#!/bin/sh
#
# Copyright (c) 1999-2005 SWsoft Inc.
# All rights reserved
#

#
# Plesk script
#


set_apache_params()
{
	apache_user="apache"
	apache_UID=80
	apache_group="apache"
	apache_GID=80
	apache_service_name="httpd"
	apache_new="2.0"

	apache_modules_d="/usr/local/psa/apache/libexec/"
	user_apxs="/usr/local/psa/apache/bin/apxs"

	apache_httpd_conf="$HTTPD_CONF_D/httpd.conf"
	apache_httpd_conf2="$HTTPD_CONF_D/httpd2.conf"
	apache_httpd_conf_in="$PRODUCT_ROOT_D/etc/httpd.conf.in"

	apache_httpd_include="$HTTPD_INCLUDE_D/zz010_psa_httpd.conf"

	APACHE_CERT="$HTTPD_CONF_D/httpd.pem"

	apache_pid_file="$APACHE_ROOT/logs/httpd.pid"
	apache_lock_file="$APACHE_ROOT/logs/httpd.lock"
	product_lock_file="$HTTPD_CONF_D/cnf.lock"

	min_suexec_UID=10000
	max_suexec_UID=16000
	min_suexec_GID=$min_suexec_UID
	max_suexec_GID=$max_suexec_UID

	suexec_storage=/usr/local/psa/apache/bin
	suexec=/usr/local/psa/apache/bin/suexec
	suexec_dir=/usr/local/psa/apache/bin
	suexec_file=suexec

	rpm_httpd_bin=/usr/sbin/httpd
}

remove_tmp_state()
{
	if [ -d "/tmp/.state" ]; then
		rm -Rf "/tmp/.state" >> $product_log 2>&1
	fi
}

#admin

set_admin_params()
{

	ADMIN_ROOT=$PRODUCT_ROOT_D/admin

	UTILS_DIR=$ADMIN_ROOT/bin

	admin_user="${product}adm"
	admin_UID=8444
	admin_group="${product}adm"
	admin_GID=8444

	admin_httpsd_conf="$ADMIN_ROOT/conf/httpsd.conf"
	ADMIN_CERT="$ADMIN_ROOT/conf/httpsd.pem"

	admin_pid_file=$ADMIN_ROOT/logs/httpsd.pid
	admin_lock_file=$ADMIN_ROOT/logs/httpsd.lock
}

lock_keyupdate()
{
	export PLESK_KEYUPDATE_DISABLED=installation
}


#fp

set_fp_params()
{
	fp_i_dir="/usr/local/frontpage"
	fp_v="version5.0"
	fpsrvadm="$fp_i_dir/$fp_v/bin/owsadm.exe"
	fp_root_def_port=80
	fp_admin="fpadmin"
	fp_admin_passwd="setup"
	fp_distrib="$PRODUCT_ROOT_D/fp.tar"
	fp_apache_stub_conf="$PRODUCT_ROOT_D/apache_tmp.conf"
#	fp_stub_head="$PRODUCT_ROOT_D/apache/conf/httpd.stub.head"
#	fp_stub_tail="$PRODUCT_ROOT_D/apache/conf/httpd.stub.tail"
}

# Print an error message and exit the program.
error()
{
    die "Exiting due to an error!  Please fix the error and try again." 
}


set_drweb_qmail_params()
{

	drweb_user="drweb"
	drweb_UID=89
	drweb_group="drweb"
	drweb_GID=89

	drweb_distrib="$PRODUCT_ROOT_D/drweb.tar"
	drweb_qmail_distrib="$PRODUCT_ROOT_D/drweb-qmail.tar"

	drweb_var_dir="/var/drweb"
}

get_admin_passwd()
{
	if [ -f "$mysql_passwd_file" ]; then
		admin_passwd=`cat "$mysql_passwd_file"`
	fi

	if [ -z "$admin_passwd" ]; then
		admin_passwd="$default_mysql_passwd"
	fi

}

#courier-imap

set_courier_imap_params()
{
	COURIER_IMAP_ROOT_D="$PRODUCT_ROOT_D/courier-imap"
	courier_imap_start="$PRODUCT_RC_D/courier-imap start"
	courier_imap_stop="$PRODUCT_RC_D/courier-imap stop"

	IMAPD_CERT="$COURIER_IMAP_ROOT_D/share/imapd.pem"
	POP3D_CERT="$COURIER_IMAP_ROOT_D/share/pop3d.pem"

	IMAPD_CONF="$COURIER_IMAP_ROOT_D/etc/imapd"
	POP3D_CONF="$COURIER_IMAP_ROOT_D/etc/pop3d"

	MAILPASSWD="$QMAIL_ROOT_D/users/poppasswd"
}

# db_test test_query awk_script
# Runs test_query and processes it with awk_script. If the output is
# not empty, return 0, otherwise return 1. Hint: supply '1' for
# awk_script to test just for the presence of any output.
db_test()
{
	local any_db=
	eval `sh_get_args '--any-db) any_db=yes;;'`

	local test_query="$1"
	local awk_script="$2"

	if [ -n "$any_db" ]; then
		local output="`mysql_raw_anydb -e \"$test_query\" 2>>\"$product_log\"`"
	else
		local output="`mysql_raw -e \"$test_query\" 2>>\"$product_log\"`"
	fi
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo -n "$output" | awk -F '\t' -- "$awk_script" | test `wc -l` -ne 0
}

#proftpd

set_ftpd_params()
{

	anonftp_user="${product}ftp"
	anonftp_group="${product}ftp"

	PROFTPD_ROOT="$PRODUCT_ROOT_D/ftpd"
}

set_jdk_params()
{
	jdk_distrib="$PRODUCT_ROOT_D/j2sdk.bin"
}

set_tomcat_params()
{
    set_common_params
 
    tomcat_distrib="$PRODUCT_ROOT_D/jakarta-tomcat.tar"
    prod_conf_t="/etc/psa/psa.conf"
    tomcat_version="4"
    CATALINA_HOME="/usr/local/psa/tomcat4"
    tomcat_user="tomcat4"
    tomcat_group="tomcat4"

    #basename directory. May be different. 
    dist_name="tomcat4"
 
    tomcat_conf="$CATALINA_HOME/conf/$dist_name.conf"
}


init_log()
{
echo >> $product_log	# initializing new output to log
echo "START LOGGING: `date`" >> $product_log
echo "SCRIPT: $0" >> $product_log
chmod 600 "$product_log"

echo >> $product_problems_log	# initializing new output to problems log
echo "START LOGGING: `date`" >> $product_problems_log
echo "SCRIPT: $0" >> $product_problems_log
chmod 600 "$product_problems_log"

problems_occured=0
}

p_echo()
{
echo "$*" >> "$product_log" 2>&1
echo "$*"
}

pnnl_echo()
{
if [ -z $necho_defined ]; then
	# set up echo
	case "`echo 'x\c'`" in
    	'x\c')
			echo="echo"
			echo_keys=" -n"
			nnl=
		;;
		x)
			echo="echo"
			echo_keys=
			nnl="\c"
		;;
		*)
			echo "ERROR: unable to set up echo."
		;;
	esac
	necho_defined=true
fi

${echo} ${echo_keys} "$*${nnl}" >> "$product_log" 2>&1
${echo} ${echo_keys} "$*${nnl}"
}

keyupdate_failure_report()
{
	if test -z "$KEYUPDATE_FAILURE_INFO"; then
		return
	fi

	p_echo
	p_echo " *****************************************************************************"
	p_echo " *                                                                           *"
	p_echo " *  ERROR:      The $PRODUCT_NAME license failed to upgrade. The failure     *"
	p_echo " *              follows:                                                     *"
	p_echo
	p_echo "$KEYUPDATE_FAILURE_INFO"
	p_echo
	p_echo " *              If you did not request the automatic key upgrade,            *"
	p_echo " *              please contact SWsoft, Inc sales department for assistance:  *"
	p_echo " *              ${sales_email}. If you want to proceed with upgrade without *"
	p_echo " *              the license upgrade, please create an empty file             *"
	p_echo " *				$prodkey                                             *"
	p_echo " *                                                                           *"
	p_echo " *****************************************************************************"
	p_echo
}

die()
{
	if [ "X$trigger_uninstall" != "X1" ]; then
		printf "\a\a"
		p_echo
		p_echo "ERROR while trying to $*"
		echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Aborting..."
			p_echo
		fi
	fi

	smart_undo_install

	keyupdate_failure_report

	selinux_close

	exit 1

}

err()
{

	if [ "X$trigger_uninstall" != "X1" ]; then
		p_echo
		p_echo "ERROR!"
		p_echo "Check the error reason(see log file: ${product_log}), fix and try again"
		p_echo
		if [ "X$do_patch" != "X1" -a "X$do_reconfigure" != "X1" ]; then
			p_echo "Exiting..."
			p_echo
		fi
	fi

	smart_undo_install

	exit 1
}

# This function needs for some print warning when some services cannot restart
# if called with arg, then we add arg to variable SR_WARNING and print warning
# message for arg, else print warning message for SR_WARNING
service_restart_warning()
{
	if [ "X$1" != "X" ]; then
		if [ "X${SR_WARNING}" = "X" ]; then
			SR_WARNING=$1
		else
			for i in ${SR_WARNING}; do
				if [ "$i" = "$1" ]; then
					break
				fi
			done
			if [ "$1" != "$i" ]; then
				SR_WARNING=$SR_WARNING" "$1
			fi
		fi
		p_echo "WARNING!"
		p_echo "Some problems occured when $1 restart, check it after installation/upgrade complete"
	        p_echo
	 	p_echo "Continue..."
		p_echo
	else
		if [ "X${SR_WARNING}" != "X" ]; then
			p_echo "WARNING!"
		        p_echo "Some problems occured when following services restart:"
			for i in ${SR_WARNING}; do
				p_echo $i
			done
			p_echo "Don't forget to check it after installation/upgrade complete"
        		p_echo
	       	        p_echo "More information can be found in log file: ${product_log}"
			p_echo
		fi
	fi
}

warn()
{
local inten
inten="$1"
p_echo
p_echo "WARNING!"
pnnl_echo "During the $inten found some problems"
echo "(see log file: ${product_log})"
p_echo
p_echo "Continue..."
p_echo

}

echo_try()
{
	msg="$*"
	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}

mk_backup()
{
	target="$1"
	dup="$2"
	opts="$3"

	if [ -L "$target" ]; then
		rm "$target"
	elif [ -$opts "$target" ]; then
		if [ ! -$opts "$target.$product_suffo" ]; then
			case "$dup" in
				mv)
					mv -f $target $target.$product_suffo || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suffo || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		else
			case "$dup" in
				mv)
					mv -f $target $target.$product_suff || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suff || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		fi
	else
		case "$opts" in
			f|d)
				;;
			*)
				p_echo " mk_backup: wrong option -- must be 'f' or 'd'"
				die "mk_backup"
				;;
		esac
	fi
}

# accumulates chown and chmod
set_ac()
{
	u_owner="$1"
	g_owner="$2"
	perms="$3"
	node="$4"

	chown $u_owner:$g_owner $node || die "chown $u_owner:$g_owner $node"
	chmod $perms $node || die "chmod $perms $node"
}

detect_vz()         
{                   
    local vzcheck_file
        
    PLESK_VZ=0
    vzcheck_file="/proc/self/status"
                    
    if [ ! -f ${vzcheck_file} ]; then
        return 1; 
    fi              
                    
    grep -q -E '^envID\:[[:space:]]*([[:digit:]]+)$' < ${vzcheck_file} >/dev/null 2>&1
                    
    if [ $? -eq 0 ]; then
        PLESK_VZ=1  
        return 0;
    fi      
    return 1;
}       

call_optional_function()
{
	local type_output="`type \"$1\" 2>/dev/null | head -n 1`"
	case "$type_output" in
		*function)
			"$@"
			;;
		*)
			return 0
			;;
	esac
}

sh_get_args()
{
	echo 'while true; do case "$1" in '"$1"'*) break;; esac; shift; done'
}

# Super server internet library

super_server_type()
{
	case "$super_server" in

		'xinetd' | 'inetd')
			;;
		*)
			# check what super-server installed
			inten="define super-server internet daemon type"
			echo_try "$inten"
			
			local xinetd_pid=`get_pids_byname "xinetd"`
			local inetd_pid=`get_pids_byname "inetd"`
			
			
			if [ -z "$xinetd_pid" ]; then
				if [ -z "$inetd_pid" ]; then
					if [ -f "$xinetd_conf" ]; then
						super_server="xinetd"
						xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
					elif [ -f "$inetd_conf" ]; then
						super_server="inetd"
					else
						die "$inten"
					fi
				else
					super_server="inetd"
				fi
			else 
				super_server="xinetd"
				xinetd_dir=`cat /etc/xinetd.conf |grep includedir| awk '{print $2; exit}' -`
			fi				 
				
			p_echo "$super_server"
			;;
	esac
}

restart_super_server()
{
	if [ -n "$CHROOTISH" ]; then
			return 0
	fi

	# if PLESK_INSTALLER_DEBUG = daemons then print process table and network status.
	# Usefull for research bugs like 63469, 51592 and other with listen/restart services.
	if [ "X$PLESK_INSTALLER_DEBUG" = "Xdaemon" ] ; then
		ps axl
		netstal -pl
	fi

	super_server_type

	case "$super_server" in

		'xinetd')

		    inten="restart xinetd daemon"
		    echo_try "$inten"
		    case "$machine" in

 		        linux)
				$PRODUCT_RC_D/xinetd reload >> $product_log 2>&1
			    ;;
	 
		        *)
	            	    # not Linux
			    xinetd_pid=`$ps | grep xinetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
				if [ "X${xinetd_pid}" = "X" ]; then
					service_restart_warning "xinetd"
				else
				    $K_USR2 $xinetd_pid >> $product_log 2>&1 && suc || die "$inten"
				fi
	            	    ;;
								 
	            esac

		;;

		'inetd')

			inetd_pid=`$ps | grep inetd | egrep "\?" | grep -v grep | head -1 | awk '{print $1}' -`
			inten="restart inetd daemon"
			echo_try "$inten"

			if [ "X${inetd_pid}" = "X" ]; then
				 service_restart_warning "inetd"
			else
				$K_HUP $inetd_pid >> $product_log 2>&1 && suc || die "$inten"
			fi
		;;
	esac
}

comment_service_xinetd()
{
	#comment service records
	local dir file service grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	for dir in $xinetd_dir; do

		for file in $dir/*; do

			grep_res=`grep "$service" $file`
			case "$?" in
				0)
					awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
						{ print \"#\"\$0; next; }
						{print}
						" <$file >$file.tmp  &&
					mv -f $file.tmp $file || die "$inten" >> $product_log 2>&1
					restart_super_server
					;;
				*)
					;;
			esac

		done;

	done;

	suc

}

comment_service_inetd()
{
	local grep_res
	service=$1

	inten="comment out record for service $service"
	echo_try "$inten"

	grep_res=`grep "^$service[[:space:]]" $inetd_conf`

	case "$?" in
	
		0)
			sed -e "s|^$service|##commented_by_psa $service|g" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
			&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" \
			&& suc || die >> $product_log 2>&1
			restart_super_server
			;;
		*)
			p_echo " no record for service $service found in the $inetd_conf"
			;;
	esac
}

comment_service()
{
	local service
	service=$1
	
	super_server_type

	case "$super_server" in

		'xinetd')
			comment_service_xinetd "$service"
			;;

		'inetd')
			comment_service_inetd "$service"
			;;

		*)
			die "Super server type is undefined"
			;;
	esac

}


remove_xinetd()
{
	local service file
	service=$1;
	
	rm -f $xinetd_dir/${service}_${product}
	
	#uncomment old records
	inten="comment out ${product} record for service $service"

	for file in $xinetd_dir/*; do
		awk "/^[[:space:]]*#[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ \
			{ print substr(\$0,2); next; }
			{print}
			" <$file >$file.tmp &&
		mv -f $file.tmp $file >> $product_log 2>&1
	done;

	restart_super_server

}

remove_inetd()
{
	local service
	service=$1;

	case "$service" in

		ftp)
			inten="restore ftp service record in the $inetd_conf"

			sed -e "s|^ftp.*/${product}/ftpd/sbin/proftpd.*||g" \
				-e "s|ftp.*/${prev_product}/ftpd/sbin/proftpd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtp)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtp.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtp.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtp.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		smtps)
			inten="restore smtp service record in the $inetd_conf"

			sed -e "s|^smtps.*$QMAIL_ROOT_D/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|^smtps.*${product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				-e "s|smtps.*${prev_product}/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/relaylock.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
		    ;;

		pop3)
			inten="restore pop3 service record in the $inetd_conf"

			sed -e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				-e "s|^pop[-]*3.*/qmail/bin/tcp-env.*tcp-env.*/qmail/bin/pop3$||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			
		    ;;
		poppassd)
			# poppassd stream tcp nowait root /usr/sbin/tcpd /${PRODUCT_ROOT_D}/admin/bin/poppassd
			inten="restore poppassd service record in the $inetd_conf"

			sed -e "s|^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*||g" \
				< $inetd_conf > $inetd_conf.${product}_tmp \
			&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1
			;;
		
	esac

	# uncomment old records
	sed -e "s|^##commented_by_psa $service|$service|g" < $inetd_conf > $inetd_conf.${product}_tmp \
	&& mv -f $inetd_conf.${product}_tmp $inetd_conf >> $product_log 2>&1

	restart_super_server

}

remove_super_server()
{
	local service
	service=$1;

	super_server_type

	case "$super_server" in

		xinetd)
			remove_xinetd "$service"
			;;
		inetd)
			remove_inetd "$service"
			;;
	esac
}

setup_xinetd()
{
	local service file rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	#comment old records
	comment_service "$service"	
	
	#setup
	service=$1;
	inten="set up record for service $service"
	echo_try "$inten"

	case "$service" in

		ftp)
			echo "
service ftp
{
	socket_type		= stream
	protocol		= tcp
	wait			= no
	disable			= no
	user			= root
	instances		= UNLIMITED
	server			= $PRODUCT_ROOT_D/ftpd/sbin/proftpd
	server_args		= -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf
}" > "$xinetd_dir/ftp_${product}" || die "$inten"
			;;

		smtp)

			case "$rbl_on" in

				on)				
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;

				*)
					echo "
service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtp_${product}" || die "$inten"
					;;
			esac	
			;;

		smtps)
			case "$rbl_on" in
				on)				
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
				*)
					echo "
service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	instances       = UNLIMITED
	server          = $QMAIL_ROOT_D/bin/tcp-env
	server_args     = $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $TRUE_BIN $QMAIL_ROOT_D/bin/cmd5checkpw $TRUE_BIN
}" > "$xinetd_dir/smtps_${product}" || die "$inten"
					;;
			esac	
			;;

		poppassd)
			echo "
service poppassd
{
	socket_type		= stream
	protocol		= tcp
	port			= 106
	wait			= no
	disable			= no
	user			= root
	instances		= 1000
	flags			= KEEPALIVE
	server			= $PRODUCT_ROOT_D/admin/bin/poppassd
}" > "$xinetd_dir/poppassd_${product}" || die "$inten"
			;;
	esac

    case "$machine" in
       Darwin)
echo '#!/bin/sh

name_service='org.xinetd.xinetd'
    
    case "$1" in
        start)
           echo "Plesk: Starting xinetd"
           launchctl start "$name_service"
        ;;
        stop)
           echo "Plesk: Stopping xinetd"
           launchctl stop "$name_service"
        ;;
        restart)
           start
           stop
        ;;
        *)
           echo "Usage: xinetd [start|stop|restart]"
        ;;
    esac 
' > "$PRODUCT_RC_D/xinetd"

     chmod 755 "$PRODUCT_RC_D/xinetd"
       ;;
       *)
       ;;
    esac

	suc
}

setup_inetd()
{
	local service rbl_on rbl_server

	service=$1;
	rbl_on=$2;
	rbl_server=$3;
	
	local ftp_rec smtp_rec pop3_rec 

	ftp_rec="ftp stream tcp nowait root $PRODUCT_ROOT_D/ftpd/sbin/proftpd proftpd -c $PRODUCT_ROOT_D/ftpd/etc/proftpd.conf"
	
	case "$linux_distr" in
		debian)
			maxconn='.1000'
		;;
		*)
		        maxconn=""
		;;
	esac

	case "$rbl_on" in
		on)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $RBLSMTPD $rbl_server $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
		*)
			smtp_rec="smtp stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			smtps_rec="smtps stream tcp nowait$maxconn root $QMAIL_ROOT_D/bin/tcp-env tcp-env  $QMAIL_ROOT_D/bin/relaylock $QMAIL_ROOT_D/bin/qmail-smtpd $QMAIL_ROOT_D/bin/smtp_auth $QMAIL_ROOT_D/bin/true $QMAIL_ROOT_D/bin/cmd5checkpw $QMAIL_ROOT_D/bin/true"
			;;
	esac

	case "$machine" in
		BSD*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/libexec/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
		*)
			poppassd_rec="poppassd stream tcp nowait/1000 root /usr/sbin/tcpd $PRODUCT_ROOT_D/admin/bin/poppassd"
			;;
	esac

	case "$service" in

		ftp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "ftp"
				/usr/sbin/update-inetd --add "$ftp_rec"

			else
				grep_res=`egrep "^ftp.*/${product}/ftpd/sbin/proftpd*." $inetd_conf`
				inten="add ftp service (proftpd) record into the $inetd_conf file"
				echo_try $inten

				case "$grep_res" in
					ftp*)
						p_echo
						p_echo " ftp service (proftpd) is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$ftp_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;

		smtp)
			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtp"
				/usr/sbin/update-inetd --add "$smtp_rec"

			else
				egrep "^smtp.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtp/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtp service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtp_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		smtps)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "smtps"
				/usr/sbin/update-inetd --add "$smtps_rec"

			else

				egrep "^smtps.*$QMAIL_ROOT_D/bin/tcp-env.*tcp-env.*$QMAIL_ROOT_D/bin/relaylock.*$" "$inetd_conf" >> $product_log 2>&1
				case "$?" in
					0)
						sed -e "/^smtps/d" < "$inetd_conf" > "$inetd_conf.${product}_tmp" \
						&& mv -f "$inetd_conf.${product}_tmp" "$inetd_conf" || die >> $product_log 2>&1
						;;
					1)
						comment_service $service
						;;
					*)
						err
						;;
				esac

				inten="add smtps service record into the $inetd_conf file"
				echo_try $inten
				echo "$smtps_rec"  >> $inetd_conf  && suc || die $inten
			fi
			;;

		poppassd)

			if [ -x /usr/sbin/update-inetd ]; then

				# Use Debian inetd config manipulation facility
				/usr/sbin/update-inetd --remove "poppassd"
				/usr/sbin/update-inetd --add "$poppassd_rec"
			else
				#	^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*
				grep_res=`egrep "^poppassd.*$PRODUCT_ROOT_D/admin/bin/poppassd.*" $inetd_conf`
				inten="add poppassd service record in the $inetd_conf"
				echo_try $inten
		
				case "$grep_res" in
					poppassd*)
						p_echo
						p_echo " poppassd service is already in the $inetd_conf"
						;;
					*)
						comment_service $service
						echo "$poppassd_rec" >> $inetd_conf && suc || die
						;;
				esac
			fi
			;;
	esac

}

setup_super_server()
{
	local service rbl_on rbl_server
	service=$1;
	rbl_on=$2;
	rbl_server=$3;

	super_server_type

	case "$super_server" in

		xinetd)
			setup_xinetd "$service" "$rbl_on" "$rbl_server"
			;;
		inetd)
			setup_inetd "$service" "$rbl_on" "$rbl_server"
			;;
	esac

	restart_super_server
}

get_pid()
{
	local i

	ex_f="$1"
	opt="$2"
	owner="$3"

	min_num=`expr 1`

	case "$opt" in
		false)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		true)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep "$owner" | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		*)
			p_echo "get_pid: wrong parameter"
			die "get_pid $ex_f $opt $owner"
			;;
	esac

	common_var=$min_num
	return $min_num
}

kill_pids()
{
	ex_f="$1"
	owner="$2"

	for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep $owner | awk '{print $2}' -`; do
		if [ $i -gt 1 ]; then
			$K_TERM $i >> $product_log 2>&1
		fi
	done
}

get_pids_byname()
{
	proc_name="$1"
	PIDS=`ps axww | awk '$5 ~ "'$proc_name'$" {print $1}'`
	echo $PIDS
}

#lib_test

test_for_root()
{
	my_id="`id`"
	case "$my_id" in
		uid=0\(root\)*)
			;;
		*)	echo "$0: This script must be run as root"
			echo "Log in as root then run this script again."
			echo
			exit 1
			;;
	esac
}
get_userID()
{
# try to get UID
	common_var=`id -u "$1" 2>/dev/null` 

# if id returns 0 the all is ok
	if [ "$?" -eq "0" -a ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

get_groupID()
{
# try to get GID, id -g doesn't show groups without users
    case "$machine" in
       Darwin)
         common_var=`nireport / /groups name gid| grep "$1"| awk '{print $2}'`
       ;;
	   *)
         common_var=`cat /etc/group | awk -F':' '$1 == "'$1'" {print $3}'` 
       ;;
    esac

# We have non-empty value if success
	if [ ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

delete_user()
{
	local rm_user

	rm_user="$1"

	# if it is mailman user, remove its crontab from system
	if [ "X${rm_user}" = "X${mailman_user}" ]; then

		inten="remove crontab of ${rm_user}"
		echo "y" | $crontab -u "${mailman_user}" -r >> $product_log 2>&1 || die "$inten"

	fi

	inten="remove user $rm_user"
	echo_try "$inten"

	case "$machine" in
		BSD)
			echo "y" | pw userdel $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmuser $rm_user>> $product_log 2>&1 && suc || die "$inten"
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1

		;;
		linux|solaris)
			userdel  $rm_user>> $product_log 2>&1 && suc || die "$inten"
		;;
		Darwin)
			niutil -destroy / /users/"$rm_user" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
}

delete_group()
{
	local rm_group

	rm_group="$1"

	inten="remove group $rm_group"
	echo_try "$inten"

	case "$machine" in
		BSD)
			pw groupdel $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		BSDI)
			rmgroup $rm_group>> $product_log 2>&1
			pwd_mkdb /etc/master.passwd >> $product_log 2>&1
		;;
		linux|solaris)
			mk_backup "/etc/group" cp f
			if [ -f "/etc/group" ]; then
				sed -e "/$rm_group/d" < /etc/group > /etc/group.tmp || die $inten
				mv -f /etc/group.tmp /etc/group  >> $product_log 2>&1
				if [ "$?" -ne 0 ]; then
					rsr_backup "/etc/group" cp f
					die $inten
				fi
			fi
#		groupdel  $rm_group>> $product_log 2>&1
		;;
		Darwin)
			niutil -destroy / /groups/"$rm_group" >> $product_log 2>&1 && suc || die "$inten"
		;;
	esac
	suc
}
initial_conf()
{
	DEMO_VERSION="no"
	PRODNAME="psa"
	PRODUCT_NAME="Plesk"
	product_full="Plesk"
	PRODUCT_FULL_NAME="Plesk"

	product_etc="/etc/${PRODNAME}"
	prod_conf_t="/etc/psa/psa.conf"
	prodkey="$product_etc/$PRODNAME.key"

	minimal_changes=""

	MYSQL_VERS="4.1.18"
	POSTGRESQL_VERS="7.4.11"
	EXTERNAL_PACKAGES="expat libiconv localedata compat4x compat5x"
	EXTERNAL_PACKAGES_DIR=""tmp/packages""

	BUILDER_UID="10007"

	PERL5LIB="/usr/local/psa/lib/perl5/site_perl/5.8.8:/usr/local/psa/lib/perl5/site_perl/5.8.8/mach"
	export PERL5LIB

	product_bs=Plesk
        support_contact="http://www.swsoft.com/support"
	sales_email="sales@swsoft.com"

	product_version="8.0.1"
	product_db_version="0801"
	product_build="80061018.20"
	conceived_os_vendor=FreeBSD
	conceived_os_version="6.0"
	osrels="fr6.0"

	# This variable contains all versions, which is supported by
	# cumulative upgrade
	known_product_versions="71 75 80"

	prev_product="plesk"
	prev_clients_group="${prev_product}cln"

	# GID for mailman
	mm_mailgroup=110

	# plesk default password
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		PRODUCT_DEFAULT_PASSWORD="plesk"
	else
		PRODUCT_DEFAULT_PASSWORD="setup"
	fi

	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
		echo "Unable to determine current working directory."
		echo "Please fix the problem and run installation again."
		exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
		0)
			my_name="$my_name_2"
		;;
		1)
			my_name="$my_name_0"/"$my_name_2"
		;;
	    *)
			echo "Unable to determine the name of installer."
			echo "Please fix the problem and run installation again."
			exit 1
		;;
	esac
}

read_conf()
{
	initial_conf

	if [ -s $prod_conf_t ]; then
		tmp_var=`perl -e 'undef $/; $_=<>; s/#.*$//gm;
				s/^\s*(\S+)\s*/$1=/mg;
				print' $prod_conf_t`
		eval $tmp_var
	else
		[ 0$ignore_miss_conf -ne 1 ] && p_echo "Unable to find product configuration file: $prod_conf_t"
		return 1
#		die "find product configuration file: $prod_conf_t"
	fi
	return 0

}

selinux_close()
{
	if [ -z "$SELINUX_ENFORCE" -o "$SELINUX_ENFORCE" = "Disabled" ]; then
		return
	fi

	setenforce "$SELINUX_ENFORCE"
}


#set_params

set_common_params()
{

	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	LANG=C
	export PATH LANG
	umask 022
	ulimit -n 65535 2>/dev/null

	K_HUP="/bin/kill -HUP"
	K_KILL="/bin/kill -KILL"
	K_TERM="/bin/kill -TERM"
	K_USR2="/bin/kill -USR2"

	users_created=""
	groups_created=""

	certificate_file="$PRODUCT_ROOT_D/etc/httpsd.pem"
	product=${PRODNAME}
	START_SH="$PRODUCT_RC_D/${product}"

	clients_group="${product}cln"
	clients_GID=10001

	services_group="${product}serv"
	services_GID=10003

	product_suff="saved_by_${product}".`date "+%m.%d;%H:%M"`
	product_suffo="saved_by_${product}"

	common_var=0

	services="/etc/services"
	mtab="/etc/mtab"
	xinetd_conf="/etc/xinetd.conf"
	xinetd_dir="/etc/xinetd.d"
	inetd_conf="/etc/inetd.conf"
	syslog_conf="/etc/syslog.conf"
	syslog_conf_ng="/etc/syslog-ng/syslog-ng.conf"
	get_hostname="hostname"
	get_domainname="domainname"

	#VZP used to determine that we're inside SVE
	vza_file="/var/vzagent"

	PREV_PRODUCT_ROOT_D="/usr/local/${prev_product}"

	#default parameters
	tar="tar"
	crontab="/usr/bin/crontab"

	#machine depended parameters
	TARGET_OS="`uname -a`"
	case "$TARGET_OS" in

		BSD/OS*BSDI*i386)
			machine="BSDI"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			compress="compress"
			uncompress="uncompress -c"
			uudecode="uudecode -o /dev/stdout"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		FreeBSD*i386)
			fstab="/etc/fstab"
			machine="BSD"
			sendmail="/usr/sbin/sendmail"
			mail_local="/usr/libexec/mail.local"
			ps="ps axw"
			ps_long="ps axfwu"
			dummy_shell="/sbin/nologin"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/usr/local/bin/bash"
			rbash_shell="/usr/local/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			os_version=`uname -v | sed -e 's/^.*FreeBSD[ \t][ \t]*\([0-9\.][0-9\.]*\)-.*$/\1/'`

			if tar --version | grep bsdtar > /dev/null ; then
				if which gtar > /dev/null; then
				    tar="gtar"
				else
				    echo "Unable to locate gtar on your system."
				    echo "Please, install the archiving software and retry installation."
				    exit 1
				fi
			fi

			named_osrelease=040100 # "must be >= 020218 for  named -u <named> "
			;;
		Darwin*powerpc)
			machine="Darwin"
			sendmail="/usr/sbin/sendmail"
			mail_local=""
			ps="ps axw"
			ps_long="ps axSwu"
			dummy_shell="/usr/bin/false"
			dummy_home="/"
			false_shell="/usr/bin/false"
			bash_shell="/bin/bash"
			rbash_shell="/bin/rbash"
			compress="gzip -9 -c"
			uncompress="gunzip -c"
			uudecode="uudecode -p"
			uudecode_full="/usr/bin/uudecode"
			ifconfig="/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab.hd"
			;;

		SunOS*5.*sun4*)
			machine="solaris"
			inetd_conf="/etc/inet/inetd.conf"
			services="/etc/inet/services"
			crontab="/bin/crontab"
			useradd_options=""
			sendmail="/usr/lib/sendmail"
			sndml_ini="/etc/init.d/sendmail"
			mail_local="/usr/lib/mail.local"
			ps="ps -e"
			ps_long="ps -aef"
			dummy_shell="/bin/false"
			dummy_home="/"
			false_shell="/bin/false"
			compress="compress"
			uncompress="uncompress"
			uudecode="uudecode -p"
			uudecode_full="/bin/uudecode"
			tar="gtar"
			ifconfig="/usr/sbin/ifconfig -a"
			inet_str="inet"
			named_osrelease=0
			fstab="/etc/fstab"
			;;

		Linux*2.?.*i?86*| \
		Linux*2.?.*x86_64*)
			get_hostname="hostname -f"
			fstab="/etc/fstab"
			if [ -f /etc/slackware-version ]; then
			    machine="linux"
			    linux_distr="slackware"
			    useradd_options=""
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/rc.d/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell=""
			    dummy_home="/"
			    false_shell="/bin/false"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=0
			else
			    machine="linux"
				useradd_options="-M"
				if [ -f /etc/mandrake-release ]; then
			    	linux_distr="mandrake"
				elif [ -f /etc/fedora-release ]; then
			    	linux_distr="fedora"
				elif [ -f /etc/SuSE-release ]; then
			    	linux_distr="suse"
				elif [ -f /etc/debian_version ]; then
			    	linux_distr="debian"
					get_domainname="dnsdomainname"
					useradd_options=""
				else
			    	linux_distr="redhat"
				fi
			    sendmail="/usr/sbin/sendmail"
			    sndml_ini="/etc/init.d/sendmail"
			    mail_local="/usr/libexec/mail.local"
			    ps="ps axw"
			    ps_long="ps axuw"
			    dummy_shell="/bin/false"
			    dummy_home="/"
			    false_shell="/bin/false"
				bash_shell="/bin/bash"
				rbash_shell="/bin/rbash"
			    compress="gzip -9 -c"
			    uncompress="gunzip -c"
			    uudecode="uudecode -o /dev/stdout"
			    uudecode_full="/usr/bin/uudecode"
			    ifconfig="/sbin/ifconfig -a"
			    inet_str="inet addr"
			    named_osrelease=`cat /proc/sys/kernel/osrelease | perl -F"/[.-]/" -n -a  -e 'printf "%02u%02u%02u\n", $F[0],$F[1],$F[2]'`
			fi
			;;
		*)
			echo
			echo "Sorry, but your configuration isn't supported yet"
			echo "uname is $TARGET_OS"
			echo
			echo "For more information, please contact $support_email"
			echo
			;;
	esac

	# setup process
	if [ "X$process" = "X" ]; then
		if   [ "X$do_reconfigure" = "X1" ]; then
	    	process="reconfiguration"
		elif  [ "X$do_upgrade" = "X1" ]; then
	    	process="upgrade"
		else
		    process="installing"
		fi
	fi

#	common_var="real"
#	if [ -f $PRODUCT_ROOT_D/version -a "X$do_patch" = "X" ]; then
#	    common_var=`cat $PRODUCT_ROOT_D/version | tr '[:blank:]' '_'`
	product_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_${process}.log"
	product_problems_log="/tmp/${product}_${product_version}_${conceived_os_vendor}_${conceived_os_version}_build${product_build}_problems.log"
	init_log
#	elif [ "X$my_name_1" != "X" ]; then
#	    product_log="/tmp/${my_name_1}.log"
#	else
#	    product_log="/tmp/${product}_default_${process}.log"
#	fi

	detect_vz
}


set_local_params()
{
	set_common_params

	for i in set_apache_params set_admin_params lock_keyupdate set_fp_params set_drweb_qmail_params set_courier_imap_params set_ftpd_params set_jdk_params set_tomcat_params set_logrotate_params set_mailman_params set_mysqld_params set_named_params set_openssl_params set_pgsql_params set_qmail_params set_spamassassin_params set_vhosts_params set_webalizer_params set_horde_params ; do
		$i
		local res="$?"
		if [ "0$res" -gt 0 ]; then
			return "$res"
		fi
	done
}
set_logrotate_params()
{
	# primary Plesk logrotate config file
	logrotate_conf="${product_etc}/logrotate.conf"

	# directory for logrotate configs of virtual hosts
	logrotate_include_d="${PRODUCT_ROOT_D}/etc/logrotate.d"
}

#all functions in this file are valid for Standard builds only
set_mailman_params()
{
	mailman_user="mailman"
	mailman_group="mailman"
	mailman_UID=91
	mailman_GID=91
	MAILMAN_ROOT_D="${PRODUCT_ROOT_D}"/mailman
	MAILMAN_VHOST_D="${HTTPD_VHOSTS_D}"/mailman
}

remove_modules()
{
	p_echo
	p_echo "===> Removing modules"

	local moduledir
	for moduledir in $PRODUCT_ROOT_D/var/modules/*; do
		if [ -d "$moduledir" -a -x "$moduledir/uninstall" ]; then
			local module=`basename $moduledist`
			echo_try "uninstall $module module"
			"$moduledir/uninstall" && suc || warn "uninstallation of $module module"
		fi
	done
}

#mysql

set_mysqld_params()
{
	mysql_user="mysql"
	mysql_UID=3306
	mysql_group="mysql"
	mysql_GID=3306

	product_db_sql="$PRODUCT_ROOT_D/etc/${PRODNAME}_db.sql"

	mysql_passwd_file="$product_etc/.${PRODNAME}.shadow"
	default_mysql_passwd="$PRODUCT_DEFAULT_PASSWORD"
	prev_mysql_passwd_file="$PREV_PRODUCT_ROOT_D/admin/conf/admin.conf"

#	admin_passwd=${default_mysql_passwd}
	get_admin_passwd

	set_mysql_client_params
	set_mysql_server_params
}

## @@constructor set_mysqld_params

set_mysql_server_params()
{
	MYSQL_ROOT="$PRODUCT_ROOT_D/mysql"
	mysql_bindir="$MYSQL_BIN_D"
	mysql_service="mysqld"
}

set_mysql_client_params()
{
	mysql_client="$MYSQL_BIN_D/mysql"

	# Override these variables as needed
	mysql_db_name="$PRODNAME"
	mysql_auth="-uadmin -p$admin_passwd"
	mysql_args="-N"
	mysql_args_raw="-B -r"

	# For backward compatibility only, should use mysql() and mysql_raw() instead
	mysql=mysql
	mysql_raw=mysql_raw
}

# Invoke mysql
mysql()
{
	mysql_anydb -D$mysql_db_name "$@"
}

mysql_anydb()
{
	if test -z "$DB_IS_MYSQL41_COMPATIBLE"; then
		mysql41_init
	fi

	if test "$DB_IS_MYSQL41_COMPATIBLE" != "compatible"; then
		mysql41_exec_wrapper $mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	else
		$mysql_client $mysql_auth $mysql_args "$@" 2>>"$product_log"
	fi

	local status=$?
	if [ $status -gt 0 ]; then
		$mysql_client $mysql_auth $mysql_args -D$mysql_db_name $mysql_args_raw -e "show innodb status" >>"$product_log" 2>&1
	fi
	return $status
}

# the function removes the "character set xxx" and "collate xxx" construction
# from -e * arguments, if there are any.
# otherwise, it removes the same things from standard input
mysql41_exec_wrapper()
{
	perl -e '$has_command = 0;
		$program = $ARGV[0];
		splice (@ARGV, 0, 1);
		sub remove_chasets($)
		{
			$refStr = shift;
			$$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+binary(\s+collate\s+[\w]+)?\b/ $1blob /ig;
            $$refStr =~ s/\b(medium|long|tiny)?text\s+character\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b/ $1blob /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+binary(\s+collate\s+[\w]+)?\b)/ binary /ig;
			$$refStr =~ s/(\bcharacter\s+set\s+[\w]+\s+collate\s+[\w]+_bin\b)/ binary /ig;
			$$refStr =~ s/(\b(character\s+set|collate)\s+[\w]+\b)//ig;
		}
		foreach $n (0 .. $#ARGV) {
			if ($ARGV[$n] eq "-e") {
				$has_command = 1;
				remove_chasets \($ARGV[$n + 1]);
			}
		}
		if ($has_command) {
			exec $program, @ARGV or die "Cannot exeecute mysql";
		} else {
			open out_command, "|-", $program, @ARGV or die "Cannot start mysql";
			while (<STDIN>) {
				remove_chasets \($_);
				print out_command $_;
			}
			close out_command or die($! ? "Mysql returned an error: $!" : "Mysq exited with non-zero status $?");
		}' -- "$@"
}

# Invoke mysql in raw mode
mysql_raw()
{
	mysql $mysql_args_raw "$@"
}

mysql_raw_anydb()
{
	mysql_anydb $mysql_args_raw "$@"
}

mysql41_init()
{
	# not_installed is the default state
	# we must init it to avoid endless cycle
	DB_IS_MYSQL41_COMPATIBLE=not_installed
	if ! mysql_anydb </dev/null >>"$product_log" 2>&1; then
		return
	fi

	if db_test --any-db "SHOW VARIABLES LIKE 'version'" '$2 !~ /^(3|4\.0)\./'; then
		# if database is not yet initiailized, assume it compatible
		# otherwise, check the flag
		if
			db_test --any-db "SHOW DATABASES" '/^psa$/' \
			&& db_test "SHOW TABLES" '/^misc$/' \
			&& ! db_test "SELECT val FROM misc WHERE param = 'mysql41_compatible'" '/true/'
		then
			DB_IS_MYSQL41_COMPATIBLE='not_compatible'
		else
			DB_IS_MYSQL41_COMPATIBLE='compatible'
		fi
	fi
}

#named

set_named_params()
{
	# set up default values
	bind_UID=53
	bind_GID=53
	bind_user="bind";
	bind_group="bind";

	# get UID of named user, if exists
	get_userID $bind_user
	if [ $? -ne 0 ]; then
	    bind_UID=$common_var;
        fi

	# get GID of named group, if exists
	get_groupID $bind_group
	if [ $? -ne 0 ]; then
	    bind_GID=$common_var;
	fi

	# old named is not able to run in non-root environment
	if [ 0$named_osrelease -lt 020218 ]; then
	    bind_user="root";
	    bind_UID=0;
	fi

	# path to directory of internal named
	NAMED_ROOT_D="${PRODUCT_ROOT_D:?'PRODUCT_ROOT_D is undefined'}/named"

	# path to directory of named pid file
	bind_run="${NAMED_RUN_ROOT_D:?'NAMED_RUN_ROOT_D is undefined'}/var/run/named"
	# Named start/stop script
	NAMED_RC_SCRIPT="/etc/rc.d/named"
	
	# path to named config file
	named_conf="/etc/named.conf"
	rndc_conf="/etc/rndc.conf"
	rndc_namedb_conf="/etc/namedb/rndc.conf"
	rndc_bind_conf="/etc/bind/rndc.conf"
}
set_openssl_params()
{
    openssl_psa_sbin=${PRODUCT_ROOT_D}/admin/sbin/openssl;
    openssl_psa_bin=${PRODUCT_ROOT_D}/admin/bin/openssl;
    openssl_std_bin=/usr/bin/openssl;
}
set_pgsql_params()
{
	pgsql_user="postgres"
	pgsql_group="postgres"
	pgsql_UID=5432
	pgsql_GID=5432

	# path to postgresql for Standard builds
	PGSQL_ROOT_D="$PRODUCT_ROOT_D/postgresql"
}

#qmail

set_qmail_params()
{
QMAIL_DIR="/usr/local/psa/qmail"
QMAIL_USERS="alias:2021:nofiles:false:alias  qmaild:2020:nofiles:false:  qmaill:2022:nofiles:false:  qmailp:2023:nofiles:false:  qmailq:2520:qmail:  qmailr:2521:qmail:  qmails:2522:qmail:"
QMAIL_GROUPS="qmail:2520  nofiles:2020"
}
#values of variables in set_spamassassin_params are valid for Standard builds only

set_spamassassin_params()
{
	SPAMASSASSIN_ROOT_D=${PRODUCT_ROOT_D}/spamassassin
}

rsr_backup()
{
	target="$1"
	dup="$2"
	opts="$3"
	common_var=0

#	if [ -$opts "$target" ]; then
		if [ -$opts "$target.$product_suff" ]; then
			case "$dup" in
				mv)
					mv -f  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			esac
		else
			if [ -$opts "$target.$product_suffo" ]; then
			    case "$dup" in
				mv)
					mv -f  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			    esac
			fi
		fi
#	else
#		case "$opts" in
#			f|d)
#				;;
#			*)
#				p_echo " rsr_backup: wrong option -- must be 'f' or 'd'"
#				;;
#		esac
#	fi
}

restore_named()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1
	[ -f /etc/sysconfig/named ] && mv -f "/etc/sysconfig/named" "/etc/sysconfig/named.bak"
	rsr_backup "/etc/sysconfig/named" mv f

	[ -L $named_conf ] && rm -f "$named_conf"
	rsr_backup "$named_conf" mv f

	[ -L $rndc_conf ] && rm -f "$rndc_conf"
	rsr_backup "$rndc_conf" mv f

	case "$machine" in
		BSD*)
			rsr_backup /etc/named.boot mv f
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --add named >> $product_log 2>&1
#			    std_named_sh="/etc/rc.d/init.d/named"
#			    rsr_backup $std_named_sh mv f
#				if [ -f "$std_named_sh" ]; then
#					mv -f "$std_named_sh.${product}" "$std_named_sh"
#				fi
				;;
			slackware)
			    rsr_backup /etc/rc.d/rc.inet2 cp f
				;;
		    esac
			rsr_backup /etc/named.boot mv f
			;;
		solaris)
			rsr_backup /etc/named.boot mv f
			;;
	esac
}


restore_sendmail()
{
	[ -L $sendmail ] && rm -f "$sendmail"
	[ -L /usr/lib/sendmail ] && rm -f "/usr/lib/sendmail"

	rsr_backup "$sendmail" mv f

	case "$machine" in
		BSDI)
			rsr_backup /etc/sendmail.cf mv f
			;;
		*)
			;;
	esac

	if [ -f "$mail_local" ]; then
#		case "$machine" in
#			BSD)
#				chflags schg "$mail_local" >> $product_log 2>&1
#				;;
#			*)
#				;;
#		esac

		rsr_backup "$mail_local" mv f

		chmod 4555 "$mail_local" >> $product_log 2>&1
	fi
	case "$machine" in
		linux )
		    case "$linux_distr" in
			redhat)
			    chkconfig --add sendmail >> $product_log 2>&1
#			    rsr_backup "$sndml_ini" mv f
				;;
			slackware)
			     rsr_backup /etc/rc.d/rc.M mv f
				;;
		    esac
			;;
		solaris)
			rsr_backup "$sndml_ini" mv f
			;;
		*)
			;;
	esac

}

delete_startup_scripts()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1

	case "$machine" in
		BSD)
			rm -f /usr/local/etc/rc.d/${product}.sh >> $product_log 2>&1
	#		rsr_backup /etc/rc.conf cp f

#			inten="enable standard sendmail & named (within /etc/rc.conf)"
#			echo_try $inten
			sed -e 's/^sendmail_enable="NONE".*//g' \
				-e "s/^#named_enable/named_enable/g" \
				< /etc/rc.conf > /etc/rc.conf.${product}_tmp
			mv -f /etc/rc.conf.${product}_tmp /etc/rc.conf
#			suc
			;;
		BSDI)
			if [ -f /etc/rc.local.${product} ]; then
				cp -p  /etc/rc.local.${product} /etc/rc.local >> $product_log 2>&1
			fi
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --del ${product}
			    rm -f /etc/rc.d/init.d/${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc0.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc1.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc2.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc3.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc4.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc5.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc6.d/K15${product} >> $product_log 2>&1
				;;
			slackware)
			    if [ -f /etc/rc.d/rc.local.${product} ]; then
				cp -p  /etc/rc.d/rc.local.${product} /etc/rc.d/rc.local >> $product_log 2>&1
			    fi
				;;
		    esac
		    ;;
		solaris)
			rm -f  /etc/init.d/${product} >> $product_log 2>&1
			if [ -f /etc/rc0.d/K01${product} ]; then
				rm -f /etc/rc0.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc1.d/K01${product} ]; then
				rm -f /etc/rc1.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc2.d/S77${product} ]; then
				rm -f /etc/rc2.d/S77${product} >> $product_log 2>&1
			fi
			;;
	esac
}

delete_crontab()
{

	$crontab -l 2>/dev/null > /tmp/crontab.${product}

	sed -e "s/^.*\/${product}\/admin\/sbin\/statistics.*//g" \
		-e "s/^.*\/${product}\/bin\/mysqldump.*//g" \
		-e "s/^.*\/usr\/sbin\/ntpdate.*//g" \
		< /tmp/crontab.${product} > /tmp/crontab.${product}_tmp

	mv -f /tmp/crontab.${product}_tmp /tmp/crontab.${product} >> $product_log 2>&1

	$crontab /tmp/crontab.${product}  >> $product_log 2>&1

	rm -f /tmp/crontab.${product} >> $product_log 2>&1

}

remove_ftpuser()
{
	user=$1
	ftpusers_file="/etc/ftpusers"

	egrep "^$user" $ftpusers_file >> /dev/null 2>&1

	case "$?" in
			0)
				sed -e "/$user/d" < $ftpusers_file > $ftpusers_file.tmp
				mv -f $ftpusers_file.tmp $ftpusers_file
				;;
			1)
				;;
			*)
				;;
	esac

}

remove_product_users_groups()
{

#	delete users of this(unsuccessful) installation
	for i in $users_created; do
		delete_user "$i"
	done
#	delete users with group=psacln (ftpusers and webusers)
	for i in `perl -e '$gid=getgrnam("'$clients_group'"); exit if (($gid eq "") || ($gid == 0)); while(($n,$u,$g) = (getpwent)[0,2,3]) {print "$n\n" if (($gid == $g) && ($u >= 500))}'`
	do
		delete_user "$i"
		remove_ftpuser "$i"
	done
#	delete users psaadm, psaftp
#	delete_user "$admin_user"  >> "$product_log" 2>&1
#	delete_user "$anonftp_user"  >> "$product_log" 2>&1

#	delete groups of this(unsuccessful) installation
	for i in $groups_created; do
		delete_group "$i"
	done
#	delete groups psaadm, psaftp, psacln
	delete_group "$admin_group"  >> "$product_log" 2>&1
	delete_group "$anonftp_group"  >> "$product_log" 2>&1
	delete_group "$clients_group"  >> "$product_log" 2>&1

}


undo_install()
{
	p_echo
	p_echo

	get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
	req_pid=$common_var
	if [ $req_pid -gt 1 ]; then
		p_echo "===>Removing installed ${product_bs} components ... "
		remove_modules

		# kill mysql
		$K_KILL $req_pid >> $product_log 2>&1
		sleep 2
		mysql_pid_file=$mysql_bddir/*.pid
		kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
		sleep 2
		if [ -f "$mysql_pid_file" ]; then
			rm -f "$mysql_pid_file"
		fi
	fi

	$START_SH stop >> "$product_log" 2>&1
	sleep 2

	remove_super_server "ftp"
	remove_super_server "pop3"
	remove_super_server "pop-3"
	remove_super_server "imap4"
	remove_super_server "imap2"
	remove_super_server "imap"
	remove_super_server "smtp"
	remove_super_server "smtps"
	remove_super_server "poppassd"

	remove_product_users_groups

	if [ -f "/etc/ftpchroot" ]; then
	    sed -e "s/^@$clients_group//g" < /etc/ftpchroot > /etc/ftpchroot.tmp
	    mv -f /etc/ftpchroot.tmp /etc/ftpchroot  >> $product_log 2>&1
	fi

	if [ -f /etc/shells ]; then
	    case "$machine" in
		BSD|BSDI)
		    sed -e "s/[/]*sbin[/]*nologin//" < /etc/shells > /etc/shells.tmp
		;;
		linux|solaris)
		    sed -e "s/[/]*bin[/]*false//" < /etc/shells > /etc/shells.tmp
		;;
	    esac
	    mv -f /etc/shells.tmp /etc/shells  >> $product_log 2>&1
	fi

#	remove /tmp/.state for ASP
	remove_tmp_state

	restore_named
	restore_sendmail
#	rsr_backup $inetd_conf mv f
#	rsr_backup /etc/my.cnf mv f
#	rsr_backup /etc/named.boot mv f
	delete_startup_scripts
	delete_crontab

	rm -rf $fp_i_dir  >> $product_log 2>&1
	rsr_backup $fp_i_dir mv d
	cd /usr/local  >> $product_log 2>&1
	rm -Rf $PRODUCT_ROOT_D >> $product_log 2>&1
#	rm -Rf $product_etc
	p_echo "done"

}

smart_undo_install()
{
	[ "X$trigger_uninstall" = "X1" -o "X$do_patch" = "X1" -o "X$do_reconfigure" = "X1" ] && return
	[ "X$PLESK_INSTALLER_NOUNDO" != "X" ] && return
	# trigger_uninstall - trigger what smart_undo_install is already working now(recurrence)
	trigger_uninstall=1

	if [ "X$can_uninstall" = "X1" ]; then
		if [ "X$do_upgrade" = "X1" ]; then
			undo_upgrade
		else
			undo_install
		fi
	fi

	# put suggestions for user what to do
	call_optional_function failure_note
}
undo_upgrade()
{
	p_echo   "    The attempt to upgrade $prev_product_full"
	p_echo   "    from version $prev_version to $product_full $product_version has failed."

	if [ -f "$product_sav_tar" ]; then
	
		p_echo 

		p_echo "    Now restore contents of $product_bs from $product_sav_tar"
		p_echo 
		get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
		req_pid=$common_var
		if [ $req_pid -gt 1 ]; then
			$K_KILL $req_pid >> $product_log 2>&1 
			sleep 2
			mysql_pid_file=$mysql_bddir/*.pid
			kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
			sleep 2
			if [ -f "$mysql_pid_file" ]; then
				rm -f $mysql_pid_file
			fi
		fi

		$START_SH stop >> $product_log 2>&1
		sleep 2

		rm -Rf $PRODUCT_ROOT_D
		setup_super_server "smtp"
		setup_super_server "smtps"
		setup_super_server "ftp"
		setup_super_server "poppassd"
		

		cd /
        	tar xvf $product_sav_tar > /dev/null 2>&1
		case "$?" in
			0)
#				rm -f $product_sav_tar 		
			;;
			*)
				p_echo 
				p_echo 
				p_echo "ERROR: restoration of files from $product_sav_tar has failed."
				p_echo "       Please restore them manually."
				p_echo 
				p_echo "Exiting..."
				p_echo 
				exit 0
			;;
		esac
	fi
	
}

#vhosts

set_vhosts_params()
{
	SKEL_DIR="$HTTPD_VHOSTS_D/.skel"
#	SKEL_CERT_DIR="$SKEL_DIR/0/cert"
#	SKEL_CERT="$SKEL_CERT_DIR/httpd.pem"
	return 0
}

#webalizer

set_webalizer_params()
{
	WEBALIZER_ROOT_D="$PRODUCT_ROOT_D/webalizer"
}
set_horde_params()
{
	horde_datadir="/usr/local/psa/psa-horde"
	horde_confdir="/usr/local/psa/etc/psa-horde"
	horde_sysconfd="$horde_confdir/horde"
	horde_logdir="/usr/local/psa/var/log"
	horde_passwd_file="$product_etc/.webmail.shadow"
	horde_title="Horde Web Based mail client "

	imp_datadir="$horde_datadir/imp"
	imp_sysconfd="$horde_sysconfd/imp"

	turba_datadir="$horde_datadir/turba"
	turba_sysconfd="$horde_sysconfd/turba"

	kronolith_datadir="$horde_datadir/kronolith"
	kronolith_sysconfd="$horde_sysconfd/kronolith"

	ingo_datadir="$horde_datadir/ingo"
	ingo_sysconfd="$horde_sysconfd/ingo"

	mnemo_datadir="$horde_datadir/mnemo"
	mnemo_sysconfd="$horde_sysconfd/mnemo"
	
	passwd_datadir="$horde_datadir/passwd"
	passwd_sysconfd="$horde_sysconfd/passwd"
}

check_opsys()
{
        case "$machine" in
	    BSD)
		dist_os_major_ver=`echo "$conceived_os_version" | \
							sed -e 's/^\(.\).*/\1/'`
		real_os_major_ver=`echo "$os_version" | sed -e 's/^\(.\).*/\1/'`
		dist_os_minor_ver=`echo "$conceived_os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		real_os_minor_ver=`echo "$os_version" | \
					sed -e 's/^[0-9]*\.\([0-9]*\).*/\1/'`
		st=${real_os_major_ver}_${real_os_minor_ver}_${dist_os_major_ver}_${dist_os_minor_ver}
		case $st in
			4_9_4_9|4_10_4_9|4_11_4_9)
				perl_req_ver="5.00503"
			;;
			4_11_4_11)
				perl_req_ver="5.008008"
			;;
			5_3_5_3|5_4_5_4|6_0_6_0|6_1_6_0|6_1_6_1)
				perl_req_ver="5.008008"
			;;
			*)
				p_echo "This installer does not support FreeBSD-$os_version."
				exit 1;
			;;
		esac

		if [ -x /usr/bin/perl ]; then
			perl_ver=`perl -e 'print $]'`
		else
			p_echo "Installation of this Plesk distribution\
			requires that Perl $perl_req_ver version be\
			installed on the server!"
			exit 1;
		fi
		if [ "$perl_req_ver" != "$perl_ver" ]; then
			p_echo "To continue installing, you should install\
			Perl $perl_req_ver (you have Perl $perl_ver\
			installed)"
			exit 1;
		fi
		return
	    ;;
	    BSDI)
	    ;;
	    linux)
	    ;;
	    solaris)
	    ;;
	esac
    p_echo "This installer does not support $machine platform."
    p_echo "Please obtain the appropriate installer for $machine system."
    exit 1
}

hf_files_processing()
{
local inten="set proper permission on hotfixed files"
echo_try $inten

while read line; do
	file=`echo $line |  awk 'NF < 5 || $5 !~ /^nocopy$/ {printf("%s ",$1)}'`
	perms=`echo $line | awk 'NF > 1 {printf("%s %s %s %s",$2,$3,$4,$1)}'`
	[ -z "$perms" ] || eval "set_ac $perms"
done
}

### Some initial parameters
	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	export PATH

	PRODNAME="psa"
	PRODVERSION="8.0.1"

	build_number="80061018.20"

	read_conf
	product_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	product_problems_log="/tmp/${PRODNAME}-hotfix${build_number}.log"
	set_local_params
	check_opsys

	test_for_root

### My name define
	my_name_0="`pwd`"
	if [ $? -ne 0 ]; then
                echo "Unable to determine current working directory."
                echo "Please fix the problem and run installation again."
                exit 1
	fi

	my_name_1="`basename ""$0""`"
	my_name_2=`echo ""$0""|sed -e "s/^\.\///"`
	echo $my_name_2 | egrep '^/' >/dev/null 2>&1
	case "$?" in
                0)
                        my_name="$my_name_2"
                ;;
                1)
                        my_name="$my_name_0"/"$my_name_2"
                ;;
            *)
                        err
                ;;
	esac

	if [ -d "$PRODUCT_ROOT_D" ]; then
	    plesk_ver=`awk '{print $1}' $PRODUCT_ROOT_D/version`
	    plesk_rel=`awk '{print $4;}' $PRODUCT_ROOT_D/version`
	    plesk_release=`echo "$plesk_rel" | sed -e 's/\./0/'`
	    PRODRELEASE=`echo "$build_number" | sed -e 's/\./0/'`
	    case "$plesk_ver" in
		$PRODVERSION)
			perl -e "{exit ((\"0$plesk_release\" > \"0$PRODRELEASE\") ? 0 : 1);}"
			if [ 0$? -eq 0 ]; then
				p_echo
				p_echo "The Plesk version ($plesk_ver $plesk_rel) you have does not require this hotfix ($PRODVERSION $build_number)."
				p_echo "Thank you for choosing our products!"
				p_echo
				exit 0
			fi

			START_SH=$PRODUCT_RC_D/${PRODNAME}
			
			### unpack hotfix
			p_echo "Extracting hotfix files"
			cat "$my_name" | $uudecode | tar -x -m -C / -f -

			hf_files_processing < "${PRODUCT_ROOT_D}/tmp/hotfix-80061018.20/filelist"

            sed -e 's/^\(.*\)[ \t][0-9][0-9]*\.[0-9][0-9]*$/\1 '$build_number'/' < "$PRODUCT_ROOT_D/version" > "$PRODUCT_ROOT_D/version.tmp" \
			&& mv -f "$PRODUCT_ROOT_D/version.tmp" "$PRODUCT_ROOT_D/version"

			;;
		*)
			p_echo
			p_echo "You have Plesk version $plesk_ver. In order for this script to work properly,"
			p_echo "please ensure that the version of the Plesk that you're attempting to hotfix"
			p_echo "is $PRODVERSION"
			p_echo "Thank you for choosing our products!"
			p_echo
			exit 0
			;;
	    esac
	else
		p_echo "ERROR: PSA directory '${PRODUCT_ROOT_D}' not found! Install PSA first."
		exit 1
	fi    

	p_echo "Done."
	p_echo
exit 0

begin 644 plesk_patch.tar
M+@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,3,P(#`Q,3(S-0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S`@,#$Q-S$Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;```
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M,"`P,3,P,#,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S80``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,34R(#`Q,S4W,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#$T-C4W`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$U,B`P,34T-30`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]E=&,`````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,34R(#`Q-#,T-0`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W1M
M<```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-3(@,#$T
M,S<R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O=&UP+VAO=&9I>"TX,#`V,3`Q."XR,```````````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$U,B`P,3<P,C``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]T;7`O:&]T9FEX+3@P
M,#8Q,#$X+C(P+V9I;&5L:7-T````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P-#,Q-3`S(#$P-3$U-#,T,34R(#`R,#8T,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````D>U!23T150U1?
M4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O87%U82YC;VUP86-T+V-S<R]I
M92YC<W,@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D
M;V-S+W-K:6YS+W!L97-K+G-E82]C<W,O:64N8W-S(')O;W0@,"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A+V-S<R]I
M92YC<W,@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D
M;V-S+W-K:6YS+W!L97-K+G-I;'9E<B]C<W,O:64N8W-S(')O;W0@,"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R
M;BYA97)O+V-S<R]I92YC<W,@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+G9I;VQE="]C<W,O:64N8W-S
M(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S
M:VEN<R]L;VYG:&]R;BYB;&%C:R]C<W,O:64N8W-S("!R;V]T(#`@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N8FQU
M92]C<W,O:64N8W-S("`@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO861M:6XO:'1D;V-S+W-K:6YS+VQO;F=H;W)N+GEE;&QO=R]C<W,O:64N
M8W-S(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C
M<R]S:VEN<R]W:6YX<"YN97<N8V]M<&%C="]C<W,O:64N8W-S("`@("`@(')O
M;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:S@N;F5W+V-S<R]I92YC<W,@("`@("!R;V]T(#`@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;F5W+V-S
M<R]I92YC<W,@("`@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+F)L=64O8W-S+VEE+F-S<R`@("`@
M(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S
M:VEN<R]W:6YX<"YO;&EV96=R965N+V-S<R]I92YC<W,@("`@("`@(')O;W0@
M,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+VAT9&]C<R]S:VEN<R]P
M;&5S:RYC;&%S<VEC+G-I;'9E<B]C<W,O:64N8W-S("!R;V]T(#`@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N<VEL
M=F5R+V-S<R]I92YC<W,@("`@<F]O="`P(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+FYA='5R92]C<W,O:64N8W-S
M("`@(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+W!L:6(O
M8V]M;6]N7V9U;F,N<&AP,R!R;V]T(#`@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]A9&UI;B]S8FEN+V9I;&5M;F<@<F]O="!P<V%A9&T@,#4U,`HD>U!23T15
M0U1?4D]/5%]$?2]A9&UI;B]P;&EB+V-L87-S+D-H96-K97(N<&AP(')O;W0@
M,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D;6EN+W!L:6(O8VQA<W,N1FEL
M94UA;F%G97(N<&AP(')O;W0@,"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+V%D
M;6EN+W!L:6(O;&]C86QE<R]E;BU54R]M97-S86=E<U]E;BU54RYP:'`@<F]O
M="`P(#`V-#0*)'M04D]$54-47U)/3U1?1'TO861M:6XO:'1D;V-S+V9I;&5M
M86YA9V5R+V9I;&5M86YA9V5R+G!H<"!R;V]T(#`@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+T5J<V4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]397)V:6-E<R]796%T:&5R+T=L;V)A;'=E871H97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]397)V:6-E<R]796%T:&5R+TUE=&%R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A
M=&AE<B]796%T:&5R9&]T8V]M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B]#
M;VUM;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]397)V:6-E<R]796%T:&5R+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O07)C:&EV
M92]487(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO0V]M;6]N+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O075T:"]3
M05-,+T-R86U-1#4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO1&EG97-T340U+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O075T:"]305-,+TQO9VEN+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O075T:"]305-,+U!L86EN+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O075T:"]305-,+T%N;VYY;6]U<RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+T-A8VAE+T-O;G1A:6YE<B]D8BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A
M:6YE<B]M9&(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O9FEL92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+T-A8VAE+T-O;G1A:6YE<B]M<V5S<VEO;BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A
M:6YE<B]P:'!L:6(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(O<VAM+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O0V%C:&4O0V]N=&%I;F5R+W1R:69I;&4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT
M86EN97(O9&)X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O17)R;W(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]&
M=6YC=&EO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+T-A8VAE+T=R87!H:6-S+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O
M2%144%]297%U97-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C:&4O3W5T<'5T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O0V%C
M:&4O3W5T<'5T0V]M<')E<W-I;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]#86-H92]#;VYT86EN97(N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]#86-H92]!<'!L:6-A=&EO;BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T-O;G-O;&4O1V5T
M;W!T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C<R]E>&%M<&QE+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C<R]D;W=N;&]A9"UP<F]G<F5S
M<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O1$(O9&]C+TU!24Y404E.15)3"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"
M+V1O8R]35$%455,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+U1%4U1%4E,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M1$(O9&]C+TE$14%3"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]33510+V1O8W,O97AA;7!L97,O
M8F%S:6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]33510+V1O8W,O9W5I9&4N='AT"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]F:6QE+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?:&%N
M9&QE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R
M<V5R7W-I;7!L93$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]087)S97(O97AA;7!L97,O
M>&UL7W!A<G-E<E]S:6UP;&4Q+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X
M86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A
M<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L93(N>&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]087)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]S:6UP;&5?:&%N9&QE
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R
M7V9I;&4N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+V-O;7!O<VET
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O9&ES<&QA>2YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O97)R;W)?;&]G+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]F:6QE+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O
M9&]C<R]E>&%M<&QE<R]M86EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M
M<&QE<R]N=6QL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]O8G-E
M<G9E<E]M86EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]P96%R
M7V5R<F]R7VAA;F1L97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S
M+W!H<%]E<G)O<E]H86YD;&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M
M<&QE<R]S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W-Q;&ET
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O<WES;&]G+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]W:6XN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO
M9R]D;V-S+V5X86UP;&5S+V-O;G-O;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S
M+V=U:61E+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]$871E+TQ)0T5.4T4)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O1&%T
M92]43T1/"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TYE=%]54DPO9&]C<R]E>&%M<&QE+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&]C<R]!<F-H:79E7U1A<B]D;V-S+T%R8VAI=F5?5&%R+G1X=`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C
M<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+VUE=&%R+6)A<VEC+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+VUE=&%R+65X=&5N
M<VEV92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]W
M96%T:&5R+F-O;2UB87-I8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?5V5A=&AE
M<B]E>&%M<&QE<R]W96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O96IS92UB87-I8RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]G;&]B86QW96%T:&5R
M+6)A<VEC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?571I;"]E>&%M<&QE<R]E>&%M<&QE
M,BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U5T:6PO97AA;7!L97,O97AA;7!L92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE06YD
M16YC;V1E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S
M97)I86QI>F5!<G)A>5=I=&A/8FIE8W1S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5#1&%T82YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE16UP='E!<G)A>2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE
M26YD97AE9$%R<F%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M
M<&QE<R]S97)I86QI>F5);F1E>&5D07)R87E7:71H0V]N=&5X="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE3G5L;%!R
M;W!E<G1I97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S
M+W-E<FEA;&EZ94]B:F5C="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O
M97AA;7!L97,O<V5R:6%L:7IE4D1&+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]S97)I86QI>F5396QE8W1I=F5!='1R:6)U=&5S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57
M:71H071T<FEB=71E<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA
M;7!L97,O<V5R:6%L:7IE5VET:$%T=')I8G5T97,R+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F57:71H0V]M;65N="YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O97AA;7!L92YX
M;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE
M5VET:$1T9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O
M<V5R:6%L:7IE5VET:$EN9&5N=&5D071T<FEB=71E<RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$YA;65S<&%C
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L
M:7IE5VET:%1A9TUA<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA
M;7!L97,O=6YS97)I86QI>F5!;GE834PN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE0VQA<W-.86UE<RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F5%;F-O
M9&5D+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E
M<FEA;&EZ945N=6TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W5N<V5R:6%L:7IE3V)J96-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95)$1BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O6$U,
M7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS97)I86QI>F57:&ET97-P86-E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ
M95=I=&A!='1R:6)U=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E
M>&%M<&QE<R]U;G-E<FEA;&EZ95=I=&A486=-87`N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:%1Y<&5'=65S
M<VEN9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R
M:6%L:7IE06YD4F5T=7)N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O871T
M86-H;65N="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V-O;5]C;&EE;G0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]D:7-C;U]S97)V97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+U-/05`O97AA;7!L92]E;6%I;%]C;&EE;G0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-/05`O97AA;7!L92]E;6%I;%]G871E=V%Y+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0
M+V5X86UP;&4O96UA:6Q?<&]P7V=A=&5W87DN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O
M97AA;7!L92]E;6%I;%]P;W!?<V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X
M86UP;&4O96UA:6Q?<V5R=F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O
M97AA;7!L95]S97)V97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E>&%M
M<&QE7W1Y<&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O<V5R=F5R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&]C<R]33T%0+V5X86UP;&4O<V5R=F5R,BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O
M4T]!4"]E>&%M<&QE+W-M='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S
M=&]C:W%U;W1E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7V-L:65N
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+W1C<%]D865M;VXN<&P)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+W1C<%]S97)V97(N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/
M05`O97AA;7!L92]W<V1L7V-L:65N="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+V-L:65N="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7T944"]E>&%M<&QE+VEN9&5X
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP;&4O;V)S97)V97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]D;V-S+TYE=%]&5%`O97AA;7!L92]E>'1E;G-I;VYS+FEN:0ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T
M82]014%2+W1E;7!L871E+G-P96,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O4$5!4B]P86-K86=E+F1T
M9`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O9&%T82]-86EL7TUI;64O>&UA:6PN>'-L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D871A+TUA:6Q?
M36EM92]X;6%I;"YD=&0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+V1A=&$O3&]G+VUI<V,O;&]G+G-Q;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M9&%T82]397)V:6-E<U]796%T:&5R+VEM86=E<R]S=6YS970N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M871A+U-E<G9I8V5S7U=E871H97(O:6UA9V5S+W-U;G)I<V4N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]D
M871A+U-E<G9I8V5S7U=E871H97(O8G5I;&1-971A<D1"+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O9&%T
M82]834Q?4V5R:6%L:7IE<B]D;V,O=&]D;RYT>'0)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+V1A=&$O0V%C:&4O
M0V]N=&%I;F5R+VUD8E]C86-H95]S8VAE;6$N>&UL"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]834PO4E!#+U-E
M<G9E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+UA-3"]24$,O1'5M<"YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]087)S97(O
M4VEM<&QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O6$U,+U!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]5=&EL+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O6$U,+U5N<V5R:6%L:7IE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+UA-3"]397)I86QI>F5R
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O6$U,+U)00RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+V-O;6UO;BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"
M+V9B<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O1$(O:6)A<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]I9G@N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]$0B]M<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O1$(O;7-S<6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]M>7-Q;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+T1"+VUY<W%L:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1"+V]C:3@N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]O
M9&)C+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O1$(O<&=S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$0B]S>6)A<V4N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]$0B]S=&]R86=E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O<W%L:71E+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1$(O9&)A
M<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B],;V<O8V]M<&]S:71E+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+V1A96UO;BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+TQO9R]D:7-P;&%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+V5R<F]R7VQO9RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+TQO9R]F:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+VUA:6PN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O;6-A
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+TQO9R]M9&(R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+VYU;&PN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],
M;V<O;V)S97)V97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O<W%L+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3&]G+W-Q;&ET
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+TQO9R]S>7-L;V<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B],;V<O=VEN+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M3&]G+V-O;G-O;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="]33510+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4T]!4"]4<F%N<W!O<G0O5$-0+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0O
M2%144"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U-/05`O4V5R=F5R+U1#4"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O4V5R
M=F5R+T5M86EL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]397)V97(O16UA:6Q?1V%T97=A>2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U-/05`O5'EP92]D=7)A=&EO;BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O5'EP92]H
M97A":6YA<GDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O9&%T951I;64N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]3
M3T%0+W1O;VQS+V=E;G!R;WAY+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4T]!4"]397)V97(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]33T%0+U1R86YS<&]R="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O5F%L=64N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]3
M3T%0+U=31$PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]33T%0+T-L:65N="YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U-/05`O0F%S
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U-/05`O1&ES8V\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]33T%0+T9A=6QT+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4T]!4"]087)S97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$871E+TAU;6%N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O1&%T
M92]3<&%N+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O1&%T92]4:6UE6F]N92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+T1A=&4O0V%L
M8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+U!(4%5N:70O1U5)+TA434PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+T=5
M22](5$U,+G1P;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$A056YI="]'54DO4V5T=7!$96-O<F%T;W(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]02%!5;FET+T=522]'=&LN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U)E<&5A=&5D
M5&5S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!(4%5N:70O4VME;&5T;VXN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET
M+U1E<W1#87-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T1&5C;W)A=&]R+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$A056YI="]497-T1F%I;'5R92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=$QI
M<W1E;F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$A056YI="]497-T4F5S=6QT+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$A0
M56YI="]497-T4W5I=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]02%!5;FET+T%S<V5R="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+T9I;&4O0U-6+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O1FEL92]5=&EL+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]$;W=N
M;&]A9&5R+U!A8VMA9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO56YI>&5O;"]R=RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O5&%S:R]7:6YD;W=S96]L+W)W+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]4
M87-K+U)E<&QA8V4O<G<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4&]S=&EN<W1A;&QS
M8W)I<'0O<G<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO0V]M;6]N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!
M4B]487-K+U!O<W1I;G-T86QL<V-R:7!T+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]487-K+U)E
M<&QA8V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO56YI>&5O;"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M5&%S:R]7:6YD;W=S96]L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]686QI9&%T;W(O4$5#3"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O0V]M;6%N9"]086-K86=E+G!H<"YO<FEG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2
M+T-O;6UA;F0O0G5I;&0N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0G5I;&0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+T-O;6UA;F0O0VAA;FYE;',N>&UL"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA
M;F0O0VAA;FYE;',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O0V]M;6]N+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+T-O;F9I9RYX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#
M;VYF:6<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O26YS=&%L;"YX;6P)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]);G-T86QL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U!A8VMA
M9V4N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O
M0V]M;6%N9"]0:6-K;&4N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4&EC:VQE+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]#;VUM86YD+U)E9VES=')Y+GAM;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+U)E9VES=')Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U)E;6]T92YX;6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]296UO=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O
M36ER<F]R+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+TUI<G)O<BYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O0V]M;6%N9"]497-T+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U1E<W0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+T-O;6UA;F0O075T:"YX;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]!
M=71H+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]215-4+S$Q+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]215-4+S$P
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4$5!4B]&<F]N=&5N9"]#3$DN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A
M;&QE<B]2;VQE+T-O;6UO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M1&%T82YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O1&]C+GAM;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]);G-T86QL97(O4F]L92]$;V,N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE
M<B]2;VQE+T5X="YX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O17AT+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]0:'`N>&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+TEN
M<W1A;&QE<B]2;VQE+U!H<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4O
M4V-R:7!T+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]38W)I<'0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-R8RYX;6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O26YS
M=&%L;&5R+U)O;&4O4W)C+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]4
M97-T+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]497-T+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]);G-T86QL97(O4F]L92]$871A+GAM;`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O1V5N97)A=&]R+W8R
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]'96YE<F%T;W(O=C$N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]014%2+U!A8VMA9V5&:6QE+U!A<G-E<B]V,BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4&%C
M:V%G949I;&4O4&%R<V5R+W8Q+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]V
M,B]R=RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(O5F%L:61A=&]R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O4$5!4B]086-K86=E1FEL92]V,BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G
M949I;&4O=C$N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]014%2+T-H86YN96Q&:6QE+U!A<G-E<BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+U!%05(O1&]W;FQO861E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%05(O17)R;W)3=&%C:RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O17AC97!T:6]N+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]&<F]N=&5N9"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O26YS=&%L;&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]296UO=&4N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]014%2+U!A8VMA9V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+U!%05(O4F5G:7-T<GDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U)%4U0N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]014%2+U)U;E1E<W0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+U9A;&ED871E+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M4$5!4B]834Q087)S97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T)U:6QD97(N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+T%U=&]L;V%D97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]014%2+T-H86YN96Q&:6QE+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O4$5!4B]#;VUM86YD+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM;VXN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-O;F9I9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+U!%05(O1&5P96YD96YC>2YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+U!%
M05(O1&5P96YD96YC>41"+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$5!4B]$97!E;F1E;F-Y,BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+T]3+T=U97-S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\P
M,#4N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\P,#,N<&AP=`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\P,#0N<&AP=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M6$U,7U!A<G-E<B]T97-T<R\P,#(N<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E
M<B]T97-T<R]T97-T,BYX;6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S=',O
M=&5S=#,N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+S`P,2YP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<V5T=7`N:6YC+F-V<RYO<FEG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#-S:6UP;&5Q=65R>2YP:'!T
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#1N=6UC;VQS+G!H<'0)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P-7-E<75E;F-E<RYP:'!T"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T
M97-T<R]$0B]T97-T<R]D<FEV97(O,#9P<F5P97AE8RYP:'!T"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D<FEV97(O,#AA9F9E8W1E9')O=W,N<&AP=`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+S`Y;G5M<F]W<RYP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]D<FEV97(O,3!E<G)O<FUA<"YP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,3%T<F%N<V%C=&EO;G,N<&AP=`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S$S;&EM:70N<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9')I=F5R+S$T9F5T8VAM;V1E7V]B:F5C="YP:'!T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,35Q=6]T92YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O,39T86)L96EN9F\N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I
M=F5R+S$W<75E<GDN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$X
M9V5T+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\Q.6=E=&QI<W1O
M9BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O8V]N;F5C="YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B]M:W1A8FQE+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+VUU;'1I8V]N;F5C="YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S+V1R:79E<B]R=6XN8W9S"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O<V5T=7`N:6YC+F-V<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R
M+W-K:7!I9BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P,6-O;FYE
M8W0N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`R9F5T8V@N<&AP
M=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9&)?9F%C=&]R>2YP:'!T"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]$0B]T97-T<R]D8E]I<VUA;FEP+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S
M+V1B7V5R<F]R,BYP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]E<G)O<G,N:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]F971C:&UO9&5?;V)J96-T+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O9F5T8VAM;V1E<RYI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+VEN8VQU9&4N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]L:6UI="YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1"+W1E<W1S+VYU;6-O;',N:6YC"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]N=6UR;W=S+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O<')E<&5X92YI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+W)U;BYC=G,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+W-E<75E;F-E<RYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+W-I;7!L97%U
M97)Y+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O=')A;G-A8W1I;VYS+FEN8PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O1$(O=&5S=',O<VMI<&EF+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S
M=',O9&)?97)R;W(N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9&)?<&%R<V5D
M<VXN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O:6YC;'5D92YI;F,N;W)I9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O3F5T7U--5%`O=&5S=',O8F%S:6,N<&AP=`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O
M3F5T7U--5%`O=&5S=',O8V]N9FEG+G!H<"YD:7-T"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?
M4TU44"]T97-T<R]Q=6]T961A=&$N<&AP=`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7U--5%`O
M=&5S=',O875T:"YP:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]-86EL+W1E<W1S+W-M='!?97)R
M;W(N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O36%I;"]T97-T<R]R9F,X,C(N<&AP=`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O6$U,7U)00R]T97-T<R]T97-T7T1U;7`N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]8
M34Q?4E!#+W1E<W1S+V5X=')A+6QI;F5S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)0
M0R]T97-T<R]P<F]T;W!O<G0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S
M+V5M<'1Y+79A;'5E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]T>7!E
M<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O86QL9V]T+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M=&5S=',O6$U,7U)00R]T97-T<R]E;7!T>2UV86QU92US=')U8W0N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]T97-T<R],;V<O=&5S=',O8V]M<&]S:71E+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO
M9R]T97-T<R]D:7-P;&%Y+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]E<G)O
M<E]L;V<N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V5X=')A8W0N<&AP=`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O=&5S=',O3&]G+W1E<W1S+V5X=')A8W0R+G!H<'0)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO
M9R]T97-T<R]F86-T;W)Y+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]F:6QE
M+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]L979E;',N<&AP=`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O3&]G+W1E<W1S+VYU;&PN<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+W!R
M:6]R:71Y+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]S:6YG;&5T;VXN<&AP
M=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O3&]G+W1E<W1S+W-Q;&ET92YP:'!T"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R],
M;V<O=&5S=',O<W%L7VED96YT+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]C
M;VYS;VQE+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8V%L8RYP:'`N;W)I
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<W,C=?,BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1A=&4O=&5S=',O8G5G-S(W7S,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S
M+V)U9S<R-U\T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<Y-C<N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$871E+W1E<W1S+V-A;&,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E
M+W1E<W1S+W1E<W1U;FET+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T97-T
M=6YI=%]D871E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]T97-T=6YI=%]D
M871E7W-P86XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W1E<W1?8V%L8RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S=%]D871E7VUE=&AO9'-?<W!A
M;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E:W-I;FUO;G1H7S1?;6]N
M9&%Y+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N=&A?-%]S
M=6YD87DN='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+W=E96MS:6YM;VYT:%]R
M9&U?;6]N9&%Y+G1X=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N
M=&A?<F1M7W-U;F1A>2YT>'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=VMN;W1E
M<W0N='AT"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S8W-"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O8G5G-S(W7S$N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E
M<W1S+T-35B\P,#$N<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`R
M+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P,BYC<W8)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E
M<W1S+T9I;&4O=&5S=',O0U-6+S`P,RYP:'!T"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E
M<W1S+T-35B\P,#,N8W-V"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#0N
M<&AP=`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`T+F-S=@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O=&5S
M=',O1FEL92]T97-T<R]#4U8O,#`U+G!H<'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S
M=',O0U-6+S`P-2YC<W8)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6+S`P-BYP
M:'!T"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#8N8W-V"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]&:6QE+W1E<W1S+T-35B]T97-T<RYT>'0)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S
M=',O0U-6+S`P,2YC<W8)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O=&5S="YC<W8)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P
M96%R+W1E<W1S+T9I;&4O=&5S=',O1FEL951E<W0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]T97-T<R]&
M:6QE+W1E<W1S+W!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+TA45%`O4F5Q=65S="],:7-T96YE
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+TA45%`O4F5Q=65S="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO;6EM941E8V]D
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+TUA:6PO<V5N9&UA:6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]-86EL+W-M='`N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<&5A<B]-86EL+U)&0S@R,BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P96%R+TUA:6PO;6EM95!A<G0N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A
M<B]-86EL+VUI;64N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&5A<B]-86EL+VUA:6PN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]-86EL+VYU
M;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&5A<B].970O1E10+T]B<V5R=F5R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3F5T+U-O8VME
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+TYE="]33510+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O3F5T+U523"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P96%R+TYE
M="]&5%`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&5A<B]P96-L8VUD+G!H<"YO<FEG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]-86EL+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E
M87(O1FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+U!%05(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&5A<B]$871E+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4$A0
M56YI="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P96%R+T1"+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O4WES=&5M+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O<&5A<F-M
M9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P96%R+T-A8VAE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O<&5A<F-M9"YP:'`N;W)I9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!E87(O
M<&5C;&-M9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]P96%R+TQO9RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+T-/4%E)3D<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+U)%041-
M10ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+V1O8W,O0TA!3D=%4PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+V1O8W,O0T]$24Y'7U-404Y$05)$4PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V1O8W,O0T].5%))
M0E5424Y'"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O9&]C<R]#4D5$2513"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O9&]C<R](04-+24Y'"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C<R])3E-404Q,"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O9&]C
M<R]015)&3U)-04Y#10ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+V1O8W,O4T5#55))5%D)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+U1/1$\)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]D;V-S+U1204Y3
M3$%424].4PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+V1O8W,O55!'4D%$24Y'"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5S="YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S:6=N=7`N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<G!C+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQO9VEN+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM
M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+V%D;6EN+VQO8V%L92]F:5]&22]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]H=5](
M52]H96QP+GAM;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+V%D;6EN+W!E<FUS+V5D:70N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O861M:6XO<&5R;7,O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<&5R;7,O9&5L
M971E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+V%D;6EN+W-E='5P+V1I9F8N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO<V5T=7`O8V]N9FEG
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+V%D;6EN+W-E='5P+VEN9&5X+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+V%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O861M:6XO<&AP<VAE;&PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO:6YD97@N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O861M:6XO=7-E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]A9&UI;B]C;61S:&5L;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]D871A=')E92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI
M;B]S97-S:6]N<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]A9&UI;B]S<6QS:&5L;"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]A9&UI;B]T96UP;&%T
M97,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O861M:6XO9W)O=7!S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+W1A8FQE<RYJ<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+W-T<FEP92YJ
M<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VIS+VAO<F1E+FEE+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O:G,O<V]R=&5R+FIS"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O9F]R;5]H96QP97)S+FIS
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M:G,O:'1T<&-L:65N="YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VIS+VEE17-C1W5A<F0N:G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]F;W)M7W-E8W1I
M;VYS+FIS"0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O96YT97)?
M:V5Y7W1R87`N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]J<R]H:61E86)L92YJ<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS+W1O;VQT:7`N:G,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]P;W!U
M<"YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VIS+V9O<FU?87-S:6=N+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O:G,O86QP:&%);6%G94QO861E<BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J
M<R]H;W)D92YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VIS+V]P96Y?8V]L;W)P:6-K97(N:G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]J<R]I;6%G92YJ<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VIS
M+V%D9$5V96YT+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+U-Y;F,T:BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M4WEN8TU,+T1E=FEC92]0.#`P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+U-Y;G1H
M97-I<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]L:6(O4WEN8TU,+T1E=FEC92].;VMI82YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,
M+T-O;6UA;F0O1FEN86PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+U!U="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O4WEN8TU,+T-O;6UA;F0O4F5S=6QT<RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA
M;F0O36%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]3>6YC16QE;65N="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O4WEN8TU,+T-O;6UA;F0O4W1A='5S+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N
M9"]!;&5R="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O1V5T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC
M34PO0V]M;6%N9"]3>6YC+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO4W1A=&4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U-Y
M;F--3"]"86-K96YD+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]3>6YC
M34PO4WEN8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;G-T86YT<RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O4WEN8TU,
M+T1E=FEC94EN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+U-Y;F--3"]#;VUM86YD+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE
M+U!$1B]F;VYT<R]C;W5R:65R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]H96QV
M971I8V%B:2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N=',O=&EM97,N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I
M;&4O4$1&+V9O;G1S+WIA<&9D:6YG8F%T<RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N
M=',O=&EM97-B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<R]T:6UE<VDN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC86(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O
M;G1S+VAE;'9E=&EC86DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O;G1S+W1I;65S8FDN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+T9I;&4O4$1&+V9O;G1S+VAE;'9E=&EC82YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]0
M1$8O9F]N=',O<WEM8F]L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]&:6QE+U!$1BYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O1FEL92]#
M4U8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+U1E>'0O<F535"]&;W)M871T97(O:'1M;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5&5X
M="]R95-4+U!A<G-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O5&5X="]R95-4+T9O<FUA='1E<BYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O5&5X="]$:69F+U)E;F1E<F5R+VEN;&EN92YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5&5X="]$:69F
M+U)E;F1E<F5R+W5N:69I960N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O5&5X="]$:69F+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]497AT+T9L;W=E9"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5&5X
M="]$:69F,RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O5&5X="]R95-4+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PO1%1$
M+U-Y;F--3$1E=DEN9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34Q-971)
M;F8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O4WEN8TU,+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)8
M34PO0V]N=&5N=$AA;F1L97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+UA-3"]70EA-3"]$5$1-86YA9V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]834PO5T)834PO16YC;V1E
M<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O6$U,+U="6$U,+T1E8V]D97(N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+UA-3"]35D<N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+UA-3"]70EA-3"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO8V]P>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO9&ER96-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO9&ER96-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O
M25-/5W)I=&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B]61E,O3V)J96-T+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]61E,O<VUB+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]61E,O1T,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]S<6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]M=7-Q;"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O5D93+V9T<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O5D93+T)R;W=S97(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R]S
M<6Q?9FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O5D93+V9I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U9&4R],:7-T271E;2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O0FQO8VLO=&EM92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O0FQO8VLO86-C;W5N="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O0FQO8VLO9V]O9VQE+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B]";&]C:R]S=6YR:7-E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]M;V]N+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]";&]C
M:R]F;W)T=6YE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+T)L;V-K+VEF<F%M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O0FQO8VLO;65T87(N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+T)L;V-K+V-O;&]R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(O:'1M
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O36]B:6QE+U)E;F1E<F5R+W=M;"YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O36]B:6QE+U)E;F1E<F5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A+V]U=&QO;VMC
M<W8N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T1A=&$O=F-A<F0N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O
M=G1O9&\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O='-V+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]$871A
M+VEC86QE;F1A<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]V;F]T92YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O1&%T82]I;6,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O8W-V+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]'<F%P:"]0;&]T+V)A<F=R;W5P960N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+U!L
M;W0O8F%R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+V)A<G-T86-K960N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T=R87!H+U!L;W0O;&EN92YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O
M4&QO="]S8V%T=&5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]#:&%R="]P:64S9"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O1W)A<&@O0VAA<G0O<&EE+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]'<F]U<"]H;V]K<RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M26UA9V4O<F=B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]S=F<N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TEM86=E+W-W9BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O26UA9V4O9V0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TEM86=E+VEM+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]P;F<N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]097)M<R]D871A=')E92YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(O;7ES<6PN<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+VYO;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+VQD
M87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+W-A<&1B+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]397-S:6]N2&%N9&QE<B]S<6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+VUE;6-A8VAE+G!H<`D*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]O8VDX+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]397-S:6]N2&%N9&QE<B]P9W-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(O9&)M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O875D
M:6\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]J879A<V-R
M:7!T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXO179E;G0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O24U!4"]!9&UI;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!0TPN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TE-05`O4V5A<F-H+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U1R964N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TE-05`O5&AR96%D+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U-O<G0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TE-05`O0V%C:&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+W-Q
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O4')E9G,O54DN<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+VMO
M;&%B+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]0<F5F<R]L9&%P+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U!R969S+VEM<W`N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO5'EP
M92]T86)L97-E="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]!8W1I;VXO8V]N9&ET:6]N
M86Q?96YA8FQE+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;B]R96QO860N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7W-E='9A;'5E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]&;W)M+T%C=&EO;B]S=6)M:70N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O
M<FTO06-T:6]N+W5P9&%T969I96QD+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO
M;B]S=6U?9FEE;&1S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O1F]R;2]296YD97)E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&]K96XO9FEL92YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O5&]K96XO<W%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]O;V\O=&%B;&5?8V5L;',N>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O
M;R]M86EN7VAT;6PN>'-L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;R]P86QM
M+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O<W1Y;&5?;6%P<&EN9RYX
M<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+V=L;V)A;%]D;V-U;65N="YX
M<VP)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W1A8FQE7W)O=W,N>'-L"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TU)344O5FEE=V5R+V]O;R]S='EL95]I;FQI;F5D+GAS;`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]O;V\O=&%B;&5?8V]L=6UN<RYX<VP)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O;V]O+V-O;6UO;BYX<VP)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O;V]O+W1A8FQE+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]O;V\O
M<W1Y;&5?:&5A9&5R+GAS;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O<F9C.#(R+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]P;&%I;BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O8W-S+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%
M+U9I97=E<B]E;G-C<FEP="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O:6UA
M9V5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]6:65W97(O:'1M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O9&5F875L
M="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)P;2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<F5P
M;W)T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S;W5R8V4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1N968N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W-R8VAI9VAL:71E+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]P9&8N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6
M:65W97(O<V5C=7)I='DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W!H<"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]6:65W97(O<FEC:'1E>'0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V5N<FEC:&5D+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E
M<B]M<V5X8V5L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]S:6UP;&4N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&EB+TAO<F1E+TU)344O4&%R="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]-86=I8RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O34E-12]-1$XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O34E-
M12]3=')U8W1U<F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O;6EM92YM87!P
M:6YG+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+VUI;64N;6%G:6,N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X
M="]&:6QT97(O>'-S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]C;&5A;F%S
M8VEI+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]W;W)D<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&5X="]&:6QT97(O<G-T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]S
M<&%C93)H=&UL+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]S:6UP;&5M87)K
M=7`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V1I;7-I9VYA='5R92YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O8F)C;V1E+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]L:6YK=7)L<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA
M:6QS+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]E;G9I<F]N;65N="YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4
M97AT+T9I;'1E<B]E;6]T:6-O;G,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R
M+W1A8G,R<W!A8V5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]T97AT,FAT
M;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4<F5E
M+VAT;6PN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O<V5L96-T+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4
M<F5E+VIA=F%S8W)I<'0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92]#<GEP="]P9W`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S
M<R]T87(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-O;7!R97-S+W1N968N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U9#+W)C<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O5D,O8W9S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]60R]S=FXN<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,
M4R]C;V]R9&EN871E<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O3DQ3+V-A<G-I9VYS+G!H<`ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI
M8B](;W)D92].3%,O=&QD+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92].3%,O1V5O25`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E+W-Q
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O1&%T851R964O;G5L;"YP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP
M:&5R+T)L;V-K36]D92]E8V(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO
M9&4O;V9B-C0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O8V9B-C0N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO9&4O8V)C+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]#:7!H97(O8FQO=V9I<V@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]";&]C:TUO
M9&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]D97,N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE
M<B]C87-T,3(X+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O<F,R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]#:7!H97(O<F,T+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]24$,O<F5S="YP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O4E!#+WAM;')P8RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W=E8F1A=BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O4E!#+W-Y;F-M;%]W8GAM;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W-Y;F-M
M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O4E!#+W-O87`N<&AP"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-13"]!='1R
M:6)U=&5S+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]344PO2V5Y=V]R9',N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T)R;W=S97(O:6UO9&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T5D:71O<B]H=&UL87)E82YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O0V%C:&4O9FEL92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O0V%C:&4O>G!S
M-"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R]522YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]P87-S=V0N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V-Y<G5S+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I<&UA<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O075T:"]S87-L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+V-O;7!O<VET
M92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O075T:"]A=71O+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VAT
M='`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+T%U=&@O<VUB+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VQO
M9VEN+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+VQI8B](;W)D92]!=71H+V-U<W1O;7-Q;"YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M075T:"]K;VQA8BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]S<6PN<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O:W)B-2YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]M8V%L+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]!=71H+V9T<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]I;6%P+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]Y86AO;RYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O075T:"]P86TN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:6US<"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O075T:"]R861I=7,N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O87!P;&EC871I
M;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V;F]T92YP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O
M:4-A;&5N9&%R+W9J;W5R;F%L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O=G1O
M9&\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V979E;G0N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E
M+VE#86QE;F1A<B]V=&EM97IO;F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V
M9G)E96)U<WDN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V86QA<FTN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+VE#86QE;F1A<B]V8V%R9"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V-H961U;&5R
M+V-R;VXN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+W1A8FQE<V5T7VAT;6PN<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U5)+U=I9&=E="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5&%B<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O54DO3&%N9W5A9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B](;W)D92]522]086=E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O2&5L<"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O571I;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V-H961U;&5R+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]%9&ET;W(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TUE;G4N<&AP"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E<FEA;&EZ92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O2&]R9&4O1&%T92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O4V5C<F5T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]#3$DN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T-A8VAE+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O2&ES=&]R>2YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O36%I;G1E;F%N8V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+VQI8B](;W)D92]&;W)M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]+;VQA8BYP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O1&%T851R964N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U!E<FUS+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]-;V)I;&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O2&]R9&4O4VAA<F4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T%R<F%Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;BYP:'`)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O26UA
M9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5&5M<&QA
M=&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U9#+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O4U%,+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+VQI8B](;W)D92]3=')I;F<N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O2&]R9&4O5F%R:6%B;&5S+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D
M92]#;VYF:6<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R;W5P+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H
M97(N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U)E9VES=')Y+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S
M<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]L:6(O2&]R9&4O3DQ3+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B](;W)D92]#<GEP="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M2&]R9&4O0FQO8VLN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TQ$05`N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+TED
M96YT:71Y+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N3V)J96-T<RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O075T:"]I
M;71E<W0N<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+TYE="])35-0+T%U=&@O8W)A;5]M9#4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TYE
M="])35-0+T%U=&@O<&QA:6YT97AT+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B].970O24U34"]";V]K+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B].970O24U34"]5=&EL<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O3W!T:6]N<RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]L:6(O3F5T+TE-4U`O075T:"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T+U--4RYP:'`)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O3F5T
M+TE-4U`N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&EB+V)A<V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+U1E<W0N<&AP"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&EB+TAO<F1E+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+VQI8B]P<F5F<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]L:6(O4WEN8TU,+G!H<`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B\N:'1A8V-E<W,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O
M=F5R<VEO;BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]L:6(O8V]R92YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]L:6(O5D93+G!H<`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+VQI8B]A<&DN<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&]C86QE+VMM7TM(+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V%R7U-9
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V-A7T53+TQ#7TU%4U-!1T53
M+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&]C86QE+V)S7T)!+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+V1A7T1++TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V1A7T1++VAE
M;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+V1E7T1%+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE
M+V1E7T1%+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+V-S7T-:+TQ#7TU%4U-!1T53+VAO<F1E
M+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&]C86QE+V-S7T-:+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V5L7T=2+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&]C86QE+V5L7T=2+VAE;'`N>&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V9A7TE2
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V9A7TE2+VAE;'`N>&UL"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+V5N7U53+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V5S7T53+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+V5S7T53+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V9I7T9)+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+V9I7T9)+VAE;'`N>&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V5T
M7T5%+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V5T7T5%+VAE;'`N>&UL
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V9R7T92
M+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&]C86QE+V=L7T53+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+VAE7TE,+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VED7TE$+TQ#
M7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VAU7TA5+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+VAU7TA5+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VIA7TI0+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+VIA7TI0+VAE;'`N>&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VES
M7TE3+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VET7TE4+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&]C86QE+VET7TE4+VAE;'`N>&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V)G7T)'
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+V)G7T)'+VAE;'`N>&UL"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+VMO7TM2+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VMO7TM2+VAE
M;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+VQT7TQ4+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE
M+VQT7TQ4+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+VUK7TU++TQ#7TU%4U-!1T53+VAO<F1E
M+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&]C86QE+VQV7TQ6+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VYB
M7TY/+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VYB7TY/+VAE;'`N>&UL
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&]C86QE+VYL7TY,+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+VYL7TY,
M+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O;&]C86QE+VYN7TY/+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+VYN7TY/+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W!L7U!,+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+W!L7U!,+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W!T7T)2+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+W!T7T)2+VAE;'`N>&UL"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W!T
M7U!4+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W!T7U!4+VAE;'`N>&UL
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M;&]C86QE+W)O7U)/+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W)U7U)5
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W)U7U)5+VAE;'`N>&UL"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+W-K7U-++TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W-K7U-++VAE
M;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+W-L7U-)+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE
M+W-L7U-)+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+W-V7U-%+TQ#7TU%4U-!1T53+VAO<F1E
M+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O;&]C86QE+W-V7U-%+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W1R7U12+TQ#7TU%4U-!
M1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O;&]C86QE+W1R7U12+VAE;'`N>&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W5K7U5!
M+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+W5K7U5!+VAE;'`N>&UL"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C
M86QE+WIH7T-.+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE+WIH7T-.+VAE
M;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O;&]C86QE+WIH7U17+TQ#7TU%4U-!1T53+VAO<F1E+FUO"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O;&]C86QE
M+WIH7U17+VAE;'`N>&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O;&]C86QE+RYH=&%C8V5S<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V9A7TE2+G!O"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O
M97-?15,N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P;R]Z:%]#3BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!O+WIH7U17+G!O"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:'5?2%4N<&\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]F
M:5]&22YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!O+V5T7T5%+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&\O4D5!1$U%"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O<G5?4E4N<&\)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]G;%]%
M4RYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W!O+V-A7T53+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<&\O8G-?0D$N<&\)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]I9%])1"YP;PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W)O7U)/
M+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&\O<VM?4TLN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P;R\N:'1A8V-E<W,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]L=%],5"YP;PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V1E7T1%
M+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<&\O;FQ?3DPN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]P;R]J85]*4"YP;PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W1R86YS;&%T:6]N+G!H<`ER
M;V]T('=H965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O
M+VES7TE3+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<&\O<VQ?4TDN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]P;R]B9U]"1RYP;PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+V9R7T92+G!O"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O
M87)?4UDN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P;R]U:U]502YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!O+VET7TE4+G!O"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O:&]R9&4N<&]T"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O
M;6M?34LN<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]P;R]L=E],5BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W!O+VYN7TY/+G!O"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O<&Q?4$PN<&\)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]K
M;5]+2"YP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W!O+VAE7TE,+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<&\O9&%?1$LN<&\)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]P;R]C<U]#6BYP;PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W!T
M7T)2+G!O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<&\O<'1?4%0N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]P;R]N8E].3RYP;PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W!O+W-V7U-%+G!O"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<&\O=')?
M5%(N<&\)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]P;R]E;%]'4BYP;PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W!O+VMO7TM2+G!O"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]L9&%P+VAO<F1E
M+G-C:&5M80ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O;6]V95]H:7-T;W)Y7V]U=%]O9E]D
M871A=')E92YP:'`)<F]O="!W:&5E;"`P-S4U"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(P,#8M,#8M,CE?:&]R9&5?
M<')E9G-?:6YD97AE<RYS<6P)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S8W)I<'1S+W5P9W)A9&5S+S(N,E]T;U\S+C`N<&=S<6PN<W%L"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T
M<R]U<&=R861E<R\R+C)?=&]?,RXP+FUY<W%L+G-Q;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D
M97,O,BXR7W1O7S,N,"YO8VDX+G-Q;`D*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O,RXP7W1O7S,N,2YM>7-Q;"YS<6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N;V-I."YS<6P)"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S+S(P,#4M,#DM
M,C)?:&]R9&5?<')E9G-?=F%R8VAA<C(N;V-I."YS<6P)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A
M9&5S+S,N,%]T;U\S+C$N<W%L"0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO8W)E871E+F]C:3@N<W%L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E
M871E+FUY<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R
M+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+V-R96%T92YM<V1E+G-Q;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+U)%
M041-10ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W-C<FEP=',O<W%L+W-C<FEP="YI;FET:6%L7VAO<F1E7W5S97(N<W%L
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?:&ES=&]R:65S+FUS<W%L+G-Q;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+V-R96%T92YS<6P)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]C<F5A=&4N>&UL"0HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<&=S<6PN
M<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?9&%T871R964N<W%L"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?<V5S<VEO;FAA;F1L97(N;7ES<6PN<W%L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?9&%T871R964N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;75V9G,N
M<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S+G!G<W%L+G-Q;`ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7VQO9RYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]214%$344N3T-).`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7W5S97)S+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VAI<W1O<FEE
M<RYS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYO8VDX+G-Q
M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYO8VDX+G-Q;`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W!R969S+FUS<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W1O:V5N<RYS
M<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYM<W-Q;"YS<6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]L;V<N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?<V5S<VEO;FAA;F1L97(N<V%P9&(N<W%L"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M;75V9G,N;7-S<6PN<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G-Y8F%S92YS<6P)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]V9G,N<W%L"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?=F9S
M+FUS<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7V1A=&%T<F5E+FUY<W%L+G-Q;`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T
M92YP9W-Q;"YS<6P)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S8W)I<'1S+V-R;VYD"7)O;W0@=VAE96P@,#<U-0HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]T:&5M97-?8VAE8VLN
M<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V-R:7!T<R]C;W5N=%]S97-S:6]N<RYP:'`)<F]O="!W:&5E;"`P-S4U
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+RYH=&%C8V5S
M<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-C<FEP=',O:'1T<%]L;V=I;E]R969E<BYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S8W)I<'1S+VUI9W)A=&5?
M=7-E<E]C871E9V]R:65S+G!H<`ER;V]T('=H965L(#`W-34*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP=',O<F5M;W9E7W!R969S+G!H<`ER
M;V]T('=H965L(#`W-34*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C
M<FEP=',O<V5T=7`N<&AP"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]T96UP+6-L96%N=7`N8W)O;@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-C<FEP
M=',O<V5T7W!E<FUS+G-H"7)O;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]C<F5A=&4M<WEM;&EN:W,N<&AP"7)O
M;W0@=VAE96P@,#<U-0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R
M:7!T<R]C;V]K:65?;&]G:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]30U))4%13"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V-R:7!T<R]G
M971?;&]G:6XN<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VQA;F<O96XN
M:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E
M+VQA;F<O96XN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]!
M;G-E;$EM86=E+V%N<V5L+6EM86=E+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92]S:&]W:6UA
M9V4N:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O;G1E
M>'1-96YU+VQA;F<O96XN:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]#;VYT97AT365N=2]M96YU+F-S<PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;'5G:6YS+T-O;G1E>'1-96YU+V-O;G1E>'0M;65N=2YJ<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I
M;6<O8V5L;"UD96QE=&4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L
M=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C;VPM<W!L:70N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM
M9R]C96QL+6UE<F=E+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G
M:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+6EN<V5R="UA8F]V92YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+W)O=RUD96QE=&4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+6EN<V5R="UB969O
M<F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/
M<&5R871I;VYS+VEM9R]C96QL+6EN<V5R="UA9G1E<BYG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E
M;&PM<W!L:70N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O
M5&%B;&5/<&5R871I;VYS+VEM9R]C;VPM:6YS97)T+6%F=&5R+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I
M;6<O8V]L+6EN<V5R="UB969O<F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M<')O<"YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+V-O;"UD96QE=&4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+7!R;W`N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS
M+VEM9R]T86)L92UP<F]P+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+7-P;&ET+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I
M;6<O<F]W+6EN<V5R="UU;F1E<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O;&%N9R]E;BYJ<PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]T86)L
M92UO<&5R871I;VYS+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I
M;G,O3&ES=%1Y<&4O;&%N9R]E;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;'5G:6YS+TQI<W14>7!E+VQI<W0M='EP92YJ<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;W!U<',O9G5L;'-C<F5E;BYH=&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!O<'5P<R]P;W!U<"YJ<PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;W!U<',O86)O=70N:'1M;`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;W!U<',O<V5L96-T7V-O;&]R+FAT;6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&]P=7!S+VEN<V5R=%]T86)L92YH=&UL"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!O<'5P<R]L:6YK+FAT;6P)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&]P=7!S+V)L86YK+FAT;6P)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S+VEN<V5R=%]I;6%G92YH=&UL"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]A;&EG;E]L969T+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?:VEL;'=O<F0N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C=7-T;VTN9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]B;&%N:RYG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEN9&5N=%]L97-S+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?:6YD96YT7VUO<F4N9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A;&EG;E]J=7-T
M:69Y+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R
M;6%T7VET86QI8RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7V-H87)M87`N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]F=6QL<V-R965N7VUI;FEM:7IE+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?<&%S=&4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]E9%]C=70N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]S:&]W7V)O<F1E<BYG:68)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+V5D7W)E9&\N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]E9%]L:6YK+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?:&5L<"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7V9O<FUA=%]B;VQD+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?;&5F=%]T;U]R:6=H="YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7W5N9&\N9VEF"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?<W5B+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O:6YS97)T7W1A8FQE+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R;6%T7W-U<"YG:68)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEM86=E+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?:'(N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]R:6=H=%]T;U]L969T+F=I9@ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?:'1M;"YG:68)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W-A=F4N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]F;W)M871?<W1R:6ME+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9&5L971E+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8V]L;W)?8F<N
M9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A8F]U="YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VQI<W1?8G5L
M;&5T+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?8V]L
M;W)?9F<N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A
M;&EG;E]R:6=H="YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7V9O<FUA=%]U;F1E<FQI;F4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]F=6QL<V-R965N7VUA>&EM:7IE+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?<FUF;W)M870N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]A;&EG;E]C96YT97(N9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C;W!Y+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?;&ES=%]N=6TN9VEF"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]S<&QI=&-E;"YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O9&EA;&]G+FIS"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!O<'5P=VEN+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!O<'5P9&EV+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VAT;6QA
M<F5A+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VAT;6QA<F5A+F-S<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N
M<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]S:&%R97,O961I="YP:'`)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V
M:6-E<R]D;W=N;&]A9"]I;F1E>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]O8G)O=W-E<B]I;F1E
M>"YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O
M:6UA9V5S+W!I>&5L+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W-E<G9I8V5S+VEM86=E<R]V:65W+G!H<`ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R
M=FEC97,O;&%N9W5A9V4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M<V5R=FEC97,O:F%V87-C<FEP="YP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]K97EB;V%R9"YP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S
M97)V:6-E<R]C86-H979I97<N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]S97)V:6-E<R]P<F5F<RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]G;RYP:'`)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]S97)V:6-E<R]P
M<F]B;&5M+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]H96QP+VUE;G4N:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+VAE;'`O:6YD97@N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+VUE;G4O;65N=2YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]V97)S:6]N+FEN
M8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1E;7!L871E<R]T97-T+W!H<%]V97)S:6]N+FEN8PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]T97-T
M+V5X=&5N<VEO;G,N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O9F]O=&5R+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L
M871E<R]T97-T+VAE861E<BYI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+V%D9"YI;F,)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;`ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E
M<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]I;F1E>"]F<F%M
M97-?:6YD97@N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E
M<R]P<F5F<R]M=6QT:65N=6TN:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O<&%S<W=O<F0N:6YC"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O;W9E<G9I97<N
M:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&5M<&QA=&5S+W!R969S+W-E;&5C="YI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O
M=&5X="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O<')E9G,O;G5M8F5R+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P
M<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O=&5X=&%R
M96$N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&5M<&QA=&5S+W!R969S+V-H96-K8F]X+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P
M<F5F<R]E;G5M+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]B96=I;BYI;F,)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T
M97,O<')E9G,O87!P+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]L:6YK+FEN8PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V1A=&4N:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E
M;7!L871E<R]D871A+V1A=&5T:6UE+FEN8PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]C;VYT96YT<R]O
M<&5N7W9I97=?=VEN+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M9V]O9VQE7W=I;BYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]T<F5E+FIS"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96$N:G,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP
M="]P<FEN="YJ<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?:'1M;%]H96QP
M97(N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:V5Y8FEN9&EN9W,N:G,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO<VED96)A<BYI
M;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T96UP;&%T97,O<&]R=&%L+V)L;V-K+FEN8PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&5M<&QA=&5S+V-O;6UO;BUF;V]T97(N:6YC"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&5M<&QA=&5S+V-O;6UO;BUH
M96%D97(N:6YC"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&5M<&QA=&5S+RYH=&%C8V5S<PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G96YN979I;&QI
M97)S+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O<V-R965N+F-S<PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]A>G5R+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V%Z=7(O<V-R965N+F-S<PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F5Y+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R97DO<V-R965N+F-S<PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R].
M95A49W)E>2]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R].95A49W)E>2]S8W)E96XN8W-S"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V-O<FYF;&]W97(O9W)A<&AI8W,O=&%B7V)O='1O;2YG:68)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M8V]R;F9L;W=E<B]G<F%P:&EC<R]T86)?<FEG:'0N9VEF"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-O<FYF
M;&]W97(O9W)A<&AI8W,O=&%B7VQE9G0N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(O
M:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O8V]R;F9L;W=E<B]S8W)E96XN8W-S"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V)R
M;W=N+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V)R;W=N+W-C<F5E;BYC<W,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)E
M96XO:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)E96XO<V-R965N+F-S<PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A
M<R]G<F%P:&EC<R]B86-K9W)O=6YD+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G<F%P:&EC
M<R]M96YU7W1O<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O;&5F=%]M96YU
M7W1O<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O:61E87,O9W)A<&AI8W,O;&5F=%]M96YU7V)O='1O
M;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O:61E87,O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O:61E87,O<V-R965N
M+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]K;VQA8B]G<F%P:&EC<R]K;VQA8BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O:V]L
M86(O9W)A<&AI8W,O8F<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S+VMO;&%B
M;&]G;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O:V]L86(O:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O:V]L86(O<V-R
M965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]L879A;F1E<B]I;F9O+G!H<`ER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L879A;F1E
M<B]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WIW+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]A;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M8F$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%M+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]B8BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86XN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V%O+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]B9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8F4N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V)F+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B
M9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O87(N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V)H+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B:2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O870N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V)J+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A=2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8V$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%W
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B;2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O8FXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)O+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]A>BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O8V8N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-G+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]B<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V@N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)S+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]C:2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G0N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V-K+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]C;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G<N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V-M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C;BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8GDN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V-O+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B>BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O9&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V-R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C=2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O9&LN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-V+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]E8RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O8WDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-Z+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]E92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M96<N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V1Z+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]E<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O97,N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V9I+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]E="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9FHN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V=A+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]F
M;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9V4N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V9R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G:2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O9VPN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V=P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G<BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O9W0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=U
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]H:RYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O9WDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VED+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]I92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O:'(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VAT+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]H=2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:6PN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VEN+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]I<2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:7(N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VES+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]I="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:FTN<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+VIO+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K92YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:G`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VMG+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K:"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O:VDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+VQB+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L8RYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O:W`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMR+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]L:RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O;6$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUC+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]K>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M;60N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMZ+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]M9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;'0N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VQU+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]L=BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;F$N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VUN+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N
M8RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;'DN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VUO+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M<"YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O;F8N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VUS+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M="YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O;FPN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUX
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M>2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;F\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUZ+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]N<"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;G(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!A+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;GHN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!E+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]P9BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&@N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+W!K+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]P;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<6$N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+W!M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P<BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<'0N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W!Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S82YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O<V(N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W)O+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S9"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O<V4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-G+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S:2YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O<G4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-K+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]S;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M=&,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-O+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]T9RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<W(N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W1H+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]U82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&XN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W-Y+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T
M;RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O='`N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W5G+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T<BYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O='0N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+W5K+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T=BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O=F$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W1W
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T>BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O=F4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9G+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]U<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O=FDN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W9N+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]U>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=W,N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WEE+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]Z82YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O>74N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V%F+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE
M+VUS97AC96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7W=R:71E<BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O;6EM92]V:61E;RYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6EM92]X;6PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7VEM<')E
M<W,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+7!Y=&AO;BYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6EM92]M<W!O=V5R<&]I;G0N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VUI;64O;7-W;W)D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V)I
M;F%R>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]H=&UL+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+W9C87)D+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O
M;U]D<F%W+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W)P;2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]O;V]?8V%L8RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM
M92]E;F-R>7!T:6]N+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]M871H
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VUA:6PN<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O875D:6\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O8V]M<')E
M<W-E9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]T97AT+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]M:6UE+W-O=7)C92UC+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE
M+W-O=7)C92UH+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W-O=7)C92UJ879A
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+VEM86=E+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+W-O=7)C92UC<'`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M:6-A;&5N9&%R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W!D9BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;6EM92]P:'`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O
M<V-R:7!T+6IS+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V1E8BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]F=6QL;6]O;BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO;6]O;B]L87-T<75A<G1E<BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO;6]O;B]N97=M;V]N+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]M;V]N+V9I<G-T<75A<G1E<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\T-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,RYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S4N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\W+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S@N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O.2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R]N82YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q
M,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\Q,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R
M,W@R,R\Q,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\R,W@R,R\Q,RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\Q-"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\Q-2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\Q-BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\Q-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q."YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q.2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R,RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R-"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R
M-2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\R-BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R
M,W@R,R\R-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\R,W@R,R\R."YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\R.2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\S,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\S,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\S,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S,RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-RYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S."YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S.2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T
M,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\T,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R
M,W@R,R\T,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\R,W@R,R\T,RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\R,W@R,R\T-"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\T-2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\R,W@R,R\T-BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\P+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0W+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\V+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S<N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O."YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Y+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+VYA
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+U170VQO9V]?,S)P>"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\S,G@S,B\Q,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\Q,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\Q,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q,RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-RYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q."YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q.2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R
M,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\R,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\R,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\R,RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\R-"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\S,G@S,B\R-2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\R-BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\R-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R."YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R.2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,BYP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S-"YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S
M-2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S
M,B\S-BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\S-RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\S."YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O
M=&-O;2\S,G@S,B\S.2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\S,G@S,B\T,"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\T,2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\T,BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T,RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T-"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T-2YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T-BYP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\P+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]S=6YR:7-E+W-U;G)I<V4N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W-U;G)I<V4O<W5N<V5T+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]L87)G95]L969T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L
M969T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]D;W=N+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]L87)G95]R:6=H="YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=7`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+VQA<F=E7W5P+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]L87)G95]D;W=N+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]B;&]C:R]R:6=H="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]L:6YU>"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]F<F%N8RYJ<&<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]D979I;"YG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]L:7-A+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5L
M;65R9G5D9"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G87)F:65L9"YG
M:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R96DN:G!G"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O9W)O=F5R+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+W!U9F8N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=')I;BYJ<&<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]K:60N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O;6%R9V4N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<&EC87)D
M+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9E;6%L93$N:G!G"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O9F5M86QE,BYJ<&<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M879A=&%R<R]M86QE,2YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M86QE
M,BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D;V<N9VEF"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O<WEL=F5S=&5R+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+W-M:6QE>2YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D:6YO
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)R970N:G!G"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O=VEN;FEE+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V5L;6\N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9W)E96YH96%D
M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W1I9V=E<BYG:68)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]B;WEA;F1M;W=E<BYG:68)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O879A=&%R<R]J97)I+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W1H
M;VUA<RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;V)A9F5T="YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]M86XN:G!G"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O:'5M<"YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;75R
M9G,N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<GEU+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V%N9W)Y8F]Y+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)E<G0R+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1I9VEM
M;VXN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6EB+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+W9A;7!I<F4R+FIP9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V%U+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VMI<FLN:G!G
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O<F5D8W)E871U<F4N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O<V]N:6,N9VEF"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O8G5N;GDN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]M86XN
M:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9G)E9&9L:6YS=&]N92YG:68)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]P86EN=&EN9V)I<F0N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O8F5R="YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]I8V5S:V%T96MI9"YG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]N
M96\N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6%U;"YG:68)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]W;VQV97)I;F4N:G!G"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O86QI96XN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<W!E
M961Y+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A<F)A<FEA;BYJ<&<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]M;VYK97DN:G!G"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O979I;"YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B
M;WEA;F1P8RYG:68)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]X96YA+F=I9@ER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W9A;7!I<F4N:G!G"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O<W1A;BYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]U
M<RYJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]C;V-K>2YJ<&<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]B86)Y+F=I9@ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W=I>F%R9"YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]A;'DN:G!G
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O8VAA<FQI95]B<F]W;BYG:68)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]A<&4N:G!G"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O;65L;VXN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]O9&EE
M+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W=A8VMO+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V-L;W=N+FIP9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V1U8VLN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O96EN<W1E:6XN
M:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%T;6%N+F=I9@ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+W-E>'DN9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O;&]V96)I<F0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F]O+FIP
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VAO;65R+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V)A<G0N9VEF"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M;FEN:F$N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O<W5P97)M86XN9VEF
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O9&EL8F5R="YG:68)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]R96DR+FIP9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+V=R96UL:6XN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9V]P:&5R+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VMR>71O;BYJ<&<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+V%N9V5L=VEN:RYP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M96UO=&EC;VYS+W=I;FMT;VYG=65O=70N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]D979I;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W)A
M<W!B97)R>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)L=7-H+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O96UB87)R87-S960N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]P=6YK;6]H87=K+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O9G)U<W1R871E9"YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V-O;F9U<V5D+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O:&EP<&EE=&]N9W5E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O9&%Z960N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]S860N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]F<F]W;BYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+V-O;VQG<FEN+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M;6]T:6-O;G,O<'5N:RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V=R
M:6XN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]M860N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]D979I;'1O;F=U92YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+W!U;FMT;VYG=64N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]C;V]L=&]N9W5E+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O8FEG9W)I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAU
M<G0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;F=E;"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+V-O;VPN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]M<G0N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]S
M;6EL92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-H;W5T+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O86YN;WEE9"YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+W=I;FMT;VYG=64N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]A;F=R>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+W=I;FLN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]V86UP:7)E+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:&%N9V]V97(N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V5M;W1I8V]N<R]B:6=F<F]W;BYP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+W=I;FMG<FEN+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O:&EP<&EE9W)I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS
M+W1O;F=U96]U="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V-L;W=N
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:6YD:69F97)E;G0N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]D:7-A<'!O:6YT960N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V5M;W1I8V]N<R]W;W)R:65D+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O87-L965P+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O96YR86=E9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VQO
M=F4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]T:7)E9"YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAI<'!I92YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6]B:6QE+V1I<W!L87DN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]R
M:6=H="YJ<&<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6]B:6QE+VQE9G0N:G!G"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUO8FEL92]T;W`N:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL
M92]B;W1T;VTN:G!G"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T<R]W87)N:6YG+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]A;&5R=',O;65S<V%G92YP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O86QE<G1S+W-U8V-E<W,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%L97)T
M<R]E<G)O<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O87)R;W<M9&]W;BYG
M:68)"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O:6UA9V4O<F%T:6\N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+W)O=&%T
M92TQ.#`N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+W)O=&%T92TR-S`N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VEM86=E+V9L:7`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VEM86=E+VUI<G)O<BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O9W)A>7-C
M86QE+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]C<F]P+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]I;6%G92]R;W1A=&4M.3`N<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM
M86=E+W)E9G)E<V@N9VEF"0HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VEM86=E+V%R<F]W+75P+F=I9@D*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R
M97-H+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]T<F5E+W!L=7,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O
M9F]L9&5R;W!E;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]B;&%N:RYP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O=')E92]P;'5S8F]T=&]M+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]T<F5E+W)E=BUM:6YU<V]N;'DN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R
M964O<F5V+6IO:6YB;W1T;VTM9&]W;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E
M92]L96%F+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VIO:6YB;W1T;VTM9&]W
M;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<V]N;'DN<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W1R964O;G5L;&]N;'DN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O:F]I;F)O='1O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#
M5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M
M;&EN92YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;6EN=7-B;W1T;VTN
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+7!L=7,N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W1R964O<F5V+7!L=7-B;W1T;VTN<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O;6EN=7,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O;6EN=7-T;W`N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+W1R964O;6EN=7-O;FQY+G!N9PER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]T<F5E+VIO:6XN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O;6EN
M=7-B;W1T;VTN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6QE868N<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6IO:6YB;W1T;VTN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W1R964O9F]L9&5R+G!N9PER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+W)E=BUN=6QL;VYL>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M;6EN
M=7,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<V]N;'DN<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W1R964O<F5V+7!L=7-T;W`N<&YG"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O<F5V+6UI;G5S=&]P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VQI
M;F4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<W1O<"YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;F%V+V)O='1O;2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V1O
M=VXM9W)E>2YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+VQA<W0M9W)E>2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;F%V+VQE9G0M9W)E>2YP;F<)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;F%V+V1O=VXN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]F:7)S="UG<F5Y
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]N878O<FEG:'0M9W)E>2YP;F<)<F]O="!W
M:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;F%V+W)I9VAT+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&5F
M="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V)O='1O;2UG<F5Y+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]N878O=&]P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O=7`N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+VYA=B]U<"UG<F5Y+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]N878O=&]P+6=R97DN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]L87-T
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]N878O9FER<W0N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V-A;&5N9&%R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T86)?8F]T=&]M+F=I
M9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]P<F5F<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6%P
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]O<F=A;FEZ:6YG+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]L;V=I;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]4
M7T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;&AA;F0N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+W-Q;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]N9FEG+G!N9PER
M;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]P97)M<RYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O87HN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W5N;&]C:V5D+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H
M:61E7W!A;F5L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D96QE=&4M<VUA;&PN<&YG
M"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W!R;V)L96TN<&YG"7)O;W0@=VAE96P@,#8T-`HD
M>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V-O
M;&]R<V-A;&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$
M?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUY86-C;W5N="YP;F<)<F]O
M="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O<VAA9&]W+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S:&%D;W<N
M<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V-O;&]R<&EC:V5R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]R96QO860N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO<F1E+7!O=V5R,2YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O:&]R9&4M<&]W97(R+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]S:&]W7W!A;F5L+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92UP;W=E
M<C,N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAE;'!?:6YD97@N<&YG"7)O;W0@=VAE
M96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+VAO<F1E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/
M3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]S96%R8V@N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V=R;W5P+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;&]S92YP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O>F$N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VQO8VME
M9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9&5L971E+G!N9PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]U<V5R+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;F9O+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]L87EO=70N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W)H86YD+G!N9PER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]O9F9I8V4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1A=&%T<F5E
M+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]E9&ET+7-M86QL+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]R97%U:7)E9"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:6YF;U]I8V]N+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]D;W=N;&]A9"YP;F<)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;&]G;W5T+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:RYP;F<)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9&5V96PN<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W=E8G-I=&4N<&YG"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W!R:6YT+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$
M54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H96QP+G!N
M9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]S:&5L;"YP;F<)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O961I
M="YP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O:V5Y8F]A<F0N<&YG"7)O;W0@=VAE96P@
M,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9A=FEC;VXN:6-O"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L86YK+F=I9@ER;V]T
M('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]D871A+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A9&UI;FES=')A
M=&EO;BYP;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6%P7V5U+G!N9PER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]G;V]G;&4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-A=F4N<&YG"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+W!R:6YT+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]2
M3T]47T1]+W!S82UH;W)D92]T:&5M97,O:&DM8V]N=')A<W0O:6YF;RYP:'`)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O:&DM8V]N=')A<W0O<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B;'5E=VAI=&4O
M:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O8FQU97=H:71E+W-C<F5E;BYC<W,)<F]O="!W:&5E
M;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<VEM
M<&QE>"]G<F%P:&EC<R]B86-K9W)O=6YD+G!N9PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]S:6UP;&5X+VEN
M9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+W-I;7!L97@O<V-R965N+F-S<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]C86UO=69L
M86=E+V=R87!H:6-S+VUE;G4N<&YG"7)O;W0@=VAE96P@,#8T-`HD>U!23T15
M0U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O:6YF;RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O8V%M;W5F;&%G92]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P
M:&EC<R]T86)?8F]T=&]M+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O=&%B7W)I
M9VAT+F=I9@ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]L=6,O9W)A<&AI8W,O=&%B7VQE9G0N9VEF"7)O;W0@
M=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S
M+VQU8R]G<F%P:&EC<R]C=7)R96YT5&%B7W)I9VAT+F=I9@ER;V]T('=H965L
M(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L=6,O
M9W)A<&AI8W,O8W5R<F5N=%1A8E]L969T+F=I9@ER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]L=6,O:6YF;RYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O;'5C+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/
M1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;'5C8FQU92]I;F9O+G!H
M<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E
M+W1H96UE<R]L=6-B;'5E+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<&]S=&YU:V4O:6YF
M;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O<&]S=&YU:V4O<V-R965N+F-S<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B87)B:64O
M:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S
M82UH;W)D92]T:&5M97,O8F%R8FEE+W-C<F5E;BYC<W,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL
M82]G<F%P:&EC<R]M96YU+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-4
M7U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+V=R87!H:6-S+VUE
M;G4M86-T:79E+G!N9PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+V=R87!H:6-S+VAE861E<BYP
M;F<)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]T:&5M97,O;6]Z:6QL82]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M0
M4D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+W-C<F5E
M;BYC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH
M;W)D92]T:&5M97,O8FQU96UO;VXO:6YF;RYP:'`)<F]O="!W:&5E;"`P-C0T
M"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O8FQU96UO;VXO
M<V-R965N+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO
M<'-A+6AO<F1E+W1H96UE<R]L:6=H=&)L=64O9W)A<&AI8W,O;65N=2YP;F<)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O;&EG:'1B;'5E+VEN9F\N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!2
M3T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU92]S8W)E
M96XN8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M
M:&]R9&4O=&AE;65S+VUO8FEL92]S8W)E96XN8W-S"7)O;W0@=VAE96P@,#8T
M-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE;65S+W!U<G!L92]I
M;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A
M+6AO<F1E+W1H96UE<R]P=7)P;&4O<V-R965N+F-S<PER;V]T('=H965L(#`V
M-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]B=7)N=&]R
M86YG92]I;F9O+G!H<`ER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?
M1'TO<'-A+6AO<F1E+W1H96UE<R]B=7)N=&]R86YG92]S8W)E96XN8W-S"7)O
M;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/5%]$?2]P<V$M:&]R9&4O=&AE
M;65S+W)T;"YC<W,)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]
M+W!S82UH;W)D92]T:&5M97,O:64U;6%C+F-S<PER;V]T('=H965L(#`V-#0*
M)'M04D]$54-47U)/3U1?1'TO<'-A+6AO<F1E+W1H96UE<R]M;WHQ-"YC<W,)
M<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T
M:&5M97,O;W!E<F$N8W-S"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?4D]/
M5%]$?2]P<V$M:&]R9&4O=&AE;65S+W-A9F%R:2YC<W,)<F]O="!W:&5E;"`P
M-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]T:&5M97,O<V-R965N
M+F-S<PER;V]T('=H965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO<'-A+6AO
M<F1E+W1H96UE<R]I939?;W)?;&5S<RYC<W,)<F]O="!W:&5E;"`P-C0T"B1[
M4%)/1%5#5%]23T]47T1]+W!S82UH;W)D92]U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`)<F]O="!W:&5E;"`P-C0T"B1[4%)/1%5#5%]23T]47T1]+W!S82UH;W)D
M92]U=&EL+V)A<F-O9&4N<&AP"7)O;W0@=VAE96P@,#8T-`HD>U!23T150U1?
M4D]/5%]$?2]P<V$M:&]R9&4O=71I;"]R96=E>%]T97-T+G!H<`ER;V]T('=H
M965L(#`V-#0*)'M04D]$54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D
M92]C;VYF+G!H<`ER;V]T('=H965L(#`T-#0*)'M04D]$54-47U)/3U1?1'TO
M971C+W!S82UH;W)D92]H;W)D92]M:6UE7V1R:79E<G,N<&AP"7)O;W0@=VAE
M96P@,#0T-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A+6AO<F1E+VAO<F1E
M+VUO=&0N<&AP"7)O;W0@=VAE96P@,#0T-`HD>U!23T150U1?4D]/5%]$?2]E
M=&,O<'-A+6AO<F1E+VAO<F1E+VYL<RYP:'`)<F]O="!W:&5E;"`P-#0T"B1[
M4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M:&]R9&4O:&]R9&4O<')E9G,N<&AP
M"7)O;W0@=VAE96P@,#0T-`HD>U!23T150U1?4D]/5%]$?2]E=&,O<'-A+6AO
M<F1E+VAO<F1E+W)E9VES=')Y+G!H<`ER;V]T('=H965L(#`T-#0*)'M04D]$
M54-47U)/3U1?1'TO971C+W!S82UH;W)D92]H;W)D92]H;V]K<RYP:'`)<F]O
M="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]47T1]+V5T8R]P<V$M:&]R9&4O
M:&]R9&4O8V]N9BYX;6P)<F]O="!W:&5E;"`P-#0T"B1[4%)/1%5#5%]23T]4
M7T1]+V5T8R]P<V$M:&]R9&4O:&]R9&4O+FAT86-C97-S"7)O;W0@=VAE96P@
M,#0T-`H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-3(@,#$V,C(W`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M971C+W!S82UH;W)D92]H;W)D90``````````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$U,B`P
M,3<S,S``(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+V-O;F8N<&AP
M````````````````````````````````````````````````````````````
M`````````````````#`P,#0T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P
M,3(V(#$P-3$U-#,T,34R(#`R,3`T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!#3TY&24<@4U1!4E0N($1/
M($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@3U(@049415(@5$A)4R!,24Y%+B`J
M+PHO+R`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]C;VYF+GAM;"QV(#$N-S0N,BXT
M,2`R,#`V+S`X+S`T(#$W.C$S.C(U(&IA;B!%>'`@)`HO*BH**B!0;&5S:R!P
M<F5D969I;F5D(&-O;F9I9W5R871I;VX@9F]R($AO<F1E,PHJ*B\*"B1C;VYF
M6R=D96)U9U]L979E;"==(#T@15]%4E)/4CL*)&-O;F9;)VUA>%]E>&5C7W1I
M;64G72`](#`["B1C;VYF6R=U<V5?<W-L)UT@/2`R.PHD8V]N9ELG<V5R=F5R
M)UU;)VYA;64G72`]("1?4T525D526R=315)615)?3D%-12==.PHD8V]N9ELG
M<V5R=F5R)UU;)W!O<G0G72`]("1?4T525D526R=315)615)?4$]25"==.PHD
M8V]N9ELG8V]M<')E<W-?<&%G97,G72`]('1R=64["B1C;VYF6R=U;6%S:R==
M(#T@,#<W.PHD8V]N9ELG<V5S<VEO;B==6R=N86UE)UT@/2`G2&]R9&4S)SL*
M)&-O;F9;)W-E<W-I;VXG75LG8V%C:&5?;&EM:71E<B==(#T@)VYO8V%C:&4G
M.PHD8V]N9ELG<V5S<VEO;B==6R=T:6UE;W5T)UT@/2`P.PHD8V]N9ELG8V]O
M:VEE)UU;)V1O;6%I;B==(#T@)%]315)615);)U-%4E9%4E].04U%)UT["B1C
M;VYF6R=C;V]K:64G75LG<&%T:"==(#T@)R\G.PHD8V]N9ELG<W%L)UU;)W!E
M<G-I<W1E;G0G72`](&9A;'-E.PHD8V]N9ELG<W%L)UU;)VAO<W1S<&5C)UT@
M/2`G;&]C86QH;W-T)SL*)&-O;F9;)W-Q;"==6R=U<V5R;F%M92==(#T@)VAO
M<F1E)SL*)&-O;F9;)W-Q;"==6R=S;V-K970G72`]("<O=F%R+VQI8B]M>7-Q
M;"]M>7-Q;"YS;V-K)SL*)&-O;F9;)W-Q;"==6R=P<F]T;V-O;"==(#T@)W5N
M:7@G.PHD8V]N9ELG<W%L)UU;)V1A=&%B87-E)UT@/2`G:&]R9&4G.PH*+R\@
M9V5T('!A<W-W;W)D(&9R;VT@+V5T8R]P<V$O+G=E8FUA:6PN<VAA9&]W(`II
M9B`H(2@D9F0@/2!F;W!E;B@B+V5T8R]P<V$O+G=E8FUA:6PN<VAA9&]W(BP@
M(G(B*2DI('L*("!E8VAO("(\<V-R:7!T/F%L97)T*"=5;F%B;&4@=&\@9V5T
M('=E8FUA:6P@<&%S<W=O<F0A)RD\+W-C<FEP=#XB.PH@(&5X:70H*3L*?0IF
M<V-A;F8H)&9D+"`B)7,B+"`D8G5F9BD["F9C;&]S92@D9F0I.PH*)&-O;F9;
M)W-Q;"==6R=P87-S=V]R9"==(#T@<')E9U]R97!L86-E*"(O7&XO(BP@(B(L
M("1B=69F*3L*)&-O;F9;)W-Q;"==6R=C:&%R<V5T)UT@/2`G=71F."<["B1C
M;VYF6R=S<6PG75LG<&AP='EP92==(#T@)VUY<W%L)SL*)&-O;F9;)V%U=&@G
M75LG861M:6YS)UT@/2!A<G)A>2@I.PHD8V]N9ELG875T:"==6R=C:&5C:VEP
M)UT@/2!T<G5E.PHD8V]N9ELG875T:"==6R=C:&5C:V)R;W=S97(G72`]('1R
M=64["B1C;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I;B==(#T@9F%L<V4[
M"B1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO9V]U="==(#T@9F%L<V4[
M"@HD8V]N9ELG875T:"==6R=D<FEV97(G72`]("=C;VUP;W-I=&4G.PHD8V]N
M9ELG875T:"==6R=P87)A;7,G75LG9')I=F5R<R==(#T@87)R87DH"B`@("`G
M:6UP)R`]/B!A<G)A>2@G9')I=F5R)R`]/B`G87!P;&EC871I;VXG+`H@("`@
M("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R87DH)V%P<"<@/3X@)VEM
M<"<I*2P*("`@("=M:6UP)R`]/B!A<G)A>2@G9')I=F5R)R`]/B`G87!P;&EC
M871I;VXG+`H@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y
M*"=A<'`G(#T^("=M:6UP)RDI*3L*"B1C;VYF6R=A=71H)UU;)W!A<F%M<R==
M6R=L;V=I;G-C<F5E;E]S=VET8V@G72`]("=?:&]R9&5?<V5L96-T7VQO9VEN
M<V-R965N)SL*"6EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?<V5L96-T
M7VQO9VEN<V-R965N)RDI('L*"0EF=6YC=&EO;B!?:&]R9&5?<V5L96-T7VQO
M9VEN<V-R965N*"D*"0E["@D)"4!D969I;F4H2$]21$5?0D%312PG+W5S<B]S
M:&%R92]P<V$M:&]R9&4G*3L*"0D)<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B](;W)D92]"<F]W<V5R+G!H<"<["@D)"21B<F]W<V5R(#T@;F5W
M($)R;W=S97(H*3L*"0D):68@*"1B<F]W<V5R+3YI<TUO8FEL92@I("8F("1'
M3$]"04Q36R=R96=I<W1R>2==+3YA<'!L:6-A=&EO;G-;)VUI;7`G72E["@D)
M"0ER971U<FX@)VUI;7`G.PH)"0E]"@D)"7)E='5R;B`G:6UP)SL@"@D)?0I]
M"@HD8V]N9ELG<VEG;G5P)UU;)V%L;&]W)UT@/2!F86QS93L*)&-O;F9;)VQO
M9R==6R=P<FEO<FET>2==(#T@4$5!4E],3T=?15)2.PHD8V]N9ELG;&]G)UU;
M)VED96YT)UT@/2`G2$]21$4G.PHD8V]N9ELG;&]G)UU;)W!A<F%M<R==(#T@
M87)R87DH*3L*)&-O;F9;)VQO9R==6R=N86UE)UT@/2`G+W5S<B]L;V-A;"]P
M<V$O=F%R+VQO9R]P<V$M:&]R9&4N;&]G)SL*)&-O;F9;)VQO9R==6R=P87)A
M;7,G75LG87!P96YD)UT@/2!T<G5E.PHD8V]N9ELG;&]G)UU;)W1Y<&4G72`]
M("=F:6QE)SL*)&-O;F9;)VQO9R==6R=E;F%B;&5D)UT@/2!T<G5E.PHD8V]N
M9ELG;&]G7V%C8V5S<VME>7,G72`](&9A;'-E.PHD8V]N9ELG<')E9G,G75LG
M<&%R86US)UU;)V1R:79E<F-O;F9I9R==(#T@)VAO<F1E)SL*)&-O;F9;)W!R
M969S)UU;)V1R:79E<B==(#T@)W-Q;"<["B1C;VYF6R=D871A=')E92==6R=P
M87)A;7,G75LG9')I=F5R8V]N9FEG)UT@/2`G:&]R9&4G.PHD8V]N9ELG9&%T
M871R964G75LG9')I=F5R)UT@/2`G<W%L)SL*)&-O;F9;)V=R;W5P)UU;)V1R
M:79E<B==(#T@)V1A=&%T<F5E)SL*)&-O;F9;)V-A8VAE)UU;)V1E9F%U;'1?
M;&EF971I;64G72`](#$X,#`["B1C;VYF6R=C86-H92==6R=P87)A;7,G75LG
M9&ER)UT@/2!(;W)D93HZ9V5T5&5M<$1I<B@I.PHD8V]N9ELG8V%C:&4G75LG
M<&%R86US)UU;)V=C)UT@/2`X-C0P,#L*)&-O;F9;)V-A8VAE)UU;)V1R:79E
M<B==(#T@)V9I;&4G.PHD8V]N9ELG;6%I;&5R)UU;)W!A<F%M<R==6R=H;W-T
M)UT@/2`G;&]C86QH;W-T)SL*)&-O;F9;)VUA:6QE<B==6R=P87)A;7,G75LG
M875T:"==(#T@)S`G.PHD8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72`]("=S;71P
M)SL*)&-O;F9;)W9F<R==6R=P87)A;7,G75LG=F9S<F]O="==(#T@)R]T;7`G
M.PHD8V]N9ELG=F9S)UU;)W1Y<&4G72`]("=F:6QE)SL*)&-O;F9;)W-E<W-I
M;VYH86YD;&5R)UU;)W1Y<&4G72`]("=N;VYE)SL*)&-O;F9;)VUI;64G75LG
M;6%G:6-?9&(G72`]("<@+W5S<B]S:&%R92]M:7-C+VUA9VEC)SL*)&-O;F9;
M)W!R;V)L96US)UU;)V5M86EL)UT@/2`G=V5B;6%S=&5R0&5X86UP;&4N8V]M
M)SL*)&-O;F9;)W!R;V)L96US)UU;)VUA:6QD;VUA:6XG72`]("=E>&%M<&QE
M+F-O;2<["B1C;VYF6R=P<F]B;&5M<R==6R=T:6-K971S)UT@/2!F86QS93L*
M)&-O;F9;)VUE;G4G75LG87!P<R==(#T@87)R87DH*3L*)&-O;F9;)VUE;G4G
M75LG86QW87ES)UT@/2!F86QS93L*)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG
M:&5L<"==(#T@)V%L;"<["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)VAE;'!?
M86)O=70G72`]('1R=64["B1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)V]P=&EO
M;G,G72`]("=A=71H96YT:6-A=&5D)SL*)&-O;F9;)VUE;G4G75LG;&EN:W,G
M75LG<')O8FQE;2==(#T@)VYE=F5R)SL*)&-O;F9;)VUE;G4G75LG;&EN:W,G
M75LG;&]G:6XG72`]("=A;&PG.PHD8V]N9ELG;65N=2==6R=L:6YK<R==6R=L
M;V=O=70G72`]("=A=71H96YT:6-A=&5D)SL*)&-O;F9;)VAO;VMS)UU;)W!E
M<FUS9&5N:65D)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE
M)UT@/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)W!R96%U=&AE;G1I8V%T92==
M(#T@9F%L<V4["B1C;VYF6R=H;V]K<R==6R=P;W-T875T:&5N=&EC871E)UT@
M/2!F86QS93L*)&-O;F9;)VAO;VMS)UU;)V%U=&AL9&%P)UT@/2!F86QS93L*
M)&-O;F9;)W!O<G1A;"==6R=F:7AE9%]B;&]C:W,G72`](&%R<F%Y*"D["B1C
M;VYF6R=A8V-O=6YT<R==6R=D<FEV97(G72`]("=N=6QL)SL*)&-O;F9;)VEM
M<W`G75LG96YA8FQE9"==(#T@9F%L<V4["B1C;VYF6R=K;VQA8B==6R=E;F%B
M;&5D)UT@/2!F86QS93L*)&-O;F9;)W1O:V5N)UU;)W!A<F%M<R==6R=D<FEV
M97)C;VYF:6<G72`]("=H;W)D92<["B1C;VYF6R=T;VME;B==6R=D<FEV97(G
M72`]("=S<6PG.PHD8V]N9ELG8W-S)UU;)V-A8VAE9"==(#T@=')U93L*+RH@
M0T].1DE'($5.1"X@1$\@3D]4($-(04Y'12!!3EE42$E.1R!)3B!/4B!"149/
M4D4@5$A)4R!,24Y%+B`J+PH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O;6EM95]D<FEV97)S+G!H<```
M````````````````````````````````````````````````````````````
M````,#`P-#0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S8U,S<@,3`U,34T
M,S0Q-3(@,#(R-C(Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]M
M:6UE7V1R:79E<G,N<&AP+F1I<W0L=B`Q+CDW+C8N.2`R,#`V+S`T+S`V(#(Q
M.C,R.C$T(&IA;B!%>'`@)`H@*@H@*B!$96-I9&4@=VAI8V@@;W5T<'5T(&1R
M:79E<G,@>6]U('=A;G0@=&\@86-T:79A=&4@9F]R(&%L;"!(;W)D90H@*B!A
M<'!L:6-A=&EO;G,N($EN9&EV:61U86P@2&]R9&4@87!P;&EC871I;VYS(&-A
M;B!O=F5R<FED92!T:&5S92!S971T:6YG<PH@*B!I;B!T:&5I<B!C;VYF:6<O
M;6EM95]D<FEV97)S+G!H<"!F:6QE<RX*("H*("H@5&AE(&%V86EL86)L92!D
M<FEV97)S(&%R93H*("H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*("H@
M8W-S("`@("`@("`@("`@0U-3(%-T>6QE<PH@*B!D96(@("`@("`@("`@("!$
M96)I86X@<&%C:V%G97,*("H@96YR:6-H960@("`@("`@16YR:6-H960@=&5X
M="!F;W)M870*("H@96YS8W)I<'0@("`@("`@1TY5(&5N<V-R:7!T"B`J(&AT
M;6P@("`@("`@("`@($A434P@9&%T80H@*B!I;6%G97,@("`@("`@("!);6%G
M92!F:6QE<PH@*B!M<W=O<F0@("`@("`@("!-:6-R;W-O9G0@5V]R9"!F:6QE
M<R!V:6$@=W9(=&UL"B`J(&US97AC96P@("`@("`@($UI8W)O<V]F="!%>&-E
M;"!F:6QE<R!V:6$@>&QH=&UL"B`J(&US<&]W97)P;VEN="`@($UI8W)O<V]F
M="!0;W=E<G!O:6YT(&9I;&5S('9I82!P<'1H=&UL"B`J(&]O;R`@("`@("`@
M("`@($]P96Y/9F9I8V4N;W)G+U-T87)/9F9I8V4@1&]C=6UE;G1S"B`J('!D
M9B`@("`@("`@("`@(%!O<G1A8FQE($1O8W5M96YT($9O<FUA="`H4$1&*2!F
M:6QE<PH@*B!P:'`@("`@("`@("`@("!4:&4@:6YT97)N86P@4$A0-"!S>6YT
M87@@:&EG:&QI9VAT:6YG(&5N9VEN90H@*B!P;&%I;B`@("`@("`@("!2971U
M<FX@=&5X="P@=VET:"!L:6YK<R!M861E(&-L:6-K86)L92!A;F0@;W1H97(@
M2%1-3`H@*B`@("`@("`@("`@("`@("!F:6QT97)E9"!O=70*("H@<F%R("`@
M("`@("`@("`@4D%2(&%R8VAI=F5S"B`J(')E<&]R="`@("`@("`@(%)E<&]R
M="!M97-S86=E<R`H4D9#(#,T-3(I"B`J(')F8S@R,B`@("`@("`@($1I9V5S
M=&5D(&UE<W-A9V5S("A21D,@,C`T-B!;-2XR+C%=*0H@*B!R:6-H=&5X="`@
M("`@("!2:6-H=&5X="!T97AT(&9O<FUA="`H4D9#(#$S-#$@6S<N,2XS72D*
M("H@<G!M("`@("`@("`@("`@4E!-('!A8VMA9V5S"B`J('-E8W5R:71Y("`@
M("`@(%-E8W5R92!M=6QT:7!A<G1S("A21D,@,3@T-RD*("H@<VEM<&QE("`@
M("`@("`@3W5T<'5T('1E>'0@=VET:&]U="!M;V1I9FEC871I;VX*("H@<W)C
M:&EG:&QI=&4@("`@4V]U<F-E($AI9VAL:6=H=`H@*B!T9WH@("`@("`@("`@
M("!487)B86QL<RP@:6YC;'5D:6YG(&=Z:7!P960@;VYE<PH@*B!T;F5F("`@
M("`@("`@("!-4RU43D5&(&%T=&%C:&UE;G1S"B`J('9C87)D("`@("`@("`@
M('9#87)D<PH@*B!W96)C<'`@("`@("`@("!796(@0R!0;'5S(%!L=7,*("H@
M>FEP("`@("`@("`@("`@6FEP(&9I;&5S"B`J+PHD;6EM95]D<FEV97)S7VUA
M<%LG:&]R9&4G75LG<F5G:7-T97)E9"==(#T@87)R87DH"B`@("`G8W-S)RP@
M)V5N<FEC:&5D)RP@)VAT;6PG+"`G:6UA9V5S)RP@)V]O;R<L("=P9&8G+"`G
M<&AP)RP@)W!L86EN)RP@)W)A<B<L"B`@("`G<F5P;W)T)RP@)W)F8S@R,B<L
M("=R:6-H=&5X="<L("=S96-U<FET>2<L("=S:6UP;&4G+"`G=&=Z)RP@)W1N
M968G+`H@("`@)W9C87)D)RP@)WII<"<L"B`@("`O+R!4:&4@9F]L;&]W:6YG
M(&UI;64@9')I=F5R<R!R97%U:7)E(&5X=&5R;F%L(&%P<&QI8V%T:6]N<R!T
M;R!B90H@("`@+R\@:6YS=&%L;&5D+@H@("`@+R\@)V1E8B<L("=E;G-C<FEP
M="<L("=M<W=O<F0G+"`G;7-E>&-E;"<L("=M<W!O=V5R<&]I;G0G+"`G<G!M
M)RP*("`@("\O("=S<F-H:6=H;&ET92<L("=W96)C<'`G"BD["@H*+RHJ"B`J
M($EF('EO=2!W86YT('1O('-P96-I9FEC86QL>2!O=F5R<FED92!A;GD@34E-
M12!T>7!E('1O(&)E(&AA;F1L960@8GD*("H@82!S<&5C:69I8R!D<FEV97(L
M('1H96X@96YT97(@:70@:&5R92X@($YO<FUA;&QY+"!T:&ES(&ES('-A9F4@
M=&\*("H@;&5A=F4L(&)U="!I="=S('5S969U;"!W:&5N(&UU;'1I<&QE(&1R
M:79E<G,@:&%N9&QE('1H92!S86UE($U)344*("H@='EP92P@86YD('EO=2!W
M86YT('1O('-P96-I9GD@97AA8W1L>2!W:&EC:"!O;F4@<VAO=6QD(&AA;F1L
M92!I="X*("HO"B1M:6UE7V1R:79E<G-?;6%P6R=H;W)D92==6R=O=F5R<FED
M97,G72`](&%R<F%Y*"D["@H*+RHJ"B`J($1R:79E<B!S<&5C:69I8R!S971T
M:6YG<RX@2&5R92P@>6]U(&AA=F4@=&\@8V]N9FEG=7)E(&5A8V@@9')I=F5R
M"B`J('=H:6-H('EO=2!C:&]S92!T;R!A8W1I=F%T92!A8F]V92X@1&5F875L
M="!S971T:6YG<R!H879E(&)E96X*("H@9FEL;&5D(&EN(&9O<B!T:&5M+"!A
M;F0@:68@>6]U(&AA=F5N)W0@86-T:79A=&5D(&ET+"!T:&5N(&IU<W0*("H@
M;&5A=F4@:70@87,@:70@:7,@+2!I="!W;VXG="!G970@;&]A9&5D+@H@*@H@
M*B!4:&4@)VAA;F1L97,G('-E='1I;F<@8F5L;W<@<VAO=6QD;B=T(&)E(&-H
M86YG960@:6X@;6]S=`H@*B!C:7)C=6US=&%N8V5S+B!)="!R96=I<W1E<G,@
M82!S970@;V8@34E-12!T>7!E('1H870@=&AE(&1R:79E<B!C86X*("H@:&%N
M9&QE+B!4:&4@)W@M97AT96YS:6]N)R!-24U%('1Y<&4@:7,@82!S<&5C:6%L
M(&]N92!T;R!(;W)D92!T:&%T"B`J(&UA<',@82!F:6QE(&5X=&5N<VEO;B!T
M;R!A($U)344@='EP92X@270G<R!U<V5F=6P@=VAE;B!Y;W4@:VYO=PH@*B!T
M:&%T(&%L;"!F:6QE<R!E;F1I;F<@:6X@)RYC)R!A<F4@0R!F:6QE<RP@9F]R
M(&5X86UP;&4N(%EO=2!C86X@<V5T"B`J('1H92!-24U%('-U8G1Y<&4@=&\@
M)RHG('1O(&UA=&-H(&%L;"!P;W-S:6)L92!S=6)T>7!E<PH@*B`H:2YE+B`G
M:6UA9V4O*B<I+@H@*@H@*B!4:&4@)VEC;VYS)R!E;G1R>2!I<R!F;W(@=&AE
M(&1R:79E<B!T;R!R96=I<W1E<B!V87)I;W5S(&EC;VYS(&9O<@H@*B!T:&4@
M34E-12!T>7!E<R!I="!H86YD;&5S+B!4:&4@87)R87D@8V]N<VES=',@;V8@
M82`G9&5F875L="<@:6-O;@H@*B!F;W(@=&AA="!D<FEV97(L(&%N9"!C86X@
M86QS;R!I;F-L=61E('-P96-I9FEC($U)344M='EP97,@=VAI8V@@8V%N"B`J
M(&AA=F4@=&AE:7(@;W=N(&EC;VYS+B!9;W4@8V%N('-E="!T:&4@34E-12!S
M=6)T>7!E('1O("<J)R!T;R!M871C:`H@*B!A;&P@<&]S<VEB;&4@<W5B='EP
M97,@*&DN92X@)VEM86=E+RHG*2X*("HO"@HO*BH*("H@1&5F875L="!D<FEV
M97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V1E9F%U
M;'0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G("`@("`@("`@
M("`@("`@("`@("`@("`]/B`G=&5X="YP;F<G+`H@("`@)V%U9&EO+RHG("`@
M("`@("`@("`@("`@("`@("`@("`]/B`G875D:6\N<&YG)RP*("`@("=M97-S
M86=E+RHG("`@("`@("`@("`@("`@("`@("`@/3X@)VUA:6PN<&YG)RP*("`@
M("=U;FMN;W=N+RHG("`@("`@("`@("`@("`@("`@("`@/3X@)V)I;F%R>2YP
M;F<G+`H@("`@)W9I9&5O+RHG("`@("`@("`@("`@("`@("`@("`@("`]/B`G
M=FED96\N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]P9W`M<VEG;F%T=7)E)R`@
M("`@/3X@)V5N8W)Y<'1I;VXN<&YG)RP*("`@("=A<'!L:6-A=&EO;B]X+7!K
M8W,W+7-I9VYA='5R92<@/3X@)V5N8W)Y<'1I;VXN<&YG)RP*("`@("=A<'!L
M:6-A=&EO;B]O8W1E="US=')E86TG("`@("`@/3X@)V)I;F%R>2YP;F<G*3L*
M"@HO*BH*("H@1&5F875L="!T97AT(&1R:79E<B!S971T:6YG<PH@*B\*)&UI
M;65?9')I=F5R<ULG:&]R9&4G75LG<VEM<&QE)UU;)VEN;&EN92==(#T@=')U
M93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<VEM<&QE)UU;)VAA;F1L97,G
M72`](&%R<F%Y*`H@("`@)W1E>'0O*B<I.PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=S:6UP;&4G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G
M(#T^("=T97AT+G!N9R<I.PH*"B\J*@H@*B!0;&%I;B!T97AT(&1R:79E<B!S
M971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&QA:6XG75LG
M:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=P;&%I
M;B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=T97AT+W!L86EN)RD["B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!L86EN)UU;)VEC;VYS)UT@/2!A<G)A
M>2@*("`@("=D969A=6QT)R`]/B`G=&5X="YP;F<G*3L*"@HO*BH*("H@4$A0
M(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG
M<&AP)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG<&AP)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N
M+W@M<&AP)RP@)W@M97AT96YS:6]N+W!H<',G+`H@("`@)W@M97AT96YS:6]N
M+W!H<#-S)RP@)V%P<&QI8V%T:6]N+W@M:'1T<&0M<&AP)RP*("`@("=A<'!L
M:6-A=&EO;B]X+6AT='!D+7!H<#,G+"`G87!P;&EC871I;VXO>"UH='1P9"UP
M:'!S)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W!H<"==6R=I8V]N<R==
M(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)W!H<"YP;F<G*3L*"@HO*BH*
M("H@0U-3(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG8W-S)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG8W-S)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O
M8W-S)RP@)W@M97AT96YS:6]N+V-S<R<I.PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=C<W,G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^
M("=H=&UL+G!N9R<I.PH*"B\J*@H@*B!%;G)I8VAE9"!T97AT(&1R:79E<B!S
M971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG:'1M;"==6R=I
M;FQI;F4G72`](&9A;'-E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=H=&UL
M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O:'1M;"<I.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=H=&UL)UU;)VEC;VYS)UT@/2!A<G)A>2@*
M("`@("=D969A=6QT)R`]/B`G:'1M;"YP;F<G*3L*"@HO*BH*("H@16YR:6-H
M960@=&5X="!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E<G-;)VAO
M<F1E)UU;)V5N<FEC:&5D)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG96YR:6-H960G75LG:&%N9&QE<R==(#T@87)R87DH
M"B`@("`G=&5X="]E;G)I8VAE9"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=E;G)I8VAE9"==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@
M/3X@)W1E>'0N<&YG)RD["@H*+RHJ"B`J(%)I8VAT97AT('1E>'0@9')I=F5R
M('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R:6-H=&5X
M="==6R=I;FQI;F4G72`]('1R=64["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)W)I8VAT97AT)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O<FEC
M:'1E>'0G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<FEC:'1E>'0G75LG
M:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=T97AT+G!N9R<I
M.PH*"B\J*@H@*B!796(@0R!0;'5S(%!L=7,@9')I=F5R('-E='1I;F=S"B`J
M(&AT='`Z+R]W96)C<'`N<V]U<F-E9F]R9V4N;F5T+PH@*B\*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VQO8V%T:6]N)UT@/2`G+W5S<B]B
M:6XO=V5B8W!P)SL*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;
M)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG=V5B
M8W!P)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)W1E>'0O>&UL)RP@)W1E
M>'0O<V=M;"<L("=A<'!L:6-A=&EO;B]X;6PG+`H@("`@)V%P<&QI8V%T:6]N
M+W@M<V@G+"`G87!P;&EC871I;VXO>"UJ879A<V-R:7!T)RP@)V%P<&QI8V%T
M:6]N+W@M=&-L)RP*("`@("=X+65X=&5N<VEO;B]A<VTG+"`G87!P;&EC871I
M;VXO>"UA<W`G+"`G>"UE>'1E;G-I;VXO8F%S)RP*("`@("=X+65X=&5N<VEO
M;B]C<R<L("=T97AT+W@M8W-R8R<L("=X+65X=&5N<VEO;B]R8R<L"B`@("`G
M=&5X="]X+6,K*W-R8R<L("=T97AT+W@M8RLK<W)C)RP@)W1E>'0O>"UC*RMS
M<F,G+`H@("`@)W1E>'0O>"UC:&1R)RP@)W@M97AT96YS:6]N+V)A="<L("=T
M97AT+W@M9F]R=')A;B<L"B`@("`G>"UE>'1E;G-I;VXO9C<W)RP@)W@M97AT
M96YS:6]N+V8Y,"<L("=X+65X=&5N<VEO;B]F;W(G+`H@("`@)W@M97AT96YS
M:6]N+V9T;B<L("=T97AT+W@M:F%V82<L("=A<'!L:6-A=&EO;B]X+6IA=F%S
M8W)I<'0G+`H@("`@)W1E>'0O<V=M;"<L("=T97AT+WAM;"<L("=T97AT+W@M
M<&%S8V%L)RP*("`@("=A<'!L:6-A=&EO;B]X+6-G:2<L("=A<'!L:6-A=&EO
M;B]X+7!E<FPG+"`G87!P;&EC871I;VXO>"UP>71H;VXG+`H@("`@)W1E>'0O
M>"US<6PG+"`G=&5X="]X+71C;"<L"B`@("`G87!P;&EC871I;VXO>"US:&5L
M;'-C<FEP="<L("=X+65X=&5N<VEO;B]V:&0G+"`G>"UE>'1E;G-I;VXO=FAD
M;"<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=W96)C<'`G75LG:6-O;G,G
M72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G("`@("`@("`@("`@("`@("`@/3X@
M)W1E>'0N<&YG)RP*("`@("=T97AT+WAM;"<@("`@("`@("`@("`@("`@(#T^
M("=X;6PN<&YG)RP*("`@("=T97AT+W@M8W-R8R<@("`@("`@("`@("`@(#T^
M("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O>"UC:&1R)R`@("`@("`@("`@
M("`@/3X@)W-O=7)C92UH+G!N9R<L"B`@("`G=&5X="]X+6IA=F$G("`@("`@
M("`@("`@("`]/B`G<V]U<F-E+6IA=F$N<&YG)RP*("`@("=A<'!L:6-A=&EO
M;B]X+6IA=F%S8W)I<'0G(#T^("=S8W)I<'0M:G,N<&YG)RD["@HO*BH*("H@
M4V]U<F-E+4AI9VAL:6=H="!D<FEV97(@<V5T=&EN9W,*("H@:'1T<#HO+W=W
M=RYG;G4N;W)G+W-O9G1W87)E+W-R8RUH:6=H;&ET92\*("HO"B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;)VQO8V%T:6]N)UT@/2`G
M+W5S<B]B:6XO<V]U<F-E+6AI9VAL:6=H="<["B1M:6UE7V1R:79E<G-;)VAO
M<F1E)UU;)W-R8VAI9VAL:71E)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG<W)C:&EG:&QI=&4G75LG:&%N9&QE<R==(#T@
M87)R87DH"B`@("`G=&5X="]X+6-S<F,G+"`G=&5X="]X+6,K*W-R8R<L("=T
M97AT+W@M:F%V82<L"B`@("`G87!P;&EC871I;VXO>"UP97)L)RP@)V%P<&QI
M8V%T:6]N+W@M<'ET:&]N)RP@)W1E>'0O>"UC*RMS<F,G+`H@("`@)W1E>'0O
M8W!P)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;
M)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`@("`@("`@("`@("`@
M("`@(#T^("=T97AT+G!N9R<L"B`@("`G=&5X="]X+6-S<F,G("`@("`@("`@
M("`@("`]/B`G<V]U<F-E+6,N<&YG)RP*("`@("=T97AT+W@M8RLK<W)C)R`@
M("`@("`@("`@(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O8W!P)R`@
M("`@("`@("`@("`@("`@/3X@)W-O=7)C92UC+G!N9R<L"B`@("`G=&5X="]X
M+6IA=F$G("`@("`@("`@("`@("`]/B`G<V]U<F-E+6IA=F$N<&YG)RD["@HO
M*BH*("H@1TY5($5N<V-R:7!T(&1R:79E<B!S971T:6YG<PH@*B\*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G75LG;&]C871I;VXG72`]("<O
M=7-R+V)I;B]E;G-C<FEP="<["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N
M<V-R:7!T)UU;)VEN;&EN92==(#T@=')U93L*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG96YS8W)I<'0G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P
M;&EC871I;VXO>"UC9VDG+"`G87!P;&EC871I;VXO>"US:&5L;'-C<FEP="<L
M("=A<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0G+`H@("`@)V%P<&QI8V%T:6]N
M+W@M<&5R;"<L("=A<'!L:6-A=&EO;B]X;6PG+"`G=&5X="]X;6PG+`H@("`@
M)W1E>'0O9&EF9B<L("=T97AT+W@M9&EF9B<L("=T97AT+W@M<&%T8V@G+"`G
M=&5X="]X+6-S<F,G+`H@("`@)W@M97AT96YS:6]N+V-S)RP@)W1E>'0O>"UJ
M879A)RP@)W1E>'0O>"UC:&1R)RP@)W1E>'0O>"UC*RMS<F,G+`H@("`@)W1E
M>'0O>"UC*RMH9'(G+"`G>"UE>'1E;G-I;VXO=FAD)RP@)W@M97AT96YS:6]N
M+W9H9&PG+"`G=&5X="]X+7-Q;"<L"B`@("`G>"UE>'1E;G-I;VXO=F(G+"`G
M>"UE>'1E;G-I;VXO=F)A)RP@)W1E>'0O>"UE;6%C<RUL:7-P)RP@)W1E>'0O
M>"UT97@G*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G75LG
M:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G("`@("`@("`@("`@("`@
M("`@/3X@)W1E>'0N<&YG)RP*("`@("=T97AT+WAM;"<@("`@("`@("`@("`@
M("`@(#T^("=X;6PN<&YG)RP*("`@("=A<'!L:6-A=&EO;B]X;6PG("`@("`@
M("`@(#T^("=X;6PN<&YG)RP*("`@("=T97AT+W@M8W-R8R<@("`@("`@("`@
M("`@(#T^("=S;W5R8V4M8RYP;F<G+`H@("`@)W1E>'0O>"UC:&1R)R`@("`@
M("`@("`@("`@/3X@)W-O=7)C92UH+G!N9R<L"B`@("`G=&5X="]X+6IA=F$G
M("`@("`@("`@("`@("`]/B`G<V]U<F-E+6IA=F$N<&YG)RP*("`@("=A<'!L
M:6-A=&EO;B]X+6IA=F%S8W)I<'0G(#T^("=S8W)I<'0M:G,N<&YG)RD["@H*
M+RHJ"B`J(%1A<B!D<FEV97(@<V5T=&EN9W,*("H@5&\@86-C97-S(&=Z:7!P
M960@9FEL97,L('1H92!Z;&EB(&QI8G)A<GD@;75S="!H879E(&)E96X@8G5I
M;'0@:6YT;R!02%`*("H@*'=I=&@@=&AE("TM=VET:"UZ;&EB(&]P=&EO;BDN
M"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=T9WHG75LG:6YL:6YE)UT@
M/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=T9WHG75LG:&%N9&QE
M<R==(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO>"UC;VUP<F5S<V5D+71A
M<B<L"B`@("`G87!P;&EC871I;VXO>"UT87(G+`H@("`@)V%P<&QI8V%T:6]N
M+W@M=&=Z)RP*("`@("=A<'!L:6-A=&EO;B]X+6=Z:7`G+`H@("`@)V%P<&QI
M8V%T:6]N+W@M9W1A<B<L"B`@("`G87!P;&EC871I;VXO9WII<"<L"B`@("`G
M87!P;&EC871I;VXO>"UG>FEP+6-O;7!R97-S960G*3L*)&UI;65?9')I=F5R
M<ULG:&]R9&4G75LG=&=Z)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A
M=6QT)R`]/B`G8V]M<')E<W-E9"YP;F<G*3L*"@HO*BH*("H@6FEP(&9I;&4@
M9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=Z
M:7`G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=Z:7`G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO
M>FEP)RP*("`@("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S960G+`H@("`@)V%P
M<&QI8V%T:6]N+W@M>FEP+6-O;7!R97-S960G*3L*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG>FEP)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT
M)R`]/B`G8V]M<')E<W-E9"YP;F<G*3L*"@HO*BH*("H@4D%2(&%R8VAI=F4@
M9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R
M87(G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D<FEV97)S6R=H;W)D92==
M6R=R87(G75LG:&%N9&QE<R==(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO
M>"UR87(G+`H@("`@)V%P<&QI8V%T:6]N+W@M<F%R+6-O;7!R97-S960G*3L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<F%R)UU;)VEC;VYS)UT@/2!A<G)A
M>2@*("`@("=D969A=6QT)R`]/B`G8V]M<')E<W-E9"YP;F<G*3L*"@HO*BH*
M("H@35,@5V]R9"!D<FEV97(@<V5T=&EN9W,*("H@5&AI<R!D<FEV97(@<F5Q
M=6ER97,@=W9787)E('1O(&)E(&EN<W1A;&QE9"X*("H@=W9787)E(&AO;65P
M86=E.B!H='1P.B\O=W9W87)E+G-O=7)C969O<F=E+FYE="\*("H*("H@5&AE
M("=L;V-A=&EO;B<@96YT<GD@<VAO=6QD('!O:6YT('1O('1H92`G=W9(=&UL
M)R!P<F]G<F%M+"!.3U0@=&AE"B`J("=W=E=A<F4G('!R;V=R86TN"B`J+PHD
M;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG;&]C871I;VXG72`]
M("<O=7-R+V)I;B]W=DAT;6PG.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M
M<W=O<F0G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG;7-W;W)D)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI
M8V%T:6]N+W9N9"YM<RUW;W)D)RP*("`@("=A<'!L:6-A=&EO;B]M<W=O<F0G
M+`HI.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG:6-O;G,G
M72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=M<W=O<F0N<&YG)RP**3L*
M"@HO*BH*("H@35,@17AC96P@9')I=F5R('-E='1I;F=S"B`J(%1H:7,@9')I
M=F5R(')E<75I<F5S('AL:'1M;"!T;R!B92!I;G-T86QL960N"B`J('AL:'1M
M;"!H;VUE<&%G93H@:'1T<#HO+V-H:6-A9V\N<V]U<F-E9F]R9V4N;F5T+WAL
M:'1M;"\*("HO"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG
M;&]C871I;VXG72`]("<O=7-R+VQO8V%L+V)I;B]X;&AT;6PG.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=M<V5X8V5L)UU;)VEN;&EN92==(#T@9F%L<V4[
M"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG:&%N9&QE<R==
M(#T@87)R87DH"B`@("`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@
M("=A<'!L:6-A=&EO;B]M<V5X8V5L)RP*("`@("=A<'!L:6-A=&EO;B]X+6US
M97AC96PG*3L*)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-E>&-E;"==6R=I
M8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@)VUS97AC96PN<&YG
M)RD["@H*+RHJ"B`J($U3(%!O=V5R<&]I;G0@9')I=F5R('-E='1I;F=S"B`J
M(%1H:7,@9')I=F5R(')E<75I<F5S('!P=&AT;6PL(&EN8VQU9&5D('=I=&@@
M>&QH=&UL+"!T;R!B92!I;G-T86QL960N"B`J('AL:'1M;"!H;VUE<&%G93H@
M:'1T<#HO+V-H:6-A9V\N<V]U<F-E9F]R9V4N;F5T+WAL:'1M;"\*("HO"B1M
M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN="==6R=L;V-A=&EO
M;B==(#T@)R]U<W(O;&]C86PO8FEN+W!P=&AT;6PG.PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=M<W!O=V5R<&]I;G0G75LG:6YL:6YE)UT@/2!F86QS93L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VAA;F1L
M97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W9N9"YM<RUP;W=E<G!O
M:6YT)RP*("`@("=A<'!L:6-A=&EO;B]M<W!O=V5R<&]I;G0G*3L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG;7-P;W=E<G!O:6YT)UU;)VEC;VYS)UT@/2!A
M<G)A>2@*("`@("=D969A=6QT)R`]/B`G;7-P;W=E<G!O:6YT+G!N9R<I.PH*
M"B\J*@H@*B!V0V%R9"!D<FEV97(@<V5T=&EN9W,*("HO"B1M:6UE7V1R:79E
M<G-;)VAO<F1E)UU;)W9C87)D)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@
M)W1E>'0O>"UV8V%R9"<L"B`@("`G=&5X="]X+79C86QE;F1A<B<I.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=V8V%R9"==6R=I8V]N<R==(#T@87)R87DH
M"B`@("`G9&5F875L="<@/3X@)W9C87)D+G!N9R<I.PH*"B\J*@H@*B!24$T@
M9')I=F5R('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=R
M<&TG75LG;&]C871I;VXG72`]("<O=7-R+V)I;B]R<&TG.PHD;6EM95]D<FEV
M97)S6R=H;W)D92==6R=R<&TG75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?
M9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@
M("`@)V%P<&QI8V%T:6]N+W@M<G!M)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)W)P;2==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@
M)W)P;2YP;F<G*3L*"@HO*BH*("H@1&5B:6%N('!A8VMA9V4@9')I=F5R('-E
M='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=D96(G75LG;&]C
M871I;VXG72`]("<O=7-R+V)I;B]D<&MG)SL*)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG9&5B)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)V1E8B==6R=H86YD;&5S)UT@/2!A<G)A>2@*("`@("=A<'!L
M:6-A=&EO;B]X+61E8B<L"B`@("`G87!P;&EC871I;VXO>"UD96)I86XM<&%C
M:V%G92<I.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=D96(G75LG:6-O;G,G
M72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G(#T^("=D96(N<&YG)RD["@H*+RHJ
M"B`J(%-E8W5R92!M=6QT:7!A<G1S("A21D,@,3@T-RD*("HO"B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W-E8W5R:71Y)UU;)VEN;&EN92==(#T@=')U93L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<V5C=7)I='DG75LG:&%N9&QE<R==
M(#T@87)R87DH"B`@("`G;75L=&EP87)T+V5N8W)Y<'1E9"<L("=M=6QT:7!A
M<G0O<VEG;F5D)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-E8W5R:71Y
M)UU;)VEC;VYS)UT@/2!A<G)A>2@*("`@("=D969A=6QT)R`]/B`G96YC<GEP
M=&EO;BYP;F<G*3L*"@HO*BH*("H@26UA9V4@<V5T=&EN9W,*("HO"B1M:6UE
M7V1R:79E<G-;)VAO<F1E)UU;)VEM86=E<R==6R=I;FQI;F4G72`](&9A;'-E
M.PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=I;6%G97,G75LG:&%N9&QE<R==
M(#T@87)R87DH"B`@("`G:6UA9V4O*B<I.PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=I;6%G97,G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G
M(#T^("=I;6%G92YP;F<G*3L*"@HO*BH*("H@35,M5$Y%1B!!='1A8VAM96YT
M("AA<'!L:6-A=&EO;B]M<RUT;F5F*2!S971T:6YG<PH@*B\*)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=&YE9B==6R=I;FQI;F4G72`](&9A;'-E.PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=T;F5F)UU;)VAA;F1L97,G72`](&%R<F%Y
M*`H@("`@)V%P<&QI8V%T:6]N+VUS+71N968G*3L*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG=&YE9B==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L
M="<@/3X@)W1E>'0N<&YG)RD["@H*+RHJ"B`J($1I9V5S="!M97-S86=E("A2
M1D,@,C`T-B!;-2XR+C%=*2!S971T:6YG<PH@*B\*)&UI;65?9')I=F5R<ULG
M:&]R9&4G75LG<F9C.#(R)UU;)VEN;&EN92==(#T@9F%L<V4["B1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)W)F8S@R,B==6R=H86YD;&5S)UT@/2!A<G)A>2@*
M("`@("=M97-S86=E+W)F8S@R,B<L"B`@("`G>"UE>'1E;G-I;VXO96UL)RD[
M"B1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W)F8S@R,B==6R=I8V]N<R==(#T@
M87)R87DH"B`@("`G9&5F875L="<@/3X@)VUA:6PN<&YG)RD["@H*+RHJ"B`J
M(%)E<&]R="!M97-S86=E<R`H4D9#(#,T-3(I"B`J+PHD;6EM95]D<FEV97)S
M6R=H;W)D92==6R=R97!O<G0G75LG:6YL:6YE)UT@/2!T<G5E.PHD;6EM95]D
M<FEV97)S6R=H;W)D92==6R=R97!O<G0G75LG:&%N9&QE<R==(#T@87)R87DH
M"B`@("`G;75L=&EP87)T+W)E<&]R="<I.PHD;6EM95]D<FEV97)S6R=H;W)D
M92==6R=R97!O<G0G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G
M(#T^("=M86EL+G!N9R<I.PH*"B\J*@H@*B!/<&5N3V9F:6-E+F]R9R]3=&%R
M3V9F:6-E('-E='1I;F=S"B`J+PHD;6EM95]D<FEV97)S6R=H;W)D92==6R=O
M;V\G75LG:6YL:6YE)UT@/2!F86QS93L*)&UI;65?9')I=F5R<ULG:&]R9&4G
M75LG;V]O)UU;)VAA;F1L97,G72`](&%R<F%Y*`H@("`@)V%P<&QI8V%T:6]N
M+W9N9"YS=6XN>&UL+F-A;&,G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN
M>&UL+F-A;&,N=&5M<&QA=&4G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN
M>&UL+F1R87<G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+F1R87<N
M=&5M<&QA=&4G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FEM<')E
M<W,G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FEM<')E<W,N=&5M
M<&QA=&4G+`H@("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+FUA=&@G+`H@
M("`@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<B<L"B`@("`G87!P
M;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R+F=L;V)A;"<L"B`@("`G87!P
M;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R+G1E;7!L871E)RP*("`@("=A
M<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F-A;&,G+`H@("`@)V%P<&QI
M8V%T:6]N+W9N9"YS=&%R9&EV:7-I;VXN9')A=R<L"B`@("`G87!P;&EC871I
M;VXO=FYD+G-T87)D:79I<VEO;BYI;7!R97-S)RP*("`@("=A<'!L:6-A=&EO
M;B]V;F0N<W1A<F1I=FES:6]N+FUA=&@G+`H@("`@)V%P<&QI8V%T:6]N+W9N
M9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RD["B1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)V]O;R==6R=I8V]N<R==(#T@87)R87DH"B`@("`G9&5F875L="<@/3X@
M)V]O;U]C86QC+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN
M8V%L8R<@("`@("`@("`@("`@/3X@)V]O;U]C86QC+G!N9R<L"B`@("`G87!P
M;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYC86QC)R`@("`@("`@/3X@)V]O
M;U]C86QC+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN8V%L
M8RYT96UP;&%T92<@("`@/3X@)V]O;U]C86QC+G!N9R<L"B`@("`G87!P;&EC
M871I;VXO=FYD+G-U;BYX;6PN9')A=R<@("`@("`@("`@("`@/3X@)V]O;U]D
M<F%W+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYD
M<F%W)R`@("`@("`@/3X@)V]O;U]D<F%W+G!N9R<L"B`@("`G87!P;&EC871I
M;VXO=FYD+G-U;BYX;6PN9')A=RYT96UP;&%T92<@("`@/3X@)V]O;U]D<F%W
M+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN:6UP<F5S<R<@
M("`@("`@("`@/3X@)V]O;U]I;7!R97-S+G!N9R<L"B`@("`G87!P;&EC871I
M;VXO=FYD+G-T87)D:79I<VEO;BYI;7!R97-S)R`@("`@/3X@)V]O;U]I;7!R
M97-S+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN:6UP<F5S
M<RYT96UP;&%T92<@/3X@)V]O;U]I;7!R97-S+G!N9R<L"B`@("`G87!P;&EC
M871I;VXO=FYD+G-U;BYX;6PN;6%T:"<@("`@("`@("`@("`@/3X@)V]O;U]M
M871H+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYM
M871H)R`@("`@("`@/3X@)V]O;U]M871H+G!N9R<L"B`@("`G87!P;&EC871I
M;VXO=FYD+G-U;BYX;6PN=W)I=&5R)R`@("`@("`@("`@/3X@)V]O;U]W<FET
M97(N<&YG)RP*("`@("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+G=R
M:71E<B<@("`@("`]/B`G;V]O7W=R:71E<BYP;F<G+`H@("`@)V%P<&QI8V%T
M:6]N+W9N9"YS=6XN>&UL+G=R:71E<BYG;&]B86PG("`@(#T^("=O;V]?=W)I
M=&5R+G!N9R<L"B`@("`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN=W)I=&5R
M+G1E;7!L871E)R`@/3X@)V]O;U]W<FET97(N<&YG)RD["@H*+RHJ"B`J(%!O
M<G1A8FQE($1O8W5M96YT($9O<FUA="`H4$1&*2!F:6QE<PH@*B!93U4@4TA/
M54Q$($Y/5"!.3U)-04Q,62!!3%1%4B!42$E3(%-%5%1)3D<N"B`J+PHD;6EM
M95]D<FEV97)S6R=H;W)D92==6R=P9&8G75LG:6YL:6YE)UT@/2!F86QS93L*
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<&1F)UU;)VAA;F1L97,G72`](&%R
M<F%Y*`H@("`@)V%P<&QI8V%T:6]N+W!D9B<I.PHD;6EM95]D<FEV97)S6R=H
M;W)D92==6R=P9&8G75LG:6-O;G,G72`](&%R<F%Y*`H@("`@)V1E9F%U;'0G
M(#T^("=P9&8N<&YG)RD["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+VUO=&0N<&AP````````
M````````````````````````````````````````````````````````````
M`````````#`P,#0T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#,P(#$P
M-3$U-#,T,34R(#`R,3`U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\(2TM(%1H:7,@9FEL92!C;VYT86EN<R!A;GD@(DUE
M<W-A9V4@3V8@5&AE($1A>2(@5'EP92!I;F9O<FUA=&EO;B`M+3X*/"$M+2!)
M="!W:6QL(&)E(&EN8VQU9&5D(&)E;&]W('1H92!L;V<M:6X@9F]R;2!O;B!T
M:&4@;&]G:6X@<&%G92X@+2T^"@H\8G(@+SX*/'1A8FQE('=I9'1H/2(Q,#`E
M(CX\='(^/'1D(&%L:6=N/2)C96YT97(B/CQI;6<@<W)C/2)T:&5M97,O9W)A
M<&AI8W,O:&]R9&4M<&]W97(Q+G!N9R(@86QT/2)0;W=E<F5D(&)Y($AO<F1E
M(B`O/CPO=&0^/"]T<CX\+W1A8FQE/@H*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M971C+W!S82UH;W)D92]H;W)D92]N;',N<&AP````````````````````````
M```````````````````````````````````````````````````````P,#`T
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V,#`S-"`Q,#4Q-30S-#$U,B`P
M,C`W,34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($Y,4R`H3F%T:6]N86P@3&%N9W5A9V4@4W5P<&]R
M="D@8V]N9FEG=7)A=&EO;B!F:6QE+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V-O
M;F9I9R]N;',N<&AP+F1I<W0L=B`Q+C4Y+C$P+C<@,C`P-B\P-"\Q.2`R,SHS
M-CHR,B!J86X@17AP("0*("HO"@HO*BH*("HJ($1E9F%U;'1S"B`J*B\*"B\J
M(%1H92!L86YG=6%G92!T;R!F86QL(&)A8VL@;VX@:68@=V4@8V%N;F]T(&1E
M=&5R;6EN92!O;F4@86YY(&]T:&5R"B`@('=A>2`H=7-E<B!C:&]I8V4@;W(@
M<')E9F5R96YC97,I+B!)9B!E;7!T>2P@=V4@=VEL;"!T<GD@=&\@;F5G;W1I
M871E"B`@('=I=&@@=&AE(&)R;W=S97(@=7-I;F<@2%144%]!0T-%4%1?3$%.
M1U5!1T4N("HO"B1N;'-;)V1E9F%U;'1S)UU;)VQA;F=U86=E)UT@/2`G)SL*
M"@HO*BH*("HJ($QA;F=U86=E"B`J*B\*"B1N;'-;)VQA;F=U86=E<R==6R=A
M<E]/32==(#T@)T%R86)I8R`H3VUA;BD@*"8C>#`V,C<[)B-X,#8T-#LF(W@P
M-C,Y.R8C>#`V,S$[)B-X,#8R.#LF(W@P-C1A.R8C>#`V,CD[*2<["B1N;'-;
M)VQA;F=U86=E<R==6R=A<E]362==(#T@)T%R86)I8R`H4WER:6$I("@F(W@P
M-C(W.R8C>#`V-#0[)B-X,#8S.3LF(W@P-C,Q.R8C>#`V,C@[)B-X,#8T83LF
M(W@P-C(Y.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:61?240G72`]("="86AA
M<V$@26YD;VYE<VEA)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V)S7T)!)UT@/2`G
M0F]S86YS:VDG.PHD;FQS6R=L86YG=6%G97,G75LG8F=?0D<G72`]("="=6QG
M87)I86X@*"8C>#`T,3$[)B-X,#0T83LF(W@P-#-B.R8C>#`T,S,[)B-X,#0S
M,#LF(W@P-#0P.R8C>#`T-#$[)B-X,#0S83LF(W@P-#,X.RDG.PHD;FQS6R=L
M86YG=6%G97,G75LG8V%?15,G72`]("=#871A;"9A9W)A=F4[)SL*)&YL<ULG
M;&%N9W5A9V5S)UU;)WIH7T-.)UT@/2`G0VAI;F5S92`H4VEM<&QI9FEE9"D@
M*"8C>#=B.#`[)B-X-&8U,SLF(W@T93)D.R8C>#8U.#<[*2<["B1N;'-;)VQA
M;F=U86=E<R==6R=Z:%]45R==(#T@)T-H:6YE<V4@*%1R861I=&EO;F%L*2`H
M)B-X-F(V,SLF(W@Y860T.R8C>#1E,F0[)B-X-C4X-SLI)SL*)&YL<ULG;&%N
M9W5A9V5S)UU;)V-S7T-:)UT@/2`G0WIE8V@@*"8C>#`Q,&,[97-K>2DG.PHD
M;FQS6R=L86YG=6%G97,G75LG9&%?1$LG72`]("=$86YS:R<["B1N;'-;)VQA
M;F=U86=E<R==6R=D95]$12==(#T@)T1E=71S8V@G.PHD;FQS6R=L86YG=6%G
M97,G75LG96Y?55,G72`]("=%;F=L:7-H("A!;65R:6-A;BDG.PHD;FQS6R=L
M86YG=6%G97,G75LG96Y?1T(G72`]("=%;F=L:7-H("A"<FET:7-H*2<["B1N
M;'-;)VQA;F=U86=E<R==6R=E;E]#02==(#T@)T5N9VQI<V@@*$-A;F%D:6%N
M*2<["B1N;'-;)VQA;F=U86=E<R==6R=E<U]%4R==(#T@)T5S<&$F;G1I;&1E
M.V]L)SL*)&YL<ULG;&%N9W5A9V5S)UU;)V5T7T5%)UT@/2`G165S=&DG.PHD
M;FQS6R=L86YG=6%G97,G75LG9G)?1E(G72`]("=&<F%N)F-C961I;#MA:7,G
M.PHD;FQS6R=L86YG=6%G97,G75LG9VQ?15,G72`]("='86QE9V\G.PHD;FQS
M6R=L86YG=6%G97,G75LG96Q?1U(G72`]("='<F5E:R`H)B-X,#,Y-3LF(W@P
M,V)B.R8C>#`S8F([)B-X,#-B-SLF(W@P,V)D.R8C>#`S8CD[)B-X,#-B83LF
M(W@P,V%C.RDG.PHD;FQS6R=L86YG=6%G97,G75LG:&5?24PG72`]("=(96)R
M97<@*"8C>#`U13([)B-X,#5$,3LF(W@P-44X.R8C>#`U1#D[)B-X,#5%03LI
M)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VES7TE3)UT@/2`G)DEA8W5T93MS;&5N
M<VMA)SL*)&YL<ULG;&%N9W5A9V5S)UU;)VET7TE4)UT@/2`G271A;&EA;F\G
M.PHD;FQS6R=L86YG=6%G97,G75LG:F%?2E`G72`]("=*87!A;F5S92`H)B-X
M-C5E-3LF(W@V-S)C.R8C>#AA.64[*2<["B1N;'-;)VQA;F=U86=E<R==6R=K
M;5]+2"==(#T@)TMH;65R("@F(W@Q-S@Q.R8C>#$W9#([)B-X,3<Y.#LF(W@Q
M-V,R.R8C>#$W.6$[*2<["B1N;'-;)VQA;F=U86=E<R==6R=K;U]+4B==(#T@
M)TMO<F5A;B`H)B-X9#4U8SLF(WAA9#9D.R8C>&,U8C0[*2<["B1N;'-;)VQA
M;F=U86=E<R==6R=L=E],5B==(#T@)TQA='9I928C>#`Q-C$[=2<["B1N;'-;
M)VQA;F=U86=E<R==6R=L=%],5"==(#T@)TQI971U=FDF(W@P,3<S.R<["B1N
M;'-;)VQA;F=U86=E<R==6R=M:U]-2R==(#T@)TUA8V5D;VYI86X@*"8C>#`T
M,6,[)B-X,#0S,#LF(W@P-#-A.R8C>#`T,S4[)B-X,#0S-#LF(W@P-#-E.R8C
M>#`T,V0[)B-X,#0T,3LF(W@P-#-A.R8C>#`T,S@[*2<["B1N;'-;)VQA;F=U
M86=E<R==6R=H=5](52==(#T@)TUA9WEA<B<["B1N;'-;)VQA;F=U86=E<R==
M6R=N;%].3"==(#T@)TYE9&5R;&%N9',G.PHD;FQS6R=L86YG=6%G97,G75LG
M;F)?3D\G72`]("=.;W)S:R!B;VMM)F%R:6YG.VPG.PHD;FQS6R=L86YG=6%G
M97,G75LG;FY?3D\G72`]("=.;W)S:R!N>6YO<G-K)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)V9A7TE2)UT@/2`G4&5R<VEA;B`H)B-X,#8T,3LF(W@P-C(W.R8C
M>#`V,S$[)B-X,#8S,SLF(W@P-C0Y.RDG.PHD;FQS6R=L86YG=6%G97,G75LG
M<&Q?4$PG72`]("=0;VQS:VDG.PHD;FQS6R=L86YG=6%G97,G75LG<'1?4%0G
M72`]("=0;W)T=6=U)F5C:7)C.W,G.PHD;FQS6R=L86YG=6%G97,G75LG<'1?
M0E(G72`]("=0;W)T=6=U)F5C:7)C.W,@0G)A<VEL96ER;R<["B1N;'-;)VQA
M;F=U86=E<R==6R=R;U]23R==(#T@)U)O;29A8VER8SMN)F%U;6P[)SL*)&YL
M<ULG;&%N9W5A9V5S)UU;)W)U7U)5)UT@/2`G4G5S<VEA;B`H)B-X,#0R,#LF
M(W@P-#0S.R8C>#`T-#$[)B-X,#0T,3LF(W@P-#-A.R8C>#`T,S@[)B-X,#0S
M.3LI)SL*)&YL<ULG;&%N9W5A9V5S)UU;)W-K7U-+)UT@/2`G4VQO=F%K("A3
M;&]V96XF(W@P,3!D.VEN82DG.PHD;FQS6R=L86YG=6%G97,G75LG<VQ?4TDG
M72`]("=3;&]V96YI86X@*%-L;W9E;B8C>#`Q-C$[)B-X,#$P9#MI;F$I)SL*
M)&YL<ULG;&%N9W5A9V5S)UU;)V9I7T9))UT@/2`G4W5O;6DG.PHD;FQS6R=L
M86YG=6%G97,G75LG<W9?4T4G72`]("=3=F5N<VMA)SL*)&YL<ULG;&%N9W5A
M9V5S)UU;)W1H7U1()UT@/2`G5&AA:2`H)B-X,&4T-#LF(W@P93$W.R8C>#!E
M,C([*2<["B1N;'-;)VQA;F=U86=E<R==6R=T<E]44B==(#T@)U0F=75M;#MR
M:R9C8V5D:6P[92<["B1N;'-;)VQA;F=U86=E<R==6R=U:U]502==(#T@)U5K
M<F%I;FEA;B`H)B-X,#0R,SLF(W@P-#-A.R8C>#`T-#`[)B-X,#0S,#LF(W@P
M-#4W.R8C>#`T,V0[)B-X,#0T,3LF(W@P-#1C.R8C>#`T,V$[)B-X,#0S,#LI
M)SL*"@HO*BH*("HJ($%L:6%S97,@9F]R(&QA;F=U86=E<R!W:71H(&1I9F9E
M<F5N="!B<F]W<V5R(&%N9"!G971T97AT(&-O9&5S"B`J*B\*"B1N;'-;)V%L
M:6%S97,G75LG87(G72`]("=A<E]362<["B1N;'-;)V%L:6%S97,G75LG8F<G
M72`]("=B9U]"1R<["B1N;'-;)V%L:6%S97,G75LG8G,G72`]("=B<U]"02<[
M"B1N;'-;)V%L:6%S97,G75LG8V$G72`]("=C85]%4R<["B1N;'-;)V%L:6%S
M97,G75LG8W,G72`]("=C<U]#6B<["B1N;'-;)V%L:6%S97,G75LG9&$G72`]
M("=D85]$2R<["B1N;'-;)V%L:6%S97,G75LG9&4G72`]("=D95]$12<["B1N
M;'-;)V%L:6%S97,G75LG96PG72`]("=E;%]'4B<["B1N;'-;)V%L:6%S97,G
M75LG96XG72`]("=E;E]54R<["B1N;'-;)V%L:6%S97,G75LG97,G72`]("=E
M<U]%4R<["B1N;'-;)V%L:6%S97,G75LG970G72`]("=E=%]%12<["B1N;'-;
M)V%L:6%S97,G75LG9F$G72`]("=F85])4B<["B1N;'-;)V%L:6%S97,G75LG
M9FDG72`]("=F:5]&22<["B1N;'-;)V%L:6%S97,G75LG9G(G72`]("=F<E]&
M4B<["B1N;'-;)V%L:6%S97,G75LG9VPG72`]("=G;%]%4R<["B1N;'-;)V%L
M:6%S97,G75LG:&4G72`]("=H95])3"<["B1N;'-;)V%L:6%S97,G75LG:'4G
M72`]("=H=5](52<["B1N;'-;)V%L:6%S97,G75LG:60G72`]("=I9%])1"<[
M"B1N;'-;)V%L:6%S97,G75LG:7,G72`]("=I<U])4R<["B1N;'-;)V%L:6%S
M97,G75LG:70G72`]("=I=%])5"<["B1N;'-;)V%L:6%S97,G75LG:F$G72`]
M("=J85]*4"<["B1N;'-;)V%L:6%S97,G75LG:VTG72`]("=K;5]+2"<["B1N
M;'-;)V%L:6%S97,G75LG:V\G72`]("=K;U]+4B<["B1N;'-;)V%L:6%S97,G
M75LG;'0G72`]("=L=%],5"<["B1N;'-;)V%L:6%S97,G75LG;'8G72`]("=L
M=E],5B<["B1N;'-;)V%L:6%S97,G75LG;6LG72`]("=M:U]-2R<["B1N;'-;
M)V%L:6%S97,G75LG;FPG72`]("=N;%].3"<["B1N;'-;)V%L:6%S97,G75LG
M;FXG72`]("=N;E].3R<["B1N;'-;)V%L:6%S97,G75LG;F\G72`]("=N8E].
M3R<["B1N;'-;)V%L:6%S97,G75LG<&PG72`]("=P;%]03"<["B1N;'-;)V%L
M:6%S97,G75LG<'0G72`]("=P=%]05"<["B1N;'-;)V%L:6%S97,G75LG<F\G
M72`]("=R;U]23R<["B1N;'-;)V%L:6%S97,G75LG<G4G72`]("=R=5]252<[
M"B1N;'-;)V%L:6%S97,G75LG<VLG72`]("=S:U]32R<["B1N;'-;)V%L:6%S
M97,G75LG<VPG72`]("=S;%]322<["B1N;'-;)V%L:6%S97,G75LG<W8G72`]
M("=S=E]312<["B1N;'-;)V%L:6%S97,G75LG=&@G72`]("=T:%]42"<["B1N
M;'-;)V%L:6%S97,G75LG='(G72`]("=T<E]44B<["B1N;'-;)V%L:6%S97,G
M75LG=6LG72`]("=U:U]502<["@H*+RHJ"B`J*B!#:&%R<V5T<PH@*BHO"@HD
M;FQS6R=C:&%R<V5T<R==6R=A<E]/32==(#T@)W=I;F1O=W,M,3(U-B<["B1N
M;'-;)V-H87)S971S)UU;)V%R7U-9)UT@/2`G=VEN9&]W<RTQ,C4V)SL*)&YL
M<ULG8VAA<G-E=',G75LG8F=?0D<G72`]("=W:6YD;W=S+3$R-3$G.PHD;FQS
M6R=C:&%R<V5T<R==6R=B<U]"02==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C
M:&%R<V5T<R==6R=C<U]#6B==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C:&%R
M<V5T<R==6R=E;%]'4B==(#T@)TE33RTX.#4Y+3<G.PHD;FQS6R=C:&%R<V5T
M<R==6R=F85])4B==(#T@)U541BTX)SL*)&YL<ULG8VAA<G-E=',G75LG:&5?
M24PG72`]("=55$8M."<["B1N;'-;)V-H87)S971S)UU;)VAU7TA5)UT@/2`G
M25-/+3@X-3DM,B<["B1N;'-;)V-H87)S971S)UU;)VIA7TI0)UT@/2`G4TA)
M1E1?2DE3)SL*)&YL<ULG8VAA<G-E=',G75LG:VU?2T@G72`]("=55$8M."<[
M"B1N;'-;)V-H87)S971S)UU;)VMO7TM2)UT@/2`G155#+4M2)SL*)&YL<ULG
M8VAA<G-E=',G75LG;'1?3%0G72`]("=)4T\M.#@U.2TQ,R<["B1N;'-;)V-H
M87)S971S)UU;)VQV7TQ6)UT@/2`G=VEN9&]W<RTQ,C4W)SL*)&YL<ULG8VAA
M<G-E=',G75LG;6M?34LG72`]("=)4T\M.#@U.2TU)SL*)&YL<ULG8VAA<G-E
M=',G75LG<&Q?4$PG72`]("=)4T\M.#@U.2TR)SL*)&YL<ULG8VAA<G-E=',G
M75LG<G5?4E4G72`]("=W:6YD;W=S+3$R-3$G.PHD;FQS6R=C:&%R<V5T<R==
M6R=R=5]252Y+3TDX+5(G72`]("=+3TDX+5(G.PHD;FQS6R=C:&%R<V5T<R==
M6R=S:U]32R==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C:&%R<V5T<R==6R=S
M;%]322==(#T@)TE33RTX.#4Y+3(G.PHD;FQS6R=C:&%R<V5T<R==6R=T:%]4
M2"==(#T@)U1)4RTV,C`G.PHD;FQS6R=C:&%R<V5T<R==6R=T<E]44B==(#T@
M)TE33RTX.#4Y+3DG.PHD;FQS6R=C:&%R<V5T<R==6R=U:U]502==(#T@)TM/
M23@M52<["B1N;'-;)V-H87)S971S)UU;)WIH7T-.)UT@/2`G1T(R,S$R)SL*
M)&YL<ULG8VAA<G-E=',G75LG>FA?5%<G72`]("="24<U)SL*"@HO*BH*("HJ
M($UU;'1I8GET92!C:&%R<V5T<PH@*BHO"@HD;FQS6R=M=6QT:6)Y=&4G75LG
M0DE'-2==(#T@=')U93L*)&YL<ULG;75L=&EB>71E)UU;)T550RU+4B==(#T@
M=')U93L*)&YL<ULG;75L=&EB>71E)UU;)T=",C,Q,B==(#T@=')U93L*)&YL
M<ULG;75L=&EB>71E)UU;)U-(24947TI)4R==(#T@=')U93L*)&YL<ULG;75L
M=&EB>71E)UU;)U541BTX)UT@/2!T<G5E.PH*"B\J*@H@*BH@4FEG:'0M=&\M
M;&5F="!L86YG=6%G97,*("HJ+PH*)&YL<ULG<G1L)UU;)V%R7T]-)UT@/2!T
M<G5E.PHD;FQS6R=R=&PG75LG87)?4UDG72`]('1R=64["B1N;'-;)W)T;"==
M6R=F85])4B==(#T@=')U93L*)&YL<ULG<G1L)UU;)VAE7TE,)UT@/2!T<G5E
M.PH*"B\J*@H@*BH@4')E9F5R<F5D(&-H87)S971S(&9O<B!E;6%I;"!T<F%F
M9FEC(&EF(&YO="!T:&4@;&%N9W5A9V5S)R!D969A=6QT"B`J*B!C:&%R<V5T
M<RX*("HJ+PH*)&YL<ULG96UA:6QS)UU;)VIA7TI0)UT@/2`G25-/+3(P,C(M
M2E`G.PH*"B\J*@H@*BH@079A:6QA8FQE(&-H87)S971S(&9O<B!O=71G;VEN
M9R!E;6%I;"!T<F%F9FEC+@H@*BHO"@HD;FQS6R=E;F-O9&EN9W,G75LG=VEN
M9&]W<RTQ,C4V)UT@/2!?*")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB*3L*)&YL
M<ULG96YC;V1I;F=S)UU;)T%235-#24DM."==(#T@7R@B07)M96YI86X@*$%2
M35-#24DM."DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTX.#4Y+3$S)UT@
M/2!?*")"86QT:6,@*$E33RTX.#4Y+3$S*2(I.PHD;FQS6R=E;F-O9&EN9W,G
M75LG25-/+3@X-3DM,30G72`](%\H(D-E;'1I8R`H25-/+3@X-3DM,30I(BD[
M"B1N;'-;)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TR)UT@/2!?*")#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG
M1T(R,S$R)UT@/2!?*")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB*3L*
M)&YL<ULG96YC;V1I;F=S)UU;)T))1S4G72`](%\H(D-H:6YE<V4@5')A9&ET
M:6]N86P@*$)I9S4I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=+3TDX+5(G72`]
M(%\H(D-Y<FEL;&EC("A+3TDX+5(I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=W
M:6YD;W=S+3$R-3$G72`](%\H(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(BD[
M"B1N;'-;)V5N8V]D:6YG<R==6R=+3TDX+54G72`](%\H(D-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3@X
M-3DM-R==(#T@7R@B1W)E96L@*$E33RTX.#4Y+3<I(BD["B1N;'-;)V5N8V]D
M:6YG<R==6R=)4T\M.#@U.2TX+4DG72`](%\H(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(I.PHD;FQS6R=E;F-O9&EN9W,G75LG25-/+3(P,C(M2E`G72`](%\H
M(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB*3L*)&YL<ULG96YC;V1I;F=S)UU;
M)T550RU+4B==(#T@7R@B2V]R96%N("A%54,M2U(I(BD["B1N;'-;)V5N8V]D
M:6YG<R==6R=)4T\M.#@U.2TQ,"==(#T@7R@B3F]R9&EC("A)4T\M.#@U.2TQ
M,"DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE33RTX.#4Y+3,G72`](%\H(E-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(I.PHD;FQS6R=E;F-O9&EN9W,G
M75LG5$E3+38R,"==(#T@7R@B5&AA:2`H5$E3+38R,"DB*3L*)&YL<ULG96YC
M;V1I;F=S)UU;)TE33RTX.#4Y+3DG72`](%\H(E1U<FMI<V@@*$E33RTX.#4Y
M+3DI(BD["B1N;'-;)V5N8V]D:6YG<R==6R=55$8M."==(#T@7R@B56YI8V]D
M92`H551&+3@I(BD["B1N;'-;)V5N8V]D:6YG<R==6R=625-#24DG72`](%\H
M(E9I971N86UE<V4@*%9)4T-)22DB*3L*)&YL<ULG96YC;V1I;F=S)UU;)TE3
M3RTX.#4Y+3$G72`](%\H(E=E<W1E<FX@*$E33RTX.#4Y+3$I(BD["B1N;'-;
M)V5N8V]D:6YG<R==6R=)4T\M.#@U.2TQ-2==(#T@7R@B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(BD["F%S;W)T*"1N;'-;)V5N8V]D:6YG<R==*3L*"@HO*BH*
M("HJ($UU;'1I+6QA;F=U86=E('-P96QL:6YG('-U<'!O<G0*("HJ+PH*)&YL
M<ULG<W!E;&QI;F<G75LG8W-?0UHG72`]("<M5"!L871I;C(@+60@8WIE8V@G
M.PHD;FQS6R=S<&5L;&EN9R==6R=D85]$2R==(#T@)RUD(&1A;G-K)SL*)&YL
M<ULG<W!E;&QI;F<G75LG9&5?1$4G72`]("<M5"!L871I;C$@+60@9&5U='-C
M:"<["B1N;'-;)W-P96QL:6YG)UU;)V5L7T=2)UT@/2`G+50@;&%T:6XQ("UD
M(&5L;&EN:6MA)SL*)&YL<ULG<W!E;&QI;F<G75LG96Y?0T$G72`]("<M9"!C
M86YA9&EA;B<["B1N;'-;)W-P96QL:6YG)UU;)V5N7T=")UT@/2`G+60@8G)I
M=&ES:"<["B1N;'-;)W-P96QL:6YG)UU;)V5N7U53)UT@/2`G+60@86UE<FEC
M86XG.PHD;FQS6R=S<&5L;&EN9R==6R=E<U]%4R==(#T@)RUD(&5S<&%N;VPG
M.PHD;FQS6R=S<&5L;&EN9R==6R=F<E]&4B==(#T@)RUD(&9R86YC86ES)SL*
M)&YL<ULG<W!E;&QI;F<G75LG:71?250G72`]("<M5"!L871I;C$@+60@:71A
M;&EA;B<["B1N;'-;)W-P96QL:6YG)UU;)VYL7TY,)UT@/2`G+60@;F5D97)L
M86YD<R<["B1N;'-;)W-P96QL:6YG)UU;)W!L7U!,)UT@/2`G+60@<&]L:7-H
M)SL*)&YL<ULG<W!E;&QI;F<G75LG<'1?0E(G72`]("<M9"!B<B<["B1N;'-;
M)W-P96QL:6YG)UU;)W!T7U!4)UT@/2`G+50@;&%T:6XQ("UD('!O<G1U9W5E
M<V4G.PHD;FQS6R=S<&5L;&EN9R==6R=R=5]252==(#T@)RUD(')U<W-I86XG
M.PHD;FQS6R=S<&5L;&EN9R==6R=S;%]322==(#T@)RUD('-L;W9E;G-K;R<[
M"B1N;'-;)W-P96QL:6YG)UU;)W-V7U-%)UT@/2`G+60@<W9E;G-K82<["@HD
M1TQ/0D%,4ULG;FQS)UT@/2`F)&YL<SL*"@HO*BH*("HJ(%1I;65Z;VYE<PH@
M*BHO"@HD='I;)T%F<FEC82]!8FED:F%N)UT@/2`G069R:6-A+T%B:61J86XG
M.PHD='I;)T%F<FEC82]!8V-R82==(#T@)T%F<FEC82]!8V-R82<["B1T>ELG
M069R:6-A+T%D9&ES7T%B86)A)UT@/2`G069R:6-A+T%D9&ES($%B86)A)SL*
M)'1Z6R=!9G)I8V$O06QG:65R<R==(#T@)T%F<FEC82]!;&=I97)S)SL*)'1Z
M6R=!9G)I8V$O07-M97)A)UT@/2`G069R:6-A+T%S;65R82<["B1T>ELG069R
M:6-A+T)A;6%K;R==(#T@)T%F<FEC82]"86UA:V\G.PHD='I;)T%F<FEC82]"
M86YG=6DG72`]("=!9G)I8V$O0F%N9W5I)SL*)'1Z6R=!9G)I8V$O0F%N:G5L
M)UT@/2`G069R:6-A+T)A;FIU;"<["B1T>ELG069R:6-A+T)I<W-A=2==(#T@
M)T%F<FEC82]":7-S874G.PHD='I;)T%F<FEC82]";&%N='ER92==(#T@)T%F
M<FEC82]";&%N='ER92<["B1T>ELG069R:6-A+T)R87IZ879I;&QE)UT@/2`G
M069R:6-A+T)R87IZ879I;&QE)SL*)'1Z6R=!9G)I8V$O0G5J=6UB=7)A)UT@
M/2`G069R:6-A+T)U:G5M8G5R82<["B1T>ELG069R:6-A+T-A:7)O)UT@/2`G
M069R:6-A+T-A:7)O)SL*)'1Z6R=!9G)I8V$O0V%S86)L86YC82==(#T@)T%F
M<FEC82]#87-A8FQA;F-A)SL*)'1Z6R=!9G)I8V$O0V5U=&$G72`]("=!9G)I
M8V$O0V5U=&$G.PHD='I;)T%F<FEC82]#;VYA:W)Y)UT@/2`G069R:6-A+T-O
M;F%K<GDG.PHD='I;)T%F<FEC82]$86MA<B==(#T@)T%F<FEC82]$86MA<B<[
M"B1T>ELG069R:6-A+T1A<E]E<U]386QA86TG72`]("=!9G)I8V$O1&%R(&5S
M(%-A;&%A;2<["B1T>ELG069R:6-A+T1J:6)O=71I)UT@/2`G069R:6-A+T1J
M:6)O=71I)SL*)'1Z6R=!9G)I8V$O1&]U86QA)UT@/2`G069R:6-A+T1O=6%L
M82<["B1T>ELG069R:6-A+T5L7T%A:75N)UT@/2`G069R:6-A+T5L($%A:75N
M)SL*)'1Z6R=!9G)I8V$O1G)E971O=VXG72`]("=!9G)I8V$O1G)E971O=VXG
M.PHD='I;)T%F<FEC82]'86)O<F]N92==(#T@)T%F<FEC82]'86)O<F]N92<[
M"B1T>ELG069R:6-A+TAA<F%R92==(#T@)T%F<FEC82](87)A<F4G.PHD='I;
M)T%F<FEC82]*;VAA;FYE<V)U<F<G72`]("=!9G)I8V$O2F]H86YN97-B=7)G
M)SL*)'1Z6R=!9G)I8V$O2V%M<&%L82==(#T@)T%F<FEC82]+86UP86QA)SL*
M)'1Z6R=!9G)I8V$O2VAA<G1O=6TG72`]("=!9G)I8V$O2VAA<G1O=6TG.PHD
M='I;)T%F<FEC82]+:6=A;&DG72`]("=!9G)I8V$O2VEG86QI)SL*)'1Z6R=!
M9G)I8V$O2VEN<VAA<V$G72`]("=!9G)I8V$O2VEN<VAA<V$G.PHD='I;)T%F
M<FEC82],86=O<R==(#T@)T%F<FEC82],86=O<R<["B1T>ELG069R:6-A+TQI
M8G)E=FEL;&4G72`]("=!9G)I8V$O3&EB<F5V:6QL92<["B1T>ELG069R:6-A
M+TQO;64G72`]("=!9G)I8V$O3&]M92<["B1T>ELG069R:6-A+TQU86YD82==
M(#T@)T%F<FEC82],=6%N9&$G.PHD='I;)T%F<FEC82],=6)U;6)A<VAI)UT@
M/2`G069R:6-A+TQU8G5M8F%S:&DG.PHD='I;)T%F<FEC82],=7-A:V$G72`]
M("=!9G)I8V$O3'5S86MA)SL*)'1Z6R=!9G)I8V$O36%L86)O)UT@/2`G069R
M:6-A+TUA;&%B;R<["B1T>ELG069R:6-A+TUA<'5T;R==(#T@)T%F<FEC82]-
M87!U=&\G.PHD='I;)T%F<FEC82]-87-E<G4G72`]("=!9G)I8V$O36%S97)U
M)SL*)'1Z6R=!9G)I8V$O36)A8F%N92==(#T@)T%F<FEC82]-8F%B86YE)SL*
M)'1Z6R=!9G)I8V$O36]G861I<VAU)UT@/2`G069R:6-A+TUO9V%D:7-H=2<[
M"B1T>ELG069R:6-A+TUO;G)O=FEA)UT@/2`G069R:6-A+TUO;G)O=FEA)SL*
M)'1Z6R=!9G)I8V$O3F%I<F]B:2==(#T@)T%F<FEC82].86ER;V)I)SL*)'1Z
M6R=!9G)I8V$O3F1J86UE;F$G72`]("=!9G)I8V$O3F1J86UE;F$G.PHD='I;
M)T%F<FEC82].:6%M97DG72`]("=!9G)I8V$O3FEA;65Y)SL*)'1Z6R=!9G)I
M8V$O3F]U86MC:&]T="==(#T@)T%F<FEC82].;W5A:V-H;W1T)SL*)'1Z6R=!
M9G)I8V$O3W5A9V%D;W5G;W4G72`]("=!9G)I8V$O3W5A9V%D;W5G;W4G.PHD
M='I;)T%F<FEC82]0;W)T;RU.;W9O)UT@/2`G069R:6-A+U!O<G1O+4YO=F\G
M.PHD='I;)T%F<FEC82]386]?5&]M92==(#T@)T%F<FEC82]386\@5&]M92<[
M"B1T>ELG069R:6-A+U1I;6)U:W1U)UT@/2`G069R:6-A+U1I;6)U:W1U)SL*
M)'1Z6R=!9G)I8V$O5')I<&]L:2==(#T@)T%F<FEC82]4<FEP;VQI)SL*)'1Z
M6R=!9G)I8V$O5'5N:7,G72`]("=!9G)I8V$O5'5N:7,G.PHD='I;)T%F<FEC
M82]7:6YD:&]E:R==(#T@)T%F<FEC82]7:6YD:&]E:R<["B1T>ELG06UE<FEC
M82]!9&%K)UT@/2`G06UE<FEC82]!9&%K)SL*)'1Z6R=!;65R:6-A+T%N8VAO
M<F%G92==(#T@)T%M97)I8V$O06YC:&]R86=E)SL*)'1Z6R=!;65R:6-A+T%N
M9W5I;&QA)UT@/2`G06UE<FEC82]!;F=U:6QL82<["B1T>ELG06UE<FEC82]!
M;G1I9W5A)UT@/2`G06UE<FEC82]!;G1I9W5A)SL*)'1Z6R=!;65R:6-A+T%R
M86=U86EN82==(#T@)T%M97)I8V$O07)A9W5A:6YA)SL*)'1Z6R=!;65R:6-A
M+T%R=6)A)UT@/2`G06UE<FEC82]!<G5B82<["B1T>ELG06UE<FEC82]!<W5N
M8VEO;B==(#T@)T%M97)I8V$O07-U;F-I;VXG.PHD='I;)T%M97)I8V$O0F%R
M8F%D;W,G72`]("=!;65R:6-A+T)A<F)A9&]S)SL*)'1Z6R=!;65R:6-A+T)E
M;&5M)UT@/2`G06UE<FEC82]"96QE;2<["B1T>ELG06UE<FEC82]"96QI>F4G
M72`]("=!;65R:6-A+T)E;&EZ92<["B1T>ELG06UE<FEC82]";V%?5FES=&$G
M72`]("=!;65R:6-A+T)O82!6:7-T82<["B1T>ELG06UE<FEC82]";V=O=&$G
M72`]("=!;65R:6-A+T)O9V]T82<["B1T>ELG06UE<FEC82]";VES92==(#T@
M)T%M97)I8V$O0F]I<V4G.PHD='I;)T%M97)I8V$O0G5E;F]S7T%I<F5S)UT@
M/2`G06UE<FEC82]"=65N;W,@06ER97,G.PHD='I;)T%M97)I8V$O0V%M8G)I
M9&=E7T)A>2==(#T@)T%M97)I8V$O0V%M8G)I9&=E($)A>2<["B1T>ELG06UE
M<FEC82]#86YC=6XG72`]("=!;65R:6-A+T-A;F-U;B<["B1T>ELG06UE<FEC
M82]#87)A8V%S)UT@/2`G06UE<FEC82]#87)A8V%S)SL*)'1Z6R=!;65R:6-A
M+T-A=&%M87)C82==(#T@)T%M97)I8V$O0V%T86UA<F-A)SL*)'1Z6R=!;65R
M:6-A+T-A>65N;F4G72`]("=!;65R:6-A+T-A>65N;F4G.PHD='I;)T%M97)I
M8V$O0V%Y;6%N)UT@/2`G06UE<FEC82]#87EM86XG.PHD='I;)T%M97)I8V$O
M0VAI8V%G;R==(#T@)T%M97)I8V$O0VAI8V%G;R<["B1T>ELG06UE<FEC82]#
M:&EH=6%H=6$G72`]("=!;65R:6-A+T-H:6AU86AU82<["B1T>ELG06UE<FEC
M82]#;W)D;V)A)UT@/2`G06UE<FEC82]#;W)D;V)A)SL*)'1Z6R=!;65R:6-A
M+T-O<W1A7U)I8V$G72`]("=!;65R:6-A+T-O<W1A(%)I8V$G.PHD='I;)T%M
M97)I8V$O0W5I86)A)UT@/2`G06UE<FEC82]#=6EA8F$G.PHD='I;)T%M97)I
M8V$O0W5R86-A;R==(#T@)T%M97)I8V$O0W5R86-A;R<["B1T>ELG06UE<FEC
M82]$87=S;VXG72`]("=!;65R:6-A+T1A=W-O;B<["B1T>ELG06UE<FEC82]$
M87=S;VY?0W)E96LG72`]("=!;65R:6-A+T1A=W-O;B!#<F5E:R<["B1T>ELG
M06UE<FEC82]$96YV97(G72`]("=!;65R:6-A+T1E;G9E<B<["B1T>ELG06UE
M<FEC82]$971R;VET)UT@/2`G06UE<FEC82]$971R;VET)SL*)'1Z6R=!;65R
M:6-A+T1O;6EN:6-A)UT@/2`G06UE<FEC82]$;VUI;FEC82<["B1T>ELG06UE
M<FEC82]%9&UO;G1O;B==(#T@)T%M97)I8V$O161M;VYT;VXG.PHD='I;)T%M
M97)I8V$O16ER=6YE<&4G72`]("=!;65R:6-A+T5I<G5N97!E)SL*)'1Z6R=!
M;65R:6-A+T5L7U-A;'9A9&]R)UT@/2`G06UE<FEC82]%;"!386QV861O<B<[
M"B1T>ELG06UE<FEC82]&;W)T86QE>F$G72`]("=!;65R:6-A+T9O<G1A;&5Z
M82<["B1T>ELG06UE<FEC82]';&%C95]"87DG72`]("=!;65R:6-A+T=L86-E
M($)A>2<["B1T>ELG06UE<FEC82]';V1T:&%B)UT@/2`G06UE<FEC82]';V1T
M:&%B)SL*)'1Z6R=!;65R:6-A+T=O;W-E7T)A>2==(#T@)T%M97)I8V$O1V]O
M<V4@0F%Y)SL*)'1Z6R=!;65R:6-A+T=R86YD7U1U<FLG72`]("=!;65R:6-A
M+T=R86YD(%1U<FLG.PHD='I;)T%M97)I8V$O1W)E;F%D82==(#T@)T%M97)I
M8V$O1W)E;F%D82<["B1T>ELG06UE<FEC82]'=6%D96QO=7!E)UT@/2`G06UE
M<FEC82]'=6%D96QO=7!E)SL*)'1Z6R=!;65R:6-A+T=U871E;6%L82==(#T@
M)T%M97)I8V$O1W5A=&5M86QA)SL*)'1Z6R=!;65R:6-A+T=U87EA<75I;"==
M(#T@)T%M97)I8V$O1W5A>6%Q=6EL)SL*)'1Z6R=!;65R:6-A+T=U>6%N82==
M(#T@)T%M97)I8V$O1W5Y86YA)SL*)'1Z6R=!;65R:6-A+TAA;&EF87@G72`]
M("=!;65R:6-A+TAA;&EF87@G.PHD='I;)T%M97)I8V$O2&%V86YA)UT@/2`G
M06UE<FEC82](879A;F$G.PHD='I;)T%M97)I8V$O2&5R;6]S:6QL;R==(#T@
M)T%M97)I8V$O2&5R;6]S:6QL;R<["B1T>ELG06UE<FEC82]);F1I86YA+TMN
M;W@G72`]("=!;65R:6-A+TEN9&EA;F$O2VYO>"<["B1T>ELG06UE<FEC82])
M;F1I86YA+TUA<F5N9V\G72`]("=!;65R:6-A+TEN9&EA;F$O36%R96YG;R<[
M"B1T>ELG06UE<FEC82]);F1I86YA+U9E=F%Y)UT@/2`G06UE<FEC82]);F1I
M86YA+U9E=F%Y)SL*)'1Z6R=!;65R:6-A+TEN9&EA;F%P;VQI<R==(#T@)T%M
M97)I8V$O26YD:6%N87!O;&ES)SL*)'1Z6R=!;65R:6-A+TEN=79I:R==(#T@
M)T%M97)I8V$O26YU=FEK)SL*)'1Z6R=!;65R:6-A+TEQ86QU:70G72`]("=!
M;65R:6-A+TEQ86QU:70G.PHD='I;)T%M97)I8V$O2F%M86EC82==(#T@)T%M
M97)I8V$O2F%M86EC82<["B1T>ELG06UE<FEC82]*=6IU>2==(#T@)T%M97)I
M8V$O2G5J=7DG.PHD='I;)T%M97)I8V$O2G5N96%U)UT@/2`G06UE<FEC82]*
M=6YE874G.PHD='I;)T%M97)I8V$O2V5N='5C:WDO36]N=&EC96QL;R==(#T@
M)T%M97)I8V$O2V5N='5C:WDO36]N=&EC96QL;R<["B1T>ELG06UE<FEC82],
M85]087HG72`]("=!;65R:6-A+TQA(%!A>B<["B1T>ELG06UE<FEC82],:6UA
M)UT@/2`G06UE<FEC82],:6UA)SL*)'1Z6R=!;65R:6-A+TQO<U]!;F=E;&5S
M)UT@/2`G06UE<FEC82],;W,@06YG96QE<R<["B1T>ELG06UE<FEC82],;W5I
M<W9I;&QE)UT@/2`G06UE<FEC82],;W5I<W9I;&QE)SL*)'1Z6R=!;65R:6-A
M+TUA8V5I;R==(#T@)T%M97)I8V$O36%C96EO)SL*)'1Z6R=!;65R:6-A+TUA
M;F%G=6$G72`]("=!;65R:6-A+TUA;F%G=6$G.PHD='I;)T%M97)I8V$O36%N
M875S)UT@/2`G06UE<FEC82]-86YA=7,G.PHD='I;)T%M97)I8V$O36%R=&EN
M:7%U92==(#T@)T%M97)I8V$O36%R=&EN:7%U92<["B1T>ELG06UE<FEC82]-
M87IA=&QA;B==(#T@)T%M97)I8V$O36%Z871L86XG.PHD='I;)T%M97)I8V$O
M365N9&]Z)UT@/2`G06UE<FEC82]-96YD;WHG.PHD='I;)T%M97)I8V$O365N
M;VUI;F5E)UT@/2`G06UE<FEC82]-96YO;6EN964G.PHD='I;)T%M97)I8V$O
M365R:61A)UT@/2`G06UE<FEC82]-97)I9&$G.PHD='I;)T%M97)I8V$O365X
M:6-O7T-I='DG72`]("=!;65R:6-A+TUE>&EC;R!#:71Y)SL*)'1Z6R=!;65R
M:6-A+TUI<75E;&]N)UT@/2`G06UE<FEC82]-:7%U96QO;B<["B1T>ELG06UE
M<FEC82]-;VYT97)R97DG72`]("=!;65R:6-A+TUO;G1E<G)E>2<["B1T>ELG
M06UE<FEC82]-;VYT979I9&5O)UT@/2`G06UE<FEC82]-;VYT979I9&5O)SL*
M)'1Z6R=!;65R:6-A+TUO;G1R96%L)UT@/2`G06UE<FEC82]-;VYT<F5A;"<[
M"B1T>ELG06UE<FEC82]-;VYT<V5R<F%T)UT@/2`G06UE<FEC82]-;VYT<V5R
M<F%T)SL*)'1Z6R=!;65R:6-A+TYA<W-A=2==(#T@)T%M97)I8V$O3F%S<V%U
M)SL*)'1Z6R=!;65R:6-A+TYE=U]9;W)K)UT@/2`G06UE<FEC82].97<@66]R
M:R<["B1T>ELG06UE<FEC82].:7!I9V]N)UT@/2`G06UE<FEC82].:7!I9V]N
M)SL*)'1Z6R=!;65R:6-A+TYO;64G72`]("=!;65R:6-A+TYO;64G.PHD='I;
M)T%M97)I8V$O3F]R;VYH82==(#T@)T%M97)I8V$O3F]R;VYH82<["B1T>ELG
M06UE<FEC82]086YA;6$G72`]("=!;65R:6-A+U!A;F%M82<["B1T>ELG06UE
M<FEC82]086YG;FER='5N9R==(#T@)T%M97)I8V$O4&%N9VYI<G1U;F<G.PHD
M='I;)T%M97)I8V$O4&%R86UA<FEB;R==(#T@)T%M97)I8V$O4&%R86UA<FEB
M;R<["B1T>ELG06UE<FEC82]0:&]E;FEX)UT@/2`G06UE<FEC82]0:&]E;FEX
M)SL*)'1Z6R=!;65R:6-A+U!O<G0M874M4')I;F-E)UT@/2`G06UE<FEC82]0
M;W)T+6%U+5!R:6YC92<["B1T>ELG06UE<FEC82]0;W)T;U]696QH;R==(#T@
M)T%M97)I8V$O4&]R=&\@5F5L:&\G.PHD='I;)T%M97)I8V$O4&]R=%]O9E]3
M<&%I;B==(#T@)T%M97)I8V$O4&]R="!O9B!3<&%I;B<["B1T>ELG06UE<FEC
M82]0=65R=&]?4FEC;R==(#T@)T%M97)I8V$O4'5E<G1O(%)I8V\G.PHD='I;
M)T%M97)I8V$O4F%I;GE?4FEV97(G72`]("=!;65R:6-A+U)A:6YY(%)I=F5R
M)SL*)'1Z6R=!;65R:6-A+U)A;FMI;E]);FQE="==(#T@)T%M97)I8V$O4F%N
M:VEN($EN;&5T)SL*)'1Z6R=!;65R:6-A+U)E8VEF92==(#T@)T%M97)I8V$O
M4F5C:69E)SL*)'1Z6R=!;65R:6-A+U)E9VEN82==(#T@)T%M97)I8V$O4F5G
M:6YA)SL*)'1Z6R=!;65R:6-A+U)I;U]"<F%N8V\G72`]("=!;65R:6-A+U)I
M;R!"<F%N8V\G.PHD='I;)T%M97)I8V$O4F]S87)I;R==(#T@)T%M97)I8V$O
M4F]S87)I;R<["B1T>ELG06UE<FEC82]386YT:6%G;R==(#T@)T%M97)I8V$O
M4V%N=&EA9V\G.PHD='I;)T%M97)I8V$O4V%N=&]?1&]M:6YG;R==(#T@)T%M
M97)I8V$O4V%N=&\@1&]M:6YG;R<["B1T>ELG06UE<FEC82]386]?4&%U;&\G
M72`]("=!;65R:6-A+U-A;R!0875L;R<["B1T>ELG06UE<FEC82]38V]R97-B
M>7-U;F0G72`]("=!;65R:6-A+U-C;W)E<V)Y<W5N9"<["B1T>ELG06UE<FEC
M82]3:&EP<F]C:R==(#T@)T%M97)I8V$O4VAI<')O8VLG.PHD='I;)T%M97)I
M8V$O4W1?2F]H;G,G72`]("=!;65R:6-A+U-T($IO:&YS)SL*)'1Z6R=!;65R
M:6-A+U-T7TMI='1S)UT@/2`G06UE<FEC82]3="!+:71T<R<["B1T>ELG06UE
M<FEC82]3=%],=6-I82==(#T@)T%M97)I8V$O4W0@3'5C:6$G.PHD='I;)T%M
M97)I8V$O4W1?5&AO;6%S)UT@/2`G06UE<FEC82]3="!4:&]M87,G.PHD='I;
M)T%M97)I8V$O4W1?5FEN8V5N="==(#T@)T%M97)I8V$O4W0@5FEN8V5N="<[
M"B1T>ELG06UE<FEC82]3=VEF=%]#=7)R96YT)UT@/2`G06UE<FEC82]3=VEF
M="!#=7)R96YT)SL*)'1Z6R=!;65R:6-A+U1E9W5C:6=A;'!A)UT@/2`G06UE
M<FEC82]496=U8VEG86QP82<["B1T>ELG06UE<FEC82]4:'5L92==(#T@)T%M
M97)I8V$O5&AU;&4G.PHD='I;)T%M97)I8V$O5&AU;F1E<E]"87DG72`]("=!
M;65R:6-A+U1H=6YD97(@0F%Y)SL*)'1Z6R=!;65R:6-A+U1I:G5A;F$G72`]
M("=!;65R:6-A+U1I:G5A;F$G.PHD='I;)T%M97)I8V$O5&]R=&]L82==(#T@
M)T%M97)I8V$O5&]R=&]L82<["B1T>ELG06UE<FEC82]686YC;W5V97(G72`]
M("=!;65R:6-A+U9A;F-O=79E<B<["B1T>ELG06UE<FEC82]7:&ET96AO<G-E
M)UT@/2`G06UE<FEC82]7:&ET96AO<G-E)SL*)'1Z6R=!;65R:6-A+U=I;FYI
M<&5G)UT@/2`G06UE<FEC82]7:6YN:7!E9R<["B1T>ELG06UE<FEC82]986MU
M=&%T)UT@/2`G06UE<FEC82]986MU=&%T)SL*)'1Z6R=!;65R:6-A+UEE;&QO
M=VMN:69E)UT@/2`G06UE<FEC82]996QL;W=K;FEF92<["B1T>ELG06YT87)C
M=&EC82]#87-E>2==(#T@)T%N=&%R8W1I8V$O0V%S97DG.PHD='I;)T%N=&%R
M8W1I8V$O1&%V:7,G72`]("=!;G1A<F-T:6-A+T1A=FES)SL*)'1Z6R=!;G1A
M<F-T:6-A+T1U;6]N=$15<G9I;&QE)UT@/2`G06YT87)C=&EC82]$=6UO;G1$
M57)V:6QL92<["B1T>ELG06YT87)C=&EC82]-87=S;VXG72`]("=!;G1A<F-T
M:6-A+TUA=W-O;B<["B1T>ELG06YT87)C=&EC82]-8TUU<F1O)UT@/2`G06YT
M87)C=&EC82]-8TUU<F1O)SL*)'1Z6R=!;G1A<F-T:6-A+U!A;&UE<B==(#T@
M)T%N=&%R8W1I8V$O4&%L;65R)SL*)'1Z6R=!;G1A<F-T:6-A+U-O=71H7U!O
M;&4G72`]("=!;G1A<F-T:6-A+U-O=71H(%!O;&4G.PHD='I;)T%N=&%R8W1I
M8V$O4WEO=V$G72`]("=!;G1A<F-T:6-A+U-Y;W=A)SL*)'1Z6R=!;G1A<F-T
M:6-A+U9O<W1O:R==(#T@)T%N=&%R8W1I8V$O5F]S=&]K)SL*)'1Z6R=!<F-T
M:6,O3&]N9WEE87)B>65N)UT@/2`G07)C=&EC+TQO;F=Y96%R8GEE;B<["B1T
M>ELG07-I82]!9&5N)UT@/2`G07-I82]!9&5N)SL*)'1Z6R=!<VEA+T%L;6%T
M>2==(#T@)T%S:6$O06QM871Y)SL*)'1Z6R=!<VEA+T%M;6%N)UT@/2`G07-I
M82]!;6UA;B<["B1T>ELG07-I82]!;F%D>7(G72`]("=!<VEA+T%N861Y<B<[
M"B1T>ELG07-I82]!<71A=2==(#T@)T%S:6$O07%T874G.PHD='I;)T%S:6$O
M07%T;V)E)UT@/2`G07-I82]!<71O8F4G.PHD='I;)T%S:6$O07-H9V%B870G
M72`]("=!<VEA+T%S:&=A8F%T)SL*)'1Z6R=!<VEA+T)A9VAD860G72`]("=!
M<VEA+T)A9VAD860G.PHD='I;)T%S:6$O0F%H<F%I;B==(#T@)T%S:6$O0F%H
M<F%I;B<["B1T>ELG07-I82]"86MU)UT@/2`G07-I82]"86MU)SL*)'1Z6R=!
M<VEA+T)A;F=K;VLG72`]("=!<VEA+T)A;F=K;VLG.PHD='I;)T%S:6$O0F5I
M<G5T)UT@/2`G07-I82]"96ER=70G.PHD='I;)T%S:6$O0FES:&ME:R==(#T@
M)T%S:6$O0FES:&ME:R<["B1T>ELG07-I82]"<G5N96DG72`]("=!<VEA+T)R
M=6YE:2<["B1T>ELG07-I82]#86QC=71T82==(#T@)T%S:6$O0V%L8W5T=&$G
M.PHD='I;)T%S:6$O0VAU;F=K:6YG)UT@/2`G07-I82]#:'5N9VMI;F<G.PHD
M='I;)T%S:6$O0V]L;VUB;R==(#T@)T%S:6$O0V]L;VUB;R<["B1T>ELG07-I
M82]$86UA<V-U<R==(#T@)T%S:6$O1&%M87-C=7,G.PHD='I;)T%S:6$O1&AA
M:V$G72`]("=!<VEA+T1H86MA)SL*)'1Z6R=!<VEA+T1I;&DG72`]("=!<VEA
M+T1I;&DG.PHD='I;)T%S:6$O1'5B86DG72`]("=!<VEA+T1U8F%I)SL*)'1Z
M6R=!<VEA+T1U<VAA;F)E)UT@/2`G07-I82]$=7-H86YB92<["B1T>ELG07-I
M82]'87IA)UT@/2`G07-I82]'87IA)SL*)'1Z6R=!<VEA+TAA<F)I;B==(#T@
M)T%S:6$O2&%R8FEN)SL*)'1Z6R=!<VEA+TAO;F=?2V]N9R==(#T@)T%S:6$O
M2&]N9R!+;VYG)SL*)'1Z6R=!<VEA+TAO=F0G72`]("=!<VEA+TAO=F0G.PHD
M='I;)T%S:6$O27)K=71S:R==(#T@)T%S:6$O27)K=71S:R<["B1T>ELG07-I
M82]*86MA<G1A)UT@/2`G07-I82]*86MA<G1A)SL*)'1Z6R=!<VEA+TIA>6%P
M=7)A)UT@/2`G07-I82]*87EA<'5R82<["B1T>ELG07-I82]*97)U<V%L96TG
M72`]("=!<VEA+TIE<G5S86QE;2<["B1T>ELG07-I82]+86)U;"==(#T@)T%S
M:6$O2V%B=6PG.PHD='I;)T%S:6$O2V%M8VAA=&MA)UT@/2`G07-I82]+86UC
M:&%T:V$G.PHD='I;)T%S:6$O2V%R86-H:2==(#T@)T%S:6$O2V%R86-H:2<[
M"B1T>ELG07-I82]+87-H9V%R)UT@/2`G07-I82]+87-H9V%R)SL*)'1Z6R=!
M<VEA+TMA=&UA;F1U)UT@/2`G07-I82]+871M86YD=2<["B1T>ELG07-I82]+
M<F%S;F]Y87)S:R==(#T@)T%S:6$O2W)A<VYO>6%R<VLG.PHD='I;)T%S:6$O
M2W5A;&%?3'5M<'5R)UT@/2`G07-I82]+=6%L82!,=6UP=7(G.PHD='I;)T%S
M:6$O2W5C:&EN9R==(#T@)T%S:6$O2W5C:&EN9R<["B1T>ELG07-I82]+=7=A
M:70G72`]("=!<VEA+TMU=V%I="<["B1T>ELG07-I82]-86-A;R==(#T@)T%S
M:6$O36%C86\G.PHD='I;)T%S:6$O36%G861A;B==(#T@)T%S:6$O36%G861A
M;B<["B1T>ELG07-I82]-86YI;&$G72`]("=!<VEA+TUA;FEL82<["B1T>ELG
M07-I82]-=7-C870G72`]("=!<VEA+TUU<V-A="<["B1T>ELG07-I82].:6-O
M<VEA)UT@/2`G07-I82].:6-O<VEA)SL*)'1Z6R=!<VEA+TYO=F]S:6)I<G-K
M)UT@/2`G07-I82].;W9O<VEB:7)S:R<["B1T>ELG07-I82]/;7-K)UT@/2`G
M07-I82]/;7-K)SL*)'1Z6R=!<VEA+U!H;F]M7U!E;F@G72`]("=!<VEA+U!H
M;F]M(%!E;F@G.PHD='I;)T%S:6$O4'EO;F=Y86YG)UT@/2`G07-I82]0>6]N
M9WEA;F<G.PHD='I;)T%S:6$O46%T87(G72`]("=!<VEA+U%A=&%R)SL*)'1Z
M6R=!<VEA+U)A;F=O;VXG72`]("=!<VEA+U)A;F=O;VXG.PHD='I;)T%S:6$O
M4FEY861H)UT@/2`G07-I82]2:7EA9&@G.PHD='I;)T%S:6$O4V%I9V]N)UT@
M/2`G07-I82]386EG;VXG.PHD='I;)T%S:6$O4V%M87)K86YD)UT@/2`G07-I
M82]386UA<FMA;F0G.PHD='I;)T%S:6$O4V5O=6PG72`]("=!<VEA+U-E;W5L
M)SL*)'1Z6R=!<VEA+U-H86YG:&%I)UT@/2`G07-I82]3:&%N9VAA:2<["B1T
M>ELG07-I82]3:6YG87!O<F4G72`]("=!<VEA+U-I;F=A<&]R92<["B1T>ELG
M07-I82]486EP96DG72`]("=!<VEA+U1A:7!E:2<["B1T>ELG07-I82]487-H
M:V5N="==(#T@)T%S:6$O5&%S:&ME;G0G.PHD='I;)T%S:6$O5&)I;&ES:2==
M(#T@)T%S:6$O5&)I;&ES:2<["B1T>ELG07-I82]496AR86XG72`]("=!<VEA
M+U1E:')A;B<["B1T>ELG07-I82]4:&EM<&AU)UT@/2`G07-I82]4:&EM<&AU
M)SL*)'1Z6R=!<VEA+U1O:WEO)UT@/2`G07-I82]4;VMY;R<["B1T>ELG07-I
M82]5:G5N9U]086YD86YG)UT@/2`G07-I82]5:G5N9R!086YD86YG)SL*)'1Z
M6R=!<VEA+U5L86%N8F%A=&%R)UT@/2`G07-I82]5;&%A;F)A871A<B<["B1T
M>ELG07-I82]5<G5M<6DG72`]("=!<VEA+U5R=6UQ:2<["B1T>ELG07-I82]6
M:65N=&EA;F4G72`]("=!<VEA+U9I96YT:6%N92<["B1T>ELG07-I82]6;&%D
M:79O<W1O:R==(#T@)T%S:6$O5FQA9&EV;W-T;VLG.PHD='I;)T%S:6$O66%K
M=71S:R==(#T@)T%S:6$O66%K=71S:R<["B1T>ELG07-I82]996MA=&5R:6YB
M=7)G)UT@/2`G07-I82]996MA=&5R:6YB=7)G)SL*)'1Z6R=!<VEA+UEE<F5V
M86XG72`]("=!<VEA+UEE<F5V86XG.PHD='I;)T%T;&%N=&EC+T%Z;W)E<R==
M(#T@)T%T;&%N=&EC+T%Z;W)E<R<["B1T>ELG071L86YT:6,O0F5R;75D82==
M(#T@)T%T;&%N=&EC+T)E<FUU9&$G.PHD='I;)T%T;&%N=&EC+T-A;F%R>2==
M(#T@)T%T;&%N=&EC+T-A;F%R>2<["B1T>ELG071L86YT:6,O0V%P95]697)D
M92==(#T@)T%T;&%N=&EC+T-A<&4@5F5R9&4G.PHD='I;)T%T;&%N=&EC+T9A
M97)O92==(#T@)T%T;&%N=&EC+T9A97)O92<["B1T>ELG071L86YT:6,O2F%N
M7TUA>65N)UT@/2`G071L86YT:6,O2F%N($UA>65N)SL*)'1Z6R=!=&QA;G1I
M8R]-861E:7)A)UT@/2`G071L86YT:6,O36%D96ER82<["B1T>ELG071L86YT
M:6,O4F5Y:VIA=FEK)UT@/2`G071L86YT:6,O4F5Y:VIA=FEK)SL*)'1Z6R=!
M=&QA;G1I8R]3;W5T:%]'96]R9VEA)UT@/2`G071L86YT:6,O4V]U=&@@1V5O
M<F=I82<["B1T>ELG071L86YT:6,O4W1A;FQE>2==(#T@)T%T;&%N=&EC+U-T
M86YL97DG.PHD='I;)T%T;&%N=&EC+U-T7TAE;&5N82==(#T@)T%T;&%N=&EC
M+U-T($AE;&5N82<["B1T>ELG075S=')A;&EA+T%D96QA:61E)UT@/2`G075S
M=')A;&EA+T%D96QA:61E)SL*)'1Z6R=!=7-T<F%L:6$O0G)I<V)A;F4G72`]
M("=!=7-T<F%L:6$O0G)I<V)A;F4G.PHD='I;)T%U<W1R86QI82]"<F]K96Y?
M2&EL;"==(#T@)T%U<W1R86QI82]"<F]K96X@2&EL;"<["B1T>ELG075S=')A
M;&EA+T1A<G=I;B==(#T@)T%U<W1R86QI82]$87)W:6XG.PHD='I;)T%U<W1R
M86QI82](;V)A<G0G72`]("=!=7-T<F%L:6$O2&]B87)T)SL*)'1Z6R=!=7-T
M<F%L:6$O3&EN9&5M86XG72`]("=!=7-T<F%L:6$O3&EN9&5M86XG.PHD='I;
M)T%U<W1R86QI82],;W)D7TAO=V4G72`]("=!=7-T<F%L:6$O3&]R9"!(;W=E
M)SL*)'1Z6R=!=7-T<F%L:6$O365L8F]U<FYE)UT@/2`G075S=')A;&EA+TUE
M;&)O=7)N92<["B1T>ELG075S=')A;&EA+U!E<G1H)UT@/2`G075S=')A;&EA
M+U!E<G1H)SL*)'1Z6R=!=7-T<F%L:6$O4WED;F5Y)UT@/2`G075S=')A;&EA
M+U-Y9&YE>2<["B1T>ELG175R;W!E+T%M<W1E<F1A;2==(#T@)T5U<F]P92]!
M;7-T97)D86TG.PHD='I;)T5U<F]P92]!;F1O<G)A)UT@/2`G175R;W!E+T%N
M9&]R<F$G.PHD='I;)T5U<F]P92]!=&AE;G,G72`]("=%=7)O<&4O071H96YS
M)SL*)'1Z6R=%=7)O<&4O0F5L9F%S="==(#T@)T5U<F]P92]"96QF87-T)SL*
M)'1Z6R=%=7)O<&4O0F5L9W)A9&4G72`]("=%=7)O<&4O0F5L9W)A9&4G.PHD
M='I;)T5U<F]P92]"97)L:6XG72`]("=%=7)O<&4O0F5R;&EN)SL*)'1Z6R=%
M=7)O<&4O0G)A=&ES;&%V82==(#T@)T5U<F]P92]"<F%T:7-L879A)SL*)'1Z
M6R=%=7)O<&4O0G)U<W-E;',G72`]("=%=7)O<&4O0G)U<W-E;',G.PHD='I;
M)T5U<F]P92]"=6-H87)E<W0G72`]("=%=7)O<&4O0G5C:&%R97-T)SL*)'1Z
M6R=%=7)O<&4O0G5D87!E<W0G72`]("=%=7)O<&4O0G5D87!E<W0G.PHD='I;
M)T5U<F]P92]#:&ES:6YA=2==(#T@)T5U<F]P92]#:&ES:6YA=2<["B1T>ELG
M175R;W!E+T-O<&5N:&%G96XG72`]("=%=7)O<&4O0V]P96YH86=E;B<["B1T
M>ELG175R;W!E+T1U8FQI;B==(#T@)T5U<F]P92]$=6)L:6XG.PHD='I;)T5U
M<F]P92]':6)R86QT87(G72`]("=%=7)O<&4O1VEB<F%L=&%R)SL*)'1Z6R=%
M=7)O<&4O2&5L<VEN:VDG72`]("=%=7)O<&4O2&5L<VEN:VDG.PHD='I;)T5U
M<F]P92])<W1A;F)U;"==(#T@)T5U<F]P92])<W1A;F)U;"<["B1T>ELG175R
M;W!E+TMA;&EN:6YG<F%D)UT@/2`G175R;W!E+TMA;&EN:6YG<F%D)SL*)'1Z
M6R=%=7)O<&4O2VEE=B==(#T@)T5U<F]P92]+:65V)SL*)'1Z6R=%=7)O<&4O
M3&ES8F]N)UT@/2`G175R;W!E+TQI<V)O;B<["B1T>ELG175R;W!E+TQJ=6)L
M:F%N82==(#T@)T5U<F]P92],:G5B;&IA;F$G.PHD='I;)T5U<F]P92],;VYD
M;VXG72`]("=%=7)O<&4O3&]N9&]N)SL*)'1Z6R=%=7)O<&4O3'5X96UB;W5R
M9R==(#T@)T5U<F]P92],=7AE;6)O=7)G)SL*)'1Z6R=%=7)O<&4O36%D<FED
M)UT@/2`G175R;W!E+TUA9')I9"<["B1T>ELG175R;W!E+TUA;'1A)UT@/2`G
M175R;W!E+TUA;'1A)SL*)'1Z6R=%=7)O<&4O36EN<VLG72`]("=%=7)O<&4O
M36EN<VLG.PHD='I;)T5U<F]P92]-;VYA8V\G72`]("=%=7)O<&4O36]N86-O
M)SL*)'1Z6R=%=7)O<&4O36]S8V]W)UT@/2`G175R;W!E+TUO<V-O=R<["B1T
M>ELG175R;W!E+T]S;&\G72`]("=%=7)O<&4O3W-L;R<["B1T>ELG175R;W!E
M+U!A<FES)UT@/2`G175R;W!E+U!A<FES)SL*)'1Z6R=%=7)O<&4O4')A9W5E
M)UT@/2`G175R;W!E+U!R86=U92<["B1T>ELG175R;W!E+U)I9V$G72`]("=%
M=7)O<&4O4FEG82<["B1T>ELG175R;W!E+U)O;64G72`]("=%=7)O<&4O4F]M
M92<["B1T>ELG175R;W!E+U-A;6%R82==(#T@)T5U<F]P92]386UA<F$G.PHD
M='I;)T5U<F]P92]386Y?36%R:6YO)UT@/2`G175R;W!E+U-A;B!-87)I;F\G
M.PHD='I;)T5U<F]P92]387)A:F5V;R==(#T@)T5U<F]P92]387)A:F5V;R<[
M"B1T>ELG175R;W!E+U-I;69E<F]P;VPG72`]("=%=7)O<&4O4VEM9F5R;W!O
M;"<["B1T>ELG175R;W!E+U-K;W!J92==(#T@)T5U<F]P92]3:V]P:F4G.PHD
M='I;)T5U<F]P92]3;V9I82==(#T@)T5U<F]P92]3;V9I82<["B1T>ELG175R
M;W!E+U-T;V-K:&]L;2==(#T@)T5U<F]P92]3=&]C:VAO;&TG.PHD='I;)T5U
M<F]P92]486QL:6YN)UT@/2`G175R;W!E+U1A;&QI;FXG.PHD='I;)T5U<F]P
M92]4:7)A;F4G72`]("=%=7)O<&4O5&ER86YE)SL*)'1Z6R=%=7)O<&4O57IH
M9V]R;V0G72`]("=%=7)O<&4O57IH9V]R;V0G.PHD='I;)T5U<F]P92]6861U
M>B==(#T@)T5U<F]P92]6861U>B<["B1T>ELG175R;W!E+U9A=&EC86XG72`]
M("=%=7)O<&4O5F%T:6-A;B<["B1T>ELG175R;W!E+U9I96YN82==(#T@)T5U
M<F]P92]6:65N;F$G.PHD='I;)T5U<F]P92]6:6QN:75S)UT@/2`G175R;W!E
M+U9I;&YI=7,G.PHD='I;)T5U<F]P92]787)S87<G72`]("=%=7)O<&4O5V%R
M<V%W)SL*)'1Z6R=%=7)O<&4O6F%G<F5B)UT@/2`G175R;W!E+UIA9W)E8B<[
M"B1T>ELG175R;W!E+UIA<&]R;WIH>64G72`]("=%=7)O<&4O6F%P;W)O>FAY
M92<["B1T>ELG175R;W!E+UIU<FEC:"==(#T@)T5U<F]P92]:=7)I8V@G.PHD
M='I;)TEN9&EA;B]!;G1A;F%N87)I=F\G72`]("=);F1I86XO06YT86YA;F%R
M:79O)SL*)'1Z6R=);F1I86XO0VAA9V]S)UT@/2`G26YD:6%N+T-H86=O<R<[
M"B1T>ELG26YD:6%N+T-H<FES=&UA<R==(#T@)TEN9&EA;B]#:')I<W1M87,G
M.PHD='I;)TEN9&EA;B]#;V-O<R==(#T@)TEN9&EA;B]#;V-O<R<["B1T>ELG
M26YD:6%N+T-O;6]R;R==(#T@)TEN9&EA;B]#;VUO<F\G.PHD='I;)TEN9&EA
M;B]+97)G=65L96XG72`]("=);F1I86XO2V5R9W5E;&5N)SL*)'1Z6R=);F1I
M86XO36%H92==(#T@)TEN9&EA;B]-86AE)SL*)'1Z6R=);F1I86XO36%L9&EV
M97,G72`]("=);F1I86XO36%L9&EV97,G.PHD='I;)TEN9&EA;B]-875R:71I
M=7,G72`]("=);F1I86XO36%U<FET:75S)SL*)'1Z6R=);F1I86XO36%Y;W1T
M92==(#T@)TEN9&EA;B]-87EO='1E)SL*)'1Z6R=);F1I86XO4F5U;FEO;B==
M(#T@)TEN9&EA;B]2975N:6]N)SL*)'1Z6R=086-I9FEC+T%P:6$G72`]("=0
M86-I9FEC+T%P:6$G.PHD='I;)U!A8VEF:6,O075C:VQA;F0G72`]("=086-I
M9FEC+T%U8VML86YD)SL*)'1Z6R=086-I9FEC+T-H871H86TG72`]("=086-I
M9FEC+T-H871H86TG.PHD='I;)U!A8VEF:6,O16%S=&5R)UT@/2`G4&%C:69I
M8R]%87-T97(G.PHD='I;)U!A8VEF:6,O169A=&4G72`]("=086-I9FEC+T5F
M871E)SL*)'1Z6R=086-I9FEC+T5N9&5R8G5R>2==(#T@)U!A8VEF:6,O16YD
M97)B=7)Y)SL*)'1Z6R=086-I9FEC+T9A:V%O9F\G72`]("=086-I9FEC+T9A
M:V%O9F\G.PHD='I;)U!A8VEF:6,O1FEJ:2==(#T@)U!A8VEF:6,O1FEJ:2<[
M"B1T>ELG4&%C:69I8R]&=6YA9G5T:2==(#T@)U!A8VEF:6,O1G5N869U=&DG
M.PHD='I;)U!A8VEF:6,O1V%L87!A9V]S)UT@/2`G4&%C:69I8R]'86QA<&%G
M;W,G.PHD='I;)U!A8VEF:6,O1V%M8FEE<B==(#T@)U!A8VEF:6,O1V%M8FEE
M<B<["B1T>ELG4&%C:69I8R]'=6%D86QC86YA;"==(#T@)U!A8VEF:6,O1W5A
M9&%L8V%N86PG.PHD='I;)U!A8VEF:6,O1W5A;2==(#T@)U!A8VEF:6,O1W5A
M;2<["B1T>ELG4&%C:69I8R](;VYO;'5L=2==(#T@)U!A8VEF:6,O2&]N;VQU
M;'4G.PHD='I;)U!A8VEF:6,O2F]H;G-T;VXG72`]("=086-I9FEC+TIO:&YS
M=&]N)SL*)'1Z6R=086-I9FEC+TMI<FET:6UA=&DG72`]("=086-I9FEC+TMI
M<FET:6UA=&DG.PHD='I;)U!A8VEF:6,O2V]S<F%E)UT@/2`G4&%C:69I8R]+
M;W-R864G.PHD='I;)U!A8VEF:6,O2W=A:F%L96EN)UT@/2`G4&%C:69I8R]+
M=V%J86QE:6XG.PHD='I;)U!A8VEF:6,O36%J=7)O)UT@/2`G4&%C:69I8R]-
M86IU<F\G.PHD='I;)U!A8VEF:6,O36%R<75E<V%S)UT@/2`G4&%C:69I8R]-
M87)Q=65S87,G.PHD='I;)U!A8VEF:6,O36ED=V%Y)UT@/2`G4&%C:69I8R]-
M:61W87DG.PHD='I;)U!A8VEF:6,O3F%U<G4G72`]("=086-I9FEC+TYA=7)U
M)SL*)'1Z6R=086-I9FEC+TYI=64G72`]("=086-I9FEC+TYI=64G.PHD='I;
M)U!A8VEF:6,O3F]R9F]L:R==(#T@)U!A8VEF:6,O3F]R9F]L:R<["B1T>ELG
M4&%C:69I8R].;W5M96$G72`]("=086-I9FEC+TYO=6UE82<["B1T>ELG4&%C
M:69I8R]086=O7U!A9V\G72`]("=086-I9FEC+U!A9V\@4&%G;R<["B1T>ELG
M4&%C:69I8R]086QA=2==(#T@)U!A8VEF:6,O4&%L874G.PHD='I;)U!A8VEF
M:6,O4&ET8V%I<FXG72`]("=086-I9FEC+U!I=&-A:7)N)SL*)'1Z6R=086-I
M9FEC+U!O;F%P92==(#T@)U!A8VEF:6,O4&]N87!E)SL*)'1Z6R=086-I9FEC
M+U!O<G1?36]R97-B>2==(#T@)U!A8VEF:6,O4&]R="!-;W)E<V)Y)SL*)'1Z
M6R=086-I9FEC+U)A<F]T;VYG82==(#T@)U!A8VEF:6,O4F%R;W1O;F=A)SL*
M)'1Z6R=086-I9FEC+U-A:7!A;B==(#T@)U!A8VEF:6,O4V%I<&%N)SL*)'1Z
M6R=086-I9FEC+U1A:&ET:2==(#T@)U!A8VEF:6,O5&%H:71I)SL*)'1Z6R=0
M86-I9FEC+U1A<F%W82==(#T@)U!A8VEF:6,O5&%R87=A)SL*)'1Z6R=086-I
M9FEC+U1O;F=A=&%P=2==(#T@)U!A8VEF:6,O5&]N9V%T87!U)SL*)'1Z6R=0
M86-I9FEC+U1R=6LG72`]("=086-I9FEC+U1R=6LG.PHD='I;)U!A8VEF:6,O
M5V%K92==(#T@)U!A8VEF:6,O5V%K92<["B1T>ELG4&%C:69I8R]786QL:7,G
M72`]("=086-I9FEC+U=A;&QI<R<["B1T>ELG4&%C:69I8R]987`G72`]("=0
M86-I9FEC+UEA<"<["@HD1TQ/0D%,4ULG='HG72`]("8D='H["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V5T8R]P
M<V$M:&]R9&4O:&]R9&4O<')E9G,N<&AP````````````````````````````
M````````````````````````````````````````````````,#`P-#0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-#$S-#<@,3`U,34T,S0Q-3(@,#(Q,C0V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V-O;F9I9R]P<F5F<RYP:'`N9&ES
M="QV(#$N.#4N,BXW(#(P,#8O,#8O,C(@,3@Z-#<Z-34@8VAU8VL@17AP("0*
M("H*("H@4')E9F5R96YC97,@26YF;W)M871I;VX*("H@/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*("H@0VAA;F=E<R!Y;W4@;6%K92!T;R!T:&4@<')E9G,N
M<&AP(&9I;&4H<RD@=VEL;"!N;W0@8F4@<F5F;&5C=&5D('5N=&EL('1H90H@
M*B!U<V5R(&QO9W,@;W5T(&%N9"!L;V=S(&EN(&%G86EN+@H@*@H@*B!)9B!Y
M;W4@8VAA;F=E('1H97-E('!R969E<F5N8V5S(&EN(&$@<')O9'5C=&EO;B!S
M>7-T96TL('EO=2!W:6QL"B`J(&YE960@=&\@9&5L971E(&%N>2!H;W)D95]P
M<F5F<R!I;B!Y;W5R('!R969E<F5N8V5S(&1A=&%B87-E+@H@*@H@*B!P<F5F
M1W)O=7!S(&%R<F%Y"B`J("TM+2TM+2TM+2TM+2TM+2T*("H@)'!R969'<F]U
M<',@87)E(&9O<B!D:7-P;&%Y('!U<G!O<V5S('=H96X@>6]U('!R97-S('1H
M92!O<'1I;VYS(&)U='1O;BX*("H@5&AE(&]P=&EO;G,@8VAO:6-E('=I;&P@
M87!P96%R('=H96X@>6]U('-E="!Y;W5R('!R969E<F5N8V5S(&1R:79E<@H@
M*B!I;B!T:&4@:&]R9&4O8V]N9FEG+V-O;F8N<&AP(&9I;&4N"B`J"B`J("1P
M<F5F1W)O=7!S(&%R<F%Y(&1E9FEN:71I;VXZ"B`J("`@(&-O;'5M;CH@(%=H
M870@8V]L=6UN(&AE860@=&AI<R!G<F]U<"!W:6QL(&=O('5N9&5R"B`J("`@
M("!L86)E;#H@($QA8F5L(&9O<B!T:&4@9W)O=7`@;V8@<V5T=&EN9W,*("H@
M("`@("!D97-C.B`@1&5S8W)I<'1I;VX@=&AA="!W:6QL('-H;W<@=6YD97(@
M;&%B96P*("H@("!M96UB97)S.B`@3&ES="!O9B!P<F5F97)E;F-E<R!S=7!P
M;W)T960@8GD@=&AI<R!G<F]U<`H@*@H@*B!?<')E9G,@87)R87D*("H@+2TM
M+2TM+2TM+2TM"B`J(%1H92`D7W!R969S(&%R<F%Y)W,@87)E(&QI<W1E9"!I
M;B!T:&4@<V%M92!O<F1E<B!A<R!L:7-T960@:6X@=&AE"B`J(&UE;6)E<G,@
M96QE;65N="!O9B`D<')E9D=R;W5P<RX*("H*("H@("!V86QU93H@5&AI<R!E
M;G1R>2!W:6QL(&5I=&AE<B!H;VQD(&$@;G5M8F5R(&]R(&$@=&5X="!V86QU
M92!B87-E9"!O;B!T:&4*("H@("`@("`@("`@<')E9F5R96YC92!T>7!E.@H@
M*B`@("`@("`@("`@(&EM<&QI8VET.B`@4V5E(%!R969E<F5N8V4@='EP90H@
M*B`@("`@("`@("`@("`@("!T97AT.B`@5&5X="!V86QU90H@*B`@("`@("`@
M("`@("`@;G5M8F5R.B`@3G5M8F5R('9A;'5E"B`J("`@("`@("`@("`@8VAE
M8VMB;W@Z("!686QU92!S:&]U;&0@8F4@,"!F;W(@=6YC:&5C:V5D+"`Q(&9O
M<B!C:&5C:V5D"B`J("`@("`@("`@("`@("!S96QE8W0Z("!686QU92!A<W-O
M8VEA=&5D('=I=&@@=&AA="!S96QE8W1I;VX@;&ES=`H@*@H@*B`@;&]C:V5D
M.B!!;&QO=R!P<F5F97)E;F-E('1O(&)E(&-H86YG960@9G)O;2!520H@*B`@
M("`@("`@("`@("!T<G5E.B`@1&\@;F]T('-H;W<@=&AI<R!P<F5F97)E;F-E
M(&EN('1H92!520H@*B`@("`@("`@("`@(&9A;'-E.B`@4VAO=R!T:&ES('!R
M969E<F5N8V4@:6X@=&AE(%5)(&%N9"!A;&QO=R!C:&%N9VEN9PH@*@H@*B`@
M<VAA<F5D.B!3:&%R92!W:71H(&]T:&5R(&AO<F1E(&%P<',*("H@("`@("`@
M("`@("`@=')U93H@(%-H87)E('1H:7,@<')E9B!W:71H(&]T:&5R($AO<F1E
M(&%P<',*("H@("`@("`@("`@("!F86QS93H@($ME97`@=&AI<R!P<F5F(&QO
M8V%L('1O('1H92!C=7)R96YT(&%P<`H@*@H@*B`@("!T>7!E.B!0<F5F97)E
M;F-E('1Y<&4*("H@("`@("`@("`@("`@<W!E8VEA;#H@(%!R;W9I9&5S(&$@
M54D@=VED9V5T"B`J("`@("`@("`@("`@("!S96QE8W0Z("!0<F]V:61E<R!A
M('-E;&5C=&EO;B!L:7-T(&EN('1H92!520H@*B`@("`@("`@("`@(&-H96-K
M8F]X.B`@4')O=FED97,@82!C:&5C:V)O>`H@*B`@("`@("`@("`@(&EM<&QI
M8VET.B`@4')O=FED97,@<W1O<F%G92!F;W(@)W-P96-I86PG('1Y<&5S"B`J
M("`@("`@("`@("`@<&%S<W=O<F0Z("!0<F]V:61E<R!A('1E>'1B;W@@9F]R
M('!A<W-W;W)D(&5N=')Y+@H@*B`@("`@("`@("`@("`@("!E;G5M.B`@57-E
M('-T871I8R!L:7-T(&]F(&5L96UE;G1S+BXN<VEM:6QA<B!T;R`G<V5L96-T
M)PH@*@H@*B`@("!E;G5M.B!3=&%T:6,@;&ES="!O9B!E;&5M96YT<RX*("H*
M("H@97-C87!E9#H@1F]R(&%N(&5N=6T@;W(@82!S96QE8W0L(&%R92!T:&4@
M:V5Y<R!A;F0@=F%L=65S(&%L<F5A9'D@:'1M;"UE<V-A<&5D/PH@*B`@("`@
M("`@("!$969A=6QT<R!T;R!F86QS92!I9B!N;W0@<')E<V5N="X*("H*("H@
M("`@:&]O:SH@0V%L;"!A(&AO;VL@9G5N8W1I;VX@9F]R('1H92!V86QU92!O
M9B!T:&ES('!R969E<F5N8V4*("H@("`@("`@("`@("`@=')U93H@(%=I;&P@
M8V%L;"!T:&4@9G5N8W1I;VX@7W!R969S7VAO;VM?/'!R969N86UE/@H@*B`@
M("`@("`@("`@("`@("`@("`@=&\@9FEL;"!I;B!T:&4@=F%L=64@;V8@=&AI
M<R!P<F5F97)E;F-E+@H@*B`@("`@("`@("`@("`@("`@("`@4V5E(&AO;VMS
M+G!H<"!F;W(@;6]R92!D971A:6QS+@H@*B`@("`@("`@("`@(&9A;'-E.B`@
M3F]R;6%L(&)E:&%V:6]U<B`M(&YO(&AO;VL@:7,@8V%L;&5D+@H@*B\*"B1P
M<F5F1W)O=7!S6R=I9&5N=&ET:65S)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG
M(#T^(%\H(EEO=7(@26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B
M4&5R<V]N86P@26YF;W)M871I;VXB*2P*("`@("=D97-C)R`]/B!?*")#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RXB*2P*("`@("=M
M96UB97)S)R`]/B!A<G)A>2@G9&5F875L=%]I9&5N=&ET>2<L("=I9&5N=&ET
M>7-E;&5C="<L("=D96QE=&5I9&5N=&ET>2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)VED)RP@)V9U;&QN86UE)RP@)V9R;VU?861D<B<I"BD["@HD875T
M:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==
M6R=D<FEV97(G72D["FEF("AI<U]A*"1A=71H+"`G075T:"<I("8F("1A=71H
M+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@)'!R969'<F]U<'-;
M)V9O<F=O='!A<W,G72`](&%R<F%Y*`H@("`@("`@("=C;VQU;6XG(#T^(%\H
M(EEO=7(@26YF;W)M871I;VXB*2P*("`@("`@("`G;&%B96PG(#T^(%\H(D%C
M8V]U;G0@4&%S<W=O<F0B*2P*("`@("`@("`G9&5S8R<@/3X@7R@B4V5T(&]P
M=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@
M>6]U(&5V97(@9F]R9V5T(&ET+B(I+`H@("`@("`@("=M96UB97)S)R`]/B!A
M<G)A>2@G<V5C=7)I='E?<75E<W1I;VXG+"`G<V5C=7)I='E?86YS=V5R)RP@
M)V%L=&5R;F%T95]E;6%I;"<I"B`@("`I.PI]"@HD<')E9D=R;W5P<ULG;&%N
M9W5A9V4G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B66]U<B!);F9O
M<FUA=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*"),;V-A;&4@86YD(%1I;64B
M*2P*("`@("=D97-C)R`]/B!?*")3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(BDL"B`@("`G;65M8F5R
M<R<@/3X@87)R87DH)VQA;F=U86=E)RP@)W1I;65Z;VYE)RP@)W1W96YT>49O
M=7(G+"`G9&%T95]F;W)M870G*0HI.PH*)'!R969'<F]U<'-;)V-A=&5G;W)I
M97,G72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B66]U<B!);F9O<FUA
M=&EO;B(I+`H@("`@)VQA8F5L)R`]/B!?*")#871E9V]R:65S(&%N9"!,86)E
M;',B*2P*("`@("=D97-C)R`]/B!?*")-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(I+`H@("`@
M)VUE;6)E<G,G(#T^(&%R<F%Y*"=C871E9V]R>6UA;F%G96UE;G0G*0HI.PH*
M)'!R969'<F]U<'-;)V1I<W!L87DG72`](&%R<F%Y*`H@("`@)V-O;'5M;B<@
M/3X@7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("=L86)E;"<@/3X@7R@B
M1&ES<&QA>2!/<'1I;VYS(BDL"B`@("`G9&5S8R<@/3X@7R@B4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N(BDL"B`@("`G;65M
M8F5R<R<@/3X@87)R87DH)VEN:71I86Q?87!P;&EC871I;VXG+"`G<VAO=U]L
M87-T7VQO9VEN)RP@)W1H96UE)RP*("`@("`@("`@("`@("`@("`@("`@("`G
M<W5M;6%R>5]R969R97-H7W1I;64G+"`G<VAO=U]S:61E8F%R)RP@)W-I9&5B
M87)?=VED=&@G+`H@("`@("`@("`@("`@("`@("`@("`@("=M;WI?<VED96)A
M<B<L("=M96YU7W9I97<G+"`G;65N=5]R969R97-H7W1I;64G+`H@("`@("`@
M("`@("`@("`@("`@("`@("=W:61G971?86-C97-S:V5Y)RP@)V%L<&AA7V9I
M;'1E<B<I"BD["@HD<')E9D=R;W5P<ULG;&]G:6YT87-K<R==(#T@87)R87DH
M"B`@("`G8V]L=6UN)R`]/B!?*")/=&AE<B!);F9O<FUA=&EO;B(I+`H@("`@
M)VQA8F5L)R`]/B!?*"),;V=I;B!487-K<R(I+`H@("`@)V1E<V,G(#T^('-P
M<FEN=&8H7R@B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+B(I+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=N86UE)RDI+`H@
M("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=D;U]M86EN=&5N86YC92<L("=C;VYF
M:7)M7VUA:6YT96YA;F-E)RD**3L*"B1P<F5F1W)O=7!S6R=R96UO=&4G72`]
M(&%R<F%Y*`H@("`@)V-O;'5M;B<@/3X@7R@B3W1H97(@26YF;W)M871I;VXB
M*2P*("`@("=L86)E;"<@/3X@7R@B4F5M;W1E(%-E<G9E<G,B*2P*("`@("=D
M97-C)R`]/B!?*")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB*2P*("`@("=U<FPG(#T^
M("=S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<"<**3L*"B\O($9O<B!A;'1E
M<FYA=&4@24U34"!A=71H96YT:6-A=&EO;BX*:68@*"%E;7!T>2@D1TQ/0D%,
M4ULG8V]N9B==6R=I;7-P)UU;)V5N86)L960G72DI('L*("`@("1P<F5F1W)O
M=7!S6R=I;7-P875T:"==(#T@87)R87DH"B`@("`@("`@)V-O;'5M;B<@/3X@
M7R@B3W1H97(@26YF;W)M871I;VXB*2P*("`@("`@("`G;&%B96PG(#T^(%\H
M(D%L=&5R;F%T92!)35-0($QO9VEN(BDL"B`@("`@("`@)V1E<V,G(#T^(%\H
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(BDL"B`@("`@("`@)VUE;6)E<G,G(#T^(&%R<F%Y*"=I;7-P7V%U
M=&A?=7-E<B<L("=I;7-P7V%U=&A?<&%S<R<I"B`@("`I.PI]"@HO+R!$971E
M<FUI;F4@9G5N8W1I;VYA;&ET>2!O9B!R:6-H=&5X="!E9&ET;W(*)'!R969'
M<F]U<'-;)W)I8VAT97AT)UT@/2!A<G)A>2@*("`@("=C;VQU;6XG(#T^(%\H
M(D]T:&5R($EN9F]R;6%T:6]N(BDL"B`@("`G;&%B96PG(#T^(%\H(E)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<R(I+`H@("`@)V1E<V,G(#T^(%\H(E=H:6-H
M('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB
M*2P*("`@("=M96UB97)S)R`]/B!A<G)A>2@G8V]N=&5X=&UE;G4G+"`G=&%B
M;&5O<&5R871I;VYS)RP@)VQI<W1T>7!E)RDL"BD["FEF("@D<F5G:7-T<GDM
M/FAA<TEN=&5R9F%C92@G:6UA9V5S)RDI('L*("`@("1P<F5F1W)O=7!S6R=R
M:6-H=&5X="==6R=M96UB97)S)UU;72`]("=A;G-E;&EM86=E)SL*?0H*+R\@
M4&5R<V]N86P@26YF;W)M871I;VX@<')E9F5R96YC97,*"B\O(&1E9F%U;'0@
M:61E;G1I='D*+R\@4V5T(&QO8VME9"!T;R!T<G5E(&EF('EO=2!D;VXG="!W
M86YT('1H92!U<V5R<R!T;R!H879E(&UU;'1I<&QE(&ED96YT:71I97,N"B1?
M<')E9G-;)V1E9F%U;'1?:61E;G1I='DG72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`P+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]
M/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=E;G5M)R`]/B`H
M:7-S970H)&ED96YT:71Y*2`F)B!I<U]O8FIE8W0H)&ED96YT:71Y*2D@/R`D
M:61E;G1I='DM/F=E=$%L;"@G:60G*2`Z(&%R<F%Y*"DL"B`@("`G9&5S8R<@
M/3X@7R@B66]U<B!D969A=6QT(&ED96YT:71Y.B(I"BD["@HO+R!I9&5N=&ET
M:65S(&%R<F%Y"B\O($1O;B=T(&-H86YG92!A;GET:&EN9R!H97)E+@HD7W!R
M969S6R=I9&5N=&ET:65S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)V$Z
M,#I[?2<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^
M('1R=64L"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@:61E;G1I
M='D@<V5L96-T:6]N('=I9&=E=`HD7W!R969S6R=I9&5N=&ET>7-E;&5C="==
M(#T@87)R87DH"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^
M("=S<&5C:6%L)PHI.PH*+R\@9&5L971E(&)U='1O;@HD7W!R969S6R=D96QE
M=&5I9&5N=&ET>2==(#T@87)R87DH"B`@("`G='EP92<@/3X@)W-P96-I86PG
M+`H@("`@)W-H87)E9"<@/3X@=')U90HI.PH*+R\@:61E;G1I='D@;F%M90HO
M+R!)9B!Y;W4@;&]C:R!T:&ES('!R969E<F5N8V4L('EO=2!M=7-T('-P96-I
M9GD@82!V86QU92!O<B!A(&AO;VL@9F]R(&ET(&EN"B\O(&AO<F1E+V-O;F9I
M9R]H;V]K<RYP:'`N"B1?<')E9G-;)VED)UT@/2!A<G)A>2@*("`@("=V86QU
M92<@/3X@)R<L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^('1R=64L"B`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^
M(%\H(DED96YT:71Y)W,@;F%M93HB*0HI.PH*+R\@=7-E<B!F=6QL(&YA;64@
M9F]R($9R;VTZ(&QI;F4*+R\@268@>6]U(&QO8VL@=&AI<R!P<F5F97)E;F-E
M+"!Y;W4@;75S="!S<&5C:69Y(&$@=F%L=64@;W(@82!H;V]K(&9O<B!I="!I
M;@HO+R!H;W)D92]C;VYF:6<O:&]O:W,N<&AP+@HD7W!R969S6R=F=6QL;F%M
M92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@
M/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^
M("=T97AT)RP*("`@("=D97-C)R`]/B!?*")9;W5R(&9U;&P@;F%M93HB*0HI
M.PH*+R\@=7-E<B!P<F5F97)R960@96UA:6P@861D<F5S<R!F;W(@1G)O;3H@
M;&EN90HO+R!)9B!Y;W4@;&]C:R!T:&ES('!R969E<F5N8V4L('EO=2!M=7-T
M('-P96-I9GD@82!V86QU92!O<B!A(&AO;VL@9F]R(&ET(&EN"B\O(&AO<F1E
M+V-O;F9I9R]H;V]K<RYP:'`N"B1?<')E9G-;)V9R;VU?861D<B==(#T@87)R
M87DH"B`@("`G=F%L=64G(#T^("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=T97AT)RP*
M("`@("=D97-C)R`]/B`@7R@B66]U<B!&<F]M.B!A9&1R97-S.B(I"BD["@HO
M+R!U<V5R('-E8W5R:71Y('%U97-T:6]N"B1?<')E9G-;)W-E8W5R:71Y7W%U
M97-T:6]N)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP
M92<@/3X@)W1E>'0G+`H@("`@)V1E<V,G(#T^(%\H(D5N=&5R(&$@<V5C=7)I
M='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE
M960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.B(I"BD["@HO+R!U<V5R('-E8W5R:71Y(&%N
M<W=E<@HD7W!R969S6R=S96-U<FET>5]A;G-W97(G72`](&%R<F%Y*`H@("`@
M)W9A;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H
M87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G9&5S
M8R<@/3X@7R@B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(I"BD["@HO+R!U<V5R(&%L=&5R;F%T92!E;6%I
M;`HD7W!R969S6R=A;'1E<FYA=&5?96UA:6PG72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E
M9"<@/3X@=')U92P*("`@("=T>7!E)R`]/B`G=&5X="<L"B`@("`G9&5S8R<@
M/3X@7R@B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A
M;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(BD**3L*"B\O('5S97(@;&%N
M9W5A9V4*)%]P<F5F<ULG;&%N9W5A9V4G72`](&%R<F%Y*`H@("`@)W9A;'5E
M)R`]/B`G)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@=')U92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*("`@("=E<V-A<&5D
M)R`]/B!T<G5E+`H@("`@)V1E<V,G(#T^(%\H(E-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93HB*0HI.PH*+R\@=7-E<B!T:6UE('IO;F4*)%]P<F5F
M<ULG=&EM97IO;F4G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G)RP*("`@
M("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@
M("=T>7!E)R`]/B`G<V5L96-T)RP*("`@("=D97-C)R`]/B!?*")9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.B(I"BD["@HO+R!T:6UE(&9O<FUA=`HD7W!R969S
M6R=T=V5N='E&;W5R)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@9F%L<V4L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_(BD**3L*"B\O(&1A=&4@9F]R;6%T"B1?
M<')E9G-;)V1A=&5?9F]R;6%T)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)R5X)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M=')U92P*("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R
M87DH"B`@("`@("`@)R5X)R`]/B!S=')F=&EM92@G)7@G*2P*("`@("`@("`G
M)5DM)6TM)60G(#T^('-T<F9T:6UE*"<E62TE;2TE9"<I+`H@("`@("`@("<E
M9"\E;2\E62<@/3X@<W1R9G1I;64H)R5D+R5M+R59)RDL"B`@("`@("`@)R5!
M("5"("5D+"`E62<@/3X@<W1R9G1I;64H)R5!("5"("5D+"`E62<I+`H@("`@
M("`@("<E02P@)60N("5"("59)R`]/B!S=')F=&EM92@G)4$L("5D+B`E0B`E
M62<I+`H@("`@("`@("<E02P@)60@)4(@)5DG(#T^('-T<F9T:6UE*"<E02P@
M)60@)4(@)5DG*2P*("`@("`@("`G)6$L("5B("5E+"`E62<@/3X@<W1R9G1I
M;64H)R5A+"`E8B`E92P@)5DG*2P*("`@("`@("`G)6$L("5B("5E+"`E>2<@
M/3X@<W1R9G1I;64H)R5A+"`E8B`E92P@)7DG*2P*("`@("`@("`G)6$L("5B
M("5E)R`]/B!S=')F=&EM92@G)6$L("5B("5E)RDL"B`@("`@("`@)R5A+"`E
M92`E8B`E62<@/3X@<W1R9G1I;64H)R5A+"`E92`E8B`E62<I+`H@("`@("`@
M("<E82P@)64@)6(@)7DG(#T^('-T<F9T:6UE*"<E82P@)64@)6(@)7DG*2P*
M("`@("`@("`G)6$@)60@)6(@)5DG(#T^('-T<F9T:6UE("@G)6$@)60@)6(@
M)5DG*2P*("`@("`@("`G)6$@)7@G(#T^('-T<F9T:6UE("@G)6$@)7@G*2P*
M("`@("`@("`G)6$@)5DM)6TM)60G(#T^('-T<F9T:6UE("@G)6$@)5DM)6TM
M)60G*2P*("`@("`@("`G)64@)6(@)5DG(#T^('-T<F9T:6UE*"<E92`E8B`E
M62<I+`H@("`@("`@("<E92X@)6(@)5DG(#T^('-T<F9T:6UE*"<E92X@)6(@
M)5DG*2P*("`@("`@("`G)64N("5M("59)R`]/B!S=')F=&EM92@G)64@)6T@
M)5DG*2P*("`@("`@("`G)64N("5M+B<@/3X@<W1R9G1I;64H)R5E+B`E;2XG
M*2P*("`@("`@("`G)64N("5")R`]/B!S=')F=&EM92@G)64N("5")RDL"B`@
M("`@("`@)R5E+B`E0B`E62<@/3X@<W1R9G1I;64H)R5E+B`E0B`E62<I+`H@
M("`@("`@("<E92X@)4(@)7DG(#T^('-T<F9T:6UE*"<E92X@)4(@)7DG*2P*
M("`@("`@("`G)4(@)64L("59)R`]/B!S=')F=&EM92@G)4(@)64L("59)RDL
M"B`@("`I+`H@("`@)V1E<V,G(#T^(%\H(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB*2D["@HO+R!522!T:&5M90HD7W!R969S6R=T:&5M92==(#T@
M87)R87DH"B`@("`G=F%L=64G(#T^("=B;'5E=VAI=&4G+`H@("`@)VQO8VME
M9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G
M(#T^("=S96QE8W0G+`H@("`@)V1E<V,G(#T^(%\H(E-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92XB*0HI.PH*+R\@8V%T96=O<FEE<PHD7W!R969S6R=C871E
M9V]R:65S)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@)R<L"B`@("`G;&]C
M:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP
M92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@8V%T96=O<GD@8V]L;W)S"B1?<')E
M9G-;)V-A=&5G;W)Y7V-O;&]R<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^
M("<G+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T
M<G5E+`H@("`@)W1Y<&4G(#T^("=I;7!L:6-I="<**3L*"B\O(%5)(&9O<B!C
M871E9V]R>2!M86YA9V5M96YT+@HD7W!R969S6R=C871E9V]R>6UA;F%G96UE
M;G0G72`](&%R<F%Y*`H@("`@)W1Y<&4G(#T^("=S<&5C:6%L)PHI.PH*)%]P
M<F5F<ULG<W5M;6%R>5]R969R97-H7W1I;64G72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B`S,#`L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R
M960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("=E;G5M
M)R`]/B!A<G)A>2@P(#T^(%\H(DYE=F5R(BDL"B`@("`@("`@("`@("`@("`@
M("`@,S`@/3X@7R@B179E<GD@,S`@<V5C;VYD<R(I+`H@("`@("`@("`@("`@
M("`@("`@(#8P(#T^(%\H(D5V97)Y(&UI;G5T92(I+`H@("`@("`@("`@("`@
M("`@("`@(#,P,"`]/B!?*")%=F5R>2`U(&UI;G5T97,B*2P*("`@("`@("`@
M("`@("`@("`@("`Y,#`@/3X@7R@B179E<GD@,34@;6EN=71E<R(I+`H@("`@
M("`@("`@("`@("`@("`@(#$X,#`@/3X@7R@B179E<GD@:&%L9B!H;W5R(BDI
M+`H@("`@)V1E<V,G(#T^(%\H(E)E9G)E<V@@4&]R=&%L(%9I97<Z(BD**3L*
M"B1?<')E9G-;)W-H;W=?<VED96)A<B==(#T@87)R87DH"B`@("`G=F%L=64G
M(#T^('1R=64L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G
M(#T^('1R=64L"B`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("=D97-C
M)R`]/B!S<')I;G1F*%\H(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G+"`G:&]R9&4G
M*2D**3L*"B1?<')E9G-;)W-I9&5B87)?=VED=&@G72`](&%R<F%Y*`H@("`@
M)W9A;'5E)R`]/B`Q-S4L"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S
M:&%R960G(#T^(&9A;'-E+`H@("`@)W1Y<&4G(#T^("=N=6UB97(G+`H@("`@
M)V1E<V,G(#T^('-P<FEN=&8H7R@B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(BDL("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G+"`G:&]R9&4G*2D**3L*
M"B1?<')E9G-;)VUO>E]S:61E8F%R)UT@/2!A<G)A>2@*("`@("=T>7!E)R`]
M/B`G;&EN:R<L"B`@("`G>'5R;"<@/3X@<W!R:6YT9B@G:F%V87-C<FEP=#II
M9B`H=VEN9&]W+G-I9&5B87(@)B8@=VEN9&]W+G-I9&5B87(N861D4&%N96PI
M('=I;F1O=RYS:61E8F%R+F%D9%!A;F5L*%PG)7-<)RP@7"<E<UPG+"!<)R5S
M7"<I.R!E;'-E(&%L97)T*%PG)7-<)RD[)RP*("`@("`@("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G+"`G:&]R9&4G
M*2P*("`@("`@("`@("`@("`@("`@("`@(%5T:6PZ.F%D9%!A<F%M971E<BA(
M;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G
M+"`G:&]R9&4G*2`N("<O<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP)RP@
M=')U92P@+3$I+"`G;6]Z8F%R)RP@)S$G*2P*("`@("`@("`@("`@("`@("`@
M("`@($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I("X@)R]P<F5F<RYP:'`G+"!T<G5E+"`M,2DL"B`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*%\H(D-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN(BDI*2P*("`@("=D97-C)R`]/B!S<')I;G1F*%\H(D%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(I+"`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=N86UE)RP@)VAO<F1E)RDI"BD["@HD7W!R969S
M6R=M96YU7W9I97<G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G8F]T:"<L
M"B`@("`G;&]C:V5D)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L
M"B`@("`G='EP92<@/3X@)V5N=6TG+`H@("`@)V5N=6TG(#T^(&%R<F%Y*"=T
M97AT)R`]/B!?*")497AT($]N;'DB*2P*("`@("`@("`@("`@("`@("`@("`G
M:6-O;B<@/3X@7R@B26-O;G,@3VYL>2(I+`H@("`@("`@("`@("`@("`@("`@
M("=B;W1H)R`]/B!?*"))8V]N<R!W:71H('1E>'0B*2DL"B`@("`G9&5S8R<@
M/3X@7R@B365N=2!M;V1E.B(I"BD["@HD7W!R969S6R=M96YU7W)E9G)E<VA?
M=&EM92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(#,P,"P*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E
M)R`]/B`G96YU;2<L"B`@("`G96YU;2<@/3X@87)R87DH,"`]/B!?*").979E
M<B(I+`H@("`@("`@("`@("`@("`@("`@(#,P(#T^(%\H(D5V97)Y(#,P('-E
M8V]N9',B*2P*("`@("`@("`@("`@("`@("`@("`V,"`]/B!?*")%=F5R>2!M
M:6YU=&4B*2P*("`@("`@("`@("`@("`@("`@("`Q,C`@/3X@7R@B179E<GD@
M,B!M:6YU=&5S(BDL"B`@("`@("`@("`@("`@("`@("`@,S`P(#T^(%\H(D5V
M97)Y(#4@;6EN=71E<R(I*2P*("`@("=D97-C)R`]/B!?*")2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SHB*0HI.PH*"B\O($QO9VEN+TUA:6YT96YA
M;F-E(%1A<VMS('!R969E<F5N8V5S"@HO+R!4;R!D:7-A8FQE(&UA:6YT96YA
M;F-E(&5N=&ER96QY+"!S970@)W9A;'5E)R`](&9A;'-E(&%N9`HO+R`G;&]C
M:V5D)R`]('1R=64@9F]R(&%L;"!O9B!T:&5S92X@5&\@:G5S="!T=7)N(&ET
M(&]F9B!B>2!D969A=6QT+`HO+R!S970@)W9A;'5E)R!F86QS92!F;W(@9&]?
M;6%I;G1E;F%N8V4N"B\O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\*)%]P<F5F<ULG9&]?;6%I;G1E;F%N8V4G72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G
M9&5S8R<@/3X@7R@B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/R(I+`H@("`@)VAE;'`G(#T^("=P<F5F<RUD;U]M86EN=&5N86YC
M92<I.PH*+R\@;&%S="!T:6UE(&UA:6YT96YA;F-E('=A<R!R=6XN"B\O('9A
M;'5E(&ES(&$@54Y)6"!T:6UE<W1A;7`@;V8@=&AE(&QA<W0@=&EM92!M86EN
M=&5N86YC92!R86X@9F]R('1H92!U<V5R+@HD7W!R969S6R=L87-T7VUA:6YT
M96YA;F-E)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@,"P*("`@("=L;V-K
M960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E
M)R`]/B`G:6UP;&EC:70G"BD["@HO+R!C;VYF:7)M('=H96X@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\@268@9F%L<V4L('1H97D@=VEL;`HO+R!B
M92!P97)F;W)M960@=VET:"!N;R!I;G!U="!F<F]M+V-H96-K('=I=&@@=&AE
M('5S97(N"B1?<')E9G-;)V-O;F9I<FU?;6%I;G1E;F%N8V4G72`](&%R<F%Y
M*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L
M"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O
M>"<L"B`@("`G9&5S8R<@/3X@7R@B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(BDL"B`@("`G:&5L
M<"<@/3X@)W!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4G*3L*"B\O($5N9"!,
M;V=I;B]-86EN=&5N86YC92!P<F5F97)E;F-E<PH*"B\O('=H870@87!P;&EC
M871I;VX@<VAO=6QD('=E(&=O('1O(&%F=&5R(&QO9VEN/PHD7W!R969S6R=I
M;FET:6%L7V%P<&QI8V%T:6]N)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@
M)VAO<F1E)RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@
M/3X@=')U92P*("`@("=T>7!E)R`]/B`G<V5L96-T)RP*("`@("=D97-C)R`]
M/B!S<')I;G1F*%\H(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)VYA;64G*2D**3L*"B\O('-H;W5L9"!W92!C<F5A=&4@86-C97-S(&ME>7,_
M"B1?<')E9G-;)W=I9&=E=%]A8V-E<W-K97DG72`](&%R<F%Y*`H@("`@)W9A
M;'5E)R`]/B!T<G5E+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA
M<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G
M9&5S8R<@/3X@7R@B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(BD**3L*"B\O('-H;W5L9"!W92!N;W0@=7-E('1H92!A
M;'!H82!I;6%G92!L;V%D97(@9F]R($E%/PHD7W!R969S6R=A;'!H85]F:6QT
M97(G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!F86QS92P*("`@("=L;V-K
M960G(#T^('1R=64L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y<&4G
M(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+B(I"BD["@HO+R!T:&4@;&%Y;W5T(&]F('1H92!P;W)T86P@
M<&%G92X*)%]P<F5F<ULG<&]R=&%L7VQA>6]U="==(#T@87)R87DH"B`@("`G
M=F%L=64G(#T^("=A.C`Z>WTG+`H@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@
M("`G<VAA<F5D)R`]/B!F86QS92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G
M"BD["@HO+R!T:&4@<F5M;W1E('-E<G9E<G,N"B1?<')E9G-;)W)E;6]T95]S
M=6UM87)I97,G72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G83HP.GM])RP*
M("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@9F%L<V4L
M"B`@("`G='EP92<@/3X@)VEM<&QI8VET)PHI.PH*+R\@;&%S="!L;V=I;B!T
M:6UE(&]F('5S97(*+R\@=F%L=64@:7,@82!S97)I86QI>F5D(&%R<F%Y(&]F
M('1H92!53DE8('1I;65S=&%M<"!O9B!T:&4@;&%S=`HO+R!L;V=I;BP@86YD
M('1H92!H;W-T('1H870@=&AE(&QA<W0@;&]G:6X@=V%S(&9R;VTN"B1?<')E
M9G-;)VQA<W1?;&]G:6XG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B`G83HP
M.GM])RP*("`@("=L;V-K960G(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@
M=')U92P*("`@("=T>7!E)R`]/B`G:6UP;&EC:70G"BD["@HO+R!S:&]W('1H
M92!L87-T(&QO9VEN('1I;64@;V8@=7-E<@HD7W!R969S6R=S:&]W7VQA<W1?
M;&]G:6XG72`](&%R<F%Y*`H@("`@)W9A;'5E)R`]/B!T<G5E+`H@("`@)VQO
M8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(I"BD["@II9B`H(65M<'1Y
M*"1'3$]"04Q36R=C;VYF)UU;)VEM<W`G75LG96YA8FQE9"==*2D@>PH@("`@
M)%]P<F5F<ULG:6US<%]A=71H7W5S97(G72`](&%R<F%Y*`H@("`@("`@("=V
M86QU92<@/3X@)R<L"B`@("`@("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`@
M("`@)W-H87)E9"<@/3X@9F%L<V4L"B`@("`@("`@)W1Y<&4G(#T^("=T97AT
M)RP*("`@("`@("`G9&5S8R<@/3X@7R@B06QT97)N871E($E-4U`@57-E<FYA
M;64B*0H@("`@*3L*"B`@("`D7W!R969S6R=I;7-P7V%U=&A?<&%S<R==(#T@
M87)R87DH"B`@("`@("`@)W9A;'5E)R`]/B`G)RP*("`@("`@("`G;&]C:V5D
M)R`]/B!F86QS92P*("`@("`@("`G<VAA<F5D)R`]/B!F86QS92P*("`@("`@
M("`G='EP92<@/3X@)W!A<W-W;W)D)RP*("`@("`@("`G9&5S8R<@/3X@7R@B
M06QT97)N871E($E-4U`@4&%S<W=O<F0B*0H@("`@*3L*?0H*+R\@4FEC:"!4
M97AT($5D:71O<B!P<F5F97)E;F-E<RX*"B1?<')E9G-;)V-O;G1E>'1M96YU
M)UT@/2!A<G)A>2@*("`@("=V86QU92<@/3X@=')U92P*("`@("=L;V-K960G
M(#T^(&9A;'-E+`H@("`@)W-H87)E9"<@/3X@=')U92P*("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@)V1E<V,G(#T^(%\H(D5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_(BD**3L*"B1?<')E9G-;)W1A8FQE;W!E<F%T
M:6]N<R==(#T@87)R87DH"B`@("`G=F%L=64G(#T^(&9A;'-E+`H@("`@)VQO
M8VME9"<@/3X@9F%L<V4L"B`@("`G<VAA<F5D)R`]/B!T<G5E+`H@("`@)W1Y
M<&4G(#T^("=C:&5C:V)O>"<L"B`@("`G9&5S8R<@/3X@7R@B4VAO=R!T86)L
M92!O<&5R871I;VYS(&UE;G4@8F%R/R(I"BD["@HD7W!R969S6R=L:7-T='EP
M92==(#T@87)R87DH"B`@("`G=F%L=64G(#T^('1R=64L"B`@("`G;&]C:V5D
M)R`]/B!F86QS92P*("`@("=S:&%R960G(#T^('1R=64L"B`@("`G='EP92<@
M/3X@)V-H96-K8F]X)RP*("`@("=D97-C)R`]/B!?*")!;&QO=R!S971T:6YG
M(&]F(&]R9&5R960@;&ES="!T>7!E/R(I"BD["@II9B`H)')E9VES=')Y+3YH
M87-);G1E<F9A8V4H)VEM86=E<R<I*2!["B`@("`D7W!R969S6R=A;G-E;&EM
M86=E)UT@/2!A<G)A>2@*("`@("`@("`G=F%L=64G(#T^('1R=64L"B`@("`@
M("`@)VQO8VME9"<@/3X@9F%L<V4L"B`@("`@("`@)W-H87)E9"<@/3X@=')U
M92P*("`@("`@("`G='EP92<@/3X@)V-H96-K8F]X)RP*("`@("`@("`G9&5S
M8R<@/3X@7R@B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T
M;R!'86QL97)I97,@:6X@=&5X=#\B*0H@("`@*3L*?0H*+R\@16YD(%)I8V@@
M5&5X="!%9&ET;W(@<')E9F5R96YC97,N"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]E=&,O<'-A+6AO<F1E+VAO<F1E+W)E9VES=')Y+G!H<```````````
M````````````````````````````````````````````````````````````
M`#`P,#0T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-S`W(#$P-3$U-#,T
M,34R(#`R,C`P,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@<F5G:7-T<GDN<&AP("TM($AO<F1E(&%P
M<&QI8V%T:6]N(')E9VES=')Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES="QV(#$N,C4U+C(N,3<@,C`P-B\P-R\R,2`Q
M-3HT.3HT-B!J86X@17AP("0*("H*("H@5&AI<R!C;VYF:6=U<F%T:6]N(&9I
M;&4@:7,@=7-E9"!B>2!(;W)D92!T;R!D971E<FUI;F4@=VAI8V@@2&]R9&4*
M("H@87!P;&EC871I;VYS(&%R92!I;G-T86QL960@86YD('=H97)E+"!A<R!W
M96QL(&%S(&AO=R!T:&5Y(&EN=&5R86-T+@H@*@H@*B!!<'!L:6-A=&EO;B!R
M96=I<W1R>0H@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+0H@*B!4:&4@9F]L;&]W
M:6YG('-E='1I;F=S(')E9VES=&5R(&EN<W1A;&QE9"!(;W)D92!A<'!L:6-A
M=&EO;G,N"B`J($)Y(&1E9F%U;'0L($AO<F1E(&%S<W5M97,@=&AA="!T:&4@
M87!P;&EC871I;VX@9&ER96-T;W)I97,@;&EV90H@*B!I;G-I9&4@=&AE(&AO
M<F1E(&1I<F5C=&]R>2X*("H*("H@071T<FEB=71E("`@("!4>7!E("`@("!$
M97-C<FEP=&EO;@H@*B`M+2TM+2TM+2T@("`@("TM+2T@("`@("TM+2TM+2TM
M+2TM"B`J(&9I;&5R;V]T("`@("`@<W1R:6YG("`@5&AE(&)A<V4@9FEL97-Y
M<W1E;2!P871H(&9O<B!T:&4@;6]D=6QE)W,@9FEL97,N"B`J('=E8G)O;W0@
M("`@("`@<W1R:6YG("`@5&AE(&)A<V4@55))(&9O<B!T:&4@;6]D=6QE+@H@
M*B!J<W5R:2`@("`@("`@('-T<FEN9R`@(%1H92!B87-E(%5222!F;W(@<W1A
M=&EC(&IA=F%S8W)I<'0@9FEL97,N"B`J(&IS9G,@("`@("`@("`@<W1R:6YG
M("`@5&AE(&)A<V4@9FEL97-Y<W1E;2!P871H(&9O<B!S=&%T:6,@:F%V87-C
M<FEP="!F:6QE<RX*("H@=&AE;65S=7)I("`@("!S=')I;F<@("!4:&4@8F%S
M92!54DD@9F]R('1H92!T:&5M97,N(%1H:7,@8V%N(&)E('5S960@=&\*("H@
M("`@("`@("`@("`@("`@("`@("`@("!S97)V92!A;&P@:6-O;G,@86YD('-T
M>6QE('-H965T<R!F<F]M(&$@<V5P87)A=&4*("H@("`@("`@("`@("`@("`@
M("`@("`@("!S97)V97(N"B`J('1H96UE<V9S("`@("`@<W1R:6YG("`@5&AE
M(&)A<V4@9FEL92!S>7-T96T@9&ER96-T;W)Y(&9O<B!T:&4@=&AE;65S+@H@
M*B!I8V]N("`@("`@("`@('-T<FEN9R`@(%1H92!54DD@9F]R(&%N(&EC;VX@
M=&\@<VAO=R!I;B!M96YU<R!F;W(@=&AE(&UO9'5L92X*("H@("`@("`@("`@
M("`@("`@("`@("`@("!3971T:6YG('1H:7,@=VEL;"!O=F5R<FED92!T:&4@
M9&5F875L="!T:&5M92UB87-E9`H@*B`@("`@("`@("`@("`@("`@("`@("`@
M(&QO9VEC(&EN('1H92!C;V1E+@H@*B!N86UE("`@("`@("`@('-T<FEN9R`@
M(%1H92!N86UE('5S960@:6X@;65N=7,@86YD(&1E<V-R:7!T:6]N<R!F;W(@
M82!M;V1U;&4*("H@<W1A='5S("`@("`@("!S=')I;F<@("`G:6YA8W1I=F4G
M+"`G:&ED9&5N)RP@)VYO=&]O;&)A<B<L("=H96%D:6YG)RP*("H@("`@("`@
M("`@("`@("`@("`@("`@("`G8FQO8VLG+"`G861M:6XG+"!O<B`G86-T:79E
M)RX*("H@<')O=FED97,@("`@("!S=')I;F<@("!397)V:6-E('1Y<&5S('1H
M92!M;V1U;&4@<')O=FED97,N"B`J(&EN:71I86Q?<&%G92`@<W1R:6YG("`@
M5&AE(&EN:71I86P@*&1E9F%U;'0I('!A9V4@*&9I;&5N86UE*2!F;W(@=&AE
M(&UO9'5L92X*("H@=&5M<&QA=&5S("`@("!S=')I;F<@("!4:&4@9FEL97-Y
M<W1E;2!P871H('1O('1H92!T96UP;&%T97,@9&ER96-T;W)Y+@H@*B!M96YU
M7W!A<F5N="`@('-T<FEN9R`@(%1H92!N86UE(&]F('1H92`G:&5A9&EN9R<@
M9W)O=7`@=&AA="!T:&ES(&%P<"!S:&]U;&0*("H@("`@("`@("`@("`@("`@
M("`@("`@("!S:&]W('5P('5N9&5R+@H@*B!T87)G970@("`@("`@('-T<FEN
M9R`@(%1H92`H;W!T:6]N86PI('1A<F=E="!F<F%M92!F;W(@=&AE(&QI;FLN
M"B`J('5R;"`@("`@("`@("`@<W1R:6YG("`@5&AE("AO<'1I;VYA;"D@55),
M(&]F("=H96%D:6YG)R!E;G1R:65S+@H@*B\*"B\O(%=E('1R>2!T;R!A=71O
M;6%T:6-A;&QY(&1E=&5R;6EN92!T:&4@<')O<&5R('=E8G)O;W0@9F]R($AO
M<F1E"B\O(&AE<F4N(%1H:7,@<W1I;&P@87-S=6UE<R!T:&%T(&%P<&QI8V%T
M:6]N<R!L:79E('5N9&5R(&AO<F1E+RX@268*+R\@=&AI<R!R97-U;'1S(&EN
M(&EN8V]R<F5C="!R97-U;'1S(&9O<B!Y;W4L('-I;7!L>2!C:&%N9V4@=&AE
M('1W;PHO+R!U<V5S(&]F('1H92`D=V5B<F]O="!V87)I86)L92!I;B!T:&4@
M)VAO<F1E)R!S=&%N>F$@8F5L;W<N"B\O"B\O($YO=&4@9F]R(%=I;F1O=W,@
M=7-E<G,Z('1H92!B96QO=R!A<W-U;65S('1H870@>6]U<B!02%!?4T5,1@HO
M+R!V87)I86)L92!U<V5S(&9O<G=A<F0@<VQA<VAE<RX@268@:70@9&]E<R!N
M;W0L('EO=2=L;"!H879E('1O('1W96%K"B\O('1H:7,N"FEF("AI<W-E="@D
M7U-%4E9%4ELG4$A07U-%3$8G72DI('L*("`@("1W96)R;V]T(#T@<')E9U]S
M<&QI="@G.R\[)RP@)%]315)615);)U!(4%]314Q&)UTL(#(L(%!214=?4U!,
M251?3D]?14U05%DI.PH@("`@)'=E8G)O;W0@/2!S=')S='(H9&ER;F%M92A?
M7T9)3$5?7RDL($1)4D5#5$]265]315!!4D%43U(@+B!A<G)A>5]S:&EF="@D
M=V5B<F]O="DI.PH@("`@:68@*"1W96)R;V]T("$]/2!F86QS92D@>PH@("`@
M("`@("1W96)R;V]T(#T@<')E9U]R97!L86-E*&%R<F%Y*"<O7%Q<7"\G+"`G
M.R]C;VYF:6<D.R<I+"!A<G)A>2@G+R<L("<G*2P@)'=E8G)O;W0I.PH@("`@
M?2!E;'-E:68@*"1W96)R;V]T(#T]/2!F86QS92D@>PH@("`@("`@("1W96)R
M;V]T(#T@)R<["B`@("!](&5L<V4@>PH@("`@("`@("1W96)R;V]T(#T@)R]H
M;W)D92<["B`@("!]"GT@96QS92!["B`@("`D=V5B<F]O="`]("<O:&]R9&4G
M.PI]"@HD=&AI<RT^87!P;&EC871I;VYS6R=H;W)D92==(#T@87)R87DH"B`@
M("`G9FEL97)O;W0G(#T^("<O=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4G+`H@
M("`@)W=E8G)O;W0G(#T^("1W96)R;V]T+`H@("`@)VEN:71I86Q?<&%G92<@
M/3X@)VQO9VEN+G!H<"<L"B`@("`G;F%M92<@/3X@7R@B2&]R9&4B*2P*("`@
M("=S=&%T=7,G(#T^("=A8W1I=F4G+`H@("`@)W1E;7!L871E<R<@/3X@)R]U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,G+`H@("`@)W!R;W9I
M9&5S)R`]/B`G:&]R9&4G"BD["@HO*B`*("H@2&%C:R!T;R!M86ME(')E9VES
M=&5R:6YG(&]F('!A8VMA9V5S(&5A<WD@=VET:&]U="!E9&ET:6YG"B`J(&-O
M;F9I9W5R871I;VX@9FEL97,L('-T;VQE;B!F<F]M($1E8FEA;@H@*B\*"FEF
M("@D9"`]($!O<&5N9&ER*"<O=7-R+VQO8V%L+W!S82]E=&,O<'-A+6AO<F1E
M+VAO<F1E+W)E9VES=')Y+F0G*2D@>PH@("`@=VAI;&4@*"1F(#T@<F5A9&1I
M<B@D9"DI('L@"B`@("`@("`@:68@*&5R96<H(BYP:'`D(BP@)&8I*2!["B`@
M("`@("`@("`@(&EN8VQU9&5?;VYC92`G+R]U<W(O;&]C86PO<'-A+V5T8R]P
M<V$M:&]R9&4O:&]R9&4O<F5G:7-T<GDN9"\G("X@)&8["B`@("`@("`@?0H@
M("`@?0H@("`@8VQO<V5D:7(H)&0I.PI]"@``````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O971C+W!S82UH;W)D92]H;W)D92]H;V]K<RYP:'``````````````
M````````````````````````````````````````````````````````````
M```P,#`T-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$R,C,R,"`Q,#4Q-30S
M-#$U,B`P,C$R-#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($AO<F1E($AO;VMS(&-O;F9I9W5R871I
M;VX@9FEL92X*("H*("H@5$A%($A/3TM3(%!23U9)1$5$($E.(%1(25,@1DE,
M12!!4D4@15A!35!,15,@3TY,62X@($1/($Y/5"!%3D%"3$4@5$A%30H@*B!"
M3$E.1$Q9($E&(%E/52!$3R!.3U0@2TY/5R!72$%4(%E/52!!4D4@1$])3D<N
M("!93U4@2$%612!43R!#55-43TU)6D4@5$A%30H@*B!43R!-051#2"!93U52
M(%-014-)1DE#($Y%1413($%.1"!365-414T@14Y625)/3DU%3E0N"B`J"B`J
M(%1H:7,@9FEL92!I<R!W:&5R92!Y;W4@9&5F:6YE(&%N>2!H;V]K<RP@9F]R
M('!R969E<F5N8V5S(&]R(&=E;F5R86P@2&]R9&4*("H@=7-E+"!T:&%T('EO
M=7(@:6YS=&%L;&%T:6]N('5S97,N(%1H92!F=6YC=&EO;G,@:6X@=&AI<R!F
M:6QE(&-A;B!V87-T;'D*("H@8VAA;F=E(&AO=R!Y;W5R(&EN<W1A;&QA=&EO
M;B!B96AA=F5S+"!S;R!M86ME('-U<F4@=&\@=&5S="!O=70@86YY(&-H86YG
M97,*("H@:&5R92!B969O<F4@9&]I;F<@=&AE;2!I;B!A('!R;V1U8W1I;VX@
M96YV:7)O;FUE;G0N"B`J"B`J($AO;VL@9G5N8W1I;VX@;F%M97,@87)E(&%U
M=&]M871I8V%L;'D@9&5T97)M:6YE9"X@5&AE(&9O<FUA="!O9B!T:&4@;F%M
M90H@*B!I<SH*("H*("H@7SQT>7!E(&]F(&AO;VL^7VAO;VM?/&YA;64@;V8@
M:&]O:SXN"B`J"B`J(%1Y<&5S(&]F(&AO;VMS('1H870@87)E(&1E9FEN960@
M:6X@=&AI<R!F:6QE(&%R92`G<')E9G,G("AH;V]K<R!T;R!S970@=&AE"B`J
M('9A;'5E(&]F('!R969E<F5N8V5S*2P@)VAO<F1E)R`H:&]O:W,@9F]R('1H
M92!(;W)D92!&<F%M97=O<FL@<V-R:7!T<RD@86YD"B`J("=A<'`G("AW:&5R
M92!A<'`@:7,@86YY($AO<F1E(&%P<&QI8V%T:6]N(&YA;64L(&QI:V4@)VEM
M<"<I(&AO;VMS('1H870@87)E"B`J(&%P<&QI8V%T:6]N('-P96-I9FEC+@H@
M*@H@*B!3;RP@82!H;V]K('1O('-E="!T:&4@<')E9F5R96YC92`G=&AE;64G
M('=O=6QD(&)E(&YA;65D"B`J(")?<')E9G-?:&]O:U]T:&5M92(N"B`J"B`J
M($Y/5$4@,3H@2&%V:6YG(&$@:&]O:R!F=6YC=&EO;B!I;B!T:&ES(&9I;&4@
M9&]E<R!.3U0@;65A;B!T:&%T('1H92!H;V]K"B`J('=I;&P@875T;VUA=&EC
M86QL>2!B92!U<V5D+B!93U4@35535"!E;F%B;&4@=&AE(&AO;VLN($9O<B!P
M<F5F97)E;F-E<RP@<V5T"B`J("=H;V]K)R`]/B!T<G5E(&EN('1H870@<')E
M9F5R96YC97,@871T<FEB=71E<SL@9F]R(&]T:&5R(&AO;VMS+"!T:&5R92!W
M:6QL"B`J(&)E(&$@8V]N9FEG=7)A=&EO;B!O<'1I;VX@:6X@96%C:"!A<'!L
M:6-A=&EO;B=S(&-O;F8N<&AP(&9I;&4@<W5C:"!A<PH@*B`D8V]N9ELG:&]O
M:W,G75LG:&]O:VYA;64G72!W:&EC:"!M=7-T(&)E('-E="!T;R!T<G5E+@H@
M*@H@*B!.3U1%(#(Z(%!R969E<F5N8V5S(&AO;VMS(&%R92!/3DQ9(&5X96-U
M=&5D(&]N(&QO9VEN+B!0<F5F97)E;F-E<R!A<F4*("H@8V%C:&5D(&1U<FEN
M9R!A('5S97)S('-E<W-I;VX@86YD+"!T;R!A=F]I9"!U;FYE8V5S<V%R>2!O
M=F5R:&5A9"!E=F5R>2!T:6UE"B`J(&$@<')E9F5R96YC92!I<R!A8V-E<W-E
M9"P@=&AE(')E<W5L=',@;V8@:&]O:W,@87)E(&-A8VAE9"!A<R!W96QL+B!4
M:&ES"B`J(&QE861S('1O("XN+@H@*@H@*B!.3U1%(#,Z($%N>2!P<F5F97)E
M;F-E('1H870@:7,@3D]4($Q/0TM%1"P@=&AA="!I<R!S970@8GD@82!H;V]K
M+"!724Q,($)%"B`J(%-!5D5$(%=)5$@@5$A!5"!604Q512X@5&AI<R!M96%N
M<R!S979E<F%L('1H:6YG<SH*("H@,2D@57-E<G,@=VEL;"!G970@=&AE(')E
M<W5L=',@;V8@=&AE(&AO;VL@<V5T(&9O<B!T:&5M(&EN('1H96ER"B`J("`@
M('!R969E<F5N8V5S+@H@*B`R*2!">2!V:7)T=64@;V8@=&AI<RP@=&AE(&YE
M>'0@=&EM92!T:&5Y(&QO9R!I;B!A;F0@;&]A9"!T:&5I<@H@*B`@("!P<F5F
M97)E;F-E<RP@=&AE(&AO;VL@=VEL;"!.3U0@8F4@8V%L;&5D+"!B96-A=7-E
M(&EN('1H96ER(&QA<W0@<V5S<VEO;BP*("H@("`@=V4@<V%V960@=&AE(')E
M<W5L=',@;V8@=&AE(&AO;VL@9F]R('1H96TN($AO=V5V97(L(&EF('1H92!P
M<F5F97)E;F-E(&ES"B`J("`@(&QO8VME9"P@=&AE(')E<W5L="!O9B!T:&4@
M:&]O:R!W:6QL(&YE=F5R(&)E('-A=F5D+@H@*@H@*B`D2&]R9&4Z(&AO<F1E
M+V-O;F9I9R]H;V]K<RYP:'`N9&ES="QV(#$N-S,N-BXQ,R`R,#`V+S`U+S(S
M(#`R.C$S.C0R('-E;'-K>2!%>'`@)`H@*B\*"B\O($5X86UP;&4@=&AE;64@
M:&]O:R!F=6YC=&EO;BX@5&AI<R!S:&]W<R!H;W<@>6]U(&-A;B!A8V-E<W,@
M=&AI;F=S(&QI:V4@=&AE"B\O(&-U<G)E;G1L>2!L;V=G960@:6X@=7-E<BP@
M9VQO8F%L('9A<FEA8FQE<RP@<V5R=F5R(&-O;F9I9RP@971C+B!)="!I<VXG
M="P*+R\@:&]W979E<BP@<V]M971H:6YG('EO=2!P<F]B86)L>2!W86YT('1O
M(&%C='5A;&QY('5S92!I;B!P<F]D=6-T:6]N+"!B>0HO+R!V:7)T=64@;V8@
M9&5M;VYS=')A=&EN9R!A;&P@=&AO<V4N(#HI"@HO+R!I9B`H(69U;F-T:6]N
M7V5X:7-T<R@G7W!R969S7VAO;VM?=&AE;64G*2D@>PHO+R`@("`@9G5N8W1I
M;VX@7W!R969S7VAO;VM?=&AE;64H)'5S97)N86UE(#T@;G5L;"D*+R\@("`@
M('L*+R\@("`@("`@("!I9B`H075T:#HZ9V5T075T:"@I("$]("=C:'5C:R<I
M('L*+R\@("`@("`@("`@("`@<F5T=7)N("=M;WII;&QA)SL*+R\@("`@("`@
M("!]"B\O"B\O("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*+R\@("`@("`@
M("!S=VET8V@@*"1R96=I<W1R>2T^9V5T07!P*"DI('L*+R\@("`@("`@("!C
M87-E("=I;7`G.@HO+R`@("`@("`@("`@("!R971U<FX@)V)R;W=N)SL*+R\*
M+R\@("`@("`@("!C87-E("=T=7)B82<Z"B\O("`@("`@("`@("`@(')E='5R
M;B`G;W)A;F=E)SL*+R\*+R\@("`@("`@("!C87-E("=K<F]N;VQI=&@G.@HO
M+R`@("`@("`@("`@("!R971U<FX@)V=R965N)SL*+R\*+R\@("`@("`@("!D
M969A=6QT.@HO+R`@("`@("`@("`@("!R971U<FX@)R<["B\O("`@("`@("`@
M?0HO+R`@("`@?0HO+R!]"@HO+R!%>&%M<&QE(&9R;VU?861D<B!H;V]K(&9U
M;F-T:6]N+B!42$E3($953D-424].($%34U5-15,@5$A!5"!93U4@05)%(%53
M24Y'"B\O($%.($Q$05`@4T525D52(&%N9"!T:&%T('EO=7(@+V5T8R]L9&%P
M+F-O;F8@;W(@=VAE<F5V97(@:70@:7,@8V]R<F5C=&QY('-E=`HO+R!T;R!A
M('9A;&ED(&AO<W0N"B\O"B\O(%EO=2!G970@<&%S<V5D($Y/5$A)3D<[('EO
M=2!A<F4@<F5S<&]N<VEB;&4@9F]R(&)R:6YG:6YG(&EN('1O('-C;W!E(&%N
M>0HO+R!I;F9O<FUA=&EO;B!Y;W4@;F5E9"X@66]U(&-A;B`B9VQO8F%L(B!A
M;GET:&EN9R!E;'-E('EO=2!N965D+B!2971U<FX@86X*+R\@861D<F5S<R`M
M(&5I=&AE<B!J=7-T('1H92!U<V5R0"!S:61E(&]R(&$@9G5L;"!A9&1R97-S
M("T@86YD(&ET('=I;&P@8F4*+R\@=7-E9"X*+R\*+R\@268@>6]U('=A;G0@
M=&\@=7-E('1H:7,@8V]D92!Y;W4@=VEL;"!N965D('1O('5N8V]M;65N="!I
M="!B96QO=RX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?<')E9G-?:&]O
M:U]F<F]M7V%D9'(G*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!R969S7VAO;VM?
M9G)O;5]A9&1R*"1N86UE(#T@;G5L;"D*+R\@("`@('L*+R\@("`@("`@("!I
M9B`H:7-?;G5L;"@D;F%M92DI('L*+R\@("`@("`@("`@("`@)&YA;64@/2!!
M=71H.CIG971!=71H*"D["B\O("`@("`@("`@?0HO+R`@("`@("`@(&EF("@A
M96UP='DH)&YA;64I*2!["B\O("`@("`@("`@("`@("1B87-E7V-O;G1E>'0@
M/2`G;SUM>6]R9R<["B\O("`@("`@("`@("`@("1S8V]P92`]("=S=6(G.PHO
M+PHO+R`@("`@("`@("`@("`O+R!9;W4@=VEL;"!P<F]B86)L>2!N965D('1O
M(')E<&QA8V4@8V0]('=I=&@@=6ED/3L@=&AI<PHO+R`@("`@("`@("`@("`O
M+R!S>6YT87@@:7,@9F]R($YE='=A<F4@-2XQ(&YL9&%P+@HO+R`@("`@("`@
M("`@("`D8VUD("`]("<O=7-R+V)I;B]L9&%P<V5A<F-H("UB("<@+B`D8F%S
M95]C;VYT97AT("X@)R`M<R`G("X@)'-C;W!E("X@)R!C;CTG.PHO+R`@("`@
M("`@("`@("`D8VUD("X](&5S8V%P95-H96QL0VUD*$%U=&@Z.F=E=$%U=&@H
M*2D["B\O("`@("`@("`@("`@("1C;60@+CT@)R!\("]U<W(O8FEN+V=R97`@
M;6%I;"!\("]U<W(O8FEN+V%W:R!<)WMP<FEN="`D,GU<)R<["B\O("`@("`@
M("`@("`@("1M86EL<R`](&`D8VUD8#L*+R\@("`@("`@("`@("`@)&UA:6Q?
M87)R87D@/2!E>'!L;V1E*")<;B(L("1M86EL<RD["B\O"B\O("`@("`@("`@
M("`@("\O(%-E;F0@8F%C:R!T:&4@9FER<W0@96UA:6P@9F]U;F0L(&YO="!T
M:&4@=VAO;&4@;&ES="X*+R\@("`@("`@("`@("`@)&UA:6P@/2`D;6%I;%]A
M<G)A>5LG,"==.PHO+PHO+R`@("`@("`@("`@("`O+R!)9B!N;R!E;6%I;"!A
M9&1R97-S(&ES(&9O=6YD+"!T:&5N('1H92!L;V=I;B!N86UE('=I;&P*+R\@
M("`@("`@("`@("`@+R\@8F4@=7-E9"X*+R\@("`@("`@("`@("`@<F5T=7)N
M("AE;7!T>2@D;6%I;"D@/R`G)R`Z("1M86EL*3L*+R\@("`@("`@("!]"B\O
M"B\O("`@("`@("`@<F5T=7)N("<G.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E
M(&ES(&%N;W1H97(@=V%Y(&]F(&1O:6YG('1H92!S86UE('1H:6YG+@H*+R\@
M:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7V9R;VU?861D<B<I
M*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?:&]O:U]F<F]M7V%D9'(H)'5S
M97(@/2!N=6QL*0HO+R`@("`@>PHO+R`@("`@("`@("1L9&%P4V5R=F5R(#T@
M)S$W,BXS,2XP+C(S-B<["B\O("`@("`@("`@)&QD87!0;W)T(#T@)S,X.2<[
M"B\O("`@("`@("`@)'-E87)C:$)A<V4@/2`G;SUM>6]R9R<["B\O"B\O("`@
M("`@("`@)&1S(#T@0&QD87!?8V]N;F5C="@D;&1A<%-E<G9E<BP@)&QD87!0
M;W)T*3L*+R\*+R\@("`@("`@("!I9B`H:7-?;G5L;"@D=7-E<BDI('L*+R\@
M("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!=71H*"D["B\O("`@("`@
M("`@?0HO+PHO+R`@("`@("`@("\O(%EO=2!W:6QL('!R;V)A8FQY(&YE960@
M=&\@<F5P;&%C92!C;CT@=VET:"!U:60].R!T:&ES"B\O("`@("`@("`@+R\@
M<WEN=&%X(&ES(&9O<B!.971W87)E(#4N,2!N;&1A<"X*+R\@("`@("`@("`D
M<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H*"1D<RP@)'-E87)C:$)A<V4L
M("=C;CTG("X@)'5S97(I.PHO+R`@("`@("`@("1I;F9O<FUA=&EO;B`]($!L
M9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L="D["B\O("`@("`@
M("`@:68@*"1I;F9O<FUA=&EO;ELP75LG;6%I;"==6S!=("$]("<G*2!["B\O
M("`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N6S!=6R=M86EL)UU;
M,%T["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@)&YA;64@
M/2`D:6YF;W)M871I;VY;,%U;)V-N)UU;,%T["B\O("`@("`@("`@?0HO+PHO
M+R`@("`@("`@(&QD87!?8VQO<V4H)&1S*3L*+R\*+R\@("`@("`@("!R971U
M<FX@*&5M<'1Y*"1N86UE*2`_("1U<V5R(#H@)&YA;64I.PHO+R`@("`@?0HO
M+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@9G5L;&YA;64@:&]O:R!F=6YC
M=&EO;B!T;R!S970@=&AE(&9U;&QN86UE(&9R;VT@=&AE($=%0T]3"B\O(&EN
M9F]R;6%T:6]N(&EN('1H92!P87-S=V0@9FEL92X*"B\O(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"=?<')E9G-?:&]O:U]F=6QL;F%M92<I*2!["B\O("`@("!F
M=6YC=&EO;B!?<')E9G-?:&]O:U]F=6QL;F%M92@D=7-E<B`](&YU;&PI"B\O
M("`@("!["B\O("`@("`@("`@:68@*&ES7VYU;&PH)'5S97(I*2!["B\O("`@
M("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T0F%R94%U=&@H*3L*+R\@("`@
M("`@("!]"B\O("`@("`@("`@)&%R<F%Y(#T@<&]S:7A?9V5T<'=N86TH)'5S
M97(I.PHO+R`@("`@("`@("1G96-O<U]A<G)A>2`](&5X<&QO9&4H)RPG+"`D
M87)R87E;)V=E8V]S)UTI.PHO+R`@("`@("`@(')E='5R;B`H96UP='DH)&=E
M8V]S7V%R<F%Y*2`_("1U<V5R(#H@)&=E8V]S7V%R<F%Y6S!=*3L*+R\@("`@
M('T*+R\@?0H*+R\@5&AI<R!I<R!A;F]T:&5R(&5X86UP;&4@;V8@:&]W('1O
M(&=E="!T:&4@=7-E<B=S(&9U;&P@;F%M92P@:6X@=&AI<R!C87-E"B\O(&9R
M;VT@86X@;&1A<"!S97)V97(N($EN('1H:7,@97AA;7!L92!W92!L;V]K(&EF
M(&$@4W!A;FES:"!N86UE(&5X:7-T<R!A;F0*+R\@<F5T=7)N('1H:7,@;W(@
M=&AE('-T86YD87)D("=C;B<@96YT<GD@:68@;F]T+@H*+R\@:68@*"%F=6YC
M=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7V9U;&QN86UE)RDI('L*+R\@("`@
M(&9U;F-T:6]N(%]P<F5F<U]H;V]K7V9U;&QN86UE*"1U<V5R(#T@;G5L;"D*
M+R\@("`@('L*+R\@("`@("`@("`D;&1A<%-E<G9E<B`]("=L9&%P+F5X86UP
M;&4N8V]M)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y)SL*+R\@("`@
M("`@("`D<V5A<F-H0F%S92`]("=O=3UP96]P;&4L;SUE>&%M<&QE+F-O;2<[
M"B\O("`@("`@("`@)&QD87!C:&%R<V5T(#T@)W5T9BTX)SL*+R\@("`@("`@
M("`D;W5T<'5T8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PHO+PHO+R`@
M("`@("`@("1D<R`]($!L9&%P7V-O;FYE8W0H)&QD87!397)V97(L("1L9&%P
M4&]R="D["B\O"B\O("`@("`@("`@:68@*&ES7VYU;&PH)'5S97(I*2!["B\O
M("`@("`@("`@("`@("1U<V5R(#T@075T:#HZ9V5T075T:"@I.PHO+R`@("`@
M("`@('T*+R\@("`@("`@("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H
M*"1D<RP@)'-E87)C:$)A<V4L("=U:60])R`N("1U<V5R*3L*+R\@("`@("`@
M("`D:6YF;W)M871I;VX@/2!`;&1A<%]G971?96YT<FEE<R@D9',L("1S96%R
M8VA297-U;'0I.PHO+R`@("`@("`@(&EF("@D:6YF;W)M871I;VY;,%U;)V-N
M.VQA;F<M97,G75LP72`A/2`G)RD@>PHO+R`@("`@("`@("`@("`D;F%M92`]
M("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=.PHO+R`@("`@("`@
M('T@96QS92!["B\O("`@("`@("`@("`@("1N86UE(#T@)&EN9F]R;6%T:6]N
M6S!=6R=C;B==6S!=.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!L9&%P
M7V-L;W-E*"1D<RD["B\O"B\O("`@("`@("`@)&YA;64@/2!3=')I;F<Z.F-O
M;G9E<G1#:&%R<V5T*"1N86UE+"`D;&1A<&-H87)S970L("1O=71P=71C:&%R
M<V5T*3L*+R\@("`@("`@("!R971U<FX@*&5M<'1Y*"1N86UE*2`_("1U<V5R
M(#H@)&YA;64I.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP
M;&4@<VEG;F%T=7)E(&AO;VL@9G5N8W1I;VX@=&\@<V5T('1H92!S:6=N871U
M<F4@9G)O;2!T:&4*+R\@<WES=&5M('1A9VQI;F5S(&9I;&4[('1H92!S=')I
M;F<@(B5404<E(B`H:68@<')E<V5N="!I;B!A('5S97(G<R!S:6=N871U<F4I
M"B\O('=I;&P@8F4@<F5P;&%C960@8GD@=&AE(&-O;G1E;G0@;V8@=&AE(&9I
M;&4@(B]U<W(O<VAA<F4O=&%G;&EN92(@*&=E;F5R871E9`HO+R!B>2!T:&4@
M(E1A4E0B('5T:6QI='DI+@HO+PHO+R!.;W1I8V4@:&]W('=E(&=L;V)A;"!I
M;B!T:&4@)'!R969S(&%R<F%Y('1O(&=E="!T:&4@=7-E<B=S(&-U<G)E;G0*
M+R\@<VEG;F%T=7)E+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P<F5F
M<U]H;V]K7W-I9VYA='5R92<I*2!["B\O("`@("!F=6YC=&EO;B!?<')E9G-?
M:&]O:U]S:6=N871U<F4H)'5S97)N86UE(#T@;G5L;"D*+R\@("`@('L*+R\@
M("`@("`@("`D<VEG(#T@)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=S
M:6=N871U<F4G*3L*+R\@("`@("`@("!I9B`H<')E9U]M871C:"@G+R5404<E
M+R<L("1S:6<I*2!["B\O("`@("`@("`@("`@("1T86<@/2!@8V%T("]U<W(O
M<VAA<F4O=&%G;&EN96`["B\O("`@("`@("`@("`@("1S:6<@/2!P<F5G7W)E
M<&QA8V4H)WPE5$%')7PG+"`D=&%G+"`D<VEG*3L*+R\@("`@("`@("!]"B\O
M("`@("`@("`@<F5T=7)N("1S:6<["B\O("`@("!]"B\O('T*"B\O($E%(&]N
M($UA8R!H86YG<R!W:&5N('1H97)E(&%R92!S979E<F%L(&EC;VYS('1O(&)E
M(&QO861E9"X@070@;&5A<W0@;VX@<V]M90HO+R!S>7-T96US+B!4:&ES(&AO
M;VL@9&ES86)L97,@=&AE('-H;W=?:6-O;G,@<')E9F5R96YC92!F<F]M($MR
M;VYO;FQI=&@@9F]R"B\O('1H97-E(&)R;W=S97)S+@H*+R\@:68@*"%F=6YC
M=&EO;E]E>&ES=',H)U]P<F5F<U]H;V]K7W-H;W=?:6-O;G,G*2D@>PHO+R`@
M("`@9G5N8W1I;VX@7W!R969S7VAO;VM?<VAO=U]I8V]N<R@I"B\O("`@("![
M"B\O("`@("`@("`@9VQO8F%L("1B<F]W<V5R.PHO+R`@("`@("`@(&EF("@D
M8G)O=W-E<BT^9V5T4&QA=&9O<FTH*2`]/2`G;6%C)R`F)@HO+R`@("`@("`@
M("`@("`D8G)O=W-E<BT^9V5T0G)O=W-E<B@I(#T]("=M<VEE)RD@>PHO+R`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B\O("`@("`@("`@?2!E;'-E('L*
M+R\@("`@("`@("`@("`@<F5T=7)N('1R=64["B\O("`@("`@("`@?0HO+R`@
M("`@?0HO+R!]"@HO+R!4:&ES(&AO;VL@:7,@8V%L;&5D('=H96X@82!U<V5R
M('-U8FUI=',@82!S:6=N=7`@<F5Q=65S="X@($ET(&%L;&]W<PHO+R!A(&-H
M86YC92!T;R!A;'1E<B!O<B!V86QI9&%T92!T:&4@9&%T82!S=6)M:71T960@
M8GD@82!U<V5R(&)E9F]R92!A;GD*+R\@871T96UP=',@87)E(&UA9&4@=&\@
M861D('1H96T@=&\@=&AE('-Y<W1E;2X*"B\O(&EF("@A9G5N8W1I;VY?97AI
M<W1S*"=?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S<R<I*2!["B\O("`@
M("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S<R@D:6YF
M;RD@>PHO+R`@("`@("`@("1I;F9O6R=U<V5R7VYA;64G72`](%-T<FEN9SHZ
M;&]W97(H)&EN9F];)W5S97)?;F%M92==*3L*+R\@("`@("`@("!R971U<FX@
M)&EN9F\["B\O("`@("!]"B\O('T*"B\O(%1H:7,@:&]O:R!I<R!C86QL960@
M=VAE;B!A('-I9VYU<"!I<R!Q=65U960@9F]R(&%D;6EN:7-T<F%T:79E(&%P
M<')O=F%L+@HO+R!4:&ES(&5X86UP;&4@<V5N9',@82!N;W1I9FEC871I;VX@
M;65S<V%G92!T;R!T:&4@=V5B('-E<G9E<@HO+R!A9&UI;FES=')A=&]R)W,@
M92UM86EL(&%D9')E<W,N"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO
M<F1E7VAO;VM?<VEG;G5P7W%U975E9"<I*2!["B\O("`@("!F=6YC=&EO;B!?
M:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D7W=A;&MD871A*"1F:65L9',L("1D
M871A*0HO+R`@("`@>PHO+R`@("`@("`@("1M<V<@/2`G)SL*+R\@("`@("`@
M("!F;W)E86-H("@D9&%T82!A<R`D9FEE;&0@/3X@)'9A;'5E*2!["B\O("`@
M("`@("`@("`@(&EF("@D9FEE;&0@/3T@)W!A<W-W;W)D)R!\?"`D9FEE;&0@
M/3T@)W5R;"<I('L*+R\@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PHO+R`@
M("`@("`@("`@("!]"B\O"B\O("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M=F%L=64I*2!["B\O("`@("`@("`@("`@("`@("`D;7-G("X](%]H;W)D95]H
M;V]K7W-I9VYU<%]Q=65U961?=V%L:V1A=&$H)&9I96QD<RP@)'9A;'5E*3L*
M+R\@("`@("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@("`@("1F
M:65L9"`](&ES<V5T*"1F:65L9'-;)&9I96QD75LG;&%B96PG72D@/PHO+R`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD<ULD9FEE;&1=6R=L86)E
M;"==(#H@)&9I96QD.PHO+R`@("`@("`@("`@("`@("`@)&US9R`N/2`B)&9I
M96QD.B`D=F%L=65<;B(["B\O("`@("`@("`@("`@('T*+R\@("`@("`@("!]
M"B\O("`@("`@("`@<F5T=7)N("1M<V<["B\O("`@("!]"B\O"B\O("`@("!F
M=6YC=&EO;B!?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D*"1U<V5R240L("1D
M871A*0HO+R`@("`@>PHO+R`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"YP
M:'`G.PHO+R`@("`@("`@(&=L;V)A;"`D8V]N9BP@)')E9VES=')Y.PHO+PHO
M+R`@("`@("`@("1H96%D97)S(#T@87)R87DH"B\O("`@("`@("`@("`@("=4
M;R<@("`@("`]/B`D7U-%4E9%4ELG4T525D527T%$34E.)UTL"B\O("`@("`@
M("`@("`@("=&<F]M)R`@("`]/B`D7U-%4E9%4ELG4T525D527T%$34E.)UTL
M"B\O("`@("`@("`@("`@("=3=6)J96-T)R`]/B`G3F5W("<@+B`D<F5G:7-T
M<GDM/F=E="@G;F%M92<L("=H;W)D92<I("X@)R!3:6=N=7`G"B\O("`@("`@
M("`@*3L*+R\*+R\@("`@("`@("`D97AT<F%&:65L9',@/2!(;W)D93HZ8V%L
M;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]G971E>'1R82<I.PHO+PHO+R`@
M("`@("`@("1M<V<@(#T@7R@B02!N97<@<VEG;G5P(&AA<R!B965N(')E8V5I
M=F5D(&%N9"!I<R!A=V%I=&EN9R!Y;W5R(&%P<')O=F%L+B(I.PHO+R`@("`@
M("`@("1M<V<@+CT@(EQN7&XB.PHO+R`@("`@("`@("1M<V<@+CT@7VAO<F1E
M7VAO;VM?<VEG;G5P7W%U975E9%]W86QK9&%T82@D97AT<F%&:65L9',L("1D
M871A*3L*+R\@("`@("`@("`D;7-G("X](")<;B(["B\O("`@("`@("`@)&US
M9R`N/2!S<')I;G1F*%\H(EEO=2!C86X@87!P<F]V92!T:&ES('-I9VYU<"!A
M="`E<R(I+"!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W5S97(N<&AP
M)RP@=')U92P@+3$I*3L*+R\*+R\@("`@("`@("`D;6%I;&5R(#T@36%I;#HZ
M9F%C=&]R>2@D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72P@)&-O;F9;)VUA:6QE
M<B==6R=P87)A;7,G72D["B\O("`@("`@("`@<F5T=7)N("1M86EL97(M/G-E
M;F0H)%]315)615);)U-%4E9%4E]!1$U)3B==+"`D:&5A9&5R<RP@)&US9RD[
M"B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?:&]R9&5?
M:&]O:U]S:6=N=7!?9V5T97AT<F$@9G5N8W1I;VXN($ET(')E='5R;G,@86YY
M"B\O(&5X=')A(&9I96QD<R!W:&EC:"!N965D('1O(&)E(&9I;&QE9"!I;B!W
M:&5N(&$@;F]N(')E9VES=&5R960@=7-E<B!W:7-H97,*+R\@=&\@<VEG;B!U
M<"X*+R\@5&AE(&5X86UP;&4@:&5R92!T86ME<R!T:&4@:'EP;W1H971I8V%L
M(&-A<V4@=VAE<F4@=V4@=V]U;&0@=V%N="!T;R!S=&]R90HO+R!E>'1R82!I
M;F9O<FUA=&EO;B!A8F]U="!A('5S97(@:6YT;R!A('1U<F)A('-Q;"!A9&1R
M97-S(&)O;VLN($%L;"!T:&ES"B\O(&9U;F-T:6]N(&1O97,@=&AE;B!I<R!T
M;R!I;F-L=61E('1H92!A='1R:6)U=&5S+G!H<"!F:6QE(&9R;VT@=&AE('1U
M<F)A"B\O(&-O;F9I9R!D:7)E8W1O<GD@86YD(')E='5R;B!T:&4@)&%T=')I
M8G5T97,@87)R87DN"B\O($]T:&5R=VES92!A;GD@<W1R=6-T=7)E('1H870@
M=V]U;&0@<F5T=7)N(&%N(&%R<F%Y('=I=&@@=&AE(&9O;&QO=VEN9PHO+R!S
M>6YT87@@=V]U;&0@8F4@=F%L:60Z"B\O("`@)'-O;65A<G)A>5LG<V]M969I
M96QD;F%M92==(#T@87)R87DH+BXN"B\O("`@("`@;&%B96P@("`@+2!T:&4@
M=&5X="!T:&%T('1H92!U<V5R('=I;&P@<V5E(&%T=&%C:&5D('1O('1H:7,@
M9FEE;&0*+R\@("`@("!T>7!E("`@("`M(&%N>2!A;&QO=V5D($AO<F1E7T9O
M<FT@9FEE;&0@='EP90HO+R`@("`@('!A<F%M<R`@("T@86YY(&%L;&]W960@
M<&%R86UE=&5R('1O($AO<F1E7T9O<FT@9FEE;&0@='EP97,*+R\@("`@("!R
M97%U:7)E9"`M(&)O;VQE86XL('1R=64@;W(@9F%L<V4@=VAE=&AE<B!T:&ES
M(&9I96QD(&ES(&UA;F1A=&]R>0HO+R`@("`@(')E861O;FQY("T@8F]O;&5A
M;BP@=')U92!O<B!F86QS92!W:&5T:&5R('1H:7,@961I=&%B;&4*+R\@("`@
M("!D97-C("`@("`M(&%N>2!H96QP('1E>'0@871T86-H960@=&\@=&AE(&9I
M96QD"B\O($Y/5$4Z(%EO=2!$3R!.145$(%1U<F)A('1O(&)E(&-O<G)E8W1L
M>2!I;G-T86QL960@8F5F;W)E('EO=2!C86X@=7-E('1H:7,*+R\@97AA;7!L
M92!B96QO=RX*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O
M:U]S:6=N=7!?9V5T97AT<F$G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E
M7VAO;VM?<VEG;G5P7V=E=&5X=')A*"D*+R\@("`@('L*+R\@("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PHO+R`@("`@("`@(')E<75I<F4@)')E9VES=')Y
M+3YG970H)V9I;&5R;V]T)RP@)W1U<F)A)RD@+B`G+V-O;F9I9R]A='1R:6)U
M=&5S+G!H<"<["B\O("`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PHO+R`@
M("`@?0HO+R!]"@HO+R!&;VQL;W=I;F<@;VX@9G)O;2!T:&4@97AA;7!L92!I
M;B!T:&4@86)O=F4@9G5N8W1I;VXL('1H:7,@:7,@:&]W(&$@<V%M<&QE"B\O
M(%]H;W)D95]H;V]K7W-I9VYU<%]A9&1E>'1R82!F=6YC=&EO;B!W;W5L9"!L
M;V]K(&QI:V4N"B\O($AE<F4@=V4@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4@
M=7-I;F<@=&AE('-Q;"!P87)A;65T97)S(&-O;F9I9W5R960@:6X*+R\@)&-O
M;F8@86YD('-T;W)E('1H92!E>'1R82!F:65L9',@:6X@='5R8F%?;V)J96-T
M<RP@=7-I;F<@=&AE("1U<V5R260@87,@=&AE"B\O(&ME>2!F;W(@=&AE(&]B
M:F5C="!A;F0@=F%L=65S(&9R;VT@=&AE("1E>'1R82!A<G)A>2X*+R\@66]U
M(&-O=6QD(&-R96%T92!Y;W5R(&]W;B!S<6P@<WEN=&%X(&]R(&-O9&4@=&\@
M<W1O<F4@=&AI<R!I;B!W:&EC:&5V97(*+R\@8F%C:V5N9"!Y;W4@<F5Q=6ER
M92X*+R\@3D]413H@66]U($1/($Y%140@5'5R8F$@=&\@8F4@8V]R<F5C=&QY
M(&EN<W1A;&QE9"!B969O<F4@>6]U(&-A;B!U<V4@=&AI<PHO+R!E>&%M<&QE
M(&)E;&]W+B!)="!A;'-O(&%S<W5M97,@=&AA="!Y;W4@87)E('5S:6YG(&%N
M(%-13"!B86-K96YD+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D
M95]H;V]K7W-I9VYU<%]A9&1E>'1R82<I*2!["B\O("`@("!F=6YC=&EO;B!?
M:&]R9&5?:&]O:U]S:6=N=7!?861D97AT<F$H)'5S97))1"P@)&5X=')A*0HO
M+R`@("`@>PHO+R`@("`@("`@(&=L;V)A;"`D8V]N9CL*+R\*+R\@("`@("`@
M("!R97%U:7)E7V]N8V4@)T1"+G!H<"<["B\O("`@("`@("`@)%]D8B`]("9$
M0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTL('1R=64I.PHO+PHO+R`@("`@("`@
M("1F:65L9',@/2!A<G)A>2@I.PHO+R`@("`@("`@("1V86QU97,@/2!A<G)A
M>2@I.PHO+R`@("`@("`@(&9O<F5A8V@@*"1E>'1R82!A<R`D9FEE;&0@/3X@
M)'9A;'5E*2!["B\O("`@("`@("`@("`@("1F:65L9'-;72`]("=O8FIE8W1?
M)R`N(%-T<FEN9SHZ;&]W97(H)&9I96QD*3L*+R\@("`@("`@("`@("`@)'9A
M;'5E<UM=(#T@)%]D8BT^<75O=&4H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D
M=F%L=64L($Y,4SHZ9V5T0VAA<G-E="@I+"`D8V]N9ELG<W%L)UU;)V-H87)S
M970G72DI.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D9FEE;&1S6UT@/2`G
M;V)J96-T7VED)SL*+R\@("`@("`@("`D=F%L=65S6UT@/2`D7V1B+3YQ=6]T
M92@D=7-E<DE$*3L*+R\*+R\@("`@("`@("`D<75E<GD@(#T@)TE.4T525"!)
M3E1/('1U<F)A7V]B:F5C=',@*"!O=VYE<E]I9"P@)R`N(&EM<&QO9&4H)RP@
M)RP@)&9I96QD<RD@+B`G*2<["B\O("`@("`@("`@)'%U97)Y("X]("<@5D%,
M5453("@@7"=A9&UI;EPG+"`G("X@:6UP;&]D92@G+"`G+"`D=F%L=65S*2`N
M("<I)SL*+R\@("`@("`@("`D<F5S=6QT(#T@)%]D8BT^<75E<GDH)'%U97)Y
M*3L*+R\*+R\@("`@("`@("!R971U<FX@:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I(#\@)')E<W5L="`Z('1R=64["B\O("`@("!]"B\O('T*"B\O($AE
M<F4@:7,@86X@97AA;7!L92!?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A=&4@
M=&AA="!M86ME($AO<F1E(')E<W!E8W0@=&AE"B\O(%5N:7@@8V]N=F5N=&EO
M;B!O9B!N;W0@86QL;W=I;F<@;&]G:6X@=VAE;B!A(&9I;&4@;F%M960@+V5T
M8R]N;VQO9VEN(&5X:7-T+@HO+R!4:&ES(&9U;F-T:6]N(&=E="!P87-S960@
M=&AE('5S97)N86UE+"!C<F5D96YT:6%L(&%N9"!R96%L;2!I;F9O<FUA=&EO
M;B!B=70*+R\@=&AE>2!A<F4@;F]T('5S960@:6X@=&AI<R!E>&%M<&QE+@H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W!R96%U=&AE
M;G1I8V%T92<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]P<F5A
M=71H96YT:6-A=&4H)'5S97))1"P@)&-R961E;G1I86PL("1R96%L;2D*+R\@
M("`@('L*+R\@("`@("`@("!R971U<FX@(69I;&5?97AI<W1S*"<O971C+VYO
M;&]G:6XG*3L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE
M(&]F('9A;&ED871I;F<@=&AE('5S97(G<R!R:6=H="!T;R!L;V=I;B!T;R!(
M;W)D92!B>0HO+R!C;VYS=6QT:6YG(&=R;W5P(&UE;6)E<G-H:7`@:6X@86X@
M3$1!4"!D:7)E8W1O<GDN("!4:&%T('=A>2P@:68@>6]U<B!(;W)D90HO+R!I
M;G-T86QL871I;VX@:7,@8V]N9FEG=7)E9"!T;R!A=71H96YT:6-A=&4@86=A
M:6YS="!)35`@=VAI8V@@:6X@='5R;@HO+R!A=71H96YT:6-A=&4@=FEA($E-
M05`L(&ET(&ES('-T:6QL('!O<W-I8FQE('1O(&QI;6ET(&%C8V5S<R!T;R!(
M;W)D92!B>0HO+R!G<F]U<"!M96UB97)S:&EP+B`@5&AE(&9O;&QO=VEN9R!E
M>&%M<&QE(&AA9"!B965N(&UA9&4@=VET:"!A;B!-4R!!8W1I=F4*+R\@1&ER
M96-T;W)Y(&EN(&UI;F0N("!.;W1E('1H870@:68@=&AE($Q$05`@9&ER96-T
M;W)Y(&ES('5N879A:6QA8FQE(&]R('-O;64*+R\@;W1H97(@97)R;W(@;V-C
M=7(L(&%U=&AE;G1I8V%T:6]N('=I;&P@9F%I;"X*"B\O(&EF("@A9G5N8W1I
M;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T875T:&5N=&EC871E)RDI('L*
M+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A=&4H
M)'5S97))1"P@)&-R961E;G1I86PL("1R96%L;2D*+R\@("`@('L*+R\@("`@
M("`@("`D;&1A<%-E<G9E<B`]("=A9"YE>&%M<&QE+F-O;2<["B\O("`@("`@
M("`@)&QD87!0;W)T(#T@)S,X.2<["B\O("`@("`@("`@+R\@3F]T92!T:&%T
M(&-R961E;G1I86P@:7,@<V5N="!P;&%I;BUT97AT(&EN('1H:7,@8V%S92P@
M<V\@9&]N)W0@=7-E"B\O("`@("`@("`@+R\@<')I=FEL96=E9"!A8V-O=6YT
M(&AE<F4@;W(@<V5T=7`@4U-,("AB>2!U<VEN9R!P;W)T(#8S-B!A8F]V92DN
M"B\O("`@("`@("`@)&)I;F1D;B`]("=C;CU7:71H;W5T4')I=FEL96=E+&1C
M/75L879A;"UD978L9&,]8V$G.PHO+R`@("`@("`@("1B:6YD<'<@/2`G4F5M
M96UB97(@=&AI<R!I<R!S96YT(&EN('1H92!C;&5A<B!U;FQE<W,@4U-,(&ES
M('5S960G.PHO+R`@("`@("`@("1S96%R8VA"87-E(#T@)V]U/5!E;W!L92QD
M8SUE>&%M<&QE+&1C/6-O;2<["B\O("`@("`@("`@+R\@071T<FEB=71E('1O
M(&UA=&-H("1U<V5R240@86=A:6YS="!I;B!S96%R8V@*+R\@("`@("`@("`D
M=7-E<D%T='(@/2`G<T%-06-C;W5N=$YA;64G.PHO+R`@("`@("`@("\O($=R
M;W5P(&UE;6)E<G-H:7`@871T<FEB=71E+"!N965D('1O(&)E(&%L;"!L;W=E
M<F-A<V4*+R\@("`@("`@("`D9W)O=7!!='1R(#T@)VUE;6)E<F]F)SL*+R\@
M("`@("`@("`O+R!!='1R:6)U=&4@=&\@8VAE8VL@9F]R(')I9VAT('1O('5S
M92!(;W)D90HO+R`@("`@("`@("1G<F]U<&1N(#T@)V-N/4AO<F1E57-E<BQO
M=3U096]P;&4L9&,]97AA;7!L92QD8SUC;VTG.PHO+R`@("`@("`@("1R970@
M/2!T<G5E.PHO+PHO+R`@("`@("`@("1D<R`]($!L9&%P7V-O;FYE8W0H)&QD
M87!397)V97(L("1L9&%P4&]R="D["B\O"B\O("`@("`@("`@:68@*$!L9&%P
M7V)I;F0H)&1S+"`D8FEN9&1N+"`D8FEN9'!W*2D@>PHO+R`@("`@("`@("`@
M("`D<V5A<F-H4F5S=6QT(#T@0&QD87!?<V5A<F-H*"1D<RP@)'-E87)C:$)A
M<V4L("1U<V5R071T<B`N("<])R`N("1U<V5R240L(&%R<F%Y*"1G<F]U<$%T
M='(I+"`P+"`Q+"`U*3L*+R\@("`@("`@("`@("`@:68@*"1I;F9O<FUA=&EO
M;B`]($!L9&%P7V=E=%]E;G1R:65S*"1D<RP@)'-E87)C:%)E<W5L="DI('L*
M+R\@("`@("`@("`@("`@("`@("\O(&UA:V4@<&%T=&5R;B!C87-E+6EN<V5N
M<VET:79E"B\O("`@("`@("`@("`@("`@("`D<&%T=&5R;B`]("<O)R`N("1G
M<F]U<&1N("X@)R]I)SL*+R\@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I
M;F9O<FUA=&EO;ELP75LD9W)O=7!!='1R72!A<R`D9W)O=7`I('L*+R\@("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<&%T=&5R;BP@)&=R
M;W5P*2D@>PHO+R`@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@=')U
M93L*+R\@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B\O("`@("`@
M("`@("`@("`@("`@("`@?0HO+R`@("`@("`@("`@("`@("`@?0HO+R`@("`@
M("`@("`@("!]"B\O("`@("`@("`@?0HO+PHO+R`@("`@("`@(&QD87!?8VQO
M<V4H)&1S*3L*+R\@("`@("`@("!R971U<FX@)')E=#L*+R\@("`@('T*+R\@
M?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(&]F(&-R96%T:6YG(&-R961E;G1I
M86QS(&YE961E9"!B>2!T:&4@3$1!4"!!=71H(&1R:79E<@HO+R!F;W(@861D
M:6YG+V1E;&5T:6YG+W5P9&%T:6YG('5S97)S+@H*+R\@:68@*"%F=6YC=&EO
M;E]E>&ES=',H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RDI('L*+R\@("`@(&9U
M;F-T:6]N(%]H;W)D95]H;V]K7V%U=&AL9&%P*"1U<V5R240L("1C<F5D96YT
M:6%L<R`](&YU;&PI"B\O("`@("!["B\O("`@("`@("`@)&5N=')Y6R=D;B==
M(#T@)W5I9#TG("X@)'5S97))1"`N("<L;W4]4&5O<&QE+&1C/65X86UP;&4N
M8V]M)SL*+R\@("`@("`@("!I9B`H:7-S970H)&-R961E;G1I86QS*2`F)B!I
M<W-E="@D8W)E9&5N=&EA;'-;)W5S97)?9G5L;&YA;64G72DI('L*+R\@("`@
M("`@("`@("`@)&5N=')Y6R=C;B==(#T@)&-R961E;G1I86QS6R=U<V5R7V9U
M;&QN86UE)UT["B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@
M)&5N=')Y6R=C;B==(#T@)'5S97))1#L*+R\@("`@("`@("!]"B\O("`@("`@
M("`@)&5N=')Y6R=S;B==(#T@)'5S97))1#L*+R\@("`@("`@("`D96YT<GE;
M)V]B:F5C=&-L87-S)UU;,%T@/2`G=&]P)SL*+R\@("`@("`@("`D96YT<GE;
M)V]B:F5C=&-L87-S)UU;,5T@/2`G<&5R<V]N)SL*+R\@("`@("`@("`D96YT
M<GE;)V]B:F5C=&-L87-S)UU;,ET@/2`G<6UA:6QU<V5R)SL*+R\@("`@("`@
M("`D96YT<GE;)V]B:F5C=&-L87-S)UU;,UT@/2`G0V]U<FEE<DUA:6Q!0V-O
M=6YT)SL*+R\@("`@("`@("`D96YT<GE;)VUA:6QH;W-T)UT@/2`G;6%I;"YE
M>&%M<&QE+F-O;2<["B\O("`@("`@("`@)&5N=')Y6R=M86EL365S<V%G95-T
M;W)E)UT@/2`G+VAO;64O;6%I;"\G("X@)'5S97))1#L*+R\@("`@("`@("`D
M96YT<GE;)VAO;65$:7)E8W1O<GDG72`]("<O:&]M92]M86EL+R<@+B`D=7-E
M<DE$.PHO+R`@("`@("`@("1E;G1R>5LG;6%I;&)O>"==(#T@)&5N=')Y6R=H
M;VUE1&ER96-T;W)Y)UT@+B`G+TUA:6QD:7(G.PHO+R`@("`@("`@("1E;G1R
M>5LG=6ED)UT@/2`D=7-E<DE$.PHO+R`@("`@("`@("1E;G1R>5LG86-C;W5N
M=%-T871U<R==(#T@)V%C=&EV92<["B\O("`@("`@("`@)&5N=')Y6R=M86EL
M475O=&$G72`]("<Q,#0X-3<V,#!3)SL*+R\@("`@("`@("`D96YT<GE;)VUA
M:6PG72`]("1U<V5R240["B\O("`@("`@("`@)&5N=')Y6R=U:61.=6UB97(G
M72`](#4P,3L*+R\@("`@("`@("`D96YT<GE;)V=I9$YU;6)E<B==(#T@-3`Q
M.PHO+PHO+R`@("`@("`@("\O(&YE960@=&\@8VAE8VL@9F]R(&YE=R!U<V5R
M<R`H<&%S<W=O<F0I(&%N9"!E9&ET960@=7-E<G,@*'5S97)?<&%S<U\R*0HO
M+R`@("`@("`@(&EF("AI<W-E="@D8W)E9&5N=&EA;',I("8F(&ES<V5T*"1C
M<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*+R\@("`@("`@("`@("`@)&5N
M=')Y6R=U<V5R4&%S<W=O<F0G72`]("`G>TU$-7TG("X@8F%S938T7V5N8V]D
M92AM2&%S:"A-2$%32%]-1#4L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI
M.PHO+R`@("`@("`@('T@96QS96EF("AI<W-E="@D8W)E9&5N=&EA;',I("8F
M(&ES<V5T*"1C<F5D96YT:6%L<ULG=7-E<E]P87-S7S(G72DI('L*+R\@("`@
M("`@("`@("`@)&5N=')Y6R=U<V5R4&%S<W=O<F0G72`]("`G>TU$-7TG("X@
M8F%S938T7V5N8V]D92AM2&%S:"A-2$%32%]-1#4L("1C<F5D96YT:6%L<ULG
M=7-E<E]P87-S7S(G72DI.PHO+R`@("`@("`@('T*+R\@("`@("`@("`D96YT
M<GE;)V1E;&EV97)Y36]D92==(#T@)VYO;&]C86PG.PHO+R`@("`@("`@(')E
M='5R;B`D96YT<GD["B\O("`@("!]"B\O('T*"B\O(%1H:7,@9G5N8W1I;VX@
M:7,@8V%L;&5D('=H96X@82!(;W)D95]3:&%R92!O8FIE8W0@:7,@8W)E871E
M9"X@270@=&%K97,@80HO+R!R969E<F5N8V4@=&\@=&AE($AO<F1E7U-H87)E
M(&]B:F5C="!T:&%T(&ES(&)E:6YG(&-R96%T960@87,@=V5L;"!A<R!T:`HO
M+R!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!F;W(@=VAI8V@@=&AE($AO<F1E
M7U-H87)E(&]B:F5C="!I<R!B96EN9R!C<F5A=&5D(&%S"B\O('!A<F%M971E
M<G,N(%1H92!R971U<FX@=F%L=64@:7,@:6=N;W)E9"X*"B\O(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]S:&%R95]I;FET)RDI('L*+R\@
M("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H87)E7VEN:70H)B1S:&%R95]O
M8FIE8W0L("1A<'`I"B\O("`@("!["B\O("`@("`@("`@:68@*"1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)V5N86)L960G72D@>PHO+R`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@("`@
M("`@($MO;&%B.CIS>6YC:')O;FES95-H87)E<R@D<VAA<F5?;V)J96-T+"`D
M87!P*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O(%1H92!F;VQL
M;W=I;F<@=&AR964@9G5N8W1I;VYS(&%R92!E>&%M<&QE<R!O9B!T:&]S92!T
M:&%T(&-A;B!B92!C86QL960@=VAE;@HO+R!A9&1I;F<L(&UO9&EF>6EN9R!A
M;F0@<F5M;W9I;F<@<VAA<F5S+"!R97-P96-T:79E;'DN(%1H97D@87)E(&-A
M;&QE9"!W:71H"B\O('1H92!S:&%R92!T:&%T(&ES(&)E:6YG(&%D9&5D+"!M
M;V1I9FEE9"!O<B!R96UO=F5D(&%S('1H96ER('-I;F=L90HO+R!P87)A;65T
M97(N("!)9B!A(%!%05)?17)R;W(@;V)J96-T(&ES(')E='5R;F5D('1H92!R
M97-P96-T:79E('-H87)E"B\O(&]P97)A=&EO;B!W:6QL(&9A:6P@=VET:"!T
M:&4@97)R;W(@<F5S=6QT+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H
M;W)D95]H;V]K7W-H87)E7V%D9"<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R
M9&5?:&]O:U]S:&%R95]A9&0H)B1S:&%R92D*+R\@("`@('L*+R\@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@("`@
M<F5T=7)N($MO;&%B.CIU<&1A=&53:&%R92@D<VAA<F4I.PHO+R`@("`@?0HO
M+R!]"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?<VAA
M<F5?;6]D:69Y)RDI('L*+R\@("`@(&9U;F-T:6]N(%]H;W)D95]H;V]K7W-H
M87)E7VUO9&EF>2@F)'-H87)E*0HO+R`@("`@>PHO+R`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O2V]L86(N<&AP)SL*+R\@("`@("`@("!R971U<FX@
M2V]L86(Z.G5P9&%T95-H87)E*"1S:&%R92D["B\O("`@("!]"B\O('T*+R\*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7W)E
M;6]V92<I*2!["B\O("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S:&%R95]R
M96UO=F4H)B1S:&%R92D*+R\@("`@('L*+R\@("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O("`@("`@("`@<F5T=7)N($MO;&%B
M.CIR96UO=F53:&%R92@D<VAA<F4I.PHO+R`@("`@?0HO+R!]"@HO+R!4:&ES
M(&5X86UP;&4@:7,@;V8@82!F=6YC=&EO;B!T:&%T(&-A;B!B92!C86QL960@
M=VAE;B!A('-H87)E(&QI<W1I;F<@:7,*+R\@<F5Q=65S=&5D+B!)="!T86ME
M<R!A('5S97)I9"P@82!P97)M:7-S:6]N<R!L979E;"P@86X@;W!T:6]N86P@
M<W1R:6YG"B\O(&-O;G1A:6YI;F<@82!U<V5R:60@=&\@<F5S=')I8W0@=&AE
M(&]W;F5R(&]F('1H92!S:&%R97,@<F5T=7)N960L(&%N9"!T:&4*+R\@<F5S
M=6QT(&]F('1H92!C;W)R97-P;VYD:6YG($AO<F1E7U-H87)E.CIL:7-T4VAA
M<F5S*"D@8V%L;"!A<R!I=',*+R\@<&%R86UE=&5R<RX@07,@:7,@=&AE(&-A
M<V4@:6X@=&AE('!R979I;W5S('1H<F5E(&9U;F-T:6]N<RP@:68@82!014%2
M7T5R<F]R"B\O(')E<W5L="!I<R!R971U<FYE9"!T:&4@2&]R9&5?4VAA<F4Z
M.FQI<W13:&%R97,H*2!C86QL('1H870@=')I9V=E<F5D('1H:7,*+R\@:&]O
M:R!W:6QL(&9A:6P@=VET:"!T:&4@<F5T=7)N960@<F5S=6QT+@H*+R\@:68@
M*"%F=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7VQI<W0G*2D@
M>PHO+R`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?;&ES="@D=7-E
M<FED+"`D<&5R;2P@)&]W;F5R+"`F)'-H87)E7VQI<W0I"B\O("`@("!["B\O
M("`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*+R\@("`@("`@("`O+V5R<F]R
M7VQO9R@G3G5M8F5R(&]F("<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M07!P*"D@+B`G('-H87)E<R<@+B`H)&]W;F5R(#\*+R\@("`@("`@("`O+R`@
M("`G(&]W;F5D(&)Y("<@+B`D;W=N97(@.B`G)RD@+B`G(&%V86EL86)L92!T
M;R`G("X@)'5S97)I9"`N("<@870@<&5R;7,@;&5V96P@)R`N"B\O("`@("`@
M("`@+R\@("`@)'!E<FT@+B`G.B`G("X@(&-O=6YT*"1S:&%R95]L:7-T*2D[
M"B\O("`@("`@("`@<F5T=7)N('1R=64["B\O("`@("!]"B\O('T*"B\O($AE
M<F4@:7,@86X@97AA;7!L92!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"!F
M=6YC=&EO;BX@270@87!P96YD<R!T:&4*+R\@=FER='5A;"!D;VUA:6X@=&\@
M=&AE('5S97(@;F%M92X*+R\*+R\@97@N("1(5%107TA/4U0@/2`G;6%I;"YM
M>61O;6%I;BYC;VTG+"`D=7-E<DE$(#T@)VUY;F%M92<@<F5T=7)N<SH*+R\@
M("`G;7EN86UE0&UY9&]M86EN+F-O;2<*"B\O(&EF("@A9G5N8W1I;VY?97AI
M<W1S*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"<I*2!["B\O("`@("!F
M=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"@D=7-E<DE$*0HO
M+R`@("`@>PHO+R`@("`@("`@("1V9&]M86EN(#T@9V5T96YV*"=(5%107TA/
M4U0G*3L*+R\@("`@("`@("`D=F1O;6%I;B`]('!R96=?<F5P;&%C92@G?%YM
M86EL7"Y\:2<L("<G+"`D=F1O;6%I;BD["B\O("`@("`@("`@)'9D;VUA:6X@
M/2!3=')I;F<Z.FQO=V5R*"1V9&]M86EN*3L*+R\*+R\@("`@("`@("!R971U
M<FX@)'5S97))1"`N("=`)R`N("1V9&]M86EN.PHO+R`@("`@?0HO+R!]"@HO
M+R!(97)E(&ES(&%N(&5X86UP;&4@7W5S97)N86UE7VAO;VM?=&]B86-K96YD
M(&9U;F-T:6]N(&%S(&$@8V]U;G1E<G!A<G0@;V8@=&AE"B\O('!R979I;W5S
M(&5X86UP;&4N($ET('-T<FEP<R!T:&4@=FER='5A;"!D;VUA:6X@9G)O;2!T
M:&4@=7-E<B!N86UE+@HO+PHO+R!E>"X@)$A45%!?2$]35"`]("=M86EL+FUY
M9&]M86EN+F-O;2<L("1U<V5R240@/2`G;7EN86UE)R!R971U<FYS.@HO+R`@
M("=M>6YA;65`;7ED;VUA:6XN8V]M)PH*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"<I*2!["B\O("`@("!F=6YC
M=&EO;B!?=7-E<FYA;65?:&]O:U]T;V)A8VME;F0H)'5S97))1"D*+R\@("`@
M('L*+R\@("`@("`@("`D=F1O;6%I;B`](&=E=&5N=B@G2%144%](3U-4)RD[
M"B\O("`@("`@("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA8V4H)WQ>;6%I;%PN
M?&DG+"`G)RP@)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@)T`G
M("X@4W1R:6YG.CIL;W=E<B@D=F1O;6%I;BD["B\O"B\O("`@("`@("`@:68@
M*'-U8G-T<B@D=7-E<DE$+"`M<W1R;&5N*"1V9&]M86EN*2D@/3T@)'9D;VUA
M:6XI('L*+R\@("`@("`@("`@("`@)'5S97))1"`]('-U8G-T<B@D=7-E<DE$
M+"`P+"`M<W1R;&5N*"1V9&]M86EN*2D["B\O("`@("`@("`@?0HO+PHO+R`@
M("`@("`@(')E='5R;B`D=7-E<DE$.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E
M(&ES(&%N(&5X86UP;&4@7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0@9G5N
M8W1I;VXN($ET(&-O;G9E<G1S('1H92!U<V5R"B\O(&YA;64@=&\@86QL(&QO
M=V5R(&-A<V4N(%1H:7,@;6EG:'0@8F4@;F5C97-S87)Y(&EF(&%N(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0*+R\@:7,@8V%S92!I;G-E;G-I=&EV92!T;R!T
M86ME(&EN=&\@86-C;W5N="!T:&%T($AO<F1E)W,@<')E9F5R96YC92!S>7-T
M96T@:7,*+R\@8V%S92!S96YS:71I=F4N"B\O"B\O(&5X+B`D=7-E<DE$(#T@
M)TUY3F%M92<@<F5T=7)N<SH@)VUY;F%M92<*"B\O(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"<I*2!["B\O("`@
M("!F=6YC=&EO;B!?=7-E<FYA;65?:&]O:U]F<F]M8F%C:V5N9"@D=7-E<DE$
M*0HO+R`@("`@>PHO+R`@("`@("`@(')E='5R;B!3=')I;F<Z.FQO=V5R*"1U
M<V5R240I.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@
M7W!E<FUS7VAO;VM?9&5N:65D(&9U;F-T:6]N+B`@270@:7,@8V%L;&5D(&EF
M(&$@=7-E<@HO+R!T<FEE<R!T;R!M86ME(&%N(&%C=&EO;B!T:&%T(&ES('5N
M9&5R('!E<FUI<W-I;VX@8V]N=')O;"!A;F0@=&AA="!H90HO+R!D;V5S;B=T
M(&AA=F4@<W5F9FEC:65N="!P97)M:7-S:6]N<R!F;W(N("!)="!C86X@8F4@
M=7-E9"!T;R!S:&]W('1H92!U<V5R(&$*+R\@8W5S=&]M(&UE<W-A9V4@:6YC
M;'5D:6YG($A434P@8V]D92`H>6]U(&AA=F4@=&\@=&%K92!C87)E(&%B;W5T
M($A434P*+R\@97-C87!I;F<@;VX@>6]U<B!O=VXI+"!O<B!T;R!I;G1E<G)U
M<'0@=&AE(&-O9&4@9FQO=R!A;F0@<V5N9"!T:&4@=7-E<B!T;R!A"B\O(&1I
M9F9E<F5N="!P86=E(&9O<B!E>&%M<&QE+@H*+R\@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]P97)M<U]H;V]K7V1E;FEE9"<I*2!["B\O("`@("!F=6YC=&EO
M;B!?<&5R;7-?:&]O:U]D96YI960H)'!E<FUI<W-I;VXI"B\O("`@("!["B\O
M("`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1P97)M:7-S:6]N+"`G.B<I
M*2`]/3T@9F%L<V4I('L*+R\@("`@("`@("`@("`@)&%P<"`]("1P97)M:7-S
M:6]N.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@("1A<'`@
M/2!S=6)S='(H)'!E<FUI<W-I;VXL(#`L("1P;W,I.PHO+R`@("`@("`@('T*
M+R\*+R\@("`@("`@("!R971U<FX@<W!R:6YT9B@G4&5R;6ES<VEO;B!D96YI
M960N($-L:6-K(#QA(&AR968](FAT='`Z+R]W=W<N97AA;7!L92YC;VTO=7!G
M<F%D92YP:'`_87!P/25S(CY(15)%/"]A/B!T;R!U<&=R861E("5S+B<L"B\O
M("`@("`@("`@("`@("`@("`@("`@("`@)&%P<"P@)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G;F%M92<I*3L*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I
M<R!A;B!E>&%M<&QE(&]F(&$@9W)O=7`@:&]O:RX@(%1O('5S92!I="!Y;W4@
M;75S="!S970@=&AE(&=R;W5P"B\O(&1R:79E<B!T;R!H;V]K<R!I;B!C;VYF
M+G!H<"X@(%1H96X@>6]U(&UU<W0@8W)E871E(&$@251?9&5P87)T;65N="!G
M<F]U<`HO+R`H8F5C875S92!T:&%T(&ES(&AO=R!W92!K;F]W('=H870@:&]O
M:R!T;R!C86QL*2X@(%EO=2!C86X@861D('5S97)S('1O('1H90HO+R!G<F]U
M<"!A<R!N;W)M86PL(&%N9"!I;B!A9&1I=&EO;B!T:&ES(&9U;F-T:6]N('=I
M;&P@8F4@8V%L;&5D('1O"B\O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@=7-E<G,@
M:6X@=&AE(&=R;W5P+B`@26X@=&AI<R!E>&%M<&QE('=E('=I;&P@;&]O:R!U
M<`HO+R!W:&5T:&5R(&]R(&YO="!T:&ES('5S97(@:7,@<&%R="!O9B!T:&4@
M250@9&5P87)T;65N="!U<VEN9R!A;B!E>'1E<FYA;`HO+R!D871A8F%S92X*
M"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?9W)O=7!?:&]O:U])5%]D97!A
M<G1M96YT)RDI('L*+R\@("`@(&9U;F-T:6]N(%]G<F]U<%]H;V]K7TE47V1E
M<&%R=&UE;G0H)'5S97).86UE*0HO+R`@("`@>PHO+R`@("`@("`@(&=L;V)A
M;"`D8V]N9CL*+R\*+R\@("`@("`@("`D9&5P="`]("=)5"<["B\O("`@("`@
M("`@:6YC;'5D95]O;F-E("=$0BYP:'`G.PHO+R`@("`@("`@("1?9&(@/2`F
M1$(Z.F-O;FYE8W0H)&-O;F9;)W-Q;"==+"!T<G5E*3L*+R\@("`@("`@("`D
M<75E<GD@/2`G4T5,14-4($-/54Y4*"HI($923TT@9&5P87)T;65N=',@5TA%
M4D4@=7-E<E]N86UE(#T@/R!!3D0@9&5P87)T;65N="`](#\G.PHO+R`@("`@
M("`@("1V86QU97,@/2!A<G)A>2@D=7-E<DYA;64L("1D97!T*3L*+R\@("`@
M("`@("`D<F5S=6QT(#T@)%]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD[
M"B\O("`@("`@("`@:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RD@
M)B8@)')E<W5L="`^(#`I('L*+R\@("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B\O("`@("`@("`@?2!E;'-E('L*+R\@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PHO+R`@("`@("`@('T*+R\@("`@('T*+R\@?0H*+R\@5&AI<R!I<R!A
M;B!E>&%M<&QE(&]F(&$@<&]S="UP=7-H(&AO;VL[(&ET(&ES(&-A;&QE9"!R
M:6=H="!A9G1E<B!A;@HO+R!A<'!L:6-A=&EO;B!I<R!P=7-H960@<W5C8V5S
M<V9U;&QY(&]N=&\@=&AE(&%P<"!S=&%C:RX*"B\O(&EF("@A9G5N8W1I;VY?
M97AI<W1S*"=?:&]R9&5?:&]O:U]P;W-T7W!U<VAA<'`G*2D@>PHO+R`@("`@
M9G5N8W1I;VX@7VAO<F1E7VAO;VM?<&]S=%]P=7-H87!P*"1A<'`I"B\O("`@
M("!["B\O("`@("`@("`@:68@*&EN7V%R<F%Y*"1A<'`L(&%R<F%Y*"=K<F]N
M;VQI=&@G+"`G='5R8F$G+"`G:&]R9&4G+"`G:6YG;R<I*2!\?`HO+R`@("`@
M("`@("`@("`@<W1R<&]S*"1?4T525D526R=02%!?4T5,1B==+"`G<')E9G,N
M<&AP)RD@(3T](&9A;'-E*2!["B\O("`@("`@("`@("`@(')E<75I<F5?;VYC
M92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("=D:6UP
M)RD@+B`G+VQI8B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S3W9E<G)I
M9&4N<&AP)SL*+R\@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO
M;B==(#T@)DYO=&EF:6-A=&EO;CHZ<VEN9VQE=&]N*"D["B\O("`@("`@("`@
M("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^871T86-H*"=S=&%T=7,G
M+"!N=6QL+"`G3F]T:69I8V%T:6]N7TQI<W1E;F5R7V1I;7!?<W1A='5S3W9E
M<G)I9&4G*3L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O($AE<F4@
M:7,@86X@97AA;7!L92!?:6UP7VAO;VM?=')A:6QE<B!F=6YC=&EO;B!T;R!S
M970@=&AE('1R86EL97(@9G)O;2!T:&4*+R\@<WES=&5M('1A9VQI;F5S(&9I
M;&4[('1H92!S=')I;F<@(D!`5$%'0$`B("AI9B!P<F5S96YT(&EN(&$@=')A
M:6QE<BD@=VEL;"!B90HO+R!R97!L86-E9"!B>2!T:&4@8V]N=&5N="!O9B!T
M:&4@9FEL92`B+W5S<B]S:&%R92]T86=L:6YE(B`H9V5N97)A=&5D(&)Y('1H
M90HO+R`B5&%25"(@=71I;&ET>2DN"@HO+R!I9B`H(69U;F-T:6]N7V5X:7-T
M<R@G7VEM<%]H;V]K7W1R86EL97(G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VEM
M<%]H;V]K7W1R86EL97(H)'1R86EL97(I"B\O("`@("!["B\O("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)R]`0%1!1T!`+R<L("1T<F%I;&5R*2D@>PHO+R`@
M("`@("`@("`@("`D=&%G(#T@8&-A="`O=7-R+W-H87)E+W1A9VQI;F5@.PHO
M+R`@("`@("`@("`@("`D=')A:6QE<B`]('!R96=?<F5P;&%C92@G?$!`5$%'
M0$!\)RP@)'1A9RP@)'1R86EL97(I.PHO+R`@("`@("`@('T*+R\@("`@("`@
M("!R971U<FX@)'1R86EL97(["B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@
M86X@86YO=&AE<B!E>&%M<&QE(%]I;7!?:&]O:U]T<F%I;&5R(&9U;F-T:6]N
M('1O('-E="!T:&4@=')A:6QE<@HO+R!F<F]M('1H92!,1$%0(&1I<F5C=&]R
M>2!F;W(@96%C:"!D;VUA:6XN(%1H:7,@9G5N8W1I;VX@<F5P;&%C97,@=&AE
M(&-U<G)E;G0*+R\@=')A:6QE<B!W:71H('1H92!D871A(&ET(&=E=',@9G)O
M;2!I<W!M86Y$;VUA:6Y3:6=N871U<F4N"@HO+R!I9B`H(69U;F-T:6]N7V5X
M:7-T<R@G7VEM<%]H;V]K7W1R86EL97(G*2D@>PHO+R`@("`@9G5N8W1I;VX@
M7VEM<%]H;V]K7W1R86EL97(H)'1R86EL97(I"B\O("`@("!["B\O("`@("`@
M("`@)'9D;VUA:6X@/2!G971E;G8H)TA45%!?2$]35"<I.PHO+R`@("`@("`@
M("1V9&]M86EN(#T@<')E9U]R97!L86-E*"=\7BXJ/UPN?&DG+"`G)RP@)'9D
M;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@4W1R:6YG.CIL;W=E<B@D
M=F1O;6%I;BD["B\O("`@("`@("`@)&QD87!397)V97(@/2`G;&]C86QH;W-T
M)SL*+R\@("`@("`@("`D;&1A<%!O<G0@/2`G,S@Y)SL*+R\@("`@("`@("`D
M<V5A<F-H0F%S92`]("=I<W!M86Y$;VUA:6X])R`N("1V9&]M86EN("`N("(L
M;SUI<W!M86XB.PHO+PHO+R`@("`@("`@("1D<R`]($!L9&%P7V-O;FYE8W0H
M)&QD87!397)V97(L("1L9&%P4&]R="D["B\O("`@("`@("`@)'-E87)C:%)E
M<W5L="`]($!L9&%P7W-E87)C:"@D9',L("1S96%R8VA"87-E+"`G=6ED/2<@
M+B`D=F1O;6%I;BD["B\O("`@("`@("`@)&EN9F]R;6%T:6]N(#T@0&QD87!?
M9V5T7V5N=')I97,H)&1S+"`D<V5A<F-H4F5S=6QT*3L*+R\@("`@("`@("`D
M=')A:6QE<CT@)&EN9F]R;6%T:6]N6S!=6R=I<W!M86YD;VUA:6YS:6=N871U
M<F4G75LP73L*+R\@("`@("`@("!L9&%P7V-L;W-E*"1D<RD["B\O"B\O("`@
M("`@("`@<F5T=7)N("1T<F%I;&5R.PHO+R`@("`@?0HO+R!]"@HO+R!(97)E
M(&ES(&%N(&5X86UP;&4@7VEM<%]H;V]K7W9I;F9O(&9U;F-T:6]N+B!)9B`D
M='EP92`]/2`G=F1O;6%I;B<L('1H:7,*+R\@9G5N8W1I;VX@<F5T=7)N<R!T
M:&4@2%144%](3U-4('9A<FEA8FQE(&%F=&5R(')E;6]V:6YG('1H92`G;6%I
M;"XG"B\O('-U8F1O;6%I;BX*+R\*+R\@268@)'1Y<&4@/3T@)W5S97)N86UE
M)RP@=&AI<R!F=6YC=&EO;B!R971U<FYS(&$@=6YI<75E('5S97)N86UE(&-O
M;7!O<V5D(&]F"B\O("1?4T534TE/3ELG:6UP)UU;)W5S97(G72`K('9D;VUA
M:6XN"B\O"B\O(&5X+B`D2%144%](3U-4(#T@)VUA:6PN;7ED;VUA:6XN8V]M
M)RP@)%]315-324].6R=I;7`G75LG=7-E<B==(#T@)VUY;F%M92<Z"B\O("`@
M)'9D;VUA:6X@(#T@)VUY9&]M86EN+F-O;2<*+R\@("`D=7-E<FYA;64@/2`G
M;7EN86UE7VUY9&]M86EN7V-O;2<*"B\O(&EF("@A9G5N8W1I;VY?97AI<W1S
M*"=?:6UP7VAO;VM?=FEN9F\G*2D@>PHO+R`@("`@9G5N8W1I;VX@7VEM<%]H
M;V]K7W9I;F9O*"1T>7!E(#T@)W5S97)N86UE)RD*+R\@("`@('L*+R\@("`@
M("`@("`D=F1O;6%I;B`](&=E=&5N=B@G2%144%](3U-4)RD["B\O("`@("`@
M("`@)'9D;VUA:6X@/2!P<F5G7W)E<&QA8V4H)WQ>;6%I;%PN?&DG+"`G)RP@
M)'9D;VUA:6XI.PHO+R`@("`@("`@("1V9&]M86EN(#T@4W1R:6YG.CIL;W=E
M<B@D=F1O;6%I;BD["B\O"B\O("`@("`@("`@:68@*"1T>7!E(#T]("=U<V5R
M;F%M92<I('L*+R\@("`@("`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G
M?%PN?"<L("=?)RP@)%]315-324].6R=I;7`G75LG=7-E<B==("X@)U\G("X@
M)'9D;VUA:6XI.PHO+R`@("`@("`@('T@96QS96EF("@D='EP92`]/2`G=F1O
M;6%I;B<I('L*+R\@("`@("`@("`@("`@<F5T=7)N("1V9&]M86EN.PHO+R`@
M("`@("`@('T@96QS92!["B\O("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=I;G9A;&ED('1Y<&4Z("<@+B`D='EP92D["B\O("`@("`@
M("`@?0HO+R`@("`@?0HO+R!]"@HO+R!(97)E(&ES(&%N(&5X86UP;&4@;V8@
M=&AE(%]I;7!?:&]O:U]F971C:&UA:6Q?9FEL=&5R(&9U;F-T:6]N('1O(')U
M;@HO+R!3<&%M07-S87-S:6X@;VX@96UA:6P@8F5F;W)E(&ET(&ES('=R:71T
M96X@=&\@=&AE(&UA:6QB;W@N"B\O($YO=&4Z('1O('5S92!T:&4@<W!A;6%S
M<V%S<VEN(&EN<W1E860@;V8@<W!A;60L(&-H86YG92`G<W!A;6,G('1O"B\O
M("=S<&%M87-S87-S:6X@+5`G(&%N9"!A9&0@86YY(&]T:&5R(&EM<&]R=&%N
M="!A<F=U;65N=',L(&)U="!R96%L:7IE('-P86UC"B\O(&ES($U50T@@9F%S
M=&5R('1H86X@<W!A;6%S<V%S<VEN+@HO+R!705).24Y'.B!-86ME('-U<F4@
M=&\@=7-E('1H92`M+6YO861D+69R;VT@9FEL=&5R(&]N('-P86UD(&]R('-P
M86UA<W-A<W-I;@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O
M:U]F971C:&UA:6Q?9FEL=&5R)RDI('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?
M:&]O:U]F971C:&UA:6Q?9FEL=&5R*"1M97-S86=E*0HO+R`@("`@>PHO+R`@
M("`@("`@("\O(%=H97)E(&1O97,@4W!A;4%S<V%S<VEN(&QI=F4L(&%N9"!W
M:&%T('5S97)N86UE('-H;W5L9"!W92!U<V4*+R\@("`@("`@("`O+R!F;W(@
M<')E9F5R96YC97,_"B\O("`@("`@("`@)&-M9"`]("<O=7-R+VQO8V%L+V)I
M;B]S<&%M8R<["B\O("`@("`@("`@)'5S97)N86UE(#T@075T:#HZ9V5T075T
M:"@I.PHO+R`@("`@("`@("\O($EF('EO=2!U<V4@=&AE(%]S86U?:&]O:U]U
M<V5R;F%M92@I(&AO;VLL('5N8V]M;65N="!T:&4@;F5X="!L:6YE"B\O("`@
M("`@("`@+R\D=7-E<FYA;64@/2!?<V%M7VAO;VM?=7-E<FYA;64H)'5S97)N
M86UE*3L*+R\@("`@("`@("`D=7-E<FYA;64@/2!E<V-A<&5S:&5L;&%R9R@D
M=7-E<FYA;64I.PHO+PHO+R`@("`@("`@("\O($%L<V\L('=E(')E;6]V92!T
M:&4@9FEL92!O=7)S96QV97,[('1H:7,@:&]O:R!M87D@8F4@8V%L;&5D"B\O
M("`@("`@("`@+R\@:'5N9')E9',@;V8@=&EM97,@<&5R(')U;B!D97!E;F1I
M;F<@;VX@:&]W(&UA;GD@;65S<V%G97,@=V4@9F5T8V@*+R\@("`@("`@("`D
M9FEL92`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&4G+"!F86QS92D["B\O
M"B\O("`@("`@("`@+R\@0V%L;"!3<&%M07-S87-S:6X[('!I<&4@=&AE(&YE
M=R!M97-S86=E('1O(&]U<B!T96UP9FEL90HO+R`@("`@("`@("1F<"`]('!O
M<&5N*"(D8VUD("UU("1U<V5R;F%M92`^("1F:6QE(BP@)W<G*3L*+R\@("`@
M("`@("!F=W)I=&4H)&9P+"`D;65S<V%G92D["B\O("`@("`@("`@<&-L;W-E
M*"1F<"D["B\O"B\O("`@("`@("`@+R\@4F5A9"!T:&4@;F5W(&UE<W-A9V4@
M9G)O;2!T:&4@=&5M<&]R87)Y(&9I;&4*+R\@("`@("`@("`D;65S<V%G92`]
M(&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE*3L*+R\@("`@("`@("!U;FQI;FLH
M)&9I;&4I.PHO+R`@("`@("`@(')E='5R;B`D;65S<V%G93L*+R\@("`@('T*
M+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE('-I9VYA='5R92!H;V]K(&9U
M;F-T:6]N('1O('-E="!T:&4@<VEG;F%T=7)E(&9R;VT@=&AE"B\O('-Y<W1E
M;2!T86=L:6YE<R!F:6QE.R!T:&4@<W1R:6YG("(E5$%')2(@*&EF('!R97-E
M;G0@:6X@82!U<V5R)W,@<VEG;F%T=7)E*0HO+R!W:6QL(&)E(')E<&QA8V5D
M(&)Y('1H92!C;VYT96YT(&]F('1H92!F:6QE("(O=7-R+W-H87)E+W1A9VQI
M;F4B("AG96YE<F%T960*+R\@8GD@=&AE(")485)4(B!U=&EL:71Y*2X*"B\O
M(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?<VEG;F%T=7)E)RDI
M('L*+R\@("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]S:6=N871U<F4H)'-I9RD*
M+R\@("`@('L*+R\@("`@("`@("!I9B`H<')E9U]M871C:"@G+R5404<E+R<L
M("1S:6<I*2!["B\O("`@("`@("`@("`@("1T86<@/2!@8V%T("]U<W(O<VAA
M<F4O=&%G;&EN96`["B\O("`@("`@("`@("`@("1S:6<@/2!P<F5G7W)E<&QA
M8V4H)R\E5$%')2\G+"`D=&%G+"`D<VEG*3L*+R\@("`@("`@("!]"B\O"B\O
M("`@("`@("`@<F5T=7)N("1S:6<["B\O("`@("!]"B\O('T*"B\O(%1H:7,@
M:7,@86X@97AA;7!L92!H;V]K(&9U;F-T:6]N(&9O<B!T:&4@24U0(')E9&ER
M96-T:6]N('-C:&5M92X@5&AI<PHO+R!F=6YC=&EO;B!I<R!C86QL960@=VAE
M;B!T:&4@=7-E<B!O<&5N<R!A(&UA:6QB;W@@:6X@24U0+"!A;F0@86QL;W=S
M('1H90HO+R!C;&EE;G0@=&\@8F4@<F5D:7)E8W1E9"!B87-E9"!O;B!T:&4@
M;6%I;&)O>"!N86UE+B!4:&4@<F5T=7)N('9A;'5E(&]F('1H:7,*+R\@9G5N
M8W1I;VX@<VAO=6QD(&)E(&$@=F%L:60@<&%G92!W:71H:6X@82!H;W)D92!A
M<'!L:6-A=&EO;B!W:&EC:"!W:6QL(&)E"B\O('!L86-E9"!I;B!A("),;V-A
M=&EO;B(@:&5A9&5R('1O(')E9&ER96-T('1H92!C;&EE;G0N("!4:&4@;VYL
M>2!P87)A;65T97(*+R\@:7,@=&AE(&YA;64@;V8@=&AE(&UA:6QB;W@@=VAI
M8V@@=&AE('5S97(@:&%S(&]P96YE9"X@($EF(&%N(&5M<'1Y('-T<FEN9PHO
M+R!I<R!R971U<FYE9"!T:&4@=7-E<B!I<R!N;W0@<F5D:7)E8W1E9"X*"B\O
M(&EF("@A9G5N8W1I;VY?97AI<W1S*"=?:6UP7VAO;VM?;6)O>%]R961I<F5C
M="<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?;6)O>%]R961I<F5C
M="@D;6%I;&)O>"D*+R\@("`@('L*+R\@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TMO;&%B+G!H<"<["B\O"B\O("`@("`@("`@:68@*'-T<G!O<R@D
M;6%I;&)O>"P@(DE.0D]8+T-A;&5N9&%R(BD@(3T](&9A;'-E"B\O("`@("`@
M("`@("`@('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R]#86QE;F1A<B$B
M+"`D;6%I;&)O>"DI('L*+R\@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:W)O;F]L:71H)RD["B\O
M("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D;6%I;&)O>"P@(DE.0D]8+U1A
M<VMS(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H
M(B%>=7-E<B];7B]=*R]487-K<R$B+"`D;6%I;&)O>"DI('L*+R\@("`@("`@
M("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O
M;W0G+"`G;F%G)RD["B\O("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D;6%I
M;&)O>"P@(DE.0D]8+TYO=&5S(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@
M('Q\('!R96=?;6%T8V@H(B%>=7-E<B];7B]=*R].;W1E<R$B+"`D;6%I;&)O
M>"DI('L*+R\@("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG970H)W=E8G)O;W0G+"`G;6YE;6\G*3L*+R\@("`@("`@("!](&5L
M<V5I9B`H<W1R<&]S*"1M86EL8F]X+"`B24Y"3U@O0V]N=&%C=',B*2`A/3T@
M9F%L<V4*+R\@("`@("`@("`@("`@?'P@<')E9U]M871C:"@B(5YU<V5R+UM>
M+UTK+T-O;G1A8W1S(2(L("1M86EL8F]X*2D@>PHO+R`@("`@("`@("`@("!R
M971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=T
M=7)B82<I.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!R971U<FX@)R<[
M"B\O("`@("!]"B\O('T*"B\O(%1H:7,@:7,@86X@97AA;7!L92!H;V]K(&9U
M;F-T:6]N(&9O<B!T:&4@24U0(&UA:6QB;W@@:6-O;B!S8VAE;64N(%1H:7,*
M+R\@9G5N8W1I;VX@:7,@8V%L;&5D('=H96X@=&AE(&9O;&1E<B!L:7-T(&ES
M(&-R96%T960@86YD(&$@(G-T86YD87)D(B!F;VQD97(*+R\@:7,@=&\@8F4@
M9&ES<&QA>65D("T@:70@86QL;W=S(&-U<W1O;2!F;VQD97(@:6-O;G,@=&\@
M8F4@<W!E8VEF:65D+@HO+R`H(E-T86YD87)D(B!M96%N<R!A;&P@9F]L9&5R
M<R!E>&-E<'0@=&AE($E.0D]8+"!S96YT+6UA:6P@9F]L9&5R<R!A;F0*+R\@
M=')A<V@@9F]L9&5R<RXI"B\O($EF(&$@;6%I;&)O>"!N86UE(&1O97-N)W0@
M87!P96%R(&EN('1H92!B96QO=R!L:7-T+"!T:&4@9&5F875L="!M86EL8F]X
M"B\O(&EC;VX@:7,@9&ES<&QA>65D+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)U]I;7!?:&]O:U]M8F]X7VEC;VYS)RDI('L*+R\@("`@(&9U;F-T:6]N
M(%]I;7!?:&]O:U]M8F]X7VEC;VYS*"D*+R\@("`@('L*+R\@("`@("`@("!S
M=&%T:6,@)&YE=VUA:6QB;WAE<SL*+R\*+R\@("`@("`@("!I9B`H(65M<'1Y
M*"1N97=M86EL8F]X97,I*2!["B\O("`@("`@("`@("`@(')E='5R;B`D;F5W
M;6%I;&)O>&5S.PHO+R`@("`@("`@('T*+R\*+R\@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+TMO;&%B+G!H<"<["B\O"B\O("`@("`@("`@)&MC(#T@
M;F5W($MO;&%B7T-Y<G5S*"1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)W-E
M<G9E<B==*3L*+R\@("`@("`@("`D;6%I;&)O>&5S(#T@)&MC+3YL:7-T36%I
M;$)O>&5S*"D["B\O("`@("`@("`@)&YE=VUA:6QB;WAE<R`](&%R<F%Y*"D[
M"B\O"B\O("`@("`@("`@9F]R96%C:"`H)&UA:6QB;WAE<R!A<R`D8F]X*2![
M"B\O("`@("`@("`@("`@("1B;W@@/2!P<F5G7W)E<&QA8V4H(B]>>UM>?5TK
M?2\B+"`B(BP@)&)O>"D["B\O("`@("`@("`@("`@(&EF("AS=')P;W,H)&)O
M>"P@(DE.0D]8+T-A;&5N9&%R(BD@(3T](&9A;'-E"B\O("`@("`@("`@("`@
M("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO72LO0V%L96YD87(A(BP@
M)&)O>"DI('L*+R\@("`@("`@("`@("`@("`@("1N97=M86EL8F]X97-;)&)O
M>%T@/2!(;W)D93HZ:6UG*`HO+R`@("`@("`@("`@("`@("`@("`@("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G:W)O;F]L:71H)RDL"B\O
M("`@("`@("`@("`@("`@("`@("`@7R@B0V%L96YD87(B*2P*+R\@("`@("`@
M("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB
M=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B\O("`@("`@("`@("`@("`@("`@
M("`@)R<*+R\@("`@("`@("`@("`@("`@("D["B\O("`@("`@("`@("`@('T@
M96QS96EF("AS=')P;W,H)&)O>"P@(DE.0D]8+U1A<VMS(BD@(3T](&9A;'-E
M"B\O("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O6UXO
M72LO5&%S:W,A(BP@)&)O>"DI('L*+R\@("`@("`@("`@("`@("`@("1N97=M
M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO+R`@("`@("`@("`@("`@
M("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G;F%G
M)RDL"B\O("`@("`@("`@("`@("`@("`@("`@7R@B5&%S:W,B*2P*+R\@("`@
M("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL
M93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B\O("`@("`@("`@("`@("`@
M("`@("`@)R<*+R\@("`@("`@("`@("`@("`@("D["B\O("`@("`@("`@("`@
M('T@96QS96EF("AS=')P;W,H)&)O>"P@(DE.0D]8+TYO=&5S(BD@(3T](&9A
M;'-E"B\O("`@("`@("`@("`@("`@("!\?"!P<F5G7VUA=&-H*"(A7G5S97(O
M6UXO72LO3F]T97,A(BP@)&)O>"DI('L*+R\@("`@("`@("`@("`@("`@("1N
M97=M86EL8F]X97-;)&)O>%T@/2!(;W)D93HZ:6UG*`HO+R`@("`@("`@("`@
M("`@("`@("`@("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G
M;6YE;6\G*2P*+R\@("`@("`@("`@("`@("`@("`@("!?*").;W1E<R(I+`HO
M+R`@("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE:6=H=#TB,38B
M('-T>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*+R\@("`@("`@("`@
M("`@("`@("`@("`G)PHO+R`@("`@("`@("`@("`@("`@*3L*+R\@("`@("`@
M("`@("`@?2!E;'-E:68@*'-T<G!O<R@D8F]X+"`B24Y"3U@O0V]N=&%C=',B
M*2`A/3T@9F%L<V4*+R\@("`@("`@("`@("`@("`@('Q\('!R96=?;6%T8V@H
M(B%>=7-E<B];7B]=*R]#;VYT86-T<R$B+"`D8F]X*2D@>PHO+R`@("`@("`@
M("`@("`@("`@)&YE=VUA:6QB;WAE<ULD8F]X72`]($AO<F1E.CII;6<H"B\O
M("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E
M="@G:6-O;B<L("=T=7)B82<I+`HO+R`@("`@("`@("`@("`@("`@("`@(%\H
M(D-O;G1A8W1S(BDL"B\O("`@("`@("`@("`@("`@("`@("`@)W=I9'1H/2(Q
M-B(@:&5I9VAT/2(Q-B(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N.FUI9&1L92(G
M+`HO+R`@("`@("`@("`@("`@("`@("`@("<G"B\O("`@("`@("`@("`@("`@
M("`I.PHO+R`@("`@("`@("`@("!]"B\O("`@("`@("`@?0HO+PHO+R`@("`@
M("`@(')E='5R;B`D;F5W;6%I;&)O>&5S.PHO+R`@("`@?0HO+R!]"@HO+R!4
M:&ES(&ES(&%N(&5X86UP;&4@:&]O:R!F=6YC=&EO;B!F;W(@=&AE($E-4"!S
M<&%M(')E<&]R=&EN9R!B;W5C92!O<'1I;VXN"B\O(%1H:7,@9G5N8W1I;VX@
M:7,@8V%L;&5D('=H96X@=&AE(&UE<W-A9V4@:7,@86)O=70@=&\@8F4@8F]U
M;F-E9"`M(&ET"B\O('=I;&P@<F5T=7)N('1H92!E;6%I;"!A9&1R97-S('1O
M(&)O=6YC92!T;RX@(%1H:7,@:7,@:&%N9'D@9F]R('-P86T*+R\@<F5P;W)T
M:6YG('-O9G1W87)E("AE+F<N($134$%-*2!W:&EC:"!H87,@9&EF9F5R96YT
M(&4M;6%I;"!A;&EA<V5S(&9O<@HO+R!S<&%M(')E<&]R=&EN9R!F;W(@96%C
M:"!U<V5R+@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]I;7!?:&]O:U]S
M<&%M7V)O=6YC92<I*2!["B\O("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?<W!A
M;5]B;W5N8V4H)&%C=&EO;BD*+R\@("`@('L*+R\@("`@("`@("`D<')E9FEX
M(#T@*"1A8W1I;VX@/3T@)W-P86TG*2`_("=S<&%M+2<@.B`G9G`M)SL*+R\@
M("`@("`@("!R971U<FX@)'!R969I>"`N($%U=&@Z.F=E=$)A<F5!=71H*"D@
M+B`G0&5X86UP;&4N8V]M)SL*+R\@("`@('T*+R\@?0H*+R\@2&5R92!A;B!E
M>&%M<&QE(%]S86U?:&]O:U]U<V5R;F%M92!F=6YC=&EO;B!T;R!S970@=&AE
M('5S97)N86UE('1H870*+R\@4W!A;4%S<V%S<VEN('-E97,@=&\@;VYE(&1I
M9F9E<F5N="!F<F]M('1H92!(;W)D92!U<V5R;F%M92X*"B\O(&EF("@A9G5N
M8W1I;VY?97AI<W1S*"=?<V%M7VAO;VM?=7-E<FYA;64G*2D@>PHO+R`@("`@
M9G5N8W1I;VX@7W-A;5]H;V]K7W5S97)N86UE*"1H;W)D95]U:60I"B\O("`@
M("!["B\O("`@("`@("`@:68@*'-T<G-T<B@D:&]R9&5?=6ED+"`G0"<I*2![
M"B\O("`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)T`G+"`D:&]R9&5?
M=6ED*3L*+R\@("`@("`@("`@("`@<F5T=7)N("1P87)T<ULP73L*+R\@("`@
M("`@("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R971U<FX@)&AO<F1E7W5I
M9#L*+R\@("`@("`@("!]"B\O("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@
M97AA;7!L92!?='5R8F%?:&]O:U]E;F-O9&5?<&%S<W=O<F0@*&%N9"!D96-O
M9&4I+B!E;F-O9&4@:7,*+R\@8V%L;&5D('=H96X@=V4@<W1O<F4@82!V86QU
M93L@9&5C;V1E('=H96X@=V4@9&ES<&QA>2!I="X@(%!A<W-W;W)D<R!S:&]U
M;&0*+R\@8F4@340U(&5N8V]D960L(&)U="!N;W0@9&ES<&QA>65D+@HO+PHO
M+R!)35!/4E1!3E0Z(%1H92!L87-T('!A<F%M971E<B!I;B!T:&5S92!E>&%M
M<&QE<R`H)B1O8FIE8W0I(&ES(&]N;'D*+R\@<&%S<V5D(&)Y(%1U<F)A(#(N
M,2!A;F0@;&%T97(N($EF('EO=2!A<F4@=7-I;F<@5'5R8F$@,BXP+"!T:&5N
M('EO=0HO+R!M=7-T(')E;6]V92!T:&4@)B1O8FIE8W0@<&%R86UE=&5R+@H*
M+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]T=7)B85]H;V]K7V5N8V]D95]P
M87-S=V]R9"<I*2!["B\O("`@("!F=6YC=&EO;B!?='5R8F%?:&]O:U]E;F-O
M9&5?<&%S<W=O<F0H)&YE=U]P87-S=V]R9"P@)&]L9%]P87-S=V]R9"P@)B1C
M;VYT86-T*0HO+R`@("`@>PHO+R`@("`@("`@(&EF("AI<U]N=6QL*"1N97=?
M<&%S<W=O<F0I('Q\("1N97=?<&%S<W=O<F0@/3T@)R<@?'P*+R\@("`@("`@
M("`@("`@)&YE=U]P87-S=V]R9"`]/2`G6TYO="!$:7-P;&%Y961=)RD@>PHO
M+R`@("`@("`@("`@("!R971U<FX@)&]L9%]P87-S=V]R9#L*+R\@("`@("`@
M("!](&5L<V4@>PHO+R`@("`@("`@("`@("!R971U<FX@;60U*"1N97=?<&%S
M<W=O<F0I.PHO+R`@("`@("`@('T*+R\@("`@('T*+R\@("`@(&9U;F-T:6]N
M(%]T=7)B85]H;V]K7V1E8V]D95]P87-S=V]R9"@D<&%S<W=O<F0L("8D8V]N
M=&%C="D*+R\@("`@('L*+R\@("`@("`@("!I9B`H<W1R<W1R*"1?4T525D52
M6R=02%!?4T5,1B==+"`G961I=&]B:F5C="<I*2!["B\O("`@("`@("`@("`@
M(')E='5R;B!N=6QL.PHO+R`@("`@("`@('T@96QS92!["B\O("`@("`@("`@
M("`@(')E='5R;B`G6TYO="!$:7-P;&%Y961=)SL*+R\@("`@("`@("!]"B\O
M("`@("!]"B\O('T*"B\O($AE<F4@:7,@86X@97AA;7!L92!?<&%S<W=D7VAO
M;VM?=7-E<FYA;64@9G5N8W1I;VX@=&\@=')A;G-L871E('=H870@=&AE"B\O
M('5S97(@96YT97)S+"!I;B!T:&4@=7-E<FYA;64@8F]X+"!I;G1O('=H870@
M=&AE(&)A8VME;F0@97AP96-T<RX@268@=V4@=V%N=`HO+R!T;R!A9&0@0&5X
M86UP;&4N8V]M('1O('1H92!E;F0@;V8@=&AE('5S97)N86UE('1H96X@96YA
M8FQE('1H92!H;V]K(&%N9"!U<V4*+R\@=&AI<R!F=6YC=&EO;BX*"B\O(&EF
M("@A9G5N8W1I;VY?97AI<W1S*"=?<&%S<W=D7VAO;VM?=7-E<FYA;64G*2D@
M>PHO+R`@("`@9G5N8W1I;VX@7W!A<W-W9%]H;V]K7W5S97)N86UE*"1U<V5R
M:60I"B\O("`@("!["B\O("`@("`@("`@<F5T=7)N("1U<V5R:60@+B`G0&5X
M86UP;&4N8V]M)SL*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M
M<&QE(%]P87-S=V1?:&]O:U]D969A=6QT7W5S97)N86UE(&9U;F-T:6]N('1O
M('-E="!T:&4*+R\@=7-E<FYA;64@=&AE('!A<W-W9"!M;V1U;&4@<V5E<R!W
M:&5N(')E<V5T=&EN9R!P87-S=V]R9',@8F%S960@;VX@=7-E<FED"B\O(&%N
M9"!R96%L;2X@(%1H92!D969A=6QT(&ES('1O('1A:V4@82!U<V5R;F%M92!O
M9B!U<V5R0&1O;6%I;BYT;&0@86YD(&-H86YG90HO+R!I="!T;R!U<V5R+B`@
M268@=V4@=V%N="!T;R!L96%V92!I="!U;G1O=6-H960L(&5N86)L92!T:&4@
M:&]O:R!A;F0@=7-E('1H:7,*+R\@9G5N8W1I;VXN"@HO+R!I9B`H(69U;F-T
M:6]N7V5X:7-T<R@G7W!A<W-W9%]H;V]K7V1E9F%U;'1?=7-E<FYA;64G*2D@
M>PHO+R`@("`@9G5N8W1I;VX@7W!A<W-W9%]H;V]K7V1E9F%U;'1?=7-E<FYA
M;64H)'5S97)I9"D*+R\@("`@('L*+R\@("`@("`@("!R971U<FX@)'5S97)I
M9#L*+R\@("`@('T*+R\@?0H*+R\@2&5R92!I<R!A;B!E>&%M<&QE(%]P87-S
M=V1?:&]O:U]U<V5R9&X@9G5N8W1I;VX@=&AA="!Y;W4@8V%N('5S92!T;R!P
M<F]V:61E"B\O('EO=7(@;&1A<"!S97)V97(@=VET:"!A('5S97)D;B!S;R!T
M:&%T('EO=2!D;R!N;W0@:&%V92!T;R!P97)F;W)M(&%N;VYY;6]U<PHO+R!B
M:6YD<RX@5&AE(&9U;F-T:6]N('1A:V5S($%U=&@Z.F=E=$%U=&@H*2!A<R!A
M('!A<F%M971E<@H*+R\@:68@*"%F=6YC=&EO;E]E>&ES=',H)U]P87-S=V1?
M:&]O:U]U<V5R9&XG*2D@>PHO+R`@("`@9G5N8W1I;VX@7W!A<W-W9%]H;V]K
M7W5S97)D;B@D875T:"D*+R\@("`@('L*+R\@("`@("`@("!R971U<FX@)W5I
M9#TG("X@)&%U=&@@+B`G+&\]97AA;7!L92YC;VTG.PHO+R`@("`@?0HO+R!]
M"@HO+R!4:&ES(&ES(&%N(&5X86UP;&4@;V8@82!H;V]K('1O('-E="!C=7-T
M;VT@=&%G<R!T;R!B92!I;F-L=61E9"!I;B!A($=I87!E=&\*+R\@<&%G92!T
M96UP;&%T92X@26X@=&AI<R!E>&%M<&QE(&$@=&%G(&-O;G1A:6YI;F<@=&AE
M(&-U<G)E;G0@9&%T92!I<R!S970@=&\*+R\@=&AE("1T96UP;&%T92!O8FIE
M8W0@86YD('=H:6-H(&ES('1H96X@879A:6QA8FQE(&EN('1H92!P86=E('1E
M;7!L871E(&%S.@HO+R`@("`@/'1A9SID871E("\^"@HO+R!I9B`H(69U;F-T
M:6]N7V5X:7-T<R@G7V=I87!E=&]?:&]O:U]S971T86=S)RDI('L*+R\@("`@
M(&9U;F-T:6]N(%]G:6%P971O7VAO;VM?<V5T=&%G<R@F)'1E;7!L871E*0HO
M+R`@("`@>PHO+R`@("`@("`@("1T96UP;&%T92T^<V5T*"=D871E)RP@<W1R
M9G1I;64H)R5A+"`E92`E8B`E62<I*3L*+R\@("`@('T*+R\@?0H*+R\@5&AI
M<R!I<R!A;B!E>&%M<&QE(&]F(&$@9W)O=7`@:&]O:RX@(%1O('5S92!I="!Y
M;W4@;75S="!S970@=&AE(&=R;W5P"B\O(&1R:79E<B!T;R!H;V]K<R!I;B!C
M;VYF+G!H<"X@(%1H96X@>6]U(&UU<W0@8W)E871E(&$@251?9&5P87)T;65N
M="!G<F]U<`HO+R`H8F5C875S92!T:&%T(&ES(&AO=R!W92!K;F]W('=H870@
M:&]O:R!T;R!C86QL*2X@(%EO=2!C86X@861D('5S97)S('1O('1H90HO+R!G
M<F]U<"!A<R!N;W)M86PL(&%N9"!I;B!A9&1I=&EO;B!T:&ES(&9U;F-T:6]N
M('=I;&P@8F4@8V%L;&5D('1O"B\O(&1Y;F%M:6-A;&QY(&EN8VQU9&4@=7-E
M<G,@:6X@=&AE(&=R;W5P+B`@26X@=&AI<R!E>&%M<&QE('=E('=I;&P@;&]O
M:R!U<`HO+R!W:&5T:&5R(&]R(&YO="!T:&ES('5S97(@:7,@<&%R="!O9B!T
M:&4@250@9&5P87)T;65N="!U<VEN9R!A;B!E>'1E<FYA;`HO+R!D871A8F%S
M92X*"B\O($1E9F%U;'0@2V]L86(@:&]O:W,Z"FEF("@A96UP='DH)$=,3T)!
M3%-;)V-O;F8G75LG:V]L86(G75LG96YA8FQE9"==*2D@>PH@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]+;VQA8BYP:'`G.PH@("`@:68@*"%F=6YC=&EO;E]E
M>&ES=',H)U]H;W)D95]H;V]K7W-H87)E7VEN:70G*2D@>PH@("`@("`@(&9U
M;F-T:6]N(%]U<V5R;F%M95]H;V]K7V9R;VUB86-K96YD*"1U<V5R240I"B`@
M("`@("`@>PH@("`@("`@("`@("`O+R!#;VYN96-T('1O('1H92!,1$%0('-E
M<G9E<BX*("`@("`@("`@("`@)&1S(#T@;&1A<%]C;VYN96-T*`H@("`@("`@
M("`@("`@("`@)$=,3T)!3%-;)V-O;F8G75LG:V]L86(G75LG;&1A<"==6R=S
M97)V97(G72P*("`@("`@("`@("`@("`@("1'3$]"04Q36R=C;VYF)UU;)VMO
M;&%B)UU;)VQD87`G75LG<&]R="=="B`@("`@("`@("`@("D["B`@("`@("`@
M("`@(&EF("@A)&1S*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'5S97))
M1#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!L9&%P7W-E=%]O<'1I;VXH
M)&1S+"!,1$%07T]05%]04D]43T-/3%]615)324].+"`S*3L*("`@("`@("`@
M("`@+R\@0FEN9"!A;F]N>6UO=7-L>2X*("`@("`@("`@("`@)')E<W5L="`]
M($!L9&%P7V)I;F0H)&1S*3L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'5S97))1#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`O+R!&:6YD('1H92!U<V5R)W,@1$XN"B`@("`@("`@
M("`@("1R97-U;'0@/2!L9&%P7W-E87)C:"@*("`@("`@("`@("`@("`@("1D
M<RP*("`@("`@("`@("`@("`@("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;
M)VQD87`G75LG8F%S961N)UTL"B`@("`@("`@("`@("`@("`G=6ED/2<@+B`D
M=7-E<DE$"B`@("`@("`@("`@("D["B`@("`@("`@("`@("1E;G1R>2`](&QD
M87!?9FER<W1?96YT<GDH)&1S+"`D<F5S=6QT*3L*("`@("`@("`@("`@:68@
M*"1E;G1R>2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("\O(%1H92!U
M<V5R(&%L<F5A9'D@875T:&5N=&EC871E9"!W:71H(&AI<R!E;6%I;"!A9&1R
M97-S+@H@("`@("`@("`@("`@("`@<F5T=7)N("1U<V5R240["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&5M86EL(#T@;&1A<%]G971?=F%L=65S*"1D
M<RP@)&5N=')Y+"`G;6%I;"<I.PH@("`@("`@("`@("!R971U<FX@)&5M86EL
M6S!=.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?:&]R9&5?:&]O:U]S
M:&%R95]I;FET*"8D<VAA<F5?;V)J96-T+"`D87!P*0H@("`@("`@('L*("`@
M("`@("`@("`@2V]L86(Z.G-Y;F-H<F]N:7-E4VAA<F5S*"1S:&%R95]O8FIE
M8W0L("1A<'`I.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?:&]R9&5?
M:&]O:U]S:&%R95]A9&0H)B1S:&%R92D*("`@("`@("!["B`@("`@("`@("`@
M(')E='5R;B!+;VQA8CHZ=7!D871E4VAA<F4H)'-H87)E*3L*("`@("`@("!]
M"B`@("`@("`@9G5N8W1I;VX@7VAO<F1E7VAO;VM?<VAA<F5?;6]D:69Y*"8D
M<VAA<F4I"B`@("`@("`@>PH@("`@("`@("`@("!R971U<FX@2V]L86(Z.G5P
M9&%T95-H87)E*"1S:&%R92D["B`@("`@("`@?0H@("`@("`@(&9U;F-T:6]N
M(%]H;W)D95]H;V]K7W-H87)E7W)E;6]V92@F)'-H87)E*0H@("`@("`@('L*
M("`@("`@("`@("`@<F5T=7)N($MO;&%B.CIR96UO=F53:&%R92@D<VAA<F4I
M.PH@("`@("`@('T*("`@("`@("!F=6YC=&EO;B!?:6UP7VAO;VM?;6)O>%]R
M961I<F5C="@D;6%I;&)O>"D*("`@("`@("!["B`@("`@("`@("`@('-W:71C
M:"`H2V]L86(Z.F=E=$UA:6QB;WA4>7!E*"1M86EL8F]X*2D@>PH@("`@("`@
M("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=K<F]N;VQI=&@G
M*3L*"B`@("`@("`@("`@(&-A<V4@)W1A<VLG.@H@("`@("`@("`@("`@("`@
M<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G
M;F%G)RD["@H@("`@("`@("`@("!C87-E("=N;W1E)SH*("`@("`@("`@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T
M)RP@)VUN96UO)RD["@H@("`@("`@("`@("!C87-E("=C;VYT86-T)SH*("`@
M("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M*"=W96)R;V]T)RP@)W1U<F)A)RD["@H@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&9U;F-T:6]N(%]I;7!?:&]O:U]M8F]X7VEC;VYS*"D*
M("`@("`@("!["B`@("`@("`@("`@('-T871I8R`D:6-O;G,["@H@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1I8V]N<RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D:6-O;G,["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F;VQD
M97)S(#T@2V]L86(Z.FQI<W1&;VQD97)S*"D["@H@("`@("`@("`@("`D:6-O
M;G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@9F]R96%C:"`H)&9O;&1E<G,@
M87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!P<F5G7W)E
M<&QA8V4H)R]>>UM>?5TK?2\G+"`G)RP@)&9O;&1E<ELP72D["@H@("`@("`@
M("`@("`@("`@<W=I=&-H("@D9F]L9&5R6S%=*2!["B`@("`@("`@("`@("`@
M("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("`@("`@)&EC;VYS6R1N
M86UE72`]($AO<F1E.CII;6<H"B`@("`@("`@("`@("`@("`@("`@("`@("1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)VEC;VXG+"`G:W)O;F]L:71H)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(D-A;&5N9&%R(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=W:61T:#TB,38B(&AE:6=H=#TB,38B('-T
M>6QE/2)V97)T:6-A;"UA;&EG;CIM:61D;&4B)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@)R<*("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W1A<VLG
M.@H@("`@("`@("`@("`@("`@("`@("1I8V]N<ULD;F%M95T@/2!(;W)D93HZ
M:6UG*`H@("`@("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=I8V]N)RP@)VYA9R<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("!?*")487-K<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G=VED
M=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED
M9&QE(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<G"B`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@("`@("!C87-E("=N;W1E)SH*("`@("`@("`@("`@("`@("`@("`D
M:6-O;G-;)&YA;65=(#T@2&]R9&4Z.FEM9R@*("`@("`@("`@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:6-O;B<L("=M;F5M
M;R<I+`H@("`@("`@("`@("`@("`@("`@("`@("!?*").;W1E<R(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S
M='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("<G"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=C;VYT
M86-T)SH*("`@("`@("`@("`@("`@("`@("`D:6-O;G-;)&YA;65=(#T@2&]R
M9&4Z.FEM9R@*("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E
M9VES=')Y)UTM/F=E="@G:6-O;B<L("=T=7)B82<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("!?*")#;VYT86-T<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G=VED=&@](C$V(B!H96EG:'0](C$V(B!S='EL93TB=F5R=&EC86PM
M86QI9VXZ;6ED9&QE(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("<G"B`@
M("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<F5T=7)N("1I8V]N<SL*("`@("`@("!]"B`@("!]"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O971C+W!S
M82UH;W)D92]H;W)D92]C;VYF+GAM;```````````````````````````````
M```````````````````````````````````````````````P,#`T-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#(P-#$R,R`Q,#4Q-30S-#$U,B`P,C$P-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]X
M;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]C;VYF:6<O
M8V]N9BYX;6PL=B`Q+C<T+C(N-#$@,C`P-B\P."\P-"`Q-SHQ,SHR-2!J86X@
M17AP("0@+2T^"CQC;VYF:6=U<F%T:6]N/@H@/&-O;F9I9W1A8B!N86UE/2)G
M96YE<F%L(B!D97-C/2)'96YE<F%L(CX*("`\8V]N9FEG:&5A9&5R/D=E;F5R
M86P@2&]R9&4@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`\8V]N9FEG<&AP
M(&YA;64](F1E8G5G7VQE=F5L(B!D97-C/2)4:&4@=F%L=64@=&\@<V5T"B`@
M97)R;W)?<F5P;W)T:6YG*"D@=&\N"B`@4V5E(&AT='`Z+R]W=W<N<&AP+FYE
M="]M86YU86PO9G5N8W1I;VXN97)R;W(M<F5P;W)T:6YG+G!H<"!F;W(@;6]R
M90H@(&EN9F]R;6%T:6]N(&%N9"!P;W-S:6)L92!V86QU97,N(CY%7T%,3"`F
M86UP.R!^15].3U1)0T4\+V-O;F9I9W!H<#X*("`\8V]N9FEG:6YT96=E<B!N
M86UE/2)M87A?97AE8U]T:6UE(B!D97-C/2))9B!W92!N965D('1O('!E<F9O
M<FT@82!L;VYG"B`@;W!E<F%T:6]N+"!W:&%T('-H;W5L9"!W92!S970@;6%X
M7V5X96-U=&EO;E]T:6UE('1O("AI;B!S96-O;F1S*3\@,"!M96%N<R!N;PH@
M(&QI;6ET.R!H;W=E=F5R+"!A('9A;'5E(&]F(#`@=VEL;"!C875S92!A('=A
M<FYI;F<@:68@>6]U(&%R92!R=6YN:6YG(&EN('-A9F4*("!M;V1E+B!3964@
M:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]F=6YC=&EO;BYS970M=&EM92UL
M:6UI="YP:'`@9F]R(&UO<F4*("!I;F9O<FUA=&EO;BXB/C`\+V-O;F9I9VEN
M=&5G97(^"B`@/&-O;F9I9V5N=6T@;F%M93TB=7-E7W-S;"(@<75O=&4](F9A
M;'-E(B!D97-C/2)$971E<FUI;F5S(&AO=R!W92!G96YE<F%T90H@(&9U;&P@
M55),<R`H9F]R(&QO8V%T:6]N(&AE861E<G,@86YD('-U8V@I+B9L=#MB<B`O
M)F=T.TY/5$4Z($EF('EO=2!C:&]O<V4@=&\*("!A;'=A>7,@9V5N97)A=&4@
M:'1T<',@55),<RP@>6]U($U54U0@:&%R9&-O9&4@=&AE(&-O<G)E8W0@2%14
M4%,@<&]R="!N=6UB97(*("!I;B!T:&4@<V5R=F5R('!O<G0@<V5T=&EN9R!B
M96QO=RX@3W1H97)W:7-E($AO<F1E('=I;&P@8F4@=6YA8FQE('1O(&=E;F5R
M871E"B`@8V]R<F5C="!(5%104R!54DQS('=H96X@82!U<V5R('1R:65S('1O
M(&%C8V5S<R!(;W)D92!V:6$@82!N;VXM2%144%,@<&]R="XB/C(*("`@/'9A
M;'5E<SX*("`@(#QV86QU92!D97-C/2)!<W-U;64@=&AA="!W92!A<F4@;F]T
M('5S:6YG(%-33"!A;F0@;F5V97(@9V5N97)A=&4@:'1T<',@55),<RXB/C`\
M+W9A;'5E/@H@("`@/'9A;'5E(&1E<V,](D%S<W5M92!T:&%T('=E(&%R92!U
M<VEN9R!34TP@86YD(&%L=V%Y<R!G96YE<F%T92!H='1P<R!54DQS+B(^,3PO
M=F%L=64^"B`@("`\=F%L=64@9&5S8STB071T96UP="!T;R!A=71O+61E=&5C
M="P@86YD(&=E;F5R871E(%523',@87!P<F]P<FEA=&5L>2(^,CPO=F%L=64^
M"B`@("`\=F%L=64@9&5S8STB07-S=6UE('1H870@=V4@87)E(&YO="!U<VEN
M9R!34TP@86YD(&=E;F5R871E(&AT='!S(%523',@;VYL>0H@("`@9F]R(&QO
M9VEN+B(^,SPO=F%L=64^"B`@(#PO=F%L=65S/@H@(#PO8V]N9FEG96YU;3X*
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S97)V97(B/@H@("`\8V]N9FEG<&AP
M(&YA;64](FYA;64B(&1E<V,](E=H870@<V5R=F5R(&YA;64@<VAO=6QD('=E
M('5S93\@66]U)VQL('!R;V)A8FQY"B`@(&MN;W<@:68@>6]U(&YE960@=&\@
M8VAA;F=E('1H:7,@9&5F875L=#L@;VYL>2!I;B!S:71U871I;VYS('=H97)E
M('EO=2!N965D('1O"B`@(&]V97)R:61E('=H870@07!A8VAE('1H:6YK<R!T
M:&4@<V5R=F5R(&YA;64*("`@:7,N(CXD7U-%4E9%4ELG4T525D527TY!344G
M73PO8V]N9FEG<&AP/@H@("`\8V]N9FEG<&AP(&YA;64](G!O<G0B(&1E<V,]
M(E=H870@<&]R="!N=6UB97(@:7,@=&AE('=E8G-E<G9E<B!R=6YN:6YG(&]N
M/PH@("!!9V%I;BP@>6]U('-H;W5L9&XG="!N965D('1O(&-H86YG92!T:&4@
M9&5F875L="P@86YD('EO=2!P<F]B86)L>2!K;F]W(&ET(&EF"B`@('EO=2!D
M;RX@5&AE(&5X8V5P=&EO;B!I<R!I9B!Y;W4@:&%V92!C:&]S96X@=&\@86QW
M87ES(&=E;F5R871E(&AT='!S(%523',L(&%S"B`@(&1E<V-R:6)E9"!A8F]V
M92XB/B1?4T525D526R=315)615)?4$]25"==/"]C;VYF:6=P:'`^"B`@/"]C
M;VYF:6=S96-T:6]N/@H@(#QC;VYF:6=B;V]L96%N(&YA;64](F-O;7!R97-S
M7W!A9V5S(B!D97-C/2))9B!T:&ES(&]P=&EO;B!I<R!S970@=&\@=')U92P@
M86YD"B`@>6]U(&AA=F4@=&AE('!H<"!Z;&EB(&5X=&5N<VEO;BP@<&%G97,@
M;W9E<B!A(&-E<G1A:6X@<VEZ92!W:6QL(&)E(&-O;7!R97-S960*("!A;F0@
M<V5N="!T;R!T:&4@8G)O=W-E<B!A<R!G>FEP+65N8V]D960@9&%T82!I;B!O
M<F1E<B!T;R!S879E"B`@8F%N9'=I9'1H+B!4:&5R92!I<R!A($-052UU<V%G
M92!P96YA;'1Y('1O('!A>2!F;W(@=&AI<RP@8G5T('1H92!D96-R96%S92!I
M;@H@('!A9V4@<VEZ92!C86X@8F4@9')A;6%T:6,@*#<P:R!T;R!U;F1E<B`Q
M,&L@9F]R(&$@9G5L;"!M86EL8F]X('!A9V4I+"!A;F0@:7,*("!M;W)E('1H
M86X@=V]R=&@@:70@;W9E<B!A;GET:&EN9R!B=70@86X@97AT<F5M96QY(&9A
M<W0*("!L:6YK+B(^=')U93PO8V]N9FEG8F]O;&5A;CX*("`\8V]N9FEG:6YT
M96=E<B!N86UE/2)U;6%S:R(@;V-T86P](G1R=64B(&1E<V,](E=H870@=6UA
M<VL@<VAO=6QD('=E(')U;B!W:71H/R!4:&ES('=I;&P@869F96-T('1H92!P
M97)M:7-S:6]N<R!O;B!A;GD@=&5M<&]R87)Y(&9I;&5S('1H870@87)E(&-R
M96%T960N(%1H:7,@=F%L=64@:7,@86X@:6YT96=E<BXB/C`W-SPO8V]N9FEG
M:6YT96=E<CX*("`\8V]N9FEG<W1R:6YG(&YA;64](G1M<&1I<B(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2))9B!Y;W4@=V%N="!T;R!U<V4@80H@('1E;7!O
M<F%R>2!D:7)E8W1O<GD@;W1H97(@=&AA;B!T:&4@<WES=&5M(&1E9F%U;'0@
M;W(@=&AE(&]N92!S<&5C:69I960@:6X*("!P:'`G<R!U<&QO861?=&UP7V1I
M<B!V86QU92P@96YT97(@:70@:&5R92XB+SX*("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)S97-S:6]N(CX*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D
M97-C/2)7:&%T(&YA;64@<VAO=6QD('=E('5S92!F;W(@=&AE('-E<W-I;VX@
M=&AA=`H@("!(;W)D92!A<'!S('-H87)E/R!)9B!Y;W4@=V%N="!T;R!S:&%R
M92!S97-S:6]N<R!W:71H(&]T:&5R(&%P<&QI8V%T:6]N<R!O;@H@("!Y;W5R
M('=E8G-E<G9E<BP@>6]U('=I;&P@;F5E9"!T;R!M86ME('-U<F4@=&AA="!T
M:&5Y(&%R92!U<VEN9R!T:&4@<V%M90H@("!S97-S:6]N(&YA;64N("!.;W1E
M.B!397-S:6]N(&YA;65S(&UU<W0@8V]N<VES="!O9B!O;FQY(&%L<&AA;G5M
M97)I8PH@("!C:&%R86-T97)S+B(^2&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@
M/&-O;F9I9V)O;VQE86X@;F%M93TB=7-E7V]N;'E?8V]O:VEE<R(@9&5S8STB
M4VAO=6QD('=E(&]N;'D@86QL;W<@<V5S<VEO;@H@("!I;F9O<FUA=&EO;B!T
M;R!B92!S=&]R960@:6X@82!S97-S:6]N(&-O;VMI92!A;F0@;F]T(&)E('!A
M<W-E9"!B>2!54DP@*$=%5"D*("`@<&%R86UE=&5R<S\@5&AI<R!I<R!O;B!B
M>2!D969A=6QT(&)E8V%U<V4@<&%S<VEN9R!S97-S:6]N(&EN9F]R;6%T:6]N
M(&EN"B`@('1H92!54DP@:7,@82!S96-U<FET>2!R:7-K+B!#;VYS:61E<B!C
M87)E9G5L;'D@8F5F;W)E('1U<FYI;F<@:70@;V9F+B(^"B`@('1R=64\+V-O
M;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB8V%C:&5?;&EM
M:71E<B(@9&5S8STB5VAA="!C86-H:6YG(&QE=F5L('-H;W5L9"!W92!U<V4*
M("`@9F]R('1H92!S97-S:6]N/R!$3R!.3U0@0TA!3D=%(%1(25,@54Y,15-3
M(%E/52`F;'0[<W1R;VYG)F=T.U)%04Q,629L=#LO<W1R;VYG)F=T.R!+3D]7
M"B`@(%=(050@64]5($%212!$3TE.1RX@4V5T=&EN9R!T:&ES('1O(&%N>71H
M:6YG(&]T:&5R('1H86X@)VYO8V%C:&4G('=I;&P@86QM;W-T"B`@(&-E<G1A
M:6YL>2!R97-U;'0@:6X@<V5V97)E;'D@8G)O:V5N('-C<FEP="!B96AA=FEO
M<BXB/FYO8V%C:&4\+V-O;F9I9W-T<FEN9SX*("`@/&-O;F9I9VEN=&5G97(@
M;F%M93TB=&EM96]U="(@9&5S8STB2&]W(&QO;F<@<VAO=6QD('-E<W-I;VYS
M(&QA<W0@*&EN('-E8V]N9',I/R`P(&UE86YS"B`@('1H870@=&AE('-E<W-I
M;VX@96YD<R!W:&5N('1H92!U<V5R(&-L;W-E<R!T:&5I<B!B<F]W<V5R+B!3
M970@;W1H97(@=F%L=65S"B`@('=I=&@@8V%R92`M('-E90H@("!H='1P.B\O
M=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-E<W-I;VXM<V5T+6-O
M;VMI92UP87)A;7,N<&AP+B(^,#PO8V]N9FEG:6YT96=E<CX*("`\+V-O;F9I
M9W-E8W1I;VX^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB8V]O:VEE(CX*("`@
M/&-O;F9I9W!H<"!N86UE/2)D;VUA:6XB(&1E<V,](E=H870@9&]M86EN('-H
M;W5L9"!W92!S970@8V]O:VEE<R!F<F]M/R!)9@H@("!Y;W4@:&%V92!A(&-L
M=7-T97(@=&AA="!N965D<R!T;R!S:&%R92!C;V]K:65S+"!T:&ES(&UI9VAT
M(&)E("<N97AA;7!L92YC;VTG"B`@("T@=&AE(&QE861I;F<@)RXG(&ES(&EM
M<&]R=&%N="X@36]S="!L:6ME;'DL('1H;W5G:"P@>6]U('=O;B=T(&AA=F4@
M=&\@8VAA;F=E"B`@('1H92!D969A=6QT+B(^)%]315)615);)U-%4E9%4E].
M04U%)UT\+V-O;F9I9W!H<#X*("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P871H
M(B!D97-C/2)7:&%T('!A=&@@<VAO=6QD('=E('-E="!C;V]K:65S('1O/R!4
M:&ES"B`@('-H;W5L9"!M871C:"!W:&5R92!(;W)D92!I<R!O;B!Y;W5R('=E
M8G-E<G9E<B`M(&EF(&ET(&ES(&%T("]H;W)D92P@=&AE;B!T:&ES"B`@('-H
M;W5L9"!B92`G+VAO<F1E)RX@268@2&]R9&4@:7,@:6YS=&%L;&5D(&%S('1H
M92!D;V-U;65N="!R;V]T+"!T:&5N('1H:7,*("`@;F5E9',@=&\@8F4@)R\G
M("T@3D]4("<G+B9L=#MB<B`O)F=T.R9L=#MS=')O;F<F9W0[0E54)FQT.R]S
M=')O;F<F9W0[+"!I9B!)12!W:6QL(&)E"B`@('5S960@=&\@86-C97-S($AO
M<F1E(&UO9'5L97,L('EO=2!S:&]U;&0@<F5A9"!T:&ES(&9I<G-T("AD:7-C
M=7-S:6YG(&ES<W5E<PH@("!W:71H($E%)W,@0V]N=&5N="!!9'9I<V]R*3H*
M("`@:'1T<#HO+VQI<W1S+FAO<F1E+F]R9R]A<F-H:79E<R]I;7`O5V5E:RUO
M9BU-;VXM,C`P,S`Q,3,O,#(Y,30Y+FAT;6PB/B]H;W)D93PO8V]N9FEG<W1R
M:6YG/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF
M:6=T86(@;F%M93TB<W%L(B!D97-C/2)$871A8F%S92(^"B`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB<W%L(CX*("`@/&-O;F9I9VAE861E<CY(;W)D92!$871A
M8F%S92!3971T:6YG<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG9&5S8W)I
M<'1I;VX^)FQT.W-T<F]N9R9G=#M.3U1%.B9L=#LO<W1R;VYG)F=T.R!4:&5S
M92!A<F4@;VYL>2!T:&4*("`@)FQT.V5M)F=T.V1E9F%U;'0F;'0[+V5M)F=T
M.R!V86QU97,@9F]R(&%N>2!D871A8F%S92!D<FEV96X@8F%C:V5N9',N(%EO
M=0H@("!S=&EL;"!N965D('1O(&-O;F9I9W5R92!T:&4@9&EF9F5R96YT('-Y
M<W1E;7,@;&EK92`B4')E9F5R96YC97,B(&]R"B`@(")$871A5')E92(@=&\@
M86-T=6%L;'D@)FQT.V5M)F=T.W5S929L=#LO96TF9W0[(&$@9&%T86)A<V4*
M("`@8F%C:V5N9"X\+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`\8V]N9FEG<W%L
M('-W:71C:&YA;64](G!H<'1Y<&4B(&)A<V5C;VYF:6<](G1R=64B("\^"B`@
M/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N
M86UE/2)A=71H(B!D97-C/2)!=71H96YT:6-A=&EO;B(^"B`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB875T:"(^"B`@(#QC;VYF:6=H96%D97(^2&]R9&4@075T
M:&5N=&EC871I;VX\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9VQI<W0@;F%M
M93TB861M:6YS(B!D97-C/2)7:&EC:"!U<V5R<R!S:&]U;&0@8F4@=')E871E
M9"!A<PH@("!A9&UI;FES=')A=&]R<R`H<F]O="P@<W5P97(M=7-E<BD@8GD@
M2&]R9&4_(B!R97%U:7)E9#TB9F%L<V4B+SX*("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB8VAE8VMI<"(@9&5S8STB4VAO=6QD('=E(&%L=V%Y<R!S=&]R92!A
M;F0@=F%L:61A=&4*("`@=&AE($E0(&%D9')E<W,@;V8@=&AE(&-L:65N="`H
M87,@<V5E;B!B>2!T:&4@=V5B('-E<G9E<BD@:6X@=&AE('-E<W-I;VX_"B`@
M($1O:6YG('-O('=I;&P@:&5L<"!I;F-R96%S92!S96-U<FET>2!B>2!E;G-U
M<FEN9R!T:&%T(&%N(&%T=&%C:V5R(&9R;VT*("`@86YO=&AE<B!H;W-T(&-A
M;FYO="!T<GD@=&\@:&EJ86-K('1H92!S97-S:6]N+B(^=')U93PO8V]N9FEG
M8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB8VAE8VMB<F]W<V5R
M(B!D97-C/2)3:&]U;&0@=V4@86QW87ES('-T;W)E(&%N9"!V86QI9&%T90H@
M("!T:&4@8G)O=W-E<B!S=')I;F<@;V8@=&AE(&-L:65N="`H87,@<V5E;B!B
M>2!T:&4@=V5B('-E<G9E<BD@:6X@=&AE('-E<W-I;VX_"B`@($1O:6YG('-O
M('=I;&P@:&5L<"!I;F-R96%S92!S96-U<FET>2!B>2!E;G-U<FEN9R!T:&%T
M(&%N(&%T=&%C:V5R(&9R;VT*("`@86YO=&AE<B!H;W-T(&-A;FYO="!T<GD@
M=&\@:&EJ86-K('1H92!S97-S:6]N+B(^=')U93PO8V]N9FEG8F]O;&5A;CX*
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A;'1E<FYA=&5?;&]G:6XB(&1E<V,]
M(DEF('1H:7,@:7,@;F]T(&9A;'-E+"!I="!I<PH@("!A<W-U;65D('1O(&)E
M('1H92!54DP@;V8@86X@86QT97)N871E(&QO9VEN('-C<F5E;B!W:&EC:"!W
M:6QL(&)E('5S960@:6X*("`@<&QA8V4@;V8@:&]R9&4G<R!D969A=6QT(&QO
M9VEN('-C<F5E;BXB/F9A;'-E/"]C;VYF:6=S=')I;F<^"B`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB<F5D:7)E8W1?;VY?;&]G;W5T(B!D97-C/2))9B!T:&ES
M(&ES(&YO="!F86QS92P@:70@:7,*("`@87-S=6UE9"!T;R!B92!T:&4@55),
M(&]F(&%N(&%L=&5R;F%T92!L;V=O=70@<&%G92!W:&EC:"!U<V5R<R!W:6QL
M(&)E('-E;G0*("`@=&\@=VAE;B!T:&5Y(&QO9R!O=70N(CYF86QS93PO8V]N
M9FEG<W1R:6YG/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](F1R:79E<B(@9&5S
M8STB5VAA="!B86-K96YD('-H;W5L9"!W92!U<V4@9F]R"B`@(&%U=&AE;G1I
M8V%T:6YG('5S97)S('1O($AO<F1E/R(^"@H@("`@/&-A<V4@;F%M93TB87!P
M;&EC871I;VXB(&1E<V,](DQE="!A($AO<F1E(&%P<&QI8V%T:6]N(&AA;F1L
M90H@("`@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F%P<"(@9&5S
M8STB5&AE(&%P<&QI8V%T:6]N('=H:6-H(&ES('!R;W9I9&EN9PH@("`@("!A
M=71H96YT:6-A=&EO;B(^:6UP"B`@("`@("`\=F%L=65S/@H@("`@("`@(#QC
M;VYF:6=S<&5C:6%L(&YA;64](FQI<W0M:&]R9&4M87!P<R(O/@H@("`@("`@
M/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`\+V-O;F9I9W-E
M8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB875T;R(@9&5S
M8STB075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N(&%S(&$@8V5R=&%I;B!U<V5R
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G5S97)N86UE(B!D97-C/2)4:&4@=7-E<FYA
M;64@=&\@875T:&5N=&EC871E(&5V97)Y;VYE(&%S(CYH;W)D95]U<V5R/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O
M<F0B(&1E<V,](E1H92!P87-S=V]R9"!T;R!U<V4@9F]R('1H92!U<V5R)W,@
M8W)E9&5N=&EA;',B(')E<75I<F5D/2)F86QS92(O/@H@("`@("`\8V]N9FEG
M8F]O;&5A;B!N86UE/2)R97%U97-T=7-E<B(@9&5S8STB06QL;W<@=7-E<FYA
M;64@=&\@8F4@<&%S<V5D(&)Y($=%5"P@4$]35"!O<B!C;V]K:64_(CYF86QS
M93PO8V]N9FEG8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\
M+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB8V]M<&]S:71E(B!D97-C/2)#;VUP
M;W-I=&4@875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=D97-C<FEP=&EO
M;CX*("`@("`@5&AI<R!A=71H96YT:6-A=&EO;B!D<FEV97(@;F5E9',@;6%N
M=6%L(&-O;F9I9W5R871I;VX@;F]T('!O<W-I8FQE"B`@("`@('1H<F]U9V@@
M=&AI<R!I;G1E<F9A8V4N($%D9"!T:&4@87!P<F]P<FEA=&4@8V]N9FEG=7)A
M=&EO;B!L:6YE<R!A="!T:&4*("`@("`@96YD(&]F('1H92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@(#PO8V]N9FEG9&5S8W)I<'1I;VX^
M"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB9G1P(B!D97-C/2)&5%`@
M875T:&5N=&EC871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A
M<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E
M<V,](E1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S(&]F('1H92!&5%`*("`@
M("`@<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O
M;F9I9VEN=&5G97(@;F%M93TB<&]R="(@9&5S8STB5&AE('-E<G9E<B!P;W)T
M('1O(&-O;FYE8W0*("`@("`@=&\B/C(Q/"]C;VYF:6=I;G1E9V5R/@H@("`@
M(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE
M/2)H='1P(B!D97-C/2)(5%10("A"87-I8R!!=71H96YT:6-A=&EO;B\N:'1P
M87-S=V0I"B`@("!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H
M='!A<W-W9%]F:6QE(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!L;V-A
M=&EO;B!O9@H@("`@("!T:&4@:'1P87-S=V0@9FEL92!C;VYT86EN:6YG('1H
M92!U<V5R(&YA;65S(&%N9"!P87-S=V]R9',B+SX*("`@("`@/&-O;F9I9V5N
M=6T@;F%M93TB96YC<GEP=&EO;B(@9&5S8STB4W!E8VEF:65S('=H870@:VEN
M9"!O9B!P87-S=V]R9',@87)E"B`@("`@(&EN('1H92!H='!A<W-W9"!F:6QE
M(CYD97,*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A;'5E/F%P<FUD-3PO
M=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T/"]V86QU93X*("`@("`@("`\
M=F%L=64^8W)Y<'0M8FQO=V9I<V@\+W9A;'5E/@H@("`@("`@(#QV86QU93YC
M<GEP="UD97,\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UM9#4\+W9A
M;'5E/@H@("`@("`@(#QV86QU93YM9#4M8F%S938T/"]V86QU93X*("`@("`@
M("`\=F%L=64^;60U+6AE>#PO=F%L=64^"B`@("`@("`@/'9A;'5E/G!L86EN
M/"]V86QU93X*("`@("`@("`\=F%L=64^<VAA/"]V86QU93X*("`@("`@("`\
M=F%L=64^<VUD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/G-S:&$\+W9A;'5E
M/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`\
M+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB
M:6UA<"(@9&5S8STB24U!4"!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I
M9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-W:71C:"!N
M86UE/2)I;6%P8V]N9FEG(B!D97-C/2)#;VYF:6=U<F%T:6]N('1Y<&4B/@H@
M("`@("`@/&-A<V4@;F%M93TB9'-N(B!D97-C/2)$4TXB/@H@("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB9'-N(B!D97-C/2)4:&4@9G5L;"!)34%0(&-O
M;FYE8W1I;VX*("`@("`@("!S=')I;F<B/GML;V-A;&AO<W0Z,30S+VEM87`O
M;F]T;'-]/"]C;VYF:6=S=')I;F<^"B`@("`@("`\+V-A<V4^"B`@("`@("`\
M8V%S92!N86UE/2)S97!A<F%T92(@9&5S8STB4V5P87)A=&4@=F%L=65S(CX*
M("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)4
M:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4*("`@("`@("!S97)V
M97(B/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG/@H@("`@("`@(#QC;VYF:6=I
M;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E1H92!S97)V97(@<&]R="!T;R!W
M:&EC:"!W92!W:6QL"B`@("`@("`@8V]N;F5C="X@24U!4"!I<R!G96YE<F%L
M;'D@,30S+"!W:&EL92!)34%0+5-33"!I<R!G96YE<F%L;'D*("`@("`@("`Y
M.3,N(CXQ-#,\+V-O;F9I9VEN=&5G97(^"B`@("`@("`@/&-O;F9I9V5N=6T@
M;F%M93TB<')O=&]C;VPB(&1E<V,](E1H92!C;VYN96-T:6]N('!R;W1O8V]L
M(CYI;6%P+VYO=&QS"B`@("`@("`@(#QV86QU97,^"B`@("`@("`@("`\=F%L
M=64^:6UA<#PO=F%L=64^"B`@("`@("`@("`\=F%L=64^:6UA<"]N;W9A;&ED
M871E+6-E<G0\+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O;F]T;',\
M+W9A;'5E/@H@("`@("`@("`@/'9A;'5E/FEM87`O=&QS/"]V86QU93X*("`@
M("`@("`@(#QV86QU93YI;6%P+W1L<R]N;W9A;&ED871E+6-E<G0\+W9A;'5E
M/@H@("`@("`@("`@/'9A;'5E/FEM87`O<W-L/"]V86QU93X*("`@("`@("`@
M(#QV86QU93YI;6%P+W-S;"]N;W9A;&ED871E+6-E<G0\+W9A;'5E/@H@("`@
M("`@("`\+W9A;'5E<SX*("`@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@("`\
M+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@(#PO8V]N9FEG<V5C
M=&EO;CX*("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)I;7-P(B!D97-C
M/2))35-0('-E<G9E<B!A=71H96YT:6-A=&EO;B(@+SX*"B`@("`\8V%S92!N
M86UE/2)I<&)A<VEC(B!D97-C/2)3:6UP;&4@25`@8F%S960@875T:&5N=&EC
M871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=L:7-T(&YA;64](F)L;V-K<R(@9&5S8STB02!L:7-T(&]F
M($-)1%(@;6%S:W,@=VAI8V@@87)E(&%L;&]W960*("`@("`@86-C97-S(B\^
M"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC87-E
M(&YA;64](FEP;6%P(B!D97-C/2))4"!B87-E9"!A=71H96YT:6-A=&EO;B(^
M"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O
M;F9I9VQI<W0@;F%M93TB8FQO8VMS(B!D97-C/2)!(&QI<W0@;V8@0TE$4B!M
M87-K<R!W:&EC:"!A<F4@86QL;W=E9`H@("`@("!A8V-E<W,B+SX*("`@("`\
M+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB
M:W)B-2(@9&5S8STB2V5R8F5R;W,@875T:&5N=&EC871I;VXB+SX*"B`@("`\
M8V%S92!N86UE/2)K;VQA8B(@9&5S8STB2V]L86(@875T:&5N=&EC871I;VXB
M/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC
M;VYF:6=B;V]L96%N(&YA;64](FQO9VEN7V)L;V-K(B!D97-C/2)3:&]U;&0@
M=&AE(&QO9VEN(&)E(&)L;V-K960@869T97(@82!G:79E;B!N=6UB97(@;V8@
M9F%I;&5D(&QO9VEN<S\B/@H@("`@("!F86QS93PO8V]N9FEG8F]O;&5A;CX*
M("`@("`@/&-O;F9I9VEN=&5G97(@;F%M93TB;&]G:6Y?8FQO8VM?8V]U;G0B
M(&1E<V,](D%F=&5R(&AO=VUA;GD@9F%I;&5D(&QO9VEN<R!T:&4@;&]G:6X@
M<VAO=6QD(&)E(&)L;V-K960_(CXS/"]C;VYF:6=I;G1E9V5R/@H@("`@("`\
M8V]N9FEG:6YT96=E<B!N86UE/2)L;V=I;E]B;&]C:U]T:6UE(B!D97-C/2)(
M;W=M86YY(&UI;G5T97,@=&AE(&QO9VEN('-H;W5L9"!B92!B;&]C:V5D/R(^
M-3PO8V]N9FEG:6YT96=E<CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\
M+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S8STB3$1!4"!A=71H
M96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB
M5&AE(&AO<W1N86UE(&]F('1H92!,1$%0('-E<G9E<B(^;&]C86QH;W-T/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8F%S961N
M(B!D97-C/2)4:&4@8F%S92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R(B\^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8FEN9&1N(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!$3B!U<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R
M=F5R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A<W-W;W)D('5S960@=&\@8FEN
M9"!T;R!T:&4@3$1!4"!S97)V97(B+SX*("`@("`@/&-O;F9I9V5N=6T@;F%M
M93TB=F5R<VEO;B(@9&5S8STB3$1!4"!0<F]T;V-O;"!697)S:6]N(CXS"B`@
M("`@("`\=F%L=65S/@H@("`@("`@(#QV86QU92!D97-C/2),1$%0=C(@*$1E
M<')E8V%T960I(CXR/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB3$1!
M4'8S(CXS/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@("`@("`\+V-O;F9I
M9V5N=6T^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](F%D(B!D97-C/2))
M<R!T:&ES(&%N($%$('-E<G9E<C\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5I9"(@9&5S8STB5&AE('5S97)N
M86UE('-E87)C:"!K97D@*'-E="!T;R!S86UA8V-O=6YT;F%M92!F;W(@040I
M(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F5N8W)Y<'1I;VXB(&1E<V,]
M(D%L9V]R:71H;2!T;R!E;F-R>7!T('!A<W-W;W)D<R(^;60U+6AE>`H@("`@
M("`@/'9A;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB87!R;60U(CYA<')M
M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)C<GEP="(^8W)Y<'0\
M+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)C<GEP="UD97,B/F-R>7!T
M+61E<SPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](F-R>7!T+6UD-2(^
M8W)Y<'0M;60U/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB8W)Y<'0M
M8FQO=V9I<V@B/F-R>7!T+6)L;W=F:7-H/"]V86QU93X*("`@("`@("`\=F%L
M=64@9&5S8STB;60U+6)A<V4V-"(^;60U+6)A<V4V-#PO=F%L=64^"B`@("`@
M("`@/'9A;'5E(&1E<V,](FUD-2UH97@B/FUD-2UH97@\+W9A;'5E/@H@("`@
M("`@(#QV86QU92!D97-C/2)M<V%D(CYM<V%D/"]V86QU93X*("`@("`@("`\
M=F%L=64@9&5S8STB<&QA:6XB/G!L86EN/"]V86QU93X*("`@("`@("`\=F%L
M=64@9&5S8STB<W-H82(^<W-H83PO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E
M<V,](G-M9#4B/G-M9#4\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@
M(#PO8V]N9FEG96YU;3X*"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](FYE=W5S
M97)?;V)J96-T8VQA<W,B(&1E<V,](E=H870@;V)J96-T8VQA<W-E<R!S:&]U
M;&0@82!N97<@=7-E<B!A8V-O=6YT(&)E(&UE;6)E<B!O9C\@5&AE<V4@;V)J
M96-T8VQA<W-E<R!S:&]U;&0@8V]V97(@=&AE(&-N+'-N+'5S97)087-S=V]R
M9"!A='1R:6)U=&5S(&%S('=E;&P@87,@=&AE('5S97)N86UE('-E87)C:"!K
M97DB/G-H861O=T%C8V]U;G0L:6YE=$]R9U!E<G-O;CPO8V]N9FEG;&ES=#X*
M"B`@("`@(#QC;VYF:6=S=VET8V@@;F%M93TB9FEL=&5R7W1Y<&4B(&1E<V,]
M(DAO=R!T;R!S<&5C:69Y(&$@9FEL=&5R(&9O<B!T:&4@=7-E<B!L:7-T<R(^
M;V)J96-T8VQA<W,*("`@("`@(#QC87-E(&YA;64](F]B:F5C=&-L87-S(B!D
M97-C/2)/;F4@;W(@;6]R92!O8FIE8W1C;&%S<R!F:6QT97)S(CX*("`@("`@
M("`\8V]N9FEG;&ES="!N86UE/2)O8FIE8W1C;&%S<R(@9&5S8STB5&AE(&]B
M:F5C=&-L87-S(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@=7-E<G,N($-A
M;B!B92!A('-I;F=L92!O8FIE8W1C;&%S<R!O<B!A(&QI<W0N(B\^"B`@("`@
M("`\+V-A<V4^"B`@("`@("`\8V%S92!N86UE/2)F<F5E(B!D97-C/2)!(&-O
M;7!L971E($Q$05`@9FEL=&5R(&5X<')E<W-I;VXB/@H@("`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB9FEL=&5R(B!D97-C/2)4:&4@3$1!4"!21D,@9F]R
M;6%T=&5D(&9I;'1E<B!U<V5D('1O('-E87)C:"!F;W(@=7-E<G,N(B\^"B`@
M("`@("`\+V-A<V4^"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H*("`@("`@/&-O
M;F9I9W-W:71C:"!N86UE/2)P87-S=V]R9%]E>'!I<F%T:6]N(B!D97-C/2)%
M;F%B;&4@=&AE(&-R96%T:6YG(&]F(&%C8V]U;G1S('=I=&@@97AP:7)I;F<@
M<&%S<W=O<F1S/R`H3F]T93H@3F5W('5S97)S('-H;W5L9"!H879E('1H92!S
M:&%D;W=!8V-O=6YT(&]B:F5C=&-L87-S*2(^;F\*("`@("`@(#QC87-E(&YA
M;64](FYO(B!D97-C/2)N;R(@+SX*("`@("`@(#QC87-E(&YA;64](GEE<R(@
M9&5S8STB>65S(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FUI;F%G
M92(@9&5S8STB069T97(@:&]W(&UA;GD@9&%Y<R!M87D@82!P87-S=V]R9"!B
M92!C:&%N9V5D(&%G86EN/R(^-3PO8V]N9FEG<W1R:6YG/@H@("`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB;6%X86=E(B!D97-C/2)(;W<@;6%N>2!D87ES
M('=I;&P@82!P87-S=V]R9"!R96UA:6X@=F%L:60_(CXS,#PO8V]N9FEG<W1R
M:6YG/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=V%R;F%G92(@9&5S
M8STB2&]W(&UA;GD@9&%Y<R!B969O<F4@97AP:7)E<GD@<VAO=6QD(&$@=7-E
M<B!B92!W87)N960_(CXU/"]C;VYF:6=S=')I;F<^"B`@("`@("`\+V-A<V4^
M"B`@("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*
M("`@(#PO8V%S93X*"B`@("`\8V%S92!N86UE/2)L;V=I;B(@9&5S8STB3&]G
M:6X@*'-U*2!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)L;V-A
M=&EO;B(@9&5S8STB3&]C871I;VX@;V8@=&AE('-U(&)I;F%R>2(^+V)I;B]S
M=3PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO
M8V%S93X*"B`@("`\8V%S92!N86UE/2)M8V%L(B!D97-C/2)-0T%,(&%U=&AE
M;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F-A;&5N9&%R(B!D97-C/2)4
M:&4@34-!3"!C86QE;F1A<B!N86UE(B\^"B`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G!A;2(@9&5S8STB4$%-
M("A0;'5G9V%B;&4@075T:&5N=&EC871I;VX@36]D=6QE<RD@875T:&5N=&EC
M871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R=FEC92(@9&5S8STB5&AE(&YA
M;64@;V8@=&AE(%!!32!S97)V:6-E('1O('5S92!W:&5N(&%U=&AE;G1I8V%T
M:6YG(CYP:'`\+V-O;F9I9W-T<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^
M"B`@("`\+V-A<V4^"@H@("`@/&-A<V4@;F%M93TB<&%S<W=D(B!D97-C/2)P
M87-S=V0@9FEL92!A=71H96YT:6-A=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I
M;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F
M:6QE;F%M92(@9&5S8STB5&AE('!A<W-W9"!F:6QE('1O('5S92(^+V5T8R]P
M87-S=V0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M
M93TB;&]C:R(@9&5S8STB4VAO=6QD('=E(&QO8VL@=&AE('!A<W-W9"!F:6QE
M/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@/"]C87-E/@H*("`@(#QC87-E(&YA;64](G)A9&EU<R(@9&5S8STB
M4F%D:75S(&%U=&AE;G1I8V%T:6]N(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W0B
M(&1E<V,](E1H92!2041)55,@:&]S="!T;R!U<V4@*$E0(&%D9')E<W,@;W(@
M9G5L;'D@<75A;&EF:65D(&AO<W1N86UE*2(^;&]C86QH;W-T/"]C;VYF:6=S
M=')I;F<^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5&AE('!O<G0@=&\@=7-E(&]N('1H92!2041)
M55,@<V5R=F5R(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](FUE=&AO9"(@
M9&5S8STB5&AE(%)!1$E54R!M971H;V0@=&\@=7-E(&9O<B!V86QI9&%T:6YG
M('1H92!R97%U97-T(CY005`*("`@("`@(#QV86QU97,^"B`@("`@("`@/'9A
M;'5E(&1E<V,](E!!4"(^4$%0/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S
M8STB0TA!4%]-1#4@*&YO="!S=7!P;W)T960@870@=&AE(&UO;65N="DB/D-(
M05!?340U/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB35-#2$%0=C$@
M*&YO="!S=7!P;W)T960@870@=&AE(&UO;65N="DB/DU30TA!4'8Q/"]V86QU
M93X*("`@("`@("`\=F%L=64@9&5S8STB35-#2$%0=C(@*&YO="!S=7!P;W)T
M960@870@=&AE(&UO;65N="DB/DU30TA!4'8R/"]V86QU93X*("`@("`@(#PO
M=F%L=65S/@H@("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB;F%S(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!2041)
M55,@3D%3(&ED96YT:69I97(@=&\@=7-E+B(@+SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)S96-R970B(&1E<V,](E1H92!2041)55,@<VAA<F5D('-E
M8W)E="!S=')I;F<@9F]R('1H90H@("`@("!H;W-T+B!4:&4@4D%$2553('!R
M;W1O8V]L(&EG;F]R97,@86QL(&)U="!T:&4@;&5A9&EN9R`Q,C@@8GET97,@
M;V8@=&AE"B`@("`@('-H87)E9"!S96-R970N(B\^"B`@("`@(#QC;VYF:6=I
M;G1E9V5R(&YA;64](G)E=')I97,B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M5&AE(&UA>&EM=6T@;G5M8F5R"B`@("`@(&]F(')E<&5A=&5D(')E<75E<W1S
M('1O(&UA:V4@8F5F;W)E(&=I=FEN9R!U<"!;,UTB+SX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)S=69F:7@B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M5&AE(&1O;6%I;B!N86UE('1O(&%D9`H@("`@("!T;R!U;G%U86QI9FEE9"!U
M<V5R(&YA;65S(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G1I;65O
M=70B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('1I;65O=70@9F]R"B`@
M("`@(')E8V5I=FEN9R!R97!L:65S(&9R;VT@=&AE('-E<G9E<B`H:6X@<V5C
M;VYD<RD@6S-=(B\^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E
M/@H*("`@(#QC87-E(&YA;64](G-A<VPB(&1E<V,](E-!4TP@875T:&5N=&EC
M871I;VXB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB87!P(B!D97-C/2)4:&4@;F%M92!O
M9B!T:&4@875T:&5N=&EC871I;F<*("`@("`@87!P;&EC871I;VXB/FAO<F1E
M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R
M=FEC92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(%-!4TP@<V5R=FEC92!T;R!U
M<V4*("`@("`@=VAE;B!A=71H96YT:6-A=&EN9R(^<&AP/"]C;VYF:6=S=')I
M;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H*("`@(#QC
M87-E(&YA;64](G-M8B(@9&5S8STB4TU"(&%U=&AE;G1I8V%T:6]N(CX*("`@
M("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2))4"P@1$Y3($YA;64L(&]R
M($YE=$)I;W,@3F%M92!O9B!T:&4*("`@("`@4TU"('-E<G9E<B!T;R!A=71H
M96YT:6-A=&4@=VET:"(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB9&]M86EN(B!D97-C/2)4:&4@9&]M86EN
M(&YA;64@=&\@875T:&5N=&EC871E('=I=&@B+SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)G<F]U<"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)/<'1I
M;VYA;"!G<F]U<"!N86UE"B`@("`@('1H870@=&AE('5S97(@;75S="!B92!A
M(&UE;6)E<B!O9B(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S
M93X*"B`@("`\8V%S92!N86UE/2)S<6PB(&1E<V,](E-13"!A=71H96YT:6-A
M=&EO;B(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@
M("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B("\^"B`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB5&AE(&YA;64@;V8@=&AE(&%U=&@*("`@("`@=&%B;&4@:6X@
M=&AE(&1A=&%B87-E(%MH;W)D95]U<V5R<UTB+SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)U<V5R;F%M95]F:65L9"(@<F5Q=6ER960](F9A;'-E(B!D
M97-C/2)4:&4@;F%M92!O9B!T:&4*("`@("`@=7-E<FYA;64@9FEE;&0@:6X@
M=&AE(&%U=&@@=&%B;&4@6W5S97)?=6ED72(O/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](G!A<W-W;W)D7V9I96QD(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H92!N86UE(&]F('1H90H@("`@("!P87-S=V]R9"!F:65L9"!I;B!T
M:&4@875T:"!T86)L92!;=7-E<E]P87-S72(O/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](G-O9G1?97AP:7)A=&EO;E]F:65L9"(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4*("`@("`@;F%M92!O9B!A(&9I96QD(&-O;G1A:6YI
M;F<@82!53DE8('1I;65S=&%M<"X@(%=H96X@82!U<V5R(&QO9W,@:6X@869T
M97(*("`@("`@=&AE('-P96-I9FEE9"!T:6UE+"!I9B`G<&%S<W=D)R!I<R!I
M;G-T86QL960L('1H870@=7-E<B!W:6QL(&)E(&%S:V5D('1O"B`@("`@(&-H
M86YG92!H:7,@;W(@:&5R('!A<W-W;W)D+B`@5&AI<R!F96%T=7)E(&ES(&1I
M<V%B;&5D(&)Y(&1E9F%U;'0N(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB:&%R9%]E>'!I<F%T:6]N7V9I96QD(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E1H90H@("`@("!N86UE(&]F(&$@9FEE;&0@8V]N=&%I;FEN9R!A(%5.
M25@@=&EM97-T86UP+B`@02!U<V5R('=I;&P@;F]T(&)E(&%B;&4@=&\*("`@
M("`@;&]G(&EN(&%F=&5R('1H92!S<&5C:69I960@=&EM92X@(%1H:7,@9F5A
M='5R92!I<R!D:7-A8FQE9"!B>2!D969A=6QT+B(O/@H@("`@("`\8V]N9FEG
M:6YT96=E<B!N86UE/2)S;V9T7V5X<&ER871I;VY?=VEN9&]W(B!R97%U:7)E
M9#TB9F%L<V4B"B`@("`@(&1E<V,](E1H:7,@:7,@:&]W(&]F=&5N+"!I;B!D
M87ES+"!T:&4@=7-E<B!M=7-T(&-H86YG92!H:7,@;W(@:&5R"B`@("`@('!A
M<W-W;W)D+B`@5VAE;B!T:&4@=7-E<B=S('!A<W-W;W)D(&ES('5P9&%T960L
M('1H92`F<75O=#MS;V9T)G%U;W0["B`@("`@(&5X<&ER871I;VX@:7,@<V5T
M('1H:7,@;6%N>2!D87ES(&EN('1H92!F=71U<F4N("!)9B!N;W0@<')O=FED
M960L"B`@("`@('1H92!U<V5R)W,@<&%S<W=O<F0@=VEL;"!N;W0@97AP:7)E
M(&)Y(&1E9F%U;'0N(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](FAA
M<F1?97AP:7)A=&EO;E]W:6YD;W<B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M5&AE"B`@("`@(&YU;6)E<B!O9B!D87ES(&EN('1H92!G<F%C92!P97)I;V0@
M=&AE('5S97(@:&%S('1O(&-H86YG92!H:7,@;W(@:&5R"B`@("`@('!A<W-W
M;W)D(&%F=&5R(&ET(&AA<R!E>'!I<F5D+B`@268@;F]T('!R;W9I9&5D+"!T
M:&4@9W)A8V4@<&5R:6]D('=I;&P*("`@("`@;F]T(&5X<&ER92XB+SX*("`@
M("`@/&-O;F9I9V5N=6T@;F%M93TB96YC<GEP=&EO;B(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:&4@96YC<GEP=&EO;B!T;R!U<V4*("`@("`@=&\@<W1O
M<F4@=&AE('!A<W-W;W)D(&EN('1H92!T86)L92(^;60U+6AE>`H@("`@("`@
M/'9A;'5E<SX*("`@("`@("`\=F%L=64^8W)Y<'0\+W9A;'5E/@H@("`@("`@
M(#QV86QU93YC<GEP="UB;&]W9FES:#PO=F%L=64^"B`@("`@("`@/'9A;'5E
M/F-R>7!T+61E<SPO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+6UD-3PO
M=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UB87-E-C0\+W9A;'5E/@H@("`@
M("`@(#QV86QU93YM9#4M:&5X/"]V86QU93X*("`@("`@("`\=F%L=64^<&QA
M:6X\+W9A;'5E/@H@("`@("`@(#QV86QU93YS:&$\+W9A;'5E/@H@("`@("`@
M(#QV86QU93YS;60U/"]V86QU93X*("`@("`@("`\=F%L=64^<W-H83PO=F%L
M=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF:6=E;G5M/@H@("`@
M("`\8V]N9FEG8F]O;&5A;B!N86UE/2)S:&]W7V5N8W)Y<'1I;VXB(')E<75I
M<F5D/2)F86QS92(@9&5S8STB4')E<&5N9"!T:&4*("`@("`@96YC<GEP=&EO
M;B!I;B!T:&4@<&%S<W=O<F0@9FEE;&0_(CYF86QS93PO8V]N9FEG8F]O;&5A
M;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@("`@/&-A
M<V4@;F%M93TB8W5S=&]M<W%L(B!D97-C/2)344P@875T:&5N=&EC871I;VX@
M=R]C=7-T;VTM;6%D92!Q=65R:65S(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N
M86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)P:'!T>7!E
M(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4B/FUY<W%L"B`@("`@
M("`\=F%L=65S/@H@("`@("`@(#QV86QU92!D97-C/2)-:6-R;W-O9G0@4U%,
M(%-E<G9E<B(^;7-S<6P\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)-
M>5-13"(^;7ES<6P\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)/1$)#
M(CYO9&)C/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB3W)A8VQE(#@B
M/F]C:3@\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)0;W-T9W)E4U%,
M(CYP9W-Q;#PO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@/"]C;VYF
M:6=E;G5M/@H@("`@("`\8V]N9FEG<W=I=&-H(&YA;64](G!R;W1O8V]L(B!D
M97-C/2)7:&%T('!R;W1O8V]L('=I;&P@=V4@=7-E('1O(&-O;FYE8W0@=&\@
M=&AE(&1A=&%B87-E/R(^=6YI>`H@("`@("`@/&-A<V4@;F%M93TB=6YI>"(@
M9&5S8STB54Y)6"!3;V-K971S(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G-O8VME="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2),;V-A=&EO;B!O
M9B!53DE8('-O8VME="(^/"]C;VYF:6=S=')I;F<^"B`@("`@("`\+V-A<V4^
M"B`@("`@("`\8V%S92!N86UE/2)T8W`B(&1E<V,](E1#4"])4"(^"B`@("`@
M("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E
M(B!D97-C/2)0;W)T('1H92!$0B!I<R!R=6YN:6YG(&]N+"!I9B!N;VXM<W1A
M;F1A<F0B/C4T,S(\+V-O;F9I9VEN=&5G97(^"B`@("`@("`\+V-A<V4^"B`@
M("`@(#PO8V]N9FEG<W=I=&-H/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64]
M(FAO<W1S<&5C(B!D97-C/2)7:&%T(&AO<W1N86UE(&ES('1H92!D871A8F%S
M92!S97)V97(@<G5N;FEN9R!O;BP@;W(@=VAA="!I<R!T:&4@;F%M92!O9B!T
M:&4@<WES=&5M($133B!T;R!U<V4_(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN
M9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@9&5S8STB
M5VAA="!U<V5R;F%M92!D;R!W92!A=71H96YT:6-A=&4@=&\@=&AE(&1A=&%B
M87-E('-E<G9E<B!A<S\B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB<&%S<W=O<F0B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5VAA="!P87-S=V]R9"!D;R!W92!A=71H96YT:6-A=&4@=&\@=&AE
M(&1A=&%B87-E('-E<G9E<B!W:71H/R(O/@H@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](F1A=&%B87-E(B!D97-C/2)7:&%T(&1A=&%B87-E(&YA;64O=&%B
M;&5S<&%C92!A<F4@=V4@=7-I;F<_(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@
M("`@("`\8V]N9FEG9&5S8W)I<'1I;VX^"B`@("`@("!3;VUE('-P96-I86P@
M=&]K96YS(&-A;B!B92!U<V5D(&EN('1H92!S<6P@<75E<GDN(%1H97D@87)E
M(')E<&QA8V5D(&%T"B`@("`@("!T:&4@<75E<GD@<W1A9V4Z)FQT.W5L)F=T
M.PH@("`@("`@)FQT.VQI)F=T.R)<3"(@=VEL;"!B92!R97!L86-E9"!B>2!T
M:&4@=7-E<B=S(&QO9VEN)FQT.R]L:29G=#L*("`@("`@("9L=#ML:29G=#LB
M7%`B('=I;&P@8F4@<F5P;&%C960@8GD@=&AE('5S97(G<R!P87-S=V]R9"9L
M=#LO;&DF9W0["B`@("`@("`F;'0[;&DF9W0[(EQ/(B!W:6QL(&)E(')E<&QA
M8V5D(&)Y('1H92!O;&0@=7-E<B=S(&QO9VEN("AR97%U:7)E9"!F;W(*("`@
M("`@('5P9&%T92DF;'0[+VQI)F=T.R9L=#LO=6PF9W0["B`@("`@("!%9SH@
M(E-%3$5#5"`J($923TT@=7-E<G,@5TA%4D4@=6ED(#T@7$P@04Y$('!A<W-W
M9"`](%Q0($%.1"!B:6QL:6YG(#T*("`@("`@("=P86ED)R(*("`@("`@/"]C
M;VYF:6=D97-C<FEP=&EO;CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)Q
M=65R>5]A=71H(B!D97-C/2)!=71H96YT:6-A=&4@=&AE('5S97(B+SX*("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)Q=65R>5]A9&0B(&1E<V,](D%D9"!U
M<V5R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<75E<GE?=7!D871E
M(B!D97-C/2)5<&1A=&4@=7-E<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G%U97)Y7W)E;6]V92(@9&5S8STB4F5M;W9E('5S97(B+SX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)Q=65R>5]L:7-T(B!D97-C/2),:7-T('5S
M97)S(B\^"B`@("`@(#QC;VYF:6=E;G5M(&YA;64](F5N8W)Y<'1I;VXB(&1E
M<V,](E1H92!E;F-R>7!T:6]N('1O('5S92!T;R!S=&]R92!T:&4*("`@("`@
M<&%S<W=O<F0@:6X@=&AE('1A8FQE(CYM9#4M:&5X"B`@("`@("`\=F%L=65S
M/@H@("`@("`@(#QV86QU93YA<')M9#4\+W9A;'5E/@H@("`@("`@(#QV86QU
M93YC<GEP=#PO=F%L=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+6)L;W=F:7-H
M/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y<'0M9&5S/"]V86QU93X*("`@
M("`@("`\=F%L=64^8W)Y<'0M;60U/"]V86QU93X*("`@("`@("`\=F%L=64^
M;60U+6)A<V4V-#PO=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UH97@\+W9A
M;'5E/@H@("`@("`@(#QV86QU93YP;&%I;CPO=F%L=64^"B`@("`@("`@/'9A
M;'5E/G-H83PO=F%L=64^"B`@("`@("`@/'9A;'5E/G-M9#4\+W9A;'5E/@H@
M("`@("`@(#QV86QU93YS<VAA/"]V86QU93X*("`@("`@(#PO=F%L=65S/@H@
M("`@("`\+V-O;F9I9V5N=6T^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(G-H;W=?96YC<GEP=&EO;B(@9&5S8STB4')E<&5N9"!T:&4@96YC<GEP=&EO
M;B!I;B!T:&4*("`@("`@<&%S<W=O<F0@9FEE;&0_(CYF86QS93PO8V]N9FEG
M8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@
M("`@/&-A<V4@;F%M93TB8WER<W%L(B!D97-C/2)344P@:6UP;&5M96YT871I
M;VX@9F]R('1H92!#>7)U<R!)34%0('-E<G9E<B(^"B`@("`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)C>7)A9&UI;B(@9&5S8STB5&AE('5S97)N86UE(&]F('1H92!C>7)U<PH@
M("`@("!A9&UI;FES=')A=&]R(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB8WER<&%S<R(@9&5S8STB5&AE('!A<W-W;W)D(&9O<B!T:&4@8WER=7,*
M("`@("`@861M:6YI<W1R871O<B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](FEM87!?9'-N(B!D97-C/2)4:&4@9G5L;"!)34%0($133@H@("`@("`H
M:2YE+B![;&]C86QH;W-T.CDY,R]I;6%P+W-S;"]N;W9A;&ED871E+6-E<G1]
M*2(O/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)P:'!T>7!E(B!D97-C/2)4
M:&4@;F%M92!O9B!T:&4@9&%T86)A<V4B/FUY<W%L"B`@("`@("`\=F%L=65S
M/@H@("`@("`@(#QV86QU92!D97-C/2)-:6-R;W-O9G0@4U%,(%-E<G9E<B(^
M;7-S<6P\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)->5-13"(^;7ES
M<6P\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)->5-13"`H;7ES<6QI
M*2(^;7ES<6QI/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB3T1"0R(^
M;V1B8SPO=F%L=64^"B`@("`@("`@/'9A;'5E(&1E<V,](D]R86-L92`X(CYO
M8VDX/"]V86QU93X*("`@("`@("`\=F%L=64@9&5S8STB4&]S=&=R95-13"(^
M<&=S<6P\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N9FEG
M96YU;3X*("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P<F]T;V-O;"(@9&5S
M8STB5VAA="!P<F]T;V-O;"!W:6QL('=E('5S92!T;R!C;VYN96-T('1O('1H
M92!D871A8F%S93\B/G5N:7@*("`@("`@(#QC87-E(&YA;64](G5N:7@B(&1E
M<V,](E5.25@@4V]C:V5T<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE
M/2)S;V-K970B(')E<75I<F5D/2)F86QS92(@9&5S8STB3&]C871I;VX@;V8@
M54Y)6"!S;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@
M("`@("`@/&-A<V4@;F%M93TB=&-P(B!D97-C/2)40U`O25`B/@H@("`@("`@
M(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD
M87)D(CXU-#,R/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@/"]C87-E/@H@("`@
M("`\+V-O;F9I9W-W:71C:#X*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H
M;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@
M<V5R=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE
M('-Y<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^
M"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H
M870@=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S
M92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E
M<V,](E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D
M871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)D871A8F%S92(@9&5S8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE
M<W!A8V4@87)E('=E"B`@("`@('5S:6YG/R(^:&]R9&4\+V-O;F9I9W-T<FEN
M9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L92(@9&5S8STB5&AE
M(&YA;64@;V8@=&AE(&%U=&@@=&%B;&4@:6X@=&AE"B`@("`@(&1A=&%B87-E
M(CYH;W)D95]U<V5R<SPO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R
M:6YG(&YA;64](G5S97)N86UE7V9I96QD(B!D97-C/2)4:&4@;F%M92!O9B!T
M:&4@=7-E<FYA;64@9FEE;&0*("`@("`@:6X@=&AE(&%U=&@@=&%B;&4B/G5S
M97)?=6ED/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB<&%S<W=O<F1?9FEE;&0B(&1E<V,](E1H92!N86UE(&]F('1H92!P87-S
M=V]R9"!F:65L9`H@("`@("!I;B!T:&4@875T:"!T86)L92(^=7-E<E]P87-S
M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB9&]M
M86EN7V9I96QD(B!D97-C/2))9B!S970@=&\@86YY=&AI;F<@;W1H97(@=&AA
M;@H@("`@("`G;F]N92<@=&AI<R!I<R!U<V5D(&%S(&9I96QD(&YA;64@=VAE
M<F4@9&]M86EN(&ES"B`@("`@('-T;W)E9"(^;F]N93PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)E;F-R>7!T:6]N(B!D97-C/2)4
M:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@<W1O<F4@=&AE"B`@("`@('!A<W-W
M;W)D(&EN('1H92!T86)L92(^;60U+6AE>`H@("`@("`@/'9A;'5E<SX*("`@
M("`@("`\=F%L=64^87!R;60U/"]V86QU93X*("`@("`@("`\=F%L=64^8W)Y
M<'0\+W9A;'5E/@H@("`@("`@(#QV86QU93YC<GEP="UB;&]W9FES:#PO=F%L
M=64^"B`@("`@("`@/'9A;'5E/F-R>7!T+61E<SPO=F%L=64^"B`@("`@("`@
M/'9A;'5E/F-R>7!T+6UD-3PO=F%L=64^"B`@("`@("`@/'9A;'5E/FUD-2UB
M87-E-C0\+W9A;'5E/@H@("`@("`@(#QV86QU93YM9#4M:&5X/"]V86QU93X*
M("`@("`@("`\=F%L=64^<&QA:6X\+W9A;'5E/@H@("`@("`@(#QV86QU93YS
M:&$\+W9A;'5E/@H@("`@("`@(#QV86QU93YS;60U/"]V86QU93X*("`@("`@
M("`\=F%L=64^<W-H83PO=F%L=64^"B`@("`@("`\+W9A;'5E<SX*("`@("`@
M/"]C;VYF:6=E;G5M/@H@("`@("`\8V]N9FEG;&ES="!N86UE/2)F;VQD97)S
M(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](D$@;&ES="!O9B!F;VQD97)S('1O
M(&-R96%T92!U;F1E<@H@("`@("!U<V5R;F%M92(O/@H@("`@("`\8V]N9FEG
M:6YT96=E<B!N86UE/2)Q=6]T82(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4
M:&4@<75O=&$@*&EN"B`@("`@(&MI;&]B>71E<RD@=&\@9W)A;G0@;VX@=&AE
M(&UA:6QB;W@B+SX*("`@("`@/&-O;F9I9V)O;VQE86X@;F%M93TB=6YI>&AI
M97(B(&1E<V,](E1H92!V86QU92!O9B!I;6%P9"YC;VYF)W,*("`@("`@=6YI
M>&AI97)A<F-H>7-E<"!S971T:6YG+B!#:&5C:R!T:&ES(&EF('1H92!V86QU
M92!I<R!T<G5E(&EN"B`@("`@(&EM87!D+F-O;F8N(CYF86QS93PO8V]N9FEG
M8F]O;&5A;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"@H@
M("`@/&-A<V4@;F%M93TB>6%H;V\B(&1E<V,](EEA:&]O(2!A=71H96YT:6-A
M=&EO;B(O/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^
M"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](G-I9VYU<"(@9&5S
M8STB4VEG;B!5<"(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<VEG;G5P(CX*
M("`@/&-O;F9I9VAE861E<CY(;W)D92!3:6=N(%5P/"]C;VYF:6=H96%D97(^
M"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB86QL;W<B(&1E<V,](D%L;&]W(&YO
M;BUR96=I<W1E<F5D('5S97)S('1O(')E9VES=&5R(&%N9`H@("!P<F]V:61E
M(&$@;&EN:R!O;B!T:&4@;&]G:6X@<V-R965N/R(^9F%L<V4*("`@(#QC87-E
M(&YA;64](G1R=64B(&1E<V,](EEE<R(^"B`@("`@/&-O;F9I9V)O;VQE86X@
M;F%M93TB87!P<F]V92(@9&5S8STB061M:6X@:&%S('1O(&%P<')O=F4@86YY
M('5S97(@<W5B;6ET=&5D"B`@("`@<F5G:7-T<F%T:6]N(')E<75E<W1S/R`H
M5T%23DE.1SH@4V5T=&EN9R!T;R!F86QS92!W;W5L9"!M96%N('1H870@979E
M<GD@=7-E<@H@("`@('=H;R!S:6=N<R!U<"!W;W5L9"!H879E(&%U=&]M871I
M8R!A8V-E<W,@=&\@>6]U<B!H;W)D92!S>7-T96TN*2(^=')U93PO8V]N9FEG
M8F]O;&5A;CX*("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P<F5P<F]C97-S
M(B!D97-C/2)087-S('1H92!U<V5R('-U8FUI='1E9"!I;F9O<FUA=&EO;@H@
M("`@('1H<F]U9V@@=&AE(%]H;W)D95]H;V]K7W-I9VYU<%]P<F5P<F]C97-S
M(&9U;F-T:6]N(&EN(&AO;VMS+G!H<"!B969O<F4*("`@("!P<F]C97-S:6YG
M('1H92!R97%U97-T/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB<75E=64B(&1E<V,](E!A<W,@=&AE('5S97(@
M<W5B;6ET=&5D(&EN9F]R;6%T:6]N"B`@("`@=&AR;W5G:"!T:&4@7VAO<F1E
M7VAO;VM?<VEG;G5P7W%U975E(&9U;F-T:6]N(&EN(&AO;VMS+G!H<"!A9G1E
M<B!P<F]C97-S:6YG"B`@("`@=&AE(')E<75E<W0@8G5T(&)E9F]R92!A8W1U
M86QL>2!Q=65U96EN9R!I=#\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@
M/"]C87-E/@H@("`@/&-A<V4@;F%M93TB9F%L<V4B(&1E<V,](DYO(B`O/@H@
M("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I
M9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FQO9R(@9&5S8STB3&]G9VEN9R(^
M"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB;&]G(CX*("`@/&-O;F9I9VAE861E
M<CY(;W)D92!,;V=G:6YG/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB96YA8FQE9"(@<75O=&4](F9A;'-E(B!D97-C/2)3:&]U;&0@
M2&]R9&4@;&]G(&5R<F]R<R!A;F0@;W1H97(@=7-E9G5L"B`@(&EN9F]R;6%T
M:6]N/R(^=')U90H@("`@/&-A<V4@;F%M93TB=')U92(@9&5S8STB665S(CX*
M("`@("`\8V]N9FEG96YU;2!N86UE/2)P<FEO<FET>2(@<75O=&4](F9A;'-E
M(B!D97-C/2)7:&%T(&QE=F5L(&]F(&UE<W-A9V5S"B`@("`@<VAO=6QD('=E
M(&QO9S\@16%C:"!L979E;"!L;V=S(&ET<V5L9B!A;F0@86QL('1H;W-E('1H
M870@8V]M92!B969O<F4@:70Z"B`@("`@4$5!4E],3T=?04Q%4E0@=V]U;&0@
M;VYL>2!L;V<@86QE<G1S(&%N9"!E;65R9V5N8VEE<RP@8G5T(%!%05)?3$]'
M7T1%0E5'"B`@("`@=V]U;&0@;&]G(&5V97)Y=&AI;F<N(CY014%27TQ/1U].
M3U1)0T4*("`@("`@/'9A;'5E<SX*("`@("`@(#QV86QU92!D97-C/2)014%2
M7TQ/1U]%34521R(^4$5!4E],3T=?14U%4D<\+W9A;'5E/@H@("`@("`@/'9A
M;'5E(&1E<V,](E!%05)?3$]'7T%,15)4(CY014%27TQ/1U]!3$525#PO=F%L
M=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?0U))5"(^4$5!4E],
M3T=?0U))5#PO=F%L=64^"B`@("`@("`\=F%L=64@9&5S8STB4$5!4E],3T=?
M15)2(CY014%27TQ/1U]%4E(\+W9A;'5E/@H@("`@("`@/'9A;'5E(&1E<V,]
M(E!%05)?3$]'7U=!4DY)3D<B/E!%05)?3$]'7U=!4DY)3D<\+W9A;'5E/@H@
M("`@("`@/'9A;'5E(&1E<V,](E!%05)?3$]'7TY/5$E#12(^4$5!4E],3T=?
M3D]424-%/"]V86QU93X*("`@("`@(#QV86QU92!D97-C/2)014%27TQ/1U])
M3D9/(CY014%27TQ/1U])3D9//"]V86QU93X*("`@("`@(#QV86QU92!D97-C
M/2)014%27TQ/1U]$14)51R(^4$5!4E],3T=?1$5"54<\+W9A;'5E/@H@("`@
M("`\+W9A;'5E<SX*("`@("`\+V-O;F9I9V5N=6T^"B`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)I9&5N="(@9&5S8STB5VAA="!I9&5N=&EF:65R('-H;W5L
M9"!W92!U<V4@:6X@=&AE"B`@("`@;&]G<S\B/DA/4D1%/"]C;VYF:6=S=')I
M;F<^"@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@
M(#QC;VYF:6=P;&%C96AO;&1E<B\^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H*
M("`@("`\8V]N9FEG<W=I=&-H(&YA;64](G1Y<&4B(&1E<V,](E=H870@;&]G
M(&1R:79E<B!S:&]U;&0@=V4@=7-E/R(^9FEL90H@("`@("`\8V%S92!N86UE
M/2)C;VYS;VQE(B!D97-C/2)#;VYS;VQE(CX*("`@("`@(#QC;VYF:6=S96-T
M:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@/&-O;F9I9W!H<"!N86UE/2)S
M=')E86TB(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE(&]U='!U="!S=')E
M86T@=&\*("`@("`@("!U<V4B+SX*("`@("`@("`\8V]N9FEG8F]O;&5A;B!N
M86UE/2)B=69F97)I;F<B(')E<75I<F5D/2)F86QS92(@9&5S8STB4VAO=6QD
M('1H90H@("`@("`@(&]U='!U="!B92!B=69F97)E9"!U;G1I;"!S:'5T9&]W
M;C\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB;&EN949O<FUA="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2),
M;V<@;&EN92!F;W)M870*("`@("`@("!S<&5C:69I8V%T:6]N(B\^"B`@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T:6UE1F]R;6%T(B!R97%U:7)E9#TB
M9F%L<V4B(&1E<V,](E1I;64@<W1A;7`*("`@("`@("!F;W)M870B+SX*("`@
M("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`@/"]C87-E/@H*("`@("`@/&-A
M<V4@;F%M93TB9&ES<&QA>2(@9&5S8STB1&ES<&QA>2(^"B`@("`@("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB97)R;W)?<')E<&5N9"(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)4:&ES('-T<FEN9PH@("`@("`@('=I;&P@8F4@<')E<&5N9&5D('1O('1H
M92!L;V<@;W5T<'5T(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)E
M<G)O<E]A<'!E;F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AI<R!S=')I
M;F<*("`@("`@("!W:6QL(&)E(&%P<&5N9&5D('1O('1H92!L;V<@;W5T<'5T
M(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@
M("`@(#QC87-E(&YA;64](F5R<F]R7VQO9R(@9&5S8STB17)R;W(@3&]G(CX*
M("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)D97-T:6YA=&EO;B(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)/<'1I;VYA;`H@("`@("`@(&1E<W1I;F%T:6]N('9A;'5E
M(&9O<B!E<G)O<E]L;V<H*2X@4V5E"B`@("`@("`@:'1T<#HO+W=W=RYI;F1E
M;&EB;&4N;W)G+W!E87(O3&]G+V=U:61E+FAT;6PC97)R;W(M;&]G+71Y<&5S
M(&9O<B!M;W)E"B`@("`@("`@9&5T86EL<RXB+SX*("`@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](F5X=')A7VAE861E<G,B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB061D:71I;VYA;`H@("`@("`@(&AE861E<G,@=&\@<&%S<R!T;R!T
M:&4@;6%I;"@I(&9U;F-T:6]N('=H96X@=&AE(%!%05)?3$]'7U194$5?34%)
M3"!T>7!E"B`@("`@("`@:7,@<W!E8VEF:65D(B\^"B`@("`@("`\+V-O;F9I
M9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@("`@(#QC87-E(&YA;64](F9I
M;&4B(&1E<V,](D9I;&4B/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N
M86UE(B!D97-C/2)0871H('1O('1H92!L;V<*("`@("`@(&9I;&4B/B]T;7`O
M:&]R9&4N;&]G/"]C;VYF:6=S=')I;F<^"B`@("`@("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64]
M(F%P<&5N9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)3:&]U;&0@;F5W(&QO
M9PH@("`@("`@(&5N=')I97,@8F4@87!P96YD960@=&\@86X@97AI<W1I;F<@
M;&]G(&9I;&4_($EF('1H:7,@:7,@9F%L<V4L(&YE=R!L;V<@9FEL97,*("`@
M("`@("!W:6QL(&]V97)W<FET92!E>&ES=&EN9R!O;F5S+B(^=')U93PO8V]N
M9FEG8F]O;&5A;CX*("`@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)M;V1E
M(B!O8W1A;#TB=')U92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)/8W1A;`H@
M("`@("`@(')E<')E<V5N=&%T:6]N(&]F('1H92!L;V<@9FEL92=S('!E<FUI
M<W-I;VYS(&UO9&4B+SX*("`@("`@("`\8V]N9FEG<&AP(&YA;64](F5O;"(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@96YD+6]F+6QI;F4@8VAA<F%C
M=&5R"B`@("`@("`@<V5Q=65N8V4B+SX*("`@("`@("`\8V]N9FEG<W1R:6YG
M(&YA;64](FQI;F5&;W)M870B(')E<75I<F5D/2)F86QS92(@9&5S8STB3&]G
M(&QI;F4@9F]R;6%T"B`@("`@("`@<W!E8VEF:6-A=&EO;B(O/@H@("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB=&EM949O<FUA="(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2)4:6UE('-T86UP"B`@("`@("`@9F]R;6%T(B\^"B`@("`@
M("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@("`@(#QC87-E
M(&YA;64](FUA:6PB(&1E<V,](DUA:6PB/@H@("`@("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)N86UE(B!D97-C/2)4:&4@<F5C:7!I96YT(&9O<B!T:&4@;65S
M<V%G92(O/@H@("`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*
M("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F9R;VTB(')E<75I<F5D/2)F
M86QS92(@9&5S8STB5F%L=64@9F]R('1H90H@("`@("`@(&UE<W-A9V4G<R!&
M<F]M.B!H96%D97(B+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-U
M8FIE8W0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5F%L=64@9F]R('1H90H@
M("`@("`@(&UE<W-A9V4G<R!3=6)J96-T.B!H96%D97(B+SX*("`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G!R96%M8FQE(B!R97%U:7)E9#TB9F%L<V4B
M(&1E<V,](E!R96%M8FQE(&9O<B!T:&4*("`@("`@("!M97-S86=E(B\^"B`@
M("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@("`@(#QC
M87-E(&YA;64](FUC86PB(&1E<V,](DUC86PB/@H@("`@("`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](F-A;&5N9&%R(B!D97-C/2)4:&4@34-!3"!C86QE;F1A<B!N86UE(B\^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@9&5S8STB
M0V]N;F5C="!T;R!-0T%,(&%S(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)P87-S=V]R9"(@9&5S8STB4&%S<W=O<F0@=&\@8V]N;F5C="!W:71H
M(B\^"B`@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@(#PO8V%S93X*"B`@
M("`@(#QC87-E(&YA;64](FYU;&PB(&1E<V,](DYU;&PB+SX*"B`@("`@(#QC
M87-E(&YA;64](G-Q;"(@9&5S8STB4U%,(CX*("`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB;F%M92(@9&5S8STB5&AE('1A8FQE('1O(&QO9PH@("`@("`@
M=&\B/FQO9U]T86)L93PO8V]N9FEG<W1R:6YG/@H@("`@("`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@("`\8V]N9FEG<&AP(&YA;64]
M(F1S;B(@9&5S8STB02!$871A(%-O=7)C90H@("`@("`@($YA;64B/B1C;VYF
M6R=S<6PG73PO8V]N9FEG<&AP/@H@("`@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`@("`\+V-A<V4^"@H@("`@("`\8V%S92!N86UE/2)S<6QI=&4B(&1E<V,]
M(E-13&ET92(^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FYA;64B(&1E
M<V,](E1H92!T86)L92!T;R!L;V<*("`@("`@('1O(CYL;V=?=&%B;&4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M
M<R(^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)F:6QE;F%M92(@9&5S
M8STB4&%T:"!T;R!A;B!3<6QI=&4@9&%T86)A<V4B+SX*("`@("`@("`\8V]N
M9FEG:6YT96=E<B!N86UE/2)M;V1E(B!O8W1A;#TB=')U92(@<F5Q=6ER960]
M(F9A;'-E(B!D97-C/2)/8W1A;`H@("`@("`@(&UO9&4@=7-E9"!T;R!O<&5N
M('1H92!D871A8F%S92!;,#8V-ETB+SX*("`@("`@("`\8V]N9FEG8F]O;&5A
M;B!N86UE/2)P97)S:7-T96YT(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E5S
M92!A"B`@("`@("`@<&5R<VES=&5N="!C;VYN96-T:6]N(CYF86QS93PO8V]N
M9FEG8F]O;&5A;CX*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`@/"]C
M87-E/@H*("`@("`@/&-A<V4@;F%M93TB<WES;&]G(B!D97-C/2)3>7-L;V<B
M/@H@("`@("`@/&-O;F9I9W!H<"!N86UE/2)N86UE(B!Q=6]T93TB9F%L<V4B
M(&1E<V,](E-Y<VQO9R!F86-I;&ET>2!T;R!U<V4B+SX*("`@("`@/"]C87-E
M/@H*("`@("`@/&-A<V4@;F%M93TB=VEN(B!D97-C/2)7:6YD;W<B/@H@("`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)N86UE(B!D97-C/2).86UE(&]F('1H
M92!O<&5N960@=VEN9&]W(B\^"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE
M/2)P87)A;7,B/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&ET;&4B
M(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('1I=&QE(&]F('1H90H@("`@
M("`@(&]U='!U="!W:6YD;W<B+SX*("`@("`@(#PO8V]N9FEG<V5C=&EO;CX*
M("`@("`@/"]C87-E/@H@("`@(#PO8V]N9FEG<W=I=&-H/@H*("`@(#PO8V%S
M93X*("`@(#QC87-E(&YA;64](F9A;'-E(B!D97-C/2).;R(O/@H@("`\+V-O
M;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`@/&-O;F9I9V)O;VQE
M86X@;F%M93TB;&]G7V%C8V5S<VME>7,B(&1E<V,](E-H;W5L9"!(;W)D92!L
M;V<@<W1A=&ES=&EC<R!A8F]U=`H@("!U<V5D(&%C8V5S<R!K97ES/R!4:&ES
M(&ES(&]N;'D@=7-E9G5L(&9O<B!T<F%N<VQA=&]R<R!O9B!T:&4*("`@54DN
M(%EO=2!A;'-O(&YE960@=&\@<V5T('1H92!L;V<@;&5V96P@=&\@870@;&5A
M<W0*("`@4$5!4E],3T=?24Y&3RXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@
M/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)P<F5F<R(@9&5S8STB
M4')E9F5R96YC92!3>7-T96TB/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G!R
M969S(CX*("`@/&-O;F9I9VAE861E<CY0<F5F97)E;F-E(%-Y<W1E;2!3971T
M:6YG<SPO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG:6YT96=E<B!N86UE/2)M
M87AS:7IE(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H92!S:7IE(&]F('1H
M90H@("!P<F5F97)E;F-E<R!F:65L9"!I;B!Y;W5R(&)A8VME;F0@:6X@8GET
M97,N($AO<F1E('=I;&P@<F5J96-T(&%N>2!W<FET92!T;PH@("!T:&4@<')E
M9F5R96YC97,@8F%C:V5N9"!I9B!I=',@;&5N9W1H(&5X8V5E9',@=&AI<R!V
M86QU92X@3&5A=F4@96UP='D@=&\*("`@<VMI<"!T:&ES(&-H96-K:6YG+B!%
M+F<N($UY4U%,('-T;W)E<R!T:&4@<')E9F5R96YC92!D871A(&EN(&$@3$].
M1U1%6%0*("`@9FEE;&0N(%1H:7,@9FEE;&0@8V%N(&AO;&0@-#(Y-#DV-S(Y
M-2!B>71E<R!S;R!M;W-T(&QI:V5L>2!C:&5C:VEN9R!I<R!N;W0*("`@;F5E
M9&5D+B!(;W=E=F5R(&]T:&5R($1"(&EN<W1A;&QA=&EO;G,@;6%Y(&]N;'D@
M:&%V92!A('-T;W)A9V4@<VEZ92!O9B`V-`H@("!+0B`H-C4U,S4@8GET97,I
M+B!4:&5S92!I;G-T86QL871I;VYS('=O=6QD('=A;G0@=&\@='5R;B!C:&5C
M:VEN9R!O;BXB+SX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)D<FEV97(B(&1E
M<V,](E=H870@<')E9F5R96YC97,@9')I=F5R('-H;W5L9"!W92!U<V4_(CYS
M97-S:6]N"B`@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)344P@1&%T86)A
M<V4B/@H@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@
M("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D<FEV97)C;VYF:6<B/@H@("`@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=&%B;&4B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB5&AE(&YA;64@;V8@=&AE"B`@("`@("`@<')E9F5R96YC92!T
M86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W!R969S72(O/@H@("`@("`@
M/"]C;VYF:6=S<6P^"B`@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@("`\+V-A
M<V4^"B`@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S8STB3$1!4"(^"B`@("`@
M(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D97-C/2)4:&4@:&]S=&YA;64@;V8@
M=&AE($Q$05`@<V5R=F5R(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@
M("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E1H92!P;W)T
M(&]F('1H92!,1$%0('-E<G9E<B(^,S@Y/"]C;VYF:6=I;G1E9V5R/@H@("`@
M("`@/&-O;F9I9V5N=6T@;F%M93TB=F5R<VEO;B(@9&5S8STB3$1!4"!0<F]T
M;V-O;"!697)S:6]N(CXS"B`@("`@("`@/'9A;'5E<SX*("`@("`@("`@/'9A
M;'5E(&1E<V,](DQ$05!V,B`H1&5P<F5C871E9"DB/C(\+W9A;'5E/@H@("`@
M("`@("`\=F%L=64@9&5S8STB3$1!4'8S(CXS/"]V86QU93X*("`@("`@("`\
M+W9A;'5E<SX*("`@("`@(#PO8V]N9FEG96YU;3X*("`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB8F%S961N(B!D97-C/2)4:&4@8F%S92!$3B!F;W(@=&AE
M($Q$05`@<V5R=F5R(B\^"B`@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)F
M971C:&1N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E-H;W5L9"!(;W)D92!B
M:6YD"F%S(&5A8V@@=7-E<B!F;W(@=&AA="!U<V5R)W,@=W)I=&4@;W!E<F%T
M:6]N<S\B+SX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<F]O=&1N(B!R
M97%U:7)E9#TB9F%L<V4B(&1E<V,](DEF(&YO="P@<')O=FED92!T:&4*1$X@
M;V8@=&AE(')O;W0@*&%D;6EN:7-T<F%T:79E*2!A8V-O=6YT('1O(&)I;F0@
M9F]R('=R:71E(&]P97)A=&EO;G,B+SX*("`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<&%S<W=O<F0B(')E<75I<F5D/2)F86QS92(@9&5S8STB5&AE('!A
M<W-W;W)D(&]F('1H92!R;V]T($1.(&9O<B!B:6YD(&%U=&AE;G1I8V%T:6]N
M(B\^"B`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G5I9"(@9&5S8STB5&AE
M('5S97)N86UE('-E87)C:"!K97DB+SX*("`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@(#PO8V%S93X*("`@("`\8V%S92!N86UE/2)S97-S:6]N(B!D97-C
M/2)02%`@4V5S<VEO;G,B+SX*("`@("`\8V%S92!N86UE/2)K;VQA8B(@9&5S
M8STB2V]L86(@*$Q$05`I(B`O/@H@("`@(#QC87-E(&YA;64](FEM<W`B(&1E
M<V,](DE-4U`@4V5R=F5R(B`O/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O
M;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64]
M(F1A=&%T<F5E(B!D97-C/2)$871A5')E92!3>7-T96TB/@H@(#QC;VYF:6=S
M96-T:6]N(&YA;64](F1A=&%T<F5E(CX*("`@/&-O;F9I9VAE861E<CY$871A
M5')E92!3>7-T96T@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I
M9W-W:71C:"!N86UE/2)D<FEV97(B(&1E<V,](E=H870@8F%C:V5N9"!S:&]U
M;&0@=V4@=7-E(&9O<B!(;W)D90H@("!$871A5')E92!S=&]R86=E/R(^;G5L
M;`H@("`@(#QC87-E(&YA;64](FYU;&PB(&1E<V,](DYO;F4B+SX*("`@("`\
M8V%S92!N86UE/2)S<6PB(&1E<V,](E-13"!$871A8F%S92(^"B`@("`@(#QC
M;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@("`\8V]N9FEG<W%L
M('-W:71C:&YA;64](F1R:79E<F-O;F9I9R(^"B`@("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@
M;F%M92!O9B!T:&4*("`@("`@("!D871A('1A8FQE(&EN('1H92!D871A8F%S
M92!;:&]R9&5?9&%T871R965=(B\^"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)T86)L95]A='1R:6)U=&5S(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(E1H92!N86UE"B`@("`@("`@;V8@=&AE(&1A=&$@871T<FEB=71E<R!T86)L
M92!I;B!T:&4@9&%T86)A<V4*("`@("`@("!;:&]R9&5?9&%T871R965?871T
M<FEB=71E<UTB+SX*("`@("`@(#PO8V]N9FEG<W%L/@H@("`@("`\+V-O;F9I
M9W-E8W1I;VX^"B`@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\
M+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA
M;64](F=R;W5P(B!D97-C/2)'<F]U<',B/@H@(#QC;VYF:6=S96-T:6]N(&YA
M;64](F=R;W5P(CX*("`@/&-O;F9I9VAE861E<CY'<F]U<',@4V5T=&EN9W,\
M+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9V1E<V-R:7!T:6]N/@H@("`@5&AE
M($AO;VMS(&)A8VME;F0@97AT96YD<R!T:&4@1&%T851R964@8F%C:V5N9"!T
M;R!A;&QO=R!H;V]K<R!T;R!E>'1E;F0@80H@("`@9W)O=7`@=&\@9'EN86UI
M8V%L;'D@:6YC;'5D92!M96UB97)S(&EN=&\@82!G<F]U<"X@(%-E92!H;V]K
M<RYP:'`N9&ES="!F;W(*("`@(&%N(&5X86UP;&4N"B`@(#PO8V]N9FEG9&5S
M8W)I<'1I;VX^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C
M/2)7:&%T(&)A8VME;F0@<VAO=6QD('=E('5S92!F;W(@2&]R9&4*("`@1W)O
M=7!S/R(^9&%T871R964*("`@("`\8V%S92!N86UE/2)D871A=')E92(@9&5S
M8STB1&%T851R964B+SX*("`@("`\8V%S92!N86UE/2)H;V]K<R(@9&5S8STB
M2&]O:W,B+SX*"B`@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S8STB3$1!4"(^
M"B`@("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`@
M(#QC;VYF:6=S=')I;F<@;F%M93TB:&]S='-P96,B(&1E<V,](E1H92!H;W-T
M;F%M92!O9B!T:&4@3$1!4"!S97)V97(B/FQO8V%L:&]S=#PO8V]N9FEG<W1R
M:6YG/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8F%S961N(B!D97-C
M/2)4:&4@8F%S92!$3B!F;W(@=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)B:6YD9&XB(')E<75I<F5D/2)F86QS92(@
M9&5S8STB5&AE($1.('5S960@=&\@8FEN9"!T;R!T:&4@3$1!4"!S97)V97(B
M+SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E1H92!P87-S=V]R9"!U<V5D('1O(&)I;F0@
M=&\@=&AE($Q$05`@<V5R=F5R(B\^"B`@("`@("`@/&-O;F9I9V5N=6T@;F%M
M93TB=F5R<VEO;B(@9&5S8STB3$1!4"!0<F]T;V-O;"!697)S:6]N(CXS"B`@
M("`@("`@(#QV86QU97,^"B`@("`@("`@("`\=F%L=64@9&5S8STB3$1!4'8R
M("A$97!R96-A=&5D*2(^,CPO=F%L=64^"B`@("`@("`@("`\=F%L=64@9&5S
M8STB3$1!4'8S(CXS/"]V86QU93X*("`@("`@("`@/"]V86QU97,^"B`@("`@
M("`@/"]C;VYF:6=E;G5M/@H@("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M9VED(B!D97-C/2)4:&4@9W)O=7`@<V5A<F-H(&ME>2(^8VX\+V-O;F9I9W-T
M<FEN9SX*("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FUE;6)E<G5I9"(@
M9&5S8STB1W)O=7`@;65M8F5R<VAI<"!F:65L9"(^;65M8F5R56ED/"]C;VYF
M:6=S=')I;F<^"B`@("`@("`@/&-O;F9I9VQI<W0@;F%M93TB;F5W9W)O=7!?
M;V)J96-T8VQA<W,B(&1E<V,](E=H870@;V)J96-T8VQA<W-E<R!S:&]U;&0@
M82!N97<@9W)O=7`@8F4@;65M8F5R(&]F/R!4:&5S92!O8FIE8W1C;&%S<V5S
M('-H;W5L9"!C;W9E<B!T:&4@;6%I;"!A;F0@9VED;G5M8F5R(&%T=')I8G5T
M97,@87,@=V5L;"!A<R!T:&4@9W)O=7`@<V5A<F-H(&ME>2(^<&]S:7A'<F]U
M<"QH;W)D94=R;W5P/"]C;VYF:6=L:7-T/@H@("`@("`@(#QC;VYF:6=S=VET
M8V@@;F%M93TB9FEL=&5R7W1Y<&4B(&1E<V,](DAO=R!T;R!S<&5C:69Y(&$@
M9FEL=&5R(&9O<B!T:&4@9W)O=7`@;&ES=',B/F]B:F5C=&-L87-S"B`@("`@
M("`@(#QC87-E(&YA;64](F]B:F5C=&-L87-S(B!D97-C/2)/;F4@;W(@;6]R
M92!O8FIE8W1C;&%S<R!F:6QT97)S(CX*("`@("`@("`@(#QC;VYF:6=L:7-T
M(&YA;64](F]B:F5C=&-L87-S(B!D97-C/2)4:&4@;V)J96-T8VQA<W,@9FEL
M=&5R('5S960@=&\@<V5A<F-H(&9O<B!G<F]U<',N($-A;B!B92!A('-I;F=L
M92!O8FIE8W1C;&%S<R!O<B!A(&QI<W0N(CYP;W-I>$=R;W5P/"]C;VYF:6=L
M:7-T/@H@("`@("`@("`\+V-A<V4^"B`@("`@("`@(#QC87-E(&YA;64](F9R
M964B(&1E<V,](D$@8V]M<&QE=&4@3$1!4"!F:6QT97(@97AP<F5S<VEO;B(^
M"B`@("`@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F9I;'1E<B(@9&5S8STB
M5&AE($Q$05`@4D9#(&9O<FUA='1E9"!F:6QT97(@=7-E9"!T;R!S96%R8V@@
M9F]R(&=R;W5P<RXB+SX*("`@("`@("`@/"]C87-E/@H@("`@("`@(#PO8V]N
M9FEG<W=I=&-H/@H@("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`@/"]C87-E
M/@H*("`@/"]C;VYF:6=S=VET8V@^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C
M;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)C86-H92(@9&5S8STB0V%C
M:&4@4WES=&5M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)C86-H92(^"B`@
M(#QC;VYF:6=H96%D97(^0V%C:&4@4WES=&5M(%-E='1I;F=S/"]C;VYF:6=H
M96%D97(^"B`@(#QC;VYF:6=I;G1E9V5R(&YA;64](F1E9F%U;'1?;&EF971I
M;64B(&1E<V,](DAO=R!L;VYG+"!I;B!S96-O;F1S+"!S:&]U;&0*("`@;V)J
M96-T<R!B92!C86-H960@8GD@9&5F875L=#\B/C$X,#`\+V-O;F9I9VEN=&5G
M97(^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB9')I=F5R(B!D97-C/2))9B!Y
M;W4@=V%N="!T;R!E;F%B;&4@=&AE($AO<F1E($-A8VAE+`H@("!S96QE8W0@
M82!D<FEV97(@:&5R92X@5&AI<R!I<R!U<V5D('1O('-P965D('5P('!O<G1I
M;VYS(&]F($AO<F1E(&)Y('-T;W)I;F<*("`@8V]M;6]N;'D@<')O8V5S<V5D
M(&]B:F5C=',@=&\@9&ES:RXB/F9I;&4*("`@(#QC87-E(&YA;64](FYO;F4B
M(&1E<V,](D1O;B=T(&-A8VAE(&%N>2!O8FIE8W1S(B\^"B`@("`\8V%S92!N
M86UE/2)F:6QE(B!D97-C/2)3=&]R92!O8FIE8W1S(&EN(&9I;&5S>7-T96TB
M/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC
M;VYF:6=P:'`@;F%M93TB9&ER(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H
M92!L;V-A=&EO;B!T;R!S=&]R92!T:&4*("`@("`@8V%C:&5D(&9I;&5S(CY(
M;W)D93HZ9V5T5&5M<$1I<B@I/"]C;VYF:6=P:'`^"B`@("`@(#QC;VYF:6=S
M=')I;F<@;F%M93TB<')E9FEX(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H
M92!F:6QE;F%M92!P<F5F:7@@=&\*("`@("`@=7-E(&9O<B!T:&4@8V%C:&4@
M9FEL97,N(B\^"B`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](F=C(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E!E<F9O<FT@9V%R8F%G90H@("`@("!C;VQL
M96-T:6]N(&]N(&-A8VAE(&9I;&5S/R!);G!U="!T:&4@;G5M8F5R(&]F('-E
M8V]N9',@;VQD('1H92!F:6QE(&AA<PH@("`@("!T;R!B92!W:71H;W5T(&UO
M9&EF:6-A=&EO;B!B969O<F4@=&AE(&-A8VAE('-Y<W1E;2!C86X@9&5L971E
M('1H92!F:6QE+@H@("`@("!);G!U="`P('1O('-K:7`@9V%R8F%G92!C;VQL
M96-T:6]N+B(^.#8T,#`\+V-O;F9I9VEN=&5G97(^"B`@("`@(&%F=&5R('=H
M:6-H(&-A8VAE"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@
M("`@/&-A<V4@;F%M93TB>G!S-"(@9&5S8STB57-E('1H92!:96YD(%!E<F9O
M<FUA;F-E(%-U:71E(&]U='!U="!C86-H92(O/@H@("`\+V-O;F9I9W-W:71C
M:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG
M=&%B(&YA;64](G1O:V5N(B!D97-C/2)4;VME;B!3>7-T96TB/@H@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G1O:V5N(CX*("`@/&-O;F9I9VAE861E<CY4;VME
M;B!3>7-T96T@4V5T=&EN9W,\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9VEN
M=&5G97(@;F%M93TB=&EM96]U="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4
M:&4@<&5R:6]D("AI;@H@("!S96-O;F1S*2!A9G1E<B!W:&EC:"!A;B!I9"!I
M<R!P=7)G960B+SX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)D<FEV97(B(&1E
M<V,](DEF('EO=2!W86YT('1O(&5N86)L92!&;W)M(%1O:V5N<RP@<V5L96-T
M"B`@(&$@9')I=F5R(&AE<F4N(%1H:7,@:7,@=7-E9"!B>2!T:&4@2&]R9&4Z
M.D9O<FTZ.B!!4$D@86YD('-O;64@;W1H97(@<&%R=',*("`@;V8@2&]R9&4@
M=&\@96YS=7)E('1H870@82!F;W)M(&-A;B!O;FQY(&)E('-U8FUI='1E9"!O
M;F-E+B(^;F]N90H@("`@/&-A<V4@;F%M93TB;F]N92(@9&5S8STB1&ES86)L
M92!&;W)M(%1O:V5N<R(O/@H@("`@/&-A<V4@;F%M93TB9FEL92(@9&5S8STB
M3&]C86P@9FEL97-Y<W1E;2!T;VME;B!S=&]R86=E(CX*("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G1O:V5N7V1I<B(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)4:&4@9&ER96-T;W)Y('=H97)E"B`@("`@=&\@:V5E<"!T;VME;B!F:6QE
M<R(O/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)3
M44PM8F%S960@=&]K96X@<W1O<F%G92(^"B`@("`@/&-O;F9I9W-E8W1I;VX@
M;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I9W-Q;"!S=VET8VAN86UE/2)D
M<FEV97)C;VYF:6<B/@H@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L
M92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4*("`@
M("`@('1O:V5N<R!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W1O:V5N
M<UTB+SX*("`@("`@/"]C;VYF:6=S<6P^"B`@("`@/"]C;VYF:6=S96-T:6]N
M/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E
M8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](FUA:6QE
M<B(@9&5S8STB36%I;&5R(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)M86EL
M97(B/@H@("`\8V]N9FEG:&5A9&5R/DUA:6QE<CPO8V]N9FEG:&5A9&5R/@H@
M("`\8V]N9FEG<W=I=&-H(&YA;64](G1Y<&4B(&1E<V,](E=H870@;65T:&]D
M('-H;W5L9"!W92!U<V4@9F]R('-E;F1I;F<*("`@;6%I;#\B/G-E;F1M86EL
M"B`@("`\8V%S92!N86UE/2)N=6QL(B!D97-C/2)$:7-A8FQE(&UA:6QI;F<B
M("\^"B`@("`\8V%S92!N86UE/2)S96YD;6%I;"(@9&5S8STB57-E('1H92!L
M;V-A;"!S96YD;6%I;"!B:6YA<GDB/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA
M;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5N9&UA
M:6Q?<&%T:"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;&]C871I;VX*
M("`@("`@;V8@=&AE('-E;F1M86EL(&)I;F%R>2!O;B!T:&4@9FEL97-Y<W1E
M;0H@("`@("!;+W5S<B]S8FEN+W-E;F1M86EL72(^+W5S<B]L:6(O<V5N9&UA
M:6P\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S
M96YD;6%I;%]A<F=S(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](D%N>2!E>'1R
M80H@("`@("!P87)A;65T97)S('1O('!A<W,@=&\@=&AE('-E;F1M86EL(&]R
M('-E;F1M86EL('=R87!P97(*("`@("`@8FEN87)Y(CXM;VD\+V-O;F9I9W-T
M<FEN9SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@("`\+V-A<V4^"B`@("`\
M8V%S92!N86UE/2)S;71P(B!D97-C/2)5<V4@82!33510('-E<G9E<B(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)H;W-T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E1H
M92!S97)V97(@=&\@8V]N;F5C=`H@("`@("!T;R!;;&]C86QH;W-T72(O/@H@
M("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!R97%U:7)E9#TB9F%L
M<V4B(&1E<V,](E1H92!P;W)T('1O(&-O;FYE8W0*("`@("`@=&\@6S(U72(O
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FQO8V%L:&]S="(@<F5Q=6ER
M960](F9A;'-E(B!D97-C/2)4:&4@;&]C86P@:&]S=&YA;64*("`@("`@+R!D
M;VUA:6X@6VQO8V%L:&]S=%TB+SX*("`@("`@/&-O;F9I9V5N=6T@;F%M93TB
M875T:"(@9&5S8STB4TU44"!A=71H96YT:6-A=&EO;B(^,`H@("`@("`@/'9A
M;'5E<SX*("`@("`@("`\=F%L=64@9&5S8STB3F\@875T:&5N=&EC871I;VXB
M/C`\+W9A;'5E/@H@("`@("`@(#QV86QU92!D97-C/2)"97-T(&%V86EL86)L
M92!A=71H96YT:6-A=&EO;B(^,3PO=F%L=64^"B`@("`@("`@/'9A;'5E/D1)
M1T535"U-1#4\+W9A;'5E/@H@("`@("`@(#QV86QU93Y#4D%-+4U$-3PO=F%L
M=64^"B`@("`@("`@/'9A;'5E/DQ/1TE./"]V86QU93X*("`@("`@("`\=F%L
M=64^4$Q!24X\+W9A;'5E/@H@("`@("`@/"]V86QU97,^"B`@("`@(#PO8V]N
M9FEG96YU;3X*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@=7-E<FYA;64@=&\@=7-E(&9O
M<B!33510(&%U=&@B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S
M=V]R9"(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&%S<W=O<F0@=&\@
M=7-E(&9O<B!33510(&%U=&@B+SX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@
M("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C=&EO
M;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB=F9S(B!D97-C
M/2)6:7)T=6%L($9I;&4@4W1O<F%G92(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB=F9S(CX*("`@/&-O;F9I9VAE861E<CY6:7)T=6%L($9I;&4@4W1O<F%G
M93PO8V]N9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](G1Y<&4B
M(&1E<V,](DEF(&$@5D93("AV:7)T=6%L(&9I;&5S>7-T96TI(&)A8VME;F0@
M:7,*("`@<F5Q=6ER960L('=H:6-H(&]N92!S:&]U;&0@=V4@=7-E/R(^9FEL
M90H@("`@/&-A<V4@;F%M93TB9FEL92(@9&5S8STB1FEL97,@;VX@=&AE(&QO
M8V%L('-Y<W1E;2(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US
M(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)V9G-R;V]T(B!D97-C/2)7
M:&5R92!O;B!T:&4@<F5A;"!F:6QE<WES=&5M('-H;W5L9`H@("`@("!(;W)D
M92!U<V4@87,@<F]O="!O9B!T:&4@=FER='5A;"!F:6QE<WES=&5M/R(^+W1M
M<#PO8V]N9FEG<W1R:6YG/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO
M8V%S93X*("`@(#QC87-E(&YA;64](G-Q;"(@9&5S8STB4U%,(&1A=&%B87-E
M(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\
M8V]N9FEG<W%L('-W:71C:&YA;64](F1R:79E<F-O;F9I9R(^"B`@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G9F<U]T86)L92(@9&5S8STB5&AE(&YA;64@
M;V8@=&AE(%9&4R!T86)L92!I;B!T:&4*("`@("`@(&1A=&%B87-E(%MH;W)D
M95]V9G-=(B!R97%U:7)E9#TB9F%L<V4B+SX*("`@("`@/"]C;VYF:6=S<6P^
M"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I
M9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\
M8V]N9FEG=&%B(&YA;64](G-E<W-I;VXB(&1E<V,](D-U<W1O;2!397-S:6]N
M($AA;F1L97(B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G-E<W-I;VYH86YD
M;&5R(CX*("`@/&-O;F9I9VAE861E<CY#=7-T;VT@4V5S<VEO;B!(86YD;&5R
M/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB='EP92(@
M9&5S8STB5VAA="!S97-S:6]N:&%N9&QE<B!D<FEV97(@<VAO=6QD('=E"B`@
M('5S93\B/FYO;F4*("`@(#QC87-E(&YA;64](FYO;F4B(&1E<V,](E5S92!T
M:&4@9&5F875L="!02%`@*&9I;&4M8F%S960I('-E<W-I;VX@:&%N9&QE<B(O
M/@H@("`@/&-A<V4@;F%M93TB97AT97)N86PB(&1E<V,](E5S92!Y;W5R(&]W
M;B!C=7-T;VT@<V5S<VEO;B!H86YD;&5R(CX*("`@("`\8V]N9FEG<V5C=&EO
M;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F]P
M96XB(&1E<V,](EEO=7(@;W!E;B@I(&9U;F-T:6]N(B\^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB8VQO<V4B(&1E<V,](EEO=7(@8VQO<V4H*2!F=6YC
M=&EO;B(O/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G)E860B(&1E<V,]
M(EEO=7(@<F5A9"@I(&9U;F-T:6]N(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB=W)I=&4B(&1E<V,](EEO=7(@=W)I=&4H*2!F=6YC=&EO;B(O/@H@
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](F1E<W1R;WDB(&1E<V,](EEO=7(@
M9&5S=')O>2@I(&9U;F-T:6]N(B\^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB9V,B(&1E<V,](EEO=7(@9V,H*2!F=6YC=&EO;B(O/@H@("`@(#PO8V]N
M9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E(&YA;64](F1B;2(@
M9&5S8STB1$)-(&)A<V5D('-E<W-I;VYS(B\^"B`@("`\8V%S92!N86UE/2)M
M>7-Q;"(@9&5S8STB37E344P@8F%S960@<V5S<VEO;G,B/@H@("`@(#QC;VYF
M:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC;VYF:6=B;V]L96%N
M(&YA;64](G!E<G-I<W1E;G0B(&1E<V,](E)E<75E<W0@<&5R<VES=&5N="!C
M;VYN96-T:6]N<S\B/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`\8V]N
M9FEG8F]O;&5A;B!N86UE/2)R;W=L;V-K:6YG(B!D97-C/2)3:&]U;&0@=V4@
M=7-E(')O=RUL979E;"!L;V-K:6YG"B`@("`@(&%N9"!T<F%N<V%C=&EO;G,_
M(%1H:7,@:7,@<W1R;VYG;'D@<F5C;VUM96YD960L(&)U="!R97%U:7)E<R!A
M('1A8FQE"B`@("`@('1Y<&4@=&AA="!I<R!T<F%N<V%C=&EO;BUS869E(&%N
M9"!S=7!P;W)T<R!R;W<M;&5V96P@;&]C:VEN9RP@;&EK90H@("`@("!);FYO
M1$(N($EF('EO=2!D;VXG="!H879E('-U8V@@82!T86)L92!T>7!E+"!D:7-A
M8FQE('1H:7,@<V5T=&EN9R!A;F0@=V4*("`@("`@=VEL;"!U<V4@=&%B;&4M
M;&5V96P@;&]C:VEN9R!A;F0@;F\@;&]C:VEN9PH@("`@("!I;G-T96%D+B(^
M=')U93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-W:71C:"!N86UE
M/2)P<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W:6QL('=E('5S92!T
M;R!C;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*("`@("`@(#QC87-E
M(&YA;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^"B`@("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@
M("`@("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB=&-P(B!D97-C/2)4
M0U`O25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E
M<75I<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O
M;BP@:68@;F]N+7-T86YD87)D(CXS,S`V/"]C;VYF:6=I;G1E9V5R/@H@("`@
M("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I
M<R!T:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@
M=&AE(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T
M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E
M<FYA;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E
M('1O('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R
M:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U
M:7)E9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N
M=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@
M/&-O;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S8STB5VAA="!D871A
M8F%S92!N86UE+W1A8FQE<W!A8V4@87)E('=E('5S:6YG/R(^:&]R9&4\+V-O
M;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L92(@
M<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@<V5S<VEO
M;B!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W-E<W-I;VYH86YD;&5R
M72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC
M87-E(&YA;64](F]C:3@B(&1E<V,](D]R86-L92!B87-E9"!S97-S:6]N<R(^
M"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O
M;F9I9V)O;VQE86X@;F%M93TB<&5R<VES=&5N="(@9&5S8STB4F5Q=65S="!P
M97)S:7-T96YT(&-O;FYE8W1I;VYS/R(^"B`@("`@(&9A;'-E/"]C;VYF:6=B
M;V]L96%N/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](FAO<W1S<&5C(B!D
M97-C/2)$871A8F%S92!N86UE(&]R($5A<WD@0V]N;F5C=`H@("`@("!P87)A
M;65T97(B/FAO<F1E/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@
M875T:&5N=&EC871E('1O"B`@("`@('1H92!D871A8F%S92!S97)V97(@87,_
M(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E=H870@<&%S
M<W=O<F0@9&\@=V4*("`@("`@875T:&5N=&EC871E('1O('1H92!D871A8F%S
M92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T
M86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@
M<V5S<VEO;@H@("`@("!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W-E
M<W-I;VYH86YD;&5R72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO
M8V%S93X*("`@(#QC87-E(&YA;64](G!G<W%L(B!D97-C/2)0;W-T9W)E4U%,
M(&)A<V5D('-E<W-I;VYS(CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)P
M87)A;7,B/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)P97)S:7-T96YT
M(B!D97-C/2)297%U97-T('!E<G-I<W1E;G0@8V]N;F5C=&EO;G,_(CYF86QS
M93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-W:71C:"!N86UE/2)P
M<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W:6QL('=E('5S92!T;R!C
M;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*("`@("`@(#QC87-E(&YA
M;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^"B`@("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D/2)F86QS92(@9&5S8STB
M3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N9FEG<W1R:6YG/@H@("`@
M("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB=&-P(B!D97-C/2)40U`O
M25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA;64](G!O<G0B(')E<75I
M<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@:7,@<G5N;FEN9R!O;BP@
M:68@;F]N+7-T86YD87)D(CXU-#,R/"]C;VYF:6=I;G1E9V5R/@H@("`@("`@
M/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA="!H;W-T;F%M92!I<R!T
M:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL(&]R('=H870@:7,@=&AE
M(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E/R(^;&]C86QH;W-T/"]C
M;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB=7-E<FYA
M;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@875T:&5N=&EC871E('1O
M('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D93PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A<W-W;W)D(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@9&\@=V4@875T:&5N=&EC
M871E('1O('1H92!D871A8F%S92!S97)V97(@=VET:#\B+SX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S8STB5VAA="!D871A8F%S
M92!N86UE+W1A8FQE<W!A8V4@87)E('=E('5S:6YG/R(^:&]R9&4\+V-O;F9I
M9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T86)L92(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O9B!T:&4@<V5S<VEO;B!T
M86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W-E<W-I;VYH86YD;&5R72(O
M/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO8V%S93X*("`@(#QC87-E
M(&YA;64](G-A<&1B(B!D97-C/2)5<V4@4$5!4B=S($1"(&%B<W1R86-T:6]N
M(&QA>65R('<O3T1"0R(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R
M86US(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S
M8STB5VAA="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI
M;F<@;VXL(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@
M=&\@=7-E/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF
M:6=S=')I;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E<FYA;64@
M9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@87,_
M(CYH;W)D93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA
M;64](G!A<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E=H870@<&%S
M<W=O<F0@9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V
M97(@=VET:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D871A8F%S
M92(@9&5S8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE<W!A8V4@87)E('=E
M('5S:6YG/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)T86)L92(@9&5S8STB5&AE(&YA;64@;V8@=&AE('-E<W-I
M;VX@=&%B;&4@:6X@=&AE(&1A=&%B87-E(B\^"B`@("`@/"]C;VYF:6=S96-T
M:6]N/@H@("`@/"]C87-E/@H@("`@/&-A<V4@;F%M93TB<W%L(B!D97-C/2)5
M<V4@4$5!4B=S($1"(&%B<W1R86-T:6]N(&QA>65R(CX*("`@("`\8V]N9FEG
M<V5C=&EO;B!N86UE/2)P87)A;7,B/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N
M86UE/2)P97)S:7-T96YT(B!D97-C/2)297%U97-T('!E<G-I<W1E;G0@8V]N
M;F5C=&EO;G,_(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I
M9W-W:71C:"!N86UE/2)P<F]T;V-O;"(@9&5S8STB5VAA="!P<F]T;V-O;"!W
M:6QL('=E('5S92!T;R!C;VYN96-T('1O('1H92!D871A8F%S93\B/G5N:7@*
M("`@("`@(#QC87-E(&YA;64](G5N:7@B(&1E<V,](E5.25@@4V]C:V5T<R(^
M"B`@("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S;V-K970B(')E<75I<F5D
M/2)F86QS92(@9&5S8STB3&]C871I;VX@;V8@54Y)6"!S;V-K970B/CPO8V]N
M9FEG<W1R:6YG/@H@("`@("`@/"]C87-E/@H@("`@("`@/&-A<V4@;F%M93TB
M=&-P(B!D97-C/2)40U`O25`B/@H@("`@("`@(#QC;VYF:6=I;G1E9V5R(&YA
M;64](G!O<G0B(')E<75I<F5D/2)F86QS92(@9&5S8STB4&]R="!T:&4@1$(@
M:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D(CXU-#,R/"]C;VYF:6=I
M;G1E9V5R/@H@("`@("`@/"]C87-E/@H@("`@("`\+V-O;F9I9W-W:71C:#X*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)H;W-T<W!E8R(@9&5S8STB5VAA
M="!H;W-T;F%M92!I<R!T:&4@9&%T86)A<V4@<V5R=F5R(')U;FYI;F<@;VXL
M(&]R('=H870@:7,@=&AE(&YA;64@;V8@=&AE('-Y<W1E;2!$4TX@=&\@=7-E
M/R(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I
M;F<@;F%M93TB=7-E<FYA;64B(&1E<V,](E=H870@=7-E<FYA;64@9&\@=V4@
M875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@87,_(CYH;W)D
M93PO8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!A
M<W-W;W)D(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E=H870@<&%S<W=O<F0@
M9&\@=V4@875T:&5N=&EC871E('1O('1H92!D871A8F%S92!S97)V97(@=VET
M:#\B+SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)D871A8F%S92(@9&5S
M8STB5VAA="!D871A8F%S92!N86UE+W1A8FQE<W!A8V4@87)E('=E('5S:6YG
M/R(^:&]R9&4\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N
M86UE/2)T86)L92(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)4:&4@;F%M92!O
M9B!T:&4@<V5S<VEO;B!T86)L92!I;B!T:&4@9&%T86)A<V4@6VAO<F1E7W-E
M<W-I;VYH86YD;&5R72(O/@H@("`@(#PO8V]N9FEG<V5C=&EO;CX*("`@(#PO
M8V%S93X*("`@(#QC87-E(&YA;64](FUE;6-A8VAE(B!D97-C/2)-96UC86-H
M92!S97)V97(B/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^
M"B`@("`@(#QC;VYF:6=L:7-T(&YA;64](FAO<W1S<&5C(B!D97-C/2)7:&%T
M(&AO<W1N86UE(&ES('1H92!M96UC86-H92!S97)V97(*("`@("`@<G5N;FEN
M9R!O;BP@;W(@=VAA="!I<R!T:&4@;F%M92!O9B!T:&4@<WES=&5M($133B!T
M;R!U<V4_("!3<&5C:69Y"B`@("`@(&UU;'1I<&QE('-E<G9E<G,@<V5P87)A
M=&5D(&)Y(&-O;6UA<RXB/FQO8V%L:&]S=#PO8V]N9FEG;&ES=#X*("`@("`@
M/&-O;F9I9VQI<W0@;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E(B!D97-C
M/2)0;W)T*',I('1H92!M96UC86-H90H@("`@("!S97)V97(@:7,@<G5N;FEN
M9R!O;BX@268@;6]R92!T:&%N(&]N92!H;W-T(&ES('5S960L('-P96-I9GD@
M<&]R=',@9F]R"B`@("`@(')E<W!E8W1I=F4@<V5R=F5R<RP@<V5P87)A=&5D
M(&)Y(&-O;6UA<R(^,3$R,3$\+V-O;F9I9VQI<W0^"B`@("`@(#QC;VYF:6=B
M;V]L96%N(&YA;64](G!E<G-I<W1E;G0B(')E<75I<F5D/2)F86QS92(@9&5S
M8STB4F5Q=65S=`H@("`@("!P97)S:7-T96YT(&-O;FYE8W1I;VX@=&\@<V5R
M=F5R+B(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"B`@("`@(#QC;VYF:6=B;V]L
M96%N(&YA;64](F-O;7!R97-S:6]N(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,]
M(D5N86)L90H@("`@("!C;VUP<F5S<VEO;B!F;W(@<W1O<FEN9R!E;G1R:65S
M(&]N('-E<G9E<BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@("`\8V]N
M9FEG<W1R:6YG(&YA;64](FQO8VM?9&ER(B!D97-C/2)3<&5C:69Y(&$@9&ER
M96-T;W)Y('1O('=H:6-H('1H90H@("`@("!S97-S:6]N(&QO8VMS('-H;W5L
M9"!B92!W<FET=&5N(CXO=&UP/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF
M:6=S96-T:6]N/@H@("`@/"]C87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\
M+V-O;F9I9W-E8W1I;VX^"B`\+V-O;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA
M;64](FEM86=E(B!D97-C/2));6%G92!-86YI<'5L871I;VXB/@H@(#QC;VYF
M:6=S96-T:6]N(&YA;64](FEM86=E(CX*("`@/&-O;F9I9VAE861E<CY);6%G
M92!-86YI<'5L871I;VX\+V-O;F9I9VAE861E<CX*("`@/&-O;F9I9W-T<FEN
M9R!N86UE/2)C;VYV97)T(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](DAO<F1E
M(')E<75I<F5S(&5I=&AE<@H@("!'1"!S=7!P;W)T(&)U:6QT+6EN('1O(%!(
M4"`H+2UW:71H+6=D*2!O<B!T:&4@26UA9V5-86=I8VL@<V]F='=A<F4*("`@
M<&%C:V%G92`H:'1T<#HO+W=W=RYI;6%G96UA9VEC:RYO<F<O*2!T;R!D;R!I
M;6%G90H@("!M86YI<'5L871I;VXO8W)E871I;VXN($EF('5S:6YG($EM86=E
M36%G:6-K+"!S<&5C:69Y('1H92!F=6QL('!A=&@*("`@;F%M92!T;R!T:&4@
M)V-O;G9E<G0G('!R;V=R86TN($]N(%=I;F1O=W,L('1H:7,@<&%T:"`J8V%N
M;F]T*B!H879E"B`@('-P86-E<R!I;B!I="X@57-E($1/4RUS='EL92!A8F)R
M979I871I;VYS(&EF(&YE8V5S<V%R>3H@4')O9W)A?C$*("`@:6YS=&5A9"!O
M9B!0<F]G<F%M($9I;&5S+"!F;W(@:6YS=&%N8V4N($EF('5S:6YG($=$+"!O
M<B!U<VEN9PH@("!N96ET:&5R+"!L96%V92!T:&ES(&9I96QD(&)L86YK+B(O
M/@H@(#PO8V]N9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T
M86(@;F%M93TB;6EM92(@9&5S8STB34E-12!$971E8W1I;VXB/@H@(#QC;VYF
M:6=S96-T:6]N(&YA;64](FUI;64B/@H@("`\8V]N9FEG:&5A9&5R/DU)344@
M1&5T96-T:6]N/"]C;VYF:6=H96%D97(^"B`@(#QC;VYF:6=S=')I;F<@;F%M
M93TB;6%G:6-?9&(B(')E<75I<F5D/2)F86QS92(@9&5S8STB3&]C871I;VX@
M;V8@=&AE($U)344*("`@;6%G:6,@9&%T86)A<V4N(%5S=6%L;'D@+W5S<B]S
M:&%R92]M:7-C+VUA9VEC(&]R("]E=&,O;6%G:6,N(B\^"B`@/"]C;VYF:6=S
M96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)G96]I
M<"(@9&5S8STB2&]S=&YA;64M)F=T.T-O=6YT<GD@3&]O:W5P(CX*("`\8V]N
M9FEG<V5C=&EO;B!N86UE/2)G96]I<"(^"B`@(#QC;VYF:6=H96%D97(^2&]S
M=&YA;64M)F=T.T-O=6YT<GD@3&]O:W5P/"]C;VYF:6=H96%D97(^"B`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB9&%T869I;&4B(')E<75I<F5D/2)F86QS92(@
M9&5S8STB2&]R9&4L(&)Y(&1E9F%U;'0L(&-A;@H@("!D;R!(;W-T;F%M92`M
M)F=T.R!#;W5N=')Y(&QO;VMU<"!U<VEN9R!T:&4@=&]P(&QE=F5L(&1O;6%I
M;B`H92YG+B`G=6LG+`H@("`G9&4G*2!O9B!T:&4@:&]S=&YA;64N("!(;W=E
M=F5R+"!M86YY('!O<'5L87(@=&]P(&QE=F5L(&1O;6%I;G,*("`@*&4N9RX@
M)V-O;2<L("=N970G*2!S<&%N(&UO<F4@=&AA;B!O;F4@8V]U;G1R>2X@($EN
M('1H97-E(&EN<W1A;F-E<RP@2&]R9&4*("`@8V%N('5S92!T:&4@36%X36EN
M9"!'96])4"!(;W-T;F%M92!T;R!#;W5N=')Y(&QO;VMU<"!T;R!T<GD@=&\@
M9&5T97)M:6YE"B`@('1H92!C;W)R96-T(&-O=6YT<GDN("!4;R!A8W1I=F%T
M92!T:&ES(&9U;F-T:6]N86QI='DL('1H92!'96])4"YD870@8V]U;G1R>0H@
M("!D871A8F%S92!M=7-T(&)E('!R97-E;G0@;VX@>6]U<B!L;V-A;"!S>7-T
M96TN("!4:&ES(&9I;&4@8V%N(&)E(&1O=VYL;V%D960*("`@9G)E92!O9B!C
M:&%R9V4@9G)O;2!H='1P.B\O=W=W+FUA>&UI;F0N8V]M+V1O=VYL;V%D+V=E
M;VEP+V1A=&%B87-E+RX@($EF"B`@('1H:7,@9&%T86)A<V4@:7,@<')E<V5N
M="P@<W!E8VEF>2!T:&4@9G5L;"!P871H(&YA;64@=&\@=&AE(&1A=&%B87-E
M(&)E;&]W+@H@("!)9B!E;7!T>2P@=&AE($=E;TE0(&QO;VMU<"!W:6QL(&YO
M="!B92!P97)F;W)M960N(B\^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF
M:6=T86(^"@H@/&-O;F9I9W1A8B!N86UE/2)P<F]B;&5M<R(@9&5S8STB4')O
M8FQE;2!297!O<G1I;F<B/@H@(#QC;VYF:6=S96-T:6]N(&YA;64](G!R;V)L
M96US(CX*("`@/&-O;F9I9VAE861E<CY0<F]B;&5M(%)E<&]R=&EN9SPO8V]N
M9FEG:&5A9&5R/@H@("`\8V]N9FEG<W=I=&-H(&YA;64](G1I8VME=',B(&1E
M<V,](DEF(&$@=&EC:V5T('-Y<W1E;2!W:71H(&$*("`@=&EC:V5T<R]A9&14
M:6-K970@05!)(&UE=&AO9"!I<R!P<F5S96YT+"!S:&]U;&0@=V4@8W)E871E
M('1I8VME=',@9F]R"B`@('!R;V)L96T@<F5P;W)T<R!I;G-T96%D(&]F(&5M
M86EL:6YG('1H96T_(CYF86QS90H@("`@/&-A<V4@;F%M93TB=')U92(@9&5S
M8STB665S(CX*("`@("`\8V]N9FEG<&AP(&YA;64](G1I8VME=%]P87)A;7,B
M(&1E<V,](D5N=&5R(&%S(&$@4$A0(&%R<F%Y(&%N>0H@("`@(&%D9&ET:6]N
M86P@87)G=6UE;G1S(&9O<B!T:&4@8W)E871E9"!T:6-K970@*'%U975E+"!S
M=&%T92P@<')I;W)I='DL"B`@("`@971C*2X@17AA;7!L92!F;W(@5VAU<',Z
M(&%R<F%Y*"=Q=65U92<@/3X@,BP@)W-T871E)R`]/B`Q+"`G<')I;W)I='DG
M(#T^(#$L"B`@("`@)W1Y<&4G(#T^(#$I+B!9;W4@=VEL;"!N965D('1O(&QO
M;VL@=7`@=&AE(&%P<')O<')I871E($E$<R!I;B!7:'5P<R=S"B`@("`@9&%T
M86)A<V4L(&]R('=H871E=F5R(&ES(&%P<')O<')I871E(&9O<B!T:&4@=&EC
M:V5T('-Y<W1E;2!Y;W4@87)E"B`@("`@=7-I;F<N(CYA<G)A>2@I/"]C;VYF
M:6=P:'`^"B`@("`\+V-A<V4^"B`@("`\8V%S92!N86UE/2)F86QS92(@9&5S
M8STB3F\B/@H@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB96UA:6PB(&1E<V,]
M(E=H97)E('-H;W5L9"!P<F]B;&5M(')E<&]R="!E;6%I;',@8F4@<V5N=#\B
M/@H@("`@('=E8FUA<W1E<D!E>&%M<&QE+F-O;3PO8V]N9FEG<W1R:6YG/@H@
M("`@(#QC;VYF:6=S=')I;F<@;F%M93TB;6%I;&1O;6%I;B(@9&5S8STB268@
M2&]R9&4@8V%N;F]T(&1E=&5R;6EN92!A('5S97(G<PH@("`@(&5M86EL(&%D
M9')E<W,L('1H:7,@9&]M86EN('=I;&P@8F4@87!P96YD960@=&\@=&AE:7(*
M("`@("!U<V5R;F%M92XB/F5X86UP;&4N8V]M/"]C;VYF:6=S=')I;F<^"B`@
M("`@/&-O;F9I9W-T<FEN9R!N86UE/2)U<V5R;F%M92(@<F5Q=6ER960](F9A
M;'-E(B!D97-C/2))9B!R97%U:7)I;F<@4TU44`H@("`@(&%U=&AE;G1I8V%T
M:6]N('=I=&AO=70@82!G;&]B86P@4TU44"!U<V5R("AI;B!S96-T:6]N("9Q
M=6]T.TUA:6QE<B9Q=6]T.PH@("`@(&%N9"!A;&QO=VEN9R!P<F]B;&5M(')E
M<&]R=&EN9R!F;W(@;F]T(&%U=&AE;G1I8V%T960@=7-E<G,@*&EN('-E8W1I
M;VX*("`@("`F<75O=#M-96YU(%-E='1I;F=S)G%U;W0[*2P@=VAA="!U<V5R
M;F%M92!S:&]U;&0@8F4@=7-E(&9O<B!33510"B`@("`@875T:&5N=&EC871I
M;VX_(B\^"B`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P87-S=V]R9"(@<F5Q
M=6ER960](F9A;'-E(B!D97-C/2)4:&4@<&%S<W=O<F0@=&\@=7-E(B\^"B`@
M("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C=&EO
M;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB;65N=2(@9&5S
M8STB365N=2!3971T:6YG<R(^"B`@/&-O;F9I9VAE861E<CY-96YU(%-E='1I
M;F=S/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB;65N
M=2(^"B`@(#QC;VYF:6=M=6QT:65N=6T@;F%M93TB87!P<R(@9&5S8STB4V5L
M96-T(&%N>2!A<'!L:6-A=&EO;G,@=&AA="!S:&]U;&0@8F4*("`@;&EN:V5D
M(&EN($AO<F1E)W,@;65N=2(^"B`@("`\=F%L=65S/@H@("`@(#QC;VYF:6=S
M<&5C:6%L(&YA;64](FQI<W0M:&]R9&4M87!P<R(@+SX*("`@(#PO=F%L=65S
M/@H@("`\+V-O;F9I9VUU;'1I96YU;3X*"B`@(#QC;VYF:6=B;V]L96%N(&YA
M;64](F%L=V%Y<R(@9&5S8STB4VAO=6QD('=E"B`@("9L=#MS=')O;F<F9W0[
M86QW87ES)FQT.R]S=')O;F<F9W0[(&1I<W!L87D@=&AE($AO<F1E"B`@(&9R
M86UE<V5T/R(^9F%L<V4\+V-O;F9I9V)O;VQE86X^"@H@("`\8V]N9FEG<V5C
M=&EO;B!N86UE/2)L:6YK<R(^"B`@("`\8V]N9FEG96YU;2!N86UE/2)H96QP
M(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!H96QP(&QI;FMS(&EN('1H90H@
M("`@;65N=3\B/F%L;`H@("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D97-C
M/2)!;&P@=7-E<G,B/F%L;#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2)!
M=71H96YT:6-A=&5D('5S97)S(CYA=71H96YT:6-A=&5D/"]V86QU93X*("`@
M("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO=F%L=64^"B`@("`@/"]V
M86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@("`\8V]N9FEG8F]O;&5A;B!N
M86UE/2)H96QP7V%B;W5T(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!T:&4@
M86)O=70@;&EN:R!I;@H@("`@=&AE(&AE;'`@;65N=3\B/G1R=64\+V-O;F9I
M9V)O;VQE86X^"B`@("`\8V]N9FEG96YU;2!N86UE/2)O<'1I;VYS(B!D97-C
M/2)3:&]U;&0@=V4@9&ES<&QA>2!O<'1I;VYS(&QI;FMS(&EN('1H90H@("`@
M;65N=3\@66]U('-T:6QL(&YE960@=&\@8V]N9FEG=7)E(&$@<')E9F5R96YC
M92!B86-K96YD(&EN('1H90H@("`@)G%U;W0[4')E9F5R96YC92!3>7-T96TF
M<75O=#L@<V5C=&EO;BXB/F%U=&AE;G1I8V%T960*("`@("`\=F%L=65S/@H@
M("`@("`\=F%L=64@9&5S8STB06QL('5S97)S(CYA;&P\+W9A;'5E/@H@("`@
M("`\=F%L=64@9&5S8STB075T:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC
M871E9#PO=F%L=64^"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\
M+W9A;'5E/@H@("`@(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@
M/&-O;F9I9V5N=6T@;F%M93TB<')O8FQE;2(@9&5S8STB4VAO=6QD('=E(&1I
M<W!L87D@<')O8FQE;2!R97!O<G1I;F<@;&EN:W,*("`@(&EN('1H92!M96YU
M/R(^86QL"B`@("`@/'9A;'5E<SX*("`@("`@/'9A;'5E(&1E<V,](D%L;"!U
M<V5R<R(^86QL/"]V86QU93X*("`@("`@/'9A;'5E(&1E<V,](D%U=&AE;G1I
M8V%T960@=7-E<G,B/F%U=&AE;G1I8V%T960\+W9A;'5E/@H@("`@("`\=F%L
M=64@9&5S8STB3F5V97(B/FYE=F5R/"]V86QU93X*("`@("`\+W9A;'5E<SX*
M("`@(#PO8V]N9FEG96YU;3X*("`@(#QC;VYF:6=E;G5M(&YA;64](FQO9VEN
M(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!A(&QO9VEN(&QI;FL@:6X@=&AE
M(&UE;G4*("`@('=H96X@;F]T(&QO9V=E9"!I;C\B/F%L;`H@("`@(#QV86QU
M97,^"B`@("`@(#QV86QU92!D97-C/2)!;&P@=7-E<G,B/F%L;#PO=F%L=64^
M"B`@("`@(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E/@H@("`@
M(#PO=F%L=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I9V5N=6T@
M;F%M93TB;&]G;W5T(B!D97-C/2)3:&]U;&0@=V4@9&ES<&QA>2!A(&QO9V]U
M="!L:6YK(&EN('1H90H@("`@;65N=2!W:&5N(&QO9V=E9"!I;C\B/F%U=&AE
M;G1I8V%T960*("`@("`\=F%L=65S/@H@("`@("`\=F%L=64@9&5S8STB075T
M:&5N=&EC871E9"!U<V5R<R(^875T:&5N=&EC871E9#PO=F%L=64^"B`@("`@
M(#QV86QU92!D97-C/2).979E<B(^;F5V97(\+W9A;'5E/@H@("`@(#PO=F%L
M=65S/@H@("`@/"]C;VYF:6=E;G5M/@H@("`@/&-O;F9I9V5N=6T@;F%M93TB
M;&]G:6XB(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&$@;&]G:6X@;&EN:R!I
M;B!T:&4@;65N=0H@("`@=VAE;B!N;W0@;&]G9V5D(&EN/R(^86QL"B`@("`@
M/'9A;'5E<SX*("`@("`@/'9A;'5E(&1E<V,](D%L;"!U<V5R<R(^86QL/"]V
M86QU93X*("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO=F%L=64^
M"B`@("`@/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@("`\8V]N9FEG
M96YU;2!N86UE/2)L;V=O=70B(&1E<V,](E-H;W5L9"!W92!D:7-P;&%Y(&$@
M;&]G;W5T(&QI;FL@:6X@=&AE"B`@("!M96YU('=H96X@;&]G9V5D(&EN/R(^
M875T:&5N=&EC871E9`H@("`@(#QV86QU97,^"B`@("`@(#QV86QU92!D97-C
M/2)!=71H96YT:6-A=&5D('5S97)S(CYA=71H96YT:6-A=&5D/"]V86QU93X*
M("`@("`@/'9A;'5E(&1E<V,](DYE=F5R(CYN979E<CPO=F%L=64^"B`@("`@
M/"]V86QU97,^"B`@("`\+V-O;F9I9V5N=6T^"B`@(#PO8V]N9FEG<V5C=&EO
M;CX*("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=S96-T:6]N(&YA;64]
M(FQO9V\B/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](FEM86=E(B!R97%U:7)E
M9#TB9F%L<V4B(&1E<V,](E1H92!54DP@;V8@86X@:6UA9V4@9F]R"B`@('1H
M92!T;W`@;V8@=&AE($AO<F1E(&UE;G4N(%1H92!I;6%G92!S:&]U;&0@8F4@
M;F\@;&%R9V5R('1H86X@,30P('!I>&5L<PH@("!W:61E(&)Y(#0P('!I>&5L
M<R!H:6=H('1O('!R979E;G0@=&AE(&9R86UE(&9R;VT@<V-R;VQL:6YG+B(O
M/@H@("`\8V]N9FEG<W1R:6YG(&YA;64](FQI;FLB(')E<75I<F5D/2)F86QS
M92(@9&5S8STB268@82!L;V=O(&ES(&1I<W!L87EE9"!I;@H@("!T:&4@2&]R
M9&4@;65N=2P@=VAA="!54DP@*&EF(&%N>2D@<VAO=6QD(&ET(&QI;FL@=&\_
M(B\^"B`@/"]C;VYF:6=S96-T:6]N/@H@/"]C;VYF:6=T86(^"@H@/&-O;F9I
M9W1A8B!N86UE/2)H;V]K<R(@9&5S8STB0W5S=&]M($9U;F-T:6]N($AO;VMS
M(CX*("`\8V]N9FEG<V5C=&EO;B!N86UE/2)H;V]K<R(^"B`@(#QC;VYF:6=H
M96%D97(^0W5S=&]M($9U;F-T:6]N($AO;VMS/"]C;VYF:6=H96%D97(^"B`@
M(#QC;VYF:6=D97-C<FEP=&EO;CX*("`@(%1H97)E(&%R92!E>&%M<&QE(&9U
M;F-T:6]N<R!F;W(@86QL(&AO;VMS(&EN(&AO<F1E+V-O;F9I9R]H;V]K<RYP
M:'`N9&ES="X*("`@/"]C;VYF:6=D97-C<FEP=&EO;CX*("`@/&-O;F9I9V)O
M;VQE86X@;F%M93TB<&5R;7-D96YI960B(&1E<V,](DEF('1H:7,@:7,@8VAE
M8VME9"P@=&AE"B`@(&9U;F-T:6]N(%]P97)M<U]H;V]K7V1E;FEE9"@I('=I
M;&P@8F4@8V%L;&5D('1O(')E='5R;B!A;B!E<G)O<B!M97-S86=E(&EF"B`@
M(&$@<&5R;6ES<VEO;B!H87,@8F5E;B!D96YI960N($]T:&5R=VES92!A('-T
M86YD87)D(&UE<W-A9V4@=VEL;"!B92!S:&]W;@H@("!A;F0@=&AE('5S97(@
M=V]N)W0@<V5E(&%N>2!A8W1I;VX@=VED9V5T<R!T:&%T(&AE(&1O97-N)W0@
M:&%V92!A8V-E<W,*("`@=&\N(CYF86QS93PO8V]N9FEG8F]O;&5A;CX*("`@
M/&-O;F9I9V)O;VQE86X@;F%M93TB=7-E<FYA;64B(&1E<V,](DEF('1H:7,@
M:7,@8VAE8VME9"P@=&AE(&9U;F-T:6]N"B`@(%]U<V5R;F%M95]H;V]K7V9R
M;VUB86-K96YD*"D@=VEL;"!B92!U<V5D('1O('-E="!T:&4@=7-E<B!N86UE
M(&%T(&QO9VEN"B`@('1I;64N(%1H92!C;W5N=&5R<&%R="!F=6YC=&EO;B!?
M=7-E<FYA;65?:&]O:U]T;V)A8VME;F0H*2!W:6QL(&)E('5S960@=&\*("`@
M8V]N=F5R="!U<V5R(&YA;65S(&)A8VLL(&9O<B!E>&%M<&QE('=H96X@<VAO
M=VEN9R!N86UE(&QI<W1S('1O('1H90H@("!U<V5R+B(^9F%L<V4\+V-O;F9I
M9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G!R96%U=&AE;G1I
M8V%T92(@9&5S8STB268@=&AI<R!I<R!C:&5C:V5D(&%N9"!T:&4*("`@9G5N
M8W1I;VX@7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E*"D@<F5T=7)N<R!F
M86QS92P@875T:&5N=&EC871I;VX@=VEL;`H@("!F86EL+B(^9F%L<V4\+V-O
M;F9I9V)O;VQE86X^"B`@(#QC;VYF:6=B;V]L96%N(&YA;64](G!O<W1A=71H
M96YT:6-A=&4B(&1E<V,](DEF('1H:7,@:7,@8VAE8VME9"!A;F0@=&AE"B`@
M(&9U;F-T:6]N(%]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A=&4H*2!R971U
M<FYS(&9A;'-E+"!A=71H96YT:6-A=&EO;B!W:6QL"B`@(&9A:6PN(CYF86QS
M93PO8V]N9FEG8F]O;&5A;CX*("`@/&-O;F9I9V)O;VQE86X@;F%M93TB875T
M:&QD87`B(&1E<V,](DEF('1H:7,@:7,@8VAE8VME9"P@=&AE(&9U;F-T:6]N
M"B`@(%]H;W)D95]H;V]K7V%U=&AL9&%P*"D@=VEL;"!B92!U<V5D('1O(&-R
M96%T92!A;F0@<V5T('1H92!A='1R:6)U=&5S(&YE961E9`H@("!T;R!A9&0O
M961I="]D96QE=&4@=7-E<G,@8GD@=&AE($Q$05`@075T:"!D<FEV97(N(CYF
M86QS93PO8V]N9FEG8F]O;&5A;CX*("`\+V-O;F9I9W-E8W1I;VX^"B`\+V-O
M;F9I9W1A8CX*"B`\8V]N9FEG=&%B(&YA;64](F)L;V-K(B!D97-C/2)0;W)T
M86P@0FQO8VL@0V]N9FEG=7)A=&EO;B(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M
M93TB<&]R=&%L(CX*("`@/&-O;F9I9VAE861E<CY&:7AE9"!";&]C:W,\+V-O
M;F9I9VAE861E<CX*("`@/&-O;F9I9VUU;'1I96YU;2!N86UE/2)F:7AE9%]B
M;&]C:W,B(&UU;&1E<V,](E=H:6-H(&)L;V-K<R!S:&]U;&0@86QW87ES(&)E
M"B`@("!D:7-P;&%Y960@:6X@=&AE('!O<G1A;#\B/@H@("`@/'9A;'5E<SX*
M("`@("`\8V]N9FEG<W!E8VEA;"!N86UE/2)L:7-T+6)L;V-K<R(@+SX*("`@
M(#PO=F%L=65S/@H@("`\+V-O;F9I9VUU;'1I96YU;3X*("`\+V-O;F9I9W-E
M8W1I;VX^"B`@/&-O;F9I9VAE861E<CYW96%T:&5R+F-O;2!#;VYF:6=U<F%T
M:6]N/"]C;VYF:6=H96%D97(^"B`@/&-O;F9I9W-E8W1I;VX@;F%M93TB=V5A
M=&AE<F1O=&-O;2(^"B`@(#QC;VYF:6=D97-C<FEP=&EO;CX*("`@(%5S92!O
M9B!T:&4@=V5A=&AE<BYC;VT@8FQO8VL@<F5Q=6ER97,@9G)E92!R96=I<W1R
M871I;VX@9F]R('1H92!834P*("`@(&9E960@870@:'1T<#HO+W=W=RYW96%T
M:&5R+F-O;2]S97)V:6-E<R]X;6QO87`N:'1M;"X*("`@($%F=&5R(')E9VES
M=')A=&EO;BP@86X@96UA:6P@=VEL;"!B92!R971U<FYE9"!W:71H('1H92!0
M87)T;F5R($E$(&%N9`H@("`@;&EC96YS92!K97DN)FQT.V)R("\F9W0["B`@
M("!.3U1%.B!W96%T:&5R+F-O;2!G=6ED96QI;F5S(')E<75I<F4@<F5G:7-T
M<F%T:6]N(&%N9"!U<V4@;V8@=&AE(')E='5R;F5D"B`@("!V86QU97,L(&)U
M="!T:&4@87!P;&EC871I;VX@87!P96%R<R!T;R!F=6YC=&EO;B!W:71H(&%N
M>2!S=')I;F<@=F%L=65S+@H@("`\+V-O;F9I9V1E<V-R:7!T:6]N/@H@("`\
M8V]N9FEG<W1R:6YG(&YA;64](G!A<G1N97)?:60B(')E<75I<F5D/2)F86QS
M92(@9&5S8STB5&AE('!A<G1N97(@22Y$+@H@("!F<F]M('=E871H97(N8V]M
M(B\^"B`@(#QC;VYF:6=S=')I;F<@;F%M93TB;&EC96YS95]K97DB(')E<75I
M<F5D/2)F86QS92(@9&5S8STB5&AE(&QI8V5N<V4@:V5Y"B`@(&9R;VT@=V5A
M=&AE<BYC;VTB+SX*("`\+V-O;F9I9W-E8W1I;VX^"@H@(#QC;VYF:6=H96%D
M97(^1F]R='5N92!#;VYF:6=U<F%T:6]N/"]C;VYF:6=H96%D97(^"B`@/&-O
M;F9I9W-E8W1I;VX@;F%M93TB9F]R='5N92(^"B`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB97AE8U]P871H(B!R97%U:7)E9#TB9F%L<V4B(&1E<V,](E!A=&@@
M=&\@9F]R='5N90H@("!E>&5C=71A8FQE+"!E+F<N("]U<W(O9V%M97,O9F]R
M='5N92(O/@H@(#PO8V]N9FEG<V5C=&EO;CX*"B`@/&-O;F9I9VAE861E<CY!
M8V-O=6YT($EN9F\@0V]N9FEG=7)A=&EO;CPO8V]N9FEG:&5A9&5R/@H@(#QC
M;VYF:6=S96-T:6]N(&YA;64](F%C8V]U;G1S(CX*("`@/&-O;F9I9W-W:71C
M:"!N86UE/2)D<FEV97(B(&1E<V,](E=H870@(&1R:79E<B!S:&]U;&0@=V4@
M=7-E/R(^;G5L;`H@("`@/&-A<V4@;F%M93TB;G5L;"(@9&5S8STB;G5L;"(O
M/@H@("`@/&-A<V4@;F%M93TB;&]C86QH;W-T(B!D97-C/2)L;V-A;&AO<W0B
M/@H@("`@(#QC;VYF:6=S96-T:6]N(&YA;64](G!A<F%M<R(^"B`@("`@(#QC
M;VYF:6=S=')I;F<@;F%M93TB<75O=&%?<&%T:"(@9&5S8STB4&%T:"!T;R!T
M:&4@<75O=&$@<')O9W)A;2(^+W5S<B]B:6XO<75O=&$\+V-O;F9I9W-T<FEN
M9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)G<F5P7W!A=&@B(&1E<V,]
M(E!A=&@@=&\@=&AE(&=R97`@<')O9W)A;2(^+V)I;B]G<F5P/"]C;VYF:6=S
M=')I;F<^"B`@("`@(#QC;VYF:6=B;V]L96%N(&YA;64](G1R86YS;&%T94UO
M=6YT4&]I;G0B(&1E<V,](E-H;W5L9"!W92!T<F%N<VQA=&4@:&]M92!D:7)E
M8W1O<FEE<R!T;R!M;W5N="!P;VEN="!D979I8V4@;F%M97,_(CYF86QS93PO
M8V]N9FEG8F]O;&5A;CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)T<F%N
M<VQA=&EO;E1A8FQE(B!D97-C/2)&:6QE('1O('1R86YS;&%T92!D:7)E8W1O
M<GD@;F%M97,@=&\@;6]U;G0@<&]I;G0@9&5V:6-E(&YA;65S/R(^+V5T8R]M
M=&%B/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@
M/"]C87-E/@H@("`@/&-A<V4@;F%M93TB;&1A<"(@9&5S8STB3$1!4"(^"B`@
M("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB<&%R86US(CX*("`@("`@/&-O;F9I
M9W-T<FEN9R!N86UE/2)H;W-T(B!D97-C/2),1$%0('-E<G9E<B]H;W-T(CYL
M;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9VEN=&5G97(@
M;F%M93TB<&]R="(@<F5Q=6ER960](F9A;'-E(B!D97-C/2)0;W)T($Q$05`@
M:7,@<G5N;FEN9R!O;BP@:68@;F]N+7-T86YD87)D(CXS.#D\+V-O;F9I9VEN
M=&5G97(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8F%S961N(B!D97-C
M/2)B87-E9&X@<W1R:6YG(CYO/65X86UP;&4N8V]M+&,]55,\+V-O;F9I9W-T
M<FEN9SX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)A='1R(B!D97-C/2),
M1$%0(&%T=')I8G5T92!T;R!S96%R8V@@;VXB/G5I9#PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG96YU;2!N86UE/2)V97)S:6]N(B!D97-C/2),1$%0
M(%!R;W1O8V]L(%9E<G-I;VXB/C,*("`@("`@(#QV86QU97,^"B`@("`@("`@
M/'9A;'5E(&1E<V,](DQ$05!V,B`H1&5P<F5C871E9"DB/C(\+W9A;'5E/@H@
M("`@("`@(#QV86QU92!D97-C/2),1$%0=C,B/C,\+W9A;'5E/@H@("`@("`@
M/"]V86QU97,^"B`@("`@(#PO8V]N9FEG96YU;3X*("`@("`\+V-O;F9I9W-E
M8W1I;VX^"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N
M9FEG<V5C=&EO;CX*(#PO8V]N9FEG=&%B/@H@/&-O;F9I9W1A8B!N86UE/2)I
M;7-P(B!D97-C/2))35-0('-E<G9E<B!S971T:6YG<R(^"B`@/&-O;F9I9W-E
M8W1I;VX@;F%M93TB:6US<"(^"B`@(#QC;VYF:6=D97-C<FEP=&EO;CX*("`@
M"4EF('EO=2!P;&%N('1O('5S92!A;GD@;V8@2&]R9&4G<R!)35-0('-E<G9E
M<B!S=7!P;W)T+"!E;F%B;&4@=&AI<R!O<'1I;VX@86YD"B`@(`EC;VYF:6=U
M<F4@=&AE('-E<G9E<B!S971T:6YG<R!B96QO=RX@($YO=&4@=&AA="!Y;W4@
M;75S="!S=&EL;"!C;VYF:6=U<F4O96YA8FQE"B`@(`ES<&5C:69I8R!)35-0
M('-U<'!O<G0@:6X@=&AE(&%P<')O<')I871E('-E8W1I;VXN"B`@(#PO8V]N
M9FEG9&5S8W)I<'1I;VX^"B`@(#QC;VYF:6=S=VET8V@@;F%M93TB96YA8FQE
M9"(^9F%L<V4*("`@(#QC87-E(&YA;64](F9A;'-E(B!D97-C/2)$:7-A8FQE
M9"(@+SX*("`@(#QC87-E(&YA;64](G1R=64B(&1E<V,](D5N86)L960B/@H@
M("`@(#QC;VYF:6=H96%D97(^24U34"!397)V97(@4V5T=&EN9W,\+V-O;F9I
M9VAE861E<CX*("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G-E<G9E<B(@9&5S
M8STB4V5R=F5R($%D9')E<W,Z(CYL;V-A;&AO<W0\+V-O;F9I9W-T<FEN9SX*
M("`@("`\8V]N9FEG<W1R:6YG(&YA;64](G!O<G0B(&1E<V,](E-E<G9E<B!P
M;W)T.B(^-#`V/"]C;VYF:6=S=')I;F<^"B`@("`@/&-O;F9I9W-W:71C:"!N
M86UE/2)A=71H7VUE=&AO9"(@9&5S8STB5&AE(&%U=&AE;G1I8V%T:6]N(&UE
M=&AO9"!T;R!U<V4B/G!L86EN=&5X=`H@("`@("`\8V%S92!N86UE/2)P;&%I
M;G1E>'0B(&1E<V,](E!L86EN=&5X="(@+SX*("`@("`@/&-A<V4@;F%M93TB
M8W)A;5]M9#4B(&1E<V,](D-204TM340U(B`O/@H@("`@("`\8V%S92!N86UE
M/2)I;71E<W0B(&1E<V,](D-Y<G5S(&EM=&5S="(^"B`@("`@("`\8V]N9FEG
M<W1R:6YG(&YA;64](G-O8VME="(@9&5S8STB4&%T:"!T;R!T:&4@9&ER96-T
M;W)Y('1H870@=VEL;"!H;VQD('1H92!S;V-K970N"B`@("`@("`H5&AE('-O
M8VME="!W:6QL(&)E(&YA;65D("=I;7-P7W5S97)N86UE+G-C:R<I+B(^+W1M
M<"\\+V-O;F9I9W-T<FEN9SX*("`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB
M8V]M;6%N9"(@9&5S8STB4&%T:"!T;R!I;71E<W0@8FEN87)Y(CXO8WER=7,O
M=7-R+V-Y<G5S+V)I;B]I;71E<W0\+V-O;F9I9W-T<FEN9SX*("`@("`@(#QC
M;VYF:6=E;G5M(&YA;64](F%U=&A?;65C:&%N:7-M(B!D97-C<FEP=&EO;CTB
M5VAA="!A=71H96YT:6-A=&EO;B!M971H;V0@9&\@>6]U('=A;G0*("`@("`@
M('1O('5S92!W:71H('1H92!I;71E<W0@=71I;&ET>3\B/@H@("`@("`@(#QV
M86QU97,^"B`@("`@("`@(#QV86QU92!D97-C/2)0;&%I;G1E>'0@*$Q/1TE.
M*2(^3$]'24X\+W9A;'5E/@H@("`@("`@("`\=F%L=64@9&5S8STB1U-305!)
M(CYG<W-A<&D\+W9A;'5E/@H@("`@("`@(#PO=F%L=65S/@H@("`@("`@/"]C
M;VYF:6=E;G5M/@H@("`@("`\+V-A<V4^"B`@("`@/"]C;VYF:6=S=VET8V@^
M"B`@("`\+V-A<V4^"B`@(#PO8V]N9FEG<W=I=&-H/@H@(#PO8V]N9FEG<V5C
M=&EO;CX*(#PO8V]N9FEG=&%B/@H*(#QC;VYF:6=T86(@;F%M93TB:V]L86(B
M(&1E<V,](DMO;&%B($=R;W5P=V%R92!397)V97(B/@H@(#QC;VYF:6=S96-T
M:6]N(&YA;64](FMO;&%B(CX*("`@/&-O;F9I9V1E<V-R:7!T:6]N/@H@("`@
M)FQT.W-T<F]N9R9G=#LJ*BH@248@64]5($A!5D4@3D\@241%02!72$%4($M/
M3$%"($E3(%1(14X@64]5($-!3B!3049%3%D*("`@($E'3D]212!42$E3(%1!
M0B`J*BHF;'0[+W-T<F]N9R9G=#LF;'0[8G(@+R9G=#L*("`@($MO;&%B(&ES
M(&EN(&YO('=A>2!R97%U:7)E9"!F;W(@;F]R;6%L($AO<F1E('5S86=E+B!)
M9BP@:&]W979E<BP@>6]U"B`@("!I;G1E;F0@=&\@=7-E($AO<F1E(&%S(&$@
M=V5B8VQI96YT(&9O<B!+;VQA8B!T:&5N('EO=2!W:6QL(&YE960@=&\@96YS
M=7)E"B`@("!T:&%T('1H92!F;VQL;W=I;F<@9FEE;&1S(&-O<G)E<W!O;F0@
M=&\@=&AO<V4@<F5Q=6ER960@8GD@>6]U<B!+;VQA8@H@("`@:6YS=&%L;&%T
M:6]N+B`@66]U(&-A;B!F:6YD('-O;64@;V8@=&AE(')E<75I<F5D('9A;'5E
M<R!I;B!T:&4*("`@("9L=#MC;V1E)F=T.R`D2T],04)?4D]/5"]E=&,O:V]L
M86(O:V]L86(N8V]N9B9L=#LO8V]D929G=#L@8V]N9FEG=7)A=&EO;@H@("`@
M9FEL92X@4&QE87-E(&YO=&4@=&AA="!T:&4@;VQD(&E#86PO=D-A<F0@<W1O
M<F%G92!F;W)M870@:&%S(&)E96X@9')O<'!E9`H@("`@:6X@9F%V;W5R(&]F
M('1H92!N97<@6$U,('-T;W)A9V4@9F]R;6%T("9A;7`[86UP.R!)34%0(&9O
M;&1E<B!A;FYO=&%T:6]N<SL*("`@('-U8G-E<75E;G1L>2!T:&4@2&]R9&4@
M2V]L86(@;6]D=6QE<R!W:6QL(&]N;'D@=V]R:R!W:71H('9E<G-I;VX@,B!O
M9B!T:&4*("`@($MO;&%B('-E<G9E<BXF;'0[8G(@+R9G=#L*("`@($EF('EO
M=2!W;W5L9"!L:6ME('1O(&9I;F0@;W5T(&UO<F4@86)O=70@2V]L86(@=&AE
M;B!P;&5A<V4@=FES:70@=&AE($MO;&%B"B`@("!C;VUM=6YI='D@=V5B<VET
M92!A="!H='1P.B\O=W=W+FMO;&%B+F]R9R\*("`@/"]C;VYF:6=D97-C<FEP
M=&EO;CX*("`@/&-O;F9I9W-W:71C:"!N86UE/2)E;F%B;&5D(B!Q=6]T93TB
M9F%L<V4B(&1E<V,](DAO<F1E+TMO;&%B(&EN=&5G<F%T:6]N"B`@("!S=&%T
M=7,B/F9A;'-E"B`@("`\8V%S92!N86UE/2)F86QS92(@9&5S8STB1&ES86)L
M960B("\^"B`@("`\8V%S92!N86UE/2)T<G5E(B!D97-C/2)%;F%B;&5D(CX*
M("`@("`\8V]N9FEG:&5A9&5R/DMO;&%B($Q$05`@4V5R=F5R(%-E='1I;F=S
M/"]C;VYF:6=H96%D97(^"B`@("`@/&-O;F9I9W-E8W1I;VX@;F%M93TB;&1A
M<"(^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB<V5R=F5R(B!D97-C/2)3
M97)V97(*("`@("`@861D<F5S<SHB/FQO8V%L:&]S=#PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T(B!D97-C/2)397)V
M97(@<&]R=#HB/C,X.3PO8V]N9FEG:6YT96=E<CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)B87-E9&XB(&1E<V,](D)A<V4@1$XZ(CYD8SUE>&%M<&QE
M+`H@("`@("!D8SUC;VT\+V-O;F9I9W-T<FEN9SX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)B:6YD9&XB(&1E<V,](D)I;F0@1$XZ(CYC;CUM86YA9V5R
M+"!C;CUI;G1E<FYA;"P*("`@("`@9&,]97AA;7!L92P@9&,]8V]M/"]C;VYF
M:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@;F%M93TB8FEN9'!W(B!D
M97-C/2)":6YD(%!A<W-W;W)D.B(^<&%S<W=O<F0\+V-O;F9I9W-T<FEN9SX*
M("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)P:'!D;B(@9&5S8STB4V5A<F-H
M($1..B(^8VX];F]B;V1Y+"!C;CUI;G1E<FYA;"P*("`@("`@9&,]97AA;7!L
M92P@9&,]8V]M/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF:6=S=')I;F<@
M;F%M93TB<&AP<'<B(&1E<V,](E-E87)C:`H@("`@("!087-S=V]R9#HB/G!A
M<W-W;W)D/"]C;VYF:6=S=')I;F<^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@
M("`@(#QC;VYF:6=H96%D97(^2V]L86(@0WER=7,@24U!4"!397)V97(@4V5T
M=&EN9W,\+V-O;F9I9VAE861E<CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE
M/2)I;6%P(CX*("`@("`@/&-O;F9I9W-T<FEN9R!N86UE/2)S97)V97(B(&1E
M<V,](E-E<G9E<@H@("`@("!A9&1R97-S.B(^;6%I;"YE>&%M<&QE+F-O;3PO
M8V]N9FEG<W1R:6YG/@H@("`@("`\8V]N9FEG:6YT96=E<B!N86UE/2)P;W)T
M(B!D97-C/2)397)V97(@<&]R=#HB/C$T,SPO8V]N9FEG:6YT96=E<CX*("`@
M("`@/&-O;F9I9VEN=&5G97(@;F%M93TB<VEE=F5P;W)T(B!D97-C/2)3:65V
M92!P;W)T.B(^,C`P,#PO8V]N9FEG:6YT96=E<CX*("`@("`@/&-O;F9I9W-T
M<FEN9R!N86UE/2)M86EL9&]M86EN(B!D97-C/2)$969A=6QT"B`@("`@(&UA
M:6QD;VUA:6XZ(CYE>&%M<&QE+F-O;3PO8V]N9FEG<W1R:6YG/@H@("`@("`\
M8V]N9FEG<W1R:6YG(&YA;64](F%D;6EN=7-E<B(@9&5S8STB061M:6YI<W1R
M871O<@H@("`@("!U<V5R.B(^;6%N86=E<CPO8V]N9FEG<W1R:6YG/@H@("`@
M("`\8V]N9FEG<W1R:6YG(&YA;64](F%D;6EN<'<B(&1E<V,](D%D;6EN:7-T
M<F%T;W(*("`@("`@<&%S<W=O<F0Z(CYP87-S=V]R9#PO8V]N9FEG<W1R:6YG
M/@H@("`@("`\8V]N9FEG8F]O;&5A;B!N86UE/2)V:7)T9&]M86EN<R(@9&5S
M8STB5FER='5A;`H@("`@("!D;VUA:6YS.B(^=')U93PO8V]N9FEG8F]O;&5A
M;CX*("`@("`\+V-O;F9I9W-E8W1I;VX^"B`@(#QC;VYF:6=B;V]L96%N(&YA
M;64](F=R;W5P;&1A<"(@9&5S8STB268@=&AI<R!I<R!C:&5C:V5D+"!T:&4@
M9G5N8W1I;VX*("`@7VAO<F1E7VAO;VM?9W)O=7!L9&%P*"D@=VEL;"!B92!U
M<V5D('1O(&-R96%T92!A;F0@<V5T('1H92!A='1R:6)U=&5S(&YE961E9`H@
M("!T;R!A9&0O961I="]D96QE=&4@9W)O=7!S(&)Y('1H92!,1$%0($=R;W5P
M(&1R:79E<BXB/F9A;'-E/"]C;VYF:6=B;V]L96%N/@H@("`@(#QC;VYF:6=H
M96%D97(^2V]L86(@4TU44"!397)V97(@4V5T=&EN9W,\+V-O;F9I9VAE861E
M<CX*("`@("`\8V]N9FEG<V5C=&EO;B!N86UE/2)S;71P(CX*("`@("`@/&-O
M;F9I9W-T<FEN9R!N86UE/2)S97)V97(B(&1E<V,](E-E<G9E<@H@("`@("!A
M9&1R97-S.B(^;&]C86QH;W-T/"]C;VYF:6=S=')I;F<^"B`@("`@(#QC;VYF
M:6=I;G1E9V5R(&YA;64](G!O<G0B(&1E<V,](E-E<G9E<B!P;W)T.B(^,C4\
M+V-O;F9I9VEN=&5G97(^"B`@("`@/"]C;VYF:6=S96-T:6]N/@H@("`@/"]C
M87-E/@H@("`\+V-O;F9I9W-W:71C:#X*("`\+V-O;F9I9W-E8W1I;VX^"B`\
M+V-O;F9I9W1A8CX*/"]C;VYF:6=U<F%T:6]N/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+V5T8R]P<V$M:&]R9&4O:&]R9&4O+FAT
M86-C97-S````````````````````````````````````````````````````
M````````````````````````,#`P-#0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,38@,3`U,34T,S0Q-3(@,#(Q,C`P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$1E;GD@9G)O;2!A;&P*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<@``````````````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,U(#`Q-C0P-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S````
M````````````````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S4@,#$V-#`U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E<W0N<&AP````````````````````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-3(S-2`Q,#4Q-30S-#$S-2`P
M,3<R,S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&5S="YP:'`L=B`Q+C$R
M,BXV+C$W(#(P,#8O,#8O,3`@,C,Z,38Z-3$@8VAU8VL@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!"<F5N="!*+B!.;W)D<75I<W0@/&)J;D!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*+RH@4F5G:7-T97(@82!S97-S:6]N+B`J+PIS97-S:6]N7W-T87)T
M*"D["FEF("@A:7-S970H)%]315-324].6R=H;W)D95]T97-T7V-O=6YT)UTI
M*2!["B`@("`D7U-%4U-)3TY;)VAO<F1E7W1E<W1?8V]U;G0G72`](#`["GT*
M"B\J($EN8VQU9&4@2&]R9&4G<R!C;W)E+G!H<"!F:6QE+B`J+PII;F-L=61E
M7V]N8V4@)VQI8B]C;W)E+G!H<"<["@HO*B!792!S:&]U;&0@:&%V92!L;V%D
M960@=&AE(%-T<FEN9R!C;&%S<RP@9G)O;2!T:&4@2&]R9&5?571I;"!P86-K
M86=E+"!I;@H@*B!C;W)E+G!H<"X@268@4W1R:6YG.CH@:7-N)W0@9&5F:6YE
M9"P@=&AE;B!W92=R92!N;W0@9FEN9&EN9R!S;VUE(&-R:71I8V%L"B`J(&QI
M8G)A<FEE<RX@*B\*:68@*"%C;&%S<U]E>&ES=',H)U-T<FEN9R<I*2!["B`@
M("!E8VAO("<\8G(@+SX\<W!A;B!S='EL93TB8V]L;W(Z(')E9#L@9F]N="US
M:7IE.B`Q.'!X.R!F;VYT+7=E:6=H=#H@8F]L9#LB/E1H92!(;W)D95]5=&EL
M('!A8VMA9V4@=V%S(&YO="!F;W5N9"X@268@4$A07"=S(&5R<F]R7W)E<&]R
M=&EN9R!S971T:6YG(&ES(&AI9V@@96YO=6=H+"!T:&5R92!S:&]U;&0@8F4@
M97)R;W(@;65S<V%G97,@<')I;G1E9"!A8F]V92!T:&%T(&UA>2!H96QP('EO
M=2!I;B!D96)U9V=I;F<@=&AE('!R;V)L96TN($EF('EO=2!A<F4@<VEM<&QY
M(&UI<W-I;F<@=&AE<V4@9FEL97,@04Y$(&%R92!I;G-T86QL:6YG(&$@0U93
M(&-H96-K;W5T+"!T:&5N('EO=2!N965D('1O(&=E="!T:&4@/&$@:')E9CTB
M:'1T<#HO+V-V<RYH;W)D92YO<F<O8W9S+G!H<"]F<F%M97=O<FLB/F9R86UE
M=V]R:SPO83X@;6]D=6QE(&9R;VT@/&$@:')E9CTB:'1T<#HO+VAO<F1E+F]R
M9R]S;W5R8V4O(CY(;W)D92!#5E,\+V$^+"!A;F0@:6YS=&%L;"!T:&4@<&%C
M:V%G97,@:6X@:70@=VET:"!T:&4@:6YS=&%L;"UP86-K86=E<RYP:'`@<V-R
M:7!T+CPO<W!A;CXG.PH@("`@97AI=#L*?0H*+RH@26YI=&EA;&EZ92!T:&4@
M2&]R9&5?5&5S=#HZ(&-L87-S+B`J+PII9B`H(6EN8VQU9&5?;VYC92`G;&EB
M+U1E<W0N<&AP)RD@>PH@("`@+RH@5')Y(&%N9"!P<F]V:61E(&5N;W5G:"!I
M;F9O<FUA=&EO;B!T;R!D96)U9R!T:&4@;6ES<VEN9R!F:6QE+B`J+PH@("`@
M96-H;R`G/&)R("\^/'-P86X@<W1Y;&4](F-O;&]R.B!R960[(&9O;G0M<VEZ
M93H@,3AP>#L@9F]N="UW96EG:'0Z(&)O;&0[(CY5;F%B;&4@=&\@9FEN9"!H
M;W)D92]L:6(O5&5S="YP:'`N(%EO=7(@2&]R9&4@:6YS=&%L;&%T:6]N(&UA
M>2!B92!M:7-S:6YG(&-R:71I8V%L(&9I;&5S+"!O<B!02%`@;6%Y(&YO="!H
M879E('-U9F9I8VEE;G0@<&5R;6ES<VEO;G,@=&\@:6YC;'5D92!F:6QE<RX@
M5&AE<F4@;6%Y(&)E(&5R<F]R(&UE<W-A9V5S('!R:6YT960@86)O=F4@=&AI
M<R!M97-S86=E('1H870@=VEL;"!H96QP('EO=2!I;B!D96)U9V=I;F<@=&AE
M('!R;V)L96TN/"]S<&%N/B<["B`@("!E>&ET.PI]"@HO*B!)9B!W92=V92!G
M;W1T96X@=&AI<R!F87(L('=E('-H;W5L9"!H879E(&9O=6YD(&5N;W5G:"!O
M9B!(;W)D92!T;R!R=6X*("H@=&5S=',N($-R96%T92!T:&4@=&5S=&EN9R!O
M8FIE8W0N("HO"B1H;W)D95]T97-T(#T@)FYE=R!(;W)D95]497-T*"D["@HO
M*B!(;W)D92!D969I;FET:6]N<RX@*B\*)&UO9'5L92`]("=(;W)D92<["G)E
M<75I<F5?;VYC92`G+B]L:6(O=F5R<VEO;BYP:'`G.PHD;6]D=6QE7W9E<G-I
M;VX@/2!(3U)$15]615)324]..PH*+RH@4$A0(&UO9'5L92!C87!A8FEL:71I
M97,N("HO"B1M;V1U;&5?;&ES="`](&%R<F%Y*`H@("`@)V-T>7!E)R`]/B`G
M0W1Y<&4@4W5P<&]R="<L"B`@("`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I
M;VXH*2P@)S4G*2`\(#`@/R`G9&]M>&UL)R`Z("=D;VTG*2`]/B`G1$]-(%A-
M3"!3=7!P;W)T)RP*("`@("=F='`G(#T^("=&5%`@4W5P<&]R="<L"B`@("`G
M9V0G(#T^("='1"!3=7!P;W)T)RP*("`@("=G971T97AT)R`]/B!A<G)A>2@*
M("`@("`@("`G9&5S8W)I<"<@/3X@)T=E='1E>'0@4W5P<&]R="<L"B`@("`@
M("`@)V5R<F]R)R`]/B`G2&]R9&4@=VEL;"!N;W0@<G5N('=I=&AO=70@9V5T
M=&5X="!S=7!P;W)T+B!#;VUP:6QE(%!(4"!W:71H(#QC;V1E/BTM=VET:"UG
M971T97AT/"]C;V1E/B!B969O<F4@8V]N=&EN=6EN9RXG+`H@("`@("`@("=F
M871A;"<@/3X@=')U90H@("`@*2P*("`@("=I8V]N=B<@/3X@87)R87DH"B`@
M("`@("`@)V1E<V-R:7`G(#T^("=)8V]N=B!3=7!P;W)T)RP*("`@("`@("`G
M97)R;W(G(#T^("=)9B!Y;W4@=V%N="!T;R!T86ME(&9U;&P@861V86YT86=E
M(&]F($AO<F1E7"=S(&QO8V%L:7IA=&EO;B!F96%T=7)E<R!A;F0@8VAA<F%C
M=&5R('-E="!S=7!P;W)T+"!Y;W4@=VEL;"!N965D('1H92!I8V]N=B!E>'1E
M;G-I;VXN)PH@("`@*2P*("`@("=I;6%P)R`]/B`G24U!4"!3=7!P;W)T)RP*
M("`@("=L9&%P)R`]/B`G3$1!4"!3=7!P;W)T)RP*("`@("=M8G-T<FEN9R<@
M/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-8G-T<FEN9R!3=7!P
M;W)T)RP*("`@("`@("`G97)R;W(G(#T^("=)9B!Y;W4@=V%N="!T;R!T86ME
M(&9U;&P@861V86YT86=E(&]F($AO<F1E7"=S(&QO8V%L:7IA=&EO;B!F96%T
M=7)E<R!A;F0@8VAA<F%C=&5R('-E="!S=7!P;W)T+"!Y;W4@=VEL;"!N965D
M('1H92!M8G-T<FEN9R!E>'1E;G-I;VXN)PH@("`@*2P*("`@("=M8W)Y<'0G
M(#T^(&%R<F%Y*`H@("`@("`@("=D97-C<FEP)R`]/B`G36-R>7!T(%-U<'!O
M<G0G+`H@("`@("`@("=E<G)O<B<@/3X@)TUC<GEP="!I<R!A(&=E;F5R86PM
M<'5R<&]S92!C<GEP=&]G<F%P:'D@;&EB<F%R>2!W:&EC:"!I<R!B<F]A9&5R
M(&%N9"!S:6=N:69I8V%N=&QY(&UO<F4@969F:6-I96YT("A&05-415(A*2!T
M:&%N(%!(4%PG<R!O=VX@8W)Y<'1O9W)A<&AI8R!C;V1E(&%N9"!W:6QL('!R
M;W9I9&5R(&9A<W1E<B!L;V=I;G,N)PH@("`@*2P*("`@("=F:6QE:6YF;R<@
M/3X@87)R87DH"B`@("`@("`@)V1E<V-R:7`G(#T^("=-24U%($UA9VEC(%-U
M<'!O<G0@*&9I;&5I;F9O*2<L"B`@("`@("`@)V5R<F]R)R`]/B`G5&AE(&9I
M;&5I;F9O(%!%0TP@;6]D=6QE(&]R('1H92!M:6UE7VUA9VEC(%!(4"!E>'1E
M;G-I;VX@*'-E92!B96QO=RD@=VEL;"!M;W-T(&QI:V5L>2!P<F]V:61E(&9A
M<W1E<B!-24U%($UA9VEC(&QO;VMU<',@=&AA;B!T:&4@8G5I;'0M:6X@2&]R
M9&4@4$A0(&UA9VEC(&-O9&4N(%-E92!H;W)D92]D;V-S+TE.4U1!3$P@9F]R
M(&EN9F]R;6%T:6]N(&]N(&AO=R!T;R!I;G-T86QL(%!%0TPO4$A0(&5X=&5N
M<VEO;G,N)PH@("`@*2P*("`@("=M96UC86-H92<@/3X@87)R87DH"B`@("`@
M("`@)V1E<V-R:7`G(#T^("=M96UC86-H960@4W5P<&]R="`H;65M8V%C:&4I
M)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@;65M8V%C:&4@4$5#3"!M;V1U
M;&4@:7,@;F5E9&5D(&]N;'D@:68@>6]U(&%R92!U<VEN9R!T:&4@;65M8V%C
M:&5D(%-E<W-I;VY(86YD;&5R+B!3964@:&]R9&4O9&]C<R])3E-404Q,(&9O
M<B!I;F9O<FUA=&EO;B!O;B!H;W<@=&\@:6YS=&%L;"!014-,+U!(4"!E>'1E
M;G-I;VYS+B<*("`@("DL"B`@("`G;6EM95]M86=I8R<@/3X@87)R87DH"B`@
M("`@("`@)V1E<V-R:7`G(#T^("=-24U%($UA9VEC(%-U<'!O<G0@*&UI;65?
M;6%G:6,I)RP*("`@("`@("`G97)R;W(G(#T^("=4:&4@9FEL96EN9F\@4$5#
M3"!M;V1U;&4@*'-E92!A8F]V92D@;W(@=&AE(&UI;65?;6%G:6,@4$A0(&5X
M=&5N<VEO;B!W:6QL(&UO<W0@;&EK96QY('!R;W9I9&4@9F%S=&5R($U)344@
M36%G:6,@;&]O:W5P<R!T:&%N('1H92!B=6EL="UI;B!(;W)D92!02%`@;6%G
M:6,@8V]D92X@4V5E(&AO<F1E+V1O8W,O24Y35$%,3"!F;W(@:6YF;W)M871I
M;VX@;VX@:&]W('1O(&EN<W1A;&P@4$5#3"]02%`@97AT96YS:6]N<RXG"B`@
M("`I+`H@("`@)VUY<W%L)R`]/B`G37E344P@4W5P<&]R="<L"B`@("`G;W!E
M;G-S;"<@/3X@)T]P96Y34TP@4W5P<&]R="<L"B`@("`G<&=S<6PG(#T^("=0
M;W-T9W)E4U%,(%-U<'!O<G0G+`H@("`@)W-E<W-I;VXG(#T^(&%R<F%Y*`H@
M("`@("`@("=D97-C<FEP)R`]/B`G4V5S<VEO;B!3=7!P;W)T)RP*("`@("`@
M("`G9F%T86PG(#T^('1R=64I+`H@("`@)WAM;"<@/3X@)UA-3"!3=7!P;W)T
M)RP*("`@("=Z;&EB)R`]/B!A<G)A>2@*("`@("`@("`G9&5S8W)I<"<@/3X@
M)UIL:6(@4W5P<&]R="<L"B`@("`@("`@)V5R<F]R)R`]/B`G5&AE('IL:6(@
M;6]D=6QE(&ES(&AI9VAL>2!R96-O;6UE;F1E9"!F;W(@=7-E('=I=&@@2&]R
M9&4N("!)="!A;&QO=W,@<&%G92!C;VUP<F5S<VEO;B!A;F0@:&%N9&QI;F<@
M;V8@6DE0(&%N9"!'6B!D871A+B!#;VUP:6QE(%!(4"!W:71H(#QC;V1E/BTM
M=VET:"UZ;&EB/"]C;V1E/B!T;R!A8W1I=F%T92XG+`H@("`@("`@("=F871A
M;"<@/3X@9F%L<V4*("`@("DL"BD["@H*+RH@4$A0(%-E='1I;F=S+B`J+PHD
M<V5T=&EN9U]L:7-T(#T@87)R87DH"B`@("`G;6%G:6-?<75O=&5S7W)U;G1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]/B!F86QS92P*("`@
M("`@("`G97)R;W(G(#T^("=M86=I8U]Q=6]T97-?<G5N=&EM92!M87D@8V%U
M<V4@<')O8FQE;7,@=VET:"!D871A8F%S92!I;G-E<G1S+"!E=&,N(%1U<FX@
M:70@;V9F+B<*("`@("DL"B`@("`G;65M;W)Y7VQI;6ET)R`]/B!A<G)A>2@*
M("`@("`@("`G<V5T=&EN9R<@/3X@9F%L<V4L"B`@("`@("`@)V5R<F]R)R`]
M/B`G268@4$A07"=S(&EN=&5R;F%L(&UE;6]R>2!L:6UI="!I<R!T=7)N960@
M;VX@86YD(&EF(&YO="!S970@:&EG:"!E;F]U9V@@2&]R9&4@=VEL;"!N;W0@
M8F4@86)L92!T;R!H86YD;&4@;&%R9V4@9&%T82!I=&5M<R`H92YG+B!L87)G
M92!M86EL(&%T=&%C:&UE;G1S(&EN($E-4"DN($EF('!O<W-I8FQE+"!Y;W4@
M<VAO=6QD(&1I<V%B;&4@=&AE(%!(4"!M96UO<GD@;&EM:70@8GD@<F5C;VUP
M:6QI;F<@4$A0(#QE;3YW:71H;W5T/"]E;3X@=&AE("(M+65N86)L92UM96UO
M<GDM;&EM:70B(&9L86<N($EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!T:&5N
M('EO=2!S:&]U;&0@<V5T('1H92!V86QU92!O9B!M96UO<GE?;&EM:70@:6X@
M<&AP+FEN:2!T;R!A('-U9F9I8VEE;G1L>2!H:6=H('9A;'5E("A#=7)R96YT
M('9A;'5E(&]F(&UE;6]R>5]L:6UI=#H@)R`N(&EN:5]G970H)VUE;6]R>5]L
M:6UI="<I("X@)RDN)PH@("`@*2P*("`@("=S869E7VUO9&4G(#T^(&%R<F%Y
M*`H@("`@("`@("=S971T:6YG)R`]/B!F86QS92P*("`@("`@("`G97)R;W(G
M(#T^("=)9B!S869E7VUO9&4@:7,@96YA8FQE9"P@2&]R9&4@8V%N;F]T('-E
M="!E;G9I<F]M96YT('9A<FEA8FQE<RP@=VAI8V@@;65A;G,@2&]R9&4@=VEL
M;"!B92!U;F%B;&4@=&\@=')A;G-L871E('1H92!U<V5R(&EN=&5R9F%C92!I
M;G1O(&1I9F9E<F5N="!L86YG=6%G97,N)PH@("`@*2P*("`@("=S97-S:6]N
M+G5S95]T<F%N<U]S:60G(#T^(&%R<F%Y*`H@("`@("`@("=S971T:6YG)R`]
M/B!F86QS92P*("`@("`@("`G97)R;W(G(#T^("=(;W)D92!W:6QL('=O<FL@
M=VET:"!S97-S:6]N+G5S95]T<F%N<U]S:60@='5R;F5D(&]N+"!B=70@>6]U
M(&UA>2!S964@9&]U8FQE('-E<W-I;VXM:61S(&EN('EO=7(@55),<RP@86YD
M(&EF('1H92!S97-S:6]N(&YA;64@:6X@<&AP+FEN:2!D:69F97)S(&9R;VT@
M=&AE('-E<W-I;VX@;F%M92!C;VYF:6=U<F5D(&EN($AO<F1E+"!Y;W4@;6%Y
M(&=E="!T=V\@<V5S<VEO;B!I9',@86YD('-E92!O=&AE<B!O9&0@8F5H879I
M;W(N(%1H92!54DPM<F5W<FET:6YG('1H870@=7-E7W1R86YS7W-I9"!D;V5S
M(&%L<V\@=&5N9',@=&\@8G)E86L@6$A434P@8V]M<&QI86YC92X@26X@<VAO
M<G0L('EO=2!S:&]U;&0@<F5A;&QY(&1I<V%B;&4@=&AI<RXG"B`@("`I+`H@
M("`@)W-E<W-I;VXN875T;U]S=&%R="<@/3X@87)R87DH"B`@("`@("`@)W-E
M='1I;F<G(#T^(&9A;'-E+`H@("`@("`@("=E<G)O<B<@/3X@)TAO<F1E('=O
M;EPG="!W;W)K('=I=&@@875T;VUA=&EC86QL>2!S=&%R=&5D('-E<W-I;VYS
M+"!B96-A=7-E(&ET(&5X<&QI8VET;'D@8W)E871E<R!N97<@<V5S<VEO;B!W
M:&5N(&YE8V5S<V%R>2!T;R!P<F]T96-T(&%G86EN<W0@<V5S<VEO;B!F:7AA
M=&EO;G,N)PH@("`@*0HI.PH*"B\J(%!%05(@*B\*)'!E87)?;&ES="`](&%R
M<F%Y*`H@("`@)TUA:6PG(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G
M36%I;"]21D,X,C(N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=9;W4@9&\@
M;F]T(&AA=F4@=&AE($UA:6P@<&%C:V%G92!I;G-T86QL960@;VX@>6]U<B!S
M>7-T96TN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO;G,@
M;VX@:&]W('1O(&EN<W1A;&P@=&AE('!A8VMA9V4N)PH@("`@*2P*("`@("=-
M86EL7TUI;64G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G36%I;"]M
M:6UE1&5C;V1E+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G66]U(&1O(&YO
M="!H879E('1H92!-86EL7TUI;64@<&%C:V%G92!I;G-T86QL960@;VX@>6]U
M<B!S>7-T96TN(%-E92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO
M;G,@;VX@:&]W('1O(&EN<W1A;&P@=&AE('!A8VMA9V4N)RP*("`@("`@("`G
M<F5Q=6ER960G(#T^('1R=64*("`@("DL"B`@("`G3&]G)R`]/B!A<G)A>2@*
M("`@("`@("`G<&%T:"<@/3X@)TQO9RYP:'`G+`H@("`@("`@("=E<G)O<B<@
M/3X@)TUA:V4@<W5R92!Y;W4@87)E('5S:6YG(&$@=F5R<VEO;B!O9B!014%2
M('=H:6-H(&EN8VQU9&5S('1H92!,;V<@8VQA<W-E<RP@;W(@=&AA="!Y;W4@
M:&%V92!I;G-T86QL960@=&AE($QO9R!P86-K86=E('-E<&5R871E;'DN(%-E
M92!T:&4@24Y35$%,3"!F:6QE(&9O<B!I;G-T<G5C=&EO;G,@;VX@:6YS=&%L
M;&EN9R!,;V<N)RP*("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@("`@
M("`@)V9U;F-T:6]N)R`]/B`G7V-H96-K7W!E87)?;&]G7W9E<G-I;VXG"B`@
M("`I+`H@("`@)T1")R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)T1"
M+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G66]U('=I;&P@;F5E9"!$0B!I
M9B!Y;W4@87)E('5S:6YG(%-13"!D<FEV97)S(&9O<B!P<F5F97)E;F-E<RP@
M8V]N=&%C=',@*%1U<F)A*2P@971C+B<L"B`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G7V-H96-K7W!E87)?9&)?=F5R<VEO;B<*("`@("DL"B`@("`G3F5T7U-O
M8VME="<@/3X@87)R87DH"B`@("`@("`@)W!A=&@G(#T^("=.970O4V]C:V5T
M+G!H<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G36%K92!S=7)E('EO=2!A<F4@
M=7-I;F<@82!V97)S:6]N(&]F(%!%05(@=VAI8V@@:6YC;'5D97,@=&AE($YE
M=%]3;V-K970@8VQA<W,L(&]R('1H870@>6]U(&AA=F4@:6YS=&%L;&5D('1H
M92!.971?4V]C:V5T('!A8VMA9V4@<V5P97)A=&5L>2X@4V5E('1H92!)3E-4
M04Q,(&9I;&4@9F]R(&EN<W1R=6-T:6]N<R!O;B!I;G-T86QL:6YG($YE=%]3
M;V-K970N)PH@("`@*2P*("`@("=$871E)R`]/B!A<G)A>2@*("`@("`@("`G
M<&%T:"<@/3X@)T1A=&4O0V%L8RYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@
M)TAO<F1E(')E<75I<F5S('1H92!$871E7T-A;&,@8VQA<W,@9F]R($MR;VYO
M;&ET:"!T;R!C86QC=6QA=&4@9&%T97,N)PH@("`@*2P*("`@("=!=71H7U-!
M4TPG(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G075T:"]305-,+G!H
M<"<L"B`@("`@("`@)V5R<F]R)R`]/B`G2&]R9&4@=VEL;"!W;W)K('=I=&AO
M=70@=&AE($%U=&A?4T%33"!C;&%S<RP@8G5T(&EF('EO=2!U<V4@06-C97-S
M($-O;G1R;VP@3&ES=',@:6X@24U0('EO=2!S:&]U;&0@8F4@87=A<F4@=&AA
M="!W:71H;W5T('1H:7,@8VQA<W,@<&%S<W=O<F1S('=I;&P@8F4@<V5N="!T
M;R!T:&4@24U!4"!S97)V97(@:6X@<&QA:6X@=&5X="!W:&5N(')E=')I979I
M;F<@04-,<RXG"B`@("`I+`H@("`@)TA45%!?4F5Q=65S="<@/3X@87)R87DH
M"B`@("`@("`@)W!A=&@G(#T^("=(5%10+U)E<75E<W0N<&AP)RP*("`@("`@
M("`G97)R;W(G(#T^("=087)T<R!O9B!(;W)D92`H2%1-3"!C;VUP;W-I=&EO
M;B!I;B!)35`L($IO;F%H+"!T:&4@6$U,+5)00R!C;&EE;G0O<V5R=F5R*2!U
M<V4@=&AE($A45%!?4F5Q=65S="!L:6)R87)Y('1O(')E=')I979E(%523',@
M86YD(&1O(&]T:&5R($A45%`@<F5Q=65S=',N)PH@("`@*2P*("`@("=&:6QE
M)R`]/B!A<G)A>2@*("`@("`@("`G<&%T:"<@/3X@)T9I;&4N<&AP)RP*("`@
M("`@("`G97)R;W(G(#T^("=(;W)D92!W:6QL(')E<75I<F4@=&AE($9I;&4@
M8VQA<W,@=VAE;B!I;7!O<G1I;F<@0U-6(&9I;&5S+B<*("`@("DL"B`@("`G
M3F5T7U--5%`G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G3F5T+U--
M5%`N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=-86ME('-U<F4@>6]U(&%R
M92!U<VEN9R!T:&4@3F5T7U--5%`@;6]D=6QE(&EF('EO=2!W86YT(")S;71P
M(B!T;R!W;W)K(&%S(&$@;6%I;&5R(&]P=&EO;BXG"B`@("`I+`H@("`@)U-E
M<G9I8V5S7U=E871H97(G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G
M4V5R=FEC97,O5V5A=&AE<BYP:'`G+`H@("`@("`@("=E<G)O<B<@/3X@)U-E
M<G9I8V5S7U=E871H97(@:7,@=7-E9"!B>2!T:&4@=V5A=&AE<B!A<'!L970O
M8FQO8VL@;VX@=&AE('!O<G1A;"!P86=E+B<*("`@("DL"B`@("`G0V%C:&4G
M(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G0V%C:&4N<&AP)RP*("`@
M("`@("`G97)R;W(G(#T^("=#86-H92!I<R!U<V5D(&)Y('1H92!397)V:6-E
M<U]796%T:&5R(&UO9'5L92!O;B!T:&4@=V5A=&AE<B!A<'!L970O8FQO8VL@
M;VX@=&AE('!O<G1A;"!P86=E+B<*("`@("DL"B`@("`G6$U,7U-E<FEA;&EZ
M97(G(#T^(&%R<F%Y*`H@("`@("`@("=P871H)R`]/B`G6$U,+U-E<FEA;&EZ
M97(N<&AP)RP*("`@("`@("`G97)R;W(G(#T^("=834Q?4V5R:6%L:7IE<B!I
M<R!U<V5D(&)Y('1H92!397)V:6-E<U]796%T:&5R(&UO9'5L92!O;B!T:&4@
M=V5A=&AE<B!A<'!L970O8FQO8VL@;VX@=&AE('!O<G1A;"!P86=E+B<*("`@
M("D**3L*"B\J($%D9&ET:6]N86P@8VAE8VL@9F]R(%!%05(@3&]G(&UO9'5L
M92!F;W(@:71S('9E<G-I;VXN("HO"F9U;F-T:6]N(%]C:&5C:U]P96%R7VQO
M9U]V97)S:6]N*"D*>PH@("`@:68@*"%D969I;F5D*"=014%27TQ/1U])3D9/
M)RDI('L*("`@("`@("!R971U<FX@)UEO=7(@=F5R<VEO;B!O9B!,;V<@:7,@
M;F]T(')E8V5N="!E;F]U9V@N)SL*("`@('T*?0H*+RH@061D:71I;VYA;"!C
M:&5C:R!F;W(@4$5!4B!$0B!M;V1U;&4@9F]R(&ET<R!V97)S:6]N+B`J+PIF
M=6YC=&EO;B!?8VAE8VM?<&5A<E]D8E]V97)S:6]N*"D*>PH@("`@:68@*"%D
M969I;F5D*"=$0E]03U)404))3$E465],3U=%4D-!4T4G*2D@>PH@("`@("`@
M(')E='5R;B`G66]U<B!V97)S:6]N(&]F($1"(&ES(&YO="!R96-E;G0@96YO
M=6=H+B<["B`@("!]"GT*"B\J(%1H97)E(&ES(&$@=F5R<VEO;B!O9B!T:&4@
M1FEL92YP:'`@=&AA="!W86YT<R!A(%!%05(Z.G)E9VES=&5R4VAU=&1O=VY&
M=6YC"B`J('=H:6-H(&ES('=H870@;F5W<&5A<B!T97-T<R!F;W(N("!4:&ES
M(&9U;F-T:6]N('-E96US('1O(&]N;'D@:&%V92!E>&ES=&5D"B`J(&9O<B!A
M(&QI='1L92!W:&EL92P@8G5T('1H92!014%2(&=R;W5P(&AA<VXG="!F:7AE
M9"!T:&ES('EE="P@<V\@<V]M90H@*B!P96]P;&4@9V5T(&%N(&5R<F]R(&EF
M('1H97D@:&%V92!A(&-E<G1A:6X@*')E;&5A<V4I('9E<G-I;VX@;V8@4$5!
M4BX@(%=E"B`J('1E<W0@9F]R(&ET(&AE<F4N("!)9B!I="=S(&$@<V%F92!V
M97)S:6]N+"!T97-T(&%S(&YO<FUA;"P@;W1H97)W:7-E('1R>2!A"B`J(&QE
M<W,@969F96-T:79E(&)U="!N;VXM97)R;W)I;F<@=&5S="!F;W(@1FEL93HZ
M0U-6+B`J+PII9B`H(21H;W)D95]T97-T+3YI<U)E8V5N=%!%05(H*2D@>PH@
M("`@)'!A=&@@/2!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*3L*("`@(&EF("AE
M;7!T>2@D<&%T:"DI('L*("`@("`@("`D<&%T:"`]("<N)SL*("`@('T*("`@
M("1P96%R7VQI<W1;)T9I;&5?0U-6)UU;)W!A=&@G72`]("=86%A86%@N<&AP
M)SL*("`@(&9O<F5A8V@@*&5X<&QO9&4H)SHG+"`D<&%T:"D@87,@)&1I<BD@
M>PH@("`@("`@(&EF("AS=6)S='(H)&1I<BP@+3$I("$]("<O)RD@>PH@("`@
M("`@("`@("`D9&ER("X]("<O)SL*("`@("`@("!]"B`@("`@("`@)&9I;&4Q
M(#T@)&1I<B`N("=&:6QE+T-35BYP:'`G.PH@("`@("`@("1F:6QE,B`]("1D
M:7(@+B`G1FEL92YP:'`G.PH@("`@("`@("1F:6QE,R`]("1D:7(@+B`G4$5!
M4BYP:'`G.PH@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL93$I("8F(&9I
M;&5?97AI<W1S*"1F:6QE,BD@)B8@9FEL95]E>&ES=',H)&9I;&4S*2D@>PH@
M("`@("`@("`@("`O*B!#:&%N9V4@=&AE(&9I;&5N86UE('1O('-O;65T:&EN
M9R!W92!K;F]W('=I;&P@8F4@9F]U;F0N("HO"B`@("`@("`@("`@("1P96%R
M7VQI<W1;)T9I;&5?0U-6)UU;)W!A=&@G72`]("=014%2+G!H<"<["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*?0H*+RH@4F5Q=6ER960@
M8V]N9FEG=7)A=&EO;B!F:6QE<RX@*B\*)&9I;&5?;&ES="`](&%R<F%Y*`H@
M("`@)V-O;F9I9R]C;VYF+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O;6EM
M95]D<FEV97)S+G!H<"<@/3X@;G5L;"P*("`@("=C;VYF:6<O;FQS+G!H<"<@
M/3X@;G5L;"P*("`@("=C;VYF:6<O<')E9G,N<&AP)R`]/B!N=6QL+`H@("`@
M)V-O;F9I9R]R96=I<W1R>2YP:'`G(#T^(&YU;&P**3L*"@HO*B!'970@=&AE
M('-T871U<R!O=71P=70@;F]W+B`J+PHD;6]D=6QE7V]U='!U="`]("1H;W)D
M95]T97-T+3YP:'!-;V1U;&5#:&5C:R@D;6]D=6QE7VQI<W0I.PHD<V5T=&EN
M9U]O=71P=70@/2`D:&]R9&5?=&5S="T^<&AP4V5T=&EN9T-H96-K*"1S971T
M:6YG7VQI<W0I.PHD<&5A<E]O=71P=70@/2`D:&]R9&5?=&5S="T^4$5!4DUO
M9'5L94-H96-K*"1P96%R7VQI<W0I.PHD8V]N9FEG7V]U='!U="`]("1H;W)D
M95]T97-T+3YR97%U:7)E9$9I;&5#:&5C:R@D9FEL95]L:7-T*3L*"@HO*B!(
M86YD;&4@<W!E8VEA;"!M;V1E<RX@*B\*:68@*"%E;7!T>2@D7T=%5%LG;6]D
M92==*2D@>PH@("`@)'5R;"`]("%E;7!T>2@D7T=%5%LG=7)L)UTI(#\@)%]'
M151;)W5R;"==(#H@)W1E<W0N<&AP)SL*("`@(&5C:&\@)SPA1$]#5%E012!H
M=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP(%1R86YS:71I;VYA
M;"\O14XB(")$5$0O>&AT;6PQ+71R86YS:71I;VYA;"YD=&0B/B<["B`@("!S
M=VET8V@@*"1?1T546R=M;V1E)UTI('L*("`@(&-A<V4@)V5X=&5N<VEO;G,G
M.@H@("`@("`@(')E<75I<F4@5$535%]414U03$%415,@+B`G97AT96YS:6]N
M<RYI;F,G.PH@("`@("`@(&5X:70["@H@("`@8V%S92`G<&AP:6YF;R<Z"B`@
M("`@("`@96-H;R`G/&$@:')E9CTB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'5R
M;"D@+B`G/VUO9&4]=&5S="(^)FQT.R9L=#L@0F%C:R!T;R!T97-T+G!H<#PO
M83XG.PH@("`@("`@('!H<&EN9F\H*3L*("`@("`@("!E>&ET.PH*("`@(&-A
M<V4@)V9I;&5T97-T)SH*("`@("`@("!E8VAO("<\82!H<F5F/2(G("X@:'1M
M;'-P96-I86QC:&%R<R@D=7)L*2`N("<_;6]D93UT97-T(CXF;'0[)FQT.R!"
M86-K('1O('1E<W0N<&AP/"]A/B<["B`@("`@("`@/SX*("`@("`@("`\:'1M
M;#X*("`@("`@("`\8F]D>2!B9V-O;&]R/2)W:&ET92(@=&5X=#TB8FQA8VLB
M/@H@("`@("`@(#QP/CQF;VYT(&9A8V4](DAE;'9E=&EC82P@07)I86PL('-A
M;G,M<V5R:68B('-I>F4](C(B/@H@("`@("`@(%1H97)E(&%R92!S;VUE('9E
M<G-I;VYS(&]F(%!%05(@=&AA="!W97)E(')E;&5A<V5D(&%T('1I;65S('1H
M870*("`@("`@("!D:60@;F]T(&-O;G1A:6X@82!F=6YC=&EO;B!T:&%T($9I
M;&4N<&AP(&5X<&5C=',N("!4:&ES(&1O97,@;F]T"B`@("`@("`@<V5E;2!T
M;R!H879E(&-A=7-E9"!P<F]B;&5M<R!F;W(@86YY;VYE(&5X8V5P="!W:&5N
M(')U;FYI;F<@;W5R"B`@("`@("`@=&5S="!S8W)I<'0L(&)U="!Y;W4@;F5E
M9"!T;R!B92!A=V%R92!O9B!I="X@($EF('EO=2!S964@82!F871A;`H@("`@
M("`@(&5R<F]R(&EN($9I;&4N<&AP(&QI<W1E9"!B96QO=R!T:&ES('1E>'0L
M('EO=2!H879E(&]N92!O9B!T:&4*("`@("`@("!C;VUB:6YA=&EO;G,@;V8@
M<')O8FQE;2!F:6QE<RX@($UA:V4@<W5R92!Y;W4@:&%V92!T:&4@;&%T97-T
M"B`@("`@("`@4$5!4B!A;F0@1FEL92!P86-K86=E<R!A=F%I;&%B;&4@*#QA
M(&AR968](FAT='`Z+R]P96%R+G!H<"YN970O(CX*("`@("`@("!S964@:'1T
M<#HO+W!E87(N<&AP+FYE=#PO83XI+B`@268@>6]U(&1O(&YO="!G970@=&AE
M(&5R<F]R+"!Y;W4@87)E"B`@("`@("`@:6X@9FEN92!S:&%P92X\+W`^"B`@
M("`@("`@/#]P:'`@:6YC;'5D95]O;F-E("=&:6QE+T-35BYP:'`G.PH@("`@
M("`@(&5X:70["@H@("`@8V%S92`G=6YR96=I<W1E<B<Z"B`@("`@("`@=6YS
M970H)%]315-324].6R=H;W)D95]T97-T7V-O=6YT)UTI.PH@("`@("`@(#\^
M"B`@("`@("`@/&AT;6P^"B`@("`@("`@/&)O9'D@8F=C;VQO<CTB=VAI=&4B
M('1E>'0](F)L86-K(CX*("`@("`@("`\9F]N="!F86-E/2)(96QV971I8V$L
M($%R:6%L+"!S86YS+7-E<FEF(B!S:7IE/2(R(CX*("`@("`@("!4:&4@=&5S
M="!S97-S:6]N(&AA<R!B965N('5N<F5G:7-T97)E9"X\8G(^"B`@("`@("`@
M/&$@:')E9CTB=&5S="YP:'`B/D=O(&)A8VL\+V$^('1O('1H92!T97-T+G!H
M<"!P86=E+CQB<CX*("`@("`@("`\/W!H<`H@("`@("`@(&5X:70["B`@("!]
M"GT*"G)E<75I<F4@5$535%]414U03$%415,@+B`G:&5A9&5R+FEN8R<["G)E
M<75I<F4@5$535%]414U03$%415,@+B`G=F5R<VEO;BYI;F,G.PH*/SX*"CQH
M,3Y(;W)D92!!<'!L:6-A=&EO;G,\+V@Q/@H\=6P^"CP_<&AP"@HO*B!'970@
M2&]R9&4@;6]D=6QE('9E<G-I;VX@:6YF;W)M871I;VXN("HO"B1M;V1U;&5S
M(#T@)&AO<F1E7W1E<W0M/F%P<&QI8V%T:6]N3&ES="@I.PIF;W)E86-H("@D
M;6]D=6QE<R!A<R`D87!P(#T^("1V86PI('L*("`@("1A<'`@/2!U8V9I<G-T
M*"1A<'`I.PH@("`@96-H;R`G/&QI/B<@+B`D87!P("X@)SH@)R`N("1V86PM
M/G9E<G-I;VX["B`@("!I9B`H:7-S970H)'9A;"T^=&5S="DI('L*("`@("`@
M("!E8VAO("<@*#QA(&AR968](B<@+B`D=F%L+3YT97-T("X@)R(^<G5N("<@
M+B`D87!P("X@)R!T97-T<SPO83XI)SL*("`@('T*("`@(&5C:&\@(CPO;&D^
M7&XB.PI]"@H_/@H\+W5L/@H*/#]P:'`*"B\J($1I<W!L87D@4$A0(%9E<G-I
M;VX@:6YF;W)M871I;VXN("HO"B1P:'!?:6YF;R`]("1H;W)D95]T97-T+3YG
M9710:'!697)S:6]N26YF;W)M871I;VXH*3L*<F5Q=6ER92!415-47U1%35!,
M051%4R`N("=P:'!?=F5R<VEO;BYI;F,G.PH*/SX*"CQH,3Y02%`@36]D=6QE
M($-A<&%B:6QI=&EE<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)&UO9'5L
M95]O=71P=70@/SX*/"]U;#X*"CQH,3Y-:7-C96QL86YE;W5S(%!(4"!3971T
M:6YG<SPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@)'-E='1I;F=?;W5T<'5T
M(#\^"CPO=6P^"@H\:#$^1FEL92!5<&QO861S/"]H,3X*/'5L/@H@("`@/#]P
M:'`@96-H;R`D:&]R9&5?=&5S="T^<&AP4V5T=&EN9T-H96-K*&%R<F%Y*"=F
M:6QE7W5P;&]A9',G(#T^(&%R<F%Y*"=S971T:6YG)R`]/B!T<G5E+"`G97)R
M;W(G(#T^("=F:6QE7W5P;&]A9',@;75S="!B92!E;F%B;&5D(&9O<B!S;VUE
M(&9E871U<F5S(&QI:V4@<V5N9&EN9R!E;6%I;',@=VET:"!)35`N)R`I*2D@
M/SX*/#]P:'`@:68@*"1D:7(@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I
M*3H@/SX*("`@(#QL:3YU<&QO861?=&UP7V1I<CH@/&9O;G0@8V]L;W(](CP_
M<&AP(&5C:&\@:7-?=W)I=&%B;&4H)&1I<BD@/R`G9W)E96XG(#H@)W)E9"<@
M/SXB/CQS=')O;F<^/#]P:'`@96-H;R`D9&ER(#\^/"]S=')O;F<^/"]F;VYT
M/CPO;&D^"CP_<&AP(&5N9&EF.R`_/@H@("`@/&QI/G5P;&]A9%]M87A?9FEL
M97-I>F4Z(#P_<&AP(&5C:&\@:6YI7V=E="@G=7!L;V%D7VUA>%]F:6QE<VEZ
M92<I(#\^/"]L:3X*("`@(#QL:3YP;W-T7VUA>%]S:7IE.B`\/W!H<"!E8VAO
M(&EN:5]G970H)W!O<W1?;6%X7W-I>F4G*2`_/CPO;&D^"CPO=6P^"@H\:#$^
M4F5Q=6ER960@2&]R9&4@0V]N9FEG=7)A=&EO;B!&:6QE<SPO:#$^"CQU;#X*
M("`@(#P_<&AP(&5C:&\@)&-O;F9I9U]O=71P=70@/SX*/"]U;#X*"CQH,3Y0
M2%`@4V5S<VEO;G,\+V@Q/@H\/W!H<"`D7U-%4U-)3TY;)VAO<F1E7W1E<W1?
M8V]U;G0G72LK.R`_/@H\=6P^"B`@("`\;&D^4V5S<VEO;B!C;W5N=&5R.B`\
M/W!H<"!E8VAO("1?4T534TE/3ELG:&]R9&5?=&5S=%]C;W5N="==.R`_/CPO
M;&D^"B`@("`\;&D^5&\@=6YR96=I<W1E<B!T:&4@<V5S<VEO;CH@/&$@:')E
M9CTB=&5S="YP:'`_;6]D93UU;G)E9VES=&5R(CYC;&EC:R!H97)E/"]A/CPO
M;&D^"CPO=6P^"@H\:#$^4$5!4CPO:#$^"CQU;#X*("`@(#P_<&AP(&5C:&\@
M)'!E87)?;W5T<'5T(#\^"CPO=6P^"@H\/W!H<`IR97%U:7)E(%1%4U1?5$5-
M4$Q!5$53("X@)V9O;W1E<BYI;F,G.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<VEG
M;G5P+G!H<```````````````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`T-S`W(#$P-3$U-#,T,3,U(#`Q-S4V,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]S:6=N=7`N<&AP+'8@,2XQ-RXQ,"XX(#(P,#8O
M,#$O,#$@,C$Z,C@Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R
M+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I
M;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D["G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+T%U=&@O4VEG;G5P+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O5F%R:6%B;&5S+G!H<"<["@HD875T:"`]("9!=71H.CIS:6YG;&5T;VXH
M)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*+R\@36%K92!S=7)E('-I9VYU
M<',@87)E(&5N86)L960@8F5F;W)E('!R;V-E961I;F<*:68@*"1C;VYF6R=S
M:6=N=7`G75LG86QL;W<G72`A/3T@=')U92!\?`H@("`@(21A=71H+3YH87-#
M87!A8FEL:71Y*"=A9&0G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?
M*")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I
M;VXZ("<@+B!!=71H.CIG971,;V=I;E-C<F5E;B@I*3L*("`@(&5X:70["GT*
M"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD
M<VEG;G5P(#T@)D%U=&A?4VEG;G5P.CIS:6YG;&5T;VXH*3L*)')E;F1E<F5R
M(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["@HD9F]R;7-I9VYU<"`]
M("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)TAO<F1E4VEG;G5P1F]R;2<L("1V
M87)S*3L*)&9O<FUS:6=N=7`M/G9A;&ED871E*"1V87)S*3L*"FEF("@D=F%R
M<RT^9V5T*"=F;W)M;F%M92<I("$]("=H;W)D97-I9VYU<&9O<FTG*2!["B`@
M("`O*B!.;W0@>65T('-U8FUI='1E9"X@*B\*("`@("1F;W)M<VEG;G5P+3YC
M;&5A<E9A;&ED871I;VXH*3L*?0H*:68@*"1F;W)M<VEG;G5P+3YI<U9A;&ED
M*"D@)B8@)'9A<G,M/F=E="@G9F]R;6YA;64G*2`]/2`G:&]R9&5S:6=N=7!F
M;W)M)RD@>PH@("`@)&9O<FUS:6=N=7`M/F=E=$EN9F\H)'9A<G,L("1I;F9O
M*3L*"B`@("!I9B`H(21C;VYF6R=S:6=N=7`G75LG87!P<F]V92==*2!["B`@
M("`@("`@+RH@57-E<B!C86X@<VEG;B!U<"!D:7)E8W1L>2P@;F\@:6YT97)V
M96YT:6]N(&YE8V5S<V%R>2X@*B\*("`@("`@("`D<W5C8V5S<R`]("1S:6=N
M=7`M/F%D9%-I9VYU<"@D:6YF;RD["B`@("`@("`@)'-U8V-E<W-?;65S<V%G
M92`]('-P<FEN=&8H7R@B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO
M=2!C86X@;&]G(&EN(&YO=RXB*2P@)&EN9F];)W5S97)?;F%M92==*3L*("`@
M('T@96QS96EF("@D8V]N9ELG<VEG;G5P)UU;)V%P<')O=F4G72D@>PH@("`@
M("`@("\J($EN<V5R="!T:&ES('5S97(@:6YT;R!A('%U975E(&9O<B!A9&UI
M;B!A<'!R;W9A;"X@*B\*("`@("`@("`D<W5C8V5S<R`]("1S:6=N=7`M/G%U
M975E4VEG;G5P*"1I;F9O*3L*("`@("`@("`D<W5C8V5S<U]M97-S86=E(#T@
M<W!R:6YT9BA?*")3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q
M=65S="!H87,@8F5E;B!A<'!R;W9E9"XB*2P@)&EN9F];)W5S97)?;F%M92==
M*3L*("`@('T*"B`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E
M;3H@)7,B*2P@)&EN9F];)W5S97)?;F%M92==+"`D<W5C8V5S<RT^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H)'-U8V-E<W-?;65S<V%G92P@)VAO<F1E
M+G-U8V-E<W,G*3L*("`@("`@("`D=7)L(#T@075T:#HZ9V5T3&]G:6Y38W)E
M96XH)R<L("1I;F9O6R=U<FPG72D["B`@("`@("`@:&5A9&5R*"=,;V-A=&EO
M;CH@)R`N("1U<FPI.PH@("`@("`@(&5X:70["B`@("!]"GT*"B1T:71L92`]
M(%\H(E5S97(@4F5G:7-T<F%T:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO
M=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PHD9F]R;7-I
M9VYU<"T^<F5N9&5R06-T:79E*"1R96YD97)E<BP@)'9A<G,L("=S:6=N=7`N
M<&AP)RP@)W!O<W0G*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O
M;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<G!C+G!H<```````````````````````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-34S(#$P-3$U-#,T,3,U(#`Q
M-S`T,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]R<&,N<&AP+'8@,2XS,"XQ
M,"XS(#(P,#8O,#$O,#$@,C$Z,C@Z,#0@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U
M92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2D[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U)00RYP:'`G.PH*+RH@3&]O:R!A="!T:&4@
M0V]N=&5N="UT>7!E(&]F('1H92!R97%U97-T+"!I9B!I="!I<R!A=F%I;&%B
M;&4L('1O('1R>0H@*B!A;F0@9&5T97)M:6YE('=H870@:VEN9"!O9B!R97%U
M97-T('1H:7,@:7,N("HO"B1I;G!U="`](&YU;&P["B1P87)A;7,@/2!N=6QL
M.PH*:68@*"%E;7!T>2@D7U-%4E9%4ELG4$%42%])3D9/)UTI('Q\"B`@("!I
M;E]A<G)A>2@D7U-%4E9%4ELG4D5154535%]-151(3T0G72P@87)R87DH)U!2
M3U!&24Y$)RDI*2!["B`@("`D<V5R=F5R5'EP92`]("=W96)D878G.PI](&5L
M<V5I9B`H:7-S970H)%]315)615);)U)%455%4U1?34542$]$)UTI("8F"B`@
M("`@("`@("`D7U-%4E9%4ELG4D5154535%]-151(3T0G72`]/2`G1T54)R`F
M)@H@("`@("`@("`@571I;#HZ9V5T1V5T*"=R97-T0V%L;"<I*2!["B`@("`D
M<V5R=F5R5'EP92`]("=R97-T)SL*?2!E;'-E:68@*"%E;7!T>2@D7U-%4E9%
M4ELG0T].5$5.5%]465!%)UTI*2!["B`@("!I9B`H<W1R<&]S*"1?4T525D52
M6R=#3TY414Y47U194$4G72P@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PK>&UL
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@)'-E<G9E<E1Y<&4@/2`G<WEN8VUL
M)SL*("`@("`@("`O*B!3>6YC;6P@9&]E<R!I=',@;W=N('-E<W-I;VX@:&%N
M9&QI;F<N("HO"B`@("`@("`@)'-E<W-I;VY?8V]N=')O;"`]("=N;VYE)SL*
M("`@('T@96QS96EF("AS=')P;W,H)%]315)615);)T-/3E1%3E1?5%E012==
M+"`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"MW8GAM;"<I("$]/2!F86QS92D@
M>PH@("`@("`@("1S97)V97)4>7!E(#T@)W-Y;F-M;%]W8GAM;"<["B`@("`@
M("`@+RH@4WEN8VUL(&1O97,@:71S(&]W;B!S97-S:6]N(&AA;F1L:6YG+B`J
M+PH@("`@("`@("1S97-S:6]N7V-O;G1R;VP@/2`G;F]N92<["B`@("!](&5L
M<V5I9B`H<W1R<&]S*"1?4T525D526R=#3TY414Y47U194$4G72P@)W1E>'0O
M>&UL)RD@(3T](&9A;'-E*2!["B`@("`@("`@)&EN<'5T(#T@2&]R9&5?4E!#
M.CIG971);G!U="@I.PH@("`@("`@("\J($-H96-K(&9O<B!33T%0(&YA;65S
M<&%C92!54DDN("HO"B`@("`@("`@:68@*'-T<G!O<R@D:6YP=70L("=H='1P
M.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]S;V%P+V5N=F5L;W!E+R<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`D<V5R=F5R5'EP92`]("=S;V%P)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<V5R=F5R5'EP92`]("=X;6QR
M<&,G.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:&5A9&5R*"=(
M5%10+S$N,"`U,#$@3F]T($EM<&QE;65N=&5D)RD["B`@("`@("`@97AI=#L*
M("`@('T*?2!E;'-E('L*("`@("1S97)V97)4>7!E(#T@)W-O87`G.PI]"@II
M9B`H)'-E<G9E<E1Y<&4@/3T@)W-O87`G("8F"B`@("`H(6ES<V5T*"1?4T52
M5D526R=215%515-47TU%5$A/1"==*2!\?`H@("`@("1?4T525D526R=215%5
M15-47TU%5$A/1"==("$]("=03U-4)RDI('L*("`@("1S97-S:6]N7V-O;G1R
M;VP@/2`G;F]N92<["B`@("!I9B`H:7-S970H)%]'151;)W=S9&PG72DI('L*
M("`@("`@("`D<&%R86US(#T@)W=S9&PG.PH@("`@?2!E;'-E('L*("`@("`@
M("`D<&%R86US(#T@)V1I<V-O)SL*("`@('T*?0H*+RH@3&]A9"!B87-E(&QI
M8G)A<FEE<RX@*B\*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B
M87-E+G!H<"<["@HO*B!,;V%D('1H92!24$,@8F%C:V5N9"!B87-E9"!O;B`D
M<V5R=F5R5'EP92X@*B\*)'-E<G9E<B`]("9(;W)D95]24$,Z.G-I;F=L971O
M;B@D<V5R=F5R5'EP92P@)'!A<F%M<RD["@HO*B!,970@=&AE(&)A8VME;F0@
M8VAE8VL@875T:&5N=&EC871I;VXN($)Y(&1E9F%U;'0L('=E(&QO;VL@9F]R
M($A45%`*("H@8F%S:6,@875T:&5N=&EC871I;VX@86=A:6YS="!(;W)D92P@
M8G5T(&)A8VME;F1S(&-A;B!O=F5R<FED92!T:&ES"B`J(&%S(&YE961E9"X@
M*B\*)'-E<G9E<BT^875T:&]R:7IE*"D["@HO*B!'970@=&AE('-E<G9E<B=S
M(')E<W!O;G-E+B!792!C86QL("1S97)V97(M/F=E=$EN<'5T*"D@=&\@86QL
M;W<*("H@8F%C:V5N9',@=&\@:&%N9&QE(&EN<'5T('!R;V-E<W-I;F<@9&EF
M9F5R96YT;'DN("HO"FEF("@D:6YP=70@/3T](&YU;&PI('L*("`@("1I;G!U
M="`]("1S97)V97(M/F=E=$EN<'5T*"D["GT*"B1O=70@/2`D<V5R=F5R+3YG
M971297-P;VYS92@D:6YP=70L("1P87)A;7,I.PH*:68@*&ES7V$H)&]U="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@:&5A9&5R*"=(5%10+S$N,"`U,#`@26YT
M97)N86P@4V5R=F5R($5R<F]R)RD["B`@("!E>&ET.PI]"@HO*B!2971U<FX@
M=&AE(')E<W!O;G-E('1O('1H92!C;&EE;G0N("HO"FAE861E<B@G0V]N=&5N
M="U4>7!E.B`G("X@)'-E<G9E<BT^9V5T4F5S<&]N<V5#;VYT96YT5'EP92@I
M*3L*:&5A9&5R*"=#;VYT96YT+6QE;F=T:#H@)R`N('-T<FQE;B@D;W5T*2D[
M"FAE861E<B@G06-C97!T+4-H87)S970Z(%541BTX)RD["F5C:&\@)&]U=#L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V=I;BYP
M:'``````````````````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,38Q,C<@,3`U,34T,S0Q,S4@,#$W,S8T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+VQO9VEN+G!H<"QV(#(N,3<U+C(N,3$@,C`P-B\P,2\Q
M-B`Q-3HU-SHU,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R
M=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RDI
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*
M<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E<75I<F5?;VYC92`G
M2&]R9&4O4V5C<F5T+G!H<"<["@HO*B!);FET:6%L:7IE('1H92!!=71H(&-R
M961E;G1I86QS(&ME>2X@*B\*4V5C<F5T.CIS971+97DH)V%U=&@G*3L*"B\J
M($=E="!A;B!!=71H(&]B:F5C="X@*B\*)&%U=&@@/2`F075T:#HZ<VEN9VQE
M=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*:68@*&ES7V$H)&%U=&@L
M("=014%27T5R<F]R)RDI('L*("`@($AO<F1E.CIF871A;"@D875T:"P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*?0H*+RH@1V5T('!A<F%M971E<G,N("HO"B1L
M;V=O=71?<F5A<V]N(#T@)&%U=&@M/F=E=$QO9V]U=%)E87-O;B@I.PHD=7)L
M7W!A<F%M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PHD:65?=F5R<VEO
M;B`](%5T:6PZ.F=E=$9O<FU$871A*"=I95]V97)S:6]N)RD["@II9B`H)&QO
M9V]U=%]R96%S;VXI('L*("`@("1L;V=I;E]S8W)E96X@/2`D875T:"T^9V5T
M3&]G:6Y38W)E96XH*3L*("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G;F]S
M:61E8F%R)RD@)B8*("`@("`@("!I<W-E="@D1TQ/0D%,4ULG;F]T:69I8V%T
M:6]N)UTI*2!["B`@("`@("`@)'5R;"`]($%U=&@Z.F%D9$QO9V]U=%!A<F%M
M971E<G,H)&QO9VEN7W-C<F5E;BD["B`@("`@("`@:68@*"1U<FQ?<&%R86TI
M('L*("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L
M+"`G=7)L)RP@)'5R;%]P87)A;2D["B`@("`@("`@?0H@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H)W=I;F1O=RYP87)E;G0N;&]C871I;VXN:')E9B`]
M(%PG)R`N("1U<FP@+B`G7"<[)RP@)VIA=F%S8W)I<'0G*3L*("`@("`@("!E
M8VAO("<\:'1M;#X\8F]D>3XG("X@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==
M+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@87)R87DH)VIA=F%S8W)I
M<'0G*2DI("X@)SPO8F]D>3X\+VAT;6P^)SL*("`@("`@("!E>&ET.PH@("`@
M?0H*("`@(&EF("A5=&EL.CIR96UO=F5087)A;65T97(H)&QO9VEN7W-C<F5E
M;BP@87)R87DH)W5R;"<L("=N;V-A8VAE)RDI("$]"B`@("`@("`@571I;#HZ
M<F5M;W9E4&%R86UE=&5R*$AO<F1E.CIS96QF57)L*&9A;'-E+"!F86QS92P@
M=')U92DL(&%R<F%Y*"=U<FPG+"`G;F]C86-H92<I*2D@>PH@("`@("`@("1U
M<FP@/2!!=71H.CIA9&1,;V=O=71087)A;65T97)S*"1L;V=I;E]S8W)E96XI
M.PH@("`@("`@(&EF("@D=7)L7W!A<F%M*2!["B`@("`@("`@("`@("1U<FP@
M/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W5R;"<L("1U<FQ?<&%R86TI
M.PH@("`@("`@('T*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R
M;"D["B`@("`@("`@97AI=#L*("`@('T*"B`@("`D;&%N9W5A9V4@/2!I<W-E
M="@D<')E9G,I(#\@)'!R969S+3YG971686QU92@G;&%N9W5A9V4G*2`Z($Y,
M4SHZ<V5L96-T*"D["@H@("`@)&5N=')Y(#T@<W!R:6YT9B@G57-E<B`E<R!;
M)7-=(&QO9V=E9"!O=70@;V8@2&]R9&4G+`H@("`@("`@("`@("`@("`@("`@
M("!!=71H.CIG971!=71H*"DL("1?4T525D526R=214U/5$5?041$4B==*3L*
M("`@($AO<F1E.CIL;V=-97-S86=E*"1E;G1R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U].3U1)0T4I.PH@("`@075T:#HZ8VQE87)!=71H*"D[
M"B`@("!`<V5S<VEO;E]D97-T<F]Y*"D["@H@("`@+RH@4F5D:7)E8W0@=&AE
M('5S97(@;VX@;&]G;W5T(&EF(')E9&ER96-T:6]N(&ES(&5N86)L960N("HO
M"B`@("!I9B`H(65M<'1Y*"1C;VYF6R=A=71H)UU;)W)E9&ER96-T7V]N7VQO
M9V]U="==*2D@>PH@("`@("`@("1L;V=O=71?=7)L(#T@)&-O;F9;)V%U=&@G
M75LG<F5D:7)E8W1?;VY?;&]G;W5T)UT["B`@("`@("`@:68@*"%I<W-E="@D
M7T-/3TM)15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@("`@("1L;V=O
M=71?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=O=71?=7)L+"!S97-S
M:6]N7VYA;64H*2P@<V5S<VEO;E]I9"@I*3L*("`@("`@("!]"B`@("`@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1L;V=O=71?=7)L*3L*("`@("`@("!E
M>&ET.PH@("`@?0H*("`@($AO<F1E.CIS971U<%-E<W-I;VY(86YD;&5R*"D[
M"B`@("!`<V5S<VEO;E]S=&%R="@I.PH*("`@($Y,4SHZ<V5T3&%N9R@D;&%N
M9W5A9V4I.PH*("`@("\J($AO;VL@=&\@<')E<V5L96-T('1H92!C;W)R96-T
M(&QA;F=U86=E(&EN('1H92!W:61G970N("HO"B`@("`D7T=%5%LG;F5W7VQA
M;F<G72`]("1L86YG=6%G93L*?0H*:68@*&ES<V5T*"1?4$]35%LG:&]R9&5?
M=7-E<B==*2`F)B!I<W-E="@D7U!/4U1;)VAO<F1E7W!A<W,G72DI('L*("`@
M("\J($1E<W1R;WD@86YY(&5X:7-T:6YG('-E<W-I;VX@;VX@;&]G:6X@86YD
M(&UA:V4@<W5R92!T;R!U<V4@80H@("`@("H@;F5W('-E<W-I;VX@240L('1O
M(&%V;VED('-E<W-I;VX@9FEX871I;VX@:7-S=65S+B`J+PH@("`@2&]R9&4Z
M.F=E=$-L96%N4V5S<VEO;B@I.PH@("`@:68@*"1A=71H+3YA=71H96YT:6-A
M=&4H571I;#HZ9V5T4&]S="@G:&]R9&5?=7-E<B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W!A<W-W;W)D)R`]/B!5=&EL.CIG9710
M;W-T*"=H;W)D95]P87-S)RDI*2D@>PH@("`@("`@("1E;G1R>2`]('-P<FEN
M=&8H)TQO9VEN('-U8V-E<W,@9F]R("5S(%LE<UT@=&\@2&]R9&4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@075T:#HZ9V5T075T:"@I+"`D7U-%4E9%
M4ELG4D5-3U1%7T%$1%(G72D["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)&5N=')Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#12D[
M"@H@("`@("`@(&EF("@D:65?=F5R<VEO;BD@>PH@("`@("`@("`@("`D8G)O
M=W-E<BT^<V5T245697)S:6]N*"1I95]V97)S:6]N*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=7)L7W!A<F%M*2!["B`@("`@("`@("`@("1U<FP@/2!(
M;W)D93HZ=7)L*%5T:6PZ.G)E;6]V95!A<F%M971E<B@D=7)L7W!A<F%M+"!S
M97-S:6]N7VYA;64H*2DL('1R=64I.PH@("`@("`@("`@("`D:&]R9&5?=7)L
M(#T@)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O:6YD
M97@N<&AP)SL*("`@("`@("`@("`@)&AO<F1E7W5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D:&]R9&5?=7)L+"`G=7)L)RP@)'5R;"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&AO<F1E7W5R;"`]($AO<F1E.CIU<FPH)')E
M9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O:6YD97@N<&AP
M)RD["B`@("`@("`@?0H*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1H;W)D95]U<FPL('1R=64I.PH@("`@("`@(&EF("@D8G)O=W-E
M<BT^:7-"<F]W<V5R*"=M<VEE)RD@)B8*("`@("`@("`@("`@)&-O;F9;)W5S
M95]S<VPG72`]/2`S("8F"B`@("`@("`@("`@('-T<FQE;B@D=7)L*2`\(#$V
M,"D@>PH@("`@("`@("`@("!H96%D97(H)U)E9G)E<V@Z(#`[(%523#TG("X@
M)'5R;"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@('T*("`@("`@("!E>&ET.PH@
M("`@?2!E;'-E('L*("`@("`@("`D96YT<GD@/2!S<')I;G1F*"=&04E,140@
M3$]'24X@9F]R("5S(%LE<UT@=&\@2&]R9&4G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)VAO<F1E7W5S97(G*2P@)%]3
M15)615);)U)%34]415]!1$12)UTI.PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"1E;G1R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@(&EF("@D8V]N9ELG;65N=2==6R=A;'=A>7,G72D@>PH@("`@
M("`@("`@("`D;6%I;E]P86=E(#T@571I;#HZ861D4&%R86UE=&5R*$AO<F1E
M.CIS96QF57)L*"DL("=R96%S;VXG+"`D875T:"T^9V5T3&]G;W5T4F5A<V]N
M4W1R:6YG*"DI.PH@("`@("`@("`@("!I9B`H)&)R;W=S97(M/FAA<U%U:7)K
M*"=S8W)O;&QB87)?:6Y?=V%Y)RDI('L*("`@("`@("`@("`@("`@("1S8W)O
M;&QB87(@/2`G>65S)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1S8W)O;&QB87(@/2`G875T;R<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VEN9&5X+V9R
M86UE<U]I;F1E>"YI;F,G.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*
M("`@('T*?0H*:68@*$%U=&@Z.F=E=$%U=&@H*2D@>PH@("`@:68@*"1B<F]W
M<V5R+3YI<TUO8FEL92@I*2!["B`@("`@("`@)'5R;"`]("=S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<"<["B`@("!](&5L<V4@>PH@("`@("`@("1U<FP@
M/2`G<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<"<["B`@("!]"B`@("!R97%U
M:7)E($A/4D1%7T)!4T4@+B`G+R<@+B`D=7)L.PH@("`@97AI=#L*?0H*+RH@
M5')Y('1R86YS<&%R96YT(&%U=&AE;G1I8V%T:6]N+B`J+PII9B`H075T:#HZ
M:7-!=71H96YT:6-A=&5D*"DI('L*("`@(')E<75I<F4@2$]21$5?0D%312`N
M("<O:6YD97@N<&AP)SL*("`@(&5X:70["GT*"B\J(%)E9&ER96-T('1H92!U
M<V5R(&EF(&%N(&%L=&5R;F%T92!L;V=I;B!P86=E(&AA<R!B965N('-P96-I
M9FEE9"X@*B\*:68@*"%E;7!T>2@D8V]N9ELG875T:"==6R=A;'1E<FYA=&5?
M;&]G:6XG72DI('L*("`@("1U<FP@/2!!=71H.CIA9&1,;V=O=71087)A;65T
M97)S*"1C;VYF6R=A=71H)UU;)V%L=&5R;F%T95]L;V=I;B==*3L*("`@(&EF
M("@A:7-S970H)%]#3T]+245;<V5S<VEO;E]N86UE*"E=*2D@>PH@("`@("`@
M("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@<V5S<VEO;E]N86UE
M*"DL('-E<W-I;VY?:60H*2P@9F%L<V4I.PH@("`@?0H@("`@:68@*"1U<FQ?
M<&%R86TI('L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U
M<FPL("=U<FPG+"`D=7)L7W!A<F%M+"!F86QS92D["B`@("!]"B`@("!H96%D
M97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("!E>&ET.PI]"@HD;&]G:6Y?
M<V-R965N(#T@)&%U=&@M/E]G971,;V=I;E-C<F5E;B@I.PII9B`H571I;#HZ
M<F5M;W9E4&%R86UE=&5R*"1L;V=I;E]S8W)E96XL(&%R<F%Y*"=U<FPG+"`G
M;F]C86-H92<I*2`A/0H@("`@2&]R9&4Z.G-E;&95<FPH9F%L<V4L(&9A;'-E
M+"!T<G5E*2D@>PH@("`@:68@*"1U<FQ?<&%R86TI('L*("`@("`@("`D;&]G
M:6Y?<V-R965N(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=I;E]S8W)E96XL
M("=U<FPG+"`D=7)L7W!A<F%M+"!F86QS92D["B`@("!]"B`@("!I9B`H)&EE
M7W9E<G-I;VXI('L*("`@("`@("`D;&]G:6Y?<V-R965N(#T@571I;#HZ861D
M4&%R86UE=&5R*"1L;V=I;E]S8W)E96XL("=I95]V97)S:6]N)RP@)&EE7W9E
M<G-I;VXL(&9A;'-E*3L*("`@('T*("`@(&AE861E<B@G3&]C871I;VXZ("<@
M+B`D;&]G:6Y?<V-R965N*3L*("`@(&5X:70["GT*"FEF("@D8G)O=W-E<BT^
M:7--;V)I;&4H*2D@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-;V)I;&4N
M<&AP)SL*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]L;V=I;B]M
M;V)I;&4N:6YC)SL*("`@(&5X:70["GT*"B\J($)U:6QD('1H92`\<V5L96-T
M/B!W:61G970@8V]N=&%I;FEN9R!T:&4@879A:6QA8FQE(&QA;F=U86=E<RX@
M*B\*:68@*"$D<')E9G,M/FES3&]C:V5D*"=L86YG=6%G92<I*2!["B`@("`D
M7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UT@/2!.3%,Z.G-E;&5C="@I.PH@
M("`@)&QA;F=S(#T@)SQS96QE8W0@;F%M93TB;F5W7VQA;F<B(&]N8VAA;F=E
M/2)S96QE8W1,86YG*"DB/B<["B`@("!F;W)E86-H("@D;FQS6R=L86YG=6%G
M97,G72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`D<V5L(#T@*"1K97D@
M/3T@)%]315-324].6R=H;W)D95]L86YG=6%G92==*2`_("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@.B`G)SL*("`@("`@("`D;&%N9W,@+CT@(CQO<'1I;VX@
M=F%L=64]7"(D:V5Y7"(D<V5L/B1V86P\+V]P=&EO;CXB.PH@("`@?0H@("`@
M)&QA;F=S("X]("<\+W-E;&5C=#XG.PI]"@HD=&ET;&4@/2!?*"),;V<@:6XB
M*3L*)&YO=&EF:6-A=&EO;BT^<'5S:"@G<V5T1F]C=7,H*2<L("=J879A<V-R
M:7!T)RD["FEF("@D;&]G;W5T7W)E87-O;B`F)B`D8V]N9ELG;65N=2==6R=A
M;'=A>7,G72D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G:68@*'=I;F1O
M=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE;G4I('=I;F1O=RYP87)E;G0N9G)A
M;65S+FAO<F1E7VUE;G4N;&]C871I;VXN:')E9B`](%PG)R`N($AO<F1E.CIA
M<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP)RD@
M+B`G7"<[)RP@)VIA=F%S8W)I<'0G*3L*?0H*)')E87-O;B`]("1A=71H+3YG
M971,;V=O=71296%S;VY3=')I;F<H*3L*"B\J($%D9"!S;VUE(&IA=F%S8W)I
M<'0N("HO"DAO<F1E.CIA9&138W)I<'1&:6QE*"=E;G1E<E]K97E?=')A<"YJ
M<R<L("=H;W)D92<L('1R=64I.PH*+RH@1&\@=V4@;F5E9"!T;R!D;R!)12!V
M97)S:6]N(&1E=&5C=&EO;C\@*B\*:68@*"@D8G)O=W-E<BT^9V5T0G)O=W-E
M<B@I(#T]("=M<VEE)RD@)B8@*"1B<F]W<V5R+3YG971-86IO<B@I(#X](#4I
M*2!["B`@("`D:65?8VQI96YT8V%P<R`]('1R=64["GT*"G)E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@
M2$]21$5?5$5-4$Q!5$53("X@)R]L;V=I;B]L;V=I;BYI;F,G.PIR97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VEN9&5X
M+G!H<```````````````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-S$W-2`Q,#4Q-30S-#$S-2`P,3<S-C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O:6YD97@N<&AP+'8@,BXQ,#4N-"XX(#(P,#8O,#<O
M,CD@,38Z-#DZ,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@
M=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?
M*2D["B1H;W)D95]C;VYF:6=U<F5D(#T@*$!F:6QE7V5X:7-T<RA(3U)$15]"
M05-%("X@)R]C;VYF:6<O8V]N9BYP:'`G*2`F)@H@("`@("`@("`@("`@("`@
M("`@("!`9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O8V]N9FEG+VUI;65?
M9')I=F5R<RYP:'`G*2`F)@H@("`@("`@("`@("`@("`@("`@("!`9FEL95]E
M>&ES=',H2$]21$5?0D%312`N("<O8V]N9FEG+VYL<RYP:'`G*2`F)@H@("`@
M("`@("`@("`@("`@("`@("!`9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O
M8V]N9FEG+W!R969S+G!H<"<I("8F"B`@("`@("`@("`@("`@("`@("`@($!F
M:6QE7V5X:7-T<RA(3U)$15]"05-%("X@)R]C;VYF:6<O<F5G:7-T<GDN<&AP
M)RDI.PH*:68@*"$D:&]R9&5?8V]N9FEG=7)E9"D@>PH@("`@<F5Q=6ER92!(
M3U)$15]"05-%("X@)R]L:6(O5&5S="YP:'`G.PH@("`@2&]R9&5?5&5S=#HZ
M8V]N9FEG1FEL97--:7-S:6YG*"=(;W)D92<L($A/4D1%7T)!4T4L("=P<F5F
M<RYP:'`G+`H@("`@("`@(&%R<F%Y*"=C;VYF+G!H<"<@/3X@)U1H:7,@:7,@
M=&AE(&UA:6X@2&]R9&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN
M<R!P871H<R!A;F0@8F%S:6,@:71E;7,@=&AA="!A<'!L>2!T;R!T:&4@8V]R
M92!F<F%M97=O<FL@86YD(&%L;"!(;W)D92!A<'!L:6-A=&EO;G,N)RP*("`@
M("`@("`@("`@("`G;6EM95]D<FEV97)S+G!H<"<@/3X@)U1H:7,@9FEL92!C
M;VYT<F]L<R!T:&4@9VQO8F%L('-E="!O9B!-24U%(&1R:79E<G,@9F]R('1H
M92!(;W)D92!F<F%M97=O<FLL(&%L;&]W:6YG(&%P<&QI8V%T:6]N<R!T;R!M
M86ME('5S92!O9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T(&]R(&US=V]R
M9'9I97<@=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,(&9O<B!V:65W:6YG
M(&EN(&$@8G)O=W-E<BXG+`H@("`@("`@("`@("`@("=N;',N<&AP)R`]/B`G
M5&AI<R!F:6QE('!R;W9I9&5S(&QO8V%L:7-A=&EO;B!S=7!P;W)T(&9O<B!T
M:&4@2&]R9&4@9G)A;65W;W)K+B<L"B`@("`@("`@("`@("`@)W)E9VES=')Y
M+G!H<"<@/3X@)U1H92!R96=I<W1R>2!I<R!H;W<@2&]R9&4@87!P;&EC871I
M;VYS(&9I;F0@;W5T(&AO=R!T;R!T86QK('1O(&5A8V@@;W1H97(N(%EO=2!S
M:&]U;&0@;&ES="!A;GD@:6YS=&%L;&5D($AO<F1E(&%P<&QI8V%T:6]N<R!T
M:&%T('EO=2!H879E(&AE<F4N)RDI.PI]"@IR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"FEF("@D8G)O=W-E<BT^:7--;V)I
M;&4H*2D@>PH@("`@<F5Q=6ER92!(3U)$15]"05-%("X@)R]S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<"<["B`@("!E>&ET.PI]"@HD;6%I;E]P86=E(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PH*+R\@0G)E86L@=7`@=&AE(')E
M<75E<W1E9"!54DP@:6X@)&UA:6Y?<&%G92!A;F0@<G5N('-O;64@<V%N:71Y
M(&-H96-K<PHO+R!O;B!I="!T;R!P<F5V96YT('!H:7-H:6YG(&%N9"!84U,@
M871T86-K<RX@268@86YY(&]F('1H92!C:&5C:W,*+R\@9F%I;"P@)&UA:6Y?
M<&%G92!W:6QL(&)E('-E="!T;R!N=6QL+@II9B`H(65M<'1Y*"1M86EN7W!A
M9V4I*2!["B`@("`O+R!-=71E(&5R<F]R<R!I;B!C87-E(&]F('5N<&%R<V5A
M8FQE(%523',*("`@("1R97$@/2!`<&%R<V5?=7)L*"1M86EN7W!A9V4I.PH*
M("`@("\O(%=E(&%S<W5M92!T:&%T(&%N>2!V86QI9"!R961I<F5C="!54DP@
M=VEL;"!B92!I;B!T:&4@<V%M90H@("`@+R\@8V]O:VEE(&1O;6%I;BX@5&AI
M<R!H96QP<R!P<F5V96YT(')O9W5E(&]F9BUS:71E($AO<F1E(&EN<W1A;&QS
M"B`@("`O+R!F<F]M(&UI;6EC:VEN9R!T:&4@<F5A;"!S97)V97(N"B`@("!I
M9B`H:7-S970H)')E<5LG:&]S="==*2D@>PH@("`@("`@("1Q8V]O:VEE9&]M
M(#T@<')E9U]Q=6]T92@D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==*3L*("`@
M("`@("!I9B`H(7!R96=?;6%T8V@H)R\G("X@)'%C;V]K:65D;VT@+B`G)"\G
M+"`D<F5Q6R=H;W-T)UTI*2!["B`@("`@("`@("`@("1M86EN7W!A9V4@/2!N
M=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!0<F]T;V-O;"!W:&ET96QI
M<W0Z($EF('1H92!54DP@:7,@9G5L;'D@<75A;&EF:65D+"!M86ME('-U<F4@
M:70*("`@("\O(&ES(&5I=&AE<B!H='1P(&]R(&AT='!S+@H@("`@)&%L;&]W
M961?<')O=&]C;VQS(#T@87)R87DH)VAT='`G+"`G:'1T<',G*3L*("`@(&EF
M("AE;7!T>2@D<F5Q6R=S8VAE;64G72D@?'P*("`@("`@("`A:6Y?87)R87DH
M)')E<5LG<V-H96UE)UTL("1A;&QO=V5D7W!R;W1O8V]L<RDI('L*("`@("`@
M("`D;6%I;E]P86=E(#T@;G5L;#L*("`@('T*?0H*:68@*"$D;6%I;E]P86=E
M*2!["B`@("`D:6YI=&EA;%]A<'`@/2`D<')E9G,M/F=E=%9A;'5E*"=I;FET
M:6%L7V%P<&QI8V%T:6]N)RD["B`@("!I9B`H(65M<'1Y*"1I;FET:6%L7V%P
M<"D@)B8@)')E9VES=')Y+3YH87-097)M:7-S:6]N*"1I;FET:6%L7V%P<"DI
M('L*("`@("`@("`D;6%I;E]P86=E(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM
M/F=E=$EN:71I86Q086=E*"1I;FET:6%L7V%P<"DL('1R=64I.PH@("`@?2!E
M;'-E:68@*&ES<V5T*"1R96=I<W1R>2T^87!P;&EC871I;VYS6R=H;W)D92==
M6R=I;FET:6%L7W!A9V4G72DI('L*("`@("`@("`D;6%I;E]P86=E(#T@2&]R
M9&4Z.F%P<&QI8V%T:6]N57)L*"1R96=I<W1R>2T^87!P;&EC871I;VYS6R=H
M;W)D92==6R=I;FET:6%L7W!A9V4G72P@=')U92D["B`@("!](&5L<V5I9B`H
M075T:#HZ9V5T075T:"@I*2!["B`@("`@("`@)&UA:6Y?<&%G92`]($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+R<L('1R=64I.PH@
M("`@?2!E;'-E('L*("`@("`@("`D;6%I;E]P86=E(#T@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=L;V=I;BYP:'`G+"!T<G5E*3L*("`@('T*?0H*:68@*"%5
M=&EL.CIG971&;W)M1&%T82@G9G)A;65S971?;&]A9&5D)RD@)B8*("`@("@D
M8V]N9ELG;65N=2==6R=A;'=A>7,G72!\?`H@("`@("A!=71H.CIG971!=71H
M*"D@)B8@)'!R969S+3YG971686QU92@G<VAO=U]S:61E8F%R)RDI*2D@>PH@
M("`@:68@*"1B<F]W<V5R+3YH87-1=6ER:R@G<V-R;VQL8F%R7VEN7W=A>2<I
M*2!["B`@("`@("`@)'-C<F]L;&)A<B`]("=Y97,G.PH@("`@?2!E;'-E('L*
M("`@("`@("`D<V-R;VQL8F%R(#T@)V%U=&\G.PH@("`@?0H@("`@<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+VEN9&5X+V9R86UE<U]I;F1E>"YI;F,G
M.PI](&5L<V4@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1M86EN7W!A
M9V4I.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+V%D;6EN````````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M-B`P,38U-#8`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,`````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,V(#`Q-C`W,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(`````````````````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$V,C(P`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L90``````````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$T,B`P,38W,3(`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30S(#`Q-C`W,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S8W)I<'1S````````````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#,@,#$W
M,30S`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S````````````````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$T-"`P,3<S,#``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S````````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30U(#`Q-S0U-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,`````````````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M-3(@,#$V-S0Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W5T:6P`````````````
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$U,B`P,38T,S$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=71I;"]I8V]N7V)R;W=S97(N<&AP````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`U-3(W(#$P-3$U-#,T,34R(#`R,3<R-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@)$AO<F1E.B!H;W)D92]U=&EL+VEC;VY?8G)O=W-E<BYP:'`L
M=B`Q+C0N,BXT(#(P,#8O,#$O,#$@,C$Z,CDZ,3<@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)T%55$A?2$%.
M1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8V]R92YP:'`G.PH*)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG
M;&5T;VXH*3L*)&%P<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&%R<F%Y*"=N
M;W1O;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RP@)VEN86-T:79E)RP@)VAI
M9&1E;B<I+"!T<G5E*3L*:W-O<G0H)&%P<',I.PH*:68@*"@D87!P(#T@8F%S
M96YA;64H571I;#HZ9V5T1F]R;41A=&$H)V%P<"<I*2D@)B8@:7-S970H)&%P
M<'-;)&%P<%TI*2!["B`@("`O+R!0<F]V:61E(&$@;F]N+7=H:71E(&)A8VMG
M<F]U;F0@9F]R(&5Y96)A;&QI;F<@=')A;G-P87)E;F-Y+@H@("`@96-H;R`G
M/&AT;6P^/&)O9'D@8F=C;VQO<CTB(V%A86%A82(^)SL*"B`@("`D=&AE;65$
M:7(@/2`D<F5G:7-T<GDM/F=E="@G=&AE;65S9G,G+"`D87!P*3L*("`@(&EF
M("@A:7-?9&ER*"1T:&5M941I<BDI('L*("`@("`@("!E>&ET*'-P<FEN=&8H
M7R@B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(I+"`D=&AE
M;65$:7(I*3L*("`@('T*"B`@("`O+R!"87-E(&=R87!H:6-S(&9O<B!N;W<L
M(&9E96P@9G)E92!T;R!A9&0@=&AE;64@<W5P<&]R="X*("`@("1B87-E9&ER
M(#T@)&1I<B`]("1T:&5M941I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`G
M9W)A<&AI8W,G.PH@("`@:68@*"%I<U]D:7(H)&1I<BDI('L*("`@("`@("!E
M>&ET*'-P<FEN=&8H7R@B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB*2P@)&1I<BDI.PH@("`@?0H*("`@(&EF("@H)'-U8F1I
M<B`](&)A<V5N86UE*%5T:6PZ.F=E=$9O<FU$871A*"=S=6)D:7(G*2DI*2![
M"B`@("`@("`@)&1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@)'-U8F1I
M<CL*("`@("`@("!I9B`H(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("!E
M>&ET*'-P<FEN=&8H7R@B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(BDL("1D:7(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@0G)E861C<G5M
M8G,N"B`@("!E8VAO($AO<F1E.CIL:6YK*"=I8V]N7V)R;W=S97(N<&AP)RD@
M+B!?*")!<'!L:6-A=&EO;B!,:7-T(BD@+B`G/"]A/CQB<B`O/B<["B`@("!I
M9B`H(65M<'1Y*"1S=6)D:7(I*2!["B`@("`@("`@96-H;R!(;W)D93HZ;&EN
M:R@G:6-O;E]B<F]W<V5R+G!H<#]A<'`])R`N("1A<'`I("X@)')E9VES=')Y
M+3YG970H)VYA;64G+"`D87!P*2`N("<\+V$^/&)R("\^)SL*("`@('T*("`@
M(&5C:&\@)SQB<B`O/B<["@H@("`@+R\@4VAO=R!I8V]N<R!F;W(@87!P+@H@
M("`@96-H;R`G/&@R/B<@+B!S<')I;G1F*%\H(DEC;VYS(&9O<B`E<R(I+"`D
M<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I*2`N("@A96UP='DH)'-U8F1I
M<BD@/R`G+R<@+B`D<W5B9&ER(#H@)R<I("X@)SPO:#(^)SL*"@H@("`@+R\@
M3&ES="!S=6)D:7)E8W1O<FEE<RX*("`@("1S=6)D:7)S(#T@9VQO8B@D9&ER
M("X@1$E214-43U)97U-%4$%2051/4B`N("<J)RP@1TQ/0E]/3DQ91$E2*3L*
M("`@(&EF("@D<W5B9&ER<R`F)B!C;W5N="@D<W5B9&ER<RDI('L*("`@("`@
M("!F;W)E86-H("@D<W5B9&ER<R!A<R`D<W5B9&ER*2!["B`@("`@("`@("`@
M(&EF("AB87-E;F%M92@D<W5B9&ER*2`]/2`G0U93)RD@>PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96-H
M;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)VEC;VY?8G)O=W-E
M<BYP:'`G+"!A<G)A>2@G<W5B9&ER)R`]/B!B87-E;F%M92@D<W5B9&ER*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G87!P)R`]/B`D87!P*2DI
M("X@8F%S96YA;64H)'-U8F1I<BD@+B`G/"]A/CQB<B`O/B<["B`@("`@("`@
M?0H@("`@("`@(&5C:&\@)SQB<B`O/B<["B`@("!]"@H@("`@)&EM86=E<R`]
M(&=L;V(H)&1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`G*BYP;F<G*3L*
M("`@(&EF("@D:6UA9V5S("8F(&-O=6YT*"1I;6%G97,I*2!["B`@("`@("`@
M9F]R96%C:"`H)&EM86=E<R!A<R`D<&YG*2!["B`@("`@("`@("`@(&5C:&\@
M2&]R9&4Z.FEM9RAS=')?<F5P;&%C92@D8F%S961I<B`N($1)4D5#5$]265]3
M15!!4D%43U(L("<G+"`D<&YG*2P@)'!N9RP@87)R87DH)VAS<&%C92<@/3X@
M,3`L("=V<W!A8V4G(#T^(#$P*2P@)')E9VES=')Y+3YG971);6%G941I<B@D
M87!P*2D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!E8VAO(%\H
M(DYO(&EC;VYS(&9O=6YD+B(I.PH@("`@?0H*("`@(&5C:&\@)SPO8F]D>3X\
M+VAT;6P^)SL*?2!E;'-E('L*("`@("\O($QI<W0@87!P<RX*("`@(&9O<F5A
M8V@@*"1A<'!S(&%S("1A<'`I('L*("`@("`@("!E8VAO($AO<F1E.CIL:6YK
M*%5T:6PZ.F%D9%!A<F%M971E<B@G:6-O;E]B<F]W<V5R+G!H<"<L("=A<'`G
M+"`D87!P*2D@+B`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I("X@)SPO
M83X\8G(@+SXG.PH@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]U=&EL+V)A<F-O9&4N
M<&AP````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#4S-C$@,3`U,34T,S0Q-3(@,#(P-C(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W5T:6PO8F%R8V]D92YP:'`L=B`Q+C$P+C$P+C,@,C`P-B\P,2\P
M,2`R,3HR.3HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]);6%G92YP:'`G.PH*
M+R\@1V5T('1E>'0L('5P<&5R8V%S92P@861D('-T87)T+W-T;W`@8VAA<F%C
M=&5R<RX*)'1E>'0@/2!5=&EL.CIG971&;W)M1&%T82@G8F%R8V]D92<L("=T
M97-T)RD["B1T97AT(#T@4W1R:6YG.CIU<'!E<B@D=&5X="P@=')U92D["B1T
M97AT(#T@(BHD=&5X="HB.PHD=&5X=&QE;B`]('-T<FQE;B@D=&5X="D["@HD
M:&5I9VAT(#T@571I;#HZ9V5T1F]R;41A=&$H)V@G+"`T,"D["B1T:&EN=VED
M=&@@/2!5=&EL.CIG971&;W)M1&%T82@G=R<L(#(I.PHD=&AI8VMW:61T:"`]
M("1T:&EN=VED=&@@*B`S.PHD=VED=&@@/2`D=&5X=&QE;B`J("@W("H@)'1H
M:6YW:61T:"`K(#,@*B`D=&AI8VMW:61T:"D@+2`D=&AI;G=I9'1H.PH*)&-O
M9&EN9VUA<"`](&%R<F%Y*"<P)R`]/B`G,#`P,3$P,3`P)RP@)S$G(#T^("<Q
M,#`Q,#`P,#$G+`H@("`@("`@("`@("`@("`@("`@)S(G(#T^("<P,#$Q,#`P
M,#$G+"`G,R<@/3X@)S$P,3$P,#`P,"<L("<T)R`]/B`G,#`P,3$P,#`Q)RP*
M("`@("`@("`@("`@("`@("`@("<U)R`]/B`G,3`P,3$P,#`P)RP@)S8G(#T^
M("<P,#$Q,3`P,#`G+"`G-R<@/3X@)S`P,#$P,#$P,2<L"B`@("`@("`@("`@
M("`@("`@("`G."<@/3X@)S$P,#$P,#$P,"<L("<Y)R`]/B`G,#`Q,3`P,3`P
M)RP@)T$G(#T^("<Q,#`P,#$P,#$G+`H@("`@("`@("`@("`@("`@("`@)T(G
M(#T^("<P,#$P,#$P,#$G+"`G0R<@/3X@)S$P,3`P,3`P,"<L("=$)R`]/B`G
M,#`P,#$Q,#`Q)RP*("`@("`@("`@("`@("`@("`@("=%)R`]/B`G,3`P,#$Q
M,#`P)RP@)T8G(#T^("<P,#$P,3$P,#`G+"`G1R<@/3X@)S`P,#`P,3$P,2<L
M"B`@("`@("`@("`@("`@("`@("`G2"<@/3X@)S$P,#`P,3$P,"<L("=))R`]
M/B`G,#`Q,#`Q,3`P)RP@)THG(#T^("<P,#`P,3$Q,#`G+`H@("`@("`@("`@
M("`@("`@("`@)TLG(#T^("<Q,#`P,#`P,3$G+"`G3"<@/3X@)S`P,3`P,#`Q
M,2<L("=-)R`]/B`G,3`Q,#`P,#$P)RP*("`@("`@("`@("`@("`@("`@("=.
M)R`]/B`G,#`P,#$P,#$Q)RP@)T\G(#T^("<Q,#`P,3`P,3`G+"`G4"<@/3X@
M)S`P,3`Q,#`Q,"<L"B`@("`@("`@("`@("`@("`@("`G42<@/3X@)S`P,#`P
M,#$Q,2<L("=2)R`]/B`G,3`P,#`P,3$P)RP@)U,G(#T^("<P,#$P,#`Q,3`G
M+`H@("`@("`@("`@("`@("`@("`@)U0G(#T^("<P,#`P,3`Q,3`G+"`G52<@
M/3X@)S$Q,#`P,#`P,2<L("=6)R`]/B`G,#$Q,#`P,#`Q)RP*("`@("`@("`@
M("`@("`@("`@("=7)R`]/B`G,3$Q,#`P,#`P)RP@)U@G(#T^("<P,3`P,3`P
M,#$G+"`G62<@/3X@)S$Q,#`Q,#`P,"<L"B`@("`@("`@("`@("`@("`@("`G
M6B<@/3X@)S`Q,3`Q,#`P,"<L("<@)R`]/B`G,#$Q,#`P,3`P)RP@)R0G(#T^
M("<P,3`Q,#$P,#`G+`H@("`@("`@("`@("`@("`@("`@)R4G(#T^("<P,#`Q
M,#$P,3`G+"`G*B<@/3X@)S`Q,#`Q,#$P,"<L("<K)R`]/B`G,#$P,#`Q,#$P
M)RP*("`@("`@("`@("`@("`@("`@("<M)R`]/B`G,#$P,#`P,3`Q)RP@)RXG
M(#T^("<Q,3`P,#`Q,#`G+"`G+R<@/3X@)S`Q,#$P,#`Q,"<I.PH*)&EM86=E
M(#T@)DAO<F1E7TEM86=E.CIF86-T;W)Y*%5T:6PZ.F=E=$9O<FU$871A*"=T
M>7!E)RP@)W!N9R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W1E;7`G(#T^($AO<F1E.CIG971496UP1&ER*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^("1W:61T
M:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96EG
M:'0G(#T^("1H96EG:'0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8F%C:V=R;W5N9"<@/3X@)W=H:71E)RDI.PH*)'AP;W,@/2`P
M.PIF;W(@*"1I9'@@/2`P.R`D:61X(#P@)'1E>'1L96X[("1I9'@K*RD@>PH@
M("`@)&-H87(@/2!S=6)S='(H)'1E>'0L("1I9'@L(#$I.PH@("`@+R\@36%K
M92!U;FMN;W=N(&-H87)S(&$@)RTG+@H@("`@:68@*"%I<W-E="@D8V]D:6YG
M;6%P6R1C:&%R72DI('L*("`@("`@("`D8VAA<B`]("<M)SL*("`@('T*("`@
M(&9O<B`H)&)A<B`](#`[("1B87(@/#T@.#L@)&)A<BLK*2!["B`@("`@("`@
M)&5L96UE;G1W:61T:"`]("1C;V1I;F=M87!;)&-H87)=>R1B87)](#\@)'1H
M:6-K=VED=&@@.B`D=&AI;G=I9'1H.PH@("`@("`@(&EF("@H)&)A<B`K(#$I
M("4@,BD@>PH@("`@("`@("`@("`D:6UA9V4M/G)E8W1A;F=L92@D>'!O<RP@
M,"P@)&5L96UE;G1W:61T:"`M(#$L("1H96EG:'0L("=B;&%C:R<L("=B;&%C
M:R<I.PH@("`@("`@('T*("`@("`@("`D>'!O<R`K/2`D96QE;65N='=I9'1H
M.PH@("`@?0H@("`@)'AP;W,@*ST@)'1H:6YW:61T:#L*?0H*:&5A9&5R*"=0
M<F%G;6$Z('!U8FQI8R<I.PHD:6UA9V4M/F1I<W!L87DH*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W5T:6PO<F5G97A?=&5S="YP:'``````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C,Q-B`Q,#4Q-30S
M-#$U,B`P,C$S-S4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%-I;7!L92!S8W)I<'0@=&\@:&5L<"!W
M:71H(')E9V5X(&-O;G-T<G5C=&EO;B]D96)U9V=I;F<N(%!U="!I=`H@*B!S
M;VUE=VAE<F4@;VX@>6]U<B!W96)S97)V97(@86YD('!O:6YT('EO=7(@8G)O
M=W-E<B!T;R!I="X*("H*("H@0F%S960@;VXZ(&AT='`Z+R]M>69L=69F>61O
M9RYC;VTO<')O9W)A;6UI;F<O<&AP+W-C<FEP=',O<F5G97AP+G!H<`H@*@H@
M*B`D2&]R9&4Z(&AO<F1E+W5T:6PO<F5G97A?=&5S="YP:'`L=B`Q+C,N,3`N
M-"`R,#`U+S$P+S$X(#$Q.C,T.C(Q(&IA;B!%>'`@)`H@*B\*"G)E<75I<F4@
M)TAO<F1E+U5T:6PN<&AP)SL*)')E9V5X<"`](%5T:6PZ.F=E=$9O<FU$871A
M*"=R96=E>'`G*3L*)'-U8FIE8W0@/2!5=&EL.CIG971&;W)M1&%T82@G<W5B
M:F5C="<I.PHD<W5B;6ET(#T@571I;#HZ9V5T1F]R;41A=&$H)W-U8FUI="<I
M.PH*0'-E=%]T:6UE7VQI;6ET*#(I.PH*9G5N8W1I;VX@=6YH=&UL96YT:71I
M97,H)'-T<FEN9RD*>PH@("`@)'1R86YS7W1B;"`](&=E=%]H=&UL7W1R86YS
M;&%T:6]N7W1A8FQE*$A434Q?14Y4251)15,I.PH@("`@)'1R86YS7W1B;"`]
M(&%R<F%Y7V9L:7`H)'1R86YS7W1B;"D["B`@("!R971U<FX@<W1R='(H)'-T
M<FEN9RP@)'1R86YS7W1B;"D["GT*"FEF("@D<W5B;6ET(#T](")497-T(BD@
M>R`O+R!D;VEN9R!A(')E9R!E>'!R97-S:6]N('-E87)C:"`M+2!G970@=F%R
M:6%B;&5S"B`@("`D=6YE<V-A<&5D4F5G97AP(#T@=6YH=&UL96YT:71I97,H
M)')E9V5X<"D[("\O(&9O<B!S96%R8V@*("`@("1E<V-A<&5D4F5G97AP(#T@
M:'1M;&5N=&ET:65S*"1R96=E>'`I.R`O+R!F;W(@<VAO=VEN9R!O;B!P86=E
M(&%N9"!I;B!T97AT87)E80H@("`@)'1E>'0@/2`D<W5B:F5C=#L*("`@("1T
M97AT(#T@<W1R:7!S;&%S:&5S*"1T97AT*3L*("`@("1T97AT(#T@=6YH=&UL
M96YT:71I97,H)'1E>'0I.R`O+R!F;W(@<V5A<F-H"B`@("`D97-C87!E9%1E
M>'0@/2!H=&UL96YT:71I97,H)'1E>'0I.R\O(&9O<B!T97AT87)E80H*("`@
M("\O($1O('!R96=?<F5P;&%C92!O;B!S;W5R8V4L('-U8G-T:71U=&EN9R!M
M871C:&5D7W1E>'0@=VET:"!;8EUM871C:&5D7W1E>'1;+V)="B`@("`D:&EG
M:&QI9VAT961497AT(#T@<')E9U]R97!L86-E*"1U;F5S8V%P961296=E>'`L
M("=;8EU<7#!;+V)=)RP@)'1E>'0I.PH@("`@+R\@8V]N=F5R="!H=&UL96YT
M:71I97,*("`@("1H:6=H;&EG:'1E9%1E>'0@/2!H=&UL96YT:71I97,H)&AI
M9VAL:6=H=&5D5&5X="D["B`@("`O+R!R97!L86-E(%MB72!A;F0@6R]B72!W
M:71H(&AI9VAL:6=H="X*("`@("1H:6=H;&EG:'1E9%1E>'0@/2!S=')?<F5P
M;&%C92@G6V)=)RP@)SQS<&%N(&-L87-S/2)H:6=H;&EG:'0B/B<L("1H:6=H
M;&EG:'1E9%1E>'0I.PH@("`@)&AI9VAL:6=H=&5D5&5X="`]('-T<E]R97!L
M86-E*"=;+V)=)RP@)SPO<W!A;CXG+"`D:&EG:&QI9VAT961497AT*3L*?0H_
M/@H\:'1M;#X*/&AE860^"CQT:71L93Y497-T(')E9W5L87(@97AP<F5S<VEO
M;G,\+W1I=&QE/@H\<W1Y;&4@='EP93TB=&5X="]C<W,B/@H\(2TM"F@Q('L*
M("`@(&9O;G0M<VEZ93H@;&%R9V4["GT*+F9I>&5D('L*("`@(&9O;G0M<VEZ
M93H@,3!P>#L*("`@(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4L9FEX960["B`@
M("!C;VQO<CH@(S`P,#`Y.3L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V-C
M8V,["GT*+FYO=&5S('L*("`@(&9O;G0M<VEZ93H@<VUA;&P["B`@("!C;VQO
M<CH@(S`P,#`Y.3L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V-C8V,["GT*
M+FAI9VAL:6=H="!["B`@("!C;VQO<CH@(S`P,#`V-CL*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z("-F9F9F,#`["GT*+F5M<'1Y('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-F9CDY,S,*?0HM+3X*/"]S='EL93X*/&UE=&$@:'1T<"UE<75I
M=CTB0V]N=&5N="U4>7!E(B!C;VYT96YT/2)T97AT+VAT;6P[(&-H87)S970]
M:7-O+3@X-3DM,2(^"CPO:&5A9#X*/&)O9'D@8F=C;VQO<CTB(T9&1D9&1B(^
M"CQH,3Y497-T(#QA(&AR968](FAT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO
M96XO<F5F+G!C<F4N<&AP(CY02%`@4F5G=6QA<B!%>'!R97-S:6]N($9U;F-T
M:6]N<R`H4&5R;"U#;VUP871I8FQE*3PO83X\+V@Q/@H\9&EV(&-L87-S/2)F
M:7AE9"(^<')E9U]M871C:%]A;&PH)'!A='1E<FXL("1S=6)J96-T+"`D;6%T
M8VAE<RP@4%)%1U]3151?3U)$15(I/"]D:78^"CQF;W)M(&YA;64](F9O<FTQ
M(B!M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@96-H;R`D7U-%4E9%4ELG
M4$A07U-%3$8G72`_/B(^"CQP/CQS=')O;F<^16YT97(@>6]U<B!R96=U;&%R
M(&5X<')E<W-I;VX@*"1P871T97)N*3H\+W-T<F]N9SX\8G(@+SX*/'1E>'1A
M<F5A(&YA;64](G)E9V5X<"(@8V]L<STB.#`B(')O=W,](C8B(&ED/2)R96=E
M>'`B/CP_<&AP(&EF*"1S=6)M:70I>V5C:&\@)&5S8V%P961296=E>'`[?3\^
M/"]T97AT87)E83X*/&)R("\^"CQS=')O;F<^16YT97(@=&5X="!T;R!S96%R
M8V@@86=A:6YS="!I;B!T:&4@=&5X=&%R96$@8F5L;W<@*"1S=6)J96-T*3H\
M+W-T<F]N9SX\8G(@+SX*/'1E>'1A<F5A(&YA;64](G-U8FIE8W0B(&-O;',]
M(C@P(B!R;W=S/2(S(CX\/W!H<"!I9B@D<W5B:F5C="E[96-H;R`D97-C87!E
M9%1E>'0[?3\^/"]T97AT87)E83X*/&)R("\^"CQI;G!U="!T>7!E/2)S=6)M
M:70B(&YA;64](G-U8FUI="(@=F%L=64](E1E<W0B/@H\:6YP=70@='EP93TB
M<F5S970B(&YA;64](E)E<V5T(B!V86QU93TB4F5S970B/@H\82!H<F5F/2<\
M/W!H<"!E8VAO("1?4T525D526R=02%!?4T5,1B==(#\^)SY(;VUE/"]A/CQB
M<B`O/@H\+W`^"CPO9F]R;3X*/&AR("\^"CP_<&AP"FEF("@D<W5B;6ET*2![
M("\O(&]N;'D@<VAO=W,@=7`@;VX@<F5S=6QT<R!P86=E"B`@("!I9B`H<')E
M9U]M871C:%]A;&PH)'5N97-C87!E9%)E9V5X<"P@)'1E>'0L("1R97-U;'1S
M+"!04D5'7U-%5%]/4D1%4BDI('L@+R\@9F]U;F0@;6%T8V@*("`@("`@("!E
M8VAO(")4:&4@<F5G97AP(#QS=')O;F<^("1E<V-A<&5D4F5G97AP(#PO<W1R
M;VYG/B!M871C:&5D(5QN/'`^(CL*("`@("`@("!E8VAO("(\:#$^2&5R92=S
M('=H870@=V%S(&UA=&-H960@<V5A<F-H:6YG('1H92!T97AT('EO=2!E;G1E
M<F5D.CPO:#$^7&XB.PH@("`@("`@("1Y(#T@,#L*("`@("`@("!E8VAO("<\
M9&EV(&-L87-S/2)F:7AE9"(^)SL*("`@("`@("!F;W)E86-H("@D<F5S=6QT
M<R!A<R`D;&]O<%]R97-U;'0I('L*("`@("`@("`@("`@)'@@/2`P.PH@("`@
M("`@("`@("!F;W)E86-H("@D;&]O<%]R97-U;'0@87,@)&QO;W!?<F5S=6QT
M,BD@>PH@("`@("`@("`@("`@("`@:68@*"1X("$](#`I('L*("`@("`@("`@
M("`@("`@("`@("`O*B!);F1E;G0@<W5B<&%T=&5R;G,N("HO"B`@("`@("`@
M("`@("`@("`@("`@96-H;R`B/&)L;V-K<75O=&4^(CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('!R:6YT9B@G)&UA=&-H97-;)7-=6R5S
M73HF;F)S<#LF;F)S<#LG+"`D>2P@)'@I.R\O('-H;W<@=F%R:6%B;&4@;F%M
M90H@("`@("`@("`@("`@("`@:68@*"$D;&]O<%]R97-U;'0R*2!["B`@("`@
M("`@("`@("`@("`@("`@96-H;R`G/'-P86X@8VQA<W,](F5M<'1Y(CY%;7!T
M>3PO<W!A;CXG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("!E8VAO("<\<W!A;B!C;&%S<STB:&EG:&QI9VAT(CXG("X@
M:'1M;&5N=&ET:65S*"1L;V]P7W)E<W5L=#(I("X@)SPO<W!A;CXG.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1X("$](#`I('L*
M("`@("`@("`@("`@("`@("`@("!E8VAO("(\+V)L;V-K<75O=&4^(CL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@96-H
M;R`B/'`@+SXB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'@K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D>2LK.PH@("`@("`@
M('T*("`@("`@("!E8VAO("<\+V1I=CXG.PH@("`@?2!E;'-E('L@+R\@;F\@
M;6%T8V@*("`@("`@("!E8VAO(")R96=E>'`@/'-T<F]N9SX@)&5S8V%P9612
M96=E>'`@/"]S=')O;F<^(&1O97-N)W0@<F5T=7)N(&%N>2!R97-U;'1S7&X\
M<#XB.PH@("`@?0H@("`@/SX*("`@(#QH,3Y396%R8VAE9"!T97AT('=I=&@@
M;6%T8VAE<R`\<W!A;B!C;&%S<STG:&EG:&QI9VAT)SYH:6=H;&EG:'1E9#PO
M<W!A;CX\+V@Q/@H@("`@/#]P:'`@+R\@4VAO=R!S96%R8VAE9"!T97AT('=I
M=&@@;6%T8VAE<R!H:6=H;&EG:'1E9`H@("`@96-H;R`G/'!R93XG.PH@("`@
M96-H;R`D:&EG:&QI9VAT961497AT.PH@("`@96-H;R`G/"]P<F4^/&AR("\^
M)SL*?0H_/@H*/&1I=B!C;&%S<STB;F]T97,B/@H\:#$^17AA;7!L92!R96=U
M;&%R(&5X<')E<W-I;VYS.CPO:#$^"CQP/CQS=')O;F<^>R9L=#LA+2TH/SHN
M?%QS*2H_+2TF9W0[?3PO<W1R;VYG/B9N8G-P.R`M+29N8G-P.R!3:&]W<R!C
M;VUM96YT<R!I;B!H=&UL)FYB<W`[/"]P/@H\=6P^"CQL:3X\<W1R;VYG/GL\
M+W-T<F]N9SX@;W!E;B!D96QI;6ET97(\+VQI/@H\;&D^/'-T<F]N9SXF;'0[
M(2TM/"]S=')O;F<^('-E87)C:"!F;W(@;W!E;FEN9R!C;VUM96YT('1A9SPO
M;&D^"CQL:3X\<W1R;VYG/B@_.BY\7',I*CPO<W1R;VYG/B!A;GD@;G5M8F5R
M(&]F(&-H87)A8W1E<G,@;W(@=VAI=&4@<W!A8V4\+VQI/@H\;&D^/'-T<F]N
M9SX_/"]S=')O;F<^(&YO;BUG<F5E9'D\+VQI/@H\;&D^/'-T<F]N9SXM+29G
M=#L\+W-T<F]N9SX@<V5A<F-H(&9O<B!C;&]S:6YG(&-O;6UE;G0@=&%G/"]L
M:3X*/&QI/CQS=')O;F<^?3PO<W1R;VYG/B!C;&]S92!D96QI;6ET97(\+VQI
M/@H\+W5L/@H\<#X\<W1R;VYG/GLF;'0[<W1Y;&4@='EP92@_.BY\7',I*C\F
M;'0[+W-T>6QE)F=T.WT\+W-T<F]N9SX@+2T@4VAO=W,@('-T>6QE<SPO<#X*
M/'`^3F]T97,Z/"]P/@H\=6P^"CQL:3Y4:&4@<F5S=6QT<R!P86=E('-H;W=S
M('1H92!I;F1I=FED=6%L(&UA=&-H97,@86YD('-U8G!A='1E<FX@;6%T8VAE
M<RP@86YD('1H92!O<FEG:6YA;"!T97AT('=I=&@@=&AE(&UA=&-H97,@:&EG
M:&QI9VAT960N/"]L:3X*/&QI/DUI9VAT(&YO="!B92!A8FQE('1O('-E87)C
M:"!F;W(@:'1M;"!E;G1I=&EE<R!L:6ME("(F86UP.V%M<#LB(&)E8V%U<V4@
M;V8@=&AE(&-O;G9E<G1I;F<@9F]R(&1I<W!L87D@86YD('1E>'1A<F5A<R`H
M=&AE('-E87)C:"!P871T97)N("AR96=E>'`I(&%N9"!N;VXM=7)L('-U8FIE
M8W1S(&%R92!P<F]C97-S960@8GD@=6YH=&UL96YT:71I97,I/"]L:3X*/"]U
M;#X\+V1I=CX*/"]B;V1Y/@H\+VAT;6P^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G96YN979I;&QI97)S````````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-2`P,C$V,3$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V%Z=7(`````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30U
M(#`Q-S<R-``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)E>0``````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q-#4@,#$W-S$Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R].95A49W)E>0``````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-2`P,C`T-3``(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF;&]W97(`````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,30U(#`R,3$R,P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8G)O
M=VX`````````````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#4@,#(P,#<R`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F5E;@``````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-2`P,C`P
M-#,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,30U(#`R,#`S,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O:V]L86(`````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#4@,#(P,#,S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]L879A;F1E<@``````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T
M-2`P,C`U,S<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,34Q(#`R,#4T,``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O<')I;G0`````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-3$@,#(P,#<T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT<F%S=```````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$U,2`P,C$Q-S,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)L
M=65W:&ET90``````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,34Q(#`R,#<S,``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O<VEM<&QE>```````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-3$@,#(P
M-#(Q`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]C86UO=69L86=E````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$U,2`P,C$P-#,`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VQU8P``````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,34R(#`Q-S4R-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O;'5C8FQU90``````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M-3(@,#(P,S<T`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]P;W-T;G5K
M90``````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$U,B`P,C`V,3$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V)A<F)I90``````````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,34R(#`R,#$V-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL80``````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q-3(@,#(P-#$P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B
M;'5E;6]O;@``````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$U,B`P,C`U-C$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VQI9VAT8FQU90``````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,34R(#`R
M,#<R,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]B:6QE````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q-3(@,#(P,C$P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]P=7)P;&4`````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$U,B`P,C`R-3``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V)U<FYT;W)A;F=E````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,34R(#`R,3(V-P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O<G1L+F-S
M<P``````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$S,#`@,3`U,34T,S0Q-3(@,#(P,S(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W1H96UE<R]R=&PN8W-S+'8@,2XR+C(N,2`R,#`U+S$P+S$X(#$Q.C,T.C$P
M(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@9&ER96-T:6]N.B!R=&P["B`@
M("!F;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A
M;F$L1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"@HN;&5F
M=$%L:6=N('L*("`@("`@("!T97AT+6%L:6=N.B!R:6=H=#L*("`@("`@("!F
M;VYT+69A;6EL>3H@5&%H;VUA+$MO;V1A:RQ(;VUA+$YA>FQI+%9E<F1A;F$L
M1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"BYR:6=H=$%L
M:6=N('L*("`@("`@("!T97AT+6%L:6=N.B!L969T.PH@("`@("`@(&9O;G0M
M9F%M:6QY.B!486AO;6$L2V]O9&%K+$AO;6$L3F%Z;&DL5F5R9&%N82Q'96YE
M=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*"BYL969T1FQO870@
M>PH@("`@("`@(&9L;V%T.B!R:6=H=#L*?0HN<FEG:'1&;&]A="!["B`@("`@
M("`@9FQO870Z(&QE9G0["GT*"BYH96%D97(@=6P@>PH@("`@9FQO870Z(&QE
M9G0["B`@("!T97AT+6%L:6=N.B!L969T.PI]"@HO*B!486(@<W1Y;&5S+B`J
M+PHN=&%B<V5T('L*("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B<V5T(&QI('L*
M("`@(&9L;V%T.B!R:6=H=#L*?0HN=&%B<V5T(&EM9R!["B`@("!F;&]A=#H@
M<FEG:'0["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M:64U;6%C+F-S<P``````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`U,S0@,3`U,34T,S0Q-3(@,#(P-C<W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1H96UE<R]I935M86,N8W-S+'8@,2XR+C0N,R`R,#`U+S$P+S$X
M(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R
M($E%-2]-86,N"B`J+PH*(VUE;G4@;&D@>PH@("`@=VED=&@Z(#0P<'@["GT*
M+G1A8G-E="!["B`@("!W:&ET92US<&%C93H@;F]W<F%P.PI]"BYT86)S970@
M;&D@82!["B`@("!F;&]A=#H@;&5F=#L*?0HC<VED96)A<E!A;F5L('L*("`@
M('!A9&1I;F<M8F]T=&]M.B`S,'!X.PI]"BYH96%D97(@>PH@("`@8VQE87(Z
M(&YO;F4["GT*+FAE861E<B!U;"!["B`@("!W:61T:#H@,24["B`@("!W:&ET
M92US<&%C93H@;F]W<F%P.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO>C$T+F-S<P``
M````````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,C8P(#$P-3$U-#,T,34R(#`R,#4P,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M
M97,O;6]Z,30N8W-S+'8@,2XQ+C(N,B`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA
M;B!%>'`@)`H@*@H@*B!#4U,@8V]R<F5C=&EO;G,@9F]R($UO>FEL;&$@/#T@
M,2XT+@H@*B\*"B-M96YU('L*("`@(&]V97)F;&]W.B!V:7-I8FQE.PH@("`@
M:&5I9VAT.B`U,'!X.PI]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]O<&5R82YC<W,`````````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,S-B`Q,#4Q-30S
M-#$U,B`P,C`V-#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V]P97)A+F-S
M<RQV(#$N,2XR+C0@,C`P-2\Q,"\Q."`Q,3HS-#HQ,"!J86X@17AP("0*("H*
M("H@0U-3(&-O<G)E8W1I;VYS(&9O<B!/<&5R82X*("HO"@HN=')E95)O=R![
M"B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@,C!P>#L*?0H*
M(VUE;G4@>PH@("`@;W9E<F9L;W<Z('9I<VEB;&4["B`@("!H96EG:'0Z(#4P
M<'@["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O<V%F87)I+F-S<P``````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-C4@,3`U,34T,S0Q-3(@,#(Q,#`T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]S869A<FDN8W-S+'8@,2XQ+C(N
M-B`R,#`U+S$P+S$X(#$Q.C,T.C$P(&IA;B!%>'`@)`H@*@H@*B!#4U,@8V]R
M<F5C=&EO;G,@9F]R(%-A9F%R:2X*("HO"@II;6<@>PH@("`@=F5R=&EC86PM
M86QI9VXZ(&)A<V5L:6YE.PI]"@HN=')E95)O=R!["B`@("!O=F5R9FQO=SH@
M=FES:6)L93L*("`@(&AE:6=H=#H@,C!P>#L*?0H*+G1R9652;W<@:6UG('L*
M("`@('9E<G1I8V%L+6%L:6=N.B!M:61D;&4["GT*"B-M96YU('L*("`@(&]V
M97)F;&]W.B!V:7-I8FQE.PH@("`@:&5I9VAT.B`U,'!X.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+W-C<F5E;BYC<W,`````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#(W-S0Q(#$P-3$U-#,T,34R(#`R,3`R-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O<V-R965N+F-S<RQV(#$N-RXT+C4W(#(P,#8O,#8O
M,3$@,C$Z,S0Z,C<@8VAU8VL@17AP("0*("HO"@HO*B!';&]B86P@9&5F875L
M="!S='EL97,N("HO"BH@>PH@("`@+RH@6F5R;R!O=70@86QL('!A9&1I;F<@
M86YD(&UA<F=I;G,@=&\@<W1A<G0@=VET:"!F;W(@8F5T=&5R"B`@("`@*B!C
M<F]S<RUB<F]W<V5R(&-O;G1R;VPN("HO"B`@("!P861D:6YG.B`P.PH@("`@
M;6%R9VEN.B`P.PI]"@IB;V1Y('L*("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L
M07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R
M<'@["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8V]L;W(Z(",P,#`["GT*
M"F)O9'DN<V-R;VQL8F%R+7%U:7)K('L*("`@(&UA<F=I;BUR:6=H=#H@,35P
M>#L*?0H*<"!["B`@("!M87)G:6XM8F]T=&]M.B`Q,'!X.PI]"@II;6<L("YI
M;6<L("YI;6<Z86-T:79E+"`N:6UG.FAO=F5R+"`N:6UG.G9I<VET960@>PH@
M("`@8F]R9&5R.B!N;VYE.PH@("`@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L*
M("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT.PI]"@II;G,@>PH@("`@8F%C
M:V=R;W5N9#H@(V-F8SL*?0ID96P@>PH@("`@8F%C:V=R;W5N9#H@(V9C8SL*
M?0H*8G(N<W!A8V5R('L*("`@(&9O;G0M<VEZ93H@.'!X.PI]"@HN;&5F=$%L
M:6=N('L*("`@('1E>'0M86QI9VXZ(&QE9G0["GT*+G)I9VAT06QI9VX@>PH@
M("`@=&5X="UA;&EG;CH@<FEG:'0["GT*+FQE9G1&;&]A="!["B`@("!F;&]A
M=#H@;&5F=#L*?0HN<FEG:'1&;&]A="!["B`@("!F;&]A=#H@<FEG:'0["GT*
M"BYB;W@@>PH@("`@<&%D9&EN9SH@,W!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S
M:&5D(",Y.3D["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"BYS;VQI9&)O>"![
M"B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PI]"BYG<F5Y8F]X('L*("`@
M(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!B86-K9W)O=6YD.B`C93EE
M.64Y.PI]"BYH96%D97)B;W@@>PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI
M9"`C,#`P.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PH@("`@8F%C:V=R;W5N
M9#H@(V9F9CL*?0HN<F]U;F1E9$)O>"!["B`@("`M;6]Z+6)O<F1E<BUR861I
M=7,Z(#$U<'@["GT*+G)O=6YD9614;W`@>PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S+71O<')I9VAT.B`Q-7!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O
M<&QE9G0Z(#$U<'@["GT*+G)O=6YD961";W1T;VT@>PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S+6)O='1O;7)I9VAT.B`Q-7!X.PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S+6)O='1O;6QE9G0Z(#$U<'@["GT*+FAE861E<B!["B`@("!F;VYT
M+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O
M;G0M=V5I9VAT.B!B;VQD.PH@("`@9F]N="US:7IE.B`Q-7!X.PH@("`@<&%D
M9&EN9SH@,W!X.PI]"BYH96%D97(@83IH;W9E<BP@82YH96%D97(Z:&]V97(@
M>PH@("`@8V]L;W(Z(",S,S,["GT*+FAE861E<B!I;6<@>PH@("`@=F5R=&EC
M86PM86QI9VXZ(&)O='1O;3L*?0HN:&5A9&5R('5L('L*("`@(&9L;V%T.B!R
M:6=H=#L*("`@('1E>'0M86QI9VXZ(')I9VAT.PH@("`@9F]N="US:7IE.B`Q
M,G!X.PI]"BYH96%D97(@;&D@>PH@("`@;&ES="US='EL93H@;F]N93L*("`@
M(&1I<W!L87DZ(&EN;&EN93L*?0HN;F]W<F%P('L*("`@('=H:71E+7-P86-E
M.B!N;W=R87`["GT*+F-L96%R('L*("`@(&-L96%R.B!B;W1H.PH@("`@;&EN
M92UH96EG:'0Z(#`["B`@("!H96EG:'0Z(#`["GT*"F$@>PH@("`@8V]L;W(Z
M(&)L=64["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*83IH;W9E<B![
M"B`@("!T97AT+61E8V]R871I;VXZ('5N9&5R;&EN93L*?0HN<V5L96-T960@
M>PH@("`@8F%C:V=R;W5N9#H@(V)B8V)F9CL*?0HN<V5L96-T960M;W9E<B![
M"B`@("!B86-K9W)O=6YD.B`C8V5F.PI]"@HO*B!486)L92!S='EL97,N("HO
M"G1A8FQE('L*("`@(&)O<F1E<CH@;F]N93L*?0IT9"P@=&@@>PH@("`@<&%D
M9&EN9SH@,7!X.PI]"G1H('L*("`@(&-O;&]R.B`C,S,S.PH@("`@9F]N="UF
M86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT
M+7-I>F4Z(#$Q<'@["GT*=&0@>PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@
M9F]N="UF86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I
M9CL*?0IU;"YL:6YE9%)O=R!["B`@("!L:7-T+7-T>6QE+71Y<&4Z(&YO;F4[
M"GT*+FQI;F5D4F]W+"!T<BYL:6YE9%)O=R!T9"P@=&%B;&4N;&EN9612;W<@
M=&0L('5L+FQI;F5D4F]W(&QI('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C
M:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M9&1D.PI]"G1A8FQE+FQI;F5D4F]W+"!U;"YL:6YE9%)O=R!["B`@("!B;W)D
M97(M8F]T=&]M.B!N;VYE.PI]"BYL:6YE9%)O=U-E;&5C=&5D0V]L+"!T9"YL
M:6YE9%)O=U-E;&5C=&5D0V]L+"!T86)L92YL:6YE9%)O=R!T9"YL:6YE9%)O
M=U-E;&5C=&5D0V]L('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N
M9#H@(V8S9C-F,SL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C9&1D
M.PI]"BYS96QE8W1E9%)O=RP@='(N<V5L96-T9612;W<@=&0@>PH@("`@8F%C
M:V=R;W5N9#H@(V9F8SL*?0HN<V5L96-T9612;W<Z:&]V97(L('1R+G-E;&5C
M=&5D4F]W('1D.FAO=F5R+"`N<V5L96-T9612;W<M;W9E<BP@='(N<V5L96-T
M9612;W<M;W9E<B!T9"!["B`@("!B86-K9W)O=6YD.B`C9F9D.PI]"G1A8FQE
M+FYO<&%D9&EN9R!T9"P@=&%B;&4N;F]P861D:6YG('1H('L*("`@('!A9&1I
M;F<Z(#`["GT*+G-O<G1U<"!["B`@("!B86-K9W)O=6YD.B`C8F)C8F9F('5R
M;"@B9W)A<&AI8W,O>F$N<&YG(BD@8V5N=&5R(&QE9G0@;F\M<F5P96%T.PH@
M("`@<&%D9&EN9RUL969T.B`Q,'!X.PI]"BYS;W)T9&]W;B!["B`@("!B86-K
M9W)O=6YD.B`C8F)C8F9F('5R;"@B9W)A<&AI8W,O87HN<&YG(BD@8V5N=&5R
M(&QE9G0@;F\M<F5P96%T.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PI]"B\J
M($%L=&5R;F%T:6YG('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A
M=&5D+B`J+PHN<W1R:7!E9"P@+G)O=T5V96XL("YI=&5M,"!["B`@("!B86-K
M9W)O=6YD.B`C965E.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O
M=6YD.B`C9&1D.PI]"@HN=VED9V5T('L*("`@(&9O;G0M9F%M:6QY.B!697)D
M86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X
M.PI]"@HN;6EM95-T871U<TUE<W-A9V4@>PH@("`@<&%D9&EN9SH@,7!X.PH@
M("`@;6%R9VEN+6)O='1O;3H@-'!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D
M(",P,&,["B`@("!B86-K9W)O=6YD.B`C965F.PH@("`@8V]L;W(Z(",P,#8[
M"GT*+FUI;653=&%T=7-787)N:6YG('L*("`@('!A9&1I;F<Z(#%P>#L*("`@
M(&UA<F=I;BUB;W1T;VTZ(#1P>#L*("`@(&)O<F1E<CH@,7!X(&1A<VAE9"`C
M9C`P.PH@("`@8F%C:V=R;W5N9#H@(V9F9#!A9CL*("`@(&-O;&]R.B`C9C`P
M.PI]"@HN;&EG:'0@>PH@("`@8V]L;W(Z("-F9F8["B`@("!F;VYT+69A;6EL
M>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N
M="US:7IE.B`Q,G!X.PI]"BYS;6%L;&AE861E<B!["B`@("!F;VYT+69A;6EL
M>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N
M="US:7IE.B`Q,G!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["GT*<VUA;&PL
M("YS;6%L;"!["B`@("!F;VYT+7-I>F4Z(#$P<'@["GT*+F-O;G1R;VP@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C8V-C.PH@("`@8F]R
M9&5R+6)O='1O;3H@,7!X('-O;&ED(",Y.3D["GT*+FET96T@>PH@("`@8V]L
M;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C965E.PI]"BYA8V-E<W-+97D@
M>PH@("`@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4["GT*+G1E>'0@>PH@
M("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]"@HO*B!&
M;W)M('-T>6QE<RX@*B\*+F9O<FT@=&%B;&4@>PH@("`@=VED=&@Z(#$P,"4[
M"B`@("!P861D:6YG.B`R<'@["B`@("!B;W)D97(M8V]L;&%P<V4Z(&-O;&QA
M<'-E.PI]"BYH=&UL87)E82`N<W1A='5S0F%R("YS=&%T=7-"87)4<F5E(&$@
M>PH@("`@9F]N=#H@:6YH97)I=#L*?0HN:'1M;&%R96$@=&%B;&4@>PH@("`@
M=VED=&@Z(&%U=&\["GT*+F9O<FTM97)R;W(@>PH@("`@8V]L;W(Z("-F,#`[
M"GT*:6YP=70L('-E;&5C="!["B`@("!F;VYT+69A;6EL>3H@1V5N979A+$%R
M:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,G!X
M.PH@("`@9F]N="UW96EG:'0Z(&YO<FUA;#L*?0II;G!U="!["B`@("!P861D
M:6YG.B`Q<'@["GT*;W!T:6]N('L*("`@('!A9&1I;F<Z(#!P>"`U<'@@,'!X
M(#-P>#L*?0HN8VAE8VMB;W@@>PH@("`@8F]R9&5R.B`P.PH@("`@:&5I9VAT
M.B`Q-'!X.PH@("`@=VED=&@Z(#$T<'@["B`@("!B86-K9W)O=6YD.B!T<F%N
M<W!A<F5N=#L*?0HN8G5T=&]N('L*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@
M(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]
M"F$N8G5T=&]N('L*("`@('!A9&1I;F<Z(#)P>#L*("`@(&9O;G0M=V5I9VAT
M.B!N;W)M86P["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*"BYF:7AE
M9"!["B`@("!F;VYT+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N
M;W-P86-E+&9I>&5D.PI]"@HO*B!3='EL97,@9F]R(&5M86EL+6QI:V4@;65S
M<V%G97,N("HO"BYS:6=N871U<F4@>PH@("`@8V]L;W(Z("-C8V,["GT*+G-I
M9VYA='5R92UF:7AE9"!["B`@("!C;VQO<CH@(V-C8SL*("`@(&9O;G0M<VEZ
M93H@,3-P>#L*("`@(&9O;G0M9F%M:6QY.B!M;VYO<W!A8V4L9FEX960["GT*
M+F-I=&%T:6]N('L*("`@(&UA<F=I;CH@,65M(#`["B`@("!P861D:6YG+6QE
M9G0Z(#%E;3L*("`@(&)O<F1E<BUL969T+7=I9'1H.B`Q<'@["B`@("!B;W)D
M97(M;&5F="US='EL93H@<V]L:60["GT*+G%U;W1E9#$@>PH@("`@8V]L;W(Z
M(",V,#8["B`@("!B;W)D97(M;&5F="UC;VQO<CH@(S8P-CL*?0HN<75O=&5D
M,B!["B`@("!C;VQO<CH@(S`W-SL*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C
M,#<W.PI]"BYQ=6]T960S('L*("`@(&-O;&]R.B`C.3`P.PH@("`@8F]R9&5R
M+6QE9G0M8V]L;W(Z(",Y,#`["GT*+G%U;W1E9#0@>PH@("`@8V]L;W(Z(",P
M,#D["B`@("!B;W)D97(M;&5F="UC;VQO<CH@(S`P.3L*?0HN<75O=&5D-2![
M"B`@("!C;VQO<CH@(V(V,#L*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C8C8P
M.PI]"@HO*B!687)I;W5S('!O<'5P(&%N9"!S=&%T=7,@;&%Y97)S+B`J+PHN
M;F]T:6-E('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD.B`C9F9C.PH@("`@8F]R9&5R.B`Q<'@@<V]L
M:60@(V%A83L*("`@('!A9&1I;F<Z(#%P>#L*("`@('!A9&1I;F<M;&5F=#H@
M-7!X.PH@("`@;6%R9VEN+6)O='1O;3H@,7!X.PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S.B`X<'@["GT*+G1O;VQT:7`L(&1I=BYN:6-E=&ET;&4@>PH@("`@
M9F]N=#H@,3%P>"\Q,G!X(%9E<F1A;F$L07)I86PL<V5R:68["B`@("!C;VQO
M<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-F9F,["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@<&%D9&EN9SH@-7!X.PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S.B`S<'@["GT*9&EV+FYI8V5T:71L92!["B`@("!P;W-I=&EO
M;CH@86)S;VQU=&4["B`@("!O=F5R9FQO=SH@:&ED9&5N.PH@("`@;W!A8VET
M>3H@+CDP.PI]"F1I=BYN:6-E=&ET;&4@<')E('L*("`@(&9O;G0M9F%M:6QY
M.B`B3'5C:61A($-O;G-O;&4B+&UO;F]S<&%C92QF:7AE9#L*?0HN:6Y0<F]G
M<F5S<R!["B`@("!F;VYT.B`Q,'!X($=E;F5V82Q!<FEA;"Q(96QV971I8V$L
M<V%N<RUS97)I9CL*("`@('!A9&1I;F<Z(#)P>#L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9#H@(V8P,#L*?0H*+RH@5')E92!S='EL97,N("HO
M"BYT<F5E4F]W('L*("`@(&]V97)F;&]W.B!H:61D96X["B`@("!M:6XM:&5I
M9VAT.B`R,'!X.PH@("`@8VQE87(Z(&)O=&@["GT*"B\J($UE;G4@<W1Y;&5S
M+B`J+PHC;65N=2!["B`@("!O=F5R9FQO=SH@:&ED9&5N.PH@("`@;6EN+6AE
M:6=H=#H@-3!P>#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC
M82QS86YS+7-E<FEF.PH@("`@;6%R9VEN+6)O='1O;3H@.'!X.PI]"B-M96YU
M('5L('L*("`@('!A9&1I;F<Z(#5P>#L*?0HC;65N=2!L:2!["B`@("!L:7-T
M+7-T>6QE+71Y<&4Z(&YO;F4["B`@("!T97AT+6%L:6=N.B!C96YT97(["B`@
M("!M87)G:6XZ(#)P>#L*("`@(&9L;V%T.B!L969T.PI]"B-M96YU(&$@>PH@
M("`@9&ES<&QA>3H@8FQO8VL["B`@("!W:&ET92US<&%C93H@<')E.PH@("`@
M9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@
M("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4[
M"B`@("!P861D:6YG.B`S<'@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#-P
M>#L*?0HC;65N=2!H,2!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV
M971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@
M9F]N="US:7IE.B`Q.'!X.PH@("`@;&EN92UH96EG:'0Z(#0X<'@["B`@("!V
M97)T:6-A;"UA;&EG;CH@8F]T=&]M.PI]"B-M96YU(&EN<'5T+"`C;65N=2!S
M96QE8W0@>PH@("`@;6%R9VEN+71O<#H@,39P>#L*?0H*+RH@4VED96)A<B!S
M='EL97,N("HO"BYS:61E8F%R("-M96YU('L*("`@(&UA<F=I;CH@,#L*?0HC
M<VED96)A<E!A;F5L('L*("`@("UM;WHM8F]R9&5R+7)A9&EU<RUB;W1T;VUR
M:6=H=#H@,35P>#L*("`@('!A9&1I;F<M=&]P.B`U<'@["B`@("!P861D:6YG
M+6)O='1O;3H@,3!P>#L*("`@(&)A8VMG<F]U;F0Z("-E964["B`@("!W:&ET
M92US<&%C93H@;F]W<F%P.PI]"B-S:61E8F%R4&%N96P@<W!A;BP@(W-I9&5B
M87)086YE;"!A('L*("`@(&-O;&]R.B`C,#`P.PH@("`@=VAI=&4M<W!A8V4Z
M('!R93L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS
M+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O<F%T
M:6]N.B!N;VYE.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G;&4@>PH@("`@
M8W5R<V]R.B!P;VEN=&5R.PI]"B-S:61E8F%R4&%N96P@83IH;W9E<B!["B`@
M("`M;6]Z+6)O<F1E<BUR861I=7,Z(#-P>#L*("`@(&-O;&]R.B`C,#`P.PI]
M"@HO*B!086=E<BX@*B\*+G!A9V5R('L*("`@('1E>'0M86QI9VXZ(&-E;G1E
M<CL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!F;&]A=#H@
M;&5F=#L*("`@('=I9'1H.B`Q,#`E.PH@("`@9F]N="UW96EG:'0Z(&)O;&0[
M"B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+W1A8E]B;W1T;VTN9VEF
M(BD@<F5P96%T+7@@8F]T=&]M.PI]"BYT86)S970@=6P@>PH@("`@;6%R9VEN
M+71O<#H@-'!X.PH@("`@<&%D9&EN9RUL969T.B`Q,'!X.PH@("`@;&ES="US
M='EL93H@;F]N93L*?0HN=&%B<V5T(&QI('L*("`@(&9L;V%T.B!L969T.PH@
M("`@;6%R9VEN+71O<#H@+3-P>#L*("`@(&UA<F=I;BUL969T.B`R<'@["B`@
M("!W:&ET92US<&%C93H@;F]W<F%P.PI]"BYT86)S970@;&D@82!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E.64Y93D["B`@
M("!P861D:6YG.B`R<'@@,"XU96T["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@
M(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M8F]T=&]M+6-O
M;&]R.B`C93EE.64Y.PH@("`@+6UO>BUB;W)D97(M<F%D:75S+71O<&QE9G0Z
M(#$P<'@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,M=&]P<FEG:'0Z(#$P<'@[
M"GT*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@('1E>'0M9&5C;W)A=&EO;CH@
M;F]N93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*+G1A8G-E="!L
M:2YA8W1I=F5486(@82!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`["B`@("!C;VQO<CH@
M(V9F9CL*?0HN=&%B<V5T(&QI+F%C=&EV951A8B!A.FAO=F5R('L*?0HN=&%B
M<V5T(&EM9R!["B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@(&9L;V%T.B!L969T
M.PH@("`@<&%D9&EN9RUR:6=H=#H@,G!X.PI]"@HO*B!0<F5F97)E;F-E<R!O
M=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I97<@9&EV('L*("`@(&9L;V%T.B!L
M969T.PI]"BYP<F5F<T]V97)V:65W(&1I=B!D:78@>PH@("`@<&%D9&EN9RUL
M969T.B`Q,'!X.PH@("`@=VED=&@Z(#DU)3L*?0HN<')E9G-/=F5R=FEE=R!H
M,B!["B`@("!F;VYT+7-I>F4Z(#$X<'@["B`@("!F;VYT+7=E:6=H=#H@8F]L
M9#L*?0HN<')E9G-/=F5R=FEE=R!D="!A('L*("`@(&1I<W!L87DZ(&)L;V-K
M.PH@("`@<&%D9&EN9SH@,G!X.PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",T-#8["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYP
M<F5F<T]V97)V:65W(&1D('L*("`@('!A9&1I;F<Z(#)P>#L*("`@(&UA<F=I
M;BUB;W1T;VTZ(#$P<'@["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U
M;F0Z("-F9F8["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED(",P,#`["B`@
M("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED(",P,#`["GT*"B\J($)L;V-K('-T>6QE<RX@*B\*
M+F-U<G)E;G1";&]C:R!["B`@("!B;W)D97(Z(#)P>"!S;VQI9"!R960["GT*
M"B\J($AE;'`@<W1Y;&5S+B`J+PHN:&5L<"!["B`@("!B86-K9W)O=6YD.B`C
M9F9F.PH@("`@8V]L;W(Z(",P,#`["GT*+FAE;'`@:#$@>PH@("`@9F]N="US
M:7IE.B`Q-7!X.PH@("`@<&%D9&EN9RUT;W`Z(#`N-65M.PH@("`@<&%D9&EN
M9RUB;W1T;VTZ(#`N-65M.PI]"BYH96QP(&@R('L*("`@(&)O<F1E<BUT;W`Z
M(#%P>"!S;VQI9"`C-#0V.PH@("`@<&%D9&EN9RUT;W`Z(#%E;3L*("`@('!A
M9&1I;F<M8F]T=&]M.B`P+C5E;3L*("`@(&9O;G0M<VEZ93H@,3-P>#L*?0HN
M:&5L<"!P('L*("`@(&UA<F=I;BUL969T.B`Q96T["B`@("!M87)G:6XM<FEG
M:'0Z(#%E;3L*("`@(&UA<F=I;BUB;W1T;VTZ(#%E;3L*?0HN:&5L<"!E;2![
M"B`@("!D:7-P;&%Y.B!B;&]C:SL*("`@('!A9&1I;F<Z(#5P>#L*("`@(&UA
M<F=I;BUL969T.B`Q96T["B`@("!M87)G:6XM<FEG:'0Z(#%E;3L*("`@(&UA
M<F=I;BUB;W1T;VTZ(#%E;3L*?0HN:&5L<"!E;2YH96QP5&EP('L*("`@(&-O
M;&]R.B`C,#DP.PH@("`@8F%C:V=R;W5N9#H@(V4P9C!E,#L*?0HN:&5L<"!E
M;2YH96QP5V%R;B!["B`@("!C;VQO<CH@(SDP,#L*("`@(&)A8VMG<F]U;F0Z
M("-F,&4P93`["GT*"B\J(%-O=7)C92!M87)K=7`@<W1Y;&5S+B`J+PIT86)L
M92YL:6YE3G5M8F5R960@>PH@("`@;6%R9VEN.B`U<'@["B`@("!B;W)D97(Z
M(#%P>"!S;VQI9"`C,#`P.PI]"BYL:6YE3G5M8F5R960@=&@@>PH@("`@8F%C
M:V=R;W5N9#H@(V4Y93EE.3L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED
M("-E,&4P93`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED("-F,V8S9C,[
M"B`@("!P861D:6YG+6QE9G0Z(#$P<'@["B`@("!P861D:6YG+7)I9VAT.C$P
M<'@["B`@("!T97AT+6%L:6=N.B!R:6=H=#L*?0HN;&EN94YU;6)E<F5D('1H
M(&$@>PH@("`@9F]N="UF86UI;'DZ(&UO;F]S<&%C93L*("`@(&9O;G0M<VEZ
M93H@,3)P>#L*("`@(&QI;F4M:&5I9VAT.B`Q-G!X.PI]"BYL:6YE3G5M8F5R
M960@=&0@>PH@("`@=F5R=&EC86PM86QI9VXZ('1O<#L*("`@('=I9'1H.B`Q
M,#`E.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*("`@(&)A8VMG<F]U;F0Z("-F
M9F8["B`@("!P861D:6YG+6QE9G0Z(#$P<'@["B`@("!F;VYT+69A;6EL>3H@
M;6]N;W-P86-E.PH@("`@9F]N="US:7IE.B`Q,G!X.PH@("`@=VAI=&4M<W!A
M8V4Z('!R93L*("`@(&QI;F4M:&5I9VAT.B`Q-G!X.PI]"BYP87)E;G1H97-E
M<R!["B`@("!C;VQO<CH@(S)A-CL*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PI]
M"BYC;VUM96YT('L*("`@(&-O;&]R.B`C86%C.PI]"BYH=&%G('L*("`@(&-O
M;&]R.B`C-38Y.PH@("`@8F%C:V=R;W5N9#H@(V0U9#9D83L*("`@(&9O;G0M
M=V5I9VAT.B!B;VQD.PI]"BYM971A8R!["B`@("!C;VQO<CH@(S!F9CL*("`@
M(&)A8VMG<F]U;F0Z("-D-60V9&$["GT*+FED('L*("`@(&-O;&]R.B`C93@R
M.PH@("`@8F%C:V=R;W5N9#H@(V4T931E,#L*?0HN871T<B!["B`@("!C;VQO
M<CH@(S9A9CL*?0HN=F%L=64@>PH@("`@8V]L;W(Z("-D-#8["GT*+F-O;&]R
M('L*("`@(&-O;&]R.B`C9C4W.PI]"BYE;VP@>PH@("`@8V]L;W(Z(",R-F4[
M"GT*+G5R;"!["B`@("!C;VQO<CH@(SDV,CL*?0HN9FEL92!["B`@("!C;VQO
M<CH@(S0T-#L*("`@(&)A8VMG<F]U;F0Z("-F930["GT*+F-L87-S('L*("`@
M(&9O;G0M<W1Y;&4Z(&ET86QI8SL*?0H*+RH@1')O<"!S:&%D;W=S+B`J+PHN
M9')O<%-H861O=R!["B`@("!F;&]A=#H@;&5F=#L*("`@(&)A8VMG<F]U;F0Z
M('5R;"@B9W)A<&AI8W,O<VAA9&]W+G!N9R(I(&YO+7)E<&5A="!B;W1T;VT@
M<FEG:'0@(6EM<&]R=&%N=#L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI
M8W,O<VAA9&]W+F=I9B(I(&YO+7)E<&5A="!B;W1T;VT@<FEG:'0["B`@("!M
M87)G:6XZ(#$P<'@@,"`P(#5P>#L*?0H*+F1R;W!3:&%D;W<@:6UG('L*("`@
M(&1I<W!L87DZ(&)L;V-K.PH@("`@<&]S:71I;VXZ(')E;&%T:79E.PH@("`@
M8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8[
M"B`@("!M87)G:6XZ("TS<'@@-7!X(#5P>"`M,W!X.PH@("`@<&%D9&EN9SH@
M,G!X.PI]"@HO*B!N97=S9F5E9',@*B\*"BYS:61E8F%R4&%N96P@>PH@("`@
M8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S`P-CL*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C,#`V.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EF9CL*
M("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]"@HN<VED96)A<DAE861E<B!["B`@
M8F%C:V=R;W5N9"UC;VQO<CH@(S9E.#ED9#L*?0H*+FAE861E<E1I=&QE('L*
M("!C;VQO<CH@(V9F9CL*("!P861D:6YG.B`S<'@@-W!X.PH@('=H:71E+7-P
M86-E.B!N;W=R87`["B`@9F]N="UW96EG:'0Z(&)O;&0["GT*+FAE861E<D)U
M='1O;G,@>PH@('1E>'0M86QI9VXZ(')I9VAT.PI]"BYH96%D97)"=71T;VYS
M(&$@>PH@(&]V97)F;&]W.B!H:61D96X["B`@=VED=&@Z(#$V<'@["B`@:&5I
M9VAT.B`Q-G!X.PH@(&1I<W!L87DZ("UM;WHM:6YL:6YE+6)O>#L*("!D:7-P
M;&%Y.B!I;FQI;F4M8FQO8VL["B`@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L*
M("!B86-K9W)O=6YD+7)E<&5A=#H@;F\M<F5P96%T.PH@(&UA<F=I;BUR:6=H
M=#H@-W!X.PI]"BYH96%D97)"=71T;VYS(&$@<W!A;B!["B`@<&%D9&EN9RUL
M969T.B`Q,#!P>#L*("!D:7-P;&%Y.B!B;&]C:SL*?0HN8G1N+7)E9G)E<V@@
M>PH@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"@G+W1H96UE<R]G<F%P:&EC<R]I
M;6%G92]R969R97-H+F=I9B<I.PI]"BY.1F-L;W-E("-N97=S1F5E9',@>PH@
M(&1I<W!L87DZ(&YO;F4["GT*+DY&;W!E;B`N8G1N+6]P96XM8VQO<V4@>PH@
M(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"@G+W1H96UE<R]G<F%P:&EC<R]I;6%G
M92]A<G)O=RUD;W=N+F=I9B<I.PI]"BY.1F-L;W-E("YB=&XM;W!E;BUC;&]S
M92!["B`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*"<O=&AE;65S+V=R87!H:6-S
M+VEM86=E+V%R<F]W+75P+F=I9B<I.PI]"BY.1G1I=&QE('L*9F]N="UW96EG
M:'0Z(&)O;&0["F1I<W!L87DZ(&)L;V-K.PI]"BY.1FET96T@>PID:7-P;&%Y
M.B!B;&]C:SL*;6%R9VEN+6)O='1O;3H@-7!X.PI]"BY.1G-O=7)C92!["FUA
M<F=I;BUR:6=H=#H@-7!X.PI]"BY.1G-T871U<R!["FUA<F=I;BUR:6=H=#H@
M-7!X.PIF;VYT+7=E:6=H=#H@8F]L9#L*?0HN3D9T:6UE('L*8V]L;W(Z(",S
M,S,["GT*(VYE=W-&965D<R!["G!A9&1I;F<Z(#5P>"`W<'@@-7!X(#=P>#L*
M?0H*"@````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O:64V7V]R7VQE<W,N8W-S````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-#,@,3`U,34T,S0Q
M-3(@,#(Q-S0S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]I939?;W)?;&5S
M<RYC<W,L=B`Q+C$N,BXQ(#(P,#8O,#,O,C0@,#`Z-#`Z,S<@8VAU8VL@17AP
M("0*("H*("H@0U-3(&-O<G)E8W1I;VYS(&9O<B!)12X*("HO"@HN=')E95)O
M=R!["B`@("!O=F5R9FQO=SH@=FES:6)L93L*("`@(&AE:6=H=#H@,C!P>#L*
M?0H*(VUE;G4@>PH@("`@;W9E<F9L;W<Z('9I<VEB;&4["B`@("!H96EG:'0Z
M(#4P<'@["GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V)U<FYT;W)A;F=E+VEN9F\N<&AP````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P-#$P(#$P-3$U-#,T,34R(#`R,S`P-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE;64@8GDZ($5R:6,@2F]N(%)O<W1E='1E<B`\97)I8RYR
M;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*B!0;&5A<V4@8V]N=&%C
M="!T:&4@=&AE;64G<R!A=71H;W(@9F]R(&%N>2!M:7-S:6YG('-T>6QE+@H@
M*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B=7)N=&]R86YG92]I;F9O+G!H
M<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,U(&UD:G5K:6,@17AP("0*("HO
M"@HD=&AE;65?;F%M92`](%\H(D)U<FYT($]R86YG92(I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]B
M=7)N=&]R86YG92]S8W)E96XN8W-S````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S0Q-R`Q,#4Q-30S-#$U,B`P,C,S-#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J(%1H96UE(&)Y
M.B!%<FEC($IO;B!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N
M=71E>&%S+F5D=3X*("H@4&QE87-E(&-O;G1A8W0@=&AE('1H96UE)W,@875T
M:&]R(&9O<B!A;GD@;6ES<VEN9R!S='EL92X*("H*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O8G5R;G1O<F%N9V4O<V-R965N+F-S<RQV(#$N-BXV+C,@,C`P
M-2\Q,"\Q."`Q,3HS-#HQ,B!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A
M8VMG<F]U;F0Z("-F,&(P-C`["GT*82!["B`@("!C;VQO<CH@(V,V,#L*?0IA
M.FAO=F5R('L*("`@(&-O;&]R.B`C8S8P.PI]"BYH96%D97(@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C8S8P.PI]"BYH96%D97(@82![
M"B`@("!C;VQO<CH@(V9F9CL*?0H*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R
M.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V,V,#L*?0HN8V]N=')O;"!["B`@
M("!B86-K9W)O=6YD.B`C9CEC93AA.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X
M('-O;&ED("-C-C`["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)A8VMG<F]U;F0Z("-C-C`["B`@("!B;W)D97(M8F]T=&]M+6-O;&]R.B`C
M,S`P.PH@("`@8F]R9&5R+7)I9VAT+6-O;&]R.B`C,S`P.PH@("`@8F]R9&5R
M+71O<"UC;VQO<CH@(V8P8C`V,#L*("`@(&)O<F1E<BUL969T+6-O;&]R.B`C
M9C!B,#8P.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C9&8Y9C-F
M.PI]"F$N<VUA;&QH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*
M"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*
M("`@(&)A8VMG<F]U;F0Z("-C-C`["GT*(VUE;G4@83IH;W9E<B!["B`@("!B
M;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@(&)O<F1E<BUR
M:6=H=#H@,7!X('-O;&ED("-F,&(P-C`["B`@("!B;W)D97(M=&]P.B`Q<'@@
M<V]L:60@(S,P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S,P,#L*
M("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A('L*("`@(&-O;&]R.B`C9F9F
M.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z("-D9CEF,V8["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V8P8C`V,#L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F,&(P
M-C`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S,P,#L*("`@(&)O<F1E
M<BUL969T.B`Q<'@@<V]L:60@(S,P,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*
M+RH@4VED96)A<B!S='EL97,N("HO"F)O9'DN<VED96)A<B!["B`@("!B86-K
M9W)O=6YD.B`C9C!B,#8P.PI]"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R
M+7)I9VAT.B`Q<'@@<V]L:60@(V8P8C`V,#L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C9C!B,#8P.PH@("`@8F%C:V=R;W5N9#H@(V8P8C`V,#L*
M?0HC<VED96)A<E!A;F5L(&$@>PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V8P
M8C`V,#L*("`@('!A9&1I;F<M;&5F=#H@,7!X.PH@("`@<&%D9&EN9RUB;W1T
M;VTZ(#)P>#L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z
M(",Y,#`["B`@("!B86-K9W)O=6YD.B!Y96QL;W<["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"@HO
M*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T(&QI+F%C=&EV951A8B!A+"`N=&%B
M<V5T(&QI+F%C=&EV951A8B!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z("-C
M-C`["B`@("!B;W)D97(M8F]T=&]M+6-O;&]R.B`C8S8P.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O<'5R<&QE
M+VEN9F\N<&AP````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`Q-S8@,3`U,34T,S0Q-3(@,#(Q-S<W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1H96UE<R]P=7)P;&4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,2\R
M-2`P,CHP-#HU-"!C:'5C:R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B
M4'5R<&QE($AO<F1E(BD["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!U<G!L92]S8W)E96XN8W-S
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,#`R(#$P
M-3$U-#,T,34R(#`R,C,Q-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<'5R
M<&QE+W-C<F5E;BYC<W,L=B`Q+C$N-"XV(#(P,#8O,#0O,C@@,C`Z-#<Z,C@@
M:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C,C(T.PI]
M"@HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC;VQO<CH@(S8V.3L*("`@(&)A
M8VMG<F]U;F0Z("-F9F8["GT*+FAE861E<B!["B`@("!C;VQO<CH@(V-C93L*
M("`@(&)A8VMG<F]U;F0Z(",T-#8["B`@("!C;&5A<CH@8F]T:#L*?0HN:&5A
M9&5R(&$Z:&]V97(L(&$N:&5A9&5R.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F
M.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V-C93L*?0IA+FAE861E<CIH
M;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*?0IA('L*("`@(&-O;&]R.B`C,S,Y
M.PI]"F$Z:&]V97(@>PH@("`@8V]L;W(Z(&)L=64["GT*+G-E;&5C=&5D('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B8F-B9F8["GT*+G-E;&5C=&5D+6]V
M97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-E9CL*?0H*+G=I9&=E="![
M"B`@("!C;VQO<CH@(S(R-#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO
M<CH@8FQU93L*("`@(&)A8VMG<F]U;F0Z("-B8F-B9F8["GT*"BYN;W1I8V4@
M>PH@("`@9F]N="UW96EG:'0Z(&)O;&0["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C9F9C.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%A83L*("`@('!A9&1I
M;F<Z(#%P>#L*("`@('!A9&1I;F<M;&5F=#H@-7!X.PH@("`@+6UO>BUB;W)D
M97(M<F%D:75S.B`X<'@["GT*"BYL:6=H="!["B`@("!C;VQO<CH@(V9F9CL*
M("`@(&9O;G0M9F%M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M
M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$R<'@["GT*+G-M86QL:&5A9&5R('L*
M("`@(&-O;&]R.B`C8V-E.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S0T-CL*
M?0HN<VUA;&QH96%D97(@83IH;W9E<BP@82YS;6%L;&AE861E<CIH;W9E<B![
M"B`@("!C;VQO<CH@(V9F9CL*?0HN<VUA;&QH96%D97(@82!["B`@("!C;VQO
M<CH@(V-C93L*?0HN8V]N=')O;"!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-C8V,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@
M<V]L:60@(SDY.3L*?0HN:71E;2!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-E964["GT*+F%C8V5S<TME>2!["B`@("!T97AT
M+61E8V]R871I;VXZ('5N9&5R;&EN93L*?0HN=&5X="!["B`@("!C;VQO<CH@
M(S`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*"B\J($9O<FT@
M<W1Y;&5S+B`J+PHN8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(S8V.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C,C(T.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(S(R-#L*
M("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C.3EC.PH@("`@8F]R9&5R+6QE
M9G0Z(#%P>"!S;VQI9"`C.3EC.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@
M9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*
M83IH;W9E<BYB=71T;VX@>PH@("`@8V]L;W(Z("-F9F8["GT*"B\J($UE;G4@
M<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z(",T-#8["GT*(VUE;G4@=6P@>PH@("`@<&%D9&EN9SH@
M-7!X.PI]"B-M96YU(&QI('L*("`@(&QI<W0M<W1Y;&4M='EP93H@;F]N93L*
M("`@('1E>'0M86QI9VXZ(&-E;G1E<CL*("`@(&UA<F=I;CH@,G!X.PH@("`@
M9FQO870Z(&QE9G0["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V5E9CL*?0HC
M;65N=2!A.FAO=F5R('L*("`@(&-O;&]R.B!Y96QL;W<["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S8V83L*("`@(&)O<F1E<BUR:6=H=#H@,7!X
M('-O;&ED(",V-F$["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S(R-#L*
M("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S(R-#L*("`@('!A9&1I;F<Z
M(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(S8V.#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C.3EC.PH@
M("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(SDY8SL*("`@(&)O<F1E<BUT
M;W`Z(#%P>"!S;VQI9"`C,C(T.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI
M9"`C,C(T.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&@Q('L*("`@(&9O
M;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@
M9F]N="UW96EG:'0Z(&)O;&0["B`@("!F;VYT+7-I>F4Z(#$X<'@["B`@("!L
M:6YE+6AE:6=H=#H@-3!P>#L*("`@('9E<G1I8V%L+6%L:6=N.B!B;W1T;VT[
M"GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@
M("UM;WHM8F]R9&5R+7)A9&EU<RUB;W1T;VUR:6=H=#H@,35P>#L*("`@('!A
M9&1I;F<M=&]P.B`U<'@["B`@("!P861D:6YG+6)O='1O;3H@,3!P>#L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-E964["GT*(W-I9&5B87)086YE;"!S<&%N
M('L*("`@('!A9&1I;F<Z(#)P>#L*?0HC<VED96)A<E!A;F5L('-P86XL("-S
M:61E8F%R4&%N96P@82!["B`@("!C;VQO<CH@(S`P,#L*("`@('=H:71E+7-P
M86-E.B!P<F4["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L
M<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@,3%P>#L*("`@('1E>'0M9&5C
M;W)A=&EO;CH@;F]N93L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@
M+6UO>BUB;W)D97(M<F%D:75S.B`S<'@["B`@("!C;VQO<CH@(S`P,#L*?0H*
M+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F5486(@
M82P@+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C-#0V.PH@("`@8F]R9&5R+6)O='1O;2UC;VQO<CH@(S0T
M-CL*?0H*+RH@4')E9F5R96YC97,@;W9E<G9I97<N("HO"BYP<F5F<T]V97)V
M:65W(&@R('L*("`@(&-O;&]R.B`C9F9F.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;V)I;&4O<V-R965N+F-S
M<P``````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,V,R`Q
M,#4Q-30S-#$U,B`P,C(R-C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VUO
M8FEL92]S8W)E96XN8W-S+'8@,2XQ+C$P+C$@,C`P-2\Q,"\Q."`Q,3HS-#HR
M,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-F9F8[
M"B`@("!F;VYT+69A;6EL>3H@0V]U<FEE<CL*("`@(&9O;G0M<VEZ93H@,3!P
M>#L*?0IT9"!["B`@("!F;VYT+69A;6EL>3H@0V]U<FEE<CL*("`@(&9O;G0M
M<VEZ93H@,3!P>#L*?0ID:78N<VEM9&5V('L*("`@('=I9'1H.B`Q-3`["B`@
M("!H96EG:'0Z(#$R,#L*("`@(&]V97)F;&]W.B!A=71O.PI]"G1D+G1O<"![
M"B`@("!W:61T:#H@,C8S.PH@("`@:&5I9VAT.B`Q,3<["B`@("!B86-K9W)O
M=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O=&]P+FIP9RD["GT*=&0N;&5F="![
M"B`@("!W:61T:#H@-38["B`@("!H96EG:'0Z(#$R,#L*("`@(&)A8VMG<F]U
M;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]L969T+FIP9RD["GT*=&0N9&ES<&QA
M>2!["B`@("!W:61T:#H@,34P.PH@("`@:&5I9VAT.B`Q,C`["B`@("!B86-K
M9W)O=6YD+6EM86=E.B!U<FPH9W)A<&AI8W,O9&ES<&QA>2YJ<&<I.PI]"G1D
M+G)I9VAT('L*("`@('=I9'1H.B`U-SL*("`@(&AE:6=H=#H@,3(P.PH@("`@
M8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H:6-S+W)I9VAT+FIP9RD["GT*
M=&0N8F]T=&]M('L*("`@('=I9'1H.B`R-C,["B`@("!H96EG:'0Z(#,Q,SL*
M("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"AG<F%P:&EC<R]B;W1T;VTN:G!G
M*3L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L:6=H=&)L=64O
M9W)A<&AI8W,`````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$U,B`P,C(U,C``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+VQI9VAT8FQU92]I;F9O+G!H<```````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,C`Q(#$P-3$U-#,T,34R(#`R,C0S-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O;&EG:'1B;'5E+VEN9F\N<&AP
M+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*
M"B1T:&5M95]N86UE(#T@7R@B3&EG:'0@0FQU92(I.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L:6=H
M=&)L=64O<V-R965N+F-S<P``````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3$T,"`Q,#4Q-30S-#$U,B`P,C(W-C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RHJ"B`J("1(;W)D93H@:&]R
M9&4O=&AE;65S+VQI9VAT8FQU92]S8W)E96XN8W-S+'8@,2XX+C8N,2`R,#`U
M+S$P+S$X(#$Q.C,T.C$Y(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C
M:V=R;W5N9#H@(V(P9#!F,3L*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PI]"BYH
M96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-F)A
M-61E.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z(",V8F$U9&4["GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD
M+6EM86=E.B!U<FPH9W)A<&AI8W,O;65N=2YP;F<I.PI]"@HO*B!-96YU('-T
M>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C-F)A-61E.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L
M*&=R87!H:6-S+VUE;G4N<&YG*3L*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@
M8F%C:V=R;W5N9#H@(V(P9#!F,3L*?0H*+RH@4VED96)A<B!S='EL97,N("HO
M"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V(P9#!F
M,3L*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L;W(Z('EE;&QO
M=SL*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]L:6=H=&)L=64O9W)A<&AI8W,O;65N=2YP;F<`````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#$V-"`Q,#4Q-30S-#$U,B`P,C0R-3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```$,````4`0,```#LCQ)_````!E!,5$5KI=YSK>_$LW->````"7!(
M67,```!(````2`!&R6L^````%$E$050(UV-@P`+^0\$#)-8@5P<`'M%8<:Y.
MAHD`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8FQU96UO;VXO
M:6YF;RYP:'``````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`Q-S<@,3`U,34T,S0Q-3(@,#(R,S$Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]B;'5E;6]O;B]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W
M(#$Y.C,S.C,T(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H
M(D)L=64@36]O;B(I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)L=65M;V]N+W-C<F5E;BYC<W,`
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-#$R(#$P-3$U
M-#,T,34R(#`R,C8S-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8FQU96UO
M;VXO<V-R965N+F-S<RQV(#$N,3,N-BXS(#(P,#4O,3`O,3@@,3$Z,S0Z,3$@
M:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!3
M86YS+%9E<F1A;F$["B`@("!B86-K9W)O=6YD.B`C,#`S.#DS.PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z(",P,#,X.3,["B`@("!S8W)O;&QB87(M87)R
M;W<M8V]L;W(Z(",P,38X9&(["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(S`P,S@Y,SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(S`Q-CAD8CL*?0II;G!U="!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS
M+%9E<F1A;F$["GT*<V5L96-T('L*("`@(&9O;G0M9F%M:6QY.B!,=7AI(%-A
M;G,L5F5R9&%N83L*("`@(&9O;G0M=V5I9VAT.B!N;W)M86P["GT*=&0@>PH@
M("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PI]"G1H('L*("`@
M(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*?0II;6<@>PH@("`@
M8F]R9&5R.B!N;VYE.PI]"F$@>PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N
M<RQ697)D86YA.PH@("`@8V]L;W(Z(",P,#-#9F8["GT*83IH;W9E<B!["B`@
M("!C;VQO<CH@(S`P,S@Y,SL*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P
M,T-F9CL*("`@(&9O;G0M<VEZ93H@,"XY96T["GT*82YW:61G970Z:&]V97(@
M>PH@("`@8V]L;W(Z(",P,#,X.3,["B`@("!B86-K9W)O=6YD.B`C,#$V.&1B
M.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z(",R-S`P-#(["B`@("!B86-K9W)O
M=6YD.B`C,#$V.&1B.PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D
M86YA.PH@("`@9F]N="US:7IE.B`Q-G!X.PI]"BYH96%D97(@82!["B`@("!C
M;VQO<CH@(S(W,#`T,CL*?0IT9"YH96%D97(@>PH@("`@<&%D9&EN9RUL969T
M.B`S<'@["B`@("!P861D:6YG+7)I9VAT.B`S<'@["GT*82YH96%D97(@>PH@
M("`@8V]L;W(Z(",P,&$X9F8["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@9F]N="UF86UI;'DZ($QU>&D@4V%N<RQ697)D86YA.PI]"F$N;&EG
M:'0Z:&]V97(@>PH@("`@8V]L;W(Z("-&1D,X,#`["GT*+G-M86QL:&5A9&5R
M('L*("`@(&-O;&]R.B`C,C<P,#0R.PH@("`@8F%C:V=R;W5N9#H@(S`Q-CAD
M8CL*("`@(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*("`@(&9O
M;G0M<VEZ93H@,31P>#L*?0IA+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C
M,#!A.&9F.PI]"BYS;6%L;"!["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS
M+%9E<F1A;F$["B`@("!F;VYT+7-I>F4Z(#`N.&5M.PI]"BYC;VYT<F]L('L*
M("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V0Q9#%D
M,3L*?0HN:71E;2!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z("-E.64Y93D["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(V9F9CL*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",R8C<S9#4["B`@("!B;W)D97(M8F]T
M=&]M.B!T:&EN('-O;&ED(",Y.6,["B`@("!B;W)D97(M<FEG:'0Z('1H:6X@
M<V]L:60@(SDY8SL*("`@(&)O<F1E<BUT;W`Z('1H:6X@<V]L:60@(S`P,#L*
M("`@(&)O<F1E<BUL969T.B!T:&EN('-O;&ED(",P,#`["B`@("!F;VYT+7-I
M>F4Z(#$R<'@["B`@("!F;VYT+69A;6EL>3H@3'5X:2!386YS+%9E<F1A;F$[
M"B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P>#L*?0HN8G5T=&]N.FAO=F5R
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",Q,38U9F8["GT*+G-E;&5C=&5D
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B8F-B9F8["GT*+F9I>&5D('L*
M("`@(&9O;G0M<VEZ93H@,3-P>#L*("`@(&9O;G0M9F%M:6QY.B!-;VYA8V\L
M0V]U<FEE<BQM;VYO<W!A8V5D+&9I>&5D.PI]"BYS96QE8W1E9"UO=F5R('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C8V5E9F8["GT*+G1O;VQT:7`@>PH@
M("`@9F]N="US:7IE.B`Q,'!X.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F
M8SL*("`@(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!P861D:6YG.B`R
M<'@["GT*+F%C8V5S<TME>2!["B`@("!T97AT+61E8V]R871I;VXZ('5N9&5R
M;&EN93L*?0IA+FAE861E<CIH;W9E<B!["B`@("!C;VQO<CH@.PI]"F$N8W5R
M<F5N=%1A8CIH;W9E<B!["B`@("!C;VQO<CH@.PI]"BYN;W1I8V4@>PH@("`@
M8F%C:V=R;W5N9"UC;VQO<CH@(V9F8SL*?0HN<VEG;F%T=7)E('L*("`@(&-O
M;&]R.B`C-C`V,#8P.PI]"BYS:6=N871U<F4M9FEX960@>PH@("`@8V]L;W(Z
M(",V,#8P-C`["B`@("!F;VYT+7-I>F4Z(#$P<'@["B`@("!F;VYT+69A;6EL
M>3H@36]N86-O+$-O=7)I97(L;6]N;W-P86-E9"QF:7AE9#L*?0H*+RH@5&%B
M;&4@<W1Y;&5S+B`J+PHN;&EN9612;W<@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED("-D9&0["GT*+FQI;F5D4F]W4V5L96-T961#;VP@>PH@("`@
M8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9C-F,V8S.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-D9&0["GT*+RH@06QT97)N
M871I;F<@<W1Y;&5S+B!I=&5M,"P@:71E;3$@87)E(&1E<')E8V%T960N("HO
M"BYR;W=%=F5N+"`N:71E;3`@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8S
M9C-F,SL*?0HN<F]W3V1D+"`N:71E;3$@>PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V4Y93EE.3L*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`Q-CAD8CL*
M("`@(&9O;G0M9F%M:6QY.B!,=7AI(%-A;G,L5F5R9&%N83L*?0HC;65N=2!A
M('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!C
M;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",P,38X8F(["B`@("!B;W)D
M97(M8F]T=&]M.B`Q<'@@<V]L:60@(SDY8SL*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED(",Y.6,["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`R
M,S`V-#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`R,S`V-#L*("`@
M('!A9&1I;F<Z(#)P>#L*("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]
M"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C,#$V.&1B.PI]"B-S:61E8F%R4&%N96P@<W!A
M;BP@(W-I9&5B87)086YE;"!A('L*("`@(&9O;G0M=V5I9VAT.B!B;VQD.PH@
M("`@8V]L;W(Z("-F9F8["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@
M(&-O;&]R.B`C9F9C.#`P.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+V=R87!H:6-S````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$U,B`P,C(R,3``(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VUO
M>FEL;&$O:6YF;RYP:'``````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,3<T(#$P-3$U-#,T,34R(#`R,C$S-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]T:&5M97,O;6]Z:6QL82]I;F9O+G!H<"QV(#$N,2`R,#`T
M+S$P+S$W(#$Y.C,S.C,W(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M
M92`](%\H(DUO>FEL;&$B*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]M;WII;&QA+W-C<F5E
M;BYC<W,`````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S$U
M-B`Q,#4Q-30S-#$U,B`P,C(T-C4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S
M+VUO>FEL;&$O<V-R965N+F-S<RQV(#$N-RXV+C4@,C`P-2\Q,"\Q."`Q,3HS
M-#HR,"!J86X@17AP("0*("HO"@IB;V1Y('L*("`@(&)A8VMG<F]U;F0Z("-C
M-V0P9#D["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(SDT83)B-3L*?0IH
M=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C.31A,F(U.PI]"F$L
M(&$N9FEX960@>PH@("`@8V]L;W(Z(",S,SD["GT*82YW:61G970@>PH@("`@
M8V]L;W(Z(",P,#`["GT*+FAE861E<B!["B`@("!B86-K9W)O=6YD.B`C8S=D
M,&0Y('5R;"@B9W)A<&AI8W,O:&5A9&5R+G!N9R(I(')E<&5A="UX.PH@("`@
M=VAI=&4M<W!A8V4Z(&YO=W)A<#L*?0IA+FAE861E<B!["B`@("!B86-K9W)O
M=6YD+6EM86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P
M87)E;G0["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C-$4U1#<R.PI]"BYS;6%L
M;&AE861E<B!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD+6EM
M86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@=')A;G-P87)E;G0[
M"GT*+G-M86QL:&5A9&5R(&$@>PH@("`@8V]L;W(Z(&)L86-K.PI]"BYC;VYT
M<F]L('L*("`@(&)A8VMG<F]U;F0Z("-A96)A8V$["GT*+FET96T@>PH@("`@
M8F%C:V=R;W5N9#H@(V5C969F-#L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B!B
M;&%C:SL*("`@(&)A8VMG<F]U;F0Z("-A9&(V8S8["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#`P.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*
M+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z("-C-F0S9F8["GT*"B\J($UE
M;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!B86-K9W)O=6YD.B`C8S=D,&0Y
M('5R;"@B9W)A<&AI8W,O;65N=2YP;F<B*2!R97!E870M>#L*?0HC;65N=2!H
M,2!["B`@("!C;VQO<CH@8FQA8VL["GT*(VUE;G4@82!["B`@("!C;VQO<CH@
M8FQA8VL["B`@("!B;W)D97(Z(&YO;F4["B`@("`M;6]Z+6)O<F1E<BUR861I
M=7,Z(#`["GT*(VUE;G4@83IH;W9E<B!["B`@("!B;W)D97(Z(#%P>"!S;VQI
M9"`C865B86-A.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N8W5R<F5N
M="!["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R87!H:6-S+VUE;G4M86-T:79E
M+G!N9R(I(')E<&5A="UX.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(V%E8F%C
M83L*("`@('!A9&1I;F<Z(#)P>#L*?0HC;65N=2!A+F-U<G)E;G0Z:&]V97(@
M>PH@("`@<&%D9&EN9SH@,G!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*
M(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD.B`C8S=D,&0Y.PI]"@HO
M*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T('L*("`@(&)A8VMG<F]U;F0Z(&YO
M;F4["GT*+G1A8G-E="!L:2!A('L*("`@(&)O<F1E<CH@,7!X('-O;&ED("-A
M8F%B86(["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V4Y93EE.3L*
M?0HN=&%B<V5T(&QI(&$Z:&]V97(@>PH@("`@8V]L;W(Z(",P,#`["GT*+G1A
M8G-E="!L:2YA8W1I=F5486(@82P@+G1A8G-E="!L:2YA8W1I=F5486(@83IH
M;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-A96)A
M8V$["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V%E8F%C83L*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;6]Z:6QL82]G<F%P:&EC<R]M
M96YU+G!N9P``````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,#<@,3`U
M,34T,S0Q-3(@,#(S-S0Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````!````,P@"````V<7U
M>`````=T24U%!]('$`H6`1<3G)P````)<$A9<P``"O````KP`4*L-)@````$
M9T%-00``L8\+_&$%````5DE$051XVE6,L0J`,!!#C_[_QSEV$'1S4!#$.6GO
MKD$[A"8ON=KYLCSW5<QL$N7)]/T-/C*1&40P0#W".\_LV\ZH?6Z^>X:H'O-_
MZIS_L_:N=3]LJ5L#OTY=R0.?TKT`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VUO>FEL;&$O9W)A<&AI8W,O;65N=2UA8W1I=F4N
M<&YG`````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S(W(#$P-3$U-#,T,34R(#`R
M-3(Q-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12`````0```#`(!@```-`S$($````$<T))5`@(
M"`A\"&2(````"7!(67,```KP```*\`%"K#28````(71%6'13;V9T=V%R90!-
M86-R;VUE9&EA($9I<F5W;W)K<R`T+C#J)B=U````3$E$051XG&V/L1&`,!##
M+.V_#0/0LQ04GWS(0>-"YUCY'.=UFR05P`AA,/6'=4_?;]U[5,\HTR%$:G0Q
M>]2OHUGMM:T^SF19WKYHCP=F'@0)V59GUP````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]M;WII;&QA+V=R87!H:6-S+VAE861E<BYP;F<`````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#0P,"`Q,#4Q-30S-#$U,B`P,C0R,3<`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@````<````9"`(```!R[*-O````+'1%6'1#<F5A=&EO;B!4:6UE
M`%1U92`Q-B!*=6P@,C`P,B`R,SHT-3HQ."`K,3(P,,6!&%$````'=$E-10?2
M!Q`++@D/E<)B````"7!(67,```[#```.PP'';ZAD````!&=!34$``+&/"_QA
M!0```%=)1$%4>-ICG+)H+0,&8#QW_1ZF*,OSYQ\P19D8L`$6!E8&8M7B,($#
MN[DL6$49L*C&Y3*L)G"2X#*L)N!2B\UEI)A`N2C+N?/G,449O7RCL(@>NXPE
MY@$>T`USO=1@\`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8F%R8FEE
M+VEN9F\N<&AP````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`Q-S4@,3`U,34T,S0Q-3(@,#(Q-S$S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+W1H96UE<R]B87)B:64O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q
M-R`Q.3HS,SHS,R!M9&IU:VEC($5X<"`D(#\^"B`J+PH*)'1H96UE7VYA;64@
M/2!?*")"87)B:64B*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)A<F)I92]S8W)E96XN8W-S
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S<Q(#$P
M-3$U-#,T,34R(#`R,C(T,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O8F%R
M8FEE+W-C<F5E;BYC<W,L=B`Q+C4N-BXR(#(P,#4O,3`O,3@@,3$Z,S0Z,3$@
M:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F5B-F,R
M.PI]"F$@>PH@("`@8V]L;W(Z(",T-#AF.3D["GT*"BYH96%D97(@>PH@("`@
M8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C9F8X96$U.PI]"BYS;6%L
M;&AE861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-F
M9CAE834["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9C
M8S)D,#L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9"UC;VQO<CH@(V8T-C$W9CL*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@
M<V]L:60@(V8T-C$W9CL*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C
M9C0V,3=F.PH@("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C9F8X.6$Q.PH@
M("`@8F]R9&5R+6QE9G0Z('1H:6X@<V]L:60@(V9F.#EA,3L*?0HN=&5X="![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9E-65C.PI]"@HO*B!-96YU('-T
M>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD.B`C9F8Y,6$W.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O
M=6YD.B`C9C0V,3=F.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-A
M86,["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R
M9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X
M('-O;&ED(",P,#`["B`@("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@
M<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED("-F96(V8S(["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(V9E8C9C,CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9CAE834["GT*
M(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H`````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W!O<W1N=6ME+VEN
M9F\N<&AP````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,3<V(#$P-3$U-#,T,34R(#`R,C,T,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]T:&5M97,O<&]S=&YU:V4O:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q
M.3HS,SHS-R!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")0
M;W-T;G5K92(I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]P;W-T;G5K92]S8W)E96XN8W-S````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S4Q-R`Q,#4Q-30S
M-#$U,B`P,C(V-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+W!O<W1N=6ME
M+W-C<F5E;BYC<W,L=B`Q+C@N-BXR(#(P,#4O,3`O,3@@,3$Z,S0Z,C`@:F%N
M($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C8C%B-SAB.PH@
M("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",V-C8V.3D["B`@("!S8W)O;&QB
M87(M87)R;W<M8V]L;W(Z("-D9&1D9F8["GT*:'1M;"!["B`@("!S8W)O;&QB
M87(M8F%S92UC;VQO<CH@(S8V-C8Y.3L*("`@('-C<F]L;&)A<BUA<G)O=RUC
M;VQO<CH@(V1D9CL*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PH@("`@9F]N="UF
M86UI;'DZ($=E;F5V82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@
M(&9O;G0M<VEZ93H@,3)P>#L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B!B;'5E
M.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PH@("`@9F]N="UF86UI
M;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M<V5R:68["B`@("!F;VYT+7-I
M>F4Z(#$Q<'@["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z(&)L=64[
M"B`@("!B86-K9W)O=6YD.B`C8C%B-SAB.PI]"BYH96%D97(@>PH@("`@8F%C
M:V=R;W5N9#H@(V(Q8C<X8CL*("`@(&9O;G0M<VEZ93H@,3=P>#L*?0HN;&EG
M:'0@>PH@("`@8V]L;W(Z('=H:71E.PH@("`@9F]N="UF86UI;'DZ($=E;F5V
M82Q!<FEA;"Q(96QV971I8V$L<V%N<RUS97)I9CL*("`@(&9O;G0M<VEZ93H@
M,3)P>#L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B
M86-K9W)O=6YD.B`C8C%B-SAB.PI]"BYC;VYT<F]L('L*("`@(&-O;&]R.B!B
M;&%C:SL*("`@(&)A8VMG<F]U;F0Z("-D.61C8S(["GT*+FET96T@>PH@("`@
M8V]L;W(Z(&)L86-K.PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*?0HN8G5T
M=&]N('L*("`@(&-O;&]R.B!W:&ET93L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M(",P,#`P,#`["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED("-",4(W
M.$(["B`@("!B;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(T(Q0C<X0CL*("`@
M(&)O<F1E<BUT;W`Z('1H:6X@<V]L:60@(SDY.3EC8SL*("`@(&)O<F1E<BUL
M969T.B!T:&EN('-O;&ED(",Y.3DY8V,["B`@("!F;VYT+7-I>F4Z(#$Q<'@[
M"B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82Q(96QV971I8V$L<V%N<RUS97)I
M9CL*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V)B8V)F
M9CL*?0HN=&5X="!["B`@("!C;VQO<CH@8FQA8VL["B`@("!B86-K9W)O=6YD
M+6-O;&]R.B!W:&ET93L*?0HO*B!!;'1E<FYA=&EN9R!S='EL97,N(&ET96TP
M+"!I=&5M,2!A<F4@9&5P<F5C871E9"X@*B\*+G)O=T5V96XL("YI=&5M,"![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9CEF.68Y.PI]"BYR;W=/9&0L("YI
M=&5M,2!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C93EE.64Y.PI]"BYF:7AE
M9"!["B`@("!F;VYT+7-I>F4Z(#$S<'@["B`@("!F;VYT+69A;6EL>3H@;6]N
M;W-P86-E+"!F:7AE9#L*?0IT9"!["B`@("!F;VYT+7-I>F4Z(#$R<'@["B`@
M("!F;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E
M<FEF.PI]"G1H('L*("`@(&9O;G0M<VEZ93H@,3)P>#L*("`@(&9O;G0M9F%M
M:6QY.B!'96YE=F$L07)I86PL2&5L=F5T:6-A+'-A;G,M<V5R:68["GT*"B\J
M($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@
M(&)A8VMG<F]U;F0Z("-B,6(W.&(["GT*(VUE;G4@82!["B`@("!C;VQO<CH@
M(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(V)F
M8C<X8CL*?0H*+RH@4VED96)A<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(T(Q0C<X0CL*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O;'5C8FQU92]I;F9O+G!H<```````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,#`@,3`U,34T,S0Q-3(@
M,#(R,3`W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]L=6-B;'5E
M+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S8@;61J=6MI8R!%
M>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B3&]Y;VQA($)L=64B*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+VQU8V)L=64O<V-R965N+F-S<P``````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`U,S$S(#$P-3$U-#,T,34R(#`R,C0T-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O*BH*("H@
M)$AO<F1E.B!H;W)D92]T:&5M97,O;'5C8FQU92]S8W)E96XN8W-S+'8@,2XQ
M,"XV+C0@,C`P-2\Q,"\Q."`Q,3HS-#HR,"!J86X@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!F;VYT+69A;6EL>3H@5F5R
M9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.PH@
M("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-#-$,T0C@["B`@("!S8W)O;&QB
M87(M:&EG:&QI9VAT+6-O;&]R.B`C939E-D1#.PH@("`@<V-R;VQL8F%R+6%R
M<F]W+6-O;&]R.B`C,#`P.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M
M8V]L;W(Z("-#-$,T0C@["B`@("!S8W)O;&QB87(M:&EG:&QI9VAT+6-O;&]R
M.B`C939E-D1#.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C,#`P.PI]
M"F$@>PH@("`@8V]L;W(Z(",P,T,["GT*82P@82YF:7AE9"!["B`@("!C;VQO
M<CH@(S,S.3L*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0II;G!U
M="!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA;"P@
M2&5L=F5T:6-A+"!S86YS+7-E<FEF.PH@("`@8F%C:V=R;W5N9#H@(V8W9C=E
M93L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-C8["GT*=&5X=&%R96$@>PH@
M("`@8V]L;W(Z(",S,S,["B`@("!B86-K9W)O=6YD.B`C9C=F-V5E.PH@("`@
M8F]R9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IS96QE8W0L;W!T:6]N('L*("`@
M(&-O;&]R.B`C,S,S,S,S.PH@("`@8F%C:V=R;W5N9#H@(V8W9C=E93L*?0HN
M:&5A9&5R('L*("`@(&-O;&]R.B`C,#-C.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",P,V,["GT*+FAE861E<F)O>"!["B`@("!B;W)D97(M8V]L
M;W(Z(",P,V,["GT*+FAE861E<F)O>"`N:&5A9&5R('L*("`@(&UA<F=I;BUL
M969T.B`M,7!X.PH@("`@;6%R9VEN+7)I9VAT.B`M,7!X.PH@("`@8F]R9&5R
M+6QE9G0Z(&YO;F4["B`@("!B;W)D97(M<FEG:'0Z(&YO;F4["GT*82YH96%D
M97(Z:&]V97(@>PH@("`@8V]L;W(Z(",P-F8["GT*82YS;6%L;&AE861E<CIH
M;W9E<B!["B`@("!C;VQO<CH@(S`V9CL*?0IA+FAE861E<B!["B`@("!B;W)D
M97(M8F]T=&]M.B!N;VYE.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E;G0[
M"GT*+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R96YT
M.PI]"BYS;6%L;&AE861E<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&9O;G0M
M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N
M="US:7IE.B`Q,7!X.PH@("`@9F]N="UW96EG:'0Z(&YO<FUA;#L*?0HN8V]N
M=')O;"!["B`@("!B86-K9W)O=6YD.B`C1#A$.$,Q.PI]"BYI=&5M('L*("`@
M(&)A8VMG<F]U;F0Z("-E965E938["GT*+RH@06QT97)N871I;F<@<W1Y;&5S
M+B!I=&5M,"P@:71E;3$@87)E(&1E<')E8V%T960N("HO"BYR;W=%=F5N+"`N
M:71E;3`@>PH@("`@8F%C:V=R;W5N9#H@(V8Y9CEF.3L*?0HN<F]W3V1D+"`N
M:71E;3$@>PH@("`@8F%C:V=R;W5N9#H@(V4Y93EE.3L*?0HN8G5T=&]N('L*
M("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@(V8Y9CEF.#L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L
M:60@(T,T0S1".#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C0S1#-$(X
M.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*+G-E;&5C=&5D('L*
M("`@(&)A8VMG<F]U;F0Z("-#-D0S9F8["GT*+FEN4')O9W)E<W,@>PH@("`@
M8F%C:V=R;W5N9#H@(S`P,S-C8SL*?0H*+RH@365N=2!S='EL97,N("HO"B-M
M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V4V939D
M8SL*("`@(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C.#`X,#=!.PI]"B-M
M96YU(&@Q('L*("`@(&-O;&]R.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L
M;W(Z(",P,#`["B`@("!B;W)D97(Z(&YO;F4["GT*(VUE;G4@82YC=7)R96YT
M('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V,P8S!B.#L*
M("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R
M+7)I9VAT.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O<F1E<BUL969T.B`Q<'@@
M<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@<&%D9&EN9SH@,G!X.PH@("`@+6UO>BUB;W)D97(M<F%D:75S.B`U<'@[
M"GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PIB;V1Y+G-I9&5B87(@>PH@("`@
M8F%C:V=R;W5N9#H@(V8Y9CEF,SL*?0HC<VED96)A<E!A;F5L('L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED(",X,#@P-V$["B`@("!B;W)D97(M8F]T
M=&]M.B`Q<'@@<V]L:60@(S@P.#`W83L*("`@(&)A8VMG<F]U;F0Z("-E-F4V
M9&,["GT*(W-I9&5B87)086YE;"!A('L*("`@(&)O<F1E<CH@,7!X('-O;&ED
M("-E-F4V9&,["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I;F<M
M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&)A
M8VMG<F]U;F0Z("-E-F4V9&,["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C,#-C
M.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S.B`S<'@["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG
M:'0Z(#%P>#L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H
M:6-S````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q-3(@,#(Q,S(T`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]L=6,O:6YF;RYP:'``````````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#$V-R`Q,#4Q-30S-#$U,B`P,C$R-3,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VQU8R]I;F9O+G!H<"QV(#$N
M,2`R,#`T+S$P+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE
M;65?;F%M92`](%\H(DQO>6]L82(I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C
M+W-C<F5E;BYC<W,`````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#<V-C(@,3`U,34T,S0Q-3(@,#(Q-C`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W1H96UE<R]L=6,O<V-R965N+F-S<RQV(#$N,3`N-BXX(#(P,#4O,3$O
M,#(@,3DZ,S(Z-#@@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O
M=6YD.B`C9F9F.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L($=E;F5V82P@
M07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@('-C<F]L;&)A<BUB
M87-E+6-O;&]R.B`C8S1C-&(X.PH@("`@<V-R;VQL8F%R+6AI9VAL:6=H="UC
M;VQO<CH@(V4V939D8SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`P
M,#L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C8S1C-&(X
M.PH@("`@<V-R;VQL8F%R+6AI9VAL:6=H="UC;VQO<CH@(V4V939D8SL*("`@
M('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S`P,#L*?0HN<V5L96-T960@>PH@
M("`@8F%C:V=R;W5N9#H@(V,V9#-F9CL*?0IA+"!A+F9I>&5D('L*("`@(&-O
M;&]R.B`C,S,Y.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH
M96%D97(@>PH@("`@8V]L;W(Z("-F.3`["B`@("!B;W)D97(M8F]T=&]M.B`Q
M<'@@<V]L:60@(V8Y,#L*?0HN:&5A9&5R8F]X('L*("`@(&)O<F1E<BUC;VQO
M<CH@(V8Y,#L*?0HN:&5A9&5R8F]X("YH96%D97(@>PH@("`@;6%R9VEN+6QE
M9G0Z("TQ<'@["B`@("!M87)G:6XM<FEG:'0Z("TQ<'@["B`@("!B;W)D97(M
M;&5F=#H@;F]N93L*("`@(&)O<F1E<BUR:6=H=#H@;F]N93L*?0IA+FAE861E
M<CIH;W9E<B!["B`@("!C;VQO<CH@(V9C,#L*?0IA+FAE861E<B!["B`@("!B
M;W)D97(M8F]T=&]M.B!N;VYE.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E
M;G0["GT*+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E
M<B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z('1R86YS<&%R
M96YT.PH@("`@9F]N="UF86UI;'DZ(%9E<F1A;F$L2&5L=F5T:6-A+'-A;G,M
M<V5R:68["B`@("!F;VYT+7-I>F4Z(#$Q<'@["B`@("!F;VYT+7=E:6=H=#H@
M;F]R;6%L.PI]"F$N<VUA;&QH96%D97(L("YS;6%L;&AE861E<B!A('L*("`@
M(&-O;&]R.B`C9CDP.PI]"F$N<VUA;&QH96%D97(Z:&]V97(L("YS;6%L;&AE
M861E<B!A.FAO=F5R('L*("`@(&-O;&]R.B`C9F,P.PI]"BYC;VYT<F]L('L*
M("`@(&)A8VMG<F]U;F0Z("-D.&0X8S$["GT*+FET96T@>PH@("`@8F%C:V=R
M;W5N9#H@(V5E965E-CL*?0H*+RH@1F]R;2!S='EL97,N("HO"FEN<'5T('L*
M("`@(&9O;G0M9F%M:6QY.B!697)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV
M971I8V$L('-A;G,M<V5R:68["B`@("!B86-K9W)O=6YD.B`C9C=F-V5E.PH@
M("`@8F]R9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IT97AT87)E82!["B`@("!C
M;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F-V8W964["B`@("!B;W)D
M97(Z(#%P>"!S;VQI9"`C-C8V.PI]"FEN<'5T.F9O8W5S+"!T97AT87)E83IF
M;V-U<R!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R.B`Q<'@@
M<V]L:60@(V8Y,#L*?0IS96QE8W0L;W!T:6]N('L*("`@(&-O;&]R.B`C,S,S
M.PH@("`@8F%C:V=R;W5N9#H@(V8W9C=E93L*?0HN8G5T=&]N('L*("`@(&-O
M;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@(V8Y9CEF.#L*("`@(&)O<F1E
M<BUB;W1T;VTZ(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+7)I9VAT.B`Q
M<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(V,T
M8S1B.#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C8S1C-&(X.PH@("`@
M+6UO>BUB;W)D97(M<F%D:75S.B`U<'@["GT*+F)U='1O;CIH;W9E<B!["B`@
M("!C;VQO<CH@(V8Y,#L*?0H*+RH@06QT97)N871I;F<@<W1Y;&5S+B!I=&5M
M,"P@:71E;3$@87)E(&1E<')E8V%T960N("HO"BYR;W=%=F5N+"`N:71E;3`@
M>PH@("`@8F%C:V=R;W5N9#H@(V5E93L*?0HN<F]W3V1D+"`N:71E;3$@>PH@
M("`@8F%C:V=R;W5N9#H@(V9F9CL*?0H*+RH@365N=2!S='EL97,N("HO"B-M
M96YU('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(V4V939D
M8SL*("`@(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C.#`X,#=!.PI]"B-M
M96YU(&@Q('L*("`@(&-O;&]R.B`C,#`P.PI]"B-M96YU(&$@>PH@("`@8V]L
M;W(Z(",P,#`["B`@("!B;W)D97(Z(&YO;F4["GT*(VUE;G4@83IH;W9E<B![
M"B`@("!C;VQO<CH@(S`P,#L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C9F9F.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V9F9CL*("`@
M(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S<V-3L*("`@(&)O<F1E<BUT;W`Z
M(#%P>"!S;VQI9"`C-S8U.PH@("`@<&%D9&EN9SH@,G!X.PI]"B-M96YU(&$N
M8W5R<F5N="!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z("-C
M,&,P8C@["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*("`@
M(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED("-F9F8["B`@("!B;W)D97(M;&5F
M=#H@,7!X('-O;&ED(",W-C4["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@
M(S<V-3L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N
M("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L
M:60@(V4Y93EE.3L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C93EE
M.64Y.PH@("`@8F%C:V=R;W5N9#H@(V8V9C9F-CL*?0HC<VED96)A<E!A;F5L
M('-P86XN=&]G9VQE+"`C<VED96)A<E!A;F5L(&$@>PH@("`@<&%D9&EN9RUL
M969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E8F%R
M4&%N96P@<W!A;BYT;V=G;&4@>PH@("`@8F]R9&5R.B`Q<'@@;F]N92!T<F%N
M<W!A<F5N=#L*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@8F]R9&5R.B`Q<'@@
M<V]L:60@(V8V9C9F-CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@
M8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PH@("`@8F]R
M9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N
M93L*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X.PI]
M"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T('L*("`@(&)A8VMG<F]U;F0Z
M("-F9F8@=7)L*")G<F%P:&EC<R]T86)?8F]T=&]M+F=I9B(I(')E<&5A="UX
M(&)O='1O;3L*("`@(&9O;G0M<VEZ93H@,3%P>#L*?0HN=&%B<V5T(&QI('L*
M("`@(&UA<F=I;CH@,#L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O
M=&%B7W)I9VAT+F=I9B(I(&YO+7)E<&5A="!R:6=H="!T;W`["GT*+G1A8G-E
M="!L:2!A+"`N=&%B<V5T(&QI(&$Z:&]V97(@>PH@("`@8F%C:V=R;W5N9#H@
M=7)L*")G<F%P:&EC<R]T86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T
M;W`["B`@("!M87)G:6XZ(#`["B`@("!P861D:6YG.B`S<'@@,35P>#L*("`@
M(&-O;&]R.B`C-S8U.PH@("`@8F]R9&5R.B!N;VYE.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED(",W-C4["GT*+G1A8G-E="!L:2!A.FAO=F5R('L*
M("`@(&-O;&]R.B`C,S,S.PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC
M<R]T86)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T;W`["GT*+G1A8G-E
M="!L:2YA8W1I=F5486(@>PH@("`@8F%C:V=R;W5N9#H@=7)L*")G<F%P:&EC
M<R]C=7)R96YT5&%B7W)I9VAT+F=I9B(I(&YO+7)E<&5A="!R:6=H="!T;W`[
M"GT*+G1A8G-E="!L:2YA8W1I=F5486(@82!["B`@("!C;VQO<CH@(S,S,SL*
M("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O8W5R<F5N=%1A8E]L969T
M+F=I9B(I(&YO+7)E<&5A="!L969T('1O<#L*("`@(&)O<F1E<BUB;W1T;VTZ
M(#%P>"!S;VQI9"`C9F9F.PI]"BYT86)S970@;&DN86-T:79E5&%B(&$Z:&]V
M97(@>PH@("`@8V]L;W(Z(",Y.3D["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+V-U<G)E;G1486)?;&5F="YG:68B*2!N;RUR97!E870@;&5F="!T
M;W`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V9F9CL*?0H`````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+W1A8E]B;W1T;VTN9VEF````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,#$@,3`U,34T,S0Q-3$@,#(T
M,C$T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y810``0"$(`#=X]7;X=/^_O[R].[FZ>#:X-+\_/SU]_+Y^??J[>3@
MY-;EZ-[N\>KM\.GO\NOBY=KX^/;W]_7S]?#I[./Z^OC[^_OK[N=W9E7CYMOD
MY]W]_?WL[^CAY-GQ\^[@X]CHZ^(L`````!0``0``!0;@)8YD688`.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+VQU8R]G<F%P:&EC<R]T86)?<FEG:'0N9VEF````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R-C0V(#$P-3$U-#,T,34Q(#`R-#`T-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6&0`98`
MQ```U="ZMZZ(TLRUV=3!XM[0Z>;;_?W\WMK)UM&[U]*]\_+LZ^C>[.K@]_;S
M\.[G[NSCY^38^OKXR<*FU,^XS<>MT,JRR\2IP+B7Y>+4W-C&V-._S\FPSLBN
MRL.G_/S[[^WE(?D$```````L`````)`!E@``!?]@((YD:9YHJJYLZ[YP+,]T
M;=]XKN^P)$"&H'!(+!J/R*1RR6PZG]"H=$JM6J_8K/;IB2@(@@L@&"F;S^BT
M>LUNN]_PN'Q.K]OO^+Q^S^_[XPT*#@L'$@@&#8F*BXR-CH^0D9*3E)66EYB9
MFIN<G9Z?H*&BE0H*#!`$`Q<8I:VNK["QLK.TM;:WN+FZN[R]OK_`P<+#Q,6Y
M#@\+&`<9'10.T-'2T]35UM?8V=K;W-W>W^#AXN/DY>;GZ.G;'\FHS&$/\?+S
M]/7V]_CY^OO\_?[_``,*'$BPH,&#"!,J[+>@P+(,`Q`$8$"QHL6+&#-JW,BQ
MH\>/($.*'$FRI,F3*%/_JES)LN7'!0L@/!R@(0#,FSASZMS)LZ?/GT"#"AU*
MM*C1HTB3*EW*M*G3IT,+N,N@(4&``EBS:MW*M:O7KV##BAU+MJS9LVC3JEW+
MMJW;MW#CDI5)`&("B1#RZMW+MZ_?OX`#"QY,N+#APX@3*U[,N+'CQY`C2RZ,
M@0"SNQ,"$-C,N;/GSZ!#BQY-NK3ITZA3JU[-NK7KU[!CRYY-&S4S#0`$"`AP
MH+?OW\"#"Q].O+CQX\B3*U_.O+GSY]"C2Y].O;IUY!D@:IA0H<*&``/"BQ]/
MOKSY\^C3JU_/OKW[]_#CRY]/O[[]^_CSZV^O`0%W#A10$$`"!!9HX($()JC@
M_X(,-NC@@Q!&*.&$%%9HX8489JCAAAQV^"`"_@FP`046=!``B"BFJ.**++;H
MXHLPQBCCC#36:..-..:HXXX\]NCCCT#.",`$`E0`8`<F`J#DDDPVZ>234$8I
MY9145FGEE5AFJ>667';IY9=@ABGFF%5.0&0%)'8@00!DMNGFFW#&*>><=-9I
M)YEF%IGFFG?VZ>>?@`8JZ*"$,IDGFB7R6>BBC#;JZ*.0QGGHGFQ&:NFEF&:J
MJ:"3)EKIIJ"&*NJHI$+9J9J?EJKJJJRV"NBIBKHJZZRTUKHEK*G:JNNNO,J*
M:Z_`!BOLIK\.:^RQR`9:;++,-NOLF,L^*^VTU$H9;?^UV&;[[+7:=NMML-Q^
M*^ZXOIY)*;GHILMJN.JVZRZD[+XK[[S*FNLIO?CF^ZJ]J.KK[[]RQ@OPP`1C
M*7#!""?LY,$*-XPPPPY'_"_$$E=,+\469]PNQAIW/"[''H>L+<@BESPMR2:G
MS"S**K<\+,LNQ\PKS#+73"O--N>\+K^QZNSSRSSG^O/0N^),]-&7&HWTTHXJ
MS?33A#H-]=1_2DWUU75:C?76<&K-]=?0!@WVV$V+3?;949N-]MI5J\WVVUF[
M#??<7<M-]]UAZWDOWGSGC6B_?0?^I=>"OTUXX6L?COC9BB\^=N..?PUYY%M/
M3OG5EE\^=>::/\UYYTM_#OK_T:*//G3IION,>NHYK\YZS:Z_'G/LLK=,>^TI
MWXY[R;KO'G+OOG<,?/`9#T]\Q<8?'W'RRC?,?/,)/P]]P=)//W#UUD]L=_9D
M8\]]OMY_?_'VXG,=?OGOGH_^QN2O3[7Z[J,+?_P?MT\_T_/?[VW^^H]L?_]$
MXQ\`JR7``9[L?P;460$3Z*P%,G!E"'R@S!PHP6-1L()`TQO@,'BZ"'(P=Q[\
M(.]"*,+?D;"$PCLA"HNGPA4BKX4N7!X,8^B\&=(P>C:\(?5RJ,/K\;"'VM-@
MSX`HL@L2<55&/&*IDJC$43&QB:%Z(A2)]<,IIJ^*5F2?$(6618=)L8N6^B(8
MX87%(S'6;XMFE)@8T\BH-;*Q4&Y\XZ#B*,=ZH;&.#RLC'@D8M!```#L`````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R87!H:6-S+W1A8E]L
M969T+F=I9@``````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U-C0@,3`U
M,34T,S0Q-3(@,#(S-C4W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y80D`E@#$``"WKHCO[>7@W,SLZN#Q[^GGY-C7
MTKS5T+K;UL3]_?WT\^WHY=OV]?+X]_3Q[^CKZ-[<V,;MZ^+9U<'P[N?N[./Z
M^??CW]#8T[_%OI_'P*/?V\N\M)#N[.3EXM3LZ>#3SK<A^00``````"P`````
M"0"6```%\6`B/D:V`8`(88C7B`GT.7!5/1AM-PQS2#N&8IA95'@*@F.R42"5
M'`J`)R0$*)%I3S&A##R`K37R>(2KY,4BG`P\"AT+8#@9%"P"S=S!>70T$!(`
M!!,1"Q:!%X,!`PL"$!<&BW8""`:25I26F(P%E9>3GINAGYR:H)FBJ)VEI*.I
MK;"OK+.GIJJWL;2KMJZ\N+ZYM<"RO[J]Q<+&P\?$N\K0P=+)T\_5R-;4VMG<
MV-[.W\WBS.3+YM';X>7HW>#NX^?7[^OR\.SJ\>GS^>WV]?3Z_`4$V(\@OGO[
M$`HLR._@OX8)'RHT&'$@Q(4.+4Z\%`(`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VQU8R]G<F%P:&EC<R]C=7)R96YT5&%B7W)I9VAT
M+F=I9@```````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#$S(#$P-3$U-#,T,34R(#`R
M-30P,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6&0`98`Q```_____O[^_?W\]/+M^?GW\O'J=V95\O'K^OKX]_;R
M]O7Q^/?UV-+(KZ27D8-TY>'5Z.;:[^WF^?CVZNC>[>KB]?3OY^/8]O7P_?W]
M\?#I_/SZ\.[GZ^G?P+BN@'!?R\.V(?D$```````L`````)`!E@``!?^@(8YD
M:9YHJJYLZ[YP+,]T;=]XKN^OYS0/@'!(+!J/R*1RR6PZG]"H=$JM6J_8K';[
M#`@D%$;#T0EPS^BT>LUNN]]PKE=2B4#$G;A^S^_[_X"!1'-U'!`?#@R"BXR-
MCH^0:X01AA`-#9&9FIN<G7^3AA:(GJ2EIJ>H2:`0=QZIK["QLI]?A1`6%@8!
MN[R]OK_`P<+#Q,7&Q\C)RLO,S<[/T-'2T]3%&!H2`Y00#P\&`N#AXN/DY>;G
MZ.GJZ^SM[N_P\?+S]/7V]_CYZAH$"=H3W+P1&$BPH,&#"!,J7,BPH<.'$"-*
MG$BQHL6+&#-JW,C1X8(+!2C<ZF8@@<F3*%/_JES)LJ7+ES!CRIQ)LZ;-FSAS
MZMS)LZ?/GS`57#BPP5`W;P.2*EW*M*G3IU"C2IU*M:K5JUBS:MW*M:O7KV##
MBIUZ@"@%@$<-%%C+MJW;MW#CRIU+MZ[=NWCSZMW+MZ_?OX`#"QY,V&Z&"&<#
M>BO,N+'CQY`C2YY,N3+A#!L0A\)EH*SGSZ!#BQY-NK3ITZA3JU[-NK7KU[!C
MRYY-N[;MU`4.4Z@$P<#8W\"#"Q].O+CQX\A_']!-8;<!!="C2Y].O;KUZ]BS
M:]_.O;OW[^##BQ]/OKSY\^C3:[]PH<*`W)DC&%A`O[[]^_CSZ]_/O[___P`&
M*."`!!9HX($()JC@_X(,-OB?2>T-X)D!'55HX8489JCAAAQVZ&&%$BR0`'3L
M&8#`B2BFJ.**++;HXHLPQBCCC#36:..-..:HXXX\]NCCCT#2.)`$1$KPC3Y(
M)JGDDDPVZ>234$:)I`94HJA+-5AFJ>667';IY9=@AHDE!F26:<`L:*:IYIIG
MG,GFFW#&*><0;LYIYYUXEE)GGGSVZ2<@>_XIZ*"$MEGHH8@F&D6@BC;J:**,
M/BKII'Q&2NFEF+)I:::<=IK*IIZ&*JHFH(YJZJF!E(KJJJR^H6JKL,:ZQ:NR
MUFKKHK?FJFL5M.[JZZZ]_BILK<$.:RRKQ1ZK[*C)+NLLI\T^*^VDT4YKK?^B
MU5ZK+:'9;NMMG]U^*ZZ=X8YK[IOEGJLNFNFNZ^XK[;XKKY[SUIMGO/;F"PF^
M^O:["+_^!NP'P`(7'`?!!B?,!L(*-VRHPQ"3&O'$^U)L,2,,7ZPQ$QEO[/$1
M'7\LLA`AC_QQR29OC'+*%Z_,,L4NOQQQS#([3'/-"M^,L\$Z[RQPSS[["W30
M^@Y-M+U&'SUOTDJ_RW33ZSX-];E23SUNU59_BW76VV[-];5>?SUMV&(_2W;9
MRYZ-]K%JKSULVV[_"G?<P-*]\]QVWXIWWL3R+?/>?L,*>.#($I[RX(:?BGCB
MS#(N\N*.>PIYY-!2KK+E&D^..:6:;RYIYYX["GJ(Z-B2/K/I$(^.>J&JKSYH
MZZ[_"7OLX-+.L^T%SX[[G;KO/F?OOL<)?/#H$E^T\?D.CWR:RB\_2_/.QP)]
M]/!2[[3U[DZ/O2G:;T]*]]YW`G[XFXQ/?B;FGU^Q^MZFSWXC[K__K_S:QD\_
MH/=;:W_^?>S/_Q[^^]_!!.BL`!+0#08\X,(4R+80```[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O;'5C+V=R
M87!H:6-S+V-U<G)E;G1486)?;&5F="YG:68`````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`U,S<@,3`U,34T,S0Q-3(@,#(U,C(R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y80D`E@#$``#___]W9E7^
M_O[]_?SZ^OCY^??]_?W\_/KY^/;X]_7U]._V]?'T\NWR\>OV]?#W]O*[LZK=
MV=7IYN/U]/.!<6&8BW_AW=F8BWZZL:>3A7CAWMG'P+CR\>JNI)J3A7?&O[@A
M^00``````"P`````"0"6```%W"`@:EA%!8'X95`TB<#62;!H>70-8)`N7A$?
M@/+RI81'@&"Y##`-AH$T$!T<"(1"(2"](A*)1P!;0#P<"L:XG$`W&NNO@]'@
MC+.)15I]+3_T"@$'?5\+"UQ660A?5%%765M058,'3DN24R),3$DZG36?,*$B
MHP"EIT*FJ:A(JZZML$:OLK&>L[:UH+>ZN:*[OKVDO\+!JL6LM,FXRKS,P,[$
MT,;2R,O6S=?/V=';T]W5V.':XMSDWN;@X^KEZ^?MZ>SQ[O+P\_;U^,/W^OG'
M_/_^`E(#.%#@-X+=0@``.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O9W)A<&AI
M8W,`````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,34Q(#`R,C8T,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M8V%M;W5F;&%G92]I;F9O+G!H<```````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`R,#(@,3`U,34T,S0Q-3$@,#(R-38P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+W1H96UE<R]C86UO=69L86=E+VEN9F\N<&AP+'8@,2XQ
M(#(P,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M
M95]N86UE(#T@7R@B0V%M;W5F;&%G92(I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-A;6]U9FQA9V4O
M<V-R965N+F-S<P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,C`T(#$P-3$U-#,T,34Q(#`R,S$Q,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M
M97,O8V%M;W5F;&%G92]S8W)E96XN8W-S+'8@,2XW+C8N,R`R,#`U+S$P+S$X
M(#$Q.C,T.C$S(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N
M9#H@(S%F,F4Q8CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-60U9#8P
M.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C-60U9#8P.PI]"FAT;6P@
M>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S8W)O
M;&QB87(M87)R;W<M8V]L;W(Z(",U9#5D-C`["GT*82!["B`@("!C;VQO<CH@
M(S,S-CL*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S!A,CDQ,CL*?0IA+G=I
M9&=E=#IH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C.3DV.PI]"BYH96%D97(@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,S8S.PI]"BYH
M96%D97(@83IH;W9E<B!["B`@("!C;VQO<CH@(SDY-CL*?0HN:&5A9&5R(&$@
M>PH@("`@8V]L;W(Z(",Y.38["GT*82YH96%D97(Z:&]V97(@>PH@("`@8V]L
M;W(Z(",Y.38["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F%C:V=R;W5N9#H@(S,V,SL*?0HN8V]N=')O;"!["B`@("!B86-K9W)O
M=6YD.B`C8V-A.PI]"F$N8V]N=')O;"!["B`@("!C;VQO<CH@(S!F,#L*?0HN
M:71E;2!["B`@("!B86-K9W)O=6YD.B`C8V-A.PI]"BYB=71T;VX@>PH@("`@
M9F]N="UW96EG:'0Z(&)O;&0["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U
M;F0Z(",Y.38["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C
M;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",Q9C)E,6(@=7)L*")G<F%P
M:&EC<R]M96YU+G!N9R(I.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z("-F9F8[
M"GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",S-C,["GT*
M"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@(&)A
M8VMG<F]U;F0Z(",S-C,["GT*(W-I9&5B87)086YE;"!S<&%N+"`C<VED96)A
M<E!A;F5L(&$@>PH@("`@8V]L;W(Z("-F9F8["GT*(W-I9&5B87)086YE;"!A
M.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PI]"@HO*B!0<F5F97)E;F-E<R!O
M=F5R=FEE=RX@*B\*+G!R969S3W9E<G9I97<@:#(@>PH@("`@8V]L;W(Z("-F
M9F8["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O8V%M;W5F;&%G92]G<F%P:&EC<R]M96YU+G!N9P``````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P-3`@,3`U,34T,S0Q-3$@,#(T,S<P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(```,>````-`0#````]LOSP````!A03%1%'RX;$D0B
M*3TB9VQ`"BD2____________;XZ+^`````EP2%ES````2````$@`1LEK/@``
M#[9)1$%4>-JEG&V"LKP.AHNZ`#JZ@!%=``H+0.G^UW3H1Y([:7%\WM-?(Y8V
MR96/4NJX$*;41G\)P6_-.7><IF$8;E-ISZ&T>Z#VCA^WGM1ENV^[$&_OMZLG
M[A?6A\LM#A_":^MQ"?#U-#U\NBU]3&/EOKVC=M+]MPZ';:[SQ&W<.AU(QDWL
M/&)JI=>(8VS3S%F#K$^>10:@-HT'&9,,L?7LS-0@Y%)T33//-)LU([2KSY;C
M.1UU=Z1"GK')8TBCYWF&-'ON\/#"(P)I\B@7O%>622B)1[+VU&T?-W"[/++M
M_-0$<B-Q4LM?SZ%N;_:O8L,:QS9L&93G&GZC=3P`82D=`.G*].)".SRNY)W"
M@Q4B':)C^O.[R2-?$JT6DFB3X*?P\$6TTHJ?=[YA%,&1Q5HGL&:31TBR6AY9
M`_F@<-@)9U'__B$\)IYIL]IV5Y+MD'DT@00)-N*1M.*>=00.D"SRA:B%<VJ0
MQ,-O/%I@*W];69YMNM\N#X`6R+ZWPT,2BT3V`^0`16'"I!C:Q+9/.+8K;\R_
MKAT>4<WH[#\11\H]DIXX\!02S%BB5[^PQ[1P@%6(1V]XI(2E>+P_\*!PSSSR
M("?S??S&MWB\.`Q.$ME[/-8\+^OR@<=#2H?.53GI#,!C:8?'+9'<OMS"OM2"
ME4WOO9D<P]CP\!RV-8^KJJ71REOX3;[!8S-"L;U6(,FI$TA0/)RIUTFG9#Y]
M-3<R^8DLGB>[$H\!>*S9N$3CQ_B(!4(&BWK>.;:T,OL\;GFRI1@E1QF;WML`
M&2V/#H`PM%9XH%4V('?G'A6/WO"8=1R/)H-PPBH\C,T+CVN#Q\OD([#6]8?R
M*7VO4LU5+4I:1$CV1!!X*(/<=](5)[J:!U?:*D!.D"^01_$,6:P!#FVLPJ/_
M@T?0HKI//$[!MJ7X7H/'8LJUL18!D=AAU]"+Q+S,F-L\WHK'\R\>-R!)/,K2
M=273HYG_*X\KE$W@L>SQ<.];F\=H>2S`HY&3/O`8-8^UM2*DV:9//(9BO_4/
M'A;XG86G*[(<2@B6FL?H.&CV>;B:!Z1$Z*#L\1Y"Y.%;]<,=Q%,^\X#XN/]?
M/*8//&B5(L[U\R6/X0./8'G<90S@,2&/B2QU_I('=SD(C<\\>C5$;WDH)2(/
MG92^XW&MUU>K6I<$_S!.3]+'#K1*R3HE@YB$-;=PE.!N\[B#]'G<6VCQ.&L>
M_.1\UCSP`002UIF[G*+!J8//7J6]=`BQ?I2(T.'AGE.+QZWBP>EJTPDAP9\Y
MP^SQ*#WSY"T>+HZ!23C+:@)D9GNI;#(#CU6IHKTI7CE/&&/$XTQPV!YVY51X
M9&B6QP0\,("&:GTE/'H8P=4\GIJ'#H^QP6/!9=.TQX,>KP"'-O*05FR;(HYY
MN'RMLUVW`,F&?%@[*!ZBR1U%+2X[M7B<^8,8Y&$#)-U_G,7'F,<9NN",/T-K
M@;64L.@!1[[C..WP*#A8;.$1!J4C84M.??75`\A*-\</+]\&\DN#DU+E4A5+
M-TV##?%L\R`<P"-N$U8\W)D_J&R8L[SA(7]*MD$SM7@HJPRZ\C"M?1Z^/VE7
MD0T<3%;)@AP&SYSQJ_"8I!"*"#]-'D>:ZS!`O3*%#5>9Q`.-+YJ`,$0CW8!F
M3XJ2R6>M\Y1W-8P-T#U)EEF6916/JP4"/!2G!3?G#`\5'"(!)+&7Y3'EC2WZ
M*.&1;SY!>%B_=XJ'Q&*\]-9`KCKO>A']-AL>J.]2[JG"X((\)KM8&,%+4MRV
M>5P"/$<"CXYY@)LN!^)A7/<#CTO%HWI`[(L%V0J42%[1!Y]%;_`L#(\H2X.'
M#L4FC\$LW$7P6UDLN7)!^V7N3U'`NCTT#]L,CT,4]8@N(PDGC:BS#_+P8O6I
M+-XN7_.XA)K':'9@^V)!Y%$R>XR5FX6I>800WI;'$2.1>83!`E&V$+EO5`S*
MLM8D!,EN,^3BAZ\UW>>19#VBRW1BZP8/#SQ(DCQ2(SPVR8\X]^$SC^FD;GX1
MCPEY)"#G9*-*K]-+X<``0:TUCD\\RHX?EY9LZ85?9^B<\/+JQ97B8:J&<23V
MVFPAIT)83+T6=V1_[3SRH.O,PX:'X8$[+YC[N>F;J7P8'A.GD-K/[(J"`^07
ME(8=^!T>5_AVJ\]/X.&R7R(/#)#S+H]=(`T>,1!1`K+T6AY9@'^#Q_HU#UG)
M7)LR[O&8O^0!ZZ)+S:.(,GIX99C7"Y:'++U.6RP<!^&1'II<69+YFL=4\S!Y
MI,%CJ'@,MU&[!(WP4#/R,K)(<C(\+(Y<6?XKCRQ,W&YI\1@&74!&'1Y%Y`:/
MJ)(*D&E^?\?C5AZ._RL/DPU:/&H)4FOS>+5Y3/L\W"Z/RY\\EL+C2#Q6QA'3
M0H.'>FP(*D"`1]))\]B/CZ@"9]DI\UCV>9P_\F@'2"M?R>,KA;#B(4=L-`\T
M:BM?F>45;!7[9I%KA(>3!>_*UMST?FH>SQT>%"%8/^(@6#Z^Y7&;\I[;MSS8
M?_C[5H",+1X&QY%Y>-5ZJF2H]+K+8W&&!P?(U;>>/X!'W$WK6![@42:V/(:;
M,SL$%Q#CH)>[8`='9\3:/%)RHG)>;HJ.TC5YO&3S\;_R&!O)2E;\ZT.IF/.'
MY;$<=W@LSO*@%=:5U-`"SB!V-*\#LY1HHHF?Q4#,X]?R\$H,4<UFBGBI&/S^
M_L3C5NZ(/#QK@5H[S8,>8"\-'G;;#@U4T6#++#6.FH?/];5^'JP-H)\Z]WBL
MQ5:2Y2D=</L9+(_!I*L8S:<*1Q6O*3R*P>^ZW)2)>7M+I.^\XB'@CUJ3-?,`
MDT`F:/.8#(RCLHQ2L6_PN/".$0UTTN$A$P4S7[IYC<:P/*B?N`'G`Z2!/)Y\
M1"C?@0*KUMET<9R(QPWVI9#'0<)C)%=J\5A06='D<6GPF.&EU`<>AF^0-XJR
M)!E0%"].ZX(!HD?$?3_6RB>/O,FLT3]7P\/KYQ\O^X0R8+09\>A)P5$I5AS[
M/-7M"7211Q=-N<AD62D6P4B'Y0GLKU+X"M^W>8S(PWAJ,5M2@;V-UD<E0%["
M(ZCDLB@><X!C%<`C)0B2LCP'W/9X!!T>@XP7>>0SC5E.ZVLR8(L'1MN3>'1E
M7EE<S9#"ZW*N'GW#3D,>RC_EUOWP6(K9=#]>()GF.%5#>"@>08W3B:??BYB@
M^]CD\5+AD3B.-FA=8Y\J7A@IU'=XW/2'+EOZ#>PQ1NMRKA9O?_"`<E_Q@`!!
MVRULMK/J=QIV@`@/+*-')2#.UX&C%]G>BD>'/-YW"1#F$1@OR-3RM?CWP__-
MXPS!\M`;]IS#*42-LZB=B,<>C\`6WE8/"8ZW/";+0^%PSNM^;Q%1,_F&ASAT
M-#?C*++-H+SA\2X;D"_D$>]Z((_\)@E4&T&(TJ'!XRD$SEA,9L!Q8Y_W*E]#
MNOH''OE(9TA>TC=YG#C_93>0J.E4/\5#R24\G*0KLUX+P!]YY`"1H9,E@748
M^%TI1-4][A\H'ILX/5H:>#P+L0\\.B_O.I+50,]MK*+"C_%$JN:8KKH_>22E
MUXG725;HP,]UH?`8Z,%$]3L-IK5XG(0'IL!]'O?TS5/QP-A[9V8E0O`NKWE<
M&\>3%0_\-93A4=YU/#D>P/5N$Z]3WB8Q%+&$1RP^7_,H"ARMT+$O\%CI/`QT
MS3S,WO2UQ0/^_,0#"D$2[4>TQ_,=%0_JM_%8U2J\<O\&C]L>#UY^%9>8S<LL
MX*'R=!&K%Q[#Y/=P+,#C+A7]J.2AR;AS//QS(#EJ;G_FJXV:62($J1^XX/V1
M0A!7U)]YW+F""(\@>RJ'AK5=S:,%)-L\U:N^=13[%WD$C>-":11XW'9Y./+Y
M=_G)7JMM<UT@F/*U0Q%$T(U4JD,+A^)AEP@[/"X!'&4;0=*5V<<$'B$6P)SK
M[E"G2HQ\P:,!)%TNRX<&CU^G>*@S$X6'%QYQHJNF4%69$/(1L[7)8W3R>E;S
M&#"21I:)$^OU2QZ8KN`!!+-J7!D=BOYM'B5A]26V:`DLD_JA]0JWXE'_R@-=
MZ[B[V<O2OFRZ4@OI)_@.\"-9E3UV>'04=:#)H1)]A)"MPZ/)(]_(.VJKYG$Q
M.*@*_'J#PP_`@XI/X%.,--[9FOJQP\-$2-YT9AY/RZ,W/#!`+DR'>$@NU;TO
MV9>B+'@2O\6C?L.K?O7+/'B8=QT>D<<*6>+((\GCM5,\Y.=\*5E)5>Z\;_*X
M*QZS.57:^>J5.NVY61XF0-06:5_QN'K+`P)$X*A@&^0H/*!+/J?.D3=YP!O%
MU]'P`-'Q=-1''E/>-=5!M6675_:A4?-`PQWRJ)>LQ,/P&"`:(H\WA(PO2U6C
ME^?]DV&71Y[VRCRFBH<OBY0Z0/J*A]"\U\5&UCL?$Q;PR'$WRL.!!`@*]*;$
M*ID>>3SYKO+_#&+_4(0>E5`0';R7G^0@@T9;H\]1\9F+$/=XR=.C-::B!QGA
M:'Z:97O]?.3ARQXEJ,]6/E4\]+VZUM0\V@$"KTS2R%$1XB&^A(<'B4?.=I8'
MV`7#B9*L$FI2YZ$&^BEUT2]KT*'+$0]^7BL_=LG&0$N3A=,+>&TGTPMCO2H@
MGH#4&:L/ED>=[#[S8!>>"<ZMXI$:\V`-P3]>*=/_YB+161Y/T;@J-V"((@_*
MV?W0F_77F=*=U)4!?S<I/.YI#_S\D4<P/*3;XRL>I;S9`#E5/`;;$$=?\Z``
MF0E.>CWW;SPVY\@O')Q*"\Q#;E/5)JM\-CP0Q^;U5Z]X3(;'L,N#9J[2U39\
M_'W+/_#01BT.LB0Q=("<@N5AP\,\$C1XK(*C;!I]R6/D/A/Q..8O_HF'`!&]
M@(?_FL=9>+Q:/![^*Q[>\G#&J,+C,.@`Z4/%H\*!/.!!(!@@\O<SRO8%CT?/
MKK&IFE^0'C$O?,M#G\%08;SQH)]>*1ZPB0D\Z%1ABH\S>2=;NI??E1YGW!LL
MTN7_ZS*1LGZ/1Q8HGNT^X&/%UO&$I>1/'KUK\TA6D^25X^-B"E7%XZ&[."?Y
M2GB$'1YO)=H1`F0Q?O/#]5SQ8&M"_?"*ARU<^`*E/U8G="./`,+CONA1=Q5S
M:AZNQ6,W7S&-K/`)@2@>4]XMJGCH0P,>CO+DX87'V.3Q*SDIO'Y0,]ZAG-._
M65&.D[M=Z%&E\+@T>=#5>W"E-_C/Z(!';:<;'[`HW@=9Y=#V[RP<&[$G)U<\
M(I([G',N6HN"-%I00&:L)>75Y`Z/&PG=XN$,CQ5XQ"_%*C\0N"3YZ*HF*IPI
MZVPC2/:7/1E/NUK;1?I':^)`(RK?V+.=#`]H]`ORV5@DJ2P!XNRI,$C#*L/$
MK[(XV?T:0-::ASG"(3RX,C9YQ-SCA`?_8QTYP=15"O?[.-@UF4=T+8__]@MX
M_`@/E2QXZ#+AN>+Q._$OW6H>Q0O92=47^$OL-@]92>2YSJ1KH/_2T(@025?D
MX1?+XX=&*Y^IPPMY;$#H3=[_``)SUGS+K<_M`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]S:6UP;&5X+V=R87!H:6-S````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$U,2`P,C(R,C$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O:6YF;RYP:'``````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<U(#$P-3$U-#,T,34Q
M(#`R,C$T-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<VEM<&QE
M>"]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,W(&UD:G5K:6,@
M17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(E-I;7!L97@B*3L*"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]S:6UP;&5X+W-C<F5E;BYC<W,`````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C$U-2`Q,#4Q-30S-#$U,2`P,C(T-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+RHJ"B`J
M("1(;W)D93H@:&]R9&4O=&AE;65S+W-I;7!L97@O<V-R965N+F-S<RQV(#$N
M."XV+C0@,C`P-2\Q,"\Q."`Q,3HS-#HR,2!J86X@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z("-E964@=7)L*&=R87!H:6-S+V)A8VMG<F]U
M;F0N<&YG*3L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-S,Y,&(Y.PI]
M"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",W,SDP8CD["GT*
M82!["B`@("!C;VQO<CH@(S-C-V%E.3L*?0IA.FAO=F5R('L*("`@(&-O;&]R
M.B`C,6(U-V,R.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"BYH
M96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-S,Y
M,&(Y.PI]"BYH96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0HN;&EG:'0@
M>PH@("`@8V]L;W(Z(",T935D-S(["GT*+G-M86QL:&5A9&5R('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S<S.3!B.3L*?0HN:71E;2![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C96-E9F8T.PI]"BYB=71T;VX@>PH@
M("`@8V]L;W(Z(",S8S=A93D["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9&1D
M.PH@("`@8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('!A9&1I;F<Z(#`@
M,G!X.PI]"BYB=71T;VXZ:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B
M86-K9W)O=6YD+6-O;&]R.B`C.3DY.PI]"G-E;&5C="!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C-SA!-$8Q.PH@("`@8V]L;W(Z("-E964["GT*"B\J($UE
M;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A
M8VMG<F]U;F0Z(",W,SDP8CD["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F
M9CL*?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S4X83)D
M8SL*?0HC;65N=2!A.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z(",U.&$R9&,[
M"GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J+PHC<VED96)A<E!A;F5L('L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z("-E964["B`@("!B;W)D97(M<FEG:'0Z(#%P
M>"!S;VQI9"`C.3DY.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",Y
M.3D["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+W-I;7!L97@O9W)A<&AI
M8W,O8F%C:V=R;W5N9"YP;F<`````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,30S
M(#$P-3$U-#,T,34Q(#`R-3$R,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12`````@````0(````
M`(&$L>4````)<$A9<P```$@```!(`$;):SX````5241!5`C78WCVC.'I4X8W
M;QC>O0,`*VL'2XNJ#HT`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]B;'5E=VAI=&4O:6YF;RYP:'``````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(P-2`Q,#4Q-30S-#$U
M,2`P,C(T-3``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)L=65W
M:&ET92]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P+S$W(#$Y.C,S.C,T(&UD:G5K
M:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`](%\H(D)L=64@86YD(%=H:71E
M(BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O8FQU97=H:71E+W-C<F5E;BYC<W,`````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#4U,C<@,3`U,34T,S0Q-3$@,#(S,#$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]B;'5E=VAI=&4O<V-R965N+F-S<RQV
M(#$N,3@N-BXY(#(P,#4O,3$O,#(@,3DZ,S(Z,S@@:F%N($5X<"`D"B`J+PH*
M8F]D>2!["B`@("!F;VYT+69A;6EL>3H@5F5R9&%N82P@1V5N979A+"!!<FEA
M;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.PH@("`@8F%C:V=R;W5N9#H@(V9F
M9CL*?0IA('L*("`@(&-O;&]R.B`C,S,Y.PI]"BYH96%D97)B;W@@>PH@("`@
M8F]R9&5R+6-O;&]R.B`C-C9A.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O
M=6YD.B`C0S9$,T9&.PI]"BYH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["B`@
M("!B86-K9W)O=6YD.B`C-C9A.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",P,#`["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C9F9F.PI]"BYH
M96%D97(@83IH;W9E<BP@82YH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z('EE
M;&QO=SL*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*?0IA+FAE861E<B![
M"B`@("!B;W)D97(M8F]T=&]M.B`P.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P
M87)E;G0["GT*82YF:7AE9"!["B`@("!C;VQO<CH@(S,S.3L*?0HN;&EG:'0@
M>PH@("`@8V]L;W(Z(",S,S,["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R
M.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@(&9O;G0M9F%M:6QY
M.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PI]"F$N<VUA;&QH96%D
M97(Z:&]V97(@>PH@("`@8V]L;W(Z("-C8V4["B`@("!T97AT+61E8V]R871I
M;VXZ(&YO;F4["GT*+F-O;G1R;VP@>PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*
M?0HN=VED9V5T('L*("`@(&-O;&]R.B`C,C(T.PI]"@HO*B!&;W)M('-T>6QE
M<RX@*B\*:6YP=70L('-E;&5C="P@=&5X=&%R96$@>PH@("`@9F]N="UF86UI
M;'DZ($=E;F5V82P@07)I86PL($AE;'9E=&EC82P@<V%N<RUS97)I9CL*("`@
M(&9O;G0M<VEZ93H@,3)P>#L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R
M;W5N9#H@(V8S9C-F.3L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-CD["GT*
M:6YP=70Z9F]C=7,L('1E>'1A<F5A.F9O8W5S('L*("`@(&)A8VMG<F]U;F0Z
M("-F9F8["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C.3EF.PI]"BYB=71T;VXL
M("YB=71T;VXZ9F]C=7,@>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O
M=6YD.B`C,S,Y.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",S,S,[
M"B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R
M+6QE9G0Z(#%P>"!S;VQI9"`C0S1#-$(X.PH@("`@8F]R9&5R+71O<#H@,7!X
M('-O;&ED("-#-$,T0C@["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P>#L*
M?0HN8G5T=&]N.FAO=F5R('L*("`@(&)A8VMG<F]U;F0Z(",V-F$["GT*"B\J
M($%L=&5R;F%T:6YG('-T>6QE<RX@:71E;3`L(&ET96TQ(&%R92!D97!R96-A
M=&5D+B`J+PHN<F]W179E;BP@+FET96TP('L*("`@(&)A8VMG<F]U;F0Z("-E
M964["GT*+G)O=T]D9"P@+FET96TQ('L*("`@(&)A8VMG<F]U;F0Z("-F9F8[
M"GT*"B\J(%9A<FEO=7,@<&]P=7`@86YD('-T871U<R!L87EE<G,N("HO"BYT
M;V]L=&EP+"!D:78N;FEC971I=&QE('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F%C:V=R;W5N9#H@(S8V83L*("`@(&)O<F1E<CH@,G!X(&1O=6)L92`C9F9F
M.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F
M9F8["B`@("!B86-K9W)O=6YD.B`C-C9A.PH@("`@8F]R9&5R+6)O='1O;3H@
M,G!X('-O;&ED(",P,#`["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*
M?0HC;65N=2!A+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S,S.3L*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(V%A8SL*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L
M:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PH@("`@
M<&%D9&EN9SH@,G!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*8F]D>2YS
M:61E8F%R('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*(W-I9&5B87)086YE
M;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`V.PH@("`@8F]R
M9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#8["B`@("!B86-K9W)O=6YD.B`C
M93EE.69F.PI]"B-S:61E8F%R4&%N96P@<W!A;BYT;V=G;&4L("-S:61E8F%R
M4&%N96P@82!["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I;F<M
M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!S<&%N+G1O9V=L92!["B`@
M("!B;W)D97(Z(#%P>"!N;VYE('1R86YS<&%R96YT.PI]"B-S:61E8F%R4&%N
M96P@82!["B`@("!C;VQO<CH@(S`P-CL*("`@(&)O<F1E<CH@,7!X('-O;&ED
M("-E.64Y9F8["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@(&-O;&]R
M.B`C,#`V.PH@("`@8F%C:V=R;W5N9#H@(V-C8SL*("`@(&)O<F1E<CH@,7!X
M('-O;&ED(",P,#`["B`@("!T97AT+61E8V]R871I;VXZ(&YO;F4["GT*(V5X
M<&%N9$)U='1O;B!["B`@("!M87)G:6XM<FEG:'0Z(#%P>#L*?0H*+RH@5&%B
M('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!B86-K9W)O=6YD.B!N;VYE.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",V-F$["GT*+G1A8G-E="!L
M:2!A('L*("`@(&)O<F1E<CH@,7!X('-O;&ED(",V-F$["B`@("!B;W)D97(M
M8F]T=&]M+6-O;&]R.B`C93EE.64Y.PI]"BYT86)S970@;&DN86-T:79E5&%B
M(&$@>PH@("`@8F%C:V=R;W5N9#H@(S8V83L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",V-F$["GT*+G1A8G-E="!L
M:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C-C9A.PH@
M("`@8V]L;W(Z("-F9F8["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]H:2UC;VYT
M<F%S="]I;F9O+G!H<```````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`T-R`Q,#4Q-30S-#$U,2`P,C(W,3<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B1T:&5M95]N86UE(#T@
M7R@B2&DM0V]N=')A<W0B*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:&DM8V]N=')A<W0O<V-R965N
M+F-S<P``````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R,34@,3`U
M,34T,S0Q-3$@,#(S,C0T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````&)O9'D@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F
M9F9F9CL*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@("`@
M<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C8V9C9F)B.PI]"FAT;6P@>PH@("`@
M<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M
M87)R;W<M8V]L;W(Z("-C9F-F8F(["GT*82!["B`@("!C;VQO<CH@(S`P,#`P
M,#L*?0IA.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PI]"F$N=VED9V5T
M.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V9F9F9F9CL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C,#`P,#`P
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F9F9F9CL*?0HN<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C9F9F9F9F.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-F9F9F9F8["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9F
M9F9F9CL*?0HN8G5T=&]N('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",P,#`P
M,#`["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",R,C0["B`@("!B
M;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(S(R-#L*("`@(&)O<F1E<BUT;W`Z
M('1H:6X@<V]L:60@(V-F8V9B8CL*("`@(&)O<F1E<BUL969T.B!T:&EN('-O
M;&ED("-D961E8F(["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-E-F4V9&4["GT*+FET96TQ('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z
M("-E-F4V9&4["GT*"B\J($UE;G4@<W1Y;&5S+B`J+PHC;65N=2!["B`@("!C
M;VQO<CH@(S`P,#`P,#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F9F9F8[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HC;65N=2!A
M('L*("`@(&1I<W!L87DZ(&)L;V-K.PH@("`@=VAI=&4M<W!A8V4Z('!R93L*
M("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF
M.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@=&5X="UD96-O<F%T:6]N.B!N
M;VYE.PH@("`@8V]L;W(Z(",P,#`P,#`["B`@("!P861D:6YG.B`S<'@["B`@
M("`M;6]Z+6)O<F1E<BUR861I=7,Z(#-P>#L*?0HC;65N=2!A.FAO=F5R('L*
M("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",V-F$["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C-C9A.PH@
M("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",R,C0["B`@("!B;W)D97(M;&5F
M=#H@,7!X('-O;&ED(",R,C0["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@
M82YC=7)R96YT('L*("`@(&-O;&]R.B`C,#`P,#`P.PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V%E865A93L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C965E.PH@("`@8F]R9&5R+7)I9VAT.B`Q<'@@<V]L:60@(V5E93L*("`@
M(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z
M(#%P>"!S;VQI9"`C,#`P.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I
M9&5B87)086YE;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#`["B`@("!B86-K
M9W)O=6YD+6-O;&]R.B`C9F9F9F9F.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+W!R:6YT+W-C<F5E;BYC<W,`````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S,Q(#$P-3$U-#,T
M,34Q(#`R,C$T,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O<')I;G0O<V-R
M965N+F-S<RQV(#$N,2XQ,"XT(#(P,#8O,#,O,30@,C(Z-#,Z-3`@:F%N($5X
M<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8V]L
M;W(Z(",P,#`["GT*82!["B`@("!C;VQO<CH@(S`P,#L*?0H*(VUE;G4@>PH@
M("`@9&ES<&QA>3H@;F]N93L*?0H*+FAE861E<F)O>"!["B`@("!B;W)D97(Z
M(&YO;F4["GT*+G-E;&5C=&5D('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*
M+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0HN:&5A9&5R('L*("`@(&-O
M;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*?0HN<VUA;&QH96%D
M97(@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B86-K9W)O=6YD.B`C9F9F.PI]
M"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*?0HN:71E;3`L("YI=&5M,2!["B`@
M("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED("-C8V,["GT*+G-I9VYA='5R92P@+G-I9VYA='5R92UF:7AE9"!["B`@
M("!C;VQO<CH@(S`P,#L*?0HN=&]G9VQE<75O=&4@>PH@("`@9&ES<&QA>3H@
M;F]N93L*?0HN<75O=&5D,2P@+G%U;W1E9#(L("YQ=6]T960S+"`N<75O=&5D
M-"P@+G%U;W1E9#4@>PH@("`@8V]L;W(Z(",P,#`["B`@("!B;W)D97(M;&5F
M="UC;VQO<CH@(S`P,#L*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,30V(#`R,38T,``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM90``````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#8@,#(Q-#<S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:P``````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-R`P
M,C$V,S<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,`````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,34P(#`R,C(P,``@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-3`@,#(R-3,W`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4`````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$U,"`P,C(P,#8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%L97)T<P``````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,34P(#`R,C`S,0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4`````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-3$@,#(Q-C(R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$U,2`P,C$T-S<`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VYA=@``````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,34Q(#`R,3,R-``@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V%L96YD87(N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#0@,3`U,34T,S0Q-3$@
M,#(S,#<S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!
M``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@`
M`!=ODE_%1@```P!03%1%````_______X___[R\K`J:B@E92-P+^WDY*,FYJ4
MJJBAM[6NMK2M_?KPE)*,F):1_/COOKNTN[BQTL[&R<6^TL['_[A&F9:1JTU!
M]UI,PU!(^/CX\?'Q[.SLX.#@U-34P\/#H:&AB(B(>7EY8V-C3DY.-S<W,C(R
M&1D9____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````?5K91P```"IT4DY3____________________
M__________________________________\`,JCP7`````EP2%ES```+$P``
M"Q,!`)J<&````'A)1$%4*,^-C]D.@E`,1#LR[EL5B]>Z(,IU^?\?5#`\0$QT
M'N;AY&32RK,3^0-(*V_P.!?%Y5J6,<;;O0("X`B<@!Q:@P.Y(,=53SY&DJR!
MH>I468.]V=9LY^[6;S9FO;EG66@9'D)HC.Z&INF`7)*CS4J^7?KKN1<(>A;F
MO_S1]@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]T86)?8F]T=&]M+F=I9@``````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`T-2`Q,#4Q-30S-#$U,2`P,C,T,S<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#=A%``!`(`!`````/__
M_RP`````%``!```"!(2/F04`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<')E9G,N
M<&YG````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`V,38@
M,3`U,34T,S0Q-3$@,#(R-#0W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````
M*"T/4P```(I03%1%``4`'1T='R<O*2DI,#`P,3$Q-C8V24=&4%!/4E)235]S
M;&EG:VII<G!M9GF/<(*5=(JBBH>$>(VD?8R<?)&G?9&G?YFSC9FEA)ZYA)ZZ
MI*&<L;&QR,?&RLC!TM#,TM'0T]+/U=33S];=UM75V-C8V]K7WMO6W][<X^+A
MZ^OH[.OJ]_?W^?CX````W9?-&0````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P($AT'.Y6_U@```'U)
M1$%4>-IMCED2@C`0!8/@%O<%<4>C@*!]_^M)-D'+^<CT5+U*/R'^#3_`R</!
M0VF`.R[&2U,7>Y_AF6LD<OG+H\CV!&'CJ"<=$'R+Z=.^Z'$<-6UF:HW@MO`E
M5FJYZ=2[FEAMHN9;:;37L5DJWDD;)AWJ-YY*/K\[1[O`&R75#F;W^[4?````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUA<"YP;F<`````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-C$Q(#$P-3$U-#,T,34Q
M(#`R,C$P,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q4
M161D6__\S:BFB-K8M,/!HLW+K/_ZO?STJ)R8=*^KBK:RD7AV8_ONCMG0BI"+
M9_;C?,_'F?/>=/?GG?_3-_;/2?K85^2N&N2V.\B6'M2C*=VN-:M]%KZ-'%P_
M)4]/3P```(J'Y#`````@=%).4___________________________________
M______\`7%P;[0````%B2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX`
M``"6241!5"C/3<_9$H,@#`70J[((1:D4ZX(-__^797-:'AC.369($,OA?N/U
MA7)/:R=/_@N>:]<)=_`[*!;"[KP&R<,,@.S%<E#JPTA$9@DLHO8S$,@8'QA\
MM@/4!&N75\`FA9",'L9,R>\/].F$5#0;4ZP1]>'DF(+J_*W>;4]S<QE,78LM
M5O?H*OBUN2VG0G+_MVU*FN,7&=\3QXR&$]\`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]O<F=A;FEZ:6YG+G!N9P``````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3$V-R`Q,#4Q-30S-#$U,2`P,C,U,#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3```!+%!,5$4````)"0D,"PH.
M#@X3$A$3$Q,7%Q<8&!@;&QL>'AXB(B)$1$15555?7U]T:TQM;6UN;FYU=75V
M=G:"=U5Y>7E_?W^#@7B&A'N)AGZ(B(B-C8V4DHN3DY.6E(RAE7";FYN<G)RC
MGY>NH'2PHGBVIW6JJ)^HJ*BZJ72KJ:&KJZNLK*RQK:2^KWVTL*BTLJJWM[?<
MO'3`P,#$P+C$P;G)Q;W&QL;+Q[_JR'O+R\O=S9C2S\C4T<S4TLS5TLS8UM#6
MUM;8U]'<W-SSWIKTWYWUXJ3AX>'VXZ?WY*SDY.3FYN+FYN;IZ>;IZ>GJZ>?K
MZNGKZNKM[.CO[NWQ\>[R\>[Q\?'R\O+T\_+T]/+T]//T]/3U]//U]?7W]_3W
M]_?X^/C\_/S]_?W^_O[___\```!3;<,5`````7123E,`0.;89@````%B2T=$
M`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01-C#MT;'.
M````Q$E$051XVDV/UU;"4!1$`T&J-*4J2$?I12!*D1)Z$>D=#//__\"]`1;,
MXU[[G#7#,-<`S'V`:>H.`0=!V%6#9P16#F1G_\+Q6'XAY.&SHDE;D-H?NE_4
M0*ZS8/\R5C02@/L1#/+KI6K2B[%`T$0-96F[4ZN>/D`3,A+C9[&:#P<>N-HP
MB#]>"[^C<=&*-XX<F2FQ1>(!ITP7Y:"]]`"D>/8VB>'00P1AW[O_N\[!?BF/
M38OG:P1<MZ#/T205MVD2L84HG`"_;3.Y4*=/<0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L;V=I;BYP;F<`````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<V,B`Q,#4Q-30S-#$U,2`P,C(T
M-#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$4A(2'J
MU,OCQ;K;M*3NWM?Z]_7RY>'2K)D```"-GGS-V<+>YM?:XM&;K8FWDX)P?6.T
MQJ*LP)AC;E>KBGKDZ=UE<5C$GXW#T;6`CW!,5$)88T[FZ^#4W<G*U[Z0H7]?
M:E-37$GI[>1A;5:HO)5\BVY,5$.VPJI>:5/_________________________
M____________________________________________________________
M__________\7Y'27````0'123E/_________________________________
M__________________________________________________\`PGNQ1```
M``%B2T=$/SYC,'4````)<$A9<P```$@```!(`$;):SX```!_241!5"C/;8])
M$L(P#`0G$:#!`8-,V/?]&?K_KS@X5)D4?9KJ4P^\!XH)E`*H:@$*,1B.:NT$
M,Y6H(HMQ:"93BDC,PCF;6Z*(+@!W)]M@RT31%1Q.MF%MF^V.,0(.[@]'L].9
M%W8=O)K9C4Y^2]G<'T^6Z7PE_G[ANR><?]]F/N/K*`TPEY7S`````$E%3D2N
M0F""``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;&AA;F0N<&YG````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`T,30@,3`U,34T,S0Q-3$@,#(R-#$R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````A````#@0#````4S!HOP```!A03%1%____P,#`O[^_@("```#_
M``"`````````6NUX4P````)T4DY3_P#EMS!*`````6)+1T0&86:X?0````EP
M2%ES````2````$@`1LEK/@```'])1$%4*%-=ST$*Q2`,!-#@"73CNJ20"Q0\
M@=Y`]];"W/\(C4W;_^EL(H^!&`J?>+()S;\`1.3V5R*XJY#H"U!!=^)D:`G(
M.7N*Y-;!0Y;9,F'1KI5,`O8026:)D\FUK#LPKZF4<LN$@[=4:[TE8I%C`UIK
MC]"$$'_R7&$__,2?("HD[6LFQX8`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W-Q;"YP;F<`````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#$R(#$P-3$U-#,T,34Q(#`R,C$Q-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``
M^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q41?SI._OG._SK/?G?
M.?;2-F59,$]!%6Q?-%M0+5Q/*V%4+O*V3>^T3?>U1/>U1?2R1->N=````/__
M_P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'I#\!L````3
M=%).4________________________P"R?=P(````"7!(67,```L3```+$P$`
MFIP8````54E$050HSW6/6PK`,`@$[?O==/;^A^U')#&%BN`ZZ(JF3UA1T`*Z
M@PCHKST"[%[B"D-:"::,YT:Y`N*9P.\8B!F4TP$1R(<KJ-T/<$GK(;(3Q&]S
M>0'V#!$%YH6,:P````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8V]N9FEG+G!N9P``````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W-C$@,3`U,34T,S0Q-3$@,#(R
M-3<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!``"Q
MCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=O
MDE_%1@```P!03%1%````____[^_OW]_?P\/#OKZ^&QL;____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````2M?+&@````AT4DY3_________P#>@[U9````"7!(
M67,```L2```+$@'2W7[\````1TE$050HSVV/`0K`,`@#K\ZN___Q+&U!TP44
M/()&AHC5674`;0(C@U`!%G+2CG;F#8(XHP)3((Y7''3SO)1'SOX$D^C7<UD?
MNUX%)VP->?0`````245.1*Y"8((```````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<&5R;7,N<&YG````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S,@,3`U,34T,S0Q
M-3$@,#(R-#4Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%BWU*;V0[7E4R[M:`\O+R[>WMW]_?VMK:SL[.
MR,C(PL+"O[^_M+2TJZNKDY.3:VMK45%12$A(0$!`(2$A!P<'`0$!````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````^)IS*P```!AT4DY3________________
M______________\`S1,NZ@````EP2%ES```+$P``"Q,!`)J<&````&%)1$%4
M*,^5SL$2@C`,1=%H?8BV2A&][___U`4,UNZXRS.9).&N,&L[<$[IE#6S0XI(
M:*C;9`!7GEK+$+!<))5MPF%N4\GEM\.,C\_[17-VNFN8&S!5E>8Q&^&CD'N@
M@[^^`Z03U,.I)L\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A>BYP;F<`````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#(V-R`Q,#4Q-30S-#$U,2`P,C$W-#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````D````)`@,```"=_^Z#````"5!,5$6Z`!9F9F8```",M<Q"`````712
M3E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'
M=$E-10?4#!01-AFO8RFB````)TE$051XVF-@`($&!@;&"0P,3`L8&-B6,#!P
MK6!@D%K)P*"U"BP+`$YG!*?ZOMDG`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=6YL
M;V-K960N<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R
M,34@,3`U,34T,S0Q-3$@,#(S,3,P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````0````$`@#
M````*"T/4P```.=03%1%````!`,"!00#"`@("PL'&A,+%A86%Q<7+RDA+BXN
M34U-@5HK<G)RJF\KI'$VK'$NK7,RH'=$HWM+A(2$I'Y.J(%,M'X^IX)2IX)3
MN(`^JH15JX=8K(=8NH1"JXA8NH9'O(=&O(A)NHE+KXU>K8UDO(I,L(U?O8Q.
MI9%VOHU0QI9=QYMDJ*.>RI]HJJJJRZ1QSJ1PS:9NS:9VT*9TS*=[T*ATSZM\
ML;&QSZQ[S:R#SJV#U*QYU:Y^TK*)U;*$V+6,O+R\UKJ4P<#`VKZ:X,*>X<*<
MX,2@W\2CX<2@XL6AX\:BV]O;````A$]HZ@````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$BXBGC7F
MA@```(QT15AT0V]M;65N=`!-96YU+7-I>F5D(&EC;VX*/3T]/3T]/3T]/0H*
M*&,I(#(P,#,@2F%K=6(@)VII;6UA8R<@4W1E:6YE<BP@"FAT='`Z+R]J:6UM
M86,N;75S:6-H86QL+F-Z"@IC<F5A=&5D('=I=&@@=&AE($=)35`L"FAT='`Z
M+R]W=W<N9VEM<"YO<F=GBL='````ATE$051XVF-@P`%\?'S0!+P=>)A1!-BY
MS(71=''JH>EB<_)!&,C"R,C$H<,*Y6NXN;L[.SL[&G%#E/AXVNO*B(M+""GR
M0P6\;-3LS,PL]!5XH0(>QMI2(B(B@K(P%:X&*K:6EE8FD@)0`1=K0V5I:3E1
M!3&H@*F6IJ:2DKJJ/)\/W!U0@,W;`.H0%TQJ<R;C`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O:&ED95]P86YE;"YP;F<`````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`W-#4@,3`U,34T,S0Q-3$@,#(S-#(S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```,!03%1%````4E)24U-355555E965U=76%A865E9
M6EI:6UM;7%Q<75U=>'*0>721>G21>G63@'UTB'^CK*F]Q<'2RL;6S\_/T-#0
MTM+2T]/3U-34U=75UM;6U]?7V-C8V=G9VMK:V]O;W-S<W=W=WM[>X.#@X>'A
MXN+BX^/CY.3DY>7EYN;FY^?GZ.CHZ>GIZNKJZ^OK[.SL[>WM[N[N[^_O\._S
M\/#P\?'Q\O+R\_/S]//V]/3T]O;V]_;X]_?W____````9%3[K@````%T4DY3
M`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)
M344'U`P($APLCC)WUP```)Y)1$%4>-I%SML6@4`4@.%(!Y640:$B10H5413M
M]W\KTV3-_)??6OO`<22#QOUA]H_!1-<U79M2:!=+R[;L50\`1CL8XC8.`?@`
MP-IQ/=?;=@!OA!#P/#_:^0$&>*`Y!G\?A$%XZ,#L`D$0)3$ZD1$"QRA.XN3<
M+S7Q4DF6Q_(U96<O:99G^8T]IBBJ>B]*!L6SK,JJ9E"]ZJ9NOA1H/V`'%AOR
M[AYZ`````$E%3D2N0F""````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1E;&5T92US
M;6%L;"YP;F<`````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C0S(#$P
M-3$U-#,T,34Q(#`R,S<P,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````"`````@(`P```//1
M3KD```,`4$Q419D``)EF9LP``,PS,_\``/]F`/^9,\S,S```````````````
M``````````````````````#_____108```````#,^!(`,\K6=WQ:V7>B#]AW
ME`_8=QAOCP`8:X\``0````$````!````H/@2`)SY$@`0^Q(`,-78=_CX$@``
M`!0`4#KY=R0```!(#10````4`.@!%0#0^!(``````.CZ$@!`??IW(#CU=___
M__]0.OEW]WSU=_6(]7<```````!``#B&2``1````!`````,````8:X\`:-MA
M`$#Y$@#K0-1W:-MA`.S___\`````&&N/`!AKCP`@FO5W*9KU=QA@&``D``(`
M4#P5`"SZ$@`P^A(``````',Z^7<@8!@`?HKU=]@'%`#!CO5W/&`8`"A@&```
M````P8[U=P4````H`````````&)>&``````````!````%`#\^!(`>`$4`.3Y
M$@!`??IW.!SU=______!CO5W9I'V=X&1]G?@-?QW=)'V=X!@&`!@8!@`/&`8
M``#@_7_,^1(`!````"CZ$@!`??IWV!7U=_____]TD?9WE)KV=P<````X````
M*&`8``````"P51@`N#@!````%`!T^1(``````'3Z$@!`??IW.!SU=______!
MCO5W+H_G=P``%```````.H_G=Z"\U'<``$```0```!!>&```X/U_``!`````
M````````"`$``"A@&`!$^A(``````+#_$@"&N^EW`(WH=_____\ZC^=W7%=#
M`"A@&`"@O-1W``!``"`````P.D*6<,O#`3`Z0I9PR\,!@*>1Y'$7PP$`````
MB0```"0````@`0``9&5L971E+F=I9@```````!C[$@#H`14````4``3Y$@`$
M^Q(`-/L2`$!]^G<H'/5W______6(]7?3F.=W```4``@`%`#DF.=WH+S4=P``
M``````````````````!$VD0`&`(5`-S;%@`<`A4`;(9(`/_____H`14`GMI$
M`!@"%0!ST$0`Z`$5`,F+PK,````(=%).4_________\`WH.]60````%B2T=$
M_Z4'\L4````)<$A9<P```$@```!(`$;):SX````H241!5!C38V"'`@9V1D80
MS<3`SL["`.(S@'E@)H+!!)5B9H'J@@`6`##)`5S3D!GI`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W!R
M;V)L96TN<&YG````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,S`U(#$P-3$U-#,T,34Q(#`R,C<V,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`$
M`P```.W=XE(````84$Q41?S3RP```-^!9-YU5?*@C=^!9-^!9-^!9&0/M50`
M```!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<
M&`````=T24U%!]0+!1,E!VV";=<````F241!5'C:8V!@8&`48(``(44(S:BD
M)$`T`ZX+"P-N,AQ@V(6F&``$*P,@!$2]U@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]C;VQO<G-C86QE+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0R,B`Q,#4Q-30S
M-#$U,2`P,C,T-30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```&0```#`"`(```!]#5'[````
M!&=!34$``+&/"_QA!0````=T24U%!]((#P<D'X*>ML4````)<$A9<P``"Q(`
M``L2`=+=?OP````L=$58=$-R96%T:6]N(%1I;64`5&AU(#$U($%U9R`R,#`R
M(#$Y.C,T.C4U("LQ,C`PNJ0O=```!FE)1$%4>-KMG>&)'$<4A(6PX002[/W3
M#R<@<`("1R!P`@)'(!R!4`;"$0AG(&<@AR!G((=P"S)(8(.%Q/3\>;=U5:][
MNGMV:ZA?N[-SL]/?O5=3,]MS_UY9KHH>%STI>EKTK.AYT8NBET6OB]X4O2UZ
M5_2^Z$/13='_40^O%OWP>-&/3Q;]]'31S\\6_?)\T:\O%KUZN>BWUXM^?[/H
MC[>+_GRWZ*_WB_[^L.CFYJN^+??O>:$7[F!]1^B*T$-"!T6/BL`&'Q2!'?N^
MZ-2W$PZ6EY,':UJ.UD\!H-:_#H!BOF#^W]#+W0=K-L2NBY@-,CLF(F:R<F1-
MPM%U$-/R<J4J-L$&UL'+2)_UZ+2VZX\UQ<MD3>FS(CZ5/@L`Q>S8G7[=/FMN
MG[4VIN8^2^J/H%':9^W!9ZWCQ@S[=CZKG5]WS3J//*O29X$-,GF6?=9\/@N,
M&S/L:V&JY$C*19UG3>RS5A.<L_+-(].<E;?/VGF>)9T2`I_5ER/7K)X^"YRO
M,^=B/7V6\ZP+R+.`FONL+8N7R1J;9S&EJGEDZNN&^^R&0\J9)/NLG9-U>OG<
M2,>@5EN>Z&"9K`PUGXKB*RLLZQVD\96H(Z$^])FL1F2!XPTX`F4HKLS@$UG[
M%+2^5<D11LQDU9$5CR[#$:`F(K9=S0+T2:S=BIC)VLPZ@!&0^F.L8DS-JJQ0
MZ\?)"N6:M1E9D0CP%L,14\68FA4KE,0:0,S=<'3-RO5'0(3DLX!QEWI?1,PU
M:P.RI'8&UI'0R-4L:1UIY['_,EE#\ZS*D8R,-$'#>=;<>5:NUP!J;@A);3'7
MG9UG39-G28B!QL0D"@Q'.<3`]S)9??,L,$J`&NE,D*E9H&-*B#G/VE6>Q424
M`#I0LT`&FVMY/C<<W0US`2G(&&+F*=4L<'%(\GW.LR;.LUK=T"#YK(@8N`S>
M\#8(DS7T1/IS:S&(@5<8Z.Y\Q62-).NJD0[$KR^D5^)-KHE73-8V9'6@YG#Z
MQSL`'PD6('?#OF2!`R\!M8+P(`C@`Z"+6U[7828(B-^+8LUDU9+%''@P;I&:
M5C4K`L7@`ZA95W;-&NVSP.!45C&I9L6WUNW$XI5KB[<4+Y/5OAM6`@6J3\YG
M16HDH$"I0E7,9&U8LR2@P,J`(ZE1YH!*6GF3E20KQTA<!S#"<!37D?YZ[0F@
MR=I3GB6AD7/Y8)TF8)JL[GF6U'T8-*X)@8PAUZ]=L_J2Q3A="2B&-:9F,><&
M$E#.L_:09P&@#LH%&V"X)(X8H%RSICDWK&R43)HNB<G[G6?M(<^2?,U!N3S#
M^"PF[\]=+G0W')W!2Z4JOL+<HY"K695R-YPO=9#H&R+G6=.1]1\AYB:^?P@=
M@YA/,7^=^18F:TNR*CE:;\<$('PL.J8TB#63U:IF=2A5$F*CBY?)RI'%'&_F
M=PN1&J;EY2;0ZL::R9K29S']$4#W\;3LL\[.9TG%"U2Q2I_5ES63U=-G52+6
MW&<Q^V.?-9_/VJ[E-?=9*[--6#-9$_@L,)*5/LMYUF7G6:L8(HZIW^'G6(O(
MVV?M/,\"/EM"C#DE8/;GWR+[K#WX+*GEY2;08DX2G6==4I[5TV<!EQ?W.18O
M^ZP]^*P<1XS/\G5#^ZRFB$F]3RI>]EF#NN$0UACHF$;)Y%EW>GJ3M3%9IY?S
MGSW+9+4GR[-GF:RF9'GV+)/5E"S/GN6:U=UG7?3L62:K?3?T[%DF:^.:==&S
M9YFL)%F>/<L^:V]YUIG,GF6RNN99%S1[ELEJ1I9GSS)9,^599SM[ELGJ<6Y8
MV2AW.7N6R>J19UWB[%DFJT<&?XFS9YFLP1'-V<Z>9;)&':SM'MC::LLF:SZR
MI`$$3S@]$D]3E7Z\TY4^D]6,+'"\I0<V'T\_>I?!!SSB/#[KO)(CA)C)JB4+
M/!P><`2HD9X)75FS`'T2:[<@9K(VM`Y@!*3^&*L84[,J*]3Z<:I"N69M2%8D
M`KS%<,14,:9FQ0HEL080<S<<7;-R_1$0(?DL8-REWA<1<\W:@"RIG8%U)#1R
M-4M:1]IYY+],UN`\JW(D(R--T'">-7>>E>LU@!II,AJF+>:ZL_.L:?(L"3'0
MF([*3"&`HQQBX'N9K+YY%A@E0(UT)LC4+-`Q)<2<9^TJSV(B2@`=J%D@@\VU
M/)\;CNZ&N8`49`PQ\Y1J%K@X)/D^YUD3YUFM;FB0?%9$#%P&;W8;A,D2EB]E
MY,&3)^6A!@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;7EA8V-O=6YT+G!N9P``````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S-#(@,3`U,34T,S0Q-3$@
M,#(S,S,P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P````1G04U!
M``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@`
M`!=ODE_%1@```P!03%1%(B(C"@P0Q<;(#!`6YNCK)2@L#!`5*"PQ-T96&!XE
M;W^1?(J9EJ&MH*NWN\;216%^36J'4FZ+3FB#77F5"@T09H*>15AK:(2@56R#
M/4U>67"(;8FE6&Z$<XZJ"0L-8'*%?I6L'2(G9&]ZC9FEB9"7U=OAY^KM\O/T
M3F9]9X.>7'2+;XNF159F=9&L4&-U?)6MB9VPBIZPFJR]I[C';WJ$&1T@D9F?
MD)B>R=/;"0T/$A05$Q46#1$2$1$0&!@72TA$$PH`&P\!020%-A\%FU@/RW49
MS'8:R'0:T7H=T'H=T7L>Q74<PG,<TWT?Q70=P7,=#@<`"@4`"`0`-1P"%0L!
M)A0",AL#938'1R8%6S$'-1T$-!P$DT\-+!@$I5P0?$4,*1<$K&`1BDP.>4,,
MM603)A4$'1`#OFH5MF84J5\3+1D%@TD/RG(8S'49S78:S'4:&`X$+A@#0B,%
M-!L$,1H$+QD$.A\%638512\:3#HI&A(,)!X:*28FS,S,1$1$)24E'1T=!@8&
M````____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````KX]Z*P```(1T4DY3____________________
M____________________________________________________________
M____________________________________________________________
M__________________________________\`E](VO@````EP2%ES```+$@``
M"Q(!TMU^_````+Q)1$%4*,]C:`:!)A``LYH90(1MD[U](%0$)-#0:%]7#U1B
M"Q.P<Z@,"4A+=6Z$"3@Z>?OY^[C'!\$$8B,]O'P]\Y*S8`(EF;EN^:XY&:4P
M@3*7].S0PJ24(KBU$3%AB7$1X<$P`9N:\N*HZ(0*3CF(`*N9@4EU016#DHZD
M)4B`G5=65T^EEDF92T)&3*29P<I<7UI;BUM=S5A!55B#@Y'!FD=44UQ*GL7"
M2)5/55"(C<'44``)\#,S**(!`&EU5,O<[92W`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]S:&%D;W<N9VEF````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-C<T-2`Q,#4Q-30S-#$U,2`P,C(V,#<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA(`,@`\0``/___^?G
MY_/S\];6UL+"POO[^[*RLO7U]=O;V_S\_/'Q\>#@X-'1T?KZ^O;V]NKJZMC8
MV.WM[<7%Q>CHZ,G)R?W]_?CX^._O[_[^_K6UM;N[N\3$Q/GY^0``````````
M`"'Y!```````+``````@`R`#``7_("".9&F>:*JN;.N^<"S/=&W?>*[O?.__
MP*!P2"P:CR_%@9/`()_0J'1*K5JOV*QVR^T.`Y=#H^(MF\_HM'K-;KO?941`
M82'#[_B\?L_O^_]W#`L1#@F`AXB)BHN,C8YE%`@/!X:/EI>8F9J;G'@2$!,"
M!9VDI::GJ*FJ)P0#`:*KL;*SM+6V6ZVOH[>\O;Z_P,$CN;#"QL?(R<I_Q+O+
MS]#1TM-(S=37V-G:VR;6W-_@X>*VWN/FY^CIB^7J[>[O\&7L\?3U]O<_\_C[
M_/W^)?K^"1Q($%W`@@@3*HQV<*'#AQ#)N2H6L:+%BZ<:8MS(L:,?C1Y#BAQY
M!B3)DRA3_T(QJ;*ERY<Y6,*<2;,F"IDV<^ITB7.GSY\>>P(=2O2AT*)(D_X[
MJK2ITWA,GTJ=.BXJU:M8KUG-RK4KLJU>PXJ]!7:LV;.HRJ)=RQ:3VK9PXR)Z
M*[>N73QT[^K=BR8OW[^`L?@-3+APM8G.#"M>+`\QX\>0LPR.3+DRB\F6,VL6
M@7FSY\B=/XM6''JT:<"E3ZN^FWJU:[BM7\L^&WNV;:^U;^N^FGNW;Z>]?PLO
M&GRX<9_%CRNOF7RY<YZ.GTMOVWRZ]9#5KVO'F'V[=XC=OXM/&'Z\>8'ESZO?
MEWZ]>WKMW\MO%W^^?7/U[^O_EG^_?VS]_2<@0]$-:"!W!1ZH(/]X"2[H('D-
M/B@A>A%.:"%[%5ZH(7P9;N@A?1U^*")^(8YH(G\EGJ@B@"FNZ"*!NKPHXS8!
MSFCC'C7>J",<.>[HXQH]_BBD&4$.:20N+1ZI9"E%+NFD%$T^*>4144YII1!5
M7JEE#UENZ24.77XIY@QACFFF"V6>J68*::[I)@EMOOEFG'*N26>=9]Z)YYAZ
M[OEEGWYN"6B@5PY*Z)2&'OIDHHHNR6BC1SX*Z9"23OICI9;NB&FF-V[*Z8R>
M?OIBJ**N2&JI)YZ*ZHBJKOIAJZYN"&NL%\Y*ZX2VWOI@KKHNR&NO!_X*[(#"
M#OM?L<;NAVRR]RW+['S./OM>M-*N1VW_M>==B^UXVF[[7;?>;@=NN->-2^YT
MYI[[7+KJ+L=NN\>]"^]P\L[[6[WV[H9OOK?MR^]L_O[[6L`"KT9PP:<=C/!H
M"B_\6<,.;P9QQ)E-3'%E%E\,6I(:S\EQQW9^#'*>(H_,9\DF_XERRH*NS'*A
M+K^,:,PR+TISS8[>C'.D.N],:<\^7PITT)H.372G1A\-:M)*C\ITTZ8^#76J
M4D_-:M56OXIUUK)NS76M7G^-:]AB[TIVV;Z>C7:P:J]-;-MN'PMWW,K.37>S
M=M\-;=YZ3\MWW];^#7BV@@_.;>&&?XMXXN(NSGBYCC^.;N22KTMYY>Y>CGF\
MFF].;^>>WPMZ_^CZCDYZOZ:?#G#JJ@_,>NL&OPY[PK+/SG#MMC^,>^X2[\Y[
MQ;[_CG'PPF\<8_%@'X_\V,HO;W;SSJ<-??1L3T_]V]9?+W?VVM?-??=X?P_^
MWN*/[W?YY@>.?OJ$K\_^X>Z_KWC\\C=.?_V0WX__Y/KO;WG__LL<``/(N0$2
M\',&/*#H$JC`TC&P@:A[(`17)\$)NJZ"%HP=!C-(NPUR\'8>_*#N0BC"WI&P
MA,`[(0J'I\(5&H\B+G1.QF*(CQG2T!XVO"&'6JA#P^2PA^_X(1!!Q,,AHH9X
M1B0.$I,X%"$RD41%?")KEBC%G3BQBN"X(A:YH<4M:J.+7F11%,/(%O\PDG$:
M9CPCC&"H1A"RL8TC?",<32C'.::PCG9D(1[S^,+$\/&.?ORC'@,IR#X64C-I
M/.0O$JG(7C"RD62A(B0W\LA)TJ*2EI0%)C.YBDUR,A6>_&1&)"E*HY"RE`L)
M)2H[H<I5;J*5KLP$+&-YB5G2\A&VO&4C<JG+=9RRE_[@)3#G\LMA8FB,QIR)
M,)/YD6(RLQ[+?":.G"E->$2SFGBA)C:)N,=M8N6:WG0#.,/)AG&24PWF/&=?
MM*E.<:2SG8U!)CPY\LYY<J&>]M0"/O,I&';R,QO[_&<5`BK0*1"TH%$X*$*?
MH-"%4LF?#H5&0R-*A(E2%$L0O6@R+*K1?&3_M*/&X"A(>2#2D>J@I"8%TT=3
MZ@N4LK0&+GTIF58J4XG(LZ;WB"E.7Z#3G;:@ISY=`5"#RB::$E450SUJ-XRJ
MU%'>M*GJ2"I4.</4J;*RJE9])5:S*LNM<K667OTJ+L,JUEV2M:R^?"I:N7C6
MM1)3K6X%:%OCRHRYTK4/4IUJ7J&ZUZ;V5:E_/6I@B3K8H!;6IX?=:6)QNMB:
M-E:FCWUI9%DZV916UJ27'6EF0;K9CG96HY^]:&@I.MJ(EM:AIUUH:A&ZVH*V
M5J"O_6=L^3G;?-;6GK>=9V[AN=MV]E:=OSUG<,DYW'`6UYO'W69RL;G<:C97
MFL]]9G29.=UD5M>8_]<=9G:!N=U>=E>7W[UE>&DYWEB6UY7G765Z4;G>4K97
ME._]9'PY.=],UM>2]YUD?B&YWT;V5Y'_/62`"SE@01;XCP?F8X+SN&`[-GB.
M#X9CA-LX8356^(P7)F.&P[AA+W9XBQ_&8HBK.&(IEOB))V9BBI.X8B.V>(@O
M!F*,>SAC'=;XAC>F88YCN&,7]GB%/T9AD$LX9!$6^8-'YF"2,[AD"S9Y@D^&
M8)0;.&4%5OF`5R9@E@.X9?]U>7]?QE^8ZS=F^97Y?6=F7YK3MV;SM7E\;P9?
MG+LW9^W5^7IWIEZ>H[=GY_5Y>7]&7J"+-VCA%?IWA^9=HG.W:-LU>G:/AO]=
MI%LW:=55^G27)EVF0[=ISW5Z<Y_&7*@K-VK)E?IQIV9<JA.W:L.U>G"O!ERL
M^S9KO=7Z;K>F6Z[CMFNW]7IMOT9;L,LV;+$5^VO'YEJRL[9LJS5[:L^&6K2;
M-FVE5?MHUR9:MH.V;9]U>V??QEFX:S9NF97[9>=F6;I3MFZ3M7MD[P99O#LV
M;XW5^V+WIEB^([9OA_5[8?]&6,`+-G"!%?Q?!^=7PO.U<'LU?%X/AU?$VS5Q
M=57\7!<G5\;#M7%O=7Q;'\=6R*LU<FF5_%DG9U;*D[5R8[5\6"\'5LQ[-7-=
MU?Q6-Z=5SF.U<U?U?%4_1U702S5T417]4T?G5-+_,[5T2S5]4D^'5-0;-75%
M5?U05R=4U@.U=3]U?4]?QU/8ZS1V.97=8W"]*QKMJG8]G-U-;P]9VMLN4;;3
M_0YQ5U/>23;WNRMC[V8"_,GZ[O>OV+WP;1"\F!2O,L(C7AB,]U+D6^;XQP-C
M\EK"/,PJ;_F6'K[SZ^0\Z",I^M'70O-60OW,2F_Z6:A>2J^W&>M;'XO8.\GV
M.9L][9'Z^=TC2?>^=VHW@Q_5WA/_"KA74O)Y!OSC7[7YSM<J]*/?U>E3'ZS6
MO_Y8LZ]]LW*_^VD=/OC9^OWQOU7\YI=K^=-?U_6S'Z_&?_\0EF\D^O_,_?)W
M>_SS#P3["\G_0H-__(=W__LW@%Q2@`:X`P#H(PM8-`*8@(F'@!"H4@\X@>@D
M@18(4QB8@3-5@1Q()!OX@3#0@#I"@DCC@2+8!29H(RNX-"B8@K^'?C#H>2\X
M@_U4@S9H!2TH(SOH-#B8@U30@RXBA%'S@T`()2%XA*R0A$H($$S8A,/PA%`(
M`$2H(E5(-48XA49PA2;"A5>3A5I845((A5XH(F6H-6`8AAB5AFK8?V/8A&?H
M(7'8-6S8ACXPAQJ"A\DC@W9H"GIH(7_(/'S8AZ00B!)BB,\SB(3("8CH((TH
M/8JXB)KPB`I"B=43B9+H%F^HA)9H()V(/9B8B9;PB0)"BML3BJ+H"*;H'ZOH
M/?^HF(J,T(KZ(8OA\XJPJ`BT:!^Y2#ZV>(OG1TB^6(B;>(2[*!_%>#Z]&(SM
MEXS*"']UV(P\-8Q`>(SN08WJPXS0J'_/F(V7(8TY:(WJ`8[M@XW<2(#;6(Y%
M=8[HN(3JN(Y.V([N&(7P&(]4Z(TV*([F@8_P0X[T>('S&(_Z*!X!.3_\V(^A
M5Y`&"8+_Z(X#Z1T-:3\(F9!>\)#:09'Y$Y$2>4_V.(,6:1T=R3\8F9'ZM)$P
M^)'289+_$Y(B>8,JN9(Z2)(IB)(R!),B*),"U)(N&80T^8&?$`K`F)-\$`F3
MD``+P``;H`$98`!*N91,V91.^910&952.9546956>97_6)F56KF57-F57OF5
M8!F68CF69%F69GF6:)F6:KF6;-F6;OF63YD!&K`!@D`("1``",``%"`!!-"7
M?OF7@!F8@CF8A%F8AGF8B)F8BKF8C-F8COF8D!F9DCF9E%F9EGF9F)F9FKF9
MG-F9GOF9H!F:HBF8$D`!#"`'=%`!%Q``"X``$#``L!F;LCF;M%F;MGF;N)F;
MNKF;O-F;OOF;P!F<PCF<Q%F<QGF<R)F<RKF<S-F<SOF<T!F=TCF=U%F=M0D!
M"+``8"`&%7``"A`!#S`!`3">Y%F>YGF>Z)F>ZKF>[-F>[OF>\!F?\CF?]%F?
M]GF?^)F?^KF?_-F?_OF?`!J@8@(ZH`1:H`9ZH`B*GA/P`!&@!$R``0U@`0YP
M``)0H19ZH1B:H1JZH1S:H1[ZH2`:HB(ZHB1:HB9ZHBB:HBJZHBS:HB[ZHC`:
MHS(ZHS1:HS9ZHSB:HSK*H0?@`!;0`$T``"$``#L`````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O<VAA9&]W+G!N9P``````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#8U,3,@,3`U,34T,S0Q-3$@,#(R-C$W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M``,\```#10@$````%-(Q;````"MT15AT0W)E871I;VX@5&EM90!4:'4@-2!&
M96(@,C`P-"`Q,3HR,3HR,B`M,#8P,')J/&8````'=$E-10?4`@41%1^O/'5M
M````"7!(67,```L2```+$@'2W7[\````!&=!34$``+&/"_QA!0``#*-)1$%4
M>-KMVE%JVT`40-'GV(1""'3_.PU.[(YD0S<0W4![SJ!!]I?^+F^8\P#`T<YS
M6NOY"@!'^S4O:\V*SUUX`#C>[[GLX;G->@&`H[W/YWS,%IZ[\`!PO+>YKOVZ
M[<(#P/%>9RO.?L7@Y:>_!8#_P':UX'FO37@`.-[I[W5JX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4
M\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/
M`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0
M$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA
M`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`
M4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E
M/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#
M0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"D
MA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX
M`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`
ME/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)
M#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``
MD!(>`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`I
MX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>
M`%+"`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@
M)3P`I(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"
M`T!*>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`
MI(0'@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*
M>`!("0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'
M@)3P`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!(
M"0\`*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P
M`)`2'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`
M*>$!("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2
M'@!2P@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!
M("4\`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2
MP@-`2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\
M`*2$!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`
M2G@`2`D/`"GA`2`E/`"DA`>`E/``D!(>`%+"`T!*>`!("0\`*>$!("4\`*2$
M!X"4\`"0$AX`4L(#0$IX`$@)#P`IX0$@)3P`I(0'@)3P`)`2'@!2P@-`2G@`
M.-Y]7[O+G.=UWN9]/:\K0Z>?_C8`_CGWN:WU3,]E?_F:S[G."`\`!]C"<UVE
M^=J:<UE_W-:/C]DB=!(>`+[=-N)LI?E<Q=DGGJ]]VKG.>>W"`\!WVX[8'F=K
M:^;90K,=L)W7XZ(!`$>Y[8/.?6Z/">=QQ&;:`>`H]WD<N<T?^<4^K/A0+:T`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V-O;&]R<&EC:V5R+G!N9P``````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q,S<U(#$P-3$U-#,T,34Q(#`R,S8T-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`P```"@M#U,```&`4$Q410```)\X4S43'%^@AR`U+3*5EA$R
M,@L2#Y:.<RHG'A(&";NSFS`M(P81$<=H24(C&+36N#Q'/4)K;&:JJWS1TRE&
M1JO/L#-`-;>OE$5!,R(M*@X7%TM=2PT,";"GB:*7=I.*;"TJ(1<5$18,"+JP
MDGIR6["D@7AP6(A_9)V2<^[6@$]'*SPX++ZTE<*YG+RRDK>LBK2HA)Z4="8D
M'#0P)H1[8;^UE[VSE)F/<"$?&&A;35I30;BMB\&XF[ZUEG!H4A43#QH8#B,>
M&AH8$ZB>?Z29>%--/6MD3K*FA,"WFI:+;2XJ(AT;%8J!9WYV7/__________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____WE:-^,```"`=%).4_______________________________________
M____________________________________________________________
M____________________________________________________________
M__________\`.`5+9P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"*241!5"@5!<'!20-1`$#!>;L_NT%S#(H$M`ZK"VG%'NS!2@2]ZD%7
M4&<Z`P`&%P"<#9<HBI@`FH$)T)B`B6K?/,_5RN!`2YM#Q0"6UL^UGX4!+&5Y
MOWU[:A#'7_-=]W\/?0U.E*IT-8!]V]_:9FD`2VO:K`WBIOK&L<?A#+Q<OYX^
M=ID`=KL]X]D_:U$54//2I44`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+W)E;&]A9"YP;F<`````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-3,S(#$P-3$U-#,T,34Q(#`R,C4W-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,```!@4$Q41?____S\_?+Y_>_R^./K
M]='A]%:F[G+&<@*:`Z+:KL_H_L/5][*R_A*>$NKV_J+6SL3A^KK>]J[7_2FG
M-Z+2_EZZ@@```/___________________________________P#>&7X````!
M=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&```
M``=T24U%!]0,%@XE)"N7".<```!T241!5'C:9<_1$@(A"$#13:1E*5%9\_\_
M-2P<M^F^<5!GW+:_^LKA9H4`$5T^,`S[O5\@`/JE`3O10?QX3K#98N0)Z9!L
M4!P@B,1Q@JL#@(B44NJ$L28;U2$:I%R2JBZP3FT.S)3W\Z7:VA<0N=J+"_K/
M?]\LX`F)*\1V;`````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]H;W)D92UP;W=E<C$N<&YG````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-3<T-B`Q,#4Q-30S-#$U,2`P,C,V-34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```%0`
M```?"`(```#VEGTY````"7!(67,``"XC```N(P%XI3]V```+F$E$051XVN59
M:U135Q8^]Y7'S>,2$AY)55X*R&.6%(JA:*:.5A'EH2A4$0@J%3L6+)6NL6BU
M,=):!%3*H!"=U<>X.G6$:D6-'4&75)'J6$>P6&V%01`4)!@@(:\[/XYSB2$^
M9KEFUK3NE1\W^WQGG_.=O<\^^]P+P',L"`"`INGGD3F"H$\$[=FSQ]O;V\7%
M12J5&HW&7Q/_)Y.O/;&?+>I^^V,7D]FT9LT:A]:&AH:*BHK_-U;EY>7,\V.F
M]V3RAA&=UV1,%C`\;<X+6JW6ONFSSSY;L#`N/W_=S)DS>WIZGG'&5ZY<N7+E
M"A-<C8V-4`D`@,:O7;MF-!J-1B-4MK6U=71TM+6UP::!@0'8\>+%BR=.G&#,
M'C]^_.+%BXRI@8$!V`4`@#]Q3B:SD<0!`"!N%7WJR/V2DI*\O#P`@$JE*MFQ
M[=54(FR:6+W\[(8-&ZJJJIZ%_(8-&V0R67M[>W5U=49&!D51I:6E'AX>H:&A
MAP\?+B@H4*O5>_?N7;5J%451%$4!`#HZ.N+CX]O;VV_<N*'3Z3[XX(-MV[:1
M)#D\/,R8U>ETT/DD28:&AK:TM(2'AWM[>SOQ?&YN;D-#@[W&8C7C!```H&1O
MT!2I2J6:.G5J3$Q,Z<X/%ZYAQ:2S.#S`Y7`6+U[\[.%:45$A%`J___[[H:&A
MRLK*H:&AC(R,FIH:'H^G4JDF3YY<5U=G,IDHBF*SV0"`Y.3DS,S,2Y<N413E
MZ>G9W]^OT^DJ*RM)DF1LNKBX:#2:GIZ>K*PLK5;;T=&1EI;F).P3DE_>NZ\R
M(2$A)"1$K58;C<:U:]=>N](MEF(``)JVIK]OC%LAP(2W?FP[JWR/'1U'``".
M[@42B?OLV;.?G7QJ:BH`0"Z7RV2R18L6R62R\/!PDB3S\_/9;'9Z>GIL;"R+
MQ;ISYTYT=#332RZ7=W5U$02A4"C$8G%*2HJ]Y_5Z?4I*2G!P<&AH*``@.#C8
MR5&W6_-1P8:"M\J$F-6U=I_YAXOW"1:&$(/SEK,CY["P1^P/RPA1L'`X^_7?
MJ]7J9V2>D)!PZ-"A_UX6;&QL+"TMW;9M&XSYAXXZJ:<?R<=;+YC<_08RMPYO
MK>8O6(/D[B2CYHTRMY@=+5ZNX]@LB%/F/!Z/Q6*1).FPCQXEJU>O?L9\"4?D
M\_DPMXV=CTJE@LP=$U["_*2[=[O6%[S-$Z*1L]D$:8R8#0#```#&0>*H!ES_
MAW'$8"6%M'\XF/D:BR=$``#>H5::MJY=NW;'CAT.@XV,C%BM5JO5.C@X^#2S
MCXF)>1;R)I,)CFBSV4PFTU@`#'M[>2B:5V:^V7[K^IZ*W7P7)"B2!96W?W#=
MGMOE*I(H%*].G#CQIY]^.GOF=-.)KM>WDA,"</&XX:35DJJ=5?7U]6PVF\OE
MBD2BN7/GKEJU"D$0&%T$0?P/SG8,P^"(*(H^91<GY>W\1>$WVIK?+J=0%%@'
MW=]9<"LR,M+^Y`0`Q,Z+O=1<]P<-G^^"(@A6MQ^]TV$QC0"3D>YN-UN-PO;V
M=H(@+!8+CN/-S<U>7EY#0T-BL?A1\S`:C4\$P),<QW$'6%]?'X_'&QD9D4@D
M%HN%((ASY\Z%AX?;`]AL-I_/=RAOG>0Q&WI__"0,10&"8)]O140BD0-S`,#1
MVJ.!P1-.?MF?\#J7IJTSEEA'1^KBJM/ZF;\T3<?%Q?7U]5FM5HJBHJ*BOOCB
M"WM3NW;MJJJJZNKJLE@L%$5-G3KUP($#]H"RLC*-1G/KUBV+Q0(`8+/99\Z<
M"0@(```L6;+D[-FS`P,#&(9)))*QEY1ERY8U-#3H=#H41:52:6IJZKOOOOL0
M@K:3DI(2J1<W<Z-`T^3VZ85`3T_/%2M6T,[DC3?>"'B1K&QTTS0]^)75N:7F
MN4_PHSP\/&B:QG'G)X2?GU]W=S<TLG3ITK&;PL?'I[.S$P*42J4#`,.PEI86
MO5X_<>)$I_8)@FAI:3$8#'"!'MKD.)Z8F`@MCY(WF\U965D3`Z0R+^[\Y8(=
MWX@U36Z?-X5)))+BXF*GY'?OWNWE3U8T2#1-;F4G/6)>\Y2X"\>/'[]LV;+>
MWMZQY.&&A!(1$4'3=%%1D3W&'C!ERA2:IG?MVN4`0!"$P^'H]7JY7.ZT(R2O
MT^D4"H53`(JB&S=NA.0?F`X(];0A0Y$Q1%0L*1"A_XY_`X[CK:VM3A?XZM6K
M'![`<`0`\/<3W+-'[^7FYJI4JK%(@4`0%Q<GE4IK:FI^_OEG`,#ERY?KZ^LK
M*RMA)/-XO/GSYX\?/_[0H4/7KU\'`#0W-Y\\>7+/GCT00))D;&PLK$^$0N'I
MTZ=AN0X`\/7U7;!@P>W;M[_^^FN]7@^I5E=7-S4U,7&4G)S<T]-34U,S,#!@
ML]D^^>23T7G2-.TQ`2\\Z,H$,/SM^T[Z\BO!OKZ^3CT?%.H=J^1#9/2K+T1&
M1CH`H-,0!,G+RV.4(I$(#IJ4E`3K<P1!LK.S&8"KJRL$Q,?'0S""(%E96?:6
MT]/3(8:B*+/9#)7Y^?DPSW,XG.3D9&;=+URX`#$Y.3D,`'K^@9-=7:E/U99/
MM]!_V4Y_]4>Z\9@)`&"C+6D%2&]O;UQ<G(,SDY*2^OIOSTQA`P!H&FG_T<#C
M\9Q?&U$T(2&!^<MPNW?O'O0JBJ+,7`$`[N[N3(IF``L7+G1([_!!(I$P^T*I
M5$)N"((P-[SAX>'ITZ<+A4*2)*NJJB!G:'8T[+,SWSMRY(C^KOZ^T6@RF;ZM
MO8&SZ(B9;(+JR=TNV[GN5$!`P*Q9LX*"@EI;6T_6:7MU_\Q2<RDQ'(Q>G,.M
MVG1^\^;-FS=O=GI*V2?7L0"SV?SX`]GA)8K#)F>*G+$`J]5J,!@<D,Q)^8!\
M3DY.3D[.Z-UN76:U9K_W9%PBP[RF]*D."`_O'CCVM_U?U5IY0N#W(K)R*9^2
MC-82P=--BW.H[<7;?7Q\,C(R_M/ZQ#Z?.R7F($Y7D,5B,<]6JY6).P1!&#R"
M("*1:,N6+8^[S^_<_J>O#G]Y\ZI%(L,``'R1>>EZ0-L(LQDGB-$+P?V[K+;6
MD<"7`(N#1"=:]/<$>7EON;JZCMTF3@LR#,,``#:;K;Z^?L:,&5#?W_^@1N!R
MN8_JRVPQ)KP!`%JMUF:S0<("@8!!%A<7LU@LF\UFL]DX'$Y24A*'PWG<FYR/
M=JY#<4M(%.NA8$,!B_V`.6U#OZOEJ],'_UQH5:>-5.^RW>VT1<9@!J/AVK5K
M3^-MH5#HYN8&W5A>7EY86'C\^/&HJ"CXT@;#L.G3IS,.=)#X^'BX<'U]?1$1
M$;6UM45%186%A9"\2"1*2TN#N6!P<+"RLM+'QV?.G#ESY\Y-24EAF#LI<J!$
MS9+%I)&:)C=-D_L[I;^9%.(R<Y$XZWW)QZ<D,+VGY0;Q>#RE4MG;V[M^_?K`
MP$`W3XHOY"H4"H=LCV&85JMEE+Z^OG#0Y.3D39LV,4&.HJC]D>[GY]?;VPN=
MCV%834V-PPS]_?WM@\B^GE^Y<B5-TT%!0?8`@B`(@@@+"V,L."?_[?D3WH'L
MK7]UW?>=='E>&(_'FS9M6EA8F-A-L"#[P=GV2JQ?2$B(?2^M5JM4*@T&`Z.!
MSD%1]-BQ8XS2Q\<'#CIOWCR:IA4*Q=A-+I%(SIPYT]W=#;<QBJ('#QYTF.3Y
M\^<]/#S&OHV6R^40<.G2)4]/3P>`O[__$\B_^9:2$F,?5GLF+@WG\7BYN;E0
M7UQ<+/-FE]5)-$UN+__.UWX5G0J7R\5QG,OEGCY]FE$&!@;B.([C>%)2$M1D
M9V?+9#(.AT,0!$51<KF\I:6%ING6UE:!0(#C.(?#L5\^1F[>O!D='2T2B0B"
MX'`X,IG,H1+O[.Q4*!00``>%A>/CR'=V=LZ8)><+2(JB2DI*[)M\_,6I[_`U
M36XO3?-EUO@7*LZSO4PFJ_OF7%%1T:1)DQ(3$^V;?AL=>^KP@5`YT=6N#YCD
M_6OX</'TJV4P&*12*451X\:-*RHJ^J5[_KG^5O<\?Z0%_P*G[^$/F_*2T@``
M``!)14Y$KD)@@@``````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VAO<F1E+7!O=V5R,BYP
M;F<`````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,C4U(#$P-3$U-#,T
M,34Q(#`R,S8U,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````5````!\(`@```/:6?3D````)
M<$A9<P``+B,``"XC`7BE/W8```A?241!5'C:[5A[3%39&?_N8X;APLQUAD&0
M"@PB&,>W$&0V&8UD6P7EH1A`09?6FL":V$IJ2KK2&*W82!!E=1MQS&H,29,F
MXF---!41'RTE,V$%41Y=(5V-PS(,X`SSNG//](^#M^.=`<6D&QKZY?YQ[[F_
M[SOW=[['_<X!F,-"`(#/YYN+S`F"G,N>)P%@Q8H5<Y=\7U_?M6O7YBAYC\=3
M6UL[1\D#0&=GY^#@X(>K/7CPH+>W=ZJW86%A4JF489A'CQ[]"!RZNKKPC.'A
MX5U=73,C'Z:0O'GSIK*R\@-UZNKJLK*R=#K=X<.'@P+<;C?'<6ZWVVZW_PCD
M/1X/GM'E<GD\GIDI?UHP#P#4:K7-9O.]3RHJ*F0RV>3*D61*2LK`P(`(0],T
M`%`4=??N7=]_7SHZ.O",$HG$:#1^H-8D^:-_5M(T"0"EI:73*VS9LH6B*`"(
M3PY+V:#`ZDJELK:V-I`\3=,]/3U.I]-BL4QC\T,`9K/9;#8'PBP6B]/I'!L;
MFXJ\Q6*9RJ.3Y`WMD:L^40#`PH4+I_D(G4Z'\4M3Y/7-:D-[Y"]^KV3")0`@
MD\D,!D.@YY.2DE0J%<NR<7%QA86%(H-GSIQ9OGRY2J52*!2QL;$[=NP0`>KK
MZU>N7(D!"H4B,C*RIZ<'ORHJ*HJ+BV-95J52)2<G8Y?XDR\N+HZ/CV=95JE4
M:K7:X\>/3TG^X!D5#N.3)T\&TK;9;%JM%H-UF]D_/5(;VB/QE;-7`0"AH:&M
MK:TB\H&2F)AH-ILQ9M>N71*)1`1(2$AX]>H5!I26EHH`%$5U=W?;;+;%BQ<'
MM2^12+J[NYU.YY(E2T2O:)K.R\L+3K[A[Y$+%X4!@%:K%3'OZ>F)CX_'_>".
MSU4";4-[9$-;9&Q2*`"L7KTZ,.S]&TGA/C4UU>?SU=34^&/\`=A4?7V]"$`0
MA$PFL]ELZ>GI014Q^;&QL?7KUP<%D"19557E3WYR`I*"GY9(OCX*SY\_5R@4
M+,O&Q,1LV+!AS9HU!P\>'!H:HFERS^_83[92_I/U?\M_W^\D2;*PL#"H*^1R
M>79V]H(%"YJ:FEZ\>`$`3YX\:6EI:6AH\'J]^*>X=>O6V-C8Z]>O]_?W`\#3
MIT^;FYO/GS^/`0S#9&5E+5NV#``4"D5K:ZO)9,+&%RU:M&W;MM>O7]^\>=-F
MLV&J5Z]>;6]O%^*HH*!@:&BHJ:EI?'P<(73Y\N6C1X^^\XG8C5\]5/\D(53D
M,9Q+(:'TKT\K_7V.+]VF>0`0'1T=M-H3!%%142$,*I5*;#8_/Y]E60PH*RL3
M`"J5"@-R<G(PF""(??OV^5O>LV</QK`LRW$<'CQTZ!!)DKCT%!04".MN-!HQ
MYL"!`P(@B.<!0!I"_-80-C8<.OJ#[V4_]!E1?Y?#8><42NFOZL+CM93(J^,6
M].W#"0#(R,@(WD*09&YNKO"H4JE&1T<!P&JU8J^2)"E\*P#,GS_?:K4"P,C(
MB`#8OGV[O\V1D1%\HU:KA;PH+2VMJZM#"!$$,3X^C@<=#H=>KQ<4,5ML]C^%
MP/^!D1.,G(I9!,O28=-N<-@DS__!QRPF%VB";/Z,?T5.!\>R[*E3IZ;J(%PN
MEVAZD7`<-WT/XF\A,,F%)B<0P/.\T^D4(2,B(J8D+Q)&3J1\&AR`$#R\X<$[
MPJBHJ(]NSOSK>5!B(@FZ@E*I5+CG>5Z(.X(@!#Q!$$JE\MBQ8Q]*?AKYYQ/^
MY7<3-$V7E97-5)>B*%Q*$$(M+2T;-V[$XS@I\(]SFEW#9-*]#6\`N'/G#D((
M$Y;+Y0*RMK96*I4BA!!",IDL/S]?Z$W?V=C,5!Y=1P`0&QM;7%P\4UW<KF`W
MGCMWKKJZ^O;MVSJ=;FAH""^-7J\7'"B2G)P<O'`C(R.IJ:FW;MVJJ:FIKJ[&
MY)5*Y>[=NW$ML-OM#0T-"0D)FS9MRLS,+"PL%#'_2/)CP\C48@>`M+2TCU"G
M:;JDI`0'N=5JK:JJRL[.;FMKPR&JT6CV[]\_U<E:<7%Q8F(B7CB3R92;FUM9
M66FQ6/#;S9LWY^7E)2<G8X#1:,S(R-!H-!J-)NBGD@`P_(KO,WF?_LW;:_(.
M?<][/>\YTB,I")/3`/#X\6-10?+/3)_/AQTB2M>)B8DC1X[H]7K,'R$D%&&U
M6GWITB6OUXL]+[*`Y<J5*T*5X7D>`PB"2$]/OW#A`@`T-C9&1T<+`([C.(Z;
MF)@(X@8`^")_%"'?VSI!R.=)M&F,/H],6D,%K4$*%5GV1Z:FC'OY\F565M:]
M>_<"*Q#'<1*)A&$883`D)`0')`Z_UM;6\O+R&S=N6*U6GN<9AEFZ=.G%BQ>U
M6FUO;V](2`A"B*9I?PM8TM+2VMK:2DI*GCU[9K?;*8I2J529F9D&@T'H$4TF
MT\Z=.[NZNNQV.U[T0#N3I[<41<ED,IJF$4(.AT/(M\7+PPLK)`G+@Q?%.U>\
M?_ER5"J5GCY]NKR\_'_Q]);`U7+5JE4RF<SK]79V=C8V-MZ_?W]P<)#G>8HF
M\S]7_*Q$$JC,>^'X9XY_]4_$Q,3LW;N789BHJ"B-1J-6J^5R>6AH*,NR@35F
MUI$/6EWJZ^M/G#AA-IL!8.O/Y^65!^'_Y`'WY6_&WCD))TF2)&F:IFE:\E8B
M(B*:FYM%#<:L)H]EW;IU>)_PV1=*?2X=Z/ROC[B^Z^2]7M[M0AXWCY#/A\0&
M29(\>_;L;$N-]Y,'@+5KUW9T=,@8R>'+\NAX*DBWQP//^Q`/O!?<+G#:D-L)
M;J?/[0"'W=?TE<OZ@RLW-W>VG8X3!/'^#J^EI24I*6EX>/B;"^B7?Z""_OE(
MBGC;$8,R\AU,GY%X^(UK8&!@]AY=3R,LRQ85%0&`Z;YM^!4_TPEBETPV,_!_
MF57R;W)KNXW"M.S=`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W-H
M;W=?<&%N96PN<&YG````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-C(T(#$P-3$U-#,T,34Q(#`R,S0V-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`(
M`@```)"1:#8```%;241!5'C:E5(]2P-!%'QO=R,Q&%"K]()5.$AM(=C9!()@
MC"'_PH-`D)@+`>$@G('TBM<H6IR-G8WE8;C`-0GW!U($A4BTVK5X\>Z,'YA7
MS<[.O%F&Q9/C(UAD!`!DL[O_5/O^O2#TY/KXBTA*Q1A*J1CG2TD0`+"WO[.Q
MN8Z(C#%$O+V^J!NFYWDAHY1"1$2\N3J?)7#.-4T#@&ZW2TRSV201'0W#("P`
M(&3?IN_+J62I6"`#K8\GS`PD!8">.WR=3%?2J8/#.]NVPUVM5HN>%QE(G4B(
M?B]X>9ZLKJ6#(*"MC#$I):5%AIX[?'SH$R90J]5(04\R3?.+(3[51L5QG%PN
M][VER+"UK0'`:?VRVJB4BH5\/E\NE^-]M-OMR*"4&HU&F4RFVJC8MAT,/%+\
MU9(08CP>$WLV\`!`UW6Z0D3+LN9;XISCYQ#3Z71"AA)^-A`[Q\1KQ46_]P>.
M"8$-*F#M80````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]H;W)D92UP;W=E<C,N
M<&YG````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C0T-2`Q,#4Q-30S
M-#$U,2`P,C,V-30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```%0````?"`(```#VEGTY````
M"7!(67,``"XC```N(P%XI3]V```,UTE$051XVN59:W1459;>Y]QS'_6N/$@(
M":0(>9@4(71"8"T8!.Q>+;A:`FTW]`RN'O[H4G%TK6$<$,?II:ZA>T2AP<A#
MA08%%C,@/L(`&:`U@@^03B9(`GF8%R0AKZI4U:VZM^YS?IQ0E#%`1>E??7YD
MU3W9YYS[[7WVWM_>%^!O>"``>/SQQQUNZYR?%;F2;3]^QW!0"OHCX9`LA:.&
M;@``RQ&K7;"[+>X4.V&91#;I[_9?.',E*JL8X]+2TL<>>^S>(T>(T%^AX4CM
M9\WEB^ZSNRP_;"]=,_I[_#WM@[Z!D"1&544;=9)@Y>PN2WI6<L:49.?=M)R6
MF518FEW_9:MA&)<O7SY__OR<.7/N.7X&`!8N7*@HBA2.AD-R>J8[0>/$C][.
MH;IS+6V-O;[^8%12J<$I9H00_:VI>B0D]W?[>SN'(N&H*]G&<N0.>[I2[)*H
M!GUA7=?[^OK*R\LYCKN'R%]ZZ24$`#4U->^__[XLRP"0G9\^<U[>F/@10@AA
MC#!]-$W3,'594AHO=G0VW]`U@\KP/)^4E)2<G.QRN2P6BZ[KHB@.#P\/#0T%
M@T%=U^ERA]OJ+9^:.37U#N\7&I:^/GU5BB@8XXJ*BH4+%][;:X\HC`\^^.#,
MF3.JJ@)`7G'6]#DY&*-1H@QF.<(3AD4(F::I&6IP./AUS97>KD'3-!%"=KL]
M+R]O^?+E:6EI8YY74U/SV6>?]?7UT8,(RWAG>7*\F:/.NN63F.UM'^ZXVH\`
M.1P.A\,AR[*F:3S/"X(@"`++LAS'"8+`<1PAA&590HC=;L_)R1D'>``X<.#`
MYY]_3BTS?79.P<S)\:(8,P)K=5B3+)P-8VP81C`8.'?F8EM+EZ(HA)#\_/S5
MJU<[G<Z[GOK))Y^</GUZ<'"0/DZ?/;5@YI0Q'!(3@;,*C/U&>TA3#%55?3Y?
M=W>WS^=3596^,W4KAF$00AAC^I?G^25+EMQ___V)!CP`6+5J52`0:&AHT#3M
M2FT'RY.<PHQ;X!$F#&OA;#^?ORP0"-KMMC?>W*I(!B&$$+)@P8**BHH$[]NB
M18O*RLJV;]_>U=5E&$93W36K79B<F_9]%R,,AQ'[Y!-K@H&@R^7Z_1]^;[5:
M`X&`IMV*IJ9ITD>J#@`(A\.7+U^^*W@`^$[(>>JIIUYYY97KUZ_KFN'K"\2#
M!P"$,(-)?]^`)$E21))$11`$M]N]>/'BV;-GC\O?G$[G^O7KMVW;UM;69IIF
M4]WUU/0DN\MBFC1P8(0080AA"&.2P8%!29)T79N:/RDE2YCL2Y:CLJ[JFJIK
MBJYJFJIH2E355%V*1`-#(@#X?+Y$7F-TO*5:Q!AEYT\<DQ:P+)$D((0(@I"2
MDK)@P8*2DI(?%G*>?/+)@P</=G=W`\"--G'ZG!3=T!$`Q@S&#&%8GK5BG8R<
MR+(VAX5W)3M2>#`!88P``8!NZ*JF:JJBJFHH&#YWXINHI(BB.&[P7WWUU?#P
M,`"X4^W):6-YKWGK6J:DI!06%GH\GCLE?UU75540A#'_R[+L\N7+SYX]&PZ'
M3=,`67"Z.80P85B"6<,P>4[@&`%C?#,*,(2U$H9E,"&8U74=(8RPJ6I*5)5D
M)<);.+O3HLBJ+,L-#0U>KW<<X)N;FQ5%`8#4##=#\)@+S)L7I+*RLJ6E19(D
MC\>S;-FR)YYX8I0>=^W:55=7)TE2=G9V147%FC5KX@7.GS__UEMOU=;6BJ*(
M$'*Y7)NW;G+94C'"_WOBS\>/57_;VF81!._T(D51*14E#"<('"`X4_WIL8]/
MMC9_R_%<:5G)+U=43,OW$"8@2I"2[O;U!S5-:VMK&Q_X_OY^PS``P)EDO>T*
M$P!`EN7#AP_3B::FINKJZE.G3NW?O]]BL0#`[MV[UZY=&P@$8CH]=>I4=77U
MH4.'K%8K`+SWWGO///,,O65T"(+`$0MC<B^L_]W^?0=C\Q?.7XS]YCF>(\*_
MK?_=GG?VQ2;_\G7M?QT\LG'3RP_^8I%N:$ZG'6.LZWHB;O\=\U*>`P`VA^4V
MU]BX=?5'4N#(#D>/'MVP80,UZ;///AM#'A.HJJIZ[KGG`*"VMG;-FC4QY#1?
M.)U.J\6RH_*=&/+8PMBP6*Q[WMX70QX3"`9#__+L\Y?^TN3OD8;[PQACTS3]
M?O\XP'_ZZ:?TA5B.$:S<;0B\?C.AP+1IT_;LV5-55?7((X_0F3U[]O3V]F[;
MMBT<#@.`Q^/9O7OWL6/'5JY<207>???=GIZ>'3MVA$(A`)@R9<K.G3M/GCQY
MY,B1+5NV]/</[-KY%I7\^U4K/SAV>._^=^XK+!C1$<MV=_=LK]Q)'W_S#RO^
MI_JC0X?WE\R<0<VVJW)W8%".2CI-^#S/)Q3P#ATZU-C8Z/?[;Q(O<CN'IQR6
MFFO+EBT//_PP`#STT$,E)267+ET*!H/'CQ^OKZ\'`(9A7GOM-:J7)4N6M+2T
M4/?^\,,/+UZ\2.VV:=.F%2M64'>[<.%"75V=W^<'@)^4SMSTQ_]0=04CG)R:
M_*NE*Q5%Y3BVONZ;WIX;`%#D+=SXGZ]8K59%UM:M6_>/OUVMJFI]?3TAQ&JU
M9F5E96=G)YKG:VIJJ*L#`&]ALZ9-X'AV3&E-&V'F',>5E97%YG-S<R]=N@0`
M?7U]U.P\S\?7845%1;6UM0#0V]M+S<[S?(P=$$)$41P:&J*/A44%BB9'HB*#
MF;R"'$$0%$7%"`<"`<ID.CNZ%LS[F:'KI@D((<I*15'T>#PS9LR8-&E2(F8?
M`6\8!D)@M0N9.1.FWI=QAZK6-&XY/,T+\>Q@=!D7Q\-B]4R\0&P'A-!HTJ9K
MJA8U,,'Z6"V#<)BJ.'[,F#%CO(R#`,"$2>Z,*2F3/*DVIW`7/AQ7@<3HY&@%
MW9PGY%8J81CF#JLT3=-U/7;[,,8,9@C#8LQ@1*BR#-.4PM$80:`;TMTPQEZO
MM[*R<KPLBP#`O,7%MW/RT<4&86*V&A,&(81F.T51FIJ:LK*RZ'QG9^=()>MP
M?'\AK57H0@#H:._D60NE]UUMW9(LTSS'<R.V\7@\>_?NM=OM+,L:AD$(R<W-
MC>DW\8$!($'D`$#(K6(^=I/CA]OM+BXNIL9<NW;MN7/GNKJZUJU;]\477P"`
MQ6*9-V\>#:OQH[.S4U&4W-Q<B]4"`%]^<7[KZ]M#`;FC]?J&?_UW):H`0'Y!
M7EE9F</A`("VMK:C1X^FIZ=[/)Z<G)S\_/P?@'QTGK\[>):A#HL0BO?Y>,L_
M_?33-`/7U]<_\,`#145%K[[Z*M74TJ5+R\O+OP^^O;T]$HDXG8[EOUQ&8]"F
M/VR>-VOA@S_]Q>?GOJ0RO_[UKQP.!ZT==5U__?77<W)R)DZ<.''BQ%'D\J\%
M'F-,(Y.JJK'@'!_/`H'`_/GS7WCA!6H*555CD6G6K%E;MVXU#(-J+>;DHBAV
M='2$0B$Q$OKG=?^T<-%(BA)%D=H<8[SAQ76%186#@X.K5Z^>/W\^%8A$(L%@
M,!@,)EC#W;VJN\,P34,WM-345+]_V&:S#0P,1"(12E=M-IO-9HL%N9=??MGK
M]>[:M:NAH4&6Y<S,S,6+%[_XXHM)24G#P\-NMUN69:O52H4_^N@C410YCI-4
MT>)@=OSICP?V_O?QJI/M[9T"SY?,+%ZU^C=EY3^I__IJ*"!F9&0</WY\X\:-
M5555UZY=HY:@OO`#6]?5%P\D8/.13@['6&YT^GT#`;_?GY:6MG3ITA_32//Y
M?)LW;QX:&F(8YN\>+/'D3K;P=HX(A"$(80#3,`Q55[J[;EP\>UF2Y(*"@D<?
M??0>MZX3,;NB14,1/V%$!8>_;6L50^'6UE:WVYT(E[I=P;MOWSZ?SV>:9DJZ
M,SG#+D5%58LR#(L1CK78=$-KOM+:U]=/NR#WL(=)`*#UF^N4TA*6(2S#$,P0
MAA?8>(9OFJ9NJ+*J8PVS=A!<<*W+K^OZQQ]_/(K,)3[>?OOMUM96PS`XGDR?
MXP%D:H:J&QK2HC$B9)IFT!]N;[T>C489AKGWX.N__!9CA##"&&,&8XPP@ZPV
M8?9/"T?A-TW=`!T`IGHG]O?Z!GL#HB@>.7)$U_6Y<^>.Z^`WWGCCRI4KAF&8
MIGE?:;8KQ3YR!)A@&M^YGPP(%E8,1'1=/W'B1&9F9EY>WCW[:%%65F::8!JF
MH1NZIFNJKD:UB"C;',+8_1P`0IBD"<Z!'G]44J/1Z-6K5WMZ>KQ>;SRKN]UH
M;&Q\\\TWV]O;:;0OF#FYH&1*S-1C-'PXDC3!,=`S')5569:;FYM+2TMCC.C'
M?K38L6.'HBBJJFJ:IBA*-!H=&AHR#,.99)VW9(;5?MLB(>B/_-^YEH'>81H_
M7"Y7<7'QW+ESQVR;!X/!AH:&LV?/=G=WT\8!0JBH+#M_YI0Q^_:C0V-_\*O3
MC9(8!8",C(SGGW\^P>KE#@'O;_DC+?P_CT4\9+HONJ\`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&5L<%]I;F1E>"YP
M;F<`````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,3$@,3`U,34T
M,S0Q-3$@,#(S-#,W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P``
M``1G04U!``#8Z_4<%*H```,`4$Q41?___P```.;FZ"XO-%9767!Q<YZEK[N]
MP"(G+D5(3%A;7V)E:4%&3$5)3F5I;D1@?D)<>$AD@DUIAT]KB5)NC%-OC5-M
MBEATDF![F&5_FV:`G&N%H5UO@X*8L4507(V@MF-O?)JJO%A@:9ZKN:2QOZ^[
MR3%.:S-0;C)/;#).:SI7=3Q8=#]:=45A?4IB>DE@>%IVDQ8=)`T1%5UXE$YE
M?%-G?$Y?<5EL@#U*5UYQA#I$3FY_D'2%EGJ*FYNMOQT@(V%J<ZNZR5MB:4)'
M3$9+4*JRNDM.48^4F5M>86=J;:ZPLO#Q\N[O\.?HZ<O,S311;352;CU9=$U@
M<7Z/GR\]23,[0BXU.TY672(L-#Y,5T)'2V)F:=WAY$E,3N3GZ5UQ>^OM[F!S
M>^_P\&QY<G%^=X*(=*"A@>[6@$Y.3CP\/"4E)0X.#O___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"ZX=T@````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]4*'`8=
M`5*^]X(```"R241!5"B18V#`!C@880`JD*UH+*8;J*TC8`818724%$Y/3T_5
MU(^$*,BR,TA+5%=+#S`+!ZM@5)$2X4])3T_6LXAE!0EDRHL+Q:>KJ?F;AK&`
M5#"J2HL*:FFHJ9F$>()U9,A*"/,#%:@%A4:!%;`%V]I86\K(F,MQ08Q48N9U
M<^/D<7;AXX8(.$1[^3(E^23XN4-<9<_(:*6@'!/GS>X!<S@#R!,13JYP/A@8
M,3(:,F`%`$PY&T@J'L"]`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]H;W)D92YP;F<`````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3$U,B`Q,#4Q-30S-#$U,2`P,C(T,C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`8````?\_]A````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,``"XC```N(P%XI3]V````!W1)344'U`P5#S<ZNAN`C@```?=)1$%4&-.E
MDTUH$T$8AI_=;OY(5]&#%1KJ0?,CP4,"0BR:1+"]^'OP4`(V5EK:BN!-*!)O
M@MI#$0F(-Z&@AX`MA!:A8$MR,!04;858J!"U\5`5*X9DD\V.AT!#9%.0OK>9
M;^;AXWMF)$"PBR@`)R)N1H=N$PJ%_NNRS^=#!AB\^XMGJ2>FAXK%(IJFM87(
M``=<,K:#[R@4"BW%7"Y'8O(2-Q-]+"XMM@=4*]![SL:CY,/M0CJ=9GK^.F,/
M[%P8KS,W-]M^!C5-T-73P3Y_AAL39Z#23>>A5:Y,.+'88'E!(SXXO`.@VA#1
M'W.@US1*O]=Q[G%B&(*M32BN].`?\;<'V!S2]H;5+B'+$GI-8+5+K.8T(J'+
M.VM<>E'AZYJ,$.!R&P1/6W'NE:G7!?N[9-YF7A,C9@J0`)%,)@F'PP!DLUF>
MST[1/_(=UQ$%Q0+S3\M(Q?-X/$=1515550D&@P0"@08@G\^WMJ4H7!L_RT#B
M!XY.B9H&&^LZY9*@6A&4M@PVW_<RDWK9T/AO=%TG/G"+Y04-BTVB0X'#QRP$
M(E9.7;1SO,_.EV\?FN_`+-%HE(V/"L)HK(VZX/.:SO3]/\S<<S-Z]4YSB*;#
MD22$:)IYE2KS<^4D0_$QO%YOJP6S9#(9NCUU.A0+U8K@TQLGCR>GS"WLYCO_
M!0N%JOX,%C3<`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]S96%R8V@N<&YG````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C,U-R`Q,#4Q-30S-#$U,2`P,C(V,#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP``
M`"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#
M`%!,5$7V]O?Y^OSU]O@X0U'I[O1I@9Q=<HI$4V1/8'.`F[A\EK*#GKN%H+V$
MG;F(HKZ$G+B)HKY#3UUO@YF%G;>,I+Z-I+V'F[&7K<6$EJJBM<K3W>C7X.K7
MWN;EZ_)!46)"4F,Y1U5OB:1SC:AJ@IMK@IIF?)-=<89@=(EK@9B&H;V(H[]S
MBJ%J?Y5A=(A!3EMPAIQJ?Y2+IL%I?9*-J,-><(*4K,65K,24J\.+G[28K<.7
MJ;N.G["?L<21HK.QP]:KO,VVQ]FOP-&UQM>YR->YQ,_,U^*YPLOG[?/CYNGU
M]_D]2UAQAYRBMLG4W^G6W.'3V=[R]OG5W.&YN;FQL;&0D)!Z>GIW=W=U=75S
M<W-P<'!O;V]N;FYF9F9>7EY<7%Q;6UM86%A75U=65E924E)04%!/3T])24E#
M0T,^/CX]/3TZ.CHQ,3$O+R\K*RLI*2DF)B8E)24C(R,:&AH6%A8-#0T*"@H)
M"0D("`@'!P<&!@8%!04$!`0!`0$```"`@(``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!#$+6;````?W123E/_________________________________
M____________________________________________________________
M____________________________________________________________
M______________\`_^$\"0````EP2%ES```+$P``"Q,!`)J<&````,Y)1$%4
M*,]CJ`.#J/3LVIJ\Y-"Z.@8P/ZE4T,A;6\.K+!XB$%EF8NWF)^/#I586"A;(
MT+/U9_!DD3;E9$\!"^0;N#`%L$C9:8HHY8(%:O4]&-U]'0QYS/AK(`(Z@;)2
M#L9:W)+"M6"!(G4K5R=#+3YS1\5LL$`6LXH8+[>`N+.H?!Q((#RVFD-5PL+&
MWI*M*@PDD)!36ZJ@*Z3,*E>9"'189&U515%:9F%-;4%2!-#I,?E!(<6I=7#`
M4!(<75M;AR10#N3'(PO$U]8F(?'K`$Z:6T[T>_#+`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V=R;W5P
M+G!N9P``````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S(U
M(#$P-3$U-#,T,34Q(#`R,C0V,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P``
M`"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I
M``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410@("104%A86&!L;'!05%Q46
M&,O2W,/'S0X3&@X4&Q$8(!`6'41=>4ED@5-MB6A^EHJ>M("0H@T3&0X4&EUY
MEE1MAUIRBUQTC%-H?5IPAVN!EUEJ?!\E*R,H+8*3I,S4W,W3V4YD>6J&H4I=
M;W*.J8"6JVQ\BUUK>(F;JPX5&XF<K(&1GW)Y?]SBY]WAY"4H*LC+S35*31$7
M%`4+!VBG:2E_*2E^*B=U*"V%+2V!+2Z`+C&',36*-CF2.42-1#AN.$]^3R=9
M)C!B($]R0ADK$!\J#00$`CX\-G-P9ZVIG*FEF"@G).;AT-O6Q_#JV8!]=I9I
M&J!S'M2:/M&-)]:0*=J6+]V8,=*7.TI!-AH.`1(*`:I?"JQ@#,1P$[]M$[YM
M$[YN$[UL$\]Y',YY''$_"HQ.#2L8!&DZ"H1*#;IF$\UV&KQM&TA&1"06"1P3
M"R,8#E-,1@,!``0!`&UK:WIY>6=G9UI:6@4%!0("`@```/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#,2Q'8```![=%).4___
M____________________________________________________________
M____________________________________________________________
M________________________________________`)/#J.H````)<$A9<P``
M"Q(```L2`=+=?OP```"X241!5"C/8ZB"@<I*,,4`XWOZ^'E5P@48F1A\_?S\
M8`+,Y66E%?Y!X7`!M^*2PB+OL%"X0&1V0GRB>TBPGP=4("HI.2LV(C``;`A(
M("TS-2/.U<G9SLJ^$BR0%Y.2'NWB:&)C90D68-$IR,W/,31VL+4P!0FPJJFH
M&[`+BBD:69N9@P3T!92D]72U^$6Y*RO!ALJJBD@HL&G(BW-!_2(CQ:>L+2?)
MRZ,)\YRP,"<GIS"'4!6J;V$``"(2655!M*L:`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8VQO<V4N<&YG````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`T-#,@,3`U,34T,S0Q-3$@,#(R-#,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````0````$`@#````*"T/4P```#-03%1%!0`''!P<'1T=
M.3DY5%145555<G)RB(B(CHZ.IJ:FJJJJN[N[Q\?'X^/C_O[^____````$)I!
MC0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U00:$`@+!R[&]P```&E)1$%4>-I=CUD2@"`,0UE4L%";
M^Y_60F49\Y<WZ1+G'#8Y%<I20O<RU`G,/T8,G$`5\0@\$A&>E?)("(=V@>:(
M"*D_9`,M0CN(;807N(`<$";0#5D8."<@TL<JT6V@S,=+^LJ,:MW_Z[^;TPQ1
M(OVC1P````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+WIA+G!N9P``````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,C<P(#$P-3$U-#,T,34Q(#`R,3<S-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````"0````D"`P```)W_[H,````)4$Q41;H`%F9F9@```(RUS$(````!=%).
M4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T
M24U%!]0,%!$V"US:6.H````H241!5'C:8V```JU5#`Q2*QD8N%8P,+`M86!@
M6L#`P#@!*-$`DF4``%GG!*=[7+#T`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]L;V-K
M960N<&YG````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,P
M-B`Q,#4Q-30S-#$U,2`P,C(U-C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,`
M```H+0]3```!#E!,5$4````$`P(%!`,("`@)"0D+"P<3$0X:$PL6%A8<'!P@
M'1P>'AXO*2$K*RLM+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z>GJL<2ZM<S*@
M=T2C>TN$A(2D?DZH@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZA$*KB%BZAD>\
MAT:\B$FZB4NOC5ZMC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'FV2HHY[*GVBJ
MJJK+I''.I'#-IF[-IG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.K8/4K'G5KG[2
MLHG5LH38M8R\O+R^OK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@Q*#?Q*/AQ*#B
MQ:'CQJ+2TM+;V]L```![0$@>`````7123E,`0.;89@````%B2T=$`(@%'4@`
M```)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!02+`1^#@'Y````C'1%
M6'1#;VUM96YT`$UE;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]"@HH8RD@,C`P
M,R!*86MU8B`G:FEM;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII;6UA8RYM=7-I
M8VAA;&PN8WH*"F-R96%T960@=VET:"!T:&4@1TE-4"P*:'1T<#HO+W=W=RYG
M:6UP+F]R9V>*QT<```"9241!5'C:8V#`#B*!`(G++18>$>$IS`P7D/82X.04
M=)"&\?G\6$`4OSE,%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<[._O[VTM!%$2
M&>IAIB(OKR"E*0X5"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$6NJX.3DYVRI*
M0`4"7*RTE9759#7DH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=%XJG_UT`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]D96QE=&4N<&YG````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,30V-B`Q,#4Q-30S-#$U,2`P,C(U-S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3```!@%!,5$4````("`@0$`@0$!`8&!`8&!@A(1@A(2$I
M*2$I*2DQ,2DY.2DQ,3$Y.3$Y.3E"0C%"0CE*2CE"0D)*0D)*2D)*2DI24D):
M4DI:6E)C8U)C8UIK8UIK:UIK8V-K:V-S:V-S<V-[<V-[>V-[>VM[>W-[>WL`
M_P"$A'.,C'.,C'N,C(24E(2<G(2<G(R<G)2EG(REI8REI92EI9RMK92MK9RU
MM9R]M9REK:6MK:6UM:V]M:6UM;6]QKW&O:7&QJ7&QJW&QKW6UKW&QL;6UL[>
MWL;>WL[>WM;>WM[GY\[OY\[GY];OY];O[][W[];W[][O[^?W]^?W]^__]^__
M____________________________________________________________
M____________________________________________________________
M__________________________________________________________^%
MHO<^````@'123E/_____________________________________________
M____________________________________________________________
M____________________________________________________________
M____`#@%2V<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MPTE$0508TSW/_0^!8!`'\$OH*2*D%T)D(^\AP^:EH840_Y!_73U/N=MNWWU^
MN-O!-RJJ7"VP@&,T`7K/]^LH`1"@][M.A>%ZT]D,(F"=L[>M\;PZLNU0PKZ_
M`__F[!>[PZJ-H?_XA!7XE[$J1_"5](EW]4ZF7A<07IK)BXU64Y-Y.IW!@"PQ
MCUB*2A6X+('Y1K?THI;3>(;`VC5/ICPL&1)*8.`N%4O\0S>!^`HC#)00AJ*"
MLLES@FD(&L?&SV&B`$C\`53`.ZYX:)DM`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]U<V5R+G!N9P``````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C,T,B`Q,#4Q-30S-#$U,2`P,C(S,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!`````0"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z
M)0``@(,``/G_``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$4B(B,*
M#!#%QL@,$!;FZ.LE*"P,$!4H+#$W1E88'B5O?Y%\BIF6H:V@J[>[QM)%87Y-
M:H=2;HM.:(-=>94*#1!F@IY%6&MHA*!5;(,]35Y9<(AMB:58;H1SCJH)"PU@
M<H5^E:P=(B=D;WJ-F:6)D)?5V^'GZNWR\_1.9GUG@YY<=(MOBZ9%5F9UD:Q0
M8W5\E:V)G;"*GK":K+VGN,=O>H09'2"1F9^0F)[)T]L)#0\2%!43%18-$1(1
M$1`8&!=+2$03"@`;#P%!)`4V'P6;6`_+=1G,=AK(=!K1>AW0>AW1>Q[%=1S"
M<QS3?1_%=!W!<QT.!P`*!0`(!``U'`(5"P$F%`(R&P-E-@=')@5;,0<U'00T
M'`233PTL&`2E7!!\10PI%P2L8!&*3`YY0PRU9!,F%00=$`.^:A6V9A2I7Q,M
M&06#20_*<AC,=1G-=AK,=1H8#@0N&`-"(P4T&P0Q&@0O&00Z'P59-A5%+QI,
M.BD:$@PD'AHI)B;,S,Q$1$0E)24='1T&!@8```#___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"O
MCWHK````A'123E/_____________________________________________
M____________________________________________________________
M____________________________________________________________
M_________P"7TC:^````"7!(67,```L2```+$@'2W7[\````O$E$050HSV-H
M!H$F$`"SFAE`A&V3O7T@5`0DT-!H7U</5&(+$[!SJ`P)2$MU;H0).#IY^_G[
MN,<'P01B(SV\?#WSDK-@`B69N6[YKCD9I3"!,I?T[-#"I)0BN+41,6&)<1'A
MP3`!FYKRXJCHA`I..8@`JYF!275!%8.2CJ0E2("=5U973Z6629E+0D9,I)G!
MREQ?6EN+6UW-6$%56(.#D<&:1U137$J>Q<)(E4]54(B-P=10``GP,S,HH@$`
M:754R]SME+<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEN9F\N<&YG````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4S(#$P-3$U-#,T
M,34Q(#`R,C(V,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,````$
M9T%-00``V.OU'!2J````(&-(4DT``&V8``!SC@``U,\``'L/``!X]@``R_(`
M`#*,```C34@19+(```,`4$Q410```/___^CGZ.#?X-C7V):5EM_?X-?7V.?H
MZ-?8V)66EM?8U]C8U]#0SY:6E>CGY]#/SY:5E?#P\.CHZ.#@X-C8V-?7U["P
ML*"@H):6EGY^?FUM;6QL;/___P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````,NY=+,````>=%).4_______________
M________________________`.P8'%X````)<$A9<P``"Q(```L2`=+=?OP`
M``!K241!5"C/?8_)#H`P"$11JZV[MBZ@[?__IN"AJ9KXPNG-0`+`ARS%BK`I
MMP!`'FL1HQ`2\5GQ#,<8&Q[1/QLB_ANO&\;ESN1N=(*(A08J:29JAJ)B4>MM
MTYU:E5)KJP'",>V1_F01TM=#N``.&`S4"P>29P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;&%Y;W5T+G!N9P``````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`T-S(@,3`U,34T,S0Q-3$@,#(R-C0U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```$Y03%1%````H)Z7M[6PN+:QY,!!Y<%$
MQ<3`Z<MBZ]!R[-%U[M>'U];4[MB+V-?5V=C6VMG7V]K8W-O9WMW;\^.J].6Q
M].6S[.SK[>WL\O+Q````<9PG$P````%T4DY3`$#FV&8````!8DM'1`"(!1U(
M````"7!(67,```L2```+$@'2W7[\````!W1)344'U`P($ATZ8_WSQP```&5)
M1$%4>-IUS>$*@"`,1E'32LV:E:;M_5\TE<&PZ/NWR^`(["<$CL88N^*=<LYG
M#2;&&#0FYS:0%*X2<KE!]1_>MV!#F<8#P.\M+'43SE(I-=3P8<ECECQFR6.6
M/&;)8Y:\?_:]!]0]#R=FNP,R`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W)H
M86YD+G!N9P``````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-#(W(#$P-3$U-#,T,34Q(#`R,C0R-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````(0````X$
M`P```%,P:+\````84$Q41?___\#`P+^_OX"`@```_P``@````````%KM>%,`
M```"=%).4_\`Y;<P2@````%B2T=$!F%FN'T````)<$A9<P```$@```!(`$;)
M:SX```"*241!5"B1;<]!"H,P%`300<%U/FC6Y1?^NB20$Z@G4->)@;G_$;J(
M15HZFX&W&0;R$X?6GF3YD@S`6$3$P9,4#P!=-8HXC/.\,@,]U0)8FKP`&$ZM
M"FL2@)X82.I''C!0DPB+P[0L:U1-N6OS#N.V'3%H'L[G)=.^'ZR!,,HMXFND
MIDL\6?Z]N./>AT0E2TXNFA``````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]O9F9I8V4N<&YG````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q,2`Q,#4Q-30S
M-#$U,2`P,C(U-34`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@
M```ZF```%V^27\5&```#`%!,5$5W=G>6E9:3DI.2D9*"@8*!@(%]?7YY>7IX
M>'ES<W3'Q\C`P,&HJ*FAH:*+BXR*BHM^?W]]?GY\?7US='1K;&QA8F*9FIJ3
ME)2,C8V"@X-]?GUY>GEQ<G%P<7#)RLF6EY:4E92+C(N'B(>&AX:`@'][>WJ9
MF9B.CHV"@H&`?W]]?'Q\>WM[>GJ?GIZ=G)R5E)24DY.3DI*2D9&*B8F)B(B(
MAX>&A87;V]O9V=G/S\_.SL[+R\O*RLK(R,C'Q\?"PL+!P<&\O+RTM+2HJ*B@
MH*"?GY^=G9V;FYN9F9F8F)B7EY>6EI:1D9&0D)"/CX^.CHZ+BXN*BHJ'AX>&
MAH:%A86$A(2#@X.!@8%^?GY]?7U\?'Q[>WMZ>GIY>7EX>'AW=W=V=G9U=75S
M<W-R<G)P<'!N;FYI:6EH:&AF9F9E965@8&````#___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"!!K02````;7123E/_____________
M____________________________________________________________
M____________________________________________________________
M__________\`+;;42P````EP2%ES```+$P``"Q,!`)J<&````+I)1$%4*,]C
MR$$##!`J&PA@`MDH((<AV]P1"++!R-'1.9LAV\(J/<L)#+*`-$B`F]O!WH[+
M5L[&VLK2%2C`+<L9KR,8'JH4H&ZD+PP22$Z(U=*4##:6\#7P2@`)),9I"["8
MF2CZ,7E[Q($$&%2EPD.#`OR9%3S=I4$"[%$J8<J!$K[B\F)N,2"!Z`B-$!,^
M/T-&-3T7(9!`)&NH*;^_#U"#+F\$4(!'-#,C3215)BF!0X<M)1O3+^C>!P`B
M(4Q>NK[7G`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V1A=&%T<F5E+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-38V(#$P-3$U-#,T,34Q(#`R,S$R-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(!@```!_S_V$````&8DM'1````````/E#NW\```$K241!
M5#A/I9([:L-`%$6U&O>ILHB09`.!-")@2&\"(4U:@Y1"@J`_$>I490<JO!#W
MUO__>\D;&,_8D@NC@5.)<^^=08(@"+`0`=[E'WC:2%=Q__+!`I[?)+A;?U[%
M[:/(`O#T?7^1KNN@;5MHFH90516XKCL-\'W_1/S^__;[M3[*=5T3N2Q+L&U[
M/H!"`Y!S.<]S<!QG/F!N,B\710%9EEU>P,N\>//P2L#V-$U!5=7Y@#FP%=\"
M`[`]21*0)(D%C.,XF8PBG8RM*&(SRE$4@2S++&`8ALEDVDSEU69%B.,8PC"$
M[7;+`G#^^4/Q5\!F&H#MA\/A-`!E?B:=BFTH8"-*/(JBL(#]?@]!$,!NMR-X
MG@>F:1(,PP!=UPF:IH%E64061>Y77LBR\P>+KY)@9/";Z0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E
M9&ET+7-M86QL+G!N9P``````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#0T,"`Q,#4Q-30S-#$U,2`P,C,S-38`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@````D````)
M"`,```#73_8B````8%!,5$7FYN;XV3A/015E7#Y<3ROQM4WVM$37KG3\Z3Q+
M2TM(2$A%145#0T-`0$`Y.3DT-#0Q,3$N+BXM+2TL+"PI*2G___\`````````
M``````````````````````````````#^$])"`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?5!PX('RPM
M2;_:````.4E$050(UV-@``-.3DXH@X.5'\S@XF!C!K.X80P>1C9F`1"#EY&5
M11"LB(^=61BBC4E(!&82A&8``#M4`5)1:\F]`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<F5Q=6ER960N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,S`@,3`U,34T
M,S0Q-3$@,#(S,30P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````*````"@$#````M_Q=_@``
M``903%1%M0``````[V`["0````)T4DY3_P#EMS!*`````6)+1T0!_P(MW@``
M``EP2%ES````2````$@`1LEK/@```!U)1$%4"-=C^'^`X3,837)@:'!@>'@`
MA,Z`T?\#`-S_#M'`<*PM`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEN9F]?:6-O;BYP;F<`````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#`Q(#$P-3$U-#,T,34Q(#`R,S(V
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q410````P3
M&A0;(Q4;(QPC*R,X33)&7"]+9S!+9S-/;#1/;#52<#E6=$18;#U:>$!;>$I:
M;4)>?$9B@$IFA$MF@TYJB%5MAU-OC51OC%=SD5MWE65VB5]XDF!XD5][F6-_
MG6=_FFB#H6R'I6Z'H7>&EGV*F(&6K8"8LX>;KI:HO9BJO9FLP)RLO:*RPZ6T
MQJ:UR+"]SO__________________________________________________
M_________Z9W*WL```!`=%).4___________________________________
M_________________________________________________P#">[%$````
M`6)+1T0_/F,P=0````EP2%ES````2````$@`1LEK/@```(Y)1$%4&--UCU<.
MPC`01(<2FDWHA(02>@EU3I#[WXK=C2A"8CXLO;=C>8W\)RA.RT=@FYU/^S9>
MHGH_K%?I(IE4"H&',)G$T5`IQU3G9!R-!C6HR*ROW.^8N`F3%.Z%)JXZ)Y6]
MB8OV2>66B=U&[I/"+H`]>UP*D]XU4"Q6GL^T[^JE]^K=<>B;`?Y_[CM/A@TE
MPT"5T_L`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V1O=VYL;V%D+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S<S(#$P-3$U-#,T,34Q
M(#`R,S$S-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````P4$Q4
M18```````/\``']_?\#`P/___P"```#_`/__________________________
M_____]88PML````)=%).4___________`%-/>!(````!8DM'1`\8N@#9````
M"7!(67,```!(````2`!&R6L^````3TE$050(UV/HZ.AH8`02#""&(BY&`X.B
M($2$24D"1<K8V%C8V-B"H=D%#`P93$-!(-B0P03$=RN&,ER<@0QC$``QP&J`
M#&,(D&!H%`2##@#CYRHZJ'QM40````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]L;V=O=70N<&YG````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#<T-R`Q,#4Q-30S-#$U,2`P,C(V-#8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!`````0"`,````H+0]3````P%!,5$4````.$0P7'14=
M)1L@*1HJ-28Q/2PT02\Y1S-"5#U)7$)15$];6UI/9$A3:4Q<8%EL;&IY>7=@
M@4B(``"9``"9.2FB$@RP%@JQ&Q"J/RRQ33:S4S[(/BO?0A[D8D7G=5N-C8N9
MF9BHJ*:XN+;`P+W)R<?0T,W5U=+@X-[BXN``````````````````````````
M````````````````````````````````````````````````````````````
M``":P#W"````*W123E/_________________________________________
M______________\`(\FGT`````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```")241!5!C3=<_1$H(@$(7AHT:9E2:4I96":%CO_X#MDFG33/\%
M#-\%"WC^A/<Z]8&'ZUH]`>T$ULQ0P[F>(&#@F@ON'@*&FKI5L*U!&'HX4><C
M\BVBA8<#I2KL#81@N!:%4B5XBEB.E]+9CQ4Q@902)08"/0,P]&:#U3H9'Q;!
M9HB379KBW^>^>@'.J1531Y@N@`````!)14Y$KD)@@@``````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLN<&YG````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(Q-C`@,3`U,34T,S0Q-3$@,#(R-#$V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4`
M`("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%%Q\6%1P4
M'24<5V]3H[:@7798<8]K<(YJ;HMH;8IG7WA:7G=98'E;A9Z`@IA^9(!>8WY=
M46=,;HMG87M;6'!36G)5:H9D7'17;8-HAIZ!H;.=#1$,8WY<98!>4FA,:85B
M:(1A9'Y=87I::X=D:H9C:(-A9X)@6W-5;8EF;(AE:81B9X%@:8-B<HIL>(YR
M?(]WAIJ!A9F`C:&(DZ:.G*R8G*N8&B$86G%3'",:@)1ZB9Z#AYJ!C:"'CZ")
MGZV:H*Z;FZF5!PD&$A80````____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````-TUW
M-@```$5T4DY3________________________________________________
M__________________________________________\`LNZQ.`````EP2%ES
M```+$P``"Q,!`)J<&````(E)1$%4*,]C<$$##,0)2(.`L[,S7(#1SMK&R%@"
M*@"4,#,0T%%5$'$&L1F<31V<F0SYU;3$1)V=I5B<&9SM]6SY9/@5M#0UA'@E
MN8$")DIRYHJR6BH:PJP\;#Q``4M!9PM=;2UE#G%G9U:@"K!!5EKRG.Q<$$-!
M5CGIJW-S<3,CW.$(`L@.(\US`**0-\]!9$BP`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]D979E;"YP;F<`````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$P-B`Q,#4Q-30S-#$U
M,2`P,C(T,C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!
M34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```Z
MF```%V^27\5&```#`%!,5$46%A1)24,8&!;FYN2RLK#N[NU=7%6(AX&1D(JP
MKZFVM:]"03R)B(-V=&MM:V.0CH996%2=G)A@7E=E8UR7E8Z?G98H)R2`?71#
M0C^3D8NKJ:/5U-%(1D$V-#`A(!Z,BXG?WMS=W-H*"0CN[NX```#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````";5_"U````)G123E/_________________
M________________________________`*=Z@;P````)<$A9<P``"Q,```L3
M`0":G!@```!^241!5"C/;8_)#L(P$$,#92T-E(0A+%/6-___BUR2*@)\L639
MLNWL"RXS4`E@/#'(`N\9*LH2LK!?B<CND)02$>E#EWR.@$HX'0?9*I@S8]Y*
M?WM-FQ0#Q=$-[OZ(V6'&.K7-]1S'VO8B*7F_*"W0HUZ90+5T4RW]_?+O[8@/
MLHL?J"2](@``````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W=E8G-I=&4N<&YG````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-#`T(#$P-3$U-#,T,34Q(#`R,C<V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`P```"@M#U,````$9T%-00``L8Y\^U&3````(&-(4DT``'HE
M``"`@P``^?\``(#I``!U,```ZF```#J8```7;Y)?Q48```,`4$Q410```0<-
M%`H?-081'!`J1!@X6!8S41H]7PT>+Q@V508-%!T^8"!"9"5&9A@J/"]1<ATE
M+3]%2SL^06EL;R-$8RA,;1PU3"E):"]5=PT7(#)6=C-5<SYCACY=>4QPD4EL
MBT1B?TYOCAXG+WV7KC-8>"U,9SYDA#YC@TIPD%B!HEMZE5Y]EWV<M1TC*)"J
MOXZGO$!+5,;2W`,,$P4*#DUUE6&(IV*"FWN?NW^COXBJQ'F7KX&AN82DO(&@
MMX">MGV:L8VMQ8"<LHFGO8NGO3E#2YFTR)NVRIFRQIVWRIVVR9^WRJ>_T:&X
MRJ_$U*N_SRXR-<C8Y,?6XLW<Z`<*#!$8'2DV/X&CNY>XT)2US)>XSWV8JY*P
MQ%UP?8VHNZ&]T9NVR4-/5ZS*WC0]0ZW%UJW%U:K"TJG!T;S5YZ2YR*_%U;S2
MX<+7YKO0WCI`1,#1W<O<Z,;7X\76XDI05-CE[MGE[=CD[*^XOK:_Q=;@YU!3
M56F&F:O(V[+/XJ*\S:6^SK_9Z:[%T[O2X+[3X,?<Z<38Y,C;Y\;8X\C9Y,[?
MZMSI\;O1WM+>Y7Z%B3<]0)NHK]7D[$-%1E=>808)"@```/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&69
M\U$```"5=%).4_______________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________\`-F0;.`````EP2%ES```+$P``"Q,!
M`)J<&````,U)1$%4*,]CF((&&$"$R\3*"4*"2G"!7.&RDL[\P'+_$(A`;T]%
M?W-V2VFQ8<(DD$!H47=[4WUZ5F%`4(8N2,"@+R^NNB:QL<#7+R5F,E`@2=G.
M(2(\LJ,MIR$^B@$H(.#L%&9N8=G:E5FGIP@2D)3S3+8QU=2Q]_9RY`=ID91W
M3TNU-=&0\7'5Y@0)&(N9>=1JJ:E+Q$;+,H,$IC"*N^E+JTB)6EDS,8`=-IFK
M2H&'5X1;E6_R9(C3)P=SL+&SLAB!^!#/39D,!@C?(@,`OA9G/:GA:TH`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O<')I;G0N<&YG````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q,38@,3`U,34T,S0Q
M-3$@,#(R-#8P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```1U0
M3%1%````&QL;34M'3TU)4$U)44]+44],4E!,5%%.5%).85Y986!>:VIG;6UL
M;VYK<&]L=75U?WY[?WY\@'Y\@']\@8!^B8>%B8B%B(B(C8V-CHZ.D)"0DI*2
MDY*1E)*0E).0EI:6FYJ8GIV<GYZ;GIZ>IJ:DIZ>GJ*BHJZJGJZNJK*RIKJVJ
MKZZLL*ZLLK"ML;&NL[&OL[*PM+2TN;BUO+N[O+R\OKZ]P+^\PL+"Q<7%Q\;&
MQ\?'R\K)S\W-SL[.S\_/T='1T]/3UM32V-?4U]?7V=C6V=G8VMG7VMK9V]O9
MV]O;W=O:W-S:W-S;W=S;WMW<WMW=W][=XN+BY>7DZ>GIZ^OK[.SL[N[N]/3S
M]_?W^/CX^OKZ^_O[____````)[,>1@````%T4DY3`$#FV&8````!8DM'1`"(
M!1U(````"7!(67,```L1```+$0%_9%^1````!W1)344'U`P($BD($`!1L```
M`*I)1$%4>-IC8,`&XF``QH^%@K`XF("THZ.4@K6U"UP@-`0(0D.]X`(24E*A
M`D9&"(%0"$`(2(>&JJBKJ=E#!.),-.U,0<"25P8D$F<1$QL=&QT3$QT58:8,
M%(F+C@R6#'<(\O#W<3;48P0*6#EY^P8$^KEYNKN*RH-4V"IQ<7"RLK,P,;/)
M@@5LS(T-]'5TM50UM'4400)RPF+B(B)"@D+\?#S<<<A^!?L7`*0(,2F/S@[2
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O:&5L<"YP;F<`
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S,38@,3`U
M,34T,S0Q-3$@,#(R,C4W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P
M``#J8```.I@``!=ODE_%1@```P!03%1%````____'1T</#P[?GUWM+.MW=S6
M\O'KX>#:U-//T,_+R\K&R,?#\_+N\O'M[.OGY./?V-?3?GQUP+ZW=7-NAH-]
ML:ZH\_#JY^3>45!.9&-AW=O8A(%]MK.OV-71]?+N[>KFZ.7AXM_;96%<6552
MY^+>\N[KZN;C=G-QU-'/RL?%NK>U\.WK].GC"`8%R;NT+BPK.SDXIHZ%\-+'
M]./=9$Y'W+RQZ,F_RE4UZ6Q*Z714XX%FXXQTDUU.[I=_K7AH[JB5\*J7X;.F
MX[JNV;FPJ#09WTDFS$@IY%$OWU$PS$LMZ&%!UV-(Q&)+T&M3TVY6ZGMAR'5A
MFUM,UI.#TY."Z**1\:F8WJ&19%51YN+AD2T6J#4;;R,2E#`9U$DIND0ID#\M
MUGUI[9%\Z+&E`0``"PH*14)"'QX>#`P,____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````&&B<[````&IT4DY3________
M____________________________________________________________
M____________________________________________________________
M____________`+SDW.,````)<$A9<P``"X8```N&`4$'9;<```#"241!5"C/
M8\AD8``B$,@`,2%80XZ/74);*A7(!,N'&BL**/(KV+@R9()ALF.B/JLPA[F'
M6TP*4`V39)A/;$0Z@V1"@+>7J0%02V1XO"'0H$P&WR0G99`9?%Q&AID@8*BK
M)`H2$-<48P`+,/`*BH`$5*6YH2ITM,`"VNK.06`S0EQDF8$"J9+65G:!0(<&
M^[O;IF6`W!'M:>F@)F_B%Q<5Q0!Q:8R%&1LGCSV(#Q;08Y"4$6+14`%S(;Z!
M>!?JTTPT``!&\3>*6Y.B]@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]S:&5L;"YP;F<`````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<S-"`Q,#4Q-30S-#$U,2`P,C(T-#``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````P%!,5$7\_OQ<LOQ,KOR4CJ04
MBNQ$=J04=MPT;KP\:K0T:KPL:K0\7J1$7FP\7G0T7G0T6G0L4H0T3GQ$2F1,
M2DP\2EPD2IP<2IP<2I0\1EP<2H0,1HP</G0D.EPD-E0$.F0,+E04*E0,*E0$
M*DP,)DP,)E0,)D0$(D0```#___\`````````````````````````````````
M``````````````````````````````````````````````````````````!V
M=%24````*7123E/_____________________________________________
M________`%+T((<````!8DM'1#\^8S!U````"7!(67,```!(````2`!&R6L^
M````@$E$0508TUV/BQ*"(!!%KY;2P^RQEJ6DU/KZ_R\,U[#DP#++G3/+@,$#
M57Z;US7O!A2[[1>EU.;1(EX[@C!8[3M$1\<A39,3(^O_X1KWG@"R/<;`O&P`
M(MBKI&)@L@F3D3E#%#:_&:*(X;UR6036.#^UUF/)63+>IN%FWMS"__X'6+$;
MU2?4JQL`````245.1*Y"8((`````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O961I="YP;F<`````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$S-C4@,3`U,34T,S0Q-3$@,#(R,C4W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```8!03%1%1D9%_.D\^-DX3T$595P^7$\K\;5-]K1$
MUZYT_O[^_?W]^_O[\?'Q[N[N[.SLZNKJZ.CHYN;FY>7EXN+BS,S,RLK*Q,3$
MP<'!O;V]N[N[IZ>GA86%@("`?GY^?7U]?'Q\>GIZ>7EY=G9V=75U<W-S<'!P
M;6UM:VMK965E8V-C7EY>65E96%A845%134U-2TM+2DI*24E)2$A(145%0T-#
M0$!`/3T]/#P\.3DY-C8V-#0T,3$Q+R\O+BXN+2TM+"PL*RLK*BHJ*2DI)24E
M(R,C(2$A'1T=&1D9%Q<7%145$A(2$1$1#P\/#`P,"PL+"0D)!@8&____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M]I&F_P```%)T4DY3____________________________________________
M____________________________________________________________
M____`*TM#'$````!8DM'1'](OW'E````"7!(67,```!(````2`!&R6L^````
ML$E$0508&07!O2X$`1@`P/E^K+U"H7$EE0B%1$$0#^&U"4(BD2L5.H50[&V<
MF(E;]R(S,N($VOTGB$6_'2&EJJK*^OE:H24CDUZ^?U0=M&*"=?R>OFQMM62!
M*>>SIV%3+<4$T^'CL#E?M@BC:;3_.&PN]K1D+>;#A_Z[;%+*<1RCAK^K5=&"
M-<=WU_VTG;02V_-0-\]"TEK,YM<(%*T("")IM1,0B.]=;3E&1F1D1@3_[NPI
M6*[)+;L`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O:V5Y8F]A<F0N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`T,#$@,3`U,34T,S0Q-3$@,#(S,3(P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`0#````[=WB4@```!Y03%1%``````#__P``@("`H*"@_\#`
MW-S<P/______````:ZQ_]0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$Q(KE=A-Z@```%Q)1$%4
M>-IC8&#@G`D"#$"&NH2&4"6((52AH2[)`!:?6M'),%&PHTEIDI(FA#$]`BHR
MHPBJ!J1]1AH8>#),:P$#(,,%!#R`C`X/(.B`B;B`U'0``5!J"D3$$FX.`.IO
M,6]W<W?K`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9A
M=FEC;VXN:6-O````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,3<V(#$P-3$U-#,T,34Q(#`R,C<T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````$``0`0$````0`@`&@$```6````*```
M`!`````@`````0`@````````````(RX``",N`````````````````/\```#_
M````_P```/\```#_````_P```/\```#_````_P```/\```#_````_P```/\`
M``#_````_P```/\```#_V-C8_]C8V/_8V-C_V-C8_]C8V/^AH:'_#GQ@_Q;7
MIO\5SZ#_&$U`_]C8V/_8V-C_V-C8_]C8V/\```#_````_]C8V/_8V-C_V-C8
M_]C8V/_8V-C_WM[>_Q%61?\6TZ/_%M.C_PU_8O])4E#_L;&Q_]C8V/_8V-C_
M````_P```/_8V-C_V-C8_]C8V/_8V-C_V-C8_]W=W?\15T;_%M.C_Q7+G?\5
MSJ#_$K*)_PMI4?\Z3TK_FIN:_P```/\```#_V-C8_]C8V/_8V-C_V-C8_]C8
MV/^=G9W_#7YA_Q;5I/\5RYW_%M&B_Q;8I_\7X*W_%<>:_QP[,_\```#_````
M_]C8V/_8V-C_V-C8_]C8V/_<W-S_)T4^_Q3"EO\5SI__%<>:_Q&D?_\0F7;_
M#Y%P_PV"9?]'5%#_````_P```/^5E97_T]/3_]/3T_^7EY?_)D@__Q*MA?\6
MT:'_%M:E_PUW7/]:75W_@X.#_Y"0D/^=G9W_S\_/_P```/\```#_#H-E_Q!=
M2?\07$C_#H%D_Q3"EO\6T:'_%="@_Q&E?_]&44[_V-C8_]C8V/_8V-C_V-C8
M_]C8V/\```#_````_Q;4I/\6U*3_%M2D_Q;6I?\6T*'_%<N=_Q;3H_\/CFW_
M?GY^_]C8V/_8V-C_V-C8_]C8V/_8V-C_````_P```/\5RYW_%<N=_Q;3H_\5
MSI__%,"4_Q;.G_\5SZ#_%<69_RI&/__8V-C_V-C8_]C8V/_8V-C_V-C8_P``
M`/\```#_%M&B_Q7.G_\->5W_'%%$_S=)1/\+:%#_%M&B_Q;:J/\,<UG_K:VM
M_]C8V/_8V-C_V-C8_]C8V/\```#_````_Q?8I_\2L(C_2DY,_]C8V/_8V-C_
MC(R,_PM81?\6TZ/_$[>._TE/3O_8V-C_V-C8_]C8V/_8V-C_````_P```/\7
MX*W_"V1._[FYN?_8V-C_V-C8_]C8V/^AH:'_#DD[_Q9.0/^8F9C_V-C8_]C8
MV/_8V-C_V-C8_P```/\```#_%<27_SI,1__8V-C_V-C8_]C8V/_8V-C_V-C8
M_[Z^OO_1T='_V-C8_]C8V/_8V-C_V-C8_]C8V/\```#_````_R4_.?^@H*#_
MV-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_]C8V/_8V-C_V-C8_]C8V/_8
MV-C_````_P```/\```#_````_P```/\```#_````_P```/\```#_````_P``
M`/\```#_````_P```/\```#_````_P```/\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQA;FLN9VEF````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P-3(@,3`U,34T,S0Q-3$@,#(R,S<R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y80$``0"```````#___\A^00!```!`"P``````0`!`$`"`4P`.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V1A=&$N<&YG````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q,C`W(#$P-3$U-#,T,34Q(#`R,C(S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```$L4$Q410````$!`0(#`P,$!`,$!04%
M!08'"`<'!PH)"`D*"@H*"@L+"Q86%!@8%B$@'B@G)"$V2#8T,$-"/TA&03I,
M6TE)0UE85$E@<DQ@;5U<56!>5T]D=5EC;65C7%1I?&UK8W)R<'9T:VMX@F=[
MBX!]=(B'@8F(@XR+B<=T9L=T9XR,C,=U:,AV:)".AI"0D).1BW^:KK>'?H&:
MKI>5CH.>LH2@M<V&>LB*@)^=EIV=G8:DN8FFO*&AH=&/A(RHO=&0A(VIOM.1
MAJNIH["OJ:BQO;:UK[:VMKJYMJZ_S<#`P,7%Q<C'PK_+ULW-S<?/VK_5Z,K6
MW]74T=;6UM?7U\O=Z\_@[=_>W-OG\>;FY.;FYNOKZ^[N[O'Q\?+R\O3T]/?X
M^OGY^?S\_/[^_@```')J$C`````!=%).4P!`YMAF`````6)+1T0`B`4=2```
M``EP2%ES```+$@``"Q(!TMU^_`````=T24U%!]0,"!(G!?`R`(,```#4241!
M5'C:8V!(1@$,#,GQ(>:V8&!OZ^COG\R0'.Y@J*T)!!J:.F8.<D"!4(?@)"A(
M,)6&"$!!4(R1.$)%8EP4(R.C.%R%&Q>7):L[LPA8(#HI*99;2X%;V$*8114D
MX!'@Y\/I[6IA8:%KK`(2<+`V,%)FL[`0DU)3400)V+EX,3(*6T@)\0M:R(,$
M3+V\DM5=+<3X.'@C0%JLC+Q\DYF$+=0$>=3#9!F2E4R,?",%)+B<55PC`O5E
M@;Z3D;;QU&-W=;)045%4E&1@@/E?+%E843A9%`"Q]3V#,(]ZVP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%D;6EN:7-T<F%T:6]N+G!N9P``````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P-38S(#$P-3$U-#,T,34Q(#`R-#,U-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`(`P```"@M#U,```!@4$Q410```*VME,Z<,?_.
M8\;&QH2$A._O[S$Q`)QC`&-C`/__G/__`(0``/\```"<_P``_\[.,3$``,Z<
M````A%-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[U-;[YN4(2\`
M```@=%).4_________________________________________\`7%P;[0``
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"`241!5!C338Y9
M%L0@"`3;)>."XY(<@/O?,H(^9_JOZ@$-F!D[+,'!;0X8^R^<AW5[9;&#P1%>
M&-;8:XO)'V>"^[5,8^8$8D*<@N&M["#F3(@0OO2'E!-(2[Q%*5^.1%%$;6H+
M*'1"`EIMDI#'/9#T:*W/@SSZ2%J[@GXK'\%8S"]NN`PJ:B0_<P````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M87!?974N<&YG````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,30T,2`Q,#4Q-30S-#$U,2`P,C(U-S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3```!@%!,5$4``,<!`<<"`L<"`L@#`\<#`\@%!<@&
M!L@&!LD(",D)"<@,#,H-#<H/#\H0$,@7%\`6%LP8&,T<',,='<X?'\TB(L,F
M)K`E)<0J*K$G)\XG)\\I*<4L+,8R,K0O+]$Q,=(V-K4W-[$W-\8\/+$]/;$Z
M.M0\/,D[.])`0+-!0;<^/M5&1K-"0M5)2;9*2K9-3:=,3+5-3;124J-55;A2
M4ME96:=96:I:6KE=7:=86-IB8KI>7MQG9ZEF9K9G9[EL;*EM;:YN;JQU=:UX
M>+!Z>K-\?+!V=N%W=^)\?-J#@[^'A[&'A[*(B+:5E>>AH>NKJ^NQL>BVMN[#
MP_+7U_3CX_CCX_GDY/?Q\?SR\OS^_O______________________________
M____________________________________________________________
M____________________________________________________________
M__]EOP2D````@'123E/_________________________________________
M____________________________________________________________
M____________________________________________________________
M________`#@%2V<````!8DM'1'](OW'E````"7!(67,```!(````2`!&R6L^
M````KDE$050H%07!AR)6`0`&T'.1O4)&9LOX94OV=LVDN,9]F>_5G2-)LK\X
M,SG_*TDBR>E(`0:VDT@..Z%KNE_+6B(G;>##??59\WID'+1^'/SW/*8OC@K8
M>ZKKNGYLM6(5-M_^_/SQ\-K@B^_P_R]7+PV,6H#J4N_.%`S;@*H$^.:B0%4"
M;,E75"7@4^2VAZH$VH\CN>XV-P0Z#A));F:;H)@X2R))<K>[O/3[/$GR#E6O
M*XP$OAO-`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]G;V]G;&4N<&YG````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S(R-R`Q,#4Q-30S-#$U,2`P,C(V,#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```$L````@"`8```!:?85S````!W1)344'TPD:"`(C](A3XP````9B
M2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!B1)1$%4:-[M
M6'],5648?N`"*GB]>N4W>C&T0`.*P!\HA@*9.KUN*A:1DN4H'8GI$-9F\D>I
M25I-U)!F.I<!M6P(&4F[M=Q<6UI3BO[H#[=,^Z%M;5&;*[Z^YXMS._=P#DYN
M;,S.NWT[]Y[SP?GN\SWO\S[O!]AAAQUVV&$'&D0X9A6/0G&+8UBO,Q\C48G[
MPW:B,J0>1T*VXF=XD3KT+R8X^4U/([^C'>FO^]3(:NY&7N=YY)VNQ_RFQ4*(
MX0565W$$#B`6U7A&`345AX;^I?,/%2"KZ2H\%0>1O#Q-`V7:-$1@2OE23&FX
M@HPO!)(/]&+RX[G#CF%[\`0JT(M)V#K$0#4M1EJSP/AE2P><YUYQ40T7QOT_
MP9(LPLR/>N$NW';3N7$/SE-,&X9!S5)@)>*QH7O+0M^;B*YAU@4%0GDV(MOB
ML.I\$FHX]L5C!>]9S7]A(^*^?1>5VMB^!MX!-V+)]FCDO)>%J=/OQ@A7BKK.
MJ%^I[FE@E4.8@=7D1I&V+G[V/XB(7A0P1L8GJZMI>/)24'"A!VZO+QB@BIW(
M;7'AZUUCL&W]""S@]1,W>B_$X=IJ64^-\T^\A*T=N^$C0!Q'JO'RE9/H^:4=
MU_A=/[>L3%:[>6T[D-[0B.2J%]5ZO9=_5?K*[SF')ZK?O1?/*K`FA)=H?^L=
M#V=[#-JJ(W%PBP,K>>V*@N!:%?@:8$;@3(,[PQ0<6_C&8($J<.&^$V,A>`UX
M('?_;`1$9PC$=,E?/5`?[,`?*!8!+%HT"QF7CT-PC`S#;-Y318;,3ZY\6_]_
MD=;Q3Z'A9XTD1K"$<&A`Z=_S6A0VO26?+@I%>S^P]-=^L>K[.O7BP8+E]3J_
M3,29#1$X9_:8#.MR0&P(P0_\GC`-'C)HID?^+),@PVZT0E2MP"5_A>9F1D;>
M&S`Q>^\V))T5^HP(>16U,@']8#'="`HR'XC5YCR2@Q0"6.+`=T6A6']K/Y;T
MSN1+984;1+2G8=W%&-Q8Z,!1L^=%3MQ)VE=QT0G%'FK3^?T0&9.PS&P^V46P
M]I3*^:RXW$S7,3_3`N0C]8Q`?,5O`6"169X(E?;G/#A0%RH%'QA/X$[&XG!=
M)%KT++^UH'_*ZA84>`KN@.(ZZ^`,53FY4/F9*<(%,=7\E#8$YU"WRD/Q)Q?Y
MXVDT,@73[\"C5EU#3R=^)UAQ44A'T5?U"I31>77]="RIV9Q9?6!=2L*'^R2K
M%X2B='\DUG+C@JN$;HQ11E.]V,(Z4$#IWE-W'E?.G@([>6<W'W&WF&:DM=4K
MF*8$2XI+.L$BL]8NM';9USO0O=F+O^:F(4&97U>'VDRU5BUXWU$A])HE?58`
M6$RW5KE?5BD_N&"58?Y+P4Q--.FI]+TAM2+A??].TQY(U(2B.TNY2?C&X9N'
MF89]XAZ@229QZ1U<)UC_^D!9\0A,<NU/RCRK3D.V8-+S&4QIK5[@*>1<6W6X
MU,O_JK]E>56M#$&8VGJ-VF+=M,J^D4Y?EQ8-HW&*.U@2C@[C]-P4Q!)(OYC.
MKG*265:I2`$^6HG>PBP\I+\?!=G[Q3^YTL]LDRQ0U9"FM(]99"(K,0>URDHF
M;CTF9B4JJDLQ51I!2V%5$+C+^NHI*R(!X>!NZJ?3SQA!I(\B(!P$1[]P@CA0
MBF)N:XW2V`E;/C<^XHF#2D-=NT.]HFYQ,\GP7?=@!N^WN9#-M4H$!VG$F?]Q
M:TYAU&;)G$:AJ)Y[LE$M<$YG);*/[U9:Q3G&%)!_2U!8];B+M`QDG/(X/!4P
M!)E3NQI7"1CM@F92^=ER?9*5:BW,`.H83T1X2J(U^V7X&#FX*MW>9YB.C=I[
MR6IJ9E6?7!"\YT;@4P(6=%HR=>":N5Q1G2<0$S?5P//4:HKJ36DKRST=/,?V
M4IT@6P291::I'7?WG^_S(4RE/H%A@>%:N"Y:!NJLW#PUQYA:/.,*O.E@@6&G
M$7Q5'(:1F2FEBNZ=;#;HJ-(PZBPS8.R<"OND=O:Q=2PF3B?N,D=3.G-J;!"M
MVNT3K'R2.:9VQF\K9']H,ZO/_U'(65"L#@&D]PKV:.FV"-72*(OPO%#>CET$
M4Y.#59JB+_L^FU6&TUG$+'E%,8Q'-73T[&GML,,..^SPQ]]44XI>\"A>M0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O<V%V92YP;F<`````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$P-3(@,3`U,34T,S0Q-3$@,#(R,C8Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```0````$`@#````*"T/4P```/E03%1%```%$2@U$2PZ$RT\&#!"&C%`(39(
M+3E)+D-3+T96,TE:/D]<26!R3V1U66-M5&E\6&V`6G"";FYN7WF):WB">GIZ
M@(:,@(>/AH:&QW1FQW1GQW5HR'9HD)"0?9>L?IFM?YJNMX=^@9JN@YZRA*"U
MS89ZR(J`G)V=AJ2YB::\H:&AT8^$C*B]EZ6PT9"$C:F^TY&&G:FPGZFPJ+&]
MH;;$LK*RN;FYKK_-O[^_P,#`PL+"Q<7%O\O6S<W-Q\_:SL[.O]7HRM;?U-34
MUM;6U]?7R]WKS^#MV^?QYN;FZ^OK[N[N\?'Q\O+R]/3T]_CZ^?GY_/S\_O[^
M````86H!I@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3
M```+$P$`FIP8````!W1)344'U`P4$BLY:2?;+P```*I)1$%4>-I5S]46@D`4
MA>&Q"P-;%&/$#NPZHBC6V/#^#^.`HR[_RV_MFXV0\1="QGU?;5EU6SU5-9!Q
ME$M9@981<A4Y3.$@[W360PJ^@:5=,/=;/&^$?(&V!=H'SKI^)69G!M/-:FDU
M8B`WBIA6R&,&[2'`FNQJOB0#"<#IUV#BB'0LJ&-0O#S`S,;W38B7L7)RQV`Q
MMO,#SGP7"C;GHIB.)CR!E(O"_W_T`NK@-G<JJ?0U`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;F%V+V)O='1O;2YP;F<`````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`T-S<@,3`U,34T,S0Q-3$@,#(S-#(U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```%103%1%````"`T1*D-;,U)N-UEX
M/V6(16^6272<3'FC4("M6XBR7XNT9Y&XD;#,E;+.E[/.FK7/F[;0G+?1GKC1
MH+K3I+W5K\7:LL?;M<G<MLK=OM#A````%+0D>`````%T4DY3`$#FV&8````!
M8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$2X,
M0*55$````&1)1$%4>-IMC5D.@"`,1.M2]P4*+LC][VG1B"7ZOCHODPX`XV\@
MXG<]UI44JS582K&12H7["*U?$?X[12R>(=^9Q1(BYK'3$I'(P<Q69H"LGY+,
MG2;-;,0IN<3!&S3P+!;^IW$"Q/H)S<'Z7PP`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VYA=B]D;W=N+6=R97DN<&YG````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P-#4P(#$P-3$U-#,T,34Q(#`R-#`R,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```!(4$Q410```%-34W=W=X6%A8V-C924E)>7EYJ:FI^?
MGZ6EI:>GI\/#P\3$Q,;&QL?'Q\C(R,G)R<O+R\W-S=/3T]75U=;6UM?7UTM+
M2[5P#O4````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$P``
M"Q,!`)J<&`````=T24U%!]0,%!$Q`?-.)S,```!9241!5'C:8V`@"HA#`)*`
M*#\W&RNR@+"@``LSLH"(`!^J@!B&`#\_0@!DOA@?R`R81>*<`D)`0UE8F.!J
M.`0$!)#X(!%>060^`P,C%P\*'ZB&71S=.S@]"@`/C05M$J,=MP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&%S="UG
M<F5Y+G!N9P``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4P,R`Q,#4Q
M-30S-#$U,2`P,C0P,38`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3
M````45!,5$4```134U-W=W>!@8&%A86-C8V4E)27EY>:FIJ?GY^EI:6GIZ>L
MK*S#P\/$Q,3&QL;'Q\?(R,C)R<G+R\O-S<W3T]/5U=76UM;7U]?;V]M+2TMS
MECH$`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3
M`0":G!@````'=$E-10?4#!01,BWJNQ@3````:TE$051XVGV/VPZ#(!!$T8HM
M7F%H%>?_/U1@H0^F]B1D=T[V85#J-RR#K$(6'E\QY(U@NDK`L(K]LX40WC!-
M$<X#SGJL(T7,L-8!\,N+G*)XZD(;@XZO[Q(YBQ!RSJ+T:*6'OC9]\.XO?S@!
MA6H)@?X`Z3X`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+VQE9G0M9W)E>2YP;F<`````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-#(@,3`U,34T,S0Q-3$@,#(T
M,#`W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```$503%1%````
M:6EI=G9V=W=W>GIZ@8&!C8V-EY>7F9F9K*RLQ\?'R,C(R<G)RLK*R\O+S,S,
MS<W-SL[.T-#0T='1T]/3W]_?2TM+!6U78`````%T4DY3`$#FV&8````!8DM'
M1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$3,0J\AE
M0P```%9)1$%4>-J%CTD2@#`(!..^!$1-PO^?*E$X&$OMVW11##CW`I>Y$)RX
MR,07EK<]Q!!I8LVP$GJ/\W"**N$"`"B,.M'T2F<[Q-29UKK$W%JR^;OT^<L'
M!QWK!4V>PL-)`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VYA=B]D;W=N+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-#4T(#$P-3$U-#,T,34Q(#`R,S`V,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,```!+4$Q4104`"@@-$2I#6S=9>#]E
MB$5OEDETG$QYHU"`K5N(LE^+M)&PS)6RSI>SSIJUSYNVT)RWT9ZXT:"ZTZ2]
MU:_%VK+'V[7)W+;*W0```(9?Z@<````!=%).4P!`YMAF`````6)+1T0`B`4=
M2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!$P$QGL9SH```!:
M241!5'C:8V`@"DA``)*`&#\W&RNR@(B0(`LSLH"H`!^J@#B&`#\_0@!DOCB?
M`%``9I$$IZ"PD``+"PL37`V'@(``$A\DPBN$S&=@8.3B0>$#U;!+H'L'IT<!
M*N<%G#41(%\`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]N878O9FER<W0M9W)E>2YP;F<`````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#0V-2`Q,#4Q-30S-#$U,2`P,C0R,3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````2%!,5$4```!I:6EV=G9W=W=Z>GJ!@8&-C8V7EY>9
MF9FLK*S'Q\?(R,C)R<G*RLK+R\O,S,S-S<W.SL[0T-#1T='3T]/;V]O?W]]+
M2TM"F7`E`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,`
M``L3`0":G!@````'=$E-10?4#!01,@RFT@A-````9DE$051XVH6/V0[`(`@$
M[:$]Q-J3_?\_K8J:U)=.0@+#`XM2+0!R4\2#O"B"4@?^"K"'(`)\G-=]W7X1
M`:;=.VO=.H5A0<=N(R(7F(,PH0:3T2*2Z2-C%M'4*T9R##6';I.VO_SR`NZ.
M"&10MEC>`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+W)I9VAT
M+6=R97DN<&YG````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-#<@,3`U
M,34T,S0Q-3$@,#(T,3<W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```$A03%1%````4U-3=W=WA86%C8V-E)24EY>7FIJ:GY^?I:6EIZ>GP\/#
MQ,3$QL;&Q\?'R,C(R<G)R\O+S<W-T]/3U=75UM;6U]?72TM+M7`.]0````%T
M4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````
M!W1)344'U`P4$3,J;<2\\0```%A)1$%4>-J-CED.@"`,1.N.6QE<VOO?U(B`
M"6KB^YO72:9$7^A#Y$9[O6\>F&AT7S<166"*(*P#+#O,P]71$<P6@)LZ;[2M
M`V5H--5)RG$EY;B5Y9=/Z2\'+RT%;2>JT]4`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]R:6=H="YP;F<`````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#4S(#$P-3$U-#,T,34Q(#`R
M,S(S,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```!+4$Q4104`
M"@@-$2I#6S=9>#]EB$5OEDETG$QYHU"`K5N(LE^+M)&PS)6RSI>SSIJUSYNV
MT)RWT9ZXT:"ZTZ2]U:_%VK+'V[7)W+;*W0```(9?Z@<````!=%).4P!`YMAF
M`````6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,
M%!$S&DL=C%T```!9241!5'C:C8Y9#H`@#$1QQXT.N+3W/ZD1`1/4Q/<WKY-,
ME?I"'B(WTLM]\U@=C>SKQLP+=!$$.8",PSQ<'1FM,03`39TWTM:!,C2:ZB3E
MN))RW,KRRZ?J+P=*]P6<F9:-H@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]N878O;&5F="YP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#0U-"`Q,#4Q-30S-#$U,2`P,C,P-#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````3E!,5$4````<+3TI0EHJ0ULM
M1V`T4V\_98A)=9Y+>*)HDKF:M<^;MM"<M]&>N-&?N=*@NM.CO-2DO=6FOM6J
MP=>KPMBNQ-FOQ=K$U./%U>0````HJ"[J`````7123E,`0.;89@````%B2T=$
M`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!01,C9@WM'_
M````5TE$051XVF-@P`$DT?EH`I+BDFA\`4D(@/&%A$7$1$0%."6A?!Y!`3YN
M;CXN=K``HP0?/R\O#Q\0<$!5,+-!`2O,#*`($PBPP.P"BJ#8`A(AY%),O^`!
M`&W]!=8#5?25`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;F%V+V)O='1O;2UG<F5Y+G!N9P``````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`T-S,@,3`U,34T,S0Q-3$@,#(T,S8U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```%%03%1%```%4U-3=W=W@8&!A86%C8V-E)24EY>7
MFIJ:GY^?I:6EIZ>GK*RLP\/#Q,3$QL;&Q\?'R,C(R<G)R\O+S<W-T]/3U=75
MUM;6U]?7V]O;2TM+.&]-50````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$2\X>`J0Y````&-)1$%4
M>-IMC5<.@#`,0\,(>[0IH^3^!R4%45*!O^PGRP80\2V(XMV.=:7!Z@A+#38R
M*?`?8.T+PKXW8>,YXHX6&47,8Z<E(I4#F9W.`%D_)5DZ39J%**MU@4,^:)!;
M+/BG<0*@:PF!S%;@'0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VYA=B]T;W`N
M<&YG````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#<T(#$P
M-3$U-#,T,34Q(#`R,C<R,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M
M#U,```!74$Q410```!PM/2E"6BI#6RU'8#-2;C13;S]EB$EUGDMXHF>1N&B2
MN9JUSYNVT)RWT9ZXT9^YTJ"ZTZ.\U*2]U::^U:K!UZO"V*[$V:_%VK[0X<34
MX\75Y````)8R$A8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,%!$S,PFO%#$```!>241!5'C:7<])
M#H`P"$!1''&L6.?*_<\IIC%2_HX74E(`UH'$EY,ZE*H(=B.601K?G,Z!"DYF
M-Z,2#NLRX2\<_.8%/GFO[>0P5V?Y'$E`/;I;.,B`'PST35N7&M3/'OWL"AQL
M[V(>`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O=7`N<&YG````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0U-"`Q,#4Q-30S-#$U,2`P
M,C(U-#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````3E!,5$4`
M```<+3TI0EHJ0ULM1V`T4V\_98A)=9Y+>*)HDKF:M<^;MM"<M]&>N-&?N=*@
MNM.CO-2DO=6FOM6JP=>KPMBNQ-FOQ=K$U./%U>0````HJ"[J`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4#!01-!&3CL,2````5TE$051XVF-@P`$8T?B2$I*H?'$^9DD4/@\_&Y*(
MI+B0("\;0D127$!8`"@`$Y$$`A$^'C8F$`.F1HR;#RB`9*@(NH`H'YJ``!>:
M`"<[!RL+L@`$,!`'``[-!=9^K>YR`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;F%V+W5P+6=R97DN<&YG````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`T-#$@,3`U,34T,S0Q-3$@,#(S-3`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````0````$`@#````*"T/4P```$503%1%````:6EI=G9V=W=W
M>GIZ@8&!C8V-EY>7F9F9K*RLQ\?'R,C(R<G)RLK*R\O+S,S,S<W-SL[.T-#0
MT='1T]/3W]_?2TM+!6U78`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$30B+%ZB!````%5)1$%4
M>-J-S-D.@"`,1-&ZU8U:%9C__U0QAHA-2+Q/S$D#4:7&;$28+1T^VVU<".*Q
M.WX%44]-D`4I+X[;^Y%OPBH)BD^]A2`&=#$PC]/0E_!$_[H`QWP%3?LQ$R,`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VYA=B]T;W`M9W)E>2YP;F<`````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-#4S(#$P-3$U-#,T,34Q(#`R,S8V,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`(`P```"@M#U,```!(4$Q410```&EI:79V=G=W=WIZ>H&!@8V-C9>7
MEYF9F:RLK,?'Q\C(R,G)R<K*RLO+R\S,S,W-S<[.SM#0T-'1T=/3T]O;V]_?
MWTM+2T*9<"4````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0,%!$T"8#B6T0```!<241!5'C:7<_K#H`@
M"$!ANDA9D)4F[_^FT5H+.?_XQF0"B`TTN4B+J(47_,9;!VU2Q<T\2#/3AD:D
M'COA+U+3F10^>:YE)NS-62DK*YA'LX?"#M+B($YS&"V8G]WX/@ADH<52L@``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]N878O;&%S
M="YP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4P-2`Q
M,#4Q-30S-#$U,2`P,C,P-30`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````5%!,5$4````(#1$J0ULS4FXW67@_98A%;Y9)=)Q,>:-0@*U;B+)?
MB[1GD;B1L,R5LLZ7L\Z:M<^;MM"<M]&>N-&@NM.DO=6OQ=JRQ]NUR=RVRMV^
MT.$````4M"1X`````7123E,`0.;89@````%B2T=$`(@%'4@````)<$A9<P``
M"Q,```L3`0":G!@````'=$E-10?4#!01,A2UOI`;````:DE$051XVGV/R0Z`
M(`Q$<<%]@8(+SO__IT#1@U%?0MIYZ6$0XAVD`5R"%QRWZ.(&0K@*F!:7V-?-
M.;=0FR6A+9%6EN8>+$:CE"8B.S7`X$4M$[D/TK^J#,3,@HDYBM0CYQ[RV;3`
MUU]^.`&QB0G-5`N:OP````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;F%V+V9I<G-T+G!N9P``````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,#8@,3`U,34T,S0Q-3$@
M,#(S,C0Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```%=03%1%
M````'"T]*4):*D-;+4=@,U)N-%-O/V6(276>2WBB9Y&X:)*YFK7/F[;0G+?1
MGKC1G[G2H+K3H[S4I+W5IK[5JL'7J\+8KL39K\7:OM#AQ-3CQ=7D````EC(2
M%@````%T4DY3`$#FV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`
MFIP8````!W1)344'U`P4$3$6<)VB]````&A)1$%4>-J%C\D.@"`,1-UQA8J*
MBO/_WRE2))&++VG2OAXZS;(4`*%YQ8FP>(7T'>Q7P&HP+&#7S1QFUP,+6+EH
MFB8:6S?TR"^:E9+DZ)P0KDH1:%AX4SQ403PF7A&<HXPYZC1I^LLO-_%,"AQ[
M;Z;K`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6IO:6XN<&YG````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`Q,#$T(#$P-3$U-#,T,34Q(#`R-#`Q,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%````!0(`P```+I7[3\````)4$Q410```/___P```'/&
M@W$````#=%).4_\``$3N\#,```&O241!5'@!`:0!6_X``0$!`0$!`0$!`0$`
M`0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!
M`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!
M`0$``0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$`
M`0$!`0$!`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!
M`0$!`0$!`0$!`0$!`0$!`0$``0`!``$``0`!``$``0$!`0$!`0$``0$!`0$!
M`0$!`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!
M`0$!`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!
M`0$!`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!
M`0$!`0$``0$!`0$!`0$!`0$``0$!`0$!`0$``0$!`0$!`0$!`0$!`0$!`0$!
M`0$]20&"G%.YDP````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<RYP;F<`````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S8W(#$P-3$U-#,T,34Q(#`R,S(U
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W
M!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E0
M3%1%D)"0````____B0!/(0````-T4DY3__\`U\H-00```&5)1$%4>-IB8&)D
M8H!B@`!B8&)B``(F)H```B)&()N)@9&!"2"`@&PF$!L["1!`8)(1QF2`:`<S
M&1D9P1A%%*86((`@FO$SH;K0%3`R$J\6"@`"#(E)MB`#F@JX("/1@MAH,IT$
M`$"6`M#G"@OV`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]T<F5E+V9O;&1E<F]P96XN<&YG````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3,U-2`Q,#4Q-30S-#$U,2`P,C0T,C4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3```!@%!,5$7]\]3]]MS[Z+ES6".BBE3&
ME4+$N:/$C#WW[=;&O*>ZI8K@P8>';SW8K%/S[^?HU*'RU)+XX:BIDV'*P*V8
M?%*<@DG@TZ_;T\*EE&_,K5[ZY+"EC5C&ED'KY-69@U3[Z[_XVGNLEF:!:3/.
MP:;@R(6-;#3U[=GWZ\O>MVWNX+ZZJ(*9A5GTVJ+%D3^&;3K:K5_TYL#AU+#0
MQ:WCPG_9KV&9=#.OFFSVW(W_^NW"D#O_\LG_]MS\Y9;[WG[]ZK#]\,O\[,)[
M5"*@AD______________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________\$0H3%````@'123E/_________________________________
M____________________________________________________________
M____________________________________________________________
M________________`#@%2V<````!8DM'1'](OW'E````"7!(67,```!(````
M2`!&R6L^````>DE$0508TV.H1P,,F`+,((`DP&S(R,@HQHPDH,X`!,QP=0S,
M]G!@P`P6<$``B``3D[&,)00X`K4Q,$OIL')80(`:GS@/`[.@";<U%&C*,@.U
M".C*6T$!OS)(0%_##@94F$&&LIO;P(`D2$"5UQ8&%,#6UCLB`#,VWP(`M$U&
MWW98IT(`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+V)L86YK+G!N9P``````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#(V,B`Q,#4Q-30S-#$U,2`P,C,S-3,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P````&4$Q41?__
M_P```%7"TWX````!=%).4P!`YMAF````)4E$051XVF)@0`"``((C@`!"1@`!
MA!\!!!"9"""`Z(L``FSX(0`!M@`!](6MA0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O=')E92]P;'5S8F]T=&]M+G!N9P``````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S-C0@,3`U,34T,S0Q-3$@,#(T-#<W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```4````%`@#```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A
M`````W123E/__P#7R@U!````8DE$051XVF)@8F1B`&,F)H```F(&(&!B`@@@
M(&($LID8&!F8``((),'$A(L$""`PR0AC,D"T@YF,C(Q@C"(*`P`!1`P3J@M=
M`2,C\6JA`"#`D)AD"S*@J8`+,A(MB(TFTTD`0X@"TJ-$18L`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O
M<F5V+6UI;G5S;VYL>2YP;F<`````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#(P
M(#$P-3$U-#,T,34Q(#`R-3$P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%````!0(`P``
M`+I7[3\````,4$Q419"0D````/___P```+$OIH8````$=%).4___``#3#E2&
M```!KTE$051X`0&D`5O^``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("`@("
M`@("`@("``("`@("`@(````````````"`@("``("`@("`@(``@("`@("`@`"
M`@("``("`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("
M``(!`@$"`0(``@$!`0$!`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("
M`@("`@(``@("`@("`@`"`@("``("`@("`@(``@("`@("`@`"`@("``("`@("
M`@(````````````"`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("
M`@("`@("`@("`@("``("`@("`@("`@("`@("`@("`@("``("`@("`@("`@("
M`@("`@("`@("``("`@("`@("`@("`@("`@("`@("6CH"V7._Z[8`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+W1R964O<F5V+6IO:6YB;W1T;VTM9&]W;BYP;F<`````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,#(T(#$P-3$U-#,T,34Q(#`R-C(P-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%```
M`!0(`P```+I7[3\````/4$Q410```/___P```````````()KTE8````%=%).
M4_\`````"`_!/0```:])1$%4>`$!I`%;_@`!`0$!`0$!`0$!`0$!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!
M`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!``$``0`!``$`
M`0`!`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!
M`0$!`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!
M`0$!`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!
M`0`!`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`0`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0`!`0$!`0$!`0$!`0`!`0$!`0$!`4+"`8:^
M#%VS`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+W1R964O;&5A9BYP;F<`````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,S,P(#$P-3$U-#,T,34Q(#`R,S$V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`$`P```.W=XE(````84$Q416YM=9.1G,_,V/___P```/___P``
M`````,%CRF(````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+
M$P``"Q,!`)J<&`````=T24U%!]0,%!,M,$=CKCH````Y241!5'C:8V!@8'!Q
M<7$`4@PLCDJ*8(:3D[$1B,&B#&6XN$`9CDI*$(:3L3$E#*`Y$+M<7&"V0P``
M/6<27`BUH(,`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+VIO:6YB;W1T;VTM9&]W;BYP;F<`````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$U
M-R`Q,#4Q-30S-#$U,2`P,C4T,C``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!0````4`0,`
M``"W1X].````!E!,5$4```#___^EV9_=`````G123E/_`.6W,$H````6241!
M5!A78_S/\)&1)!SV&T(W%&*C`1_`)S6Z\9=?`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<V]N
M;'DN<&YG````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,C`@,3`U,34T,S0Q
M-3$@,#(T-S,T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````Q0
M3%1%D)"0````____````L2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!
M`:0!6_X``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("
M`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(`
M`@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@````````````("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("
M`@`"`@(!`@("``("`@(``@("`@("`@`"`@(!`@("``("`@(``@$"`0(!`@`"
M`0$!`0$"``("`@(``@("`@("`@`"`@(!`@("``("`@(``@("`@("`@`"`@(!
M`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@``````````
M``("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("
M`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(`
M`@("`@("`@("`@("`@("`@("`@)7(@+5@_C(\`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]N=6QL
M;VYL>2YP;F<`````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-#0@,3`U
M,34T,S0Q-3$@,#(T,30Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!S5#=
MJ0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\````"5!,5$4```"0D)#____R_1\E`````W123E/__P#7R@U!
M````4DE$051XVF)@8F)B@&*```)B!D9&(`D00"`.2(@1"`$"",;&3@($$(2$
M,1E!`,H$4HP,0(`B"@,``40,$ZJ+B7*U``&&Q"1;D!'*8:2B(/E.`@!PP0+[
M11LG$@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O:F]I;F)O='1O;2YP;F<`
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S`S(#$P-3$U-#,T,34Q(#`R
M-#0T-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``
MK\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M``903%1%````____I=F?W0````)T4DY3_P#EMS!*````-4E$051XVF)@9(!"
M1D:```)B"`(((#@"`H``PD\"!!`#'B8$,,(!$A,@@.C+!`@P).8P$00`/G$!
MAH))F#,`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUL:6YE+G!N9P``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,3`Q-"`Q,#4Q-30S-#$U,2`P,C0P,#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!0````4"`,```"Z5^T_````"5!,5$4```#___\```!SQH-Q
M`````W123E/_``!$[O`S```!KTE$051X`0&D`5O^``$!`0$!`0$!`0$!``$!
M`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!
M`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!
M`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!
M`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!
M`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!
M044!A]7QV($`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM:6YU<V)O='1O;2YP;F<`
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,"`Q,#4Q-30S-#$U,2`P,C4T,C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_````#%!,5$60D)````#_
M__\```"Q+Z:&````!'123E/__P``TPY4A@```:])1$%4>`$!I`%;_@`"`@("
M`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("
M`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("````````
M`````@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(`
M`@("`@`"`@("`@("``("`@("`@(``@("`@`"`0(!`@$"``(!`0$!`0(``@("
M`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"
M`@("`@("``("`@("`@(``@("`@`"`@("`@("`````````````@("`@`"`@("
M`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("
M`@("`@("`@("`E7P`M9BE9->`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S+G!N9P``
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,"`Q,#4Q-30S-#$U,2`P
M,C0P,S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_````#%!,5$60
MD)````#___\```"Q+Z:&````!'123E/__P``TPY4A@```:])1$%4>`$!I`%;
M_@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("
M`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("
M`````````````@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("``("
M`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`0(!`@$"``(!`0$!
M`0(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("`@$"`@(`
M`@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("`````````````@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("
M`@("`@("`@("`@("`@("`E)R`M#)#J(=`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUP;'5S
M8F]T=&]M+G!N9P``````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,"`Q,#4Q-30S
M-#$U,2`P,C4R-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_````
M#%!,5$60D)````#___\```"Q+Z:&````!'123E/__P``TPY4A@```:])1$%4
M>`$!I`%;_@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`````````````@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("
M`@("``("`@$"`@(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`0(!`@$"
M``(!`0$!`0(``@("`@`"`@("`@("``("`@$"`@(``@("`@`"`@("`@("``("
M`@$"`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("````````
M`````@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`E+8`M+7WSW>`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+VUI
M;G5S+G!N9P``````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,V,2`Q
M,#4Q-30S-#$U,2`P,C,T,3<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```'-
M4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P````)4$Q419"0D````/___XD`3R$````#=%).4___`-?*
M#4$```!?241!5'C:8F!B9&)@8@)B1B:```+2#$#`Q`000$#$"!("08```DDR
M,>$B`0((3#+"F`P0[6`F(R,C&*.(PM0"!!!$,WXF5!>Z`D9&XM5"`4"`(3')
M%F1`4T$-0?*=!`!$LP+4?U:T7`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M:6YU<W1O<"YP;F<`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-38@,3`U,34T,S0Q-3$@
M,#(T,30V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````4````%`@#```!S5#=J0````1G04U!
M``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M````"5!,5$60D)````#___^)`$\A`````W123E/__P#7R@U!````7$E$051X
MVF)@8F)B`&-&)H```M(,0,#$!!!`(`&0$`@"!!",C9T$""`("6,R0+2#F8R,
MC&",(LH$M`4$``((51MV)E07N@)&1N+50@%`@"$QR19D0%-!#4'RG00`27<"
MUU!#0:0`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+W1R964O;6EN=7-O;FQY+G!N9P``````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,S0V(#$P-3$U-#,T,34Q(#`R-#,R-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%````!0(`P```<U0W:D````$9T%-00``K\@W!8KI````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/`````E03%1%D)"0
M````____B0!/(0````-T4DY3__\`U\H-00```%1)1$%4>-IB8&)B8H!B@``"
M8@8@8&("""`0!R0$@@`!!&-C)P$""$+"F`P0[6`F(R,C&*.(P@!``!'#A.I"
M5\#(2+Q:*``(,"0FV8(,:"JH(4B^DP!,:0+995[\T`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]T<F5E+VIO:6XN<&YG````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#,P-2`Q,#4Q-30S-#$U,2`P,C,R,C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!0````4"`,```'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P````&4$Q410```/___Z79G]T````"
M=%).4_\`Y;<P2@```#=)1$%4>-IB8&2`0X``8F!DA""``$)&``$$1(Q@!E82
M((`8\#`A`*L"@`""D/1B`@08$G.8"`(`.)8!@OL*7RL`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]M
M:6YU<V)O='1O;2YP;F<`````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-30@
M,3`U,34T,S0Q-3$@,#(T-C0V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#```!
MS5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\````"5!,5$60D)````#___^)`$\A`````W123E/__P#7
MR@U!````6DE$051XVF)@8F1B8&("8X```F(&(&!B`@@@(&($"8$@0`"!)"#2
MV$B```*3C#`F`T0[F,G(R`C&**(P`!!`Q#"ANM`5,#(2KQ8*``(,B4FV(`.:
M"FH(DN\D`$>E`M:\^J3'`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<F5V+6QE868N<&YG
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S(W(#$P-3$U-#,T,34Q
M(#`R,S<V-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````84$Q4
M16YM=9.1G,_,V/___P```/___P```````,%CRF(````!=%).4P!`YMAF````
M`6)+1T0`B`4=2`````EP2%ES```+$P``"Q,!`)J<&`````=T24U%!]0,%!,N
M`$J7S54````X241!5'C:8V!@<7%Q80`!%B$E$0<P0]E8107&,'*`,L"J@`PE
M)1$(P]A8A7R&D!+4'!<7F/U@``"A^0S+!`=&O0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUJ;VEN8F]T=&]M+G!N9P``````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3`Q-"`Q,#4Q-30S-#$U,2`P,C4R,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!0````4"`,```"Z5^T_````"5!,5$4```#___\```!S
MQH-Q`````W123E/_``!$[O`S```!KTE$051X`0&D`5O^``$!`0$!`0$!`0$!
M``$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!
M`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!
M`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!
M``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!``$!`0$!`0$!``$!
M`0$!`0$!`0$!`0$!`0$!`0$!``$``0`!``$``0`!``$!`0$!`0$!``$!`0$!
M`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!
M`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!
M`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!
M`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!`0$!``$!`0$!`0$!`0$!`0$!`0$!
M`0$!/KT!AD"D;I$`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+V9O;&1E<BYP;F<`````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(W,"`Q,#4Q-30S-#$U,2`P,C,U
M,S<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3```!@%!,5$7]\]3]
M]MRBBE3ZY+"_A#O"C3IV6R2_B#KWZ\OLYMJLEF;&E#[EW,OWW9_TYL#[Z+G\
M]N:OFFSST(/PY,;=PGF^L9CESI3AU+#\[,+YVWK)NZ#0OIN_A3O`BCOV[M[C
MPX*NGW^EC5B?AU#7R:SVV9;@TZ_/K57#D#S?T[V,:S1W52+MY]W(LHBIDV'!
MBSNZJ(+7N&'YVWOUUHS0Q:WXX:CJV:S[W7US6"/_^_'#D3O\XY#^]^3\Z:K^
M[\'_]=-[5"+]\,N@AD____\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!2N$_^````0W123E/_________________
M____________________________________________________________
M__________\`06($[P````%B2T=$?TB_<>4````)<$A9<P```$@```!(`$;)
M:SX```""241!5!C39<_7&L%`$$#AW>@]071!1!>=Z&N\_T.9(8,O.9?_W1'/
M0"(,:0!P_V!9E5(.C!_TD@(#2ML2P.-;7GM#K9,Y^:FXB5`8Z4<_:^8A1&(7
MKI0BV"WNW#Y+D&O?N,J8P$E<N7*?8-,Z<ZLF@EV,U@^?UL,Y0@,FBIMZW?#M
M"Z^Y-8]6&(.!`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUN=6QL;VYL
M>2YP;F<````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,"`Q,#4Q-30S-#$U
M,2`P,C0W,C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_````#%!,
M5$4```"0D)#___\```#/D=W4````!'123E/__P``TPY4A@```:])1$%4>`$!
MI`%;_@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("
M`@("`0$!`0$!`0$!`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"`@("`@("
M`0("`@("`@(!`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"``(``@`"`0("
M`@("`@(!`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"`@("`@("`0("`@("
M`@(!`@("`@`"`@("`@("`0("`@("`@(!`@("`@`"`@("`@("`0$!`0$!`0$!
M`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"
M`@("`@("`@("`@("`@("`@("`G1N`ON4%E&H`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E+W)E=BUM
M:6YU<RYP;F<`````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,"`Q,#4Q
M-30S-#$U,2`P,C0R,#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,```"Z5^T_
M````#%!,5$60D)````#___\```"Q+Z:&````!'123E/__P``TPY4A@```:])
M1$%4>`$!I`%;_@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("
M`@("`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("
M`@("`@`"`@("`@("`@("`@$"`@("`@("`@`"`@("`@("`@("`@("`@("`@("
M`@`"`@("`@("`````````````@("`@`"`@("`@("``("`@("`@(``@("`@`"
M`@("`@("``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`0(!
M`@$"``(!`0$!`0(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("
M``("`@("`@(``@("`@`"`@("`@("``("`@("`@(``@("`@`"`@("`@("````
M`````````@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"
M`@("`@("`@`"`@("`@("`@("`@("`@("`@("`@`"`@("`@("`@("`@$"`@("
M`@("`@`"`@("`@("`@("`@("`@("`@("`E6*`M3QS3FM`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]T<F5E
M+W!L=7-O;FQY+G!N9P``````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,V
M,B`Q,#4Q-30S-#$U,2`P,C0Q-3(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!0````4"`,`
M``'-4-VI````!&=!34$``*_(-P6*Z0```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P````)4$Q419"0D````/___XD`3R$````#=%).4___
M`-?*#4$```!@241!5'C:8F!B8F)@8@1B)B:```)B!B!@8@(((!`'),S`R,`$
M$$`P-G82((`@)(S)`-$.9C(R,H(QBB@,``00,4RH+G0%C(S$JX4"@`!#8I(M
MR("F`B[(2+0@-II,)P$`2$P"U8&CD@``````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M<&QU<W1O
M<"YP;F<`````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,C`@,3`U,34T,S0Q
M-3$@,#(T-34U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M/P````Q0
M3%1%D)"0````____````L2^FA@````1T4DY3__\``-,.5(8```&O241!5'@!
M`:0!6_X``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("
M`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(`
M`@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("
M`@("`@````````````("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("
M`@`"`@(!`@("``("`@(``@("`@("`@`"`@(!`@("``("`@(``@$"`0(!`@`"
M`0$!`0$"``("`@(``@("`@("`@`"`@(!`@("``("`@(``@("`@("`@`"`@(!
M`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@``````````
M``("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("`@("
M`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("`@("`@(`
M`@("`@("`@("`@("`@("`@("`@)6O`+3`9JY`P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E92]R978M
M;6EN=7-T;W`N<&YG````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,C`@,3`U
M,34T,S0Q-3$@,#(T-S(U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````4````%`@#````NE?M
M/P````Q03%1%D)"0````____````L2^FA@````1T4DY3__\``-,.5(8```&O
M241!5'@!`:0!6_X``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("
M`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("
M`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@("`@("`@("
M`@(``@("`@("`@````````````("`@(``@("`@("`@`"`@("`@("``("`@(`
M`@("`@("`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@$"
M`0(!`@`"`0$!`0$"``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("
M`@`"`@("`@("``("`@(``@("`@("`@`"`@("`@("``("`@(``@("`@("`@``
M``````````("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!
M`@("`@("`@(``@("`@("`@("`@("`@("`@("`@(``@("`@("`@("`@(!`@("
M`@("`@(``@("`@("`@("`@("`@("`@("`@)9U`+7`?ZRK`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O=')E
M92]L:6YE+G!N9P``````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S
M,#$@,3`U,34T,S0Q-3$@,#(S,C`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````4````%`@#
M```!S5#=J0````1G04U!``"OR#<%BND````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\````!E!,5$4```#___^EV9_=`````G123E/_`.6W
M,$H````S241!5'C:8F!D@$.``&)@9(0@@`!"1@`!!$2,8`96$B"`&,AC`@00
MA*07$R#`D)C#1!``/U,!A\/]E(T`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+W1R964O<&QU<W1O<"YP
M;F<`````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S8U(#$P-3$U-#,T
M,34Q(#`R,S<W-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%````!0(`P```<U0W:D````$
M9T%-00``K\@W!8KI````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y
M<<EE/`````E03%1%D)"0````____B0!/(0````-T4DY3__\`U\H-00```&-)
M1$%4>-IB8&)B8F!B!&.``&(`,H&`B0D@@(`(+,S`R,`$$$`P-G82((`@)(S)
M`-$.9C(R,H(QBB@3T!80``@@5&W8F5!=Z`H8&8E7"P4``8;$)%N0`4T%7)"1
M:$%L-)E.`@!%6@+3-0EQ9@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]A<G)O=RUD;W=N+F=I9@``````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(P-R`Q,#4Q-30S-#$U,"`P,C0T-C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$``0`+,``.+BXLS,S+R\O*ZNKJ.CHWQ\?%=75T-#0P```/___P``````
M`````````````````"'Y!`$'``D`+``````0`!````0T,,E)J[TXU\.[YQL0
MC"2!6`@AK&MAG-81L$,!HZI0O]FANC>,S*:1I'C%Q"&H03";R:@T`@`[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O:6UA9V4O<F%T:6\N<&YG````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`T-C4@,3`U,34T,S0Q-3`@,#(S-3,Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P```%U03%1%````?YBTA)RWA9VWB:"YBJ"Z
MBJ&ZCJ2\CJ2]CZ6]D*:^DZB_DZC`E*G`E:K!F*S"F:W#FJ[#GK'&G['&L<#1
MLL'1LL'2L\+2M,/3M\74M\75N\C7O,G7V>#G````D4G)`P````%T4DY3`$#F
MV&8````!8DM'1`"(!1U(````"7!(67,```L3```+$P$`FIP8````!W1)344'
MU`P4$PDYSU?W.````%%)1$%4>-IC8$`'<E"`$)`5D9"4$4<2$&5D8F'G1A*0
M8F;EX.%'$I!FX^05$))C@$,Q+CY!861#46U!DD!V"@:)2S7$%E1OH*F00U?!
M@*(7"@&[`0@F[URD"P````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM
M86=E+W)O=&%T92TQ.#`N<&YG````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-3<P(#$P-3$U-#,T,34P(#`R-#(Q-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$````!`(
M`P```"@M#U,```!^4$Q410```"<G)RHJ*C`P,#Q!1GJ'E(.1GXB1FXZBM(^D
MMI:CL)6MQ9>NQJBMLIJRR)VXTJNUOY^YT9^YTI^YTZ"ZTZ"[TZ&[TJ*[TZ*\
MU*.\U:2]U:K!V+''V\#.VL'2XL+2X\/3X\34Y,74Y,?6Y<C7Y<K9Y<S9YLS9
MY\S:YP```)%:.G8````!=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES
M```+$P``"Q,!`)J<&`````=T24U%!]0,%!,*!E(<B<8```!S241!5'C:C8[=
M&D)0$$6G)"K:?I)4XJ#8[_^"'#Z.NFK=[?7-[!F1`8Z(@4W=Y/YF)120I0?K
M2]SCRW[9T@W'Y\TS-5L*2US-A!I$A6@6+$`&77+BDO%Z?QZ1/0FVT&2I.Y^E
MSN'9V9E.X/=UK-/TF?Q/#TYU"Y-\J!(]`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R;W1A=&4M
M,C<P+G!N9P``````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0S-B`Q,#4Q-30S
M-#$U,"`P,C0R,34`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
M2%!,5$4````!`0%"0D)-34V(EJ.=N-*DO-2EO=6IP=>OQ=K!P\BSR-JTR-RV
MRMRWRMZZS=_(S-+'UN7(U^3-VN37X.G5X>S9X^T````)QS-D`````7123E,`
M0.;89@````%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?4#!03"A76HL@8````3TE$051XVHV/-Q+`,`@$Y7#..>W_?VK-N!"X$MTN
MS`$A9!<40.)R."<IB>H:&UFQS6UO!4>G&I/!:L?C`O8H3'^Y'[E(Y/DS^#M_
M'$W^DR]D.00M4QL`X`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O:6UA9V4O9FQI<"YP;F<`````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,C<@,3`U,34T,S0Q-3`@,#(S,S0S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`@#````*"T/4P```#]03%1%,*:Z*BHJ
MAY^UB*"VCJ.WCZB_DJF_EK#(G;C2GKC2H[S4P-+APM/CP]/CQ-3DQ];ER=?E
MR=CETM[JU.#K````E=-PQ0````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L2```+$@'2W7[\````!W1)344'U`P4$PD5_8^;VP```%%)1$%4
M>-J%CTL.@#`(1%L5G:KU._<_JZQLP32R('DO#(00&D7/.QU#:!FUB4>:@32^
MAN2&3GN5R1C,5B<^D7C=*V0YRPPG>U:-6%;3\^>Y4@\PXP01T\R]P@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VEM86=E+VUI<G)O<BYP;F<`````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-#$T(#$P-3$U-#,T,34P(#`R,S<Q-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,````V4$Q410````8'"2HJ*G6*G7:+GWJ,
MFGJ/IGR2IHB@MH^HOY&HOIVXTKK&T\'2XL+2X\34Y,K9Y0```&]D$4<````!
M=%).4P!`YMAF`````6)+1T0`B`4=2`````EP2%ES```+$@``"Q(!TMU^_```
M``=T24U%!]0,%!,)+SN#0FD```!/241!5'C:K8W;#H`@#$,GHC(J2O__9^4B
MTV?C2?;0DZP5^8BC"-V3>58!6C[``H8I&2GGA-MPA[%T$P"-40$_?H*VCGFR
MUJVNK'SMLM]/7#6R`^;5H<PA`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I
M;6%G92]G<F%Y<V-A;&4N<&YG````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C$W,"`Q,#4Q-30S-#$U,"`P,C0S-C``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!`````0
M"`,````H+0]3````!&=!34$``+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_
M``"`Z0``=3```.I@```ZF```%V^27\5&```#`%!,5$7>WM[=W=W<W-S;V]O1
MT='$Q,3#P\/`P,"]O;VYN;FRLK*PL+"KJZNJJJJIJ:FGIZ>CHZ.BHJ*?GY^>
MGIZ<G)R:FIJ9F9F8F)B6EI:5E963DY.0D)"/CX^,C(R+BXN*BHJ)B8F(B(B&
MAH9Y>7EX>'AS<W-R<G)Q<7%O;V]@8&!?7U]:6EI75U=65E924E)145%(2$A'
M1T<X.#@B(B(A(2$%!04$!`0#`P,```#___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#Y)V#)````.G12
M3E/_________________________________________________________
M__________________\`-\#_"@````EP2%ES```+$P``"Q,!`)J<&````)Q)
M1$%4*,]=S^D.@C`0!."*J'A010Y;J0IXH-8#3X;W?S$1E!+FSR9?-KL9DC5"
MRH$\=8!P^1(*(*:6S0(H\"9#RQ,UF-GYAE\!L&`NFT=_`/5>*U]$Y2.2P=2U
M\?V-YW$O44!/(^T.34,>[*[X0E]OZ8:9L@%?RP)LHVN,G$?(POB$XJA#J8-D
MNXD/"7YO\_NXR/,-53G5CS3K?P!B#RU+L1XI;@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+V-R;W`N<&YG````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C<P(#$P-3$U-#,T,34P(#`R,S,U
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$````!`(!````+7Z-^H````"8DM'1```JHTC
M,@````EP2%ES````2````$@`1LEK/@```%Q)1$%4*,]]T;D5P"`,!-&1NG,S
M%$,S%$,Q<@(^T*'TS]M$,LEN6*,CLV``K;G'P<OAPI<OT9K=PLE'X/D71/P)
M8GZ"C%<PK&$8.`;=#$)W##J,@D'6<L+DW]QW`SGO+\TU5-#"`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]I;6%G92]R;W1A=&4M.3`N<&YG````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#0V,R`Q,#4Q-30S-#$U,"`P,C0Q,S4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`,````H+0]3````5U!,5$4````H*"@J*BHQ,3&-G*J4
MH:V1I;B<M]&?M\Z=N-*?N=*?N=.BN].BO-2CO-6DO=6GOM2]P\BQQ]O!TN+"
MT^/#T^/$U.3'UN7(U^7)U^7*V.74X.L```#Z@2Z1`````7123E,`0.;89@``
M``%B2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03
M"A<XK*DT````54E$051XVHV..1*`,`P#S8VX`@',Y?^_$T*#397MM..13!2!
MO&BQ;\<Y)4HP,'1E9H1KFUQT1^'[6DSQBE',#J-24RE?"^#G[T80,+^$;%M_
M^3$4RPUY&@7[ZR_,@@````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M:6UA9V4O<F5F<F5S:"YG:68`````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`S,S$@,3`U,34T,S0Q-3$@,#(T,#(S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y81``$`#$``````!XE[%(9G\B
M,#O5U=6FNLMSDZ[5WN:/J+Z[R]@S2%J9F9GDY.2BM\E/;XK,S,R#H+A+:H22
MJ\#___\````````````````````````````````````````````````A^00!
M!P`3`"P`````$``0```%5N`DBL1HGB-0HB8!`(C*DL"1%`W`S`!D.`Z!CB=1
M``:`QVP""`"82M%BF(H\5RGJA/$ZE6K/$7<Q>CP!CC#+?``HTC/N`>@PQIMU
M(Q;E<LJ6$RZ`7B@A`#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VEM86=E+V%R<F]W
M+75P+F=I9@``````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C$R(#$P-3$U
M-#,T,34Q(#`R-#$S-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$0`!``LP``XN+BT]/3O+R\KJZNHZ.CGIZ>>WM[
M5U=72TM+````____````````````````````(?D$`0<`"@`L`````!``$```
M!#=0R4FKO3AKE?9,B">!8G(0W9880:B9AH!F\"`4\[7:@M#JAUBOEZ,D"(&D
M$N#Z()[0:$I$K40``#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]I;6%G92]R969R97-H+G!N9P``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4S-"`Q,#4Q-30S-#$U,2`P,C0P
M-#<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0"`8````?\_]A````!F)+1T0`_P#_
M`/^@O:>3```!$4E$051XVF-@P`ZT&"@$_\DQ1!VJ\7__BGW_B36$$<G)5Z_>
M>\;P[.TGAM?O/S/\^?N/(<[3G(&!@4&<@8'A%2X#6*#TU>8%.QCF;3W!<.?.
M'08&!@:&G]^_PM2P$N7G2:L/_#?VB/K/P,#P7\G`&N8%?:(#K6+Z1I@F!AR:
M4Z'B8LB"3##&Y<N7D<6U&1@8+J(9,!M*OT0WA`$J@.P"7.GB_]5[SW"J@QF2
MBB:NC^PU__PN%`.8D!2^@D;K;#3-%Z[>>\;`P,#PW]@C"F<ZP`:D&1@8GER]
M]XRA:N(2N."3FQ<8SNY8!M?+@L>`WPP,#`R+=YZ&:V1@8(!IUB8V>K70HO@_
M-,F3!+3PQ`Y)AF`%`"\`90%XO=1_`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O86QE<G1S+W=A<FYI;F<N<&YG````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`T,38@,3`U,34T,S0Q-3`@,#(T,C8T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`0#````[=WB4@```#!03%1%$1$1=W=W)AH`/#P\IH`:
M_\PS0#,-````#0T-<UD-\K\F,R8`+R\O____________$<[0I0```!!T4DY3
M____________________`.`C71D````!8DM'1`\8N@#9````"7!(67,```!(
M````2`!&R6L^````6TE$05085RW&L0D#,0!#42TI%+*'2&-PE5$RBTN/X^;@
MI[A[U1-P)B!@C2?-G:O9(#CV!,%*!PB:!L35-!MQG'HBEE]?#T2=.NBJWS]G
MZ]BI/;7N#-6V[>CS^`/D0U+0+2J9AP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%L97)T<R]M97-S86=E+G!N9P``````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,#`Q(#$P-3$U-#,T,34P(#`R-#(S,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`(`P```"@M#U,```#`4$Q410````P3&A0;(Q4;(QPC*R,X33)&7"]+9S!+
M9S-/;#1/;#52<#E6=$18;#U:>$!;>$I:;4)>?$9B@$IFA$MF@TYJB%5MAU-O
MC51OC%=SD5MWE65VB5]XDF!XD5][F6-_G6=_FFB#H6R'I6Z'H7>&EGV*F(&6
MK8"8LX>;KI:HO9BJO9FLP)RLO:*RPZ6TQJ:UR+"]SO__________________
M_________________________________________Z9W*WL```!`=%).4___
M____________________________________________________________
M_____________________P#">[%$`````6)+1T0_/F,P=0````EP2%ES````
M2````$@`1LEK/@```(Y)1$%4&--UCU<.PC`01(<2FDWHA(02>@EU3I#[WXK=
MC2A"8CXLO;=C>8W\)RA.RT=@FYU/^S9>HGH_K%?I(IE4"H&',)G$T5`IQU3G
M9!R-!C6HR*ROW.^8N`F3%.Z%)JXZ)Y6]B8OV2>66B=U&[I/"+H`]>UP*D]XU
M4"Q6GL^T[^JE]^K=<>B;`?Y_[CM/A@TEPT"5T_L`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%L97)T<R]S=6-C97-S+G!N9P``````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q-S4T(#$P-3$U-#,T,34P(#`R-#(W-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$````!`(`P```"@M#U,```,`4$Q4100"!#Q2)!PJ%$QZ+`P:!#0^)&QZ
M7$Q:/"PJ+`P.!'227!06%%QZ1'R:;`0*!#QF'"PJ)#P^/%1F3%QZ/#0R-!PB
M%(2:="0R%!0B#$Q>1`P.#(2>;`P*#$QN-$1*/`0&!#Q6)"0N%%1^+!0>##Q&
M-'R*;$Q61"PN+'R69!P:'&2&3(2:;`P*!$1J)"PN)$1"1%QJ5%Q^/#0V-!PB
M'`P2#```UP$`]```=P!>;0"`:14*]P!X=ZA+WN0`YQ(`$@`````#^0$`FP``
M]```=\B8X.4`21*:^P``=_``#HCLV?G]]'=_=X@:XAP"V/0`]'<`=_\XT/_G
M9_\2%?\``#<`@)``:/0`%7<``,24`![F`.42`'<```"J``";`!7T``!W``"S
M``";``#T``!W`#BX`,?I`!82``````0DV`$`YP4"$@$``-R`&.)H`!(5&@``
M`'Y>W@"`YP`*$L!X```")P```````````/\D`/\``/\"`/\``/\`;/_P6__]
MY?]_=P!T:`#FP``2%@````!&:```P```%@`````P:`#GP``2%@```&OP``"(
MP`#Y%@!W`%CY``.;``#T``!W``;@!_9)`.3[`'=W``\C`!ZC`.7T`'=W```K
M``&C``#T``!W`'CD`&3F``$2``````#(```H`!7E``!W`!0``.4``!(`````
M````;```6P``Y0``=^!X-OAD`!(5`````/``_X@!__D`_W<`_X@$-API`/3E
M`'=W`/\$5/_G\O\2$O\``#=D`)`O`/3F`'=W`.``#!@`Z.4`$G<```!H_@#`
M6!462P````!O[``0YP#E$@!W`'C_6V3_8A7_3@#_```((`'HZ``2$@```&28
M;R\0$.;EY7=W=P!LO@!OZ`!.$@```*HHR(>6_PI._W@`?[@`B`8!Z!8`$@``
M`-P$:.;GP!(2%@```%X`;X`!$`H`Y7@`=P#`:`#<P`!/%@```````0`P````
M``!<``!5``!.``!3``!/``!2;@!4_0!%1@!$`'SD&D(````!=%).4P!`YMAF
M`````6)+1T3_I0?RQ0````EP2%ES````2````$@`1LEK/@```'A)1$%4*!4%
MP0D.P4```,"A[C9E65$EUIF*QNW_;S,#````VV4)`.IA<<@3`&E=K&),`,P7
MAT]3`C!_=V.S!1X[7M=I'1.P;-NSR_$7&H#JMAY,[G4$H+^Y9N,P`J"Z3[(R
M`$!5=+X!`.Q/(0<`O=D3`!!S`$`"\`=X`0?2<M`'20````!)14Y$KD)@@@``
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%L97)T<R]E<G)O<BYP;F<`````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-3(R(#$P-3$U-#,T,34P(#`R,S<T-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`(`P```"@M#U,```!@4$Q417%Q<8```+<``-T``&HF
M&J8``#<``/_,F4PS&EX:#7<S)DP``(!F3%E`)G-90(0``+^9<YT:#=FF<^:R
M@(QF0(!9,VHJ*H@:#?*_C,R99LP``%$J*F(J*O___________QPQ[_H````@
M=%).4_________________________________________\`7%P;[0````%B
M2T=$'P4-$+T````)<$A9<P```$@```!(`$;):SX```!?241!5!C3;8_!"L`@
M#$,+@387O>V\___+I:V,*4L1S%-*8K?D2WFW]`"H`V\@3P^RB:67S2EB^<X7
MP/_!B*EA;FX0)7T<&YAB&Y!P@&-'7#A`):ND;'72[K;DJZU_^C\9%PD"C7>B
M(P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M;V)I;&4O9&ES<&QA>2YJ<&<`````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C8Q-2`Q,#4Q-30S-#$U,"`P,C0R-#``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````_]C_X``02D9)1@`!`0$!+`$L``#_
MVP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?&ALC
M'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"C_P@`1"`!X`)8#`2(``A$!`Q$!_\0`&``!`0$!`0```````````````@$`
M`P;_Q``7`0$!`0$````````````````!`@`%_]H`#`,!``(0`Q````'T>NXW
M4RR39:IE50SI-C.AV&4$EP><9E.V,D6[.*YUSHEM9-6V,<R(H8'H!$LBAEAS
M*2K*RJ*HRRHFM0GH3`]`4!T,42C+SRTU;+0T54KIS=RD71=E4DHF!8BR6)04
M9H[:7,/9/FKEL6IZ(6Y=.=9CM)I-$(PF:11VTU.G-(F%<NFNZ8*H5,<S)FG2
M63"72B*FV$OFMNE"H:Y.AT9'CL*2;6'&QL*.DBMIMI=AMVPEM9=LEVVVFVTF
MPP[#)L;;;/\`_\0`&!`!`0`#`````````````````6`P0%#_V@`(`0$``04"
MCSAF=@C3(?\`_\0`&A$``@,!`0```````````````3``$2`00/_:``@!`P$!
M/P&'5X*CVX"\PX'@I91__\0`&A$``P$!`0$```````````````$1($`0,/_:
M``@!`@$!/P$6WA$]@]PGR?)2YO'_`/_$`!00`0```````````````````(#_
MV@`(`0$`!C\"#O\`_\0`&Q`!`0$!`0$!`0```````````0`0$2`Q03#_V@`(
M`0$``3\APN:;RYG)OV;F&ER,#>8XR3Y+[YY<]I),Q!&<C.;S.3,SC$1Z<\LS
M.,1$1<CSR9F9F<$1$1$:S/@S$1A$1&,S.,SA$81$,7<9F9F<(C"(B[G9F9F9
MF(^1A@8NZSC,S,1'@9W75F9F(A\]N^.ZSOV[%WUW>YV_<7"^?P-[=\?,_]H`
M#`,!``(``P```!##;WG94P#O\J%ANN(M6T#_`,)+=[UV)S4^H`>OFA%!BNC=
MRLL]N#!A&3E<$L7Q=:(@'QM0N\C_`(`0P0'`0/_$`!H1`0$!`0$!`0``````
M``````$`$1`A,5'_V@`(`0,!`3\07]E++;>PY]@1;,I9;8;8MLEELLL\!'D6
MS/DS,1PLZ),D(OL%DDR2)9!!!9;?3;4DEED$',DR>,LL@LCG_\0`&A$!`0$!
M`0$!`````````````0`1$"%!4?_:``@!`@$!/Q#/A""`LD)"3H((7BPLF"3A
M$$'#&9+(B.!"9GA$,6S,LML,,.VPS']2R\/'($0VRRRSPX,-LLLL\__$`!X0
M``,``P$!`0$!```````````!$1`A,6%!42"A_]H`"`$!``$_$$J)4J0C7="5
M<-R":I";F"H:F%#UY$'1-0X%H2@DZ0(ZN;)N&B$\(K<$H(00T8-P::."V;3T
MWT02DV]"5=%41A"(:I")]'6($'2_&*V1Z</,&OP@0B%1">83!!$L*&JDOS!%
M*,()1*JB<$J)3"$QL3!!$/10FH)AJ)\%0B%L59&3<'!H()D^O,-ACJ'1UD01
M$U1Z=P3!JB0>SZ]-6:L0Z3_1:>#8)AJ3^`@]#TT$'MC?</@U9A&0V#=&&P8X
MR/6'`Q]HPS&(%!?<(&&0B_3@8;!MP9!BC#7`Q12C$#=P;")1B+3B8)IB<GHT
MZ,Q185%U1ANEP,QD,Y@S71_W`M"=G@HQ.9*RZ@W<*/8VX,SO1NG7A3X1@FT)
MPNJ448J+Z-PHU*.%1N^!M-^#'PAQ"_'^B<$Z4J+J"=$X-.E&Z<4J0;JA=0^0
MOP4__]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUO8FEL92]R:6=H="YJ<&<`````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#0P(#$P-3$U-#,T,34P(#`R
M,S<P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!`0$L`2P``/_;`$,`!@0%!@4$!@8%!@<'!@@*$`H*
M"0D*%`X/#!`7%!@8%Q06%AH=)1\:&R,<%A8@+"`C)B<I*BD9'RTP+2@P)2@I
M*/_;`$,!!P<'"@@*$PH*$R@:%AHH*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*/_"`!$(`'@`.0,!(@`"$0$#$0'_
MQ``;``$!`0$!`0$!```````````%``8$!P,!`O_$`!D!`0$!`0$!````````
M``````,$``$%`O_:``P#`0`"$`,0```!T1*Y<CQ*Y%\7IW:4J:U6[C3%"HJ/
MTI0STHO0&1&R2JW<<2N/%1_1B9GI0[UP-PEJMW'C,BQO]3$C?1BW;H;A+5;N
M0$9&D?ZEJ%WQ;]HA<UJMW'@NYV1T1VP[X_24N'N-*K=QV<T6=E9O.:?+72^K
M=''V']U6[B#J!.[-57-ZMTT:56[_`/_$`"80``$!!P0#``,```````````0S
M`0(#!2`R-``0$1(A)#$B04/_V@`(`0$``04"U^QDGE@V\BT/WC?8BTM;R)1%
MO&4CK2O$HBWC+D*RG$HB*#+E*2C$HB*#+E*2C$HB*#+E*2C#W;I^\58I24X=
M#Z@EY2DJP]VZ?O$T2K+,.B(W\A$2%I<SU*'[AO`D7("9ZM$2[CJ.U<?'W;IC
M.\0C7]0V\B[Q6\0P'>Q4?X[Y>&9U'W__Q``>$0`"`00#`0`````````````!
M$`0`$3$R`B`A0?_:``@!`P$!/P&8/+])F@04S1!3-4%,P@IF!TF?*+D^\[4<
MO__$`!P1``("`P$!``````````````$$$"`1,3("(O_:``@!`@$!/P%$_6*(
M]F#"71@PEN#"6Z([HALT3&/&:?_$`",0``$#!`("`P$```````````$``B`#
M$'%R@<$184%18E+_V@`(`0$`!C\"7*K#]]6IXB57&#9L2JVHL,Q*JZ"W,2GZ
M=VYBY/T[07,793].T%S%V54T00S%V56P$$,Q=E5SBS8NRJOMW5F1=E#V2;4\
M1<J8^FVIZQ#?Z/A%.PJ6L"5Y^&#S9ZIC\P__Q``D$``"``0'`0$!`0``````
M`````1$@(3$005%QD:&Q88'!X?_:``@!`0`!/R%JA"#H?EQ<H4.1A*I'FNK_
M``I.PXJ308^7ZO#>.\F=IK[,I4L;Y,SLG*462SO\DS.QC+6]_DC.PQE+6^2P
M[0J=HGN$7DR.QV!=?+W!+R)7<'D^EH6'T;D>#%J?$5(0/W?<KVM0C9TSF!4A
M`7*:#-&V5WD#J^R%A`T>2-!#%=U\F/EMD79H(C^)-FH$$SE_%_1X,5E:$=\D
MD__:``P#`0`"``,````0T_?\ZXW\N]7\Z-_\89_\9`?\-L?\>`=\_\0`'!$`
M`@,!``,```````````````$0$3$A46&A_]H`"`$#`0$_$%)3X%D?9&(?A>Q&
M(;A"PQ"\B,0]J*K@LAJ2'#%D/2V0+(__Q``;$0`"`P$!`0`````````````!
M$``1,2%AH?_:``@!`@$!/Q"LI-GL.KXEI#V6D/<N:79HZM88=07#V'4(@;#"
MO__$`"<0`0`"``,)``,!`0````````$`$2$Q42!!87&!D:&QP1#1\.'Q_]H`
M"`$!``$_$"4:F6L>'T=+EKF][Q[N8H:W*`;JG938$<>D%(S6!OY/E"#4.&YB
MI?\`J7[#+\U75*%HS/1&U:N.&YO94^#L)AQN*R,K/1%B,D=B^P]1,;<#P;!\
M0X.D#NCI_J*N?,7]&#8KT]Q]S%?*>LP0_D:-C`^8NR>9AY;T_&S?\T;'H?D5
MZOT9=#<.[?A.ME7'])L/!U^2M.[Z,)4MKOG])CY\JYKXAE^<G1^0*_"\PIS/
M"WW,7/E9W(\PR_.(B%-*M.\4:4YC0'[8JYK]G0OD0R_-*O2*OH.S?[BL6W3O
M+>@15>,NS!;O578<W2#0YCWJ6P\J312WW&-M8+"+DM[AV`5W`KV@O86K1+\#
M!49.'(&$Y<G@O[&9S?7L$UO0EX7:'%/HI6W3&6S</KD1R%)?&Q__V0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M;V)I;&4O;&5F="YJ<&<`````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`S,"`Q,#4Q-30S-#$U,"`P,C,U,34`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````_]C_
MX``02D9)1@`!`0$!+`$L``#_VP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.
M#PP0%Q08&!<4%A8:'24?&ALC'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#
M`0<'!PH("A,*"A,H&A8:*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H*"@H*"C_P@`1"`!X`#@#`2(``A$!`Q$!_\0`&P`!
M`0`#`0$!``````````````8"!`4#`0?_Q``8`0$!`0$!```````````````%
M`P`"`?_:``P#`0`"$`,0```!_5!MI0]I$4EECC[>;I`-FR#)?)C;&,I+#:T]
MSCWI`1BQ#1?&C;&-I+RWM'=X]Z;Z%8L`R7/R5),TEANZ>YSNL^!&+`,F2DS3
MRU)9;>KZ<[N/H1BO#)DO(V$726YC[>/.H'P&Q8AHR;AKR!I+N:/8X.U*`6+(
M-&3L$=SLH\ZYI0&Q_\0`(Q````8"`04!`0```````````P0%$#,T`B$!$1(B
M,40`(/_:``@!`0`!!0)C4'LP?V>XWDYZ#&T:VHA2.H0@6Q;X,CJ,)6WE=`D=
M2A)V_L!D=3A(V_K!D=3RT1M_6!*ZC*1M_6#*ZC.1N9W0974;!*X/H^!,ZC8*
MZ.G-'P)G4IPM'5+CH:!F=3E]'57CQ"D=5]BZ-G\>\B'EU_A9XZES>C.'D`%Q
MV_@<NX/_Q``=$0`!!`,!`0`````````````!``(0,0,1,C,A_]H`"`$#`0$_
M`4]-^O`E]K%Z"76L?H)-K'V)-IG8EUIG8EUJG;EUHTL)VP;7_\0`'1$``00#
M`0$``````````````0`"`Q`A,3(1,__:``@!`@$!/P%,3SXTFVZ4W!MNE+P;
M&E)P;&E)\S;=*3DVU'(-MJ9H#\+_Q``C$``"`00!!`,!`````````````0(#
M$"!Q<A%188$2,4&"_]H`"`$!``8_`K3$07:`L&(GH6'L16Q6[5]XK=J^\5:O
MRQ^/XK5^0L)KPK5]BPEQ5J^Q8/C:MZ(X?P(EYB1PCQ%LI2[IHCA3T+91GVD1
MWA1?EBV2Z??3J1E[P@U^30A:)0?W%]"+/__$`"40``(``P@#`0$`````````
M```!$2%Q$"`Q88&AL?!!4<'1\?_:``@!`0`!/R&QX4H&!S'])TX%A/=QH9S1
M/5&I%1]`[7E$U0GRH<'$[G4R)EJ3]F")$H[G:R)]9UT1A48K=[\)M9U40\NH
MK6N1(BW8KNR1R+C92-S9PAWX(Y/%SK,QMQ)3/8;=X%;M8T-1*?:8;ID*WLJ-
MJA:9^F_^7%AG/R.)"3^82U[F/]LA,B7/&GJF/"YI,@;68@W`AZ3)"PN'M$,1
MZC(G&9(VI,.\\_P4L@S_V@`,`P$``@`#````$/+3//-=,O`>O/&,0_*!,O+/
M,O).O_(H?__$`!X1``("`@(#```````````````!$!$@(3%A07&1_]H`"`$#
M`0$_$![="D)M*E"8$XU9V.-PWW+C4:^_`Y7=E0@NCP%Q@3W!_\0`'A$!``$$
M`@,``````````````0`0$2$Q8:$@47'_V@`(`0(!`3\0FEY;SU$%NUNGX!O\
MX%,8S?B%,XT>&#4Z:35-+0`H[:B,B/_$`"80`0`"`0,#!`,!`0````````$`
M$2$0,4%188%QD;'!H='A(/#_V@`(`0$``3\0TRIW_(U&Y3H0FN[?Z1R>5,],
M'37%G9?FXTU^$RK8[R+]PW3P/LF&M(]GQ<J5R$.^=,\#]QV.\$O6I`?I85OH
M3VT(!M[:JB>88%<0Y1VQT,#%:D-S>PMB#D@:KL(-28S7,M$/ACOHS<>""F7G
MZ7#&JG95_P![Q>5U%"YR@8@WK>CA:&+Q8S_4/U&3*@<7K8,-T]E/N49UB^]!
ME>B?4PP[J>\;:U.[K;VCU%65+EN.R'Y)AW(#6MA.%H@VF"SWM'PS8=L?Q7^`
MG\!9BJJXJL*2<87V2YO2>[4YK4;.<G;.$2JZAR"X=UH/B4*=J/AN9OTRZX4"
MNRBY2R&#.4O!8]Q*J94--[7]$E&97RC>?__9````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O;6]B:6QE+W1O<"YJ<&<`````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3`Q-C4@,3`U,34T,S0Q-3`@,#(S,S<T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/_8_^``$$I&
M248``0$!`2P!+```_]L`0P`&!`4&!00&!@4&!P<&"`H0"@H)"0H4#@\,$!<4
M&!@7%!86&ATE'QH;(QP6%B`L(",F)RDJ*1D?+3`M*#`E*"DH_]L`0P$'!P<*
M"`H3"@H3*!H6&B@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"@H*"@H*"@H*"@H_\(`$0@`=0$'`P$B``(1`0,1`?_$`!L``0`"`P$!
M```````````````$!0(#!@$'_\0`&0$!`0$!`0$```````````````(!`P0%
M_]H`#`,!``(0`Q````'ZH```````QTDA$V&]YZ```````````&%#N7U9SU?N
M6VFGT5-IHB;]PSULD;JO%O0])\[]FOJCYKU\U=C-```````0==-4Z8.B%<82
M9VNIV>4&O-O(^F7E1\Y,,F;^;A,Z^MT6VS5;+.H;<]Q\WRB_IR%-BP````$'
M?`V8W,6='TC.9XJ--+J^CQTC6>EEY8X8&>&LQHSUZYFD[SG63=O/W]<Z^9LK
MR1]"X;9'3OF.46```-!"V:.?N**QPRZ<LH^^,5/<_+>ICKU'E*+GRG]+;"KP
M+/778%E$C\T>]917E<\O<,MS3@LIN_O?G?T3GT#-``5%OS>S*XKJ.4Z\YK'3
MLR?-&D@\]VL'-I+>IKIOJ_.:D%Y[1XE]!II1A,F6FSYM\RJ<_<?69>XLJ#]'
M^>=?'3H1%@`.+[#A+C?6R=%\T.=,Y=*"+U^7E]/.RKC.=IH_1-<A&[ECAMO:
MF\O+O/"D\N\2H\MQ3Y6NCKQA8Y1_;Y=UM!\CI]"'/H`!&X8Z<\=1L66T^']A
MZ3>61L^C=]]-SP#PPQ,8C-Q&;%K3Z_RYT$[\OIPY]0/_Q``K$``!!`$#`0@!
M!0`````````!``(#!!(%$1,@$!0A(B,P,T`5)#$R-%#_V@`(`0$``04"_P`\
MD!&6,+O$*$C#]HD`37H8D[4Y)">_R)T"+*86%%<-<IL$X7>-0KJ'6@H;D,WU
M"0T6+[6(BS93Y*=<F_9D7#/*A1:A4B"[K$C3B*-$("Y`C<R38(9E'?M5'5-0
MAL#Z$T[8P]\MI\LU>DI'6+CHJS&(`!%P"=.QJ-R(+OL:%N(H2M*!W1`<I:;7
M(6)H1W<.;0U-T:BE;*SW;$^*;&9C=O[J"L&]DCPP37O%E34+*9H+BAH5<(Z+
M73]"B4FD6(UG;K&O=#TUP<B`X/@?7D;QWFU;$E62K8;89[<\F*9%D=2N&=\$
M(C:II1$VO!-J4E6C!5;TE$!RNZ:UZAF>Q\3Q(U6(#DQPNPUY75I8)6S1^S([
M!K&9+6+7$RM$(VHG%I:;EZ)K8H]UNLEDMUNB5NB5JU</CHR[]FZF!@EF:V:+
M3K/#*/$>P_U)K$H@AB#I9NRP[%FC/#+N:Y%R+-9+)9(O62R4\@$-'XNS]Q2/
M%-8;@_2Y^2+KE=A'66MS;O:,6]EAG)`\N:^M=$S.1<A7(N5<JY%FLUFK=AUJ
M2LT9=MD'";::'39N*QUW7*`^!=S7>BY7.0:<H[NQ;*'C-9K);K=2W(HDY\]L
M01`-B8(V]%+X'>2:J_D@ZKCO5+^.E5&T2DD#%&_,<[,6/R%BHR92Q3,7'#NT
M3K>Z%E>*_6%&,.44;`F5W/+6A@Z:_EN6QL_1WY0=5EV[]0=CIS?!BL;;,Y70
M8'&N'8[%;%.KM>G:<UR_%K\84W3$VD&H1%JQ>N-RP<L3T?QGO!:&_P`W2\[,
MF/FU0^FFM+BV(+$?0(!3H@41L9SZ5X;C1G;6>FQ\+_EU+^PHV[,^G8'A-XPS
M^,.FG:SV_P#_Q``D$0`"``0&`P$!`````````````0(0$3$#$A0@(5$$,$$R
M0/_:``@!`P$!/P'^5NAF,QF,QF%$5]+B^(;+BA,IE,I83[$Z;VQ\22VM#5!,
M3INK]DA,J5*E9127*(779$^!VFG2=).+J<-R&^R.PS#P8H[6%X;^LT:[-(NS
M2+LTJ[-*NS1P]C\-=D?B-*L/(E1\BOLQ!W1A\0^KR?VS[/\`_\0`)!$``@$!
M"0$``P````````````$1`@,$$!0@(3%!43`2,D#_V@`(`0(!`3\!_E2D_$@@
M@@=)'Q5/;$C@;)))P@=.M(2G!O4AH:G5&\?%8,:T4K<7.+6,X)8LJT4<B+6W
MHL^>1WY=(SS\,X_#./PSC\,X_#.U>"OK[11?$W%6Q,J4/C10+LM-ZOE=/T6C
M_\0`.1```0(#!`@$`P8'`````````0`"`Q$A$C%!4000("(R87&1$R,P4D"!
MH10S4V*QX31"0U!RDM'_V@`(`0$`!C\"_M]2JO;W7WC>ZH]O?XJM%?-2@0R>
M@6\1#'YBO.TQHZ+>TIY7\1$[K<TPCJO(TICOG);[2X=U*,R16X\=#\)-U`MU
M6G'PV>YRQCQ%*"P0V\E.)%<MXS5RN5RW'$=%Y<4D<U+3=&#OS-O4]"C2=['*
MQ'!ES5]EWP.94F=\E^-'4XCB&Y!5"H%4A55X[K#NKQW5"J&:J%-ALE>'I;?&
MA?4+QM"?:;EB%8BU"M,,QZTFWYHEQDP7E>!H0DW%RFZI5%52ABT50>&WG1>=
MI'^H57Q3\U*<3NMR+$'6JG!C!WT7GL,L_P!U+'(JBDX+Q=%,CEFB6BQ''$S5
M-M^(]2RWB*F[A"^SZ/1@O(UDDJFY!&*\MN]BXW[<B)A%T#==E@58B4>,2IXX
MZA%@FS$;<472LQF\34$'-]*:M.O*$""=]U_)<]1*;`:=T<1_5-9#$FBX>EXK
M1OM^H33GNG6-(@WCB&838L/A=52=PXJGHRP"<\W`)T:+>3K;_D/U42U>1+7?
MZ#R<E/-XE]=AVCNX'[S>JFK)O'H$KJF0&]2I:W-7C,HX'>Y%<\1Z0@0*C$IK
M658S',XG8#V<;#:";$;<X30G=<?0:WYHG)18F`,AL^+"%<1FIP"6O]F*E&!!
MS4VD'IM5=:.07X4'$E6((-DWNQ=^RELQ(1_INIT.IAY;9Y)[^2&9U"A)-P"N
M(E@4XB9LF5%.1'53%'9KS&B*WG?W5"^$>87EZ0Q_S7`T_)?<M[+><QG8+SM*
M+N3:KR8,S[G_`/$#%,\N2IM2PB,_1`HC([9.94O=1#4VTUQ$[VWA/`)G/=+K
MY*('L(;:'`G4=*>[:R5Q5Q56?17'LJ3[+^97'LN$JC"N$JXJXJX[$!WYI=]3
MAF-H]-6CLYZJ*M5</@*A;M%(J?M(**;SVG]$%`'+4/A`4_HFG-H3.NQ__\0`
M*1`!``(!`P,#!0$!`0$``````0`1(3%!46%Q@1"1L2`PH<'1\$!0X?_:``@!
M`0`!/R'_`,_1`[LT9^$$_FFKSL((Z(_]-Z8.L`;OZ1PY[D8VRZ/XB9>B%9JF
M=$/W%=`\)>S71<R_"F:&</W,(]';R8A9D/0?^1P@&[#4S=EU>Q+#JMKV(\&M
MK>E]H1>VE/Y%5I>PU\36V.N9@'T/B4+EGJ29P)LK)6J?!4./7S3"5`X60043
M9</G_A="]'CO,MT-=D,4?*#+8EHU$%,C`,1-!G3>:D?./F8#W3.K7_>(Q1X#
M#K0[G[@BP'1N'43XC]X=$:@O8]IBZ,>5&_-(D"CBG4[0L-/O55^KA-6-DWB-
MJ6"-9NFY5RL`"A1%BS&MN#NPLHF`+#P&69X7W?Q,RI4O<_:RDO.P_4881V_R
M,&U[(MZULVYM*;C](N)]@^'>'J]-1U)4`DNE/79T)&$\_DZD&Y0ND=&`<0\'
MW&R.IP3+%9%8\576\Z0<`7"V%0*U=^QUB1:O.WL<L)4O4%%QZ*12XP0Y$FHF
M(-_GSQ+W+:/@>G64D(,!V8.S+`F6'Q*8<#K<G2/`X'W(@6';A^T;K78Y8NX2
M/0P9&R"U,M6$QI=&#EVC:;&C@U?[I!R%H":]8F(N/&9QIK!VC9]!'C%M04*_
M)0P^UGB.L*;0)-L?,1(;"CP\1K)M@?N(!5CD?LJLNU_95484!1VSL;$>"'$9
M%T5L`>%9?>%]X@W]!+*S?F)Y@;1ZX]<TD1S3V^R%I>"7,(.C+':ENVXB@<<S
M-]Z?;['.58[S`5UP_L=IE?&2@'F7+95&J8[P1I`#_%.L*HT2#<U]*YOZ'JCG
M=QOJRRZQK:OF7!HXIA,"C_`,4=HL/11&`O4FT!B-=4GP?8IH[H5BL([S?@!&
M;>ET0Z$TIS!X8I&&5.';DCD98II*PWJN68)5EUU8.6J]#EA2!W5B"@#54>7]
M2@!@<H.#C\F"*%])J^NI7.)U$OY!^Y[EFZ*T>Y]=O#A+*=&Q6/(LN`A0T#*P
M%;:I"D9<D`NEV].9V!J-,Q9O`F-`;X>Q^XI;O\/<_D"8C82OYS#XU_B;0/..
MT_5H]X[F=[?CB(Z9NW^'[8N>FAT[`P2B#S+5A!]"*W<#RK^%E`2U^3W^O.6I
M*'D/<PT.GI=1#=:.N(;`""UW/S`P`4LK@-,9(:RVZ!OW9UN%^/8F.ECM-8[Y
MM-./RBC0>RG*+PP!MEKF^N2`4;Q'_P";-W\4`_E*-2\>@PBG`E]@DK%X9_BF
M/JL/"98#EG>%T[$T#I*`//$'J5[2O3VI7&(2I7H$J54K'IM*E7Z$TP>Y,ID_
M$1@I(PCJ#X1EQYR2D]1]2KO([[\[(/\`4=8%3?U-)QZ;0^MF\8S:;0.==3!]
M?Q'?:_"F(\?GZ/_:``P#`0`"``,````0\\\\\\\T\T\\\\\\\\\\\TRHDT0`
MX\\\\\\\\0P<P000LL<T\\\\\L,\(LP-I(4(LT\\\\L4L0P$0D,@4X`\\\VX
M$(<\\X\$XD0<\\\T(`L(0P@($,($<\\\`B_\!``@`=B\@`\\_\0`&Q$``@$%
M`````````````````1$`$"$P4&#_V@`(`0,!`3\0Y(`````````"&H```5`$
M`P)@(`(L8A4A5__$`!L1``$$`P````````````````$`$2%`(#!@_]H`"`$"
M`0$_$+@`'@```````#W0`H)B6S&!`@AF343O8?_$`",0``$"!04``P``````
M``````$`$1`@(4!0,#%!46%QD:'_V@`(`0$``3\0R-$(D0I=A2``]!26.(1@
M0($`@````D$0*`!B`=$!0H*B!QH"E0"`@4)`0`%`0!!!`4`!%`("@V*``+&`
M`,"(WFQ(*`!"0!`0"D*`A`!`!0```*$4```H``%`.0`/PB%@H:((@`1`1(``
M```$0```)`"$`(@*(```0``(`0`"``0`(2`4$0```$J&H`,]A;"`@`A`*`"`
M``@``4)``!0``$2%(0``````("B%!]H=S8TPA`-YD*",```A`%,0`$T@````
M!`#`!```"B0!2&`]&$D`Y$)@"0```0A"```````4@`0```S(`(6$$_0+````
M0`@`&!0(@"`@``````40`6,``")@,B```*K%=$`0```````"$````*$`````
M`$!0``(0@`````1`(5%F`'NY`,"`````````$@``0`!1""0`!`"B``0"`2`(
M``$``44`!0``!@"`XK`P$$,$`*``!(``))```2```2(A2"D```$"400(,4*(
M``H!`;APZA"`F`"`(`0```0!0``(```A4"%A!@BAOS*`@!1\D0@,F0$R:#)H
M`F0)`SHH^E"X;%`^[B*&.X2#_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M;V)I;&4O8F]T=&]M+FIP9P``````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`S-C(V-"`Q,#4Q-30S-#$U,"`P,C0Q,#8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0$!+`$L
M``#_VP!#``8$!08%!`8&!08'!P8("A`*"@D)"A0.#PP0%Q08&!<4%A8:'24?
M&ALC'!86("P@(R8G*2HI&1\M,"TH,"4H*2C_VP!#`0<'!PH("A,*"A,H&A8:
M*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H*"@H
M*"@H*"C_P@`1"`$Y`0<#`2(``A$!`Q$!_\0`&P```@(#`0``````````````
M``4$!@$"`P?_Q``9`0$!`0$!`0```````````````0(#!`7_V@`,`P$``A`#
M$````?5`"+Y9ZYY5K%FKKHWE6YK&_E[67*/KY/4XV3F:XRF*=91Y1T)"G>J;
M(YU49E:X5:0WT3QNW/>S*'OT/'6F"AS)>@,=0```\R]-\\N>=F\_]#WFIP;O
M5KE?CIK<:8Z8$'7.9OACIPR.N^*B]^4@;[<^^L8SG-A)WN6>F%K6OS==L]1N
MDEM`QT```"CWBE7/GWI7F[W>+T<8#49#885RMPPBL<,285G3/?BUC&A&Y&Z,
M]<XZ+ARBY3?IQ2K!G>:[.KVL0_0/.?3\Z?`9V```%)NU0N:*K=+=XL2J7Z7-
M4SG'K]66=`L")%VO18G/OT3CP8;ICKIJU9UG2&:=E<-)JZ_=YJLUZ1'N-?6O
M)O8LZF`9V```%5M5;3SAJK<]>50]1K5;FO7X5:F3*2#;-ZJ;56X;C])'0C[]
M]S3ITWEI,^98&J[?T4/'6V4WA5=>;NPG0=%_M/CGL^-9`F@```KECKZ>:N$S
MKKS:J&VDU3W+).Q,(TU:[=:JQE=9F[-0NTSL1U#WS1&+&/K<[0]).>BBQ=#6
M.:YBO./L7C?LF-`$T```"!^@3S)VD>=>;/7*F:98(\=HD!I7*M7#*++96EY>
M(53ZPNZO^BP)6ZRF>L;,DG"%W;E<R7)$]F\8]GQH`F@```0/T">8OD-@Z<YU
M?L"IKK://6<6ZE:.#A*K,^M^EDE2U&+<^8B[H&5G&UHU$6&'TYR8B0GNKJN8
MKDB>S>->RXT`30```(7R)/+[#7K#TYS<9T:CKI6Z0X]ARJM79=1%.B]$TE\>
M,0;%I(MK,QSL*=&4,88X]@6L5Z1/9/'?8L:`)H```$CM*GEEBKEEZ<Y:EK6V
MKA-I=CA3P<PE["J=9VQ%81Q.BP886L*TTTM$JK<A":=%E62%[%<D;V+Q[V'&
M@":```!*Z3IY19:S9NG.9&EC50G6!.F\Q9R(DUNF6UQZJ[S)4A3H+6">TZJ*
M9#ZHT4#$6M\BZKF*Y./K_D7KN-`$T```"IJL3R&RUJQ].;*))5-3.#2S2TN5
M*K*/--^51X+J*+^TGN;FG0UY\YD02P0%1,8>+)2YDM3'K?D_K&-`$T```"YC
M"3QJQ5RP=.;>L6;+2KHMXI9>4?EE%8K-M5PW1=(L2'7<2M43BMY=6?9-H"I9
MJ9?\I"ZK&2M)'JOF'I^-`$T```$>1H>(.D[+IRL._/5KOSC])5N^[.S*EL%0
MFV&.BN(]DE??&560G_`B3^D.3IB',MYJ6J='?H]"ON-`$T````!XSF<GZ<[>
MJ8\5P]J%IR=T">PKGUJ[6NVSF3FUSC:N`JS7&NIBQ((\MH6R%LB%Y7[!IP2M
MT;-\MZ!_SZ`"@````>=TOU#RC>+HQ06"EZ6W;2UF%:LLJ(%KB6[=JQUDLVM=
MY1#L\5GJU!PRB(H+)JNG/KP2(B:\(]7EACH``````$?PKWSS.YK=NH%@WFW9
MCR)K&,Z@:E@8P;8(I(RJA%B-<FNN_(UB]%Z+[52O9,U@!G8``````$*:'@AZ
MIY-KG8GE0:U8\*.E,M8>Q*(H2U<K=9/3GQED<(>+F1QVY)Q1]YDKV_8VQT``
M````````Q6;.)X8Q]:J=RHEQ^MG4S@#.#)K@VZ<,$K2/P,(;58BD^F=LYV`*
M```````````!C(&,@````!C(``8R`````````?_$`#$0``$$`0($!`4%``,!
M``````,``0($!1$2$!,4("$B,30&%3`R0B,D,T%#)35`8/_:``@!`0`!!0+A
M8&Q`Y'P+4?=6MQY=P!.6[/X?^&4FBQR;GC#E5[K^7!CW&[LHWFQ;[JV0!S0L
M^Z,92@FM39=6NK76+K%UK+K5UJZU=:NM76+K%UBZQ=6Z>P1T[O)Z`>:8ZNNL
M*W[CNRS>.%GK%U=!R9]L[,^HY\^IK6"F>O=>90W9D:O8(1#O2<4[4N='73L$
M*19C'$(K#JV^LL(WZ_=EH_J8HFPS)VU:U5>N_9:KD.[578U:N4*E1>4.E?<`
M!1L2A*0;("$08;!<0`D:5<$00FZ/)3\QL$VK=V4;]U%^78JEWBX6**_+1^W:
MZVK3MT=4Z4C(0XBC)T>?A8GX0?S8!M*?=F?+:NQVDQ5A1DIV]2$I6RKY'YIX
MTXUR;#+DD=&)$$XB)*,NDBI=*R8+.Y#\I0GO;0Z:MD"*6+MLPJEVNAY2Q636
M(%&6>JM37]8:.E#N^(&\UGSAKSV2<YCRL5+>(L5\G&W&9R,F/-U&;NKMKI`5
MP=.Q9R)(6UB3\Z:.BB[%'1LEIFF><46Y-=222B62O9#;$-:YC1RGY#2UE^6,
M;2CW?$/\8';=R''<P)FZTD&=LCA=9#NEKRK$KG0P,O"WF32<D]JVK:MJVJX+
MG5*4^KHF#HY"0#$759!\;B@T8W=.7!]H1QU4?OJ-MJ]V?;]OX:F@]BFVX;X[
M(1L!W:JR`5B-C"#>;PRM)L4S\AQ.T69:+1:(8V=2AM52T:JN3D3JK1H"G7F*
M4"E:#9&SJJS.>P50^\?A#NSOM?RK2VO?!O:$I`+7NOME8<KQ&.$BRU'B'U#M
MEJT5M6B:*T=D\7:&%E^J83&74CBT90`2S:T9GG;)&+#$55FUL=^<]K^0$RLU
M(S=N97F%X'3S(-^;JJ\NFR&U;%M3148J,%EC,"OCGY%5[:A`A&L6A5D.L6T\
M(1'&2*J/N^_-^T_*OQG!IL6D^H[9!,T`G5ZK+;B[C$CM6C,I-&+QBC$B"%@C
MW[0ZQ"J9JE53>Y=0*@@<9(JI^[[\U[/\J_'5N#^*)6"11A9$GKF@:GDG@AG@
M2`Y#B]K)P"K5DUQ8^K:"*55R(8Q"9WU6K<7155]SWYKV?Y@X2<EFS\G"B8@H
MU(]BK(18%BM710#(GHQ9WISDAT@P46VKQ=>B):;?&A>.I89F8XK-!#DQ(/Z%
M5;W/?F?9_G63JL3I[\BC;)<[1B..<+E.565<T3B?P4K<=T8WIJ4,A!/<D-#+
M`L4T9W24.C#"Q;GS>=(D[Y&Z>A%XTW155]SWYGV?YUO1U=K<]@$;F%F\TTR[
M:\M!8I_W!?W%PS1JU@6G>K*\/=(PB/D!M2L6)NU;''&''53O*_NU4Y1#!FE>
MFG154]UWYCV7YUO3A8`,[,*T!=9L1;)[+4ZW2CO;@6B[[2U)R-A-HHS:5Z;W
M#/".UAEJ*%JO%N=8FHT]9\'1O2G[OOR_LO\`2OZ*4FBTK@64+(IJ,G3N[\';
M5GH-&3-D(K=D'4JU@Z`$8(<-74B1BGN!9#+`C<#>E'WG?E_9?Z5_M0(QN7N>
M$=@]&H=CXXU=5[3$E]`DVA&(+!V'6I#:<ZNW)U(@58G-"C*A[WOR_LO]*WVJ
M4GJ7W!$LIV7@H7'>5^M&T&@?G",6(H#%;LM'$2FTL.[(M6Z!5K;%=WT8$H1@
MQ>:&<8*0HK+'V@K"Y($98_WW?EO8_P"E?[58#"P.7-IRUYPQQTBQ-@\5K(KO
M&>5OSYX*%WF5IWG8@[.YLWI$MK65.!>;5J;QP\RL7HP>K5DQ.!O3&^_[\I['
M_2M]O#^B8\,I<F]!3IVK"$*`1Y"O.4AD#9B,4FBU62G(=9HQGD3J5(@R?\BG
MID*@`%7CP=&],7[_`+\G[%_Y*_VHQHC6V[)IF,%".,O'^S5PF7R\;+H&=#H5
MH._&4FBS3E-Y1M10[3<Q.C>F*_[#OR/LG_DJ_:L>1OF!HC-=WLZNXT)DQBU2
MMXIX>9_!2.)EU(4TVDI1W<)3=YM4Y,WMZ*=J;QS,6)5I3<E5T?TP_CD.^_[.
M?\M;T5Z+U[-4\=\"/-@SW/(+'J8DKRA8*\7>C&#U`5"`G2K2:QBA*!R5[!I[
M!!@\*N-.Q`SE%.T5?,]DD(,.#H_IA/'(]]SQJE_DJ>BT:3&HD"XK4%#S*Q8:
MO##BDT>;R<UD#.8E:4XT'-+=7/+9G)[GL#<E6J?J`,SPB:X`+<RU>56L.J-.
MC^F`;7(=Y_$!OY*B;B08RM+%U7<>.JPDKM1K,6*6NH7*KI[E1E+(1DJM*;E5
MBD"Q)L4!"I5@I^,E8]/AQOW7>[>%KP+4=1]"D8<8#LE73V].I<4HNTFX?U((
MY)JX&3>'%T\]9-5LR1`V(JO88O"2.OAJ/F^AE([+=1U#TNRVGOD/-\.\^GL1
M$6-H),;,1(E@IV(,[2-)/(\4UN#.SL[+=S'K6*@YEAN(,7+E<\N54E87PY'2
MM]#/QVW:SH3^%ZN]@%*T[(=AM#V/U9%YP,+)T1Y'M%$.J*J1^;:L0#$L!'&;
M7&V[A-E4VK8<//Z^1%:LQ#"C"5BPZFK'KA8[<?\`0^)A_J`?QKOX,K=.%E.]
MBJ\+M236KX],95>L$Y7IY4EACBKDB*,SM.+G>3Y8O4V#"8@*]EZLNLILT\EO
M<5"9)_TZ*ZGXDJPY=?Z'Q`+?1B^DJ<U'TX3"$B&,8N%D`[`XU;M5=;8@OF!7
M4_F=IJ5$=3A.$9LU2LR;RMPDC26-'S\A]$PV**Q!Q'K$T<$]6[]5KPU9EJS]
MKJ;JQ-?#(/I_$U3:6#JJ;1#GJWT"2=UL=U&P/JFUTX.ZDZ+).SE+2`U:M]*R
M"%@%NO.K8&Z`;1#+JMRU6O9JK]4EFO4KN,#40L<DO'52DG=3EHCD7P]1^KF<
M>UT.CPF)U#<FE)ES%S%N6Y;EN42[4UIU.P\EO7BZ:#J?E1RK$4'NFC%HM]31
M97%0N,41:I`V&90M#=,6LZTJNN57=<@"Z<*Z<*Z<*Y`&7+K,M:L5*R"*+=@C
M'W+'8DEF0Q0%#ZY@C-$^`#)YX`S(6!GM^0+Y#)?(9+Y#-?(2+Y"1?(2KY"5?
M(3+Y%90\`JN+K5EI_P#%_P#_Q``E$0`"`0,$`00#`````````````0(0$2`#
M$A0Q,`0A(E$30$+_V@`(`0,!`3\!)':-'U+T_@Q>J@SD0/SZ9R('(@<B!R=/
M[.1ID_61M\1-OW8N\)"&KU]BR'8LJQ5QD>\)="HT;2S-IM+,VB5&1P?0A46+
M%6.#Z%34U-I!R_K&*BW\B<8)?1>D<'T*DHI^[HG5LN2E*58X/H7DC@^A4O6V
M%Z,C@^A>-D<'T*BK:JJR.#%2U=QNQ9'!B\D<52Y?*]8XK&Q;)=9WSO58L5+4
MN7Q637C2S:+E\+TN+PN)M+%BQM-IM_7_`/_$`",1``$#`P,%`0``````````
M``$`$2`#$#`"%#$$(2)`41/_V@`(`0(!`3\!6FU?I?T\@CTE0+;5%MZBV]1;
M?6MM4^+:U/BVM14^CU$^2`&GL$8:;"'>W>Y+6/$-/-P4]GLZ>!@.;'"]C`<W
M`D4+F`YQ-<P'.)[F`D\S`93`93`93`7?$?1/HF(LUW3R,1Q%I&0.,S!PDX73
MITZ=.G3^O__$`$`0``$#`0,(!P8$!@$%``````$``@,1$B$Q!!`@(C)!46$3
M(S`S4G%R)$)B@9&A%#2"H@5`4Y+!\-%$8&.QLO_:``@!`0`&/P+,YKA49FJN
MZ055^!51A_)5<J_1,9O`OS!Q]T=C5NTV\*JU317T*V?NMC[K8^ZV/NMC[K8^
MZV/NMC[K8^Z[O[K8^ZV/NMC[K8^ZV1]5N"JXU5IVPS.WTG3?R<B,QD;W;MKD
M=)T;2QE,+6].CNH&50JZ+'#>G-DH!N4QH-5M0JET5*5H,5(30.%X5AMAMV+T
M*XZ(:T7E!C=WWS!2<F`:<PYJF:A5IE\7_P`Z-.JL[CO"+[5UBP@.IIQWIHJ*
MVOLIZ6:/%`K)Z*E*5WJ,-+;8%"K-F.EU';TUM:T&A1HO5!>=[M"=W/3D'$#,
M,Y?D]`3BW<46X/&+3VP<31G'BK+!0:#G(GB[38>2JK)S=%D[>DEX<%UN4-;R
M:K73ZW%:DX=YJ]C7>17=%!DM6N.Y6G$9/'Q=B?DM8SR^9HKXIF?K5<GGO\,B
M]H8YA"JR&=P]"U<DE^86K'T86L_]RZF9S>1*I_$(M7QMP5J-U1G`3.9TXCR0
M=FCR:`T>_?X1Q73P2=(P[1_Y5Q+9?"L5CFMXN-S0OQ.5=9E;[P#[BJ\DE`O%
M0C:O.;HI[VE#))G5C/=/S8K%7HP1#I)77472RCJCM`'95<\/EIPGFC&_9=<A
M')<!CY)SY,940;PNDR.YWA71Y6PW;Z*K7C,XN[K)]W%%QTCXVWA,?[^#E>JR
M.`"L9(PMCWR%6MN;>\HVE)%_3=J^DJV?EFB'PC3C]2P3K/?-%!Y('`A"IUQB
M,U)F!RKDL]EW`KQ,'S4[G;3G7JINY:-]RO4L,43I+1J`%62QDS/B5K*)73R<
M\$.A+;(W#=G>:]736_X7+,WRTV>K-4+I(QYC@JM-/)7JR#9&\JT,4X<0I&\P
ML:C1N%4YSS>LI<-[DVVX@!4$=6C>B^,[6Y:Q5(]G>Y"-@H!F:.?8-]6A:CN=
MPXJX'R75.LOX*CQF(.R[3*%=IVLKEX6C>59CUI%;GU6<%98*#/'ZAV'ZM&CQ
M56H77JQE,=MO$+J)!:\)Q6&NU".3:S:UR`WG-5R_\++W%5P;S6/32<&K^C$J
M@6W<3HQ^H=A^K1Q5RUA5<"NKE)'!UZD>[>:W(,E/U6RZG(55==QPV2J7-//'
MZ)P8'4/'>C9+6U.\57M,[Y.6Y=7&`K]*/U#L/U:'X>`V:;;N"`DRB0O/-5R?
M*#Y%4RJ.[Q!58:C/K,'R58Y7L6OE,I"V:GXEJ@#R&>Q"TROX-59'M@;]UK95
M)56K?2Q;ZH.&!SL]0[#]6A.T^\:J!U1:-:JI*UZ6>:Z?(]G>SB@]N:S$UTCO
MA6KDUGU%7P-/D5[1`]G-58:C,YK'6(&[<BLY-9)&/%.(.%K54=7>_P#X3[6"
MB!QIG9ZAV!\]`.CNE;ASY*DC`)1N(O3;K5,6G>F-Z($!U;-JY$.WG`;EE#&[
M.*BR:MEIO<>2]F>R%C!X5&^;5?2I0UA0\T6FA/!,F@N8XZS5(YOAJF--*4O4
MQM=)J@6P*?)8"I5IU&M"M.!;DP_=H1^H=@?/1I(+Q@[>NK+9V\'7%==D<H\E
M8R3)7-KBXJE;3W;14>4MV=D\DQS9:!M]*51:YU74Q*I4;Q]43=9XIF3Q7\2K
M/NTHBUT9ER?<6K5BF\@Q=1DUCXI%;RI_3/X;AHQ^H=@[S&A>MI7."N*O.:AO
M'!6LFE=">&(5Q@D7=Y.WYKVG*KN$85F%M`<3O.:Y8J]RVPM1P.A'ZAV#O,:#
MVR]U'NXE=&R)G1MH#1N\K6A9\@K62/+F^!R+'ZD@Q:>QJ4'=U&=_O'Y*KHWR
M.^/>AU#:;]47+\1DVHYN(":_Q#/%ZAV#_EH.K<V2\%6F/<"7VC>@&WDJ\:II
M2_E5-E9=-2H<M;;;<5:<5::&PQ\7[U5V5N/I6KE,H56.;,.&!1:X6)!BTJJ&
M5910EQI$P_\`M-)D:Z^M68(7G_35;1_TU5GWG7`*./>!?GB]0[!^A8D^1X*D
M]\>Z0(=&04`1@N#&A3O&R5$R78:+5.:#8W-VJWX*YC64--7!-YDMHGUW.HHI
MF7/3[.-A9,8K)=%N=@G5Q>ZT:;LW1Q=;+P:NGRHVIO=;N;H0^H=A)HT-X5J(
MNA=\."ZO*8W>I>U90VQP:A'&*-39X;WLQ'%69"*CW7JC!<."-H;U61[0@ZA&
M3,W\<Q?D<EBN+'8+_IQS7M.4EPX,5(6!O/?HP^KL)=#B3N56Y-=S*Z_)Y&CC
MBM1VAUL8)XKJY)V>3EK91E!^:K8MGB\U7+/>NK8YYY!5_#GZA='(TQR<':$/
MJ["7RT)WOQ;JCDF-`OVWFN:U'U<GB:A%E>_9?QS5JKUMM6VU7%8YA'$+4AW*
ML])'X@;E&UMD-=PW(T(#A=\U:.VW`J-QQ(SQ>?82^G0Z=O=ON=R*+QB[>I+(
M=[U?JL'607;T^.5IY53HW7EER:R,6I'[(3!E1,LK_=!H$)&PM:.:[IGT5828
MG<E^'RK]+N*<XX!1367.MFLMG&B>?<M$,KP6`3KJU-35#)8+W''DFL;@T4SQ
M]A+Z=`AXJT[E:R369_3.Y67UB=P<M1[37@4;;VEVX!/F==;P0+O#<HB8^EA`
M.J#2].CDVKZ#DK(M`$_X1,FT;E#3:JGL]XMHA`YY:YMQ;6B`%&M'-:TE3P"I
M"WHH?$52.\G:<=^@/(]A(/ATJ2L:\<U<'M\BJV2\_$<PH;,C<"K.50N]35WI
M;YA=]7Y*F2Q/>[BNGRS;W,S6GMH[Q!7R3$*K8@3Q=?I./!O8%%#-:<FWLAM;
M-K$JU$^*7R*LY3&8CQ."NO&AK11G]*[F/^U74'D-"RP%SN2P:SS*-AT<E-P1
M%++QB#H3.Y#L9!\6?)P[9M)@CD!+CJ-`O329`64PI@58DLFNXKI(:N@WMX)K
MF8'-3$\`M7)WJ_)WJCZL/Q!79G$FS$W$C?Y(0PEM:8UQ1<7OH=P<MK=3#'S4
M);BZXZ$CN+NQ?SOST9WC;VJC[GMN-=RN1Z2.2V>[(W*D@H2V\*:/<TW)F3,-
M*WN/)1L@`:7NLVMZGB+BX1D4)5_+<KP'-/$)H::Y._=X4]PX)K86M=JWUQ5I
MT<0;8%:#_;\Q<Z@1RN2YHN97?H1\[^Q8_B-"W6Q-X@O:(B]GC8KYBWD6KH\E
MK(\HF3O'WGDA*=EXI567>8(W(T)<7&KG'>J'#'-%!%>ZJ=&=XHNARNK",'<5
M4Y37R"LY%"]YXE"7+W6N$85-W#/11LX-[&UX#HW+7AC)]*ZJ-C/(9BR45"]F
MD;,SPNQ77?PXGR6I_#7?-4LLR>-5K;E/OYJ2-#AS5?P\?T5&@-'*[1B;SJ>R
M<PX.%$YAQ::=KBL>PDG/I'9C*6X.N=Y]I09OP]3TBOT@QNT<$R(;A?V;XG[+
MDZ)^(^_9V8'636JC;(ZTX8E=/8'2<5=I?B91Z!_GM:L[YNSSY(M<"'#=FN['
M!8Z5M_<-QYH`7`=M:9J3<>*L3,+3FO5ZVE=(N^7?!=^%WP7>A7O"Q"N5V8/G
MJR+[E!D8LM&`'\A9E8'#FJQ2.CY8K5G9\[EUDX!^$+\R?[5^9/\`:OS/[5^9
M_:OS/[5^9_:OS(_M7YAOT7YAOT7>QT76S_VA5:RT[B[_`+,__\0`*A```@(!
M`P,$`@,!`0$```````$1(3%!46$0<8&1H;'P,-$@P>'Q0%#_V@`(`0$``3\A
MZ(S,6!(&>`FPD?)?9)U2^(0Y">XTZSTGK)/\7UF9`QWBASJNYY+`F17M+O\`
MRBB*?)"+5#&?+_`M2X:P/$VPV&5.XA/JK[!*$-PB#`[?WV.?3\>F8A'<(3D&
M!Z2NXQS[")8&Y*VU7.KV&R9AD2;A.?JOY^<%[DBL0<IW2B]3L-3:_P"C1GKI
M<>$->^+S!&+F#=OVD1A3;=AL%K_MB-7`SG[1:*N#1C>FSD:3%9T:7'5;61N;
M6YX6YA#LWNZ,*Y)F?SCUE]47IT60EB)341P,BF]VEG_!34IRG::QTCHVL[,+
M"/1MW)C)/4E;=/D-!'9MIY8C:Z1?864W&1?,4)2C1B>#8HR4@QV[V/?I!!=9
MEPENR5LOF9&F9V/&D<P*E_/OS#:G%BW<OH[RLT3MBT;ZBV$TWY^T;C0X@BNC
M(\$FC$VC]R9$1N=NF17-TEO0@2-O]!#W\G+(4829$QV7@^K%+^=QPU7R>TR"
MPD4X197,T==ST+.1SB0K(Y\I++LP;IPM`^1-&*99%S.BM(N1=X924Y<IL%F?
M9>Y96N2M,:AH:IA,IWQ&$=S4;;4\B.K,2D-D[MN\MA04?L2#.B8]:=Y#]_\`
M/YP;QEZ/_1:'A\,>F\"$"DM_5?T3_P#G/`BZ4K9C.W&5L9/),MZLL\\MTF\#
M]O0Q(6EQN.IF;W*<8'X409C1.J&-_P#C"6MT:9I$]88R.,,LI");LH^Y"FBX
M:GP4DB32)Y(MW^K_`)KY5>PVUIML]&9@)MN$M^R&HI-]%HA&"8K34RB4=%<7
MCL2C\'D7@3))(C::8G<ZW#:E_H]V6W(@@N`EV%M(+R^I/V"\R+YDO)L2J=1N
MU:,??)"%RH8["(I$TZ:+PJYZ'Z'RQZ&6/&2O;^<C?NNBL9+ARWT(ZD-2R()I
M@R&?WU7D:-1XWZH8GS&Z"MXE+<K7+#9?ZZ/:(LN8:V*&S2T,.#$=&/SI-?IG
MV.:[(PAM!4ADL2C2=O0E(5+K4;%A20N(D+9/YI].S&@Y#+$LH/%[B<)EAX-#
M:.?="G';W"^/D/3-V(EG*=[$,'*U>>@@NEB3F3!)SA$:(:F[20I7=D6T"0EV
M"L;6\#-=`Y[@<8;QW)/-2_X"\'NWN43.:D(_FL]K\,9Q15$6%Z,3>!ELBZ>7
M$U*%Z0G)>/4@UT+I.'I7G<&\:W\X,207FG":V$+IWBG+$IL[GE^Q53@@P,1,
M_P!G^##V?#&="Z,H@:/5'L(4RNOK41=N]EZ!E&GT%NAU"2*F]1'@F";K>)1T
M9QWHMQ_4ML@:O8P;FHH*_CHFS1_F._(NDUZ8&)3ZE_@^)\,R=!H/P/B":>1!
M:$T-$V-Q(DMZ27]BGTG`?Z9(P//X9+G/RX/JAHQ\-H1.6F3RWA8U@!$Y?H*:
MR-,0S3<X]"$1<PQN0<V2>F)BQOL:_@^)\,8O`Z0Z)02TRO&E,)$S:,9QX\Z$
M%?@,8HHB:V$4=XD$H5P>Z.?['DRYDD6.QB)9;922];-LDBQW8NEC16+PN\8I
M7TV2+2T2NEBS[3?\%_!_8_D)2,('4F!>4*>I%[O%40H"W;'E2MFD#$Z<M)#6
M4RMAH2X)S&4(0SA/@$DI!9QV%*(Q^`Q9KZ?;[(1M^;+(C%K'L(2J$VUJVXC.
M5+*W87'<P,3ZS?\`![+_`&/YB5Z&L2\8O(:UPZ0F[57E@3,\IL5UCDIVIGI)
MM)!@+AP/:Z>]@Z-B6TD;;TDA*9M8$4M2&Y>P<UK&,$5)P:;3(.HL2>K8@BJZ
M`(-6EZP]R>OC!38'6I_KD=X2,#$^XW_![6?WZ;<Y,B=LPI/)2'Y>-KPDH$\(
MQ0ML34I%EBDOR+D-<AR3R'V0ZIDU74AOG8W)6,,JYT$,3J<#<<-,]0TN4)J;
M?!-O=^!2G]%J\1GLE"2T$8]#[K?\6"]+`WA(H(OE64W;O]#6?P9$9&PEB$W+
M7(P"@]95T:3DA]0ON2/6:&7W&)0A3J@>O[A3,2Y<#*U^1@?86,TZ'TV_X%_A
MB>2]>8/<+J64AAS-8'[$UDK+Z,4$^F,$5#*91"DCH[4CZR^DF63$#$.KO9Q\
MCD&P;R+\B/+)P'X$)ZL&8,^RW_![KY=%NEE>#D[""G)+J)47,A3LI':9ODR4
MU0/Y:MV?<?6NA&"$D+[SP^^Q'CBR@R&<P3:9U`SH$*>U)*1`THVER%--AQ#D
ME2J!E\M\H$M6ZAF2?,==PS%E_K7^#XOR?VZ[2FLIRQ"*>)"O.PV>A'3S!)#*
M)SRE`RU/4<0*CK(\EG5XU#$=A'4Y):4*DF&&2-A"*?/&7#,B&!XX;6I(Y3DD
M-5^X1;"U^8K'@B6MUK9%5LI7%RA?T;';&9A/I:_@^+\C^9#I[&60F93P-F];
M?`6,JV#-<M;)&!/=[B9<+9"\J==3D2MC(,I'N6>!U16YB;9,:F2]@^W`ESF1
MRX+J)3V%OMSA>I8$9U/(S7HS%NU_![!?**>8\J20JMJ$EMBH%L2F7>PBA["R
M4/C7T/N>C>ZSTER&>W60:U+M3I;0:HI*J2JA+8B.Q('5:G>7/[!=!BV)G@H1
MTU&87\,SY^I'F^W0/W+%MA87D4%:;'B9H(6X:-$4)K#)[V4X&22T"&T>4)SU
MNYBE]BO#*FC"4,=+Q4TY?`I3XLW!:UV&.CA71)->Q.H%7K>LE<,B=#47+,#(
M)^!5D7R==.4]`!7!23EHAD=X9X>XZ=1(EHQ!8H998R2WMVX)[JC=Y+'/*+DM
M&0XETW\#LG&]>@N0MO#@Z$B1OO@]$N!HTWJF^)"BA:?!%1HM,U+/[#:(.[GR
M'3D%["?A_@6#R,O<:@L6-2BD-L,9WW2\G9N+M-DXHL>&[*,CRPIJ7(DVR):\
MBC>M?W&<))(<B[J%^6FPB-1Z$1=E%@/BA2V.@L/]@-UV1;(^HI014+OHT>=:
MXQ>=+AT<S$QV9[?@3F&^#/W)PB0CR=L"+]<CEVF46H+R(>D)*,1H<9HQO(I<
MXGCM6BJWXIAS/6I$UE"]KN.SOQK#9Z+4H]210SWK9#XZLA/OGY_!,O<6-L^N
MF>A(8TF)_8$]T=-IJ"T.9UI9'D6VT@QK<ETTV,OG*&&]\5PJ>T>1$/0V0J$%
M4M/:9BMG63K';VHYRZ8#TSP`^^GX>,F^2U%@O+-EO!*NA!I5N39R[%ZDD;;/
M*;+#-++$IQC(';QP2S)'Q!=1>+/1O02FV<#JQREH9#;!/>RM(C[.XM,D0G$I
M[$D[8%1I,]PW;(:],1LCVFUZ+_?P^-/87HF08*F)^[V'D38@2^`_""X17,-B
M"U#69$-\-`6U)S;$L>G!"5IW_81%%,R[6!(U-IEALGP(*YK\2<R':&%AM*">
MY<CHMB!D>!)-C*48C<5"Y2?<,!J&F`][G[OPQ:*/T_Z0F=3A0V2-%6MW(LF<
MI+&NZ&W@V)2,V=!LV)#:;^A+EJUJ188G9R1;03!;1JE6F0Y>BT/$;Z,<GOR<
M=9!*0<<.#QG'3$V%G`\F$1))23"Z:!HAHY$OPUW,GAUT"A(>>B7J'D[V:#:6
MF\;]16[-@*O5=AGP#^L+,3>9$B?W"RK+,N!1%JS98['<XLL@_A)S(5<:"C4?
M88B3)XM>@5D?AS/D9-ZR(*X%SB4]-.C,CL3)4V2>K(N6-2T]1.1`:Z.1D$5L
MT#`Z_P"OXV+..#3_`$1LF)-B[1.>DGD;))%B1QHK)J$Q&#08J8F#`RZ.A"Z,
M*8C66PFY`;5):O7\4"TY3'^B&[ZX;HA:L:BEB$R)61>*'(E<DDD2./=(3XDC
MJ:-QE&8HZ78)"(6-24U&Z8(_'!&9*66P-L00VW)(%!):%O1#<2OIB-!C4T0\
M"J=!G:3-2.DLVG0F):=+;MA!,"$EHORX0/T2?'N&](>C[,@9,=1I-"TY>3;/
MD3-"\FUZG0-SU!_L`LA>3>1H$A4&MW%=Y<,5&4XT'_@:]IT&:5;((8V5P8;[
M$R(;?;_9]C^SG_?<^G_1P?KN/:^K]C_V'[/^M/\`HQRQW4O]#VY\/]K'WK&?
M_C-)Y((_C'2.D$#4K_YG_]H`#`,!``(``P```!#SIG:\6X\Y\D/QAWSSRI3[
M;K@_#AHL)CCSSRHP30.-C$>?KI63SSS'A9PR5#F5"3*##SSSJ$B;W3`PS#O?
M#SSSSZB!AR%S#F&]VA3SSRK0A?U$D'KC?#CSSSR[23XSS"S"1_13SSSSX"1F
MA1`41RAP!3SSSH@@5BA,-A`A33SSSQ:`C$G2-/BQ#!A3SSP"`0W;A@!@[AC#
M3SSQ4@S2X1!Q!9&0!3SSRRCRH!CD%PR]2"'SSSR#A=1S::AA,C@3SSSP#B2V
M"??0VQ3C3SSSQ,R`%ACR`W2"/SSSSQB-AT$%0#WWY3SSSSSPD(331WK*/?SS
MSSSSSSQSRQRPRSSSSSS_Q``@$0`#``(#`0$``P```````````1$0(2`P,6%Q
M0$&Q_]H`"`$#`0$_$!1I!H2H]#_#ZGV/J?<^I\I]A&-V4';?$36#^*U\RPJK
M-.@"7X7D?O%8E>E4@S$YPTT47$*,4R#3Y!BP2J<VQI:S$Q"1>(MX_P!#KP?(
M(0:)&T5X(3!<B$D8DETA'B(K*R"T1X?2"K$$6*NL"(F(S>(1=0&1,41Y.<SQ
MP-XHK&S?,\=2<S\RH_.*BK%16?'-.1"/HI,JL1D>*LJ>..KPBRLO$(407'^X
M7*EZ9[("CW"E*B2X(V+7.4J466645@DOXW__Q``?$0`"`@(#`0$!````````
M````$0$0(#`A,6%`49'_V@`(`0(!`3\0)5!-RDZ:(_IX'D>1XGM/6>(V<8("
M(E$'3#L3)*!17(RY%^J<D/0CG4`<4<63,ST*I83LXS<1H16+!C#"TAB&,=.B
MTATA"D0M!V'2@=,.F+-VP6*%F[6I'3'%,4YNV"I"I:QATA4QZRI2*:6LQ8H>
ML*<A:$J,=(**0JDM@L9:18*?D$!OYO_$`"H0`0`"`0,#`P0#`0$!``````$`
M$2$Q05%A<8&1H<$@L='P$##A\4!0_]H`"`$!``$_$/X22]OR9'UG1)N.C-XL
M=]"#XWV3PAJ]5'!@!D]9K9KM>?X**Z_PO%RT&I9&W\+EX3B+4WJ82XI5OOB5
M\DYW[$RJ,FYS+++!U$7[I6?,:(8"PM"_1^I"QW$G9"/1J5TUR0U"^KLKVX\1
MW-04R\WQ7$6%\F/1Q*9UM+^\^(1\1U6L?O:?\=^(FHKIC^(+1W^^(T:H[R!1
M@=_T3=Q_6T_1_B#?U^(4MJW][17\3\0?X3\0MOW\1I??!^(97[=NLX6A;2:K
MZGT;,+DM+K+`&[1"#!<.MT7]58J5@&?0G\5+W+-""BAF[\QB[16^:O+>$!!'
M)3HZ2C24ZE]93R^L2MCTE)LQ&+\W8!*2+=5M;SI;'L&J!&]6@>DILNV;MXBG
M6%FW.-7'%0+QJ$`OET@8SVD&Z=[EL`+[%!Q7>"2$*:;>'B!3='I,]?64NB'O
M!7:HE\*YX;BX#G?:`YBPL\C!M*TE`[Q8.@'=1?M]:-)L]D?B**+-0FO5ED/#
M:46=$L1LSDC!,;<!WW[0QCWVE(@PP&N^J-JW.\=5$%U4%O2,WEEK5X@C)7!:
MM--=HGF(3L*SB-A%7"&_E&`*M-:WK4'$B"&`.#M!?"*-1`YE(:4,NAO.<Q#C
ME&Q[](VPB[A:!T.-(F8@:3%8S7-3<`EPNZ`OX^NY^V]P#\RL)3VQ^I13+'24
M"64M9A.L++"?3<F[VA[T(@LO<=G:7(SJE$=0?&\IM56]<P9LJ6O7HMR2PM)Q
M25%74KJ)/F(-T#:X;UB]1Z+^-)DW7RML3#:8TJ4H-]S2,`;YTH!-*7%'V'5N
M%S#*&5\F[U@68OGB4+42M7%$5CY,%*QM[T'UY*I1VL1P`T^5FL-F%M<._09M
M8V%+!`YDL;:RO`M-^*C6"H%"H;98RG-BB4+K%+$@5;X0KF7<H=$I]HA*E%6Z
M:B8D[A)Z);[RY6ZED\LWZ2U+A;/8X]IN<:CP&98`"XG(UF(KYW`P9%71]ZGM
M#)]`0W[2I.*Z3\<=-)?-,:NZB"Z)A6CUE@C@F`'72%(U<]3!2V>QL^'UIMGF
M03V4WY5?P[^8H6+5<V<QD^1V;P0:PH3J+8ZS;N<%/3F5%XN&W2'A8<L(I7``
M+%+7M\1CK-B$-$M^D4*W4NNA+,CT*%UJ/9T.%NDU"TTK%1_BX7W8&U;OHKFQ
M$N@*;U8-P(TDG0B-V)JW",M-!/*;O2'5":C-'8#>.->CMY&H[YE'8A[S(+K>
M\6BU7K'Y^O"-O7#\0=`1+1/L2N3L;T(.<F9:LT%-;TC[;5%$F*(FR.L!CR]!
M7"X[W%MI;!=?PN5.QHN_W]H2%'L^]PDK_H!!\O$6M4.G:6;0\6%#?\`6L(/#
MB5Q9ANBM8M!5`\V?;[D1'1LQR<XJ>PJWP,1G[1:#E=CL11`L+2_?]VV'V]4:
MCJ//F9SUKN[;LC%!DO1-3GM%D<MW-HWZX:\8^;\1112\+B!F0+05*YPL8!0%
MF$30E1%D=3KU(U?HQ*,[RNV,D//HE]"3B:5T!-\E1SCN_"ONPFJ<!W#Y17:%
MX7B6:$!WV"<(-E!2\D$<J@EB[&FM#T@V4-'SY@,QBM[OW?+#`0JD!Q4,$V=9
M9.V$I&IT1#9;>G..8ZV0H:!Q&>9P39FA[5]97<'W@'&)>#OTX[0;.P]7"`&A
M:JX%_F'DKUR!W-I1G5/4=(#QQ1E1Z1RI=SK?327'SGS3[P05I<P[L4U)T)T9
M9`=**`R^O4#V/^RR(1:O(^R0M`;5I?,+V8W!-(I<JXZQ5CL!F7!"WN'#M%FL
MJV(R_P!D#/,=V7BLS;^K4"`%[>WUW/AH4V0C!U`UM3QQ$)<VL\=;0((.@/&\
M8D'-V'I6T8.!PWA.\',6MC'ZJHO2E8^-/#"QJS6S>*VJ)%8I'((\DQ0&DZ.Q
M-1J#THH#T)4V"^L&)HA7M^8@8=FUZ&T6!2+6]4'V=@&O>''II-3K+3T,''U@
MNX@.#?)-:7-RV>NO6-A_\P?S#!=6Q=/C?S+,-$_:=9=*1K9NZGVA9&=BGC];
M?,9*09H&J>&7U6OL]F-90K9K26:&@<-?^Q+JJ>T:D$.6FFYR2AX>@%LMS*!W
MP=(!59_,>JM"F^44+(M&<#]Z1.RQATZG?WC:%6PKC_GB8F4'+I&NO23CZ\QT
M@7:&T-939TCHRA-2X%JB[_$%**=S'O*X)-VPGDC*Y#=OD8F.B`->7Y1QN%#5
M;T/V0/H$J'U/>H8<"O*N4OS$VFL6)Q$(/-@'LLSS4N%:$I'8JZ1`'>]?%QZC
M*QAJ1V\!%!QFL4\QD<=4[?:,HT>,D`Z5Y*B5#_&,<0D<?T`8*MVHZ*,LVE'.
MB[H[5S`P?W+<H&I4/+--&7(FT:#K$44PJZ>IJ1#1.PJ+V-Y,GII%7EU]M?-S
MU>H^U0>J-5+_`'4'6?>EY"A\C"I)OD/0CG,]Z]M)5Q`%,&GQ+MYRL"]`A=AX
MT#?]J7FVUFEL-.WA$6?1[B&!#$N(./KS;V^P(M,!=!UB6SZLZNC?$'L/V:+.
M!VJ%$M-`:Z:L-$7*@&<W=-TUF%.#$;W"5&`P>XX>L.T&+,W9S>T<6;:_3U=#
MU@=DM1H>)TGW:_:%#1RCW86:LBO9-F6:G+Z0/CZ=5[NUNPY6\HVN\O>'3TE#
M>`B],QI2C99#4I&O6`5XJ.G278+L2&0>D=UFMU@L^2CCZSFX;^`9;C6)=!?:
M%.#[`N768.G1RDHI=3J0:DP(/))=@$!9X$PQH^9BMV5:=HU(*!0`;F8P@HTN
MT<,Y&&6T#1W*F(,8'4R=H;:>4#`3O;-:)L]K?$ZP@)ZG#&*<N\63+&K2ZB^;
MC16(Z6M`+[QJT%*4B@3S40.130BE8##Z0A9T#8-@DBF`%!P;!]H-<UND%B;R
M<?6+9V]V_P`QS+!BN8G)'#`'/6+8<R_#^#9*<]**S^/>,`LRX0XR5?$=@DJ6
MVPM!Z17@FD6;'2'D@.4-W2`*>BDO,;^8LK4(%NE>TT]2XN@HF-<2Q(X$RV7B
M:11S1Y>#K$E^LX*J7X]"/;"<N83[8M2ST&#L$VW$O@;O6:`H*$4#@.(.<2F)
M!2>8+,_0?F<?6;Z21QY7"2YS*L$TWA[,)=HEH>MH]:BM\NC%^J""X=WE\8A`
M"&RJ>D,*P+OO#OS10=TO):VOHEW[RAJS<'[RM3'(N]\1$+==1Y8@X66]GGX"
MCI!P;:=)0VO8U??F,U"MC*55<E3WE<Y+5?G;Q"CQA;`BO(-1Y0Y=)EUR]GXG
M'UAV/N5',%"TXF;="XDU310;9K4[5%P=Z%8Q-;:O2"@79"[-(J.]7HCC)F"G
MQS%4P4CDZ1MNRE`!\9B:U5R-DN]")P%Q3)'O-6DQ5:]HN8`LZ^=NT)FZMKAY
M7+#],UR51HNCPAQ;BA@F7\%RCK>A-A<T!V8;/XPL^9./KSZ21?NJ;!9J6,5Q
MI\9U[X^5E(LY3>S35Q&L@`!=BSV(/"!4MD`)#K!<72,,6E%(<P?AKMXZ&_:5
M!::XG1P^Z0`,K;IZ5<'>$(8<WB#VC--@=;KVG`<HIVYB]V">A"8!H#73_OB!
M(^8"<`M;\Q3(6)DS5&W/M"=!:J!38-,%\5,TYU9+0K>(]M`ZM?'\,)"GLR<?
M6+Z"_2%JL883:LRL2DTQ;G6,;QM37I,QO+^'<O1-F`ZF`=:-S6TO9,!=4%5<
M=X56->)"*.**72\Z326-$%C-1*/_`'?52K6H;J`%58,O!F576,SI`9&B`Y5G
MF#/B`,Y+A93:S**MUWSO-!.":G:K!&QAA:U8FY^^4>M:0@+D3JWO`R*WS_*7
M$2<?6;Z`O9^8H)"W648QK*`:96U8FQ;JUW&7AI=Q@/6@V!]R#ABZ_M4`1F&?
MESR'F,4!3:<NG7,REN2BE:.L$4642LMM`RR@>M*NM,XTBS05%1Z1)7RUKW='
M?O.@56%8JJJ6/IFO<9J9B<UW/:+G5GG2WXB2K*#/<6?2='I,N$H7TCA;D6^C
M<X^L7T6@]"'@:5>TP?5&L<`?>"&(8Z9V7B,.Z?SU$^7U1OR6282N"\QG=OO`
M1H#O[$&L^8-'K9%]@&E`2_9QH+/B$A5T6C['M%!:D#`;J"(]#I<LJ6[7C'VC
M0,U*J._$?UK1#?ECWGFE"^\7:5%0]G>6ZU3K7$./X2RC@^DX^L6/2^B/Q,:L
M5J<3:\LJ!18:46M<]8S47=.E5="NFS!K,EKD:&-',70UT>+FL&':`8JT$Z:[
M,0O'(,#\#"#`C=,Q,.;0J('!)[L+!)YC_GO`!H$5DS*HX"=KJ#>QU2I>MB!5
M-'+0I5RDLN2DU18,9PTU](IG`FIJM*M![1[B>D+Z,T8@O,U^6((4-V3Z"_$X
M^OJ,3&BZ0\0WFVA4'$K4N,K/3K+&ELX.A\OF+/N"[H,L-&CI&SJHR>EKWE=C
M>^YEL%N[XJ-ODXY>3UCK*VZW]@;PKYM&X6VI[7+]!"*E:Y=>\IK"J&MFM8*Z
M\I&KJ6[-(1:=OHH29%L'-$=0[\:U&M-S[0W_`-$#`S<U@](DDZ@`45GT.D0S
ME0.6]UQB816"]2KM*+C%X'S,"[)6'=!^D-OJ)X6_!<P:&2:.\LU]DJN2>PX9
MJ;<==!;('3*Z:V]^7:7B4K(+Y9K,HF%`7.7:.X%0JIT1*>K%HSLZLU$6/@HM
MK42%0#.Y`WB0,6\T]?OGO#J<+5U6[Y13I&L',&OI,;[RO(N,$W0#Q?#TJ,?4
M*`===8B2VCV?,L1T$)3H;PIT36RO+B9[PJJHZ@^P>^#[LV^JH]!H?6#4"1+<
M8,TD-M'O&QNAYTC=J-?5_P"D;+O@CU&:R>'Q`7.(,`*!P1`OZI@WL])HY&8J
M<-0XE-V%5^(C=!I30KI$!>`>!10T?G>%6]07;[):UZK=^*CYF[Y6V]HA[@?@
MC@/Z8KUQ[106PE64>FWB8Q<H%Q0_Z^4?F'UW;H4]2I;MVH^&HX!WBY+%8J=[
MXC[8JLA"UIIVCNK)<P%UAMT4.3LT@3MP:2TH*LD#S7R`D65-JY'H1`3)NC[K
ME'Z7%?)3*ZM*O7_LLM2@M2-92M?1@!$TR3BAKWC^G2CQQI>&]FIR(C)YZG\5
MC%1FI@L^5^$/Z-(;IWQD>T"]=(J7F;EG?1&Z>C`^7L#-!T(ZMJ"SFKERQ4=0
M*&QP.\0W=MKJ3I#+$M146I1JLLZK2]>#2&V"Z+D.<U`/+)&0ZT'/K+BX.Q>\
M25&F6$@OAGK[5-V-H8P-:HW;T2H;4$Y@:N!5"+.!D5Y=6"+RUX(JV..T5+I*
MP0VM$=@?NOZ;W06)[GYN4%<T]B4X(HZ!79>\$(!1&2K;G>9\ZK;NMWC>+;!#
M4*P81=[A.\OMZ+B9J*9T.Q,)JMM:UP][E)@=BKURT6FHVU!,"V\UYG!0HBX[
MZ1'HZP)ZYE(&3P@\1UZ</G2)7X4%CJ.MH6-4,)=JJQ`I-JWT]H#,%%2P&.,&
M4E>,PI*EUEH-VINJ;G>A[$V_HK8U%ZO\"(0;<Q#7,,BVJ[WS#UO'>@[P-I4Q
M_0E4;;1$Q7$=VY&U55@%68[##RE[F="!@#U0$8O?.B%Q9\RFQ=6@%T&DK4B#
MT!'':;`;["5"JR,^A_LO;G5KY[RRN1K&W'8C=SI<*=!/]C!__1M[RM`9BP]6
MT0'_`*2@X.D52I5M-9+6JZW1`*,C.&L_TNXV-_HW3TC<&:@MBX-6K*+NLP.[
M0=MO2<P/R7>B=`B[Y!X9A*5-+EP,;#"\KF*0*XH4[OS*,$ZL;]F7%_W=?L10
M6*HOU+8]&EJ*?9YN)F-HTYY7',Z%=HO5G0E,'H5$W:U5_NOF7-?=#!>("K)0
MI']BXE.O]('6@OJ:]S6"O7$!'\1J4@.&94N!19&@&;8EKAZ18LQ,6HUYAM9K
M57'U+BFJE:GPL+*ZGF8ZG;A`05>&<VDK%0["9YCV+[P,ES$A,QW,5&3<R_</
MZM=9LHY*H*%]7IUBFE8EL%=8246\2MIB+:-&)<0NZXBE4PAHP!.$WBU%ANX-
MO,5N`9R:PZ/;<Z@YJ$`6\L-8G4PRS24EXFL(@"INJ="7!*@*MU?U4@&K59H[
M#J45VB&[`M#:Z$=5B7(/>'PM?$*N#%93F+J2+.M(%WE5PRS1Q!A7>K+T(72_
M3#28:UCZ:76^L:Q&)0+4EC2C:("7M$I6HO6;[I$R5KESM*\_UE-%UN&`4L!R
M)^S*0ZHI.'^RD"%*25I4RZ/#*5P#S"^F`*%8'%><3Q>9L/O-'R[+S3VT@JEL
M+PNR#:C:[Q0ID0W@=HP522Y2Y86])9!6M./SUXZP\X!E`:!_:AR-57>)F)17
M!P#7Q47(6%R'H,W)KG>#4SQ!Z$U[E;)E;U>YB[1=Q#:\K`?BH];(?4$Q<?)0
M#"$Z2L*CH+JY>?%"KM#H=96?4%'^OU_OJC5C4B5D5V=2=&ROMM'WET_;9K`S
M>M35W4FU])(7YD?]%'6/G#MAYPF,YGW@=G]SK/V#YF-?LN(N3;U^6?$*T_10
MO%![2F-<:=/_`!:('O*1*YMQ5;2OXHE0IO"5_2!UE)2&@[^91_\`+__9````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+V%N9V5L=VEN:RYP;F<`````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`W-C`@,3`U,34T,S0Q-3`@,#(U,S`V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````%0@#````KD5$A0```,!03%1%````_____?\`^OKZ]?7UZ^OK
MZNKJX>'AU-34T-#0S,S,Q\?'PL+"P<'!OKZ^NKJZN+BXL+"PK*RLHZ.CFYN;
ME)24D)"0C8V-BXN+AX>'?W]_:VMK4%!0)"0D("`@&QL;%!04$Q,3"`@(____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````8>&W]0``
M`"1T4DY3______________________________________________\`6"P-
M#0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"9241!5!C3
M98]M$X(@$(1W2CKL),/>B-#3^/__,=`FQ]A//+.S>PMBE%4Q(LINE40D_-GI
M6?A%?JN%189L?EF"LZUU01;NO>$LX_OYOC]QK;6NN?&Y/YC1OZ8C`6Q"VN/X
M,KV?!P74[`1B69.JJDJ19BL8VIGW,[=#X:<\.E)*D47.I_XKSD34X9[[T_WF
M@:S;<O]_7[%_\[\/OO$:++GG?@X`````245.1*Y"8((`````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M
M;W1I8V]N<R]W:6YK=&]N9W5E;W5T+G!N9P``````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-S<P(#$P-3$U-#,T,34P(#`R-C(U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````#P````\(
M`P````P(97@```#`4$Q410```/___\X`4K4`2/T#9_P#9R$$$$@/*"X4(A`+
M#CPC,Q(-$0\,#Q46&3W,M3"@C@83$0L@'0H1$(_BU3_5NS[1MR:`<#JZI#FX
MHB9Y:Q]B5S>LES6DD$K:P"1J72Z`<2QU:5;=Q4[(L@<2$`@4$FO@S&O?RSZ!
M=B-%/W_ETC>OF#:LE0@8%0,(!PH4$ATE(QL;&____P``````````````````
M`````````````````````````````````````+<?XF`````R=%).4_______
M__________________________________________________________\`
M#5"8[P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"3241!
M5`C798_)$@(A#$13[BN.BD8%!491&!<R__]SLGBQ)J>\I+K3@38542#*'21R
M2DJI'!4F+3"5T)28]!,9YYQA$P?0.E'M+]?:`*!P+9#"5?5^W"T`0T5`$KFQ
MWGMK.$J"4'A;.'3V4<_6M\]BNGEE??1'?EX.AO-=]H_W&V2S7G]\*/=SON-D
M=/KEZ^3_^^\+0YH>*YO5=9@`````245.1*Y"8((``````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O9&5V
M:6PN<&YG````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,30Q,"`Q,#4Q-30S
M-#$U,"`P,C0T,C,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````5"`,```"N142%```!
M@%!,5$4```#____&("/%("*:&1N5&!J4&!IZ%!5P$A3#("*Y'R#V+C"-'1Z0
M'A_W/#U+'!WY:VUC$!(8!`/R(2'M("#E'Q_(&QO?'Q_,'!Q\$1'H(R'<'Q\.
M`@+/'Q_-'Q_('AX4`P/6(2'+'Q\T"`C3(B'"'Q_`'Q]H$A$?!06U'Q^N'AZ#
M'AYC'1U2&!CW5%0G&QL@&QO\_/S[^_OZ^OJ]O;VUM;6BHJ)U=74;&QL8&!@7
M%Q<0$!`/#P\)"0D("`@&!@8%!04"`@+___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````/YZQ0````0W123E/_____
M____________________________________________________________
M______________________\`06($[P````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#2241!5!C3;9#K4L(P$(7/(B(-MJE(`<&[\0+15JG*
MBB*E[_]0;+?(C#.<R8_]SIG-;H+RO["'DVV=U'QUMN7S>^7Q7P\2Y8L=WRI?
M>C!GS!A,E2?^.33&/`RF7OG5!TYT<^"Y8O:-NV[O-+E^:HB!T@:N#T3`T`6V
M!(=NU`%2H#-R(8/-(Z(TCN,TPHMA9.:;4"LO3"8YB.3,%C1;2L[AZI-^B?(%
M?1327]K6>OY5Y>_%D=7YS35R>OLI3G2^&(=+N6W5KO<3PU;['UO>_9>^3ZL-
M/'XSTZ94]N,`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O
M;G,O<F%S<&)E<G)Y+G!N9P``````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<W,R`Q
M,#4Q-30S-#$U,"`P,C4S-#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,
M"&5X````P%!,5$4```#____.`%*U`$C_`6<D`0]4!"8^!1]7""T;!`\6!0T"
M``$D!Q85!@X/`PJ6(&7C,9G?,):.'U_:,)+!*X'$+81I&$?&+H:!'E>B)FZ5
M(V4I"APC"1A\)EA^*%H5!P_K8+$5"1#JB,`@!Q:Z+(&W+'^N*WCH/:.()V'J
M2JB9,&[F7JY((#CO=KXF'"(+`P@9!Q(/!`L;&QO___\`````````````````
M``````````````````````````````"E#AS\````-'123E/_____________
M______________________________________________________\`2U<B
M90````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"4241!5`C7
M98_9%H(P#$3G*&ZXH57CAA:EM6BI&O[_W[2M+Q[RE)N<R4S0^&)VS*&#)VNT
MUL9R9,[584^[J\K9,^<EK<;SV9+*[P"-503<GZ<W2-D&;$@`\B$!08;!FK)*
MUG4MJXPTPT6^1':MO=<?ST6:3E]![^]GMTF2C!;A?O`7PTZWOX[^/A]M![W-
M+U\K_]]_'P37'\-],X+R`````$E%3D2N0F""``````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)L=7-H+G!N
M9P``````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-C4@,3`U,34T,S0Q-3`@
M,#(T-#4Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%
M````____^OH`[NX`UM8`R,@`Q,0`N+@`IZ<`GY\`FYL`F)@`BHH`?'P`/#P`
M$!``!`0`U=4-S,P,Q\<,__\?__\Y__]5"PL$$A('__@[V<X'X;88_],IYJ`?
MYY\C_9<S_Y4X\'(C_W$A_W0]]F(U_EPR_S\K_T,M_#4D_R09_S`I_P0$_QD8
M____````````````````````````````````````````````````````````
M````````````````\_A9C````"YT4DY3____________________________
M________________________________`(*/<U4````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````E$E$050(UV5/21+",`S3-&["DJ:&QH&R
M[WO__SUB>@)TLJRQ)*-3,-?,GPG*@G?.^<`]Y\J2PE:LG*N23%$4ALJ\0!<L
M`3%&@&SHP)X,("*`(<]@M]RN),V2[,YKQZC=Z75MTSS)XWES==8WEV.;4I+#
M?9]U]@LT,=_'*?0^^P\PR?X-1NJO^6,HAGW^;[^__E__O0%>K!((]42$"P``
M``!)14Y$KD)@@@``````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]E;6)A<G)A<W-E9"YP;F<`````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`Q,#,W(#$P-3$U-#,T,34P(#`R-38Q-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P````\(`P````P(97@```#`4$Q410```/____X8&?8>
M(_DL+^XM-.\U/>TX0=Q'6-1,7M)8;[Y(:;)+;+1FC:UDCH9BEH)@E@$!`@,#
M!65HJG5\PUEQPP$"!`(#!1,4%CQKOPP/%#!UVBMFNRYLQB%-C1U$?!Y&@!L^
M<B9)?%B#Q1P@)C%[XP(%"1Q$>"QINBQGMQQ"=2MBKCV&Z"=0B$J-ZE*$RF":
MZR`Q2':J[PP/$P8*#P`!`@$"`P<)"@`!`1T>'O\$!!L;&Q,3$Q`0$`L+"___
M_Q:O;8H```!`=%).4___________________________________________
M_________________________________________P#">[%$`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*Q)1$%4"-=MC\<2PC`,1'?H
MO1-"$34&@F/CA(Z`_/]?8<.)&732T\ZN)*2NF`/F3P='L9)2JIB__&A["R*:
M>N>G8QYL9B<AQ'J^N[+E.`0BK74$A'$*5@1H8XP&2#%8=AL]DR2)J9=:DA'(
M<J:XNCPO^]P]+P.K-PN5PRVYC:K9FM59#?L1K!_1V/EM/@G8?`AR^2DOM]3Q
MA=^A[=+MMX-P<GP=)Z'%?_?__/<&PP4F#7<L?1$`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]P=6YK;6]H87=K+G!N
M9P```````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#<W(#$P-3$U-#,T,34P(#`R-34R
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````#P```!4(`P```*Y%1(4```&`4$Q410```/__
M_X1$70@"!0,!`@4#!!$/$*\Y>!<%#PP#"!@%$.,QF88=6N(RF-HPDDT1-`D"
M!C4,),8NADX2-2\+("((%S(,(AD&$4P3-",)&%P<07PF6'8D5'4D4U\=0TL7
M-7<E570O5^M@L<Y4FW4P6%`A/.J(P"8(&M\PET$.++HL@;<L?YTF;:XK>$41
M,'`=3^@]HVT=38@G878B5'(A47TG6NI*J.=)IM5#F3D2*2D-'AP+%<10E$@@
M."\6)3\?,N]VONASN=UML-QMKT4B-R8<(A$$#`4"!`$``08%!@#3#@"H"P"H
M#`"F"P"E#`"@"P"="P";"P":"P"9"P"8"P"7"P"6"@"4"Q8P&!HB&D>#.#@Z
M+@(!`9%F9A@7%^?DY-+/SYZ>GAL;&Q45%1`0$`@("/___P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````.=SP<,```!G=%).4___________________
M____________________________________________________________
M_________________________________________________________P`4
M%KIX`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```.5)1$%4
M*%-5SE<WQ&`4A>$31@V#HQN]F_B4#U%#E)@XNHS>#_;__PDN(FO%OGG7<[<)
MZ>0N+:4YDVO)^U2N\I9+2>0FYW-))/GGJE1SOI"'Q_O,&LAMC;'/FEI+GCPU
M,'LE!0A?`V5^;77=(I='OD&HU':U+?J^OSS7$U=`NM)+V9I6E=3P#,5[!T>%
MN)F-4F1X=FMR?_IP:M-E$Y$:=C?&PS"<6.OH-$IJN;BTOC.V_5+O]%DE!!ZW
M])^\T3M][`8@Z%!WX>?3(8>.!Q4$Z/!\8QU1^\*H9O^M,<8&?_\!J$:J`(!?
MCVI4ZZ)DOT@`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]F<G5S=')A
M=&5D+G!N9P```````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-38Q(#$P-3$U-#,T,34P
M(#`R-34Q,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```!@4$Q4
M10```/____KZ`.[N`-;6`-+2`,C(`,3$`+BX`(J*`'Q\`&YN`&EI`#P\`"LK
M`!86`!`0``0$``,#`/__#[:V%O__'[JZ%___.?__50L+!!(2!____P``````
M`````````,3W5W`````<=%).4___________________________________
M_P`7LN+7`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```())
M1$%4"-=EC\L6PC`(1.<DV#QL-+12HOG__[0T=J&RXL*9&4"W8J[,1P>CDF*,
MJ?!@SH&L0F9CSA-YYYRG:1^@ET"`B``42@<G\H"J`IX2@R,YT?9L*HXBHPY^
M#:[GOC7=[I=];_I5=OVVS*8W?[>*/);KX7_FW^9/_N]]?_=__?<&"!T-%F0K
MCVD`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8V]N9G5S960N<&YG````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#4U-R`Q,#4Q-30S-#$U,"`P,C4Q-#$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````\````5"`,```"N142%````8%!,5$4```#___\$%`0'
M(0<QXS$PVC$NQB\LKBLQMC`"!P(F?"9+ZDI@ZV"(ZHD<)APNNBPNMRPPL2XO
MKBXGD28HB"<A2"!W[W8;&QO___\```````````````````````````#2AUON
M````&7123E/_______________________________\``30*MP````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"#241!5!C3;4\!#@(A#&L4
MA@)RJ$#W_Y=Z'#$7Q"Y9TG7K-JA"]4PXXDS0N0%+_XS_.IG(KZZLQ3E7*@>G
MS]*1/3NGW\0:8ZQL>P%:LP`A!$!R5;"(!6*,@)5"T(D)L;46@Q%'I,$?@Z=%
M[_.W.W8\C_GN?WGO_J_KX;_L_[UON7_Z[P.,R1.>+7A]5`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+VAI<'!I971O;F=U92YP;F<`````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$P,34@,3`U,34T,S0Q-3`@,#(V,#(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```/````#P@#````#`AE>````,!03%1%````____50P;)0,-S@!2M0!(_P)E
M_P-E`0$`#PL"/2D``P(`BUT!^*0"\Z$"[9X"U8\"THT"SXL"MWH"=DX!<4P!
MB%H">E(")QH!^K`?43D*_K,@XZ`=D&82AE\17D(,%Q$%'Q<'_;L\]LINB%@!
MQH("PGX"EF$".B8"%0X!_:L1'!,"%Q`#>%PH_L16=%DG]+Q3)AD#(!<(%PX#
M`@$`)A()%PH''`H'6AL4/Q`0`@("____````````````````(DI9Y````#QT
M4DY3________________________________________________________
M______________________\`NXCKIP````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```">241!5`C798_G#L(P#(0M=H$00R!ECT)#6&&5`L[[
MOQ=)"T*(^^7O;.G.8+V(`J)L`D]:"B&DIIPI5.BE0O),88R<,<8Q=@;8QJI3
MKPW'LZ2+ZXT%@J^2/@$)9-/+\7183!@*@L#Q(#)+$XT<!]E^%!F3L[N7R,_[
M>9I>=QPE@=4*V?96J=Y;J/0G_U$J%]IY?M:O^2SVWOW^^O_\]P)YV1]L9Y<6
M7P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1A>F5D+G!N9P``````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$P-#`@,3`U,34T,S0Q-3`@,#(T-#`V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````/````#P@#````#`AE>````,!03%1%````____QB`CPR`BN1\@
MKQT>8A(3FAT>10T.D!X?OBXO?1X?]SP]\3L\[CH[XS<X2QP=4B,D^6MMR%98
MF4)#%P0%\B$AFQ450@H)Z2`@KA@8DA049@X.2`H*Z",ASA\=:!`/3@L+1PH*
M3`L+3PT,QR`?PA\>MAT<C1<6@Q44@144TR(AP!\>L1T<I!H::Q$10`H*:A$1
M20X.@QX>2A(2CB,C&`8&!`$!31H:]U14P4)"1A@8\H!_)QL;&QL;_____WT-
M`0```$!T4DY3________________________________________________
M____________________________________`,)[L40````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````K4E$050(UV5/UQ+",`SSD3!20@D!
MPBA[0\HL*RUU__^O2"@O''JRK+,D0^:`F")^)G!,,$HI$YASC,CYJ(]G$J'C
M&!4V$*@`-@6[@$P0_0"/>_#01&2`3(_:]]C$]_9(,P2DH?*-E-+X2E.$M'CJ
M<"-?TO!>2%.K+X8UTVRT#!]LK8YLW2W?DF=2+\V7]M[Z[V:5:NUZF:Z<O\O?
MCY7J3PYYONNG';[]_OK__/<&3&8BVL"0?GH`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W-A9"YP;F<`````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`W-34@,3`U,34T,S0Q-3`@,#(T,3`R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%````____`P8+
M)V*V)EZN)5NJ,'7:%S=E#B$]+FS&"10E`@0')DE\B*_J'"`F)F"Q!Q(A,7OC
M`@4)+&FZ(4Z+($R'+&>W($N%!@X9(4V(*V*N+F:Q/8;H,&FV+F2N)E21)U"(
M2HWJ8)KK(#%(=JKO!`L4&QL;____````````````````````````````````
M````````````````````````````````````````````````````````````
M````_/4+00```"AT4DY3________________________________________
M____________`+ZJ+A@````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````DDE$050(UV6/R1+",`Q#-2P!0RF$0H"P94/]_S_$24\,.OG98\G&
M6$7V9*M0*0?O?<B<F-UM)2+K2\?*[$['I;5V,3MK`V-VU_TCQOB8;UP>P2`&
M2"D!1@)!+Q8HI0!6/-$KQU1V)47EOLV5R\1L^\\M5/>VK_[R>:O_ZR#57_,'
M,9IO9&CYVG!2Y:;[_N[_^>\+J>D6S.)U;V<`````245.1*Y"8((`````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V5M;W1I8V]N<R]F<F]W;BYP;F<`````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P-30P(#$P-3$U-#,T,34P(#`R-#0U-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````#P````\(`P````P(97@```!@4$Q410```/___P,&!QPC)3BBNRQH=H[2
MXSV[USNSS@D;'S22I6G+X36>L#6:K081$SB;K3:4I3>6IRU[B2UU@57)WR)`
M17[6YAL;&____P```````````````````````````(`V]G0````9=%).4___
M_____________________________P`!-`JW`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```'1)1$%4"-=ECTL2PR`,0S7!%`*A3<M'W/^D
MQ;!JT<K/'LLRNHHTY*R@5',((5<NIDVB2I;*M)=XYYR7:S30:Q*@E`)(JAW,
MXH$8(^`E$PSB2FRMQ>(D$&;Q8['9YKK_.C#TGOOJ__P,__N<_MO]_WQ;_I__
MO@<+#/'O6!7D`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O8V]O;&=R:6XN<&YG````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,S
M-2`Q,#4Q-30S-#$U,"`P,C4Q-#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,`
M```,"&5X```!@%!,5$4```#___\``0$!`P,"!04"!`0!`@(=8E<]S+4?9UPF
M9EP(%1./XM4_U;LZNJ0YMJ$XLYXWL)LRH(TRGXPPF8<WK)<UI)`N@'$G:5XL
M=6E6W<4UB7HA54P5-C!KX,QIW,@:-C$1(R`,&!8&#`LC13\2(R!_Y=(];F4W
MKY@QG(<*&A=]X<YCLJ,=)2,!`P(+#0L#`@$3$`X*!@41"PH@"PK_``#Z``#U
M```@```7```!```X`P(E!`0&`@(;&QL7%Q<3$Q/___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!KD]K[````
M0G123E/_____________________________________________________
M_________________________________P!$%A```````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```*A)1$%4"-=EC]D2@C`,13.*N+:BT%9P
MUXJXX%[<H_S_3]F*/CC>IYQ),CF!U`0Q1GQ78$@*SKF0F#'ZC)HP'PT_*C-:
M(H24:-1Z:A[E<V!5.W,;P)JD@,(M6F`/"K`J4X&`G)+N>+F8#MN$<H18<]`/
M:V$OT!R;_@:R7!S=1T$/YZ-*5'+:FOU4LOKZII2Z[APF]3WTH\9=3^^;D1;Z
M^+F>]_7[\__Y[P4-4"$G:"7_-P````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]E;6]T:6-O;G,O<'5N:RYP;F<`````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3`Q,2`Q,#4Q-30S-#$U,"`P,C0R-S(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@````\`
M```/"`,````,"&5X````P%!,5$4```#___\(`@4#`0(,`P@8!1#C,9G:,))-
M$324(F20(6'&+H:;)&F-(5\O"R`R#"(9!A%<'$%\)EA+%S7K8+%U,%A0(3SJ
MB,`F"!K?,)=!#BRZ+(&W+'^N*WAP'4_",XBZ,8*U,']M'4V()V%V(E1R(5'J
M2JC50YDY$BDI#1Y((#@_'S+O=K[H<[G=;;#<;:]%(C<F'"(%`@0!``$;&QL5
M%140$!#___\```````````````````````````````"0FW2_````.'123E/_
M____________________________________________________________
M____________`#M<$<H````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````GDE$050(UV6/R0[",`Q$+984,&L):V*@!`*$LK0U]/__C*2(`^J<
M_#32>`;*(.:,N;H@D#-$9!Q_F6.-03KFP*^)PD@($:&:OCWGC6%G8ZW=KT=%
M7@(?QO!3Z\C`A$LHKO=GLV@C,62$J\OLMGC,SP(I"[XXR31-I17!9X.06"FE
MW0$:AM+I/FQ]?@(][?P_CM6@2N\J7ZC>K];_;]\'L@D=0LQJ)/H`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O9W)I;BYP;F<`````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#<T-2`Q,#4Q-30S-#$U,"`P,C0R-S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````/"`,````,"&5X````P%!,5$4```#___\K`0(8`0,E`PP'`0,6
M`PP$``("``$;!!&B,-J/++^,*[N4+L:1+<)_)ZEZ)J-_**K*B.JG,>.(++J'
M++>!*ZYF)XA?)GRT2NJ\8.LZ($C%=N\B'";_```8```2```(```!```;&QO_
M__\`````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!-_HH4````
M)7123E/_______________________________________________\`/\]"
M3P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"-241!5`C7
M98_)#L(P#$1'K"7%4$BS)V5Q_O\;B1MQ0,S)SR/;8U01<V%>*P@E9ZUUB3NS
M-R0RGH79SZ2TUHKFUD!-AH`0`D`F5;`C!<08`46.P99TB#GG&#191NE\[US$
M/Z+K/3:_S>^>+\''2>;;_LNP799E,XRR7^Z?]\T^W/K]-=]UFK[Y_O+__/<!
ML\(4C<MNX>L`````245.1*Y"8((`````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+VUA9"YP;F<`````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P
M,C<@,3`U,34T,S0Q-3`@,#(T,#8U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#
M````#`AE>````&!03%1%`@("_O[^HP<$_D@^WPD"L!H5VBHCO@@#[Q,'I@\-
M[2@?RB`9[AX6_#DO_FMGL`<#3@8"5C8N_EI1&AH:VAL3_GYZPA,-_BP@_`X%
MT@\'LQ(-RR<BNQ\:_AT1S0D$````R=,R5@```"!T4DY3________________
M_________________________P!<7!OM`````6)+1T0?!0T0O0````EP2%ES
M````2````$@`1LEK/@```)5)1$%4"-<UCXL2A"`(11FS-(WPT:96MO__ETNZ
M7889#LS`!;XLZ&KED_,\'BSH#&*\['G:G1YHZ/V"VGMN<,S79)*O/NO"Q&,[
M(:!/D#;%6\5A38UA#;$N-[2YP6']K)ATY],@#B&D^O*4HW,N2DEL"N@J,=>:
M9530[ZNR+5K+N]WG!AU[*;?J_IYW!!$)^/M_'VS5#W"F#=3A8<F6````@W1%
M6'1C;VUM96YT`%1H:7,@86YI;6%T960@1TE&(&9I;&4@=V%S(&-O;G-T<G5C
M=&5D('5S:6YG(%5L96%D($=)1B!!;FEM871O<BP@=FES:70@=7,@870@:'1T
M<#HO+W=W=RYU;&5A9"YC;VT@=&\@9FEN9"!O=70@;6]R92X!55-34$--5#T`
M.A@`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O96UO=&EC;VYS+V1E=FEL=&]N9W5E+G!N9P``````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$P-C`@,3`U,34T,S0Q-3`@,#(U-C0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````/
M````%0@#````KD5$A0```,!03%1%````____QB`CQ2`BPR`BN1\@]BXPD!X?
M]SP]2QP=^6MM%@4&)08+%P4('`,(%P0(6049/P0450,=)`$-S@!2M0!(_P%E
M_P%F&`0#\B$A[2`@Y1\?R!L;WQ\?S!P<?!$1Z",AW!\?#@("SQ\?S1\?R!X>
M<!(1%`,#UB$ARQ\?B185-`@(TR(AT2(APA\?P!\?'P4%M1\?KAX>&P4%)0<'
M@QX>8QT=]U14%@@(\H!_)QL;(!L;&QL;____````````#*Q`YP```#YT4DY3
M____________________________________________________________
M_____________________P"Z^W$V`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```+])1$%4&--MT-ERPC`,!=`[U,Y:H*QM2(&4?1%=*"8T
M5?[_MXAER@Q#]:0CCRS9*&\#_SB]Y*GS?'SQY%W\]M>#5#R]>BV>&3`7S!CN
MQ5_FZ&NM/X9[(_XUBJI8/1BV9E/;O@R2=/E9JPHH0T6O0`",2(4EV*?,`W+`
MR\AGL*8DR*,HRH.$-*-P_G$N[LYM_R$^U9OQM_3;^Q/O\;G?&,C]=CYE3]U>
M>^?F5P5%FU9GH=Q^52&T^_LA7_]+WB?9&84`,MH_%4]Z`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O96UO=&EC;VYS+W!U;FMT;VYG=64N<&YG````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$S-#,@,3`U,34T,S0Q-3`@,#(U-3(T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````/````#P@#````#`AE>````8!03%1%````____S@!2M0!(_P%G)`$/
M5`0F/@4?5P@M&P0/%@4-"`(%`P$")`<6%08.#`,(&`40XS&9WS"6VC"231$T
MQ"V$:1A'QBZ&@1Y7+PL@,@PB&081(PD87!Q!?"982Q<U%0</ZV"Q=3!84"$\
M%0D0ZHC`)@@:WS"700XLNBR!MRQ_KBMX<!U/Z#VC;1U-B"=A=B)4<B%1ZDJH
MU4.9.1(I*0T>2"`X/Q\R[W:^Z'.YW6VPW&VO12(W)APB&0<2!0($`0`!&QL;
M%145$!`0____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````AL1V1@```$5T4DY3____________________________________
M______________________________________________________\`LNZQ
M.`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"K241!5`C7
M98_)%L%`$$7K$%.,K5'&$'/2"$'$$$F1__\FW<3"\59USUN\6Q"K$`5$[PL4
M>8X0PO'HPV38J&(;I/@QL)`SQCA:PZ?DL-AIK%S7W2R[41@#;7OP375'0`+G
M$)TNMU)40T$0"%P<Q^?9=7)@*`+5L[WI^[[I,M63@[P_FNIZY<[1(8@]&]FZ
MK&F%.MJ>W"-#[N=3Z6S3DD*)7SN7:25^?_X__[T`1/PFK[I<]78`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V-O;VQT;VYG=64N<&YG````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$S-#`@,3`U,34T,S0Q-3`@,#(U-3`P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````/````#P@#````#`AE>````8!03%1%````____S@!2M0!(
M_0-G_`-G(0002`\H+A0B$`L./",S$@T1#PP/%189``$!`0,#`@4%`@0$`0("
M'6)7/<RU'V=<"R`=)F9<"!43"A$0C^+5/]6[/M&W.KJD.;BB,I^,)GEK'V)7
M-ZR7-:202MK`+H!Q)VE>+'5I5MW%-8EZ(55,%38P"!02:^#,:=S(&C8Q$2,@
M#!@6!@P+(T4_$B,@?^72/6YE-Z^8,9R'"!@5"AH7"A02?>'.8[*C'24C`0,"
M&QL;%Q<7$Q,3____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P=%*Z0```$1T4DY3____________________________
M____________________________________________________________
M_P!QTH\2`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*E)
M1$%4"-=EC]<2@D`,13/V+N):UUA85[!@0\2*4?[_G]P%7ASO4\XDF9Q`I$,4
M$L45:/*D$$)ZE##9%NI8-FE^]R[(..<,@\5'\:'9`*._NID`QBD"DI.V`>:N
M!:\.2@(2R-?'Y^.\7W(4!*%B9^L/?==1',9]Q_7]A-6\1-;=W&OEP97I_<BS
MD,_KN7QUA):G[I$=(*MDLL5QH(12OVFI,$O]_OQ__OL"/9LFS1:RQE(`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V)I9V=R:6XN<&YG````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,34@,3`U,34T,S0Q-3`@,#(T-S0R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%````____
M`0,$`00%'",E.**['%!=+&AV`@<(*X69)WF+/;O7)G6'(VQ\.[/.-)*E!`D*
M'T)*:<OA*7N))G!]-9JM*'6#(6!L'UME&T]8*7:$'UED2,7<+7R*+W^.+76!
M5<G?(D!%+'-^``$!`00$`0("_/S\^_O[^OKZO;V]M;6UHJ*B=75U&QL;&!@8
M%Q<7$!`0#P\/"0D)"`@(!@8&!04%`@("____````````````````````````
M````````EF*QX0```#AT4DY3____________________________________
M_____________________________________P`[7!'*`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```*))1$%4"-=5C\D6@C`,11,%<:2*
MUA$M110<(HJ4_O^?V9;#PK?*S?@"VHK((W(16)*",28DM4P!]ZUX0)8I6/7Z
ML\DHR[8F`5KRX?AX2>:GZ9E+#23\,$ZB*$KBT!<$Q`;0:<$(//9&!,2\Q$(Q
MS]3!<5%B7IDZB?J!7\=W9>:U7#?/E^V_J8UT]Y<-%'C]J)V[;Q+[RBRO#ZV_
MSG_:^?_[[P<^J!L-X?DU,0````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+VAU<G0N<&YG
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-C(@,3`U,34T,S0Q-3`@
M,#(T,S$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%
M````____!@('#P04'0@GDRO'?B6JHC#:@R>PE"[&.1),$@88`P$$?C2C(`DL
M<2&:&`<AIS'C=R.B%@<>B"RZA"NUARRW@2NNA"ZQ%P@?B#"V@BZN;":1/A93
M9B>(7R9\M$KJE3W"DCR^C3JXLTKIO&#K*Q8V(Q(L.B!(Q7;O"`4*(APF#@H1
M&QL;____````````````````````````````````````````````````````
M````````````````#OKN/P```"]T4DY3____________________________
M_________________________________P!:I3CW`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```)!)1$%4"-=EC\D2`B$,1%-N&'=T!%=@
M5!3$\/^?)V'*@]JGO*0ZG4!F$26B6@%3,%IK$ZACL@I9RA(SV68R'@P7H\VV
M-"`'A<OIU5UF:U0A`QD4^_;A[_.S0$-`&N7-QV?T3J(F2(6=CZ^.4YT7CI\Y
M^P\]*-I5/^_OGYQSQU7=S_DHI)0"FYK_>]_?_5__O0&?0QK-0$^;C0````!)
M14Y$KD)@@@``````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A;F=E;"YP;F<`````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P-3<V(#$P-3$U-#,T,34P(#`R-#0R,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P```!4(`P```*Y%1(4```!@4$Q410```/____W_`/KZ
M^O7U]>OKZ^'AX=34U-#0T,?'Q\+"PL'!P;JZNKBXN+"PL*RLK)N;FY24E)"0
MD(V-C8N+BW]_?U!04"0D)"`@(!L;&____P```````````````````(8M.PP`
M```;=%).4___________________________________`"<T"S4````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````D$E$0508TV6/;1.#(`R#
M<YL4*@[W`FCY_S]TK7KS'/G$<[FD`:W)J=;0Y'9*&A1_MCX[O\M?M;/(:N;!
M4G.:4JZR\U(BFV)9MOMEY."]#SP6ZZ^1`2(".%;=DSD`SCD@<!9(8D]N&`9'
MGI-@G3:^;SRMG:]YS*1Y2K"\]C_QT/X9;^NW^Q^87OO]_WW=_LO_OI:`%`7M
M_,<[`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O8V]O;"YP;F<`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3`P,B`Q,#4Q-30S-#$U,"`P,C0R-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``\````/"`,````,"&5X````P%!,5$4```#___\``0$!`P,"!04"!`0!`@(=
M8E<]S+4?9UPF9EP(%1./XM4_U;LZNJ0MD8`KBWHJAW<IA'0RGXPWK)<UI)`[
MKIH^MJ`ZJI8N@'$G:5XL=6E6W<4UB7HA54P5-C!KX,QIW,@:-C$1(R`,&!8&
M#`LC13\2(R!_Y=(];F4WKY@QG(<*&A=]X<YCLJ,=)2,!`P(;&QL7%Q<3$Q/_
M__\```````````````````````````````````````````#2%75_````-712
M3E/_________________________________________________________
M____________`'RUT`H````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````FDE$050(UV6/V1+"(`Q%[VBM=0$WT&*CXH98EQKM_W^;T#XYWJ><
M23(Y01W#7#$W%2(YH[4VCEOF0LD857#D]_`F,R%$)LOU)_"IVT$RVMY3(+G4
M8+/H)T@//;P&TC!82[$[/Q_7XT9(S:@"T]Z/O:7`5=,GZWW+8=Y(Y&2MI27B
M?NW4!"LBRC%3+MSCHIPC9EH&H7^_/_^?_[[C'QNE57:04`````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O;7)T+G!N9P``````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,34Q,2`Q,#4Q-30S-#$U,"`P,C0Q,C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@````\````5"`,```"N142%```!@%!,5$4```#______``!`0#_Y`#]
MXP#\X0#YW@#SV`#8O@#6O`#3N0#&K@#%K0"_J0"RG`"KF`"GD0"?BP"4@0")
M=P!O80!I7`!B50!$.P`(!P!N7P!H6@!930!`-P`\-``T+0`4$0`8%``;%@`:
M%0`;%0`8$P`C&P`/#0A"+@$/"P(E&0"O=`'XI`+MG@+@E`+5CP*Z?0*W>@*W
M>P*V>@*U>0*N=`)J1@&F;P*(6@)Z4@)Y40)</@*Q>`6S>@?^LR#]NSP%!`(&
M!0..7`&)6@&%5P'GF`+&@@+"?@*J;@*"5@(Z)@(O'P+]JQ%8.@;8EAH=%089
M$PC^Q%8-"`!^3@&35P&"3P%>.@4+"`1C.PD"`0!/)P4V&`"8*P`,`P`6%A8(
M"`@"`@+___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"\8KDI````8G123E/_________________________________
M____________________________________________________________
M____________________________________`!!6DJH````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````]$E$0508TT60YU+$,`R$=T(O1S5P
M5`.A!1+,41-*3#V#.4KH)8#\_B^!X\S-[0^MOAEI=B08)_CPR\95OV"_Q0M8
MG@>:3'IM<>GSYO:T9#JZWEZ9W-TZ/Z2"*;E<_WG9O`(N$C*`5L\;=U_W'V_[
MWZ\`"(@`*:5S*C@$LBQS3@AJ"%.9G64R#5$+0([?VQX=V_E81(W4[J>-2,0$
MHY6PBU:A4-KEU\5OGN>KHE[D\UY*U,G#T]^Q2JB;@X_VD8YW#O9B39V#'&9B
M8'B&*"#BO'^VN*=:Z1GG5AV5J?+>N2'&/,9&JLU_L#'/ZV+3K?\8UL[+YA_*
MF4?\__'RV`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O<VUI;&4N<&YG````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#4U,R`Q,#4Q-30S-#$U,"`P,C0T-#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````\````/"`,````,"&5X````8%!,5$4```#____Z^@#N
M[@#6U@#(R`#$Q`"XN`"GIP"?GP";FP"8F`"*B@!\?``\/``0$``$!`#5U0W,
MS`S'QPS__Q___SG__U4+"P02$@?___\```````````````````````"RWG:)
M````&G123E/_________________________________`!0B`-H````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````?DE$050(UV6/VQ("(0Q#
M,]`%+URB6U#^_T>E,OO@FJ>>=I*V&":RDM\*1B7%&%/A8N8@II!IS+R)=\YY
MV68#HP0!5!604`:8Q`.M-<!+(AC%:>NOWM1)).KB]^)ZS/LQGW[L.OWZA/EG
M_@6/F;_C9OFV_P[3=>T_W_=W_\]_'["8#$?I##FA`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+W-H;W5T+G!N9P``````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`W-S<@,3`U,34T,S0Q-3`@,#(T-3`Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```/````#P@#````#`AE>````,!03%1%````_____W(*Z&<+RE@+N%`*UET,
MKDT*RUH,ITH*_W44/QT%)A$#GDH0CT82%@L#UVD?TV<?&@T$_X<T^H0S\8`Q
MVW0M_Y9,_ZUR*!\9VET,4"T6_Z)E%08!%P<"#@,`&@8!&P@$#P,!"`(!"`$`
M*`(`*`,!_P``^@``]0``.@$`(```%P``.@(!&QL;____````````````````
M````````````````````````````````````````````````Q;C:Z0```#!T
M4DY3________________________________________________________
M______\`8J70>`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``"<241!5`C758_I$H(P#(1W&JVE6CP0$8KW4;S"^[^=39EQQOS*EYU--NBE
MF&OFU$'(.V.,\SPPYYJD=,["G#>DK+6*FCA`[S5-5^NBG,](^Q[L2"V!"E@H
M<@PV9`N@!0I+AE$+5^VVK83KI)<7`*=-TL6_OX<0/N?DE_WO1^A"]TK[Y?[N
M%O7G8;@?!Z-K]!_'0[Z4?Y)EO_Q__WT!0"H6\^LDR8H`````245.1*Y"8((`
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I
M8V]N<R]A;FYO>65D+G!N9P``````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#(S
M(#$P-3$U-#,T,34P(#`R-#<U-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P``
M``P(97@```!@4$Q410,#`VJ2OC)"5AXH-++*XDAD@"DY28:JTE)24A`0$.;N
M]E)RDCHZ.G>?SLK:ZBXZ2IBXVO[^_DI*2D)9=5Q\HSI.9B8R0J*^WG*:R@H*
M"A86%M+B[D9>?D(^0KK.Y@```#!$DQ`````@=%).4___________________
M______________________\`7%P;[0````%B2T=$'P4-$+T````)<$A9<P``
M`$@```!(`$;):SX```"1241!5!@9-8X+#@(A#$0+\A&1E4A9%W'A_K=TBK%)
M&]Z4S)2F%$G]7D+-.;=?EH)NNI92JH8BW*J-S!P_U4$`6U8I)<6V[F#@X7/.
M_F"KX4%1B;F1@0]$G(BVOA$E+FYQ'OW61P8_B`+88&^$L9]!^9<9YGI_QRIY
M`?[G\US^PA#^^6W=.T.0^VP#+H:"'*$YOUIJ#??$(HK.````@W1%6'1C;VUM
M96YT`%1H:7,@86YI;6%T960@1TE&(&9I;&4@=V%S(&-O;G-T<G5C=&5D('5S
M:6YG(%5L96%D($=)1B!!;FEM871O<BP@=FES:70@=7,@870@:'1T<#HO+W=W
M=RYU;&5A9"YC;VT@=&\@9FEN9"!O=70@;6]R92X!55-34$--5#T`.A@`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V5M;W1I8V]N<R]W:6YK=&]N9W5E+G!N9P``````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P-S<P(#$P-3$U-#,T,34P(#`R-34R,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````#P``
M``\(`P````P(97@```#`4$Q410```/___T\0'B,$#LX`4K4`2/X#9OX$9@8(
M`V2(':?C,:3?,*#:,'VK)I#$+4UI&)+&+E^!'AHC"5]\)A`5![SK8&R'-[OJ
M8,CJB(VZ+(JV*XJW+(.N*P\4!;'H/59Q'A,9!VF()[7J2J340Q$5"3M((,CO
M=@\3!B,F'!$2!QX7#10-"1@."10,"4TE'#@6%1L;&____P``````````````
M`````````````````````````````````````````#E%(CP````R=%).4___
M____________________________________________________________
M__\`#5"8[P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"3
M241!5`C798_)$@(A#$13[B)J%%%'&!U01MS#__^<+%ZLR2DOJ>YT(*0B\D2Y
M@T3.:*V-H\(D%*92@A*3."!GC'&LX@""4_7T=#U;`%0N`!F<UY/M3@)P-`2D
MD5G9MJVT##6!+[PO[#O[J.?KS>7QNC59'_V1'>^C\7.6_>/]"OE[,.PMROV<
M;_7I+W_Y.OG__OL")?\<.0S'A/L`````245.1*Y"8((``````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O
M86YG<GDN<&YG````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,U-B`Q,#4Q
M-30S-#$U,"`P,C0T-3$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@````\````/"`,````,"&5X
M```!@%!,5$4```#____&("/#("*Y'R!""PRW(B20'A^-'A^B)RB%("'\1$5+
M'!WY:VT"``#_!`3_&!@0`@*?%A:7%Q7H(R'.'QTB!07[)R>M'!O3(B&?&AF$
M%14L!P?_*BHC!@;6)B7\,#`0`P/O+R^R)23]-S??,3'E-#.#'AZ-(2&"'AYU
M&QOE-S;V/#SY/S\,`P/Z0$#R4E+W5%0L#P_W5547"`B$,##R@']D0$`G&QMX
M6%CT]/3FYN;EY>7:VMH@("`?'Q\;&QL6%A85%141$1$*"@H("`@#`P,!`0'_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````#30HAX````27123E/_
M____________________________________________________________
M__________________________________\`#`B?50````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"R241!5!@9!<$%0L0P`$7!WTT@2(HN
M$MR#0]%BR\??_4_$C`"P>QL``<XIQIBR`8%KV%@KJ\NA&H3KH"S-+,POED$U
M(H<B35Y.[:J$C)S*4.JN.VE8DN5X>'71M6W;31\<1:N/YW,[M^U#VVW.KL1>
MCF?W3S>2[AZ/]Z+EM/W^K$;-Y\NH)(L</EZ_&C6?;Z.0$:YC/[^2_KZWJA&X
MCI^LE[(_<6H0X)QBC"D;$`!V;P/P#_4V(P&3>GD4`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T
M:6-O;G,O=VEN:RYP;F<`````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<S
M-B`Q,#4Q-30S-#$U,"`P,C0S,#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@````\````/"`,`
M```,"&5X````P%!,5$4```#___\.$0H&"`-DB!VGXS&@VC!]JR9ME")JD"&2
MQBYRFR1HC2%??":\ZV!LAS>[ZF"-NBR*MBN*MRR#KBL/%`64PC..NC&*M3!6
M<1YIB">UZDJDU$,[2"#([W8/$P8C)AP)"@4;&QO___\`````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"567-"````)'123E/_________
M_____________________________________P!8+`T-`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```(=)1$%4"-=EC\$2PB`,1'=44*.@
M%:J52,7P__\HD>E!W5->,IM-4%4B1>1302FG&&/*TEE<(%5PHBSN0M888VEH
M#=0<QLW]^6"`0JZ01-MQ?3I[P%(22"3#?G[-G@U%0>F\ZER6^;S,FQ\3>^_Y
M!O6W_0=<F7G"7O>W_.$(U:[G_][W=__7?V]*KA/0!""J,`````!)14Y$KD)@
M@@````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W9A;7!I
M<F4N<&YG````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-3$@,3`U,34T,S0Q
M-3`@,#(T-S<R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!0
M3%1%````____"`P1/7>W.G&M.6^J.&VG-FFB+%6$+%6#&C-..G&L.6^I+EB(
M*4]Z#ALI2(+"-UV)4(C%%"(Q#!0=0&B33'>F3GFI:)C-9I7)8I#"78FX+D-;
M&B8S>*/2C+'9EK?<P]7I$2$R"0\4`P,#`@("____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````UE<]VP```"=T4DY3________________________
M__________________________\`@U:7V0````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"/241!5`C798_)$@(A#$0;,XB@3A`WW,!!Y?\_
M42+EP;)/>4DEW4$5,1?F3P4A9XTQUG%G'C6)],C"/`[D0PB>AM9`=9JVCU,\
MSW:D705;\@<@`4=/EL&&0@0R$`,91A%.^9Z3<.GSE'-GEGU\)?OM_OJI;I>K
M>BWD?O-?;E0;JGWW;XWYU.)-JY[O+__/?V]S[`_V20QX2`````!)14Y$KD)@
M@@``````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H86YG;W9E<BYP;F<`````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P-S4P(#$P-3$U-#,T,34P(#`R-3$S-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````#P````\(`P````P(97@```#`4$Q410```/___\Y<
M"/]R"L=9"%DH!.AG"]9=#,M:#"P4`[94#O]U%.!G$JU/#C$6!)Y*$!$(`H]&
M$ELM#?]])2(1!1H-!`8#`<]N*K)>)/^'-/Z&---P*\AJ*3`<#O^63#LC$O^M
M<B@?&=I=#-1:#",/`E`M%O^B900"`1L;&____P``````````````````````
M````````````````````````````````````````````````````````````
M`````/?EIX8````J=%).4_______________________________________
M________________`#*H\%P````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````BTE$050(UV6/V1;",`A$.49)%#7&NN$2VVHB^?\?M*0O+O/$
MA3,,0%&)="*U`J7DG7,^R<@2+*IL$&4)_6PR7ZZGS\?0@)(LKO97/KX6:%,!
M\6AVEUN\G[8&O8`XI'/,.4<F=`+=P!QS.W)7Y_PQ5_\&5(?JU_W4,'-#=;_F
MHR$B@WW-_[WO[_ZO_]Y=817;]P2X/`````!)14Y$KD)@@@``````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]E;6]T:6-O;G,O8FEG9G)O=VXN<&YG````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#<W-2`Q,#4Q-30S-#$U,"`P,C4Q-3(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@````\````/"`,````,"&5X````P%!,5$4```#___^$.P7_<@I9*`07#PET
M,P7H9POB9`O>8PMH+@6Z40K670S(5PO+6@S?9A'_=13&6Q"Y50^>2A")0Q&/
M1A*,11)=+@W_?24N&`G?=BW4<"O_AS0L%PEF/!Y'*A4Z(A'_EDQD.Q[&?DXH
M'QG:70QL+@9F*P9"(`I0+18=$@O_HF7NEUZC:$$&!`,;&QO___\`````````
M``````````````````````````````````````````````````"_16_,````
M,7123E/_____________________________________________________
M__________\`'YI.(0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"9241!5`C7;8];$P$Q#(4S6S8N5:666G$INZA%^O]_G88GPWG*=\Z<
M20))Q-PPOR<0BLX8XR)_F"N-(EVQ,%=M"6`!RC8;D*+&#)0MU#$!.U2>0@CD
M%3H&-F@I=%T7R*)A:#+7A]NSOZ\S-Y)/U\?'_;3;3B7/_>*ZD?ZJD'Z*D]'<
M$Y&?]<91]B\O0V6M58/S@O_<]W/_UW\OWCD9D]IX^"(`````245.1*Y"8((`
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO
M=&EC;VYS+W=I;FMG<FEN+G!N9P``````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W
M-S4@,3`U,34T,S0Q-3`@,#(U,38U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````/````#P@#
M````#`AE>````,!03%1%````____!@@#9(@=I^,QH-HP?:LFC;\LBKLKDL8N
MC\(M?:DG>*,F?:HH7WPFO.M@;(<WN^I@R.J(C;HLBK8KBK<L@ZXK#Q0%5G$>
M:8@GM>I*I-1#.T@@R.]V#Q,&(R8<$0T#&A$$!`(`%@P##`8!!P,!)0P#)P4!
M.0,!_P``^@``]0``(```%P```0``&QL;____````````````````````````
M````````````````````````````````````3,3"6````#%T4DY3________
M________________________________________________________`!^:
M3B$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````F4E$050(
MUV6/V1*",`Q%,]J*40056VPM%G>+2_C_K[.AXX/C?<K)>@,]B\@3#1$P.:.U
M-HX24Z&0I0IBIF*#4@@AL8H)Z)VJQ]O]S@*@<CV0P4D]6JY*`(F&@#0*6S9-
M4UJ!FL`G7B?V7#]"TCN+]3A_?3U"%[KG@>?C_EE["R'<SQGOC_>KZ25VGQ;I
M_N!OGN=??W_^?_[[`'@Y&0Y[\+%V`````$E%3D2N0F""````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]H:7!P
M:65G<FEN+G!N9P``````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$V(#$P-3$U-#,T
M,34P(#`R-30V,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(97@```#`
M4$Q410```/___P$!``\+`CTI``,"`/BD`NV>`M6/`M&,`L^+`LV*`LF'`K=Z
M`K=[`K9Z`J]V`G9.`8A:`GI2`B<:`?JP'U$Y"OZS(..@'9!F$H9?$5Y"#!\7
M!_V[//;*;HA8`<:"`L)^`I9A`CHF`A4.`7A<*/[$5G19)_2\4R`7"`(!`!8*
M`"`,`!H)``\%``@"`"D)``4!`"@#`#H"`/\``/H``/4``"```!<```$```("
M`O___P```````````````+D!T?@````\=%).4_______________________
M________________________________________________________`+N(
MZZ<````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````GTE$050(
MUV6/ZQ+!,!"%=Y1TJ;BD[I1&*.I.ZK)Y__>2M(PQSJ_]]IR9/0O&B<@CRB=P
MI`3G7"@JF$*)3C(DQQ3&Z#/&?(SM`DQE5BN7>H-QVL;YP@#!5VF'@#BRT6:U
M7DZ&##F!9[D;)=,DZEOVG']^QY^!]4G@Z7'3F<[N.Q0$1LGJ]J*UOAX"J8K[
M]:--[QO%_;Q?L]7Z]/OK__/?"SY]'4##'%AD`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N
M<R]T;VYG=65O=70N<&YG````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S0S(#$P
M-3$U-#,T,34P(#`R-3,V,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````#P````\(`P````P(
M97@```#`4$Q410```/___T<0'B$$#LX`4K4`2/T#9OP$9C'C,3#?,##:,2W$
M+AAI&2[&+QZ!'RRN*PDC"0<9!R9\)DOJ2@<5!V#K8`D5"8CJB1PF'"ZZ+"ZW
M+#_H/2B()R%(('?O=@D2!Q07#0\-"1$."0\,"3DE'"T6%1L;&____P``````
M````````````````````````````````````````````````````````````
M`````````````````````````````#7SP*`````H=%).4_______________
M_____________________________________P"^JBX8`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```(A)1$%4"-=EC\D2`B$,1+M<(QI1
M$&40<-S"__^A`EZLR2DOJ>YT4&J)>)'6H5**6NN8I+.8P+6"D<IB!E9$I'CX
M#E!28,!:"W!(!1)9`<XY0'$4B&:R+N?L++$6^,Z7SGZRK_K#Z7Q_WHY-7_WI
M.J[6CTWS[_=?B^5LV^^W?/OW?/?+-\G_]]\'(Z(5YF>4?QT`````245.1*Y"
M8((``````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O8VQO=VXN<&YG
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,34Q-R`Q,#4Q-30S-#$U,"`P
M,C0T-3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@````\````5"`,```"N142%```!@%!,5$4`
M``#___\``%D!`<@!`;\!`;D!`:\!`9,!`84"`N8"`K8"`J`"`ED#`UL'!Z4-
M#>(&!E@3$]85%=(?'[P<'%88'!C!PL$8S0`8P@(<E@PWB"QQB6ZZPKG`Q[]\
M@7N&CH0F*27-``#-`@+-`P/.!07.!@;.!P?."@K0#P_/$A+0%!31'1W3,3'3
M,S/4-C;50$#734W855798F+:9F;;;&S;F9G<J*C=M+3*I:7AX>'4U-3.SL[*
MRLK)R<G'Q\?%Q<7"PL+!P<&]O;V\O+RZNKJSL[.PL+"GIZ>?GY^:FIJ-C8V+
MBXN&AH9_?W]Y>7EN;FYL;&QH:&AD9&104%!.3DXD)"0@("`>'AX;&QL2$A(,
M#`P)"0D("`@&!@8%!04#`P/___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````"_5]``````87123E/_____________
M____________________________________________________________
M______________________________________________________\`KH!O
M,0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#[241!5!C3
M19!G4P(Q$(9W['K8E4"H=L7>3=1(%$\TG"UPKI7\_U_AYH[1YT/F?2;)SNZ"
M2Y@>SJ0!DG-V,`@R_SXS$!#C/9_LZS$ZE?C$T%A_D#!'SKFU(ZE:RSEPQIAM
M8XQM2XD#,);CE;`15GB.,2#/%XHEI52I6,A[AW)V_E)*>5'-ELD<UV_0%4)\
MP/>S=8!&G7^='6SNG72OE4'`4$MQ5%M9WA52A0AQ`V[$]OK"XIJ0/[<QW7\V
MQ6%M=6E+7+TWZ;VY@];I_L;.\0/X_\[J1[BG^BUXT53?851_]6W`4SU"/U\G
MTLJCHTZZ#[2&^C<6__:%-!\FZ1=DLD5V)>;O-0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O:6YD
M:69F97)E;G0N<&YG````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,W,"`Q,#4Q-30S
M-#$U,"`P,C4V,C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@````\````/"`0```"1WUW!````
M`F)+1T0``*J-(S(````)<$A9<P```$@```!(`$;):SX```"<241!5"B1A5&Q
M#<,P#`O0K2]X\0]^I)N/\!1DZI[%:[8>X`<Z]3N65.48&0J#@$&+HB3+"Y:.
M@(`(G2-V2@D9Q9#)>XJ+#ZQXGEAY_R6XN#&XHQIV\LT3*"=SJLS+(*8*27)@
M+SD5;`8Q5<CT4RZDE:Z&MZ&15\:*Y'B1/Q<Y3MV]]WWL`K?1NT]><?CDAWE]
M\NF[)UN;[OS_CWT!`)(B%]4D2Y<`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+V1I<V%P<&]I;G1E9"YP
M;F<`````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,3(@,3`U,34T,S0Q-3`@,#(V,#`Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````/````#P@#````#`AE>````&!03%1%`@("KH0R
M_L16;DH"SJ9:H&P(^*0"_K,@6E)"+B`"U8\"9E8ZMWH"'A,"_:L1_;L\_O[^
MGGY"QH("[9X"B%H">E("#PL"'AX>QHX>:F)2KG(":E(B]LIN.B8"PGX"````
M/WO<&0```"!T4DY3_________________________________________P!<
M7!OM`````6)+1T0?!0T0O0````EP2%ES````2````$@`1LEK/@```(A)1$%4
M"-=ECXL.PC`(1>^F`X=]Q+5;M=KN__]R?1@3E82$`^%RP5X#V(!>U4Q>*>43
M.F/-4B.O%0HNXHC(R5(:V%,6,LQL2'(J2EZ<86LM&R<>0)1XM^,X6B:)A96<
MGI?SJ[%J<^)K"(\A8)O0]X=PLSRE6/9_]?_N-W^SUGKN_M[^X\?_UW\'PUL.
M=->=S)@```"#=$58=&-O;6UE;G0`5&AI<R!A;FEM871E9"!'248@9FEL92!W
M87,@8V]N<W1R=6-T960@=7-I;F<@56QE860@1TE&($%N:6UA=&]R+"!V:7-I
M="!U<R!A="!H='1P.B\O=W=W+G5L96%D+F-O;2!T;R!F:6YD(&]U="!M;W)E
M+@%54U-00TU4/0`Z&`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O96UO=&EC;VYS+W=O<G)I960N
M<&YG````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W-#0@,3`U,34T,S0Q-3`@
M,#(U,#`T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````/````#P@#````#`AE>````,!03%1%
M````____!PP2/7>W.G&M.6^J-FFB+%6#'SQ=&C-.*4]Z'SQ<#ALI2(+"4(C%
M,%)W#!0=2'&>16R71FZ9:)C-9)/&4'6>>*/27G^DC+'9EK?<`0(#$2$R.5I]
M"0X3"@\4`P4&____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````$KZPRP```")T4DY3____________________________
M________________``W0PW$````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````CTE$050(UV6/VQ*#(`Q$,TT!P87>HDBU6O__)TNP+YWN2W)F
M)\F&=A6P`*TC)>^LM<[C8`33=]SU)D`9X1SHDBY4*RI[PS.-,M+,QN\$QW'=
MICQM:V0'@N4TY%)*'A);T%)9<GF6+)67YDOSI?DZ?WM3U:/-Z_[32T3NU[9?
M[W-,*44^[FL^5GWS_>7_^>\#Z?`.DR`S=HX`````245.1*Y"8((`````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V5M;W1I8V]N<R]A<VQE97`N<&YG````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,S8W(#$P-3$U-#,T,34P(#`R-#8P,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````#P````\(!````)'?7<$````"8DM'1```JHTC,@````EP
M2%ES````2````$@`1LEK/@```)M)1$%4*)%C^,\`@]+_I?\K_`>1"#&XE/'_
M\/_98!@.9,.40"4#_A?^KX3#0B`?H@`J60P4;/G?"88M0'8Q5`%0VABLLQ.H
M>"88,@/9(!.,0=+20+M`.B<!I9>"(0.0#3(A'*@?*)T-UCOS/]O_36`(,@6D
M/QLDK0"77OJ?XS\OBK0"LFY6;+H)V(WI<BYDEQ/T-X%0(QCFN&,,``*((;G7
M8D6]`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]E;6]T:6-O;G,O96YR86=E9"YP;F<`````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3`S-"`Q,#4Q-30S-#$U,"`P,C0W,C<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M``\````/"`,````,"&5X````P%!,5$4```#___^G`0+]`@.U`@/X!@D$"A,<
M1X0P==H.(C\/)$(($R,N;,8<0GD6-%\D4YDF27P/%1Y`2UL<("80*4PQ>^,C
M5Z`/)40)%B@7-V0L:;HL9[<,'#(K8JX+&2P]AN@G4(@G3X=*C>H\<[\\<KXJ
M1FM@FNL@,4@O1V=VJN]47VX;)S8+$!8.%1U&``!%```R```P```L```D```7
M``#T]/3FYN8@("`?'Q\;&QL5%14*"@H("`@#`P,!`0'___]HA0-;````0'12
M3E/_________________________________________________________
M__________________________\`PGNQ1`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"I241!5`C754]9&\$P$!QW$92JHQ&-H%'WS;KZ
M__^5I'UAGW9VOCD6B1TBCRC=8)&60@BI*</D<F:'NV0QN6".[_L.@SD@T1R]
M4"D55L!U`I)-C*=1%,W&:$@""2!_7L>;4_$`0?!$#:4M@'UA-Q*>X5M58!6W
M<>P/#4^2.:$R>A4ZS.B-/^N^WO@\!\SZF_S@?D'N<;T%:;XY+)9UE#OSK)_M
M/_GM__??%]O;('/[A".K`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]E;6]T:6-O;G,O;&]V92YP;F<`````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3`S-R`Q,#4Q-30S-#$U,"`P,C0R-S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@````\````5"`,```"N142%````P%!,5$4```#___\QXS$PVC$BE",A
MD"(NQB\DFR4AC2$LKBLRNC$QM3`F?"9+ZDI@ZV"(ZHD<)APNNBPNMRPUPC,H
MB"<A2"!W[W;]``#Z``#V``#U``#T``#R``#Q``#L``#=``#;``#7``#3``#2
M``#)``"]``"\``"[``"V``"R``"?``"5``".``"#``!Z``!R```O```;&QO_
M__\```````````````````````````````````````````````````!1!!R4
M````,W123E/_________________________________________________
M_________________P!QGKV.`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+E)1$%4*)%ESMM.`S$0`U`K"T-#=\(V399[N17*I65V_/\?
MQT-:@>CCD2W9($FZ#^XD29#T6F*,I7JS]UE$1'+O).C]0KH00B>+W@G6+("J
M`I(KX44Z(*4$=%(<'B5H&L<Q:9#H&)HOFH>CW(M@KBDE/8<4!VL^PU)5YSC-
MM>W/```G;?__OZ/_)-UM9[1/VYOV<OEAV]M7._CAZO[Q^6X][4U[N[E>?4V'
M/FF;U=/$7_/[?>)?TTCR!YGQ)0(>@Y&``````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]E;6]T:6-O;G,O=&ER960N<&YG````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#,V-"`Q,#4Q-30S-#$U,"`P,C0T,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````\````/"`0```"1WUW!`````F)+1T0``*J-(S(````)
M<$A9<P```$@```!(`$;):SX```"8241!5"B1A9$Q#H0@$$5--FZQ5Z#A#EQD
M.PY!9:SL;6SM/``7L/)V?__,@H3"3'YB/KSYC`P#ABH'!P_YMKT;!40D5:2O
M)05^,6&Y-7']+RAPYN:*3;72SZ6`.&ARPXY#M=/+"4&P8R])2I<1&6]U<D)D
MGCAI]B`Z59E>\DFP[_#586^F:^]/FP5>K;?QY^:]C:F9,W]^L1]ARB,.W5/J
MV@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O96UO=&EC;VYS+VAI<'!I92YP;F<`````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`W-C$@,3`U,34T,S0Q-3`@,#(T-C`V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```/````#P@#````#`AE>````,!03%1%````____`0$`#PL"/2D``P(`GVL!
MFV@!EV8!^*0"[9X"U8\"SXL"MWH"=DX!IG`"B%H">E(")QH!^K`?43D*_K,@
MXZ`=D&82AE\17D(,'Q<'_;L\]LINB%@!QH("PGX"EF$".B8"%0X!TX\.Q84-
MRHD.>%PH_L16=%DG]+Q3(!<(`@$``@("____````````````````````````
M````````````````````````````````````````````````C#/L+0```"YT
M4DY3________________________________________________________
M____`(*/<U4````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MD$E$050(UV6/VQ8!,0Q%L]2M$Z5%W,I4&8I)___W]/)@X3QE)UDY)Q"SF`5S
MJ2"3UTHI[;DR&X=9SG!F-BTV4LH&V]2`.#K-AH/U9M_/\7R)P/!1OV1@A7+W
M>CSOAZU$Q2`2KVPX!DN)19F3#:%RVM<('5EKZ0:H&:)W"[@240<3YZO_M%P?
M5__??'_YO_Y[`],U%SD3FHW7`````$E%3D2N0F""````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A
M<G,O;&EN=7@N9VEF````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-C0P
M(#$P-3$U-#,T,30W(#`R-#$Q-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$\`$<`]P`````````S``!F``"9``#,
M``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS
M`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,
M`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S
M,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,
M,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S
M9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,
M9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`S
MF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,
MF6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\S
MF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,
MS#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PS
MS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,
M_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS
M_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,
M____^+\D````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(?D$`0``V``L````
M`#P`1P``"/X`L0D<2+"@P8-05AQ<R+"A0X8)`4B<".#`PXL8&[*@R%&BPHP@
M,6[L.''%"HDA4S8D2=%*H),`5,HD&(#E1"M63`+X.%.ES9(P);+HF7+D3Y)$
M0QZUF11DS:5!)4)IBO&I3HHF<T;=2?5B32NL7K9D1=9*QZX/`ZQ@=>U:H)MD
MV;+:BM9A`+`NYTH,9"UGH+`<ZS8,$,C*`;`P_YY<RRJPX(4L<.XLM4*%"BNK
M)BJF^'CAW;DJ_HQ*-6K4'Q4DG+`JY;AS018!5@'*DZIV;56C\I!:]:2UZX$U
M_Y!JEHH9JF;(D:M2Y<3W;VP;\XPBCHI9<N2I5`%R_IO%BM&I4/Y5OYY*5&Z.
M0Y\+W(AGE/'DX47)']5\YV+UZP%4D9ZJV2CY?O@A7"E52.322?A!=P`II%`A
M&H`!DE(*-*NHL%-A``2`WT:!R`+(;'GD404@I9#5EEGVH:1>``&8PLHJI83X
M82FK0-/6-:P<P)&&W=W52BMDK2+D*FS=>,TL*%*4WF.P!5!DD"^R(HN1;>G%
M75<<&AE7D50>F>1$2Z*U$11<=FDFCB2%V=1&A)WI)HX6GH5E36N]>::5<B8%
MFT>!4&E-F55N"1A)/!)EU`I_M6*D-5UN^1<K*&ZE9E%/`?"7G50*NIB.G/5D
M%%B8FOFG6R4IV5,`!]349ZAN6GF5BOXJP;91G:RZ:99)44TJTE.KUGKF6SH%
M56A(`<P*J*]:!A55K+PBZZ8URIH:$INT=JDHLM&6-"V+.SWK;))1#7O1K):V
M^FVIG8KD$0#'WMBNG5]>R9!5U3;J[%LL9;0GKN\ZVQ:^2*E+4;_.6H/O5C%A
ME)`35)"@0K\$^VD--/4IR6)&@9"R'""7/>EO6\^$7+%$)+#@74:EC-:,*GFH
M4$6[-K*Z',L=J95'1M+!5X4*]2)K36DT=U3%<A=9(0IRUOG7'*+^6F,-::G@
M00)'*I!"&D/[Y2$:<<9<-PJ?4_IJS2JEI>(':A.ID(<JY2TD&C-)3V<=W,@5
M:&#$5,)8VOY_>#CAMQ.BC2;*0GXT`_?A25O77REQ`@`JJWK_5]H?@9?6#"JI
ME'*0*,4=;CCBU@5M8*T4FL>,>9(;8PSBJI!B$.>>@TYW=A6O<*V9,;<%32GM
MG5Z:**IW_?G5!?WQ>>*R]S>*A2184>LJ*_2^>O#,"._Y**X/]';LR6>7QQ.`
MW&[G7"2TMSIRJ]/]N>&C:2Z0'^Y5G_3QB-<V8:@&GZ0"_+(ST[GG_@'$0/@G
MO_EUCT&YNU.25&`ZQ*WO>/X9Q4``P;GTP<V"H(L@%4ID)B"))6T$G)MQJG.X
MO1$D9UW#8/^ZQAP5/.%19`E$("+"$2<0\'CBL8XQ4%>0/'"..('S0UH!TS<*
MJ4UM*1*QX2C2A\'29,\@?\!#'OP@']1=AW[FZ=L1EY*:!QVN:\SX#T:J0`4I
M5DYNV!%%B!K'$80YK#VEB5MN5$*%.N*ABI+S@Q9Y<A$I5M$\?Z`"4<CH!#Q$
M$0]]<T)*5.`@ROTA#X*DRM^<X$*9J(!A>*AC@IX3$```.P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9R
M86YC+FIP9P``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C8W-"`Q,#4Q
M-30S-#$T-R`P,C0P-S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#
M`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`
MM1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*Q
MP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ
M_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#
M!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1
M"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1
M`Q$`/P#ZR_X.8-(\7ZU^W#_P3/'PXD^&\_Q#T#X4?M;>(O"V@?%";5+70?%4
M]MJ'P8M]6\/6-YI$R7]GKUYX6E\1W>GWL-GK$5C'I]U=ZAI;Z?%<W-M^0?[,
M7[7'PX\6_M!?`SXU_MQ>!?&_[/G[/GP"\::]_P`(5XWT;2=4^-'[/WQ+_;"M
M=2T/P;81:O\`%?X<>#-5T:UT7X0Z=XDU+7?"UU:Z]=^';KQO)>ZG+X@O8O#9
MT[4_U*_:-_X(W>!?B5XTTCXQ?!C]I/\`:0^&OQA\`Z/K6G_"R?XL?$;6?VJ?
MAMX:?Q!X=U+P_P")8I_"7[1%S\1/$36/C*WOA'X@M$\;3V$,4<;6>F23V\+U
M^G/@OX"^!](_9[\0?LT?"FS\->!_!LWPP\9_#;1[/P[I2P>&O#E]KFFZII]_
MJ(\/:7<1VXGAUK5]0U6ZLIKN%DU*ZGD:X-Z4\W^4N-/$3A7.ZM/'X7"5\3/%
MX*.65*M2,\MSC)L+75>&8..)5+,,!5A6I8B$</#V..E3JK'U:<L+46%JUOZ/
MX<\-.)LGI8B.8UJ&%C@)K,,+3A*EC\!FF*C.D\/2=!5L%C*=2E4I*=:K*MA8
MI1PE.<<12G6C1_%3X&_LR:W_`,%X;/XB_MK?MY?M6_$G]E?_`()F:A\;+']G
M/]E;X$_#[Q-I_P`.I/C!>_\`";6_A#P5XL\=7/BBT\7>!TUW6_BCKGA;0M-N
M]6TGQEJ^J_$6V\1^#]#?PAH?AWPY>:SS?_!37_@W_P#@K_P2:^!VM?MQ?LY6
M&K_M>?!;X0:7<P?%?]E;]K[5-8\4Z-#K7Q"6Y^'/A_X\^%+[X,Z/\/-)U.]^
M'^M^)?"+^(?"?C3PLVG_`/"#V_BW7+'QOH?B.T\-7FA_6W["_P"VA^Q+^S]^
MRG\'?^":/_!9SX7WGP#\5?L,_%U->^`OQ,^)GA'XMR_`3X]:W\$?B!J>N^!?
MC/\`!WX@Z/X>L_M>IZ)=>(V6[\.:GYFAZMH%]!YZWMKK6M>$=$TO^"O?_!<O
MX`_MG_"?4?\`@FK_`,$W-#\;_MD?%K]JE]+\&^.-;^'7A.\T[PKHWP9F)UCX
MC+X-\3^+VTA7\?RZ5IS:?::[J/AC4_A[X,LT\1ZYXJU6"YT2UTV\_HC+<#PY
M@^'*&'RY86AP_'!7A6PN)]A1>'C1O5Q,L;AYT>2JZ<)3K8SVL*MU.=2JG=GX
M7CL7G&(SFM6QGMJF:RQ3YZ=>C[:HJLJJY*"PU:-7F@IRC&EAN2<;.,8P=TG]
MQ?\`!-__`()$?\$>O@/X9^+?_!/J]\%?"#]KO]JKX4^#/A;XH_;&\7?%3X<+
MK?B>YO/C#I=UXE\%OX=N=>T^\TKP1X/GT[2?M7A?PGX`U^XU'0M"ET>_\9:I
MJGB;Q#>:YK-K]D+0?A9_P2<_X*;?M/?L1^!C;_`S_@GC\1/V.++_`(*$^';K
MXI^.["T^&'P:^+_AWXN^$/@'\8[/PEX[\;SQ:EI'@SQ5H_B;X8ZCK&D>,?&.
MK6/AK6]%L_\`A'WTRQ\0/8+C>!O^"]O_``2U^'7[0WQ@G_:,^"WQ8_8;_;$;
MP#\-]#^,:_%#X2Z5XI\7>.-'T#P5=^-O`_AB7QW\!=<^*<7BZYTQ?$5YH/@6
MT\7_`-@>+]:EUC1=+M-$M9IFT;1_Y\?VZO&_P?\`V^/^"A7Q2^,7[6W[!G[4
M7B+QE\<?@XWP(_X)-_LQZGH'C'X7^+?BWJ/PCU^ZT^Y\7_&W3_#?Q`\,_$GP
M!J?BOXA^,=7\2:;<^*-)\->`_!WP/L?%6JZZOB77M)\,ZMK/7C<YP>!PV'KQ
MOF%;'2I_4<+EGL:^)S%RC3DY8.,Z].G7A1PT_K-:JZT80P=.IB'*,(V7-ALN
MKXJM5I-QPM/#1D\36QTITJ.%4>9)5W&G*=.56LO8TX1IRE*O.%*S<FS^Y_\`
MX>,?\$]_^C[OV-?_`!)_X)?_`#<45_GF:+_P9[_\%3-2T?2=1U'Q5^S#X>U"
M_P!-L;V^T#4OB7XBN]1T.\NK6*>ZT>_NM%\#:IH]S>Z9/(]E=7&DZGJ.F33P
M226%]=VK17$A7K\S[_\`E.?^?K^';7S^7T_\#BNWW;_+Y,_6KXG?`C]OS_@E
M[_P4,_8B_9(T?]N^X_:-_90_::;XA7'@[3/VD/`T.I_$70=`^$Z^'?$7Q%\$
M:C\3-%T2_P#$&K^,AX+N96^%FL7'BC3?"?VWS-%U/P=H%G'8SZA^E_P__9Y\
M;>#_`!E\?[KP?\88?A]I/QQ^,7@/XN:+=^%?`YU#Q;X7UNQLO!FD_%+2]:O_
M`!YXH\;^#M>L_BIH?@FP\)V\OAGP%X`_X0W2=2U'6+>+5?&\K>,#]_\`_!7S
M]CSXJ_M._`7P#\1_V:%F?]K?]D3XK:!^T!^S]I2^*/\`A$K#X@SZ?'-X=^*/
MP8UW5[B5=*MM&^+OPOU;Q)X5>75$2S?5'TJQU*_L?#]_KQF_.OX!?M$^"/VW
MOV=9?B!\'?%?BKX<ZAXETOQ#X4U0BQT*/XG?!+XC:<U]H6L:;JN@^(M.\0>'
MO^$H\%^(;6>6TBUK1];\+:\MG;WAM-8T&^V7'\L^,>1U<FS/"8_+,%@\#E&8
M4*>%QU:E@,'*C+&0QWUZ%?&TJ>%DJG.U"$95J=:MB(X7$4ZKJQKRC5_IGPCS
M7#Y[E&/RG,\;C,;G.#EB<3EE&MC\4JCP=;+OJ%3#82=;$J,(T[N<J<'2IT)8
MBA7HN$\/SX;ZX^.WQ1_9A\#>$;FV_::^(OP(\'>!]0O])TJ[MOCIXM\`>&_"
MFH:O*LVL:)I]U!X_OK?1+O4I3I-QJNDVTG^E3)HMU?V\7F6KSQ_BE\0?$O\`
MP1._:,^,$7Q%^'/[?-K^R!\7_AIX!U/X.S?$7]GW]H6W_9(L/$WPPN_%VM^(
MSX*T+5?&NA6/PJ\=^&XO&VI:EXV.L?#6TN;K5-2N-(UK4M;U+1T\/[_N/]FG
M_@G=^QW\!=2UGQ???#6V^+WQG\8:?!%\1?CU\?+V_P#B_P#$[Q]?Q3)=:CJF
MHZIXXO-8TGPY)K=VTE]JFD>`-&\'Z+<M8V$7]F7MQ!8)!]Y^+?A!\&/B7H-I
MH'CCX7?#?QWX;M="OO#.GZ5XI\(>'?$&E6'AR[M5T^XT'2XKK3YX[/2Y;.!+
M-[*S^SV?EJL0MXUB#5^/X/,,ER*NXX3&\454XU*<\;A:N!RVA+VE*,*Z665J
M>91Q=&H^>G%8C%X6;IQI5YTX5%["G];F&4YSC$H8_`9+2DG"K##5X8K&U4J<
M^:ERX^E/`QI3ARJ4GAZ%:$9NI0C5E']Y/QS]D;]EK]F#]F[P$;K]F7P_HDVG
M_$RST?Q1X@^+,7B>\^(WC;XT/=QW5]I?C'Q=\6-8U#7==^(2WT>M7^HZ-,VN
M7.AV%KK<T?A>STW1I!91^&_\%(?A?\2(_"OPI_;/_9VTRXU#]J']@CQI>_'7
MX8:9#J5Y;0^/?A\]C:P_M#?!J;1K71_$5OKDWQ=^%6F7GAO2]-AT^UUJ'Q*F
MC_V'XCT%I+J.]^[/AM\,OAW\&_!FC_#OX3^"?#'P]^'_`(=_M`:'X,\&:1;:
M)X8T:._U"[U*ZBTW1;..WM]/@N=2U&[N]MND<4;WC"V2)H_*7\POBD?B1_P5
MU\<W?[$W[+4/B#2?V,]-\8)HW[<_[;%M9:EI_@;Q%X,\+ZFT/CK]E7]G77+[
MP^=(^(_Q'\;7GDZ+XK\=^$_$%YHGPRT6TU2'Q#::HFNZ3INI^IP#A>(\^X]P
M./R*MC,5B<)F-/&XG-,?)\]'+8U%1JSS":JSBW6P4IX9X2G6FZRE.A1YJ:E*
M/C\68C)<IX3Q6%S:EAZ%'%8.IAZ.7X.*2J8V4(U8QPL7"/+[+%QA7]M4@G3N
MJU1^U:YOU^^&O_!7W]C3XH_#GP!\3-#F_:!LM$^(O@KPKXZT>SOOV5?VB=0O
MK32_%VA6'B#3[:\O_"OPW\2>%[VZ@M-0ABN+OPWXBU_0;F9'FT?6M5T][>^G
M*^UOAI^SK\%/A)\./A_\*?!'PV\(Z?X,^&7@GPI\/?"-A<>'](O;BR\,>"]"
ML/#>@6D]Y/9-/=S6VE:;:0RW,S&6=T:60EW)HK^\/9R_Y_UONH>7_3CU^_R/
MY2YU_P`^Z?WU?+_I[Y/[_(_F4\#_`/!?#]O7X.W=Y)^V-^PU\*OB9X,TS6VN
MM=\:_L<?$+Q3I7C#2_!$?A9[JZO_``]\$_B_#K,OC_4=,\2Z??173P?%?PI-
MJ&FW]G9^']`U>]TYKS6/RC_X*5?'+7?CW_P5=_9]\>?\$(T\":GXC^)?[.WA
M7XR?M*_%3X8V6M:7\-?B%K/Q/\0^,M6T\?M>Z=<QV_@:2^\)>#4L[HMXET.'
MXI:-XO\`%VH>$;B7_A8GA_P_H.@_T5^+?V*](U7P8/$<`A>Z:SAU-K*8&YV;
MYI@LL4307=O+NM+A;ZYO;EH91;YMWBL#%/<2_@#\./B!X6_X)2_\%$_BQX>N
M_@#\1?''P._;"^&'A;XR>*?$GPC^'VL^+]3^$'B7X1ZOXB\-^,-9'AWP]\WB
M?P5<2>--&\2_$2XLM.?Q#I-_XFT*\M],UY]7C_M#YOC%8V/#>:5,MRFAGV/A
MAI+#97BZ<:U#%<_)"LJE&<HK%*%%U<1'"M_[35ITJ5-JIR-^_P`*SP?]O9<L
M=F6*RC!O$)U\PP51T<3AW!.=%T:R7^S\]:-.E+$VFL/3G4K2C.,91/3OC5^T
MU_P6%_82^!Y^/O[3?@/]B/XM?";P%9:'K?Q1U;PGXE^)?@/QY<7/BGQ7#X9L
MOAQX?0Z5?Z%#XEMM9U;3-(L?$,7@_6-%^RI]JU6WD<O?3?0G[4G_``5G^+W[
M&_[._P#PT1XY_80^(-MX4UC6/#FD>%M1\5_M0_L>IX5\6>(?$\PDETO1M3^%
M/QG^-/CCQ%J<&BV.J:Y)8^&_AMKM]96FEMJ.N'PYH+:IJ<?P%_P6U_X*=?L;
M_M"?LK_`#X=_!#XZ^'/&VA^*OVK/#>H?&7P?)'XY\+7^G?#7X0Z=XHDUKP]\
M6OA#J.BZ-\2X=#O/'UUX-U31-'\3^!AH^N:EX2AO].$DFGVFI6/R_P#\$CO@
M!H/[0GP?_:%^&GQ9\%:5\8?V+7^*]KJ?[/\`9>.;+Q'%8:3XBU/1-9G\<S?#
M*WUJPTCQCX/L[2/7=,T^+Q9H$VE7"ZG)XGNM/>YF;Q;<3?D/!'AUD_%.21S7
MBWAF&6YD\RQ]-8'"T\?DD7AJ-2E"-/%X*->,J$EB(8FG^YIX=JBZ48I.*F_T
MWB_Q"SG*,QGE.0<0ULPRQ8+!OZUC)8#.*BKN$I2JX7'2P\IR;I.C*7/6K.59
M5G*;C)1C]R^$/VZO@-^V):^)=5_;[_X*1R)^SE>:QJNO6G[$_P"P%^RU^VC>
MZY\5="@US3+S3_@O\3?VNY/@?X1U'5-.8:9>^$-;TSX8W/@*7QU_PD=QXAU7
MQYX&T>$:#8_N9\$?^"XW_!,;X">"?AK\%])^!'[7_P"R#\#_``OX=N_#GPZF
M\;?L/?&SPW\-=+L/#-J;F30]*3P9X>\:>(-3U:ZEE>:[N+?1-4OM1UF]FU#7
MK]K_`%">\G_(/]GKQWX@_9!_:&\%_P#!/;XF:S)XG^&/C'P!KGBK]C?XHZLZ
M6WB*^T7P3+!_PDG[.WBM+:"YBU;Q+\//#SOKGASQK=_V?'J_A"&PT[4OMOB1
MHHIOV=\$^'+74W@\X6\C*Z;G8Q)&9/M+I%']MD6*VMXTDW&:ZDG4E58Q3&WB
M6:W_`'+*,DRG(<(L%D^78/+L.FI2IX2A&DISY8Q=2JXVG6K2A&,95JTIU)*,
M.:4E%'X_F&9YAFM=XG,L9B<96:LIXBJYN$;MJ$$_<ITXRDW&G3C"$;M12O<]
M#N?^#CG_`((NV-Q<66H_MM:)I.H6<TMK?Z7K'P7_`&D-'U?3;VWD:&ZT_5=)
MU/X.VFI:7J-G.DEO?:=J%K;7UE<QRVUW;PSQ21J5VUU^RUX?N+JYG;P]X)NV
MGN)IFNKNSD%U<F21G-Q<@V%P?M$Q;S)LSSGS&;,TOWV*]/5[-6Z>Z]M.M_/^
MK,X+KS_JWE_7R9]3>(P/^$1\2-@;AI=V`V!D!M-U`L`>H!*J2.A*@GH*_E5_
M;5U;5-._X*Z?\$O;/3]2U"PM->\+_MNZ3KEK9WES:VVM:7#\*K;7(=-U:""1
M(M1T^+6]%T?6([.\6:V35=)TW4%C%W86LT114T_M_P"*/_IJF/[%/_!_[=(^
MX_'O@CP7K6FZA8:SX0\+ZM8ZII-[:ZE9ZGH&DW]KJ-M->:?:RV]];W5I+#=P
M2VVHZA;217"21O!?7D+*8[J=7[GP[ING:9HND6VFZ?9:?;0:;:1P6]C:P6D$
M,;6UN&CBB@CCCC1A#$"J*JD11@CY%P44W_$C_@J?^E4QKX)?XH_E,_*O_@K.
M[Z5!_P`$]?$VENVF^)+#_@I3^SCH-CX@L&-GK=GH?BC2OB#:^)M&M-6MS'?V
M^E>(K:RL[?7=.AN$L]7@M+:+4(;B.")4_>7X91QMXL\.VS1HUM-KS6\UNRJ8
M);=M2F#021$&.2$A5!B92A`&5X%%%:=%ZO\`*))]Z^'YI9M!T2::626672--
MDEED=GDDD>SA9Y)'8EG=V)9W8EF8DDDDFBBBLET^7_N,S73Y?^XS_]D`````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+V1E=FEL+F=I9@``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,S(R-2`Q,#4Q-30S-#$T-R`P,C0P-C$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA0`!`
M`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F
M,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,
MS`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S
M,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9
MS#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`
M,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69F
MS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_
M,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DS
MS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,
M,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`
MS,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9
M,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_
MS,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F
M,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,
MS/_,____`/__,___9O__F?__S/____B_)```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"'Y!`$``-@`+`````!``$````C^`+$)'$BPH$`K!A,J7,BPH4,6
M#@E"C$BQXL`5%B=:W-BP!,>/(`UZM!@@I$F!23:6/!DRI46,+$&VH6,1"I28
M'Y.TV;@3Y\8GD#9&\KD1"J0G!&TJ31CI)M&*D-@,;`.I:E4V(P="<ME0H\^J
MV*!$@D2K;-FJ;6!BBQIQ)5$VD)#`-4N75E6D:Z4Z5.LSB5RR=>L>!1JTJU><
M3T@`#DPW*A*P79\*),PX<%3(!;WR]4FULN?"!=VRD"%YK>?/!ED@%*AZX.&0
M0$]7UBN1X&J!;D\F65SY,EW:K#6V'IC;9.?/E,U"FF-;+0O-..=6GA.HU!S>
MM'H>5&L%.LLG;#S^7PIT[5J@Z\IIJX9IQ0KIX">A4,5N]I*>\N5+73++!BZ;
M).W!)$-WKMW6DE7*G74??N7I`5A5=K'1WD3MV68@2%:<AV!XR['"8'FLS''6
M61)6..%`5U1X$GG7L*+'=?Y9X>&'U\#EFUU/3+B"%<Y9<05+,X*H!W@D'&`%
MC2%>1595.[9W(C:J7?C1"BNP"&(@*QP`P)$?!G)5$OVU@5243C9)X$E:<MFB
M=6R04"6#K`1B(Q().6GGF2=E>44KUUAGU7^!5!?H=4MR5="`3CXGV1R7_&G5
M91"2J)"=I6&SFZ./9BIIG>Y5BDU_H/X):G^/;3K0I3F^AM-\C_:7:53^<VU%
MT&YEL?&$JC%!^"""C<7JE$#20;("$K_Z!)ZF])UU5T&^Q0479YFR@<1?O&6J
MW4!&V6@C),6&=)QR5DW[X+2V)@1F57+%*B5'1BE+XI*E0GI40?(]^EBXZW+T
MH+;[*KGO$S==&N&H_1D:TK#P/E%J>C8VIB2))=Q[U68RD:"M"?1%RMABW'YJ
M,:GY;A05PM(FVZO&5N%5\K(Q4?57PY[]A\T3K$+2QJ]I/0$P4:Q*UQN=#K7Q
M)%$Z_24;7@Q!D2.>DH5WVG(.)=$DKC'Y/%U#4`#HI*<+>\8<0RFUL'6EKG[V
MM4(EL*>B9+M9+5BW!#WA$J6E^<>K8`LI/1!UW9(M.2IV!F,[QZ^(AFQ2NW8Y
MJERW+"0!)AL]KDTT=KS:G-"CVI%9&JUW`W;MK$N>'275)L7:=5F?%S0?TF:R
M?6^H?@<-]4%C^P2%Q4JZ"NO9"^F\=Z(XU2MJJU:E[M#0++':DTZO6NZI0R<P
M1,<<HP9>6D```#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O879A=&%R<R]L:7-A+F=I9@``````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(Q,#8@,3`U,34T,S0Q-#<@,#(S-S`S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y82``(`#W````
M`````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`
M9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`
M_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S
M,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\S
MS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F
M`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]F
MF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F
M_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^9
M9@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9
MS)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,
M,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,
MF9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____
M``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_
M9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/__
M_P#__S/__V;__YG__\S____XOR0`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```A^00!``#8`"P`````(``@```(_@"Q"1Q(L*#!@P@3*ERH$``)@P\9-ARE
M@J`*BA(3`FB&$=O%9A4%D@"0<:"*9AQ5?.3X\&)$C0!B`EB)LB9*E:.:O41(
M(J?-GT!1[D1X,JA1H0Q['C6J8B3)A$67!ATUU*)/J3\[%HQ)$^C%E5]'K4`(
MX"I0)V)5KLA)0@6`%8'&'NQJ<]035M>NL7HB%B\K*X&J"J0+<@7>O'H-(V8E
MERA0BG\17S-L)2^KD'/-UE2\V+#?Q@8)H[1[F/',%4VA:J98-*V*M1Q'C7K*
MDT3;FQ2/JG0KD41*V2`UU]2JL&?%F:P)RQ8,4>15U@YM2R\Y."M5ZA`UI\8^
M4*9FYAD!)`0Z[9,X=YFL&*.>#5XB5\\KW@;F[EQV3+CXZ6.3R;\_;80!`0`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5L;65R
M9G5D9"YG:68`````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,P,R`Q,#4Q-30S
M-#$T-R`P,C0W,C$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S
M,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9
MS`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`
M,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-F
MS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_
M,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68S
MS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,
M,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`
MS)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9
M,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_
MS)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF
M,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,
MS,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S
M,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9
MS/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"'Y!`$``-@`+``````@`"````C^
M`$E4&4BP8!4`V!(J7,APH4"#!DDTG-CP(<2"$B>2R%CQ(D2."3<.!*E0I$>,
M`%(^5'%0HT6/*EA6D>DD9LN*<EX:E#FSBI,JI)Z1>D(RI)R<$&T.E$EJU;.G
MI4BIP(FTH-*>0(4^U2J5(8FC5;$N'1B45-"G9H6"_`J6Q!.>!<^2`K0U3YZG
M*QR"/>K6:E:T6P.K+;DW)\^?9P4K7L61[5$59M_^54R9,6&P3[8ZI?SL[M8G
M02T;?9R8<^<5I=`^6;&*5&.P2$QK?K+*<YY50/->EN-$-EI6T&RSRN-:[]'8
MOO58LR:<N.[1<I"CS9,ZL')659XZL7*W*_3>:$FAE5I16@\K*ZR?U90[-:23
MZ.&)DW`BU^X*VTZHHVU,`KG9/"J\EUE@FVU%BEW/B%;26?(=15]@!T+H67$,
M0=9:'HX]>"!BTZ7F747D2;579H`<6)M=Q`G5'D78;%38@\^4<MMP9JU0E$;O
MC;B5C-1)A02+%6V$Q'&EF>7$1AL!61)!2$*&EHTY'JEDBW[-A&),+N8T)38`
M[#32D3&IP!9(`0$`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O9V%R9FEE;&0N9VEF````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,S`T(#$P-3$U-#,T,30W(#`R-#4S,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<*!"`01($$Y(P"""APX$,`<Q!
MZ)!$GH@/'48D,5%A'A48,Q(T.''B)8K8+*HH:5#D2``D+JF(B9)$)Q(J3K9T
M*9"CBDZ=3DY$PC$FT)4H>=KL-)-$T8E.?][D23"F$Z!`G<RYBM7)2:H]3U["
M&M0H5K%)'\+,<W/%"J=N`;B%^Q;HPHP+EZY@Q<HMW[U]`<,\Z;0B6Z8X65V[
M]I<$X,6L0$K]6C6K'Q6HJO#MF^E3)L"LJJ!2X>?J78@P,5-!Q5J%:Q4K/JUX
MC9GUZIRGL0W&+&TTJMZL43D)_MMW;ZDUC_YV3=PUT]JM51RW.W!II^'1G0?;
M_IPY:ZZY#Z)FW1X,*/GSYK>#WUD0@(KS\..CWYZ[?2?Y^,__#$:Y\LVE3N3'
M52>#I57=0@;MAQ]B#!E($!('79+?=CH!@(1(3A$U5H`3:G506D[91)B"$U8X
M5H@IE4786.]-&,Q/*QKE%&%.F623B[A!-2-"3F&%(`DNEI>7CQ3=R!U,]P5Y
M4Y)"AN655T8&^>(E3U(&4TD+D:7EEF5AV5![$84IYI@A!00`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]R96DN
M:G!G````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`V-S4@,3`U,34T
M,S0Q-#<@,#(S-34W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`^K/@9\3?&FK?`WP5\5WT_1M(UKPWJOQ-OO#-A9ZC<:3J=EI?B?P?XZ\!
M>$=:T.[CFOWUWXE&;Q3IFJRZ?+.;GQ#XCAB\W8WD+#Y;\6OB/<?"S]FB72Y-
M2N)O$WB_7=,^",&N^(7T^?7/%EAX5LX?#GBCQ@'L;.RMH[.PTS3-;\/^&M-M
M;:#3/#EO=7$WAZQTW5M2U'4KSE?!OQ)L_"/[-GA1].6U>7X<7/C/QZUFQ$'E
M^+]4UR;2OAE8C[/&T,+:/JVLP:R1]CFDBFTO3)T4QP3P7?R%X@TSQ=\=?@39
M/X/U)CH7[+O[-4?Q2\;ZG<&ZU?4/$%WXY\9W6DZG?:;>7EI8VTWB+3K>SUKQ
M8Y1+:+RX+MGC6%AY?[MB89=DF$P^<Q=&BL#@:&'E.,8Q:<E&-K_.VS];'XYE
M&$S+-,2XN%2?MJ];D;YGRTTDU'T73KIZGZ9?%'QRMM\>/V5O!.F2.VDWNHZC
MXR2)?L\.FS6-QX/B\&^$YKBW\L++!:6%[="VC4H$N"+B!HY@&KOOAY\6(/$?
MPP\<_%.&9KBPCUOXG:QIX<$J+?P%>ZE!80X!#&.^M;2S,RJP,TTTAA:!&2-/
MRP^)7Q!\3:1XU^!<WBC3]4'B3X!?#CP=X(\=:P8&M;:Y\0^`?%&H:LS6$9N)
MH@OB[X<:<WC736.IWLDFGV&H%89PT4<7TG^S%\1O!NJ?L;:C')J<%E8ZMXP\
M$^%=&S_Q]:D?C!XF\%6_A:SMU)*G4M?BU>>>[?RS#+#!=A;>,Y8?193Q%EN.
MPU&5#$PA*<X1E--72DXW=]=EJ_\`*QAF>4UL+4C&O)VE*,6W>\4W%?Y7^6^M
M_ONVUG6O!/P[^'K7).J:_;2_#70=5?5(4O1]NU'7M(\.ZN6M@(%N98&UR\DM
M891)&T-K$ES'=(LPF]`TWQIX:T+6K$:I:Z5K]OJ1\8?#SQC\/Y[/^T+3XH>!
M)9I)/B5\/-;U"Y:5[J]N-%OM0U70&N7DET+Q(MA>6SK96\FGS?/WQZ.M:QX_
M^$7AVPNH=&\$>`_BWX.^*'QD\9&[2'2K'PKX<@UU]$T"=\_-)XMU?3;W7WB4
MF2;P[X3U%[8VT^KZ;>V?F_P]^)DFJ>%/V?\`X@:_I>JZ3XUUWPY^UG\6M4\'
M2QP2:A9VWAV.]TZ^BNE\@K%?O`^GZ9F4-<?:)97B="H\O/-L5D&?87'Y##$4
ML=6C5<-9*4DW9)JS7VFM;;I/0YJ>"Q>65EBX3E7P\9*>R<8J+C*ZTZ6O]UT=
M_P",_P#@J[X&^%?C#Q9\,+#X@_`77;'X<>)==\!66M^)?`OB1/$>LVG@_5+K
MP];ZKX@33M?T[3TUO48=.2[U5;'3["S6_FN!:V5K`$@C*]/'PA^$/BT#Q7J/
MPQ\#7NH>)P/$-_>3^&-%NI[N\UK_`(F5U<S7+6#M<2SSW+RR3L[M*[M(68L2
M2OQE^'F)BW%5ZJ2;22D[))I67O=%>WR\SZ=<5TFD^:.MG]GKR_G?\?(_GHT#
MQ7XVTOPYX_\`AMX@L#9^(#XQUQ98(;KRKH^(?!&IV=QJ>GVRRS'[,;5%MM4M
M[64F8VH/^D"0B9?HK]D>7Q/X8\`>(]/E_94\%_&7_A?'B^^\&?"KQ1\5O$%]
MIWPL\,>$?!/A;QW\2M2;QK?^'[6XUG4-3O/#-Y?>#/#7@O1[F#5O$/C.]TBP
MTZ033K;30_M<^$-'\'?M#?$#6(M!,$WB0^'/BG!J%F&>/_A)-9TAM`U[4889
M3+"_V_4-(NAJELT<D<T)@3:A+,_Z;?\`!%CXD^#_`!E=>.OV9/$.JZ;(OA/Q
MUHOQ4\%^'=2EM;"[T_PSK$%Q:ZM::5$+12FKZ?KGA[1]8TN_M%AU73U\1V36
MM]%.8IHZ\4EF>2\"9;:$\0Y8BE/,)/F?MZ=24(TE5:^Q%M-6>EU<U\.,UK9M
M'+,?1KRC0E!3GR6^&?*IOX7O%O7S[GY=_LOV&@?MP:5>)I'@;PM^S3X[^-7P
M9U_Q-IWPE\*^+?&7CWP9J7QK_9W\4ZIH&BZMXEA^)4U]XD\#ZCX\^&^KZUI]
MEH5CK$5SIO@<O?O%>3PY?W/X4_!6;X4?%;XU?!G4]#;4?"G[/NG_``X^+R:"
MET3K#:UIOC;1;#X.RZ3/+IUII*II"^(O$%N\]W;I;H/!<$SW-I#9W33_`-1W
M[-'[!G[,_P"R%X<\7^$OA+X/UR^TOQYXLNO%6M7?C;5(/$^OK/>:1<Z#_96C
M^()-/LM5T_38-.O;J"W*7CZI)Y[)>ZI=08B'I&A_![X'ZWXR\4?$WPGI.CZE
MXKU*#1OA]XO\3:9?OK(N;OX=W>NZ8?"5W:K<*I?3]:U7Q%=7:W%S*RWS*RR0
MK&4;\)H<0\383"YG2PT_8*U*6%C3G_"C*4+JFG=[76MV_)ZGZEG.1Y%FDO=E
M4E=I;-7^&_:S;>FFFY_-9\6?BQX;^''C?X>?`WXY_$3]GKX8:UK/CK6?B5XJ
M\->.-)^,WCC5_B+>Z-8C0O!?P_N/`?@G2=-\>Q>#-#\)W\)BU/3=+U^PLO#5
ME<7,_B"\N)+N_N85'B_2?@SH'[1.M7?PU\4^'O&WQ9O+*#X@?!WXAZ+XN\#Z
M-\*?BL?BSI-[9MI]PD.K^'I_%?Q&\=^$X9K"34]9N-&M-"T)-<TVWGL;V6\^
MF_\`@HS_`,$;?B%\6OV@?@I\;?V,])\%?#[QKX,U+7K_`,;_`!/M_'MEX'^-
M$/B2[\36$.F^+M$U:3PMJ^HZMJFE:*T]E:Z'+J::7J%HJ:>\,3R_:EN?M-_\
M$T/@G^QK^Q[_`,%!?%?A#Q>=,T'XQ:3H,OPS^&&E:8?#7P_^'&NV5OX?\(>&
M-&\':2)8[2S\9^.-4MKKXB_$K4[+RSX@UAKS4+&UT2PE$"^GD&<YU@L71Q>%
MJXB.85,11GBN5WG52K0<D[W5G%6>FKYFGHD/.^&LER_`X2C0JT:]!X.I+%T(
M:UZ<E3;_`'TVW%I6N[:M=$>$_`C]HG4[7X'_``:MK@M-/;?"GX=P3S20":26
M:'PAH\<DKRDYE>1U9FD/+L2QY-%?E'\/?C?_`,(KX!\#^%S9^/+H^&_!_AK0
M3=6WAV66VN3H^BV6GFXMY`6$D$WV?S(G!(>-E;)SFBOZ;7$&.DE)X.5Y)-^[
MU=G^OY]F?SP\)E=W:5.U]+-VM>-K:[;?UO\`6W[<7A?7-;\'Z;XWTN::#6/"
MND:_IU_:)&MS<2Z-JT(N-)O;@HJE_P"SM9@$D;;XXH[6[O59/,DCFA\0_8V\
M:^*/!W[9/PR^)?A06T=K=66C:#KFFQG3=/U#QE-XKMQXE\,:+HVIW:FWM]5U
M7_A'-.\/V^F7:-+?".TM;6\LKF1KT?I-JMAI^O:?=:/J-E::E9ZO82Z+JMA.
MLLD>HZ9=$I/I\XCFBN/)F1W@_P!'GM[@1R,(IXY=DB_CYXT^#$W[.MYX@USQ
M#/K?BCPQXL\=V&@>%?$NB2S76LVGAK2]`TJZ\":C=:7:VY;3_$'AY-=\0P1W
M6F6MM=WDFGZ7'IT4-Y'-)><_B3*&;8>>3K$J67U*:;C)KV<?8I2I0<DM$I))
M:I_(^-\%>,8X3V&4NHW&DX4X4;[*\8\JZNZTWU_+^]I];N?%G@2-],DM;>^C
M@M()QJ]^^G6UM>SM#)>6&K7%I%=S6LT5@\WDPQ/'+>7"+]EG0%17A/[&'AKX
M4?#;X.6?PK\">/8/B->6_B_XF?$'Q#/JZ7VA>(M5UGXF?$;Q'XRUEKN'4;>R
MN=271=3\17FC:1?0&&(^';2P@EAO+U)=0N/S>_X)A?\`!1?2?B+XF\/_`+/W
MQT%E\//C[XL\+6>O^!CJ.M9\/?M"?"SPGJNJ>&_"'Q&^&FIVD3Z-KVNV]WI<
MVF^,/#*ZA9^+](O-&O=2%I+%?V-G#^]EQN6UN[J>.-+:2R<ZK=W<^FPW5CI]
MFK3[]3UN?3;;3+*QMU1KB.*37K.=$4M<1R$/7\J4,NJ1Q6,7UJ;J4JD$H3E:
MBJ<)1Y5'HTK7OK=)']A3ABJ>&=1T?8QQ3Y:/M5R.,966ETK;W5M5IKHC)U2[
MM+"'4WOM5TW1;'2K*34+_6M0,\&CZ5;V\1N91<3B=)ITC2,RW").))%C81,C
M%2/Y1O\`@IS^U!)^VG^T'X:_9HLVU:/]EGX+Z-<_$'XF>,-&U&:W_P"%Q^)K
MC3;F7Q1IWAFU26ZCM-(\':3;3^"=&NYK>YO;C7=3MXX+N>Y**/OK_@IU_P`%
M+_A/X<^%>H_"KX2ZO<>-=>\0Q:UJVL>-M)D>/X8^$/#OA>:WM=??3/$LMBB_
M$[Q+8VHU:<:?X,.J:%#>6T%OK.IV-M]HE/X*_LWZCJ'A*T\%X\(HNH>(/"VE
M^/\`Q&=9-WJEAH=]I^H:)K/@#PI?ZE]IB-V+'QS=Q_$WQ;963PV^M/I5IID?
MV.T%U;77ZYPSEV697%Y]FV,P34TYPC5E'WY*S44KI6;22^6EC\WXQS^EDF!K
MY;4UJ.C44HWUJ-PMRMM\S4MGK:S/V'\-_#+X/6OAW0+;_A`O#^A_9]%TJ#^Q
M4\->(=031_*L8(_[+6__`.$G3[<NG[?LBWFU?M(A$VT;\`K\U[C4=2N+B>>^
M\?>+;B]FFEEO+B+5KF".>ZD=GN)HX8!'#"DLK.Z10QI%&K!(T5`%!7T?_$5,
ML3THX%+2VVRY;=?+^M;?S4N)Y:?\)RZ='_<_+]/4^@9)IE2_999%9+6=D978
M,K""1@RD$%6#`,""""`>HKY"_P""H=S<:;^Q'^T5J>G3S6&I:9HWP\O]-U&R
ME>UOM/OH+XB"]L;N!H[BTNX0B"*Y@DCFC"KL<;1@HJN)O]PK_P")'PW@_P#\
MECAO^PW"_P#I^D?S3_M+^-O&?AS2/A#>^'O%WB?0;SP'\1-?O_`]WHNOZKI=
MSX,O[FS\/7UQ>^%)[&[@E\.W=Q>HMY/<Z0]G-+=*MQ([3`./ZKO%7QD^+WCS
M1?V!/`7CGXJ?$CQGX%\::K\(++QCX+\6>./$_B+PGXLL]3\2:'9ZE:>)?#FL
M:I>:/KMMJ%I=7-K>P:I9W45W;7$\$Z212R*Q17X+4_W?'?\`<Q_Z7(_T_P".
M/]VR3_L(PG_IRB;G_!8NVMK7XB?"?0;:W@M]#M/V;?%45IHT$4<.E6L<&KZR
MD$=OIT:K9PI"J(L21PJL:JH0`*`.7C_<:%X(@@_<P)\-]-V0Q?NXE_T&V^[&
MFU%Z#HHZ#T%%%>!Q9_R2F7?]?:/_`*<IG\H^,/\`R/9?XOUB8M%%%?!'Y(]_
MFOS@?__9````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V=R;W9E<BYJ<&<`````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S$R-2`Q,#4Q-30S-#$T-R`P,C0S
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MVP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`
M'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%
M!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*
M%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"
M`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF
M)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^(34/#UU9
M7$D322J\EPZ6D,\3P?:'G>-4\AI`OG,\A$2K%N+,Z@`M4$UGJML!#/"\,K*B
MB,;E?#2[4VH0&+O)&40`99@R@9!%?MS_`,$H?^"=6I?\%)OVH9?AYK.K7?A;
MX-_#S3?^%A?&GQ)8RR-JC>'1/:6MEX8TRYMXY4C\0ZY=7:1JVY(UTJTUNY4;
MK0LGZ4_\%_OV0O"7[!GPX^!7AWX)_#GP_HGA7XAZCK_AZ'Q?_P`(II6N2Z!I
MW@^W@7P]X9AUJ_99+'5=?35+F\:_E<W]];V6HW]E'+:6%[)#\AG]?`9;F]#)
M\)4Y\6VO;SK3]G"C2=G3<91O=M+5.RO:W0^[P,YXFC+%8E.-"$8I1I)2G+2-
M])=KJUD_/2Q_)?#K6O:4)D5[OR9<"ZM[@2#S/**![9PV-C#<K'(W*%((ZUF:
MMJLFKW8N7C-LJK';Q6>]I8<2*$=S(I(5O+=E`8CEU[D9_>/]C+]CS4_VA?\`
M@G?^V-^TE\2]#TN/P[\`M+U^+P5\1]7LRL]_>VGAF_U+5="L;UHH8=170]33
M2=/@GMGF27^U(LMO,*O^+A\+:A,+:\E@L].BLT,B0$`0QRX2*.&WW`&ZFF6:
M&ZF`+&W0*'`#@GT\BAFN;3QV"IUX^SPU_P!][5RHRO:]YM*SC9*4=;=^VN-J
M971>&6#6,Q&*Q7(L+A/81=2=16]ISJ*O&%[<KW:3/9O!7P>^-GPT^$^B_M+>
M'K34=.T<^)X-+T;Q5IL$-[/X3\F.[?\`M>YEDC>'1[HBW:RL;NY9)'FO8[*S
M#7EY;*?[0O\`@V<_;>_:?^.`^/'P#^-/B#6_B/\`#KX3>!="\1>"_B'KVG_:
MM?\`".N7VIQV%U\/K_76AB&I6.N6<\>NZ+8MYE_:1Z3=K(`&K^;+_@G]^WU\
M;OV$;3Q-H,WPN\-_&CX+?$'3[I/%7PJ^-/AG4KOP5JT$Q@CO)M*U/RDMX(KB
M,%)%D-S:W.GS7\,%O+J$EDR?MU\(/^#B[X,?"+X<7W@_P-^P3X5^%,,,L5[9
M^&_@_P"*?#?ACP3J%Y<[EFGU5G\$O/+J$098GU.]@U%1:FUM+0>8EVR>1G?!
MN<XRE['"X7+\;SO_`'A8B<7";Y>9)03ORZK=7;U>FOHPQ<,+7HRQDL3E\.2,
M:^%Q6'<5"44KRI2DE&3ENN;3U/[.Y-;L3(Y;5;-&+L63_A()8MA+'*^45S%M
M/'EG[F-O:BOX7M0_X.1?BI)?WTEG^RMX'BLWO+E[6.X\5>)KF>.V:9V@2>Y@
M2TAN)DB*K)/#:VT4KAI([>%&$:E?*KPDXN=G:'3_`)?3_N^?]6]+=O\`K)D=
M_P#=\<]=U2P]G\.J][9V?],ZO_@V>_:W^#WP-^)/[1?P8^(>K>"_"&L?'&R\
M!^*/`7B#Q//%H"Z_<>!V\1Z=J/@VPUF^EMX8-2OTU^.]M+$2,U[%8EEB<^6U
M?UQ_M&>)_P!CGXB_"76M,_:9L?@]XW^'$,D6NWNE_%Y_#EUX.M[[3(A=IJYF
M\4*T5E<V_P`MG97NG!GG:2:W59(9;A:_RCO$FLQ:AJ=KJH6VM39VMM#IMLFQ
M&7R%5)Y?E5IK9Y&.X7$(250Q`<)(P:W=>.[K5K2ZL[R^U6;RK=;;3XM8U>[U
M*TCA.UYH(HY;F"V6!GC5QY[O)O1%",'8C],S_P`-J6=YS6S9YI5H1JJG'EC&
MGHJ>ZYFT[.^C\NC/ALOSVK0P,L/'#4N:4G>KSSYK:6]WX=DMUJ?T6_\`!87_
M`(*=_"+XB?#O3?V%OV%O"?@KPC^S%X:O[67QC>_##PZGAGPIXLUNWO9+O3_A
MSX=TS2DTU-<\/0WME:ZOJOB%-'F'BS7(-#&GZA+865_#-TW["O[$?@WX5>`=
M*\<?$KPCX3\4?&?Q+:P:Y/-XKT&RU^T^'%K=^1<0>'O#NF:M;7-E'KUM9'3F
MU_4YX5F%]>7-E$Z"UNTK^?O]D+1D\;_M,?"#0=34WNCMXL@O9[2>$A;BTT6T
MNM7EMI;9`UN$E:Q6&%BQ=BP1,AS7]@>DW;C[4N\0M&L"7$L&)8XG9`)HV"AE
MC0F.W9V;:%)B#8\Q<XX^E1X<PE+(\NJ.,:RYJV(C)^TG*HTY-M.SNUMLNA_7
M?T:N",#Q%1S/C+.\)2QLL%C*>6X%5*<'"BZ=#VLJL5;X^:T7I:S;?1'87GFQ
M6O\`9R:3HK:8D1EMM-?2M-N-,M"8VBE+:9L?2[HS+,QVPP1K#&702)DHWX[_
M`+;W[!OA#7_#VM_$SX3^%M'T3QK;64^LZKX,T"UFTGPYX[G5F$TIT^$26T6J
M(TJR0R6;\E9(%C)G&/UJU#5A"(TNQ))'&N5FMVV7`W(0&@<G9&^TL0TGR;`P
MSG%>2>+-?LK>PE:ZOX_L\,<I@1=K(RS!HA]O9B0\B/*I::,^2N"K$,R@^+A<
MWKY6W-5I1C2E&U)SDXRE[KE-MW=YO=+30_J'BOPRX=XQR;%95CLDP2=:G3]A
MB:-"%/$4IU()^TA4BDV[V]V5DK66A_&)<^+/#EI<3VMY-J-G>6TTMO=6C6EV
M&M;F%VCGMB&4,#!*K1$,`05Y`/%%?N5XE_97^#6L^(]?UA=%M%75M:U74E"Q
M1;0M]?3W0`^7H!+@>U%?5+C>5E^\W2^T^O+_`/)?U;7^(JOT<90JU(1Q6/Y8
M5)QC^\Z1E9?:[)=.OF[_`(:>+M#\0>%M3N--\2Z7JOA[48+J[E?2-;TZZTJ_
MLX998P?/M;B*$11F5D6#@;PP\O<,UB"]MU4Q2QD2`9P1AL#'(4C./F&>.ZC/
M.:_4G]J7]H_PEXLUZ>W^,OP=UB"X,T<$.I`Z0+Q7A!)DTW6+15(BC5R6MKO)
M(9)'PR)G\F/$>HZ6^L:K-X7:[AT6ZOY[FS@NY$DDBB!"(+EL%I+C:WR2Q?N2
M@D'4KCCX>XU6=X/VM?!NG5Y(S:I2G+#IRY6X\[U]UZ2MJFK-)H_$^*N$<?PC
MCL1EV,]VO1J.,*=9.%2<+^[-I*UY)-Z:/?:U_IK]DGQKI?@3]H_X3^);VX:S
MLH/%=I9WLUTC-9Q6NI)+8327(X+01K<%WP055-Y(17-?UO/XE\+PW,42W!NI
M]25GM=220Q"6WN2)8CIN&$,,/EVR,))R?EVX.'&?X:DUJ\5E99S&8Y(Y!)$?
M*D\R*5)(_+F&#&Z2(DH(8$B,K_%S^P7[/'[?:3>%[+PY\1[TVWBO1DM]/TS7
M[BY>&TU?3(HQ`D=Q("1;W$*N@&XKYB))(22M</$ZJ58T,9@Z<92C"%HJ3:;2
M7,K[W7EHN_;^H?HM>(^0</4\TX8XBQLL%3S'$QQF7>T<5">,5%4JM.7,[*GJ
MI7WONK:G[[:UX^\/6CHD4K32Q*9HT&Z**XNX\0+Y\LA"W,P2:3YH"8R-QZ@5
M\M_$WXAZ#;:/J=Y=WL\D\=PD@MK&17>W)+(3%(K,D9CE>-'>;$2;]C$.Z@_G
MSXP_;"TRU>9=*EBN88+B*-3#=7-]'<2S(\S3VTC`QR1KY95FC9MI8#H37PC\
M2_VI-4U"6Y:SEEAN9;F\(C\R0*YD.%CGC8_)&P/FJ2/OQ)@\XKXFEA<SQE64
M:U)1IU>5N7-+36-[7Z)]?S>A_4?%_C)P=PUEU2>'S;#8S%P47"G2J1E>I3@H
MJE[C;LM%=6>_0_0F;XYZA#-+%]JT<>5+)'BX4M<#8Y7$[`@&;C]Z1P7W$<45
M^'$_CC7[B>:X?6=3WSRR3/@RXW2NSMCCIECBBOHUD\K+1;+JO[G^7Y]C^0ZG
MCWB)U)R6`E:4Y25I5?M235OO5OEWT_8O]MJPL7^&NHNUE:,\"(87:VA+0EK"
M?)B8H3&3@9V$9P,]*_#/30#I]ID`Y=\\=>6ZT45X7AK_`,B3%_XZGYTSD^E5
M_P`EOA/^O6$_]N+DJJ)R`H`V=``/[OI4P=U:`JS*1(A!5B"#M;D8(HHK[M?[
ME'_$_P`XG\T4_P#D=9+_`-A%;_VTZ&&\O&=%-U<E0P(!GE(!VN,@%\#@D<=B
M:YZ9FDO29&9R;@9+DL3PW4L3117/1^%?]O?G$]G'_P"]3_["W^:.F6./`_=I
MT'\*^GTHHHJET^7_`+C/I([1](_E3/_9````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W!U9F8N:G!G````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S8R
M-B`Q,#4Q-30S-#$T-R`P,C,W-#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1
M"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<(
M"0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!
MD:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I3
M5%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6F
MIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T
M]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$`
M`@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S
M4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.T
MM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`
M#`,!``(1`Q$`/P#Y"^#7A:]^+'B=[&V%SINA:<X;Q)KLR0QG3+3RS'##;$LL
M=]=WB136FFV<4$Y>4KYH2)+EE_4?7-%T;P]\/-"TY5^P65O8K:HKK@6]I;SV
MXM))&9T5S/)<-<2NHW--,\LA,KN6_!K]DKP%\?OC#^V++I_@?XH^,O`/PA^%
M47@_Q]X]M-/U?6)?".O:;8+9WUGX?U70;36['3=8OO&6IWNL>%+=M0AU%_#]
MC>:UXG>PN;+2[NQD_:3XD76H?$+QQIO@[3)FN)]6EE@L8//FBL[6&PLDO[Z4
MVD2K;3+9PV<L\?FO!%&((1"Z1-&:^LS7!+`9%0P&%IRJYIG]&G[.,+<]*C4Y
M7&3J+W8N5](N2:Y9.5EJ<V`K8NIGCQ>8RE@L)DLIR4*JG2]I6]C&:YZ511FX
MRA*-6G))TYPJTIPG*,M/RG_:EU[QEK?[3?A'P1\"/`[_`!+UW5/!KZW\0+6Q
M3R%TJWGGDL_#NHG5]0O[#1=+>>'1)8IVU>Y"7K?V=':_Z;)"P]YT7]F#XK2V
M,-SJMMH&FW(B+7%I<:N+B16E7*QE;*TNK;<CJQ8P2.%9=P.Z%2/T@\/_``HT
M3X;1+X=T"PL;KQ3K%T+CQ!XFATJ&VUCQ-JT7R64FHR22375U'864(TG1XKR\
MGBTC2XET[3!;65LD36=?DETXSVY"-]FF$:F..)B\22`3L&VD2R,&=I&9V!0,
MID*228^2Q?#>"R;"87"XVI.IBZ>'2FHRA&\H^_/6\G4:<M)1YER*#NCZG+>(
M\1F>)K8C"*/U:O74X.=FX4W&,*4HQ3]V,G!RY9)/GE.Z5['Y,^-OA5XQ\#(M
M[X@TYY+`O;11ZG:217EJMR[7CJ\H9!+;1"."9_M$MFY5C;X<F1(:\Q2**.+)
M:9YXS\PW,5$OD?NI6C9A.J^;YFTM'ED8/"JR"7'ZXW6GVVM6MW::A:0SQ3J;
M62UO$2[@-L(%0"2%PT<P>X8J6EC*[F6,S,O7\]?CC\+[CX=:O;ZG8213>'-;
MU"\%L$AA@BTFZD$DD>E-&+JX)C@LTNYK.=4B`6SDC\JW,&^OR[%XB%#%*$8R
MA"K*:IN3CI*.O+?X6^L6VMFFFVC]0PL)5L-)[5H1BZD-.5/EC)<O;56>K^*R
MZH\E%G&P#`W0#`,`H$B@'G"NJ%749P'!(8<@D'-%48]<41H$U*R90BA6,FTL
MNT88JL#*I(P=JLRC.`2,&BK56D[/EJ.]G_%IZ_!_>ZZ??Y%>R_Z=S^Z/E_>\
MOZUO];?L!7$/@3]CD_$2TG&I^-OC+XLUT:X+1H+'^R-*^&\B6>BV.I705KV:
M\EU/Q-XCN7W1""*S>P*[)"!+Z9_P3&^)/B']H'XD_M5?$KQ)H%@GAKX:^(]#
M\`_#1V5KM%CMKSQA8>+-6L];O8D,ESK#R:`\YL&B@2&QCM4,T<MO.WY7_LO?
MM7V'PX^"%S\&O$-EJUP=*\0:]K/A+5='M;-HKJQ\42F_UVUU)M2N[*XMY7N[
M>.>UVP3O#YT\:&VA@M@_[<?\$=_@G=_#7]C(WEW.L^H>//$_BS6;Z\*S(+E;
M'QCK]@'<2!$#E+&!&,$4:R3QRAB"6K^H<@HX;&/+:O/&O4PF6895(M-SHUE2
MC&:=V^63Q#G-I]).UFTC^=O$W/,3F'$O%.:-2IX7,,^QE+"W2C2JX%2AA\OC
M",8Q2IT\OI4*=H\JBH02BFFG]/:M_;4&O7^O6]HT*^5>16MY"DK0A[6P%O)`
M)ED5#<RVLY=M[,\;,,A!E%^%?V?]+^/&NVGB[5/CGX?N/`NHZAK]W=Z9H6H>
M.M#\46ZZ0VF>'_)N[-/#^KZU!I*2:E#K#0:")(9M.,DF862:"=_O[XJ2QV-M
M9NCN9--DN3;Q-Y8"+=R,EU,T84'=+&N\^:)-J[(TV!:^`OB-^U9\(?A%XH\`
M^#?B'>>+/#FH?$&36;FU\6W6E:5+\.],6ROM%@33-3UB37/[1LM4#:DUQ+:0
MZ'-81:;+9W:W2N;BW7PN+LMP]3'TZE;FE7I4HN#@VDHS<U)V6EGS<LE;50:>
MNI'!N.C0PKQ/NQ510P]Y7E%.A)NW*U;52M&3:=W?=W-/X^>/?%/P4^&_BWQG
MX0\"ZA\0=<TO1X_[+T/2]$N=9DN-4U'7M/TR.^FM[*(ZC<V&BV[W.L:M#!/:
MRG2K2Y<7E@-]VGGOB'5+CXO?LHZ1\2?%NDVVF>(+WX7:;\4KO3M/M+AHM,U>
M#PE)K=W'IL%W)>7UO%<>;.T-FSW5Y';R26HEN)8U\SV#2O'WP[\6:G<6W@WX
MK^`_%&L06MQJ[>'O#/BO2_$.L'1$G@E;5FM]$NKC[!;+<75M$YGDCN(9I&MY
M+>%I$:&]XMN3J/@3QII=R(6C@\'>(+7+KY,3-+H-Y#(DDB;)BH64,9&+3'>[
M,'8`G^;N*/\`9Z].FJ$J;H5%*G-W;JPE:7*[ZZN,=59JRMHVC^A.&52Q=:OC
MJ6+=:&(I1I*E"5Z5-Q46Y;VO=I6O+XF]&?B%#XZ\'M%$R^(;Q%:-&56",RJ5
M!"LQTUBQ`P"Q8DD9)/6BL&X^&5@;B<QZY?PQF:4I#$\;10IO;;%&QVEHXUPB
M,54E0"5!XHKSUB<M:3<L7=I-^]/=VOKSKSZ+T[^L\#F-]*E"U]/W?2\//R_!
MGR]H(N-`\6)IMW;&U<:G?6=S',F^X@F`D>;<L3JC>7(Y6)&>1&=W:)V&V63^
MPS_@G5XDTW5/V,_#.DVFY3X,E\>Z/J".CK''<W/C#Q5XBQ`OFS&4RV6MVLD1
M:*$"9T5U`1I:_!3_`(*1?#W0_AWX,T#XFZ+91P^/)O$NGZ%I?F`/:ZM'>1Q2
MW-OK*VZ0"4P65K=-'/%.DD<3SKA(W:W?[3_8KU^Z_9+MO$7A[]HCQ)I_@2R_
M:K\/>!_%/P@L-8N);&;1-8\$^&FO?'FC>,9-1M+.W\)7<)\<^'+;2&O9Y([R
M^4:;->1:J\=K<_V?P3D..I8O%6@IT,51G%3BVYQGAG"LJ;22O4C!UY--JT8N
M3NHV/X\XWQV&GE^'O4Y)T,92FXI12M4Y(N3MM[]2BV[:*HEV;^]_CYXEM[:X
MNP?."0[$FC5-T1;S&:UD0%UE=5$@1\E&4J3N<2`)^9?QA\%Z#\8O"3>'/$%C
M:7<&FZI!K>BW=[;?:H=-URRM]2M;.\:!\M)&UOK-[:7D"C=+IEU?0P26\]S'
M<Q?1/BR[\0>+$U$Z5=:?XBM=+-V^G7)UFR<7^F>:(T%O>SZK'975K!8I&(+B
M&98Y6B2*&64RQ)-\P7/C2Y@:2'5$CLF#SP2HZ/&[-;SF,1JKW#2!$<M"VQ`L
M;>0LC(@`7Q..\OQ*J*HZ-;V,J=2$;1<>;F5I1;337*VVGNTM.K/J?#W,HX&6
M&JX>K06+PN(P^+HN2IUHPJTY1K4INE5C*G47-"TZ=2+C).TD]G%^SS\%_A]\
M!K:]A\+:-I#^(-0N96U?Q)!IL=G=SHUE8VEQIUK.OFW]IH9N+".]33WO9LWL
MSW,TKR\CZH\6:NMC\-_&4S1,7GT+683*SK*IDO[06EM&C!\.3//O$8*JD*8W
M;P$;X]O_`(R>&?#<\%QK&M6EK;JD495%N'G21WE"(UK;Q2W13*.IF\K[,`'`
MD!*UP_[0/Q3\1?$KX(>(_$/P.?2_%5O\*+"X^)WQ!N3<M;:;IFC^%M`N]:AL
MM666^L+R=)(8+C4KO28);>_N;;2FDBD^UM8V]U_.?$63UZGL_91;UC",ZE5V
M4ZCC3IQG.2;@N9I/?=*VJM^_Y5GD,1BL5BZ\L/"K6G4Q>(]A3I4(2;?M*WL<
M/1C"G%VC)QA!16B2M8^?;O73#=7,*7<R)%<31HFZ3Y521E5>;9C\H`'))XY)
MZT5\9:9^TSX-U#3=.O\`6K=X]9O;&TN]6CL6NH[)-3N;>.:_2S1VG=+5;IY1
M;H\TS+$$5I9""Y*^>_U(SY:>TI:65E*ZTY5O[/7U\].E_4_UNR)ZK$3L[/71
MV?+NN;1ZO3II\_U;_P""N9)^%OA($DB/XF0",$Y"`>&_$1`0=%`(!`7'(!["
MO7O^#@R:6#2_V,KJ"62&Z.@_&W-S$[1SG_B8?`=>9D(D/RNZ\M]UF'1B"45_
MH'P?_#H?]AV:_P#J#6/XNXE_WNE_APG_`+B/YN=.\<>-=)B8:5XP\4Z8%+E1
MI_B#5K,*7U2;>5%M=QXW;FW8QNW-G.3FMKGQ-^)$L&MQR?$'QO)'Y\B['\5Z
M\Z;3I]R"NUK\C:1'&",8(C3/W%P45Y?'7^YQ_P"OU3_TE'N\-?[[#_KQ'_TI
MGE3^+?%5QHMM:W'B;Q!/:R2+<26TVLZC+!)<.C[YWA>Y:-YFR=TK*7;)RQS7
MZW?L-W%Q!_P3W_;ENH9YH;F\TOXNV-W<12O'/=65G\!K>>TL[F9&$D]K:S7E
MW-;6\K-%!+=7,D2*\\I8HK^:^(/X%/\`["L%_P"I-(_4LD_WN/\`V!8[_P!1
MY'Y%Z7;6[Z9ISO;PN[V-HSNT4;,S-;QEF9BI+,Q))))))))S1117MRW?J_S.
M`__9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W1R:6XN:G!G````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,#0U,B`Q,#4Q-30S-#$T-R`P,C,W-#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_]C_X``02D9)
M1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!
M`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0``````
M``$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^,2RTP:WJ5^UH"EI`ES?!
MV01JELLRK`D@C5H8FD\V-5080L"J,%'/O_P5L;7_`(2&U5=OGK,`/G.=R17(
M!^4\':2>!WY`Q7!?#>WL!9>(Y]0,L6C7XM=+:]>*.)P3;WMU&L08O$DYD^QR
M@?:`D4QM4D5T=9XN@^&NA>/=4\:^&-#^"OAOQE\1O'FLZS!HVE>#?#/A#6O&
M6MZUK-_.]AI6DZ'H&@V<^HZ[J>IRRRPVFG6(>YN+L)';B60!*PXSP;KY9#$1
MG3]OF-/%3J05E*E-U8J#<%\-"49.%*K=J7)*/2[W\-,1A\HS3#UJU*;PN!K4
M'.HW"551C44)JDJC@ZM:G*+G5I1DI+F3BG>R_KS_`&0+V\0Z+(+5$CCCMXI?
MDD,4S0PA)1:'S!(3"P5)_.)802PR1J'%PZ_O7\)]2E6*T,`CF:2.!)&79*'/
MDPF0JP"[A%N=<`!BBX(:0#=_)_\`L)?ML>%?%4D7A#7+7_A$_'FE*%?2IH_)
MAN=5^Q6]E=#3)+N_-W-.\]X62SE2*^:%YVF@BC*O-^POQ0_;5UG]EGPW_:$?
M@OQ#XEO+*W.HVZVVD11:'9LRWESIS^(-?O=2L]/T'31)IH75-0U%XS#"9KN"
MWOP3$W\7YQ2K8#.(TJ].IAZ[K0Y(*-IZR24J=[<T9):-6YHV=K'^H%1X'BOA
M>AC<LQ6%Q^#J81ISE)VAR4DYPK)7G2G3EI.FUS*U[-,_:/QK%#J&B7:W$,+-
M+!*@:2"&4QHPC5]@N(Y5!*\C?&Z$A"Z,JA:_@^_X+R_#.V\#?'+P7K&G:$]E
MIGBOP]K5_+-IZ016E_XAM-4AM[][2V6"T?SQ'<:<UV8V%K(EW#"EL]Y;:EJF
MJ?L[^S__`,%#?VE/VPM6\/3:Q^T!^S'\`_!<FLP:3JEUX5T37O%/B<ZGJ0F@
MTO153Q0=3\`WMWJVM6VDZ-;6EQJNFZ@8?$L4FE:;J6M?V5I5UY#_`,%J?@;K
M7BW]E_P7XYG>R\::K\./B5JMY)X@M=*FTZXU+POJ6FW-Q>ZL+1[F<6-Q/'I-
MMJ.IP:2MK:M/913VL<%I8V^FVWKY$JN2<=93C:V)HJEB9SH5E.4HU>6M0JI2
MJ1G!14U*TGK))Q:3T/R?/<AJYAX6\09/3A.>)Q."6)RZE2IUI4O:X?$TVJ6&
ME.G%5GRT91;@E*/-[T6GK_._X)_X)5?MS_$3P9X1^('A#X#>,M8\)^.O#&@>
M,?"^K6^D:H]OJGAWQ/I5IK>B:C`Z:>R-#?:;?6US$RLRLDJE6(()*_OU_9@M
MK/X<?LU?L\_#PZ;8RGP'\#?A+X,,EQX<U&>XD/A?P#X?T,O//%?V44TSFQW2
MRQ6=I'(Y9TM;=2(D*^CGXT9Q&I.-+#8)TXSE&FW33;@FE"[]CJW'EN[]7\O@
M:/T?\C5*DL2N)5B%3IJNHXC#J*K*,%544TFES\Z2:3LU=+I_G8_$SX2:C\,-
M4\>_#S6;@[M%\5>&;V"[*6BR:CH7B?1=1ET_60ME+/9HMQ:VVGW;6T!:6RFN
M7L;RWMKFUGMT^[_V0_V>M>LKC3?$^J-X5O/`=FUEJPO=:^'7PV\5VFH!1JES
M`NLZ3XWT/Q6NHP6VIO\`9X[:YLYH&0NKQ>04$??_`+7VF0W_`(0TN=M%L;E7
MEU+26UR6*T:_TM]0@WZ=IMO++ONT@N[WS;G$,26?VC3X3/<VMQ-9I<>*>&OV
ME=/\-_L]3^"+W4K>TUO3K6WT^:%II?M4S6NLN=C1+;2*#%&L>[:Q\SS&D&=C
M-7]L?2U\.\7X6<<T<FX=Q.,KY7-4)9?45*M1KX3!UZE3%8'#0KP<>;ZCAYK+
MX8RE."KRPE5\D*GM*5+^2OH%^(N0^+_`5;BSBZAEF"S:A1QD,PHXJIA<7@<R
MQV`AAZ6;2Q6#KNI"%+,\11GFWU2O3E'#K%X:FG4A[*I6YSX%ZW_PM[_@I)I'
MB/2%^VM\1_V@M=\0R>2UR#K4FOZU?ZAJFIR-J#I<0KK5VFHZG+9JUO\`8TN&
ML[&"VC2UA7^S;_@HG^R*WQV\")=^#+1K3Q!X/U73KRTU)8]%O(#H<-I)'#!J
MNF^((;FVO--FN[F!KY+,V>HR&*V"ZA96=N)HOX9OV%O$VH>%_P!J_P"`_B;3
M%9]3@^(FE16X1#YF-1E&GO*6".S^3#=7+;6C.5\WYHR[.O\`I#7OBR#PY-?2
MZJCW-A%I]Q!K;SR7$0M/-$;"[O"5N'2,QNLLMQ,"EM'+YDDJQD&OX6\172I9
MOE3Q$6E2P="3K/64/92KQO*5^:<^>4)-W;?LUIRIW_NGPJQ^:/+:F;993H3=
M;/.(7_9"IPIX7%0QBR6I.C[."5&'+AZT\/AU+EI\N(E!QEKR_EY^RG_P35LM
M,T+0Y/BAHFB:['X.\1:1XA\.217'B:74]!.FZYXMUZ&S\#ZKK?Q(\7#X9:1-
MK?B?6-4\4Z5\,K?P38?$2>_NXOB)8^+O,CN(/JG]JGX-^'?BW;>$/AA>V=M#
MX(\/:_:?$#QC=GR?LVE^$_AG:ZAKUW-<&_N;,-::CJ,&D^'+[=<3NMAKEU=R
M6%_';31I].Z!XXTC2-+U*VTVX6`O$ODK;W#SQL)#.[-N*SNZ,LSM$JRHL990
MAVJJK_-__P`%M?$/Q6\6>(/@!X#\.^)-?T7X;^*9?B1=?%2PTO76L-+UNR\/
MZA\.]7\*+XHT9;B$>(+>74[/48](TR]M+NTCU$W5ZX)M94.G`?#./\6O$'A/
MAG+ZN9YIF.9XB.'Q%:A2]O5PV#I.I.K+#1I*]*E0P2K5ZM>K)4*%*+G4J4X0
MDUAXA<74?![@OCOC_-\'DN0\/<-8+$8W*<NI4L/E5'%8W'+#X:G/$TJM.FL1
MB\7CJM#"4(I5J]?EH4*-*?+3I/G/'_\`P5"^/TWCOQK-X#\0^$;GP/+XM\22
M>#+G6?!%JFL7'A1]9O6\.SZLG]CQ;=2ET@V<E\OE1;;II1Y:8V@K\W#JU\"0
MK6!4'Y3)93/(1V,CB\4.Y'WF"J&;)VC.`5_O!AOHV^!6%PV'PR\,,CKK#T*-
M#VU:KCW6K*E3IT_:U7',(Q=6IRRG4<8Q3FVU%*R/^=W%_3!^D5BL5B<4O%/.
ML,L3B*U=8?#JC"AAU6J.HJ-"#RR3C1I*7LZ47*3C"$5=VN_9_BAX*C\=^`O$
M>A`*]_/:B;1E,EK$W]MVA-]IBK+=8CM4N[FU72Y;]GCCLDU'SII%CW!OPV\8
MZ+>6WB'5](U"SN;&9;D0:E%>Q&S?3+FQ*)JB7L-SY+07<=S'*DD4ZPS+<AD=
M&EW)7ZR_MA_%;4_A7\"O$<VA7%QI_B3QCJ6C^$="UG3KB2UU70)KS[3K%YJF
MG7<-Q;7=E+%I>E7EJMY:.)[6ZN;61&(!CE_(JRUW5KZSBU:YU?4M0\1ZA;S:
MAK%_J]_<7EY>S:RUQ<O=1W,\[WM],J7DPOB[S3+)%#,S,F77\9^GQF.08SB#
M(,HP4:KXHRW)88C,:T:D?JSPN+Q&+EEV%G2LZBQU",,3C(U$XP6'KTTTY2N_
MVW]FSA.),'PKQ)BLQG2_U2S7.)K)\/*E-XEXS#4\+ALVQ$:LFJ3P.,YL-@U3
M2Y_K.!JR4DI34OO'_@GC\$_A3X[_`&AO"UWJWQBO?`UGX=@U?Q+H@_M'P]H?
MB#4->T+3DO=-TO2FU:2>'4;V_P!1E\J#1;6QAOM5L[6_2TOK5HI[NT_N8^'W
MQN^%GB;P3#XD\4>,_"NI7FH^'4M/$NCWVJ:+*]A>?8[8:C9:CIEQ?3W%L\:V
MP-W#.9G9;S>T+)<6JQ_PW?LB_LJ:YXVUW3=>TR]\*7[WUA;7MCI::I)IOF;I
M5-O>VFHV0M;O2IK.XE^VI.)D2XN-+BB5+B86<D?]9O[)/[*FG_#/P[H^M^._
M`>AR>,;5-9MS<7D>@Z];6TMY/8F;4HM5\W5+C4-3OC9W#)?&>V_LZ"[N+"VM
MXA<7\U[_`(Q^(F*E7S)Q^NRK/#04*<90IR<)--5(WBE)Q3;NYQM>]GLG_P!"
M?AYPIPWA/#'#X_$XRIE.<8S$SKT<IP5&HZF)<II1:Q%=N%&%54<*W.DY24*,
M8I<Q]Q>'-.L)HWCL;J.[L9W$-I>2&)GD2*:6)A+*LC0%T9##YB2+`"A(VQX`
M_F\_X*0_%+1/B/\`M%:CI?A;4+K4-$^&OAZ+X=W!F93IDWBW2-?\1ZIXGOM-
M2.5O])MY=6L/"FJ33002?VAX5N80)+>&WDK^@#XP^&?&U]\!?C/X9^$E[<:%
MX[OOAKXTT7P5KNA7KZ5?^'O&'B'0=8M?#>IZ7?6<MI/I^J6^M7UK=V=]93I+
M97$27TDD?EAC_#Y\`/B/XL\;/XZTKQM>:SJWBC1-874KS4?$UY?W/B.^D\0:
MG?OXA?5I-1>:ZFO=/UI97N;F:47&=6BM;A7EMI)I/ZQ_9Q4.&8^+^.QV<5JO
M^L$.'\PPO#-*-H8>G6Q=*O5QM2O9\SJ5,KP.*I86":IOGKTY*4ITT?YT_M.\
MVXLK^"=#+,IY*V18GB/+,1Q54J/GQ4\%EE;"+`4*,HI4U_PL8G`8O'+24%3I
MN,5#G</>=[CLOYG_``HJP;1B201R2?\`6-_\117^X>O]/_@>O]/3_G\4Z6GP
M]/T\_O\`GW1X!_P4KDD7PK\+(5=UB?Q'K\KQ*S"-Y%L-.C61D!VLZQR2('(+
M!)'4':[`_GSX39AJOA<@D$O;J2"02K[4=2>X9&96'1E)4Y!(HHK_`#0^FQ_R
M?#//^P#AG_U0X0_U4^@G_P`F=X;_`.QGG_\`ZT.8G[R?\$E?FUB#=\V)D4;N
M<*EUI[(HST"D`J!PI&1@U_7QX?9O^$'\.'<V3!;9.3DY6Y8Y.><MR?4\]:**
M_P`G^-O^1UF7_7I_^ER/]QLC_P"2!X'_`.P:E^<C=\%`/\.=&+C>7BO&<M\Q
M9O[7N>6SG<?<Y-?P.:Q^X_X*)?M5QP?N4?XO_M(0ND7[M'AC^.+LD3*FT-&C
M1QLB$%59$(`*J045^_\`T%_^4A^'/^PC#?G7/X/^G=_RCSQ[_P!AN9_^F8'O
MB]!]!_*BBBO^@@_YWET^7_N,_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V%V871A<G,O:VED+F=I9@``````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R-S<W(#$P-3$U-#,T,30W(#`R,S4T,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$O`#``]P`````````S
M``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,
M`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S
M`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,
M,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS
M,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,
M9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS
M9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,
M9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68S
MF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,
MF<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,S
MS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,
MS)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S
M_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,
M_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S
M__]F__^9___,____^+\D````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(?D$
M`0``V``L`````"\`,```"/X`L0D<2+"@08(`$AY<R+!AP80E(D*96$*APXL.
M`4S<R)$B`(P@'W8<N?%CR)`:H40$4`4/GBHE5)8\"3)EQ1)X`)30HS.E2IH7
M=7J$@J<B3Z$4@39$.I&E'P`O(6XLH91A3(Y.5_BIHO,J%)-5#?KD6$6/'I42
MFX8].)9CVI%@UPKL&K&NW;LKY0Y<(;,NR;=YY8XM<>"`UXD(6+!`X%:OSQ*+
M"U\M@:`P@@>,9RY-&!?A5!J!$K)HD7@%YP,LO'[40\KD"H2<XRJT>:"%:0`'
M:(`^*MJK0#W)JCPAE2S/P-A@9^M\4F4%"\X(6M!`@)R%X8@"GR1+!KSX<>38
M+/XF[$XJ<>$6>JH<J$Z*E&F!5;8#?PT[_,?9X;<3U^.<?.7U`(Q&G'L"K4"<
M?D_,Q9E]RN47W'80DJ*=>XJ-9M9VMR6D7WL,)M<@`,F0TAV$W$&87G=5$,?5
M0"$NN*!8LP$7'XDTTDA*?+?!IR"#,(*U`G<SUB@DCO;55R1LLLDXHI`1EF62
M;!;!*):,*3()816>)#C70YTIV&5X\=T89(UEK7@D1E$^M%.(551)8IE/IGG2
M"EHJ6`*6(J979G-Q?@D2<4\\89I67.E4EEE\&JD4`!.Z=X`?J*!2!0M0(&#I
M>CWZV="$0,84J:2ZZ0;!<VS)B9%V\JV`&J1^D*287MX$L;9=6LZ%:FL+7VFJ
ME';JC8;K1BW\"H5U*<+*8C*FL0"!;L'BJE@++.AAC35F&3O<"GQ"8>L#%:VP
M0BFKK"*M'L:&)^T30JWTQ"K4ELDNN>4^,>TJ@F++[K36T%O*M._!RA*^``><
MK[P\04'?6@"L(/"\X0(L'$PQ';RH2O?F*^X*%25<UBJEE!((QFJ5BM^6<S75
MTUW?0225P6C>E]QA9-7Y&$=/^-'RF=BL4)1=;=89'LQWHN(S0_>%AQ`>?B2M
M=)?88DPGJ[H>9W1G"=6,[D).H<+JU>4&5:^F`0$`.P!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M87)G92YG:68`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-3<@,3`U,34T,S0Q-#<@
M,#(T,#4T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`
M,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`
MS```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S
M`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\S
MF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S
M_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F
M9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9F
MS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9
M,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9
MF9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,
M``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,
M9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,
M_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_
M,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__
MS`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````A^00!``#8`"P`````(``@```(_@"Q"1P(
MH*#!@P@3`AC(4"")`1`C2IPX4<#"A@,?4MQ(,0#&A@$XBH0H@,1'AR-'6CR)
M36/*C1Y98@NY44```1!OVB1I\B0)G!0%K!BE`H"*449'W030\^3-B4F;$1TU
M%>E*F3,E!J#J9-0*HT.]&L0*@*(*J4]87;O&:H4*5FW_-/WHDN31%6K7LEVQ
MEI4*K#.!#@CPIZA>O7BML&(*F";$HV^MZ&T+E]5<GQ(%W,V[%^QEIT"CCDK+
M]LFH9E(_.QT`X#1JJ6Z'OB9*XJ],C49?HW;]6L71U+<AMA[E9/?OV:=I8WT:
MX'A1W]"9DE#]42>)WKRI4K]=4/=L%=L!35_WWLPV8);CO8<73X+WZ^GGZ4*J
M[;X9"3;K?9*`-!_R4<;Q833=?I"HP%]1^`7(D&Q$^:><@@.=1=YN^7UT5'VS
M50A2020PI=!%)P4$`#L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W!I8V%R9"YJ<&<`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S<Q-R`Q,#4Q-30S-#$T-R`P,C0R-#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#^F7Q_]OGL--UJ33KK3I]+UBT,ANXRJQV]
MM_'YL9<$/SGY?E]6ZUX3^VK^T#JWP=^&WANS^&.GZ+XI^.OQJ\1Q?#3X!>#+
M^:`&]\?W46JZY=^/?$<<<=Z#X&^&_@;PSXI\8>)=0NTL[>%;+0=$:>VU'Q7I
MQ@^K/BUXH\'>%?`_C'Q7X[UN32/`GA;P5K?B?Q/J4$5V+?1]-\/:-?Z_JE]J
M4]G:ZK]D%MINEWLS*4?/D@;@6K\BO%'Q'^*OC@^-_CKX\^%S^#]7\)?L[0>(
M/@W\-;9_'Q^(.C?##XH^,M>U>\\/^,-7>Q\FR\>_$+4_@S\.]1UU-,TV6Z\*
M76G>$](U][/3_$VL0VW^>>+QM/+\M>8U:=:O-J:A*%6:]]QM3;L^7D52W,DK
MN"E:2;37]EY+AGFV8PP_+"G2<HW3A&S2E'F5W:5VG;LF]5JD_I;]ECP?H/P;
M\(WG@VSU2?QSXR\:3ZAK/Q?^(WBB*5-6^-/CV>^NWU+Q)XI^U>1-?^&TUG5-
M8/AKP9IVI::GAF33;'P-_;NI:/<+/!AZ_P##W3/V7-9U/X]?"74M<TKX(SZG
M>:A\;OV>M(\-ZIXG\,:/IOBG4+B#Q=\4O@EI>FZGHOBCP=JOA?2;6_\`$_Q"
MT?P9J&J^'?%_AWP]XJU+1]&\/Q:/8R:W^5-E_P`%#/B+\$OB!X=TC]I7X,>$
M=*\"7.E_#<^-/$7P@\27FK:A\(]?^,_ACQO\3/"O@7QCI/CF#PX-,^(-CX1^
M'?BG6_$FB>'=4\3Z5HFN^&;2_G\1.WBVRMK7J?A?_P`%/OC1^UM^U=IOPP_9
MPNO!_P"S]\-V\/:YXN^'GBKXM_#WQ%XGO?C_`*AX?NM2U<Z'HVL?VIHOAKP5
MX?\`$4?@[5O%_AG2X+Z?6(M=\.7^H6ND>+YO#^FS>&?BLBR3Q7EF+Q^(4(9:
M[UN5UZ-:+C>ZY9P<^9.VB4[)-R:Y;M_0\497E6`G[++H4U5E&/-RRE%.Z2;:
M:G9J+;344[J*;2M;^A7P#XDT;Q7IUGK'@G7].\7>&O%^G:;XM\):_H^M:7K^
MB^*=#U&SLHTO]/O-+N[NX\2Z4_VT>';6;4K6?6'\#Z=J5C>:)I]W9KJ\^CJ%
MKJKQ2PZQ*@8PW4-NO!^S_9OXO/R/,W],;4V^K5^=/P9^(T7PL_;@^-GP.O\`
MPP]G\/OC5X^^%GQ&\-S:!XBBO=#\._'+QY\`/'7B7XC:<VD^(-:_X2#Q+8>+
M=`^#OB>^@M=-\,IH:1?V[K/]D:)*)[2+]4+ZPL;Z,PR>9<1?Z5QDH_\`I/\`
MMC)^3I_M=\5^G4YXJIR8N=237JDK)V:5DD]K<SNV[W:V7Q&&BJ&)E&I"-I<N
M\$I2M&.ZU2:=W:-DM7:^I@QC26CC9Y&W%$+?Z1%]XJ"W?US15-?`VD%5)CF)
M*@D_O1DX]/.X^E%>DLXH:>Y+I_R\G_=\_)_=]^5Z5]GO_/+^[_>\E]WK;G?B
MAX'TCXB_#;XD?#[Q58Q7?AWX@^`_&O@SQ)87;WEO;ZGIOC/1K[0;DW,.F7=N
M9!:Z;J=]#Y8=#<>=D26Y4&OY@O\`@FK^T!^TMXQU7]FSX=?M":?XHU+[7\"_
MC/J>@>--<AT/5M%\=?"J_P!1\`2>!_%<VLZ;?WUS<:EX#\>_#>TCUJ?681J&
MC:A^T'I7AWQSIA/B'2]2G_JSGFEBMQ)Y4L4?D^4P@")N_P!K]Y)-VZCGZGM^
M&?P'\'^*OAE\=_VU_`GB#P5J6B1:%\;_`!U\1?!&LW-S<:;H$OP>^.=[H_B7
M3='^%=[::[$8K+P_\0_A]J_A3XKZ#IEC;Z?IFN:]X3\6ZLOBU='\,>'=/^!S
MC.J&!X-XAI2P7UVK@$IT)72E2<K4ERW^-<]6,I1Y92:CSIPY'./UO"U%RQZG
M.JJ-3:]DG92BKJ*>Z3T:3=[):\J?A-SXBF\;_!OQC^Q!<?!_5[_]H_QO^U5\
M2]6\<?%#XJ_"V\71_A[X&\:?%C6;.;]H5/$/BG2[NTUWXE_\*.O]*^&GPR'A
M:_\`^$P%Q'8ZU:W=OHV@^)"_UO\`LO:%\=_AYK7AW]G70/%7PLLO@1^R7X_\
M4V'AJX\W6]?^.OC;P-\3?#7Q&'P,T?QA<S:7:Z-<6<_A#QI)J3^++<:?J_B[
M5O!VFZ)K$ZR:CXEO]6X7XA?M!>&OAC^TE\&?@M?ZY#H=EX@T:_?Q+>S:3IUE
MX,@\<^*M1GT/X!^"?%GB8:EH1\`R7NL^$?C-XI\#7%M>7OB77/$7@N+7M)DO
M-6UG4]0O;/Q(\?P:;^W/\&O$OPR\6WWB;PK::/X0^#/[77@[P9J^GVO@OPG%
M\5O&6K?#WX'R?$C7KF[59OB!I7Q$^*6F:EX,\&*=.\0Z7IOA/5?#MS+9QRVF
MI-XN6<2<5YS@<LP<*=3+<+BJ;JSBYM>UNWR.ZC>"O94XQ22C*,KJ$N9?1YWD
MV$PE1XEM8BLE=\LY36R<TH2G9)KFBKZ<TK23:LZ/A&TU+P5_P5'\*ZW>_$?P
M\EW\7_&GQIL9OA?J,O@S4H/"7PY\&_LN?"S3]$UB'61/XD\1>'_%_BC5K&2=
M[[2=9TUCH&E>+/"NG_9QXG\6ZOJG[OPW+9_=DQKV:6,)G_QXC_)SQFORD\1^
M$?"EE_P4<_9!^(#Z:;GQGXY_9N_:<\,:^;=-1L=%.O\`P>N/AT;+Q-=^';"P
M:4W.E:3XN^*7@F?4KC5K%=7N/$?A>8"`V\5A+^I5E%`EMM1Y;I^>6N/,(QUX
M*K].#^&*_1\!0Q5#)\`L57CB%6_B6C"+=K12;A&-G9)MQ>M[MN5S\WQMJN,_
M<Z.R;27?KKUO>^B?DM+=$M_)M7YH>@_A]J*S0L``'E-P`/\`6'M_P&BNKZK0
M_D_\FEY>?E^+[GG67]?+_)'*17D4Z9F@0Q_\\"K]O]O?[]?+Z?6OSK_;EU[4
MOA=XV_9?^/\`?WEPGP;T3Q)\0/@'\=;R&SL]2U?2?"_[1<_@.W^%?CA7$5M%
M:-X5^,/@OX?O-<36LT=E9ZAKT]W>.MQ.LGZ&CS?M.T!D3_IJD<8X]1YK=NV:
M\Y^)_P`,_"'QH^%GQ"^%'Q`T^;4O!_CGP3J/A7Q)I^F$'58(]7AE:PU33U(S
M-J4.IK>:MH]PAADTF[TZ`QO,VV1/@(5*.&HXG#8O#_6</C[+%4VM9J6CY9:N
M$UJXM62=G9JR/I:DI4:\<12;ITTU*\6]]K/5-WUT36KZ]?R?\/>$=%\=_M2?
MM;^#_'_ASPSXFT:\\`?LBZ7:^%8=.L-?T:]T+1O"/QXBCT73[&\6XCU*PT;Q
MSI>L7+PQ:[:0V46NO-JMAKP\*^%3I7K7C;X,_#CX8_"GPKX0^&?A2P\#6MW^
MU!^R+X@U73-(M$O]4GUZ7]MWX+:G<^(=3DOX]5NM<F:VL?$(UOQ+XIU#7GDU
M'1]'TGP=KNLQPF\UCYL\,?#GXG:!^T!\5?A'\1OB=K_A[XAZ7\$4\)^$?B8F
MI:-K7B'XF?!/PSKGAVV^#WQET#5_&>ER>$-*^*_@I?B)\1O!/[1K2'4DT#6_
M%WPYU'PTWC@>-=*MD]BU_P`$:I\,O!O[/7[-7P3^($^G^*/'?QI\,:'-XB\>
M>*/%_P`4/'NH^$=,\':YJ'Q9\9ZQ:S>)/#=_X5\0>#M:'A[XE?";7KV2;PAX
M+\06WPCT^Y\/>&O$OB&+2+KS\+EU6'$^3T%C,53P'[APPWLY3@X0I)*;J+FF
MX1DE",(N22YH25-0Y9?<XJIA)8#ZRJDI*<>;F3Y8IKEC[TI*ZO%-M2<KJ.FK
MC?Z#_9MO+?XX_M-?M#_M':;J!M_"7PV-Y^QC\#K^S;69K;6;OP[XA_X61^T[
MX[U(20"&YL/$_C^^\.>`M.NK(Q1W-]\-+V"/4)5B,,/Z&0F)T\Z=!'_TQM92
MG_CP5B?3[O>O'/@E\+/"OP#^&7@WX1?#NW72_!WA'PI8^%_#ESJ&H7-_/K&F
M:$=1U*Y\2ZOK2.'UGQ+XJN]>G\8ZO<26MO/+K.MW;R3W.U7/L-E;Q1=$V<_<
M:7?^1(7C\*_3\32IY94HX1WJX>E;V,+NZT6[5VV[W>KUO=MZGYUAZ<75G4>L
MG)V=VM&M-.FWWW:M>QJ_;[;^_P#R_P`:*S2]J22(!R2?O'_XBBNA:I/N9>PI
M?R+[Y?Y^7]79R]LJR`^8JR<#[X#>G][-1^(Y)+8^&9K:1[>9[;3P\T#M%*PC
M&H&,-)&5=MADD*9)V[WVXW-DHKX*KM'U7YQ/0Q7^YKU_1'XS_MHZGJ4/_!8;
M_@F?X=BU"^B\/ZQ\+/VJ[/5]"CN[A-&U6TD76=1>UU+3%D%E?6SZAIFG7SP7
M4$L37FGV5T5,]I`\?R=XI\7>*X?^"Z/_``3\T2+Q/XABT6?X,>/M,GTB/6M2
M32YM-_X6Y^U%IO\`9\NGK<BTDLO[.\-^';#[(\)@^Q:#HMKY?D:78QP%%?<X
M3_D=9+_V!_\`N6H=E3_DFH_XY?\`I<3^F:PCCC\3ZO:QHB6UM)I8M[9%58(`
M^D:=$PAA4".+='&D;;%7<B(ARJ@".Y)%U@$@<<`D#OVHHJLX_P!]7^+]#RL)
MM]W_`*2:+`9/`ZGL/6BBBG'9>B_(D__9````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V9E;6%L93$N:G!G````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#<U,"`Q,#4Q-30S-#$T-R`P,C0S
M,#0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`@(`3@!.``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&
M!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O
M(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!
M!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"
M`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G
M*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*`,7Q/XJT'PK:BX\1
M:O9:=&R.Z"XF"O*$`+;%^\Y&1PH)Y''(H`XNT^//PUNKJ&WB\3QK)*X13+:3
MQH"3@;F9`JCU)(`[F@#O]%UK2M=M7NM$U.RU*V1S&TMG.LJ*P`)4E21G!!Q[
MB@"_0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`'S'\:OVCX[3SM&^',V^]BF
MV3:NT:/$`N"1"#D/DY!8C&`=N[<&`!\I7=S/>74UU=S23W,SF2665RSR,3DL
MQ/)))R2:`(J`"@#UCX?_`![\:^$[H"[U"37M/=]TMMJ<C2/R5SLE/SJ<+@9)
M4;B=I-`'UE\+_B[X7^(%K;1V5['9ZVZ`RZ7</B56PQ(0D`2@!&.5S@8+!2<4
M`>B4`%`!0`4`%`!0`4`%`!0`4`%`!0!\Y?M0_&#4?"UTGA7PK<QPWT]L6O[I
M.9;8,1L6-@WR.5#$Y7(#H5(/(`/CZ@`H`*`"@`H`EM+F>SNH;JTFD@N87$D4
ML3E7C8'(92.001D$4`?5OP$_:"M9+"+0/B)?^3=Q;8[359LE9P2%"S-_"PS_
M`*P\$`EB",L`?3E`!0`4`%`!0`4`%`!0`4`%`$5W<P6=K-=7<T<%M"ADEEE<
M*D:@9+,3P``,DF@#\R_%6O7WB?Q'J.MZK)OO;Z9II,%BJYZ*NXDA5&%`R<``
M=J`,J@`H`0]*`$#`^QH`=0`4`%`'TY^S3\;8]/ALO!WBZ?;:+YGV35;JZ1([
M9%0%87W8POROM8L3EE4#&,`'UE0`4`%`!0`4`%`!0`4`%`'B7[5WCQ_"G@,:
M+:12?;O$*2VZS#;LBA7:)<Y!R65]H`'\1.05&0#X>H`*`"@`H`:5!H`!G/4X
MH`=0`A('6@`'(H`^TOV1/'?]O>#I?#.H3[M2T7'D;WRTEJQ^7&6).PY7@!54
MQ"@#WV@`H`*`"@`H`*`"@`H`^!/VBOB+:_$/QO'/I#7/]C:?#]FMO-8A93N)
M:4(?N;LJ.>2$4G!^4`'EE`!0`4`(3@4`(`3R?RH`-PS0`H(/2@!C_>H`<G2@
M#IOAWXPU'P-XML-<TN20-"X$\*/M%S#D%XFR",,!UP<'!'(%`'Z0:3J%KJVE
M6>I:?+YUE>0I/!)M*[T=0RG!`(R".",T`6J`"@`H`*`"@`H`^0_VC_CE_;/V
MKPGX+NO^)5S'?ZA$W_'UV,<9'_+/L6_CZ#Y<EP#YMH`*`"@!"<#-`#5R3DT`
M*QP*`(Z`%7[PH`5SSB@!8^AH`?0!^@'[,]S/=?`_PQ)=3232*DT8:1RQ"K/(
MJKD]@H``[``4`>G4`%`!0`4`%`'P]^T5\3?%FI>/-9T$W%[HVDV#RV0LH97C
M^TQG@R2]-XD7!`/RA2,9R68`\2H`*`"@`H`:_3\:`%`P,4`,8Y/TH`0<F@!Y
MPHXZT`,ZF@"0#`Q0`M`'VW^QSJ%U>_"6:"YEWQ6.IS06Z[0-B%8Y".!S\\CG
M)R><=`*`/<Z`"@`H`*`"@#YR_:8^"L_B.2Y\8>%(Y)M95%^W6()8W2JH4/&/
M[X4`;!]X#CYN'`/CZ@`H`*`"@!",B@`YH`BH`4'!H`.IH`>HP/>@!U`!0!]M
M_L<Z?=67PEFGN8MD5]J<T]NVX'>@6.,G@\?/&XP<'C/0B@#W.@`H`*`"@`H`
M*`/SJ^.>E3Z-\7_%MK=/&\DFH270,9)&V8^:HY`Y"R`'WSUZT`<-0`4`%`!0
M`4`-*B@!-GO0`X`"@!:`"@`H`_07]G'3[K3/@IX6@OHO*E>&2=5W`Y225Y$/
M![HZG'49P<&@#TF@`H`*`"@`H`*`/@3]J'_DNGB;_MV_])HJ`/+*`"@`H`*`
M"@`H`*`"@`H`*`.O^$_@R?Q[X\TS0XA(+:1_,O)4S^Z@7EVSM8*2/E4D8W,H
M/6@#]!=:UG0?!F@)<:K=V6D:3;((H@Q$:`*I(CC4=3M4X102<<"@#Q'Q+^U1
MX:LO,C\/Z-J6J2I,4WSLMM$Z#/SJWS-S@8#(IP><$8H`\[N_VJO&#74S6FC:
M!%;%R8HY8IG=5SP&82*&('4@#/H.E`'OW[/GC_5?B-X,O=7UNWLH+F'4'M56
MS1E0J(XV!(9F.<N>_I0!Z=0`4`%`'YR_&;Q/:^,?B=K^N:>N+*XF5(&R?WB1
MHL:OR`1N"!L$9&<=J`.+H`*`"@`H`*`"@`H`*`"@`H`]C\`?%FR^%>C:KIWA
M+2(]3U:[>,S:Q=SN(9=G9+?:K!!N<*2P8[MS`?ZM0#S'Q+XAU?Q/JLFI>(-1
MN=0O7R/,G?.T%BVU1T506.%4`#/`%`&50`4`?27[%&O6-EXC\1:)<R>7>ZE#
M#-;;BH5_*W[E&3DMB3<``>%8\8H`^O*`"@#YM_:C^,/]D0W_`(&T!<ZA<0^7
MJ=S(GRPQ2)GRT!ZLR,,MT4'CYCE`#Y#H`*`"@`H`*`"@`H`*`"@`H`*`"@`H
M`*`"@#J?A;XJ_P"$)^(&B^(&B\Z*SF_?(%W,8G4I)M&1\VQFQDXSC/%`'Z2T
M`%`'R'^TS\)_%>H_$#4_$^@Z7<ZKIMW#`\GV95:2)PHBV",,7?A%;(7`#?[)
M-`'@6N^'-;\/^1_;VC:EIGG[O*^VVKP^9C&=NX#.,C./44`95`!0`4`%`!0`
M4`%`!0!WWQFMO[(UW1O#C:?]@GT+1K6UN$\[S=\[J;B5L\@?O+AQ@$CCC@@`
M`X&@`H`U="\.:WX@\_\`L'1M2U/R-OF_8K5YO+SG&[:#C.#C/H:`-3_A7/C?
M_H3O$G_@KF_^)H`MZ7\*_'FIW\5I;>$=;263.UKFT>",8!/+R!5'3N1D\=30
M![1\)?V:M335;#6/'<MM;06TRS?V2@6=IMK'Y96Y0*2%.!OW*Q!VF@#ZRH`*
M`"@`H`X;QY\*/!WCB22XUW1X_P"T'1E%];,8I@2H4,2O#E0JXWA@,=,$@@'S
ME\8OV<_^$2\.:EXA\-:M<W]E9[7>QN(-TR1<!W\Q.&P?F/R*`N23\O(!\[T`
M%`!0`4`%`'L?[*7AK3O$?Q6C;5%D==*MCJ,"(^T&9)(PA;')`+[L<9(&<C((
M!Q?Q=\2IXO\`B5XAUN%HWMKBY*V[QHR!X4`CC;#<@E$4G..2>!TH`Y"@`H`Z
MGX9>-+[P!XQLM>T]/.\G*3VQD9%N(F&&0D?@1D$!E4X.,4`?HWI.H6NK:59Z
MEI\OG65Y"D\$FTKO1U#*<$`C((X(S0!:H`*`"@`H`*`"@`H`*`/S_P#VA/AX
MGP]\>26^G0R)H5\GVBP+,S[!T>/<0,E6[9)"LF22:`/,:`"@`H`*`/H+]BMH
M/^%D:RK1R&Y.DN4D$@"*OFQ;@5QDDDK@Y&,'@Y!`!\^T`%`!0`4`?7G[&OC?
M[=H5]X-O'_?Z=FZLN.L#-^\7A<?+(P.223YN!PM`'TE0`4`%`!0`4`%`!0`4
M`>+_`+67A?\`M[X5S:A!#OO=&F6Z4I;^9(8C\DB@CE5`82,>1B(9Z9`!\,T`
M%`!0`4`>Q_LGZ_!H?Q?M8;H1K'JMM)8B624((V)61>OWBS1A`.,EQ]"`<A\6
MO`E]X`\8W^F3P7/]F^<WV"[D1MMQ%@,,.54,RAU#;1@-D>E`&?<^!?%%KX27
MQ/=:'>PZ$SH@NI(]H.X`JVT_-L.0`^-I)`SGB@#FZ`"@#N?@9JL^C?%_PE=6
MJ1O))J$=J1("1MF/E,>".0LA(]\=>E`'Z*T`%`!0`4`%`!0`4`%`%#Q#I4&N
MZ!J>D7;R);7]M):RM$0'574J2I((S@\9!H`_,"@`H`*`"@"UI.H76DZK9ZEI
M\ODWMG,D\$FT-L=&#*<$$'!`X(Q0!^DO@;Q=I'C?PY;ZUH%QYUI+\KHW$D+C
M&Z-U_A89'L0002""0"7QGX:T[QAX8U#0=961K&]0*YB?:ZD$,K*?4,`1G(XY
M!&10!^<'BK0;[PQXCU'1-5CV7MC,T,F`P5L=&7<`2K##`X&00>]`&50!:TG4
M+K2=5L]2T^7R;VSF2>"3:&V.C!E.""#@@<$8H`_42@`H`*`"@`H`*`"@`H`*
M`/RQH`*`"@`H`*`.T^%/Q%U?X<>(UU+2F\ZTEPEY8NV([E!V/]UAD[6QD$GJ
M"P(!^@'A'Q3HOC#1EU7PWJ$=]8L[1F1`5*L.JLK`,IZ'!`X(/0@T`>;?M&?"
M5_B)HUOJ&BF-/$6FHPA5@JB[C//E,_4$$$J2=H+,#C=N`!\1Z_HVH^'M9N]*
MUJTDL]0M7V30R#E3U^A!!!!&00002#0!0H`_1#X)^/K'Q]X(L;J*]^T:O:PQ
MPZG&ZJDB3[?F8J.-KD,RD<$9'!!``.^H`*`"@`H`*`"@`H`*`/RQH`*`"@`H
M`*`);2VGO+J&UM(9)[F9Q'%%$A9Y&)P%4#DDDX`%`'KWP\^&WQBT*Z@\0>$M
M&O=-N71XPTTL$3LI."KPS,#C(R`R]E8=C0!]H^#[C7KK0+67Q7I]E8:LR*98
M;.X,R`[03G*C:=VX;07`P/G:@`UKPGX=UVZ2ZUO0-)U*Y1!&LMY9QRNJ@DA0
M6!.,DG'N:`/,==_9K^'NI>1]CMM2TGR]V[[%>%O-SC&[S@_3!QC'4YSQ@`BT
M7]G'P[H5T]UHGB?QCIMRZ&-I;/4(XG9202I*Q`XR`<>PH`])M/#NJ074,LOC
M/7[F.-PS0RPV(20`Y*MMMPV#T."#Z$4`=)0`4`%`!0`4`%`&!\0=0NM)\!>)
M=2T^7R;VSTRYG@DVAMCI$S*<$$'!`X(Q0!^:%`!0`4`;7A'PMK7C#65TKPWI
M\E]?,C2&-"%"J.K,S$*HZ#)(Y('4@4`?47PZ_9=TRQV77CN^_M2?G_0;)VC@
M'WA\TG#OP588V8((.X4`>\>&/"N@^%;4V_AW2++3HV1$<V\(5Y0@(7>WWG(R
M>6)/)YY-`&U0`4`%`!0`4`%`!0`4`%`!0`4`%`'@7[8WBK^R?A_:>'XXMTNN
MS?.[+E4BA9';!R,,7,>.",;NAQ0!\74`%`'OOP5_9]U?7]5AU+QS87.EZ#%\
M_P!EF_=SW9#$;"OWHUXY)`)!&WKN4`^O?#7A[2/#&E1Z;X?TZVT^R3!\N!,;
MB%"[F/5F(499B2<<DT`:E`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0!\2?M#Z/
MXS\8_%35;RS\+>)+C3;3;96;C2Y-I2/[Q5E4AE:0R,&R20PZ=``<_P"%_@'\
M0O$'V:3^Q?[,M)]W[_4I1#Y>,_>CYE&2,#Y.X/3F@#ZH\`_`KP7X1_LF[_L_
M^T=<L,/_`&A<._SR\_.(MVQ<$_+P2N`<EANH`]3H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__9````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O9F5M86QE,BYJ<&<`````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#(R,34U(#$P-3$U-#,T,30W(#`R-#,P-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$"`@!.`$X``/_``!$(`+X`E@,!$0`"$0$#$0'_VP"$``8$!08%!`8&!08'
M!P8("A$+"@D)"A4/$`P1&18:&A@6&!<;'R@A&QTE'A<8(B\C)2DJ+"TL&R$Q
M-#`K-"@K+"L!!P<'"@D*%`L+%"L<&!P<*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*__$`:(```$%`0$!`0$!````
M```````!`@,$!08'"`D*"Q```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@L1
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`^J:`"@`H`*`"@`H`S-4\0Z+I-PL&JZOIUE.R[UCN;E(V
M*Y(SAB#C(//M2;2*4)2U2+]O/%<V\4]M*DL$JAXY(V#*ZD9!!'!!'>F2U;1D
ME`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0!XS\8OA+=>)M6FU[0)X!>
MO$HFM)<KYS*I`97)(#$!%"X`XR2*SG"^J.RAB5!<LCP66#7O!/B*%Y8KK2M6
MM6WQLRX/!*Y'9U.&&>589ZBLM4SMO&I'NCN_#7QR\3Z==LVL^1K%JW6-T6%U
MX/W61<#DC.0W3C'6J51]3&>$@U[NAZ?X.^-WA_6MT6M+_8ET952)9',L<@/?
M>%`7!Z[L`#!SUQ:J)[G-4PLX_#J>GV%[:ZC:1W6GW,%U:R9V302!T;!P<$<'
MD$?A6AS--.S)Z!!0`4`%`!0`4`%`!0`4`%`!0!YW\7/BUH/PTM85U$27FK7*
M,]O86Y&\@`X=R?N(6&W=R>N%;:<`'S;=_$_XW>+;6:]T:SU:/2;U"B?V1H[-
M$!C8WER[&<'(/(?(.<$8&`#@+;X9_$/7]997\+Z_)?7;O(\]];/$';EF9Y9<
M+D\\L>2>Y-`%O4OA+\2?#%U971\-:LER'\R"73L7#Q,A!#9A+%""003CIQT-
M`$W@SXT>,/#VHEM0U2ZU_2IR%O-.U28SI<1X(*AGW%,ACR."0-P8#%`)VU1[
M?\./$?PD^).HM#J/A^#0-=DV@6LEVT4,Q+;%6$HRJS?<RNU22QP&P34\D398
MBHE:YH>-_@+):VGVGP?=SWDB[0UG=L@=N3EED^5>./E('0G/05#I]CIIXN[M
M,\[\$^*M:^&WB*X+6+J[JL=U8W8>,E<A@<<8;&<,0<!CP<U";BSHJ4XU8[GU
M%\/O&FF^-M%%[IY\NXCPMS:LV7@<]CZJ<'#=_8@@;1DFCS*M)TW9G3U1F%`!
M0`4`%`!0`4`%`!0`4`?"G[6>E3Z?\9]0NIGC:/4K:"ZA"$DJH018;C@[HF/&
M>"/H`#[ATG4+75M*L]2T^7SK*\A2>"3:5WHZAE."`1D$<$9H`M4`%`&!XQ\&
M^'O&5@MIXFTFVU")/]6T@(DBR5)V.N&3.U<[2,@8.10!\A_&KX`:GX-\[5O"
MPN=5\-Q0^;.TC*9[7&`Q<`#>O.[<HX`;<`%W$`E^!7QZU'PI=66B>+;F2\\,
M*BP12%-TM@`3@@@;G09P5.2`!M^[M8`^MM8\.>&O&%C%<:A86&I0W$*&*[3!
M9H\[EV2K\VTYSP<$$]C2:3W+A4E#X6?.WBGP]KWP>\6P:MHD[R:;(Q6"X896
M13R89@,#.![9QN7!!"XM.#NCT(3C7CRRW/;OA7\0[/QQIA1PEMK5NH-S:@\$
M=/,3/)4G\5)P>Q.L97..M1=-^1W=48!0`4`%`!0`4`%`'@7Q6_:0TCPQ?MIG
MA.WMO$%WY)+WB7/^C0N1\@!4'S?5@"H'`W9SM`/._"GQ$^-_Q)UF23PI)':6
M+.$>2.QB6TML;`W[R568GY@Q4,S8)(&.*`/HW6/AUI'BGPYI>F^/5_X22[LL
MO]NE7[-(SG[Q'D[=JGCY0<85<[B,T`=5I.GVNDZ59Z;I\7DV5G"D$$>XML1%
M"J,DDG``Y)S0!G7'B[PW;7$L%SX@T>*>)BDD<E[&K(P."""<@@]J7,BU3F]4
MF1_\)IX6_P"AET3_`,#XO_BJ.9=Q^RGV9OTS,*`/#/B]^SUI'C._O-:T&Z_L
M?7)\O(A3=;7#X;EE'*,Q*Y<9'!.TL22`>0_!KXHZO\(_$<_@[QW!<QZ-',4D
MBD&Z33G/.],9W1MG<0N00=ZY)(<`^R$:SU7359&M[W3[N'(((DBFC8?B&4@_
M0@T`G;5'R_\`%3PK+\,?%NG:KX:OG@@N6>6T`),ENRXW(2>&7#@#.<@D,#U;
M"2Y7='IT:GMHM21[M\*_&\7CCPZ;MHTM]0MV$5U`K`@-C(=1G(5N<9[AADXR
M=8RNCBK4O9RMT.SJC$*`"@`H`*`/`OVO_&E]X>\'6.@Z>FS^W_-2>Y$C*T<4
M9C+(`,9W[P#DXV[A@[L@`X#]GWX"6OB/2K?Q-XWCN1I\V_[+IA!B^T(579,7
M5@P4Y;"X4G"MDJ<$`^M[2V@L[6&UM(8X+:%!'%%$@5(U`P%4#@``8`%`'EG[
M2_C76O`OP]M[_P`-SQVU]<ZA':F=XA(8U*.Y*ALKD^6!R#P3WP0`3:XVH>/?
MAG8V.I%M(O[ZWMYKQ5BR%?"NR%&^90&[;@1@9)Y!\NKC]7%+J>IA\)RM3;Z'
MC][\'M>B\]K:ZT^X1-QC7>RO(!T&"N`3]<>_>DL9![HZ^5G.ZAX!\46,*RSZ
M-<,I;:!`5F;/T0DXXZ]*U6(IO9BY6)X-\6ZWX$UF>;32(Y"#%<VERAV.1D8=
M<@@J<X/!'(Z$@[QE;5&52E&HK2/J+X5^-XO''ATW;1I;ZA;L(KJ!6!`;&0ZC
M.0K<XSW##)QD[QE='F5J7LY6Z'9U1B?/O[8G@R#5/!,'BJ$1QWVCNL<S'`,L
M$CA=N=I+%792`2``TG<T`7_V2/&G_"1?#]M"G2Y-[H&V)IY9-ZRQ2,YC`)Y&
MT*4V]`%7!YP`#M/CKH_]L?#75-D'G7%EMNXOGV[-A^=NH!Q&9.#^`SBHFKHW
MPTN6HCP7X%^)I?#WCRS@)=K/5&6TFC7)^9CB-L9`R&(Y.<*S8&364'9G=B:?
M-!OL?7-=!Y04`%`!0`4`?'/[:VH74GCW0M->7-E;Z9Y\4>T?*\DKJYSC)R(D
MX)QQQU.0#Z7^$&JV6M?"_P`+WNFI'';'3XHO*B#A(FC7RW1=Y+$*RLH))SC.
M3U(!M^)?$.D>&-*DU+Q!J-MI]DF1YD[XW$*6VJ.K,0IPJ@DXX!H`^/\`Q[X@
MF^.WQCT_1]+DD/A>Q=A#(L)C=8<*9I2<,06*@+N`'^K!`);.5>JJ4'(UHTW4
MFHGTY7SI[H4`%`',>-O!>F^+(4-T7@O8E(BN8@-P'.%8?Q+DYQP>N",FMJ5:
M5/;835SY[LKC5/!WBF"X$;VVIZ=.&,;D@$CJIVD95AP<'!4]<&O6A--*43&<
M5).+/LCP3XAB\5>%[#6H('MTNE),3D$HRL589'494X/&1C@=*ZD[JYX]2'))
MQ.'_`&H?^2%^)O\`MV_]*8J9!X#^Q;_R5+5/^P-+_P"CH:`/LK4;.#4=/N;*
M\C\RUN8FAE3)&Y&!!&1R.">E`TVG='Q-;F7PCXVB-RB7$^CZB#(D;D+(T4G(
M#$9`)7KC\*YMF>P_?AIU1]P5TGC!0`4`%`!0!\Q_ME>!;J]MK'QK8_/%8PBS
MOT:0#8AD_=.JXY^>1E;DGE,#`8T`<_\`L@?$6UTB_N?!FJM;6\&H3&YL[EV*
ML]P0B>4>WS!05Z<@CYBR@`'N?Q1^#?AKXD:K9ZEK4VI6U[;0^0)+*95\Q-Q8
M!@ZL."S8(`/S'.>,`&3X1^%?AWX;W-Q_88NKBYN4&^ZO'5Y0N?N*550%R,\#
M)/4G`QY.82?.H]+'J8&*Y7+K<Z>O..X*`"@`H`\8_:#MH5NM$N5C`N)$EC=\
MGYE4J5&,XX+M^?TQZ&"EHT1):W.Q_9:U'S=`US3/*Q]GNDN/,W?>\Q=N,8XQ
MY77/.[VY].F]#S<9'WDS;_:A_P"2%^)O^W;_`-*8JT.(\K_8<_YG7_MR_P#:
M]`'U/0!\G?M"Z/%I7Q'N)8-@34($NRB1A`C'*-TZDE"Q/'+'ZG"HK,]3"RYJ
M?H?3WA;4)=6\,:1J-RJ+/>6<4\BQ@A0S(&(&23C)]:V3NCS9KEDTNYITR0H`
M*`"@"AK^LZ=X>T:[U76KN.ST^U3?--(>%'3ZDDD``9))``)-`'YW_%B^\+ZC
MX\U.Z\#64EGHCO\`(K<([?Q/&F`8T)Y"'./]D$(H!>\/_%/X@^$(!9:?X@U&
MWA,,0C@NU$ZQQA<Q^6LH;8I5@1MP"-O4`4DT]AM-;GWAK:SK:V"W<D<MR$(E
MDBC*(S87)526*@GH"3CU/6O-S+[/S_0]#+_M?+]3(KRST0H`*`"@#S;X]_\`
M(GV?_7^G_HN2NO!_&_0F6P_]E3_F:/\`MV_]JUZ]+J>;C?LGI_Q=\-/XO^&O
MB'1(5D>YN+8M;I&ZH7F0B2-<MP`710<XX)Y'6M3A/'/V./#FM^'_`/A+_P"W
MM&U+3//^R>5]MM7A\S'G9V[@,XR,X]10!])4`?+W[34\4OQ!M4BE1WATZ-)%
M5@2C;Y&P?0X93CT(]:PJ;GI8->Y\SZ"^'O\`R(/AK_L&6W_HI:VCLCAJ_&_4
MWZ9F%`!0`4`?)O[;>O;]5\->'XI+E?)ADOIDSB)][;(SC/++Y<O4<!^#R:`+
M/[-7@"WTW0HO%6IVN=5O-QLS(#F"#H&"D##/R=W.4*X(W-GR,=7<I>S3T1ZF
M#HI1YWNSAOVL8)E\>:7<-%(()--5$D*G:S++(6`/0D!E)';</6NC+VO9M>9A
MCD^=/R/K^_O;;5]%TS5=/E$MC=1+-#)M*[T=0RG!`(R/7!J,QB^6,B\!)<S1
ME5Y1Z04`%`!0!YM\>_\`D3[/_K_3_P!%R5UX/XWZ$RV'_LJ?\S1_V[?^U:]>
MEU/-QOV3WZM3A"@`H`^,_B[J/]J?$KQ#<>5Y6RZ-OMW;L^4!'GH.NS..V<<]
M:YYN[/7H1M32/K7P=9SZ=X1T.RO(_+NK:Q@AE3(.UUC4$9'!Y!Z5NMCRZC3D
MVNYKTR`H`*`"@#Y#_;;TCR?%/AK6?/W?:[*2U\G9]SRGW;MV><^?C&.-O?/`
M![%\-O\`DG?A;_L%6O\`Z*6OG:_\27JSWJ/\./HCQ;]KW_F4_P#MZ_\`:-=^
M6_:^7ZG%F'V?G^A[Q\+-1AUOX(^$KNT61(X+**W82@`EH086(P3P60D>V.AX
MK;'Q;I7[,QP4DJMNZ/'?!?B#4?A7XFF\)^/+B2?2M0N'N-/UN5V*,S$;@Y8G
M:"QRW]UF).5;>.:K3CB(^TI[K='33G*A+DJ;/9GNM><=Q7U&^M-,LY+O4;J"
MTM(\;YIY!&BY(`RQX')`_&G&+D[)";25V9OA/Q1H_BW3I+_P_>?:[2.4PL_E
M.F'`!(PP!Z,/SJZE*5-VDB:=2-17BSD/CW_R)]G_`-?Z?^BY*WP?QOT'+8?^
MRI_S-'_;M_[5KUZ74\W&_9/?JU.$*`"@#S+7?@YX3O\`7;O7+^:_B668W-Q"
M+A5A)SN?)*[@"<DX88R<8XQG*,5JSIAB*EE"*/1=/O;?4;*&[LIEFMY5W(Z]
M"/Z'MCM50G&<5*+NF8U*<J<G":LT6*H@*`"@`H`\,_:[\(R:_P##F+5[*W\Z
M]T.8S,1O+"W<8EPHR#@B-B3T5&.1R"`<3^S#XQM+OPM_PC-W-!!?V,K?98V8
M*UQ&Y:0[06RS*=^<``+M]Z\C'T6I\ZV9ZF"JIQY'NBS^U?\`\D[T[_L*Q_\`
MHJ6EE_\`$?I_D/'?PUZGH?[.,1F_9\T!%SNVW)&!G.+F4X_2O1Q,'.E)(X,/
M-0J)LX#5_A[KWCKXAWDOCUXSX6TYV;2XK.14\T,4^5N"^-J8?)!W'Y#BO-CB
M(4J:]E\3W_K^O,]"5"=6H_:?"MCS'X<^`M<UC6O%R>"O$UWI6DV-P\%O=Q3.
M%OF5F\H%X\*1MY+#.-X(4[JZZU>$8Q]I&[?X'+1HRE*7)*R7XF!XET;5[GX?
M>&?&7B#7K_6+"ZNY(&LY[A_,A^9@?+=MX^80G)P,';PW;2$XJI*G&-G8B<).
MG&I)W5S[`T#0],\/:<EAHEC!96BX.R%,;C@#<QZLV`,L<DXY->+.<IN\G<]>
M$(P5HHX?X]_\B?9_]?Z?^BY*Z,'\;]`EL3_LJSRM;^)8&E<P(UNZQECM5F$@
M8@=`2%7)]AZ5Z]+J>;C5LSWJM3A"@`H`I:Y:27^BZA9PE5EN+>2)"QX!92!G
MVYK.K!SIRBNJ-:$U3JQF]DTSQSP=XGNO!-_=:7K%K+]FWEI(E4>9&^!R.<,"
M`.^,8(/KX>&Q,L+)TZBT/I,9@X8V"JTGK;Y-?U_D_+VC3[VWU&RAN[*99K>5
M=R.O0C^A[8[5[T)QG%2B[IGS-2G*G)PFK-%BJ("@`H`*`/E/XR?LWZC<:S?:
MUX`6R:VN'WG1Q^X,1.T'RV8[""2[8)0*.%!X%`'E?C+PK\5-8L+N]\5Z5K,]
MIX=B\J26Y0!40$@NO_/;[N6D7=P`6;&#6<*4(7Y5:Y<ZDIVYG>Q]$?L9W,\_
MPIO8YII)([?5I8X5=R1&OEQ-M4=AN9C@=V)[UH0>BW,8BN98U)*HY49]C7S=
M2*C-Q71GT%.3E%-]48'A/POH_A+3I+#P_9_9+224S,GFN^7(`)RQ)Z*/RIU*
MLJCO)BITXTU:*#PGX7T?PEITEAX?L_LEI)*9F3S7?+D`$Y8D]%'Y45*LJCO)
MA3IQIJT4;59EGGGQTMII_!4<D2;DM[M))3D#:I#+GWY91QZUU81I5/D3+8H_
MLLZA%'J^OZ<ROY]Q!%.K`#:%C8JP/.<YE7''8_CZ])GGXU:)GT36QYX4`%`!
M0!SOCGPU'XFT@0!UBNX6WP2LN0#CE2>NT]\>@/.,5RXO#*O"W5;';@<6\-4Y
MMT]SQSPAXCO/"VLJ)S<_8U=EN;3..>A.T]&!`]#QC(S7AX;$2P\];VZH^DQF
M$ABJ>EKVT?\`73_ASWC1=3M]8TNWO[(L8)URNY<$$'!!'J""*^BI58U8*<=F
M?)UJ,J,W3ENB[6AD%`!0`4`5=6T^UU;2KS3=0B\ZRO(7@GCW%=Z.I5AD$$9!
M/(.:`/D/]C[7)-!^(VL>%]2C^RRZE"5\J:)Q*+B`L?+/]W"-,3N'50,@\$`^
MH?$$12_+\E9%!''IQC]/UKQ<?!QJW[GKX*:=.W8S*XCK"@`H`H>(+.34=!U*
MR@9%EN;:2%"YPH+*0,X[<U4'RR3?<&>"?"#73X3^(UD^H.]K;RLUG>!U5=@;
M@;MV-H5PA)X("GZ'W825[G'B(<\&NI]A5T'DA0`4`%`!0!R7CSP?::_I\T]O
M"L>JHI>.5``92!PC'C(.``3T^F0>+%X2-:+:7O'HX#'SH349/W?R\U_6IY/X
M+\0S^$]<D:>&4P-^ZN8#E6&#UP?XE.>OJ1QG->-A<0\/4U6G5'T&-PL<72LG
MKNG_`%T9]!PR1S1)+"ZR1.H9'4Y#`]"#W%?2IIJZ/CVFG9[CJ8@H`*`"@#XS
M^)\J?";]IZW\1Q01O8W+KJ+0H6D?RY@T=P<,1\Y;SF49VC*]N``?7NMVXFL7
M8#+Q_,/IW_3^5<F-I\])OJCJPE3DJ)=&<M7AGL!0`4`%`'B_QM\)PVVS7].@
MV"63;>J@.-Q^[)@#`R<@G/)*\9)-=^$JM^XR)+J=E^SSX^^WVD7A34_^/JUB
M9K.=I,^;&#GRR"<[E!XQQM7H-O/J4Y=#S<51L^='MU:'$%`!0`4`%`'E7QC\
M.2NXUZV$7E(BQW*@!6SG"OG^+J%]1@=1T\;,\.W^]7S/?R?%I+V$M[Z?Y?J/
M^"^N*8KG1KF=0P;S;5&)R0<[P.V!@'`]6//.'E=?1TV_3]19UAM56BO)_I_7
MH>I5[!X(4`%`!0!\^_MF>&GU+P'INO0+(\FCW)64!U"+#-A2Q!Y)WK$!C^\<
MCN`#:_94\;_\)3\.4TJZ?.I:#LM7X^]`0?);A0!PI3&2?W>3]Z@#N=1MS;7D
MD>,+G*_3M7SV(I^SJ.)[M"I[2"D>:^._'TNA:H=.TVW@EGC56EDFW$+D$[=H
MQS@J<Y[XQ7;A,`JL.>;T/K<GX?CBZ/MZTFD[V2M]]]?-6L<M+\4===0%@T^,
M[@<K$V3@Y(Y8\'I^/&#S78LLHKJ_Z^1[,>%L&GJY/YK_`".T\*_$.PUN\2SN
M8&L;J1L1;G#(_3`W8&&//&.W7)Q7!B,OG2CS)W1X&8\.UL+3=6$N>*WTLU\M
M=/G\K:G6ZE86NIV$UE?PI/:S+M>-NA']#W!'(/-<$9.+NCYT^=_'W@[4_`>K
M64XF`M[EFFL+B&7YU"L",G`(<`H<@8R>#P<>W&_*I/JCFC.,VX]CTOX7_&N"
M#3XM,\:RSF2+Y8M1"&3<@!XE`^8MP!N`.<\XP6.T:G<Y*V%;=X'N>D:G9ZQI
MEOJ&F7"7-G<+OCE3H1_,$'((/(((/-:IW.*47%V9;H$%`!0!%=V\5W:36UPN
M^"9#'(N2,J1@C(]JF45).+V94)N$E*.Z9\WZK9W7AKQ)+`'Q<V4P:.3`YQAD
M;'(Y&#CGT-?+5(2H56NJ?_#'VM*I#$T5+I)?\.?1NG7<=_I]M>0AEBN(EE0,
M.0&`(S[\U]3":G%275'Q=2#IS<'NG8L51`4`%`%#7]&T[Q#HUWI6M6D=YI]T
MFR:&0<,.OU!!`((P00"""*`/@ZVEU[X#_%]FD@DE:S=U"2$Q)J-HQ(#?*2,,
M`&'W@KJ,@E2*`/MK0]:TKQUX8M=5T*ZAFBE5'P)%9H&*JQCDVD[7`897/!Q7
M/B:'M866YT8>M[*5WL>9^/?A]_;6H2WME.MO?D!94ER4D(P`<C.T@#L"#@=.
M2>/#8UT%[.:T3/OLFXA^JTE2J1O#HUNKZ_/7TMY['$V'@37;+5HY+O0XM2M(
MI,/%]K6-9EZ<,&##U!^F0>17H?VA0:^*WR9]#6S[!U:+5.LX2:T?*VT_2S3\
M_P`'U/0[_1[GQ)'8VMYI&GZ!H,,AN)=.LV5I)IN5!9E4`#;Z<X_#;RULQC%-
M4]7W/EJ.,IX%SJ4ZLJM5KE4Y7LH[Z)MMN_?3\;]K86YNKI(AG:3EB.P[UYE"
MDZLU$^>K5%3@Y'4W]E:ZC:26NH6T%U:R8WPSQAT;!R,@\'D`_A7T)X:;3NCY
MQ\<?`W6;74)KCPMY%]92RDI:[Q')`I+$+EVPRJ-HW;LDGIWK&5-]#T*>+BU:
M1YA_Q/\`PGJ'_,4T6]DB_P"FEO(T9/X$KE?ID>U1JCI]V:[GV+X!N=9O/!^E
MW'B:#R-7>+,Z%`AZG:2HZ,5VDCC!)&!T'1&]M3R:JBIM1V-^F9A0`4`>5?'#
M3_\`D&:DD7]Z"63=_P`"08S_`+_('U[5XV:T_AG;R_R_4]_)*OQ4V_/_`#_0
MZWX9WK7O@K3FDF666)6A;&,H%8A5('0[=OZ'O7;@)\U"-WM_7Y'GYG3Y,3*R
MLGK]_P#P3J*[#@"@`H`*`.+^*WPZTCXC^'&TW55\F[BR]G?(N9+9SW']Y3@;
MES@@#H0I`!\>^'-<\6?L^_$*^M+VQCE:1%2XMY)'\F[AW@K+$PP,X#!7(.W<
MX*YR*`/=M!_:)\#^(M,:3Q%]J\/:C$/N-$]RCY+<(\:Y/`!.Y5P6XS@FN;$X
M>-57ZHZ,/7E2?D4-8^/?@BP\G[+/?ZGOSN^R6I7R\8QGS2G7/;/0YQQGS8X&
MJ]]#T)8VDMM3S7Q#^T=K-W;"+0M&M--=D=7EFE-PP)'RLG"@$<GY@P/'''/7
M#+XI^\[G+/'R:]U6.Q_9B^+FO:]XZFT#Q5J45U'>VS/:$VJH_G)\Q4&-0,%/
M,)W?W!@@G![*=&%-6@K'+4JSJ.\F?5%:&84`%`!0`4`%`!0!YU\;;B)=`L+9
MFQ/)=>8JX/*JK`G/U9?SKR\UDO9J/6Y[620;JRET2_7_`(!+\%/^15NO^OUO
M_0$JLJ_@O_%^B)SK^.O\/ZL]`KTCQPH`*`"@`H`^??VU+:!OAOHUTT,9N8]6
M2-)2@WJK12EE!Z@$HI([[1Z"@#S7X&_!;P[\2OA[>:I=7NK6&K07,MH'CEC>
M$L$5E?RR@;`\P`KOYVGD9P`"S_PS1_U-G_E-_P#MM>9_:7]W\?\`@'H_V?\`
MWOP_X)Z#I7P4\%:=I5S:+I\EQ//;R0->W+B250W\2@C8KKQA@H(Q[G/++&59
M.]SHCA*25K'R]I]YKGPN^(@N(!''K.CW#+B2,M'(,%3PP!*.C'!X.&!!!P:]
MN$U.*DNIY$X.$G%GZ">`?$]KXR\':3X@L5V17T(=H\D^4X)5TR0,[7#+G`!Q
MD<&J)-^@`H`*`"@`H`JZGJ-GI=HUSJ%S%;P#^)VQDX)P!W.`>!S45*D::YI.
MR-*5*=67+!79\^>(-6O?%WB))3$HFF98+>%2`%!/RKDXR<GJ?7L.!\S6JSQ-
M6_?1'V&'H0PE&U]%JV>Z^$-)DT/PY9:=-*LLL*MO91@99BQ`]AG&>^.U?18:
MDZ5)0?0^4Q==5ZTJB5DS8K<Y@H`*`"@`H`\"_;2_Y);I?_89B_\`1,U`%K]C
MNPN;#X1SW-W&(X+W4IKB!RP.^,)'&6X/'S1N.<=,]"#2;25V-)MV1W=?,GT(
M4`>._'WX1W?BS36\3>&+..35K-2+JWC4^;>Q@#!7!^9T`Z8RP.`2553Z^7N3
MB[['EX]1YE;<\9^!_P`6M1^&NLE)!)>>';IP;RR!Y4]/-CSP'``XX#`8.,*R
M^@<)]N>`_&V@^.=&CU'P[?QSJ45IK<L!-;$Y&V1,Y4Y5AZ'&02.:`.DH`*`"
M@#FO%WC'3O#6(K@2S7KIOC@1<9!R`2QX`RN.Y]JY,3C(4-'J^QW83`5,3K'1
M7W/%-7U?6/%FI1_:/-NI_F$-O!'D(.I"J/;OR<`9/%>#4JU<1+75]CZ>C0HX
M6#Y=%U;/6/AYX)CT&);[4563577@=1;@]AZMZG\!QDGV<%@E17//XOR/G\QS
M%UWR0^'\_P"OZ\NXKT#R@H`*`"@`H`*`/E/]HOP]XU^(WQ9L-`TG0KU='L$6
M*WOI86%J6D57EE:79@``*I7+<Q\#<VV@#Z`TK1(_"/@/1]"LFC\NR@CMWDBB
M$0E(7YWVC."S98\GDG)-<6/DXTM.K.O!14JFO1%.O%/7"@#J](M7M+39(1O9
MMQ`[=./TKWL)1=*G:6YXN)JJI.ZV/#_C5^SU:^,=5FUWPK=6VEZO/\US;S(1
M!<N6&9"5R4;&XG"L&..`2S'I.<\!TOP9\6?AMXCBO=&T+6[74C"1YMC;B\C9
M&R"K;`Z'E<[6Y!"G'0T`?9GPK\3ZKXK\)0WWB#0;W0M6C<PW-M=0-$'8`'S(
MPWS;#GC/0@C)QD@'7T`>;_$/Q\VFRMINA2*;U&_?W&`PB(_A`/!;U].G7IY6
M-Q_(^2GOU9[>799[1>TK+3HN_G_7Y;^=:'HVK>+M4E$+M-,%W37-RY(48P-S
M<G)Q@#GIZ`X\NE1JXF>FOFSV:^(HX2"OHNB1[;X3\*:=X;@'V5/,O&0++<O]
MY^<\#^$9[#T&<XS7T&'PL*"]W?N?+XO&U,2_>VOHCH*Z3C"@`H`*`"@`H`*`
M"@`8!E*L`5(P0>])I-68TVG=%273;.1@6@4'&/ERO\JPEA:,G=Q-HXFK%64B
M2VM(+;/DQA2>IZG\ZNG1IT_A1%2M.I\3)ZU,PH`*`"@"*[N(K2TFN;AMD$*&
M21L$X4#).![5,I**<GLBH0<Y*,=VSYDU:\_M#5;V]V>7]IF>79G.W<Q.,]^M
M?)U)\\W+NS[FE3]G3C#LDCZ(\):+'H&@6M@H4RJNZ9U_CD/WCG`R.PSS@"OI
M\-15&FH'QN+Q#KU7/IT]/Z_$V*W.8*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`KZC:1W^GW-G,66*XB:)RIY`8$''OS4S@IQ<7U1=.;IS4UNG<X_3OAIH]
MAJ%M>0W.H-+;RK*@:1,$J01GY>G%<,,MI0DI)O1_UT/2J9O6J0<&E9JW7_,[
MBO0/*"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@#__9
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA;&4Q+FIP9P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(W,R`Q
M,#4Q-30S-#$T-R`P,C,W-S<`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#
M`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8
M%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K
M'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#
M$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G
M*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`"0.IH`JW6
MH6MJI,\\:`>K4KC46]CG-4\?:'8`AKI78=EI.:1M'#S?0YR]^+^CQ8$*,[=Q
MG&*GVB-%A)=3'N_C1&)F6WM5*@?Q-S2]H:+!]V<KJ7QHU-I3Y$L<8'&U4S4^
MT9HL+!;F1=?%SQ%=D>7-<JJ]XHP,TN=EK#TUT(+OX@^*9[<!;F]=7'(W!3^E
M+F92HTUT,S_A+O$O]_4O_`EO\:+LKV<>Q6N]?UF\(-W!=3D=#+*6Q^=*XU%+
M9$']I7__`$#W_.@H/[2O_P#H'O\`G0!?A\7ZS;(J32ZC!".!LG;`_`&G=D<D
M7T.@T?QQJ\0#6FK7#`G.V1]V?SHYF2Z,'NCN?"_Q0O(KDIK6)HFZ,BX*U<:G
M<YZF$5O=/8-+U"WU*T2XM7#QL,@BM4[G#*+B[,MTR0H`CN)H[>%Y9F"1H,EB
M>!0-*YX;X]^)PDOVMM,O8H(4."Q<`M6,I]CT*.&25Y'F>J>+([YFBDU<M*3T
M5B2:B[.I02V1EV5K'J$;.;FY==W\8*TBBV-%M-X8J2WKF@"TEE;H21&N3UH`
M>MK`K;A$@/KB@"5451@*`/I0`M`!0`4`%`!0`C*K##`$4`9][I<4X4QDQ,IR
M"G%`#+2\DAN/LUZ`I)_=OV8?XT`>L?"GQ2=.OUT^[D_T>8X4GL:TA*VAR8FE
MS+F1[HI!`(Z&MCS0H`R/%.AQ^(=*-A-<2P1,P9S'U88/!]N?TI-71I3GR.]C
MS:?X#^'EC8VC`3$Y#2QAN:CV:.A8R75'$ZU\(?%%O/(^GW%H85.$"Q<GWJ'3
M9O'%0>YS&K>$/%ND1M)=RD1KU*6^:GE9JJL'LS/M[YH?W=QY\DF>28B*5C2Z
M$.L_O?+%K<9S@'90,M6-U+<.XDMWB"G@MWH`N4`%`!0`4`%`!0`4`%`%:_ME
MN;=D8<CD'T-`$>C7KRISE)H6P?J.]`CZ?^'FM?VWX9MIW(,Z#RY![BNB+NCR
M:\.2;1TU48A0`4`%`#9(HY%Q(BL/0C-`%"?1--F#>990'=U^04K(I3DNI@ZY
MX"T?4+=ECMUAEQ\K(,8I."9K#$3BSPWQ+H5UH.H/;72$+GY'QPPK!JQZ5.HI
MJZ,BD:!0`4`%`!0`4`%`!0`&@#%MW%OKTL.T_O5W`T`>S?`_4)(]:N;'),4T
M>_'H16E-ZG'C(^ZF>V5L><%`!0`V8D1.1U`-`&9X8NIKS24EN'WR%V&?H:2*
MDK,U:9(4`<E\2/#XUO0)?*3-S#\Z8')]JF:NC>A4Y)'SO+&\4C1R*5=3@@]J
MYSU4[C*!A0!8M[.YN"!!!(^?[JDT6)<DMRW/H6J01&26QG5!U)0T^5B52+ZF
M:00<$8-(L2@`H`*`,'40T?B&RD4C#@J10!Z5\+KG[-XPLB7**YVGWSVJH;F&
M(5Z;/HRN@\D*`"@""^E$-E/*W1$)/Y4#6YA_#VZ6]\+6US&"$D9F`/UI+8JH
MK2.CID!0`$9&#0!Y_P",_AY;:S(US9,(+D]>.&J)0N=5+$N&C.;L/A+<,0;V
M\51GD(*E4S66,71'3Z/\,](LN;@-<-G(W52@C&6*F]CL+/2[&RB"V]M%&H]%
MJK&#DWN<1K'C&]O[Z[T[PKI*:D;?Y997;:BMZ>])OL:1@DKR=CS7QCIU\KRW
ME[HTFGR#EQ'\Z-[Y'2LY1.RC56USE@#L5\$*PR#CK69U7$H&%`&)JW_(:T_Z
MF@#M_`__`"-.G?\`744X[F5;X&?3E=)XX4`%`%/6O^01>_\`7%_Y&AC6YS?P
MD_Y$+3?HW\S2CL75^)G84S,*`"@`H`I3ZI:07\-E+,JW,P)2//)H'9VN7:!$
M5VCR6LR1G#LA"GT-`(P_!&@?\(_I`@DV-<N[/+(H^\2:25BYRYF;ES;Q7,+Q
M3(KQN,$$=13(/&9M!CU#3M?TVUB4-I5P?(8]=I&2*S:NCMIU'&2;ZGF;*58J
M1@@X-8G>)0,Q-6_Y#6G_`%-`';^!_P#D:=._ZZBG'<RK?`SZ<KI/'"@`H`IZ
MU_R"+W_KB_\`(T,:W.;^$G_(A:;]&_F:4=BZOQ,["F9A0`4`5]1O(;"QFNKA
MPD42EF)-`TKNQR'@K3EU:Z;Q/?HQN9\BW5O^6<?;'UJ5W-)NWNH[>J,@H`*`
M([B9(('ED8*B`L2>PH`XSP#:+=#6=5&?)U*<LBD?PCC-2C6;M9=CQKQG8#3?
M$=Y;C[H<D?C6$E9GITI<T$S#I&IB:M_R&M/^IH`[?P/_`,C3IW_744X[F5;X
M&?3E=)XX4`%`%/6O^01>_P#7%_Y&AC6YS?PD_P"1"TWZ-_,TH[%U?B9V%,S"
M@`H`X7QY*-=U"T\,6LBEI6$MW@\K$#T_$U+UT-8>ZN8[6U@2VMHX(E"QQJ%4
M#L!5&1+0`4`!H`XKQ%JJZYJG_".:7)N?K>2+R(T]/J:EZZ&D5RKF9UMA:16-
MG%;6Z!(HU"J!5$-W/'?C1HHMK^'4HA\LWRO]:QJ+J=^$G=<IYC69VF)JW_(:
MT_ZF@#N?`JL_BK3@H)/FCI51W,JWP,^FJZ#QPH`*`*>L@MI-X%&286`'X&AC
M6YQWPMU6QM?!^GVES=10W*[@8W;:P.3V-3%Z&E6+YFSNXY4D4&-U8'N#FJ,A
MU`"/]T_2@#S;X6Z<D^N>(=;N)'EO9+IH`S'[J*>`*F/<VJO11/2JHQ"@`H`R
M_$MY/9://+:0O-<$;45!DY/&:3*BKLI>#/#\6A:;\P#WLY\RXE(Y9C0E8<Y<
MS.AID&5XDT2VUW39+2[7((^5NZGUI-71=.;@[H^<O$VB7&@ZK+:7"G`/R-CA
MAZUSR5F>M3FIQNCD-=REU8RJ/F$F,^@I&AZ-\*^?&=A]3_*KAN<^)_AL^BZW
M/*"@`H`"`1@]*`,#6O"&BZP,WEE&7[.ORD?B*32+C.2V.5M].3P9XQT:SL;B
MYEM=2WQM%+(6";1D$4MF6WSQ;?0])JC$1_N-]*`.%^%'_'MKG_80D_G4Q-:O
M3T.[JC(*`"@`-`!0`4`%`'(_$3PU#KFD22;/]*A4F-OZ5,HW1O0JN$O(^9/$
MEI/)"L4:DR)*,CTP>:YSU3T?X-VPG\70%B08HRP^H%73W.?%.U,^@JW/+"@`
MH`*`"@#@_B5_H^L>%+Z/_7)J`B&>FU@0:EFM/9KR.\'2J,A'^XWTH`XKX7VT
MUO;:QYT;)OOY&7(ZC/6IB:U7MZ';51D%`!0`4`%`!0`4`)(H="K#((P:`/!/
MB?X7DTK5'N[:(_9)3DD#H:PG&S/3P]7FC9[DGP5!_P"$N)QQY+4Z>X8OX#WB
MMCS`H`*`"@`H`YGQS:17%OIDDJY:&^B=#Z'./ZTF7![^ATPZ4R`H`1551\H`
M^E`"T`%`!0`4`%`!0`4`%`%>^LK>^MVANHEDC;J&%%AIM.Z,_1/#FF:+([V%
MLL;MU;O244BYU)3W9L4S,*`"@`H`*`,'QC_QY6?_`%]Q?^A"DRX;F\.@ID!0
M!#<74%NI:>9(P.[-B@+&5J'BG2+!`UQ>Q#(R`#DFE=%*#9F?\+"T#_GZ;_O@
MT<R*]E(TT\4Z.?*W7L2&094,<9HNB>21KPSQ3J&BD5P>ZG-,DDH`*`"@`H`*
M`"@`H`*`"@`H`*`,OQ)I"ZWIIM&FDA^=75XS@J0<BDU<J,N5W,`VOBW39`MI
M<VE];C`"S`JV/K2U*O!E74[?QOJ=[Y<$]EIME@99<N^>^*-1KD2[A'\.X;F3
MS=9U*\O7.,AGPOY4<H>UMLCHX/"^CPK$%L8B8QA2PSBG9$<[+G]D:=_SY0?]
M\"BPN9E/5/"^D:G&$NK*)@O0@8(HLAJ<EL+X?\/6FA>:+-I=LAR5=R0/I0E8
M)2<MS9IDA0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4
M`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!
M0`4`?__9````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VUA;&4R+FIP9P``````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-S0W-B`Q,#4Q-30S-#$T-R`P,C0P,#4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`@(`3@!.``#_P``1"`"^`)8#`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&
M"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P
M*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RO_Q`&B```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@L0``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-1
M80<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8
MF9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;G
MZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+$0`"
M`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2
M\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,
M`P$``A$#$0`_`/JF@`H`*`"@`H`*`(KNY@L[6:ZNYHX+:%#)++*X5(U`R68G
M@``9)-`'`:U\:OAUHUTEO=^*K*21D#@V:O=)C)'+1*R@\="<]..10`:+\:OA
MUK-T]O:>*K*.14+DWBO:IC('#2JJD\]`<]>.#0!W6EZC8ZM817NE7EM>V4N?
M+N+:59(WP2#AE)!P01]10!:H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`BN[F"SM
M9KJ[FC@MH4,DLLKA4C4#)9B>``!DDT`?-'Q&_:BL5L+JR\!V-S)>MOC34KQ%
M2./!`62./DOD;B-^W!VY4\K0!\Q>)?$.K^)]5DU+Q!J-SJ%Z^1YD[YV@L6VJ
M.BJ"QPJ@`9X`H`RJ`"@`H`].\(_'3Q_X:D4)KDFJ6P=G:WU7-P')7;RY/F`#
M`("L!D=.3D`^B/A7^T=H/B>2'3O%,<>@:F4)-Q)*!:2E5!/SL08R3N(5LC``
MWDD"@#WB@`H`*`"@`H`*`"@`H`*`"@`H`^'OVA/C5/X[NI-#\/220>%87Y."
MKW[`\.PZA`1E4/LS<X"`'B5`!0`4`,9L'`H`56S@=Z`'4`%`'K'P>^->O>!M
M9MTU2[O=6\.E$@ELIIBY@C7A3!N.$*C^'A6'!Q\K*`?<^@:SIWB'1K35=%NX
M[S3[I-\,T9X8=/J""""#@@@@@$4`7Z`"@`H`*`"@`H`*`"@#PS]L+7O[,^%:
M:9');>;JU['"\<A_>&),R,R#/9TC!."`'QU(-`'Q)0`4`%`"4`1L<F@!*`'!
MB*`'*P/UH`=0!ZQ^SW\4Y_A[XGCM=2NY!X5OGQ>Q;#)Y38PLR@'(((4-C.5!
MX8A<`'WC:7,%Y:PW5I-'/;3()(I8G#)(I&0RD<$$'((H`EH`*`"@`H`*`"@`
MH`^/OVV=5GF\9^'M(9(Q;6NGM=(P!WEI9"K`G.,8A7''<]>,`'SE0`4`(QP*
M`(\Y^M`"4`%`!0`\+QZ&@!5/8]:`'4`?5G['?Q#>:.?P-JDT86%&N-+)55)&
MXM+'G.6.6W@8)QYF3@```^HJ`"@`H`*`"@`H`*`/BG]LRY@G^*UE'#-'));Z
M3%',J."8V\R5MK#L=K*<'LP/>@#P>@!#P,T`1DDF@!Z#C.*`&,,&@`'7B@!Z
MJ!]:``MDX'6@!-IQ[T`+NX/K0!T7PU\3R>#O'FAZ\KRB.RNE:<1(KNT)^655
M#<9*%@.G7J.M`'Z74`%`!0`4`%`!0`4`?`G[4/\`R73Q-_V[?^DT5`'EE`!0
M`PISQ0`T$CO0``\\\T`29`&:`&\L?04`+PHH`!D^PH`4J"*`&[.>O%`'Z4?"
MC_DEO@[_`+`UG_Z)2@#J:`"@`H`*`"@#+\5:]8^&/#FHZWJLFRRL86FDP5#-
MCHJ[B`68X4#(R2!WH`_-KQ5KU]XG\1ZCK>JR;[V^F::3!8JN>BKN)(51A0,G
M``':@#*H`*`"@!"`>M`#&&#0`+C//6@!Q.!F@`5><GK0`Z@`H`*`/TE^%'_)
M+?!W_8&L_P#T2E`'4T`%`!0`4`%`'RQ^V=XTOH9M.\%VR>593PIJ%S,LC!IO
MG=5C*CC:"FXYSD[>FWD`^6*`"@`H`*`"@!#0`A4]C0`PY_&@`R?6@"13D9H`
M6@"6TMI[RZAM;2&2>YF<1Q11(6>1B<!5`Y)).`!0!^G^DZ?:Z3I5GINGQ>39
M6<*001[BVQ$4*HR22<`#DG-`%J@`H`*`"@"KJFHV.DV$M[JMY;65E%CS+BYE
M6.-,D`99B`,D@?4T`?FKXS\2ZCXP\3ZAKVLM&U]>N&<1)M10`%55'H%``SD\
M<DG)H`Q:`"@`H`*`"@`H`*`$H`-H]*`"@!:`/6/V9?!D_BSXH:?=$2)I^BNM
M_<2KD?,C`Q)G:1EG`.#C*J^#D4`?>U`!0`4`%`!0!E^*M!L?$_AS4=$U6/?9
M7T+0R8"EEST9=P(#*<,#@X(![4`?''B7]F3QQIGF2:0^FZU%YQ2-()_*E*<X
M=EDVJ.@R`[$$\9&30!XWK^C:CX>UF[TK6K22SU"U?9-#(.5/7Z$$$$$9!!!!
M(-`%"@`H`*`"@`H`*`"@`H`*`+6DZ?=:MJMGINGQ>=>WDR001[@N]W8*HR2`
M,DCDG%`'Z(?"'P+:_#WP19Z-!\UVV)[Z42%UDN&50Y7(&%^4`#`X49YR2`=I
M0`4`%`!0`4`%`!0!\Y?MF>#WU#PQIOBFTCC\S2G,%V0BAVAD("$L2"0K\!0#
M_K2>,'(!\?4`%`!0`4`%`!0`4`%`!0!]>?LD_#2QL](L_'US=?:KV]AEAMK=
MH%"VF)61F#$DEB$P"-N`S#G/`!])4`%`!0`4`%`!0`4`%`'-_$O1G\0_#WQ'
MI4-I'>7-UI\R6\,@7#3;"8_O<`API!.,$`Y&*`/S5H`*`"@`H`*`"@`H`*`"
M@#]&O@KI]KIGPE\(P6,7E1/ID,[+N)R\BB1SR>[NQQT&<#`H`[2@`H`*`"@`
MH`*`"@`H`Y;XJ>(/^$6^'/B+65N?LL]M92?9YO+W[9V&V+Y<$']XR#D8YYXS
M0!^;5`!0`4`%`!0`4`%`!0`4`?HK\#-5@UGX0>$KJU21(X]/CM2)``=T(\IC
MP3P6C)'MCITH`[F@`H`*`"@`H`*`"@`H`^=_VTH]7E\$:,MG9>=HT5Z9KVY5
M<M`X79%GGA6\R0$XQD*,@D`@'QS0`4`%`!0`4`%`!0`4`%`'UY^Q3KUB_A;7
M?#_F;=2AO?MVQBHWQ.B)E1G)VF/YN,#>G/-`'TE0`4`%`!0`4`%`!0`4`9?B
MCP_IGBG0KG1M>MOM6FW.WS8?,9-VU@P^92".5!X/:@#Y'^('[,7B32[HR^#9
MX]<L7?"PRND%Q$"6(W;B$8`!06!!)/W`!0!R'_#/WQ-_Z%G_`,G[;_XY0`?\
M,_?$W_H6?_)^V_\`CE`'(>+O`OBCP?(R^)-#O;&-76,3O'NA9BNX*LJY1CC/
M`)Z'T-`'-T`%`!0`4`%`&_X&\7:OX(\1V^M:!<>3=Q?*Z-S',AQNC=?XE.![
M@@$$$`@`_1#P-XNTCQOX<M]:T"X\ZTE^5T;B2%QC=&Z_PL,CV((()!!(!OT`
M%`!0`4`%`!0`4`%`!0`4`%`!0!X/\??@WX7O/`>KZUH&D66DZQIEL;A'M5\B
M*2./+.K1J-I)4M@X!R%!;:"*`/BF@`H`*`"@`H`U?#7B'5_#&JQZEX?U&YT^
M]3`\R!\;@&#;6'1E)495@0<<@T`?8WP:_:`TCQ983VWC&YTW0M9M\OODE\FV
MN$SP49V^5AD`J22>HR,A0#VZTN8+RUANK2:.>VF0212Q.&212,AE(X((.010
M!+0`4`%`!0`4`%`!0`4`%`!0!RWQ7_Y);XQ_[`UY_P"B7H`_-J@`H`*`"@`H
M`*`);2VGO+J&UM(9)[F9Q'%%$A9Y&)P%4#DDDX`%`'O'P>^#/Q*NO,N8M5U+
MP3IMQCS7\V2*>;;O`_<JRDX/]\KP^5W4`?8^EVLUE816]S?W.H2IG=<W*QB1
M\DGD1JJ\9QPHX'<\T`6J`"@`H`*`"@`H`*`"@`H`Y;XK_P#)+?&/_8&O/_1+
MT`?FU0`4`%`!0`4`7]`T;4?$.LVFE:+:27FH73[(88QRQZ_0``$DG``!)(`H
M`^X?@K\$-(^'GDZK>2?VCXF:'9)<-S%;DYW"$8!&00I8\D`XVABM`'KU`!0`
M4`%`!0`4`%`!0`4`%`!0!RWQ7_Y);XQ_[`UY_P"B7H`_-J@`H`*`"@#:\&>&
MM1\8>)]/T'1EC:^O7*H97VHH`+,S'T"@DXR>.`3@4`?H!\*?AUI'PX\.+INE
M+YUW+A[R^=<27+CN?[JC)VKG`!/4EB0#M*`"@`H`*`"@`H`*`"@`H`*`"@`H
M`Y;XK_\`)+?&/_8&O/\`T2]`'YM4`%`!0!+:6T]Y=0VMI#)/<S.(XHHD+/(Q
M.`J@<DDG``H`^W/V7OAD_@OPP^M:S;R1>(-60;X9XE5[2$$E4'5@6X9@2/X0
M5!0Y`/;:`"@`H`*`"@`H`*`"@`H`*`"@`H`*`.;^)EM/>?#?Q7:VD,D]S-I-
MU'%%$A9Y&,3`*H')))P`*`/S5H`*`-KPCX6UKQAK*Z5X;T^2^OF1I#&A"A5'
M5F9B%4=!DD<D#J0*`/M;X*_!#2/AYY.JWDG]H^)FAV27#<Q6Y.=PA&`1D$*6
M/)`.-H8K0!Z]0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`'YZ^./AQJMO\7]
M=\)^&-,DO9(KG?;P6FZ0102%6CWLWW0JR(&9C@'J>]`'IWPZ_9=U.^V77CN^
M_LN#G_0;)UDG/WA\TG*)R%88WY!(.TT`?5'AKP]I'AC2H]-\/Z=;:?9)@^7`
MF-Q"A=S'JS$*,LQ)..2:`-2@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`__]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1O9RYG:68`
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$P-B`Q,#4Q-30S-#$T
M-R`P,C,U,C0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA'0`>`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+``````=`!X```C^`+$)
M'$BPH,&#"%<H1,B0X0I6K%8TG$CPX9]`$BD:5+C""D96%S,F9&C%2D>+&!VF
M/!@HHL)`,$TF9"7SX`J8+2&NW,@*IDB"&(-"I/ESX,VC+(_F[%E4X,F=V#C>
MO#9T:,V*)G<"4`+Q(=6J3)MVU*I$TT>P.O5`(@&`A%L`#[5N5?(0;2"U;*R0
M0,*7A)6(!0$`*+%4IQ6\>ECI64%B16*H4;,.#522!"0VB=$R+:C4<-O+F343
MQ3JVI&`DF$5;+2I1ZEXDH55?=?A7]6J-':OBU#V;(=S:-"GG'HW;Y%^,)8UO
M+I[5"ES!OR&K;-XZ^4WIG$N^I/G<Y/;>!(DD@G6N?7Q3I\+-EZ\*'GU6G-JU
MXZ3<WBF`J-`%8]._(O]]@0$!`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O<WEL=F5S=&5R+F=I9@``````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-38T(#$P-3$U-#,T,30W(#`R-3`R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$@`"``]P``````
M"```"`@`"`@($```$!`0&```&`@(&!`0&!@0&!@8(0``(0@((1`0(1@0(1@8
M(2$A*0``*1`0*1@8*2$A*2DI,1`0,1@8,2DI,3$Q.2DI.3$Q.3DY0@@(0A`0
M0A@80BDI0C$Q0D(Y0D)"2A`02BDI2CDY2D)"2DI"2DI*4A@84CDY4DI*4E)2
M6@``6A`06BDI6D)"6DI*6EI:8P``8RDI8SDY8UI:8V-C:P``:RDI:UI::VMC
M:VMK<VMK<W-K<W-S>W-S>WMS>WM[A```A`@(A'M[A(1[A(2$C```C(R,E```
ME!`0E!@8E)2,E)24G```G)R<I1`0I1@8I9R<I:6EK2DIK:VMM:VMM;6MM;6U
MO;6MO;VUO;V]QKVUQKV]QL:USKVUSL:]SL[&UL[&UM;.WLZ]WL[&WM;.WM[.
MWM[6Y][6Y^?6Y^?>[\[&[][6[^?6[^?>[^_>[^_G]^_G]_?G]_?O__?O___O
M___W________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________________________95E8
M(?D$`0``_P`L`````"``(```"/X`_PD<2+#@/P,7#"I<N#`"PX<0'4*<2'`!
MC04N_GU@\('B0P,"`@`@L,#C1`(0```(0,/DPPL"5`(8`,(E0P(R50X@4-/F
MOQ4."(B4.8`H@1`4+3B8X.!!@@(Y"X@HJI,#`X@2MHQ)LT;+E1X)=*;X,H/J
M``XBKK[4,(8-G3E<>A0=D*(-&05%!52(,F("4Z86%%I@>X>-7)49RJS)D&*$
M`B5B;H0Q8T8-&S$:`AL$(::*`J(CR+!9$R5!@PM%IDRQXF8-FS%@$A:D,0%"
M`06X%4!(@49-$`]$B$!9,KQ)B`PS@*`P*('%D"N6UZP9@X3'C0\TD@R'4MS,
MF`Q8*OZL('C!R9HY=?#<P3.G"ILX96#0H+&D_A(B.MB0X8"#!7DG<=BAGGIW
MH-$"&6W0$08,*F1'A`HUG%'&@6#<((-`#"@1QWH<VM'&$6+TD,(82J"Q((1>
MG)'&$66045,,`DU0!1T#WI%''%JT44<<8@"1AAHEKB'&#SP`(888/0DD@1-M
M<'B'AU_,8<<=:@@Q@AA#C`''BFB,P84&$Q0T01DTVD@'%UK,L5X<1ZA1Q@\X
M\-"#CV2`J=`$9'0Q!X%UT"$@E4C$$0<0:L311AQC)&E0`TK,.*`=>=Q!I1)K
MU+'&$7&HE^A#!#R@A)1.LE&&$6K@P:8:3[H(D447/+&AAU-C:$#!#674H4:@
M=ZCJ$05/I!&K;"N$``:I>+"A@4LE*.#70#;$V(,<=XPAFTDE%-3L/PZ44=BQ
M/BTTP1IXJ!%FMPIIP$9A#Y!KD`5BJ+=&NA,%!``[````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;6EL97DN
M9VEF````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,C`@,3`U,34T,S0Q
M-#<@,#(T,C4Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`
M,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`
MF?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S
M`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS
M9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S
M_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF
M,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-F
MS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9
M`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9
MF6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9
M___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,
M9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,
MS/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_
M,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_
MF?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````A^00!``#8`"P`````(``@```(_@"Q
M"1Q(L*#!@P@3*ES($-N*%2H@KFBH\*$*/ZA029.&2B)%@@^I8-Q(DF3'B12K
MB"S)LF3'ABK]M)RYD0K*A"I7MO2CXF))%0!N&EQ!16=+H```R-R8-"A"HGZ6
MMFP*0(5&:4@!'(1JU"55`%0V^FDJ5"!4J4>IJMB(*NM0D6A9CJ5*DDK3@ESC
MNLP*P*3;@43ATA3;=&W=NX!%=IW)TV=)/W9!*M8[N"4JK8D%5]Z,V6S1J#-[
M;N98]JQ>H%<'JS"HXK/>L58'MWT+F;+=V)8C$@P4R$KKVHRKIF8+="!OWKXG
MTVQL-6-/I]B.]^[]>[%)*CVSVS0^W4KOY)HW+K_<W?U[:[B4358Y*-V[%=_G
MP[-M6]9@^_=`S]?&_O"CP./N6>21?P06:"!!`0$`.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+V1I;F\N9VEF````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C$W,2`Q,#4Q-30S-#$T-R`P,C,W,#8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA(``@`/<`````
M````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!F
MF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_
M``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,S
MF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,
M`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`
MF68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9
M`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_
MF6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF
M`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,
MF9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS
M`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9
MF<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\`
M`/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]F
MF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____
M`/__,___9O__F?__S/____B_)```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"'Y!`$``-@`+``````@`"````C^`+$)'$A0(`F!``X67,B0(8F'#QM*G`@Q
MXL2+!2M:Q,B11$(D'$-B(U%BHTB')4K0J?.$3HF3"TNLH$/GR9Z;=%;`)%BB
MSDTH=?1`V?,DD,Z=V%;L^;1G!92B1@,9W4F"SJ>K4'):,;IB*LP22T%]RBG3
M*(`5);\N9?ID15NG,Z&L4'$2+%,KI$@]R?I$SY,G>5<<Q6@7\+.\?TD]*U7J
MV6*]''LVS5LE;V/'F!U#QOBDS@I253YG'JWY"6&YB!63'JU'H<2J@/6J7HUY
M\\0D-0&MT$,[<RE2="G*U2-X]FI2>8"?[JM"]&A2E_,&IUB3.`#`ES7G:4RJ
M-4?<4/Q7(FD.?7$>0(?]B@3O5T7SOGD1N^Y(9T]X0,3;NG>/5"E1MRXA55!/
M5RW5E(`$(;%"'5==1<=\2)'@U$T%OH1@4H$((A=04*1TX0J"M"*(($;)=,5@
M#`4$`#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8G)E="YJ
M<&<`````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,#`W(#$P-3$U-#,T
M,30W(#`R,S<R,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/[X*^(_^"E/CWPK\*O^"?O[9?Q1\8^!OAI\3=*^&O[-_P`6OB!8_#WXQ^$+
M7Q[\+O&?BWP9X.U3Q)X!\.^./!]ZCVVO:!JGCK3?#EK=V;M;L/,2>*^T^6)+
MZW^W*_FH_P"#FCXG?MA^$_V7O@Y\(OV:?&6B>&_AM^UCXW^(G[./[2FDZ'X"
MN?B'\>_$/PXU[X7:YX\U\?!_P_/-9Z+J>F67PH^'WQHM_'GAZ/4=,\=>+[C5
M?!7A?X?7]MJFJ7T@RKUJ>'HU:]:2A1HTY5:LWM"G!.4YRMJHPBG*36J2;2;T
M+I4YU:E.E37-4J3C"G%;RG)I0BKZ7E)I*^EVKV1_%7_P3SL/%V@_&/\`9)^*
MOQ;_`&D?V/?V:_@A^U'\3?'?[0/C+Q-X"USX:_!/XQZ1X4^"WQCU73O&7[.O
MB>W^$MO\,?%/PS^'?QR\>V/A^?P7\-+C4H_AM:>$_#&@>)/`%CIEGX-U3P?J
MGZ:?\%*O^"S7[/<'[8^F:=^S]^U1^W3X-'PQL=5\">,?B1^SKXI^&'BC]FQ/
M$GAO3?$NI>&]>\/?L^_$"23PI^T/]L\<^)H?#/Q-UKQ!XF\`:3-X6\$VJ^`[
M_P`:Z?>6>H3_`&5_P1K_`."-W[&_PU\$W7[3</Q-L?VT=#^-?@+Q5\,[:U\?
M_!_3_#GPM.CZ/\6XGUV:X^%/Q+TG6?$FF>+=)\1_#32]`O;;Q1,EUH&JZ1XB
M`MBNHQ0Z?^4?[6__``;F_MQ:9^U!\6K?]D_0/@]XQ_9V^/7B._ETWQ%JK?#C
MP5!\'/"OB+QOI7Q`/AFX\-:S9ZAX@\(P^!/$.A:;X8TWQ-\"+'4=<U_P+'_8
MXT_2M!\7^+_`</\`/5?B#PYXCX[Q\\TS*>`AE&68G"4/[1I4LLRW%8NK4:S*
M5:CF6#A7>88=QIT'A<:O9XJ5!6P]9^VA/]@CE'&>3<*8.C@\%'%/,,QHXF?U
M*M/'XNE0I4X/!*E5P.*G16"K7J5%B,*[THU6W6IQ]C-?V+?LR_$.]M_V3O`_
MQ0^,O[1OPI^-MOI_@O6_%?B/]IWPKIFD?#OX9^-?`^D:GKE]I7Q&U'2I=9U3
M1O"<J^!K'3+SQV;;56T2R\26GB"2RCL]*FMK6W_,GXP?`;]I[XT?\$G_`-I3
MPCX\NK?P7^TE_P`%>OVZO@EXK^!G@#Q1IE_X)U+P'X!\=>)OV8O#OP\^%7Q@
MTVRTRRM_"7B#P/\`LH?LW:I??%?1+V_U:6^.D:WX5DUOQ7XWUN'2-5^*_P#@
MH#_P3@_:&^$/['G[$_[&7PB_;-\7>./AUXW_`&E?V:/V:(O@O\8?#O@/2/@]
MJWB3Q)-XUUNZU;Q1XS^&_@"T^.&H?#6?Q]9Z;JEIX!UKQ1XMLM#T58K:T;5-
M0\.>%;K1OVU_X)WZM^V+^W;^W7XO^,G[8_PW^#OPU\%?\$P_$GQ%^"GPYT?X
M#?&6^^('@[QC^V'\4/`>FV'Q$\9WLEN\5Y?K\+/V</B(O@1?#GC.STL^&?$?
MQ>\0$Z7>^+K#4[+X=_GG"O!/]M<4Y%BLDS?)L=E%;BF7$N:.GAHX#,\)DW#&
M:T<=E-#"8"MA\.WA\TS=X;#YM2P.#C@LN^J82-'$SI58J.G'>=XMX7"Y7CL'
M7P57+LNPJ:GB'B56Q^+P:HU).K3K5X35&E3G+#5<56^M5(SQ$YP527*_Z0K:
MVMK*VM[.SMX+2TM((K:UM;:*."VMK:"-8H+>W@B5(H8(8D6.**-5CCC5410H
M`!4U%?V:?C`5^"/_``5:L?$OB[]O3_@E7X*6.]U3X>>'-$_;J^/OB;0TE6+2
M['QG\-O"7[/_`,,/AQX\OPM[93S77AH?M`>+?#6F0XU*T\SQ[<SW6D22P6FK
M:-^]U?BK^U)XLT?Q3_P4>L?!\^DWI\0?`+]D#P%XDT/6&U"*XT^;2OVJ_CA\
M1++Q5I4.E16EU>Z?>QWG['/@FXN;R":)M5AN+2*YT^Z&E:7<)\+XEXW^S^!.
M):^MYY>\)'E;34L?6I8).Z:MR^WYF[VM%WOL_LO#W"+&<:<.TI6Y:>80QDE*
M/.I+`0J8WV;A9N?M'AU3Y(IRES<L=6F?,_[%_P`/WT7XM?MV_$[3=0\2P^#/
MBA^TW:VW@7PO>:TUYX+T]/AG\$_A9\/OB=XK\-Z1!K6M:?8ZAXG^-6B?$ZU\
M330M'>:C-X;T^'48(YK%[5OO<^423O?)WG`A11G/R#"RX56&2V!B,X55<<C\
M+X?'O[;'_!,RXEG\7?#KPW^V1^P)+XG^-/Q"\7_$/]GOP+XBM_VP?A?XT^-W
MQ=\5?&CQ#XG\<_#/4O'VH>#?''PYTKQ7\0O$6GW;?#W2]/UKP_X4:#Q1KHTU
M/!]S:>-?V,^$?QA^%?Q[^'OA[XL?!?QUX8^)?PX\56]W<^'O&/A/5['5-&U$
M:;>SZ9>0K(D2RP7VFZA:W>FZOI-[#;:E::E:W-GJ%I;7EK/!'_$/$F`Q<:RS
M15J&899B%0PF$S/!R=2C..#PU/"X>EC8R2K8+,JF%P\,17PN,A2Q,G.=91G!
MN9_3.2XN@E/`2C7PV8TI5L1BL)BXPI5N;$XBI7KU<.YRG#$X&.(K5*5*MA9U
M*490]E>+2C'P7]K;]G7PC\=#\#_%/C3X[^/_`(%6W[/WQ?T7XW>"];\$ZA\'
M]*LO^%KZ%I][I'@K7=?NOBW\-?B!HEZ/#,&N:\-,\.O;Q^']0EU^9_$6E:S>
M:;H4NC_.?[`6F?#K]FS]IO\`9W_9P_X)_?M/?%?XP_#O7OC-\3=;_;F^&]CJ
M'A?]I+X?7^L7?P)^-NI>(?CI^T3\?K;X7^,?%/P,^..O?%CPU\)+'^PK3XK_
M``\T+Q[K]CX=\*3?#2RC\87?B2/S3_@M-^RYK_[<OPQ_9(_8L\'W_A_0/&W[
M27[8OA7P[I/C;Q)HOBK7(/`6E>$/@A\>_BAXN\:6>F^&I$N-0N;+PWX,O-)G
M@U$?V,VGZO?W=Y+I<=E_PD^C?!G[*WPX_:/_`&`?VJ?B!^R5\'_'6F_\$\_V
MV+OPSI7Q=^'O[*LWQ6UCX[_\$Q/VQO""1W_A'5/BSI7A/X@V5A\6O!WB3Q-=
M_#O6=(\1ZEHGC+PQ\2O"'@OP9I?B1+'7M/T'Q=I5K^K>'N)I<*9'EG&V=9OQ
M%A>'\/BL;0QE/)\KPU7+\'A:&)?[_/*T9SS/'9<ZN(QF(KPP.`QLLLHT*^-Q
M57`X:"K'Y7XA8O#8K,L?DN&RK*JV85,+@ZCS#%XC$/%J<J:<:6"IJU'#5(48
MTN1UJM*%9S?[NK4J.+_O3HK^*>]_X.^YO@[>W?PB_:+_`.">/Q+@_:#^%EU<
M?#CX[0>`_B+H5AX&A^,O@>5_#/Q/B\&6-]IOB^]LO"D?C;2]<3P[:7GBWQ1=
M6^D"SAN/$6MS(^IW)7]>TJ]"O2I5Z%>C6HUJ<*M&M2K4ZE.K2J14Z=2G.,G&
M<)PDI0G%N,HM--IIGX4X33<7"::=FG&2:::335M&FTF?VL5^87_!0;_@E5^S
M_P#MZ3^%/BC<_P#%FOVP/A$NA7GP!_:U\'Z0NH>./AWJ?A3Q/'XR\.:/XL\.
M'5-%T;XO_#"/Q`+UM6^&GC2Z-A)I^O\`BA?"^K>$-;UZZU]?S)_X+]?\%O/B
M'_P3UO?#G[,7[*FE>%;G]I[Q;\.;7XR^+_&GQ$T35]6\*_##X.:IXQE^'.C7
MOAC2;66PL?%?Q(\2^*XM2?3+?4M0;0/#6C>&=1NM;L;^[US0XHO\]+]H7X^?
M'/\`:X^)6I_&/]J3XK^*_CI\3-8"?:_$'C.6R73+!5T[2-,:T\+>#-'M--\&
M>#M,:VT33E&G>&M"TZ$F`/,9Y7DE?'%RP[ISH8BG"M3JP<949Q4XSA/FA)3C
M)<O*XW6[;NURI:O?#*M&I"M0J2I5*52,HU8MQE"<'&<91:=^9.S6R32=^W^A
M%^SE^T=XN7XW?M"?L9_'+6?`,?[6_P"R1KOAK2_B7'X!U`0>#_BMX'\8^%=`
M\:^`?C#X-\+ZEJ%SXBT;3-;\,>+?#\7C?PQ=OJB_#KQIJ3>'1XAU".[TF[N&
M?%G]EK6=,^/MO^WE^RU#/IG[1^C^"]5\.?$GX'+XKMO`7P<_;'\/0Z7=V=CX
M?^)VKV>B:S+X=^)6@I%H\G@3XL:CIM])ID^B>"_"OC"#4O!<&GS:3_$+_P`$
MI?CM:?LE_MN_"WXM7FE:CI7PH\1:A:_`3XR^)-"TM[FUT[3OC1#K"_#G2[G3
MX+JQ2]GO/B!X)L/%]S!IL6J^($\+_#WQ/J&GZ)JS::EM7^AY\-OB!X&U_P`9
M>.?A]H_B+3;KQ_\`#VW\-7_C7PP!<)K6CZ'XTLKR[\):I<6]Q;P`:/KLFD:S
M#I&LV$]WINI7^B>)=(9SJ?AR_AT_^,_$;(*G!/$E?$Y)AYT<IS7+IUOJ_)5J
M81X.O-83,<MQ/ORD\*ZTZ3CS5(3H+%X1T*M&O&A5C_5O".=X7C+A.E_;-:G4
MSS*<QH8.6)=6E3QE;$**Q&7X^GI2OBXX:G62<J=?VRP6+]I3JPG6C'Y6_:3_
M`&J+_P#9B\6_\$K?VD?C'I]C\(]'U/\`;`\#_#?X_>&M7\?:-'X4^&FF?M"?
MLO?'KP+KK>,_B3I^FW'A_4/#GP@\=Z[HFO7NN26VG^'O%%YX6L7;5O#EK.FJ
MV7O7_!Q7X!\!P_L`:O\`M1MX@\"^`?V@_P!CSQ_\.OC3^S5X_P#&.NV/AJ63
MQMI'CKPW-XC^&&G7UU<6LFMM\5?!%IX@\-IX-226'Q#J/]G)=P-8V]VP]A^+
MWPB^'GQW^&7C?X-?%KPM:>,OAI\1="O?#7B[PSJ%_J6FP:UH.JJ(IX$U#2;W
M2-:TZX#1PW%EK.B7^EZMI5W##J%A?6=Y;VUQ;_PZ_$W]OOQ[\*OAOJOCGQ!\
M>OB]\;_VL)?`WC/]CW_@F_\`M#^(M(TWPEXT^&/_``3^\&_%76[KQ5^U[XB;
M4O$&O7/B#XL_M-:9KEU\!/AC\0-,\/V?BZP\-?#+4O'C?$2XUW1[J#Q)^H>!
MN;X'.>%,YX;Q>6TZE#*\7[;$4ZU*.*P&(PV<5,15HX>5*M[6<E3JX6M"5/$*
MK&5/V<Y5IWG&G^3^*^5UL%GF7YM2Q"D\RPZI049*GB*=;+HX>G4J.S5.*E3Q
M%&<73<&I\\8T5RPE5_HZ\$_\'(O[%FG^#/"5A\8?BOH7P@^+=CX8T&S^*7PE
M\8?#/]H;6O%OPN^(UMI5I#XW^'7BG68_A[I2:MXC\$^)DU/PUK>III>FI?ZG
MIEU=+868E%O&5_GF_P!@Z0_SW6GV>H7+?-<W^H6EK=7][.W,UW>W4D)DN;NY
MD+37-Q(2\TSO(WS,:*^$J_1'\-YU:DZ?$GB'AZ<ZDY4\/1S?()4:$)2;A1I2
MQ'#->O*G2C:$'7K5JSC%.K5J3<IR^36?XQ))X3+9.RO)TL0I2=E=OEQ$8W>K
M?+%1O:R2T/ZO_P#@Z656_P""H'BDLJDI_P`$N/@RR$@$JQ_;=U9"RD\JQ1F7
M(P=K,O0D'^5>BBOZLQG\9_X8_D?/8;^$O67YGT#>2R:=_P`$[OC)XIT^1[#Q
M-H__``4`_93M-(\16;M:Z[I5KIW[.?[5.NZ?;:;J\!34+&WL=;O;S6+.&UN(
MH[75;NYU"!4NYY9G_O4T+5=4M/\`@M#XIT&UU*_MM#UW_@F5X=UK6]&M[RXA
MTK6-9\,_M??$73_#>K:KIT<BV>H:GX?L/%/B>QT2_NX9KK2;/Q'KUM82V\.K
MZ@EP45^%^-_\#*_^R;S[_P!3N&C]5\*O]YS'_L:97_Z;S0^[/VKM7U;P[^S!
M^T;XC\/ZGJ.A>(=#_9X^+&NZ+KNC7MSI>LZ/K>G>!==O=/UG2]4LI8+[3]5L
M+R&*[LM1M)X;NUN8HYX)HY45Q_GL?\%3;"QT3]JVY\,:-96FD>&O!OPQ^&_A
M3PAX>TRVAL-#\*>%K#2KG4+'PUX;TFU2*PT/0+._U;5;ZTT;2[>UTZWO-3U"
MYAMDFO;EY"BO%^CS_P`B_B__`*_9#_Z3FAV^+G^]<.?]>,S_`"P!^<M%%%?T
M(?DA_]D`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O=VEN;FEE+F=I9@``````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#4R(#$P-3$U-#,T,30W(#`R-#(T-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<2+`@```%$RH<>!`A00"D2#E<
M2!%`LV?-$#9L*)'B0HL8GQV\2%)D0X\&0UX$H+)EQH,HL8$D.=-ER),554)L
M.?+FLXX>698L*=0E4)@&20TU6A3B1IP,ERX]2.KF09-(!=:4BI&J5(E99=K\
MRO4B4*U5RXZU.5&KVK<Z4\(EZK*MV[53E?),6'2NR+U\_=)\^A'O6`!NW-AE
MN-7PX(J*^SKN6A&2Y9YS%VMM:!E20[8ASQKL?-!-9\^'-RH$<-HS:])7S49$
M3'A@:]BMG[Y^?=GA[=.\?WLV#5R@\,ZF@^/.C?"X\^&W(69TS;DU\>>7:>I4
M[CGZ[Z)UN0A3/_A=;[.````[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]E;&UO
M+FIP9P``````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8Q-#$@,3`U,34T
M,S0Q-#<@,#(S-S(U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`^.?VB_\`@V9.B>#M?\1_`OXA7FO:]9V_VFVT/Q'_`*'_`&IS[=/_`*^>
M*_#?X&_M%_M<?\$L/CA=:7_Q57@FZTW4#;>(/"NJD_V+KUCGOIG35O;J>OM7
M^HSXSM]!\/Z9+JEO+>36FFZ/KFI:A#!<_;+VZ_LO3N1VK_+L_;F_;6^+/[</
MQB\4>,?&_P#9V@^'!K%];>!_`^E:/IUG9>&-$_M'_B6:</\`B3_VWJVKC_F9
M=<)/0]`<5^)\(9OC>(<++"YDH9GERC:TV[JUNF]TK\UU:U[:\M_V#/<!#!8I
MYIECEEF92DY)P;6LG>RM9ZOU=TK']%7B3]I_X4_\%7OV<M9_X4/\0M2_9P_;
M;\*^'[[6]'\-^'-8/AO1?BS?:7IW_$S\.\?]![_F6M=_Y&/PYXCS_P`RM7XP
M_L2>,/V[_B[\:XO@C\*[K4OB1?Z]<?VEX_\`#GQP_P")QX+T+0]+)TSQ-XB\
M<ZIJW_(J:1H/J3GI_P`(L?\`A*,5\#7'P%_:!^`W@+X1_M/^%+37M-\+^*I[
M_6O"_B/0[@C^RK[POXC.E]B.<Z9D=LXSP<5]!7G_``5$_:SU?PCXN\$>'IAI
MWB?XA`:;XA\8Z%X?-GXTNM#TP$Z9X<_M/2@#_9*ZOJ>IZR<@C.J'!/!;NPW#
M/#JP>/R_#91D>9Y?F3DE.3A&IE%N7FNTW*]];\S2:T:;L>GA^.^-<%7P..K\
M49]E^/RWELO^%;EE:UKIW4D[VV:U\[G[[?M3>/\`_@DU^Q<9=&\47VN_M!?&
MT:?9C6/!WPK\4:EX<^&7AC7/^8EI^F:H#_;0']K@Y')(P25^85^"_P"VE_P4
M0\)?M5:;X6L-+^#0\*ZSX#M_[-\+_$"X\4ZCXD\:77A7D_\`".>)M3U;_D+:
M1H./^*9_Z%WH.>O@]Y^R[XH\!>&O"7QC_:HL/&'AO0?B1?WQ\'Z']GQXU\9#
M3!_Q,]1_XF__`""=('_$MSK>O=<^QK^F;_@BO^RK_P`$BOVX;/QE\.I/@]X\
ML_C;\,?#]CXLUC0_B-XH_MBR\4:&=2_LO_A(O#6I^$_[`_M;^PO^)9_PDFB'
M0.NJXYSQGA<HX:X-PLLSP&"<U@(^]*+O":5KZN_,DW9WNF_DS;B?C_Q"X_G"
MAQ/GCS#!PE%T\HE=5(M<MI*]FGI?3S;UN?RO6'[7G[2>EV-EIEEXV\0066G6
MEO86D`U,*(;6SA2WMX@N?E$<4:(%[;<45_I;6_\`P2M_8/L[>"TB_9W\"S16
ML,5M'*?#HE,L<"+$DAEQ^]WJH;S/X\[N]%?,_P#$3N$7J\OA=ZO3J[7^UYO[
MO6W<LYX^22CG^81BDDE=:)<ME\DK?+R5_2+/X]^`_%-EI>LZ%XDTW6+7R/LM
MO/!J`_TH@'\?S_2OYU?VG_\`@CW^Q)XL^+^L_%KPGXI\=^%;7Q3X@OO$E_\`
M!WPY<>'3X7NK[5"=4U,:9J?_`"&O"FD>NAD'_J5LU\;>$_&_C+X?Z:8O!=_J
M4TNO7'V800?\NOT]?\YK]J?AOH=KIW@C08O$D7]I:S-;_:=0OM5M_P#CZOO[
M.S_9W7GG';(]3SC^<.,..\VX"RAK)L<UF&9IQ23:LFK/E[-)Z.RLU?<_T#K?
M1CX:P.9+&8C&K,L`I<RR:5]'=.^O9ZM>3.)E^''@.7X>:!\-;GPMII\">%?#
M_P#PC?A?PX8/MNBZ9H>E_P#,/TWGOZ]SU/45Y)I_[,'[/WAOQ%:^+='^''A6
M'7=-(N;?58-''^BGC\3W/TK[7N-/\.1I%+'I6F^5-_SPX_R!G'^37!^((]&M
MX;^6.ULX983_`,^_VSGZ]2/S/:OYGPG%^>O$RF\QSWFG)RE_PL/EE)M2E=7U
M3;=[WTOH?I%#PYR3&5HQKY;DBBDDO^$>-TERI*^EVE'=;VW9^7G_``5`_9]^
M+/[>.@_!"U^%&E:%J7Q5^"GA[Q7HEMX5GU#3?#E]\1?`_BC^RM4`\,C5B-$_
MM;0CI?.?^$?/B+PYJV>>`>L_X(A_L"_M`?L5?''Q[^U)^TQHL7PL.F_##7/!
M/P_\$7'B#P[>:SKU[XHU#2O[3\1:F-)U?7_[)TC0-)TP\YY\1$<#G/N7C_Q(
M=#F_X2+1XM,AUG0?^)WI\$%AS_Q*^?\`.>M?,'Q+_P""@OC?Q1X=^P>']*GF
MEO+?_2/]'^QFUS^/8_G^>?[#\/\`Q!S[-N"EDN+2E9*+FUS3Y>9-7;N]-;O>
MVG-;0_GCQ1^C8EQ9@LWX>P2BLQW25HWNKZ+1+HELNVQ^\5Y_P4)^'\%W=027
M]I+)#<3Q22M/N:1XY61Y&;'S%V4L6[DYHK^/^X\1>,[F>>YNV1;JXFDGN0J>
M<HN)7:28"7/[T"1F`D_C'S=Z*^F67</.S<==&_7W;]/+^K._RJ^C[G6G[Q]/
M_;;=?3[O/7Z'\`:I%<>.O#?A>WE\Z*SUBPN=0GYL_P#P69/_`%#/>OW,N?'^
MC3Z5%%)#-/%]GL?W%C<?8_?^I[U_.?X0\22QZ_H/BBW\X13ZO]IN)_\`E]^P
M_K_CGVK]6=0\:12:!:RV\LWV74_L-S<3SV_\N17\^^+N3XC&X_).7=->BVO=
M+[[?Y'^BV#R[#YT[JZ\[6>Z:N_6Q]#ZQXLTO[-:PZ7+>0R_\>UQ!/_H?'_0.
M[]!_];G%>&:Y\0Y8TEADOYIHH;?_`$>#[1[_`/(.[^OY9KQO7/'G[_\`=W4,
MT7_'SY]O_H?V3Z]?[6[>P->7ZI\0_LT/E277DQ0W%]<_O_KQD<'KZ"O@\MX:
MK75XW>E]->GE^730]NEE6%P"OB''1::JWGU_KKY=1\1_&%U<6%_+%+-YOV?_
M`$>#[0?MMU_/W'/_`-:OS)TN35([/S9+7SH8;C[3Y$%Q_P`>O\_3\>OM7T9X
M[^*>ER>';^6XNA-?P_Z-;007'_04_P`\\U\TZ?;Z7'?RR6VO^3+-_P`?%C/;
M_P">?S]>:_H3@3)Z^!P&-TLM+)Z:7B]$^]GT^\_/\]S/#X['X+ZLU[KZ.Z5K
M7T5[:_KU.C/B&W4E3&JE201D<$'!'7L>**G72K!%5'DL7=%"N_V`Q;F489O*
M_P"6>X@GR_X,[>U%?;^Q?6_WHY^9^7W+_+R7W'0Z>JPZ).L*B)4NO#&T1@1A
M<9QM"X`QVQBOK99YSX)\(.9I2Z>$3,CF1RRS?\]5;.5E_P"F@(;WHHK\UXTW
MI>L?S@?;\-?[O_VXO_;3Q36[Z]EW>;>74NRX&SS+B5]O3[NYSM_#%<9XPN[K
M^S#_`*3<<7/'[Z3CZ?-Q117AY3\</2'_`+:?-\0?\BA^M0^;?%<DCW_AI&D=
MDEA^T2HSL5EN,?Z^122'F_Z:L"_^U72:$23JSDDL7Y8\L>>YZG\3117[;@_X
M?_;O_MT3\PX<^./^)?G`CW,>K'\S1115'W1__]D`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O9W)E
M96YH96%D+F=I9@``````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-C(R(#$P-3$U
M-#,T,30W(#`R-#<P,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6%!`$T`]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````$$`30``
M"/X`L0D<2+"@P8/85@!8"`"APX<0(R)4R'#A"HD8,:ZX^)#ABD"MKEUC=<V*
MPHPH#U+DB'!A()(B6<$,U#"E32L5`5`TJ)"%R&N!6*Q@<67D"BLV,ZX\))-5
M()HU!P*P$E/&`P0L'CR0(8@5RZ007<JT(H/JM9U29R+@RDJ052NLHH(]R,*B
M("L/+NBU\"`0T(U2?\J`\',D@K4YYQ9DZ#?O!0@6]#X0:3(M90A-`V'+R7#@
M1HLV&8J,+"-'%P06+,1D"<!O200;5ZA0`<!`C"U;:"^,L;GB5X@4S2*2$5(P
M9I&<=2X,PSS,(D:,#!G2O4(ZHUC88QU2B-;A0BX_`_[)*%S2`B+D#`W`J`VC
MN?/GTL7DKF(HN_U8T@W%T/E0(<QKI[DFD@P7P,20#3PDZ!YSBSP'771;0'??
MA+$`XI%*`!36Q04RP,1*7C^Q0)L-8)2X8!B,./@@([#`0N&$AG"Q'W\$*43>
M!7R])$-D/UD1@WH\F.A>@RNNB)]T+]['16>>`?`?4`^D)N5X(E41!@PD"MD<
MD884R2(7LZG`19+9/;%0C0!065@@*R#P`"+%78-?D%INZ25T+HH!B'Y<K,#%
M*MC59Q\@NA&$TPI/BH0(4N3%P@B==3H'79<KNHC=(3K1%D.?*JP00WX4R87-
MH8F2]],AAH11(A@GHNBEB_[2'1(#))"L``A@33)ID$NFFLI*=%E&JB(C8N`)
MBRHJ[$<++4APEY)%O9(7"+'!LCHD=&'$L((8TGER"1LD`+`L)!XAI9%=T:ZD
MPJK6+MCI?TY9@1,))+#!!BVT0H+$F>?J1%Z\Z2$8:1A;:"N@M$[)AJ^]2)`0
M6G(<I3>P:-&:2A&XOTD4ZH4"A;JJ>^LM5+&I.`&`!!M(@!7;028!4*<!OI7:
M:UT)(>&)8@\9\/&5R25Z%WG\RH"S0SCMG!RZ(PGR+XU#.Z10NV$<S1`+\IJZ
M&6]->^>RJCPG9\@6-6W,$-99MP2`>[IQ)@9MN7*6<=F]N0=S3@:`+6JN>CQA
MYOYG=^.\7'-S5[2%(?P65+(>R21NIF]E+V0#X)QM(<94!RVD1RF))U-*N!69
MVS1.!C`7^!-ZY`W:8@"4KD+FB9-0BB>Z-OUWVI@GKD?AGCVA>>FLJX!Y[$,O
M=$,8NB'.NB=F%G1Y,GIPE[GQP`<?^GK&LZYXV``D7@I_&UF_.-P"G;V?)\FL
M1+[M%.E>RA,$`?!$[<F<_C98`&S!`P"EW+X0;=8OWSP+X:O($U:2D-,-;07M
M21U#5%`%]UDO<1P16T6D8D"<R89XBUN(W:JG/0INI&6@V1@`Y\*TLX5A8XS8
M@D)<Q[R3;*144#&9OOHF$7.53"JBJXAT"N@^CP`@!O[1D@$`[D4+W#E-5-B+
M2NBB5A%N(46$GI+92*H`B66%:WX%"57'&/*8,]4O#(';GR%P54"9C(P555P6
MLXQHD$-QSPH'0(!>#L"0+1"/,]+I5``!(2^9L<(*:AS7OK`8/D2Q:2%YR<L.
M=$#'"*60,RHPA*Q4(,7"W(MS1"07#9M$$C:AY@)NV@$HS_:@Y'PJ!F;IE8<N
M<8F*(`%?;-S5"D02B,A<X"H[V`$"0N>@M'$F3KT"B154`0B']:9AL90E*PAT
M@5SJX#!?#$.J4NC+A0!B9"*I3O+:%ST,(4`'S<SE#NBX1!480`7<(EQ.*AF3
M&!FQ9>?ZI@[$&809>(IX=/X$``-CM#%LEB06S@(+3A!P`*T$X:!!*(-"O9`#
M&<S`"S/87PP.L:0,1>L05HC%*DZB&(5$]`!<(`-"%:K01)`A$2:E2"17T:=2
MR80+];'0)C.B$P^)E*0E16DB^-80A4P458*RSW:2^2S7!,(D,L"I3DUJA:/R
MZSLODE4W4V*25LAD!0>0`0N\4`:4=M6D0F0<10`UH5`14B."8`A)N_#"LW1A
M48B(GEDEV+38J+6K73B`658@`T2,)992.RM-^6.1+B@T!ZX!0!=,@BBG,*UM
M4TV*0LRUD`3!0`:+E0D`\FD1>(+OB+E*$'4T2Z.2<>RSAN,FB>X7/J?>38NH
M[76("H+$VLUXUB$CC&WEVA,&'JB@D(_5+4H`P%OF!'"FPNU(<4_8&^0FMR7M
M:5#4FOO<T*A`4L3J5'"K&Y$?2G-2=A,L=YM$J15%=KRH*^^#NH->V1:I2^X4
M+W=W8RRA$K6]):O"=2:TBO..ER(QV.^$_`NW@```.P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V%V871A<G,O=&EG9V5R+F=I9@``````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,S$T(#$P-3$U-#,T,30W(#`R-#(S-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$@`"``]P`````````S``!F
M``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_
M`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F
M`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_
M,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF
M,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_
M9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF
M9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__
MF0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69F
MF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_
MF?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-F
MS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_
MS,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F
M_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;_
M_YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F
M__^9___,____^+\D````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(?D$`0``
MV``L`````"``(```"/X`L0D<2%`@`!(%$RI<.)`$B3D(&4I<2"+0"H@3,Q(D
MH<(A@(\?(P[LZ'!BQT[!@G4B`1(`Q(A..G6ZM$)DPB<H4^I<&?)2IY.=5JQ8
MM<KFP!67=NI4R?+@SB=$K5D#D%`%@!4I5Y+(J1)DUB<65U@K6M#J4&O/5H3,
MR9-$RJ%#B:Y(R'*5U+&KU+H-]G!K2A6K#I94>-6N4*).@QWD>LGJQ!46I>;-
MF_.CRI@L,X:46A-MIY@?>7;Z.+&I6&M"T>(<O=7A2HD=#]J5O.J93M<K91K=
M"*DW)*A5\JK@FM7U[H:0>NWR/33X"A5+@P$]CHT$I%VT:/E6\4RJ[>@J7ZI3
M]$W^M/?H6I%(M$X>ZEW4SXYE=7()),.#O4F<O9L7[5^4(%&'S4&%O8<:`%(=
M\UE76XE'ET6SO?>1=RN@Y!J#"T&VGV032@5=,#$Q%1)%!8ZEUUT?%G?0)0)6
MY]"+;)RV2HI\+:98B]@@00(;,<Y6TU)^=7400QZIL.%PX*7$$@DL+@28@28F
MF=)B/&48H8G$18=D4PR=E5=B2X6XU&+KM90E4WLIB5)````[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;WEA;F1M;W=E<BYG
M:68`````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R,#(@,3`U,34T,S0Q-#<@,#(U
M,C<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y83H`1@#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`
M,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```
MS#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS
M`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`S
MF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS
M_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F
M9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EF
MS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9
M,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9
MF<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,
M`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,
M9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,
M_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_
M,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_
MS#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````A^00!``#8`"P`````.@!&```(_@"Q"1Q(L*#!
M@P@3*ES(L*'#AQ`C2IQ(L:+%BQ@A`@"P`MM&`!ZQ6;&2<>+'CU98!0JT8N7'
MD@^MH!P9B&,@F2<[PERXXF3.C596X@2Z$V%/GT!Q!@5ZLNA!I"A]6CG:U"E!
MJ$RQ5K4J4&I2JE)Q<AUX])K9LV997:MY\N;&L0,WL@J*MNZUCVY!.F6TJ.^B
M+0#4H@UJ!>W&O'IA\O7;%T;A0';7GAWZ=N=BOV<,%+ZV^>R*NFQ?[F3<N#/D
MP759`7B<."/IO@!.<^XLN6Y@5B)'DXX!`'5DPVH#%7T-N"[MR*=C#'^].JW,
M%71_7V,5HR^CDJ\7G8EM=N4*E=(Y_H?);C%[WQA5OJ\,;W:%^477)[[O"WCU
M5.E6JK^/'W'^^8TPV"2886?XQ]]#_KT6A@'<&9;@(A(]2%R#:\'P8(02DG;&
M9]WIYU]$EV6(V696;'$A1")F!X-95HR7($0AIMC7#859<8.$",K(V!8WC53B
MB0PUHJ-?/!KGXH<,#=E7&+0%9^*+"\6BY"(QL&(E9]U9"*5"2H;!&V\J<1B(
MEDARJ2./+2[B&'20!7+CE@C%*.$9@<1@XADQW#39D?,MI*.7^FW'D8,)'GB0
MB`$"8("+V\%`(UH&`!EGAC#$<$.`!@`2X(U;T$;F?GY*&`8`!=(78*E%GA5I
MF0G):1X`_F]BMNHB-*[D4JGF-1+D@S',ZM>B?BUXTI/F&8J0E/YMAVMCGZHY
M;)\.)>@H:3>02NU)?)*FJT/(F@>#K]H!D&VX&X%+6D1"9C?JLHL8$"MI'Q%+
M'KJO;9=M#,TR]A&[YTJ4KE\Q>+BDN.;5!P"K$'6[+FGNOI<HP=!.)*0!\M*:
M+V,/OSMO10(OLG#!Y6Z$L$(TL;2:7HO9.U^U!O`&<;$,U22<2$N-)!!?L/JW
MT8WECFS07"[%9C))`L%P,6.C6EOMRQL;=)C,,HW$D7TG\\NPR![O''%!A*W6
M$DO0G<P1;E98K6_.L"FZ=5PC68G;337Y.)5;K'"Q\D:XNCQN8E\(!66E4$O1
M_!)0@&@8`Q=;"'IPL!]E9RQ!/;(DM6I!V7I3W:2%`9;:'F]A<+81I3170;;>
MK.'#`)C8Z4<-^_5X2:Z>X7F!87B^!>APF2[BZW`UXJI?C6R;^_#$%V_\0`$!
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:F5R:2YJ<&<`````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`W-#4T(#$P-3$U-#,T,30W(#`R,S<S,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_V/_@
M`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!
M!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!```
M`7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9
M&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY
M>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*
MTM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!
M`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%
M(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/RS^%WB*\MUT2TE
MENK0O<:#)(PC$D<,=O#;27,YF\EG\F#^S07@`&]IU)D4Q`2_TB_LZ_M0?"3P
M[X6TYO'?BK1+*.TAO$O+M]+U36%>RD&HZAI(FC'AS4;73%"E4-_*88X3:!#=
MQF[$)_'7X%_`N34O#=[XOGO$0Z;_`&K=PZ=!;P7=U-IT3SRI$EN+O[2?-&G?
M9?\`CT.P7AE.XP"&?ZO_`&4?B[^W)XK\7V_@/X1_"CP)XQ\'^(?$DWAZXTZ?
MP.WBVX\/V-G`ODMXBBM(-+N#9)92W"SOJWV31UFDMXKBX%S+9JWY7+#5\ZJO
M#X"%.=:$I*5.=:E0MR6O9UITXN^]DV?V+@Z<N%LF>,QT7*ECUB)Q3O/EHQLI
M5.6/,XVO?WDI:.U[G]3?P5\;^"/B!H>G7OP\\<^"_$VA75M8O>ZCIWB72Y99
M9$TN4B&/3;77+,VEV;NZM+.12&FB@>>8P-M:*OJ..ZNTT/4!=7.I/;"X^S6E
MAI_]I(([W17O].O;&&Z>^M;2^1R5N([(W6V^3?<B,_8"S?B+JOPFTOX+>*_%
M.O>)M"\->#?%W@*PM?&DOC;X/6VI>#-*OFU:VMEU'PWXA\*:+/-H]LMI=1Q:
M<;1M=U&2[N;FVU81PC2VM+K].OAY\0_^$G^$/A_XJ:=)-+)K]II>NBSL3;?;
M+AM0CGUP:7*;C0[B>[72$8Z9>SFXLO[6>[CU)S8&T%E<]>6YG/!U'ES=/FHS
M<:D?:0?[Q64HJ2;B[6W3<7T?1_C/&?!]3ZOA<\P^8*&$S"KAYT4H.4;8MITK
M]N;LTG'[48[GB/[7'[7^D_`KP3;R^"/#6C_$+XD>;X:71=#CU*#PY:1Q:JNJ
MW>IS^(OLWAF35[Z32!I"6T?AK3M1U=]>OKZU)%J;7[5!_+S_`,%"?VAOVHOC
M%X*\6_#WXS_$'23H7B"#2-5L/AY\,=*DMOAYI%E::9IFHM!J-WJ-I#K2^+M.
M$UI;WMG<&.&V%W?*4GD@25?TT_:DT6Z_::_;$\-:3#\#_%OC+6K;PY'IUO9>
M(O'-S\,/!$MM<:Y<V:ZAI#^'](\57-]?>']1AL+[^TH%T6[BA-TIOK>$2PWG
MY,?\%&4T?0_`G@GP-I/PR^)'PL^(7PWG\0>!O&2ZUXV37=#O[?PG"_AV35]`
MUR_TG3)?%NEZEK&J^?JFO:A.NIW5Q9:9:QVWE+-/']I@*F$JXM?6HP4N6+BX
MKGOHK6<4U?UN]%?8Y,=DU7(L&N2<*F,Y$ZTH2BDDU%I7YN5N[>B?G:[/Y_\`
M^T+JW_<#3FD$'[D2&X(+B/Y`Y'D]6V[OQHKI;7Q1IT-M;PW%KILMQ%!#'/*6
MD)DF2-5ED)6U=27<,Q*NRG/#,,$E?9JGAM/W<>GV5_=M^GWOY?$NOB;]=_YE
MY?\``_I:?U6?L2S$PZ#X5ET>=K&U2.U<7-QJ;V45VL6KR+-;)'IEW9FYEM-1
MB=8[6"ZN%BDE"QO#YTJ?N3H?[*GPLTFZM/$VD:5X9TW7-7O(AJ=W?3VMM;7%
MU<OI+-->K%J-G&?*@CFD:"[M;.]E`;_1DC$K)_/!^S+XIN=%\817-U:06R:E
MJNJ_V9/<*MP;E[:\M+*,(VDS66J02168"JZZJ4VP.KJ6F4Q_U-?"/Q>=6T.P
MU>XOM5TC3$A2[DET[5ET![B)+6WMKE7ET_3)=2OX(MIN&L]1N+I[AHD9K^)H
M5,OX/A)X1YO*..C4POL)3J.M3DVIN;3C%JG=OL[IK7T1_47B!B,QI\.Y54PN
M&C6A6PF(PDZ;J48\DIJ,8-*4T[MM--+=6;L?GG^W_P"-/#_@GPO_`,*?\.27
M+7OBN:6>_P!1\/W<\.D:B-)36FM]/LULK&[L;>*YCTZWN4MFMY[B:62)!J`6
M%DNOLS]C*_U'7/V;?"6FK8:_);Z7/X:T>**2TNEDECCM;*WU8/)%8"2-8X$D
MN;A7C*)+%#I[2![U+B/\MOVW?@_\5/%?Q]\7?%_4S)KO@.U@\/V/@#PSIB1W
MM[-?6\FAVTUP9-3BA$TXO=.U.[E58S--&9;,`)<27,7Z=?L4O?7GP]66X\.G
M2D0ZGJMK%JN@V%AJ%K?ZEJFC76IN=,1[E6@%_H=FT=T)(S!&[VH4B?S%QPCP
M5?-)U'@:K52I7E1E%W]I2H2CSU$];::N,K-]%L>9Q9E]+!>$N3TW7HRQT*F"
MQ%6$JU-5H.E;VT%!R4K4K))Q34TWR7/H'5_AOJ6GV>JW^E>(H/#]FZ:U)]LM
MH-$35=,T;4]2OP9M(F%G)K&BA]-OK^"YAEENHHKP6TI83M$L7\??_!9SXY/<
MZ[#X-\&Z#XAT#X<SPZ?X;\.>*]4BNHM0\9S>';HW?B/48Y5EM;F2SU/5!,^H
M'SY;6YN+BTN)$9[.%9/[8=:.H?V%OD345M3$T=VK70DT*.&ZBOGU"YECDN!;
M,MWJ4NG-%8"V@;3[>.ZD6\EC\R)O\_C_`(+"?M$V7[07[4_BVR\($?\`"L_@
MQ)>?#OP5]G:%+"[N[.6R/BF_MHX!L@35=7RUNNVYQ'ILC?:Y1,5C_3<DH8>K
MC83A3E2PT\/2J4E*[<N9+WFG>23:TYM;)Z'X"\UQ>.HUYRG*HI8BLH5):.4(
M\D8:2LTK*RT2UT25S\?)O"QGFEG6[TJ-9I9)5C;18I6C61RX1I&O`TC*"%+L
M`SD%B`3170_V9=GD--@\C_1T/';G[4N?K@9]!THK[;V=M$]/^&_X/]/3QN6M
M?9_^!1\O/R7W??\`T@_`O5H)!IVKV-DT-GI^IB[ME37+"Z_LZVU"YLC/.L0T
M.S>Z13=#Y1/%NP`0"0R?L+-\:;SX<_">7XK>(I;C5/!NDW+:;;Z9H6DM<ZOY
MANK:U$US#_:^GQ_V?=6<M[)-,ID-O.EM%Y$PG\Z'^23]E[]K;2K6"'P]XKOX
MM,$YM+?04GMII)[B9)M/M6@NB[V:0)&!).9C+/NDC2'R?WGG1_T2?!7Q[X8^
M)GA:.SO-4LM;T?5-(@LHO#HUQC'<2F1O-:33;31=5DL91):),EW,DD6,P,ZM
M,A/X1G^6UL+4G4H4YU).*4Y*,E9Z>[=VO9^;3U^7];</9UD7$6$PN!Q<'BEA
M&JLYJ,DN6\79)I)VMT3?WGM?PU_;P\+^*+ZTUB70/%^HI_:"7VFA='U"..Q-
MO<O<+;3-8:AJK6ZWS07MT;I[=HK;S!`8IVVL_P"A/P\_:]\)>(+"724O?$MU
M)>7ME<:6D4FKSR0BZ^U/J%K-#>Z-9PFQTT3%II$NC)(\<2^5&AD9/"?V:?V5
M=&T'2FU'1]>BT2'4[%@NGZ@+6YLWFT_[5>!EF"Z7=Q"Z+"Q5?LTHC\T3&.5@
M$7ZYL/"WA7X9Z'?>,?'&K:7I>B>!O#FO:Y<WMW'IUEIEO8WNHQ:?/>D'4+AK
MB.RMGVI++]GDFDU!$\B+:7?DRC!XZI4P=>GB?8T_88ZC.+A)M5:KBH+1._-W
M2:TN[&?'V?>&>(RYY?1P6(K9C0IQ@JC6(ITTXIJ,5&I&,;IIIR6DDVM8Z/Q_
M_@H7^T#I7[-G[&GQ8\9OJPBU_P`1Z9J?@;P39S1RVZZEXOUB.WT^3[+<_;)3
M%)IVEZE<ZHKI:/OEM?LX:%F^T1_YXVOR1MJ.I3W%RL5Y<W+?:UC:29I`2[6Z
MSM)*0TKS+?7%Q=8#SM<)&500[I?UC_X*S_\`!0P?MA?$V+P;X.OKQ/@C\-M0
MN'\)O'JFW3M;U^W:.TU;Q(+5+*)0UX%@2"$S7'DQQOMN9?,^3\?9H$N9([[[
M=`]I+:0V]QM4R7,UY')-(+DGS%V(T<KH5P^U@AWG<`/VGA[+JN'P6$EBIJI6
MAAJ=.4UT<?L/6^G?;4_EJO55ZD:5)48<\N2FI1MRWT;:=M5KUU[(D#N`!Y5L
MV`!N+29;W.'QSUXHJM_9Z?PPRE>QW@9'8XV\9'.**^@Y)=OQ7^9P7K_U./E_
MG^#['7^)88;;7O#9MHHK<@0,#!&L1#'7M+!8&,*=Q!()ZD$C/-?L'^R5J.H6
M^HS/;WUY`XO=`0/#<S1.$?\`M`NH9'4A6(!9<X8@9!P***^6SS_=*GJ__2D?
ML/AO_%K?]>'^3/["?V;%63P%H]Q(H>XCTRT>.=P&F1WO;!7=)6RZLRLP9@P+
M!F!)!.?R2_X+_:SK&D?L8:!'I.K:EI<>L?$G2;'5X].OKJR35;*3PWX@FDL]
M26VEB6^M9)HHI7M[D2PM+''(R%D4@HKY'*/]WA_U_J_^VGSW%O\`R-L9_P!P
M_P!#^-#4;>W32+>-((4C2=0J+$BHH:$LP50H50S<L``">3S6=#%$LL`6.-04
M&0J*`>4Z@#FBBOU+`_[M3]%_Z3$_.\3_`!?^W5^I*S,&8!F`#$``G`&>G6BB
MBNLS73Y?^XS_V0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M=&AO;6%S+F=I9@``````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C0Q(#$P
M-3$U-#,T,30W(#`R-#(T-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````"``
M(```"/X`L0D<*)`5JT"!K%@!P!#`M88$(TH4V!#`B8N/'EU[>.TB@(D@+5X<
MF?'1'E8,5W@$&5&D-)4>"SQB@1+`"I4?60ZT>!/F"0`%+M!,B5/GSA,]1P(5
M6E.I48HC/>Y9.E3DSZ?8K/[<\^A"UZ$^<QJUV)`KI$?$5BAD&*%MVZ<`W+;E
MNN?:BHIQ(Q`@\)9E7KU\]]P$8+`PP[U[=>8MP+A`0U96"JM%B5AQV\:/U08R
M:`4A@,I^+S-F6+AP9\.)0T?`3)C50\ZO*1.PO'ITZX.<2W^>K9JUP4`K6-U$
M:'`W;=:$5P2Z]EOY;MXA1=O&[9IYPHJ6\3[>/+DFP[%MM7\S1$C^,&B0D-KN
M%8\W$.+4$],#)M`PD'B#[_VFW]NS]<W."%FQ@ESZ1<#=2Y#=9MIMA.D'B7`W
M)5A8@`(JM)!"(4$"B8#_6;C'AWMH*.*(#HX("0`BHFBB&X&X`4F)++J8XD,F
MVA?(BP[::*)XRJT`ETW`:?>0>%BQ9Z18V`0$`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]B;V)A9F5T="YG:68`````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(R,#`@,3`U,34T,S0Q-#<@,#(T-3,T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y824`
M)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````)0`E```(_@"Q"1Q($(#!%003*ES(<.#!
MAA`C%@0@L2)$@Q8S*L2HL2,VCMA6&!A)$J''A!Q7,)#`DB6#`R9/"L2XHJ5-
M"0=@RIP)P,#*FRUSZCQI$`#0FPQ`=BQZ]*92C45_-DU*D:A!)%BS:L7Z-&-1
M$D7#?GWH\2H2L&(-DLBJPBH,.6S8(`F+)*X<&`S:E@5@`Y">N&'CZ@%T0T),
MJ`"X!`KT-[">Q8&X'/8*`'(@-H$M!YIL<<4*RYB+LM',6>(**X&ZQ+@!*+3!
MT5QN*+92&N(*+ET:')#0&BT)-H19RJ[=L";+!A*XR)D+`(D<+C>),_1ITT9C
M`&STV+#)P$!'D21]7EIACL1*]_#2*QI(ZWWGPA5IT[OWZ-ED_9#W[PO,S]^^
M9XKVA22@@`C%9&!"AR$$@&?[$=C?0`SB=R"$'PU8H(4$4M@@00E^M.!^'\(7
MXH`DBAB@AO.EJ.**++H7$```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA;BYJ<&<`````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S$U-"`Q
M,#4Q-30S-#$T-R`P,C,U-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R
M`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+
M_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$(
M(T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%56
M5UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBI
MJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W
M^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"
M!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`5
M8G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!
M``(1`Q$`/P#^-6[^VVUP9CY=O&CNCNKQJXBF@EB+N9"$:`L8PS](1O<D9!'Z
M^?LI_P#!,3X\_&OQK\$/AMX-^"VD_$?X@?'3P=8^/[:^^(NK^*?!'@'X>>$X
MWTKQ%)I]U-IUI')?>(X_`VH>']8UR_U![VS@'B'1+*VL?MFHK]K_`",O3#++
M);&1P+RS:%O,Q(&E_?>0D,`S(99IVCMI7`*QVEQ/<'"6LC+_`*CW_!%O]H3P
MM^U+\"_#'[5=_8Z'X&_LSX-_"C]F?PQ:ZF^D:):ZIXZ^$F@6.C?&KQ!X;AE2
MW2YT_7_&]QX;T2.]M7D)@TJVT^63?!&E`'Y"_#?X0_LK?\$POBAHOP!_:R_8
MR^$;ZS:RZA:^$_CGXU\"Z-\1?`GC#X<,+35M1UKP#JWBC1KF[7QEJ.LS7VC^
M-KWQ+;Z3J=MH5G;V-G86RZ9)<S_77PN_9J_X-U/VC;P3^&_V5_@I_P`)CX@U
M/5KB^T+3=7\4:7''>37LUW9O,-*\1F.RT[4UFN/[,O-&LX;.%Y/LBP(T>Y?T
M=_;W\+_LC?'CX8ZQ\%_VG_$7PL\/ZE<,OB7PCIWB[Q58>$_%VFLL[Q1/X;N!
M>1:K93ZY`+>SFU%-T5S)"+8QL\.3_-3XD_80^`?P+^'FK_&OX$?$O5;;5O"O
MB>T?PQXN\-^+]-UG0](T*#6(K/7].\5ZG9?VG_;CVMU/<:;>:I<20WND0LMS
M);PW6BV0G`/SJ_X+L?\`!&^W_P""?WB'1?V@?V=K75=<_8P^+VNQ:+IJW<MW
MJUU\$_'UQ#/>1?#WQ#J<DU[=ZMX)\5V]G>ZMX8\0ZA-!<-JUC_8JM(TT(G_G
M&CN)(B?/;Y^$+LWFN75`LA1XR0T!E5S"03F,@EB237^EC\7;GQ=\??\`@D)^
MW1\*OCSH^CSZMX3_`&=/B7XG>6S%M*=!O_AUIA\5>$->MXI((3'";^QTS5;>
M2R3S;"[BUS21<-;S(@_S:9[)+F)I_*=)62&21""QCWVL,L1\Q<HYDMWAGD*<
M122O;MB2!P`#)V2MR'@(/(R#G!YYSS150F0$@$8!(')[?3BB@#L+ZSMA#*4G
M,";&28L"TAC9'$Q>*/,MQ&C&V"Q,%CC:1W#[I"*_MP_8*_99^+7Q*_X)]_LW
M?M4_LT^`_`'PC\.>&/A+I5U\2/%/B3Q"OC7QBOB;X+^-?&S?$[QG\.T\;:?=
MZ=\*;%;71H?'GAAO!NE:K<:YXXEGCUN4::]OC^)2_F50[00Q9(_>3F&+"/&)
M)H(P[L)P"4D:X5%*(BQ,3R<?Z*'_``;!^-/$7[0G_!)#XB?L^^*-032M(\`>
M/_BE\)/"_BC3K][W7-.T+QEI3^+I9[S1+I;?[%>Z)JWBF]U+2I))PVM6\X1(
M_LVDRNP!Z9^UW\(?C;^T!XE_8,T/Q]XZTBXN?B7^SP^NZSJI\->&M&F\;?$N
M>:T\9:]X5%];Z*]E\/==U/P5?VNG>$_%-UH^MZ9=:QI<L$VC:9<O/<7/%>$?
MV!/#OP`^$?QSU_\`:F^*'P[USX>_$[X6>)?!OQ1B?PEIWAR^F\0:V-1T#P'=
M66I^"D7PSJ_BRPN]2\-:&FK6?AJ35/$^L&34&O9X?L=C9>H?%[Q#\6_A9^TO
M8>&=0\0>)?'WP,^#&B>"?AGH_@KQ!H,?@6\B?0_!MC'+XX\-:^=1U75]5@T^
MUAMIY->\V"V\7>);_6TT^)[1+9YOL3Q_\,/`?[2WQ,\!OXC276O`,'@30_%M
MEH>N,1I6D7)^U6&L'2K>)XX8?%MQ$5T_7M>NUEU/2H+;[!#:0RQW<L0!_+9_
MP3^_:-^+'C#]G[]MG]DWXL2^)O#'QJ\(_L4?M36NE?\`"9Z?<6'_``MWX7^&
M/A[XGT_0O$MB-0M=/?Q#8)9:-):Q^([.UDMKIK$R&4NK-7\@NF+));Z<BJQ6
M2PM[E/,8_.GV.W\X`G_6+',SC<"P"M&#@8%?UD?M1_MSZ7IO[0O[8_[>OBCX
M+KX?\+:7^S-K/_!//]A[0-0UV[D/Q`UCQ!XC\5_#;7/B)8/;:,=-&B>#_A_#
MXBUK6/#]Q+/<1K'X=TC!>2&6Y^:_^#=K_@FY\!/^"C>K?MP>$/V@?#]QJ?A7
MP%\`?`GA/P;XRT1HHM9^&7Q"\4Z]JMS9^.?#5S!%!!+XCTO1O"$,:6%[&ZW6
MCWM_92`3N#$`?S;RM&LDBEK)"KNI1KN%64AB"K*7!5E/!!`((P>:*B^)NJS>
M!/B3\0?!%E>7&O6?@WQQXL\*VFN0-HMK!K5MX>UZ_P!(@U:&UDE\RVBU&*S2
M\C@D^>%)A&WS*:*`-HSQ769PQ25[>2#>?NDEDE7$>/[B7$0DP<M.J9R<5_77
M_P`&I7QP^%]QXH_;'_8T^+OQ/N_`6E_%K1OAM\5/`VB+XMNO`MUXEN?`]U=Z
M7\08-%\4V4^FWMM/>V,.@?VIIEMJ<4VI:`+[[-&JK=35_(1*ZFY6-2"C%E&P
M#C:K2,N!G!5%>0^B!G/RJ:_<G_@A?_P3L^%/[??Q3_:,U7XQ?$CQU\*=#_9N
M\!>$?$WA?Q5X6U+POI%BOBOQMK>K^'[K3?$UQXN66TGTNX\/VEV?[.LAIQN9
M'2XU74XK6TL]@!_6GXOT;]AZ]T3XT?$'QS\9/V2/B=XY\.:_INC^%-0_9QO/
M&_PV\>_#](/$^H2:5+X[\;:I\6_%UUXSCTG3K*ULKW2KK3+6SEU"35[IK>-)
MW9O+O&7_``4=_9P^!G[,FA?!'X*_%70/B#\<-2\%:M8^8WC2R\3:?\,[3Q!<
MZE%<_$#QSXQ6?^QKFZT>"?5=5T?0%O1>S:K>0VKH\BQQC^1#]K*-?@)\9OB1
M\+/B%\>-.\5KX`\5W.A:%K?@C5HM8U3XDZ$\4$?@WQ;+-H<\NFQ:+>^#K?2[
MN<Q27FFI?WEY'87TJ,A'K7['WB/]G*;7-#EM8O#FIW.HB9XKG5]!;S+EK6YC
MU2ZM9-2U2"62S:TMX96$%P1;M-+*T:$R/0!?_:E^.OPA^(GB#X2?#JV\/:%\
M2M!_9RL/VG/VAOB?X5U.^UR?P!KNHQ>%4U3P1X&N[W0-4TR[FTVX6#0%URUT
M[4+2+6$OWM8-2CN'O8Y/ZF?^#<*W\8>&?V%_%7[37Q'\/^"]!\>_MH^+/$EM
M\*O"GPV\$^'/AYX2T'X4?`?P5K7AWP]:>%?"GA^QT\3:-9:GIWB2Z-Y=6UWJ
MM[<7-Q>ZEJ5_+*U[=?RI?M%_LB_&GQE^U'\:X?A;X&\0>)/#_P"VO\0_A!^S
M?\#/'V@^'9IO`$]Y\4=7\.WOQ`T:?QC9:;#X9T34O"VA>%#IFJ0-=^9%9:AJ
M0F"'3[M8/Z\/V*OB'\+OAY^UU:>&/#NM1CX!?LN_!C3/V+OV:-`TXV=K;^*9
M?"]EH>C^,?&]G;13#3[)O'GBZ.?4-:\8W6Z'[1=V-BUR\NOVL=R`?YF7C*33
M-4\7^*]3U;5#;:KJ/B37;_4[>\N(+6[@U"\U2ZN+V&ZMIF2:WN8KF21)X)42
M2&56C=592`5Z3^T9X$T;2?VA/CMI6CZWX6N-(TSXR_$_3]*G@O+6_@GTVR\;
MZY;6,T-_;326U[%):QQ/'=V\DD%RC":)VC=6)0!S6KDIX7UZ[0E+J*STEH[E
M25N(V?5&C=DF&)$+1JJ,58%D55.5`%?>_@F\N]"_X)J?M-#1+JXT<:Q\0_A!
M-JPTJ>73_P"U)K+P#JTME+J/V1H?MLEI+<3R6KW/FM;R33/$4:1RQ10!^<-N
MS-=^(4))2VAT]+9225MT9FD98%/$2L\DCLL84%W=B"68G[K_`&2;6VA\,>(+
MR&W@BNTU",I=10QQW"%Y](#E9T42J6'#$,"PX.:**`/[9_V9[BXT_P"$/[$T
M%A/-90)IW[:OC)8;25[:)?%_AW]CKQO)X?\`%:QPLB+XDT*2[NY-&UP`:IIC
MW5PUE=0--(6_*;X-3SMX(^&<!FE,.M_M/?"/P_K,)D<Q:OH-WX.\2:S=:)J<
M9.R_TBYU>XGU6XTVZ$ME-J4\U])"UU(\K%%`'\L'[4.C:1X?_:8_:)T'0=*T
MW1-"T3XZ?%O2-%T72+&UTW2=(TG3?'_B"RT[2]+TZRBAL]/T[3[.&&TLK*TA
MAMK6VAB@@BCBC1`444`?_]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+VAU;7`N:G!G````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q,3(T,2`Q,#4Q-30S-#$T-R`P,C,W,S<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_]C_X``02D9)1@`!
M`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`
M``````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01
M!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT
M-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"
M`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A
M<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$
M149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7
MF)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;G
MZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#\O_!?P_\`#WA3QHEIX+\`ZK8Z
M[K>O'3_'6NZO:6"7ESX<O'61IDB>_N='M]-M/#UQIL5A\VL3IY:R7N)VELH/
M=/%:7&B6-CX:M$N[Z.^\*>'O-L?#VB7OVW1+;7K>YO6F\.>("/#7A>VN]/T>
MZMO$&I7LEIK]J$NY=+-NE_;3R'TBV\/Z;X1L=`UW4?"=MH<FG:G<:;XINSJ^
MAW?AZ"ZN[M=0U**TT[[9=R6L4]^LFF3&"1'CU1+[S'+G:OD/Q/BUS5M6TVYT
M]`FL:3?Z"N@2I=ZCJ6F_V'!?[[#PO#J!FCT!,V%VJW<,)\Y+M7M))8A#);K_
M`"/7QV(S.LI8J=>6)HQYH2DY*,;<JLN6R=K[.Z];']IT,EH9=@G'#<BA)OFI
MQ5T_:0M*3O=ZJ4D];:^K/T2_X(Z_\$W/@)_P4!\:>)OB_P#'K0K_`,1_"SX`
M6_A?P1IWPDTW5Y-"\._$KQY*-4BMO%OCKQ;X=CL=3US3=`\-Z5X6\:S:%HNM
M6L/]K^.I[?4%E?PI<Z'XB\%_X+V?L*_LR_##]N3X(^&/@WX=T3X=>$/&WPE_
MX2/XA^$_ASJMMX:U#4H;'5YM#T^\LH9=+NO#5O?:U#8#45=]$U&;6KJ/4M6N
M[BZNM1><XW[&GQA_:2^&?P4_:`\)?!1/&7PV^%W[3-O=>$OB+XQEM)F^(GA'
MQ;=V,NCW'BOX+1Z=-HD(LK*UOO$/AZ?QG8:E?P>'GF>VFM#XB\,:-JFDM\2?
M#V75],^'/A;QUX^\;_$1/@=H[>'OACXC\?ZY9^*O%7AKPW+K/BK5[FSE\7ZW
M-JVN^)=*T:]U75-7TM;_`%+Q#!X8T2^L/#T'V'3]'L],LOM\%Q+A<OR7"X.A
M[*GF<\9#GK2BYSE%PJ^ZFVWJ^6UDNNFS7P-/@W&9IG]?%9@Y3RF>&>%ITH\L
M(6A3BZ<9)1BK0DJBBKN35GS:V/Q6^,G[`GBWX;?!O]E_XD0>,_`6H:1^T%!\
M;+C2/$.F1^(+KQ4T_P`,?B!;>#[S3]:^'EYI%OH]D]OJFHO9:,='UVZ?Q9I%
M@=4SI=]!J$<OSMX_^`>IQ?#7X=:Y\/\`P]XNO=4GEU.3Q[>Z/:ZIJ5K!!XHM
M;*Z\%7VBWWAW3HM+U+2VLME[<F338C#+>S122"59)'_;;XN_M(_"V_\`@G^S
M/\&=<^)WP9U(?`/XS_%;XG^&O''A[XJZ[XC@T3X=?&JTEN?&'PP;P.NB2>%0
M5\1VT7BJV\76/CZP7PIJ$EQHNI^&8=1@U;6K_P":?ASX;\(0:Y\*O"&C_&_P
MWH>B>+?%5M_PD_B/6YKW2+7PKX1^(4]I8Z#?7?AZT_L[5=:\-Z?"MOK-OK%C
M9RZ'8:=KEC'HC:SH<>GZK??1?ZUYUAU!UZ-'$QA&-15:E!R<7:-[2:;27,[:
MV\D[->-E_A_D&8SIX+^T982O/%8K#Q<JT:CITHN;ARI7=VX0DDTW%^[=VN?"
M4'@?]L>.&&/3/`GQ2.FI%&FGF'PS8K";%4"VAB64^:L1@$9C$O[P)@/\V:*_
M;:^^`_AJUOKRU'[<'[$R"VNKBW"'Q!\1E*"&9X]I4^$GVE=N"N]\8QN;J2H_
MUW=]<)@KWZTEO[OGZ?>_E^I0\`<O<8/_`%OQNL8_9EU4/^G?]7];>9>&)=&E
M\0:AJVJ^$-=TGQ)X6O+"P^)NJZGK5GJM@=9U>RMM9C,EGXHT^WTZ_P!?E?4(
M]0AT33;R^EFN9VE,]HC_`-G6W3Z@DMA>:AJFGZWXON7NO$WAJV'@?7=%\*:4
MT5YK<L1\,>*KO^SCHDFC)>ZE8W*WMI%)<O%:3VM\Q`FW2?-]WKFC?$+4_$_A
MGXTZW-XMNM(U>ZU[PKXM\^\@TWX?7]]?:A=WUGXF8./!?BB>]\27=O8V%SI-
ME9:MHD,HAN=19H<1=WJ'B71-(LO%>C^-V*VRZ%K&@106T.E:GKNKZOJVFZ)I
M3Z_=>(I[?5H]`;PO'HJ:=X:UT)-8V=JT\EQIUY=3+<1_"5,NG3BHRE/GNDXV
M]Q+1.SM>_2U[:=58*6-H5/W<,6VK7:YD]$XKKY]M==#Z?UNX\53:I:Z1J^VX
MU318=(D\/6FBQ^-?[/TV&WT^$7,$VLP:SIMO>:\FHRW0U'1]%DBTO671]3^R
M++=29_/?]HWXDZCXS_:`T']G*\^)NI_""YTOP?IJ:!JI\4?\(7\/=;^(GB[5
M_#EYJ6M?&;QCK7BK2-1\._"70_`L]T/$5MHGASQ5JTNLQW^DV^C:H%\RX]I/
MQ+A\;7,_A.V;5M/L-%\.275MXK\93I<Z=J^O:[;QVNC>%OA_I<-I<:QJ&B>'
M-&AD_M#5)+ZRUF[U&UEU&QU>RTV:WLH_R1_:I\'W=MXFM?B)I5[J6H>"=8BB
M\+WNI:E=SPS7HT&*&"PN7L1]JEU!?)LTO[2]O9;K48I[B2![T6,<&G6OM\(9
M/A*N?866+PU.LEK'GCS)3;II-:V3M)J^ZZ>]8^3X]S?%Y=PW5GE^+JJ<:T6E
M3DDX_NJBYDTK[/E[>]VL>O\`Q&\$?!KXK?%76]8^(O[=7[$?PRTZ;Q!X&\/-
M)^SS^S1^TOX4^"FG^$[]]9\(^,M7\/>'O`O[+7P[T2]DTG1-'\,>(O$OB>_@
MU*?XE:1XP@OK?Q/XA\:R:[HB>*>+_CW^TUXB\/>'?A_XR_:C^-/QB\"?">;3
M]-^$VBZ_\3OBAXI^&WAW2/!K6VF>&[SX>^"OBE9Z5=>%/#::3HVD0Z+X6OO!
MOAR*PTFTTZTU/PS;:C!=,_B4GBV-FC&FG3]'B+_:+*2RLU:>/S?WT+12$O)9
MI'-)+=?9D*6LMQ<2O=VTX6)(K=B-9UZ[L]!TM1?ZE?R3"U73%DFOI/-DB-Q-
M=)!!<SS2O<W9GD>SL+C=$7-Q(MQYK#^B_JV6*A7>-IPCAX)0TIQ;:Y(ODO:]
MGOZI:H_DNAG'$#S+"U<NJUZ>*BY5I5'4;=G)*4ES:)MR5[6TVLMOTP\/?\%H
MO&GA_0-#T'4_V9?V9_%6HZ)H^F:1J'B?Q%X$\?R>(/$=[IME!976O:[)I'Q4
MT?29-9U>>&34-3?2](TK3FO;B=K+3;&V,5K$5^7NJ_#I](U34M)U+5;TZCI=
M_>:=?F#3QY)O;*XDMKHP^:5E\HSQ2>7YBK)LQO`;(HKXIY3PY=VC&U]/W:V^
M[^K^EOU^/&_B.HQ_X5\1HH_\O5T4?[O2W_DOF?:<T_C"&'4]`O=9\/6?AS1Y
M;FZDCN=/N?#NCQW.HW&C:K->:-<2-_:.HSZHFEVS7"W]S>"UDO\`48D5+CRK
MB)D/QV\2>(/%=UJ6KG^P%UC45FM=0\J[N]&N&M(TT^TMHKRY_M=+O3[>WM8K
M6WM-2184CB1+LW=PDMY-^Y_[2G_!&+XJ^&M3U#2?V:OC3-\2HIK>ZU;P5\.O
MVC?"UKX+U7Q;X9BLK=['1OA7^TSX?E\7?L^^.O%IF:>WM/"/Q"B^"GCM[6W2
MU7P[J<UN^MZA^67PO\"3:GIWB?X>_$G2G^'WB3P!K+>$?$_P[\:6D?A?Q)H?
MB379Y[VQB\0V=MO:73M1EEGDT_Q#:W\FDK;7%@3$%#0GX')^(^$N(\+[3*,V
MRO-:%.,'5E&4:<\.IQ356=)R522BK1>EESJ]FTW^AXC`YMA\3+"T\)4P=2C4
M3G7JTYNG5@KQ=)2M9\TKVE&Z?LY)2?+(S=!NKG2=2TV[%]JLNLZG<ZMK.IQ:
M+J.CSQP1?V<;**XN+J+4IY-'GET]8VT^QALHK9;.:)4M%!`$$7B31[$V:R7.
MMZ8+2P&E:#;>+V\,ZOIFJ->`W;&?P*?"FC7NG3PI.=.M+W_A+'_M.S@M]58Q
MO>M&GHO@W]C7QIXFTW6/`/PU\6ZO9>.K"?4O$?PL\.V/BBUUWPUXT>.5M5\2
M?#&2YT[3=*B;QY#9:A#J.D^&`LMYX@LY5N[*\@%U%!!\]?%/7O%7@[4KV7XH
M_`*?2&\%:-_PC>JZAX'\?>/O#EG9>,K94L@/&&@^.$\1V6G^(+.*WEN[WP9I
M>EZ;>M&!MU:1V:[G][!9)B*4X9IE=2GBZ',X^VP\E#V3LIM\K?-[O+O9KMLC
MHQV19YCL#.I7P*E@N2SG"FZT*D]+1E3O>":4GS[*S75V\U\0^`/V=[N\U"#7
MM.^+_P`.=<N[6?5(M5TNT\-W^BZSJ*:E(=1M;+PG#IVJ7\6GR6KJ+.6/Q8YM
MW2268,H^R0]E\'-5_9)^%WQ`T;Q)\0?ACX]\:?"7PBOB>]\4^'O#?C:ULOB9
MXIU2]T'4--\-7^F?$#2+?2$\$^'+>[ET_4]=T6#2'NI(U*C4UN?,NY?TB^"_
M_!+;PS;?L[^'OVX/VV_'?B[P_P#`;1=.\1_$KQ+\&[+3=2T[Q!XQ\&?9K[2/
M@O%HNL'?K-KXG^+7C+Q7H,&BV:V5EH$N@V#SWETUS,+M?RL^'J6^O:SJFE:M
M:Z??V/A[P5#X&TVUTG3M,8SZGJK:;X3\/Z1YDFF,=6U(ZG?:9INIRWHU*28Q
M7*VE[*#%?OVPSZ.:T,1A\+F5;$8FAB%3Q.$IV32C%<TY2E&SY9.,6EK[T;)I
M)GSU#PUS#"SCCJV5991P[PLZE.I.JU47O4VH^RYERWB^:]_=ZI7LO[1/V7?^
M"#_["?QV_9G_`&=OC?'^R]XRV?&3X%?"/XJI_:WQ2-WJNSXA^`/#_BY?[3N[
MB?[1<ZAC5Q]MN)SYTUSYDDOSLU%?U'>$X/#O@?PKX9\%>'M-M?#^@>$/#^C>
M%]#T'2K*SMM+T31_#^G6VDZ9I&FV_P!F;[/8:;96D%E9P[F\JWACCW';DE7]
M6Q&EWBT]+KVE/1^Y=?!TL_N/F9+&*34<!A'%2?*U3KM.*<;--3UNDW=>5NA_
M/;_P3"\2^(_'^C>)-$\=Z_K?C71K_P`'07-]I'BW5;[Q)IE[<E;MS<7=AK,]
M[:W$Y<!S+-$\FX!MV0#7X:_M]VEK>:Q\'=>N[:WNM<UOP+\?M(UG6KB&.?5M
M7TGPQ^U5\4-#\-:7J>HRJUY?Z=X>T33[#1]#LKJ:6VTG2K&ST^PBM[2VAA0H
MK_-/P9_Y'C_[%\/_`$]1/[1X_P#^2AXI_P"P[`?^H,SX^^+VM:QX9\%WUYX;
MU;4_#UWHGA5?$6C76AW]UI-SI'B"S\3ZK:6FNZ9/82V\MAK%K:6UM:V^IVC1
M7L%O;P0Q3K'%&J\7\0OB)\0/B/X,^$&@_$/QUXQ\>:'K/P^\3:_K&C>,_$^M
M^*-*U77;JW\837.M:EIVN7U]9WVK7$Q,L^I74,MY-(2\DS,<T45_HOPY_NJ_
M[!I_E$^*R_\`Y%&/_P"O4O\`TY$_=C]KXFW_`.";_P`%[*W)@LY/@_\`\$V-
M*DM(3Y5L^F?VE^S_`"?V:\";8FL/,N[M_L;(;??=7#>7NFD+?S3?LLV%C_PU
ME\`-,^Q6G]FS?\%#/@!HTVG_`&:'[%+I$?QL\%Q1Z5+:;/(DTV.*..)+%XS:
MI'&B+$%10"BO@/#[_D><2?\`8=7_`/3E(X^-/^28RK_L74__`$E'^J9=*INK
MDE5),\Q)(&2?,;D\4445^NO?YK\X'\U+I\O_`'&?_]D`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]S;75R9G,N9VEF````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#$@,3`U,34T,S0Q-#<@,#(T,C8U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M82``(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`
M9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`
MS)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S
M,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68S
MF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F
M``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F
M9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F
M_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9
M,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9
MS`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,
M`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,
MF0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,
M_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___
M9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_
MS)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````A^00!``#8`"P`````(``@```(_@"Q"1Q(4*`5``@3(K12
ML*%#;`M979M(<2(K``P?-D0HL:)'BA<S:L38\:-)BP!&ECS)\EK*C2UC4GPY
MT,I*F2Q7$`0@TXH5F31MRF1U$<`*EC1YQI3HT^<*A$<KZA2H%"=(HJR>0MW9
M4V%%HC0'`KCY\>"%LQ<`I$WHL.I)LVC/KD"+$691A!X1TE5[X>G9NCLOQH5Z
M#6[:B7A=_BVH-^Y:K7\K5E4;%N+?QH_YNI6<EC%:`HW5^CV,F*="A53C@G:L
MN;1IS(OY?G;<-_)IVF</RA[<>&[:%7-WL]:->S=4W+09ZL8,&WGQG00&0Q+N
MG.Y&Z=.=GP9\G2ZD[-5%'SXTO'8[:XUB$U:/*_ZA;/7(%Z)/37L[V_GTJU>>
M'Q``.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+W)Y=2YG:68`````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`W
M,"`Q,#4Q-30S-#$T-R`P,C,U-S,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``
MS```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9
M,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_
MS`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F
M,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,
MS#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S
M,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9
MS&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`
M,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EF
MS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_
M,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PS
MS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,
M,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`
MS/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9
M,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__
MS/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"P`````(``@```(
M_@`!!`@`H*#!@B0`D""Q8B&))RH0/EDH<&!!@@03DC"@T,#"%:2>&'"B`ED5
M$BI4;!PH0$!!EQ01`O"X0H63/*H8DJB2;.&3/`L#M`Q@@%6@%0@31E1((L^<
M9P_S.+'F9$6>4E59"F3%RDH@*RJ93E1!RLDSE:1(E`)*`L\39"566`QTU-JU
M:W1K+E3QY$E:%:6:Z@&@!RB@)ROD`K"2V`JKN]=*6;%R4B5$$B$1DQAU^0^)
MP8NM%%SQ&#+D)P%0_JRLT`G#)P`4T]68N`K7N]`".0D$Y8F>9'R?G&RHDB"`
M0*P6KK*6IZ"*QX!4!%J[*D^>)ZNJ."%U4C/!*]?X_CJ3@ZQA=8-JN5;18^B:
M$T"K'*K("'Y%84^J\E2Q!HAQP2K7/$.*7<\D1I$!`PT$7E/(D-*)$WK8=0TT
M#0&PREVL6`,;"0DFF%!]3S"7!REY6/.,'ERH4`*'>I`R2A6Q-=2A``2Q<$T5
M*D"3QS.K.&.--:5`P\<*@BP$B#5(0+''%0FV)$!"-B:WW#/'+'>7-5\Y\40G
MU6AH12G1R,42C0:T@A=A`8Z"S)776$/*'@(^`\V`;98@E),)80B`"GF,XLR`
M$E[Y3"?+02.A7$["A"$)-W4R*"EM0@;-**0<TZ9=K-B9Z$"S7+,*GYV,8HTS
MCD+F9C("_OB,-="TTD*B_@5!YD0G)%K3H(\_6H/?JFV2$A(KLV#A)%&X;>=@
M-0)VXHRAT#B#!!6>D`)(,J1(=U<K"#Q)`H;;/4/>,\B,LJJJI,C1+7,,0=8*
M"\1.N&4UM#ZCYC/5/#&'K\\\X]0S?5F1"&2)>'37*G+(&6HUI"!CC2I(_,$5
M5WI4X6U:5MPURRPSW15(%<@@:PFXXKJY`B#(!?+$B3ON9MI`K,CR3"GB/C.'
M$ZN$BPR]R>2:KQS.\%LQ9!P!`DTI5`HX"A(['N,)I2<])"`)-U<!GL4*!;+*
MJ@D?0PH>2.!1:8.K9GA-63]&;-I,@8QH(JO.2.7$N4""7=B/G:QP-F%4R`D9
M("M.F#N'37G((8=UYM([Z'.0S220X@<M;I!QCC_>>$```#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]A
M;F=R>6)O>2YG:68`````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R,#4@,3`U
M,34T,S0Q-#<@,#(T-C`V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y84$`00#W`````````#,``&8``)D``,P``/\`
M,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`
MF9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S
M```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S
M9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S
M_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F
M,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]F
MS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9
M`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9
MF0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9
M_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,
M9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,
MS)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__
M,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_
MF9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____X
MOR0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````A^00!``#8`"P`````00!!
M```(_@"Q"1Q(L*#!@P@%5EFX8L7"*@DC2IPHL4K#BPT97H1(L:-'@AHQ9K1B
M4>3'DQ(S5@$@<F/)%2P=KD!)4R#&ARU%,@3`$V/-CSJM6,FYD63/GA=_3GQ)
MM*'0ASB1\IPZ4RE"BTPOLARZ0NA3K5ICPJQJM>#(K"IS(JT2B&N@5:L<EC7;
MM&5/J%8"L5JUDN7;57GG#A2)M&[7O'JM[1U:)2\K5H$$*\PX5BQ,EHU7!;J,
M.9"USXI9@58L&5M)BRPMW[6BF;-#SZ`?CV9%$RM4;(9O-O:*&*[HT<"MH40;
MT[)#DDSUBOX=''BUY]6L13X)EBAKP!G_-M\^.OKGZ1]#_E)F:.5QV\?>N:L'
M#MYC5M9LV5H#G'B]?>"KAB?%MC<SY,;/W2?@=V5=!!=)JT`7W&/,Q;:*;)_!
MQ=Y<0VG&&G35/`98;P]:<\V'U\"5&&2!O#6:9&QUB"%<FJT"(BM"N:CA7O/I
M%6(5JWQ&FV`+Y:7@:'"!&`A6)1;9%H[?L1:A8*PQB&%Z,.:%W5B\C<664,M!
M-M=;3W:IHX4D.90C:"25"=M\?&V98)<8?ME6F$B2V5AC9\+%D56!L.DE<'N-
M"9IOBHU6Y%Q5L*+GG@XRI]EV0K7WDX^'_HC?FXXU%Z5D%ZZ((61^\@FAI7"5
MAB-T@#WW&&,/L@AJB0&25II"_BPN=&J,0^[&%H-[O=D6;)J].E"/1?9)ZH/]
MX57?7KGZBM!;Z+4:VZ[UA::9H\H.Q%>CQ#HWFX752E0B;PMQ"5V?;74[$;1%
M,M85B\B92Y%C)5[9V&&VW>EN0O`.>>107SUT;T0E:@857LCM-M2_!M$WI$KD
M]5AO0P@3M-F<>#WDE4B]E8AP7/P*Y11#<V+D%[&]WAMP6@Z!+!Y;(VKI+F`P
MWH8393?-R*V[USDZLTL&PCBMO<KZ9H5!(:6XUW[8E&DNL<D6]!*2##(4<8S1
MA>IT5ROP6B+2+P?L&[5E9ITK:BPAO"NVU.(V5D-3]61V7F@?Q'985$V]J]4&
M<=9V9=T18X/W07L'3E;?$06^]^"F04RX0%88CA1!&"]NFN`60;ZV4Y)O1A56
M*;]4'.+W5CFP<72#;BY73L&]=5,\`8VS6%;,9U%KEZ_M^KUZIUP9Y9(/YCA5
M<O6>=TL]"A]13L6_&A```#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F5R=#(N
M:G!G````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,S4P(#$P-3$U-#,T
M,30W(#`R-#`P-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"
M$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"
M`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1
M\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:W
MN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?
M`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$
M!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0T
MX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_
M`/X<O$UH+37-6MRQ98[G*$Q[&"L#(%V;FVX#$9W$$#/L*VBZ)?\`B37=)\/:
M/:W&H:GJ^I6>DZ?:01*T]W?7TT4%O;P(6VF25I`%W':"<-\N379>/T#>*+V[
M>V>!]2ABN8;7"%F,JB`1JVY8RP/S!G*)DA6*CYQ^CG_!(7X6Z'JO[2:_M!?$
MC2[FY^#_`.S)X-UGXQ>*[XZ?-<6]Y?:!9O#H,6FI=0"RU"ZAU=;&]FMI7(,*
M3H(YDA9V^NXIS^/"W#&;YS-Q4\+2]I3BK2KU*U17PL*-&-ZM656LZ<(J$)6;
M5[*]_!X(R*MQ/G&295!2D\;5HTI1C[SC3C",Z]62@Y.%.E1C4J2E*RLG;4_H
M%_9&_P"""7PFL/A1X$LOV@/$GB+6?'3:?/KOBV/P?J,&FZ99^(_$`M=0N]&@
MU*YLY%U"32=)AM+!A;1J'U"XU.Z01/>F"+W3XX_\&ZW[-'Q.\$:AX9^$OCCQ
MC\*O&]QIWD>']0\17<.L^&9-32X%W:RZS;01:;,+.ZNEA@OYHIFE@MGEFCCF
M91"WZF?LG_M+_"7]JOX=:;\2_@WXHCUVP6S`U70KF."/Q?X;NYUE6.WUGPQ%
M<74VF'4KF*,6ETMLEEJ,6+;3=3DNG6-?I7QO\3/`WPN\+3^*_B)XVT#P-H%M
M'=R3^(/%.O6&FZ4(H+A+-3:FXDCN+F>6\GL[$0:>MR(-1NH[2XN+<!IQ_DMF
MGB[XITN-Y8W$8O/*6/I9I]=JY#)OVE/#U*L7!U*49-1A.ZC/F5X1DW/E2=O]
M#LTX.X+>0+*,)@LD6#Q.4T<MCFL*:BHU*5/E52,Y1NJS]V3A%JIS6NFO=/\`
M-6\<?!CX=_LW^+]5^%'[05_XRT[XT_#6YUCPCXK\$6NBS2Z?I.LZ7?W$YEAU
M::>&&]T>Y:W1=/U1+*-=1@NHK^TMY[!)+B/Q5/%>B"TOK73YM/L$:*_-FFJ0
MI+=20RQ2"!!(@C$4L@*JA96"N0<$`U^_/_!R1\(=#E_:%^!'[1'A.U36+;]H
M_P"&-N^HZUIXFNM,\0Z[X/M-/CBU6*:W-NUY=/H6K^&-2F<VUDL4ES-:6D+6
M*W%M<_S.Z_9-%?7,5M;C'FVD)CDC*-!,I4-&Q_>LGFM\N&V8S\S+UK_5?P^X
MO_UWX,X7XJY(P_M&AB*=:$4URXC"25'%1E&U[TZETI?#):P;24C_`#2XSX7I
M9-Q+F^25*\XK!8I4J-1N[DI\M2"5M4I1;NFDK];NT>WA\72PPQ1>99GRHHX\
M^:HSL4+G&PXSC.,G'J:*\I:TD!(,.""01ES@@\C.><45]G==U]Z/F_[,H_\`
M034Z=)?W//T_K?T76=,SX@\&KXDM;K3K/5+O3+34ENK.YL[@:6=1CCU%EM[C
M)!CMFF(/F8)`^8=1_=G^S7^SO^S?\`?A'=^'_A+X7^R>$3X<\#GXHZP]W?W6
MH>+=,2.W3Q/JUR/,NUM_LFB:IJ]]9V&F0K-'=16K1W3S01M7\.OQB\1>*_$E
MAX7NO%FNS:W=6T,MHMW]E@L[@`VL%Z4>2(X>2<7!B#YCV%?,YW!1_41_P2%_
M;;T_5?A+X:\-?%?4[K2-2OIY-`T/Q+KJE='\2ZAI$\-JME;ZA=6Z64>J10;)
MKS2KN8M!;QF2-[W(C/\`,/TD<OSK%<.Y-G67UIQI8+&4Z.8X#ZPJ$<11I3C*
MC)^_&3E)Q27)&4XW37O)G]K_`$,\QX<I\2Y]@,PP-.6?8O+L5/A_.:]-SHY?
M4ES4W2G2G&T5[&<O>G:%DU*2CO\`4GQ)_P"">/BG0OC?\3?C%_P3WUBZ_86T
MWPQJG@32OA^=7^(%_K'PZ_:5T3Q!H>J7OB_QIH.GZ,VK3^&[CP]JUM9P:CX7
MN=$NM#OVU4M/:V,D$AN?6/V:O^"5%Q^T+^T3XFA_X*#_`!&_::_:*?X>_`O0
MOBMX9\87>EII_P"R9J_B#68/#$E[X,TOQP=>COM:U;P[?>(HM$U'P#IFBZ'H
M^O:UX0\5:W/J.=(71+^[\+_CIX)G\4>+K3PNEA80:9XL\1V\=LO]IB*SB:[6
M<RPQR^;!;6VLL(_.AMT>UN8E>,2(DQ*?JC\(_$]QJ?A1KU]9\2/I-S<*J>&;
M?7KRX\,V21I<F36[32;IXS%?ZH+VZAU.X,\MU=+*1)<LC212?R5G?B9C,EGF
MF*QG#="@L;E<<)AL1"A1>(^L3@Z:3S'%<F(GRRDM=&VE&+N]/ZCXF^CZ\EX7
MRS,\EXBGCL35SQ9MBLSHXKZ[E\H8BHIK!4\)&=2G1E'DG"":BY.<O:64*=_R
M&_X+J?LL_%CXN?L]?`KQ;^SQIFF2^(/V>]=\7ZA?^&84430_#<^$?#:0:SX9
MT<*QUI?"4.CK/=06XM;C991[+>[=%AD_BU^,OP_T/P#J%OX>@^)O@G7=2NO!
MEOXY?7]!UN:ZN;+5=5$LNK>"/$6GR6*W%QXDB@2>26U8V/\`9BX^:8_,?[:O
M^"NO[?>D?LV>'/#?@?POX;N_%?Q:\:^!_%FHZ%"VJV=OH>BZ;/!/IFNWVJRV
M\HNQ>6<2SQ:3IMAO:[:V6?S(R1#7\5.F_"-M3N/'<GC;P-\1KGQKI?B6[L/$
M_AN62R\+3:)XBOWM;C0[&VNKG1=2NI]6N+35+@WT%Q*HO;.%+9Y;8W9F@_J'
MZ+>99]1\/%2SC!U<+EV$K57EE2I9JHL9-5*[C%.4TN>3O)Q2ZW:/XO\`'GAG
M(:?&N6U,KQ%3$9Q/`SQ>?8".'K?[+B7/V>&4YNDJ4W*FU*T)S<+VJ)2NCX__
M`+2UT<+)"ZCA7W2_,.S?ZC^(<_C17ZR:=^P)X#O=/L;R>?QG;3W=G:W,UN?$
M]HQ@EG@262$LMB%8Q.Y0D``[<@`<45_2/]LX!.WUN.FG3^[Y??\`]O'Y/_JM
MC79K+9]'_"E_=_O+M^?9GQI\0[%+OPC?SL\1DT[4=+GMXG"G[2EW!:VD4/SR
MPK&L]M!)=,QD4*/W+,O^O'ZN_P#!*G]H;X>0_!GXR?`#XR^!4^)OPV36_#_B
MW4].>WCNM1T+2[F/5=.O_B)H%G;0OKD=SHL\6DRZW-IK/;BRU!FF:7[%B[_*
M[4Y;;4UU#PM?J4UB:S7^R$FBCMQJ][<6\K:$U@LWFP3?9I1]A4.6CE9O-<(`
MT-?K5_P0#^%W[.'Q=^./Q?\`!WQ(^+!^$WQSOO!%E8_!"XU7RK'P5XBN;[4=
M1;Q#IM]JL[Q3(((K/PV\N@-&8M3-Q<6T/EE#YGS/B9@,#F?">/H8BE4K3IXA
M3H5J-HRI58/FIUH)K65.2C+6,DVK-::]'@[Q)C>&.)<NS.C6IR45&&(A.+4*
ML9\D94:D>5N5.HO=:49*TI<U]$?JA\'_`/@G9\(_&Y/CGX<_M1ZQ;Z==7<4E
MOH^DZBG]NZ;8>42;:\GMY3)920)(/($P^W6C1*RK)*H6OJ7PE^RSIMCXX@L-
M9_:U^*WC"VM+J*'3/AAX%\=Z]>:E+!%M:.+6YW^Q>19%$:>^FGT\V:0F1)KA
M(]TP_2OP=_P1X\-ZYJ4'BWXB6>D>&=;TV^D%W+\/=;OM+C\10P/&+*_O+;2=
M1TK2]4LM5&'NE:WM[U(7>-+EI"L@^2_^"W/Q=^'G_!.?]A#Q'\-/V>=(T+PS
M\2?C.EQX-L/["D:PN].\%:G97J^/_&@U'284GNKZ/3''AW2;Z^O8KG^T-;L]
M35V:U-E<?P_A>'.(N*L[I9='-Y8[#8C$_5*L\?DU.&(E3YU3Q"AC%!^^H.?+
M.5"$>9)J2T/]",7X[<'9#P[C\5A\JK8>M+VDYY11JX5Y74Q4(0GAJM"+PB=.
M*K3YU!N$TE=VNI'\H'_!1#X^>`OVP_VS;OPGX-U>'P7X"^&%AJWPK^&/C0W<
M%QX<@\1>&C?:?INO76KPK?ZI>Z/XRO[6_C^USV-O+<)J%I?[88Y"4^P/$?PY
MU[Q5X1TOXB0>,?A[XDO=>\*W3?'#2_$7BG3;;QK??$'P]HWAB&_UKP]IBM%?
M>(QJ-[<O/INMQQ:;<):6QL(=.G=_.7^;6UU_5K;3/)TZXEL[S=<7<.HV(AL[
MN&]N(8HKF62XAM_M,[201?9;5C<H;&V?;"3.@G;ZVN?BK\28]/\`#.@OXNUR
M[BT'3-&MH;W5+J&_FL[B^MDUO19TUA+2UO8[J&RFCAW7C7L4DEG'<2QLA^S)
M_>&6\%Y!EG#.69)2>9X"GE=!8>FXUZ;CB7R*,:DU3FWH_>?-J[-6NU;_`#JQ
M7B5G+XNS/BG&*GC)YWC*BQ-*:YOJ=#FO24;WO%NT$H)^[[UE=L_=31=<\'IH
M^DHGA2`HFFV*H5L8G4JMK$%(=]65V!`!#.JLPY8`DBBOQNTK]JWXF66EZ;92
MZ9X0NI;.PL[62ZDTJZ\RYDM[>.)YY,:D!OF9#(V`!N8X`%%?,/@6-],TK-7T
M=YZK2S_#\/-GWJ\8[)?[-A]$O^7/;E_N]+?^2^9\Q>.26\#_``]O6):\ATZZ
M,-VQ)N8C#>>*3$8YSF6,Q&.,Q[7&PHFW&U<6/#EY=Z<WCC5-/NKBPU.SLM!O
M+34;*>6UOK6[BM-9EBNK:[@:.X@N8Y88I(YXI%E1XHW5@R*045]?Q)_R)\3_
M`-?/T1^4<'?[[A?^OU#_`-/(_;[P-^UE^U1X<^#]E;^'OVE_V@="M_[/N?W&
MC?&7XC:7#\D<>S]U8^)($^3`V_+\N!C&*_*[]KCQ9XJ\6?%/]IN^\5>)?$'B
M:]MO'/@6SMKSQ!K.HZS=6]I>6^KW%W:P7&HW-S+%;W5Q;6\]S!&ZQ3S00RRJ
MSQ(RE%?DOAY_R.J?_897_4_3^/O^1*O^PM?^EQ/C>S1/)3Y%YEMP?E'(+C(/
M'.>_K7UMH<$$OQ%\9VDD,4EJGA?P;*EL\:/;K*G@&#9(L+`QK(G\+A0R]B**
M*_><;_"I?X_U1_/D_AK_`/7R'YP/G:_EE6^O566156[N555=@JJ)G```.``.
M`!P!P****X#=[_-?G`__V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D:6=I;6]N+F=I9@``````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0P,#`@,3`U,34T,S0Q-#<@,#(T,S<T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y84$`00#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````00!!```(_@"Q"1Q(L*#!@P@3
M*ES(L"%!68'T6`EDS:'%BPD#!0*TL>)`:-`.81QY,2(@4H"L&`QD917)EPNM
M5/DSLXK!)U:NP-QYD(LU0%4`Z;EIQ<H>GD@%LK*V)>A!*"SV6`&4=*<UEE,/
M6EEQA<65HE5?@D68$XK1G"K#CDQ[L,J>*U]5YE2+;:+%0`CAZD0K<*A:*S(L
MLD(H52"4KW0)VFW8*F]:*X?I%E4)EZW"P0MQ)B[Z]>T5EPLQQZ2+5V#.R@Q+
M)6[(4:!>N*(1EEX]T'+MHE&N1#&J!YI"*+1K)Y3Z%DOE5K$+LEQ]FF%.J44#
M7;.67#C=*V\M2H0"+5H@5M>@_K%*3K$JYZ^5M]HVR%'6-5:"P%\+[Q';JE;U
M=[Y.OUZA^_FER!<>:*R(QY,,+)C%PH(8N>1>--2Q\MTLT;RG%"N@*62-+-'(
M0N%\@9@22((R1+%@@BNP8%-HULPW7X'1[!%(A4MAHP<B@4`CBWB-$:3C?RZ*
MV,J0"6[%@@PK/&$1D!6*QTHI@<P"XG@"SN<D-L_(U^)TR`F"""O(;;4"3/])
M62`KRD`IG8M2;NEB-.!%,XMX:@HRI"FM?#G;2U6"5*"(:[KYX3526GD-H*8D
M:@J80PY9'4G@M0@G-!15Z.)\EF*Z)42)*I,HF..U(DN&/$%S*30B2KEHA5+.
M4NBE_E+N44JBLS:*'X15;>@BJE&6`M@5%5J3J8NMA`=EFK."Z>*C5KD8Y42E
M?&7*I2Y>H9$57%"Z*'+S4>A;8M#,^1T+46)%(:O7X(C(1%9`]!TKELZ9GUH1
M6L-"%S(<((,5X18*S0I=""*##*Q<@>-X\\U+&RNS3(3O%01?(V>Z,0S,PD1X
MZH$P-`JO)C$B5W0!&"*8@GAO%P%;,6>`'=.FD8"%6F/%`2NL('$@7\6''"+!
M(<0P*P^R"8T5\4E,:*'C"=+S005>:FF+A[AI:;@T+FT0E56:$J!&LT@H,81=
M!\*SU06U6K(UR"$W'KI-PD?V0>)=VJ*=W4+XXG>FO'W0_B%56A/SI1I%M*?>
M`AVR:)6$$BOA*K)T13A!H4XGR"&"!")(Y8@L*HN$T2#VN%+6M-C*G/""">?.
MK"""2+2?8X/P>X<(/0OJ:5L^.-G6H"I+A!6R:G<K@<B"NM*/CQK(*JM@F&FA
M.P9R"""KI-1?S]&K8KTJ4\'J+"#6&Z**(501OLKUA:A"$[560J]**J]@8P@5
M>NM1116&_)&**MBD5.RK'7*Q2BI_".`6_A"^X,R/>]<S7Q[RH(HJJ"U4R.$>
M3?ZP/NO19'H[B9[ZU@=`+9""%%2H0A[R9*L(`N5Z]UL?4%:4%`FIXB2`2$4J
M8%&(%(YB@6,RR"KR@(P\C"*!X=A((0%;PY-`/"$EL@"*]PH!"/7E`0]^*4@I
M5-%#4GSOA5<$"B"X,#:81&L%5?#5"E10/@)6@0JJP$,>E+02;"S0>H7XPQ9J
M^,)5/.$)$MI)S59PB$"L`$DT`43-5)"'*CPAB@3980!3@3Q9'&(+310;*[:B
MD9?XD04K",3`:O8'+AQB!3%8@1[8B)`%4M`0R6/%$>=GA3PMZ'8-$9-*_KC'
M*ASB"2P()0L1LHH_Y&$57*C9%?9(2\#LD2?'%(@?YV>1)LZO9ELQ`#%S6#.8
MY)`@F-1C,@5RS=9Y\YO@I$M````[=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O;6EB+F=I9@``````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#4V(#$P-3$U-#,T,30W(#`R,S4R-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$@
M`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8`
M`&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9
M`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`
M,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9
M,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``
M9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:9
M9F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`
M9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9
MF3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`
MF<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9
MS`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`
MS)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9
MS/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`
M_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9
M_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(?D$`0``V``L`````"``(```"/X`L0D4"*"@P8,($PY<.#"A
M0Q(02>29F`<`0X8."R*)")&B1XL7"3K<&-&CR8(AL67D*-'DQY0K.;I\&?(A
MRYD405Y,R+(CSHHP$?;T.5,G1IX``A146O#D08P;,R*\EI&J3@`D(4K=^I1@
MGJ$&I$HDX;#AQ((LQ7XEB]!L10`]P_*<R-;@0@!GT<I\VY1HU[LY>[IL27/G
M6<$_<Z94N90E$J=P%2]F'.#FQX(&)"\^*)BM5KQ`)\--&A?`G-.G*X;>7'=H
MUL=?)Q/\##<M7-BK6=>M'1')P;.R]>ZNC5OS9MX\B0(7#8!JU.0^C=9L?HTJ
M[8<HCQ>L;GWX2>8'N0QG++S3H?B$F9=?#`@`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R
M<R]V86UP:7)E,BYJ<&<`````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<R-C<@
M,3`U,34T,S0Q-#<@,#(T-3,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`
M,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*
M"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A
M""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U15
M5E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>H
MJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V
M]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!
M`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P
M%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E
M9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#
M`0`"$0,1`#\`_K7^%.B>%_CG\8?"'[4'PQN5OOV?OC1^Q#I'A'P3=6&DG3+3
M3+?7O'LWBZ,1PK<"RT6YUGP_XET>5M"%G]IOM8T5+@-8"ROX)/R%\&^#?'G_
M``4#_P""/7[9?_!-3Q9X.CT_]J;]BW1-6_9T\,P7>FI:VWBG6O@]&-4_9S\>
M>'GU.6S:RN/B3H7A/2=%;5!.UI;7=[<ZI<Q_8[WR7Z'_`()-^)?VV/@%^RGI
MG@'X#?L9W_Q3_9@G\;7U_P#L\?%KXG_M#^&O`OB'7?!OCGXB:W+XF\<:M\*M
M4TW4/%'@+X=Z-8"VUK1_"EM/X@U\07-_>Z8^KV5VTS?O;I_C'X/^'?CSKOP[
MC\6:4WQY\?>`=%^(FO\`@BUN1_:2>`_"=S%X27QMJ-B;>6/3=,2_N8M)M;_Q
M!>R:AJ9M)[+1[=[?2[MD`,/]G0>$_A-\'_@5\![J[T[PYX@^'_P;^&7A!=`N
MK^.X%G>^'O!^@:1=:"FK-.]G?:[IMU9*]YI"W@U6ZL9;?6(X98Y!<'Z.U+48
M]*TVXU&>"[D2TMC/+;6L(N;Y44X=OL\+/YHB`)8P,RMAB@9<$?S^_P#!4KQ'
MXFT_0_B_XI_9=\7?$7X8_'7X6G2_%GBOQ]#X\-SI_@HW]YHUC!HOC7X"?$.#
M^R?%7P:^+^D:;9PZ/XU\(R:SH\OB19M!EFT+Q!'<6)^%_P#@C#_P<,W7QM^)
MUI^Q?^W;<^&O!'Q;O-0/A_X2?&&SCD\.>#?&>OV4&VY^&?BRVUBZED\,^*[F
M8*?"7GZC]GUU!#HT]XFM_8I-<`/W_P#VWO&7A?QE^Q_^T9=^&_$>GG7?A_\`
M#35_BYIT+9M]8L+[X+W%G\7+6X-CJ@L[BRAM=5\'V5CJ&HVLY73YI+:XBO+.
M]@@C'U1K&B>!/CA\.-+'B'0].\5>$O&&CZ1XELK6Z4S&5=2T6#4M,NM)U.+[
M'?:5J\<%W%<:5KEA-9:A:RHKV\MN2%%SXC_"WP#\6?#VH^%?B%X:LM>TK5],
MUC1;V*5I[6ZN-+\3:+=^'-8@COK:6WNX8;G3M:NK.2V%XZ8,3@//!;21_!__
M``3G\2_$[PAX>^)W[(WQ?\2V7B#QI^QYXI'@'0M;ALK1[_Q5^SSJKWTW[-_B
M76;J'67DN?$-G\.O#\>E^,+M[+S[_4XV61VU5;F=P#Z%@^"?[1MA!#8Z5^US
MXI32[**.TTU-=^&WPVUW6TL+9!#9KK.N7FB/>:SJJVZ1C4-5NW:YU&[$UY.S
M2S.25]8I$BHBF-,JJJ<I&3D``Y*HBDYZE54'LH'`*`/B/_@G1J6GW'[&_P`"
M/"MO80:#KWP?\"Z3\`O'WAL00PW7AKXD?`UYOAAXVT6_A@)%M+!XH\,ZA?:;
M;2&-KS2-4LO$9%Q;Z[:7$G*Z+#\-/@%^W3\4M4\5ZIJ.C^(OVTO#?PNN?!FO
M^*%M!X9U'Q7\%?#6I>%-2^$WA7Q0?)M]*U6'PJ^E?$*P\%ZA=?VAK-[J/C7Q
M!X6M[Z&VUR&+\"_V4_\`@II\7_V=/VY-)@_:K\.^"-"^#G[7Z>'/"WCOXK?#
M#4KR3X5:Q\:]-MM.\)_"_P"/VG:'-`LWA6Y\>:;86?PL^,UAH)FTW3=2M_AI
MXPU"VLFCU>Z\0_U#?M"?L_\`PG_:A^$?BKX+_%SP[#XA\%^++&WDD@AO+C3-
M7\-ZG93R7>@>,_!NN:1/:ZGX9\:>%=<2WUK0?$GAW4K'5M,U*U@N+/4`5B1P
M#S_]J']C?]F7]JS3M"O/VAOAUI'BB?P"NJ7'A_Q%=:UXB\+WFA0ZE;1MJNGW
MVL>&M<\-7-_X5NTAAN-7T76KZ;0K^>+SI+%9RK5_"!_P4U_X)1?!W]E[5OB9
M^V+\!OVR?V</%UG%XH&N>#_V6[FVL/$7B?5+/Q;=6&B7^E:%IWC+Q5XL'BFU
MLK">;7Y[G4]/U*XTN\E,L3PR00,G[L_`G]KC_@J7^P'^TK\9/V0?VG_A5X[_
M`&]_V;_@K\.[/X@?#O\`::\(Z=II_:0U/X.>*-3U+2?`=SXBT^&_L[?XHZEI
M>J:+=>&/B!/:Z6/&.DZR++6"+S1;^&=OU3^'<O[#W_!5?2_"7[0/@S6(?B-I
M?P_>[\+2Z/+X8\-:;J'A+7[B4:EJFD:_)X@\'7OC+2-9MQYNF73>'?$ECIMR
M+036QDCN!<D`_G6_8&\9?MA_!G_@GLW[07Q9_;V_:>U#Q'X,^*5A\+=&_9]\
MCP[\4-'L=2O(?"NI_!;POK/BGQY9V_C/1'^*][J]I:Z9XG.H:_X,;PMJ&GR1
M^5J$J78_JH_9#_9@U'X"Z)XC\7?$GXA:S\8OVB?B]/HOB/XX?$[7)K95U#6]
M(T^2TL?"O@C0K*WM]-\-_#KPO+>ZC9^%M'MK=+@6;1WVMW6J:[/<ZD_`?MB?
M!G]ACP]\#/'?C_\`:>\(>"_"GPR\'>$].AUKQK;W6H^&O%-E8Z!:V?ASPO::
M%K7AVXTOQ!J7BNRNDT'1_`5A#/>:S<>*FT>TTRTDE@LH[GNOV&/B/\2?B?\`
M`6T\4_$676KZ*3Q-KVE?#K6O&.DV^A?$7Q%\-M).F6FEW_Q+TS2]FBGQ_'JY
MUW0M7O?#]I8:+JT6DV.M6=NC:C/-,`?:`&`!MV8`&T8`7_9`4D#'3@D<<'%%
M`7:`O7:`N<`9QQT'`^@X]**`/P&_:WNOAO\`';P?KGA+]I/_`((N?M/>)O@C
MJ5G"D7C?P#HWP.UOXE:9"8Y[V/4;;X>?"GXL3?%?PTD`B:'4KFT;[?)!YUC+
MI\D5Q+9-U7_!(G]NWP%\4(O%?[%$_P`:$^+/C;X"Z?)??"/QUXAL-7\->/OB
MA^S[9:O%I.@6_P`1O!'B6QT3Q5X3^-7P8E>W^%_QET;4-&2:XU#3M"^(*7-_
M9^+Y!!^YQ10%0*%5"-J)\B*5<.NU5PHPP';D94Y4D'\WOVO_`/@GYX$^,/BC
M2?VG?@CH?A3X4_MV_"9)_$/P8^/=K82Z:VJ:Q9Z=<V;>!?C`NAM:R>-_A?XS
MTV>;P;XNM-7M=4UC2]&O;?5?#5WIFIZ5;7<0!T?C'4SH_P#P4F^#Z:O$FF:9
MXJ_8Y^._A[PIK=VES##XF\7:3\7/@QXCUWPS:W:Q16=QK.D^"]-U+Q%::;N?
M4$T>#6]5M+6_L;"[\G-\`>*?@G\'OCKX_P#@=^S'X-M_%_Q5^*_Q,U#XM?'D
M^'Y=*T[P1\,9+G2?#OA_5M9\2ZC;1P10SII^E:5;Z5X(T6*_O;GQ)=:G-J=]
M9W<EX\FE\*?&?P:_X*+?L^17/Q"\%W'ASQCX.\5WGA;XJ?#>[U6YT+XH_LX_
MM`^#(9-`\4:3:^)M`NM/UGPYXET*+4=6_P"$=\6:!>6#^*?A_KEK<64\^A>(
M=1M+G\#M*_9^_:V_8K^+/QVT;_@GKXS^&MQX%^%TVHVWQG_:#_:1^'>N^$M&
MTRU@\,W_`(P\3CQ;\:GU._\`"?C^[^'$UQH&C:1X:\&>%;@P^+KO4M>\;:"Z
M:1`LX!^P7_!0?Q!X`UOQ3X:\(S^(M-^(7Q6TS3=.\,_!3]GR[\-V?B+PG#^T
MI\<]33PG\'_C+XZ@O)-2TJ^U+X7^$=(^(7CCPOHVJV5V=$T#PIXY^(5E;?VE
MIOAZ<?IG\+_A_HWPI^'/@7X;>'Y;B?2/`GA/P[X4L+VYD9[W4H/#^CVND1ZE
MJ4QDD>ZU"_CM1=7MQ-)-)/<R-*\CL%8?D7_P3'_9/\;7.B?#/]LG]INTTI?B
MSXT^'UOXL\*>!Q/K>M:MX3U?XHZ!!+X\^+OQ9\9>*A#K_C;X[>./"CZ3X,U=
M]2TK0_"WPI\`:3:?#+X=:9IVFZAX@BU+]L!G`W#!QR/0]Q]YN_\`M-_O'K0`
M@`````````Z`#@`>P%%+10`V,DHA)))122>220,DGN352ZXM[IQP\4%[+$XX
M:.5;=462-NJ2!7=0ZD,%=@#AB"44`?DO\&T30O\`@M!^VAH>B(NCZ+X@_8\_
M90\:Z]H^E*-/TO6_&4GC7XQ>'9/%NKZ?:"&TU+Q-)X?T?2="?7KV&;56T;2]
M.TMKLV5E;01?2'[<=E9ZKX+^!6A:G:6VHZ)KW[8'[,NG:[HU_!%>:5K6GO\`
M%O2[Q[#5M.N$DM-1LWN[>"Z:UO(9H&N88IRAEC1E**`/M<LQ1,LQ_>J>23R-
M,>0'D]1(!(#V<!Q\P!J\%5`$151$&U54!555X5548`4``````#`XHHH`****
M`/_9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]A=2YJ<&<`````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#8R,S4@,3`U,34T,S0Q-#<@,#(S-#`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_P`_^BOZ+S^P%^PG\5?AHND>
M'_#O[27[/OQLTO3;UVU_Q#HOB;7?"FHRVUC>W*GQI\'_`!+I*^.?#]SY]E-;
MSZQ\)_B!\9-%L(89=4U_1=`M!);V_P`[:9_P2'^(7A'P'XZ\>?&?1O%FC>&M
M.^(/PS\%_#WQUX?U+3;SX>_$#3?&OAWXRZYJ^L^'->31+LWMYIC?#71X8[.[
M73[O2/[8N8-?T7[8UO;P>;C\WP&69?C<QQ]?ZK1RZBL1C*5:G4CB:-%U51]I
M&CRWKTU.]JF'=6G*,92A.4;-_7Y-P-Q%Q!G64Y#DV&HYAC<\Q7U/+*E#$4OJ
MF(Q3H?6(T)8F;C##594^7]UBE0J4Y2C"M"G*Z7XLT5^_7[3G_!$GQAX%_:"\
M2>!_@+9?$;6O@EJ^B?#/QK\&_BK\5M7\%^&=-\;^$/B;X&\->*]/AL/$FL:9
M\/\`0_&_B+2K_6=2T+5M/\`Z=J%[!?Z+J%I%I,UQ;'SV?%3_`((.>.?@!\(K
M[XQ_M"_M%^$/@KX:!D;0[GQQX`\1>'+?Q%+#B>XT'P]H?C?5_`_Q@\7>*([$
MK<06O@?X-^*-"N7N=/67Q%917<LUGT/'8%K">SQN&Q%7&4</B*6%PM58O&1I
M8J,9495\+AU5KX=24U=U80BK3;?+";7#4X4X@HK%3KY97P^'P>(QF%JXW%RI
M8/`SQ&`<EBZ-#&8NI0P^)JTK*].A4J5&YTXQ@YU:<9?@117NOACX(WOBK4C9
MZ9J=U<6\MP]I831Z.YNKZ>1S#9K#91WTSO))*\)DMXY)'+,+6&1YG1J]5\<?
ML6?$;X>:U>>&/&0UGP=XJL!"]YX9\<^"]<\':[:)/&)8FO-*U9AJ%KYJ$/;F
M6U$<\961)-C!J^DH<.YQB8J5#!NIS*3C%5\-&I*,;7E"G*M&<XINSE",DFK-
MIGS3JP5[MV6[49-+;=I6UNK:ZWTN?&M%?2__``S)XF_Z&/0O^_>H?_(]%='^
MJ?$/_0KK_P#@=#_Y;Y_GV9/MZ7\Z^Z7^7G^?9G]1_AGX5V?C"QL]=^*OCS]M
MKX"^"=6TQM6\/6?QO\7Z`_Q%\6V(;S?[0\*_"K2[N[\4W6@1JMM+<^+O$=CX
M3\(VT<4]_<:Y#:6XD'3Z/HO[-OQ%^#?QTT7X+?M'?'OXB^._@MX5\.?%[4?`
M?C77M(\6>"M1\''XD>#_`(8WNJR:AX:GO?"-IXBT.V^(VB:C'!X3\2^.-+MM
M/74K6;7(+J-X9_Y^_%?QF^+'Q6BO+OXB_$+Q/XODUF\DU+6FU>^61O$6I.]O
M(=1\2S0Q6]QXGO[:XM@;.Z\0M?S:>ZN+%D#&XGZKX*?$CXR^`/$.O:1\$M0U
M^'Q'\6?"EW\)=;T'PWHZ:_J?C;PSXCUG0M7F\(1:0+#4;N]>_P!>\.^'[^UC
MTR!=3&HZ99/9S(ZE7^%S?P-RW.,BS:"E1PF/Q6`Q"RVC#%XUX"ABITD\/7Q6
M(K2J5ZL*4U&:C&E3IMW=2E./+"/]$<(?2+XEX8XEX?Q]2O4QN6X#-,!5S:K4
MR[*O[2Q>5TL53GF&$P=*E2H8;#5,7AO:T/:.K.M'F3I8FC+GG/\`JZ^"6K?\
M(Q^S[\"?$GC+_@KE\1?V;O$/Q)\-_$E?A9\'/$UEXHO/"2+\(_$$O@R7P5X4
M\:^(_BEX9^&'AC5;FSE\,_V!INMZMX/46GB.#3]/@DAFF9_YV_\`@I5\?_B]
M\7/B$OAGQ]\6?B/\4=3:TBT>QU7XD^!?">A7VC:+8W.H2:I:V^M:1XJ\4:DR
MBX14LUM+JZ\/:]I&J2ZEI>L7<%S'Y_S-^UOX^_:=LO#GPP^"/[0&F^+O#FF^
M!M*U;Q7\.O"_B[P;:^&+K2]'^,-AX2\:ZEJ=I>2Z19:SJ]MXHTY/"^J"+4;R
M_BTI62*R32[B;4K:?QKP>^O:AINC#7M9UG4X-$L/L>B66IZE?7EKH>F/.UQ#
MIVEV=U+Y>FV[SEKF2&UC$+,B#[I4#I\/?"7!9%+(JE7%5<1FV%P-&GFT\+FV
M:8O*:U:G%1=;!T\1B512DHTF_P#984XMU81I*$8N/F>+'CEF?'&8<483"X?"
M4>&L?FV*QF31QG#/"^7Y]@L#7KRJPP.+Q^6Y:L95Y(U9P<IYA7K2G&E6J8JK
M5]I*?V9\/_V1=:E_96U;]J/0OBM\!ETKP7XR?PKX@^#T_P`4['2/VB-'MFNO
M#5KI'C"S^'&IVUA=Z[X9U75O$B(FH>&M3U._M7L;RZO=/@M[6>2VL_'[]JO]
MH#]I?_A!;[]H3XJ>)?BQJ'PS\*1^"/!VN>,7L=0\1V/AF&8W::=J7B?['%KW
MB)A<F6[DU+Q/J6L:F]S/=W,EX\]W<O-\\VYCB@61L!G9AD@9)R0%#<84[,_,
MP4'))`Z>=>-O$\EE;K;6;!]0O'^S6D`!8-*SQH4!!`/EB0&7.`\ABA)"LZ+_
M`$9&G1RO#RQ&*EA\34HSJ5,!/ZI2IU\'0JTXTXX>%12DYR<6X<\?92J1J<DX
MM7;_`)\=1348TU*FYP@JZ524HU)1E?G<;+E7P\L'S)22:;.C?Q?8([(98<HS
M*?FB7E20?E>Y5AR.C*K#H0#D45X__P`*\:?]_-=7SRS?O972W:1'DD^=V624
MO*ZLS$J\CN[`AG9F))*\_P#M/.WJL+&W2]2%[>[:ZYM]KKS?=7%"G_,^GVO3
MR]?Q^?76)#6=J1G_`(]XARK*<JBJ>&`.,@[6QM9<,I*D$^A_#/XF>(/@S\0?
M!WQ6\*-I2>)?A_XBTKQ7H4FL^'O#/BFPBU71KR*]L9GT/QCH_B#PY>3PW$4<
MEDVI:/?);7BV]W#$+F"%U_,AM9UA\[]6U)LLSG=?739=\;W.93\S[5W-U;:,
MDX%1OJ>I2(T<FHWSHZLCH]W<,CHP*LK*TA#*P)#*0002",&OB9<74I471E@)
M34J3I24JT>62<.22E'V;]V2;3C=Z:7UN=BHR4E)2LTTTU>Z:=TT^Z:NGW/TZ
M_;;_`&X_B!^W=^T+=?&WXW3>#]!U2[B@TK3])\/6:Z?IFD>'+>_N[N"TA;4)
M[K5;I)[FZO+RX>[NI+--3OM2N[&QTZ*[FM!P.D^-O`T5O'&OBOPW$\@+%7UC
M3H0BHI\M,O.BH%C4%8V(8.Q0`,VROSUHKSLNXEJ98G'#X'#^SY8PC&4IIPA%
M644XV5DK_9ZW=RJU%UW.56I*4YR<YSTO*3U;?3?6RMZGZ3W'BWPZ(ED@UO2;
M@2)FW,.HV<L;*5W)(62Y91&Y8.=KG=O)C!&2/FJ]^*?AZ+Q7]OODO]4M+2)D
MM&TY;:0*SDD2,UQ=)'+,RO(SNK,$=XB3YD#0I\VT5OF'%^-QOL?9T*6']E45
M2W,ZL9-6Y4XRC%6BTVD^;=6LU=YT\+"G>\G*_6UOU>A]EK^T1X)"J/[)\3KA
M0-JV6DE5P`-JG^VE^4=!\J\`?*.E%?&E%1_KEG?\^&_\)X^7G_5_2Q]3H]I?
M^!,****^5.H****`"BBB@`HHHH`__]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O:VER:RYJ<&<`````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$R,S8P(#$P-3$U-#,T,34P(#`R,S<R,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/Z"O`_Q,\#_`!*\6>//#?@O
M5-*\01?#'Q;I?P]\8>+/#FJ:7J/ARU^*'VRXN?$WPNTF^N-9@_M_QSX0\/\`
M]B7GB_2/LFD6/AVY\7>'M-DU^]\16_BSP[X4_)?_`(*_76O7#_!VSA\07WAG
M0=3_`&9_VW-*U#Q-HUF^JQ:CXPU'4_V;?$OP%\$>&9[.2WN#XX\=_'7X>^%-
M#\.:/.KWNKZG:77@[1=4EOKVX72?O+]C[]GO1_V2_P!G;X6?";3[6[C\80^$
M=!OOC#JL$]_<ZEXG^-'B+2E\7_$/Q=X@UH7L3OJUU?:Q8>'(_$.O0:GXBL-"
M\->$O#Z:DFF^#_#EKI?Y[_MS?"7PC_P4`^..M?#WQYK?C'X9?#S]D#6K2VFU
M/P;J4$$/Q>\:_$OPKX/\1^-H/%6JW=K>0>&_"O@/P'=^$-$^&_B3^Q[VRUJ]
MUWQ=<Z=+X?L_#U[':?P#@JN3\.9K5Q6-Q4J>%P%!R:^J_6%6]JE1BITES*+4
MG%P=I)-WDI14HG]R8"CB<QK865&K3C&O5M:KRN%EH[7B^DE>S3=DKJ[;_/3]
ME?\`83^'W[1_@+XQ_%KQ5\69?#OQI^-/BR_U_P`4:#\$=?\`!-[;?#6]U7Q+
M=^,+_P"&OB73%N_%>@^$M*\1>(/"NB?%&?PUK,FE>(]$D\.Z1X:O&M_'FA7U
MS7T7XH_93^`OPA\:>&_"OC/]I#XW>,_$7Q(U;XB^*O`OP$\)+X%^&VHZCJ_Q
M`DM_$>NW[>(`?#>CZ5X;\0S+87FG>&_&7C/P]I?B1-+\//9P:_+I6D30]EIO
M[+'[-UQX#\'>!OV>O$;^%/!7Q*^-GA;Q#XPNO!7Q$\3>,[CQ?_PAGP]^+FOZ
M;HZWU_XRU'0E\3PM<W%UK5G:>*M+5=!LO^$[\17VI^.K75[KQ)[K\5/^"?\`
M^S'^T-\0?%WC#XF_#>YU_P"(GQ%NH-5B\:^&_&VJ:?XS\)0:/:RMIWB+X417
MM]X<L;ZPM3IJO8:UIMW?:8^BW=J#H&J7A@U0_G^8\;4ZO$]>ABL\S+#95CH3
MG0K1RA.I1A;EA!-RC*$(I-)1JKD3<H+FJ2D?K,LN6!P5*-"K@98NDN=44H)5
M&^722BFIK>334GHMFTGPW@CPY^S_`.`]-TG]E_QG^S+/I_PDO=8$-IH7QCT;
M79/B1X<^(VK^"YM#\':KXFT/Q'H?BGP]>:)XST7PI9>`?"WC[X:^*/'5OI'B
M6VTOP;I=EH&H>-=+\/>%O`/%/[+[^'_VK_%]CIY_:$_:";X4>#?A]XA^!5EH
M/QS^$$8^"OPVGUCQ/9^-?"!M?C%<:SK^J6^D/;Z;>>#?`_AZUU+PEXL^#^KS
M^'/$UYJ6M?#33M?@_1[X,K\8O@!\)?B;#\79=*^-FK?`GPYXL;X.?%^VU.ST
MWXG_`!0^#NG>'+_XA:3X.\5R7RZ)>/+HCV-IH-I9W/C+4_[9&J7GBO7$U?Q'
MX9&I:I\+6?P6L=#T7]EO]L"]U_XVZ)^U+\8_C1\$?C#JDNO:D'^$WQ.USQ)H
MD;:5IVC:O\/K[7-2TGX;^%?A-XF?X+>#=6\-W&L6>D:9JGAWX<^.O#AT?6O%
M;V?3D&9X>E4QD\-Q'CLWH5)>P4L2JTFJM27M54C[2I"48N*5-NSY;1A*'M)3
MG#YS%XK&58*.8T\-2K5I.%&C""BHV7-=1BK)RBFW;73F=TDGZ%XO_9\^`_CG
MQ;XH\;2#]N*XD\8>(M;\4R3OX&_9YLGF?Q!J5SJS2O9Z[\#+C6[1I&NR[6VL
MSS:K`6,6H2R7:3.Q7DGB;_@L-^T!\,O$GB#X;:I^Q!%XSU/X>ZWJO@?4?&/A
MKXF^-+SPYXLO_"=_<:#>>)?#]W'X%U".ZT37;BPDU32KA+^^2>PNK>5;RY5A
M,Y7VD:&-DE+GAJD]<9AD]5%[.NFNFC5^C/FO[/?9O[_TTZ]-/N/Z)%GL]0\9
M/>V^KV6OVFK:FE]!>6<EGJ*R:9K?V?5HIKF_5&BGGM].TT7.F:A;LFA:EX?D
MCU`0/%)&P_D[_:1^)/@#4O"7Q7^+OBG6/CEH7Q^\:_M>^)_AA-\3O%ME\&OB
MG^R;I^E?"CXW?$O0O!6HZ#H&O:'XUU'5]$^"GP'CGT+P*-,TBRU:/Q1JOB*'
M77U#3M$TJ'3OZ4?C-X:OS\!OCAX<^'DNG>&O$\WP2\9^&/`U_86]SI\&@F#P
M7<^'O#L/D:684\J#28[6RT>WTB*$:#IMOK$2+$+"V$7X.?`+Q1X?^,OP@_9'
M\"?#GX,?!+4M)^(O@BZ\-:7:?%K_`(1V\T#PM\6OAAX`\3:Y\6-;FL[33/BI
M:V7_``N.ZUBTU72/%&K1Z%XFU"[DO8;S3-,GU76M.FXL#G4J6"Q.8U<'3Q*Q
M3H49>TC"4GR*=:,6JEU+F<.92Y9Q@X*]N9*6F291@:_/3Q&(Q5-4J2GAY8:<
MX*G4;@I.3CJH\NFK7-KULSZJ^)O[._A3]G_XW?`?XY:9^VE^U9;67BKQ?#^S
M]\4?%]Z_@CXUZA-\+M7^'OQ<^,D\END7P%UO2+:PU/QAX/\`@AH%WK4&E:KX
M:AT37=0L)HY]/\/WU\_B_CMA\2_'7P=\+_"3XM^'?^"@D'CVY\:>)/')TKP%
M\+?V</B[\*/''P\L]$TSP=XOT+XJ>&/"VBVFC^)9?&/B32K+4K34=/MY;K1/
M`_B>VU+6-2M9M2>Y]*\+6?[/?PR\0V?A[XO?`#1OV*O&<TJ6?A;QWI(TSPM\
M.M5G%NNA2Z+X8^-W@0Z)XF\/>)O[/\0MH.IP^*;/1)]3TFYO?#EQ':V/B^\L
M=-Z.Q\>>$OV5_&VJ^)M(O_AMI_[)_P`7_$OP_P##6LMX1\0>#5T'X&>.M,FU
M;P3X:\0Z-X>\/WWACP[?VWQ(CGF\.20:1HO]F^'-<T_1/$OCWQ&=1UW4EU#S
M,5Q)C*]+F7#U/'3HTIT\+'ZG2E[31WA^[4U>,:D+1<[6BU*\G&#]&?#$%B85
M_P#6F47&2Y*<L54]K'2/NN\N>2WLHW;EHK-I+B_$'CW]J?0?VH?"7Q4U7X(?
MM=K\/=<BM;[5_@B/$'PL^('PYT;PEX>N?#%OXV\2:!8_#+XLZ+X?U7Q`MOXA
M\)76E6VM_#K7?$'B?4+>\?29ETG3K&TM.B_9W_:4TR__`&9_AY\,_@YX*6'Q
M>-3^,/QA@U?XFV&N^"?A!\+_`(9:G\8O%Z?#WXZ:YXKM[./QWHGA[Q6FN:KI
M?P]T[P[X9GUF]U&?Q/H5GXK^'_A""V\7:C^F.I6EQ;O>6IN6M)Y+N&:[NM-M
MY8;EX[2Z;5HKT7-BNI:1)JT-V+6SM]8GU.RU"%+&.W@N;>W7R*_%#XN_`3X)
M>%_A'HWPWV^+M2^$VC:I\3;?]JOXH>%IKZQL_#G@KX/^'-$^-GB;P7X]7PQ=
MVND:KXAU?P'IV@?"C]G;P7X_N/$/P^T3Q#X^N?$N@1:1>7-IM^4X1XLRWB#%
M+*\3D\\#CL+C%.IA:,9PA3I^]3YI4I2:4IWC!*+A=Q<8IRG8]W-,JJ8+*I8Z
MK7I8N-!.:KI>TJ;<RESVYG>VMN9\S3OIK]`ZC_P3LT7XD:A??$2W_:N^$^HV
M_CV\NO&D&H7G['-UKUW?0^*9WUR*\NM<6VB76KFZ2^6>?5EBC7497:\$:"8*
M"O>IO"?_``43M)I;2Y_X*)_L_?!ZYM99+>X^$F@?";P_K6A?"V>%C'+\.=$U
MB7X>3RZMI'@B16\,Z;J4LTTE_9Z9#=/+(TI<E?LJ65I)?4JVFFT^EO/R_%^5
MOR1\1R;;6*KV;NK.E:UX_P#3IZ:=WUWMK^E/AI;H:S;1R":[DCNK?0KZ."`7
ML5K<W%Q:)?3_`&86\]O91V]I+?:;>7#/+873:E]JNC<PVNOR7/\`/[\![_X<
M?"G]D3P(WQ=\1:%X<\$?!WQW\>OA;?:QKHM?[/\`"USX&^/WQ*MO[2\/K>P&
M5/&$NDZYX9T"SO='T.[%O906L>DR1VJ0`?FBW_!0S]N_X@'P[>:I^T3XA\/7
M?A>'^P]!D\"^#_!'A/31JU@)=5O-5UQ/#6E:A::Y<:AI?B33]-F\/ZSH+>&[
M4VVH6]AX<TV._P!1MIH/@5^T7XHO_&$'[.7QA_L#XL>%?VMOVG_`?B/5;O7)
M=.\&P>#M4^)GQ+T/3?B7XAC\%:+'\,[75M8\2ZE?>&84ELI]*\-:3XCM[R\L
M=$6QL->MKOQI\.4*6#K86E7G7]G.EB88>E4E&3A24I5(TDX:2<9<J=FVTU&,
M[I/^BL'X:<5\(QEFF88?"3R[DE2JRJ4H5(.*ORRE%Q?,E=N]M+N[6Y\D?$O_
M`(*9_MG_``S^+/Q[M_`?C_6OB%\";3X@>)]`D\%_M%>'4_:*^&VG:7'>:M;:
M!8ZS:_%=?&<DU_<6M[-!86^I-X>6-KR>!M'TGS9M/@F^#?QC^-W[>?QP^'_[
M,K_!G]C3X;W'Q4U)+GQAXA\*?L2_LS?"#7M#^'6A:4?&'Q&U;3?&.E^%)O&-
MIXIO/"_@K5M1@UO2O%/@>^OAX<U2PT&]OSK/AR./^GE?V3?@%KNJ>(?B?K_A
M#0-)U[7=!@>_US[1IVA:-)IFC6L*Z1K>N6GCB\F^'%EXKL=)-E<:MXVU+P_X
MA\):Q)8^)+BSGM=;32].U#XMT7]LW_@GM\,OCC\9=8\$VNO?$WQM:?"273+[
MXJ_V;K^OZS\0+Z?5B-(\$?";X;ZAHOA/0=/L+%M(\;3^(?B)'X?^#VCW<,6F
MP:CXCUKPAK<&JZS]5PSXL91FV6X_*<CX&GALPR[!QP];,*^"IQC6JRG&@I>W
M]G%N?/S3DW)N?,N=M-R/Q3BC@?#X/-?[6Q/$53"NIB'B(X7"PJ58.$N67)[*
M"<5"*:Y;+E<E*#=TU'](/V,=9E7]C/\`9\MO'OBS6I?^$>\+^-/#ND^+=9T[
M.MZMX/\``GQB\>Z3\/DN-$3PI:ZO9:[HOPT\.Z:ERSV%GH6LZ=X>UF.[UEM1
MA?Q5><A^PS\!/`?[0FF_';XX:G8^/O$/PG\?_'W7]"^%VB:AXV\4Q^#_`(Q^
M%?"T\&I:YXR\:_#OP'K.O^$/BKX6\=_$YY-"T?PWXQT+Q+H\O@;PKH,WB[P[
MHTM@D-I^-?B[Q[\<OB1X7U"PO/A)X?\`AU\%?#GPS\1_#[]G_P"`OBGQ+XTB
MU73OA#=>$_AC;^(=!U&;2H]*N/$'Q`^+/P8\<>$/'&@^-8_B6L'B/X1^&?'6
MD_#V\\+Z]J_B/Q=8==;_`/!27]O'5?`WA'PUX)\6_#G]F_P=X4@\66GA>Q\$
M>`/A5XT\5)HVH>(/&OB;PCX.DU74/"&I?#?P7X6\(?#:\TGPSH/B#PYH=OXB
MOQX4M+[4M<U/5M4U*_OOG<!P+E>78['<18VO1PV;9JXTYTH<M/V$$W63I1IS
M:YI*7)4<>;EE%1]I)-R?VV2\,<7\;8*CE?"SK8["SUQ4\3A)T:=.B[.G4YY0
M?,O:;1Z1^%1BHI?V!17>LSQ1S07.A7$$L:2PW#7ND7K3Q2*'CF:]DT74I+MI
M4(<W3ZC?O<%O-:]NF<SR%?R2V?\`P4J_;=^R6O\`9/[1NM7&E?9H/[,N%\`?
M#:)9]/\`*7[%,L>E?""'2XQ+;>4X3388K!`VVSC2W$:@KO\`[/7_`$,\7_X.
ME_=_Z>>:_INWM_\`$LW&O7#X._IKT_Z<^GX=M?R2\)00?8]03R8MAUAK@IY:
M;3/+<`23E<8,T@1`\F-[A5#,=HQZ'\/56X\.?'_4KA5GU'P[\)?VH]7\/W\P
M$M[H6J^#OA-_;'A'4]'NG#3Z9J'A75KFYU3PY>V4D%SH>HW$][IDMK<RR2L4
M5Z&`_P"1G_W"E_Z4C^L_$W_D@JG^-_\`IL^Q_P!K_P")/Q%U7]A3]D6'5/'W
MC74HOB3\4/V<+OXBQ7_BK7;R/Q]=ZE\,_'^O:C<^-4N+^1?%5Q?ZYX=\/ZS>
MS:Z+^2ZU;0]'U&=I+S3+*:#[7T/PUX<\)PSZIX6T#1/#6I7-G^W/IUQJ/A_2
MK'1KZ?3]$_X*=?L0Z7HMC-=Z=!;7$MGI&F:]KNG:7;/(T%A8:UJUI:)%;ZC>
M1S%%:<+_`,.G_P!A^)_])D?Q5'_>\1_UYPW_`*EH_GH^%7B'7_$OBPW?B/7-
M8\07>A:/\(9M$NM;U.]U6XT:;2_AGHGA;3)M*FOYYY-/ET[PQX:\.^'+"2T:
M%[/0=`T72+<QZ?I5C;P?2GQNEDB\,^(/+D>/?\)M4NGV.R;[J/XPZ'8I<MM(
MW7"64\]FDQS(MK-+;AA#(Z$HKEXL_P"1OA_6D?WGX&_\DW_W"A^43QPZ3I3$
MLVF:>S,268V5L223DDDQY))Y)/)-%%%<2Z?+_P!QGZI+=^K_`#/_V0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O
M<F5D8W)E871U<F4N9VEF````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#(U(#$P
M-3$U-#,T,34P(#`R-3(U-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6%!`$(`]P`````````S``!F``"9``#,``#_
M`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF
M`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__
M,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F
M,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_
M,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F
M9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_
M9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!F
MF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_
MF9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]F
MF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_
MS&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QF
MS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#_
M_S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF
M_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____
M^+\D````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(?D$`0``V``L`````$$`
M0@``"/X`L0D<2+"@P8,($RI<R+"APX<*K4!AP6(%Q(L8$S[9N#&CQX^8+LWA
M".6CR8>=+HF<@^W)R9<+=Z6<,X>.2Y@X#>X*-A,*G9Q`!^[:I7(.E"<E@P*E
M0X?F'#U*L3%52G-/4"B7?@:E"16G%3J[,&D%ZG3A"BM6K@BZ,C!M($%[OEX:
M2C1JV80KH.0!E.P9E!4K].@I]>R9ITN8AE[R%!7;78-Y5W`L%6BC"LEYGJFD
MB]BJ4A8T$5JAN$*%BB>DGI0&_`00LDO!%#-N#,4H0HI/2)!0844U8,!ZD'4*
M%GO7[*B@;V*#PAS*%1:J293F^'O%'E*=#A,=&S3Y1LD5J?[_EO[=R1.G13<?
M'[B"!9VLGC,BY?B==>_Z'-&KO#1S,<&\M6UVB4E[.$7?1FCY1A]-`G8RG(.`
M$`3%'DW-X4ELW&'DU!R2<816;QWJ1U0PPB23#"DU=;6<)WHP.!<F!(XTDF0=
M*IC?'/NI)`PII7C224UT,-<4(.?-D=TE2;659$-'B:>"$RPP=UZ1.2JF4AX<
MF4>3350.*-"$S.T2GT-3JG::8"T6Z:)**8FD!T<``%#C@0*M`)9(*M$QYD+0
MD63%)Q32I":.^\V11VKWQ2GG91TF:2=1<R1FW$.CT6=%()\T>:.+I/#(VA.*
MQDDC"_\5NMDN&2XDT7F"[:'I@?ZH=2K8IZ$"<%NA.`ZE(D3?I77%%1+=!]AE
MI@4@'6"U`A``00%(5F51'OGF!5R!Q+6";BH<6YUOORFZK$#A$9IC:!E5Q$(7
M:P%;VF[7,CH=M\@J2Q!TN>XW5*H/`69%%X&,-NQJTPF6Y:<KV/K?$_;.-=1Z
M%TG6A;K5_?:$'IUZ8N2/JL%9T`ISP::P2@Q#U!Y@,@02R!5=Z&'%ACD6M9&!
MU06`L,)T+?Q19"0#VUN3&^(HZ,N+_<8HPHIQYJ5'4DH,Z]*"<OF$$Q'7RQFJ
M)S6W-'4+"CK2:9*Q=YZ`'>/;,'T1S_FR@?1MS&#1,+XT<MF?;MJS;01]36@G
M8N'T]O6VFZIY21Z/S7M431,"55'9?1>%'DN-X07W@2/]^#/CC3L>L=SY%5EY
M1(<K?=Y,&6^XN4)0))BU@0QN.7I$]ZGFA-9.Y>$)1ZLGA%85N)^M.TWF65$[
M9+_I@7L5F#NUY.]U`G9X[ID_[02+>R+_UT;3,^^4$T]2COR\'=7YA/7G$:_]
M]@)M1.K&<E=!?D'G'8\-C2NDOCY:>]3_7LC8M*[Z]E8<%M*=GL`?<R3BOLJA
M14@)R]/Z$"(EN;5,;-M[U>D$!,'?]>EJZ`D+_J1W-<CEJ8*CTY39($>H!1XD
M/!WTB0E/B$+Z,&>%"M$74EX(PQK:\",!`0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-O;FEC
M+F=I9@``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$V-B`Q,#4Q-30S
M-#$U,"`P,C0P-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA'P`@`/<`````````,P``9@``F0``S```_P`S```S
M,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9
MS`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`
M,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-F
MS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_
M,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68S
MS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,
M,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`
MS)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9
M,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_
MS)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF
M,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,
MS,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S
M,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9
MS/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"P`````'P`@```(_@`!"!Q(L*#!
M@P0O`!!0L$`!`1`C"G#H$*)`9!B1";Q01F#$A1)#1GQH$0!&@64ZDA0IL0#!
ME24WJAPX4:1+`#MV"(194B$`ESI_VL1Y[5I0GAM_`M7)\^:.HD:%2DSJ]-K.
MED2A)MJYDFI6JS"!%@50=&O%GC\!)(+J<:%8JP*OF>T*0.'-M333DAT;=^Y'
M`"H9XAT(%RI<LG[1/E1[V+!APHD9UMW)V*ICQXBO_KU@5_#ESW*53JWK\R;?
M@H[G&E3H06A<DQDU[BU+,)CMI*T+QLX8-[1`V\%."C2P5_=NV0./RS9`_&!P
MY;L/&LAM\#ETWAJ1M_99^[IRV`,Y7',$`-S[=^'$.78D;_[XQ>7-4_ZV?IT@
M;P#3/;26/[]]QML`4,<9>//1AQ%PP!4DWD4%#H0@@`5)MN!)NR48(7G!3;:1
M0A1"AZ!'##VG(8?9^7>;12(BI.**!04$`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V%V871A<G,O8G5N;GDN9VEF````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,38S(#$P-3$U-#,T,34P(#`R-#$P,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$@`"``]P``
M```````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F
M`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_
M`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F
M,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_
M,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F
M9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_
M9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F
M9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_
MF68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QF
MF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_
MS#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EF
MS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/__
M_P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F
M_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S_
M__\`__\S__]F__^9___,____^+\D````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(?D$`0``V``L`````"``(```"/X`L0D<2+"@P8,($Q8DP;"APH<"&:ZP
M$JAB("LD(")D2/&BE8\@,VHD2`*D29,KD&ALR/&DQ9<K1!Z4V+'BQY>L<NID
M57'%S)H[*^Z\1K0H4588%PK5>32GT:<Z`_DDJ2<0JVNL5JQ@9>WETJ`]%WI*
M=I6G5BL\I0(@L<*K5(8&`7PB._3H10`16<J,^ZF4M6O6G-J5.G(@B3U7L0KF
MF7:OQK9U<UI-&[,PMK:3=0I*G-9*3,<)V7I-/-AF98A(,`LV*ODE:(,DA#XU
M&CCHU(T42<\._-5L:-F[=_(4!$WR:VRQK09?+9SP3^50=1>-FO2@ZJ?09[>^
M71#`]:+99U%CO7C\.]'-XJ?W/)Z[*&_IZC-S'YB[J]#)TSEG9^6X8]JT%CG%
MRBI_,38=7O0I9V!ZX_TWW5Z0_9>9<*U=M%5.\P&@X88<=N@A`$B0L)9``0$`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]W;VUA
M;BYJ<&<`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<S-C<@,3`U,34T
M,S0Q-3`@,#(T,3$W`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B
M``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40
M``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$5
M4M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC
M9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2U
MMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$
M`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'
M!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6
M)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#
MQ,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1
M`#\`_$O_`(*S_P#!6[XW_P#!3_XTIKDMQXE^'?P-\)'4-!^$7P9T+6;I?L6D
MZI(QN]:\;_V3>PZ;XG^(_BEHX=/\075I/=Z':PQVNGZ!YVDWEY<C[2^"W[-O
M[$?[%OPR^#&K?%[X7>&?VV?CU\3;;0/B7XRL=6M?$%M\*/@QX"@74?%WB?X4
M^'/#,,^@1>(?B!IT?A+QCHGCS7]?6'3I?$"1V&B:=9SP2W(_FMFNKRQDM;JQ
M2:TFMY8KNVNE:>+R+F!UEAF66&6WE1HI51PT5Q!(I7='-$V'7^DC_@E/^Q1\
M8/\`@LIXU\8F[^.5]\%?#WP)T.?Q?/XATZP@\<ZIJ7Q!\3:M#96NA>(M!U;4
M]*MI='URVL-7N-2U%]2NFUO3(=8O_*767$9`/N_X3?\`!8;PM\*+6P\#?LT?
MLX?L^_L^_#ZPN?"FL:W8?#_X:Z2OBC3/"O\`PC-WK'C:V76+JT-Y=>(O%.NC
M3[VU4ZS=_P!E1O!`ZA+A0]S1/^"L7C']HSP-?6_QO^&OP3^,,?B'Q.VJ:AX4
M^(GPX\$>,K+1/!,#6=W9:9J^K>(]/BE@N+A=+CN=2UF6^M[C6=6%Y"_DZ-9W
M=Q'^FG[+'_!"+]EG]G'X>MIGQMA7XY?&G4/^$WT;Q=J\6IZEHWPSC\,ZSJ%S
M96'AOP_X<GAU+4Q#I.AR07MO>RW<.IZ9J<8;29'\J&O3/VR?^"7GP=^)'P&\
M01?L[^!_!_PX_:"\)S6WC/P9K&E>&K;4-*\7:GX?T<^'4T?Q5H#2I;ZA8WOA
M\):6XXNTU"TAO'@::_7>`?C#_P`%&/\`@CU\`?VB_P!A?6?^"AG[#OPV\$?!
M[XH>`;'6?&?Q5_9U^$/B:?QK\.?%7A/PNPN/&,^@Z'-82GP=\1?!F@._B&\T
MWP_--9ZE'8KIUEB:2$/_`!Z6$EI<PP3P*C)-"DPDC<2J59"ZL-A8,K)\R[<[
MU'&><?W_`/\`P1J_:`\8V7QWM/@+\9[/PYIWA3Q=::MHOA^]\-ZI;ZK\/?$.
MJZ+:W>GW?@O5/"VI-]H\/WLVF//L62)[62"VNM'OB]T50?Q@_MX_LR>+?V1?
MVK_B9X!U_P`,_P#",^!?'FMZY\5?@=*K/<V>J_!?QAXP\3W?@>YL;Q5%K<3V
M@M)-"U5+1Y8],NA'8W!CF`B`!\B&ZL@2#/!D$@Y1L\>O%%9;P$NY\M^68\1L
M1R3T.T\>G)HH`P`VP_Z0P>!\*`SJZJ#W9)$FC9<=5>*5&'#1R*2A_J9_X()?
M\%"O"W_!.GX-_$KQ;!X!N_B7<?&#X^>'O!WQ5@C\)>-[?5O!GA70/#+1^`(]
M*^*-G::A\/KK7=2M;_Q1K,/@%C8:[K<EG+%9P>;&TL7\LS82!D#\(C$R*6\R
M,`??7RPT@91\RE%9@0"H)Q7]R7_!K-H7[/OC_P#8^_;3\+_$_P"'^A_$CQ7\
M+/C#I'QKN/"EYI2:QXAN/#L_PSDT?P_J&AZ)>KY9O;&_\+:_9Z7JEJLEVFJ0
MJULCW5QY3@'ZI_\`!1[]I7XG1?LY?!7XG_LBZGXC\2^#_C1/=^(?$'B?P#;6
M6C>.?^$`T>VN;E].@\2>+VMK/X42Q^)K34-(\;>(+UX;K1-1T*SMHVBO[R&"
M3Q+_`((T?'_]J+]IOQ!^T4GB.?QU8?#'PEX-\+W?P?\`%?Q;\6W7CJ72?B3X
MADUF'2-(M=?N/#.BZSXB&@:99I<>-K::]U"'1;N:T1$=I[99/U9^!7[0O[*O
MQ:>+X3_LW:9<:Y\,?A?\-M)OK'Q''X(UC2_"7AY_$M_>V[_#R]M?&VG6>I77
MC"Z8Q:]XHM7B\BXN;R/5=6$%ZUJD_P!7^'H[?26M['3[?3DL&DB-GIVDV%M:
MV<QWK!!)%I6GVL%NT[V[O+%-"TS;5:5-ZJ6`!_`'X5\?_'/X9?%WXZ:M\5--
MUKP'XRT?XZ^,=%UETAET%[#QWI.KZO;^,_'/P_GACCO)/!HUH7EQI<BQ?8[B
M+7;>U65BB*?IG_@L!\/;#]KC_@E=\._VLK9#K/Q2_9!^+/AG1M7U:RM;:=[+
MX&_'"UC\-:EHVH7>T7$^E>'?BKHECJ.DWC_N;2QUG4;B%QEF/!_\%FOV\?!?
M[1'_``4I/[/_`,(=)29?V<?"OB/X.>(M:C_LY=,\;_$^+Q58>,_&&@V9TTE9
M]/M8?M&F:=J5TTEY;^($>&\<-'*E?6G[(WP^UCX__L]?M6?LP^%+:]\5^!_V
MC_V//BM9Z%))<*L^B>(]'T:7Q=\/M3U"R?>1KT/BGP\NAW&G(BZA9B[NI%B6
M8$4`?Q)8N%^5A&&7A@9""&'!!&1@@Y!&.#156+7M/M8H[75;9;75+:-(-2M9
MY%BGMM0A41WD$T<I62.6&X62.1)%5T=65P&!%%`'/NUQ(I,2C"@E#&`6+#E=
MV,\$XY(QSVK^A?\`X-M_VB_%O[/W_!17P_8V^L#1/!OQX\"Z_P#LZZE?ZP9)
M?"5I\4_%^C?\)/\``H:T8[FRBG-[XU\-O91JM[;WKZ=K]^UF^YV:OY_828(6
M##S)3*]I#;,DJR7-\@"C3T2%6N'NWD*P_9[='NMSJL<9D9%/[4>/?@!KWPD^
M$'[/?P.M6B^%GQ)\-^%D^//BWXAZ+]H7Q9K'[0^OW^E^*?"&FRW.GR1-9W?A
MKP9>>#M`T3P]:W$4/AN^L]4U2!UU!YD`!_6E^QU\2/\`@H]_PTS'\.OC'XO\
M/^,O#&IZKXHD^)WA_P`7?L]>,_AU%X$F\.76JVLOB;P=X]3PIX:\.?9/$7VN
MYM?"FCW-SKFF:[)<6T=WJWD6\LR^V_\`!2C_`(*>>$_V-M)MO@M\*KVP^)7[
M:OQFM;C2?@Y\&M`NX;V\\%7FLK)IT?Q8^+&QY5\(>&/!QD&I6MG<QVW]K"RF
MM;-I)"0/PE\/?\%&?^"S_P"T3^SM\7?`3?&OX5Z'JG[./B'X5?#KQ9\7/#LU
MGX)^/'C_`,,_%V2QT_P#XTT)+6+4X;_5]2MX[C4?$&N:!'X7N[(0((;F?4)4
MD/YV_L7^!/A_H/QA\0Z=\5OB+XGT'Q'XEO[G4]8^(VD^)AX>\9^(O%9O"]S)
MK/BDZ-K7B:^FFO+6]F1&U>%9#/N6(!@:`/SK^$6B^(]%_:!\?R:CJC:SXO\`
M"_B[QO8^)O&&JW*C6-0^(?A_7XM6F\27Z73?:7@UW4?[4MQ(XQ>1ZS!:QL[1
M(M?T=_\`!-G]HSPW\'?VI=`\96>H:EHOP\U?XI6;W^FWMRM]IOA^W\?3V$T\
M($+A;'0]7U&/Q1J-I]J,=K;7$$.G(P>3RZ_+S_@HA^SSX'_8X_:Z@\3?!&RN
M]9_9]_:7\*>%O&GPD\7V/B.X\66]YXWL[?3--^-WA'Q)XNF$@MO$^@^.;/5_
M$7B6WO'CO&OY]*N!!%9,"WW?_P`$[OV,/C#^TUXTU*Q\!76B>#OAKX4MC8?'
M#XX>(GN-5^'FA^'%\C6_#>@>"K;3)$7QM\9?!NJ:;/<IX6M=0C\/:+#;6]_J
ME[:0:C(]`'SU^T]_P;;?M?>)/VE?VAO$7@2SB7P/KWQR^+6M>#5MM-O#;KX4
MU3Q]X@OO#H@\J`QF$:1/9B+RR4V;=A*XHK^N_3OCU^SCX0T^P\):E_P6%^+"
M:CX7LK7P[?I=_$_]D2UNDO=$@CTVZ6YM;WX1WUY;7"SVT@FM[N]O+F&0-'/=
M7$JO,Y0!_([_`,&OOP]\`_$']J;]K>X\>^!_!_C>X\#_``$UG4_!4_B_PSHO
MB6;P?J5OX=CNX-0\+RZS97K^'[Z"[C2ZAN]):TGCN$29)%D4,/>/CM:VUQ^V
M%\"([BW@G2]^+?QPN;Q)HHY4N[C3?"S'3KBY5U83S6!MX#92RAY+4P0F!H_*
M3:44`>7_`+.K,OQ-_P""FJ*S*EC9_LPVUBJDA;.WL/$4=S8V]JH(%O#97$44
M]I%"$CMIHTEA5'16'P#\=6:P^+7Q!>P8V3R>/_&_F/:$VSO_`&;JA73M[0["
MWV!69;+<3]E#,(/+!.2B@#^AKX:>%?"_B?\`9B_94\`>)?#>@^(?`FH?M/\`
M[+>FW_@K7-'T_5O"5[IVLZQXGN-8L+OPW?V]QHUS9:K<0PSZE:S63P7TT4<M
MU'*Z*P_:'_@M8[_"K]ACXX:)\+W;X;Z+I7P0\:7VEZ1X"8^#]+TV]1[:-+RP
MT_P\=.M+.Z2.66-+BWACF5))$#A78$HH`Z']DS]E3]E[5_V5OV9]6U;]F[X"
M:IJNJ?L_?!K4=2U/4?@]\/+W4-1U"]^'/ANYO+Z^O+GP[+<W=Y=W,LEQ=7-Q
M))///(\LKO([,2BB@#__V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O879A=&%R<R]F<F5D9FQI;G-T;VYE+F=I9@``````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(S-#`@,3`U,34T,S0Q-3`@,#(U-C`W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y82``(`#W````````
M`#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`
M9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``
M_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS
M,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``S
MS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF
M`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!F
MF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF
M_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"9
M9C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9
MS,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,
M,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,
MF<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_
M`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_
M9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#_
M_S/__V;__YG__\S____XOR0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````A
M^00!``#8`"P`````(``@```(_@"Q"1PXD`02```((ERXD*##A]@.`D""C:'%
MB1`A7MQX,>-`CB`M>@Q)LJ'&D"M(D0*@@M0J4BH`Y$%(XB1'4L]RIER5<V7,
MD1,W\LSYC-2*E$<!U?18,2C#H3H#L5HA=053@081ZHFY@NBS52163!6[]&K%
M%:6,XB2Z:H65J6_+7B6QUNLS/49932VU@H1?LRV?V"V*]RBI)Z56O93[D`2@
M)W79)H;*EK%#`#OM&CTZ^*ME@BTY]S2L=C"ISUAQJNP)V651R(H5PV1*@O)A
ME:*-DE"AXBA%C[6]IM1=UV@>4FE5T(;:]G9*K[=[*L\8/&=;GF!;0H><4^G#
MA77;OA)=@7"G;,'/2C$&``'"@>=?N_:TZ!<^V,L0+%APC[;Y^(NN>>80$B4<
M`,$%%T`PG'Q%J<`&&PN)IIY#)'32R0H'7F#!`0<`4%Q?8>'670`)%63A)1@B
MF.![D2EF5UL)0%!BA9WP-L<*!JK(7V1V`6*@C%C5J-(3EUR8(8+\E3(8("O$
M&(")*O!TF(4!Y(BD@G65PN0`$#P)Y5!3JG!CAAP^P"*.`7#9(4$51DF46BI<
M4J4%*\KXHX$'7+)40```.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W!A:6YT:6YG
M8FER9"YG:68````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(S,R`Q,#4Q-30S-#$U
M,"`P,C4T,C``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA)0`E`/<`````````,P``9@``F0``S```_P`S```S,P`S
M9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9
M_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`
M9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F
M_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_
M9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S
M_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,
M9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`
M_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF9
M9IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G_
M_\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF
M9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,
M_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S
M9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9
M___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"'Y!`$``-@`+``````E`"4```C^`+$)
M'$BPH$``!A,J7'@0@,.'$!E*;`@@T(H5$#,ZE*@J(42,&D,R[&CP8TB1"_&0
M+'BRI40G*E<2!$`-@+.;.&W6G(C-"4P\+&DZL^G,F-&ASG9.Q/,S*+6<P*(:
MNZET(L*20F\"B`J,:-*-"S,ZA>H0Y]>K"L7.S#JTJ]>S#&D".'8,+#:'3[6^
MI6K7XU"ZU&HBQ&NVL-;`:$O^/495,-O".N?6C2O9;-W'..OR55N2KF7"AC4W
M!F#&#)[$`Q\ROGDY;V'121&7/HTZ-5VZH%^7Q8D8C^_3'F^W-NSLLMG>OVM3
MA+CZ\]Z:M6KY5AX\-(#3QP%$G\[S;O/,UR]Y9-S.O?M<W7@NJ+_PF_9<ZIVM
MMW=_&W[P[\4SUN_+L[)SU;CQUY]DPA5X67=AM21@0JPTR(I!#CH4H8,.3D3A
MA11*V"``&#;(4(<9LJ*AB"!ZR&")&X[((8HGHOC0A"RVB&%&*:[8H40EVLCA
MCC::B&"(%_9884$!`0`[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V%V871A<G,O8F5R="YJ<&<`````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`W-S`R(#$P-3$U-#,T,34P(#`R,S<R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````#_V/_@`!!*1DE&``$!```!
M``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!`0``````
M`````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q
M008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+C
MY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!`````````0(#!`4&
M!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R
M@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JB
MHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR
M\_3U]O?X^?K_V@`,`P$``A$#$0`_`/XFOV;?AK?_`!<^*W@?P%8Q&YN/$&NV
MD!4;YFBLY)HXI6:.T8W,31>0K^5(D;-#&CQK,QA5_P#0J^%7PS\,?#/P!X(\
M&Z996-E_PBGAJQLX)(XV\L/#`IN[Q!<PV^X_;9'NY6,$,L,TX:183<$2?R/?
M\$+?AEI7B[]H^\\3:U:+=P>#M(DU:V^UP,]C;SS.+3[83<F6TB=)8HHK:=(H
MI?MDD:1W7VJ"!5_I=_:I_;L^$W[)&G:3?_$"TU.6\\12W+V.E:9%#-?SI!:P
M/'<76V0);Y4K%)YKN8DC3EC#/%;_`,3_`$F,;F/$/%N3<$Y-AL3CZ^'HSQ\\
M!A/>J5L56A)P2IN=Y1HX>$ZDV[QA*I)P:O8_H#P_PCPV65<QJ5*5&-9RBZM:
M2IQA3A[C=2K-J,8S:Y(Q;M+E2O)R3?VGNLS*UQY`>:,OF=+4W$F83=0L%E@C
MFW.JQW"&)7::/S!#)&DLZ1/4DO(H#?"1K>W$48=<7KA)5^T3*QVB`+;RN\L:
M3R(AD\ZY1)9%1+>=OP.\7_\`!<[X0VQF_P"$:\%ZOJ\UI-(EM+?*EGY=UYSN
ML[I)(@CBD8"X6VE'FEX(GEB#PQ+#\S>,O^"U'Q:\;RR:;\+_`(41VMY=J-CZ
MF]SJSVKNRQ*4CMH+5%FE%RA6XE3Y)8IR=NXQVOXA@O!GQ(QR37#E3+Z3LYUL
MSQN%PE.BKJ5YQG7]JH)<TI/V3DW&UE))R^W>:9+2FHU,WPU:I?DC3PRJXJM*
M4907+"&'IU;S;:4=/9VYM6TC]<O^"B'P9\&_&']G/XA3Q1Z=I^O6FEOJMG>W
M<%O;M-=:5<R/:G9';_:;NZEB'E6;0*SJ\<*3NSQ2O!_$3XIA:TC:&8>7-'/>
M1G:[12*Q,2O.[.LP1H45HG*L3'&D<L"N$^S+^W2^&?\`@J#^W5X9?6]+\,^+
M'^&UU>SVCS(4T+0MVEVXN;FVNFN7B\T(9&F2.6W2::ZFMX8E?=9(/QR^+WAG
M5/!GB+7O"&LI<PZIX?U>]TO5`8VADBOK&4Q7(<'SI(YD8SLGEF7?+&R!)"XN
M(_ZX\%>%<TX)RF>29OFN!QN)KXM9A2P>7U)UHX*E/V>'K)U9)7YZL(QDH4U"
M/LY>S7-SRE^><9YAA<U4<3@H8ATL-#ZI*OBX*G*;3=2%)0YG44:?++D=:7-=
MR6RM'RR$2^5%A2@\M,)\D6P;1A?+,<ACVCC89'*8VEV(W$I8Q(\:/E3N16R&
MCP=R@Y&(YA@YXQ-*/263[Q*_9I3P_,[PIWN[_NZCUOKK]<C?7K9>BV/A(QJV
M5I5TK*UI12M;2W[AZ=M7ZL_KH_X)3_L)?$#]CVU\5^*OB;XB\&:I?>,M%TE[
M+2?#OV'4KW1[F6(3W%C>7R&:[%Y9I.(YY+E;!&/FVT#2LD<UG]Q_'K]FCX9_
MM#:=86'Q!T:'51IDS36,DL4;2VY97\Q$G+).D4C>6QC638'C0J$_UD?DGPG_
M`&G/A5XG?X?:?HOC/0M2\5>+]$;5+C0;*_%Q=B,10RO+/''<&.VGMO*N-T<]
MO:RO#.L9B5?,N*^U;;4$EC2550L=\<Z2E5$)!,$S'<60F*1L1E7;<P#1LQ4D
M?YC<<\6<89IQ=/B7.O;Y-GS?)1JX3#U\LE1A0E4PL98;WG4<+TZL75C*7M)^
MV;;NTOZ=RG(L)D6`I87+JL,=@I04?WGL\1"::]HX58SYH24^93BIZ.G*DK15
MDO,?@;_P30_8G^"_PM\4?&KQU\(M)\>WVA:)K7BN^M9M/_M,:;IWAV&XU62U
M\/Z4GV</?S0VZ.L,M[>!YEBA26#?-;0_.WAWP_\`LF?M1_"CQ+\=_P!G[X)3
M?`S6_#?BRY\$ZS8ZMI2:9#JD`M9KB2_L+9($\FX=;2*"[G@AAD5[N)]M[>6P
MBK[UT;XA^/\`P?;:E#X;O=/O]!NX)DN?#VNVDE]ISHZ3QWDMJ()X2LUX#MD!
M$SSK&!(RB;YOFOXA?$/5M2N9/!\6D^$_"WAFT>YU=-(\-06VEL);F6.WN)+J
M*RF>&-[6W=%FOK:UCNI)T`N-3MK:ZDTVW_8L?XO\.9CX:T<EJ/'XKB-Y4L+7
M==U:M668QM?,)8VM.-Z,JRIU_80G*+C>@Z,J7-)>%PYP3GRXX><X?%86EA88
MOZVW1E&DH8-M.I@OJ,*:@VXS=*%-Q]BN5SE*"Y4^TMM7^//@G6_V6[;X0^*/
M#?A+X">%?"*VWQ>\,SWUC;ZUJGB:[6X@D,L48D:];4I3&+&2UE/E74CRI<RW
M`L[I/XR/V_\`4VU']IGXS7DVGG2'/CS6BUK$'"Q,[RW0FF,43Q0NPD+[)H)9
M5+K$,NDID_K+M_&`BO+/3YKHM#:7D2FUN;BY$3W#,_R3:>THDN89%=F$KHMF
M[W%N;87$KH]I_)I^WTT1_:4^+,L,L\D4OBV\.^<QP%WFD+M,PM;:.*.YD#D1
MLOD!IAN@@A$SI#]_X'\?X[C+B"MAL9E^'P4<LR'"QC]7=5>WJ3Q>'H3JVDN6
M$*D8+W(\THMOD<W%R?C>)'!D>%<I595)U99CF->LZM:G%3Y.6I7IPE-R;J2I
MJIO)IMRO4=Y7/C)-H1`ZP;PJAM\@W[@`&WY\X[LYW9FE.<YD?[Q*:MQ%M7&Y
MAM&&58RI&.JD$@@]002,=#17]-2H4N9\U>2E=\R]E5T=]5\3V>F[]6?BBK:*
MRIVLK7=-NUNONK4^Y_\`@F5\/_BKXN_:?\#ZYX.@UA;;PC]KUJ_OEDN8(4L8
MK.6Y%N)&VK/#=F-8C;*S"83G;&R/.Z_U#:+^U7X2\/7ZZ!XSO8O"NK:?)'8R
MV>MSZ=81C=;/<331*\D1:680B))D^U+"Z26\SO+)(X^1/V7O`&L?LT?!OP#%
MX0MM'M_'&KRZ1K.OW/GPIJ<C7\L41T^YCE#R36[07;1R07=P(+97AN)6OU^S
M2)]V_'CPU\/FU5O!_P"T'\,]/U"QU33H]5@U73H(8[W3EU='EQ%J&V)H6L);
MH>?$XD:*%(Y9W6\G@,G\H>.N%P/%N:4N(GEF,J9+EU2KD%+$Y9"BL5:C4>)>
M-4:T84L32E*O-JDW'EC::J-2:G^^>&52GD^`GD>-5'%X[,(PS58.>)Y*]%U(
M0H^QHIIQ=2,*48U:=I2FY6BH/DD]:/\`:@^%,]G)(WB[P\8;@X$@U2TMY(YB
M$\T&-XPK26KRP2.S%_-A43M$D<RHOP%X\_:1\,ZGXYU630M7T;4#!M4&*02^
M8ZVUM<K<32SPXN(IC+;AK52'389))(I$VTWQ%_P3P_9Z\8^;<_"[XSV>C,LQ
MDET+Q#?-(H`:15,DOVJWGLQ;^3=%9[JV6/$D3".WM7FN+;YI\8_\$X/'7@NT
MUO6--^*_@.^L].M?MA,=]>)=BR>(70,J0!Y#Y<2A7D,4ZRR_:%2)+FW\H?E/
M#W#?AG"I5G6XIQL*M2$:,<+F665,&XSJ3IM0FZ;KQJ.]E:G*,;N_-*/-%?M>
M6YGA\EQM#$4<EJXUUW[.I@'4Q<,72;2A?DJY=AZ7-4;2A.E6EK*/,DVD_2YO
MB[XE\1ZW::1HUQ-+<736UE'!:^4+%XY9XXY!'%)OMQ+L=9@[@1,RB!42ZGG^
MT?B!^V;#)8_'[XE01ZH=4B/B2X66\!<!F54E%N\C1J[M`LSHJ&1A+/'*3'#(
MCW!_=+X%?!KQ)X,^%?Q2U_X:01>,?B5HG@_5=8D\2Z[.MOIGA.[LK25=0&F0
M7-JM[#)%;1.R-*1<K/+;"V07'DSI_/#9>'?$?Q0\0ZWK.N:HQNI+R]?4KZ\<
MW%S=W=Q=W$TY3<D+$&>7<90C(2)`S(3"B_T?X*</T?[8SG'Y1AX4\KPL*.5T
M*\Z$J5;,:\:M+%5L6X2A[6&$HR@J-"3G&52K.NZD&E`_,_I#<8X3,<+D61++
M8Y9B\)]8QF*H1J4IRPSQ,:=*&&J>Q;@ZU.%*\XS?M()VBHI-S\8&]@"0@)&2
M':`L,\X8AB"P[D$Y.3DT5]?Q_!?P+;QQVY@UF8P(L)F76@%E,2A/,4+9A0K[
M=P"@#!X`%%?TH\FS*_NRK*/V4H-)1Z))5K6MM;3L?RDJM*RO!MVU?,M7U?\`
M#/W'^)6HZA;>.;]K:^O+<V?BKPO#:&"ZGB-K";>Q<Q6YC=3!&7^8I%M4M\V,
M\U^VO[22)J7P@^#FKZBJW^JWGA6P%YJ=ZHNM0N@-!MIP+F]G$ES.!.JS#S96
MQ*!)]\`T45_,<_\`DW-+_KUEO_IJ!^U8K_DXU3U?_JNPQ^#/Q;N;C0_$\4>B
M7$VCQO8:<KII4LFGHZPZAI<,*LMHT(98H;NZBC!!"1W-PB@+-(&X)=9U@:@Y
M&JZD#:PS?92+ZZ!MO.>_DF\C$O[GS7=WE\O;YCLS-DL22BOR3-/]X?\`AG^5
M0_J/(?\`D6X__L#J?^JZ9^N?PGTO3(/^";'[26HP:=8PZ@_P;O;U[Z*TMX[Q
MKR:+,UVURD:SM<REF,DY<RR%F+.<FOXU/A)//)K;B2:5P=3F!#R.P(\FQFP0
MS'(\V667_KI)(_WG8DHK^I?!C_D4O_L+Q7_I5<_DCQJ_Y+;/O^PO_P!OI'U9
M1117[I+=^K_,_'C_V0``````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:6-E<VMA=&5K:60N
M9VEF`````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#<T(#$P-3$U-#,T,34P(#`R
M-3(S,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$H`#P`]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9
M`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P`
M`,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9
M,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`
M,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9
M,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`
M9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR9
M9LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`
MF3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9
MF9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```
MS``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9
MS&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`
MS/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9
M_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`
M_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+``````H`#P```C^`!$)'$BPH,&#"`FR2L2P
MH<.'$"-*9,AJX<2+&"-6S,B1X\:.("5^#$FRX<B2)#<B\G)%ALLK7;P@0BD2
MT945`'+JU+E"QI66,KS09&5EI]&C.0-8F9GRZ(JG4)$"8"$T)"NC5G`"6&&%
M5:!`7I_J/-#%ZDZ7.5>PNL:*Z]J*6=->`=DV)XNB6]>RM0+VFE^X6N=Z%,1B
MA1<6.0/Y91MHA>+%;.NNN,+T(BM$@JX(PJDV<N/'C/O6W2IXXDC.:[\VMO(7
MK&._@<Y6AC@2,8"WC@-U#;V;K=:<I6E;3-0E)^MK6<'JK:C7]\X5LQV.1(3:
MMUO(D$?K%"1R>"(O.'?^:W5;,?OOG%VB4_2>Z$H``&!C;]7--SM2Z*T>GF1X
MTVWXBGTMAA=/:04BB"!6R)`>>XED]A1?#]:WF';S&9?59%E=X1UF3S7V8(?9
M#6@<9Q<J%E9!YVW587E_B9A68G@]UIA4/.G&E7(S&L555`42Y>)1-J9(HXHJ
MDJC55_<Y)N1.(BH'H%,7[A3D5E(I^1R/.B;G6%S/9>GA34/">*%8/%F1G&K*
MP?:@?#22Y^*.636''6-0\96C43*6.6.<<V(W&E=7.*7<F'?RV:=7.4ZVY!5\
MG7E4<H=")>EY$,ZGVI*09N=A5P".YR%7/R*5U7%_<?:5F6::&IZ'!$I5U''^
M1$'5'&`[\L157LREJ*A:%W9EIIRH"@D=1`IYE=:-)OY:JEBY_<8@1(+L!%=K
M?,5ZJY1%/?L0=3T&>,VGH>JD[4-=K-"%;G"]M>EOY^$T[K:)4`=GJBR4E9!`
MK+0R2Y_Y04LB3-QEU):^K11LL+[7S`*1%0<$3)=Z#;62L+\06Z:MQ`D?7#!1
M&A>\+W8'[Q>QOK.4;/(LK6A(\LD=GRSRR!HW]%1P`L\D$,)]0C9+73(07#!&
M5\GZL\<?]XL(EVI][!?*(D$GT$3[VM2N0QXOUJ])#D^DKQ4!!/!4O2MD/?*^
M5[?U;B+[;J;@"@>P3?-#$BN<2$7[HGQUU2C+^[4D%>EEQ/1&!??)=+P^"5*Q
M1'][%S--TEU#T;V01XY(6X8+%!```#L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYE;RYJ<&<`````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-S<R-B`Q,#4Q-30S-#$U,"`P,C,U-38`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````_]C_
MX``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P``
M`04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0`
M``%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8
M&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)
MRM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!
M`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$
M!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I
M*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^)6767,\;'RHE
MDDPTK,%5V!SM5BP!9B-H`))SCKQ6-XWU:34+%;:W*B*79!(Y+F+=YBE@SQ98
M%1\[`9PH)<%`PKS>76+QQL#@M"S21ASPQ_BQSR0,D;>X^E:"7$L@LX%W7$,R
M/<72,ZQ[2R.9(UD<X0LFX<G."<>E>="GB:*IU:>'IU:=%RG[Z7,Y1C'GY8R:
M;Y5R/JKRU:OK]`L8\9*<*BM4Q=2%'$SVYZ]2<5[LG92<KQ44M6]%KH_V7_X)
M+?LQ?MS^-M7\7^*/V6/#=WI%EXEL#X2O_BG=77ASPS'IEJ)A;ZK#HGB+7(+^
M>*&[AN7T/6M0TO2-:NM(T_5+F\33+JYB2UE_=>3_`((<?MT:W-X!T+Q+XQ^%
MM]X:75KR>XUSPIHR:?/X,^T))K]O-)/H]G/?>+=)\&:A8_V5\/K?6KI;KP99
MZYKIT35H]/UB\\-O]??\$X+[7M-_94^"GA?X8>&-3M-+M?!^BZAJ.E6^B30?
M8]8\4:=!K=Q?7^J06P-RMV@TUHFD?$@U+3W3(N[<R?J3IWQ"^*L.FP:/J&L:
M=!*59AIT%U;2W+)`J3LCQ32H,;#$7#D?+(I'+IG_`#N\0OI&\3QXLS>CE=#+
M<#A,'BYX5+&865:525.2O4A5<7&4'>,5RNRE&:MLE_<.3^!4*?"F2O+L1EJQ
MV)PE/%XRE7QM:AB:,:JNU5HT9ITX\D>;]Y!3:U;22O\`S'ZI^P=^V=^PC\;-
M/^-L'CS3/$W@+X=6VH0W_P`3+C1;WXGV[?#WQ%)+X?\`']OK'POUJ&P.O72^
M']:U>X_X1ZP%SKMY&F[0(I=96P5ORP_X+3?MV^&_VUK+]D]_#6KN^K_"OX<_
M$30O&NF2F.6\M_$.K_$B]TBT\0:IJ-KG0YM0\?\`@WX=^&/&;Z=H\CG3M'U7
MPU&6:%)GD_LQ^*OC;QCX?\.:_P"*?&-E,^@6-O?&=5TO35TC3[34+"YC-SKN
MI2M)9:98S6CS7#7-\T4+6L<LH?8K./\`.=_;#T[0M*_:.^,>B>$+2_MO#VE^
M-=6T+1(+PQ7$LUM8ZE/!=S2&$%8BL]JZV.T8?34=HR8T8C]<^C;QG7\1^)LQ
MK<0T\-_:&59?[7"XS#4%AL-["2E&-%<T(J=5SE4<DI-\K5DE=O\`-O'O@>AP
M-P=D]7*:^"F\TQJPV/HX/%3Q/-B>6FYSFI2=17BZ:VY;15M]/E!&38F60G:N
M3E>3@9/7N:*Z]-%LPJ@M("%`(!.`0.<>U%?UP\5--_O'H_\`GY#HX_\`R+_`
M_F2.3NT?W;V7V-/L>7K]S[Z<;"^]@[E4VY8EP0,*I)4C&26`V@<$EAT/-?0'
MPA^$GB?XAQ:G?Z5I^K2:+X8U?P2OB;4K4B:+2[3Q[XFL?".DF6W"DQW-S=Z@
M9-+2<I'<W%M(P#I!/M\#MBJ7^R1VAMYI'CDEVL/+MWS'<*-J2'<T3R1`;&PS
M@$#-?I%^Q+\2?AOI7@[X]?"3Q[H_@2+4_B)X$O?%'@/QIXB\1_V/-X9^(_@K
MP_J@\&6-O'K-Y9:/J]S*^KW,^DV,UU)(GB6&Q:TCDO;>"`<V?5\=0RG$8C+/
M>QF"EAJL*<KJ-2G7QV#HU>1I>^X4G4G.*4G&*4FK'I<%X+*L;Q/E=#.L5*A@
MG6KU>7FY5'$8?`8N>%G+I'_;IX)IR>O*UTNOV[^)&E?M/>#_`!!/X7\&V/BK
M0/`W@&UDT?X,_P#",?M.^(O@[:Z;!I8TG3SJEK%X363P]JFO^(K47_Q`O9?%
M%Z^E:AH<NK^$].L]2OK6#2KC[8^#'P^_;3'[/O[57BGQM\1HO%'C_P"%'A5]
M2\#^*++6$L8/%;-I;W-U8SZ';>#/"KVTFFZ/8QZU)>:MX:L+B?3[W1M)-S?:
MCH.HV[<Q^Q+^T9XF^*^C:;_PE,FIVVL:)H&CV;ZEIJ[]5U1[73K:PM[?6+"T
MM+NTGU2UN=/O?+TRSSJD\I^S0PR7,B1MZ[\:_P#@I3\$OV2]0^*WP:^+?PV^
M.$_B_7]#GT[5IM*\'>'K+P!<S^+KK0-1TV#P9XMD9+_QG?I\--2T[Q%K47B)
M8!I6L6-]HD)74I(K8_YT9MG7$^/SC$<'X+@7`XO$Y7*EB:U94,'6<XU*=*K-
MJ5>?M(Q=6HXS5*,8N4O?;DKQ_P!.\=@\CP67X3C'+\[Q6&I\5U)854::;=/!
MQKRI47427N*.&BM9VLE[NK2/R/\`B+\0_P#@H-H-_''XC^*/QD^)/Q%M_#(C
M\-:SX0^.K:?X9TVWO]&BU/Q+I=M\,])M/#NBZIH^@WEQI^C_`!4/BCPUXAMO
M$FM7&CV6C7>G;WO8_P`1_P!JWP3=>%OC7\0XDM[>TM[;5?#E_JFGVNFFUTZP
MUOQ1X<M-8O=*"Z7->:++>Z1J%WJ6DV&HVMX\GB+3K.]UB%)(3.\?]87[1WQ_
MTWPE\%O#^OZ?.^M2:QX7\+ZOX=L_$VFII&OZ]ITVESPZ)=^)+.UMEBT--?AN
M=-OO&*7TMO'I.M:C<07C1W.AM''_`#:?&;XC^']9^!?Q5\=^.38^*?BC\=/B
M1I\.D7FFZMII7P;I?P[U#38XM4U/1H)&O-.N);#[?X4T2"ZC@.JZ/?7&M6YN
M(+1Y*_I7P6X@S+,8XZ-3@_"Y+]2ME5=QP]##RG6IJ%6=2G2H^[R6K<R:M+FT
M4;7<?P7QWX8X;P.3TL)_;D\57H82&=4IRG%S;K2G35.*NG)WI:6VNVWI9_!Z
MS6X4`VT((`!!M9P00.005R"#US17`?;F//VH'/.=W7W^]17[O]1EWG_X"_+R
M\G_3T_B7^UH=,9B^GV)^7^?X^3(=3C6/4;V+&X1W%PB0[MK,6N`B*HX)/(8`
M#)"DU-!INM:?;Z=K1TK4(+*ZNFCTS5FM[@6$]U;'S)8[:\*?9IY(`A,R1RL\
M2JSNJA35S556+7M0E;(A^TW<,A*95XY3/!<1!BI5#(CM#YH(\EW$@8%01+/J
MUWJMOIEG<W*&/2=/DM+"!Y`+>WA-T&L[98]H#S1W)CN+FZ'S26R-YY=(RU>Y
M&$98>A*5G"4W3J):M+E@VG9W7:TE:UT]!8NG*AF>8>STE2K2=&?V9J,TDXNU
MI)M/WEU35]#]NOV(?VFM8TBWFM=-N=-T_P`6#2-'N[.]\26'B#4O"^DZH1::
MM9^(/$%EX:CDUDV41OIKNSEMT5)+J&%W8VZ3$?>'Q,_:1^._BC5+^?Q_KE]K
MFL:FZ:OIU]X4_8V/CSX?ZJZ6UWHEOJ?A_P`3GXNV'B&\%QHHL+*\C\6^'[?^
MS+*.74+&(7]G:D_C7??!GXD?`?PK^S?\5M(U"ZAC^(7PNTWXB>#O%-CI5P--
MU-=;U>Z;6?!KS2S6%AJVJ>']4BU'2+_2XKXWVGZ!>V%S-;JDMNLOUKIO_!73
M]I7P[X%N/"%KIW@$!)Y;.2\6UU:SO+2YE06@MVT;4;Z\T^\2%G$P"HR02*+F
M,+)"C+_-/%7A]B)Y_B\]X8R'(LSE+$.AC<9B<9[+'4'%J4J48PA5_<153GNX
MJ\W4C)*T6?VSX;^*F`P7#&"RGBS$9C1C#"JIAE1PE&K2<>2,(MSK.+4^:+34
M?=V:W:'?M=_M->.M9^%<.D?$CQ%X7UWQ0VI6&CZ':>$M`U#1X]!T?3W@NH;3
M5+#5KC5+JVGNC;+8"RTO46$5S<)$^Z+>K?A'K6H75]/J+SQ2J;FZ-VEM_I$<
M=DTLFXN('VA3-'E!N'*G<IX7'Z*:-I?Q8_:R^+/ANTO;:7QKXL\2Z\MGI6@0
M6XTRSEO(KA9-4O+J&*,&'0-*M?-NO$FMLBV7AW2(;S5]2N+6TLIIH_D_]I3X
M>I\'OC1\5?A39W^JZUI/@+QYX@\/^'=<UBW_`+/O]<\.0:I=OI_B26R>**1D
M\8VOV#Q+:[=ZP6MRHC9X79Z_5^`<IRG)*4L%2I8..8XO_A1QM'!UI5E&M45.
MC)N,[2A:5))Q24=+*^Q_.WB_Q)CN)LV_M+#UL;6RK#TE@,/4Q="-#W85:E54
MXNG>G**C6O>[E[SZ)-?.N\^@_7_&BIRL63EESWR5SGWHK].L^S_K_AU]Y^+>
MT79_U;_/\/6W1ZV3]OU$9.#?7N1DX/\`I;'^=9-J`;JU4@$-<P*P(R&5I4#*
M0>"&!((/!!(/!HHKBP_^Z1_[?_\`3:/9QO\`O_\`VY+_`-3*I_H07G@3P1KO
M_!(+XQ^'];\&^%=9T'P3^R]\%/$G@S1-5\/:1J&D>$?$5W\*1J=UK_AC3;NS
MFL]`UJYU*./4+C5=*AM+Z:^C2[DG:X59!_&%JR(=1^'<)53%JG@K0+_4XBH,
M>HWQMI$-[?IC;>793Y#<W`DF*_+OQQ117Y#P+_R,^,O^QEC_`/U'PY^SY]_R
M*LA_[%>&_P#3]0_IE_X([^&_#L?['G[3?C*/0-%C\83?'QO`LOBM-+L4\22^
M"8+?3-<@\'2:ZL`U1_"L.MV5GK$7AYKHZ1'JEI;:@EF+N"*9/Y[/^"P%O!;?
MMR_%V&VABMXEB^'6V*"-(HUW?"[PB[;4C55&69F.!RS$GDDT45P>'?\`R<?-
M?^Q8O_3]8X.,O^3?8+_L;O\`],8<_,@(F!\J]!_"/\****_>3\.73Y?^XS__
MV0```````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+VUA=6PN9VEF````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`R-R`Q
M,#4Q-30S-#$U,"`P,C,W,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```
M_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"9
M9@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#_
M_S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F
M9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,
M_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S
M9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9
M_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`
M9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF
M_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_
M9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS
M_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,
M9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`
M__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^9
M9O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/__
M__B_)```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"'Y!`$``-@`+``````@
M`"````CT`+$)'$BPH,&#"!-B6P&@X0J%$`DR;$@1P,.("2=6I'@18T&-&SEZ
ME%AQA4F3)4<*+`F)1$M((%5.-`GI)0E:,&>.I%@3"21:0"'YA$31X\R;0H'2
M\DF+A,Z(#@'\9(9**2IF."TVC#@3@$MF3I0Z8=92JT6('!NZ_!FTK%D`:!V6
M)7$3*%VO,(MFY%B3+<ZV-35V-%A2[4^Z2$E$U7NPL%J<-9NF94QX<F272(F^
MA8MPXT3,-A=3)NGYI.F3(0</#,FZ=<7&KF-O-`A2MFN3*G,KG%T4KN_<OX-C
M$ZY2>._AR(NO1FX<^/+@6T?KGDZ]^O2````[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]L=F5R:6YE+FIP9P``````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$Q-C4W(#$P-3$U-#,T,34P(#`R-3`P-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#_V/_@`!!*
M1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!
M`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!
M`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F
M)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````
M`````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/T\^-7C;5_$7QU^.WP.
MUC3;32KGQ)=^(?`W@/Q;JOV33K3PSXC7Q3X>\82W.MZQ+"1IW@+Q._PYT?6;
M[5(Y;R[TV_ACF:SMH=5U4C\;/VR]4\0_&NR^''P/ALM'U^Q\->)8/CGJFJV=
MZDNEP?"OP9X`\9Z;<7XO+83O=W>IW^I^&M&TV2WCFTO55\0"_MM0-FXD7]:O
MVJO!^N?"+3_A/\9?#\D'Q,^$_CF;6$LOAOJ%[;V_BRU@(^VW/AK0?%MY97^J
MSWUIIDDVD:9X;\5ZCJ6FV,*S>'[==!M+*PFL_P`:OC!^T%:>"-!^%GQ/^&NG
MVL.I3?$SP;\/+;2]>L=&N-+\2?LO>/\`P[\2+G5OAUXTN;PZG'X>U^U\1Z;X
M=\/VNNP75O?:!XD6WT"ZU860ELF_S?\``[P[7"7C1X3YSGV78/,LAPG&&%7#
MN<\.8^>+PT5CY8V&%GB*./PF6X["8JK5JTXX^%>@Z->5;&2P%3%_5\3B#]>S
MSC;+^+_"#Q$R+(Y8K`YC3X3Q%3,LOSK`1P]6GB(4J6'K8K#5\-5QE&OA)4:5
M.I3C1=26&E"DL6Z3J*G+L_@S\5OA!9'Q1XX\9:A9^'/`7P#_`&=?`FEZ[J]S
MO\V'QA/K/B_7M5TD:7:K<2R6TTOB[P_I^BQ6B37FH7MU<P1VR^3;FX]S_8?_
M`."E'Q"^%GQ(M9+CPQXYUG3?$GBKX>ZB_P`-_P#A&-2U'Q#<^'_$'A?XHF&]
MB'D6MN(=8N[70+W1+BTO-1TF\&G:R)]6LU2&YD_FA^*/CZWTG]IKQGX4F?64
M^"7BKXO_`/"=7OPHU6=X;W4+/PC;S1^`O#?B&.26&>\M8O\`A);?4=6TV_OI
M=%672Q`8[B/3Y$/[2?#[]KSQMX7LO&7QPU_5K9/VC/B2=!T?P7K.@Q2V-QI.
MB^$YM5M=#T^#2GMX6\0:9H&G:C;+#J>M64D,D\4VHO;NT7AQ-*_V4>9<59[Q
M'/AO+<CP%3A?!X7%8C/>(,PKNGRXNOC7++\FR?#1@Y8O&8QNIB<5B*CI4,MP
ME*D^3%XG$TL*_P"1,JP64Y%P3EN<YKGE3_6#'4J2R[)L#2C.?^R83#1QN:9K
M*:<J&7T[SPF$I4IRK9AC83@O9X3#SQE+^I./]IOP]\6/`?BOQ_H_A&]NK9X=
M0.B:2D^E:GJ.D_9+2Z47&LB&[1+!+R9"\2M&LI2&;!DPCU_-=^U+^T'JOA_X
MN:;XSBT/4["_\-:_H/B6R9T@-M'?:;K5O>P)*K3Q1,DTMF8_+";=D;1*^SYV
M^E/A'\8(_">AZ9X$\/7-SKFM>*H(+76KF0:5J$>FO<-);Q>?J=G;R1F[@^VR
M2/:Q7MW:^:LD4;M'&ZMZ9^U!^R4=;^`'C+Q))I,=UX@;POJ-_8:A);3J]AJ%
MG8W$T+198Q7P$H5T4>:K,P4!0HV_K609/ALFHXFE/GA/$RC3P4I5;QDX0:^&
M::5.,GR.7,W-^^MT?+9OF>+S.A%T6G4HI5*VG5)2<79+WY12:CJHZ0O9-GPQ
M>6EOXDN[KQ%IOQ*U?2=.U^YGUK3]*F\])=,LM5E:^M=/E2._EC22R@GCMG2.
M65%:,A)'4!B5^6]K\:/$NG6MMI\KZJDEA!#9R(LEOA7M8U@=1YL+2X5HR!YK
M-)@?.Q;))7N?VC66CKU%:R:]A%VMRW5^;6WO?U8Y5Q#@K+FHJ]E>U;$)7TO9
M)::K3MIVU_;#_@MU^V-XRUGX3_L]:[X=A\'Z3=?$#6O"'Q.T&7P1X3U&TFU"
M^UJT;7/#,&C:M%XA\1/X@2ZFET^)+[4;/PWKDTXQ<>&-+GN9--M_Q2T#XR_%
MKX1_M%^&="_;!\)36OPH^,FJ^$;/Q?X*\%:[%!I":YXCMH-/\#P>+]*:":SU
M&T\-Z[IEC?\`Q)T+2M1L[&[MUNY;J35;RQT#29\KPKX^L?B+X9\,_!GXJ>,/
M$7_"J]`\3WGBK08[%)]5USX;^-A;7TFG>*_"%L-0LL3/J4D=K?:)JDNI^$)[
M75;S6-0\,ZIJFFZ3>V?U#^T[\&/#GBVR'[:_CC0+N7X,>`_!ECF\L;&]T+P3
MXC_:#:V'A3P9\(M-U.[U:^M=1\06^I:'XX\:WUEX'U"+PAI7P]\-^%==T_2[
M;2O'.G$?YJ8!\-XKAN?!&986>4Y;GM+,LJSC#9/DN-S;,<5F^85JM;(,WP&9
MQJJKDSPE>G5K8;$^PKSP^;?5:3Q^"C7H5L5_7/&'`N;>%N?U<QA&6;RA+#YI
MPYGTL=_9V!>6X67L,PRW$8145'&YE)2HT<=A*>+IPHX*?UE4,;&<H8;]?/@-
M^PQ\%W\6?%'Q)\9_@3\,_B59^'M9U"RLM$\2^'[.;P_X'NK#4?$`@\/^%KVZ
M\.^:?!]O=Z@!;P"QTJ:SLK#2K%;.]C@2.W_"N[U"U_9)_:2UOX;_`+4'PJA^
M&6M6JZ=K6G:A!X9\)6GPQUG2)MDB:QX%O-)+6^K"YCE5!LALKJTN[66RU^32
M+U(HF_H>\"_M*Q:_\'M075_$>F>'/$?QH^&WP<_:&\`1QZ?)>:9XYT?QYI&@
M>-/%*:!?1*]K<7/A[4KZ_P!)U#28A<75IJ-A>Z'/]EU"UDM'^,+?7?&/[3WA
MV'5/VL_"/P1UOQHEUJ5CX*^&WPY;3O%.G^$_#!^SOJVG^)M<LE9]=\3PW%G`
M?$VM!1;)<((6E\R%I*_D/P+^DI])GP^QW%>1\?9KE.-X#R*KA>&.'85LMRR/
M&F!ABX3H9=G.2YC.C*6(R["4<#F%;,*'$>$QV(I48X.4<30PZPCQ_P#0V)^C
M;X?<<TLKXQH91C\)'$.IG^(P-&MF<\LSU1PN48G$X3%X>G+`QH.MF&9O"8>K
MEF,H\U6.*G1ISJ8/%U<-^D7_``3T_P""D_[&WA#Q-:V&GW_AN34/$NIZ)8'6
MICX7N=9%W<33Q6!2XN=42[M8X99F2"+1D3R`TC"T,@19/TS_`."@'Q+T*T^$
M'BWQYIH2^\$>*?#T,UW/HLD-S<V/BB.&[BAU;4AYZVT6FZO:VFG:='<03N\&
MM00.\+S:Y),?X]/CS^P7^SMH'@";Q5\+=`OSXXU74;/1O"^J?!G2O%_BGP=H
M'BGQ)JEGHO@_4/%GCG3[BZ^'_A6U/B"^M+8N=6O;I9!=*(X;R(+']^?\$_/C
MS\5/'?[/WQS_`&(OVQ/$^ICXI>'UU*+PV^J)866MZG\--1M;*.*ZM[>*RMTU
MA_"7B+3K^9;R*&6ZM+E=)N[F8-,9'_:>%/%S./#['X7CJ7&F<<=\-PS?#XWB
M7#<5KZSQ;1PN(K8:CB\3EV.PU7$4\SR^E3G##U%.IA?[+QT\!%TYX>>)CAM>
M/?!+*.,L!47#G!O^IV84L$\-A\#EO.LBA7I4ZCP<*N%Q-#"X[+:]6=*=:,I4
M<9A\QPE/&5:>-=>$8U_CV\T/X?ZA=W5^+*QE%[<3W8EEMH!)*+F5IA)($#('
M??N<(Q4,2%)&#17.W_[)'[5UA?7EA9^!M7U>TLKNXM+75M.O=/?3]4MK:9X8
M-1L7\P;[.]B1;FU;`W02H<#.**_U2H^-'A!7I4JU/Q/X(E3K4Z=6#EQ1ED).
M%2,)Q<H3Q<9P;C*[C*,91;LXII(_S^J>&'&,*DX5.#,_52$Y0FO['QCM.,DI
M*ZP[3M*ZNFT]-6FS\>;*PN-.O[?4;5=JL46>/&Z*YRGE,)`%W*\C%96(90O#
M$KG97[<_`KQ^/V\/V6_A-_P3T\2V<?F_"SXM^(_V@I=,E6WLM*^*V@>#_A1X
MG\,^$?!4<EBR:DFOZ)=ZGI4-[;-`R:WX6T9#_:;7ROI[?C%;0/\`O&W*D)\M
MXXRQ#/(&(&TLY\O<!D%2BXVH[E2%KZB_9N^'GQ(UWQE97W@!]>L-:LS%?Z?K
M>DQ7UM/IKQ7MJZ26=Y;(A@N8I3&Z7*2QF-TX8DHI_P`R.,,QCEN48O-O[6CD
MN+R_!XJ&&S=8AX7ZK&OAJE&<IUKI_NU5]K3G[TJ->G0KT_WM"GR_ZL9YD_#?
M$U3*LKS/!4L='!9O@\[P6#K4UC,,LRP-2G.*Q>%]I16+R[&QI^QS#!RE3CB,
M/4G%R4U&2^Y/V(M4^%MA\1?&WPP_:OET:Y^#'P?A^,.M>$_!GCNTU;4=+^'G
MB'0H;NXUJU\`V&D:?>:YX:U;Q;-JW@O67T+PI'H]KXH2RFDU$3MHT3)T_P"R
M+^QKXI\3^$O#C>##\2M!^#'BH'6O$7B+Q9/H6A^)/'^BWMF=9T.U\/\`A;P[
MKEQJNB^%Y#'=ZGJ\ECK+3:Q8ZKHLT<8@%OJE?1WQO_X)K?'SX]_#Z/XR>"K7
M3O$GQQN]-MI_B5I\]K=:5XH^*EGI.A+IGA>XT/[%%9>&+3Q9X<BDOK2ZFN;3
M3)_'VEZO=0>)M5U'5M.TV[;Q+]GCX$0_##X#?$_X8Z1XI^,7Q._9DUC3?"MV
M?@Y\4]2U+X;^//V4/$-BFNZI\2?`GQF_X0RY\*?$KQ)X5\?ZE/I]UX+\-Z,M
M[HNH:-X=\0V^H^#KWP_XG76=;_F=<?</^(_!V=YUP/QKA,PQ5/-<KRS/<EI2
M^M5L)4RV=?+\?4R[#XJOAL%2S>G5Q,<XR%9GB\KR[-<-#$Y@\?'.</AL'0^C
MPF:SP7&DJF7953QF*J0Q>'J3IXNG4P/#^+K2PU3`?6,/AJ$:ZPF90>)PN.Q]
M/"8[&?6X8.GA\HITUBZDOJ34?',?[5'B;X'>%OV=[W6]#_9;TKXR^']0N-:T
MV^\,:EX5^-^O?"'7=$\4>+-.^'^FMJ-[XL\,_"W0)=`\*^/--U[7M'\,ZSXL
MUV*;P]X9TQ?#]AXF?3;GQ;^!<T/[4OP$^+7@^+SM7T+XBZ-X/^)<L8"WUWX%
M^+%W=^%+DSPC<)+*PU&Y75?*,J,'M$D0RS.B'SWX1?&MM*\3^)?&6EPZ;IVM
MWUA8Z'X9%]8:7!K>G:/]DO6UU[*PTVWM-!L=1\1QI;-+:>'M+AL]`T^U^R:1
M=W-YK'BK5=<_0C]G'3/"PM?&'Q+\<:PDFH:7HLGBC4+^]ND&F+)X9U73-1T+
M3[=1+;VB2V5N^HW3I(-[+))/,[M&#'\S@7C:F=9?@,OP>"RS*\MPV;8+$9>F
MJ]#$TL\A3IX]XW,%A<#4SC&5<%*M"KF.)P^%;JQIT,'A,!@,)A,)0]O$RK<+
MPQ$,VQU;,L3F6&A6QDY-RK8W&QJ\^'C@</\`6<8\%A,M:P]E&OB'6S!8K'XJ
MOBZF*G7J^$0?%.ZT^&&PDA<R6,4=G(5=MI>V00L5Q'C:60D8XQC'%%?'NG0Q
M:UI]AK%WYJ76K65KJ5RBLZ*EQ?0)=3*J+&%15DE8!5`"@```#%%>96H\/4ZU
M6FH*T*LX+W8;1FDOM]DOQ[H[J/#O%TZ5*4J%I2ITY.\:FC<8-WT6S;[;/:RM
M_/D680OAF'[VT7@D?*\?SK_NMD[AT;)SG)K^E?\`X)_:1I47@_PY+'IFGQRM
MX?T;=(EE;)(V[^S`VYUB#'<&8').=S9ZG)17Z3],/_DT^-_Z^U/R/S?@?_DI
M,7_V"5?S9_4]^RW;6YM[@FWA)BM=!2(F*,F-&MKO*QY7Y%.U<JN`<#(X%>;_
M`!O\#^"_^$O_`&B8_P#A$/"_E^(?AD5U^/\`L#2=FN+IEWKK::NL+]DVZF-/
M:]O6L1>B<6AN[HV_EFXEWE%?QI]$7_DS&#_[++B'_P!2*A^,Y5_R<SC7_L&R
M/_U?9*?R$?#N**#X?_%74(8XX;^">.WAOHD6.\AM_LS_`+B*Y0":.'D_ND<)
MR?EKZE;4M13]F_XK,M_>JQ\%7^66ZG4G?8:_NR1("=VQ-V?O;5SG:,%%?UEC
M/CE_V&99_P"HN#/WS/O^3B9;_P!>*W_IRD?BSJVNZVNJZFJZSJJJNH7BJJZA
M=A547,H``$V``.`!P!P****_1J/\*E_U[A_Z2C]P>_S7YP/_V0``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V%L:65N+FIP9P``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C(R-"`Q,#4Q-30S-#$U,"`P,C0P
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MVP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`
M'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%
M!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*
M%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"
M`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF
M)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^(;QQI<-G
MXYU[1M&C-VIUR[LK:.PLGCCCN9KD^9IEK9H"TBV=V\FG6YME\JY$*RVZ)%)$
MB_M5^RC\*-=FTN+1]'&KW%_?1K9:?:ZN=.LX;[1=*L(+O2]0$IT^RDD:*&YO
M+2VG@E6"\@*O-#<W*B['Y/\`QK^%/[0WP<^/ES\//&'AO4(?C2GA/P#\4[OP
MWX6M[SQ)J.F:'\2OA#X<^-^EP26MDFH2/%HWPV\5V%SXBLF^TVNAV5KJ=I>S
M2:?87$Q]Q_9N_P""CGQ)^"NN:1/XJT'3/B'H=KY-G-;/LTK5%TF3[6MQ';WL
M-M/&MY%%<PKIUPD$;6UM8K8GS;*^O8YO]=\D\7.`\LXAXDH0QF,P5?$XRI2R
M&IF&%@LGP]./M%0IXK&9?5Q,W9U8J=6&&J1FJT*E7$TZ$%3I_P`B>*_!7%W'
M?!/#M'AI9=G6'I9;@LPQV'684Z>/S55\+2J86OAGB*6%PDL/4JX>-1U)8K!5
M*M.5:6&A&O2HH_I?AUB\\":GIVD^(Y(K70);-([;4;;3X5NKN^T72M/T6<:G
M;VTM_<16=R;9=0M0ANM1B%SI5I/?K;6U_86O[8_L2_"]/&'A-7DT\(-0;5-3
MGN=(M9GOKVVT.YGM[&"]GO&NK6*\MY[;5[ZV%I;B)[2U?RK7^T'O+ROYTOVE
M_B_\+_C+^QO\"/VN/@?XKDTV'P]\<O!WPZ^./A*9[^+7O#?_``FMK_9PE?3K
MRWM-0NIM1@U*'7$\NR%@VDVEG=6?E2:WHVHV_P#49_P3Q\6:1\/?V#O'GQJN
M+G5E\1GP7XVN?",9U:5+P6\7@6\AM4N+Z::ZB34G\2ZI:O'=Z;IVGB34[Y[A
M[*>>Y>XF\SQ'Q$\KX9_M'(<=*MF>-QU')H4,%",:&95Z^/\`JN6UJGLISM3G
M&3QTJEZM&O\`5:.,PJ]E]7KS_B7,LI>9T<DIYM3K\)8C%X[,\DS_`!V/PT:5
M7)IY'-U,VQ*PN)Y7/,O[*=.AAJBK8K#YAC\TR^A3G1G.M[/ZO^$'B+X+_"?7
MAH?CGQOI[WVNP"_TJXM;$^9<I-8P/#;,8IW<K;Q%YTN/M]O:VT%_-=S2)IUP
MMQ<[OB?XB^%-;UK[=H$K2Z)+<_9Y]4FL[NPT_3K8V=Q>6LM]JEQ&]B]RY?3;
M#[-<W=K?0R7L%K/`MQ:O'+_-#\1_^"CG[*?_``3D\0:KXL_:[CU'XY?M2:]I
M-EXF\&_`;P=%IM[J?A7PWJ.FZ8WA";XC7%OJEKHW@&ZUS2+O3M4;3_$>JW7B
MN^\.6^I7O_"(0Z9K]AI-]\/?$;_@[._:0OM=T36=-_8-^$'P_P#AUK.F7%YI
M.EZOX@\6R:WXAMPR6UGJ>C>.;3PMX6TRZL+>XM'2]DM_"M^MS.US$;^V=G4_
M@.=Y=@:'%N.J1QV+SRLL)1I8_'*O"C@,)5Y)2TP6`P..Q%&<H^RA_M2P=.&(
MC&+4XU*E.G65^#/B!XB^'E.EDO#:Q<5FF)S"AF6+GE>1XGBG,*M&G3G4R[,<
MRQ&`AB\FR^FITL%+#X:M353"XF5:O7IQP]&7]K7V.U/*ZK9JIY59H=124*>0
M)5BL9XED`X=8YYHPV0DLB@.Q7X&?#O\`X+\?LV^,?A_X%\7>)?!FJ^&O$?BK
MP=X8\1Z_X<L_&GP_O+/0-;US1+'4]5T2UN[O6-$NKJVTJ^NI[&"XN=&TBXGB
M@66;3+"1FM8BO+6"Q;2<5BYQ:3C.%!2A).S4HR^KJ\9)W3LKIWTZ?B%?P7\3
M,/7K4)\`0YZ%6I1E;,J#7-3FX2LX\0RBU=;QE*/:36I_$+I7[;_[5_[.W[;G
M@_\`:M\-_$'48_CK\&=.\&?#_P`/^,9;?39;W7_AMX#^%NE?!#0_#WB2YM[)
M1JK:]\%M-L/!^NZ[.B^*)5FEUB#4M/\`$D%M?V?S]\<YO@O\2/BDFM_LK?#7
MX@>`]`\:QW^N7GP2U.2Y\8V_PL\5:IXL\43V_P`-/AEXOEUWQ)XT^)?@/PYX
M/7PG#I'C+QW;Z)XYU75GUZVU?1&ATZSUG6/J#]K'PIX@\&_$/1_CWX=M+:'P
M7X]GQIC+:3L_A[Q39V?V/Q)X-\7P7-I9WMGJEW<?VC/IC7H@N;K26DMM.>UN
MM`OK+1_U6_8$U>RBB3Q#H.A6.M0G2M?UO7+NUTZ.[\226VGZ5/=:.VC2:E!9
MWUMJ%['J^GZ-#I6F3SVMU;ZQ(]U$E_)<R:;^S9?X2\(^*&+K\;<.\98G#\-9
MO7EG>"P=3`X6&.PF68C&8BA3RWZT\7AH+%95B7BL#.G/`3I/%X+$4Z4IU.;$
M+_5WCOQ&Q_A+P_D>*K<*0QF.C@L/DU>G@\TJX++J.88?#152&+PO]GUX3PE.
M\*V"KTJD:]>-54Z4X85^VG\&_MH?M3?\%$OVB_B?\,OB9^VI\.]8^&EE\1_`
M/PN^&.BV$7PEO?@KX5^('A?X4ZCJ^E^&O%9T&&WTQ]5\5Z+<>)-8N;#Q;$86
ML3!8Z=H(L?#^A:5I%A_=[I.J_%+X`_\`!&K2_B_\!_AH?B9\78/@UJOQ!^!W
MP[TRVC\07OB+Q=%XML=/\+7.OZ>EC;#Q1'X"CU1?%WB3PW#>07&OZ3X;O]!A
M57U.*2U_DH_:Q/C?]JGQKX*?P[\.O$7BC1/`=MK=[=ZUIOAJ\\4W?PZ\`V-Q
MX?@'C'QM>P//9^'O#.@WUU+-'?F2TT[P_=>();674WMI)=27^N[]E+QC\1]7
M_9Z^#/P#G7PA;:Q9^"_%7@WX:>'KW7[6Q\3?%'P_\.;:VM_BSXC^$?AMM:@U
M'Q=HGA2?6](E\5>-=&:70M#UNZ:SG@N+_4(H+;W?$?@FGPKPCDG"U#B:4LMR
MWBG!8NO+-<5@,+C,/E5/+LWQ%>E@JD*%+#0A2Q684<5%5,-)4<+3Q%91?LZT
MH?QMQ]QY0XMRC@O-WP1E^)SZE+'*ED625<?/+9YA2XFR/!X7&YS.G7>:SP]3
MA?`8W#8NK/&4\2L;6R:I5J_5(X>C5_S>OV__`!3X/^*_[17C'X_>$?`?COX6
MW_Q[U+6?BE\4/AEXPT."WTKX?_&C7==U&/XK:+X$\5V%IH^E>,?`NL>-(-4\
M:>$VTWPQX>@\%Z!XLTOX<SQZS?>$;SQ%JOI_[3?[?/[5/_!1#X;_`+$G[+7B
MCP;X4U33/V1?AQ;?!'X!^$/@O\/=9M?%GB^*YTKPGH-O=>)M+L-0UZ3Q5XTO
M]-\'>';*(>'],T>Q\V.^N[70XM1UC5KJ]_TQOV7_`-A/X/\`@;6;;0?C'\/O
M!,FA77A2*2_TSQ=HMO?Z%J[VENMSK,%QI&OVFH:?8W.J^=.U[;:3=+9/"NI6
M=U<7,Z6-O<KX]\"?LV_L\^*=0\6?#GX1_"WX;Z-97NIZAK'C#1OA]I>E3Z#X
M.\/Z<]EJ5[<WVBV$>K6<L=E>1:1:1V<$FGO)>W"SVZB^NKF?\'JX7A'"Y[FN
M59+F>:9G1^H_VD\QKY5@(X.K"$<?3Q4Z&?5,UJUZ-;$X*IC(XG%4L-4JU56Q
M$Z^'E[987#_LF+^E%B<NR#),VGX?Y?GF:4\]S/AC(LOI<93H\0/&TL#A\;*5
M?ARCP[BL7ALOI4*N$PE)XNM7Q6(KT*$Z3Q%2I2QE;^8;X$?\&^_[2&M_`_X-
MZUXA^#>@Z5K^K_"KX>:IKFF:[XXUK2=<TW6-0\(Z/=ZG8:SI0;&F:K9WLT]O
MJ.GCBSO(YK8<1T5^L^L?\'(7@?PEJ^J>%?#WP_\`"&H:!X9U&^\/Z'?ZU)<P
M:S?:/HUS+IVF7FK06VDW=M#J=S96T$U_%;W5S!'=/*D5Q-&%D8KY+_B9C-L+
M_LV%R/A26&P_[C#NK'B6I5="C:G2=2I',8QJ5'3BG.<8QC.3<E&*:4?OZ7@U
MQ]F-*GF&-SK/,'C,?3AC<7A*.5\&*CA<3BHQKU\-2^L8]XA4Z%6<Z4/;MUE%
M+VK<TS^*']F;Q]\._C)\*_C%\$_C%XD\1:SXP^(MS9ZA\.-8N)=*O]"7Q5-?
M23:QXC\3Z_J3ZAK:^(KZ>1;.VUG3M-U6X=Y[NXUF:&6.UFE^7/`WC7QC^RM\
M5]6\,WEV]WX?34K6P\4:)>1W=M;26KI#)'J*VPAGN-.UG3;:<&9XX)Y-Z36$
MJWL:J]>$^'OB5XBTO3]$T"&\A&AZ1X@NO$^D0/8V=U/;Z[K5KHMA=W<VKW5J
M^OWUI?Z?%X=L_L%WJ#6-F%MK^RTZQN[[7$TS]"[_`,.>'/VMOAAX;U._N_#O
MA;XS65Q>^$M!UV^UK0K<>.)-!M+"\DT7QI9VD[:QH[NFM:=8^%O&6JZ59Z'?
M2W">'_MHMM(NO[)CZ._C?@.!U/A/BAJAEE3,'FG#/$CE6YN&<TJT94<;EV/6
M'_?8CAG/K4)8FE+V]'*,QI/,J&%C#,<YJU/Z/XRX.P'$F%QM'&8..88',L&L
M!G&624'#%48R4L/F%!2@Y0S++G=T:M&=*O.ER.,ZM?!8"DOTF_9Y_:K\0>$-
M*^,6B_#?5]1\+WOQC^#VI?"_QU+I]Q!I?B.VT#6KYI0VAZ[%%)J$<VCZA9QS
MFXM8TM7L=:%M*;>^OG6P_K._8/\`V(_AIJ_A/]CO]N"/7_'&J?%/]E;]DG3O
MV+]'TO5O$,B^"/#VK^&/#3>%_&OQ!\(Z:UQ;S:-XA^)UG=S7'B_7;66VFU:'
M5'6[2UD^V(G^=]X'A\9WGBKPEI[7.L>#_%G@K5]+\(^.?#=\EAJ&K7NLZ;>W
M-SI6O1V^N/)##>W]Q<6]M<-YFEZ=JUC;HK7Z7%@-4O\`^^?]D'P]^TY?_LP?
M#S4I?VG=#\-?#;Q3IGC'QI<>'_AU\'K2WNH-2U!["Z&GZ3XA\>^,_$4=_K<'
MA[3[BZGEA\/2KH'B*+4K*XO=0L]-MHU_L;QJPM+B')<GS/+,5E.52SG%1CC,
MXK8/$8W"9YE^+RO#TU0C##83'3>)AEL:V$HXJ<:&(I2P3HX3%RH.%/$_YH\<
MY?A_">MFN7U,VQ48YM@L1E^$R[#8RO@LSR?-*52LL)6Q&-IX#,,3/*?W=:O*
MGA%4AB\-C</E^)G"MF%C[B^-GQ`UKQN;CPW#=7::N;N^MTETJY:6[L;N6VU'
MP^D-G>N-2^T3ZGI\UE<26+6<\6EW!FL;F+4I[B\L[+^>K_@K'^V'I'[(GPXO
M?@'H^IR_$'XV>,I/"_BG]H35_'"W6I6YM[$6'C'PQ\)-/1=5M[)?#EOKNHG6
M?%5II-ZNH:EJSPV,.LHNDR6NG?1?_!33_@H]X"_8_P!`'A_X;/IUG\=[V""'
M4]-O+JWU&S^%\/V2Q?2Y5MI["&"Z\6ZO8R6UT'U2ZEDT*2\N+NZMCKBP3Z9_
M"O\`M$?&GX@_%KQF=:\9WWB"_P!8U&&UN+&;Q`VHBY.E7<4":-<VD&IQLZZ9
M-INR?P_.+5[,Z%!=:I:1W%A;Q::W\1^*/B3A\!DE3PXX3E/#X1R@N(\12A2I
MN=:A5A5AEE'$4IU76PM.K'VE>%*M/#5*L,/-U,37I.K']E^BWX&8ZOC<L\6.
M,<-B(T_JSQO#>$S&K3JYAF>8XJM"J^),9[.IB.3+\-&DED%.>*J_7?:_VFJ?
MU>E@,;F6-?\`Q,\9WE]>WD>MW=G'=W=Q<I:6QB2WM4GF>5;:W18E5(8%<11*
M%4+&B@``8HKYN>9"[DVMA*2S$ROJGA#?(22?,?[397]SN?[S?:+Z]GR3YMW<
M2;IG*_F@_P!!1SS3(+.5)9%D-EJ<QD5V5S,OA&RNUE+@AC(MU?7MRKD[A<7E
MU,#YEQ,S^S?#J::#5K+R)9(?+O=;AC\IVCV0VMSJ/V:)-A&V.W\B#R$&%B\F
M+RPOEIM**`/T+^-<DD/C[]B?7H7>'7?$VJW&G>)-:B9H]6\0:?I_C3PG#86.
MMZBA%YJMG8PN\5G;7\UQ!;1.T<*(K$'^YOPWXB\06O[/6D+;:[K%NNC?#VXU
M+1U@U.]A72M1MM"G>WO]-$<ZBQO;=T1X;JU\J>)D5HY%*@@HK_1#@[_DP_`/
M_7[B7_U6TS_.#Z5__)SN%_\`L"H?^K/#'\#_`.VQJNJ:A\3_`!3)J&I7]](_
MB"9'DO+RXN7=//U)MKO-([,NZ"!MI)&88CC,:8^`-9U74]<NM.N=:U*_UBXB
M7^Q(KC5+RXU">/1M#U[2?#^BZ1'+=R32)IFD:`S:'I=@K"UT_2&;3;2*&R)@
MHHK_`#QG\<O\4OS9_HQA?]VP_P#UXH_^FXGEG]L:M_T%-1_\#;G_`..T445)
MN?_9````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]A=F%T87)S+W-P965D>2YG:68`````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C,T-"`Q,#4Q-30S-#$U,"`P,C0R-#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA(``@`/<`````````,P``
M9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F
M_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_
M9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S
M_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,
M9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`
M_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:9
M9F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;_
M_YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF
M9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,
M_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS
M9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9
M_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`
M9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F
M__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___
M9O__F?__S/____B_)```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"'Y!`$`
M`-@`+``````@`"````C^``$('$BPH,&")+`I5`B`E+.'I"(^G$BQ(D52"1<"
MH*BBHT.+(#DNQ+9Q(JE1*@"04/$Q9$6,&IV12KGR#T&6+BNJT#B3Q$&!.'-"
MS$@"XJB?`%0(G;B3Y,,5*GP>)-$R)\R2,H_^#"IT9\F9`TGDZ42VTYR52V7Z
M?/A$JXHY93OE63&'*T29>!\*I$AB!:L58\GZI;NB)2FH'544=K9WHM]K?P6S
M@DS8X<P\F#.OT&I2H%\5<CU'SA-5!6:I8DDW/CR0U=N4`EV3)7V:8&J!$>F>
M#3NGM>FX;WW.Z4VB=U+>J/-(%4AB95SES8O#MCGP;6:SS.<$CCL[SYS-0-_"
MSH9=\.QOX*0],FXXLVR>J=H[/K?;^'PG%8`*7R;-7>YBBJL!1M9*N6W'71Y/
M5*570Q!U=)I\_<VV&4C,X722:08>&%US])$`"20;1G=:<:AY2`LDM)S8UT<`
M8$-"BB=^"*)*'R(!"8TI0H($C#<JQ9B+*-+2'(HWOIBCB2?:"&)S*CG4(I`R
MVC@D+3;20N.0,XZDPE$+1??AD36"*..'/HVD4)EF8CEEBBIM:.:;;[:)A(<>
M@@CGG7AV.6=&>8X4$```.P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O8F%R8F%R:6%N+FIP
M9P```````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,30W(#$P-3$U-#,T,34P(#`R
M-#<P-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/N7Q?\`
MM&^)_A9#X?\``_Q*_L[P]JVD3ZKHVFK8ZY9ZK;7K:2;;3K^2TN)IK66\TB;[
M/"=.U!+:UN`AA%S8V;;C7R!^T-_P5P^&'P?\$7\DUW;:CXABTO4Y]/T[1[VW
MO-8O[N&W1IHKZ?39)18K=3W":5;QZI-LMI7DTVS-PEFENWT-\8OV=OAU^U'X
M)\9Z'XECUR#63>Z_JN@:WX8ECA\0:'-I[O!!KMIK-S`[Z=!8XM#=02S7+W\)
M>*YBOHOM$@_CH_;C_9C^.O[)_P`;/`OPM\4V&G>*I_&_BG3=>^$7BZUO="FT
M[XEZ=I>M?V3I5AK%KI]W%8:=<P^(=1L['6[758])BC\]+Z:STZ"62:3\7R7)
M<%G>+>%Q%>,E"GBI5\+&5*<JV'HI2GS^TER*$=(S2DJTE)J,97;/ZZ4LEPF5
MXK-<12Q=/%8!8=4Z$O=PM7$5ZL:-.?+!^VJ*HVVM)4XKW9<K:3V?VF?VL_C7
M^TIJ7Q4\>?$+7Y7\+_#<Z)IFA^!=/<OX.T_QIXY2X6ST:YTII!I/B&]\,:-I
MFO:CK']H6.K?VAKN@VLMS#9VMU/9Q_)5C\-]6\0?#?QI\1_&-[=Z*^@WVDP:
M?%KEO"+SQ5<:Q%-]NCLFFD%S;/!%':7M[>7+W&ERZ<TL^GF>2SEME^G?VE/"
MB:K\0/BI;:%X@\)7GP_G^,7AK6O$NK>']:L=-T;7/BY+\.K>;XA>$/`@UZ>2
M_.D6$VG^-=.^%&H^(=-@\'ZG'8:UH^E:K+JFJZ/H.I^<?M8:MX4USP5\,/"?
M@OQ#:^+7^'>EOH$.MV5GXC\):GK7AG?J,^F6OQ2^'?BI3>>'_B;X9G8:4^H:
M=KOB#PSK?AZ.RDM=7O2D#-^UY/#`9;4PV78-87`8%2E55.C3A0I8?#X:E1E2
MR]/D4H/'*JX3::J4I1<YR@^6_P`KCL!BJ=&KC*V7U<3BEA7*$:=*G3C&>*KS
MDJBC'DFZT*"I<M"A%RJ1O.%*4;M?`,\\+%D9;HC:%MT(62)`PD282;XU+13"
M1T4X0NC%YS(9)BW[M_\`!.']K/4_'MCJ/P,^)&K:GK?BC0;&3Q#X#\5ZU?\`
MVQM1\*62VL&H^"?$VH7$IN)KW1M173[KPGKMY-+/+I=QJ&AW]VGV/P_`?PFN
M-,N+=T6X0Q"4@(&0[C$`/,F*PAP8HG(C=PVXG+`;<9]B^&,OQ*^'%QI_QP\'
M7-MILWA6\FN=.:2]@EN[JRDD-AK9NO#TTK'6O"3VLTVC^)Q.K:;>Z;>:A82Q
MNN^>#[3+\Z_U?QF$S"EB*5*<JT*4EB)RE2QD):2PU;62E&3]]*JU33BGS;'Y
MU1RC,LUJ8S`TLNQV+6'P>(QN)5##5YSP&#P4:3Q&+Q,:<>>G2I^UAI6LIN?+
M!3::7]<$6JVZ11H)HD"1HH0Z?;L5"J`%+2'S"5QC+_.<9;YLT5^2&G?\%0?"
M$FGV$FI?"C7TU&2RM7OTT[Q-H+Z>EZT$;72V+ZGHEWJ3V:SF06SZA=7-\T`0
MW=Q-.9)&*_8?^(@99UJ.+TO'DQ>C?)=:4K:7:TT[=#Q5PIF&FM+I_P`O<#_=
M_P"GENGX+S/ZP?V</^"@/["?[/\`X$\1>*/CK^T-X`T[59O`L=OINAZ#XAM/
M%'B;5KS4+;6'O(+31M"74$@NI9WN5C?47FU2[O)5M(M*=K>6SM?Y,?\`@JG^
MV3\&?VX?C9X'O/A1;>*DO?"6N77@WX;W>IV=AX3\/Z?I7B37K:>\F\1:WK6M
M:AJ^IH^O3QZKI5V;+P+'8?VG?:EK+S2/INFZ%^0-QXT\1W*BWM]42WCDN1<P
M7OD6,M_&ZWYN!.M\+2ZU,.LA2..*VDLI;G+Q72-"A@@XV29I)UDCE:Y:66(Q
MRM`[N\\C*JR2&6Y6Y9Y&D8R.UXBRRR>9([3@/-_+O#G!>59!A5RU)8W,H2Q<
MX8^<(T5S8U6G[3E4)246HZ23@DKQC=GZ%F>=0Q>:5L0J6(>&K5L).KA*DU[%
M0PLE*G2H0<M(OWKN3BY3<92<K)K^K[X&_P#!.'_@GYIGP=\+_$K]HC]NW2_&
MW]JV"ZA/\+O@9H6@0V5GI/AV2RUO5M&^)5WJ>MZG\78=)N[+2IYKS6/#%CX"
M%KI8L?$7AKQU<:A.SV'P3\:O`7[&OPP^-7Q!\)_!V3XQ_';PWX&UHV>M_$G7
M]7^%?B#X9V4$NC:;K5G:^"O&VDZ!%_:MYI@GO5N/%'BW7]'T*QMM&N]2>/QU
MJ4L+W/Z!?\$T/A-^SE/X3^$G[9_CK]K+3O"7[1'C']G+]H,S_#SXBR:/I_BG
M6/B/8^$_B5\'Y/BUJ'QI\2:H/&&I?#Y6U70)M&T#7M,O+#7/BM'I_AOPM=:K
MX.\#ZX^BZ_[$WQ0_X)^:OK7AOX+6?[!G[*FM?%7PW^S_`*GJL?CC7[?Q5KNM
M>#?B#X*N_#EII?B[Q[X:\27FA>$OBUXRU^36#XQO=)\*27.MOIFD2Z+I_BW4
M3<"STC\;>-QF'QN8X>6'S7%SI2GB<?FTH.O@L/6YJE3%X['PR^36%I14*%'"
MTU2A!J7)*E*I;E_?L-F&.Q5.AG<L=G.<8"5&AEN"RJ&-H9-6P6'CA'6P&"R_
M`XW!X/!U:-*45A<5F%*,JT7S26,K3KRJR_F:^-?P@\4^!A%J>K^%/&/@_3?$
M&FZ1XQ\/Z/XW\.7/AWQ)/\//%>FV^K_#_P`820"QL4N;3Q1I<5Q>6FL:8D&E
M:O(%U;3[:V@OXK6.'2=6:T^',$D4-L-+@^'U[I=W*)$>ZAU>;Q/JHTNQTEMW
MGI)+<7]ZFKV4L4BK8/93S2,&MT7[%_:]\4?$'5/VE?B-HOQ=T"Z\-:I?Z-I=
M];:)_:P\1:)%8^,=/MO'6A>(/!>IQ1Z5:7G@OXBVNO6/B;2M3T_PYX4^W+J+
MS^)O"6D^-I?%5_K'YN^)K"_T!]3\,P7DUQHMU<V>K11LFU9'@!D1)8BH`FMQ
M</%)L6>:,IY8+N-J_L&'P\\QP^!RW%8G#U7AXX7-J6)I<TJ%;#UU42IP4E&3
ME1E3<6ZD(UI/62;L?GV.Q<<ACC^+<KPM>%+-\#F.19AA(Q;KX3,,)4P]:BL7
M'$RJ57EV9U*,J56G!U%3E&'.H0YFN6CCO%CC6,VK1JB!&*Z82R!0%;,T*S<K
M@_O5$G]\!LBB@2R``>=J!P`,K).%..,J&D5@OH&56QU`.117VS]@WMHW_,WI
M[O6WF_Z1^,J,TDDY6225JSMIRI?\O-MOO9JRWXGVBW6ZS!'<PDM%$`J&(Q<)
M`\KQ1%5)O9!(\D+3&$*[8=F-;2CRHR+A9F7[2UJ05BVKNCP3<2'"1H9&</'$
M&4[25&TCW/P3\$?BK\2+Z+3_`(??#'Q'XG>XN+:R2:PT=);7S=2>.'3[=[V\
M:!(YK^>:.V2);JW*.DDXB<G<_P"RGP*_X(=_'N\\/V.O?%O2KOX8^)?$$)OO
M#RZWH>C:C+8Q.YCDD33H_&6CR:?XBMM2Q9KK'B)Y+&VN)%"^&[]/(O%^?S3B
M7(\FI5YXS,,+"5"4H5J?M'4J0E%J$U*G152JI0D[2@H-IN]KNQ]92X;S+%8J
MG3Q-J%.IS0]I7PU?#<[Y823IPJ4J<ZM.<)J4*].,J%3F7+4:&_\`!%?XJ:-J
MUA^T=^QMJ4'POM?B%\<OASJ=C\%9?C3X'UOXD?#'Q)<WC:-J7Q=^#?C;PGH%
M]8ZQK^D:CX8\#>&/B7X(TG1M3TF6V\2^`KV:SEUB[N8?#FJ_2O[5_P"S+^R7
M\%/"6IIX`^*7[,O[+7C[55TC6?B'\.O"_P`>-*_:#^/'@#QG>VKW#^&?A3XK
ML?%N@&Q\,QW]EI]UK&KZO\#='\9V>J6,;)XU\.6]U-:O]<?LZ_\`!(#X0?LQ
M7OAKQUK7B74-?^)5AK.G^++75UO;.YU'PEXMTB6ZN_#.N^']4BATK3;JY\':
MK=VGB;3M(L_#:64^NZ?I:>(+S6=(M9;2Y^ZM)^*?B"[3QG:>%/\`@ES^S7\:
M?B?H_B"Z/Q>^*37?[,-Q>:]XKLM(L]4TGQO?6WQ6N[GXDZ#IVJ>%+C3M4TG2
M]&TC68])G6XL?#D6KP1F%/P+,>(<GS7B/,O[)Q6+PN`Q.*I9JG5IX>E4CF;I
M0IU,52A+!5:3H594J/LJ4I4W32GR48NM54OT/+%5X>PE#$XBE0Q4H0>$Q,*>
M*P^%2P+JPE3@G.G[:%2FN:"K8'V57EE"G6=1QC*7\JG[?VC:2_Q=^&D>C>?;
MJ?V7OV?);*ZU&YCNU?2KO6/'E_H&J:MJ>EVMI!(+KP99Z5?Q:BD.GZ;JZ7$,
MEE;:;:3Z;IT7YR?$OP]#?2I=Z(96LHIYWMY+V,F1[9)&N7$^;G9"[*\#FV+S
M3!A/#!<W2VL\L?WY^V3H_P"V)^T3^UAJWB3Q-^S=XR\-^-?V@!:Z]\/O#FCV
MIUC2_%'PR\!M-X/TA=!\2:?L\,7O@_PS>Z;?GQ1J"ZM8:"FO&U_M6VTRVL;#
M3Q^L/[*__!#R\\5I9:E\?]1N/&VMF%GN?!'@N6^T?X;>'&:Y?='K_C6S&G^(
M/B#>V9E74KU]`N/#'AA+X3P1/K\959?NJN<Y?P=A,HHU<5+'8VEA:4:6&P4G
MB<4W)RG*,XP52G3BY3DE'$RA&#O&'*HZ>G*KA<YR_-UF4)8+"5:CJ1J0]I0I
M6G4<H\WM?8U*M6FFDY)2J34KRE)/F/Y.39ZID[M*NW;)RZ-+L8YY9<,1M8\K
M@D8(P2**_OZA_P""+7[+UI#%:M\`='=K:-+=G_X5U)=[VA41EOM<^O\`GW6X
MJ3]HF_>S9\R3YV-%+_B+%'_HFLS6VCKX:_V='[WGKZOLK_$?V!DO3/ZOE_PF
MI]K:^TUVCZZ=SV#_`()S_#_P'!X`_;H\3P>"?",/B31/V@_C?:Z-XAB\-Z-'
MKFD6T7_".W$5OIFK)9"_L((I[^^GCAM;B*-)KV[D50]S,S_2_BT"?XP>"A,/
M.%Q%J5Q<"7]X)YY/C7XYB>>8/D2S/%;6\3R/N=H[>%"Q6*,*45^2>(7_`"/N
M+_\`LI\\_P#5C$]S"_Q\I_[%61?^JC#G>_&JSLSX"N+LVML;NWT.]D@N3!%]
MH@DDOK>&1X9MGF1N\*K$[(RLT2K&Q*`"OQP_8JU/4I?^"J>@Z?)J%])8:K\#
M)[G5+%[NX>TU*XL_VBOAI;VD]_;-(8;R:U@U[7(+>6X21X(=:U:*)E34;Q9B
MBO.7^]P_[!Z?_IR)[>0_\B7B#_KW6_\`3L3F?V`O^*F^)GB*[\1_\5!=Q>+/
MB7H,=SK?_$UN(]#T#6]7?0M&2:_^T2)I6BO>7;Z3IRL+/3FNKEK.&$SREOZC
M/@Y8V4?A&S$=G:H)[NX\X);PJ)MYO4?S0J`2;DCC5M^=RQHIR%4`HKULA_Y*
M+-?^OTOR9\WQ]_NF$_Z]T?\`TVCP#5-=UN+4]1CCUC58XX[^[2.--0NT1$2X
MD5415F"JJJ`JJH`4````4445URW?J_S/"CM'TC^5,__9````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VUO;FME
M>2YJ<&<`````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#,Q-R`Q,#4Q-30S
M-#$U,"`P,C0R-C8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#`1$``A$!
M`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8%A@7&Q\H
M(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K'!@<'"LK
M*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!`P,"!`,%
M!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()
M"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%
MQL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!`0$!`0$!
M`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&
M$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2
MDY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KB
MX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@`H`*`"@`
MH`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`
M"@`H`*`"@`H`*`"@`H`*`"@`)`&2<"@"A?ZO96,'FS3`IG'R?,:I1;.FC@ZM
M67+%%,>*-,(!\U_^^#3]G(Z/[+Q'8/\`A*-,_P">K_\`?!HY&']EXCL'_"4:
M9_SU?_O@T<C#^R\1V#_A*-,_YZO_`-\&CD8?V7B.Q-9:_I]W+Y<4I#?[2XJ9
M)QW,ZN7UZ2YI(THIHY21'(KD=<'.*5CDE"4=T/H)"@`H`*`"@`H`*`"@`H`:
M[JB%G(50,DGM0-)MV1S&H^,;6(,E@AN95."!TK54WU/8H9-4EK5?*CGY]:U.
M=I2TVV*7^#^Z/2KY8GJ0P6'@E9:HH*"HQN)'N:9TMW%H`*`"@`H`3GL2#[4`
M2VMS=63E[*8J['+9/6AI/<BI3IU5:HM#?MO&3B6)+BV(C'$CC^=0Z1YE3)59
MN$M>B.ETK5K35(F>SE#;3@CN*S<6MSR,1A*N'=JB+]2<P4`%`!0`4`%``2`,
MGI0!PGBS6FOY38V,A6W4_O9!_%["MH1MJSZ3+<$J*]M56O1&#&B1`")0OOW-
M:'IRDY?$QU(0E`!0`4`%`!0`4`+0`$Y&#R/2@06KR65ZEW8MY;K]Y!T:AZJS
M"HHU:;IU=4=UX;\01ZNKI(GDW"?\LV/)'J*QG#E/G,?E\L-9IWB^INU!YH4`
M%`!0`$X!)Z"@#A?$7B)[V22RTYBL*G$LO<^PK:,+:L^DP.6JDE5J[]$8*@*N
MU>E6>DW=W84`%``>.M#:6X`/F.%!)^E"=]M0VW)4M[AQE(&(JE&3Z$.I!;L<
M;6Z'_+`TW3FG87M:?\Q&T<J_>B85'O?RE*47LQF1TYS2NMBK"TP$H`6@`1I(
MYDF@<I,G(84":C*+C)73.^\,:P=6M&,BA)HSM8>OO6,X\K/FLPP?U:>FJ9LU
M!YX4`%`&-XKU#[!I,IC<+/(-J#UJX1NSORW#^VK*ZT6YY[;ILA&1B1N7]S6[
M/J9N\O(E12S;1UHC%RERK<ANRN+)&R'YAD>M5.$H.S$I)BP1F0GL/4]*TP\%
M+FYD*<E$Y#QI\1O#O@YC!=7"W.H8SY49SCZU+<*#5];G%7QL8.TF>8ZI^T1=
M2PO'INDHC9X<^E$\5&,OW:/,ECFT^5'+WGQ+^(.KN+JS>:"#^%8UX-<-?-(7
M4922:'3CC*T;QC<A'CCXDLRD7-UE>?NUA_:=):\Y?U?'?RFE:?'/Q78.4U"W
M21UX.]<5ZBS'GC>*1E+&U8Z.)Z!X8^.^C:M+!;ZO;?8Y7PI<?=S3]O!I*VK.
MNACX-I-V/68TBEC22VN(Y$D&Y<-DD4_8-NU-W/35:^C0P@AMI4Y]*Q=T[-&J
M::N2>6H(5ID#G^$MS6KHR32>[,_:J^PQT9&PPX['UK.47&7*S1--:!#<SV-Y
M!=6TA7:V)1V*TFDU9A*E"M3=.:]#U&UGCN;>.:)@R.,@BN=JQ\;4IRIR<9;H
MEI$`2`"3T%`'GGBR\_M#4UB&UK>(_*R^M;P5D?4Y;1]C2YNK,LDD^_:J.Q'E
M?QX^(,GA>Q@T/0YMNM7'S3N!DQ+VQ[FM:CC1C9/WNYY&-QCB^6.[V.1\&?$/
MQ?X7N++_`(3&WFET&X(#S2+R@/?-<E#-(RJ\O-=F$/K.'M.JG;\B/XH_%>^\
M1:I_87@=Y$T]\+YL8P\I_H*WQ>-4(N[LNXJV)G6DJ='5LA\.?"B.0-<>*;F6
MXN)1G;&Q)3ZFODZ^;S<E[):>9[>%X?AR-UW>1VND>#=&TA`MM8128_YZ`'->
M;4Q-6I/G<SV</@,/1I^SC$UD2*)`B6T<:#HH7`%8OWG=G="E&"Y8[#AY?41)
M^5*R[%\K[E2]TW3;^"6&YL;=O-&&<(-U:1J3C;E=K'//!TI-MJ]SEK;X7^%X
M)69EN')!PK-P#7;/-,1)6O8\F/#^'B[V.2U;PSXQ\,7#W^C:G<7$$!R@20DA
M?3%>MA,ZA&2C\+[]#R<3DV*I+GI2YO+J=MX4^.XN-!NK;6;4+K\,9%M(!\LK
M>A'8U]`\?%1O-:'#1QDF^22U[=V>9WEO\0=8O+C5G%\LCDN=KE0!["O,EFM)
M/G<Q_4<PJ3YE%IGJGP(^(]_KU\?"_B9PTT:$P3L,-D?PM7HTL3&<>6>M]F/#
M8JHJCA->\CV,@AF5QGL1ZT.+B[/<]J]]4;W@&[%O/-IS,S$_.O/"CTK.HKZG
MF9S1YXJNO0[BL3YT@OY8X;.9YF"H%.2::6IK1A*<TH[W/+B`LLFW[I/%=!]C
M>Z5QR,%8$]`:NG-0E=B:NCYQ^/\`ID^E?$Z'6[NW\_3[]5\ANP8#&/PZUS9E
MAY.+Y7:YX%O88E3DK_YF-X_\0:M;Z##H=Y=0WIN@&78.4'8?6OF\OP]*=3VL
M4THGK9MC*L(>PDDY2['4?#7P[9^$?#<NLZ\J0WKC>"_5$]/K7-CL6\354:>J
M6WF=V69:L%3]I4M>UV^WD)%XC\3^.KJ:U\#6/V33XQ^^O9N!^?:NBG@L/2?^
MTS]Y]#AKYO7K3Y<,M+[LCM_"7BZYC=M%\66E_=0-^\A1^5-8NKA(3Y:U)Q7<
MT^LX]MJ-9-#I_%?C+P\ZQ^(M`:[C48::$<-3AA<-B9?N:EO(F.;XC#PM7I_-
M%F+XFV+V[23Z7=0RKUBVU-3+:M.?(VCKI9_2G3YDF41\4[B]C=-)\-W3W'9M
MN0*V>4Q6]1',N(DG>4&T6K;XC2V85/%6AW-BQZ2[#@UC++[K]S-29U4<Z]Z]
M6+A%]3N;&[@O;&*\LI5GM)1D8.:\^46FXR1[L)QJ*\7Z,\N^,'@T/$WB'2(E
MC\O!GC0?^/5Z^68UJ7L:FJ>Q\SGN71Y?K%/XEOY^95T7QAK6N1Z;-'<K:V^F
M@?:\G`E4?_6J,1A:.'G)37-S;>1EA,QQ&)4%%VY?B?<;X,E?Q9\:XKS08#%$
M'WG:,`*.I/UKZ'*(/#QC&:O^AY>(Q4:N.=6FKK^M3ZDN6#3L1VXKTJVM1GMT
MTU'4;`[17UO(CF,!AN8>E9/8<XJ5.46KZ'J-O*DT*/&X=2.".]<S/CIQ<9--
M6,KQ@H;P_<@]./YU</B.W*W;$Q.!/6MCZ8.X'KQ0!S/B+7O#,^H7WA;Q'"ES
M<6D!N(@RY\LXXQZ5TJ.G))W/)Q3IU9)Q^+<^:?`]D=?^(1G<%X()2X'7@'BO
MG<WQ"ITFHJUR,GP\L5BN>;^$]/\`BIH]]XE.E6-EGR#,/."]EKPL%B*>&YIR
M[:'T>98.K7A&$7[M]35^+]\/!/PLL]*T-1:K/B,F,8)XYYKFRJF\3CG5GK;4
M\/'N%&G)1TZ(\W_9O\[_`(3*:16?;Y1#G/!^M>MQ%K15^YR9/%.4O0^CGF8E
MT<*Z9Z,,U\BM'>.C/IG2BT5!IVF3S[Y;"!G[G:*MUJK>LM69NA&*T1XUX\^)
M]SHGC!+#P]:6UO;P.!(0@R_M7TF"R5N@Y5V[M'E8K,O83]C"S[L]GO;.QU[3
M88M8M(YH[N`,P(^Z2.U?-TZD\/4O3>J9WRI*M1<7MV/%OA]#/X>^(6L^&=[/
M8)N>(,?NCM7TN,4:V'AB6K2>YEE%:I1JRPKUBM4>@75N+RRN;0C*RJ5(/<5Y
M:DUK'<^HJPA.-I[-'SOX=\.G5_'#>'!?"S@EG*,[-A0`:^UH.,H1G45W8_-9
MTN6O.E!VC<^M/"7@S2/`%@=.TB-9;MP#+>]2_P"->G&<:<?=W/7P>&ARJ:5E
M^)KC@5DE8]$;-_JF!Z&FAQ^(]$\*J%T:$+TQ7//<^6S%WKL;XN_Y`%S^'\Z<
M/B'EG^\Q.`/6MCZ<?#_K!['-;8=)U+,F>QXA<Q+;R?$OQ1,AN+L?N(7D'"`\
M<4ZO[J4IQ/#45^\K=5HCD?@);*+J\O=Q,I4C':OD,XJMR4#T>':2DY29WWC3
M7[GPOHPU2RB6617P5;IBO+PU%5JBI-VN?1YE7='#RFE>QM7UA8_$KX>V4EZV
MUIUWHR?\LGKGPN)GE6*FE&_1W/!E2AC:7JAWPW\#0^"-/NE60323_?G;C`]J
MG,<QEC)*VRZ&N%P5'#I*&KZFY'J^C/#<2QZM;NMMGS<..,5Q.C532<=]CH6*
MB[VZ')Z)\6?"VK:K+IN9+7?E$N)#A6]Q7H5<GQ5."J6O^AQ4L?3K3<%+;\3R
M;6?`6J1_$J**U#:E9S3B5;I1N3;G)R?:OH(9G"K@VY.TDK'E1RZ7UM12T;N?
M2S210(CS2+';P1C>YZ*`*^+C"=1\L%>1](VH09XKX5G&M_%;6M<L<OI2`Q+-
MCAC[5]/B%[+"0HS5I=CBRUSQ.+G57PI61Z#`"96QW!Q7EGU-3X3YTMK9[CQS
MJ:(K%Q(YRIY7GK7WF73C&,7)]#\XFO\`:I^K/I?X0:F=5\%RAY7F>U?87?K7
MH24O9-S7H>IA9NZ39UXZ"N<]`;-_JS30X;GHOAC_`)`\/TKGEN?*YA_'8SQ=
M_P`@"Y_#^=.'Q%99_O,3@#UK8^G!20P(..>::;3NA-:'(>(='N)=+\6PF")=
M%N(=\8`Y+XY-=$%[2]SS:M-PYK]4>'_`>[*:K?6+E1'M)!/7-?(9S3BK3ZFO
M#LY*4HI:'JVJ:?;ZMI\]A>INBE!&/2O#A*49*4=T?7UJ<:D'&6S6IEQ^(=%^
M%OA1;-YFNKHL3#;YRWX^@KJKT:N:UE-*R2U9\K.E0RQ.#DVGKYGF=_XX\:>/
M;QK/24EBA<X\N`8`'N:]..`P>"CSU-SS(8W%8BIR4=+_`)>IM^#_`(+:JUV9
M/$=TUK9-RZ1N<R?6N7&YY2MRT5=]^QT87*W%MU)7\EU.GU#X#Z/>QR?V5?20
MS@?NPQR":XZ/$%:#_>JZ-:F5X=.[31Y_::SXS^$>M_9[Q&EM-V"DHW1R#V/:
MO4E0P>:T[P=FNQY_M*^$?++6+9[5I/B'0?'GAJ;RKD1"5<3VV<,#W%>#.AB,
MNQ*G%:]&>Y"<,9'DINZ*6E:;9:/9FRTF#R;0'..['U-;UJU2M/VE5^\SZ#"X
M6&'IJ$%:PS7+U=-T*]O6<)Y,9()[FHITW4FH+=L,76]C2E/LCR+X1V,NK:OK
M6J3;A$D3,S8ZD]J^\PM"*BE+9'YU2E*=1U7LSZ`^%6GMIO@G,D8B:ZE+`=R/
M>NZK.]+E>Y[.$@T_Q.JZ<5S'>,F_U9IH<-ST7PQ_R!X?I7/+<^5S#^.QGB\,
M=`N=B,YXX`]Z</B*RRWUF-V<`>M;'TPE`R2%5F,EK,-T$Z%"O:M:+?/R]+&-
M:*<+]4?)^IVI\!?%IHI%,5HTW/IM)KR,UPWM:<HVVV/&R_$SPV,36B;L>I^.
M_$L/AG1?[07$CW(Q;KZG'6OE<-AY8B?*M.Y]IC,=3PU%SGTV\V>6?#WP9J7Q
M'\02:GJ[NFFHVZ:9OXO]E:]G&8REEU%4Z>Y\A3PU7'2>(KO1[>?IY'7?%*RU
MGP5+;7O@^`VNE1`!I(ER<_[7M7%EM2ABTXU]9/HSMS"E4ITHRPZM;>QZ!\-O
M&*^.?#DEVZF.\L@!<IV)QU'UKR<QP"PE=4XO26QME^-C5A>VNQY1\2/BEJ6I
MZK%I_AE)[5;=]I9!\TC`^GI7O83(5AKRQ6M_N.'&9A-U?8X>[U^\]BM[$>+/
M`4%CXMM@+F>,9)'S(>QS7SKK/"8ISH/1,]2KAE6C:2Z:H^<?%.@:S\-/$ZM&
M[F'.Z&8?=D7T-?84*E+,J%[>OD>!+VN6UU.D]/ZT/:?!6O)XJT".^C`6=/EE
MC'4&OG<1AY4*CA(^VP&.AB:2G'KOY,\V^-'BZ"\":)I[%EB;,[@\$^E>KE.$
ME?VTUZ'SN?YA?_9X/U_R/6O@+X4?0?!9N=4B4MJ`#JF/X3TK["E%4:?/+[C@
MP&&O&[ZGHR*J(L:#;$OW5]*QJ5'4ES/Y'LQBHJR%J"ALW^K--#AN>B^&/^0/
M#]*YY[GRN8?QV:<REX75<9*D#-2<D7:29Y?>6\MI>RPW./-)SQ72G=:'V-*I
M&I34H;$/?`Y/I0622(T`1Y6"..50GDU;HSY>==.AFJL)/E1XY^TEX3_M+1(_
M$%HK&>WXE4#^&MZR]M24UT/(S"@W'F['@\FI:EXNU'2=.N9"R1[88E'0#UKP
M(8>&&C.I'=ZLXJF*JXIPIS>BT/K?1]/CT;0K+2X$6-88P&"C&37P-:JZU5S;
MOJ?848Z)OHK%F1$F@>"X198'&&1AD$5$9.+YH[FMM;K<I:/I&FZ'!)!HMJEK
M#*=SJ@^\:NK5G6=ZCNS*E0C36BMJ$&BZ1!=/<PZ?;BY?EI-@R36L\=BJE-4I
MS;BM@5)*I[6WO=R\Q+=>W2N8U6AD>,/#EMXN\.W&EW0'G8W0RXY0UV8#'U<%
M4YJ;]U[HY,5A85HVGLSYK\.^(]1^'&L:M8F`22,#$0QP`>S5]=7P]/'TXU(N
MQ\_A\5/+JDJ;5_ZW.H^!_P`/G\8:W-KVO0G^QH7+MN_Y;29SCZ5[>%H))7V2
M,,-"5>LZDE>[/IH%`BQPC;"@PB#HHK2=3GEN?1QARH*10E(!LW^J/<]AZTT.
M.YZ+X7W?V/!O0H<=#7//<^5S"WMW9W-6I.(X3QI8O;ZC'=1[I#,<;?[M;TW?
M0^DRJNITG3>ECROQOX_DTB^&A^$K%M7\1/P4496+W-=5.2IQ;M=AB<1*W+#5
MG&F\O?`.L+XG^(>NK?:Q.A":1`^[R\^HZ#%11FX-U*FES@C:D_;5):OHBM?_
M`+1,-Y9W5K)H"/!.I4JQSP:R^LR5^4F>.C=<J.1^`FDPZMXUNKUH-MO`"\>1
MPASP*^=SG'SP]#DCO+<WRB,75E-QOV/HMV+.2>O2OB4K(^I2LA*8!0`4`%``
MK%'5AU!H8-75CP7]I/0HK76+'5H4PMRNV3`XR*^LX>KRE3E!]#YO.:<FHU7L
MM#K].^-_AG0_#VD:5I]@YBAA`F"+@;L<_6OKJ5:$H>^8T\71IZKM]QL:#\;_
M``IJDICU(26`SPQ'%:SJ4)6C%&]/,(-V3^\])@>*YLXKRPF2YLY1E'C.>*SJ
M4O9ZQU1Z%.M&IL%9FQ-8P376J6T5M'O96R_H!0VDB*TX4Z,I3=CU%!A%&`,#
MM7,?&O5BT"*&MV;7NG30HP20CY6(Z546TU8Z,+65*JI/8^/OB%\1M'\*W5_9
M^"HB=<E+17=^Z\J>^T^M=U>MR)0@SOQ6)C"\:>[_``.*\%^`]0\52R:OXAFF
M6%SN#2DEY3^/:OE\?FKB^2D[OJ^QW9;D<JC57$Z1?3JSI/&WA#0?#OABYN;"
M$_:2F-S\UP4<97KUH0D]+GJ8C*\+0H5*C5M-#;_9P0#PQ>,(SN:8Y?%8\0O]
MXO0XLGIQ6&Y^K9ZN2!7SQ[%B189&!9ML2#G=(<"B^MD9RJ1CYG/:MXT\,Z0&
M^U:M`9%.'13DBNNC@<15=E%F53$0IMJI)(L:9XH\-ZJ(_P"SM8@D9^@+8(/I
M6=3"5Z;M*#'0K^V3E"S2-B2-XB-X^4]&'0USIHVC*,M@10Z2IGYF0A?KCBGU
M3)JWY=#P'7[W4M1T#Q!X=\1.C:C8RF:WW=2GM7UE&E'VU/$4%HU9G@UIRI4:
ME'$.[>J*WPO\&:'KWA62\U%':Y$I7(/05KF&-JT:W+':QOE&64<30YI*[N;V
MI?"C1;M66PD:W8CY68]#7'#-,0I)O5'J5,@POLVK6?<YK0-?\1_!_P`1BTO2
M]QI,Q^:/.4=?5?0U]/EN9PJ*ZVZH^8G2JY?5Y:FL6?2NC:U8:YH]OJVDN)+>
MY'R)W#>E>E4HV7/3UB>UAZBJQT>G<]#\&:3-IMB[W6//F.XCNH]*XZDDWH>)
MFN+A7J)0V1T59GE!0`'I0!X)\9/@[X?EOV\8VZ"V>W;S;R!1\DWOCL:XL>YQ
MHOD/5R2G3GBXPFKW>ASMW?6=MI*ZA<2I#8!-R`'`^E?)P@Y-0BM3]!JU8T%)
MR>V[.'\?:M9>(?`MQ<6#AE3L*Z\*I4L5&,U9GG8Y1Q.!G.F[JQPOP\^)]_X.
MTJ73X[=)K61]_/4&O9QV4T\55523Z'QF#Q_L%9JZN>D3_'/3(=+22*Q,MZPY
M4]%->)#(*LJK4G:)ZE;-J7+>%[]CSC5_$GC3Q\1$C7#69D^6.$%57ZFO;I8;
M!X+:USS92Q6)CS):7.STSX%,;>.74[\F9URRKV-<4>(Z=.MK"\$=E/*%*-ZD
MM2AXK^"]WIUJ;K0[EIG49,>>?PIT\_I5:CYHVBWH7+)[0<J4K,/AO\2=5\/:
MG'H7BYI7T\G:&F'S1'Z]Q2QV4T:\'5P^YGA\;4H3Y,1OT9[/;^*?#LUP%@U*
M(D$$98<U\U/"5X*\HGM4\2JONIJYY9\?=$CM;@^)HY2C7:")-IX>OI>&L14E
M"=%.R1Y.9X>E"'M;^]L3?!2*1/!,FY<;I25]Q6.:R3KZ=CU^'DUATWW.HMM<
MTB[OGL8+M&NU."F>]<4Z%2$5.2T9Z]'&TZM1TX.[1F_$O28]8\(7,=P0KVH\
MR-L<Y%:X.LZ59274YLRPD,10E'YHZ#]D7PWJ$OA^ZO=521=.\W-JC@C)[D>U
M?;PQ$XTW!;,^%HXV5*E*E'=L^FATK`X0H`*`"@"&\M8+RV>WNHEEA<89&&0P
M]ZF45)69<)RA)2B[-'RG\9/@;X@?Q"C^%YI;CP[<ON>VW\VA[X'<>E<4Z=/"
MPYH0NSU(8FMF-50Q%3EC_7XE.R\&:1I?AW4-*L))9KB6,K()>H;'85\Y/&3G
M656:]Y=#[*EEWL\*\/'2,NIYG\*IM"M?$=UH?BVT$EO<,8DE(YB?.*][&X>M
M7I>VH3Y6E>W<^0P,E1KRP\HIN]CV_3_AEX0TJ5FCLOM6_D-)SQ7RKS?&2CRM
MGMPP5+F<E!)G465M9:?&(],LHK5!V"UPRG.;O)W.F%%1CRMZ$I)))+$DU-C7
M05'=#E3^=%A.*>YA>*O".@^++-K?5;402]5NHA\RFNK"XZMA9<T'?R.7$X;V
ML'%J_P"AYA+\`[G[26L]<46H.?,<8(%>W_K$GI[.YXW]D\MK3=SF/BEK[:BV
MF>#=-N?MEOIQ$?V@G/F/TKNP%#V2EBZBM=;$XVK&JXX2@KN^K?5GK'A739-$
M\/V=G,5>01\E?I7AU)^TG*?1L^TPV'C3HQI+HM?4\G^(/@6\\-N_B+2KO]P9
M=Y7=AXR3^HKW,%C8UU["NM;?>?+9EET\+4>(PK>FK\O^`?0'P2\/S^./#=CK
MOB>W:.W7Y8X","XQ_&?:HI9/:LW-^ZMBZW$M\-[.BO?:]Y]O0][M;>&UMT@M
MHDBA085$&`!]*]U*RL?*$M,`H`*`"@`H`*`.+\3>`M/U2XEO[5?(U`J=I7A2
MWO7EXO*Z=9N<=)'T&7Y_7P\51GK`^7/C1\&?$.BSV^NZ=$;QYY,2I:H2T;]C
MBM<#1JTZ7LZVIAF^-H8C$JMAER_Y]S<\)?$F/2[=-"^(=K<:3JMN@V2RQD!U
M[9KP,?D56,W.CJGTZG9A,VC4:YW9]>S/1=)OK36+'[;I=Q'/:_W\XKP*D94Y
M<DU9GMJHM//L6HD,QQ&T?_`FQ4MI=2IR4%>0YX'3.YHN/1P:+K<F-6,MALJ1
MV\)FO+BW@@`R7>0<"B,N?X=2766O*KV/%?B5\7;5(+S2/#I,H;*-<@\'UQ7T
MN!R.5XU*KMY'CXO-X*+5+67<XOX1^&XK[5O[7UDR):P'?&=I_>-7H9KCHTH^
MQCNS7(\GKUFL7):7T\_,]\TNRU#7;E%TNSD>WD.P7&/E2O"I4:E5\M-:=SZS
M$5Z&$@W6DDUTZL[G3?A+:WL$/_"4N+IHGSY2'Y''N*]W"95[-\U1ZGRN8<2\
MZE3P\;1DNIZA;6\5K!'!;QI%#&H5$08"@=`!7M-W/D4DM$2T#"@`H`*`"@`H
M`*`"@`H`Y[Q-X*\.>*)X9M?TBUO9H>$>1>0/3/I3C)Q=T*45)69S^K_"S1[S
M4K"YL6?3H+;@VUO\J/\`45Q8O`T<5?G6O<]#+\QK8)ODU5NI3\;?"/3_`!)I
MOV6#4+NP;.?,A/-<F!R3"X6?/:_J;8C.<35I.GW,GP_\#;/2H4CDUS4+G:.2
M[=:Z*^68:K4YN6R[$4,UQ%*E[.]_,Q]4_9PT_4[^26Z\0ZF;=SDP;OEKO]EA
MXV=.FD<53%8FH[.>C%L?V9/"5N^Z:>ZFQT!-95H2FK1=BL-5C2J*<H\UNC/5
M/#G@C0]"T6/3+>RBD@7J9%R36%+`TH1::NWNV=N*SC%5ZOM.;EMLELC?LK.W
ML8%@LX4AA'14&!73"G&FN6*LCSZM:I6ESU'=D]69A0`4`%`!0`4`%`!0`4`%
M`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`
M4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`
M!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`%`!0`4`?_]D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V5V:6PN:G!G````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(P-"`Q,#4Q-30S-#$U,"`P,C,W
M,C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MVP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`
M'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%
M!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*
M%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U
M=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&
MQ\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!
M`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"
M`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF
M)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$
MA8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4
MU=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^QOQK\3;/
M1M3UA;2)KV^-W*4MK8*I,:2-%''///)&\0+H6S"CMDX(``KY%\=/\0?BQJ<5
MA?SM;>'X+ED.@Z0^P72!\(^JW$3^;+"Y12"ZYAW.8RS,6KS3XB_%#Q5K6JZI
M9^'/#MCI]AYTACUO5KN:YOK_`'R&22YC*"WEL^3*%1F=BH7H*]]_9X\0V]U:
MZ;875O&=9A6!-0D>1Y);[83YLLDC,74K\^R,G#$@D$9S_&_$/B)AN),\Q.2U
MJV(KY;5Q57#NE@ZDZ6&KQ5:=*F\54NZM:BIVJRP=**IXM12JRJ\\H/\`7L)D
M&)RG`4,P5&-*LXP]^:4J])S@GS024HTZCA+V:G43<;^ZURJWRG\=_B+\0?V<
M/#4/B#P1X>37=4\M=/O':TNKFP\,:;"?.6+2;>V"W+L&93<,LD:SO)))]]WK
M\YK?_@K=^T5I'B:RMI[SPEJNB76HK#>:!<Z=>_;/*!!DA:XD=;J*<H\"IA72
M-OD:-Y`J/_05^T%\/I_%'AW4(M(M[9M2NM-NTMXGCD"O/)$/LL8EBB),Q?RE
M$>?D!8]UQ_'C\=?A5\.OAWK7Q*T?Q?H/C[0?B(GB*YF\/>+=)U:.?28+_=]H
MU+1?$>E7=U'=VL897-O=*B(--F8LR,8I*\#-<#CN'L7:..S:K1E-<^(H4E4<
M\16<6\34HJO[\'RQA]4H0J5%2H03PLJ:ER>[ECP.:8=*6%P;JITZ;G6Q'L'"
M%E)3<^913IM*"E-<MYN4WRIG]//@OXQ^&?VIO@G-XCTV2"RU._T@6>MV*1NZ
MV=U,B[K24*L+1S6LL1'EE`6/R[QC)^./%?QX\2>`?`L_PIMIYX=5AUQK>WU.
MVD/G?V)"PF@1)/._=.)E0M(2WRK\R$'%?E!^P'^TCXB^$NL^(O"M_:ZCJ-IX
MML`8G#3W&DP2VS2VEO?W?D"4V_VA0DZW'W/,<AWD<&,_H7XF^(/P-\0>&9Y+
M_P`3Z+_PG\RS7BF^U$6J6L4:AHDE^9"_FDE45!N9]HP02*^2S?-,9A<;4HX3
M&SPN:O*\5A:^/C6@J6/P=>FG&$G%QJ5Z\KNE2]G!\U2C"M4^&I&'KY?EM&%!
M+$X9UL%]>IRH0F[3HS4*<E.I)<KE15.JFU?EJ*<7;16YJX^-?B&>>>:;6BTT
MLTLLK,EX6,LCL\A8J^TL6))(&"<D<45\X2^/M%265!=K($D=1)%J*^4X5B`\
M>4SY;8W)GG:117SB7$#2?M\W=[.[JUTW?E=[*HEK>^B2UVUU]%RHQDXK!X2R
M=E_LN%>B:2U]F^ZZO??M_1%!\'X=3MI+T10P_;(3,&$30*%D9\00Y&WCS0Y*
M9.XEAP<5\X>*M9U'X(^+K-UC4O([R0,DFUKC[+,#Q(?E*,THRA52R@C>!D5]
M90?$`_V/::?]H;$4=M'$;,9V-L0"-HINL@(^9U;:W`S7D'BSX<VGQ!UZSU#Q
M#OFTZT\QA`L_DR/"58/'*I=2$:148JK,#@$G(Q7O<283*L#A88O)98JCF<9^
MUC6J23A&;FU6O348\SO:=.LW*$4ZB:JKV<*?A97CJG-['-;5,$Z<82I03<Y<
MKM%1YK+=1LW9W2OH[GE<_P"T5\1/B#))H7@FVO(_$-[.8UO;RZC33[4P@EXW
ME\MVMWCDB7RV#,=K;<D'CYF\7_L)Z3\7?$.K^*?CUK5U<^+]5_<1?\(Y(D,=
MF)G"O>W,H18KB[:-%1'E#.%=\,HD85]HZKXX^'OP#18]+T2TN)97E:6PLPC7
MT[I(Y/D@^=(TA5F#X*J1SA>:^<?A_P#M7ZS\;O%_C<Z/8^&_!NB^#]0BMIX]
M;U>V@U^_DN#F-+'2YW\IWMU?<)0Y5I#$FW<2M<7]HXGZK@\9BL;F>/QDJC=+
M"PHU:6&IT_=E.O.-6KRMRNJM2JW>'+*<$W8[J5-_OE@<-0P.$G*%/VU62EB)
M2E9QI\\:<^2/N\S5I64?XEOB^>_B!^P-\(_@[^S_`/%_Q!X:U7Q*_BN+0=3^
MQ^*-:N9/ML:V\;36>CV5I:Y@(FD9HI)HXU:8-&IPBA1^0_[(_P"S5XF^-'Q1
M\/\`A:VT3Q-IK:'<7&M>//%%[J31^'8_#,%PL$4(LY;83C4881)]I@^ULINS
M"$5(RT9_HU_:1U+QS:_LYW_VF(RSZWK-OB86\<K7EA?75M%;110*P9FDE*RP
M@`$D@'()%>>?LA_"KQ/\-=/\9>._&U@VBR^)?#1M=,TR11;3QQ0))/+=:CN#
M,91C:H)'#[,8.![W#&*S#.\XKX*658NCEOL<&\=6E3EA'AYTZ46Z<G!J-6$E
M6C1HUYOGE",ZU)-\J>6/]GA,JHU'BZ;Q2Q57ZK153V\I4JF)A1E-0M_RZC0;
M=9VLFTG91.#F^"/P)TV:73H_#27D=A(]DEY(B^9=):L8%N9/E^_.L8E;_:<T
M4Z[>Z>ZN75$*O<3,I:4HQ#2,064(0I(.2H)"GC/%%?I7/P['W?JO#ZY?=MR1
MTM96UQ+VUZ]]>WSEL0]?K>(UL]95K_9\M]O73N?;6C7NC:REIJ5K<K-IT,D5
MPJI<%D8QJ%AC*MRH=B78$8(8#'R@5TGC+XDZ?X6TVZDNUC@M+&`2.T4K32%8
M2LTBF)%,K;\`,RD*5)!!!K\\?V=?B]+8>(+7PCXEO5N;._)_LMKDA;?S%+RK
M#&3.'D)DD*/D,(T1&(`-??5[X%LO%=M),EI:7<=W;^8EO,RW+-*S$E8KA8BT
M43("L<F3$RY0.6X/Y7A,5#B:C3Q.`HQ]O33^L4ZV'A-J4J=%N:P\VX^RJOV-
M3#T5.TYNU1.+DCV,5@991BWA\QE>G"5HNG*2C.',K1]JO>5M(3]UV=U:2U/&
M?#7Q.^%OB&];Q;X@NO#NBR337-K:W?B34(@K+#(T=R;:UOL>6[I'DGCAN.K8
M_/']O3P-\+O#FJ^!_BI\(5T>-/$FKWL'B6?PAJZ7^GWDD%M#>V>H7EO:R-;V
M<J74#JZ1-RT0<XD+5]"?M*WOQ/\`@>=`U2+X.:-KVE/=SB6\N=*MM>T:2QAR
MDT+1VL3O;R",K'(I"RPL7:0`FOA[0]-\,_'GQC':?#[P=XM^'VJ^*M=L9_%7
MA+27>]^'>IO.&,\PL+S-SHUSB25M1CM/(2=XS&W[Q'->-*>=5)TL!BL+7EC8
M8VE'ZO5HUX5\33J0C-PG2P3=256NJD882A'#2HU*G*ZN(E"G*M#W\)1P=%5<
M<L7&GA)X:?/*-2%2$91IW5U5A%\T;;N2<E=W5]/T5_9_B^*WQ@\%>&=6^(&K
M1S>!]$;2KW3K>>SFO)]6N]+ECGTY;>1DC2.WMG@$=V&:0H5(#$8-?6OQ0\2Q
M6WA&\2)$DGGBFLC&DS%C,%W2H+63=(%*DC@\\`9.#6OX5\,6_P`,?AUX?\*Z
M1L:+1M(M[2/S558S<0B,,QD"2,P-P[I\S*Y==K3R/R?`_BEK;ROI^G>8\;()
M9S;O+$R-<7)7;/(P;S@A$P="XV%03G:2:_>,-@,-PID-2-*E46,K+"RQL:^(
MJXSV^95(0HVE*M.JHSH7A3P].E*-.G3I4I<THTTG^?3KU,US"GSI*FN>-",8
MQ2HX6,E*%.*C&/Q2FY5)-WG4J2E:-[+PUKB0LQ\MUR2=OE70V\_=QCC'3':B
MK[1W(8@^43DY(GM\$YY(^?H3R**^"4<.K*5>A=63O.@G=<E[^\[.Z=]7UU/H
ME"EI[E?I_P"V_P!WST^79G#_`!.TK2]*\`_#/5M+TVPTW55U>R*ZG86=O9Z@
MI:*'<1>6\<=R"V3NQ)SDYS7Z>?!*1Y=/T&25WDD:SMMTDC%W;$7&68ECC)ZG
MN?6BBL,E_P"2AP/_`&+LN_\`4+#"S;_<7_V%XK_T_4/<O$EO;W>CZY%=00W,
M:)>[8[B))D7<)MVU)%95W8&[`&<#.<5^2/[,%G:1_&SXNO':VZ-;:T3;,D$2
MM;G[1=C,#*H,1QQF,KQQ117T]3_DY'"O_8=F7_J!5/*H?\DYFO\`U^P__IR!
M]T^,W?\`X1[S-S>8/L@#[CO`:YA+`-G<,DDGGDG)YKXV\=2R'7M0S(Y_=V:?
M?;[A3:5Z_=*@*5Z$<8Q117TG%?\`R+,/_P!A%#\XG'E7^]K_``K_`-.4SDB3
MD\GJ>Y]:***^=I_!#_##\J9];'9>B_(__]D`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T
M87)S+V)O>6%N9'!C+F=I9@``````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,U
M,2`Q,#4Q-30S-#$U,"`P,C0U-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA0`!``-4A`/_>.?___P```%)24JVM
MK1@8&#DY.7-S<U)*$*V4*>?GY\;&QHR,C#DQ"!@8`,:M,7-C&.?&.8Q[(?_>
M4G-C,:V<:U)**5)2.8R$2CDQ(:V<4L:M0JV4.7M[>XQ[.:VE>XR$8P``````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``"$`+`````!``$``0`;_P)!P2"P:C\BD<KD$.!^"J*`@-1BDT<,`RXTR
MOT6G.-'H*@)HQ>",;J<#!$%#3!=/P,1Z'<)P^]L*5`,$!P<$;50/>G1)BXYT
M4&YQ$(^.D6@+`H=N6T<3E6((FP.9!`-S>J)M%72J:`,%?P)X0Q=J;@8#?VB$
M!`D`$0D0&(,&``FZNY*T>4X($`D.!@RF:`=G`\S:S%13`X,$#`IJ`KFP40[9
MVV!C6(-=Y0P#?0OU"@0*#`?=L^N->J0.;=F%SXT"`YLP"9!0J0FH.IJ482I`
ML<`!!Q$624@68(`#"$H>+DH0D0$"D7I(+F@C@".O?DP^)6"PLHT!-E,*7`E8
MP`.D_P2*'B$PI\Y?`5,%&B!PH.\;Q:`(_$EM=NQD,`=E$&A%8*'`U*](!(7H
M)\6!!`15BH+]PB_*MV]7<L*KLM:(&"A2VL)C,-==72$0W;XK)[&-J4);&F34
M,U4/A"E8:K99@/`/3317@CK2]NAF@'J%)\?RX[%A3)%,0^_29[:.5FB_G"3Y
MA%*,!`%_MIA=_#`BFI:?QQH(4[M.@TT'3A9WTH#C`=Q^8`Y9GFY<%+Z\(6F9
M1Z$5QS@)7ZE%0AO`@S+@#*%I>F]`;``4T#1?5>?!6;>O_`$8))F`@<_A(7(!
M!2`PP$%*"!&@X((,$K`.!(2P$0`U`?S7D1@)-JCAAAKJY_^,,P+YQ\E?VY@G
MP`']39-0+B2VZ.)?PPTQG@$6O$B+7E7H1,`"6L3%A5<V&H'C%`901`@5%4DQ
M7HNRA>"C`5H8&4<YS_75DHMT.`#/D.=8&6-==-SFUI1SZ;1%%$,R"0PT4ER#
MA7^2%<:7''6`58>644#)ETMJY!+@9XD\<L<ZJ701)R9_$##:%I0\0F@="11P
MQI0$A;=20@=AY"AG>L3W"G2J$>*'`0Z8AH=0ATITSP'B&"2`<IM]49XC$8PF
MIP('Y%+(&6HX\%ZL(:$D@:W*A*/``A4AH)D8M0X0%T,.%=>`A7Y0%D4#$F2@
MU+)T'-<&+%?\LQQ)I+VZ'*@!"-#_`2=7`K:<&.@6T&AQ$E`;AX2O?#EK<:X(
MD%UM)WY+;1K2A?#N`Z080L6O]4'PS![$^M8&`T`2)U*]'9FBB0'SUF'*(*R$
M<H!AZ*)1L;B0GN7`**5\0T<P'ZQ,GQC3SN/?7*<>,_)D.V?<'C024*#@`0]8
M0`T#';LVRCH31#"(&X5@]DT?F,"Z004,!Y,`27UM,\$@5`>@0,D&#=+`UB__
M@DRHVR`00,\=X=@`158H5087"-QMI1?::'`--0I"60UEH1#UUN&()WZX/P]L
MC0H"`VQ'S0*F.!#D%Z'\H@K8U^1W>1,D74:.>M9T]+E#":#5$DVX4KE`(*>C
M#BL")-%!!E+LN&\3!``[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O>&5N82YG:68`````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,3<T(#$P-3$U-#,T,34P(#`R,S<P-0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$@`"``]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_
M`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF
M`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_
M,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF
M,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___
M9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F
M9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_
M9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-F
MF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_
MF<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!F
MS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_
MS)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]F
MS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/_
M_V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF
M_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(?D$`0``V``L`````"``(```"/X`L0D<2%`@@(,(#Q9<
MR)!@PH<(&THTF'`%@!48$TYD^!"C1X\1-SJL^/&C0I$4+5XTF3$C`)38#JI4
M"5&C2)DUG1S4^?#F180D=N9QXH34T*`G)SY$>O"9TV>D>F[\N9,$49UYGN4!
M8!7IU)\ZNP8E^HPKUZT^#VX=.M3)4*UDT7X5FH?44U).GD*5JQ2H6U)V]]H%
MC/?E5XM6\]2U^]>IT:0-$2)VJQBPWKV0.:[D2D)QW3Q/0F<M;%BB3)6)%WMV
MK--B7Y<D.B^^O/7G:XLKNE;62]JUZ<VYKS:&RM/V[Y96*0LO3K5T0<D'4W]6
M#'UF9IPT*2]^C!W`$P!UG5KCC`Z`LF6HDD%^#T^Q.8GUYYW67HD8?LJ$[\O'
M=\H39/ZZ,=44VW?[:95>?0!$U1Q"5^EWV3/%940-->DE1)0??E"#U5-9&0B=
M$QGFA.&(%!8EF(>G`1!B0```.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A
M=&%R<R]V86UP:7)E+FIP9P``````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`R
M,#<@,3`U,34T,S0Q-3`@,#(T-#(T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/_8_^``$$I&248``0$```$``0``_]L`0P`!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``
M$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!```````````!`@,$!08'
M"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R
M@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2E
MIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S
M]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!`@,$!08'"`D*"__$`+41
M``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'87$3(C*!"!1"D:&QP0DC
M,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:
M``P#`0`"$0,1`#\`^C?A5^Q1X:_;7_:2_9[?]H#P%?>,OAA^PC\&?A9\5OC+
MJOB731X6A^*?Q-UOPWI7ASX6?"/7!K"C4H9?$>I^&=0^*'Q!TWQ(AN+SPXN@
M:#;V$\?C&TM[W]@_VPO&GA#Q9\3_`-E[P/\`''QMX9\!^//BIXQ;PM^Q]8Z)
M<W7B'Q!X?^('BWP7K%UH?CC5/!^GZ5#I%G#97>AZ,_AVX\3:U>1:CJUQ/I.E
MZ%X/GDT^.3T_X0_`?5_&'PHUZ^T"&]T]OVCOVGOVH?C)\3GM(+^TBUK5]=^*
M.O>$/!MCJ&N?:(]0T[2-.^&GA6TTW4C:R"^;3;*6R\.S6>IZM`[?GW_P4Z\5
M_`O]E3QW^P_X"L-)L/&/Q#\0_MU?L>WGCCXMZ\]M::UX?N=(^)7A:W\/:%X=
MO=)B&G^#O"HT*/46L/!&B&UT71=`FB2:"-=)LEC`/S\M;?QA^T_\?-+^$/B*
MV^.'_!3?]KN[\.C4/B9X=\1>/?$/@W]CS]D?1;W4I[>+0OCK;:*?`/AIO%&F
M3VVOZG'\+]/N-$N[F"YL]/UFX\9:C<3F;V>P\0?M2_\`!.[QSX&^"_Q9^!7P
MM^#^F21:M\7/@N_PKEU'QI\%/&'Q)\!S)XMCT+1YI-,M_$7A_P`3/X1/CG3[
MV"]T>Q%S80VIU/538:%H=Y/^MW[.WQS_`&0?V+/VW?'7["-\=$^'7QQ_:S^)
M'Q-_:!T&]DMQ;Q^,?$6IZQ/:^%?`MWJEP%3^V[_X=>'=.\1>`89)FTG5;/2?
M$5@T<6O1PQ7'V?\`$_X-_"GQU\0-)^!?QS\'P>//AYXUU/Q!\3_@9-JG]H27
M7P[^(.D:)K%KX]\.Z9K.GS1W^E6PT/6;WQ'X9M;J<V)M=5\3^&8;?^R/#>EV
M@`/P'^#W[8'PQ7]H/]M;]M?X:_L?_$KXE_`GX#ZOJUCXV_:!U+5[^U>RU,ZO
M/K?Q!C\%:UK/G^+?%?B'18"FIZUI^@OIWPX\#_#T6_AW3[833$:_^U?PJ_:&
M^"'Q2^)'Q0T!O&/A#Q7^S[\8/A]XB\27.D^*&TR\\,0WVF:/#JGQ-NM0EUAA
MI\'@OXA_#/Q%H?BC4=-U)1I"S^&O%VLW%OI,,TUK<_:GPU^'?PE\%_#";X0>
M#O#V@MX&\+Z1>^#?$.BI9Z:]EK+MH\-MX@C\1M:VMOI^KZSK%G<K-XPG>*;[
M1J-Q<V]R\TL4JQ_RL_L%?\$P[GQ9X2\;^%?B?XHN-3_9@^*?QU^(?A7X&_"K
M3=<ET>3QKX"\)S^(_`D&O:EXSL=4T[QK+\)=)^%.DVMY)X?TFZBL?$?BJV\)
M:!?Q3Z4JP(`?6&C_`/!,+_@E!XVTC2O&?P\^/'QOTGP!XNTVQ\3^!M*\%^/M
M2/@[3/!^O6L6J^&=/\)F_P#"=W?'PS9:+=V5MH)O;JYN_P"RX[7[1<33;Y&*
M_H!\(^`?A9\/O"GACP%X3LO#7AWPKX(\/:+X0\,^'T:YC70O#_AK3;;1M&T=
M8YM96:-=,TZRMK)4E42*(`L@#`BB@#PS]A7QB?%/P+U_2;^6W.M_"CXX_M)_
M!OQ'+]F6W6WO_A[\;?'&FVT\T+EG"WV@Q:'JDK.1]LBO;>X?=O#G\??VH/V0
M?"7[5?QN\'>&_$>K:U;>*_%FN>)OB%IVOKY6H77@N/6=8MK'PSXFL-'O/,CN
M-9\+:5J5O>-J*B*ZM&6"UM9OMUUI[0?9?[.OB!/V??\`@HQ^U5^RQXDE,WPR
M_;6TO_AN+]FSQ'%=O+H&L>()]"\*_#O]ISX:6&K0.8&U>UO]$\(?$[3HH)OM
M5UX<\8ZAJUD!'9W!B^A_!GP=TJY_:^^(?C2:6673?"N@:'X4T.U\J/[1#>:`
MOA/QN+&>1@3-;1#Q);-;G)5HC"[XF,I`!_-5^WC_`,$R?VI_^"L>F?#+]L_X
M?>.+/X>_MB?"F2^MH?A+KNJ6O@S0]<\*:-X\\0>-/@IXD^&?B_0?LNI^']2T
M?0+:UN)[W6AJ_B;3?&?AW5-+U-9].6[+_8/PY^.'_!4OQ[X3_9A\'?MQ?`+Q
M#\-/B[\&]8\1ZKXW^('P)UBTU7Q1XDTG6?AKK7@/P1K.N:DFIZA\./`WQ"^(
M.M:KJEC9>#I?$.K1:_X@@T76YK/P;H^LZ#IUS]H^"O$47PL^.OP"\5V6BC5?
M#_@+Q9^U/\"/CQK+74LFH_#KP]X2^*.H6?PN\5W.GS2_8-/\"65EXW$FM:XJ
MV7]B#Q*)I)I+.[N%B]F^,WA#5].M?%_[37Q-^.WBCPY#:_&'P%=:7X1T#XMI
M;_"2T_9F\`^/+"]NO#6K^`K:ZO?#OC#Q)\0?!'_"5^-]=GL-.U;Q'XAGO]*\
M/"X31]!MK``'\]'Q<_X+B_MI_MC?&?X=?L=?\$KO@1\3O@?X)U+QAIWA'QM\
M3_C%\,)[SXVWNGVFO0CQ_>V/AB_74_!_@C3=.FDU;3?$FN:YJ.L^([[Q+<7T
MRR>';$S7.E?;W["/[4=O^V/_`,%,?&GACX%^$M4\)?L9?\$YO#_A_P#9V^&&
ME7]I!:WWBKXA^+M>\3:)\2?B'-;R&<6VE2W7AFXT;139W<SW.G::U^PLY-3N
M=/MO7?CK\9M<^+G[.7Q,TO\`9<\%?$G]DO0OC7\49/`VD^-$O;[P/\1O''BS
M7=!L=9^(OC3P/I4+VVK^!_A)X(\-:GX@\4^(O&\_]FWOB?QA>6<&AVT`OF:7
MH_\`@BM^S/X<^!GAOXWV?@^PD3P[>_%;X:V%K=0R3ZA=;_"_AOQ1XIUJZUS5
M=7D>_O-7N]2\2@:MJ-U<3SM?M+<)<!+I`P!Z'\7+SQ`/BM\3A#?7ZPCXA>-!
M$L<>K>6L0\2:D(U3;=!=@7`7:`N,8`&!17X]?&K]J#XZ>*/C)\6O$W@6#QE?
M^"/$7Q-\>:[X.OK/2M<>TO?"NK^*=5U#P]=VK0YA:VN-(N+.:!HB8S$ZE#M(
MHH`_1GX;_LS_`!R3]E/X8^-K;XAZMXHD^%WQ!\3_`!1^#6LIX?U/7?B7^QC\
M:?AQXC\1^"-4\.:18P+J/B;XH?LX>-X[+6/!/QG^$\D)^(-GX3US5CX9M?%.
MHW"6VD?J=^QQ^T'\.?VF+37/B!X4U+0-(^(_A[7=6\/?''X4)JL&J>(OAY\0
MWTKP997=J]U:;&U3PGJ=GHMKK7@WQ;)8O;>*?#FN:5-##X?UN#7M)M/%/^";
MG[0_Q8^*GP]\9>)/C5\)+SX>Z*VIS>)A\5+>32X/AUXT\5C6-6\-_$:[\+P0
M:G;ZUI8O?&.DZKJUU:3:4(+74-3UN)YW@D1:^_[KX+_![7?$-A\1!X&\+?\`
M"8V]A?0VWCCPY86^D^(YM/UE0;L#Q%X<CL]3OX9S-<362R7L\*27%Q/&%FEG
M)`/BOX7_``0^$_Q4^+'[3^A?$;PA%JI\#_M(:QXSLV.N:I9Q32_$7X9:-87L
M&KKI6KV]I>Z0UG9MJT>EZA:((]3.D7UQ&U[:0SU\BW_[/5KX;U'PL?@OK&M>
M$Y[[3=*AU33EUZW\1WWBC4_C!XN\2>&?`_P^E75I[V7PQ#?>`[%OB'\1/%:2
MGQ+I?AWPT]SX9ET_4[^]NKGNW\3>+?V:_P!LWXF:C_PG9?X2ZW\1?!Z^)O!T
M^MZ-XT^/GQ!U)?@W96?AWP]X2\(:A?1>)]?\%SW&IQZX]SX:M]5\67NL>!=7
MTMT-G`]O-[EIOQF\'Z_\;['XM7WAWQ3\,?@#\,O"WB#5-7U?Q1\._$&BMK_Q
MD\:Z)X4TVPU3Q=#%ICR^!9/AY\)K.32S/XXN-#N;"W\46MO:V=CI$=B]R`;_
M`(8^&U]_:GA;P98^&;E+"QM-1T3P5#J=N;:*V\#^'%?7?$'Q!\3+AWT[6?C#
MX^N_#\5KILF+A?"<L]C?>;)%>QUY5^T-J%A^S!\/O`/[$7[,E_</^TG^V1XN
MU7PWX*6*,7=Q\+?`O]EZ3:?'/]I'Q%%;`'3?"/PI\#VDVH^'H[UXFU[X@ZSX
M/\*Z<LR:AJBQ>MWW[8VF>*?#NJZK^QGX!\3?ME>-_'=S&OA_Q5X9B/@O]GZR
MLIH7&DWOBKXZ>)([7PC_`,('I%NUW?7LGP^3X@^+;V2ZU.[T#PMJ>HZI,U=/
M^RC^R)XA^%/C3X@?M+?M`>+--^,?[8OQGT[3-)^(OC[2=+O-&\$>`O`>D7AU
M'PK\!O@3H>I322>'/A3X,U*:YN[[5K_R_%'Q)\2K>_$3Q9;VVI:S::5I(!]6
M>!O@S\,/`7@GP?X%\.^"?#</A_P7X6\/^$]#BN-(TZ^N(M'\.:3::/ID<][<
MVK7%Y,EE9P++=3LTUPX::5B[L:*[SRM)/,EM;S2'_63&Q\TRO_%(9!`PD+ME
MBX)#D[LG.:*`/B7]AVQLI/`'QZT)[.U?1+#]J?\`:$T:QT9[>)M*LM'N/$=K
M+<:5::<4-I;Z;/+?7LDUC#"EK+)>73O$S7$I?D_V&]6U24_$;P[+J6H2>'_#
M'Q%\?:3X;T*2\N7T;P]I6G^/]2M+#3-#TQI#9:3I]E:@6UI96$%O;6UO^YAC
M2/Y:**`.@U+POX9\:_#+]I[4_&7AW0O%NI>'O%_Q\CT#4/$VD:?KU]H:>&K?
M2[GPXFCW>JV]W<:8F@7,$%QHJV4D`TJ>&*6Q$$D:,OS)\:+Z]\(_L>_M$:AX
M3O+KPQ?VO_!.G]H'Q?;7OAZXET6[M_%A;Q;.?%$%SIKVTT/B(SHDQUN-UU(R
MJLAN=ZA@44`??'[&FA:)X=_9*_9DT7P_H^E:'HVF?`#X/6^FZ3H^GVFF:9I]
MO+\.O#%S+!96%E#!:VD,EPS3R1011H\S-*RER6/TL$0$$(H(Z$*`1\NW@@<?
M+\O'\/'2BB@!^2.A/YT444`?_]D`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+W-T86XN
M:G!G````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S4T-B`Q,#4Q-30S
M-#$U,"`P,C,W-#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(`
M`A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`M1``
M`@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152
MT?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D
M969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6V
MM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`
M'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%
M!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D
M-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T
M=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`
M/P#](?A?_P`$//$/AP0VVC^./`^G:Q+B77=9T'POXE\3>*]?NY(8UNM7\6^*
M]3&A:CKFJ7F"+[4-7UK_`$B5UDBAA$GE#Z.3_@A]XQE,DTGQSL5X4B(_#*VE
M;A<%<?\`"TH8%`Q@;=V5QO8MN8_T6Z/I$.EVD%K`BJBQ@3_+DW$P";YY6<LY
M8E2%4EE53@8``'QG^T[^U?XW_9^^./[)?PJ\*?LF?M$?M!Z+^TK\0=2\">+_
M`(I?!KPWJ.M_#[]F?3-,U;P+8#QQ\<=56VET;P[X:O;/QWJ&NV\^IWNCO<Z%
MX"\7R:9=:IKMIHVB7'XCA/!+AW$0A6S^OF6.QU5>TJ16.J>SH-64J:;<E)W=
M^:FJ$%9_N6[./Y/C_`CPDQ&,G5?#F8X^49.,\3G'%'$F,Q%?5-3BZ>:4*&&C
MWH4,/&#OKRVL?C]<_P#!&B\TRZ-K<_'Z>TN&C!^SR_!Z]A5@S8+Q36WQ7N+>
M>%2A431-)&2>6!V[J[?\$8_B!>VS'PA\8=#UA49P[:EX,U'08FD558[9X=>U
M6!LC@YD,P90&4(8R?Z+?B+86D_A^2ZGCDBEL);-[=[6-&N$:2ZBMS'&"\2&-
MTE(DC9Q&P1202JX^=_VP?VF],_8E^!EU\89/@?\`'[X_6&E^)O"OA[_A6'[,
M7PUA^*'Q2OQXCU>#2O[1M?"USXB\+VQT:PN+B.?4]5N-6@2RN)K.R"7DNIV]
MM+YM+P)R26:8B-6>(CE,(0G2Y*\IUY.3:=/FJ+=**;^SKI=MFF+\`O!&M@Z4
M:7!]6CCYS<)1IY_Q(H*$>6TT_P"UGK)OMHUKT3_GT\:_\$A?VO?#L<\V@V'@
M;QC%;JTJ+I_BZ'2[YW5V"JMMJMO"$*E4D:9;J(1@L\=W;M&+F/X%\?\`_!,#
M]M3X?:EKWQ.^&7P6N4UV2U7_`(2GP)8>)_A[JOA3XA796*T,Z)X2\4ZKJ7A7
MQ@L#SS6_B>ST)UU.X06/B>SU*TDDDC_NQ\.ZO'XG\,Z!XACTO6]%37]#TG68
M]'\1Z;+HOB32$U2QM[Y--U[1[EO.TC7-/$XM=3TZ=O.T^_AGMG/F0DUY?\3O
M"EXEG=^)/#%IIH\216-Q"BW\E]8Z=?W4[V=MIYU75=,BNKO2[2*8K%J&H6VG
M:E=6UC<7=_%9WZ6,FGWAFO@U@<IPM;%Y#C<=47(WB\NQ4J=6ABJ;23O%I1YJ
M*M6CS25I4XV=SR,L^CCX=1Q,J6%Q_$V2PQ*G3J0I9EA<?E^(51.*ACL#F&75
MXXB"32IOF5:%14ZE.O2JQ5:'\5>E_L__`+3.I:9IVHW/[+7[1VF7%_8VE[/I
MLOP?\4/+I\UU;QSRV,CP+>P-):/(T#M#>7<3-&3'<SH1*Y7]2_@;]HSX#>/?
M!/@_QSI?CW0])TSQGX6\/^+-.TKQ/=PZ-XETRP\1:3::Q::?XAT>_NY[[2M<
MLK>\CMM6TV\FFN[&_CN+6XEDFB=R5^//@^AS/_9ZBUV]CAFEK'3>[V7]-':_
MH9\"-MKBW-DF[I+*LJLD[.R_</;;=^KUO^DX8@+@Y'<=1^!Z^_Z]Z8X4N_[R
M3<P0`*V`HQVV\D,,GYMP4DE-I))\4T;Q_J%C:K;WMJE\D05(I5G6WEV*@55<
M?995)7:0&!W,""2,8-R^^(]Y,C)9Z?%:NX(::6?[25R,`B+[/$K8'4%U!]N2
M?ZII\>9`\/&NJE3VO(YU,+[WM(Z*\8MKDYD[*RDDU=WNC]ZJ<,YO3JRIJE'V
M;ERQK/E<;=++FYKM+K%O=;;=%X\UJ"UL[>PV6]S<7-Q#*UM*D,H:W@9I20LH
MD7>TB)Y;;#A5?!!Y'86DD.I06M]:W#B*4+*LD+1,)D&[]U.3&X,>6D&U2I#'
MS$97"LOS-<RW-U<274\QEGDRS2R')D8G/*!=L2G+'";L'`P>HWM!\37?AUBD
M:FXL)&'F6;R<K@<213%&96#L28\!)``"RGI\ME_B)"6;XFIC8SAEV(C&EAU&
M5Y82,9+]Y4BE=SDG[V][*VSO[F,X3G'+L,J%YXV#=2J^2RJ<RC[B;V<;.VJ6
MNK2U7T8N54*H4*@"A0,!0H``4#C`&/3'0<`5S'C&55\/:G',KO%<6LUI)&B*
M_F_:%\I4<O+"L:.[K&\GG1,%D*PMY[0XY=/B?HQ5<V>JEBI#K';6[(I"$D%D
MNCL5B-B$@,"5RJYKB?$OBVX\0A8H[62'30KK]EEF\N6Z651!,MVZ1RD0K"\S
M)!ATFD\M7:,#>OT>;<;9#3P-=8;%RQM2M2Y%3I<\9PY[+3FBEI>\G?:ZV/&P
M7#V9U<515?#U,-3C44IU).#5H>\MI/=JRZIZL_C3;_@GQ^WC\<6;XU?#?2_$
MO@7X=_&`GXH^`O!.N1>*=*UKP=X+^(!_X2SPMX5UC2ULP--U3P]H>KV.D:A8
M``6=W9S6XXCHK^P=G:1C(PVLY+LNXOAF.2-Y5"^"<;BBENI5<X!7XJ\SIMW^
MJU]7_.N\>_S_`!\S](6$G9?OZ?3_`)=)O3EZ\^NV_6R[LJ[Y%)4#*=0?E!)_
MGW/:ODO]K7]N_P#95_82\)^'?&_[5GQ:TWX6>'O&GB(>$_";W>A>,O$VH:YK
MZV4FH2VNF:3X"\+>+-86"UM(VFU2_O-*-A8QM;DW/G74%O)]$>#/&WACXA^&
MM&\8^"=>T?Q+X9\06:W^EZKI5['/#<6\B1R)B)C'=QRI'-']K@N[:TN;&9UM
M;NWBG.P?G!_P5/\`^"7/PN_X*:?"+2?#7BCQ!KW@#XO?"^S\<:K\`/B/I-ZS
M:3X<\6^,M,T&UU73O&_AZ31]13Q3X`\37W@_P8OBG3;)]-\006WAZ*7PEK:Z
MK<W^GUCE7]G8G%898[$/ZC4J*-6OA8.HXW5[I6G9)[MJ2:TM=Z/$8KVV"]OE
ME7#XJ=2*E1E2KQJQFO*,%&36UVI+IO=7\&G_`.#CK_@DK!=O:+\??%ER\33!
M_)^!_P`;<,L$SVTH1I_AY9J'292/F)5E!*A@01]J_LF_\%-OV'?VY=3UCP[^
MS7\>_#OC/QCH5I!?ZMX&U?2?%O@'QE;Z=*TZG4K'PY\1?#?A+4-?TNT2V:?6
M-6\,)XAT?0EGM_[9U33WN8;:/^9;]F?_`(-.-1DC\07W[8G[2]E97TDU[;^#
M_#O[*UCJ7B?3C'++:75KXB\3>//BSX-\,/#=W4;:@5\#:?X#D7[/]@OX?'MP
MMS):P>G_`/!.G_@W2_:1_9"_X*%?"W]H7XE?&WX*^,?@3\%]<\4^*/#4G@Z?
MXBQ_$WQSKE_X)\1^'O!)?PAJG@)?"OA1])U'6Q>^.I-*\?>*"=*TZZT/3;G5
M;BZOH-(^ZQ^3\`/#8GZEG.)AC*.'KU<.ZE*FWBZE%1:H4^6*4IIN\K7;BU:V
M[^?P^.XDI5J,ZV&2A-N,XRC-V:6KC'FVL]$[[-;']A$3K)#$2[-$R1NIW.."
M`4QR&`Z87@`<$8R*L@*HR,#<!R<'./KDCK^.>:JB59`6W(#M::7:XDC2.-3-
M</'-&&241Q+(\;J`DNU2&16W+\U?'7]JOX+_`+/`LQ\0/$TUSK^H6[SZ3X$\
M*VT6M^,=8A"PNQ@C>\L="TB%8KJUNYKGQ+K&D0_91(;%[^Z46K?FF(Q6&P="
M6*Q=:G0PU)1E5JUZD:,80<E&\IS3C&3O:*:;E-J*5V>YC,QP.`6'>-Q'LJN,
MG2HX7#TZ53$8G$8FO*-.AA\/AZ*E6Q-?$5IQHX?#X>%2O6J2A3I4ZDYJ)]/;
M;AOF6"X96Y5EMIF5E/(*LL9!4C!!!((Y!Q17X!ZE_P`%2_B:^HZ@]A\+/AS!
M8M>W364-^?%5W?0VC3R&WBO;N#6;*"ZNXX2B7%Q#9VD4TP>2.V@1A$A7P3\5
M>!$VO[<P^CMO!]4OY[=?ZUM^F1\*/%*<8R7A7XF)249)2X2JQDE)1=I1EC8R
M37-JI14DU9I-V/S*L/''C7X?ZEIFN>`_%_BCP3K=Q=6\$^L>$?$&K>&]5G@G
MD5)H9M0T:[LKN2*9$1)8WF9)%15=2%`']>7P?EEO_A=H]Y?227MW-I5@\UU=
MNUS<RO+',TKR3S%Y7:1B2[,Q+DDL2:**\KP?_P"2<J?]?:7_`*;9^9\<?\G]
M\0/^O>&_]3ZQW=A''*^V1$D4I)E757!Y3J&!%9GBDF&XA2$^4NU6VQ?NUW+R
MIPF!E3R#C(/(HHK]<I?[U@O\<_S@;U/]^K>M/_U+P!^2W_!63XA>/O`7PK^%
MMQX&\<>+_!EQKOBQ]-UN?PGXEUKP[-K&G77AOQ%]IL-5ET>]LWU"RN-J^?:W
M;303;5\R-L#'XE^&@+ZQTZ\O0+R[O+H&\NKH"XN;HRW(64W,\N^6<R*2LAE9
MMZ\-D445_/GC=_R+Z'_<3_TN9XOT9/\`E+"I_P!DIQ!_Z8D?5?\`9VGK\JV-
MF%'``MH0`!P``$P`!P`.`****_B\X,1_O%;_`*_5/_2XG__9````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+W5S+FIP9P``````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`Q,34R,2`Q,#4Q-30S-#$U,"`P,C,T,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_]C_X``02D9)1@`!`0```0`!
M``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````````
M``$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&
M$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3E
MYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<(
M"0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(
M%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*
M4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.D
MI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T
M]?;W^/GZ_]H`#`,!``(1`Q$`/P#^/<#X+>,?"2ZA\-?V:/#&O^/+30O&?C#X
MN>%;6;XZZ;X:^$OASP5XST+6M#U;P3XDN_VC?$FH>*M!\0^'&F\)^/XO%>E_
MVOI^A7VJ0^$[S1_%TNA_$32<,:#\!]5\$>+[Q/@7\0?%-KX:L?AM=_\`"Y_A
M!XP\8_#[P/\`#SQ!X_TG3YO$/A;XT:-\1/!'[0\7B;3])UO3]7\.?#F]\*:[
M\'-1U+4;+Q=K%])\0;"[\-:+X5UKR]\,>,/AKIGPX^(>I_#OX9:%\`O"OQQM
M_A-\7_`GPE\3ZUJ_[4'CN;QOX?UF/X>^)?'<5WIZWVFV%MKL^H^%?$.IZ;96
MW@SP_>PV>J:0UYXDM6/->)M?\<:WX?UVP\>:MKOPZ\3ZKX.^!VF^#_A%X7^%
M@\&:#\9O"UI9Q2>#_$7B*Q\-IX9TO5&M]$EL/$F@>)M4T/Q+>^++C5;5]+NH
MK=;26'^PJ_A_P;B,-[%Y-EZH8BH\0\0Y5L'7P_U/,(U:>'HU\#4P]:HJV&DT
MY.I[#$T:4?K="KAUB[>5',,9!32]C&4XI)RP^&G*/^S\KJ0A7A.,.=24XIP<
M75ES4$JJA;IM0UO]G":/3_A?IGP.^"VD:>WQ/?3X/VKM9\4?M;:O]M^'^G:+
MH.EJNK^#].\::9I]YJ_G-)XR\87OA_X6:-?3ZSKPT[P]X5\)^&TTS3H=QOB_
MX/\`&'A[PUX)\9^$/@I\)/#'PW^'OQ,7P3\1/`?[*WP[U7Q+\;_%&D2:@GP^
MTCQAX@US0O[:O++;::1X4D\6ZO=:UKH^R7FM^.+[7O%NKZIKJXWCQ/%-KXL1
MO&7@BW\)_$=/C)I5Q<?L-3?#?XH>$=`CEU_P?X=GL/%FD^$EO8DLV\82)I]C
M/X;@N-.UJ[%WI4NDVE_X9O(["Q\K:\TSPM9Q'Q3INA?%@WOPQ\6:#IGA&]U7
MXEZ7)^S_`*UJ/BK5+>QNI(8Y]#V:MX<UR[OM8LM`O+[5_#%]J?B"6;7K'4C>
MV\^HX83A+A/*<0JM#(L-.DJCJT'C<MHXYU:?LXTISA4S'EQ5+GA4E5I5J,XT
MZD%"O'`X7VE-Q4LRQM-TU3Q;H4YSDY*BW0;<'#V%.M4PS]M%RG3C&E"=6<55
MYY3G[6K3K3_9K_@CG^SA^S)^TO\`M-7WAG_@I3!\$?@Q^SQ\5?V;]8^(6C>)
M=77X1?!5_'NK>!O'_A;P9X'?PY=:8/#GB7X>P>;I?BLZE<_!"3X5:O\`$>XT
M&YOOB/J?CC0[_P`0VWB#]@_B=_P;J?\`!+OXS^-[X_LJ?M3>'M9TRUM]36P\
M-?`KXS:=XATN*S%Y>7ND-XJE\>+\=_%;^+8X+AK/7-0T;4](\+_V!9^')+#P
MLFMIXAU;6_QY_P""'G["OP,_:W_;=3X0?&O]H:XL?AY8?L=ZY\:7\3_#/6K&
MQN_!NN_VYX&EO?AMJ[^/?#.I:?!J>@2^)-:.NZ?H]A<)/J,2W%A>2>=<*_\`
M7%K7_!`'_@EAHUGI4U_^W;\1M(;Q)K\/A#PW<:G\2?@2(-1\4W\MY:Z;IMO;
MGP-:RWLEU<65PUM'%/!'?00F2VNQ#+%<'^0?''!YSDW'5-9'D65PR6>28"M%
M87B2KPS5J59SQ=&HZ^#PN)_LQ8J"2I2KO!5*M10HRK.&)I15+^SO`[(O!//O
M#YT>->/N*<AX[AFV-HX?+L-X)8#Q1R;"Y5#V->A4J8J.7T,ZG[:O6QM:M@L-
MGV$6%E%1Y?>K1K?AB?\`@U]^%#$M:^._BY?VK$M;7UI\7_A6UI>P'F&[M6E^
M",,K6]Q&5F@:6&*0Q.I>-&)4%?HE>?\`!`/PSIEW=:;8?\%3_`]A8Z?<3V-E
M8P^&O&GDV5I:2M;VUI%_9?Q3BTSRK:&-(8_[.BBL=J#[)&EOY:@K\*<^,FVU
ME.<I-W2_XB!A'9=%=YY%NW=Q3>MTKM'[(^!/`--I>-?AI9.RY_HE^,3G9:+G
M=+"NDY:>\Z;=-N[@W%IO^"UM5L$\.:+9Z]XEUCQ/X&MYOBX/!_PTB\3:K_:G
MP\\2:EH>G0Z3XHU73;C2[;P[!'KVJIX7O-8G\/,9?$=GX1N[34/L3Z?96M=!
M<^*/"\/@SQOHNOZ,?C7XMU;P/\(SX&^*[^)OB-IMW\!(-$EL'\0^$!X>OH;3
M1/$%IY-[#\/2VH1W?A[2I+2SO_!]^S7JI7]4WQB_X-2_CY\*=1OY?@O^WW\-
M?B+XT\1:;KNG>++KQ#X"\3^!=#O=`\7:7J-GK5C=>(_#_BCXJW^J7FL?:##J
MMC>Z!:HEK>?VDE]/=QPP/X!H_P#P;+?M^Z!X9\8^#-'_`&G_`-G+3?"OCQ_#
MJ^+=$M-8^*JV/B2'PSK=UJ.BMJL)^&`+OHQE&J6$2NRMJ-Q<64DL<$27\_\`
MI:^/>$Y3ISP/$5">'A*BJ4^?$X-\E.3E1E+#XO#X?$U7'VLI351O#5</6KY=
M.4\%*HY?YFPPE>7M%4H1I.$ZU*46J7M*=6+J4Y4G"I5BU%5FH3K34ZE%05:$
MG*ERO\'4\9:;XDTRPN?&5SKFM?$-?C7\*[O5_P!O&+Q5\9O$5YX"\(3>#;:Q
ML/`$GAG5;723?:QX2'AZ;6-"U-$M_$?V;P;J^B>&5U'1;;2]2LO.)-0U7PU>
M^(8O"/C74?"VG>*/!?Q$\,>(_B/J5SXTM])^/6F0>)M3U6\@TB(^%Y-3LH?%
M=C:^&]';1=7`MGU:S:7Q+K>F?VK<6UO_`%O_``J_X-(_'_C3P!;^%M?_`."E
MGA3P,VI7MMXG\4_#I/A#XCU+P2OBOP_8+IMMK=I=7GQ9\.6FN365IXKU+2]`
MUW4_#6BZU)9W&OP0:?:VPNQ)[)=?\&8?Q#UG0M#TZ\_X*@>%M4\->'K+69_#
M=E<?`S6;W1=%TYK[[5X@FT:"3XWR65A9'4KC[1J\EFL4`O9_-NV$\NYMI>)/
M`$J$Z-;B6A'$J,:L.?"<1XIQE[2C&=)5)Y2YX>G.A0HP]MAIN[YXJ$Z52,D4
M<!C7RUZ&#Q?L_:.FZT&N6K6C!>TITJBDJ<>6"J/DA&HX3515'*2GR?@G_P`$
M>?V`9/VY_B3\98O"OB:T^$7_``JSP)\([J^?Q3I6I>*K_4Y/&>B:O#K&I:3%
M;7OA\0V>OZ[X>7Q!9VUT)[>TT75K2WMKNX-I!/=_U9_!;_@VJ^&OB6+^V?B5
M^V_&FDRQ7"1:'X:^'FA^%_%%G=17$D$+:D?$/CWQ+:1VUTL;W,)AMG+P+$%D
M+W$OV+\F-(_X-T/VV_AAXB\<Q#]J7X2>.(;1M!\&^'KW3-6^(.D7]YX5\`'4
M?#WAN(VS:(VCV=O;Z-+!-!8V^NWUK;`WGV?4-1FG^TWGU_\`#S_@@C\7_%5A
MIV@_%G]KGPMX?O3JEA86`TKPGXG\<^&(;=PEG#K&K:GXE\5^!)M*:U6>079A
MTB_CBM1-<+=`2-;)_"/C/E^!XB\1<ZS7+^!:O&$91RJC@\V?$D\NRVMA\-E.
M#BXT,+5J4\/2HTZL:]*K2ES3J8M5,3*4YXB2E_I=]&_Q;QW!WA%DO#E?Z8F5
M^!.1>US_`!6.X/P'@I2XRXEPF-QN>XJ#JULXPN!Q.?5<9B:/U/'8?$74,-ET
MEELG&.!<J7Z<_P#$,G^QC_T>#\5O^_\`\*?_`)645\OI_P`&OR2*KI_P4'^&
MKHZJZ.GPB#*Z,`596'QD(96!!5@2"""#BBOR7^P)IV?@W@DUHT^,J2=_=T=Z
M_P"??7K?^BUXP8>23C^TLXE::337T:,Q::?*TT_[*:::::?GZWO^._\`@@+^
MWSIFBZ_J][^W-X@\2)I%E=W@>[U;QV;&Y32+?4)K.XN)KCXC7FIVVG1F>Z;[
M1'HU[J%A;7UW/'I,LCW%N_P%J_\`P1O_`."D\[QS6'[57@2`!H(7MH?C9\>.
MD]Z3<79>3P!`NVWAG>8P@%S#;"WM@288A]M7/_!&;_@NO)*9)/VROM<CYW3'
M]L#X]NQV,T2;FN/#T<C;HXT=.#B)XU;9(KQ1^#7O_!.#_@L!/$J6?[?7V&42
M!FE_X:7_`&E[G=&%<&/RY?!`498JV\'(V;1PQK>GDF%=2E4CX>\:X>2OSMYY
M.K3:;3M.->I6FU&S2E"$9M.]D]3S,1XHY[1PN+PN)^F']%_/,.G2GA\/'PLP
M^6XF+I:6P];)\)DM&+KI4I5:=?%SI1E24(U%%*)S_P`./^"1O_!2B/4M%T_6
M/VQ/"?A6SUJ]TZ#7=3T/XQ_&@7NGP3N$+S6<GAGPWHFH2:8]Q,`]WXATC3Q%
MYDCWT$?F3O\`H'9_\&__`/P4,U&!WO?^"DGB?3F\XC[-J>O?%J>63;NE%R#I
MOQ"U.WV-+=7(7?.LXE:X=HE6422_`NB?\$X/^"QB@/J7[>%PI1&4I<_M2_M*
MN[F>RT:1-JVW@^YB(LYH[^SDEDD266X2:XC66&Z%Q+]&>'O^"/G_``7.U;2+
M+5=)_;=:VTW4X(;^R+?M>?M&69N;:ZABE@NQ;KX4#HL\+(4\](YBH4M&%V$N
MKD6$P\I->'?&F*2J-I+/L13I0;FURTXX6O!J*Y>:-HZJS<K:HP_BKQ%FZITY
M_3(^C#PW/V,:=2$?"K)\QQ5>%&G3M/$XO/LMS*.)FHU5AZDWCI_!9<TFY/S3
M]I/_`((7_P#!1#P)#ITVA?ME6WB_6=6N-2=KWQ/X_P#BEX0%]!HL-O"@TZ^T
MRY\?WVH2SK<VT4=MKEOX:AMXY+.0WCF&YMK;YB\,_P#!(/\`X*<+>W":I^T9
MX/M[1H93'+J?QP^+EPC21S6XMP@L?!VJ7$4TL4ERTD8C6W41+NN)7,2K]A_$
M/_@DE_P6U\,:-]I\8?MPH-+OW?2(;F?]K#]HK6;?[5?VMW(;62Q/A*>61)+>
MSFDF66W^R2H@AEE+.$/RC9_\$O?^"P4&M6EQ)^U^LDEE?V,-OJK_`+3GQZEM
MHK:R*VUM?H5T*WU58-/A@M9+*U2V2<6\20^1$8EMG4<BPU:C*_`?&>%A)INA
M_;,JCG*5KM5*M.M7BTXQ=W4II2;;Y8I-Q6\5\[RS,L+*'TL_HT9_B:--0IYI
M_P`0VH8"EA:=&T8TYX/+\5E655H^SJU*:C#!8J52A1I1A[2JY0I_H!H/_!"?
M_@HSK6AZ-K/_``W1X^7^UM)T[4]MGXJ\87-FOV^SANL6MS>_%W2;VXMAYN()
M[O2]-NI8MLEQI]G*SV\97S1_P[F_X*[?]'W?^;/_`+3?_P`P]%:K*<&DE_Q#
M7C1V2U?$>-N[6U=LR2N[=$EV2LK<4O$'B24I27TW_HR03DVH1\%N%G&";NHQ
M<^")SY8I))RG*5EK)O4_%N;]M/\`;'N5"7'[6?[3$Z!@X2;X\?%.50X!`8*_
MBI@&`9@&`R`Q&<$U6_X;&_:[_P"CJ/VC_P#P^'Q-_P#FHHHKS<%_N\?5_H?;
M\2_\C27_`%XH?^D'#6G[9?[7]OKNEV$'[5G[24%C'%J4,=E#\<_B?':1PVUY
MK,-M$ELGBA84BMX8((H(U0+%%#%'&%6-`/0(/VT?VQ;;=]F_:Q_:7M]^W?Y'
MQV^*46_;G;N\OQ4N[;N;;G.-QQC)HHKHS'_=H?\`7JC_`.GSQN#?^1WB/^QI
MB_\`U6TATW[:?[8]RH2X_:S_`&F)T#!PDWQX^*<JAP"`P5_%3`,`S`,!D!B,
MX)KPV_\`VQOVNK;7]6U"W_:H_:/@OYKFYMI;Z'XX?$V*\EMXYE2.WDN4\3K,
M\*);VZI$SF-5@A55`B0*4493_#I?]?8_^DS)\0?]XQ7_`&*Y?^EX,]I_X;&_
M:[_Z.H_:/_\`#X?$W_YJ****LS/_V0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]C;V-K>2YJ<&<`````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#<V-C$@,3`U,34T,S0Q-3`@,#(T,3`S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/_8_^``$$I&248`
M`0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!`0$!
M```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"`P`$
M$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G*"DJ
M-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%AH>(
MB8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8
MV=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$````````!
M`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,08205$'
M87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X.3I#
M1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3E)66
MEYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+CY.7F
MY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_@OHHHK^R#Y\_:[_`((&_M+V
M?P1_X*`>!O@]X]N)]3^`/[:^G7_[)'QH\!71U6^\.>,$^+D,OAKX;#4="T\2
MPSZBGQ#U'1?#$6OS0QSZ!X3\:>.(4U'3M,UG67F_=K]EC]A3QK=_MA?\$,?`
MNHVTUOXF_9)^$7[7WB[XT:C>R1WOB#2/`OP+_:F^)FC?#(ZB+.XET;^SO%'Q
M"\6Z5H'A^UT[5KIK&PU3Q!=PQWMGH217?D/_``0&_P"#:_QW^U+I'P=_X*!?
MM3_$#QG\"_@]:>*]!^)7P`^'G@BRL=-^,'Q0;P5X@@UCPS\2=5UGQ3I.KZ9\
M/_AGJ'B#1K2X\,+_`,(WK/BCXE^&UN/$F@W/@SPSJ'@OQGXJ_MVU+_@G9<:+
MXZUWXO\`PD_:C^-GA?XKZSX1\.^#KR?XF:3\,/C+\./$6B^$-=\8^(O#&C>,
MO#%[X*\(_$9?#NF:K\0/%MW)I?PI^,OP@O\`4I;^R74=;N+?1M+M[;_&_P"F
M_P#1^\4N./$KC/Q"^CIFG`V&S;B_PLS+A'C/+N)LUSC*H9SQ;3\/O%SPERW-
M\"\'P_FN5U\=0X$\8,RI2Q^/Q%"C5S'@[@S+ZTHY=2Q6,P?Z%PUF^!PV"PN%
MS:GBN7#9A3Q6%JT:5&KRX=8[`XZK1JQJUXSA#ZWE<&J:HOGHXW$58S;=-2_Q
M]_VCO"^J^)?BA^TC\:_"'A74;?X*C]IOQKX3T[Q(QL'TG3]8\<Z_\1?%_@KP
MG'=60M[/4=1F\(^$M=U"=M$MGT^PMM.MY+H6$>L:)'>_,]?UN?\`!:WX`P?L
MD?L??!?_`()U6/A?X?\`[*GPQ_9,NIOBIXU;7/'^F_$?XD_MS?M&>/?#7B3P
MQ\-_BI\&]!TJPTKQ[XH\)SZ99^-[OXK?%OXI>'?A7\//ATVLZK\&OA_::CJ?
MP5\*?##Q)_)'7]^?1=\1L]\0N!,VCQ#PKCN#<5P;Q3FO`^79#F3^M9GAN'^%
MXT,ER/%YYFV#K8W(<;Q!GV"P,>*L=@\@S7-L)DF"S_*LKQ..KXZAB*M3Y3.L
M)2PF*I^RKQQ$<10IXF=6'NP=6M>I5C3IR4:L:5*4O81E5A3E4E2G.,5%I(HH
MHK^E#R`KO/ASX"U?X@^)])T>RT7Q3J>COK?AZQ\3W_A31I]8OM"T?6M7M]-E
MU`JJ"RMKCRY+C^S3J=S9V=S>Q+!)<Q)YDB5?ASX(U3XF?$+P'\-]#EA@UKXA
M>-/"W@;1YKA))+>'5?%NNV&@:=+<)%B1H([S4(7F"$-Y2MAEZC_50_9L_9S^
M&_[*OP.\!_`SX0Z`-&\!_#O1[+1H9Q!']MUG6+B.6YU;Q-XDO8(HH[[Q1XMU
M./4==UB\=8S=WTUVUO%#:P1P0?YR?M`?I\Y7]"_*^"<JPG!4^/>,?$2.=5,)
ME\\_7#F"R3(LI^J8;%YOB<<LGSNI7Q>)QF84,)E6"C@X4ZDZ6-Q-?$*.#AA<
M9^N^%7A76\1JV9UJF:PRG+LI>%A5K?5OK=?$8G%^V=&A2I.OAX1A%47*M4G4
MO>=*%.G-SE*E^%GPW^&OQP\+_!;PA^QI^Q)\1/'_`(3^,?B;XO?MF:7\.Y'T
MOP'\/[/6_AWI7@GX<2?`#]AN7XB?M.:WJVE?&KP)X3\875[^T;\9/A3\??"/
MAK]H/1?@YH7[07PH^%OP_FB\':]HWCC^S3]C2VUKPM=?$GX7KK%EXC\.?#_2
M?A5!XHU#0]4\4:]X%\*?M*ZIX?UD?M$?"GX3:QXLG&H+\*?"4^F_#_Q;H/AF
M.SF@\#^)OB/XS\(+JMF='_X5W\./PZ_:+T/X"_##X;^!/!^I:=\//!\OQ6_:
M\^$5M\-M.\0#PM8Z-XE_:2^,?[0FF^,&O]1C\6I<:3JT?B+Q!JGB[Q1\3K*[
MM=576?ANOC_3KK1-:T6:[T&[_J/\/^'O#?@S0-,\-^%M#T3PIX7\/V$5AH^@
M>'],L-"T#1-,M$VPV6F:5IT%KIVFV%M&,16UK!#;PH,(BJ*_&OH;_21SGZ3W
MAOG?&V=<)PX8KY/QCF/#6'KX*C7H93GF#PN!R_'8?'82EB<1CJM'%T:>/AA,
MTP\<PS"E3Q='VM/&2CB'AL+U>)O!.$X#SW"93@\S>8PQ.54L=4IXB?M,9@JM
M7$UJ?))TE1H^PE["H\/)8:BZD)3=2BJL)8C$?C-_P7W_`."<_@O_`(*'_P#!
M//XNZ%>"32?BM\!O#WBO]HGX,^(=)TJSNM:U'QW\+OAQX_N=(^'E_>.8KP>$
M?'JZS?>']9MHYIHK.XOK+7X-/N]3T>Q4?X]*L'574Y5E#*<$9##(.#@C(/0@
M'UK_`'E?B+#]K^'OCZU;PZWBI9_!WBBV_P"$7,'VL>*5FT&\4Z$MK%>6<EPN
ML&0Z6;<WEA),TS1K<0*Z7%?X/.IZ5>:#J6I:%J#Z;)?Z)J%]H]]+HVL:+XBT
M>6\TNZEL;F72/$'AN_U3P]KVE2S0/)IVM:#J>HZ+JMFT%_I=]=V-Q!/)_HOX
M3XJHJV;X%SO2=+#XJ-/?DJ1G.C.>D_W?M8SA'WH/VWL?<FO833_*<=%6IRMK
M=QOW6]O.VO72^NZ*5%%%?M)YQ[7^S3\4-+^!_P"T?^SY\:M<TS4-:T3X/?'+
MX2?%36=&TEK==5U;2OAY\0/#WB_4=-TMKR>VLQJ=]9Z/-;6!O+B"T^URP_:I
MHH/,<?I[X-_;`^.O[=G_``5+A_:"D_:^\.?L*VMQJ'B"[\-?%3XD_$.STWP1
M\!O@5X.T^34K/P!IFB>)=3M]$^(6K:_I^DVL=_\`#*PTY=%^+GQ.UW5M7U3P
M_INDZQK%QI?XKU]7_L??$']ESP+\2]5M_P!L3X+^(OC-\$/&'A2\\-ZI'X#\
M07/AKXF?#O7EU;1M:T7XB>`+R#6?#UIJVK62Z3?>&-1\,:]K5EX?U30O%.IW
MUUY^I:/I$+?@GBQX:\"UL9G?C%FGA97\5N,LI\.<QX!H<.8;!Y/G./S/@K-L
MWI9EQ)DF49'Q'C,!D&.QN94^:I7H8W$PK9CA\''*L+)RQ=3#8OZ[AG.L;1JX
M+(Y9K#+<GKYUALTQ#K8C%X+"_7</2E2PU7&8O+Z5;&TJ$6U!U*=*I]7<G745
MRRDOZA?B1X[_`."1_P"WG^T)^S=/?_\`!27]KS]HG]ICX3_$CX90_!_0O&OP
MMT_P]\)O'^J1?%_PM>:OX2@\!^#OV8OAI\/?#UQXM\.:78V_BSQSIMMHVHR6
M6@:=JFL7/QBFTG2M%K_21D`QO,7FO%NDC4!-^_8Z_NC(R(DCH[QABZ##LK.J
M,QK_`#P/^"9'Q$_X(,Z1^U+^SO\`"+]E?4=(^%/BKXG?$WPAXL^(7Q>^/5UX
MUT#6+;1_@]KR?&?P9\%]#\>?%F^N/"VEZW\5OBAH/@+X::CX/\,R:5X=^)'@
MJW\0:7K6L^(/'</P\L?$W]^WP^^,WPF^+-YXILOA;\1_!OQ'?P3>6.F>+;KP
M+X@T[Q7I7A[6=0AN+J#P]JFMZ%/?:/:^)HK*"/4=0\-/?#7M)TO4=#U35-.L
M]/\`$.A7.H_S/X49_'B#A64\N\`LW^CIPMDV9XK(N%.!<]X4CP%F5?*L+"CB
M:V=+@?#5L3E_#668O-<7F6$RNA0K/$YG2P%;.L9"E_:%""^JX]Q$<3FV'JU<
MRX>S;,*F!HU<QQO#-?&8O+G5FY>QP\\;CL1B<1C,7AZ"IPK595:OLZ<J.&E6
MG4H3C3^*?^"O_P`8?"GP+_X)D_MK^/O&/Q(UCX4Z8/@#X\\(V?B_PO):0^-D
MU[X@:3+X'\/Z'\/[B]U/2(;'X@>*-6\06GAWP9K/VS/AWQ#J=AXC-M>1Z2]I
M-_BK1IY<<<><[$5,XQG:H7.,G&<9QDX]:_U2_P#@Z:^$W_!1[X^_L-+\)_V-
MOA5:?$;X#2ZSI'C7]JS3/!\TOB'X[>+-&\':[8^(?`GA?P+\.TTNXNM:\%>'
M_%NCZ9X[\>2^%+B]^(=]JND>"(-#TU?!NF_$9-2_RM@00""""`00<@@\@@C@
M@CD$=:_KCPJPN'CA<RQGMZ<\74K0H?5E63J4,/"*G[6=!-.*Q-1\JJ234EAE
M&#351/\`-L=)\T(V:BDW>VC;Z)^2Z>>O06BBBOULX`HHHH`0@$$$`@@@@C((
M/!!!X((X(/6O]Z_PWX;\.^#?#N@^$/"&@:+X4\)^%M&TSP[X8\+^&]*L="\.
M^'/#^BV4.FZ-H6@Z)I<%KIND:-I.G6UO8:9I>GVUO96%E;PVMK!%!%'&I17X
M=XM_\C'A[_L"S?\`]/Y6>E@/@J_XJ?Y3/X`_A[^UC^U//\)_"7BZ?]I;]H";
MQ9JO[;WACPCJ?B>7XR?$63Q#J/A0_%:RT0^&+_6G\1G4KSP\=%)T@Z+<7,FF
MG2R;`VWV0F*OY[?^#A?P[X?\,?\`!8/]KRR\-:%HWAZSU6W_`&<?&FJ6FAZ7
M9:3;:EXQ^(O[)?P'^('Q!\67\%A!;Q7GB;QUX\\3>)/&WC+7KA)-4\3^+O$.
MN>)-;NK[6=6O[VX**\WPP_Y*2I_V+,5_Z>PI>-_@K_''\I'XOT445_09Y1__
MV0``````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]B86)Y+F=I
M9@``````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S-#<@,3`U,34T,S0Q
M-3`@,#(S-C<Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81T`*@#W`````````#,``&8``)D``,P``/\`,P``,S,`
M,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`
MF?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S
M`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS
M9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S
M_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF
M,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-F
MS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9
M`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9
MF6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9
M___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,
M9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,
MS/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_
M,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_
MF?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````A^00!``#8`"P`````'0`J```(_@"Q
M"1Q(4."*@@@3$CPX<`7#A@H5/L0&`,!"`!,C&G1HT")$C0XY-F0X,6-$C!^Q
ME329<`5*E1L7:BP8\J`5@R-GML0)LZ=.A`=)JF3YTR'&)RIJBBSJ4`^@4L]6
MK8I:BA0@/4^(CM0S]9G7KV"?E=)S4V(54F'3AAUK<@574FC5AB4%=96>DE:F
M8HTKURLI/7'O#JPRU2Z@KE[UZ($Z=W'4*@;C_DU;905?L(``^3U8Y6OFM%<O
M?YT<M:EGS7W5<O7Z!(">TZE5QW7YVNOGV&$_KW+8V6]MW%\!/R.E`MN3KF.!
MCZX-*"CJ9\*!CPT\T`ICTK'_2H8\<+7AU'\!Q5LEQ;UA%<7A24F%:_6J\%+G
ML])<`:@*U/"*G<)%;#=\68'HZ7$68G+]1=A5$UFQ&"DKJ/"$?J5$"-=5\EEG
MU7_8*/C74!4I9=1+5@""H4!/8.B0%5>DF&(75ZQ0XD\J57%>(*TD4N.-7>3W
M4Q69Z4%C(D`"V4H79XTUDV6/=1%DD(C($%=S&A%FFQ4V!CFD%:-IA4UO8EF!
MR)*M7/$;E!%9Y]5N5W@A"")L*NB5D3/E-9R'#AT'W4]6J*>'1(O!N&5Y?@8$
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]A=F%T87)S+W=I>F%R9"YJ<&<`````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,30W-"`Q,#4Q-30S-#$U,"`P,C0R-S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````_]C_X``02D9)1@`!`0``
M`0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$`````
M``````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A
M,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W
M.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'B
MX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%
M!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B
M,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'
M2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:
MHJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ
M\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#^?>[M+6_M;FQOK:WO;*]MYK2\L[N&
M.YM;NUN8VAN+:YMYE>&>WGA=XIH94>.6-V1U96(/E?@M[OX/V7B+P=8?&._\
M>:7\3]2TSQUX\^#VB^$==TK5OAG%\$;+Q=X4\&?$7XK:O<:1X2^&^L:)IWPR
M\4^)]9\&W_PTO_B1+X:\%'XIZMX[MO@_=:7J^B^)O7*VO@[\-?@KX:\4>%_V
MEOBU\$_"'Q3/A_\`:L\!1:;X5\0_$#1;_1/B)X7^#,'@?XF?&GP7XR^$&JZ)
MK<E_8>(=,\2?!#PMK-YK]G<>"=1^'OCOQ/X?:UU?4_&5G=_#S^YOI,+B3!XW
MPCSS@V&)J\3X#C>6'R[#87`8+'?VD\7@9OZCCX8WV*EE2=%XO&4\#C\!FKAA
M^?`UY4XXS#ULN"'E\UGU#-,)'%8-Y4\364L36PLJ5*A6A"O4HUJ6'Q<*6*C1
MKSGA:N(PU?#_`%BG2HR@IUJ=6G]A?$;_`()Q_MH_"2_L])^(_P`$;[PIJMWX
M3TCQM)I6H^,_AP^IZ1X=\2^*)O!/@^;Q/I]IXQN;OPCJ7CSQA::EX8^'7A[Q
M3#H_B+XB:[HVOZ7X(TK7[S0-:BL/9O%7_!'_`/;:\*>"[;QE=>`M/O5E-Q!=
MZ+8:C<2W.F:C9Z2_B:[T[5?$+6"^`]"N+?PD(]>V>)O%VA37<K/X>TR"_P#$
MSV.DW_R_8?ML_&;Q-\1/#W@OPQX0CUSQWJ%_X&\9^)?#7AV-M9TGQKJ>E>*W
MMM%U70?"MQXTTCQG\,?"6D:7X+^`_P`";FP\&^-?#5U;_#CPK%KUIXP\5_$+
M3-!T6OZF/^"8TG[6/[67Q"\>?"GXT?&GX<:E\)?#6M_#']M;0=7^"ND?$C5/
M`6NW/C*'P/JOP&\%>"]1^,%EX7\8:C\-OAW=?#W3O%?AR+QCX>TWXP_#OQQ\
M/]'N?%NJMXMUV]&A?B>?_2>\:,BS_*LGS[(^#\DQ^#G5P7$64Y5@L\S>-//J
M-?$PK8.KCL7*E&MD*HX95<+G&`EA*N)I5J->K'#QQE*CA?5PO"_"^)R?.L30
MQV85L1A\1.IE.-Q53"X/#8O+J4\-!*>!I+%XJCF==8F$H86I5EAW)S4,4U@,
M4Z_\</B3PSXA\':W?^&O%>B:GX=U_2Y(XM0T?6+*?3]0M&F@BNK<S6MRD<JQ
MW-I/!=VLP4Q75I/!=6[RV\T4CX=?Z-_[77_!(#]EC]H7X,>)?"^LV?C#0/%V
MG^%WM/`/C_PA+XKUWQ#X4\1:1JNIWO@?44\!6_B:T\)>-;.VAUW5]"\5Z)KN
MF0C6;'Q!XFU_P]XB^&7BG7=;\92?Q@^#/V#/'7@SXN>,OAS\2M-CE\4?#OQC
M?^&]0%E'>MX>U#^S;R2+3]8T.YU33=.U#4M)\2VZV7B'PUJ9TRW_`+0\-W]A
MJ<=LJ7#Q5_1O!?TA,IXIR2;EE.(CQ?2JTL+#AS!SJ5(9C4J4DUF&&QE2C[/"
M9;SQJO$QKNOB<`HPHI8ZM7PGUKX:OE%2E4NJD5A]&ZTW%.%VTH.'-S3EM9Q2
M@VUS.%]/SJ3PWKDB)(FG3E7574DQJ2K`,"5:0,IP1E6`8="`>**_H^@_8X\*
MM!"UQ]F6<Q1F=5=PJS%%,BJ!;R@*'W``2R@`8\Q_O$KZ5YKXUR;E#(>"XP;;
MA&<LUE.,6TXQG)9C!.23M)J$+M-\D=$\U3RS2]3%7TO:=&U]+V_=O35]7Z[V
M_FEJGHGB>WTS6_'WAJV\.>#IM1\1^%/`K:EXJOK+6M7\:66C6GB/Q/>V^BZ0
M=5U"Z\&^$]-NM4TJ"[&O>&=!L/B'J2IKWAZ\\41^"]3UC0-<N5PWA_3SIWC#
MQ\SW&G/+KM[H7B`6MO=RRZA;V7_".Z;X;M+B_M)+>-+87M[X;U>.V,,\T,D5
M@'#F=[F&U]_Q"PN#QM7@'#X^BIX9>(N08I8B5.=:&"QF783-LRRJM*E#63Q.
M:X/`Y92J2:AA:^/I8R5UAW%ZY/7KT/[4EAW'GJ9-CJ$H/E4ZE"O[*EB52DX3
M<94\/*KB)\DJ4IT:-6DYNG4G2J;6H>)=2\`^)?A_\1M`M[Y?$/@_QCILUGJ^
MF13M>Z9INH[K76;>2XLIX;ZSL=8A6#3A?Q0ZA!H.M2:%XMNM/9?#:7UA]/\`
M['W_``4%\6_\$I/B!X=^(-MI.I>,?``M/!/P;^*?A>R>TU^-='T3QI\1M>T&
MWTS2=>\2W\,&O^!/!NG>(-/B@O;JS\/ZWXHM-,\375AK6C6/AC4[;Y-\>^'Y
MO$7AF_MK$$:U9QS:CH$R)`T\6K0VMQ"D4$L]Q9?93J=I<7FB7-U;ZAI=Y#8:
MG=FSU73+DQ7UOXQ\9_%7CNYT:ZN?$>DZ2]R+SP9XM\2S?VS>73I)H-[X=TG2
M;G0-7N+2QOX/%\^I#Q!;QWFD3RKH/AR:ZOK>PTB+7%T:Q_DCZ3G#6;X7C#&<
M5K"8BCD5;(,JJ/-:<*LL'+,\/B99?_9V(KQH>SHXVM%X.I1H2CBJE7"TY5Z5
M2E3I8KZK[W"E&&/K8++XU(JO6QCH2IR=*+E1K.FXQA*KB,.FZM6T*476H1EB
MOJT'[64XTI_TH:/_`,%3?VQ/^"@WB;X=?M<Q^"OCIX<\:?"_XB>-/VJ/V=_A
M5H_P^^*GCG]D?Q-X"^`'A2^\):9\(]`^']_-X/\`A]\8_$7AOQ]XMUK_`(7G
M^T?JFL:7\2O!WB+4+Z_^#?C#2O%D/[//[+6G?JO'\:_AW^U1XNUC]IOX=6]M
M'H_Q3L=$UZY+-!)JUMKNH:'IEQJFD:[!:^(?$VG:/X@\,(\/AK5M)TC4I;2S
MGL7MKB:YU6+5+R\_";]@.P_:&^!7[%OQM\2_#G]GKQEX`^"FL>%_$^O2?M!Z
MCX'\9>#=/U[P[I_PI^)6L:5JVD>,;C2HM`\76\>M:/IMGX`N_"&L"\U@?%5K
MC4-'\/\`AOQO\1/&WA3[T_X)I^(=)G_9SE^'MHUM%JWPF^(WQ&\,ZO80W]EJ
M36L'B#Q;JOC_`$/R+VUOI9]1TRTTGQ9!X=LM3U#2/#>I2W/AW4=-U;29];TG
M5=8U3X3Z*5/!4_%.M&CF&-Q3Q-+/\1B*./QF)Q#PN.GA,NQD,MPL,1*U##4L
M.X8VAA,+"&#IQBZM)2J>TG/T.+I8F.#PE*O@\/A'1P&#H4I4,)A\-+$T*6*Q
ME-XK$3PON8G&5:BE1Q-?$.6)2H4J-5\T/:5OT'HHHK_3<_.3_-_\(_M-?%3P
MI9W&G2WUGXFMDG:&"7Q?#J>J76G%+R(W1CU,7&CZC=1S2ZC(-GB+5[I[.WAT
M^TBFT^.`1ZC[7X2_:&U#4K?QU\3+SPM"U[X?\)_#?0;[1;+5)+:TU*[N_$6K
M(VJQS2Z==:G8VIE\32&TTY[+66B6#R[34;[[7<W4/R/XW\!W7@36((8KW3]?
M\.7WGW7A?QGHTMO=:/K^GVVM0VTK6^I64\EJNH:7+BUUBW:^T^[TV^E:V.H3
M:;)I5SJ&G9:7>V7P<U#68[LHFM?$;0O#=WIJ!R@GTG1-:O(4U.S@F1I(Y9+B
MVO%M9--N3+>Z1;W%P]\\Z06'^4F9\?\`B9D?U7A[,^),VI3R'.,GQN#PN:3H
M9E/"XW*L72S'*ZU"OC(XMU\-[M.>%=/$5\!B\%5HQC'$Y=4A"7Z[A\#EV(<\
M7AL%3D\3@\1"K+"*5"DZ&(2PV)C.-*$(1<57G*2G2I5%[&<8RHUXPY?OSX9_
MM,^!O']Q8:1?I-X3\2:A-!:VFGWTWV[2KZ\NWO\`[-8V&NQ6]O&+UH[.-/LV
ML66BRW=_=0V.BKJ^Z.>7LOC_`/!>77_A]H'C/2-.TC3]7NO$FHW&M7KZ0]SK
M.M^%=-CT'18M3M[[3);K4#%H%Q=ZWOTC^QIIM;CL#'+J-A<:9X5T[Q)^0Z(`
M!(S1HC;(F:X^T-(D)M&N+<2W`DMIA&]HSZ?-'%'!%=6RA]-MM0GC!A_H<_8<
M\):+\39?V<_A=XD>Z\.>#M)\//!XFT2[N-3LM+M7LO#%WXW^)\,-IIFM^%;C
MP1=^-;/P_`OC#Q@VK2^(M3U2335MK>Z\.>'/$_A]OKN*/&C/?$+@A<'<28?#
M5<?1S+"YB\\PF'E1Q.,P&%PN+IXG#5,%A\/+#4LQKSQ"I4\7@I8*A.G56'EE
MTX2K1Q'G83!U.&LRP^;9;6E3G[]-4_:1DJ<E5I5+I5).4Z$H))T\13Q$823?
MM9U(TYP^LOV(_P!HC2M+^&/PR^$VF^./B\/"OA"_TCP]XU^&WQB&NVXTRUU:
M]LX_$RI\/(H;7PWJT6FZ=>ZMX!TYT\/:I,NELT82]\11Z7KZ_IS_`,$IO#4%
M[XT_:*^`&N>,]1N-5T*70O%7AC49O"DF_P`0Q>&+71O!NO\`Q&O+_P#M:]2*
MR\?^&]0^&$^D:1-XCUZRUBTL(?&GA+5;6*Z\7:=J7YI_';X:+\#_`(V>(WTB
M:[?P?XP\::?9P3/%XDDT_2=:U"PT&_L=(;[1JU[%<N;+Q7J%A?RVC'2;.^O?
MA[,NA:)96UU)7T=IOQ8UK]EC]HGX$_M4>'[DVFE?$;PU>)XWTGPX4U[5]5TN
MPFL_`_Q'L8K"?QGIL=_KGB?0?%GA/2;B2\\2:IJ_C[XA06#^*M*\`SZ))<7'
MY-P?F&8<&XW#YMEV<8^CG.`Q&.Q.%Q=2=&H\-.I0KRI4*4L92JX;ZCB(4:.$
MJ8>M.A*I#%8S+H1KX/$QCB=L[QL,^Q3J/`X3`*=+#4\3A\#1E2P]=TJ4%+%U
M%24^:=7FEBJ\:52K.-:G&KB8K$TN8_HGU7]E'XW:7JFI:8-!\+WPTZ_O+$7L
M/Q.^%]A#>"TN)+<745CKWC'1]<LXKCR_-CM-9TC2]5MU<0ZCIUC>)-;1%?L+
MX*MO@/XZ\&^$O&W@SPOX]U_P?XQ\,Z#XJ\*:]#IWQ/L8=;\->(=*M-7T+5XK
M&_FTV^LX]2TN\M;Q+6]T[3[NW680W%E:S(\$97[,_I5^(,&X3ED//%\LKU<+
M!\RLG>#RN3@[[Q<I.-VN9VN>'2R#`3ITYNAQ(W.$)-T^&L?4IMRBFW3J0Q,H
MS@[WC.,I1E&SC)IIO_'[\(^']!7]HSXH>"UT32%\'3^$[2:?PF--LAX:FFL+
M3X97]C++H0A_LN22ROM5U2]M'>U+6]WJ5_<PE)KRX>3W6WTS3=$_X)5?MWZI
MHNGV.D:G<_\`!0#X7_#>YU'2[2WL+ZX^':Z3XE\4KX"GN[2.*XE\%KXG\%>#
M?$8\+22-H8U[PEX9U<6/]H:#I5Q:%%?G_CA_R1W`_P#V<BO_`.O1S$^LX>_W
MS.O^R5C_`.LFS\;;UFBEC2)FC06=DP2,E%#76F6@N6VJ0-UP.)SC,PXD+"O[
M5_V+?#V@6'@;X5:W8Z'H]EK2:EI$Z:O::996VJ+/KD7P@T[6IEOX8$NUEUC3
M[FYL=4D$H?4+.XGM;LS02R(Q17Q6$_C_`/<AF/\`ZCUCAQW^\X7_`+&V!_\`
M3N6B_MT:CJ%W\$_B+<W=]>75SIOB2/3M.N+BYGFGL-/U/XJ?M#Z3J5C92R.T
MEK9ZAI7A[0-,O;:!HX+O3]#T>SG22VTRRC@X#]MB^O=(_9!\(C2;RZTL6_QK
M^#R0#3KB6R$*2_LYP>+94B%L\7EK)XJO;SQ-(J;0_B"[N=98'4IY;ERBJJ_%
MC?\`L$PW_I^N>77_`(>6_P#8PQ7_`*@H_#&;POX9N)9;BX\.Z%///(\TTTVD
M:?++-+*Q>2661[=GDDD=F=W=BSL2S$DDT445\>]_FOS@?K^'_@4/^O5+_P!(
MI'__V0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]A;'DN:G!G````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3`P-#4@,3`U,34T,S0Q-3`@,#(S-30V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````/_8_^``$$I&
M248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%`0$!
M`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!?0$"
M`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:)28G
M*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`````
M```!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A,082
M05$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU-C<X
M.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)BI*3
ME)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN+C
MY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_%KP/\1)M,AL?#WQGT+4
MI_"5L%%SXCTZVN[\6%C.RB&XDO(2[6UI&88Y8KAPUP#$=NW9S^A?PZU30M&M
MSJWP8^*O@[Q[IEP+.XFTS5M8MM-O[_#$>5K>C:JEJUQ<6\,KP:?K>G7/]JS!
M[E+O3=95;=;/Y1\`?!WP;\*=+74/C+^W[X.\"(K)+<:7KWA*&XBDMIDW2Q)8
MM<S37[OO@\Z&&'>3Y0;DICZY\/\`[1G_``3:L/"=KI6D^/?@Y\6_B9IEW&;K
MQ-HO@?5?!&I:C!$':!)++4;2-+FXD)9D>"XF#&++JF8L_P`0<8Y>\=&IBL@R
MK-\SPTJ\O:?V/E.88K)JU23UJ5J&8Y/1I4YSJMTW7PF9/EE=<K<73?\`I+DO
M%]'"?5<ISS,Z>!QKJ*BLKS;$Y)5S.G"F[PC4Q."S&M"K3C*,/9NM&-2E!4X-
M^Y8]V\1Z7\#?B!\,IY/$W@:[\,^/[=+N>PTIOM>A7#W\ET@.H:!K\*V>BWEC
M,T47VM)["TN;F,VBWT#`0FOSSU7]C^5_#^L_%/XD^./`OPFL[6WOIK>^T;Q'
MI$OBVYM(II#;'6;`ZEI7A^6-XT0>1#>6MY.IG"P7;*!%_5O^R5J'[/GQQ^"J
M:[X:T/09DL;>&VGMA90*;*2VACG#268F@5R9@$<!',PE;S`,_-_*7_P5,\%>
M+X/VUX_#'B']F/QO\6O@7H^A-I>A>$O#/B-/ACH'B74==2ZN&\5#6K.6[AU+
M6;.\G@^SB\LYVCCTQ+>1PKQ@+@7(<\6.PU!YWALDR_,Z6+K8O&8CZIB*N6K`
M8C#2Q&7T\-F6(P^$A7Q59S@X8FI4I*,*E>5#$/DH5/$S_P`0XTL+G&#P^0YA
MCLQR_'X>.&RZO3KXM8RMBVHT<5"6$PN,Q5*A2IRI5XU,+0J<].=.G*=*FZE6
MGT/P'_X*`_"'X.VUAX?OM?\`V<?B#IVFH+5O$&FZ;?>$]>6%)#`TFKP#3]1N
MIY$\U3>7:PR6B2^4T4\WF;E_72^\&>!_VL_A8NM+X=T72XK[3S-X>UO1Y9KF
M2\C\H26S/=WEG9W+PHSJ8YA!$)T=0V[RD"_A?_P3[_X(]?&#XR:C<+\:M+L/
M@=^SM-XGU+6]?:WATZ[^,7C32H6M;6W\!:OXS>&#4(_"L!TY9+K2M.6TTN^N
M+V:[O+:YF,+1_P!1]EX:\)>$;32/!GPTTJ#3O!'A6PL_#?AZVM-R0I8:9%':
M(DDGR+<2NT!,S*H4MC&>W-XCY)PCE6(P=?AC.L3C\RCB95\95C+!.@Y.//'V
M4L#"EA.?VCC*HL)"%*#YZ?*K21Y7!O%O&&9RK8CB/AZAP]B:5/"3PE*%3-)X
MCV+E.4Y8ZEF.(;C#$PE3A1I5,,G+#PJ3C&G#V4I_SF:I^PI?1:GJ,4FBPRR1
MW]W&\K:;`[2NEQ(K2,YB)8NP+%B26)R3DT5_2V?#NE2$R2Z#9M*Y+R,;>W8M
M(W+L6*9)+$DD\D\FBOEUQWQNDDL6K))*\%>RY4NF^WX;Z7_2?[<R!ZRR;+')
MV<GR-7;Y+OYMO[S_`#DK;X>W_B/1O&FB^*/AK\7?%7QGU;6-,O\`PEX[T0RZ
M_P"'7TV,2KJ.BZFE]$DYCF6YM7@OK>;S;`0.ZF,LA/MGA_\`9J\76NF>%;CQ
MU9Z7X6TW0]4U77]&\*Z5;3?VE:WNJQ:997(U?Q#<E]4N8FETFRN4M);A[>UF
MFNFA`:>0GZ*^#OC_`,4>%K*'4-#OIM:T35=/2:V@MG68V\%U#M1EADW//N&^
M(+`R^0L(1\JZ`>RR3:CXQMGGA=&GCC@%W;W#RV=XB$RO%$();<ED5ED(19"B
M$9PN0:_L/-.+LVPF*5%4,MP6"IMP>+^N5'55>,%14*6%?*J&B]G-)R51.516
MYG;^7>$_"3(,TP\<UKXO-,VS.JJ;A@9OV5%.I5CBXU:]6C!RS.H^955.<X<D
MN64H\T)1?[#?\$2_B7J.D>(O$'P]NM4F>TNK%M3"M<RD/+#.+>3R]\F^1581
M;V8<X2OZ#OB]\*M$\4Z)-J,FF6FI:WID$TEF$L[>8>2TAG>VR8F(65L,4!`9
MMS$$DU_*%_P34UYO`W[1>BZA>I>0V^IV>K:*VZ(R1*\D;2QAE7(D02IYFUU`
M60*X&>1_71X8O/'OB/P_I=SH5M#I$%S<6;SZEJ\`D>[M()(&G,<4H+$W,0D2
M-^RM(`<,:_#,^CEU?-\_P$J4JU/&5:.8TZ=&E[:U;'PC>K>$7&$(5TW-[O=.
MZN?H&<X?'9;#AK-L/66"Q"RZC@:D\16EAW*I@:M>@Z<OM3;PZA32U<N1)]&?
MFC?>)_%MYJ;^'K2WN-'LDWP7,3B2.8L&`=4`(VKE<D#`.X'!QFOKOX,_"A=9
ML(GOYY1%''&4=@5(*F9PN3U"LS,H'"L[D#+L3W/Q!^"6EZ[XJAU71-0M]+U]
MG+74$D@2QNG:260.L$:D`[-_GA0N1Y`?.Q-O2^"-0UKP=+:>%O$]D^F37#7$
MNEW$S)##JEHA`:ZM]S_:9(=SKM*@*H<8ZBOS?!9/B,%FT?[6H*6"@_94JL%S
MX;GD_=C*45RPDN973LU/W=[GJYEQ%0S#(Z,<AC'"X^K1C7Q>&E24*T(\E.=2
MI3NVY1J\GM%K9PE&5HI)*"3X<6\<CQ@L0CL@)4$D*Q4$G'?%%>Q%XF);*'<=
MV1-<X.><C+=#17U;RC+KO]S#?^:7>/GY?@K]3\]6>XU))UY75D]([Z7_`%_I
M,_S2O^"?/BK3-6\3CX.>,&GT[5M,NYM0TFWO)&B-]I)N!'>6UI-(05&FES<6
M=DA"&"Y'E(%7-?UF6GA#X>>$/@5XDUB/P;H&LWNGZ%-_9DUQH.F:G=2R_9]X
MNHB]K+<1>9%"A8Q%6#%V)RV:_C[U?P9+_P`)C!XY\!ZG<^'O%_AO4K#6-#U*
M"'?YP2./*70&T'3)U<V%[;,V(HQ;J(RB8']-'[#O[6?AWXL>!)_"'B]/['\:
MZ99MI7B/P[?JD02Z6TEC:XL'W+#<Z5?+NDM7PY*[XW`"@'[CQ^X(X@PU7`\4
MX7"XRME%*4GFF'I.HJ.%KQC&4L0U1O4E2G&TI2=^6M)QNH)GF_1Q\<N%>)LC
MI<&//<#2S_"5*.,RZA4Q5"AC<;A<5+#S>#I>VJ0C6Q6%?M8>RIR3G"GRQ3D[
M/YG_`&:/C-H'P]^*6E:SXD^&UJVDWNH77VW6M/AO9-4M9)FGEBFLM/F)C1K1
M)!'(T1B\M)(U.5(`_H=NOV]-5UO4?#/A;X4>!;77+!-*L+=];UW5(4ELS+:I
M#]GT[PSIBM>76HY<O&F\"*15+<S&OY,?VL=$^*_P=^*?_"9_#G7#=>'['Q*F
MK:IX.U"*TNO"NO:-,6^U:)J\<4;S65O>V?VF.VU"T426=RL3Y5_**_I9^Q__
M`,%6?V>_@1\,K_\`M#]ECQ%9_%6TU)M>\+ZK8:K::WIT3HT<[6BZM<D:Q-:0
M1M#'$M[+</.3(JHOV8@_/5.'LTQ^%PO$7#F(C2P.<82E'&ULOG5Q&)HQP\:U
M?ZM4P\XRK.;@HM5*48TXQ3<VHIR/WO-L5PYF&95\IS+(<[SK/,IES91@JE7`
M8#)<=0S*$53Q5/'5,714/J^*M#%4*T'6E4G.E2I8J+5&O_1JOQ-UGX5?`#XH
M_M&_$KP[?:+X4^%_A+6_'WBFYU2UMD\9ZKH^B&UMK[2?"?A8SZ1"_B.[:[4Z
M'#K6OV\.ISK]E:PU&27-K^4__!.K3?VH/VDGN/VXOVG_`!QK][XA^*FO:B/A
ME\+H[J]MO`?PW^&VDW!LUM/#/AES]BTI)+ET-O<D7&HWD44=]<7TXN(MORUX
ML_:@_:;_`."S7QM\&?!R7PC_`,*<_9F\-:I9^(/%?A;1]1DU._UR>!X;V;6O
M$.II#;BV$MS;6SZ5IK27&R7[3*%B>U0G^E+P=X$\.>!]/\.^"O#=BFF^&?!G
MAW2?"NC:?#'$EM96.FVT:BV18E2-Q),7N9G"A9))<G<R$U[&9X2CALK>28:I
M/$OVF'6,Q-;$4:M2,HUJ.)5%4:,JE.A.M6I.M6Y*DJE*-'#0K*G4KU::_.LQ
MPM7AG_A2S3#T<MX@SNGC5A,EAA\33AD^2U>6G.I*>,I4,3B,3BY1>'R^K/#X
M;#4\'0S.>%HU,/7R^M3]0AG'E18M(B/+3!:)"Q&T8+'NQ[GN<T5:$%P``-N`
M!CIT[=Z*QC@:=E^[GLNW]W_@_?\`=^8.I0;?N1W_`)I]X^?K]WEI_F<6BJJC
M:JKG&=H`SN))S@#.3USU[UUWA*^O=+\4:/>Z9>76G7GVRWA^UV-Q-:7/E2S(
M)(O/MWCE\N0`!TW[7``8$`445_>'%G_).9I_V!5?_24?XV\`_P#)P^%O^Q]E
M7_JPHGZ5>(O^)F(1J/\`Q,!-H)247O\`I8E0QQN4D$_F!U+HCE6R"R*Q&5!'
MQMX#L+$>.[^V%E:"WMYYI((!;0B&"0&<B2&+9LC<%F(9%5AN;GDY**_A[A[_
M`)$.;?\`895_]*1_TI<#_P#([R?_`*]K_P!*H']4/_!+O0]%T[P+=WNGZ1I=
MC>7=W8R7=W9Z?:6UU=2,-15I+B>"%)9G8*`SR.S$``G`%?JWH;N][<;W9_\`
M2T3YF+?(CRE$Y)^5"S%5Z*6;`&3117R.!_WO$?\`8=7_`/=4_'?&#_DM\Y_[
M`</_`.H^"/069@S`,P`8@`$X`STZT445](?BI__9````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]A=F%T87)S+V-H87)L:65?8G)O=VXN9VEF````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C$P,2`Q,#4Q-30S-#$U,"`P,C4U-38`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA(``@`/<`````````
M,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!F
MS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_
M,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,S
MS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,
M,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`
MS&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9
M,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_
MS&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF
M,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,
MS)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS
M,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9
MS,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`
M,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]F
MS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__
M,___9O__F?__S/____B_)```````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"'Y
M!`$``-@`+``````@`"````C^`+$)'$B0(("#")TH7*@00$&#"",RG.@DH<.'
MV`!0W,A08\.+#SURI"CR(\:2(Q>BK(@QXT02,&/*7`FRH$R8*6EB),'QIL^8
M+!_^_/FLJ%&C)&IB`ZKP9E%2"H]*?082IQ.94$GEV;J5%*FI1T$VY>DUZU>P
M:*D.A"D0`%@G9Y\Y2:NVH%NC9^<>A9I6:4:C<S7BO<MW*D*[1>%2U?N,%&'&
M4TF1&'@P<=ZO<>72E=S6,>"\BI_2;3PYH^?1J)^5-GTW-5K.$%VG=1Q2-EJ_
M;6T;;MD:\,>(NUO^E:O0:^3>M(4/E^T8-^+4S=D@<1Y[]D$VTJ<KAWBP;',`
MV*4?8]>^W2["\./#DR_?%HG[Z>K12Z=N]_U[\$CDS\<6$``[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O87!E+FIP9P``
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-C$P(#$P-3$U-#,T,34P
M(#`R,S4R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#
M$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#
M`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S
M8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H
M:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#
M`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!
M`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q
M%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X
M>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`.(^
M)'[7GBOXL^/XOA%^S;X<T^^;Q=XIF\)>"M7A>&/Q-XTUR^N8;2PU:P?7#81>
M$=.O(H([V5+TV\NF6I76O%%]8:=!K%G'\S6=_P#'_P`3>*KO2]=TWQ/'KVCA
M[.]U#Q9966B2Z$;G38]0BAU!M:M3%`);"YT_73:7>FOK4^B0L='DL[>_NWN?
MA[X5>.;V3QMJWC73;NSU'7/!?AVT\<>#/"NE>,4O)1XN\/>*?#G_``B^L7]_
MHUK;ZIHNA*\MOJ<=_<?VAJLUUJ@MM'\1V%M'X:CU7]7/A;J7Q)U+X(V'Q+US
MPOXIUWXD>+O#WAS6H_#UE%K.MZL]CJ>C:1;V]WXBU2ZA^W:/?7=];RZ>FEPQ
MQZ[XFU:T\0:K%MU"XT\P_.TO9IM^RC>4H\LG"\JC44[MSBI7ER1DE%ZM7:5F
MSZN4ZU9WE6G[J;<8R2A"-TDE&%TE'FDFVG[NB;;0W3I+?3K==0\0>)O%5SJ5
MG%;"QTK2K.UA\/Z-=>)O%D%LL!U>ZTRYBO(X+>TTW1[)X=$BU>VNM8O-=NM<
MTIKS3K*S[?X??M1O\.I?#TO@/QQXR^%'B*2&*]T]]5U*]UK0QI+Z3*-(NM4M
M-4DGT;7+2XECMI]6T_4=3OH-4BLK.R<6FNV3H?#_``C%\<IM0O?$7B+PCXA\
M.:'X7TFRU&^DAT__`(1NX\0Z7:W6B>(K;2M.?5=+N]1\17[FZN[Z?PII^K:5
M#>:9<WMN+C04U34[C5O"=;\7^(/BA?,OBN&[%_8W<T6G)H?A:6YU`RO^YO=,
MDM8+VRB2..TTJ34K:?4#<7DR6UQ;M>6\,5O;G=.UN:ZU7PV;6L8IM1N[-R3T
MTY+.ZNDX<GHH7;UMS\T>:VKM*35FE%I7UYTURM*Z_K6_8[_X*6^'_BO<:3\*
MOC/%I>B>(]4ED\/>'O&UA#)I?AKQ/>6\,UE)X?O[-+W55TGQ.;B*"Q@-OJ*6
M>K:E>C3K>RTC48[&RU7]%+FWTX:A(EA<WJPSP`M-,BXO8442^5-*\2AFDD$E
MS:P$+,]PL9A3SHI+=OX._AUK.F/XR\-_#W4H`8K.\U'59=<?5[37/"__``@Q
M6\^WZIJNF7=U8VJ:;HMM?^)"=8N0VGV"ZGXDLXO`NJ>*-1N+:Z_;?]CC_@JC
MH?PQU'3?V>_BU\3/#WQN\")/I7@+P=\7O#G]O7'B3P%J4VE^'M!U&U\6OXG\
M/:.=:\/?VA?RZK%K>G76N1P6L.LVL?B/Q&--M;5\I152RIU7&2;3Y%&^T7))
M/FC)J+4G%)\R=UI'6'%KWDG33LI*^C;:]Y*45;5-;<NB6C:3_H(`0@%[:[WD
M`OBTMW&X_>PTD32,,YPTC,[=78L2246WB=-5MX-4LM<U&[L]2ABO[2ZT[4DG
MT^YMKQ%N(+BQFMY3;S6<T4B26TL!,,D#(\1V%:*Y/9MZ\M7772E?MU4VGUU3
M:>FNNCY9)_"UMT?]S_)_<?Y97[,_Q]C_`&?/VAM-\:VUEI>J^';^4>$?%SRS
M:G!%?:+?:]I6J76OQ7LFMZI?)-IVMZ1IFMJ]MJL!U:PTQK)KC3'U.>[M_P!4
M/VG]7_:,U_QW!X3^#^N7WA#0H4L+RPM=/O\`7?[6L-(AOGTYKF^%B]M:7.KZ
M?<6^GSK%J9L-'>:"?S7C$\QE_#?X6R6-Q\5_AS-XAO'BTR?XA>$)-<U"9_,D
MCL9?$FGMJ=Y+)*DY=TMVGG=Y(YMS`LZ29*M_6YX1_9B75M6NO'OQ2\-^"WT7
M5O!YM/#OPRU74KJ:UN=$BC.J^%M:UC2-0N([/1K`2^%H;G1_"36NFVO]E3W/
MB:+51IMM:0ZOW>S<E&$6^;E2N[:VM9S=G)Q;Z1B[M[<M[31ES1G?1<ZDDFTT
MFU=12T3:2UEM9M-RW_(K3?VF?VQ/@XNG:Y;^)=;\4WVF^$8F@T'63K&HVFJ:
M*M[=ZS:-JDEKHHD\0ZU_:-_K%WIEW+IOAJQGTV9;..38+W2;WJM*_:UM?B38
MW[_%+X5):^-]52^+>(GO]2LM;6QT[4QJ,K^(KV2WO/[4U#38VL3;>'O%=SK>
MF^'M!MK?2--T-8-`6:Q_1KXH?"SQ'JNAHGQ4^&%GX=U2QT*VL==^)>C:R=9O
M==\1VUUIT-JMAX>TOX:Z3+X16XU'Q!'<7#W&I6?A'1(;230=0MM<;<(?R,UG
M0A_:_B"T2QU&PMI))[0Z;=[8I+!9KMM.:T@26U2SAN+EKFYGFNOL5JW]IV]U
M?/!(;Y;;2,9.I!+EFZD5+53YFFE&Z2BV^G*^:$5JEYI:R]RRDN6\=+)*2?-"
M,N9-:/=<LI-+5+5&_P#M2>(=>UEO[8^$VMZG8:WX\OG\-7NH1^*-0M+O[+>W
M%U/K^OSJFEVL=AH$FGKIUM%I+3RR06=W8:AHK7-]X?U2TT./PL_B;X2>'/$]
MAJ^K7FF7FL>%WEUJ*-M&:]UIUL-0ATJUU_2UN+&&&=]2G6)Y]1M(M;T\ZK>7
MUEI\\TUKI<WQW\4_COXD\,^/)M-\-0:7<#P?IUG:-=^(8'N+A]4D$+7]S%:/
M>6%IJ)>2XL5DMKK29B9+![S[%%;PR,O::MX\U/Q!#>^(M8N+[33:6/B:6\FM
M[C2?$$FO3:?80G5M!M=1UD+;6.J:;9>')]5T)FLK^TN-/CUFQUCPWI^IP6<-
M[$VU4C)).ZG[*\KRE)TZ:<VWS>\K2E"*M?W%'5V<Q:DI-N2DG#G45:"CS2NE
M:UDV^5N^GO.5]&OKFR_:\^+&@6=IH6F?%CQ/:Z;HMM!I.GVUIJ>L+:V]CIT2
M6=I!;+9SO:+;PP0QQPK:N]L(U40,T6TDK\O[_P`=>*(+Z\ATP^#[K38;NXBT
M^ZO_`!#H;WUS8QS.EI<7C6^NZ;`UW-`(Y+AH-.L(6F9S%96J%8(RL+8EZIX?
M757<;ZVM?FM*^JW5]-5>QJJL$DN?%:*VCG;3M;2WIIV.R^&GP3\.:E(M_KKR
MZUI[Z?/=!97GL+)O/MK<V<$$NBW\YN=1CN)XY1)#K#V#VIDF\JXBA5YOZW/C
M=J7B/1)?AOXL\*^,-$\2>#HO@=\*+WPX^KZS8Z;'XICT?P/X973]`TZ^;2=0
M\%:DRW.C6NG6MGK?C/PO87-Q9ZO!<>((GT*UC7\=OA]_P2A_;#A;Q[XC\?VG
M@KX::W\-_!^M^(U\`>.]8\9:A-+J;Z9KNO(^F7GACP'XYTZ"_;PS)?Z1?K<:
MOX=OH=6TZ7PWINE:E>6,^F^'/TF^'>L>.CX*T']G#Q\MUJ>L_#RW\7Z3\.OB
M'X*N8_%>E^)?"$^FW'C%O#-Z]]J$6H37ND6EJFLZ/X,UO^R?%&C^%]=\/Z!K
M/P_,^O6,=:+VE2C.3KQC*Z:FY0:]Z\7#ENH+WK)QLG+6SO)-:4(JG5BO83<9
M17N\LHO3EDI<UG+5-M/51:3:]VS\>\2_%7Q=\0/$UAX<UJVN]`U3Q)/!%I&E
MV-YIWC:&ULYX9K+3[6Y\;:!?:QX.L-135T2]_L[5;C$=U/)NL+ZQNK#4X?AG
M]NOQ!X7^$?Q.MM1WO//;^`/"\NIVDEG_`&:9O$&H+_Q+M.33X[:9!J$WA33-
M!U:XDN+O2;^^O7.K:UH]A/%-*GWKX9^*"^%SH;^&_#WAQM3OM/NM;CUG64CB
M\+ZWX9TZ]:\U)[0IJ>M:EXZF>:ZDTF\L;K3-+LYIM+T^T'BO4K=[/4)?CGXN
M_L$S_'/XGOXSF\="'X>_%>&'7KWQQXKU6R?Q_P""SI5WJ_AZRUNY\%Z7HUFE
M]I]C>6VOOJFAZI+X7L'O9U\,+XFTB.X\.>(-)FE*HH1C.M"4?W5G3=YQ5^;5
M2G4D[12<4[R@N9.+T-,1",[^RISYW*3ES^["R45=6C"/O2DTY*T6G'EM=L_!
M2^U[6O$?B'5=>N[E3JVJ0ZO<7LR6S.C0R:7=1WD*0PP7+(K:>);99W4^2"+J
MZNX0DU[']*^&_$4=M\,[P6NK7T=_/'X<U&_6VFL@^G0V.J13ZIK3/:Z5820Q
MV>E6$5AH.C65_P"(M(CLO#5OI%]91W]M?>'++]7_`(?_`/!%GP@;_5O"OQ%_
M:,N](U:3PCJ>MPV$_@B;X=7T3P?$+P=X1'V>ZU^XUO2/%BV=WJ>C2W6@76N:
M/)(VMPZAH"SVMA=ZY/\`9?@;_@BU^ROI&NZ-H'Q7^)7[2%YHVAKXFM?B+;>`
M[CX:ZA-X-TZ3PQ=V=YH'BO4-"LO&+:#XFM[GPE:7VI:EXDL6\&:5H,FG6NG:
MPT]WH(\/[5)PFDH->ZTEHM8V=E'5-\UG"RO9[K5*7+3PE>-Y3@^K?O)N,ERM
MJ23ERM)J6J3DM%KM_+C_`,(W\2T^72+K5GTI?ETQ[7Q9;RVKZ>O%DUM(M]9+
M)`UL(C"XL[0/&586T`/E(5_7YJG_``1'_8=;4]1:VN_C#>6[7]XUO=W_`,1O
M"XO[J$W$ABN;T0?L57L`NYXRLMR(;R[B$S/Y=S.FV5RL/;RZJA?J_8SEK[O5
M3UWWZV3ZHW_LZM_+67E[1*VW3V>F^W3;M?\`93XJZ/I&G7OQ2U'3]+TZQU!8
M?"<BWUG8VUK>*^M:)I.I:PZW4$23A]6U'7M=O]38/F_O=:U:ZNC+/J-Y)-^9
M'QP\$^#-/\.:W\1[#PCX8LOB'%\4=%MHO'EIH&E6WC..V@^&?CN\@MT\40VB
M:XD$-W96=U%$M\(X[FTMIT42P1,A137QTO\`'+_VXZ7_``%_W+?^DTS\Z;:S
MM+WX5?MC2WEK;7<O@_\`:,:?PE)<P13R>%IM5OOB3/JDWAQY5=M$EU*:"":_
MDTPVKWDL,4EP9'C0K]"?"*QLE^.7[->CK9VJZ1XU^'?[*&H^,M+6WB&G>+=0
M\1>*/%FF>(+[Q-8A!;:]>:[IJKI^L7.JQ7<VIV(%I>O/;@1T45%'^%_V\O\`
MTY4%+^)3](_^D1/U1\$65G9^&+&TL[2VM;25_@AJ4MK;0106\NHZM\-=,\2Z
MI?R01(D3WNI>(KV\U_4+IE,]YK5W<ZK<R27T\L[Q?$'PYX>L+;Q]XBL=!T6S
M\0>&-?U-?#6NVFEV-OK'AY;Z[^"4]ZNAZG#`E[I*WDR)-="PGMQ<2HLDP=U!
M!17)/X)_]>I_^F\0>@]J7^.C^>$/FZ;Q%X@N9IKBXUW6;BXN)9)IYYM3O99I
MII7,DLTTLD[/)+([,\DCLSN[%F)))HHHKE>_S7YP.Z.R]%^1_]D`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]M96QO;BYJ<&<`````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3$R,3,@,3`U,34T,S0Q-3`@,#(T,#<Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/_8_^``
M$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`0P$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\```$%
M`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$```!
M?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87&!D:
M)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!`0$`
M```````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1!`4A
M,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H*2HU
M-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&AXB)
MBI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9
MVN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`^!OVM/VU/'W[3W[/
M_P"SKX]^-.NVESK^C?$_PA-\4/$.@KX57Q5J%@-:UC3/$>G^'_&FEV<.K2Z=
M!9+8Z?HMC#<I%<2BZDN81>7-WNH^*OA!^U'^WG\+_B#^S@VSQ)XL\(?%CX7^
M,/V=?%_QYUKP?\(K?PMX$N+6V\/Z@MIJOB76+$:K;W?A:[A\%:K8^%--O+O4
M]/\`AUH7]H6US-I=K%#]1_L7_LU?"/P[\*_!^H7?P(^*/[2-O-K>JW\7C#QE
MH?P<\#?LYP6&M:K#XRT73?@G\./V@?$*>/?%NC:3J.LW>F>&?BQJ&BW&M:RE
MG)K_`(.?2M,NDMS^BWCR6UT+P;9V?QG\`VOAOPOXGU6+PMX6\">(_B?XQ_:`
MO_&'B">>Z@MK"Q\.:3=>#=&LS9W%W?%M5^&%_J=Q87%Q=M*-&1[K4)/\V\3Q
M-DG"^;8?+\DH8/$9CDN=9AC\'C)T5.I@(/$1Q-HV;QE"#C0KX6OAJLHWP];E
MJ4W92C^9TLPP\ZE*E.HU452,I+FE9V5K]$][J7<_!_\`9)_X('_M#>,?$OQ"
M^'_CC]I_X=?`[Q7X/M]1U_7-,TKX6_&;QAXAO_#,'B6?1+GQ+X,OM8L?AE'J
MFG67BC[1IJ()D@U&XM'UF":_\/W=AJMU]E:+_P`$F?BOI/C_`,._LUW7QQ\,
M?M`^&_V?=5U8>-;FRTC5OA3X%\*6'B26>_\`#OAGXI_$.?Q#XBTS3O$7C35-
M2CO-5\`_"A?B[\48_#=_:WL6A>']#N+:.S_<3XE?$.7X8?L]>*Y#\4M=^'GB
MGX0>`AXZ\+R_$"*_^+GC'P7HAM+#POJ"1:.=+UW4;#X4^,[ZXO\`X:W4'C[6
MO$5IICV]IJ&FGQOKGA4RZ3P/P%\5>$_@+\*-6\*6VWXE>$=1^('C;QM>:[X8
MU;QWH_A_Q/K6J0Z3I=SJWB71-+MK#6=5AM=!GTK3OLWB-]0TI?"EMHNG>'?*
MO+S4)V\[.?&CB'.GB'B:^4X:&.Q<</0P4<%2A2K8S#QYOK$<1*FJV-@J59N5
M&5>\*CHS33A&_O3HY3C:U.C7JJG&K9KE=G*HGI=1TU?-S-ZM?(_E7_;1^$?[
M??@SXI_LY?#?]M;X#^"_AK\&O!OQY\,:?\/_`!K\(O@+\#=.^%=IX$TOQA+)
MJGAKPW^T%\(/!UOJ?BW1+33'MM0GT3XLI<ZK<Z_IU]?^,+6/Q3::LZ7/A?\`
M&WQ*_P"S=\;=3L/BYK?@#QI\9+WX[>._'GQ#M[2,*PN]<O=`_M&+^S18V^@Z
MIXH\*^$M+T:+4=.A%S-!<Z[XBB9KTV#-_7+\)OBKX(\0ZIK'@73/A/\`#_Q]
M!X5)T[XH>'?A4OP_CU/P_::C923:?:^+_@%\4)+/6/">EW>@:E`UQ:VC:MHK
M17DT]K%Y%ZBU^3'[<_\`P3S_`&7_`(EZ;;Q?LO6_@[]E+XKV_B;2[[1?@;\7
MO#OQ#^$WP`^*<-K?3ZW=^$/!6H^)]&UKX7>"?%'B6'3;2X\.W/AW5++P?XG\
M7R2Z8(M,OUE^S?5Y1XQ8+/*N5\,\0Y*\DK8?,\#4CF&$BY9?B<)&K'$5XU*6
M(YJU"A6J1PU22E]9HU)4X2G4LJ=O.SO*<%6A3IT)^YAYQ2::NY)/JDE*[6J>
MKM%>\XH[3PO_`,%?_AY8>&?#MC#^T[H/@^&RT+2+2+PE<_$C1["Y\+1VVGV\
M*>'+BQM_#P@LI]$5!IDMI`!#;26K0Q@(BT5_*3XN_:L^(WA'Q7XG\*>)/%]Y
MHOB'PQXAUKP]KVC>(/A*-2U[2=:T74KG3=4TS6]176YEO]7L+ZVGM=2O5EE%
MU>133B1Q)N)7[W'PUP$E&2IU&I)234(6::BTU:@U9KLWOOKI\]_J_5Z>T:TZ
MRV]S_@_CYG]%_A3]MKX6_%#X9>*?VFM7D_X9]^/'Q#U"_P#A3\+?BWJVF:M\
M:OV?_A@^BZOJ&@^%?"=QX(GT'66\'P^,M/TN\\5>)O&>G:!XE;5M?N(-,N[N
MW338=/LO6]+U^V_X)_\`P;\(_M(^-M$UKQA\2_COK^N:;!\9_B/\1-5^*.ER
M^"/`W@[4?%OAWQ5JOC70!;:U?^#_`(FOHVKZM%\#=$N/!GB&?5_$^A>"/'/B
MK3M'T.<^!/Q3^&.I3Z)\`_V3;'7%TBW@/QSO[W6;/4+>W72%L=%\5_'#Q3HE
MH(I4^S64.G>)[N/[#:!%CM]0LX+NW6.>-)!ZYXR_;-^-WPW\4?#^V\#V=K\2
M/#?B;Q1XDTOXH_!OXB1_\)+\$_B=>^+#X*D2W\9^%=;:[TZ?Q?8:KIE]J?A_
MQ'9V,EW:3V]K?B=;Y'EK\[_U*X8SG%PRNIA:.`P]?-,UQ..Q]"I)U*N6Y3#$
M83"X/$-6K_5Z<\-*M4C&5W.-/G4E*<7Y5+#^\J7Q5%5=7G;?-9)K23?,TG+O
M;35=_P![H?AUK&H_L9_%K0-,\5_&/X__`!!_:7^%/_"SO$EC%IFA^'O%&J^(
M/B?H-EIEEX-T'P;S<^%+#P/X(=M,MO"OB62^?2+<W]OIXCL;KRV]U_8%^"WQ
M/\??LO:'H_B-/C7XOU#0KOQ9X%76/&UQX!M4T?2-)*V>C>'K/4+RPM]8\265
MCH\UGHFHR^,-;U2\MK^UO?#6DFR\%Z?HNG6OP/HW[6WA70M5'Q'T7Q'>?"K0
M=/UNR\523)>W8MO"=MI6IQ6^M:=8^(4G0V]M=P1/H5A(@B=K&X-C,9%:4-YA
M_P`$^_VLO&/PP\4?&GP#^T/\<-<EM_'#V/QA^"OA75-;U:Z2ZN]2U&\_X2K3
MO!NJ6\XBN[K5/">L^%K/5DOGCD;6=*O=/821Z?$J_P`ZXGA/,\=PIQ\JV%JX
MNEEV>X3/<'C/80HTHT(RG0E0RMJDE1H1H+#RKI*G[3E3>RB>WE%2E.E6IUY-
MNG63C-/WHM1=DF[M*\MEV2ZW/U#\3?LS_##4=.U&W^)NDW,_AKX-_$:7X;_8
M?A!>36?Q_P#V1]=UJ32-=TG6_"?CS3M=\,ZUI_PMN]$\8>"O$_B#PK>^+/&7
MAKP''XLO;KPCIFD_#OPM<>&-.--_:.^$7PW\)_&S]F/]I#QS\/O&WB+X/^(M
M,\$^(-0\6M9^.?&'QW^#'B_1+3Q!\+_%WQ"$.AV6BZ?>:[IMWJ?@_P`8-I]@
M)].\2:5=7)EO7#:C=?FA^U3^VU\2_$'Q7^.G@+PW>ZG\-?`OB']C?3M;@NM.
MC%O)\2?$OA'6_B+HMWXFN(;66,6NO:=HNJ:;X(_MJ8-?RZ#X<TRQ6Y_LVWL[
M>/\`+'Q1\0M9N?VD/B[XZBU2:]M?%7[/GP1\0W^C2+I3W.IZYJVF:_/H[Q:G
M<12RK<F)99I)3*T[37=UESOP,H\#YSQ1E5?!XZM/!X.CEE#.<LQ&'E-X^GC)
MX_):=*E];@N:-&='%XA5:'-RQJTVJMY4[GIR]ARR=*I*4KN_,VVUM?6ZTM=2
M]W1NS=['[>0:G\*M,@ATWP?^U[\1_"_A+3XH[+PMX9_X5UI?B#_A'?#EH@@T
M30O[>OEDO=;_`+(TR.UT_P#M>\=[K4OL_P!LN':69R2OR)TGQW-?Z5IE]/=W
M]E->Z?97<UD+C1L6DMS;1S26HQ!C%N[F(8X^2BOHX<+<;1C"/^L^=/EC%?[S
MBW>RBMU4UOKKUNC#GG_-+_P)_P"9\^>*=-T/7?A%\&/#22:=J6C+XALM,\6Z
M?+>6=UI\_C**_P#&.F>+=9L-9BABU>UE3Q:U_JVEK;RB2T352D3H78M\]?'.
M77Y#8^(8K[4[6#P-K?A/5;?0]!TXW5_<Z_K_`(GN8-*N;4W\TU^-7TR+3;33
M;6Q:+[+>6=[-=OE]2N/,^S]>\.1V/@O2K?5-`TF./X;_`!GU:'4M&>&WO[B6
M5?B8EG:1VNKRZ9I\D_VFQ\0:7-<SK;(MY(1,TEV-EU+\X?M*Z8/"]M8^([>\
MU73/$_G75[86\%G'J!O[?PA%-XSN4U%)`8A8:(^FW5\^LR[M3BF,ME:,(844
M?T=0IQHYKE[5)SE5Q&<.G"/VGB)47-/E4M))3<GRRNVY6;M?R:"7-A797<;-
MVW]Y+7NO+L>W>)]!G\<VWB6PTZZO#:VNE7^JV/A>24#PIXGOWFT]-#TSQSH4
M20VNK:5IL]B+N;P]J5K<Z9INK+<Q6$"111$[7AS4?%6F?&G7?#_Q`\9Z5\2M
M+C^$]CXJL;JRTFTT:T\`^-].USPSKVJ>&_#EJT*:AHFCZ1I>MVMY<W*&.U\0
MOJ3:8/.M+"&"+;^%DL5WIMWXALYM.F7Q#I>E:K]IL(O,L)EOY!>IY,5S'G3;
M:1YS*L%Y&8H2YV(L>T5X#K_BK7YOVG_%\&MWPO+KQ'X1N/#69+IK^/3+'2-#
M\+:_H6C:9JVE-;:>\]Y)H^H7\%I8Q1-:33S0RJ]Y'<R/\+A)X['8?BG(IN/U
M2&79ABG1=TZ=2A6HM14;I6BN;3X;MNVUNC#Q2G6:27[WLND7_7R78[+Q3\0_
M%;_'IKCQCIFB2^$O&OPGU3X6>#1I.NVUQ?\`A_28M5U7Q!KT%VSQFQ\0:@UR
MET)[$Q+;1:1=:?I]YODMVQ\OV&K^-;.R\+:?(UA#KFO?!&WNM<G@N+J:TM=(
M^$=UI5IX/6**[D=[;6;FVO[RVUB.+;%'K,^LQVH6VF*MVWB(ZI-\7/A@MT+$
M:,FC_$2P^U3S7BW;V6H?V-%K=Q?12-)(VHFVD@LTGE9II8Y+K+E)W4^57;>(
M-8TG3M7T&TL]UK\*/'\&K3WT]W;7%DT/Q,?3([>SD;;((YS!]ML8D8(D-Q&8
MPH(S][PU@4\ORVA*E3_?932INT%"SPM;,,+&[BU=N5&-22:]^I%2EJ>]1HQJ
M**25[KHKM>[=7MMMZ(^E[?Q&X@A"WEN`(HP`;%<@!%P#\G845Z[_`&#X2@_<
M3W6E130_NIHC:3$QRQ_))&3Y7)1U*D]\45U?ZN5.\^G?^YY^?]61Z_U*/:/_
M`(#'R\OZMZ7]`^,LDG_""_&!_,??:ZQ\$;JU?<VZVNKKPMX$O+FY@;.89[B[
MM+2ZGFC*R2W%K;SR,TL,;+XY^U_%%%X#DNHHHX[EO$_AR%KB-%2<Q:GH26^I
M1&90)#'J%O=74%\A;;=PW,\4XD2:16**Z</_`+_@?^QGF7_I4C\ZPW^^4?Z^
MTCVWPBJVNF:VULJV[>7X<AS`!"?*4V,:Q9C"GRUC_=JGW0GR`;>*^&OB1&EU
M^U#XZCN42Y33_B)I\M@DZB9+&6#X2NT$MFL@86TD+,QB>$(T99BA!)R45\3D
M?_(^XP_[$V;_`/I$3U<+_$K?XU_Z0=AJ<$"^+_@BZPQ*]W8>.Y+IUC0-<NVB
M:%=,]PP`,SM<DW!:0L3.3*3YAW54/^D:%H*3_OTN/`7PC:=)OWBSMJ7Q@TVV
MU$S*^X2'4+8"WO2X8W4`$4_F1C;117V7"_Q9+_V#5O\`U98\]G#_`,2'^*/_
M`*3$_9`>$/"<P$TWA?P[++*!)++)HFFO))(XW/)([6Q9W=B6=V)9F)))))HH
MHK];73Y?^XSZ6.R]%^1__]D`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O=V]O9&EE+FIP9P``
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-3`P(#$P-3$U-#,T,34P(#`R
M-#(T,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_
MQ``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#
M!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*"
M"0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS
M='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$
MQ<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!
M`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<`
M`0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9
M&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"
M@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2
MT]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/[?OVCO
MVB/!O[,OPXE^(?B_P]\1_&\]WJD7AOP=\./@]X$UOXE_%3XE>,KO3=5U?3O!
M?@'P9H437&K:_?Z;H>KWRO?76E:)I]AIM]J6MZSI>F6ES>1?DI\;OV_?"GQ`
MT*P_:Q^'?P8^-?@SXE_\$R_CGI%_^V9\`OC9\,9/"7Q]\#?LB?&OP-XH\,_%
M'QWH/A.QUW7-)\6^'$\-0:7\?O!NN>`O$GB`^-;7X#ZSX<T6>ZN9=4T&^_=^
M6VMYY+:6>WAFELYFN;.26*.22UN&M[BS:XMG=2T$S6EU=6K2Q%)#;W-Q`6,4
MTBM_-5\5OC!\.?VI?^"FOB+XF?LZ:IJ&K?#/]G/]GCQ9^SE\=/BEX;MK^S^&
MWQK^.>N?%?P[K_A[X>Z5KK6D6A_$^[_9?T?P1XXCUWQ#HL^K6?A'Q!\:?^$4
MT[6X+M/%VDO^+_2"\7<M\"O";B_Q0S3#X7,*?#>`A5R_)L5F,<J_MK.Z^(IT
M,FRJAC%A\75A5QN/J4:=14L'BYPP\:N(]E&E0KS/I^#>&ZW%O$679!0G*C+'
MU)QJ8E4W6CA,/3I3JXG%3I>THJHJ-"$Y0@ZU%3J^SASMR4)?7'[8_P"V7^S1
MK>H?\$ZOVB?AW^UK\";[X1>!OVWO"-]X_P#&6D_'#PY;^!1X%^+O[-'[1?PO
MTZ^\2>(=-\5Q>$[*Q_M?X@^'+NV7QI!/93M,EK82:9K-U8WB?7WPL_X*`?!3
M]HKXFQ^!?V5;77OVI_!.E-:I\0OVC?@?J?@#Q-^S1\/KR\M[:XA\.S?&"\\;
M:7X?^(/C:U@U+2M0UWP7\)/^$^USPQI-S/-XC@TO58;;1;_\F_$O[,O[.OC#
MX;:U\'/$?P-^%&I_"GQ'J\7B#7?AV_@/PU;^#]5U^"ZL[V+7;S0;/3K?3Y=:
M2[T^QG&K&`:AOM(";@B-0/I?X%>`OVA-(^&ES^S5^Q%\0_@/^R=X2\%Z"_B/
MP/)JW[/MY\5M*T>[DU+4!K7AG2_!.E?$WX6>&?#GA_6=9U72-?U+58$UG5[W
M4KKQ7=/:+J>KKJR?Q!]&W]I1DOCCXF9-X89QP'B>%\UXJS?.:619CAL?AZ^7
MQPF!RAYCEV&QWUBI*M7SC,)X+%8"JJ-&AA:<5A*E*M*525*A^I\;^".-X4R+
M$YYA\UCF.'P%#"RQ-#V4X5?:U:SI8O$P2BH4L+2BZ,HP<JM63E/GG:G'VG[9
M45\2?LE?&G]J[QGJWQ`^$W[7G[-@^%WQ,^%PL+@_&KX7:Q8:]^RQ\<M"U[4M
M8M?#VL?"2[U_Q#_PM;0/$ZV6C3WOCCX<>+_"]X/`2W.C+)X]\0MK]@B_;=?Z
MB0FIJZNFG:47;FA*R;C))M7LTTTW&46I1<H2C)_@KT"BBBK`_E,^(W[5'[37
M_!4KXS?M!>!?!?Q%\;?LQ?\`!-_X)_%/XA?L\N_PJU&#PG\>OVS_`!K\-O$-
MUX1^)6K7GQ8TJ_U#Q#\+_P!GVUUW1[S2=`M/AO/X4\;^/](U'5+/Q/KNEA+K
M0]+W?'G[+8T;X&?"SX0_LI>(5_9NB^!WC[X9^,OASIOA:75['P3>Z-X,\51:
MCXK^'GC_`$G2;VVU/Q=X,^(WAG4/%6F>*+2]U)KW4_$.KVOBO4KR^U2RD>Y^
M@?&?_!+[]MKX'_%'XJW/["'Q8_9DU/X"?&KXM^*OC5=_#G]JW3OBPOBCX)^.
M/BKXDU+Q=\74^'OBOX7)>CX@>"-=\6ZAJ/BSP[X.\86WAK5M"U'Q#J>F?\)Y
M/I-A8Q3\;?\`["__``6ZT?5+F\T;XY?\$PO'NG7=N%31]>^%W[4'PQCTBZ"R
M8FL;[2?'/Q1N[VWW+%YUMJ#&2?SG:&ZLA;+'=_XL_2C^C3].CQI\7\[XGPN*
MX6QWA_PKQ`\7X8\,XCB;+WD/]E4F\/A*V)X9QF&K8?&9SBL)6KPSZOQ!A[UO
MK&.P6%K/)GA<.OZ=X%XX\*.&^&<'@*U/,:&<YA@XTLZS&EERCCZ>(52G.3IX
M_"R52GAJ&(BJ^`5"4JRAAZ5>O3^M.*GU,OQ:^'D/Q;LO@3+XDA3XKZE\.=4^
M+5CX1:PU;S[GX>:+XFTCP=JOB2/5/L']AF&Q\2:_HVF3V!U,:L'U"WN%L&LR
MUPO5?LW>#_&7Q:^/.@?M4?L;?%+X3ZYXA^#'C[XB?L=_M=_#'XDZQX[T.S?X
M?Q0:9XMNX;+3-+\.:]=Z9\6O`'CY/"WBOP%<7FA>']#\=_#_`,0^)8(_'$WA
MWQ1X>U>R_(J]\(?MV_LP>(?VBO@U^T-X;\)_$W]O#Q)\/_!'[0?A?XJ_LV_$
MF:ZT+XT?LRZ-\<X=!U_X&_"JQ^+?@^74_@#XS\,Z'J'B_P`)^'89_AWJGP^L
M?%7CNP^)&I^*KW6VUG6V^TO!'_!2K]I_XM?M_P#[+W[/O[/V@_"7X7_#3Q1\
M:9'_`&E)O"/P-U*XT;QCH7A7P7XA;5_@+X._:*\5ZP-'^.OQ(^&_A[1I/%7Q
M*\6_"CX8^%/#7P]T?PNVB:I\0;'Q&]A\-_%?QWT-/HX\.>"GTE)R\4>(*^6\
M>\&UZ/"O#O"."Q&-S6IG/$F></X#%8KC3&/)LFGE^7^'M;!<0T,#P?+/,SI9
MAFF?X:I4Q."PV9X6&3X;T?$SCC'<4\$P61X*GB,FS-O,,=F%>C0P]/"X/"XN
MM[')^?$XYU)Y[">#5?'1P5&4?J\Y+!U)TJ=7$3_=K]IK]O?]C_\`8VU/PIHO
M[37QW\(?"/5O&^EZ[K7A?3]?AUV]NM3TKP[)90:G>F+0-(U=K&%KO4+33]+_
M`+1%HVO:I(^EZ$NI:C!<6L7A/[`W_!0K3?VL8_BAX?\`B;X?L?@9\4M`^)6M
MZC\-?A3XTU>RTGXA>-_V9/&MU:ZU^S[\7)O#ES,CQ:AXG\/:HOA;QIX?TF?5
MY?`_Q+\->(_!6N7*:U9!;C\X/VLOC58Z;^WQ^V)\1EM=9\?6?PA^#G[)'[+O
M@'PAX,C;7]8\4?'C7-3^+OQ5U'X.>%-+TJ&XN+CXE^,)/CG\$+2^L;R*5-(T
M[4_"VK:G<Z3HD>K75O\`1WPJ_P""2/Q-UOX]_!OX[?MG?M2:%\>_#OP=U#PS
M\7O!'[-?@[X#^%OA]\/OA]^TYX=NM.U30/'>A_%MM:U/XL^,?`WPZU."YO?!
M/@_Q-_9\FK>([7P_XQ\9WNJ2:'IOARR_TPR+QA\6>,O'_C7P_P"%/#SABIX5
M^%F:Y;P_QIX@9OQ3FF$QV;9KG_#>2\0PP7"668;(,5@J^:<*?79X?B#+\;BG
M2K_6L(HYEE$IT_KGX;B^&^'\MX2RW-\PSO&1X@SS#5,9EF1X;+Z-6GA\-A\=
MB\)[?,L3/&4ITZ.8PI4ZN#G2I.=)4JS='%*HEA_W$HHHK^ISX,*\R^,_AKXD
M>,OA3X_\*_"#XE#X._$[Q!X8U/2_!'Q2_P"$6T+QM)X$U^[A,=EXDM_"WBBV
MOO#6L7FG,6ELK?Q!IFLZ+'=^1<ZIH6NV4,^D7OIM%)JZ:=[--.S:>NFC333[
M---;II@?Q/\`P7_92_;._8U_;LTKXU?\%"]0^'^L:Q^UK\&+KX2_#WXL>$]9
M\-^([ZZ^,>E>.M5\<:A\+?B[XWM_"'@OQ9XG^(WBGX<^%-%\3>&->URTUGP/
M"NAWWPU\`Z]I,5AX:\&/[=_P4)^''AS2/A-\2/VC?#WQ(^(_P*^/'@GX6:UX
M2^&/QT^''Q@^(_PDO_AF^H'7=2&H:K??#?5;/5M2^'3>)-0TKQK\7?":Z?J^
MD>.=,^'OA>?QAIMQIG@NQU'1OZF/C=\!_@[^TE\.M9^$OQV^'7ACXH?#O7GM
M9]1\+^*K!;VS%]I\PN=-U;3KA&AO]&UW2KD+=:1KVC7=AK.DW2K<Z=?6TX$@
M_GI_X*,?L$_\$RO^"<W_``3C_:3UG_A3G@_4+KXO>*_"NBV?Q(_:4\7:]\;?
M%?AWX@^+KK2=`L_$GA[XG_'#Q#XI\3^!=2\.:#I6J>(]`N/#&NZ1>-XIT^QF
MAF-_):SV_P#FUXQ?09Q6;^.&5_2"X#\6\Z\.X9!EF6XO.\IRW*,5F&;8B7#C
MJXG%0RC-,'G>5U84\_P=&%#,*.)P^.JU\?7QF)Q$<PACJV'7[7P[XK_5^%,7
MP=FW#F$SUXV6/I83&8G%T:%'"QQU)1H>VP]7!UJ;67U[5J5=XBA&G1I45-QE
M0=6?XE_L/6_B7P+_`,%-O^">'Q(T'XQZ'\;_``KXC_:=_:L\/?$+P_IOP]\=
M^&/@/\,_$>N>&/A9X%M/&GABQ^)DD/Q&\:?&KQO?_M&VNI:E^U1\3]0U'XB^
M//%/B4^&KR[UO2/$*K-_:Y^U3XP_;"^&6J?#WXE?LW?#'PE^T%\//#D'BBV^
M-_[/XU?3_!7QF\7Z9?\`]BW&@>*O@EXY\4:MI_@"7Q;X073M9C7X?^-KCPWH
MOC:+6WL&\8Z'?KINIZ5_&'^Q#XIN?VH?VV_V-_#7@4V?C6_^)G@D?M=_'3_A
M&[F]^*FE>$OB%\4_VZ_@O\2[V;Q1XJTK1+SPM;:3X'_9_P#V2F\#^%M/\9Z3
MX,\+Z9=6W@RTM-&U_4[[2$O_`/0$K]\^B/C.+,9X7XW!\68+%83%9;Q3Q'A<
M/B\;0PV'QN9^TSC&XRMCL17RO+\FP68+VN(C0IYCAL)0JYE0H0QN.E4QN*Q-
M2?R'B#2P%/.J%3`U*<O;9;@'7HT_:?N:M+#4J$N>%>4ZM"5:5.=986:4<-"<
M*>'4L(L/*7YGO_P5"^'4#M#>?LM_M^6-Y"S175E<?LA_$=Y[.YC)2>UG>U6Y
MM6FMY0T4C6UQ/`SHQAFEC*NQ7Z845_57X_UY'PC=VVDDFVTE>ROT5VW9;*[;
M[MO4****!!7C'[0?PW^'?Q3^#_COPO\`$[P%X+^(_AD>&=?U,>'?'GA;0_%^
MA#4K+0M36SU`:1X@L=1T\7UH)YA;7?V?SX!-*(I$$CY**QQ'^[U_^O-7_P!(
MD..Z]5^9\M?\$P/A/\+/A_\`L6?LTZOX#^&GP_\`!.K:O\#/`>FZKJGA'P;X
M<\-ZCJ>G6%M/=6-AJ%[HVFV5S>V5E<WMY<6EK<RRP6T]W<RPQI)/*S_H9116
MP@HHHH`__]D`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O879A=&%R<R]W86-K;RYG:68`````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(R,#4@,3`U,34T,S0Q-3`@,#(T,#4Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y82``
M(`#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``
M9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`
MS,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S
M,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DS
MF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F
M`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF
M9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F
M_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9
M,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9
MS#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,
M`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,
MF3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,
M_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_
M9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_
MS,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````A^00!``#8`"P`````(``@```(_@"Q"01`D*#`@R0(DCB(K:!#
MA@T=%D0(J2(D$A@E/ARHT2`V$A9#7NSH42,2CR!%ADRH\2#!DR<+IE0IDN5$
MB`Y)L)E)LV9,G`Y["JU(`@E$C#L)#AVZD*)%I1>7JL3HE*A,J2,!Z+PHD"<D
MA4(Q9LS)]6--KQ<QKF!U[1JK%07?[JQ*D\3:MGCQO@W@MFE7IFSS"G[;ER%:
MBPD%*[ZV%N[1E58!+&[+R@JKMX'\4M2I,;#B%8'6!O!HF`W)NXKCRL1I4R/J
MO*H)LM+,6>+E%793R]9)@A4`IZTE4[YL)2]<K163=F5S,6G<MBNB>W:+F_G(
MY1@MFB9XE^U;SY;?8V;DZ#4X@+O<IU-N"F`J0X=K"[ZF[K(F1,.^)<(-4,+H
M0,2:W==;9P&8<()?6E%UGX#M570>*R6<<,)O"U;XWDR]K6#@A!1:6"%/O04@
MX0D%=NCA8Y$!L*$))IAXHF$D/100```[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S
M+V-L;W=N+FIP9P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,S0Q,B`Q
M,#4Q-30S-#$U,"`P,C0Q,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_]C_X``02D9)1@`!`@$`R`#(``#_P``1"`"^`)8#
M`1$``A$!`Q$!_]L`A``&!`4&!00&!@4&!P<&"`H1"PH)"0H5#Q`,$1D6&AH8
M%A@7&Q\H(1L=)1X7&"(O(R4I*BPM+!LA,30P*S0H*RPK`0<'!PH)"A0+"Q0K
M'!@<'"LK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK*RLK
M*RLK*RLK*RO_Q`&B```!!0$!`0$!`0```````````0(#!`4&!P@)"@L0``(!
M`P,"!`,%!00$```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P
M)#-B<H()"A87&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F
M9VAI:G-T=79W>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>X
MN;K"P\3%QL?(R<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^@$``P$!
M`0$!`0$!`0````````$"`P0%!@<("0H+$0`"`0($!`,$!P4$!``!`G<``0(#
M$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G
M*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%
MAH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35
MUM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/JF@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`
MH`*`"@!'=44L[!5`R23@"@:3;LCSKQ/\8?"^@Z@MFUP]Y(,B0VPW",CL37+4
MQE.#MN>]A.',9B(<]N7U,G_A??A?_GC??]^ZS^OTSJ_U2QG=!_POKPO_`,\;
M[_OW1]?IA_JEC.Z-;P_\8O"FKK<F2[-B8<<7(V[QZBKAC*4NMCEQ/#>-HM6C
MS7['5:+XLT+6HYGTW4[:98B%<AP,$]/Y5O"M"6S/-KY?B:#2J0:N:+:G8*,F
M\MP.G^L%5SQ[F"P]5[1?W'`?%+3-4\4+96_A[Q)=:&;:0R230?\`+7C@>]<%
M3,(QE:"OYF\,%)QYI')Z;8_$OP?$9M)UV'Q=$!))+8WXV2,<#&Q^N>.GUIT\
MPBW:2)J81Q5TSHOA1\9M(\<W$FEW<+Z3X@@4F6TG.`Q'WMI/7'H>:[TTU<Y;
M.]CTG^TK'_G\M_\`OX*7-'N:>PJ_RO[@_M*Q_P"?RW_[^"CFCW#V%7^5_<']
MI6/_`#^6_P#W\%'-'N'L*O\`*_N#^TK'_G\M_P#OX*.:/</85?Y7]P?VE8_\
M_EO_`-_!1S1[A["I_*_N)(+RVN'*07$4C@9*HX)`IJ2>Q,J4XJ\E8GID!0`4
M`>"?M-^(-3LQIVDVEP8;&Y1GF"'#.01@$^E>;CZDE:*V/MN$L'1J<U:2O)/0
M^>*\H^^L%`!0`E`$D<LL0/E2.F>H5B,T[M$RA%[JYVWP?T*[\3^.H);EYSH>
MC_O[ER24FF_ACS73!*-)REN]O0^(XDS&I'$1PF%=N5>\UU;Z>B/I-W,CL[=6
M.<>GM7*>*DDK(0$@@@D$<@CJ*!GB_P"T+X$%S9?\)OX=MWBUVR<&^CME_P!?
M'_SUP.X[UZ&%J\R]E)Z,X6Y86M&M#H[K_(\@BU"6YACN(;F4QRKNX<\'O7#)
M2A)P?0_6:4Z.)IQQ%-:35_GU'?:KC_GXF_[[-+F9I[*'8/M5Q_S\3?\`?9HY
MF'LH=@^U7'_/Q-_WV:.9A[*'8/M5Q_S\3?\`?9HYF'LH=C2\.>(]3\/ZQ!J6
MGW4BW$1Z,Q(<=U/M5TZLH2YDSFQ>`HXFDZ4UHS["^'/BV'QGX:AU2&%X')*2
MQM_"XZX/<5[M"JJL.8_*,TR^6!KNDW?L=16QYP4`?.'[4_\`R&=%_P"N+_S%
M>5F/Q(_0.#OX53U1X97FGVH4`%`!0`Z**>XEC@LTWW4K!(5]6/0_AU/L*J$5
M)V>W4Y<9B'AZ$JD?BMIZ]/NW]$?5/@'P[%X3\(6.CQ$%D'FSL&R'E;EF'XU=
M:ISRN?F%*#3<Y;LZ"LC82@!\;!7^895@4<?WE/44TVF14@IQ:/D+QEHL7A'Q
MYJOAN)D:WW_:K4JV=JM_`?>NK$1<X*M\F?1<)Y@DG@)]^:+_`#7^1GD$=17)
M<^T::W"@`H`*`"@#ZM_9L/\`Q;I?^OA_YU[6!_A?,_,.*_\`?O\`MU'JM=I\
MR%`'SA^U/_R&=%_ZY/\`S%>5F/Q(^_X._A5/5'A@YZ<_2O-/M5KL1R/,`WV6
MRNKUT(5A`A8*?0GU]JJ,8OXY*/J>3F&=8?!2=-ISFNBZ>K[^1#97HNKF:U>"
M2VO(3AH)>&JZM%TXJ:=XOJBLJSBCF,I4X+EFOLOJNY+IT6IZ[J[Z?X9M$O)(
M4+3R/PJ_C4U70PU)5<5+E3>G<\S,.(9T\1]7P45/E^)O:_9'H'P.\-WUY\0K
MJYUJTA*:-$!F*3B*=^@/O@-^=;QJ4OJZG1;M)]>R_0^9S#,*^/K)8A)<BV6U
MW^I[_P")=8MO#WAO5-:OVQ;V<)8<9W2$?*,?7%8TH.<E$XZ]3DCH<5\!/%VI
M^-/!-]?ZVR27EM>^6LBKMW(W0$>W:M\71C3DE$Y\+5E*5F>B,<*Q]!FN0]!;
MGGWB_P"(1\+_`!;T;PS?1VXT74($+W#G;)%(V<'=TV].,?C79##J=)R6YYKQ
M,U4,O]HKP2FM^&VU6TMU;5M-.XRQ*?,FB[@8Z\=*,+5Y9<CV9I5C>*J0T>_F
M>+3:'IMMH.G>(]#OKYM&FD,-^MPF]K9NQX[9XS7G1Q=:=>>$KQ7M$KQMI?\`
MK<]O+\RG@Y1K0DW3D[2OK;S^10NYXK:/S"QD5O\`5+'\QE]`HK>G"4W;;OY>
MI]WB\91PM+VTW=-:6U<O0NIH/BJ>P6_MM#9;7!9HY6_>D#K@5B\9@(S]E*K[
MWEL?-SXCQ4FIT:"4.J>_R,W3[V&^A:2,F-D)$D;]8\>M=-6C*D[/7MYGO9=F
M=#'TG5INUMT_L^OD)9ZC9WDC1V\X+J?NMP6^GK14H5::O):!@\VP6,FX4*EV
MNCTOZ=S[!_9\TZ[T[X>6XO(Q&9I&EC&<DJ3QFO7P46J6I^=\35H5,<U'HK/U
M/2ZZSYX*`/D[X]^)+CQG\1H/#G@ZQ6\O-.0I/<E@8\GDC/08Z5Y69U,/1A[7
M$2M%?>SZ/),VQ&"A*&'BG)OKLD8VC?#35[BRWZ[J%K9W3-@PPC+1IZ@]"37R
M6(S[#PG;#P<EW?5GUF'SC%UJ,O;JTG\+CI8](T73;/1-.BL=,A$-M'Z\LY[L
MQ[DU\YB<14Q%1U*KNW_5D>?A\-&E#E>KZONSGO'/P^T_Q<#=$O9:LJ;8[N(8
M#GMO]17H99G=;`>Y\4+ZI]/0Y<7@8S?/3=I=T0>']`L/ACX)U&XGF9K@QEKN
M[7^-OX50>F:TQ>-JYSC(1BM+^ZNW=LPP^'IX*BYS>MKEOX$I_P`(OX0O?$7C
M+4_L*^(+Q7B-RISP#M8_[V3_`-\U]O7IKW:5):11X=&H]9RU;95^+7Q;\&:U
MX!\0:%I=[<W%]/M6)A$0DA!'(/I6N'PM2$U)HSKUU/[BI^S?XL\*>'O!5WIN
MI^(8K;4;B;[3)'.NU(U7C:I[DT\92G.5TB<--0:E?H>ZW%U;0Z?)>SW$45DL
M7FM<.V$"$9#9]#D?G7G<K;LMST_:124CY7_:5U_1M:^(^E7NCZE!J%I%:Q"2
M2W;(7#9(^N*]G"P<:;3/&J/WKGMVG?&+P#K3?85UB6S(M54R7,153A>0/>N"
M>%J)\UCLIXA*/+N87A/PJ/#FFSV$-];:SX;OB9K%C'S)$_+!_7K7R7$<E]:C
M4BG&5M_3MZ=3VLJI\U"4)[7*GAKP)H_AW599XY(YR'+V-M<,"UMGV/7VKAQF
M<8C%TE%JVGO-=?ZZGJT91I8>.%3T3O?UZ+LCK69PY+%@_?->2DK:&R2MIL>6
M?$+P$-4\2Z;)H4$MN=29EU1H@!&B#'S^Q//UKZG*<Y]CAIK$-/D^"^]^WH>-
MB*5:G6<:#LJBM+S1?\2?##1I/!;:?HD#+J-BK2VMT3B29NI#GT-<^$X@Q*QG
MM:[]V6C71+R%6RQ0HKV>DEMWN>M_L\^/]*\0>"--TR6YAM]:LT,,UI)(-[;.
M"X'H:_281BHKEV/EZU:I5J.=5WD]SUT<BJ,CS;XR?%*V^'UK!;165Q>ZU?1L
M;&%$RC,#CYCV'-3*481<I.R0XQ<G9;GEWP_TJZTK0II-3MX(-7U&=[F\,(Y8
ML<@'TQGI7Y=GN/CC<6ZD'>*T7;Y'VF5X3V%)<RU.C`'I7CGIE#6]2.F6<<D<
M#7%Q-,EO!&.`9&.%W'LN>IKMR_`RQM=4D[:7;\EN<N,Q*H4^:URKI7PMUN[N
MQ>^+O%]V7E!::PTSY41CT"N>,"ON:>'P%&*C"DG;ON_,^:=3&5'?GM?^O4SM
M5^!=YJUL;;4?'M]<6H?<D4ENQ`],^IK>C+#4)<]*DDS*K#$U%RSE=>J/6=&T
MJ'3M`TW2IA%?)8P+`LEQ$'W;<X;!Z'FLY59.;DC6.&BX<LNYYS\=/!'AJ7X;
M:[JT&AVUMJEJRRQW%HFUF8GG<.FWVKJPM>;FHMG-B:$8;=AGP7\&>%-5^%&@
M7NJ>&]-O;N1I-\TJG<Q!/)-/%5YQFTF3AZ$:F_1'INHZ5I^J:9_9FI6<=SII
M"@VK$A"%^Z..P]*XHU)1ES+<[IT8RCR['S]^TSX3T'1M-\*+H.C6>EBZF=9I
M+=#[`9]?6O4P=:4[\SV1YM>DH2<5W/9/#_P\\*Z'I^DQIH.FW-[:V\;"]DBR
MSL1G<5/?ZUQ5,34;T9TT<-"<>9B^.O#FJ>(=/BLM&UJ#0X`/G9+8LW7(V8^Z
M/6N=T\/5:>(CS6>AO+V]/2AHCD=2^!FAW]F9%UK61XC(#?VK-+N5G'?8.0*Z
M:=>G"*IQ@E'L83H5FW4<KO\`KY'%>`O%NK6_BVZ\&>*HYIM0AD<073+AF`Y^
M<>A`R#7SN>Y+2I4OK>'TCU7^1Z>79C-U/95=?,]-R<$9.#U'K7R1]$&3G(/-
M`'GWQ,\$V5]I=UK.C6QLM>M09P]J"#<XY(8#OQVKZ+(\ZK8>M&E4E>F]->AX
MF8Y9"<'."U/I;X=ZG=:SX&T+4;\*+NYM(Y)0JD#<1SP>E?I35F?(IW.,^+E[
MHEKXDT)+ZYM8-6FCD2V\T88KQN&[L*^1XJIXF=./LTW!;V_#0][)*M*G*7/N
M]CG%9'&8Y(Y%_O1MN4_0U\"TUNK'U,)QFN:.PIH*)].U*QTO4+>?4[B.W@D<
M0K)(<+O;A03VYKU<EO\`6E97T>QQ9C)1H._<[>Y:.T662^FCM8(5+RS3-M1%
M'?/2OLHP<I<J/"E5C&'.8/@GQ"_BK1IM6&G2V%BURT5EYQ^>YB'_`"U([`]J
MNM25-VO=F5"M*;::T-ZL3I$E1)89895#Q2H4D1AD,IZ@^U-.VHI14MR#2=.L
M]+TV.RTV&"RT^#)5!B..//7VIRDY.\F2HQALM?(CEUC2(KN"UEUK3%N)RPB0
M7*G<5QN!/;&15^QJ6O8YXXVE)VB]A=2TS3=?L'M+R.QU6TBD$CQ(ZS"-QT)'
M8TESP=UH6JE*J_\`,N9R%]`H4>P'05F;J*BK(-I8%595<@["WW=W;/MFFK7U
M%-R46X[G$>#?'R:KX@F\,>(K(Z%XM@8@6KMF"Y`Z&)CSDCUKJJX>T>>&J..G
MBG>TSRGXWV4MI\;O#S:+$L>I7"HTR0.!(W/S;\?[(/X4JW)]0JJOLEU[]/Q)
M5_;Q=/N>GOC>V.F:_,%L?:J]A%^9@`1D]*>PWH9G@:34/&GQ"GL=.W6?A_17
M'VZ9DRUW)VC4D?*![<U]ODO#M*=!5\1JY:I+HOU/F,PS:K&JZ=/2Q]$@```=
M!7VBT/GCE?'W@#P]X\M+:#Q)8_:!;OOB=&*.OJ-PYP?2BX'S+-K(^$GC2^\&
MZ\SS>'_,\ZPN5!+P(W(!]1V-?+9_P]/%/ZS05I]NDO\`@GM9=F+H6A4VZ,C\
M6_%NWAMVA\%P/J5UY9>6YDB.V`>H'<UYF5\(XC$2;Q*:2Z+=^OD=V*S>ZM15
M_P`B]8Z[H'C[X:RR^)+U+40J#?&,X:&0?==1WSZ5Q5,)B\KS%+"QYKOW?-=4
M_0:KT\7A'[3=&;\,AXO^(YL?#OB"ZNI?`NGS">2>6+!N$7[D9;N#Z5]Q4E&E
M#F6DGT[,\",74E9:_J?2SL&8;5"(H"HBC`11T`KRF[NYZT(*$>5#:115UG48
MM&T2]U6XA:XBM5!\E3@NQZ?A2E+E7,;X7#2Q6(AAX.SEU['B>O\`BG6_$=LL
M&L72FUW>8L$(V@>BG'4"O,JXF4M+GZ#@\IP>"DY4(^]:UW^9Q5YX4T:[`\RU
M9&#%MR.0<GK6U/,\5#:5SDQ/#^!KJTH):]--S%U8:EX!N+?7?!M]=V>&"SKY
MA8$]L@]0?>O6R['/%2=*OJ^A\CQ#D<,#!5L.K1V:_4^H_AUXD3Q=X(TS6A<)
M/=2J4O65=H$XZC';BEB*?LYM'C86IS1L=$>1@]#Q6!U'$?%#X;VGCQK&Z.H2
MZ5K]@NVUO$'#CJJMW&#WKKH8ET]'JCAKX>_OP/#?`OV_PQ\6K[3O'T,IU^[7
MRX;ZX?(![,&/4,!@'WKBXCHSKX)3H/W8N[7?_AMR\LJ1IU_?UN>A_$7Q7_PA
M^C0W$4*7&I7,OEVULX)$@'WCQZ5\GDN52S/$>R5^5+5K?R1[^88[V$5RZMG$
MVOQ,\9:I'+%IOARVMKC<L:SN"/*8G`.#UK[*GX?OEE4DY.,=UW/.IXS&8B\*
M<-?,^GOA'X/G\&^%S;:A?&_U.[E:ZN[C&`TC=A["OH*4(TZ<:<%:*6A\Y4E*
M4W*6[.VJR0H`^:/C/''+\1+H30PS;85V^:@;'TK]#R.A3J8"+DKZL][!.]!7
M5_4XV%(X"QMX((2XPWEQ@;QZ'U%>O'#4HWLCK4K?"DO1'%W?A2W\1^,M/\,^
M&[>&VN;@F6ZD\_Y=HY.1[=<=:_/^)(X7"R2IQU6OW]#RL5"GSJG35N^I]7E]
M.\&>#$$LHM=%TN(+\S_*#['@DGTZU\'[]66G4V7)26NYYAJ?QYTQ;T_V'HVH
MZKIJ@;KN.)E`/<8([5M]64=)S2?:Y4)5:BYZ5.4DNJ3L=[X,\>>'O&<ERGA^
M^\^2W"EXW0H^".H5L$@'C/2LJM"=/XD%.M&>S-'QGICZQX2U"T@C:6[4>9`B
MMMY'7Z_2N:K'F@T>KE>*6%QL*LW:.S_KIZG@=O,D\(>-U8`[&*GHPZCZUX]2
M$H2<9*S/T6%6G47-3DFNZ=R2I+.,^(]R]U%::#96\UQ?W<BLB1J23SP!ZDU[
MF2T'SNNWHM#XKB['0]FL*E[SU/J7P!H*>&?!&BZ0MJEK/%"'NHE;=^^/4D^M
M;UZG/-L^3PL.6+9YOXZ^,%U;:_?^'/".GK<:G;%HY;BX.Q$.,'`/)(;/M6GL
MZ=*FJM9V3-Z-*MC*KHX=7:\[&)\.?B_?:/?0^'/B&'>2:4>5J;$853V?'!&>
MXK1TJ=>'M:#T[&5:%?!5?98A69W'QR\!6/C#PU+J9NC!J>FP&6VN@VY)(P-V
MWCL>Q&:C"UG3ERM:,QK4E-<\6>%>![JYU^-=8UJXEO;RT`M[8R_=A4#J!W;W
MK]#X1R;"4(2K4XV;D=&$G*LO:U'=K1>7_!.MN996C+F1VD3YD/<'L?>ONH1B
MG:VC.UR<M).Y]3_#_4'U/PAIES-=)<SF("21<?>[Y`Z&OR[-*"HXJ<(QLKZ'
MSF(AR5&DK'0UYYB%`'S5\901\1+O..85/!K](X??^P1]6>[@OX*]3B+F9;:V
MFN'4NL*%RH[XKU*]3V=-S[(ZFU%.3Z&W^R_82ZA)XC\5W3J[7$@MHT9<LG\6
M0WICBOQ;.L7+$57*74\O#-U*CF^I5^/L:ZC\6-)TRX=Y;(V"R/;ACMSZD5Y\
MZLJ.#E4@[.YW91AZ>*S!4ZJO'4ATW2KN>WE72=,GN8+=?WGV=<B,>]>!"C5K
MWDM;'Z>YX;#*-.<E"^R?4YHZ2VE7MOK7A4FVU*";S28F*F5?XD]LUWX;,9QE
M[/$/W;6]/,^=SCAR$J;GA8I3O?U\OF?1'PZ\9VOC70CJ5G$;.ZMY/*N;-G+/
M`P[L3ZUVUJ7(TUJGU/BJ51MNE4^);K]#E_'?PI76=4NM7\+ZFVC:K<X,\0&8
M93W8KV-'/3FE&M'F2^\WI5<1A6Y4)M7.4/P:\;`$KXOM">V8:7L\%_S[-O[6
MS+_G[^!U?ACX-:1I'B:PUV^U"\U74K?#!)CE6D'0@>@["K^L<L/9TXV7D<E6
M$ZU1U:TKONR3XZ?$>U\':1/IMM<NWBF^7]U'`_S6H/\`&Y'?T%7AL.YRYI;(
MPK5TER0^7]?U<\@\'Z`]C#"%@DNM9O6&]5.YY'/;/I[UY.+Q$\96Y(?"MC](
MR7+*67X;VE2RE:\F^AN?%CX?76FP6]IJI@DNY(O.M)H^,..J$?U[UO&-3+JR
MUT>YR5UA>(,+.5&+YH/2_P"#^?8]L^'5_>ZIX"T:?6]/^QW@@\B6V9,`JO`;
M'H175745.\7='PN&4K2A)6:?XGSKXM\/Q?#KXK?V?'?O)IFJQ_:$C`Y3<3M5
MA['O7V?"V8.-91D[)Z>5^AG0DJ5?EOHS<8$$@]17Z<CU&K'T#\!?^1#C_P"N
MS_SKX#B?_?GZ(\;,/XWR/1J^=.$*`/DGQ06/BO6BSNY^U-RYR?I7ZQ@K?5:=
ME]D^DI?PX^ASOB*4P^']1<123'R2NR/KR.OT%9YA/DP\W:^G0*KM2D[7T/9/
M@.8F^$'ASR?*R$D$GEXSG?\`Q>]?AN+_`(K.'!?"S#_:!\-75[I^F>)]&M!)
M=Z.Q.H21G$K6_;`[@<U5%*K3E1EU7XFD*SPF*A76B3Z=NI8^`GB6&'77MX[B
M!=,U1/,C:0X+2#H!_A7)E525&LZ-33H_T/K^):$,?@(8NC>3CV_E?<ZOXE_#
M%;J2;5_#4:QW39:>T7A93_>7T;^==>8Y8IKGIK7L>?D/%#II8;&.\>DNJ\GY
M'EGA#69O"6OSWD%LICN2$U&U88,@'\7^\*\2EB9TU[.3T7]6/J,=DF$QL'))
M*;U4E^3\CH+SXWZ9IVM7D&HZ%?KHJK_H%Y$N7G;NKCM[5[%*G3K1]R6O5=CX
M#&X3'8*HU6C\UJOD-'Q_\(9&[3-9"Y&3Y?0>M:?4Y=T<?MZW\K^XQ?$7Q=\1
MZU!<Z?X0T-](CF;$6KW+8D6+U`[,:SE5PM!7E+F:Z([J.49ABI*+ARI]7M_7
MD<=HGAA?MLEQ.)]:UF9_,>YD!=MU>;7QU?$OEA[L>R/LLOR'"X"/M*S3EW?Z
M'T+\//",/@JRN/$OBBXCANA"0$.-MNG7'NQ_^M7KX'"1PD'5JZ,^?SO.)9K4
MC@<%&\;_`/@3_P`D>(_&'Q=)J-Y>>(K-#"A=(X8ISG<@/4#L37!&4<;C.5K3
M\CW*RJY'E2A!IRB[OY]/,^B--G-UHNDW#`AI;*)\'MD=*TE'E?+V/BZ53VEY
MVM=W^\\-_:7;2_[<\'(@B_MWSR92/O\`D9^3/MUQ7T'#O-]:AVYCCJ_QXV[_
M`/#F3+_K'K]ECL>O+<]_^`C*?`J*&4L)GRN>1SWKX+BA/ZZWY(\3,/XOR/1Z
M^<.$1F"J68@*!DD]J$KZ(#Y)\3,K>*=99&5E-RV&4@@_0CK7ZS@TUAJ:?\I]
M)2_AQ]#+N(?M%M/!O*>:A3<.HR*NO3]I3<>Z+MS)Q[HT/V5]?AMI-:\)S'$X
ME-S`2#NDQPPQVP.:_%,VP[A4?D['D862C)Q9[_>6D&HV%W87N[[+>0M#+M;:
M<$>O:O)C+E=SMK0YXV1\H:=8W_@OQ5=>%=<5HWCE\W3V/S*XSD%6&,__`*Z>
M945.*Q-+YGO\+YG[.3P=5Z/;]5_PZ/I[X??$V#6)4T[6DCL[L(!'+N^24@<Y
M)^Z?;Z\UV8'-(5O<GH['%G?#$\-%UL.^:-]5U7;U_K0T/$/PTT76$OKJ#?'J
M%T"Z3ALJ&[''I6E?*Z-5.2W9S8'B;%X9PIRUA'2WD>3ZE\-_%-A-%%]A%Z67
M<9+=@RJ1V^;'->%5RG$0>BOZ'VE'B/+*\7)RY;/9K7\+E0>`O%)./[$GQ_P#
M_&LO[-Q7\K-?[;RO_GZOQ_R-/2_A=XFU*U,LL45D?,VF.Y?YL=V`&1712R:O
M+5I(YL1Q3E]"?*FY:=%IZ:V/7]#\/Z%X#TF:[9EBVH#/<RGEL#M_@*]^AA:.
M#AS?B?"XO,,;G%94UKKHE_7XGB7Q&\:3^++T[B8-'@.Z*!C@''\;^_MVKY['
MYA+$3Y8;=#]!R;**6547*3]]K5]O)>1Q/PVT)/B1X_CO+B#SO"VC',^^3:)7
M_A^4<G)_3O7HX:C]3H>]\<OP/B<[S+^T<0E2^".B\WW/IM5+,J1H`!\J(@P%
M'8`5ANS!)0B?+'Q?U>R\7_&2PCT1_,738EAGE92JED)W8[\=.<5]=PWA:DJ\
M$N]_D>?%>TQ"Y>YKN<N2.A-?K"6A[#=V>K_L\W%O%?ZQ;O*%NI=KK&2?F4=P
M.E?*\5PFX4YI:(\W,4VHOH>WU\2>2(ZAU*L`5(P0>]--IW0'R-X@$2>)-8CM
M@JPQW3*%48"^V*_6<*Y/#TW+=Q1]+3OR1OV*-;E&#K%C=Z??Q^)/#=PUGK=E
M^\W1_P#+8#J,=S_.OF,_R:GB:;JQ7O?G_P`$Y,3A^=.I#=?B>M_"CXQ67C6_
M?1]<MH=&\09_<IDB*Y]5Y^Z_MWK\NQ6!E1>QR4<4T[3_`.&.G^)G@>'QQIEM
M:R7)TW4[*3S+>[V9=#_=/M7+2J<EXR5T]T=4HNZJ4W9IW31X%J5[K'AS4+G3
M_%VCW$!M\"2]@C)A93P'R.QX_.N:KE-USX>5_)[GU&`XMLU#%QMYK8ZWPI\5
MKS3]/<:7KD+VSMPEV>8SZ`'H*F-7'8;W+/\`,[:M+)<R2K2:7H[?>=AH7QMU
M!(6@F2QU.Y+;E:.0*0/3`K>&:XBG']Y'YLXJG#66XFI_L]7ETVW-3_A=.HXS
M_8D./7S#3_MV79#7!6'>U9_<9NL_&36+B*(V45IIXC.Z5W8,&'ISTK.IG%:=
ME!6.BCPC@L.I2KR<E;TL>9>(?'][K5Q=*LFHZ[(7622&S0M%&>@YZ"I6%QF)
M]ZH^5/O_`)"J9QE>6VIX:-Y)=-[>;-_1OA1XC\5Z9(?%DS^'[??@6ELN]IE'
M4L?Y5T4:-#"RYH>\^[Z>A\]CLYQ680]G+W8]4GN>Q>$?"&F>#-&&FZ%9M!;2
M,'<LVZ25L=6[TJU:4WS39Y]%4XZ1>J,7XE^*%T32I].T]HYM=NDV)'NXMU/!
MD)'0@=/>O;R/A_%9I^^A[M)/XGU\E_F:.,JJ]W8\.T32(-)MA'&1+<'/F7)'
MS2DG/-?K6`R^G@Z:A%:]S6E1C2C9?>:-=YH=_P#`K_D?9/\`KU:O`XF_W%?X
MCCQ_\'YGT37YZ>(%`'F'Q2^'$>MA]7T-4@UA%S(@&%NAZ'_:]#7TV29Z\-:A
M7U@_P_X!WX3&.'N3V_(\%?=&[QSQO#*A*O'(,%2.HK[M6:O%W1[&^P"1000P
MR*=F/4SM3T?2M4F:>]A(NR!BYA;:Z$=&'O7EXO*,/B;N<=;&=2A3JN]1:]T=
MEX4^('BC1F6UUV[MM>TF,_+,1MNRO937R4^!8U9RM4:TT]?/R.>G@Y4Y/WM.
MG?YH]$M?B+X;U.**PN9EV7(Q);W$8*#OM8GZ5\_7X0S;#QE/E4E'JMWYHJ6'
MOJT17W@'X?\`BJY?59=%L[J5QM:2SDV(<?[([UXM26*PLO954XOLSFE@X\W^
M9S^M?`CP9J&H17>GR7^B;$VF*U;<&/\`>R>AJ5C9VM)7]2?JLX-.F[/NG833
MO@?HMA<0O!XCUEH4D#O`X!67'\)/8'BLZE6E4^*FKG90Q.84+*G4:5[]S;\9
M^%/A]8^&KJ^\2::+;28B-[+,0S-V5?4^U1AH<M1.FM3;,,RQF(I>RKU;K^MS
MSS3/C3:Z=ITFF?#KP9]D@W>5:7#*`C_[4A[GOUKWJ&2XO%RC)*Z?4\>E2<M(
M1;O]QDW?C?XG:KJ3W;:U:Z($"A+>,`HQ`P3WZU[F&X.JRB^?1HZ5@:TOBLAG
MAVXU?1;B^O8=?O+K4M04I>3RG*D'D[!V/O7TF$X6P%)1=>GSM:J_];'52PM.
MGJ]6*B[2Q+/([?>DD;<S?4U]+HE9*R71;'0V.H$(S*JEF(`'<TTK[`>N_`SP
MMJ$>H/XBNA]GM)(C'#$P^:0?WO85\CQ+F-%T_JL-9)W;[>1YN/KQ<?9K<]LK
MXL\H*`"@#"UKPEH>M74=QJ6GPS3H"`^,'GUQUKNPV98G#Q<*4VDS:G7J05HL
MH?\`"N_"W_0)A_,UT?VWCO\`GXR_K=;^8/\`A7?A;_H$P_F:/[;QW_/QA];K
M?S!_PKOPM_T"8?S-']N8[_GXP^MUOYA&^'7A9E*MI,)4]0<T+/,<M?:,/K=;
M^8Y'QO\`#>]TV6RU[X9F.QUFP78;"1O]'O8B>58=`WO7FX^M4QVN(?,UUZDO
M$U)-.3N:?A0>*=3,B:_X;BTAHX@V];Q9EE?N``/E'UKQ*F7S7PNYUT\='[2.
MA31[LN`P55)Y(;D5E]1K=C:6-I):'C?B#X;^+?B5X\@C\:VITKP=9AOLUO:7
M2L21T+<<ENY[5ZF'PZI+S/,J57-GKMO\./"MO:16L&D01P1($5%R!C_&O8HY
MIBJ45&$[)&D<76C%14M$+_PKKPM_T"8?S-;?VYCO^?C#ZW6[F7K7PG\/:C-`
M\"2V(C!#+`<!_KFNK#\1XNDFI>]?N:0QU6*UU*'_``IC0_\`G\O?^^A6_P#K
M3B?Y47_:-3L'_"F-#_Y_+W_OH4?ZTXG^5!_:-3L7-(^$?A^POA<3&:\4#B*<
MY4'UK&OQ+BZL.2-H^:(GCZDE9:'H4:+&BHBA448``X`KY]MMW9Q-W'4@"@`H
M`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"
M@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`
M*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@
M`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*`"@`H`*
M`"@`H`*`"@`H`*`"@`H`*`/_V0``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V1U
M8VLN9VEF````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$S-B`Q,#4Q
M-30S-#$U,"`P,C,V-S8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA(``@`/<`````````,P``9@``F0``S```_P`S
M```S,P`S9@`SF0`SS``S_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9
MF0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,`
M`#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-F
MF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_
M`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8S
MF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,
M`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`
MF9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9
M`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_
MF9G_S)G__\P``,P`,\P`9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF
M`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,
MF<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S
M`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9
MF?^9S/^9___,`/_,,__,9O_,F?_,S/_,____`/__,___9O__F?__S/____B_
M)```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"'Y!`$``-@`+``````@`"``
M``C^`+$)'$BP(#8`"`TJ7%@0(0`K$`$PG-@0HL6(%"D^O&A18D:&&SE:\?A1
MX4.'*$>6-`E@A<L5@5BM2+BRX<L55E:P"C2SILV;,5V2K(FR:-&,1@,I7<IT
M*0NC!(U*G4KU(%6$>[)JW7/BZ=6O6+#N`9`5H=>O4\<^(LMV[8FK5M,"6`L@
M[%RV4P=2'7L-*\*^;Z7J!7#-RK5K._T>9KMX+("8A?M*)'RX<F6RC@?5Q?K6
MLF6'AV<Z7-%7*P!2`$YP)2RZY>*_G@^S.NV0E#'4"%$'BMTW;M&^MX/;'FZ,
ML&"0"(4K=^A3X&GEPX<2=;B<N<_GQ+/?EJ[1]M?M$XL\BIX9+'NPE@A;#TU_
M,^O,"U()8+XI^B!]EWM$$[A`H']__BWE=U]+]PE5%@`7))B@7P4V:.!614'8
M8$```#L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O96EN<W1E:6XN:G!G````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$Q,#8U(#$P-3$U-#,T,34P(#`R-#8P,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#_V/_@`!!*1DE&
M``$!```!``$``/_;`$,``0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_;`$,!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!(@`"$0$#$0'_Q``?```!!0$!`0$!
M`0```````````0(#!`4&!P@)"@O_Q`"U$``"`0,#`@0#!04$!````7T!`@,`
M!!$%$B$Q008346$'(G$4,H&1H0@C0K'!%5+1\"0S8G*""0H6%Q@9&B4F)R@I
M*C0U-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H.$A8:'
MB(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7
MV-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_Q``?`0`#`0$!`0$!`0$!````````
M`0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$!P4$!``!`G<``0(#$00%(3$&$D%1
M!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ
M0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J"@X2%AH>(B8J2DY25
MEI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(R<K2T]35UM?8V=KBX^3E
MYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#$0`_`/QM+`9X/'4D8`S[\Y[9_P`Y
M4$$`CH1D?0TJ_P"NC!!EVGYHDC9EY!(W.,`\'/&""<8R,TVYFCM87O+WR]/M
M/MDD+3W4]I;;(_-*IY%E+<BYN0?E"NA4%3OV``@<E>K%7MB%2:TVB]4XWW3Z
M/?[ANEB7%.C2==R2T2>C=M/=:;U]/F<)\1=+T?Q'X>EA\0WDMMX>TP-JNKVU
MO'J!L=3DT3_B;26NH1:5;WFI7>FXLR=0M[*SN;BYLUG@MXGE=5K]/_\`@F5_
MP4M\5_LEVS^*_`_QWT34_P!ESX>^.O#7AS]I#X3:SIFBWOB'P#\+_B3J.O?#
M7PW\5?#^DP:GX!\8:Q!X=^)K^&-&\2:-X%\6ZWKGA^?5K/5K3_A*="M[O[5\
MH?LG?&?P/\#/VG/@7^T'\6O#\_BC]E7P]XS\2>"/B[XNT_PE;^*O#W@?Q7XQ
M^'GC#1O"GB$V9\1>5=7?AOQA!>:MJW@2>SUC4K/1_!NO7DE]>B`6[>[?M?\`
M_!&/3-._;]^'OA3X6KJ$/[-?[9VA?&O4/AAXCL_[,3PSX8^(,OPZ^(?Q.^'O
M@"PO[#3?L-SX%UOQ`NDM\-='U?\`M7Q-X:\(13SZ_P")]>\3V,'B:#P)9E.I
M+]ZKI-)ZI:)QYGTZ)N^EW;?4^BP.25*F`A7=1TL6IISPW*FY1T=K2O+WK-:6
M?6ZW/V^^"/[0G@K]I#]I?]L;XO?LW^%/B=\,?C!#K%QX5_;E_8X\!^+O#OB2
M?]K7]D^9=6^'?@S]OSX07&F>#=-T^R^/?@"1EU_PWHG@_P`9>+=4^)V@>&8O
M"=A>:OIOQ5^%WQ&\97_V1_\`@G/_`,%(-8T+]G_]ES]H?Q5\.?B+^Q]^R+^U
M-\(?VI?V=?VA=9U?6?"W[07B[PGX`?6M:LOA?XN^&LEGK/B3P)K6HIXJM)O$
M>A>,(M-F^&\.EV'A"VN_%#74=S7S9_P0?_9'^-GASXY?`7]L?Q;XZ;P]IUC\
M"O$_[(/QS^$7B#2+G1O%MCXP^$5YX9\,^&-*T&^LWTU+3P-H-GX*\(75YJ.I
M1ZR;_4/A_K&G6%U;V3Z+IFE_I-\5?V[?^"AW@/\`X*M_`[]C#PKXX_88\5?#
MOXM-K_C&;PYHO@OXV7GC?X<?`[0O!OC#QK=^+?B=XGNO':^']6\9>*--\(ZE
MJ/A:Q\+VROJ<GARUT:TT&QTR^UOQ-I?K8#&X2OS4Z=6*FK1Y$[MNT=+MM[?R
MO9+7H>7F&78["3C.MAVX5$G&\6G%76NG3OOYZ'[RWOASQ/<WEW<KHG@:Y6XN
MKB=;B>S\6033K+*\@FF@33;A(990V^2);B=8W8HLTH4.Q77R^)=8$L@C^&WC
MJ=!(X2:";X;>1,@8A98?M/CFWN?*D&'C^T003["OFPQ2;D4KT[+S^]_YGEVE
MUI=NK_N7Z^;/\RK_`()X?L'?%C_@IUX[UW6=0UG7/AK^R/X9URZT?7?&.A/$
MOQ/\<:^EM</IWAKX?6M]$^B6VD0W<,0US6=5MI;B&&TU$P749,83^HWX"?\`
M!*']@C]F>RTS_A%O@UX2\<^,=+N?LTOQ`^+VE6?CKQ`XBA:SN+[4?[9DU7P[
M<:G?KYLE]<Z7IT-A)=SRS6$4,!A5?K']GKX$>"_V9/@[\-OA%\/-.T_2]`\%
M>$?#^CW]SI=A::8?$^I6VD0Q:KXBU?[%%`-4O]>OY;W4KK4+P3W-Z][)<7$L
MCSNS='\5?B?\,_@K\-O&GQ=^(>NVW@3X>^`-"N]:O=:ELTU"&RTG1%CNY+V#
M1BC)<M%XC%GX7TKPZD6S7[.Z73HX98)?*/XCFV8YEC<>J-&=2$8RY&HSDKVE
M;F>OO-]6WKMHK(_I+*.&,MR3!T\?B?92YJ4*LHRA%I-Q@[:II:Z:+;5WL?D_
M_P`%K=-\)>`_@'\,/VA_$NCZ/XA^''P:U#QWX*\7_#*336TWP_K/AKXX?#C7
M?V=M)UJ8F%[+06\$>,=:T/QCX;U2WMXCX5\0Z.VNZ3]DU"[U&>[_`)B/@;^U
M#X6_8M\,?LV>)/V:_P!HO7?B9JMQX\M?C'^UI^R3K'@B3P[\,?`%S\/_`!/%
MXJT:?X8?%?6[O7_#FDIJNF1OHM]'HVD:$FN27=OX5<2:=KUSIDG])7[5?Q7_
M`&R?CG^SA\2M>_:@_P""?GQ#^'__``3B\;Z!H&N^(O'_`(7^)_P[\:?M2^"/
MA=H/B[3?%FF?M&WOP5\/:.NN:#9_#SQ-;:?X_P#&7ASQ!)?:!;>'M.US4O$F
MA:GHZ:A;7GR;^S)_P1<^&/[0EG#X^\??M:^"_CI^SYX]\.:U9^%_"GP-\'^&
M_A+J'BO2M6M6MK/5_B?KWA*QTVT\8>-O`@:U\4R:;900WZZ_X>L;B4&.V=*^
MHPM>O@,'&IF%-3]I**?.U/W9*%KIWU2<NO>+<6M?@LRHT<[SV.9Y-C*5*<'"
M+P=&\(MPFG91BDN:6BTB]6G=F=\/O^"F/[2W_!0WXJ_#[2]!\?\`P>_8&_9A
MM_B/#XT\6Z]KOQX\':S\>3HNEZ_IWQ&T;2DTOQ/I5\/['O\`Q'X3T9)-&4Q:
M-/:7VIS7]I=6][J5O??IG_P6#TW3==_X)D?$;]J#X>>*1-#^SMXV^`OQ7^%W
MQ3\&7^FZSK6M_$2Q_:#\#^$=%\4^$];T6%-!\3MHQ^)?B76]"T#Q)8ZY9:?X
MG_LG0]"TZRTJYFM*^5OV#_\`@GW\#?@U\=HOV(OVQOV8_P!F[X]07EQ_PM?]
MF_\`:CN_@GX+UBY\?_!R'4AX6U#X=_%GQ)J'ABYU75/B!H^BWE\='O-:OKB]
MBUN'3&@D698I!^EW_!/KX.:_^U1XP^(G[3?Q>\0^"O#O[$_A7XG_`!8^%'[#
MO[&_PX?2K#]G#2O"7P;^(VN_#RW^.7Q+^&.GF#X:^,?&^E:[X)OOB#X,NO%7
MAZZDT&WU/3O%>EW5IJFA:/<1]>6X7"9ACH8O"35&>'FI<E)<BGR_S1CNK22U
M[+317PXCS''Y70AA\=156KB8KV+J>^J;DTGR<R]UW3O):ZWU;NOR[\:_\'-7
MQ=\">,O%O@CQY\`F\->.?!OB;7O"OC/PY<#XS6\^@>*_#VJW>D>(M$FM[+Q+
M#9P2Z5K%G>6$D-I#%;1/`R01I$J*"OY\O%?P+_;=^._BGQ+\<+:+7[NV^,NO
MZQ\5K>Z\0Z)X9U/7[F#XB:C<^+XKC7-2NC-<ZAK$T>L+)J=]<32SW=ZT\\LD
MDDC,2OK_`/:OYI??Z?Y+[OO_`#GZUB>D$MM.WPZ;>?\`6M_T-^'_`/P7W_;]
M\&Z)IWA;XF_LT_"CXGKHNCV&@Z?XH\)R^//#NKZC%I-I%86%WXHGN]3\0:!'
M(MK;V\4UQ86=NUUY8FG`O)9G/ZU?\$UOBM\8_P#@K<^O>/?VH?!?P7\#?LX_
M!3]H?X2Z;<_LY^$['Q1XRU?XY?$6TM/.\+0?%G7/%FMZYX9UGP'\/UB@^)2?
M"WPQX2\-IXD\7^&]/U+699IHFB/\U+`J$+`J)#A"PP'()!"$\,<@C`SR".U?
M2G[&W[3_`,8OV+_%?Q#F^'LWAS6_#_Q1\1>"_'6N>!/$G]IZ;)/KWPROX=;\
M+:EI7B;0H-4DMYIKW7[BX-G-IIG1=-O('W-'.8?(H91@,+.GBIQC*<8QE/3F
M:E[O,Y)WW=VU;>]K*Z7MU.*\_P`5AG@IXR<H-<D8).34;12A>*=K+1WN]$_,
M_P!'/3_B#X5U73_'-I)B"+P5XI@\,>(&1)>;S4;B"Q%PZVSQ7$DTQN1'.T4J
M7$L;/&LBLX(_`CXU?`?2_P#@EO\`'67XS?"B*R\$?L#?M$?%'5[7]H+PLUE:
M:7X._9A^.OC@Q-\)?B;\+(+2STV;PQ\-_BMX[31?AS\2M,M5DN?`WQ+\2^&4
M\&WV@Z7J&IZ?=?EQ\'/^"X?QJ^)GQR\9?L_:?^S?\-KZ[_:JLM<N?!^H^(/C
M?>:/I/B_QW:Z-?WVBP6'B.\^"^L1:%KVG:A;07]GX*\7:+J5CXJN;:/P[J$4
M-KJ<L\7U7^TM^V]\6/VCOV0/B?\`L2?M2?\`!+;]LKQIXV^(/A>Z\+:Y8?#3
M6_`_C+P8VI:-<VVN>"_$^C_&V.\3P\M[9:QHVE:GIFL6OPCTFQ\,W5E:QWRQ
MG?,NF/6`QF&^KUI<DXI\CT5I/X&EMOMYZ&'#E+/LNQ\,?@\$ZM!5J?MG=32B
MIPE---NS<=5I>^VBU_:$R+;R6NHZ?/:PW%AX>86<MEJ%O:?8Y+AEUW3-6TF[
MU-;FSM-+\2:W!80:3XLN8+C63XBO-.NY[FZ>,1-_*1^S[XZ\&_LO?"[]NW_@
MFY\*OV[+;QY^QMXE^&'CG7-+_:#T'POXBTSQK^S!XTU_6;C0-;\(>(=1AT;1
M/"WB?PM\2/!WAS6-)NM2T$V-EIOC"+5O%UOI$NK7,=_8?,%O_P`%!OVC_!'[
M)^J?\$Y/B'XU?PSXQ^$OA'48/VB/VK?#?B:VU3Q1\#/AU#XB?5-(^$NI0:'%
M+X*\0?%&S7Q59?!#7K_4/%N@2>&[[4K'PM<:,WB;P!J&E7F%^P1\*/$_QFA\
M$?$*V\.S?#?]DCP%X@U"?P/\'K^VNM;F^+_B[P_;W5[IWQ0\?WWDZ9_PD$<7
MB6.QU:>UT:PNHM+\2SZ#-/?%(-LT\&<'8R&(K8C$8QRPM:=Z7LU=Q5DK^ZN:
M.ENB\U967UO&/$&"SFA0C'"NGC<-#]Y*2:<7O=.6KLVTN5Z)]7=OPCX?:O\`
M\%.?!/@+P1X,\,?LK7?B7PUX1\(>&O#'A[Q':>"9+JU\0:'H&C66E:3K=M<R
MW[2W%OJMA:6]_#/*QDFCN%D<EF)HK]_+KX;:@UU<M)XJ\4-(9YBYLIX5LRYD
M8L;12S%;8MDP+N;$6P9.,T5^G_ZI8;_H.J_^`S\O+S?X=F?G7,OYE]_]=E]Q
M_.?/+)!%>O#(\+G3;LEHG:-B51PI+(020``"3D8XK$\'2/=Z&QNW>Z)AA)-P
MQG))1&))E+9)/))Y)YZT45^=2_B8S_KW_P"VHUP/^]K_`!/_`-M/*OVK;BXT
M?P+#K6D3S:5K&D>-I)=)U;397L=2TN78R>9IU]:M%=64FUF7?;2Q-M8C."17
M]W'[`/B7Q'K?[!?P5UO6?$&MZOK*>#Y@NKZGJM_?ZFH30+IT"W]W/+=J$=59
M0)1M90PP0#117S>8?[W0_P"OE'_TY3/U?A+_`)$V8_\`82OSI'\&=C=W>I_L
M%?M.:[J5U<:AK?B;]H7X+VOB/6;Z:2[U7Q!;7O\`PB&JWEOK>HSM)=ZK!=ZH
MB:E=0W\UQ'<7ZK>2J]PHD']:OP2TO3-*^$_P]L-+TZPTVQ@\-6;06=A9V]G:
MPM/9:=).T5O;QQPQF9U5Y2B`R.H9]Q`-%%?M?!?^ZOT_2)^<YW_R,ZWHOT/5
M=B?W5_[Y'^%%%%?8GA'_V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+V)A=&UA;BYG:68`````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$Q-"`Q,#4Q-30S-#$U,"`P,C0R,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA(``@`/<`````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S
M_P!F``!F,P!F9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,
M9@#,F0#,S`#,_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`
M_S,S`#,S,S,S9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.9
M9C.9F3.9S#.9_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/_
M_V8``&8`,V8`9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F
M9F9FF69FS&9F_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,
M_V;_`&;_,V;_9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS
M9IDSF9DSS)DS_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9
M_YG,`)G,,YG,9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`
M9LP`F<P`S,P`_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF
M_\R9`,R9,\R99LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_
M9LS_F<S_S,S___\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S
M__]F`/]F,_]F9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,
M9O_,F?_,S/_,____`/__,___9O__F?__S/____B_)```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"'Y!`$``-@`+``````@`"````C^`+$)'$A08("#!1,:
M5*CP($*&`Q]"C.APHL$5%@TZ#&#QH)6,V`X"0$"R)(*"#C]V#&"R9<F0*3.R
M=.E2P$:5$$?:W!A`@`"3.SU.!!"4Y\&?)(OB;&C4*%*E.9LV_<ES*4JI4ZM"
MQ,HU)L.#@59T;7KR:X!`@0",Y5DVH<-`UP))74&7;=NK`:R@W8@6+:NT=K_F
ML:*6[[7#UUB1O4LPP+-G5HS"C2N5),6(CR&OW6A9(,F-F9]YM$)Z8Y4J@3V;
M=!RZ=>;3J#FW;<G:=6O8=LNNSI,YCV_?MT_G/KFZ=1[$O%]7(6&4)H+:CW__
M?@S;0'.7!VWWIB[\.NWDH8$JASXMUOOSS^"U<R_L_2!)`.EMGV:.];/[YP&J
M:!=NG2O[F?CE-UYY:P4$`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V
M871A<G,O<V5X>2YG:68`````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,38Q(#$P-3$U-#,T,34P(#`R,S<S-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$E`"4`]P`````````S``!F``"9
M``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D`
M`)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9
M`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`
M,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9
M,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`
M9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF9
M9IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``
MF0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9
MF6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`
MF?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9
MS#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`
MS,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9
M_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`
M_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9
M___,____^+\D````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(?D$`0``V``L
M`````"4`)0``"/X`L0D<2+"@P8,($RI<R+"APX<0(RH$H((@@(L2$:I0D2K5
M"A4?4S5+M7%%QH$<FTT;F6J4R&DK1YK,""#52I(;<[Y<"9+FR(VBC`DU)FJC
MS6DD)5(<Y20HLZ=0B3IYZ1$B1Y*BH&J%6K29UYD.57A588S9T*=GC0'PV@QL
MPZMDC>44.I>N2+<+5;A4D959J3VEGOX-;+9HU;`=`93U6R*NBA*$S7+$JU#O
M*,6"-])5$5GNX;>C+B\VNUBH5L^4)V)%N]4L6L.I$\*E.UKRT)2Q-8ZEV_=I
MT:%KFU5\F)(O,U%-A2+/VG6L596IDA?-&13YSL\,Q<+$*:J[=Z,PMT_G-J@=
MYD^*);&M./H38DVVS2X?A#L>X<7[`!+>/\F_O_^#^&&SGX`$YD>@4A8EF)^!
M!D84($8#,3C@20LJF*!2^PU888#_=>CAAR!Z&!```#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]L;W9E8FER9"YG:68`````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R-S`@,3`U,34T,S0Q-3`@,#(T-34U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y824`)0#W`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`
M,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`
MS&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS
M`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,S
MF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS
M__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F
M9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QF
MS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9
M,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9
MF?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,
M`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,
M9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,
M_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_
M,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_
MS&;_S)G_S,S_S/___P#__S/__V;__YG__\S____XOR0`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````A^00!``#8`"P`````)0`E```(_@"Q80-`L*#!@P(3
M)CQ(4*%``-<B2IQ(T>!":A@S4FOX<&)!CP0I7@,PD)JSDRA1DAPH$<"NEQ!'
MOMP5,^)*`"93ZB09$X"PF1!]`O7X,*=.E2Q=[A*6+%(DI;MJ[7IJLZ@S@BD!
M(`WZ,EFR6DY?UAI+=65)K5>-&=.*]5A(I<F$D1U+M^Q%E,:``4-[TBW7J'+I
M"K9;\N2>/0#T`MB#TJ],L8+K$L:Y<V]*QX^C1G8:].Y.OLXP/XX,EG#ASY=#
MMH1,ENK(HJ"/]E6].JI3UV9Q4HZ=NN;JVST?ZC;I5O9LEA6?!A=..33OQC=%
MULR-L7EQXVX7^FYYU_ISZ`X9EE(_J?68^>_.':H/G[/\>>/IUZ]O3KX@_/CR
M%=*_?S1[_H7'\"?;>?^%9YZ`E_E7H'8'\G>>60OJ!X!Y%%9((4<1JD>0A1SZ
ME6%^XB'TH7RLE&@B`":R@F*)(RJ48HHKEABCB2.^"..-,[*2H8TWGI@CBQ'R
MJ")!/A*9XHX\%E1DCA_:B.*3*_ZH8Y-.5GEDBT)F.65````[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A
M=F%T87)S+V)O;RYJ<&<`````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M,#<T-"`Q,#4Q-30S-#$U,"`P,C,U-#8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#
M``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_
MP``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%
M!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q
M%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(
M24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*C
MI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ
M\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`
MM1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!
M"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=8
M65IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJ
MLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ
M_]H`#`,!``(1`Q$`/P#\`S\;SI7Q@@\#^$)%\,>%++41)J][IUG+:W?B#0-'
MU*:WNK":YM;:RDM_#NN26DU[)I<=E.!`+=)%9O-CC_=']B7]MGXP_#>2]TO0
MOB-XMT30K;63KVEV5MK7B-8[32KT6QM-,%I:ZG_9=O97(GMT,"6US;)%!+`U
MBF`\WP-\<O\`@DC\>_V%/VQ?B%I_Q::T\4_`[QCKNJ6OP$^,=MJUAJ4/Q$L)
M?&*ZAX-T?Q'IFB73ZUX&\86UO:W]UJF@:Y8VVGSZGI>H+IFM:UH9LS<]UXGU
M32?A?X%\1;IUTZ^LXKQ]?UQVN(X_#ND66G7EW=ZC=K)')]K?2XM+^W0V\:23
M7YLA:QONGE63^2?&N&&Q>:Y7E.!J5)YO['+I1QN%JSC7H8J5:$WB(8BARUJ5
M:BFX2A3J[*G&G3J3DG+^Q_`2AE6)X?S/&9O1P5;+XU,7'V&,I0G05.G3A&M.
MLJJE2=.,5/GE*+N_=M:*D?T:^'O^"DW[3?C:XL/$6G_$W2].MM+TW3=,T^SO
MM`MHM(U:*]@GO[_5M5AMW%T-9M98A;0W]NBM+#-Y-Q;P1M)/6UX?_P""P'[4
MFA2ZE:W7AKX=>,+N[%CJ<4VH:;KT<>C0V;Z59ZC%#%IWBG2K:;2I;9)&2.6Y
MCGMM7FU">&2ZCG,,7\['[+'[1GP>^+/AJXU?0/%$_B2'2?M6A"2XTG7='6'6
MH_[%7=!974(GN5MTU"WE,[I)%/:SY0AX\I]/^'(9;OQ7J,NLW4T]AJ%M%'I:
MFWEMA)!+&/(4R1K!-;16KW<$VR7,LL)AN)79YFV_C^+XT\1N#<SQV#S'.<_C
MC<OHM5:682QRQ+J-Q4>>EB&X\T*<J4I1JTFI)W=Y7O\`:T_"3@3B_!PS+(L%
M@/[,Q&(4,%5RZA!T*M*$U[2U2BE.4.:-36,DDO=>JLOZL/@E_P`%:?@#XQTG
MPM;_`!535OA/XPU:VOAJD%WH^IZIX0L;NS$JK%#XATU+U4CE@L94C^U0KYEX
M#;PNSR1[_P!(/"'Q<^'WC[2-+UWP=XMT/7],UFQBU33IK.X=9IM,EBBF&I26
M-RD%_:V4<<T1N+BZMH4MF<17!BF!C'\*OQ+\63^%[NR2VN/,LK&2&:&S5A.;
M8+Y,CE)WFU*4?,S2AC=#8Y9\$EU/S3\7?C5KFHZ1>E_$U[%X;.FVEUJNGG[0
MUI<:C:68N+)C'(GDW-Q#ILMO86R1Q"SA\QKUX\0W(?\`2^$?I!<98FIE]',<
MDRS'83%0@WB8_6<-C9-PI14+T/:T95G=-Q^K2<I32]JE91_/^(/HW993P^*Q
M639[B:%6A%S^K8J%#$8=I25]4L'B*25.7-RRC-_NYO9I/_1.N/B=\/+.XGM+
MWQYX.LKRUFEMKNRO/$NB6]W:7,#M%/:W5O)>K)!<6\JO%/#(H>*5&1P&4BBO
M\G[4/VS=:TR_OM-MC#%;:?>7-C;Q_P!J:7#Y<%I,\$2>3_8Y\G9'&J^5D^7C
M9DXHK^@8<5<75(0FN%Z24XQFD\15NE)1:3M%JZ4K.S>MM=3\;?AM@T[/B?`W
MO9VI-KILW4NUV?FOG^F%E\7?'?QT%KXH^*WQ!U3Q3<VVG0V\5_K'BO6=40X5
M9A=YUS5-1NGN";E[J9WDC<PQD%"Q<'XK_:]\/_%;XK^`M<T'X2W6E_;-0U"S
MT[Q-)<W?V4:IX/TX74VI6D%Z8[JR_L[69A8V^HVU[&T=[ILE_:WL3VMPT,GV
MOK?P:U7PY\"-#\7:4D]O<ZKXFGT9()3F21?[&M-2MG:2S`$4FV2=%>9S&PLG
MB*[I%+?.5GX.\8>(9K;PWI=U>VFL7-XLTEHD\A2XM<I%?3).+^TB_=C+RVDR
MYD1?W?F.WEK_`"5D694\#G4<[I5L,WEV/C7H4L>EB*-)473KQJ5:<JL95()Q
MBTY2;<FFE>"M_:V;<.Y;F_#N.P.&4<#A,7@L7EE6>74XX>%"SC0K\M2C2G&G
M?GUC)6BE9VYKE7_@GE^SAXP,7B[5=:T;1-`\3>+/%GBWQ7/HGAAM(L_!6D7N
MJWL\"V/A#0O#&AZ5H.D:(=$^RQVEC;V#/IBP/'8O;Z1+%96WZ\^,/@-XB\+:
M=<W>MVKV]MK-N9++4;>.6/3M)C@NFMY+>*0V'EP7)PKW7V9[CSO/17\O`%=9
M^Q!H?AGX406EOK,+WTKZI973WEU$+K<TWA^QAO3:VS))/:P75Q'J&+7)?;Y7
MFET#F3]JOC)+\#?B=\-+3PN]U#X>U"9XKNRF^S2QO!/>:E:WLR6HM[0P+;^4
ML<$^1\C+(&/&:^!XYS'/.->(,ZXHGB</%RG&O"FU*FL1&A[&FJ="K.,U&*I4
M7+DJ-\TDK-N33\;(,=4X`P7#/#."R[,Z^386,\,\?&G4JQIQE.K7EC*E*DI-
M*5:LYJ=M(N]MC^!V;]HC5/#7[>GB+X<^,M?\:365KX<T[PYX>L]+U+0]'\%+
MXDU#1O#&JQ>*O']IK,.IZKX@AA\/:KXC2U3P_?>#?$VE>*]'\-WM[JVMZ5<^
M)-+U+V;]H9+^S\"7UQ:64QT2"TO)KM500B.QQ.;F6.0RVMA(\-C$MM+]I18$
MCCFCB+6T,0KZ8^+OPM\&^!OVC/&;^.?`GA_5/$6DWT=UX6\47?ARSNM:EMM0
MM+>25K;7/LV]=.CCDC@CM[EC"D4"6]ND;#)V_#FEZ5JEIK-GXBL-)O-.&H33
M"RU9+>;1Y8O)1G-U`2UK-'+$6@E@>&1W@:0.I#JU?I^8\79-;@O,<#D4</\`
MV+D&5X?&QH^P5/-ZM-R=7%8>6'CI5J3J2526)4JO-.$92E&E!+@R3A;B3#T^
M-\1B<X>,I<19[CLURW$3J59K!8?&1J.E2E&M&G"-.BWR>PHQC3?-*5DY2;_F
MZE\/:WJ<LFI6NE72VVH2/?6ZPZR8X5@NV,\*Q()W"1".11&@9@J8`8XR2OZ;
MKG]H?P?H-Q/H5CX"\`6EEHLTNDV=K;^!K=(+:UTZ1K.WMX4M?#$MJL,,4*1Q
MK;2RP*BJ(9'C"L2OUN/CEG:452\/,9.FDE3D^(\&G*"4>633P":<HZV:33DD
MTNGX-/PPKN<G4XPP"J.3=11R^;BIWCS)-8BS7,M&M&FK>?[JV/P<OO%'[/WP
MY\'ZNMB+>VMM/B2PCTR:"]M-0DTHQ7#F>\>-WTV"&66XT]=$BN;-%N'5+N6T
MBFE3N?V;?^":FDZ=J_\`PGWB&UBU)+J348M'EO+::]2!;Q[4VUW'!+J*I;S0
M>6SI/!:07N#L2\4`(GZ$^#/"UMX5\+VGA74M'UB^T6V^S;KC3Q#J>IQ7J1&&
M\T[[5:164-QH3Z?%N>VBLC-%-)-<7$K02(D?L^G_`!)\+^%_!-YIOAR[MO$>
MO:?IE]<Z7X2DF-KJ=Q'8VTRVFF6J,CS)?B^%E800B&57DD>-&+%%3\2X-X3P
M>.S;"XC-:\:5.EAH5))U8TU6Q-&$(^PG1=:-3%4I<LVE!5'-N*C"7O6Y>(O$
MC.\-EF9Y7DTZE+"YGF%>5>%-3G2]ABJTJDKUHIT,*_:*#E.?LY+W_:34531_
M/E\??V=-1_9O^*[Z;;ZQJT_ASX@ZYKVL3/HUK<SW6E>(M8\0QW8UR:+5+^:Y
MFL=-L+S5O-TZUU&WC9(7V+-(T$$UCP'H&N_&;Q5X1\#_``U\6KXVU#3[N>X\
M0@>%&M)=(MM7TK36TB$W>NR:=%/-]DN+J\\K3M1$$,6FR#5/M-U-I]C7U-^V
M1^T+\7_%?@'4;CPO^RE>+\21ILO_``BNI^-I]2N+2TM=3GMK=[J6TTK1+#4;
MBY@M)KN.6W@U&R^R:B]JLUS);W$AA^S/V(O$GPD\/IH<_P#PI3QI\/?&/B2U
ML=.OS+X;TS7_``Y;7^G6-Q%+?+XMT&QL9HK1XHMLK:UI5E/:^9;V0N+J.);N
M7[N7`N1YKF$LO>)G@,NQE2$Y-*MAI3A7UG2BJU*5ZE.O*#I\\8J,)6ES**M^
MIP\8,WR?PPPM7%9/3QF;TJ;R^GBZ6)R;%T)5J4'&&*KX>C.IF$J,</%7E2E&
M%6M37MHS5.FH_E__`,%7?V$/#GA:Y\"_$];A-2N(?#$6C^(1?6]NC075L=/M
M+*ZMM1@GN;E))H#+YD!LC9*D6Q)_,D1J_/-OV7M#^'_[*UW\4M9T2.35_$/C
MV*UT'PT=0FMM4_X12/P?<7UQXECTJSOWUO6+>XN$ATF.>RLC&UU+'!$GVEEC
M?^S/XO?#SX;_`!CTD:7XLMO#6KZ3Y]J)6U.+3+BS>*WC:1()7OHI;>&.60!"
M)$^=Q$L95@`?Q-_X*5^&C\4=&\`?#C]GG3[K^Q?!ES#X:UBU\#W\VGP:)"UO
MK.EW%QJMGX;T.1V\(V,%W!8ZV]YXCM]'@>[MHK[2H;BXTVYNOB.->#_]5<RQ
MDL-CE'AJA.BLGP:Q,ZM:;E3P\9U*5G)5849RK8NHY*[G."LXIQ/"X"\6,9GF
M599PQ7C-YG+'5:N;YUB)4Z>$_L_#RJUZ-*I*$(U*<ZU11PDI*<83H1C3DI-M
MR_EI3X(:9JB)J<NG1Q2ZBJWTD9U?483')=@7#H8KG48[B(HTA4QW$:3H1ME1
M9`R@K^E[P+_P3_L8_!/@Z/7(?"]QK4?A7P\FL7!5(S/JB:19KJ$QC6Z14,MV
M)G**B!=VT*H&`5Y:\0N(HI1IU,0J<4E!.6(NH+E44]=U%6\_FSU)YCPQ&<HR
M>72DI-.3JXB\FFDY/_:4M7KTO?S=OTJTR\N[+PC916=U<6D5SK-R]Q';3RP)
M.\K1K*\R1,BRM*L<:R,X8N$0,2%7'YR?M&>*O$_AZR^'>HZ!XCU[0]0NI=*D
MN;[1]8U#3+RX=I]0G9Y[JRN()YG:>""9FD=B988I"=\:%2BO;R__`'W)?\=+
M_P!*1^#S_P!VS;_!+_TNH?M5X`TW3O$'@+X?WNO6%EK=Y=^`HY;J[U>U@U*Y
MN98TTQDDN)[V.:6:1&GG9'D=F5II2"#(^?)OVKI9/!?PUT23P=(_A.234-)B
MDD\,NV@N\5UK-M%<QNVEFU9H[B/]W.C$K,GR2!EXHHK^AL\_Y%L?^P3#_P#I
MJB?F6"_A8;_L:8C_`-)K'A_A7Q'XAO[".&^U[6;V*?2].EFBN]4OKF.:7^TM
M;7S)4FG=9)-L,*[W!;;%$,XC0"'P[I6F6_Q"6^M].L(+V[\<RZ5=7D-G;Q75
MSI=])$;W3;BX2-9IK"\,LINK.1VM[@R2&:-][9**_G;BG^+EG_7Z7_MI^I<.
M?[MG?_8'+_U*/M\Z+HX)`TG3`!P`+"U``'```BP`!T%%%%>-4_B3_P`;_P#2
MH'AR^.7^+]8'_]D`````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:&]M
M97(N9VEF````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3,P(#$P-3$U
M-#,T,34P(#`R-#`U-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!'248X.6$@`"``]P`````````S``!F``"9``#,``#_`#,`
M`#,S`#-F`#.9`#/,`#/_`&8``&8S`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9
M`)G,`)G_`,P``,PS`,QF`,R9`,S,`,S_`/\``/\S`/]F`/^9`/_,`/__,P``
M,P`S,P!F,P"9,P#,,P#_,S,`,S,S,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9
M,V;,,V;_,YD`,YDS,YEF,YF9,YG,,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`
M,_\S,_]F,_^9,__,,___9@``9@`S9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.9
M9C/,9C/_9F8`9F8S9F9F9F:99F;,9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`
M9LPS9LQF9LR99LS,9LS_9O\`9O\S9O]F9O^99O_,9O__F0``F0`SF0!FF0"9
MF0#,F0#_F3,`F3,SF3-FF3.9F3/,F3/_F68`F68SF69FF6:9F6;,F6;_F9D`
MF9DSF9EFF9F9F9G,F9G_F<P`F<PSF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9
MF?_,F?__S```S``SS`!FS`"9S`#,S`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`
MS&8SS&9FS&:9S&;,S&;_S)D`S)DSS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9
MS,S,S,S_S/\`S/\SS/]FS/^9S/_,S/___P``_P`S_P!F_P"9_P#,_P#__S,`
M_S,S_S-F_S.9_S/,_S/__V8`_V8S_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9
M_YG,_YG__\P`_\PS_\QF_\R9_\S,_\S___\`__\S__]F__^9___,____^+\D
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(?D$`0``V``L`````"``(```
M"/X`L0D<2!"`00`$$RI<F/`@$B0D&$ID2`+`0Q(8,T[<2`()`!(J1C4;V6R4
MBH@;%W8,2;)E214I58YRXK+E*)0Q!ZJH61-F3H$D1/*TB3,FB:$N38+,N9/G
MJ!505ZA@=8W5"J-.K5"MNF(K*Y\3C];L>JTL5U9:BS)DZ7*%6;-=6;%2NW;D
M"J%DK93]JJ(O$J.C3+(<]41NU2=";\;\&'+FR*=][Y)4G-(B`+8V`TL]^3=E
M1(--)V\&1(J4'KH2@R9]HJ>T:].H93HNN:+U:]>Q5;*M??OUZ9]BFZG0,[PW
M[)^AAV,\>=(@QI_8@A=_G2=WV,DJ;EN?&+H9[]*_H38+E"KT)>GPXN-"3=Q7
MQ4?QT<U:E?QXZM6?4+?N)6^7:T[U^LEU66!35;4=-@<EZ)R"#!(4$```.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O879A=&%R<R]B87)T+F=I9@``````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(Q-C(@,3`U,34T,S0Q-3`@,#(S-C<W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y824`)0#W
M`````````#,``&8``)D``,P``/\`,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`
M9F8`9ID`9LP`9O\`F0``F3,`F68`F9D`F<P`F?\`S```S#,`S&8`S)D`S,P`
MS/\`_P``_S,`_V8`_YD`_\P`__\S```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S
M,V8S,YDS,\PS,_\S9@`S9C,S9F8S9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PS
MF?\SS``SS#,SS&8SS)DSS,PSS/\S_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F
M`&9F`)EF`,QF`/]F,P!F,S-F,V9F,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF
M9O]FF0!FF3-FF69FF9EFF<QFF?]FS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F
M_V9F_YEF_\QF__^9``"9`#.9`&:9`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9
M,_^99@"99C.99F:99IF99LR99O^9F0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9
MS&:9S)F9S,R9S/^9_P"9_S.9_V:9_YF9_\R9___,``#,`#/,`&;,`)G,`,S,
M`/_,,P#,,S/,,V;,,YG,,\S,,__,9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,
MF6;,F9G,F<S,F?_,S`#,S#/,S&;,S)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,
M____``#_`#/_`&;_`)G_`,S_`/__,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_
M9F;_9IG_9LS_9O__F0#_F3/_F6;_F9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_
MS/___P#__S/__V;__YG__\S____XOR0`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````A^00!``#8`"P`````)0`E```(_@"Q"1Q(L*#!@P@3%B2!C2'#A@HC
M(@2@8E1%%20<2MPHD,2H9B";I1I%`@!$C@I)I`H9$B,VDR@3JF09TN+#AS$)
MJJ!)TZ;&G`T_\J0Y$B,2G!QG#AUJ$2;*G4N7DD0)P&/4I2IB`@"P\FI/I!))
M0/7*,BM*CZ.ZBDREEN?4I"I6R!TU2JY=H33-;ES!JF]?N7[[5L$+,A58F:RN
M6;EVC15?QI`=?TV:&/)CQ9%7M-4;MG+CRY`_JS5\-K!CSYE''TYI%W!HQI)K
MKI:9ENVH*JA9#09I,Z='MKQQ_UTAU"=0%<BAUIW+TDG:MQPK`F?9EK=SZ&$)
M>[TX&Z%2LLTJ4):,:15\,XM`&TIGR[[H6-+I&V:<GYPP_/@$T58/C]^@6*8N
M]3?0=Y,)V-!^O'&&7T5NR87%"MUM1,(5Q+57%Q98"()AA`IMY>&'('Y84$``
M`#L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]A=F%T87)S+VYI
M;FIA+FIP9P``````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q,B`Q,#4Q
M-30S-#$U,"`P,C0P-38`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_]C_X``02D9)1@`!`0```0`!``#_VP!#``L("`H(!PL*
M"0H-#`L-$1P2$0\/$2(9&A0<*20K*B@D)R<M,D`W+3`],"<G.$PY/4-%2$E(
M*S9/54Y&5$!'2$7_VP!#`0P-#1$/$2$2$B%%+B<N145%145%145%145%145%
M145%145%145%145%145%145%145%145%145%145%145%147_P``1"``R`#(#
M`2(``A$!`Q$!_\0`'P```04!`0$!`0$```````````$"`P0%!@<("0H+_\0`
MM1```@$#`P($`P4%!`0```%]`0(#``01!1(A,4$&$U%A!R)Q%#*!D:$((T*Q
MP152T?`D,V)R@@D*%A<8&1HE)B<H*2HT-38W.#DZ0T1%1D=(24I35%565UA9
M6F-D969G:&EJ<W1U=G=X>7J#A(6&AXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*S
MM+6VM[BYNL+#Q,7&Q\C)RM+3U-76U]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ
M_\0`'P$``P$!`0$!`0$!`0````````$"`P0%!@<("0H+_\0`M1$``@$"!`0#
M!`<%!`0``0)W``$"`Q$$!2$Q!A)!40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1
M"A8D-.$E\1<8&1HF)R@I*C4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI
M:G-T=79W>'EZ@H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZ
MPL/$Q<;'R,G*TM/4U=;7V-G:XN/DY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1
M`Q$`/P#URLC6M6EM)(;.S57O;C.S=]U!W8^U:]<FK^;XBU&>3[T;+`F>R@9/
MZT`6H]&M<^;>;KV<_>DG.>?8=`*+NT"V#PV>+<]1Y8Q@U;WY7;W'05!)*'7.
M:`*_A"VM4AGD$6+Y&\N9VY)],>U=-7,:"V/$.H*@Q'Y2%AVW<_TKIZ`"BBB@
M`KC;MY;#Q'<P>4'^V,)(R6"CI@]>]=E7+>,+;<]E=-Y@CB8JS1G!0G&TY],B
M@#,N+K6KDM]DMA#&K;';?T_VB?3Z59M7D'FS/.TL)`$;D8S@<GZ$U(D`GA#7
M<]W,"/\`5S,"`?<#@T13F]DD*;3!'\N<<,>X'M0!H>%8&-E+?RC$EZ_F`?W4
M'"BM_-<=:2:EHUN\-E''<VY.8UE;:8L_S'M5D6^K3J9)=7='/\$2`*OMS0!U
M&:*YG^SKSOK=SG\**`.BN)X[:"2:5ML<:EF/L*Y-Y-0\01M)<3FRT]P=L"*"
M\B^K$^M:_BE\:,\?/[V1(_S-9AN3<ZB(8>(+?'F%>A..%H`SYM&DM8!%%=7<
MELRX*H063_$582Z:&VM+6VA62X:/*J@P@4=6/I6EYF?F;@DX^E-1@.<8P.*`
M%M;1D827,PEEZ#`PB>N!5J:6.!#([*@49))JO<&06TI1]C[25;_:JEIP.O7R
M)<(/LT$:RR+_`'W/0'V'6@"+_A(0>5MI&4]&'<>M%=B$4````#MBB@#'\3_\
M>-O_`-?47\ZQM+_X\ICW,[_^A444`32D\<]Z=;DE>O>BB@">YXLIR.HB8@^G
M%.\(@"VNR`,^?C\-HHHH`Z*BBB@#_]D`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V%V871A<G,O<W5P97)M86XN9VEF````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#(V(#$P-3$U-#,T,34P(#`R-#8P,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$@`"``
M]P`````````S``!F``"9``#,``#_`#,``#,S`#-F`#.9`#/,`#/_`&8``&8S
M`&9F`&:9`&;,`&;_`)D``)DS`)EF`)F9`)G,`)G_`,P``,PS`,QF`,R9`,S,
M`,S_`/\``/\S`/]F`/^9`/_,`/__,P``,P`S,P!F,P"9,P#,,P#_,S,`,S,S
M,S-F,S.9,S/,,S/_,V8`,V8S,V9F,V:9,V;,,V;_,YD`,YDS,YEF,YF9,YG,
M,YG_,\P`,\PS,\QF,\R9,\S,,\S_,_\`,_\S,_]F,_^9,__,,___9@``9@`S
M9@!F9@"99@#,9@#_9C,`9C,S9C-F9C.99C/,9C/_9F8`9F8S9F9F9F:99F;,
M9F;_9ID`9IDS9IEF9IF99IG,9IG_9LP`9LPS9LQF9LR99LS,9LS_9O\`9O\S
M9O]F9O^99O_,9O__F0``F0`SF0!FF0"9F0#,F0#_F3,`F3,SF3-FF3.9F3/,
MF3/_F68`F68SF69FF6:9F6;,F6;_F9D`F9DSF9EFF9F9F9G,F9G_F<P`F<PS
MF<QFF<R9F<S,F<S_F?\`F?\SF?]FF?^9F?_,F?__S```S``SS`!FS`"9S`#,
MS`#_S#,`S#,SS#-FS#.9S#/,S#/_S&8`S&8SS&9FS&:9S&;,S&;_S)D`S)DS
MS)EFS)F9S)G,S)G_S,P`S,PSS,QFS,R9S,S,S,S_S/\`S/\SS/]FS/^9S/_,
MS/___P``_P`S_P!F_P"9_P#,_P#__S,`_S,S_S-F_S.9_S/,_S/__V8`_V8S
M_V9F_V:9_V;,_V;__YD`_YDS_YEF_YF9_YG,_YG__\P`_\PS_\QF_\R9_\S,
M_\S___\`__\S__]F__^9___,____^+\D````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(?D$`0``V``L`````"``(```"/,`L0D<2+"@P8,($RI<R+"APX<0
M(TJ<B!"`Q8L8,V9<"(`6+4@@0XH<"8D-&P`).])BQHS31Y(P3:(TJ)*9L9<A
MV2#9*=+839,G"]:\*9(-)V,LC;D,Z=*HS($UI>$LB52:56DVI[)1^C3JTIQ5
MKUIEAI,-,VF<9`(PR8DLR:UGQ6*E!?1LVJ!KC4X=&5;NU;LSL>7=.]*C84MM
MK0(6:I(PS)"T."VF"=3DX[=/*[+E6KESSJ`*\R;VB[5E2=`<V;;T>#0II].!
M&>:%Y!AH[(:S,:.&*+JRI<P31;.<3%$P6^+%C=M.SG@W<X$6GTN?3CUA0```
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]D
M:6QB97)T+F=I9@``````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,#4@,3`U
M,34T,S0Q-3`@,#(T,S<P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y82``(`#W`````````#,``&8``)D``,P``/\`
M,P``,S,`,V8`,YD`,\P`,_\`9@``9C,`9F8`9ID`9LP`9O\`F0``F3,`F68`
MF9D`F<P`F?\`S```S#,`S&8`S)D`S,P`S/\`_P``_S,`_V8`_YD`_\P`__\S
M```S`#,S`&8S`)DS`,PS`/\S,P`S,S,S,V8S,YDS,\PS,_\S9@`S9C,S9F8S
M9IDS9LPS9O\SF0`SF3,SF68SF9DSF<PSF?\SS``SS#,SS&8SS)DSS,PSS/\S
M_P`S_S,S_V8S_YDS_\PS__]F``!F`#-F`&9F`)EF`,QF`/]F,P!F,S-F,V9F
M,YEF,\QF,_]F9@!F9C-F9F9F9IEF9LQF9O]FF0!FF3-FF69FF9EFF<QFF?]F
MS`!FS#-FS&9FS)EFS,QFS/]F_P!F_S-F_V9F_YEF_\QF__^9``"9`#.9`&:9
M`)F9`,R9`/^9,P"9,S.9,V:9,YF9,\R9,_^99@"99C.99F:99IF99LR99O^9
MF0"9F3.9F6:9F9F9F<R9F?^9S`"9S#.9S&:9S)F9S,R9S/^9_P"9_S.9_V:9
M_YF9_\R9___,``#,`#/,`&;,`)G,`,S,`/_,,P#,,S/,,V;,,YG,,\S,,__,
M9@#,9C/,9F;,9IG,9LS,9O_,F0#,F3/,F6;,F9G,F<S,F?_,S`#,S#/,S&;,
MS)G,S,S,S/_,_P#,_S/,_V;,_YG,_\S,____``#_`#/_`&;_`)G_`,S_`/__
M,P#_,S/_,V;_,YG_,\S_,___9@#_9C/_9F;_9IG_9LS_9O__F0#_F3/_F6;_
MF9G_F<S_F?__S`#_S#/_S&;_S)G_S,S_S/___P#__S/__V;__YG__\S____X
MOR0`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````A^00!``#8`"P`````(``@
M```(X@"Q"1Q(4"```-@.(E28D&'!AP4!/#LXD:)"9,@00MS8\)G'CR`S:N2X
M42+(D"-)0C1YTF-&E1Q9MGP)<V7+CS1K1KSI,J5.@SR?Y?R9\)I,E$0-&C7Z
MD:)0GS4!+%5H4N)0G5*S-IWX-&E1K1XE6H4*TV++L4F=GG1ZM6Q0G&1)'KW9
MMJS:F7'=\JP;-2A?O73SJIP+MZ1@PCT-YT7L,"+5DDVI7C.Z\B"DN)(G:SY8
M&1+EAP`N:YZL\'-$S]<N@X8DVJC4S61?FQY8^N#HS2L]-Z8M^S;IV`I5TV[M
M&_?`@```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]A=F%T87)S+W)E:3(N:G!G````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,3<Q,2`Q,#4Q-30S-#$U,"`P,C,V,C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````_]C_X``02D9)
M1@`!`0```0`!``#_VP!#``$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0'_VP!#`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0'_P``1"``R`#(#`2(``A$!`Q$!_\0`'P```04!`0$!
M`0$```````````$"`P0%!@<("0H+_\0`M1```@$#`P($`P4%!`0```%]`0(#
M``01!1(A,4$&$U%A!R)Q%#*!D:$((T*QP152T?`D,V)R@@D*%A<8&1HE)B<H
M*2HT-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ<W1U=G=X>7J#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN'BX^3EYN?HZ>KQ\O/T]?;W^/GZ_\0`'P$``P$!`0$!`0$!`0``````
M``$"`P0%!@<("0H+_\0`M1$``@$"!`0#!`<%!`0``0)W``$"`Q$$!2$Q!A)!
M40=A<1,B,H$(%$*1H;'!"2,S4O`58G+1"A8D-.$E\1<8&1HF)R@I*C4V-S@Y
M.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W>'EZ@H.$A8:'B(F*DI.4
ME9:7F)F:HJ.DI::GJ*FJLK.TM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:XN/D
MY>;GZ.GJ\O/T]?;W^/GZ_]H`#`,!``(1`Q$`/P#X(^('Q#TZ\_X*&_`/Q+I'
MB^[NO!EY\=?CM\#M/M[?65N?#5EHOP5_9X_9G\2:9/`MO=MI<%Y;^/?B7\5;
M:?R6"6EW>31);VNHW6J&X_=C]NKXH+IG['Q^,FB:@]E=S^%_AT(;NTN=DRX^
M,?@3P;J:6D]M<+(T\>A^,+1D2.Y+)$Z&3]PZ)+_'YX(T"\LOV>;KXD7'Q+\)
MVGQ`^"OCCP5^T1H6G7WB#2;FX6]^.&I:CX*^+L\NFQ7<]ZUEI*>'_A2NH![.
MX:ZF\4:5%I=G]IM[\5_1-\*_&'@/]N#]@SXB_#'P+>ZE/-H?AKQ1I=A:WT.J
MVTNGS:C<>(+GP(S7.KQV$+7=CXC^&^A^&+KR;RXMSJG@>\EO+D17]E?ZM^@<
M#\94<YPF8KE<,SHXW$XKZO5TG6IXA4DY4%4?+.,'3J*<8.3C[KDDI1;^"\0>
M`JW#V9Y(^6GB,'++L"I5*=2C5C3K4KO]\H2DZ<IT:E&HIU8QY^9I-SA.,?KW
M_@LAXG^)GAE?V?\`XG_#RQOM9T;P[HNI:AXN325U6XS;+:_"'XPVLEO'I3"&
M.271?A#XJL[-[B9`]]J12$E+BZFA^@?VW?#7AWXC:CXP^.27%OJ^F_$;_@FC
M^VI\-M&O8!%)8W?B7PC=>`/CKX6L;NZ5+CS+^_\`#&G^/&TE#=S2M:Q:I<V<
M"VT.HW2?/OCWX[?\+F_X)R_"SXW>'8K:['BCX:^%=1$MQ"DL%_)\-?'^C>#O
M'NA7,-[!&-/CU'0=,\5>'+N<H9+*U\17<]NMX]M;,_S?\/OCAJOQ#_X)Z^#/
M!'BKQ)IYUW]G+X]Z)X#\;ZJDUG;-K/PD^(/@/QO\&6U96W6T$J:_H7Q:\-6]
MQ9VES>:E%=6TZ*9)K.>:'DXK>'KY3F.%HRC*OA:-?$\NL)PPV+E.FJL7)1]R
M#@I-1;Y&DY16Y7#E.MA.)<JQSPU6M@XYUAJ2G&E*I"35+"8F=-J,9.$YTZEO
M>47*TDFY4Y*/RI\/?&/BSXU?L!?M"_LO>+M<\.6/B[]EJXTSXL?!31]=OTM=
M4\0^%/A3:1:M\'?&GV6]N)K_`%6#4/!NI^)OAQXINM)L+>WO=0TD:7:WD5O;
M3Q+R/[#WQP\8?#E=,7PYK'B+3-;T:STOQ%X8T'6K77=(MO"GA0_V?J5GIVI7
M^A7-L+J#X9>)]*;PSXOMF$?_``COP[\1>%/!UR;;4[^YA?S;6[/XI:'9>"_C
M5\,OV>/$7Q"OK/X2:G\&?C#K$^L>'/"]JWPSUE_M.K6MOI>KZ[:>--2O?#^L
MV'A?Q'X>U6Q\"-!?7-M>:/;:B/[;O[.;YF\%7/QJ\1>%Q#\/_`TNI:[X:U#6
M_C-X1UGP[\5O#,FA:EX9%G!8_$[P1KUUJ2Z'-=:9X[F\2ZSKNM:&DNNZCHNG
M>-!=Z//.?">FR:9^)Y)XCXCFX>XDKU:,IPPW]@<5X%UJ57FIX.<L/+%5:<:D
MXIXC"^SK6E^]A4H3YXQ;@G_2O$_A52AF7%G"N"PV*J8;,5_;W!F,6"Q-%RJX
MN4<1#"X:56A3E5=&O*>'4J:E3G&O2G&<J//./]HOAS_@ME\*-%\/:#H_C'P5
MKUSXNTG1M+TSQ5<65[\([FSG\26%C!:ZY-:7-WK_`-KN+:74XKIX)[K_`$B6
M)DDF_>LU%?QO0_M[_L]:;%%IWCF>]\->-M/C2R\8^')?A++XFE\/^*;51!X@
MT23Q';Z<8/$$FE:M'=V#ZW`3#JK0&_C.R=:*_<(9=PQ6C&M#B#*E"K&-2">8
M896C-0E%-.HFK)V::6TMNG\Z/#<3T).C/A_-5.B_93_X3L1\5-QA+>E?>/77
M>_6U;PK/\??B9XW^$7P#_9A^`'_"P/'4WA>]OO"USJ<>OVOA?4/#MKX7N7\:
M)>78T/03>P_V!/J.H7$&G37Z6%W'H.NEK273X+R+S7X-?$KXA?L5_M33^"->
M\##P1\0]6UG7O`OCCX8>"]?M?&&@ZGINE7MU9:YI7BK2-5N]/\5?#K5(=3T_
M2]:\!7.J>%[C4?%.F26.W4(M/N[9+G]=?V%_APWPJ_:B^&'PC\2:Y=Z_J/PN
M\:"Y\%_%"WL[W0-1U3PM/HOBOQ#H&I>'M7%Y#<VLDFC6%SX:U:ZT+6I%D.D7
M^G2S7T3V=K=?HI^T'_P2:\!?'+]M=?V[!\3['PKK<?BCPKXPUOP#HWPSWS:[
MXJ\+Z3HM@==7QLGQ!TF;2;G7;GP_INJ^(+>+PAJ0O6CN+>6XE6]N9J_D#+N+
M\KX+Q^+I8[!8W*<ZRW%8FI&K[3$5'B:LINU3FG[LJ<TM::A:/,DGK=?VYQ#P
M7CN.L+E>*6?T,[X9XAR_+)T</+!<CR^"H4J4,.J="$9NK1E%N<U4<M%SQ2:/
MR-^!'QN\`?LPR?$CX$^)?%:^)_V8?B)KVH^-_@KXBG>UCG\/CQAHMO>?%/P9
MXFN[AAH,/B*"7Q/HZ6%A8XM$U72;T6\#SO/-<K\([O6_"WB&^\3:;8V4W@SX
MO>";OP'XSU2&YM4TSX>?$%-?MI;'Q8+&*R>V/AKPUK$:>+AJ5U<0WUEX9?Q,
M;NSO%TK3+.7]$/`7[*7P`^,_[0_Q._8WNO#]CJ5CX@\&P^/?#/BN+1[:[U#X
M0>,/#BZ9#JELLL\"#Q#_`,)EH^O:`TBW1T^RW>"XYY?M%W<W*:;]V_"O]@+X
M7_">V\4>&(M-C\1V7B=X;Z[^V)]GTK3+YH[BQU>#1_#LEWJ%OI.G:K$MK+=Z
M7:ZBVGO*;G9;I]H=VWXG\9L5FV593FBP,X9A%8W!U8R@XX7-\HQD81GA<13:
MA*+PZ<I4)Q;=1M7<=#+A/P0RGAS/,^R/,LS57+*D<!C*=3#S?U_*\UP<ZE3"
M8^A1G=3CB(S<,50JRA*E"7+*[BC\\OAE_P`$V/VD_P!J#6QJOA76_A_X0^$N
MJ^&[B#6O%?Q/TNR\=>+/"&KZ_/;:A-%\,OAE.TW@BROD\&WVF:A8_%CQS'XH
M\8ZA=#9X:T+0O#VHQ:BW\GOBGX1_'_X<?M9^-?!/PGE^*.I>/OA5\3/B%X>U
M#5M>T<P:IJGQ)\(_&CQ'\.[>'0(?"L&@O;6?B62ST"RL]#U*2#4;[6]5O+&/
M3)-(FM@?]//X2_"N7X<^#--L_!B#PQIMM8V]M#!9WFHE3'%;B"VA\HW,2P01
M0A8XTC\Y+:"*&WAW11*$^&?$?_!.C]C?PK\1_&W[1.H?#.+7/B7XEU[Q)\4O
M$GB34_&WC[4=,?Q7>:E+XSU;Q%=Z/+XB.E$G6-*3Q$R7L#QC4!(&F\RX$I\W
M*^+\-E62TZ53))498B+E2C4P].=/$TL1S*4HPBI5'B*DYQC)-MR34KK4Z\?P
MAE6;<28S%X[.:V+P^&@UA9/$U:+PU?#^RDJ<YQJVH83#\CG35&<+<BC)NUE_
M&+\1_!?[8_A;XA^//#&O?LH^'/B%KGASQGXHT'6?'VF?"'XJ:GIWCC5M(UR^
MT_4?&&GZE9>-+*SU"R\37EO-K5I?6EG:6UW!>QW$%M!%(D2%?T3^-?CO=0^,
MO%L.AV>FOHL7B;7HM(=_$6IVCMI<>JW::>S6LFC/);,UH(2UN[,\))C9BRDD
MK:.'\1Y)2I>'=%TI).FW.2;IOE<&UT;B[VZ;==>CE\'UI6\<LTC66E6*K1M&
MJK>T2WT4DTM7HEKU7XF_"CXU_%;X%^,_!O@_1?B39/\`!71-8U_49O"GB_2-
M,U[P9\,O%5_IEGJ>E:K?WL=_H7B+2](\7OKNGVZ"'Q3::)H6MP^'M3U*SNM.
MU"UL:_KL^$7Q"TCXW_#31?%=C+#;3:UI=S!-':WL-Q>:5KT32Z9?+<8$:0S"
M2T9X[6XB622VGADB"$EW_BAMM,\5?$?PI?>*M$@T#Q%\9?A+I.H6'QT^%OAW
M2[P:+\4_"VJV]NWA^XTK2KFQ35]9U;1]#U&^U*T;7X[*'3[G4/%>C6-WJVF3
M0VZ_=W[''[?,W[+_`/PA&M^,+_5=7^"7Q)&K6?A?Q+XDUNUU76$UOP:EVWB7
M2O&4FEWTV@0:]I4?B+0;K3;E&L[O7_!]Y::M;6VIQ:+XBO\`2OT+Z17`%?B"
MM3XUX0J0Q6'J8>-;%X"#P].<HSC2J4\;A*K7M,0IPYZ=?#/3#RH1FES8EM_F
MOT<_$#`91@L7P/Q+SY?BJ>+KSRC-:\YRPRQ<*D:=?*,;*;Y<,_:>SE2Q,=5[
M24$[(^_O@/X-_;!_8<_;5^-_B[2O!&J_'?P;^T6/`\%UXWM;"72Y_ALWP^\.
M>+$M-->S@BU1;W2_$VJ>,KV"\EC;2YM*U%+%[MKRSN;>%?WE\(:YK&L:9;:A
MXF\-?\(WJ\KNEUI<EV+F>UMQ&9OM+NL%O\K2EADQ+@J!OVDK7S'%\3?`_P`?
M_!@UK2=5\5Z59ZFD$TA\)>)=4\#^(+232KUT2*RUWPMJ6FZO;>6UHQN7M[Z:
M">%F\B5[:<,_6?#KPCX7TN2]N;C5?BCKDA6'[%%XV^,OQ2\3Z?!)#<6MS;7/
M]CZSXKU"R6<W,$4KWL+)=NJ-`)4MY9XYOX]QN8SQ\\/0S'%SHUL#A*6!HT84
ME2IJ-&G&E%UXT^6G"NU3CSOE3<TV[MMO^N,5E>(H4<34P/#N&BZ]>>.Q^:_7
M/:5:M7'2]O4C2B]:M"$ZD_9-2<>1^ZE?7[5O_$&IZ=X<N+J"YDU!K6Q-S8Z5
M%+;PSZ@MGIYN;>PMFEBV1R7\Y^RQSR/)L=QLC)6OQF_;O^*'QCD^!&H>(O%&
MJZ!\"M.TA;N<>'HKJW^(']EZDNC7UI;^,O%6JV\-F]Y;VE]K%KI:>$M'9KC5
MM4CL;70+N77K[3["\_3_`%G7I;;1RL4BM/<RFV;#R,(5FADN+J\!=@3;H<O(
MZJ)-[Y,#N7E?\!_CU\=_!WQZ_;:M_@78?;_$^C_LUZ._Q`\>WCO8+\/_``_X
MP\.:GJMY;_\`"0SVMU<7.I^,?AS]F?QWH5C?VM[X=\->(](\$>)3INI^([&*
MZTO]"\+\MS3C#BW*LFPLY5XTZU+$UL55;JO"87"OVE2492NZ46TH:.*>BU/R
M+Q!EE_"?`^?9]FB4)0P]>E@L%1M36-QN+:HPISI)159)U74Y9*27*VE<P_`?
M[-G[9'B?P/X,\2Z9=?LNQZ;XA\*>'=<T^/XFV/C;P3\28['5M(L[^T3X@^#+
M>]>#PEXX2"XC7Q9X8@=X=!UX7^E1,R6BDE?F#\4?^"C7[2,?Q,^(L?@CQ3K1
M\&)XZ\7)X1-Q=R33GPPOB#4%T#SYI)YI)9O[*%IYDCS2N[[F:1R2Q*_T7CE.
M#C&,>;$MQ2C=.=G9)76NSNK>I_G8\PPTI.3P4+MW=\/&]VXO7W?-7^?9'PYI
MFJZII'_!6GP3J6DZE?Z7J,GC35[:34-.O+BRO9+>7X0:'%+`]U;213O#)'/-
M')$TA1TFE1E*R.#[#X2TW3D^-O\`P5&^&R:?9)\.KGX:?%34;GP"MK`O@JXU
M#P]JWA_Q-H%]/X5$8T*6\T/Q)))X@T>YDL&GTS6W?5K)X+]FN"45^29-_P`D
MME?_`&*J'_I,3]CS_P#Y*_B+_LHL7_Z<1^@G_!O=K.L:G^SOKL6I:KJ6H166
MJ10V<5]?75W':1&X\3H8K9)Y9%@C*(BE(@BE552,*`/ZBK+FWM2>23:`D\DC
M+\$GJ/8\445_#OB%_P`E#Q9_V,\+_P"ES/\`1G@+_DWW"'_8`_\`TQ2/%_VS
M]0O]&_91_:6UG1[Z\TK6+'X'_$%K+5=-N9K'4K-AX>OG#6M]:O%=6[!U5P89
M4(95;.0"/Y8?V!42/X._MTW$:+'.WC_Q!:M.BA9FMI?AS\(7EMS(H#F"5YYG
MDA+>6[32LRDR.245^S_10_Y*+$_]@M;_`-+/Y<^E=_R2^'_[",M_*H<]X4TW
M3I_"_AN::PLIIIM`T>6666U@DDEDDTZV>2221XRSN[$L[L2S,2Q)))HHHK^X
M9;OU?YG\:P^"/^&/Y(__V0``````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O879A=&%R<R]G<F5M;&EN+FIP9P``````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`V,S0@,3`U,34T,S0Q-3`@,#(T-#(R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/_8
M_^``$$I&248``0$```$``0``_]L`0P`!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!_]L`
M0P$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!_\``$0@`,@`R`P$B``(1`0,1`?_$`!\`
M``$%`0$!`0$!```````````!`@,$!08'"`D*"__$`+40``(!`P,"!`,%!00$
M```!?0$"`P`$$042(3%!!A-180<B<10R@9&A""-"L<$54M'P)#-B<H()"A87
M&!D:)28G*"DJ-#4V-S@Y.D-$149'2$E*4U155E=865IC9&5F9VAI:G-T=79W
M>'EZ@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"P\3%QL?(
MR<K2T]35UM?8V=KAXN/DY>;GZ.GJ\?+S]/7V]_CY^O_$`!\!``,!`0$!`0$!
M`0$````````!`@,$!08'"`D*"__$`+41``(!`@0$`P0'!00$``$"=P`!`@,1
M!`4A,08205$'87$3(C*!"!1"D:&QP0DC,U+P%6)RT0H6)#3A)?$7&!D:)B<H
M*2HU-C<X.3I#1$5&1TA)2E-455976%E:8V1E9F=H:6IS='5V=WAY>H*#A(6&
MAXB)BI*3E)66EYB9FJ*CI*6FIZBIJK*SM+6VM[BYNL+#Q,7&Q\C)RM+3U-76
MU]C9VN+CY.7FY^CIZO+S]/7V]_CY^O_:``P#`0`"$0,1`#\`_G<^)G[*>K>"
M?"NI>)=&UA=?BTF]OKF]M1;-!=P>&D56M+YB9?(DN;',TFN,HBMH[%$O+=8Q
M:W:7'R8UI<PN5GM9H<37-JYGAGC6.XM57[7&X"AQ-9++'+<189X0T9FC*N%;
MKK;XB>++-'2TUG5;8->ZC>IY6N^(E6-]3M6M;F(P_P!L&WN8W3RC+)>PW5U>
MK;06NI7%[8*]H_NWPZ^"/BOQRVF7TFC3V?AC4/$^AZM+XOTV_P!%LXX['3K6
M\MO$%C8Z)+=217[QZF\,&AZK;::^B6:VNJS:79W&G:A%I]?U1BJ&'XKSK"X3
M@SAK,,NJ5\.W6RQXC$9S2IRIU(47C5C*-"=?"X9U,1A:5:6)P_U:A*7MZF(H
MT95'2_7\=D7#'BUQ7E^"\'>!>(.'Z\L/2CF.0>TQ7$F"A&G.G!YHL?3HNIEV
M'E.I'"8B>9NE@(UYX6O5QV%AB*\</V_P^_9YT?XC^"EUW^PI?`^I/&$L+E]5
MD\0Z%XHCW><;IM/G5=4T6S$]M;+!<:1XEN9I;:YO8C>7*EHE^6_B%\-O$'PU
MU4Z-XA6);Q-OSQ9%K>12&0P7^D32;&U+2YUC=#<B*"ZLKR*:SU2PL)39F\_2
MJU\::9X0T:/2?A]X7D&BVXDDN_&GC[4KOP7X6:]E6$27^H>(?$-G-K/B*_9O
M,^V?9;":0+82VD=Q#';(EOYW\9+*'XB?"O4O$^J-X1?6]$UBTTWPOJ?AQM3U
M!M7&J266GW'AQEUC2+&6*YO+J_#VTD2ZA;6ES;VNI[[*6SN)H/T?B#@OAJOP
MU0EE.-I2XORC**F8YK6P=.<,DSS"Y?1]KCY86JL%@,!5AAX5HK!YEEM%_671
MAA,?6QV,E[6/].>)O@+X=YAX?_\`&+3P]#Q'X4X=>:YGF&7898+(.(Z&68.>
M(S2$98;+<LR3$RC0P]6&"S+*<+1IU,93I8?-*]7&XV56?YLD$!2<?,,C#*3C
M<5^8`DJ<J?E8!MN&QM92>E\+Z6+_`%&*XFNS8V6G2)?7]S')/;W<%C;L&GN-
M.G2&2+^T4G:SL]-A9O-GU?4=+A2"6*2=X>XT_P"%FO:WKNC>%M#AU/Q!)-IB
MZY.+!"-/_P!.N1;"6UO6673[#3YHH+..;Q'?R"PG\B5K$:E)!86-_P!#\9-(
M_P"%=SV?@"TFMY9K&SLW\0W5K:1R:=?ZM=V,UZ=.MS>![FSL_#NG:S8/IENQ
MN9[R[U6Y\3WT\&N7'F-^-0P&->"JYG5P=6GEM'$T\&\56IRAA\3CZOM*E'+:
M,IP:K8B>&H5\3BH4XR^IX6E4E7<*DZ,*G\9X?@+.\HR_,^*\_P`JKT.'N'\;
M@<!.K57-A<WS_%T_K&%R'"8B/[G%_NZ5?$9K4P]5TL)@,/62KRQ=?+Z.,Z2V
M_:7UK1K>#2++P-\-([+2H8M-M(YO#5SJDJ6MBBVMNDNIV_BFWM]1D6*)%>_@
MMX(;M@;B*&))%12OERBO>I\;<64X0IPSO$0A3C&$(4\/@H0A&"C&,806%:C"
M*BE&*;Y5I<]J'CWXK4H0IT^*\73ITXQA3A"E0IPA""480A3ITX4X1C&*480C
M&$4E&,8Q22559F"J"S,0JJH)9F)P``.22>`!R3P*^X?@!\,M1TNQUOQY\0=`
M@F\.:_\`#_7K3P+=?\+-U+X6Z[X:\<WVDPW/@CXGZ,^E:5JVDZZ-%N].A.K>
M'/&=K9V/C'0[[5_],T^[FTOQ;8_)G@*+P]<>+-%@\4K<MH4E[;F_%E:7-]>M
M#!-'=-!:6MMO:6>^6!M/`DM[N)8[MV,*.J7-O]`'XN^'_&_QZ^'>I?$DZV_P
MC\/>*=)34?"W@LR)J5GX7CO574M/\./I]Y!'J'B:^TV..U2_BN+:PFU-ULK6
MX.@V]M=S?.UX\/4LBSK'9[0SK,JU##5/[+R?AK,Z^4YU7K8>G]=K8VGF."J4
M\=@U0]E1HY?3P]7#SS/,:L</*O3PU#%-Y>'O^HN297C>*N+\7FV,S&.987*N
M&^&^'LVAE6/G77LJV8Y]FN-5*M4P66Y9AJ]-9?3C&-7-<RJ>RI5*6'P6.K4_
MNOPO%\(M:^#9T[7M"NOBE\9--^+_`(=\;:;^T%J/Q7L+WP9X!^#ECX-GC\4_
M#J;P%I%VWAJZ\4W?C&VNY[GQ'/H,R:AX<U&VD;Q+I$_A6WT^_P#)91JWCQM?
MOO&WB"YT/07F@O?AG>7-O#HVAZC;7$VHZ!INI7.GR_:=0T[4)-2\2^%-8LY]
M1N4O;OPCXC\&:M9V\$6MK?R?6GP)^,'_``2F^''C+X:Z_P#'S2?CE\2-*TO6
M=)\7^,?!'B.QM-=^'OC;0I/V4+K2-1ME\%>']5BT'6?$$G[36@1:AHUIX@N+
M;P^FD^,-(M9/%LGACP)J=_XJ^!/CO^VAKW[2B>%O",_@#PEX1\'?#[X46O@S
M08K!;R^\1:X?A[\(_AQX'TOQ1XUU6ZG^P:QKFH>'O@1\-X[^SL=(TO0X;G0X
M)+2P783)\1P9XR9MFO'>+X?X;\+?$BCP5GF8XWC/CWB?Q3XCS)8+,LTSS+<R
MR7AWA?A#!U<TQN)IY1D-7(,JS#'9=A9U<-D57,:4\/SO'5Z=7][H>/&18+-,
MMR_),!F5;+<USK,\QXBP^=Y]F&-J\19KB\A63Y-A:\,/7KXC!Y'E^,E@L9@X
MX[,\XQ4ZU)S6(H8>C[.I],_"M(+VZ\=>(=.$2Z!>^)(/#GA=(2)K<Z#X&TJS
M\,B:SO!Q<V$^M6FMR6FTRQHN^1+F?SV*_*O[8?@06NJZ;XXM8UCMM:C6POW,
MLH3^W]-LW:.1_M%W!8V[:KX=LDM\Q1W%Y=S>&=.L[:W5YYY9/NWPZ=,31M*@
MTNRL=)M1I6GW4&CZ>EO!;Z;:WD1D@AAMK>*".*W#+/'$R6\,<C0R[$!1U7R;
MXT7_`(=\3>!_'?A*UO;34_$6D>'KGQ,VFVL3:A)8/X?D;4XA?-#9W]I8S7;Z
M=/8Q66I",ZBLLUBT,L$\RG^_.-.&LOQGAM6RRMB\''&T8U\ZRNNO8X2EB,_<
M\7FE6A@:%7V:IQQ\\1CL###P2JTL)BIP24H-K^S?%W@#*^)_`[-.&L?C\`\T
M>&QG$F3XMKV5*MQ73J8[/ZM#*,-7G[>E3QE3$9EEN$P=)3KX3+L4Z$:4E1=-
M_D'15B[BB@N[J""8W,$-Q-%#<-"]NT\4<C)',;>7,D!E11(89"7B+;'^9317
M\9Q:E%25[22:NG%V:NKQDE*+[J233T:3/\7&FFTU9IM-/=-:-/T*]==X)T==
M8UR-'NELH[&"?5'N6F,(A73HS=LX\BX@U":15B;[+9Z5NU+4[_[)I-E+8W&H
M1:C:;L?PB\?W/A=/%UEX:U6^T3-]YU[;6P=(%TZ:"TOO,MC*-4B;3KXWUKJ4
MMSIEM86W]FW<\%]=V\4\EOQ5AJ>K:#<Q3V4UQ8744VGZE;/M:*:"ZM6CO])U
M.U+`/!=6Y=+FQO82DGD3R(LCVEW/'-M7PU>@L*\5A:]&GBZ>'Q5..)HXC#?6
M\OJSA*5;#N2HU*E&O0<O8UZ,XPFY1E3K1NIKZ*GE&*R+&Y%B^*LASC#91F,<
M)F5&&(PV*RUYOE%5TZL<3EV(KTJ:Q.%KT9PJ4Z^&GRUJ-2+HXBE[6G7C^QOA
MS01X?^'O@?PQ=?#?]F_QOHWA/Q2/&_VOXM_`W2[7QW<:;<?#2U\"2^#O%OCS
MP-XA\-ZMJ_AW3EL;+Q6-.U5[Z:#QI:#5I-8GLXI-.N>/^.GBC3/VGE^!W@^R
M^'?[._AC4?@WX63X:7VN?LR?"*]\`>'[GPK,MO)JFK_$_P`4OXLU[3/%_C61
M+:^N--L;&XTFZL]:\4^(-2ETEA=S32?F+>^//$OB.]M3XH\0:MJ]MYJ^<FL:
MKJNJ6>[S[J:WFN;6]EU(?8[.2[R]C86\`EM8/+MUAOG-[7Z*>'?B5\,/C.-,
M^&=I;:KH<7V5-5U30+)+:ST/4([#[6+[PFFIZ->(+BU%RJZG,;:"WL]6TVV_
M=RE;B>"/ZOAWPZ\#>(N*Z.9Y?P1A>'<_RZHZF1?7>*>(I2S;,\^GC,!F4<OP
MJQW]@916Q4<?B*6/J3P&:U98;,8SR_+GB\-AY83^V/#JOX!>)>=8S`Y%P7D_
M".:4:F5X?*,JXCXAS2OB^+\96JU%'#Y4I8JIEN0SIRPF&CB,5+"9_B*,,;-Y
M7E;QU.AB(>E_$?P]:>-_#DT^AZ?H7B74+5VB*^1H.HSW=L+>=I-(@O-1:."`
MR7$]I<R0'5-)26-&CFO$@GEBG\;@\,>*_"7@[QSKNMZ79>'["Q\#>,8+C2K.
M;P_X9T:\GDTO46LY=.\+^"A<Z5)<SW)C@CU#Q-K&KZA'!=16^GV5I=M=RW7M
MT/P^LO"VO6&N?#_3]*\.0W5Q!9^+="L+5K/2=9TDXCAO+?3;6YM-*L-9T>1F
MN8M0ALOM%W:27EI<?:6>WC'RM^T;^T#;SV^N_#31M(NP$U,V6K:M<70BM=0M
M]&U"-+W3H(+8?:)+&YU6SO--U"1;VUF:+3[JR,12_>2W_H7CFCDN54LPXFXC
M^M99GCHXG+\#@,MQBKY7Q)B'@:CP511J8*&(3A&?LL7*K+"2P,Z5=0JU:-:G
MB,9_2OBSF/#G!V4YQQ_QQ6K\/<3X?+\=E&18'+,4LPR3B3-7@J^*RB>%4\HI
MX^JU6=*&.CCHX2AEV)H5Y?O</4H8['?"%];RVE]>6DZ".>UNKBWFC5D94E@F
M>*1`T2I&P5U*AHT5"!E%5<`%5:*_DF*:C%2:<DDFTG%-I:M1;DTF]4G*32TN
M]S_'&4G*4I/1RDY-+:[=S]L_AC96>G^!]#L["TMK&TA_M/RK6S@BMK>+S-8U
M"63RX(42)-\KO(^U1ND=G;+,2?RA^,]O!:?$?QG9VL,5M:67BSQ!:65K;QI#
M;6EJMS'<+;6L$:K%;VZSW%Q,(8E2,2SS2!=\KLQ17[OXP_\`)+>%7_8KJ_\`
MJFR@_P!"_I6_\F1\#?\`L599_P"LSDYY57TO^R>J_P#"WM(;`W"TU=0V!N"M
MHFJ%@#U`8JI('!*J3T%%%?D_"G_)6\(_]E9PQ_ZO<O/Y,\!O^3S>&7_999)_
MZF4S]6:_#;QK++)XM\2I))(Z0>(==BA5W9EAB.L7TQCB5B1'&9II92B`*999
M)"-[L245^]?2'_W?A'_L,S?_`-1<(?VI]/?_`)$?AQ_V-.(__47*#F****_F
M<_S1/__9````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]A=F%T87)S+V=O<&AE<BYG:68`````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C,T-"`Q,#4Q-30S-#$U,"`P,C0R,S4`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA(``@`/<`
M````````,P``9@``F0``S```_P`S```S,P`S9@`SF0`SS``S_P!F``!F,P!F
M9@!FF0!FS`!F_P"9``"9,P"99@"9F0"9S`"9_P#,``#,,P#,9@#,F0#,S`#,
M_P#_``#_,P#_9@#_F0#_S`#__S,``#,`,S,`9C,`F3,`S#,`_S,S`#,S,S,S
M9C,SF3,SS#,S_S-F`#-F,S-F9C-FF3-FS#-F_S.9`#.9,S.99C.9F3.9S#.9
M_S/,`#/,,S/,9C/,F3/,S#/,_S/_`#/_,S/_9C/_F3/_S#/__V8``&8`,V8`
M9F8`F68`S&8`_V8S`&8S,V8S9F8SF68SS&8S_V9F`&9F,V9F9F9FF69FS&9F
M_V:9`&:9,V:99F:9F6:9S&:9_V;,`&;,,V;,9F;,F6;,S&;,_V;_`&;_,V;_
M9F;_F6;_S&;__YD``)D`,YD`9ID`F9D`S)D`_YDS`)DS,YDS9IDSF9DSS)DS
M_YEF`)EF,YEF9IEFF9EFS)EF_YF9`)F9,YF99IF9F9F9S)F9_YG,`)G,,YG,
M9IG,F9G,S)G,_YG_`)G_,YG_9IG_F9G_S)G__\P``,P`,\P`9LP`F<P`S,P`
M_\PS`,PS,\PS9LPSF<PSS,PS_\QF`,QF,\QF9LQFF<QFS,QF_\R9`,R9,\R9
M9LR9F<R9S,R9_\S,`,S,,\S,9LS,F<S,S,S,_\S_`,S_,\S_9LS_F<S_S,S_
M__\``/\`,_\`9O\`F?\`S/\`__\S`/\S,_\S9O\SF?\SS/\S__]F`/]F,_]F
M9O]FF?]FS/]F__^9`/^9,_^99O^9F?^9S/^9___,`/_,,__,9O_,F?_,S/_,
M____`/__,___9O__F?__S/____B_)```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"'Y!`$``-@`+``````@`"````C^`+$)'$BP(```2$@47,BPH4`D!Y$X
MG-B0!(F#%BEJQ$9"11X]@$#J4:%PX\*.>O(X40%HA1-`(4F:'$A"3\H2`*J0
MJ@*`Q,N0)2EBS)-GQ0H``9Q4N0A`A4=2>H(Z/(AT12!6@:P$`&"5%2LK'O-0
M97B1!-&+@:Q=L_85P-5KU]I2!7#R+"!215G!A6;%RHJOT-8&ZID2(T&S5520
MPOL7;MQ`?P/'M6)VL8HJ40]77FQ5+=:C:06OR+,8+\O,#UF6+GK5JA6N5R&3
M+DW*HQZZ`FO2WND4@%^J3IWLAGH9]V;:*IPXF7O0B<KA>(.2&/Z<U'*JPJW/
MI@VHY/'5M%7".J<]?K?WN^&A#[=8?K%WZNIWMU_</3?Z^-")4O>^'7_X_JM)
M!U]^\Y56'TVSM717?X#D81&``19D5DNL/+&@<BM=E-U^9%7Q5X5Z+$9:2M7M
MYJ!#:,5EH8@8[M9@1A/!%M<*]^VFQU$':5257I"%2-N-*[QV%$4DK!``"U8M
M599%L'FU`@L!3$0""U!268(3HSCA4Q5:6N$DE2Q(=1B850:05):CY)$E"0$\
M2::8')%9)90&F(FEFDX<2:6>80X4$```.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V%V871A<G,O:W)Y
M=&]N+FIP9P``````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,3,V(#$P-3$U
M-#,T,34P(#`R-#,Q,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_V/_@`!!*1DE&``$!```!``$``/_;`$,``0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`?_;`$,!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!
M`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`0$!`?_``!$(`#(`,@,!
M(@`"$0$#$0'_Q``?```!!0$!`0$!`0```````````0(#!`4&!P@)"@O_Q`"U
M$``"`0,#`@0#!04$!````7T!`@,`!!$%$B$Q008346$'(G$4,H&1H0@C0K'!
M%5+1\"0S8G*""0H6%Q@9&B4F)R@I*C0U-C<X.3I#1$5&1TA)2E-455976%E:
M8V1E9F=H:6IS='5V=WAY>H.$A8:'B(F*DI.4E9:7F)F:HJ.DI::GJ*FJLK.T
MM;:WN+FZPL/$Q<;'R,G*TM/4U=;7V-G:X>+CY.7FY^CIZO'R\_3U]O?X^?K_
MQ``?`0`#`0$!`0$!`0$!`````````0(#!`4&!P@)"@O_Q`"U$0`"`0($!`,$
M!P4$!``!`G<``0(#$00%(3$&$D%1!V%Q$R(R@0@40I&AL<$)(S-2\!5B<M$*
M%B0TX27Q%Q@9&B8G*"DJ-38W.#DZ0T1%1D=(24I35%565UA96F-D969G:&EJ
M<W1U=G=X>7J"@X2%AH>(B8J2DY25EI>8F9JBHZ2EIJ>HJ:JRL[2UMK>XN;K"
MP\3%QL?(R<K2T]35UM?8V=KBX^3EYN?HZ>KR\_3U]O?X^?K_V@`,`P$``A$#
M$0`_`/X1;AHDO5,ZL\*S,TBJ^PE`[%BKX*[E'S!,AI"`BD%@1^]G_!+K_@D/
M\>_^"E.BWWB;PGKOA_X8?`7PEK8\.^./C-XELI]7:3Q)#86FH+X1\'^#+6ZC
MU#5=7E@GC>6ZNYA;Z>\IO)DEM+62TD_"SP^MO+KNG?;()KP27+16UG;#?-->
MSAX+8&-"'"R74MK$F0%DE8(N\AEK_6-_X)?_`+)VA?L4_L4_!'X(6NG06OB:
M#1%\>?$_4(K5(7UGXC^.H8]8UB74<@F:\T.P&BZ7!*-H@4D0K&SRE_Z0XMXN
MK\+9'CJF!Q%-8[,*LJ&'HM^\E1IT9SJR5TU&2FHP:YGS0D[)73^<RK)*.>9C
M@<+B\/*IA,)'ZS6J.*=+WFX>S4K-\\7!-KW5:2U=M/GC]E7_`((@_L#?LM:5
MI]J_@'5?CUXOMA;75]XM^,\L>L6\^IQ;6DEL_!-FUGX7TRR23=):1:EH]V^]
M8L-]H6.1/T8USX'_``7O-&F\/Q?!SX:?V)+$?,T5?AGH$.EGRU#1JD5OID-F
MBHZ(R`1A-R*0N[!KV'6-52%)'-VP(B=C(Y$TC/&I>%6:7S'=3*$`5B5!(P*_
M/;]HSXL>.UUZ_LM*\5:II&FP0V]O%IEC-'"KR&W,LS,\<:S_`#!2^/,(7&$"
MC@?S/G7B!G,:DZ^:X[&8RLU&RC6DJ<(2C&:IQ]Y>[%MO9/5O2Q^W</<(X2=>
MG@,LP.74()<WMI4N:=Y/NZ;L[):7U>SZGR7^UE_P37^&OCKP5KU_\(_&$W[,
M?C"WT^\-CJMHUK??#V"\F/E_:-8\%373VHT]XGEAGEM+6..P$HU"YAN;>UE@
MD_@U_P""E?[)6O\`P#^,VK7RQ^%[ZTO=.T2^U:Y\'ZJ-=\-75Y<6L=M>^(]-
MO,0SKIFKZE!)+<),K+ITU]Y4;Q011+%_;#XUUO4;^W4:Y?WFLQ7SO'/;ZC>7
M%S&(V)\X3":0AT*%LJX9>>!D5_.__P`%+=(TF?QU\!?%]S;Z;>Z0;_Q?X,\3
MZ#?M(MAK'A2Q-KK]]I-Z89(Y#;R6T=XMH`ZB-Y(X%86I:&NC@[C&KQ%FM'(:
MF'3IX_F5.=2<IR53E2;G=MQBTHVLGK=I'H\><'U<HX?K9L\4ZE3+ZE-RC1A&
M,>2;C%1BDE?EE=MNWNM/5Z'X/^'_`-L?]J_PQH.B>&_#GQG^(FE>'O#VD:;H
M>A:797LBV>FZ-I-E#8:786BK:,HMK.QMX+>`!F`BC0`D<T5Z=J_P+^$<FK:G
M)IOQ,\0Z?ITFHWKV%A!]GD@L;)KF5K6SAD)8O%;0&.&-RQ+(@8DYS17Z3+PR
MQ/,_W/5ZWGW7]S^K+R/RF/$6,M&V*@E:-DZDKVM'_+^KZ?//PKU&WT3XE_#?
M6K^!Y[32OB!X-U6^@4(WGV.E>)-,O+BS<G<J)>$1AY9AY,/E*?WDC+$_^JK\
M%OVS=0^*'B^Y^''C_P"%/B/X,_$+3=)U34M/@\07D<OA7Q_I7ARV\-IXSUWX
M>ZM]IDGU_1_"3ZAHL>HR-IJW"27<ZK.8K=0G^6-\.?A-\3/''@OXK_$_PEX5
MO]4\%_`KP_X:\7?$?Q6EM.=)\+Z?XH\?>%OAMX8M+J_V?8!J.O\`C3QCH$>G
MV)F%^\.F7U_;Q"WLKJ5?]4CX76GPA^,/@KPY^T'%IMOJ?C6'X+:1X/TS4)[&
MUO-3\/R^(O"?A>W\4IHMU/'//:6FMZI96ESK"6BI%<?9R\R[=^?&\99X9QRC
M&4,5%XB&(S##2BIJ5)>SPF&J1C*UU&IS5973UVNE9'T?AYR1>9X;&X>I*@Z.
M#K1E"DY3:Q%>=/FA>RY/W3N[VT?Q-V.5U7_@I#^Q==ZQ<>'W_:#\!:7K&GZE
M;:9>Z;XB_MGP]%+<R2OC['=ZE;$7"DVLJ*\9$4C85<%EKYK^*WQ*\.^)_$>K
M>)/"VK:?XKTJ^F,EG?Z3J<%U8L3`\44D<HACC$81^=XPRYQER"+WQ>_X)7_L
MN?&#3=25?#FCZ9XS\4Z5X7TVZN]5U>;3M5L;;P]?P:[!<^#YW2Y-M=37=L\>
MHW,,`N;K3I[RSGG:"0JOF<W[*7P=_92TJ/PGI?Q(\6>+;Z2R>;7_`(?036>L
MV&F0PQ-)!>7?B'4KIM0L?/F2*-8;6-49F6*.*$N)%_FK-)8S$X53K2@YRC&3
MG&3<;*,59MJ]TEKIY7/Z$R*CE=+,7+`JIR2A%1A4IN-2Z2BW_(E)QTM/JMMC
MQ/4?[6\3K=6MM'NE*3_:Y$_=64"!7=2U^X$,9+*%/E$/(3Y2$.ZU^'/_``57
M^'%SI'AK2M1L?$^G:I)\*?&WA[_A/[.UM;F#^R[?XB6-M8Z6D5S?%[>9Y;AH
MDN@00UKY^!S7[3:E\2X_&6H:%H4<-IX6\(Z9K5HBZ'IJ7#3WUO#=QO.=2N\2
MW=V?+C:0>;+*L3JKH(R@9?PM_P""IOQ&:WB\7_#_`%N^CM-=_:)^+&E^-9]+
MO+F.2+0_AM\(;9]$\/1+$;575_$>JW5O-&?,2X5`\R2$1*![?A/+$U.,,J6$
M3K5H8BFGRQDX12E%R;=E9:VZW7E<\SQ-JK"\*9U#'3ITJ.(H+V,)23JRG%Z2
M4;N-GHE:5[]-K_E;'K_A&"-(4\-Z-*D*+$LOV\#S%C4(KX$@`W@!L`8&>.**
MXB+7K"TBBM!X8TQA;1I;AA;1ON$*B,'>X+/D+G<Q+-G+$DDT5_I`L3B;)/"J
M^E]*>_NWZ^;^_P"[^&^>;LTZMM+:>EOT_#MKYU\(/VH_BM\*_@U^TO\`LZ>'
M]2CC^&O[5GAWP-H'Q)T"8(H74?AG\3_"OQ1\(Z_;*8S)%>Z=J_A&32I`6CV:
M?K5ZV5E,'F?VO_L/?&B;]I/]BOX">&/!EKXYT+7KKX?Q:;XFU[P9X_T3PMXA
MA\1^"KW^Q]<T:QTK6=;M[B^L_$2:;%?R7EG''?VUM<O%:3PVI:%OXOOCW\([
MC3M8^('CCPYIT&G6?P]\;/X5\=:5]JB:XTO59M6O=(T34].M)#YUSIFLBSB6
MZE,1@M[UH(P[233)']X?\$WO^"@/@K]GVUC^&WQY6RN_AM<:A>ZGX?\`$%UX
M:MO%-]X<U#4);:6_TR]C6%=5MK.^N=/LME[:WD4FD,[7]LT<<4Z2_P`I<;Y%
M4S/P_P`9/!4JF(QN$SG^W8U)M^UJ9;B\+@L/*-"[;G)SPU65FU!K:;V7[]X?
MYW1R[B*K3S/%1PU">`GESBH4YTEBZ->K.E[1R:MR2J-.R<DDO=Z+^MI/#7BO
MP3<Z?"WBCXO2^)`D-E#X=^(=SK=W-HZQ2K);RZ?J=_>ZI#?^9*B&21;ID:$N
MI+1,4;RSXI_$K[%YT[O=+J.N:=:W6MI?+`)8[F*.XM9XA.$$UQ"]^MO?)#,[
MQ1&$>3&BY4^5:9_P4#^#USX/FO?A3\3_``=>VFL+-#+#KGC[6/'%KI%I)`PB
M70[35I+B\TV_#E%M[.XNIUAN"B(`1BOD+4_B/8^-K^.\MSXVUS2+;Y;Z\?3)
M+34+B"(R27*V"S[;,!8'G:U>6-(Y7V">=%S+'_)=5XNE)T7]<;I2<)T*D+.[
M:DE;F?V)1COOS>I_5.7JE62KP]C4HO#QDJ])4XQ:48\SYKIWNG+;9KT.M\0Z
M]J_B73M1&D:UJ>APQ02V[:QIDCVEVMY,?*C:SG@\MXF,CHC^2R*T32+(&0NI
M_FV_:9U?QUX?\56.I_%G5KSQ)I_Q(M=:\1^`=4U;7Y->\1:)X'\/>._$_@S2
M;>:WFFFDMS>3>'+B^ACN#YEU'=K=3F<V\3Q_IU^V9^W'X;^&'AJ'X7?`PVGB
M;QAK,<ZPO'C4XO"$=PNRY?5;BT5_[2\4Q6WVG[3I,/GZ?IB;]06Y=K0(WXK_
M``L^(N_Q7=^%?&_AZP\=:;XW?PWX>U.;6;<ZEXAT'0M)UE[VYMO!][<^9=:+
M'-+/>R:@UK<6LLUI)=2R,]RJ2K^[^#5#'Y;CY9@Z-+#2Q#]AA858-OVUH2]K
M)V;47S*-XMOW79=OYT\8\URW,J<,NP^(J5XX>?ML7[.I>"C=ITDW+F]I%PY^
M5I1LTF]6UOP?$#X;&"$G4+X$Q1Y$MKB0'8,B0*H4/G[^!C=G'%%<GJWA[]G/
M3]5U.PL_$?CN^M++4+VTM;TZ?"AO+:VN988+HHBJJ&XB192J@*I?````HK^E
MGC>)KN];+-]?]HQ"[7_YA_7[_N_$8XG*THI9?C'HDG[!:Z1L_BZZ/[O*_P!N
M_MF(EOJ'[8H@18!+\2XUE$*B/S5@\7^"YH%DV!=ZPS32S1!LB.6621`'=B?R
M?OF9;)RK,"[0[R"07S!D[B.6R22<YR22>M%%?)XS_D0T_P#LE<L_]/8PZZ__
M`"-<=_V-\;_Z>B>N?!+7-:L?%OAZWLM7U2S@76;!U@M=0N[>%7:Z&YQ'%,B!
MCW8+D]S7[6_&?X@>/(]+\+V$?C;Q='8ZAJGAK3[^R3Q)K*VE]87NK:=:7MC>
M6RWHAN;.[M99;:ZMID>&XMY9(94>-V4E%?S7F/\`R,*W_7Z/_I%,_I7AK_DG
MX_\`7N7_`*;B?'?Q/TS3=,\'?';5=-T^QT_5-'U/2=-TG4K&T@M+_2].FUK2
M8IK#3KRWCCN+&RECEECDM;:2*!TDD1HRKL#^>.CN\6G^*=1B=H]0@\/Z=+#?
M1L4O(99O$&G132172D3QR2Q.\4KHX:2-V1R58@E%?JW"'^\99_V$/_TBF?S]
MG_\`'S+_`!_^WH](TR&%]-T]WBB9WL;1F9HU9F9H(RS,Q!)8DDDDDDDD\T44
M5^VO?YK\X'YR]_FOS@?_V0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;@``````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#8@,#(R
M-C`V`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$T-R`P,C0U,#0`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4`````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30W(#`R,S,R-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?;&5F
M="YP;F<`````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W,3<@,3`U,34T,S0Q
M-#<@,#(T-3,V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````+````(0@#````.$6A1`````1G
M04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```
M.I@``!=ODE_%1@```P!03%1%````________````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````2,JW!P````-T4DY3__\`U\H-00````EP
M2%ES```+$P``"Q,!`)J<&````"I)1$%4*,]C8$(`!KQL(D@&PFP&PFP&*,##
M9B""38PY1+F'*'\11^(/9P"':P'YV0*8P@````!)14Y$KD)@@@``````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&5F
M="YP;F<`````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W,3$@,3`U
M,34T,S0Q-#<@,#(S,S4V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````+````"P@#````GG*'
M%`````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P
M``#J8```.I@``!=ODE_%1@```P!03%1%````________````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````2,JW!P````-T4DY3__\`U\H-
M00````EP2%ES```+$P``"Q,!`)J<&````"1)1$%4&--C8$(`!G22`<%F0+`9
MH`#(9D!B(XNCJ$<Q!Y6$```KU`"I-7*!O@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO9&]W;BYP;F<`````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W
M,#8@,3`U,34T,S0Q-#<@,#(S,S<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````+````"P@#
M````GG*'%`````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y_P``
M@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````________````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````2,JW!P````-T4DY3
M__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&````"%)1$%4&--C8$(`!C#!
MP$`\FP$&0.(P)E@-E(FI%X6$```KU`"IO5B2_0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO;&%R9V5?<FEG:'0N<&YG````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$W,3<@,3`U,34T,S0Q-#<@,#(T-S(Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````+
M````(0@#````.$6A1`````1G04U!``"QCGS[49,````@8TA230``>B4``("#
M``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````________
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````2,JW!P``
M``-T4DY3__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&````"I)1$%4*,]C
M8$(`!KQLHD@&8M@,>-D,4$`,FX$(-CYSB'$/T?XB@L0?S@"':P'YG8N(?0``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O8FQO8VLO=7`N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$W,3$@,3`U,34T,S0Q-#<@,#(S,#4P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````+````"P@#````GG*'%`````1G04U!``"QCGS[49,````@8TA230``
M>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````
M________````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M2,JW!P````-T4DY3__\`U\H-00````EP2%ES```+$P``"Q,!`)J<&````"1)
M1$%4&%=C8$(`!G22@0%"09A@#@.4">(PP)A`#KIZHMA0```KU`"IMT+A00``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?=7`N<&YG````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$W,3<@,3`U,34T,S0Q-#<@,#(T,C,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````A````"P@#````Q@T4#0````1G04U!``"QCGS[49,````@
M8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!0
M3%1%````________````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````2,JW!P````-T4DY3__\`U\H-00````EP2%ES```+$P``"Q,!`)J<
M&````"I)1$%4*,]C8"($&-#Y#`SX5##``'85#*@`704#-H!0P8`;D.@.NJG`
M"@!QK0'Y++X%@`````!)14Y$KD)@@@``````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;&%R9V5?9&]W;BYP;F<`````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W,C4@,3`U,34T,S0Q-#<@,#(T-34R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````A````"P@#````Q@T4#0````1G04U!``"QCGS[
M49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%
M1@```P!03%1%````________````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````2,JW!P````-T4DY3__\`U\H-00````EP2%ES```+$P``
M"Q,!`)J<&````#!)1$%4*,]C9&(@`!B15?R#,9@&1,4_W,YD@IOQ#X<TBBW_
ML$F3[E*((B8\(885``#A*`DB7CTB*0````!)14Y$KD)@@@``````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<FEG:'0N<&YG````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W,3`@,3`U,34T,S0Q-#<@
M,#(S-30P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````+````"P@#````GG*'%`````1G04U!
M``"QCGS[49,````@8TA230``>B4``("#``#Y_P``@.D``'4P``#J8```.I@`
M`!=ODE_%1@```P!03%1%````________````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````2,JW!P````-T4DY3__\`U\H-00````EP2%ES
M```+$P``"Q,!`)J<&````"-)1$%4&--C8$(`!DR2`9G-`&8S0`$RFP%-'%D]
MACE()`0``"O4`*F,=,D2`````$E%3D2N0F""````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO<W5N<FES
M92]S=6YR:7-E+G!N9P``````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,S8@,3`U,34T
M,S0Q-#<@,#(U-C$P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````<````#0@#````C5G^F```
M`&!03%1%[+"=_8]U7%0D__GX\,,*_UDT_W-/__0H_,:W_>/:_^$6GY*`_SH6
MD'Y!_^[KOI!Y__\S____````````````````````````````````````````
M````````````````FTQKGP````EP2%ES````2````$@`1LEK/@```*1)1$%4
M&--]D%$2PR`(!4$$,5$,][]L,4D;.YWI^T*7513\3V"ID>\]I@7>M39S5">&
MQ50)2NK6U%D=6EV@,<<R^@6=C1HZT7.L<32K.`P;(=KTGX%,PAU[3Y$^7-C<
MJWZF18:4\[9MN:<=*=J;7!"D^IX"E3)Q`L?6@"Y8$<,+5(Z)<QH-[;P3U,BI
M]_".F1*PQ]-L0F%FQ/1FQZDJLM#7]_WD!6(/$3L-?YH$`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W-U;G)I<V4O<W5N<V5T+G!N
M9P```````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-3,P(#$P-3$U-#,T,30W(#`R-30S
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````'@````\(`P```,1DCZX```!@4$Q41?[MZOE6
M&?]A1_]Z)/^#;O\\&VXX(/W-Q?ZTI]6TJ8MC2\4\#+JBF*F+?OR6@M*2@O^9
M,____P``````````````````````````````````````````````````````
M``HRJO\````)<$A9<P```$@```!(`$;):SX```">241!5!C3E9!9#L,@#$1M
MUPN0`O7]+UM#%C5M%2GS`98>,P.`7PINX$;KGN@O-@ED[I1.V'BN#F).YDG@
MA`$)IH>:QX3MJQLP#-&8._1IWN.W&*!P]5I4M=3L/-(@?5R-*>LB&%KT&>G`
M0CM.#%X5\3&$J#D:I!WAQIQUP%<H#I0N#%MWLE%4<+*5+W5SC@>)$+=RT.!8
MK!'=_/-?O0&,`!;R[ATVXP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-R`P,C4R-C4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(``````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30W
M(#`R-3(V-0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\T-RYP;F<`````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-C8@,3`U,34T,S0Q-#<@,#(V,S$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````@````
M(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D
M;V)E($EM86=E4F5A9'EQR64\```#R$E$0518A9V7NVM4012'M_%/L1+S)_CH
M+2RL@]A866@G0AIM%"2-E4;L1$$(P4*4B`$+BXB*B((015RPD+44P<>XWVR^
M\=S9N3>LQ=FY\SBOWYS'["BE-(+^_/Z1&//DQLVU].'3.&W<N3+;O7MO(YTY
M=SX]?7QKMK!R\7(Z=.1H^C;Y.EN8DP'_H\TGZ>7V>AKQ@8SKJV=G,HX=/Y'Y
MEY8._F.1/NYLI7=O'B9'Y)9-1&V_>)W%(0HJ=B(6TZ#EDZ<3<R3\^OYJ=N#J
MZK6\>6KY0-)<J6,#F]+\@9_C-/[\K!B)^'(`#HQ\^WXG@X@Z0("IV,`F!*AL
MXD4Q$@X.X2(`X1[JR@%<XXYTDP,%*+DB@4.Y'=!;VWJ>+^/^@_W9AEX<.G<[
M]0`;)E\V"S&'VCA5>(&5A,=X+HE`Y[*]<.$"3T*.;YWG*HTKQH*2!%((,0B9
M,Q)_,&"-"';N0:BY"PB@(NR@B@`8#87.36,JAS@,,Z,"F2L((3!&((L%EVZO
M9W\Q&?^YLI4+AS.CL=:ZL?S#/>L[6B:3?26L#,X6<V\<M/*CSI.%`\D@8GTP
MD-CDH,DGZLX1%H4TF8U`(Y*[C]'(&D+F!,!@^8D1R6AA&0QE#LM,;#@WF!BM
M:<W"Q]6I&4:(=5R(B611+)%HW8EY(&&V"12USPD@:&"P-LF<J^XT(A$"DP!W
M7,!4DL<$@OB&65*[S!T0.4S2<!`7%"*ULK%SC2)LDXC-0J(FJ%WFC@";%L0W
MQ#ISK&..H&9S`0,.L`EXI#89*0/`MA*ID\X<D`%F"$;V&'O3V6H$(V!FS=-K
M@P`49L[\5ST8JA$9R-V4;Y'[0[5D(0/J&E/WGE@!I%8=&GPA#"EN*8UQR4BN
MQKEKEJ"6(7LJA\DB8+:1DGY#)(DY[]P:J"'V0E'1D$'E"*MK8TUUW?29:"V!
M+,96,8T8-*!6'DMDJV3F1-TM6J)4=P+(-5%H*K<B(C@:HF=ZKW+.8X#"A3[6
M[UC/.==K`+!0>GR>:`1*5!@K+^O404I6+-LJJ@-3@YI7P$(LJO9!1\FYAL(#
M`K[>Z@84N[J!V`Q"&Q+>^<Z"7*N;E<9ZSFOP\:;W7H?IV_NLL"?%!UZMT,=>
M_&^B`=&HV/PT!L][_XGH06Q)L:/&-97Z+7E6.;Z)6R^R9B4DP.@^H@#DM#8[
M-=]X:<-QSZ!DCB%XRYW3A/IZP)P!'+2(F-\8`_P:9YO4`/;,#%_(>REL&@`3
M`O0:0T3"M%.IWT:\RH$=8Q;MKL4`%=F[6<ME<ZJ,/PL^VS!.R./9H9X_1'\!
MEFXBARQ*W20`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R
M>#,R+S$N<&YG```````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0V,"`Q,#4Q-30S-#$T-R`P,C8R
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8
MU$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```3"
M241!5%C#[9?I2U1A%,;]-Z)`B+Y$U(<@(BHHVA,+6BA3L$5J3+-IT28<!L8,
M-<M)32JCG"S;Q;`@FTR=,DW3+#&)H45)HP5%#1,*.?D[P[TYN6`D?8@^O'/O
M?9?GG/<LSSD3)")!@X?YTM3T0LP)N]TN5NL>24U-]:]:=NX4B\4BSHSC@>?-
M(]FG\\1F=_HQSE\IDOS\"U)552VA8=LD:'KH6IF[*$1.Y.1(@-B1AOY\^_9=
M<G-S=20YG;(A;)-JL7+5&O^NJ]7UTMO;*\ZB<HGW5,FK=^]EW[D;OR%B?#8\
MKJV5NOIG<O9BH0S9<*>D1-C@\7C4H%%14?*\L=&O9']_OQ04%`CFQ^)8C.LN
M7KI<7K]YXX>9,6N.M+>W2_+A%"DN+M;3)D)'9[<\>=TJ^245:@=W<;GDG+DD
MXW?-/P(@+J*M\3(F`*SA\_DT3+`"%L'A-IM-XN+BU'08@``@(-*/ILN'#Q]_
M(L7L/2A>KU=Z>KZH0^+C$\3M=NNAKJXNM3_!C47QQ]9=-B'*3("0-6&2GG5*
M'"F9&KD+5JR7@NNW)#DM0[W+.H$<&9V@[^P!V`1H^=RA=PV_6ZG(A"@N"C^6
M*6UM'V7=K7NZGG3S]M!0R7[J4W6-24O-"VEI:96.[F[!-H:-(BH;%/SON?$?
M`+`><&A,_#8`!\O*RC5'`<#WGSY]EE$!.CL[)28V5L.7)Y%(N!86%FHH,\\[
M\Y&;M^@(`,#O;(1'"5OBG?AG'L;@\-5KUW2-/;!%`$!B4IHR!I)0'P`2B<1"
M(PZ1`R3;['D+-9Q-`%*6U.4@6L!'$!E7X`"@2)P8/%GWD`?DA0G`_3$<R;3=
M:M<-?$--`#-'<C'/.YE+N@=<(>9ENQ(?_$:>DSSP0ZC[BB"`Y+KGJ323*L`+
M)`K&<I76:.4@"[DOW[@RX<9=-2`N-=@T``#I;*"R4&6B&]^J5"/[D,H\W\/&
M041RJKG0T.A3"Z,5A&',0RI1=H?\@]GX7X&_J@"Q_J#RD59;LHQ6HN)AM1@5
MF+HXK@J0-)`(O``_T/Y!.#PA'ZC-$)Z9E:6\8=1/*CC,!49S<[-6/9[D&WQB
M5+<A0EG@IF0R=,A!R`@@B`H`V`VB@O'@%-:H^B@!$S#O<KG\R3V@)&NPHD%L
M[/O:US>\`K06W!)S<I"GP<<HQ0VA65S!DS7F<0?`".0=Y:$A+(>R,`E%`.L,
MKBX!PNDC,2VL"BA",1M@`*`0MT(H@KB]T4RQSNTY@R+T1$:#Q3MGM1(-E#>4
M&%)0&/@6X?1$^!;MN3'^#)XRU>R)F,?,`*(<3XH,"M!\39@4K+6#.9HPYAB<
MI?>B-`RK``/S;+M?*_RK0#"'YNUWF(#,+3N2K8`HPHU8YYLUP*<M66T*1>D%
MSB.*PP6Q(.5FQ"R@3XLXF:=!]-+W5DL)?Y$P,41/I9B_(U9OH&5HH"DTWA]4
MU,KNT^?4#7R3JE00BH71XXV:AJ[J)A6.?^DH*5,S-X9K(%+C<KTUZB(BF.)H
M*$/6W"PJ%9K*)7L3M`JUMK3I'P>"=4P\P,T!P&R8"(U)20:9D>AM4-,3="C'
M]PK'(:FKJU,!*$4-93^6P'(A>9>UJH_Y+\*OK>^OL3'8=Z,-%"9[1FKF_A>C
MP>,'G#^BDS84A!4`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,BYP;F<`````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R-#0W(#$P-3$U-#,T,30W(#`R-C(R,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````(```
M`"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!
M9&]B92!);6%G95)E861Y<<EE/```!+E)1$%46,/ME]E+E&$4QOTWBJ"++BN*
M@KI(J&A7*FBA3"G2B"G-;'&A)F/:3+%L46.21I-$$:W0B\R%M$S3J2Q1E*%%
M22,310L+"CGY.\/[Y>22DG017;SS?=^[/.]9GW/&3T3\A@_KI:FY6:R)XW:[
M1!TZ)(F)B=Y5F\TF#,?%2[[GK2.ISBR)LSN\&#?S[DAV=K;4U-3*^J`P\9N[
M8;,L61$H5]+3Q>?:L8;^?/OV79Q.IPZ'PR';@G:H%`$;-GEWY=4^DX&!`7'<
M*9/HLAIY]>Z]''$53.**J=GPI-XM3Y^]D!NW"F7$AGLE)>)VNZ6TM%0-&AH:
M*B\;&[U"#@X.JJ4P/Q;'8BZ72U:N7BNOW[SQPLR9OU`Z.SOES-D$*2HJTM,6
M0D]OO[A?MTO.O6JU0U;1`TG+R).I4_./`(B+_5'1,B$`K.'Q>"0U-4V=CD5P
M>&Q<G$1&1JKI,``!0$!@S@\?NGXB<=/#ZL?RZ=-G=4AT=(R:ET-]?7V2D)`@
M!#<6Q1^[#\0*468!!&X*DJ2K&7+B7(I&[K*`K9)34"QGSU]4[[).(._:%Z/O
M[`'8`FCK[E%=@TL>*3(ABHN"+UR1CHXNV5)<KNNX:H0-KC[WJ/?-I*VN2=K:
MVJ6GOU^PC;%12'6#@O\]-_X#`%&Q)S4F)@W`P<K**LU1`/#]QX_=,BY`3V^O
MA$=$:/CR)!*3DY.EL+!00YEYWIDGK!D^`/B=C80O84N\LXGYW-Q</9R?GZ]K
M[($M?`".GSJOC,%-B`\`B41B(1&'R`&^%_LOUW"V`$@D4K>BHD*E@(\@,E0@
M.P'EQNDS9^D>\H"\L`#0'\.13'NC[+J!;T`9S)%<S/,>?N28IKN/"N&MG4I\
M\!MY3O*T>M[*^JP\X0*2JZRTVDHJ'R^0*!@KI;Q.*P=9B+Y\X\J8@A(U("XU
M;.H#P.U8FLI"E=G?^%9O-=G'K<SS/6H<A)Q)M!8:&CUJ8:2",,P\I++''B__
M8#;^%^"O"D"L4_M(71H`6HG*1[5B*C`<,*4"D#20"+P`/]#^03@\(1^HS5R>
M<OFR\H:IGU1PF`N,EI86Q>%)0B*HJ6XC+F4!3<EDZ)!R"1D!!%$!`+M!5#`>
MG,(:51\A8`+F66<O0K(&CB$V]GWY^G5T`6@MT!(I.<@3Z>%CF!`-H5E<P1,&
M05C<`3`7\LY%T!"60QB8!(6PSO#JXG,YC2:F!0A0+L5L@`&`0&BEM#5T$=J;
M9HIUM.<,<_1$IL'BG;,[P_9I>4.($06%@6^A=#I\?(OT:(P_::H,I3-O*I89
M%!D$8-^T&3.U=C!'$S9OD;_.<Y;>"YQ1!6!@GK"*>N%?!1=SR/]HO`7(X35)
MJ0J*(&C$.M_L9WWVJHWZS4"!I8XDQ4%!K$>Y&3,+Z--"KF6J&ZA'E!*"#A-#
M]%0*?UN$:J!E:*@I-.\/*^OEH-.E;N";5*6"4"Q,CS=N&J;4-.GE^)>.DC*U
M8'NP!B(U[GI5G17!%$<C#%ES]W:YT%2N.ARC5:B]K4-<]\LU6"?$`V@.`&;#
M1$A,2C+(C&-5#6IZ`@SA^%X7?UK_`'$>H:BA[,<26"XP,U>[_@G_1?BU]?TU
M-H;[;KR!P&0/`OTO1K\;/P`H0J*N_`#'40````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S
M,G@S,B\S+G!N9P``````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-3,@,3`U,34T,S0Q-#<@,#(V
M,C(P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6
MV-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$
MO4E$0518P]67?TC4=QC'#?9'_37V5T$%(V8$453[(\;^,`8+6221*R/KCZUN
MV&QH,U<<67G9E=&17EJM>5OFBIU9V=)$TZ`TH1\:D@:*165$1Y<<3)`*]^Q>
M3WS.N^Y[5W>CC?YX_'R_W_M\GN?]>3[/^_U\3!&1E'#3/^7N"NFY,R"CHZ.O
MON;^N$U*#QR1T(RAH4?R/#!A_$.4CX'!03E1>V9\1LWI>BDJ<;WZ\.+%2VEL
M;)!=1[W1/KIZ^N3.X'VY._18ZNH;(R=\GO:E.%T5<K:I57B."#HV-B93I\^0
MN0L62MH7Z3)[[J<Z1H4HV/2-6,*.9Z&'OKY>Z>[ME[[^NSI>;&N+#`%J?FBY
MU"ZD*LH#R6`')#80"$1.R%ICDZ^6K9:=SC*=P&XB)O"!K:7.FJ.V*#U#:NOJ
MQC%\W]HNV(W.26++R0G]&(&AY_HG$G>;R9KE1PZ4@QVX=U\>/O9I[AI:+BN\
MS)798K<[Q._W6U<4$\XWM\JESFM2Y3TKI\\WZWOV^ESQ^7SQC_+WDUZQ%^^5
M\L,>'4GK?O<O8M)\K+HZO@-2O-:6IPL<^PXJ7"J9L\$AMO"S-(GIH/;4!=E=
M?C"T_]].SI&_1U(DT^'4TZ<:8B(X45TOA16'Y)E_6*JJCBOMUF0OEBV_;A8*
MT6KQNSO&_]\!W.KLOJT*01&A$B25VN"W\'J(6LQ9<PJH&PZH1(A:4/B35B)'
M3&'%=$`107<6=USK4@1$Q0%R&7<+R!.:2`1JG[I@,4;T-^:@\FB5EC$+/#5>
MY0%\L&W<JM#?Z(!Z1STI7Q95!@N*$7N]A"T=P`.<Y&]QZ&*Z`H0R9"(/,1V0
M."8QF<4X^W9#@9**$51HF='3*`<P;]K',U7TTI<N5ZU'"!%$F@$C#OC-T@%]
MQU;YLXHR^DLBGPY]((O2IBM#Z5J0*N86W.X:.=[4K(V+!O:@?Z)D9<T7M^LC
M\3WQJ^K&36+NGRTR,O*7U@"+D&AHG;%VB:*Z$BSCM^("T=N:4J6K^Z:\'W3^
MSP$,#P>4[;1AY`'"4EL8>>[HN*K?2"$20G7`T7\%`/V!FP1$6I`:-,H8DD,P
MHU]H&7,P^`S'][M<"I)"20@`$N3<X]+=F2`X!@B!",@[N\8(!JER\X(L=)1(
M::E3^R'%!0\2!H",&6)1U@0SK1XC`T8[V2UMGS7AEZ"D:P`GR``-F2,@(#K#
M,P%YYYGNCVBAA%P/`6#N'DD#(/5&?Q`T=)I`!.$=(VAIV9'0[0'9)?U(K]4]
M)B$`I!+G&(X)2!````1`=!SN0\BW46)4F(L4F7C]O!,"@`--9S`X#I%T9$[/
M.7@D?#=W)L`Q,@<PC/Q.]@"8$`!2C^03G%12`^S.[!#C&ZGFV5S:J'J",P(,
M`P`^&&-I@24JQ)LC6'?L#TG?5*B`\GZPZWO&=SE*+X*MVK9:A3]SQ13YNJA8
M+X$4(&MI#LR%_QZ/1P7*"D1,M4-TX#E,X*PWG&G0=H63XATK]=995_NA7B+S
M-TY6_G.Q;&EJE\W><WJ92*H(D5EZ(@%!;1S2;%&R(OL\#:Z]LJQ$FRX90'#"
MYR;-`G8!Q\,=\&^/8WNJ!N;.S9D:K3_5?%&[_3MO1E"J]_:MMQ:8]Z8=_P.<
MGIE^IU\DH@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0N<&YG````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C0S,B`Q,#4Q-30S-#$T-R`P,C8R,38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```"``
M```@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`
M061O8F4@26UA9V5296%D>7')93P```2L241!5%C#U9=M3(UA&,>S^<`G\XG-
M?*+-9HR^F/F0V<@8LD8(8\JRL]`J;PD=28TS*GGM$`FECE!K)[)1VAJ%5=XF
M&QG.'.ULVAJ6B]_5GCK'><G),!^N[N=YSGU?U_^^[NO_O^Y"1"3$W?1/3NX1
M>?CXN71W=_=^-26E2?:AX](WHZ/CC7QV#>G_X.7C1?M+*2ZU]<\H+J^0M`Q+
M[X<O7[Y*556E[#U9XNVCZ5&;/&E_)>T=[^1R1:7GA!GALV6_)5]LU3>$9X^@
M/3T],F;L.)D<-DW"9T7(Q,EA.GJ%2$I<*SYA![*^A[:V5FEJ?2IMS]IUO%%;
MZQD"U"2PYE:=D"HO#R2#'9!8E\OE.2%Z99S,BUPN>S(/ZP1VXS&!#UCHA$EJ
M,R,626E963\&T\TZP>XU#)>X^/B^'STP/&H<+P&W.5CS^9$#-0[V]5N'YJZR
MYK;"BUH:(]M3,\3I=/JN*"94VF_*K89&*;QX1<JOV_5]=>Q&<3@<@8^R^'RI
MI*9G2<XQJXZD]6#N*3'27'CV;&`'I)A(+#`?R%.X5'+"IJWJ$)LV/5S\.K!=
MMLN^G#S=/[PX<V&2?.L*D2ASIIX^U>`7`?!3CAR5C\Y.*2@H4MJMC)DC6T\G
M"X5XJOS*7SS&?^\`;C4TMV@!8:@$145M\)M[/7@MYJPY!<AI5"+/22E;M!(Y
M8@K+KP.*"+H3N;ZQ24>BX@"Y#+@%Y`E-)`*U7U)6I8LQH@^8@_P3!5K&++`6
ME2@/X$-\0HI"']`!]8YZ4KZQIFV2_Z.@&+&?2]BG`W@P;_$:2=QFUL4X@U`&
MF<B#7P<DCDE,9C'.UFU(4E(Q@@HM,_34RP',0]]A9,2"2'U&XQ%#F@$C#OC-
MIP/Z3ES^"15E]+?"9I</'4-E9OA892CLA%1^MY"76R3GJNW:N&A@KYX-D^CH
MJ9)K&2F.]TY5W8!)-%VKD:ZN3UH#+$*BH?7"5?,5U9T?9?Q+7"!Z;76H-#7?
ME_^#SG\=0&>G2]E.&T8>("RUA9'G^OJ[^HT4<O)4!QS]+0#H#]PD()<#Y`6-
M,@S)07HPU`,M8PX&G^'X08M%05(H00%`@C+W6W1W1@`<`\003=[9-48P2$4K
M,YLS)#L[4_LAQ04/@@:`C$$L%(JR)IC1ZC%#K0G.;FG[K'&_!`VZ!G""#-"0
M.0(XAL[P3$``\$SW1[00+ZZ'`##N'H,&0.H-_4'0T&D"$81WC*!9.<=5Z+C9
M(;ND'^GU=8\)"@"IQ#F&8P(2!````1`=AX:!?"/C*#$JO#S6I)GX^;R#`H`#
MC.`X1-(Y`LZ9(^$[@'@&'"-S`,-(%R-[W'B"`D#JD7R"DTIJ@#YC]!J,;Z2:
M9^/21D"",P(,%@``'XS^M,`G*L2;(UA7>$GF)J8H(!SROG!]O-*+8,MVKE#A
MCUHR6J+2TO422`&REN;`7/AOM5I5H'R!\*MVB`X\APG<.C?8JK1=X21]]U*]
M=9:5CM!+Y.:$4<I_+I8UU7627'+5[V5R0`#(+#V1@*`V'-)L4;*T'5,TN/;*
MPQG:=,D`@N,^=]`L8!=PW-T!__:8=X5J8.[<G*FA]8@4XQ]O1E"JM>7!+PO,
M?]..OP-@B9F31GXT"P````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,S)X,S(O-2YP;F<``````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-3`T(#$P-3$U-#,T,30W(#`R
M-C(Q-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``
MUMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```
M!-9)1$%46,/ME]E/4U$0QOE[?-,7H_'%)<:8H-'$)8H:L2X@[AN*$G$AN1@4
M40QED4`IF[A0Q:4N$`4M*H@U()8"P40?4`P/\D*"8W_3G*87"D&-B5$?#KWW
MW#DSWYGEFR%.1.*BE_YI?_U:=AVUI*2T/+Q[L;A"NMZ^E:3]&>&-D9$1>=G:
M*CZ?SWX^HL/?T2F+5R:*;F18N9*8<DC/HRMNVHR98EF6#`\/2^1(]$)ZG$Y7
M>:7<:VR2_+(:R<AV2K"G5RIOW)$5&U/"4N[;#9+F+)+-S7XY<CQ3-GB\LL0Z
MIV;&F8@)>\H"!87%,J&`==ZI`''"]#GSQ":0X$A2U&NW[E?DW`('J4!?;Z]>
M$4_U]_?+PR<^F1N_1@5Q>%A]R'.#@X/B\7@$'#RSIQK.^'OU845JNCB<+B&8
M9UP5\G/7_)D5<[/E19ND9>9*<TN;NJ6XLDZJKER5*2E8N6:='JR]]4#.YKOD
M19M?2FL\ZL**ZW?U=W1TU'Y'-JP+19IP'&85EM>JL+^C2XRK-9NL,#+<;,OI
MLAMA%Q],/:R17)V\2S8YMDAVGE/F+UJJ*3YKP5*IK:M7&9;M"NM*JL3K>ZZ'
M;][V2M;Y"WH-WEU5]4(VY.5=4AE3#;8K1/NAH:%!6.:=[R2!"?[O#^.?HV#G
MW@/RX<-'^6$%4`M."P0"\NI-5X2EIJ2`!"'6)`[IG'WILH:3&H74)E4P-#2D
MPF0:69F94R"=7>^4&JD'4IM\B*E@64*2$K+[6KW2!]8YZ-B3KBB"P6Y%Q7<4
M&8**.`MK6";?^=V>>DJ?J4:JL_[!$ZV-=X&@DI<A+E7`"YIQ&)81I`IQ(KP$
M`A#B!UI'\H%C=@7D]J'*ZUH@P*:DDT];6D0XE2)BQ2]?+8V/FR1AP\9(>",^
MP#D4$(<?/VM3"X2RN?FIP/U$!A\A,S`P8"^F$QW]:IWFX':[E11Q$N]P05:(
M:E%VZGZCT-_&10%!M/*1*ISMV*8*%N[>I^SC]7I5`=>*F0?16GGF`"1O]F">
MCLY.V]Y?5,[_%@"*G=9.LM->('_JD_QD-@EV!^6W`:!ZRFMN:FU3HG5W'VF-
M,T[`-/QFY95HQ5&RI.TO`R"E*5^X@*D#DH%4,`BAF.F/FP,,`)0^O,$WP,"A
M>.V'`5"`L%RINUI'`V[,PB`+TF+Q#7K$((;-=$#=06@`IKE3V,PG>&U"`+`!
M[0-FY)889,2`:GF&W%'*[3$&`'@+_B87H!UXFU]`L(\N9/`0S0*:AN?&D2$L
M`7MR(Q1#?B@R((S;24"^`P1`+'*"=X8GP@!E0^GD@O&2H7D6``BI#0#Q9G0A
MYC`N<3>3+^[%,R@DKH!`*>[.N>C47P!R.W+`R.$EJH.%#O2BGYF+BHJ9`P6A
M&\/F>`1BAN5=KO#H2X@8B8MKK^D^G&N&-93B?A*NNKI:SYK_,8@]8Q6MA=R8
M,`>^CGZ3GD]?5`G*F;GYGP/4M!F`8(R$`B!`F<U-WP(\G<3(EI56Z*T!0T.8
MM`HPO*/OLY8--V@)O-<N2R5H*PJU8290^(!0;<XIDE7>)KTY%4.>;$I+5T\A
M3X,%/.Z?$@_DMW?+^O23RFICA2"9W*H:!:.32^B&A(,XFLG6]%*^X2$\P8P=
M/0K_$A-B""-C._K8,L8@B\J83/9_-S3K.WL.P"_`--G_`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\V+G!N9P``````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(T,S<@,3`U,34T,S0Q-#<@,#(V,C(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````@
M````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E
M`$%D;V)E($EM86=E4F5A9'EQR64\```$L4E$0518P^V7VTL3<!3'?>NM/R!Z
MK(>("H*(HA[*LAL15'0A*Z4;91?H:DE7,\K2H%EB2":9I8)=9JUD(*@9BT8B
MN9R6I6LNU[HKT2A.?<[XS2U765%$]?!SOYV=<W[?<W[G?,_/.!&)BUSZ9_FZ
M;7+UFEW"@I0M^R3O=+'PJ8(%S5[).'!`O%YOM'W8Y'I5K<Q<L"SD8_VF[;)E
M[Q&)GY4H4Z;-"*EA>]'E[CDE<C4V-DHOGUFYA6+)+Y*=!RVZ6EM;Y8J]6I)7
MK0]IV>UV&=G^1L'OWK=?+-Z`='=WB\?CZ0TS)NP^*VQ+W2%?5"@JNRPGSY0I
MN"$C1DN40H6M4JKK')K,6[>=JH2!*KQ\^4I#)'5X0(D]&23<N`$=02',TM)2
MF?3HN=34ULK:]`SIY_O0DTF'PR&9F9FRR_5`X]^4>42"P:!\?Y@_LF(*-Z9E
M"#7!Q=8YZX4:\_E\\DT'#7==<JKX@AKS>;S@O%35W)1YR1OD@JU*TX>SF%5,
MT9&VPM)+:@@*<M[D;E;C].P\29B]-.QD?'Q"*,W&4]/K+CGTL$..67*TX!,Z
MNG3/(OW(DI*396*Y37+S\L5JM?9DF=37-S1(JB<@7*S3Z=3RY).2Q$%!08&T
MM;4)]\JU?36)@4`@K(`#LP?R[[G&/\-!3FZ^=L1W.Z#O8!%G?8.8PH(H^N2`
MQJ60RBLJM3=I6BH19APS=6Y,1U%?@$P94VVFC`];3LJJC7MT#[*8Q(<AK'"N
MO$+*+EU3)]0_\"EA[I]P^!V4:[>G:]^''0#;P*7N.1%'&+%`@]&._=EZT)PE
M:[2LPPX0`(_3.)EXR0/P<01'(5N\>JON65$.6'`4O`DU#72X=4_2!KL[=2P0
M)HW$'GXS_*#&*Q^_4`&QTH7T`N1'0S%*2!P'\#L--V_^_.AF@C4GM'2J9SKM
M1M=;.5M3JYWX_I-"V@.O[AD:Y"*RV<(AP**0!P/0(##(V,_V=6G+Q[S&+[4R
M\"/EAJK_LG;^=P!0@[0:!0T[0#M\I[6042&_!`"]S!R#&&A+"`&JHE59?+_A
MN*U@F(4\R!AE3*"?!L#!$`T'$'%+2XL2+7O(A\&+C,,9S.A#.(931HV=(#![
MGP%`<0S=PJ+09(<6#4$3J2$LV([%'CW(C,,!ZFIR*V4`TKS$>$^BQU4QMV,"
M(!K0DU[HD\-Y=W*H<8Q#=&!#F!(9&>%`]CR$^`Y@,F)T8!A\PJ8\20BPU_L-
MYL2`B#G<&/$R!CW&+"*#83B4]%,CR"A&DPWJ@`7O`00[K@3PT#I4;AX945<`
M*D",V;!94\H=\N(U:^CDZ3)YQ1J-@M_,)TZ1&WWS.3SKA"ZCRRB`R7EGF:L(
M'][Y+BCM_J>:FK3B$C5`$;GKB5\-\JJJ%1Q.KG@[I:3=)WZ_7^7C%B9J9.@B
M)RL\X)`=M=IT$GQ.Y%$`DNXTJ?.4E!2=!C@&#.]NHL`1DP$@_%YVKSE*'UUL
M`##E8):"Y(H(BMI8E)JFNI\_E'NU!?.+V<:AQ@!']#5SCFE+M#P.F''\CLWH
M._?5AHF,#'VR-,@6^N^-FOHA(DKTO)!A)58=\9&CCLD,&#(3^8*M?-4M_=W/
MM"9X'O\?1G\\@(_9N-.J4DK2_0````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S<N<&YG```````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4W-B`Q,#4Q-30S-#$T-R`P
M,C8R,S(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``40241!5%C#[99-:%17%,<#TIT[<>'&C<6"BBVX$)5N:JH0*DB+7XT+!6/:
M!FTT"8I1$^*0QHI*9B)1QV@^FF_3)$P'R:!11R6-R6A'V]&B-FJ-2OPJ@U,T
M8H[^3KCCO+QGTK@0P2[.S+OOW7ON.?]S_O][DT0D*='T9\G*#)F<EB5S4A8/
MOLW84"!;\K?)LM3E@R_Z^_NEM+14KE[[R[H^[N-H^PGYV!\6?9&1E2O+5J^7
M>0L6R8)%J9*$HVTNE_3U]4E\2:+MV+E+;#YW[JT4S%-6(UF;\J7Y9(=<^_>Y
M$)Y.Z+GYM^3MVB<9Q75JXS>?DH*B'<Y;!(-!^Q;#F67`_J^=4-7HD]5K<F1Z
M.*I`?I3G?A4#'X\%.^33N2D:/3@>]K4)F"9%HU%-;^'7:>*M;-`T*0.H\4T]
M-#7]+*'0.2%=5OW:V:GET2WVG'^B#W.K[PD3L[*S9<+V2^*816_O+1DVS3<Q
MQY>T0$.S3V,]$FB7C:[=4ECTHX0O_B$#`P.:CZ.#!P\?*A)`5M-\1'%-^39;
MBB_VJI,6?T`J;C\5C\=C=<!$)M"C+#2+08KV\OO]XO5ZM3$!JLB]7^A\2T\?
MO_M4PVP+!+10A\Y<5Q;DG(C)IMS-NCM.2(.Q)8)_G@S(I'DKQ-_QNU:;/F4'
MN%%=7:V+<49DF3FY]FX$F,27T`4C=/(U+(E$(F^IC.^&`YJ%4M+\HW(`A:@S
M74C-#0\!%1`-P(X.H!N=2!M#6-B=O#8OSG#&2%ZBL-@X\$O@I!HDWW_CL:SZ
MP2U3/YFICI&L].(R>Q_0LBR@88Q\D#_RD;/%):O2TJ6VK5VU#J5@#O\6S<'!
MZ;,A#1U>E!RHD$/EY2H0M#8.:?7/DN?K,[C$'>`-X#`(@R:5US1JS^.0"(VZ
MHUVT,XXM&$Q,]RI98K&8@H0\@_;8]!HQE0F'+\BLKU8Z<X%^YP"`--"4_Y8K
MC[2<Z!XLA1O@04H6!U-^>J:[S\CT:-X?NGLTW\4NKZ:1O+5.ZNKK52QAIRT"
M:DVX=-W]6+],F?VYIL%DH[2\'QI^W,'0=L49-"9\4L,9."!YHR)39565@OIN
MT_G]"8`BHE$P!"9PX'5U=ZMRP%%.]9&TZXT"H`EP#DF@)1L2!"(QIKY+>Y^.
M&U=X4,<8;<P8HQ._<#?)!Z4^&P=&#(`6AL(=7;^I0B&H6&=72/5AW>6HGMP0
M[OO0;94]N(*A&YF=-R2URB]K@G_J>$0:`"%,KFUH$J.M9(W:\6SNBV2/.'&8
M(UYK"W>K;*!TJ"`EH5S\,X?-.:<I'4J8&$A\<X0*J!%NI)4-R9H->4:?D%N^
ML2DPAR.7E>CH4W.K3R]P%R*75#GPQ3=N$@3`OUF+%#/7$@!9`;?)E@VI-1=@
MOH$(61`@]SS4!;0P=`[M0SBXAQ,0")$Q2/#,QABH,,:_K00T'-<9&HNK#C4E
M>LX'GLF:S)!^QC@BZ(DIW^F8S)C//#,F"*Y*O$.8"?:UAS*VO?N93%NZ<7"S
MEU""`M&2(49'$QP=S3'2&#BC=253>HASEW4<'23$6AJ6$D'E89N0<^?+DJ!"
MB7&TTM$T%PZY,5("GBD!2#&F#-1TVKX[BH8YBLF<8XI@*=NP5W3-_*4#H&,#
ML@,N.$XF7%.!WAR(T`^&4'.X3NG(E#4@\4WK+3V-0<WI4FD+P!QA;.XT$<=D
M16>;1B,[TX2H(J<VFY,I<_$WZIO=?S'0(3.S"4$Q=H+X_]-P)'L!64F2=ZS"
MT?X`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O."YP;F<`````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,S$V(#$P-3$U-#,T,30W(#`R-C(R,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!&!)1$%46,/MEUU,5%<0QWVOC[[V
MO:8F-OC0A$=KE+0FU:01C&T4/ZJDK`:I6'6M320V:UR_`!?<;&J(&]9=(MD*
MVT`EC22B$HA0L:R(100)H*!$04*DT_Z&G.5>]J+XD1J-#V?O/>?,G?G/G)G_
MG)TC(G.L0W_Z^OIDI?N`?!)MG%PM+2V5BHH*<;E<=O'$)[:%D9$1&1@8D(]W
M'11=Z.SLE%@LIM]W=77-0H>C0'U]O1P]>DSJZNKD^]UN"<;.RZKT#&EM;9V2
MQ##/\?%Q?0)F]B9>70#[!'#!Y0'Y</4F?4:CT4D,;!87%PL!O7[_D2Q-2U-/
M"(X*C(V-26UMK0KX_7[Q>KU27EXN-34UR5Y47HG;7+5AX+D\ZT>QSE^/FZ^D
MH*FI27"2D)`6.`N\>#QNAX@0!QT(!"04"@F'W]'1(;Z;@[+%ZY.%*8LT;#DE
MIW5.Q'I[>Z>B-#P\K!^A@%!&(A&=(TC6>#P>"8?#DIN;JXH(\=#0D#W,9`\9
MNRY[AT)D_'G]+UF[Z5M]!]'9\Q<D,S-3,&B.PN;S?,\ES5$S_^G4;V(],_:?
M&<3L[7D)@8F)"5NPSK5VR1ZW6_[?8WS+%9CDHE`I+TZ'XS-E9E-`Q$D,A,DP
MTI6/375#DPNWNN73%1D)RK,I((&@3[*0O.?XSE56RN=?KY=#C1W2T-"@*$CM
M95^EVU!H<9-E"$!^T`?I>L)7(AM<VY1&R$!2FG?V48"+"00HH(@,]U!U(,G/
MS]?ZH!:@&@B:=^1Q6Q48_Z\V-RL*%/!$`7F/4JSC$H3&/F5NJP4F!&[)OJ`&
MCQBTM[?+E]XJC;Z9?Y$?T4"/CHXZ4]:]P0<):(S"0-`6\=O==V>NA2?C3V75
MQAQ;,1%4*Z/BRHP*NOL';9O?!!K$RJ[3]Y,4I.P]*RTM+6*%:W4'_]_1:GP/
MX(T`:&MKD[GEDQ1%B7Y4$-;Y!Z?^D,\RM^A\WI$RY8&TDQ%]+R@H?'86FG*F
MH4)MILE",O`"E$998QRCKN9^Y<<U!WV2??&6=N^M^SVZMG%SEJZM^24JW]5>
MTST(BNN!M4W:"!GC*(=+,`CI,`P`*!#",E?/V)TAY=L?#A<)+1,CA?Z`T%IA
M0;?'JS+PKZ%0G(/PD^Y7`*!=]/3T*--AT-S6H$\HA3F1P1/FU^(WM$_#D%75
M-=)^ZV^]27#](P([\G8J8*XCZ`@&@PH<)QT!<#6!*6$3T&*,CQC<=9BS#@#>
MH6P\13E`F&.4.>=MU@&!(QCG'2>3`)@<H"^`$",8I2OA;5%1D>:$]4AX!P!R
M&*?9(`M@]I$S0)@3?G1SU%:*G#'3[S]\+/`K7M$FG&1:;MS^3VG<<<__>[/V
M)Z?KU*S*\$#H@OA*PXEKI'7@0>KABYKQ3N``S_=EH3/R4CS`<1P/5>N9DYS3
M]T>>C#FN)WBB^YZ"IW1?"D#J_E]E?=[/6A%)X)[^H]Y3@D[1H6\N/G;)L?F^
M4`3(5G/U>9'!\?"M^;OXOAD];_P+EE0;G1Y./P\`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\Y+G!N9P``````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,C0@,3`U,34T,S0Q-#<@
M,#(V,C(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$)DE$0518P^V6RTO4413'_6."-BU:M(HV4;A*J/Z%B%I%5)10AEA6UD(P
MDL'4F!EK?+\?P_A`!Q&3E!3?FIB9Z(Q,V@SBC(ZG^9SX_>:M41$A+L[\YMY[
M[KGG^3TG0T0R8DE_RLO+97%Q4?CJ1E%1D=36UT<WDJ[$;:RLK,C$Q(0,#`S(
M]O:V9'B]7K';[=+:VBH<*ELXO"=;6UN24D;*1]"IH*!`.CHZI*NK2SH[.Z6B
MHD+&Q\>CG",C(RH21KZ\_>M/_#E#34V-.)U.F9N;4R=65E9*7U_?3QW"X;#4
MUM8*#NWIZ5$+&AL;U0I3`J:5E)3H05U=G5175TM_?W^4H<?]01=%;YKTV^IR
M2YP.9VYGZ\:IZS<D=OUWS/PW`G9W=S6)ZNL;S-R9GIZ6^?EYF9R8E.'A81D:
M&E+/<$92+"TMQ<>:9",8^!>_=W=WJUL1BEL)CL/A$(O%(BTM+<D"H$!@2TZ<
M/2>Q>\Y(X(S_G^:7Y.3Y3$GK`_?[C[*ZNFHR?-O8B&,F?IN;F^D%&&JEH^7E
M9?E/PW@(!(1"(7&[W5):6JI)`\+,S,QH)E+AL[.SFF2@8U55E>['"?!X/-+;
MVRLVFTV`!^"`BP@9'1W5-`8KR<ZFIB;]SZ.F`)(#IN+B8@5`!!GP`7&1_.=U
MM&AK:Y-@,!@5$`@$5&W@A'SG%51N;F[6NN`BM8")"(!W9V<G*@!IP*P]4DAH
M4596ID4$81*"J4(JE3TJ%[!+BL+=EGZUV5A[UK_%Y3[G5&W:,-Y_\MP\W-O;
MD].Y3\TUF''O47[Z6J#G/,S+,QF"P9!IIU'J>?G["'A1[5)L-M8OW[:KTXSU
M4WN[#`X.IA>`(XVNEXHX,T)WR(KI2(&_K@"Y2VW[?#X!9:@<@^@X:VMKNK^^
MOIY$#$:<PP?!MQ'I3&2@4;K[*@#CPL*"PAD80%V`"_P'C0`1IB#P$*B;FII2
M7`!'QL;&M(,#==P'Q8Q.3SV!<*`8G2]6&?-Q\!&-`5_`&00#F`H+"W6Z0@A[
M#%.,"$`DB(=0T`_D@^CZ3`2@((3R?-EWN5R*5<RP*3V`N[`,<&?$X%%&";S`
MFH>P#BNQUB`#\%&,NW@+!.4>1N!)]I!-:,&U%%@6UEC!@(L1C,98;;5:U94H
M@758C44(Y3^6\\4C>(9FPO]8.$<6,NE41C=*\@!*<.CW^S69\BT.R;QR39L(
M\69B@["$J>W9ZTJY>"=;E2-T[/,E3W#UXU<VO8]WC&2,!>@#R_"[/R#CD21+
MA:'3DY_$8GT7UW\2:>.[7^\G/GJ@`J'0CCQXZY3C69>TQ2:>TZL8!*_>O*45
MD'B^\M6C]X]=R-I7P;0*^'R;\OG+<ERRQ)+=T2&7+3;)R<E)>>[U^O3^;R,A
MO9$YN3-F-DX,S8<()I"PJ1[/M3;H'$U.'/6"_UZ!'^9.8+T&WL.1`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+VYA+G!N9P``````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C<P,2`Q,#4Q-30S-#$T-R`P,C8T-3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```53241!5%C#O9?'2F11$(9]`E_`
M1W#GPE=PZ<*5*W<BN'`IB+@1440$,:%BSIC%@#E@SCE'S((YQYKYRCGM[>FV
MIT>=&3CC]=YS*OSUUU]'#Q'QL"[]K[>W5PH*"F1Z>EH\=G=W96AH2-K;VZ6\
MO/QM6TM+B^3EY<G(R(C]>9N-\/!PB8^/%WW1UM8FWM[>XN_O+\G)R6_;.-_0
MT""V(]:5EI8F-S<W8F=S=G96LK.S969F1E)24B0X.%ACW-S<?-M%T%E963(^
M/JZ;AH>'I;:V5FYO;QW#)+K+RTM[%ZZ6[6%B8D(>'AXX*4]/3_86FIJ:A$#!
M*C<W5PX.#N3\_/P]3<",BHI20.?FYJ2QL5%(5S<0?5E9F82$A$AE9:5X>GI*
M45&1]/3T2$9&QIN?_/Q\+0DI3DY.ZH:2DI)W%]W=W;*_OR\U-34"]FQTR&)O
M;T]<IOG1(BZW<%I=7=52\'QT=*0Q4RLROKJZ$ECT^OJJW\G!P<#+RXL\/CXJ
MCG5U=5K/L;$Q-0KU^OKZ)"<G1Q'[]<_>`(>I%O!Y>7G)\O*R%H;G]/1T\?/S
M4T,8("*G$6``%"E:55651$9&RL;&A@0%!2G\L)IBWMW=.2<3]%M86)#$Q$09
M'!Q4'$B%GX6%A>I@:6E)/@3Q]/14/QX>'NI!.%5?7Z\=8@6NM+34?3K326Z5
M\;/+Y4>`_)2!X^-C+31EH[R\&QT==4WEZNIJW0#;.CL[M2$!%C*=G)P(3<MW
MRKFRLN(<Q+6U-9F:FE+B`!YJ`_H("3($N:*CHQW+2/WQS(:PL#`-G9"A,1'P
MC%'ZVDHBFP%8"/_Q!`LA3&AHJ!JDQ_&*T>+B8NWUU-14QQ0N+BZT67Q\?,37
MU_?G%P]EX];6ELI,8&"@5%14*,%P:#/`(7+%`]XQ@'AC`%7?V=FQ&01H]M%D
MT!T5LD4`ZL@_G@",0^`1$1&ADHEQ`*47C"[84B!7%)`-="-A4@T.8@P@!P8&
M5%1(@Y9W5D;M1*8'-<>(6?`"X\PDJW<[`Z`;&QNK'8A7A(.R(;]XAU14A/R=
M&F`<F6>PH(69`AT=':J-1,<WC/UQ.AG)0@?/SL[T>7U]_>]E'?"LD^S;]0"]
MY";QS_3D3XN90]6_-0`*9!T;5C@I]/7UM<**Q,`,V`(*S\_/^IYBTZO6=C-U
MM=Y^7"*`(]A#4T""^_M[0211%ZA)0R`>*`S4I76A+EV&8#"%"(8;#4RDA4$*
M.VZ7@`E%$(@GVH@B<4_@*HD>L$#%R!WT-D'1+[Q;7%R4N+@X[6BW2H!:<YA,
MMK>W5?J2DI)T2&.0K@8%9()O&#9R@82RA\#Z^_NU#)F9F2JI*"6+,_2D2P2H
M)36E#`A9<W.S*B1JR//\_+P^HQ!T`5</[F<$C>SR#=E!BKGGL`_XT2\&AP,"
M##U&$=D!&0W/3S,@,$0`7"%QQ@T#)Y2#LG!K1K(#`@)T<5-G'_:H/0MD"9P%
M2@@,/O&MTPAFHX$XYR!BBCH3`'":`(#;S`;NMF0,6D#-.Z:8"92Q0.D@)23E
MAH-S2L#U$9_X=B@!,%%_-L?$Q"CKJ2N!46?J2"9`3GWY"6*P'6X8KM`I##L0
MY#S#Z_?6=.``F\@(+8`T1`O43+^NKBYM+Q9.S-V599SRC6[@[L;4@!O8X'I.
ML'"(Y-QJ0\I!G2`2TP5-,'^($!3&6EM;=0$O4#/:^9TK+`AP'BXY$[8/`Z`^
M9`#!B):N8*$+9)F0D*!PLR@)R."<#$&"B0TI&;PH'SR`N&C*EV8!",!H%`[C
MJ!I\`!&<\XX:LP\M^?T\P9AKYK<-(\I`ISC3^/\R#;EE\L?$5VS\`&U97`B]
M#\J$`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O5%=#;&]G;U\S,G!X+G!N9P```````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-3`U(#$P-3$U-#,T,30W
M(#`S,#(U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````*P```"`(!@```?R=L94````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```"-=)1$%46,.M6`M0E<<57ML:8ILV:=I.Z]A))FTSMHW-=)),&FLS26N,
M^$1-0,&*BHE(!:+!B&(D%J/FT:@38XW*RP>71W@_A,M;!45!?"$:$!%%,8@/
M4$$"X?0[NWM__GMY:$EVYKO[_[MGSW_V['GM%6)ABA`S+.(7[^60#2(P4PCA
MERK$=`N)-Q.)FUB>13\/R=,3,RSTTI:#]/SF`_1Q48V>P#)R:.+=;$S@&W;\
MY\5K-N`IJ9995<^#296-]-C:0AK^GWUZ\*TT.[YBVJ[GA?!/59BR2XKVRY!\
M.M;00E57[Y`(LI+!>LD>_2T_1=S6WD4=U$7K\FH,CE576V7?O3^Y^6C*/7>=
M&EK:J:3^)FTKO4";#M89BXP]FS#(X=T>K(<A>##KPA$@S%+$V)P<P$9X0XVW
MV^D*,#FR7(W]*UEIQ[9!2;PT2\+61FXZ".5FDO!-D<3&!IFXXQNBH>_G4WC9
M!6/!$Q_NA7YW]R06WDD4D'&&FN]V$&M&>">3M>H:X7!Z$A=6-]'&HEHJA=IV
ME-53\JD&6KGG#(G9<2;B%58^UAXF8W?4OBE:=?:Z_`OP2+]Z-N`:]1)S&K_U
M,$T+*Y68$EY*DT)+:;(&/_.8;=X%2*K\"C:5TP15C^UF;#,-FU+8/P(SNS'G
M"REV.ZM6M]^LR\<19'73J*,P]&!O<S;&?]].N5#BZ+##E'GZJJ)VC9*+TT]?
MH<2*!LJ#]FN;6NGIC<74PJ?B&7L?C-VC:?_Y&Q1:>I&$<SC=A$7UU49\LE]Q
M&Q]Q'XRG[E(4CW\@^Q<^*Y']DVL*Z19<;M*.,OD>D%9)WJF55'.ME81_6B^,
M^<BU<TO&+V\CL2A-ZE;,3X0-H5^2H=Y]DF&(&/-%OR!)S;G"."=&&HP'OY,A
M!@>DFTQH>9:T#&U[_S><EF0XF%M@)IO("9,E;`*6`JN`WYN(:X$((`FXI,>F
MZ/ZO>NU'!A_#AGV2Q<-!UG[C1E^0(6)Y%CM+L+US@.F&?;7DLJW$,'P&.X,+
M,#5<@=_-\Z,_/:`4.R^1I7[""%82'C%"AWT5I!A^J7)!Q5>WZ7?K]]'(+<HR
M.+$8-"L0L1>GJPCX=KJPC]KNFNERDQ=QB/=-)3'J<\GL*=AJ1Q=H?)*Z:>!U
M0T#'3'O:K8VISA7218%G-A019[=AZPKHM=WE2E(VNT`569GVP7LQ#;">H9\%
MYY!7?`6EG&JD?X0IX[_=WDGEB(G"*XZ>_4SIL>[:'?K>"DBZ(OL>DOJET)'Z
M9IGA6A%@AH7D4OLW72H(O?!?R>QQA.\OP9!;!`*O$Z3MGZGK;CN?WUQ\GO;5
M7J-Q.XZ2\(CFPZ#QD4>H[F:;G+^!'3@%W8NI#G$>,<=I?D(%B7%ATH6MB&3%
MYZ^3I?RRE*ZBH9E>1!4AQH;=QT$AW_TD.)<L%5<D\^"<:EJC<WA>39/L(\LO
MR7YE=C4)-\N]#TK,B)8+:J^W412DLK7XD^HCJ:A%NO38JMRS=.?K3AKT3H8#
M4YOQ>\8JIAR=7K>PAY!X`_",(?'/&/T<I\8Y4G$:Y0B&P#TN](AD*J,58$0I
M+GX>",JZ3@-H[-ZP&@'5*7Y&)$+JA:<,.`3":>S"7W_8K=VQK_D?Z?['NG<"
M'A1ZT37`!0@`8H!$/=ZD>Q_=^P.AF@$Y]*6]UP6F,,@UF9B\<V;T*77J=X'6
MKJY>T>:`5H>^K8]U-G1R&&"O?3N]"LF8C^*W$"X22.Z[B+%A5IS005T=[G2V
MJG@NJ.W!8[-@::^$DA@#YW..@!,";M'J&5XOQH:3&!TJ*P+Q1D)/'A(8'[F%
MP@Y?E-\T$DJ/BLM4#9A]S":LC%'F\&T*T6(1PGA`.O+#+4GKC8C!;>CJ?-F/
MCU#!<_NA.OHI@BKG$[N"RLP+<]\/M-H).VQ-@1T&+BR#QU$*_^&C0D6+*,/M
M_?RSNNPY*'N7K8=D&$0B4P5X;\)BGB.465A;4.FUSNI56#Z^A2DJH'#RFXLC
M\TY0@696+(E)N!\M3B//V.,P@4BI33$GCD9\L%?2#E^3CW!Y5M;QP@L\W+%Y
MMRC%TSU&;E!N!+7:MQ?VY:WD;CDFG\..U,L^[D0#6:L;Y7-VU55Y1PC)/R??
M)^*NDZZ=,A#W!\GCK739CT$M(L<S3M,C*Q7_EO9.13,AD@;K"^#`A>6=0P.=
MG?!:>&ZB3CRL/6[^,2=0PR08T?;8I69Z%$>KUJJT&F*MEOV?-Q;)?M3Z_3(3
MVMH/V#3PG2'OYGQ+85&RB$7I],-@*_UJ59ZTNZ?X+N<22:]\7D(+DT[2@K0S
M]&MVH#&AY&$Y+@5QBSI&?"N>O@OY?G8L30PODV;D''J(9N\^+K/NWV#3#P5E
M4R!G5:]X<EJ6^1UHUB/:T()S^!$ZW]Q&:^%$1;B<K"T\1T]_HC3F`7-Y$<[$
M;?3V4GG_7*Q-85;,2:ILO$7;#RM3^N.:`HH\>IFZNG15Y)_Z'=CL-#C0?'G7
MI@FHA\6?UE/!A1M4?JE%5D5S8D_22?SQP*VFZ0Y-B"BEJZU?R_>CEYMI-LRD
M_I:JGA)@0B&H69HPSZ7'^@-U5':Q!>7;9GF'&0(M#T#8Z&YA72TJY"!$;2BN
MHZD[R^DY'!\7F\\`,V-/T`P(S!<D-U1GKUN.TK.;#M"@I7ODW(@-Q;(^Y_<I
M./['UA;0VKTUY(-;VZ.H-]_+.TO!!36J=M=5GDW8H8BM9@CYWP^7'J8;'5<=
MG+F,#.:R4X4NSC9>&G--S_+]"_NY>0YT<WM99Z.#0A[03KDZ7WY753"^NBQ:
MD*2J&;MTQN41IUO6+NHO"""%'LC]:Z!W-BDD"\=*Y-K-X<;9.YB0L13/BW&-
M6M0/`N^#IE]`,0$9ZGO+LOJ6"3_5P'!@!U`&/`14`GY`ITZ),_5XAWY?#029
MRKB[0)5^'P.XFM*I)S!!/\=H^LFF^7\#(TWO6P!G_7P9:`&*@4:;U#SQ*C#"
M),!*(%N7:4_J^WTN\#&0:5HW%#BJWU_3\Z_J#UB`Y_3&E^G;\U:MG$;@2^!-
M8)3^K^`0$`BX`XLUSQ+=9_T/8KM#XWR,N"\`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O,3`N<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#$R
M(#$P-3$U-#,T,30W(#`R-C(W,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!)Q)1$%46(7MEUM(E$$4QWWJI>>">BAZ*>@"08$8
M@?70%DA4%)214'332@*QS*"K=L?*,KQ@%%Z*TBC3-KHHUEJV:1G$:B!M1EO;
M9I)8II9Y\G>6V7;=+;;(*.AA=KYOOIESSOSG_S]G-D)$(OR;[\&R,55N55=[
M7[).%DMV=K:T/'_N'6AO;Q?;W7M2__!1X'J?C=++UV1X3IGHP,'C^1*7D")[
M]AV0K6F')"(JVB)',S.EXT.G!+C]7M.?KJXNN5I5(QDY!1(;MT)-V5PO975"
MHG?6H;INV6%URM3"#JEY[)3D@MLR8J_C)US\G@FK$S?+IFUI"@`M>M?A;S$4
MG3DGH#,_=J64VNURK[96=^";P!9977?_OJ(^9\$21<_I='K-)R6G2&]OKT[P
M>#S2U]>GO5H`@]X^D:3*][*F_(U"O.I"B_R^;?ZR`1@#E6[;[LB&I!0)VP!X
MWK'72W-SLQS+SI7Y:]=+XG6[S(Q9J.CP#+>"#,`0/%JO5ZD!H(5[X$T48)^5
M=THJ*ZND\4ES(,PTT!L9O50_C!H[41>.B9RM%)PT=;HL69FH/8ZFQ,;+^9*2
M0+8MS"J3SI[/:H1SRB\JT?=1<S<*?*9G'"4%8<`A^P^ZW>Z0H#D<CJ#QP3O&
M?]P`20SV*1O[SQX>A&V@L:E)C["XM%R&7'B@.J6'$Z@<M;M<KF`FFE9PKLR7
M.5.;/+(\+5-FS(J1:7,6R9:'SP2^]/1\"C:0EW]*O6$`[^E'<C7YL148R+?M
M!X^I'GAN:VO[QD2\$;;)GG`=RI+AH30Z(*OP3(]FB,IGP'AF(5[0`]N`[Q45
M%=KC&46B"1K/`5N(S'6JU1&+TS7DT?'YJD;>Z0&1<=YQ:.CN,S!M2Y&*A])A
M1(1X")=W$B**G;!L9["82(PLI#@0<LY=MR(]+J]5$PL]W#AK:Y*!PM,?)E#X
M0!:OA$]/N'S'"`N'KK\86HWHW7\PE)R9$VK\+Q73GVS_;@!H%UFAU8&)?E`"
MH-:A(+1^H]KFDRIUC@!('L@5O4-;QDS:(L514`9J(*P`*+14:Y.EN.@0`,%$
M-;R5R>LV"U=+GL=;^M.>]8'63<9Y9LS2X-$*3R'^J0"('(A-IL,Q`?%.`*=;
M7JOA=>G[9=^56LTY"9MV:Z#,V5U2)N7]$B5Q@5181X!#8"8'7;+>5&,\LW-@
M)Q`R)D9?M;Y5R+F\ON@7.9P@Y9"6X`AW&-[Y;FP1(%=%4Q0"G!NHR>7T0(93
MGC%`(!A@]\SAK'&&(\Z8QAHVP3P<PP/#'>R3RD'*'$=``.1"B,1.#`J0"V,L
M)')*&\Y!A'DT<R0XQK@I@:!$$#36\MWTY-Z01V!W=6OVIG:P(TK!R5*K,IX`
M<QHZ95AJM1JA/'`U)DF#!$:?NMYH'68^N9?*P'QSF?LA!Z@`[G>=6DI9?.+1
M)_W/P0Z0$-\A&\Y([F<='R5F1['OXFZ"XV\!]@B0[]]S'A#`NZXO6L^X76*@
ML;5'+'E>Y^R,=Y`!6N/<!(=SD,,Y?."=^7R'L&$E(HKJO.0,*2PL#%I@@L,Y
MI,(!"H#A_E<<?Q1Q/C=^:]#W7\Z$@]7^!_`5VL6\7X@?!&,`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q
M,2YP;F<`````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(S-S0@,3`U,34T,S0Q-#<@,#(V,S`Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(`
M```9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$CDE$0518
MP^V7VTO441#'_7=ZZB7H(>BE0*)Z*$@C*NA^,2/,RE(Q2K2PR.Q":DKJKJ:[
M+KEKFM6:I8EWM-0N6V;D#211,T1%)C^SG'47==G*7JJ'L^?W^YTY<Y_OS(:)
M2)C_TI^)B0DI=%2([T/RE1O2U=4E)Y/2O&134U-Z.CL[&WC?=\7VX*'L.!CK
MY9%77";9!38Y<")1X!7VZ4N_GO3V]LY+";;T)^>>16SE3^1J9KZDI&?)Z^YW
MXJYMD..G$N8I)R<G971T5#H[.R7%6JK/H8M8'@(4Q.;6MC9Q5S^3``*T=3VN
M46=LW7E$>GH^J@5*D'@A5=YY>O00YY0XJV3]YNWJRO'Q<2\;3(JK:9:9F1DQ
MYK+[1!"6LTG)ZJ"SSFKA??G,_"4&8V-CDF^]+ZXJMY`;&!HR@\L9V?*DYJ7F
MH*.\2KK?O)7<0H=Z*2XU0U:M62<+&+2_ZI([><7JZXRL`GG_H4?2LZWJRM:.
M3O5[0TN[)N;MG$)UUNZC9]23/DY9.?=D:\IUE;!BY6I=/&^)BM7=K(V1^V1;
MY`ZYEIXN`44Q,O9-HF-.JWI#0T-"Y5RP5TA#8Z-^(T78"=.B/N"@HZ-#3&&R
M8S,["<!>6ETGM77U\N?#^!<PP./46U-+FX*1<6)(#&+B+VI-DGTD%NE<9'?*
MV@T1\G5D1((R0!H91_HV-K>*L\*;RH=CSRN>D40F+P(8D#1(06*^W257;N<J
M%K-(62[#"&U(9;0$+7P,^)!QUZI%!)/:IE:M@Q?U+7J16F%!1YU`"^SX&""!
MB]B-U(B],=+7UZ=%Q$6C/HOSR'W'9=.V7?,,!@8&M$!,(;$C(?S8:>]S^*;Y
MXDI(55K*?8$3P77\06D;,*0N+CF?RO#PL#Y#LV@40$US2/S]BPD-R87"2O?B
M46`-#@Z)800^$W.#KDES(,,.D"R9!W'GX@-*%RQ84-[9%OD+J_'?5`"XH1?3
M!*C;8'"S+`K0:<$W2K+84::Y3,ZS*%4P@(;*[.%TN7R3PV\K0#U0]S14T`KA
M[F?/M6/3@/G&6,G(QG?0"D@$!@PL%!67R"\I0"%BM>GX"&$O*GLD-W/OZT(X
M^`N`@W2`%0JH0G/+[GJJ7F,V\1^9EE2`N!)3X-)J*U-+F?W`:,,4P<PI("9G
MT(*06/KQ@T<1E)V1!,50V'069DB:P_[H4POG-Q*JP%ZN`Q!"8`2NPX`I&6M-
M@\#]*(,0\-[C\2CV0X-2\$`(D(U!*,#.7?*$$)%7`0J`O%S`[204G8<=UY('
M7*0O8CE]`VN@P>58RC`&'6&`CL4=A&*UX<V>FG95##P&A(`XH0B6`<#T#5S+
MV%U:ZM!%EE,%)!TT>PX=%8O%XCV;Z\'LF9F9NKB+Y5'GDO0>WJ(S3$]/!Q^A
MZ3_$WVC)X)=8\E#KGDYIYK1;-I>O-[.@P6/T+MX_]P]J+S.=)N0JH.V@L1E#
M*FL;-<;^F4QOQT(F4=[)%V+M3\,9-#^E0$)5G9:.:66C$]]US"5N1J&;SL?Z
MS8R\.E?,_4/SI\'=\/+_UQ22`HP$N#D8FOT,C0GC_VZXU/H!8$/SU2\-594`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$R+G!N9P``````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0V
M-B`Q,#4Q-30S-#$T-R`P,C8S,#0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8`
M``$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@
M26UA9V5296%D>7')93P```3(241!5%C#[9?+2]11%,?]"X*@38L@B"!:U*9%
MM"BH121!B\+>%-+#,F.PIJ)1RRRSQ*B$,NQEF1*:D:-E.AHZ6HZFH^58-AC5
M]*`B%`I<B)SZG.'^FE\SAD5!5(OKW#ES[[GG]?V>8YR(Q$4N_5-=4R^7RVZ(
M8Y<K+#V05R"Y^86R9O..L"#7VRF#@X.RI:O??M_24>Z^+6<NEH@*9LR>)W,6
M+I/%*S9*_-*5$K?5X90-I6[Q-K>(=25R<2!*)_:45%1)34.+G"^]+D^?]NOW
M[7L/AD^=K/:HT67E%9+<Z)<U6;GB\_GDXZ=/T6;&-'O,!TZ=*911#Q"\L\7E
MZAY^VP[DG[LB1&?Y^F0AL`]Z'LGUFYZO<<@[7:0_(N2@B5RGWQ]64]_HE=3Z
M-GG]^I4*<37QR,FPAHR6;AD9&9&DI"1Y]OR%IHA4U=;6R8^[^3,KIK"EM5UP
M#'M[`@'-WY[,HS(F!=M2]VK2J^N:A/`U-/NT'C>G[K/V0T-#$C,1K*:[/@WG
MIAU9<NU&E<:<=>KB5:T>5_8),6&G8"P%A6T/9=K,65I)*](.RJ0I4S6BRQ(2
M=)_4&])/SB!'@64!:>#2MM9>R<G)D?3\`MG9V"$NETO6%57(!8]78P$2*-WN
M[FZ["R@P`ORCCB/C$@P&K>^`X?>G\<]1`,XIIA]60+Y!$)%O[^A44GO[[MW8
M*C$Q98\6%`I`.%1)58)/:N"["@*]C_02I<PGU4?Y&K"C*";Q&5;@$/5/.5.R
MR<X#^HD;Y!\%+"RT52):01N'0)ZI>U_[?>GK>Z**X2+(&06X"6E;"C"=B/,Z
MK^(O"G$#FD>V8,DJE;,'L>#"YD)BY1W9Y$C50&VLO:><-7'29%F??UYFSU^D
M+R[)RM.,H`SZLBG8G9:A8.KHZ57_@J_>R/L/'Q18$*(!&7M`9@LB%R%!$+G_
M5I/ZO>IXH2(2LCQ:YM:+9A^5!2`+DX)$(%M\-PQE4%H7""HG#`\/2Y4_H/LH
M!?QH!*%0R':`WXPL<O\7P?G?,H#BI?\#/1`"9@$[@P,R,_K\<@.`*O@%Y_0Z
M)B3PSB@!SOE.-X;"G.G9BC2@_&W%_90!AA]Y@$6'@J7Q'KDA'"+!HYR'P2`?
M$`T%,+V-V0#`2$B+2TK5&[B5A_`63Z%-E-/Y&1?8.](.ZV,\CI&!QT%E1HPR
M]TD1^B"RR+9K>QS>Q0O""S/JC/*E(_"H40R=XB',R)R"K-W_0!_4_1<=?,=@
M'C1GB!)Z,1)R-"W*9@"$R`4LYG$N8HCQDLO&2Z9%'B4E]#Y2PED3#>J`15_`
M*5@8.<9C@)E.;`;`?1BP]F:S\CUK;LIN_1PW?H+,7)R@%,\>.=1O]BCE-\X@
M9[&?OB#>.F/VD/+`P$!L`V!V6!TRIB40*KR%V5<?.RU.IU,N-+:)HZ!(]U0Z
M.27TAVY[M1=!V-007K*0,U<C9R(<M0B[GKW4?H1U3(LT.2Z1/WH3U7^IM4L?
MH5#I#F:"!((8`A<P#!HY;<K(T3,J"NZ'WJKW"^/C-<>950U"35#)**.?7ZWQ
MZ)C*OM+MUMY'CMESE]$6P](K/9IW.,/(::B172O*`,*4DIEM_7=A4D(C)26$
M%`5X0^^,5))1WZI]E+29W'XK)X+_F]$?:<!GUMBJN:H`FI``````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,3,N<&YG`````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,3$R(#$P-3$U-#,T,30W(#`R-C(W,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/````]Q)1$%4
M6,/MEUU/4UD4AOF=7/$+N.!&TT1"3!@3/\8I6E`TJ,21`;4ZQ$"LM5"4"I4>
MI5ALJU!;I7B&MF28$!(2\GJ>15H@!05!XQ@O=L[N/ONLSW>]:[5!4L/V5=LL
M+U=4.WB5+:A4*HEGPYZ?[#AP_RDIF4QNRKC]]U.Q!A_&=?Z/SJVK+2TMVE7&
MGDIRA8^:R;IZ]][5AZ*KKDM7=TI86?E7:VMKVMC8T*-P6+V]O0=4<?@+3V..
M*N6R>J[?4]V%7"ZG_`=7D=BL>GK#MB][E^U"-!H5H9].Y<V]?'%)Y_P#Z@\^
M43J=WA2SOKXNUW6%JUU=EVHN[FJDXR3D\_ET=&X>2@`.3DU-Z4`"4K.O5?;P
M1S2&'SERIK/*S!5UZDR?3I^^5@-:G0!06'1+&@S%!'((X\W^B*+C,Q9>DD3\
MEY8V[_E\)PP\-20EG!=*I><5&DVJ\\H#3_ND"N\7S9KQ1,9R0Q*?/<]J>B:M
MQL9&52KE+P<)DX>&AA2)1-36UB;B<N`L@'''<?3]T_@_%T#0(`<JZ<!(')^<
M]0JV9'E.9=[IXL6`]B6``H9&^7AL<L[HD&+O"`0-7-3R9P7$XW$CODS.U823
M-TB#/+@5^&(98*H3`,KF\T4K'&";>5,PZ$(SCZ..64$-O)Y;\"Q<,F[:09P4
M"]+1@J#^^Q.:2<VIY+E2K85;=T8U.#QAQ76S;T1-34U;`N[>#5JPXD[67E*Z
M"(,->5*5G*$D'$DH>.^!3IYLKZ=N4K:ZNFHFL^<Y,.!584^/5=]VKMLWD&*Q
MF+J[NTW(=C;=MP`R`ZU1QLW-S?HJ*(="(7/M)ZW&7P9\-P.H92J+NE_\N&BL
MPQGT1671>?9"VJ$,6%A8L!J@\;)03*>&J7A2_IQ#1-#>Y2M!=70$ZCKX5QDP
M,CI64PK'PBO,BE#E<'C:6.^_E66+Q,B35[KQYV,;)\:>I:V)7PCTZ=BQXQ:Y
M?1E`"*$./&;.JL[(3BJGR9=OC4:9'"`W%K\Q!,6PI4T2W@C"&(*Q+)CVK_X[
MUIX@3>1O3]76).Q9R<B!T*&1*>-N&):N\F:^8-,AS6+P8<*X'I[GS!16-E<U
M37Q'$X&Z(=2*MUXDYVU>8F"'RNE>.PS`:X2AC)Y0G5L))Q2.A[0UWA-V%!(A
M%DJ)4/4.6&!5_REP5AW4P,>N!E13`,IA[C-G?[?+]`WV/%GM[;\IT-GEG?G5
MVMIJ3,]OB)I\<\[B+HJX3U.G'W.7]@*PCXP'\OF\_'Z_Y1;#4<*>UH-2WGU3
M(J)=\=\+[XD>31.PL<?[+W'#D3$:"C&$L!,)O-]KHOW5"WXH`SX!F79C/N?C
M9-D`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\Q-"YP;F<`````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S
M,S,@,3`U,34T,S0Q-#<@,#(V,C<W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&
M```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\```$;4E$0518P^67_T^2<1#'^R/]3_RAY=QRSBPK
MFN:71CF+55HR7;*<D?@]1"E`4#10$24%%)3,S3G=+EYG#T(@A*VMU0_G>)[G
M/G?WN7O?^\YK(G(M7_3/\O**^/PA"00"YV_?3P8DE4K)[*?0A:K9;);<D2(;
MT>V4M-Q[>:[A\7AE9'1>3&W]4E-3<ZYFM5JEX$B^V.UV*;*9W$N+[;U+>@>F
M9,JY*.ET2G9W]^3Z]1L7FKV]O7)R<B*12$3*AAF+Q8I=E)."!^>'#W*I`H&-
MC'HE%$GDDI!3V$FD)+(5EQ>O)^3+=D(VMY/".U4X.CJ2I95UZ7KR5C9C<<UX
MC\6AY<A9.#L[DXV-C9Q9A\,A%HNE^)K#P\-26UM[^36I<-EK7D5*OG2Y%K16
M^_MI.3C8EV>6-^);6)"*!L`=Z8K&DK(83LJX<T5_/WOAT+21OJY'3X2D%!B8
MG)P4ZY!3O2V&8^(/;NHS.<<H!VWOW`K*8"@J_0.S<ON.J3B+-IM-P./T]$PV
M_'TY/#Q4)7X#8A!'RU"[DE<(A\/ZH;N[6SV#'0R2?5"(08S\4A4PQF$*WM/S
M5*JJPF^7\>\P0-+(`7U>E0&PX)P/2CJ+0I!(W=O;.^7KUTQE),;C<2T?W3T]
MMZ;@P>##SD'M5VBHK`&WVZW0A19<WDV%-0T.*H$RD;6VMLKQ\7$AD$`>RK``
M!T*K6PI;(#TVY=$H]K*1?5[?SD:XISUB`$H-@'FL&]R#Q\7@JE['('98E2O!
MK,_[)J2AH>'"`#U`LN9]J_H15DMFVQD:PJCQ#B=$-#`PI#U1D`.,\(%&8230
MLJ>GIQH!5X#'Z`F#RTHFD8YK:FJ21"*A2B3+Z#R7:TYQ0>B034D#\`(">.KJ
MZ@22)%E$P&\<&,8K(I%K$#8'D:JAC&=P0<CY!%)5,Y7S_/>T\_\3`(6D,QAP
M!FNPO-`1-``[227NNE(`F4Q&T41KT@"0`FP#ZX2SY$#[\LWG7U?:>MPS*/7U
M]47CZTH!T'T8-SB2&S.QH;J1,;^RUK?#C+X?GUG2"<Z6!)>RX[1W]BF'_KR8
M71H`K<]MF:?P!K=ETGN#&^)>6%,:9'5ETT)X)A`<O[).R-:7'0V420")(3`E
M)8)R&:^4JN1@I[Y0Z,3<DHR,?U3NA2%94,/K6SI22+O-[E&NAA5YE_ZQ`.&4
M3""<@Y*A7DK(=TK$2G+O?KO25%$`<!BIIJYP^D'F0`?"S.RRV,=\RN>,)8(A
M[3@T^)XR@05#!RP@!('PCHQAZ^[=!TJX)4M`:D@_E,T@I7Z,,#8R#C8WWQ:3
MR22L/CRWM+0HV?+<V-BD9UK;S"HW&V[I=_1)/=_0BT:CE<F8>N$8'H7!`1'/
MB+%_E1+:$'W.0:-<"(=DERF0OU;^$IEW='2H<S)AC!D$H-(A``I'!&P81Y]S
M"+5FHO".`!B0O\V$@)7@Z'6"(@A&%[\))%\7WH`/RA%45<ZY`3A`^&_$V%R-
M%?CG8?O'9@%43`!D@9H#-((HE>)_9QC]*?D../F$_62!OKT`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S$U+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<W-R`Q,#4Q-30S-#$T-R`P,C8S,3,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8
M,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```.1241!
M5%C#[99'2V59%(7K[SEWY-")(P450<PH!G!@3IBS8@Z(@EDQBQ%S%@/F@#FL
MXMOTLWUE:KNDF@:%R[OW>/8Y:Z>UUP])/YX_3R_KZ^MZ6HB(B%!=79WN[NZ<
MMSN9?+RPN+@HIX7+RTN]:O+J$8^/C^KIZ=':VIK2T],5$A*BSLY.'1\?_[WS
MX>%!)24E&AH:TN#@H#P\/#YQQ==M`$=#0X->;`!]7U^?1D9&E)B8J.WM;6UL
M;,C)S8F)"5NXNKK2[>VM2DM+G;Q0?7V]+186%LK;VUOO@MS?W]?7N?G'#["Z
M(VQ$HJ6E1=W=W8J-C55F9J:(\^'AH>;GYY6;F^N<Z_O[>S4U-:F@H.!I<W-S
MLQ4'E9.=G:WKZVLKF.3D9$5'1[]:+"(GY"(L+$Q^?G[V#9JVMC9E9679P>_&
M`(/S\W.YN;G)U=75##C`Q<5%C8V-'Q_PGV?A^X!?TGES<Z/IZ>D7J7OS`(SH
M=JJ2JLO/SU='1X>FIJ;LFS(O*BK2[NZN'>[4\!BEI*2HO+S<V`$N[>WMU>SL
MK&)B8JP_TM+2='%QH>#@X!?]KM/34RO=A(0$XQMN'!\?MYJ'0:C&HZ,C!00$
M*"@H2#4U-2][86%A065E9=K9V9&#P,?&QJPW@'QR<F*]45%1\2;CV`:Z#_\=
M`:0WX'9W=W=]&$1\]/'Q,9_A=Z`#>W5U57%Q<3HX.'BWF0P!D<:(`!)<2(5X
MQ,?'ZU\5$C'@E_1]-]/7/]\`_C\`:#":"DJ#:&"KZNIJ)24E69O3O<S.O[C3
M&I)W^*._O]\Z^MG?VYV,$1=!"=#BYN;FDSQP_!]Y@%8:&!A03DZ.:2:D87M[
MN[R\O#0Y.6G\`WWL[>W9]_#PL*DS3T]/)X)_%0!>@APJ06O-S<TI/#S<C$='
M1TUNP,F!@8'JZNI25%24#7VD2%55E3$G#\,!-EU963'Z1>3"Z>Q]+P5V.8P*
M:G[]_?T-/<:.T!(E1#R<Y^OKJ]345%/01(P]/*VMK<;`1`)MA";Z5`W`O,O+
MRY8.+CP[.[-PSLS,6%18<X#!8^8)Z4"],90`Q*!ZKJ(_-90=AU-`>%9966F'
M1D9&JK:VUL*]M;5E`PM`R$G"#>"\O#PM+2U9L?[CH?Y:.@!"U>,5.2XN+K;+
M48IT`.D"))Y2>$Q+ZB4C(\,`HV,=T^2WVI#"))=T!H5(1'[=@Z!`0/`>&AKJ
M)!Z^F?`;P%O/3Z5H=A*ZS:EQ`````$E%3D2N0F""`'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S,R>#,R+S$V+G!N9P`````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0W-2`Q,#4Q-30S-#$T-R`P
M,C8S,3``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$`
M`-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P`
M``3/241!5%C#U9=M3Y)A%,?]DGX*W_BN^<9R%IE:81M-BE)RN=&#31>YR$'V
MP*(&4T@#"C,J(LTH`T2GGOP=O7CP!K*G96X7%]SW=9W'__F?8XN(M%0O_5A:
M^2I;6UO2T=&Q^]1FL\GX^(0XG<[=!]O;FU)SQ2+C6?2UW+K]1$^U!(-!&1@X
M)_:!04FE4A6AH5!(+#)F8\\EGG@E%IEW_,_D^H1_9SV0W&I>L+-0VI"^/OON
M*?1X/!Z]:7;TQN/Q6A-QA/W3RDIC/^KZQ2H6BU(L%L3E<DG=`_E"4<;O!,5[
M+RQ.E[>B(IU.2RR15JN]OI`4=B2->*8D%'Y9B8/#X9#N[A/B.#\H0T/#TM-S
M1GP^7^6`<2V93$I[>[MDLUGQ>KVUD<1O=A+9U=5E=1,U)FCF\('B<.`XF;6Z
M^DUSM9HORNNWR_(P-*<>G[]P3?"AH8!P."R)1$(BL06]-'XW))>N3"JPW%=]
M0B(^+'^1-^^7!3=,6LM@2"Z\DWRQ)#Y_6"_PNU0J26EM3::#,;$[;LAINT=S
M@.#>7KL5CS,S,S(]/:V6@%[SG30@B!P5"K5PJ!'`@?T^8OKFYJ:NO;^6N;FY
MQED@4"0Y$`B4R^;4J5X!4B@`!$VS\-MI/!P"\#?W):>`@I,V-C;DP`*BT:B`
M1FJ0A1#RW]G9J2EL*H"H0SMO,I\E\#BN8$(`%3[IC\A9NULRF8PU"R#.7`Y&
MXGH8M!EZR"ZMR/KZN@J^>7-"TPD^R@(BLPGED^C\@FI-I3^*K6]$:82+6,$[
M8`[W`'5<*@N@\EXN?M"J0Q"XA\/QF<M<Z#L[JG7`.P3!SQ4!.T%SN]TR.CJJ
M9`'RP#NFPE-0,.S.)=[3.BQ!'!L;T^(A"Z:\*2),11C!HVI),0HM`CC(,J3!
M/C4UI3C8JPGI[^]7H0BJET8M(A-=EBD<>H'I:]656!=(<,(^+6H)SV#<'R*1
M(.$G@>2W<8'`5=-U0P%<)J#LQH*VMC:UXG"6\S\Q`$P15\+":D87?\0`@/LX
M^%3\CZ*2^_I-H08!4)>4822V*!<OW1#:KZ&C/V(`.)Y/I%01<P7[J_0G\05F
MM6%>O_50(!)8:.;%6ZWWH]V7M=Y/]K@4>?MQ?V`#8&2\@9E@J.1B5I4P!MX/
M[E(>!$3[)S+0'F2#@9FEG'9PG@\Z+Y>'$9BMJ0&$V;1_6"P4>:'S(8(P`H9'
M"50)WQ)ZH@&[4>TH(#6D`,,Y3\KR^8)R,?Q\Y$B'DI[%`"H?;U#`*,$D@"=X
MC/=0+>]8<#,DCV`H%QQP!D,99J%?C.2[X7&>$26FO[KS&X+@,L9E!B06AMR>
M?*K>DM=C)X:4[S$,8\$(N##AYAR*C]N&51G/6$S:8(5NU-K:J@-T0PPPPG"`
M4H/2Z0$81XB)"CNE!SY@9UB+Z$%Y@`X6!WC<A<W@5GYSMCKT3>=+!C,NLQ,N
MC##DC&`&:GH,XY/YSX/H5;<)2A7%&(!BT^#H64T-P$,60D$O'II9M'JAG/[%
M.Q1C&`"LGG?I(`"3'3D_58:DPK0?HH)`PJ[3QTZ)UFLBI('4L?`6D/XV$P(T
MK&<VP&L6OTWKY\-T;V9I\()R<$0*]\;B7S>`**",,))GAI=ZXR(YQS#21LY1
MCD'UR.>O=$,\-O.\B=)_T8Z_`P3>G$`[&69S`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,3<N<&YG````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R-#0V(#$P-3$U-#,T,30W(#`R-C,P-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R
M90!!9&]B92!);6%G95)E861Y<<EE/```!+A)1$%46,/5E^UKU648QQ=$V#^@
M0=2;$@+1%_9"I!<;1+&,S!BU3`M"9^I8/LSEXT!/<V[H(7?<RH=SFMO2VF/3
M=IAG.D&=@@\SM2U,6F"+ZM!I'&@P,M:W?2ZYMQW/PSP3#5]<NW^_W[GOZ_K>
MUWU]O]>]#$D9X\W^5/@J=>7[&QH:&KK]=>7:+2K_9*]&9_3W_Z*_HX^,?8CS
M<;WOIKYH:!F;<:CYB(JW>V]_N'7K'P6#;?IX?WV\CTM7>L7ROO[?U-C:%COA
MA<R7M,-;J>:V#O$<$W1X>%A//OV,9LV>HZP7LS5CUO,VQH4H7/.^$L).9:,/
MO;T]ZNZYKMX;?38>[^R,#0%J$MAQXHQ(59P'DM':WJ'5ZSV*1J.Q$W(7YVG>
M@G>TM72WR#R[B9G`![8V_;F99EFOO*Z&IJ8Q#"M'XF(7SSVNO.7+1W^,P7#U
MPK-*N<W)6L*/'*@[V)]_#5ON@J%3!B_GK47:N+E$D4@D<44QX9O0"9T\=UZU
MAYOL\'E_;^F'"H?#J8^2!9NVE:GBLX"-I'67[X!<F@_6U*1V0(J)Q`+/SCT&
METKF;'"(S9F;J:0.6AI#VEZQQ_;_8]]/JCX\T]B3XRFUTZ<:DB(X5-.JHLI/
M]6=D0(%`P!8N7O2RUG^^3A3B@>:O'^`Q_O\.X-;9R]>L@#!4@J*B-OAM?#W$
M+>:L.07(Z2J1Y\*BCZP2.6(**ZD#B@A6$[GK?+>-1,4!<IER"\@3FD@$:K^^
M*6B+,:)/F(.J_7XK8Q;X:[\T'E#>RPHV&/0)'5#OJ"?ENV1%D:K\M;:8YSM+
M.*$#>(`3A(O%=`4(Y<A$'I(Z0">9Q&06XXS(D(H15&B9T],X!S`/?8>1..(9
M(400:0:F^R,.LE][([$#^DY>U3X39?2WM26D/_H?55;F4\90V`FIDF[!YZM3
M;7O(&A<-[.8/4Y2;.UL[RZ8J_'O$5#=E$O./=FAP\"^K`18AT7Y_G>:_^ZJA
M.CU2QG?%!:)WMD]7]^5+>CCH_,`!#`Q$C>T0%GF`L-061IZ[NL[:-U+(R5,=
M</2>`*`_@;H&"\CE`'E!HYPA.4@/AGHX.<+@,QS?Y?4:2`HE+0!(4.D.K^W.
M!<`Q0)QH\LZN,8)!JOQ5A?)X2E1>7FK]D.*"!VD#0,8@EBG42%D3S+5ZS*DU
MP=DM;9\UXR]!DZX!G"`#-&2.@(#H#,\$Y)UGNC^BA1)R/02`NWM,&@"I=_J#
MH*'3!"(([YB[>KB;':)'^I'>1/>8M`"0RK**O69H.@$)`@""`HB.0\-`OIT2
MH\(+E^9;)NX\[[0`D'J<$!R'[`Z9XYPY$M[=G0EP[AM@&%E']@"8%@!2C^03
MG%0"A-VY'6)\(]4\NTL;54]P1H!A`,`'8S(M2(@*\>8(EAS\2MEKB@S0JH)-
M]CY_V0=&+X*]O66AJO<]IIPWGU!.\3:[!%*`K*4Y,!?^<]=#H!*!2*IVB`X\
MAPG<.E>T!*U=X61K\5S].YBA8T>GV"5R=<$TXS\72YBQKOY(TLODA`!0,7HB
M`4'M'-)L43(7G%[IVUUB39<,(#C(LYL[:1:P"S@^W@'_]KC`U353[4R=UC>&
MCMMXWYL1E.KY[MN[%IB'IAW_!_A[F:WC0:;M`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O
M;2\S,G@S,B\Q."YP;F<`````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-S`@,3`U,34T,S0Q-#<@
M,#(V,S`U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*8@````1G04U!
M``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\
M```$RDE$0518P^V6[V^3513']\YW_@'&EYJ0F/""&`P!8C3@_!$UP2`8MV1+
M1,3J8K(XRR"BXY=44&/%*1(G`9G+"*C;',[&):Q.:VB8@W7M*M/1='5-%=`M
MQD;S=9]3[K.651P8#5%?W#Y/SW/.N=]S[CG?<RLD510O^UGSY#/J.AJ2)_`]
MW:0W]K6)IPE6CZ2U==LVI5*I4GO/Y./>L.Y=_4C!1UW]>C4\OU/+[J]6Y5WW
M%-32Z;3>CR5F=BE>0T-#FN5S5_,^!=_:KTT[@K9&1T?5%3JFVK5U!:U0**0%
MJ9\,//""Z9RFIJ;*PRP+>\X*]8U-^D.%`^T?:N^!0X9CWOR%*E'H[.[1L?Z(
M)?/+XU&+``-3.'?NO(5(ZO"`$N]DD'`KKAO/BS`/MKZG9=_^H+YP6$]LWJIK
M,K_-9#(2B2@0".C9V&F+OSZP4_E\7I<?YI6LLD+R14UPL/W1`5%CF4Q&?^K@
MY*F890)CGKO?;E5OW^=:65.G(]V]ECZ<E:UBBHZTM;0>,<.G-FY7?^2XXHD1
M,][\TAXK2N=DR>V5A30[3_$?)[7CFW&]&GS-*NJ.\4E[9Y%^9#6UM5I\Z".]
M_N9>=71TS&29U`\,#LJ?RHF#C4:C5IX\*4D<M+2T:&QL3)PKQW;)).9R.4\!
M!^X=R/_,,5X=#L@T'7'9#NB[5YK?471@4!06=;&I:8OFY(#&Q>!P9X]5(DU+
M)<*,B^Y<6=91R1\@4\94FROC%X-[M+;^.7N'W\H2'X:P0NOA3K5_<-2<4/\&
M_P(1$@[?0>E;WV1][SD`*HOXJ7MVQ!%&7YT<+I#[M%'CEI<-Q0/5ZZRL/0<(
M^$##L#/QD@?@XPB.0E:]KL'>624.6'"4W^\W:KK^BX2]D[0;$Q,V%@B31N(=
M?G/\8,:/IL^:@%CI0GH!\J.A&"4DC@WXOO'TN!Y<M:JTF6#-VY(3YIE.^VSR
M9[W;%[;N^W5:`2.:BJ%!+HJ;S0L!%H4\&(`.@4/&^XK,I+5\;#BN2U9B-IOU
M%(!?W.*.JO]E[?S?`4`-TM`4-(U.V_&?'D9&A?PM`.AGYAC$0%M""/0VK<KB
M/_,/,,Q"9A^CC![XRP#8&))A`R).)I-&M+PCY[*#C,T9S.A#.(Y3;EYTJ\W0
M.0.`XC"`C-W]@HU<I(ZP8#L6[T0-F;$Y0&/QI-QQN9L8]TG\<53,[;(`B(8H
M2"]G;,0^?=]C4^<8AT0(&\*4R,@(&\(07(3X#V!\.1T8!K^P*5<2*&O6_0WF
MQ`#$;(XA0!@(1(DQB_3#,&Q*^JD19!0C>J2>.F#!>P#!#CG@86.HW%TR2HX`
M5(!8^%B='O9OL#-D<>MEW;3\;BU?\[A%@=P]F17(G:Y[S@\$M:!YOZ?+YC`Y
M]RQW%-[F$[_D=6::1P&QX6";&:"(//9=U@QV?_*I@<-)5WI";6<R@GN1+WFH
MRB)#%SE9X0*'C.]<_"XF\A(`-2?B6MK0*)_/9],@>P$,]VXBP1&3`2!\;Q\>
M*=%'%QL`5+ZPRT!R1`1%;9!1="^^*,]J"^87LXU-G0&.Z&OF'-.6:+D<,./X
MCLTM)[XV&R8R,O3)T@W=8=U7566%>$5$5)4Z:Z.<%BH>I%R%`4-FBF^P/>>G
M=&WB>ZL)KL?_#Z.K'L#O+J+358IRUM(`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S$Y+G!N9P``````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C4P,B`Q,#4Q-30S-#$T-R`P,C8S,#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A
M<F4`061O8F4@26UA9V5296%D>7')93P```34241!5%C#[9?_:]55&,<__T3^
M)(5%4+^5$"1"B!%!!?5#45#X0R2D(8J1Y30<.9UZO3IOFVWJ%;=QG7?L;K9E
MKCO<%[?IW29NN<EJ:].!HYO.NSO*"QN,I\_K?3G7ZRP)E/"'_?#<<\YSSGD^
MYSSG>;^?YWIFYN6+?E:]\K(M?_$%&QX>-&]V=M:>?^Y9^^C]=ZVXL""[;&YN
MSC*9C,2[ST;_Y1YMF4FGK:^OQ[S6YOTV.79*LFWKEKO[:?G`?3;^\5R#EYNL
M+5YE3SVYU)YY>IEE9@8M=*A$XLW/S]N1[\KL6%F)E1_<:V7!/7:T](!5ABLL
M4EWY'S_Q<`LX0R+1)<=Q\>:SW]O;;[UA.&1H:,B\KO/M5E$:L-'A#N,V/]0?
M-KS-3?"65UH:,KP5W%E@IVMWJ[]RQ4MJ*T\<-Z^A(:9K<CVDO"2@*T<CU<:<
M#H)+<:]KG:LYW\-?\_\QD$JEK/_2.>ON;+-8](2-C?3KT7$=P77GSVN*)01?
M,VYO;S<9X++'CQVU*Y=JK/Q0D5PY>K71EBQY0CH,)#HC%BS>:BUGRRRT;Y=E
MIL_+&$;D0=XBN#^@R8-[=NI-BK9MML(OUDOH@XC`KD+-:XV_ON9D)'N/D9%?
M92T>CUM=;51O1"@2DCQFI"JL%GVLKLX:3S=H[<3$A#TFK[!HP+R)ZZ/&4^[8
M7J"GN7"A0RU(!]6IVS>L/E8C^(%TT/_Z:ZNSD0CTTJG?%'F$*&">OO6+U4:C
MTE_L;+)75Z^T<_%Z^VKS!NN]V*S-!*`,))-)2]_JDP%H@M!E3%320@#H(Y4!
M12)AC<'Q\7%AWDLD$C9SLS5KP(]Q,;,_YFNT<)#8U)^#]9T!PA@C'B'<VWE$
M0MQ_ONYC`>KVC9C("Q#1/U6UW39\MLZJPU]+#TT)3,0T7,61$8"T;\>6')`<
MF-`[,`$D#`P,#&2!!)S#%8<EW!F.=SQ/"]=7A(*:!V0X&'")=^%6.D+C3V>$
M-%`GY/GD`A+I@U*DJ:E12.SN[KZ;GURR<K*081?J$?8L@NG1R.(![AE,3DXJ
M:R`$._%*G(NR?'I"CXXP!,>,B7_&)%?HBLH)D&"+-<0]\>_L(B`PQT;\4$6@
MN//7[^(^TAG9F?&G:S\4!_R1'-,88L&`FX=\VEI_5!_042'1!_8(X'1[60>O
M8H\+Y0[`+2'9]-0555$P&RB&!JD/83'*!.:I%:&$H9];-.9`;BVZ3]9\H!(-
MKL$C>`!.9AX>Q@-\+U<^\0,?L3A]LTOE!`<0#T_WZ`#<DG*#>0X`V;&.,0>`
M>A%(CPNPK[AHHSX(GT'!Z&#1HF\*]6Q\4R4BKD=!>9))M=AT\HR%R[_4!QCS
M!&29COBW&C,7.K!)?70<SLVAAZY=GWT\`U2/CCQ`VB-&\(2J>0Y`8.%63L<'
M<:,31^?<FI9_#MP,-Y,[W!P>>.^=-S7'&HHO/H;PYNAH&;M`A9!%Q'1("4Q`
M^PA/X.KB7$'F)R?RBLLY3A@S3SY2*O'W8H-:.E>?^6F$+*B:S1_35SXB!H`+
MSX!;F&`!XO(4AO1?Q#=,;E+.RON(T[O#TW=[\@\`M)V0RJD'<C!TJ6=J:NH>
M`<\LY)`(\'$8IT\P+=3GS[,7.ZY%X`R>_H%_(IA$7/_?]`O[^;H'V5G,!8_-
M`?X&W&<(((<3Q.\`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C
M;VTO,S)X,S(O,C`N<&YG`````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C$S(#$P-3$U-#,T,30W
M(#`R-C(W,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-
M00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE
M/```!!U)1$%46,/ME]U/E%<0QO?_\ZK1F]YPH8D7-DUKC$T,&&MM#*T85"`B
M!&57-$(QE$I;K=;X@2`L^\'GPG877[HL[+*N$%(()<#C_F8];S$V<F%C3.5-
M9L_7G)DY<V:>,QN0%-A.]O/+G;OJZNY1)!I58'-S4ZVAZ\KG\RH6"Z^S^UO>
M/N%Y,XI$(FIK:U,4H3MN>8,!,P8&!C2=+YHY5]NNR5MXKJKCI]37UU^V<WIZ
M6O%X7).3DTHD$DJGTQH?'[?YG57\-PRSL[/"@3T__RK&UVYVR6<H%HNJO5"G
MWWY_H%/5=:H^VZB*_5_JA\YNK:VM*;"TM&1>X@1S<W/&5%C(ZTKHAG*YG`*+
MBXMVI(F)"4U-31G!G$PFQ>;W<,SW(X#[Q"77.SIUIKU'7U36F!<:[X=U_L>[
M^OQ8M1JZ;FGO@2-*E3;@4O:8`#:.CHY:Q-35U>M24ZO^2'L6-;7GFZS]^IL:
M><_2.G3X1&G/EMT%GEU>7I8)P*4(&1D9L06BF+E4*F4N'QL;L[6AH2$]?MQK
M8<B\"<"4;#9K]S,\/&Q,X7!8@X.#1O2QSA'I@1(4F(`/XQ9V!?PS(*NA3"9K
MJ19L[[0K9@U4VY[IKPE87U^W4'ZRLJ6*SZI*2=UH_3U[]RN\H=*])ZPE$@EU
M>'T!#(@J@N3YWUOJ#\<LG/D>/GQD;<W9>L63GD'+X2.5-@_FF0`Z+OKX+EYL
M-3#G>P52EA,@"VAZ^\X]/]R)XL#*RHIM`')FO&<&5H1U,!BR%P$X)A=BT;CF
MY[*V'HO%+#<V-C;*D,AF)D@H8!FK2"2'7P@`NCDFR81#?0OP`9YV&0DC^.X`
MD#YK$*8[[,]D,F4!9!0:T8)D_.&RT&6ERT3&9"R"?0MV<^'=!>P:\/\U`.QK
M3A9]:HA[]D+/S^=T^E)(P3]7;9ZVJN6&G@X,&3IU=-[4N=YQ7?'^,J)?WQ34
M6PT`#@J%@J4[F4I&`WV4`2C[[OM:PQ#6F,^5YK_ZMM8J@7.-S7KQ:@QL/DBD
MU#^S8%48QC#_Z<&C5@V`!L`)R.B7%G2`$ZHQ<,9!*\+Y(M%AVWSR]`4#]);+
M(9NGD@-:04T^>##TQ6+12I-/]E4XS#989IV*`N*@H+!!$:\)<`PS!@"&X)<S
M@"(I>+7\-$&4D^P9'9LP?'>/AJL[;_W4;6/J(0SBPU#>!.2[2A.H-SAW:`S"
ML@`B<P58BN407F$=``7^[1]`R3/<.WSA<!G>(0["F`K._?6`&',%/!L@.5XW
M#V`%`[S``HIPD;,6E.=-03!C/.0*.?H\3A#Q`;'&'EK&U&(<"(*??<@FF,T`
M?@@*K$?!]B?%/2NTS*'(*74*'3^$LG^;AQ^C4.P*?!>(?CHPP!O<KZLRMA-!
MXPB/[43PK:ZNOB$'0KZ?!;M(^-$;\!)6'+R<_=AYK0````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R,2YP;F<`````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(R,C$@,3`U,34T,S0Q-#<@,#(V,C<Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W
M87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$(TE$0518P^V6WT]45Q#'^7_Z
MV`=],4W:Q`=-K/:EQM;4&$UJ#.H#C147$:F"E1)U<0T(Z\("6=!%6BIDM8HD
MHFPU2(H_L`7%\$,M2+`1%"%^Y3.;<^%63$SDP9A]F#U[SYF9^SUS9[XS&9(R
MYHO])!(M8OV]L2ZU&X^4:'QL5+>[DWYUS\2W<>U:4O?Z>O5;8XWPE7$@)TO!
MPX6*UT45"9>]@X\%%3!]\'>SIB>ZM&G#.EM[NA-S+F/!@-HC`;6&<TS:*O/4
M&BW0Y?.->K=7O+]"1\=5]??WZ]>&J`E!)!">PE_7&_35FE7*S\[4Z,B_^FS9
M4K6>.ZF9F9E4Z+D:LN+S)7HR,JA$4\J+>6B]>-ZNZ*YY\62^7?-LQ0$MXBW>
M1Q;/0:RV7#NW;U1#?8F^6?>UK9.C+994>P*[+(S)MN.Z=RNFE2N6FU@8,29A
M4=KT[6J%BO,LG-*HDNUG=>)8H4(_9ZEP7[9]A_N]G5KZZ2?V$L]!3\\=18+[
ME;=MK1I#V3J8M=XD69VKH[O6F_#,>2@OTY#B\,7SYRD'3\?'[</%RXM24OJ3
M3H7VBC1%ZH.[U52::\+W:ZX-6=U\8%\A[4`95/+_UZX;G1H>'K;JYIE\X3]"
M$OD13"?-@/2EZEGCL?V:G)BPM'TR4.>E,\_1JJHY!WB#["[]4:^1H:M&>&3;
MJQ?=EC"QFDJK#=*=<U*<]/<<P,CD/CD^^=\_5@\HL7<D9[-W5G8T7Q>:3QL"
MF,8<D,\<L*(,)^$=@T.%^?96.@.&G`\-])DQ\3`'P(?Z*93:PSNL:"B>^J(M
MQF.NL#AW*]?S$+R<FC+(Y\KW>.0WG^<A0<?WCO,I)E\,B#Z-S%4CE>BJD4JD
MQ%TEME066=/@Q>E:6"0':0`?'X#XJ;`TW:*2([FBW26:@GHY%E=%:8EQ(%S(
M,SJ.0RC$@9ZP4=ZCOBH[YQDNN=MUPIXY8ZT.!SP>61``(P+<NO7[[W2FX71J
M1!AK,RYE%&/:`A3"[`A9`0P0Q<7%UK"Q9TJ@^Z/#-(8]9X!BW`"X#P`;<"\*
MKZ9ZC9LKR@IL((6#&>L"/V3:&72*<VG0@#)50$5,=M`QNNZ%SKXZ\HM=!GW`
M^B+`#6[=O&FLRDO@;T9&F)/9YMG3(9MWX#!F&X9OA/^=?[9I[9=?&&7S'QKG
M]O'2@$THZ&"'/8"(*@.MKZ5!C(27[\P`Q82/4_@?`11.<<#^[LTKC>X!B"YG
MZ#A;]-S^_#VBBQ[MT`>`\-,?N"T,#G/3'J#^]JI]J38PVQ+XCW1$]]K@AO"?
MO2LU!2:7:P^98`OS.W&?B"BY5N+[!*[WVO><#9WUH>B<0X0]@#4?__$-,8"S
M?0Q`"P'$UK6B-P`X$$P0E!X*3!:/'PZ:/!Q\H.&!.7'/K&\39XL?_.$7_R[T
M:29,`W#R&NY5\R#"A@;.`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T
M8V]M+S,R>#,R+S(R+G!N9P`````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(P-B`Q,#4Q-30S-#$T
M-R`P,C8R-S4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!
M34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')
M93P```08241!5%C#[9?O3U-G%,?YMXS_@(GZACD23'39HMLTF!AU(8$$3).1
M=#),9U.MJ;6T`X&N%CLVMAI@XS=(,$&LY8<83)4$(PEQ3D-PW_$Y]=[U"DM,
MY,6R],7A>>Z]I]]SGO.<\SV'"DD5I6)_EI>7-3(RHHGQB>+;NKHZ/7WR1(T-
M#5YU]R>>%^OKZP)C:FI*:VMK1<#:VEHM+2W)=[[Q/3!V5&AM;55]?9VRV:R:
MFIK4V]NK0""@Q86%HM90MEM]R;`RK0']&`\JVQG6;YGOE9^]J_<S\>$*Z71:
MN5Q.^7S>A&`02%?ATT^.:'1TU#SG`Z<X>^9,4>'UJU?BF">__$*12$1_O'AA
M:S!XJ:BPL;&A@9M1]:>NVC%[;US1[61$O_=T:A=/\2&R>P#M[>U":FIJE,ED
MU-Q\03Z?3S,S,YJ;G[<PAL-A"Q_A)"D\`.E4EV4A"B@"Q@K0]/2T^OO[-;\%
MU/R-7WOW[-'LO7O_`&QN;JHGF5#EP7VZ?*'1).AOT/ES)TSJ3W]N:S+2HIIC
M1W7T\"%UM,6]'LSG<P;2=BVD\,6OMPF`#O#5@%_H_\=NH0R@"K*/2A[>HD6>
M!P<'Y60H>0+#4<R.>`#@4@"H=+*-%&:%$LG$ZNIJ'3]^3(E$PMY#LQX`4IA\
MAUO85U5];%8ZN[J,'0"B)@"9O3\KO]_O!8"\X1WR'?:$F'`=P&;?5\:J>%==
M56D`Z'H``BU^^R'6Q\;&].?+EP:`JRTMWYI'5"D529PX%G%Q`0K+CPS5K+TM
M'/:_=(2LP*!MGBDDIY@@0Q<`#H?+470$`C2N;PNY1-AW,Z[AGG;1"SP`4.G$
M4)]5(I7V;B66ECB2ZD@(MBW7PBX!E!WX?SE`=3$90AQ0''N8*/5#RCHQG`@_
M\,S4!U/!6'`(#'7]>DS1:-3E$.B/1@TI@1F+Q=RY9T<'4(0&X=,#^_?9RN`T
M-S=G)'7HHTH#9>S$(6>0@F_I_A"6,TOR[&!`\NC@Q,K*RK\[``M"G9.3DRH4
M"F:<*-`=('Q.A0$<#85"=GJ,P:8XB"[?,<(WWA,9GAEJB1`'V-$!Z#7X7<`,
M81A97%BT<.(Y*],W)R:4I?-/[:G/S`#A)H+HTA/`X*J8@V!A^/+YLU7]]>:-
MMCD`.=X9'W$G>^Z;#H1@B/#3#UB)!">'ULF5U=55NPY"CK.T!HP3.2)*CM`*
M<8[VX##Y-@=H"^,#/VGLUZ0K0YFX!KNCMH[V)$R&;\7LG2/.-UJ%(P/IN+4/
MYC5';O]\RV8RIQ-X'"`L3PN/+4P,X`#0@^A3SI[>Q(3XKM"W^/^$01Z'<+#4
M2>>WW6T1PR?7=DQ"G,`[^AOW3:_G*AXN+FR%,&]AI"(X!7ONG6\(>][3\W-O
MY4'NONF1T-P]N*7W7V;"L@/(WZCY^8L0C=MZ`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C,N<&YG````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q-C`W(#$P-3$U-#,T,30W(#`R-C,P,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T
M=V%R90!!9&]B92!);6%G95)E861Y<<EE/````QE)1$%46,/M5TM+LD$8]6?T
M*\)UM'(1]86;P&40!.TJD@BB(K*@"QA!^$HE="%3*JT,*HJ**(6B"PH585E@
M%[$(ORC%;N?S/-!%,'#UY>)=##+SSIPY\\PSYSEJ`&B^-TW&@;JZ.M37UT.O
MUT.3W9*T@9V='926EF)K:PO9+<DXX?KZ&F5E96AK:X/3Z10ZK:VM4!0%V2'D
MPH2*B@JTM+3`X_'@3TD).CL[T=/3\Q48J]6*@X,#E)>7@Y&;G)S$S,P,<N44
M_Q=@?W\?)R<GV-C8D)!-3$Q@9&1$^L?'QV"TCHZ.9,[:VEIZE)@Q#0T-6%A8
MP.CH*)J;FV$VFV7Q]/0T*BLK45!0`)/)A-C?&%Y>7KX`DLDD+BXN0`9#0T/2
MYN?GT=75A=[>7DQ-3>'FYD92D9M<75TA1X.H`N0"P/CXN&3A\O(RO%XO@L$@
M%A<7Y7';;#;X_7Y);3YX)M\GP.OKJZ3L[.RL9&-34Q.*BXM14U,C8`Z'0YHW
MI:\41T6Q(!Z/?P$\/S_+&YB;FY,=G:G)+I=+1)F@[>TF26TRZ.[NQO#P<'HJ
M/SX^RH-Y>GK"WMZ>4/3Y?'"[W;B\O$1141$,!@/&QL;D/:3%X.WM#;%83!;P
M?#PWGRHGD@T!^*C.S\\1"`0D-CE\C2K`[S25@$H@K4-9I#"%PV%4556)MM36
MUJ*OKT]DD.Z*U9Z>D=_HM*JKJV&WVZ'3Z3`P,"!2RC541^HS"[G1:)1U=`:*
M8I4BGY$`A>W^_A[KZ^M"@,"T=A0X^F5*:T='AX!24JF2=';T,1SK[^]'?GX^
M5E964%A8B,W-S904M\N:I:6EE.*ZQ-O\&`'ZE=W=70&@ASD-GLJI2(0;\<34
M>$HVG3+]#XFLKJ[B\/!0"@@C0P=-+\0H-#8VPF*Q(!0*B?W)>`7O[^]()!*(
M1"+">G!P4"2=H/2MK!-T9@1F06'M8#A)A'6"WRG_6JU6-F'4SL[.)#)Y>7G8
MWM[^_+>051(R%^[N[O#P\"#$;F]OI8;RBC[&V5B'F#/1:%1^V>?]\AH_L#CV
MO9_;KT`EH!+XC?8/)4CX1NGA0SH`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C0N<&YG
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q-C`R(#$P-3$U-#,T,30W(#`R-C(W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%
M6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/````Q1)1$%46,/M5TM+
MJE$4]6?T+YI'(P<A09,&S80@:&9A1!"IA`8](`DD+0HRL+0RRH2,I*+0(-&,
MP![TA!Y*14BDH3W6=6WH(1@XNCEP<-!S_,[Z]EEG[[67"@"*GT-1<$&KU:*]
MO1UU=750%+<E;R$4"J&VMA:!0`#%;2GXP.WM+>KKZ]'=W8V9F1D)A]^M5BN*
M0RB%!QH;&Z'7Z[&TM"2D]/;V8F!@X)L8F\V&:#0*M5H-,C<[.XN%A064RBG^
M+\#N[BZ.CX^QN;DIE$U/3\-NM\O\\/`09.O@X`!'1T=87U_/9XD9T]'1@>7E
M94Q.3D*GTV%P<%`VN]UN-#4UH:JJ"D:C$<ED$J^OK]\`F4P&EY>78`1C8V,R
MO%XO^OKZ8#:;,3<W![[`Y7+)2VYN;E"B))8!2@'`X7!(%JZNKB(8#.+DY`0^
MGT^*>WQ\'/O[^Y+:+'@FWQ?`V]L;MK:VX%E<E&SLZNJ"2J5"2TN+@#F=3AG!
MG+Z*(`X/(YU.?P-DLUFI`8_'(V]TN9R8GY\7_5G,@9I,1DGMO>@>^OO[,3$Q
MD9_*S\_/4C"I5`J12$1"W-[>EM"OKZ]14U.#AH8&.1[K(8^#]_=WJ2YNX/EX
M;I8J'V0T!&!175Q<"`?DIH2OL0SP-Z,<0#F`O`EED<)T=76%YN9FT9;6UE8,
M#0V)#%+=V.WI&?D;G99&HX%C:@I*I1*CHZ,BI=Q#=:0^LY&WM;7)/CH#>LMX
M/(Z"`5#8'A\?L;&Q(0%,Y8`->H,('/TRI;6GIT=`[3E)I4K2V=''<,UBL:"R
MLA)^OQ_5U=6B\2:32?:L^%;@SDDTO<VO#-"OA,-A`>#&T]-3C(R,2"!\$4],
M%M@T#`:#^!]J^]K:&F*QF#00,L-3T@N1A<[.3@SG&LCY^;G8GX)7\/'Q@9>7
M%R02"8F:5%+2"4K?RCY!9T9@2CM[!^ED[V"?X.^T\#P]99^&^.SL3)BIJ*C`
MSL[.U[^%HI*0N?#P\("GIR<)[/[^7GHHK^ASG8-]B#ES=W<GGYSS?GF-GUA<
M^SDO[2HH!U`.X"_&/[H]^#8FC3:9`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O
M,C4N<&YG`````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,C$V(#$P-3$U-#,T,30W(#`R-C,P,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R
M````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!"!)1$%4
M6,/MEG]HU'48Q[].*H7(/Z(2"2,PU,HD(?_J!]B"6%#JK)ST>SDZ4%+S_*<C
MH0UL'1(G%S+/<K5FJVV!G#K;,8VMZ>"&F^M2E%EL&.SBTJ%QN-5X=Z_G^&QW
M;L2@DI#[X\/G\WD^S_?]>;[/YWG>S^-)\G*'-Z5@W;8Z';TX8L.;WB=Y@J4K
MRK1JRW8M61M2>?#P-#"F5+C[]8!F;FK4K+(-\G9VZ,X%2^3%+\KK2&6UJJJJ
M5%]?KZ:F)J52*04"`0T.#@KY]*[XCQ6P%D<PSW@I8H;-:#@K'!2)1.1U7OY3
MF_U^,>.M70?:M*?K)P4B+0J'P_*BT:C]6CP>E\_G4R*1L(-8+*;K]!?7!\`[
MDI3W7DRWE+RKHCVGQ/[94+.*GJBV-3(\Y,Z\RF/R*O9/.&';^2N:_^C+YMOB
MT'=BO^[]G?81^[4MW9J],JP76\YJP\!5TUW??\6"Q@!X$!X(5Q-5N!B7,XBJ
M8#"HTM)2B[;V]G;3X:R_OS\+@!(?C8V-F1*RT=%14V:=3":53J?M/=GSENS_
M1Z]0`/B'`.0K&0YO69AF>(NH8[T\U&@AR_G\AIZ\4'^KLC8;!P0.PHW[6XPV
M[BVKR`)`?$=_MK!=\62Q;OZLS0"X:&ZP5D7W^2<`5G_>;8KDP"-;0Y8#Q+RO
M]Q?=4_RJK==\%=/B$K^6^;^6_TC?!`!Y4-G8:R$,+W$;YK'>7E,KJ@/K\+<=
M!@Q?L;_M_A>R`,0UR>&2A*0!%-\XRH;#&(!S$3+6!D#2N.0@H3@D^T@PY``A
M8\[E?A)L_!E)8V;2DP-``6`F0[&.V9TY1BV$\K\$4##@QC!@>'A8B[X\H=OW
MQL<'[)0K>["F4WT#OQD7L']S5U1#E]-Z^N`9HSL8C6J>'OG#"C#ZU0>ZM+2A
M-P^C[EA"DPP@Q:WGRY1\>D!X`K)!1E=E?2'G&6ZE9V0-9<ZL.R[OXR[3A4;-
MD$P[<6M-JQD$?;KOT+GIHV^R.ADFA#7R#'CXY*]:]L,EFQ='S]A%#_1=LO'0
MN;01.B"+?.^8;,YKN[6@>TAW[&C57<]4F+<8&,(\M^E',V#>Z=^-PZ'EQ[XX
M:'L,@"CS#*@;&E'%OKA*5I4;9SW_2KDB0U?UU)9&\XA;TV^RAIJK.Q/&[=0"
M*-S)>3[D\+_[CKX)_:J>"Y,-@*H/'3^ES1\TFP$P+XR+[+DW0F9`<]OW5ALP
M#/G"Q]^VWA9Y]T!*)\XG[7VY],/=GVC'IZUV*>>'>P9LT/?B19Z4.\8-X(\1
M4!*XF#*`#!:'U6G$V+M2@1Z7LZ<2<$8@.UT\"N-CK"LU#.Z@7O'#DWHS#OG(
M-7<`LJ>X`<(>@U@C!P29*T.<N0X3'7!84X8X!P?CT:,D3<D#`#K07%GN!PQ`
MW1]<*_^[G+\6I\"$!0,8?P&H6)X),IT]3`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\R-BYP;F<`````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T
M-#,@,3`U,34T,S0Q-#<@,#(V,S`T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&
M```!!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E
M($EM86=E4F5A9'EQR64\```$M4E$0518A=V7RT]341#&^6/8\@]HW.I&W>A*
M$]]Q@8;$!%=J?"2^@@$5?""^4,I#P$=1*0A$T`!*T12D$JA$7D4*Q0+M;8'@
MR&^:<Q7;1*)(@HO#O;WWW)EOOIGYYI`B(BD_+_WC*"F7Q\_?BOW@?I%#.KI\
M<C&O(K[M])DL24\_*!D9AQ9_;W\2G`B)_2`4"DDP%)%"QPOA/B40"$AFYF$Y
M<O287A-L)+7)>MW6)>LW;)3)Z;!LW+19SI[/^8$3C+[/P^(?GQ(K&M--SNH6
M#6;I+OY^P[#_BY0_>259%W(D8</@T)`2R::RBL?B?N>5N;FY>!0MK:U2_ZI#
MIL,1:7W?KU$TM_5JR+IA?GY>JEZXI:=O6*W$8C$9"4S([&Q,UJQ=%_>3FYLG
M)TZ>$M)T^VZ)7,Z[H51?NYZ_##S\L0&OURLLX"W9``&34VBK:W1K/,26G7M3
M/!Z/N-WM"<;B%1@,2M>G$7G3[I,K-ZJ$(@Y-3LFG@8!\'AH7*I3GU##T;MFR
M5189@#WS@GRX._LT-XX'C>)J\$A168,BBT:C,CCR5:J>N>36[3OJR(9B699Z
M\WP<T(_P^&U^3B*1B!JE3,@CQFX6NM1!6EI:<F+@8F9F1F%2,N8W".BKE4GC
M*C<`6145E=+K\PDULF0#;*9\N5)$I/)<5O[2#50^>:Y=CX:5/FS4/J!8=N_9
M)S3^KRE,,$#_4C#;MN]4V:2XJ$"J%"FA/ZC"!`.NFEI5#)1C[_X,[0.DA<I$
M7@@G^U*Q*@AE#S>V`3H/:!C`0S`TK9X_]`:TI"EGF@QD]`;H:"JJ4PV$P]-R
M*/.X-E)U=;5T]XW:S<1(P`C7:"PNV2QF$/I.GR@,B'K9W"E=/7YQUK2H9/(A
M7B-65(409+RCM?L'QY1D.E(-$!-QTC`8XJ6W9T!_6PM>Z%!22C<R,.C&NGKW
M8M%T.I^JDII%G*@\I*%*YI[A:(8;CI.V,IK-U2R0$!9D4Z6KH)E6<JU.`+0:
M<XK%_3\%0+>@)/0[&E=75R\#_E%5'&J>]J4D:99E!T!O#(^.J2*AD8'Q<?V-
M<X2'TQD+':%'D()E!5!2]DB==73W:;1H"@N1)FJ:$\U%+E$ZE)!C!*#XCF/2
MS\KW6P!$"=5H+H*%$80-:4'P7+5-"@0]HJ'MM4`_)P:&/DH!&%3S7JE34W2U
MP*'I,\?"!`"\8`/G:&@V=*-G1,NAR+(B*M,XY$",SI,&M(W[<,12$.C<L5/Y
M]CA#T@"$^E)+20%`$P=7BHL(LW,+U<B.70?$Z72J888+5^2>6<%Y%LDG_U_&
M)L7=T:_S@A2QA_\0]/D"@[#`,2@U-549@F53M#82HD=D$=Y`<$K!,`(ZN_MU
M#)`.%!^'E<_>J+(3+8YA`'5G'J/#L,08`4"GSZ^MROD,E@!.@#`"LS8`1+NI
MJ4F=,X=P:.801T\88%[AG%Q3:!S6,4JKXM1$3&K,81"0?,=4)5TPQ#O8H(`7
MY8.I`2H]72_DG^CYT$Q5C)W-*E8#``44S#&5`0H;%"R.V4<=\"TV2!=I9E&@
M,$#=)6T-QC9G!7,JAQD6N:,F$",*BF7NV<<[\YYK04&!+NYYCSWSKP/`87U%
M=?^/I/B_!_`=$'AUF*=?#](`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R
M+S(W+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<P-2`Q,#4Q-30S-#$T-R`P,C8S,#8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8
M,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```57241!
M5%C#U9??4QM5%,?Y`W6F?T0=7YSI@R-/BHP^5(MVK)U2:\U86L$IU"!I20D0
MH="0T(9"4D/:Q)T"`1I"4GYF[$23XWY.O)LLFU"93IWIPV$W=^\]YWM^?<^E
M0T0ZFD7_K&2G973H.]FRQNNKB\FGDLUF97[)JB]DGVU*L522Q^D5]WE'Q\;*
M?4G%1T07YH*7Y);_MDS.).W?->E(9U?EI\'?="$6BS6?K\EA85ZVUV=%_MX7
METX^A,=NRO[AH:#A7O"JQ*8&I&$T7Y3UC4U)6079V7DAP/RRY[(D$HL-$^5R
M6?9VGDOYH"#I]+)4J]6&AN.D\:-:5H#@`;`')`%,+X[*]"\]DHP..9MT@[4\
M(=;:ED0?903`1&DU,60VU,1_TR?7;O@UP!^<Z91\:4<"HQ/U#;M[NQJY?&%;
MH]?7/RF#_HB4]@X:&Q*IK*K.6#G);13DA[XQW>1@P.?M8E'CL)ZS-+E>-UM*
MS>7R\7%J2NCSM:BD'X<DFYJ49T^F]/>31$A*ZU,>A:Y`LXEX/IB[JX)?L_._
MB^_KCX2Z0BF%4*WL>EV@"C-+0>GOOZX50Q#NA*):043O5F!6EM*K$@B,:+)<
MB4((ZY\O7VK\"1A"T4?C:55PL;=?KOKZ-/RDQ5-,W9]^(A.388DG,WIP.#CO
MI(/TD&3*E+(%63Z_Y4X3)<J&F=A3/1@*/]2<<G!T?$'.?C6@3P[/1!;<"EY'
MWK2"$Q>2+;6*5`XR6C0T($]^L_YJ!78QY:Q[3B7^L1S6WPA%UDPW+2N18J(2
M.<`S</US[>Z%F0%M8J4B>U\+!36%BA7JGS*&]6``2GGD2J?2!<J:Z:*AP/8/
MJUB!#2A?*HZ<4T0_#PX[2%#6'`\'/I!10)%,SZ6T:"@LZI_B@G(@#MSR4"\*
M&`DT"E.`NC?]@'6J</]@7U&A[$5QS:T`AN$CM$PS4;Y8II&@+!2<_:)'&#5T
MI2$\1P$?L`R?0W[PP,-D3AO'-!8!Y3L(<,6E@(C3B30(46?SI>]_U3:F&T&!
M.RAFS^G3[[L51"(1[7$V$76LT(VXA#LHI$,)*L'U*"`&'(2)\!&?<05K3`30
MG+\PI(J)BT>!$1@)J_C.&"/:T#B*XO%'PHC[O]OYS<L)-M?J+8#0D`@5;=X1
M;9'C^>?DA&8K-OQ$OQK&0*`;!A]K4!!/+EC*7\H:KP9SK&&,HM30$Y))C:N8
MWH<@F(<`L9)CNF989S,;_+?OVP-IR\@812EBC)L(8(1KFU:H7>[<;VZ<>T_N
M7NM2PP"!&J%`)KI>J_X3H]M(,8X1;E5&"<;H-9J25D'H:GJ.'O/?B2G;#?C.
M*0``<H[H``!@[4!X1HK)M0DE#`D#P-/FK@+%8!2V@+L1OM\.A14$]Q=`,T$,
MAP/DZ#0Y`J">=PPCY!4%/_IZE3TP"!WA,=YB#'#GO[FB+,/-$3KC">/`0%R<
MF0W<EP#6JAY<:+AUP8L<1`$,#1,S'V`B6!A6@C,-3_*^D+04V(5O+SJDS/P@
M*@``/.GBYMX6`#2'@;\J%14`#`Z/ZX3#",80UO$0I:0"VN0[[T2"*/%D='"9
M(WU\`XB93RT!@+BW][*<^;!+WGGWE`HA)N\,-\B>B#"G4,A4P',F!2.'T#,,
M3&2XUS'G('Z&(<)_`/4HM`"`U\PUHL`-$[08Y6*`01-NWIDVK+-&!`@YGIDH
M<9YB-:D@:D0,$&T!D`+RS"&\XHD7ZJ4-!H\)+XI1BJ<F-42)M!`%,_IX-U=D
M4YA$`QOMB]"^)F.80J1R*2H$Y.2TN_LSX1Y.JI"NCSMU'\(>]E*P=`9[S9J1
MH]Z_QC0TE]YF>4O'\3_WR?_.$%!<Y`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,C@N<&YG````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M,3`V(#$P-3$U-#,T,30W(#`R-C,P,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````(````"`(
M!@```01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B
M92!);6%G95)E861Y<<EE/```!=A)1$%46,.UEUUL5%40Q_=!`U'#&R;X:&+P
MP1!#>#&&\*")#<:0&#5@,82H33"T:;"&#X,T!"IBBH%4*!+81&2!;(S`!MIJ
M2[6EU7X$V$*I=5,$9;%?Z[98T,+%\?[F.M>[W;5?A(>SY]YSY\R9^<_,?\Z&
M1"3$N'%C2)CU);;E$6G\]KB4O#570L._GY..BQ>DH[-'ZDZ?]L2KOCDKJ51*
MFEHO>0O!H3\[5LS4_;IP</U,N9(<D(_*CWA;4(@.%A8M6CA&Q]]_R#L%K\G/
MB9AN=QS'^_!7^KC$*V;(UK(/Y9677Y"1D1%!-;,*]/4/2JRF12+1[Z2NH4--
M[!\8E+<+"K+-9-'<]LT>;_@//S1%)'WA19&[U_3L#(%;YY^60Q\_)<4O/:1X
MI4X\F"F`!_4-WTLX'%9@0>K=-_,\I,[%GI'%S\U3R_'D?.=5*=OVJ5R^>ETW
MA"*'(]+;VZ<+N(G+/`,O6D,G3U5KK/;L.ZD?ZIN[5)`UM/I>H`5$_]?-7(,-
ME7L_DTGAA/#.\@^$@`++UC5/*AS+\F;+Y<9GO?RX$U<KB.D8!8["([?*=>.J
M_/G2VORU))._2E-[0O9_7JVPD0#=9_(T&+=OCTJ&!21O^_X%LK?X846'9`"$
M]%!:=NV.R-+75\H71ZL49I1^LK/B/P4(?77LF)26EOH0=R:2BBCO6&#P(\-F
MU@H+B[S3B170HXB-G/)EK%F2O_6K%6PDR#MV134\R%(-A-!W`9^)/*B#0]GF
M93HO7OB8;%K[O&8+J8RE&S9LE)Z>'IDXG=V(H'128<PU<&G2]9)KU)\JFH8"
M-\;XR9R(S9%4?Z,^!UV!+;(4M-2\*C]V)S3;:L./:_62B13JZ)D'1*UQ,6$F
MP;(4W+TSH((@3V53M&0DPD3B>NU\_3X65/T9Z.L2!C7`YECT@(:)^%.FY`#K
M6@]NNEL:9UC0VS!'2I;/ENB12C\KR;B2DO>4QB('MZE5R%171;,5W+Q6)+_L
MGJ'I"0F3@8SV^$^:0-0#M4":\ZYXH>!26Z&B3=E"N[:1.L!T<@$B)XW9.#@T
MK,5$2?N,@YDG:NJT"JV0$%+>^E<1=<&S64,QJ0)BBJ\`AKDM9[NU8#B1HFIH
MBJL5E#<RQIX<ICT+M#D)OX/L::1HO0S_:1P,^A/\H.V''R5L=X.Q#SYCLBFW
M-109P1NM*0;$%3?X`"]2NH?"^4IA)!/)!<"$=E_E=@VSI7..`G'\]D5N6-KB
MVI2KD58;S+HI*QAWN!7*=8)(3%O'Y`UP-!6"?9G,I[&":]!+L$4V2!E3,,#1
MHL:K(!O"%-#+^^ORI3M>K@4]VOJHT@U!III8PZC8X24::'0%][>UM?H\/B$"
M*"(!:`:0`.\P#?<,J`E"H'3G/3'+'ZQSRV-=FZ=K$$:CAZL7!DPA!(ZV</@/
M@D$Y=&8#KTEWE%(O5##U@N=\ISF##C-.**N+,Y$!WJ'$%4:'R1G4$G5$.1`6
M6(P^3-TQJ'`&]$"%0R7;U[^A^[@I0.3<3>@8&#@6B9S9#7QL`E(0X"!(#-*C
MV.W:P6V!`^GE?,<PJ(9"7[,Z7Y$#?IY!#:[/0N#/FU<TL;`0[Z%F8DTL@1,E
MW"`XC(,9L"W$P`S\?(.F(%"[!S%X1L:X$L/6KBM65N(YXP+)(/L1@(&!%<\@
M6"-5XFU4#]P8`6NQSCN<:81+*[2.QG<,X+J$'.O:^8,A(#;`R$>(EG?SEK8`
MU/03%,#V#.LU'!R\BYFQ(&,Y@W-PQNKBC2K+19PS_!L0AP*GM0L.9C,'F*?,
M;`9J/&+-#K2<P&@Z"W(8;3+(8S0M&R<)*[S@_]DAN1"T^&*4-43S&D_-F.#!
M!C%APS@&(<`(]O',C#YNI1C!OHP00*=`18+80)"P,)/-K-'JR&K>252^`ZUE
M.S=7T&0V/1QJ,[J`?IQVF#DPC$JIK:I0`[G=4:JP(T2%8O['#:>[O%NA*T?R
M&F\$]>3J#]/OANYA4"V>!O]^WJ=NF'O0'2G3>]'Q#XI](4QQUPA&`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S(Y+G!N9P``````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C8R,"`Q
M,#4Q-30S-#$T-R`P,C8S,#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```4B241!5%C#S9?/3QM7$,?S)_;67*I>>JG40Y0#IRJ'
MJE43*<FA)4T<57$$EH@3<&3B6&!CT@TXCB$&@\$08P(!BQHJ?C6)"(3L=#^S
M?FLOMF-0U1^'89=][\W,^\[,=\;G1.1<H^B?[?51>98(RM&?<^[7Z?P+65LI
M2GHLZ7XXV)Z0Z:';(D=5_WE/Q\J2)0N3@Z(?$D,1>3F?D7*Y)`=O:T>"E\[+
M1BDEWA%/'*5R5!'Y\(?X=&+>LH9E+C^F[J#N12XKR<1@[>3QCL2Z+TKH^R\D
M<NUK*3RY*\5\4FS[^(2;]J'(\1M=\)GXE-3_^?C.=="19@V.UUQ^>2$EY9FX
M3#_K%S7'!G9'!^[*3,Z2Q=FTK%?69&Z^(-9(Q-VPM[<KH%59*^D&!/1O7.FJ
M`S63""CZ7''LWF59*UL:J[H/CH.!;S^7A]T7I+IL27F*0-@GH;85`[U-RVNV
M%-O3U!DG<\"!A(RIK*8]:#8KDQI]^^!5>P\.#_;DZ4A(^D(!B3T**Q($'=@6
M%XLRGA[7!.@+_BQ3V83_CF!-IG`P-V')4FE6GV`-_B0D"L&?#`+BK<V*'Z2W
M.R75'@Q<E8'PKS+\^+Y$^F[IYIY??E1Y'.U5+U_F^KVK>`KP@CL2#M(2>7#Y
M*PT)L2NFPYHFKXM#S0G?E+).PFW,/Y3,P'65<J;7#;P>M,\2QL[R3RLX<R*Y
M8%+CIOA<J38E4&L%M:K=7$EZ64CE;*V/R]Z&Y2IJ"Z*#_O&[DB^%$2ANJ9#4
M*B_E(S4E)Q3@]NOE*4V@@0<]RF&D[^KJLJ8R*4PJ\ST:OB7[NW4E^H>TA#9(
MTTQZ1-,:9B@O3JH"4P^D\V^C<4UYOGD*T(@"%LEW:L&*AU0)M3`[F]/#>$)J
M4TR'A^_K"K(92UW'.H?AI\)D2@L&;_C?**%68%T_XSCHTU,H&#Q!*!RLF6+B
M[J/)/DD-!MS0G@21"(P&+VGA#-WNTF*"[R%"JH]H$%+EW);%Y"1/-GY5#][Y
MX4NM2IH$U8AB*I%P8JA-;[`UQO=O?J-EC()L[*92F6%:J*X#J=J:QI0NUB<>
MW5`^I^_JO5ND<\L"41?9#(TCVF=:%]5_SP?_J@,*#7`TPF.$;\Z:&^%/<]#9
M"$W'"I>?(/WWNSD-*@+-(+Q#-ZR19MZDHT$_(R%ZAI7;JJH0`Q2!H:J%:3>G
M$4-;K+&';Y3JZGS,;20>F9XRB0PC8QC^H[E2U@@LQ"P#:_&DY.GDIH=2[KPC
M[(<>*7U&`Z;$Q@)L<H!%R(>.;I1C$&/,B1`6A`19&9[=J/XNVSO;*KPS2K`'
M@15Y<KZ_YR<9CO4JL;&W[90(K4*5YK;0*\9QBL,(ZU!M+AW7D0.ZQ2D$SC:L
MR1/ZA6%!0IUPD.%_,Y;X'&!4Y`"0<P`G<,!,R!B@06`8!X#6-`VH6P=RYQW#
MH(7C"&A"X;!RVHK*FWU_7_0A\/'#OBJ!OCE$?!L[%8)RGJ#"D[AS.QS&^<8<
M`44N@Z[^GN^$^0L;;1W0DG/*AZQG)(+%X5/F*<@XGPI*X6E(UV@;K#?.8>R%
MP!$J@N2C8IX_"=?XN.J-[^W+L#9:;)6BVHN,`>9OA)\ZW5V?Z1,'<(K!CZZ!
MDSA(ZT$P3F@84^K-X#2S70T)ZICVA$%Z',*[$1JFZ3B@PJ\)10OC3@/%`<BI
M?G-;.O)`$QDYCL"`Q>=WU`&,`C\PFYF)F_.N([#SSHU=1JQV9,/3]P#E_QWQ
M?E2VE*I'P:?M"7^CDYG!M_,`_+]NQW\!;"7O(F,[MMD`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S`N
M<&YG`````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S,#(U(#$P-3$U-#,T,30W(#`R-C(W-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!:=)1$%46(6=
MEU]L%%44QK>&D"@)$3$VX=D7M,J;3V)B3(P)RHM14Z,^2-3$&#5J3$A,'S18
MT@@JBK0E:E$P(:REMM&V-K(6=<664NA2VRZT%&S9W;(+M75)ZK@<[^\,=YC9
M6>AN'T[OSLR]Y^]WOG,;$9$(,C\W)ZSZT%&W4I`W7UPGD?QLOPP/GY2]^P])
M8O2LNSU^>(^T;+E;)6)U6-$_VY^]6<_KBVSG"FGM^%W2F8R,3TZ;;5?FY:W:
M-;+UC9IK9CTQ'U]Y^3DY<ZI#/Q8*!?=#_F*7%/9%))D\)7\FS\FEV4OR\<Y6
MP7G=<*2[5L9WK9+HAX](XWL/R_??O"O-NSZ0EI8OPVYB`@T!MV\DW@^B_W=T
MO4AA2A86%H(:YN)K-2U_[ZZ2GN_V"+$'-HRT+)="9Y7D<CE-"A%XF1J./21;
M7KA-^@>3&A;98N/4]'EI:*A'C2/=T<<UQ$_K-VF8K'5O;]0RJ8G>O37R7^(>
M2;>ODX4?;Y?<R8V>HUX4%$/R77+=,$M*/BJ-C8VA0R454"^<IJ"X0[5)QS,;
MJC5_&K4S))>S^Z3NG<W%E7`T(,E_I!FA\.FO;]+BDQ&$['"0K/F+<<T#`]X3
MK??)L?>7:5$FIS(*XM_ZQB3V:T(ZNOHUU5890`GFP&A%`<FZD,WJYOW?'E9%
M'.(=SQ0199]_U:W8#23$N;!9J'IBFQO&E:@K_`:NL]$J`;J$'$IB)C7BQ44=
MQTXT:#*??^).S0V%YR!=TM9VL$PXFXK86!<M8RGQ-\Z2%,1^>'4)"DPU-$:S
M3K2MDMS,+_K;'PIY""D@NP`'M,6:JN6?Q(.:=1K%B2\3]<;DA)56"WM@/K(1
M"$-<`.KLCN7*,%1@IG>]?B].JE="!,S#J]2>_H7#_"#2?C`E#7$*DOZY6BUS
MN'W;77HH,Y.5GMB@*AI(3"H*Z^L_DT,_=8<5S(R]IB[CP>"13N\0L&4%NGAS
M/I71IAH8..KVPDC?2X)U2*OY]=7:`QQFI0^PBB=@`J&YX"[(S:,DVP?QKD^\
M@W0@5ME,.#8$WB$HHFIZ>.KT#CG0M$F[<?2+F@`!\MX^P_=*B":$4#L##L(@
MD?Y.M-T()F`G<%(2B920>A,*",03JL':M_M6N3Q1JSA0V@LK<*2WURU-P<FX
MK6OJS0$X'>7V^^1X;+'IY'@;4G_<Z\$6&JNX&\\D6P.HJUC!#<5T*&'Y4;D4
M*7.CFQ9[H;&X`S9`PA\E:&"OGS(J<,#1IB8J?Z$H+#Q-<>%J;>B^.W3PP=ET
MDQ;=.$71P:N?^#E/ZY6J8TFO@!SMB4'H",4,B/[F6^2Q^U<KUL$TOQ&<@`.8
M2+QG>'(&I]'#^+*]7V8)'+U(T%A,:(QP_>,&1%-!.O0('0KQ6.9BII(].)7&
M@UL(0EG=EY'K..!(=OJ`>@^+8X`)3V2VLW&&]QBU5P9X!YX9&IY0_H'M(#-X
M!X$Z*`L3@](49Z(DNJDG$Z#8.!%C@&@1__7#WO!X!U-RO[:4S#.W+(NMP$S+
MSY]38.$AJ(:&2!^7),829$C$B>-Q58XQQ!J&6>UUA>'!Y,$9#/DO5CA.B7"<
MO3C$MT#T1)#ZJT=13:H!(%'8:*@U*PH1%!$=!E%L#6*,R"D)9W&0<SAMSP!,
MRA9P@'9ALH%<$`^8IA/M.C<PR`&BM$H1WMGH,(XC_LP@&.0=9W&6%?Y@;P"$
M9$#[_RH.N/^#9%`/%NQ8`1.L5N@67:_NH71<30`QH*;$#`$`B+.+MZ&964P2
M\$`64`0H&4W</'&(EK3",^_YSC\*$)3>A9I<#H#<RF9"KO"T#7-/O37W)1R"
MB%#(U89+%_^-$#E@Q4&^6V9DPG.&2WMJ\%%M1?^-MO)98$K"_VJJ!(?,,TQ'
ME$\_]8`</W;0+9LQZNTKTL&\*#4?ECS%,)8>>E+!5,XMNLP25"9$50RJ2N5_
M\&LP4S@2.OD`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,Q+G!N9P``
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C8V,2`Q,#4Q-30S-#$T-R`P,C8S,#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET15AT
M4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```5#241!5%C#U9?M3UMU
M%,?W%QK?&%]HLE>^45\LFL5H3&;<LFE&8ER&@KK-:=D8#C;:,=O2PBC0(>6I
ML%[H`P\#NR<(<6IP<W1GO\_YW7MIRVT!C1I?'`JW]W?.]WQ_YWS/X9"('*HV
M_;&^VB^C\?.R_3AMGQ9F^F3NUG?B3-^T#YZL)V4ZVB[RQT+M>=_'<C$ESF2O
MV`=;61GL/"6S(QTBSQ[9U[[YZ'4IEP;$/^+;DZ)P0IZN28U/O@#*BA-3<R9Z
M9`P4E=_=D^9$7^N[TGGRL'2??D,QSV?C(L^?UL$T)P#"%[4AFMC.']N/+<"M
M7(`'`_)N\98LY0>EE+TIV=L]"M!_H;PX)*6YJ"SE8C(_WBWYJ5[96+SFO5"1
MR52'$I/H."[IGL]E(G%>XE=.['BXDVA5]DEQY&J+K)6&Y,_-5!63!B#T7CM[
M1!XLI30$GNO2-`^>;8AL;TIPFH%6\3WMS9-WP%"R];!?5I>'A;I8G$_*_=4Q
MN5>,RO/?,DT0F#PXR(&[A0$IKXQH`=P>""DCH^$6R<_&9#C2;B^C-L>*/H2=
MO"E</BG"\+GWE5*X=\:Z9"9]129'?U!GRD<-`N,@'?Y"QB.M4IR.R*.U87%&
M+\NWQUZ5R&=O2>+B,44'BN)DR$]EQX&I#W)L_^`5"1U_38U[P]E/G9\H`LID
M)1<)*/CZDB6=;$C&KY[4RLBGV^S%Z\'*0:YQ;_NG'1RXD"R9FBMWK0V8U>*R
MK.]V5GO8[=K[2S&_"JD)*O'7<M0Z:DBB81\YI`*]PU@NTZO-3!'E)[IW.=G)
MU2@EDD`9(P]$'0R?48WL.O.F.#,_JKRJ$E3U@Y\WDDM$BN7G0E*6Y_ID;2&A
MGQ01CM!7RIM@M0Z,1U0=N`]*5I@NGCILZS]Y00\B.]B-T`E+;$TSF<;@)9H&
MZ257U(7?Z0$0T4"DP>C8[<"P3^FB5T#&0!+[ZJCV1/^Y#S4`&D%[VW:NXX`;
MX$7:V#N(WM.)(((#R*6=@YO)/`0F`X+\Z4J&Q.+4=1G^_F/E)3^;U$`-9H.5
M,ZZLJ^5M=8`VD#_I(#0HEB<DC371(*%UT7):&3W_925L\Z92]]5,0*18&&68
MSIG@IOKO]>!?!%"QMP<=<,EE5!N4\9W><',-.IB@X=35)T2?GMU<[=/6PY@>
M?"(W?*?#CPOGC%[Z0071"\QA4Y;4+0'H(A1&MS#3DH4[<35/MLK+(\(>PMAB
M06+ZZ"!I(J9[*')6,\4Q$H?48>@EADZPJB$N;$1T,%*`("%[/*-KF:'*"CZK
M&C`8@!N<`V2-([)4`&:[0@K(4C<N.MNL0;I&F+]1/A8L0"`;L`0(Q&L\>M8J
M0`"(@)&2TXYGE+";X(S@!"28!C(*2?8Z].-?6ZU"LUUC>G".3PP-9[9;,6BX
MGKG[FZ$>>LF<480C_F:%)!!9JEPQ9=QM`S">G+-%`PKS9@"325=.9!QAV3W2
MO,+;5)33R3;=DZ;Z+VA0])"B*LWT^A.*:<5W`$&`$5S$%_TD.$"\78H1H`N9
M`MAH!,"M`5.U:"<Z"M4XA`%4G>E&$.X9\\8&`##>50"1-JV7A_<R6D<`H*!U
ME+KK>V,Q=^M@?>&R3@5OT;O>>D2-;?'+]U[63^87H-@B80F0<ZE+>BU:I"9X
MT1FTBX!___O9[4!IF*"/H?C3=U[2&<<_`@3WC($)4UP5C#!Y8(O@3N:&=@GB
M9+4@6)2:JZ`K1K0E50P(@@Y=.JTT%S)A+52Z@=]A`A;(6-N.P'5W_M=F@3<>
MZ6/]I[)J;?0M9^^8=PBZSYGP-R:9M_A6V_]P'+\`O)+Z.Z=_L)<`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H
M97)D;W1C;VTO,S)X,S(O,S(N<&YG````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-S0T(#$P-3$U
M-#,T,30W(#`R-C,P-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]2F(`
M```$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E
M861Y<<EE/```!79)1$%46,.UETUL5%44QU\IK8A1(=%(0J,)?BQ8$4-T(0M=
ML%%C0MSH5A),W&#0Q&CB2B0$4>,"K`)-#-@V:)N6UFF%MNC0#SMI@-J*[90H
M+=B/4:FU=6I:I\?W._?=U_N<#P8:%[?MF[GOW'/_Y___GU-/1#S6S,R,\%L?
M).[)[+$2D81GOM&'\0W2NN\!L[VO\X`^_-6[VGS@+OWQ_+:[Y.`K&TW02\WW
M:3`"=Y]\S&P;KKE=NJKN<8ZU:VE:>",YW*M?9C*9(,D_K@IQI<TSX6*>]'Q\
MM\S-S9H-K?6[I/J=S?H%9TFC)UU''Y;)R?'L-#G"7CL[!\ES+U97_`OY<SHA
MDKDJZ70Z&N%"7[OFD#Q0*C6[R^7;XYNC&P;JUXG4>2$@4NN%F[R.QA=EZF2I
MN4&RQ"Q_<^K4:FD_?<*$.=?PE"R=\`P._DI5EDM/W2/+2'*US-@.&:K>*K^W
M/B'CR=VRL+`0A1I0"EXSW^IH>EF*PHFZD*LLS<KTY$=:;<H_T[!*TTNUEXG\
MTZ]5:*EY+KL2RH#Y3Y5(9]\N,[#%G.5#=_C5"NGO>#I2C#``5>)$BJ$O)`)8
M?[Y-9"#`WP\*4#E!(BH!J"1LTA<&@I4(2E!K`BS-[<]-IOFY7MU8_=:#IFYU
MP:HUM:/@W[7M]+<N9@?XY=I8>*]+WY^2'\_OE=F)-S033C2%-R^>B1TJGLY-
M]>\65\9<RQ7.+06X$8GR!OCFS"=:ZXOU]TMJ(BZXA7L5W"(K0/.7KQL[\=F&
M_M(#VQ5U=-?=L-6@[[,T'GM-)B>NY0:1%[&;EY[=*%6[RM45KWRX2MY\88-,
MG=TF&!H'95T!I?TZ]8-R_LDMZ[7N2B9+8Y\+,)3@T-VR,)(!SE"Y9XTAD/6W
MA,-"/R"6/-52)KWGCF0'@-^DKLQK"RB,#I(EH9O"QL&&QXV[V0`@#DAXD-IO
MG:,#ORMHD"`+,%EL\M2_R7CZ^O5E,*"K]H1:;]G#K9CB)H-DY5H9[=ZN)8Y<
MX?+(H)H)Z85>T!:\&%_V`_RNY_.*2"6<,B[*U\>VZ"F)?6M-)H$:`7;HR$/&
M?GV>Y&0B6:`XKH*=H7M0/U_UJ)8O/;)#K<RULTB`WIYFL9FX@3H;GY&QD8-A
MZ3@(\`IJP:H0VN(3_#TZ.G+SMHXV7-;=4E\HM&B9K)7$*'HCN-%[7$N`.I#8
MO26?`^&-;IXW`:R"6T7=<%'P:8H[/+!?"XST?JJ_0[4YU+=3/UN8.ZXL869Q
MC9]DF"%RU3%G5K@+-[O2OEZ#T1QPFI;W[U7#P)[0/=)E\<R`\M5[=VI"J(V$
M!B]\IJV.."1P$R585,&@=SR"7HG-\5O=RA&9V_KX#B4?WK-)!8F:3Q_:9%S=
M021O`E`>F0,UDN=E;JK-VAX:\\(Y*;2*>/`<"WS8WXL;(&*,G'&"RX!F_\5.
M*8R`;U3`!XQ`2V<(#=X>ZAH==FNGAX232)`$EZ`MS:;V1DPP3`!F4Q]$CVLH
MT?S6PZ*^.JS;F[N'8]/8M;5LFX1%H]'8-W;&A`9A:;(HAVX-T2-VSF(RH5ZP
M&F,%?GIB!/J$<W,.MDW'32!H@S0@/!4$B$EL=\3.*@$:QKU@+FR&U90AG+-B
M_RF#NUP>.!W`HLE4\/?\;X5E2#E4_]3*;][P`.G1Z'3LM$1T&[Y=C<MJ`'H.
MY_\5Y$LLA@8(Z(XD!9V0`3#=6:JU@TBP&5934\@%O!S$XF]DQZ$T36#7"<1'
M!37E:R0Y$P`!Y()LM!/YPQ2>,#WY@0Y<M#@=NH(YB=N3()^U'ZV0L=@:;7^\
M`^1VYM!I;R6]`-;J6.R/B5HB_P"X`DHXGG[F)\M![OCLVG&N_K"B;DB31U;%
M3-'_2SM&4OG^_RMV_0OP"L`R!5[&"@````!)14Y$KD)@@@``````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S,RYP;F<`
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(V-3`@,3`U,34T,S0Q-#<@,#(V,S`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9=$58
M=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```%.DE$0518P]67VV\;
M51#&^Q_"$[P@>$-"O%0@@9`J52KE5BHD2B/2H@8(;G#IU;DU=APG#8Z;VDI<
M.]G$=IRKFUZCB`@46AIW.+\YNQNOLW82$"`>)KO>W3/SS9QOOCDY(B)'&DW_
M;*PE))/HDIVMC'U:*0Q*<:Q;G+LW[8.G3T8D/W1.Y/=2<+WO8WEA3.:F8F(?
M;!<D%?U$BNF+(L\?V\^^._Z*K%=3XB_Q[6E56"'/:A+PR0N@K,PEU.:S5V4R
M;E#4?W-7FA4#'>]*]*/7Y?*I-Q5SJ1@7>?&L":99`1!>!$.TL=T?.UL6X+83
MXL&`7*W>DJ7RJ(*]>_NJ`O0_6%^\)=69N"P[<<V`*FTL7O<^J,O4^$4M3#)R
M0C+7OI1<LDL2T9.['F:3'5K]V!=OR<25T[)J:OW'YGA#)0W`<\=>E>MGC\K#
MI7$I3QL,QG-3FN;!\PV1G4T)3S/4ZKZG_>OD+3`EV7XT++7EM,"+Q?F4/%B;
ME/L+0_+BUUP;!"8/%K)@M9*2>RMIK>GM5$0K,A$[K?N;[CMO-R.88UT?4N_Y
M_(!>(6'OA0^TI-3>F;PDA<PEF9JXK,ZT'@$$Q@'>LWUGI3(=D\<U4\U,CT!>
MRC_\_7%%!XJ%J8B?RJX#PP]R9#NZ/WQ-#6I6#:([T4\5`6Q8F>L+(7PS90V:
M6B$BV2L?*S/*F4Z[\;JP?IAMW-_^:0>')I(MIN;*7FL#%I1<MNI[G047NUW[
M8"FN+*1!:528N+4^9!VU+**I/G((`ST*(T$SV5[=/DBD7=;D9#=7HY1$9#']
M"I%&>\]H]_]TYFUE*/*J2M#0#W[>2"Y1X?^]BKDO#$BME-0K),(1^@J]"19T
M8#RBZD[NAO8!B[H_>T,7YD>Z="&R@_5'3MK"!IK)-`8?T33D3:ZH"_?T`(AH
M(%)@=.QU8*H/==&KY=E!M8?548F??T_E>OC",9D9[U&-H+UM.S?5@!W@0]J8
MA303>D\G5G+7I)2+:7%5<T.;R3P$)A&_-?;U^R_KD%@TK?WS#R>T*\O%$0W4
M8C98.6/+:&/:.GNS0_,GG7)^4!7+$Y+6FFB0T+IH.>*"GO^RTFOSAJD':B8@
M0A9&&:9S)KRI_GL]^!<!U.WN40YJR68T&B7CG>YP>PTZG*#AU-4G1)^>W5P;
MT-:CX3'ND1O>Z?!CPUFCFWY80?0"L]C0$MX2@"Y"UU`;6K+B)-40$`P9\\XA
M\T5SFIJ-V4'21DSW4>2"9DI@)C6!,0)AZ`1'-<2%[J2#D0($">GC&4.8&:I5
MP6=#`X8#<(.S0-7-9+HPFU`)\*YDB2&;#'#`\1OE\XX02"<#'!"(%PVM"A`"
M(F2D.-KQC!*"X(RC'?<$0S%12+('0#;QC3[SCA_>$81U7`&!AC/;K1BT/)ZY
MYS=3>LI+QNPGCOC-$9(@9(E<801#^P'AI*/Z'BGG-^;-`":3'CF1<81E[TCS
MB+>I*/,CG7*GKU.FA^W!"CU$XA%6R$5@IA4J#1`$&,%%?"FW`C)<@)P0DA&0
MZ?_*!;#1"H#+`<-:M),C$:5&3ZD`P76ZF2"0#?/FC6=\BP$>OCRZGU-"`@!"
MZRAUC^^MQ=SEP9/2CYJ==]"[T7%4C=,BHX8K\PM0E%_GN`')X&-;,"8(5="#
M@+__!SG;@=)4@CX&Q*EW7@K,.<\8F&3,5E$1)@_58O;-Y?J5I(B3U8)P46JO
M@JX8T9:P&``$'>OY7,O,E(:H!.2>2E`%,M:V(W#3GO^U6>"-1_I8_ZEL.#;Z
MYM@]YAN"'G`F_(U)YAU\&^U_.([_!(/I^H\UR*(-`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S,T+G!N9P``````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<U,"`Q,#4Q
M-30S-#$T-R`P,C8S,#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB
M````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V52
M96%D>7')93P```5Z241!5%C#M9=-;%15%,?'A1\LC"$QZE(6NG'!QH^-RXK&
MC;)1C(E+B[@CF"@K11,,`4,,-B`(D2C8:&E#2:>U9B(,[02<R3"4MDS+`)W2
MZ10L=3*/SJ3I]'A_Y_6^>8^9:<<2%V<^WKOOWG/^YW_^Y[R0B(2P0J$@?+M_
MHALE%WY'^-8[X_W;9/;F#ADXV>HNOQC=*W_L6R^2#+D7_*8?/#]X?(N[:?K,
MBY(?^4P*\:TRT/F2NRS]XV/RU^$GJL=ZME24T?`S,I9.Z,U*I>+>F+IU5;*1
M'5(:?5><[">2'VN7Q/ECDI_.N0MZ.S^6U(&G1'I"4HF:2^TAB?WT;'6!WSC"
MAEWK@S2("XM%?Y5_;L=%*EF9GY\/[I!*GM7``0`;"+<*$>@"?G`!($KC'XIS
MXTL93YP4\-0P(UWORTCWFS(5^U01OSW2JK]!,-)_S#WG7%>+AJ8AFE`)>;#C
M^2J2A+:4W2SCO[PL<^%7%?N%A84@U("R8IB-#)2;P@ETU5>3T+F9_1(]^K1$
M?WY%<AT/JWO3OS\JLIC2+/2>>#N((W"`Y8U,IT2[=[J(I/?*O=QI!?_NW5G)
M78]*ZF*WW!SIEYF9"0FPN%PNR_3D>7T8UCAC.Y4UI:F//&/#B?@19='8T/?B
M.,7[^&A2C,O`[;$JZ9J%GWM#)S;*DK.G/IE*S@5=F-BSWMW(9Y>_>5+Q@!4&
MC-H-)B<G/)(-7^Z5JZG=&@:G<Z*;>/?!2%];\W0^<VI7<VFL9_["6=,&JY&H
MX08:H\G*4->&Y2*<%7\HMM8"&W":RHEAVY6.QZ4\O$E11QP0)$7?L)1O?UT$
M3N9$N'"M_2VONJW!3NH63VH\((6<#L-@XIW$+BED#JK[A;F,?D-AJ`QCH;8G
M&9;*?_9](;'?MLN=<UNE?.D]3P0Q-O-H/'A`XK%NCS,*".F"..G>[7HZM>"O
M`_[GKWRG#Z-'>.%Y@.X`$AIT[=0'7@CHD]4HJU/<RT=>U^R@983B`0A=![Y>
M5]6N9&TQ40\3@RV:X@"(F<RHB@E>V&KT*K*G6HGH'6GU$\R7QD7I^_8YN=[V
MB-S[X:%`)?(_=?@%Y04\J<M$O-"**WZN<H;"LB$/TLS("E+FE[/`!J3&>L)&
M8,)&%PQYX`<IM`<!WHJU8*L0B8-D]L'_7(VPTS:(-97S:D;+Q!YDCZ87@IM5
M<BL)4`<2^Z.TE;%:Y`T=0"J(*JB&BX).DUQ*C@13'<@.#6\TODVO+12/*$NH
M$K_PXPQ]KUX>ZWJ%$T3&YI`>0:"[,I]1;9G]ZY3;UOC/Q,!]GM%J,W2&?>S#
M\(`#32"PJ"(!U$@8AZ.!3#\(S?#9KU25&-/HU(@*ZZQQ#=FC)#"$!_ISG12B
M8'XM#3C`#2!"<($0Y:8,5.&,1#)A(9-6*IFV[,3E3+?I&('AE'6$J$F=_2:U
M_/9S).``%Q'P?/:01GLIO%LE%"EEM+"FARYKM<HMOXWDVONL!RD0H`DP#H(:
M>Z/]G.7),7"SB(9`U)B%F\,5<K,A30$C6FN0#N-W\=8^;PV'@0`.D`IUQ@S]
MJ))6CCD#-`)RCI$C((35O!T,'7]-)D]O4J,/0*Y<_(T5C748RHV.TE_IL^S)
MWB#0D(3`@N>V`F"\I^R^%F'-]AKOOZ]UV`[`FPGE2M3ETM\KER'IT/HW<PC0
M$A&E53/L]32PY?M:EN9PN@GERUZ\\$#`^T?UA@K%<$14]#`VX@V.37&FG@[0
M;;D/](RPM#">IX%R>--*J".\J7]*4;TUPQ1-E+$?*&EQ3K)%\PR\1(Z##&+<
M(W6\I?`,D!,(*?5/M&OJ!;#6'1EGW9G"'`"YB!*VZS7C+$-.O<,H\7K]X8&Z
M(2I'=,U,T?]+.Z9L&[W_-6O_`IH^4SP9A7+\`````$E%3D2N0F""````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O,S4N<&YG
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R-#0U(#$P-3$U-#,T,30W(#`R-C,P-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%
M6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!+=)1$%46,/5EV]H
MU644QQ?TPM[TL@(3@K)>B+ZP%Q*]6!'%1!C"Q%E:$+J:7++9G,98-.><6WK1
M;:Z6[:9M*5TWUQQWS'MU$FT._#/+VD*C";:H+MW6H,%0&=_\''FV>[V_>_7>
ML/#%V?/\GOL\YYSGG//]GF<YDG+BQ?[4-^S5A1]^U-34U,U5WSL5JMO=K)D=
M8V._Z.I?]\TN).FX.'I%!P]WSNYH.]*E][;[;RY<NW9=/3TA;=L73-9Q[ML1
M<7QT[#>U=X42-SR;^Z)V^)MT)!01\P2CT]/3FCOO<2U:O$3/OY"G!8N>MC')
M1.G&U^7I=CJ9F8R,#&MH^*)&+HW:>**O+]$$7O-#Y&2_"%62!H+1?>RX2K94
M:6)B(G%#X9HB+5W^BBIK]HC(<YN$#2QPM?E/+33)S<O7X8Z.61]\)_J%G!U\
M0$7%Q3,_)OAPX<P32GO-;,5SD82ZQ/[\:]1B%XI\9>X5K%RM\O(JQ6(Q[XIB
M`^$Z.7A&+<$O+?D<?JUH@Z+1:/I4?GXHJ/*MM:K_*&`C8=W5^(E<F/<?:$VO
M@!!CB0/;/F@T=ZGDX@V;32&RY)E<I530V1[6]OI&N_]/HY>U_]!"0T]!9;5E
MGVI(Z<'!S[I4MO=#_1D;5R`0L(-K5K^D+9]N$H7H=?CNI?'_5P"V3IW_S@H(
M@24H*FJ#W^+K(>DPN28+L)NK1.:E99NM$DDQA992`44$JK$\<'K(1JRB`+I,
M>P7H"4ZD=)%@1X\=1K!^VQ@T[6NQ,N9`H"UH.``/5"*NWU8!]0Y[4K[K?.^J
MJ:751N36$O94``Y0`G%QF*X`H!R8B$-*!?`DF]C,892M75]JH&+$*[C,\6F2
M`I#WZ&-/&NFA"*Z'""%$F@$C"O*6+?=60-\I:OK82)D\=W6&]<?8_7HN=YXA
M%'0"JI17:&AH4VMOV!H7#>S*I3DJ+%RLG;4/*?I[S%@W;1!]W1%-3OYMUCD$
M1;<TMRG_U67FU=>#I^\,SECOZYVOH?/G=&_`^3]W8'Q\PM`.8`<&3AE@F5-?
MQ-FM$4(R3W6`T7_E`/P#-N$CW@#0"QSE!,J!>A#8P]$1`I[!^"Z_WYRD4#)R
M``JJV>&WVSD#*,811YI\<VL$8X"JY.TR5555JZZNQOHAQ04.,G8`&CO:$S:&
M0A'&7*M''%MCG-O2]CD3_PC*N@90`@W0D$D!!N$9YACDFSG=']*""7D>XH![
M>V3M`*%W_`.AP=,8P@C?"`3GC/.R@W8)/]3K]8[)R`%"65O?;()B#&($!S"*
M0W0<WD/0MV-B6/CE=3Z+Q*WYSL@!0H\2C*,02H?F+,\W4L(Z#C''.4;VX`PC
MOQ,]',S(`4(/Y6.<4.((MW,W1%@CU,S=HXVVB7%&'$/0@PX<2<4%GEY!WJ1@
M[8$OE+>QS!0!*[[SWWC3X(6Q514WGIR!!U6PXA%[`"(4(&=I#NP%_[SU("@O
M)U*R':0#SD$"K\[UG2%K5RC9^OY*34_FZ%CW''M$EKSUL.&?AV6DMU^;@D?M
M,9%5$<)B]$0,XK532+.%R2HK%IAQ>F7#GFIKND0`PHG?FS4*N`48CU?`OSW.
M,"$GIX[KV\/';;SKS0A(#7__S1T3S#W3CO\!@:N9F!+-8.P`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\S-BYP;F<`````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W,S8@,3`U
M,34T,S0Q-#<@,#(V,S$R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*
M8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\```%<$E$0518P[672VB<513'OSQJ-F)+01'!XD:KT*V/A6ZT
MN*AB=>':C6`$"X)@*-VHM-@(31!I2DBEB,84&Z.-`ZF98CMI'HP-(6V9T"0$
MVB8F$VHSQHR=@7%RO+]SYT[N9+X9QQ079[[[/>ZYY_$__W,F$)$`65U=%:YZ
M(]%`<E]8T3?IKCI9N[Y=^C_993\?'_Y,;S*7Z^T#7_0GUQE(\G"#53K5_Z!(
M/)#KW4TR^MTS]C-NQD]N]XYULIX2=LQ,Q_5E/I^S+U(K<S)ZI%$D%L@?[8VZ
MQL9T.FT_&.AKEM,?[Q&)!/J1]`8R<?(I2287R\WD".=VN0U2P2]D9.B,_)GZ
M520_+YE,IE3#Q/AYF3V^0P@`QBU\NE-R0^T;;L[]T*0&$AV\.+*_47X^L=M^
M@`<$1C^(F?`E`LF>"81-OT1/V7.&SNX3Z3;+J!6.&_O^B8TC<&W]YALRT_.T
MK)Q[7A9G/R@:6O2"H%1ULY)@8TUQ(B]J:SXMJ>3GFNUKWSPIJ4B#Y*?V6@=O
M1S0+YWKVEV<"!.3O?BFSG4W681.5=U]^0'+-@=P^4"<77ZF3OE?K]?[HFWO*
M?21+``X`*R@,"(^]U2"9P4"EH[E>[P'+]/C;`M1*8V!2//+C<_8CARJCA+SH
M-6I11J37TZWA8,JDX_KAJ9;'K1N]!>FVN5L^72_#`\W%TTL4_+9PJ^C7U-5^
MF4NTRMI2BUK"B23>;8P-GJ@=S@,_M=66QC#Q"V=+"O!W2PK41Y.5R;Y=LKPX
M)+"%[TIH$(&LTLG?5[24_II\2:,.&DFO6I-*Z#6YM!`>1*H*"">.-DKV<)VF
M3ZO<R)V.Q_39VD<[I,P%*@WNRLZ^IIO)?;:E7LX?ND^K'P@#9ZZ7#2)G9A+E
M%F!:[X>-Q<*'.J`0D(D2N`:%0#I^J:M<`21`\2CR8A;_%[H>4@6N!E#0]GZ3
M93>G`-XA2)1MB0)#_G0%RGAA<)ORUMI7@0:66!'TU,K*1C"`:^L[CVYPERND
M1*&P3(%=.[93YD?W:HI+7"`HD,G4V6?EVP/;K!71PL:HW8QB^&ZLYQ'Q62KP
MP0'70BCXNKD::1:8#TY"D8@55!RN$#SJGD;(1K!!BJ$RG\Y*%,3'(L6FYA2Q
M$=<H;9<Z#B)X56O!52'8@"=8S]^:_N^TKD3K%<Z6^D(UH64B]Z*CY@^)&[W'
MSSH`1GPO61/"?_.\H@%0!5[Y;(@R>)KDDE`23.E!.U0);89G]#50HC@U#5*E
ML)\9(BR/H5;!+GB&<I31'&C^T?;[=4*"<;3_%>B*->1!#5#2-RZ\*#+RNMR(
M'-)>R3O6-:=`PV<*!@@SJW#@TG'+5/`!5`>M\<RMN=*U72='W#WOE@_N+DEA
MJ`%`'H\)-25/01:][2U0@J$&2!F*A#90SIHK9*;/#''SK.N]AXOKKSOVJ>XK
MD\-2/0*&J,@G842!(WAW./Q$%*!8J-6MN7(0*2)J/(/?W1K,^"18-("P`!"*
MGI#C/=2+X)&&WAE0&%>@Z,Z##1HEUACB`(GX6.&>;]%'DW7]$:"7T+D;\>C"
MH!IBQ0`=T?T(Q#=1O2]QC[W-'HR'4^%3=*+;'['+4@#X8"^0ZSS!B,T8T$C$
M/&-BFUJ'UP%<-/$ZF_F].@B)@-:_R14U3?/""!I=28N)5)#"P7C.X0CEJ[H,
M!P#`S:-Z189B.+I[J4%S2SKN7'Q!%=*B2`N'$!F$-=,G[VF:S$+Z?\Q$!9Q4
M:B2A!A`!R@5&TP$*-C.<D$JVZ2Q`:3)T89#^OS%AQT#^!O".U,&6["'D.`+P
M_(EV2[T`U*H2,R9J.9D#P`I1NCK1;9\98QERPB9BP!?6'^ZI&]+D\:Z6*?I_
M:<=XY<^Y6Y%_`"8/GR+);,\:`````$E%3D2N0F""````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S,W+G!N
M9P`````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C,R,B`Q,#4Q-30S-#$T-R`P,C8S,#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@```!ET
M15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```1D241!5%C#W9=Q
M:-1E&,<'_B%A_B/]X3]&!"H$B:&MQ%;8$$(;--3^4"@&-1$2"KMD[F;.\ZI-
MQW%HP^;2-;>E;6E=K'E#:B87-5?+G<W%W'`U&G5@L-5@L/%MGT?>>;?KO%V;
M!OWQ['WOW?L^[_,^S_/]/L\O2U)6O-B?X>%A7>[N5575L9NKKQ7M4V5UG:9V
M('_&YB4N).CHZ1M0Y?NUMW:\5].@-TK\MQ;"X;`2CCBY<>,/1=H[U'8QHK&Q
ML<1+UCR1JX/!*IUM#HMY@H;1T5$MN7^IEBY_2/E;MBI[S5-:G;TVV<R]WNT:
M'Q]7DMFWDX0?Y[]H$W+I^\[D5[2V1?1=M$<7OVZ7U^M55U<TT8;JDQ_9$W<5
M^9-MV.7Q:LO6E^R9VPI>T9-//Y-XQ8I''E.\)&UP<KUGOE*^@OA-]\&,_)"1
MGYS4-YY51U>W^GX9,B$_R#'6ZAM#"@2"R<%V\G)AH9H^:5;GE:LZ=:;%#IO[
M)CV5U@+2"7>^':C4_K<J5%Q:8?."'1[E;7HQO0*RB,W$(G#TA"DKWG](.U[=
M8QE=5%JNZN.UJ9.IK*Q,/,'C\1BF-FQ\5GD;%]B<]#A\Y%V;N_>G="+`)*:A
M4$B_#\Q3QE&X$NW4K,(XZSR8$P6=EZ/&#@`0C)$+?7V]FIB8N#VDAX:&]&6D
MPS*/+!SX]3=U]_8KTM%EF4@D4)A2`0G$`11\^\./EI$H)+P^WP&+#%%*J>#3
MEO.J:6BT@\Q1Q!C/ABF?$(O%+(4A/R@$GCEZO$%%7I_Y(JT"R!`%)?Y#VOGZ
M/OD.'K&15,[-79]>P>XWWS'0@`<8'0%08`))JR`O_WG;".91PLU8`;@`U?H-
MFU,S$F3WP(/+]/"*E<;K<#WHA``YR/_YS27_J&!P<-!02+@<^D!B_G/K!$J)
M/TPT/1HI,S$<NE?(N<^+,T=C,+#=#M?5;)I4\$%F"EI;"M7^U3V:*:23%D9&
M1D1"W34X_^=\<M<,H-Z#41@"`>31G_JM;C$B\870]0K4.!@$+$-5_\J`VI-U
M4TH1+G<7PW<(:S`0%X)&JTB3H&%TV(!0,^Z1``^U$,4(7'GU6K^1*SSIO`!S
M00%0(2^F<T.F,WA&'N`P;1]])^['C7`K+0/"A=`EK2P7([P>`^8D!Z@`<!%=
M@GL=K<;AJA-V,>OP=O#8AT:[$""\A==F;0!NIQWA$O@=+]":,/<4^ZV==!Z`
M=:%Q6)<1KU%09V4`2G@-RE&,:_$`(7"%AH87H_C-B`<PVM4/*EE\&S1C`\AZ
MO@=<*>!5KE`Y-V,@ANWUE^M`><`,XM,&P4.,[$//J=--FK$!P`3W`Q]J$]\?
MU*GL[$>MK.;DY$RM+UZ\:$KX/^N(VX<P)R=`1$8AP'6T'_`ZM8[>-[[:7&A=
M:(TC5>?CIIL5AS/4@G@4S2D5H_"S,RNEO[(4K%BEDCV/V_Q<\S;=42K&?:?K
M"\27#L+ET&HL=MT*-@QW1PWX^=IJ?7/A/OE*7[!P_*^JX=\Q=Y:TE4,%,P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,S)X,S(O,S@N<&YG````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S$S(#$P
M-3$U-#,T,30W(#`R-C,P,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@```01]
M2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!);6%G
M95)E861Y<<EE/```!%U)1$%46,/%EUMLRW$4QY=X\(!(/'D1(D$B(01#8A$D
M\[`0,\'B3HRX/+@4LY+1N<S0U%V1C1G&W"J;K80A%9?)6+&)C8W%0A.2C25+
MMAP^1_[5KKJV;#R<_G_]_7^_<S_?<_Y1(A+E2_I37U\OSUZ^%KO=_G-W57*J
M'#R>+=X3T%=/)_\-/QX5535R],3)7R<.9YZ5=9NV_=IP.IWB=\6@SY^_B.M1
MB13?<TE34Y._D-%C)DB&S2Z7\XN$M1^'QL9&Z=6[G_0;,%"F3DN4Z-%C9=B(
M,8%J;C8OD>;F9@E0NRWR^W.CV"4W;A7+XR>E@5;P\HF[7.[=?R1FLUG*RMS^
M.AP[=5Y--*6D!>JPQF26Z7.6JIFS%JZ0L>,G^HL8/'2D^%+``8.J*SI+4"N(
M7VL?A.6'B/QD4';N92DI>R%5[^N4R`]RC+TS%QQBM=H"@VW0XJ0DR;N2+Z7/
M*^3<I0*]C/N6K]HH(34@G7#GCKV')'7[;DG9FJ'K1<O6R:2$.:$9D$4<)A;6
M(UG*#"9()Z-9VS-S@B=3>GJZ8(+)9-*:BHV-E4EQ771->NP_<%#7AOU!G4AA
M$E.'PR&?:CI)Q%%X[BYM\U+'YT&[,"A]YE9TH`"I,7*ALJI*6EI:VB[INKHZ
MN>TJT<PC"VL^?)27K]^(JZ1,,Y%(P#`H`Q*("S!X\/2%9B0,":_%DJ:1(4I!
M&5R]?E.R<L[K1=8PXEE85!0Z$ST>CZ8PX`>$@#/@:K+9HKX(R0`PA`&T<FVJ
M6#(.Z)/T]D61H`S6;]ZI1<,%-"#OR?^$F8N40C*8&#=5"XB:APF$%A07C'@?
ME`%@![X/&CQ$<9UU='2TJLY%WE.MDZ=,^WT>U-;6:A42+J/ZJ,3X*>.$*B7^
M(%'K:`3-Q")'5X$*"U(BKT:;=8E>/IV5\(/!R<@8.*\GR<.[W27<D@[8:&AH
M$!+JGY7S?\>3?Z8`_9X:!5)`"8K<_>J-]BW0@[71",LKJ[VS`CT.!*&6@:H_
M4N!4]FD5!%,(X0A!*'@'L0<"(3!Q]CPM'HJ&IU$;`&K$,Q+%P]@'8PAK#0O!
M2<,+(!<0`!1B,9,;U!K!(_(`EQG[4`#WXT:PE9$!0B"`Q2C+/(+PZ8GS5(%V
MR0$Z`%BT[VBF"D,(HP;_P6FF!U#3=NRL%W9Q.5[[:P6PFG$$(2`I5B:GINN:
M.9-Q$H7P`*-+7/Q"15W@'**A_I4"N!YK8`[$0[B8$!B-9O6&-%6*_RB&!U":
MWA$_8[YV,M\Q*&P%R'J^!XQ6`#.C41EN9@^+Z7YINZRJ*)\V$![BR3GXG,O-
MD[`5H$Q0@,OT)KX_^O3MK[V)82\F)L:[W[-G#R_QGGT(Q3D'<8><H"(B"@&N
M8_P`U^EUS+Z^W>:.LYL.CG2=BWD_.PYWZ`6^5=2N4`S#:Y>&B'R+$MN>8;)I
MXRA=%^;/"COK_T@!W)>;LT#XTH$0#JQZ/-7:L-^^+>]8!=Y5#M<>;=DR5\/Q
M7YI11]%W&#66C3=<EC,`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\S.2YP
M;F<`````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(T-C,@,3`U,34T,S0Q-#<@,#(V,S$R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````@````(`@&```!!'U*8@````1G04U!``#6V-1/6#(````9
M=$58=%-O9G1W87)E`$%D;V)E($EM86=E4F5A9'EQR64\```$Q4E$0518P^V7
MRV_,413'^Q=()#86$HE(Q`(+"[$@02(:8D$\BJ#Q*&V32<=@**-&">,1)NK1
M4$4T33VBH^A3VFFKHSHUF!8377A$PJ8)21=-<_1S)O=G?J:5(8A@<<WI^9U[
M[GE^SY$F(FF)1_^IJJZ72Q65XMBZ,\[U'CTK/G^QK-SHC#-\P;#T]O;*ID<O
M[?<M'5<#U7+FPA51QJ1I,V7ZW,6R8/D&25^T7-(V.URRKBP@P>86L:XD'@22
M=&)/^;5*N=O0(B5E-Z2GIT?MS'47QJ7\575BA+*;.F6EUR>A4$@^?OJ4;.:0
M9J<LX"^^*,,*8%SQI0IU#[]M`MPD.DO79HOGH%\>/^V2F[=KO\3A\*E2_0@3
M01.Y<+@SKJ:N,2AYC6%Y_>:-,G$U\^")N(;=K1$9&!B0K*PL%2!%I*JFIE:^
MW\T?.4,R2<.)TQ>DO3,B3Z-1S9^GP"LI*<AQ[M"D5]4VR<GS9=+0'-)ZW)CG
M49J(]?7U29("JH.#T(T[]V2#TRO7;M[2F$>>=$M1:;E6SX["8T)>"#.66@K.
MA1[+A,E3M9*6Y>^3,>/&:T07+UFB=%;TM?XB`TW>+`M(`Y=RVKK$Y_/)+O]I
MS9L[?[>L+KTN)75!C06=0.E&(A&["R@P#/RCCA/C$HO%K+]IAE^?QC]'`7U.
M\7^W`F>^5^@@(D\U`FKO/WQ(K1(S<[=K0:&`#@<JJ4H*AQKXIH)H5[?6O;EL
M2IFBH3I1-"3P<6@>$($RY1+0D>W:J[\/.\(*ABC@8*&M$M&ZM<"G0EC`R]1]
MJ/VA/'_^0E\'Y`%G%.`FH&TIP'0BSNN\BK\HQ`U@'M[LA1G*AZ9CZ0N;"YF!
MP0YTY&F@UM?<5\P:/6:LK/&?EVFSYNF+"[U'U/2YZ>D*7S8%-`[-U#'8O@C%
MWK[3U-%8SOH'"BB&1M861"X"@G3DGCM-ZG?&\6(5!BP/501L=%(6:%F0E$ZD
M92^W=HC;[5:TK8W&%!.@;W5&E4Y2T-_?;S&-;^;PS?`2Z;^HG?\M`V@UYC^M
M1[L%6T/:M_0Q/+/Z_'0#:%7ZESYGUK$,,>=8)0`0_FYI:U<4<N0?T+:E<;ZN
MN!\RP.`C#W"84(`LWL,W@$,DP`_D&;Z`#QT-!&!@R@;0C(#2Y2ME`K*S)O`0
MWJ*(U0#EK`H<:+SF,1['R.BSF"(C1IG[I`A]`%GBV+4]#N[B!>$EQ[JC#$X$
M'C6*@5,\!!G96>`1$1XD5=`<#$:7D2%*Z,5(P-&,*)L!@!P7L)C'N8@A#`6\
MY#*'\)-?'B4E[#_PB)R)!G7`82Y@"',1/L9C@-E.;`:`=QBPZG:SXCUG1LXV
M_1TQ<I1,F;]4(1X:/M!O:)3R#1GX'.B)<](M&4,#RF#OD`:`[*`Z56Q&`MZR
M:ZTX<DI<+I>4-(;$,=AZ`#;?R"GI*ZP.ZBP"L*DAO.3`9Z^&C]RP11A^]4[G
M$=:Q+3+DN$3^,`1E3`H>*2HJTNE@-DA:$$/``I9!PV=,&3YZANT"'L=[IB4%
MYPG4Z^"CDE'&/"^_6Z>K*71E(*"SC\J&YBZK+89Q=XOW@&*&X;.U)DZM)`,(
M4V[!?NM_%R8E#%)20DA1@#<F?^9X&MITCI*2Q&^[:EHM?LJ+V?]A]+O/9V%5
MJMPJ%L`O`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S,R>#,R+S0P+G!N9P``````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0U-R`Q
M,#4Q-30S-#$T-R`P,C8S,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$
M?4IB````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA
M9V5296%D>7')93P```3!241!5%C#[9?=2Y-Q%,?]'[KLKB`B(J@;B5X@2RC$
MB\C*J+#"RI)2V,R2EJ5E2:TWRZ0R>G&YV!)M4TLLF(7K18-ERV9F8"^$0>!%
M70AUVN>,WU*W:H;=5!>_/7N>WWG.^9ZW[_D]22*2-'SISZ?/G^5J79-$'Y0=
M/2W![FZQ%A^.B)VNK!2[W2X.AV/D^]%77/5>69UCB>BX>*U>SM>X)3O?)OL.
M'9.D:=-G2/;F+>+Q>+];^=G2G^HK#G%Y6L1>=4G*CI^50+!'?/<>27YA<43J
M3*!73K9UR/;0._&V^/1_EO_)&$R,CP``\?EA1V?4Q:@`:`%',):NS957?7VR
MS;HK`I+H]+QXI9MLX.Z"M)4:2NY50\;RY3(P\$&C[[O;+D^#0>E^_CRB@1A\
M^?)5BOU=NOI>OQ%KBU_&S\W?4C`X."@.ITL\-V\+M6'=O5\25D"R6WU^=;3>
MVZ+.FGHJ*JN0&<DI$J,@T!54(2R>.%<C+WI[]4HH.P-=&L[V!YTJ4WFA5I5G
MY>X4D$8UG3M?+<D9F3)O\3*9,'&2YF+JK-F:.*[)*6EZ3<_(4CE20_M$%5C=
M3?+VW7N9N6:#YHP:;KW3)JD%N]25.=E;==]9UQ#K`B\,KQ\2#FPL#!>V6"PR
M-#0D?SZ-?X$"<D\/TIRT&_E.6`%EZVRXI=U-$U-<M>X;6A_Q%(VXL1\_)?<[
M`EJ^6"?_T&J.=:^45U1+VLJ-VL\Q"L@M38/%2VZ/$B!<S*)DZ0^4@H92!J6I
MD2AL:I\F0@EU3Q_`GB"@5UC(F3[!I>\3(&P![30+5E=MR)7^_M=:C;S(/O!9
M9I]>B2J`DI:45\CDJ=.T%Y@`W,^>.U][@.OTA>G:3"FE1V11:JH0KQ%!S#Q1
MI0&D*W&!%_$3^N2^N;E9JBIKM;EB@@@QTD`,AY+24JE[%H8>".A]*!2238]#
MVIE-@:?J5HP"!+#@<KFU98$/5QMK*"6@2ZH=\>N`J3FZ;0TWFF<H'BWWEW3C
MOPD`NME=<E!KE((>S=WC#H!J@M]H2:8*C<%L8]&J<`!LP\BBE,<"Z*>;\`%]
M#T?`B1BGH:`Y",4\@^)X#I]`P/`$<W3BE%EZ1/@M`,9KZ`^&,TS'.99G+/Y#
M'Q`X3`=9`0!9%H<MHE906!0S3N,"(*^$TGB'IW#S99=7%>(IACFG$!GVE)_#
M#(FG4"U4\S)\I4X``#@S69@R#`>.RC$`*"@,<0!"*4K(-0I0A+=F0!CNQPA\
MCV&HRM'0J*#0@1PUP3T`<(QG''5(#QPY`@"%@U<`01@07$D#SWF1W)J:P!MD
M^)H`(*#8(PW(,7!XA\&$UX!!%U?.53@8MP:<#X/*XLP6.)7Q@!)F"+GD#+;"
MVZHS9H^M1.\A:?9M-INV)X<W[O/R+++MC$/E^4^'0/H<Q>+6`(.-,S:?0YS5
M^.98[^O0G!&A@8^#4NJ\KIXR;@`+`/).QQQH:%-CYIQ'6C(/'I:R\O)?%R'*
M\1ST>.WOZ=?#/IYJ+83_LX]Q.@1C?!#A*0#8QSC[3)ZJFB:=@]1%0FW(4,W8
M423FD\2<5EA\GED?]VCQ4.U$BKXGY$3"R`*,2%VYVJB16[QNO19H0@!0^J,P
MF2/T\-S]BCDY1B4B_W\:?@.>\+\6=<U-'0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#$N
M<&YG`````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R-3`P(#$P-3$U-#,T,30W(#`R-C(W,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````
M&71%6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!-))1$%46,/5
ME_M/DF$4Q_DG_3?\U?F+S2ZLU'EIHT69B9MN2+.TK(8:&<.\00B:2(E&6>2T
M4GH!G>O4Y^B#+W*935O%]OC`^S[/N7[/]QP=(N*P+_VSN;TC!P<'TMC8>/C4
MZ73*\/"PN-WNPP<_?AQ(R94R&?/Q=;G_:%I/.4*AD'1U79?.KIN22J6.A4Y/
M'YVPWU^(+TIBY:V4R7SZ[)4,C@3$-Q*4;UE+L-/*Y:6E]?KA*?1XO5Z]:7;T
M)A*)4A-QA'UK>[NZ'Q7]8N5R.6%U=W=+Q0-9*R?#CZ=D=&Q>W-V/CE6DTVF)
MKZ3%*NSK2ZSO]TW(3/C-<1Q<+I=<NGQ%7#?<<O=NKUR]VBY^O__X@'$MF4Q*
M?7V]9#(9&1T=+8TD?K.3R.;FYG(W46."9@Z?*@ZGCE,Q'-FL9+:^2?:[):OI
MSQ*<65*/;]P:%'RH*B`<#FON(HMK\N+EHCQ\.BMW^IXHL#S]?DT"@M]M;$EH
M:E9,6HM@2*Y^T!C[`Q&]P.^]0D'R^;P$0@O2Z;HG;>U>\7C'5'!K:T<Y'J/1
MJ$Q.3JHEH-=\)PT((D>6997`H40`!T[ZB.FDAG7T<2PM+57/`H$BR8%`H%@V
MUZZU")!"`2"HF84SI_'?$("_7[[NZ!IZ\%#V]_?EU`)BL9CL[.YJ#;)@D/;.
M?FEJ:M(4UA0P.S>GM//NXY=?X$DHF!!`A4--"-K8V"C/0J&0UY2A>2J2T,.@
MS=!#9G/[EQL%%8Q+I!-\%`5$%E:43V++:ZJ5(G*V>)1&]O;VU`K>`7.X!ZCC
M4E$`9K]9_Z15AR!P#X?C,P7$A=:.`>4BWB$(?BX*H(0]'H\,#`PH68`\\(ZI
M\!2%`[MSB?>TCK(@#@T-:?&0!5/>%!&F(HS@4;6D&(5E`CC(,J3!/CX^KKV)
M[/!I:VM3H:9&3J91B\A$EV4*AUY@^IJ]$BL""4Y`"^8:P5C"LZ.2KHU$@H2?
M!)+?Q@4"9Z?KJ@*X3$#9C04T`ZSX-\OYKQA`=H$"86'5HHMS,8`BIQ?17OA.
MAX``J,M=JZ"][/:=>T+[-71T+@;@Z>N5E"JBY[&OIK=D['E,&Z;O?E`@$K@@
MNOQ>Z_W"I1ZM=\@$Y)W$_:D-@(WQ!I*!H9+K&54R%UV3YU.'E,>[M0^;$@C&
ME?8@&PS\M/E5.SC/;][J*0XC,%M-`P@S[(50*'`FLJSS(:''"!B>SHYW\"TS
M*='P3\P)U8X"I@$B`J5R'D>84^!B^+FAH5%)K\P`0(5B%#";D&,\"<=3ZCU4
MV^=]IE["S9`\@J%<=LY@*,,L](N1?#<\SC.BQ/17<7Y#$%S&N`RH4&P?DLCK
M16>O\CV&82P8`1>$>R(8TW,HYAS*>$8:B!!8\?E&I*ZN3L>=JAB`[S@`?4/I
M]`",(\2@GYW2`Q^P,ZP%;T)Y@`X6!WC<A<W@5GYSUA[ZFO,E@QF7V0F7_;\+
M!#-0TV,8G\P[HF=O$W0%%&,`BDV#HV?5-``/60@#O7AH9E'[0CG]BW><Q3!P
M8Y]WZ2``DQTYOU6&MHE2HX)`PDYG`=F5F@AI('4LO`6<9V9"@(;UL!Q>L_AM
M6C]_3/<&.^`%Y6;&KM1#?\L`!*",,))GAA<\/<G_Y!S#2!LY1SE&5"*?/](-
M478TNSA,E/Z+=OP3(]&<6POS%;P`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\S,G@S,B\T,BYP;F<`````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-S<@
M,3`U,34T,S0Q-#<@,#(V,S$Q`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!
M!'U*8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM
M86=E4F5A9'EQR64\```$T4E$0518P]6764^341"&^R?Y%=QPI>$&)0HBH`()
MQ&J116TL*&H!ET):"!;92DH+TJ)%0!%$D*W4EA!'GX%3/N@2B!BQR>&TWW?.
MK.^\,]A$Q&9=^F=E;5/V]O:DN+AX_VEY>;FXW6ZQV^W[#W[^W),C5S)DC(7G
MY&G7D)ZR^?U^J:VMDYK:VQ*+Q0Z%#@T=G+#>GPA/2B3Z03)DOO*.29O;)^WN
M`=G8B@MV[B124EE5MW\*/2Z72V^:';V12.2HB3C"OKJVEMN/K'ZQ$HF$L!P.
MAV0]$-_9D><O!J6[9TSLCJY#%0L+"Q**SLM.,J4OD?*@[;4,!]X?QJ&^OEZN
M7"V3^@:[-#4U2T7%3?%X/(<'C&LS,S-25%0DR\O+TMW=?322^,U.(DM+2S/=
M1(T)FCE\HCB<.$YF;6]OR]*W#=F*)V3NTU<9&)Y2CQONM`D^Y!00"`0T=^.3
ML]+_-BR=KT:DL?6E`JOYH4?#A^#YQ57Q#XZ(26L:#-'89T5(CR^@%_B=3/[0
MBPBL:7@B-VI<TNKRJN"JJEN9>`P&@]+?WZ^6@%[SG30@C!R1<2L<C@C@P'$?
ML8#4L`X^MJFIJ=Q9(%`DV>?SI<OF^O5*`5(H``1YL_#':3P?`O!W?7U=B[_C
M6:?L[N[*B06$0B'9W-J2X/0GQ0)"R'])28FF,*^`D=%1I9WY+QOB\T?2`JCP
MU]X)J:E[*(N+BYE92":3FC(N#XY'!!X#;88>EE:^2RJ54L&X1#K!1UK`^$14
M^20T/:M:8PLK4EYY7VF$BUC!.V".&T`=E]("J+SW<TM:=0@"]W`XA[G,A:I;
M3G&V>_4=@N#GM`!*N*6E19Q.IY(%R`/OF`I/43BP.Y=X3^O("&)'1X<6#UDP
MY4T182K""!Y52XI1F"&`@RQ#&NR]O;W:F\@.G^KJ:A5J:N1X&K6(3'19IG#H
M!::O62LQ*Y#@!+1@KA&,)3P[*.G\2"1(^$D@^6U<('!6NLXI@,L$E-U84%A8
MJ%:<SW+^)P:07:!`6%CYZ.),#(!>Z$7>-T$M>*!&EZ#4*,-`>%;N-CX6VJ^A
MHS,Q`$_?16.J!*4HA"@\?6%MF.U/!P0BP2CXCWJ_=*5):>M:A4.1=QSW)S8`
M1L8;2`:&8D?):/"C]`WN4Q[/:/_>@;#2'F2#@=`?'9SGM^_<2P\C,%M>`P@S
M[1^AL-CP^+3.AX0>(YBT6A[U*%7"MX2^MR^H[$:UHX#4$!$,X?SJ1EPC"!?#
MSQ<N%BOI91@`J+`:!8P2D#R>H&3FX[)2+6,%7L+-O$.PP0%G,)1A%OK%2+YS
MEFCQC"@Q_66=WQ`$ES$N,R"AV#HDP>.7RYJ4[TV4P$C\-S9,N#F'XJO7FE49
MSU@8`%8>M[NEH*!`QYV<&(#O.`!]0^GT`(P#$X274%-ZX`-VAK7@32@/T,'B
M`(^[L!G<RF_.6D.?=[YD,.,R.^&R_G>!8`9J>@SCDWE']*QM@JI!,0:@V#0X
M>E9>`_"0A3#0BX=F%K4NE-._>,=9#`,WUGF7#@(PV9%SJC*T3)0:%002=CH+
MZ<C61$@#J6.94?:/F1"@83TLA]<L?IO6SQ_3O<$.2E%N9NQL/?14!B``9821
M/#.\X.EQ_B?G&$;:R#G*,2(;^?R5;HBR@]G%9J+T7[3C7WN6G#I+*ZS#````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S,R>#,R+S0S
M+G!N9P`````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C8T,2`Q,#4Q-30S-#$T-R`P,C8S,#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```"`````@"`8```$$?4IB````!&=!34$``-;8U$]8,@``
M`!ET15AT4V]F='=A<F4`061O8F4@26UA9V5296%D>7')93P```4S241!5%C#
MS=?M2]97&`?P_KFQ5PW'V)O67A5[$<1:;&M2%(V5%,@P-Z-2I^[.TE:6*9HX
MLSM#7";B/;<,B449K=D#$1+V<&V?XW[J+W636"SA^'LZYWKX7M_K>\Z])B+6
M+![I7V5E9;2UM<7.G3OGWA8*A6AN;HY]^_;-O7CQXD48\TMR-AX_?AR6;-^^
M(W;OWAUK!@8&HJ>G)X[4%:)4*LU-:VQL3+.6V!@='8VIJ:E8$M?1UK-Q_?KU
MJ*BH2"N'AH:BIJ8F6DX5YV;-SLY&75U=/'OV+%AY^/!A]/;VQM6K5Q=,B?O:
MM6MITL3$1.1<_-.8OWGRY$E,3T_'P*7!I4'6UM:FP+JZNF+;MO+8LV=/PBU-
MN'W[=@KHT:-'*8O?;MQ(@6[:M&D!AT.'#L?A(]^E43AZ+*%V\N3)^0DI=S"Z
M5E=7)PN#@X,Y)$,1.SHZHE@LIGA>SB+%8/@X/#R\>AQ6C1.34#Y^_'B`1;R2
M,<ZT=\9G7^Q-]5.>D9&10).<`;&?/GTZ.CL[H[N[.]9]L#XA`4+CQ(D?HJ&A
M(<K+RU.N%XH7%PQ`961T/(%OX5MOKXU//R]/6&_8L&'^W7OO?QCKUF^,KRIJ
MH_3S5!Y%X5=55:4(=(`0@=77UQ?]_?V)2)#&[ENW;@5J+`'Q^?/G:1%Z&AF'
ML._.G3LI17^XO6P54%8DN`U(.3]]^C3NW;N7<!!51H#74L8WR`#``/?[']/Q
MT^4KL2H#``00`#'O6.NIOXAT-@Y\<S"Q4*,"LJ6E)=K;VQ.X.0,05B;M1A8Q
MSE!6U<@8BA,Z/L<##WC.,@\FHS%#O"*0]Q11>MB92V%X>"0J]E>F.O.Z=>O6
MY`GG,=$SKQ]O^20U4U]Q-,[UGE^(@%5YKWWGW<3WS5N^3/S/AG=Z00^X4M2<
M-E-2_-=QAG!A@?<B:6L[$]_6'$Y7F%"_7`HJ@/L668#K]@8&Z`-\T%FSS<S,
MI#DY`YJ(,IH@-,\V&N#I">AG#F`T.3F9Y&T)#UI;6R/;+#25H=XBH,>J92'C
MRTH:(SY:P+,%<A:=5!:'OJP!H?,D#>%GPN'^YLV;J<R93JRH!XS8!/2"9RF0
M/!OW8CE_<]KY?PD`\\%AEQL?_R7^_GM]`:".@\&%@;%49*2^?W]AT*V>'Z\D
M^<GH]LH!Z!1;$,8T-34E$7#J0@)B0)H\HZ9KID($`W4UBG9&6>SS;*VYU,A>
MZ:2S8@"B)ZP,ZWD!,*`;.=7BWG'*N$`Y,]_@E*YF5_.Q6+G*RLIB;&QLY3;@
MV`Y/U>DH.51O#J$B>SL^A_7U]2EC#6HN_3$O"Y0>>[83^$:#26C;V<&,-_D`
MD.K7B<DX<+"0E(]147-*H_3FQH\VIRR]EZ$YG@7N'LQ.NH)V3#$?>D31MO1]
M\_GH.C<6C4V%6/84"G)PE<8G$Q*()>+:AH[XNKHU]NXOI/LK(Z4T)Q,,F\3%
MH5+2>7-V[#J8KM;:/#JZ+T5_\7):@ZAW[]Z-%:6,@"(BPF2P@MPBW2!#^X7R
MR![4I,_ISCMSJ;5[4$/*<3`KJ5*NJ*69]"D')H.18X%P(EMM9J_E",$85G/H
M>6=SDP3-53X<L=X\-I3CP8,'*W>!()0#"AG+&>(@^ZD$*<'(SA:4G1ZU%^?F
M$']<$3`.6?_R+Z%5"1%G!HAE;E.$#,-9,%#C4$!XP:%,\<GW5U'"G'&UPP4P
MRCSK=S6&EA+X!F[UAAYNX(K`7EF*L^.R>C+HEQ9UA(!,%P?I4`,=]?8=Y/CP
M;[+\G^YL3A/96846+%?S-VX[_A-GM&[F<K&,\@````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,S)X,S(O-#0N<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#,W
M(#$P-3$U-#,T,30W(#`R-C,P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````(````"`(!@``
M`01]2F(````$9T%-00``UMC43U@R````&71%6'13;V9T=V%R90!!9&]B92!)
M;6%G95)E861Y<<EE/```!;%)1$%46,.METML5&44Q\>&2&2A01`2UFX,55RP
M1!,WP@+9^"`UL+&))"QLH@1QHXE*;,`'/K"5!&DA(2'44CH)M#2V4$)!QM+"
MM(6V]&$?=J;M6-(Z3>JU/7R_<_TN]\[<L5/"XO3._>[W.(___W^^1D0D@LU,
M3PM/?8E^_*1@'[R[7B+I>S'I[.R0$Z<:)7YGP)W>TEPI-0<+Y=C^]>Z`W_3/
MUSN?T/4Z,%&_0JJC5R613$K?X*B9MC`C>XK62>G[A0^.]<Q\+-G]A@ST1O7C
MPL*\^R']5YTXE1'IZ>V5KIXAF9J:DF\/5PO.ZX1K]4725[92JK[9(N6?O2KG
M3GXJ1\J^E(J*8]EN<H0-.]L'R1&7C?Z?[I=$YD=D;FXNN,-TRW.:EO&R`FDX
M6RG$'IAPN^)QF3__F*12*4T*$>"+3NBZM%D^+WY*8NT]ZAS98N(?(TDI+2UE
M&T?JJU[7$'_XHEC#Y/G)OFU:)CVB_<Q&^3?^O-SYN5#F+JR65,<VSU$O"HHA
MZ3K)&6:HI:NDO+Q<\LH3]<)I"HH[5/O>+P6R8^M:S9_BP[DELY,GW7G!#1P-
M2&8/:48H?.)$@6)P8G)2BT]V]GVX5\B:OQ@//##@)1DW]B_3HK"`#:[$NJ7I
M<IM$ZV*::E+,-X`2S('9E0U(%J>R\%1UL]:#18SQ3A'9[.CQ>BUF("'.Q$="
MU>-?/2T+IR,!`Z[D!.@2<E82QQ-=7ES4L?OF`4WF.V\^J[FA\"R$)34U9_*$
MLZF(C771,H89V<^;+V'6=.Z]A]C`5$-C-,_^FI62&K^LO_VAD(>L#<@NJ@':
M?CV\3O[N>$6SWGC\17&N+A/UQN2$YY]CR9`DFH],!,((%X""X2@,%1B^N$F_
M9R;5*R$&YM%5Z@Y_T3!`E!QW0:1\,"7-TA2EZ\6U>C*+D5Z0Q\(+33=UH];X
MH*(/(C5?J@T!4G>)#!Q:KAZT73OO+0*V=C%E)7Y(U=KZN\N%V]=W":<C6C^6
M/*.$@40\X0'8QQ,68W`$[4+</$FR/&BI^]Y;"`,YE<F$@Q=LQAC&1E1-%X_<
M_4ZJ?BI6-J)K?@%DW+ZC]SP)(8O.@(,P2"2"XF<B[U:=P$DH$@$._"84$(@W
M5`./8D=6R&Q_D8L3GYP%)(V8^3WO)%WJFGJS`$T''[9T@WU-XB=9"$$<KWV-
M_?:"#(\,Z6]D;,EL'.BI#J!NR1O\KQF&$E9C8\.BE'\$#CB:-W]GIU@4"DCX
MY8'?S%TL\AP..$IJHO(7BL(FXF]I<=%J)?3U-7H/0+-ADQ;=.$71P:M?^%D/
M]<+J&.H5D(.>'(@<L3$-`CB^MFF58AU,\QO#"32`CL0XS9,U-!?V`=Z6^WF6
MP-&+!,2B0W,(.H$^0BR><`2&(CQH!49/)7OV6L`:@E!5]V4DAP..3(Z>5N]1
M<7L;)3++;)QAG$/16<J$[J`SMSK[E8NH'4J([F!(!V6A8U":S$R$HIMZT@&L
MN-O#B9@H;<3V<(3-WO`80RGM_9KOO'/+@C4X'>AIZ9DA!18>@FIDB/1Q2:(M
M(89$W-'>HIMS&&;O/2BKO:[0/.@\.,-!9,G>A<B,=9RY.,2W0/1$,#;<H*@F
MU0"0=!(-3V2=)QMB;$1T',C&]D`.(W)*PEH<9!U.VS70-]!/+%WH;-`+Q`.F
MT7BM]@T.I,Y$:3?%&.-`2F/[KS\S&`<RQEI[6\0!YF9I,(8CX(#[/TBFU5HL
M4)Y,@RT\`2M&Z;B:D$5`38EI`@#0?R7)34/3L^@DX($LP`9`26OBYHE#]C`H
MR3OC?$_4;I!4=+6NQPDTP#:4O)20*SRTH>_I/Q;FOH1#"-&5HZOT:D/OY+\1
M(@>L.,AWJXQT>-9P:1]KVZI4]-]HE]X+##7U/U4VP2'SCM(1Y=O;7Y;V&^Y5
MDD.]>1E[T!O"^L/#=T-S&/T!,.5SBW[T[?B_J#)!M52[#T\$,'V[/<\J````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T
M:&5R9&]T8V]M+S,R>#,R+S0U+G!N9P``````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$R-"`Q,#4Q
M-30S-#$T-R`P,C8S,#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```"`````@"`8```$$?4IB
M````!&=!34$``-;8U$]8,@```!ET15AT4V]F='=A<F4`061O8F4@26UA9V52
M96%D>7')93P```/F241!5%B%I9>[CTU1%(?O/X/_04&ME4CT&DJ5!!&=0J@D
M)!)&03&9>!04(B8R*,R$9`@R$\^0:!0SA5"P^?;UG5E[GWW/O<D4^YYU]EF/
MWUI[/?8=I91&<>6?MZ\?I!?+-_/*&_?N+Z8S9\^E^5MWMS:N7CJ=KMQ8*.4[
M'9\^+F6./[]_I-'7+Y_3Q<MS:?7EJY1^O4NC"T]6\]?=>_:F3H0%.Z)`X`EW
MQ\!'/@"#=?#0D?3XX;7T<^/96!HXQT^>RA^Q!0/O^_8?&#,``MM\@$8`NL`P
M:77$]V^+&<>']97\!-<6PS_$('<9R"(RV`;DHZ6GV8,[\^?'D8*!P!#@PT=/
M9'#+*\^S%YEA<V,SK:VMYX^&%?<*+_B`FX27<\-$QZ#_V-=_M/3<C`O;+$*-
M^RP\=;\9)P41:H4$6%UX_BOK90/")B1A`C9PH:,BHE9DBPI@(`C$FJ0P.=@S
MQ`9)%)T"`J1%PLX3(<Z$=Q7Q#F\OH1%@TS/:N6-7?J($FGUH>3#6*>"PT<R1
M8<GT90]F7,-O:#*&<R].`6@H@38!9+*HI6,.S%0/,]=+G0]$V23B>./9#RL(
MM45.V"5XOG]S>S@3%5:(11+%+*R5%+`M^VC5S.04H&,2E0B"=9B(O">@=5,Y
MHN@I4)!LXTE:TQU8",=VTE,`3)*'9.*)`IYD((K)0A`V%0#/U@LS%GF26"BB
M'NQ;[!<*@"MDK=K<+"1<L=!0DL>%"NSK+&B$2668[9`6DR7-?N$"'^O*@^;)
M._Y;B:PB#ZPZ+.(*]+'K"SE86(>V2T%;>)T"_,%W!/'5QD)),TN`#(U;5F:G
M@&C:MFWZ,$.S#^U0M$<4"H`=ZQT7@.@Q$0-I>\6V^H&S8=K:5C^99-!!%>=.
M:]4]:`C05.,VMMJ(G2)>K%I[%/X0D$&OZ^;8`D%J.CCI!2P:1@3">QSO@P#J
M<$>O!&%-:"Q>`V+SC0#@;X&8&G85D.DLLMP>8Y^A3&Q2\1H1EY&:&0!GAZ!=
M,38\GEXWO?:QO'[9=I"-@T``[8E2`=`XANRR=AD!V'DU3!2@X?,.P)YST=OU
M1``T$#W60-WJ5>I%TXN7,\-E1-@7-'S^C>@=@7U2I4XUQX2#"B7P>`,T#P3K
M,#,B-6B.!MEF#L"(<+PI\NY(8?&N5W%V.SWE<R1%,%X.'8;-(XC_:1@]&G7?
M88$B^:39]W:JK)/((3O8B`B-Y63(";&*>:<\32B\YTS9<V(908#Y[X5]]@9;
M,<9![7E#F]4H(SKN:T0>CPN#D<?].,";`**7GD]4A@=>:J#A)Y-YPJ,L,I/V
MIPZC2<,"X2$/D`%T;029UGZ]_@+-Z3G;";P;6P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O-#8N<&YG
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,34V(#$P-3$U-#,T,30W(#`R-C,P-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````(````"`(!@```01]2F(````$9T%-00``UMC43U@R````&71%
M6'13;V9T=V%R90!!9&]B92!);6%G95)E861Y<<EE/```!`!)1$%46(6EESUK
M%4$4AO,[K;7R!]@*@F`7$*LT5FEB$5"K$!1,L%"BC5=C(2:"5U")1F)(<!WW
MF;G/[MF/>V^"Q6%W=L['>SYG=B6EM)*I^IEXYL7^V^WZ426>^</>ZTDZ_G62
M/AY.RX>UM?5T\\:U=._NZDR^K^/=_J?T8'TU_3G92RN/'C])B&QMO\QB6>'?
MLP_IU8O-]/OT-.BHS1X>[&;3/+]/"Y2&`1A('_TX3MA`+78:ACNW;Z7K5Z\D
M;&*+-<@:AJ_?CC)NWC<V-I/?`X:"H_A3#1GP"8`2GK0,M12@SL[/LQG`/=VZ
MWWIQ\/YA^CS]DH.!?;S(#(#<V7F678.!://$`[QIO(`!%]G`A-1@*(LJ?R0&
M8$"HXP4@86)C,IG,BT.;6]S$=7(BL2[NC\3)0,)D4O&8K!L6WB&BTHUC"#9"
ME`FI(VQ$P\A`*$`92CJYIE(((T*\HPB_4;#[_$U.$OO$``,$JU%`J;&!59@1
MY"FSWZQLUEE!K%>K#":@VC40:^(2TS4:1*";>"P;6*J%)PCYUNZ-I!$_00$:
M@L<W%/".96(1^<?K(/:&%'*_1$$1G%M$LP$RMY!@(F`6DU/"-8JBDHX"A+$&
M8ZQ`UQ915C)SJ6,=89AR+]9KZP-%!%`ET+"4:UALD`6+!T6DSMI`"0B<FP,%
M"#`N(!2@S"'(.]\0;A7,*I'^AF(O6,XV%^2@IRXZ"H")=<<N2B"8%73*VVCE
M&)FYP*9P9528RD,`_VUOD)'63@Q@AI$FBL0P]$D@\9]@#]((-'R#`0&B'2,/
M8<!X#0H)V#`[C[&"@%9M9_ALLD$EJMF17&!666EL]87-9,!*-98,^>U"W>@L
M*.=`0:4K8TH6S(/%,X)>D&SU/K5S9'R67`)`U3FH'`_S*,Z@[AP:`KF0X3&C
M\;(0QTU_[4$X#\A\X[,P1X/.N%Q1]3X51;%X*6$_OBO#DS[`D3Z(I9XCC$(Z
M%8,>L%0GY('LU/(HC!%Q$*.G"V+!Y01&!#`(>5UP5#I3G'3]PSO.8,%X0K3'
M2C4T[FU-KS5(.WDKP#BMY=JVB[<)AB&`O==XJCC+O64UAO'2J8IB##IZ4>SQ
MQ!X*^:X14\/:B[TCO4R>JAGSR'JQZ@!@D*($1@S[CG&]-KPQ+7H;SPQG)B#]
MIBQ[_I(,:B"./:^#'`-]4KGO&E4FDM=F[VM>LQ:V(:AAQ(AG</^,4J'_)_%^
M;JXA]+`//WE?>C4S[R+UEX%90.[B(8DAWC%$%.(M7.-0_+-8>AI)5K:1:,-6
M9KM#!Z.`L[=]4L1T@->B>(9>^BSPQBOUO3!M`&6O!;U<]U*&6`MTA9$!U%BT
M_`&PCOX;@'5A<;7U,00:6]!_PD5',?0/2-3K((#((R<`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A
M=&AE<F1O=&-O;2\S,G@S,B\P+G!N9P``````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-#4@,3`U
M,34T,S0Q-#<@,#(V,C$V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````@````(`@&```!!'U*
M8@````1G04U!``#6V-1/6#(````9=$58=%-O9G1W87)E`$%D;V)E($EM86=E
M4F5A9'EQR64\```$MTE$0518P]677TS35Q3',=G#?%KVY!(S7R:)B<'LSX,Q
M/K#%N&BF:$*4*?JP"%-'"#@L6XA_.T19;`)5YIQT@@PR_H.AL';5N,E(0$0-
MX*;#9<JRV5A)$TF(&CSZ.>9":W\MEF4N/!SN_=W>>\ZYYY[O]QP21"0A5/1/
MJ?.H7+YZ7<;&QIZN9GVZ2XI+OI:)'</#?\G]X*S)A0@=UX>&I+JN:7)'=6.+
M[#[@>+KPX,%#<;>[Y8MO:B-U]%X9D%^'_I0;P_](?4M;^(:ER<OEH*-,&MN\
MPCS,Z/CXN,R=]X8L>GNQ)"];(0L7O:-CA(F\'1^)I=NQ9&(R,#@H??V_R>"U
M&SIZS_X4;@*O"2`_$*H(#02C]0>?Y'YFEV`P&+XA;5.FK%R[4?85E0B1YS9A
M&UC@:HD+DE3>6[E&ZAH:)GWXQ'=>D`M=LR5SV[:)'\-\N-(S7V)><[IBN<B#
M\K"__W%3;OWMU]BU><^I>ZGKTZ6@P"Z!0,`ZH]A`N,YV]<C)FF9]?`ZG9V2)
MW^^/_90UW]5)P?Y#4GK,I2-A/>P\(2;,%965L140XLV9.7K`_N41=9=,YFU0
MB"Q>DBQ1%335>^1`Z9&)^Y^L29)'HPF2NJ]07Y]LB.H![MN.?B5W`R-27EZE
ML-N4_K[D?[M32,03C<TO\!G_?P5@JZNO7Q,(@25(+G*#WT+S(>(P;\TK`$X.
MD8G,\VSYFHD\,;P450%)!*JQW-E]44>LH@"ZC'D%Z`E.)'61V@:W'D:P/F4,
MRHZ7:QISP%55JS@`#UNS;>KZE`K(=]B3],W(^ES*GB04(_)L"ELJ``<H@;@X
MC#(`9<!$'*(J\/E\NHG-'$;9ENUY"BI&O(++V&>I`.3![R`21<PA0@B18L"(
M@E6KUU@KH.YDEAU74H906IH\<F?X)7DW^75%*%4+4$6]@M-9):<Z/%JX2)2;
MUUZ6M+2WQ.EX5?RW`\JZ,8.8==HKHZ/WU#J'H&A@G;+Y`_7JYZ[NYX,SUL^T
M)\K%OEZ9&7!^X0Z,C`05[0"VL_,7!2QSA#B;-4((+Y,=8/1?.0#_@$WXB.8`
M>H&CC$`Y4`\">\!E[$'`,Q@_['`H"$B4N!R`@HH..O1VQ@B*<<20)M_<&L$8
MH,K-L8G=7BC%Q45:#TDN]L;M`#36ZO8H0Y'6@,F4>L2P-<:Y+66?,Z%-T+1S
M`"70``69)\`@/,,<@WPSI_I#6I`7[2$.F-YCV@X0>L,_$!H\C2&,\(V8UL-T
M=M`NX8=ZK?J8N!P@E#3IATJ/J6(,8@0',(I#5!P*!O1MF!@6II$B$L^^=UP.
MH`#!.`JA=&A.W_G)D[!N>B:<8V0/SC!2Q8@>'4]<#A!Z*!_CA)(<X';FA@AK
MA)JY:=HPB'%&'$-P`!V,T;C`TBO(FR?84O&]K-AA4X>`%=\I'V]5>&'LPUT;
ME/A3U[VF#2!"`G*6XL!>\.]RN92@K)R(RG:0#C@'"72=VYO<6JY0LG_O>NTZ
M&^I>T28R-WN.XI_&TMMQ7O)J6Z,VDU,Z`,%0$S&(UT8AQ18FVUWPIAK76EE2
MJ$67"$`XH7NGC0)N`<9#%?!OCWU/HAJFY^9-#=?7>W[4:O^?%R,@-=!_Z;D)
M9L:4X\=A)IF_D1-ID`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0W+G!N
M9P`````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C<T-B`Q,#4Q-30S-#$T-B`P,C8S,30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@@3=#2$30``
M``9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!7-)1$%4
M2,>%E=MS$W44Q[_9>YI[VJ9)FMZ@*:U0RE4'1\=A4-`9?7+@T?%O<$1?=7Q0
MGWS@G1&'!Q]\\(F1%J%@RZ`(CK2E+2TIS:6YIVF3W2:[FUW/+DY!@?++[&RR
MF_V<<[[G?'_KP$N6T6ITTVD4IOH3_7*99FO[GH,^<'!TL)\#[#VZ-,>P4NK)
M_9W!9PGZM@/:24,O0]-DZ)JR?5^4W&`8B2@B\?UTEJ[2Y=,4H+(CG,`!0)\R
MM/PKBER$W#"AJDV8A@&'PP&&Y<#Q/%AH<#E%"N0!PX>)Z)RDQS^T`CA>`(Y2
MQN?5QMJI6KT*94N#:9K84K8(RM@!6)8%+PI0&TVJ2$/`)R+8W@5!ZK8"6!5\
M_`)X[2KT\O%2)4M@U09;15IGTS203:7`"X*=.<<+=C##:,'G\Z"WIP>L$+$D
M>L_QG*SWR?7"G71J42@4JBBL.^`6FU`TZ7&`9@&;"@-)9*!4U^`+^A&+A>#U
M>J'(-42C`83#?=3GB,H])_&O_K@S(S"<'RY?)T9[?.`X%H:5O760WI;FLBSC
M_NP<5K(Y9`M)'#O:AU:KA=1J#NWM'1"XEO`,_.:MNVCO'"``0U#.8E&6'!CZ
M4I,;J%:KF!@?AU*OH58O@V?JZ(ET0VUVV97EUS+HW]V/D*3C/_#Q*]?VS"\L
M]L:'AA$(!NQ9DF4%6UL-L)3]YL8FUM<K2*[<Q>N'8PAT'H%+5"&0_KPHV0S)
MZ42U4D$H5`/S-#R93!]G.?%0E0#%?(Z:9%"FZ]!US:Y"4U7D<WFT.7VD\VZ$
M0TZ$(E%P`D_WFK:I1$FR)\A:VW!JI"B*_$"U6K;'3%4UK"02V-RL(9%8P>^W
M;B*5SF`UF48AGT9B:0$-1;:A<JT&27+"[?5!H`JL<06)LBU+8B4=,0W]LZ7E
M1U12%P5K88-D&(S'21:%@NE(90CZ<)FJR4%IM".;R<!;K\/K]\-/3;3ZP]-X
M>GT!F`[7$SC/L]]-7I^&Q^=#J52!2L9H-E7\/3,+B32MU66";CPV-2-20,V6
MJ<WELI^W>M+26S3W+/P!/P5Z*O-[<\O#O;T]=G,:#85<9T!OD;7;)/A]+F1S
M.>36TK;M)7<_FKH/>_:-VB:R#*61C):9?(%VN-T=E`-S?5OS='H5ZY19,I7!
MPH-E<IL7L>XNJD!'I2H30(3?3P:)1&@T)22S,C+TWV:#)HGE;+@U_Z'.(&UB
M'DN+;VQXI5SLGIU;E/*%HMU()SWL]GB0SA2Q1($*Q:)MI#:7F[(S$8[&P$OM
MN'1UUK[.,`XRD+6!,7!Y!IJFP_D%8:_9LDS=O/UI(;_67RX5208W6%'$U/0T
MBKDL#)BVGD&:>ZNQ-%)DF`;-?QVEPAJFIV[C^(DW:$_IAL\?)?'%;QFV[4O8
M\T(K5RCK#,N:5EWY?(8,U($J0;-K26IP@"R]@,2R03N>"_+F!E7E18OTU70#
M\RMUG."CM,<,-N#@SQ']ZV=>%I<GI^>O_'EWF*U6,';H`&8?/,3AO2-X4$K@
MG;%SN#PQ@O3Z?AP;C8-W>S&_F,"9=\<V.D*1:X%`CR:(KC/_WTJX?PUT^OY2
M*CS<'4;?X0-PD!GV&_BY*R0>B?5_'PL'5\%C!`>'XABBK6'#<."#6`R[XH.?
M.)W>\R]ZX3`$=MU;3+[_UZ.,OZ<C"#/8B=\F?D5[T/N64OHE5$GGL?K(@ZYH
M&?%=4:15X,;X%<NI9T5!N(`=%D-&>;/.L!_=N3%ISRNKT]/J!M2M\4!?_*(P
M,W,*Y<IKF+[.H;E50Y7FO4U@,#JZMT2OLM9.<(YE&'A,#7L&8HCO[K_D=(H!
M]>#6L8ZN'W'AAP".OGH2LE+'O@-U#(V,71QLZ4>4H;Y\1\`[@9>L?P`B'':5
M('Y_-@````!)14Y$KD)@@@``````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,2YP;F<`````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S(R(#$P
M-3$U-#,T,30V(#`R-C(Q,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P-.AKBWM;!````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```$7TE$051(B>V47TS;513']^BS,3%9-/+DF_'%
MS&0QBVX22:93V1AA,`=,H-".OX7^`80RX%=@A?X1*!W%%OH/VM*-CI:Q`@76
M`O)/RK_2T)9%Q<%@L`$MCK"OUT8P,^/!Q`=-/,G-R3VY]W-/ON><>^S8__:O
MM2I1O8K!Y)HZK?=4_PC0.3P2WFL?#(KK9$&=P0R'<QA:_2U0`G&PH5%1ZO7Z
MW_O;4(?3>=W8WDZ55U2N%/(H?%LO@U*E0ZO>"+E2#8&H#FF9>>"55:ZDI-*I
M/KN=<C@<E)WX#K.9<KL7J&?/]MX^!.[O[Q\/!`*37J]WLIRBGI,%BL]'=@X3
M>2PVF+D$5E(":8,,+!8+M-0T,-(SH%`JP>86@,^O`(_'"]UI:]-C??UQQ"&<
MO!2VL;$)A\,)-IL-@4``:U<7N<1':6DIQ&(Q6'DLV'IZ4%%1@<RL[)"72"0H
M*BI&34T-FIM;D)6=0^1SS@:"P7<.X3L[@;"9F5ET6BPAH%ZO1T='!X1B"<F:
MA3:R+RLK@\UF@T[7BH*"0JC5FM"C&9G9)*8+[1.2Z5A>_J7F!9U5.GT$E^BK
M-YJ@UFBAT6A(EKV0RYM"4*%0"*%(!)5*A?[^_I`$,ME-2*52Q%Y)@)+(DY&5
M@YA$!NID3;M;6]MG#O2.4*BTCZIK&Z'6MI*,S:"(YK]#N/D%T!L,X'`X*"XN
M1GU]/4C1"+0!=SH[P>'FXUIZ.AKE<ESZ*A&1<<DHH:K@]?DB#N!O7><+EB0R
M!1J:6I"81,/%V"LX^\4%1,;$(_YK&K@$DD9G@'$M'7'Q5Q$5$X?PB+,X<?(4
M8J_2$7$N$A^?BT)2!@?E52+X_/X_"SKO7I!R*H6@\TB'<(N1R"S"Z7/1"/_L
M(J(93'!)G/U-.?+X0J3G%N+SZ'B<_.1+?!#^*<Y?3D$4/1<)M`PP\XMAM5H7
M-C<WWSV$]\^XP^2N!7Q(ST:;@>C>U0.9L@5">0MB;JJ0R>:"^DZ#\R(91)):
M:(VW42)M@D!8"T9I-9*;6T&&36%L-\4_?+ARXH6"NE;63XL&1U$DKO591J>?
MYXKJX5[PP#SK16*#`M/N!4P]^`ECQ/N(KS99T'&W.S`V,;V<:[&C[O:=S=W=
MW0LOG<K[_I_GM?=Z,3(RUIS=[=A+JZK&HF\)EI$)#(R,8L#E09*R%=WWG3`X
M)G&I68^^H>%EY[C+JK79]Z9<KLLO!:^L;S+RAUP[B9Q"#(Q.@-ENA<YHA'5\
M&BE*/>[:^E#5/81X(L/$E.O7:DL_<A4M\"SZ<,/2ATJM/GCD7R*9\-2D&CI1
M4D;Y`X&@B4RKZ?'&$T_YX`32;X@P-^=&X_`D#+UV+"TMG=G:WC8%@[L/3#U.
M)*C;T3<Y=33<M;I18QO_84VA4)PZB$VZ/.];YA9_-'=V.;>VMF@;3Y_2R-]#
M(VW[^A_M^]'(]/P3P]#W\/C\E4?"R<%7]_;VWOAK?'7UT7%2^=>.NK>VMOZF
MW[\41LZ]<B3\/VF_`85M(5O3ZNG5`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\R+G!N
M9P``````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(S,C<@,3`U,34T,S0Q-#8@,#(V,C$V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X!.`E*QD0`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1D241!
M5$B)[91=3)I7&,=[N>MER9)FR[S:W;*;I4N:9<WJS$PVM[2V.JVM'[6*WZT*
M*FH51%Y$*@(3$)6"@BB@1*F@%K\+U?HUF5IA!;3;7+6BMBJX&OO?*YDN7>K%
MDEULR9Z;D_<YY_F=__M\G!,G_K=_K?$$4E5&+MW09;ZK^D>`MM$'(?V#(WZ1
M1.9OU=^!U3:*%ET'.+>$_MIZ!<OE\GSTMZ%6FZVLK;V=8%=P5XH9!&HD=5"J
M--#JV]&@5(,G$",UBP9&.7<E.26-&!@8(&PV&S$T-$08C4;"X7`2+U[LO7\$
MW-_?/^GS^:9=+M<TFR!>LMD$"(*#[)Q<T/+RD4LE8<PR2&MEY'<>DBDI2,_(
M@D*A1#Z]"!45%6`RF60,`9U.#Z]W/?0(3MX4M+&Q":O5!AJ-!AZ/!W-W-S@<
M#E@L%H1"8<!OZ>L#AP1EW<@.[!WX2TI*P:^N1E-3$VYDY^">S3;G\_L_.(+O
M[/B"9F?GT-5E"@1IM5IT=G9"(/P..=0\:'4ZE)>7PV*QH*6U%85%Q5"KFR$2
MB0(7M;2TH+FY&?%):5A>_I7_2IY5&FTHO;0<>D,'U,T:\J"&5#D`N?PV"65#
M(!"B6B"`2J4"F5N4,AB0R>H@D4H1'7,EH#HKFXJHA'2(9?+=K:WMX,-\ARI4
MFJ?\&ED`?*#X0/W0\##HA470Z_4H**"CM)0!L42"3J,14FDM3"938#\S,POU
M]0V(CDW$^9@D,(E*N-SNT$/X>V6<6XO"6B6D#4U(N$9!Q*58G(N(0MC%*XA+
MI(!.+T1:6CHR,C(1$W<5%R*C$!+Z)4Z=/H-+5U,1&G8>GW\5CL3,?+!Y`K@]
MGC\+^G#!(2W@"I#&J$`VG8'XW)LX^W4D@L,B$)%.!9W)07XQ"S1.-3*I-_%-
M9!Q.?W$.GX2$(?QR,BZF41%/R4(.O11FL]FQN;GYX1%\:'8AJ,'NP)F4ZV0_
M&Z#N[D.ML@G\^D9\6Z?&]?PB$+<U"!?602"J@::M`TSI;515BY'.XB.IL15"
ML4RAT[?%/7FR<NJ5@MI7O&<%(^,H$8G=IG'[2YI0`H?3">.<"PFU"M@7')A9
M^AD3Y.HFURJ#"<:>7M_$U.PRU30$<<>=S=W=W0NOG<I[GE\>:N[V8VQLHC&[
MU[J7RJW"C^Y%F,8F,3SV`,-V)ZXIM>@EYT!OG49THPZ#]T>7K9,SYF;+\-Z,
MW7[YM>`5[V9ZX7W[3CSYZ\/C4\AM-Z-%WX:>B3E02&"/I1^5O5;$2N68G+'_
M5D4JS56HX'SD1J5I$%R-UG_L6R*:<O)3]%U@EG,\/I_?0$ZK87WCF9,],H5,
MGA#S\PNH'YV&OG\0'H\G>&M[V^#W[RX9^FR(5[=C8'KF>+A]=8-OF?Q^32Z7
M?WKHF[8[/S;-/_K)V-5MV]K:HFP\?TXAWQX*V;9O_]&^GXW]L/"L;70<3L\B
M]U@X>?#-O;V]=_[J7UU]>I*L_%O'Q:VM>=]=>OPXR+N^_L:Q\/^D_0[N12%V
M*;V\U0````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W
M96%T:&5R9&]T8V]M+S(S>#(S+S,N<&YG````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,P,"`Q
M,#4Q-30S-#$T-B`P,C8R,#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@
M*M2@````!W1)344'U`$,#@4KZ9A"G@````9B2T=$`/\`_P#_H+VGDP````EP
M2%ES```+$@``"Q(!TMU^_```!$U)1$%42,?5U<MO&W40!_#O[F_7NYO8<>QD
MLZGMA,0I[B-!21&EJ*JJ1JK@4-0B(8&JJAS@B'J@A7^`&Q)23Y0#0G!#5(4#
M4LLC1`H54M-6:IRTM(T;.XD=O^UXWR][;4X<2N,6B0O\KB-]-)KYS0SP?WW4
MTX+)Y60D$`B=<)JM\^5J#2S'PK,M@*+@8UE0A('`^R`-2?`QY$:I7/IX(!S>
MDB2I]52\7"X?>IA:N]+JT+&^_B!Z!`$,0T!U@':G#9HFL!T;CN.B6"Q!E>MX
M;B2*O8G$^Z(H7@(`IAM^9VGIC=[@0"S`\V`)`<O0H`D!2P@TW8"BRKA]\P8L
MT\!V0T&KU4:KV<)$/'X.0'<\G4X?O7OOX8=M544X%`0H`DVW`'3`,@P:VPT4
M2P6D5E/8MS>!Z+#8I@ES/3X^!H'GLG\Y.^)??O4U+4H1)AJ-H;B51V1T%)JF
M0Q`X\!P'V[&ARAIBL5TX<_KM!4$0K@J"\.G?'7HG_-3)4Y\U&C((R\!I=Y`O
ME%&L5%$J5)!.9V"8)C9R6[`L"Y[G+>X$=\77-S;BN:T"&K("6=:065]'J,\/
MM^4BFR_A]NUEI%97X;HM$$*Z_K8GRF)9UH73[[S+BE($MNW`T$W8KHO55!HT
M1<%T;,B*"@H4:M5M>)[7%7\B\V\O?W\D%):()`W#,$Q4JG54*W68A@F:HE#,
MEZ$TMD$1'VK;=5R]]F-4U[6^?X0OWEK"@"BB5JWCT:,,*)K"Z&@4/I8%H6D$
M_#WH``@&^T`1#LLK]\XN+%Q_\9GXW/R\+Y-98U,/[L.T+;3;'O;MV8UFT\7&
M9@[KV1P(PT`<$L'Q//K[0\@6JUA:^>/BW/Q\;U?<LJQ>UVU>XGGVA&T[T%45
MAJ;A_H-5)),K*!6R,$T37MM#J]D$0R@,24,0>GKP\R]S,UN%TH+G>;MW;"C#
M,"(Z>*_14%"I5.#C./3V^J'(VR@6\N!X#IJF@6$9.+8%FB8`18-F&%`4C:7D
MRDO[]SQ_',#:$XO+\SRRN9F[,/?KPB>_-1KH;*XC%AR$.12&OU%'LYV#*-[$
M@Z0&8_@LH@R-<%\8-1^+H%Q;VS,^KL_.'E,CD<A;A)#R8YD30CQ=-]7I`S-@
M2D5,''X%Q78'D1X>6C4-,?0%8D-E?%Z6$)B8P.ST#+*&`=8R%W>/'#TS.3F5
MZ5ISVW:&,^NY#WZORX@-#L#T@*2JPU)J&.R[#%TQ<&<EA(DQ!V&T491-+"DZ
M+$-?V`E^#%^\E>17LOE$OEZ#R'-0W";X:AYJ[1L$A)_PP[67T:2/8WDM@H'^
M$*JV`;'E*+-'#M]_YH3V^_UH^7R8#0H8&QL])ZMW7U?=ZZ]-[/\.\S=&</#0
MF_#X8<P<E*VI%R;/;Q;+('1O39*D*\_$1T9W;?E5;9RB.FBZ[J:A*;[I*>-8
MOC#+B8,G"_'XU*L.Q1B!:+R=2"2R__H&RG+CH_1:ZF*M5COPGSO0?P+1M/T3
MAC>"]`````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-"YP
M;F<``````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,C<R(#$P-3$U-#,T,30V(#`R-C(Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.""8BAT!N
M````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```$1TE$
M051(Q]65RV\;51C%S[QL)['K^!6[MI.T3G"K)E531*F@J"*HHHNB%@FI4D'=
MP!)U00O_`#LDI*XH"X1@AXJ*A)!:'B%26A!)2TGLM$J"8^=A.X['[\>,QY[Q
M@\]&+$KC!HD-C'3ED4?W=\\]Y_ON!?ZO#_.DCX%@P&TR6<[4M/IE,9V&H-.A
MH2J=:3I!`,/QZ#4(<`XXP?/\K"@FW[=9K7&GTUE_(EP4Q>,KH?"->HOQ[NGO
M1X_!`('G.Q,:K18XCH.B5%%3:TAN;Z-4R&%XT(.#?O_;#H?C6IO!=X//+RR\
M:C3;O":"\@0B97\.CD59KB"?*^#>W5]0J<C(YXNHUYNH:PV,^'R7:'IW>"02
M.?G@X<J[S5()@_UF,`P+698[W]H+%/)Y;"<2"/T>PJ&#!^!U.9HLQ]_Q[1^F
M'>JC?W%VA'_ZV>>LW;F7]WB\$`GB]@Y"DF08:!<&O1[5:A7%8AE>[UZ\?N'\
M3$]/STT:'_Z=P^X$/W?VW$<%VJH@\%`;36QMBT@FTZ0VB7`D0E94$(UMH:HH
M:#0:<SN!N\+7-S9\L7@"N4()^4(1:^OK,)N-4.L:XELB[MT/DB7+%&:]$VRW
MYS%;%$6Y<N'BFX+#Y4:M6H,L50BB864U`I9A2&T5!5JTK2N3SK65=X4_IOS+
MZU^_8+$[.9?3!8FJ(IW.(I7*0*%%6"K$1$+L!,IP`C*Y+&[>^M8C2>4]_P@^
M>_\WV.QVI#)YK*ZN@6%9#`UY.OZS]&XR]E%W,&03\3@=@HL/+\[,W'EZ5_C4
M]+1N+;(JA):7.J$UFPT</#`"35.QL1G'9C0&3N`PX+!2Y?3`:K$BMIW&0G#I
M*LWMZPHGK_M45;UF,`AGJFVORP4:92PMAQ`(+"*5B$)I+T@>:S65@F3@&!@`
M50J^_V%J(IY(SI#_HSL&2LWA0(MYJ]UMHIB"GFK::#)1>%DDJ=;U!CW*Y1(I
M%SJA<M2IY!FH>>B'P4(@^,RA`T^=(E3XL8.+5N4V-V-7IGZ\_<'M7`ZMZ!H\
M%CL4NPVF?!9:*P:[_2Z6`V7(KHOP\"RL9ALRE(6YD`G[]^^37IJ<++G=[O-4
MGN(CRNF/AB152A-')\`G$Q@]\1P2S18\O3I(J778K)_`.R#BXY03)M\()H],
M($8V\55Y;M1S\HVQL?&UKG5./KM"JQOO_)S-8YS4RK4F`N2Y10,IO`ZI*&,^
M:<'(<`UU-+%=J&!>*>.P5IG9"?Q(H'._+A@6HW%_/)N!@_PMJBH,Z2V4,E_`
MU/,=OKGU+#3V%()A-VS]%J2J,AQ:K3AYXOFE73NTW]B+ND[`I+D7^_8-72J6
M'KQ24G\Z/7+H*TS/#N'8\=?0TKMP]%A1&3\\=CE,YXV>[<O0Q7!C5_C@H#=N
M+)7W,TP+FJIN2N6B[LB8].)68E+OL)]-^'SC+]-)(AN]HTV_WQ_]UW=@H9!_
M+Q(.7<UD,D?_<Q?T'VJ\^9(;T?Y@`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\U+G!N9P``````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S-S0@
M,3`U,34T,S0Q-#8@,#(V,C(S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`X(.:^/39L````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```2)241!5$C'W95)3!MG%,=SBJJF!PX]]1!Q
MZ[&W1,JA2D5516I516V:2+2!!`+%90D0S&*"C=EL@K$]-HOQ-C9>,(M9;%.,
M"9C5QI6-L4T**02Q"(Q!JD"$I2SZ]X-641#J$K6GC/3I&WWSYO?>_-\R%RZ\
M]9>8JKF<\C`WVN7Q7OY?@)N;F^^N12(I`JD\I9JJV^4+:]#CZ-]5TOJ4N=FY
M#_\3?'#852>1-Z)!K4-W[P"\_DDX1]RHI.2@ZI4^4ZLYZHVADX%`E*A.<3V3
M63!K(]#)8`AMUEYT_O@4FF8+.NT#B&?DX&9LTCZ;6Z;EEO$__M?P"?^DEEU>
M!7U+!_J'7+`Z!E$LD(%53L%LL<,Y.HZT/"X^OY.(3[[X!G?N)AS.O9B_^X_@
MX^/CJ.'1L?W22A&!>.`8=$%E[`!?JH;:V`Z/UP]Q@Q8)&040R_60*`Q(SF01
MZ;2;X?!:PJC+\_XYJ$[?]%X)3WBOL]ONJQ;7P&BVHM7J@-YL@U#6B*S'?)0*
M9>"2+WCPD(4:I1X^?Q#^0`BVOB'4*#2GN5'I3*MRA>K*&;@_$)0QV3SPJ`:8
MVFV0ZUK18NG%D.LG2%5&Q#%R(2).ZC3-,+99$)IZAMG960P0B4Q==O3TCZ"%
M[(P<#BJJA,]75E8_.@7O[NY6E%<*COD2):1*`\8\OE-#FV,(S9T]*.11*"*K
M;W`,P:F?$0A.P=X_#'V;#<SB*K#*A!@;]Y%WC;B=D`YF(1M>K_?&*7QA84$4
MGYP*2JZ#J:.;Z#J).MJ$TFH9?F!R45VK1NC9-*9GGI.(I]!-9*@0RQ&?FH\;
MM^XC.9L-=F4-DC(+B3T'N8^+,>'W_P%_N;U=04EKC[,+.*A5Z7!2V_FE0MRZ
MEX;/OHK#]UF%,!`I:'TS5/J6TQS<3\_'IS>_0\R7L<C(Y8!95`$FNQR)C`PT
M*%3[:VMK,:\T7PZOR21F"QH[+'A2)4`>\9[!+$"10`PF58?4C"R4\*J0^HB%
MV/@DY!?S\2`U&XR,'.+4!$-3,SC%)5"JZ2VB=]R9A&I[G-$"VH!ZI8I$3R.7
M&'I]/K1/SB"!+X9*34.K-X+6ZH@-#?7(.+KL?1@<&D8)K0-56P^'HP_A<'CZ
M7"G.;+YT.2<"L!.#1)D6MTE$:HT6D@8%^-5B#+@]2!=0,+2VH://B<1*(6B=
M#HTD8BG="+?;C8F)B=SM[>VS=?YBX]>8`N_T>B*+@ZZG3J209')*RTGVM6!*
MZB$0BE!"VOYKG@BC+C<D>C/X"C4,QB8\(CU!-;4>[N_O\W9V=JZ>BUHSLR1B
M](XB.X]U%/IEKF!Z<7EK?-QSF%;^!+'YA1!3$B23BN&J-(A$UG_K[7?"'PS"
MW-6%3)(338MY[R];WCZ_*JIOM^S06GW*J^$U-<-KLM@@)5I:K;83+6U[>WL=
M1T='5\@]+!8+%$1_!IL+?VAJX._FR;7#P\-O7S\[.#BXNK*RLKRXN(BEI24E
MV2_^:7MQ8V-#>=*=\_/S"(5"('/_^AN/7@+Z@#B))NO2Z^?KZ^N7MK:VH@DT
M.A*)G#Q_Y^WZ[_X.LS51]1?]Q7X`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S8N
M<&YG```````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C,U,2`Q,#4Q-30S-#$T-R`P,C8R,C``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@D/>2[I
M0P````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!'9)
M1$%42,?EE.M/FV48QO=-/VHRL\4O[@\P,7X91HUS4P?&R=R8([(!8S#M!BNX
M#`H;XUBDE$$9A[9`@;U`2^F)0J&4MIQ**8=26@ZEA:Z(*U`J)8`&.4AV^5#C
MDF6)NN@G?9([[_,^>?.[G_>^KOL^=.@_O<IY@M<8:>G'J,:F8W:[_:5_!3KG
M<EV@A!(:I[S27,ZK@K!9CE)N=8%M<O+C?P0VF$8BJRGQ1JU(#I5&#XO5AG[3
M*'BU0C#9G,6^?D.+U^M]Y87!'1I]0ED5]2O_H1C2-@VH9B4DRD[(R+Z[?Q!"
M:2LBO[F%[#SVCE@BHS)SF'\_"8O#W:X5RJ#6]6%PV`RUOA\BN0K]1A-Z#284
MEM>`SLC&)9+@S/D(I&<QJ3\%>KTKAZMKJ*,$QLW*+WXB;]>AJ]>(ULX>U`@5
M).30]QG!K6E$+/TNR@1"M&FZR;,1J5D%3P:,)FY22L91M_O[P\_!=3U]#IZ`
M0@FW)E`*H4P%18<V`$E@,)%T-Q\YA5S$IV2CODD&N\.)Z1D'.KL-D+1JD)-?
M#$9F/E1J[?+6UM;QI^#1,4M4;F'99D5=$V0J#9H5[6A2=&#$8L5#L1+1-Y)Q
MOTP`;>]`H.83TW82,VCOZD%))85NPV#@K]*8Q8B^=@.34_;9O;V]MP+PI-1,
MSL%'#ZH:8+;8T-*A0ZVH!<4\"K?O%:!>W$+.K8';CD],H5ZJ`I/#1VS2G4!B
M0:,,F:S2P/YT:!BJJJNQL+`0$H!W=FDY]_**0!P"I5J'_%(!$E)R$'Z5CNO)
MF=#V#$!';MU.+*DB=;Z=P4)8U'6<#(W`ES$WD9#*Q%>QB8A-8.#3<^'@\?F8
MGY__';ZQL?G&B,4VG<A^@#A2MY"SX7COU&<X?B($[UZ.Q<6OXW$^/!+GPB_C
MBVMT!%^A(>B#TWCG1#""HFEX/_\!3@9_CM"PBXB*OH(6I7+'[U_[*`#W[>Z]
M[5G?N%FUO(9+ZAZPBHJ)KUM1)U?@$\,X(EE%X(FEJ)/(<'7(AM,E?"(@"WG<
M:J3P!;A068=O<[^#1*V!7J]O(\T5]510VMH>IV+)#_/$)`0-C9`,C2+-]S,T
MI,XJXNUR`?&U>P6YIC'TC(RBDJ(@M4[ADG,14E4'\;X!\<['H,G;8;5:2Y^Q
M8;+S!TY,127J%2VP+J]@8LF+>+T1Z44<.'RKF/8LH6K(##K[/NQ.)Z;\ZS#/
M+R"AK@$UHB88EGW@MZK!8+%!!EO',W#BRS,6BX5;_W@%9P>M:!")#@3!M',6
M;-\F(DC[&X>&L;BXB-7M'01;9I%1+X3;[8:1)#XUN8!LHM<CMUOC]_M??:Z)
M]H&7G;_LL!7F\6WIX/#N'9<'M:TJV%9^W!?INK<+)QPH(5YVNEQ0SS[:;NCM
MW\^8<:.Y2XLNQ]RN:7AT>W/SI[B_G"V7/>MOQHW9YWAB"5'=3S\X2YSWJF\I
M5!@:'E8?O&LWM^@Q-M>.4-D&E\OUX0M-1@(-(O%4]:6EI2.D+#2/QW/DCS.?
MSQ>UNKI*(]WX^@O!_]_K-ZO,02C,Z.%W`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O-RYP;F<`````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#<R
M(#$P-3$U-#,T,30W(#`R-C(R-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P."2VL3JBG````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```$QTE$051(Q]V574R35QS&O=^6>#$7HXF2
M[&)9LF0FNW%+MB5N;+H)V\2,!84A:*A:76%VM"*@I:VE6-O2EO+VA7Z\_2YM
MWT);2J%\.2B"?/A1:;`4)<.I*%@U4P<;SUY9MLSIO#"[\B0G)SD7O_,__^<Y
MSUFQXH4>(R.CJWXX(DCCE1]+NS(]O>Y_@<[/SV^/=/6R;$[W&85&!Y661*2K
MY[[)YF(M+"R\\=S@NW?OYIH=[I3)[D&3MQG=/;T(AL)P>OTHK3R.HP+QR.1D
MDKX0NTC?NW>/GIZ>IJ>F+M.SL[.O/1,<BT^P+0[/HE)'P=W2"H>G!04U6KRN
M]&&?6(G5VA:L-/?BS8(2K)=9(+#[\*XN`([9`Z_7F_9,.&5S/E"39OC;NM`?
M/8V>OB@X"A+I>C^VE)W$1Z80-K#+\0ZK%.E*"S(49FRA0B#<S9B8F'@2/C<W
M]RIEL:Y.)*?JJJ2*)0?=BO:>?OC#W3`Y?>!*U2BV!)`OJ@6;=.'K7?M0K2)1
M;?2@YG0"!^4$U'7UM:KZQG5S\_.O/`;OZQ^(DT8KI,IZN/UA4*X6-#.5$^8F
M'*ZJ02&'CSI/&-\+9="U=.*H1`:"LL)`61`8NX2<@KVH$,E06B%&;U\TS`B^
M=AE\[MSY/*%4?D>CM\/F"<(3:(>!Z>/@R%GX0IW@'!8A>S<;[D`(7-X1=/P8
M13?3+JE2A:KC4G1%!U'"KX"KN0T%!WBH4:AQ??;FYF4XI[1"KB1,D&F-B`Z.
M(!CI@=[NA8YR@ELI02UA@+Q6#4)'0B@2PV:W@R1)L`YRL;^$#ZO-@>S<`A27
M56'GG@,02DY@,CGU)]P?ZI#S!1(HZHWPM4:80_0XR!<BMZ@8.XI*X*(#<#1Y
M(9,K8++:EZOE\LJ0]4T>OLC.AU!<C4QFS2WB8`^[&$2#'M>N7]_\EZ?7#PV/
MQHX1#FS:4X[/M^4@ZUL6WD_/1$9.(3)X6GR6M1,<_C%LW2_`IQE9R,K)Q\:/
M,_%A>@:*&.#V76SL+&3=)\B&V[%8S,`P5_XMJ'MJ(8WK'L57^\J@J=/B[/D+
MS'5M:/1UX(.J9E3+58C$;^*32CM"H39T]`]#JM"@N[L;%RZ.,X*7PDO[&ACH
M2T]8,75_H99L.<7T6`R13(T:91W<'B\(3PB9>WDX-30*1U]LV983/]]&D>T<
M2+,#`P,#<-/-X!TNA\/I0C@<?MSGJ8=+:X_WW;Y\2-T$B]V)W3PQMF;G0:LW
MXX1W`*2!@LW?CN_DYF7K4?U)O'V`0*U6!ZY0#O%)#6B:3B42E\8F)Q-K'H/W
M_/2[?%/CY67Q3H_%P!:I0)"-X!LBV'C(@/*C51`Q(DOK#=`;C*BW^E!268WV
M4P/85A=%8273LDB$?NISUXP]E'\I,$(BK?GMQHT;_)F9F3O7;LX]V.^[LK1Y
M!PLFB@)A,*&A40^7RP6!4(A@:RL&IU/8P'/"Y`[\.CX^_M93X:E42M[9V?E+
M,!AD_7._+1P>>U2I2JV&1%(-RFR&T61"N+T=R61RA,F1AT:C$4PB=OUG4"TM
M+;VWN+BXX]_[3'QN9R8K'H^?>52U6J.![*0<9HL5\?AX_JU;M_(8,(O)DC7/
MG>W,X:L&AX:&F]SN>"*1&+8[G&E7K\Z\_.+^O7\`<;IE0W%DWZ8`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\X
M+G!N9P``````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(Q-C`@,3`U,34T,S0Q-#<@,#(V,C(P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X*`UNU
M]JL````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/]
M241!5$C'[91=3)M5&,>7J/'*9$83O3*[,_%B6>)'=F-23=0MCAAOW!(U86YJ
M59(9.@,3-V"B3;"EE`7*^DU+^_9#U@]H*6N@@Z[TBPK=1@.RIH!(6?F0[T(I
M_'W>-[:)4=-=:N)S<][SY+R_\S__YSGGT*'_XU\9.SL[@E@L9DLFD[:%A04;
M&R,C([9X/&X;'Q^W93(9F]_OMTU,3+SUMX!\/O_*^OHZ;W%QD4<`7CJ=YD;Z
MD4>`_A>,M_!)8PO>T/?B&64O7JR7XJA(BW?:#'A/:<6;S1JH5"K^7\"Y7.[4
MZNKJ4B*10"`0P.#@($*A$-AY*I5",!A$F2.$URJJ4&8/XN6S7^#5JN]PLD:(
M4WH/R@PW<490C7`X[-G>WJXL@O?W]Q_/9K/RF9D9>+U>Z/5Z:#0:='5U@8X*
M.BH&AX;0X(W@M*`&W_3X\6'Y6>@8,ZXI-:CM'<8%C17\"U_"X_%@;FYNBL0^
M4;#C!-F!R<E)#M[9V0FE4L6-#H<#T6@4GKX^F`(_X>.+E\#<"N-]@HO:Y/BJ
M^FLH'!Y4U-1!I]-A8&``T]/3V-W=E13AFYN;8)7[?#YT='2@J:D)$DDSZR'<
M;C<Z='K<]`_C//\S,'8GG.Y>J(QF?/IY!;0&!@U"(60R&9Q.)W?2(IQL>9K@
M-M;;_OY^3K%"H8!6JX75:N74L!NP\\I*`7X0B2!M:2%8.QH;&U%5506CT8CV
M]G9$(A%00X`$%^$G:"=05V!L;(RSQF0RP6`PP&PVP^5RH;N[&W*Y'$)2*)%(
M.*A`<!%JM1JU=75HHAQK"]L,Y#G(\R+\,$TT*RLK^]2W7%%:KRO1UB;C++)8
M+-QQ%52'YI9K8!@&M;5U:&UMA=UN1ZOL.NJO?LO]QXHCD?ND_/L_M2.I%Z^M
MK3'SZ86YLBLJ:/1&MA4]Y"%#Q6;Z0G'O5;D)`SZ?E\U-34TQL3OCGIH.#\X+
M+N?)#H;L95C./][&I=7-U[N&XKG[R22VLSO'"GG'T*AE9.P>EI>7CQ=RB=G,
M,5\\"5\@G"UYS;.Y_%-7S,$;C+WW@)0TD&6/_F%=^P?2G@.MY09^6ULOPJ,_
MSR?$G2[8'<YW2[\AN3V^R'T7"IT)L[.SU47+<GN,RQ_[-1`8%E)]GBOD;:')
MM$!J@$@LYI6$_Y)9X2?NSR`<B;Y-_G.07/[@D8:>A*51_>,:%:N\N/;!\F.3
M,^F%T3MW#=2"ATO"C]<[^*<O-2,2C?H*N;W\0;DZD()4K<?&QD9=(7]O]H'F
MC-B!C\Z=$Y8$LV$.3O'M7C_FY^>+</+[^<S2,I]N,)^^7RKD4TOK&H=_%/[;
MMQ\.SCXX5,@C])`]6VHM>[/)IB-;6UM//A3\/Q6_`VVM+6<D3TRB`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+SDN<&YG````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,38R
M-B`Q,#4Q-30S-#$T-R`P,C8R,C<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8`
M``#@*M2@````!W1)344'U`$,#@H4V&9S;`````9B2T=$`/\`_P#_H+VGDP``
M``EP2%ES```+$@``"Q(!TMU^_````R-)1$%42,?M54U,$U$0GG:W?[2II:WI
M'UAK0\I/-"2&F\&#&@]$CQHOQ&N/QAB-1T_&1&/DXL&#\>!!!(ER,$+1F!B1
M&()26RV68B&HE;;;=EL*VW:=>70;(`0]&R=YW;?S9K[YYF=?`?[+/R4J95,N
MET_A>B0(`A2+1:;3:#2@U^N!XSBVF(-*!;(LP_KZ.JRMK4&E4F%G)I.)G@-&
MH_$Q[J>V@"-@=&%AH3T>CT,JE6*@-IL-/!X/VV^6:K4*HBA"+I=CB\@0$8?#
M`5U=76F[W7X>`XVJR1BC7UI=7?41$Y5*#3S/,X:2)`'J&6"M5F-L":A0*+``
M.IT.+!8+6[0G&\S>AF?'R(>G'TS3C6`ZBHYOC!4!$0BE72J5F",%(U`*7"?%
M[$A7+RWS)=L&N%JM?H`.9R@(&5(0`M!JM2P+/&^4AAS)AIX4E!8!DJW3Z619
M*/WAZV7,(*!$3;%:K<R96"CEH7T^GV_46V%&C:4]V1`A`B6=(@IX!QX8*;K!
M8&`.5&MB3*7`"=APK`-24"6P(D2,_$FGZ%E#T?$Y1DZ8S68!4Y,^?1?@VZ\5
M\/O]A4`@('B]7F%/LUV<6?P)V6)1;FUM%=QNM^!RN0JRU@BO(S'`=\GG\PE8
MEED$O[WCX(MBZ>+`:*CR<&A(3B02W8I^-AR[_';JO9Q,)D<47?QKTOOB0VSF
MZJT[<CJ=?K(=B]^NF)J.2%Z^"IT=W8/()EEO8O#^R-BUQ502_";#=<768C5?
MR$7"E7,GCTN8]<!V+/7F%TFJ].<X_L9P:(*;B\6F<78S]<;U>FQFK==B_H%E
M*BKVJ6SA['CXR^'YI<4JEG5B5^8(WG30;=-93_<E`VUMDXH^')F'HH:#_4['
MW9Z>GEE%WVPR0%]WY^2!EI;QG4J\A?GPFQFX%WH)V6QV'AO[:F/T:B>65H2C
M@V,AB$:CC?'`^;[R[-U'ZUPVXRZ*XM!.X%N8&_3XT0@9<!UJ;^@X3CV6+X@W
M?4[3$:?#\3D8#-;OHG*)DR5Y+\_MP]Y8=KT52?!NZ<1;L1=G=AEG^^F?KE3\
ML/KQ"F@B6^S/\O\_F;^2W[$YEK:%FEIM`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+VYA+G!N9P``````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C(P,"`Q,#4Q-30S-#$T-R`P,C8T-#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!<`
M```7"`8```#@*M2@````!W1)344'U`$,#@HI@`X_?0````9B2T=$`/\`_P#_
MH+VGDP````EP2%ES```+$@``"Q(!TMU^_```!`U)1$%42,>M54E+HUD435%=
MFP*A&FQL>A5PI>#"A1APX4YZFUJYD<)::*`W(HJB/R"X$"6"43?.L_)IQ%EQ
MUG*,\SQ/X)C$*6K4V^<\.E*TD;;!#SZ^X;UW[KWGG/N>3O?&:W-S\\O.SLZ?
M^_O[7W3O??7W]QL&!@9D<'#0\"Z`,S,S?QP?'_N+R&_CX^/&RLI*:6EI,?+[
M^OK:?WEY6>_Q>'[]3Z"+BPL_W*;+RTN]]]_4U)1]965E^.'A8?SL[$Q:6UME
M>WM;'A\?QT]/3X='1D8$8V;.Y;JKJRL3@OJ]`-_=W=4O+B[*Z.CHC\G)R4]/
M3T\Q`'*"!CDZ.I*]O3T9'AX6!!2`R/S\O'1W=POFF>UV^Z<?N.;FYH0X+\#7
MUM8^V&RVK^WM[2>@P`U`#P$;&AJDIJ9&ZNKJ)#<W5XJ*BF1H:$CJZ^N]@3RH
MSDW*`+[B=KM_?Y4>9*0A<^GKZU.@Q<7%"JBCHT/:VMK4[0W4T],CX)TZ")):
M<#J=H:]QKMW<W-@1V3DV-B86BT7*R\L5%?R>F)@0!N43#$AO;Z^4E95)5565
M2@*<.['V^\;&AK\O6I9@-Y:FJ,C/SU<9$XQ",@!!:4?24EU=K3@G3=!)T`=J
M;'5U=>D%^.WM[3=RS(PR,S,E+2U-(B,CA8Z(C8T53=,D.SM;2DI*I+"P4(*#
M@X4\0R<U1JHX=WU]_=O/=!C@9P.ZSPC.!.]26EHJR<G)$A(2(@D)"1(5%:5`
M$Q,3%5A<7)Q$1$1(?'R\='9V2FUMK<S.S@K7(W,CA#805P=0539+I/H4C&*E
MIJ9*3$R,RCHP,%"RLK(D*2E):1`>'B[1T=$2%A8F34U-S_31MJ2TL;%1B*MS
MN5P.1'/`JRXOEWEY>0K<9#))3DZ.!`0$2$I*BJ2GIZOQH*`@-18:&BH9&1GJ
M'P'I,(CN@C4=Q'VF!VW,#A,V$L6T6JWJ21'-9K/Z9E7DF?9$,JI"@L.&`I?(
MW=T=FTKOR]^6KJXNQ6E!08$JCP*Q7.K`CEQ86%!NFIZ>%C2:T%VDY!^?*ZLZ
M'`[+"W`X1<-VNG=R<J*RHH`L]=\^)RBK^1F8`;E5P(IV5*#Y;"3L=N'GY^>K
M5-Y;/BMA5K0H`=F5S<W-RGX4DSHQ&"C17FU[["4?`/H5$T\J*BK4(K:VEV?2
MQ&ZD>`S&_ZR0\R@D+&F#XS[Z!#\X.-"S;`+CW8:M5$-`)S-D!S(0@9@M&D6!
MHRN=]_?W&JJQ,3CF6>'OS[[:WP_<FO`T@1J5`:JP4V2ZB%JP%T@!]A`5$-]V
MSH,N']$C5F[-&-._Z22"2!I.(@L.!SW<8B0M2TM++MH-P2RHYIEG'!*?L87H
M4<DO__O(@Z`&\HV`CG<_H)&I86MK2PX/#_]ZZYJ_`83H3*%#H?J#`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,3`N<&YG`````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C<T(#$P-3$U-#,T,30W(#`R
M-C(W-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4
M`0P--QW)%#TO````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2
MW7[\```$24E$051(Q^V374S:9Q3&>[WL8M=+EIDV:;*+KKW:DFW9VM4L+NU%
MFS:IIFJ5;?+7JE70JE695J=H503\`.5+$$%!P"\4/R<JBM*)HJ#&#]`.II7*
M9A6TSF?_WKAUK<VR[;)/\N9-SON>WSE/3LZ)$V_T7\3F5D7?H:<1>D-/]/\"
M=+I<[\PZYK3%+*Z6)ZK?5ZHTD"G5^\5E'*UQ:.3+?PVV.QPGF[1ML\4</AIU
M>LA;]6"K6J`B[]!\-D*2L_8EFC9_T\B$O\<T1E<.C_OGG2[_[N[N^Z\%Z[O[
M3\H4ZM$2;@WDZC9H.WH0PZK!AU5-N)J>BU.23IRJ5.&#\`2<+96`PBS'QW4=
MD+5WP>5R!;T67L2JO%I05@5]SX\8,IDQ-OX03%DC(L0JA#&*<*-"BO.AT0@.
M_08W6;4@=`.(Y,IA'#;]NKW]]+V7@'Z__^VI:5M4G:PA2J'2[%?4UD&K[X6F
MW8`::2,R'G"0(U6`R,I!2GD-PBCQJ!!(P5-JH+`OXE9,/,HXE9*LG/PHK]?[
MT0MP@406Q!-*42V20]*@1EVC#DVZ3K09^E'&KT-<:A:$BD90XY.@;&D#3R`&
MI[(:U35"](V:023244D6H]W+0W-+Q_S>WO[9([A:UV$I8O-1)6Y`[Z`)]:I6
M=/89T3TP@N=Q:@(-`J$8M-1TC(Z9,3$^CIR\0F0P\J%NUN(!BPLIV5`DD8*"
MHA(XG<Z0(S@],\_!K95!UM2*AY/3$,I5**\6(2FK$,SR:C2J=5"I5&0!$0P&
M`SJ[ND")3<*U\&]AZ.G#[50&"%H6HN/HR&.68'EY^4_X@''$<IN>"297B&JQ
M`G?S6`BG)N/R#0H2[_T`H52)S.P<L'EBI&7?1WAT#,Z'7,'G7U]#[!TZKD?$
MX!:1!$H<#75R96!S<_/B$?S1D]V@6LL3G`YC()VT&EL@P!4R@99=@$_3Z_%5
M:`P8;`G.)?`10:$BE\E"<%@,*-1X9)8)<89@@\C(G6C6:A4>CR?RA8%*9P)!
MJ>TN7(YE8-;I@;C=B&G;#`R+.SB7J4.+OAN3JS[<%73!,3>'WJD5-!L&X'9[
MD-RR@C!F$Z:FIXE7K_K6OLE@MF%RRH:4KG5<2N/!N;J&H04WV/4:S+NW0&\8
MQZ!E!C,;`814C$/9VKVTL;4MNJ\8A*ZCJW-]??VME\!;_M\O$FV>C:COR_&3
M8PD72H=01&[G_"^_@2HPPFRQ0FW?QAFZ',,35H@LF_@L5825-3?4U@WPFON>
M'1P<1+RRZWK['NL+_CS2<@H/'ON>^D=F7?ZU1S\_JS1O(3A#1-JU(5&SB.^*
MY;#9YU*GG1M^DW7NP.7=P26^%66J`?^QZZY9V&.5*@P[,IF,^(N;"$:/V\?A
MBUT[.SM:]\9C[:;7JR67X_3S]\/#PT3KJB]`Y9&SL"_T'PLG+7T2"`1N_CU.
M3OTZ>2X<E^?S^2*7EI8(\L^[)][HG^H/D2P#*1P74*0`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q,2YP;F<`````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(S-C(@,3`U,34T,S0Q-#<@,#(V,C<V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````7
M````%P@&````X"K4H`````=T24U%!]0!#`X,&QZ#R7L````&8DM'1`#_`/\`
M_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```1_241!5$C'[95;3)IG&,>[
M9#'+KMS%DEUMWNUF27>Q;#=+Y@[9FF7IVG5IK+%&L1YJ.V/KG%,)U7B86">"
MXCR!H"@B*B@"HE(0000%%44$/*$6-![P?(S][Y4E)FW:IFEVM>Q-WGSYGC?/
M[WO>__M_WN_"A?_'ZPZ+U?H--3L_@9I;F.!9?!S]KT#7U]>+U1JMA%5>M50G
M%$/8(D6#6'K<U"*1G)R<?/5:T-W=W6"'T\4O*JU\4E4G@KRK!T;3$`:'K.A2
MZU#(J@*=P3[6&0;MXQ/VT/6-C>!7AAM-P_S2ZCI4\IO0)E-"W*X`M[$5(JD2
M\AXMU!H=_F!4X,<P"JA9N:BLX?)?30I2!:.<<\AODJ!;H\>0Q0K]@`G-4CG4
M?7J8+:,HJ>0C.2,/F7D,1-]-P[5PRA.=7E]^>GKZ]G.AJVMK5_D-S5'=C_HL
MC+\X:)0H(._M0YVX`XPJ`?*9U>"+VL&J%N!64CKHS$KT#PY!K3.B5BA!=6T#
M1&TR7@Z=$;6]O?WI4_`Z8;.#S1&@C,@ADBK`(0F=/?_`TW**$7N/!GH9%ZE9
M#U'#$V#4-@ZGTX6^`3/:%&HTM'2`S:G';P\*P*[F,<[!JEY-?@&SXI1)JI(H
M>B!3/8*@I1,&LQ7\YG;<H]*17<C&@'F$0"<"L\]@#NB?36?B3S8'0R.VP`XB
M;Z>BA%USN+^__W4`GII!8S`J>"CGB8BF8Q#+NL"J$2"WN!))Z7EH)%6-$*#=
M,84)^R3$':K`6C21YTIX#%)H!:"7<G`KF8J87]+`(K(2:2X%X/9)1WX:+>\T
M]R$+U?5BY!2Q$9N<CFN1B;A\(QXE%7PTMLI0Q1="(&['@\(R7(^^BR]_",.W
M5V[B)JGV[$.1<4F(N7,?'7(EB)TOG4OC]7H=O/H&)))M?G?Y9T1$Q2$L@D*>
ML;B=E`I*TJ\(2\E$."4>E+@[@?G3]0C<B(Q!5&(**!G9H-*R()6V8W5UU4F<
M<_$<3CKNZL+BXRCCZ+A%UBG'[-P<N!H#Y*I>V&RV\NFY^3VE6HMABP5ZZRC*
MB52#)C/&QR=@&;6A5]L'MWN:Y_/YHHZ/CY]VR\;63A"G?RB#*U$<KJRL&#:W
M=].YO?I]44L;R'M84X_.KS59SJKZGJ\UQA=R&K"PN#3AFE_(%?2;,>_Q*`\.
M#I[O<P)_1^^>[RJK;\3TS(Q&V6\*G7"XO+[E%=O1T=%%09?&+U-VPSXY^87)
M.M;HGID%<42ZP3KV.U>IAL,Q)7EA9[H]2^_->!:=7J\/VSL[<7+'C*>LK@G+
MR\NU*VMKM"GWS(G7YZM56L??+Y*J8""=NK.[^[EO996D+1WY?,L?O1">J=2%
MT`1MZ.I18]7O_Z3?X7:URI6'Y#I(*I:JA$SB>^O(2)98:PAN5JEA&1FUV!S.
M4('6B-9>S<%+[Q3#M"=$:QTC7><\J_8M<L"?[>WM19ZMF5RS0KUI^"R>1>)!
M1*8$8K4/79[%C\WV*4RZW"^'DX0W-S<W0[:VMD+(P;SQS-J[Y%#/XL'/Q(/\
M?G\(R?O@O_5[_!NA%%<GTG"]L`````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M
M+S(S>#(S+S$R+G!N9P`````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0P,2`Q,#4Q-30S-#$T-R`P
M,C8R-S$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'
MU`$,#@P3$%A!20````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!
MTMU^_```!(Y)1$%42(GME&E,TW<8QTWV9MFRS)=F2XSO?+$8=9LQ6S+C03(W
M-49@,Q.%68Z5J@/I4"A%H!U72VD+R%5HQ=)R%-I"6TI/H(>4XU]*H10VK0K#
MH>"`S`D)P^]^D,RE<TNV;*^6/>^^_^/SW,^6+?]Y$X@KME]B9NPPFLS;_Q7@
MO?O3KP0F@O1B@8A^O:;^J;"B!BJU]NF&=KK<._\1W-;GJJR4*M#0I$*/PP6O
M;Q16>R^*1%5@<?C4[=#=TK\--73;MAK-]H;\TLIG\M8.M'4:(6U20]79C7:=
M"3W.6ZBH;<`GGS.>\<55*Y6U]1?_,KQ85'VP4%BU";7T.G'+,PBUWD3@1KAN
M#:"CRP+B&$EIV8@\FX1C46?65&WJ<W\*7%E9><DWZM]VXZ9\FT9G#!2+JZ$W
M]\%D=Z&UPXCJAA8T:;J(=B*G4(3DM&M0MNN)4S,V`JFNN[$T,?D-C5,DW/;C
MDR>OA<%=_0,[M'HC:F5R7*]KA%)MV(2V:(W@54B1D)(-5KX(F5\+P6070&^R
M8G+J6PQY1Z$S]T*J4"%?4`XVEP^3K4\8!C=9>ZKS>&4HKU=`9^J!5-F.+DLO
MW(->"&MNXAR=B89F#<F&//,,P3\V#LKGA[Q5BPJ)'(->/]0&,[Y(8R.+4SCU
M\-&CW<_AF3G<H)@TJ:Y1A1'_V&;*,M+$O!(R&21:`XET9-2/B>`DG/U#D#2V
M(:M`A)C$+Y'"XD*F5".-9/09[1+2LW)`4=31YW")K"&8<O4:)#=;T4+*D<N[
MCJ14-J+C+H#++X=[8!C=UEYTF6UH5'6`<24/QT_3<.1D#&(9Z:"3'IQ-3,69
M^`M@7F7!Y_/]!K\W_=UP2ID$$;&).'@R&@>B8[!SSS[LB3B!G;O>QJG+F=C_
MP2$<2TY%Q/%(O/M1)':_=Q![#W^,?<>BL.?041R(2<"N=_:CIJ9V]?NYN2//
MX<&%Q;C,;B=.)##`KZD#JZ@$\60*HC@\T-A<G)<V(^X\#26*5IRF)2&N68?#
MD:=!^RH#R>DL,&J5^)1;`DYAZ3+9[-BPA@;GYA-9I"1E!%SMIF#M=8!KZT=J
M;@$,?6Y8R:RK2*V;[0YH/<-(5FB1GE^(4E)"N],%9J<=C+Q\^/W^8!AX?7W]
M3>MDB'(,45!Y`X@GTU$EO8'!0!`&LC39%C=JFU7@#8XC@9T#Q_`(W-0(1!8G
M:)7UD"F4&`Y.D64;F+ES)_16&/S!\A,AVT$AFR>`H,>#*T4"\/167.:703[H
MPUFQ!/PZ&5*5'>`(RY&GLT':KD56AQ4L424XVFX4RA3P>KV:M;6UU\/@9<-!
M(:.I$U62^I_O/IQ?Z1^?`-OD0C([%^*>?J3P1?"-!U8G0O=7C)1_/;ZYD]P6
M"0+WIE<=U.A:EF<,3!8;3J=+0.`OA\%;O0&A3*/[R6RVT#?T[1^6[4*]!5U6
MVRHQS?+RLF9I:>G5C7=R[T2_4*V#Q^.A%A<7MRI\DQEBFQMJC>;!_./''[YP
M5TC-WR<>8W[5Y,Z\L;"P0"?`V-]_2YR="H5"])F9F<U[3O[;.SL[NZ%?!/]O
M?V2_`"@"/7J9?!_U`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,3,N<&YG````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q-C0V(#$P-3$U-#,T,30W(#`R-C,P-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M%P```!<(!@```.`JU*`````'=$E-10?4`0P.#`L#--D?````!F)+1T0`_P#_
M`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#,TE$051(Q^V5NT\;613&
M4U%3TFV4)DVD[?8/2)IM5]HZHDR5)AU::24"38B#8@R*27:]7CLA!,S@!TD<
M;`.V\8P]X]?8'MOR8\:/\1M#LD&`%?3E>)!6*2)%*!0IN-+17,WC=^_WG7/N
M7+ER.7[($8O%[FWO[##!8)#9W]^W?C<P(V6OR4HMDTI)1Z5R^5.WVT6M5L>.
M/X2M+?]1/I^?$D5QY-Q@556OI5)I-I,M0*XTH#8[6@SG1;F.%=L[+"V[8+&\
MF*,%?CT7/)O-9F1%0;?30:O30T*J82N0!LMGT6BVX?,G\=A@PY-GZWABM+8W
M-SUA699'OPFFEVX*T?B@T>JBU>ZB6.E`$.OPLSG4U1;*LHHU!XO-K3@BL0(8
M1P"Z1P8$`H'HWM[>]:]"^_V^CA*VE$C$ZV6Y`JE00S*K("04\<83A]/-@XT6
MX'@3H>"@5%1TNCTHM1:$F(A7*ZOP>GU\)!)9.CP\O/WE;G^*\(*2+U91HH_X
M>`[;;`HEI0%.R,'XEPN.UQR2Z3+"@J190[O4E*3S%<I'&VJC"2Z:)Q5SM(CW
M^.#@X)8&3R02LVFI@+<D-5NH:I',E%!6FO#X13"N761R9?3[>P3MH:JVZ7D9
M;I^`5XR?WJ\@+A;!.%G,/)R#P6!`+I<[2S39,2N3%2FIA&:K`U&J(,AFL+[!
MPN8(HE)5T24+>KV>EH=`6,*_+[V8-]IALKC)L@BL+WV:NH<Z/186%D"E>@;_
M\.'];9[GWX?8,'S;NW"^WH;9ZJ2*>$YAU>X%@BQ8ED68C\+\G,&LWH*91V8\
M_7L%-H86<'FP;G?A_OVIH?=Y4OGS_[Z3A[_9[?;Q<#@23222X'D!N[LA<%P8
M25$$Y034J5A=M>'!@QF8_C%C8N(/3$U-0Z?3#>;G%\:-1N/XD$%]\LM7JV8P
M&(P>'Q^/??SXWQC9,$:JQDY.3K1KM5J=65M;@]/IA-ELQG!.0"PN+AY=Q!GS
MY_+R,DPF$W6G18LAG..X[X=3#5_=V-B(>[T>Z/5ZK%!M3TY.DE6K=R_DA*2S
M9-3M=F-Z>AH,PQR0QPPING$A\-/3TY%&HW$G%`K=H4;Y_?*'=.[Q&>K9P4!7
M*NHW`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,30N<&YG````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,3$P(#$P-3$U-#,T,30W(#`R-C(W,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P-."5FCIE^````!F)+
M1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#U4E$051(Q]V5
M24\;9QC'TW-;J8=&JGI(J'K@4JE?H<=\@!QZH>+2BD,^!$I41:@+P0DD(!.,
MB1=B&S`E%!M[O#M>\3J>L3UXM\=K;5:#3/CG&0Y%58M4FI[R2B.-1L_[>_[/
M.C=NO->G7"[?=+O=0R:3::C9;-[Z7Z#[^_MWT^GT6+%8#":32?C]`223[+'9
M;!X[/3T=_L_@;O>/$9[/]5A.0+U>1Z?3`:E&.)*`2FV`T^D*=SKM7Z\-)MB]
M7"XWJ-9J:#1;R.9%L'P)._%=E,HBMIDPIF<->/Q$?AX(1OJ)1.+>OX93*OHU
M422U;53$-D+Q,K;M<22Y'.J-%LQ,%,^5)FCU+OPRJ81<OC"@NHQ<">SU>I_Z
M?+[/1%&<B2>2YX5R'=*3$D3X(D4X?3QV"S6$H@*65UP(13+(%40$=W@HEY9!
MQ29$+T+GZ\/#PX__`B\62UPBP2+%\<CL%N&/9A%A\[![62PM,]"M>6#WI+"V
MX46(@*U6"ZUV&^5J$Y5J'3Y?`*9M.T4Q#X[C)O\$Y_/Y[R(Q=B\038/-E!",
M\G#[DZB*35*:Q;/Y5[#:=U"JB,@7*@1N$[@#/EN$R\>B6FM`)%N[F\5//\LP
M,3%Q"7<ZG9/I;!Z,*WX!$/(UQ+D"_.$,5C9>(QCF"%!'FY1*X`1?P*8E!*7&
M`L4+,[R!%#9-0>A6/!?P\?'Q2W@FDYF,Q>)(\3GD2U4$(@(VS6$H5!:HM!84
MZ9M8;Z#1:*!6;V';$</L\U=X]%@/C<Z.+68'*[^Y*2VO<?_^CS`8#)=P*L!M
M&I2XQ6(]5FN6,26;P?R""K(G<LAD3Z'3&_!"I8%>K^\;C>MGLW,+F'ZJP*,I
M.=D^(]M%ZOUE+"VICBT62SR5XF[_K6.VMK;&""`9@7H75BN#0""`@X,#S]'1
MD68P&-REU#R@KO!XO5YHM5JX7"ZDTQDX'`Z02/G9V=F'_]B.-'7#L5@LK%`H
M+BY:K5:P+"M-Y[?]?O]+FM"%;K<[3:/_!;7MZ.KJ:H]V#F@=D*`E9+,"]O;V
MAJ[L=U*_2NH/7K[4->@=!$4T&NTRC*V]MK8F*3VG2+252D6IT6C>S,W-0:?3
M01"$'CF.D.//KX13<4<HQ!_L=OL=NO20+FQ0@:!1J[&^OH[-S=]!@P):#QL>
MC^<AS_,VA\,)2M7JM78,Y?@#"OE[AF&D8EXH-!J-D-32]U')IMELW1*$W6](
M\5?7A7\BU6!F9@934U-0JS6@5$AIDGI^])UW.J5IF-(0E!PL+BY>.*%BXN3D
MY-WATJ%E=M-FLX6H,SBJQQU2/D11??3^_GO?`FQ49\\02%VJ`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE
M<F1O=&-O;2\R,W@R,R\Q-2YP;F<`````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$S-S8@,3`U,34T
M,S0Q-#<@,#(V,S`V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H```
M``=T24U%!]0!#`TX-7LYB1H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``
M"Q(```L2`=+=?OP```*+241!5$C'[51+3YI1$/4GN.BBJZ;K[MITT473L.E/
MZ*:+_H2F:=*]24T^$V.-1'E'0<$`/A"#$0UQH1(@/'P0BH`2P53"0P%)$%`Y
MG9FT7=B739=ZDQO(O7?.G#ESYNOIN5NW;W6[W4>7EY>JDY,352*14$4B$=75
MU=7]_P5]2Z#*Q<7%Y^/C8VQN;F)C8P-.IQ/E<MD#0*$WRMG9F9),)A5*J-#9
M^Y^`Z/`>LZ''FG:[O56I5+9RN5R3P-%JM>#S^3`_/P^OUXO)R4DL+R^C5JN!
M$N/T]!1K:VO(Y_/\VZ+X#]?!DP0.8B'L`H$`YN;F4*U642J5!-SM=O_8`P,#
MV-W=13J=!DF%_?U]V.UVV&RV&N&\_B4XLPF%0A)HL5C@<#BPL[,#H]$(J]6*
MZ>EI`>&[8K&(P\-#A,-A23(U-86%A86ZQ^-Y<QW<Q>5'HU%HM5J,CX\+(#/B
M<ZZ$2Q\9&1%@O5Z/1J,AE<W.SDK,X.`@AH:&8BZ7Z]UU\%[2JH]T2S*03J>3
MH%@LMD45]9&N1F(DP.OKZU(-O1?)5E=700V5NXF)B8=_<LAC2M!.I5+"BOZ7
MMK>W`YE,)L[]J-?KLKDO=";54'7MHZ.C9V0`&R5[\%MPEH<2@/4G7XN.P\/#
M4DDVFQ6VK#4SY]Z,C8UA;V^O0^^?_]7;#,[`G4X'P6"0-11W<)*9F1E)R#Y?
M65F1IFLT&IA,)G:9ZR;@O;1;[%]N)EE+7#(Z.@J_WR_-+10*6%I:@L%@8(TY
M:;?9;'ZZT602^,=ODU?DP6%F9K/Y"^FI\,22#.[^_GXL+BXZU&HU-]WRS^-/
M+)^2?U44K*)F/?E^3LU[=7!P<!Z/QU_2W3E]:U[<?8%OP?H*48V9-"+GH$D`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO
M=V5A=&AE<F1O=&-O;2\R,W@R,R\Q-BYP;F<`````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S,3(@
M,3`U,34T,S0Q-#<@,#(V,C<V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&````
MX"K4H`````=T24U%!]0!#`TY"Z-#I?`````&8DM'1`#_`/\`_Z"]IY,````)
M<$A9<P``"Q(```L2`=+=?OP```17241!5$C'W97-3V)G%,9GT46;=M$F31>S
MJ6FF.]-T-;.=31L777311=.D&9?]!Z:956.[L4['L;83M2J*SB`@#!=$^1`1
M^10!4<#+11!!N'!!^12PT=$^/?<NIIDX:<VD29.2O(LW)_=WGO<Y'UR[]K_\
MM=OMZWM[Z:YBL3@6#H<YI\O%\3P?6EE9Z3H[.WOKE<''QZU;N1R?YW;3.*I4
MT.ET4#JLPNT-0*=;0"02D==J]2]>!=S-\X7D?I:'4*ZB4*J"%ZK@]GBD,@*T
MS"JF9QEH--J&(`@,)>Z^,CR3/6@*AQ6T2*UPV(`OF(+1$L!&B*-[#4NV$`:'
MU1@99S`P,$(O85IDW3\GJ#?J7^^P\6=YH0*>%,>2!;@#2=C=$4E]/)G'8]4J
M+/8P0I$T%BWK^/71.*Q6*W-Z>OHYG7<N0:O5&A/>VMI*)I.-;%Y`,)*"/[P+
MFRL"E<XIG15G%"JM$]:5(`Z/ZFBV.LCP1V`3&9A,UL:RS5Y1*I5LM5J]^QR<
MR^5NAL*Q8I3+8B\KP!N(P>8,83]7@B<0Q_"(%OHE']A='C$V@^;Q,5KM$QSP
M94F`<%C'4;4)AR>&'P<&,3HZ.O0<OKV]/11ETS"8U[&7*2!!A0OO[(,E"_0F
M'Q;,/J3V>;0[)Q)4$A",XZG!A6F%!=%X!I[U'3Q6VG'__C#Z^OI>A&>R.8)E
M42C7X`LDL&C=P(QB&7/S*]2"-1RWVNBTVRA7&C"3+2,3!CSX68D)N0D:,<D3
M"_1&-Q5X"&-C8W_!J95Z6#9^Y/;Z8339H-.;,3XYAP</QS'TBPPFBQWV51>"
MP1`<3B\4J@4\');CIT$9?IN8@UIKA,Y@AE*EP=34U%$BD>AYH:#-9O/33"9S
M0J^@XIBD$^>X/U*I5(<F$Q:+!;.SLUA:,D$FFP+#Z.'UKL/M]L#O]TMQF4P&
ME\O5\[+!>7-K:WN2&H8^<&-A80&;FYL"J>A=6UN#T6B$V6S&S,P,M%HM8M&H
M/YU.6SP>#[+9+%975^DXQ$1W+L$YCNMR.IVD;$D":#0:T/TN);AAM]O]8DR$
MZO4&3$]/BY!>VB^SH5`(*I4::K5:$D!W[A*\5"I=IU'.!X)!3$[*6@S#E`T&
MP\=BC'K_;5(=%FTAA6FZ@Y;:=]5JY1M27M[=W8V(8++F6Y9EWWWI=`*X1<%D
M/!YWM-N=?H(,DTWW<OG<O?)A^<-ZO=Y/T(\*A0(*A2((#MJ:CD:C^0%]UT_G
MUM^.__GY>??%Q7DO[8H#K?8IYN?G0;:`"OT>)7_MXN)B0O1X8V-#JHO#X0#9
M\\F5%Q?M[-M4=3Q1S,'G\TE>DY?K!/\R%HO5EI>7(:I74%SL%K+T]RO#Z?FW
M(Y&HI$Q4+4(.#@[6Q1BUXE=BAXB%E\OE4IS6Q]7A]/37\_G\]RJ5BJ-%Q'F]
M7JY6J]T08V3!H\7%15BLUB(5\)E"H1BA&7G_7_GKH[Y_@ZP9(L]OVFRV'W0Z
MW6?_R7_PGR8YZU2LPLFE`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S$W
M+G!N9P`````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C(W-"`Q,#4Q-30S-#$T-R`P,C8S,#8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#3D>SIY!
M&P````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!$E)
M1$%42,?5U<MO5'44P/'O?<W<Z73::6>FTW;ZL`5:$`S%2%`QAD:C"PP8%QI"
MU$27AH6@_X`[$Q-6DK@PNB-17+!`$VIC08/8`"WET=+']#6OV\Y[YKYFYLZX
M<H&T8.)&?]N3?')RSN^<`__7)SPN.'U[NMOG:SMJ56NG-S8V4=PNG(H)"+@4
M!4&2:5(5PAUA9%G^7=-2GP7:VV/A<+CV6%S3M$-S\TL7J@UZ6EK]-'E4%$5&
M`.KU!J(D85L6IFV32B8IYK/T]T;8/33T42@4.@<@;X??FIIZL[DUT.-3511)
M0I%E9$E&ED3*ND$VF^?&Y#7*NDXN5Z!6JU.M.NP8'#P%;(\O+2V]?.?NW"?U
M8I%>OQ]!$"CI.@(@RS+Y;(Y$*L'<W#Q[=@_1TQFJBY)\=7"@'X_J7OO+V1+_
M^IMOQ5"X2^Z.])"*)XGT13!*.FZ/BNIV8UD6Q7R9GIXN3IYX9\+C\5SR>#Q?
M_-T1M\*/'SO^92Y70%9D*O4:\82&EM)()C06EZ+HIL':>@S+-'$<Y_I6\+;X
M\LK*X'HL02Y?HI`O$HTNX_/[J%0KQ&-);MR<8?[!'':EAB1)V_ZV1\IBFN:9
M$^]]H(0ZN[$M"[VL8U<J/%B((@HBMF63RQ=H`.G-+([C;(L_DOGY[R^^U!8(
M2YWA3LJZP48Z@Z9M8I0-!"">2)+/9A%$%^ELADL__A0IETLM_PB?G+Q!(!AD
M8S/#PD(401#H[^_%I<A(HDBSUPN`W]\"LHO;=^Z^.S%Q]=DGXF/CXZZ%A7EE
M8786PS2IU^OL&=Y%M5HANK+&RMHZDB(1Z@CA5IMH\P=83Z2Y.3-[=FQ\W+LM
M;IJFMU*IGO,VN8^:EHU>+**7BMR?G6-Z>H;-9`S#,'`<AVJUBBQ!1SB$VN1A
M[/+ED5@B->$XSLXM&RK+<H@&'^;R>;34!FY5Q>OU42@42,;7<*MN2N42DBQC
M6R:B*-$01$1%011%IJ9O/_?T\*Y7@<5'%I?C.-+JZOJ9L9^O?'XEFZ6QMDRD
M-8C5T4YS+D.EODY7UV_<NVE0"K]/1!9I;PV05B1:\YG%X8&!\NCHD6)W=_?;
MDB1I#V4N29)3+AO%D0,C2*D$NPZ_0*+>(-+DHJS=)QC\BIX.C7/Q+GP[=G!D
M_WYBAHEL&==W1CI/[MV[+[IMS2W+[HPNKW_\:R9';[`=W8'I8@FCD*'=_P/E
M@L'43(#^OAKMU$GE36X52ICETL16\$/X]3^FU9G5^%`\DR:HJN2J-NIFC&+Z
M.WQ-OW#QTO/8PJO<BX8)M+6Q8>N$JG9A]/"+]Y\XH7Y?,S6WBU&_AX&G^DX5
MBH4W2O;DZP/#YQF_%N'@H;>HNSLY<+!@[MNW]_1B4L/=XDV'P^$+3\1[^[IB
MS<72@"`TJ%8JJWJIX!K9ESN2U%YQAX+'$H.#S[Q6$22]I7=G?6AH:.U?W\!\
M/O?ITN+\V70Z?>`_=Z#_!`Y._!JS\M!W`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,3@N<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S4V
M(#$P-3$U-#,T,30W(#`R-C,Q,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P-.2[H1W&W````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```$>TE$051(Q^64ZT_:5QC'^VY[N25=VNS-
M^@<L6?9B-EG2M>E:;;;IM.MF.N^S%[5>VM5;7:N3>;]AU2(B5D%!BH@@@@BB
M@(@@(JB@6(IS0T44HVYQ7F;ZW9%E)DV3;69[M9WD).=W\LOG.<_S?;[/L6/_
MZ45K8+Z1GD,YQ6IK/V6WVU_Y5Z!/G<XK+`X_@5K',-70'X/#ZT0-C5%JG9R\
M\(_`6KTQBLGB;K1P!9#(^V&V6*'1CX+>S$%!&75!K=%V>3R>UXX,ELG[D^L8
M+;_26WCHZ):#]40$OK@7`G)6:8;1QA<A*B$=^85E.SR^@)5'*?C[04JIM.UF
MC@`RI1K#!A-Z^S7@=O9`H]-C4*M'12T3J=D41-R\BX_#KN)!?@'K3X$>S_)Q
M>A/[I-Y@HGU;5/F\LT>!OD$=1+TJ,-L$:"*[7ZT#K:D-\:DYJ&5RT"U7H;:Q
M%??R2Y\/Z?2TVYD/3KI<WQ]_":X<4,\\8K)136ORI\\52""4*@B$B^2L`MS^
MI@24BGHDI>>!W2Z`?686-OL,9"0KOE@.2G$ELO**()$IEK:VM@(.P:-CYNC\
MTIK-NB:N'\P3]J!=*(71;$4+3X28I$Q_*90DDW[U$":F;)BP3:.G;P#5#2RH
M2*E4&AUR"JH0<SV)!+7/[NWMO>.'W\G.H]:0GQXR6C%*@"*9$DU<(:KJ6;B;
M6PHVKPO&L7%,SS@P;K6AM4."0BH#\6DYB$[,\)?M?E$U8LGY4O!E,!H;,3\_
M?\D/[^U34',+*U''8*%+JD3)0R9N95(0_E4:$C/RH!@8\K^XIT]%VE*%=!+P
ML^ADG`^)Q.=Q*4C)_@Y7X],0GYR%D+`KJ*?3,3<W]SM\8V/S+>.8U99:0D4,
MI00?A8;C[,5@O'<V".]'QN.+Z[<0%AY%=B1"KZ4A*/8F`LY<Q.D/`A$0=0-G
MRNMQ+C`8(9?#$1T3BRZ1:,?G6_O0#_?N[KWK7M](82RM(4(ZB-+*2O!%8C1W
M"G%!/8:HXG+4\_AHY@L0I[<@L)I.!"Q!(:T1Z?1&A-*;<:>@&.W27BB5_=W$
M7-&'@B:L[5$?+?I@FI@$D]T&_L@H[GE_ALPT#K%61]J-]/7<,@I'S%`9C6A@
ML=!AF4*$8P$=$BG46BU2IN=Q@WC!8K'4O-"&&8X?J/%T)MC"+EB6EF%=]."6
M<@CW*ZLPXUV%S;T(AF$,:155L#L<F/*MPS0WC^3F5B)\.[1+7M#%4F25E($,
M-ND+<-*7GYC-9AK[QV5\JAL'B\,Y$`0VQRS*O)OXDMA?IS?`[79C=7L'06,.
MY+(Y<+E<T)'`YR?GD5]>A6<NE]SG\[W^DHGV@5<=O^R4"4WF[8YAPVZ.TXW'
M8@FLRRO[7*5JNWQB!M7$H0ZG$[+99]NM`YK]W&D7GO0I()^>W=4;1[<W-W^Z
M]I>S)=*]_G:B>?II'9=/5/>E'MREN3RRKSLE&#$89`??BLVMU#BK<X<CZH;3
MZ3QWI,FXLK)RFH`/55]<7#RQL+"00$ISXH\[K]<;O;JZFD#<^.:1X/_O]1L@
MLD#Q#QA`\P````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\Q
M.2YP;F<`````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P-S$@,3`U,34T,S0Q-#<@,#(V,S`S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`TZ`X:U
M?@$````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/&
M241!5$B)[=!+;Y1E`,7Q_W-YW[E0.QV@4Z8MVE9;1<70`(F!&+9N1%T:/X,;
M5YH8%_HMW+@C2HQQH\0%8B/$60!N1&MI@>*43J>=S.V=>6_/Q04;PP=P8?AM
MSNXDY\!3_RL"P%K[PL/M!S^LKZ\?M]9BK:5>KW\Y5:U>N'WKUM++K[R*`.[<
MN<.9LV=)TS%;6_=(XC''GUTDRU*BX0`I%=8Z:C,UEI=7+BIK[8IS[I(G.8ES
MNEP*]:.=;=UH-,Z>.+$\O;FYKG=V6GIAH:X;C1LZ'H_TT2.3>F)B0@<:_?/5
MJWIN?E:OK"SH4KF@V_MM_><?ZWIV;NZ2S+)L*8[C,\(GK*U=Y>;-VYP_MTJ_
MUZ';:5$J*IK-)J%."`.!R8?T>WM<_OHK#O;;6&M)X@231_QZXQ<*89FW+E[\
M;F9F9DO&XS'[[199TB4:'K#]8(M"D"&E)4UZ>!?3Z[1)DPAC8EJ/VLS5)WGC
MW$D:C0:')IZA/QB2)ST&_0,ZG0Z5RM0[Q6)Q0^I`?[1_<(#)1^!SXE&,=SG6
M6KR+P><DHP'.#L$;_M[>X<<KUYFI57GW[?/<O?L[#^]M`@G.9K1:NSS:V6$4
M1<@LRR_L[K;P=DRE4J1:+9*F7:*HCS$QI2(X85'"X%W*BR_-$!8ME[_YGMEC
M$U0J!:+A`$&.$(9!O\?FYB;-G2;:6DN2)/0',:=7%\DRR]JUW^@<C&ANMSFU
M.L_[[[W.WEZ+OS::G#YUB#.K"RPO5=FXNT6KU>.YXU7VV[L,HPCOINCWNK3;
M;42KU?)KUWYBKW6?_;TFSCJ&_9ARJ4AU:@HG<CK=+E&44BZ4F#Y2Q9#3[?6P
M5A$4)YDHETG3`8-AS-'I.G/S\RPN/H\60N"%0(H"T[5%I+,<JWF,R7'68`U4
M)ZI,E2W>@[66("Q3KU4(`@U2H[5&JJ,@-4A%(2Q0*I?1A4*!(X</$PT&.)."
M![Q#YQG&&H0/P8-U#@`I)4J'**5`")36Z+!`4"BAE,9:@Y`2K15::WUONC:S
ME&89HRC"&(,U.2Y/<<;@G`7`.8=4"N\<0DJ\!Z4D0@BD5`@A45H3A`4F)R>I
MUV<1\7C\9IS$5T:C$8/!$&LMUF1DF2'/TL>E4F),AA`"YSU:::SS!$&`<XX@
M"`G"X/$JI:E4*M1J-82U]K`QYC7O_1?.N>-`"."]=\88Y[T72JG`>Y\YYT(@
MDU*&0@@`;ZU-I92AUAH>GVJ44EXI]8G@"=;:CX$RL`%<!Q:!#X#/@$__E0#W
ME5(?6FL_!\9`%_A6*=5^LO>I_\8_V6<+;00#OMH`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(P+G!N9P``````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,38P
M,R`Q,#4Q-30S-#$T-R`P,C8R-S,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8`
M``#@*M2@````!W1)344'U`$,#3HM6F-SS@````9B2T=$`/\`_P#_H+VGDP``
M``EP2%ES```+$@``"Q(!TMU^_````Q!)1$%42(GM4TM/$U$4_F;FSJ.=ME,>
M\D@)+"0@ID1,U$2,(29L3%SX#XPN7+ECX\Z5B7L3X\Z%.S<NW+%PH02(1EX^
M4(&H4"@@06BG,YU.V_&<D3$-+EQK..G)[3WWW.]\Y[MG@"/[KTPZ',CE<MFW
M'SZV!D$`(00&^OHVDTE3GIB<;K/=,H:R)ZLG^OLF.'=R:GKXRT9>Z^YHKU^\
M,/SBK^`OIZ:?KBO)JY`DU#P75JGX-M64$AO0!_Q:'7'?\3*Z<GUU[5M5RAQ_
MY$K"U%&K?E^8NW'KYK7'C5ARN5S6?=^_X[KN;+%8G'5*SJ7XL5:\>S./Q5?S
M^/IU;=`VS('U_#869V:AMK?K,^^6'BA6TT,D3//U^'/HNBJ02-W_M+0\2SC/
M2J521ZU6TX4LRW<=QQG;WMY&H5#`UF8>I[*#V&\UT6:UH63;R,05O%];06]"
M0W],P=S.3KK[>#=DNX1TW<'\^#CV]VSK4\H8\EQGJ*>G)U^OUR_+Q'Z,JH`V
MH;-.&4-'JV5A:26'S\MK2,I$3->1IEA<EJ`K,IH-%6:]0N1CN#(Z@A-4+*@'
M<.E=B"SHS6X+D@6[N[L4='\_@FL7D?NVBO/G3J-:]4C^`%8B#I*/SB54O`K*
M!-#1V8D?^S::FM.PJ+"J:4@F$P0,!A\1&@52J50X&:05#&+M.+3&#.B:@%`"
MY/.;&,SVA[+E-[<0B\<HMPA9ZL3(A;/05)4H!5"%`E;!HT$(5;!M.]C;VP-W
MP"T5"OMPRU[80U>F$YJFAV<UFA2^Z#@NS(1)124XK@>O4D&%O%BD#M(I<@LM
M+2VA"XE&CF>:72$MN3WZA9TPL.]7()/.LJR0@\X2!^\3$&.*22H$Q6-Z,U3J
M0%&4\(SMMRPT-:'NK"LS9#9L#-1HOT@H87X(0"08E/<<9R>^89[@RRR'36/E
MNDX(''7"A2*0J,.H&,<YQOEL$6O.B?)9EGNQF#$JA'+&]Y-A<G2!@:+D:#W\
MOY%QU)%A&+P^"3]_`NNE"UT16'0YVC<6:31F%X$WVD&1A3\N'-F_;3\!5AZ>
M8459ULP`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(Q+G!N9P``````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C`U,"`Q,#4Q-30S-#$T-R`P,C8R-S$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!<`
M```7"`8```#@*M2@````!W1)344'U`$,#3L#GZY/0`````9B2T=$`/\`_P#_
MH+VGDP````EP2%ES```+$@``"Q(!TMU^_````[5)1$%42(GME,MO5&4<AI_O
M.^?,G.G<+ZW#,%PZTX@"(@L:H581#/'"R@TN3(PKU_I_F.C6Q)4+%T8WAHL:
M"`6\026U)(A:;>BT]'KFUO;,S#GG.]]Q42'^#81G]2Y^>?/DMWCA"8\5XF&8
MGKYIN]O=XT)(_""\XP^VCHS6#_AV/#'?6)A[9M!W*5=J]PO%8F'F]HV,$`*B
MB&)I-X.^B]OK`I`O[.;$Q.22:9I_FP_+.^VU<CJEKVYMN>S=>^C+3K-YKNT\
M<'?O&9LJ9+RSY,#SMG\(_&1M3SFJ2"FP3(/UYBJ6$3*VSR(B8F5]F6;3^03X
M4#XL;S77,8V0M>7[M-OM<^DAN'GSIV3/[9Q-V![YM,9Q%B:E85:N3-WC\R\N
M8\=][M[]C<!K,S<WSZ>?G>?\A:LL+2Z]HX)@XI'Y"R=.G5E;OD,VEZ/=6J4X
MFL9Q.FQV'=H;#F$8HK2%N^UR8O(U'C3N\6`]9/K7?SA\^!!F/$:]]C3I3(E2
MJ3BLM<Y(@$&__VZD^<C=#ABKCQ'I'HE$FFZWB[.^PMS\&G?_6,6,Q9F=OH&W
MM<'XL4-\]?5UXO80IFE3']U+K5;&[6TAA+@D#6/65$KENIW6FXN+"QFWK[AV
M_3:W?OZ%X>+[Q&1$*I5F8G(2;^"12-C\-?,-E4J>6]._L[*XQ$L3QT@DLER_
M-L-W5Z8X\.P1E%*G@8-2:WV\T]U\>W'^3P@C`F7P7+V*E#;9?(E,9IB+%R[S
M[<7+*&6BXT7VC!ZDU>IR\N47*>>3:!6R?[3.Z5=.,3X^3MQ.S``+PO>\UQN+
MC4L_3GU/>V.51J/!_I$$5JK$?&.9D9$RC;E9QJHE9&H7*TZ':K5*$/@(:=!Q
MUDBF4PRE\JA($O@^)U]]8_7YHT??,H40Q&(Q4LDA@I9'K12C6L[C]7M8(S$L
MHT/M:)U**4=KTR4=2:2W@M("7VF&DV!;$=W.,LI,L*M:(Y?+;*H@Z)M::WJN
MRU;7H9"*DRN6L4P#,601%9((!!I0&C*I)*E4%H1`"$`(0@VA,*E$$F4E>6I?
MG6*A<-%.)&9-PS0W"X7B1JF\?WA[;1X/120,#"F)(DW@#U`J0&L-@$!AQPPL
M0R"%1`JPT"@,A/80"*24_]T"O5[OXZ:S\8&SNH0:N.@P@`@B'1#I$``=Z4=;
M(0484B`0",-`2A/#BF,ELY1V[6MFL[GW8O'X>0&@E!KS/:\:^!XJ#%&!1Z0U
M6D<[!CLSLO.*_R-V+*5A85DFIADC;ML]R[)N\83'CW\!%P2IAUAD^W0`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O,C(N<&YG`````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S$Q(#$P-3$U-#,T,30W(#`R
M-C(W-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4
M`0P."S(3<,?0````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2
MW7[\```#5DE$051(B>U476\B911^AIEA@`&FD2HM!8;4;<)NNUU3&]U8$Z-=
M+]:]6XW7_H3]!2;^&&\T,<:8Z)4AUEYTX]Z8KH"Q*]5V*!T&J&6&^6+&\[Y8
M3.,_V.Q)"`/O>YYSSO,\9X`7\5R%</5P<7&1,@SC;KO=QL[.#KK=+OO;US3M
M6;_?KZ?3Z;^'P^'`-,W:]O8V?-^')$D(PQ#FN3D'K-5J3G&I^/@:>-<P/OOY
MR9-/D\DD)I,)!($?V8N+BXW!8/#`L6U#DN5GV6SV[3B..?!X/`85Q7FOAU)I
M!4$80):DUNZ]>S=9LG0%_D>G\_'EY24'I2F@JBIRN9QZ<'#P8&-C'8>'AZ5R
MN5QB@(JBP+9M=#H=5*M5&*>G**VLX->G3R%*XGR*Q-4#2U(S*O;W]S`:C9!(
M",CG\T2/@7Q.8X4XX-'1$>^:-;&YN0G'L1%.0UB6A>ETBOOW/_@_N*[K&-MC
M?/CP(_B>2Q<C3D^E4N63L&YCNE=\N4!<"A!%$?5Z':F4`BVOX=:MFYR:5JMU
M'9Q$T=V)D^Z;/1P?=["^O@'7=7DW6UM;Z%M]#J8D97AC"TGZ)FYQ<G*"I"S#
ML2_1;#:QO]?`\E(Q'4VG^AP\BJ)'[5937WWU!GJ]<VC:`IBP?=.$3,F,LB`(
M.&TI=8&Z31$U,M,!:C8')97!<K&(.W=N4R%;)\$?_4<+J;^\O`1WXN*]W5TT
M&C]@0-V>$=^_M5LX.S/(;F<8#?MX_<VW"/07L"F[IW]A.!A`IDF45!JK-^K8
M^['![3EWBY!(H$)J__E[$]]\^1/6]!("WT&A5H!O':-64!"1:!G1P?=??8[5
M:HEHBO#:6@FA-X0['.&[K[]`$$5XY]WWYYQ+L\9C&MN#7EY"Y16-@`+$I#QS
M!%%&9R&)&?.UN+MUF_//SM@GC@6R8X4W*$@**M7R=7!)%(UL;L&S%%69D)">
MSX`3"`,?KN=Q\*N0I00Y)PF)K"HF1%Z2%?;#&)$@$>=CWM"U#24AF@/+K(\L
M$T/RN<]!/28'94>\F/#O[9B2F;=G/V:T*DH*.3*"OKIFO518_(0,\>T<G!;@
MC<#W,ZQ3F]S!WATAK7/,ZD=3DE[DBR7,W$6K'F)6&=PY;,DRF32RV9PC2M)C
MO(CG+_X!V6V68W[EKMP`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D
M;W1C;VTO,C-X,C,O,C,N<&YG````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,30V(#$P-3$U-#,T
M,30W(#`R-C,P,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'
M=$E-10?4`0P-.R@S$K8`````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2
M```+$@'2W7[\```!\TE$051(B>V2R8X2412&?ZH:"$,Q-D,Q26P32*#;C4%Z
MZ\K'T+=PY0OX%BY\`*.)"S&=2+H3-RX)"P(D8)@I"//H.2>I3O<;F,C9W)M;
MY_[G^_];P*E.]4^4Q=QLM]OSZ71Z5JE4WO?[_6NKU8KC\8C-9@.[W8[=;@>;
MS8;U>@V+Q0*?SX=:K890*(1H-(IFLRE]FN9!L?CRD\/A^'!FBI/0S]5JE2V7
MRW"Y7)C/YR+8[79E7R@4T.ETD$PF<7=["ST6DSY-TU`JE;!<+D%PR.<O<75U
M><.:RD,;+,)D3)U*I4#3D<EDX/%X0(-%+!P.XYQH&XT&O%XOZO6ZG/O]?@&X
MN'CZA^Y]?"2^W^^Q6"RD,9%(R,J4%!=RN9Q0<8^B*,AFLXA$(N+,C$F/Z4BG
MTT2>_^5T.G\_$N=L)Y.)V-2C.@S#D"&#P0"JJMYG[W:[9>7!]#;BI-5J0554
M!OI"[M^:FLKA<"C2Q3O*[`F3,]%H/!+R7J\GEYEV.!S*$#[G2!B"'Y-=5*M5
MN4=`7XG>,,4M9/4Y#7@WF\U8X!E9?=%NMQ$(!"0FL@C^QJYX'Z.'9%(6)A<&
M9?YM/!Z_HCBV]#9OXO'X]WMQ/"@2SI"M:R:E@?+K<7&N?,;%;\#G_'>0DU$P
M&/Q,Q*^I?T-`/W"J4_UG]1=+BO$?LDGYZ@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E
M871H97)D;W1C;VTO,C-X,C,O,C0N<&YG````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,3(U(#$P
M-3$U-#,T,30W(#`R-C(W-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`J
MU*`````'=$E-10?4`0P-.SE9HI;R````!F)+1T0`_P#_`/^@O:>3````"7!(
M67,```L2```+$@'2W7[\```!XDE$051(B>U2R:I2<1S^/!X59W&>$PP4%._F
M(MYMJQZCWJ)5+]!;M.@!HJ!%1I`@M&DI+D0%#9P'G,=^WQ].W/L&07Z;__3C
MF\X!;KCAGX#)V!R/Q^!RN=0;C<;;T6CT8+%8<+U><3@<8+/9<#J=8+5:L=_O
M83*9X//YT&JU$`J%$(U&T>UVU;O'XT&E4OE@M]O?Z0:Y$/W8[7;Y6JT&E].)
MU7I-00R'0ZQE7RZ7,1@,D$PF4:_7$8O%X)0YM]N-:K6*[78+,8=BL8A2J?2=
MG-KC&"2A,UU<I]-I.!P.Y'(YY4:$U3D<#B,8#"JG7J\7[79;B3`)#62SV=_B
M^OT3\O/YC,UFHP;ICFLJE5+N"X4"%HN%FM$T#?E\7HFP*J.F>#R.3"9#YS_%
MQ*\GY.R6!(S)R+/93(F,QV.8S68EPNY=+I=:*<PWBO1Z/34CACY)^M<&IW:Y
M7"I"7)?.GK$6#D^G4T7"OGFFL\ED`EW7U3TKH0G6PQ3-9A.12`3S^?RSN)\;
MY":)>B<";U:K%0F>2]3[?K\/O]^O:F+/?&,J[AF?3DDL0O-.I_-%4KZ0.H[R
M;5XE$HFO?\GQ"$*<$_</[%4$U:]%L%?>$:R']_P[I(II(!#X*(Y?ROQ!#'W#
M#3?\9_@#/Y;Q'5QD*#,`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,C4N<&YG````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#,T(#$P-3$U-#,T,30W(#`R-C(W-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P.``^H[%(*````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```#J4E$051(B>V42TQ<913'?W/G<6?N
M#'.'\AB0>0%E>+1`A0DI11L18[6I:>+2J+%Q;U<NW+DP:J(QKDQ,%R8N=-.T
MB<986P,K(JF6BH.%0J'.T&&&&9B7PS"O.]=OB"[LRK7A).=^]WSG]3_G?#EP
M1$?T7\F0S6:#GZ[L7/IL)8=6-W!6SK-LL),N&3ENTGG_M)?WPBFFM!R>$[V\
MLY+'OK?'E:E.OMZN4-E-LV>QLIC74.LU+OOMJ<OG1CXY##X[._O"Y]6V[Z_%
M=8RKZSAW(N3/7T"+;F-QMS%V_QY;P_T8YA919T99#B<P/]'"R%Z*=%<[F0=;
M5'K\'&1+2`X;WD2B/*,E/WC[U:<^E-+I-`5)0T\E&?C]*O[,&A6!0)F[+LX<
M=R(QXJ4\CP2ZI4(-]>=;C-R_P>HO/[&5WR-;J5$P&S#=OHU]\2:;K<?D;/+@
MW40B,6UJP#\FOKY0$&/@+?3?[M+5I2*_^3I_ENK4DAO8K./DG3)FJP799</6
M':1]=YY]Q43>(B'93.B".]4Z!G<3\5L)%A;V.0P>$HK26HSH=U>Q:$5>>O$"
MX;O+/'LVQ&J@AZ$V)_?JV_CL$K]*T#UTDF+!R4D+Y&2-+KN1)8-.4&UEQ&[B
M8:5"/I_'5"J5\)BAQRB<^MTT*:(2L\[F@R6&GQLEK5KI%X/]HUQBW*E1]O@8
MJ130;!(>62)JE1E6S"@G`OB[5;9B<121T.EL02H6BV@[8DCI!%JUC$,V8XL_
MPE0K8]R.8*L6D>-1M/@&EJU57KOX-,?;FM%2,91,`DLFAKR]SO-G!FB1%1:N
M7<?M*M+;VXMI>GJ:2"3"Z6XS27L7X^/C1*-1II[TX%$,C'DEW,8J(7^-0',3
M3=5==N.[^/4-V@T!:G(:MZ$-=RTI6IIATE=E]-0I)B8F,'5V=E(H%-!UG8.#
M`QIRXP5YO5Z:FYM1%.40Q=KZ.AZ/!TW3#N\;`)Q.)W5=M+,[@%?HYN?G#_W/
M3$[>%#9AR6*QS.5RN2N93`:SV?REU6J]4:U6<;O=!`*!S5`H1*U6HS\8Q.?S
M?:RJZIU8+$90R(.#@PP.]-/;T[.92J40<9B9F2GW]?7]*$#%3")X6:#XIE*I
MO"R&6[3;[5\)U&F;S?:*R^5Z0R0Y+RJZV-K:J@K=#PZ'XZ'PB0DV"GVX\2I$
MU5\(GTOB[EQ'1\>W`N!'_]H#8@U,-%;!W_^N_?W]9T1"1T,6K1@2"<;^L15R
MN^`.'B-A'Q1L??S^B/XG]!?T!I)5K#?V3@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\R-BYP;F<`````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,3(@,3`U,34T,S0Q-#<@,#(V,C<V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X`
M(YHT/ND````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP`
M``07241!5$B)[51)3UM7&.4G9%-U5:F[+KOHHIMTTS8*:M4NVTT74:4B*PEJ
MVB9$)!$-)3$U"9@P!(*EX#"$A%!,@['Q%`=/V!@_XWG`\#P_C&/CX1G,I-,/
MJR6;JDK3+G.EIWOONT_GGN^<\[ZZNC?C=4>A6/K4X_$(HK&8@-9O_R^@.SL[
M)[+9K&QQT9KT>KTPF<P(AU<5_PDTG>;.^_S^'9/94C4:30B$UZ`WNZ#4VB&^
M,X!(9&WDM<&7'<R.R^-'FMO`YHL<@FM)S*ILT#YG()\WH*?WKE^I5'[PKX$/
M#P];-,^,AVP\#3:6@-GNQ=-Y"X8?/,;@/0GN2T?1TBK$V/C#F&W)[@P$0\Y$
M(GGJE<`3R>3'3Z9G]TQ+7DS/&G%#>!?7?^G"@Y$QS,TI(;HEQIEO&W"V\2)5
M8H%";<"<4KUGLSO.[._OO_>WH*E4JE.A5$VHU+JD6K^(>3V#]HXA#`R-0*Y0
M8ZM0P/;V-G);1<RI#&C\O@D-@G/H'Y1B<GH>4S(Y8K&8G2YXZQB4-B?B\<3P
MLL-Y&%I/P>UG:_J*.B68EOV._%8!Q3*/578#@4@*C"<*;C-/59G1UGX/WS4T
MXJNOO\'YQA](JG&$PN%WC\&)4;W+Y08Q1R;[`L%(G,JU0:,SH%`L@J]L(YDI
MDO81:!9<B*QS9'(1L_-+&!J68W1"@S9A'S[[_$LT7[D&EF7%Y%M]#7R=9>M=
M;C_%;1VS2@.Z>L?0+KH#A].#!)='/)V#+Y*!B<"MCA"27`Z6I3`>32U@Q1=#
M-)&%Q1XD";MQ\N1'$(ENP>/Q<J52Z9,ZGB^_OV`PA9JOME)I%W!3^"N<*VZ$
MUE)8<D7`>%GHC&Y(QS20R:W0&KR8D9OA"[*HD`<EOH(XD4BF.9C,5HP^G,*/
M%R_#OKR,&GLR2CSQ:!)Z@PU6)H1(=`-':7%ZU["9+]$ZA`')4V(<()`<."Z+
M,L^C4.(1)I\,5A^*I3+Y4X+FN1N7FMO0W=V#O[)]:<7EJOI"<1AL/M*:1XCE
MX`NG8+0%B?%BC6DN7T2E4JF!>NE;N=H.Z;@*]T=5<+A8J)XY,2DSX*>FZVAJ
MNHQC8S<RF0`;C6.5F$03F\0V6)-!(E5B9LY2NW"+8LB7RTAMY*'4,>@;G(&X
M=PH3I+]2R]3D4NEL.'ON`F[<%+X$+Q0*7Y`1>[]-SZ!_0(*>OB%TW.Y!:UL'
M6GX68E@ZCH%!"<VC>/QD!IWB/G1U#](\1#]:)X6@$]T]_1!UW,:5J]>@U>I>
M@A\-RO-I+I.1K:RX9!3/\%$GM-OM8!@&#H?#<K3W!P+P^7RP6JWTCH%>KX="
MH8#-9DL[G4X9G<DHCK)JM2K[IQ[S(3V"O;VJX.#@0$#K=_Z<:_O=W5TZVQ/P
M/"^@J@74GD^_4G]Y,_X`I>61PL;]JD4`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(W+G!N9P``````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C0S,"`Q,#4Q-30S-#$T-R`P,C8S,#$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!<````7
M"`8```#@*M2@````!W1)344'U`$,#@$$)B6ZPP````9B2T=$`/\`_P#_H+VG
MDP````EP2%ES```+$@``"Q(!TMU^_```!*5)1$%42,?-E4ES&U44A;-@P39;
M6."_D"U;_@<K%E2*!1LHLH*"(D6%)'+B&(B)X\1&B2Q;EBQ9EFS-<FNP9+5F
M]:BI6_-D6Y)M6=/AM8J-$U*0"@NZZO7K\;OWGGM>O6O7_@\',+U-ADJ9WQ7T
M/J;C.3+,TW&?F0R/F?'P9#(>'F-"YNGHE,%T2,;H!OGV^EO"QW>FXQX&O0).
MZA$T)"\J!0\J>0_JY/JD%D:_PV!RV2'LD96</OBW6=]2LCMI1%&7?9"R7O`9
M.T3&@2SCA$SN*T4?"JP#Y9P/@[ZD!'#^,W@Z_DP!-V0*<LZ+HNA&GG<1L!U\
MTHJ02XUTR`"6-H&)&)$\U(&C]>BU.9!JG6^L@&AX?3H\MBH92X('!=Z-@N!&
MB03)$7B8,H`.VN#=UV!W]3M$W&LDR`Z2)%CF4(O1196PQY^_26>SHG&1=T)(
MV2!F'$C0=B2B+L1H'UA>1##"P.'V0[WP#=QZ%3*D@G3$A(!M!1+G(>P+^6^S
MGX[/&:5Y><Y!?C`C<K@/011QVNVB?WZ.!)/'END`-A<-T\XNG.9G2(7T2`1U
M"-J6X3?.8]!5]!_.O097[*:X0DA9<41MX2A"HU1KH5BJ(YK*P>JD$4N)J+<Z
M2+$"]!LKH/:?(^!:G_5B7_T]6J4$,+F8>]4A'XT&G4)!D21A1<"]@5W+/L(Q
M#B9K&#JC#WO.0V0X11H6>ZX8#&8?MLTNQ#-9.)PNF-1W(`M!I;%'K\)5E^<M
MDL$?H.P:V*U;<!^$L&EPX_<5`_9L%*+Q)#Q>"BNK>MR=7X5:ZP(KE"!5VPC'
M<]@VFL%F(IA.1LQKF?>[]4(X%$0RP^$@F,"&P0FGRX=(+(U2N8I6JX5JO8X0
MG<;]A\^QOK&-HB03F=J()`E\-PA?((S+RXNK\+.SLQO97*'<[9_AN-M'+)&!
MRQM`J5)!H]E"BI?A#[,(13F4JW42^``/%K6XIWH,C=8`(2?#L!N`><^'XY/3
MJ_!NMZOBA`(J]3:HPPQ>:G=(5B74"5BJ-!%)R7!2212D,L1\"1J=%Q;[$='=
MCU^7-%A3ZW%(BTBR>?""\`J\U_U*J]T<?'WK6]S\XDNX/5ZP8@F,("$4R\'N
M31(830`\3);PS(Y*!95:`VD"?+3X&,M/U_##CS\C$`A<A8^&PT\"P6##N&.!
MAPJ11A7@]B=(`(DXAL>3YQ;H=WPXBO((AAG4ZDVT.QU2A0P^1RIL-)$DZ^#>
M_&^@:?HJO-?KJ:*Q&-$U#5\HA8)<03R=0UZJPD7DT!D/9AFVVJU9#W+%"M&?
MAU;OA9N*@Q-E[#FBN/W3`AP.QU7X8#!0<1P/7BPBFR^#SY9FVF^9R%+7.I$O
MEM$DKF@2QTCEQLS[BTO;6/A%3[X)0+/E(<]"N'/W$2C*?Q4^F4P^[G0Z58X7
M9E[>W#)B^9D&\PNKY(=%;.KT,)EV8#:;8',X21/7R+LUJ(@EEYZHB??7\6)=
M!_6+ETBETC=?6_[#X?!#GN?GVNWVTUJMSLBRS(C9/,-Q#%.MY$^KY3QJE1QD
M29RP3)I))%.,WQ]D6)9C&LUF_,'#A3F+Q3(7CT??>]MM[]._]L]WWT/_J^-/
MM*JOQ_Y/PTD`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,C@N<&YG`````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,3`S(#$P-3$U-#,T,30W(#`R-C,P
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.
M`10[DJJG````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\
M```%T$E$051(QZU5:TS35QS%N"S.)2Z9KV5N"\D^;)G;W$RV$74/W<PP6^)C
M$=!-'.JP$Z(((@R,@4T!P?(H4.0M\@;'H]`72`NVE%<IM(66E@)]0$M+2WD)
M!8IGER;SPW")R[S)/_?+_W?NN>?\?O>XN3WCFK+K`@P&+0P&O8?;\UXV$]=>
MS\A&67G%_P<'',&V2;/2:IV@8<7L;E51ILNR?*$:D/=A9=3=X9BB62QFY?+R
M<O#?-4ZG<S/Y=JP!<SH7O`<&NBDC6BW%/F5?_]AIBE7UI*.!4X2E1T),B3]%
M2?S[Z!(FX;'C`8:56:BK+87#L1"[LCRQWF;544PF4\OBXB)U#?CRXM@)G>HN
M6+5IT&J'&7`:U':Y%XII>Z$4>&.J81.*HUY%<<H>3$J_`2/S0_#8-X`5H]HQ
MW<QH:<I`JZ@5>KW.?0VXPUZ[;MZ<&&CK^1K%J0<AK/>'IO$3T`,W(<1G"WP/
M;<;W!]Z!K]=^7*/LQE7?;5#P/+&@\8:\;B<2$Z(G.CL[CHV-&=8]5>?'*W.4
M17,.)MDO@1ZT#5'G7D?HD8VX=G([8L..@<LJAU*E1DU-!4)^W@5^VFL8+'D1
M29&[()<UJP'G9T\QSQEJM2A[AM1MAAES/M3,=Q%]9CM^\]^#VI(4\!NK()%T
MH5NF1F6-`'\R6I!X,Q0WSFQ%=O@6<(N^Q.)T*>9F1@US<S/5_P0_.6>IJE3R
M#J'ISEO(N?8&"F_N0F<''^+N;A06%2$M/0/QU&30TG,A;).A?T"+G-N_H#1B
M*T39;X.1[8'2_`AR@U[E&O8K#IG[TE0)#`_WH3IJ$S@9/R`N/A[4Q$0P62ST
M]DK!9#<@.245N7FYZ!3+4'(O'9=.O(>K9W?C\KFOD$:]BB&-\O034/M$AT>O
M\**'6D0Y:M/$052X%^SK+^/FE>_`XC9!KM#`-&Z!V3(!(]FE?6K<3L[&Q:!P
MQ,33D9Y9!+Y``BGYCWXG!TG)R=,<#CM?H]%XN%G'>9`VGX:T9B>J8E[!^6,[
M$'AJ'QC5I3":Q@FH%7*5`>W=`^B0J#`Z-@YF0R>H*64(#8]%:%@4V`W-T(Z:
M(6SO059.'F)B_H!*I8*;>;3.0R'TW\^I3M"G)48BXTXV"NX58'S<#*O5YBKJ
ME`Z#)Y!A1&^$8<R,FOHV5%0+R"Y"2EH!;MU*@%(]@@:^!+5,(3*S<B!L;8UT
M24,>HZ2XN%LH+"DC>N:C1Z;`X(@)`T-C$,M&T"Q2H$G0!YE2"PZO!U5UK=`,
M&UQR#0P:4%Y1A9BX.*31<Y&<5H(DVET(!$*LO@<?=(F[^I-IJ1"TMD'>UP^9
M8@@B\0#D!(POE".OL(&TGP@M;0JP&[LP.&2`U69S2:8;'8=^U.BJ8W*:$7G]
M!AA,/AJ;>'"S3=H\.5P.,:4+32U2PDX'&3%-W*O&F,E"=.Q'07$#)%(U)JQ6
MF,T6%V.=P83VKGYP>1(";H)J4(]Z;A>"0\+([>^ACQQ&)!GUY//Y4*B&(.Q0
M$A,M4&D,!'R0'"9#=9V(Z*EU=8O-Q7:"F*M$>54S,O,8*"QM0B._!Q55`K`?
M2'#<RQNTU/15$N5N"PN.@SV]4B>+S4:O7($^TE(/VQ6X3R8Q*X^)_$(V&?D1
M#&OUJT'A,K6.TXZ4]/M(I%42N83$2#'I&"'JF(WP\?%&;6WM*A%/EZ%+2XMG
MFWB-LY>#_''A5S]$1$0B+"P401<.X_C1+Q!ZZ0A"SG\.?Y^/$'S1#R&!AQ$4
M\".N7`E&0``%@0%G<>HG+_CYG0*=3H?1:-00+S]^,DRS,U/>C)I*2E9V#H7%
M8E%[)4)4%(0C+YL*A;P:XOIOD1KV)F@)`1`UTU&2%X:XV&APN5RP.6PJHZ8B
M0][7!YU.%TF`]_QK"I&;;%A9<42;3'JEV6QT)=&\D3I=3C^`-M'#Z?G9?G?K
MA(ZF5&F8)(W<2;AL(#4;22JY$^`7_G/L+<VVV[DUOX.,M?VY!_3\(TN`3CNX
MJF?`L];\!<KZK^3;VZJ8`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S(Y
M+G!N9P`````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C$W-R`Q,#4Q-30S-#$T-R`P,C8S,3,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@$F\T7[
M)P````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```!`Q)
M1$%42,>]E3EOG540AI\YYWS+^7PW+Q<[=N0E!`LA(O(#J$.-9"@0)1)%*AHD
M$%6$H$A#BT2%$%7X`>$74`!ID$(LX<0VN7&\7=_-W_VV<R@<.R"6!*$PU2F.
M'LW,._,./,.0I_WHO?L$L$`JHC[\3W#GRDGQY;(7^5I\`=ZO`@IPB*Q[#*+,
MAO>\K93I/C7<^^H=7+Z&'[_FRQ%%/L!YAT<A.+32:&-101TDNHE$-T29+YX(
M]]Y]@!M_C!NI(MUE..PSSDNJJL(YC]%"%,6(=]@DP=9F03<<RGXDHC[]6_A)
MQMGG+M]3P_Y#!J,4YQ79>`P>G',H)41Q1#'.R8N25B-B9FX9$\\Z5/RNB#ZK
MP/R^Q[A\S9<]M=.YR][!D*QPH#1*%*ZJ&`UZ!-H@.)0.J+QG;[_+87?(RJI2
MH6VO.5=^<ZJ!/`+7J[*X,>CO7;F_>9NM[1WRZJ3\YN0,M5J3(`A02J&U9M#O
MD8XSO`<H.=S98K)5X\+J)9X[M_*MUGI-*3,XS?S:X>'^E3NW?Z)W=$`0UYFV
M"=9:DL02A@83A$11C`YB8CO!\6A(419XYQ$1>GN_LO'+.FGNK\S-+5P#WCN%
M?ZG$O^E=/H]21%%,&`1$@>"*E*/>+E%LR>P$)JPARN"]QSM/Y2J,,50>!OT^
M9K=#;:(&C^:6JJK>J)R;4^I$7ZT4D4V(D@8ZB,G'&<-!'U>6I(-#BG&?/!]3
ME,6)%L,!]S?NX*N,E97GF9QJ/X:/1L?VP8.':CA,$02E-2(0&$-@%+&-L38F
MF6B@M4(KB*,07$599&BE,%&"$D\2!X1A^(=I^6QI\=SKPVYG:7MKF[(H&*<M
M\FR,4@HG,8AB>^L>_>X^2;V)#F(J+[BJ9)P.B6/#POE9K+4.2,_@K=;DIBL'
MZ>K%!;+^+D<''4I=,"P'X#VXBN'1`0</.Y1E0:,Q391,D#2;--IMZC:DW3C/
M\O(B)@C73[WG;,Y1(5/M61;G&JA>A]CUF(@T^YU-C@=]C&BF@IS<9\Q-QS3:
MTYBX3F-VFO0XPU<9-JGCY3'R["7>OV7"QH^S2XO\_,-W/.AL8FMU\BRC?]2E
M66^R].++3$S.$-F8(LL);<QX-`1EF9MK8J(6B-DXR_=L]<7<0^*;C9F++%VZ
M1%Z5]'M'C-)C/.!%,&&$".QOWL57)8C@G*>1"/7)!5`)WLO5/\&5,EU4>`-=
M=ZNOO,H+ER_C10A%(:((DPFJLB*V"?.K+]&<G47AJ=F0J?8\8IH.":Z+R,Z3
M7;$:J/MW;[%^ZWOB(":P-6QS&JU`&TV<)#1GIJFWYA'3>K(K_I6?%^D!Q_TN
M69J>5*@U<6*):ZU'/4Y`F>LBYOU_=XF$K[RO+OSS)9*K(K(CHL;_ZPU]IO$;
M_6?FO68(6"<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K
M+W=E871H97)D;W1C;VTO,C-X,C,O,S`N<&YG````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-S4P
M(#$P-3$U-#,T,30W(#`R-C,P,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(!@``
M`.`JU*`````'=$E-10?4`0P.`A`7TCU]````!F)+1T0`_P#_`/^@O:>3````
M"7!(67,```L2```+$@'2W7[\```%=4E$051(QZV5:TR39Q3'\18"\9JYQ'F9
M=3%+=/O@=#K,]-.R.;\0F6[+S#+GAV4LDFTQF\D&T\4;$Y$*R$5;L("4`D(M
M+;1:[JT4*+106GJ%TBM]^_9"J=+2"_^]D(QD@R4N\TE.GN3)\_S.>4[^YYR$
MA!=<4W[K.9O-`KO-FI+PLM>46^07\!BHY;#_/QP(G_=Z75K2310@3M`"8QD!
M3LEIZ+0J->)VVFPX4.`F"6TL%CO_UYMX//X*9=N6P&+1F<]UH_+TB8GQ=/^4
M?]5<S)FM4Q1"+&(A\ER*YXI]8.?LA5QZ"W/A#ECT91`TU2(:C63'H\0JGW<B
MW46079%(]-82>"0\^8595X4F;BDL%G,38C9#0'T*-?2#,$A.8:IU$]B7-D)0
MGH*HZ1@$S'?1+KP&Q)V&D%_8U"F^`XE4"JO-25L"?^X3K0@Y+F=XY$?!*3R.
M`>%W,+<=1-&/&W#QR\VX\O4F_)"V";]\NQ_B_+VXGK$=:O&'>*9/@XK_-NAY
MUTFYO/\3N\.YXE_R'$J/$N4("!)Q]_QFY&>\AK9+R1BYL0:*@JV0,#Z&0E*+
MOAXQJEG9:&?NAXF=!'K6(8RH.@U`]+UEH-&?W2ZM<MS8:PL2E1AK?@N5/ZW'
M>.%J!*M7HN_N/JCZ6V#4JT$0;LI(C)FMX%17(B?S!!Z5?X305!V"TPY;,!CD
M_A-^VNNHKS=(TO"4N1,563O@8JQ&I&$E!ED',"RK`TF2L#L)R(=,Z.D?I>!V
M]`[JD5_4B$)Z#FK*SH)3D0GUR+!VJ5K"&EK$SX%;>A3"W]=CKC8!'DXBNAJS
M,.DB0+@],)F=%%@'I<J$2<(#49L"#3PI'K<K<(]1@=J:,BH(=X"2XU<+4"_1
MEZ*4?I\R)OTFS6^Z!B7W"#1Y:R&AOXEFQ@FH57*,&JP8T5KPM%\/7DL?NF6C
M:.M2@=<L6_@!27I@MM@A$`C0W-Q,J4;&T6@T*0G>R5:,2,_"*-P+#S\)G-_6
MH>7&/LBZ^1@:&H9B9`R2WE&,3TPN1%C*%$"N-&!`J:/.'/#Y?+`Y"&BI`-QN
MDOJ='57L1^CO[T>"U\%-&96>3/'9!&KG2";$C`-X4G<=W3TJ*"GP_&6UUHQ1
MO07-3P;0(1D&52SP>#P4U(7!81/XHCYP^4\7'+1U#:.HI!RBQV(LYCP:-IR9
M<17"*#J$#EXVC`8=+#8GE8X)B#N58%6+\:1]$&[2"Y("SUN/7`\F2XB"XD;4
M<264`QFX`AGN5U2CJ[,#BVKQ.+A3@X\_0R?["+K*#L/$.P-)XR4(V1=167H9
M=W*S4%E\`:T\.L0/KT(F9J*&14?)G5LH*2X%LR0;Q46W\;"!!RZ7!X5"D;NH
M\V"`4$[YQFPA?P4F>+O0=F4#)<=D3%<G(L!)`DF9FU+/-#<)/C:U5ZW%4,$&
M-.3N1D?]<1C5E5`JNFQZ@Y$O%+9LT6C4B7^3XUR,2(_9+V"B?CV8F3N@9.P&
M>7\C?.5K$'JP`N$'"9AFK8*;N0[.JFWP\1(A*5X+1EXJ0L],RU?H0O1STZ_'
M_`UZ8VL*J@I/8JC[`@(#A]&>OP6=.318V&^@-6\G5*6[8*]]%;R;E..!#^#O
MW8/ZV^]`*.21,S,SJ<O"X[&`UJ2^!Q[W+B4I8K$K5N8>A*;S4T2ZMT*<MPY5
M-_=C5OT^RJ[NP>@0"]&PUN`UYY,-;#JD4DD)U:Z3E^WG>IT\W>5RI,_.SB[I
MY[&Q5#S,VPY^PZ^8>\Y';\<?:!4+;/.IB,4BJ>,F1<F\/$/A$.V%)I&+L&M=
MKLF%210ABP/U]XZAM[<[@-@XC22M!3KC^&*3H@)*CD:C-*KT5__GL3<;[/.+
M>%=@-!G]+WU`AT/D.:O5!(?#>>Y%W_P)Y0-\^^+WN(L`````245.1*Y"8((`
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S
M,2YP;F<`````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(Q,C0@,3`U,34T,S0Q-#<@,#(V,C<T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X"(M\%
M;/T````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP```/A
M241!5$C'Q96];IQ%%(:?,S/?__YXXXUC3&1A"RV)(B+1<`N^`4I*NO1(($2%
MH(@H*6A1)!IN@&M``H0B)$P(QDGLV&M[X_UV]]OO9V8HO(F)`B0"(4X]>C3S
MSCG/@?^PY$4/>F\_!A*@$-'O_RNX=V4/U"U\N8FOP-L!H`"'R#82@X1W06X@
MZJ&(GK\0W+OZ'=SL+=QTR]<CZGJ*<V[!]ABET$&*!$N@NR#135'!N\^%>V_?
MP^8?T1RI:G9(/JLH:X]SX)S':"$,`Y1O2!-#G*U`<-&A.Q^(Z$_^$GYVX^GG
M;KZK)OF(?"YXKRF*`L'CK$4I(8XBRJJBJ6NZ+4U_Y25,NN[0K4]!??@X(GDJ
M8S?_DF:XE8]VR0M%W0`B*!&J^8SAW@/".$6J@B!K@P[PSK+<"UE;?PW"-9!H
M0U2PPR+$1:E;N-E650PYR3UU[0"'4F`"0SV?8[W#!(;AP3V.[M]!:8T)8_;W
M1N0G]\">`OZSQT1SGDFUZ>L39K.2LFPP2A!`B6#+@C"*>/GR.EHKN+S!?#H!
MU^`0K+7LW/F%J^T^)NMN_@F\QC4%=>,1[W"-0RF-K4I&>_<Q:4801BCQ!%%"
M$"=8YQ`Y>]G)<(]B,J*=G'>D.A\0.Z@:1U5[;&,QQA!&(>/C(W:V;[._\S--
M63(;YW@\WCOJLJ`J2[PRU$XSG4P!/U@,W)/,$[Q3U;SD]-$I"H^U%KS%-14F
M"%`BA'',?#K!5A7:!-1%#MX3!"$F3FFL!;Q:3/*36`I$N::NU/1X2!2GM'L]
MG*W)EGJ\<N4Z49)RM+_+X=UMUM9?Q98=E`Y(VQU$AT1QBM$:$`<43VY^Y@JU
MG201H1;RPWV*?$Q=-FBE:+4[Y,,#'F[_R"P_Y>C!+N/A`4$0DW2Z**5(LI16
MIPO(]F/WG'^HA$1IARP+.;J?\^A@GU:WR_'>/:;Y*4H46FF2.*.]LDJW?PD=
M1@LA0)(FQ&D;5,RSW2+A71WUKURZO,KM;[[E\,$.2;M+5<W)1R/:G2[K@]=I
M75@F2A+JJB9,$N:3&4IK5B]U,7%_(;,_=,M9N;=1V=?M_@8;UP84C65\.F(Z
MG>$\B"A,%".B./[M5[QK`,$Y1Q9;6DMK9Q)#;CP#%Q6-4.E7!"ONRAMO,KA^
M#72`,1$H39!DN+HF2E-6!U?I7EP!$;($EOM])%QQ2'0340^?;\7Z4.WOW.:G
M[W\@,BE!TB;I+:.U8+0G3B*6+K3)EM;.P+K[]U9\UN>3K6IV2#$>418S/!JM
M-7$:$K=ZF&@9S-*+^_SI322W\-4F?@[>#Q8#`F+&2+CWCS;1<W8HP'<B^@O^
MS_H=SPW2X^@[P>8`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C
M:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,R+G!N9P``````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0U
M-2`Q,#4Q-30S-#$T-R`P,C8S,#0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!<````7"`8`
M``#@*M2@````!W1)344'U`$,#@(U7-;I.@````9B2T=$`/\`_P#_H+VGDP``
M``EP2%ES```+$@``"Q(!TMU^_```!+I)1$%42,>M56UL4V44;MDD<PB&%3*<
MAA2<8&)BE!#60/B!)H+^(,`O-9&IB;B$&!,#9A"3+8@./_"C0R<@&\0A<[AU
M[<8&6^T^:+NRK5W7WO7C=MW:>_NYKNVZK=W:41_?VQ74M$1,=I,G;]N\]SFG
MSWG..3S>0SYNEUU$`.[D+??3V_F9B`#<N2R$?I]+$@IZQ$AZA4&OFE))=R/@
M[J6X[PL+47%PRFN.Q^,?W;N?3"8%!$]F$/F\KM6T15O&,K:R2"22`RR6#`\V
ML=3`UXA'>^"W58&6"<".5N#/A!+CUM^A5%0CD5BH2B02.210V:3?U4L^G\T@
MGYX."6FS$@/=GX!UZF5(>F@_<Q&ZYJ?AU^Z'^>9.3$IR0;5MP_3885CEVZ!7
M'@-W;W8V)-,JOX5II!4>MU.803XW-\OW>IA#^MLG`Y9;6V%3OP&GZE6</UZ`
MJG?7XM.W!*A\/1_B(P5HJ'P*?3^N!JO>"Y8JA^G62S#^<2`P/-1UB"C`SZHQ
M)T5PTD!3;<_#^/-*5+R]`3\<>0RJ4[D(7>(C?I6'2!T?NB]6HN7$&BC.;87]
MVN.8:!&`'FVAN?>S6\WMD#CL*C8:^@WFKI=QXLT"U'^0A^@O?$!"XM[X!Z0\
MS%_E8^C,*LB_$F!$)L)\I!G1.8:=F0E+,L@G[$:Q1GX<=QHWXT+Y4L8IXE9"
M)B?H(U"E(5\*$K_&A_%<(<R-S\'07H)NV7NP6C3F#/)$G!7.!CO@T.Q#U3MK
M4U*D,I:G"8<)#`1Z@GX"!2\5F/TI#SWB)S#:OAT^QQ5$IMVE]TF)?42:GFJ1
M477LH-=V!E3'+IPBQ>,T3DG0ER:VD6"._*53GP[8SB/_;@5,EXIA[]R9LFO`
MK:2X1B.6%O$\[G'<[CP-E70/3)+U<#:20A)7<,5+D:O2V8[G`9X-2P$,Z=\[
M.6EXN'.V$-/2'-!2`53-N]'=40'&08/',A91]XWC(A^CH+@&&6K:CM.'!2E7
M_"MS.B=KYK'Z%3#7%H-J?3'58#ZG@E+<."ER3EC_'A/Q>*0T[&L"+=^%B\?6
MI>R6H;D^?=XK*G%-\/*CL-9O`M._#['I+B07/9E-Q#(FL[+C*+32%R"OV8*;
ME068_P^WW&W@8ZJ^",9Z(88:-V&PNQR,TRS.TOY!221L9Q=FFDF+EZ#E]#IH
MB8_COV;QN62).%B["N:ZC?!J]H+K#YOE-NMBQR4/[%!FHIL>DQ5A[.H:])]_
M%H;J0K`U>2E7<$7F-.:DX#*FKQ3#??T1DLP.S,W8']RA9!+RQ^B10P9%:<#8
ML0..X0\1H0Y@L+805-TF6&J?@8:XPGBA&.,-6Z"[7`3?G==@4NS'1-=&Z-7B
MP,)\;']6\F!PBDS%'@ST?HY)/Y.>BA>@:UJ:BE[E'O@E*S'<L!4^W4$899OA
MM%3C[B)+ZP:NRS3RCZ$;:*T)AT+Y6=880^;Y<)G/ZRR+Q6+WY_E(_Y>(S_4@
MS'X/1]MZT.KWL1CKP^C@-U#W7&2Y>V,V*F?<;J@)3GD0BT:%#[6)N.($)EVI
M360:^NZ@MOT5,-:6"))^82#@%MO'C/>+1Y9$/H&0(/=_KSR]5B)2*ZK@<QO"
MR[Z@0R&_R,72\/N<1Q_VG;\`P!(8/OR?A"4`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O
M,S,N<&YG`````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,3(T(#$P-3$U-#,T,30W(#`R-C(W-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.`PEJ
MHJ3\````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\```#
MX4E$051(Q\65R6Y=11"&O^KNTV?R'1S?Q.$J";*%;A(Q2&QX!;\`2Y;LLD<"
M(58(%A%+%FQ1I&QX`5Z"@(@0<@;L./$0SW<^?<[I9N'KF"A`(A"BUJ6O2W__
M]1?\AR6OVAA"_060`A,1_<F_@@=?S(.Z12B6"0Y"W0,4X!%911(0^Q#D!J*V
M1?3TE>#!EQ_BQ^_C1RNA/*(L1WA?$]`(-5II3)0C40MT"R2^*2KZZ*7P$.J/
MJ8>?4^TI-]YA,':XTE-[\%ZA=2"V$2I4I*DAS2]`=-ZCFY^*Z"__$CZ;^!L_
M?:2&@WV&4X4/BLED@HC@ZQH1(4DL5>%P94DK5W0N=C'I%8^>^PK49Z<2R7,:
M^^EMJKV5P>$Z@XFB]"<M@E!-Q^QN/L8D.>(FV+R!:$/M/9UY2_?*5;!=D'A)
M5+3&[(-FI6[AQRMN\I2#0<!5`;Q'"=A(<,64.@2BR+"WL\'>X_N(UI@X86OS
MB,'!!M3'0/CZE&C.-''+H3QD/)Y2%!5&"2`H$<IIA;4QW4M74%H1+B]1C(<0
M/*'RU'7%VKT'7&]T,'EK^4_@);X:XRJ0$/!5C2A%77H.GCPFRC(B:R&`C3,B
MFQ#J^@1B+0=/-YD,#VFD9XY49PM2]USEJ<I`795H8X@32W]OE_7[/[.U=H^R
M*)B.!H3@@8`K)I2N((BF])K1<`2$WFSAGFF>$KQRTX+CHSY*P/L:O*>J'$9;
ME`AQDE",1GAW\G@Y'A!"((HBHB2CJFH@J-DF/Y-E@BA?E4Z-]W>)XH2Y<^>H
MJXIFJTUT[2WB)&=_:X.=!ZMT7W^#J&RB3$3::(&.L$F.B2)`/#!Y-OE)5NC5
M-(TQ1C'8W68ZZ%,YA]*:N4:+X=X.V_=^83KJL_MDG?[.-M8DY,TF6BG2/&6N
MT0!D]31[SCY4(N*L19X9]C8&'.YLT6BUV=]\Q+!_3*0-2D7$-J5UX36:G46,
MC4_=0)9E)%D#5,*+;A'[4,<+UQ8O7>3NG1_8?K).UFA2NBG]PP.:S3:7>V_3
MF%\@R5*<*XG3%#<:H;7F_&(3DW1F8?8'MYR4_P"5?]_H++%T]2I%53$\/F0T
M'N-]`-'8)$5IS?[Z;P1?$1!J#UGBF6MW3T(,N?$"7%1\B,J^(UKTU]Y]C]X[
M;Q)$8;5&&8/-,GSEL&G*Q=YU6N<702!/:A86.HB]X)'X)J*V7YZ*Y8[:6KO+
MKS_^1&QR;-8@;2^@M4)K3YHFM,_-D;>[)V#=^OM4?#'/ARMN_)1)_P@W&1'$
MH)0BR2S)W#PF7@#3?O4\?_X2R2V"6R9,(83>;$%`3!^QF__H$KWDA@+<$='?
M\G_6[YI"UM=0WO&(`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO
M8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\S-"YP;F<`````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(V
M-C,@,3`U,34T,S0Q-#<@,#(V,S`W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````7````%P@&
M````X"K4H`````=T24U%!]0!#`X#&YD;U;0````&8DM'1`#_`/\`_Z"]IY,`
M```)<$A9<P``"Q(```L2`=+=?OP```5`241!5$C'K95K;%-E&,>+0U$B1B,8
MC<@J1A(^^8$$I^$#QD0F.,018_SB)5&9(<2,,+Q`PKBX+0P%R@B@FVQ#7)@9
MW:6;@VVE6W?ING9K=[J>]9QMW;GT]/3>P]:M[5;^OF6"DO$!$T[RS_.>D_?\
MSG.>]WW_CTKU@)='',\B0CJJ'O9UH[4XBPCI^%"`/EG0AD.2!BE9'?3V.;KK
M-R/@Z7(@):GC\9@F%/32B41B[YWYJ53J6:(7%X%DK[2"'1W,$P4V3U&4#&#^
M=9M%*PSWGT`BU@G?:!%&FU9!HHMP*V'$Q&@=>F^<1#(9+TXFDQFAD)SG\XF=
M9/S3(G@X'%8S="?,AH,0.*J19,?X^')8ZUZ!;W`'G,UO0M`NPXCN-4393T!?
MWP!;USZDYTU-A1J'NH_#:6LF:\*I%\%)MDN\'C[79CP08%O7P]7[)?S6G3"=
MS01S80TBEYZ'\OMSX"M68[AB'9RU:R":/X3D.@*J/0?#AB\@"HQF;B[YQ"(X
M*<->4K]B#S_$6'5;05U]&T-UGV/L>CZDOD)(EI/PV<X@,'SV=F2-/V.DYRQL
MAB*,&?/!.O6(QV<Q/S]_^!XP680"61;C+MH$-]L"6W<)'"W?0#`6P#=T%&'F
M-!2Q`5'9""5H1R3@@H_K!DM=Q_!`$QA[,R3!`K_?`T6)QN?FY@Z1VB^[`S\I
M26X8VTMA;,F#N:D`HGX/E(%=B-L_QNS(1YAEOT+,78!IL033PB4$N28(=#/H
M(1WLEGI0ECI83'^"96R8F9D!^4#V77@\/@,/WP&JYS#LK4<@]!<C3!5"H7_`
M%+L?L<E\Q(1\3//[<),]AB!3!H_]`MB!:MA-5^`PE8%GVW!3B:1+`\+,5DW=
M#.^.A,2X+-HQ/G(15OTA,!T'(?4?A3)Z%%,3A8B)WV%&VH>X7'`[QKAO$66.
MP^OX!1,#O\'>6PW66@'W2"5\G@$$9%I+3O(FE>09A[&M!#VZG:!:=H"^1A:Q
M_0#XWF/PVTL0=I4BRA=!\11ARE>"*%>(\-A!1)V%\-I.@S.78:CM!+C.7:!T
MF]%=_Q:ZKAT"S[F@$G@F2]_\?9;,WW!PU'$,-I$]7),-4;<-LCX'DGD[V1U$
M]IP%#9'G@UOA[R'2;P-_=3.<-=M@;]F"2:H8/L'@2/,F)^E_;2(9CWP:E6LQ
MVK8)U*G'D:HANU.G0LJ@PBT3D87<6TDTDV>=9'R-C.M5D,M7P%'U,CC3NXA%
MVY":\RP^1*(P2O>T[H:E<0-&JC(1K5H&7"605@)I(T`C40\9=RR`T:!"XH\,
M<`1,7<Z$N?956`S[R>EV:A;!H]&P5HEPPDRT`:Z6C;!IGD*T\E'<ND)`)$,T
M_R/=0L:)RX_`??X9#):OA=BW!8J_%BZZ2Q`%M_:^+I@V*V'2P$S6K82[^DFP
M5:OA^?5I!,L?0_+2$B(5E(M+;Y>"NZ@F?[@.8MUC&&Y\`['I,2;]_GW!:6\9
M'W/D4H;/`HZ_-H(;W(.ID?=@J5@%IE*-L>IU&"A;">I\)B9JUF.X\@7X^G)`
M=^3"HW^);,<S@?CLS/;[PD.AX((K=I8@%/#<XXK>@??A[7P',LG21L"^P5PX
MF];"XRS%_)S(6$U7&DWM^V$U-YP+AT/+%\$%@5O!$#_W>;D\<GS_X^>E2$P;
M$.%.89+XN;OW:R1CW:#,&O1W50CI>>/C=(9[PG$N%)00B\74#]2)1'Y"&_"+
MFG3GH<UG/AAJR0;OTBKISA0(2!J&L=U=/&)4RXG41$O_=\NCK$U9)OV/D#VV
MR$-OT.&P/TOD&?AD;O>#OO,WY%B(G%I77]H`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S,U+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(V-B`Q,#4Q-30S-#$T-R`P,C8S,#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@,R
MVZE-V`````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!$-)1$%42,?5E<MK7&48QI]SF5LFDTSFFLQ,8C)-)]6DM!%ML11Q(.BB8L1%
M(8@*NI0N;/4?<"<(79F%(+K32A$$0T$3&*K26$TR21.3)I/)9>[W.6?.F3/W
M\9T1%S691G"C!\YB+M_O?;[G?;[W`_ZO#_.X'_VK?H?!T'>E5*U=3R53T&AX
ME"MUL*A#I5*!X7AT:56PV^Q0\?R]1"+^H<ED"MOM]MICX8E$XN+6=N!VM<FX
M>GN-T.FT+4![0:/9!,MQ*)=*4,IEQ&-QB/D,A@>=&/-XWK5:K;,M!M\)OK2\
M\JK!:'89M%KP!&J!^=;+L9#D(K+9''Z[?P^R+".;$U"K-5"MU.!VNZ_1\L[P
MW=W=YQ^L;[TOBB(&C48P#(,"05JJ6T5RN1QBL2@>;FWCJ3-C</9;&PS+WSWE
M'H9.JSG\BW,L_+//OV"M]@'>X70A$8O!X71"*DAM:[0:#4IDAY`OP.D:P,S,
M59].IYNC]^._<]CCX-.O3'^2R^7;-E3J#43(TU@R36H3".P&42R6<!B.H*0H
MJ-?KB\>!.\+W]O?=H7`,.4%$JTAP;Q^FGFY4JE6$HG'\NN3']M86):<&COK1
MZ3EBBZ(H-V;>?%MEM3MH^V7(4I$@55!RP+`LRN4*\GFQ';1T*MM2WA%^1/FM
MK[^YW&>V<W9[/R6AB&0Z@R194I05<-312&M'V0S`J9#.9O'=W!VG)!5Z_A%\
M\?X*S!8+4JD,=G:"[:0,#3FA5O$$9V'H[FK_SV@D'J_"@_7U-WR^NT^?")]?
M6%#O!+95.YN;*%*S&HTZSHR-HEJM8.\@C+W#,#AJLM5FH=.J0U^O"?N1%);7
M-F[26GU'.'FM)S]G]3K-%:7E=4&D^!6PN?D0J_XU)*.'E))BNV"%?.?((UN_
M#7I]%W[X?OY\.!KWD?^CQS:48F>E)KV3R^?)XQ34:@WTW0:(@H!8Y)"4:E"0
M"FWE):7T9TK(,I9F#,LR6%Y9?>;)L=-3A`H<&5Q4E3LX"-V8G_=]Y*,3V-P/
MPM5GAF*UH#N70:41PH!C$1M+!13L;\%)>S;UFI%6\^C-9P)C(\.2U^L5'0['
M52J<>$0Y?5&7I*)X;G(2;#R*TY>>0[31@*N+%"?W8#%_"I<MCMGP``RG1N`]
M-XD0I8E7Y,71P8'7Q\<G@AT]ITSW!_="[_V8R6'08H),\?6+$F0A0PIO01**
M6%DUXXG!&DQH(I:GST(!BBSYC@,_`E_\Q:]=.XAX(IDTK#0)A4H9VE0(8OI+
M&+KNX-NYBR@S4]@(VF$V]B%5DF&IE07OY4N_GWA"C89NU#1J>(TZ#`\/7<L+
MPLM"^>>71CQ?8>$G)YZ]\!H:FGY,7A"4B;/CUP]HSG"L/DT7P^T3X8-#`^%N
ML3#",$V:RY4#61+4YR>D%V+)*8W5-AUUN\^^6&$XN6=HM.'Q>`[_]1V8S^<^
MV`ULWTRGTY/_N0OZ#][T^?;9)Z]P`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,S8N<&YG````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M-C0Q(#$P-3$U-#,T,30W(#`R-C,P-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P.!`TBCO8B````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```%+DE$051(QZV5:TR35QC'W_=M"]Z8
M\S*S9%&+R\S<E\W%:+?YQ9AL?IE._;29C6R)&\O<IBY.=_."P2A30QI1!!Q#
M#<R*%"@J.*"`I5!NI:7T\E(N[=LK+;U`:Z&E_'<J;"XI2USB24Y.SLDYO_.<
M_W.>YZ&HIVQVVZ"(="1&ZEDW17VVJ+DN&PWWLY\-W.VR27UC3C'B3N&8\Z%.
M6;D57D>++C&?G)P0^\9<ANGIZ.&_]\?CL16DOY0$<CEM::RQ.Y.S#F0&@T$>
MV;1%W7F'Z^\XCVBX&6[S61BKEX/K/X&9J`+#IG(HFZY@.AJN13R\VN=S9GI&
MK<VQV.2%)'@@X!<.&)O1T70<G*6W&G$'.VHIA*YB#3Q=[V/H[B:X*ODPW]V(
M@.%#&!O?1$_3=\!X'T(!IU+=F@.]1@:'W2),@H="(=KIL.Y1/_S9P]:NPT#K
M1_"IMD-U(14#.0*$BQA,%U-X5,!@+"\%[AM\.&NV(%"U&VS96_`6O`Y'W>D#
M1`%Z7HT34GA'-:Q1]AKL)0(,YRU$H(#&Y%D:SFP:CW(9N$[2B&;1"/]`PWL\
M#8&C`D1_I!#*3L=$2U$M,7)9\E>SCT@M0VU<V%<.9\O;,(L%"!73F*F@,'6>
MP:5]"S%TA`?I/AX&]C-HV<M@^`L:M7MY<.^GT?CY\VB17(3?Y[F;!!\9U(@[
M&@ZAJSP=C>?38+_$8.8.!=01*:XN@.Q+/MB?>"C[E(?VKP4HW)^*P5\8Y&4L
M@B5+@+P#+^#>K<]@,JH,2?#HI$4XX:N#M?4]2(\MA?LJ`\@(O('`_Z!1=8@'
M]3D>;AWDH?L4@XI#?`R+:5S+Y,-VF4;IJ36PL44(!AP93_ZRVR9J;[H@TK8>
MWNT<.(>^>UN1F[$$DS=HH(;`%10B<@J_?Y\*DV0Q),3Z_F(&I<=X,)7P4'Z8
M.+:<0=FOJV'3GT8B'A(!1[ZTB'+8A]'\X`P45=MAJ%@)<UD*+GZ\&)%_P<-M
M##K*4F%7+H6J-`4>.1\CLA2HBQ;`<IF!IC`-JGP^]!7+H:QX!_+:T[!:3*`X
M*RMZ4'-2Y+0TZFRZ$^B0O($S^]+@+)R3I9G"C(I"3$-C6L]#3$LCKB:OJ2>_
MJ))&Z#H#P[578+BS$59RWFV1ZQ(\RXCQ29J8F@ID^%T5,#9M1=ZW*]%RG(<9
M*8'_.6L]R`70D-XS-T^L5U$8+5X"P_67P2EW(!RH1SSF2`XBJT5O4-1^@\[J
MS6BXO!ZWCRQ#J(1(4ST'DL]!Y7-SLAXK96"_N0;Z&^O0*4E'E_P(B>Y^\3SA
M[Y,&_4-<)%@)?<TF2+.6H_[$DEGM*ZE9B6KFQLI9,%?P''%N.MQM.S#NN0V3
M_B%GLPU+_S-";2--K%FZ"N;2-+3F;T#WQ17$:2GD%0RB-XESB<9>(D7"8EW)
M.CAO"Z"5;4%HW,PFSL\+)IF09EGM'FW#)YZ^^YLQTGL0X[H/T%:T"GV_"6$D
M3E/DK((V?RU&;KT*;<F+<*O>A4&^"Y:&U>A5BCWAT,3.>>%C8UZAR="$MH8L
M>#VVQUG1;2U`CW0]7)T[,:K8AM%*`=22#?#T[().MA;#_6*2<CE6K9)4M]<?
MA;JC^HK?YULT3QFSDGRNSG2[K)F12"0IGP>X7%AD*V%29I)Y"_HZ<J&0YW.)
M?2S;SQLR:Z_XQAR(1!X)GZH2V;@AJ==C?UR)#%TYNWON;8/5)`TB[A9Z/`[Q
MT*#F'^<1@Q;%8E-"<AG_?Y>\WFZIJ%U^!FZ'UO_,"[3?/RJR<P,@I>RKISWS
M%W+%"B6YDQ2G`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R
M,R\S-RYP;F<`````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-S(@,3`U,34T,S0Q-#<@,#(V,S`U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!#`X$
M*H>$0TD````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=?OP`
M``0'241!5$C'W95;3!-F%,=]6K;$11\6DBV9J8DA<4$W,C)F:+!LL9@P6`&%
M,:&`XY9AN70J)<)@NM`6$'#HY*Y`D4M;V@JL@K3E8@%+2^\%6C08Z9@IDP(#
M9(3\]\D["&-/^Y+S=O([E_\YY]NW[W_[7KZ<WV]W/*$H^P8H@\,C%&7_X*;U
M/QJF#&FT%+/52EE<7*1L;&QX[`H\IC><T1K,=\WC=@P]UD*C-V%X=`PC6CVT
M1LNFZ4UF3-@=F)RT&VRV\939V=EWWP@F3C$/50/NOF$M=.8)3#Y]#L>T$U//
MG!B?FH;-,0VM:1RC!BLD73VHK;V#GEXEW`L+==N"29D'16))DUHS!KW5#J/-
M`8O]*8$^(_`9Z$PV=/6H\%TR"]',>,2?3P"/SX=&H\'JZFKKMG"%0DEK:FZ#
M^+X<(SHCK`0\:K1MFFG<@1[5(PC:I*BHK(12J2+0T?7>WEZ.T^GDD,0.;`LO
M+"H.O5Y6#J&T"YW="I*I%3*Y"@.O6T1:T:T:0''9;71T=$ZLK*Q\LKZ^?GS'
M0C[6:%=9;`Z:A%)(.A^@L54&V6\*-(L[4%%W#V6_UB#Q^TRT"D7Z78]?47')
M:E(J&W4"(:KJFW&CX@X$0AGN-K?C9NT]L"[F@7$V%C=O5>P.[G`\$81%1(/-
MR0.?E)Y7<!U9N5Q<Y96CN+P:%Z\4("[Y!T1$)R,T+,+>-Z@^M&,XK[!4DOT3
M'^SLJR1`/CCY?/!*;Z/T5AVJZUO`R>/C[+DD,!/2$!.?@KQK7.Z.X9'?QDDB
M8Y)(=IF(CD]%=4,+?JFLQZ4<+G)_+D$^]P92V3FD-;F(BDU!7"++:319^M\(
M;F@4'#EU.F0TB!&YF=VY^`O@E54@D96%UP$SLO()O!0IZ=E(NY1+JN`A-BD=
MK(S+?[>TBJA;@LE(O2=H:AGR#PB$UW$??/H9%7[^=`30@^'M0P651D?X-TQ$
M,1,0Q(@B@D8CZ.L(!'X5CA/4+Y#.OBS9$DYF]0-2WO/4"VGX_(0?/O;VP4D:
M#0Q&*&@!7\+KF!<\/3UP].AAG*('PO]D`$)"&`@.#D%8^!FT2Z2OR'8RMPPP
M,S/CJU:K[6*Q&`V-C6AK$_Y5557-+>1?L7&O?82B@G?P8T[4*Y%())/+Y61#
MJ\IELOLJXM>DT^FX:VMKOMOVG3AXN=UN&CE<M+FY/_T4B@?!'9*@%_J1_;#H
MWD:_(FF>^'@L+R_3EI:6WB*G]A"Q@[M>)I=K-M2H+X'#?``UE0ST]QS&\&#D
M_)X_"2(P0Z>IGILP?HB'7>]C3$=NC(:#,6WSWN$CZ@SNE.4(NJ2^Z);7.)>7
MER0+"W_DN%PS]#W#7_S.XQJTF5`HVJU$:.__].\D8GE..29.NURN8_^6\0_]
M-+5/<^.9W0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B
M;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S,X+G!N9P``````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C$W-R`Q,#4Q-30S-#$T-R`P,C8S,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!<````7
M"`8```#@*M2@````!W1)344'U`$,#@4"JRK:\@````9B2T=$`/\`_P#_H+VG
MDP````EP2%ES```+$@``"Q(!TMU^_```!`Q)1$%42,?=E6M,DU<8Q_VT;(F+
M?EA(MF2F9@N9<6YS<V$$(L7%RB(P2H!N`L6A6`R4FS!*!`'-6BIR&4BX@T+!
M4EI*$42ZMJS4`BLMI?0"M&!PT#$#D]L`&2'_G?$=A+%/>Y-_WO/A.;_SG.=V
M#ASXWWXO7LP?M#LF*,J>7HJFKY^B5&LH*B+UDSY*KTY/,5MLE*6E)<KFYJ;+
MGL"#QJ$@_9#YGGG$#JW.")UQ&'T#@^C7&Z$W6;9D)!JU.S`V9A^RVD:B9V9F
MWGPEF!B%RU4]"^H^/0SF48P]G8)CTHF)7YT8&9^$S3$)_?`(!H8L:.V0H[JZ
M%G*%"@N+BS4[@LDU#S=+I`U:W2",UC&8;'98QB8(]!G&GTW#,&Q#A[P;4=$Q
M"&-&XF(D"SE\/G0Z'=;6UIIVA"N5*JJ@401)6R?Z#298[4\Q8+)M:7C$`7GW
M$S0T25%67@Z5JIM`!S84"@7'Z71RB&.'=H3?SLVEYQ46H[FU`^U=RBU/VQZK
MT/-/B$@HY-T:\/-+T/:P?71U=?63C8V-CW:=R%]T^K6XI%0(1%)(VQ^CODD&
MV2,%A)*'**MM1%%I#:*NQJ-))#;NN?QR[^2OL6*34"-H1E6=$#^6U4+0+,.]
M!RVX6]V(N.1,T$.8N%M2NC<XJ6E!8$@X$CE9X!>4(HN;A^\SN+C)+\*=XDHD
M7^<BXLHU!(5&P8_.L/^LT1[9-9S+SY>F9?.1F):-),Y-<#+YR"DH0T%)-2KO
M/T!:9@X!L\"\S$;HQ:O(NL7E[1K.N!`A_28\BGB7@+!(-@$*451Q'RGI/&3<
MRD,6KQ"QUS+`3KX!1C@+$9=BG*9AJ_J5X+IZP?MG??P'OO(+WMH8&AD+?F$Y
M6.Q4,)C1B$O))/`"1,=SR#J#W"H'W['BP$Y,_4O8)/;<%DQ*ZBU!@[#WM/<Y
M'#_Q&4ZY><+#BX8S-']\^KDG/*DT!#%"<8%Y"><#&`@(#L/YKT/@XQL(=X\S
M2$A,D6X+)[7ZCMEBF8IA)^$+=P]\?/(4O*C>H-,#0?7^DAQX'*ZN+CAV["C.
MTL[AM)<W?/WI\//S1U!0,%JDK2])=S*W/6!Z>MI-J]7:)1()ZNKK(1(U_UE1
M4<&[S;]N^R'[`^1RW\"-]&]?BL5B66=G)^G0BF*9K*V;V#7H#0;>^OJZVXYQ
M)P8?+BPL4,G@HL[-_>&A4G7YM4M]GQO[#\)B>!UJY95Y8N.RLK)"75Y>?HV,
MVB-$A_?<3+.S,W23,1\.\R%4E0=`+3^*/@UC?M^/!$EP@$%7.3=J>A<_=;R-
M00.9,3H.^3?L']ZO3>"-6]]#1ZL[NCJKG"LKR]+%Q=_3Y^:F:/N&/_\MAS>D
MCX=2V6(EB3[YG[Z=)%FNXXY1G]G9V1/_EO$WN2.U0($`""L`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO,C-X
M,C,O,SDN<&YG`````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S<T(#$P-3$U-#,T,30W(#`R-C,Q
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4`0P.
M!11?_F^C````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2W7[\
M```$B4E$051(Q^V4:TR;913'2?QB-,9]))HL^\8'LXQIR**)"]M(MLAT&1")
M`P'+P,)0+AUR:;F5L4*YO+1`H>52"I0[+;24W@NT!<JE+6!I(3K8!!3%*<WF
M($'V]P$3M!J3&?UD/-_.\YSW=\Y[_N<Y?G[_>2OG"T]^PL@^I=;H3OXKP-75
MU1=<KB5Z664UG2^2/*%JA>B5*9X<^A;K1,`_@H^;S0*AN`-M77TPFB?@F%^`
M?M2"TNIZY+,Y]M6UM:J_#55IC2?4>I.DI%+PM*-W"#+%"%JZ9.A7:"!7:C!J
MF01/),'[<<E/J_AUNP)1<\HSP\MX#<$<J@%]0VKHQZRPVF8A&]:B3Z&&=6H:
M0R-ZE%0)D)B1A[#H1(1&W-CO&5!\^)?`W=W=YQR++G]QN]1?KAQ9XO)%4.G'
MC]K0,ZB&4-*#+ID*6I,%!9QJT!GYZ)2-D*1ZE/)$:&B6[+B75VCLTBK_1X\?
MO^0#)Q6=&B35B4B/ZYK:"&@8O:3RGL$1E->)D9#*!+.$A]P2"AG,.U!I#5A>
M^0*SC@4HM6-HD?:AI((/9G$YM,9QR@>N,XPV%'%K4-LL)<&C$'<.D,K'8)UV
MH%K8AACZ;4BZY;^>3<U@T;4$^_PB.OH4J&ELQPQ)(E/I\'$&"TPV9^6[[>TS
MQ_"<@F(/3]2&QHX^.!=<D/8/$Q$'45@N0,X="BJ-@9POPNU9AF5JEL3U@W67
MAQL)J4C-*49KEQR,O+L(CTU&)K,`=KO]RC&\22SQI&;E0]36>]3C0FX=$M.9
MB(A+`9O\T:&H&L,85#H3#B?HUF=%N!I)PZ5K48A)RCS2(#HQ#1_$)X.1E8OY
M^?G?X/>_VIA+Y3<B)"8!P=<B<#X\"@&!00@,>1<!IU_'];0<G'O[`D+I:0BY
M&H:@=\)QYLU@G+T8BJ#0"`1>N(+ST3=Q^HUS$(I$>UM;6Y>.X9[M'V-S-1:\
MEYB""F$3<DHK0*/J$<[F@L9BXR-Q-^)H\:B0]B*2EHC8+B4NAD6"=CL;29FY
MH#>T(Y)=BN*R*N_ZQD:,CZ">K>T$)FE)36,+&B;L9+[-8)NFD5K(P;!Y$CHR
MW_VV.72;S!B:FD.2=!#I[!)4D8DR6:Q@*$Q(8G.(T"Z/#_C@X.!5_<I]NWG6
M@7Z'"_%$V/J65DR[/%!/SB!?/P%19P^X,R[<9!7`/.?$A-T)2F\!3=`,L;03
M<YX53-JFU^_=6WW-!_[-SB.*9;8CCUN)BE$;LDHK4:XR(KV<C_:9>43SF\!M
M:D4ZJ;:XFH\BI1$M_7*P%`;D\`1@#VK`:97"Z73*]_?W7_:!\^UN*KE+@?K&
MYI_7OMW>M;G<8&FM2&(5@F>:PJ=<"@M+[CWWZH-=M7WQ(+Y;@5JA")X'ZWOC
MCH5]INUS,)@L6*W62@)_W@?>ZUBBQ'+E3SJ=GG[H?_F#UT219SUB,.X1DWN]
M7OG.SLZ+AW?M3O<4-:"$S6:SD[,3'0Y/-L\X@0&9[&OR<"[_::^0GK]%,D;]
M;L^\\OW#A_0=KS?FC[$DV76RY^ED(H[V.?GN[.;FYJ%_V>]_>Q;[!0\!/:T4
M[0NE`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M8FQO8VLO=V5A=&AE<F1O=&-O;2\R,W@R,R\T,"YP;F<`````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(S-3$@,3`U,34T,S0Q-#<@,#(V,C<V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````7````
M%P@&````X"K4H`````=T24U%!]0!#`X&!1YC')(````&8DM'1`#_`/\`_Z"]
MIY,````)<$A9<P``"Q(```L2`=+=?OP```1V241!5$C'[91;3-IW%,=]7/;4
M+'M:MJ0/>URR+%O:+&MVL75MTZBS,=;82[051[56NU:GM>*\(:#R1U$$5`3Q
M@H`@"%[X"P(B%`'%6K5BZV4V6^IM=?$6C'[WKP^F36O2-'M:=I+?R^_W.Y]S
M?M]SSB\DY'][5_.-CIUB%+'IN05,^I.9V81_!;JRLLJUV!U:ODCR5*Y0HU6E
M06.K.MC0U*9=6UL+?2?HQN;FD<FI:5EY5>V>N+$-AEXSG&XO[GN&T6L9`(L0
MHIA-!/L'G.-^_^CW5*`C;PUW>WRRZKI&B&0*M.N[H::6I$4#94<7NLE^D!8[
M2@@!PB\D((M1"(&X0?96X!=9\(7UVU*%%J1U$![?"!PN-U04V&QU8,@W#)Y0
MBK3L8MQC\I!P(PN1L5?W^LQ603`8?/^-T.65E2BY0A5/`7R\F@:T:(PPDG8T
M*O7@B>0HJ:B%K$V'RMHFT-+N@L438L#E09_-"6FK%C5B"13M.FEQ:64\)>NQ
M5^!-"O5D55T3!'5RZOG=J*<<#"8;FE5Z9!5PD70K!YPJ"3+SRU`K;8'_P4-,
M!0*P.X?0T6W9OU=-^6;FL2`0BH@#L,EL97(J1+O\NF9H#29T]EK1I#901?1!
MKM3A%P8+^:55<`X-8^3!V#[8ZKB/+M**?$XER@42>(?]:&AIQ^7K&2@IYV\O
M+2V=W(?_RB@B"*$,-0T*#'G]5`%[\")0$5=(:5N$9K4>P_XQC$\^PL.)2:CT
MO2BD.B8A]2XB8FFXD\<!FU\/6GH.XI,S4,#BXO'T])E]>.#Q##./R=TM+.-#
M+%>A@,HR*3T;YZ\D(RHN$3RQ;#^`6-J*9HT!O[$K$9-P`Z'A<3CUTR5<_/DV
MXF]FXTI2&N+BZ>!5\C$[,W/F0)IGRZO"@K8.G+A&QX_G(A!^-1F?'?L&9Z/C
M$,GFXWCH:5R@I2+LSCV<^"$,D3$7\>7I"'S]71C.7[N)LX4<7$I,0BZ#@4&7
M>XHJZN<'\/KAJ:/%5@_.T>B0*C4HJV]$4W,K^,8^1(OEX'!YT/<[D$Y4H[9.
M`H%*A[(:(:JJQ$A5&)`BK(-&VR$UFRWQBXM+KW;+[W_][6PGS6AM4Z+(.H0D
M+A^34P&0_G%DL`F03C=*30.PN#TP><=`;^]!>U?O$X=[1,*0-D.MTSW?W-R,
M?JW'%U?73C*]$XL9!!].GQ\T=1?2<ABP>$;![K'!8K-#1`6,$3:@Q]*/2M*!
MJ!("UD$WE)XQ-/:8=RB-+[]Q@-2/YHD4LPN)UU,P/3L?%"M4T'<:P1\<02R+
MAZX>$KG==M`*F=!J.S(--@<J*&FZ!SR@:TS@M:FW#AUYW=0\D5%&0"@2S5)Z
M':?&6/GTCV=:5J_U^>VL7,S.S7N<+G?0:#1.!@*!+[:VMK3KZ^M:->G83J3D
ML[M<A\,W-C:)\8F)Y<Y.P[<O[WN]WA&;S>:DGOSI^L9&`O7O?/7R^>S<W)\F
MDL3"P@+G4/CN[MX'.SL['[]6B\6ECZCUX6%^R\O+G\S-S1^E[KP7\I^R?P#<
M:#&%9C&U^0````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+S0Q+G!N9P`````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q-"`Q,#4Q-30S-#$T-R`P,C8R
M-S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,
M#@8:DVL19P````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^
M_```!%E)1$%42,?=E<M/8W44QV?A0J,+38R+V4C,N"/&U;"=C8:%"Q<NC(D9
MEOX#8V9ET`TCSH",$T">!2E]3I_T01^4ODM;6DKINZ4MO>WM^T$+!H;QZ[E=
M,#%,%(V)B4U^Z;V_<^_GG-_W/.Z-&__+7Z_7NYE.9P98MCP;"`1B-ILM5B@P
M?I/)-'!^?O[&/P9WCH^'C@I,(9[,H%9OX.3D!)5:`S:G%S*9"J%0B-=H-C_[
MV^!NMSO(%(O)3*Z`<K6.8KF!`EM'+,T@E6,AE9O!6Y5!+)&V69:5D^/!:\.S
MN7R'K3;0/3D%6VW#[4]!K?=BQQ^C^R8T1A\>38DP/:_`@_&?Z22*;K%8_&L'
MS5;GRX-([!D7*4,1AQ-%.+PI;-E#8&@OFBA@36B&WAS`;BB##;T'/SV9@UZ_
M*3\[._N4UEM7H(U&0QX(!(.)1+*=+Y3@"Z7@V4W`9-V'4&;M+Y,U!*%T&YLF
M'ZJU%HY[/>28&B+Q++0Z0]M@W*H+!(((L>Y=@H^.CF[[`P>E<"S?U]3A/8#1
MZL=AODS744Q-2Z#0N!!),@A'#M$Y[J+;.T6>J6(GD`!;::#6Z,#B"./!]Q.8
MF9F9O(13YB?WHQDH=6YD<B7$,PP"!X>()!C:\T"E<R%U6.SGH$=5DZ8`7+XH
MGJKL6.;KL1_-PN&)X!>!">/CCS$Z.OH"OK>W-YG)'1$LAQ)%X?;%L;&Y@Q6^
M`>MB,U5,$\?='JCN428YM$8O)5.)AY,"+/"T$"MMX*WIH=BP$WP"L[.S+^!4
M2L/1:+1F=[JAUIH@4^HQM[".AQ-S^/'Q$K1Z,\P6&WP^/RQ6%_A")2:FEO'#
MHT7,SJ]#)%%#KM1A72#!TM)2+1Z/#_^Q:3J=C[/9[&DP&(16J^VO:"SV6RJ5
M.K':;%PU8'5U%1L:#187%R&7*^"D8.QV!SP>#]GU_7V[W3[\LL9YG>19X.#T
M`%0J%79W=UF*8F1[VPJU6MUWN+*R`JE4BG`X[$FGTWH.GLOEL+6U!8O%PCFZ
M>P5.L@Q8K=9+@$0B`<V2>^3@EMEL]G`V#JI0*+"\O(P=KW>$YLNJW^^'4"B"
M2"2B`#9`][$K\'*Y?+/$L@6OUXN%A<6N7"ZO*)7*#SE;,IE\4Z?3!3A9*+I,
M(IG@DOM-HU'_RN%P5!*)1(@[&4GS-07Y]DN[$\!0)!))T@,62O(80:=(IOLT
MP.Y7*M7W6ZW6&$$_H%8'M^KU&FAJ6EKMSGOTWABMH3]M_XN+B\'GSR]&6+:4
METJ?0BP6PV0R([BW]PXY?X7L\YS&7!*YO'`ZGYV=?W3MP<4PS!W2&VMK:W"Y
M7'VM?3Z?F^"?4R*;!H.A'SF?OPZ2!23IK]>&-YO-.]2U_<@HF03A<Q7AYFP:
MC>8+A\,)^@>/Q^O;:7Q<'TY'?[50*'PK%`IC-(AB3J<S1@YO<3:JD"<<>--@
M*%$"GY'CZ7:[_>Z_\NFCNG\M?'`PZ?7Y;AN-QN]D,MDG_\DW^'>LX.MGIJPO
MSP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V)L;V-K+W=E871H97)D;W1C;VTO,C-X,C,O-#(N<&YG````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,S$R(#$P-3$U-#,T,30W(#`R-C(W-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````%P``
M`!<(!@```.`JU*`````'=$E-10?4`0P.!B_%V-5$````!F)+1T0`_P#_`/^@
MO:>3````"7!(67,```L2```+$@'2W7[\```$5TE$051(Q]V5R6\;=13'>^``
M@@-(B$,O1*C<(L2IN?8"RH$#!PX("9$C_T!13RAPB1K:F)0J25N;.B&.G=C8
M\1+O2[P[MN,%[UOL>&R/G7@<.[:#DJ9\>>-#*Y0*`D)"8J2?-+]Y,Y_W?M^W
MS)4K_\MK,!A<+19+8RS;7(I$(AFGRY5AF%K8:K6.G9V=O?:/P;WCXXEJM<9D
M<B4<MML8#H=H'G!P>H)0*C6(Q^-BKM/YY&^#^_W^>*U>SY?*#%@",BR'>K.-
M?*F&0IF%0F7'XQ45-N2*;H-E58/A</S2\')EO\>VVA@,A@0_@B]<@-88Q$XX
M0_L.MBPAW)W?P,(#!6[/+M))-OOU>OVO'1P='7V>3&6>,(TV1<LAD:O#$RS`
M[HZAQK:1SC%8E=E@LD6P&R]ARQC`#_<?PF@TJ4Y/3S^F]<8%*,=U5)%(-)K+
MY;L5AD4H7H!_-PNK,P:9TDEKF^[CD"FV8;*&<7!XA./^$.5:&\EL!7J#N6NV
MV-M2J33%<=S-9^!JM7H]'$DT$ID*:=J@2),P.\,H[;-TG\;\@@*;6SZD\PP2
MZ3(HV>B39/NU%@*1'!HDW0'7@\.3P,SM.2PN+@J>P2GS@D1Z#YL&'XJ5!K(E
M!I'D'E(D@=H0@(:>Y_?JZ`]/"'I"[[#PAM)0J%UX+#'B%W+H]B?QD]2*V=E[
MF)Z>?@Z/QF*"O4J58!4T6AWX0UGH3#L0KYDAD=NH!#LD09_``[3:71A(E@6A
M!G>^ET*XK(=<[2$G)FSJW`2?P]+2TG,XE=)D*IT^='O]T.HM4*H->"A<PQW!
M(PCNB:`WV6"SNQ`*A^%P^2"1:3`W+\9W=T5X\&@-ZW+MZ!NI5`Z1Z,?#;#8[
M^<>FZ?4^+)?+)]%H%'J]?K3HI=\*Q<*0.I.O!JRLK&!K:XL'0*7:A)>"<;L]
M"`0"9#?2<Q%<+M?DBQKGU5@L)N3A;K<;&HT&N[N[+#F8VM[>AE:K'3E<7EZ&
M0J%`(I$(%(M%(P^O5"JPV^UP.!R\HR\NP-/I])C3Z1Q%Q@/D<CD?Q4UR<,UF
MLP5X&P]5J]40B\78"0:G:+ZLA$DJF6P=Z^OK%(`.M,]<@#>;S:O4RDPP&(10
M*.JK5*H6@=[G;?E\_G6#P1#A9:%3E&A/W3OXFN/:7WH\GE8NEXOS)R-IOJ(@
MWWQA=P*82*52>7K!08-JAB#S)-.M*L/<:K5:[U+WSA#T/6IU\*O=/@1-34>W
MUWN'OINA-?&G[7]^?C[^].GY%,LV]A6*G[&QL0$:L:!\O$7.7R+[(UYC/HE\
M7GB=3\_./KCTX*K5:C=(;ZRNKL+G\XVT#H5"?H)_2HGLF,UFT-2$1+(VJA:2
M]-=+PSN=S@WJVE%DE,P1A*+U\S:JF,\\'N\H\7QB>3N-C\O#Z>@O,PSSC4PF
MR]`@RGB]W@PYO,;;J$+NZW0Z&$VF!B7PB40B6>AVNV__*[\^JOM7$LFD(!@*
M7;=8+-\JE<J/_I-_\.\1`.M1RR!1C0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO=V5A=&AE<F1O=&-O;2\R
M,W@R,R\T,RYP;F<`````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(S,30@,3`U,34T,S0Q-#<@,#(V
M,S`P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````7````%P@&````X"K4H`````=T24U%!]0!
M#`X'!0=X+=,````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q(```L2`=+=
M?OP```19241!5$C'W57+3V-U%)Y_@(4+7;B:A0OCQLQ"^0-<."M7)JZ,\;'`
MQ,SH*#J2`8-`"V&8BXQ"`2D,E#XH[6WINZ5T@#YX%*&\+L,S4%J>27EV8'A\
MGO.+D7G$2*)QX4UNVIQ[[W?.^;[OG-^5*__+*YO-OKJTM'1U=755DT@DE(F)
M"263V8F'([&7_Q'PWMY>;C*92L[,S&-A<1';V]O8W-S$H]EY!'NBPR,C8WF'
MAX?O7PH,P"MTRV=G9W)O;Z_<U=4U:[%8X?8$$.CN@=<7I-^'D.U.Z/0RJN\W
MH:FI><=H-,IC8V.RR^62@\&@/#0T))^<G'SZ/`57-S8V$`Z'T=+2@K*R,K2W
MZU&F4J&BH@*UM76X>[<*G/#'DA*H5&H8C29ZIYW^J]#6ID-U=34J*RN1R62D
M%\!75E9@,!CH(R.!U<+E<N/>/4E\K-/IT-#0@%`H)&)55570Z_54?1,D21+Q
MTM)2F$RFS:.CHW>>`2=.78%`0``3)3";S7"[W:BIN4\5_836UE9HM5IT=W>C
MHZ.#0+6BD.;F9JC5:I#8HENWQS<W-36=\R=P.IU^>W!H.&VU.6&SV1")1"#+
M,@8'!Z$NKX#19$)C8Z.HU._WDZ`]?U2M11,E+"TM@\?C@:9!"X<GBJ'XR`4M
M4U-34ORW!'ZI?P"K;$-?7Y^HLK^_'[>_OP.GTXGZ^GI1,7=GL5A$5R0\5.H*
M:#3TS&S%SW4&V!PQF,R6"_"9F1GIT>PL^L,#T+4;</.K;_'%C7Q\\MD-?%=0
MCCN%Q2@N+D%A41$*"XMPZYL"?$S//OSH<^3?5J.@L!RW\G^`SN@CC`0<#L<%
M.`EPG:K?BD2BQ)D?MJX`]$8'M4F</K!0-T[X`R'1R<#``.S.;C1J.U%9]2L]
MEV$PV1$,11!Z&":WQ;9H'JX_[?$OCX^/LUM;6X("\BMQ:D`B,8Y%&B#R,,R=
MG8+G3OKU>KU4A!>1:`P^?X!$;0'Y6\2I2.7Y`9+.S\]!$\<M";Y93+O=#D51
MA)CL$G911X=9%#`\/(Q4*B5\;K5:0:80G2TL+*3(Y]>>`:?)Q-S<G!@,]C.[
M@@=J9V<'T]/3PJ)\,Q@+.S\_+XKI(>>PP!QCEXV/CV-W=U=Z&CR'P-]\_/AQ
MDL'JZNJXRG0T&LURTM/34^YD@>U),4Q.3H(II/TC_,U%\5QPE\ED\BV*Y[RP
M7XB:7`)3DQ7;::@\M!'37'TL%L/Z^KJ6DY`VHB.V*VO#])`A3NA]-254'QP<
MO/17R^L]ND.49)1!N%5>`TP3NX06DA#8Z_6)Z61Q.1%1]/5E-F,>"\M4D#`"
ME(>&>6YM;</&QB;1$A/B^GP^+"\O"P/05GQ"5^[?@;]!X'D$_N0PFQ7NT&@T
MM%]J!#74/D@7$6?;L6OB\3CSS.#O7J;Z(DHP30D46L$*<:J,CH[2"911.$8)
M%*(H15/-^V2%3BBFZH-_[?@CT:[M[^]+).#K:VMK$OG]M?_\#/X=%^-$NJM;
MMP<`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S+S0T+G!N9P``````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C<U,"`Q,#4Q-30S-#$T-R`P,C8S,#4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!<`
M```7"`8```#@*M2@````!W1)344'U`$,#@<7],%<FP````9B2T=$`/\`_P#_
MH+VGDP````EP2%ES```+$@``"Q(!TMU^_```!75)1$%42,>M56M,DV<8K:)!
M40S+_&%T,Q`3-]V/J=.-Z?RU+&0Q(=.QN2W+7,R2L;`M1C.3J5-'IFP!1"X"
M0KEU*U#`EEZP2+GUPJV4%FA+Z07:4EKX^O5"02Z]GGTT&<D&2USFFYSD^_&^
M)R?G.=]Y:+1G/'->:X;-9L&TS99,>]YGSBGT"GAE8+'J_C\YL'+9[9[5D4ZB
M`&$BT3>1X6,^^`0&O5J#\'1BP.\K(`A"Y_?[+__U)A()OTAAWSJR4&CI_+AN
M,-UB,:=[O=Z82,B1I5,60]1:C<"B#(NJ(ZC-?@6#LAQ$_%VPZBL@X+$0#`:R
MPD$BQN.VI!-.4AP,!G/7D0=6')^:QW\'E_T05JN9AY#-,*?Y&'6Y;\(@3<.\
M,!ZUMQ/`JSB)X$0*!/1CZ!3>`<(.P[*WE2?I*$%?_P!L]MG$=>2+GM9-R_;,
M;UV#I\$J>A\*X3<P=YS`@TL)N/GY;F1^^0(NG4O`M:^/091_&'>_VP=U>PJ>
MZL]BE/\:\N_=)A6*P7..&6+3O_B\G!XD*N$3Q.+AY=THO+(?HEMQ&,N)@2)_
M+WKH*5!*6)#WBL"LSH*(?A3&VNW(NW$"ZM%N`Q!\:P/2X`\D,:8R&_MM"TX&
M3"V'47,E'I.%6S'/W`QYV>M0#CR!4:_!+.$$Y2TFS%.H8]8@Z\=4-%>E8'FN
M`0OS=MO"P@+GG^2?N>U-C0;IAY"6)Z'Z^LN8>;@%_L;-4%0?QTAO(UPN$O89
M)P:')]`[,$:1V]`_I$=A23.*[F>CKO(BZAFWH%&/Z-:G946;&)BKAT/V#H0_
M[T*$18.K+A82]D^8F24HM2X8)NV0R<>A&C5AAG"AM4,)-E^&MBX5RLH9:&RH
MA(LD?%0<OXB2NHF!9)7L^V13SU=GO::[4').0I.[$]*\@V@I_P":$3FT>BO4
MXQ;TR/7@/AZ`I$^##LDH]=V'28L=I,L%LW4:/!X?@I862&5]]5JM-IGFGFF'
M6G81QM9#</&WH_[&#@A^.X(^"1_#(\-04BJEE`V35@>>="I12A=@4&6`0J6/
M$GL\GM7X06>8@I-TPV2>!H/9#+E<#IK;SDD>Z_DHV6,3:!R:ZV@K.XXG#7<A
M[AV%2CT1O:S6F3%&J6]I4Z!+-D(-E:1FX(J2#@T;P1/V@\/OP9C!B@[Q"$K+
MF6AO;\.:Y\$5PX7EF7P8A<?1Q<V"T3`.J\V!T3%+5'$U4X2VSJ&HNE4;5M&K
MT(->+41!,1L-'"G8@CYJ!KVHKF&@N[L#:VEQV3ESRM8TB)FGT%V9#!/W`J3L
M6Q#6W@2C-!-%.3?`*+Z*#FX>1$V_H$]$1UU-'DJ*<E%27`IZ21:*BO+0T,0%
MF\/%T)`R9RWG"SY"Y?-:;,M>!LS<)(@R$S!;N0/S];$@67%P1K$-\YSM\#"W
MP5>U$\/Y5!WD'H3DT1D8-0RHE&*;7F_D"X6/]VBUFMB_Q3$2)M)#]JNP-.X"
MG<KZ4-D!.*L2X*G<BE`M#?X_:)BKBH&S,AYVQCYXFW=`6AP/>NX9/%VP;/R'
M1M5'YO<'/&R]57P:Y;GG,2RYBCG%V^C,WX/V@@,P5B1!G)<(36D2IEF[P<T^
M`'+P/7CZ#Z'Q_A&TM`C(I:6EU`W)PR&?SJ2I0#.;#I(DHJTXKTT#\]X;T(K3
M$)#LA8C*/R/[*%:TIU!QYU6,#5<AN*(SN,WYY*/:/,ADTA*JKN,V['.]7IT^
M,^M*IQ9`M,_'E85K?1Z:2$53WDO@/[J&R!(?`UV_HEW$M:U:$0X'4B=-RA*2
M=&)Q<3'QF38104RO;:(`6>QK*GL7_7V=/H0F$SVNZ0*]<7*MI"A!<102*6SY
MSVO/OS#@%7(R830:O,]]0:\LDQE34R;8[8Z,9WWS)Z]V?1:A_-;1`````$E%
M3D2N0F""````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L;V-K+W=E871H97)D;W1C;VTO
M,C-X,C,O-#4N<&YG`````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#(T(#$P-3$U-#,T,30W(#`R
M-C,P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````%P```!<(!@```.`JU*`````'=$E-10?4
M`0P.!RJLJ1"*````!F)+1T0`_P#_`/^@O:>3````"7!(67,```L2```+$@'2
MW7[\```%H4E$051(B9656TR:9QS&>[';)ENRNUVL%[O:LF2[V9+=[&XQ6[:U
MW5)K#S:=UJ[:M=IJK;8J'BC60U$\@`HB*@HH?("`R$$!141$/%0HGK&Z5JM2
M3]4J\NR%I6FL:YM]R9,WW_?E_3W_[_\^[_L=.?*>*[C_XA.BB+?HN_?-?Q<X
MA:@C&%C![M84-M<\86UO>+'_<A[!O:4E\IY)5/A_H-\$]S<]@=V5G8U5)Q;_
MMN&QKQMSLY:P'OMZL/"X%ZN+O=A9'\/^WDJ0S*DE.OI^>&"M8._%%):>],`W
MVQV6UV/`([<!8Z-:C'M,F)HTD7L]W"-M6%ZP(ACP@\"%[S0@+]."+V?W_4M]
M!&H)0T+PZ2DS@>E@UO/AM+>BOU>,8:<"+H<,HX,4_(O]KPQJWP:.#0;6]S?]
MPYB9-F-RO(N,EC`\--JM$A@T->BU-$%82T>GE@?/0]V_)OT2;/F'B,&&CW`^
M>Q/\$9$VL#V-I_-=X19,>#LQ00PFO`98S4TP&^M)>_3A>Z.6"T,[%Z-#ZC#<
M8JS#S+@.^[M/0M4SWX0?"P96\7)C&+X9<[@BAYU"ITX`H;`:<J4"4DH*OH`'
MG89'OD),JI5B:(""O4<$O;H*O5VUV-N:>`M\;QG/G]DQ/=F%+D,3RMF5X`J:
MH&S7HZ_?230`5;L!C"(6"HMRH:"X<)#>A]1M%$`A>8"-U1&$XTOVQR'XXGPW
M;%8I2E@EJ.(WHD6N@;!5`;Y0`I%,!4.7!0J5%M=2[^)45!0R,I)AU-7#9A%"
M0Y5A8R74]Y600<0A^,RX$9P*!D02*;K,5O0/.&'NL4%"P*&QRV)%&HV.Q+0<
MT`L?X$)</-*S:'#86DEK.&111PE\_2!\_?GRL95GD^@E"\?A\M$J5Z.-M*"A
M28(R#A>,XC(T-DN06UB"A.0[$,O:8'<XH=(:4,+F@<7*1X.@'&O+KE>1?`V?
MF)BB*CAL5-540=:F1;V8"L.%8BG2:0S$WTQ#:04'MS+SR',]QMP>/'SHAE*C
M@URE`[=>A*Q[Q5#*:A'8VQ01^(=A\,+\W-?<^J:%JCHAI$H-U%HC1%(ENJU]
MX<I#P(KJ.KB&AL-0NV,0^DX3!(U-R,R[#S4Q4ZH[</-N'DZ=.8>!0=?KM*PL
M+S/+*SG$O1E6FQU2N0I%S#)D,YBX3;M'S,@V]WC@=C^"<]"%*EX]4N[2<.:/
M2S@;FP!Z`3/\95>3TQ`=>QDVN^,U?'UM_6A9975'`;,<G-H&Y!>S$)>0A!-G
M+N!T]$6PJ_FH(VD)Q;)!),75I!0<CSJ/B!._(_+")<1?2T)4S!7$7$U&[)6$
MG>&1T90#.??.S-VBE=4@-OX:+MW)P4_'3^)*%@,__'(2L;=I^/&W2$03P-F+
ME_$S,3T5EX!?R1@5GXC(\]&(2:<A-9.&1K$L^]"YXAAQ>U+9=6AN:87&U`T.
MOP%%"CWBXN-`%]0A\MQI<#D,I*6G(J.D`I$)UR%LKB0J![N6AQL5/"C4VEW_
MZNJG!\"D+5^:+-;Y8A8'?*D*#\HJH'>.XD9F+B0*"<FV%`:C'"55%7`-R%'-
MYR$]XP[*&R6@%$K(^ES(8A1"U6'\\U#58^Y'3)'13#)K1*E23U8]!U*%.IR6
M&GD[Z&PN&I7MN%Y8#G%+"U0J"A35@FP"#\6SE03`,>`<(JG[_`!X9WOM>Y-W
M>NVO+#K)-.7/+F9ML`0B)!640B"6(;NV&0R2''YS"W(*2U&FZD0FO0!M9/-D
MY!>#+54C,3L_E'GJ4-7CXQ,1E,F*]#P&9F=];.(>PY=0@<2\@E!%%-6F@=,U
MB,U-?R79^K;[@A:4<ZJP_>)Y!TE%8Z6(0E)F;B`T[[_@'T].>JFI:>]3TOLO
M0L]T1M--IVL(4S.^;\D>B-C:](?^]!\L+3VAF7NL&!X>,H5./=_<_%?]`X.P
M]=FW#X')]0]P41`MQI).?`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+S0V+G!N9P`````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<V,B`Q,#4Q-30S-#$T-R`P,C8S,3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!<````7"`8```#@*M2@````!W1)344'U`$,#@<Z
ML1X`[@````9B2T=$`/\`_P#_H+VGDP````EP2%ES```+$@``"Q(!TMU^_```
M!7])1$%42,>-55M,FF<8;K*+)4N6)4MVLYON>C?+=K7L:DFSK!?+LETN67JW
MS&Q+UF:+3;.V-NE:7;5%K58\@Y:3U`):1104D/./G`7D+(*BR$$!L2@\>\&N
M2;N>ON3]3]_W/=_S/N_A/W7J%0.HOHW:X5G4'JM1+0#'NZ@=I1KWAM6_58LB
MH'*6'CX]]::#%G]#&P=0S1-V#$<E-XHY!L6LX>1.=GS@H;DP'9@&D0C1GB_>
M!/@T:I5[M<H&2OD5;&_JD8CKL;&^_-02<1TR*0WV=XVH%.VT/$$''&R12Y^]
M&KQ6*1^58]C+,(BOZQL6\"]BS:=JF,^C0#BH;MBJ:PZ1P!Q*63-MBS\YX"4>
MT,0E8EPM9HT-AJ&`&K[5>2S,2V#0BF#6BZ%5\;!BD<"Y,@4[(VV8QS;YY(!-
M$`;K1<`?4I"6BSD7HF$-5JP*+"])8+<Q."CE$0Q&,2630C;)Q@-A/QX(>F&S
M2.%VS,!NE<'GDN+H8*T>Y&.Z?/4\>!..L]A.+,)BF(39;$8H'$<FNX>]_0)V
MTADDDBG(I#)P1WHP,GB7O!'"2S)9#&(L*D:1V]91@+=)GO+99\&KA:;C<A`K
MYFDPC`7YO1-0KR^&9;T#2QHS8NM)F,P.='?UH(O5@4%V-]0J(7EX'S.2/D1\
MTY1!T7J:_O`<^%Y3/LU@63U'H"5D<WN(1#=AL?JA6K1@?2-%[+.0RI0033R"
M5F>'2"3%8/\@=&H^YJ8'H5%R43T,$_,*G@+G\OL?Y')99L4\@VAT@]BNDP5A
M,'FPI+9B5JZ&S1[`XI(!0M$T5KV1AER)9!IVAP<C`QW@CW5#+J/2*/OK67,"
M_KA2.>UT>CQNSQK\_B`\WC"4*@8N=P!&DPU<KI"83I,<;JA4RPB$*/\/RLB0
M9^[5$#:W=NB@')Q.-T;Z6E$I45!KCT_`(]$(R^GRDYLV8A0@QB$8C`YBM0.]
MT0D>[R%6;"Z*08'D*C8"&PC%H=-;P>=+X0_$&H%?4!K`OMN&W92S7K'C#7"C
MT<#:2NW`YO`CM;U+BS>(I9=T-A)C.;VOHU`L-=CN%XJP,"Z(Q;,8'!C&Z"AI
MK=""+Y!1+%3@#/=B9YMDH7[3`-\OE,[9[*M[)`U,)@OFY$IP1L=QIYV%WKM]
MT.DL\'A68;/9&G&8G)Q&/WL(W9V=&!WAT_LL!#PA)`^G(1COP_Y^LI[LGSP-
M:#R^^;U.I^=8&09]]^[AKS]_P>\__X@_?CV'EDL7P&IO1=>==K3=N$G/-W#]
MRGE<OG@>MV^UDMT$N_LZ[G,ZD4P$7URA2VISDU:KQ\/)!Q!P66B]=AXMS3_A
M2O//:/O[*JY>_`U#@\/H[""@X3;*$!8$E"&:I062B8I.+\?A84%!X.\^`VQS
M>-_3&1B)0J&D`F(PQAG!E(2#H9[+Z/RG&;?;6HCU-;![VL$=9<-!Y:ZA'B,6
MCL/G\V)2/($)(1^Q6+SY?ZP)_/2"4E?F<KA5D5`(@4""=#I9R^ZL5O1J$=B]
M+'1UD"2W6M!/$A@T0GB<<HAX;(R/<4CWJ7I<*KE\WO'2=CLK5TJFIN;2<KE"
MDLUF8X>'AUVUVC'#F&8T>NT<-I-.[*0"."@DD<EL4CN(![92Z2F#T8KT;J;I
ME;V<//C:Z_5^&XMO?:?1FG?K%;D6B"Q4CBH?U1M;J52\,"M748>,P&JU0Z^W
MM%)UOT7YWW10+G_\VC]1(KGUN<EDS8]Q^1@9&FZD7J%8E-;GHK$-J=7JP/S\
M(@1\'N6\=4"G6W[GM:#_#8?3_:5"09MY8UA8T%+YBQ".Q(WU.:52;93)9A")
M1#`\-`#QA!C^-7_G&X.3).\;3':16,@!ES.&1X_D"(;"9^IS+I?KC%P^3ZQ%
MX/,F$`H%42CLEU^$\R\$GT'$[ZC55@````!)14Y$KD)@@@``````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V)L
M;V-K+W=E871H97)D;W1C;VTO,C-X,C,O,"YP;F<`````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,C8Q(#$P-3$U-#,T,30W(#`R-C(Q,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````%P```!<(
M!@```.`JU*`````'=$E-10?4`0P--P7:>*5Y````!F)+1T0`_P#_`/^@O:>3
M````"7!(67,```L2```+$@'2W7[\```$/DE$051(Q]65RV\;513&/\^,[7'L
MQ$[<L1/;";$3[$*(FB!*!44(2Q4LBEHDI$H1H@M8HBYHX1]@AX34%66!$*P0
MH"(DI)9*C9#5+A)::)RF2HAK._'['8_M\6LF=C@>Q*(D;I#8P%A7,[XS]W?/
M_<YWSP7^KY?F<2]75E<=0X.6TRU%N5C(YZ'7Z=!6%&@T&N@X%AJ6PP"O@\UF
MAY9CEW+Y_$?684O2;K?O/A:>R^5.;(0B5SM[<`V9+3`8>`)PZH!.MPN69=%L
MM="6960S653%'3PQ[L!1K_<]01"N]!A</_B]E94WC&:K:X#GP;$,=%I.!7+4
M:E(=Y;*(.[\LH='H/5>PJW31:;<PY79?H.']X9%(Y.6U![]_T*U68;&8209&
M!:H#2`ZQ7$8FG<'#S1">/NJ#:U3H,BQWRS/MA6'`$/^+<R#\BR^_8@3[&.=P
MNI!+I^%T.2$1G.?UX/5ZM%IM5"HUZA_#PL*Y@,%@N$;MD[]SF(/@9\^<_;2W
M;);30NX"R4P>V6P!F4P.X4B4I&@AEDB@V6RBT^DL'P3N"]_:WO8DDAF(E8JJ
M;71K&V:S"3(Y)9G,XNYO05426=Y5\]#OVB<+17-IX?P[6L'N0)N67Y<:Y`@%
MFZ$(&(91^T2QJAJM6-CI1=X7OB_R[[[]X:7A$3MKMX]"JC>0+Y:0SQ?1H&<-
M_9*I#,H[)8#5H4CW:]=_<DI2;>@?P9?NWH-5$%`HE!!Z&`5#&V9BP@DM69%A
M-#"9C.IW%@OQ.#U6UQZ\'0C<>O90^.+BHBZZ%=:&-M;59.UU._#YGH2BR-B.
M)1&+QU4K"C8!>CV/8<LP$ND"@JOKEVFLL2^<8$995J[P>NYTSVI2K4JMAHV-
M302#]\F2<7()N8,F5"@'+*N!S6XC7P_@QLV;<\E,-D#Z3Q^84([C!$K2NV6Q
M@ER6Z@CM3*-Q$%5R3"85I_]ZVDBUWG=H-5M_NH0D8[1:-=$4P'-/^;RG"!7>
M5[AH5C862UQ:7`Q\'-@I0Q./PFD908/T-Y5+Y/<$!&$9&T$)];'S<-*:1\Q6
M%'4<S&(I['-/2GZ_O^IP.,[1Q+E'(J>.CB0UJL?FY\%FTY@^^0+25*"<`SRD
M_!:L(Y_#9<OALYP=@QXW_'/SB-?KT+8;RU-.QUO/S,Q$^VK>:LFCT:WD^[=+
M9;B.6%$G^P:K$AJ5$D7X#:1*'??N#V-JLHT1S1XR8@,K]+XI28&#P(_`[_P:
MY-<2*6^J5(1`^HI42OE\"K7BUQ@TW,"/UY^'PIS":M@!*[DDUZI#4-H5_\D7
MUP_=H4-&'J-:%OXA'I.3$Q?$RMKK-?GV:YZ9[_'S\@2.GW@3'7X,<\?+S9G9
MF8L1JC-ZQEBD@^'JH?#Q<5?25*VY-;1D199C]7I5=VQ6>B65\NN/6,^D/9[9
M5V4-5S<YW5V?UQO_UV>@*)8_C(1#EXO%XOQ_[H#^`\IQ]@#>BF8\`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O8FQO8VLO;6]O;B]F=6QL;6]O;BYP;F<`
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,V-S$@,3`U,34T,S0Q-#8@,#(U,C,U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````P````,`@#````8-P)M0```P!03%1%`/\`,3$Q
M.3DY0D)"2DI*4E)26EI:8V-C:VMK<W-S>WM[A(2$C(R,E)24G)R<I:6EK:VM
MM;6UO;V]QL;&SL[.UM;6WM[>Y^?G[^_O]_?W________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________`/\`WT_9
MW````0!T4DY3________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________`%/W!R4`
M```!8DM'1/^E!_+%````"7!(67,```!(````2`!&R6L^```#1DE$051(Q\66
MS7+<1A"#`?1P5U*J7.4XLOW^3Q=+R25_-CG30`Y>V;*E.,DA%1YXX/`K<+K9
MP##X=Y?P7P/C^<=O8T(_/K/"IWNX76T`"3C.=W\'O-G["$",&(NGZ_'CMX"W
M^V%C$VB[MDY.Y)?(%\"K]QQ<IGD%+PY@C4!U_Q?`B_U&DWL+UFD$U%K%WLK;
MN^>J]&+=X#?8"I/IVKJ%2:^;ZN<47ARG[?@0``)92^=];H&_:VW`_9/&O3A8
M\[C@B=7+F6U,G9+\\#7P_0'U,@D(Z61P;Y+,'SN8>7S_Y2>]_@5@FC!#`(-1
M)D#&O!EQC%\?*QQ`(26+DL8H+E3B$(3GSM/8;Q]5Z?8#13$0&<01KK5"(6&Z
MIF^NUN^/%#Z`NJR"1+`O.354-<1UI'N=Y^UG!0/5"%A)(&0,SZZ*QMZ`X?=]
M_FY]4GAE8#H4$`:EH;3M$+T,`DSOTB>%PPQ`&BI4E%[)&,NG$9!0"/8Z/RB\
MF4$22*"P#8#`.&U;:=000M+1?/_RHA#STF";*BX$NB)&!EV=]!CD9!\/`#[>
MAMRI/0L,%E5B!6IZNYI'^+D/1`B0H@@[*;*A`NRZ1G^(J5KT!:"L$%Y!@B+:
M/',2<HBK7H!5$SE=`)7-P`BAK`@8JDI,1AT/!V/XDT)J`DP<,(XH:[38$&SF
M;!^X'G$N97U'7:8`(0FR]XDTXW8%IT'WHC0>.IVB@X#00&>QUE20=)A&AN.L
M_K0'4'("(EXVH&H>Q8];0E-%=,"[!^`TX8#4M+$E1AJ#))ID+W([+7W\EP0`
M=QS;&&.<-B6#<"-;T6E#'520JMH^ST.M,2(%**7A`$'D;(2I104:=X]F^F5L
MZ9@^U12Z&G4E)L)1A!'X]//CF=XH((<S5XQ,@U*)7A(!!Y?2/SC?W6L#!NB,
MA:VKM@T&03H`T$-?.=^K)<QIGK/&F:LVH@.CD9#!Z?XK;U5ZNZXE[8G'*``R
M:`$-8+M_XJT_[!ANE"FR4"&=-!R"]=,S=G\[EYJ#L51`4+`G`&'\]&P^O-YG
M%88#2B8)=P)BW/]59+ULH`AG4!]-W`0?Q<F34'P[)RBC*"0!0=U].W;?+L<L
M"#2H=_\@IX$W09Z^^@W@_SV<_`DL:4#(;4YU3`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V)L;V-K+VUO;VXO;&%S='%U87)T97(N<&YG````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S-C4P(#$P-3$U-#,T,30V(#`R-3<T-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````,````#`(`P```&#<";4```,`4$Q410````#_``@("!`0
M$!@8&"$A(2DI*3$Q,3DY.4)"0DI*2E)24EI:6F-C8VMK:W-S<WM[>X2$A(R,
MC)24E)R<G*6EI:VMK;6UM;V]O<;&QL[.SM;6UM[>WN?GY^_O[_?W]_______
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________________P#_`,Q,@W<```$`
M=%).4_______________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M_____________________________________________P!3]P<E`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```S5)1$%42,>UELMR%$<0
M1<_-JNJ1@,#A\(L0C___+B3`>&4<'HUFIBJO%]42&I"PO:`7O>B.TY6/FS=;
MYO]=P?<&ZD,/WR1D$&\?>*>O<GBUVP]J!$9U<_5OP&_;,9(HT6P/+>?E\EO`
MQ?46HXA232UV;M`I<@+\_%<6&Z&EE1Y%])JA\NX1X/FV)38"+6?APC@V1BO9
M+A^HTNL_;]HP@&7Y&(L=L8_L3\IXH`]O/MV0`F,L>63NM[M!/U]2O/H:^'1-
MI(TLP-`/8_0^?"S-C(LO@5^VD#(@L,D:?804VN[!_?#B%'CY23(F#""D0ZF2
M$>5X2$O'GTZ`ZP$RZF(ETH%E(_*XUU+W+^\!+_X.0+@(A(U;41K(8&3?^6RY
MO@=LL301`?)(Y2@U:JF*?O#H_>SP\JX/K[ME@3S[*$D>1+7:?J2,=V/SM-\!
M-WU6<M9HUFE`6.H]0R8\;I:X"VGG.X4("?#HBCQF%"1"DG+7;X'7A_OBTGI,
M:2U*BQI8TB".NU_7D$9JYH!P&`PJBD:)7H8]:A5'C>-Z0D[!(4TEV<:9J2BJ
M)22W\S,L>3TAL6S-%#PU+W>WDG(Y9^R<BM+E]03'BAN,D)%"87N@S6*148R7
M%0B$D>?'#1)2!`Z!ATM:M2IR#:G,J;G-8UX98(5)EAS'PUE+;D,JM\&;.0LR
M=MH,IZQ68XQ!45V!RX)22&B&-/OH=*88IJ;3?=SEP$;(&+!7D7AF)+I'ND@]
MT=6MEI[<I%<+\;S+ZW@CC2XU]8C/6GI?IESNI"?/?F9:`XIQ*:5]GH>SF;2T
MUM5@P2!"270%J%Y]!IXV$^"Q#@/(MB-"ARB9:;E<W9NXM\^(#*R!/;6$%:'1
MHZSBT8D)?#PG$CLLD((HLR.$>T(ZXM0JGQ^[PK-&`DEX1"B2Z3[U\M3(+I]7
MCRB$A9'LV1.B%`/M_9=6^?NS@BW/G!%KV3Q2TO+^ZZ7XQP_MU@=FTL[,T<>P
M%.\>VJ(??]CD;-[T`8PI4:3ZX;&5]>-V.MGT@=IJ(-0N'U^*%]O=.AQ"45I3
MQ-6WU^Z+_7ZL?AEULWRY1!_8TW!Q<^R@6C<?_LMB7S?8VT=^'?3=_V;^`<.Y
M\NK8R,^2`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]B;&]C:R]M;V]N+VYE=VUO;VXN<&YG````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S,V-R`Q,#4Q-30S-#$T-B`P,C4P-C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```#`````P"`,```!@W`FU```#`%!,5$4`````_P`("`@0$!`8&!@A
M(2$I*2DQ,3$Y.3E"0D)*2DI24E):6EIC8V-K:VMS<W-[>WN$A(2,C(R4E)2<
MG)REI:6MK:VUM;6]O;W&QL;.SL[6UM;>WM[GY^?_____________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________________\`_P`4.L2F```!`'123E/_
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________________\`4_<')0````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```*$241!5$C'Q9;;;MLP$$0#SIR1
MI3B.D_A2-<K_?V;[0-*6<VO[5,*`(8!'.[/<Y>KNUS^NN_\#+//I^'+X\?/O
M@-?G^P`@9WO^(W#:#I8DRW8I3,_+=\#\*%0`VS;883I^#;R@8%L&;.K*]O4+
MX*$,8,DJ<DRE3,;C9\"R=95?)*F]OX8;5K(NP-N##5(IDIMI61(FGLX?@)T<
MN5PB2%8IDAP2QOD=<)!LJ]3]136KDE2<`/>WP$^J`#?"MMHJ!H@?;X!]L2WY
MKJFQ5>-)DC'@'RO@;+N^M+W8-JAIPC(#VQ6PM>BBJET;]4>IF.#C!5@V,FXZ
MKJ)4$UV3`.POP,%JFOJOZ3--8I'-=`'NU3<98R.I6%*-X.YJ;L""W)%6$%+C
M6XAZZ$\-F"79PK9Z`8E@"-13E%TT->#<`H!LT_P:DB&V).I?&G"L,@&O?%:B
M-VLH$DL%#E2155-/J"&$#+%<0PP-.*%+,KTR'P(D"(B+NZ2YMIEJZAN0CB3!
M.-CC):U>U9!DU/HY;=D"L^L'MW'K,1E91IV@ND`R]JD#C[AT/>JZH%J`I!9:
ME@[,`VV?5'K1WMC&Q@_7\I[B>F3J]:WJNLO"9GBY`L^$4@^N=Z8).%V6R;AJ
MH+<)8U1<6FE;-:?8"1AR6/?TB2A(=^IWF4ERD64\W5XSNQA**<4M24D2`L$8
MYWP++",,E@N2`\DP7",X/+V_^<ZCG8C:$TF&%J,VX6[Y<!D?!\<87.57HAW&
MP_+)=7_:>#44TDP;D^O^F_DP3W:<X+:]F<A^^6ID[>&V3@&FTS=#<=ZUM->J
M(QF?7[\?N^?]&)(,PQ#&W?LA^NE@GY^VXV8SWC^=EK__='A;_MO'R6_H;*WF
M6HB=Q@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O8FQO8VLO;6]O;B]F:7)S='%U87)T97(N<&YG````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#,V,3<@,3`U,34T,S0Q-#8@,#(V,3,U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```P````,`@#````8-P)M0```P!03%1%`/\`"`@($!`0&!@8(2$A*2DI,3$Q
M.3DY0D)"2DI*4E)26EI:8V-C:VMK<W-S>WM[A(2$C(R,E)24G)R<I:6EK:VM
MM;6UO;V]QL;&SL[.UM;6WM[>Y^?G________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________`/\`%Y409P```0!T4DY3________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________`%/W!R4````!8DM'1/^E!_+%````
M"7!(67,```!(````2`!&R6L^```#'$E$051(Q\667V_=1!3$?W-V[1N20!$1
M;0K)]_]@38/45N(A!-W8NV=X6-_D-DT+/"`L6Y;6.SOG_UCFWUW!?PVH+RU>
M97.JQNT+W_2E#V_V2S=*B/GTP]\!KO?KVC*1!4F93DYOO@&XWJ_9K$QC$"8\
MG7W\*N!R[TEKSV8E1MN6^=7[EP$7RTEI7IK=)*4`+$OE_.-+@(NVXSX:5N\:
M3F`L%.7)K#@ZOT;/!D(!"4[;"+S<O_X"<+&HK,LCW++M!!P0Z]W;9X`W"]'7
M1$C"2+(E(%.&]>[JLTS_^B?JO2M2D(@<NY'!F-C??<:P@.02#J12:ADA,D8V
MQKJ_/&+X9:^014IA*SL2MF0+AXTB_SABV*-0D,@H$J4!R2Z@M,'L7S\Q&$JF
M4;%-24QB4'@PI0(MCPQO.JR=.-1"*(ZBR\&?)\":V`:(6N=:@^QIL`46(,#K
MV\VDZP4,!*EPR1YA2<8:)0LRQON-(7UP)-,J84N*\2`P$L@\;`QF+-;LW>4A
MVX@*$)8AC(1%._@@+"R%%'3;"K`A,1$:^RQ?#8""0,K61,\2!6L2PPS%J`XA
MQ\80E33.WBVY9928(C2B8R.$)>2;S:0`@3.=V%U%18?6$B@\&K9L#.^V/-E8
MIDAML;98;#[:2-/!:1=R'!*5[)V2ED9`G]*`3QZC%`6GP=GHN;J(W(;&ECYA
MQWP`[*(&$H6V]%K4$S\6$^0HC=C='``W4:=:ZC378D^0"5/8QS-%TNZI'TJK
MU1&&$IDFA25I<WT@RJ<GP&VQ([0L35./XF)WZU`$2@#.CH?`M$::Q6[N(;?'
MJALWEN=/QT/@_51K&.B>S1QUFLL6)(T^BO-GH_*R!>N:VKF7'6MX7=J6/.'P
M^>_/%"C<Z^E#"ZV.+!,IP@A20)Z>/Q^5M[/7%8AYGDB9T>)C_,7)#^^^&,:_
MG935F!)I$4-3;).P^_'F!16]G6N+2BE%"2$DC]?9JYNO2-;/-D7J+O*Z](Z1
MI_,/7]7IC]]-])XY>MP@Q?<_??BF[%ZW=*K@OBZMS/69B+ZDTW!E0V^>YG?_
M1-C_[Y^3OP#`P.^JJ^O84@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+VUI;64O;7-E>&-E;"YP;F<`````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,S8P(#$P-3$U-#,T,30V(#`R,S<Q-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$```
M`!`$`P```.W=XE(````84$Q4182$A/___P````"$`,;&Q@```````````%QP
M7RH````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P``
M`$@```!(`$;):SX```!=241!5`C7)<HQ#H`P#$/1%".Q8I43=&%-CP#*@2HQ
MY/HD[9^L)XL/B0X7'XPV%U6>RG(+4`"V)ETC>U[Y*K`SA@?9%`2EJ/;U`8+(
ME*">Y\&*,L=ECRW)<EB6H\U^%@@7SPTSPB@`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V]O;U]W
M<FET97(N<&YG````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,Q-"`Q,#4Q
M-30S-#$T-B`P,C0T-#8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2
M````&%!,5$6`@(````#____`P,```/____________]L?[^4````"'123E/_
M________`-Z#O5D````!8DM'1`<688CK````"7!(67,```!(````2`!&R6L^
M````.4E$050(UV,H9P`#<89R)B4@4(8R&)BA#"8PP\7%"2X"4>,"!,[H(D[*
M!-4X*:&H838&`2!#$`S$`9N!%.SLG&(#`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]V:61E;RYP;F<`````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-3,@,3`U,34T,S0Q-#8@,#(S
M,S8W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@````]03%1%````
MF9F9S,S,____````J7X.F`````%T4DY3`$#FV&8````!8DM'1`"(!1U(````
M"7!(67,```L3```+$P$`FIP8````!W1)344'U`P4$PPHV)`CCP```%5)1$%4
M>-I-S-$-@#`(A.$;H=4N`+(!"VA[^\_D:5KC__2%``"J*E![9MK"42;(B0R4
MA6HZRAIHW;M=+7"2;B,"V-R-FJ!YOP8%JJ&K[\\/VG9_P+<;9U,17Z#\KAP`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O>&UL+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-#`S(#$P-3$U-#,T,30V(#`R,S`U-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`$`P```.W=XE(````P4$Q418"`@/___\#`P`````"`
M@`#__P``@`"`````_P```````````````````````````"$-1KT````0=%).
M4____________________P#@(UT9`````6)+1T0/&+H`V0````EP2%ES````
M2````$@`1LEK/@```%!)1$%4"-=C^,```OS_&3X(@H`"C*'(#V48&P,9BB(N
M@HK"#!]$$QU#$E.!##5!5_=$,660B$L%6$1042P-K`:L2Q#$<`$"1P(B4,9G
M8P@``%-=(`>HY5H(`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M:6UE+V]O;U]I;7!R97-S+G!N9P``````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#,T-R`Q,#4Q-30S-#$T-B`P,C0V,C(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0!`,```#MW>)2````&%!,5$6`@(````#____`P,"```"``(```/_____0
M+L$`````"'123E/_________`-Z#O5D````!8DM'1`<688CK````"7!(67,`
M``!(````2`!&R6L^````5$E$050(UV,H9P`#<89R)B4@4`8RF(U!`,A@%`0!
MD)004$H8S'!Q5H4PC(U2H2)FHF"&,%`3F`'2!&8H*0N##6124A"`,@P-C2`,
M864A%+L$(78!`$N=$Q%/P`IM`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R
M8V4M<'ET:&]N+G!N9P``````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`V,#<@,3`U
M,34T,S0Q-#8@,#(U,3`R`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`@#````*"T/
M4P```&!03%1%(2$`0D(`````>WL`.3D`8V,`>WM[``#_6EH`A(0`0GL`8YP`
M(=X``/\``'L`(5H``+T``#D`0KT`O0``.0``.;T`(9P`>P``____________
M____________________>L(=BP```"!T4DY3________________________
M_________________P!<7!OM`````6)+1T0?!0T0O0````EP2%ES````2```
M`$@`1LEK/@```)1)1$%4*%-5S\&2PC`,`U!%P>PJ<5L2H!SU_W_)H64&=-,[
M>"S8!@K\"6S62PU^P[7^E1^H_S7`D\`B26H1QQV4"*GGLDJT;6R]][R-7*5B
MVQB9.<8<<YY@WA];#F87#K@_<R7VKN,7O%XDR_+IA!]&2RE(DP1LWA8I0@%%
M%-B<J2/1&F%SGSG;/F<A:=CFN@WR'/,&,F,0&QN/=Y8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;7-P;W=E<G!O:6YT+G!N
M9P```````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#,V(#$P-3$U-#,T,30V(#`R
M-3`R-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`(`P```"@M#U,```#`4$Q418%_
M@,&_P/_^_W^!@`$!`/__XO__X____<#`OG=T5?_SL__QS__PS__PT8!``*5E
M)?_=O'H^')]C0=)2$=-3$GL\&WP]''T^'7P]'J%B0:%B0ZXN`*TM`*PL`*DJ
M"<Y/+@$``/____[^_L'!P<#`P(&!@8"`@`$!`0``````````````````````
M````````````````````````````````````````````````````````````
M`````````````,]_G^H```!`=%).4_______________________________
M_____________________________________________________P#">[%$
M`````6)+1T0_/F,P=0````EP2%ES````2````$@`1LEK/@```*M)1$%4&--5
MCUL2PB`,16-]4-NTH"@516HJ8G?!_G=EH(XS'G[@SN%.`BFEN``0^0$YH$)5
M14Z@EX,U?/Q(%%-,(!LL*$\T,V#0:3_Z$6T(@<(,%K537GD<<D_(AL'M_L^P
MN-NQ<?X9=XWH3MFHQ=)QLT8[-#0)$=[@%6+;=ETCZ[ITC-Z:X^%ZD;T0I8-'
M7_.%0H96CQ),-"WK3$L0N;\N1GB6+R]>83-_^0"[O1W7NDUYC0````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O;7-W;W)D+G!N
M9P``````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S8P(#$P-3$U-#,T
M,30V(#`R,S4W,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````8
M4$Q4182$A/___P``````_\;&Q@```````````/M!LW4````(=%).4_______
M__\`WH.]60````%B2T=$!Q9AB.L````)<$A9<P```$@```!(`$;):SX```!=
M241!5`C7)8VQ#<`P"`1)FM28+(`I4MO*`K8\D#O6#T^N.DY"3[XIN)Q\<W`Z
M=<#'0QJW<*U_66.2J8EQ2&N]S!&B9B:0UN=;5A9188X2[UD,H&#B1OFWLBP`
MJ<D'.+$7>R?BQUP`````245.1*Y"8((`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V)I;F%R>2YP;F<`````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4U,R`Q,#4Q-30S-#$T-B`P,C,U-#<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!`````0"`,````H+0]3````8%!,5$4````P,#!"
M0D)86%AN;FYP<'"\GG.\HGN,B8:9F9F]J(>\K92^MJ^\M['`KY'"LYK#NJ?&
MP;;ES*?IU;C.SL[>WM[MW<?NX,GHXMGQY];JZNKT[>+W\NO]_?T```````!_
M+KH/````'W123E/_______________________________________\`S1EV
M$`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```!Y241!5"A3
M3<KA%H(@#(9AC6^FF">-#(FM^[_,9J<![^''>+;NHSE+Y^X'^]GB)E=`M#=$
MI0#I>\K4&Q!$1L*E@"C(OHS-!83YN-4+C7.:&V#F=#1`NJ=8@9@2X>4-&)E2
M1*B0H7_@:I!3C"&$Q_"';5O7^^S]8-#7OG6*$JF5@9WQ`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O;6EM92]H=&UL+G!N9P``````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(R-#<@,3`U,34T,S0Q-#8@,#(S,C,Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````0````$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``
M>B4``("#``#Y_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%````
M____ZNKK,T]M-5%O2&%\5FV&=(*1>H>5BI2?N,#)P,?/,4YL-5%N.U9R/EAS
M0EUX0UUX1%UW1U]X4&B`5VZ&7G2+9'F/G:JWCYBANL+*O<7-RM#6T-7:?(B3
MC):?QLW3V-S?WN'C[.WM2TM)_O[^_?W]^_O[\?'Q[N[N[>WM[.SLZ^OKZNKJ
MZ.CHYN;FY>7EY.3DX^/CX.#@Q<7%Q,3$P\/#PL+"P<'!P,#`O[^_OKZ^O;V]
MO+R\N[N[N+BXMK:VM;6UM+2TL[.SLK*RL;&QJ*BHH*"@C(R,BHJ*A86%=G9V
M;&QL75U=5%144U-30$!`)R<G)B8F'1T=%Q<7%A86____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M23'-[P```%=T4DY3____________________________________________
M____________________________________________________________
M__________\`OF,UXP````EP2%ES```+$@``"Q(!TMU^_````*Y)1$%4*,]%
MT-46@D`4A>%9=HS=V"T6B*T#2MB(BLK[/XH(Q^5_^=WMC0P#_3*^(0,UK5KC
M!?I!)YARN;.S]AX!5&)4O>@I7:YW9$/&GPOC0O+<>`/@&L[C*J;I"4"Z[(N'
ML'?3F]K0HJ(!!VW6GP%TRPEG9"N*@P5`?P@M`<27I!TU29=7``]&416589YK
M`%E7;J?;3M\1`(9EV=&(XSC!ACDAA.<%LX,%__G6`1\*S2W3)#<H80````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W9C87)D+G!N
M9P``````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<R,2`Q,#4Q-30S
M-#$T-B`P,C,S-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````
MP%!,5$4""AX"1@)::G)FF@*6HJZVOL;)SM:$D9J:9C+.UM[.FF8:)C+:XNHJ
M,CK^SIHV0DZ^RM+BYNK^_LZ*EJ).6F*^QL[FZNI&3EK4V^,*$B;:WNJ3GJJ[
MPLO+TMOJZNK"RM136^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]3
M6^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]36^]3
M6^]36^]36^]36^]36^]36^_^&KX1````$7123E/_____________________
M`"6MF6(````!8DM'1#\^8S!U````"7!(67,```!(````2`!&R6L^````C4E$
M0508TUW/T1*"(!`%T`T4E<BD,DC8W?__RQ9T:/(^W(<S=V`6EE-@436O<+]=
M/P`+*&IYNX@@T)?DO#+BU/U@'Z4"(804F)RUCMJ"#=G'/!Z+)!N!V1[0]RLS
M4AS'C9[M#22MM:K@\VIPB@4N-!1@-ABWS7OY=@?L@)R7V@&[)!=0K6$HU\!_
MG<__`K6N#Y:X4DZB`````$E%3D2N0F""````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]O;V]?9')A=RYP;F<`````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,3,@,3`U,34T,S0Q-#8@,#(T,#8W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```#!03%1%@("`````
M____P,#``/____\```"```#_@(```(``________________________P62W
MTP```!!T4DY3____________________`.`C71D````!8DM'1`\8N@#9````
M"7!(67,```!(````2`!&R6L^````6$E$050(UV/XSP`&\@S_F92`0!G$$#86
M-@0S3$)"@A5`#%,7%V4F?K!(D%H!1$0I/1$D(A*D5B8,5@P4`.LR4@T3AC(:
ME2&,B$G*J";#[&(V!@$@0Q`,Y`%#,B"PQ$6_KP````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+VUI;64O<G!M+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q-#,W(#$P-3$U-#,T,30V(#`R,S`V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$````!`(`P```"@M#U,```&`4$Q415A86-[>WKRWL9F9F?___^KJ
MZFUM;?S\_'!P<,[.SC`P,(F)B6MK:T)"0DM,2U985EM=6V1D9&EI:4Y/3KZB
MH.*RL/;U]>+@WH^)A&YO;B$B(4M-2W-S<\S,S._O[]*_OL!H9<%13=S'PN?@
MV;ZVKU)34@<'!A\@']_?W_[^_OOX];Y&0KM`.\[(O[RNER8F)0("`O[^_?KX
M]/CT[(U*1HX7%+:$?0````P,#$9'1L3$Q&1B7HB">,"UH[RKD'9Y=KZ[N(Z.
MBQL<&[:PJ!<7%[.JG!`0$,V^J;RHBG]^>KZVJKRPGKNLE;RFA0<'!U)24LG$
MOM[8SLB_L];+NM7(L]+#K-#`I<^[GKRC?_3MX?+HV/#DT.[>R.S:O^G6N.?1
ML.7,I[RA>,;!ML2]K,.XH\*SFL"OD;^JB+ZE?[V@=KR><_______________
M____________________________________________________________
M_________S1O*TL```"`=%).4___________________________________
M____________________________________________________________
M____________________________________________________________
M______________\`.`5+9P````%B2T=$?TB_<>4````)<$A9<P```$@```!(
M`$;):SX```"L241!5"B13<XM#L)`$`7@]]+"-E4$@0/7!$-P]`8$AZWF(IN>
M`(_"8JMJ,&@(%ZB#8%!@^"G;PFZ[I$_-^\3,4`*(4>=7:("ZL7"4M.!H8%$J
MV0"'S$O1``CE4FE8TN;:NU.N]'3NGP:&+@S(*!YF0&`@XYASLV-D^C-C2$Y3
M'"8*[J=%[AG.D'I\^/7:G0&@BY?W%GF;6WWVR%O''D[JQR(+FPH6L+"NP,<_
M7Z/A,A"\6WNR`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+VUI;64O;V]O7V-A;&,N<&YG````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,S$V(#$P-3$U-#,T,30V(#`R-#`S-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$````!`$`P```.W=XE(````84$Q418"`@````/___\#`
MP```@(``@```_____U;LI^$````(=%).4_________\`WH.]60````%B2T=$
M!Q9AB.L````)<$A9<P```$@```!(`$;):SX````[241!5`C78RAG``-QAG(F
M)2!0!C&,00#$,&!F8#!&$U%2PBUB`A,)@8H8AD!%TD)0=<'L8H:)"(*!.`#8
M_!6)URW5I@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]M:6UE+V5N8W)Y<'1I;VXN<&YG````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3,P-B`Q,#4Q-30S-#$T-B`P,C0T-3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!`````0"`,````H+0]3```!#E!,5$4````$`P(%!`,("`@)"0D+"P<3$0X:
M$PL6%A8<'!P@'1P>'AXO*2$K*RLM+2TN+BXX.#A-34V!6BMR<G*J;RND<39Z
M>GJL<2ZM<S*@=T2C>TN$A(2D?DZH@4RT?CZG@E*G@E.X@#ZJA%6KAUBLAUBZ
MA$*KB%BZAD>\AT:\B$FZB4NOC5ZMC62\BDRPC5^]C$ZED7:^C5";EY3&EEW'
MFV2HHY[*GVBJJJK+I''.I'#-IF[-IG;0IG3,IWO0J'3/JWRQL;'/K'O-K(/.
MK8/4K'G5KG[2LHG5LH38M8R\O+R^OK[6NI3`P,#!P,#"PL+:OIK@PI[APIS@
MQ*#?Q*/AQ*#BQ:'CQJ+2TM+;V]L```![0$@>`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!02+`1^
M#@'Y````C'1%6'1#;VUM96YT`$UE;G4M<VEZ960@:6-O;@H]/3T]/3T]/3T]
M"@HH8RD@,C`P,R!*86MU8B`G:FEM;6%C)R!3=&5I;F5R+"`*:'1T<#HO+VII
M;6UA8RYM=7-I8VAA;&PN8WH*"F-R96%T960@=VET:"!T:&4@1TE-4"P*:'1T
M<#HO+W=W=RYG:6UP+F]R9V>*QT<```"9241!5'C:8V#`#B*!`(G++18>$>$I
MS`P7D/82X.04=)"&\?G\6$`4OSE,%Z\/F,7A"Q-@,^)B961DXC%EA]I@$!0<
M[._O[VTM!%$2&>IAIB(OKR"E*0X5"'/5<[>W=[30$($*A-B8*,G(R$BJPE0$
M6NJX.3DYVRI*0`4"7*RTE9759#7DH`)VQH:&6EKZNNJBD0B?00`V?P,``.(=
M%XJG_UT`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]M:6UE+V]O;U]M871H+G!N9P``````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#(T-B`Q,#4Q-30S-#$T-B`P,C0P-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!`````0"`0```"U^C?J`````F)+1T0`@$<UH!(````)<$A9<P``
M`$@```!(`$;):SX```!*241!5"C/M9!)#H`P#,3\=)Z6GYE#*:@P51$2\3'6
M9$%D,X-"$U+5*-2-A[!,4`9B0FL<K3RB*\YWN)0O"8L=7ESQZR<K<@HX0W8:
MM8$Z+A9DN`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M;6EM92]M86EL+G!N9P``````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(R-C(@,3`U,34T,S0Q-#8@,#(S,C`T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````0````
M$`@#````*"T/4P````1G04U!``"QCGS[49,````@8TA230``>B4``("#``#Y
M_P``@.D``'4P``#J8```.I@``!=ODE_%1@```P!03%1%DY./2TM)^_OXI:6C
M]_?U^OKYP,"_C8R&O+NW^?CTMK2NW-K4V]G3VMC2D9"-^_KW^OGVZ>?BXM_8
MD(V'W=K4VM?1^??S^/;R]_7Q\O#LDY*0W=G2W=K5Z>;AX]_9C8N(^OCU]_7R
MZ^GF]_7S[^WKEY22LK&QH:"@_____O[^_?W]^_O[^OKZ\?'Q[>WMZ^OKZNKJ
MZ.CHYN;FY>7EY.3DX^/CXN+BX.#@S\_/RLK*Q,3$P\/#P<'!OKZ^O;V]O+R\
MN[N[K:VMJ*BHHZ.CH*"@GY^?GIZ>G9V=G)R<FYN;FIJ:A86%=G9V:VMK75U=
M0$!`'AX>%A86`0$!````____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````N+5Q&````%5T
M4DY3________________________________________________________
M________________________________________________________`+"A
M!\\````)<$A9<P``"Q,```L3`0":G!@```"[241!5"A31<[70L(P&$#A&F9M
M92_9(P(M5H&FLI<MM"*B)'G_9^$/4CB7W]61.+O$_22F:9H^FM\$P+;M6>_3
M%P##,#:'XR^C]`J.L_WX?C@QW!0"\/8.]<<,XP@5H.]<U_6\*0!^I`(&(G,A
M`/]0`.]K;Q*R%!`+"A@28EG6&J`8R@!,EJLUY/Q%.Z\M@.LZ8P&4SCV7`#BG
MW;B$$)+E6M*'%U1(Y.N-2BWU#^TG556SBE*NAB_`Z3U^!NY>.TD6"DM$````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V%U9&EO+G!N9P``````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,W,B`Q,#4Q-30S-#$T-B`P,C,S
M-C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2````&%!,5$4```"]
MO0"$A(3__P#&QL;___\```````".I5WQ````"'123E/_________`-Z#O5D`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````9TE$0508&07!
ML0W#(!1%T0?"<AL%90%2O#8-$]A,@/X>X.:NGW,$K!,0\,Z`8/]N0%#;,!:[
ME_"#=ITE;/0976%0O68Y#*JCY\.M*7VGPJ"5>@F#6+6$C2"U\(-@O6YC`2D#
M`M8)_`')L27'Y^"<T0````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O;6EM92]C;VUP<F5S<V5D+G!N9P``````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(S,S0@,3`U,34T,S0Q-#8@,#(T-#(V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````0````$`@#````*"T/4P```P!03%1%``0```4```0'``0+``(.
M#!(@"@P9LTTV@"\<=CHO"```3U9@;8.86'^>?K#3<:W2B\SL4Y2J`#0]S2T)
M_Z6$_[.>_\"Q6A0,*P``&0``"P```003``@?``PK`!$N%6!SDMW@`"83TQH(
MOQ0#RS@NK2T@BA8`MT8DG"@`H3,`:Q,`D%@W5TD^]/__``H,J-')``X`QQL1
M_]#*_[ZY_]+&_^/#_\*'_\%J_[-2_]!V]*1='0``\_3F#2`>J+VXH24=_^#:
M_^7B_^#1__G/_^.:^K9'_\1%_[U(ZK]C#0H`\O_Z``<.M,/*"@``I#,C_]?(
M_^[D__':]NBW[MJ$^\M/_\8[]L!"[<]O``<`X/GV``<?M[[;%``(IQX`_^#!
M_^G0_^_,[,F/YKYF_\%%_[@S_;I%X;=E$0P`[OW_```SLK/L$@`>J2P`_]RP
M_KJ5],69],Z-^\UU_[Q%_]%2_]!CJ7TT!@$`W.[_`!)`M,'V"P`GAS8`__&]
M_^&S[M*@W,!_]-!Z_\9;\:\_OX4BT*]HS.[M`!<FH=+A``D,>4`5)```%0``
M#0``&@X`$0$`/1H`&P``"P(``!`$``T,'U57D\C"'4<Q``0,1%);7&YX:7Z/
MB:6[D[C3B++(BJ^W`!X4``<C``\R``@R``@S``@I`!,E``HF<I.R``D'%#M"
M`!8F1F^%``@C+4YO``4I1V2,+E)@``PB'E9O`!`K0W:1``XF+$M@``4;````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````F1/3'P```0!T4DY3
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M________________________________________`%/W!R4````!8DM'1/^E
M!_+%````"7!(67,```!(````2`!&R6L^````:4E$050HSV/\SP`"C!#P$\CZ
MS\'(^(T;*L#XEH%1F!$%W&/A1Q5@0!,XS,#"AR+@PT!("WZ!VA:P`,30M2&,
MC!/!*AC!3I\!4Y4`%6!8".3\9V*,8H`)@,!RQ@@&A,!*J)X`%J@T!\Q:`"+`
M$[4PPS%Y`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W1E>'0N
M<&YG````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,Q-2`Q,#4Q
M-30S-#$T-B`P,C,R-#,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!`````0!`,```#MW>)2
M````#U!,5$4```"$A(3&QL;___\````L9:@&`````7123E,`0.;89@````%B
M2T=$`(@%'4@````)<$A9<P``"Q,```L3`0":G!@````'=$E-10?4#!03"PG;
MN*46````-TE$051XVF-@8'```08&!A9#(#`!,H2=00`H)&P,!$8H#!,7$V=T
M$1<R1&`,(240`#)87$"``0#Y7!5JW)+KX0````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]S;W5R8V4M8RYP;F<`````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,C$@,3`U,34T,S0Q-#8@,#(S
M-S<T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB4@```!A03%1%A(2$
M____````QL;&``"$````````````B^D4?0````AT4DY3_________P#>@[U9
M`````6)+1T0'%F&(ZP````EP2%ES````2````$@`1LEK/@```#Y)1$%4"-=C
M*&<`@?)RAG)&04%!(7880P#&4%*',`2%P0P7%PA#Q%'$$9TAB$L*K@MA#I3!
M;`P"0(82&*@#`*,4%"C8:RJ3`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+6@N<&YG````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,S$V(#$P-3$U-#,T,30V(#`R-#`P-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$````!`$`P```.W=XE(````84$Q4182$A/___P```,;&Q@``
MA````````````(OI%'T````(=%).4_________\`WH.]60````%B2T=$!Q9A
MB.L````)<$A9<P```$@```!(`$;):SX````[241!5`C78RAG`('R<H9R1D%!
M02%V&$,`QE!2!S)$'`4%A5$9+BXP$1%'HAE``P51&,S&(`!D*(&!.@"S1A1>
M9S9^?P````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]M:6UE+W-O=7)C92UJ879A+G!N9P``````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#4V-"`Q,#4Q-30S-#$T-B`P,C0U,#0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!``
M```0"`,````H+0]3````8%!,5$4A(2%"0D(```!"(2%24E+_>WO_.3E[(2&]
M6EK_``#>``"]O;V<.3F<``!:6EHQ,3'___^$A(2<>WNEA(2<G)QK:VO.SL[>
MWM[O[^^,C(RMK:U36^]36^]36^]36^]36^^BICK[````('123E/_________
M________________________________`%Q<&^T````!8DM'1!\%#1"]````
M"7!(67,```!(````2`!&R6L^````@4E$050H%07!24("`1`$L.H2%T2T70>]
MY/^_-`E`!@A@&B!`V@(!TC9,!*1M!YV`-'=M3!N0T_W#8V.:(-.G^_-SQ\R$
MF5Q>SN?KZUM"I/N^']?KYWX%F23?NS\_NY<@:7O9W=T]BLPTQ^[N[E'$)'O[
MG?F^'4608\*<_@9!)M"!?\1K$5RW4&3[`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O;6EM92]I;6%G
M92YP;F<`````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,S0@,3`U
M,34T,S0Q-#8@,#(S,S0S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````0````$`0#````[=WB
M4@```#!03%1%A(2$____QL;&_P``A```````A(0``/\``(0`````````````
M`````````````````F$/RP```!!T4DY3____________________`.`C71D`
M```!8DM'1`\8N@#9````"7!(67,```!(````2`!&R6L^````:4E$050(US7-
MP0F`,`P%T.H"FD@=P(,+M'M(U:`WI=`9NH);QR3B/SW^#\0Y#3.[!@"P^]%S
M-'C:!.,\%PR+:Y"H#%%NQJ.6L`CPJ/=^:7-.[:K`]!!:DZ`8,.</GNB;0'\(
MVDDC(,O%+\3^)0^Y3-I6`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+VUI;64O<V]U<F-E+6-P<"YP;F<`
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S,Q(#$P-3$U-#,T,30V(#`R
M-#,S-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$````!`$`P```.W=XE(````84$Q4182$
MA/___\;&Q@``````A/___________]PZ/BD````(=%).4_________\`WH.]
M60````%B2T=$!Q9AB.L````)<$A9<P```$@```!(`$;):SX```!&241!5`C7
M8RAG`('R<H9R1D%!02%V&$,`RA`V-H<P!(5`#!$701$PPT7$T<4)RH"*P-0@
M1&!JX+K@YL`83$H@`&08@X$Y`/#Z%8)31K%5`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]M:6UE+VEC86QE;F1A<BYP;F<`````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<R,R`Q,#4Q-30S-#$T-B`P,C0R,#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!`````0"`,````H+0]3````P%!,5$4````6%A8K*RLO+R]#
M0T-5555H:&AU=75^?7A_?7B30CBG13Z`?WG434&"@7R#@7R%A'_GGCR*BHJ1
MD(F2D(J<FI2=FY6@GIBCH)JEI)VGIZ>LJ:.NK:6TL:JTL:NVMK;`P,#*RLK/
MS\_8U<W9UL[5U=7>V]7@W]?BX=OEX]_FY>#___^]O;T`````````````````
M``````````````````````````````````````````````````````````"V
M:2*O````+7123E/_____________________________________________
M_____________P"E[PO]`````6)+1T0_/F,P=0````EP2%ES````2````$@`
M1LEK/@```'-)1$%4&--CT$$##.0(,"`#D`"CE!`[&RLK"PL+,Q-8@$%;6U%;
M6T%;6UY;&2*@),,I(R,@`R1%H"K4Q;4T)965Q91E(`*J<GQR<KS<W-QR,!4:
M8FK*W(*"7"@JN+FXN&`JE.5X9&3X@(9*2S!@=1@AOP``Y(<>(C:/L<@`````
M245.1*Y"8((`````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O;6EM92]P9&8N<&YG````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(S,38@,3`U,34T,S0Q-#8@,#(S,#,S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````0
M````$`@#````*"T/4P```P!03%1%````@````(``@(````"`@`"``("`P,#`
MP-S`ILKP!`0$"`@(#`P,$1$1%A86'!P<(B(B*2DI555534U-0D)".3DY_WR`
M_U!0U@"3S.S_[];&Y^?6K:F0,P``9@``F0``S````#,`,S,`9C,`F3,`S#,`
M_S,``&8`,V8`9F8`F68`S&8`_V8``)D`,YD`9ID`F9D`S)D`_YD``,P`,\P`
M9LP`F<P`S,P`_\P`9O\`F?\`S/\````S,P`S9@`SF0`SS``S_P`S`#,S,S,S
M9C,SF3,SS#,S_S,S`&8S,V8S9F8SF68SS&8S_V8S`)DS,YDS9IDSF9DSS)DS
M_YDS`,PS,\PS9LPSF<PSS,PS_\PS,_\S9O\SF?\SS/\S__\S``!F,P!F9@!F
MF0!FS`!F_P!F`#-F,S-F9C-FF3-FS#-F_S-F`&9F,V9F9F9FF69FS&9F`)EF
M,YEF9IEFF9EFS)EF_YEF`,QF,\QFF<QFS,QF_\QF`/]F,_]FF?]FS/]F_P#,
MS`#_`)F9F3.9F0"9S`"9``"9,S.99@"9S#.9_P"9`&:9,V:99C.9F6:9S&:9
M_S.9,YF99IF9F9F9S)F9_YF9`,R9,\R99LQFF<R9S,R9_\R9`/^9,_^99LR9
MF?^9S/^9__^9``#,,P"99@#,F0#,S`#,`#.9,S/,9C/,F3/,S#/,_S/,`&;,
M,V;,9F:9F6;,S&;,_V:9`)G,,YG,9IG,F9G,S)G,_YG,`,S,,\S,9LS,F<S,
MS,S,_\S,`/_,,__,9O^9F?_,S/_,___,,P#,9@#_F0#_`#/,,S/_9C/_F3/_
MS#/__S/_`&;_,V;_9F;,F6;_S&;__V;,`)G_,YG_9IG_F9G_S)G__YG_`,S_
M,\S_9LS_F<S_S,S__\S_,___9O_,F?__S/___V9F9O]F__]F9F;__V;_9O__
MI0`A7U]?=W=WAH:&EI:6R\O+LK*RU]?7W=W=X^/CZNKJ\?'Q^/CX__OPH*"D
M@("`_P```/\`__\```#__P#_`/______6").MP```0!T4DY3____________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________`%/W!R4````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````6TE$050HD5V.RPU`(0@$N7FQ#OLOC&1#!;PE
MHL*;B^[P">+N\F`(8<E<4JM"L?BL`P5I@M2)%%PZXP=8%T-_`HHN=+=<,1`]
MP!$C`E15]NFYX(ZP9$V\G**>^P&ZF93#$VX9AP````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+W!H<"YP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S-2`Q,#4Q-30S-#$T-B`P
M,C,P-#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!`````0"`,````H+0]3````!&=!34$`
M`+&.?/M1DP```"!C2%)-``!Z)0``@(,``/G_``"`Z0``=3```.I@```ZF```
M%V^27\5&```#`%!,5$5[>WL```"]QL;___][A(1[A+TY0EJ$C+V4G,;O[_?>
MY^^MM=;>WN_W]_]"0EJ,E,;&QMZUO=:]O=Z,E+W.UN><I<XY.3D8(2D8(2$Y
M0D*<G*7___________________\@("`A(2$B(B(C(R,D)"0E)24F)B8G)R<H
M*"@I*2DJ*BHK*RLL+"PM+2TN+BXO+R\P,#`Q,3$R,C(S,S,T-#0U-34V-C8W
M-S<X.#@Y.3DZ.CH[.SL\/#P]/3T^/CX_/S]`0$!!04%"0D)#0T-$1$1%145&
M1D9'1T=(2$A)24E*2DI+2TM,3$Q-34U.3DY/3T]04%!145%24E)34U-45%15
M55565E975U=86%A965E:6EI;6UM<7%Q=75U>7EY?7U]@8&!A86%B8F)C8V-D
M9&1E965F9F9G9V=H:&AI:6EJ:FIK:VML;&QM;6UN;FYO;V]P<'!Q<7%R<G)S
M<W-T='1U=75V=G9W=W=X>'AY>7EZ>GI[>WM\?'Q]?7U^?GY_?W^`@("!@8&"
M@H*#@X.$A(2%A86&AH:'AX>(B(B)B8F*BHJ+BXN,C(R-C8V.CHZ/CX^0D)"1
MD9&2DI*3DY.4E)25E966EI:7EY>8F)B9F9F:FIJ;FYN<G)R=G9V>GIZ?GY^@
MH*"AH:&BHJ*CHZ.DI*2EI:6FIJ:GIZ>HJ*BIJ:FJJJJKJZNLK*RMK:VNKJZO
MKZ^PL+"QL;&RLK*SL[.TM+2UM;6VMK:WM[>XN+BYN;FZNKJ[N[N\O+R]O;V^
MOKZ_O[_`P,#!P<'"PL+#P\/$Q,3%Q<7&QL;'Q\?(R,C)R<G*RLK+R\O,S,S-
MS<W.SL[/S\_0T-#1T='2TM+3T]/4U-35U=76UM;7U]?8V-C9V=G:VMK;V]O<
MW-S=W=W>WM[?W]_@X.#AX>'BXN+CX^/DY.3EY>7FYN;GY^?HZ.CIZ>GJZNKK
MZ^OL[.SM[>WN[N[O[^_P\/#Q\?'R\O+S\_/T]/3U]?7V]O;W]_?X^/CY^?GZ
M^OK[^_O\_/S]_?W^_O[___\'Q@QM````('123E/_____________________
M____________________`%Q<&^T````)<$A9<P``"Q,```L3`0":G!@```!;
M241!5"C/G8])#H`@#`!+2%L%4=R]\?]?&I"R7)WC9-JT$"*J`I\`0806BL@#
M^E>A.J+`!$$I$'D8#36%G9C=7`OK%O1K4[`WN"W=CAV/DR[Y15'B?N1;N2!D
M7KFP"".%W##Q`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+VUI;64O<V-R:7!T+6IS+G!N9P``````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,S8P(#$P-3$U-#,T,30V(#`R-#$W-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$````!`$`P```.W=XE(````84$Q4182$A````,;&QO__`/___X2$`/______
M_^,7U7D````(=%).4_________\`WH.]60````%B2T=$!Q9AB.L````)<$A9
M<P```$@```!(`$;):SX```!=241!5`C78V"``$8&]O)R!B"A",0%)B:*8`9+
M:)"`.)!1X&*BR`1FN(8*"H*DP$K`:IA#@\11=3$PACJ!%3L)B!B!&"R&S,Y@
MJ0(E1B6(8D&@,4`&DQ(8*#((0@$`@+<6DNH<%!<`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]M:6UE+V1E
M8BYP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`R,B`Q
M,#4Q-30S-#$T-B`P,C,P,#4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!`````0"`,````H
M+0]3````P%!,5$4````P,#!"0D)86%AL;&QP<'":``"N``"V``&Z*BJY*3*[
M6EG```#*.3G"7UK%967:>7B\GG.\HGN,B8:9F9F]J(>\K92[M*V\M['+DH7"
MDI+`KY'"LYK#N*/<JJ?@L*_DM+3&P;CES*?HU;?+RLG4SL;9T,/=W=WLW,3F
MWM3NX,GIXM?QY=3JZ>GS[>+V\>S\_/P`````````````````````````````
M``````````````````````````````"ES>*7````,G123E/_____________
M____________________________________________________``U0F.\`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````K4E$0508TT7.
MZ1*"(!B%8>U+(\5M7,MR2<<-$+S_FXLEI_<7/'-FP#ID<";/EH9954$&)S`A
M8XZ0HL$-,(JY<$:1V0I<[/D^\MK4N5XT8'=D;`X\QJI4`;J!"**VQ2,GI0)\
M0!#-K,,]HX5>'!`^N8C11$GQ6W1>&^-RI9M9N"`:WR\GNBRY>04$)RN1]\$`
MNN]\IW09AH\!^=-FH]L@(3$`??AXO^HZ3TZP_WT!9%8<21%\580`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]Z=RYP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C`T-"`Q,#4Q-30S-#$T-2`P,C,P-C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#___^^'""L&1Y,*BOBP,+%<'?+@HR[KK"Y
MB)&DE)?LP,[[^/DW-3;:U]J,C(VWNKS)SL^)BXN_QL-D;&4;0A4Q7ADN<05;
MF35:DCAWJU>(N6HJ;0`N;P4Y>Q`^>QA)B2%LIT98ACMTK5!RDD%VFP-]HPV*
MKQUI@QN:OB]SCB-]F2J&HS".K#6IRT*AP$:QTD^NSE#$Q[MSEP#@Z%>JKV/#
MS`#%S@/%S0G-U@W8X1W-U!_F[B_R^D*AI2S?YT'W_T_R^5"KKT#T^EZ_PW;N
M\&78UQ#DXR&PKB&\NRCR\#7'QB[2T33\^T;EY$+^_5#V]$ZHJ)#O[^[0R@7*
MP`#$OE_MZ*_$NVG<TWO9R)>TGW/DK$[-=P'+=@'3?@K-?`W=BACJFBOWJ3[^
MLTWMJ$G[LU'RN&S7B"?2S\S/@#GTIVVZFX6^+@K;/13G32:Y1";$3"WT8#K/
M4S/?7S[];TKQ;DS\=%'/*`?#`0"]`P/'!P>L"@K1%!2_&!@A!07>)B;-*ROK
M.CJJ+"RT,C';/C[7/S[!.CKU2DHR$!#J3$ST45'C34W424G@45%"(2',='-4
M-35/-#1E1D9>0D)N4%!J3DXQ+R\>'1U$0D(Q,##U\O)14%!03T]'1D;AX>%_
M?W\W-S<-#0W___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#+ZSJ/`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+U)1$%4&!EES[\.`4$0!O"=V;7GS\61B$KM010J
M"JU"(WHA"*]`H?`"GD!#2TVO$@^@N.8D<N[6CCDZYNM^F7R34>)OE"@!N$\B
M;2EV,,S@58EYOUJPQKPL($<"T["V;:7<T!(B`"`=E`AU;VWB"8M$+<D()8QW
MZE2G\UE6(^]9R[3:Y\_']!(>A(JPOV`:-+&RB2XHE8,4C6],]9UL=W,!2(ED
M.4R-LG^C>R)<]*51T0OX>.HC1$F][_^\]`9'(TO.,9\<@@````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V%L+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0U(#$P-3$U-#,T,30U(#`R,S`R
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_]4U-L<Z._]G:`<!`,P``,@``)\``'\``'8``%P``!@``+$!`:P!`<X#`\P#
M`U0!`4T!`8H#`]`%!<X%!<P%!;L%!6$#`\T)"8L'!ZL*"M8-#<T-#9`)";H-
M#=@0$(L*"D0%!;L0$,\2$H\-#5T)"68*"M(8&,\8&)01$>$='9`4%.0A(=0@
M']<A(=$@()T9&;0=':<;&Y(8&-@G)[`A(>XO+[(C(Z<A(;DF)MTP+[PH*'$8
M&/(U-;\J*L0M+<$L++LK*\<N+AX'!\HP,+(J*LTR,>$X.-4V-=(T-,\S,_<^
M/MTX.'D?'T82$OI"0MHZ.KLR,E@8&.=!0.`_/OQ&1NI"0N5"0OY*2N1"0H,F
M)NI&1L4[._]-3>Y)2>Q(2/]/3_Y/3ZHU-9@O+_Y04/),3/U14?Q04/9.3NY,
M3.E*2OM14?E04*TX./%04-1&1K`Z.M)&1NY14>M04+Q!0=U-3?975X(O+^Q7
M5Z@^/OI>7NE96:E"0OUD9,=/3X8U-6(G)_ID9/AE9?]J:OAJ:NUE9:A(2+=1
M450F)AL-#7<Z.K1>7E`K*SHA(2X='1@4%!`0$`4%!0,#`____P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(0+
M</(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````ODE$050(
MUV-@P`(X.0UC6ROS-,4Y1!1T[<)204):06T]I7YJW,+R1N8!B;E`(46WFJ;V
M1E4A075;)Y^XG'B@D&4!2TF%_V16EPG1A9'I::%`(>:6<E\3)9Y)$_L:BE(S
M([R`0LW5(09R7!)=_2FU];DQ3*Y`H;H$4UD^7NG@WJJRXOA`=T>@4+ZUB@"[
ME$YG=W9'5JBW@Q50R$-#C$U463^Y(",SRLO9Q@PHI"?)QB^C;1Z>E!OCZ6IO
M88S-.P#?\RZ$Q<1]K`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O8F$N<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-3`@,3`U,34T,S0Q-#4@,#(S,#`S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____`!=(3VZQ4&NH-5B?`2MV"2]W&SEM
M(D6&-EJ;.EZ?.UV847:V0F"4:8G"<8>N<XFO`"YW`"YV`!Q*`2]W`S!Y`S!X
M!3)[!3)Y!S1\"35[#3J!#3A]##%M"B=5$#V$$#R!$CR`%4"(&$*$'4F.%#!>
M(4V2'TB)'TB('T6#)T^.(4!U(T-V+UJ>(3]O)D=]&S)6*$E^,%:4*TV$,%*+
M+D^%*D=X-%>1,E2+.%R:.%Z:-EF20FNN/V*=1V^P06:A0V:A.UF,26VJ2&VG
M06*64'>W4':U06"24':S37&L4G>T1F:94'2M0EV(7H"X9(:]:(F_9H:Z:HO`
M7'6>>9;$?YO)>Y7!@9S(CJK:EZ_5DJG-AYJXH;76O<OA5WNS6GNM>(&/N,78
MJ+7')$1M46A^:GZ(BY6+DY-PL[*2HIIACX9/TK8TE((KP:U1L:!2S*4!T:H'
MH887Y+TAU+(?NIL>[L@OW;PW^M5"X,$^_MI*[LU)_MQ0^==0]M=7H(P\HI!$
MIY9*R[=>TKYGP*Y>R[EGT;YKS)X`S)\`S:`!S*$%S:()UJD-V*L0VZ\4WK(8
MTJD8X;4=Z\`K\L@U]<LZX;TX^-(^_-1&_]A/\M!,^]A1]]50SJ`#T*(%U*8*
MZ+PF____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````FO">0`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```#!241!5`C78V#``I@,$_DRZZ9.Z&J?VUN<9^\&
M%!)1\XL+RRKI[IC3,[&LR=T3*"1OGA`;[II;T#FO?]*T9F]GH)"^3R!+C(!<
M46'?_"E5;5YV0"&GX'@K3@_!E-+BR=-K6ATM@$)!_@X:[%HAW*GE%3-J6VQ,
M@4(!+MJRHFR*R;QILV=5YUN:`(5\C97$A:24N:(CTV=6-IH9`(6L522%)134
M62.B^#-R&HQT@$*:TD)B,JIZMLRA23S9];H<V+P#`*'H,C5U"CRZ`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A;2YP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`Q,B`Q,#4Q-30S-#$T-2`P,C,P
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___!`0W``0W("A;##1B$"A+2&"3.)S+?*S:J*C+M/DGU35?D25/B2%+Q45O@
M66'T9&T-`<`/`\`3!\4=$L0@%,\Q)MPI(9\Z+])%.NI(/]952O163.A;4?-.
M1LQ:4.AP9_8-"<$-";\6$L<8%,(D(-$R+LTV,]\T,K@[.,-)1>Q#0-!75/13
M4.123^);6/%M:O,``,P#`\X%!=`%!<P)"<T-#=80$-@8&-(='>$A(>0?(-4O
M+^XU-?(P,,HX..$V-=4T--)"0OI&1OQ!0>9"0N4[.L=&1NI/3_]04/Y.3O90
M4/E75_9>7OIF9?=J:O_,>`/,=@?0?`C.>`G,>PG->@_8AA/6@1/`=!+2AAOA
MCB/DE"3/A"/4B"6P=2.R=B?NGC6\?RKRI#C<DS3'B##AG#O2D3?*B36P>3'2
MD3S\L4GEHD2[@CC&BS_^ME/VL5#6F4KSKU?SLE[HJUS`<Q#%>!;$?""G:Q^_
M?R[5D3KZK$CJHDCJI$O_M%7YL57HJ5C,``!_``#.`P/0!07,!07-"0G6#0W8
M$!#2&!B4$1'A'1WD(2'4'Q^=&1GN+R_R-37A.#CZ0D*[,C+\1D;G04'&.SO_
M3T_^4%#Y4%#V5U?Z7E[W967_:FK___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````"[
M9F2J`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*-)1$%4
M&--MC#L.PD`,1/W;39!(@RA`X@X<@LMP#BY)1Q$)I0"!^`@28GO9K>%5]M/,
M`/R`L(-I7=F[5V4I;`F@#M%'-25F)L:<BA+1/N:)F`C9'P*SBM)099-_HE34
M>F*/08V$.48<]4A0>Z]F)1$"V6@@T'KOI9:GV/.5U>;5M"OLJL4+FYLEW0O<
MGR<]2$A7P?/H5HIYB87#@M'M,N^6\(<O34M.V(\2TXH`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+V)B+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#4P(#$P-3$U-#,T,30U(#`R,S`P-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___R@E6"XK8`X,1P\-1Q843$)`;$)`
M:T1";%A6A5]=BUM9@71RGA(12QH94B$@538U<CLZ<$].>FAGH&9EG5!/>5I9
MA6!?BVEHDP``3@``30``,0``,`,#40,#4`4%4`D)4PT-5PH*.Q(26A@87A$1
M0B$A;1\@91\@9!D92QL;4"<G:B$A5R\O>2$A5"8F72@H8#4U?3`P<"HJ8BTM
M9BXN:#`P:S`P:BHJ730T<3@X>30T<#,S;C(R;#X^A3@X>$)"B#HZ=C(R9D9&
MBS\_?$%!?S\_>TI*CT)"?TU-D$9&@TE)B$A(ADE)AU!0DT]/D4Q,BU!0D4Y.
MC5%1DE!0D%%1D5!0CD9&?%!0C5=7DEY>F%E9CV1DGF5EG6IJHB(C62LL9#H[
M<?[S2GMQ`']U!;VN"MO.%)J1)EQ7&%A/`']S`7)H!XZ""H-W#=_-.-W./LRR
M`,FP`(%S`<"K`\.L!,FO!;ZG!7UO`UY4`\>P"<.M":Z;";VF"\:O%*J8$<^X
M&./,(6UB$,^Y'X1W%,^X(8I[%D=`#>W5+]O(-;"A*N',./CA0O/=1F)9''%H
M(?[G3^'/1O[H4/?A4//@4-S*2<NZ1(N`+^?54>[;5.K76I6*.D$]'5]9*WAM
M*____P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$S_[X4````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````P4E$050(UV-@P`)D9+62>&=U-Y055@NH&[GX
M`X5DU9SC)*<U5Q65U#/K.0:$`H64+6-B>>;E%6?G]K';>X7Y`87T(T3".=HJ
M4W):NH0]0@+=@4)"\5'63#59J4W]^5S^P9XV0"'1:#<-MM**]CG3>[F#O`4M
M@$*QOCI*K.5IF7,+IDCX.-DE`H4BC57D66K3,V8GSQ1WM34U``HYJ"I(\=4U
M=DZ<-$/,RLQ0%RBDJ2@MQ]_:T3-A\E1.<Y,$;6S>`0!)63':PG4V20````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O86XN<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#4@,#(S
M,#(T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____Q</&PL'#X>3IK[2YB\OHL,/,?(6)`'ZR!8*S#'VL'8V\(9C,+9C%*Y*\
M+)&Z+HVV,YW'+8FQ.*'+-IG`0:?31JS409S!4+WH4+OG4+CB4KOE7K_E8,'G
M:,7J6Z/"JL#)JK_(UN?N`H&R$8_`$HBV%HJW()S+'Y"\*J'/)H^W+)C",9>^
M)W>6,9.Y,)&V+XNO/;'=-Y_'-)>]-I6Y0:G1/J#&0JC/.Y*T1J;+3K??4K_H
M3;'83K+94K;<4[?=6,#G5[O@5[G?3*+#5[C=9L'D:L?K;LGL<LOL<<GKO]+9
MH+"VJ[O!M<;,UNCOQ=;<T^/IV.;KZ??\X?#UVN?KY_3XU^/GZO;ZH:ROQL?'
MLK.SU-74U=74V,;`Y]?2]N7AW40DS4$DXU4X^6]3[W!7X,W)PQP`P",%QB<(
MQ20)P"<)QS08M#HF[UY"]E]&UUA`]&E/UL&]Z=G6]>7BJBD5J"@5ZTXUL3LH
MKT8YOU!#SF)6UG9KS[FW_O[^_/S\^OKZ^?GY]_?W\O+R[N[NY>7EY.3DX>'A
MV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*Q\?'O[^_O+R\N[N[L+"PIZ>GG9V=
ME)24?W]_____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MCNI;X0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!
M5`C78V#``F;,F!;%6%*0DY%=V]'67%\'$IH^N:DA/BDK/;.HO:6!L1$HQ!$9
M'A'$7%%6FLL4&!(<%@H4TG/Q<!52YQ86Y-$RLG%TL`(*6;H[B4@(<.H:\SI[
M25E;F`"%W&3--/6U^54U[.4\I<5%#8!"\K8Z:BI<"GQB;)(R=N:FAD`A96]V
M)476RJKJ&A;_`#]?'Z!0>U=?7W=<8GE^2D)KUX1)4X!",;U]/9UIR7F%J<6Q
M_1.CIV+S#@#HNS%+[?6MKP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]A;RYP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C`T-B`Q,#4Q-30S-#$T-2`P,C,P,C4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#___^^.CO_9V@_-38B(R,K+"P?(!\'
M"P$3%@HB)0%65TUH;"MH;!B"A3YL;2:5EDH2$@!_?P=86!2*BCJ2D4(T-"%)
M23565D)D9$X4%!`Z.C575U%+2T934U`R,C$P,"\_/SZ)A`-^=R_-KP!<3`T4
M#P#4G0K,B0#OI37HAR;;<!3-50',1@'<8"',1`/-1PG*)`##'@7.(0U*04#.
M$`/>)!B["@71$`?,``!_``#0!07,!P76#0W8$!"+"@K,$!#/$A+2&AB4$1''
M&!CA'1WD(2'4'Q^=&1GK*RO8)R?N+R^G(2'=+R_R-37U.CJR*BKA.#CX/C[7
M.#C)-#3Z0D*[,C+@/S[\1D;G04'^2DKR1D;&.SO_34W;0D+N24GL2$C_3T_^
M4%#R3$S]45'[45'Y4%#T4%#Q4%#L3D[41D;V5U?L5U?Z7E[I65G]9&3W967_
M:FKV:FH4"0DJ("`Y,#!/1D9:4%!93T\@'1UG7EYN965D9&1145%04%!/3T],
M3$Q)24E(2$A&1D9"0D(Z.CHX.#@T-#0S,S,P,#`O+R\N+BXM+2TJ*BHH*"@G
M)R<F)B8A(2$='1T;&QL8&!@2$A(-#0T)"0D%!04#`P/___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````F5)NW`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"K*P\8@JS`YUL+*WMW/PB
MDD!"SF$%N9'N!AJFMJ[>H8EI0"'[@+S\!"]C71UU,\^@V-1XH)!/%G.&KZ.^
MBH6VEG]42G(X4(BI*"?8Q<C0W$%/,SH],RX$*%1=95)2K*:D6JDL6E%>QE(*
M%*IIZI_&P<7)R\/'7=O8*L\&%*I3F#I34$B87T1`ID&QHV<"4*AMR@R&&5)B
MXK)RDA+MW7T3@4+LTQEF3IO4U5)?URS=V<LZ&9MW`/J.,+ZKUMLN`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)D+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0U(#$P-3$U-#,T,30U(#`R
M,S`Q,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___Q]*(")"(RM-+#I9.P`O```M```<``,P`P,O`P4R!04Q!0DT"0TZ#0TY
M#0HF"A`\$!(\$AA!&!$N$1U)'2%,(1]''QDV&1LY&R=.)R];+R%`(2]9+R$^
M(29&)BA(*#5>-2I**BY0+BU.+3A@.#!2,"I(*CA?.#-6,S17-#YG/CA=.$)K
M0C98-C)1,CI=.D9N1D)H0DIT2D)F0D9K1DEO24UT349J1CM9.TAL2$]V3TEM
M25!W4$QQ3$YS3E%W45!U4$9F1E!T4%=Z5UZ!7EZ`7EEX662%9&6%96B(:&J*
M:C!6+S)4,399-3]C/C]B/D%E0&:%941F04MM2!U`&#%6*PTO!0DL`$QI0AT[
M$%MS3UAO3!\W#6]M3EQ,+T`A`6LW'XE2.FTN&&0?"6L:`Z5D48HY)YXP(905
M!\)31J0D&,U;4,A:3]U84:X%`*40"=LZ->I*1LP``,<!`,8``,T!`<P!`<H#
M`\@#`\P%!<H%!<P'!]0*"M`*"M`-#<X-#=,0$,\2$ML4%-<4%-D8&-L='=\A
M(>@F)N4K*^DO+_(U-?,Z.O,^/OI"0OY*2O]-3?___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`+::.!T````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````ODE$
M050(UV-@P`(X."18O5TT0L/9N`7%%`UM04(B^IZNP8D%^:FQHK*ZUHY`(0%U
M=X^0](;RLMKL,&US!QN@D)R3EV-\4T5)34M'DK&#70!0R-+;136YJK2ZL;T[
MR];>1`LH%.06R)127%G?UM67ZVBAIP84\K"2XDLHJVOM[)V09F;@RP(4<O81
MXHS(;.[HZ<^+\==4D0<*Z0CSL'-'9106Y<09:2DKR`"%Q'G9N?A%I2.C'4W]
MU)28);%Y!P#JG2QDI:V\/`````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O8F4N<&YG````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(P-#,@,3`U,34T,S0Q-#4@,#(S,#$Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____.SH[:&=H'R`@.CL['R`?45))
M9F=>#`T"$!$&QLT`L[D#R=`%O\43N+X5X>@FPL<J[/(U[_4Z]OQ&TM=#QLP`
MRLP`Q\T!QLP!R,X#R\X#RLP#R<P%M;H%R]$'Q\T)SM0*T=0*M+D)N;X*T-8-
MTM@0UML4V=L4V-X8S](8V^$=W^0ATM0?RL\?Y>LKZ>XO\_@^]?I"^?Y*^O]/
M^OY0]?E0Y>A9S<X-#`P!X^0A[NXOX>$X%!0*&!@-(R,9.3DP<G)J,#`O04%`
MR,(*R\81T\X<W-@JY^(X\.M&XMY)]O%0[>E2].]5P30>R#\JTTTXW5M&P5)`
MYF=3T5]-Z6Y:W6E7Y6]=EBTDGC,JH#4LISDOJ3LQVTY!K#TSKC\UL4$VM$(X
MN48[MT0ZODD^NT<]P$I`XEI.Q4]$YU]2RU1(T%=,U%M0Z&18V5Y3Z&9:ZVA<
MX&18W6)7YV=<Y6=<Y&9;S3@NUD4[MT$ZX%-)OD8^RU%(YU]5V5Q3Z&1;XV-:
M9F5E:FIJ965E9&1D7EY>65E95U=74%!02$A(1D9&.#@X,C(R*BHJ)R<G(2$A
M&1D9&!@8$A(2$1$1#0T-"@H*"0D)!04%`P,#____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````7[\VP`````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"\241!5!C3;8PQ#D%!%$7GO7DSDWPJ42A_
MJ2!1:"16H+`/:E$(O[$`(A)[D:@UUJ"2"(4$B9CY\V<\-3>YS<FY5XB?`'<Q
M[K[4[>F:2?U<-DL48N5G^^/]924`)%H)%&OG(/J210.`6EE&KLBH$TX/HP&D
M#I[1Z#V7L9JC48`8K&.4R=TD7*BF"!#R/#*2U%L<*H;H*WG_'=*6J*7U^808
M0\%?)&1?#1)J7(%)]#ZP-57#33N%-(40V(KB3S[0SD<@-P'/S@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B9BYP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`R-2`Q,#4Q-30S-#$T-2`P
M,C,P,3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____]9V@`6@`!7`$#7`,#6P,%7@4%704'8`<)7PD-90T-8PT0:!`291(4
M:Q08:A@=<QTA=R$?<!\;6!LF>28G=B<B8B,A7R$O@R\F9R8H:2@UB#4K;RPJ
M:RHM<"TN<BXP=#`^DSXZBCHS>#,X@S@T>C1"DT(Z@CI&ED9"BD)*F4I-G$U&
MCD9)DTE(D4A/G$],E4Q0G%!.F$Y1G5%0FE!0F%!DJ60,9PHP?"\R=S$V?#4_
MA3XRA"LK:R`.5``160,66@DZ<#!`>#9.C4),AD!1BD9;F$];EE!HGEYOHV4J
M>AA!AB]YIPV>P!W4GQ#%?P70/R&V%@#,&P?)#0"X#`6_'QC>.C70/CC#.C3J
M34;42$*Y/SOM5U#E5$[E75?P;VK'``!]``!\``#(`0''`0'*`P/(`P/+!07(
M!07("0G."@K0#0W)#0V("@K3$!#.$A+9%!38&!C.&!B0$1'<'1W@(2'/'Q^:
M&1GF)B;3)R?E*RNF(2'I+R_;+R_M-37S.CJN*BK=.#CS/C[U0D*X,C+@/S[X
M1D;B04']2DK#.SOZ34WK24GH2$CZ3T_Q3$S\4%#\45'W45'V4%#31D;P4%#R
M5U?U7E[E65GX9&3S967[:FK___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``"9O1WL`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*Y)
M1$%4&--MP<U-PT`0!M!O=R<S=BQ;.!&=4$Y..>:4KBB)`E`$$A`K1EGV?R@`
MW@/^,#B:Q]V</V\^B$C?]6<+,X\/9;W_!":6C3A8#.->_>JS(V86BK"8]J=R
M\W%96#;,-<'@0!J;UJ:6G3.U/1.N6J)K9C3YVYE6%82O\.8#GH;ULNU2VKV"
MH-N0E%]XZKLZO5\J",M'JD1.6#3>2VFPN*9LB600E^;<2L$_?@$,RE(.(86X
MZP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V)G+G!N9P``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,#$W(#$P-3$U-#,T,30U(#`R,S`Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___\;'Q\G.R,3)P^[S[<_3SN'E
MX*NNJO7X]#R"(,+'P,/(P>'FWR%O`"%K`"-Q`R5O!25N!2AS"2UY#3!Y$#9Z
M&#R''4&((4Z7+U.8-4F$,%.1.$^,-F"F0EN:0%R80F">1E&$.VNN3VRL4&NK
M4&FF3G"K5W>R7GVT98*X:D&$(#]L*4Z'-&2F1F2C16.92'.O57BR6V:63]38
MTO;Z]//W\>;JY.3HXH6'A"]S##%T#S5X$SU\'5*2,5>0.7*I5G6J68J\<"]G
M`45\&$^`)U:+*TUW+&B;/EZ*.G6F36V:2(:P9#!H`3AO"CEN#56`,6^<27BG
M4<`+`,`-`\41!\0<$L\>%-PP)K`N)M(X+[LU+>I#.L8[,]9'/O-32NA53/-:
M4>A94-0Y-<P"`,L$`,P'`]`'!<P(!<L-"=01#=@3$-(;&-\A'>0C(=,C'Z8=
M&[`B(>TS+[$F([PJ*/(W-;TL*L<P+LDS,.$Z.-(V-/E&0OQ)1N5$0NE)1OY2
M3_Y24/903OA34/[^_OS\_/KZ^OGY^??W]_;V]O+R\N[N[N?GY^3DY.'AX=C8
MV-;6UM34U-+2TM#0T,[.SLW-S<S,S+N[NYV=G924E']_?____P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````?P)V4````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````J$E$0508TVW!RQ$!41`%T/NZFS?^JB@"
ML+6P\(U)#)9*#+*2!,L9"F.*U]T"X!S@1\`1MO5#302:3#^^$\!];\P,4[>T
MVP/89+&QKDNKS?-.;;%<(6`:>VYF3L7@1J%[/0E*>SS?24FX&-XI[X`0K<HU
M!:8@S_#1'(*)OV>/9BB)*/,JOLZ"496L3]04)K>V-2`8WU-BX1@E)%55$$I5
M8I(ZDU[,W?''%XQF4"(+QP!G`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O87(N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q-#4@
M,#(S,#(S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____U=35Q\;'_O[_[>WNZ^OLU]?8S<W.R\O,^_S]]O?XV-G:P,'"I*:G
M_/[_^_W^^OS][_'R[O#Q(J+,%65_(Z/,):3.)J;0)J3,**3,&69_*J7-*Z;.
M+*C0+ZW6+:7,,;#8+Z;--*[6-['8-ZS2)WF4/KGA0;SD/J_4/:[20[KA1[[D
M0['4.)*P,X.=-XNG4,?N0)Z\5,SR/Y>S5<GN2*C'6LSR5+_A1Z&_4+343[+2
M3JW,8=7Z3ZW,3ZS*9-?\6<#A2J"[-W>+5;;45++17<7G7<3E9M;Z:MG\7;_>
M;=O_;=O^:=3V5JO';-;Y9LKJ6K+/8+[;<MS_<MS^<=?Y;LWK9;S8>-KZ=M;V
M;\OH69VR?MKW7J.Y?]OX<<+<9ZW$A^'_@]KU;[?/B^/_@=+L@]3N?,??CN/^
MC>'[DN/]B]GRC=GQB]+IF>7]\?3UY.?H3+'-3+#,4;'.V=S<T=34S,_/W=_?
M^OO[U-75S,W-V-O:N+NOP\6\K*Z3V]W"Q\BWM+5OIZ45@'\>I:0MGYY2S,S*
MY^?FS,S+A8,'H)Y6X^'9Z>CE^/?W_O[^_/S\^OKZ^?GY]O;V\O+RZNKJY>7E
MX>'ATM+2S<W-S,S,RLK*____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/)+[#P````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!
M241!5`C78V#``J2E]?T2(QVU%*3D5'3,/4.`0J)J3C$1;IHR8N+RZH:VWOY`
M(>?HW+S4\.*B0BNOL+B4S#2@$%\IOW!)66U=375!OH"@4#E0B)EQTK3I;:V=
MS=V3^_LF39T.%.J=T%XYHZ.KJ:5G`N/$*4RS@$)<;.P<G%4-C?7<+!6L/#-Y
M@4(Y\8%V-JY!44D96=GIR0FQ0"$+54D1"44-8P<?7W=K,R,]H)"NDI2LLK:I
M1W!H@(N]I8D!-N\``-+-,(\O#,.9`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]B:"YP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C`R-B`Q,#4Q-30S-#$T-2`P,C,P,34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____0-3;=.3K$P\2)B(FDI*7Z
M^_SQ\_/EY^?BY.3*S,S'R<G3U-30T=&XN;F:FYO'``#'`0#(`0''`0'(`P/(
M!`3&!`3+!07*!07(!07&!07,!P?("0G."@K.#`S0#0W3$!#)#P_6%!39&!C8
M&!C6&!C.&!C<'1W;'1W@(2'?(2'?(R.D&QOB)B;/(R/()27E*RNL(2'I+R^O
M(R.V)B;J,C+'*RNX*"CM-37L-36[*BJ^+"S#+B[`+2W',##O.CK),C'&,##1
M-C7.-#3+,S/S/C[*-#3V0D+U0D+5.CK3.SOX1D;W1D;</S[;/S[</S_A0D+Y
M2DKF1D;Z34WE1D;J24G[3T_Z3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#T4%#V
M45'334W,3T_'34WR<W/*;F[B?'S';6W'=771?7W'?'SHG)S-BHK8DY/[P<'U
MO;W&N;G&NKK=T='/Q,3)P,#X[N[SZNK)PL+MY^?#OK[[^OKU]/3Z^OKU]?7N
M[N[HZ.C>WM[8V-C2TM+-S<W(R,BNKJZ0D)!]?7U\?'S___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!1#B);`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```*])1$%4&--MS#L.PC`0!-#=C;_Y$*34
M=)1T'(#[(-%#00VGH*7F+)P!B9HH-HX3&X<6IGR:&8"?()SQM.W,9=E:J77=
M5%<""'%$6AG+E-3S4@#!,?9Q\*TES753")L(SR&CAPM)ZE*/[T1AAWU<#)*K
MLE+1F$3[C-#?HU2J+H2[A6E(&4.GF6H*;;I-GX@H.%K+/!WUSH\.6")$_Q3?
MHR[9U,)#QG@^R[E]^3!X^),/WMA#=.[*F=$`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)I+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30U
M(#`R,S`Q,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___]+`P??L[N[BY<S+S-/8V-C;V\G,S./DY+*SL]+5U,O0SL',Q/#Y
M\JF^J,O8RN;SY=WLVC!X($J+.*_!JCR`)V2D4-#FR9JAF#MO*DZ+.F:H4&BI
M46>G46:C4'RT:'&=8N#OVSQS)D)R,&NK46VF5GB>:9*X@XRBA+G5KFET91Q'
M"4^-,T1[+4Z&-V.?27"G67.D7I/$?I3#@'ZB;[G8JQ]-"CAH(49\+$N",%"(
M-%**-EN5/E^90E.%.V.=1F.>2&FE3&NG3E^21G.L5W:O7'FQ7G^U9'^S982Y
M:HR]=&!W5:C`G4V$,5Z90("C;L_2R.WLY<7#P,S'Q./9U*MQ6+5[9;AY9-NF
ME,.HG\*EG=A_<LW&Q<):3][.S-`/!>$H'<XK(>-#..I01M1)/_9?5_YJ8>]S
M:N%P:ON">LQI8^)X<LUW<OF:E=&0C-/!P/[O[LP'`,P4#-85#^XW+^$^..=(
M0^1'0M!%/_923LI&0/E74,964LQW<[^(AO&XMOW+R=ZTLMBUM,P&!=80#=@3
M$-@4$-(8&-4X-?I&0O]23_]J:IUS<LRLK,NZNMO9V?S\_/KZ^O7U]?+R\NSL
M[.OKZ^CHZ,_/S\W-S<S,S,?'Q[N[NW]_?____P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'7(26@````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MP4E$050(UV-@P`*TY_;6]J25=;04);15-$Q4`@KI^,QASBM/S<U.*LEDF63F
M!A0RE](0G-H<&Q5=T#1-R$3.`"ADX:*@YCN#(RR<?;J6JJR3+5#(WLM5)&#6
M+!XVSBG>,LYVUD`A3W=_8<7^N)#XF"!C<0<;*Z"0AZ.8/G]P1&!H))^$H;2?
M)5!(7M>4ES5_PO3)A8U3!-3UE(%"1J*S^BK;DS.RTJMRF&9KJ@"%N&?6%;<F
MEG9UUZ1T5M=S26+S#@#@P3+2':O9L@````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O870N<&YG````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#4@,#(S,#,R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____SB0ES,3%XMO<I)^@^O7V
MQLK*]_KZ\?3TW^+BV][>T];6T-/3S]+2SM'1S=#0RLW-R,O+Q\K*^_W]^OS\
M]??W]/;VZ>OKY>?GXN3DX>/CW=_?T-+2Q\G)Q,;&]?;V[/#OQLG(SLG(\^[M
MR```QP``Q@``?0``?```R0,#R`,#RP4%R@4%R`4%QP4%R`D)T0T-T`T-TQ`0
MSA@8S1@8D!$1W!T=QQP<X"$AWR$ATB`?R!T=SQ\?FAD9I!L;QR,CQB4ER2<G
MK"$AZB\OZ2\OS"DIKR,CB1P<N"@H[34U[#4UNRHJV#(RPRXNQS`PRC(RWC@X
MW3@XUC8VT38USC0T]D)"]4)"N#(R^$9&]T9&XD%!X4)"Y45$TS\_YD9&PSL[
M^T]/^D]/XD='^U!0^E!0\4Y.]5!0MC\_KCP\\U96V$U,\E=7P$=&[UE9]5Y>
MRTY.^F1DZE]?Z%Y>VUI9^6AH\V5E]VAH^VIJ[FAH^&YN[FQLY6QL^'AXUL[.
MQ\#`QK^_V-'1V=/3RL3$R</#R,+"Q\'!^?/S^/+R[^GI[NCH[>?GW-;6T\[.
MR<3$^O7UZN7EZ./CY>#@OKJZ]O+RU='1T,S,____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````-_*GJ0````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``C0T[1(J<H),]-1T
MC"V](E-`0F819?G1M@9JVD;FKN%)Z4`AC\R:VN(X)PL;)M_8K,+R(J`0Z[3^
M[L;FAGKF.I;.]HZN'J"0O`BGC(`PNR`/ER*'**<T/U!(04R*3UA.B)=;0DQ4
M7%)6"2C$-K&WI:U5N6F22O^4"5/[)@.%JK,#'!W<@I/S2JLJ2PIR,X!"@:;Z
MZKK&5MY1J6DQH7Z>SD`A:P-5+4-SE[#$]/@0?Q]W>VS>`0!GWRYB%OGB*```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B:BYP;F<`````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`P-R`Q,#4Q-30S-#$T
M-2`P,C,P,38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___\Z>3L`7P``6@``.0``.``!80$!6@$#7`,#6P,%7@4%704%6`4'
M90<)7PD-90T-8@T0;A`*0PH291(28!(8:A@12Q$=>!T?<!\?;R`95!DG=2<G
M<"<A7"$J9BHX@S@X@C@R;S)!A4$[>#M(D$A0F%!&A490EU!7G5=7F5=>HEY9
MF%EDIV1HJFAEI65JK&IJJVHP?"\P>R]!B4!FIF5%@`--A`U;CQ]PH3A#>0#+
MS0#-T`?6V13BYB;O\SK<WS[Y_4KN\4SX_%'(QP#'QP#+R0')R0'(R`/+RP7)
MR`5&1@/+R@G.S@K0T`W3TQ#8V!C2T!C<VQW@X"'EYBOIZ2_M[37S\S[U]4+X
M^$;Z^DWJZDGZ^D_[^U#W]U'U]5!64A1A7B%N:R],1PK?SR'LW37.P33WZ$;Q
MXT[.O`74PQ#ATT+ZZU#4&0W=*1WI.R_&.C#0/S;U3D+E4$;Z6D_T6E#=&!CF
M)B:D&QOG*RNL(2&O(R.V)B:X*"CP-36[*BJ^+"S#+B[`+2WQ.CK',##),C'1
M-C7.-#3+,S/S/C[Z0D+5.CKY1D;;/S[A0D+Y2DKF1D;Z34WJ24G\3T_Z4%#N
M3$SQ3D[X45'U4%#V45'___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#):G^#`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`*!)1$%4&--MP<UQPC`0!M!O_R1C0L"'S-`$-$TC*28SN67"(4:[DJ44`.\!
M3PA&']_7.)Z]:E(1O3%HR9?JHX:8,`N#<9CF'C%"C)F9&Q3[B>/]=_S12L0\
M.A1I+OY3]$I!;$WJIV)9]W=?%R43IMX-BA+WA^MY)Z=I<H\*AA^*M[S1G%*K
MV]:@B*\262GO;'A$ZV"X%[-$;UFC;+UWO/`/"H)++*YKQ:,`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V%U+G!N9P``````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30U(#`R,S`R-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___]=15/)L;?F8F<Q+4+(N
M.7XA*+HT/G<T.<II<+558["3J%@Z4(]GBY)GC\ZTS'-!=YE[GL^VVG)DAK"E
MP%Y(AL*TVZ&5NEA3;(9XP61>AE-'F(Z&PFQDIG-LJI^9TA0)?RPDCG)MP(B$
MR;JYQA$+@S0ODW5QQW1QPY.0U`P+AA02B144CQ\>D"$@EB4DFR\NE4=&JT)!
MGU!/O$I)J554P554O%=6O$=&ED]-GU!/G&)@LI^>S0$"@P8(AP8&A`<'AP@(
MA0D)APL,APT/C@X/BPX/B!`0AQ(3CQ(2CAH:F!H:E1P=DQT=ER$BG"<GGR<G
MGB4EE"4ED!\?=BPLHS`PIR\PHC$QIS$QIB4E?28G?S4UJRHJAS@YK3(RG"LK
MA3HZKS`PC3]`M30UE#(RCS$RC#\_LS<WFC8VED)"M#P]I41$MCX_H3L[F4E)
MNTA(N49&M#T]G$%!HDQ,O$U-O4]/OT]0ODI*L%%2P$Q-LU)2P%!1NDU-LE-3
MOU55P5-4O4U-L%%1MU96P597P%A8PU96OU55O515N%!0K5)2KU]?PE-4HVAH
MQV=HQ&UMR,K*RPP0BB(FBSP^FE]APS-$J^MU<L1.3O!D8_AG9ZY/3I1+2NA[
M>[MK:^>-C/___P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````*E@/"(````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)X):6GBPO83M5V
M<-:7+<RO!PIQSI[+S#*/BUO-WBM0V:2R`2C$/FO.S&FL'&R*KGYAR:5:*D`A
M$1[A&:)"8I/<?"*SRNHT;8!"?!I23#+!_(*ZX0K=U19=&4"AOBE&2AYV$]4-
MXOI;S1N-4X!"O;7%D]V=W+PC<LK:JG(SDX!"'?'R$ZP<?4+3RUN:3/-2$X!"
MV7IRJCV>`8DES36=$I:Q44"A(!<=0U__F`*S]HHBZ[3H$&S>`0#YH3(958(&
MB@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V$N<&YG````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q
M-#4@,#(S,#`T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____U=74]O/RY.#?RKNXTKBST\/`SAT%RB0,T"0-URD1TBX8X30=
MW40OQ#\MLCHJS40Q_V1/\F!,^V51U%=&UF=6R&)4S')FSG1H_9&"SGALY(^#
MX)B.QHJ!_K.I_K2J_KFO][:MS9F2S)V6_,_)S*NF?PP`S!L$S!@%RAP%S1X)
MUB0-BQ<*E"`1XC<ATS,ARS4EL#`A[D,OLC(CIRXAN38FO#DHP3PLRD$PX4DX
MTD4TU4@V]U(_X%`^_%A&Y55"[EM)[%M(^6)0\6!0RUA)^G!>]&]@_7-D^'1E
M_WMJSV58S'%EVH!U[IF.U(A^^*6:RH9]THN#X9F0[J6<\:RC^;2L_;BO_\?`
M_,K$],W(^M/.S;&NRA(`?PH`SA0#WB88U"\?IR@;ZSHK^D]"QT@[_E]0YU9+
MYVE?U(R%S0X!S!`%SQP2V#$G\CXUQS<NSSPS^DQ"VD,ZNSHRYTI`ZD]&_U9-
M_5I1]E=.]F!7Z6%9_,_,\L[,W,S+S`D`G1T9\CHUOS`J_V]HTL/#_OKZV-75
M_?S\[.OKY^;F^_O[^OKZ^?GY]O;V\O+R[N[NZ^OKZNKJY>7EX>'AWM[>V-C8
MUM;6T='1T-#0S,S,____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````84'20````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``#!241!5`C78V#``N+4Z^48>R:QJ<R8/D6FP3X-**2N5ZS4U<'N:J@V=9)?
MH9`S4$A7H"J\?4J,1E;FY/Z`,A%'H)"I:%-HK;<X)Y=81I1"N;`=4"C5JS*X
M63.6@UL_+U*QPL$:*.3I5N+/JA6OPVN<HAI6:F,)%/)PRI6>H6R0D&PKWQE2
M)&@!%'+ARY&8,<TWW5VJK5>V@-\,*&3%D^TSO96EIKJ%>6)0OKD14"A1NTYR
MZJ2^Z(CN"4R!C29)V+P#`-B7,:@;#L3E`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]A=RYP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`S-B`Q,#4Q-30S-#$T-2`P,C,P,S0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^J04/Z@8/GBX^)7%]^
M4%:]GZG)K[UA76F[Q-:URN)(7&Z0IKEDH,EHI,QJH\MOJM-KI,I^M]]YL-6-
MQ>M]JLJ6S/"%L]2<T_B5QN>EV/NEUOFLVOJIUO2PVO=FH<=FHL=FH<9GH<=G
MHL=II,III,ELI\UKI<IJI,EJH\9QJ]%NJ,MQJ]!WL==VL-5RJ<UWL=5\MMMV
MK,]XKM%^MMIYKL^$O.&%O>&&ON&-Q>B/QNF5S.^7S?"%L]&<TO6.O]^=T_2B
MU_J/O]VCV/F4Q.*1P-VCU_B!JL2HV_R;R^FJW?ZIW/RGVOFFV/B?S^VDU?2C
MU/*GV/>5M<J1Q^:TX_]`:7]BD*>"N-.3QN&PY?]`;7^"Q=QOIK6@S-ANI;-V
MK;IUJ;:#N,:2QM.&M<&BU.&/N\:%K[FLW.BASMFKV>6UW^ESJ;1RJ+-]LKUI
MCI9\I:Z%KK=]I*RAS=:QX.JMVN-UJ;.)O<>%M;YRF:":S=>-N,"HV>*0MWBF
MR9*'L6J+M6Z*LVV5OGBBRH9_G&N*J'2RV):4LWV=O8:_Y*6NSY;$YZJ]WZ61
MM$Z2M$^6N529N5JAQ&"OT7".J%ZJR'&8LV:^WX&BO6^QS7S*Z8[+ZI+#WXS"
MWHZ[,C+I65GZ<7'___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!8`X;X`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+=)1$%4&--MP2U.0T$4!M#O_LW,
M(W5=``D>@4*P!D#1'9"*;@:'8`>H&CR")9"@@`1954(S?;S,W-L%P#G`'X2%
M/9;+EY/=QYSST>=I?B+,IOMENG[?51U*2C-9,WJCAQZU63;38A,45^W6;E[W
MD5*68KV!\<WEXNW7+2<QDSJ"<.SGS\V)F97)W3>$U4_J[L+$PM%IN%.<C<V#
MF52(>KA#\17JQ"3"Y!X>4$R^#1Z$1_)2*5?\XP"S`T>Z`@"F,P````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)M+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0Q(#$P-3$U-#,T
M,30U(#`R,S`Q-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___\```<$&"<L("=02$\<J*\<N+_)86O!?8.AA8^YE:/=K;,-7
M6.YT=>N-CGD<'[<^0<U)3;(P-X,R-JU'3?_6V.C"Q.&FK6,W/Z%H<IYK=FE,
M5+.(E:B"D(56<<FIP81UA+"CM<"NRV!"<T(?7%@]<92!J8=UIFUG?#(E8Y&2
MMJS9R$W0/H#H:'2Q2[KBH)2C3=?6Q=S9OM;)J=_+G^C>T)9G,]O.P-ZA?_+=
MT=1R3L%'-<$\,>UO9=-A7OJ!?NF(A<P``,T!`<P!`<T"`LX#`\P#`]`%!<P%
M!<<&!M$'!\T)"=0*"M8-#=8.#LX-#<<-#=@0$-85$\\2$ML4%-X8&-(8&.$=
M'>0A(=0@']0A(>$D).@F)J<;&^LK*]@G)[`A(>XO+[(C([DF)MTP+[PH*/(U
M-;\J*L0N+<$L+/4Z.LHP,.X[.^$X.-4V-=(T-/@^/OI"0M`[..`_/OQ&1OI'
M1_Y*2N1#0NI&1N%$1.Y)2>Q(2/]/3Y0P+OY04/9.3OI34?E04.5+2]Y(2/%0
M4/M;6N%95_UD9/MN;O)K:[M85N=O;;)85NF#@?___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+WTD4X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````NDE$050(UV-@P`(D931Y%2245+R</((BTTOK@4("==T\#CU";"YN_C&Y
M9;5-0"&1WKY.1WM185??%G%^L;9JH)"BK#*?MIR\*DLHEYFE%4<)4$A*0[U=
M34M:D#6RRUC'J+D`*,3-614=R,0<')%D9VIA4IP#%.JH20AP<?8-BR^TUC/0
MM\T""K6FAK@[>8?&9I<W&NJ:9Z8`A?+"/:$N:JBP84]+!`I%^3BY^44D%=4V
M5>;G9"3'8?,.`#2C+F>(M_ZD`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O8FXN<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q-#4@,#(S,#(P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____S%M=[I&2P18;W,K+
M9F%BDH^0_/#Y.SH[?WY_U=35_/K]U]78]?3VZ^OL'R`@S<[.P,@%XNLO[_A"
M*RP-]/M/\/A0P,,#Q<@%Q\D8U-8=X>,_S,X]Y>=&7V`CR\U/:6I"PL(`P+\`
MO[\`P<$#NKH#P\,%P<$%P<`)R<D-S,P0R<@2QL<8U=0=V-@AR<D?XN(OW-PO
MYN8UO+LP>7D?[.T^U]<XUM8XS,LUEI8H[^]"\?%&CX\JU=5`OKX[\_--X^1)
M]/1/\_-0\/!1[NY0[.Q0Z^M7U]=19&0G>WHR]?5JVMIDG)Q(Z^MVW]]S]O:7
M]?2?:6EE?'QX/S\^04%`6UM:O;D`1D4;]?3+T<D0P;00^?2N1T4TGI).[^K8
MT,['O8H`7UI,N;>QFFL'VYTAZ[50WI0U[)A&XM_<JZBF5U54G)J9PWU>I)6.
MO$,5/A`!U$HZJ5]76`D!PC,FT&!5N%U4EE--8P\*<1X8AT(^[+NXGV]MFFYL
M7@``Q`<'KQ<4+0@((0D)D2LKX4I*DS@WVUQ9.1H:IE%1DU13[9N;R(V,XZBG
MXMS<[.CHDI"0X^'A^?GYZNKJZ>GIS\_/RLK*LK*RHJ*BBXN+:FIJ7EY>,S,S
M+BXN+2TM*RLK*"@H(2$A____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````$`&-+P````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``KQ,K>R]W2VD
MA%34M?6-;9R!0ES]R9&!_K+1B1):>H;63JY`H1G3)O/P\PKFYBO8R9@YN#@"
MA=BF9_:Q3NEFJ6?JC8\)\/,`"G'.#,MNK:DM*^VI[N+@FY``%`J:%2K05-?8
MWIG7QCQQ$O=4H)"/KZ=H07%%97-5>5$P>TX64,C-2$<M/*6AI+"E(RED]MQY
M0"%S70TER:C4](RT.,78.?,7`(4,-)55M:2%1<3$Y2Q-;.4CL'D'`.B&,GKR
MN]7^`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B;RYP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`Q-R`Q,#4Q-30S
M-#$T-2`P,C,P,C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___\`7```60`#7@,%704%7`4)80D-9PT09Q`8:1@==1T?<1\A
M=B$;6ALB9",A7R$OAB\J;2HH:"@UB#4N<2XP=3`X@C@T>31"E4)&ED9"B4)&
MD$9/GD]0G%!.ETY>=UXV?C4D;P`F<`,K=0<S>!(ZA15*D"<_=29-C2]'?BU.
MAS-:E3YLL$MII4QOKU%LIU!>H#I@<D9A;42$C4=U>"[)RP''R@')RPW3U2>]
MORS5V#KHZDCW^E'X^F3(QP;-S0G2TAC4U2#*RC#)RC'AX3C2TC35U#;GYT#\
M_$;EY4+'QCOJZD;__T_X]TWJZTG^_E#V]D[Y^5#V]E?Z^EYP;RKX]V7__VK*
MQ0;/RA+3SAKHY";U[CK^]TKR[$SQZU#4ST;$O`"GH2'=U2_CVC;@V3[]]E'_
M^&B@D@J0A!*BD`WFTD.VIT.4=0:HCRV89S9]0`;-)@',(P'4)PK[:5'.*`V+
M'`K>,QCK12O8/R>R/2KX5S[_94WN8$GL7TCI;5G]>63,``!_``#.`P/0!07,
M!07-"0G6#0W8$!#2&!B4$1'A'1WD(2'4'Q^=&1GN+R_R-37A.#CZ0D*[,C+\
M1D;G04'&.SO_3T_^4%#Y4%#V5U?Z7E[W967_:FK___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!W1@)Y`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```*A)1$%4&--MP4M.`E$0!=!;'WB@#!RX`A9@G+LAU^$>29CHQ!C;1(+8
M=/?#KEO/!>@YP!^")VQ6A5.-,'=W?U1@M5CF'`PU,S6!XUP'R3G8U,6DKN'X
MS%)];#=R$I%U+7!\;/KOR+ONY6%\*^=+0''-@6UKSP<IKC,)1=>=QFGW8[=\
M_>*1$P3WE\BF*E>A+5O+O>.]#ZI[Z5V"3$(Q,,34%P8NDY'XQR\FXUF]#$?9
MMP````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+V%Z+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#(V(#$P-3$U-#,T,30U(#`R,S`S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/____KU]C$YOCU#N1LF
ML2,MM28RM1LB>D-.T#M#GU5@WF-NYEYGUUUFUF=QY&MSU7>`Z!PPO``GS``8
M?P,JS@4LT`4LS`DMS0TTUA`WV!@\TA$JE!U"X2%'Y!]!U!DRG2]4[C59\CA8
MX4)F^C)-NT9I_$%@YSI6QT]Q_U!R_E!P^5=U]EY\^F6!]VJ&_P!>``!<``->
M`P5B!05A!0EA"0UG#1!L$!AN&!UU'2%X(1]Q'QM:&R%B(2)D(R^&+RAL*"IM
M*C6)-2YU+C!U,#B&.#1]-$*50D:91D*-0D:01E"@4$^>3TZ;3E"<4#9^-4Z%
M.3UP(6"*/RA4`"M6!%)S-'"343A@$T1C)U)W,$MK+5^"/VV032]5!VZ12G.4
M4?+?V,AN4L^OI<ROILDQ!<`P!L,]%L8\%]-%'<U((L]+)\Y4,-YB/KI2-,97
M.-!=/,19.=)D0^)J2?IY4N)L2L1>0>!K2^5O3^1R4/)Y5N1S4>QU5/%\6O*`
M7O.):_R0<<5Q6/J/<=9\8O:5>N.LG,NRJ]M-*,U5.=!</_1U5,IF3.YZ7_6$
M9_.);?J5>L\O#<`['LI*+YM`+.1G2]AD2])E3.]T6.1S6<%?2^-V7<AH4O*+
M=.Z\LL%I6\*.B/___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````)DS:D(````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````KTE$0508TVW!2T["4!0&X/\\
M>FVP'9@0PH`8949<FJMP"RS!11D',&*"DQ+L`VC/.=<%R/<!_Q#FJ,H'OUS-
M1%55OQ@HBQ23N;&(L!`4W9#(!WELR1.3!`C;DJ)Y2KDER=)7\:XXS.+DNQ!=
M[5Y_T\\$QK+N(]:;M^?E9[V(>8;B;#?+T_ZEZS\:&X\9BF\)S]>NX8H\CT5`
M<6K-1*5,-S9W=S`&=Q8N"A5/$9%QQQ^O>E4'PA3+LP````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8V8N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S0@,3`U,34T
M,S0Q-#4@,#(S,#$S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____QTM-P517A0<B?@`>BR0_F#A3__[_?'N`Z>COX>#G!052
M!`0M"`@T$!!9(2%H)R=N-35Z.CI^1D:)3$R.4%"065F75U>465F6:FJC:FJA
MG)RGT]/=YN;LV=G?V-C>ZNKO.SQN9F>>$AAB0TJ(T]3:P<G0Q,O1NLG#X.OF
M[/+M"6823)Q2`5H!`58!#5X-&&89)W$G+G8O*VLL.GTZ39I-/7D]2(U(28Y)
M0X%#49E13H].4Y-37:-=7J!>9*1D:JAJPL?"Y^SGUMO6Q,C$[_/OY^OGTM;2
MNKVZ"F@',G,Q<JMQ5J)1"UT`#EX#+FDF59A,69I0'6@2.7XO-G(M/'HS2(@^
M\O7QO\\0X.M.LKH`MKX%M+L%N\(8GJ,AJ:\HM+HNO\0TS-(XT=="S,H`S<L#
MS,H)U=0-X.$=U-,?6%@-IZ4;LK$COKTJRL@PU-0UZ>I&9F8L24DT8F);X.#?
MUVPAZWTO]HU0\XI0BCH4?2L*?"P*O6A*JU$UL%H^S```QP$`R0$!QP$!S`4%
MRP4%S`<'S0D)U@T-TQ`0WA@8TA@8X1T=Z"8FZRLK[34U]3HZ]4)"^$9&^D]/
MP4].V%U=RE=7VV1BW=S<_O[^_?W]]?7U\O+R\?'QZ.CHU-34S\_/IZ>G____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````UIK!/`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"U241!5!C3;<'!30)A$`;0;[X9W,5D)6LTF&A#-L&=4(4)-X_&`CAZ
M\VX+-F`!9J,<A,0`R_XS0P'Z'O"'H)E5K[W_+/N'2H7D-R$U#W63I>0-555A
M&%ZD<O/"L.O/O!((5C%_'NK=>C09>P@_'@7WD_7HV"VV=O$DM^+R9M"O81/:
M-=IIVX<[B-_]SH-"RMB/A]9AN&26+*&,J9UEWKT;VB%#O)"E.8_,A*&R$(I0
M<IJ9F?C'"5C=4/::?HW0`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]C9RYP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`T,2`Q,#4Q-30S-#$T-2`P,C,P,3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____0-38`?0``?``%
MR`4)QPD-R0T*B`H2RA(8SA@8S1@1D!$?T"`?SQ\9FADGTR<AI"$PV"\JKBHX
MW3@XW#@RN#)!XD!!XD$ZPSL[PSM(Z$A&T490[E!0[5!7\E=>]EY>]5Y9Y5ED
M^61D^&1F]&5H^FAE\V5J^VIJ^FI%QP!&QP%'Q@-)QP5+QPE.R0U2RA)7S1A<
MT!_L\C7O]3K;X1W;W1W?Y"'BZ";BY";EZROEYROI[B_IZR_M[S7S^#[U^D+X
M_$;'QP#&Q@#(R`''QP'(R`/&Q@/+RP7*R@7'QP7,S`?(QPG.S@K0T0W0T`W6
MTQ#3U!#3TQ#6UQ36UA39VAC8V!C<VQW?X"'@X"',QP#+Q@#-R`'-R`//R@70
MS`?3S@K4T`WIIR_LJS7OKCKUM$+WMT;YN4KZO%#SL#[ZNDWZNT^C&QNL(2&N
M(R.U)B:X*"BZ*BJ]+"S#+B[`+2W),C'&,##.-#3+,S/0-C7U1$+5.CKW24;;
M/S[A0D+Y3$KZ3TWE1D;J24GZ3T_Z44_Z4%#Z4E#N3$SQ3D[X45'X4E'W4U'T
M4%#T45#V45'___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"XZ)A$`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+I)1$%4&!EES\L2P3`8AN&T
MHFGKO"!:ICK(,,7&K;D%%^'^Q,J,PU#)G[2)6/N6S[R;#Z&_>:CAM>*>*#^:
M96%T::Q./O)"TI6@*C9-"/<+AGR$2;O6$EB:ED[RTE$4826`T<G[#.N\TC_J
M@(`EG;ZPVL^,4(Y:4LK%,'UROL\".%J$D5$P']%'B'<T?JM#Y2HE\O'P'IR+
M402ZMK6KQ"P9W$*^'0=6J*HVKLHF_6N3;R@AH*TQ]N^-@R\MK$^\.2-(*P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)R+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U
M-#,T,30U(#`R,S`R-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___UAXI@$P:P$O:@LX<294CR91B#IIGC18@F.-O%V%L0H]
M<2%1A%F'M@0Y;"%2@")/>$5FA%YYD0]#;1!";!)'<Q-(=BM5>2Q5>3-8>$%N
ME%%^HQU3?252=2Q=@TYYFF2#FSIY.P!:``!2```Y```X``-<`P5;!0E?"0U@
M#0I#"A!D$!AJ&!%+$2%X(1]P'QE4&1M8&R)B(R%?(29F)B]]+R%8(2AI*#6(
M-2IK*BMK+#!T,"YO+BUK+2IC*CB#.#1U-$*20C)N,D:71DF224^<3U"=4%":
M4%"74%&745>;5V2C9&JI:F6A93!W+S9W-3^"/EJ768JHB0I?!2-T'56=31UI
M$E*21HVGB$-^,WR6=7.L7E^11D6('3-V!72I3*O`F7:H2'&B.'FG0K+#G9W%
M9&V5,5:*`&R%/7N439.^/GV=.Y*Z+W"6`XVJ-'6+-;;34*2]/G>*+:G%09.E
M2L+99<SA:+W->H&1,I>E2L+0>*"V#9ZQ,+;%6*N_$*:T09BE&K3#)];C3M;E
M4:*L'+*[,<3-.L+)&-SB2+_%0L+%`,?*!>+F*_+U0O;Y:L[.#=35(.'A.-74
M-N?F0/[^2N#A0NKI1N[N2?[]3_W]4/;U3NWN3?;V4/'Q4/;V5_CW7O___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-"+P/`````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````P4E$050(UV-@P`)4U0R5?+V3.WHR0G3T+5W<@4)J>LY^,25ME<6M
M-7%F3FX>0"%M^Z"TSE)1%F:>K-[L,"]7H)!Y;/F\+DE!.0D!]KJI+0F!0*&<
M_OF3JCBEA(05F2)GS9Z6#Q0J6S!E8@&KB)B\-'?JW.F3:X%"/DE-$QKYQ645
M9+@J9K2G6P.%//W#\[HS>=DX^!+G%$79F0*%''0U5.+K&Z*#JYM3'&TM3(!"
M!IK*ZEJAN7TS"R,";*R,C;!Y!P!]ZS)VH@;*#0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O8V@N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P,S0@,3`U,34T,S0Q-#4@,#(S,#$U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%U=35Q\;'P<+"LK.SU-74
MX.#?W=W<S<W,R\;%X][=^N_M\.GHQGEQR\/"L14'M1L-LAH-J!D,MQX0M1X0
MLQX1O"$3M1\2J1X1OB,5PR88O"<9N"89OBH=K2D=N"XANB\CQS8HR#8IP#0G
MSCLMP#8JA2DATD(UST(UN#PQV4D[N#\TUDH^N4$VI#PRSTQ`N40ZK$$WXU9)
MSDU"P4D^QTQ!ND@]RTY#P$H_T5%&LT8\W5E-S51(V5E-O4U#HT,ZZF)5T%=,
MR%-)WUY2U5M/MDU#W%U2UUM0Y&-7VUY3ZV9:RUA.YF19WV)7P55,PE=-UV%6
MQUE0WV5:O%5,Y&==WF9;NE9,ZFYCX6MAV&E?T65<Y7)GZWAMR69=SVIAYWEN
MZWUSXWIPZH-Z[HJ![(F`[8V%ZZ2=RY^;Q9N7QIV9]<3`QZ"<^=#,[^/BM1$'
MY5I1^/?W_____O[^_?W]_/S\^_O[^OKZ^?GY]?7U\O+R\?'Q[N[N[.SLZ^OK
MZ.CHY>7EX>'AWM[>V-C8UM;6U-34TM+2T='1T-#0SL[.S<W-S,S,RLK*Q,3$
MO+R\N;FYLK*RL+"PIZ>GE)24BXN+?W]_````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````?B0L[P````EP2%ES
M````2````$@`1LEK/@```,))1$%4"-=CF((!&*9,GJSJ$A]N)B\B(":CK%=<
M"!*::!<79>&7D:XCJJAI4U`&%)K4%QOMIA34V>$KJ6;H4U(%%)K0G!!H(A?*
MWAJC;F4?4L$*%&(LB#!*X^5H:^3DSO3TKVL!"N67.JID=;8WU5>59GM[,70!
MA8JJ-:2U3'D::E*3$CULV9F`0I5LLL)\N0&UY<EYKM:6W;U`H?H6<7XQB<@<
MKA0G!V.#GGZ@$$N'H)"4@K9[6+"SN;XN\P2@$`8``#&W4"6\4;%/`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B<RYP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q
M-30S-#$T-2`P,C,P,S(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\[.CMH9V@``P\#!0TA0;!.=/9D:'8`,,P#,\X)-\T-
M/-800-@)(6H%$#0=2^$A3N0?2M0O7.XH2KPU8/(N4<<T6-)";OI&</Q!:>="
M9^5/>/]0>/Y0>/DR/F,`-,<`,\8`*)L`%5,#.,X"&V,%.]`%.,L%.,@-0-$0
M0],81\X=3MLA4^`9.YT;/J0B1Z\O7^HU9>TJ3[LP5\8X8]TV7M%"</9&=?@Z
M7\=&;^9/>_M0??I0>O57?_)>B/I)9+-JC_MEAN,80ZP90ZTA2[,N6+Y!:<Q3
M>MIAAN)<?M1EB.`I4:\G3Z0]9+Y9?,A'8Z!.:ZI:>+EHBM-HA\H?(BD]8ZQ'
M;+D_6Y9NC]0?("`K+06FJ`KGZ4#4UD3Q\U!.3QKFZ%(6%@"#@@7)R@C$Q`[7
MUA">GPUN;0W<W1O>WAW-SAOCXB'M["_AXB[:VRWO[S7(R#"YNB[0T#32TC;$
MQ33W]T+M[D'Z^D;1TCSCXD+GYT;\_$_\_%#T\T[U]E#V]E#EYDSR\U3Q\E<P
M,"]!04`,"P,"`0$P+R]F965J:FID9&1>7EY965E75U=04%!(2$A&1D8X.#@J
M*BHG)R<A(2$8&!@2$A(1$1$-#0T*"@H)"0D%!07___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!JW/JU`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+])1$%4&--ESSTN1%$8!N#W_;[W'$<F49@I-$(QA27HK$*E56J)
MQ`)F"C9@(1*=0D2K4XA$*Z(0<>^=>WXL8)X=/,`:0GN322K=7^DWW$/4HY#/
M%[/RU@^5)@\R$+?#ZNIPJW8D25J[$\9Z<3V\YAU&?=O\O8"PI:3X1(]*@7FX
M,2RL>PZG\R!&>5E5"*9T]'7R8=I,WBH)0;_3L_V#D;WB6%M+$'S[<I</DO0Y
MRZW^@#B^GWKP$&4EUU;:R_H'_[(G06T@SG]Z`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V-I+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#(R(#$P-3$U-#,T,30U(#`R,S`Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___^;MYN_U[]SB
MW"B-(3:9+S:%,#J+-$6E/D28/E"N2D^D25>Q4%:M4":&'2)I&S*0*2AQ(2IT
M(RYY)B][*#Z?-3%]*C6"+3.`+#:$+D"<-SB',#N+,SR--#Z/-DRI0D*4.D>9
M/E"L1DZH1DJ=0D>3/TZB1E:Q35&F25BR3UFR4%6I3%JR45:L3EJQ45FO4%JQ
M4E2B3&*W6EZN5V2U7#J),=+8T<K0R<3*P_/Y\O7Z].SQZ^#EW\W-S,S%O]'*
MQ-C2S<_)Q.?AW'\V`,Q7`<Q:!LQ<"L]B$LQC%M5I&=%G&91)$M1L(-=R*-QY
M,+%D*N&`.=Q_.^:'0>N.2?"54=.#1_6:5_F@7NB66?ZI:OFF:,M4`,U6`\M6
M`\U<#<Q>#LM>#XM!"\]B$]1J()U1&M)M)*99(N%^.+ML,\9T.\9U._&24.N3
M4_RC9/RD9?ZG:/>A9?>C9OZN=,S%P-C1S,W&P>':U?;P[/[^_OS\_/KZ^OGY
M^?CX^/7U]?+R\N[N[NOKZ^CHZ.3DY.'AX=[>WMO;V]C8V-;6UM34U-+2TM'1
MT=#0T,[.SLW-S<S,S/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````.TN`GP````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````JTE$0508TVW+.PK"0!1`
MT3<O,^:#*11#M!'<@B"X`&NWY5YLW(=BJ0LP1%-:2""9]W&TU5L>N``_&=C`
MPJ5N.'"PO[:C/+D@0&+CYN0LB*+)8@<(<_ODL5BCI%F4N"Z0&Y12&SPPGU-T
M_"%K'S19PI98<C0=@858B.IV1LPF2"^!F+R?%D%XW4M?5F&\^T+U&(14A6X^
M$%$ES2H(H`BS?$D-(M,N,B]E$?C3&_!36Q"[ZR1=`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8G0N
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U
M,34T,S0Q-#4@,#(S,#(V`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____N+.UU-?;Q,G+T=35S='2J*^PV=K:HJ.?L:V=M*R-
MN;&3P[ZMQZ1%?5D`?%@`PXL!PHH"R8\%QX\*RI(-Q8\-B&,*SID8D&L1SYP?
MFG49W:@GTZ$GSITGI'XAV:<O[+@UKH@JWJXXW:TXN)$RXK-!PYL[PYP[Z+E(
MNY8^[L!0[;]0T*A&\L57\<57]<E>]<I>Y;Q9^<YD^,UD],ME^L]H\\IE^]!J
M^]%JMIQ>O*EYMZJ)S)`'R9,5Q)`6S9<<P8\;SI@?PY(?SITLOY,QX[)`UJA`
MZ+A(S*-#Q*)2N9A.T\JVMJ^@N[>NRI8KY\Z:N*N4\J],P5T-G89ZPZN?J)V8
M]X)0R+RWN&Q1N65)X<S%UL;!V<K%QSD0V$@AP$$?I#D;K$`AKT(CMD8FN$@H
MNTHJRE$OODTLP$XMQU$PR5,QYFI&S5\^V65%]'50Y712PV-(WWYAXG]DYHEM
M[9%XV(ARRH!KT89PZ9B"X)1]XY>"WY>#WIB%YZ&.TIF)V*"1Y*N:R)F+TS0-
MPTPNQTXPTE4US%(SUUDZ_'%/Z&E)_')0[X%D\H5HZX5KYI^.YZ>7P(^#K(9]
MJ9:1P3(1SU$T^F=&\FM.]F]0[HISHYZ=M9B3V;FSZMC7WM#0P<#`____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````:5\V&0````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``O@%I#4L]50DA(6<Y604@\*!0@*2JN:&:E(B
MCE:^\WT"2F<`A<25C$PT944%7;W\F.?-K2X`"LGKFNDHV-F+V?KSSIE969('
M%%*WT%=Q\.;BM@YEC>V/;I@*%#(U<'/1XIP\FXF%8T)M46X64,C8P].&?59D
M>A-;8T]71W8&4$C;G2<L9-+$^N*^NIB*]LP4H)`R7V#4E,*(JFG=T\O*6U*3
M@$).P0EQS?$UO9WY.6VM:<F)V+P#`#SE,>3<BIC^`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]C:RYP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S-#$T-2`P,C,P,38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^2.3JM?H!B
M042::G";@Y+.M\B5?8]20$^JFZF%;89Q4'>]K,%<4U^NH[1I5'^LI+C`M])F
M6Y"4BK]E7W\S)W5018<V+'A&/H9.1I.,AKHM)GDN)WHS+'\U+GXZ,X4X,GX]
M-H8]-H-"/(=)0I)(0HU(0HLZ-6].2)%?6:584Y!O:;1P:K-S;;=J9*=H8J-T
M;K9V<+AW<;EU;[9U;[5S;;%V<+6$?KMG8Y."?JV"?JQR;Y,I(W@N*'HO*7LP
M*GPP*GLP*WTR+'XS+8`R+'PT+G\V,((V,8$]-X=`.HM"/(Y-1Y512YE64)U:
M5*%"/G=>6*=@6ZA6499<5YY43Y!23HYD7ZM'1'I84Y1C7J=>69U?6IU<6)EK
M9K!I9*MN:;)D8*%O:K%M:*UR;;5H8Z1K9JAM:*IV<;AN::MW<KAV<;9W<K5T
M;[!E89A\>+MZ=K2%@;]D89",B,*!?K1\>:AX=:)J9XZ7E,:(A;)Y=IZ<F<F!
M?J9A7WR=FLB<F<0X-8!'1(Q85)YK::5J9Y]]>KN"@+F!?K6(AK=Q;Y1Y=YVD
MHLLM*WX\.X9J:9-;8:#-A7M_6E7-HIS+?'.F?WK?L*JN6%'5?G>G95_-?WC3
MAH"04T^Y;&>80#YF*BK___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!:7?W\`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"./EJ
M9PCQ"O8[R<BI)<;K&@.%6"9.F35U$C.KA%.H=4E=<0Y0:-[L"=,G3YO+)-98
MVA2NU]T.%!+E8I_)SR;0X-(2$I1B4F`%%.(0D9XCW,O-H]0<E9!EEEH&%+)H
M-1!7M.V1E.I(,C+7C^P""A6F:WK(VKM[^[7E9V?&:O<!A7*#E1WMW+Q\`ZLK
MDF/"BLJ!0M$JKK+.GCY:.H;UE7F6-@%`(75Y60<%5?^X#-.TFJK."`ULW@$`
M+)`QC7_:DP<`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V-L
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#(Q(#$P
M-3$U-#,T,30U(#`R,S`Q-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````%0````T(`P```'%,
MU5(```!@4$Q410``V@``_SDXWC8V_WL`C$I'_UI9_\X``.D``/\``.=Y>X0`
MB:48C(1Y_[V^QK6V_[W'__^-B]G:V=;;_^_O[^_W]_?W[________P``````
M`````````````````````%BW;1@````!8DM'1!\%#1"]````"7!(67,```!(
M````2`!&R6L^````2DE$050HS[7*.1*`(!`%T?[B*#JNX'+_FYI2:.H+NQH`
M:%)I03:;*=RE"W4YAZH>J-O6NI[()'N_DE35A+?N[M->&AD^Q-]J_-`_8;P-
M5(HDRTL`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]B=RYP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S-2`Q,#4Q-30S-#$T-2`P
M,C,P,S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#___^\XO4OG,PTF\LTF\H@87XWI-0XG\XWG<PXG<L[GLM`IM1$K]Y#J-=#
MJ=='IM$R=9-(IM%/LM]3MN--J=,[?IP_A:9%C:]'D+)@P>U.F+MHS/AEQ/!0
MF[U5H\98I<ECN>!=K-%>K]-QSOE5F[IMQ>QUT?MKO^5LON->I<9PP^A\U?Y]
MU/U]U?U[T/A[T?AYSO1_T/2+U/:0V_USI[]TI[]SIKUXK,1TI[Y[KL5YJL!\
MK<.$MLZ'N<^3Q-N6Q]V*M\MLCIZ1O-&BTNA_I;:FU>J3O,Z9PM6OW?*QW?*I
MT^>DS>"RW?*PV^^FS^*6NLNKT^:YX/(NG,POG<TPG<PTHM$XH<XG;8M`K-L]
MH\]1NNA6ONM/K]A'E[E6M-QCR?5/H<1(DK)6J\]CNM]RU/YUU?]NQ^YQR_)W
MU?UWT_MTR_%YQ^F&V?V%U?B)L,%!/#E%0#UH8V!Z=7(S+2I$/CM)0T!+14)3
M34I84D]64$U:5%%B7%D6#PP9$@\;%!$>%Q0C'!DF'QPM)B,R*R@W,"U*14,7
M#PQ'03]43DQ@6EAC75MB7%IO:6=V<&[___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#0J.V(`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+9)
M1$%4"-=C8,`"V-C$M$R,%(6X6#GX1&35]4!"@JK&>1JBW"R</,)2*CH&0*&(
MI)Q<M=APYA!VWAB9M*QTH)!3`%.@LXV9J86MO8NGK[<'4*BMN*B\N;ZVOJFU
MK+J[J[,0*-376U'2T%[7V%):5=-3V5$`%`KR<;0VM[2R<W#S\O-WSW<%"F7'
M1X4&AT5&)Z1F9J0D)\8!A10%@"[B![I(UU!325Y:`B@$=Y&^MK*"G*0X-N\`
M`"Q[*7I`.O\X`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+V-M+G!N9P``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,#`U(#$P-3$U-#,T,30U(#`R,S`R,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___SIM.P!(``!'```M```L``-+
M`P-*`P5*!0E,"0U1#0HW"A)3$AA9&!$^$1]@(!]?'QE'&2=D)R%0(2I9*CAT
M.#AS.#)B,CMK.TB!2%")4$9W1E>.5UZ37EF*662:9&299&6996B;:&J=:C!K
M+T%Z0&:897B7:A0]`!4^`1E!!1Q#"2!)#5AY2&V,7BM0&$%C+^#D(>GN+\?*
M,,[1-//W/MO?/OG]2NKM2?K^4/3X4*2D&ZRL(:^O([:V)KBX*.[N-;N[*KZ^
M+,/#+L#`+<;',,G),<[.-,O+,]#0-O7U0M76.OGY1MS</N'A0OKZ3>7E1NKJ
M2?KZ3_S\4.[N3/'Q3OCX4??W4?7U4-'!$-C('>+3*\_"-?7F1M[10O?I3_3F
M4>W=.NO=3,JC!=.$$-!"#=M,'<<B`,P6!\H-`,L0!=`8#=@C&.(O)NP^-?1,
M0N5/1OE73?%73OA;4<@``,<``+L"`,@!`<<!`;T$`<L'`\H#`\@#`\D%!;P%
M!<`)!\@)"=$*"LX*"LP-#<@3$-D4%-84%,`5$MD8&,\8&-$?'>(A(=\A(=(?
M'^(F)N4K*\HI)^TO+^DO+^PU->\Z.N`X./,^/O9"0O=&1OE*2ME#0?M/3_I0
M4/504.I85____P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````)6\VSL````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````GDE$0508TVW!T6U",0P%T&O'<1X4M6(#
M)"169"D&8@4^**V$7D+L.!V@G`/\0\BT^SF=Z_-9U\?U:U<N#-KHH7BK;2&B
MK68P5$O,=6VL1"GG%QA+$4NU/7Z%E,MP"/+RLEF_G92<9^]@?/9-][9G5F(R
M"PBZWRU2.19A"AL#C/[1QU31G)ACA$/@-S?.FB5-#_,`H[L)JTJBB!DQ\<8?
M*X%/*U;:G,L`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8VXN<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,#4@,3`U,34T,S0Q-#4@
M,#(S,#(R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```8!03%1%
M````____U34VQSH[LI<JE'$1NY<RZ;A9]H)7?Q(`?Q``S2()S!H#BQ<*SR02
M_W=H]W9ES!0%SA\-U"T?S`H`G2`9_6UDS`@!S`D!IR4A\510U$M&_V]JS0$`
MS```S`(`?P``S0$!S0(!S@,#S`,#T`4%S`4%T0<'S0D)S0T)U`H*U@T-S@X-
MV!`0SQ(2VQ04WA@8TA@8X1T=Y"$AU"`?U"0@Z"8FIQL;ZRLKV"<GL"$A[B\O
MLB,CN28FW2\OW3`OO"@H\C4UORHJQ"TMP2PLQRXN]3HZRC`PS3(QX3@XX3DX
MU38UTC0TSS,S^#X^^D)"VCHZYT%`X#\^_$9&YT%!Y4)"_DI*ZD9&QCL[_TU-
M[DE)[$A(_T]/_E!0\DQ,_5%1]DY.^U%1^5!0\5!0]E=7^EY>_61D^&5E_VIJ
M____````````````````````````````````````````````````````````
M````````````````````````````````B3-BT0````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```">241!5`C78V#``A0X12-D.+P,U>14=8T=
M@V.!0ERL;`*I(<*:<LK:1M;^,4E`(5X6=K%H2R%Q12T#"[_(Q"B@D*0TOY0=
M'X^LNKZ96UA\7!!0B#DCQ=-04`1B4$*H#U`H/370E%L>:E`XDSM0*"W:4D="
M"6I0@(<+4"C97D]%#F:0K[,M4,@3[B*@0:X.5D`A$PV8B\*]W9ULS+%Y!P#P
M^B/<YHNO1`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O8GDN<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,C8@,3`U,34T
M,S0Q-#4@,#(S,#,V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____U"XQU34VX3P]YT%#B3@Y^HR-\)J<`,P``\P#!<T%#=$-
M$-40'=P=(>$A&Z,;(:TA(J\C+^HO*+HH->\U*KLJ+L4N,,8P-M$U--`T0O9"
M1OI&0N)"1N9&3_M/4/M03O-.4/50!<(`",4##,<'&=$4*MXF*K(F,;TM/NLZ
M-\<S0M<^3O5*4.I,5?51#KX%$,$*([<3I"4!HR4!JRT*IS`-MCL8Q$TKHT8L
MK4TQTE\^N58ZVVQ-S&9)V&]1MD8JS'-HNR\BP38JS```QP``QP$`Q@``R`$!
MQP$!S@,#R`,#Q@,#?0("RP4%R@4%R`4%QP4%S`<'S0D)R`D)S@H*U@T-T`T-
MR0T-TQ`0RA(2UA04?0P,V!@8SA@8S1@8X1T=W!T=?!`0X"$AWR$AU"`@SQ\?
MXB8FTR<GY2LKFAT=D!P<[B\OZ2\OV"\O[34U[#4URC`P[SHZW3@XSC0T\SX^
M^D)"]4)"^$9&]T9&VS\^XD%!X4)"N#8V^4I*ZD9&PSL[^DU-_T]/ZDE)Z$A(
M^D]/^E!0[DQ,^5!0\4Y.^%%1]U%1]%!0[5!0Q$5%\E=7\5M:]5Y>Y5I:^&1D
M\V5E^FEI^VIJKDU-YFIH]G5U]75T^WM[I%55T&]O____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````I*5ND@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"O241!5!C3;<'-6<,P#`;@3[(?V3*!2Z%3,!)K<&$!SER8H8S0";I(
MRX&?0YTF`1)+#-"^+W"&\"!YO?[=?]9!KTJG-T^,HZYNYZ]^'$1SR=<"QO;^
MSOOO.H0B.1>9$/%*]O-13ZV3HJK+!$:U^?TXS9I44_;A#XS.'NNI#REE41Z?
M&PCI93.:,U-@=C/?1=!;K<Y$(;";FR-B83\PLZ1(2VNM@6'N1!0E<%O,S7'!
M/W9#3O7]$+5-`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]C;RYP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`P-"`Q,#4Q-30S-#$T-2`P,C,P,C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^A%!:E&1JB&1NN
M)"6K*RR[-#:1+S"=-CC*1TFG/3Z^24JQ1$766%K#4E/:86/27F`!(X4!(X0*
M*XL-+8D8.9<G1)DK2Z8K1(PR2Y4^7;4Z5*%-:K](8[))9+-1;;]D?<8'*'P)
M*GP-+H$8-H4:.HPL2YLK0G\U49@_7JLR2H@X49%$7J!/;;=1;+!6<KE5;[%C
M;WY&5FAVA95T@9"!CYZ`C9R*EJ0Z2UP\35Y`4&%49'5E=89;:'5O?8N/FZ=2
M8G'-K0#,K0/1L@?/LA+;O13HRB;=PB_UV#K@QS[^XTKRV4S]XU'QV%#4OT;,
MJP!_:P#-K0',K`'.K0/0KP7,K`7-K0G4LPK6M@W.KPW8N!"+=@K>OAC2M!B4
M?Q'AP1WDQ2'4MQ^=B!GKS"O8O"?NT"^GDB'RTS6RG"KAQCC2N33XVC[ZW4*[
MI3+\WT;GS$'ERT+'L#O&L#O_XDWNU$GLTDC_XT_^XE#VVT[[X%'YWE#VW%?Z
MX5[ITEG]Y&3_YVCWX&7_YVK$#P#&$@/%%PG.'`W9*QW-+1^B)1NM+B/G/B^Y
M-2K$.S#/0C7S4$+D4D;X7$_R7%#___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````D\I+=`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```)U)1$%4&%=ECS$2PC`,!"59
MC@G)A`P-#;_@);R&+^1U^0,-=%1AL!4LHZ2@R94[=SMS`)L@7.'8'^0U1?%5
M%4(]$$#7=/,4DS![[W<.")I]K^D=O\3,57`"#,WC-$K60H1$5'1!%SG_11B7
MUA@#B6*J\4.HN35TSTF7&3ERQ02&^AA6D6,3E9*?"*VHFM@(JJ5$A"$;05Y)
ML=YM^P=^^OE,(54_474`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V)Z+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U
M-#,T,30U(#`R,S`S-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___X$F88(H8X0M9HPR;)%!=7,T78=%<)%,>9I3@*UDDT\7
M/8PU<)A`>II$?FLQ6'T]9ZI7C[=GG<:%L8(I9I%4?KQPI+ESHWD>8J%,B[1H
MH)Q1BK!<G+AHI'LA9X8R<ZRKK*N?^V16RX!UW)B-]38HS#PNS#\PSB\FBT@\
MSTT_U5]1ZUE-V$<^IV-5X5!&N6%6W%A.Q&%6TEY3S')F^&-8U7=K_F==VGMN
M_G)G[F]DYFMAWVQAWWIM^71H['!EY71IZF)9QWEM\G]T_WEN\7AM[G=L['UR
M]H)V_8%V^VYEU'YS\8-Y]HI_^H%XZ8^%_9*(_Y"%]Y2*_XN%SU9-PEM2RE!(
MLE]6SWMQ\L;"^CLTUD5`TD0_L$Q(O&9@YUM7TG5O]FUIU'MWY(F%]Z2@_A\<
M?S0OT#(NS#8RS#TXV$I&X3`NE%U9[E-0QV%=X6]K^EI8SE-1NVADY7EV_WAU
M^8*`^H^/TY"2U;N\]K_!]H.&PHF.Q[2[_'B#S7.`RZ*M\I/1DI/)D:SEJ9O+
MF9C)E:[9J]/]S]O_UY3-C(W,@YS,E,+ZN<+RNZ;FF97,BIK&D6^:9L7UNKOD
MK9JZB\G,QX./<Z:SD6MO-5E72'-F.;"B>+BLBZ"5@)EU.JJ&AO___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/]L@M,````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````P4E$050(UV-@P`)X>`3$1"1D%.0E17GYA83%@4)I.44I9?%)=?6%
MT=FY!26E0"'-</\`^_*6KL[&"AU3%R\WH)">=Z"K2M.4B=.F-ZN:>T;:`H6<
M@GWU:[KGSI@WO[?2TL/!&"@4Y&>M7=VO.'/6U)XJ.T>S,*!0@+NNAG+KA-ES
M)G<H65F8A`*%?`RUU-5"VOHFM4<YVT08&0"%\F,R,]*SDAMJ4Q.+$_+B8H%"
M;"Q,S*Q\4K)RTMQ<G!R"[-B\`P"J:3(,QN_.A0````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O9&4N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P,S0@,3`U,34T,S0Q-#4@,#(S,#$S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T#4VQSH[YV=H
M.CL[QI``QY(%TYX0S9P8K(8A[+HUWK$XSJ0T]\=&R(T`R8\#RI0%R)`)T9<-
MW*0=WZLATIX?I'P;ZK,OKX8CN)`HNY`JPYHNT:0U]L%"X;5"YK=&^\A/^LM0
M\<1.QYHP]<10QX0`QH4#S(H'RHP2UI44XJ,FMH4FV*`OP(\M[[,ZRY@SVZ<^
M^;]*[K=,^,%1[KE0R`P!QPP!SA0*R1<-V2(8TS`GY34KOC,LR3HQ\T<^U4(Z
M^E9-ZE%)Z%!(]EI1^6MDRP``QP``K0$`R`,#K0,#SP4%S`4%L@<'QPD)T`T-
MUQ`0"P$!LA(2O104TA@8VQT=XR$ASR`@RB8FZ2\O\34UDR$AQC`PPB\OX3@X
MTC0T]4)"V#HZ_$9&XD%`Y$)"Y49&QS\^_E!0^D]/]4Y.]%!0XTI*V4Q,]5=7
MXU%1V5!0OD9&]5Y>]&5E_FIJ$PH*%@T-$`H*(1@8-"LK+R<G1SX^,"HJ4$A(
M54U-65%14$E)8%E9:V1D:FIJ965E7EY>5U=74%!03T]/1D9&0D)"04%!.#@X
M-34U,C(R+R\O(2$A'Q\?'1T=&1D9&!@8$1$1$!`0#0T-"0D)!04%`P,#____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````OJ.@Q@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"U241!5!C39<^Q30-!$`70
M/_-W#S`@$J`C"J`+(P<$2`1(4`1R8!)B^J`,D(@0(C%.?'>^G?U+`7X=/&"/
M`7B^>V1WF.>K.M70@P/+\N0YI_F+HM4&)-S_9"O;^+S^H#G-D/!]L5RLMZ/R
M5SZ:41,<;[SY&Z8@Z19EW,%QJWXW%:;,KF.\5ABN-$K-W>F4U-X3-F.HN5NB
M-S4)AI.J=CR<]CRW6)]ITQLNHQHM=4RE'@S2[_X'_^M,5B:(*&8L`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C<BYP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q
M-30S-#$T-2`P,C,P,C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\"&DT$*GP)+X`[6Y]*;+4_6I5#7957<:E%5X!=<I]E
M>JB"F,D)+WX4.HH</XDE2I@<-6DX7*@\69,]6)!4=;I'8YY:>+=4;J)-8HMM
MB<1H@[E6:I1YDL9VC;R"F\Z5HKM=9767I+V8I+V@K,6LN-%Q>8F[Q]_(U.O/
MVO&ZQ-G0V>NCK\66G[#+UNO/VNUS=53.SLJRLJ____S[^_CX^/7N[NOKZ^C>
MWMO4U-'-S<J+BXG]_?OIZ>?,S,J7CW3LZ^BC?U.E?5'8U-&L8SNO<URO4CZT
M2#N^/S79M;+ZUM/*-B[`.S/!/3;824''24*]13^V0SVY13_@54[B65+D6E/%
M3DCH8USG8US?8%G@9V'B;&;E<6O0:F3B>'+B>7.X9V+(G9JVEY7!H9_QR<?,
MJZG=NKCZU-+OS,KNS,JV%1"V'QF^)1[%*R3'-2ZY-2_20CRY.36]/#?61T"N
M/CG-2T7`24315$[/4TVT243565/46E3975?77%;H9%[C9%Z:1$#E9F#+85[I
M=G'L>73K>73E=W+L?WK&;&CPCXO)FIC7JJC,HZ'DN[F^(A_0HJ+^_O[\_/SV
M]O;R\O+EY>7DY.3AX>'8V-C2TM+0T-#,S,S'Q\>\O+RPL+#___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````""QO<M`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,%)1$%4&--ESU%*`E$4!N#__/?.*$S2,/F2(I(*)8&;D#;BIER0
M3ST*Z@A:&8*!,*:)BCGW7!?@MX,/N"$@8A.Z+-*#1.0^7@L:04'MA2='"D6"
MH47E%'EK-DGNO5<5PN*M*)/F9T?-Q^MWVZ3^W>(<C*N#_U7+Y:/"2.I3$*6T
MEN8[;?$E;#\W5$"XITD]3.P7%\:XV;P)B]6B.^X&.=/R\D?O=0-!GX175?6D
M-2(]P>/OW3[^>R"S)/.)VQYO/[@"GN1,MXGHM/<`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+V-U+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30U(#`R,S`S,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/____IG:/=M;K];
M7/&"@_+=WKX<*+L=*[(B/,NQN*A5;6D4-TL"+Y=JEU(`83\0CRP*HVA>K`0!
M>'=VNH!_Q8N*TJ>F]IR;Y@``Q@,#RP4%R@4%QP8'R08&Q`L+R0T-T0\0S!`0
MTQ87TA@8S1T=VQ\@UR$AWQD9G2<GWAT=H"\OZ"0EK#(RY34U[2LLN#H[[#`P
MQ3@XW38UT#(RPT)"]#@XS41%\CDYS49&]SH[PTQ,]T9&Y%!0^D]/^4A)XD='
MX%%1]U!0\U)2\596^5-3\5=7\6IJ^E)2OU14P5=7P%U=R6MKU&AHR6YNRWQ\
MXHR,[WQ\U(.#W)65](N+X924[IR<\)N;[J:F\ZFITK:VWJVMSJ.CPM75^<[.
M\:JJPZ^OR+FYTL?'W]75[.#@]L7%V.#@]=;6Z@,)S(V.J\3%[)B9M]'2][Z_
MX&5KR:"E])^ARIJFS*FSS]34S<[.R,W-Q\S,QO__^?CX\NOKY>CHXM[>V/[^
M^?W]^/O[]O7U\.[NZ>#@V]O;UMC8T\3$P+FYM?+R[M'1S<_/R_WMYL>+A.A^
M=\\B''\``,0)"8D*"LH1$=(@(*,A(=$L+-TP+[(J*N$X.-\X..U04.-34\M6
M5M]@7^QI:.MW=O;9V>SL[,S,S/___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,-4`OL````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)XA36L
MW-V,5&0DI974]2QM@4*]/$+Y84&^7AZ>WC[^`<&A0*'^J=V=\YM+RDJ+JRLK
MRNL:@$*39C'-X2J*CT](3$I.24M/!0JQS)L[G5U`5EY9T\#:Q=7!`BC$RC9[
M8A^_E(*JMJF=DXVQ(5"(>>;D"=QY?H$AX>(1$F*B(D"A&5-ZNA:T-U75U]2V
M-7:TM`*%IG'P%19$1F7EQ,;E1L=D9P*%.`4SY!35=,T=G>W-3/1UM+!Y!P!@
M-C*O_/W<6`````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9&LN
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#(@,3`U
M,34T,S0Q-#4@,#(S,#(P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____T1$2Z"\P_VYO_6YOQ[N\RL7$__GXY^'@S0$`S```
M?P``S0$!S`$!S@,#S`,#T`4%S`4%S0D)U`H*U@T-V!`0BPH*SQ(2SA45WA@8
MWAH9TA@8E!$1X1T=VQX>Y"$AU"`?G1D9Z"8FIQL;ZRLKL"$A[B\OLB,CN28F
MW3`OO"@H\C4UORHJQ"TMQRXN]3HZV#,SRC`PLBHJIR@HZSDYX3@XU38UTC0T
MSS,S^#X^^D)"NS(R]4-#X#\^_$9&P38VY4)"_DI*S3T\ZD9&QCL[_TU-^$M+
M[DE)_T]/_E!0\DQ,_5%1]DY.X$='VD5%^U%1^5!0_E-3\5!0\E55\514_UI:
M_5I:[E55[%14^UU=U$Y.Z5E9_61D]V5ES%Y>SE]?U&QLVW%QU'!PY'Q\X8"`
M[HF)S(2$T(>'UHZ.S(F)W:*B[+*R^L+"_\G)T+^_V,G)Y-75\N/CX=/3_.[N
MY=C8TL;&_O'Q]NGI__/SS,+"UL[.X=K:U<_/U,[.^O3T^?/S^/+R[NCHZN3D
MTLW-SLK*S<K*]O;VY^?GX>'AV-C8T='1S\_/S<W-S,S,____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````E\[#R@````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"[241!5`C78V#``GAXE%SSVE-EA+@%Q11T[+U`0K(V<;D=B<+<
M_*)RZM:>@4`A<>.8V)RN!#Y>$2E5*[<`#Z"0231+:'9//!>3/+-M4'B('U"(
MK;*BN*6O*K^@L*BDO**T#"C46,]9U];76EW35,_1T%S+#A1BC324S.I-EC9U
M#XN*\'=V``H%:TD(I'<G*1LX^7C;6>II`H7,@"[*Z$H!NLC7T4)?6PTHI`AT
M469G&M!%+N9&NAHJV+P#`"^2*\LB&S\E`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]C=BYP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S-#$T-2`P,C,P,S8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____%N+K#N;OE
MV=SWZ^[8S=#4R<SJW^+BU]KUZNVRJ*N]L[;(OL'RZ.OQY^KIW^+#MKKRY>GQ
MY>G-PL;'N;_`L[S/PLO`LKQO:VXP*V9#/8E63ZAT;KEJ99]V=8`X,I([-9([
M-9$E(5H_.)<]-I(^-Y-`.94_.9-`.9,]-XQ$/IE"/)1$/I='09M+1:!*1)Y"
M/8A12Z1.2)PW,VY23)]74:A"/7Y<5:]43J!:5*P_.W=*1HA&0H!B7;-G8;=3
M3I-K9;MN:+Y;5IU138Q138IB7:9T;L)I9+!X<L5K9K!:5I1_><U\=\E[=L=Q
M;+9V<;YC7YZ!>\M_><=Z=<&"?<R#?<QY=+Z!?,J#?<J!?,AN:JN%@,=]>+MP
M;*>!?+V+ALR#?K^1C-./B]&0B\V5D--=6WU%0II/3*564Z-B7[-85:!03HM9
M5Y9T<<*!?=%I9JIQ;K:#@,]I9Z.*A]*&@\R&@\N<F=EC8GYE9'UA7Z!55(MX
M=KQX=KN*B-.(ALQ:67YW=IR-C:2)B9?7SIW0Q9*$@7'#N(SFVZ_%O)Z\L)W*
MO:O:S\7D6S726#/'0!_72R[)6T7'-QS&-1S-/B2]4S_S;U;59$[Z?&3J=%[H
M<UWV?F?XC'C___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!`2B,U`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"E)6M
M`U-C/(PUE-0-K!S]PD!")MXI"?Z6.DIJ>C+VGJ%10"$IU\3D`#-=155M(SOW
MH,APH)!M=%*\G*2AEHJ^A9-O1(@74*BXO+Y9OCJM(B,KKZBNM*8`*,3/U](I
M*,'4W<HBQ"K,*<(,%)HSJZ]_\J0I$WJGS9@]<_K$J4`A`?;V+C%1\9X.+BX.
M-EX>;J!0869Z0V5V8U-^25EM055N#E#(5%-!VJ4M+M8G6-;-V<'&')MW`(UP
M,+A5E0W=`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5C
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0S(#$P
M-3$U-#,T,30U(#`R,S`Q,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/____E04;T`#L(%$[X%%,08):4A*[$H,[PO.<<T/]4X
M1-5"36-=8"`2P3@MN5Q0Y%Q1W1`#O3$GK3PPSCXTPTD_U0<`Q&5DXVQIU0$!
MS`D)S`T-SB(BTB<GV"LLPC(RS#,SQCHZVCDXT41#XDE)[DA([$E(YE!0^6!@
M]F1D_6AH]&NLLV:^N3Z5@4!Y:)F;FF*#:I.:E#M..EIN3V5Q75UD6$A,1:[!
M?Z2T>+C#?FAR'%)8)XB/)\S*`,[-!,W+"M;5#=32(*>G(=W<+^OI/.#@/N?E
M0?[^2G5U(_+R3/W]4?'Q4-341O_^:(F(0<S&`'][`-#)!<S&!=C2$(N'"M+-
M&)20$>'<'>3>(9V9&>[H+^'=+).1'O+L-;*N*K*O*N'<./CS/OKT0KVZ,KNW
M,OSW1I.0*\;".__Y3>[I2>OF2/_Y3_[Y4/OV4?GT4*>E-Y62,?;Q5Z>C/OKV
M7NGD6?WX9/?S9?_Z:K&N5,K'9\"[6\._8ZJF5]//<-S7==71=^#<B(R$(Y*.
M4J"4+6EE0JB>@I-T6(![=YQ^;=2'7LA5*).'@^=K4J6&A/!*1H)M;,P``,T#
M`\T)"=8-#<8:&>`='=0@'Z<;&[(C(^XP,+\J*LHP,-4V->I&1O544O___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````!CRJ4T````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````O$E$0508&66/O0X!41"%Y\[]L2+81"$B2I52--Y"IZ;Q%IY!
M%!I/XCU6(T%'PU;+[MZY,V[O5"=?ON(<@+\H6$"SD]9Y$0*BM4EC;P!<JTN9
M9U;81^L0#)@DE>](#_&5DW/H(WJ7.9>#:^;=---:***Y$5^>2Y*Z-[/"X:1@
MPK[B(5.0]KTKQ#<$";6(+)9V)1)\8-#@JR*HAQM/JLLS=OHJ:'EAM?L0*KWE
MZ%<*#A07H2G2]3$"ELW?'8`?S+ACH*V`6H0`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O8WDN<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#4@,#(S,#0Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____[>OM_/O\
M^_K[^/?XWMW>S<S-R<C)RLK+K*RMW-[@^OS]T-+3Z.OLS]/4Q\O,S]34]_S\
MT]C8R<W-S]+2\?/S^OO[^?KZ^/GY]O?WZ>KJT-'1Z_/QKL2UN<"[N,^^@Z>)
MN\&\J,FIK<.MP=7!\O;RS=#-]?;U]/7T[>[MXN/BU=;5QL?&T=K0]_?VX>'@
MR<G(L9R%[.?CR,"[PTH&OT@&OTH*PGQ4TI=WQYI_UL2ZV,[(P4D(PTD)R507
MV79%QW!!PFU!V8)7WYMYQ(MMZ*N-R*:5V\&SY,N^RTH0T9N![LJY\^[L]>_M
MW=K9[>OK^_KZR,?'Q\;&^_O[^OKZ^?GY^/CX]?7U]/3T\_/S\O+R\?'Q[N[N
M[>WMZNKJZ.CHYN;FY>7EXN+BX>'AX.#@W=W=W-S<V]O;V-C8T]/3T='1T-#0
MSL[.S<W-R\O+RLK*R<G)R,C(Q\?'QL;&P\/#P,#`OKZ^N[N[N+BXMK:VKZ^O
MKJZNI*2DFIJ:D)"0B(B(?7U]?'Q\____````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````4\T<F@````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``AJ;
MZDI#HM-RBXKSLU+CPD.`0DWUE5$:R:)%Q46\W-(1H1%`H8::I'`^81,!$4$;
M3U]Q_7B@4*V,>("UNY.%E:6+CX1D;#I0J#10S-_1S-S4R\%8*#0F)1<H%!FA
MS>]J9VOO[.;'$YF4HPL4"DO(XE0R\O;0DV66BM<Q+`<*:646<,@KRBDHJX7&
M9N2750&%TO**2]C5550U66(,<DLKN8!".45!A3EL3*S,D8G9P175M=B\`P##
M=RT=9`&`3@````!)14Y$KD)@@@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]C
M>BYP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q
M,#4Q-30S-#$T-2`P,C,P-#,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#____&``/9*"FE`QFC#BIS"$!M$5)I$E`V$'`U%'77
MU]@%#9997\(%$)4,%I,P.:X`"%T.%V(1&G$F,:-06\8`%*`!%9T)&YL-'Y\*
M%FH2):48*ZH8*:$G.*HA+84P0*\J-HXX2+@X2+9!4+L[1Z)(6,)&5+!79LQ+
M6*U>;-%D<M5H==AF<])J>-AT@-E35W2OM=T,()X?,:908,=B:Z3GZ?-YA[^P
MM,7&Q\?@X-_-S<SRY^;.`P/0!07.!P?/#0W4$!#;%!3>&!C;'1W>(2&C&QOB
M)B;F*RNK(2'H+R^N(R.U)B:W*"CL-36Z*BJ]+"S#+B[`+2WO.CK(,C'%,##J
M.SK.-#3*,S/R/C[0-C7T0D+5.CKV1D;;/S[%.3G@0D+X2DK0/S_E1D;Y34WT
M34WI24GY3T_Y4%#Q3D[M3$SX45'T4%#V45'D3T_Y65GT6EKDV=GEV]O^]/3\
M\O+V[.S8S\_2R<G^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV]O;U]?7R\O+N[N[K
MZ^OHZ.CGY^?DY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#.SL[-S<W,
MS,R=G9W___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!\'[!B`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```,!)1$%4"-=C8,`"A`PF6S+6M_=.FM3?U=9850$4$A0V-:MI
M[9DX:4)W>U,-8RU02$J15]^0>\*DB3T=S76,U4U`(7EU'5$!30OKOLZ6AHK*
M1BN@D*J>AK(LCY%Y6:%-27%I43E02%=+Q5A"C(^=.2PUOR`O*1XHI*TF)RG.
MR>KL$9F2FQ83$@`4,E&0YF>S=W(/3LS.BHL(\@$**<EPL=@YNOK%9F0FA`?Z
M>@*%1#B8;!U<O*+3<Y*C0OV]W;!Y!P`6Z#!B',3\:`````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+V5E+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,T,30U(#`R,S`Q-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___SLZ.S8U
M-FMK;.+BX\?'R$Q.4R(D*#$S-T!"1E)46&EK;P(%"@D,$2<J+SL^0Q`U9QI6
MI1M7J!$V:1I2G1I2G!Y:JA]:J1]9IB-=JB):HRACLB5:H"IDLAH];2))?3!F
MKS!FKC=POCISOS=MM"I0A$)WO3UMKDF!S4V$S3I@D4Y_P5N1V@4(#%6'RT5M
MHUZ3V5>(R4QUK&::X&>9W6:8VV.3U%V*QUR)Q6:5TFR9UW*AWFJ2QGFDWG:@
MV'VHXA07&Q89'4U05%)564=*31\@(+*SL^SM[.'BX=35U#HZ.4%!0-75U,S,
MRV9E9?[^_OS\_/KZ^OGY^?;V]O+R\N[N[NSL[.KJZN7EY>3DY.+BXN'AX=C8
MV-;6UM75U=+2TM#0T,[.SLW-S<S,S,K*RL?'Q\#`P+^_O[V]O;R\O+BXN+6U
MM;"PL*NKJZ>GIVIJ:EY>7EI:6E=75U965E%145!04$]/3TY.3D='1T9&1D)"
M0C@X.#4U-30T-#,S,S`P,"\O+R(B(B$A(1T='1@8&!<7%Q04%!`0$`T-#0P,
M#`D)"04%!0,#`____P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````)-R'^H````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`($
M!=6,':QUE"2%).14M`Q-@4(B"@9V-D:J4L+B,LJ:NB9F0"%Y;5M[2PU9,5%I
M175]<RL+H!"'*P\WIZ,>+Y\3OP"[BS,74(BIH+BFM8>AIZ.YMJJLHKH.*.1?
MZ./6S=#;V=)875Y6Q=P`%&(I:VCKZFIOJJTL*2JM]JX'"GGZ969G9[+%LX9[
M1">FY^0!A6(24E(28Z-"`P-"(A/2LG*!0E[)*4EQ,6%!C,$1OJD9[OG8O`,`
MJ_`N58M>W00`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M96<N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#4@
M,3`U,34T,S0Q-#4@,#(S,#(P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____PQ@:Q1D:AQD:QKZ_U<[/65E;-C8WPL+%1D=)
M]?;X:&EJQ\K,[/#R]_GZR<O,P\7&(B,C]_KZ\?3TSM'1S=#0^_W]^OS\X>/C
MW=_?'R`?R,G(QL:U-C8U34U,1T=&6EI9R<C!W]O$T\6%RKES[>OBT\>:T[14
MWL1SX-&>Z^'`R\.IR\.^QKZ[QP``?0``?```R`,#RP4%R`4%R`D)T`T-TQ`0
MSA@8D!$1W!T=X"$ASQ\?RR$AFAD9QB,CZ2\OU2XN[34UW3@X]4)"N#(R^$9&
MT3L[XD%!PSL[^D]/^U!0]5!0K#DY\%-3\E=7]5Y>]V%AZ%Q<Y5M;]&5D\V5E
M^VIJXVEI]G5UXMK:I)Z>U]#0R<+"^/'Q[^CH[>;FV]75T,K*^O3T[.;FQ,/#
M_/S\]_?W]O;V]?7U\O+RY^?GY>7EY.3DX^/CTM+2T='1SL[.RLK*Q,3$P<'!
MNKJZ;FYN;&QL:&AH4%!03T]/3DY.1D9&0D)"/S\_.#@X-34U-#0T,C(R,#`P
M+R\O+BXN*BHJ*2DI*"@H)24E(R,C(2$A'1T=&QL;&!@8$!`0#0T-"0D)!04%
M`P,#____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````X<-;<@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"^241!5!C3;<P]#@%!&,;Q]VMVL799$2=0*IR%1)Q!H]-Q
M`16]2'0:A80[*%2T*HE&ZVOLC#$]__+)DQ_`3PA-C*-8W^XF$Y%0U(8`<V'Q
MK;7-F%F1(!`<JA5FQ_MC%"5)7`A`H!,BOO++AMNUE0-";Z6!#<RSG'/NJI11
MYNI?+B">EPP2MHAEY2T,Y4'ZX3`S(DJZ?DK6:;TVO)Q/EUZRC59Y;XU*TI]8
M<S>62(1Y0##C_O1CM?T`+@C'!'_Z`O>R/:0M+]6@`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]D>BYP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C`T,B`Q,#4Q-30S-#$T-2`P,C,P,S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____N1TCX
MYNC4RLO5U-7Y___X_/S!PL*RL[.RS\;9Z>/!R<3U^_<->2`%:A(@<R-*G$T`
M70``7```.0`#7@,%8`4%7P4)80D-9PT-9`T0;!`*1`H29Q(8;!@13!$==1TA
M>R$?=!\?<R`?<1\951DG=R<OA2\A72$J9RHXAC@XA3@X@S@R<#)!C$$Z>CL[
M>3M(DTA(DDA0F5!&AD97GU=7GE=>I%Y9FEEDJ61EIV5HJVAJK6H"8@$E=20H
M>"<P@2\P?B]!BT!FIV4.80<470DC:!@960HD7Q-1AC[@X-_5U=3-S<S2T,QE
M0Q)A/@UI,`%F+0!E+0/OY-[8M:>2-A2N1RRT;6'FMJZIBX;$KZO]]_:=&`;Y
MZ.:I$`/'E9"D%`KBM[3,``#,!07B65CGY>7>W-S.S<W^_O[]_?W\_/S[^_OZ
M^OKY^?GX^/CV]O;U]?7R\O+N[N[KZ^OJZNKEY>7DY.3AX>':VMK8V-C6UM;2
MTM+0T-#/S\_,S,S*RLK'Q\?$Q,2_O[^\O+RYN;FPL+"GIZ?___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#.J!:V````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+M)1$%4"-=C8,`"
M1$14]6W,=`1XZFHJRPJS,D!"\KI6YGI*'E'I5>5%.8RY0"$930M+0WO_F'"6
MM.(\QNPBH)"&B;6Q@U^<.Y=O:D%&9J$74,C`QE3++3F0/S(ED3TCO[0:*.1L
M[J3LFA3$%\\4P99;PEH/%+(T4I.R#4BPXV8&&E3APP$4,G:4%15R"0T+B04:
M5-O8`A32EA,7%I-6]`R.!AK4T-P*%%*1$!:55%`7Y,TM\:YOXFS#YAT`3U8K
M9Y<4FGX`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+V5R+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P
M(#$P-3$U-#,T,30U(#`R,S`R-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```,`4$Q410```/___Y8Q-*Q05,AV>[ER>I=88G=-;I5TE*>+J8=Q
MD&!MIH.2RH&2QF%UIEU[M3]:C$]PJD9AE$ADETQHG4YKGU!MHE9SJEAUK%]^
MMGJ?X7N@X'"0RGN<V5Z'S5-SJ66)Q6J-R59]N6N9X'.=W4^9*U>9.%V;/FNK
M3"AS`"IW`V*G/G>P5S)T!3A]#4"`&&NG0G.P37:P3W>O42YP`#)S!3U^$$F(
M'4V,(5J8+U^<-6^J1FZD27>P4':M4'JN44N!&#UP"I6V:H^;3%]@#7%K(WUV
M-'YR/;MJ"L)Z(\:!*Z%X1?.V;JMW0+I;![E=!_&M;+E?$LQ[->N@8H4_";U@
M&<>"2]1]1:YO1[A("KE)$;Q0&W4\']I]3\]M0+8\"K4^#-QX4.2#7MJ"8,]S
M5KQ$(L%-,+980NN&;+,H#*<H#.:#;=5#*N5:0L=/.J!#,N]G4&X5![LE#;`B
M#[0G$,<Q&KXQ'<4W),,[);HV),<\*<Q!+<E%,M-)-=9..\M30^)@3NIH5.IK
M6.%W9[<:!KT>"F\4"+4@#K,B$+DD$K4D$;HI%KPL&GL>$L8Q(;LR(80E&94V
M*MU20=U;2ME92^MK6]QI6N!O8NEZ;G01"+0@$<`C%;HG&NU?4]UG6^IX;ZY#
M/,!.2?___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#5ZO\````!8DM'1`"(!1U(````"7!(67,```!(
M````2`!&R6L^````P4E$050(UV-@P`)F%L:X.^FHZ9N:Z)I96%G;`H7:)BR8
MWQSAZJBII6=N:6!D!Q3JS4_.2*R9DQ7BXJ"J;6AL`Q2:&!8P+RBTHWUV7YJO
ML[V&.E`HW2<I+M4CLZNL>M+<J2G>;D"A[.!PSRB_DIZJNH:FQLD+V8!",V*]
M`OTCN\MK<PNFLW+Q"0*%IN5%)\1WEN9,8>'D55"2%P$*U5?.:FGM9^;@D591
MY!<7%0(*5105,[%SRRE+R<I(2H@)"V#S#@`;)C+Q94(]]0````!)14Y$KD)@
M@@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O97,N<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q-#8@,#(S,#,Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____>UU@
MAVEWJK@HM,,KWN@F[_4ZT=DSRL\S^/Y*R,H`RLP#S,X'UM@4XN4FYN@KM;DF
MS,XMP,0M[_(ZV^`^W-X^^?M*[?),^/U1^/I1[?%0T=-&^?MD^?QH]/9E^OQM
MQ\0!Q\4!RLH%S<P*T,\-R<<-T],0OKX4V=D8V-88V]P=W]\AY>,KZ>DOI*4A
M[.TUOKXLQL<PKJPJR<DQSLXT\_0^\O`^T-`V]?5"U=8Z]_=&X>%"P\,[^OM-
MY>5&^?A-ZNA)ZNI)^OI/^OI0[N],\?%.]O=1]/10]O51Y>19TM)6[^]LB(8*
M\_!CY=U-Z>)FGY<\I98.HH\7H84EC&P1P:ISM)-%NHPUNHQ.PW\\S)IOP%<&
MQEL'V'$CCDL9JELAZ8$UP6TNVWXXWH5"]Y=0Q%,"TF$0CTT>M6$HS'$T]8Q&
MR5\9[XY.JE<IC652]X)>Q2L`>QL`QRX#QC()SS<-CRT1VD8=SD8?Z%@O]&E"
MMT\RXF1!^71/]'10](9EE59$;#DOR```QP``?0``?```R@,#RP4%R`4%R`D)
MT@T-TQ`0SA@8W!T=X"$AT2`?FAD9I!L;ZR\OKR,C[34UNRHJQS`PW3@XT38U
M]D)"^$9&YD9&PSL[^T]/_%!0]5!0\E=7^VIJ____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````@*2J"```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#`
M`EI:)\Q9N&!Z3T=S>W??E%GS@$)%9=7U!345)87%I>655;5U0"%?8R\?;R$U
M1245+5US!T]'H)"^C%Q8?@@/-R\?OXBXE*L84,A6(2"J(5!#65W'P-K%S<84
M*"3O%YW'Q!RNJJUGZ>QA;V$$%)+UC\QHC(_0%#"S<W>R,C$$"DESL`2%!K.R
ML7-)2HAR"@L"A9)S8M)BT^,2LU-S4[*2,A.`0OV=36U=O9-FSIT_>\:TJ9,G
M8O,.`!]E,O'N;H#)`````$E%3D2N0F""````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]F:2YP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T
M-2`Q,#4Q-30S-#$T-B`P,C,P,C0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____-S,[!P<;%Q<GQ\?3O[_'&QLC[^_SR\O/O
M[_#=W=[:VMO-S<["PL.WM[@%$6$0&VLA+'DU/XHX0H4T/7M&4)E"2XP[0GI0
M6I].5YI78)YJ<JUZ?Z*3F+J:GKFJKLL'%64=*W@=*W<V07]!3(U07)Y78J!>
M::9F<*E^A[IF;96$BJQL<(BPM=2GK,FRM]6]P=L%%6,+&V8-'&L0'VT4(VP9
M*&T<*6\@+W<?+7,@+7,G-'DH-7DM/(,O/H@J.'DP/'<[2H]"4)<X1'X^2HA!
M3HM"3XQ&4I%/7*!06Y!?:J%57XUR?;)X@[:'D;^CJ<F6F[,$%F,$%F('&&4)
M&V4,'6<,'&4/(6P;*W%79)U-6(1H=:Q>:9AU@;9M>*EO>JNUM\#.T-F_P<G<
MWN;DYNZ_P,3"P\;Z^_RRL[/4U=35U=3^_O[]_?W\_/S[^_OZ^OKY^?GX^/CV
M]O;R\O+N[N[KZ^OJZNKIZ>GEY>7DY.3AX>'>WM[8V-C6UM;4U-32TM+0T-#.
MSL[-S<W,S,S*RLK'Q\>_O[^\O+R[N[NRLK*PL+"GIZ>=G9V4E)2+BXM_?W__
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!5LJZ_`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```+Y)1$%4"-=C8,`")DSH3==2=T]N:6FLK2K)RP$)]76R
M^JHZ)+8TU567%C`6`H7ZNRIRO6W,TYKK:\J*&/-+@4*Z@8;ZKF;AVK(Z<@%Z
M!@KR0"$)&6F1R-!@`4$A83%)*7%1H)"FAJI56%"(B9*]LZ>:AXHC4,@_WLO%
MV"C"+2HFSB\AUB<:*,3%P\1LH6B9Q,F1P<;-R\</%*IN:&&W-K5+R<LIKFQH
MZ^@&"F4UM[#8*CNE,A:69[>V9_9@\PX`\)\O7N0B`DT`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V5T+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,R(#$P-3$U-#,T,30V(#`R,S`S,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___^$A
M)/E15LI)6M1<;5UKC(":P!1XN">)Q0QTJ#F9RQ!VIE>NT".+KV&VTEZOPS:'
MDV6[R`UQ?11R<#F+BF:PL$"+AD2.B8W+N&JLE5F;?6VOAUF9<':O@V&<;@!;
M$`E@%F&<:6VG=AUT)"UX+SIX.P!:```X```W``-<`P5>!05=!0UE#1!H$!AJ
M&!%)$1UR'2%W(1]O'QE3&2^#+S6(-3B".$*20C)N,D:61D&)04^<3U"=4%":
M4%><5UZB7F6E96JK:F2<9(C!B"YH*E.>35>?45Z;66FI9`]%"C*"*T62/D^3
M2$^427.I;'RS=92<(<;/+]SF.LG2/N3O2MOD3.7O4=OD4,#)1NGR:/?^5LK-
M#.7G0>CJ1OK\3OCZ7LS+`<W,#M+2&M35(-?6*,'`+,S+,LG*,>'A.-+2-=34
M-MG8.N7E0\?&.^[L2>OJ2?[^4/;V3OGY4/KY4O;V5_OZ9??W9O__:LPP`-U8
M+^!D/O)S3/%V4,PQ`\\^$KE()L10+<]7,[TS&N9V9\P``,X#`]`%!<P%!<T)
M"=8-#=@0$-(8&.$='=0@'Z<;&[`A(>XO+[(C([PH*+\J*L<N+LHP,.$X.-4V
M-=(T-/I"0N5"0NI&1O]/3_9.3OE04/___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````.?#_J8`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````LTE$0508TVW!
M34X"01`&T*^J"YL9T!$2%Z"8N$&77LDK>`4.P(%<FG@&]FY8&$D(PMA=/QQ`
MWP/^(#QAO+^SOK<J2432NX#RX-95]]%R2LP$P4--))O=D?/DD0IE"')'7NX_
M;_R[&?(H'()%:X?RT?'%Y#">4C4PFNVV_EIYKAK*7^Y@Q/70!Y=&2VUG>J4.
M098NZLOJC<MKGW,$!/,?M4;4R>?FZ@;!R8P2KYO$9AX1^,<9G990JG%'7JP`
M````245.1*Y"8((`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O9FHN<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M-3`@,3`U,34T,S0Q-#8@,#(S,#(Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____G8N1KI.>IXZ9WL72E8J08DQ9N*BSFW^3
MBFF"O["\H)N@9UQHR[K-O[3%@&F.T<?>?G>?J:'+<G"+FYK':FN(4E:54EJ9
M<7^SM,C499.JK\_?J]#A:9NP:IJO;)VQ=Z.V<9RML-#=L,'(>+/(<*6X:YZP
M;9ZPA[_3<J"PA;G,=J2UE\WAC+S-<9>E<YBEG<[@=YNHFLC8G,K:I]3DIM/C
MA*:SJ]?G?IVIJ=+BF+W+E:RU<*[#:J.V;)^P;)ZO<:6V;Z.S;J*R;J"Q=JJ[
M<Z6U<*"P@;/$>ZNZD<?8?Z^^<)FGA;7%A+3$98B4BKG(D,#0;I.?D+_.>Z.P
MA*Z\E<33>J"M>)ZJAJ^]@:BU?J6QG\_>AZVZI-+AE\'.B[&^J=;DG<;3K-CF
MH,G6K]GGI]#=IL[;M=SIM,?-:Z"P>[/$=JBW>ZFW?JRZA;/`@:VZ;9&<@*JV
MC+?#I]CGDKW*J=CFJMCF;J.QKLS4G*RNT-[=L+2?RLVKPZE?N[BQX:5`[K%-
MO;JVVZIKV,BTSGLOYYYBJZ:CQZRDZJ23YXIVZI:$XJ"3NT<TT%]+]8!KZG]J
MPFU>[XIYWX1SE&)9YJN@J5=*['UM[(1TUWAIN89_][>NOT<X@3`FQHN(=4I(
MM'IXQ:2C____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````ZCQ=VP````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```#!241!5`C78V#``MAYQ28*\O%+RCNKJ6KJEJ0"A>9/
MF35I]M1Y"WSL+)G:ZZ5,@4)SIW7U3^B;TZMOR];:T-AA"!02X6"=P<TL(*Z0
M7577UMP4#!1B$1:=*23!R:6H75G;V9(9"A22D;4V5Y*6*_+S4NF>/IDG#RB4
MD9+OF%61XQ$84U[=4Q,;#A1*+];1L'?SUC-)+%->:!-B`!0JS757=_(,,#9+
M3HN/C#8J!`H5:#FXN/J&Q5E8)25$103Y8_,.`*'P,O$,[RM8`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G82YP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`P-B`Q,#4Q-30S-#$T-B`P,C,P,3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\A
M/&,H1&PT4GU0<:``)UX%+&(%+&$0-VP8/&TA1WLU68LN3'0X689&:9I"88Q.
M;IL'+5H)+UP?.5DG0F(N2FLU4G15=9P/-%\3.64C2',E2'`U68,[67M(:Y-+
M:HY5=9I`65HM2$@O24DS3DX\5%10:FI&65E6;&Q.8F)C>WM6:FIQB8ESB8EQ
MAH9WC8UB=W8`0P!!ET%>KUX!:P`$;0,*;PD.=@T251$>@QT@?A\PDR]#HD(S
M>C)0JT]1J%!FL64&;@`ZFC4_ACMNNFH$10`$1``+<@4,<`46?!`>?!@GBB$=
M8!D]DSA,J$96KE!<K%<C>P$C>@$K@@HM@`T@5PHYCAA$D2=*G2M`>RI=K3YJ
MMTUCJDADJTEMMU%QKUE]OV3`Q`"_PP/$R`?$QQ+.TA3<WR:?H2'2U2_I[3K6
MV3[S]DKHZTSR]E'+SD;GZE#U^&C)R`#%Q0+#PP++R@/-S`7)R07*R0G+RPK3
MT@W&Q@[5U!#6UAG/SAC>W1WAX"'2T2#1T2CBXRSKZR_O[C6[O"S(R##1T#3?
MWCC&QC+2T3;P\#[W]T+3TSKZ^4;DXT#BXD+%Q#OGYD;\_$_W]T[\^U#EY4GS
M\D[GYTKV]5#T]%+S\U?W]U[W]V7V]67]_&K___\`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#$E*NT
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```)])1$%4&--E
MS\%1PT`0!,"9V95.IH0?O'GRXN$P'"_A$(2A*#`6I[O;)0!W!@W<(<Z<-ZYC
M1)VE;>6;XU(F^_E<>E`2OPC'B\_L;43*)%K"\524M4=*-"D#CM=C__BMS6>?
M'HKJ!N%Q7/_V9FZ^3-[VA)#[]][IYLM2LF6".+41J3&Y+-4BWHECCZ!$NZUY
M/=PRB.=162C50T;-S,O]!_]IED]+!Z^JR@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+V9O+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#0R(#$P-3$U-#,T,30V(#`R,S`R-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___\4("<()"L`3%<$<(<HK,+\M,KPO-=D]
M0K@[/\-!1>5/5-1,4-=15NM;8.9<8.AI;>AP=+0C*KPM-<D]1==05[Q+4<E1
M6.-A:,Y:8+-.5.9J<-YF;=]N=.I_A:<P.[`W0;-(4JLX1+9!3<!-6,M:9<)>
M:/KY^I^/H):'FI2&F-+)U\K"T+NRPH9ZD:*:K:RLK=WN^:.^S;_<[*G"T,GD
M],?B\;S5Y*>]RJF_R[S3X,[F](F9HLKA[K'%T+O/VM7K]\[C[[3%SXBQQY2^
MU+'0X)2LN)VVPZ6^R[K4XJ[&T\7<Z,SA[-;K]H^WR=CM]\CE\<',S,3.SK['
MQ^_W]\;,S/?]_?S]_+&QK_S\^_7U]/'Q\.'AX-[>W=O;VL[.S<W-S,/#PKFY
MN(N+BOOZ^,S+R<O*R/[]_/OZ^??V]>[M[.KIZ.GHY]W<V]/2T<_.S<<``,L!
M`<<%!<P'!],0$,P2$MP='=0G)^-!0?-75]S;V\C'Q\?&QKFXN)N:FOKZ^OCX
M^/7U]?'Q\>WM[>GIZ>;FYN#@X-[>WM/3T]+2TM'1T=#0T,[.SLW-S<O+R\C(
MR,?'Q\/#P[N[N[BXN*^OKZ2DI)"0D'U]?7Q\?/___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````!K>(&8````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````NTE$0508TVW!04I"810&T.^[]\=`]`75P(&@`U$J
M27`+S5M`\_;A,MR$"W`/(DX$G6@0/*I!/I0*7N_>VP+J'.`/8LI\O7F8M0:W
M7KI93`3P(..G9-C1/00)B\\K89#E/OS@5D/"MK;MB%O]];U0;<8)";L4>7'_
M<B*I2C,D?$=5FL>1JDJW0,)-]M9^9J?'#R'M,N8)7>WGE>C9^86(B!""X:A1
M!?F5K:XY&H^7$(B`(<SB4>\*\@G_^`5\14TL`*PG&@````!)14Y$KD)@@@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9V4N<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,3$@,3`U,34T,S0Q-#8@,#(S,#$S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```8!03%1%````____
MB#4V<7!Q__[_.CL[7V!@E9:5\>WL:@``9P$`:P$!:0$!;`,#:P,#;@4%;04%
M:P4%<`<'<@D);@D)<@H*;PP,=0T-<`T->!`0=!(2>Q04=!04?Q@8?A@8?!@8
M>!@8@AT=AB$A?2`?9!L;BB8FCBLK@2<G:B`@:R$A?2@HDB\O@BHJ;2,C<B8F
MB3`O="@HEC4U?RTM=RHJ?"TM?BXN>RTM>2PLFCHZ@C(Q@#`PA#,SD#@XB#8U
MAC0TGCX^HD)"C3HZI49&DC\^I$9&ED)"ITI*?C@XFT9&J4U-FD9&JD]/GDE)
MG$A(JE!0HDQ,JE%1I4Y.J5%1IU!0FTI*HU!0LF1DLV=GM6YNQ;Z^W=?7SLG)
MP[Z^^_;V1$-#SLS,L[&Q6%=7W=S<\?'QW=W=U-34R\O+IZ>G:FIJ:&AH-34U
M&1D9$Q,3`@("____````````````````````````````````````````````
M````````````````````````;9[9X0````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"B241!5`C78V#`"K)9,Q+=Y04X^265#)W\@`*Y.5F9
M;'$:PIR\XHK:#M[!0"%F]K24M`03'FY1.35[SR`?H%!Z*DMR4KP1EY"TJH5;
M@+\S4"@FEB,J.E)+$&Q0H*L=4"@B/$1'1DP`8I`7DQ50*,Q778*'1U06;)"C
MI3E0*%1?BH\39I"UF1Y0R$8!XB(7D$&F!II`(641F(L\;*V,=56P>08`W1\@
MHFF6K1(`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9G(N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,34@,3`U,34T,S0Q-#8@
M,#(S,#,R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____T#4V[NWQ``#'``#&``!\`P/)`P/&!07'"0G(#0W)"@J($A+*&!C-
M$1&0'R#0&1F9)R?3)"3$)27#(2&D*2G',##8*RO$,##-*BJN.#C=.#C<,C*X
M.3G*04'B.CO#.SK#2$CH1D;14%#M5U?Q3D[57E[U65GE9&3Y9&3X:&?Z967S
M9F7S:FKZ967E>7GSA(3XQ\?+P\/'PL+&U]?;S\_3SL[2WM[AQL;)[^_PV]O<
M^OW^SM/3R,W-QLO+Z>[N^?W]]?GY\_?WW^/CUMK:Y>;FTM+/T='.R\O(R<G&
M[.SJX>'?V-C6R\O)WM[=V=G8TA@8WR$AVR0DI!L;K"$AZ2\OKR,CM28FY3,R
MN"@H[#4UNRHJO2PLPRXNP"TMQS`PR3(QQC`PSC0TRS,S\SX^]4)"[T%!U3HZ
M]T9&VS\^T#P\X4)"^4I*^DU-Y49&ZDE)^D]/]TY.^E!0[DQ,\4Y.X$A(^%%1
M]U%1]%!0^596[5-3]EA8Q["PS;:VU;^_W\G)Z=34\MW=[]O;X]#0]^/C]N+B
MR,?'^_O[]_?W]O;V[.SLXN+BT]/3T-#0S<W-S,S,RLK*R,C(Q\?'____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````LHU1,@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"F
M241!5!C3;<'!30,Q$`70/^.-8V,K*,5P0U$*0*($*N)*%8@B*`'1"5EYUV//
MIP!X#_A#$%'NSU]/U^7]\BWY=/>J0*Z5#]L&BBXE12R(I3C]6$F)-1T;%#F'
MWL*`)SFE/#H6U-):,/BD%/%MAZ+N?>W@_!B28G\C%,-^;)"?)01M^XM!8:M-
M\O!X<V$?;E!L;<QP()]MVMYM0G$;IL%)1EFG3^(?O^0S60BZF-I_`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]G:2YP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C`T-"`Q,#4Q-30S-#$T-B`P,C,P,C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___]Y$A/:-C?/<'&/3D___O_5
MU-7'QL?*S<W^___4U=7&Q\?!PL+GY^;@X-_-S<S(Q,/Q437Y7D+\74;E64/Q
M9U>KGIW_5D^]GIW,``![``#.`P.)`P/0!07,!05V!07-"0F="`C6#0W8$!"1
M#0VX$A*O$Q/2&!CA'1VO&!CD(2'4(!^X&QNG&QO`(2"P(2&8'1W/*"CN+R^R
M(R.T)26\*"B_*BJ6(2''+BZ%'Q_*,##A.#C5-C72-#3`,S.P+R_E0D+J1D;^
M4%#V3D[<1D:.+BWY4%"<-C:(,"_,4E'\:6G\;F[I;&S,:&BT86'0='.P966.
M4E+QC8RY;V_=AH7$>'C/@8'@CX_QH:#2BXNUEY>OH*#X]?7[^?GX]_?=W-S/
MSL[^_O[]_?W\_/S[^_OZ^OKY^?GX^/CW]_?V]O;U]?7R\O+Q\?'N[N[L[.SK
MZ^OJZNKIZ>GGY^?EY>7DY.3AX>':VMK8V-C6UM;4U-32TM+0T-#.SL[,S,S*
MRLJ[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"[/6X\`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+U)1$%4"-=C8,`"VMJ:>1BSRJKKZFHJ
M2G-2DD!"+0V9:<55XC&UE65Y:8SI0*'6QJ+D_.@@*S=6R8(,QM0\H%!3%5MN
M0J"2NJE65'92<@X_4(@#:%"BI[0"DX5_7%)62350*#Z-CYO30U;5T"&`*[V0
MO1XHE)Q?42NHJZ9O[^H;FU<NP`L4B@QE\?,R8A85\_8)C@@/"P$*V6C(2\FI
M:`N).+LXVEF:&0"%=!2E9)0UC84EW)ULK<U-]+!Y!P"2/BT;-=4)*0````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=L+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0S(#$P-3$U-#,T,30V
M(#`R,S`R-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/____E04=535-:NK\;'Q^#@W^G1T,T!`,P``,T!`<P!`<X#`\P#`\P$
M!,P%!=$'!]`)"<T)"<P)"<X-#=0/#\\2$ML4%-@4%-(8&,P8&-(<'-0?']0@
M'^0B(J<;&]@G)[`A(;(C([DF)MTO+]TP+[PH*+\J*L0M+<$L+,<N+LHP,,TR
M,>$X.-4V-=(T-,\S,]HZ.M8Z.O)$0^`_/N=!0>5"0NI&1NY)2>Q(2/),3/90
M4/%04/M75\]+2^A75\I-3?UD9.ID9/EM;?UQ<?9S<_]Z><QA8?IY>/^!@?I^
M?OB`@/V<G.&.CO^DI.&9F<Z-C?JSL_ZXM]*7E^ZSL]ZHJ-BCH^>VMLRDI,ZF
MILVFIO;)R>&ZNOK0T.[+R]2UM??6UO_BXOSIZ<R_O__W]__Y^?;R\N7AX=+.
MSM#.SL?%Q?7T]/[^_OW]_?S\_/O[^_KZ^OGY^?CX^/7U]?+R\N[N[NOKZ^CH
MZ.3DY.'AX=[>WMO;V]C8V-;6UM34U-'1T=#0T,[.SLW-S<S,S+N[N[*RLJ>G
MIYV=G924E(N+BW]_?____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$@G7?P````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MO$E$050(UV-@P`*ZNMI94Z/]@Y.;&VHJ2O)R0$(=+0D>IC)"4@&UE:4%C(5`
MH<Y6=A=+!1%N+M'0LB+&_%*@4%N=GXV*&"^'@+A]=DYN"1M0*"O%55=:F$]0
M0LXX*2<M/0,HY.T5'A\5$<D2$Q?KYNS$[``4<K0,:VQNJJLJ*TJTM3#4T00*
MV:C:-3?75Y<7Y_A8F1AH*`.%="7YW3-!+@JR-M/74E,$"LD*<?(8^88$>C*9
MZVFK*\EC\PX`V#0N,]O3E\@`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O9W`N<&YG````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(P,S,@,3`U,34T,S0Q-#8@,#(S,#,Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____U34VQSH[_V=H?SL\S%]A
MSF)CS61FUFMLE$Y/X7AZU'1U[HF*^IB:NW)SYXZ/_Z&C^9^@TG9ZY(2(L&EL
M\I28O'-VQWQ^X8Z1_**FY927_JBL^J:H]J.F]ZBKS&9KT&EPS&=NV'1YTH2(
M2;U64L5?8-%M2YM45*=>;M%Y9;UO9[EPC/"7BNN50KE.*7,P1KU21;I11[M3
M4,5<3;U95,%?8-)K1)%+7L9I<>!]<=]]7;)F;<AV@>N+@NN-B.Z3?]R(BN>3
MF?&BU-4@S;T)X=(XTI<8S'\!YZ)`]K-7SG4-\9M0V'(GS%@%_XUJS",`S1$!
MW3\OSQL2^F=>S`8`S0$`S```S0$!S`$!S@0#S`,#T`4%T0<'U`H*U@T-S@T-
MV!`0BPH*SQ(2VQ04WA@8X1T=Y"$AZ"8FZRLKV"<G[B\OIR$AN28FW3`O\C4U
MQ"TMP2PL]3HZRC`PLBHJS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*
MZD9&_TU-[DE)[$A(_T]/_E!0\DQ,_5%1]DY.^U%1^5!0\5!0U$9&Z5E9_61D
M^&5E____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````?856WP````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"T241!5`C78V#``@P,+'2<G;3,C/0-
M3<RM[!R`0JQ<_/*R`CP<;.R<W+Q\@D)`H:22GMZFK(3(B+C4S(J&CD:@4$XW
MBT]0<G18;$I&45U;:S50B-G?R\W=+S0F,3V_IJ6]M@PHU!?BZ>(:$!6?EEW9
MW%G/5`P4ZFWR]?8(A!I455H(%.K*"XX.AQE47I`+%)(45E)05!81DY*1DU:1
M$!<%"EF:&JNJJ5O;Z^HYVFK;:&I@\PX`*X8P#Q?/^D8`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]G<BYP;F<`````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S-#$T
M-B`P,C,P,S(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#___^(AYI!0*-*2;@[.I);6JF1D-4``%`*"H@,#(D.#H@.#H<1$8X6
M%H\8&(L8&(D:&I`='9DD))HO+Z<W-ZDP,)0Q,94M+8DX.*,T-))"0K<V-I8N
M+GP[.YXC(UU`0*@[.YLF)EY&1JI24\)!09I*2JI$1)E45+M96<186,)34[98
M6+Q<7,%<7+E45*!J:L=M;<=@8*IL;+QQ<<-X>,YW=\IF9JEG9Z=_?\MP<+-K
M:ZEJ:J=O;ZUN;JMN;JIM;:E^?K]Y>;9X>+1V=J]34WN.CM&-C<]Z>K*/C\Z&
MAL%]?;2(B,.`@+5K:Y>=G=IT=*&6EL^'A[J;F]68F-&0D,:0D,2&AK9^?JND
MI-Z>GM:FIMV6EL>5E<:LK.&JJM^EI=><G,JLK-R;F[B=G;J>GKJ>GKFFIL*@
MH+NHJ,.@H+JRLLVTM,[!P=RMK<6LK,3#P]R2DJ7.SNB=G;'0T.FGI[O5U>[1
MT>G2TNFQL<77U^[%Q=J]O<6_O\:\O,."@H?*RM'$Q,NVMKR3DYCQ\?CIZ?#?
MW^;<W.//S]7-S=/#P\F^OL3S\_GQ\??N[O3FYNSAX>?:VN#!P<;Q\?;DY.G5
MU=JSL[?S\_?%Q<C?W^'DY.5X>;&DI=SHZ>_GZ.[-SM.JJZW___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C;_PV`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`,%)1$%4"-=C8,`"..2;U0TL8SWLK6V=?$*BXX!"2J[3@MT3\U*34]*S<XO*
MRH%"]0MF39\2),##S2<LRJ*EJPT4DO7N,6%VF='=U3EQ7N_D_JE`(5;VN0K\
M8A;F5HZ>_I%1H;Y`(;>DF4:J,N)R:GJ&IF;&;/I`H9:VAMJZFL:.]M;>O@GS
M)S4!A70D!;DX>85$I%4T-905I22`0F&S'6SLG+T"Y\0GQ(1'!/@!A?*STC(R
M<PI*JBJJ*TN+"YFP>0<`3[8RW<:V1_4`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M87!H:6-S+V9L86=S+V=T+G!N9P``````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30V(#`R,S`S-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````")4$Y'#0H:"@````U)2$12
M````$@````P(`P```%C,'8X```,`4$Q410```/___]38VWR^Y(+#YQ50;1=.
M:2=\J"9XHBA\IRAYHRU]I2^`J2)9=3%^ISB$JD*7PC^0N#V(K2M@>C%JAD&*
ML#5QCSESD#QWEDV7O#YZF$N1M4)_GD:$HTN,K4B'IE*7NE>@Q$Z.KE*4M4N(
MIE>;OV"LTENCQU*2LDV*J%*1L&BVW5*/KE:5M5J:NE20KEZAPDZ%H&*DQ5R:
MN6FMT&:HR6.DQ&ZSV'"WVG*YW'&WVW&XVVZSU6FJRW"TUFVPT7.XVW.WV6ZO
MT':VUG6TTX#"XWV]W7V[VH&_WH"^W7:OS("[VH;"X(C#X>[R]/3V]U>IT5.A
MQT6!GD5\EE&/K6>QU5R>OF^]XVNUV6>KS&^SU&*<N&JHQLW2U#^0K4N8LS.)
MIC2*IS>-JCZ5LUREOG&VS83'W(W0Y^7IZL_6ULG0T-'7U]_EY=OAX?C]_<[0
MT/7V]LC-R[6YM[W&P:&NI>WQ[K/%MY*AE:2PIFJ#;'Z3?L32PVR&8GV.=J"S
MF%MQ2W&&8FV`7\')N[3"IXN:?'F";'%]7X*'3ZZP?]G9U\7%Q,C$6,;$A).2
M?Z^KH/[^_OS\_/KZ^OGY^?+R\N[N[N3DY.'AX=34U-+2TM'1T<[.SLW-S<S,
MS/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````&8_-,<````!8DM'1`"(!1U(
M````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`)8V41TT@NFS9@S
M)U]0($`['"C$)FSHG98S??:<6;&2@:&6%D`AWF`OS]3LKJ+RF4SJ:E:.)D`A
M\6@?IY3BFH[VRC+S"`=[`Z"0OJ^S:GQ%2T]W8QVS=929,E#(P]U(-*ZDK:^W
MOIG%SE17"2CD:BO-EUC8VE!5Z^\6J1<B#Q2R4>#G2LCJ;*HNS7,)TU*1`0HI
M"G%S)&5.G3RAWR]&0S-(`B@DR,/)GIP[92+CI`QC.5DI,6S>`0"'>S$FD!!Z
M%P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O9W4N<&YG````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q
M-#8@,#(S,#,U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!0
M3%1%````____@WAZE'V(4DA:<%Z'64IN5TY]3DEH;&6.241F+2=>5U**.#9?
M0T6`$!=8&21C(2QM%"%@5&*@$R9F`!A=!1YB)S^!/E*(.TZ!`AYD!B!@!R!@
M""%A"2)B"R5D#"=G#"5C#RAE$RQK#1Y)$RMH%S!N&#!K'#=W'C5P(CMY)3QU
M+$-Z,4F%+4-Z)#9B-4V)+3]N-4J!.E*++3]J/U>2,T9V,D5T/%.*.4U_.$Q]
M-TIZ1%N51U^9-DAS/U.%/E!^1EN.1%B*1UR/4&:?1UR.2U^35&NB4VF@3F.7
M36*546::5FRB4VB=56J?5VRA56F<7'"A87:H8G:G9WRN76^=:'RL:7RL;'^O
M:7RJ;H&P`10_`A0^!21H!2-D%"]M&35T$R9/'#9P(T"`(CQV&RY:-$N!3VRK
M2F2=/%%_15N/46NE4FRE4FNC3&*65FVB25V*5&J>67"E:X&S`"-H`")F`R5J
M!29L"2IM#2]S$#%U'3Z!'SY](4&$&S1G(CML(3EI+U"0)C]P-524*D-V*T5W
M,$I^,$I]-$^#-E&'0F&B1F2B/UJ/1F*94&ZK266<4&REA*:C>*R>8Z^58K>6
M5\247ZF"0+)F2)IBA(AAN+1AG(N(8UE9____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````;U)/-0````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX`
M``#!241!5`C78V#``J*C4S.+BXP38DO+JVJ;N_N`0C&)=I'!62E"_''*6@:V
M[A.`0BHFH6%>.B(L<P0T=&T\_/N!0OH%$0%&\=PSIK.)F[KX>/<`A1RB`B4T
MQ;BF36'FR_#Q=>X`"H4'.6HKB7),G#2;)]?/3;(=*!22IZ<J*\4[>2J3<+ZG
MO74K4*@P35U.1D%PYBS.'&\G*_,FH)!%DJ*TO%HR.VNVKZNEF6$#4*BFHJ2L
MLKJQ*WU";V=;2WT=-N\``-'-,:4?]D9.`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]H:RYP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C`T-B`Q,#4Q-30S-#$T-B`P,C,P,S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```#`%!,5$4```#____1R<7+N++-FHZ_(0"^
M(0!W%`#`(P._(P/!)`3#)@7")07`)07`*`G'+`O)+0W(+0W"+`V#'PK+,!#$
M,1+&-AB,)A'5/!W4/!W702')/!_(/1_)/B">,1N4+AG-1">G-R'B3B_B4"^I
M.B.>-B&P/B;22R^S0"CE4S6U0BJ^1RZ[1BVX1"RI0"K#2S'`23#74SC64SC)
M3C3(3C3%3#/L7#[*3S7+3S;O8$+N8$+05#JS2#+P9$;<6T#663[Q8T?<6T';
M7$*^43N]43OT:4W?8$;D9$GB8DCT:T_S:T_H9DSH9TSS;%#K:$[K:4[R;5'Q
M;5'N:E#N:U#N;%#G:E#+74;L<5?K<%?P=U[@<%GS?&3O?67N?67V@FKU@FKV
MI93,BWWPTLR_(`'$,!;1-AC-02??1ROS9$KJ9D[U:E/P:5'V;E3)7DK(7TOK
M<EOU?VC6>&;FI9K-O;J_&`#")0W+*1#%+1C",!S633CG9%#+8%#(8%#F>VSW
MBWK'=VOJE(;;L:OVR</E237#1#3O5$+/4T/S8D_S8U#;?G/6@7CBHYS1FI/E
MK*;=J*'\S<?+N+:^%@7`&@G7+2'9R\K,N[O,S,S___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!V_:!:`````6)+1T0`B`4=
M2`````EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"V-GE7>(CC,HG
MLO&(2&G:^H*$Q&UB(QVE:^JY!"24+#V#@4+">E'1'FFE$XKY4]/-7`/=@4*J
M8055A7D5S$R-19D9`3[V0"'GN/#*ZJG36+JZDQ(Z_)U,@$(QD7:RDUIRVSH;
M6MM#W"P,@$+1'@I"R2D]?;5-==GNUOJZ0*%0=5'.DL0IO?G].=[VICIJ0"%#
M,5Y6[K+)S0Y9?D[&VAJ*0"$9/E8.04EE*Z\@-W,#+14Y;-X!`.[*+HHAS2/&
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+V=Y+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,S`V(#$P-3$U-#,T
M,30V(#`R,S`T-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X````$
M9T%-00``L8Y\^U&3````(&-(4DT``'HE``"`@P``^?\``(#I``!U,```ZF``
M`#J8```7;Y)?Q48```,`4$Q41?4``?```=T``;D`!`"%0`"$/0!Y.`&%/P&`
M/@6(0PN+1@:)0AB23@""-P![,P"*-@"*-P")-@"'-0"$-@"!,P"!-0"`,@&#
M-`&"-`%^,AB020"&-`"$,P"#,@"#,P"",@!],`!\,`!X+@.`,P-_,P1Y,05W
M,!:(01^5342<90)\+@)Z+#*353.>4S>@5C":3#FA4E:M5UZT7%>N5&.T776_
M77&A887&9W6\483&6(G&7&^14J+3:JS?3J/23[?<5LKP0[W?0\?F/LCD2L78
M,MCL2=SM.^WY/^?P`=+9!.[V+_'X-_S_$?__`/[_`O__`O__`___"/__"L_.
M"___$O__%/__'OW^'_S](?__++FN!:B=")&!"9-^)X]Q!Y)@&8-+!Y`\`I,A
M`9L?!V`X,Z89#+8*!*$+!V\J)_\``/X``/P``/,``.,``-X``,@``/P!`?L!
M`?H!`?D!`:(&!````/___P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````&:.QZ(```!W=%).4_______________
M____________________________________________________________
M____________________________________________________________
M______________________\`J9^D90````EP2%ES```+$P``"Q,!`)J<&```
M`*U)1$%4&--C*,4`#*4I9H;J;$J*DBI@H*P&%,I-C76R->)AE9,6!`(!9:!0
M069^8G"8NYVQ!KN(M)"@"E"H.#.3H23.(R#$V]Y$BD5>"RA4E)F5F<F4'.WO
MZQ_JY6BN`Q-B3(_Q\_4-#'>ST81HS&9.\/0-BG"UTN46U@8*%6;F)47Y1#I;
M&'#QRD*,STF+=W&PU.,4E1$".H(?Y(@,:U-]#CX%,0DP$%<%"F$``+L1/:2[
M?"1B`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O:60N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-#4@,3`U,34T,S0Q-#8@,#(S,#(R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____P<+"LK.SU-74X.#?
MW=W<U=74S<W,RL3!Y=_<_??T^/+ORL/`R,/!HRD`I2H!I"H!I2L#IC`)JS(*
MIC(,KC4-J#0-J3<1IS<1MD`8>BL1ND0=LT(<L$0?KT8CM4LGQ%$KR%8OOU$M
MED4JTV,^U6="SF-`H$XRQ6)!MUH]PF)"T&E)VW!-RVE(W')/T&M,VG-1V7-1
MMV%&QFI,WGM;UG=8VGU>S'99V'Y@WH)DVH-EXXYRT\W+TLS*^/+P]_'OZ.+@
MJ28`HR8`:1<`HR@#K2H%JBH%J"P'=2(*MC40J342LCD4LCH8PT4AAC$9P$DF
MT5<UN4\OSEPZQ%<XW6A&P5L^KE0[V6M*VG!0VG%1T6Y0L%M#VW17Y85JX(-H
MR\3"WM?5[.7C;14`CS<AXV]0U,S*]O#O_O[^_?W]_/S\^_O[^OKZ^?GY^/CX
M]O;V]?7U\O+R\?'Q[N[N[.SLZ^OKZNKJZ.CHY>7EY.3DX>'AWM[>V]O;VMK:
MV-C8UM;6U-34TM+2T='1T-#0S\_/SL[.S<W-S,S,RLK*Q\?'Q,3$O[^_O+R\
MN;FYL+"PIZ>G____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````#X'?+P````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```"^241!5!C3;8PA#L)`$$5G=V=W
M6QJ2)D@.0(*F&HWF"!C"!1"@D%208!#<@,-@:""I(*E%$IK2V:%E/3SY\M\'
M^$'`K(@"VU8U.414&!\1BENWQ\^R9(7&8#@$"3J,VZJJ&R%1*ZLN@-!_#-AG
MC?:9EM=AAO`.\^>+6&F#'128^56DSJ,[3HT3IS81G'LED[&=M.2H+A=!)R5_
M'^Z-!&9V-#=[NTF]"E;*FP\1&+O64GBUU=`PDSMHN[-R*>`/7ZA71QG4ISZ^
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I92YP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`Q,2`Q,#4Q-30S
M-#$T-B`P,C,P,30`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#___\`>P``=P``30``3``#>P,#>0,%?04)?PD-?@T*5PH2A!(8
MB!@17Q$?C1\?BB`9:1DGD2<A<2$JC"HKBRLNCRXJ?"HQCC$XGC@UEC4XFS@R
MA3(ZCCL^ESX[CCM(JDA&G$90L5!0KE!7ME=>NUY3I5-9KUEDOV1DOF1HP6AE
MNV5JPVIJMVI]R'V(T(C>X=[4U]3)S,G(R\CT]O3CY>/5U]7-S\W,SLS)R\DP
MER]!I$!FO67-S<SJZ>?V]/+R\.[>W-K6U-+0S\ZG41NP6"&R6R.Y7R:\82CR
M?S6_8RK$:"W!9BS':B[*;##-;C'2<33/<#/5<S;ZBD+8=SG:>#K@?3[\CD;E
M@4+JA4;_DDWNB4GA@$7_DT_^E5#RC4S]E%'VCT[[DU'YDE#KC5+UF&#5AU7\
MHVSEE6/_J'/RH&[[J'3D:B'N=B_*:3#2;C3X@C[@>C[^C$KNADG^D5#YCE#_
M_?S]^_KZ^/?HY>3^_O[\_/SZ^OKY^?GX^/CU]?7R\O+N[N[KZ^OHZ.CDY.3A
MX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#.SL[-S<W,S,S___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````"J!":X`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```*))1$%4&--MS+T-PE`,!&#;>2__($$#0F(/QH"E&(2>BB&@IZ!B`UH@
M<?QL'(D.KOSN=``_00@P:>=QET<XS9;W:7$(@%4S-8P!U$JLO2'(JT8-`YI8
MF16Q<RKKC'NB8TH;I#P-3FW#78>PE70FPIZ=UOWBR:SB*\*.U>DQW#B92U+R
M8B1>N40705.1\>M]%2%V@8M^5R_A+%B2?69J20W^Y`/6@%P6!X(+DP````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VAR+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#0U(#$P-3$U-#,T,30V(#`R,S`S-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___[Q!0[U=7ZQ(3,&D
MI<U$3)$/(*%-7X,U2:2@H7([5UD;/5X50<:FO%4G2T8E4()@C%(V7'IRP$=!
MJP``A04%B04%AP<'APD)B0\/BQ`0DA,3DA@8D2,CGR4EF2$A?Q\?>"@HB#0U
MKB<G@BXNDBXNC#@XJ#0TFS4UEC,SD3L[GT)"K#X_F%!0PU)2Q$Y.NDM+LE55
MP$E*CUA9J5!1EV1EL"4GI2\QD3$SD41&ODY1P5=9H7)TP75XQ7=[S,7&Q^WR
M\LW1T?G\_/?Z^O'T],[1T<K-S?O]_?K\_.'CX]W?W\3&QOGZ^O3U]</$Q+R^
MO=/4T]'2T<C)R.3DXM+2T/S\^_?W]O;V]>?GYM+2T<?'QMO7UL7`O^S;V,EZ
M=L>FI.1S;^>II\P``'\``'T``,T%!<P%!=`-#=40$)`1$<P9&=T='>$A(9L9
M&>DO+XD<'.\U->$X.-4U-?5"0K@R,OI&1N5%1,0[._I/3_Q04/504*T\//97
M5_%65OA>7OED9.M?7NE@8/-E9?QJ:O5H:,U96>1L;/=X>,!>7L9G9\)F9M)P
M<,)L:M%V=,=^?M&)B=O)R?CS\_?R\N[IZ>SGY_GU]>SHZ.3AX<_,S-?5U>CH
MZ.;FYO___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$DZG7L````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````ODE$0508TV7/,4I#01`&X']V
M9EY\>5NEL3!@F48A1Q#$@P1R%D$0;(.>04AM[P'2V`EVEHF1Q.S+S*P'R'>#
M#SA!F%,[S&57S)A%5.X%T$%W?.`F^ADG9H(@YXXBM;U()X.D#L'SD]>1;X,>
M6PN2=Q!NSKSYNYC&L5NRFMJ;X!Q.QD;#%8\244'"_BX:77_(RNKA]D`.P<^B
MY+K]OG[5J_5+4P*$R;X/TO'GY#>9N<<7(QM8N5SN!(Z*NCG]X!]Y(TG\UHQJ
MI@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:'0N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S<@,3`U,34T
M,S0Q-#8@,#(S,#0R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____UQ@9Z"HN]#Y"^TY/N@D4P2LTUT%+[D]8[X6+PR`LO#`Z
MQC5`VD91Z5!;ZUYHZV5OLJO8IJ#&C(#C)1B^13C00#3#/S.[4T;I3D+41CJY
M75#M6D[E=6KO8E?EAH7(``#'``!]``!\`0'+`0')`P/(!07+!07("0G'"@K.
M#0W0#0W)"@J($!#3&!C8&!C.$1&0'1W;(2'@'Q_/&1F:)R?3*ROE(2&G+R_I
M,"_;-37M.CKS*BJN.#C=/C[S0D+U,C*X1D;X/S_?04'B2DK].CO#34WZ24GJ
M2$CH3T_Z3$SQ4%#[45'\4%#U45'V1D;34%#P5U?R4U7F7E[U65GE9&3X:&?]
M967S:FK[*"O.G)W6>(JX7V=[>9*ZD+"U@9F::W9R55Y.M["1QKZA:6)/ZM+&
MQ:.7R```QP``Q@``RP$!R0,#Q@,#R@4%QP4%S`@(R`D)T0T-S0T-TQ`0RA(2
MS1@8W!T=WR$AT"`?S"$@I!L;UR<GK"$AZB\OKR,CMB8FV#`ON"@H[#4UNRHJ
MP2PLPRXNP"TMS#(QQS`PW3@XT38USC0TRS,S]D)"V#HZ]T9&VS\^X4)"YD9&
M[4E)ZTA(^T]/^E!0[DQ,^E%1\4Y.]5!0^%)2[5!0_&1D_(%_____````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````NC1*A@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"X241!5!C3;<'?20-!$`?@W\S.[H5<5/*G`K$&0;`1&_'%4@0;\#4U
MI`Q?!"60(!XFM[-SNV,!^GW`'X1K6BW7>ABRIB[.NOF609>+E0UGU2B2XHS!
MF"\V[33D*8C$U,4"0;_F\GVSN^>:]RE-!L'[!XW^9A2V'`/5"L+2<S!ZX%!>
M/;G[#^%E_!SSU7$BOBMF6I\$?M#2SL]$=.NUN4%P/)4:Y;&_Z%JQ,E4PODQ9
M0NJ3J-96&_[Q"Z/%5JWMM<Z%`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]H=2YP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`R,2`Q,#4Q-30S-#$T-B`P,C,P,S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____^]O>FH*'5U-7'
MQL?4U=4`;P``;``#<@,%<`4%;P4)=`D->@T0>A`8>Q@=B!T?@Q\AB"$;9QLB
M<2,G@"<A;"$OF"\I@"DMA2TH=B@J>RHUF34N?RXPA#`TB#0XDCA"IT(YD#HV
MB#9&IT9"F$)&GT9/KT]0K%!.ITY*GTI"@D)0FU!=KEU1E5%=HUULNFQKM&MQ
MO7%NM6[S]O/FZ>;9W-G'RL?[_?OY^_GW^??J[.KHZNC6V-;4UM3/T<_)R\F^
MP+XVC35*BTG*S,GGY^:T``"S``!Q``!P``"U`P.X!06V!06U"0F]#0W!$!"]
M&!BX%Q>W%Q>$$1')'1W-(2&^'Q^.&1FZ(B)^&!C7+R_)+2W;-37..#CD0D*K
M,C+6/S_%.CKG1D;204&V.SOJ3T_K4%"C.#CE4%#D45'D5U?L8&#G7E[;65G=
M6UOI8V/F967N:FK::&CL='3,PL+0Q\?/QL;+PL+<T]/:T='TZ^OGWM[]]?7\
M]/3QZ>G?V-CQZNK3S<WX]_?^_O[\_/SZ^OKY^?GV]O;R\O+N[N[JZNKEY>7D
MY.3AX>'8V-C6UM;2TM+0T-#.SL[-S<W,S,S*RLK___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"1*FJ"`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```*I)1$%4&--MC$L.P5`40.^W
MVE),#"W$#BS'M`D2B5B$)5@$VS$@(HTTKWWW79USAB<G!^`'A#7,JBHT3>Q4
MLE$F9P$L\TD?@O7"JL0$`O/I&"V1BJH6)#ZHR_ZPU0(-A9R0?7AI/&4L8)9B
M=!'=$.R.UYHA)3?;,=<Z5"NFK"F\=1="8KP)=*']F!0Y<_+DB_NP?[ZBD80R
M%XQ=>D0@>%M$)E4&6WKJ#/[P!=571;)47@'!`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VEL+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W(#$P-3$U
M-#,T,30V(#`R,S`S-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/_____^_]74U<?&QX2'B\/'R_3X_+;,WLC8YK/`RP-%=@IQ
MO@]TOA)ZQQ)UOQ1XPA18BR."R"-^P1Q1>#&$P2MRIC6%PC6%P#R/S#9]LCJ%
MO$>AY3%PGD68U4".QT&.QSEZJDR=V4>0QD&$M5BO\%.@V5VS\EJMZD^6RE^R
M[U6=TUZMYUZJXUVCUVNZ]&JV[F6LX'>_](K(]H&LS(*IQI*XUJO3\9NUR)VV
MR:S#U*O!TLC?\:R]RK+!S;3!R\;+SZJNL?7Z_K*VN=C<W]'5V,C,S^KN\0=R
MOQ1WOA^"RB*(TB!\OR:"Q2B`P"^0UBR'R328X"V"P#&&Q#N4U#-\L4>G[3R.
MR42;VD&+P5.O\DVDXE2L[$Z?V39ME4B.P&&S[F"JWVFU[&ZZ\5F4OGJ\[*.[
MS+G2Y-_P_.+O^,+(S.WS]\S/T?C[_=CF[]_FZM;;WM39W.#EZ/'W^N3J[>+H
MZ[W!P^GN\-35U<'"PN?GYN#@W\W-S/CW]]W<W/[^_OW]_?S\_/O[^_KZ^OGY
M^?;V]O7U]?+R\O'Q\>[N[NSL[.KJZN7EY>'AX=O;V]K:VMC8V-34U-+2TL[.
MSLW-S<S,S,K*RJ>GI____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*D6S2P````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````P$E$050(UV-@P`)$1.)2C%/U%$2#@B65=)*-@$+<@E))"1%"_#P>
M?-Z!85$Q0"%6QR+V4M?)%I83"_*SG8I+@$+3)S)UU-F91BJ;<;;5-[17`X58
M&%M[)]E+I%FIY376M_9,`@K5-E=53.$2M^;0S61LZ6:>!A1JZ)HP>:JMB;:A
M>4939W]-)5"HO-"!+2NG+]VF/M?=Q:W,&2@DY^O)*^#E+Z.JKA$K+QTJ!A0*
M]_,1#@B)UM(W2-2,5U&4Q>8=`(M@,*,G#W+-`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O:6XN<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P-#`@,3`U,34T,S0Q-#8@,#(S,#(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____J(Z4EX60U=35
MQ\;'\O#YR<G,HZ33IZB[F)_+?HBWE9['@(Z_H:W6<X6\?(NYEJ*^U=[OM<#)
M[/'R^O[^RLS,U-75Q\S+]_OZZN[MZ.SKU-C7R<W,^OW\OL+`UMK8RL[,R<W+
M;K1C8JI3A<9V19(P2Y<W4ID_5Y!):JM8:*-8=;)DA,-SB\QZ1Y(R6J1%8)E0
MB,MU/Y`?.74A4YTX)'<`*7P%*7H%,X<--(40.8480I0=1),A-7$;/GHC1H0J
M0GXH5Z0U28@N4)`T7Z%"9:I&;[90:[!.*'P`*GX#+X`)5*0O3HXP5)8U9K)"
M:+)&<;I/<+90Y^?FS%(`?S,`T%8%S%4%V&`0U%X/SF`2Y&\AG4X9V'`KZWHO
MX7PXLF(L^(I!_(]&QG,[_Y90_I90[HU,[(Q+^Y=4_:-G?S(`SE(#R5`%S%,'
MS58)UEP-BS\-TF(8E$01X6H=WFD<U&8?[GHO\H`U^HI"NV@RYX)!_Y1/^9)0
M]I97^IM>Z91<]Y]E_Z5JS[BKW<>[X,S`_NC<\=W2U,.YZ-##IY:-]=W1_>?<
M\MW2_^OBPJ^ML9V<^/?W_O[^_/S\^OKZ^?GY]O;VZNKJY>7EX>'ATM+2S<W-
MRLK*____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````.T*-R`````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"Y241!5!C3;<%-3@)!$`;0
MKWZZ>\`@!")(-'@JSN"*L'$+'D!7QIUW\2ZP(!&"1B$P,%-='D#?`_X@C)'2
MJ%YV5\8LMQMY4UP5*9GU3S90%1H2%/'S[B,?K'>]O5F+:(9B.(C)O/7@S^=^
M%:D$(=2O0K/*C>+<E?F>\?3R_DC?9<7GGZG0A$$8&85C.)QR(4J1;:%((:=`
MO;VW:W>/)12=:+D0Z5X>R=SS#HK<R?3%;:&+?<-WWL0_?@%1.$=6NGDVX```
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]I<2YP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q,#4Q
M-30S-#$T-B`P,C,P-#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___^(&QSS5E?Y>'G*PL//R,G]]O?\]?;QZNO;T]7\]??P
MZ>LO+B\M+"T_/C]Q<'%C8F-655;5U-5/3U#W]_C\_?[)R\S#Q<8B(R/.T='B
MY.3BX^/V^OGN\O#BZ>6\P[[&U,F\VK^CMZ6FN:C&V\B.LY%OGW)@E6!HE6B7
MNI>AQJ&&HX:;LYO.X<['V,>ONZ^XP;CI\.D?(!^[P+OK\.OJ[>K&R<:^P;[@
MXN#5UM72T]+(R<CL]>LV-C7'Q\;;UM7'``!]``!\``#(`P/+!07(!07("0G0
M#0W3$!#.&!B0$1'<'1W)'1W''!S@(2'/'Q^:&1G/)27))R?I+R_M-379,S/=
M.#CU0D*X,C+X1D;B04'E1433/S_#.SOZ3T_Z4%#U4%"N/#SR5U?U7E[Z9&3J
M7U_H7E[S967W:&C[:FKE;&S&O[_5SL[*Q,2DGY_NZ.C?V=G0S,SX^/CV]O;H
MZ.CFYN;1T='&QL:\O+QW=W=R<G)P<'!A86%45%104%!/3T].3DY-34U&1D9%
M145"0D(Z.CHX.#@U-34T-#0S,S,P,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8
M&!@0$!`-#0T)"0D%!04#`P/___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!+9+&8`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```,!)1$%4"-=C8,`"G)P#X[*2P[W<'%T]_4.C$H!"SMZ1&2G1`>Z.
M+AX^(1'QB4`AIJ1LEO388#_?H+`8YM3,-*!0?A$'#U=>#BM;;B$G.W>!`U!(
M0DQ.345<05E=45Y6255:"BA44FRIJ6-@J*NAKV>KK25L`Q02+2NOL#`QMY(Q
M,S(MM;:O!`I5U[7Q\G7QBP@*5-74"C6U`(7:)T]GF#YE0D=S?6-K9V__!*"0
M\32&&5,G]K0VU#?;=?=)3L+F'0#]5S">O;>-"P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VER+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#0Q(#$P-3$U-#,T,30V(#`R,S`S-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/____I14LMT==-[
M?,FRM./AXOKX^OS[_.+AXL_.S][=W\3#QOO[_/+R\\_/T/3U]M#1TL?,S/7Z
M^N[R\LG,S/7W]\_1T<?)R<;(R/3U]?+S\^7FYN+CX\W1T/K\^_+T\T^94DR5
M3@!S``!R``!(``!'``-T`P5W!05V!0EV"0U]#1"!$!B!&!%:$1V*'2&/(1^$
M'QED&2^:+S6?-3B7.$*I0C)_,D:M1D&=03J*.U"S4$^Q3U"N4%>P5UZU7E6;
M566W96J^:E:85F:E9H[`CL'&P<_3S\'#P3IF.6.H8G*U<5Z-78+"@86^A)#,
MCY#+CXG!B*#3GNKLZ-'3S_;U]/?U]-#.S<?%Q,6LJLBJJ.G'QL>RL<@``,8"
M`LD#`\H&!L<'!\@)"=$-#=,3$\T:&MP='=$@']\C(Z0;&ZPB(NHO+Z\C([LJ
M*K@I*>PV-L<P,,,P+]$V-=TZ.<XV-O9"0O=)2>%#0^9&1OM/3_504/%04-MR
M<<QL;,=I:<9M;-!T=-9\?,IU=>*)B;5R<MB+BMN/CL!\?,N%A>V?G_BIJ.^B
MHOBKJ^VEI>6EI=>FI>&\O/GV]NSIZ>KGY\C%Q:.AH>WKZ]O9V?KY^?CW]^?F
MYM/2TLG(R,C'Q_;V]M75U;V]O?___P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````!?DW^@````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````NDE$0508TVW!,3($41`&
MX+^[_YGWS,Z04*6*#"<0*%4"T4:;2QV#*JE@E<`AW()4Y!!R&66Q.]W:`?@^
MX`_!`89:_>O;5PU)VA,AM2DQ>HPT,Z6`V+/EX)_=2^YVHBH"Q6PR.VVU.3HN
MC[66Z11`7W<FW59CO-LLP_K:!@AVVLOJ;-^?<WO417TCYB+Z<')SF/?7[:(/
MG@OF'I%)K:FRU(PKXO7=0\E2;B\](AS$1[B:6FL7,?Y$)O[Q"V50/^2)H[Q'
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O:7,N
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U
M,34T,S0Q-#8@,#(S,#,U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____VWAYK9ZOJ9FLE(*BEH6DH)6JT<3=S\/:DH*DFHFO
MHY.XQ+?5GH^SLJ7$CG^HS\K<HIVV#@V+#@V)'1R3553$`0&%`0&#`P-4!@:'
M!`15!`14!P>'"0F)"@J,"PN+#`R)#0V,"@I>$A*0%!28$Q.1%A:5&!B7'!V3
M%!1G(R.>)B:C)R>B)268*RNF'Q]X)B:&)26`)R>",#"?-36M+2V/.CJS.3FP
M.CJR*BJ!+BZ,+2V),S.8/CZU,S.3-366.3F=/CZH.SN?1T>[/S^F2$B[2DJ^
M3$R_3$R^34V_24FT1T>M3$RW2TNR45'`45&^4%"Y557#5E;$5E;#557`4U.\
M65FX>WNX=W>E?W^OIJ;=FYO.IJ;;!PJ*#`^,)"BE(B:9'1]R,C:P.SZK-SF/
MBHO&D9/-FIO4B8J[J:K@;G*P=WNZ/TRD15*I4E^U8F["2U.-<W_/@X[<?XG1
MAI';0%"H<7S`<7NXEZ+DS"P@T"TBUC8KSCTSUD4\X51+VU!)[F5<[&IAREQ4
MU6);^G9NYVYH^GUTZG1L_X%X^7]W_X=_^HB"^(V'RB,<U&MH^9F6\J">_*VK
MQPT-S2$ARBLHT41#Q5)2QUQ:S%]>X'AV[HF(SWMYXHR*Q'EX^YV<\IF8____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````%88K\0````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```#!241!5`C78V#``J0ED]B[>5-$%:44U'4M/8*!0C):J9SM_(DB
MLG)JVJ9N0:%`(66K<(XF/B4)<7D-?3NO`&^@4&%%I6"#4%EN7GY!47%I23E0
M:-ZDB4Q3IL^8V3]K]H3Y"^;.`0KU]K1-FSRUMJZ^L;6SJZ.E&2B4E9[#W,>2
M'9&6$1T;DQD5"10*-%'AJA)0U3%W]_=UM34S!`HY:<:S5G,G6'B&A/DXVML8
M`87TA./8:GB27<1"_9P=K(T-L'D'`#FK,J4&D>R+`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]I="YP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`R-B`Q,#4Q-30S-#$T-B`P,C,P-#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____0-3;HU=8`
M<```;@``1@`#<0,#<`,%<P4)=`D-=0T*40H/=P\0=Q`2>A(3>Q,7>Q<8?A@1
M61$;@1L?@Q\?@B`98ADEA"4GB"<A:B$J=2HXE3@XDS@R?C(ZACL[ASM(HDA0
MJ5!&E$90IU!7KE=4IU1>LUY9J%EDN&1DMF1HNFAEM&5JNVIIN&ETP'3"RL+!
MR<&^QKZ]Q;W2VM+)T<F^Q;[+TLO:X=KJ\.HPCR\\E#M!G$!FM67-S<SJV]K2
M&QO>(2&C&QO;)R>K(2'H+R^N(R.U)B:W*"CL-36Z*BKE-C6]+"S#+B[`+2W(
M,C'%,##.-#3--#3*,S/R/C[T0D+5.CKW1D;O1$3;/S[@0D+X2DK0/S[D1D;Y
M34WI24GY3T_Y4%#W4%#Q3D[M3$SX45'T4%#V45'@2TOY65CM557V6UO0O;W6
MP\/>R\ORX.#_[N[ZZ>G][>WVYN;^_O[\_/SZ^OKY^?GX^/CU]?7R\O+N[N[K
MZ^OHZ.CDY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#.SL[-S<W,S,S_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#NE&4L`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*])1$%4&--MP3%2`D$0
M!=`_/3L[PQ:+@F51!D9D)-Z"S)N9&IMZ`(]A2)4F),:$*MO-_&D/(.\!_P3T
M6);K8=<G?.U#60PO'3#FT3UU:"'*?)8@Z,O0)N^"UU"N9EDA6)1HMR9OY/.8
M,PT1-W/5XVJ[J7SPB)-^".YMK<I62<G)7AL$1SO\T"M)%]7'"H'>_=(;R2IN
M]#,$]FF,B:P(;3(C!#J=I7/6I_C^[6P-%_P!2+5;NG;TAW\`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VIM
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W(#$P
M-3$U-#,T,30V(#`R,S`S-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___SLZ.S8U-FAG:!\@("LL+`UV#3J;.@1M`01L`0YW
M#1)Y$">+)C:)-4*706NX:A1Z$%&G3BB)(5>M4`QQ`R>('2>!'TZ@1@UP`!%T
M!1)S!15T"21^&#N9+T"<-4.5.$VH0E*J1EFP3UJM4&&N5QUY#4:*.QM\"C./
M(2)]`S*+%$B-,&6U2C*#`#F)!X?$7E.<'6*C&'2S*U>7!86X0H*S&(2Q)V&!
M&9S*-8^R`)&U!Y*L*LGF4:6[`[;+%,_B+]_N9;S)`+_-"L?0-.;Q/F-D4(B)
M&\S,`']_`'%P`"TM`,W-`6UM`:FG`]#/!<S,!<W-"=;6#4Y-!=?8$,_/$N'A
M'>CH)FEH$:^O'^OK*[*S(W9V&-73+\?'+OKZ0KN[,D%!$OS\1JBG+___3>SL
M2+JY.O+R3,&_/NOJ4')R*,3$3WEY-:FI41H:#9&035E9,VMK0F9F4"@H(4)"
M.%-323(R,3`P+S\_/D%!0+JV`+"L`]71(>;C/O'N9)&066!?2@\.`&9E96IJ
M:F1D9%Y>7E=75U%145!04$]/3TY.3DQ,3$E)24A(2$9&1D)"0CHZ.C@X.#0T
M-#`P,"TM+2HJ*B<G)R8F)B$A(1@8&`H*"@D)"?___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````*)H:!L````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````P$E$050(UV-@P`*\/"W4!5059*4EI7@T+9,R@4*-$0F.!OSB
M,I*BW(8.\=EN0*%94^OK4LW5N#@US*)J\]M[@$(S^EB*DD/M]/3MP],:VKLK
M@$),S6T39P97^8?4Y/1U=/5/`@HUM5:RSO:N#@J++>SLZ&.>#!1JZ9V6Y^OC
M;&3LFI);.J&,#2C449[HYV&MS<NA:YN>43!E.E"H)";`R4106%Y)1,C4)2ZK
M&"@4&6BEQ2XFIZBL(L&G8Q/MCLT[`%?Q,@9R=(O;`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O:F\N<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(P-#<@,3`U,34T,S0Q-#8@,#(S,#0P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____RAL<^VML
MSY.4R0$&P4)&Q[6YX=W@]?+U\N_RY>+E[>OMT<_1Q,+$NKBZ]O7VY^;GTM'2
MZ^OLT]G<O<7%W.'A.CL[[_'QY>?GY.;FUMC8[_#PXN/CV-G9R\S,TM33.4A`
M*7TP-H8Z`'L``WD#!8`%#7X-$(,0'8L=(9`A&VH;(7(A(G0C+YLO*'PH-:`U
M*GXJ+H4N,(<P-(XT0JI"1JY&0I]"1J-&3[)/4+-03JU.4*]01I!'/W<_6:!9
M3HE.:*UH:*=H;K!N(RHC&1H9[_#OP<+!-I`U1X!&6I=9#FH`+C(K044^7%]9
M861>96AB&!L4(20=4U9/&1L40U()1$H(:&AE>2T%:E!+%@,`LRT?IA(#:C<R
M600`SFADOG%OR0``?P``R@4%R0D)S@T-B`H*SQ(2SQ@8S1@8BA,1SR`@TR<G
MHR$AVS`OL2HJR#`PX3@XW3@XU#8U\5!0YTQ,[5!0PD5%Z5E9T%)2^&1D\W=W
MX82#\965RZ*B]-G9^>3DN[BX_/S\^OKZ]_?W]/3TX^/CT='1R,C(:FIJ7EY>
M5U=74%!03T]/1D9&0D)"04%!.#@X-34U+R\O(2$A'Q\?'1T=&!@8$!`0#0T-
M"0D)!04%`P,#____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````.]6\_`````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`241!5`C78V#``N*B
M7,4[NR=.G\TP>\:427T]0*&DK-CPK@E39S',F3EM<G\O2"@MOR(^4M$E,"3(
MQS?8/\`/*)1;R5Q2G-`HZBXO)RDA(Z4`%"IOJ"W*2"ZHDY9U:VYJ;6L'"E77
MUV2G)#*QB`FW-`D("G4`A:I*<U)9V=A%.'@XN;AY^?B!0F5YZ3%A2LJV]H[.
M3EX.GG9`H<+,"&\U#2T#,RMK<Q,C?1V@4'2HBJJZIIZII8V%A[&AKC8V[P``
MY-PQ?ZF3QPL`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K
M92YP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-"`Q
M,#4Q-30S-#$T-B`P,C,P,C0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^3%A>Z+S#`-3;!/3ZT.CNZ24KG?7ZH75['+S;(
M.3_33U6]3E+(55K57V/I;W3W>'WQ=WR],3CG;7/XAHP#`@,_/C]X?GY]@8$Z
M.SNHVK9MJ'T`<!L#<AT)="(->R<?@S<;9RTB<C4PF4@J>STPA$0VC4I1K68A
MB#A$IEA*H%TPC$%1KV1?L&YEFF]OE7:>R:8A@#!GFG!QH'F&LHUXGW^!J8B@
MRJ<`;!`%;Q48>R<A;"PH=C,N?SHTB$$XDD5=JVF/N)4%<!)"F$V7EY:;@6"H
MCV^;9E#$E']13DVC```^``"C!06U"0DT`P.6$1&\&!B\(""W)B:@(B+,-36[
M,3&U,#!;&!C+.#B]-#2^.3CF1D;60D+004#/0D+#/S_41D;J3T_G4%!@(2'?
M3D[B4%#,2$C@5U>\2DJ[2DI3(2'96EGE7EZ[3T_D967K:FK49&2@3$S5:&CM
M=W?:;6W7<G)9+R_UA(3J@8'TB(C-='3IA(2D75WWF)@;&!A`/3U54E)H965S
M<7&6E96BHJ*4E)2,C(R*BHJ)B8EW=W=J:FIE965A86%>7EY04%!/3T]&1D9"
M0D([.SLU-34R,C(O+R\A(2$='1T9&1D8&!@1$1$%!07___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!0HM^``````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+U)1$%4"-=C8,`*9DIU-TV>-4>L?O;T*1/[02*SI_;T-3>F
M1#1XS9@V:0)(2+RWK;53LC8KDU.BJZ/%M1TH5%1=5U.<%Q#-&E)84E%56084
M8BO(B`ST]0D.RPZ-24Z-CP(*Y>?&!?EY^S,GE,<FI26RA`.%1$5XN+F$F=)S
MV(4$!?CY>(%"%J8FQOHR'J4<GM*&3N9F!D`A!VLK2V<C'3=W/4<7>SM;&Z"0
MHKRLG(*FBI:NAK:ZFJJR$C;/``!SZ3$`8-]UB`````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+VIP+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`Q,C,U(#$P-3$U-#,T,30V(#`R,S`S-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q410```/_____^_]74
MU<?&Q]35U<;'Q\'"PK*SL]35U.?GYN#@W]W=W-75U,W-S,`A`+\A`,$C`\,E
M!<0H!\DM#<PQ$-(X&-0\'=A!(=]**^).+^Q</O;MZ[\>`\<I"L@H#,XQ%,,Q
M%LID4NE[9_2'<_:.?/>1@-B%=\$:`<`8`;\8`<0R'-L\)ML])N5*->A1.NY9
M0L=M8/61@L=Z;LV`=<B!=^"@EOJVJ]6<D_>WKO&_N,RGHMN_N[\5`+\:!<XH
M%/);2O->3<F5C].ZM_+JZMC4U/CW]_[^_OW]_?S\_/O[^_KZ^OGY^?CX^/?W
M]_;V]O+R\O'Q\>[N[NSL[.OKZ^KJZNGIZ>?GY^7EY>3DY.'AX=K:VMC8V-;6
MUM34U-+2TM#0T,_/S\[.SLW-S<S,S,K*RL?'Q\3$Q+^_O[R\O+N[N[FYN;*R
MLK"PL*>GIYV=G924E(N+BW]_?____P``````````````````````````````
M`````````````````%6D%:H````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````MDE$050(UV-@P`**BO+9&/VCXE-2$F(B`SS=04(%67[>X<ZF
MQM:Q44'>C#Y`H<*<,(]@"T4M37GU$%]&KR"@4%X<4Z"-MBR_L(*.E;M'`#=0
MB`5HD(F=@)"HA)Z1NW]$/%#(S9N+U=!64$1<RD#-)Y0Y%2CD$1R3Y*0A)R8I
M[6@9%,W'#A0*Y$E,25&RU]5W4'7A3DS/!@J!7>1JIJQB+A,1GY:9"Q3B3$Y)
M@K@HE#<U@R,/FW<`\)LGY^3+BB0`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMG+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,T,30V(#`R,S`S
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M__K60O')-<N<`<J/`]*7"O.].LR+`<N.!<^/!\V3#=F=%-R@&/:_/LJ)`,F%
M`.6D)LN!`=2-#>*=(>NJ+\E[`,V'$MV4'>BB*_NV2ORY3<IY`]&#"N6:)MB#
M%-%C$,I8!=%?)_6"1OB(3\4Z`,D^!\5!"=9/&/:`4<M'&/1V1NA?-<0L`^MA
M.O)U4<$G`=E$(<M!']1/+_5Q4,`A`+\A`'@4`'@5`,(C`[\C`\,E!<,F!<`E
M!<$H"<HM#80?"LPP$,0Q$L8V&(PF$=4\'=A!(<H]'Y4N&9\Q&\U$)Z<W(:HZ
M(^--+^).+Y\W(;`^)M)++[-`*.93-;9"*KY'+KM&+;A$+,%),*E`*L-+,==4
M.,M/-<E.-,5,,^Q</LM/-N]@0M!4.K-(,O%D1MQ;0-99/MM<0KY1._1I3>!@
M1M]@1N1D2>)B2/1K3_5L4.AG3.MI3O)M4>]K4/%M4>AK4.=I4,M=1NUP5^QQ
M5_!W7N!P6?1]9/-\9.]]9>Y]9?:":L`?`+\>`,$A!<HJ#<(J#<PN$,<R&,DY
M(-]'*]=1.-=2..]=0MQ:0?-E2N1B2>)?2/5H3^AE3/-H4.MF3N]I4/5_:.YF
M4/___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````&S$
MD8L````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(
MUV-@P`(LS#TR&BJZVYN;K!W=@E/R04(NR?55O4;JJKHMKGZ)><5`(8?(ZMH)
M2MPL'+(:G?&9)3E`(?_R:67&XJP"7#QR>GU%!6E`H8R&RBXM3C%%!1%FY<F%
MZ;%`H;JJU`YU?AEA"5$FE>G9"1%`H9I<KU8#(39>23YI_?ZDJ'"@4&F@DU6C
MFKP@NY3FI+2XL`"@4+2SK9E-FZ&.MLF4]-C0(&^@D+N=J:6]JV_/Q*E9,1$A
M/I[8O`,`_%HP7'9OO.T`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O:V@N<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P,S(@,3`U,34T,S0Q-#8@,#(S,#(T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____PQ(6A`X0P!47Q!<;TAL?SBHMWS$T
ML"LMTC4WNS(TJBXP[41&]5)5Y$Y1XDY0\5=9Z%58X%U@]&EKQ7!QZ*FJ\[.T
MR`X3QC<[P&]QW(Z0SX:)ZJ&C\[.U'!2>+22L0#B[44K(6%#%6U/,$0J73$:W
M%1.</CVL#`N9!PAA#`R:#Q"=$1*=&1FE(R2F&1EU*"FR*BNI*2F..SO!,3&8
M-SBB0D.Y34[..CN;2DJ^65K56EO19VC4;F[4``VH``AI`Q"J!1&L!1*I"16J
M#1FQ$!VU&"2Q'2F](2W"'RNT&2&&&R..(BR9+SO,-4#0*C.D,#JO.$/#-C^X
M0DW91E+<.D.N1E#,3UG?4%O@4%K:5V'::G/DU+RO^.3:S:R=Z]/)_^KAWL&V
MS)F,SIV1X;6KUJRC[L&X^M+*S()TV)6*^ZVB\K.JS4@XT59&S&9;T(!WSR\A
MZ$8XS$0YY&5:S2,8_VQCSA(-TBHCV"PGIR4AP3`LRC4PS3<QTCDTU3HVVCXZ
MYT9`X$0^Y4="_E!*QS\[ZDM&[DY)[$U(\E%,_591]E-.\550U$M&_%Y8]EQ7
M^F)>_6AD_VQH^&IE_VYJS`,#VQ04P!04P1@8U"`@W3(O]3XZX3LX_E)0^5!0
MUDY.____````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````.%'(-`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```"S241!5!C3;<$Q3L1`#`70;WLR$42*5JR$1$\!
M)Z#E7%L@6@[`&3@--10H-4N!Q$91)AZ/S0'@/>`/PCV&(<>ZF$F2G--+PE?>
MYFAE86&1)`2"G/5D:WVFQV_N2/R'<-AW.KY=O]/-Q^TQQ_;`&/JVF\HD-NE\
M16I(&.UTWK1RS/2YJ^9(\%(F->_<93FJ!P@7I<9E[8-IBZ?#R5?"77%7)2(.
MX3'\-6&OE9/DG+B91PO\XQ=3%UHG:HU[M@````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]K:2YP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q,#4Q-30S-#$T-B`P,C,P
M,S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___$.COZ9VB^BXS+H:*^EIK4QLRFH*J8F*B>I,2JKL)788J<H[]48I)@;Z.!
MC;M^A9^+D:BVO-)078=Q>YR4H,6`BJER>9"*DJV?J,2!B)ZIL<MD<)1C<)-S
M?9I]AI^'D*N<IL&>IKYP=H>1F*R,DJ0]4(!58XA47WN'E+9X@IR:IL6HLLQ^
MA9>[Q=V8G[!O?J!YAZ=J=8YS?IAF<(:2G[N3G;.-E*.SNLEU@9F&CZ&ZQ-E!
M685*88M[B:/`S-W7V<7,UB&[Q`7$RQ##RB??YCW$QI+>WX_2T@W=W!VRI@"[
MIP"PEP.U@@>YB`FN=0#MR'[!;Q2X70';@C7#?T>W1`&U.`._3Q_`/PVX,@7#
M*0##(@7M:%?&%07!&0K+)AC81CC<3T'<,2;Y;FK*:69]``!\``#'#@V)"@K0
M%!#'%!+8&1C.&!B0$1'<'AW@(2'/("":&1G5)R?F*ROI+R^D(2'9+R_*+2SM
M-37P.CJN*BK=.#C/-#3S/C[U0D*X,C+X1D;W1D;</S[C0T+A0D+Y2DK#.SOZ
M34WE1D;J24GH2$CZ3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#M4%#01D;Q5U?2
M3D[U7U[E65GV8F'X9&3S967[:FKZ?7O^C(KXE)+___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````M
MQIR4`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4
M"-=C8,`"TM*+VE-B$Q/BHF.R"BH;>T%">0US9B1%^/OX1N:7UO=,!@IE5L^<
MW5V<$18<GU-2US&I"RA4-I5Y2GEV>(!?4')5V\3^9J`0T]QI-;E1WLXN3B%-
M?1-::X%""^:U%%:$NGIZN07.G]4Y/14H9,/-QL(I:N'NX:COP,[*80T4,C.T
MLU47X>,7$-/1,K*WT@,**2IH"\K+BO/*Z"J9"TE+:`*%5$TT>.0DE:6XA"T-
MU(Q-5;!Y!P#*KC*V^'VT[P````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+VQB+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#0W(#$P-3$U-#,T,30V(#`R,S`R-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___\P?(<TH*K`H*?)%1OQ66/Y:6]'"
MP_WO\-O-S]3.SXN&A\[)RO_^_]74U<?&Q]35U<'"POS__L[5T;_)P^SS[KC!
MNK+"M<O,RRME(^7MY)*GCW:3<'JA<8&B>55X3$1I."M<&3=A(?#Q[SU9&6)T
M/ZNLH.?GYN#@W\W-S+>VK:)U5+6%9=RYKM"LHL2XM\P``'\``,X#`]`%!<P%
M!<T)"<P+"]8-#=@0$-`0$,P0$-(8&.$='=@;&W\2$N0A(=0@'\X@()T9&=(C
M(J<;&^0L+-8I*>XO+[(C(_(U-;\J*LHP,)0D).$X.-4V-;PP,/I"0M0Y.<<W
M-OQ&1N%"0=(]/>I&1L8[._]/3^Y*2OY04/E04.5+2_975_I<7+M&1N=86/]H
M:/]J:OEH:/IT=/=Z>LR[N\R\O,_`P/SKZ]W.SL_"PKFMK>#2TO+DY/'DY-[7
MU__X^/CQ\>ODY-C2TK*MK?WW]_OU]>[HZ.SFYNGDY/CW]]W<W/[^_OW]_?S\
M_/O[^_KZ^OGY^?;V]O7U]?+R\O'Q\>[N[NSL[.KJZNCHZ.7EY>'AX=K:VMC8
MV-34U-+2TL_/S\[.SLW-S<S,S,K*RJ>GI____P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"/X6JP````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````P$E$050(UV-@P`*,C)PCDN/\;$P-32P=O$*B
M@4+VO@EIJ8E!S$Q.[GY1\4DI0"&>LNKRJE)>=6WNPI+BHHI*H-#T"7SMM9/$
M%15$NEOKZMLT@4("C"V]$R5EE93E51KJ6GHF`H5JFC0$I\A(J:K)23,V=_%/
M`PK5=_9/GBHJH:,K)MS8T:<E!!0JR,Y,S^#@TM?+XLS/RS'(!0J%NEB;6]FY
ML;*QQ\6&!0>P`(4<S0R-+6P]`B-CPOU]O#U=L7D'`-WZ+_?$(O_D`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;&,N<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q-#8@,#(S
M,#(P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____4T]1?'>,8EU\4U%=5E1IDI"G.35X.S=W0S]_0#QY3$B&8UZ?5U2)3TQZ
M8%R26UB(<FZH9V28;6J?:VB<:VB:8E^-;VR?8E^,='&F<W"C8V",?WNR?GNP
M?7FN>G>K?7JL@X"SCHN[:VF-D8Z]E)'`DY"_7%IV=W68,B]V(R%))")*/SQ^
M/3IZ0#UZ1D."2D>)+BQ52$6#1D-_2$6!2DB#-3-<4D^+3TR%5U2244Z'44^(
M5%&+03]K/CQE3DQ_6%6,2$9S7UV86UB02DAU1D1N8V&<:6:B8V"87ER25%*"
M4$Y\5U6%5E2#7UV/7%J*85^1=7*M9V69=7*L:6>;>7:P9F256%:`85^+@7ZX
M?'FP=G2H?WVT@'VT=7.F@7ZU=7.E?WVR?GRQ@'ZS@H"Q@H"PB(:W@'ZKCHR\
MCHRYC8NXDY&_9&-V,S%S0D&#3DUW:VJC75R,;&N8?'NL5%1]D)"P24E3,#`Q
M>'F!-SE",C0S"`D(`P,`"0D''AX;&QL9&QH18V%8Y+8AZ+@FM9$@]<<ZZL)&
M_M10OJ%!X;`=G7D4J808[KHOOI@K^LA"RZI*&!4-248^GG80\KLU_,A&_LY/
M^<I0R*9.*B8=$@\*@W][2DI*$!`0!04%____````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MNE);6`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#!241!
M5`C78V#``G2T[25SE#PU5?+TC*T\PA*`0MKF$=GI(BZLY09<%NXAL<E`(:."
M#.5$6YGZ!G%#9R'9I!B@D%NQJJ(7#UMM72YO872*@AA0*%(]5=B4KV+>W#EI
M07'R$OY`H:QT"6M=C9J),ZO9H^2D`P6!0IGQCOJ65;-Z^B95JDF%!W@#A4H$
M3#A*&[M;VB8TE8D6^?$#A8+-./.9)C=/F=HQ8W:HKX\34,B&6XNEM:NW?]KT
M]DYF!U<[;-X!`)N@,;O36"%#`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]K<"YP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C`U,"`Q,#4Q-30S-#$T-B`P,C,P,S0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____'.CNN:WB[>8:QAH_)F:.Q=(&P
M=(')C)FW@X_6H:VF?8:\CYGBK[K-GZGEM+_=KKF;<GS'EJ7;L+ZS@Y.B?XO8
MK+O;L;_9L;^F=8>H=XEG252H>8JP@)&\C9[*G:W>M,-[7&@%$X$##%`)&(4*
M&(,5(XX=*HXF-)P<)FP@*W4Y1JP\2*,V09-)5[E+6+D]2)-,6:]58\!48;Y6
M8[U;9KMM=\<%%X4(&88-'X@1(HXA,IPC-)4G,W\U1:LO.XD[2)S+SL[EY^;,
MF93KM[.+$@SK-RZY+2;/.S/@1C[^4TK_6$_R5$SQ6%#[7%3+;FG0=G#8@GW]
ML:S,"0'-#@7*#0C4%@W;&13>)!OD)R'.)1_/)2#:+2?N-2_=-"_R.S7$-"WU
M0CK*-3"R,"K--3'2.335.C;Z2$+X24':/CK@0C[\3$;E1T+J2T;N34G_54_^
M5E#R4$S]65'V4T[N4TSK3TO[55'Y55#I:63VBXC[EI/'IZ;RV]K1"0?+"0G8
M$!#A'1W<)R/H*B;K+"O/*2>G(R'!+RSU/CKX0C[^3DK_44W]55'32TC(2$C,
M3DO25%']963X967+6%;1;&SA@H#%D9#7H)_(FYK'FYK+GY[4J*?.HZ/\TM'Q
M\?'.SL[___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#U[8G9`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"5%2T#,W-=#74E%75-74,
M3(!",DIB(A+"HK)2TG+R"N**DD`AMY3*8->@Z)#0\$CW3!__4J!06^_<>=/G
MSPBKBVCNZ.HIR@8*,5773FV=7-/?$)604UB2FP84FE3E/*6^SVE"8UQ&045>
M>C)0:&+9[)FSILUI:NGL+L_/2FT'"OG%QP2X!,8V)WD7^WIY)GH`A=BX.)C9
M63BY^00$^7E9>82`0K96%I;6-O;ZQJ9&CGH.=MK8O`,`;[LR5_.:^.P`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VMR+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0U(#$P-3$U-#,T,30V(#`R
M,S`T,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___^!/5J40,9Y1:I@A2EX#0&H-4]74U<?&QX15FDI$EB`=FYF7UPH*CQ@8
MFBLKIB\OL3X^L4=(N#L]K)"2V(:(OX>*NO'R^O;W_>GJ[\#&QLW2TO#U]=/7
MU_G\_-35U<'"PK*SLZ2EI=35U*^PK\7%O_O[^=?7U7-S<NGIZ.?GYN#@W\W-
MS).3DO_V\/SU].B6E,ZEI,T!`,H``-`%!=$'!\P.#ML4%,U`/\Q(2-2/CL^J
MJOCW]\S+R_[^_OW]_?S\_/KZ^OGY^?;V]O3T]/+R\O'Q\?#P\.[N[NSL[.KJ
MZN7EY>3DY.'AX=_?W][>WMW=W=K:VM34U-+2TM'1T=#0T,_/S\[.SLW-S<S,
MS,K*RLC(R+^_O[R\O+N[N[FYN;BXN+2TM+.SL[*RLK&QL;"PL*>GIZ6EI:2D
MI*"@H)V=G9N;FYF9F965E924E).3DY&1D8N+BXF)B86%A82$A(*"@H"`@']_
M?WQ\?'IZ>G=W=W)R<FUM;6MK:V-C8TI*2D-#0ST]/?___P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'0%1\(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````ODE$
M050(UV-@P`(J*K*5W5W\0J*BPL)3O!WM04+Y&?EY8<&141%AU?7AC,Y`H:+4
MG.)".2,K2^L`U?)B+4^@4'JP;ZZTC;FQF86A;%:,FPY0B)/1)5"&Q<24F97)
M0-[5)P0H9.NDK1#)S<;.(\BE[^S-$0T4<O"*+E,3Y^,7$.)53X[5500*N0?5
M-FF&BHD(BTIJ5-4E)0"%_$(*&AH3?:4D[#U*:_3BTH!"*I%VE9G^GDZ,SM[Q
M)2E*Z=B\`P"(ZBJN@=(8<P````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O;&LN<&YG````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(P-#4@,3`U,34T,S0Q-#8@,#(S,#,T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____!D,`&%81*8(?%7,);K=D%%`*
M)7X8*VHA/(XO-'4J1)0X188[5:%(7*A0491&:;-><+5E=KMJ%U``%T\`S.$U
MQ-0F\O@^]/I"^_M-__]/YN9)^?E0S<D8Z>1&Z-DOU,(ZR*\4V;LKV+8=[LI7
MR9XA@&49\,=1P8T*PI4S_])JS(@`S(D!T(L%S8L)TI08W:,OVJ=![+9(EV$`
MF64%GFT2P(<=UYLKJGPGSYT^Z+!*O)!`^L%>S*-7Q)Y9UZ]HUHD-WJ$ZEW$R
MNH(NPW80X)U&MF,`MV4!MV<%NVD'NVX2Q'LGQH0[XYQ.YZ!1P7HTJ%<-Y(\^
MEE0;Z)50YI50S%@#LU`%SE\-U&P@X8`X\910S%8`SE@#MD\'_:1D]Z!EL44!
MY(1*YH90KCT`NDH0Y(%-QF8XXGY1UF8ZW7A0MT08R%`FSEDOSEHOJ2L!UVI.
MI1D`IAT%L"<0K"\8LC<?S$PUV%U&J!H%O#0AKQT-M$0VN"@=H30JI3<MT%9,
MH0D`G2\HJC@PJS<QUUE1D28AR3HULC@UPTA"P49"U%10F@``H`,#G0,#F@,#
MH`H)HPH*G@T-J104N20ADB,CF"8FH"PLJ#`PKS0TTD1"T$)"O#\^TD9&Q49&
MR4E)V$]/UD]/S$Q,____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````)>QK]@````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```"^241!5!@99<^Q#@%!%`70-V^&-6(1LC:9
MB!")1D3##RC\DW_R']024=E$(PH$:X7=??.,VBU/[BTNP%\$!-P<1.G,M^QE
M11+[I8*+&#=O2=7<*U?]&'HQ*"BHG%^F'3W6B3'OS@00L"!RRY30YU.N8T:.
ME+3,EF)/L8J/FGY#^R-,-ZG<(HYJKO4D8BND.;^%SUAB1SHGRXABWI\N.CIC
M-W10Q$R85NJ?6F5Y`PF6PR`_-'I*=Y^A"5:[OSL`7W;S4_Y*W=5P`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M82YP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<W-"`Q,#4Q-30S-#$T-B`P
M,C,P,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!4````-"`,```!Q3-52```#`%!,5$7E
M``+A``+:``'<``#G``#J``#&``#4%0#(!@#3!@#:``#E!0#0``#>`P#E``#I
M``#H``#C``#_"!C[#ACO$Q7G$`WD"0/D"`#F"@#A$P#2&P#;+0K?*PK7%0#C
M$`#D#P'=$@/@#0+N!0'U`P+S`P3M`P+F``#W``3L``+:!0#1#`#2$@#3%P#1
M&@#('P#!+P#`,P#8/0W''@#8&0#3$0#8)0?/$0#M"`+X!`/W!03R!`3L`@/_
M"0WZ!@;J#@+H(0KQ.AKQ2B#D2AC31`K84A7+10CB3QGI21?Q01CM.13T1B'Q
M,A;M!@#Y`0'W`0+S`0#K``#^``#V``#P``#I#0#A(P#8-@7(0@/$0P'-/0"^
M)`#$)0#F0@W9-0+=,0/D)`#O&0#V!0#^`@'\`@/P``'Y`0#^!@#_!P#R!P#9
M#0#,(`#+/P'651'.0`#"+@"Z)@#=1PS3-@#=+@#?$`#S#0#Z`P#_`0'^`0/X
M``#R``#N``#U!0#[!0#Q`@#D`@#<$@#;,0#<3`_&20:_30:X1@#`0P'1.`#<
M)0#E#`#]``#X"@#V!@#W`0#T!`#N$0#E'0#4*`#)+@#20PG=51G<5!J_,`#7
M-P?9'P#L$@#U"`#\`P#_`@#_`@+[`0+T``#[`@#[``#O!P#A'@+;,PS5/A'7
M.0S<%P#E#P#J%`#P)0?N-Q7K-!+J'`3H!0#X`P#]``+Y``#^!0/]!`+R"@#B
M&P;;*0O4*PK:(0/M!P#Y#0+N(`OI(0KI$@#H`0#Y!`'Q``#T!`/X!@7Y!P7W
M"`7V#0CU$`KP#0;K!`#X!0'Z`0#X`P+W"0;X"@?X!@3W`@'[`P/Y`P3T`0/N
M``+F`@#J!0+R!`+X!`3^!@?Z`@/Y!07T!`7S`P+V`@+[`@;\`P?M`0/H``+7
M!P#<"`#C!@#E`@#K`0#P!`3N!`/J`@#G`P#E!0/C!`#@`0#B``#O`0'F``+@
M````````````````````````````````````````````````````````````
M``"6&F83````"7!(67,```!(````2`!&R6L^````>4E$050HD6-D8`2!__^9
M&1'@$Z,0(S:@CE74!JMH(*;0:S'&5*QJJU"YGU^I,+QG9.S"JG86*YK`"4O&
MDXP;&:"\'Q\DP?3.-Z\+&0_`%3V7`E-@59<9_38#J84)"0L9&8OZ&0OZ/'8S
M,CZ$JM2X"2*5LUYU^6YA!`!TL1^0U'+5^0```!UT15AT8V]M;65N=`!#<F5A
M=&5D('=I=&@@5&AE($=)35`YA#DE`````$E%3D2N0F""`````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M8RYP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-"`Q,#4Q-30S
M-#$T-B`P,C,P,C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____'/#W_9VC5L[3!PL*RL[/4U=3@X-_=W=S5U=3-S<S-`0#,
M``!_``#-`0',`0'.`P/,`P/0!07,!071!P?0"`C-"0G,"0G4"@K6#0W.#0W8
M$!"+"@K/$A+;%!38%!3>&!C2&!B4$1'A'1W2&QOD(2'4'Q_D)"2=&1GH)B;K
M*RO8)R?N+R^G(2'=+R_R-37R.#CU.CJR*BKA.#CX/C[Z0D+A.SO2-S>[,C+@
M/S[\1D;G04'^2DK\24G&.SO_34WE147N24GL2$C_3T_^4%#R3$S]45'[45'Y
M4%#^4U/V4%#Q4%#41D;V5U?V65GZ7E[I65G]9&3W967_:FK_;&S.I*3,HJ+-
MI*36K*SAN+C4KZ_NQ\?*JJKZU-3GQ,3_VMKYU=7JR,CZV=GXV=G^_O[]_?W\
M_/S[^_OZ^OKY^?GX^/CV]O;U]?7R\O+Q\?'N[N[L[.SKZ^OJZNKHZ.CEY>7D
MY.3AX>'>WM[;V]O:VMK8V-C6UM;4U-32TM+1T='0T-#/S\_.SL[-S<W,S,S*
MRLK'Q\?$Q,2_O[^\O+RYN;FPL+"GIZ?___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#>((?_`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+U)1$%4&--MP3%.`D$4!N!_WL[.FYD%Q,0U1J[$!6Q)#">0"DM[&PVQ
MM**F]0(>P#/82`@!`>?M8\<#P/<!)PQZ&%S7\KW:)!=BK.('`77_2E?;7;+L
MV04+PD7_)F_7OXD\LX\V@7!YNY#EYJ#.!?;<_H'PY8<_>T&L`G>ZMFEA,<K:
M.>9<&"(RYOWNTX*JR)2ED?0Z]I'G((29(ZAJ(_=NQM,G$/Q#`=6C"!Q/2C(@
M/)=H5:5Y*_F%Z='@C'_:=4)(5F2=^0````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+VMY+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,T,30V(#`R,S`U,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___ZN2FYZ"CMG`RUI%
M3[6CK)-VAGU4;[FKM<6OOV)88GMB?K6KNLB\T%])=J":IG%CB&M?@)F-M#XP
M:(=\J)2+L'!K@#TQ:E-)?&-:BT(Y<%Q4B&]HEWISHC<O:U)*@E=/BEU5E$9`
M:U1.?%A2@'%IH5]9B')KHG5MI'9OI'UVJGQUIWITHS`I9S4N:C4N:3<P;#<P
M:SDR;CDR;3LT<#PU<3TV<3PU;D$Z=4,\>$0]>$,\=$=`>T=`>DM$?DA">$])
M@E!)@E--AE1-ADY(?3\Z9%M4CUA1BE1.@UQ6CF!9DF%:DDA#;51.?DQ'<EQ6
MB65?EU!+=TY)=&5?EFICFV]HHE=2@'!IH5Q7AFYHGF1>CWAQJFYHFW5OI6AC
MDGARIVQFEGMUJ7-MG7!KFGESI71NGGUWJGQVIXN&LXB#KXJ%KS8P;C4O;#0N
M:C<Q;4A"?F)=ED]+>65B@&9D>3LW<SLW<D=#>()_KHJ(IT)`>'-RBH.#F%]F
MEIFAH**OI[G-M*"ZD:[%FY:?ALBB?+F:D.J#;>>*=_.`:ZI92[YI6^F#<NZ(
M=Y%A6/:WK..JH+=#,\!+.(`Q)<]?3==P8;F%?7)(1<.(A+%Q<?___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````,\#0O`````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`)8N4NZ^+AX
M:_,-C*U=`K72@4+3>J?V]/5/GR&1:^FD%):>`12:U-G>T39YX@214GOWFLJD
M-*"0.!M+-R<33[F9G:):8YUF/%"(65ALBF`5.X>5<Z%H2VML)%`HJT*67UHO
M1U+!.R*[H5XJ'"B4F>Q9EB=O7N`5%2/0U"Q4!!32#;`QTC>U]0A-2)>K+E;Q
M!PI%.YCH`UT4$I>>FBCC%ZP,%'*UT#>T=/31T-9)45<-\G7#YAT`1^DOZDS*
M(R@`````245.1*Y"8((`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;60N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,C,@,3`U,34T
M,S0Q-#8@,#(S,#(R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____U34V`!>4.$NS4&+%9'73`!!:`QJ6`QJ5#2.8'S2C(3*`
M05:V.DN@.TR>66N_9'?197;/:'O39GC-`!N1!1^3"2*4"AMF$BN9$">($BJ+
M$BF)&#"<$2)N&C*2'S>@'#*+&2IW)SZE,$:J*CR*.$ZP,D24/5&A2%V\1EFK
M4&7"5VS'7G+,5&:U:GW3:7K%=(7,*#Z3=7]2=7LQFI\*J:X/QL@*L[4+O<`1
MR\T:RLPP?7X^S,P`SLX#S,P%S<T)PL(-TM(86ED+Y.0AU-0?N;H;T]0F[NXO
MX>$X^OI"__]/_OY0^?E0>7@GW-Q(U-)&Z^Q>K*@!IJ$!R\@UT\HU]NQ.[^91
MT,(%ULD-V\T8T,(FZM]&J)D4<&@4XM1"Z]U-TL9*E8U)95H#4D@)@6L`@VT'
MB'8GG(H[>FY!9DD`@%<AICP%L4<0_%A&_V!/^V%1X2L=ZSDK]4LZU4$UY4Y"
M\EI,V!X0Y"$AIQL;L"$A[B\OLB,CN28FO"@H\C4UORHJQ"TMP2PLQRXNRC`P
MS3(QTC0TSS,S^#X^^D)"VCHZX#\^_$9&Y4)"_DI*ZD9&_TU-[DE)_T]/_E!0
M\DQ,_5%1]DY.^U%1^5!0____````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````8^0&)@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```"L241!5!C3;<%=2D-!#`;0+W,G-W#U@C]8L45:T.WYZ`I<H$LH]4$1
M"OI06I.9)"Y`SP'^(`A6^X?-CWJLUB2S/!7@EFM&CR"R81H9!9?R>8A]O[Y1
MHEE847&X&M+.[@N=.XWLAH*![W+Z%I'9&I,V%'#LY"OM[34F8GT.%'A?9!NV
M[R<ETO82J%CJ,8.6CZ2GA7GOJ&CJ1O1QT?N4S=U1899<9SI2&3,\$O_X!9;`
M5`%+B2FO`````$E%3D2N0F""````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]K>BYP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q-30S-#$T-B`P,C,P-3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\`ALP`A\P!B,P"
MB,L#B<X#BLX#B,P%B]`%BLP'B]$)BLT-D]8-C<X-C,T0E=@8F]X8E-(=G^$A
MH>0AHN0?E]4?E]0;>*<:<9TKJ>LGG-@B@[,A@+`OKNXOK^XFB+DHBKPUL?(U
MLO(KD,(JC;\QHMHMD<0NE,<PE\HRF<PXI^$XJ>$TG=(SF\\^N/@VG]4VH-1"
MO/I"O?HZI-I&O_Q!K^<_J=\_JM]"KN4ZF,=&LNI&L^I-P_])MNY)M^Y(M.Q/
MQ/],N_)1P_U.O/91P_M0P/E0P?E0N_%7P?9>QOI:N.=DR?UEQ?=JS?\)BL@5
MD,PKGM,UCKA$K^-$L.%.P_I0Q?Y:P?%KS/H8D<8,C+LOJ==5P^Q<P.=;O>%?
MQ.D?D+4IF+U,ON-AR.L=EK=4P>(4CJX8D*X9CZQIRN,@D:A*N=`WH+-`LL@6
M7&,Z@HA4H*=VR]*`S]=5M+M<P<>!U-D:7F%%I:ESS<XG:6A9NK9UR,4[G94^
MH)@ZFH51KH]MNY%"=U1>JG:(S)6.R9:"MHJ=UZ5VMWIKEV.#NW>JW)M!:3&L
MVYJTXZ-NJ5-QJ%&PW95SITZ&MEM\J42_X'6HQ5.4L3;,P`K8RQ#___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M!_A)`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```+])1$%4&--MBTT.P4`80+_I
MS!BTZB?5Q([$SEZ"Q$F<PS'<P4(B$DOGD:91"R&$3N=7C35O^?(>P`\(EMW5
M(-)I)F2%T;`SV!$0?*+-]:($(;C6#!Y`P&<2\9-8Q-F>M7TBG.)!XY[-T8A$
M12^Y60D>H&J9SL8!1KC5#U&1N\JS]E)ZZ%Q_*F.*PCB%E16;>M?+\C@Y2J7=
M6*&E>J_O*!Y&5ZGLMQ*L5(QNPVGCQ;E6UBD2'"C!?OM$>6ZL-O"'#U%T54/T
MWY[?`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUG+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#(P(#$P-3$U
M-#,T,30V(#`R,S`R,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/_____^_\?&Q]35U<;'Q]76U=35U"=]"C2$%$^>+T:&+$Z-
M-3N-&$&/(4V<*TV-,5^K/E:8.E61.FRV36:J25V90F^U43=O&TN6)CUU(3]X
M(T-])D1^*$>"*EFB-4J%+5ZF.E&.,V:O0FFP1F&A0FRS2F:G1G&T4&RL3'*U
M46ZO3FJE3TR'+D^+,%64-5.0-%Z</G*W3W*U4"YN`SYZ#4R('5Z8+U:&,%>&
M,UR,-F^G0FV?1GJO3WFL4.?GYMW=W+D;!<$F$,XW(=Q*-<-&-.A:1M)40NMC
M4.-@3KM&-\41`,$/`+\0`+0/`,`1`;\1`<`3`\D5!<46!<85!\89"L`8"<D=
M#=$A$-`B%-$G&,PG&-0L'=TQ(=TS)MXZ*^(^+^M$->I'.NQ,/NY10O951MM*
M/O172OI?4/-;3>962?-=3^E83/1=4?%=4/!?4?*(?\@G'\=*0L]<5-YR:L`*
M`\$5#=L_./_^_OKY^?CW]^SKZ]W<W-+1T?W]_?KZ^O?W]_;V]O'Q\>SL[.GI
MZ>'AX=C8V-34U-+2TL_/S\[.SLW-S<S,S,O+R[N[N[*RLJ>GIYV=G924E(N+
MBW]_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````);5GX(````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````J4E$0508TVW!,4Y"41`%T#LS=]XG*I9N"8C+T<3":`@5"[!P+P8Z
M2BJW8$^(P;S\_V:>"]!S@#\$;XC'ASI\U3H4)^U=@8QGX3B-Q6E6"A0]?E*[
MCTHS<S8HHKY2>F].&AD-`LLUZY'?(J(JF1_$D^\/V],D(E3)3!#DXEX^FZN:
M9>0$@KN5]B%N9LX^.V>[*&QI"/-B<VG].A**C2%?[AIO+^TJSYGXQR^7W$:5
M?P]R``````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;'0N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$Q,#$@,3`U,34T,S0Q-#8@,#(S,#,U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````5````#0@#````<4S54@```8!03%1%W=P`W]X`WMX`W=T`VMP`
MX>``V]H`R,8`^OD(^_H)__X._OT/__\6_?L2[.@!__\+__T$__L"__\)__H&
M\>@`V?\0V?\.V/\/V/\-VO\-W_\1W/\.X?\3W?\0SO<%=?\%=?\#=/\$=/\"
M<_\&=/\.</\/=?\4<O\39/(((N\`(>X`(.\`'^T`&>D`'>T`&^L`#]X`!OP`
M!_T`"/P`%/\`$?P`$_\`$OX`!_(`,^(+,^()->0-->0+-N,+..`%-MP`.M\%
M-]\&+=0`EY`,EY`+E8X*E8X)DXX,DX\2D8\4CHX4B8H2@X0-M2X`M"T`LRT`
ML2\`KS``K3``JBT`I2D`X0T!X`P`X`T`X0X`WPL`VPD`^@4,^08,^@4*]P,#
M^`0#^`0$]@,%\`$$Z0$`Z`$`X@``X`$`WP(`V@$`TP``````````````````
M````````````````````````````````````````````````````````````
M````````````_H&=V@````EP2%ES````2````$@`1LEK/@```#Y)1$%4*)%C
M88`"1B@%!BP<J*(0819V!E0`$65C_`^&C!":"2+*A5V4&-M@HM0V%RC,@.3>
M_R@F<*"*0DP``'IE)O7W!?A!````'71%6'1C;VUM96YT`$-R96%T960@=VET
M:"!4:&4@1TE-4#F$.24`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;'4N<&YG````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(P,S4@,3`U,34T,S0Q-#8@,#(S,#0U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````(E03D<-
M"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T`4&
M\C4VIYV>U=35Q\;'R,G-QL?+]O?[Y>;JV-G=R,G,O;[!^/G\Z>KMY^CKU=;9
MT]370FN_1G##16[`16Z_1W#!2W+`47G,4'G)5'K&4W?!5'C!8(C87X;467S&
M7(')3FRG2F:>9(?07X#%5W:S4W"J<9CF<);B8'^]7'JU9X?);Y'69(/`=);=
M:XO*@:;Q@*7O=IC:87NQ=933B*OSA*;K?9[?BJWTA:;K:H6\<H['B:KN@)S6
MD[/TCZSIE[7TD:[HS<_3Q\G-^?O^\O3WU-75Y^?FS```?P``S`$!S@,#S`8&
MS0D)U@T-S0X.S`X.V!$1U!86E!$1TAD9SAD9X1T=BQ(2U!\?Y"(BWB0DG1H:
M[B\OZS<WV#(RX3DY^D)"NS(RLC,R_$='YT%!^$E)QCL[_T]/_E%1^5!0_UA8
M[%)2[E-3]E=7^UQ<^EY>]V5E_VIJZ6)B_6UMS;Z^T</#S+Z^V\W-S\+"Z-K:
MW=#0_O'Q]>CHX-34_?'Q\N;FU,K*__3T\>;F^/?W_O[^_/S\^OKZ^?GY]O;V
M\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````&8MNS```
M``%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"V241!5!C3;<$Q
M2@-1$`;@_Y^9MUGW81#/DRIE0,@)!"]@+8B6X@T\0\!>.QN+%+E)($AB<#?[
MWHP'T.\#_B`6N,RY[(^]ORW;U4UZ$:!K.O\9AL*KI-=&&*;Y@OVIJFBK;3*'
MX?6!G)R[4T1#Z2":\;E10ZU>2IBE6\'CT\>[PCUJO5>]2R"F(D?.8AVS^&QD
MY(&8'[[Z,,LY2;C'L#%L=R=G<I/",G@I,'Q7FJ;N;&)CE2#QCU_LNDF9^_9S
M;P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G
M<R]L=BYP;F<`````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S
M-2`Q,#4Q-30S-#$T-B`P,C,P-#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,`
M``!8S!V.```#`%!,5$4```#____!I:[@Q,V#$#A2"B.#$3F%$SN'%3V+&$"'
M&#^(&T%=$RV2($B6)DUE&S6;+%.?,%>B,UJ8-%>>-UNQ1VR`-$ZU2W"E1F>:
M06"Y476F2FJ\57FK3V^S57:Q5'2O4W.V6'F:2F:^77^V6GJF4W#(<I"ZG*;%
MJ++2M;_#K+3KT-GNU-WGS]?QVN*"##:##SB$$#F#$#F'$SR(%3Z%%3V.'$6.
M'46*'421($B+($:3(DJ+(4>*(4:0)TR2*4Z/*T^A,5F4+E)N(SYU)D*E.5]\
M+$F$+TUV*D5_+DNJ/F6=.EV>.UZ',U&N0VF--E6)-5.P16N6/%R1.EF3/%NE
M16>?0V2L26R<0F*E2&F+/5F[57FK3F^]5WN_67V00U^V5GB41F+`7("^6W[`
M78"_78"[6WW`7H&]77^Z6WVW6WRA4&V]8X/%:8JX8X&W8H#":HFU8X#$;(O%
M;HW#<8[)=9/+?)BYFJ6]GJG1N,'6O<;FS=:YI*SZ^?KY^/GX]_CW]O?N[>[I
MZ.GFY>;@W^#5U-74T]3-S,W,R\S^_O[+R\O)R<G___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````>0+T?`````6)+1T0`B`4=2`````EP2%ES````
M2````$@`1LEK/@```+9)1$%4"-=C8,`"6%F=$TMS0NU,C3@L!?VBTT%"_%$E
M!3%.7$;LY@)>4BD90"$>L<)B>6%N%D-./E?Q.&4YH)!'MEJ6CQ6;@8FUD&AL
MJJ(T4*A&3[>22;V\0D.365NGNDH+*-10U]S6T=7>VM)8VUG?U-8-%"K+#W.P
MM;$7"4_++<I358H'"JEX6QCH&_,Z!LHD)T0&^;L#A23@+LJ4E0SV=0,*.7$9
MLIL!7924H1`1$N#I@LT[`%SR*EN4OJ'T`````$E%3D2N0F""````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYA+G!N9P``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30V(#`R,S`R,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````")4$Y'
M#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\P(
M#-$0%.$A)-`K,MXR./),4?]?9/ET>>Z`@_Z(CZEW@L*4GJY^BJJ1I9-ZD(V'
MH3`O@3LZ?F9EJP``7@``6P$!/`4%9`D)90T-9A(2:!@8<!\?=2<G>S@XB#@X
MA4%!CT%!BTA(F#L\?%=7H5Y>JEY>IUQ=GV1DJ6IJL`$$8UQ=EW!QK2LM6RLM
M375WH!@>=4E/F`X7;Q4?=!,6,4=.BG)YM'Q_G148,$5-BE);F$5/D&EQHH.'
MFB@K-XG1E&>[<3><056T7U:L7VG$<E:S71MG&R)R(R%O(2^4+R9W)BAY*#6?
M-BM^+"I[*BZ"+BV`+3"%,#"$,#2+-#.),S:--D*G0CJ2.D:G1D*<0DJJ2D*8
M0DVP3D:@1DFD24:>1D^O3U"P4$RG3$ZJ3E&O45"L4%&L45"J4#*',3:--3^7
M/C^5/JC5IIS#EXNB>IZSC+;(I)^HCWV%:L_6OE=A*'F#3)6A,<;38L&BEMNC
MG-%=5.^EG_&KI=`^--Y12<Q.1_)J8>&.B,X*!=L=%\P?&-(N)^XZ-,]95-N4
MD<P``,T!`<P%!<P(!<T)"=0*"M8-#=@0$.0A(=0@'^@F)NLK*_4Z.O@^/OI"
M0OQ&1O]/3_Y04,Q86-EH:,.,B____P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````%_Q1D@`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@
MP`+$3?55M%3E921$):QY&V?.!@I9EI99J"G*2HH9&S2USYC%"12R+Z^P4Y:3
MTK;BJY\ZG:,V#RBD5URD(R1M(EC=,F4:=XEC#E!(6%=#P=",IV[B)/::7+>8
M$*"0B+J2C4!#\P06KD+7C(2P(*"0II'MO-;N?K8JA]CT^(A,/Z"0.7]';Q?S
MW`+GZ-3D[-!`;Z!09UM/%VNEBV]D4DI42("/)U!H<A_3G'PGK_#$M+BL8'\/
M=VS>`0#/?3('9Q0;W`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA
M9W,O;6XN<&YG````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M,C0@,3`U,34T,S0Q-#8@,#(S,#,U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#
M````6,P=C@```P!03%1%````____3X&H4(.I5(>M4H2I7(^UE;W;6HNN9YJ^
M:IBY@*O)4(RS5I&W8)K`;:7*>;'5A;O>C<+D@K+1C\/CB[S</9+!/)'`0I;%
M093"1YO)2I[,4)[)5JC57J_<8K/?<+[I>,7O-Y3$.I7&.I;&.I7$.Y7%.Y&_
M/)&_09S,09O+0IG'0)7#0I3`2Z332Z325Z_=4J715Z[<4:/-9+KG9+GF:[OF
M9[3=<<3P>\SV>\CQ@,[W?LKR@LSTQXDGVZ5(TY`XQY%&[+%ES80OY)]0[:A>
M\*]D\K)HO6``QW0@V8Q`O5T#P&$-OV<2O5<%PV@8BD<1IF,J\ZEJL6HRZ9A7
MW9)9O6P[R%@?UFXXP3P#OS$`P#@)O"P(O"P)OS$-O3,0>10`>14`QC05QS<:
MQ#T?ER\9GC$;IS<AY$TOJ3HCL#XFLT`HYE,UM4(JOD<NNT8MN$0LPTLQP$DP
MR$XTQ4PSRT\V[V!"T%0Z\F1&UED^]&9*VUQ"P%$[]&E-WV!&Y&1)]&M/]&Q0
MZ&=,ZVE.\FU1\6U1[FM0VC\AST(GV4\UPD<PRDPT[EH^STXVUU<^Y%U#QE0^
MY6))]6M0\&E0[6E0UV%*WV9/\'!8Y&M5['%:[7ED]81O>!``A!H*]79D\'=E
MGR\AZF!0____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````<$C\ZP````%B2T=$`(@%'4@````)<$A9<P``
M`$@```!(`$;):SX```"M241!5!C3;<$[;L)0$`70.Y\'Q$(@BL@42"EB>GH6
M0DW/'M@5K(>"(N+G(*3$SYX9%@#G`"\(ZTCEUV9QM.)G51V''UO&LKY^AW:3
MD=#\4`P2&$0<7?RW-R6J^JF!0NJ>_'F^<Z+>J;`,Q6["^Z'9YTTH37^;#,59
M4O2-KR(DT>8`0_-#G%+)0NQ-YU"X%AZ4+DP<9MY"T8W#F'FJ1&;9#(I2(U3T
M-`MO(SSPQA,HZ$TGK=$_T@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]N8RYP;F<`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`R,R`Q,#4Q-30S-#$T-B`P,C,P,C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#____2
M-3;.%!G;)BN>(27H.C_6/T/R2D_G3%'R458F#7\U'8E',)E:0JAH4;-B3:AK
M5;(<#%<_,W@J'&\;&I8?'GX``(X&!H<$!%4$!%0+"XL,#(D6%I41$FL;&W(G
M)Z(X.*XZ.K(Z.YQ,3+\[.XE65L1>7L%N;LX!!%8$"8P.$Y0>(Z$Q-;!$2+Y1
M5<-05<8`<P`#<`,)>`D->`T8@1@=AAT?AQ\;:ALA=2$B=",H?R@OE"\J?BHN
MB"XXG#@TD30PAS!"J4)&JT9"HD)&HT90ME!/LT].L4Y0L%`VD#4B@@5@LS5M
MEDIUG5%QEE!%9R9-<"U4>#-AA3YOE4PA,1!?AR]YICH@,05ME0"'IR&MOA+8
MWR;,T`72U@WCYT#R]E?-S0#&Q@!(2`#,S`/(R`.WMP,]/0$W-P&YN0I45`7.
MS@V_P`UF9@G>WAC3TR"DI!O8V"=T=!A+2Q+?WCB%A2?HZ%![>R_]_62UM4C_
M_FB@H%Z^OG2^OGMU=5^DI)UA7@#;UA1'1`?5M!#=OQWWTU[]U6KHJBO(A`KH
METC,@4GB)R'K-2_O-36[+"S(,##1-#3',C'O/C[W0D+3.SKZ1D;C0D+&.SOG
M1D;X3DW\3T_H2DG\4%#T3D[V4%#T4E'W9&3V9F7___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#1XB9G
M`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```*Q)1$%4&%=M
MB[L.`4$40.?>>>RN2A")1.VC_(%$H9#X#"4?H/<[LGJBLEZSLWOGX8J24YZ<
M(\0/($:@E4[M,_,2)2*62G1?9AJCW%(?&$Q<]6#FP5N]J[^J0O%8189N2^>:
MEES-U>9:#J)S-,DQSZ!I%R@Z*1$UDB>CD>9)*)%4CTA#(8W1WJ\#JWVFBS&F
MX\6"20RKR@[C(>A[+='Z&"(K%T]G1+[0F_"I_O`&IN]4_=2N3N8`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VQY+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,C`T(#$P-3$U-#,T,30V(#`R,S`T-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```&`4$Q410```/___P!P&@!P&P!&$`%Q&P%Q'`-R'0-Q'05T
M'P5S'P=V(0ET(@IY)`IX)`U[)PUW)@I1&Q!^*A)Z*Q2!+AB%,AA^,!%9(AV(
M-B&,.A^#-QEB*B:0/QMG+2>(/BN41")R-2%O,R^82"%J,R9W.2AY.S"/1C6=
M336<33".1BM^/RI[/2Z"0BV`0"IU.SJA4CJ@4C"%1#"$1#2+23.)1SZD5CB5
M3C:-2D*G6CJ23C)^1$:J7D&<5C^74T*<5TJM83J'33N'34VO9$:@6TVN9$FD
M7DBB74^P94^P9D^O9E"P9TRG8E&P9TZJ9%&O9U"M9E"L95"L9E"I95"H94:4
M65>N:UZT<EZS<EFH:V2X>&6U>&BZ>V:U>&J[?3*'162X=____P``````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$>_[2P`
M```!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````G4E$050(UV-@
MP`)86*0=8D/-Q+B8.(4D-:R]0$+B5E%A-E(\S.S\$DH6'OY`(4&]B'@W.0%6
M-CY1>5,7/U>@D')(=+"F,`<KMXB,OKV?MRU0R!%ND+JUEZ^=,5`H)AQND'N`
ML[DA4"@2;!`OT"`G/U?+."V@4)":,`<ST"`#>Q]O6Q-=%:`0PD5`@W14%8%"
M,(,\`YW-C;059+%Y!P#5\QJ8R<Y+C`````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+VUO+G!N9P``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,#0V(#$P-3$U-#,T,30V(#`R,S`T,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___Q^!0RN2436)5$R6:`!P)P-R
M*@-Q*0-P*P5T+`5S+`5Q+`ET+@ES+PU[,PUZ-`I1(Q!^-P]W,Q)Z-Q1Y.!A^
M/!%9*AA]/1V(0B&,1Q^#0AMG-B>(22)R/B%O/"^85"%J.R9W0BAY1#"/436<
M62M^2"I[1BZ"2RV`2BIU1#"%3C"$3C2+4C.)43B56#B563B463:-5$*G9C)^
M34:J:4&;84*<84JM;3J'5CN'5D:@94VN;TFD:4BB:$^P<4BA:%"P<DRG;$ZJ
M;E&O<E"M<%"I;U"H;T:48E>N=5ZT?%ZS?&2X@66U@6BZA6N\AVJ[A@!&&`5T
M*@9S*PUU,!V(0!^"0"*&0QEB,C*85#*'3SZD83J26$&<8#^773^66T.<83^/
M65BO=5*B;5RT>5NM=EFH=%RF=&:U@6JWA'*_C&FO@&FH?H[*HD:>8DF@9%"J
M;'&YB'S"DH_-HCB=53203X"^D2:)0*'5KQI],H.MC1!W)A5\+!9[+#2.1Z;0
MKQ9Y*D>F6HZTE9FXGC660ZO&K[[:PM#JTR2!+BR'-:2]IAAY'1]^(;S2O#F3
M-^CWYVBY7S&%&<S5Q]3=SLW4Q_/X[?___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#`85:L````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````OTE$050(UV-@P`("`R,L`SP-)'C8N(2D
M5$T=04+B)KY>9DRU/9P"D@K&]JY`(4&M-!^'NH[NB35]S-$V+K9`(44//_?2
MRFH6UO*61@L7ISB@D%6`IV%G`U_7I.22"8[.YKI`H0SOV##1JJ;6R?7M6076
M1MI`(1\[V1#AYBF];5/[B_)CHM2`0FXJ(AS!B3G9A16YJ?%ZFDI`(7TQ;K:@
M\/2RXN+,!%T-97F@D#0O&SM_:&2*?U*>D8ZZG`PV[P``?SLND73Z$&,`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;7`N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#<@,3`U,34T,S0Q-#8@
M,#(S,#0T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____OK:]M*NTU]#8QL/*:%N%?WB5:6&,;6>'C8BCN;3.03M^4TZ'96&)
M*"-X(R!61T*45%"2;6BU5E*-<FZWAX/!FYB_%Q)W(A]V*".#&!9+*29Z+"E[
M+RM\,R^#-3*&-C."/3J./#B&*BA?0CZ*/3I_-C-N,C!G2$60.CAQ5%&A4U"=
M5E.A0D!]7%BJ6%6D4$V51T2#1D.!1$*`2$6$3$F)1$%Z2DB&4D^23DN+4D^1
M4$V-5%&37ENC9F.O7URC:66Q8V"G85ZB55*,75J9;VNU;&FQ9V2I<6VW<&VS
M<6ZT7UV3?7J^?'FZ='*N>':S>7>S@'V[A8+!@7Z[;6N2BHBYC8N[='*7F);`
MIJ3)(R%Y)B1])B1Y+2M]/#J0.SIU/3QX34N+5U6<6%:<4$^/5U687%J@3$N$
M86"H75R>:&:K:VFO<6^X<6^U;FRO<7"U86";<W&U962<@'Z^@X'!*RQ\,C)^
M3DZ%9F:G<7&Q>'B[;V^H;V^0M;6]RLK2P\/)O;W";G"H=WFP;6ZA8F.%046)
M6EV&24USN+G"J*NYJ:NRD9FK>XB7<XZIAIRB4&ENP<?(EZ^DOMN_E:]]@)%J
MRMFUJ:.*NK"0I95NNJ6`RK>4IYN.\.CDN*NJN;FY____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````E0QD7@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```#`
M241!5`C78V#``J2E-5R"O6OX.M1B%`0-'$5!0BH90=5<LV=.G<49KVWOZ044
M$C#W]^V9PM;:SC&C1=\M+QLHI%586C!]@D1MJ%3?).'<G"R@D(A8D>L<GHJZ
MSN*F:8'NSM9`H1`_A[9^H[B&>MVJR<U.ME9`H1(/S;)>]O+YC9G<$RO3;$R!
M0OF&BI*\\R*ZN\3GAB>G6N@!A5*496.C?9B96%DBTRW-3!*`0JIR_#+R2CIA
M40%V0DG&B>K8O`,`U!`QYA6L[+,`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]N9BYP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C`T-B`Q,#4Q-30S-#$T-B`P,C,P,S(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#___^7S9BHV:D`=0``20`!=@$#
M=P,#=@,%>`4%=P4)>@D-?PT->PT*5`H0?A`2?A(4A103@!,8AA@8A!@171$=
MBAT?B!\?AR`ABR$991D;:QLFD"8GC"<KERLB=B,A<R$A;B$OF"\F>R8H?2@U
MH34K@BPJ?RHNARXMA"TPB3`J>"HZHSHSC3,XFC@XF3@TCS0PA#`VD38TBC0^
MHSY"K$(ZECHR@3)&KT9"H$(ZBSL^DCX[BSM&I$9-LTU*K$I(ITA)J$E/M$]0
MM5!,K$Q.KTY)HTE1M%%1LU%0L5!0KU!&F$90K5!0K%!;N5M9M5E7LE=>MUY9
MJUEDO&1DNV1EN65HOFAJOVIWNW=UKG6"P()_MW^'O8>+PHN)OHF=U)VBUJ*4
MPY2(L8BHVJBDT:24M926MI:>OIZ8MYB:N9JLR*R^V;[.Z,ZJOJK5[=73ZM/6
M[=;`S\#$S,3N]^[S^?/Q]/'+S<O3U-,@A!\PDR\RBS%!H$`_FSX_ECY,G$MF
MN66&LX6!KG^#L(&+LXF?O)ZWQ+:_R[[4UM/Z^OKY^?GV]O;R\O+N[N[JZNKH
MZ.CGY^?AX>'>WM[8V-C6UM;4U-30T-#/S\_.SL[-S<W,S,S___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#[#^\8`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"6%FEK/*Z)K2USIP:
M*:EJX0P2$C4/S>F?TM0X?7*TDJF3)U"(3SLH)'M2685U^<18$SL/1Z"0HG>8
M;]:T7#:APCXF>W>7&J"037B`?LO,)$[^N.X$+U=+`Z!0?6"U1-K,9AZQJ(YD
M7ULC+:!0L(,L;^J,.F$Y?T9F-[,J-:"03Z4`1T:1H(R.7W%*K:ZF,E!(3X2+
M);,])B*^I#316$-%`2@DSLW"GCZA)[^@L[?!4%U>&IMW`$@>,",N0S$)````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VUS+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30V
M(#`R,S`T,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___[)K<*Z5IU](6YU_F-S%V;BGMY)RELZXT8%7B69;:K>KPGYFE\N^
MX;.KR6Q>I$`QDEA*GY:+TYN2T71OD3XRE%!%HD(YIE))K3\YA%Q3O49`BU=0
MHUA1I%Q5J65>MF9?MG-KQ'QUSC`IES@PH38NF34NF#4NES4OFC8OF3<PF3<P
MF#HRGCDRFSDRF3LTG3TVGSPUFD0\IT$ZHD`ZH#\XFD0\HT0]I$=`J$,\GDE#
MJTY&L4A"HD])KU1,M%1-LE!*JTY(IEA1ME1.JEQ6N4A#CF%:O4Q'E&5>PU--
MGU%,GE!*F55/HDY)EEQ6KVQES65?P65?OFICQ%Y9K7)KRW9PSW5OS7ART7)M
MQW!JP&YHNWUVTG-MPG]XU'UVT7ESS'UWT7UWSWITR%U9F8F#THN&UC0PG#@S
MG3LVGSPWGFIFO5U9I8)_THB&M6QK@$(_HDE'HH6$SV]NCFEIJW9VOH.#REUC
MNF-ILGA_PX*)S(V4S[7,WY:KN9FUP\KI]KS7X<#;XK;4V:?#N:>YJX^=DL/:
MQXZF>9*F8HV87Y"88)66BK*W8^N'<^B.>Y)=4=%F5/2";<)N7_")=^N&=;F!
M=_>RI>.DF*M=4<%00H$U+=9T9[E)/G1%0L-_?O___P``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````.&,;&X````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MP4E$050(UV-@P`)8N(LG\7'REV>HZ1K;>X;%`87F]D^=/&WZ/"8Q35/'H,AX
M9:#0K!E]$WLGS)PCJ%I15UM3I`04$F5GF\+#S%N8*5'9U-I8I@@48A46F2U0
MP,%E;E-5W])0*@\42LV-%C)321>7E*YN:V\ND04*I<6Z9*EK&5J[!N3U='2F
M>`.%DOVM=-0-+)V#(Y*ZN_*]/(!""K;Z&GH6#H'AB0G9.;Y^,D`A)R,-;1,[
M]]`8Y:@0.1\W*6S>`0"[WC&#6,D>LP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O;70N<&YG````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$U-S4@,3`U,34T,S0Q-#8@,#(S,#4U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%:P``<P``<UI:<W-S<WM[>P``>V-C
M>WM[C(R4E)24E)2<I9R<I:6MI:VMK8R,K:VMM;V]O;V]O;W&QL;&QL[.SGM[
MSH2$UI24UM;>WH2,WM;6WM[>WN_OYX2$YXR,YYR<Y\[.Y];6Y][>Y^?GY^_O
MY^_WY_?WY___[Y24[YRE]X2$]XR4]Y24]YR<]Z6M_P``_X2,_XR4_Y24_YR<
M_Z6M_ZVM_[6U_[V]_\[._];6_][>_^?G_^_O__?W____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````,,"OK@````EP2%ES````2```
M`$@`1LEK/@```"-)1$%4&%=CL(,#?2A@L+,3DT47DN,6$$97)2J'K@H.!I40
M``#K+7/9U%''`````$E%3D2N0F""````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O;FPN<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P,S$@,3`U,34T,S0Q-#8@,#(S,#,R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____BPX/U=35Q\;'
MR,G-QL?+]O?[Y>;JV-G=R,G,O;[!^/G\Z>KMY^CKU=;9T]37(428`#.J`C>K
M!3BN!3>K"SZM#D.U$$.V&$>S(5+#(5&W'$"0(U"P)5&P*56U)$J;,6//*$VC
M-632*U*F+E6M,ENU-F&_-%RX,EJQ.&/$1'3<1G3>0FO)1W+/4'[B4'SA3GC9
M47W=/U^D37/$1VBO68+:3G"Y6GW);I3E!#JL'E+`-V&Z1G',:)#D:(W;:X_:
MS<_3Q\G-^?O^\O3WU-75Y^?FX,C'S```?P``S@,#T`4%S`4%S`@(S0D)U@T-
MV!`0U!$1SA04TA@8E!$1X1T=WA\?Y"$AU!\?G1D9[B\OV"TMZS(R\C4UX3@X
MLB\N^D)"NS(R^$1$_$9&YT%!QCL[_T]/_E!0^5!0_U-3[D]/[$Y.^U=7]E=7
M^EY>Z5Y>]V5E_VIJ_6EIS:ZNS*ZNT;.SV[V]S[.SZ,O+W<+"IY.3]=G9_N/C
M_>/C\MG9\=G9U+^__^CH^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7E
MY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````)XM]D@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"R241!5!C3;<&]<0(Q$`;0
M;W].$G,W0$0#)"Z"P"G=$)+8D8<>Z`0B)P0X<",D#!YN\)VT6A=@W@/^(:PQ
M[[IRZX<B30Q!]PRTJ;7'F`MK(R($QK&=LCU&#S'&-`D,Q390C9TY$PL1?8&@
MM@NB,*NEN&JS8;Q_?!X$M;K9F\BV`:%C[FGE9U_Y*7"FGO!Z__EU3HLAY3!X
MK=^*R[48:RZ3D>[9[`K&S>J++&,2MAEY;?'$'Y==2@&P9"!A`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]M>"YP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T,B`Q,#4Q
M-30S-#$T-B`P,C,P-#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#____5-3;\EI?[FYW@ZNKFZ.C&UL[#RL82>C$GB$0`<R$`
M1Q0#<"$%<R4)=R@+="D-=2H-=2L*4A\/>"T7@388?C81628:?C<?ASP?@CL9
M8RXC@S\A:S8PCTLJ=3\XEE(XDU(XDE(R?DA!G%L[B%%(HF)0JFE&E%U0IVA0
MI6E7KG!>LW=9J'!DN7QFMWUHNH!EM'MJNX)POX<`;AX`2!,#<R$ZAT]DMGIF
MMWSN]O!RA';!RL.ZQ;S1V].)FXR4H9;7WMCK\NRTO;7(T,G&SL;W^/=/9DMI
M>V1^A7M@9UR,E7YB83Z_N[!D4!]J63%A64=64$1]=6S8U=)=,!&NIJ'#K*:R
MJ:B,>WKD(2&G&QNP(2'N+R^R(R.Y)B:\*"CR-36_*BK$+2W!+"S'+B[*,##-
M,C'2-#3/,S/X/C[Z0D+:.CK@/S[\1D;E0D+^2DKJ1D;_34WN24G_3T_^4%#R
M3$S]45'V3D[[45'Y4%#89F;A<'#K?'SUBHK5>GKEAX?RDI+_H*#9V-C^_O[]
M_?W\_/SZ^OKY^?GV]O;R\O+N[N[JZNKDY.3AX>'>WM[6UM;4U-32TM+0T-#.
MSL[-S<W,S,S___\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#<8K7C`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+M)1$%4&--MP;\N1$$4!^#?S)D_U\CF)K*BV5HM044I%%Y)ME3I
M>`?/8<MMMB%;TA"%2B*Y9^:<,QZ`[P/^<#C=C@L9KT.`?K[F6;X+V.X.U3H1
M3!V5%.&1AY(;T=-*NYOER"#,2_KA%ZC_N#^79+SV&$J;ZIE9XWX;'3=XS"NS
MB$AEOXS\8"#L\7NW?1[3]\'C23VR30!/7:A?/6NZN/Q2$03P%`_?=LJQ6&A-
M5>'!K-ZQZ4V@;FH=__@%&+A<LY1#3$$`````245.1*Y"8((`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+VUY+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,T,30V(#`R,S`U-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/____67F<1%2<-%
M2<I-4,Y15M9;7L-E:<)G:\1,4N1^@\)S>,U?:,=Z@->IKF1:F30GBQD,?CDO
MBAH1A&UFOG5MP!0+?UE=S3(YH&AQW1(>E!,AE!4AE1LGE2LVG@48ECM)I@`6
MG0,/71@IE"$SI3A)ME=IRT52FVY]U0DDE"0ZF$=:JV%QN'2#Q3],;(Z:LR,N
M0TI457^+BSY'0YNIF69O8*Z[I&MV6;2\CTA.*%UC.9ZE;:FN4[&U0NSL2,YN
M:\QP;=9W=,QQ;M%V<\QV<^&$@=N!?L]Z=\=X=NB0C=N*B.22C]V/C.Z=F_ZK
MJ?FII_VNK/ROK?&IIOZUL\JCHN1C8<Q?7LYB8,QB8/)U<]!F9,UD8\QE8^IT
M<]9K:=)I:-AP;OR$@M1P;L%E9.5Y>,UM;.%X=_B%A-)Q<-1T<O:&A=IX=OZ+
MBJ=<6^1^?=Y\>_^1D.Z(A^Z)A[)F9;!E9/N3D=!Z>+]O;O*/C;QO;NN,BLIX
M=]6`?MB#@?J8E^&)B-*`?^Z4DOR=G/B<FNJ2D>60CO^AH+EU=/F>G?ZCHO:>
MG<1^??JCH?6>G?^GI<^'ANB8F/^KJ?NGIO*AH."5E/*EI/6IJ.">G?ZUM/VW
MMO*NKNZ^O=6LK/K+R^K`O__2T?G.S?___P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````!Y,J04````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````OTE$0508TVW!P2Y#41`&
MX'_F3(][>RD;Z8*-="VE"XG8V!"QL_*2'J`KB5V%]!&ZK0JB:-W.G'NF#\#W
M`7\0>MUZ2=E7[Z>#C?'5/=\Q.C2-.YONC3V-3E;G"8)@SK$U;[RW53%3!L,B
M-UD3Q9>#_=VJN(;@J]C[_7"FNGHLJJP&P6)B@8)Y><E,.0\A>"M9U9EOG\M6
M4MV&X$;-<@CAZ($OW%*"X'#VDSAVVHLS^K31L4'P^FTD4:*XU=Y7Q3_6'DE2
M94U7AF4`````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O;F\N
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U
M,34T,S0Q-#8@,#(S,#0S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____T;&SXL+$\-'3NZ*DQJRNT[BZ]]G<Y\O.Y<G,]-?:
M]MS?`21BBY:JIK#"!RMI$#1Q$C1N'4!\)TA^05^25W2DE:"R!2]IB)BNAY6H
MEJ6ZH*_#`#!I"C=O#CMQ-EF#/F")K+O.&4E^*E6%/V:12G.?68.P9HVW;I*Y
M8'N9@IRXAIVV)UF-.FJ=.%^(3'NL3WBC686S7'Z?8H>I<96V9(2A:(>E;XZK
M@J7$=9*LD;+1A:.^=(VEE[?5DK'.F++)I\+;JL+9L\K?E[;0S8-]\<;"SKR[
MS3PXS%A5SEM7S&!;]9.0QGAU_J"=U(J(]Z6BS```?P``S0$!S@,#T`4%S`4%
MS0D)U`H*U@T-V!`0BPH*SQ(2WA@8TA@8E!$1X1T=Y"$AU"`?G1D9IQL;ZRLK
ML"$A[B\OLB,CO"@H\C4UORHJQRXNN2PK]3HZRC`PLBHJW38US#4RX3@XU38U
MTC0T^#X^Q#,R^D)"NS(RSSDY_$9&Y4)"ZD9&_TU-X$5$[DE)_T]/_E!0_E%0
M]DY.^U%1^5!0TDA%\E-2_5A7\5=6Z5E9Z&EF\G!NT6-A^GUZVW)PZ(*`IV!?
MX(N)\IN9_:.A_:6C_ZJIWL;&____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````*_+-J0````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"_241!5`C78V#``H*"DGV=Q?C;PP)#HQ*SJIM`0O&5`4ZBXAZ!
M(9$)Z16-;4"AZ(+N:0XB?$7!$;&I976M#4"A2?[3W72$I%S[)DST\9LZ93)0
MR-;115M10L'8Q-32VL[>Q@HHI*FAIB(O*Z>LJV=@I&ZHJ@\4XN%B<M?BE9S!
MS,+!S<G.Q@H4ZBJ,\383D.[):^[LJ*\JSP4*%<>%>9H+RO16-[74E.9DI@&%
MDL(#O2R$E?H;VVI+\K,S4K!Y!P#M"3$,=UP@;P````!)14Y$KD)@@@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]M>BYP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S-#$T-B`P,C,P-3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\V-39N<W)G
M:VAM<&V8FYAZN7-ZM70N92<C;@\E<!$G<!,J<A<L=!@O>1L^ABL^@2Q'C#10
MECU-C#Q9G$=5DT1AI4]=FDQIJE=MKEMLJUQRL6%HGUIRK6)XLFF/Q8`M<Q@W
M?B,]?RI-BSM5D$19E4ABGE%6B$AVKV:#O'.'O'B'NGB1Q8)>85T=10MH:F=Y
M>WB0DH^(BH>HJJ>EIZ2@HI^RO:A<=CZMN)EF9V.YNXFYNP"_PR^YN@"GIW)Z
M>G9T='"$A("4E)!Q<6Z5E9*$A(&@H)V?GYR\M@6EH2.QK"J\MS#&P37,R3K8
MTT7OZ4_EX%:WLTK"OE+R[6C-R5K=V6;[]W;O['7Z]WR\M`/$O`W&OA#/R!W2
MRB&;EANCG2'=UB^NJ"C@V#6YLR[$O33JXT+KY$;6ST+;U4;NYU#FWT[JXU"_
MNGZ\J@F\F06_APJ4=4;9E#VZB$C<F4_(>BWPH6C2DF9=)`2O3A?+71_5G'Z[
M9T''2!A[+A3;=EJ^AG?L<%"&'PK&,!*R02K)-!A^$0#40R_83#CE9%6L6$W#
M%PF0*R%S!P!N"P504%!/3T].3DY&1D9"0D(U-34T-#0P,#`O+R\A(2$='1T0
M$!`-#0T%!04#`P/___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!^-N\,`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"*O0Y
M-;0UU905>?B4A$0E98!";746[/(2@KQ<W/P"PN)2TD"AII9Z>PY95141,74Y
M+05=':!03W%99P,SBP&KH3&;J8F9$5"HT#JWJ+6/8<ZL&5,F]4^</!4H5&UN
M6=/=.W?VS.F3)_1/8IH&%"HO*:WLTK-R='+V<'=U<W`!"C6V-Q?8^OD'AH1'
M1H2%!@<!A3IJ\^T\8^*2T[.R,U)3DA*`0E5Y-E'1L8EI`3F9OC[>7O'8O`,`
MF^\R)U\Z%OH`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYP
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S4W(#$P
M-3$U-#,T,30V(#`R,S`U,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```&`4$Q410```/___\<*"^HZ/,DS-,<Z.^E.4M$F,?_K[+(P.]U>:*0!
M$Z``$[(N0%\`$:T8,G0",:@]:+%.>IE#:I5(=54;0)Y6BUT+2FLU8(E">VXJ
M9TX)25H559I>E]O:VT8$24<.5$(/6(5CJ&50>TDK<7UAI5]"D(I]O3,O?[JX
MWUQ:HUE8E#\_<5M;B3T]2",L?='*R=A+1-,0"^%`/,T_.^RAGL^;F=VXM\T!
M`'\``-$'!\T)"<P,"=L4%)01$>$@'M0@'\PA'^@F)M8F(]$E),XJ)^XO+XL?
M'>PU->`V-J<K*=0V-?I"0KLR,MD]//E&1N%!0.I&1OY/3_Y04/E04/%<6;!$
M0_5>7N!85OUE9/AE9?1E9?%G9OIK:^IF9M%K:]>#@^B2DM>(B-.3DLR4E,RF
MILVMK?W9V=#!P<S(R/'Q\<_/S\S,S/___P``````````````````````````
M`````````````````````````````````````````````,^-3J<```!N=%).
M4___________________________________________________________
M____________________________________________________________
M__________________________\`H`4\,P````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```".241!5`C78V#``BSY1)4U<Q$`)&3G&\TEK((L
MY!Z6F&YJR,(MH*`!$_)*YLB2,W.TL+)E%U2""+'&QD3PBLM+RTA)BLFJ:ND"
MA:+"`UR8>!3UD<R*C$M*2S$QXE=#"(6:9^?D&/@Y,0NIPX2,XU,S,Q(\/?R#
MV42T(4(.UC:NSO9N/D$A@=Z<$CIZV+P#`%*`+5K5'@Q6`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L
M86=S+VYR+G!N9P``````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#0S(#$P-3$U-#,T,30V(#`R,S`T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````")4$Y'#0H:"@````U)2$12````$@````P(
M`P```%C,'8X```,`4$Q410```/___P@EC@HGC@XLDQDTEALXGAXVB2$YC!<G
M7BU)K"4Y?C9.IT!<O$1<KC]4G3]2E%)JOU=PR$M@J59MP%YTP&!UO6V"T`TI
MA!`KAQ$MAQ$MAA,NA`P<4A0OA14OA18PAA@SBQ@RB!@RAAHUCAPXCALUB!TW
MC"`ZCQ\XBB,]DB5`EBA"FBM$F!TN9BI"D"])G"M#C31-GS!'E#!(E#90I"@Z
M=CI4J28W;CU6ISA/FBY`?3!#@$%:JS-&AC=+CC9)B%!KQT9?KT)9HSI.CSA+
MBDQEN$ICM#Y3ES9(@CU1D4%6F49<HT-7FT]GMDA>ID59G%1KN3]1BU=OO$UB
MIUEROUAOO%!FK%MSPE1JLU9LM5%FJT=:E55KL$E;EUYUP5IQN%MQN%ENM%AM
MLF!VP6!WP5-GIV%WP5!CGUYSNF%WOV!VO5)CFV9ZO6R!PW"$R&9YMG*&QW.&
MQ'B+RF]]I9ZFN\O,S)V=<JJJ@JZNBG!O0G5T1W-R1GY]47]^58R+8964;XN*
M:)R;=ZNJA(>&:+"OB;R[FJ.2'Z64(;FI.J^@.LBX3*N>1]7&7L.U6,F[7MS-
M:=K-=::5)JZ<*[6G3M?(:=O.>____P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$#>^X8````!8DM'1`"(!1U(````"7!(67,`
M``!(````2`!&R6L^````O$E$050(UV-@P`)D92UBBG/]]95EE+2,G,+204)Z
M045YX29J,@H:!K:!*=E`(4[/@L)D*TTY>75=2S_1K"2@$+>PN`@/*S,3"QL7
MKZ.0(!]0J*6MLJ&NIJJZMKZ\HK6YJ1$H-&UB7]>D]H[)G=V]$Z;V3^D!"N5'
M\G-(2JGHF+M%Q$?Y>-@#A1+32G,D%+5-W4-3$T*\7>R`0LX992720!<%IV=&
M^WHY6`.%C-GC#%5!+A*+#1!PM3'#YAT`,X$NNE0T!LD`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&$N<&YG````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#8@,#(S,#(W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(E0
M3D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____
MP;F]T<G-_?W^Y>7F\O3Y9("MYNOSL;S-Q<[;GJ2MO;_"]??Z"C1O%$!Z)4Z#
M9(:RGZ_%T]OFP,;.[_+VY^KN`2]I`S-L!35N!S=P#3AO#SQQ$C]T&$)T(4V%
M)T^!*5"!+UJ1,%F)0FN<2&V<3G&;:8NS<9"UGK++W.#E`#%J`S-K!35M"3AN
M#3UU$$!X#SQP&$5X'4R"'TM]+56#,UZ0.&&/3WBG4'>COL+&[>_QRLS.W=[?
MOL'#OL7)P<+"LK.SDY24S<W,VMG8R+^^KPL%MA,-N!80KA0/KQ41KQD4OAX8
MP2,=Q2<AS#$KQS`KT#4OTSHUVD0^W4A"U49!WTQ&NT(_XE)-U$Y)XU5/XE90
MX%=1WE50X5=3S5%-Y&!<W5U9T']]O(%_PYV<[<_.T+NZJ@(`K`4#L@P*N104
MLA@6R"DFNRXKUCTZN#0TQ4$^X$U*UT],X511VZ:ER:FINJ6ER[^_RKZ^T,7%
M[N+BZ-W=T\G)_?+R^.WM^._O[>;F_?S\Q,/#_O[^^_O[^?GY^/CX]O;VZNKJ
MX>'AV-C8U-34S\_/SL[.S,S,O+R\N;FYLK*RL+"PIZ>GG9V=BXN+?W]_____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````@EY!
M#@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C7
M8V#``J9-FV+'TMY9Z9WNYN$7%!8-$G+BUA1F[2[WS'#W#0R)B@4*39W(R2[4
MU5OAE>GC'QP1$PD4FMS-P272TU>>G9635UA<5``4XN&UMK6QLF?*#0B-2TB,
M#P<*::BKF<H9RB@R5]75UE?7N`*%!%45I,7%^02TVAA;&ER<'8!"ELJR.MI2
M_&9BS8VI2:5-$X!"YD:ZVI(&\BJBS>TE^<G]DX!")GK:$OK&2A9LK1UI*66.
MD[%Y!P!G]S!V15&RO`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F
M;&%G<R]O;2YP;F<`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C`S-2`Q,#4Q-30S-#$T-B`P,C,P-#``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````B5!.1PT*&@H````-24A$4@```!(````,
M"`,```!8S!V.```#`%!,5$4```#____5-3;H/#WA04*G45+_B(E!H",Z?"-1
MJC)"ABI6K3=)D#!0F39FNTE?JD1KN5`^?25EK4AOOU)PNE(V<AU&ARM.D3)4
MFC=FMD1QO5$^B!-!BQ=,D!]4F"A)?2A1AB]FJ#Q9CS5EG4!UM$QTKDYZMU-!
M=PGKX^+&.#'$"`#$"0'&#07)$@K.%0W5(!CB,RNZ,BSO13[20#KW5$WF4$GS
M6%',``#+`@'.`P/,`P/0!07,!07-"0G6#0W.#0W8$!#/$A+2&!C-&1CA'1W,
M&QO2'!SD(2'4(!_1'Q_4("#8)R?/)R?N+R_;*RO=,"_R-37*,##A.#C2-#3=
M.3E_(2'Z0D+G04#\1D;E0D+J1D;L2$C_3T_^4%#V3D[Y4%#U4%#Q4%#L4%#'
M0T-_+"SV5U?@4E'^7U_Z7E[]9&3R8&#]965_,S/Z967X966=04'_:FK_<G*+
M04'49&242TOWAH;QA(3&;F[]CX^[;V^R<&_IH:'8Q<7,P\/>U=74R\OV[>W.
MQL;-Q<7_]_?X\/#GW]_[]/3NY^?^_O[\_/SZ^OKY^?GR\O+N[N[DY.3AX>'8
MV-C6UM;4U-32TM+0T-#.SL[-S<W,S,S___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````"$8`0$`````6)+1T0`B`4=2`````EP2%ES
M````2````$@`1LEK/@```+9)1$%4&--ES[M-0T$0!="[=V87"R0[=T*(!'VX
M"@C(+43H!JB``(D.<$XM9(@4B<1^O_7;W1D*\.G@`&<"MK_KQ;Q:J:)5L^8[
M(E]?6HTBL.9N.X%BF8(,4ZVQ^?[>7RH"XM/K\W<^68J?#Q?J]5WP&&_?UMUD
MACO8//1?Q%4^;J9"T924]<.@*%T_E)X,)-UN?J#(_5B.;:`(W=Q&*`Y=:3S\
MJ<3FYF90C*60Y#+,3.Y%\_D'_Z(X771-%"4>`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+VYZ+G!N9P``````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W(#$P-3$U-#,T,30V(#`R,S`U
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````")
M4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/__
M_[1M<+YTB,*-IIQIA]O"UUY(6YM\EZ>.I+>FMH-7AI]PHY)UELRWT(=<EV9;
M:GUEE[6HPHQQJFU2CW18G\R_X7A>J&1+FVY8I[*IR7)BI&97H7]RN9B+TG5O
MD3\QDT]"H4Y"H%9*H81YS(E_SIF0T#TRE6]FM#XVFE%)K49`BW%HQ7QUS7MT
MRC`JES4NF#4NES4OFC8OF3@QG#<PF3<PF#DRFSDRF3LTG3TVGSTVG#PUFCTW
MG4$ZHD0]I$=`J$,\GDE#JTA"HD])KE1-LDY(I5A1MC\Z@U1.JEQ5N%Q6N6%:
MO6%;ODQ'DTY)EF5?PEQ6KV5?P5)-FU%,F51/G6ICQ%Q7K%I4I%A3HF1>M7)K
MRUY9J7-MS&->L'1NS75OS79OS7ARSVYIP'!JOVUHNWQUT7)MPW-MPGUVT6UG
MMWUWT7=RR'5OPWYXT7QWSWQVS7ITQXN&U8F#T'!NC34QG#@TH#@SFCPWI#XZ
MID=#K$=#CFADQUI6IVUHR'9RT7ETTGIUT75RS()_TC@UHT5#HU-1HF]NT5E@
MM^N(<^B.>_2";<%M7^^)>..CF/>RIM!D5*M=4>J$=9);4KF`=[Q*08$T+=-P
M9K1#/71$0L6!?O___P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/.9
MO34````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P$E$050(
MUV-@P`+8!4IZQ/BD.LH-310E`Q*S@4(S)T_I[>^;Q:1N5"'*'-]0`!2:-K&K
MNW/"U!D*+55>.FFJN4`A>2ZV24*<(M9E$N(U]2HL&D`A#CFUZ3*MO-R5_#SM
MV7JR,4"AXN9494W]4B4MW]A,W93P2*!048:GK8&QE9-W76-^>EQ$,%"H,-#1
MS,#2P3TL*2\GJS;4#R@4Y6QA:&[O&I20W23,VN:O#11RLS$TM7/QB<[43986
M#*GVP.8=`!.K,)U6W=K-`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O
M9FQA9W,O<&4N<&YG````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(P-3`@,3`U,34T,S0Q-#8@,#(S,#(V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````2````
M#`@#````6,P=C@```P!03%1%````____RPT.TAP?V3(ST#4VQ#H[\F)D^F=H
M^'5V_&YT_W5ZS)R?U:VOS,G*VM;8R\G+[NWN_/W^^OO\RLO,?X>-R,W.W^3D
MZN[NT-34WN'A]??WV=O;R,K*^/GY:9F%RM#-?;"+7J!ICLB7D\29M^V\O.*^
M4)=0H=FAWM_><I!NJ;JEJKRDT-C-BZIX]_CU=X17D91][>WLH9!HHHIXHVI+
MYN3CL9.'Q)^:P$]`KY.1R```Q@``?@``?0``R0,#QP,#Q@,#QP0$QP4%R@<'
MR`D)R0T-T0\/B0H*RA(2S1@8D!$1X"$ATB`?SR`@FAD9I!L;TR<GK"$AZ2\O
MKR,CI"$AMB8FV#`ON"@H[C4UNRHJOBPLPRXNP"TMQS`PKBHJR3(QQC`PWC@X
MW3@XSC0TRS,S\SX^]4)"U3HZN#(R^49&U#L[XD%`W#\^VS\^X4)"^4I*PSL[
M^DU-Y49&ZDE)Z$A(^D]/_%!0^E!0[DQ,Z$I*W$9&\4Y.^%%1]U%1]5!0]%!0
M[E!0[5!0T$9&\5=7Y513]5Y>]6!?Y5E9^F1D^&1D]65E\V5ET5A7_&MK^VIJ
MX65D[F]OS*"@TZBHW+&QXKZ^\]#0^??W\>_OT,[.S\[.R<C(^_O[]O;V____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````)/M">`````%B2T=$`(@%'4@````)<$A9
M<P```$@```!(`$;):SX```#!241!5`C78V#``FSM_`O[IDG-FBW+E^T3F54.
M%++SSNQIGRHI("`RLSHXO:P>*.01W]%5Q2NFHZW`WYI65%<"%`IMYFABL5"4
MUU+192^HK<P%"K'UMR0SFRB)&NAI<%74Y*<`A;K;<OR8S-5-+8U5N1N*61.!
M0IVE@6Y./,J&5FKZG"49"=%`H<9P3T>'23*:1D+3)^:EQH8!A9*\G&U<)HL+
MR@G/F)`2$Q$$%/)UM;9WGR(Q=XZT66]<5$@`-N\``$JQ,9DBWA,,`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P9BYP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S-#$T-B`P,C,P
M,C<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M___&5E?(6UW/:6KCHZ7JK+"WE9?#>HF79XEV27N'9YJ2=Z.*?[ED6Z&4C,EY
M=*.BGM.DI*6^P.>$C-&>HKMU@\JVP.OT]?BBK\_W^?O9V]S.T=+O]/7V_?W&
MS,SEZ^O8WM[*S\_Z___X_?WS^/C3V-C(S,S`Q,2NLK+W^_OJ[N[H[.SEZ>G+
MS\^VN;GO\O+N\?&)BXO/T='Z^_OY^OKX^?G0T='/T-#;X-_8W=SQ\O'<W=S5
MUM7&Q\;X^??-S<G+R\G)R<C+P+;(N[3/A&#";DK*O+>\:4[FKIR_GI/@Q;S!
M43+3=V&_EHS$02V_D(GCGYK*@X''@H#4CHO#CHS=HJ#AIZ7\O[SSN+;(``#'
M``!]``!\``#)`P/+!07(!07("0G1#0W3$!#.&!C;'1W@(2'1(!^:&1FD&QOJ
M+R^O(R/M-36[*BK',##=.#C1-C7X0D+X1D;#.SOE1D;]3T_[4%#U4%#R5U=\
M,3'[:FK)5E;06UN01$3<:6CI>GKUBHKB@8"X:&CZDY/UDI'UFYK&?W[SGI[-
MC(NL>GFXA(/.EY:^EY?[^OKZ^?GV]?7U]/3$P\/Z^OKU]?7Q\?'N[N[M[>WJ
MZNKHZ.CEY>7BXN+AX>'=W=W3T]/0T-#.SL[)R<F^OK[___\`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!I
M`_N?`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4
M"-=C8,`"8F(SBJLJ\E,2HN.3TW**RH!"E;5-[:V-+,Q,U35U]0W-+4`A(TU=
M%1TU%[\`9T4%564M;:"0D+G)-&EW-Q]_5V]94[.I-D"AB;W6<V2\/-A[?#VE
M)DV9/1\H-&'R+`L'`2Y.'@Y!B?Z9\^R`0GTSYBYP%.7CYN47MI]NZ[00*&1H
MI22O;BPI)B(N9V"IIZ$/%`KK"&X+"@ED98N(#.\.[>H$"J4G1L4EI685EI:7
M%.3E9F=B\PX`]?HR\:^;_9<`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W!H+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#,S(#$P-3$U-#,T,30V(#`R,S`S,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___\TC)<U)2LNJK;$-(+X@,<TR0[DT
M0:\S0+DX1MI%5<U(5N!28=M280D%:A81=B<BA3HVE3@UA4M'HT9#E551J5).
MHP``:@$!;`$!:P$!:@,#;`,#:04%;@4%;`<'<0D);@H*<@T-=0T-<1`0>!(2
M=!04?1@8?A@8>!T=@B$AAA\??28FC!D96BLKCB<G@2\ODC4UESHZG#@XD#X^
MGD)"HD9&I#\_DT%!EDI*J3H[@TU-J4]/JDE)GDQ,HTA(FE!0JE%1JU%1J5!0
MIU=7J5Y>KFIJMV5EK)B8SU148PT.2$5&@Q<;>9"2O'=YB=C:XX&(GL[.N?'Q
MW-W=T<W-Q\_/R[*RL']_?M+2T>'>N?_[TMC.BOSXW>OAH<:^DO?OO]3.I]/-
MJ*:CD>?/5OKA9/_J@/;B>\RUB=2^LLP``,X#`]`%!=$'!]0*"M8-#=@0$,P1
M$=L4%-X8&.$='>0A(>@F)J<;&^LK*[`A(>XO+[(C([DF)KPH*/(U-;\J*L0M
M+<$L+,<N+O4Z.LHP,,TR,=4V-=(T-,\S,_@^/OI"0MHZ.N`_/OQ&1N5"0OY*
M2NI&1O]-3>Y)2?]/3_Y04/),3/U14?9.3OM14?E04,Q65LN`?_'Q\>'AX=+2
MTHN+B____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````%`+TV0````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````M$E$0508TVW!L4T#01`%T#^S,[,GVUA"0B(S
M!5`$(<)].*,'6J$&(F=(CI'L'K!$2&)\>WL[<R[`O`=<(:SI^V81OW_GP;)E
MG7T*EOVJQ:F4051-+('QW`G5OE0V53&K2+A3)OTIGLW4LM>CH&6=[+'M>B)F
MBH"`ILBG^W<G$J:("0*/.'_$J^IME^M0VYO@:<LO#TW2W-2KCPT"6K<]2^IF
M2F4<W<'XVAPHB2Y,A^(>@7]<`#FD25H"+9D?`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<&LN<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#8@,#(S
M,#0Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M______[_Q\;'\O'SU-;6NL&^S=?2S-;0/'9-,VX^Q=3(0')(1'A,3XI7:)9O
M5GM::H%LAZ.*%5,:)6`I5(A83790CYZ0=Z%YIKJG"DD,)F4G(E(C*UTL28!*
MAZ*(`$(``#X``#L``4,!`3L!!4@%!44%!4(%!3\%!TH'"4D)"4$)"TL+#5`-
M#4@-#DH.#44-$%,0$%(0$E`2%%(4%$\4%E86&%@9&%48%T\7'5T=&$T8'5P=
M(6(A'UP?(6$A&T@;)V(G(5`A+VXO+VTO)E<F+V@O*%DH-7,U*ELJ-7$U+5TM
M,&,P+EXN.'`X-&@T,&`P-FHV,6`Q0H!"0G]"07I!1H)&07A!0GA"1GM&3XI/
M3HA.3XE/27])3(-,4(E048I14(A03X5/4(502'=(4(1037]-48-16(U85(=4
M5XM758A57HM>:I-J98QE9HAF:HQJ:(EH;HYN>IAZDK"2C:F-@IN"HL"BH;NA
ML,JPK\>OY^_GV^';Q,;$U-74,F4Q,&$O-F8U/W0^1WU&Y^?FW=W<^/?W_?W]
M^OKZ]O;V\?'Q[.SLZ>GIX>'AV-C8U-34TM+2S\_/S<W-S,S,N[N[LK*RIZ>G
MG9V=E)24BXN+?W]_____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MOK*OP@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!
M5`C78V#``F;-FEZ6F^5GH::@:F3O$18/$IHQI2HGW$[+4D?7QB4X*A$H-'-J
M3V6*HUZ0H+YY:&9T0BQ0:%H_4T6#L92XB(FT$$=&7!-0B)FQL]1:G8O-S-Z#
M3R([PA\HU-;14JRMR,/*Z18<DQP9Z`,4:N_N*U)1%JYE%TU+E^.MEP4*=;5.
M+%32-,UCJ2XOD1?P=@4*]4Z8G*]A:.O%SUTC*>;K[@04JILTN<#`RCDD*;6Y
M,<!3Q@&;=P!!`#%!916*JP````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]P;"YP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C`R-2`Q,#4Q-30S-#$T-B`P,C,P,S<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____'P<+__O_&Q\?@X-_-S<S,``#-
M`0',`0'.`P/,`P/0!07,!071!P?-"0G4"@K6#0W.#0W8$!#/$A+;%!3>&!C2
M&!CA'1WD(2'4(!_,'A[.("#H)B:G&QOK*RO8)R?-)26P(2'N+R_6*BJR(R.Y
M)B;=,"^\*"CR-36_*BK$+2W!+"S'+B[U.CK*,##-,C'A.#C5-C72-#3/,S/X
M/C[A.3GZ0D+:.CK@/S[4.CK\1D;E0D+^2DKJ1D;_34WN24GL2$C_3T_^4%#R
M3$SN2TO]45'V3D[[45'Y4%#Q4%#*1T;534WZ75WG65C]9&3J75W_:6CY:&CZ
M='3X>WO8T='0R<G,Q<7RZ^ODW=W2S,S_^?G^^/C\]O;V\/#EW]_AV]O2S<W=
MW-S^_O[]_?W\_/S[^_OZ^OKY^?GX^/CW]_?V]O;U]?7R\O+Q\?'N[N[L[.SK
MZ^OIZ>GHZ.CGY^?DY.3AX>'>WM[;V]O8V-C6UM;4U-32TM+1T='0T-#/S\_.
MSL[-S<W,S,R[N[NRLK*GIZ>=G9V4E)2+BXM_?W____\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!&.8BH`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```*Y)1$%4&--MP3M*!$$0!N"_:[NZ9\;'PA[-
MS%A4\!!&)H8F!J)X-#.7!4$9Q.FI1Y<'T.\#_DBXA]_ZS5$I,+76^DL&NE_Y
MR(QN+O)\#4+XIXS,*=15GBXK"+X\3'.A.W-3N:B/2*#S#8DC(@<')7K-.&OZ
ML9<T[+9#3MT"&3J_S4L,HC&-K34#0=^_UUZX;H=JJZD@8_^U&G,^/BFIB;B!
M<&BR89Y.:UE^S-WPCU]2_U[R:=1";P````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W%A+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,C(S(#$P-3$U-#,T,30V(#`R
M,S`R-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```&`4$Q410``
M`/___V,%*F,)+&D-,60.+V40,7,8/&X8.FX9.FP<.W8@08$N3HPU5Y="8Y!!
M8(M#7X=+8HA098I2:)-;<8U9;9)C=:%TA:AZC+>1H.C;X%\`)V$!*5\!)UX!
M)V(#*F,%+&(%+&4'+F@*,6L-,VX0-W$4.FH5-W08/G@=0G@=0WPA1UP;-H`F
M2W\F2H0K4&,A/(DO5&8C/FLF0FTH1(TU66\J1GLP3G8N2W0M2G$L2)$Z7G@P
M3GHR3WXT4GXT4WPS494^88`U5)0^88`V5)A"9H0Z6)M&:8H_78Y"89Y*;)Y*
M;9)&9:!-;Y9)::%/<:)0<II,;*%1<I]0<)Q.;J!1<K^2I+6?J+2AJ;>FK:N0
MG,"IL[JEKKZLM-G)T.O;XO_^_\?&Q]35U<;'Q]35U.?GYMW=W/CW]_W]_?KZ
M^O?W]_;V]O'Q\>SL[.GIZ>'AX=C8V-34U-+2TL_/S\[.SLW-S<S,S+N[N[*R
MLJ>GIYV=G924E(N+BW]_?____P```*0//4T````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````K$E$0508TVW,L0W",!"%X;/OS@G!!4J'Z&BR
M",.P!#LP"AT2,]`Q`!(2$K0@B&/[;!Q1PE]^TGL`/RG8@-QC?W!SSVR:=K(C
M@"35/G='3T1F5B-HR-*G53HMU%="(1D>)#%F@VP;SK[0;3M%E?,5N;:LW;N0
M6?NGT%+S.'-#*J1HVN9\06YK$WP8B0;4.NK.5AR]CT,AM`B"ZFR-=KT+4NB%
MD`RA*D=!4HKPIP\CITA:`^XBPP````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W!M+G!N9P``
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,T
M,30V(#`R,S`S-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`
M4$Q410```/___YM[?))^?^+0TMJXO9J+D"XYECE`BE16:[R]QXV5TFIUMX*,
MS#)%GC5(HS=)GS='D5%EPCM)BUQKL%MGHB8ZE2<[E2H^E"D\CRU`DSE/K4-5
MID=:K$98JE1FM%UON&=YRFQ^SE]NKCI#:G*$RW2%R&Y\MV]\LS9&A#A(A3M)
M?T]AIT%->TM7@$A4>6!IA8J5MEID?9*8HVQT@9B>I8F.DYR>GV1N<:Z]O96:
MFM78V-+5U=35U82-A[B\N3Q40$]A4EAP68B:B6UR;6AL:,O-RWN-=)B;E6EN
M869L6I^BF'^"=:&ECZ.FDF)E3V9I4ZNNE*&CD'AZ8H:(<X^1?8""8IV??X:'
M:8V.=[*R@*ZNE)220:.A78&`2XF'49>69J*A=;BWAZBC/:^I1(%]-Y",2;>T
M;+>S;K"M;;NX@<&R`JV?"+FM%=3&(^[?+^G:-<*V+LB_._GM4.[A3N794.+6
M3XZ',]#&3(%[+\.Z2.G>6=W358N%-JND1N+98<&X4Z6?2:2>3HF%3<&\>,_`
M)96*(.?7-;6I+??G/JRA,J^D-L6Z1I*)-,W"4S@O&:Q]&(M_9,*5.+%<!:E9
M"K=L(;11`,9=-=QV5KLY&:XC$+$G$:2-BKBDH^70SZPB(,V[N[VVMO___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````!"0?HX````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^
M````P4E$050(UV-@P`(<7)R8N-7D^24DI01DA115@4*.=LZLO`H&GIKZ,2;*
MOH9*0*'^.1/=>>3T4OT%PV+53;TU@$+,"^=9ZO`%Y-0:-35XM&2(`(7,;=VX
M9+2R<X/S"ORJ2\P2@$+6-O;&XMIM<2GY-='%Z:(10"&6!7/9=,4JTZHZZY/*
M(AOC@4(SIL^<S^F57!0>%6@5ZM/A"A2:-&'R+':+UO;2K*#$NL)F8:#0U"G3
M9G-(AU1D]O5T=_66JV#S#@"WTC+QV/7R9`````!)14Y$KD)@@@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O
M9W)A<&AI8W,O9FQA9W,O<'(N<&YG````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-3`@,3`U,34T,S0Q-#8@,#(S,#0S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````(E03D<-"AH*````#4E(
M1%(````2````#`@#````6,P=C@```P!03%1%````____N!05RC4VLV5FGQ8G
ML'>"APPJ1Q$MR+;`4"A)FGV6:D!V73]]4SI]-BM[GIG**R9:54^5>7.T=G&P
M>72OCXK&EY/&2$./1$!UAH'#<W"C>WBAY>3R1$"+6E>@CHO"V-?J5%*<145^
M75ZF&AU43U*9EYO&J*_#\??]X.#?SZRGS8%[S)..RY.0U)R9QP<`>`0!Q`T(
MRSDU\4Y)\U=3ZU10Q5E6SE]<\YZ;]*.@S8B&UY22Y*.A\;*PU)Z<X*FGK82#
M[;BVN(^-Q)F7^,7#X;2R^\K(\L/!RJ:ESZNJV;:U\M+1WL'`^]W<\-/2O@``
MQ0,#PP8#P0<#P@4%OP4%R0T-R1`-RQ`0S!@4QA@8U!T=U"$=UR$AV"@DEQD9
MGAT;XB\OXC(OJ28CY34UM2PJYCPXP3,PP#`PUC@X[T5"[D)"R#HW\$9&O3L[
MX$E&WT9&VTA%]%)/\T]/\U!0[E!0[E)0ZU=7Q%-1QE53]6IJV6QJS6AGYWU[
M\XV+X(2"^):5\I63O8F(QY*1^;R[Z+"O];NZSZ*AYL/#_-S<_O[^_?W]^_O[
M^/CX]?7U\O+R[N[N[.SLZ^OKZ.CHWM[>V]O;V-C8U-34T='1S\_/SL[.S<W-
MS,S,Q,3$N;FY____````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````H/&#NP````%B2T=$`(@%
M'4@````)<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``C@,X_.JRC.C
M0@-"(F)3<DN`0JI<+%:6]37F%946U;5U#8U`(4%E=<V)TV;-F3U]RJ1>QIX)
M0"%):2D%3FU/3R_O#I]./W]?H)",K+@\'VN0461<FHFI66$.4$A`452"GSTP
M+#HQN[BT@#D#*"0F(B3'K6-M8VO7TM9JW]P$%!)64M.8,V/JY+ZN[GZMF7/G
M`854>-ET]?0=G%S=/=S:79P=@4(\3`;!X3%)645E^<;IJ<D)V+P#`(6D,?<&
MJ6\]`````$E%3D2N0F""````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]P="YP;F<`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S-2`Q,#4Q-30S
M-#$T-B`P,C,P-3``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#
M`%!,5$4```#____0-3;*9&7`76B2JYLZ>3L`6@``5P``.0``.``#7`,%704)
M7PD-:0T*0PH8:A@12Q$?<!\95!DA7"$J9BHX@S@R;S([>#M(CTA0F%!&A$9>
MI%Y>H%Y9EUEDIV1JKVIEI65JJ6H39!(P?"]FIF4)905GJ61NK6@Z?R=;H$AX
MK5<V=0-KGD!5<`)/8!&;JE-^@B9[?@UV=R=Q<4%85AV(AU?#H1FTFCR2:#_.
M;1W6=2?'8Q?%7!"T2025/@>Y20?#31*>3BG?5BO(,PVB.R2_4CR;9EJJH)[$
M%`'(&P>](A3A*B''``#)`0'(`P/+!07(!07*"0G."@K0#0W3$!#6%!38&!C/
M&!C<'1W@(2'3'Q^D&QOB)B;E*RNL(2'M+R_J+R_I+R^O(R.V)B:X*"CN-37M
M-37L-36[*BJ^+"S#+B[`+2W',##O.CK),C'&,##@.#C1-C7.-#3+,S/T/C[S
M/C[W0D+U0D+5.CKX1D;W1D;</S[;/S[A0D+Y2DKF1D;Z34WE1D;J24G[3T_Z
M3T_[4%#Z4%#N3$SQ3D[X45'W45'U4%#T4%#V45&K7%NM9&3___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````#2H-\+`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK
M/@```+9)1$%4&--MC+T-PC`01L_VV<XE1("(*$"P`"/0L@X+4-,R#A(-"[`(
M/Z)``AQBGQ.2&E[Y]'T/X`<!).@Y&2_/%2NM\U%O(T%8G')]\RP1DV%F`$&C
M-=1<M4:E"S(E2-`FI7[?OEF9`5&L6H56)2>SDD_,\J1QW2H/LMH=#R+:06JJ
M;6R59Q;[IG%4$+ER[=M\R+RZ+ATN4O(^Q$[QG7G^F$VZD/OXT!XY!G4QQ9!T
M^?)U'>$/7WB"1QIOPN=:`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V=R87!H:6-S+V9L86=S+W!Y+G!N9P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`R,#,W(#$P-3$U-#,T,30V(#`R,S`U-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````")4$Y'#0H:"@````U)
M2$12````$@````P(`P```%C,'8X```,`4$Q410```/___X@;',6WN:.>GYR3
MEK64H,VWO["+F:J:H+^?K,O)RK^UO,&ROKNLO>CEZS<VF4Q*L%54Q&!>OP``
MA`4%B`4%A@<'APD)B0\/BQ`0DA,3DA@8D"$AGR,CGR4EEQ\?>"$A?2@HD2HJ
MDB@HB"<G@C4UL#4UKBXNEBXND2XNC#0TFS@XI34UECP]I$9'O3L[GTA(O$)"
MJU!0P4Y.NDM+LE55P$)"CE%1JDI*F%%1HEY>L6UNRVQLPG)RRV]OPO?W^O7U
M^,_/TL3$Q\+"Q>;FZ.3DYM+2U,7%Q[JZO,7&R?+S]??Z^O'T]._R\LG,S/O]
M_?K\_.'CX]W?W\[0T,/%Q6^J;&B>8EVB37Z<=_S]^^3DXM+2T,C(QO?W]O;V
M]?7U].?GYM+2T<K*R=O6U<<``'P``,@#`\L%!<@%!<@)"=`-#=,0$,X8&)`1
M$=P='>`A(<\?'\HB(9H9&<HB(LXF)<HH*.DO+^TU-=@R,MTX./5"0K@R,OA&
M1N)!0>5%1-,_/\,[._I/3_I04/104*X\//-65O)75_5>7OID9.I?7^A>7O-E
M9?=H:/MJ:N5L;/AX>-;+R]C1T<O%Q?GS\_CR\N_IZ>[HZ.WGY^+<W/KU]=#,
MS/KZ^O___P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````!N_780````!8DM'1`"(
M!1U(````"7!(67,```!(````2`!&R6L^````N$E$0508TVW!L4T#01`%T/]G
M9\=GK^Y`LFSG9(24X`8LT0150$1`$Q1``XB,P#DYN6-+QA><?+<[2P'P'O`'
M\8"V:R]]GW-0;:(]"=#,TS@,)4L(LQ`)P>MFJ4'BHNVZZZLN&12RKB[-<]"7
MICCE"XK[]V*<;">/6X\Y"A3)"V=OF67<?4;A!&(;,VG[;+Q+HY`?"C]_+ZO=
M'.36SUZK0W$\V0]C6,T'^L6G`D%?J*:+=`AT(2O^\0M):CXGC?'3?`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<V$N<&YG
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#<@,3`U,34T
M,S0Q-#8@,#(S,#,S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@``
M`P!03%1%````____@ZV$`'0``',``$D``$@``7$!`W8#`W0#!7@%!78%!G@&
M!G8&!W4'"7@)"G@*"W<+#7\-#7T-#7H-#WT/"E,*$((0$GT2$WL3%'H4&(88
M&($8$5L1'8L=&GT:'8D='(0<(9`A'X<?&VL;&609)(<E)8@E)XLG*Y0K(G4C
M(7(A+YLO(6TA+YHO)GHF+I(N*'LH-:`U*X$L*GXJ+8,M+H4N+X<O,(@P*G<J
M,(<P-(XT,XLS.)@X.)<X-(TT-H\V/J,^/J$^0JI".I0Z,H`R0*)`1JY&0IY"
M0Y]#.HH[0)5`.XH[1J)&2:=)2*5(1J%&3:]-2:9)4+103[)/3:U-3*I,4+!0
M3ZY/4;%14*]03JI.4:]11I=&4*Q05+%43Z103)Y,3Z-/5[%75[!77;9=7[=?
M7K9>7[1?6:A93I-.9+MD7[!?8+!@9;AE:KYJ:+MH6Z-;5YQ75)=4:+=H=+]T
M::QI>L)Z:Z9K9IYF=+)T;ZIO;ZAO:)UHA<B%ALB&;J)N;:%MB,B(<*1P@;N!
M=J=VB,"(>:5Y@:V!H-2@K,^LL]>S,)$O,HDQ-H\U09Y`/YH^/Y@^6[=:9KAE
M;;5LIL.E____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````C`@##@````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;)
M:SX```#`241!5`C78V#``EC95+WRD^UDN)FYQ)6,W(.!0FRRKGEIGNJ2@KS"
M"GK.(>%`(3'+S/*NBN+:AJ+"EHS`2#^@D&YLP92IK5GM3-55W74Q81.`0C[Y
M*8D=C97--65MG?71'M9`H<GI_6KR@E*B<DX1D^)]'2R`0MG^&B+L[`+2FHZA
M,4$NO<9`H;@>"4X^<^^$G-*FW(DVIOI`(5L9;A8>10.WF-22)'LS0VV@D#(_
M,X>0G(YS2%1`GY6)E@HV[P``V:`MR[S@Y1,`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]G<F%P:&EC<R]F;&%G<R]S8BYP;F<`````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`U,"`Q,#4Q-30S-#$T-B`P,C,P,C8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````B5!.1PT*&@H````-
M24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___\G0X]266[`R>$!
M)X40-)(*(%8?094J0'E0;;ERA+*&D:T#+(8#*X0),(,2.(H9,6<I2Y@Z5YHZ
M58](:+`G.%U(9JE.::-7=+5$6XQRC,9B=Z528H=\D\:*H-!]D;VELLZXQ>($
M+(`&+GT+,G\,,7P.-(`2-X(;/XDK3)`?,EDX69TE.V=$9:9(9J5:=[1C@+UG
MA<%IA;]MB<%D>ZBAL]D>/WH]6XU,9HXU47%`5F1395]N?F@P?@UNLE!%CR%)
ME"9?ICYGITE@I3IFK$)RLT]LJDQ&CATZ;!M`="%>HC5-@RQ2BC!7D#19DC9F
MH4)RLTIJI49TM$UVM4]UM5%WM5%RKTYSKTX_AQ!#=B-:GB]'?"9)?BA+@"I/
MA2U1ARY4C#%3B3!6CC-9DC58D#1KK4)>ESIOL$9CG3YCG#YKI49NJ4EWM5!Q
MK$QWM%%VLE!?GRN`N4:#CW9+A0./OU%GF12)LR^LRTIM>$E\F@6XSE";KQB^
MRC5X?C>@I@#9W$V0D#VSLV"QK@>KJ#O*PQVFGB#,O`#-O0',O076Q0W8R1"R
MI134QA_HV";HW#KZ[4+=T#S&LP#,N0/-N@G3P1ODT"'%M2+KVBOXYC[\ZT;^
M[E#ZZ4_.N`74O0K___\`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````PVRL_`````6)+1T0`
MB`4=2`````EP2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"F,4$1>19
M]#555?C9+)IFS08*:>M*R9DH:*FK\`G83IPPIQHHQ,ZIJ"3.I*',:M4R8V9#
MJ3-02-94VD!"AE>M<FI??T6H>R90B,=,4D>8V[JM>UIMD7UX@!]0R-A0C\.\
M;FY7:[FK6T&0OR]0R$A4R*:G8UY-H5-P?DYZH@]0B,NR<7)[<YFC2V!87E9R
M?`Q0J'AZYZ2J2`?OC-R(@-2$6"^@4.^4^A([C^BTD(+LE*2X*$]LW@$`R3$Q
M]5E`CD``````245.1*Y"8((`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W)O+G!N
M9P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#`S(#$P-3$U
M-#,T,30V(#`R,S`T,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X`
M``,`4$Q410```/___P`E?P,G@0,G@`TPA1]`D#A6HCI4DE!MM&1_PV6`P``G
M?0`83@4L?PDN@0HC61(VAA@\BA$J81]"CADR:B=)DR$Z<S!1F2I$?4%@ICM5
MD$AHK%!OLE=VN%Y\O5ETL62!PFB$Q&:!OVJ&Q1`R=1`Q=!0U>!<X>!P]?R9%
M@CA9GS)-ACQ9DD9BG51OI6F#MG6-OLVR`,RR`,RT`,RU`,VS`<RR`<ZV`\ZW
M`\RT`\RS!=&W!\&J!\VS"<*K"=2\"M2]"M:\#<ZW#<*K#=B_$,:O#MO$%-[%
M&,VW%]*Z&.'''<6P&>3-(>3.(=2_'^C/)M;`).O2*^[8+^[9+\ZZ+?+9->'-
M./CC/OKB0OSE1O[J2O_H3_[J4-W+1OGE4.W;7-"U!?7<.L^M!=6S#=V\&.?&
M)O'1-?K;0NG.1O[@3?793OS@4<PK$-4W'=]%*^E3.LM+-?%?1MM80NAB3/!H
M4?1F3YXF&Z8L(:DN(Z\R)K(S*.5#-;4U*KHY+;<W++TZ+L(^,<`\,,A!-,4_
M,\I"-NY10L]'.O!51M5)/M5+/MI/0M]21O-;3>-62?-=3_->4.M;3N=93/)?
M4?!?4>Y=4-<M(>([+\`Z,,@^-.Q)/O)52N-32?-;4.Y:4/___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````,UZ5?H````!8DM'1`"(!1U(````"7!(67,```!(````2`!&
MR6L^````G$E$0508TVV,NP[",`P`;2=U0@6(!?$-7>BO\<LL2`P,J!5YVZ0S
MW'@Z'<`/"`?PRS2'Y9VOX_38^QL!\,6HQ#5:1!S=``2&5]6P)N,1C1M25^Y,
M*B$4YEZQU*[LITJ+>=XY))*T5;Y4E63OO;)8LH(%:54;>7:V#TJ5KFHMB@[]
M*9&^6MM>Q]P$#7,DU5-M6_7LACR9_A9MHO"'+P=F4B>9(#_3`````$E%3D2N
M0F""````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M
M97,O9W)A<&AI8W,O9FQA9W,O<V0N<&YG````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#8@,#(S,#,U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````(E03D<-"AH*````
M#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____UCY`S,/&.38Y
MT]'3(B,C]_KZ\?3TW^+BT];6SM'1^OS\X>/CSM#0XN/C[/#OFJ^>)G`I`$``
M`SL#"6()!2H%#6D-#F,."D<*$FT2&&T8&&P8'W8@'V<?"1T))WLG(6`A*6\I
M*FTJ.(PX.(@X.WT[2)5(4)U01HE&4)M05Z)77J=>9*QD:*]H:K!JA:.%)"@D
MH;&A<7)Q\/'PR,G(,(,O08]`6IM99JME:9)C'T81(BH`-C8U1T=&6EI9O+JU
MM(%DDD$R;`<`QP``R`,#RP4%R`4%R`D)T`T-TQ`0SA@8PQ@8Q1D9W!T=X"$A
MSQ\?G1D9RR$AQB,CZ2\OU2XN[34UW3@X]4)"^$9&XD%!PSL[^D]/^U!0]5!0
M\%-3\E=7^%Y>]V%AYUM;Z%Q<]V5E]&5D^VIJR\/#QKZ^XMK:U<W-^/'Q[^CH
M[>;FV]75_/S\]_?W]O;V\O+RZ^OKY^?GY>7EWM[>UM;6TM+2T='1Q,3$NKJZ
M<7%Q9V=G86%A4%!03T]/3DY.1D9&0D)"/S\_/CX^-34U-#0T,#`P+R\O+BXN
M*BHJ*"@H(2$A'1T=&QL;$!`0#0T-!04%`P,#____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````?!8M%@````%B2T=$
M`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!5`C78V#``FR<`Z/3
M$\*]W5W<O/S#(F.!0L+63JF)40$>+JZ>?B$1,7%`(4EE"\=DIF`?WZ#0J/BD
MM!2@D**FGI:5`W-F1G96;DY.7CY02$U?6U5:2)"/BU.`G8>#EQLH9*EC+BLJ
M85!17E)84%1::0H4TE57$%<R8JW@-RDL+JNJK@$*:9A)B1BRM#76UQK7V3?9
MM0*%5&3$&"9/[&MO;FAJZ>CN[0,*R<DS3)G4W]72V-!LV]G#-@&;=P`8!3`=
MZ>/820````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S92YP
M;F<`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-B`Q,#4Q
M-30S-#$T-B`P,C,P,S8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.
M```#`%!,5$4```#___\#&[P2++LF.JHP1\HM0K0Z4>,_5<Y*8^M,8^%1:>M0
M9N!D96LS2;\`(J\`(Z\!([$#)+$*++8*('@8.L`F1\PK3,XJ09T^7MQ&9>(Z
M4K--:^1/;.50:]ID?.AE?>,`%VL!):P$)ZX%*;`%**\&*:T'*[0(*Z@)+*8*
M+*X.,;81-+D1,J@6.;P9.K42*7\8-Z(>0,(B1,8@0+@@/Z\@/J@:,8@G2<D<
M-)$A.IHC/9PP4M`B.9(H0Z4U5]0J1*<O2J\[7-@Q3+(U4;HY5\8V4[Q#8]T^
M7<PS2Z9'9^!`7,9#7\M,:^))9M5'9-!0;^-,:=91;^-1<.-1;^).;-M-:]A2
M<>)1;MY"6[1'8;Y9<M-I@^<5-9E7<<=MA=5XC]R!A8BIK*UO<W.>HJ*2EI9X
M>WN4EY>3EI:#AH:>H:%W>7)Q<%#6N`WAQ!W4NB#NTR_*M##5O3;ZX$+GSD#J
MTD;_Y4_YX%#ZXE[XXF7-K0J]KFC.P(#'HP_%H0_)I!#!GA+%HA3*J!7$I!_-
MK"+&IR.NE"36MB["IS"QF"W/LC;-LCNYHCW8O4G>PT^:B#NGE$7NTV3(LE2@
MD$BNGE>FF5^RI&?*NWBXJF^@E&''N7S*O8+6R9+___\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````'<B3]`````6)+1T0`B`4=2`````EP2%ES````2````$@`
M1LEK/@```+])1$%4"-=C8,`"%!7-I1,F3C)555+1,;;W"@8)&7@JQ/?UZ`HH
M:QO9N`=$`(5$)*+EX[HZ-02%1<4E94+\@$*V43%RD:UMFNIZ%DZ^X6'>0*&9
M<V9/F]#8T#]Y2O7TFEDSI@*%*BM*\JOJZG/S"HK+RDN+"H%"21EIO#FUS=F)
MJ5DIZ9EIR4`A'E9FIMBF#C%V3FXN#CXV%J"0J[X:OV%+MX=44*B/BZ.=%5#(
M1$M)R*R]-U`VPM_-V<':$IMW`.(K,/B2N%,A`````$E%3D2N0F""````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE
M;65S+V=R87!H:6-S+V9L86=S+W-G+G!N9P``````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,#0R(#$P-3$U-#,T,30V(#`R,S`S-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````")4$Y'#0H:"@``
M``U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\'"PK*SL]35
MU.#@W]W=W-75U,W-S+\A`,$B`;\B`<$C`\,E!<$F!<$H"<<J"LDM#<(K#<PP
M$-$X&,<W&-4\'=A!(=]**^).+^93-==4..Q</NA:/N]@0O%D1M97/O1I3>1D
M2?1K3_5M4.]K4/%M4>UO5NUP5W]U<__P[<`?`+\A`\0E!\(H"L4L#\(M$,0L
M$LXR%,XX&\@Y'<DZ']Q")MI'*\Y&+9<R(8XP(.E6.JI!+MA4/LM3//-E2NAE
M3/-J4/)K4=UB2O5R6=5F4\)=3-]M6?B)=?>1@'U-1=&/A,R[N.]_;>N#<_&)
M>>B&>+=K8/F4AN2-@/NSJ7]?6J:(A-3%P]7'Q<J]N_GJZ,-[<O6?E,Z\NM;$
MPOCEX^'0SN;6U.[>W/KJZ(N`?\V[NNK;VO?HY_[^_OW]_?S\_/O[^_KZ^OGY
M^?CX^/;V]O7U]?+R\O'Q\>[N[NSL[.OKZ^KJZNCHZ.7EY>3DY.'AX=[>WMO;
MV]K:VMC8V-;6UM34U-+2TM'1T=#0T,_/S\[.SLW-S<S,S,K*RL?'Q\3$Q+^_
MO[R\O+FYN;"PL*>GI____P``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````.C%[TL````!8DM'
M1`"(!1U(````"7!(67,```!(````2`!&R6L^````NTE$0508TVW+/0Y!012&
MX3/GS)GA)HA"(@H)M4)O'?8@-J"@4E)(KD)O,S9!HA&)A.LW<<\,UZAYRR??
M!_"3@NXC:1ZW-TF=-IJ8UP29JJ9EU@='_!4\(700Y7[9>*4)B>@%&JZEC!]I
M+4/68?;>`L(Y[Y(D0VUX;WA'];!J/`M1<5]6B*U5NWE5@;`266R(DW3>ST5+
M"<=\;!"\]TYZ)K;C::#<D(*\1,#8$:,*-&%X>R]NP79F<:#@3Q_81T(T59I5
M?@````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O<VDN
M<&YG````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,S4@,3`U
M,34T,S0Q-#8@,#(S,#0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=
MC@```P!03%1%````____BXJ=H:&T7%YUI:>]TM/<*C%1:W*2<WR;ZNSSG*2\
M97BF=XFQ8V=O'CMP`"9F!2MJ!2MI"BYG$#9T%3=N(4:"(41[-5B3,U6+-%*#
M1FFA06"20F&3,DIP.U6!05V)4'&G3FVA572F3VR:4&V;0E5S:H6P9&Y^"BYF
M$C9N'T1[+D^`,DUV.%1_/EV)1F>:6'>F6GBCI;?1`"YK`S!N"35Q#3IW'4F$
M+UJ4,%.!-EF)0FNC.%B$.5F$1FJ<3W:K4'6H0V*,2FF47H"P9H:R;(JR:H.F
M>Y>^>9.W@)O`CIFHK[W/ZO#VY^?FNAH*MQL-OAX/NQX0N!T0N"(5QRD:P"<9
MPC`BS#8ITSHKPC<KF"TDHS(HKSHOVD@[HS4LX4P^ND(VKSTSTTY!Q4@]ND0Z
MQ$H_[%U0YUI.UU9*V5M0[V99YV-6[&5:YV5;IT,^VV1>I!T8I1\:J20>JBTH
MM#`KPD$\G#LWNTA#T%1/L4E%P%51TF1?VVIET6=B?'AXB(2$_O[^_/S\^_O[
M^OKZ^?GY^/CX]O;V\O+R[N[NZ^OKY.3DX>'AWM[>V-C8UM;6U-34TM+2T-#0
MSL[.S<W-S,S,?W]_____````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````7$UNVP````%B2T=$`(@%'4@````)<$A9<P```$@```!(
M`$;):SX```"V241!5!C3;8T[#@%1%$#O[\U($(U*HY#068/6"FQ%(Q*+L`0K
MT(N&!6AL`"&81'S"O'NOZ3GE*<X!^`%A.FRT%J,0!#2J?GQ,<'P_E_E:&$S-
MXEB``+7;L1ZC%T9'$P&!F>$FS*/?ZEF=^BLK6LVK6<*&3,0)YKH7:/NV5C8D
M1!:TZ'N&D%5.LDL.M_0"YRN^3P*#3S0G0GY5W?U1V@CL[KF22)I*IKE&+XXO
M-6$*I8!1$2G"'[Z,BU<BH@YSC@````!)14Y$KD)@@@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]R=2YP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`T,2`Q,#4Q-30S-#$T-B`P,C,P-3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^L#1BL$!JQ
M%!ZR'BC),CRB+S?!.D.M-S[714^W/47&25'B55[85U_B7&786F*\("O;XNJ\
MQ<Y\@HBBJ*[J\OH@;K,N=+(Q;:(X=:M4FME/C\E8F]>UO\BTOL?'T-C4W>7B
MZ_,`6J0%7Z@)6J$)6J`0:;$09JP28J@58:08:ZX;:ZTA>+XN@<0R?\(G8)`T
M>K0X@\`V?KA&E]E%C]!"BL4[>:Q`@+=&BL)0G=Q.F-52G]U0D<I7G=9,B;IJ
MK.%II]UNKN/9X>CG[_;8W^7K\O@`7J<#8*D%7J4)8ZD)8:<-:;(,8J<==[X=
M<K8?<[0OA\PUB<PP=Z\W@;Q"E]E"DM)!C<A&D<Q/H-]0G=I3FM-8HMU7G-->
MI=UFJ=ZWP<G#S-/&Q\?,``#(``#)`P/0!07,!07("0G1#0W8$!#2&!C<'1WD
M(2'2(!^D&QNP(2'J+R^O(R.\*"CR-36[*BK'+B[',##A.#C2-#31-C7V0D+\
M1D;E0D+F1D;^4%#[3T_V3D[U4%#^_O[\_/SZ^OKY^?GW]_?V]O;R\O+N[N[G
MY^?DY.3AX>'8V-C6UM;4U-32TM+0T-#.SL[-S<W,S,R[N[N=G9V4E)1_?W__
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````>[B43`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+I)1$%4&--MP4U*`@$8
M!N#W^\D)8B`BH19)!!.M,O)27L*=X+9MJX[2`8($H3;"!!&V<Y-:XWP_'4"?
M!]A!>$2\/$T.5.$6WN:(@<QJ+"((S["1@'!*=^2]?,YU2;2Z?5T*KB]PKK.B
MN[K_[6-P)%^*@NRMZ;V3U%7=^6A;*&ZR:;9>*8M4%/.KJ>)S;B>6NCSK+/BR
M_5Z`</SGD5RN53@C(QK%\,=,5(I#83-W?V!LW%E8"Q7WR$SL\0\BY%9)M@IE
M-P````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W-K
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0W(#$P
M-3$U-#,T,30V(#`R,S`T-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___\H#!+P/$LX2$[<F)^$P,L(M+LTS-/`\/O%,3?Q1
M4O!04=5/4,=-3\I45<QB9,0-%,AT=\RTM;`:(_;"Q=.^O^72T_GFYYL/'9PC
M,[5)6)XJ/(DJ/XI)8ZEZD(]>>'M5=TPS6U]3=E%$;6I<AWAKDWINE(A]H&]D
MB%Y5>F]EBTU%:%1,;T`W8D5";$%+>SY2@86&B`HS<C5;E#15A$9LHCM7@4YQ
MHU=YJVJ)M?;X^^[P\^'CYM36V0$N;3!4@SA?DS9:BT)MI4%GG"Y);$9LGD)D
ME$]XK4QRHU!WJE!UJ%R`KUZ"L6*$LF:'M"%/BB=4B2]BGDYOF5Q^J51QEG67
MP//U]^;HZLC,SZNMKN'DY<;'Q_?R\<QB7\P``,X#`]`%!<P%!<T)"=8-#<P0
M$-(8&-@;&N$='=0@']`D(<TA(:<;&[`A(>XO+[(C([PH*/(U-=LP,+\J*L<N
M+M(U,LHP,.$X.-4V-=(T-/I"0MT^//Q&1MX_/^5"0OQ*2NI&1O]/3_Y04/9.
M3OE04.M14,Q)1\R_O_[^_OS\_/KZ^OGY^?;V]O+R\N[N[N3DY.'AX=C8V-;6
MUM+2TM#0T,[.SLS,S+N[NYV=G924E']_?____P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````!RX]DT````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````P$E$050(UV-@P`)FS9H1P]@S8?*T:5,F]O=V=H"$9DZ/E1`7
M$VZ?.FE"7Q=C-U#(*"I:M)67/Y4OTL[6QCH\`BCD&AHF7RT@E"T5Z.CIXQ<2
M#!0RM[)4*&V+RY(),#'SMG`W!0KY^[HH,TO*"LH%.7MXN3DY`(4T-%64].R-
M#115U=2UM71U@$(\12Q,(OJ&TISUW%RU'.RL0*'RM*3XQ'2VPIJFYKK*DH)<
MH%!F<GQ"2D9>56-+0T59<7X.-N\``.&N,5K$\W''`````$E%3D2N0F""````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O<VPN<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(P-#`@,3`U,34T,S0Q-#8@,#(S,#,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____U=35Q\;'
MR<K-^_S^^?K\ZNOMU-77RLO-R<K,OK_!Q\G+]_G[\_7WYNCJV=O=S]'3`%F=
M!5VA!5R>#6>I$&>J&&FG'W&M(7:W&UJ()W"G(5^/*7&G+76L*&B:-8?&+G&D
M,'6H.(*[-'FN.8"W-GFM1I;20HF_3Y[84)S63I?/2I#$0G>>4(Z\2H"H7:#2
M48BR79;";*S=:Z?3<:_=`%R?`UZ@"6&A'76U(F23+X;$*FV=-GZQ0I711I#%
M4)S3;JG4Z.KKUMC9U-75HJ2AVMW8;J!!?[1/?K%0B+=>C;EE.'4`(TD`.W<#
M/WD)1(`-2H`72G\7-5P14XT=48<?4H<?/V894H4B9)TO7Y,M:Z(U=:Q";Z(_
M9I4Z6($R8XP[6GXX@+%1@ZY9C;M@A*];CKMCC+)HFL)T.W8`)4H`0'L%/WD%
M2H003H086I(A.5H8:9HX>[!&@[50A;-7E<!JQ<C"^?OW[.[JS]'-RLS'R<O&
MQ<?"^/KU]_GT[O#KX>/>UMC3U-;1[.WIY^?F^/?W_O[^_/S\^OKZ^?GY]O;V
M\O+R[N[NZNKJY>7EY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````IU%20````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"Y241!5!C3;<$]3@)1
M%`;0[_Z\&=`1H4`+HXEA"VY`W8T)G14E#:%P-ZZ#QFAI#,1&I##1:-[,_9X+
MT'.`/P0WV/7')8*AJN_'<N?85,WV+08Y5#W9D\`Q^:A.VS:;)K>D9P6.QPLV
MS)*]QT+)*PB,R\H<$>RZXIZFBODBWQO($C$SNTT`JJM>O_'1\'"0#NKKO7T(
M+G<_W[2Z=M/"0CXXUI]!L;:M3:(+!AQ?YY3GB=KVJ/#UA"_XQR\T9$U]F9V9
MU0````!)14Y$KD)@@@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T
M8RYP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-2`Q
M,#4Q-30S-#$T-B`P,C,P,S0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___^\4E36=G?6>WVP@8+JK*V<453=<W?6>'QP*"VG
M/4/"8F>N76+:?8*?,SO&H:2XD)6VA8UE0$=G14RE>8/*K;:38G.-5VJ;>8B-
M8W;"GZ_-L<%A5V&PJ+=[=8:WLLN+AZXW.6Q05(`1'5HN.G(S/7-R?:E46G0`
M$U@.'UYK>*@''6`A-WHR0WQ-8:%>;Z,*(F0-)642*&44*VX6+6L8+W`=-74A
M-W4O1H8I/'4N070M/W(T1W\P0W8T1WPU2'T_4HA'7)="58Q19:!'6(=5::!!
M3WE3999-7(9>;98`&EP`&UP`&EL!'%T!&EP#'%X#'5X%'V`%'U\'(6(((V0)
M)&4)(F$*)&8-)V<0*FH2*V@4+FX9,G(8,&P=-G4A.GD?-W$;+5HF/WTG/7<K
M1((B-60A,V$O1X8O2(8F.6@H.VLR284U38HP1GTJ/6TK/F\Z4HXP0W4^5I(X
M3H0V2GU"695"6I5&7IE&7IA*89M&6Y`]3WQ(79)%68Q)7I-09Y]/99Y/9IY.
M9)I19YY099Q09IQ-8I9099ED=ZE6;IN,A6&OJ(:IF56^JV;HR67@Q&N*@VSN
MOUG,KF?&KWZZIWSJN5[*FUV*6%C<H:#___\`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````YS5,;`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```+Y)1$%4"-=C8,`"1&0U>!6DQ;IT?(.B$G(K&X!"PC-8^=AF
M"HEK!42:9Y0UM0&%N-A9.)B9N/E5(F)SG-Q:ZH%"\@(RG'*"4FIA)@Z3)TSQ
M<`0*B2JJ\RA;24J8ZKI.FS35TQXHI&U0IV2L&:IJ8=G>/[VOQ@XHU%F;8N3O
M9VB66JS?T]NM5P`4ZLB+#O0)B4DNK'+QFNANDP44*HD+]@:YJ**AV=G6.CL=
M*)08[A,8&9]9WMA:75J4GY:$S3L`E44P],R#A@0`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W-O+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#,V(#$P-3$U-#,T,30V(#`R,S`T-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___\W2UR=M
MJRINJRUPK"YPJR]QK#%ULC!RK3!QK#)TKS-TKC1TK35TK3AWKSI[M2=1=SU^
MN#UZL4.$OBY9?T)^M$F(P4V,Q4B#N#IGD3=BB$Z(O%:4S$^(O$N"LT!OF4-R
MG%J8T%>4RC]JDDEYI&"?UUZ<TTM[IU^<TU>/P4U^JD^`K&6BV%&"KEV4QE>+
MN5.$L6BEW%Z5QEF-NUB+N6BDVFNGW6^KXEZ2P&ZJWV^JWV:<S&.7Q5F'L%J'
ML'6NXFZDU&VBTFN@SW:OXW>OXG.JVW&GUW>OX7:LWG:MWG:LW6:4OG2HUWJN
MW&>2N7NNW'FHTHFZYH:UX(N[YW2:O)7!Z9.[WX:GQ9V_WIBNPJW"U;/(V[G.
MX2=MJBMOJQQ&:S)SK#-TK3E]N3=XL4B*Q$-^LD^0R4B#MT>`LD=WH5:/P%*%
ML4AUG%:)ME2'LU%^I6:<RW*MX7&LX&:<RG.NXFJ@SW6OXG:PXV:8Q'>PXG:O
MX'>OX'2IUWNRXH"SX("TX(:XY'^@O(FHP[?3Z\+(S>'AX=;6UO___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$"LC,D````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````MTE$050(UV-@P`(2
M$J3M0@*,Q1+9N(4D-*VK0$*B!<$--AE)\9P"XDKF%5Y`(<'<P$8G&9Y,>0X1
M63.'&D>@D(I/D*]66EQ3<[*R;I&'NRU0R#[$3U_,/ZJ5*2:\V-6MT``H%%QO
M(\G+$MK>%FE4[EUFD@,4:G22XV=GCHB.;;&H=K3,UP8*U68+<[&F5*:KA=6Y
MV^;I9`&%("Y*5;<J=2LQU5-5``IE\+&!7>3BZ6QBJ*$HA<T[`,R@*5O\"I0C
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M=&<N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,C4@
M,3`U,34T,S0Q-#8@,#(S,#,V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____S`<+SQ88BQ,4TB,EV"DJW3(SYT5&QSP^X5!2
M]EM<]E]@^G-T['!Q_X2&`&T``&L``V\#!7@%!6\%"7$)#7\-#7@-$'D0&'\8
M'8@='84='X$?(8@A&V8;(G`C+Y@O+Y4O-9PU*GDJ-9@U,(4P,((P-HTV0J="
M0J1"1J9&1J!&3[!/1IU&3ZU/4*U04*Q04*I0$7T0(XLA-8LT-HLU2*I&0YM"
M4:]03ZE.7GHZ-U4$;:@,=:X0@KD@DL@RJMQ2J-A3:J,#-E(";*4&HM5%=:8#
M>:H(=Z@)@[03@[`;D<`D<Y8C?:$JH<\XAZLPFL,[C[4WKMM)G\=$M-Y3KM=0
MH\L=E;H%I<<9L]<PE[(OH+PUPN1"J\D^R^Q1OMU-RNE5F[P,L]0JP^(^M=!"
MSNQ.QN%0S^Q5I;<.Q\P(QLP*S-$.RL\9V-TU[?%6S,P(S<T)U-01V]L;WMX?
MZ.@MZ^LRN;DKQ,0R]?5`^/A$S\\YX.!$_OY0__]3[NY/\O)2_?U7^_M7E(LC
MI8L(P9X(OYT(PJ$3S:\MXL9-]-EISJ04?P``?P,#S`<'S0X.?PH*U"(BIR$A
ME"DIYT1#G2XNQD%!^E]?_VMK^&IJU')R]Y>7LGEXNX:%\;*R_]W=_>GIZ>GI
M____````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````"-74^`````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```"N241!5!C3;<&Q30-!$`70F=E_Z_6)D(R`"I`#5T!&/]A=
M@`CI@@)(:,"!B0F0D)"<64Y`Q][\3P'PGMD?;G=:>FQ6[ST+AD4=7F&E--[F
MS7.-R;UV-]CV$7*VM7L$@'R!W9.:<CJ,WZ-'B.:VK,F>U_M+/YZ',W>P!V92
M3^50VQ?Z3(.=)$E7%Z5$B-0;[%.B8CP#H%DI@WW\D!Y1$$Z2,MANZC&@MJ',
M[92S[!^_4M14_##5CND`````245.1*Y"8((`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]S<BYP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,38R-B`Q,#4Q-30S-#$T-B`P,C,P-38`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@````D````."`,```#*2L::```#`%!,5$4``/__________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M__________________________________________________]S/I7:````
M`G123E/_`.6W,$H````!8DM'1/^E!_+%````"7!(67,```!(````2`!&R6L^
M````(4E$05085V-D``)&.`$F(2P$#6(R(=BD`B2]")/1;`,3``60`!-WOR^^
M`````$E%3D2N0F""````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T:"YP;F<`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`S-R`Q,#4Q-30S-#$T-B`P,C,P
M-#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#_
M__\U**=)/+M-0JUF6\9_=-Z*@.&'?=QX<+F!>KZGH..&@+:=E]"MI^*OJ>(E
M%Z0D%Z,M'ZHL'Z0M(*4N(:<N(:4N(J4P(Z<P)*@P)*4S)JHZ+;8Z+:\[+[$_
M,K4[+ZM`-:Y,/\1&.K1+/[Y00\-(/;)%/*0^-HY:3LI>4M)52KM=4LQ52[EB
M5M%63+122:U=4L!93[9L8-MD6<MK8-=F6\QN8MEA5\%N8]EQ9MQE6\594*QJ
M8,IV:]UR9]5P9=)V:]QV:]AE7+ES:=)Y;]:`=]R(?N)X<;E]=KZ(@<B7D-9\
M=ZR5C\R.B<&SK>VVL.W0SO+)Q^?9U_G7U?;<VOBHILVEH\AP;X?*R>2AH,>@
MG\:SLMC!P.6RL=/*R>F4E*W.SLG-S<C,S,=_?WSY^?3AX=S6UM&4E)'___OZ
M^O;N[NKGY^/4U-"[N[CW]_1\)!-[(Q/%.1_)/23%/2312"_,3#7=5S^8/BWK
M:5+;9U+V>6+'8U#(95+!8E#Y@6O(9U;0;ESP@V_;>VK0=V:D7E+YDX"N:%OI
MC'JZ<63&>FS0@W3UFXKEE8;ZI)3TH9+^_O[\_/SV]O;R\O+EY>7DY.3AX>'8
MV-C2TM+0T-#,S,S'Q\>\O+RPL+#___\`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!!
MMW$9`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+A)1$%4
M&--MSKT.`5$0AN&9V3E[=N.GH1%1*+96:*A<C!MP"V["]2B4"HVH)42$E4BL
MQ<Z9X_0\Y?LU'\`/A!G:.)&7J"(%/&=XL"NOA`5J[(WW`B$E=W'U-WNI\$)8
M"VG397<J2F<Y3NO6'X"@O=+\^1$3&9M:K<J0UI-EL1?#1Y-:U!(A`FK:>^S4
MM`SC^[%MY`1IYS1\C4>#<];;[OI)%GXMB,!KX,.I"''*<!-!)L.$E?JPP1]?
M'K!-P,)IPML`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W5A+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#(R(#$P-3$U-#,T,30V(#`R,S`R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___T"KS$&KS$*KS$2MSD:PT4:OT$6L
MS$BMS4NSU$ZVUDNOSE"XV%*ZVTVPSS1VBUB^WE2TTCM_E%S!X6#%Y&+(Z%JW
MU$2(G6C,ZTJ1IV7`W''3\G36]56<LGK:^&[&X5ZENW'%WW;,YX+@_H'?_&>P
MQX;B_X;A_8#7\HCC_XCB_H;>^7*]U(C@^X+6\8K<]I#A^H?2Z9;E_Y7D_9GG
M_REK?T.MS4.LS&"\V&W0[GW=^G[4[GW2[)3@]T>MPDRQQDNNPU:ZSUFVR67&
MVW?5Z6NZRW/'V8;A]'O,W6NQP(WD]HC<[H[>[I[H^+S#%[[%&;W$'L;-(]'8
M,L;---_F1+[$0<C.1^SR5MK?4MWC6/'W8NSQ8NWS;^SQ=<S&`,W(`<S'`<['
M`\S&`]#*!<S&!='+!\W'"=3."M;/#<[)#=C2$,_)$MO5%-[9&-+-&.';'>3>
M(=3/'^CB)J>B&^OF*]C3)["K(>[H+[*N([FU)MW7+[RW*/+L-;^Z*L3`+<&^
M+,?#+O7O.LK%,,W),>'<.-70-=+--,_*,_CS/OKT0MK6.N#;/OSW1N7@0O[X
M2NKE1O_Z3>[J2>SH2/_Y3_[Y4/+M3/WX4?;Q3OOW4?GS4/'L4/WX9/___P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(/+;:<````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````JTE$0508&6W(L1+!0!``T-W<W>Z12112H-<:
ME=+__X"2`H4Q#$,DN<MMSO6\\@'\0-C`L9STSU<3%%D>T4X#[,O9^]VV`34O
M\8&@X%-,0SXZK^8WYL;3Y(BPF%*XU774UC)K=`<-:QU]-0R89:@4BJ2J8N@E
M#69I!HF@8=N>ZC9:XLI:YUR`#.*E<0,94Q")E]ZGNM8N&*/'.6'7.Y%4]\XK
M8[A@TW5!4OWQ!<=`4$JNB"%U`````$E%3D2N0F""````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=&XN<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-#8@,3`U,34T,S0Q-#8@,#(S
M,#4P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____S,?(P"``P"$`OR$`>!4`PB,#OR,#PR4%PR8%P20%P"4%P2@)RBT-PBP-
MA!\*S"\0S#`0Q#$2QS48QC88C"81U3P=V$$ARCT?E2\9GS$;S40GIS<AJCHC
MXTXOXDXOGS<AL#XFTDLOLT`HYE,UMD(JOD<NNT8MN$0LP4DPJ4`JPTLQUU,X
MUU0XRT\UR4XTQ4PS[%P^RT\V[V!"T%0ZLT@R\61&W%M`UED^\V=*VUQ"OE$[
MOE([]&E-X&!&WV!&Y&1)XF)(]&M/]6U0Z&=,ZVE.\FU1[VM0\6U1Z&M0YVI0
MRUU&[7%7['%7\'=>X'!9]'UD\WQD[WUE[GUE]H)J\=W9P28(Q20)R2L-P2H-
MPBT0TC@=QS@=R3L@WT@KSD,KYE,WUU(X[UY"W%I!\61)XF%(]6I/\FA.Z&5,
M\VI0ZV=.[FE0\VM3]6]5]7]H^JN>R[2POQL!P1P#V#HAR38?TD0OZ5$Z\V90
M\&91QVE;UGQNRWINSW]RRGQPXY.&^:B<XI^6WIR3[+"HU*&:W*BAS9Z7S;*N
M^N3AR'YUU8R#RH9]RHN$\]+.T;:SR[2QYL;#S+>UZ]73U-'1^/CXV]O;____
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M,.*D4`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"_241!
M5`C78V#``MC8I&Q#?75%N%DYA214S5U`0F)F(?XII='AQ9'B"B;.'D`A`>V`
MH+2$NL+VVIAX(SM/1Z"0HD^^=UD-4T_?U/IR*W=72Z"03:A?4NS$SK:NQK",
M+#=K`Z!0L+]%7%1_=TM3<T=>CH.Q%E`HT$F&OZAJ<NND*065CJ8ZFD`A+V5A
M#N:(Z@F]#;F9EH8:2D`A/5$>5B[!DL34BFQK`W456:"0)"\+.Y^X?'*ZA[V^
MEIJ<-#;O``"C^2W*>@37W@````!)14Y$KD)@@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]S>2YP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,38U-2`Q,#4Q-30S-#$T-B`P,C,P-C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!8`
M```-"`,```":>VY1```#`%!,5$4`````_P!"0D*$_X2,_XRE_Z6M_ZV]_[W&
M_\;.SG/.SL[._\[6UM;6_];>``#>WM[G_^?O``#O_^_W``#WQL;W]_?W__?_
M``#_SL[_____________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M____________________________________________________________
M______________________________]F%TE`````"7!(67,```!(````2`!&
MR6L^````4TE$0508TV,0Q`+XF!C$L0!A!A*%)<"`$X4286"0!`(!7A8.,1#%
MS"L$XDM"A"59&3E`%!LC.Y@K"E7-+012+<0!A%#5/%P\_#P@P`^GN;@8:`D`
M>J0.G@+];PP`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G
M<F%P:&EC<R]F;&%G<R]T;RYP;F<`````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3(S-B`Q,#4Q-30S-#$T-B`P,C,P-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````B5!.1PT*&@H````-24A$
M4@```!(````,"`,```!8S!V.```!@%!,5$4```#____'P\2GI*7AWM_&Q\?&
M#@#&#P#&$`#&$0#'$0''$@'&$0'&$@+'$P/&$P/)%07&%07+%P?'&`G-&0K-
M&@K0'`W0'0W/'0W&&PW2(!#)(1+5)!38)QC8*!C-)QC,)AC;+!W>,"'/+A^C
M)AOB-2;A-2;E.BNK+"'H/B^N+B.U,B;7/2^W,RCL0S7L1#6Z-2K3/3"]."S#
M.B[`.2WO2#KO23K(/C'%/##%/3#.033-033*/S/R3#[R33[<1CC00C700C;T
M44+51SKW54;V54;;2S[@3T+X6$KE4T;D4D;Y6TWI5DGI5TGY7$_Y74_B5$CY
M7E#Q6T[M6$SM64SX7U'T75#T7E#V7U'L75#Q:%W1:V-^2T?VO[K=R<?ZY.+&
M#0'&$`/(%PW(&@W))AK/*Q_3,2?(,2:0(QNM,RO<0SB)+2C024#G44BX2T-]
M-"_D8UOX;&3C;&/WAW_TAG[ZD8O\FI/_[.N<6%7^T,[UR<?2MK7LTM'Q[NY_
M?W____]3'TI4`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`+=)1$%4"-=C8,`"ZO(K6,NCLN0%.02DE/1<`H%",1EYL?$!J<(<?.**FD[^
MX4"A[,R"TAK#9!XN$5EU6^\(7Z`0<W19;5Q*(J>0C*J91VBP&U"(J;**I5J2
M#6B0ODM@D+LU4*BDN"@GG9=/#&10F)>C)5"H,#<M*8%;5$[=SCO"Q]G<""@4
MJ2/-#S1(S=0C-,3-QD0;*&2O(,@.<I$KT"`K8UT-H)`RT$420(/\PCP=+`RT
M5+!Y!P"BH25W/GG7=`````!)14Y$KD)@@@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F%P:&EC<R]F;&%G<R]T<"YP;F<`````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`T-"`Q,#4Q-30S-#$T-B`P,C,P-3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````B5!.1PT*&@H`
M```-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^7-SR+?X!Z
M:FU&/4&BGJ"LJJM%0$/5U-5\>GX`.Z4!/*8!.Z4#/:<%0*D%/Z8)0:<*0ZT-
M1J\-1*P02K(84;@83JX=5;LA6K\?5+0K8L8O9LHU:\TX:L,^<]1"=]=&>]E-
M@-Q)>,Y/@=U0@]U0@-A1@MI%;K=<@\@K6*67J<:4I<&9JL:DM="*F*ZRPMW!
MT>O-W/3$TNG,W/2SP=:]O[[V^??EZ.8`=```<@`#=`,%>`4%=@4)=@D(9P@(
M9@@-?0T0?A`8@A@=BAT8<!@ABR$?A!\;:1LB<R,A;B$OFB\H>2@UG#4J?2HN
M@BXPAC`XF#@VD3<TBC1"J4(UAC5&JD9"FT)&H49&GT=/L4]0KU!0KE!.J4X_
M@C]9KEE.E4Y5H%5HNFAHM&ANO6[5V-7Z_/KS]?.MKZWJZ^K3U-,E@20VCC5'
MBT9:HUG9V]C)RLC2CU^Z:SZ.C(M`(!221#!Z85N)+1JVBX(Z-32D54BS>&VI
M=6MO/C=?6%>N4T[-96#0<W!Y%!-/$A):'1W;<7!C6EI#/3V4C8U44%!S;V^/
MBXNTLK*PKZ_^_O[\_/SZ^OKY^?GV]O;R\O+N[N[JZNKEY>7DY.3AX>'8V-C6
MUM;2TM+0T-#.SL[,S,S*RLK___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````U.-:C`````6)+
M1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+U)1$%4&--MP;]*@F$4
M!^#?^?-FHA8$ED/W('1EH0XM@4.;0Q'=2$N7$*232X(N04M#H'R@\7WO><_I
M`NIY@#\(DY/I3?VRK^NL1ZJJ&\;I_KKS$-9D41$1`H,\C+@Q4A%A*2#<LB5_
M-B)B$B=>*-J5'A[OSKRX6:BF!6-ZWWTJ%!ZEC$3&"L(LPJLMI[=A+*^L\SH7
M7'Z\KS\'7_5%X/SX)_66BEW5F*PTMQ,W._MV,`ZY<.+44LK]$L7QCU_>>5+:
MP);=6@````!)14Y$KD)@@@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W5G
M+G!N9P``````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,V(#$P
M-3$U-#,T,30V(#`R,S`T,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,
M'8X```,`4$Q410```/___\><GKV`@\G`R*VGK;:RMKB[OBPP+$Y335)743L_
M.DI.24E-2&5H9`,(`0\3#2DM)S,W,;*SKE153F%B6K"R`&5F`+"R`Z2F`[6W
M!ZVO#;6W$KJ\%'EZ$:^Q'];8,:2F)L?)+\3&+Z^Q+=O>/+F[,\G+/J"A,N+D
M2MO=3.7G4=K=4-;84-K;7MK;9<S,`*.D``0$``("`,W,`<S,`=#0!<S,!=34
M"J6F"<[.#=C8$(N+"M[>&-+2&.3D(;FZ'>OK*]C8)["P(;R\*/+R-<?'+K*R
M*N'A.-+2-/CX/OS\1N7E0O__3>[N2>SL2-760O[^4/;V3OO[4<7&0=O<3^GI
M6?W]9`D)!104$!P<&"4E(1P<&4I*1CL[.#@X-5144%I:5ST].VUM:JRIH[V<
M7]"=9<1F)Z-2(=9N+^Y^.MMY/OB,2NR)3/>04>R+4,]Z1L-'`,1*`\1-"<Q3
M#<E3$M1=&==A'<U@'Z%,&^%K)N5R+ZQ5([A>*L-F,,UM-?*"0N)_1O>,3_&+
M4/F>:+XB#<,N&-1-.<9(->Y=1]A60[Q,.^EC3O%F4>EK5_-\:N%$-=QO9#PC
M(4DS,4\Y-UM$0F!)1VM24&M347=A7WUH9B@+"2@-"UQ"0HIT=/___P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````*8L&-4````!8DM'1`"(!1U(````"7!(67,```!(````
M2`!&R6L^````MTE$0508&66//0X!411&[WWOOH<P1J%0Z"02B4*BM0D+FSU8
M@NBU-B`:C4(D?AHAF#'S[L?4<\I3G.0056":TLBSAD+W0S:B=F%)L]OU%&W"
MY7STNPZV5Z99,^;TF>80)PWK\Y70N-Z]?5L/Y8[<C8&2T$#0`Q*+!+%`2Q6C
MD`8[:(0:JX*8VA"`O,Z7+S:HO5.F\2<K5*QU8A"@X2#4?V>9=^*]YV\(BK^:
MY,K&BC-E"`CKR@[1#[G86)GWV'_^`````$E%3D2N0F""````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M:&5M97,O9W)A<&AI8W,O9FQA9W,O='(N<&YG````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#(P,S(@,3`U,34T,S0Q-#8@,#(S,#0W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(E03D<-"AH*
M````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````____T#4VPSH[
M^KN\\?;VXN?FR```QP``QP$`Q@``?0``?```R`$!QP$!R0,#R`,#Q@0$RP4%
MR@4%R`4%QP4%S`<'R`D)QPD)S@H*T0T-T`T-R0T-B`H*TQ`0UA04RA86V1@8
MV!@8SA@8S1@8D!$1QAD9W!T=VQT=X"$AWR$AT"`?SQ\?FAD9I!L;XB8FR"4E
MY2LKR"<GK"$AZB\OZ2\OKR,CI"$AS"LKMB8FV#`ON"@H[34U[#4UNRHJOBPL
MPRXNP"TMQS`PKBHJ[SHZR3(QQC`PRC(RW3@XT38USC0TRS,S\SX^]D)"]4)"
MU3HZN#(R^$9&]T9&W#\^VS\^XD%!X4)"^4I*YD9&PSL[^DU-Y49&TT%!ZDE)
M^T]/^D]/^U!0^E!0[DQ,\4Y.^%%1]U%1]5!0]%!0]E%1[5!0Z$]/T$E)\E=7
M]5Y>Y5E9^61DRE%1T%14]&5EQU)2\V5E^VIJQE=7]8"`^X>'^(F)Z(.#QW!P
MSWIZW9B8V):6TZ.CR;Z^[>CH____````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````10]`'0````%B
M2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"S241!5`C78V#``KAY
M="-+<SR413B$Y#1M`A.`0CRJ`26YH3KB'`+2ZJ9^\6E`(5GGO,JJ&!D^7DDE
M0Y^HU%B@D'DV2V-=@2"GF+R^2WA*4C!0B+F"M59%5,U=3LLV*#$YS`LH5%3.
M5B/!852H`30H/9K)#2B4GU7?4&P@J0@T*"/6W]4>*)1II5!6;0$Q*,3;T1(H
MY*$BRB4,,\C!VA@HI"W.SB^E;N(;EQ;AZ61GIH?-.P"G_R@Y(G682@````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]T
M="YP;F<`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`U,"`Q
M,#4Q-30S-#$T-B`P,C,P-3$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8
MS!V.```#`%!,5$4```#___]!04(!`@,J+"US=WF+C8X0$Q2QM+5,4U43%QA[
M?X`J+S!065N,E9=X?7YW?7Y57%T]149F;W`O,C*2F)A-4%`Z.SLT-36=GY]M
M;FXV-C63DY*KJJEQ;V["(@#`(0"_(0#"(P/!(P._(P/&)@7#)@7")07`)07!
M*`G*+0W)+0W"+`W.,1#,,1#$,1+1-QC&-AC5/!W;02'+/1_-1"??2BOC3B_B
M3B^?-R&P/2;22R_I5#6X1"SI5SK!23##2C'85#C)3C3L7#[+3S;O8$+S9$;<
M6T#663[S9TK;7$*_43OT:4WD9$GB8DCW;5#T:T_H9TSS;%#K:4[R;5'O:U#Q
M;5'H:U#P=U[T?63P?67V@FJ_'P''(@9]%@3$)`>$'0K'*Q'7/2'(.2"]0BWO
M7$*M13/?7T;+6T;Z<%GK;5?-9U3-9E6G7U/RCGW/A'?#?7#NFXWADH6\>F]Y
M3TC_L*+<GY3.E8OXO+&.;&;LN[+>M*S!&`#()`K+,!C4.!_K43G233KS74;=
M6D7P95#Z?VS;?6_$D8GOO;7>.R:I,"&5D9%S<7%E965>7EY145%.3DY-34U*
M2DI(2$A"0D(^/CXP,#`K*RLG)R<='1T9&1D2$A(-#0T%!04#`P/___\`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#;'83#`````6)+1T0`B`4=2`````EP2%ES````2```
M`$@`1LEK/@```,%)1$%4"-=C8,`"2GAFB4O)%M6IRZOJ&MNX^0.%XBH%>_N8
MV+)KE+6-+%P#0H%""6G5HI-GL,OEU!J8.?N$^0*%+#-:JX1GSV-F;>NT\PP)
M]``*>4=G-;<+,<SEZLYK"@KV<@(*146X)R<6<,Z9*2)9VI+N8@\4BO0SU8F)
M+>>=/G4B1V&C@RU0*-Q:7T4AOKY,8%*_F$Q^BA50R-%00U%-+ZFA@F_"%`GN
MXBZ@D(FF@I*6D7EJ9@>_]#26GEQLW@$`YZ\Q8P-"D1P`````245.1*Y"8((`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+V=R87!H:6-S+V9L86=S+W5K+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U-#,T,30V(#`R,S`T,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410```/___[QB8[IB
M9+ER<^R6F/*ZNZXK,*\O,[$Z/[A'2]9D:.%M<>5S>.!P==F#AJUL;L*2E-RH
MJM*GJ<FIJOG;W/7;W*<H,*<N-J@\0[Y%3:]!2+E&3K%#2K!&2VPK+\!.5<13
M6M%;8M1=9=%=9<Y;8Y-*3]=Q>-UV?=-Q=LI]@>:=H<ZBI>;%Q\BXN9H.&)P1
M')L1&YX3'9P3'9T7(:4;):@?*:,C+)\B*Z8G,;$K-;4O.:@L-<`\1K,Y0L1%
M3LY/6-!47<!/5Z=%3,-26M1<9=%C:]9J<L&@H^[)S./"Q<2GJNK*S9U*5I9<
M9<1ZAG)`2;"8G<VSN.O3V)UC<:AP?I>"A\"KL,"EK+:?I=6[PMK`Q^;,T\:S
MN.S8WGY8<)J`D8]MAK6AL4U/>Z*CM%)5=!TI<$90C"DN2E=@FF1KE:FLO043
M7&AOD*:LR**IQU%@E6-MD(B0KC9'?5QLH6UWF8F3M"`W=B8\>FI[KG6"IA`P
M=$YFG%1LH5%GEG.$J6AWF(Z?Q-/9Y^GL\PTN<@XC3BM#<W6+N'%_G)"2EDUD
MC+B]QD1:?JVXRI^HM\C2XJVQMIJMO]'B\<'+T^3O]^?#PGI24L6,C*V#@\RE
MI<6AH?#.SN_0T-+`P,^^OOSIZ?3CX____P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````(^_JFX````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`+D
MIW5V5&86<7'DYE1G^;/.!PIE!`@LZ"\HY60O+$_49&MN!`JU]B1I3YW<)R&>
M$LJ_8%)[#5`H+#Q.5T=DEH6YL)"/6$QT$%#(6<--QM)8W\C,VM[15=5)&BBD
M[JY@8V)H8&IEZZ"LXB(K"10*CHKP]A"<:2<U6]33*S8R$"A46S=1CSDD6U&I
M:<H<K82N-J!0??=TN?B**FZ>_)+>>2Q^J4"AN4R^R2UI97R\>>G%#1-FJ&'S
M#@"1.3+P$R&;GP````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O
M='8N<&YG````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-3`@
M,3`U,34T,S0Q-#8@,#(S,#4S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````(E03D<-"AH*````#4E(1%(````2````#`@#````
M6,P=C@```P!03%1%````____MWY_Q(F+LIFOH8FBN:B\VL7?74ACEGVBB&J:
MN*G&Q[7;8UEQ?&.EMZS/R+WK;F*T;VF:E(SADHO=9F*41D6V.CNV7VG+7XZX
M9I:]ILSKK<[I<Y^ZE[[6;)^\FLCCDK_8H=#L<*2_>*O&E,CBG,_IIM3LD,7=
M=I^QFLWDI-;MJ=KQCZBT=*.V=:&SC\+6>Z6V=9VME<'3J-GMH,[BK-SQI]?J
MH,[AK=WQ;ZB\;J6Y=:[#<ZS`<*>[<ZF^<*6Y<ZF]<::Z=*J^>:_#<Z>Z?;/'
M>J_#?;+%@+7(>:N^?*_!A+C+B[_3B\#3BK_2B+O.B+O-C\/69XR:DL;9<)>F
M;I6CE\K<FLW@C;O,F\W@HM3FE,'2J=GKKMWOJ]CIK]WNKMOKJ-/B;J>Z<*BZ
M>*_!@;C+@+;(@K/$B;W.A[C(G='CN.+P<:JZB[;#I]CGHM#=K-SJ@:BQ@*6H
MD+>YK]G<LMS?H<C*B[.TBJ^JL-O-JM+%N^37ILW`D+*FO.33EKFGO^;0Q.7$
MQ>C"Q.>_P^6\F[F0J<B=HL"6I,*9P>"PI\.4S>JOT^^PZX5LZ8YXE&19YZV@
MOU`]T650]()LJUQ-WGAF[XIY^+JOPVQ?[(5VNH=_P$P]@3,I<TI*____````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````_`]Q)@````%B2T=$`(@%'4@````)<$A9<P```$@`
M``!(`$;):SX```#!241!5`C78V#``CAX16<*\/!+R*?8N_EJ%?8"A>9-F#U]
MQD1F)CTK]T#5_,8RH-#<J?U3^B;/F:1OXZ-1U=QC"A028F.?Q<W")Z:<;J#6
MTJ1D#!1B%1:9)BC.R:7B%Q5KIEY>`A22D9;3E964RLL,-X^+5^AL`PKE%&39
M)N>FIH5$)R1:M%<8`H62(KT<K)T]@[)UZKL4&XJ,@$(QWD[6CA[^$2:6I;4=
ME9IA0*$,5VL[EX!P[9K6ZNZZXM!@;-X!`)O0,=Y=#YV;`````$E%3D2N0F""
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]V82YP;F<`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q,#4Q-30S-#$T-B`P,C,P,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````B5!.1PT*
M&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4```#___^TFYVX
MKK32T=*JJ:W`P,;0T-3BXN3/TM*RL[.JJZOCY>&$EF>XOJO0U<:7H'^VO*1\
MAUF+EU.?J6YY?6.RMYC&RK'&Q\#&RY_:WKS+SIG3U;?+S+G-S<#8V,O\_/#1
MT<CKZ^'AX=C2TM#N[NW5U=30SY'4RQ_,O`!_=@!_=P#.O@/-O0G6Q@V+@0K,
MO!#AT1V=DAG>SR?2Q27NWR^GG2'AU3C'O#O&NSOZ[D_QYE#]\63X[67,R[[,
MR[_U].C__O/,N`#,N0!_=`#-N@',N0'.N@/,N`/,N0/0O07,N@71O@?-N@G4
MP`K.NPW.O`W8QA#-O`_/O1+/OA+;QQ30OQ/-O1?2P1B4B!'6Q1ODT2'4PQ_4
MQ"#8QR?=S"_HV#.RI2KAT3CATCB[KS+RXD+GUT#GUT'LW4CQXE#4QT;VYU?V
MZ%?ZZU[IVUG][F3_\&CWZF7_\6K_\FJQJ(*=G)OIZ.?2R\>ACX:RJJFPF)CN
MZ^O(Q<7^_O[]_?W\_/SZ^OKY^?GV]O;R\O+JZNKEY>7DY.3@X.#8V-C6UM;0
MT-#.SL[,S,S*RLK'Q\?$Q,2_O[^\O+RYN;FVMK:PL+"GIZ?___\`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")B1;6````
M`6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```,!)1$%4"-=C8,`"
MM%V,+(MSDDWL>[HZVIKK:X%"6I$IA;GI,>%VW9WM90V,C4`A_<2\_(PX?P,Y
M=@D^`7X>5:"0659!9GR(1Y`BFZB0"*^P+%#(HB@[*<+;*4R>@U.P1$Q<!2AD
MFYL6Z^OL'J4L(ZU>P<PZ&2ADDQ$7X.;J9ZPD)5G.5%G*#12RC@_V=/8)37"H
MK:NNJNF?!!0RC_!V]@J,3E6H;6IEZ9LX!2BDH:NIHV=H:N78V*+6.X%K*C;O
M``!(?B_>QXU^(@````!)14Y$KD)@@@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S
M+W1W+G!N9P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,C$S
M(#$P-3$U-#,T,30V(#`R,S`U-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12````$@````P(`P``
M`%C,'8X```&`4$Q410```/___\(!`\,"!,(&",<("<\1$]\='M4U-LE#1M]H
M:JD$":D%"ZL+$+80%;0B)M]@9.KHZ;BMMS,1."L,-#$4.IR/H#PD2B8--JRG
ML8V*D)"$GC0B2E-#9U)%8H)TE"43/C$G/UY/<FYA@')K?$8W7%=*:Q(')1X,
M/8%XD$$X4A0+)AL1+RP>2D`Y3FUBA#(I2`\')"481UE0<#4J54Q#:XV&HQL2
M0O7U],P``,T!`<P!`<X#`\P#`]`%!<P%!=$'!\T)"=0*"M8-#<X-#=@0$,\2
M$ML4%-X8&-(8&.$='>0A(=0@'^@F)J<;&^LK*]@G)[`A(>XO+[(C([DF)MTP
M+[PH*/(U-;\J*L0M+<$L+,<N+O4Z.LHP,,TR,>$X.-4V-=(T-,\S,_@^/OI"
M0MHZ.N`_/OQ&1N5"0OY*2NI&1O]-3>Y)2>Q(2/]/3_Y04/),3/U14?9.3OM1
M4?E04/%04/UD9/___P```````````````````````````````-U*<:<````!
M8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````I$E$05085VW.NPW"
M,!2%X>O'O0XAD4#*#DS`*#`%R[`!:]%"@U"@2>1G;..@='#*K_AU`'[&8">%
M-AW=7GM4U&RJ,X=:]YT9<DH"4;4*@4-8Y:L4*3-"W"JT($&*9H@*)4=LB:(O
M]&;29Q\"D_6:F`F%>G*4$N-L#NG+H=#)W$>3*U)S*!RGDL\/[1(MH1A\H>?H
M)L1OR`878Z&7]<LC:Z=8Z,\^C6U(K:U(5&8`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S
M+V9L86=S+W1Z+G!N9P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#0U(#$P-3$U-#,T,30V(#`R,S`V,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````")4$Y'#0H:"@````U)2$12````$@``
M``P(`P```%C,'8X```,`4$Q410```/___YB(CXI_DW=JA%10CUY;D&IGIFYK
MIF9EJF9EIRTM9#,S:S4U;3DY<CL[=#T]=S\_>4)"?4%!>T1$@$='A$9&@DI*
MB$E)AEM<H%14DF1EK%=7EEM;FF%AHV1DI5)5ID5'B%=9JE%3FU16GF!CKV!C
MKDY/C0E/(5F2;"QJ/VJ<>25C-U6-95"'7A16)"E5,Q(\&R-@,!E$(B%,*DN!
M5D-Q34]^66>;<G&B>VZ>>'*C?7.C?0@Q$#)?.T-Z3CMH1&&4:V*1:VV?=S]V
M1A\@'R9=&5J&3#MI(XRM=5-L$XN<3G-\(!H:&&UJ#'-O#Z>@4(=^('=A!Y%Z
M(@P*`W)8!2TG%*V848EW1G98#55"$)AY*GAA)Z:+1&14*[B<5(-U45@]`DXW
M!54_$*F%-;.43\:G9*R266%:2CPX+UI74#`B"3(E#4D_+QL0`)AY2;:=?!82
M#:.*;*B2>1(."D].33LY.`(``"(A(5!04$]/3T9&1D)"0CX^/CHZ.C4U-2\O
M+RLK*R8F)B$A(1T='1@8&!04%!(2$A`0$`T-#0H*"@D)"0<'!P4%!0,#`P$!
M`?___P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/M\HW(````!8DM'1`"(!1U(````"7!(
M67,```!(````2`!&R6L^````ODE$050(UV-@P`)L;4W,;!SMC33<_),KZJLK
M04+&#E86ICKZ7D$Y+0TU55E`(4,[)V<]+0^_Q)+6QMK2A'2@D(&YI:Z+3VA>
M3UM3749\,1M0R,Q:TSTPJ;RWH[D^(HU961$HI&WA'9S-T-?9DAE;P*$B+@(4
M\@R(*>SO[_*-2V52DU07$P0*A>>V]S'TA$47L:O*28D*\P&%REI[&7JC4EB4
MI.5E)(3X>8!"KMT,(9'YK`J<7++B(@*\W-B\`P#BFBV6Q!N2YP````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=F4N<&YG````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,38@,3`U,34T,S0Q-#8@,#(S
M,#,V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%````
M____PS%"K`$7K@49L@D=LQ0GO18JRR<[HR<VKBX]V3I.N#1$R$!0XTQ>UTU>
MXU)DV5)B$AJ:&R.<,CJY,3>:0TO&353"3E7!6%_2#!69#QB>&"*H'RBJ+36J
M.$.\1E#3-SZD.T2G/T>P3EG0:7#5:&_3#1NG%R6E'2NT'RRK("ZJ*CBT,#VG
M-#^O-D.Q15+,0DW!1E/$4%S74%S15V+27FK6:G3=9G'6"!FA$R*4%B65&BNE
M&RF9'"N;(3"H)#.D,D3$+CZP*32!05##04_`.D>K153`2%6R56/+86_<5F/#
M6VG,6V?$4UZL=H'3(S6H87'9QL@3S,P`SLX#T-`%S,P%S<T)P<$*O[\*UM8-
MV-@0PL,6TM(8X>$=@X(1Y.0AU-0?TM,A[NXO\O(USLXOW^`TX>$X^OI"_/Q&
MY^=![>U&__]/_OY0^?E0M+,[]?55X^10]O97Y.11\?)9^OI>__]J\.]L:V<`
M:&8`UM)EB($P7ULPNK)A/CTT1#(3S```S@,#T`4%S`4%S0D)U@T-V!`0TA@8
MX1T=Y"$AU"`?IQL;L"$A[B\OLB,CO"@H\C4UORHJQRXNRC`PX3@XU38UTC0T
M^D)"_$9&Y4)"ZD9&_T]/_E!0]DY.^5!07EY>____````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MB`BR[`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"G241!
M5!A798_+#L%0%$7W>=Q6@@81<Q%_:.([^#XC(HAG4:U[[L'8VK,UV5G`'X1Y
M9F4>'\_:.`L:=,%PG[3]U31&042%P-C:RN+[S2&U?@0HUF=*=64D?`DL;A"0
MWU;[6)Q>Q7'CF^:V4XQ2[S$8[B+;N-X7YB!,R^Q..7'%TKUVTOU`Z%\U.3.)
ML*?O*L*RC,8J>4LI6C2;,9[V>]-<^"O<_3\'^`"<?%A)LMKIZ@````!)14Y$
MKD)@@@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC
M<R]F;&%G<R]V9RYP;F<`````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C`U,"`Q,#4Q-30S-#$T-B`P,C,P,S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```!(`
M```,"`,```!8S!V.```#`%!,5$4```#____<H**]5%N<45;5<WC6?(&*5UK(
MIJBG-#W<<WS(:&^O8FG7?(/HIZRP@H:H.T=P)R_;?XBZB)#.K[1E0DJH?8=D
M1$RUF:"?:GB=87*<;WZZG;#-M,65>HUE6F*RHK&\LL@O(UB1BK!;5GU`/&]X
M=X@L,&<]0W4G,G`Y17TT1(1"4I1,7)]N>JL`$UP=,GH9*FDO1(TJ.W@^49DX
M2(-18Z1K>:L#&F(*(6T-)&L4*G08+7,A-X`A-70O1(E"59([2GD\2WE>;Z=D
M=JT`&6``&F`!&F$#'6,%'V8'(6<)(F4*(FD*(V@0*7`1*6T8,'`=-GHA.GXA
M.GT;+5XF/X(G/7LK0X4A,V4F.6PH.VXU38\P1H(K/G0U38XJ/7`M0'8N07<P
M1'HZ4I,V2H%"6)I"6II*89]&6Y-%69%)7IA(79=/9:).8YY09:!099U4:*-2
M7'<`&V(`&V$!'6(#'6(%(&<%'V0-)VL0*F\2*VP4+G,?-W4B-6<O2(DP1'DT
M28`X3HA&7IU&7IP_5(M/9J)09Z-09Z)09I\;.6UF<H<K1W9/9HQC>J`V6X%<
MAWZ#C8AFC&UOE'%,BDIEGUELB&5K<VFFSXZ%MF2,P&J!OE5\ME"LS8JLTWZ4
MN&6!C%O___\`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!/WKTQ`````6)+1T0`B`4=2`````EP
M2%ES````2````$@`1LEK/@```,%)1$%4"-=C8,`"Q.4+>11E1'I]73W]@J*;
MVX!"HNS\0GQ,PI+J%A4&]JFM'4`A018V+E9F`4XER\[)4_K-LH!":ARRO`H2
MTAK^UMVSYT[2;0$*B2F;<ZO8R4EIVO;-F#-1IP$HI.><J6JH7Z9E;-0S<_I4
MTWJ@D$MVF)5[B8]-N,F$>;/F.\4"A?)CJDJ+O*I#D],+NJ8Y)D0"A1H#RMW*
M*X/CFMIS';03HR*`0C7>Q1X5@75I.7D9*4GQM2'8O`,`%C$RGX,2GRP`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+W5S+G!N9P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#,U(#$P-3$U-#,T,30V(#`R
M,S`U-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q410``
M`/___\%A8\9G:,5K;<]R=-R!@].!@K!L;>J1D\9]?M:,C?.@H?.CI,--4KY:
M7L!B9:YA9.Z*C=%Z?M:!A.B:G+I)4+M25[U46;916,9=8L%@9=)L<:)77.!\
M@;EJ;NZ3F.:.D\)S>;=H<+V"B-*GKEQ3J2<>A#$HBEU6JF)=G"8B8TM&GW=R
MP8N&S1T:6#8RE5-/F61AMV]LOH!]S8%^R8F&T!035QH86"`?:3(P=#8U?4I)
MIT9%D%M:IVQKP7-RO7]^SST]AG%RR&9GHW%ZN*6LWZBOX&!KKHR5R\MH8LQH
M8\QN:-:`>^N;EL>#@?NPK<,S,\4V-L@[.LT_/]A.3LE-3,M14>9?7]5=7?)P
M<,]B8N)M;?=[>_)Z>MAP<.]_?\UO;^:`@-MZ>OB,C.V)B=9[>\MV=?B0D,-R
M<<YY>?*0D-!]?>.+B_>:F?*7E[MU==V,C+MW=\>`?_";F]2+BL6"@NJ=G/BF
MILR)B<6%A,.#@^F=G>B=G<R+B_2GI\2'ALR-C?6JJM:5E=^<G/BPL.^JJM>;
MFN.DI,R5E,>1D<:1D:!U=<J5E:Q_?_&SL^6JJM"<F\22DKB)B=.>GLV<F_*Y
MN/B]O>BQL?6]O.*OKM^LK/;`P/&\O.R[N_?(Q_K+R____P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"D`Y7$````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````MDE$
M0508TV7/O7'"0!`&T&]_[E:')`:&,23.';H75T`!!`2,(U?C4IRZ"@\1D1G0
M2&#I]EP`KX,'/""\)CXWPVUW)S83HJVB(JG;\^G+B4E8"(INX_??N)Y>9!:L
MXO*I6$P24G^Q'Q95S0Y%+W6?2[L,(=9"_@?%NLBS3-^=2AK(<X$B>1&WMV"F
MYC<O`#Y,%RPAIJ9]JF?["H15-7%AYFY.UWF^-$?%^S`6BRE&RF.FT0^/'_P#
MH0,\OO_$$'@`````245.1*Y"8((`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A<&AI
M8W,O9FQA9W,O=FDN<&YG````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(P-3`@,3`U,34T,S0Q-#8@,#(S,#0P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````(E03D<-"AH*````#4E(1%(````2
M````#`@#````6,P=C@```P!03%1%````____QTQ/OF-FQE1>7BD^;CA7:#!5
M>#YIS\[/X^/DX.#AQL;'%")P`15;!QUG!1]EV.#JHKK4TMKCEL+MFZ.K6*'B
M>+GSI<[UH;[8N]KX@I2DN<[BO<?0;*?8=JS;992[:YO#A[WJCZ6WT^;VL\+/
MY.KO996[=ZW1O\S5Q\K+RM'3R\S,LK.SMM+1;X!_I<JWT]O7XNCEY?'ILL*V
MJ]2R)I(S3:91`)<`%I,6'XX@U-74C:^+<:A?J,F=QLS$FKN"B[1LI\!TOLR:
MX^G2J:Z6D*@LGZX]MKV'YN^)X>:4[?&MEYX3GZ4NYNU&O,$_K+(]]OB\Q,:7
MPL0`A(81U-DU\/10Z^U-ZNQ/O<!`P\9.JZQ&U]A:Z^UDY>AD='4ZXN-UZNU\
MW^!WZ^R*U-:$\O2<Q\B`Y^F7UM>1\/&Q[_#!L[0%Y.4KT-$O]?5`[N\^\O%,
MX^1(W=U>P<&&>GIDX>'#]?7:UM;)\?'ISL['\?'MG)R9W=W<]?)<J*=S>GE4
MOJ\JO;%!L:A=[NWCYM6-TM'-OII$BXJ)U*B!L5X9TF!/RE93]O;V\?'QX>'A
MV-C8UM;6U-34TM+2T-#0S\_/SL[.S<W-S,S,RLK*Q\?'Q,3$O[^_O+R\N;FY
ML+"PIZ>G____````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````P`S?0P````%B2T=$`(@%'4@````)
M<$A9<P```$@```!(`$;):SX```#!241!5`C78V#``NI+JGD8>[B#BG4F]W-5
ME04"A>)#HM,S2R=&!E>69R3%120"A=KK8F(+HT1]?5P]<O+#DYN!0M)"+D6Y
M`0)\_+SZ>05>:I)`(04)4UO_;%9V-HZF,`,1846@D)*4G95-6B=3=U>+L9B<
MK#I02$70WM+,O8&9I:-63UY32QDHU%O#:6[AEM+8YNGMI#UEUER@4-^DZ2:.
M#LZA?@GB&JTSY\P#"EE/FSYU@J%15FJ%C.J,V;KSL7D'`/OV,D@/-2*$````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]V;BYP;F<`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T,R`Q,#4Q-30S-#$T-B`P
M,C,P-#<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,5$4`
M``#____0-3;#.COZ9VC0U@W9WAC;X!WEZRO*QP73SQ#IW"_(K0/6N13YWDK&
MIP#?P"'LR#7'G`7,H0?SPC['@P#.<@K(8P'B?";'2@'U@D+WAT;O=SK'-@#-
M2AC?42'Q>$[Z<5#3,!#X;%',&P?'$0#(%PG8-R_O1#K*&A+6&13B+";'``#&
M``!]``!\``#(`0''`0'(`P/&`P/&!P/+!07*!07(!07'!07("0G'"@G."@K0
M#0W)#0V("@K3$!#*$A+8&!C.&!C-&!B0$1'<'1W;'1W@(2'0(!_/'Q_/("":
M&1FC&QO3)R?E*RNL(2'I+R^N(R.D(2&U)B;8,"^X*"CM-37L-36Z*BJ]+"S#
M+B[`+2VN*BK),C'&,##=.#C.-#3+,S/S/C[0-C7U0D+5.CJX,C+X1D;W1D;B
M04#;/S[B04'A0D+Y2DK#.SOZ34WE1D;J24GH2$CZ3T_Z4$_Z4%#N3$SQ3D[X
M45'W45'T4%#V45'M4%#01D;R5U?Q5U?U7E[E65GY9&3X9&3T967S967[:FK_
M__\`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``">2[G.`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@```+Q)
M1$%4"-=C8,`"]/2]\]KJXIW,=4SMW</22X%"^BYIK0W9GFJJ1C:N`2G%54`A
MNYC&YB)?6TEQ:T>_I/S*0J!04"U+C;JFB:BPEK9&;D59%E"(N:T^7DZ(GY-+
M0%"ZM#PG`2C4TI#I927+P\K.+5525<`4!Q1J`AID:"#&QB&27UV8&AL)%*H)
M<3#64>&5D.%3+LM*C`X&"L4[6^B:*<F'9R@JY"1$A?H#A3PL=8QLW$`N*DB.
MBPCTP>8=`)9$+7":)4+B`````$E%3D2N0F""````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R87!H
M:6-S+V9L86=S+W5Y+G!N9P``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`R,#4P(#$P-3$U-#,T,30V(#`R,S`U-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````")4$Y'#0H:"@````U)2$12````
M$@````P(`P```%C,'8X```,`4$Q410```/___^3H\]#1U(F9P)VMU*R\XK_-
M[Y:<J\K2Y<3+W'F.O(67OY6IU(^AR7%_GH^>O[K,\Z*RU+?([;G*[YRIQ<+1
M]*"MR9ZJQ:>RS+?"V\71ZZRVS;G$W-7@^:BQQ=3>]<'*WL#)W:NRP;6\S-OC
M]=[F^':-NW>.O'Z5PGR2OGZ4P'V2O("5OX><R(NAS8.7P8:9P8ZBRX^BR9RP
MV9"BR'J*J:2XXJF^Z(24M)>IS*R_YY:GRK3(\*B[X+/&[;C+\:J[W[K,\++#
MYKW.\9NHPZFVT:*NQ[;#W:NWT*:PQ-'=]JJTR,?2Z=?B^+2]T+"YR]#:[\_8
MZJ&HMM??[[>]R<'%S>?K\\3'S=37W>[Q]_S]__CY^XVBRIFPVH*4M8N=OZ>Z
MWK/'[:^YS,?/WKK`R[S!RMC=YLG-U-38W^[R^>SP]\+'S[W"RLS1V=G>YNOP
M^,'$R:^SN<K.U-#4VO/W_>?K\>;J\,/)T<#%S/#U_.'F[?#U^[F]PM_CZ,C*
MS/3V^.?IZ]K<WLK,SLG+S>SM[M?8V-W6NOKTV7]U5O_UU<:_J8M]5G]U6*>;
M>)V2<O;HP.OAQN'8OJ^*+I)S)[B4.?S4<-*P7OG2>._/A/;8D>*W7<?&Q-+2
MTG]_?____P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````)N<6EP````!8DM'1`"(!1U(````
M"7!(67,```!(````2`!&R6L^````P4E$050(UV-@P`+F]?9W,S))24J(BKMY
M2'O+`84ZITR=U<%IRL)CR,?*)B+&#A3JF3Q[QL2VYOH6YJ;&ANB85J!0W_1I
M,]MEN'4,C$RL'9R<A8!"<[HF3)H;ZNKN*>NKX!>HF`P4RBY(KTA-J\S(K,XJ
MC:HK+@0*N23&:JEK:.K'6=@FV5DEQ`.%RDK"<G-S\O+#JVK*(R-JBX!"7`'R
M7C[^2D&J:B$I*LK!'$`A8UTM;3U><WM!84<;`4LS?FS>`0#O8S&IIS^),P``
M``!)14Y$KD)@@@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T:&5M97,O9W)A<&AI8W,O9FQA9W,O=W,N<&YG````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P,3<@,3`U,34T,S0Q-#8@
M,#(S,#4V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````(E03D<-"AH*````#4E(1%(````2````#`@#````6,P=C@```P!03%1%
M````____VAT>T#4VMP`.N`$/N`43O`<5O0T=Q1`>T4%.YEYJYF5QLP`1M`,4
MLPD9N2`O&06Q#`&Y#P6[$PFZ(AC!)1O!0CJ[85GG<FKQ9EW2"@"]"0&\>WKR
M``!]``!\`P/,#0W-"@J('Q_3'!R:*2G3(2&G.#CA+2V01D;35E;H2DJX9&3X
M1TBN:&K]:6GU:6GS?7W[<W/E=W?B?'W#$A7.043;B(KPRP``QP``Q@``S0$!
MRP$!S`,#R`,#Q@,#RP4%R@4%QP4%S`<'R`D)TPH*T@H*T`T-S0T-TQ`0RA(2
MV104UA04W1@8V!@8S1@8W!T=VQT=XR$AX"$AWR$AT"`?HQL;XB8FUR<GY2LK
MK"$AZ2\OKB,CM28FV#`ON"@H[34U[#4UNBHJO2PLPRXNP"TM[SHZR3(QQC`P
MW3@XSC0TRS,S\SX^T#8U]4)"U3HZ^$9&]T9&VS\^X4)"^4I*^DU-ZTA(Y49&
MZDE)^D]/^E!0[DQ,\4Y.^%%1]U%1]%!0]E%1[5!0_61D____````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````97%I=`````%B2T=$`(@%'4@````)<$A9<P```$@```!(`$;):SX```"H
M241!5!C3;<P[$H(P%(7A2R3<FX`.-)8NPC6Y!I=@[1JM*!A'D$?(X\8PEGK:
M\\T/\+,,3IFL0Z>?_9F4WM?Z)B!3Z/GH(TM$.B@).>RDM#PSITLU*%<0D'M?
M5G740JH]4;!)]2(*'V@6J,LB&I/4-`SS:M_+FI!T=T[J.CY>8]14-8C&7%Q2
ML1V60*A3R%G/6ZOMC:."OB'K0E+=M.0%X1:RS,'#GWT`9#U.K7;&=WH`````
M245.1*Y"8((`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P
M:&EC<R]F;&%G<R]Y92YP;F<`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C`T-B`Q,#4Q-30S-#$T-B`P,C,P-#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`!(````,"`,```!8S!V.```#`%!,5$4```#____5U-7'QL<B(R/4U=7!PL(?
M(!]]?GV"@X(V-C5M;6SGY^;-S<S?UM//Q,'3S,K,P+W"(0!Y%`#&)07#)07/
M,!#!+0_*-AC#-AK;02&7+AG20B7I4S7.33/?5#C94SCT9$:J1S/`43OM94KW
M;%#N<%?E;%3B:U/Q=5SX@FK@=V+TA&[]\_'\\O#QY^7^]?/QZ.:_'0!Z%`!X
M$@#!(`/!)`G)*0W`+`_(-!>,)!'5.!V%)1/).1_B2B_O7$*S1C+<6$'T:$_O
M:%#U<EGP=%[N>F70Q,++O[W:SLSGV]G<T<_TZ>>FGIWX]_?^_O[]_?W\_/S[
M^_OZ^OKY^?GX^/CV]O;R\O+N[N[L[.SKZ^OJZNKEY>7DY.3AX>'>WM[:VMK8
MV-C6UM;4U-32TM+0T-#.SL[-S<W,S,S*RLI_?W]\?'QO;V]A86%@8&!=75U8
M6%A145%04%!/3T].3DY-34U(2$A&1D9"0D)!04$]/3T[.SLX.#@U-34T-#0P
M,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@0$!`-#0T)"0D%!04#`P/___\`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#BO.<T`````6)+1T0`B`4=2```
M``EP2%ES````2````$@`1LEK/@```+])1$%4"-=C8,`"C(6EE;74%"1$A43$
MI&0558%")E8.;JZ.MF9&IN;6=O9.SD`A&R5M'0TY20MQ2QEY%1=-=:"0KX"!
MOC>_AZ"[IY>/KIXA'U"(F3$L+B4C(S4Q-CS0/RPF!2CD%\S#FIZ1EA07$<P8
M$LV4"10*B$Q,RTA/CH\*90R*2.!E`PIEY99555>6YN=P<&9SYQ44`H5JVKL9
MNCM::LN+2BKJ&IM;@$+L70P]G:T-%<5%Y5SU32QMV+P#`/Q*+2HF'D7T````
M`$E%3D2N0F""````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&AE;65S+V=R87!H:6-S+V9L86=S+WIA+G!N9P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#0V(#$P-3$U-#,T,30V
M(#`R,S`T,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````")4$Y'#0H:"@````U)2$12````$@````P(`P```%C,'8X```,`4$Q4
M10```/___\H3%.%B8]1H:MYP<NN!@OB1DO^<GNZ3E?N=GLUW>O;4U3LZ.[[&
M_K>^\D)>]U!I^F!X^W2&[I2=S[S%_2$WK2@_N"Y&PS1-ST)<X4]L^DYH\H&*
MN8N4Q**LW[.]\ALUI"(^KRI&NS!-QC94T49EYE!O]<#&V]38YWB-@LS9TH6;
MCY*GFIBJGZ[!M;'#N**VJ:FZKW>.?CM90!P['TUA3P`D```C```@```7```3
M``$A`0,F`P,D`P,?`P4J!04D!04C!0<E!PDL"0HM"@TS#1`P$!(P$A$G$1@T
M&!T]'2$^(1\Z'QDM&2=!)R])+S51-31,-#)(,C!%,$9B1D)<0DAD2#9+-D):
M0E!J4$YG3D9<1D]G3U!G4%YV7F5]961Y9+F]N0$=`!(O$1TZ&QP[&#-.+TUH
M24%7.@PK`6EV89:FC9>FCH.2>8N;@7R*<XV;A')_:7N(<KF_M'"!62]&!4!6
M$CU4`"LY`)&@4(N9.'B&#8***IVC&+.Y+ZVR">3E:&]N"K6U)XN*(*ZM.+NZ
M4(R,1FYN5TQ,0",C(8&`2,<``,@#`\L%!<@%!=`-#=,0$,X8&-P='>`A(>DO
M+^TU-?5"0OA&1OI/3_M04/504,>HJ&9E96IJ:F1D9%Y>7O___P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-#1?BL````!8DM'1`"(!1U(````"7!(67,```!(````2`!&R6L^````
MOTE$0508&67/L0X!01"`X9VY67OGB$9)J$1$:'02CR-JG6=0H)-X!YU*IU+*
M*54*(0[=Y7;%W=C3^LMO,I.,$'^!Z'/Y%IWC69*@XR#BD,3@(%OL=B?Q%!%L
M@H37TX^X<JR-1QD@6W(ER>?9[2R;0"G@)P!17-P3HW>NDG8&J5F3F",P8BY'
M)!6DC'81P[=Y!1Y550+$:"Q=C=[K0MW;7I3/43X['X4GXS?\E>.H-Y/)*(AU
MN[0)P2OPK[]O+'P!M@%(A*&WGJT`````245.1*Y"8((`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9W)A
M<&AI8W,O9FQA9W,O>74N<&YG````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(P-#(@,3`U,34T,S0Q-#8@,#(S,#8P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````(E03D<-"AH*````#4E(1%(`
M```2````#`@#````6,P=C@```P!03%1%````____U=35Q\;'W.+RI*R_N\/7
MM;S-U-SOS-/D`"=Z`!A,!"I]!"I\"2Y^##*$#"18'4*2+5&?0&.N06"D3W"X
M2VJM2FFK4'"U4W.X98+`G::[HJO`K;;*B(Z<NL'1U=WNS-/C`"EZ`!E,`RI\
M!2U_!2U]#32%#S2"$#B(&#V($2I?&D"/(4B6'T*+&3-H*4N2+U2A-5JF*T5\
M.%J>0F:P,DV$1FNS.E>/3W&X4'.Y5W:V7GR[6G:P98&\:H?#R=+EL[K(U-75
MY^?FV-;5P+Z]I"D`I2L#IC`)KC4-N40=L$0?BS<;ED`CR%8OH4<JK$\PM58U
MU6="R6=&W')/UW%0JUU%S,G(^O?V]O/R[>KIZ^CGZ>;EHB0`IBD%I"D%L#00
MK#D8O$0AJD`AJD(CDCHAKT8HGD(HRU8UJ$DNN5(TL$TQLE`TOU8XUV=&Q%]"
MQV-%VV]0U&M.H%0^OV9+U718M61,Q7%8WX-GUH!GX(=MUH-JTL[-S<G(S,C'
MR\?&_OKYW=G8U]/3^_CX^/?W_O[^_/S\^OKZ^?GY]O;V\O+R[N[NZNKJY>7E
MY.3DX>'AV-C8UM;6TM+2T-#0SL[.S<W-S,S,RLK*____````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````2Z7.2@````%B2T=$`(@%'4@`
M```)<$A9<P```$@```!(`$;):SX```"[241!5!C3;<$]:D)1$`;0;W[N>XKA
M8;`2M!`+.Y>6SLHJ".)^TL7>K"!@HHB(A1H0,4;4W)F;!9AS@#N$-A[*>;R>
M8Q35$&3"V)3RS#YNZS7S1H474(12/K?&)?%7DU:L#D91O.6']^^B6GQV?RJ'
M,@CBHTP49AYC4@U/C.?AZXO`/9GU17H!A,&T\\O)P\PZ4][5]F/%I;Z])M&L
M+K>6-Y;=L>)X<B>+[D)F]GB$8F%.3*I,[BEYPC_^`/M+4G<4[1MG`````$E%
M3D2N0F""````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R]G<F%P:&EC<R]F;&%G<R]A9BYP;F<`````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`T-R`Q,#4Q-30S-#$T
M-B`P,C,P,38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````B5!.1PT*&@H````-24A$4@```!(````,"`,```!8S!V.```#`%!,
M5$4```#____5U-7'QL<B(R-45574U=6XN;D`6P``.0``.``%8`40:A`12Q$=
M=!T22!(A>2$951DOA"\UBC4XB3DXA#A"E$(R;S)&F48R;#)!BD$Z>CM)ETE0
MGU!/G4]0FU!7HU=3F5-2EU)7GE=;HUM>HUYEIF5JK6IAGF%MK6T?(!^?HY_S
M^//H[>C6V];2U]+T^/3H[.C,T,SV^?996EG0T=`0:`T;;!@[?S<07@4?9A`T
M<1\O:QF]PKHY:A9'<QE-;!)#7@-(8`E#5P`Z.CGGY^;$Q,/DX]*^MI(A(!VO
MG7*VJ(5];4M:0Q5\937"HF&)=U*YI'L[.34R,2^^O+@P)A1-/2%E42R3>$:L
MC%*3>U"WG&RVG6^WH7C4NX[ERYN\IX+'LHSNV;%G7DZ^KI'DU\#EVL7`G%^[
MFF:ZH'9Y:E'9OY3JTJO@R:3*N)K+OJM.24(;%A#BVM!,249245#X]_?^_O[Z
M^OKY^?GV]O;T]/3JZNKEY>7DY.3BXN+AX>'2TM+.SL[-S<W*RLK#P\-/3T](
M2$A"0D(\/#PX.#@V-C8T-#0P,#`O+R\N+BXJ*BHH*"@A(2$='1T;&QL8&!@/
M#P\-#0T,#`P)"0D%!04#`P/___\`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"'E#XU`````6)+1T0`B`4=2`````EP2%ES````2````$@`1LEK/@``
M`,!)1$%4"-=C8,`".#D%I=651<TM.;AY!(0E9(%"7+SB:JI2UD[.CF9\0F)R
M\D`A?DD-324+.RL;!WL1&0451:"0MI&QH;ZWEVV@A[^[@8ZN'E"(F;&ROB$S
M(3^O*#>GK+*F`2A46N[*UA03G9B>&I]44<W4#!2JJFML"4F)C,V(RTZK-75C
M!PJ9N$R:.CW4-]PG((NUK:.K%RC4.64FP\S",+^(J.2"[KX)$X%"6C,89DWS
M#&YO+2D.ZNEGF8S-.P"1LC`[PE*8EP````!)14Y$KD)@@@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VQA
M=F%N9&5R+VEN9F\N<&AP````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,3<V(#$P-3$U-#,T,30U(#`R,C(V-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]T:&5M97,O;&%V86YD97(O:6YF;RYP:'`L=B`Q+C$@,C`P
M-"\Q,"\Q-R`Q.3HS,SHS-B!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA
M;64@/2!?*"),879E;F1E<B(I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]L879A;F1E<B]S8W)E
M96XN8W-S````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$W
M,"`Q,#4Q-30S-#$T-2`P,C(V,#<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S
M+VQA=F%N9&5R+W-C<F5E;BYC<W,L=B`Q+CDN-"XS(#(P,#4O,3`O,3@@,3$Z
M,S0Z,3D@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C
M965E.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z("-F-&4U9C<["GT*:'1M
M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(V8T935F-SL*?0IA('L*
M("`@(&-O;&]R.B`C-S$P9CDV.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C
M-S0R83@R.PI]"F$N=VED9V5T.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@
M("`@8F%C:V=R;W5N9#H@(S<T,F$X,CL*?0HN:&5A9&5R('L*("`@(&)A8VMG
M<F]U;F0Z("-E,6,R93<["B`@("!F;VYT+7-I>F4Z(#$R<'@["GT*82YH96%D
M97(@>PH@("`@8F%C:V=R;W5N9"UI;6%G93H@;F]N93L*("`@(&)A8VMG<F]U
M;F0M8V]L;W(Z('1R86YS<&%R96YT.PI]"BYL:6=H="!["B`@("!C;VQO<CH@
M(S9E-&4W,CL*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-E964["B`@
M("!B86-K9W)O=6YD.B`C93%C,F4W.PI]"BYC;VYT<F]L('L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-E8V-A9C(["GT*+FET96T@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V8V93=F.#L*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SEA-SAA,#L*("`@(&)O<F1E<CH@
M,7!X('-O;&ED(",P,#`["B`@("!P861D:6YG.B`P(#)P>#L*?0HN8G5T=&]N
M.FAO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",V9#!A83`["GT*+G-E
M;&5C=&5D('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C-F$Q8V0["GT*<V5L
M96-T('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-E,&,S934["B`@("!C;VQO
M<CH@(S`P,#L*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O
M;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8T935F-SL*?0HC
M;65N=2!A('L*("`@(&-O;&]R.B`C,#`P.PI]"B-M96YU(&$N8W5R<F5N="![
M"B`@("!B86-K9W)O=6YD.B`C93%C,F4W.PI]"B-M96YU(&@Q('L*("`@(&-O
M;&]R.B`C,#`P.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)0
M86YE;"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C965E.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&AE;65S+VMO;&%B+V=R87!H:6-S````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30U(#`R,38S,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:V]L86(O:6YF;RYP:'``````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,S4@,3`U
M,34T,S0Q-#4@,#(Q-34W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!+;VQA8B!T:&5M92!B>2!3='5A
M<G0@0FEN9V4@/',N8FEN9V5`8V]D969U<VEO;BYC;RYZ83X*("H@1&5R:79E
M9"!F<F]M('1H92`G3&EG:'0@0FQU92<@=&AE;64N"B`J"B`J("1(;W)D93H@
M:&]R9&4O=&AE;65S+VMO;&%B+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@
M,3DZ,S,Z,S8@;61J=6MI8R!%>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B
M2V]L86(B*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+VMO;&%B+W-C<F5E;BYC<W,`````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#`U(#$P-3$U-#,T,30U(#`R
M,C$P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@2V]L86(@=&AE;64@8GD@4W1U87)T($)I;F=E(#QS:V)I;F=E
M0&=M86EL+F-O;3X*("H@1&5R:79E9"!F<F]M('1H92`G3&EG:'0@0FQU92<@
M=&AE;64N"B`J"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+VMO;&%B+W-C<F5E
M;BYC<W,L=B`Q+C$P+C8N,B`R,#`V+S`S+S$P(#`P.C$R.C4T(&IA;B!%>'`@
M)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(V4U935E-3L*?0IA('L*
M("`@(&-O;&]R.B`C,S,Y.PI]"BYL:6=H="!["B`@("!C;VQO<CH@(S`P,#L*
M?0HC=&AE;65L;V=O('L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z('5R;"@G9W)A
M<&AI8W,O:V]L86)L;V=O+G!N9R<I.PH@("`@8F%C:V=R;W5N9"UP;W-I=&EO
M;CH@8V5N=&5R.PH@("`@8F%C:V=R;W5N9"UR97!E870Z(&YO+7)E<&5A=#L*
M("`@(&AE:6=H=#H@-3!P>#L*("`@('=I9'1H.B`Q,#!P>#L*?0HN:&5A9&5R
M('L*("`@(&)A8VMG<F]U;F0Z("-D9&8["B`@("!B;W)D97(M8F]T=&]M.B`N
M,65M('-O;&ED(",P,&,["GT*+G-M86QL:&5A9&5R('L*("`@(&-O;&]R.B`C
M,#`P.PH@("`@8F%C:V=R;W5N9#H@(V1D9CL*?0HN<VUA;&QH96%D97(@82P@
M+G-M86QL:&5A9&5R(&$Z:&]V97(L(&$N<VUA;&QH96%D97(Z:&]V97(@>PH@
M("`@8V]L;W(Z(",P,#`["GT*+F)U='1O;B!["B`@("!B86-K9W)O=6YD.B`C
M,#!C.PH@("`@8V]L;W(Z("-F9F8["B`@("!F;VYT+7=E:6=H=#H@8F]L9#L*
M("`@("UM;WHM8F]R9&5R+7)A9&EU<SH@-7!X.PI]"@HO*B!-96YU('-T>6QE
M<RX@*B\*(VUE;G4@>PH@("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&)O<F1E
M<BUT;W`Z(#5P>"!S;VQI9"`C,#!C.PH@("`@8F]R9&5R+6)O='1O;3H@,W!X
M('-O;&ED(",X8F8["B`@("!C;VQO<CH@(S`P,#L*?0HC;65N=2!A('L*("`@
M(&-O;&]R.B`C,#`P.PI]"B-M96YU(&$Z:&]V97(@>PH@("`@8F]R9&5R.B!N
M;VYE.PH@("`@<&%D9&EN9SH@,W!X.PH@("`@8F%C:V=R;W5N9#H@(V-C9CL*
M("`@(&-O;&]R.B`C,#!C.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K
M9W)O=6YD.B`C9&1F.PH@("`@8F]R9&5R.B!N;VYE.PH@("`@<&%D9&EN9SH@
M,W!X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"![
M"B`@("!B86-K9W)O=6YD.B!W:&ET93L*("`@(&)O<F1E<BUB;W1T;VTZ("XR
M96T@<V]L:60@(SAB9CL*("`@(&)O<F1E<BUR:6=H=#H@+C)E;2!S;VQI9"`C
M.&)F.PI]"B-S:61E8F%R4&%N96P@82!["B`@("!P861D:6YG+6QE9G0Z(#%P
M>#L*("`@('!A9&1I;F<M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A
M.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9#H@(V-C
M9CL*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@+C)E;3L*
M?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!L:2YA8W1I=F5486(@82P@
M+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&)A8VMG<F]U;F0Z("-D9&8["B`@("!B;W)D97(M8F]T=&]M+6-O
M;&]R.B`C9&1F.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1H96UE<R]K;VQA8B]G<F%P:&EC<R]K;VQA8BYP;F<`````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S$W-R`Q,#4Q-30S-#$T-2`P,C,U,C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````B5!.
M1PT*&@H````-24A$4@```(P````H"`8````L31+&```61DE$051XVNV<>7A<
MU7G&?W>9J]E'THS6T;Y9MH2QP=AF-00,#@%CXA@,*8%2V@0,;8$"80DE)90D
M$"A-:!*:%-)0MZP.D(#!9C&;C5>\R;(E2[:UKZ-9-/N]MW\,'FDT(]L0DT*J
M[WG\//:]=\[YSCGO?;_W^\ZY%G1=U_DS,%75:&\?8M.F@^S<V<VV;1WT]?D9
M&`C0W^\G&E.QVXPHBH3+967:M'SJZPN9,Z>,L\^NQ>6R,F5'-^'+!IBNKA%"
MH2C5U7EHFL[O7MK!'UYMXJVW]M+9.?*9VI1ED05GU7+UU7/YQM)9*(H\A8PO
M.V!T7>?.^U[CB5]_B*;I++UT%K]\[.LLOO17K'UKWW'KIZK2R0^^?R%+OWXB
M@B!,(>3+"ICF_<-<^NU5*=>>?/A"]NSHX*:_?Y$2MY7*<@=Y^29L5@6;34$4
MP>>+XO-%Z>X9I?V`E[Z^(*IV]"%?=.$,GOCY9>1DFZ90\F4#3"`0H7,HP@T/
M;TZY_N!W3J3(%F=_6QMVFY(8D"`@RS(&@P%)DI+LI*HJT6B4@<%1MGT\P-OO
M=K%I2Q^1J#IIOW4U+E8]>PUEI3E32/DR`*:WS\]=]ZTF$(CPW[_Y)@_\KH?F
MOB@`Q7:)!RYS,SS81S0:Q6JU8C*9R,K*0A3%C.%$UW7B\3C!8!"_WT];>Q__
MN7(7K[QV@'`D,W"FU^7Q^Q>OQ>6T3*'EBPH87==9^=QV[OW!&CPC(<I+K:Q:
M>27ND@)V]*F$XS"[4,*L".BZ_IFUAJ[K!(-!MGW<QCT_6,>.W<,9GSOW[')6
M_OI*#`;#%&"^:(#Q^</<\8]O\,)+NS";#%Q]11T7GE>,+(N4E961EY?W^?3K
M"W#7/[W!LZN:,]Y_]($%7'GY:?_OA?`7"C"M[<-<<\.+M+8-TSC=R6TK&G#E
M&E`4A9*2$K*SLX^X8`.#(0X<\N'U1?",1+#;%)RY1NJJ<[#;E:/VKVD:=]SW
M!K]]9D?:O6DU=IY[\NODY^=/`68\1=]R]_OX_`F=$(VJ^$=C6*T*JJIQQKPB
M5EPW,ZV1AW^VE37O=,*$M8S'-$Q&B:<>/P^7\\C9QL:M75SW]R\S/!SBHO/+
MN'9Y)9($>7EYN-WNI(`=;[&8RIIW.GGY]0-T#8:PY1@IKW20XS22G6/$[XLR
M-!BBO=5#U!_ES%,*^:MO3L=FFQP\\;C&I=_Z'[;MZ)TP4_#$PZ=QP7FGI/D2
MC:J$PO&TMD1!.&)?1[)-6WM9NZZ3OOX@_D_6XUAL1GTNM]YX4O+?[Z_O9OVF
MGF/ZK:((..S&9&UJQK1<9IV0ARB.+6Q*A:JO/T1G0.7.^\]"4:3#\X1L$'GE
MQ1:LZB@>CX><G+&LX1=/[:8S#(^M7)P"F-%`C-MO>)T;_ZH:]%'"80&CT9C1
MT74?'N3ZVUYE-!CC+Y;5L.PB-Z(H4E%1D=+78?/ZHCS^Y&[6;NCCI#-*6;)B
M+DZ7Z:AZ9=/Z;I:N>(>K+J[@JF5UDQ;Q'OG!(BZX[+]0U53R_6AK/_/FC.!T
M.E.NW_*]#_'$5&2#F+RFQG4&._RL?O:B3P44?R#*37>]C^(TLW!1)6>ZC[T"
MW=L38.TSN_#Y?%BM5D11Y.>_:6+9W\S$8)`(A6*$@O%C:BL<4?GMFD-\]X<;
MN>O&V9Q]NCL=,!NV]C/MY!+\J@%"XVZ$X+T/>KEIB<+0T%!R$9]XNIFWF_U<
M?]M\>OUCCP='8_SHNVNY;K&=O)P@7J^7W-S<S&!9?XB_N7TUT9C.LHO+6':1
M&UF6J:FIP6*Q3`@9.D\^LX_?O'*0A<L:N&79+`1!0`7Z`T<E4RIFNKFIL9A5
M3^]BWX^W</_M)V=\LK8JEPO/K^,/:_>G7._JC^#U>M,`T]X7XO['ST^YUK;/
MPUO__1'[]NVCNKHZ(T.F,Z;&M;>^Q[G+3Z!A5B+T?1J]T+R_C[)BC?;V=F;.
M3$2"@:!&?E6BK4];')@QKYS%5ZG\Z)YUN)Q&&NN=J8#9N'V(@C-JZ?%/?#W!
MT^<EQU&$S68#X-E7VGEYFX]OKIB7`I9P,,83][_-=RZQ,J/6C,/AH+*R$E$4
MTQS:US;,W]V[%E6#!?/SN7QQ*;(L4U=7A\F4RAC]@R&NOV<CYMI"OG7O0D11
M.`:09`;.&9>>P&O/[.*I9YNYYK+ZC$\M7]+`ZG<.I%P;],0)!`(IF9G7%R5N
M-M'M3?W]>Q\-4%^31202R3CV3/;#Q[=3=FHUSJI\>GV?(8QM&>2Z<ZQ8+!8$
M0>!05P#%Y:!G0EN=;1Y&AH(IUXQF`Y737$CR1%\E+OGKN?SPI^_RRQ\O2`7,
MKO91\KYJ2W/6TQ^@HC#1D,UFX_E7#_+8*[TLO6$^?8&Q.!0)QWC^T7>YZ1(S
M#;4F'`X'5555&2=L>"3,]7>M)1R#$K>5ZY:7(8D"U=75:6#9T^KEFN]MX;3E
M)Y-?XF!@](\7;[,7-?#X(V^R\(Q<W,7I0G;>2<58[2;"X[1)7!>(Q^-HFI9D
MC`W;!LFO*:1[PISMV#'$XLLL6*W68\JL-FP;8.V^*$NOKTA;8!W0XMK8$LJ9
M`3C0ZZ<P+SO)S`G?"M((8.4O-W/Q*:EM]/OBO/@4++_C7`Q9J7MINME*?P`Z
M.CK&`!.+:72&Y10`'+:=&_LXO]&*+,N\O\7+`R_TLO#J^?2/CCT;#<=Y\U<?
M<.L2(PTUQB."1=-T[GUD/3U#(21%YMIOE&#*DB@M+<5J38W9>]M\7''/Q\R_
MZ@RP*I^153(SC:.^@E6K]_'MJW+2:BP&6:2N.I==^X:2UYRY1B8FE1]L'<!6
M7I'&,&%O`(<U-RVL9K)@*,ZMCS0Q[^K3TA9WN,O+YA<V46*-(@BPH]?`Y7<N
M3!?K416[%$$42?:Y:><PYH9I*0",1>(X33&^NJ`@J7,.6_%;PWRTH8_JV>Z4
MMB/!&(H$HZ.C8X#9OG<$,2\W(Q6V[QMB]EDF-C=%>.@/!YE[Q3SZQH%%BVML
M?V$3MRXQT%!CQ&ZW3PH6@!=6M[)N4S>2+#.[WDI#C16[W8[+Y4H5M_X85_WC
M=JHNF8]/5_#YCV^*J!3GT=1V@,'!08J*BM+NYV2;D>0Q)#ASTC.>+2VC%,^P
MIS!,9#1*D4-#$#@FP-SSV"YL<Z?CB1M@7#OA0(2V51MY^'H'=JO$D%?CYI52
MQC4:.N2EKCSAG]EL3JSI@3#N66:"XYX?:!]A>F46`#4U-2G:RK6KG>%V`?.$
M]MLV=G+^;'.JZ-VPPX.8[TK1(X>S"[L6H+W;Q/TO"=1>?$H*LVAQC4.O;^;.
MK^DT5ANQV6Q'!(O7'^%G*W<A?9*%+3['A2`(E)24I%'W[8_L0I_5B(^LXPX6
M@`@*$57`[_=G!(S);$CZ"5!5:D:6Y>380F&5UH`!P9_J]U#;".=6&1$$(2V\
M3K2W-O3S<IM$S7GY::&H]:5M_.0O;-BM$FZWF\X1%;E037L.H+/%PT4GFC"9
M3,BR3"BLTAXR($V(&(?V>5@Z+_'<>+`$0W%^]8<>3.?,36D_Z@\1;-[/N7^7
M"'5)P'RTVT>HI#S-F:@G@%./<_?SD/N54^@/26,9E*KA>6\K]U^BTEB5A<UF
M.VI&\._/-1,(J4BR3'E1%I5N(SDY.6D3N[5IA-^U&\@_/8=P@,_%(H-19ILE
M8K%8QOLC_AB2G)@B08`9569,)E,2V+M:?01M.6GZ9:!]A!,696&Q6(XH>#V^
M*#<]WH[Y]#EIK.%KZ>3R61%*"JSDY>516%C(YN?W$,TNS<@PPST^IEVB)-EE
M5ZN/D#4[;3W[N_T\_6:85>N'L5H_'M.OG5&"-=.QA&4(?S(_?1ZDG=MYZ%H[
MLB106%@X!IC-71K#V0((J9MPD;8AVONMV!><1%\`0$TJL>CF'3QP48S&*N68
MP#+BB_#*ND-(AD2W)T]/Z)5,U=-_>>80:E4-?2/JYU:UC!X:H?ZTK(R+&E<U
M.@9"25^KBA4<5BE%8ZW?.4+0FDWW\`0?/7[*"^6CAJ/;_W4OO26UR./G%="C
M,<K[VKCT&U841<'M3FB*S?M##!>;(,.<%(BC6$VF,?W2Y$T`QI/ZK'C23'9F
M<J9!``%\'A6UHQ>ZNEE<'^2:%58L)H&"@@(<#D<",-T#80[L]Z#M?R>M'4G0
MD00![VOOI\M&36/0;SDFL`"\]D$744U(+D)=F1%%&7LKDO085GGU@P'\X?[/
MM<SM,`O,OMJ1L:!XL#M`,*HG?3UGCAV`[.SL,<&[PTO@@_T)^AEG)U>+&&3[
M$0'SRGO]_.>K/2"EC]$@ZMQRBPU)A/+R<B1)0E5UMNSVXMW\3L;VSCXU(=H/
M]_E1DX_`AZV?;6(T#5&`:)T)BUFBM,1-7EY>XN@(P*8]?G1!(E/R5U$LLO1T
MA8>>#Z=7D221'S\?8>XL&W5U1R],O;FI-TGQH@A%3@,.AR--N^P]&,0?(6TA
MCK==>J81Q2!@M]O3[KV]I2_I:ZY=8E:-$;/9G`R=JJJS<6\@,9")+VN5DK)X
M$ZW?$^7ZA_:"G/DH:+5;IJE#8W^?P-8N/^!GQ!_'&]8GG9.&BL3Y'Z,QD<EM
MW#,*0KIO]:42Q@G:?="KTS6DD4P`)1$->.Z]&%45%KX_.R^Y1C*0&+@AL_,-
ME3)+3E/H#=CX[5I/.G4#U_QP/VL?-=-8[3ABO-[?$T+\I!]3EH!B$-+8!6`X
M$$>0/]]SM2Z[P!7G9"%)4@IK'`Y':S;U)WP58/'I%F1)(#\_/SEQ[3UA>D:T
MC'XV5B8V3#,=A]!UG9O^I87!@#[I&/?VPD,OQH`8,";@CC0GC94R9K,9413I
M'8[2WA]%D%-?8ED2^.D*,Q:C,,$G^(\U4?[CC?0]J\>>[^6*<TQ,KRT=!YCF
MT4F=:2B7$$61?[UE.FW]37S8E*Y`O1&X[/LMO/5H(X7.S/M%>SO\")+$X3$8
M%`%1(..D*@;Q<P6,*,!=RQ5L)H&BHJ*T4/K.U@$&O#%D1::J4&)6E8+1:$S9
MWEC?Y,_HHR!`0YF8K+9.M)5O#O+R>N]Q'9_-!&5YXIA^:0X@9)C7JF(!BS&1
MD8[?WM!UG7LK8SSY]L?I.@]X=VLOY6XG9K,9.1+3^/A@9%)ZG%&68`%3EL33
MWYO&63<WT3F8GE6T#^E<^<\M_/Z!Z9B-Z6T-C$23%'^8F:)Q,NJ>VA(3DB*C
M:I_#]CSPMU\3F5<G8K5:,PKNQBH'9\[.9VOS,)>?:400H*RL+`4`'^X9S3AG
ML@0_7P,F4Q!-:"422XWC[^_T33K7G]6FEPLI-9_-+9E]FUDI)*OU\H3[AP8F
MQT`X+N#Q>!*`V7TPS&A,1,A0;K:9H,RE)1TIRE58>7<MY]_5DC81`!M:XZSX
M63N_NKD:24IM;]@?3PK(Y+71Q%G;B5:8JW#FK&S6;3^^Q1=1A!O.AV^<*F`P
M&*BLK$R"H+O'QP,/KN'0(0]+ELSD>U?/8=VF%K*5`"Z7*[F'EASKOE!&EH@#
MK^TX_&Y&,T+V>+-G8[F>*G@G\:W.K1..R\1T!5]P;-Y;NR/<^&\=D_I5D*T3
MC2;&(F]L":;%NN2;7JQCD+04\79*G85'OU/&BI]W9OS-LQM"U#S7Q5V7IQ;B
M9%E,`TS;`,R-1#*V<]]5)9S7W'+<6,9FU+GC:SH+INL8#`9J:VM1%&5,5]R]
MALW;NA/[0(]]1&%)+F?-*^;0H4.4E)2D%N;\<?;VQB?5?9_6C++.W1>K&"<Y
M`=KG$WAX]>1)14-I'$4Q(,LR<55GZX$H9%C3AU^'G[P.B'M2KL=BVA@]3K`R
M)]04Q).,)&]JC4PZ\!DE\8QJ_^IS<]C9$>$7KWLR[[J^Y*>Z:)#E"\:.4[JR
MLQ`-J0[MZH%`8)1,A]CFU5MX\"]+N..IGC\Z!IU:K7'S^1J%#AVSV4Q55159
M65ECM::H1E=4H7!&Q=B&9U>("TRFC.6"#7M#QY4E_G)!C+.GZUBMUHPI_JI-
M400Y<W%1$J"^.)[<Y-S=$68T+B(8TB/&9!4MP9`9C+*H<_.BQ![6X4Q2_J@M
M.KG@+8EA,!C2A*D@"#QX52%[NN.\NR>4G@D`*Y[T4%Z0Q:GUB8Y*\HQ($Q#<
M'X`MK7XJ*K2,Q;,;+W+ALDO<\F0/OM"G2[$%`6:6J'QK?HPY%5JR0.AVN]/Z
M4@PBIRZHI[U_C.UFS2Q"EN6T6`^POB4\*2M_6JMT:BR;$\=@,%!=79VQOY8W
M>A%D;\;?E^1JV$WZF.!M/3Z^.2TZ_W!>F#D5&E:K=0PPMRUQXAWQ,N)-_\QT
M5HF*Q>+(J/856>`W-Q6S\NTNO-[,@]G6=)"9I558+!9JW6;L-H71<&J,>;U9
MY[29P[@+71G;6'Y6#G.K=!Y]J8?5NV5Z?,(1LY_R7(WYE7$6UL>HRM,02+P=
M;K<[8PK?U!%$TW7N7%[)LQ]'&`KIS"F6^,H,X^0A1)%8=)(%O_^/V[,P*SI?
M/S&"08*2DI*,8`$P&T4NF&5"B*>?ZZ@O4!'&1P$!%LVVX@]\>OVG2#H.DTY#
MD<H953',RA@C'\:`H.NZ/C`P@-^?N8.<G)R,QR23-*>J'#AP("E>!4%(`9BB
M*)26EB((`C][K9=WF](W0AK=(G<NK<1@F/S-"(?#='1UTW301TN_B"<HXH\(
M&&4=LZ)39->H<JKD6'0$$ME7;FXN+I<K9?\G6<S4=5[=.L+*]X<P&P3NORR?
M0J?UF+\*\'@\M+>W'Q>6L=OM5%=7'_F`^\``'1T=XP2\F/+WQL;&Y+5@,$AS
M<_-GC^)"(C/.R<G!Y7*E]/4G_6J@8RC*=U=VDNE+U=-JS7Q[83Z*?.33:;%8
M#)_/Q^CH*)%(!%55T74=29)0%`73)_LID]5!`+H],7[]UB!-72%L60(7SXA2
M;`Y@^D2SC-<W4S8!3'_JSTR>?M_#ZIV9V6Q:819_?4XNA=F?SP=CGE&5WW_L
MX^W=?J(JU+HT%E;XR1*C6"P6JJJJDIG3E'U!`!.-ZSSX^T':!C*K?D466'2"
ME0L:+5B-XA_=GZ;K[.^/\=Z^(!^V!(FI8#9HG%,^2I4]@``4%!107%Q\S&=O
MIP#S)S9_6.,G;XS0X9G\DX<3W0HW?L61\DW,L5HXIG%P6&7KP0A;#H;Q!!-"
M6Q9T9CK]S,KS8Y0TC$8CY>7E:<="I^P+!AB`4%3CW]_SL+,W'1`Y9H'[ON;@
ME9=W\L\_6H,@"-QVZU?XYN6SV=X5)18'<Y:`)$`DKC,:T?&&=?I\*@>'XO3X
M5,:=F481-:8Y_)R8Z\-JB"-)$H6%A>3GYT^QRI<%,`#Q>)PU.P99>T!A-#Z6
M4GYUNL+\0I4%ESY--);(OB1)8,TS5[+';^2E79%C:M]AB#+-YF.:W8=14A%%
MD?S\?/+S\Z<^K/^,]G_Z?W/)LLRBV07,+!Y@78N/O3X;0U$3.1:9@WU^<JM+
M4YX_T!<B.\^2ML4PWFQR%+<Q0(W%1UY6"('$CGA^?B$NEVO26L>4?0D`<SCG
M=Q?FL\P9H[>WE[:^/ARZD^IJ)S4G5C$:T3XIE@F<.,W).QT@RQ*2H"$+.@XY
M3*XA3*XA1)XAA,,0^821)!R.7)Q.)S:;;>J_'_MS"$F93%55`H$`=KN=3H_*
MVZU1!.#L&H5\B\KVW?N(J1JRD/ASV"1)2M9@'`['40]@3]F?"6".9",C(X1"
MH21`)$G"8#"0E96%P6"8`LB?P/X7,#6O=?K,HF$`````245.1*Y"8((`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&AE;65S+VMO;&%B+V=R87!H:6-S+V)G+G!N9P``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,C`W(#$P-3$U-#,T,30U(#`R,S`P-P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````")4$Y'#0H:
M"@````U)2$12`````0````,(`@```-V_\M4````&8DM'1`#_`/\`_Z"]IY,`
M```)<$A9<P``"Q(```L2`=+=?OP````'=$E-10?4"1$+'BA-;][6````%$E$
M051XVF.X<N$$$P,#`].]^P\`':`%#LYQM6H`````245.1*Y"8((`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]K;VQA
M8B]G<F%P:&EC<R]K;VQA8FQO9V\N<&YG````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-3<W,B`Q,#4Q-30S-#$T-2`P,C0T,#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````B5!.1PT*&@H````-24A$4@``
M`#<````H"`8```!:6V((````!F)+1T0```````#Y0[M_````"7!(67,```L3
M```+$P$`FIP8````!W1)344'U`L$#QX=`=)&Y```"X=)1$%4>-J]F7N0U-65
MQS^_9[^[IQ_3]$SWO'H>#&"`B20@2I"LJ$%C1!1!"R$F&U=7L]G=,FY88\A&
MU]HJUVRJ3&VM68MD8\BB%1$U0H2HY*&;$-X#\AR8&6:&>0_=/=/=O^[?[[=_
M##2TW0,.S'BJ^I][;]][OK]SSO><<Z]@FJ;)IR"Z;G#R9#\[=[9RX$`G>_:T
MT]T=I[<W04]/'"VCXW99456)0,#)U*E!&AM#S)E3R8TWUA,(.,=]IC#1X#HZ
MAD@F-6IK2S$,D]<W[^?7;Q_BW7>/</KTT!7M*<LB"[]0S^K5G^?N9;-15?G3
M!6>:)M]9MX477_H`PS!9MG0V__6CN[ACZ7^S_=VC$_;QHC5^GO[^$I;=-0M!
M$#X=<(=/#+#TH4UY8^N?6\)'^]MY[%NO$0D[J:GR4!JTX7*JN%PJH@BQF$8L
MIM'9-<S)4V?I[AY!-RZOTNU+IO/B?R['6V*;7'")1)K3_6D>>>XO>>//_LTL
MREQ93K2TX':IHP<*`K(LHR@*DB3EK*[K.IJFT=LWS)Z]O;SWNPYV[NHFK>EC
MGMM0%V#3*VNHK/!./+@SW7'6KMM*(I'FES^[GV=>[^)PMP9`N5OBF>5A!OJZ
MT30-I].)S6;#8K$@BF)1ES)-DVPVR\C("/%XG):3W?S/AF;>W'**5+HXR&D-
MI;SUVH,$_(Z)`6>:)AM>W<=33V]C<"A)586331ON(QR9POYNG506FD(2=E7`
M-,W+QL:ESAD9&6'/WA:>?'H'^P\.%%WW5S=6L>&E^U`4Y>K`Q>(IGOC>._QJ
M<S-VF\+JE0TLN:D<61:IK*RDM+1T4E))+)9@[;^\PRN;#A>=_^$S"[GOWOEY
M'W)<X(Z?'&#-(Z]QO&6`:Z;Y>?QO9Q#P*:BJ2B02H:2DY))6ZNU+<JHMQME8
MFL&A-&Z7BM]GI:'6B]NM7O9\PS!X8MT[_'SC_H*YJ75N7EU_%\%@</S@_KR[
M@Z]_ZPT&!I+<?G,E#ZZH09*@M+24<#B<(X>+)9/1V?;^:=[XS2DZ^I*XO%:J
M:CQX_59*O%;B,8W^OB0GCP^BQ346?"[$U^Z?ALLU-M!LUF#I`__+GOUG/A9@
M\.)S\[GEIL_E=,F!,PP#412+;KCC@U8>?OQMAD<RK+RSFGMN#R.*(M75U7B]
MA4QU-J;QX_4'V?Y_W7SVA@IN6A+%'[!=-KYV?MC)YE\<9-67JUEU3\.8:X^U
M#'#+\E^@Z_EV6;.\FF]^XWK\?O\%<.>-5\RE=GS8QC<>WX*FZ2R[M9R57ZE`
MEF7JZNIP.!P?<QN3]1N/\K,W6UE\SPR:YI:/FTP,PV33R\V$!8T??/O:,=<]
MNO8W_'K[B7QBN;Z4M8]=2S0:':UL<E8MHL31E@'^[JGMZ`8LG!?DWCM&@34T
M-&"SY5NBIR_)PT_^&7M]B`>>6HPH"O0DKH0Z!&Y8^AFV;&SFIZ\<9LWRQJ*K
M5MPY@ZWOG\H;ZQO,DD@D<@PMCT75`T,I'EZ[G50&(F$G7U]1B20*U-;6%@#[
MZ/A9UGQW%_-77$LPXJ%W^.K9L>G6&?SX^=^R^`8?X?)@P?S<SY;C=-M(I;(7
MXM$4R&:S&(:!)$G(Q8`9ALE3SW](5W\2295Y\.X(-HM$144%3F=^=7ZD)<;*
M)_<R;]4-X%2OT%K%+>AIK&;3UJ,\M,I;D,,46:2AUD?ST?[<F-]GY6)^+%I>
M_VKK<7;L[$2299H:G<RH<^)VNPD$`OG$$<^PZGO[B'YE'C%3)1:?V-RFEI=R
MJ.44?7U]E)65%<Q[2^Q(\MD+X+SY+%L`[FP\S0L;FI'443J]8U$`01"(1"(%
M[OOMYYLQ9U]##,N$`P-(HY+6!>+Q>%%P-KN2TQ,@6F%'EN4<ZQ>`^\FKATDD
M=219IJK,0DW8BM?K+8BSW8>&>/VD0O!Z+ZD$DR+I/HTFNT0FDRDZ/Q3/(,GR
M.4*$Z5$[-ILM9X0\<$.Q-&_N:$-21H>OG38:7Q=G_?/R'QO;T*-U=`_ID]:]
M:VU#-,ZW%,V_6=V@O3>9TS5:KN)Q2GF<D`=NRQ\[T`PA]X>&2BNJJF*WV_,V
M'DGIO/W'7N*IGDF]FO#8!9I6>[!:K05SK9T)1C0SI^NB.6X`2DI*BH/[[<XS
M.3.+(I3Y%3P>3T&L'6D=(9X^YPN3*$L76%$5`;?;73#WWJ[NG*X^M\3L.BMV
MNST7/J9I7@`W&-,XT95$//<E;!8!51$*K`8PD,@BR/*D`@NX!58NLB!)4IXU
MSKODMIT]H[H*<,?U#F1)(!@,YADBI^&1]CB")"&?(Q]%%1`%"O(+@*J(DPI.
M%&#M"A673:"LK*R@*']_=R^]9S/(JDPT)#$[JF*U6O'Y?,530>^0EC,S0!;0
MLA2M]NLC-B151C<F'I@`?/,VD;D-(DZGLRB971/UL*`IR.[#`]R[P(H@0&5E
M97XO)P@7P`W$L[G@S(T-C]YM?%Q"/I4%LTO8L6]BDYLHPB,WP]W7"2B*0DU-
M34[ASJX8SSR[C;:V0>Z\<R;?73V''3N/4:(F"`0"N%RNPBO!7#FCB`7@6GKA
M\^ET4476K8IPT^%C$V8]E]7DB=M,%DXS412%^OIZ5%7-D<-C_[R-O^SI!&#_
MC_Y$*.+C"W/+:6MK(Q*)%+1/>98+^:V(2KX+-G=!(C%,$<]@;J.#9[\:X8F?
M=EVU'UY7:_#W-QN$/"9VNYUH-(K%8KF0S#6##DTE-+WZ0K'>D>06FXW:VMJB
MH9-GN8I2*Y*<OZ@G`;N.QZFN+M[(/GI[@(!;XA_6=Q%+CB\M"`+,C.@\,"_#
MG&HC5RR$P^&"LU1%Y+J%C9SLN>!%LV>6(<LR<A%B.^_*N4X\DS7XV@M'&4[E
M^YG7;O+]Y5,(AP)C*MIR>H`?;NYBZT&9KIAP21:L\AG,J\FRN#%#M-1``-QN
M-^%PN&C:.=0^@F&:!+T67MF;IC]I,J=<XDO3K8CB)[AQ/N^C+VPYP^\.Q0K9
M*2SRG64U*(HTYD:I5(KVCDX.M<8XUB,R."(23PM891.[:E+F-HCZ=;P.$X%1
M%O;Y?`0"@;QZ,-=VF29O[QYBPQ_ZL2L"/U@>).1WCJNSS[L@:N_7^*<-IREV
MFSV_WLY#BX.HLGC)#3.9#+%8C.'A8=+I-+JN8YHFDB2AJBHVFPV'PX'#X1A3
MT<[!#"^]V\>ACB0NB\"7IVN4VQ/8SL78Q?$XKK>"E_\PR-8#Q2E^:LC"7R_R
M$2I1)B5Y#P[KO+4WQGL'XV@ZU`<,%E?'L8@:#H>#:#2:8]`K`J=E39Y]JX^6
MWN)MABH+W/H9)[=<X\!I%:\:D&&:G.C)\/NC(WQP;(2,#G;%8%'5,%%W`@&8
M,F4*Y>7E8][.C>LA))XR^/=WAF@?S([YQUEAE4>_Z+EL4!>-SXQ!ZX#.[M8T
MNUI3#(Z,DI@LF,STQYE=&L<J&5BM5JJJJ@JN-JX*'$!2,_C)[P<Y<*90>:]=
M8-UM'MY\XP#_^F_;$`2!Q__QB]Q_;Q/[.C0R6;!;!"0!TEF3X;3)V91)=TRG
MM3]+5TPG>Q$IJZ+!5$^<6;X83B6+)$F$0B&"P>"XK?6)WPJRV2S;]O>Q_93*
M</9"/OG2-)5Y(9V%2U]&RXR69Y(DL&WC?7P4M[*Y.?W)^C5%8ZHKQE1W#*ND
M(XHBP6"08#!8M&`?KURRM)=EF5N;IC"SO)<=QV(<B;GHUVQX'3*MW7%\M15Y
MZT]U)RDI=124<7EEEJP1MB:H<\0HM201&.T\@L$0@4"@:%*>%'#GLWTX%.0>
M?X8S9\[0TMV-Q_136^NG;E:4X?2H?UE5@5E3_;S?#K(L(0D&LF#BD5/XE!0^
M)4FIDL2CI,]96L+C\>'W^W&Y7%?\S'7%;EE,=%TGD4C@=KLY/:CSWG$-`;BQ
M3B7HT-EW\"@9W4`61G_G19*D7([S>#PX'(ZKBJ=)`7<I&1H:(IE,YL!(DH2B
M*%@L%A1%F70P'Y?_![H7<,0^Z$-U`````$E%3D2N0F""````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+V=R87!H:6-S````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,30U(#`R,38S,``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E
M87,O:6YF;RYP:'``````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`Q-S$@,3`U,34T,S0Q-#4@,#(Q-34R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W1H96UE<R]I9&5A<R]I;F9O+G!H<"QV(#$N,2XR+C$@,C`P
M-2\Q,"\Q."`Q,3HS-#HQ."!J86X@17AP("0*("HO"@HD=&AE;65?;F%M92`]
M(%\H(DED96%S(BD["@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+W-C<F5E;BYC
M<W,`````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q-S,R
M(#$P-3$U-#,T,30U(#`R,C$P-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O*BH*("H@261E87,@=&AE;64@8GD@4F]E;"!'
M;&]U9&5M86YS(#QR+F=L;W5D96UA;G-`:2UT;RUI+FYL/@H@*B!"87-E9"!O
M;B!T:&4@261E87,@=&\@26YT97)C;VYN96-T($)6('=E8G-I=&4@*&AT='`Z
M+R]W=W<N:2UT;RUI+FYL*0H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]I
M9&5A<R]S8W)E96XN8W-S+'8@,2XS+C(N,R`R,#`V+S`S+S(T(#$Y.C,S.C0W
M(&-H=6-K($5X<"`D"B`J+PH*8F]D>2!["B`@("!F;VYT+69A;6EL>3H@5F5R
M9&%N82P@1V5N979A+"!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V,Q9&-E9#L*("`@(&)A8VMG<F]U;F0M
M:6UA9V4Z('5R;"AG<F%P:&EC<R]B86-K9W)O=6YD+G!N9RD["B`@("!B86-K
M9W)O=6YD+7!O<VET:6]N.B!B;W1T;VT@<FEG:'0["B`@("!B86-K9W)O=6YD
M+7)E<&5A=#H@;F\M<F5P96%T.PH@("`@8F%C:V=R;W5N9"UA='1A8VAM96YT
M.B!F:7AE9#L*?0H*+G1E>'0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A
M93AE.#L*?0H*82!["B`@("!C;VQO<CH@(S)F-6,Y-SL*?0H*+G-E;&5C=&5D
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B860P93<["GT*+FAE861E<B![
M"B`@("!C;VQO<CH@(V)A9#!E-SL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S
M83DU8V,["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P-3,Y-CL*
M("`@('=H:71E+7-P86-E.B!N;W=R87`["GT*+FAE861E<B!A('L*("`@(&-O
M;&]R.B`C8F%D,&4W.PI]"BYH96%D97(@83IH;W9E<BP@82YH96%D97(Z:&]V
M97(@>PH@("`@8V]L;W(Z(",R9C5C.3<["B`@("!T97AT+61E8V]R871I;VXZ
M(&YO;F4["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,V$Y-6-C.PI]"F$N:&5A
M9&5R('L*("`@(&)O<F1E<BUB;W1T;VTZ(#`["B`@("!B86-K9W)O=6YD+6-O
M;&]R.B!T<F%N<W!A<F5N=#L*?0H*+FAE861E<F)O>"!["B`@("!B;W)D97(M
M;&5F=#H@,7!X('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M<FEG:'0Z(#%P
M>"!S;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(",P,&(Q8C`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X.PI]"@HN
M;&EG:'0@>PH@("`@8V]L;W(Z(",S,S,["GT*+G-M86QL:&5A9&5R('L*("`@
M(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["B`@("!C;VQO<CH@(V)A9#!E
M-SL*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E
M<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PI]"F$N<VUA;&QH96%D97(Z:&]V
M97(@>PH@("`@8V]L;W(Z(",R9C5C.3<["B`@("!B86-K9W)O=6YD+6-O;&]R
M.B`C,V$Y-6-C.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"BYS;6%L
M;"!["B`@("!C;VQO<CH@(S`P,#L*?0HN8V]N=')O;"!["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B`C8F%D,&4W.PH@("`@8F]R9&5R.B!N;VYE.PI]"@HN8V]N
M=')O;"!A('L*("`@(&-O;&]R.B`C,#`P.PI]"BYC;VYT<F]L(&$Z:&]V97(@
M>PH@("`@=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4["B`@("!B86-K9W)O
M=6YD+6-O;&]R.B!T<F%N<W!A<F5N=#L*?0H*+RH@1F]R;2!S='EL97,N("HO
M"FEN<'5T+"!S96QE8W0L('1E>'1A<F5A('L*("`@(&-O;&]R.B`C,#`P.PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(V8S9C-F.3L*("`@(&)O<F1E<CH@,7!X
M('-O;&ED(",P,#4S.38["GT*:6YP=70Z9F]C=7,L('1E>'1A<F5A.F9O8W5S
M('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C,#!B,6(P.PI]"BYB=71T;VXL("YB=71T;VXZ9F]C=7,@>PH@
M("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P,#4S.38["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+6QE9G0Z
M(#%P>"!S;VQI9"`C,#!B,6(P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED
M(",P,&(Q8C`["B`@("`M;6]Z+6)O<F1E<BUR861I=7,Z(#5P>#L*?0HN8G5T
M=&]N.FAO=F5R('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",R9C5C.3<["GT*
M"F$N9FEX960@>PH@("`@8V]L;W(Z(",S,SD["GT*"BYS:6=N871U<F4L("YS
M:6=N871U<F4@82!["B`@("!C;VQO<CH@(SDY.3L*?0H*+RH@365N=2!S='EL
M97,N("HO"B-M96YU('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",R9C5C.3<[
M"B`@("!B;W)D97(M8F]T=&]M.B!N;VYE.PH@("`@8F%C:V=R;W5N9"UR97!E
M870Z(')E<&5A="UX.PH@("`@8F%C:V=R;W5N9"UI;6%G93H@=7)L*&=R87!H
M:6-S+VUE;G5?=&]P+G!N9RD["B`@("!B86-K9W)O=6YD+7!O<VET:6]N.B!B
M;W1T;VT["B`@("!P861D:6YG.B`P<'@["B`@("!C;VQO<CH@(V)A9#!E-SL*
M?0HC;65N=2!A('L*("`@(&-O;&]R.B`C8F%D,&4W.PI]"B-M96YU(&$Z:&]V
M97(@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*?0HC;65N=2!A
M+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S-A.35C8SL*("`@
M(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C86%C.PH@("`@8F]R9&5R+7)I
M9VAT.B`Q<'@@<V]L:60@(V%A8SL*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L
M:60@(S`P,#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C,#`P.PI]"@HO
M*B!3:61E8F%R('-T>6QE<RX@*B\*+G-I9&5B87(@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V,Q9&-E9#L*("`@(&)A8VMG<F]U;F0M:6UA9V4Z(&YO;F4[
M"B`@("!P861D:6YG.B`P<'@["B`@("!M87)G:6XZ(#!P>#L*?0HN<VED96)A
M<B`C;65N=2!["B`@("!H96EG:'0Z(#<Q<'@["B`@("!B86-K9W)O=6YD+6EM
M86=E.B!U<FPH9W)A<&AI8W,O;&5F=%]M96YU7W1O<"YP;F<I.PH@("`@8F%C
M:V=R;W5N9"UP;W-I=&EO;CH@8F]T=&]M(')I9VAT.PH@("`@8F%C:V=R;W5N
M9"UR97!E870Z(&YO+7)E<&5A=#L*("`@(&UA<F=I;BUB;W1T;VTZ(#!P>#L*
M?0HC<VED96)A<E!A;F5L('L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-C864X
M93@["B`@("!B;W)D97(Z(&YO;F4["B`@("!B86-K9W)O=6YD+6EM86=E.B!U
M<FPH9W)A<&AI8W,O;&5F=%]M96YU7V)O='1O;2YP;F<I.PH@("`@8F%C:V=R
M;W5N9"UP;W-I=&EO;CH@8F]T=&]M(')I9VAT.PH@("`@8F%C:V=R;W5N9"UR
M97!E870Z(&YO+7)E<&5A=#L*("`@('!A9&1I;F<M8F]T=&]M.B`R,'!X.PH@
M("`@<&%D9&EN9RUT;W`Z(#!P>#L*?0HC<VED96)A<E!A;F5L(&$@>PH@("`@
M8V]L;W(Z(",R9C5C.3<["B`@("!B;W)D97(Z(&YO;F4["B`@("!P861D:6YG
M.B`P<'@@,7!X(#)P>"`Q<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*
M("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["B`@("!C;VQO<CH@(V)A
M9#!E-SL*("`@('1E>'0M9&5C;W)A=&EO;CH@;F]N93L*("`@(&)O<F1E<CH@
M;F]N93L*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@-G!X
M.PI]"@HO*B!486(@<W1Y;&5S+B`J+PHN=&%B<V5T('L*("`@(&)O<F1E<BUB
M;W1T;VTZ(#%P>"!S;VQI9"`C,#`U,SDV.PI]"BYT86)S970@;&D@82!["B`@
M("!B;W)D97(Z(#%P>"!S;VQI9"`C,#`U,SDV.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED(",P,&(Q8C`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C
M8S%D8V5D.PI]"BYT86)S970@;&D@83IH;W9E<B!["B`@("!C;VQO<CH@(V)A
M9#!E-SL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S83DU8V,["GT*+G1A8G-E
M="!L:2YA8W1I=F5486(@82!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z(",R9C5C.3<["GT*+G1A8G-E="!L:2!A+F%C=&EV951A
M8CIH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",S83DU8V,["GT*"B\J($%L=&5R;F%T:6YG('-T>6QE<RX@*B\*+G)O
M=T5V96XL("YI=&5M,"!["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X
M.PI]"BYR;W=/9&0L("YI=&5M,2!["B`@("!B86-K9W)O=6YD+6-O;&]R.B!T
M<F%N<W!A<F5N=#L*?0H*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@
M=')A;G-P87)E;G0["GT*"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J+PHN
M<')E9G-/=F5R=FEE=R!H,B!["B`@("!F;VYT+7-I>F4Z(#$T<'@["B`@("!F
M;VYT+7=E:6=H=#H@8F]L9#L*?0HN<')E9G-/=F5R=FEE=R!D="!A('L*("`@
M(&)O<F1E<CH@,7!X('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S`P-3,Y-CL*("`@(&)A8VMG<F]U;F0M8V]L;W(Z(",S
M83DU8V,["B`@("!C;VQO<CH@(V)A9#!E-SL*?0H*+G!R969S3W9E<G9I97<@
M9&0@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-A93AE.#L*("`@(&)O<F1E
M<BUL969T.B`Q<'@@<V]L:60@(S`P8C%B,#L*("`@(&)O<F1E<BUR:6=H=#H@
M,7!X('-O;&ED(",P,&(Q8C`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L
M:60@(S`P8C%B,#L*?0H*+G!R969S3W9E<G9I97<@9'0@83IH;W9E<B!["B`@
M8V]L;W(Z(",R9C5C.3<["GT*"BYB;W@@>PH@("`@+6UO>BUB;W)D97(M<F%D
M:75S.B`Q,'!X.PH@("`@8F]R9&5R.B`Q<'@@9&%S:&5D(",P,&(Q8C`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X.PI]"@IT9"YL:6YE9%)O=RP@
M='(N;&EN9612;W<@=&0L('1A8FQE+FQI;F5D4F]W('1D+"!T86)L92YL:6YE
M9%)O=R`N:71E;2P@=&%B;&4N;&EN9612;W<@=&@@>PH@("`@8V]L;W(Z(",P
M,#`["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V%E.&4X.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED("-C,61C960["GT*+FQI;F5D4F]W4V5L96-T
M961#;VPL('1D+FQI;F5D4F]W4V5L96-T961#;VPL('1A8FQE+FQI;F5D4F]W
M('1D+FQI;F5D4F]W4V5L96-T961#;VP@>PH@("`@8V]L;W(Z(",P,#`["B`@
M("!B86-K9W)O=6YD+6-O;&]R.B`C8S%D8V5D.PH@("`@8F]R9&5R+6)O='1O
M;3H@,7!X('-O;&ED("-C864X93@["GT*"G1H('L*("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z('1R86YS<&%R96YT.PI]"G-P86X@<W1R;VYG('L*("`@(&-O;&]R
M.B`C,F8U8SDW.PI]"@H`````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]I9&5A<R]G
M<F%P:&EC<R]B86-K9W)O=6YD+G!N9P``````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#0U,34V-B`Q,#4Q-30S-#$T-2`P,C0U-34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````B5!.1PT*&@H````-24A$4@```KP`
M``'0"`8```!#9+G_````!F)+1T0`_P#_`/^@O:>3````"7!(67,``"XC```N
M(P%XI3]V````!W1)344'U0(:"P\).5*(+0``(`!)1$%4>-KLO6EBX\JN-)A!
MN4[O?TF]C]["MX#OVF+T#W$`D$`.E%1E5P'WG5>V17%(YA"(!`+X?_^__\.2
MEI:6EI:6EI:6]I?:DDV0EI:6EI:6EI:6@#<M+2TM+2TM+2TM`6]:6EI:6EI:
M6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3TM+2TM+2TM+2$O"FI:6E
MI:6EI:4EX$U+2TM+2TM+2TM+P)N6EI:6EI:6EI:6@#<M+2TM+2TM+2TM`6]:
M6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3TM+2TM+2TM(2
M\*:EI:6EI:6EI:4EX$U+2TM+2TM+2TM+P)N6EI:6EI:6EI:6@#<M+2TM+2TM
M+2TM`6]:6EI:6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EIO\>039"6@#<M
M+2TM+2WM3X%/-/Z&QO?1^*XU9K.G?5/[R"9(2TM+2TO[WL"5SK\MT`GSW1&@
MBD'0W#N_=UQQ[CGZ/2TM`6]:6EI:6MH/`JFCGZ,!/!D`S=:Y9P`N!Z[=`Z@6
MC+,!8MGY/2TM`6]:6EI:6MH/,`Y\C@`8>@"7G>L@`*FMOY6+X'D_E[PW[YY'
MV\ACKM/2$O"FI:6EI:7]$/.87(^I98F9V1E`.OHW7'R6WKEPX7RETQX)C-->
M89FTEI:6EI:6]@0`M(`-SF?H`-A4-VBW+0)@C(GSI/W;E@QO6EI:6EK:('"R
M;&,+7"78>O\[8=#>=-Z7M=:[3$O`>]V8HS\M+2TM[6<:!T%7VN]])ZV$/`Z\
MOY+O+P'OV]SCM+2TM+2T;VZC#.X(DVA!52Z'KX<5D50:$MRF_7;`FY:6EI:6
M]D.L):?5T\'M@;.T]X)?^7LR\VD)>-/2TM+2TCH`:K0@0]K/`,+19TPP_-=;
MJC2DI:6EI?W38,@KFSO+X*;]_+Z`<DVK."T!;UI:6EI:VK<'N^P`G&3[_BZ3
M<=?RO];[SCZ0@#<M+2TM+>W'`=U2_.IFK>\P@<^/`[018)75XE`RC"$!;UI:
M6EI:VE\,AFQ%KU:R4VO+.^W[.351!3@)<&T_8+[G!+QI:6EI:6D_&0!YP+55
M+2WM[^\7F`3):3_74J4A+2TM+>VO-C:`;P2*T]*B?M&3/$M+P)N6EI:6EO8M
M@&\O46T$,*?]&WUFIFI;VO>U#&E(2TM+2_LG@6_T=Z_"6H+=?ZMOL-$?TA+P
MIJ6EI:6E?5NS,9L)8M.\/B+[1X:]_#V6(0UI:6EI:?^$C6Q+OY+5P\1]8>+>
M1ZYEM^+1.!\&[XL#Q_+"\__T/I.6@#<M+2TM+2T!]@!(G0537EQII#@Q`Y![
M@+U5:GDDUOEWQD./.A*9A):`-RTM+2TM+>VB]8H9</)X#\RR`]YF`%\/)*(#
M7*VV;0^@OZ)M/;`JKS5RG02Z"7C3TM+2TM+2+MHHD!H-!8B*9/08UPC$,@#/
M(V!YM"1S"P2_HFVS#'!:`MZTM+2TM+0?!(Q'6$D.@K[18V88Z"O')/A,^RZ6
M*@UI:6EI:6G_D.')[^+-UTA+>X<EPYN6EI:6EO8/&7_#=Y/93?MNE@QO6EI:
M6EI:6EI:`MZTM+2TM+2TM+2T!+QI:6EI:6EI:6EI"7C3TM+2_E7C#[_7C,I,
M2TM+P)N6EI:6UK3,6T]+2TM+P)N6EI:6EH`]+2TM+0%O6EI:6EJ"6VOOJ.65
MEC;:]UY]/',,O,%2AS<M+2WM[0LB&K]_UWO]KO?IM><.TD>*XOZ-8`MO:-?9
MST>`&QJ`#@/?&_G<^ZQUO6=`(BX"5@[<.R_<!YPQW'M>3(RAV3[RN\<CG38X
M_YZ`-RTM+>WM@(0O``]_XEY[P..[M.<H6$!G88P6SQ:XP@#(P@#XP\3]CSSO
MK)/U[.<SWWG7O<PD6_*)^QMU/%!^3_'ED;[::T\ZP/<*Z+UR?0XZ-F5P7/C`
M/0%O6EI:VLN`V`AH>0;TSBYH'#SF%<_[.PS;U1E`"0RV#`:.&CTF!COZ$P2\
MW@CH8@"F1M]]?2S)`J#[M_WOI13UF?>WD7/USCUSWK%KH-/G'^^06W.AC#W_
MF#,S"L[1`:XSXX,O&6/^???.CR>O.7-,;TS48S,!;UI:6MIE`$<S]>I)N,_3
MS8)>N^#,`MJ801F[D_TH##_AJ]J<%9ALLWD,`"->V&,@KH.!5L#4>VZ!YY&6
M[$!^![Q%X/$`F.+,3:#9`*(>>(3X7@_D(CA?>/]D*?O?]Y]9SK\=[Y#;_SW>
MK#Q5[UGW<V"B<^VWK<\-9\@B/@%0"FD>!]7G!=BNYP/WQR&O96U[CLOSUYH%
MP`EXT]+2$NP^Q4XP.`L;C`A='NF5;,CHL1"0O<\-04%U3H.L&,".\7`]1R)^
MKW#?1"^Z>F93M]>+)`!0+.44O)[OR2JBTX##X_?@(17K"GO.!CLLSEU=9\>6
M\ISB>T=?=)A?``H`6E:8#F"6[4V)-(^_T1TV'.EMU+_P`KGJMI/\O752\9GW
M[/)9?2<!39#*S0DXWLV)TG5OVT`U['?*OAN#\^^P\T@],]*9(<<`=#U.Y%\2
M\*:EI:4]"7;]\US?7AR!X#/'V+L)^=F1$#X%YD]&S'*JT:+#X%-V8&X%3-AK
M8U0@K02@UR[/^KX"UC'8AN8!`,K))!I@HD$@RMA6-IWK%O>-AL\H#E,`*7C7
MX3$LA:#U*71;P5RGL<NOKN-]AJ`/--\Y53>I[NW`@=MWL(/#ALO#TMXU]P88
MBM,?BM-.IK]S8EX*[UVV"9V.4'3;XG$.>NU)=;#^;'LFY0+#F2_0=UBIQEW=
MU^G-?,HAJ^<);B`[9<G2TM)^O''[WQ6`R>/[5T!I*]Z-WH7<HVG^&P>RO:=F
MXYG%3PQ0*368H`NI$#UF=2J&S@&++ZOD_%W]RJ%6FGNY;+@,@TEC0,VRX5ST
M#W"!XC-XS7RT5CM%J-$Y#*6.3HE>@W>9;G]IG+\,7F.D.S.XCFQ_&L`V-DSJ
M>T*CN[:V#WK;"%=]\Z,/-?HF&EUC1E!A9`L&#N#GX#OL/JAM>XY-EL+!2(8W
M+2WMK["K$9K8@-QK`AKF%[*(V6REM!CZ:/L-P9(GXXS1#EYH+4;HLY!]G03Z
MB_X5+#IT/(ME>OLGAP-"T5A8]P65\>>272-BK^>X#O5QLRI<\@<:X.U]U@S)
M[NT3](="^!QLO0N,=RQZ#F8#N;GG\*Z':_UOOQ_BXGD8CWR.#CC3[XEX^++1
M+L_ZB9%_['6K([[:=[C=?M1CPL5'"7C3TM)^G-5;H'#FUS/2T/[NK]/^Y\T9
MGF5>_G48[-4'8AA=F,^VQ83%`5WLW13/Q1`C](Z.B'!9W0/0T;"A%EQ'CSF:
M*<X^"',7S5:2$@(0!P<L>5)/#KBP[X!P[AWZ75QV"J"=@2[P;`#=8>!6)B5F
M1U$^RKQV+=Y\W!2ROX@BT6@#U$Z6<N0&^]&44QF[Y;%SXO1Q.GW3=61:SQ[W
MNP2\:6EI/Q?L'G.GUDDXP2AU/%K%D5K&D<V$LG.:9H`YY[0.8E#&,^[.@[IT
M)G>+0]@#*0QB_AH+KV2LT#W:B3Q@!8[=]NLRC:,@H?,]CA0TL"!5+-:V_=@"
M2>R`N=;><R\6`!U0-`*B6N=Z5B[K&:`W^[<KYWY7?^-O:)_1_LX)9_G5]W3E
M'?.%S_[`T`EXT]+2?B[8C::[$'<VA.&'02^;<S%'=M!IF,U>\E4%=NU##F3\
M5WCK20##AJ9!N$7>`E.ME_=.H#5#E_9`PRL6^BO/_"HP.`HTTF+[78X!ON$[
MP;?N)PEXT]+2OBVXM5(][66ZQT)U@!3LV=`X6^,Z9.&0X+Y1]ZD..,%CG*,E
M@)<4XVS*+Y0X66H8##U306X$G/U))O$5Q\Z=L07O,7%'45'5R-W`Y+T^\_W6
M<_?JU;VNO`D:3W0EDRQRX*+K_:F^^[O`;N^99]L#$[VOK063@#<M+>W;@][Q
MU=ALMSLK);P)E0(PRK\W=]9?4PZ4%+JBK*6"8`#R4.QJ>!QJE:%W@<@_N!:/
M`J1W%G<>"2P8`;XE`(2]8(51CG8&<O1<%71`>`_8]YZGU6^]ML'06V>S5$P?
M@(]64_P)[/AH:6M>'%57P/]L^$)[ERP!;UI:VM^"CHO6ANPOSN?T[22_>+$)
MPP!\=*$3UT$,S,?*0O36)*MW^SL7TM===5RQUF<0K]Q-"V2-WLO5ZW`0'+[3
M@;@"1\J+[WOV/F+HP^!8#M\#)^^\Q2N7,JZWS?(.UGOF[?")UOF3H/_18@EX
MT]+2O@E>G0MAZ`)(-X)!B/=C!&I@'NQ>83$8HUV.7GM_[%YE)N#[O//JD3$$
M\Y_AAUX-P#*R]8?-,]_@FL]$?H^D+J;Y+9B`-RTM[8\#7>_GYT!O;R7AGP[?
MC"]P,2(`XPT>@EZ/L<2E.^AM;48JO?PQ&\!I:=\5S$=L<+?T]%\.G+/26EI:
MVA\'NC]G*?FF!LS=):-MW><BY6*8;"3CRH1^?EI:VJ79*JIRZ!6]BS[OU4#\
M26,V&=ZTM+0$O0&(_$ELXUCH0ZL6VQS<KW/<XTC7V5C/M'\#E.$[7GQ6/"#R
M\?ZJ!NL[OZ\<OV,BC0EXT]+2$NC^8]:KEA4O77SBBBPCVZ'\3?W)+;CW8T'@
MD+C;GJ/9.'B/7O&B6.3?6!HODYU_[8V7TE;[$I\1UQJD*A#HR"E4R@T\_-@I
MO(L&VE*/0^4KJ[;?__:*8?ZO.$,CG\TV20+>M+2T!+I=9/']\:ZW3+`!0%^5
M,?];%7395UFV0`X7G@T#?XOP7`7*.A>SH$BJY*'4()1>8YL+RRZ[_^QU8XYF
M4_7^;57X]1H%#4#+P?['P-.R[63Z#.F<8Q1\<0R<>6VN^N7`S]WJN6G3+'`"
MWK2TM`2Y:K;<4`?Y,[;9V09BDUCB6S\FAOO<^2KMWX'VN2.YL2:V<VZ.@^C7
M`Z<NL!M]_?P>?;!YW(R.&!UP/.N%/7//;_*=O;Y8%5^<\I[2>O-?`MZTM+2T
M$*G\A,F=+UG_O_LK`?H+?P48!4CRMN_EUC@-56OKD+A@>-2;2+#R>X'U#YMJ
M."&Q/=T&R*ZR#],$O&EI:6^:S'.5[S$0O5C"OXVE?<;WN-R=+*B0U9CK"B0U
M6!#IZ(0#AODG>]!WZ,7?Y7[^/;P?13MX_1.EO(XI_F&O.AG>M+2T!+IO7IA&
M=F#YY'G^9O.2?_S6>=&J^(H*`?_.VYE$0%%F6]JK`'!W+F'_3;9"AP^WAB_J
M-K^YG1+PIJ6E)=A]P^+S2GS$W_D0WPB3Q%N^/3F`[]:P[^YIS[ADK7-'T@M7
MT`N^"="=N?]_A[EFIY78Z#E3K11UI]_0S`EXT]+2G@2XV!BX!+L_]N9-?"MZ
MN.C-`-=G=",`]1U`U`][T>/I?S^XEX]([S'H60CU3'`44>'Q\QY)#Z==]7'?
M$U1?U>'N'8,9O\-SMGN)BE,73,";EI;V%-C=IO1_`.ORI]TLQA_*50<P?VCI
MB'JJ"*'<4JF/<9/-GGH3,XJV5WH!.M>T*_`5SZ']G;T,<RR,%J&!5K!RK_7P
M=,OVQ"O&NBTW4,HWCO6X_+7W<ZL7^+RY?K_S/>7[:Y6-E,%13O:,>L<%2\";
MEI:6=I$\X$^Z60_H-D&6H^++-OLJ@6\D"2;![S4Q_FB#E<%G'&^0[G&MC=R1
M(.`KW@H[_8Y#9SH!<C%_C:^!!A1$I[VZR53EY$5[?_,B2]D3Q44+N6/@87'A
MS>TU!SG0-NT2+>SV?O\-_*0@C)EG=I^Q%W%COIR`-RTM;7ZB^D?"%WYTTEBK
M$M80F/3!;/3J)1"V[.[H.>:6R"MBKB/P8!0RC/<*;WL<`ZY4="<U&X@**GIP
M7)YYY.Y[H&N\0$<+Q,Y$O[/NS_)?^9#</:J-/B1,XVQ?XNA[G]%*P<!@?`U(
MG/D;!N<X_*'I:OJ9@^D`@4^<@#<M+>V?`[LM_(<.M'H;*+VX0C2!!V<7F"MQ
MGCZ(?5TWF0WD>Q8NM,J`S5\!3D1H&^S*3]F5HCJOJ3?*7]EOT70OZCMDT]$(
MVC,J0]S2YW.[!7PV5]8`EB7M+(**XDF+=[SW*`VPKLH!C@+C7FA+_),-^V`C
M%(>!8W0Z5*^9MG[/&N7WX02\:6EI?SW`]9:/D8)-OP6;S08Q<NS^QRMP11N+
M?X+S89D)#8C`X)5JK'0@`2N($*<R78'8]EIC+00-GGK>3]`A&24).5]A%![`
M&B`2#BBTUP?G,J$4VH8_"!B]LQ+&SKA8FH(`'ID4>F'3S6>B,_:#"Y,3PW!W
M?AIC6SWDV1*]?LVC!^+'I8HFX$U+2PN!+O!W9;^_';JWP.X(I3Q"*(I=VOUK
M?$N+,(`&?_;-]-+&2@/L<O@E^A5MT=R6]^A(VWPV.6RR;K`$1$-5!RQRZWA*
M"#K42$G@F20COK[W('C?.-"]^)LH&\Z!'C_BD[HCA"\>!JT8*S0<C%9?9R`X
M)IP:'L'WQ7$+?T+ZW.,F+P#>+.J<EO8O@=YZ[.<<\#1^;.'*'L;D;P+O8^CK
M#>?M!ULTG_\R-D?SZ6KPPS-.E`(E-ME+]M%ZM.1BH-EZU/:K"FOP3PZQ<;8_
MFJDXV!OXQ##'$Z,`HP<?G1*3,42R=&`0L$)Q`3H`&5';]H-V_M34_/'\Y)26
MEO;OV/<`NZ.R^7\<Y#8P6*NB42A"4%H9^E&<Y)]J+0[<4__;X;<X=@).PIB#
MO8JTUFJO<+Y9KX2\C#3?6^)T7M\C1G4SGG&Q^?YA/>R[ONW:@M'M2;RU5#?&
M.E]QV&`[INI@:U[P0M]5L#I#&M+2T@:FP'&@\B<6T._JBDNM309WWHN@E7&%
M-11HO;E7UL5%O`B&Q]DW-%(H@@$TM4&ED\@#CM<0BMV;6$FR?<O?Q+D*P0%?
M?WD,@-3(Q9B-?,C]I-FNH3OT6-KCQ%R_[VA(!GA/%&0)XJ5QN9NWA1(3\*:E
MI5V9,-FJ+B!U?[XOZ/W3R)K32"Q><-K`X)V"^]X",YJ98R$1N@Z!K%P5M3O)
M:YY-*T%H)"YU`FR.+NTCXE<M]V&FFX+^6WDG^\D7]U2^N9^/Z*OA.\U%$T]'
M=S^(3[4X:`;,$=)S9"V:9,H6SSS>8B..4N],"7C3TM(FE1@F2GC]IL7NK1!\
MD)+BY53N,2BI%X@1`-I(N^_=G25P7$#.0_^U)Z_5:JMP$>;O>+FO[Z,C>8D>
M"'TE6.2;P&?KN;Z-Y[MAKB82'0D(EX(&/2\$[7;>-PY*$?K495[/^#OV]_W!
M]D1`Z.VH4S7#4_8HY=1#[LYMZ+J$O2R#!+QI:2^;^G_6QAOU_QM;&3'8"@PB
MRN3,_UO>RLDVN*">UU9P6\&J5KV_VG<P"%!&4FK:;/)H/"QM>SIP-5JF>26@
M=3(.M;=ABP:^^5VN6VM_A.\8UW\*_/SF"[,W1\W0Z<]X-#;:!O%]DOY(C3;7
M?DKEM,C)@E3^B$3.I3Q:B%IYJ77D$0EXT])^]M1_[6XWR;&G:M%33"<8@&)'
MF%>CFM>K)W=H22GVXD!YY:WC">>G%T+28CEFG:S).%@7BU*=KB=I+X$R(ZU8
MOG;$C2AJ_3/@<#9++'+Z4*[6X1B8B_9=\6U.<N00.5H-C1-(C!<:<M2GO3`L
M:=J7XE$E.\R)6>0[`&8V_&Z46KPD3.`M(T#84]$^]Z(2\*:E_6O0?)N!VHQG
MC_(SLQA;`-#,O`%.T\GHKV/,Z8&U%P"6U\36LM%(UR!4C"=?K&=F&!M&JQ.=
MMN?KWL.W4@'];G3<:-$\EEB';>!<I"XM[?V,4#F+V]^QS4EPYJ;6@W#R[T\T
MY+L#BMGP9W%-A*/EOUQQQ=_I!(Z72'8Z$R)J_\Q"6'+Y3TO[]\!N>PIZEKZ(
MI^7Q"9NOV4HFC_]>!;CB-GLEDHR6`S:![GR5M1<]^BSHDG_#]1:Y"I'?N8#3
M*CA]Z_F@;A[2_WGZO.IG'O_&BKE1Q_!+K/#XG_Z-XC@&_S[;W\;/\\2^PHCH
M"IV!;WYGYU31/M)WZ+Z^'X9"4PY9OS3J@2@^3(8W+>UO![DS*Q?06.EX12#R
M$NGB9E&/JL7+$PP*_/-[OC7W=[96+F<;]+<]Y+1`!=P=A7D6"YU^A;<SKUK@
M9-NCP/SWFT(I`\.(4=^WS"OT[W;85W&FC2H?`(Z0A!.2>&]T-'*Z5P3<<X_U
MP*<#.D=`+PX0I;?#ZZD%0;(9U;GDWW2U/G9VLH*WRT:`<B^6!P-S'\P[Q_O*
MS5R?"7FT+&P_8</S`A/PIJ6E>=[]NWQ\'=?`T57]JEQ#9[;FU#T_CQHKV:@.
MIL>,1L-W4368$HD8$SY["FB_>)5F$/:C6<WSN48`K-WN9Z>M)(;G:-\O+*3>
MFB>B9[+%-A#V0@ETRQ23ZJ<;<K8WJ*2GYP8G$6O4S7*U#$K$<*BTM'X/*#I*
M'JJ=4$6NNE4#J64`1UZ)&_4FQC=$]QA)%GT]".;4T$_`FY;V%QM'*:-+*.(%
MH.C98YYX+'86F0&(.0&.B@(J'GNR_QWH5YE]]2N:%>7P\Y=0E)Z90O1T6GAN
MF[G;ODY7]Q*@GG^/<]&/E.\TE)2@<ZU&,N2F=4K.OE'6YQE"RSW6U<(0.`X;
M*J>73]<FPUG*&2^8DU[HTI>G`!^:L(ZN2G8<_Z^Y]_A^IR8+ZKG(=B5BB'-X
M_QHH`'\"WK0_AF?2W@ARKV)7LI-O?VVR\3<S&[UD0A;LZKV,K7B8:;IV1(AW
MXPYY;$OATKOS%Y'.S^@<UQ5O@_I(#MA]U=S@)439K/_>NQKY^UR+U2#/51E0
M#1'J-=77Q$@"5:_?HI3)"EPTM;SZ+<+@#,^HF@37&`EEBCVUESB+&`2[\:4]
MAV*FS`(NC>-N<^#B1!&<M!?`\0Y6>+]F`MZTMWE5:3_U;?!M5S]V'Y\HVG:N
M69R!T`.+,[K`Q5OB9.7:9KSC:(U5&8<K>!E*!O4)C,`W'%LY-AL"]9(DG^E=
M#++Q;.RI_M>X$)LP*`GEH`#>=?BZ$0!H?6J.0,=Z.QV,84%?P:*E"3=2&-AW
MRFRLI'N<;-.H;C:>[[3J"3V'DKJ"M.>(71'_HVT*LYO3![V<].PO,N+FNU2A
M)*A?PRN\X@ZZYF\"OPEXT]+^%EC[A]/"GY^<XKIB[7GT!7&@[C3;WL*MRB^,
M)FU-[8C+;.1)#=T+B_;+')NW]L7G(/MY;SS#4P$AUW?]RG!_LXPL.E76VG0E
M+[5#HP/:T!/;_[I%_=B/=FC="AI`=;3!)6;&F/9KY'^V?I[W[MM8MCLKP:G0
MQJB_C4S`'+II+Z7.4[CM7A3!^V[$.43!-:\`OBE+EI;VEX#=5\0J7H$>GAQ6
M2ZTJBMGT;A_%5]]Y'P?@/\%O31*K;J&OG\O&NREE-([N!^S+X$H);*N'MOUW
M+,80;&OTWUAZ#-7//'J[%<\JQU^EE!:"T?-FN0UT.E%/.LYKWH%Y(,1;L\#9
M`83`V/!Z2;M=\<VBZ*DJ!KW^&4)AP^FF+^P(#%\-CAAL/(>O,=[%7R'^F`QO
M6MI?`';EOW_\?@;(F1J@URX^FV=^R0S?G&&[%=YA4'DIKZ-2O:U[LQN.<IV)
M:J7#'.`/[W`H6GVBCKVMFP'=]^6#72D1A>-<(_&6P^\)DH?W_O\S^M:\WH=Z
MM95'*A*,WAIC_((&WBDE+N86!1M5YV,X7%XELM)ODZGXAVMCQ!LSWA#&=*PR
MA^=%K<B!9IK<;-^9Y3)F'C$!;UK:#P>Z?PK4ON+^`71CNL9XF6L;7ZP4/`=3
M1R)-L8EB9B,XQ(8XOOP=#)U0K*`"73Q*4_O@I14-6N>?PRSH&SM*N.]K#LBW
MXU:IU%+A8):),)+6)7N>(0;/6R%&!V%Y_N"H-O,%L/L,QG/_!M/G`S6**?>`
M<TW^1R;&V;+F48$36:JX]L>N3).=6<R[=3W>$`+C:VT2=ENTWV\"WK2T!+M3
MWO/+"0RSDSM7"PG7J8%`7Y,7'HA/$'"<_.P]B[,3;,=69@G*,'9JR10Q*D,=
M@=T`X(5`TVM)-%T>RV"-++J7\(,1^4=I=&G9LR&_0[\/.FV"TBKO^V>=WVD0
M?N%TH[OGWZDR=//&6\=Z&+BG7%%$2#9F9J^^(@B-<%K$&Y3RA*2;544T$H](
MP)N6ED!W=L'HK,GS)Q/08SZGGP&([?,)','.'9#[7>7W&"$R>J!G=!^;;:#:
MC/\HS22>B'GCB!)^=)W>"GHD:-'YG.Z?AZK`&8QMU1\\T*G^UKD(9YJC483J
M.;>WU_`8&_1/@^MQSG841\\`KU;HQ:!`0=]QFMDNB@ID]N)U3-\Z0>\CF1/>
M-(&9]PO'<7VQ?^,]CXFL2,";EI;6CU<MY3F)^($YL=8J?8WF0GO]$,+UD^WT
MU.3\%F>HZ-#;"*O^+@_)>2&5"$#QPD<:SHJSZ%J9*;>S1LH#LE_:,'(TG*.K
M[V?PLT>X")^+$T5Y@83=S$8T7@9L1ZZB@1."8YZ?.]#PUS`(V%HM@W>-N9X3
MB+Z[B\(2I5K4VN`\]1FG6IC-=_BR#I.`-RWMAP#2-S&[([*PK[P.'/F@/5%I
M=JKSJGQ9:2>TOLUQ)/AL/:AA(N15ZURKE"\1OO'6%F/[82R-I,_T6`LQB+UD
M7*!!;0'AR\!Q.SZCV:XU>JENL_%58W<<^*KQ/E(\H06R&#D[HP_F)/HU>U_T
M_O%$[X[2H1KE<S'QZKQ*RA-@=H:=Y.Q0??5TT:X+<T[*HI-*7>U'SH6</ATP
M7)5Y'J4>:K?B9=J\XED3\*:E_8L`^C=>)-2W%-N[Y,R2%T&U^BA6=>;%67%-
M[NO2>MU+:+J815-5IF4'[#:V?SFPB"-L82\0@=6Q\::O%U?;@!Y&GY0<?PX)
M>EWH_\*,IJ?V*>AW#9;Q30F_.\R`UU$]LG?`-`RT++2_A><N\<[=FQD!#,3X
M],*%<12"4>3`%@(A0:M,1)4D!,5W]Y_1K)F"B<:/9$+.=QQLQ$R_YP2\:6G?
M&9B^@=E]"]B]7/5V[(AJL7!!2;U<A6"7?&\;M7*E+)O$N0A)Z3!XGT;5R+P;
MZRZD+$U1>`EO&T%^XMLC'%A#<&U_=8S:871<B3._*!![!__GW4MV```@`$E$
M051\PUB+(M5C1`0#XC=WPRE+O)<8J-S#J-R847QP?;<98N^J@T&,.9`3YV?O
M7G_3G-LK@H'2+]%;M07DKM=995!E07:&PZZL0[)=/KU0@6QZ`!FEC!6I[K.^
MHTY-%IY(2TNP^Y*37DD^B-E=CIV+$6"*JE-)U?9KW-+,),MM7=ZW6;D_\[YX
M["`.FH&4\)`&<W"8[HD!9J^TP?,-T>/*,`AV,=!79$&'%PV*QG7JZY[L-5\Z
M*ADC>MM)O!=+A]=E<4I7GV5E*9ZI`M$2Z%*,,CA#BR6N&.,5H!M5'?3$`3S_
MZ-D,6[(=E?&'@_C9<2FKV=.^+^!@?@\LO/VM"68GUB5YG,XK0-%9<##S-LI(
M'?9F(0K(2VW_`Y+A34O[V\'N[Y.V>L4ZP!C+3B]<<"?^2)OI%:PNO1N6A1SH
M.`ERNW`'P"7&.!HDC*;2O#`\HP-P=32UWR-LC*K-V>90(&T-,GLR1RWLTN]L
M,*`7%ST#]E$:&[)/H@0RCM`<G'&5@@T#`S>`K?1+U&U)V^8T"!AU>(UI>SC]
MMXJS%AA(ACRII$0.OJ[2`+W=O"KXQ[:H5UR<ZMZ0XZ?:'0)@HG,Y<EM[$+?+
MQ-JD'K$J7\W)QIM0468IR[(<@'>W!+QI:=\,Z+ZJ1/!EV;#1K<`W(.EFV$)7
M;G=(`J)X5<M>MLJ$E1SHE'V"`!Z38),E`%TLY3K7V5S+;,BSWI&D?DQ'BLM[
M#:H9YMT@X<2<O]M70+2<H`X]I)[-07)VL/2"SJT@JBR\$A2GPG'IW:&`#I_8
MSH?MW'XUZIDZ<C)>T],'CIR8EC-"4X:6[OU9:;8Z*?'1F1"`3[5U+O2?,3-%
M0+2Y4C(P:;*($&:95>HJPU%!D:27#3?I]&BME;</%`JB)9AT>'URK/(P66IY
M%4\$F,X\8QZXJL$)']DGX$U+^T9@5_[[>R]>PNI,OPOOTDE,&B3YV@C=!2HO
MKC(ZE=KOL6N&VFJ6GO,YQEF8R^%@:W^[GM9W\,(_J8\=Z4@]/V?H()=`Q1RA
M='P7]67I,%^FSQJ="H7LCT0_ZG!&TB)'5-`P3`EDZV7RXJ0PJ%J!SA\4A2L>
M%DY0]N$(Q#L6;,3UJ+$(#:1#]M_<"AT@'5T'K2T#HTH3#-RV4U\B9ZGQ?1/L
M3XB870?(KF3AZL7'>.Q')'+M#4#X,-7H0X,>$$?[N:(E;$$!_&C=!+QI:7\C
M>'[Y@>-,X'4.`$ZA@<EG0&-FQ"B*?BW8;6LB1"M;BW<[6^KR3BH=DB<$Y&V4
MZ,DG<PBUMI=-_XHH'D./T@<=N%B0CZ6NX%LM[Y9AE"RA`Q)"G=]B:4;QLI3C
M9MADOKI@[NPX&:7K&S1JB#"=%P?K<6'`JW,DXJ;FM+J-8=5"6JUI^R0Z/D/K
MPU84D^MKF)U#P:ZNZ_J(VW4O,8K0&XFF3K^,5$/.8CZZKX]N.F)7I/":(F7)
MTM*^`3A]$7J\&.;Z+:HG\.*S7COSW-8<AVYT3/4!$T_&0*[GQ957G:UHVYLP
MWO8#F7`VM9"-9W)#&9SH`3:Z-!R0W(V,L%$'(EZ:WKZU`#YD[\UW>B^@8VSA
MB`;;O7[@`+TSL#>NB<;P.+<O!T5C3'2OV+UF[44$>M#J=R^&5&Z-/SE;C#L"
M];OF%7E#6[R0OF_G[L#)6.?.Y'(DHD$4^F4YP*['W=;%B-CP85O!,RUGC$>B
MG&7C1Z>5_:S+LM3OQT0V).!-2_L+P.XT^.GM>C9$[_F2^_05<I]%<.?6)5T6
MCKT4)7?AGMD[;R^S?,G+F0&P(\?IK4<MK87AD,060,(X'FX_]T:ADAQNJ2,$
M@/JI%'D*P;H9`K%.L*F?A!3@U+TQ"^98(QP;Z.R&.-$'^61S*/,%O8WFC`S'
M01U?&<>=HNFJ^#L^#EM(AJ,5SFAL59#S6A+5-;WO:V<5O<F4WL1:T_Y\R;2`
M4U)L^\L#[,:]6O]]O&1)')##<")"*0IXCTUH.!S?!5!#R&M6).!-2_OY0)>S
M!_]&/<FVIRYU2\5B%ZS0,V5]9]8&B$53,T@CG#F;1_+M_<@\"\I%FK\H::H6
MN^(3452P`*6]D+H+OIM"KAD]SB#ZCL-U`H%2T954E&VO^:0&'2>'&4YPQ'89
ME1:;?:7"UU""JJW"Y5:`<W3+T/&6(9TINN6?/:#LYX9)\'G&FX_EB]5%#NQ6
M/DNHT!;<:8F=^<[=]'6L?0!-VJ>PA^H,OIW9?;6A,4>,S4(8)Q7$=&$3O8^8
M>'/MU.%-2_O!8/>5J+6J-G4AG/8EM\+.O;W+W"`\/MNL;VE$J4F+$3+DA;?E
M`^(3)C3U,0\1XA@O^?T.;WKW>Y:2_-<!LT.-`B'N'VM!PUQ[!+3&QYPP`:56
M-.TC#.C!Q1[8E4EGQ0A#%]=)4$RG8<`KT0?5>=#,H:5X>A:].X$V5%+:R1&P
M/,&T/(IF/N*A\SJ_GX.VX^`"OTCDF,+Q9-6]'UU[4ZNN=';A3[*CWCO[<)WE
M];M;-BX:%<N+LP=MQR7#FY;VD\'SA0-'V"!V)I?^I5A*N&D8T4SO!]C-ZTRB
MQ:&8Z59D!%K0)@:ZQ<$A'534?W[+;J,'>)YP*@18\,\O);>V&+].A^`@I)CR
M*$9[KE?7V-G$11G892ASNQ/^5C,:6\A.W&PKWZCJ9//MQ:@/-#7PZLI:42IE
M%+A0P];ZCEA<<>MB5:UV%OK1%-LYH<MVR$T*%=S`^K$!>[<C&9[&X>@XGOXX
M0%G756:'*>@?@M[6]@+:[QSE+5+#5;ECR#X#XR)G:>&TM-\(3/]4K.Z++D1<
M^W(4`=>]WK?U'-J.@7N^!G-28TB.XPF3VS05N!F!D%8V&CH.2J`A?8:N:!U9
M#R"ZOUTL$H+7#-QJW9\KG3TNJ?]\OQ<=(=P5%LEB[!<HJ0$]M7/2+LD5.CM-
M(-UPJN@Z71AH$^]XAJ?1X>UTQBM.,"L+AY7383OZ_I&,1:V,HAZE5SJN!"*V
MT=MKU5QF%7N`7N^T<FAL=9CV'=DW@&?[/'58#!K`/`%O6MH/`[N70>MO`(3#
MJ0W5_B[_</NP.TE?;2=/B][3[^<D"7:)$NP=PC9V>:SI##&-9EI,8@^U&]2\
M$'M21LZ*R7))9[D'B?`D,!V*H1W]G)W#1J2&^22\%N^H%W&J*ZVQJ:PQ=,UH
M4,!$Y3*0,IM];`3]RG/"@J(<.Q,L'53%,2O&MY0A85Y79Z]N??G("Z#\(=C3
MF;%Y@G:$%?/"`=.3$G\U\!55!MT"%]N_&<.;EO9FL/NJRFG"/W\Y4!V:^#%V
MV-1]\U6(?.2N=H%4_3#+HK4;]Z4"4^=6A$,W\<M.]KU2PJ]X/S;JS]T4#18I
M0(<X[S'$5O=R![0*[/)J[3<.]"\3$^P%$+/]UMCX[-7JMKZS5]H2IK:3F(#=
M@U@48L"P_4**`&!LBFA5)^,D8,7\Q*D#U4=ZB*\+=WWR1`.#FG?7=4R#02=O
M.7ID\FJ#:JUNJ=`@QZE^1%2=I(ZC-BC9[C`-2A-Z<^0\-W2>Z5$X0\;/UYT]
M&=ZTM-\`>E^Y3@X=.%TZETT0!U<;=O:&@K]>I%.;(:6`D9;:4DM0A-YC:V7A
M?+M-)OEQD-!JV4-[\GQF!MG70R0P_5=A"7!-MD4))=!,V'2W\35E63E*Z",L
M=(=(]S,^,V@A&"@K6X8&@($#=`=!=%01CJQ!?#,\$]W9P6TS!,["E>S]**2E
MWN%_<:0HQ^?8ET[B:(/>*A:8495U\6:WRF.8N/4H_$`I8UR1![%3IBT%/>TD
M6?$S.NF.3,";EO;=@2ZO?N$IR0!33:B@28E=?4J4]N(\?T*<(8H0>=-;!DJ=
MAX5C6U9KM$XTW^L+MPT^ZL:L`AHWW6Z/*7]]E`L]2]FV%CJ.$C/#?9!/G$$6
M,FXWKZ>-NB,&\2U``V09PAHNH.,Q(=U\1%%MK5+68/`]SE^/@V.S6=3#)G_Q
M$HZIR#\,.EWH>'L1^>WI&O=B1]TYZ*E!65XE4CZ,_QEZ#T8D39;_.W2LQSTJ
MG1RY.Z-64!)C!6EZG['V8<A&:6:9(GAH#=/-'$G`FY;V#8'N929IB(C@U`DY
MXLVWSCU0/?24%*(I==`E>THI&]-IP-]8=5L4<CVH!E[-7GLUYFTLGEI[5#PE
M-@:[+`6W4I8M/O`A0_0`OZ2_NOSN+LN6X],"2?2X)GL>HXO:K"?[/'#QF,W>
MZ2-@S:GACDJE852GVG\"7+J7:/YYF0-52E=J+*J!U[N/L>+9DR`.K^E7\^O.
MZ=])NRTW]6#+LA2NZ\,A=@%RKT_2[8MJK:@F^E[Y&C_XEYQ_?@W2]6J2@#<M
M[96+^!;7>!7TOCJQ[!K8?<&-L0V]X[4"<>$)KS+8UM[1=N80M%<2/9U5R5L5
MT:F&=&4Y55OA_G,3+"C+P6(#'K,C^B-9[NO]CX#;7EY]-_Q/4([=,K=A2\,C
MO_P[1N-&9#!SD.7>PCM\$0QDX0OG#XR-9[RP$W0NPX$^XL7!7TTX]1)++P'@
MZ`;XNP<<R[(L!4N]'@$H"S:)LF9P\]@6%B.I-Z?3(`2Y@:MFY,8.H0F,]'P1
MHTQFTEI:VNL][>M@%[/K"MN`X1TA9F6""YA:6#'BO9LG-<D[LQ$&TXRN!4NH
MBD<%[8%K':+Q1PI*IP:[SIH!E&6Y.;[!:V(?KR@7L`Q(N\FT:_C1Y'%Q`?DS
MXQ)PO0$D,K@.!\D6&.M@0UOF`"_W>%_X\J*:!Q?Q\FP7X^#76=HL.B9NA1/-
M\7[VX@D["C`L!7OL[C%'V&,03VRR8[,T7$N4HHIOH/F6]#CQF%V3=,;6>!SO
M9`EXT])>O5[@.H"XMAU90AW%=@X'G*Q<?])"0^NISN<52@A[@IA110C9V`U(
MT#TFF.D&8@SQY*(4[8B[1:;8OK+.B^YC#C:6XSU<`1.(8UD>H/<9L,NA=D:U
MG'D@M'D%%*WW:E+8O:2K'E/,K=(;>Z"7^D?:BD[R=CBN##?T_'S'Q-1!BDY0
M<%5\CA/7X)OFU\&#6M7^.#03^\T4*["@<1RZRBVCSF`[EET7G7@DM-:QO)[#
M2UD!44E'V(LSI!;HO80&T8"C7:C^[78`=-J/L>I-AC2DI3T[&3^[W>=,7;SR
M!8R4F3V_,'N[K2U%?P<XKH[NPWQ=/:=6A@P>FF>:\O0"AQ(*\(?OF'YV<;OM
MV)R_)=OA;E1[8JNE/.*/!WF+H[;$@K(095UIVGS,>>C)W5L7Z(@W)6.<'3H*
M<!I;]PM.#12'B14%$$+-Y!*'K;QTUWIT'U[HCC8%<)W.MB<L>3ZE+`@"^S:C
MX'@O@ZX7LAD^\,"@BK1>35$'KVF>@=<C##`%24"W#IY,\2INGRN-.34,W!),
M+4HIR^UVLK=298=Z_%!D4=K:F,2^3D2C'E.P_'P(6:$.0?@*_12X2#91ONS&
M>T_`FY9V&>CN,D.V'-D?V,N"#W`8QM(.(/0!MII%;I>=3)P$$]@EPK:D*0O]
M#GU(B2KA('89WDO-+*Q<RX+Y#:O'_=$)F="R9T"40#4/=FMF!(H)<I&VU8D2
MIUG)AZC\8"=!]WZ#A"\8-TDH'333G;9XXPH]AE69V*C-%P5X#V`H^U(#S_"E
M<?08:60-TL[NSZ./'MGGU%7KO.M2>62ZD``E74LHU%6/S(:6,B$+BP48VX%I
M5B/880C1<#J!TI"HJ+6&W?L*P?`S664<&/-E:G>G-,D$\YEP8AYA2V='@IGO
M]CF8ZUJ1$VZ_@M63[T0WMP*A'24)KSRT['^A>@ETNS[F?S0("R;@34M[%O2^
M8JE\BB1V*W6A6CC=A4P(.5;$B65-Z:<CR(EPM=<2BS:$QDRWU<@*Z"!"\=MB
M?+W(!V)8VM&RGP*ZKE@FVPM(IWSK@Z499WGW^VII\Q>R,&AG78\4VM?3JE]]
M8$T_(M"VB%NA#O!UN-P_B5*X0)>?DNW.`:#:!+ALL)T4/@Q]S=LBB@705*K3
M8-1_FUK)@?ZML<=J^FJZE,"W:':X61[8`.FXZ1SE"*>=8,YQL+N=)-ZC:AA,
M3Z#N,D,(-;H0+DSP=M@A/JVU/4D-BL&O;X+K:JX5!TO03H*JM'3L6*"WW5:A
M6+;[2N-<>Q*>VX_XF",SI"$M[2+(?47UM*GM]\8LQ]87$(/B(^N=EI.!6$P8
MQ--*P+R!W<X6.5H%']`3^CW%T_6S;'=,O+2J'9_Z;J?8@K=2-RE*"R*N2_<<
M`&D'<]*QZ)5O+1)HPB_^(%A?F^>BM3_[_3=DO:"IPBA2@F+!!B;?<?C\\5"L
M%GV>MTIH<`DAEL]BQ$9WA\."#`G>#R?#0U(R2*;Q'KVQJ,",B3BVHJB4]V_`
M4-27-N:1!@2"_9V0`ZQ%X45&JY4MBE1MRFE6^2"^$5=W1F]JCN(4KDI(F$W$
MNE50EMNR[:9Y2:RFJ,X&`/OJ"\[/6]X`&P5!NJ6()QK#]@LXA9&6Y;RJQ?#D
MOC8EPYN6-@UV6Z#NW6!J9$U6BRU&SF'I7<$$[*"WE(@?TEJOC3:+P.C._JX6
M@)F%&.6Q?1]N"UY\)Y;,Y*M>4F_!LPLC>CV$-?U^M*N._T6O]U4,+COKC@1@
M`]7-/-]+@.4:#[3V03O.0&-LL6BVKG**+E0<:-X915@X',`@JJ[5)T7P;IS!
M+H\!PN-HG,U^^5T&(+7X3JAM!0Y430`JJC;D%UO=P4%CG"AO*W$\&X]'^,/0
MNMU['*GUWUV6,JJ$,8HZ#>N[+$M9CF(T<2_=XW:?E28<)6O0FA-M=9-A41LY
M]Y4"H<'NW<PCS&,IZ[HFX$U+^SWV3&G>>G'FS!=8>\H\9[_&C.4E48DL]^)5
MZVE/D*'0.U"64A3H56#)LD(1'EQ9L%Q7'KA"OL2<Y(!#$C4.')1T[-.B<AC&
MXW,?YZB3L5!GYIDE'090,XBWI"4#@S7-Z@MK)C9F+GE1.T\ZJR@(%];6PKTS
MX8]82.L+Z"A4E$'V_5*\C!B!$OB:!+RC?XB7XE8@.^*#'?;0,+JMWCZT@U^!
M:D33G.JD[ZJ&QM[@'V(H#4A62GIZ#H94,(G"5,K@=KY(1-W?/T(GLFS%9UY)
MN[1OK7K#C-<T]26W:]3SWE%:W0D?8>%6:GU?!E.6+"UM<'VQ#.:%J1?/3R3=
M$HYF(H]9SP9(59H^U"0/S82V)Z)Q<)UQ&"C:+5"OS2)F3"Z_N.)0[(N$V`:^
MO!:8C!HVFM7\KO*VC]UD:*#*FFY:EN6<]"?N$\OB/*A5B;522SJQ!#+#2CP0
M1!&/G7'R>YN1&5,A-C:V]`2[J&]S\+%/4$"49F5";[A*L'M<&J%;H9ZI+90U
M@`D[H.*(O79DVXH(7W%\R:V*(A696E4UJ\*>Y#6LG"',+(6AH</J7`/`"CVI
M/R-XU01[G,2!:"+D0VZ+]1BO<1XJL#OB1#]"&6XJ.7B&$FD[_RPO`\886M@:
MQYIR%=CFL,8<P'5/DGZ46B^E).!-2WLG<N4,;=@0CJR+&V#J!IZ=MO8)=72G
M\)B`Q7_2:;#?7=<`-/.<V%LA"WOIXWFPRGKS;[(@FL/SN)J@K7O76L<:Z*H<
M+14N:35UQ[O68P'P5PH7A#MGJC1J!:M[+-<5H.T-)2AE#`VZ<3*K`QVQE0QY
M.&N--=?=C8#05'7S"75BW)4PFT[.E[A_*X,E'=UV30W]-ED=%]5PTXEN%MK)
MG]`0CJO!L1UXWCVY]TSG^<7_ZN_*(L1>)V(9+(M2VG7^&(X="\+95J"MGL?:
M4H%=V[ZLQJ67`R"311_C&H5\44X$!XESB@'@R#"B%`?<^T[.F5AYGCM#&M+2
MF@/U.4]YN$3EQ&5\30')OG&,`V[HB4IF!T)_*"P3#\U<G%N^0N\Q`O-P!+DH
M(=^B)WQ7A)QFV;O"9O3?`P,JXJKV?BTQ9<LO/UZ`RB/:OG>[W4;J<%2VKFM9
MN9[/$SXZ/:[/E0ZC$P)L64IV@6F#+>M_.:[H"GV3D.H+^\].*(!"Z5*YHBIU
M6LL$1&Q>5$RUU7<XH_/<"^+&M>FG`IRN1&HKV]Z7+4`8S@`3/.%+6/E`UFRF
M;^^,LB_A!.6(M*^=N19ZTM'%49J`F.["0.AVH&0X!K&FSHU`.)*Y,0(J#\(2
MWY43QT)"#(]`PWFP3PVE--@8=I-3LMA2\H'$GT?F)^!-2QN`ERZ],G`\1U:4
M`+M*S<3V5T;`+L/)860B"A]#L,V2O249SD?QO7L@%`J45=^4@A%EG)ZEF1T;
M>+Q2,^TVTH3_PJK/.+RB7(BV>.;;QTW%ZPU?CRSK?>U)%*C6/_M5$8LSN\_<
M4E13D-`D2C[`Y4`.GPNKX/>1UKE@%4=*G5S53=SRAAE=IY?"T;/.Y=$$YM9&
M9*T0`-&F-SX\3IQ1P(C4M,Z1`'%%ZTH3]!TJ-Y[=!+Y7S\#SA<N$J""(7(4-
M3,R+!W2&GK404!$G@-\+A;!B\:L5`_&X@<U8$W1$"-WW"H-1F%M4%YLP(/@U
MC&_4'>%Y>$+5YE2@N!;1G8`W+2T$![,?X)K<#(JC_8CV?3F5J73<5P"&T&9V
MO=M;.@REQ\"Q!QQ/*OA<_&D!BW-NUO.S?,YE4)9,\M5V$6@4RQP#N[-UH6=\
MKU+*3511FMU_N-]7=VN4GL-UT*-G4A2WS@?T41CI]P!ZS%^0L7TP/IWX2@4B
M65JAU+6><Z1(H)+<["VV-OT?MI(J#(C%[[0VC$;BNHJOY!"'&/8?JWU,NCO'
MM<\5);25&L=Z!6,J&J\2'(EW&L!8Z@\,=)HEUBT^-HXY@<8.&?RQXLV!-:BO
M$X?A?-+;%91NU(+E3))$.4(0)"-[EM-F6==5Z.H67[16ZK$%8=@C2;Y7*WF6
MAD^JUDA$=[`E]ZZR>,7CWP2\:6G7R(^IP=N:1(]MZI&M2U?8D)WMZ'ELY<TV
MH>R8][,%!8BJB*'HJD_LKN!LW.:"N*ZI"P[XJ-(F5T:$K$^ME^K=:)/99"GC
M4L&UDL!MKZ)TH9,^DCA6K;+A*7.@]I(`'O`TSIR6&])5JP2+DYM%I<BY'6QU
MF:&]CZ'M5+H@5X%?N`P=O)T;#\^)&.OASNMH"2NG#M8)B(DP"YHDFZB^1[\(
MG0V?:47[-$LP#Y"61RA,0Q5O5K&KYWA[;6S#=YHU8BZ\T\A)OAH*M?<O8"FG
MRHF83EFO$#*4Z6Q_X\RIL1"\-<P]?E.!<9)\TL4TG.(:E*^*QD%(AC<MK3%8
MO<+PPT3?,"+VYE)/O[WE[[\"E%\%POT3PZ?C5$OS43S"G5]Q5`=KR6`!RU",
M(KW)U%-G`^HEW5W5(29E#C79&/"MEX9EP42'T\OZNJZ"8(OCL4^L#QW68'&^
MX&AM`AQ=O+EM26X(S-L5`.MW7P;<.8:>ZMG0B-0BR,HU<LH=!!RUP_CUWH^C
M>%*[`G3Z5M'@QIVOMM_WG9-B?;.:5Y02:U*O^$IR;KQ;'I^/`4&@D7X=VR'?
M!4(N5[XW'39ARPS32V`M,$46T'6^NFPRY^=G./T:6R$>THY%#6CWP@OW^ZK7
MEU+O`TKGLA+9JY`K?<_+>%N$+[7&TJX"WAX\@<.MB`NHM\UD>-/2>G/1E.+M
MV+F[(06=R$PV%ML)4G=D&U25!':`0@4DZ0@K!C(S+(V2QP&DC]G=1>G1CKZ7
ME1/1MO2!%#LQ(P$1'$[T;"RK]_OZD"&R99\-/+2I04>R"H/'L50<(1*!>BP?
MFGGI\C[H%,XH8$TJ':+_[`X#"N!6)#@YJF\Q@`/Q^#Q#$>1W.Z6&W7<2-D;'
M*4.@:0OM0"B-5P$"51@08C3J@6<R&(,V_,2V@?Q<`E*=7T"7MK-P$T&LQ4EA
MTJIAP(.>`@I*&METV+U,<AV<;)Y=19_700BKFMG@1C/+B%OAPI0P`,.I,6+9
M70EB9=ONDI'K>B^V6)!U']AR36`FLVWN1S<>&)6T!T7B6QBN&R\Y#:)`C']W
M&R0KK:6EO8[Q=`LUU-!@C^GRY@J@J(EJCG$=6WCGMLQFRU#)"0X#66_UXNM4
M434,EUX$(21LZ!2W;`*=C49WG0ZR">(*V712V'IN`QB("&`451SMSK4L7`H1
MN08(2"7J3':S&-"Y80L3H_A(A:E*NZG/[6N$815<G62MYJBSQ5!TYR%-OXS.
MJ_H=140)?,<%`9TM0-P(X]LKK7SL<`A`>3*X)LY!/KN,\_:JLAD4P8#I/L,<
M6!42T7B/+FA6NPF>`T..C%3_OL.&I$^S-K7:Z.H_2.:3@7MR-IQ\;]$^"JO0
M-`LUH4I.BV:650O%,39^F3S'Q7V]FZ1<S7W6_<W9H:%1CFD.(YE3PD-2$F8B
M84.ST\KM70F!\!RW!+QI:26..WL90!;57L)A#KV`]SC*,)@!SG<G-=4E6WJ6
M8Q4LETQLLOH(<MWU8C0]*J^+Y'WD`*#13/VILBE)Y4!LNEMX4(SW\?B,ZU)Y
MF=:M1]_QFI3DX<%$CBP)T`EH'F,K0!0$YQ-C0YVD"8>U]U\O&NF`.!C9L6'%
MQOO&,+MJ7_2ND-+OPY$3PRH13;.C)\MW;)D#=3`KQ&?%H;^:F(^^`H4%NH:I
MHT?J%1W::>/@X<PQ;#D]_5=01OP+M$;[M7*)UXF"?4Y3A(9FE5%/&>;5Q+L1
M$@2N*PMN"*JVG>!WW<(9;`DXFA<IL2<;L^](Q(XL:"*U??M;'_YZ*9/.9$)W
M]*Z5))E\)ZG#FY;VNB*+;+$.C2UMZ9TW&80>J`E!WQQ-K%GFQXP,RX(JG'G.
MYA"@J:F]VW@36O>Q=$79CQKV%D@.1=OYH$D]K]#L=).ZQ*KEX_F`N6J^5BCJ
M]U@[ET6$?B`H#E%?9Q?$6.G0N?L][N!'/&!,T*,T"VD%9;`YC#HUR)+)*8\^
MR4:5D-@!`)KKJZ@*Q[B>@+G-HZ_:Y'=G]Q_03@%)EX64X1E2Z>$HP"+*R#+8
M*K*?'>6#9?PT69:@K#`;KN=L6"HGCE6)=IT<5@ZYQ3YH''L"Q'T@VO^1A1.H
M9!R.,`QXOHOMZTX?@]1YYGF9J#KONJZZ#+5QQ#W5B][[;[`DP0BL.>\A8N,(
M:]K^WU814Q:D095BL8U>KH>BC&S;!+QI"79[8^\JA/37LHGSH3%]<.J>9UJD
M4JTAN\K-I=P``"``241!5-6:CJU6>@PB`_I`7\B/SVK7?,*#]IQ,_37;_I[X
M.AP4--C(=!E(N)0*)OO2NJ[EMMQ4S&H'(9XL\;(4W.].#.)V;@:?.(]P@&[%
M6(I_086+35AM2))[:ZB5-WOX5&B`CCI)AA:/!`C+#Q&0(,;9>F4?O!VG@>[L
M$@`H.3(:>3/E2$&QLRZC&QSK,74K^?Q\^88YF1RY;JWC[1W?*O91!P;T)O^!
MS`@:RG&'I3OX1)1L03<4C&8:6I:E%"Q6GTNW6U!J>K9V7'=J=7629QW=#J3>
MR13X.1H481*TK+8X<P+>M`2[O^&D\SG/&)S:GWO&(V[O8'V@DA_8HU-"QFP0
MVM//L*>SOK"J_'6RZD==]8F6AI#]HD)A=*@[*TJI&X,!@$4EVFZ23-C*78?[
MOLB'_J8+=!K(<<$CJ4:UI(BWU@6-Q8X%/*%[N.\,`6"Q*3\5:U7AMA,,GIK#
M(A6(;8&I\_VB6]6L=GCV+5#&#^0MS]L#N<`B>%"46@O&SP>#8/:V=MA#:&1(
M#:U$GF"*&TPMWC`?GJ%03YVD(V<R)G15A^[Z\Y.GZ*#VCE1U#Q8;XZ+O!,Y<
M@'JP0-"UU$E=+?`'!-)WVWE7D9^`#JCMS=0#=6J&BZ2P<R)$(RR(7K/[=`\U
M&I\H61+VI"78G?0V?PO`ULL1&U-"=?CP]<3YQ=8;*<['4IJ!G([>X]1S!DR&
MORAAH%7GWAD6R][BK)WJH'U/DDIR*/8K=2UZ5,X&38A=O4EIGGBUKP]#U2X`
M",>@'4:MI-F</L"C9+37'>R>:=TK6F#WB)NE^+;8.?"*A+!@A\=%%RS1,#O,
M64(@D$1_F-%AL/:JB.YP<8$)-&"5Q\I8;0F[9&S]#NBC@@WP*QAZU1NO@=VV
MSO#38-=K-Q50/*H!A^Z[4*6@3V'GTX]T&\J<^TCRA>-22&=DK[Q!O_,+)X6.
M$W,ZS'#[I746@$WN$7!2>OO_S?@F[>]AZ'>*]R'G&!G:<[#=L$YW':`F6ST9
MWK0$N]U)G=/?[;)*348/%;CRA?S9!)^]Z[-;]WBTGJG]E=V)L<)I@CE<EF7S
MTD?.ABF(6R=RPP2W^H&;C$"OS1:I\\**%5ZUP$4NPKBJR&X9,8DFQ3%[VU8Q
MRNK>FS6!]2/!7[C._/0Z\%7V.U;U=1LO;$C.B[X(L*<&(3+=918ZJ"O+1;&A
M,F0`L_,+!&@Q"9.N+)B0F1H=GYR1>?&E;N-CHB>-,LO4=WOI9XU6[.UDC,SV
M0=$1EKKR'NG-Q9T"0L<SR[[M_&R!KFGGL)KBQISO<\BY(R>JU1TRA.=-D=<#
M"X;WS73(LLEKK55`_"M"05<)['=6NU5V?`'*/:C\F0QO6MJK@#+[T_@,6X)C
M4[;E,1M62S!$?;`+AZE@_`1HW3IK'H\!*P;-,.)(1EC*<EO$AXU8UU'Q=B=S
M64[,CQ#@Q66:J<2\SHQH=R^88QU(@QI.@1,6&PM'/^N%U)0+Q-8^4&[++6Y+
MN-W*80K/OED!AE+T(BP9("_S$1W`-,3?L91&DJ2_$5"'L$"RJP+(5J,#>AN[
MPRGV/;_6=]@[+X?![<$8]L0M,#'^W3%_S@9TF4R:BWF\(AJ)B:-SJ=.1Y>_L
ML8^1)K&GO"+[HM.^\&[)R#?(N2*L<Z/![GE*6V+^,LOC3@_AK@!*,V:B[98A
MF``0]'C$;`O[CYH,;UJ"UE=]!^,#KW<>``$YP=BEAO:,FP[X<:\M'M@(QK-5
M7,V)I?2"$5DOJ(^M]G/A6U?Q#&AD%1]N^T#\7J\&JBVE6W$1C=)X4G/52XJ2
M4D`.&=ME`HW2`RS(K4(:/%7],\/_P?+N[*76A6X%C>C%U5N#$/0A]F,`T0"^
M*'U&K>HH9J&M->AU.SHQ%H_<H9HEEVH'MG=XH^F4.$/-+E;OFN%8I;=[8/!2
MU]FN6$,>B@X>L)MGKHN*?=Z=+!5)JL;^?AR<F80]/:N@C_@#&VZ'Z\(Y_Y)*
M%<`'<%[83J6280&RV95!4!I]EV>(B1"6TBB%S=*N'#<FS;;UD,[.C+R;>EEC
MUY]BE,3G5.M<U[6LZQI&X"7@3?O[0>X5Y>H+$)E7$2X"75:77#'5I*H0?ZBZ
M#]Z-T46"&KR&B0->-;=0YLE,[/1G7Y+ED4W%,[Y0+``NV+12:*6N>@;X;>EF
M!7E;C1%4L^"=[?I\1`QF7<6`IA22_MXA"P<!%SI(FB+9R<5?08I[!>K0CZIF
M(&T_7%@"_;'&SOAC]$Q%$XEP,N=9C"S8GDQWL,&E++@=VZS[WQD,&(I$(LJ%
M66PWK_=[M;`_QA)$=]ZS_57QY^)O&(\XM1;Z["D^HEC)\'P&A^&#?V76ODJD
MQ1M.XW"<STZ_C)2@HT+&40=$Y:C8<`A;8*&SF^/-U6(G`,J)*DT'TU/(1"EE
M+48-!.W$O_8.(YM!9:SZO]]5V+FBS@]`76FC/)+T[NOJM^FF[)*`-^VO-^`Z
MV_I6&1YHI8#QM00-QO=DO*0^[JF![FW$^<E80](T]'UNG_V(V2:]S=JJ"F6>
M4L6^(KZUH*1H*:6L>XUY.(1+L5)5,6@:5ZLH-:MV5(O#N8C*C[=DLQU056&Z
M4EBI4Y>3Z\DV'IGC$K@O*`N6PI5G=O]B"/IE>0C@<W4D?6U,I)/_SAK;2^8+
M6`J/[#QG`400@SX:.'\\B.?<U;&#191TO2VWLMR61SGK</0%U+44T[_IAGO$
M7:Y'N]=)JY)S1:-#VI'+3D>%X\M!O"U[W&MF11J8;6.^:<;?N6U/U_DJ`?3W
M\BFH"&<X=>T<+%T\!AW.(M-J;_M\NO^';*XXYG:["<WLXI>:;X17JV)!J"=(
M+V8=U2R/@H&%JP6&$1(Z=H5Z@%RU([4Z-T9J"43AR.Z5WA+PIOW=[.ZW0]\&
MY`ZQS_5"`Y'T0B5R"H<IW/1J(1DF-CSV8#EL)F4[^ZTSX,,F[8E'5DN0N(=E
M673R%SK-Y^"!O9H69'**JHB$(YYNN6$#8C)[FNZ6<W&73PUV]U`.[!)C<MM\
MP1';;'?5([#;[>][GUE0%B[;-<K)-A[),!NZ742F^"$1MAS,YD/$'N6^,9)*
MZ2-8^FAEPK;G6&ZW<EL6\5PH]_O7IJ=9RK(\%OG[P7[*;7.42*K`'5XP(&7[
M]7;[*,N"$WCR!!P`RK*]*XS2T$Y95*J_H]H%6+"4CU\?Y>OK:U/CF,T(D)"P
M-R#,7Z#DDQOGG>$!^T$16OV-%5-9S9<5C***7\7`VX$H)N/O0F@0AO"-FJF7
MSGSM%0C9':U@3+?>]!Z#'X99,R[PX(GYP9D8VST'PPYF);V(H<7`!\R;CC7H
MB_VJTMBB0J6<QQ/PIB78?2.S[&Y/CZR5,U^H7&61D86:H<+F+:]EK?(K7(]\
M4$_15B;KSH3;=I\"K0%II71G#2@&R@5Y@\BG.+V0$U!K3=$C)E&*G3^$+XT`
M%H+88S[BC@_I(VPE@RLR5OV\+QXL");V,0<*0+E]W/2V[.U6%^(`Z\IUB)8C
M!Q!-%%OANI:RW,HBXK$_/GX]U#KV]MF`[\KU`7REN#QJ&3E?SP!JF$`X`;>/
M$T@L95&P``K(]Y6352B""S7J6,:=;5^6I7Q\?)3/S\\CC($3(/-T@!W9$-AG
M$?W4%?:03DS`>^X.$3`R.[A_/]G<T^G&!NS6;9L:;/O2-)",7<77MNP'(?N2
MY)]93;=$>S^,7@"_=(PV9S$HFJ><?.G?R?2!G=[<\RU&ZQE.5U1S'B.L8.C$
MG",BO1TU#UVC[0%VZWGIS$%@J#M8DN%-2[L,INGGG,3@X!G87J?P<HC2;+/,
M>XRMY'79P:ODP.*A:CZV&Q".EIH$EG++V2W=/`IT@U3AG455F\<XP>X)-DV\
M:X'2ZF1AN:_WBMUSF\8P.ZT^)5F2@DZ?H@8AW;8QB-K*YX,B<8@0)9;/@)F5
M%*"GAIK=A76[Z+H^$DX>3*Y<X&^*B'W4A+B593E#+K[N7U42D(W]=,<3SAC=
MC]N'RVC*3A-ODWO/"]T'W"R\VKL#>(#>V^W!]%;]P&U-!,ZD<"KAJ0M`E^<.
MJAVJ<'74XQQPV&C25#>)J=T=L"T+RK)\"&?S$9>Y)R-)7UYZV`P<'8/+??91
MQI$:AALETMFN0[BB^?<$ZJB<)X]3I2ET<:C$`.5V^RAA3"S/>URYNDZ5NUU4
M3+$T=(JT.(4M>_DK*M#'%L-P0*H-M6#%L[/<[X\"$SL9PE".Y2Q9GX`W[:\$
MHU-NZ@Q#S`Y%B$',.LS(U70G1Q]N@.DK2WG$=-I'9.<^1W13QVEPQ6#`:FW*
MDK=R-D:)X\A&=$6W-EANR[%U7K:M:QWC5GRZ@*/EG<\DBR-??4]L\K0VZ65X
M.S)*9)0*KN]/(D:+6""*;0BHM]];M!T,Y_U88#?;%>[W!^`]'@?P8PBW$!0L
M*.1:%BYE/4HF.^2.$*YWV>[;`T![E;(HHEE]`#^B8<U!?DV"1Y2/C7&^W^].
MH`B*6WO1)CVQ..QLJ2@U*]FGDZ4D*-V"=-B;>UD#8S>85H_]V\=-Q*D_^N;'
MLI3"1SM\?7WI\"93#`51@IW3=![[>/83NU>CF40=;^Y%O4;A/3I"F$'P#TTH
M`$LIM]M2RF(25KTDXE7($;(1$B/H85GSK_X*#[K[=+YM'/3(6LI@FJ['"`TS
M`)6+PK*N]^.XM:P/T$NK^ZW?0ZHTI/WER'<&>`T<[ZC'5,-]MO`7!AZ!E@Y$
M/)%'P,^MA+%ERSN@UVW'<)UF%\BSP9]5(%Q.U%X)6=2LP=B^>?01U%9Z\S0J
M3MJ6`D5YY'#Y%4!H='?W2;H(23:::[!)D9XZI:37+^"\/T>>8/"UZ[2S<I2R
M98-`HM,G%*`4[W?=8F<7+/W"+8+U!I:R\EYL80N%^<NY,0TE';64Y79S66F&
M"@5\TR14.TD?OSX><DOWU2A3!'):II!%M5L#UN,6^F55!4FHT^?(V+>BP4D2
M^%8;/P+4/1S/VQ$O75>?*^7V\4@6_/KZ>K![BB&FULD^27;?X75]9`H)-=,7
M)/J$W/D0Q4X0.##"<?**"2%(MK4[&\OM5M^7`S@/=M>64J0_=U2.N3=G()X<
M#`=1W"4K7-O*(8OH':`BS<H97U],'UP/?K<.-Y'=(@%OVE_&[E[4(./$(?#9
MNW!RC<Z/-AM)NP_7>[8>V`Z2A\^L_QGIH>(5K_*WJKK$]@:C%-OHB\X[01##
M[VVN\IW3C/MBB-:1J^,D,9CH)4L3@(Z!UGN7";V"XFV.KG>K>4F_VI]H`VSQ
MCEZ,I>?/->^OBF64%=ZL3F\-)K#%RK;;FV]KU=$)Z=>O7^4+]W+_^BHKE1Z'
M</O.<`6ECK&A$:NB)X&=)5\A@:[5)MX;5N0GZ*0S3Z5+)Y45^K):1U(@_&EQ
M!\8?OWZ5CX]'"`Q9ROWK:XO?9!4'KT&88&1IT)H(I6J0M=6FBB6OBZSU8IP3
M.BJVDIG6$P"4G.%RN[FA)O6PP\,Y$DX>:9A2QVVRSH+=$3!$;SA"W!HCIKN>
M2@K;<POYO]Y,]TBBK4?2H>ABY<=1I(N>E=;2_C:P^T9RN/*FX:O.M/3,F[-%
MO[)K"&8QR,R6.OYM9R?+#.!@S;*:2O%S-PL<TELCD*%%L$=2\*_I'0AU<QGZ
M-5)^[03!/-0R)&1$E8PVK@KPKH%5R\-SVU:D<TQ=PI1U,2;Z8/>L((4)^&D`
MA67:I)"'J.KWZ^/C-S9E5#4J*&=GVOOC=BN__OOO(4FUX&"J;1REK+CEYLM2
MOY,:D)U)F&&1,Z#8D@@^Z&%5-OET'$_FDN54`T%0V,UR"7LHRL?'(QQ%S\D(
MM*!M^`YT&`>='14SJ<&T)623V.['*Y..>!*>\^MM6<H1Y\`B_M4#:%WO5?PN
MS!Q4?Q;/6:H@7(DK&4;U02SY`4HG%4H:K@0)>RQG.6&EQ.",(NFL><M9,KQI
M?P70!3`VCTR4+*7YHA9=")A=3ER+`3X-E?3196NO`OI=O:&`3AQ4M.@537&$
MUPB8//'Y@J6IV3CZ,+\#OT3;[5Z2>B@/)67B*M>A?NW@>WG'D%D1<7[NAH%S
M7S*>U*TU(L(P9!CP[;9TQW'5Q&)78(^KM.$=-JQBN3VDOX!7]A:X"A7JH9V_
MT<M:%X!`.@8+4/[[]>L1^G&_EW4#B<L&!A[)>\4MHE)-%YQAG>L^;).YPK<%
M"C9/H^['U'$F9ZTKB^?S*N;9X"Z41^SO_7ZO]&KEV%)]$G#EQ5#\$)PAKTN,
M=_AEP>JIDX&2CW%8%BE=V*G$<K_?MQ_7X%X]/AEQC42UMH[L+GKE/1I-VM%(
MW^>=!7`=-UAD7&PI%7WB!+QI?PWHG2;"1C$R([JD,S$^@T";B!V70'SOT'.;
MT2M_J4'0$6='EOLZDZ!4ER@^M%W+?+:AM_7V*C#HA4=;_4H><E+UZY+]QO-/
M#IF=+9M^5/_M8HF0Z>?>X\?A,CHP?82.DZ8SK+VM71*'Y-IMBU%LU1NQU:EK
M*3RQ2IJF0-E8P5\?:@'UKC$\?@30WHM&/#1\>80$'&HC>X*<U5WF^)RVLUT?
MOWY5GR_+4K[N][)N26[TI@W:+6@+:'3\+X5TVYG>%E>2L_>M0O*ASU?Q`YUM
M+0;U1;`L!<M2N*X%0%G7-8X=/9X%X?BAF%_AMG_\SD:<]CI*C8&[>TKQ1>N!
MO)5U7;=<C)IJ0-,)H@ASL0FB8]G6?E*:/Q>IBFG['.@^_?;\M^7<5<!RO%^*
ML!0I),,B&5Z9"\$$O&G_"B(N\?Y-:RQSF/080I7S.UPF(T#HQ(['R#9"-*@!
M[S$7A17<!"-<&E6]PF??J^&(X@6`HTF*8U)LD5$V.8(='T&S,:TZ2,.D3G5!
MLG&D#<O>0QN(`3^&I1\>@NI!HN<<Z9<GBRMA^LZZ+.5>OMRP!AN+S,(&^-C!
MKMZ.;ND;T``]R;#:Q*,=E#ZVP#]T'+B7Y=YSF\1W5G*+(5U/I8^B@V+7<FX_
M?WU]G?>!6@JP4@P(WH_7GLOM5GXM2[DOC\0NL%T66(7*RR(UJA_!:`K[LTH8
M8B3F7;EQ!3C]()ASV''*K#[VJ?+"EDJ5XY35(\,3._!B2*L""QY(-J!7^FA4
M\Y[F8EL[$7)HWN]?HK")T0-G*?&>6['1'<5RI25(NO.=41FASX8S8/MG_9Q[
M",_^@FZWY0#WLC'I9`50L-3["TK`F_;W,;L>V)D!NJ@GDR;QZA5ZCY)CCP'J
M`$T7[(KL"$EG#8AW5U)7#N#R=&GW6#')WK&2`J.0"$,UF:+#E,HV]D)27-W9
M??4$J[)F;-5TA\^^VHH\M*?M,NAF2L<`0)5;GT0U]9_;G5;VJ,,]!MOB#(9$
MB\FN):Y\2:Z]&EE<@8_5`HCZ)3\RT/?J;@ZC'BG74CI?,,415-$5E-O'QR'S
M5?>-QB`7B.;4K"Z%]_5@4UELT399F*0^]?U^+^NZEO]^_=K`NF6EVOK%*'&,
M/X`M$8_EZ^L>JGQ$X0AU^D%K!P6.UC'-`*MO'I;%VW3!SSC>P<J!XLYNM]L&
M\D7RFE.(1"68N5,$.PZLC4S7(-Y5)V![N:&:FZEBL+%I@O?6K76];PX7G5"C
M49J%G26.IG\P<$*H=F"\PM7.`*LDZAX2E8MHBPT$?]S*LJ+<M^2\PB!86BG(
M/'Y*P)OV=P'=44:WLQ/,%HOK*]J[F&1(+<L@4,`,6+%-I=6%H*N,H4W?T7/'
M'53QJ'*$#72M6[4G!F"$%8<T5$S.9-/6<5WTT[X=$'XL$J..3;$A%89,#Q8K
M;S&C>$\P3I)D1BS+"T(P7SRRA_=L<^Y@4E5]*PVU?-\)`GM+6Z"$2?UL7E_5
M/_M7@'LUW3-VE9!FC8+2*&Z[R7=]?GXJ(+6S?[]$O&[M7$;0NG['C^('=[%U
M;-6H!-/$<Y>"%"TLXC?_]_F_\NO7?PK0#`F@H9_5^O'QZZ%@<+\7+?\6^4E.
M;Q7]#('CY&^&M3AZIV`O2[=.3R2$L_]\6V[ECKLA;RDDRQH[7GR^4.,Y!FHM
MVZ8TEW&N81IBKZS66PN_ONZ:F'CE6ANF)W;6S^JC>AZT/^Y`]RPF<<8Y*^"\
M+.4##]#[2-)C[!#+<9'0*>VO`[LC`#=B@#GH#P\H;5/IXF#HWGDLD"7PU(TH
MNJ@$UJ3!6J@[DO0LC_A:XLRBUC2I<+TY*WHL)G6OLM-Z2AA9K4DI35,V<(XG
MXE;KZE6FS*])\_"T,[4^K5G0@W:VN!4LY;[>C;3>#G[7Q_:>:CY1.&+$VW"3
M9W!L^4&!7>JD,WH:MVQ$]A@&GCJ64_':9/G\^BJ_/GZ5([S5Y8+B/K8LRP/T
MK/=#V_-CN1V%#"S8/5PXY<7H2>"(C;S?R]?]:]M&;<4D&GFEO7UD<J+9:?G\
M_"S__?=?/UG/;/O;L`T84+M7)CN!MYXW[,:4IPPBB[P08SL$J@P:J9T/<URU
MU8^^%G8X;6%G>3\KIPT,XIG=L7@R^6XYQ.:6GS\>/%WHP-57LFTH6_QJ9YWY
MVD)JK%L9%K7H:.C0BC^&GKZS)1"L!81>7.ORPGMUP>68?Q$4OBF4NRT,F6:O
MI1/PIOTXL.LE5`T#TE[F+=H@<!141F`@$G2(.*<ZKJ^61=\93I3E^`Z<V+DF
M`#:3DTP"@(!OT5:K);T14*HHC?*5Y)%Y?H(%!#$#`I2L+.6V7)-?IF"+C\7O
MO@&7Y8@?LS&A!P#@H_0I=S#$#D`3Z\%23D=B9PXM,WM,YV3YNM_+Q^TV%N+0
M&!-5&5'R4::W6(W+4Y]YUU^E*>[P:#N4N+PN11O#(:4W_FTK$XQJ<UDIN#8>
M#:(02"D?'Q]'$MP)&)V-:R>X\AB?ZUH^OSY%;&XYI;,:\=%2BLOJ@DO@NB=8
M[:#7^]PRZA;XZHK"$(S?U^'(R%T'.`.@D@S;KF,3W^AY+3#W1I7VY?:'D%9%
M>4HYXW:[;2H%JUX?C*15Y-RK.%>SJZ3FM<8](BC=ZXO8M@L(G8G!A@878^]1
MA./N;$FRFFOAO`W_&:($<`89H_)1Z8?-B>J)T2*T[W3L.SYA>?OMC^NVZS("
M`9`,;]I/M"&PVP*RK3D''?`;T1NHF5T%:DT\H8R/I0&#<!A&)?I-'[5R*ULK
M%_T0(73BDD%_PB"\M`-68.0`W<7&5NIRO?NY[ONDM<W.>SQG'2.JMPNIIO%3
MQ-Q];V&6%LNZ;@O\4H[RE%Q9N-X+[UH6Z&273\!RO&]3^2D&N_N$_9#;V<^Q
M+\Q*,U.4(RYD69>EW(@2[L.R-P#.9[ZO:P4.2+][2X92)H?UMA%(!VW++6S9
MI]#;H(E+_>[,*A:4C]NMW*K,]CD@]2AC^ZD++1QZHW7IV1&&J2[[>TI)W>_W
M<KO=JKCM.K:=?B4RZVSOQVU]TYTSJRH*/'X^KR/`MX<0[6X&=DW5\R4?AX)-
M+15/C:`JX2L=8=...^@]PX&*6PC"KB%N^6IJ5T:%>KM@UKQ]JQI"HR+0[)78
MY/-N`O#6\5]?GW<!=IUVI=$+-A7%:S!<YM95U*%H:L/431KVV66(>":9<Q@N
MN^O]7#><A1C!WQ/PIOTH=O<2T(V"S4;"&$;*=)FX^Q8F;BX\<A*-DN`@MNB,
MN"DEH.1`V\PZ&QZCQ5HN:%\`EVT+?CT4W:FV#N7"HP3%]R2F/09QUVT]:!@>
MS!F\YVKM:35R'(\L;\.%K!LP+&8B7BN'@+%XNKNMN8%M`0Q*Q97J&^?*4I8B
M*A3UMC`<%V7=&,"]QZA+L&:_'2`,.`/)R::2&JHV,[U(5P6GGFR_1*`=D(^_
MW9:EW);_U$H\*U.W;NRH9(Y8+;X3(GQ6ZB]X*[MZ0Y-Y&V0_=T!,[HFE#C-L
M@9\8?W9,VO'I@7>_,])HY@KVT0!HX.&H=.=\63J9=%E"&S]K0Z`\N45_BJR]
M/YO4:36"M0(%*P>!EAR!W$^1D_>6K!:@T?L69N.-61M5</SN1"EHK6*1"S%(
M^E!FWFW?;12J<]OY$<IP<QVY:AG?=L/N]WMS[I-]3L[I"7C3_D9H7)JZN:5#
M_O28W6BK10BLLP%J??D=B"07A@PM1!'1V#&80*^#QT1-P=:BNT]06^),D=OA
M@<@X-Q"XW,ZJ6$<U,B+T3GB6F8J3";UT_VH10"E<-8=H8V\''`DX"Z4D@=W^
M2A9=/-DPQT-,#+HAU8\X5].+G#ZG%`=L@`%/)T$_OXX2?+!ZLG1T_>A08-M/
M=,)V#PA+'C!@D5`0;<68P7Z_/T(8E#ZN:/LJYC>62A!,U'D\BZ-I?,B;/4(;
M'CJ]4.QW2VG#+X#R4&J080U5Z$+++P1J4`NKW#*,^$,7!H*5W4L\>\SM3)B#
M!/O3),D$CR*?#XKI+G$8G%.2OBYPM*T%"\Z$-9L01I:OSR^]D]0)N06BS_6:
M=&B#[Y&\U-'?"D#:(&I)IP=EB+WYJB6!Z9U"ES,WWU`3+-3LD3&\:7\-LQM)
M%X7,+AL`!A.SGB[H78?/LYQQ=(T%$B(6CHQYI'W;EBOU'%,TLU!5\4'IJTX$
MS^\I$9RL@9YIC[C/C2WCN@H>SS("T?M>"\M2LPT*ZGNBM0/IWL5?0&A8OA-D
M#Q3,XYABKJ""2UA\&1U*&F<F-SGH\(C3K.O#H>B!'P:#0RY\WB"KX],QY)">
M59V,$$40M^[2Y]W!ZD,\[HS9U]<&ZL0UE=*%[NNASV@*+TC]Z5)TO.L!Z#8=
MU?O]JP`H__WZ[V"T'NS7[GST0>L.(I=E*9^?G]KAE&$!'HJ65.6^O2R<([=H
MQ%&]3#X;^_($FS;RKU^_?-X!:/(3,"ANGZ=NRW(P]/9>U/V-`-H(P]-([[6D
M`=1<[/=]-;9+V6+U_?GXZ^NN&/G(H_!W5+QN:N::346&IN?JDAVT';S>G63L
M7E9<.M>R+!^5$F5Q^X1V$^C-!_"7_`2\:7\%V&V"C.`+89&"7AA#$#H9):ZH
M+<7P=#B+$#0>YB%A]=`GY+J><:R4'C`5X[PLJ`/(T&`[[3%B,5F+W*8U[TC$
M8W+SPLD81%'%^PF@OL708H':$I:+C%SP]DIE[AI+ARZP3`NY%0<X62RJ^%/J
M)"41X]B4>_**8C@5K]1K4<P(65L1(0``(`!)1$%4*_+B:$="S^^.!BA9O]\C
M7M@96U1,\K;@N=@`)C;]W'60,<HLSA8O*Q1PL)![:5F:S/DVGFTPK@/J(7N"
MU_V^%E?6R4G".OZ.AL=M)QM8<>]BXKTAMLQ9_N___G?,"_?[O?SZ]>LQCJ?(
M593__ONO?'Y^/L!\<4(3;!]F+2@EG77)NJKI0SK$%HP%[XLB074G!6#CB@.@
M7-C078V^)P#Z5;!KQY/JJ^=THO5U)9,)383`E`L\BKJXU=4>YUS7^Z`S?^8\
M6`UVV#FYV/"5,YM`AWE1QU+3MK'=A3-.B:>\P,>:=5NHM-=MJ-P>'J=";;PW
MZ.ST['MG2T*JM+_%0E'L3FV*\(]6LFRX@`5#F5[OMJIM90])[X3CL>#H@5TG
MIIQWL'HS1P0(X3VG8>^"K<V=G:ZE=SSI)VAVU3"IZ_&<BX,C<'CZ9XWY@4X1
MS8U'OLYZL+LTHL4TSS_JC*D6,.RV&W\,9[[>2]06G?5OP[Y=7&4N\M"L=-:B
M#6W9^.73:_$#U$]VG.Y6B7Z6=D$!OT^U'Y2M'9F`>9=][//S<TM^V?JN%#IB
MO<NAV&T&+]J+;Z:_'KNG8*DDX3X_/R_'WO_Z]>M1BEBRHJB5(TX]9!U6`$=E
M0LY'$%4!/,UF^2_+(_F51:@0&-9X/VZ]W\OGYV?Y_-__RO_^][^'8[(IHM"?
M'NOW[L3K-K\["'UMM(<=LS2*@;1EI$W2G[RC5E*BC4>NO'AH@'<F%;/N?P.S
MEJP":-M':4M7\G(06S3:2?+[_+EW=(9&V9W+QQSMECOOO+,=N"?#F_9MF=V1
MV*TIK[SWIUZ5"%=DT<R`[*6T./&'FZL<SF-*!0B%P?T^&+*UU'I"Q4A%]%!_
MGW&'9&A*K65+-B[@:)+15$TK>U@#_+"&4B#*3.K2O$//"`DP45A6=<\VXA(8
MTU$VK:!9;Q/*H7H"]/9P48P,U0Y`&`^+0)U#DBX<&!-"O)0.4ZH70#C@#2[+
MVFJ[LT)8<=![3/E"W?0P,?>0'/O\K,*'O*0L)?3$TSFHYBE'KDR.69V\:G&G
MVD(XS[V<?>!^_RJWCVM+]J^/C[(4E/]]_J_N.[1)D(TM;A8?`,M1<U2E"V)I
M19M]?'QH98CMJH]WH]_I>K\?[Q]'@0(4+(N69+O?PSX4R2=JV;$ER/H*IA0&
MTXT@3/:V@!@WA.X5".5ESK>R;LY9LSB@"@>"1P$Y=^M(FJGYG&:\F6H]\,:K
M&:-1?21'6N]\=]HIX#KR'-'81P+>M&_*U@[(C]E=Q"L$",;72__B3CS7"-YF
MQ9W"]X`-RQR7W7P<N%KO%Y'P^\R[<.2JK$-RQ*;6<Q!0)Q2P5WJ3C\EMN>FP
MAG-N?2QTZWV=?#(G?A90D@N>]NEL\LLAW%]A=:=@P%YFV`E@TS)UJ))3W+"Y
M*#=K;36'(QBE8BT0!`<+,&%`2]3_K;-4@5TID15UQ%8,>!%ZJ2JT:(M:61^%
M+I2@'F.A,7IK*D\@J/KL=A$;]G."#EG[^W1DJGC4RL%"6;F66TT3=OK_^?GM
MXU8^^'&$-RA'Z4BXU4F*&NS`+2$,4YBAE@T,`-RFHXIE>80R"-9]75<_8W_O
M7YN4V]Y_]DQ_;EK>%D3[0%5NL3?B]8.DJI:D>^7'0"?L'F%LI,K?>)"CR]F6
M)@;J$9)41%*9[K,:<_J1^7'M.X8\3ZFJ'%+-:9Z#6)2C7W1<>*E+5)?BJ&.8
MR>AN].9L_"Y$@HF5HTN&-^W;,KLC`&-$?6LF_VR:*;:QP"W'V\:DN4(24!6-
M(D;Y9/H"H'B,?^H224_8LJ`\UA<_<UKE8DE/?M?5+:6L9:WONU&I\KXMAI*7
M.;B03;9L%4EQE]T=*9%$NH[7#.AE)0A@-2)E0@B55C&<DE94Y>8HJNOY,M-L
ML-LL[?9G81V&)^$+(`A@5@#"?:4">,KM<^DT?7U]'<47W+JL'<9-;=&3U2)<
MA`S3Y]>G(TTEP1Y4/'-+TNX`N!7`@[E]'5`M$TJA6#*AJ2UTI<FB"F!8GBRN
MXJ4[P,?'KP*@?'Y^JGYX^!@N.*VUM$O%_MECY81$H]MUSO/W^UIXOV^ELW$R
MNU+OV>FN\D[630EF9W8/@$Z3*"L!O*R&)[3+(>;JUK2YUO7(VM,:ZSD<JC#0
M^;Y^W3Y,F!"5FH><.]1SK:;"6IPIUB!?HF4G4!BAF),DP#5LL5=CPQ%X">AR
MX?Q15+HTQ3!.SH5UG??M9`EXTWX<LSL*9J.C>`4]3V+AV>.45FV/RBZ!3J0I
M>VN]?(0*!F,/ORPHZXJXI*PC9$ZRW'FO0QKWZG`+C@6N<GQ*$4R/6%11CN_1
MR&5->RRLI8SL?5C6M_M.0[#+.*[;,O&LOW'J%[>UGL-<R\WYN*]WD\5\M@,[
M[D%-O*"CN$&M"^LDRIV?R6I,`6B6,:CD$!LG[>OK2RF<J'?LQ2.T).GH90R8
M_D*?`Z3T#@6[*M]S.?%$T:'J"`GO\V^!P@'*P::?<<%T$Q_/=[666*NQW5"`
M+E$,4P)RUY)=<5?#95DZ<E6"Y:RF!UM8PB$6]@^HV$$?Z'KZXVAHD(R3.[I-
MCJZ]+'J_97LQC\IBC@R9:`?IN`$1L(7B;#T10*U/B(.!=T]($[Y3R9[YR%LF
MTRT0^1C19$KY'FII-)8XD7'7#<^DM;1OQ>Z.``O.XM--I*!*Y'$3M$J=O&6.
M\Q,=QK&6]'AIF5M[`9Z[08=Z@`-VZ_+#Y[%[Z=B5G'0?Y&87CGKG=8USN,S+
M$0M)F3@A2LCB(3J^EY24A^^3]PYX;:P@RJ-"F8ZI;!5<0!/%5<NV"\X:F(H]
MX%57B++WH&+F3.##Z70LFLT,;B'*K[S=;F798I^5_P.M%D`7D?M28L=8<))M
M(J#KC7OVLN<KY"*3I9SJ5RJDA.5^OS]"8%"4LZ3)2)W@8^>#L^!&.QY9!&]Z
M=0C=)SS;H9RQVJ6XA3]*N83W53_``@4R*28?4L]RJM"(C$/M2!&?>LWV.RPV
ML)PB2=\O?B$28\6H(A^,JTPXM0EI%!7G6$S$S+&HP&W':+[GY@I4UQ*A`ZW_
M;(EPFGP06$>/+%;>1;6#VG60S^Z-9YYK8MT3KW6J8H(F*%C63L+<<L1AH['J
MRS_!G48CD+^?-P%OVL\$QY/'P:IWM33H!USS@Y6<#1\M7LSP@^F4B2/U)-NN
MD0P%,.0\(<#ONKH24_'/^Q:93E*1`-7'S%#*"ZSY'\%*Z$E.+I2[<L*#!3SC
MVG;V9U<<>$QT2\Q8ASIOXKI"#RO4U86I2>`M$K3ZE!`[T[W="[&=7O&UCX5\
M3]2SS).W.'N0^_'^;@)OL,11#NV!P0KDE9`A;Z##*E._C+DJ^APV4<Z<[WY?
M'VRB1U)&2ZRI$E*#<HQ,%4&_[(LITL05DYRY='=6](M@^&S`"1`9/J,7=NVU
M`Z"=H;.?4"LZ5)7>I.8`%<`L8KM;_JX\:(^:W$&D\"S(4XXO<FVLLHZ)I!T*
ML0KE`<5X.HJ["&=(`OW24B-BNW_O\=!>Y`X=,F.VCQW_HZ]I#C'^;[+*WCY^
M34Z#]@?HMEM[NDE9LK1OQ.Z^"QJ3`TE2(PL);9&"F7MVLI$H^5,<B@1BF2DV
MIQC8O6$[I^&<G.`LZFR4!'5G1[_6_,ZF+LLBA&/BNO1-$?$%5:4NUD*195W7
MLFR5AQ[/OCPRMD4BQ`(X5`:*K_/E$8505:$DJRQQC\52JDTEFR$DKC3[8;L!
M?-U6![8>(0U#SI^S+7$$NE$X?Z:(10?0(60TG\!>QX*^CB+'X7FD*BI1Z()\
MN25*A][C$*UO[\$3O89JLUK-!#53C+KHPW/A5P]MWWU[O"J:X#B&YQ8YJBX"
MB,@=)^2:AL6E*(+B:HU[^M!%E,=51?48:?!5B8`ZP<X\1`4>-9LJ0[1<1^_8
MN3ICFN6Q7C4\%*]:85U8G$="WVI2QVCZKT&N%LTJS>!Z5\Y7W^10=<?^`GJJ
M?$@">`'*KU^_PF(@,KGO?K^+G8<K=Y(A#6D_".SRZ0,<@F6"+>$8.30'?7FR
M%$`+M$"!WOI<&WMWE"6]<C<29J/-!I7B2E.-7S72FM3G.J5X'C)DAQ294_VI
MQQ0VA(9UZ(25,AK`&0Q`:JM_P](7C"]RDE5L'1;QKW7R&G4C-XO?L>WBU4R<
MP^!&+:"JP*TQN+T(JO?"$D=1"5+$K=;@ETX%*Y9VC#A;68*N0RGC'-&\=TJ6
M,MI8QZ3CCG-,:<`7\W106M1"JUH`6,C?&QK1GJSR@/A&16)8V:UB0"E9L^>>
M0Q12H58242H2T$K/BCP`J[AA6&L56A$\X6H:9-W"TFCG2)Y=&I&_;"08CS`;
MT:U:.%)O+,!9`T=R;LXP-BQ;A;V/C_+Q\>'(Y`F)S\T1_?S\+'=186X4`BA'
MA1G2D/:W@-T`T%XBCD/`X6_G[9-=E^F21*#-G6K&V.J3G-(TE>3A@P$]V-<&
MJ=Q8'1$LVV&R7Y/S%JRI^-\.<+B>S%&=I6NV<S<PNE<+H\G\UXM7E'/L!(M0
M+UI153R*23AJ6[7-.M%5/6;>;A'O+$??GT&?42VF`P6B\*-@4RWF'C-7/;=.
MK#S"/7@=W'H`\GY?]5:P*.I`RFUK*D>,15<K5%N\M&._!73MXT2>=K^_W.]K
M^=__/NNP"@X/].-21UA2(U&1/'5W%3M'N!>A0KW"64#='RH-;^@M:](+E6A1
M#E#X'X/MBD;?D5O^).L=FPCXEDTA8B<@]K\)5E?-LT8CV/Z=)RTKW'4H7Q8>
M5A>%1,Z"(CSG8D_V;63X-R)KCNO)PA%%1\LL>PC2-I^C,\]P78U"29_*0/!9
MJC2D_27(68/)NK3C!)L+!S.U2EDZ7CY'5/X-D*HT=TO1<CG%E)<UIU[+6LJZ
M:]2BSKNI=%[1`8<(*[\K]LDLLC3[@&K;7H4JL)!?*CZWN-=Z@./;%GNZQ^Y*
M35YU_U7-RU(\#8,CWNY0"B@=JK.46D22K^BV];IM=U?WTL!<Z[*V[GN4+:03
M71Z@6186J)/@V'%0(^?N``>`JZ3`"HQL[WAK]ZW<B$24/OMC9,TB1FI=[Y5N
MH">\514I=-IR+V%]LM-T6$0>0%B6=NU//&T&>7_,KZ^'P_/KOU^ZZIEI9*L-
M8AW@V\='^;K?"^\\89`1)=^!?UW!L;AA.'K84=V+G6,.+0&N9V1EF(1G'&I3
MKII-=V-@RC^2]M@E9%`],UTE+958[04PA[YH77FN.(Y])TI+M=M9=IU*&8+>
M?3N)U;8]T)-]+HTQORT9RR*I#R-3*+8`#J<";0)K-`TG`6_:3\"Q97#.<MDS
M6(00X3SZ%*?+;E(R?N=`/3)K`Q5SO71052O?"1(6/WU,3_'^0K=RW>+J3B_:
M;NL<,:O%U\^,X).]F,J8ELK^D2J[K#-_E#TN!;PWWNNCC5:NY<:;8A+WAWG$
M^"Y:S[33BU0BWH+R4$X[521HYV_X?]`E/-L,*%RJQ+0_BP^>6+1>;T&PCVD'
MA-YTO'_=S]"!$L5U^_?=`[L]J;*3R?,ZABE08M"K!`-[K.29](2X?ZYUA#EM
MG&139QF-YD'5IV!W)+PQK,I(^Z-,8R0HT'N_K^6V.X`!H)723=%NSZ^/C_*_
M]?-,SC/:MSP\$:M3'%<G9S1Q\&0A(`H#'!7'Z($FJV5<CXUCAF_H7H<5"!VP
M!VBYK(8L<7?-DD588$B2O3`-C%>CVD;\_.C_BW(JZ[9G4*Q#[VX4H-"IU]/2
M#E:`DC'8I(/^+?FTKNLC2<W*[WF`?IN?EV4Y=K?"Q7]@F4_`F_;GP.QD/$[K
MP"&9,IN"VD)U<A`%6?O5LSAEA5N3B`9*-$`=`5#S3ZP9A7(DZ'C,PB-3'UIJ
MR%DV>YM(5%G^HHK4$=-G0@WH$^9N5)V2WGD49-B5&4C-UMW7]3&)?GR4VPT-
MQJ/-L-CW%X%=S0^+[=Y0F5TG*6F]T_.+*Z4#Y+'1I\YE-T[;C8\495>#$MAJ
MT<?)@%=5?='R*Z3:A'$BC9H').`L?JPLJP4=[=+5XEED-GLHOM?0_JY+9ON.
M2;W<HUZ(K59NI1VJ'2#I$,O=EH?B"DNYE:K4KPK-,$4@[-A>;K?RW_^#\O7Y
M53ZW..?](JHOBIV;W:>LVL71-;;W=<P'&]JJJX6=?5X6]R8UG'KH<Q<QKE@G
M;8FV6UF_;]OF-H:8WF2KZD#89%V=,"P3^2S8!E3U[E-/BRRW+=3D\;F,9:7K
M#)U]"*?S)MLNW)TR16Z*Z8^>V'?3K3^=#B]'Q0+R53ALGK-OP[W653@*SB)X
M5#R4ZP:%,\1D>-.^,=CU'.P([+)_2+PL=I*OQW.S.R`7I2'_I#^4VT]N`F_@
MF5-SVKHMG2I8I][M0,2;5\>V:)!_;(VRK@34?MUL1@C(>#,5RR6SO_'(/-_!
MO`?>1O*-=>"@!6D,2GWXCA,#D7YY7_H=0Y71H%BD%$]'EK*@L*-M:>_UD?1A
M'2H$["(/<*=$\:''G06+5=+.P<BBAT\%P^-1:R/]Z'SR^_U^Q.\VR\#2?W9=
M&M@,//18,-E(==A!"RQ#]`.Y^T.N9<%R@,3[NI9;!?I7<7U4;"^=3KHL2[G]
M^CA++8M2O+4B#=R"!]1>B0BGU:V^RG<!K4!@[ZM6&_<#YYOZSG)&A%TOV"90
M*KQG0S+,KL$!WO5[5_5'%#$@G!,^)H/E]LB_B$B3/;%6.?T#;6>K2$*WS/D]
M[#M'-%$]=)L!D^'CCPKNCZ>_KVNYE5OM$)AK[N%L,HS-OG<U>E"T6H^A[A/P
MIGU+L#NXKHT#XTLW&MPK)^\;_K14B\$XJ@`#B-L7!FN#?LFJN;&2$?U-NW`X
M\6;JAD8JY\''-_O$M3QT<E<I744'QK"4];X6X"861`UD-#TIXZ8AY+%$JZKG
MA<.YCCE=7I4A?SP85@XUUO*+XIJFM'E-*\M]72N-3;5DT):&I6'IG%A)3\$A
MJH@@O(]*[Y,LR[;85S6L.M7<O$M]?GYMSA%U?Y?QVI63N5^J!KO40>IUWX4&
M/Y+]AP%%^D7J!#FIUJ+&EPAK.(M3%&</WH2I0&;6T]E9.AW*=5W5F`$L"TT5
M0\L2SX]G5KZF7A7DJK90QI,5Z45DT>DJQRZ=K`)IR81&R%-8$KZ=GU&-:#K5
MP21_L.!1`<\D<E6@%2CTV%8&NR[N5"M`+:DV8$R`M'I^55X8P<Y<)0U7=$@%
M9)]'_,Z/<`Z*\O'^_$+UUD0Q&IJ[09863ON.@'CR`X[B##YY_6*\1A_^-"EE
ME$CHRYR/X_<XEH<'-2%6\5[4I7LM9W5LD6W/3@8Q(!873(>ML$)["Y:R`.6^
MWI5:!@RX>%QN+2PWL2;99RKGGJQAGU%P5$Z*[M-U+,2BKD$5I_M\I/2F,ID%
M^TB[N4J'MST2!"FVHX-X5<OZF(!&%@2L/T,G"Q:T2N80IHI<@0(G$[3N<;^[
MBH<J9+!]MEA&6CH.M/'L1V3]`81]CU,?7U6\`M5,89-I)=AN[:Y0Q,C3W8/W
M)QLZ+I(BH64A'6$K6;O4COJ-#^JAPA@J]XFU@S=5')R>`RX8=7>30$@Z0G*<
MMI2N`$M>=3\U1WGA+&9'I[23IU%*^77[4,4FY-A91^;-8%BV&R\XGV5/]T0U
M6SC"S776,Y9THJ6ZA)1'<Y,O><8<GW*%_=7Y6-=D3H!HC`2\:=^&V1U:UC#*
MJ!FP=P%LQ_JI>WUXME$M!@%>P/0.-(,?1SF27`'8<,K&JBF8!:$+>86YKZ"]
MMZCN,CI`P;*4Y;:4^\IMB[IFTDZ\;JD>X5R0)B)#@CN>8)D3(*O1!E<+J=!L
MC$NV<R_442>FU,PSJS"9DUNSO<CN6)Z)@JR2;8I8H$8<FG47_*_6W#-YJ:JV
MAH&PH,!?)%D^__>Y[0;404-K)95F]`R.D`;)2#V2WV`JD<G-Z2J$@+4/%^W<
M5-5C[8/!2%%Q0/9N0)IL[Q>/V'@1'_O_L_>N:V[CR+)H!BB5W7/>_U'W:KM$
M(LX/$D#>0+)LSYZUIZ7Y/';712)!7"(C,R-X9MF%";<V]C%;FJ%KBB>)')D;
MRGY%5*>TS\Z"3</,^EX%:@QL[U)')W1[-`9]#"`-7FVS'_QE"`2R/)9AV:XU
MQ9,Z>^!DGL7;3-?-*2`.K*Z9AO/F-9/E8'*NV9([(Q^6DN5'P%JU[3BF9Z"]
MKE!'TG_W#7C?K_\58/=RCW81_>TFM5\$N_>H8LP5$WX5T'?`QU,)%IQ%^F%O
M0*`.2T=_28WAC7$H!5(W2!7G2'0S^QRA2&3-RK(SM5U9@#F7`I_+H[-#;L\J
ME/\J\,+:P=DL9699TVO)]2QUGK&V]-<YJ38FCV;#4Z`\>XH,$X2FD7`P<RV5
MB,E"RYLX50/2-"6J>]<&]"XB0V7C+![D=-#Z=;U>+V,YG17\[!BF(4RKMM%1
M#[7O`*2`>M2,3Q4\D)'Y6D@5JH*6J\>[$1JRLJN3G`):D?ES[(SX-HH>.*MT
MOW:W8+KJ8/1K82I(88"A9P'%7WOB&(X4_-$$!W9,<)>;Z`\0`N/,8"`SHTRA
M-P/2I(N%@KN9SO/Q.+33)=2_VWE19).:`_-L5)B`R#;7B.E\ZZ/GFN\N3U,G
M:9=E`%JWWJXX`27UYZ7]Z)J4%=.E'AI\'P/.=]HWX'V__J^`W:L4+V^@(_X[
MK_$2>OOZQOF%!=W!:RY9KJ32^97QN@%6<W[E*XE%2%F*U$,7E*I6[I+559MC
MUC;5TFB[0]8$U*F<-QUC,M^8T[8BT<Y-9^Y'ON.9)VE\P_8FB(>9^YG^?UUC
MK3CI>M3A/I8ES,/YX0T#<+VDD=8CCM=[S4;#RWWI(E`M:>:=J)JL''L1BF':
MK+I'`F#<Q%G75;9U4\H,8JM7R:,B`(&=;AD"QLH<$Q@T-:>:CH.MQLG`;OO9
M@I*SD!)5M;3I0Z\S%I%U6^59/E)V+E3%IF"W'N.VF6N;<[DVJ,DT1&BE#(+1
M"1'#1[U^PWZ`7,XM`[Z`79M=IM!D?#A1^[;OW8,:94*BZZ5YDF8T#8\)F]HD
M]<JRR//YM/NQKY]V^I3<[&SC*0T"\9Z92)WI%"FB]W$X%[W;1\-<([OM%SI0
M\W75C7/8MGI(D3$^'(G-GQ!,SIPQ8F_`^W[]QQE>_B^XOA0`75PIS]C7M/0B
M"OURXDU&U?!QRGIG9!HF3+=1`V#HYO:<V%GY,R"R;O5TXS\-(=HU<:)\D-JU
M)K6$RK)2N*?]8Y3O618&F2\12?K"YTU;_$HPDK+G>\TH[GDL&`MJ63=9)HSH
M#.BCP/?@F?G'V_7M"N1RPBZG-X+X=^J1[2$)%'A,NGW4%:P&[-+`7?I:S^Q8
MY"CQV/$OG#P2@[7J-(2E!#,69+71M&GOSA:'ID985"BC5AF9?^\YN=\;0K=:
MCV9&NC4`$Z3`C#0F>WI^G?W#X2=ZZI'>@XF]O"*_=#C2UI3E]YIG3U,V4C9/
M0WG9/6-*@]'#@/YUOY>ZLP[(=_WC1Y_/QZ[,(&,OG-7$0R`;JZSK.LGFN$S%
M1(LB/6\:0&=^;.1[&D-S77]&KJPKVZ=\9B(V%^]**V0D2"+I?ZP;3*:@Z+*7
M]^O]^@\!W?-#6L1ERW\+R-YA=^_(C6F'RRRBO/-^H4-:HD`]'`"='F`3G!&:
M@I3E8ZZX>Z/3V+-5-='%.BD.^W7#V.`99\9OG&MP&RG-!NI3JP;\=C,.3.<M
MLA,RC2\0F.;VV5/6`[-Y0@7::+1HKV:^KM`H*,?8?,U^D&3"YIX;;5!_,*E&
MW_VMRD?JH:5\I@T\NV\`A_UHC2-(:_$[M*>M`;17,<C-&C"IR[=!$A5+;RQT
M%5/;[K^S[L:YBVZ<YL^W"`24_L>RR<,)F%#_5MQWK9M5?1#?O!H[W8WL05B2
M3)S"U`5U>0>Y-*+DC;V5B@;N]KU(%#Z:^H&ND74+C\;\Q-;C:^OKT?3GM835
MG$)$<CHS7Y8BI1F'4'H-==^EX#1_(2KC!3??,`*R[J:IV5TD79$6H,/5XYPV
M4#HPG_@ZGF*`LBQN'W1T$T4U)S--I/KGS\`V>6)I7]-OP/M^_4?!+F\`S3OU
MNOP%B'7/^/>,K6,`)_KGLB-S)JX/F92JG7C=GXTQ##Q!TN-S?NI<P6%J6I03
M]);89/X*Z$VU.!'_7I9E9S(=&,KFPIVFG\MF1W)R.M"FQ2'!K>R,C.O6U`V(
M5(X#@*[+_@OS8GD\W!E,HWKA?]^#70U23]V7+Z3,3,/*,0B[;NYF3")TB%+I
M#03&=RM%MAJ9:B]@P""E!R?1A0`FLLP#DV;``6X5BTPK%)*X$`?#`[,!=%M5
MU5P8S%$<$ZC68P?!"A##&5YL6YW2^T$``CIR2'9-O5<UL`S5X(5L`L16B^E\
M`<R_[7ON#%]U8:*-`'CM+)@&HPFPU^NQE3G0,L[F9HH"HH`\'L]AHC+;=-4X
M[;76D6#8`;X."$=@LX\)%`/N4X#C`^A$O4W,*KEQ3]:_PG!F.&`,'(83*3N3
MC#M4W?.-\]Q?)VV?PAOPOE__MA=P'W#.OGD'$,\@S)7E]Y?U>UT'J2V4AWC)
M]WA<,E0!WV&:3R5M'*#D#"`Z%ADI<D1XCS,CBDPQ(/B^:VM,=VCU#?NB(0:^
MR"(Y&);ET66M[%A.#D!QSXS7P5(<7^1*.0E[-'MO<G;$,V%R5.=RY2FSF[T*
M(,_'4Z[XX9YN#Z*;T7[Z!@]^/M?5?-D;U^2DDE0,2ZS':F]NL4\(F7`^\_EE
M&']:EE;_G+?8G3+UJ1\)78K6[5NNXD/@VJ20!R7$O+R*9WLCCWETK&.W,BVC
M#M702*O(H"<+$M,1F68U<)0+2,(*Q^"6JH@YR]3H9Q3&!S&H;-=G9DURO1J\
MZ3&!8XWM@:#&)K'0+64Q;H'#07#_TQHJV?8HE#%6WAI;O$F()"41$AGYMO'I
M0"8DTQC.8AJEDK,#"OWGVSZW-/DUS'YV[&'5!-8X\4K4SPHVH#?@]UW2\'[]
MAQG>*R2,VS^*4-=UYV.FD`0SAI.W2B!XRGO-#Z;+B[F'Q=V^1\G+`KSNZ)>B
M&=$=N>;/9-,=<P(3C(3)WPZTTI`E4E".FE91C'9VR$,)R8*_```@`$E$051R
MS:N<4<K^':]4:4QB=#=K7=X\`$1P6<NTMCR3WN2V]OK-KZVY!BJ7Q^-:NSJG
M]:?C8*%=='K*M&\-`\18Y@,G7P21D+&``N1:=HYF'T#*UF;_DTDVHY>3^-2V
M"\X#66S*19%D]&$:T8S17W?M4C:IHIC%0[()/%%M<2%C[<.%(XWNVYXF&9$>
MF)3>3,F3O6FX""+-(@SU!AF#A(P1/4#,A.WS;:@\32W`J*NDF0VH(!GCO\4'
M0#H801:%9\.X/^L].,>EH@U5%H`NJ\([F2?U[WDVL]@U'X+GY"`D36D?Y;H'
MH#E@+DM))17\^FQ**[.3CA<;5W!_M'?[?KU?_TO`KEAV@S<XW4R+#U]DFN[]
M($]96-SBN2*P@:4>\H:*ZTLS>5%;DY<USS%$S$CYM/,'-</B,P4#A0Y=[;(]
M,$Q-69@(*G7,D=;S7&AVP`YD-+]3SW#[9PX?2$#R5FP_#O0`.&'L#<!WAX%N
M[%'UJA,UM7S\`5F69<C2.?`W>^SS``Z!04\>UVAR.^EOV[::,.D#XM`4XN!T
M;<`_GK#F[$&NFW;ZS\]2+2X]GQ4V69"B`5,(!=S/):!CLKXHNY*)!P>8!=1(
MV/54*"(&GAVX3GXB!G)P"EM%=*,B,<EL4.T-0>M-UX4SF(N("A!BQ"6=[9WR
M"!.Q&@0K82N(1B9A,))0&]BS+,_%,+*IHH>[KOT9CQ*JJ'B#L1]*4==U/`_=
MRI;UQ1!I8]I<KBU>[&QFM("NE7$@J?_569;*IL[@FB0GCRJ.VF1VXEW#^W[]
MA\#N94WNY>&MY?9YN_'L/N*^21.?[+$RAP`)8+T!+F^-*/.QI.))F:LP\.Y=
MZ_I.WAO)V48^NZN1ZD=HBO%N/VFS7BBIY@5;/9$1\Z"7N0]]0H)(\+!`MC:L
MV@$],L$,`)V/?U::,NIO;=I6<ZG9+#)N94FX&8(]+XL%D6MR';V!RA>BQ!5N
MD_6MIID*N'HVC*KI;]0B2UP+/(U-;0TS,Z#H^5L)-L7Q=Z*ZKX38-U\GKW63
MGS]_]J:GZ1ZH>[=D6!3;X(])0)SC'$[,"TV]=XCS9S7O:FRUL@$<33Z1)>NS
M\:I&#3X8E5%?/U-F9+;[XO)#O'5Q=_HKB^!H5FMF..ES<]%UU8HXGBW'>>VY
M!\6]>=EE#L[VZCOG*B8-I2*[;?(>:)=>/H,LH7?8@MN,4)Y]F6=HXXBV]WO+
MDKU?__<!\070Q6V<R3_ZV<DN9]Q:INY/<NZ3IIV]\DTEIGM!FZ.=W:MG<7V[
MD$^;QY1?]`6Z,W99CPT<DQ@DQS@#?5FM(24MP73,$"4Y`W!Q\<T>68:C4=94
M-G6`HC)ER.2(%.6AZ\EDHA,9@<E$EDVI>=$]VSOE->0N];/KKC(&7%Z^:7*A
MF6:UER6:D6U6ALW>?3W,%);EH8[@"ZUCR754(VY`UX!E,BF#1'TBE^<L`J>K
M65P=*>`K>>'`$4W#%Z=KW#E\-6UFRF6E3MK,9Q1,Q&A+&Z<O3/P;,%EW<',>
ML5FS?0^J+A<)80)@"@:A]T8J591D[QGF,U9B+30MJ@@%JN%+0I!XDSCA8&2'
M%*-:-TR,(A(R9=LVM:U`20OS)L%$5^HV[G$6Z$\A/I,T33>KT1;V3?>]R+(\
M(B,<&C8IGZ]7UX>>"=P[:66[-UX0<6_`^W[][V%V>8?=/3>BG-DI_#8PAG1?
M^"S%+)A?.XSK4+:!Q*!^`*M[NI^>:3Y0L^AT6J^]XQW-B\P6TMYNLY[U,FK3
M`.$K&G&N>2<\=@W`*H4ELG2S.8",`X#<:GKL!R1PK9UKSH-X$]JAB\K:M;-G
M_:"T=<`%D()RIQS9K,W7:Y6M;O89Z::0.S41F!RDGJGBO,Z.WO!!AMM2K91E
MD4EP$(7UH0,$Y0C1@.;^I1'\F5*$!KI/:B.#88[.KH,F()XULX5Q59'<92VU
M&VNXH(L">3X?9R&`B6.8N.:94H76R$6:WX5$@)N]EZ]9;WN8N0O?L$>FO]^"
MH-$#NLO/!=M;5^L_JF"4KCA[^U=ORH247NH09+)"F0'NN5$B*I*!%`+'=HR<
M,C]YU7JX0&ICC^3Z?+F)V4^0$T4\21$1\^F8JZ^XB.?(X#T>CSQP<?-S7==1
MJL43`YQP_XI@0.*DI^[_7=+P?OVOH7WOR5;A)&4S5A#^\.5!("C''U__-_L=
M*%W(3++R!%?8^LVO%$CDX+'E,B&^Y!2GJ,;4FKF;0V"EAA(%3SHL>/'?AM6>
M":*KJZEDVA25;M5>YHU*>Q5Y72^0>$[YE&ZN@A1`94BAN@.H.L2LFP'[?Y<B
M9?G:UOUZC<.$5[;(.HT[*YS3/P.G3\)HP=P;LQ)F28^1J4V^;DU1=8J1Z0J-
M9I-9,1/CSWZO,VJ`L:86U<QF]*GTJG<:KT'U8U*,K44_=,#:`/OC\3@-\_/&
M5>ZJ)DJA`89V<RR<J#KG$X>Q.U_+P!8G61;]8?4`NW2H>^@Y.U4)5;MK1J`]
M6W^-?J!_A1YA(C"ASJ.EE'LJ.*:V?3O9V]7><'(.C0`1?^@\3"9G<F;N[.YR
M>EWDK@>]KEO?/*:&.,R`NM.Y.^D3>`/>]^M_![M[\V>FG`@BV+TO:2;7AR'\
MP:6BV&DCA)*M809F?YUY3I.I:1,&)SM-5K<WWL38:9Y<+Y+O&YYA4HYASW;*
M58%*WL^7&3RXOWV'^$TC%*WU2=XP>S;[?B((U65#X=A`JO)$&JET>Q^T>J1?
M.+B:JD,[C>'7$_)G2E9[COB"5R?.+V+]!?0<U+7)G?E3S!U4<2F=%YY7DF8X
MX-@9,)&H'J!+1)@4VW\I/*9FJ6E*=@-+R-`U%>[`U^0PZ98T#9KB@R?)NQ]3
MPV[[_;(4T[QHF3HKP@I-W:MZ:(/:?9.3^;X+!DPCHWK_Q@B']Y:]L:KZ!DBE
MY6'<-7Q9!/KGS+1@FD,8DI**$01%7>"\"1GN9V0/5$LQSQZSS4>QEW6KDB45
MIP![<D9HIGMZ?/8UFBO5Q*!P<EW'&SP?#[]:S;6C@_HJ60D#3@@HB4>MN?;L
M=]^`]_WZOT7@SJE,W@7#O/6FOP-T;T6UYS#);)0S>U[>&)\93L/)>_'"@F,8
M&]2OA1SF`F`<B?SSU&`@TS/UOW"EQ.'[_W6Z50ZYFRN#CBM*F8J-Z>^5^'+,
MQCV7?(W,?`"KDVYG,LXJJO?X6C!JV3___@.$J6"'%M1FC#W%EC08!S/.9I^X
MAD<:F]V2Z#)S,M9&%JG6\]D,"VKFDGF#3:1C2<EL]:FGS=E_7R2#<79SC#*#
MJF8$@8V\[F7OA_^AV"$ZN).LF<T_,TP!!2=K94BJ)0$RM<.A)S`UZ\N9\VZ(
M8K1*A,TJS/?SK&H\E;>"15>(D\0X#+;/?JK4?O;\F=1BK=OF:EHQW2692E)&
MH$AW]L;=067V=-G-)`-F:Y['`]J-@(K,RKQ'+%2EUDU-=R?]IFW599)F4+)M
M9R6`;\#[?OW;V5U>843YFMZNS,Z16^_TZ[`VLJNX?@NM69D=WSP'NUEJ/"MG
M[8S!Q+[+?T:M/$\+^=IA`](8G8X2*L"WC9!^@[\R`,D]E[0;F653OO*8,?^:
MLO.DTD&MY,V9?2ZT'QE:;<&;3VT-`+P/_?UPDS990:]'2M>T!L>FP/;/81R@
MNN,[&PLD[E-^"'``,+IG'5C^9+%07Y3D36>&L4?.<PV),*19""])E7\M,JUV
M/5M)*DDR%Y[=I_``]3HK0%FW33Y?G^H9WMQ)CTG0W?<T0#?EYDP890GWWY^]
MUBAFU$G7\P!J\X_.DLX$QY50><6(0`:3"B1#G'GSO@<RD9$3YS"6A>C&A=#9
MN`<@O%_SQ\>'/`[]ZZB>,MH^2?LLMG632J5;<D/N,2J4[-^L3NV`B.>*64=Z
M/4EFY,!4:[LQVP_5J'9F:+0>Y5;=5MM9"S,1*>0\:K#)"7=M;\#[?OT6T/UE
ML.L9FHL?FU8I!1;N=[G=,U>FG1FM5\5LNK[*@9JL,RI+^8R]DRGC8Z-Y&#`2
M7+)F5.R$3;U[=.)*.3VX-?DHW[(Z7K3?ZZ=BQI<!M\3/3UG>!/M;-@@A!3]G
M6OV,90J\NK:L*P/(FNK:9VDWN?O8'J9.D0JC]=IE6&%9:C;-/:M1IRW!MF"V
M,IB,\2B]W-][>3P$!YC'V>G&DP,_,?SP@?EHS,KBG40GN3N=(0&[.-WMPN<@
MV0Z<HQV][)GVJ'8K@:2\/E_R^?J4:Z_&J`A05#UX:,`T@:_5NZ73108L4]G6
MRY@154:-OU)^IMO3DO7ISYAZ!)]4*A*GV[&V%':R9S8P@BVQ(D-0F,G\98'S
M`,_LP3)O$RW[OU_KWF0*`\B=O)X>(_KKI,VZ)7/.2QP:J^P)&Z/KS\4QP>U[
MC\?C5M:MUMH;:75I5WH"^:,P,8U)L8':8]XJ#>_7OP\0_Z'W@8G+SUG5>XUO
MU^`Z8Y19+<NG\5[K,M<\0NGI(TK(_")G&W$+NS,P;H8QH67A)%$2X)2-NL/,
M[S>^1^43(*QY0DTI:HDFSNGSUB0HGE%P!T=O3,*9RL#73*1M]0:4$11<`XC:
M5_U8P#V/228[TX"E42$8C.4.7,NM>S'OBYW)X^LUR@<,"G4R3DV1A#,&'E:/
MER/H:(H42(JJ`VFH7J64T7Q%F1G/31^E5^3F'5UKF[3(K7L]H^AK]&E97("A
M?\I,=P=B<YU>E6">N>DYZ=AU7>7Y?$H!+G1L8@9F69;>&-4-)F"98)O>9HC*
MJ!\LSA4_S-Q!D^<=814S+30?_+ERJ33`R::0IS]AF<DX/0="I+G71#X-L!KE
MBNW\JA'3NJ[R^OSLV0AO&@%(F%!:%NQLBXC*&3!VT5J1:+8_:V46/\:/99&R
M+)<:HTTFL5:J0,E*;4+I1^^2A]/5G!(X>@\&WH#W_?H-=O=7%O)703&S%O^O
MX9<;<'HLMFF%7M)\%6ILE>\X9&R`U6N[3NUF\]'9U__0\8UX.9KI]ON!-V;5
M&K$<0.5+H8`2+5?I.*-*8=BMW%*,.UWC'@6.U'8YI+?0F93**JV/*@3R:7WE
M#,SGUA&^!K.-ZW[@#&>Z4J``$WKW.`Z@T/Q\.I,H[``X&E@@5.FP/QNJPWP?
M\U)P.UC3.*J4(H_G4^JV9RA8JU2IHIVQS(D"56,KB`A=.P\B8TH]0$.<NV64
M.SP_/@P8YIF.G'O,3;E"MLU(806##HACW6&0)]V]W5FC=#:R=&C`&.1XFU;7
M`4A::2ES8*OWUT&8F3Z4W,REWR+2_(/NHM=RS$&EPNB;P6OHC0L*.EB<)U*@
MP=88(ZWLC#"6XSX]@`T&!;!:QW=8D62:N_(;7>-,$Q!``_!#CFP&_'@"=C\_
M59F**\Z]DEJ4Q!'O"ASJ=QAUUHPUXDDPIP.V4HJ4PUCC;)@[[Z]K[Q68USK=
M`#WOH:6HAT3@[!Y5V=`;\+Y?OP5ZOPQD^2OL;P)#$:6A3D/[,UK8?(*NN:/Y
M;S(+=7/FJFN`DD%O4VN$BIRP3&W!ZUHI=][X]I&8AB\)"-5IL1O/PUP8\D#D
M.+#M9UE&JM<8=P9A'`@=:V&,93W*1T[G&7DT(EUMKYH2@\2J:@8:3K/,53W_
M'=^.]]P/;<NL#("YR;JN/>VF^[H-LQ32JQIPBOD='Z3DC73J1,!H<"K+(@4B
MV[I*7;6/65)\@3'1]G'&9-W#6H!24@1L,*MCBK9M$QP=W0EM.]]<CKE42I%U
MVSJ(JD:Z2Z*C%1#5HA%!+(!;^UVV.=&M%DB(.<->!$&>HD6V[V)JYL(4#@V0
MIK'W[OY5#HU;;Y:BRR!H]9!YXL_%S/!=G,F+3%A<&]T8(`>;'8+6IA7[M:$&
M`A<(V;]S75MGL-&:!&4$ZH!G37<=6*@Z\;9FZ[:)/*[AU@YV?SHR99:N5WL8
M1*P6+]2>8UG2`0B9GV.!^;4:T^`87SGA&7!QII"4336'^E(CWK'QG&S[7FNX
M7?\;\+Y??PSH_FXYP?G&%_=4;][0-S+PIM20YF-P#K`SWYYP.-A#DB*GM5MT
MNVQH_,'@.+*#>1!%-(P(56J\D*K)B;;AHJ'XJVXOW'%?LUW1^UO74(](HP8P
M9]1;N436)>WK9VO=/P<%N3X;)+5C@TFC*GFPT9%UO#^/>QG`7A2;'50%>HUA
ME>6Q['5J34L3ZOOJ0"^`:M*PSU:4$]>Z;4IW]5PJKIM=F)(91K!W48L]4K29
M$P@GT\3KDR4A)L?XKJ^7+&5192QR3YO[>(]E602O5:V%QE!92UV/T4PZG'$G
MT&R=4>+`C&WV-L..;S),):ZZ-B>4H_3RB<P<QKL1Z@LS>2!%E16!;$?0686!
M5!C@D`KL8*+&H5/N]GEBTBRHZZ=)A/F\2^1%/TNF'HU>#21G_WPP,[(<[E.\
MTR,]29^PS!BZQ@#&'G6REZ[K*J_7*P\X%/4^=1I4#)!6?/`B'K$WI(?W_7-+
M0;#WG8VOUQ7W9AZSL$C7;Y^7P;"7VD39S_AL->CW?[^;UMZO/PN&Y<]4&R!%
M=G+9M\:;[QR_,F_JBKT);:$7R2FMX\NUIM^#26/2=!13RT`EC37Q/G1G:U7O
M<Y0!U"%KPTR$_0OAQR7D/4ZY6G>9F>JB=9*[*]J)A(S2BU>_4U6#B!^S4<,8
M6:6XXVM#C]@3Y;5O+=@=0'Z_CUKK[G&?Z,>1E&W=1`1=GJ>SN#V-M\^$95EV
M=8(IXS6>V_I:.WB>*EOXAD;:+"3KH>V9J"!D_X&)SJBM!-=E+LX\0Z*TFJYU
MA"386+\%XE;@G]TX7*D"$XWG.8W=K)6S30;#K6\&SV3FV7N(53)13*'6.M6(
M0,O.^?OQ"A6&71-7YREYK6-H>0."WJ_)6-/_#LTW9VESW=`89,H8L)EA>W5P
MX@?5?CU7U-4!J"D=DV@8E`6)6;ABYN',7_UBKYP:^!ROK5;Y_/RT*7X/,=V@
M^6P0LQ0-G$6RR#1(\4%B/H-@FHY]4S')6%8RB^&FTICQIQ/G\_0>>)J%?*LT
MO%]_F-V]P\;PFCB<G/IRJ=E[OQ;52OSS)B/LB4(HB2@#U$[872UU%4&UU3(-
MJL(^7:0Z6[U14[O6K6KIH*^9,)A/.W%(:PS-`(GL;%"L?;9P)3LOO'.:E0QR
MH)?<6<)U==)83$*-O/R#;GS8%#EJ-1)NND-:=W!KMZ=V.-5:CW(&"?J<702_
ME+VA+.C<PK#2&GBMKS6(T<,5M]@B!2M_45F/PX:G2JVZ*[P#7]K.>J.R0@O.
M3`"@&>O)?E*9I&X<J&#6A"E-KLT"22L5K4I&IM%>-+D84E&Z/,*M>4:[<?)"
M?L8?WAIP<[XTD8RCEV3K9=BT?\0#XD2E`AD@TN4A@M[0"(Z0*<8ES.=CFN[F
ME`F$:F(5>JA+->_]4T.O6^[2>3K,A?T=Z#'4+"JCO7)VV.#&.71VPJR?GR>D
MCV?)<_(?@:]QI1OJ[6)FTI,\68&#W5EL"?QP&V2M1H<>,X)**:JDACK>T(G.
M-4X2.^.PBNU]O0'O^_5'P.XE%S@!NTJA*544^"J;S%L=[%[,!%^&SPT(0/(T
M7?7LKF?,<(X[F;"3*>@4RV9-'MS0=YQ]Z-DI>V?'/AK-PGVE7>:>5=//4VMG
MJ@T1B38IK41/K50,B:]O8^*K/!B3ZG1,!Q/M#H'>R(Q+QINRUZ9NZSI2G.T^
ML`LUH31]4:,Q<'Q.9./)O>;M\S78(*J@C49K,ZE3ABX7:<_(.EU9[(9<[LO]
MS;0B=3Y]6O&`UL8U%JHJXQ]J7IFLQJ-T1]>F>Y!-,REIW.NR#`^]V:"S]C66
MSXFM,G6`K(PKF+"Z3.%VLB%.IEU1<FZ<\@6P@O\ZD\'1C+K_/?Z]#T!1S6/C
M/IBR[I-"%$32(H`3)-(6B';KNGG/@Z\I8'(Y"ZVM;:41M=H"K2R;#M8G&US6
ME+R4)>QA'>RNZV$PP1C,2Y*LXC37%TQMLGT6JH1D1CI%ZWF8LCF_,>D>A>TX
M^RX5H1V)$#`&)T&BZFV8Y2LYV7S>@/?]^BVP>X]5G8$>?>AZP>_SI/N<.+F^
M&DPXB2N*.1"DPCGH]^PNXH:M:X$-&(/BZY!)<%I;8]YX=N'Z6F=[B#SN!1D>
MWI3CO4HI'<3`1S.`N69.?"F-5F32Q!=2VH`CHD=>E+"`SPK9%SM&1Z-<V[RU
MX+M`COI2=5_*$C<7E!^(J90B!"P($NDR8T;B#8-A\>^C&>579[3O0<T&6&JM
M0R=5,?/V8!/'<KE#W'>0\WH-A&M5;&CJ/L=Y8)OM!:DAA[/SU5]&IAVF&Z6\
M,+^SZ;*US=EH(]1:>D6XV15,@]$)FH4R9DA!;3H*"K@J(.IK6XTI@]G[,`$7
ML(`_O3\&A8L6T'D[<GIW=ZT)G1EZ)+)AXIXWG>H'TZO5*`O!9IV7^^THK7A^
M/*=GS;JN`0":/80TS/[,L`<Z*'<HW]AKF]*Y&>F2U6_8NO1<__;8RWAF$J&E
MI>\UA7H^AGK2GN8++*7]!KSOUV^!W=GR\#O#=<UH7E5YQ>C*EQC>M)KP!$;;
M)1VCY[BQI)WSY,51C9"2SK%X9";O5B6T@T2_:?FJ1>UDK#7354J1Y;$<G=]#
MM:&4]J?T.CM?EJ'K%4<#$1S8BE[I'H@,)B6ZQX7]VW(XL=$!,-)NPW3"I\R_
M,H*V[GEGII-&$#EO<JE'R861ME"39[J**`%XIVO>L;I:3%\#\+,!,/N"=CIS
M@=B4S?*QF'-WA<K!!_4"NK&`KO6,^T(8#PY6O,V)W.=&FS!,E$]\:76HI:=4
MDW=B.+[C>P^&LQ3O6@;AV0X*!S+U)X;>@PPZ^WM6X)^2YO^#EK-9]]&XQ$M!
MVN=#=VI8)9MJ@EO['$U^#S#2B6>G@IY?"(0P#9F@[_/CX^,(QF;&)+Z6';&D
MZV1=A:>C!H)9_*>;<I&[>F9[%9D!8/M<:#(&5T3)D(L[/=LQUX?WP-V'5'ZV
MO%4:WJ\_`XK_P.][+=D_\L:3V"]GPV`81AC`'A<PDLVJK<^L8L!$WL8FF"<`
M)0.VO\*I[QVM8`2&O_)\M?8O+B^8KO-:2;TY9P*>L@H2Y5/=X=#M1XV@*"X%
MT,7//X@I5]$R=5;LX9#K@AA+5:,3BFA[J8%D;T*C;AAQ@"=SGJ+(ME4I2WNN
MF(1'@R$*,F_8RS?2<=0_ZVQ3/1-UOJXMBVNU/8^57ZQUK%Y'V;IJ?[]>G\?X
M891X<-*!3F4.T0-'B%_T3&1@C/:G9,#`SU<8,`%:X-0#&E4%"S??34`YZ09H
MLG%[ML:B(5QM%8?K@W$]\P#/E6RPAY)P_C<P@3`($T2VKU&B&H(QL];VWK#[
M"[S4KZI31^:(<%Q;;;)4M&=-+VL)`\5Y(ZL5%DR#M2:#51Y%/CX^NETV4K@H
M$SG"V2-#EZD,;+R<)@'"_LQTGT#J0*C'T'_F;)[-SI<V7KW\;&*7##.>8HNI
M&=0EPY:?/<DWX'V__N-@-V5G^>^Y3IQJ`&4FQN?"P;L<5AD"XPXX&1"1"=OW
M]'U6T\H4)!X.!]'-RFU<YLAO[D0:LUP`WC/%I-GQL&V;;-OF``'DJ%B-OT%)
M4IL#6$)W*)NW'.P6#``;^L>0DWM$W)@I-*E:(,/PB<01Q.I[PM6,UBI2$-O'
M%."U8%<"D^2GXF@PJA,+LW$X(:RK\[EF!/V!K_F\.""C]8:-])-8XIV2D_!G
M__UZO53M8U4I;8@<,E;[84GW_DIA@@/(Z,ZN,Y`]9:!<68BNU:\NR##,FB1:
MIR[PZ+!=@SXS2VPS9L1P$'W#I,J!H.SOF\A5^>IR<<_49DG:[Q0%F+V!!M+`
M4!13VO,_RO&+Q^;5@#.,"<[>0:=EM8"1Q8/NVC=`VC+]3;\9*7BBFP^)*8-Z
M+<LBWSZ^#9D].;'$*46P;5(5$#TC$Z@DSR0$47>X#YAR`%T_GNV18Q_1JMU9
M\"I=8O',($=$C+K-S'`S*Y'"&;)/B2&KQ_TN:7B_SL\O7A4B7!]^UV4(ZA28
MJ%;S2]><(1LHB^+S)C6M,7D:;4ML8$$I2J[,0PH:T&22FM20*_<Q]Z02OV"S
MZ!&<KE_]M>>K6$VR;V"]?HNT]7_FSXPV5MV^;J/3[*0&P+:K5^D^WJQ)SN:)
M.)U1+1O79=&\#JA6-%`YV5%S*R+"R*(JR;7P/%4]L06FKL9OPOX!)VO-U#N+
M*7-0B-Q^9K].!L`S@B@'ZOP8JS*!("U6RI<6N)9P"M)BAHUVI4AN/&F%HM.]
M)(,MS%KF@PL5$RO7N_LJ5*VQ59.!T[S=&_8NR`1=$87<#(VN'RM+K%,0+<*I
M]LTVIAB3@$KY(&-$Z2U\TV?AM7?%NAB2P?+:*-_0J3Z$>:#JKWN)5F;!J]PF
M)50C"[`SN[U<8N8;<3R\Y_,9E3>2IJ\S1;0SL)LZ'XJX&O-8ZI)^$*/^/2!&
M*P-7V4/*[B17\[5AR`*W]G@3"=`Y&?;G^89T[]=],/!%L*L6G.Y?\HL*[F<@
M7Y1K..&*(\#%Z3UEFT1:SN`VD'(T)I52DD5Y1Z2&>9BK?^-&WLO7?G4FP&V@
M$)SZ>O!JE%S*J++:+OMT@V=G?2"JP>UTG&*Y`F=R;P?@SBV3YI.VU1BWPRS4
MZ.H@)>EX;L\>3.J*E9:P/RR:.YCP>A+J+FB]/G`B;6(/8SUV46_8ZE?ZN:]J
M*Y$$7[K[O"WFK':_L8B(3":]IMZ-2&PIBZD/3JQA3)`;0:>$X(K'-=)KSKKF
M1P]HO2YT7(L,`2E\@#U9WK9HBJKLXCC$48X:4:08W[\3NPI#OUFESN`4-/H@
ME/U/J#G13"!<_!YMB7T5K`;&QI[79P9<*V#<DZ-&[7!8LTU]5A=#W#R4!(S[
M&15_#RZ8"$$GY[O<4HI\^_AF=*OE9F;!F$Y,U!WNB.\8E1%OEJ<S!\CE,W5D
M&.WL;;C8&H,SDPRS*6&H9<`$S-<81%^GWK_?@/?]^B5V]TZ]J98^\HHN,E/%
MXLT:I$D0FNE]<M)/>KD-X/RS^F<>'?:`MU[-$24.@*2W&P\,XL]&U8<(/N?/
MKBL3:'>G)*4<Z[JN)\!XOMYU:T`NTP0FD,?ST6O;YL-.=Z"Z<=0J$\>%-,,+
M7Y;;>+@``"``241!5,<WFW,R84@N5=N<A?#C\=A!%Z)L$\T!?MS_X[$S'+6&
MN3ESB+*=T9G+D3U@8`2?G/:Q.@P"`Q0L1V,P-L0W;%W=V2(SIBA)T+AII8JK
M:!0BRV.1I91NWPU(PLR/"9`WKB6!#"T`R+).T]W$=%9%A633(&1J9ZT4FM[1
M@!RBM.?_>#Y%%S:.O13CC^A_V];=VAT1K2YS)<^#,%($Q36:1O,,4QN@)QQB
MYZVIXP:4#;1KWF,,'B#>I8\CFT"9&B+0T9=4<\)Z[]'H6\-DI=1>2JWS.Y1I
MHI''`-2E%..@&$'FQ8:DQLW7X^N?M2W;/"U7&\N#)K[)YB$-XUO,_N^/JA&@
M)<]-N]"X7H>NU7N#2C)LO?K.&_"^7S?`+F]RODG*XP872Z/@:-4<>?M]DOW@
ME^"ZW01Y\[-UPXRQJ4V8W%:ON2S+Z6#AD,[B3,LVDT/*=%*5M:6<9/KYE1'R
MUJ$:R#AA9<-H'?<-@:S;ZL"!2"F+/)Y/6TGMI)=:$/!\/+O2A`:5N/&H;5#&
MWOCDI8X,((;]=SNDN@R;22LS,B_'+7U\^Q"4(NNVCJYLD?3`"E)03K*@+(MC
M<S/9H'/IGXRU]JP+)BK[3+JC=.=U"!2=JU>6DKVC"M,^X^/C0Q[+$B=UZL[&
MV,U/3M4).QM^8T.#ZUCW35(&O"30HJT9JX^J['O;7J`S)0WP/I[JF4N0W)]U
M\YOK2@!M#`)CX.XM9.F94<TXZI_-FB'E#-@A=#&2B2(%Q2B[=$8X50V@5%;G
M`!CG/YF5%<$H25!K*?*0&L,(VLESIF;;MF%28Q8E39-JWT_\/$V>S2Q(\?/O
MKDLIK\Z#GKG2I1Q(&VX;X*78^9')[_&$!&!B;<[T]_:OO9O6WJ__#*#^0PUJ
MGL1+^D=GL>NM`PQIZUC^ZJ#R8IN@[%:22]DM9>N1[M;U@L9HX&3#)%JC5&,=
M(+9K>6P$P\^]!,W.7W^&NBD`@\6$]`YRRE[R`179OUZO`3X4BU!KW<'LQX=R
M3AL'9P.[C\=#:JV&%6S.94")$\)UV'MBLCL3*39Y618II<BV;;MVK3Y$#^#=
MV,6"QMKNUZ2[G7S-,8#]_LE+]S'X0TS=;"NAR8$74VJ;SM%K@,=8^VW2CJ&8
M53E2^7N]"UI[5WBLR=5CD0KVJZ]]?'S(HJQ9=1*ZNBP!="``L1F/9)$'MLS]
M$!(]TAV81F;6IKHQ>2[H#5IQUS#65B)">3X_)-<AO?^J:KYRU@A%J^0!)R_7
MU>'4NFL@$&4PNTQ`V(Q!=M[0.:`C;6I?=$,<8A"<!G?J?@<];#^67M^5IN=@
M?(>=8!!%5II^%C??7NLJGY\_$]UI)AD:F\.A8]7[,YQ*!9T7CO%LSJGL0&^>
M;N-(M.U^](<HPQ_O:MEZ/:X(MK8_(.GKZ#^-&+CE?IMO6;+WZY39_4*T1Y$3
MJ_(`D[Q8P=<YV.L%"[/;_/Y87+V+/;!/7.F.]]VVS8`670LXY$5Y73Z"I$8A
M['/,SY3?F">D/9.:=`W00._^S<?R[`=4K7NM+TVCGD[Q[7:\R[+T%!^CA[&L
MZZI8ZV%-^5@>%NRJO[,:24LHV#I>"@4%\BQ/X^#5;8.W3?AZ[=?ZW.^Q+,MN
M12SS.N,,R)]E*HR$G"H:7!J[G(!("2P.$\W*C#5-QBY=!-&UC\F8G\MBV>G*
MRB`-`O7&D+RV?.\,+_)\/N7GSY]A2U*J<4:B3<\MZY3&^1[`UM08I<-L;:/7
M^X9C816@=@\>7=*,SKK52^85>3P6`7YOS]=U[[JI#,YFE\G/!,OG-'B@Z2>@
MST9E`%NL)JW/`$`!:)!&):<#'R\9Z::W#X+@I.0J*07E8(%M*<SH7>-DSZ61
M\#)"*NI'MVWK8)?"/`/CUG3T!SW@H+)&EAGH]<_W,HT7,QB2N-9I&<?!WB;;
M!T5^?G[N3<ZZD9`YZ604AZ9*%+;PQ,?EFNAX`][WZY=9U7BRW&%T$KW=1&KU
M2]?@PSG8SYLK('X10,NYNT[&`,VNN7?U;U2UD+IN[GQ`/'A#FGIU*4<%M#.[
MWE]]&>DF[!M]46R&+O>H.B5G#C]1W>%5UEH/MA:J^60$!+M1@]K)CEK:X-@%
M&_G[LD%@5PWS[")E5Y[XK)]#7HJ**5=B^>O!`#=K6YD<7/J0TPH65P>./BC[
M(0#L)3')`6'M"72>CX?)`.-YZ)@L./8EZZ2&ELK3!X_]R.ERTV`4JNRFG#0R
MMFI<SW5U62HRFEW0R>"9!B/D-J[)0=VK6L)I:IWJC([N0%]6P?58ERU([))<
MC3GU;G.Z*8A098X42OWEZL1>SG,HAF19,Q?G2"*I/;9?UW_@66(FC*.!C)RT
M&3>`Z_R>D=#H<*`Z"RCU'*^J'G>F#&%#/(1Y8?9<!8Q]A9D%Q)3/SU=RSB"J
MP`A=YA%?.,WBAHU)D''GO!U`GB';N"Q+JM/;]II::]]KH:4`74CK3)U'K6^8
M'`CS]*RD[0UXWZ\OL;N_4^<#=UR=^0I<L9IW+'5_<S#4M2C=3CE7\9UJZISQ
MW?3&`E=!0P:F,8E$[K/VOP)TP_4J=J3M/%J](>];MPRL<7RZF&OM4'L\'@,H
M)?DL3@\HD5JW4*<GOC8/$KZG;[Z*"`US?<6.:]<K3%E4*_^T:_SBD#(2U[&>
M6*"8H\`S\IG3;Z5-P7J"DHRE$F9X3J0(,P9/#G:.I!3!P:8MYX?XQ(:X*NW=
M*]*JITE)SY.);QZSKGJ47.K?1MQ#DWG4\Q)9D=7Q_*K;@XFH[(`AUUU*D5HI
MVUJE/)>Y3?/-K-2LG"0\.P?,M;7V['E75Z(SL\;U<+*4,AJ"C[D"M_$$9S*O
M4M,;&F$S;(#)#G5Y<Q.`9ZPJIH>43L*4,NJO[5H;^\.V5:EUBUDGX73=:",/
MGYE!EL8Z*6VX8TD/M1D8=IR)))_(:+Q#S%)E!Z65I)];0L6#`B9[($J!(Z.Y
MVA?>36OOUZ\SNPDS=.L]+KJCKIR;3"W4F0)8TO%\AXJFCH*ATF^G;EVYLSR_
M,*C7NK^.:8L>BTK3==[R5PYU@Z\T!6;WR\2\(-1F.X8*&7LIN>4D)_:4_FM+
M*5)0TFWRSJ;>2A#TI2'M@%#-@AQ-3S3LM23-4I*D;R?Q"3V#&+5SE[(<DFZ2
M>ME'?@SILXL':SLT?4VJ5AAPK&;+%/2.>J<V@O@L,QOA]J[==0[S/QX=[?K7
MD'5=1\-2?UXT\TFSIZFTE>I(-P<V1U-9K*;41C.Q1,$V'3D)L$JA,YQJSP:(
M@,N[M:WKZJRWOV@7KFKCKX+C62H\^YW9^X6FMLF6R)Y)45_K&2`&S=K3L\3O
M=="*,9.]IW*4;CA%B/D>T],5LBR/TXB+)O-U4!83R[*L;.E/GN5^C<3/C6PR
M$K9CVE.@!KD4J/(?.2UIM%LOQ19S.'>8``"8NK:^`>_[]6]E`:<+E2>,G5P2
M-.+.FPM)I,3:Z2:%B;OE#_"J#.>`SK"/`3SZWGP:T77.F$'/Z9VDS/&U!W?W
MB;C#V?;%TR4%LY(*3FK..!D=W9%MQ-.9$X*Y&0,S:<ZX`9,3L.KD^3F)$$1I
M!7O!2RVJGP2$.JVWLRBX\:"L^%`_T""IU-O0GD58KZ27-6-G@GE2)\B3AKPX
M/)1MJU;7T_P0YLNZ/?J2K-G452Y*A67SN8$0'>0TP5ZMR!*4+5I`X)C:-#Q!
M?BUGXZH96DZL67D#Z&Q;=4`'69S7`W[]LYB4%=PI$<FLK*^`GC8SH23)M)EA
M`I.Q8U0!8L(0ZTTCE5!TM?6-`0[E1DDO7N:,^"M!BSAW;//,5*WS6</@:4`J
M$E1C?&F)"$8#I3J/LZ"Z-73F4\1:&U=FCY2JEA@3-B:'O6_`^W[=2H/Q9+'=
M80I#S:X^=&]SKR<7E>4O,&>Y[D`XG*&D7T6)B0XQY@AK)).@:CEID966G;W+
MLA]NG&<XZ?H-$7\YJ@0DDT7.4Z"IQ$Y2UPB!+$N14A;+P-`"3YZRZ#E`HLPT
M2"WH2TXQ26.RHYDC&W(:!C]AS(^/K*RR/![IN,]#QV$L,+SKQ4B-:=6"%/`P
M\=M";&"9,G^,=9;!5K0?VK5+Q(6I!DYC+92]S./Y?.ZE#3*QKQ5)7>_T84R)
M]KVZ-C.SDVO@UA@JT`+U&=-])BNE_V92CT/E8I8MV>!F%_:!.@V.Z1;-5(+,
M!Z6X9U242='QPBXWS_PPE\,\"1YX0G+DGN*(P3>M:4(C)KR>+E-^0M=^>R45
MYT:9:H@G0<6D3CBZHTT($R]?E@8WB2T]]E*&92FV,0\Q:!_]"YG&N&:Z;QR]
M]*85G#Y#OHTGWJ^[#.\=DXE?I'Q39O(F3IRJCL'I6'[E<OQ&;F^24U.,B*TQ
M9UIPNI<-G`+/F"+9U*[Q3V"P6F/5K)/^Q!XV`XRVVUF)B9-9D_I-<MV#!-\)
M=<B=E<4T*3+PK6>\%SM8BB`M`:3*R""KN8Z@99=/>WY\R+=OWP]-91K%!Q_H
ML5NDVH.TS:EE*=9<X")DT\U.I#5?H)X.R@"E,@%&/KX$3D&)O1P'-BI%:Z?"
M=!1"MFU-Y_E9@$M*UT36Y2C:7<[<)YT1A*BFM%`#GHS`='X,8&@R,XSN;![4
M3C,=0:D`IA'?%].?%;1X\%LK#9,]-5_73F6(T;69#PGH.LO>>5O>N^>291YI
M:H69!.+=?IBV\S\$(5GMJR_G,(<$>C9P-P+)U%-@@HK![#.4&&EU'D[V<LB%
MF#IS^H8SX#M!EG-#'JI?+;VG((CAJN>QK;O6L%5Z45FHVV>8>\;:%IVS3>)M
M+?Q^?9'QS!;6E>K0W6PX?^4]>/:^^!(QR\D*TQ']F6/MO4&S^P].[3]O#/I7
M[L_)2?%B`(*#:#3V47@7Q@W'EEV(\SKE*<B-#3%02"0!.L*H,W0:$47ZH*"$
M@\QJM8IXRD7C#-U(8\LOQK_6]27KZCJR-;:^*&IKA^"ZK@>#:0U.+ML]6E.7
M.!V!5IJ@G+X,?KIA8>W!GJV335A&V!H\79Y2RB[MYLM]=+!WAH'TLV1&T`NM
MC;E22/%I\E9;.R(#F%3M8+\L\,)%XYR1JM+-4Z&M/W$=HW,&DYB)XF2U!;4"
M#(!;O:27F4T(#Q+*!T)T;:TWW(!CP;-93M\"F66D>!HT9.!,8,NJK#6WEU]+
M@"0RA9#S_7]9%BDHD>T.H-J6LG3U(M+8<R.LG?&`D8%+^"A.VY+[DD#DF[O?
MS\+8VU%Y'NHXTX0J1%ZO57Y^_ARVPD%75UR6$C/R>0I\D1!<1AE%WBH-;V;W
M-Y09[GAT3RU];S##T]_S9@*8X<I?%ZCDC3$R>PNR0P;:U/1V>.&[LX.JA19'
MOS64C)WM!MG(2;/?O-:J`)TABM^%T3^%8CK"3J8%[#$V?9\ZQ$SC!U<3)=\B
M02@P05M"(+.RBSA.C"1FGS/KNB:@UDX@ZQ*5O'<'I_O!46N5CX^/#K2`8FQ2
M_*%-#AF@HKOF&8_Q!@KONB_EX`[37M)QU-ELQ>/Q&`<GHFG*S"%N6%;3:A;#
MKD^SKKR)QJ3I29=\@)(V\AG@I-A8R1A2![)"K:5)_QP_1\A$Z?5@_!_6CO?D
MN65,?*VTD"#)Z$SENMQS(E7G//TSC(H8?1W"*A1X@PL]7D:IP9E@A-_S7Y/<
MG1(*TS=UAF&N,`>]O0^A-S@W]12]CN<KJ!X-FE#S4+.^.O-@@A&<)+`@5GG"
M["$P8VW61_L=+5F&P8JF[W4`_,?CX7258_JE;ILZRV`T>.U40H;@E29O7,_(
M5&Z2LT?X-IYX@]T+J'!5PGG]#M=(=O8^TVNXJBO@UW,7YAI<\:<_U*V1`^:W
MW"5"=>=H!!AY*58BX:;#8;WA^V$`8A.<=IM*Z1]'?IYL'.-SBHAL%OP(]_LU
MI"P<QLL;)+(F&.8PV;$E#(R^.\8#4-(VR[N_.V2M*OUL!,MY.2<I,?U)5QO@
MTX&<`?&@96%!5=VJ;%L]E!IPB/`7,S\R*3UK:C)K+&(\#/5<=M-EEXZSDZ2Y
M306V6,1THFM#@+I5P1.'M%QDKN`3'%H519DS#,`4@RHM0P8%(&+#J%TW<!?@
MY14[>*5OQJ0)9#HC&?&^.L!=NAVQF:Q]QBY/][@5VF.R=D9&@E8^RAEA:)8P
MU#I!:;,BR6`H%0+2CZ6$9]4#&20)K09N];^53G<63&LP9B2U?+F)4N:9L8H\
M]HH01`#R?#R"2L'LO%W75=9MD]@/X&IN/2#4S7'0]<M(#"FL=&/F32&:P4=2
M#N.;"UT`M0?>28.VJQ-^/)_R^?.G!:RP9RK@#SI,D`5<]L&N0V<,9[(I;\#[
M!KNW-L>OD[3W+-2\)]'TQ^]V8^'7Q+B9LHXMVLYR<?;HUQ'J7$1&&Q:?W112
MEBF@8\2ZUL`4AIW;ZD->/HR3TI5FNQM8L5FFS;."S)^S<]`U,G$Z_<V#.2@H
MPW@@9!=RX*NEMEI-GSE\>9W%@)^?F&*F4=5!S5I,"'8FC8#*V&,'B/NX+Z4,
M]R^5KH4Z>'HJ_!ASGLX[BL<$FJ%C"-2<^42;+\R"IB,2U535<3U+=QO\A1Y1
M-][E`/_:&&-8E$K^.0TT)T8%':RVP`%'>E@_$W%C`74TJU**L#B3/@9Z9#\N
M3MW3+O(_U`"N#4S\_K^NFY7=0J*9BFAZ$#896O`5F%W-T"%1K8!WDD.H!<[J
MA>$16K+QSS1Z7?I`&938[(#_$4A4*&@!\_/Y5.8S\?.;I?CK]>KN=JDTH&9A
MU3H"\G`[N#`&-M0.$!.K4RL]Z.\;":,/>1SWFPZ_6\3+$9Q7>K.*>7!QUHV1
MA$)NWT3*2;UK>/^AKSNJ#&>UL[SD$W"[3O2RUO>7&N/P6S_MZ^RNWC:7FN$%
MI,77"H%GZ$NEL:!I$=-`=Q)68,*6GZL[V;JMV:`X=F"VKPV!>#&U@E0%U*1C
M]F1ONMGJ9H"<D2RS,,[.?0[-S4T)[UO[74ZG(WF2;3@-,.<%T_3CCRCGU]RQ
M6*MK@FO-6;6[?.FZS_8S-;$7'LH%LXYVBVBMCB_"__+]`BIMBWZ8X@B>\)L>
MN4P,#L:8C4!S-.N-,9&)0QXFP;>IG:9NE'4L73:7];LK5O04LJHW`W8]TZ=W
M%I2TSRH^R>,9OUXOH](@7<.8)@OD70K3[ZFU!K?RO#O8^"[">A91DG>3LZ*O
M6VT,,UF']!=NBH\M(Z][!;2..9.MNCM`-G;WXZ.KL!@72_40/C\_Y?/S<^CO
M^EV1]JR)S<A4@%9,`,%)'1;-.8,H7>,D\6S_FB5\/)!OY1MW7I^O3V-N,D@,
M-?]YAUJ`%^RT82+B.4>.A_<&O._7U_#E9;.:MD+$;U\+?N'B\<5[;4T;M5;C
M[I66$W`>$C"#"+-&C=\9&F`J_\"0(H.+H&WG_JF<ZXE6<D^+3YY6T+Q,6'++
M9.FFK\G/:QU<K=5X:(EZ&=X@K>5VU?8YE=5HJ@ZV:V)\<4?D-,P$&(3LB?K0
M-W(1#=;#Z*+-61Z6G;76`]".`*&#7=-0QA0@!?%[H[5+\XST,^3I_\04#NJ&
MN?:A6]W^1!1O@.0`,QPF'9E)PME.AM@-@)F.*;43'5SC'K]**QC.S)>$Z'(&
M$^+U0+V9@>2R7J_7>M270VQ:G:G=LFG,HUZOJEPK:2J+@>/X#'T_>C/2Z\%H
MTV+@F=%HAC"^D*BDX)LI!;F*CL^,<4(TZ*^74HP46=#O/0+4S\_/J:'.N#D.
M5A7=[Z27>OC./_M,Q)8\.!,&ADK<$>@UJ_9<!QHAB&J**%=;($GY\?.GK.OJ
M@I8C4^4S?71_)G2)UM*F!L&D4^NQ/3#ODH9_(J"]D"";UN;R"A#_@O[47=3+
M:X#>E_+-CVY76TDK%Z,6I$D!P]?OGK"]X+EE\N587GS`3$8F:5P",DC.W)3K
MHEM)_TC=MBF\"_/,-8_DP-@]/RUGY`P8]-_M0!GR8I"<;X^LB94]RVN+.8T+
M:!N;TL_-!S07HO]:9D-+F^F^1-UU;J2.&)F^G!6,U8`=!+6S.6VN/%FV0`!P
M^BNSYL>K728+LT?CE+(=;24)0>23X5H(5:YP8?Y@C%>#'>TL&(PX?0#*?+.#
M`4.4Y\<WD4/FKM4NVOIX)JEH'.!FDY\_?XCM):`-AD4U4)F;31H<O=^+&M!^
M7^YWO;N;;UXZ,R;(LV<PG\VS9$H6;:J2J9C5@QUGW=A%#J8SL<UNO_OS\],%
MS380]!)]H6?DJ&UHH!<-#"<;7%8FH8?/UO</+3X;G-MU91L;BRR/1W*F,31S
MOEZ?>V#EQ2IZG3U2D1VFW*ZZS:!0,=%^ACY7\&9XWZ\O8,O;0-)V4_Z.ARUY
M#78AL8/T]KU.!$T[:S#Q`+]DQZDCZ_'O:V&;R?MA@I8N'Q,#>VB:0BX<QK+W
M;7]OW1J3CDE-&J(4PZ(W>LR>2<(=!N:]2^W@<)P:##\R`IO.+($>]$XD*9G4
MZNJZ0\H%V,4)\,&4-;Q>&.I=B[5+14_/-DFH:C*:\5Z]?YT8B^I::501M"$&
ML[FMQU2\(`*CQ%-CJ\/O.0,&R=.2NCRVI]4O+'?1);:0+G$(=IQ!EX8/*P'!
MH,-O8##!EC<:4$U?.BOC&UR/KSR6AWP\/TPZ7M=YZI0ZE)R9<&^6^OOOOR4W
M4&$")7G416,21'NQ%PKZ_8YT,T3+PEFAN@'VLZ"PS8>6>:M[R0ZCO-QHC+,:
M:I@4`P.>,VQ5_TZ2,@%RVI4P7[LJ\5ZKU+H=ZZ_&.F`S_R"9D(U-+ZGY*TYI
M@G:*,97XH-VMR+A?0FS3H*J]?C95!LG[(MIK75=YO583@-M,P)@;UA[T6',N
M&V5.]]LN2W9/>C.\;W;W"[]\IW;7@Q+DLC9RPVSBQJ7B!)#]%O"?=?Z>#LZ,
M?>`-CDH"FW8?%E_1@KP>0-YCT]NK-:MU";&)@Y2G;HSLEY.#8JHY9P_31@%G
MH+Y12H'ACJ?;8/(.L)PQL4KE9WPG,.(S>^<3"0S)T\#AE$N:8](Z0@5NBA'N
MAP"46G=%C5**U+JEZ@EGNBPAS3E;:#JST5@Q,CH")VG3!G1CESL50XMT=;6!
M:9)K5O(J+Q`$XP45I8,*T9)UT9""3>*I:CUF1*6W(!G&DW3#N/)VW<7-8P#R
M_?OW4"=M`HJ#3=7U_!"1S_4E?__X6S6$P0(JD;3%<[]/QEB;]I>AQ3JHRRR<
M&]KQK.B8X/"<X&7Z(GB=C8.?<'!K<1#.=1]C1CIQR/[9G$</PBCR?#[VABP-
M(FW=UVZDTGH4CC6R?ZN:T@Q?Z*V#[`)1%M8J4#,6W^KZ#L:^J'UU"(1@2C;,
M,X9'T(.RJU%,;.W;===:Y?5Z6<"L2`7S3.#Z>0,!<JP*WZ/(1'$($IJ;]5Q^
M`]XWV/U%8/4[`.PFKD(F&W0-&+]2/0S,.>&@M8FABVEK/)F`("?^G58AX&`[
M+!`P!X$DMLQ.D-$W95T^#31+T7+^N)R,@*F;5;7.F7Q7Z(Q.72OR60'G^&2?
MYV#:\B:ZZR??4ML%.)Q_1O,'E(J`9V)`GDXT>[T74A4>:8C5((;D92OZ*PL@
M2RE#GBS3#"5D*<?U/)X[VV3(7`9J4PO!ETF6(4X3CYIXFG$PM<+DP5"S_ULS
M5@@!@/HHH\2_`^;E0<$GI/3ZY<@$MSG:50,8U0AT>9-I?B(/P!;9X;Y?J7(<
MN/S\5*/U^$81I.0"1>3;MV^R*'=!OT@@$46`>]/0CQ\_QJ_5J%MK2HX(0<'(
MFB3**HYSLR8]8M4M@+QD"#HX,C@:YG>I&C`1LFAB&'2(U0F>06*$_W9:S;VG
M,)Y6;8XT#5JS\ZC]GB*R=7>QXQ/",E&F+R)!CDWHK*[I,C.T)0JL!Y`&U770
MU.3:K2+O$.SU[VJL'L]#>DV7=<2C0EZ?KR#[UM^-3N&#63?,D2.`)H%LC`6<
M`XH>/*IW?`/>]^L+M.<UIKIKLL";W_\R(?T+].ZL^#YTV[::R523%ZY4#I[G
M]BK8"="S]^`2S%V22B0N>&@VZ43G>#`L1;(]+_5&<!MP:_(RVIJJ#F^.[_:#
MJ[$#U8-[$RS8*E$DHIQ&V_0P59@4=T[9C+IM._.IW8\.<*NOO0!"S_A#@I@^
M5(3&+,&A1>83JA1`7K@6`B7(<NA^GFE_-K:R'5*/^MB[\QW+0AU`J0.)DVL(
M'>2X6!-AO5&?K/)8'D8Z#=VJU1"@:J[;!ZR)LH(B*$6HA/VUFL*^CCC*0!3H
MTIF`3$?ZF`S[5X..JUK%&$;;4Z;>Z;].%4B/WUN613Z>'WG=/>;1_KJN\O/'
M#PL^=,F#5U-136N9"43(XLPWU@$^ZQAO_[Y"3MA%5_[DTA)>2C*SN<[.&AU.
M>X.&L$5#K)26JK'=UU2;EU'(O!X*,+4VU%EW?&<D^QCVALPAT$I^V?W$6.QB
M&#NTLK6:&#1D`!,N$*?8>5L*Y/%X='.*67'>:UUEW=:4!,'12!FF:W+XS;+`
MS,:DK4LC,1<'\@UXW^SN?7;W!M@-%O3X=?9U#K*S=/>_H5G.'](NE;YM]6!*
M82)GTY0@DQWUPMVLL;_T`O"8(Z&9"H17MEF613`!2;B0(A.(U"U1&TA8K*QC
M%]C!U[(LNQXEG>`]!L0@D8+R!H9T@]M,UHHWIK/6!VY@G(`<M0`[N%R670K,
M-=D!B:9QLP4U\DWZ(-*U>A.:PJ'D+'B8@5TD#8*M8<,$<2(&</AYB\3-RB"K
M:4[4IK^CGFFLG\GJM#.VWK.O5HH.G2E_/A[R\]`ZM=^U(O6ZD6U:1^T;B:@<
M<SL3B,E^RV!D8!J[O"B7TS_M7RZ0;]^_.POO\[F-(X#X\>.'U:_6)4`2;9C)
M:)ABFRSOU:?IQMB=+4[*GJ[NH2`88K3WHIL/&OQE71E`.23[T(/D2JL-[$M#
M"UR"'-:(H])F07S@4EFE:G:5RAC%-"+.P"["6-EF/ZM?W"E]V8$N5+F&72D7
M>R5=8QAVR^]V;DS[;&N5S\^7>CY9@(3#E2]W]@O>,XB!=]Y4K^V]X[2LY+MI
M[9\-=O$E@,@;S"Z3A2/\$DE\\:$#-5+R'O@_4L,K44V@UBK;MLFV;K*NJTGK
M`Y;5^-(]I3)A<\O>1G7=.P4U?0``(`!)1$%4DBUT'\/?&:!^&%=WB3.IG;AY
M[T!M.0!JL6+F[7\MN&AL&RRSV7ZFU93M%JLEWNM5@*8`K06!31]R@(NE+!$4
M73D=TT5^4&E4B-.MC2JE!OR+K=DMO93A_GIO8]_F:$'I8ZVS!+XN>.BEWO%?
M](=R?!Y#KFKH_M:M"BO3M+E,F%935>GBAL?S<31:V0R(81\32]ZK_3/36,UE
MO')`X26K?,UH:!HZOO[MXT.>CT=>/PW)YR1$UKH*>\.7=H=K!9\,S7*B;(_K
MD;FI/;NEWKQGGL3H&TMBEM=J@*?/5LT[X[C(6*[0YF)INLZFMM?7/*OU1P61
MJ9AEU1QE&EYA2R^&=O!HM*IU&XU6V9XNXO31M1P;518#5JK!SS'=O*D6$VE5
M%?1#@([.:/>7\.-B&_WH@S"(/!_/^=YR_%FW;9P/(LZL!CDH\(3+'>?X&RR-
M]6/;SXLWP_O/AL)?9#G/O0^^8(9V_;.!"K[R9/-S__=T@#7[5>NNU3I2+5EC
MSU&/2PCO](U=VOOFX&(FNT:1F[O$[K"T+`?3&\S9M5O4Y#Z8%1PP9PRGFYH"
M@,6R5M`%S*J12-];ER"C`G*&&;M7SPQG50KC0S^8I'5;4[>GF4R=<92B]KI$
MKP7/'A=$85UBHO:,`"CO+J/'8Y&M/G:]WFU3SU+$U!'KIZJD?>ZM^`@(+0Z`
M8>L'"*:9BE7J:,*#E3+S^Y%MOMO9O&_?OQ^*!!+2XK/TM_]>2+\G`456!YO+
M&#`!W<[^57J_43^JGQ]/^?CV+6DTC+V-=`MW6S=G$I)</X[&P$I?5FZQE+)G
MAK:J5>LU]BI0M,:L3]D4Y;YUI502<(U^AK19OK;ZP,3:7#&M@]'&7G9AC"FL
MR3M<\`41X6&)'>NH59D:30^;877'6N/D/!B?6@+5J>J@4TI>70FB\V'&K9A@
M0S5C/I>'E&(#<]]F3%+6HU'--"N[\A?7ZVCV/>TPEQYGR`B@Y"RD9O9'G?Z;
MX?W'LKM7Z8&OXF'<QM"\^W93IP;\*0Q_>=M&(.O4EO6&%V]VDZZNBF[S2AN1
M`L-U8PQT>AP[,S$8:DZOW]K56G,(+Y5F:L`T6P,KY03E<:\9V_X]F"/@>)^B
M&*#2_RYE+S<H!>FA>'OFNO1=LVR%KD.$!W3M5F&8T@[2M?Q;Z$21O-P'UK0`
ML2T^;5"[6)5F/GW[]DV^?_LN*/OX`>ISU3/O6L=I[?D=EK=(MS*5F)KVK.]K
M?0TFT')4P@P/I*FD\<5E6>1?__IK?Y;`#3::*N6:.TQQ9D(@2,Q2X%(K<;DQ
M_?S1FOEX/KHJ@QVO.`9,TC>U5NL0)Q%\Z`'6LG&BI.=T,UAG18U#732&V=='
MF>[A;=[M<Q`IBZX;,K\DW8=Y/@)N7952[->TJDRM=A[0ZAN;DA8?E$\SJ(CQ
MD"]WF:2J=.F/7J>C\=(]4Z<Q?W4NZ7KN(<FGF_-$.6-:Z+T[]]'.>>89&5*B
M2R35G#-.D_,#VIK@Q.I!D[5[,[SOUU?2XN2-=SDA?OB5ZSEQOO@S'F[7`"%*
M9O*$17.;VT73T>_4>22M3AD%9X!<EP6"!KTUI,5C@P`SS-S+*J#5%))RCE&J
M2,ON*D95-_UH";$.MGH#1CLDBW%HTN4,&H1JL?C48:M]OJE5%54N$#WD1:+%
M:EY7J=FC2:(B>73T[/,)0/M2&L;9J<H!,BIIZ18/2DVZV#<VQ9Q-/^^JI6E8
MZ>K8$3`TJ\CGYTN^?R\I6]JER3`.1CJVQUMFE+*#WFW=9-VVO21IV_9[USK2
MS%;7O$P'CDEJ`>#H*^6H,]?71>?@J)AK_;R;H<'W;W^I0#//WD)D(C6G%"-H
M:VIYFJW2`0I5LZH8AC=4GRCYN!$L4945Q)WLV_=ORFJ:?>TV(Y(6>`Z=YMI+
MRZK3`;\$<AX$._G$8*(@5IXRRPY4#8*3B5)=@S/#/LTC.Z@I8%>#WYJP8'6?
MLWFOS2=T]HI!)02CQM>B].Y(V.YQ>2S=-CF?*WOS[^NUNL`G*O-P-I$3XQ^=
MK:.<6"[3JD,&DEP!_C?@_8>SN[_/DN8VNK_TECPKFYC)'"7]M?@SJ/@N#IV+
M;"%OOE&`40>U&DSLFJGU%+3%5/&`J"`<H-Q++IH>:_NE_?V+CX7CLPU1=J8T
MB\YV6,W%P1DU-F401%[E8(!=W]4^F)[Q56WEJC?:<%"9`VFD4)<#V&[KVIGI
MED;7UU9*Z8YN=($#U'CNK)J6&HO!@G>*RV`6D,MF!+#K%\QLS?LT=AUJ"`TX
MF.:=X("7`5O7;<B3#`>BTD9_<D7/XRIUHRP%$C86:J>]N+'0&!G8SWT\GO)X
M/*16D:UNPDKY^>.'L30V#5`\\=462=EJL4F"0Q-8J:MXN^K@S#;N[>/C8V=V
M@?/'2^LFE;6T[X^7X[F;\:*D&@G0QB+VZ^QJ`,><Z<$,#KO8.F3^D)5X#>%!
M5DI9EKYO=+FO106]!\0K2QDLI^JIJ-I:F]YM839?;6/@/B[*-=$%'TT!P:^_
MO:FMS'L&JAQE;I10ZJ.X=%T>8NMK]U*+M%Z$+L.@YA0<.4RU_JH+DF@7>E]#
M[>>6\I"L3U'_Q\_/E]2-N<OFB)8""8#DYZ'*8[+N;FTWW36K:W9U</?W!KQO
M=O=/OL.L6>H+;\4;E+,5E$DJ'/DGQ^>FU5N2KF(0?X=A++;>11Y9QP8,MP9Z
ME18+`X7,A(^-QXN@=`]T[6PE6;.-*0S4&7_%#+I`9==/;9L,1#<_0#C*$01[
M8P.5"@79-^7>3"56/F@0!?.Z@&`6,F%I.]M3BN#0K:3J\F7-\6(#W)I)+J5T
M7=;=XKAV8*%%XG7PT\'NE#:)$FOZR[;6\->"X;U^<F]>(W.@2GJ7(URRBG'N
MY1%B++??`Y=MJ_+\L+V<!LAZ9SOW?%GM23Z8R,.IK#R$H*R/A]3/.C1.M4P;
M$Q%JP#J&>Z,$1CE%>MI>K*8MS,WMY_9C6>3;Q[<0$$[#:T72ZYKR>@`EUA.K
MV=P]Q,GL4#&P-A`9YAX,<T5D9VJ#@]R!X4K9N_6M@U\;'[7#-PU;K5K#O6WM
ML2PBRQXH;=LF/W_^3(/IAN`B(RU&/Y`<7T>J#XC#CEZ.,JHBK-'FMXW5MNU*
M#JQBY=38U$$HR12Q08DQ=+G4M;`ZM\F)IKU8"$F;+;N#72DB4J36[(39=X.M
M4EZ?6P]@!):`$)]%2HI-HD`<3)"%*=$$5];,4Z+K#7C_:]G=?S<*'C)+?P)!
M9X7L\RF>M@GU*]HWH_);UR)*M)X)XV68*DY*!%W!+7$PJD<Z&=6>]ZG/^_2<
M@Y%X:INPV2B;4<;!QB['P;3K0];>@2U28F,-<(+J81HP3/TG1NK..ZDMR[*S
M-+!VM-9/P#IOQ0:A<J@S(#RPKB:@A%<[0&,R=GYHC\_:UFT`"?TH:1FGH19Q
M`%ZA5&A=5S'%EM9K(0<R]+6?:OBUN'W)P.[,+0_Q>Z44>3R?LJYK3_%K5$UZ
MG5);3C38L00(372$D7BFFN!!CH"H#'<EP.]I,/L.,I;;L$'(*THPZL8'BITZ
MW8R@[&*K8V)#:P)A2I?"&O7-X[.74N3[7_]RM:\W2`4WORNK;%L-W?ZSS)_E
MZFTA$WKZ._X^A3UEW-==*TG`[O45#7KV^]Y_I$C4Q%%KP3#\<`UA^WVV#-)2
M'O+M0?GQ^:F40'*<"$_3'ZYY/"AS*#:[&3=H1[9F._U<GG*X=H>1;.HC4JE4
M*NC*RV(M>G=X4V"NJU\22:JAS1]89ADN($KF;@#81NOZ"(JKBD<9<W^OURK;
MIC-#M"8LH;I6C*/@*'L1)U+LIGS8QZCVC[CI`#2Q@N`->/_+7V>Y?=Z1N+T`
MAO<8WM.WO)&-C4L3,M-[('O3_V\$"S:%FC+1AK&9(>%X"]NVB518:T:7@YV6
MHC!&V/G8<1PJZHC>MKV.4?],*9EQNP365'][L*Q5R>R,FC;;\#,VRW5;Y6/Y
M&,`QK8_&P8PD-7J`H%:II1RE"#LH0)F)!R.=LR9U+4BL;N,8;W53TD`#H+0Z
MQ2J'S)E2$CE3`?",M+6;GS#U!QXK*#U3D-:*GXLG]-?>[%?D]?K<E4AJ58=%
M*+(P#"BTKB?&N*(,1A$%3G;+FQBT,I>C+EM$RM(DZYC>OYBZ4@O*^XGM)0*9
M\YC/Y\?>+/=:A\UKK+HUZ^)NF5@OJQ&K^2O(U^INF+';!B\E^/5%MO@LT<2=
MY>:V"0X&?^5FS$[2"DIJF^2#@3S`0A%KWJ$5`F+&IWV/8C69!R?751Z,XUHG
M].X9&+6`'NR`MCP>@@/P(N,3U5ZB;9@+RM@;V@TKBUX<[&7K00#V1JYE642H
M`P+OGFD#_UX?+</M;@1G^B@H8^E5VO7F-GSK:J?*,FB-B*S3>_Q<,U;852$>
MC^<(=VL"G$E9UW5H>(>LBI[B='B\71^B05.@0")2'W7DPQ2JJ!(:W^@*>3>M
M_0/875R<?A<,[;06UDM1_28FEWOUNQJT,#GM]YK`WQ0?46+ILLKMF@RR-5#M
M@"U<JV(RJS^@/+#U#"=S,742DH?"=C(P:?()O^\`V9F1`[WAKY(0\TT+FN#9
MMJV[]?22!^/2M@.OZKNC]8Y=JQ"09=FM@5%T`!'KI@U\26H*-1LT`_M&9LS%
M-*Q5I5]Y&N31U1?J`Q"3W_?DZ<Z2NWKUF=M6`HA]O?BR/$1DGZ^F;MS);?E:
M\N+&F@=PJ(BE/`WH%;'-C0TDE%;&<RA'1`O8>"(V*<"=Q<U5,&;9ES:.R_?O
M(OQ;UI7]\#U07'#;XW'/`S#1!OX*2)0&<J'ML@]0U@(!6#>ZO_[ZWALP39#I
M0*EM*LQV\Z.F]4CSD_7`;[`5NQ0C?564ZJ.K=NW8+ZO#SJ028<"'*T+KC#ZE
MUDT>7(XD$^;9`+\WT\XOW:F/4CI`U5&&;ZSMGU>4MBX4RP_GAMC*ME#DX^,I
MS^>'E1'L%U]&NZ(R)=$-H);]'&5CIG:X1Q32_228^-0@L=+LVMX<6EQMVA4X
M4Q!$8D.PKP\H0Q_">H=".8]&8QR.TA"X.G5HAGV_(,S2K"[Q`C-'.;)>@'H6
MOC-BS/DWX/WOA[^G@!>^+.$.UI7[%L)&U'X6N>-^32"O/A_X`R-&*6V7,!:8
M$^*6XR##40]I@)^CF*[ZZ2B'$+^<VW?J5/,OYP!"^8+<D_]A-N;LFU]-/(:)
M'?`NRR-T#E/EGM9UO63/BF)X7Z^7/)_/#GJGS8*2@=UJ$&,K.6FUSG6KO;&I
MJ/3LT"*U(NWW&,`H+M=K^F8+0$FR/1Z//.F132ZD\J_F.3X>CU'+7=!+8W"D
M3RO%2,G9@V2`FE*T=30D*P>79AB@@PDM/74PV$5B763`\&!Z/X&8Y?G\__[]
MN_SX\?<1:%FP3JKB+4>C6B?$&`#B9/%`:4]+@7S_]EV>SX<3RX][W5`@D:/T
MP\<WN\[VY^?/G7FC'2-HR_..Y>P[&-41^`8@USSLJD!0Q-02ZYI04S:A2G26
MH\PIK`Z>\#0*I%'K<:$!=P@5[T'D3+]/'_3,04'(P`!%EL=N[]S7H%B2@>)J
M2_TX"=)3F+9DU?1,M+EN=C2H^SI^"92HJ^YZ/SOH52A=E^'H\^#Q>!QGFFZG
M@QE3T%IQ0]O;0QEXJ(#0E$1-%FC+#E%EHDU6M(PRE>!R"$C)_-S?)0W_-)!K
MJJCDCHR!K<7)CVPY:VBFC<CNL-(QY7=!LI*S?.&OCURTRYJ^O6Y2\^SD])'0
M><^&L64J"^<[T%L)`%F-1-*,(?%?[:GQ.^/"'2!:LP6O-L$HCJXF`RG=CKG7
MX`W$USO:@S*%U\TLI=,;==WD)1'TW@/\141JESI#@3R6QY#D*8N4K0Q;88R-
M>UF6O39Z:<![-4V`L?Y8KH.T1#Y(1(.#972S@R?S5@,89RXAT087LDMXH>X5
MF]([\8_?I&Z$YN&\]+'+?-5MK\7$`#E0AX_?:PHP.L5%.VFQ*V>8YCQ3$PA[
M_9!KFT7,BIL/UF<I\OW[=_GYXX<(-]&<9*M(+%@.35O%5E);F.)H`,IB;IB[
MU0H?(B+?OGV3;Q_/::`)#YXTNR<65*R?J_SX^^^C/(59Z;\DDM(BXDI-#H:S
M]!(KU?:GJ&9H%E\DU(NB#%0&S4AV)JY**3[=/LEP<+;O#F)BM"#0[#\A0R/>
MA,230$HUXKCP;]];4())38@NNSG85:GV:R:#I@D66_8B87<MR=JE"@PFUZ1J
M?8>'BY5,+"X8;L_GX[E(*>9$"OE4RJZH4BL[T]^UB47OYV)*P$J!\7.#DTVT
MMS168JKT@GSI,RDK>P/>_R:8>^(>E`.[D?JX`HI.)>^25S3L!&<H>LZ6WH/O
M,V#&7V=Z>?+?G!BD*4RV;=N=!Z4T%3/F'+V.3=NP!H:2(LMC!W_ULQJPV_4'
M&S#D:,YIP_]0`%&NGD,_L^?454CQ!I81G?TI)8/Y$N5@$_;Y\7CTZVZ'<1OW
MC^>'/8!OS-;'XW$:)+1F.U8G^MX,-AJ0^U;DQX^?O8XY&YLTYC&"&%F7\AB1
MK6[RJ`]7MPSE!@4+%`@'N6+N&3RDV$#A`7K)/25<54-).0ZSLBSR>#REE$,^
M[[,ZDPW%3"6?V;1_]=\X6'M[GB'?TV82GNVS#XIZ9YQ%<E4/>WP_EH<L__J7
MO-9U=Z`[2BQV^^F]9OS'SQ][]J$%=LKZ5@<7:<"EU@Y4_??'MP_Y_NW;)?>`
M#,.[+V[;)G__&&`WP_A90UT\,QP`1/(<+IY)9JS`VIB[0^>UQ/(";05L]7N1
M.[A)=%8L!5+K""QZ&AVN=*B;1KA#"4I5'4-=YOE<>G.J`5Y^R1[O5UF/^2/B
M&[>,XUMC-*M-<7HWQP+5.IH+N=B4J0?W/ONA?TZ1)^A[WF)R.::.6Y.MO7S'
M?AY=HVY[ISW`&6RZ>7[PA!SL;N*B9!_+ZJ#)_L=QYKUAXG\?Z/T*[SNS^CUS
M-+I3MWO6I):KJ\3XD1)3J'?XZ-K3JE_#N;W2BE8IP`.Q4Y+N*R82Y.ESD1NU
MV"WV-S:KXFTQ7=I11);'XV#2,+V?S%ZX,7#;9`*=,=M6/@I3%[&<PAEO56OM
MFS$/U0D<==.?\BD?'Q^3>9AG-69@U\N(H5AM3L\,:?<@^X@]PYB4<K0<H?=U
MA06*I5(^/S]WP7ZQ-9FYYNF-*8E=7%X_IVU=99,JJ$>=-T:SW+*4_ME;K8/)
M.4"=9@1/XVA7'L)MD\?S<01ZZ%W66@?8#)?7C>;>7+BMJP"0Y_-Y8P2T"Q7D
M\7R*]-]KUJ7[,_W^_;M\?KX$@+Q>GWN0!1VY:YDIAL:_GK4XYLS']V_R\?$A
M1+X59H[$J>K2L59_?G[NR@PG<]_K`#/%2DCI5,KUW)JI%6@0)`?`HR#T[^_[
M#E0@F-!W2J(Q0]CZ432VD2[@@J*1[5Z']$3J)520R5X12VO6]35$0.!S-EYS
MNQ6X,Q_O(RL2P6Z6Z;$_TS_#6T^WVF6X>BCL=M8P-=\JXU94+7:!E`6R5:UD
M=_Q>P=R94'7'A<J#Q.C&G`"Z;ANPB@^P4X:P8_X&O/]%KZ!!^J5?O@9U%[CA
M-B,[DQ6;F>9Z,9/IM?`>^WQVW>VLWFMH`_PX/;MQ`^R:]T%B1XJOC6AS2V.T
MEQ$Y='_7;5.&E&,#OYY/DP,11;DJR9!<,W1N7@9CGB\F>KK`-"C@T14L!T-=
MM8;NT13W^GS)\^.IF,^3:LJF]S/YD18\.5$NJQ&*\2R&77,6?#+6`*M[#Q)_
M8&_.Z?)$AW[SY^=+/I[/X_KRA\6[ZSEY\,OSN3>E#(_8'F#PP.9UJ[L=\'$'
MWL8V+E=]"K/+MC4F>EF*5$*X[2P0W+AP4MZDQ^WGZU.V=6^,7"[6#^WEY!*W
MJEP**/+Q[=O^[)9%?OSX(=NVNJ9;%6)Z,YA^H)>>'I=#"SE/'<WJ6=W%'L#N
M\_7:55GHLTG.5,-)XQC`S9V*-<H2;KPD"]\84)Q2R(!;PR+ED`![K:O\_'S)
MQ\?S1&X681\`$5B4;FDLQYA2I_Q=D'EL]$"QG7=-'[E``6$(:Y6-=:_C#]DG
MVO&AR+IM\N/U.N3$(*/BC*Y/7#&[W02(:=^I5IXP[F(<EP]CP#.NLP7C@*Y/
M5Y85:@Z#W+.&U$KT>7/[SMHO4OFR&=T&]'D2;R):IU,]6_@,H4L$0@5,(QCV
M\]SN(6_`^P]A=^]QFU\'QU\%N^<_@Y3EO?UA:F%\I;PC&\/JM".O-/[O,+S,
M`-V4Q#U)@:M?("GK:YU>%$H1M/I3=Y\T-6685X&X36O7GMT/E<"RV?/)1>FJ
MGA.3071U;LQ8<$"V6F5)$!VYRY]A+?(\2A7.0Q5,65YH-[?6B-7&'1?LF68N
MF0-\4A,T=++KR,'(L1[6UVN79IL&+G>C4@Y')S?)FN+)7B(0T?3GZ]7=Q'99
MMA-V7U2MY*0VO=53[\Y5OV:72(K4C;)BDT<=P0K<,PD!`6?N4S**EU7:O90B
MW[Y]E[__YW^ZIK0V16A_F08XP6XJ\>V;+(_',$B8I=1T"E[BNM>P8%TWJ=M1
M!V]<K12KV=ZS)G;2XYT->(OF#:-;CCIXD4/:RT6!PU+9JHKT(:U[[?OC8-4Y
M9:?%J=PP%OJ2A]'%`=9T)F`"O+1-,JH"BM7.D]U4AB):#?"D_N[U6J5N#')M
MT;'PV!7K4*!IC*]5\DE.PJHC!`E6W_TQJ/D`K4CCK=&QFV@LRZ)*0B[.[J-[
MLAZ!4O_TVD:>PXPHJY-+3"4H]CQJ\FW5[*,3V;Y`;U@#I3?@_8>`W6N0>1\>
M_S(S?`$(;WU?<B:$;A'^#N`-6K>\9HU3,YF9XMM5C;$M7QJLHC=`ZEJ+CK_%
MO2=+Y1>?71;G<4AZ@UJ:S#>:^*YMGY4PG>$S@7\UQFC_`Y36\*`^MG4]:DR7
MRZS(Z13#`'+>Y6TXUAT<2-<-;H\/2B_2E\<,($!)FL_T@0Z7O3B^MJZK/#^>
MQKAA--9A6'2&W+4M.$27K$N"K%HC4RF[BU<]TN>52=0A^7W9?<K.H5WA1)6U
M\'X_`CJHVZV2ZV>5_[/^'_GV\2'/Y[,#[MH5/I`&2P9O>AV4KHE_.+8MB_SK
MKW_)CQ\_9-W6<0"[Z'@/$!=Y?CSE>:A_F-I?MW3I-+\(JX&\_V@Q`&%]K3LP
MJP,D>'*S&B2K0[J826LZKN+E_;3K8_^<P["%U>C\5J65FM"5_3VV;2#@,^&1
MF4XU#@:6VMJ[.L,@<GKD=5DMVDQ?44UE.,PTR@T;3U)D>VW[=9!#*[:?5=5<
M1DW8Y](U9K,\AFX\4Z"P[_UTH#@_HS4I`8S]XOE8G$->F*8FD&B!VU:SP_AH
M?JW9WDM;TF"(AVKGG8Q,'#EWG8.QR)&1G>&;X?WG@.$[^))?>!_>IW1UL?D`
M/9/WIEP[82@PR(EDT33Z_C+8O<+?T><[,YWXHGG=5!GC7JA"6U"6W!-E!TM-
M#Q<)\<POQ!YB#8LD^G)I":EB&R@,<P;'AKAK4,"[.;;E6L'L\DP?'\MOK9W>
M?5_KSJ8BGQ>@VH@MZ60$_T4BA9AE)`;@X'1-;-LF3S[-(K;]-XCJ[\EZ"5^C
M<B@R0&L<'`$=F&#S;-8GNFFMF;)6P?(PP4P#1ED=J+_N'S_^EKIN4HX,`+=-
M_O[[;_GY\Z<\G\^N2%*/QKL0?(GOH(?[.HR(O<C.AOWUUU\[Z%UWT"MUS/5E
M6>3CXZ.K:YQEBSI#[MGV%IB:>;*#]UJKO%XO^?Q\C:"HJ17TTAN<!L!P`9SR
M6QB=\_TZ[)P$)]XG+KBC<4#$T4.[?];CHR3.?MD^Q\EVIX$797N]C@93<<HQ
MQW!6K9!0K:,9M<J(`O6'$8/P^H!\?7[*Z[5:`7)*T$G7P(Q.=[8SU%UXU@HD
M-Q`]U@-4$YRS+9_5VAE917:;]&59#KMDE9%1Y1U#/YR]5*+6-OYYV6$0VVE]
MU$KWA,:07E*HGTH0JDZZ()MW3-+V^6_`^U_)[D:/[E^'Q/=_;M[\QFE]X2\@
M$,NVG%S9&<N;U07K^DM_V?.ZX_E1_M7A#!O]I`Z6NL-#Y$3Q@GO];L*JM%I8
MT^#%.>C-9.B\:YF7DR$M?]2DO(P#5[8)RY"I"H#LT&MM.IA0]K0A>#D`@:Y7
MQDWEN@QC9O.I5PD7*.M?)A1Y<K`EZY<G3)0Y`KBG/S\_/^7;Q\<H+/'UO+UD
M`D;%83P[.\+#!(3=$<^/:7L5%*E4JB3U1(Y%LR_=Q$(I7@AD?:WR>#R-3)GT
M0SRN77CFV-F`M^=5:Y6?/W_NUUQV'>,'V;66LXQ#+*E`N(=V]:4L\J]__7^[
M1-NA?5N611Y-0LXS9:VN\ZB538LWF#MJZ8"DUBK_\S__(]NZJ;W,UG!VLJSK
MX]**K<`)M5*%J]7SB\-$0P<@!F`%SVXHP*1Z,X[]:W\>SV!>P)MKDR;8Y.'0
M:(UD#"/MC'R:;CJ.4H^6E:$*MKH<H%+)@<PSC)^?KT-RT;EGTCY;)@%'8VPJ
MZ@AX]4\ZDYRL)X!>>HY,1<6$WHSGJ#6NL>RG7V]E8(GK\3L27-9<F1@0RY[$
MUMM6U[]C&CY]!L:5V5'5@(0&WF-^OP'O?QW8=1-%SJPGOFI;H,0?[_1:38A'
MWNB*NUO5D)7.WBEE"*FBWJ!S%[4F/^A[52Y^,S8"L'<H4Y4(-#<I<>>(R-'M
M3)V_LD"8K./M$<L-&M/;@&-^K3`'WIX:KN8@1/.@[XT[49IH61[[9SEGI*ZB
M?P"26FN7K#*>]T?:_OE\]HUT![,(XTF*5-8`>.\&6KJQ$,-K5)S_J7)V:OK`
MZ)L_LPQ&QB:*2[\FK.^L%&!;5]D."2$]?W3*?C@2(<EHQ*YH,@&3[F\&50XD
MM#&,+;1>'$-X?J"25AM^7NXS=[);EF),2SP;/"RK*9^?+WD\%GD^GWO01PWJ
MDF;'OK:M^Y.^B,<!<F_MU][%S;'D.0.O-:^KK*]U![M=`Y5NG@WQ?IU2'J`2
M)ON09?]CQ@KSZ_;S7!5':U95&Q[L:UF!\ALKTP2>W>UK_UZMW#]+`W^+PL:^
MI=WR8L2\K_JR!RS/CP_QS7/#06V\UG5-72))3N/=?'!````@`$E$0518:B:Y
MSZV2')H,0%\4*]_5428E>-VYC3;3@-F9Z9LZO?K/86']^?/ST.%E<`5DPM`S
MR0X(8D!NR^1$,<LRK*'=N9FJ!2DBYPUX_SMAL+@BT!.PRXEM[7WZZ[*])`:W
MZ1OQSF=BFMERF_"UM89F+!LK@(!E.1W!.^Q#!I"1^+QF(S%`+DZD6B!+V0_R
MF)Y&*-JR(&!G1%"*+&7INU353(Q`6?],F'#=($$GA]9]YY]'XT$UX&O\R@'J
MCT/P]7H%,%4.6:"FN;LLRY&"VXTALO0"66_%<-,UPK'QPM=2J[?0PNI98#("
MF7@`,F&?Z;(4<+K#^O!O2A6-_69"0S%+,RIKX[0#5#O]J<]GN$&ZX$C5<@)6
M90&1->YF!TFJ@2E`B%_;MFU/ZZNQ[>,2/FO__NOUDG6MLKXV^?[77ZZDY&2Y
M_T)V*B,F\K1]M,DSS5.UREHW65\O^?S\'*E[.6I7$^"2JO=X5RY=C<5,&BI"
M<!WT1%<]U;1&9?#0Z\QQ]&B-P)GUL%T^R01JDQ\3N%6[-]G4]C"XT3;7XO:Y
MKA'LB)/GQ\>^/YH]V=T[T0$O*8G:1NFI]>FYI$MW*#8SYRD(WU3(W.*:OHF+
M>CTH)T7%QA[2T]V]C:;)>-3=DI"?/W^.()-^WQ(S!Y#4]6L]XCWN8:ZA[NO<
M=7F-V"P?X*\![Y*&?P;H#?#*'CY?E"V:U95>I:%X>5+`6`A>H<C;91JN_L^D
M(NDU/L6(]Z>UF%>H>V;@X9QP=#J9$Q++B*Z;.@/[>V25FGO,[!VYGF9-E`36
MURH;+#.VJ'3O>J@\M#I$`RZ-%)S3&Y51R\@CW=A!!]HA1`/DUFUG"A[+<AR"
MZN=K[9;+M=8=K*L:-GT0ZK3\*8O+"%['K57%P;C2B0:$$\.,[/D'+DC5SPW-
MT/EA&!G>\;5UW8[F/(Z:1'/@:/<HF0`6)&#8E5J0SN(>9OVV@Z4U5/DT*KPB
M1F^N.X"[S.MSSX))7;+@S4%\'8[EV?;/>[U>(@+Y_M>WW$7K>OO*@W"=I;"V
M8&*H[LF;D-8-[+6^#BFTFK+$LQ1&-G<L.+7]@7D6CN'[7F]ZO]::,[%!G86'
M\D&UUW&4>P"VT=4$BKHGRSE,[E]CRB;`[Q'>$.70E!Z]`?O`/)9'.AXD#)C:
MY](Z6.T#+++MT!S)+-WHJ<T=NHJ%*BWJJ[>I2>C#6`<6JL&Z`T+X$AQ;V^KK
MUJ@+;G7-NC-P83M[#/FA2VD02!#KNFGA>.+;*5FCSDCVP;#`M4:C#N_6">`-
M>/^?A;,W51DP8RB_JJP00K+\V[/]][KYZXO`6Z[M*!K(,JF0#+9JU8/).\*,
MYHU.79G58L+6)_9#1,O4J.JG60.0<Y8:Z:!1^$_=9"247)V'RBY8*0^\/O<&
ML^-0V<=RE8(B6ZT&[/J'35.S2=FV*MNZ!5_4`?`.XX)CA+=MZRRN<>^B!E[8
M50)@781T>0`P$9@XF=X\66==H]F#%&(N*.`!-:RM9\#!)VM($O9D#TA6J3^V
MPPWJ*<MCL5WG/#ES;,^U.DAH&!DXD.ZOH8,)U^YNZVVIF'+U_<HHC,^3U)'+
M$K6TOJA:S.E>V0!$LXTZJ++7ZU.>ST>O#4\#5@5DX+))81]T++61*H"D"A1&
M#0(C(["NJ_S\^7/86T_2Y=YZ?/P;DZ]/YM<9\"5]=4#(K)GSQ=3ZNE$Z4N*L
MSJ2@$14B??\Q&8G#I:W5).MK*<>>U?;#/:-DG>FF=`5=]4"OR\^L)F(V8%LW
M&V339HJ@2[_HR\7$-+GU8$TS\3IP[F4!'$8:ZA08M>8:6-M@!^J\&;KJF.91
M_'YP#)'14Q!/&.EU3'%!G[8_1]@S`>;$@6K0[:`WG.Q1V>0M2_8/XGE_YV4$
MX'D%L),&?-[YC)/K/0'9%U'!U!W(?!;R#V)R#1J,\M2?3I,:#CBD*1T/PADV
M)QN^N/2;6&<Z)"P_E2D/W#8X,+]VS*JA4:UR"X8`(3*GM_OT:2E5GW4PUM#U
MST95AVJ#@X-GHAIQT$L-&ALRKL%I38<TNA/&H3CF^?]G[UW7'#F27$$S9V9)
M>][_4?=LJS(9COT1X>Z`F3G)+*F[I9FL^7I4ER09C(L[#`8#7*)(^7ND^&-@
MV]U8@(0"A&$Y@"0"X^@F[*I7']Z:P&$_/[K=CML9O#!8WX2M?7.7KX+N.,[I
M_XX%).<@UO6JXWZ(Y=J8Y$<Y9,9R"U#TJ*?V4=5I?U3?3YVZ`#I(QT'_W>6^
M&1/J'Q\?"GA%[K$8-'&M\,)R;>B00[(@)]$E/75X1D:Q_O'Q<4H72([4R4XP
M,FR@RD:+V(*$*"*#<8[GK]>G)+G"423=NVU>D^E,`7HV83.U<`#>])[7"SI@
M1S^6-K:OI+;;Y2AP>WLCZ\!S$.XL#GI(FN31/@LB4G(A(->KVW4_"%N_J4CO
M]_NR@YO=Q4ZW=^Z%=G1YUL>Z%+V[4<D:."*8!\72>E+=:YY2,+WTI%R-13>L
MR'M;X4Q>[67\![@PTMD,SS52?JCHJ@#*L-Q6\L`(H$&`^!OP_@]D=Q^BWZ]$
MWX:'9*=FQ8:E^#5P_;7WP"_^6\46@P!8W=&K0CI"LI)'$::3HB'[W0JX>GI>
MPQ!#PEE>\<L)<)9!M]+2\LLC,5]34"R5MHQ"L8`LQT"8\%;;+,J0#]_7:>`)
MCDU!805MM2:EYR`)+;@>-:Y8K3H>TICMQ'.'2DP$[#XGN!''(<G29ZOA#1/J
M>9.[8!DR0(WGUG`"T9$V-N)U428I5!OB.=`UV$3>>,_H9ION`P>!K>&%:J0W
M=FB9)U957MV$"QB^,M@Z!\QXTAYA<!,[ACP/Q]WO=_O\_#P'*QLGPJ$(#>GE
MS*I%]KQ8')5`.)/S^G%<4@6?]^H8L$O:^:O#P4"_GO/SDL&-@$C!E6OU'0"#
MI7Z`9>VSX]*LFG@R^S68"K*)ZM;M?ES.%KY:\./^6QTZZ$3^'7:X&SX^K+6;
MO;W=IK^RDV]Q);>;C&CH0%!-,K_O^_O;Q1*WH,D/&N(KY9';[J-+TBEP8JX!
M1)_S(%9'*$=YL#2`0B%*:=\"A2553D/GQQ?/YC4L!QOVO4B`>JQIQW'8'S__
M"/[B879&(IO#L*:'P5Q?P15F6;_/8+[;8W\DCQTT7_,DWX#W?].O7P6[?R+!
M[2M!O_+\OA#1^ZN@'Z%RW8)VRU1P81*DWQ?[J;I4J<:]_A6=!F]0(LKD1=+C
M#OL`O":,*)9+NF&"R"ZD`41AJKT^L?#@STGLM'4>I,$T^$^)2?$+>=VVF[JY
M*R1A,'G>VMI\Z3LM71HNIXB>?#SG1'377'>.)>6!&.A:'SF6O"&/-FV(RT[Q
MJ)/%6WK8:.+V^7F?(&D-OOG\_7"O<,<,8_KY\7,&2N1-_=RH[_=[N&==G#9F
MM/2F'6H4'B+WBG/\KB765L_ANLYO;V^3U9N'=;7)+:0)1M`36=.?/W^:MV;-
MV@G`.&UO,%O]L'YTZ_V8K[VU9K>W-WN[O>W#9]#G9Y\69J=T9TB&=)*_A0'%
MT#;#`MX5@,VLX:;&\:QMY0%%;]22=[<J/$:(;:,NCNFSB2*LO?=N__KC7RN@
MI0#FLRN"<[",-;KC>GQ\')?+1YOG)*#U"7!+_V7..@',V\U^^^W'>0]=WT?&
M15EF98N)EGD1S]*AX9;C/O2]%.0!#HI9UGT0EI7`IRNC&?>1CK@77[_"8*"Y
M/GA#>RS2@F!%>:"OZ.'LWK=`J;L6_$QGJ*T"=5[4+8^)@'I>J!Y>L[3^?$L:
M_J'L[AZYON1T\!<BYD?@,#;7M^[`7[(L^Q-$-1X=[^._5ZW](RNF>@1J,9L9
M1'H`WZ^%>2A[^D",L4?S!=*>WJM;C?<#3X[-IFN)\8KV6VMCK`H&MM5*C3TO
M_HX6<0"S)3P.[TQ@:Q=K!GM[NYF97]KA^[38F2TX&8S35*@U+=VW;B31-0'!
MGW-:'`GSXU'4N1_8]+@VV&2P[_<CQ5'S[7.[72RPFWU\?)R%03$:CWZU+SD%
M#Y"")'9GG*V#7,WE+6RBV;*,"Z>-\3Q]IQ\_?M@??_PAUSBWV@.;>0U\LA[W
M?L#^[__[?Z^6^66!UYH=]_LYO-E'LIZ"Q<,.\_O=;K>;_?[[[P1,%I`]CL,^
M/Q=[OB448`;O<W`I/6,<2.$VI37+#G!)$J;G=>'8L?3^W6)"8WQ^/54B?*NE
MJ+@'6X;7%+];"JN13M!DAI6]9#TX#';8(8![V20B2\,O$:I,_*-?@2'-;F^W
M-!LQ)"FKX!RGX$AL^6[:8\FD='Y!XJ"OOOX8!ASA%\OIQ.1A&1T'I]CSJHN8
M28&EK&ZMV?_S^^^7W.3Z;LW7,^_K/-_:;9V7YBMJ>NYI3FNZ29+F_.Y$V,QK
MTNHMS)\,8:SD0:2M:0XB?@/>?RSL_:M)W#_[L0^1J(XR[=_S*ZSNGP.[3PS+
MJI2T^=![+N^WC@N5<7OU;U8/Z>#Q:8XK@K\0@9R+"CQG]F7B)6R^I<:L!KT:
M(.67C5(-QJ)',3PFR!$80F9>^$0!G`P$.XYS.GR$-'Q\'(0E&.ES)/"2%2Q`
ML:;">=D&,K@0F0)"@6,AT8R&PYQHSUJ/7EA.3;;=4V@76\@!9OW^.:WI.C.D
MG'0WVLU%$`AS1S#V?[;0X]]5D(O%.SU/S6J*%%N*TOVTLKL?=[M?C@LIF8W^
M&Z>W0$X*<ZWJW>YP\?4]?Z2)1G@RK'9:AO7CL-[[!`YV_?W/CY]VOY-+215/
M%GZUYL+Z.[-\S,0::,A'YP76O%/H@'@B>O-P)93U%$NY9F(Q)N_GSP,SN?A(
M.FE;DJEJ;?%J,,21BM^EX48:_/<)KL25>(A')GLO7M&AL@,Y_G36I@?YGSQW
M]&=U#JTTPO0\.,T=\#R)Y_O2=PT!WLN<YE#\U$/_^/'#K*VA5!BLH:U]CPK5
M^_%I-AQA'(G5]UFDJZ6FYNGIM:RV`J\,^X)HF#L/HD\/%F??@/=_,4;&7_`F
MSQ:U?QOCO`.%OO\,;%G0/.2Q8RV+ONHO?)$'1NTOO.46JN-Y1'36^B%M-AHR
MP2\T%H"I!8#[P^M3L<2(AK,]1V665!$0^*%SP76$&8DA"T!F/^4K;)DV`M,7
M(.L([!DY&@C@=MF'4ZA$O+<\%%;&$@EJ?U1^JB@J)00FB6>HJE^]]]-\\\']
MUMD=H+CND=GF$K`V1EQMVP%LA@8SW7?/'N[K77_[\9M]?GR*/*`#E6A>?L^%
MW8GM^AK`2V4JB('O<N\T/]FU^_W3_N__=]AOO_UFK37[XU]_V-&/.5AIA?[3
M`WA++"=/QQ>:\.86RXX@]:&.D@>)0HH>=NHJ#*#M!=N&.6`45]3H!^VL68U2
MEA2W&T8L6[[NG$I6)S<Z<XWSG*[$;6AA,1X[+,#Z\^<?%`>]0E%&8(;Y&2/<
M>S^[1`UE;<</1<5K3`Y%PG94V^MPPKKKI+M%?ULW"5L<[\GQN_+HNKV_OYVQ
MVV[V\?DQNSFGM*/9V^TVOR\ZKD"?N_DMC'!S:%+H/#E;JADHWL4(!&>ZPXW!
ML^5B+7:/G/7868+S#7C_29CU92NRY-SS"A'[$%8]A7B;X+&'".Q%"4,)#'<2
M`NR!(2H$'-)?'N)-X,$Y?T6/\$6PF]K<10D<$J!*GKG<[V$QGUUUN-BMV>%8
M]M[#"&<]#OXD)58(Q9#I<FBTJ;P[@WTR=S=Q1;C\,`6PFC!B*#R*=<A,O3!T
ML^9)?GU>Q]<>7I'3V<"RW9>3?EF_=F6UY8$]0GD1.NT73MMD=%W9^76B`KFD
MC>W$U#@E6,61N@Q<6[C-V_4_+YC)N'F.`)!5J,5["!FAK7\'+)HC69!K$+RB
MH:%Q[R"9[(^.Q7!/^->__D5@TF<GH,+Q&MWA-'0#8:RB-7>I=<:&!Z#OL)BU
M*MQF!:6L(22(ES/?/UBDKP(Z#]?;*?TS&%A,UM6TL^%6Q6U[*"X76RK68E?7
M*T8<.RSY+7-0PY##C)`<`';S9I]8'L.]GS:`IR<Y[/.S$WCU!/2$_099=WF(
MBZ="SV/._/AM0Q#.XOJ>O+8HJ!P_VV$V@B<'8WR[^25_6FX@?E510+?[T>UV
M:];1[?[Y.9>\1I-^@&^"\LZ4RED0FM6^U+L_SY1+%'LL:?^+HGA=X[4F?`/>
M_T&_TA#4`V;W2TZRV'_6GV%L@><2C,>LI6X3D4&HD\YH@A<U=_2HL"@9UCF,
M55A=X0N:XY(9J$!\]+J,H,^2!A=I6"YHB5]@AE%XRG*:363V4HT";.\;#G6-
M4\EFA1Y/M'MU30*[+)9\>5("L3!`>?X78'9QP`#9=`E:,T_A$<OKTBQKMX='
M\@)$T>1-0*EKI*=H%_$HT,5$8@#6U1GI^V@0*J99.1=&B+6ET[-'K)OQ$(S&
M\8)MYBY]XA@X4HNEZHY:0S7J^WKY27<(^P,4P04[SG@;Z889HWK*%$+!8@RP
MM*T,6W9M;OT*5B#NZNC3.61$!F.Z7(1S5P23('232Z0+T_8N])D*%85(A91P
M!H6U%.U^5+[7*/MIZTU7)'DPAR"7`#J7H66]0@6:DM-QX?*PJ+@5UFHNC.[<
M11S6[1#K@7,9N$^D#TGU4QE3G#^=3L%4V.D7]QR[F+:5/'@VOG,UF#<`</-`
M7+2S(\&L/S__[2HJ/SY_SA/;HG1K.$O,H=4H6<$L!%9'(UYLMJL+*&;*:5A[
M3JF7"-T"C\4?YBG]!KS_DQC@1RCX5]\%O_;!S]2DKX#=KWP@'BE\H2S:EBP6
M<+)S*BT^(0"^N2`!?^Y22!O5@I;,M^SU5\[MG(PM4YYVR(#3;+B5RC&RC[%$
M_$=M3UD!D$C_.G==56@AQI[.-EH$.\34TJ*8+WCEF:K%1ID9#UA_T.DH92/Q
M3QN6+J:C89^]NKG!I1Q8]PD/8L'%UH<9TYA7'UGY]'T@L5@GF)O!`J"0""]]
M81-\BB/<RYG?/CX^%RM'&RV#NYZ>R6!XS]_ITK&H#E@K34@A0@(3]Q3[ZB/M
M`A01/<!NB,".#@U5]\$0`8T+&*@&3^=0GVO!Z'@P;Q#\:L^0"%HC!N!(PY,(
MY74^[]-1IELR8`9U#A"+.!397%`?<T]9W3S(AQ3O/9]*TLS7]R-$MS_L^')W
M!.)28(8RPL*@-EX>6`"$]8"+&_<GSWRAU:Y:=XCGBX8N/:QB*:Z8XHX1]B!>
MFY<MY#ZN-7;%9#LN=+T[L,O?C;?-;\#[3P&S>)93]E=@5Y1,V9<^\Y47^>OO
M40,W?P%2A\][.-#E@46L_]7#@@W#8ZSA9IM`K=>O!.+PU@/P^`J;#,HKWUT'
M1'/O+'WT0$(SPXS``.^_>Y`[%$-['0A7W*DENAIW#%!S.V,LN,Q>9':I5(W$
M\"C>Y4VGG!$V/.S8;&=OTO"6S/+0R>W]Q4!M89JR9C"VOBMJ;6Y:/4\\Z^3\
MF!ZO@S,ZI3B=;]F"11L/EO4O`/@BHOGR!I6!,!OQU0N412D'HLV6:^(7I\H-
M)PX&YM*UH"$XZSVXJ%S`B!F\>4UZ^<QC4]\RZXL$5(,':8298U@1I%TEQMY+
M%EQ1$W7V%YX4<U177RYX>;R)@82GNA[!?%9**W?MMEC0R\LZ?+;4RVP%5A%A
M%1,(\JE`^D_/X;-@[.K]''VUG#GKT*"':E1!UHSC^4I=W%"(ZS7S//T09RW2
MP*#K!24:8P)5X)0Y=&*G*>P$_MPYRJUP9&(;O9)$4-EA]L2F5]*IK"B%;\#[
M/_E7T2;Z9;"Z>SV^`(;]K_A2J,'P$UT$GIZF1Q/A]0A58NKP"\5!>BHC4[RW
M<`O4U!:(2P5-"^*PA?&B9M?7*8QF6Y_(;.))D:9M8"_,[:WPK1U@,FP_*`(G
M=I_OE;7-`).Y4R`2F4+"P(K>;8IFV,CB_N(>*AF+8'#O)E(.L+VD\2==H7/@
M!N0C_=G#.J?S?>O0<9*Z2"WJJB!*ME</*N^U=S>A@-KM9KA?(2!#+VUM6CG!
MJ/"Q0M//Q5>P6NL=I\=K`,;NS2*O-_2G67O:TG62)PJV'0"-$=?+\HV#"8)-
M8K#H$#V\'%]5F`KGF8!)?B[RM>>`C=I-1)]%<"3N.#/8IWLL';>M!#QV.B#D
M)/*=6.PP6QTZ/N`!55`$LK<KSCHS.(MA;FN%@"<M->):,0;.PO5@>8:.=\#B
M#`7H?`L148#=49123[+8X];Q=3-K%$D\<M::+X<;=II17WT-E!&O^!&X\<`3
M/[*ZEFX[W^YW1IV";\#[3V=^[;7V-9ZRIJ\!M-?!\@.OX%<'U1Z(A/'BQ[VF
MR(C,=O5F:V!*V_:^P?*HS1S\3Q8!&_LR'?"R(N^QCC?W'$,E&S<>)`1CL[AD
M)HK.D>SK87B,\H4E.MC8:-YI*APE>$K`^V*/8LSS\H2-7\K3D%T,6AA:3085
M(_'+RI0Y'8QQ`AH#E*E#A8*;&3(A,;D$VP2\6,U87MO/9,WA];,#JQ/2:'B+
M"Y[=32Q^HYX;V^L[^,4DK39WA7N'5MR]3_#(U[@?70:^5EB&B=;9PQ.-SC['
MF+':*Y7/)GA_N*CL%K8=LSD+'S=T*\O.>>\6+"V#I,B<ZTS#\D_6NFWH5K'`
M^]#DBT8`4\9P#EZ:_'PZ)C>U$KR>IXTK7"C'"@]N\G/F&M&)?9<.#%T/#;$-
MSSV=MW@L'D8N(:EH)X./36[]TJKV8I_QPK=:F:DX@"R:\/A]9S&A:[[$9L?[
MP_7\I.VH6+_,<CRSL3N#A9$3%)'E6UNZ?3T-"B3Q\E&#6)"!R(.I\[95T'\#
MWG\"J'W1G>'+[&Q59;\PL(4'0!,[@TGVS?LB0'_JFVM6SAZYO:IE?2QIB,RH
MZ,@JCU24)Z9$N5&S5`'QG<2B\C!&RLLTM12;Y*BGM#75:]$BXLN#=N<$@@T+
M.;]CR2BY-/E2JEG0(;J$4YCXW"/$(/'BC(G.R$.)B=4@Q]!6H\E$]?Q[UK'R
M9END597W:&A%`[R9Z747;TE01.L#9I63IF(W,^FVNVX.PD)!V4(4(1.[J-H:
ML&8`/5T/+LE`WO#XN61WBO5^([4LRDB8Q<KV;^,8AOR"(G_C`%+Q"$/2`K,.
MM[HVGD!_&.$/SW9D[%9!%965G@$&V:#E(=4XQ,;W!D0JLLX]>5$'52@G#TZP
M-=C5QA[7=%_*[Z'W96D!Z27ED0HROD92-%=2'XY(UN,<+B#\?='QN-,"E92L
M?Z=/1.',(,]7C,H-FBLL.11O-YR85\F:4M<N`,F8T/<4D[AO]JHUC`&K-;N1
M>7W6^N3/TX:H!EPY.7@L*=(J1+X![_\R)OC/P.'R)U`SI=MXW:\<M)NVC'9'
MB/I[XN4/J=FLN&/#BTC&XL?Q8/+?XSR(9X5PW:;732[5WHYMZSR3U:ZFM;Q@
MC1])0W*V=%P/B/7M,%5QP1:@#+'2M,G#`U"0\^WE1A:'SL8FL1A/W51!B'?O
MP&$BRD4\G[WG^P\Y/`/8G3ME0^-!],X61T^D#.1*L;X?V;+US`)ECRXKVO>>
M-Q]?X1SN_E+AKJX)/!Q91];B2<SV.47^*=0?N@7I"6L?F75:;/%@=9^MB"H9
MA-PCU>#=!'ZLTQ0+LG7>.VK.'#+L9H]!`E80Q=36<CM^6E0AI7&Y*Y/HA1^P
M4\'/@1WJM0OY7EC6"0N@N1:5"''CXY[H..4D5DA0TSVWZ0RX[0NV:64(2G0<
M@!Q!N#1=16QC!:@2A5(>5WB41PD;.]*HG[5V+7A.A,D.O@?3,ZX7X"FY5CVW
M>5`L<NFCJP;Q$Q8B1!AK=GZ`D"(RF%9<YM*"%-&Z[_+Z_H:"?T-D^B*S:WF/
MVK[7ZTQG?#+=MFW[9\QN,6;N7SD/OR`V]E_X:8T2W[R#^Q>NGR>6@=<%396R
M!<!L)PN`S,@N%D1O`%3G#KK0Q*&>W7F;K&.<+*;/3+&^O,A>G[4^DX6K:Y./
M;2JV[4H&4H@_2\"Y:C=#GQ"$<QU9[\)Y5OZ('@USKFMS&;6SCVUD/)$D+@AO
MKLRN>@";G-?M9E2B,@58/)0C]E+%^>7;RS>MCT?>Q;M?YP">RC&F;1KVSUX\
M!YVN?S\.ZR$`Q-U3),?P'A6/7K>L_XS?$<5EZ^?_&-!.!A`+>(RHZGD?F++#
M%B*/)53!\B!96164#AGZ3^,^RD!`PW?`YPE=CXO$YS-ACJX#B#F,+A_S'@T6
M<;B2RA"\C5=SH:WS%\]3N`_'4L`='W2$M47UL_.X)[SD]D)@DIDUM'U!QM*C
MO6N@DSW:%2#"/LR6M=#<H2DMT$/Q-,$[=%V8#BG`]IF-?U\5<G/-*XB0$M'3
M^ZZ`$G[&$%9_K/MRDX":!M(]]F;6J[X9WK_;+[>G%==+G.PO@,68..3N,U82
M>`:9B[GTKR:O19R"7_A"12=,8$QJE;K=;LU89]0I:2:U^N+#7HB@A&QE3=W\
MO-LT+1\9Z-4F!F+7$KDY^"$R&M]/S44C_D1%;IA[;$89=#DI6]M\#S$0;J?N
M;P"#R.;,A3!$I,[B(=P3@$?X&6Y!%XXDVSV%+^UJQX/4EL#CCD4<ZBD@%$]:
MFWM@M7(K;\>>HIAN-F&7O"Y$72?9)RM/KA4Q$(.9*R\87P_A#J\^K*KI5"]0
M!->*]!R,X^M0_78$-F.Z'.Q[BM7)V*PR"$EP,:ME:3U=.A:1IZQ.AWBV7I*2
ME1""8OV@=GI8Q'+(AVE2G+NP:-7B[)+DQTQ>2Z"U!G9J]Q"CMJ=]F:WAI25G
M\5(*5/?U8F#.I<3>!&*F)IS*:-?`,C/KUP]V0YZ/",_`EGU$2)R+FM0+3$=!
MW+BO&DM8C.-XJ=CHET\N>R?/=6GY\IY,/*\P6*E_D:"BD+T:'\1H]T&2%^$@
M8;@LSB=8:B+NF.2,=%<XGF\A@DO'`-\,[]^:Z,6?]%+X!4<$=R^+1348?X0_
M'T3,?N$8_2L8/F$Q7R;DF]?%-*^Q(8S?M]8N"QLW;VW^N=UN\W_;31V5MG4-
M;4PM7-Q([7'\;/P03I;ZL@5'G')E9BNU[;&`9$P>&*\MP,YXW]MUKE8$ZCJW
M\A6AP!PQ56,:VT.J_O5[Z,^65#>8PR'PF[4*K$&45R.2LE@@*X!(9@?7$#^7
M=<L``"``241!5`LS*E=80LF2[M<#9<Q>:84@)(IEMKXC%P&@]"9AZZU*DT(=
M[B!@P8W-_97]AMV/^SE\1@-!SI"2Q;P$D)A='T4@"Y7:-63H-.#E".WZ<$\*
MDQ:;!\$HNC4OO)I3F@"U>Z`28?'YS?KA==ZN4]"RHP6*IECVWX6$H%BA)_;B
M/'`7(!9@".D]"E"0KO<\AOC,Q!5S6S1MY%)Q/9'?CR%3DEH`:_!4'&Y.E0OZ
M>2^UZYHU6[9VM12@7J[S,*DGFMDEO&5]QRIBG7I5TTNY48*=;VF)MKT_*H:7
MF7+>MX2)1=4E*VHJQ*3-0G_MNI>L$#T06X_4@8IS+@^R8\SL>VCM[TOT/M5!
M/@"`4;C_5>P,9O86X_-H6&T?R/`K]/0C!OGQ^Z4`+*O:L5Z^=S_ZM=FBQ-)X
M1#RGB%`+`WKKU2>S>V[LQ>HC;-K0S2(E7*VD(Q=7A3AA3`SNQCW@X?D5_S%/
M/[FSQAJ!D*U=\9M#-]B/2;OP9&^,U>3B0<YA,))EAF7YX"(SA.Q>$*W"'A2;
M>-()$>EK"!O04^N2_%-QY'6]LP&Z$@Q1LT0"$C96&M4&/8(3=NQM[SUYT3Y8
M2@*[&!>3=;?>/^_VX_W'U,:VZ0*004V,"V[N=J3R!D5#PVW&@E3G<^-.B,NW
M-OHAB]55I!:-M9CJ5#'D,;9AS?<W:.7,D?>-.F'.RWMI7N>VNEPRQ(@\#"M>
MP$E?S!()U(4$Q?_R@BTI7+/(R<^36'*YCO!%284,R-'SJ&'>6*X2Q'SVL&1V
M'DQTD@BQ&PF>$$GQ4=3<]KQ%R;/>9]0UNSB`AHR7-CJ'>T=6%-66*`T-<L:1
M3&C?/%]L0V?"QB^I2-TUC+,/^BCFR>V\XFD\,5P]B+^'UOZG,;P)['JR9C$K
M.@\EPQ@?_L+?*N&^)_J%KT2-E7'&_G@@K*CHXKFH7W$R7"<PV_O'PFK'K_/S
M"C"H/#E=VV['P2QE;M,R`$2HEI/4^OJ_+LV;<$VQ&TC33<`\MX2Y?94]B_?W
MK#O%^E[+X-G)@TH%Y%;S%$%<1A7O7`'&9E9Y^5(;._FP2]6T&U[<!#2$+^%B
M@*0;)B1-2L06&F>\:6!H`9,?*S<K!]]0>4$%[5"'R4!2/&]&MJ.JVS2+$S1]
M)C?UX/6,U=INZR#?6K.W]W>N'LZ`%.=M-%A.7:"LM6;63C[.^AKJ<:RV,.*B
MEUH='K9XNV00ZEFJZH9A7];.X`QAH7E84(=P*B^LY15<R8^@@Z;I>YAZV`9K
MJ)$^-W[)]_`Z30S`C*&.7MG@A"^17[&4`U('@%$4](EF7VAC]Q@"+_-X.\H@
MH'G-23N[AB&;E=%CU_W1H;I8Z>!<?]41V`UG\.VACJ:C:SF&NMRV7?V'5^"$
M)L6M0D+E0'.(%SE$PH,C#\3:AF<<(%:%O6.&DW2K)GET/^ZFY(+'U;LHS)F1
M[J8R!E1[G9?L(#DR(!$S$_A^:WC_OF#W%88WW3E"HOC39F>TO]DQ-$4$^_,P
M!7OLZ/`4XY;2G:+*>]&A`85Q+Z[%O^%D=\M*LFH/;O[[2OX;F#T)1N6Y7>>%
MAC2R8Y?..IGE:Q#%T`/7BE*2+SP8&F+C<P.GX7@1T[D6/NZ"N2,)#19X67_?
MJW*^,(;?=3589UE>2P^DLF>KMT?/@FWPL`PC;6SK=@75]CX//],ML_B`#@M5
M#+Q7%GJ:^62H>I+8+!HIO@&R<5?1K<)X7<?<6K/?_\__65*$>E<+05X\.6]V
MN]VL]WX./_'F9\'A%<$>RB%=V>CI&EOYPN)[\6RH\+B(IPU:U>B[%Z?>Q5MZ
M1L9<$A1-3$#L?KBN=6)O-MZ_=QH*TX$V3X$48=(T!+"D>\H7Z%U[6N5,4DV`
M>>GJB/@L3EVP^N2>%G>>UMK(Z#LR&1`]O'/B7=`YSW-J$C@Q`7K</\=<3(BE
MWCV5EI2^ZWK/SD!PIHEN,<M6F1'O&BB>Y\W7`LQR))BE;IJ"_.AX8R'%T1^N
M;F+A[)!U8'4=:DO#Z#N]H?;.POH;7O[]?GT)[&[1HCW@XAXURE[[0=_6:O9K
M,@I[EIQ6)XY]K9"HC_=^'/64_R.<7E2?('-%E+TBDT59%XBZY2L1P+%-Q5(%
M&L:*EEG^P@7VQ#1L*X4"[+#?+<L+,"4B$UR`XC>K01@9UN5L>^SDS(E]^M+]
MX);`D;R/:TI4^HP'FW)Y#MTW1="F$;&#?IZ9<=\PX/X4;(<MGM!$L&5=?S<`
M3_+\W+-9V-Q3Z-T^/S[L_?W=O+5P+VRB(L-QW6XW^_GSYSR'IUQH%R"SO[VC
M$\!.LL,2A#[CG$=$<EB#?>/_RBX<S4NR8\I+L"`K5VTRW`5_P0^[*EJR_RNB
MY(B`LYL3@\\^Q)L[JFN7C,\]T$\-*@_A$9,;Y4?3S,U-T@*=$27)4YBI3A9K
M%W-IE)B'H@G`T>>(K:,1U1XFXQ3$Q_3+T/%3JE>*NOV]BW"]1AM?N//,E`XP
M#B_O9Z/$N8X%BE<,.I91!]:<I;+VL1M(5*MIPJ1*6)P4=)#.144RY$[6L$.S
M-)@X?O<->/^F#.\S:/(GE`$;IA=/Z&-L@&96MGX)=.S?QIYA7]\RN='V2)=;
MS4-'>49?"<;PN#HR\^K[\WM:DKD=O1<X7E/!A#VC65O.O>>6K3)53M/7F[N&
M&5/IEOIB(>B_3KHUA"EO"]Z4O<.`@P:T,K!(+@[2=KN^<9I:?U3#A[,)R]/(
MS.H"MB.U'^G'4G2E[=X$#WIQ]3^YOU!GX$G!2G(F_M*^C0)>WT99S96FI+9I
MEHL5RR$CYS1Y7_(69I\N?7HWLY\_?]K]..RW'[_9V]MM&[&;.DUC&.7V9LV;
M=>NF^0^J>8VZUD>.$GAXOK*.=EAX189Y.AW$Z^1+5<P^?4N??8'(;D&S3L]=
M:U*<Y5`(+;[YJ[3F,I#T*O4A=GFIQ7&M.TW97(_!)7Z>%W<*8N`C3]($DIP4
M*<SB]&'[ZZO.)BM8!T%GVM&M6;MD6%`I45QWN#N$$'EL[$%,K'GRL1V7'\4:
M=15QT)F:/@-;R+U<EIOLA%,%T\@*YL%UQ[2@@)EY5\E-3'*<<=R9W-U>+T]+
MFZ]B$1DKN"^`?.Y/2$(EI+8-OET:_EE@]W5$^ZP]*VP&,MA#Q;8^/31_"6%O
MWW_[]?"%V&":@">'`50,2[28PI-S#-OZ`X_!F6K*6;5/IW/![79;4^/$+;B=
M+=ZWVYNEV"`&"J'5RI/_G!K7&ODH^X8MW##6QBUFZ#VC8+?9[>TF`S.G]5B?
M`WJ!%$D,VOCO^X\?]O;V+OJO\C[QO;1$OIW73M5*''E('7+-<*]DXYZYFBWH
M+89V,M#RYV3PM`S2:>:2-RJ>Z34LN/Y/O:B]!";5IZ3[SQY;9X_[0=8`LMGJ
M@-WO=_O7O_YE/S\^5FI9#,-XX&GZ_N-'Z*Q`B]XPC;X#N^R%^V@YCFX3`]1'
M+VK(<>Q2N>@UD?%KMJ;8VP4D9@'!3XD7S'TUA?<<R"^@YB03L-(/M5_7;^0T
MX`)G4X5TY7N,P3]F=_5ZZ/M7Q6JP`DY:?4Y"8X_723`VG\?(*XP,_L+,K5DO
M&J<>;TFO.WXHUBE.ZISV;>Z:Y&;5T-LJ+IR84U@SH%DT-%SWY7[=9XD.@W)Q
M6Z'J=C41@S\ZS`S-S-J6!$!B9D,JGUAK!L:6I6S!_YV]\V/'6:T.USG_9GC_
M9\+FK^D3-B`R!0>6Q;]GNN6K@+U@K5#1N2_@;FU)^Q:W\@,+3_"ZI@\+7;%3
M;.'4$?;^<F62&$(WN[V]6;M:I?W!9BNM2CPJ:HB115S`O;QM/&:Z;A9--[=V
M.Q>3-<&NG+E[MKI:^WF8MF]-](SR3H%,<I<NXDMR`*ON@>$_6\5YFK(U#]/K
M'CP#,65+[\_H.>F3Q9/,#O.R*%G7@KY1\&G=/?[GL^(/"V[GB7HH\$[1I(%)
MCE(1/J86;+A.UJK;Q\\/,S/[\>/'.8BV._?!8/OM[2;2G+5?%^XDU8!E8L$:
MM7*S?C%&%H.UZ$6\Z^C3L`V66Y,A1`]LO`[]C.-2'FPQ89>WJT_"=SE26/!J
ME1&C8OAM:(9]?/]NQ@X`Y&G-6D]F)/F:G2.(;6I#![,_!Y'[:L>[C30S70,J
M/6X+]Y+X"8/6,3Z_U'7H_+[!=:")WEE9QTZLI_R9UM6I/>6+6XB0;\VG#1H<
M9*_)OKNA@WI=%R=MM.A>83(0FQHE[C*[X`@A%V'@3=<GX[N9ACQSG"^?<]'G
MF@[E>?/M?$"\1YUD9JR-YUAA'JYV7Z7&-^#]Q[&[>)X\'77CE8[4;.:B[R!P
M9;^%';CVU\'H]@/=]G(%/+?UQ1.L+S&>TY3=4B+#*WKF>!QM>OCZY<"@K6)6
M*74:%(G?X-9NI_W1T1?+!6U.>8A@%(K:-PR<)'DM<YIN736^`Z",10*F4:RQ
MQAD;0#^VY5*ZL&,!+%C(SX_/S&B:BRZ\O*6#7=NS9\DC961Y$(ZGQV>Z,%FT
MN7%K]9(0M"8%CPQA>6S<5L"X"7"2X)*`0%EO79MN%.EL'MJ%PHA$4$1<EE?G
M)H!686L48#H!XLCX3Q!Q%5#=3M#[]O9F;[=&4]:9^1[O,32E;^]O]L'W4`"U
MR8ZK6ILX94N&W#866Y=?*ZS/P2^_G!O6L[B*IZ&!%>WVJC[,O)FWH(@$7<\9
M'XSE-A"`P0I[</T,T^<V+K+LA-,::83=$G`^P>4IJ6B^V-)&PVGK+#>^$2PJ
MSQAHKV'`!;`Y)E?LT0A,J3?T^%A?`]Q\_=IY`&U#=+B3)1<OL9X+<%`DL\<!
M8KE978"K`M]37NL(WMJ>-[0%A,<U***LZ3K$8ES,-V`B(P')UIS<#Q(K-:5N
ML:.VBC5EFQE\5\FMEZ6F.']X(MZR,R']5.GHH`$8WX#W'P1V$^##'H"YVZ-&
MJV2@/Z7%9JYX_>&O\KJ%U5].*]O9++@^H(]=&+#O-7E@QF)["EZ1B18H`NJY
MS;4L'<=.:=U[7^/!`22.H9VC'P3@43"K9CQF#*6'DEXVWV/#7Y&IT6A+YPH,
MH`LJ!W4<]SL%0QBU0O-"Q>=2W79@_<QJ+:71I1]TNG5</B]K`,TLL0,UY2Y[
M1<"!GHV1U@*\Z7?N);V:(Y^!AB?)'R(.E<0V-W$>W;B=<*J93&2+=A#4?E4&
M2=0:5[NX:C$^&J22PHG`5K=NG_=/N]UNTU?(BT7"+_ND<2):NYGYIPR"LJZ3
MP6>Y,H$GQ-<U;>T$L/.\MV;6NU[WZX)X`MA(#8"3S>M4<#&C_T1;A5QL=^I$
ML-UD<R^'L1RK+:R?.;[K>._SWV;G93X[EQ6;$Q/93Z#?K_3(U%]#8/7&^7+]
M_GQ.^^PD='4[(!`O##-?U;;\F-NEU8UL8)14U'N:6YA*DYCXRL+06QCDFR#8
M4^B(K!E."6VF*8B>#-G<=NV/%4B$Y%GMR'L:RP-F,(H4&L5)$BLU?D:K==&I
M\*%C;71-P&YQ$)F'$Z">W1:WY*7M<;T<;/CU#M^`]V_R*T<TVI-V_`,PG+P^
MRP_4Z,,]SEPW]09M.($#/!@^BV![-)%5O[/Z(*O=2OZ8.RLR+^D^VT?$N;0$
MUX\C@9"HB<K,$)B4".]G!`3=1/T?#M$GJ])/O>,#6X+Q">_O[W;<#V(5D4#+
M\X20?54BFR@B%V17+',L7+PLNA"G,$8KC8"4$Q"N@%MT;8K#?<,)`F1(OR;_
M,\,7(*F<VS;;?NL^]9!AWR)[BM5FG<"&6*G4%JQ\0T5'H``R#EBR_=RP0_+@
MPRDZ0N@&Q=>G76"E42N?V6RY5]F?F^06PM)!HZ$]:C'C^N<*`M#[!%6R*T<F
MO@V-*.S`_0J(Z'IM8Q()3E3BHGD_@=[I@7H-FU'GXSS&*19-IQ!!9H-0Z$4W
MCJMIGL#,"*M8WQTVPB-1QF8CYKEID,2$&30DVIP>.P+;_73-&#*MCB5I.+M2
M73UH+VF$NYNU$91#7N(M#S@ZRZ38_SC$^ZX@G=5A\F"BUZX!LW&]HF+?J:"*
MQK7G^6@%-7'V&?@)\P'..G(:+X5"Q'OU/*<0IX,)T$+LKGNP>70/`XBZ67A0
M;V^'D@TT-&J!E44`BUK$XO+1KCK&+M[CTOXIUKAZXB)*UC0B1-_#*?:8B0BW
MJCM5=[B_`>\_A.%])I]-9MRH?0?B`-#YX&F6."HI@.W_/6&=EY09R";KD4]%
MY.ZR)]HV`2UZZFPBTJ"I[^G?W4,>_(2NRII4$_)6%2"TH@R3;V:?FI_)9'BM
MM'G@@0L1ZV\I=O?]P!%64`(/-<P%SMW>W][MZ$?M3QO/-ZVH'C?@31?#V0K6
M%S]@M"F:YWM:._*P1P,<T@KVH6=SLFGC@D93SG8WO[=&LID%,JH\^=AB]X".
MD."BK6GP0*55K=^AT<,L8EJ*AW5?H+=BND7('!ZZ\5DMS$"WUF8R57H49_I1
M);FP%>'J7FJ]5P$5UK*..E>CLOZ;U\:7+&(`]^;Y')B)%,G#^I@R(DQ#&EPL
MWP((%]K>$S.'32V/'I,D1QO>+8H*]OL,K7%M#)>U"8*F/&-*)#S()];WFA9M
M'HNCDXD?'05$K6@XI^?:`TUYXU;Z!7XE^0S$&*9PF68KVN#J7"""+6X+M:5'
MMRP9C*AJ`.JEI\5RFFEY[6?/7C"*Z_T:2,O;1D]=J77=.\]C>%S_(U.LPUQ`
MF#%PVO%)$SU?'U@'-V:@L\A>.WTMWG79AL_4*<@+H($M.EJN,I+\=GW&-^#]
MA\D9-JJ"O%ALMW5-2,H3CO5ZZ,%+D-.D[,$QV>/FW,-_\*H-6V!*WY&7W->`
MN`)NV-_,QF3VFS2^A33UI:DI\H]4IX`U]5R=(]EH*9D(VT??'TA$JFK82>]K
MJ2T9:_1;:V9#SE`PEH]NK#FP,C<`3SD'YR+:)LO343'Z'MCY5G<@L`"+;@"#
ML.,#;=K%#`SP]-2?=CCDMQ'2IZ*VKHKJY7\?'J.G+IK/A%K".>NT.5``VM)V
MJ]T(O!KRD6+!17<;P5;V_\U#D7+,KIT'-R^9=@;^;V]OZ5Q%><[:E-O4O(_"
MM)/I_PE@002=)\=@?EZ&EEAEBUZG'8;[?'PN"K0J+JE0KFMMS'T-I5.\<@]K
MS60.!13X?(^TZ'C+[AUCQF!Z"N>!0Y;;C+]OK95[UV)Q&[G&%&WFXO15WT6(
MBTM7S>N[!\D70J6Q@%@7RG<6?];".HS)UJ88WHV'M9-.%)2PMU[CV66O8S*H
M[;IWQ4G%FZ1LPO8:]%'PS,&Y$,X3ATJ16W(Y94[6I06,YX^"97R:%E@+FC(C
M@L*YA/=#[:ZNX\C>N^M\<?<1X6?L.UKX[R-G>!7TO@0L']#!L</]+-4MM9#M
MN8X2+WZ/QS^+4$%F4+^56)2<-C:BAMTUR191\X'W/<['*]?.'S.WV*)%<I7P
M2L&U&V**0TH\N9Y9H-R&K;_5V^WM6KQ[9CA=%S4^-@%-O%@BWI,+YL?S-[TI
M*Y`5SG.GA9-9DEX4,^.%[=HB)>4G#8\Q"`X2HHWE4QGA:D%@0ZP6J(6*SO9?
M&HAQ#A\Z!7<@M/+#O1AUW>2>L/2#EN-C"SWPN%_;L-"RJ#,?S7OJ,1.XF6SJ
M:%N:VZTU>W]_)Z9Q#<,!.0_.F]MQOQKLQ,+WZP>Z6*+E[.S)[EX7X]X7>';W
ME.PFK&CLIKG/Q+?6&H5,:('2"RWI9,0'1BWT^.-U;.>$2Z)AZ,+F&PB$$#,J
M/LG"Q/G%CBT5Y1PFQ.)U.Q2`<-,#U,%S^<[Q-1J%/C]_0VL/$`U(OX_`8:.A
M2+^6MJ:R+G(G&,.#R2YK`BZDH;')Y-(Q=I(O=8X&AR#(^;/>7&0%AZE3B<KB
M-)Z:NW+\#(,&ECG6.M=HP4%G]"O]V=Y4[%:H61&X>D$O=XU`^Q?;W/)&UZAU
MEE8Z-O[?`O9-[K&QS7T#WG\(P_L,76:-S:9UA1JU1M#[3.JY_=<7$.\KC#+U
M4LM7Q>&,_9%YBL=*4_+1;NQ5Q)ZIDB>OJ36Y$':H/XR>M<#N,C.(V/R."WF9
M&N6VF]TJQOJ6=K4U:[=F_3CFQ'E:,3?:\#BW6RZH7*U[#AL0*[)=+0%MH?L#
M8D[E*DR">VTMXBJTV3&VT?>UBJKUT,QCR83'"%JK6WP.U4DO-0>T+1E;L0)\
MB..^-(;HO6!`8YJ3I2*""P%^@OLF&,7(!]C=[????Y\L(M\/.^G+^([#&K!=
MK++:HOD$AR#]84SO8ANC="^Y">A>\@R]^X84@.</*&%A!C,P>)V@W&WJJ"MR
M9*JZ+G/4,3@VP'*W<)GBX*MGX`);`V[340*NK@K.T0)+;S_MOXQ;ZT@,*`I0
M(V=:R!=M?U?[)&BX:@W3J8W>&JZ\V&L$KVTG<!M^C6`.)V<&1RTS84]EP.C8
M5_]C;46QN!P@KJT",@3YL&P`E?S0BP`0C]'MV<X.OF2"'"[C86_A!\"EZ,[=
MKU044EM,A(31>.:%;93=9W35S!M-3#3U;Q_>?P;8#7/\FK]NSQC.P(6\@&1S
M\Z'((Y?F?DPU>PVKEWBS^`>\P,`^>G]9'EY,OTK']J)2(;O50]D(`@AQ0OA,
M)KL_>=B+]N&&=4Y`&S4QCJV/,L0WE$_L[=;.M+CC,`MI=4Z:7T<8:!0P6=O\
MNL<T(A[Z\+")>\G;JT4K@3Z.=)4""%I'0+>K.-`6K?C*QRJ:DC(`CE("?CX+
MC:K/DTD;KAO)*=98/:K:R$*ZDNM]Z%'"P$$*EB-F+093A(C=/B)C+^NB=OU,
M<P4F7`@,QX_W]_?3G2'<#RHY*+QNO=FMW>:6BMZ+H:[S_'1>#NF[-?ZL>"WI
MVGLL8H!A\&?3P.'\TWKR+P:[HUN_AL`&J,1@ND.WQ8JUN+FEZQB"7/,BZ6Y5
MC$UT4I!!9M?C9HF#1W`S-.!$++>@=]?6^A)R\*SB.8@66XJ>B]MY?ZXU3H>:
MV`WB/`\W#UIFDNK)O>_K`9O@',5V@2@M,!ERU0A<%XM!=,SGP^8`6W9S:9;7
MO=RPSW>*NW[/Z":L'38GPP1RO!@`7J1T>;#0M*RC,".$K%`K^GSJD9QM\*AH
M'T]4N!AN&KTGVMW`"GX#WO_RKU?E#*^PNWO6DELKXI"2GN*7HXAE*WT1>18?
MPA&C1MGLK]#!_DH"4VKB$,J*L8[025KUB;2G6@XEO[34%$[,STW]_OEI![`?
MI"ITROQO-QJ,LF1\OJKPW;'6S#@R?>XN]8+!K-UNAMY/_]W$OB$7+46-X46%
M+P[\)'<8S`SQ)93MGJ4<77(H!YMA4T\J]E#4KG9F?JXA&/8VA1CS^K2A`F\`
MLEB'P40M)0@TC6-&OF_%@FFUM=FB3%\?1#W0^]#IV0?4MDLLGWP%++2;&^>I
M*)8*>F#2%$_`0+&I[BX.'CS8_O[^?D8+E]/6C_[N],!^NS6[M3.V^[BOA"@,
M^[(+/+0!--%I,%+MLL:C@(<A+*<<HETHU]UEQ7$"TFM?=C'BCYVGP;9V`G8<
MF,#'X9NIA,EHN]FM@!T<J.(.<1OA]G#5O?!M@`=20?\HS<YH3F(`;:](FE53
M"4WL#]KPXWRU9E?A8^<@6ABZY7N*M;0BZS$"T`2JF/EMY,*P;.I",@X-3`[V
M>/IW)P>2M:XTIV)&;,4HCCKVY0:#[G0DKEM@W2V!=KM0S%Q',L4SH6,=:1C5
MB3$6]Z=J3[^D'['`3`6/1=VV`F5O:H_Y#7C_Y@SOMKF]3=:R++H-FQFWG_W)
M<?@60'Z1*GZ8&`'5FX4!N6>?^9("P4M7:F4"0Q'ADA03!JHMGM[""8%0(@^U
MM=;FIE=OX+XI;'1#:;=;6J`,L&CNDD`Y?5YK;F]ORZS?]?])*V]\3KLUN]V:
M?7[>=8(Z;`ZH;+B*8H^-\>&T;!;:P*G4&S]WI?NTR""DX3&]:,Z@MCA'ISZX
MBN]UM3"C]G3TR6S.?KDCF,"2_=;XP!;:>BA"*D[PZ)8)-K?;-9U<W_,P:RWX
M+B]0-#Q#6]-VX#3#CX59"@Y!O.7+^&?^9M/^K)U`^<=OO]G;V]O#]3%W"LZU
M8N0T^)5:-7V!!]H%S&^^?L_I<621AZ(H\##-SZR_.'DT:I^V2P4+!2^W-@H'
MY`X"69,"W>APISNQ#*FZBR3!66K#EZ.9V'&MI*WK?FFZ[CCYJXX\M#+Y4-KF
M+(E8LHT<P%"$';EO.G95##14YN,;P,\%<QMGOY<LB1`%`[QUD]0Z9K<M@4</
MH0Y4J%^DA`_J7S37];HLZ_P5U;:^#@Q3E^SL0Z>;K0^@O(**W"L=@$Y7B!6D
M;V0#._+*BY:7J_S'<[LH#..I'&7=>M@F)<)SI^Y<"]JTU;-O#>_?GOO=P]VG
M.1$HAY:VZ@;@A4]^#C"QBVY_$95B\P6]U!5X`B\[+:\7[$;EJ5LZ1'``4G1F
M$D4'N,^SC-T9B!*SP]/VN4V.Z<7I%.L\]&/N9F^WV[4QNM+/[/^(?=$R%IH?
M/WZ<P1''8??C6.;R`0S"8&_MS=[?W\?\Q6F?QL2%>^8G'Q12B=N:[6%;4^8A
M#$2&AZ!SU#X62LNQO`,9C%=TZQ>(9Z_?K%7FG((5PYD+NMF-QK(@,_=EHT93
MX_S:=KUP,3EF;(,'!'>"ZXNV,#U>#>OQZ1-+/P[]<)8[(!=?=.['\?51>KBV
MPE/7Q2"@5$`9LV`P^_';CPOLXF$G9T2N(GQ&'^"T-4,_@C89\SYE0+O8510=
MH^$PT=<=*INUBY-%!<I]#)%=@W=C>&Y%,NM=U\6W=XW].S>+?46QRG2\A4`M
MJ:=#*(T`O.@H@B!54UI05N"F+>=NN?`?/S-\D=W<EC0[)#]RQP'JJ#+^VYJ?
M7L%M1^VJ_`64_SZ>DS;L[H;&&X74K%U^P@X9W.7A+U#+?U@VQY6M7[[%LQ@O
MF6^)!E'=<,EO=?.;3[]DFT4KRS]\:;Q;2:'*=4V=@8E636=!"J_U%-/.!`Q_
M)F=/N"=WARE0\/".P8><W]_=MT"<N]CX9GC_SNSN"S(!?!64QA8:#9E@YV?P
M2,Y0D+15*M63XWO9MC?QL>.FQPOI6_%/7KSO$Q]D`D^E3_$8W,*&?0X/9N\]
M`.Q-`(&TT]94\LGNH?`&@0``(`!)1$%45BP^V6V1OC"BN.'Y.W[=;C<[CJZF
MY"0Q\;%I72W^S_M]V0XUW^J#'Y'^Z[V7=LW]M"&SOCQ<LU3<PR:^F$K^%"E2
M/-O@8'/"$1TM&&!$+;%I5#.N\\%:7?:<%FLQ,7&_!L2:%U\8#WR9=;#-K]2M
MBA)-UV=H@!\WC5(\<H-V3CJZ1<_-&(Z!1+R#BB1<FMTBL<IC<8IR75O7HE]#
ME'W]]+!CXJ$A4X>::0,G7>BH/70BYO-`8N^X"A@>"K(5,7QMWA%PN]3#'F0Z
M5$##YG!;_.P8UQPC>;?W##ATH\NP592MY/??4POQ.63G#"0_R;;D5]09F.=Z
M$@57$,;-0TL;A>2"UA9A\G$-5I+\@#I-$%!JY6";!#$UUWD"L094-AG,2(J<
MJRD6X%CQYBFA#LP>!\84LD^0E_%@3`MRR[AKY"P'&YVN$.%L^;SXUHA?_!5F
MLA[L\3Q)'+Z5`A<,ME$VB[F`Y_OC&_#^U\"N;1>(5PE@Q^L$:@)6+S*[3RPG
M4^&($MGLC_/EXTZI84A\+?S5-\ZQL/LR(4@<K/Z>`.Q^_\SZ-V3OTJ/WJ[W&
MU6@TBK')\JY-;3W,]_O]E$9LAES&AG5[>SL':@A@CV,\^F']H]O;VYNUUD[0
MR^P88NX-9HOH..XD`UDMN+ZK-F:Q$"TQR(.70!@\L!N10H277KS2L?>]6)FU
MEE8X%<@U*P:\TA`0>Y>.Q1K(=Q;K7JE%JW(9));7`DCEY#8`P;M8HTFK&UH:
MF5Z!(`]LI<F&N?R+NVB`2U!:Q%P[V46YF7W\_&F___Y[Z0\M28O!20.AL.D=
M=O_\5/#-15MQS22HQ!0H[ES*JV3,=K6L3Z;Y\LD5ILMD*$R\59T]<?-6`&'^
MEZM#S<Q;"!:Q,MI;P6M/25<(PQ2\_@ZGB]@OB](7?@T/@(DF-UI_H6;<^3W6
M,74!B?/Y`6FEQWF@]#T&1_#`,)+O\=+:JKG7[,B@D`\%PV'P>@/D4!`\&5*1
M:3R3=%*'/G5%=%(`[E84).N[B>%(F#:>6G</\QJ>B3!W#_[3='112E(]830W
MTB4RV'.)-<^ID\]R=N.%?4L:_IN0-[2,O@+_[)F4]R5VM<`>+U+&+_*R#US+
M_"O'OA$05:&+.\"=90_8]'^?,\7Y^(E=V60SQ\E81+<(0'LQ<1.FWQ_7]%`_
M>CK-;JZA9I<796MN_3@F*`.YB']^?EIKM^!/FA6D$T#A_.S!GF##O.E@?TC^
MTG%[1AN+48C?C0<\=U9J(>8:X*EAC?3D5C407":Z`E$%BM#)X2IL@J[QS@9O
ML!7+AFFU(8'80,TN$6G@E1AYT(0TM\XY^M=WY]9\TZ(O;,?&9PQ6FR;2F=F5
M(`!O=DRP=G[+C\]/>WM_OV0-7H+*5N3K.MV7GY^?]O'Q4X!6!29TW5A@:`!Q
M'>*#@"Y/NOOUO2U*(EH1I&#!TJP3F*@L)4.4<V2G=ZNI!':TJO`4^EX3[SP$
ML6PBQL0JZP*_PS=YN#Q(V1#<.2J'S&AL8H;BWO0%TM-R'],',<,T8HSQC!WO
MO6BM6W:F"!Z^<@]"C`57E*^9RH^"7UP:O-KMD="]P<468MV'+::BANC?L^@+
M:\+.E])4'ND(,?-SV)Q![ECWPK/FGF+N>:UTV_CC3R>:]2+94SCX(T5Y*_/L
MWX#WO_?KE]T9_@*8O0.D6[SG`8M]E4#]LZ#7OX:SG]/)_H7C]M)/MI(G[_+,
M/0!MM?JJ3VJ*KPW6<!M<K0^[N=T_/Q^RZN,]!V,K8,KRWMN/X_(+14&<LN>A
MAC;SL%]BI5V[#AY!35J0W;:B'>Y\.)[>@_-XB8'A#83/AP7F(_IAH@IS,-7B
MK?=UT@9>&?>2CE5+!'BC[3P,8AP!O!CBU7Y5L"4:5_K]<#*((1AN+L6##(U`
M.$C1KYNIARLNRS+608YC^/CX./V=FQ(!>U<`F^?M.`[[XX\_I)B3^[SW31=@
MW8,CJK9R&!"@:17HU="`1XLHM[`]4(["-J).E^/`"4$!V"QGV*SC'JZG6PZE
M0'`;@*D3QS0KB?[2>:U-FOH'A.9D_RD"UVRDV%W1L:Z=%?=L`"F-'M.9"9QO
M6/;[_'&O[X2-I#->H!`R<#6?*_32DO+\3Q?V$D2!.W)@1K0^5(<'S,AB`Y+]
MH[E-AY*=^,`#:+82?-=[SFBYL&PAMJAD$#"L8;',9Z]EL*=W]`/G(!'3(I&[
M#]^`][_%[WXU6>V%C?ME%/B%%VC,(QYAB)<!*K9,Z4N5PM?,?E&SO<]\'L1?
MT!?8?'2\`)[\G6_;BA73SIT^+UPK@G,^V2N%39I`M9NGMG2Z%B0JC#*1^P"\
M(1;5Q-2\6$JQ+Q(6@=%G"QC(I0.>I)5XT`D*^T;`R:-%&ES98;[N'!7JRK0A
M+.PRG`8(TYD86<=#$*=%PB-+%FVI<GN2K8QV*6_\>Z"P-+/H_;V&S]0X?_U,
M#['->G>@!+MF8PCR!#.M>6C+(TE+)MCMW?[UQQ]V]'ZET:%DB.61B68H-.P3
M7^M7=/&,U@VALT!FE"2FV[-V/6[MB.X#%J0T(YVM]X<^['S.6PH36OIS#LQ8
M[?$Z[C6N(6L;N7ZVUW'9L6B7A&">HWX8^A/\M4-K&ZF0)&<%$3D0<.Q(@&AI
MO160/5K32WET7#--([;SN5TMI/CWR?[<BYF0Q'Y#UO@0T$;@T%*T]ECW^[#J
M._LJ6W*N3W(B%^6I\R3`&W(_I#V5.Z!"/$#TS3J>`EVQA!)>';YOP/MW9H'M
M1<NM+[VG/QZ`*1I7->'Y!,W^(@G[B'@ECL2V<8>Q];N)"_=@SQ:+`7CT"UQZ
MT,?RAKAXUY(5O$"7X\'OW<(*&%MB'"]*';%JZ,XBQ"'TMS9(UX$3"][&Z5YY
M+=3#PE+-=G&),0TQI<Q\GS_?YQ=T2YF:IA;#H3HH3F4G4)ND)M>+^FZWA@9'
M"",KF[W3YH9T'^=:%8F%`C%+5EWG!YLVDD40Y'53KE(4(!S9B^C*!RS@"UR6
M51'^N@SO50"W8J*YD`-.S>YQ')(*AZ)-B@=MFLH"3C?OQ^F'$?Q4TIOQS(^U
MA>%8Y=82[Q\SE0QXG'0/$2IQF&O^7NX_2`*@%(=A.C]JM9GQE6*SHRXV3!TH
M8RA&4N>4C.MR?^$!NWR_K/D'?5T7V\0D3`-*AE<=)&`AK;@>-C:.?L:#;E7V
MM>XD^9GGB+7Z-"<0D/_I+,'7P&H'B4<#C?,<=3P?"*=P'`0]^1"+>'$MTMQ/
M*DZ1A__B7A\F;M=0L(:"C,WP&_#^G5G@OY;:I6$H?[@9>F#-:I"\V0">V//B
M+ST7GA[G#'R)AQ3G+D\>B\RD9$G!`DJRT04@D`>-<ELN5>RAEQ.=)0#4H)W9
MJMWY"A9%TKX.H"!3+:X.`)3"HT-3=6N2'=OBY7)DDSB7V,J=["?$OLXU+PPK
M)/<YE]9FR!VV79A\8A@18S<+-AJ/6P%K\&B$(?`&3:`(RSJI`F-1(SW=`%**
MGVNK'W$8K=,]P<4&`8,`DJRQ_K3-B]QCGM(%:,?@R=!31A>!Y)Q@)E&S6WL[
M=SN.7G9_$(JEF)C'NL+J&>7[PZ^'B,'OL,DZKZ'//\<"4[2N8:AF@N!HX0;L
MP3E0=H]V7JYIJ*RZESK2(*9X8/,SYL&KV&IM^4Z*HD5G69?J(S2'Z9I98=^E
MP'%('TQ8W/AL1V:X<M3T`,2RHGXPL:X9/1BNOW@AS!.+=K5&WZOE\UYT.2P,
M<1EJS3DGH4E!M>MM7L/$;'^W(WH6F$5<G=?R:GI!1?/LQ1[+][@X0*WV3$^?
ME./3S_5LW//?@/>_`V3_(CG#5W%OE0.!-$$@<#>W09^`Z:]8I;UZ[-H.-!./
MH>`5J"Q3K/01!C`JSUH7:Z^G(X549<NLF3.#5Y\M$1:DE9:65N?<>#I.Q\8%
M`ZG\KG+?M\H3CPDW+FTQ.5?!+S8S7!I+BGAX<3OR&(;B%(P7)LC%(6)Q7'.1
M=]49\@*:VMF6F<6G.ON=/6`,CH@QRDX;I<76'.E@'=-6H#+9-V+QT9?)?9H2
M?Q#>T`58@=:$E*^\7M]66WA<`U0]""P1`WNM%E\C/U,54$)D2Q^Q3RZL$T)!
MY.(Z<`TIMBJYR1<8+L!$"L'0V2IA=)GUTZ+)E0$N'NK6VF33'Z_`JLN-4^V1
M^%A$A3^D$UP8XA%F`/&/%O_4I&L>UP.%)94626E/@=$ZH`;9PZM\M]:6$HD-
M"GV\AYUGM:/8DX9[AIEX`[C7Y8A\#H(_=B!.=ICAT;H$6^X2D>V7HZ=Y@FJ?
M%AUN@6&RES"1$&'FI'+!@!0WV#!G-MU]O"AL5H>HF+.1MSS/\S?@_;?_^@4J
M]M7W'>;M7Y#E;D&G>ZJRLIK/2HL'[%J&?Q&HK[YV[)!X$,I))&L!/KGR!^)$
MKHGGZM/V/&M#/5OQ6&0KW?,`G8`AS8S)<H(<8)`-'];6XIF32.C'I?BYSFG+
M[#ZJ<>*B/9;:<6:)*7#W\AZ,"^G:WW89\M?&VYH`]!45':R?@A>U"S#W&O06
MMD-^.4J\?*]#K9E2M'(8`(JRR524AMCF.6V^V1R=P)N39QZ25FXS8#0*+[C<
M=Q+'761))RD"K/109?LH\Y;LK8#3?[;WTVNW7=K:=FMFG^3%K"/S5WNW19YK
M:;0O_UF.'I;OZ]'7,W>'$@"`R@6RKG'9EG$8C17,,,S$DWJ%V9@,:ZUAV*B?
MQ^7#JJRO!4WMO"^\'M3URR]W!;%0%#R61S@70!U1XD`Z>*U$"R#J:<`6Q?I0
M28#4[WE-\0L+BARFP39W'7&5(:>3D/L9]?]U!P9C/FTE-(:0!A=6UU\FRT"?
MP>[=+H-?%W`,@WY,(#CM?3MQM5_)(<ME(<,".+;M*$GB+.S4Q/E&/=+F]^M%
MN%;</^<],P#U=]+:?X3/_6O?RO_<^WK10GI\Y-A7R@43$)-2?OE0W4.$+^I<
M]P`:%]A1[91B>C\],V?;HZ\X4BBCJ2)8T\^)E\8CG@UZ5`^ZTJ19C`4X^>Q>
MD^U`,4!BD=3SHLD9=&A%:_C5"\8M^04&4KZPM,#GA*W8>=ED_9I[8HB3A5KP
M#N63U2Y0,6)JX\59802Z<33RZN16^PQ3"!NQT\_RHKLK!&K&R4?*J`*Z@B[V
M]"RP#C&FN-6?%]NB)0,6BB0QVXR=A<U`H;N5[<]G3'G5/I[(X#JF^_UNGQ\?
M=K_?Z3R<@2GO[^^Y10M]CLYZ`',8+MWFXNW*USJS;E%;7)Y7@Q0(*?2$NT*3
MJ6>7D";.$K,P,:??IT-/K#,G9BVF6AGH<7O/:.!BT&U[+Y.<A8>E/!46(*!S
MI>4A.S)ZLF9#8`:]2@-/>XZ'),)S@"^V*L*]<!75GELUB[3WL!<E>5`\=Q'`
M8R8<CZ"3$;$]K;XN%PH%OC7_C`*4\@#>^C?2C'?MG,6I@59L`P+V.U8,>D<H
MPJCC5E0`PN_+^0X6;;'S%#JNL9#P8E!0[H7KW[\![W\:_K[H,/"0%RYOQ*\D
MECU^+>(J^L([^Y\X)^[U.RQ?/Z5TW4V&FR)3NIB>,$$]8TV7E^/Y@#<[K(<$
MK%U++&/>2](HVC17X2P!DQID*O-V@2(?P-S-NZ_`BCHAV6;L:FGYX\N+DK2G
ML[@HZ,;HKPN>8G:RY`FO;7.J_1QJZKW+0-'POYR,;/Q\G)&<#";F<%21W3[N
M!P&OYF*^[`;KAQF\2QMOMK@]V`()U=.E"&J^)I<;'9N\=M.:%'_@6$NA"B*P
M(AW)I^:2"PB4[49DYMKB!'_V^%7S_K!VN=8U#*P'N,CK".LKN]Z7]-V.X]#!
M13M]HC\_/Z]X6I+XF-O]N-O]N`N#.B.[JX""N;7[8J;A$OPBVV80HD^1QJWI
M/>V<7*GN"L>54*B]\'7]D((D+F8W),(C>%*E03M@>JP.O^,Z30C*LO<E/I79
MI\T0*H;%EFMKG/67`)*'\&2)T2_0Z^*Z,/3L<_C46.]MIM/W!3/)C+;<S]%D
MJVC-NZ7)WIGLYJEIP$GQP3D!P>M=Y2H#4;+["3]7DSGV('<9^U)LO2!M?_.[
MIEB0$9E\HMZYEK$,`Z`H7TD=/#_[,"3I#MM!"LPLQR*6YMD*AC:1:;X,+C41
MSB4PJ"Z="?Q>7^8;\/Y7@*Y_G?JL#?.^ZC+V&D@%V^3@(9`*F2OU`9%,:1<,
MJNQ>]*<,((?:?1TKZG,:<C>;7J!JG$6YZ1M]5/;GM`>VFAX%!A)#NK1M;MZ/
M@IGPH!OL@<%<(+5=WIU'+'9@8AX_-&VHV'`"1GTSK.ATS!8"*F;[U;/NE1<_
M;VV%!#BQ6)12UEJS6VO74(2RNO&8)Q/?NQC7S[/8%KMK5PL5MI@R'VQY,VL&
MZ[T1`*KUCJQUGA&7?GVWV_G=WOS-COMQ;F#B_\KV/.J$L(:DVOS)Y*\*)+G%
MO!9%7*D;.T#4/KD:7.!IV%&`G]?KP7BT&X&C/+#HH@&LUD!V&F#9R.?GW>[W
M^_R9-%0YP!!4.VFNS@WBM4J`I=%@GX4(4RLW82HPG!T%/#F9",L9Y%*M44N=
M&CW.PU(RJ+3.]:X5!]/`E^AM7;%\@';/8GM(\E\LVAE&_>QR(!@%8T>_0$]M
M1Q9E7"#@#:A'=?2J%6:>?HV_[ZR-IY78+_WGNE]JQY(4#L+`,W389QUL#/HT
M1&05M9`NP[KG+(6;-&_GVL5N0-$)@^Z`Y)IA>[M-UOISYT.&D;WJV)H,CT[&
MO*U[%5-6Z:+=]9!X,<,^6+[U9.B:Y0BZ;:NWNPE1A40>C3/W#7C_0[]\(Q!_
M!$>]&#;ZLY2J%_0J^]RAJGX?&JG;<_G"`T0^]AE.O'+'\K#<?"0H40HAR:QU
MT^G5TE.R3VBZ)J]1)\I)0IBMYLYU[CKO)B3FZB&B-+:\!ML\V!U`FS%`M][=
MR'TGM`HC\Q*;.28+5'(72)(,%R:X'WT._(`V$-:"=G0QGQ\3_&-E:]8,C8W_
M2=?85G\!@.'29BY&>AWS[7:[COV0?S=7IFHP)DL_>6Z*/F4L*@G@^^.\!AR=
M6K7'?24T`6:WDW3O1U_MR'Y*(H0@MA[:S4BLJH8@9/>,4>QA8U"<I0-9P+2.
MJ9L.!(96,%F.Q<*Z0S?VO2T?RJ*+"Y_Y]E."=+WV.-8]:=IJY^-P\E]CJ#-L
MJSCA"^*A;,F**Y?P!.J:)V;UK)FN?_/Q9RO;S]5Z-M_?08I6WR^SE8\K%C,H
M1=M5^$N@A.W;_NQ9'9ECN8XMIL5Y8M6C[VQU[.(BL7$4T6)7]:;)`LSKS6C)
M&+*'<QD53[_ZICBT"^R*JP_O$X&T.&4M(>`F%&;#8YG)!5R=*;_D&,E&#;9G
M>J-3D*FG_'JNU!VF)9L.E1*TV+4,W0IK+A*>?(*=NDZVB1)W/0XM4:GH./^V
M&=>KD/JULS?V-^#]C\/>EXG<;,;\%2K8M[Z2BK8BBU-M6D6ZRXMX5I[!1Z7<
M9=;M#'YJ.=YJ3Y#1].@B#A*FFY5V4:R;:\R4@#9]BI"UT0HNHCZG83L@QU(-
M$+H8;[L.LTQ#^QB^=K(6L,,:6AA42@C<.`L]G3G/C%N<E':68Q`X/HXN6F.?
MPT0^Y14R2.!N1S\F2S>D!GVZ62RVE'5O`^SRYK=DUBY`>;!AWGSJWR;8[4@I
M5!UFM\$0C"A1CPR3%CR\^8_S=0L2C/.>/<,\G9G99N8@#2:SQ4%*H9LHDF2\
MAP$Z<3&*;(CE0B_I"%TMN6;L*KE@K+FGD+;GGGHZ")Q0%5`P4J+FM1JA=EWY
M\.`1GP)4XH2WFZ]BTZD([?.;*/\)';3ABEMTF-V6'5-HQBVO5FB70W21U%@.
M0XHJX5?Y5/.VAM-,8Z"MT'@+F^:%"P14RB6G*@X63<>%EH:6*I;8-P4.?VZU
M04393`S;D.(%!+)!X[<>.R9>LGK:+M?5;C##$9P:='!1.P:>&.?S9;QFY6N8
M9$#&PY[J(K)>$]>"PM:-=]C!),/*GU;F?[@O=+E`+OKU@$6J6.W!K%X=&[]F
M9\QT2%#\%:A(]GA#R5"OR\"WA9^O/(2'+2#+?UOXN6_`^Q^5-#P>#$J1KR5R
MM&VO/32RD]^AC(I7+4M[5"6_$"?\@."5X1ND]>B%`3I,@7L,/-AI@'?.P:/:
MAGQW%.S!M;C&&1Y:#*&*_&L342T7;44A^E`MMRSX;^+"E-V[,$QS4]T(]6,K
MDJ41T<P^L[S+>BB!IP%V+U`Q6&F$Q+A^^:(.J<%P?#!$P+**AN,"O=1?7W("
MEH]<H+.U-L,,_`*9=FB;USP4?I7/*AO0@^ZN0GYBE[Z-V5#W7*)&@,"`S8M!
M)F[[5F$"**,):3!$?%PS(%KLG<:41@G$8G\6@S*[%$%XO.R$//1U-?K6R?JO
M%\!5PR<@3BJ5%[;($&;]%[RJT?4[\K7@YY(_JP>@C;P>:+O=Y+[1P<!(&%!W
M)\G07(8R-0A%P2XG/JH<HPBB4#&N,%W"!)XBGZF3G``2T#UDMZ;3M@+S8(#0
MM/MP$0*CJRYV?.9B!<GW#?>WSPY2LWBBHTT<2GTGGW.^_SD$I1Y"E+4")L-_
M@RQI=G6\N&B['$`X#$>2](:4B"4,I32E9K81`/J)9\OQ+@''7`2QEMB%T58]
M!RK`60ZD8B^O*-9_UCA(PN60`T7V+76]?$4Z$SF"P@#^&_#^Q\#N:\SNCHP%
M5*^Y%T&$-8WMQ:K7X@E(?8)FL<??"8SQ(H9,0.:*%=GX#/98H+Z`CJ4';`^D
MD6L!F7B&3(5&FK2:KB];U)?&.`[(],$2PPHM%0%@Z-3]SCAC:0Y79OK:.9#2
MTMRR]S)+/4!@V*9#P4$`(J:OG>W=!MAMZ&@=9MX%E,#;Q3+VM*#.Q6^<%RNL
M<N*DL8_%?$D=&LDBSJGB+N<R`@[V_M4G2;V)ESW38.G[8J]OIV=J`^R8D@^6
M7:1U6#<`<W'UT#`&TF+#,LB&RH7TQE!P%%NCT;Q@18=F)C`-NH7/5O#5Y\&P
M-":"22\&Z=+M3<?2"Z_DT]+,I>7J`GZ5<9N>PJZRH"5;XJ(HXBP(Z##S$%`0
MB(@B^HU!_<[^SZVX=Q;EM8KO.)E/0(*$59G]OP#96M+4_JLP\=/SSCY>;FF@
MC64PJI\.MTUE$X;%TLT."%#%-$[I5AUZ$8MWEL_IM?2X-L;BMY'6V!9X;Y2\
MZ).M=SU<UWMP.!)XD/>(/A?9$VEY*:]YA"G[8&:GT,4`0@I/XF9VDN!JLP:3
M04Q#[C#(F@/:\ZQ()4K^X"0Y"4%)\;6R#U,A5'EEK\[8>O]OP/MW`,0O_,#K
MRM^_YK/](?M<?,XK&<A;W=4C!OGQ$;HKNY1RZTNF]UJL0BKC9)'3GD'#>S1H
M-H=E2B/B3=ZDF5A@*8C8R$D":*]LR4*OV9)QMUCZK*EUV0";YZ$HUL,.IC@$
M'I27;$H],"W'N'7.#@2LNS5;;3'05.[Z3JL5"1^."6;'<>F49^)56YK73DQR
M[^<T..H0BL6<NB3R+9(3V1YR+,9CF$-LSER!&H-.V3!B]P?"T%8%=#F`P\!Y
M,^1FH46YTL)"=*HM-G]*]-K8U"OK*K^<`OI5Y#3JJ.1[^[&9?I"F(*1+E6#W
M`CR\>=-`3FSOFZM5&;.$ZE&*8+U7;=:!??7]`K2LJ5P9W(T%&#\O[=+[&Q=`
MYJL=Q!V(81L6F70>*"HT=#X$7]G.=X)-!H:=AI'4!<9DH-"#6P:OAQ8B<OE:
MJ\RIA7L9<T"Y8K@K"SGW*A$S#N5IEW0X-C3WM'^-QZ$[0M%D,O`G81RRKU\#
M?[,`*>PD(^2EKN-DQKWL9TJG847ZPGB2HPJ8$AM,VB^Y(Y4?;">WB2C#"[:%
MT]J1GN?TO!`!@12>J7LOH.?;LH-#^X:;?PUP_,\!XR]J`?[4=W)ZW+U\']^V
M,'X!:<,V5:W>^#PXM5A,!1G3[NA!MB,S+XCGDX:W^+_33FM8_KB)4;U\/=:G
MC?=I'H;#3/6YR<(%84_2UI<SRV!>.%!8H6(I?<NT&0]4(3DD??`"P&3O9K$.
M0^'3.B>^N9&PIC^RA^S:&/ET#;#KWNQVNYU_OBS=AC74<1R7KA9UX`$JJ8,Z
M#_`Q^,[F*'97"HF(`AD/02@:9N!6IR[-`H6^PSS6Z,L+9>WX.R,"V.%L,=D3
M36:+'8$E^4#FQ*>T05EYMZRO*Y]-%(F/$CNZ@E6\^34LB""W@$[B#WWV^$Z]
M)P`=`>[XO!QSO+R+&[L/="@#2C[0XN<Z&?X%KAKY;Z_OKRU@]-,104W_6Q&B
M<,FHG%OJN_46V@GW/6%1I7!!PD@RZS#7P<)+M]Q]6A/9T_Q]I_,(MUJO2]'2
MS:<,0F<'HF6@;^Y$+*F/A>MZW<>LS^;[]Y1==25H/,]&>TA)2D-]PL:ZWH\6
M]BQA8O/Q5CLV2*8!C_,O:Y?OIMIZ&O<^_\W7Y_5K?>N@<VAUG#0_SW%?2<4O
ML_H2GF,)Y$O;%-]):[_.NOXW0+CO9`SX980;DX5CN[CRZ/RU\U1$7"8/Q06*
M4%`,[FSO`HUAO1;3%MG>,`F:)J51#*297Y99[7)AZ!-,<K#!:-5W/+#/<!KT
M:LW:'&3R)$^IVKHA_&S.]\H$A'G>P$RE`4`@40+SXGSN:1@O[W6%`'@[B^C"
M9L1V+V`90(3!I18VA=XY!<]2BIN`N<MU80#=#M!Q(-G"O>2_['JNJY8=Q'<Y
ML.(78.P7V-'6:U_`N"/,BKD,QSQ<K[BHX$GKJ@T=SAW21=#^ITSA,_M'OL`Y
MG**.C:T&87BMB<-3>28!U"Y'.I=.[*;+.6ZD\(%(2MA+EJT!JZAICBEF_V2W
MY1\>[VUX=@CH\IX>DB18LZSG):X#\OG\W"!VB;@-YMG2SHN..#)XY0[RB-WU
M(8-"I$F0$KD6$XW-/>!Z3:C058L^+8B]->NF(0SSF*"S&U6L-2BR7)T$5L):
M(^<0M,'^MJ5%O>Z7/@=D^Y2.)'<(6+GXE%(8+-B[%L@U"=:#Y9E![^&Z/1N&
MF3NF1=H,"PFA2IHFJA9R\L1%I94XNT"&0Y-:Q26Z*34OA?7UF/RZDFB'-,[\
M6\/[SX#37TDGKB8IGXD#*J&^F]@CK:$=/-8I#%',```@`$E$053R/N1LW'8U
MM"-J`FNP.V[L"7SL#"F8X-]OU\U^O6<;_IN7J?TN*9T>S-NM2<SM[78KVV)G
M*W@EXU37S6<@@BWC[*'K#`V6N*%.@!]]T9EA),WA9!^VFI/LJPLU!IW`N'=8
M[]"D4A`[UD$&YSEV>K!4$&W@6K%T=FY-)0]VKEW?K4]0$=+7BO;^^/O>,64;
M1^_6CRZ3T[SXWM[>3C#<#[G>]_M!@X3$Q#MGU&=TC-X-PV;.Z7O-F%@*4PF%
M22=H"(_`("=T)8#@=K6U"]MNM^2IH``IA&WP>K#S'F/0T$++TQ74"F`D3^<N
M\";\:FXAQX,\-]UDKL;4\LK<$RL^/**7;VN3`4F?&SM"?CG9FI&?JDA$;'A7
M+_U\'(8ULEAS.O#1:$T1JT5Z(@/?CCZ/UZ_SI:WRU?IN@[D3NR:U."3SP<M-
M@^*(8RA%B.OM\UH0L/55(`GPB?>$#6>,53A-D0BG9P:+,!A-Y3<7B[9D91<T
MRAQ,LF*GQ[GT$+H#,CT_?WNPU=<,(.FG21;X_/B4R:&3[Y<76);M^@JR83U/
M7`RM8[;@KNG.>N4E<1))UG4$G8#J>1N/S[]68-=CT/Z)E47_(^8<LG_Q/H]$
MUL2(J2P]B=U(YM1-"L)OP/OOAK;`0UCX$H[%J^^_)W6??DY8P#PDJ<#PIX,N
M+%2&NR/&0X88Y;!4C3;'XG]-(E=A"X4?ZW%TLRO525K>)TDKD^G-W0X4:,`G
M]S//)P90+!C6_,6OR-U+BPJ#X>A2W?-$?1P/6)7R6N1J=GN!WL$$==G(5VK1
M'#[RP&2ZD>\G'4M3!S6IT-W29W0"6-W/H;?)E%RML3'@U]&MH4UVK[,OL[L!
MQPG8>[=^\3WL'L#@]C`S\V.=AW8SV'VUW:[ADV%M!G(<&.>KHVOPBM.U'C1;
MMY1&%0>#%N[,C**QTP:"C^<87D$>).'4.KMFBRP9SK-0V>@:T[8;I)9Q``S2
M?:!BJI@8APS?.#END&>MY^;KV.P[%Y]ITM.K0+,+M-&@([H<FUK4/6B7D9T5
M""0QX.O#JBXV89#3[+*+6Q6Q.I[CKBWHP+*/9;S3FS;X>`+.SH&36=5UN7K'
MLO]RU8]+E(,3DTLQG4/&,><;`(G+'=[7,^:W.+U\S6<R8%L^Y6P%M@8K+2PP
MEQM.LCFCPFZ*8-K%N'<SM#@'E3>DH@LT"AV?QU*!.@RMBJ2%E6$W'@89H3:C
M:\A2Z:,.#6+@-:!7UG4&*3[<L\O/[)"@ZGA!&7KNM#UUNRB>'2OB@`7%HMZW
M^7-I+?70!1K__`UX_[:_=M5+!KMIP?P3H#H/1KFV%;`#L?GO\J3[;@.QF<V[
MEVBLH:LRE&(KG-C_%`<;G"$/^L`CY*Z?1.WM9+-B>S5)02S9>G5<3.-)2;!]
MZ.7KBA+TBO]JH(&`7%&O*?5+``&35B<[%)C%(;\SE`-,Z/+0B9TN"(.Y[ECL
M@`QPL5C-"U](4!$P0#8S=]VLWT`_HW?"`,#.>CWZ[F+;9=%\/N@,:9CO+'B6
M`\7P>FW%]/A@!D?(Q$KQZNL^M>CUS)/?H2TM.W],]XZ6?MIN!=GZQ!1&#RPA
M3/UY5_J;3RLW<<CB[R[3Y)9\8)/<H1H*(I#I1BSQ!`.7[C%;$DR_94V=(B:(
M"@9IKY+7<@2K9I6FF9\95ZUS\N2ZI`K=I(LRA\HN;U:GEGB:3]\$`(EMW'6-
M9[<BI)>YHTQG0Z;E+[TS\1Q!VSH972]2*`5`!AO`3H\]==U//_/1M<E%MW:P
ML@,`^!X>W3)*M4,GMI?#$GCH=X*XKJPJFCC1B'O+S!"V`D!/3K20XU";W?<;
MI3C$A+]CLF5URQ38*5&;L0**O7T^,UT+;@_QHA+'':P,XU!@E)5MY4H(;AB>
MYP%@.Y*P#MG`!I`@#K'C&_#^!]G=/RUL>"H8."<I*6^ZO!F^0`5'X^LJU,!J
M5L1])\L(23N(#%$&TN="[OO#CC&T8804AI5B0Z]9Z6.P^YT6#13,[[7P=8?=
M:'!@3>)+')=,Z,]@!4KR<O:SH4V;<^GC$`0,FTA12)(?H/I>^`J!P)0.L!2"
MV&"VT.)/)=;*'<MC5]@T2%);M/-"[$&/&#(H:S8_NYLU7^>K#[D%8-Z['39"
MW8;;0`C,\&67--F*$4QPV>]TT17Z%;=I%!MK<OPC\6ALC+VOXP()W4"QP5/^
M0>\Y6NM@*<'HHHOKNY.3A04[LFQ/QDSL!.P(LB5?4A2J-<^SWO-$#ZQ**RS6
M.GYF>K3;RG$5T5=SM:!=UA:6K/#GG0X@C0!XD&-X,1G^:-D#I'OAMG35/JE-
M3^R"NF0-O>0*'3G0$W6Q!%Y+GA#C@6>"6L?T1"ZP*ZU15J?64R@!Y)XQ8].$
M*4$-L:]CB''X;I_67[WP8%T+.=,DO/0N@)M;]WQ7(_BB-Y&24`$T+EG+MGJ`
M4J=+HF3DG]WX`9CKWQECKBQBSMI<@'JZ[B!,.\""Q1=2K#,HT9`#391H&-9^
MOF5*302((0F/O+4Y#EJ*=WGN=58#M=^A7.O2.*ARG"ALXZ*7OF?:FXKRS+BC
M8'>C)[G9MZ3AW\O1;MMCM@>D$<9N$\=JUC)IW'B#"!MEKL`*?T/+Z5Q6#$9]
ME:VNF`=F4>KOO5;BC:0PM#-,VLY)&11SXRU/V<;C'`NA&&+[&:>XHH);*97@
M0<`V4KO"6>J(UXP7`Y^^D9S"Y*83^BX;."W0*3XGWE6+E>U@0WTUZ,>E+3[/
MP<E>G>W,:POQ=FY0)#&>DH,B^0>RJ6P6Q6+A/3K.)+K+-8-X]S/Q:&Q:0Q8"
MS**#`10/TT6]Z7`E.-N\)S!I=E/FOO<RH6UU#*R,[38K.AHQSA,:A,&#4"-5
MS#Q[P^KCDB-D(2`(Z7Z)6LNHQ5W,>*_7-.=K-AADRS(.!,LMK&EXMZJ0YG9P
M6]>.Y1Y44)1K;;14<MNW82]]YZG_U_"9.(!9M;.SH?\"ZIQZ=2;TM:`'!_G8
M6I*&S"%'&6KS>OT=-E:LH[[BO34$I).7+25?V>HF=)(G*(!3/W-V3[\6SU7`
M#94/O=Y;(RE=+J1W>RJSR1)W+??J0O*:7(B9-NB735VU-PI1064;!\A,3]W6
M-C*`T/4+@[.R'H+N(;9@XW"-X00A[*_0211VPJ0,_\[9]V&^WLMCIH&\YF4,
M-=LPRK6EYS-+.=:0*)(=XQJ:F_+`$)@1R9;$'E-PR[\-\'YESNI_'\/KTHQ[
MV7_VT0H;?T`8COB>:_Y=)E9#:^$1D,4S38.%!0_[=TF#*7@@M_#]YVD+!Z6^
M&20+&!Z<^\M#X\K4ZNSH9MUS@I6YRA`$$$.]V$/;%Q%RRWOX-237[#@@K>.A
M\V4F6H,M74#X^1Z'+*@#P(\A'F8<QN8W=7J7[4QK9JV]V>UF$_!*D&38,/K%
M<(]6V3GPUZ5=UII+*[>1ERN@+;;I==^O][M=@VYA\1U6<H.ANMQ*K^M8,/^Q
MV)#"\V(4";`M&RQ,KTYIW?5>LJ017+&<P^-@&NJ6X/PF\%`6(J2]H7Q&G,B3
MJC7I&P]I965>6_<XO8T)WN9K((J'FY)/;-%%`&D'+;!GZ/T"'I=\2((9F`TE
M?CNT:7%I:^+S+*`.2OR>3&VSYK=9O,_(X)D^9J4[@"6IEI<[Q`#"H&=MVMN%
MYX.MR)J'EG6'Q5G;DTE=H'*&&0P'CN8J<PH^TS"S=O/IS\W7?%X#M[Q6L-W8
M==V8P*@*(,JZ$%87!@%7*L/1-61VO#RWY%6_X!0?'FW9G(C1'+<P&/(4=5]=
M77$0<[&<6Z:4E],(K6/NX>=GP(0KI<-RF.MO9Z%)WU4[$(%JX\(5&__>&26?
M]3"Q<([UY[@W.C#'NE-03@B$29K=I4^ZO+G/<_-O`[S?8/=E6X6'0/#Y.:YC
M!&,J$:J$JK%X/O`5U6-!`)6/0.ZN]5GH)ARFTT^YW;XSVT\QH-9K"Q;HA*FA
M6^_+R#R$%5MA];U`3H?!NVR48!].*X*`W!-`&(QNG[Z=S`)KNP=AD6*1V@E*
M;;51J97)#&M;H^9+I[GHE2L'?NWD[^_OUEJS^_UNGY^?9%M&:YB9-6N&%I@K
MN>:G"P*S).=&V@FTQYOD9#[:K4T`<Y`DY'9KUMIM.F_TH]MA;JVMC7JPN6?Z
MV<WLLB9C,'O<[U-;.*0ONO&-[PB)__6+=A/&6%KO181F8$G&>W6R+!/;*'`\
M:96,ID^;>U7WHGA6/&P<5L1>J>+`0YL3P3Z.`RN<INJ[(1%%''/;)>`A^&D6
M>DE-F7(Y;PRL5.>(U'H5"KK4<#4:R+)":XB50,5@S]KI1SKN.[3IQ)#:]:8J
M>@2O9'2L.%T/&D=FW"U>,P]PRN<S8<04#N#26O"N[5W7:E?&;7G.0JVSPGTP
M<%KO*E:#:92V4<"$-U<_8%--^714`'1^(?E]%Z1"*J`*5M\U>8P+J9Z<:2VY
M3;CK@+?<X[XZ*G.@.0IQ@Z4[1.K#+&]7N5@QX*FR%,_A-VY21,Q';\JK0(4=
MICO'++AHH(YM$3HSK(4'<%7P6R+;8M$K)5(*LZD&\8;4@:_/MZ3AWR=H>`'V
M8RM->(2-\81A577G0X5!T4Z-;^3+BV^3H/N8_=V!\^(%KD:-"30_8G87LKLR
MW7,H,<?R+B#69V@!F^K#6%NH3@IG2P^)/>\7@+M1R``#SJE3',WWH>/L/0PL
M.)EFP#X_[PNLL_42_-Q0PN!7!"6C[7Z_VK+IQ`W0>;N=VMCKG`Q90-).7IO-
M,73)?57];[>W2R^\;K3CZ!<3"V%\QV>(W=AUOL]$*;/WM[>IJ1MZV'$IWM_/
MS_KX^#D'`CV8LILO!X#[_9ZD#!^?GTMS?7TG-CI?U^4<%AK'?!R''?V8S#4$
M2'9**%L3\M%\RV'SWU*1V$&::]?0&4X-(X:/$\%ZI:V\[FM/_J5!AB"^SKJ6
M^#5HY^UJ65["3\!UE[VL@2RY4!!P:K:)C=9S50V_<E"#>3O9I/E>I\8T#42%
M_[^>P<46<;J:!9]P9ZLQJ`QL'$NG1:&'AM2Z%S++ITXFB)),4]UO8!C)*8&E
M;'U:L05J;`+8Y2,>92^K'>W3P8%G(1+[#]4;\UJ&Y&*AK77I:D@1TH)]ELD:
MRH7,(C**HH:*NI3"&?3=5?K?#!XJV$;^\UG(=W(]4&LYI^<+XC(>;#E#1'>,
MA?/YP%+*'UF>U011"%ZYY!ACHED$.E!IB+BS@;^!"MB'(T5S73^X4\G[E_BT
MQ[YR-.--*7=#D*%=5NF>!JMF_P:\_TYVU[\(=&7EV"L`9.(`6V9U_QEK:`$%
MJZ-='.1ALE>8:^S`L(?CK1;-0"\5\;QU2`"T317>,[4%K]?<[W=[>WO+BU@Z
M+='FIF+AV1-V`9/CZ.<&W/4H1N1NKS2E'%H0%S"8`)_>+XG"Y1;`QS/T:;WW
MDS%MM[E`,/O8G`:_+D#W\^?/.:@"D62<$HC/S\\%Y*_SV8_#W-MDA^UB49><
M867>M]8NS]N['?V0>Q)7O[*UP][?W^8P6;_`X.?]L+>W;NUVNS;EGEK3DPTY
M:::+(8[WIK:2W<?Y"K?[Q98?UWD<U_5(8/?ZS-,WBX!G+I`TB2_:3/GV3A0C
M^=C*CVL/#6)::($FU[`'M7<7=JY/;VGVOF7-8!6BDIXN:.NT1[]6.6<19.@D
MMC#B<^"(@RE(S#7TV48>JE34#\NS.#B:,B%<6>(>8L;SZQ:+.*0"PW)/P9<F
M+P[W!W<_!^#<Q%>:@05;[JUDLJ!EG9+:X^R@$'@>,A.9]RJ3T5SN9?1P#S)+
M;2YZ3J.BC#6J'K341L6FQX),I`4R92':5S,/T<W$%KIM.Z*V>;Z$E)C^OZN3
MUFQ90'K1K5G=1T^Z8*&HC:VYVAPXM&`9Z6LS20`^)YFI_K4BV.9>4.7.>.RZ
MD*^\1VF0Z^>$3&5/+:9X^KV,":VBQ:,I$A"^V;#:^PZ>^#=QN_XX.A&/L>X6
MYSZ32CR'HF-1IP8-=H#9GFJ&\1#LJO61/8:ZF?O="`05Z\,>$-V;BCGGI]_O
M]T<7\QJD@)BI&ZK%8K&7X\^]]ZG?X[;E7*1"GZWZ7D8,%'\G&:SKR%/<X?L/
MOU/^,!0#@,=QV,?'1]*W`J=\XL>/]\GP+NWN1%-FMECBVZU=K&GQE=SM?AQV
M[WUNZ@+*S.SS_GD&?[!UU05J_OCYTW[[[;?%:`EX6:R3S_;?B/GD&VY-;7-\
M;IS]&DS7Y\>']>.VOC^TY79>BWP_8I.PE.=&\>#^#RX<^199(+]X2$L%0]6.
MJ3HQGLOIV"I%,;@G=V)(#)M`L?>0/-:#'1/(0>!R2^G,)$6OWN'=BB#)*'34
ME"KHK<4&F&H-J;O`-FQRFIH7LJ/-AF[1<B_(F;KJLF/!G*PDG0HXAAPL#\#2
MY+H;13^[ZD9E4"W?FT#L$%6Z7GW6>4C1#07>HG,R-*"N]GF>&/+S&;Q-[>QE
M%4A#OG,0UWI)>B3P!R-`9<G59NXCQ!J#[1=CLJ*W*7GK/8!J&N/U:5-X77%I
MYU,*WF3R@XQH#G>9!-Q$*TM-7%Q?9A2_'4%LHPHZT_15S#"66*]#SB%W:V@8
MK2IPN,CPM:9UH^2W.=A&<TBCH^$K<&489XSB[QOP_ML8WJ^\X!77V/T,+K[R
M064RUC9(J5B3/$V<[PZ"-?-X)-F@U-3D0N%5!?C$(NE1P`=>O%[7Y]YNM\EX
M]"NUZ]$YQS7UVSL$I%F`"VZNUDVHA^Q43I(C?6$((%GE#-SB]]:V-\_]?K?;
MK5F'G<SMY3R`P*K=;C=S=_OX_"#]ZKJ!YO#$!?3OATNZ&AOS?GQ\GK*2$F!>
MW[?C2DL[$@`_CL/^^.-?R@P/OU(Q6;<);*II_20U<VUGLEO"T7&%6O32*JMZ
M<B.X1/EOV2$A@LRH.14#KR`=0M=84I=A&L^>G=.'M0*K!6J')>_-5&!B`S0C
M:'>63;"^$3,S20NB<Z/K,DWNPG[WZWZOG#C8[Y;UAFL01XOV*4]HMMA2EN>D
M>%^G@;DQ!!H8N!"%.EGG3BX3VF(H+H4.C+$952#XA66#N6A8,-CZP?JCIS;_
M:.O+Y'U@0FTXHVS65&8?^VR<(!,ZEUWA/"]QO:4]R"]@<S#P`\DG9I*86E]-
MKA<:N^VN<HAE)>;I'AG`K+%%6O.2*9[W)#/'=/_VN2]0C._0-),V9G:#Z)Z+
MT>6<\%C=/W$X4Z/("62&3A%WP:0X\&)>YCKVD1ZYW!!=TM\J1YYY,AM90*;"
M1-U^F&B$$NORZQOP_ML87CQF,+^&AU^*"'[AR+9Z@Y??,[1,++04(^`D:\N]
M(@*/0;Z9;<\G$HN%&K'OV-^$SO4@>S_;YE/3VKK=/^_&D_L10"FPPZ;HL*)-
MEG^]O;V=^MO/>WH_3O*I(C-YZ*3Y2GUCFR&G@9:?/S\OQX6^.6]^#;9=/K=@
M<V]N<>OT/-LQ#9:F1[WX[CI?6LS/2W];=5)85VSAODS)5K%P"BR4,(:AU3C:
MI_>C+TWX]).&=N@HL$6'3CSYL1KEONN4-S0B]OK99D%J`)--/)U;5Q>6`1B-
MY"-C"`:2X.9J<<>,5BA*MP6@:8B#:,Q=/:,1>Y&^XJ4GC@B%`3LD1#_BY=2D
MK6S^$`_ZT!YL`->Y#T6,N0@SV=^8"US66H,8R_BX=TJHZ@,(1F`2GI&RB*!A
M(E<"C_Y[@7!?5:H,7'H(!GD$3#;/[LX_N56>[=>%Z&05-L!\/T"'2:XY1FG"
M&'*"(*T>-@YGX._9>1_:3Y^8:A;<XIO;+T:6W`\<%#,!K.^S(GY.S^^XXW;,
MECHG/=Z\"1B>;]N,Y#EJF.PQR=`VNF-C&R\7B\)2JD'%S)*U0&*2/?@3\^,Z
M9%[#+E`U\6[-R*6#"N:IJT84S/MI1L'9':[,NQ<XHL6N#)1M_@:\_V&&]ZM@
M5<VJ_$^]WWS^_R(07B%?%"@3"3UH]?WL*$J;(WLAJ#D85-?M6P7S4:L\!I.6
M%1*!APV>93V:>>Q2KXWT]G:SYLT^/C[40W31NZ=-4!'1JQ_)BZ!IVIC3SUS:
MP0X&6PMD'5,+',WOKY]W,S2?4;H]=`&520_M6&(UHC'\'#_PH+_R!>C[<:0$
M*K",P6Q:IIDDS/W_['W9EB/)K23@$5RR6IK__\Y1=V62C'#,@V^&Q8-D5;?N
MS)GL>_I*JLHD8W4W&`QF0>N9M1;,,G]VDKY?+0#5V)H4$Z;2!YBB(LT6AF!'
MU9@,!!C"UDV@M6LU^R83[VHY>G^MU1:<A]1.938592^:T,0P8GD1//=-/0]`
M1]8&*KO0$W1?R(1:9Z'4;!5S87(SCL6V5K5HQE.`6FP:V#*XI9TOV(W*CR%1
M17=UL&NCEI,*\,CH;*">L6$IH*S/1&@WX,5*G=HU;>SBWF0@8A6>0EF:/I_[
MD&S_KNK,HGUK:W`&$R4I5F4:7.GS:9K\]AQ;ZS`+LB2<RS#6<#*<)-!1`L.*
MQ!I4\XPP00<'40.1:#W8W_0,H,JIU^J[(:Q8X52UV(F0787E%43SB;0?;<[:
M*4/)W)3E@N[T!!F-_<+@L1%JCEV$T_#C9DW1UBTHJ?V14?Z`99&TG)_D%B`6
M`@"N?;S)`%0RC2TVD8%]X)7\!HS1U4HQ4PL=_DY:^^^!W5_U)8YUL.^SP\SI
MJ8?M$U(W8*AP_9]Y]TZ`;M0*,5CI)?E&T":VK?WX5_B8\:4CV4!P?FKP0B]0
M*54'!&!]4DJTI&6T+W-6UBIHH20'>@QK\J\C)D6WLZ4,JKCG0X\0.Y8491B#
M==7/P[R%.6_Y,[!XPQW-M-X2TWW;ZD#36,1S!;36W%Y5_X$V;-:%<790_0>?
MY\(+!2R>$?!.OQL&5VR<+#(S(CSM)O7U!9*>$D,RFY4CA%TH]BU+,_E.=O-O
MSUK[Z\Q*"]TC>0$HM59\1ELE?(_R`+G-O[2YG'#K2/36+KLB`:D?L;QN)N<[
M[&0EH$W6PU[(Q@Z1=F/#.(@&9O)%;Z@U`+F`[FK-NUOMSW<:PZV6B<W*U<%V
M'NR0G)Y@["R=:KV#IZO1A*([@=:9LQIB:LX>S:4E0\&&Q9&HXE>4SZT>]@JL
M('N`!"MO^0:VU``=:1<$YN&Z(2%W@L60#08ARHS%CVBW`_2WY=%UX$1J8+,/
M`:;A#-/#0M0Y&;*&6=OU$:G44#%Z+N:C/=V$19E.BK?.9+?>)8*!<2,5P@=9
M=0_`6UFUB`D+T@'*21$E8FM1=2K?MF3_32#\NMC@\/?D5[Z3V5G<RHN?A[HF
MF3*CT?$+S6,UY(AD'<?XK$J0-ZZH_'KQ$9TW!^`:;6N<N7;5I#7[L+SO)(O0
M6AT(2+*1@@R63`+;(B:>WZ_)-=WSW@?(T!Y(V#C_X#-B/'?'0)(!QB&S$EQ'
M8[ZA6NC6\8G:0.'0S.B4'=)^DB1Q@1-8#T6F7=X!(]*I!EXHV"ZD@XW`LJO8
M&9&#]T_IY2C\[ZK%3J(`,N-&;:E[1DWC&(:QGX'2B-[8;6R>8)'"A\6E+H+$
ML/P:Q&-G93@KB'(5404*D],?NV)%Z<EYKKLFWS/M<@?1[@`VE<X5>!!-CL-Q
M"("R2DT[6B9!$F7BHK&'(E*`0%U:BJ68""UI`7:[W?6L])L2#$Z*ZL:)]@0F
M/^#70"W#D&]/VZI%/K%+].U$039%H'E<APS$='ST]8B[,/;O$!"J_B2+BN:-
M.R?2H[L9>_7@5<P)Y!HJ^MW8$2K_6!IDB+?05=U:9IV-AL4_*4_A%O)BDUB]
M+EV`=7+.+ZEV%$Q7;I`GY0IVC3US^#X-!8/4>XZ)A*13Z+%;B?,-(EK/3OKW
MQ-0TWX#WOP!T^0E@DU_]X!=`]`!G,*'^QL='.MGG:-TOC*ZRXY@!-EVYY\W9
M@[^:Q+RK7\.78E30XC_#X%MA$_C!@7-#GW@M7D?.7*I[A<H4[*@DMV"8R)*_
M/&4PBPZV,T[93.0+F;::OY9M\TI]*E?")UU>Z'P4B[1$N>IA+=#U;/T\5(5I
MR$V8FX?NF/)V9OC,3]_/Z!E@9O\\"JL6H9I6M]PXP\\SE7ZQ,,3&^O;<:"D*
M;!"LNR/&O@^U<[HB'=/TZ#F-+*/`AN+\:T$*PR"?T9NQMM92Q438,?*/6S1@
MAJ$9:EB+Q\0KAGFH]\=&GRHC^RI!$(&-WW:OM(0)-<PXO:[LWGJ'(@WVS;GW
M8.\VJ;CD!BQPZ)7`ABGJ4""QT4YC!_LSKD7O8&_M&D;*DU>9^#LLCCIS5JPZ
M=L-R!N!D"O9LWN$"D).R=+3OJ@.+$VUS@H%%IUM5OL8XRLFN*^"BL"D&GZHS
M(%[*P7V&`BK^9HU':"M'PSF$(.C!@/P^W$AC6$ZL9SRA?S01R2@@0[M+]U2*
MUDX32H;8V3'JC=4/E27H8F`'+KJ'/)%;::"LV5L%\E7Q-IZ_]`U)_]E_IGCL
MMZ/HY(58"QW'*R)O?Z^V(XE#)6)MJ83RAM;.89H;@/;<!C[B6)]]=TSI3ET@
M9')5.?A(3,7A^"`46!4(C;!_=LAT"^W&G0`GV$V331WFT92T<P0(V%V+A=I!
MY9S5."\.8?06Z(&L9T@'TQB,".\;9JFK3&;UD'!B8']:E'+JD<+DKIP^*39R
M!OM8#B!DZ`-UU+JMBAOD8&A!&@"(J;4_;2M8E!;3&N:W27Y\6"!!KKD>,,&_
M3%1;I\*#D>J;G_I9V%A`=\Z)]>:?]'T3>^Z&33\:>`K+9;&R)!XL7+-0ZN\&
M0_I7E`3&YMVH)Y=J2`5!6AYTM#)XK*)<M'UN2B,ICQ/W"?G<+:%$,7B-:45&
M,XL>#E(%`SR/+J;:^=R%@7D#(/60AJS7'X)!N@JX>P=(:2M['P`8\M9=&&LZ
MODMB_P_CV>U.QMI!R`WWX8"J"<#(""PG^F"[MK+Q@(TZ1+W0R7[_E*..J'A)
M73]_F1,<7>)4UZYA<:E#A7H7D731B=:5&>P!;7%D?=_=[FE_GKR_+R<.KZUV
M)QIM.SWW0-7)Y^!:!-W!IQ@*YR'LH,VWAO=O9G/?T<<>#"&]PA._A5N%7@2[
M4)5A)1UI&VVU2Q0.K+D%*&KQJN`%#K7&,MT5HS(`1SOIZ2*E&=K7KP]'_30`
M`"``241!5&T/\)C@8VL^KQAFUEZ>L_)EK^EH[MF"*,O3>J+'_>XZWO9BA;I5
M:_Q]Z%E,.GG-3/1KH'K\)*=NVQ27A\KI@BWSSB[!:&RR[,SK)>J;=Y8H<)/H
M"8-".3>F1F_DE,DQ9*EW#44;]JMQ>?->@>::32M!#6$`PSE^3((`!#:L_-@4
M66<)J[&7[M8A09(6Z_09RR`YJT++"-EH;,NZ3H$#M,VS9K`;JS584_!:-FV9
M/D376$%;T#1=*_/\@67]CJ1D`A-(AZ:PD0:@UV_SY<ZJ8R-J\"T,MC$2`UNL
MJ8A;4^HIQK0&)K!EC]OJ;P9H)1`A(V-("L3J:]BZ0=DXO[`))M!M>/@9?,\3
M=VVK7:#23$X27!\-3/6EQ5<M,<PGL#DV=(Q@#L:ON<<VV_U0L9C6]<BTU*)T
MM[EC1M70VTY1(#O1O\\!Z<0^'I@]B<NFJU`.W;09.M.A6ZQ=XB+BKE^XAUC)
M#P62!P"W6J?=FR;?__P_@J;?8F656YC("WRP[8WK.,40"K*#MV2=%X0P,E9\
MC*Q)&9NX_T[!KCBNC7M4)]/SCTHIT;HN(9CU]*0!SS(TG*R).\+I5_Q$)!`3
M\R'"5D$3''/[B<OQE\2Q(':Z,EGKNM+E?%8?[@V_X^=DM(`+XWR_W=4F.;MR
MO7V6DAJN&FQO`C9'3$M?LY!SQGT\!.?3B3X^KG0^G^EZO:KV'0/HY!HE[1E=
MV^[3&V'B(L-@9M=]4+04)V(N#'9B#U#'=1TL'IOB$*UTRE_J_RXUSI=)^_8@
M0]L&NKK;165IL2^HBZ[F6I#@V@_)2-^(&K"OW]>&MCCLUK#;Z(O%'[M.3F-4
MV8`4,G9>VA9)'!N.H"<;?^9G;+-(D-(HNKA2:Q9*+DSKO-_8/JY?/B2!QS!#
M>W<$,@L\#Y$VW%]?_7>PUJ#7JAWX<JRWN'>W=SB2D:RPV5MX#+KU"?_!-18M
M<=!U<VN.D'LOL5CBH%C!XC]:W^G)<XG7S2C(M%9<K-N,J"4(?9#UH7AW#?T^
ML6OS,_,A053^,Q]BA'3446&?]!8%0)#,W&CFG41FW:T@,=_!("VROL[!M9X=
M&T^M'X/WHS5TOI'D?QV/$KT`Q-R0F'D1^(6/%6A7O<H.]U:$#4L(DL7B8353
MKT(;J@0R9/>O>VE$3R_Y%#8/N*.7SOYMV`')4D'C:BQ/2/O_J8_C&']Q7`W8
M2,W"!J8.4L?T.5YZ,T&O]@*&UF!AAI9U&94T;&:<F)8TSD^=BJ&$#=\Y;3.C
M;V6[8NVS[>">&X9H+58I(18-0*)\04D9FH<P>`8SDXX9;?Z,*=&ZGNARN<0`
MQMQ'ALH?V0X$>PI$HNM&2N;9L@WU<2\0)#:@5P!L)DR_$#6U3/WG"%KPC!0E
MXX0==XF#`FA]>@8MBD1=3[U1^2JO'7\##XF3LVY#^8@N-+BSV0U(XW,@L!LQ
M%A1&8Z&N:[5_8LL*DM;N]F&WH%6+K6*UGL&$;B21;JQ=SN(`HY9O)-45L]?;
M#E^-`!8F=#Z)PDV0A12U9O!A:QJ+U!)W+OY=!7"@`1ZVC(V%&+/IT+&75D4A
M)(%[A6)Z@W0PKP?7Z6Y6`]KVESSK^C@&&.^/J-0Q79R;8U;QQ:(`M&9@)]I9
MUFX_6%!A,:6?AR@-D572(>J3V0Z;VB&Z"3`F9O5,,^B?27FADRL8<)]UQ!LK
MA=]+A:CH_S<&`QGL$MO^9Z1NUL/\^Y_?^&=63,D3,O4HQEY!VV<M_H._>UTY
M1V&4I%"@;3UL_XOA#`$(M)=8]'\/_U4-/\.LADX31C]H:.#(J+JD@6U%&G`Z
MT;*D:N'6V+"YS=H1;\Y<K<A2LJ:%)4&&J#HF<`&KB=M>IQ@XG]&&5F1%R[;M
M&RUIH65=H85&/2R#:P(2*6#"@59+YNU4\C9)7*_1:#&6YR<!HZLV%6C][?M.
M0D*GTXG2DIRFM'R&\8:$A1N%E6A]U8YMJT$5%HBX#=<^0PQZ6VG?ELJ_G"@M
M/!9^*_D`\#F`1%*,BXC6(>-P5VO1E^GZ5+62-4(4D]D,B&O/:GMNH1(9FP&/
MWR7F<+6Q/M78.E:2$J:@0!G/&QV\,;V@@&*&3$&1R18T[3H"&\W'G04BJZ./
MV2]F;R0M!I`[T%F+GAG;(0+M?6:]7O6B.A$.`#*Q9L;Z"295B![KH`6LU0Q8
MA=_#]Q-M`#$V'24CN46(HT^R\](-&-/^7NIUM,<O!_'6*DB&/+A.M6BR?RXY
M*UE--I[`S1=;`B#5W$#09WM8Z/FB.?Q^$A=O&S\>XYVQ$@O[;G(@8>`#QK=W
M[GK%@H2):(:V^W]G\[[XM1ZO<19Q'N51T9`E^!FPK^@22R-/."I,O(VB(=4,
MR89_WC3-WQK>OXWA?1J#\-[GS8"HO/I[<0M<#GCAF6-`L]121W7DCA`QO6\<
M[[,_9]OJDMEW'UQ3V#$;"["DI;*.U'5V#53:2E]H(MX%AN)T6KON==LW2,TI
M+^#V**EFJ<;USIXK9O19)9/41?1X;/WX$]@!49U\WO>]_*O8=*W==*6*!3_D
M9:+8QF,^9M.1K6C?>;O=:%W6GB8W[H=`.WJX7_06O=%O,SRG5,'TWI]97X@(
M##8H4W_TC)_I8<2D#-5C2CKGR0`4KHX<3=O)+@Z8,=6,T?Q>C(1"^ZTV<).@
MD.'`6JII@06TD>AL,3Z[`+7.8*N6^AAXZ@!^=GW5AMV.35MO)4IJ((^E64%1
M9V,$?'W1)4.BYQ=3S\RY=S#@)NZ-7ZNSI=&A#?X]&?*#7+M%RFL<V]@8.`#.
M(NB.,>HC#M9^G5B6JQ^V_FOK36HFWOMSR(ZX8-#)]FL;^/9BU'!C[I3[1<3P
M'>T\1H_?UH!H2<R2BR[81-,.5EA,&YW#W0A9Z4@3BT-G4>KM40&BF/[ZSBBW
ME0YZ]7O3[>F"8TR!#AD+F.&-/E;8,506D!K6P0*UM/(L"*H=G[@UB7&-,>\*
MV[;PQ(A'PCW0ON>&*<9N4]P7_K8E^Q^5,[P$BDWI2VSR$U_Y?'D!),,"[$IN
M[4$8RR8<QZ4!LG&_>38<-DT$UOM(>##*<]2L=%IKK#>\P@AL1#OY$`:3'1Q>
M4_-^Y2ST>&R=(;%#2VUQVK:=>-^=O9@:+A7C:0QYYVVQV1X;$>\Z$4ZT9"3#
M<``!8,)VW.S9T"UT%_=P^%*(NZ<E!8N("KN>O;65.&"?U8!+WQ"[7W.Q7>/[
MO5YOD.4$;)0VUP`@SNAE#-I`PX(PPW!&NWZL-S33*P=7!JH):I%#.AC6DX_(
MC$(PQGO;``L%@QUF@$Z`_14`Q2G5@H-4Z$8'/C"$D[-,NQL<&%CUUFA*-3JW
M`OTJ$2@XIH*H7MRFYNQ5P3BT56%(*\'&3<SSS9+T\!86;(,1'.=80"B'K6<R
M6N)D?'6=?AGTT(UQ8D;)1!P7FS,ZEIB<NPD.L)\7=1Q&=UC&.M7N#ZP7X]G-
MCF7$ZQ:&7^":@P#5%)0:O[#J,@VO5NX%!?J4XS5E$YC`6H_B<1#<HVR94O7N
M6?D2F\)/]_MZ$B#(2$A:HAH^E[B6EH(I0\PWREY0&J>BH864)9I:@GM!I;V3
M=;`#JV[`\$X>!6]6NFR<$X)XZOJN^&13T5(A>!<B#W<*(N35WOFD>RTJS$>3
M6]^`]Y^4.1R!NE])D.#G/_8T3C0\SKE_*O&OI\0=`<)7"@`YNJ#\[,0\JIY9
M8+H6/EH1!9_+?/"5`"2;PP*1&6I#!D"&.[(+85#'+13:WO;)<#)60Q04+S6J
M=G)?G,&X+8B,9(2.$N`DMI(3TSYELK&CVHS`M0WK[R9(*D+PL>^[ES$XYH8]
MYS%N"(!?D^861>@R.T8!-T3&"6X>N=.L&/+J/TIV*%H;OY=]0EP+43-:8]`L
MBS>>QAAB)HR*C4SD85_OK%X*F2\=.L"F8-'GTP$T@)Z$N#_1P0`<NXG^I!A:
M5J#)L9+&_DML`8=>N@P1X5`DIGJO/)CVH21*CPT..`48S!,<NTY8/;=RV%'$
MXH=#`,#>ASQ(X+/^L)APH)9?\"=6$B.CZVS%>W%LR,8*,9``P"N;P`-8V7+5
M^YNZ?W!6]Z@_URUBW"8:-J"'T>0M%`0D#EI2T)PURKO<GK0]9R4-P=1%>WWV
M#&QM7]/;^R_PS(@O@(S.M]V[C%T[GMUS=-,9&MP<,-^Z2"%+7XWH]"S&QI"5
M.<-8SUB1*D6N)6J]:]>6>0Z6<`!3.8X81KP=2L94SGH-O@'OW\/QOOZG\@(8
M_@TZ60[0[S%P%1]ETSXGA=,%TS0MGJ#P5T`^/P/N_'HJG>MGB/S&W400>7Q_
M(BPNP2^S>R;80021J`7D!\&8M"T1B?C:8&;596&<*03XK4).#IG>OB$(A>U#
M(E+&\.%S):3.$<$?#B,UEBI:1>VD/]G0!!/F8$_)6D@5P_P\!@.MK18Y1QT-
M$%NRF;'PL5/WX7.L)J*M=9MF7V9)='I89[QD&9ZI+HM`8!1H"T<0DI4>(.#G
M$8#"I(($^L`7LI.IB!P&D`&M)P_IA-5.II2Z1C.BAEH+UPX,QDNM@&1#ZO'H
M2/`F5VK?ER4[ZRT2(1RP5^QF[>`UL&L96I3^N&Y8ETZ8QZ.%7VB"7[7)1YQS
M!7!J'>'8'<%VWMJQ9JT?MA/]S9]X,79I[=ZWISV/JDR=(Q9APD0L'*;#]7<5
M^D2B4\-'02HR*=RD`V$,3>!.'(KNP+:B&2EXR6KF>P\T']S\S570A(0#E_U:
M,),QXNSO$X)N'<8@/A`'U^(\[A&3OA;(@&<BG>K(@[S`7F%6MHK>$Y@"!Y((
M@H1KGMD7,A1$73YFBJAOP/L_!(^?N2S(!$S)P=""DY^](WV0":!FWQJ;L\G!
MD?-4?7`(,N7@'%4T]ZOQPM,P!(XUSA+?K\.B@0\898G)^C'92ZX.5W9D/+N^
MK.R6[*)(`=BE`Z9?5/X[Q\RZC=PUH0DSMIZ)#SV'5<PNBPG8\-?*@D8"0*`8
M7F>@3TK.,,9YQ>D5D34I<:GXYWHCYJ3!1A;I#7@B<8LW&]#`D$[$/?)9&ZFS
M'3PQ[*YBZX0!#++^'+AGJ4L*6`.`YMT+C$\!<$F!5$O-,3#(0Z=*76J1:&A1
MK+<J*W90(+)5#]NX=G3.?9!L!`N0`G+XF3GG<#42G+87/=1E05$#O4V^@.UU
M5XR%]7<+&6!G@<80JL'@>H`,7&-`,TSR8W&O$O/J?V8[*!46/R!(Z<\#KBGZ
MGB$+W%O:AI%+`-]23RV18'D68^TU'I[^KD.;OOTU^OVFE&+?=O*M?;LF<P3H
M#9&AG9+\GCS<"_(T8(GMHLI0."[H<$.:]0TZ*FJ=2Q1JD76GB9[J`MA^AQ"M
M"P<=$U&A'U:ZPL"V)M-9:^O[FI:Z#F2=Q&8^D\RYV$Y7,I6LLBRKS\TWX/V_
MBA.>`"7'U!K&X$7$?,CN,D];9-J3D:89[V)!M]E/K(?U,RV.X584`#F2T,I+
M5"R%U]!X5_O%@=Y,SWMVHY%1LL#;NGBP>/398DL#"4&4_'4$_F?N#!.##HQ@
MFYZV:K'*G!&V["XY,CMX<$Q@@)*,F/Q//_PUF`!2C%T<D(P^C]TKE;FSA_VC
MC6T@RBXZ<VS=1Q1CW"0S+=U"P/5AG-*(8@4-78Z8Y7'!VN"5VB0`:)+!^!%;
MSYPZ;=;\!K)J,0ILKKY#P.2-[*F#\<$_*J`KJ,7T!O5V:*H\<QP4%FT=RP[T
MM:$S9*:YM[RY^]!:IVNT2TM&/ZK9;F/FBQ(D,;K@)BG`2&Q;R"*H50-#0B9J
M:CQCC*PN#!Z;X(`>`1O\G6U;8;!!OX\@+8C6V2Q#$J`)`'8^RPS%IE+<"^E.
M0'_V4B@'&->&U)!3#WB`()Q(SA`5!3A0_#3=K0VVLI=[-1BX+`M=+E<ZG59=
MR/O)1`?V(LLW/J!G9AA":>\C4K5>P\>^T9(2W>]W)=W;MXTRLQD.I,!K=ZP5
MU\N%3N<S?=V^Z'%_Z%F5YG17)LF)@@3`8&H'SEW/IGP#WO\FH)5W?N\@'HSA
MEEJ-C4P(SB/(5Q<@M)T9#$*:`FHF.Y<.[4:.$3=3%(YP1)G&%\&&L7$$X.6)
M.P5:'Y!/1;-9`4^QZPO,K[5W.OPPGX-,O=^$&I$)@$T!2_&6%IO]`$E<C4T,
MR[%=%9V_2B"JD:442&*`V=7S+GJ@RNJCU886E&:*101@*G;(H[?YLF.DFIZS
M*\505A*QWI([8$4O3.6IZ^Z##&<'TXZO?7O]K+%_#:P[A4JK(PH2^"S8)Q45
MBT-4#-IU=(Q0&E>!UKJR<D+]L(3->I$\+=:0Q1%S<WS3RCJM(.`>NEIJ;?+V
M;+%U@X!G64JA1'VHKMKJ(6.,PU^-%:W>:ZTK(#)D,4-/#$5M!_!"2M+$''H;
MI]XA`/`FK%1KC,\=Z^-M;*UR;``$S"E-/(*UO$!I9/&=ZM(5"?<C!5U:%Z"#
MV:2!/8&^5T3IMVW(`]I7B95*$#EV,0*Z=I&T?YZPW=X+M.'+[(88$]/Y5/S#
ME66<"9]0`23FVEMFE*KCB9WK2/5:MD'?'@01048FYW7?W]R<:2>BQ^-1`"\#
M.V%#:D0SK9:%S50L.A_W1Y73Z'>;I8TM#VNZ[KW>M+]FXQ;\60#VWX#W_]I_
MF$(/!)<5+;]&(_NY^2A7@G+>C:[H\.C\M+],6+\0I/F:?^8>\/3:S:IB.P%L
M66=Y_>X\!<&-U7O'-)DB8,R>[C<M+L>\!JS$D4W7C/Q5U399ZGMBY`ZMT+B=
MRY[=9<LPD+)-MU9LT48V*P#BQ![4>T4:(.[L&VXE_9X"9\%Z[EF#?LOTV7(!
M!B2%Q_,BE)TT27=09!0`65=EN8,)[L-"8T!D.!W(Q-@?W[L^PI=8>W(V@,$<
M)!`&(&B@/!<X@/Z?ZM'EL;%CBQT'5KK#MP7L@9-`MU6#UGC7%(INLZ)EG9HJ
M5_<#"@@&4./.D4E2Q98C6V(`$[7>:=#77&<&ZX_#;LB\PW!ABR]63)^1:BAG
MC]3O35I2#Q^2P%FFVX9%$C?+FD>L&X-#BHB./)X4?'DO,@4R`![;Y\ZS7@ZD
M>)/U)B"P5<?$=3HG:XPHYPIR*Q@F'*[+2I?KA<ZGLQL;4#(<.)YL6OL,;+\P
MT^/Q(,F93N<3219Z/![$-6V3;*0S,ODPV&JK7]NQ.U\N8\AOWS46:<?+3.S6
MF'@3['[<AE(6($[Z]6#=S3NR1^Q1Z?7#OP'O[S*Y(G_?9^%_<WZG1U7PK[@H
M\/-CZ;JR_/+Q\W/<'EPS:X`:>P=:XN[I]T>#$R:^5B<4!4D@,H?E00JFWP"$
M7G"4,'_!T6@;!#H:=P9YYH=\\(R&8-<,QX4N$4_>@;"9Q@=,B6LUDK)>BQXN
MW/@D9W^:UI:)C"F^F'Z=2Y%@S0891XOA.H#>IQJEBDAPW)C.5)DXAI]M:H8.
MJ"+O*89;)-UR:D@OQLULB[Y(Q*J32EX2.]5#I(L)\H5V?Q\8DH_`"S;7@1RW
MX74)@G&BX,&L*]:P"%M+(1X\!SKQ2Q?-X_(E4P`E2DQ=EM$8.ARN:4QD;$V&
MEE$CPAH/@4UCICV+W5.6?+A%.XX,KA&V9=VMP@B-%#@H[DAM^J2Z"WI]%[10
MQ/=H<JTY*C`"]C<B']HQ<60CQ\/SN15;;,,KQ+.O;`H-#M9\!UIGS14$6Q.R
MH/UGBKI9S&X_:-<L<:+UM-+U<J5E6<82YYCV84F9]YWV;:?']JAL;:J!0TO1
M22\+/1X/^OG77T1$='_<2;+0OF\EA7)9NS]\"XE):=&N$82V91RNZ7C>'Q\?
M],5,C_O==0:CKO1LP*A=PVP*RG!OS;G;.N(PW9"4B7-C:97F-^#]3;`[JR*/
MB,>7.-W`6/\E>[!`QO"4'XV<OR>V4K$7KI!1_[B+$:A/_0S^&R`^'%:G7W2^
MB*CH`^WN='VT]^K-X4&[R$09:.X0)X#<>BN^]/TPK%:`4]:PAFGJ7/!2X1.!
MU<!_4\5SRCA_Y''4QML&U:QFU+58M3F_EFP$0R"!T)S!.8.5'E=B=ISUXZU8
M>>A29]#3ZK:ZC.X*3EO38"S'8)@!B+UAJ-N4JK/!&CRIYR\/$*PW.NK@M(72
ML(L;%N4#&BTOZ.&*`1@Y&\]:8.XM,)_I*P<Q(&"7Q$I.T9ZG-HB(X+-]=PF@
MP4'!Y`H`ZU!AG_LLVDJ+0`XSNB\"SS?J#[7WLUJ>6V'$OENC@B5X%$:CQ4O=
M'LVE7O6"(ZO(Z*A#IV8G<$@N`'FXR(1[)VI2@1%6[Y.W`G?#51;(^SI%E#XT
M?G8T\!6*?9)[A'$PB.J-7@H;N2PK?7Q\T&E=PZXJ_F[.0OO^H&W;Z'Z_CV0X
M&DEY!?@F6D\GNMUN-<&3*-_AW<^9'OE!1$+W^[V"72Z`MPZKKNO:)19+6L80
M;RO^S?HO(K2N*ZW+0@\*'*+@`B>0'6&'3&AXKDNPT0KKM9P/`CA4-X)%%9?M
M^_YFP/NW.+;^/_//O#7_2XCK\.??&G*;[]<T%1($[-8AO3E!,S*Q-^##\YD)
M)(Z*C2?7P?@3Q3&P<S_RZ/KSY/3#B=DG-T#D&!%:/2*39HGBV\!O=QTL?AUF
MW8$6-H+B42L[:#&]8DV"+4Y['6<DN1I,>>OE#<Z1,:*2_;VJ4@.V0`6`;T(6
MTUZ;WD/6,H`V\5[PIK;6(4BO2BX0)1NK-LM&6TF%5`LN#9J=KM9N]M'P#VE#
M^)QW=:,0M`B<-YKN8YH6^B.WO3*3Q.]88$P_&S)"%G*8]9,+@E#Z&^-T@0^(
M!CIZP*<_"YB(F.,T+@N^5=&G@F+\$)',AQ<T&`L2Z<:@(_5BBJUFW6IP63M/
MV!=?3.+%+'+6_9D"YM+E&*+TR>/]T%N+]."0>>>(2<_`FID.9F]'."9]QT#@
MA`BV?KE=NQX0'VU`]'0^T\?'!RU+.MS0MWVG^_U.V_;HWN(J`KD/598_;WK:
M;*-X@Z2\$AI3$O=PX*P=/S/3^7RFTWJB95EJ(`9T3.S@Z[)06I8>^#,\JDFY
MHC!$E*NDP3ZTMY:$S)P5^V^CDZ.MQ.J=<=@#I25_,^#]_P?LOGU97J@%(K#T
M2E[#T4>_TDV/#/I#(<$LZ0Q^8#:4=008HS_A)W_ZDJTNOO`3M[3&E+"P;]L?
MV8S!G[!Q"6!;-T#;N$=XOG3\GD.W\_>>B;`I8L</$+,^6;&_&UEMA,#7,S9A
M'+'SNS22!6?U$4RZ!UZ;1YIW#038<^K,P`;69\$.43'W:D/94C5=;/][&]>+
M@1F%LLB",VI"G)J9NM;7<;4^Z[GT79=9QI+Z=53Z5^M:T"F>_G=*OSBQ33G2
M*:+QO-Y0]$"5X,8CHD%(LRE"WU`1`.X\K*?(!!T<_&,C:1V`4LS22+?"9UZE
MAU4?WQ"L@O71F/^2KH%EYBKS`!<'(7TO3<=7\/C%6"8>L%SZ?K'KNXG$H141
M::.CJ4F]&PGBD&=#P:4X(Q,",4`5VJWAERK'"3)C`^8Q11`GX@,7HG,KMH([
MO/<:&&.Q)<ISF=0S2%URH0>T+/&!H35I6>ARN=#']=JO04_:(VVO]W@\Z':_
MT;9MB@UW,POP#&2X=E9#;=<]YO&<(C[<]]S__O/SD^[I3I?+A99E(5Y7)=M!
MQOMT.A$S=Q9ZWW=@Z(5L($:359S.9\I[IG5=BL1C7>GQN..D7UC(,OGTM8AU
M[T4?B+:_)0V_@V/?F7!Z(7`BT@#P6\X.<YS]-*S!F$/SP9<=F9W,ON!HR&L6
MJVU=(&AFFW5T30_:^C8%1]YRN)#XF'@*1SOG\O8,'F&A\8P)%PVT7V!:_?"C
MBA<SH0\".D`/8I5%F!S?H+X0VVN-=@RHI(C[A,&$?V1L,C,X!YLF\MZ_6D@O
MW0NWEQ8R!)HMU4>#Y79RS8ET:'?5IJMD""/R5R!Z+L/`G&`P!9NA,Z6Y+"8.
M.>LA%4XFJOJ5+I*9P&?3L6ALG+ILRNI$#^`H=:226"3,E(W7&[B\%GBK8Q13
MD)'7RO9P"*<!)<*P"?3D;<^HX/-NW#?0%K"'9`2*(&5G9W35#7@YO_!`TN'!
M@3GF27<'I_]5D>BZ9*S7H"[)J=/R><AR]-./ZV0,O%-*YIY(_W.QG3ACQ8SQ
MT,B28]0M.K)H%PR[#^IAXZAM7GR'L[(,.Y0V5NNMZ\<'B0C='P_*>:=U/2GY
MENP[W6ZW(ETP0Z/ZN1GV>HKA!-`;LI\4V@M/_V[/.WU^?=)I76E9?E!*RUB:
M67_O:5UI759:TD)?7Y^%J;5#P,"J+\M:!O5.0_>?ZG7LD@T[,S&Q:(MTZ]AM
M0SUQ^H:M_S#8-2_`RW9<;ZA#>+++SR7BL]\7"LP:/.CBHW.4Z<D^8Z$M1'@5
M[.HO?'[&ZJ?D33H\;%IU0LI,"^LO4W;E\L(UM!?GB297/&SU5F(<L[RC0RO'
MVF@^X-]AT?4,?Q0XH:?>([UL>^`X8%6(M(W2]-:YF%L])*,TN>*'3:BRN&I:
M6EUO!B]=S4P[:RY@S1HXZTE?C-'-,NRX^LUA)[?PGKL#6`H`$7<_\M`QYH`Y
M]?9N5'-5I0^399B"[B"%Q^>W1\%(7KMFNO^?\4UNGZU;^Y/.ASE(^SE'(,L6
M0Z5M+*J+I)]M,@-IXWD?DA6F92F#0.@M2^97%'@"0-S\;^TS63;P^8!;`Q36
ML2+#?1C/)#"@:BT<%90(+B`E4CJ*M/$>Q]I'-Q](_O$]P]9ZG[Q'1P)08EI'
M#^5>9&0G[5G5UTP,TRGF&-EO2G;#Z-8<K.P0\;O:]YW/Y^YJD'.FGS]_TM?7
M#9Y3HFU[T,^?/^EVNY7?S4UV,(;7^NV17/\-!C59IQ"J;4C$O(_BP*^*A);R
M'C^VC?8]]^(F=J\O_W$ZG^A\/IO/F^$48,\Y%6F$*7SP`;77>#SC.98Q">EU
MAN0;\/[J/\QOT'1OL[3R7DK:"ZWKU[Z;G[8-^>G@'9CH\5N7@)[%&,@A.<H$
MDT'/4#G(',2U%?6[%GN#'AYI9.$0Z.N?%0Q"\\4B`K>8%&23B#TS%("&@.&6
M"=B=1=3V=M_!3=<;CTQ[!&*SX65>,EFK(AQ,D4E1Y(&]V<A5$,+8X]J0QSB7
MH*7*$%0@+:83FGXH70``(`!)1$%4'HO4_FYLY?C].8O:I%1LIAEGG!82`"0D
M6E,"'U5U#@W<9MRYP)LX6P-]UKJ`":/8P;O5I$IS"8"0CTF1)^:E:$QEMX[*
MTH?.&D.*0RSM_P3"&]R;*+'N'Q="<8!"*#=P0!P"BFB`$W6@RA[.S&DYL&R3
M!REF]QJSR=WG-?G"O#Z8):*YN'Y0E7OHXQ^_WP!USAID>Q8QEE;8\XY`;R^`
M&DO'XXU)8,W%##9U`(3<4)N[1N:1Q447NA9VB(Z#F0PVH0N7RX4^/C[H=KO1
MGW_^28_[G40R[?M>F-!MH]O7%WW^_"P2!@+_6B;EM(:RLHAXZD5;3S@+V&EX
MKR*RP`7_U)^]/PKKO&W[L*U#0@!^?CV=BI]PM+.)T+(L8)%FG$G2H@:#M:<X
M.Q9WMG8)O#S?P1/_)/-[\`?/M+82]!9_5\/[!F5-OXF;/3LIOWF<WJ?Z.4L<
M37$>H"\U.<U1K<$32,['A4>@(Q'2?J/\CFO'D\*`%9C7D;-B_RZZ+X)]60!M
MDRF\9P.;:",4`S*9=C-L)*0/$K!M.YD6H.*#0YUMU?S1BUQ81($.-G_>0QVJ
M57IIJ7)-9R.=:]_U<+DGO27E=%#MJ[I,PLR[04""]($ZAD&D8>EDP3&K0?5A
M%R&0HB8OOJ,X$3U`ESA/93PV&+%7^EQ&S^]LHI[92U.T_9N7N223O-63XC#Z
MU<2@2K#^MON2Q;IS8"W(_A%G"(Y@(T.Q709UG@&3:770P7JK+;BT>*16*OH3
MA-3D?/G>#+[)!QI@#.N8/!P]*KK+A;(;I%*Z5^@6N``&TA[4(]([]>/)$SK]
MF889Y41VNY@-WD5Y)AFZ0)?SF:[7*]WN=[K=;I1S[J!61.AVNU?/7'$:7"5U
M4"R^Z#4Y]#+7X3^)F9:42M'0V-`HF:U)K88(V\T#W.XW.I].=#J=IN$GR[+0
M]7JE?=_I\;AW=GA)3&E9Z'RY5+]GH6W?:$F#V5V6I>CN\^XTN4WOC^^SD@V1
M'RA$]HCYVY;L-_#A*Z-7BCA]'2B_I?E]+E>0(W#:%N47=[BWE!P&0,IK^Z<_
M^.FP'#!.9.RH2.OV'#D#G]_M?Y]=,W29MZT]"IUN],0V.5G<\7V<1`9/KZ4Y
MEZ/GD5^Y>>#!RVY<)'X/GH5WJ`&*(Y&Y2<&SK)5XT\O!2I+U8&33RASA`@@A
M,*+4A5'`1A3UUT5BXWR1J#5AK>>X'V]6"7JD-CAI&VH?XF,E9>@L'L?W1H>X
MB"JT?4>`1U!$>\<@G<E&F';_WQYR,33'//%^'1Z:1>/<?%>[]E:!QNS8S'ZX
M*0UFV#@`-'VNLY-JUST5)X(.S*2R[P;T]I2G/G0EZAEKFDH;8L/<"B,$+PUX
MDP->[?D:FWV3!FB@*F(L[Z9#AEP&*%M"&18D>(]`ZVI?S@8^DXE!%](6B,9U
MU@P/:><985Q11CQUIECB9JW!.)"#V%U!:83K'E<Z)V5@DDPW;(1[Z-`)<?A9
M5)L!V^=<[;M22G0ZG^EVO]/]\:#+]4J/^M_[-1$AG(?L$A/!YW&L/[FZLB"#
M;,CTSHHS5VE-2G1>5SJ=SK3O&WU^?0W0#>LF$U.J?KY9A)8ET?E\[H-H[=C6
M]414==5'WNCKZ4S+FFG/F;:]V*"=KU<Z@6PAYTQ?MQM=SA=:F2GO.Z64Z'J]
MT,_/SU"JEBRC:_<A8VTWMNVR1GT#WO\1VI?"C4A>_/GI1Q\.<_G1L):&0B^"
M][?`KOS3U]"#77FQ,+&?Z:RI@`$+>U\VHA08&V4?IIC3URL2/#-G<4,O#B$2
MQ9KD*>`64A$V&DH%S@A^D]&`@H=-4WA0;#Q@#>`2/_"B6[2DI\5MI.53.04'
MNE(SZ:M:[K#`YG;XD>N#="`J!G#CPCO`FK;J:N^DU*$/,443JQ:B?A*ZZY:*
M3+5M6["].N@8J#0_PUR*Z`)1M4Q)@P1B:,^CDX,*+A@WO.MU&:^/J'>O#.)Q
M."R)W04=!ZSMK\2=IW\O$K-*',/GH/OQN@*)%.LIP)R7C7Y4[[T``<`Z$M*X
M@X\&3!*QMA43/61I)3G(7+;A-9L:E[JO\+`LPQ2[$4]=P*AFRWFZ]D2@DX3,
M?8<.`6&,O1[4:A*)94G:AQE"*D+?<?.L-[NKG(4H$>B-#6-<KW./KW7^R+H@
MR3(&"W-U_3C7F."OKZ\2&5Q#%=9U+0X-.?M4PTA>U(\KZW,#J[\R5%;"))8E
MT;9M!7"?SI12M1Y+3*?U4F)\?_Y4UZ\]FY>J,WX\'G2]7NET.I'(%Q$]^O?N
M.=-C?U!>&\M+@09Z%'II68@XT;*NRLVA6*@5QONTGCH[GI9$*:VP]N@N7:Y=
M!6W'",F;Z/$,)%4'XM]H]!_^YP7F=(!=?A-5.@>G)S^IER-Y&\6^(&=X18/Q
M"G!G#8)\&``;8*C3T@XUI'2,%E^-58BTT[;;A-K)V;1Y9.XCP6=&(WF:X8NO
M(QZCGK`-I8OQV1I3^5<>\T.=.Y.;/"=3D=>)JH/B2S3#%H#NQGA:FRX=4F&C
M=D6Q+8UMMA*-;B/&C3$3O<@2Z'@[4#6*XBSSR-(6%*^^$QAW$963FA1K$ZG/
M`11,7$CZE'1*:N*[#9>EWCHT]RZP2K(A%S91RQ4BS`K(JHU?M3>KA5N3)[BV
M^]`(>PLK#0US'L>J`<4`FZG?7PU@=2-"S/"79V_W/7?0)I$G+#Z$]CX36F6A
MEK8F5-4":0!=K04=S'-2C*0:-DOX=VQ\?$D!O^$V(FY*'F4';HL1_?X6UHX=
M\9/`+:&=ZKYG2FGX-V,7CR<[W2A>I<M7TD(0'UT.:(=.C$PD4I&42G6<ZII6
MP.:)]ISI=#[3^72BSZ^OTNJ_7.BOGS^[A&%0E]#%,(-^$LB#VC^G]437ZY76
MQIQR`=4E%&(IY[8/><#E<B')N0=4"!$MZT*7TYG6I?S\FA*E)2G'DYQS&6"[
MW>FQ;?18'O3O?_^KI,1%^PWL>8F)SJ=3M3+,]/GU1?NVJ^'57(_I="IL=+\V
M&8W\(5)<<$B<%-!-('&Q>2K?@/=ODC/0JZS;4U9.ZP!^1<[PHNVOB5SZ&P'^
MKYY[`$CE"3*6@,*4`R.Q$)!+?-PQ\\7A<?'D\X_LV'1]HW6;,Z<&GA.V08?`
MGQ@?_X)F9\W9\<'S[P9G0FLNY7[G(C^U.L'JUPX`=!"A*J91CZU:D5D80%UC
MQ8`6'+HAZ:RL_5WI["XI/>BPE61SI^O'9W'2E_9^AL\5!E@@ZZ:`O)<V*!"O
M&'73WC7:1P;&/5M;$R/78,.$JBX'`.H([$:=`Z7W5='#,@()%)O>&,TV;`2^
MN&E$!(\P@$3.CMAZ2</UZVWO>LS9LI65X<N2G>?L<.60'EZ2"9T14&8SUN;8
M*Y<AJ,5W$5`;+P:<M20[R>2LUO+$\U%U!KKTQ(+8P50R^0*[%1=D]:88L*'\
MY]EM40WLBE#7@0IV>(P,810E/B:W`=4,^FT..E:1EKBO-/5<6CQO6A+]\?%!
M)$+;XT$?UX_2K<F93J=3&5K;]RY5Z\\&-4<+&7,`;0@O0[HAB7JW\[[1Y\^?
M=#X7X(M3E/?;C1(7UI=K+#=7B[0&"O=]+Y9BZSH&UI:E']/U<J;'[=:+/JGB
MGGW?:=\V6I=%*?VP0&9BNI[/1<:P+)1%Z/;U1?MCZSLUUQ-G(I*\T_VVT_9X
M5)]N`D<;S>;@<\L1-H,!UK&6?FMX_UNJA?=(X!<'W68`[AG8%=+).'\'62W!
M)-1;NN4C!&H75A+GTZ?8KX/O=DR.B7]]KCDV&E1L,0M(`PST?I[*Q\9[T5\&
MC!,>?IUC8U-QL3)GKR6&PN/::I3YLIW:7$IP;!LVPCC865"]FF8H`;/FSJUK
M&OWYY<JN<']#4N>?\.(Q<1PAW%G=`68&R-3"3@90W#7-QBQ>%V]M0S`,DXG\
MC=Z184R?X=EFQ08J\W9HF0_FEH#E#B18%`6/>)VT]:?N@H:45/NZMX>[AEB4
MY95J76>IS*2`QZX4WV&83\#SQ-0NU)0S@&_M%TRA="):A[M4("4'%/4US1!Y
MG`QX!6-_IR&/"T`]6.4'=[DY-,"]:!ZWDH.X14.,2##)UUC>#/'5?5`0[>;`
M20'!?\ZD0T>87>^JM2.:=&"IURHEKDX,$,EMNF"I`7PR@165O>\@-:4QP`@R
MH@(2@T'&]OTR)#?=+YF9]ERTMM?KE=8UT<^?-[K?2I!$!OLU]9X'N;KCD=6#
M?_T:IB+M6=<254Q$])___(=$B-9UH>WQ*'_WXT?7[9[6E3@E.I]/SM'#/E.2
MFSSC7'L#S<&C2E^:1W*P._9]*B5:$].^9]H>#WJ`AAG?BK24X(G;[=X#,-J'
M)"1/JEPLX>"G\;RF@/%OS\4WX/V;V-U?!8J>M)2G+*UZJ"8:T./ODC`63)Z0
MP:_1QGKS?H7QYE<_G_6&;@%-2[=Z0;;K/'Z%7_E."H&X1*UU%:H@:O+VH`S1
M*)K%W1MG`\,>:$_]RLC;'`&2T^UN-UCEK[N/?:0P\:BS%1(7`'IBV]=A'":K
M38;93,2<DA1$SXS92+0L0IYW1X!5&YN3O6((+@WT8TAHL*UQ1W\'`S2LM:"6
M<5.LNP$=-N*7.1I(U-/\%!Q;;&VDUXT1N);-[W`H>\C`@DX[:L8:#J]!&QY2
M:VJ+R34#BG@_N[R$8K93`K&OTJU'L;Z-6<\Z&(.!V;7=*<8@DD`>H*P'S7W/
M@::R`U>X_UF]?[KH46$*EG$/&`7;<A=37.P5)!(PM?:Y8L,(HWZXZ[9[AZ4P
M_`WLYAX$0BJ`H0]Z&B<!`F`ZGA_?*_3[B2A0G4UW1O:=Z':G?__[W[0LB?8L
MM.U[T1!7L)N5@Y#6G97W)'5=,ZZYK7A<4J+K]4K+FKJ48=NV(C78=LI2O'.%
MA);3N4J%%LIYI\>VE;A@(5K6!,_LB"Y>H.N1)5,6IG;K<K6@2\QTOV]$E&A=
M$V&"HI@)\WW/]/GY2=MC'U*.$==&G!)M6Z;[MJNMK#NCD!D8%B9)=CA-NL1)
ME'L(CD9^`][WP>N+C)/K.\L[OW`,7-W'O>JP\.2`9L3@0=8`O>%5$;<@*/9#
ME9E<`#<3_D6:79QR9)XY(12TH0,MHK,T8RT>$J%GP:B:L?=ZZ"@%2MEZL37\
M2D.WR`'[1]:Z[<4'"3Q(^Z"8B&,@K(Q`;8SBKR\'I/O!US\I1MFU5(\*.=W*
M1PWL6&@[*X6,6V,7K.Q!74X.GJ6@D!#??1!#50P['@8S:3_PB@X%]OI8FR7O
MZJ"UR1K?,=A!L?8?[7H_H90TXZD=`J7[O#9G`T^"ZF,,AZ`\)P8!;6T#S./&
M`8BS;>_^K"16?J^]_6\"GI@I](YM_V0RMGP81PT!(IU]M^!1%7Q#BA$VOC1^
M<-9,6`@.P*U=373<+@.S#E!0M$9=$S02'KMRF\@8R3T9?&O2DP;:X67?<QMN
MJ^>9?!!-UV83T>[65CWD:$&GV#4FH^^ME`(%BMQ^;;,N>/@T`CW*D-6B@2['
MQ2Q&K*N!-GAW4DIT_?%!']=K/8Y,/W]^TNU^[\-PS%P*#&:ZW>^TYYTNYTO5
M/Y?W(.^9'MN#F)<N>6A=K5TR)4JE*-B+%=GI=*:]!LT(E0+F\_9%]\>=_O6O
M?]&ZK,&(=3GJQ[;3[?XPA?F('"_,_5C7VOJ9\=WOJ6EQD>V)!E+'TJ[[=_#$
M?X'A?4%,Z^X1O_!1;'LX=/R[O;5EV_+"JJW'+WZ6*'82K:;XI=-V#,41*`E#
M`IPS]W-&5V=HA@E.[#%*>$5$#J;<F%[[PWX:[-D:"V3=T!4<BTE-ZC_#GK['
M"6TV2EWV\^UA_<;,*NBB#<\<OR-L-FQVG.$1LZM^TKG%Z]`3GKP<GJ6W\91#
M4\GFX9`^)*8/-`UJK.C24.9`\=`6A4PRFZ.SH$0#H/[3*D@%@(/M&;`.S$@]
MA."@XR#(/(&LQ3D;!+K;EN(63,_CY#DK$Q`AGYKH7=UP4EM,6[@<,OKM4@U4
M8-4B;G*",00[_#JKJK-,F;?!+EAO6FI6U^B2"2,1Z6EYI&03.A(60S?PS;/A
M(NBO/:*4XVC8,02):SXK4!_1\6P":D2HMY=5ZEEB<\\\L1(&8.#0)E-L&9F&
M,T8'E8G5<Y*II?Q)`6%YC#^U9S:U5]LP^3D/'^!DIOJ]IS;#.E?O?=:6EV38
MXR4ENEXN/5RB,:88?L)2"`*N%H.4A5@R<9:>H$8U"3%QHM.ZTFE=Z>/Z0?_^
MUQ_T<;V6Z[#O]/,_?]'79QT"R\-W.M4J+6\[W>\;2<ZT+BNMZ41+6NA\/M.^
M[?3Y^;/(F'*!FGG;*6][7V?ROI?G3<K?$^9!Y!*R4F0*!9@GEOXO<Y5OY>']
MC7M,H;TA1;X/H8)?=;U6A$/*!S[JX]@&F\:-D,G?MF3_+,/[%N?IIP!XTOZ?
MX:EG!@EJ*8U&9Y^PRE:7BQNSKUA?TQ\+QVS?*]?4,]VL!WVBZ\$35M&".HE,
M#K01-U,P8"AVHI;,`)@I6DR'U`)PL4`\`$,T`:CZ'/79\A-PRA$KWMD."X#9
M=^<"SMZ!=/%9ZQPP,H?O(EE6FUTGPWEG<K`IVX1!G`K&A#,9$UP8!$QMTA\6
M;#+#54IBW*-CC=D^L*=]P(C8"K=KN\^_E\P4!"U0]UNU+R`'189CWE#/VMOF
MN6ZN`+`C%X;61K?L\J3K,IPO+(C616MKV[<!,3(.P\W+E(@HI:H-!@4RVDLU
M)X8"L#))YG'<W>N-1G(3&X8/2]"J7QU,NV&!*=#+YN&)FUC[_.IB0=P0%[+S
M.DV,C$R"W?T9EE1LG?V&1A5^IG4W[+EWS;IHR[:FYW4`'H><B*==EUY\9'&9
M'KB4-V>/%M$]?)]U(<BF.]7]:FE8ENGH;P:+.DWFM#\3*(R7I6AI+^=+84KW
MG?9MI_OM1I2+%I5TJ3HLM0B>_78-<Z:T,'U<KW0YGWO`1ON^^_U&7[<O(DGU
M=V2`W:;]KP7$XW&OZ69")`OM^TYYWXI&=UU[4;%MCRI[2)2E!$?T[YP,=B_)
MST50G04I#@S;&-*3<6W[^]ED._M>-;L,YP'K+,Z3B%0)(SLK=CL+4*X+?0^M
M_5T,K_R&G$%"`',,7E7K.PBIX/!KQRH2:4GGOW=(H!JVD5\&^3W4BXRGISQQ
M-IA=5AX@(CK6>?&@$3Q+2)I/;IJ.0E+R`+8`6&"QDQBXFV***<YET`/IT7?J
M3_8NG3#D%<D%(.5G5A"H`1J7YD9!FIG5?(BJCXS;K@-NKC5I@??!2SBTP=Q#
M!=@KIH%E"F)VR:0KF=\4U$9T/1LFF9GAI]*T4X-D>FA*>P.K9"%EP>;7I\9&
M<@EY&\"W>QYGQ8AR]?TE^$\K)Q@%F-6K@NV;:28@>)"#R&';X!JKE![@:>P5
M,IZC30H.%';B7VE;J]4;:RWE*#9,<QN&OEJAI%PQ^D5,3G(A.=>`!78RHQ%N
M5X?VLAAM,75F>K2XZC.C7"O\<XAI?JV(&*!0V^`-8$L](C@9%Y)1>,7=%QO?
MBUV?W`$,LL_C.N&`6__?;`)BDCDWB>WPF*/CY;#E;0<SV;#32H=,&OA*(`T1
M(;I<SH7=A=_Y^?,ONM\?/141%VL<3&P.#5@H9!HM?UY2?R:$B+9MI_MC)ZH%
M'[?>$G:A0!]_?VSTV/^L`#51SD6>\'$]5SUL^7<]G2EGH<=CAPCU]M:G&M0"
M^O/>760C/=1]8H%DPU.-'MX>CQ$\4[6\),->KWM1D\_&0BLXJ!O=;$,ITL=O
M?DL:_C$J^#E0?(7S?4IS2MR^G[?B^=<&[U[VUI67I!!NPQ9-PHEJ33__S@$8
M7_OB4%'[!.5&K5E';8;)1]%4.X!%AB,"I8;P..0<W%>!03!AT^EQ3)K)/I?9
MT)=FB7ISF>.P`6>,P#2?9(<>0S:!3DK>PN0RW[6$A+T4A='JC.TLDO;MG1J`
M8"LU8,H,DL,I:@)B5P@Z;\IN$V\Z!#!`)V"T?3&#VLMG.'@_&.)-O6)?!EAD
M]M[1[7EAAI\UC'1E0AD\6G7`QBB$AG`*P$Y*[J$056!R$\=V%KGTGLMT>.Y,
M>MUX&].*PV*<5!2I@-:\_SG';#8^,]+:WP#HJ(.>9-YC+5.(F-Q^S618+'$/
M3"!U3W#:7,MU0'J&&E1(LVO'(A+W:AB^)Z4QN);!::`#/_9@5K^7\0"K_?,B
M:\E][U'O-(EGP#OS+EUVY<`N#`(21XXA6O\:]:[:L;00B':/^_$)OD\-?-I]
M/2CZ^O-&W1]9KU&LU@A<)]I[L%=;N]/I1&E)3>'0@<'V>-#]?B_'QJSW`M7Y
MYU[(Y+TDG]T?&V7)=#Z?JP/#Z-K\_/RDK_N]OX>/;>_'B!(>Z>MXI@U^QHJ1
M!.Y52U'[XX\_Z(\?/^CZ\8.(BAXX]QVP'B^L06BYV-=($1+N*U"]#I$82M_/
M;\#[F^SN*Z#WC2]X_6.9?CW@@7D*L.6W#DW4QO_LLKBT508YL9VE,IA5O/.K
MIH>??+G3`#_%O.QDHTIKR4&E`@,A8FX>Z_YKS%(>2(2G+@*B6[5V.E^#65&:
MNB-A"P>B/3&G/G]/!$;`Q&N$7=2=3)P9)O(#5Y1IW]1Q_NRLT\2PKM;VB5E7
M'FST,JV5:C7P5IM>I)R#E1`$S?T>I<'N5;:R7[G$=<*>1P$D^GUIA<DL`0M!
M2D]ZXI&*)/V_)\J30B@WIS:.@9^*8@7%'E76K6R:HAP[&OCJB7%-$VXTQLZR
M#UL$!M#U>]=2ZP"\DI'`$/BPHMU6['^;QD!:!S^Y`^1VOPI02X264A2`@&!B
M5S''S#B0)P!J1;'9(@2@F^-@#])2IB'S`%`.[@TX[*/6B1E3&C#`_GM]]X4<
M.-$]J<9X=M(`GXFD91\#4`_&7O1*Y]83CN8!('&N+WV,TA4/G/%<MNU!7U]?
M15?;V,\<`P,1W^EE*LEG_^O?_Z++Z4RIP601NM]NA34VA8:/.]/7TTK(SN=+
M#Z<0$OJZ%8G$MFW@>YP/L4Q*B=9EG6*&%BK!1/3Q\8.N'Q_%):)>(QP<S$(N
MP$4H"I01=:_'\R]CT-"0+.W]_I8TO,5R<ICO_$2K\(*<X74@/?/K?=DU3/6N
M7SL"D3FOR@?Q#,\LR::.$(8TC7V)#_PPH^/G./3`,J84.!K,KH=BQMS)<\#L
M#@VH90_+KTC8&I`7[E]\P_P$MK7TXDA=++@A42@K<-/:!]6%+4V\G$;;]!SJ
M=WT,49V@9H4RD>5B=#/`C<D-[`R&1-N(!<6"Z#(Q>G:5A5@_=E*V86(89O+-
M@B#=B9^N,_V/*["-[,BL]I?A^F`HQ8BW)?-,&*VM.A]Q`(5YPCC2&,2R1<MH
MY(MBEE&\S"U]*[64KJ7J>C5PS<X&S[Q&75[#VJK.Q/&6"%D+4I");RUJ5M\O
M$#/6W0AF1`JC9(1',ADX7)2)_"A\W(--%#CUP`X5:<W*LU<?+WF]&\_M`>TY
M'8<W^/6"6;._47RRLJGJ1:4>$D6W%#9I;G@M\;U`-Q#U6(A>R[,(D/)>[E&2
MP^Y#CTT)W"#B*-YFO5;:_@O]^!@!$=AEO-\?=+_?7*0N&5)#Q8EC^XEQ4%3;
M>R5.M.>=OFY?E!ZI6[>I>]>Z/2G1]7*E\^DT'A/GC2_E,YAI69:N^Q>1\K]3
MHJ6Z6#3!#BZ5&MN@<,(D`7)PC&S>XRS?#.\_QO"^Q<#R6UZZOX&Q`U'!*XPP
M30P&^/<^?0+8)6)_#XASVX*:L;JCS6.GB-DAZG@^?$P9-9V98@Y$M(">.9!E
M:`<`<?R#/+V.HK(5&;Y7IL^!3;*<,=YB!F'##<JDV9"9_H]NL-V<].>RFO7R
M+5NKW1'G,2MF4XBOI;A%T;($!&UXE6!E6Y"J92CCL^RI*PLBW0X.+?':5#^T
M5R-&WS(WEL-"/3#^T]C5`5"'+*'\79Q<Y))O)>H8\>2>`*AF=L>><U:!#TY.
M`6M-3_D*B=YQK*GZHHF9:$%#?%(%Z[#]BHM<T?9A2D*1PN<Z8M;4N;?S)NU4
M@4!5.4&`]C9F[?3]Q7>R?9?(/"!F]IFC><9*J]UKM(D\:G8M-"M'#DV+<93)
MW0Y+.UK8/8@3]Z*G%7"M("M^LKF[9(B]/N::J4)3C/\Q%(1]J)3TSYQ.)[IT
MN0![6T;<#8Q?],>/'_1'M?J*Z(GS]5+=0WS'HLMW`F(*Y2Q[SG2_WVG?]W[>
M2UKZ\3WNCS)L1V@+IK]KJ0EMCVV;.A:)%"G%NI[JT%SYA)06NERNE-(R8JHE
MVG6UMD[W"H/BBLS>9';I;X;W-\#N.VYCQW_UFB?NC.1QF^;AK\A;X/HMUOA9
M>$7T/R8V;/+&)=4>GT_.J4^"(X/D@4I\WC`HPA0"JXAMEB"/I@-O"33^!T:T
M8@;E5%4_0_H!8,%]._$84B/KG!!,UV,[F&D^`&=971;XGHFS,6[H\LQJ3K$^
M8TI[7![C'@$+IKV\V&H=;@P<DUL5B#0?5I>2Q*.DDFQ#34QREME(&.VQS#U0
M'LVV\T2^-<Q10`##9[(6ET2;VJRQT)C%P0H/0(\^LZX9$;@Y8,"!C1D>+#$I
M^RB!XD`DJ?-MF[A-)L.:5"#FMOF^]H&]-D@FT>"3]B/V^_*PAG+GIU&MEP@%
MGL:1-C:2)[7V\S.)0=@-G`!61V*(.!<5E&=(Y,\[\2FVUP8[!FKM83$#=>2\
MOG7,LBB3%&6G1Z-HX8,U:[P;`I\!Y\_&-[NQO3ASL0L1+R1UZ'"XM-AI=EV4
MCQ"8A7;P<VB@?7ML=+\_:I&H.RP])3%@-NSH\FD]T?E\UI*A5`;@!KL_"JR]
MVI/A)7O4Y+0B5_B@'Q\?8Q*]_K/O.ZWK4EPFK.<1,YW/)]JVC?9]=]TW!FL8
M5:C9+I!]E2"25/EA)/YF>/^Y?_B0X3V"*4_)2GX?8[-C*?F0-<7*E@];I_+\
M<V9_]\H//P'&,U8SM/6DN`VGWB%^[?#ZIF#_C=C3T,`_>$8$B$`Y:!((N80H
M4BZA_OHTWTHT96)C530%E*QU4SQY#O6`&04LZ[!U4HT0MFW<N<V5A$76K*!X
M_GYX+1X^UT):`2A3MHI@,MX,2JN"H__B>?1%```@`$E$053^A$73FEV_(."O
MXH`1F0$Y,JX.%G"HWR6*"XPH%8:D)QI.V3QRA'P'-/(JHTAU0"ZQ;YOQ$"[C
M(!P.O[7O;#I@3%"S+'MW"*BM52_38:.CG:P'B8>3A/4?#B*A,S"\$J3CJ8$Q
MCD$CZD\[.PG:9SXPS+5_BIKID/%T^Y#6(2N)!L?)?O'[+>Z\!WAG9\'6UK$&
M7EU!D#B\IHR^UCG/V>T:F9MS_9?P7Z8L3%)5M?K/R[?L>QG^^OGY&3X#XUJ0
MN_\][(3&^>/[4)C9FWN7NUZ=`B=K?!=S2Z@K`W&ML,LY5]`)UOS]?8_3+MMG
MY2ST^?E)]_MC.+74>[3O>P'7E>UN9Y3@V/=]I[]^_C7TPI9`DUG;>;#XNNLD
M:H`8U^UOP/LJ?.4#D^,7&>%#9/<&T'J#^'T9&<M+"'4&=OG7-1AR\&5/3T@.
MJX2H+:),Q%WLP@1117=;?`@(QWNE3C8RO]`2LT;+GP]US@JD<C#9QS8Z@H?6
M;*)U&)(0F?R(9PN5N486QR2SJ2`XJECL"S09M!DLICYFWS(04]1(>"'57&'.
M3B+1CE_7,:+9=[+.">*K)C&THFO'$D@7*&C%L6:0V5PV4:/=:LK<_GF4:M6.
MK;?J[;U@8%J"=[\0+E[-2B!/<,`X*J9H!O;JICIAFMGJGHSN7GHH@7[?$X`#
M]7V&?7?OW41_Z6*[V;>?4*X@`4CKLA09T@HE8<BZ^'3@(*:*(00#.C'(@@J>
M&W5/8F1U;8&7@%EE;I93XO^EXOJ16\$-8):H3.>/="T*Y#<9GENXAP@$@Z2V
M$BX1[=W2[SVY8EKT?R)[W9(-!TP;5G_`^K?KMRP+G=95WV-DQR?88%D6NGY\
MT/E\#C>^+$+;8Z,]N/=1Y'78J62B95WH=#KU0(EVK6^W+]KS#IIG,>^AT+*L
MKD/76.;'X]&OVUX#*2Z7*UVN%Q>:E(V\K#P3MB@4.ZX!TC1Q[W[7NJMU5PN]
MOB4-KV*S)^W569O]);SY9E+QRPRJ08U1'+'\QC49K4MY__."7J-P&`PVPRW^
M\P[[L*/-(6'`QW.IA],I!2W&L$(]./(C=XS#/PO99`X!>]?)<:RI%:&G-AQB
M%@ZE.U.@7E[K!$`;WME:P49OOU_[$6MG!9'G;\/PBC32D"?807\C!B&82#P\
M6YEB>14!K*(0!)TL:O@!@&DL/&3B/2Q!G+$V3;9Z7WYR[_5G=Z:M6Q0AFD^*
MAL9B:5I,V<MB+=B4W:"U02,ULX7/3/%XG2#EJ08V%Z82!KA*R,8(FU&6@M4O
MJK>L-04?2A.\7&`,9_6XYBP.V3<M;L3"CC:\MM%"AE8#!Y!3D0X5$=^F"6R_
MBOM%GNR-]C/Z]YAG05"B4L^-@\Y++,EHOM&D91$)?'A9IPYVJX0>$")P[F*"
MND=XA1Z:*G]G)21#^E#N6P+'BTB6,NS3-#`/$Q"9*>]"C^TQO&F-EW:TU@JT
MT1(S?7S\H&5)W0NW_=2V[W3?MK%OL1G)3(G6=:5N))/!&[?^Z)[W?F\>CR*[
M*."=C-20?6=D261K>`SF&&$_''=-B%3TMIMGJ$_]-^#]QP#R&\#U+:'L,?*3
M9\A2Y.6O=E/,(8C1_817W!EF?\F18%*>7"IY3V-,*@;"D78^NAESRMA,^O+,
MDY="VPR?CA3=(SF\*?ZOV(VS2C0Y9<`U!_9I3/,D0=469#/)+/%='E$;[*Y)
M5XD%:%4/?TE\.4'/*O)*5,DD-",`8M[$02C.39#P/U$"HN]K,)RJG!M`N\N#
M@K.R3PE:'Q)-@.(]MVE5L!G;(35.P_Y'`UW8;"0N*B4$MCIKT#I^,,4I?5Y#
MJP%WTUD.`#=:V4M*/K"$`MVGI0:,;4-WFVB@-LNX1ABC'KGWP)_M>W;2#QN,
M(4?K>B`OLC*!D7S&_ITE'V*3)4KF8^=.D$UQG\7*L[`HXZ>;H'8T$:5G1SUP
M:;>/STDD#C@K`%ZJG'%\(]$'[G_5>]<_SS61+P.3+`3.!RKQCHF7`J837/NF
M`2^.)D3WQXW^_.O/$6.<6.U3?5TT*8Y[WHO^?);-(L8Q1`9@%!O&`?>/I1[K
M4HB*I<9E]V<S9_K\_*2\9]//Y.Y&,0I"46PV&X8:U[33^402;%RV^$HIT>5R
MI75=:=LVNMUN@_%5MHU<,V.&OK<Y_`@2.*1CGW&5^Y8T_,]#XY>'R'[1>M>U
M?%]CAI\#=_6Y_/JQOZI2>!7T'TJ!^>AXAIW0T<65D.4W8,&U3\C)-69RNB-9
M!1\PI>P0&@56Q`P:5)07^*0QH<F$NF+'GCU-R!L:QUWV;@WZ/)XT`8)O4)R5
M8*H:Q0!DYEGYK&RTGKSA&\E#_L#&O(`I\"U`QXWCP4?]E"3#@$(^?05A-H1"
MLRPRAK84RUC/(73)"CP^U:1T[FW%E,9U8-8.$YW!KRSJ</G0WV,GZ!LP2LFT
MV\W#V'QU<\XU\$"GBQ5,I%OR;`-D.O`QT<8@-6C`=\AA>("S0+_:S@5=%\A&
M.F-V+_FA,NNZD;OS@I8L2-?K:W>17-O36;G)6+^:84.7F2DK!Q8,XSAX5J6Y
M%PB$.UB;0U(L*@*J`JI*E+&@"P+/#-J'";7(L*(C%R+#W>,9`?`X-G`OJ=<V
MM\CB=FI9H-@?[7AEQ]>D#KT@'RX1(V!AR#PRR%S2NI04P-KV;S^[[SO]^?D7
M[5E(**G[F^%8LTCYF>:Z`A9ZVY[IS[]^TNWV4&3-ON7ZN>-^Y%R;#'#M]BRT
M[UF'[=!@I4_GB[(QQ&<.07(6JD$:52*3%EK7E=*RC+]KX1,T0EQT&))FX953
M$\CS<I,#U3__9GA_`S[R[P*VWR%U`Q9PVDQ^AVW^I7]8\3C//E..M+GO(/J#
M5NGK;+AHEHF>`-*)%E+(RU,A0%([%ELVO$__LH]F#;Z(C^AXMB!)/,_&<=MR
M>JW:\:)+`-H2.8>``$]"W&-44`F][M2A@)MHW?!P:HATTP$K)-'Q\.&Q-0:!
MS<]'O"^;`@&C+U'/.XA]8Y'&DPZ->#LD_"=GG2#6904*7?1<O<'P-5#@;..@
M'8_#)#R$)<(4LKCH(ZL8]L;N95WAS087B^PI\&`FT\X-VOC-5:,Q6FS]LY$5
M5?9T&"-,RI\8;="ZPX,93$)@2@'[&OEXS[S>DQU*LKIZ<)FPD>/Z-%EK=6'X
M+,L^OK/%32LF<QQ5^6MVG816X66)"G\_V-H'&ET70;QD@$NT+?2[E6\RTT*9
M,LT"ZA.G'B.=B2@1]V'%+LMB7VCHX!RRBXYZUE-*E)9$^[XY/3AV39AJI'3-
M.U].2RW61.FHB87N]SMMCQW<1=@XO0"IP*@Q'N]92DS+LI;@ARS$2YLAP8Z.
M7S.'1_A(:V0JOKHM%.3CXX/6JN]EXN*%O6>BY8!(Z@M&(F:A?=MIV_81[F+2
MY?08"#M15N]G--<A\DJ_;\#["M!\HM\]P!A/VM+R\N^HQIZ\BNF:M<AH+ML/
MF#6#GS&[8G_[F1T8T?,HWR<LL5A6DY]+)2(_!MO^M<EID79WI':QX\RCWQM1
MOT,"T(^'3?@$ZCBG6F@=13N]CJKW+['$16)S]?X3P%XT`,%/GS6[J8K35UJ;
M')/#$$873S&XN7<BDR<%6&\!C0[:#$G0$4!9"(>3B(,,]&%91I=+-9ZL&X1B
M56/TN(G4X(7;T'HNK`9E.IM9>PV7EJIY%HQ+0[M9F<1$[AHY`[B"Z-=?IUU%
MWJ3M>Q-,J1O351]2T&4Z#9Z(Z>ZPB63VK7L<S$&W!@[?&5_8=*VN*ES8%#`\
MW2_"`CF(ZVV@50BD`Q(KQ;L/+/E!0>;6`V#XNU'D"&D++;N/L=)@-Q#1VO8)
MWKO!]KIW2#`NFMSS%VF;^S.01;E+%/_<!";*^H"=,ZO52W?I"#C-],\6]"\+
M_60%.F6M($P8YL#:]NQVN]&^%^`F=6%#^S`=:%)\@9=EH1\_?H`L`#VCF4ZG
M"WU<B?[\\\_0V4.Y*7%]4P1MEI@NYPN=3FO5RS))9J5S8TK&%G`\O_N>:=^E
M:'>I:(ROURN=UK4`?+#B:]*0C)V*J?6==)G%DA9:_W6B?=_I/__YW[TP83L@
M5)_!/M36"Y)4AFCK-4OU_O;')7T/K;U(),:ZQNG`D=G3YALXOQPG3!&HYB/,
M;'16$]]6?@6(/N.Y7\#M@A+&2-M@=6P<5Q1B+AU'?T=!U^L9HN()RV@W)O92
M@/#<)1IE\B!4*#+-ID#*R_,B!0W2\5H&\U1NH$%)'5I&N0\0"$EYT1/QH5;A
M8*AH]HY)4)3Y9#?I+`$?^=W)<?%Z5.CU3`]K:T0X=&>C;1N#Q),0"M'#GC(L
MY1KCP<KE@$.?7_*!<PKX]*L`@RG1L3-X\C;\K36=MNCC@\%1KPO2X)EZF]':
M20^M[`#O"A@8!DH"FS\$6LTKF<.)?%P?M$>TIU4M-4_*-_@(Z,Z>-PMP+=NL
MK-,P`:]C5F3D@P$Q>(<QH:Y:5`SP'OIX@V."BB[6WZ$MLT1YW>*0&`[1,9`4
M8HD?]%Z&\`@A4OI,5<?B,Q1TSA3KE[2.O1,+#!T.$CW?3)C<)N%:E>L1)DH5
M6R9*E4$=<J+"R'(JC"ZRTYUM%J''MM'I="Y?F'6PPK;M!6BO2]'Y"I(W/(Y;
M)<:Q8J(?V][?B<9J[UNFS\^OXK,;%+$-;&ZY)*9EDEZ(91%:3Z<R/-C=-ZJ3
M`Q'='QLMIQ.MRQ)*R.S=RGDO/M8ID7`BR7MYCO/HJ!&L2PS7#RZ`6<=;-Z,\
M1]^`]Q?9W6?!$+\2YO"6K=A38#IL1:*6[N'Q/&&<+>?0<"0_.>FHTXQ_QK/O
ME^.@#GE&B4<`,YCQL;-R3.3:1;-VFRJ`(/9RVJ8_NN`RJ18BO<"!.0(S,"R!
M7[&?#32`WCX[!^\%#G8TL"+*O2-^NJT^.F(#Q#V_PT9ITEDD.R2&"413=BE@
M>BV[W2\1CP+*ZDV5/*8S9*3``S=+.J'A;,#ZR[440%4-Z$*IM:8P3(7`52A(
MMR/QJ5NV3:[<)/"WT[BG;.W@GBQ7D7N%&$95.4EXNRILS3,P#_UU0!-^ZPQ0
M(US):,Q5FEMM?R.SZ\(*6G`'QS'<-HC!:7`#;VD-=F/_#!74H6*#28%,+*Z6
MQ(KE;H>B6.\&T'BIUS0-J[+ZF9&E&Z%<!B*'QW#68"I56`*C=2*[X;EH*^@1
MU%CAD/>WU76FCEM.J<0RC^Z!F#1.'SFLUKUZ_1+(F@2>QR4MM"PK[8]'97FE
M#YMR0JEX92&I@$G4FK;/:\>^;0_Z^?-G[700".42#&Y)&`'?"N'M\:#3QP<M
MRZF?WYYWNC\>74]LYT%:Z$-;6ZS7=5;OQ7B9T[*4`<(]$U76>K8H9!'*>:>_
M_OJK2X_VUNG`HHZ'PPS7288>XYY+&`X+:Y=.THV!;\#[MR/D-W\$6X_T8L+8
M.PG'3"3/+)I^\;-QFXBFL\/M*C`D"*4)TXMAVSF_2MMC"Y]<I*J6J=A&(NE)
M6+?AS$-'F'QTYNRZ119D["I8J!:,#G0F`]"-!1OIJ=.LRD*7?/QNUW**^KVQ
MT(JSHAD%P?$PH?"!\P>SLZ5R8+>!48G9>G8%C0'O";L6)@6-92I_4-93QK,5
M%0?#XFHT'81\#CRA'()\O/!H]Q;0U;^S`HN4-*`@?$^9ZO0V:78ML(3S]AA:
MTM0GWYD4J)H]A%;'3*R+!B9K236^:X!=F-`VC+JR+.JM:U,<D3:10[WN8%1%
M/S/-^HL'^-HK@&HO7P>46&!AP>4L-T2GEMDE2N:!%U@<BI&`D`R-KB*L6SJ@
M*4#QW-O040JZ+@+3[R'K32VAS),KC=TL;7'6-:D0%+/D4PI-YV(V,X$K33OR
M+.4-ZL.&V4C:(#.R'7(V=GGH(SYTW:+62V89(\+2(BF2DB@TN<$`>^4ZIR71
M:07_7=%4]O5Z)<E9A5GTC4NMM]#=89W<>#Z=Z'PZTY+Z$="ZK'0ZK>4\LK@.
M;%?9-FUR*AKJ94ET/IW*(>2M/UOCQ'9BR;2D^F;:@8;Z^5O>*==DQ+SOA47>
M]R)],M*']L_2A`[&,JZT0\2.2G?O:/H.GGA-SO`6KF7Z36_;]_[\.-R6#ZBK
M@R_B-Q/3GARW8KN,:$R")$0FW[+5S-1K106':`]NDA+ZDQOZG9^=S%E(PN0I
M<$.8D*42/#AN3LG<9ZV-U7*&D4M.T/(2LFZKD2F%LTT*V%=DR"5X^CI)]):W
MJY]*Q\&0F84<$I+8N6[A')A`I#9E<Y[X<YS,D0<M?&8?[.'N.Q?=8_O?C`$@
M3##L-8`W!6WRUHXEKKJTYM')FJ%,*9F4,<V(]4V186/B`8J8J;LK,%-HH<73
M-]T,!D'BEHCU\^10UC3S$66XCC91BD#CIR4./@2AG)L.'>A3XL9-@<!%`DCZ
M;O_D!JQ$1MO>#,PY"4,[Y@:2B"E)'9XBHB1E0V?HF*7ZO"4&?U8HLA*GX8G"
M`PBTZY,*Y=O9,A:AI0**]GE+2I3J[R]<9HUJ?EA?<1/83MEWUA89R@8N"QG;
M;EVP$@X+BOJ='O<@Y;C;F2[,W5H,$T%9VGEWK4P!F-4>H%WWI.*'0))5+<L2
MN)[HH!BJUQN<?IKL*0^9RK[OY5ARI@3M!Q;_3K7!KV5A2DDHL5#B<M^XO?\D
M=#Z?R_L?@/U^#)`.6:<(Z;RN],>/#_KCCQ]T.BUJ>5D2T[__]2^Z7BX5F-;G
M1(0X4__?DG.]_N7:7$ZG$A<L9=B,JS8_P379MP)F^W-)P\.<4[DVGW_]I+SM
M=%H62LRTT&#.^W_6^YK:?>\%QM@_RO>WPJ8)8<J_"9)(OQG>_S*[^TR\\"Y8
MYFE7N\]?3W/3A7[--U=>%%\P:49%O>23[^`7<3D].78VXEG,6U*#8Z2KX`CL
M^<V8U7G,3@(Q3!PM;%E:GC,](?,\OS!LV([Q%Y$/,[MSC9*Y$#9;4&+/2P(_
M8:V)BY]`UP:.VHHHU^B@V1<M.$@1F?Y'0T,]F`1./7%R4IAL-*V]M2GL\KBU
MB3H.@0VTSFJ`</B#(N"B7`M$[`JA@P"[$;S"R'3/X]2MKQ*E-NA-*:/^+^N[
M!1K2[C=*;)A7S<2/J-[DV_^D!R([,VL'>OQ8MF'6RCW2QOX"7%V@C*J3ZU8W
M+_E8WM*92Z:#T`?-\A_Z61L9B=/52^1ZPHHE)01;G>G.?;W'L(_^E>@/;=[O
M/6=*G(JUE]/Y^P(1SU\GHI'R]9ZO(Z:`-]V;<1W`48*1T>:A!JI`-D/X1M=]
ML[@N0@:OZ19X-#QN`;37=P&E$LSZ>5#2H+JV+DM),KO?'_`>Y1)'+'I8LK'R
M^[[3[7ZG95V'M:&V/:'[_:X2]FPC"!/E.N')3.?+A7Y\?(2=OYQ+(MK]L4%'
MBF$?&?>TV:\)$:4ED52KM19EG7/NA?VV;;3M58/+OM`A(?J\W>BQW>ERO1"E
M1-RD)B#+Z>MK8K4F)-;_6Q,9P1Y5GY=OP/L,FK[:,Y<7NO&F%?@TV>$W6>'!
MAQJ?R:?Y7^]^H[P5GA$-U*M0A`E\Q\%V(6-98K\CF-[W4)\/K.7$+?1JL(;U
M$`V;7=9/+;/;S-S@!IS/X6/!H<QY>F_L$`9^CYA6MMK4HO8ADXZ[M2X&1D]I
M+XH;F7,6!_QT&,@"+=MXC/Q5!V#(6B)"P]Z)+3M%K`;MF-AO-*"3Y-*O!)>%
M44[H--3AE%%^'C6XR6Q>4*,DSY9ERL2<AO-!9WE!;0?."&URO#'9`FT8D0QL
M>=*#@ZT-RG&(`1M9QFAYMW.'P2D94HP.F-J]2V4B?&QDF4B28C=17J,LF,QZ
MFM5@G/0!-0DBK!=>[`L[B@8>AOM6VRG@PVO?MQ0&D)"S\M,1OC&SGK-HZ8=]
MD\SP6S_'%GY04\F&S,47@:W($@%313D8VJ[WSG5"X1U65FDT"64QUG/H?M+>
MG3&Q;[-#(:BBGJ\PN"(HG2YK"46/$1ZM<#5S`#'.3;8BCL3QFMEF2T:$SDBL
M;".[CE]*//?"R[`I2\EM9IR6$<H!VGN12-XS9%DI,6W[1K?[C<[G<XV"'FJ(
MV^-.?_WU5RWZ$NV2=8)::XBD1"DMQ,QT.I_H?+G08]OKVE`*]"ZCDO'SI1BJ
M1\B-KRTQQ#\_OZA)J7/.7;=KDPH;(X];6P9+0*(AJS)E&@AXRV=]`]Z_B\@]
M<`N(?^\XOO$=^O>Y[ZW\!H?\&E,MKV#>21JN_VMD=R0<1F(!?=>S"4+GI<`O
MG-50;V*=($QAK"]Z'0@;"47@8A&%&\<M_Q?NVN&UCQ],=1Q/Z'1<_,1,V%OC
M>$.I*::@L2W:,U%/5ZN6*+`U'6QR`'+9L,T,_]E*O@:2)FR3`HIL_'$QT:IN
M%APX$A"/!"?E$03,"5I:-;/\OO$:YH]A@V;23&([+L]2LRI"&#9M;+?WH4H9
M<N>V^8IPC1#%(`L&+5RY#YU)RT?R!@8]*-R7#*UH3A"4D4V"&)N!-B:NSAR[
MD;Y@-<+X[DZ?:U9``9E%[=`1#S#9%U99EIFI?I+YL;#`>@.3YZVUW\\'"]0`
M?/;_!!TQMZ0O`R`H`,="95W%05UF:ZF31XA`X%S@HG.[9AA8NZ"HQJZ)B_.6
ML<YT0%1ETZ4`]!2BB&8GF\2C:;E9Q.P,X`4,N2[]OF31#3()_"RAM;>N)UJ6
M1PEJP(Y("T(P_L&$FOM^$%AP$IW/)_JZ)=IW<9M(,@EX*0T;Q-.ZTEHE`UH.
M0[1PHNOY0BDENC4&608^)V#X4V+ZX^,'+>M2W&AXIW59^GTI;F?E7ES.)TK\
M@V[W&]WNJ7KT9B(N:7(_?_ZD/1>YP[[MM*9D]@R.=>!FS@#71F8="TWHY2O?
MDH;7N,QHJ.4%T/L+?WT(UV9LICS]W"<>:6_+&>(S^AN(ZA>O&^CLB(P4@77K
MV69O>_?@P9;(_/MZG"N3UUA.)(UX/10`MI:"^/T\?^YF;@\XL&/O@83)Y:]U
M!G1Y4$"E3$@9_-\B?@,8A"SWECZ1EQ9$[?'XH8I=@8=\%NVS*E"J&R^;A=.^
MVPV@X919M[NJNUUOAYH)<<7WRK#_4AM;%11T;^S&ZB4]W98HN:0O!'^J281@
M!H&E`LX&]%06-U,NND(>+7]\;Q`L)6!Y\YYKRW<,\G46.0UM,=H)82Y*XE0+
MH'$L)08UT2:[=X^`Z\!5KYQPJ-$DG*&LHC#78RA+^?T:OV,+9IQK@&69+>N-
M'L_*L0'879;0R4=KNL=WY+Z94W<':+^1L\\K3VUHD<EYTB:,7!9V78<>X(`,
M-F5*#/I=`FD`L8NLMIIE=$;H^ESV;W)"R0';;HH,>1&^*DWWFT9QX/4@NI.H
MUE_EL$)=`RT!!L!A.,4P=Z`O'1"ORZJZ@N-SBSBWR`&DRZ6R9-KVG2Z=4O4/
M_[JN]./C@SZ_OFC;MC!2NA6EU\N53J<3W6XW.IU.M"QKO?Y)K77GTYG6=:7'
MXU%TND#@M/>TG0\G+HEH=4U(RS*\=.OW;]M.V[;1LBQT/E\HYTQ__OE7B?JF
MX8>=<P;65LC:'R>C`U>=5V7;(>2I?SV(C4/(WX#W[Y`S_$W$Z4MZ6O9(]SE`
M9576O71>_,YYF>R329'P*Y<)!U*"4S<#*Z*_1RP3.),N3(H)98^C$W^(23$O
M>O6>`VB9R2M8YIL&Q0E/9.U[C+>I6Z"#/'.9,$6:=?53A3[AS&-1CJN+MUXG
M'=G)8`5FL3`31B<+RA6,E=&P9A+7BNT%1!6!-ZT8+IHZ1T_ZIM#EKS2&O\9U
M'%$`W"@;'LSS2'_R;LVI#:BQE8QH[7$RS@1V#>-4I0^L`:F(CAH6D$(P3'3C
M?R\%!'>#?3+M>*T%K,]A&4GOUY=-8$,[EB4ME/->6^:@VY4QD$A2K(^Z_R>R
MW;7%V<-)6P%4V]W]?MG8X3K<U?=59T=EAJP,4]D^*XLQQ`9G![0YL\4S&Y;.
MI?/!<3B6E+43A9B"43/$I)A%+*N3"O\8NNCN!D*I_@S:>;%B<>U"B]('[(CA
M-41'B11-[?*0\*B"#O0]S$/Z4<('4MPN,^*3!L"9M9.+^GKG7(+!+OYK^F>1
MMZ$CHS5NS_?7YQ=)%OJX7FD]I]9.'/<F,7U\7(E3HC___+/X\0:LETC1T'Y\
M?)#4H;)]VTO!FJ2X-*31,9(L]/GY6=;%6B`VQKF=YKYO)%EHWS;:4ZI!$:D,
MI27N[^K/SY]TO]TI+0M]7#^*OV\;XE-&V=3]KR.@H_:?;M&GU^O$PT?9BJN0
MFQ*0`WT#WK^9BGP]QO<H*N)%5EB>`TFGW00/3PJM\X\/:#8<AXM`9+;.`3Q6
M&[O.L-#?Q>3LM)Z"?)YQ@NR:^FQ3P4P[3T`3)*QI3/]=9GK9,9X2EPDN^BDX
M=NN12H"3.69=19A4T")KN[`C?9Z\4!2HA=Y<O_#4IY[![.^MTL'J``:KFQQX
M%T`O`!K)`SRD67@"&N9S@I0IXQ$*4=$,NC1.Y!*J$B]>-PJL9SO-!.EL75.9
MAQ2"NYBQD\3E[Q,KL5T'*Q#%A:"(P#NT[3^9:HNX?4_6K#!S*BW2SL1FXCJP
M$FFNVW`;#M&TI[`PDAKHC*$D[NRQTL:3EN?B>422C@$&D[)MZNUU,\@H.I?5
MVR@:]9GU-W9#6J3=5+"KT)A.3%%3KS:2&`S68-R*&NK^IPFTKKE+=K%``,TJ
M3G,`FZMLLV!Y&1(8W4J00)K1?(LU^<`*0(;#:VVZ'ECGJ)C0(1L6YXHZMQY:
MD2`<I'4J7%8XZT*FS['I,`<<)&Z?FR&F79$A]9>6=:6/CX_JG>O1L+*ZJ]=A
MSSM]?GV22*9_K7]T/>RP,"S'<5I7.I\O='_<J\U:5MV,E!9:UJ4,CFT;?7U]
M%;"W+G2]7FE9+NHRI+30]>.#]FTC(:*OKR\B$EK7$AI1[,AJP0[2B/8<<Q:Z
MW>^T[YEN]T=Y1O:=_OK\J6(CK12G!:LH:T3XN\4\%X9^Z;_G=_1!_`X)F7QK
M>'^9^9TRPF^V]G4&HYJ8C\:0Y"T@BI+^B<^8<.S;^D(T\B%(5X;Y$[!KT2QK
M<*@6$P&*PNJEY(4)+W<1Q2'JOE1+/`JE0`NSEBX\N\7V9?2W7L/9!Q<``"``
M241!5"VZ<1>?8<`*6O4SMITM4Q@,E5#L7J`.(GBPV!F^^\AF.Q8XAC0J_QH<
M>_.,9O"*Q4EF'&21Z.D3GXXFHET=5)RRLSW3+'&WLJ)A887C:T,ZX:-TEX5[
M^S<APU4W>#(MR*:=4PQ&BH;Z!H#M0,$PMAV8-J/[@41-)*X,YIPHT&U6:R!N
M8*UL=KG:Y6/7)"/#+-;CE:A[90FYY+7F),'5H;3I3M$OM>/WG,M$=QO$<RU/
M,A/Y`_@W^Z>,U0\,M"2VN$3?-X*N06^[FT`+UY40'D$6,(R$01Y9@.T6[1MZ
ME`281;.E[=[G[J`ARH.]Q=P22'U:6WT`<A[A#CP`="3IP.Z7#@HI6O`90^J&
MY13[R\HS&*45"3H,*`/C@%AILP;=O:+II#M3/2,U-)#N/O:L'7Z4S9I0:%]X
MN5[I\_.KOMM:)J/.6W7>N#HUS`5G]_N#4K43RWNFGS]_4A:AR_5"MZ\;+2G1
MQ_6#<BZ1Q>TYOMUV(F):`,2V8SZMIS+45JT/'X\[72Z7&J(Q`&^2T?5Z/!ZT
MI*+AO7W=:=LW)?%I_KK*/8;'S(+.31053M4*"[9>TL9Q@T@[9S@"1K3LZ!OP
M_J+T()(:,/V*CM4/4LV`;X@X:29K&$S4%!BSI2A%@4UD*"1BY]X6)7/P>T;/
M)F-81RTX(EH?2<;Z"C8(O'ZN.X8)6?U_RU0WI;+5.:9N@ZM'+A>Y3\(KQRJE
MX>5@P^UM23!][P!'HI`)G1O'S@))3^<[GPIS'8=01)3><<Z?EW9U<M%Y+U93
M)/.:$/1\?8@+A`)LIJ#;0LJ2W/,U!L:H"2.I$9:85C:LN.HWH3X$?'MS?1X&
M2-5#%TT+J[2MB7LRD';)&`X%0R<YAO::!$$EKC%H;I$)!Z/[]C,-U%BVSD[=
M#PTG=X_.3".\`@%,"@(K-/-O8X*+>3WJ=[LE6GLN4Y48"&HT`:C4X=4EE3AG
M9/3;BY]:.SZQ]P$7":4\^-\3LL(&U-@H6W3T2*VK`%(E3#5CR<Z#G"O@[,`H
M);4T[1"FT`]?+&-*"NB7'6!Q27M<.P\)V->NS4S:ZFZX%%`HNVJ:8<_>)K^^
MFV<+V=\C#_!N>P7'T0D*'MZ]=N@3_74'T]U:Z>*<;G`[Z$LGZWNO+/E$2#@1
M2XGIE>IR0))HWW))7-OO?1U'+7.7_D&K3D1H>VRT;T+KFO3@9)4XK.M**ZVT
MKB>BD]"ZK+3M&RTI54E..=[/ST_:MHURWOO[=[_?*:5$U\N%T@GUO*E:])60
MB^NEL,!%*ZR)E-R'8%,'X/^'O7?=CB2YD80-'I%)5K4T^_YON3OJ+C(OX?A^
M^,T`AP?):HWVVW,HG1EU5Y&9<74'#'9I+@V&.AD@]LTZK[R;);PBI<VL<>W5
MGS0L9&3.[UZF=\1J%\597'XCO/]VE/?LY]=B-SE)EOT$]>"$:G!::JQ`/(JE
MMJ,Y<;2##Q1ZQ$&P>55V<]#0K]4*C_RH+W(WT.#KOW8G(SB3\5_7J:JG[XHK
M6B6>YT<WI1?X:D8\+$B:*GB!*WS%C5#GZS.C%($*G7QANU.`<KF\N(HF?SU(
MD6MCR67,&HWLU>-3D6>N&.](]>EH%+[!HC!5)[2L5@5=V`Q!VF0@HE%D;C-/
M9W%33RJ2OND8OT[N(`6&FPJ1B:LI*4'8]JGS0&$C/UGI!.(NPCLHD`C-W;UV
M'3H?U=S7LKGE9D(?C*7550G\''!A/#,@4B_\_:B?1Y+-.[452G,1YL13CC*E
M+&X!PM%ZLU6:0B2"Q+*PK=71I!Z9HGUS"VXHD:DVF,%.'H[.)R7ZC(*\E!D`
MB,&7*25-AQU9MZ93M<\AB;;8B06(72?XWUOS-/OM:AB9#5?H*M0&VO3TNM9(
M4A.3)+;79.H*[1L*2U]H;B%*:7#JC&S:5$2GIPD41,%1T85Y7R@$!RZ7K4XN
M-ERO5SP>CWZ_,GFM*4T/>A$MP-OM'1#@CY]_].)XW_=^`/M^,>O<Y;)CO^S]
MLW[]^H5__>M?7=AFK<T5C^<=KR\OI:'.BK2E<5UZ\Y'J=^UU/;$S-:GI<'_^
M^2=NM_M(!'1%KGF7'-JS7W;\\8\_RC*5\WB.()TRHM,4M^XJ%8A0,PYV&B)"
MDYL.XKO@_0]5P1^!H3H%(V+"#?7?=8@Z%^(S4J<?!!RL;79\R(5.OR<?7C(N
MM%AH,5U315SF!XJI^=PG5]C0U$*AIQ=.W(;;1_?BU-D(K'/$CAD-=\RCS+J(
M8IOP6UXCYM'#[$)A+840A328(E^-;9O="$9A)8[4KF?4DT!H)<&&XY^M40AJ
MYQR6Y*O<NZ,FOA@`HKAGR2G"!2:8!#(V=19/F4AE]HYTT;K>.4/4\EFY0>+I
M?#L'+KP*@IYG[J.,Q+7L8X';%9S<,+07+))D$FJQU[0*IO-JF?=#$)G-RM''
MY2:"FM_O:G<D6[_&4!O,D1H7,Q]&G*K5K-\Z<M"$PO-S231F1&;N.<_>NS4L
M;-4@KRIVA"YF?&2+RH;^PM@JC8I$J]^O.N>#_B-J$5-U+*11)'-1.0",-N(7
M20Y![9:]4T5OV!_^F@8TF(%8<^PTA:DPZM9X\R1VM)\UWFMO4V4*;YTI$3T<
M1CF@&]U9HG/T^][2&I12]*:.E*L)Y!"BGO1)`P1'];N]7'Y"H-CVA-?M%4<^
M\/[V1M>R^G[3.V?6.E&\WVY05?S\\;.'/`ROV?8,>]9T*1SOC_OLQDGKW?$\
M\/;^CI\_?PP1Y9;&^]W6SR;PK).=]KP_*B\XI53"-7BO*;G1"*W\Q*Z[.1^5
MKP]D/<Q$4@EN%\_IX5`0Y\,T>..%Q\2IF-^V9/_.NE;_1D&JOKR23Q_$Q[9D
MOE"8"T<-Z0:>WRM?MUJ0(/WADQ^@IHNG:$;AL;Q.1;(ISF`,#69:PH1R?^)*
MBL0D%*=T$<<YE@9E&Z'J&34`%M4]*79U)MEZ>K_]="^T^`0/Q]-@+"]VC.2\
M'=ST##CTF/^3]0S]!B9U'_V/46WK$!ARSKJD@B#[9"_5W+G10F.-@J3E@;"I
M$G)I$;$>+\N%EK>PZRA(X:M",V7]5?/[QKVM4)-*[M^;-)&"W"'"J)&GDI`P
MCGF*L5>0;W%CE+LQ?RL(<RYC4HELMK2?HT\N:ZI^@-`[]2@L%6-TG08R9"V4
MV.F`">_%^<$6'UI136_-EK-.3>K$W64AO2DX;0'="W%7`%IKN+@8!(_S82W!
M.&Z6FPYO;R9LEZB(;&E,<3TAH>H#(ZQ0DFVAQ1G^=^ZYFQ$9^S-)+A7,1I(W
M!Q">_$3-8@L<\2X/+36P]_+.):+[&*M?1WDY8J<5?CX4R((L))03ZR^<:I3M
ML.L>"/>1%5L:_ML_?Q:W@L?]WN^5D%N,H8/IH*T\'T_@!_!\//'^_H;+Y8*7
MUQ=HH;%W*LG[>W%W2%LJ?-XV)8#UW<Y:IB*:,Q[W.Y[7*RZ7"P3`O1;8);YX
M0]:C-@*%(PP`/W_^1,X9?_WU%Y[/I^,_BXEVC_9EWB:DBE/__.LO_/SQ6A']
MV:NN<?4]\")4X)K2Q=LCJW5P^"YX3PNN3Z*UGNOZ10K$>;GA2CO]N_0*/44'
MO>GW*JI!%W[``6S\Y4.RP@$%"YI-:LN)>&_I#B`QNBMMZ?MDXR*+#&06T)@.
M7&0N3\6P-0RB'5YL$4<CUM,&2CT*+@B.50%(F'C&I)AAF13FKPV4E^(V$2!Z
MV24OG;Y?!CG#,&M7)U[DL`EV^ZB;1Q->D:$"M1L92-4>C)&^AK[6XF`6Y:`@
MM>PZT%.%N+%0HE_PPIQ]+F@O6I((CH90>V%.;O&YVE/7BG]M0[$K8M*0UX9L
M*3V-E3RJF=3UV4XOD@AR%4`5!XD,D<VBH3D'CUU5L`MS9I6*T&32OK+F[@HQ
M"M,F,AKBED1*:S'4"9A[8,:I-2Z7$YC\.+X5#=;3M)XSN3`85-&,3='T>XX&
MX18+U8G[+*`0$Q)H%@NP@5Z)"`ZV4',`1D-.VW/A4?B9:RPF7EB:*$S@J!8P
MUG#\VK;K)L29M][@<Z'/>*2?3&BT;E%ST'Z'A6P1E<6#3V7=2/$]-/,C)\Q3
MV]AWCK"G?KE[<;N51+,M67[LC]<7',^'21&TWZ=3HY8UX[__]=^EB#X.W!\/
MW!YW7/<+]OW2T?K;[59075CDLZ^%9,O%UGEO;[_P_IYPN>QXJ:X/S^<3NEE.
M-Z=3OK_?ZCD$^X_I&F5:YY/,0%3A%UO+P^@Y]MVH<>*`M:+T>P1K>KX+WI.1
M^J=]>#_AAWO^ZQ+0YP/$[W.'\>'?K?U^XTJ54Z=.OWM1F'V]_AYCB*RK*I]2
MO#1&LB<7!J>&5<,-'K9=HI-I67S<:V8!+>RN8-%HJ.RH'JK+9`>.DEPU:E-:
MD5CT8(`^)^E/C%R'+@WV21)C(JZ&O_M1V(-0NI33X3@#>@ZMB%$%<4;[0SQ#
MG]?FMU4(:"@4HG'2'L:XO13(,$(31GC9<4`K4BM!S\&\1Q/YVHXCUPT0:?*V
M;EQH[4*H^=$<1;^]3MIY;:D["/!O]A$]I9]MLO6@";O9V9CI;O1.-`?.N6<N
M:3O*K'$L;GLF&BKEO9\/1_E0U2FV]LC9!;%I_(KQ.L`H)&"0.&-#)FYC#9YM
M3C:;K>WBQG6L3=;?MY^C>T\,K4-CX,;08L3&H_?S9/2VOI,CI(1'Q0J77&R.
M15M$;!O=+]YY>MBG2GM8G:?>'`JL=_)4?"Y22W5JS.)BRGB^IXC+S-ZQ8N-W
M,9P)GH\'KIMU6MBVK8_T!7,J74/=C6]O5J@>_1".XT`^#MSE41'D2H%I:U/=
MN!(]X-U!PCFCH(KC(,#S^<#S42S,`.T1PONE<(4?SP/[7F*"[_<'V.=6P7IO
MLCP-!8CV_85IX@OXD&9$B5+4YH+K3.@8O0/?!>]O(+SZ&Q#K>0%XEB:ERY_X
M"E%`>7%9#N_EY#ABY'<JC.6+U\9]D(CS`'5*<G7"*2.DX[&9N#9?(^9F&RDJ
M(7"#Q*M1>@3%&:ZOM2T">MX[YCA+@3KAN"YH()X6&'D>+^REW+@T>KZ,2,ZO
M2#)`2/91911(86/EF`JSLJ[S14$.FLTAHEC9MDD?>T)LNI>42G+>'!73OWO>
MH$>B],2HNBB/47'01F5HL@OI\;UV(V>49Z!HQ4$AFZ,HOK?2>=$:N`OPM>K(
M:RW"!__2CK$E"3;L/?FH352Z=R\5?D>NQO75D[=\QS$]@RUJF$?ADL;Y60H+
MI;RY]YJMJ))QRU#BPB9D/88P!C:^F-]7W[Q.3)LFE'&N![-7[UPTR<)_G-%$
M8;H,+!7!!F:,,)N"4,N4EM807Z@3&5(1&ST;85'N>+#M$'-60RLQWL--G^C0
M!G4(K3^><'^5>4TP-I`R'"R:V#6Y]UF#(![;P\U4L1EA5ON,4%)B;\),ZIM8
M6H2,W[F]WW"]7''91WFU;SO^^8]_XNW]%^[WQXP6A[6'])1AV^AK$456MY9D
MJT'#$U;Y>-1:>+^/?O[/NGX\CZ/?RXNTY+@\N,_L.P[%Z_45SUQ"+D!-;M:8
MI#G\A<OQ;MM6"OQ@?,Z!*ZQ[49<K@,GK&28][KO@_2U$]O=<&K[VB?HAPOM[
MZ67Z&[\S%\[1V#W6\)\:K!GJYQA1S3Z<T<A$(KXGB0QHA1L+.M9*:_X.,QIQ
M5UW/6A?58"Z/F7Q/2-%9`+#WVA!JJ97].S'L:+P1!%]G0WJ"2W>B!=+I'(QG
M:^1:('!J:\^I<+9/D6'_*D8XIC+/Y]$'$97WU8HEG8J1L8BVM7,\O3)XO6!/
M7YT0_+X13_=^+IY'PIH,I-@57X-*00X;.MY8S=KM@UAX$_E>JVIQ!&@[)KFL
MY".;?S<^O#+XRC+S@)!0C.^?SR?R<4Q"IO;/S9:KQ:@F0KF+K^?6-]NL5-P$
MS\"V%2_0Q^/1A6H#Z4MUK'_8=]`EPHP-4^ST956LT9/BBT[^9`D*3-NLI?X,
M1$AN1IYL%=M#D1QR#:8$U1,P$:S&V0#NG4N3<-"Z'*`*!\M$(7>1E*63>`<:
MSU56)U1N/-NEKRR]SV84K:`88EL(9RKV_3HV$/6R\WB*AKKKTL->W-ID&B.U
M3A9P"9,B#'0(GL>!M_<;CDO&?MD*N@O@^G+%D0\<A^)`AA[9%=]MVYJ+MM;\
M*-VL%E/<[GDRP,,01#8P(+OX[(QB#69!B0';VB%I:7;+\_PL0,.VT3N]X\>/
M5[S?WG$\C[XV'L'DE=F`Q?>W'-L??_P#M_L=[V]OQ?Z0*E:I695*3<R4"EK7
M.2,Z-=S&;X3WWP`%_SM^7W_[P_6W"]\5E0-+1/4SI?(J,$P]"JPTN@U&YHP6
MSW9C,GV7#2.0Y27T=D""$?=Y;J),BFN5.4*7/E^#$8!^%)D'.;FOV@5OAN_7
M(W"'LEO4Y?_"_BN;$.3H8)T%#,06$6-O#H;T)!;C0L_P!;VP,.`.MP)=H:?4
MHIX^YL2(@F)Y<[V^0$3P>#RJ'V6>A(`:CH`'L@H2J'ET3\Z>%$HIZW^68`K8
M:)ID1M=9G?!LA`(T0V!?1[1B(`<A*27.5WH4:+NVY;KDSO?KF[LTU?KP/[U<
M+L60?MNZ[=%\70:"7/QT-X@D;"GA<KW@<KUV+N9Q''@\GKC?[S5.V#N4E*+]
M>GGI+]>1LT'#E4RH)K&DIP1XY-ZM$1(AM(O`!*9JJ'>[]^_.8BK4U]:<>U1R
M]%UV;0RF,'P\#0UO#2R-TD$.&BW)*J4T:"SUJJ3:^"09U)*11":=PN,]>,/W
ME8JG>9ZM4^$R'%9@T'^V,?/I;4I!("(D6-681M0:N@*L9&MAR+6?!,X4Z)`]
M)@_R^K*^O_\"\(K]^L?X+%6\O+SBY?J"V_V&?_WK7\B'=MI&XZT;E-8T].1`
M0H5Q=C2V:5G5^;E/4[2QM\=WZX>`0BP4U^N.__KG/Z>UV`I\`W3=[]N2`"3<
M[_<IB:U?!^>!G>DY2["<;'.;V&FG6:%]5ZQ_L\;]F_S=C^*(STI?_<VZ^W-4
MAG%R?A`/L<B6]<-;!5MH0'W0:M_ETJ]$UC`Z"9/\R%ZG$(W`%S+:=!R_;HW`
MRQ*!58?&K=+DU@^1[3CX+#KOMB[0/0YV<8BL5M;H_GBQG$=`.])KDZ+Z553+
MJP45.`.IE7#,.-*=K(#"C&5AQ[^1V<?P-A"'ZI5?N%111U0T:!3I6I^/Q`V9
M\C1!C35>%WA*,S\O>`DT(QO,1.<D,'@N*6W:R9U7C@N?\=E!PE>[!WVC<(4H
M+#I2Z`G6']N\\2UE*25<KM?^^YX[RT@J*HLYI81MVW!]N6+?+[C=;]W2**6$
MR^6"UQ^ON%XO!=UY?S=/?LXET>EZ?>+UY;6.VIO1O16L^$5.@^F+%<<-01P7
MC$8\U28@W9TAV?0U+BHY1I5&\J$.8$Z9Z5QA#KR`I[\0FJ_!,:^BQ\6-;%)4
MR&/$0JN."?&>''*-.31B?J<&:NG3^!I2UWG[4^RVF"#-Y+W',PS'V7KZ#B&C
MD!IX-/NETT^M*<A*2[,"FHI`L^]SF..Z=:8>F#6X?716Z-'XQVGPC)/@Y>6*
MY^,%]_N!XWB.0J#'Y>HDNFD<7]\@I!!=LNL+3RL9Y14"*J:):2^*,X[GLTQ7
M(+A<+OCQ^FHH-7_^^1=RSGA649Z-;Q]E;G([7J[N%9?+%;]^_46%/Z:U"DKX
M1GM7C%T5R=-"4Z/OX(GSL?07"DCY79Q6=2V,"L8!?PMDEGFLORH.`UQU&L5[
M5,[-=V*H5]`C#1MZ8[YAU,(SMXD]+L_.CQ!(-<5N[#ELCM*,1,9W#M6X15@,
M6G?B=QNAY+IX'I;M"*6UC69)3/$S:!=T/P0NW4-!#DVV$U<-F@1"[]0Z/[)W
MK5=AKSB-/`[NL9O<\"@5L,)4%YWYR<:=H=RT;=N0MLTD6RDE<?GGME'1NF68
M4DJ=<PDIQ4+BAW*@^NK<5)BS2<(.3Z_(Q$GE:S?Y-I/:NGF7,B+-3@`#";:3
M@E0YN&U\S7QA.$-^'JVGE/#Z^HI]*U&B]_N]J[4MVB;#4:-N[*\_?D!5\>=?
M?^%6[8_:?=GW'7_\\0?VBAP?1^4`8GC*%K','=?K"_;+!4<^D)_5J+[3168Q
M5K2F*W'PQ;DG-*2U/Z>+ALFL@Y%=#0;2:'RK.5[6-+,2IKY%_VZ:&Z<"\H(N
MBVC2&+FBP,H3CP`QCL1^C=:BU98K:QN;#W5(UHQDPC.HV-$\V1:.'DDF6E6/
MM98Z?*]9*H:7W5PJU%K<E<)K%LLRA2I!*,6QK=%BBZ;D>,S0<.,U00D0W.\W
M0!4_?_[$]7(Q=CF;;/CYXP^\7`_<;N]X>[^9YA?\O&2UCCD](ID;&W$T5J:F
MN;U/=?8$GAJS(KQM#7>)"5;\_/':OZ1=T^=QE$"+1[$JJ\2::=OA$EC8M2AG
MJ!Y%X)I+5K/UMA_3+#LET'Y^:5&M&-[^-\+[[_G/!RY+YYS?K[I!_&WN0I01
MQ,;EY_BF+DIS@8VMC9"GOI%T,_EHP"=?P%<#)$?FPE74HZAQ@6GHOHZ**WXL
MMV2FR-)>3/F`(^LP<7'",P2)N)S6-5*O.KW\4D>2';DCI$B=?%U5P]$8L+(<
MDBXN$GZH:('TR56ZV.AYU['HA#IJS"@H4BH(Q./QP/U^QV7?N]IX:N]XK%U7
MYVZ"KVUXAFDZP=<H=20\]<0VK>E-TAP+"+6R8UB`.>XBOCD3%VU-Z*/`(*U'
MSD/!GTN4KN5)5\0J236RURE,P]Q'&:A/06%_X++O)5'J*&B/1Y$8L4\B_?=$
M!._OMSZV;(EM?1S[ZPW_^.>&E!+V;2_7[!@0I:+04A[/>TFN>CZ@CX<+;1&;
M4!AYSYI1M1IG#^^-^^&:[!9]'X!@"ZQ822[!.^'%FGX:P,\'NQMP(`J_JT70
M.6,1[0]ZU*U[QZ+5I3SOI<A-QG9FT$5$1L`#]VN9)H4]PILN8>YI6.@.$=ST
M*`H?M)NO$5?7+[C>D:`5]\FO+TF@AQHT66HL^NC_,R4ZRNF^3RG&W>*R4'4R
M_OG/?^)RV8V0<M]W;-N&R_6";=OPZ]=;Y6A;[]^!?'NM0VO:,C7J;M(C+N*\
MT9B@/53"8U3F?J=B([COQ77B<KUT/K&?W'%CS<R/:3^2*3^3WH=HEQ5#,0'K
M(;):#GG63D/Q:7[?'-[_&Q2(S_`C)@I`_&-?J7\%A#1AYJ$N2C/[^[THB!%*
MD;CL&FX(#<423D(UR6LKZH&$R#$Q!YH+P\R^&)NW.9'Q:HJSZ#EUZ'`V8R8Q
M6!8__`%*/U%3EIZX7@\EG<O)/I*,UO&XGP41*?GK6S9&5(&%+C9?"005(QX7
M)+T-8I&C3=_M'`J?Y#9?(0D<)-JY[OL%*27<;C<\ZQCNM1<6;D/L"^:P8NJV
MOB)031TIE86!B<B@/'@1W7".T#XJ3EL:3A82)+:A43RR17@9R8,3V2P4^)UV
M5`N\A-1#`0[-X_Z90(9R/%NE'$A*^/G''X7O63^+^=`LJ.H%0OVPR^52>;H9
MC\=CC-?5MDVM@$XI]6*\TP%(,/7KUR_\K_]5U.^/FO)F4%:Q*%`OKCG9BV@;
M(?@`U_7ZHA-DE47<%]\H^*([GS62)VN-B>J6\<[8N%@LPG3$"LW<%,<7VY/M
MESK?8\`4HD6XE(Q(,&<UWL;-5WC8JW$@Q#A8#F+HE)&4)I_B1F5H_LJYCOD5
M@"8K<N-K[74$/5$OV1`C!<=+*WMNS5,#1Q4I;`:!=RM_/!XE'$)?L.^[I=#4
M^_3CYT^("'Z]OR$?!>7,6<?RSE,(0R]S-23O14'HC[K&O:R_-0VOQ2S3L_+R
M<L7+RTM!V.L$:M^V897V?`[\7@8'>@G!\'2,IHO3I"$RC^_/*Y&KV=N7J5GA
M_?JF-/Q'4-YSA'>81`\^DKW1&ODSB$Y`F)Z1%,BJB?.G.<L=9#G"UF.=`]@5
MQPPZR82F1.-LJ>DXS:.S)^UD:S5D3/1-T5#^L^VE("L(4TN0F57T7'2T[PZ=
M)421\UQDFI=V#NJQ&RB1EG6Z\,/$S`A\A$(T=$Z)BZQV^F8A@F1H)8)M2R5C
MO0J/CN,HOHV&Q<_EY(BB[2-.-K:O"."1#VL3Y%HH$:N`SX1.3D*+D^<2/7#`
MDS[$T1F&50\C0&WTN.\%@2B>DC4[_O'`]7K%\WF$G.71$"@VV?HS6C9@&VW:
M.:]5-)721G&NP)8V;/N&)()'=3)H!=:^;4A;X;0VBR]`\'C>N]]NB<Q]HAS^
MN#:I&K-G'7'`!:`7!UH)-`W?7NV(D5+"E4"/W,5J*0U4LZ5.M7\_GD^\O;UA
MW_;NEWO4$>:Z72[W^S@.0-'Y?ZT@R(P@UF/,QP%<+E.812;^I"KP>-QQN>R+
MQE0ALF'?TBBPR')M#AL8*!ZCU.R8((R4,66'!\S.[DZIP4$TU:@<74^Y"8OD
MD_W&_K-S!O%,!9E]JGTCJUA;L''H0P\S:-_#4<O`9$$GE&8&L1.!Y3&Y-=`C
MYW,#/M8`_WY'[A'F^1-9;."!]F39,+'+AIHB3$3P_O:&XSCP7__U7XLR0/#C
MQT^\O+[B=K_C?K_A^<CU':)"M/US`YZ$PC\":S\16:*K(?):/^>R7R!)<'\\
M<+E<<'FY4!!01\V@JGA[O^%VOPW@HT7012F/9D-M#7>&D&!S+JAT"G0I`[B9
MMM4U)N)%W^6?OPO>?Q>*J[^)\$Y(9?PR^,[NJU4UCZDX6=2&"!!GT;6QDZT2
M8C]1$>U)2<:`E!?F>B!E\].0^L#%7T>S:#%C2Z4N8O!^ODFP;_M`;7@3PQ!H
MB.0I*,+7=NK`88T@<+9$8^&3V,W0GZP?\<-Q_?C'4TH51?`QMR-,(&WE_^0A
M9?P[B1C*OZ>T=>6M#5^H]SME)%21CI'7RK11*W3\G%@*B#$\QW`2@$.6)GZ(
M+"8(8@M=K3#(92N%YJV-SNOH+:MBVW>D[8&C%<(8&_6(^JTB&21LVXZ<:M-P
MD/$]WS]-V-+>T3Z!%''6MA6Q5?TN*)"VA&MU-^BH9<Z%!ZM5XM5<#;#C.+*A
MTS1$/JGT`DUU1,1V-*[15*I7:[=V:LX,WLJ-GC##X:OHJ*KB[>VM^&2FA-0F
M`-38]A&N\<CGT0``(`!)1$%4XQG=;K?"$SXRV8[USLVDVRDU)[YA9C.1PA,L
M'.14J1Q\/FU$#`B>S\<<UN$B<W-NJ+M6I%LJ\$\EK4/&@-+8L,AL\N+]P,.7
M_\Q'S)KB("AB@\1J\S,]<K@U0-0X^T(PY]RM[G@M\@(_1F!]@]R\GK-RP64+
MV#2ME7E,WSB0H0DQ^3EE)PBUOM\R^0C/>AASGQS:J^Y\YW"+<3X]T2Z/HE;[
MEJ;>'=X(ZC)*JMC]?JLN!U?L^VY\;),(-DFX[#NV)-C^N."O/__$^^U]3!%$
MD:3(:Z')%N1BLM:1%EW2TN%"B!LLP(_7UVX#R%.+5H2GE/#^_H[;[3;`&3?.
M%(H!][H_H3F>%X)Z"IRW<>0DMBY&%)OP*6[DK)J_"]XO8+BNMM%_WT?K9PMC
MG1?$DQ"T_A(G&G>W,6#0'=O-SUE\&"!S%+TY'WVA:0A`R<7.)<R*3J[P:TH1
MI80B.OGZ[(79-M;C,(*%Y%#;K,XDIOGR`55@8P5?`L&6"MKV>#Y[S.$YW8!5
MR!$5PY"-K(N'*F:<P2G$3WH8<?P2:5ZKY>SK6+ARPM*&?2^A`IJ?@5W:K-0_
M.L^-;(S(,'^HL\=4H*&"P[9,.UU&1'#9=]P?C]A@/0\RGR[LR6+7Y-DL7BIG
M%*B&Z6UDC_K<9<7KRRM^';^*?RRLSV/GG4GY]^OU"D5!BHO0"G6$'H5A)&RI
M\-M4%>_OE4Y!\;[%2W9,)QZ/)W)^XCBT%V![%=N5PE5*@$,5_:@6_]K"NYV3
MU3(U+`T];-9F_9'L\:68T"];8*JE?X#$7)7JP.ER-KYZ/%.-4F+@%D9*^P4L
MEF7/QQ./3YCR/YZ/6:TN',6;ZK7*4#S#2=P(%\!(<4L<K""4)E9LV7KDJQ-[
M^:C9G/,T!8M<#?A_1X2O.\[NA,(\?V)+^<:`2@E,%F_V.TTAV(O-U$5@_N=\
M`>G1:!$+BHQSF-T!E(O=^J[F2NYMT\9QO2U2K2U6>^&!W%T6.E5+IQ303KSI
M7&9+PSASRVC6E-R7G^D[VN\]GP?^_->?]=G[HQ2\8*%N12&W':A_]_+Z@K1)
MC\DN7/9G];).T`P<QP-IVW"MVH7&YY>`*M=0]K;OB93&\.7E!:\O+P4LR,6#
M>=]WO+Q<Z9J69^-QOT-2P@;TIM[[,T_T-QT!3*-HI;"50/C.S^N(LK9T2%AR
MH@'RE!I^U"GO=\'[I:I4?K>6_>3/Z;+(-H5C4("%WQDD`1ED@<0CP)K3:\9`
M"\J"9L6A1[<;*G2%PW7[=;'<HHV#A1@937=I(ULQCSL7)2<7)#D?.+B8I0ZP
MI72)`VD]W&+RUYGVT0M$P/.O^T+6XHI)0.>%?09%$HG'36:$WS.`C$U1/I[(
M[[DLE-42JOBEQ@W1<1Q=[0X%#B=+;`V,"HV\:$-B5P7%G)ZT[3OP>)A1]50L
M9)MF9$0/;,/$A8@;D^U[*18;E6,ZS^>!R_6*E^L+WM[?1]QH\YY-`TG<][W_
M>1&=Z!!YP0I\&KJKJGA_>\?S./JYMOC?$H"1ZJ;WK`X'Y1A[45PC67=ZG[1:
M)K5&4;4Z+!"EQR`KL/Q5S?/]&-&^9"-*8J=\(IH:STR&`W,=7;!DSHD.3^8^
M.7"CZ+81/^X/O-_>\3RR=?H`T=1I(Y64@$H7X>N0->/Y>"`?J=`D<O6+I>F5
MS*_J$-+Z*35&G"[3>QKWD7VKE0(1,BS/.BHXV6LU9UT42H'#@-L(M*+E_O/Y
MWOD]H%G1=8"C\F5;2$@FCC<WQX"U9HMB?KW@3:S_H14;6D6S1:3!Z"\Z'[C;
M,U:PI$SJ1MIA,M'JV;ZG)&I2>AB.0^LDWO*XA]6<&9"7QE+=?N&8$:80)J17
MI!2*MUMQ<;A>KQ6\45?X`:^U$&WO\W'D\AQ*XQLG_.N__QMI2_CYCS_P?#SP
M_G[#XWZW5"<ZS'W;\8\__BC-=<ZXW>_8JJ-*`PU2JD+8^FZ,Z&#!Y7K%_7ZG
M=:PV."G1HC"NLQ]?3^M*G<R85+8/..[=@,C%Q_=&KTZU6+3VS>%=H*(?%Z?Z
M&U7MHF#^5/#$O#B8144_=6+&`DKMT&$*@%B:DDT*"5X<I',+&=F84EP`$AKI
MY''-Z(7Z8M>L/?:`A9')5C3@.1*G@CC>Y_-I$*OIG*E`G>Y_'>T-]-R:GPD+
M@42#^^=XI#3.L;9B8HH[A6\Z>.4M/-KG\\#U6F-9*QH\_%@'NI&=\$@G%02C
MV7F^7\0/Y2)"JUK[>#YCOU8ZAK8!>M$/?S>/:COGG0YDWW=(+019J-.*\\?Q
MP`47[)<=Z3Z0IXZFJAU]'<<3M]L[GL\G;6):`QK$>(VV(C#G8UCM.73R\7Q`
M,5!/OA:YW;LDW>NR^XRV8ZS7:=]W"HL(;-:\>P`L_:<45D>0N@4;0QP@?!Z9
M-.EH*I/7:U1P"5%B^._>*L<Q3W9TQ%&LG.-F#2B4BM<:@?P\\,@E5"%K[DE?
M792(.'`"V4J-.O5"<R]L4WL.^P:>!T^SZA'4O4-3>("G3!+%B*=N7$AF,U%0
M]V=V?!X5S;;!3',1+8G07O31O2W2QZK5:!`PX(+CDK?[08VEI3'IQ!<;]Q1&
MC)1(4[+Q<[31J+MZP[>B2R@M\&CN$8'S8KL'&U$K[$@]FX)50-\'2[,8:[L+
MG^^6:6/EN[V_X_%^@XC@CS_^P(^?/SKX-)[N\0XE2<!6ID!9=]PKC6"#X/7E
M!<_'$^]O;]A2PC__^`/OVX;[X]X;FY<:]G*_W[#7:5-Y3C/^^/$#O]Y^X?%X
M%">6VOGGNE9=+E=`RG?_>GO#^^U]T)0,MJ;6-HSV:6$ZG*-QIIJV)D*>RR)N
MHCFH#+Y8,'^.:"T:W_]=\/X/4Q$([UL6O5^-'?X(9_:_T<4KE"8SE6]J1S:J
M=AQOC+"9H"J6O=3,XH<+P(DMP3I-=A1C.#>R4"`PS%9H!C1EZK;%;"DZH1WG
M%U,(<>+1<5&BETTD-R%0]PUL+[+@:&A$A0'&N-<5V6[L9Q#X*E+:MJWDL;L"
MDN]\H9I<NLBD>1,SXI`K:I!=NE`KWDT(>4!NT56W5<_AR!G'_3[S?2D@8]_W
M&E&KCH-G;RHW#U/3(=*I`#[]J_W^\_'`&WYAVW<2.:HY5]'F^?J`R*.C;@-]
M<[R^FG+7/L^$7SB.9D.9_;%;:RN8PL,VD^4XMKJAWUP#P<?E'38LJI*[,X.Y
MYN3%R?>7N8VCT,DC`$$M6FOH+W0?<_?*G)L?#G;P#;'Q]@5*,A4H^:N-XS-Q
MF&OD,<")>#K9(\XN%VF,7KNU7G*W<Z3/=1V`!$E?(Y&$7`G4Z@,6L<P`B!LK
MTY]K]9KNYQQR,ZE@JX)CYJ9&16KN"79I%CR90IW=2Y@*$$VG#+<C7%]+;>)L
M!MDY)2"/]7=!?&J>&LXHH-AX@B96`]"*V-;TLFX$CC^JF`6"@H$2,P?9+A&%
M#H!DWYG6&+V]O>%RV:NG[0,OUQ=L^^8T$.-=VJ04L)#:!&\_RW3O61K&E^L%
M6P)^:D&&\W'@^O)2A;170!7[5JZY5%>;/WZ\EL].J3NQ0`$],IYZ+SJ('S]P
MN[U77B_%+D>332[6&Z"@S6/7.@H)>2(/L@D)TM2%:1)HXYM&<<TTYS]]^_`N
M^#9?\L75KV"Z\@5TE[_#?M%'1^>_MXN)/OAM(^@(PC#4;:9&K>HX7H!+Z`KL
MQ$Q!*4:33U]H4\<LD&@-N>%>@&Z=(PE2>5!:41BV1EK:9M%Q:]#`E`+K@,AA
MQO%,L&^3Y\$[ELI]SO#"#E\$27!`^]Z$9@^#NK@Y;$VD&I8]F;A-)O)4JI5.
MWR@PAX:(8-\VW.N83)QY_F<F'-F%+;3"?]]VW(Z#1J@:!I;PHF9N2"UR$A7P
MF"*)I=,`<E;K0:+QA6[QJ1-2B3%":VA8&^%#,B&#P])HMI>2J<%A"[)2F.0A
M2*-SR;78V6JPAGFUVN]3F`1[_BI'#KL2L!6JN8L?'<*'H3COJ&808<KHH)@U
MH-`;)LX^;#B,B'VF&D*?<\*V5<&>X0139+8A-A,?E$5J/JR!AT^,1KIW9#7?
M4^;!)C'',RRWJ0@+P@JX&5?BJ,G"NSK>?Z07H^6Y4<.K]&M<Y!`1[7\F66Z!
MVGO>*W<(_;X8YY-YK6L3QE(<.=H+;4Q"[D*9W"-:S*S2YS+JO5JBQG2/Z#*T
MF:AYCT+#S*%KD&&-*01;"\68L]UB<X-Y'@?^]__YWR7@92M3GM?7UWY\E\NE
MH[&H:\^V#?J`;O68Z,\`X'*]&%XKH+ANU_8`]!.Y/^X]VCKGH]@.*G"]7`M0
M4),17U]>2F&J,)KBUBRH@_<B"N%,VBS_3<)":,?_%?^^S*:MDY6E<$K?:,:^
M"]XO4QH4T83^O!YF1VKY$ALBXM']5J'NO/Q6U`7UPW:)K\TPL]?`$4R[T$`C
M)@)%W#9NJU([9K9D5\\Q]8OM:SJBI(YI)>@$_X8"=B36%WG!_5#A_`,Q8YO&
M@;4)9TJ)6G".#XT!.O-8/3UD0DSK9Z64X`9#=N^@L5$^<OCL;-M>#/P?#SR?
MAX',&^^TJ7#W?<>^7PKO[/&P%DZ\F%7:AD`<,FD1*Z8:%#]'RS7E^D)-:E!#
MWO)T;2[[WC?!;=OK]XP4L8%^+D2:Y(M;_#W'G^=:V(W)2"F&LS;E>447,T8A
M9HPZN+@%4MH(L1GCY,AJ:0KQH@V^/0<=U:K4&F^_U9J^'HV<&VTAAU0;\\J+
MC?8\+;X`2W$PY4&Y;L=1Z$[J./&CB$G(0A0F3IV"5N_@4C2FYO0@`DE<2#4Q
M7=U$D[B`D5@PUKB*)G6-%@7&';@([N]6&OZK$"ITG:\I`_<=_1([1>$E[]RZ
MC.@7[#(SK3%Q#+!'C5F@-4\/!L)O.<*#P^X;]S95:EH1'P@!I\$0?TV;_9;`
M4&W8&[NY!O!Z9`KJ:!_U`1P(@B;9E45P0O6">9^!><UBYP@?5-%^ZLB*C`P<
MP..1\7P>A5.[[\A;ZL5;KO'CC<;CQ:)->+WM6Z%SY`+&;)UB<N!^?Q1-2R[W
M]%'=3*Z-]G"[E\DE@/?JM++MVV@\G+XLBR]A1QU@DBYA(^_%-'5M^C10]=C[
M7`)&=018C-<J$07KN^#]/1;#9T'>F82B#L[4]02H%RYG4;0."5BCRS@M=N&^
MEZD.I?N>!X-J9E*6HZ6+751UIB3,/5_9?)X=FCQI#OP&SV.,>CV>QX$-PW-V
MVS=LNB%W=X)C*,.!$\]8KH"I".&)'8V@.::6(6-=\;F]9RTAU5;<D@DYF[F8
M8Q$]W-]ICW,MJ3E7['LV0J4R)LW=^[5<,Y!7\&S$SA9!0L;KJXV5"^_BF*"C
M,`N;.-Z$70%9SZ?][O7EBOU2W"F.X\#C_ABQQSK069'<4;&.+O;(SN0F%OQ2
M"8DJ"$%LSX;J1!DJ8^(-U^L5E^NEB()R[K9=X]S8]!Z&>L,-5AMI-VLO%<N#
M;)'!8O`J.X%AQPD-XK`;8FFXNAC&^FU,+G+,Q7D0*]X1ZIP--WG0!JK/:T6"
MQ7N=LFA*!"^OKWC^^6>_!N*-:2=!T;`]F-;*9D]'U`9=A:\WV[+FJ"!I"&V,
M#H(#%328/)&`D*Z)+SIEB@RF.&F=&QO^7CD)NI!%JF([!M_(L`O/_)T(!7-,
M>XC2YR?_7<0-U5S0@QI@G7C2$^)LPDE@]!Y\'@VI;4+)W$;DB28"C<HR44)&
M,R[]&1E4[X/D&%FMS#E0CN#^>`(H5+@__WK#MFUX_?&*9W5H>#Z>-6I[H_0U
MQ9]__M5%8#]__,#S<>`XGCW>^^WM'6_O[V:?:J_'^_W>J=;Y<<?]^2CQ-Q5-
M/W+9*[+;"D4Q)9KQ/$2SCF2^%O0$%#]NS45SD@L=0\4,*HV,A74M0P,R[V]:
M@3B%#<+1;TK#_ZTR&<NT'V^^Q.KUCQ!>H4C&3Q["LCB>J0X?_)1^S$0>>Y$&
M<9MT-%),^0797"=Q-`/P9C_OBZ,@5N"9GYU/"VF)4X*T[T@YX3B>.#P1WQ71
MGA/DK6*MALZC7%@;+2^NH>>M`L#S\9@W,2>+UE[XZ(2Q,U52<\:]^IY.`C:_
MJ-=QM=^@VMBMC\/]X43I=1V9$SP?>6R<.E`T?MZ"P*#JERO%7S=M%4$\.H>Z
MU.QB%+IS8I)TRR*#XB=Q,<K$Y2-.^V1-YT5Y,BRB7JY77*O:NL0>WXK;03/Q
M;Y<@MXV5$LPT=R2XN5"DZB'=&X6M?,\SDV^F8!HQ]_&MMXOJ80+4>.4Y2%JD
MB&3>W]_732VL-V9#`H6F,6,4.KBJN9XG%U]<M*`A6B*X7BYXW[8R=:!CRV2Q
M91!.H%L:2C`5:\>B2LVD+J9_;;+DT,-6X"7Z.S4(HH:HO2_6?(,X4'H/B=!D
MAJZ;+U1Y?,_7MCWW/`D)$>`6>K+0.H24!LPBO2&&S`:]]FEOOKCU4=SMZ>(X
MXI!&%?@;LUC:^M*N0RU8O+F:IHH)<JH-T6":4L1R6^K$4(2\99L`N#\>?7T6
M`6[W>__\XSCP\GSB>BV<W-O]AI\_?T*K__7U<L%]VW&[W7`<!YY'QO5ZP>-Y
MD$/''$S1',79Q6,5"2^KZ;A'?$6-\)J;8:W"[WW?<2,+L?[;">1G/^8]1LAM
M&)#$):]_F>F-^2YXOTH-^`1*>EY:?J5,5H-P?O:;OHI"R]?J]-`G=_ZL.6:0
M6]J!B`:<GHJB>6-YSR51&8I>"2QBE%#5HN#O@8A]`]CVK19,.W*^FX+0G*L&
M'4(DTD"R'$AVC7"E_J<>,_+);!9G=G2I-CW/=@1NDRC_>QP'4K4K:P6T\0FF
M'\_(!@UAVMT0-%543JW8"8'%53OXSITSP0%N<@#O>>Q0)`$N>['1>7]_P_WQ
MK"X)[?FS&TH^M+MJC'`!/X6Q#4M'K!6&2]O'D3HLR++._+[R'"=<KU?DX\#[
M^SL>CZ=%0(@?G#N&BJ$8QP@(.(["L6OCQU+\2MVL=*#T@<B4?9.Y>6G/EHF-
M)5_9AJR+*+`!KZ^O>!X'CJH45_>R-%PY;6FBH?3Q+XG;VCWJOMH:K,4D\-HZ
MG2/BI0X#II2$.-M8Q@KK--61*8@&+&QS11E[A'J>=#O?G'T1R][/L848_W-#
MBDO1ZN@!:M=A[Z`0H:;#4G#02S)9@7%CV@)<HL\ZXP"O?'(C'V)?2%DZTVQ#
MU>X+'[,7Y'6;N,[3=05K;:),'/HT*1AK;T??R6+#4@Z5T-[VK-5@F1$-V8_A
M<KU6/89MYMN:FK:$X_E$UHR4MAIHDWM!W7S"BX/"CLM^P?:/#?(K59K7L%@L
MT[X+]GV#R*OY'K\.-7N_OG[52=^1CSG-54A_H+!BM"!B6TU&805QGL_A\]TX
MM[SNTA[,]NP:`%R1&),?H.^"%^N.^S.5[N<H#1/\=^IY*YB1PB]]E]]T4^TF
M%?BLZ5H4H>F/(KI6RU-S6J-58(:`QA?.9DD]S#?=#C$Q<F7LHD2=(&$(BHN`
M/H'+)9D1K3KUM.$M@=B@?G&MU[IYK@X1T1"0@>)IO8']=$U]EO'B/9Z)<!H&
M8[1_;U9L9;&4;E=GKAP5UTQ@]!0`9NOTS</'>!J4J4;P5@_(3.IV+A.5+++\
MD]*XVZ5AV7%_W'%_/*I?;C:K<9^.M.>@HJ--Z':PGVBR7L=C$[!D;).)H?'K
M[='3G#/>WMZLB\1(07#6.U+X?*#L>`R$J44EI[0!\JPCS'(=!()##RK6[?/U
MX\</_/KU:T)2V#^UB]0<Q:GQ;`T:I9CN&]JHO\4?$T^V;WF^:9(Q0FZ%/C=?
MTL;)`NR72W$`J5'1?#WY=P\*)R@^LX/WP6BEF`:=T+V&1JH5/_DTL>/(`0V@
M/>L:3_($U@8P*!XY".$XLD$9SV@*C)SZPCE3L^GM`IE?Z;\C<X(<K-]SA"A[
MI-JBPY83/*U_(D9HZ#>*/@U0<<#&(E*X4UE2OY]#*Z?F.3;7R?-^=1XC>J>:
MX6^M9C(X)8&FA)\_?W9[L#:Q::)4D_KF20_T'#>>[E8]U_,SXWJ]]G_?]QW;
M<^N-T.5RP?622IC%D;'M>P>>\E&G&Z)X/C.V.A'=ZB3EK[=?W:8MTL";<Y1X
MCY(Y$[LX%C&*@"'^Y@`5X5/OUH]V\GH*`G[;DOT=*/@WJL]/FN=J#&A^4*1Z
MGN_0+8H4X_N,;-P)HF+(J^YE=?AG;@]MM,/*3?D<.JX!VF9^UD80K8M\4LC9
M:Z.G8QB/EDR+&XB[U%/ET-&?WK$#%FU#XT"B(PY^D]/UV2Q0&H<$TV:?)++$
M&^?U:-0(C@<-KKOW3VT+,#MIJ!1%;Q.0W)WI.9_KY7*%HBSJS1R]\4TA,VT!
ML/9'_#BEK0@S[C5*>"BA!\1O%-Y<HQH'ATSCXGDD;F-&LWM?(M&F':FU>-[C
M>=A1/25K^;=9S'?9L>KC\<!Q'#U)[W*]X'J]XOY_[L89)1M$JQ1@U^L%M]O6
M@RM4&<V&;7P<_7R>ZD@5T*AS"ZA%NE`*7)(1NJ(YI#6)?^$G/FRJL<];'=,>
MB[5$T+5J3H35T>2&^M$[T!H=[SW,GN`#8<R=%J5A<:G+^-9^_6K#QU0#;E0B
M<5U$$XK^F<5XS,WU81@^)`)!D=R<&DQ81BW.SB@%9TCP<)304V%VYS6[.\SA
M$@+F58L1V3'5C\D%2>P[+C1F'Y^AAIZCWE5'9@333BKMG_!WB6;<WV_]\[8J
M3'OF`]N6L"%5/Z[4W^5\'*71UZ%'D5HP[GL1(O]Z?T<^GMBD@`%0Q?-X]@3"
M3F-H03>72Q=UY3ST'#EG/%L:Z;:5],H\WO/DP!]N%;L]V`D2-E(\QW364$BB
MZ2HYG7C'AP['T3O/3GC-A>:[X/T==!?X0AQP4"UV?]//VY^=H;/5WNZTE)0D
MD&PSJ4.JA<LR,)(7^>"813Y]/CHM@C-G0.9P1-/V?^1HO&T[5'/9&+U?*#C6
MD'Q)>8$^+?C1PSRZ6E6/KACF39:+HL,<N./TG8@.F5=F`SLDG`2<-65*!4M3
M5TC0X10TSQ:>[)4Y1MA%;;ZEK88#:!B*(``NEWTDH@4(=Z,P^.=T3AX6[/N&
MY_'HV>ZVR[=M#H/E+2:SO!<@3FO]/2$O2%%X8Z-Q;$V4"#NVAXWZ[4$1JS92
MO.C/%SYSXW"[W?'SYX]*R:FI8@TUDU33F+P@J7KYUHCC6+5*OJ_*UGZS<EK!
M:#[%/%.S(8G0W!;G2]9M6TM(DC2\<_U:IX./G*KCROO;V^Q*48\O;:EOZ`7U
MQ]B2&?4UR["6OVL)7JI0/>Q&3/]_%,SS-&44I+D+UL3QF-KZD@QEH3QWAUH_
M7$\)B-!4OA8I)1M:4C];R7*N/:,<7,$%IF^R8M]B&<X7@"TL:W$=-;VV2)1Y
M>N.*9,\1[MZYW9G&N@))GR;-WL-<U+=)G/*8YLR!!#&-[=R]I)VW\[Y7X'Y_
M*R)<`>2!;D%T3(WOJ;(=0.'W_GI[Z^?Q!"`5U.BV:)B?&8Y]]W3%]K/WZJ4.
MT^#H'$CE]"TJ/+5=7R,-:3P:E`0R[6$C2&EH-;R-:4NQ^RYX@X[TO.C5+P&]
M2^=<5?^X?)(7\.4*OJ`/-0DH24).>2IJK=-"Y,1`XQ^S4<\OGWQ`^6`:?R(U
MM"X7&9W5UO05"5'1USB'0-J*@G\X%@RCJ$V*Z*G0&XYP1.B+4']\2BES7FQA
M"A6VJM&`CJ%!N`@[>DS(ND<;"9&0SSP:.A;OFA(U6U+8,\]>/"EV]&K'H4$D
MJI;Q[[;O.*IX8J9T1,>@$P=&JH?O^_N[60"CSY,4]4VEN$DH%F,Z>?X.Y;[U
M>Q;SG#$)B%%D+T"":.7<5N8'BLF[UM([UU%K]R,^N7<%Y;U#\:,D(P%X?W\G
M%,Y?@UI('<^J\MY,$<0T$>\,`6>1-D?@SDUP2*9QG-V.D#%'O89X3*/V*O))
M=;RJJMTNR:PK23I5143&F+05[Z(32XC_94N;0<9'H:\CZI;0<X[@]2/MTN2@
M4SKXQ?1B)2M,D_5HWA5Q/(7*OEG6>4(A;OU,Y`R!]BR81#%[8I\I1G%"=?`H
M]?B[.=UO%8DLXCF]U%PNDN;XO<$B=KGY'[?G/XFE5:4D5ES*7NGN\[A18?Y\
M7S_R>*;'GBNAIF6Z#3+N;T(008^8)]W7,*8(J6O^N#A=7$/F03--48Q7O2P;
M!BN(GB/.EX50($9/1+V*/>3KJR_#(_^[X/TDPJN+2E=__]O.T>"_?3+CCF<`
MJ6XJ35'?D2/F".DY?\+2'89RV-`<8:,5=85(=]*\G9WV46_"0$^AOD;T@WH$
M_@!X/@_LE[))ID3V0?4[4QU7'L^CVSU-2-<G+G/P+KK\2IA1S8"\!&'<G(71
M%JX6>O[]1+L88^HQ\E>K/NN+(-,:AEW3_%P8KF--$4MIH^LHH4/#XU'H![?;
M>_A<P&'P)G6LWNDDJ8]9GQ7=75F?">6J^V:.'RHCUJL-T[@U8F9K(XU)IJ`,
M!?-;U?%=CU*45;_?;=L+*@[%_59C0-U4?V7\?^2,^_V.U]=7',\G;K>;C5L.
MBZ9R_:_7%]KDK1E^W[2-T\"XED<^<&O'>D)M&C9DM=CI]G;%!]M'!Q=SHBJH
MR^R;2WM>*MSOD5*(J3CK:6OU_=W2AF>VO&FFYQBDKQ4&C8O.!5<3*:7A`VM"
M-6P*.(K-&FP(0?<'G1'"YJCBN:3^/AJG@``][=,%CX@ZA(TMGO)"BZ$N]$?4
M-B1PSR=3"<:U=E.UL$"VCA.^.#+/<+;1WIU68HT7EBAXU'3P`:H#?08OFB<"
M3BRIMIAD;O+P\<:L/U&+;IJEI"8_3C[Y.GC^#$AGT!1#2KQ\>\>%=N,^90DT
M,'TO-M:+<%/8-1@N?7T61(8-9B]2MZL%FA-V"#+KHJ%!3/DK='QB$F+_(RX-
MOR>T^O\7POL[QZ\G?["PX/U;UVD6!2R2=:B7:R@65[**,][$#.EJ!`;*>BLL
M&]IA,]9A>6M'+@;<G9<I)P0&U4E$PMWHX_[`ME61$H_9N@=O1H[0W3/:RB*=
M*X@:<<(;BUHN>=#&K-('$5B7!@FV#,L^L62'$:N)*9;4<WAU\FE5GQ+?/^/Q
M>.#1U+8:68!52@=3&3PRHVHK')#B*:7:```@`$E$053?*6#2=)['@>?;6Q>^
M,5_6%P0"IXIOFTUS0%"8[TM<'.N,7'C>YS!3D.Y)"1I7JW.;5Q0;GH96/A_/
M8@2/&A!&FR+[]/K_/.YWO+R\X/W]5@2([2NR3CDWK9A[/)[8]TOGP4[HBW`\
M,:9K+Q#\ZU__&I06]M162DOS'K%)<-TO2*F<\^U^AVK&MJ5B!P@;(ZZ=;B(&
M84^5^SWQWK45F95O6HO>G`\SAFZHK'<X`(7?*&LBLBT*-5B\A;QY.0:[H^):
M2Q):+&T:7=#8,>^6A'=][5J(7:/TR,DFC8`&4P@&A2:/CG6!V$E07/OS\(AV
M]$PS/261VP9\42A6ZV&++_:QCOUY)_]AKS%Q3C3LNN.+1:VA&D-#@9D#/D:D
M9F_A25!OR,/C*'MU5C4>TTJ&)ZT:'R)@9VT*2UGPT;N6I$#WK+LAJ9EB3I,2
M1NG%`PB<AV;ID4K`TI(0L@@46('"@S'ED.[_1,'[_TJQN]I4].3$%%\(GB"W
M@`_5A+-5PU+@)=&Q$KS/B399'2H[C<D_Z%(T(CO(%#&K4[47(7G>G'^@(=."
MJ!/K8BJB?8(-_^WS."!5Y0RA$;Q#/E?/@L"*GPQ*[3!/73T['5FU?:E&Z*X&
ME39!".K18\>IA;:-6H/K$6^0'J;7;F,U/R6F-Q=*V,K:(Y,CI`IFJC`-"Z:G
M.4(11J'%-`N=:"%L`V42U7C#Z`X(]AU3CID%7-*:17),<6T]M;KMFA7=E**X
M">T\3[<U>",131>BF-H\/)]X?W^W!4>BN%-85/[(!V[W6P^N4)?R-EWMJ0@[
M9KJ.>W3)M:F/BG/./:*44;?B6E&^JZ'!?IWH?K[U[]YO0^QCPFX4R)5#GS!S
M>U2U.U@,9([2$3D]C!K.<5P:PDFM2>I!$N&ZU^@#MNA=^:9[X55#)=.6G+5A
M3"D`G$B3KD=H!T8WS8=?<!/%GYVSFO&X?]]-L9$S5$:$[(J"8'QR@;!P'L<^
M6B%UFZ4X%'B]UUK;R(@7W>[K2@_A7X`>#!.LN9TJU=:(4MV/Z&L_Y!42X0JF
MIJ;O:;1)MM3`:`_BZ&5)$CKI1+\_PAR(#XP9XN5GS5<+XJZ1!VKRHK85HI>(
MJZ62`Y',-1)JP*O3T#>EX7<0ZD]8DH7^L_@DYW>"ZV+1FJRA:M.SJ5L05-=%
M&1_@)-(R_RPQ*FRE\*N!YW06;`7F%^BR*'W@Y1992YA`@_J294ROH4<()I1#
MX5O5Z><MU]CRB<3%54(B+B1]O$A<S#I$BJBCEF/CF!(KK6$;4]I(9U^$>ZF5
MQ`]YF(8T-V9VM"R!G9"$HS/KAJ"3,M[_IUE".0^"L.#WNDDO-+04DL7+2(@)
M_^Y`K\=SKCB,#RV$IC`$EV2=IT\<O9E2*EQ6S3;B.:1WC'?A<7]@_[$CB>#)
M[]ET3<F.;&EU%R\]/O*T)53U&-@E52>(5JB%P;:E[E"A'#_L/\LCZ\XGN#C6
M:!_;>C&3%Z!Q(<LT"#:ZAVL06>5OQ^L2-F6^P.V(;AWA]R91'8TCXLXJ>C%C
MD\]RGRI,;A6!6`V(PP1\H,-TG3'3"B3-P1A]/33O;>KB/8^4MI`8=HUH"T3B
MZ^#&VM$$UQ=Z'<WLQTLBX0@/(CI%?TZ"\YS3V!K`(Z;#[N]TVR]\7#U0H\Q)
M#"8>;F&?:)AFHU]#XL7;#<(6_%`;!#(FBG,B9K]W[1C<7C`%*'E*3P?`B6)E
M*`DZ[J^@JAXB,$R6-4;[F^^"]W<0:ODJPFNKCH\*97ZH/R-@TQ7\[,;8I[^G
MGX/D(Q\!<\P:H,:&W[LNV:,AO_)H1[YZXV2JH72Z/NI&3'X$#1;L!USB0-1&
M&C6%#<B8:O-5_">/R=SW#76THUY(W(1\:`8BF".:U7MT:%=$6_L8']$YCR%E
M51LZ/L9(]$/8E!E5OE,&BMO\E2@XPN*>B+L75.<E3$,MKRY$\2E>E;*55O4P
M/XBFR.^;$)PUV.QK"A0G@I>75[R]OV'56O9(6]/L%@[T_7XWM(9Y_"S+0LVC
M2[XYL0=A&R;VJDB2G"V4V`D5H7<E);$<-XOMU,>9Z]AX0<5A"T?1:JK?8WI;
M(4^\76X^-$`BU=T?6^@VDP<]><?%A"CX9U)H.C"*[F2BD9G6T*9W#3UM`23<
M.8C8`C)JHNRS,SM%J.K'B`N)HN:FRPFB&B<8,U=]+ABU<V,-?8^:@8:T#WK(
M:!I3T!@D&6EMS2?=-XQ^UQIN!<G8_K$%G"RFQRS4`L8DAD$7G?W_C)"L$**L
MN+2O?3E7R+/J=?K]3\91)6$>5HQ`H\']3;`UR\3WX./,@[+1=XB/]FNEGQ?;
ML(O+#>90#`W6?`Z\L"6N=11/WR7M_T!!?')S/ZH[@'/^[]GO2@"U*/1K=FL?
M?*4$_^3=UJ9QE'B$<+R\_-]VV,83\;,G3YN<>,,!4X0[<VR)BT_XD9(@0/VX
M"Q]H;.=783;9#GOC:,1'/[\:R:6Z:4L24_RJKBW;;#2P7<`D6)S]>$(^7,5D
MZ1*A/C;'(.;V]T36^ZI$5?,<N>,:G_)%E=IIT%@1G3TSW<<,T4=V7Y,(L89!
MK_G_4A**'ZU7/@TDB9\-!4*U?O?>%,'U<L6VD6"H=U<(Z3W=][)N*,^C<EO9
M^-\4/MI'^]Z3V(KQXGMFQ$?1O6L;EWKJ3'#<&'&GD[C4X3C,T\\D:!Q<Z/$L
M=JNX5BR`K0J%DL9(2!?P3ID"VW,W`AZK;T9FYP%K+Z:P[B/-)[45_'Z_R%F)
M#ZQF?8L01^LKK-.S%OXG:Y]8#;$=C(*H^X\O@C%BT5[^8/LL1:;2?=!<K.0T
MVTA9;KS;\Y-UMIW,;0*DBU0PIUM14L8IG-B1`BZF-4_%@`3E(@GR,1K<]C4I
MH#)J#671ZL66`1PM"K[6FKDU;0Z[:@T>'Q_;,#:*6<W**/>V7E>FGF74),=^
M/+#/:*H.$I7#FU.E9R1+P?#\<+M.]P/ZL&81BO<65P=(0!?4RJ__1GB#%_)#
M2L,G_FZ2+DTHXR=KVD^D$G\UN'C&[A`>GW[R4^1K(+';W.<\)XM)K<_.A]_,
M$:>SZC:\:/2#&MC_K:X3R!-WA!S`\HB";&*1"-V.&IV9LRN0]3-+ZEH]:55X
MP>"34ET_7>I&]N)PSZQJ31\^Z\GL*`U3T)S:ZVBX8+ZY"S93I8AK3(ENKB=I
MB`NEM0E99W'YI=`)K3+S?->P6/L=-<V#B3E>\$]:O&<)[ZA!$_>[M>:2F+MK
MT6AZ][)BWS8\VD841<<ZPWSS/!IDG@M5Z[(A;K-3+JC8]Y>$6\EY>`+`\_'L
M''$$:[5"D0^%II%R58)?:'(C%)0A-)YN34[6CG8E&=Q*S3.?.4(O\Z*@8SK$
MDE=J!(.6[M#0S3-QFG&#(<LQ#;Q_^7Y'U(+H_(J_KW9[0B6!GD_2:FX[S"D_
M*UQ:3#:/WYEFT?C"P_DAT[JI?0R>:R'<$AW;1"I<$>LQ\K&;N'2*]D:=,G`E
MFA&'9G@OVX%(NMHB\2A7ZK7EN%Z9`25>N(2XU$0]:)Q5Y:;<3_!<DSH%#VDI
MJL7=X&$KZ-!L=<US18VGO=2MVTJ?,];3HG/(:EUD9%RF3OEI]SZ+G5;ZFJ#A
MWM\%;X1`_1O078&S9M;S`E4^B:Y^_)TS:K?B_LK).:V.1T_G69^_:I-G7QC&
M(9#%N%;,9ND^5R)44()O9PA/X?;Q^1K(PFS8C7A&!**2.P-6T.ML`W/6)`0C
M9.:?^6ME\^C=`DTZ/'4KDT:^FXC%"HS.KXK=T.,XOA1AT3O&X!*&54P7-N+X
M>H&5BT?NQ2(+VYH[0?\9F4:S4G9#8PYJ+8;&RKM@OAN[J]4X^.7U%2_7:[5U
MN^%&B7;E][,9)X_B5[K-$>B<CN,H:76K4`.1<.$9Z6/1W]EK-!5S'M'$V.28
M_M"]D*5X);<1?U]76X"$S*N+5N&?J/4(Y>*;$:=!%Z`BOXV'>T$H<Q)TV./,
M@DT3GYRMR&RB%R"V+;,>P)_SJI6P@7$T$!_;7GFH&C3-DV_M27',!?IP#7$T
M)+)1X]&\?Q8UF.#TF&!Z%]N/-%H#IF0T3,]@Q"U6M>*G%/6@W98P3]9KEMNC
M,:V!W4R$/D=<FNEDAT`--W3:[Q)%;/J)H2QJG$.'-_AB>QH%\;0GS/J,88<F
MO?`=#?!,?1)?V`LK!^:$4[_O9&ZP(8;FPK9%WSZ\GT!X?]=E0D]V<OWL[WP1
MQM6(TJ#Z^>,,HD3U$X7W9RBBIY]YXGEKN<"A;']9AGN^K(;9:7'C8]&[^$=C
M,4,S`Q"#/,A)Y\_=MP8+VXH*,:FS/^B(C#B'BCKHF=(Z/M?P23KS;Y:`#^9\
M?<>"IQ[D[DCCTKXFL*`Q'$RM\[7@&T-45!2I<ZYS_UV1YC2=NT*XB4VT\D2%
M4+WN@2D:IL6-$3#9F!FT9M`B[K=B/Y:KM9OGWUK#>]L("*2,%[.:YD^)JVH*
M+^+R38))-S7IOJ`GJX8&[ZY%WN+8['[?=3'FI(*4Q5-&M\JH&;VL_7>\152+
M#&>/8D:.W#F-<`P;'N'?@N[8!SW==_A<6S'N4=_(;WD5[&">#2,$%HKTGHO@
MQGL&^?HV%XR5]9AWC3#%L9O2M.]D*SEO`V:N`U;A,I'P<#0'&WUN^RSC?J%Z
M[ISD?(WY96CA21'/FZWF;`"&&I27&U-IB&6T][#(#?QN!Z)%D0^!M$&Q8G&W
MM[:T(K5Y?UVDY$UF9^.Z)6?!)V*38L5X9-,$,CLZ&J/QG:NO"]I@^7_?!>\'
M"._O4AK"G_P@FO<SG_=57V,)HF?/"E61\VI7/CH.Q7J$A$`[*8B1UP^**%\0
MJ[.XT#,_.9FK>]\L^$9`/M$@&(<$<;9F5/P&@,4",&/O3YVBD?W&%G7=JWLP
M4#H-S=0C>H&8!/5H3"%&(#9]D.ODY^\=3Q=S(\V".B4<:<^(CU#%XI,IDY^C
M&!6QP.BR*(::9VE=8-+ST4:!;KT\[<;OBSAP]&[]+VNFIJE%_8OC*/[5A?^9
MK<^ER.).JVV<>F*46D34IS2MU@;,N??<3)Z-KK/CC(Z-2D[\7#)R0Z;%1M*&
MA0[;N]E![#K%K(N\Q$3R=FXYC/',.-8TT,"L:HYK+@(&Q6.U[ZR$BNSK'-F8
M1;S<,^2WK;U#'#?'ADL5<O'BY@6C9Z(WOS:U!D+)3C"Y;GHJ\ND=:HAQ1".Q
MZ*G8WP7QC(.?->AT%%01@$=<Q&LPM?.(K_40%B/(,H]M\T>7P:E5OD0T`6">
M]G3,&E/R?/(ETWK$-Z'$Q!3V[-6YOA@N"_.>:0I^NB=#P*W+0#6OPQ%'4Q3C
M1B7F?Z,*Y3\2//'_<K%[BEZ>UZX+.S,]'2W\%G+\&1"X>M!]NE26984Z43/T
MDQ5YY"_,&Y)Y^759I9V@ERO_RQDI-F/456'N9+/3..4CZ%M!+@L"S^#R8\#8
M2'^,@?S7C-$8(;2NT+<"I`6=@$?S;HQIQT]B5C)A1*`!!'E1S9^A#!`3DN!M
MG?S29S:AEAMLQJ$)+'8TGTF=B_%V;`5"9'4E\3U72F9(4M%`4:@FUZPP32)J
M::P!<$L$C$;2H\`HXJ7DQK'6UW?VAN,(57\_4ECD#DJ1M>'3H*&>"Y"/IEL#
M&2/J$MEYC5`&_]5,W4FS8P>AZUJYA5P\<LRQ3Q\S?&,))EEB;>QZT^*YCL1)
M]^N2!&XBW,QQ4A<767FQ9LQ3`[$6CT2S:47!\&HFY)&="C(E=269.-B>@M&G
M!0&-9=5H9/*'C]P@?.+='#T\(\K%74,"+G\1VTE#9(')L8)W!S-.I\8JF7<1
M!C3P]S:Y>^4Y]DWTUYL/6NJ,SWL38C=7$VU()KL:B(V%YO>=[#'5Z&58N.S1
MXU@L;#UQX?RK=0:'[*)N*1%FK^`42UJKU5(2^K/@&N\$/C>B5#A?^^^"]P,Z
MPS+LX-/V70%,^&5T^(-2]Q,^9T+CU]\A:CA]D[7W^D"@M/Y*]18.Z],//S,>
M#7XF#MA#NU/>`_,N9;;Y\@4VU^0QEK[V@940E].P:)<6GL#A%:[`D9.B<_*%
M)+FN&?\+IH+0TB+LF-?[KG[T1.>)(PP,AP>UWL<+J+&CV2E-F(,B.[$53*I?
MV602((6NX,4[ZA60C'!FFP<_U,')_(HO:K)1UL_A'7YL'8V+V_G*D:>?#5,4
M`T)[.@D\\`/)KGSOJ*GV"48OKMV3+$%!'3X7WNR>:39M8H#8KL]$DDZ6>F[=
MJFX,L=N)A*EAW;OV9#V)QOC,T9V/984P!Y0<&NU[%-XGFW%QN-RSG.N%_[Q6
M*.H4';Q5VHNXB9J:J-A$!1<7DDP?"&DW?G+#:.6PJ:@>LNUV6ULR+O(2<SBI
M7^8_[WQ7R#)&L]AR>:]E%%$C->3%',$ZED1\;']O.^()L?`HN];PY$/.-_VH
M^<FJQ(>-A'6RVIXF&N)2A"R@0(C8L6PYSCS9[Q4QFCQ^1$;13^AQ/S.N2X@W
M_5WP_F:I><9M_-"?5[]2\GY@0"M?/Z<HP7S:H/C!%8OVN%WJ]#E6S%]HBDNA
M!W3ZW:_Y3ZCJ^8^'<M<9R>GV7A)SER0X437UO[BT('O5?<1E;-]D!4:VK%![
M;=EOLR701&BJK,1FTD57]AIR`;5XWMFPW(G'IN(-,&;_\[T@=$[4+,P194."
MH(1B,9:*<$H]9U.M91@`18))EVM/76KCO*$D9A36"[L,#8`CAH708-7N0RNK
MW'AJ6")?4N:,3L(\@Y07*[1F?]4LE)COAN`97'$1^;S@5.21V[)0(:)4C&3D
M2:0R^DL_`G(C[JRG1>?XE7(?.U>0"F?+P\04TL(-1O>VQ12N9OC52M_+OKQG
MUF1&%!B(OCJ/M5FF!;'#9K1-A;F)M0T<:B+/W0B5Y4*B6+C5%+&T#;H#%5=\
MKR:T.M)>"'JQG,-8XQJYVX)88!/%_(*4ILD5Q7Y#)U$J3[#,L]C>"1F:C!X9
MC%R;$`V:FD:?<HJ,+GJT'K,>(!&QZZZ:^6`@^)1%,R5L`(KA5"'J:`>VD;?3
MK#J]@M="J*$]2E"="G!.4_+3/)XF=6><V8A=#(IN-1`CA(1BE`,__6\?W@\H
M#;_#+Y!/_6),KI:S+]+E1TVQ@W)ZK++\OK-A].1#ZU^L!2O""U9]72J>2F!>
M'&HC3[$H3(L/R7^H&PV*:`W\;F7%BT2((O?S9'&,@@(&!O]`5G/RQ?D9.H;S
M'/;'JK[X@DZ;.1>2D9L%:\+9'[=[)ZM'E5WO[1#A[D7;`S@D>!YF+]R!UNJR
M_8LXLB+`5OE^:4L6-6#_%$[(`@L(U5I7]7.`&=UQAELSS_=^PKZ#%&H2)IH-
M^Z^2>&KB+4(,&APWXDH67XD:)IV5Z3JCDM.SK^K<&!+]'CZ>)DB\PD3);D-,
M1<>4UR*MR)[,<#=7Q7)`_<A\_ZOG:?,?;=9[?'VRB[-NUSTY&H`I(G'.?V5N
M<L[9/(=,S>@!'`%BSS\CK@GMK@@I3<?BUXE,T=-)4@E<H$",J.#B9+7NL>L^
M>T27:UCLLL^J=H/:L8ZWX^H^RLT;5F"<W7D]]!'@V6U0!GCH**W2[E>N69ZL
M%`O-2.@>EP93JO>8D#<Q)W<*"2X]7]@"O][+EI'V4-2I=N]3N',#17/7O\_:
M7,;'NZ<837J_II3NGMLS1;9]&>,9,UZ]-(UDX9Z?`G4AJ8YDP79\2N^<TOO:
M(]GMX'::EWXCO">4AL\4NY\7M>FB;HUD2K]3L2^0U54^\(DYF@#.1N;K!Z.?
M0*P'DJK&:T\C)#J(_>2BPX9\*3`-/]1"8"L$W_NF$`JCE-.N&M\_@2PV`Q<]
M['@4.E7M$EB`?1RY-UN@S4E[N8LCK%732!?S:)^$G%`[!1"#5*TV](F*HI%U
MF@=G)136^>A4@YRU>YC5<IQ)<$8^#95F44??N3[#(L4](0V:!(0Y8FV_3!1E
M3/9P="\4`7`.FVPD#DWDHL/Z`=LBUG<"6J-E0QZ?MRQL?I;>LLV@E&)=#>B<
M-.<>JN%]:CTW5>MHF;GFDMC-PJ);HC8(0KG9,'Z;SBM8;;.FBS"4Z3,7]PB3
MV-2BLUAPWR,!6?OG8Q7/&_S[$+S.SW_B8H[=%=K:D6!C@QD%Y**1KP>CMJZ8
MGK)H6"7OK<G(7[4]PQ%O5K.Z`):`]K%RJ*`YH%_GIGTLZ`RG,(3V/<[B<6Y*
M8+UH*<U,7>,I55O`*[TJ%[;,6[?HMYF*TE[2H\K];N>>A^$6-,X[T\+M/7!%
MI!>]:O9B3IVT:NU.YR%^/`33>ZU^7!KP_!7:N<IB;NP\/1=:PS-`=IIV=0?M
M_]\([^^!N+]'D)@H0_IQ(:,!Q>`K1Z^VQW)#Y^5Y#K'#9Z^#?.Z:+2*TU$4O
MZ.KW)(:4Y01%,H6'\YH-D=HD\]>0NM2>AIJ%AP4OM'H/E:GWY9W0;'_=G=N#
M?M10>#PQ%N6)I(&XN@5?`G275WJ#TJ`9T=L-+QJ3(A@/KY/9%T^2$9;I><"%
M"\OP*`XC=MF@\'R=K!*XC2/%C*7)#U,D:#`7:7#`-!;-"[]BOL9"!:A\X/7-
MO;8Z+Y3,S9\;9:MR-S)H-7X4WYJ!Z?3D/%'0^]>NJ&']W:JI="55T"'`PKQV
M?IG&&-PCZID+<JDR)4;C5.?'J/X<(V.<R&8YNKJ<)&I0V+;DQ`CQY80]?VUZ
M"(0ZJHQ:B@@CNQUYY48L0`E7O%!EI##KM&ZPVP)S>?W4HC\6:7Q.3[]SS_#P
MUG5<:P@XY,QPWZ=CSV---2E_,P35D'7_CFD-/C'/;%V8+>]]/#.IKN>2QFP7
M+3VM*=)J1SBL%\4T7YG6L7[O>:^0@6[WPC"Q3S6)XD2`>CVETDTT0OJ;.5K=
M7!/$[0TR.^<8BA3OY]D*0M5OS2/#LG@28\9HA1L!Z6EO/62RO$10\C-N5I'M
MF+X1WD^4<1H`E/KEXA.8>;`R%4W_G@+<=H`?G]3Y=YP9$DB(Z7X2M=9@3KWB
MQP:;J#BN4]1@\&9@N,@2G86C7H20^7FYKZ[($$29=.O/6GL?2_@<&@2[+SZZ
M3MT2F:R:F@5.4VEC*D+5H'X>613!9%?D-\GN`N"$2"F)*0Q%;)>>-4:W?`%E
M4&F76B:$*B9)5ES2TO4"M"&;34RZ3Y#OV0HZE0??LCE6"'DR1Q,A9U`OF$5.
M(SIX7&.;N*7&G2%)FE/%>CH1QK-1-V)&X1/[H"9&-9,=4IDP`'92L$B5'S\:
M=J,;XZ0I,7`U<9.^9_>BS04%,,HM-7:JH]PI050A1`>($-CH4?-<60W<-&8?
MY/&SR4>_^E%^9#$8^<[Z@ME%?GMU/`NHVCUN'LY<D*[H(MXMQ(LQ010`M.L.
M:]V582.;X<280T[AO+1-N!#,L;(8;L0*Y\!V#/7=E_X4KG4`<R(84_GX'3'.
M'$+(KHY&/G5.::$`)7I0-[CUVR':4CFGQ9=7IRH"Y+H!7=B3J?/*KL=@4%*Q
MF4C#(JW'L,UK7CC2&/.9UI"68TG#.0+NRYJ5I<FR(7"I?ZZ,*I^XN(8^/#G\
MR&@>FKCRNZ1==[,QTN@FW5\N3C6>"Z\*:/F(BH&I^S\+8UAYVXK#!;^$@#?>
M4BJHX>C&';_2SB(<6CL0E@FT<BA(JARIAO8`$N#5.B-L2[J%AM-Z.;D/D3G%
M,M&N=?@KA$\^MJB8>*PBV+8-^V4O/-5H;B#2BQ5O1-Z1!QK!"Z$%8="&:S1.
MGW\J)%)D5:5>S6R?9\/*<-<K1G4-K-(14>8&\\B6$=Z.FA)]HV7X\`Q7/==;
M^#E/)J>>-R=)J2*A8[R^I<UP:<NU3Q\M4MTR*E16^P))+5+4.>:+!+KQNX'U
ME6`:.]M;'3_#[7T5[3W!"0`L"R>%&3A6Q91,-W/=,8=1Z"K:5]V;S\B[NNM1
M?9![(YC[[UKDVMY?#7Q4^;V,DLUF+V<):1+>=LVX!`37U3L]A/2C@-<;7KM@
M(<R:9]%EP#7VKA@1K8&CH3.YF=ACG46/2I'9YKD+-`VKO4VIX&*!(`RMC8(;
ME$;H,A#XXBNFE2^E4U(=GSD#%>6UT<EEPWO%>]<-^(FAF;31VB4$28LM.$<S
MM$V?P<CJ_"RPDT]M0AAP883?T+V<S[':VH'#6-L53($#A+IY<?M^D>_@B;^%
MIG[HQA"-5W\'5?X`6XP28&;@5$+J`)8()!7`$H.<_--;'8T(+13'<<!/]\U+
M0KS"-N;*38P1E)U%A+29_'`1'?R=D\$^P'&#&I^,45K'@*P@MDPY]2.>D"27
MR*2P""W1']0@76/8M:6$Z^4"`'CH$UERV7@Y_`&QL,0L6M-,F;IC':@)%ZD@
M5)0;F].-T%M,L0;E1,/7.;9N@6?EL$6?ZG)K[6TK\C2W1@,-9>Y>P%4CM`80
M2JZB&4,AM9JXSX&J)60<0,Y(J<3YZE%YP<B`IGX<#159`/HQYND\D_F^];D2
MQ]KV@C05YP2B+'"Q9M:33-&@=0P]BOC1U'C;,R5[)-XM$Q<$T##^5]#0<IGX
MC'P^R-HMM.!1=`S;*AAW`2%4,=O%J:)+[1:G)%1X6?J*TONR2D#C1I612N]M
MZWUV):7N;\N4*6/@G]>HK.?,MB+4VX.%QQOX_D9HMC\';K;:/<J:S<^WJ0\?
M7[NF.>>!"-?//8X\3W#"!B&(5*9W6HG7'G&HQ8=A"/'EE>O%@4".^]N@9)A0
M%?#?T[)R]DX;Z]KFL$`OD22!'GHZE>C.&43IL/,]N\*HBJT3C`9`/RAIYJHE
M-QM-]TLA,$0.I_TX1<T0+#,MT%`^G)7=*@O@VX?WZX6GO]EZ4@A_-8(W_CGI
MA=TR[`#!>"$H&C[^+HVG]S*7S%$WWCTC6Q+4)\Z]=9*2DDUUB:@1=0$?A6D"
M$$360J9BSK[@,B'TXLOC4.Q@HKC,,R`<RRB8<KS-Y&?RYBS#EI$-;XM!A:?@
MDWJ?D5F5H+B.!#%M"A<9V#OO6JA!'?CXC3>#R+(ZXP++4@_B1[?9:7E'"N'T
M'X=F#OLC.RYG"D;YYSQ&;%T\18B+F4D*_5V:.;TF,<DEG^F8_0G!BP+%ON^E
MX,AW')GO@1CT*7[RB*OIN)N3K5#;>!K2%J!"$)\<Y9L0RP9<88,``"``241!
M5+4$/69\/$HCWUSCB@TUHSUK68UO<))1;(II+%E,B>EWL;!E&K22V>:K\WZ!
M7A@CF%HT2IA!D&IAGJ&FJ1_(NGV_?/V1`VK`$'1I&$\K]5QT0LV3=1:A>QNA
MPAX%[.$F#:GT`CKW&GC$F=\WGX;&ZZ[`AGM,P1*]L;)4*1,,$E$X,#NUV*(\
MF?7;X;Y@]Y>H@.;U2OSY=PO#3+[+8PUL8E%*4*!G6.RT(5!H3\$576CKBN6L
M'U8I$E``_32D",2RL[BS:SN+#V?*2Q[/.\?]ACD[)/8-4`Z1>'JH.F56].-/
M/ES"3YTHG.C;ENQO(+SR05["A*.2(OZSW]<V,6O*O_ZEY4@=;/(TSZSG?.Q/
MG'CPYSDK\G$@YZ-;])S3,2P5PE,8_`A<`>0C]Y=LE5BEP4T2&N5$]T?=5-S^
MOA@AV>I"B<8D%<$'J=)4`'3EJ40(K<N<<'?93:RFQ3KJM*U*5ZT/I([/Y:`-
M*WX*1`PDXIBLF1#$=*IO-%`WK>0*Z&%5E`,DC>UR!M]2+8S01ER^"<@D_M%A
M-30*4:_$G[?0,5H%"3-8)3W&JRDE<F:@YU\Q(>9A\8)1)*64W&9M_SNH/PA%
MBO.CJ-82:(H>7K_/&D06LP41/R?%6BJ'**,_5U24U<8WVX5/`_$D%XF+BGXN
M$H36`K+.ZDV];^9T%IPWV@-[/G/1:3C.Q*_4T'DBBG'&A'!-P,`2K-%1\+OJ
MO-_OUHB1!1GS?%NQV_Z7D6-O+^6+K7[_:2T1XI3GK%-(TX1>YCP)9(5X<S'E
M`0:%%VHPO>APA?Z*P*S-[<]RH[KD(>@5\$2B>0`SM2$W2YC>3/*>V`K2AC!/
MSW02,^7U%)5H'_76E*%(41`Z5'A+L]:H)I&)6FG7RF0G+9C7E?X>83C<1,)1
M/E;ON\SOF@1^WO+MTO`QPGM68)XQ+T,FVH>>J_9WE1_FSQZOSF*QN?#VZ.Q'
MZ/-ZXPT+_<CL7&V83*K=\+9M9L.>OGF*4%*K`)6SZT\OMD2;TKKX7`GE;)UK
M7RVU==5<$`>"^NZ6T)6VXJC'0F,Q,0AVQS](V"%)#+HP;718+&8L4E`>)07*
M?CA^[0FE!HMT*Q$;\VNNI^.:<ORLA(IXUQ4QXN*#,'HQS06=Y:=J3!YVQ;4:
M7T\NMGNAVVFAQ;M3<_FSX\@5!4U]X*A!T<A^ISZ4A-7C-L96XV[N9'PM(J?V
M=V:4VJ^]3@6^+D(`4IHG#B$2*<6B,%?OST-S55@GS%XSM6@\,G(58%F$TEMD
M9?O<;PE"W'>5H?(>_J\RE.\BT(01'&+H!YX"8)_K[*R_5B-!C\K/-!XQ1=JJ
MF,6BJ(`ILFWCF`E&:P5^Y.+A/7C9I]=,$X)FMTWGV*,U=UYNG:.DA&T;PM*<
M=9D*J$#H'0SGJ9Z/W(LHD<`M9W4=73,@WNG`^U8'L/#PKJU4O2R5OK0![?^@
M4#T@B?R%R>U`E_<WHD#$>[7QP350A<X%9?"Y/-X;[CYTCJIVJDE>PR.D1JR/
M,+LIJ`83*G*@H":\7?^L@:6H=S<B1/O;I>%W$%X?HO"E#_N8\>LI!BO;H>7O
M."A1E\78.)XP7^$3CFEFA/<9]9Z,8F?;4L!3I!=G\J>-_DD6B4)B1BBF"S0O
MLOMY\0X$P6QRQ:[FW'/'5^Q4A^C^"Q5+0?%MIOJN^%>=5[[F:2E^M$-':\1J
M,I2L*E'`!<<U9*.J_]0[4S@*XPC(@HB1:<L_12AF\((4'Y/LQ]$V1$)I@\J]
MZ`7F1+/A":W59%YMVE!M5,;F7VD\WJHC2>@K?!Q'^7GPM&)&CWT,:;_OA*;T
M:ZGK#5P-M6=P0_G?4Q=883D*UVRI#CT-3SWB)09U:XC=9-EGD/,Q2LU3,=S6
M!,<_),_=AN)FLC]B1;U2>%.AG]3[%^1K8")OR;*P+/^3S?UB)'1.QPH<'01A
MO+$&4ZYP60U&S?Q,&TLPEVHF;N(C)GZ,W#B8!TQ(NG\?/?\8/NC&Q52:I#CC
M9*&=N@$-FE"1D`_*XW_?S$:H;]-)1`X9S)_VX1_0V;_></_)7Q[JG4[442?(
M[E`&[29W[K%.^?.MF4Z+M#CM0$@TCXMK#3.ZZ,7](-1E$]]K`1'&&]C%*FLF
M_^]LO(*-'[=8/_=^%FI#2.SSIF9F[=,.QZ,\$@N_"UZL'1H^-I'Z#;A8Y5.F
M7>(ZEK[@+$C?&HW(];Q8CSU:+?KVF?,?`BM\J+9K@JO(4W)"EO`Y\9Y&';@&
M2+$X?K7&L*LN(%D>CX^B7"84-,PI#LZM9]'G'(R6A8(@9AH(B'?9!"$&U70%
M0UL$-D+355UJ6)YK_;)IM<5GH*_=_0&8[)VXP&)$5E1QU"+#1G"VD5BJ&YY6
M;MP!I]<;UXWC?8,B455P5"^N84M6F@%.+S.V3@(@$\HM5:A6_]FC.;WH;?RP
MBD1*38)"+CM22@F;)#P?S_)]:=U(]O.(O$DYPM073N+N:5#L(N3-B>.#KAG_
MUA[*-D<YCSA><<7,%$KAWF^9+,EPFJ!F3D$&8BA->(8X1KA[FK9;$#H2*#W;
M1!H/]HSA)^PYI&I\E5,0G-!-_BD&>-`\U#17EJ<=HWYG`BPSC8`-?.";*N!8
MZWK?LE8*Y`@H\:+7B`HP.44$?V>N>\`['I9\,A6R$H`8_6=U\%/;<M?0975.
ME,K1Z+61-RCVPA$#CJ;B$Q^+H)/%<2/;UDP@C?"W(4=*%HY>=D[7O#[+C3'0
MK`0-*,O>\73L$S0D'QEEEHELITAEG3Q-)MJ>^.D=@@W&3T]G/<YHH"0`9"(]
M@0WS:='NWRX-08?\):3W"U6P.'A]O"SS![5@`&:V,Q$\BLD,2T8Y+Q"G4K<^
MM:E]MT\WR=DEU#C$!R/!"\-+V]?[./)ATI!*D2,?'F?D7BS!#1&%&]NTKZ/D
ME1.EKW?%-XESXM%A)_3SVA<#:.D")9H1`[/,A;0-(:ZIC4-M"W=O+)P9>Q?=
MY"+!&1&EH/M2[LUEOT!5\3R>2'6QV[<=:=L`53R/`\?Q=(B7_<^6$BZ7"Y['
M`7T\ZBB*"@MAT5/U=LU'=9P8&U)#75)#C'TAT3<L13ZRXS"+L2=KO+(D:H,%
M4KDNY=`$^^4"U8SC.'I,JY+89Z`IQ/%3-2B,2*HI;98/571N.H05CK*AB?Q2
M:2PI2N(2AW)+[>RR9F=385%S.*NK,9IOSP\F(9'I#]4EIK&]EHFBMJ-=?RX3
MX.`*H0A%-`X<'BVD]R>WS5EAT>U%<A=3$)(I9DM3F=CWMQ>L@YIDQ#H&B)S3
M`)EOS/2:"=D/:#2VL8LYRZ%`T4UW(M&?2:S#H!7T)NY\@&?I&`ZM9AYY*V`F
M5!CS=?"BKIENHTNK.=]HB;H)F;BI&0*W##[F*AB&<7.Q:UC?GR-?R\7]4D)/
MNV=YNT?A)IX[@BM(?3J79+P5PZ-A85D@+,RTKD@VL4S,.J<:;G7S/5"'.*4Q
M[5D-D25JSL'6D3KO@[P.J&V.3;J=?+LT_'W45C\&=<]&,%PAKIE*]B&2B)F`
M14RM[WZ#0FTHO)WAN[JQ>GO1U2*=8F:JZXO"J.@0JY0-9=NV3U_;L7`IO)AO
M+#R,"KB7032\QM'&XNTX]"-5GU?=\H*0]72ZH%.W;<_/U@49JF($)GSI4DK8
M][TO'$<>7,=<1X?;MO7QI,I0'[=[DBK'F@WKVS$?S^?P`MYW/)]//)]/&C\3
M8E=_3H'^,Z,X&<@QNS1(S7+0;C%6CKG]7T<^@XV^(=/"(_!:K&QJO8A]#&A?
M/.N&_')]`:!X>WL?6P+9:#45?:6:TLA\-`#/YP-'/HP%$Q][&ZER,=/<#@P"
M:?8[G3C0/1AD(?P2\B[S=E5V$Y:)A\^67)ZKZK^G\Y>%%RO+^V5(D9N(J&O2
M!1H]#.K5%=@V=2SG(Q34).*L)DDUB8N/TW*2LVLR&$GDC7DX&&13/*HE>1/-
M8TZZ$X?L,DI;6!2YOUM3H<'I5]R8*9!%)Y%CA`JWXS@Z/]I.!_J[TU!?S%.H
M57!&7T^@I_Z^H9]TY/BP2%R,!9D6V86;GBD5ZS[J=JP-)$"OWUW>)P<4$=+H
M]P.F>XSK7I[L8T%C$3_E4"6*EH2!(`IU34Y<;(,!5Z9N$%=*>)WB?6L22)\P
M`8<WG*$7BA\AN9\9"^](?FR3P)'VJ'/$I.-S?Q>\_[,U[_10=7_'-L8E1)3[
M+*U>='8SRZ'?;/>LFP/M@05".".2<[:XV9>:DX)\C,1^A)*;A48TM,72S_C<
M?O!GQJM/[;7F0EV#H`Z_B$^9N)$+LZPO2%28(1CKP8W88F..4=CDZOO:1W.5
MSK!M6]_,'X^'+;"THC`I8=^V29#%#4!+W=JV#8_'8WP6'<^^[WA]?2U(\/-I
M48N3Z]"6KE;T#K6W.*<#>UDU9QPY3PM\BP25E+#M&XX\[(?*PD\C;0$RB(.K
M1^_@AL*ZO'/[?L&^[W4R41'4K/VAZA.9>E]8A`-5/)\/8\M5.+BY(X^<!,?^
MJ3GRE)71R`UE_T?-;:Q:GL?Y,%'"$2C$2%1<GY+`S;L7^'4@:![5)<EY1+2@
M_C(U`B+KJ5WA]NH0S9;8+6/!Q+,/"0K`L5%[1)Q1UFR#'WISH8.J$Q1A'%"A
MB!L6P\UUZ[`O=OTDSH+\:J)_N6E+/A6DKB.'$ZJQ'1=3'4J*5SPQY4;@H/3`
M5O2WJ8U&:7-]<B>&"R[N>/WW*IH[QXR$BT,NQ=$S,%$*$,2+$FNW:P(LDNT1
MW)%BAFG-;6O(?"Z4G-8T#[[H-12AY`KC,6Y4;O3=*8G:3Q*:)'K>O3O5GF37
MW1/4%</]^/DSA^4J-\7#J).^SVVY1F.2T2=R@CF!C^_$=\'[-_^CG_W[:>1+
MG,@8<#2;RVIC,U"^$7P-A61?*%;P8S02\,K>XX"V<;*/T/Q$!R"NT.Z)X4;F
MKE/`P^<:#`E'),J>BV)3L&P`Q+PH"5$CQ*&O@XH2-*^?[88\VN]][CKG6"?5
MK-2&J-!'%6!C<$),CN/`X_$PMD'LDYE4\80/HF#ZA?9-ZOE\XG:_5;$5(4_U
MV<@YXWJY%$3(I'VYM";R'!V?5>#<G`4I`3FG4,33-L0>3A+8[H@(D@(_7E\+
MZHRG%0LI%2D09#V<RT!%!5$V[\?CB7V_8-LWR,-20[J`C.[-\(D>M]4HS76^
M_Q(U/\$_1ZB1&M$I"XNR042]JX:X`I/O3TH21A?/B.LY'4BYZ)ZH/FKXYF'Q
MAC&I\2_;:.XP%P\3OWG$ET(!33*A9H/J'+^T:CQC9Z3,4@28EYKZ^SESED^<
M/Z;SM92R>!R.[H$\C_K;E(.H"HXW[6T*.=8Z\_$[JH;Z,(O_K[TKVVXCR95`
M%BF[__]7Y[1DB96X#[E%`,@B;=]^D\_13%L6Q6(MF4`@ED2L1VBSFW9J8A69
MTS0BW0,_IT>L%1H2D0NM3D?O2T:7<$BSJ*?7L*W6]!"'(B_S6,Z.AVD$+A-(
M-Y0[1Y-`2\JQ/L\&)_$TGX\FF=TZZI5[_IE.YF@8B/`:%JW)S-HU-0I.#XJH
M+H3=$#74C"A_H^`>-*;,S>>[X+UXP.P_?U=+"Z?8LLG6TDS#R#.RVW`,@VI-
M_'>/FF2?O]FJU%A88GIB4GR:1Y4EY_],*YQ=&@LBSDZ4E8Y33'.B""CMPY@*
M"BN#[I#=$KR*%'_.*%?^:3/DD\Y4'0JNJ8<O\LI8F-/.W^?G)\2@2G2^Z`7)
MV""M(Y9UI!7)VD#/DXO=L=B/GSUKX[C>[_<YBF?B#(_QS<4^CY$<(L:C4!?@
MQ,YC=3ZCV>B2(C+%);P)\VR'4P*Q3*V1.\[S(;56.<HAQ]&%9P$M76E$5E=D
M<2E14&E2>TB)2X:#$5WV#&:C:R_2"`BO"R?`>\8C;S16A6D#(N0HFLJ*72\^
MPW$T.C%PJ<GH<_@=)M$[UX4P+D15%C(U:`:.$VB:?>84^-Z?6WB_A<HM$_Z1
MRM:>!4N+J#2QS%$0TN1";Y552BL4`N6EAM?.!$PH--#)8K<GVJ912A%X`;]6
MCY([]-B302EPP?.>,6A%8Z$<:3EQI&V0G,>."XQZ9E2:K:6HLB/.$&_*CJ.+
M[C/&C@+K955DPTW--F8MFIX/<^`.3E2*%)X`=<&;UU@36NJZ7/J]:J&89H&C
MHV)XL;'0@"DMM*U:!)Z`JF6;)H+`D.]25[;=WY4/K]GSM&!+5M*<$&"7X^L\
M@S`:O%\<]5-:QCJ2C`?CO1T3*RTW]M!,3F:\6R'G[LQ&N)L%!C?C@+)NTL`\
MZC;$(C.0(WB"ZM9WV"MR!?#TE,X@>9&OODJ?&SS>EQ5\A]EF*T,>)KK6B\NY
MX5I4U5KB+H'GKU:3LY[RZ_.S-SJ<A*1@,T>1I:XAH;A1Y\5JAO2)=I9NMQN]
MIBV\/0#@/,D,/PM1&+QC;@1]H2++)-Z<^X`M4_Y:JYSUE./H]`]9W+WACD%)
M;L#;1)]?F\ZN"M=UB=XPHCD@4F:Y;5THBO91HZC`WZ.I0N<U17?KLE)KUP3.
MK6M@#>@:.A@@B[/5.-K.(S@TVVYV.DW]*1W.K:]X;]4U#BY:6K-QUN4+WN-(
M2]^SB\#:4/!Z<'JD.0!A)4ZU,]TLM>(JFB'VOOB9%G%9L:RICUI`2\F'UO+@
M#VP<ITN!LU3SPK@9PB%"]F:AH,]&`!$R#Q[0'N&>#:`8^+%"1'%=?/F:1#E;
M^.S701Z7^\Z@+D@4M06K:PB`F>\-P3E9D,O:!D"78N#5;9@]ASQPF>N].0X1
M"Z8K.\?KDX(@`0(CSSH):U(NNBNL<^E]0/>*DE--MI-ZS06)ZR_V;>F4F^\_
M?\ACN'R>_^9WZZ;HA;]OG<7,Y+G)&J_":8BIAJV2AHQ".)>)QE@W(7_"E(>_
M(A<Y=>6U*IWST2.(0,\Z?BR3D*"$7]4;MD-U/_X]:TP,1TC*[ZD7398WWP^J
MY`3=]:DT6/%;PA6<=D^`[!RER.VX]<VB`GH+'HNPDGO3>W,)5VMAYT0I[,:)
MRQZ-H;M@;4>[B6-/+843^\HA;V]O7!S!6W$BFA/%&"^>C>\[7"A$2KD[#J%,
MI?E`O*,/L8;(3#R7?O'V0A]+J`\K2<D;[U\5P\*=>DA08P&5.:*0YP3O5A@%
M6[&([/A-#J<Q/ADM%S#YL(WP\>HJ`+PVU0=4Y&-FZ<KWY5;B$<56\)35YAI:
MZ@FM(=EH/#MV$H4Z-%TV"6!8F"X_\C@AP`(WI/*Y8\DF)U@,^T:VAL3"*E8M
M<.Q#T>2H"+OK45P@C)^`H$>KIN"5NO6=)R/(A]]1&>8Y[KZ\XD$2M\[Q4\Z-
MFDT'$$T>R^XA7EM(S1*0NP"/224HHOU+])CKS8@>ICVWZJ(.E+C=\UJ>5`[>
M[%<U`$R9.XDX8,='S(M;[S2I=\1!9W3/;]:E8=N&C;%\VY+]+2I\7;/:D^^E
M1;+&&]&_3IW1M9F%@(F=3CNMDLTCNXM,'CYCJ@9EY,&KI1WVM#DJ#>CL2TUW
MB&3UQPR!`,YD?(+G&UL?1D\,F@-+^Q.[Z'B>>B?["8)PIKDPK[\Y3607W=@B
M2R%2M1R''+=;M];1B<8^SD>RV,OD<GH?8!.TEF&'B\PV:9J8;X80(Z)2G8*\
M4WL9$7(HD"IG$_[X\6-^KAH0.3[/*!;#K@@W,:LB7Y]?<K^_K<2P,ER!VNM_
M_/PI(BKO_[[O@8N^L0ZAW"IH)#QKFB77[:P3>50P89V!#J8;`CYH%]Q"T\25
M5Y5<`Z).-A:NU`CT-$$Q<3QD+I2';W/UBFXGQ#,Q4I2KXQ\C\D>F^)"2)TZ1
MCO<U7X*U[I8$J<."!'U=+4$\LQCAG4M!)@`+-(A-<>W?ZUF!&=#F3E'*J`\*
MJ6SL-8PTEHLIZA5%HI]X)?]KF8K\D.0),&FSD"LQ+`*F>U9YW(ZHM/=&GN=N
MIM^Q:#0VLL:)G::SR"SI]0$!JH-(HJV=3JYKXU9'7<EX^VI&I*%6RRKS^6UQ
MV$N2Z)KRKR6C1N&T1N$90RV'2)%]K'G86UVSK\'MQ<"!9[']>?+"4[5OA/<*
M+7@^X7@9#OXMVUZ+V.'N=ZZ+^IS00*!=2KU@VH$9CX&(*\1>.Z&3TQ3^N3JW
M]BSF/NTRUO'!TJ5,]WMVBCV:9L`C-AR1)H-EW3VL%Z"]3T6RY#RI;L9.Q@4;
M.O:BS=.,XW6CS?,\Y7$^Y.OK2SX'3S8!`%7YI@C4.-?5F^RMI+@XECFN-:B"
M%K6OQ`TA00XCA[O]_,?'^^3_6O?-W3T9L#Z'A799EK6"[?/7)R-#'6TZRB'W
M^[U1+<@6S(3%IOL,[.T$[JJ[)J3*(7[`M4[[S%%$3@$J]G>,^-(]9A(Z4E+_
MPTA\%J06Z0GJUJ,IK_73%L+)-&2E!T5_*<X]RW*E.PGKA.SAS#A13T#PA<>2
M(;B2%/XUH=T@(KN2Q2*@D:)6"6)*#VZ"[NY^#_XWQ5AWJ@`Z*SS;-VL28RR6
M4RRL&@5L8`,8UW8->X)_#N?Z#.@K[RML_3;#9E3<Y$HOKY46=C]8H_<"@T!T
M#5E.+H.292_4`3M.]=0G!S>9M>?.I]4@_&;0/DQ`^%NI.2F7M<XFW">A-OB8
M8`4-3-%X;8-KC[%(;U"/U.229RZ8J&F1]SSVPV^$5WY?L&;RG"EKS[&\)Y7I
M\]_]NP9A9L^/R+*%NR\.1SE$>M[WB:,OV8RY7SJ#^C)ROON8F2>HV759&F,,
M84'4G863;M'=(,Z#]9/^+4/5W'@.\M'6PC2KQF68J"IRN]V[0*W2&XZ/5AW?
M]03?6-S`,QL7Y"D2BB8<EZQNH_0;K68;N<9MG@0F-`'05:")I.*$L]:)IKV_
MO\O/?_XA89K/:1^6F3AZ$XKC'.*M(BHF7X\ON=UN4LHAC\=2KQ^WFUAMP1S3
M)U.9^^FYN4HQR)*:K&?K47#&D^>>VX:3"?.1ID*H5S:O")&NLI^*:+\.O)"T
M.%NKQO4$CCL['UB*]:U7I]T>-5,:-S'+.#8]"6K^7#.,G>-DLK5*O-4&*MU&
MV(M3BP54*8>C[>@,)LD\47>I@'Z:%(K=!!$<Q9<`\ICN#T]<!U@TIY,N@($;
M#=D5"FU!#V=)1M2C8BEEQ42O$?1P?-!HVT66)S(CQ@G-Q_0R&QZY3,.8'M8@
M7BTETH9JC2)0)1%:<KYD3=>(0^[0:'ST%>]53+53I2G4^+Q,(8"D0EO>RU[#
M,E%OR/\NT+3[^RLZ#RG@)IS0Z3L.3L\38KX-#WB<`E(259_<I'0^8;U/N\^9
MVXQ(MFI^GT\!O6I(9_Q&>)\69WD]:J\&3KQ>Q_)D\F(WTST&\.2]'+$@@(@+
MF?*ZM=&52[^A@].@00R90P,U\NP)W1$3CU4^K7B)Y[-:W_5>9$[?+$^P$Q;E
M3C-\`5]M?7&T;R@<>FSTE!ED=!2-"SUEU3L$G7A*QI>I'(>4HP"Y?_TN,T0W
M'!_45G3E?#TA(!74Y7X4JH&*.=[O/$\PJM]=-5QX->SMF4@"O\:Q#)_:\:6`
MIIF(?/[Z#(C9=!MPWHQ(TPC^#F"!]GA\R=O;#9Z?(K=R[VES)PG@YOF;JW*-
MY\(6!]0V5G[VXIHQ*0P.O4/;GM!,./ZN'R.NILU<XI]MD[TP9E3POM4,<8&_
M%Q@1F[E0.H6-6N4)\-U^NI1Y[D=1L;-45"S`.D*NW3)1QQC:G%=K7W.*KFM8
MP-,Z*VXSFZ3=?V=K$/TL6E)A7'@_7OQY+T2+>Y]#FP&T.,\:$MDRA-@WZTCW
M]/J(2;D:SY>15UH3&@;@I2Z183?35AF.%JN@*QA_;/(2Q]-3(C)ZAZK.\YKQ
MR#,A,]C%3)M+/S$ITRQLQ%KW9KR(%.U_[T]2HW,,4>T043KA@7))5URL<[9V
M3'L_C<F-$]8PEN>0!*._MCCM!\EZ:'\K'-PAK$V=UFJ*^`X4K3J^%%!M)0W!
M:J+XTWP7O++G,NUVF%?\$%3UE6R$?4WZGWBB*1>JEI?2/I(O6Y@]@C<]!-`*
MR78?1;?G_7G1JSD4?8E\JWNBFHJ:%N_^L!^WF]SO+6B@V6P=<T.@+T?=L`DE
M^4C5_6=!JQKEJF\NR%MD7'LZG3U']+T`S[#)&%'2(HEP<!,7K&SA-OZ,4(I(
M-!@+57&\-^:`%?!YSL;$802=QJ_V?;.>[`P"FVP:_2I"0C!28/<`BL?YZ"$4
M]R:`N+6&XS$H%.Z\X0'Y&-,H`(R4"G$;18;<K6CB#7<S<8")])K(T_;.&D9H
MM(;Q>KK6J5"SYI]6%.QY@5#V._W?J^U":IA^E-_?+CZ\<_V'/=,8\WNTU@"^
M(Q&0MM=790K.[P`K6=/A71)VT;H*G.)Z8<VT7E=FH8Z_R],71LB$%XME""@>
MNTVG&%[3D#=K`3F,][TE$XE0C,*Z:=YR32P@MH2*&M-5QC%EC48(3W(W>^J,
MTHO>Z&C!8KHH(%=RCAGKR@Q_ZD6QJ(E)G5QW_X<F?(EKCAFK>]0EEWJ0+-.K
M9)5.J)M-`F=Z6P-XE-^?;X@`%\DI8>H*B7&/?%,:KE#<;3'[O"#]`R*#3^#\
M$X>QRV-0KD[#9S+;T0Y`F)2Y2-#D]L^I(0J32'N!S^#!CO5@*)E^^]>C0K[Z
MQ;K69J#:1X73P-][_8KC@\FUB/&JT=(+,_DIJ#(AON51CCYZ166M]_A<"VM6
M.)2CR*$J<AP-Y3V]IRF'.M6`(AI'4^/XC19=(X1M!J%4(=0<[<A6X[7>\W:_
MR>?G5]CLZ9B*TNBL75\8_ZH/48#S!H(.&@7V;YSG*59-WNYOHJIRO]\[\GM2
MD`#3!.`]C$>S^%R%C=Z-44,!LWD.57WX#-,(=$YG)%@9SDCN6:BL$:?A#@D%
M,HJ9,/I6<:%LL&/GZ:Z%:-(E#)!G',.B0`7.F>?@IC00:P-,0NYG$8/'S!S:
M:EV4*"VY<GK6%@7AJ,8XW4%_$*!$H?`5`E<R3FQ6T%9G!^;7B>H2NS@0(!:E
MZ`OL4^'"9"!UAHATEQ`C[.:,124X!PU:Q+"K\T7PO*<&A<$%<BA`@96<5H1>
M+U0\&J7XH>`2PUS4'6/V>4<!2JXF9N$YI(`--3$IG?\]Z`8F)B>XHCB$W6$U
M:U.O92?I6@``$BM)1$%4\>'7VO^M,+T$FP4,7\'P'^1:2TW+VFDM".(UOXZ0
MSW=H^$`4#(MD]=[BQD"$6'PVR,HM`=94T,ZNH;K#&.V[X/V+:M+^`(6U9Z6I
M;0&]?1'HBN3+PFN,NOUK$#RU'!/2PM&.D:/@#E]?1*OU(J',G1I-NFR+93W9
M>IDC+[?-S.@`VQK2L^/!V]%$0K+8<E4%M4\RCN^)S]?7'A9%C#3.Q!H`&\CM
M=IM%^?"378N,Q<7<I2I)']%9YTGM+%X60T5AD;>$@**1$RT+;:UF<AQ%CN.8
MH@FDB1S'(?=>2'J5_8@L?7O[(>=9Y?%X!'-WE0,&VN/F*\#1G?86_3@U3#TP
MM4R)%M,VUB(M<>['SQ]RO]]$2Y'W]_>V`3B%-(Z+D7M-R+$NIQ%\W0SO\$65
M)/ZTV\5`\V;6;!9DLXA0"0XDY$0@GLN[[+*";W=1E_B(`2L2;)#X^)RX:"/6
M-;'."59JJF94NS%S;VV6*Q+7%YG8Q*'1OJ=8S_>`^]Z@$![/9#8!2X,DA!7O
MYIH@WPQ-[]GQ_&+<;R)<(PNQ&@O5'0IL3H3&W%V-7JAN&M&<&]:-6I*P#P6D
MKKAC\39K:<?NBZ$A%!S%-%2+C)C[9IW4"`YP`*ZO+94I@0QS"E+!%0?V48W%
M+)^S49:YAHZF--/IO?TNBUJ&8:E'R+"[S^BY<A.F&2JN^6[5L!?;JFP-O)49
MQ+)]H,>N3JJ6-"ZP\YO&\(GD/O;3ZF]*PY_^^4TT[V66@OXWQW51_4+=ZI3]
MP.MIOJW'6E`L$8OX4=33CX/&W!(1*>=!BPC2,[Z(>33,W%S&A+P9?96'Z62\
M&?G1E$W[)BJL]?JR>+1"19A?.^L'Y-<U^L';_4V.HXE)'N>#4O;8`%V)(N"=
M#D9RWD17"YI_K_&\&T)"3#6/Q<4XV6B<R[-6J><II11Y^_$V$]E*_UR#)E#!
M/-U(S+&JI&$[-CF#X_,5`<YC@<^@;.FC:.JW[C,+"-;P.&8/GZ_'8Z+C#=U]
MB"4\I.!J(4L<I(*)?E`,RG)#(>0L'\JDXT2S&OQS??-'X0[-CQ[4WCI5VP8)
M,SY:.*1@2>87+C%M!0H+E23`Q<6&,B*^$.=V#P@[M+AP%4MH$]@`>7$.NF\(
M.#$LCG,OF@V1/$V7;6P'D;>Z&R_/PLN$BM:L*%7G[+!#9U_YOE]7/6J+_%]?
M"&?69^/U17D1-)CP^#]E\G^CU9<E!?)$_@HW`I+<DXNVI>`GC+SJI'YSU*GE
MA0[KJ^FR$YOT`Q5.>E\Q#X@J%P`S="@^/+W)_(;5O_K[MO<&'UYZSCV/&,$.
M#=,S?[]>"Y346\73L^O-A2R@K[H-=?(N/'A\!8*BO%8)D_/V85%%5,LWPOM*
M[6E_4%=F&]0SFD/Z[S1:E+1+1'3FVN\7/%%QE(EC[J()<7T]B&<ODOR"Y)%$
MW0+8!EV7TYEZW]]H<?#\>NE2:49U=QR%TC%11-LDXW7!FP%-8G.?)'01NSS6
MC<_&7&A+=Q-8OLBE''*[W6:Q=?9QNKI*R\AY(8^O/L]3/G[]DI\_?\KM=I/'
MX]'1#),LW56]""G9<,-&V(_IX^-#?O3WT1^-GE!K$V*<9Y6OKT\YSRK'<<SO
MX29[UBH?OS[D.&X-+7(;^2@<&Y^M;21>A#&/345NMT.^OAZS4%K\/:&"R]S(
M[O'XDO,\Y7:T\_5X/'(02N,95V@;U-@&#-TWQ'"LVU&5;>.4B,>FPT%T-T"N
MY^")M_,"C8!YA`0F'%:#+9,X2I./_-:BX;DB#^+8@FQ=(XA/;&0&`9MF85XV
M-`.&<=VN4?`3H:+HJ5M2#]IU3T4*P#B&$M+#ZG):$!!06?=IMKR0]6ML[8*R
MK)GU*.4635.5$Q!IRSY#1V>/X^"H68UH)2/-'+^\.X[J$K`0V2L91<,6RN\+
M>9J4P;V"@EA_7GB,OO![$PQB63];@*==B9[4&RIW1QM,10;2OL2.`Q5-!KUF
M<6KCG":P(+1-DX2K/](IL@8LN_99,Y`5M6O8V:=(P1+0UE0T`3,$(JK-(?@<
MA+/\]MLDJFR/E_9VD>^"-X/!L\WE-^JNL$D]+Y)M/]*7U^@*/IAJ7ZS'^`D:
M=?3I;.N"@;!?:YHPIK#`S)&51"\]"YUWY(=8=NS&)P7KB&SCM00!X[%KY-P&
MJY:!OBGW'&89?UOIO+K#I<(V]U;,O]=>7OOFO=:(LYY2/^O<\(S"RP%]W=XG
MUHK%?G+/\Y2/CP\YNLU2]&/E1)VL>&[7WEM\K5'66+`^WM^;"!"I)<ZW]CP?
M<IZI)E$>7P]Y/$Z']BQTC]Y3JE,_<%#&>58:H0^N=.3CK4UUC(3?_WV7G__\
ME/?W?TD4HJ[+FQ00?S^:+5LWU=B`$;+$@B0J?L![F2@+GA9@XE`FC1S')-U+
MD\D'=_267`O/5V!>`&W2T'RG0BM-`\J7)Z?!0V]HTI_'IRKRAJE0V`1`0&K@
M>+C&>#M>"[X.YOXM*U@I>:IR&,XN,7-\[RA%3CMA[,V%)R>F7>]S67`%HK(&
M5`%&>Q=:&H(M<&HUKIXFEFVN0,V.R[\&=0`!`7>"OU&LSF`%+'I%N>F<S^RZ
M+]<^V'(TM1@\,0`9P=0P>"49<YW4\YH[QYWN%3$X-G3`<`EU_5ZO&^$H%ZJ\
M)N`S7ZV"7X0%KVLL3#U7?\:TCZ>.+)B$0#;U]W8IDR8Q03L%7^"P[_A8&&X.
M@N8!ZY!OT9JDW5):Y+Z(U%ZAPB^_SG*0][K0SGT[XR_9.`=0@(!)/?,\\DLD
M.@%3?2&>&$-$GB(F76T^D7KC\$&8M1ARX*'PJXV$-F_U*)=-!(!+A<WY1K0/
M$YV4QUQF&[9BMX-KQN6`4G9AP11-C"-1AUN;A/?S39;V,`HL`*\V2"P.6!@5
MQ[`9%?NL9VC@5(?(P(\0PZT[%WN/(GHNFZB)G>8$=JO;;_9I*(IQC4)?@(L6
MBEPV:[2&\W__Z^A?+EPAY`,:J?7\D;EIFCAEU.8EB4X));1QVW(4:(_<&$4N
MT[6V;%P3T?V,;SF0>)H8"&L)LF-;?T^(`B2<-#"$MN@"`2+$:HOCVU#*,M%(
MCZ366KO/;0WWVD`Y0X&LR5Z":]C&>]07==.K-D/;.B)<O(@'J1,"#@7]X0++
MWJ=%;D9U&*AK1FG)/'G#/3`B<_O*58A77)F"XB@-`_T-3:@H!61X3V.>-FH,
M8J%IX_!:MNDJT9[/$C>JY#Y74(,;OLR8;D&%^RQ4ZYQ(>,`#M04CHAPI'D83
M6YW@AX\B7Y,?#E_!I#+\_!HW+F[0?/IAIY=4='8DG-O8VQ[W!*N.EJ61.P]-
MO4JV/MK<A\=ZC>FM.,G^+GA?+B%AJO#RZWBW>!8O;*]6U2^@A-G+\69^5CM7
MR3O&(*0)XBK=5,!N[*$ISKO.T2QZ'==(40P0QWA;[#RY=IJBW.OQ4-%4*(?C
M;ZMV8;RL$W'+QO^2%`N6'3WYM!J4V3#R0TB:T($N;$LV,G7(R):'HI*C%DX@
MA>-.SD9/[E/H$IQOOA-[90\'QQEG8[ELK"LTIG0?PPD@T6L514>#+UK-%UD[
M<861&;])%V/4UF"@#58H2G'A!U-^[<V-CTQ=A9%.M&E7R&2K!:<48\"(B@\O
MSRRIO'L!*>A5$KJ3:VG#]93)4JS!JW;CQZMQK=)2Y``ZP1R!]K%$$'B5LIWD
M9=0'1`=572=W-4%LALTSX,%_H%"4]M]9'6H\1:\91:HNU;VFL?#[O<1\1'(0
MP@G];I_:1F(P%1=PD]#?(#(=&ZD9))$L3]XE1*[H&_X9@`E?#='2>2"2VMF?
M/X^CH,@-+1!MCCEK=T0HO0.Q'K-M4M-GDPI*E=XL(&MN"84)8O`A$18;Z?F_
M78MG742,4PIU<)^1"!O*2G6QW?TO5=KU+(-BY"Q=1W-1S37>RN@Q\I4JT3HX
M2DH+K!.T%BU"Q+=H37XC>$)_Y\<2K]%GA:;NH=#KU^G?GP1]H>"G[ZO[;Q8)
MH4&W/P'C)I[FZJ7'%JLCM"-QG5`4"5T]=H,AVH#B>"62[I/3H/2X9V5H+!(M
ML4<1C595J=`%C?N3<T>;J?K4LM6U3R/N1$6=%H1/[FV.K\7,]WCVKKA?V53!
MJ`OWJ;46I@-XD7?&_>)H)][O5LPC;/#YK`E(K&9J>C_^[,=;XS.0%0R"J3^T
M*"<3E.DANBEBDGC391.VN'(F[`M]O<[I]G>V[Q5XJI:M52C2J#E(:`535!B?
MJR!J0A$:"E:1KM`U/Z6L!JF-5UO3+GU<6ZW*:57J$)FZK-,IT-2VT:L39K9G
MJO1KDX1*"(<I(-7`NQV$,;S*LC^\<"A`C8%MD%B#H!1_/KT[@X_.#9\I";RX
MBC?.[-.,FIXUC@^QO8GON%TX3B#*Z\]71MTI":I>R8E'Q:1T0=@PZL'=HJ\-
M<DB5)1R3*5KK?]<B,PZB%[2U%ZNU'8A4L?X]7D/#O>_L_M*]&F)U3=!C/=8(
M-NYI&(Y8;XKF.@D>T[3.(<5`T;W(>51WYQ_KZ1#S&M%"M'ZG50R[4@BZB?<"
MV\:Q#B`@^&:92^IWP2O;3>7/ZTO;_.4RA.`/B^NG!P7/E-]_=%-@1_HP\V,P
M;G:.+_I&-HK74D8"F$:SW=Z-:2E=)%<HS8:O22P^RG'(<3MR0_*,9O@[U\MW
M)\`OVFA:H;B5X!21>PPJ);;Q?9@KJSVZ&B)?0XI6\CO,QQ!HLF'ARB208,.?
M*4V,<QN*YW1>"2DU<;68PHK`&XX%HJ<XS*9`O6DY/Q2+H]P'R6:]:)20@#>]
M7:LX$>3B><9Q=1ZMC#_G"Z@T'4^$%-8["H59G`H,93@B@CY!T/\.0HW%GBJW
M\5A+(@[B>ZR&@DI=88-CVRHKH8M&G'`(%;\_B@F-8081F=Z$5T!"F3_)WJ6`
MG`LZ:N_&42D_%;G9:<!$YH>+*OEMTA=,7-QGF,4@%,.[B0@)\T32D)<8J"`;
MVD43F54HQ-&6S#;1RF4393P*9"KJ$X&J7J#8BV.O+C2&O8H-K-V7>P`Z_&CJ
MB,%-@?/$I8F!!5<)CBE>%(=*'NF</H@I;BA@JX[^,(OQ=/U>8KK9Y"9[&F2;
MQ7.K%T"B7D&$%C<PY#\31UK3>V84[D93;4CB^RYW]Y2`OX=,]<]^IZMQ]-5W
MRM3X^O2P7O[L7'R0+)K0RY&816IH',40TJE39*+L,\2H:'^KXSCD.([`0=Q@
MAY>?U=?Z:=,1D!96BJYSDD1+BLTP!I_VL[,SFD*,-.;1N)L=2.OX;S0`SY)_
M$DLN#9LPWB0N.`%1YA64GA9KR]@],2$W<:C+XL@B+UN39`7/#D91G!=5$9W%
MKK'-E<9&P,G,AM=26G1LN/7ULI#"<AN1<>0$&XS\T9IM!$44[<^3+BLFVUA7
MX89;-C&HMGE=V-S0CFP6:"EW($7XRV6P"HYKE9LKB04,"ATSL,+7/.L.5A*$
M*02`H/#5BZ\:4@Q):\ITAM:H2^($$FD)'IGT)SLK:D/BH$!Z&9YC*/B6N++2
M6/>Z$).T4,X0X8">)L^^+XR6D+F#'))/-&BZ`=S9-'QCXV)Q)7H+=HG"8F4=
M:[4,9PV;,;[:,-V^CM?AJ-M<<\@JDZE3DR*`./)LUE:#K&[-0@N\4GAJD%V+
M=/J(/U.4+-%>HWRP->"*'W;)H(BL*G.EG]$G4SM'L?#LAV8.T)>"1;]%CV$2
M4MMW\$2^$/V__G*YL*G"SB3!KM#3WZY0X$2-]KMA#Y>'G6^,EA3;:/2\;$J4
M4-"`9`[!5<9EE(U25%;2CIG]4;OR.X%V5"JJ1_8R--TEACBA6ECPP7C?>Y?Z
M4?HT6">:="Z8"HN&>@Z4)FB1D$)X(?J%_"B]T6HZRLS\6O7J>@&7-@M=:9+@
MQ6MSXAU\8#3+`2?5+ORL%1)4C5MT(F$#Z4HXVUE`@4?LJ]7)K<T:'WM*[(="
MH(@+_V@%FYDY#Q9\)IV0#9"SS'5@K1$+[<H,L(.=%=`6&JI7<]ZF1J-\#=.'
ME88V*`8Z@QX<&@I"G*+<>"S!KVVG>:&!Z.<7"ZZYMFV1P_[_-3HXA"9#->4L
M>X]>3`>S(!:RU.R?.Q9-$Q=W81B^>$YM)D=A*H4*GN!R`2CAKNB.(10UC/85
M/[\K;HM#B2<5*`&U?'.B@Q@K%H1:%$CA/+&9;E(G/YPH6/U^*ZK4V!4J2KNO
MKC*/>=8#P-LV%V/OUST?GC']J[U83IR#%#[KHXG"I1O>O[AG*$`VWI5(9#D_
M:/2[+Y/2Y03H+@X8DQOU0D!+U*F24()$Y/\`NTK)9JYV"=T`````245.1*Y"
M8((`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O:61E87,O9W)A
M<&AI8W,O;65N=5]T;W`N<&YG````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`R-#4@,3`U,34T,S0Q-#4@,#(T,C0T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(E03D<-"AH*````#4E(1%(````!````
M,@(#````X)59&0````Q03%1%+UR7.I7,________*4;FZ0````%B2T=$`Q$,
M3/(````)<$A9<P```$@```!(`$;):SX````/241!5'C:8V"@,7!@<````60`
M@<VN4-L````7=$58=&-O;6UE;G0`9VQO=61E;6%N<RYI;F9O?*`UT`````!)
M14Y$KD)@@@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+V=R87!H:6-S+VQE9G1?
M;65N=5]T;W`N<&YG````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#$W(#$P-3$U
M-#,T,30U(#`R-3(V,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````")4$Y'#0H:"@````U)2$12```!*P```$P(!@```#4BD>(`
M```&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q,```L3`0":G!@````'=$E-
M10?5!Q@/&3EF\^)Q````'71%6'1#;VUM96YT`$-R96%T960@=VET:"!4:&4@
M1TE-4.]D)6X```)S241!5'C:[=N]BAUE',?QWSPSY^1LH@GNQBH8;(*-D$(C
M1(2`))`BEY#.R]!2K\$;R$4(BKAH)=II$1)$#'8Y&UB7/2_S9K%A%8.5AIWB
M\X&G&Z;X%U_^,\Q4U^]_/@9@XHH1`&(%(%:`6`&(%8!8`6(%(%8`8@6(%8!8
M`8@5(%8`8@6(%8!8`8@5(%8`8@4@5H!8`8@5@%@!8@4@5H!8`8@5@%@!8@4@
M5@!B!8@5@%@!B!4@5@!B!2!6@%@!B!4@5@!B!2!6@%@!B!6`6`%B!2!6`&(%
MB!6`6`%B!2!6`/]9<^'F#5,`;%8`_X=J__%R-`;`9@4@5H!8`8@5@%@!8@4@
M5@#_JDF26S]_:Q+`2U,G>:V9Y^WS%_/!JWNY7C6Y-)NGE#I5*7^=5$E5I:JJ
M%^Y1[3]>CCNOM*8)O#3M,.3)>IVO#P[RU<$ROZY6N77Q<CY:7,KK.Q=2FEE*
MJ5/J^GFLR@O!$BO@3'S\Z%&^/%CFDRMOY?VQI,QF:9IY2M.<;%G_")98`6=F
M/0RY^^,/N7_Y:NZ-=6;G%JGGYU(WLY124I7Z-%A>L`-G9E%*OKGQ7AX\_2W?
MSYMLCH_2;589NC;#,"3CF'$<Q0J8AB_>>3>?_OXPR\-GV:Z.TVTW&?L^XSB<
M7B-6P"0VK#N[>WEP?I[MZCCM9IV^:S/\+5AB!4S"9]>N9?_P:8Y61^FVZW3M
M)D/?91S$"IB8-W=V\LN5J^DVZ_3;K5@!TW1[=R_?_;$\W:SZKA4K8'H^W-W-
M3\>'Z=LV?;M-WW49AC[)\]]M`*;@C<4BS[IM^KZ</`+VO<T*F)Y9*>F3C,-P
M<L8AR<EW5G\"SM#!8A*N,50`````245.1*Y"8((`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+VED96%S+V=R87!H:6-S
M+VQE9G1?;65N=5]B;W1T;VTN<&YG````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$U,3(R
M(#$P-3$U-#,T,30U(#`R-3<V,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````")4$Y'#0H:"@````U)2$12```!*@``"<0(!@``
M`+V;*;H````&8DM'1`#_`/\`_Z"]IY,````)<$A9<P``"Q,```L3`0":G!@`
M```'=$E-10?5!QL1%ABI#\]T````'71%6'1#;VUM96YT`$-R96%T960@=VET
M:"!4:&4@1TE-4.]D)6X``!FV241!5'C:[=R_CE1E',?A[_OOS)F!#-F$RZ"V
MQ=+>Q)OA%BP-+;>@-81:4:]@"PDT%.Z$1,*N(=FQ.,/BQA@+L^P4SY-,.<VO
M^.0W[WG/E!=OWNP#<`2^^.G'/+G89[ZSS7I[DOGNO8QYG6HTP+$3*D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H
M`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$
M"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`
MH0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*
M"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H
M`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$
M"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`
MH0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J
M0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A
M`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`
MA`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J
M`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$
M"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`
MA`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J
M`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$
M"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`
MH0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*
M0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`
MA`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J
M`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`
MA`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J
M`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$
M"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`
MH0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0
M*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`
MA`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0
M*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`
MA`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J
M0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$
M"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H
M`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$
M"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H
M`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$
M"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`
MH0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`
MA`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J
M`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`
MA`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J
M`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$
M"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`
MH0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*
M0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`H3*"`"A
M`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`
MJ`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"
M$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H
M`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0
M*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`
MA`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J
M`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$
M"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`
MH0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0*$R@@`H0(0*D"H`(0*
M0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A
M`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`
MJ`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"
M$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H
M`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0
M*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`
MA`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J
M0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$
M"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"A,H(`*$"$"I`J`"$"D"H`*$"$"I`
MJ`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*
M$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A
M`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*0*@`A`H0*@"A`A`J0*@`A`H0
M*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A`A`J`*$"A`I`J`"A`A`J`*$"
MA`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`J`"$"A`J`*$"$"I`J`"$"D"H
M`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"$"H`H0*$"D"H`(0*$"H`H0*$
M"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H`(0*0*@`
MH0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0*@"A`H0*
M0*@`A`H0*@"A`A`J0*@`A`H0*@"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`I`J`"$"A`J`*$"$"I`
MJ`"$"A`J`*$"$"I`J`"$"D"H`*$"$"I`J`"$"D"H`*$"$"H`H0*$"D"H`*$"
M$"H`H0*$"D"H`(0*$"H`H0*$"D"H`(0*$"H`H0(0*D"H`(0*$"H`H0(0*D"H
M`(0*0*@`H0(0*D"H`(0*0*@`H0(0*@"A`H0*0*@`H0(0*@"A`H0*0*@`A`H0
M*@"A`H0*0*@`A`H0*@"A`H3*"`"A`A`J0*@`A`I`J`"A`A`J0*@`A`I`J`"A
M`A`J`*$"A`I`J`"A`A`J`*$"A`I`J`"$"A`J`*$"A`K@=GVXO$P3*N"8O;ZX
MR$F?DOT^*67Y)"FE"!5P')[O=GFPV5X%ZE"I[/=[H0*.P[/=6;YY]2I)2:ZU
MRD8%'(F7Y^=+F&I-K2VUM912LH\S*N`(/#H]S</M_4R]I_6>VGI*;2FUIL1&
M!=RRB\O+/-V=Y>N7OZ6VGMI'^IB68-66U))N3,!M^NK77_+X[?M,8Y4^IHQI
M3ANKPU95G5$!M[M)??GSBWR[>Y=>2MH8:=,J?36G35-:'\LY56Q4P"UX='J:
MI[NS/'[[/J.4M#%EK-:9YDWZM&Q6M?6K^U1"!=RH#Y>7>7UQD>>[79[MSO+R
M_#P/M_?SW>Z/3&.5-L82J?6=C'F3L5JGML,V59:??B4_?+\W2N"FM"0G?<J#
MS7:Y)U6251\IM2V'YM,JT[S)F#?+1K5:IXWKH>I/+G0*N&E_)N]^3^9-2JUI
MK:>.L1R<3ZN,U7KYR3?-A^L)GR*5)'V^LS5#X$;ML]PP3\GA,F=/&U/Z6*5-
MT^%,:J1^C%3*5:22I*^W)Z8(?)Y0[??+M8/6TGH_/-GKAT]+2KFV25V%:KY[
MSQ2!FW7MW;UZ]9I,:DT]W)4JI1Y"5?[Q]3[FM2$"GZ=7AW?W2DI2R^&)7OG7
M0%V%JG8W%(#/IWY<K_[V?U/_I9?B<CIP\YO4__$7X`1T7*&#T;4`````245.
M1*Y"8((`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V=R965N+VEN9F\N<&AP````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<P(#$P-3$U-#,T,30U(#`R
M,34V-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M97,O9W)E96XO:6YF
M;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-2!M9&IU:VEC($5X<"`D
M"B`J+PH*)'1H96UE7VYA;64@/2!?*")'<F5E;B(I.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H
M96UE<R]G<F5E;B]S8W)E96XN8W-S````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C0R-2`Q,#4Q-30S-#$T-2`P,C(Q,38`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+RHJ"B`J("1(
M;W)D93H@:&]R9&4O=&AE;65S+V=R965N+W-C<F5E;BYC<W,L=B`Q+C4N-BXT
M(#(P,#4O,3`O,3@@,3$Z,S0Z,3<@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@
M("!B86-K9W)O=6YD.B`C,3`T931C.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L
M;W(Z(",Q,#1E-&,["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z(",Q,S8X
M-C4["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S92UC;VQO<CH@(S$P-&4T
M8SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@(S$S-C@V-3L*?0IA('L*
M("`@(&-O;&]R.B`C,3,V.#8U.PI]"F$Z:&]V97(@>PH@("`@8V]L;W(Z("-F
M8CDQ,#@["GT*+FAE861E<B!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG
M<F]U;F0Z(",Q,S8X-C4["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C9F9F
M.PI]"BYS;6%L;&AE861E<B!["B`@("!B86-K9W)O=6YD.B`C,3,V.#8U.PI]
M"BYC;VYT<F]L('L*("`@(&)A8VMG<F]U;F0Z("-F9F0S-C@["GT*+FET96T@
M>PH@("`@8F%C:V=R;W5N9#H@(V8T9#<Y,SL*?0HN8G5T=&]N('L*("`@(&-O
M;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V9B83(P.#L*("`@
M(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@(V8W93!A83L*("`@(&)O<F1E
M<BUR:6=H=#H@=&AI;B!S;VQI9"`C9C=E,&%A.PH@("`@8F]R9&5R+71O<#H@
M=&AI;B!S;VQI9"`C9F9D,S8X.PH@("`@8F]R9&5R+6QE9G0Z('1H:6X@<V]L
M:60@(V9F9#,V.#L*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO
M<CH@(V8U8S$T-#L*?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@
M(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R;W5N9#H@(S$S-C@V-3L*?0HC;65N
M=2!A('L*("`@(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@
M("!B86-K9W)O=6YD.B`C,C@X.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*
M(W-I9&5B87)086YE;"!["B`@("!B86-K9W)O=6YD.B`C,C@X.PI]"B-S:61E
M8F%R4&%N96P@82!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)O<F1E<CH@,7!X
M('-O;&ED(",R.#@["B`@("!P861D:6YG+6QE9G0Z(#%P>#L*("`@('!A9&1I
M;F<M8F]T=&]M.B`R<'@["GT*(W-I9&5B87)086YE;"!A.FAO=F5R('L*("`@
M(&-O;&]R.B`C,#`P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-C8SL*("`@
M(&)O<F1E<CH@,7!X('-O;&ED(",P,#`["B`@("!T97AT+61E8V]R871I;VXZ
M(&YO;F4["GT*"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J+PHN<')E9G-/
M=F5R=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F9CL*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V)R;W=N+VEN9F\N<&AP````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<P(#$P
M-3$U-#,T,30U(#`R,38Q,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T:&5M
M97,O8G)O=VXO:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS,SHS-"!M
M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*")"<F]W;B(I.PH`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1H96UE<R]B<F]W;B]S8W)E96XN8W-S````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4R-"`Q,#4Q-30S-#$T-2`P
M,C(Q-#4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+V)R;W=N+W-C<F5E;BYC
M<W,L=B`Q+C8N-BXR(#(P,#8O,#(O,C(@,C(Z-34Z,#<@<VQU<V%R>B!%>'`@
M)`H@*B\*"F)O9'D@>PH@("`@8F%C:V=R;W5N9#H@(S4P-3`U,#L*("`@('-C
M<F]L;&)A<BUB87-E+6-O;&]R.B`C-3`U,#4P.PH@("`@<V-R;VQL8F%R+6%R
M<F]W+6-O;&]R.B`C8V9C9F)B.PI]"FAT;6P@>PH@("`@<V-R;VQL8F%R+6)A
M<V4M8V]L;W(Z(",U,#4P-3`["B`@("!S8W)O;&QB87(M87)R;W<M8V]L;W(Z
M("-C9F-F8F(["GT*82!["B`@("!C;VQO<CH@(S4P-3`U,#L*?0IA.FAO=F5R
M('L*("`@(&-O;&]R.B`C-3`U,#4P.PI]"F$N=VED9V5T.FAO=F5R('L*("`@
M(&-O;&]R.B`C-3`U,#4P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V5B96)D
M-SL*?0HN:&5A9&5R('L*("`@(&-O;&]R.B`C-3`U,#4P.PH@("`@8F%C:V=R
M;W5N9#H@(V)B83L*?0HN<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z(",U,#4P
M-3`["B`@("!B86-K9W)O=6YD.B`C8F)A.PI]"BYC;VYT<F]L('L*("`@(&)A
M8VMG<F]U;F0Z("-D961E8F(["GT*+FET96T@>PH@("`@8F%C:V=R;W5N9"UC
M;VQO<CH@(V5B96)D-SL*?0HN8G5T=&]N('L*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z(",U,#4P-3`["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN('-O;&ED(",R
M,C0["B`@("!B;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(S(R-#L*("`@(&)O
M<F1E<BUT;W`Z('1H:6X@<V]L:60@(V-F8V9B8CL*("`@(&)O<F1E<BUL969T
M.B!T:&EN('-O;&ED("-D961E8F(["B`@("!C;VQO<CH@(V9F9CL*?0HN<V5L
M96-T960@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V-D8V1C9#L*?0HN:71E
M;3$@>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V4V939D93L*?0H*+RH@365N
M=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C,#`P.PH@("`@8F%C
M:V=R;W5N9#H@(V)B83L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C
M,#`P.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O=6YD.B`C8F9B
M9F%A.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E964["B`@("!B
M;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C965E.PH@("`@8F]R9&5R+6QE9G0Z
M(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P
M,#`["B`@("!P861D:6YG.B`R<'@["GT*"B\J(%-I9&5B87(@<W1Y;&5S+B`J
M+PHC<VED96)A<E!A;F5L('L*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED
M(",P,#`["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S`P,#L*("`@
M(&)A8VMG<F]U;F0Z("-B8F$["GT*(V5X<&%N9$)U='1O;B!["B`@("!M87)G
M:6XM<FEG:'0Z(#%P>#L*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V-O<FYF
M;&]W97(O9W)A<&AI8W,`````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30U(#`R,C<R,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T:&5M97,O8V]R;F9L;W=E<B]I;F9O+G!H<```````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,#(@,3`U,34T,S0Q-#4@,#(R-C0P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]C;W)N9FQO=V5R+VEN
M9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%>'`@
M)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B0V]R;F9L;W=E<B(I.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S
M+V-O<FYF;&]W97(O<V-R965N+F-S<P``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`V-3(W(#$P-3$U-#,T,30U(#`R,S(P-0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````O*BH*("H@)$AO<F1E
M.B!H;W)D92]T:&5M97,O8V]R;F9L;W=E<B]S8W)E96XN8W-S+'8@,2XX+C8N
M-"`R,#`U+S$P+S$X(#$Q.C,T.C$S(&IA;B!%>'`@)`H@*B\*"F)O9'D@>PH@
M("`@8F%C:V=R;W5N9#H@(V9F9CL*("`@(&9O;G0M9F%M:6QY.B!697)D86YA
M+"!'96YE=F$L($%R:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68["GT*82![
M"B`@("!C;VQO<CH@(S,S.3L*?0IA+F9I>&5D('L*("`@(&-O;&]R.B`C,S,Y
M.PI]"F$N=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"FEN<'5T('L*("`@
M(&9O;G0M9F%M:6QY.B!697)D86YA+"!'96YE=F$L($%R:6%L+"!(96QV971I
M8V$L('-A;G,M<V5R:68["B`@("!B86-K9W)O=6YD.B`C9F9F.PH@("`@8F]R
M9&5R.B`Q<'@@<V]L:60@(S8V-CL*?0IT97AT87)E82!["B`@("!C;VQO<CH@
M(S,S,SL*("`@(&)A8VMG<F]U;F0Z("-F9F8["B`@("!B;W)D97(Z(#%P>"!S
M;VQI9"`C-C8V.PI]"G-E;&5C="QO<'1I;VX@>PH@("`@8V]L;W(Z(",P,#`P
M,S,["B`@("!B86-K9W)O=6YD.B`C9F-F8V9C.PI]"@HO*B!3:61E8F%R('-T
M>6QE<RX@*B\*(W-I9&5B87)086YE;"!["B`@("!B;W)D97(M<FEG:'0Z(#%P
M>"!S;VQI9"`C,#`V.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",P
M,#8["B`@("!B86-K9W)O=6YD.B`C9C-F-V8X.PI]"B-S:61E8F%R4&%N96P@
M82!["B`@("!B;W)D97(Z(#%P>"!S;VQI9"`C9C-F-V8X.PH@("`@<&%D9&EN
M9RUL969T.B`Q<'@["B`@("!P861D:6YG+6)O='1O;3H@,G!X.PI]"B-S:61E
M8F%R4&%N96P@83IH;W9E<B!["B`@("!B86-K9W)O=6YD.B`C8V-C.PH@("`@
M8F]R9&5R.B`Q<'@@<V]L:60@(S`P,#L*("`@('1E>'0M9&5C;W)A=&EO;CH@
M;F]N93L*?0HC97AP86YD0G5T=&]N('L*("`@(&UA<F=I;BUR:6=H=#H@,7!X
M.PI]"@HO*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8F%C:V=R;W5N
M9#H@(V-C8V-E-3L*("`@(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C,#`V
M.PH@("`@8V]L;W(Z(",P,#`["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(S`P
M,#L*("`@(&9O;G0M9F%M:6QY.B!697)D86YA+$AE;'9E=&EC82QS86YS+7-E
M<FEF.PH@("`@9F]N="US:7IE.B`Q,7!X.PH@("`@9F]N="UW96EG:'0Z(&YO
M<FUA;#L*?0HC;65N=2!A.FAO=F5R('L*("`@(&-O;&]R.B`C9F9F.PH@("`@
M8F]R9&5R.B!N;VYE.PH@("`@<&%D9&EN9SH@,W!X.PI]"B-M96YU(&$N8W5R
M<F5N="!["B`@("!B86-K9W)O=6YD.B`C9C-F-V8X.PH@("`@8F]R9&5R+6)O
M='1O;3H@,7!X('-O;&ED("-D9&0["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S
M;VQI9"`C9&1D.PH@("`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P.PH@
M("`@8F]R9&5R+71O<#H@,7!X('-O;&ED(",P,#`["B`@("!P861D:6YG.B`R
M<'@["GT*(VUE;G4@82YC=7)R96YT.FAO=F5R('L*("`@(&-O;&]R.B`C,#`P
M.PH@("`@<&%D9&EN9SH@,G!X.PI]"@HN:&5A9&5R('L*("`@(&-O;&]R.B`C
M,S,S.PH@("`@8F%C:V=R;W5N9#H@(V-C8V-E-3L*("`@(&)O<F1E<BUB;W1T
M;VTZ(#%P>"!S;VQI9"`C,S,Y.PI]"F$N:&5A9&5R.FAO=F5R('L*("`@(&-O
M;&]R.B`C,#-C.PH@("`@=&5X="UD96-O<F%T:6]N.B!N;VYE.PI]"F$N:&5A
M9&5R('L*("`@(&)O<F1E<BUB;W1T;VTZ(&YO;F4["B`@("!B86-K9W)O=6YD
M+6EM86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9#H@=')A;G-P87)E;G0["GT*
M+FQI9VAT('L*("`@(&-O;&]R.B`C,S,S.PI]"BYS;6%L;&AE861E<B!["B`@
M("!B86-K9W)O=6YD+6EM86=E.B!N;VYE.PH@("`@8F%C:V=R;W5N9#H@=')A
M;G-P87)E;G0["B`@("!C;VQO<CH@(S,S,SL*("`@(&9O;G0M9F%M:6QY.B!6
M97)D86YA+$AE;'9E=&EC82QS86YS+7-E<FEF.PH@("`@9F]N="US:7IE.B`Q
M,7!X.PI]"BYS;6%L;&AE861E<B!A('L*("`@(&-O;&]R.B`C,S,Y.PI]"F$N
M<VUA;&QH96%D97(Z:&]V97(@>PH@("`@8V]L;W(Z(",P,V,["GT*+F-O;G1R
M;VP@>PH@("`@8F%C:V=R;W5N9#H@(V1D9#L*?0HN:71E;2!["B`@("!B86-K
M9W)O=6YD.B`C93EE.64Y.PI]"B\J($%L=&5R;F%T:6YG('-T>6QE<RX@:71E
M;3`L(&ET96TQ(&%R92!D97!R96-A=&5D+B`J+PHN<F]W179E;BP@+FET96TP
M('L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G)O=T]D9"P@+FET96TQ('L*
M("`@(&)A8VMG<F]U;F0Z("-F9F8["GT*+F)U='1O;B!["B`@("!C;VQO<CH@
M(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-C8V,["B`@("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S,S,SL*("`@(&)O<F1E<BUR:6=H=#H@,7!X('-O;&ED
M(",P,#`["B`@("!B;W)D97(M;&5F=#H@,7!X('-O;&ED("-C-&,T8C@["B`@
M("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(V,T8S1B.#L*("`@("UM;WHM8F]R
M9&5R+7)A9&EU<SH@-7!X.PI]"BYB=71T;VXZ:&]V97(@>PH@("`@8F%C:V=R
M;W5N9#H@(V-D9CL*?0HN<V5L96-T960@>PH@("`@8F%C:V=R;W5N9#H@(V,V
M9#-F9CL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E="!["B`@("!B86-K
M9W)O=6YD.B`C9F9F('5R;"@B9W)A<&AI8W,O=&%B7V)O='1O;2YG:68B*2!R
M97!E870M>"!B;W1T;VT["B`@("!F;VYT+7-I>F4Z(#$Q<'@["GT*+G1A8G-E
M="!L:2!["B`@("!M87)G:6XZ(#`["B`@("!B86-K9W)O=6YD.B!U<FPH(F=R
M87!H:6-S+W1A8E]R:6=H="YG:68B*2!N;RUR97!E870@<FEG:'0@=&]P.PI]
M"BYT86)S970@;&D@82P@+G1A8G-E="!L:2!A.FAO=F5R('L*("`@(&)A8VMG
M<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T
M(&QE9G0@=&]P.PH@("`@;6%R9VEN.B`P.PH@("`@<&%D9&EN9SH@,W!X(#$U
M<'@["B`@("!C;VQO<CH@(S<V-3L*("`@(&)O<F1E<CH@;F]N93L*("`@(&)O
M<F1E<BUB;W1T;VTZ(#%P>"!S;VQI9"`C-S8U.PI]"BYT86)S970@;&D@83IH
M;W9E<B!["B`@("!C;VQO<CH@(S,S,SL*("`@(&)A8VMG<F]U;F0Z('5R;"@B
M9W)A<&AI8W,O=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@=&]P.PI]
M"BYT86)S970@;&DN86-T:79E5&%B('L*("`@(&)A8VMG<F]U;F0Z('5R;"@B
M9W)A<&AI8W,O=&%B7W)I9VAT+F=I9B(I(&YO+7)E<&5A="!R:6=H="!T;W`[
M"GT*+G1A8G-E="!L:2YA8W1I=F5486(@82!["B`@("!C;VQO<CH@(S,S,SL*
M("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O=&%B7VQE9G0N9VEF(BD@
M;F\M<F5P96%T(&QE9G0@=&]P.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED("-F9F8["GT*+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@
M("!C;VQO<CH@(SDY.3L*("`@(&)A8VMG<F]U;F0Z('5R;"@B9W)A<&AI8W,O
M=&%B7VQE9G0N9VEF(BD@;F\M<F5P96%T(&QE9G0@=&]P.PH@("`@8F]R9&5R
M+6)O='1O;3H@,7!X('-O;&ED("-F9F8["GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE
M<R]C;W)N9FQO=V5R+V=R87!H:6-S+W1A8E]B;W1T;VTN9VEF````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#(P,2`Q,#4Q-30S-#$T-2`P,C4V,30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````1TE&.#EA%``!`(0@
M`-WCU=OAT_[^_O+T[N;IX-K@TOS\_/7W\OGY]^KMY.#DUN7HWN[QZNWPZ>_R
MZ^+EVOCX]O?W]?/U\.GLX_KZ^/O[^^ONYW=F5>/FV^3GW?W]_>SOZ.'DV?'S
M[N#CV.CKXBP`````%``!```%!N`ECF19A@`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V]R;F9L;W=E
M<B]G<F%P:&EC<R]T86)?<FEG:'0N9VEF````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$W,S`@,3`U,34T,S0Q-#4@,#(U-#,U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$=)1C@Y89`!E@"$$`#"RLV]R];"T-K,
MU]_1W./>YNK>YNOF[?#M\O3Q]OGO]_KR]OGS]_CU]OCU]_GS^/O_________
M______________________________________________________\L````
M`)`!E@``!?X@((YD:9YHJJYLZ[YP+,]T;=]XKN]O(!`.B%!!+!J/R*1RR6PZ
MG]"H=$JM6J_8K';+[48=AD&@($R8S^BT>LUNN]_PN'Q.K]OO^+Q^S^_[_W,.
M@@<!!A`/B(F*BXR-CH^0D9*3E)66EYB9FIN<G9Z?H*&5@H,!#@NHJ:JKK*VN
MK["QLK.TM;:WN+FZN[R]OK_`P;6D@@,$#,C)RLO,S<[/T-'2T]35UM?8V=K;
MW-W>W^#AU<1@`N+GZ.GJZ^SM[N_PZ.0(`0WV]_CY^OO\_?[_``,*'$BPH,&#
M"!,J7,BPH<.'`\DY"!"OHL6+&#-JW,B1F42*'4.*'$FRI,EV'_Y/JES)LJ7+
MCBE?RIQ)LZ;-:#%OZMS)L^?&G#Z#"AU*5!O0HDB3*AUZ=*G3IU!9-HU*M:I5
MBU.O:MW*U5O6KF##BL4Y<:S9LVB3"0*9MJW;JVO?RIWK-"[=NWA]VLW+MZ_,
MO7X#"R8)>+#APQ<+(U[,6)WBQI`C<WLLN;)E:90O:]Z,+#/GSY(]@QZ]6#3I
MTX)-HUZ=5S7KUW)=PYZ-5C;MVV%MX]ZM53?OWU%]`Q^N5#CQXTS+(E\.5SGS
MYU"-0Y_^USGUZ\G98M_>4SKW[R&]@Q^?43SY\_',HU_/3CW[]^?<PY_OU3K]
M^XGMX]__3C[__V1I!^"`\NA'X('U"?Z(X(+;^,?@@`X^^%^$$NY'887W78CA
M?!IN^%Z''JX'8HCGC4CB>":>^%V**F['8HO7O0CC=#+.^%R--BZ'8X['[<CC
M<#[^^%N00NY&9)&W'8GD;$HN^5J33JX&992G34GE:%9>^5F66F[&99>7?0EF
M96*.&5F99C:&9IJE&<@F>VN^:5B<<J;F9IWDT8EG7WKNV=J=?G+79Z!T#4IH
M;(`>2IVABK;%:*.U)0HI<X]..E:EEN8F::;$8<HI5YY^VMNFHO(6:JE5G8IJ
M<*2N2INJKM;5:JQ/SDJKE+;>6F6NNF+):Z];_@JLE\(.&V:QQI*);+)G+LNL
MFLX^VZ:"TF#B2FVUNUZ+K:_:;AMLM]X2"VZXQXY+KK+FGMMLNNI"RVZ[T\++
MK;R@P4KO2O;>>U*^^I;$;[\C_0MP>-$.G);`!O]4<,)F(<PP1@X_C-7"$H,5
M<<7P7(RQ.QIOW-Y$(0``.P``````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O8V]R
M;F9L;W=E<B]G<F%P:&EC<R]T86)?;&5F="YG:68`````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S,#,@,3`U,34T,S0Q-#4@,#(U,C0U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y80<`E@#C`P"ZR=3M
M\O38X>?____&T]S<Y.GS]_C#T-K*UMW>YNOR]O?0V^*^S-?CZ>W_______\L
M``````<`E@``!'APR%$(D(&1%(9BA2(.AV"<1G,HJ+$LK8&8+5+$-G[7.YKS
MNB!PZ.N=?D5ADG@TRIS(IE+*?$ZMU2AVR:5VM]XP>*PM0\]7<QJ=97_5[;4\
M3G^[Q7#[7%_'W\E_>7Y[@WV`A(>&@HE\C86.C(^2D92+EH&8B)>:?Q$`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+TYE6%1G<F5Y+VEN9F\N
M<&AP````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<R
M(#$P-3$U-#,T,30U(#`R,C$W,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]T
M:&5M97,O3F585&=R97DO:6YF;RYP:'`L=B`Q+C$@,C`P-"\Q,"\Q-R`Q.3HS
M,SHS,R!M9&IU:VEC($5X<"`D"B`J+PH*)'1H96UE7VYA;64@/2!?*").95A4
M(BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1H96UE<R].95A49W)E>2]S8W)E96XN8W-S````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(R,B`Q,#4Q-30S-#$T
M-2`P,C(U,38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S+TYE6%1G<F5Y+W-C
M<F5E;BYC<W,L=B`Q+C8N-BXS(#(P,#4O,3`O,3@@,3$Z,S0Z,3`@:F%N($5X
M<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C-#0T.PH@("`@<V-R
M;VQL8F%R+6)A<V4M8V]L;W(Z("-A8V$Y86,["B`@("!S8W)O;&QB87(M87)R
M;W<M8V]L;W(Z("-A8V$Y86,["GT*:'1M;"!["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(V%C83EA8SL*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(V%C83EA8SL*?0IA+"!A+F9I>&5D('L*("`@(&-O;&]R.B`C,S,Y.PI]"F$N
M=VED9V5T('L*("`@(&-O;&]R.B`C,#`P.PI]"F$N=VED9V5T.FAO=F5R('L*
M("`@(&-O;&]R.B!W:&ET93L*("`@(&)A8VMG<F]U;F0Z("-C8V,["GT*+FAE
M861E<B!["B`@("!C;VQO<CH@(SEF.69A,#L*("`@(&)A8VMG<F]U;F0Z(",P
M,#`["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C.68Y9F$P.PI]"BYS;6%L
M;&AE861E<B!["B`@("!C;VQO<CH@(SEF.69A,#L*("`@(&)A8VMG<F]U;F0Z
M(",P,#`["GT*+F)U='1O;B!["B`@("!C;VQO<CH@(S`P,#L*("`@(&)A8VMG
M<F]U;F0M8V]L;W(Z("-A8V$Y86,["B`@("!B;W)D97(M8F]T=&]M.B!T:&EN
M('-O;&ED(",R,C(["B`@("!B;W)D97(M<FEG:'0Z('1H:6X@<V]L:60@(S(R
M,CL*("`@(&)O<F1E<BUT;W`Z('1H:6X@<V]L:60@(V1D9#L*("`@(&)O<F1E
M<BUL969T.B!T:&EN('-O;&ED("-D9&0["GT*+G-E;&5C=&5D('L*("`@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-A8V$Y86,["GT*"B\J($UE;G4@<W1Y;&5S+B`J
M+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-A8V$Y86,["GT*(VUE;G4@:#$@>PH@("`@8V]L;W(Z(",P,#`["GT*
M(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A+F-U<G)E;G0@
M>PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S@W.#<X-SL*("`@(&-O;&]R.B`C
M9&1D.PI]"@HO*B!3:61E8F%R('-T>6QE<RX@*B\*(W-I9&5B87)086YE;"![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C.3DY.PH@("`@8F]R9&5R+7)I9VAT
M.B`Q<'@@<V]L:60@(S(R,CL*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S;VQI
M9"`C,C(R.PI]"B-E>'!A;F1"=71T;VX@>PH@("`@;6%R9VEN+7)I9VAT.B`Q
M<'@["GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=R
M97DO:6YF;RYP:'``````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,38V(#$P-3$U-#,T,30U(#`R,30S-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]T:&5M97,O9W)E>2]I;F9O+G!H<"QV(#$N,2`R,#`T+S$P
M+S$W(#$Y.C,S.C,V(&UD:G5K:6,@17AP("0*("HO"@HD=&AE;65?;F%M92`]
M(%\H(D=R97DB*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1H96UE<R]G<F5Y+W-C<F5E;BYC
M<W,`````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S$R
M,"`Q,#4Q-30S-#$T-2`P,C$W-34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+RHJ"B`J("1(;W)D93H@:&]R9&4O=&AE;65S
M+V=R97DO<V-R965N+F-S<RQV(#$N-RXV+C$S(#(P,#4O,3`O,3@@,3$Z,S0Z
M,3@@:F%N($5X<"`D"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C-60U
M9#8P.PH@("`@<V-R;VQL8F%R+6)A<V4M8V]L;W(Z(",U9#5D-C`["B`@("!S
M8W)O;&QB87(M87)R;W<M8V]L;W(Z(",U9#5D-C`["GT*:'1M;"!["B`@("!S
M8W)O;&QB87(M8F%S92UC;VQO<CH@(S5D-60V,#L*("`@('-C<F]L;&)A<BUA
M<G)O=RUC;VQO<CH@(S5D-60V,#L*?0IA('L*("`@(&-O;&]R.B`C-3DU.34Y
M.PI]"BYW:61G970@>PH@("`@8V]L;W(Z(",S,S,["B`@("!F;VYT+7=E:6=H
M=#H@8F]L9#L*?0IA+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(S`P,#L*
M("`@(&)A8VMG<F]U;F0Z("-D9&0["B`@("!T97AT+61E8V]R871I;VXZ(&YO
M;F4["GT*+FAE861E<B!["B`@("!C;VQO<CH@(V1D9#L*("`@(&)A8VMG<F]U
M;F0Z(",U-#4T-38["GT*+FAE861E<B!A('L*("`@(&-O;&]R.B`C9&1D.PI]
M"F$N;&EG:'0Z:&]V97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+G-M86QL:&5A
M9&5R('L*("`@(&-O;&]R.B`C.68Y9F$P.PH@("`@8F%C:V=R;W5N9#H@(S4T
M-30U-CL*?0HN8G5T=&]N('L*("`@(&-O;&]R.B`C9F9F.PH@("`@8F%C:V=R
M;W5N9#H@(S4Q-3$V,SL*("`@(&)O<F1E<BUB;W1T;VTZ('1H:6X@<V]L:60@
M(S5D-60V,#L*("`@(&)O<F1E<BUR:6=H=#H@=&AI;B!S;VQI9"`C-60U9#8P
M.PH@("`@8F]R9&5R+71O<#H@=&AI;B!S;VQI9"`C-S<W-S@Y.PH@("`@8F]R
M9&5R+6QE9G0Z('1H:6X@<V]L:60@(S<W-S<X.3L*?0HN:71E;2!["B`@("!C
M;VQO<CH@(S`P,#L*("`@(&)A8VMG<F]U;F0Z("-E964["GT*+G-E;&5C=&5D
M('L*("`@(&)A8VMG<F]U;F0Z("-D9&0["GT*"B\J($UE;G4@<W1Y;&5S+B`J
M+PHC;65N=2!["B`@("!C;VQO<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",U
M-#4T-38["GT*(VUE;G4@82!["B`@("!C;VQO<CH@(V9F9CL*?0HC;65N=2!A
M+F-U<G)E;G0@>PH@("`@8F%C:V=R;W5N9#H@(S8V-CL*?0H*+RH@4VED96)A
M<B!S='EL97,N("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@
M(S8V-CL*?0HC<VED96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82![
M"B`@("!C;VQO<CH@(V9F9CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@
M("`@8V]L;W(Z('EE;&QO=SL*?0H*+RH@5&%B('-T>6QE<RX@*B\*+G1A8G-E
M="!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S4T-30U-CL*?0HN
M=&%B<V5T(&QI(&$@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U
M-#4T-38["B`@("!B86-K9W)O=6YD.B`C93EE.64Y.PI]"BYT86)S970@;&DN
M86-T:79E5&%B(&$@>PH@("`@8V]L;W(Z("-D9&0["B`@("!B86-K9W)O=6YD
M.B`C-30U-#4V.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(",U-#4T
M-38["GT*+G1A8G-E="!L:2YA8W1I=F5486(@83IH;W9E<B!["B`@("!C;VQO
M<CH@(V9F9CL*("`@(&)A8VMG<F]U;F0Z(",U-#4T-38["GT*"B\J(%!R969E
M<F5N8V5S(&]V97)V:65W+B`J+PHN<')E9G-/=F5R=FEE=R!H,B!["B`@("!C
M;VQO<CH@(V9F9CL*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O87IU<B]I;F9O+G!H<```````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R-3`@,3`U
M,34T,S0Q-#4@,#(Q-#0T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE
M<R]A>G5R+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S,@;61J
M=6MI8R!%>'`@)"`_/@H@*@H@*B!`875T:&]R($IO;W-T($1E($-O8VL@/&IO
M;W-T0&1E8V]C:RYO<F<^"B`J+PH*)'1H96UE7VYA;64@/2!?*")!>G5R(BD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&AE;65S+V%Z=7(O<V-R965N+F-S<P``````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#<W(#$P-3$U-#,T,30U(#`R
M,C`P-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@075T:&]R.B!*;V]S="!$92!#;V-K(#QJ;V]S=$!D96-O8VLN
M;W)G/@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]A>G5R+W-C<F5E;BYC
M<W,L=B`Q+C4N-BXU(#(P,#4O,3$O,34@,#8Z-#$Z,#(@<V5L<VMY($5X<"`D
M"B`J+PH*8F]D>2!["B`@("!B86-K9W)O=6YD.B`C-C1A-V,Y.PI]"F$@>PH@
M("`@8V]L;W(Z(",S,SD["GT*82YW:61G970Z:&]V97(@>PH@("`@8V]L;W(Z
M(",V-C8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C9F9F.PI]"BYH96%D97(@
M>PH@("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C,#8Y.PI]"BYH
M96%D97(@82!["B`@("!C;VQO<CH@(V9F9CL*?0HN<VUA;&QH96%D97(@>PH@
M("`@8V]L;W(Z("-F9F8["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PI]
M"F$N<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F9F8["GT*+F)U='1O;B![
M"B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S(R-#L*("`@(&)O<F1E
M<BUR:6=H=#H@,7!X('-O;&ED(",R,C0["B`@("!B;W)D97(M=&]P.B`Q<'@@
M<V]L:60@(SDY8SL*("`@(&)O<F1E<BUL969T.B`Q<'@@<V]L:60@(SDY8SL*
M?0H*+RH@365N=2!S='EL97,N("HO"B-M96YU('L*("`@(&-O;&]R.B`C9F9F
M.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(S`V.3L*?0HC;65N=2!A('L*("`@
M(&-O;&]R.B`C9F9F.PI]"B-M96YU(&$N8W5R<F5N="!["B`@("!B86-K9W)O
M=6YD.B`C-C1A-V,Y.PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED("-E
M964["B`@("!B;W)D97(M<FEG:'0Z(#%P>"!S;VQI9"`C965E.PH@("`@8F]R
M9&5R+6QE9G0Z(#%P>"!S;VQI9"`C,#`P.PH@("`@8F]R9&5R+71O<#H@,7!X
M('-O;&ED(",P,#`["B`@("!P861D:6YG.B`R<'@["GT*(VUE;G4@83IH;W9E
M<B!["B`@("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(V5E93L*("`@(&)O
M<F1E<BUR:6=H=#H@,7!X('-O;&ED("-E964["B`@("!B;W)D97(M;&5F=#H@
M,7!X('-O;&ED(",P,#`["B`@("!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(S`P
M,#L*("`@('!A9&1I;F<Z(#)P>#L*?0H*+RH@4VED96)A<B!S='EL97,N("HO
M"B-S:61E8F%R4&%N96P@>PH@("`@8F]R9&5R+6-O;&]R.B!T<F%N<W!A<F5N
M=#L*("`@(&)A8VMG<F]U;F0M8V]L;W(Z("-B8V0V93(["GT*"B\J(%1A8B!S
M='EL97,N("HO"BYT86)S970@;&DN86-T:79E5&%B(&$L("YT86)S970@;&DN
M86-T:79E5&%B(&$Z:&]V97(@>PH@("`@8F]R9&5R+6)O='1O;3H@,7!X('-O
M;&ED(",P-CD["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C,#8Y.PI]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T:&5M97,O9V5N;F5V
M:6QL:65R<R]I;F9O+G!H<```````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`W,30@,3`U,34T,S0Q-#4@,#(S,S,V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES('1H
M96UE(&%S(&)E96X@=W)I='1E;B!B>2!!:61E($9L;W)E;G0@/&9A:61E0&%L
M<&AA8V5N="YC;VT^(&%N9`H@*B!-Z6QA;FEE($=A<F5A=2`\;65L86YI92YG
M87)E875`=FEL;&4M9V5N;F5V:6QL:65R<RYF<CX*("H*("H@5&AE('1H96UE
M(&ED96$@=V%S('1O(&EN8V]R<&]R871E('-M;V]T:&QY(&EN('1H92!I;G1R
M86YE="X*("H@5&AI<R!T:&5M92!I<R!P=6)L:7-H960@=6YD97(@=&AE('-A
M;64@;&EC96YS92!A<R!T:&4@:&]R9&4@<&%C:V%G92X*("H*("H@5&AE(&YA
M;64@8V]M97,@9G)O;2!T:&4@8VET>2!O9B!'96YN979I;&QI97)S(&EN($9R
M86YC90H@*@H@*B`D2&]R9&4Z(&AO<F1E+W1H96UE<R]G96YN979I;&QI97)S
M+VEN9F\N<&AP+'8@,2XQ(#(P,#0O,3`O,3<@,3DZ,S,Z,S4@;61J=6MI8R!%
M>'`@)`H@*B\*"B1T:&5M95]N86UE(#T@7R@B5&5A;"(I.PH`````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O<V-R
M965N+F-S<P``````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C8U(#$P
M-3$U-#,T,30U(#`R,S8W,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````O*BH*("H@5&AI<R!T:&5M92!A<R!B965N('=R:71T
M96X@8GD@06ED92!&;&]R96YT(#QF86ED94!A;'!H86-E;G0N8V]M/B!A;F0*
M("H@3<.I;&%N:64@1V%R96%U(#QM96QA;FEE+F=A<F5A=4!V:6QL92UG96YN
M979I;&QI97)S+F9R/@H@*@H@*B!4:&4@=&AE;64@:61E82!W87,@=&\@:6YC
M;W)P;W)A=&4@<VUO;W1H;'D@:6X@=&AE(&EN=')A;F5T+@H@*B!4:&ES('1H
M96UE(&ES('!U8FQI<VAE9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H
M92!H;W)D92!P86-K86=E+@H@*@H@*B!4:&4@;F%M92!C;VUE<R!F<F]M('1H
M92!C:71Y(&]F($=E;FYE=FEL;&EE<G,@:6X@1G)A;F-E"B`J"B`J("1(;W)D
M93H@:&]R9&4O=&AE;65S+V=E;FYE=FEL;&EE<G,O<V-R965N+F-S<RQV(#$N
M-2XV+C,@,C`P-2\Q,"\Q."`Q,3HS-#HQ,R!J86X@17AP("0*("HO"@IB;V1Y
M('L*("`@(&)A8VMG<F]U;F0Z(",P,#8S-C,["B`@("!S8W)O;&QB87(M8F%S
M92UC;VQO<CH@(S8S8C5B-3L*("`@('-C<F]L;&)A<BUA<G)O=RUC;VQO<CH@
M(S8S8C5B-3L*?0IH=&UL('L*("`@('-C<F]L;&)A<BUB87-E+6-O;&]R.B`C
M-C-B-6(U.PH@("`@<V-R;VQL8F%R+6%R<F]W+6-O;&]R.B`C-C-B-6(U.PI]
M"F$@>PH@("`@8V]L;W(Z(",Q,C)E8F$["GT*83IH;W9E<B!["B`@("!C;VQO
M<CH@(S$R,F5B83L*?0IA+G=I9&=E="!["B`@("!C;VQO<CH@(S`P,#L*?0IA
M+G=I9&=E=#IH;W9E<B!["B`@("!C;VQO<CH@(V9F9CL*?0HN:&5A9&5R+"`N
M<VUA;&QH96%D97(L(&$N<VUA;&QH96%D97(@>PH@("`@8V]L;W(Z("-F9F8[
M"B`@("!B86-K9W)O=6YD.B`C-C-B-6(U.PI]"BYB=71T;VX@>PH@("`@8V]L
M;W(Z("-F9F8["B`@("!B86-K9W)O=6YD.B`C-#$X93AE.PH@("`@8F]R9&5R
M+6)O='1O;3H@=&AI;B!S;VQI9"`C-C`U.34Y.PH@("`@8F]R9&5R+7)I9VAT
M.B!T:&EN('-O;&ED(",V,#4Y-3D["B`@("!B;W)D97(M=&]P.B!T:&EN('-O
M;&ED("-C96-E8V4["B`@("!B;W)D97(M;&5F=#H@=&AI;B!S;VQI9"`C9F9F
M.PI]"BYS96QE8W1E9"!["B`@("!B86-K9W)O=6YD.B`C-C-B-6(U.PI]"@HO
M*B!-96YU('-T>6QE<RX@*B\*(VUE;G4@>PH@("`@8V]L;W(Z("-F9F8["B`@
M("!B86-K9W)O=6YD.B`C-C-B-6(U.PI]"B-M96YU(&$@>PH@("`@8V]L;W(Z
M("-F9F8["GT*(VUE;G4@82YC=7)R96YT('L*("`@(&)A8VMG<F]U;F0Z(",T
M,3AE.&4["B`@("!C;VQO<CH@(V9F9CL*?0H*+RH@4VED96)A<B!S='EL97,N
M("HO"B-S:61E8F%R4&%N96P@>PH@("`@8F%C:V=R;W5N9#H@(S8S8C5B-3L*
M?0HC<VED96)A<E!A;F5L('-P86XL("-S:61E8F%R4&%N96P@82!["B`@("!C
M;VQO<CH@(V9F9CL*?0HC<VED96)A<E!A;F5L(&$Z:&]V97(@>PH@("`@8V]L
M;W(Z("-F9F8["GT*"B\J(%!R969E<F5N8V5S(&]V97)V:65W+B`J+PHN<')E
M9G-/=F5R=FEE=R!H,B!["B`@("!C;VQO<CH@(V9F9CL*?0H`````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O;&]G:6X`````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#0@,#(P-38S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]H96QP````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T-"`P,C`T,#,`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VUE
M;G4`````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30T(#`R,#0Q-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O=&5S=```````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#0@,#(P-#,R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M86EN=&5N86YC90``
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T-"`P,C$W,S4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+V%D;6EN````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30T(#`R,#4T,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O:6YD97@`````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#0@
M,#(P-38R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]S:&%R97,`
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$T-"`P,C`W-#``(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M=&5M<&QA=&5S+W!R969S````````````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30T(#`R,#4W,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T80``````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q-#0@,#(P,S8T`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]C
M;VYT96YT<P``````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-"`P,C$S,3``(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0`````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30U(#`R,38R
M,@`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q-#4@,#(P-S4U`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]R<&-S=6T`````````````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-2`P,C`W-C4`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R;V)L96T`````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30U
M(#`R,3$Q-``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O8V]M;6]N
M+69O;W1E<BYI;F,`````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$P,S,@,3`U,34T,S0Q-#4@,#(S,#`W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QS8W)I<'0@;&%N9W5A9V4](DIA=F%3
M8W)I<'0Q+C4B('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*=F%R(%]S
M971(;W)D951I=&QE(#T@,3L*=')Y('L*("`@(&EF("AD;V-U;65N="YT:71L
M92`F)B!P87)E;G0N9G)A;65S+FAO<F1E7VUA:6XI('!A<F5N="YD;V-U;65N
M="YT:71L92`](&1O8W5M96YT+G1I=&QE.PI](&-A=&-H("AE*2!["GT*+R\@
M+2T^"CPO<V-R:7!T/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"CPA+2T*:68@*'1Y<&5O9BA?<V5T2&]R9&54:71L92D@/3T@)W5N9&5F:6YE
M9"<@)B8@9&]C=6UE;G0N=&ET;&4@)B8@<&%R96YT+F9R86UE<RYH;W)D95]M
M86EN*2!P87)E;G0N9&]C=6UE;G0N=&ET;&4@/2!D;V-U;65N="YT:71L93L*
M+R\@+2T^"CPO<V-R:7!T/@H\/W!H<"!I9B`H:7-S970H)$=,3T)!3%-;)VYO
M=&EF:6-A=&EO;B==*2D@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@87)R87DH)VIA=F%S8W)I<'0G*2DI
M.R`_/@H\+V)O9'D^"CPO:'1M;#X*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M8V]M;6]N+6AE861E<BYI;F,`````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(W-C8@,3`U,34T,S0Q-#4@,#(R-S4W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"F=L;V)A;"`D;&%N
M9W5A9V4["FEF("AI<W-E="@D;&%N9W5A9V4I*2!["B`@("!H96%D97(H)T-O
M;G1E;G0M='EP93H@=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("!H96%D97(H)U9A<GDZ($%C8V5P="U,86YG=6%G92<I
M.PI]"C\^"CPA1$]#5%E012!H=&UL(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A4
M34P@,2XP(%1R86YS:71I;VYA;"\O14XB(")$5$0O>&AT;6PQ+71R86YS:71I
M;VYA;"YD=&0B/@H\(2TM($AO<F1E.B!#;W!Y<FEG:'0@,C`P,"TR,#`V+"!4
M:&4@2&]R9&4@4')O:F5C="X@2&]R9&4@:7,@=6YD97(@=&AE($Q'4$PN("TM
M/@H\(2TM("`@("`@("`@("`@("`@("`@("!(;W)D92!0<F]J96-T.B!H='1P
M.B\O:&]R9&4N;W)G+R`@("`@("`@("`@("`@("`@("`@("TM/@H\(2TM("`@
M($=.52!,:6)R87)Y(%!U8FQI8R!,:6-E;G-E.B!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL("`@("TM/@H\/W!H<`IE8VAO("@A96UP
M='DH)&QA;F=U86=E*2D@/R`G/&AT;6P@;&%N9STB)R`N('-T<G1R*"1L86YG
M=6%G92P@)U\G+"`G+2<I("X@)R(G(#H@)SQH=&UL)SL*96-H;R`H(65M<'1Y
M*"1I95]C;&EE;G1C87!S*2D@/R`G('AM;&YS.DE%/B<@.B`G/B<["C\^"CQH
M96%D/@H\/W!H<`H*)'!A9V5?=&ET;&4@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=N86UE)RD["FEF("@A96UP='DH)'1I=&QE*2D@)'!A9V5?=&ET
M;&4@+CT@)R`Z.B`G("X@)'1I=&QE.PII9B`H(65M<'1Y*"1R969R97-H7W1I
M;64I("8F("%E;7!T>2@D<F5F<F5S:%]U<FPI*2!["B`@("!E8VAO("(\;65T
M82!H='1P+65Q=6EV/5PB<F5F<F5S:%PB(&-O;G1E;G0]7"(D<F5F<F5S:%]T
M:6UE.W5R;#TD<F5F<F5S:%]U<FQ<(B`O/EQN(CL*?0H*2&]R9&4Z.FEN8VQU
M9&538W)I<'1&:6QE<R@I.PH_/@H\=&ET;&4^/#]P:'`@96-H;R!H=&UL<W!E
M8VEA;&-H87)S*"1P86=E7W1I=&QE*2`_/CPO=&ET;&4^"CQL:6YK(&AR968]
M(CP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER
M*"D@/SXO9F%V:6-O;BYI8V\B(')E;#TB4TA/4E1#550@24-/3B(@+SX*/#]P
M:'`@96-H;R!(;W)D93HZ<W1Y;&5S:&5E=$QI;FLH571I;#HZ;F]N26YP=716
M87(H)V-S<T%P<',G*2D@/SX*/#]P:'`@96-H;R!I;7!L;V1E*")<;B(L(%5T
M:6PZ.FYO;DEN<'5T5F%R*"=L:6YK5&%G<R<L(&%R<F%Y*"DI*2`_/@H\/W!H
M<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C87!S*2DZ(#\^/'-T>6QE/DE%7#IC
M;&EE;G1C87!S('MB96AA=FEO<CIU<FPH(V1E9F%U;'0C8VQI96YT8V%P<RE]
M/"]S='EL93X\/W!H<"!E;F1I9CL@/SX*/"]H96%D/@H*/&)O9'D\/W!H<"!I
M9B`H571I;#HZ;F]N26YP=71687(H)V)O9'E#;&%S<R<I*2!E8VAO("<@8VQA
M<W,](B<@+B`D8F]D>4-L87-S("X@)R(G.R`_/CX*/#]P:'`@:68@*"%E;7!T
M>2@D:65?8VQI96YT8V%P<RDI.B`_/CQ)13IC;&EE;G1C87!S($E$/2)O8FI#
M0V%P<R(@+SX\/W!H<"!E;F1I9CL@/SX*`````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R\N:'1A8V-E<W,`````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`Q-B`Q,#4Q-30S-#$T
M-2`P,C$S,C8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1&5N>2!F<F]M(&%L;`H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8P``````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#0T,C`@,3`U,34T,S0Q-#4@,#(S,S(V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0HO+R!#:&5C:R!A;&P@
M;V8@=&AE(&UA:6X@9F]R;2!F:65L9',@=&\@;6%K92!S=7)E('1H97D@87)E
M(&9I;&QE9"!I;@IF=6YC=&EO;B!V86QI9&%T92@I"GL*("`@(&EF("AD;V-U
M;65N="YP<F]B;&5M7W)E<&]R="YS=6)J96-T+G9A;'5E(#T]("<G*2!["B`@
M("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(BDI(#\^)RD["B`@
M("`@("`@9&]C=6UE;G0N<')O8FQE;5]R97!O<G0N<W5B:F5C="YF;V-U<R@I
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS92!I9B`H9&]C=6UE
M;G0N<')O8FQE;5]R97!O<G0N;65S<V%G92YV86QU92`]/2`G)RD@>PH@("`@
M("`@(&%L97)T*"<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N(BDI(#\^)RD["B`@("`@("`@9&]C=6UE;G0N<')O
M8FQE;5]R97!O<G0N;65S<V%G92YF;V-U<R@I.PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("!D;V-U;65N="YP<F]B;&5M7W)E<&]R="YA8W1I
M;VY)1"YV86QU92`]("=S96YD7W!R;V)L96U?<F5P;W)T)SL*("`@(')E='5R
M;B!T<G5E.PI]"B\O+2T^"CPO<V-R:7!T/@H*/&9O<FT@;65T:&]D/2)P;W-T
M(B!N86UE/2)P<F]B;&5M7W)E<&]R="(@86-T:6]N/2)P<F]B;&5M+G!H<"(^
M"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED
M9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](F-A;F-E;%]P<F]B;&5M7W)E
M<&]R="(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB<F5T=7)N7W5R
M;"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<RA5=&EL.CIG
M971&;W)M1&%T82@G<F5T=7)N7W5R;"<I*2`_/B(@+SX*"CQT86)L92!C96QL
M<&%D9&EN9STB,R(@8V5L;'-P86-I;F<](C(B('=I9'1H/2(Q,#`E(CX*/'1R
M(&-L87-S/2)H96%D97(B/@H@("`@/'1D(&-O;'-P86X](C(B(&-L87-S/2)H
M96%D97(B/CP_<&AP(&5C:&\@7R@B1&5S8W)I8F4@=&AE(%!R;V)L96TB*2`_
M/CPO=&0^"CPO='(^"@H\='(^"B`@("`\=&0@8VQA<W,](FQI9VAT(')I9VAT
M06QI9VXB/CP_<&AP(&5C:&\@7R@B66]U<B!.86UE(BD@/SX\+W1D/@H@("`@
M/'1D/CQI;G!U="!T>7!E/2)T97AT(B!T86)I;F1E>#TB,2(@;F%M93TB;F%M
M92(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;F%M92D@
M/SXB('-I>F4](C<P(B`O/CPO=&0^"CPO='(^"@H\='(^"B`@("`\=&0@8VQA
M<W,](FQI9VAT(')I9VAT06QI9VXB/CP_<&AP(&5C:&\@7R@B66]U<B!%;6%I
M;"!!9&1R97-S(BD@/SX\+W1D/@H@("`@/'1D/CQI;G!U="!T>7!E/2)T97AT
M(B!T86)I;F1E>#TB,B(@;F%M93TB96UA:6PB('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&5M86EL*2`_/B(@<VEZ93TB-S`B("\^/"]T
M9#X*/"]T<CX*"CQT<CX*("`@(#QT9"!C;&%S<STB;&EG:'0@<FEG:'1!;&EG
M;B(^/#]P:'`@96-H;R!?*")3:&]R="!3=6UM87)Y(BD@/SX\+W1D/@H@("`@
M/'1D/CQI;G!U="!T>7!E/2)T97AT(B!T86)I;F1E>#TB,R(@;F%M93TB<W5B
M:F5C="(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<W5B
M:F5C="D@/SXB('-I>F4](C<P(B`O/CPO=&0^"CPO='(^"@H\='(^"B`@("`\
M=&0@8V]L<W!A;CTB,B(@8VQA<W,](G-M86QL:&5A9&5R(CX\/W!H<"!E8VAO
M(%\H(D9U;&P@1&5S8W)I<'1I;VXB*2`_/CPO=&0^"CPO='(^"CQT<CX*("`@
M(#QT9#X\+W1D/@H@("`@/'1D/CQT97AT87)E82!T86)I;F1E>#TB-"(@;F%M
M93TB;65S<V%G92(@<F]W<STB,C`B(&-O;',](C@P(B!W<F%P/2)H87)D(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&UE<W-A9V4I(#\^/"]T97AT
M87)E83X\+W1D/@H\+W1R/@H*/'1R/@H@(#QT9#X\+W1D/@H@(#QT9"!C;&%S
M<STB;&EG:'0B/@H@("`@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](G-U
M8FUI="(@;F%M93TB9F]R;7-U8FUI="(@;VYC;&EC:STB<F5T=7)N('9A;&ED
M871E*"D[(B!V86QU93TB/#]P:'`@96-H;R!?*")396YD(%!R;V)L96T@4F5P
M;W)T(BD@/SXB("\^"B`@("`\:6YP=70@8VQA<W,](F)U='1O;B(@='EP93TB
M<W5B;6ET(B!N86UE/2)F;W)M<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?
M*")#86YC96P@4')O8FQE;2!297!O<G0B*2`_/B(@+SX*("`\+W1D/@H\+W1R
M/@H*/"]T86)L93X*/"]F;W)M/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,`````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8U,S,@,3`U,34T,S0Q
M-#4@,#(S,#4W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H*
M=F%R(&-A;F-E;%-U8FUI="`](&9A;'-E.PH*=F%R(&9I96QD<R`](&YE=R!!
M<G)A>2@*/#]P:'`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)')P8U]S97)V
M97)S*3L@)&DK*RDZ(#\^"B`@("!N97<@07)R87DH"B`@("`@("`@(CP_<&AP
M(&5C:&\@<F%W=7)L96YC;V1E*"1R<&-?<V5R=F5R<ULD:5U;)W5R;"==*2`_
M/B(L"B`@("`@("`@(CP_<&AP(&5C:&\@<F%W=7)L96YC;V1E*"1R<&-?<V5R
M=F5R<ULD:5U;)W5S97(G72D@/SXB"B`@("`I/#]P:'`@:68@*"1I("L@,2`\
M(&-O=6YT*"1R<&-?<V5R=F5R<RDI(&5C:&\@)RPG.R`_/@H*/#]P:'`@96YD
M9F]R.R`_/@HI.PH*9G5N8W1I;VX@;F5W0VAO:6-E*"D*>PH@("`@=F%R(&%C
M=&EO;B`](&1O8W5M96YT+G!R969S+G-E<G9E<BYO<'1I;VYS6V1O8W5M96YT
M+G!R969S+G-E<G9E<BYS96QE8W1E9$EN9&5X72YV86QU93L*"B`@("!I9B`H
M86-T:6]N(#T]("TQ*2!["B`@("`@("`@9&]C=6UE;G0N<')E9G,N<V%V92YV
M86QU92`]("<\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0W)E871E(BDI(#\^
M)SL*("`@("`@("!D;V-U;65N="YP<F5F<RYR97-E="@I.PH@("`@?2!E;'-E
M('L*("`@("`@("!D;V-U;65N="YP<F5F<RYS879E+G9A;'5E(#T@)SP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")#:&%N9V4B*2D@/SXG.PH@("`@("`@('5P
M9&%T949O<FTH86-T:6]N*3L*("`@('T*?0H*9G5N8W1I;VX@=7!D871E1F]R
M;2AS97)V97(I"GL*("`@(&1O8W5M96YT+G!R969S+F5D:71?<V5R=F5R+G9A
M;'5E(#T@<V5R=F5R.PH@("`@9&]C=6UE;G0N<')E9G,N=7)L+G9A;'5E(#T@
M9&5C;V1E55))0V]M<&]N96YT*&9I96QD<UMS97)V97)=6S!=*3L*("`@(&1O
M8W5M96YT+G!R969S+G5S97(N=F%L=64@/2!D96-O9&554DE#;VUP;VYE;G0H
M9FEE;&1S6W-E<G9E<EU;,5TI.PI]"@IF=6YC=&EO;B!C;&5A<D9O<FTH*0I[
M"B`@("!D;V-U;65N="YP<F5F<RYE9&ET7W-E<G9E<BYV86QU92`]("<G.PH@
M("`@9&]C=6UE;G0N<')E9G,N=7)L+G9A;'5E(#T@(&9I96QD<UMS97)V97)=
M6S!=.PH@("`@9&]C=6UE;G0N<')E9G,N=7-E<BYV86QU92`](&9I96QD<UMS
M97)V97)=6S%=.PH@("`@9&]C=6UE;G0N<')E9G,N<V5R=F5R+G-E;&5C=&5D
M26YD97@@/2`P.PH@("`@8V%N8V5L4W5B;6ET(#T@=')U93L*?0H*9G5N8W1I
M;VX@8VAE8VM3=6)M:70H*0I["B`@("!C86YC96P@/2!C86YC96Q3=6)M:70[
M"B`@("!C86YC96Q3=6)M:70@/2!F86QS93L*/#]P:'`@:68@*"1B<F]W<V5R
M+3YG971"<F]W<V5R*"D@/3T@)VUS:64G("8F("1B<F]W<V5R+3YG971-86IO
M<B@I(#X](#0I.B`_/@H@("`@=VEN9&]W+F5V96YT+G)E='5R;E9A;'5E(#T@
M(6-A;F-E;#L*/#]P:'`@96YD:68[(#\^"B`@("!R971U<FX@(6-A;F-E;#L*
M?0H*+R\M+3X*/"]S8W)I<'0^"@H\/W!H<"!E8VAO(%\H(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(BD@/SX\8G(@+SX*/'-E;&5C="!N86UE/2)S97)V97(B(&]N
M8VAA;F=E/2)J879A<V-R:7!T.FYE=T-H;VEC92@I(CX*("`\;W!T:6]N('9A
M;'5E/2(M,2(^/#]P:'`@96-H;R!?*")396QE8W0@82!S97)V97(B*2`_/CPO
M;W!T:6]N/@H\/W!H<"!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<G!C7W-E
M<G9E<G,I.R`K*R1I*3H@/SX*("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO
M("1I(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)')P8U]S97)V
M97)S6R1I75LG=7)L)UTI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<CL@/SX*
M/"]S96QE8W0^"CPO=&0^/"]T<CX*"CQN;W-C<FEP=#X*/"]T86)L93X\+W1D
M/CPO='(^"CQT<CX*("`\=&0@=F%L:6=N/2)M:61D;&4B/@H@("`@/&)R("\^
M"B`@("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)E9&ET(B!C;&%S<STB
M8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")%9&ET(BD@/SXB("\^"B`@
M("`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)D96QE=&4B(&-L87-S/2)B
M=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D1E;&5T92(I(#\^(B`O/@H@
M("`@/&)R("\^)FYB<W`["B`@/"]T9#X*/"]T<CX*"CQT<CX\=&0@8VQA<W,]
M(FET96TB/CQT86)L93X*/"]N;W-C<FEP=#X*"CQT<B!V86QI9VX](G1O<"(^
M/'1D(&-L87-S/2)I=&5M(CX*"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F5D:71?<V5R=F5R(B!V86QU93TB(B`O/@H\/W!H<"!E8VAO(%\H(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(I(#\^/&)R
M("\^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)U<FPB('-I>F4](C,P(B!M
M87AL96YG=&@](C8P(B`O/CQB<B`O/@H*/#]P:'`@96-H;R!?*")5<V5R;F%M
M93HB*2`_/CQB<B`O/@H\:6YP=70@='EP93TB=&5X="(@;F%M93TB=7-E<B(@
M<VEZ93TB,S`B(&UA>&QE;F=T:#TB-C`B("\^/&)R("\^"@H\/W!H<"!E8VAO
M(%\H(E!A<W-W;W)D.B(I(#\^/&)R("\^"CQI;G!U="!T>7!E/2)P87-S=V]R
M9"(@;F%M93TB<&%S<W=D(B!S:7IE/2(S,"(@;6%X;&5N9W1H/2(V,"(@+SX\
M8G(@+SX*"CPO=&0^/"]T<CX\+W1A8FQE/CPO=&0^/"]T<CX\+W1A8FQE/@H*
M/'`^"B`\:6YP=70@='EP93TB<W5B;6ET(B!N86UE/2)S879E(B!C;&%S<STB
M8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N="YP<F5F<RYA8W1I;VY)1"YV86QU
M93TG<V%V92<[(')E='5R;B!T<G5E(B!V86QU93TB/#]P:'`@96-H;R`D86-T
M:6]N240@/3T@)V5D:70G(#\@7R@B0VAA;F=E(BD@.B!?*")#<F5A=&4B*2`_
M/B(@+SXF;F)S<#L*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@ID
M;V-U;65N="YW<FET92@G/&EN<'5T('1Y<&4](G-U8FUI="(@;F%M93TB9&5L
M971E(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N="YP<F5F<RYA
M8W1I;VY)1"YV86QU93U<)V1E;&5T95PG(B!V86QU93TB/#]P:'`@96-H;R!?
M*")$96QE=&4B*2`_/B(@+SXF;F)S<#LG*3L*/"]S8W)I<'0^"B`\:6YP=70@
M='EP93TB<W5B;6ET(B!N86UE/2)N97<B(&-L87-S/2)B=71T;VXB(&]N8VQI
M8VL](F-L96%R1F]R;2@I.V1O8W5M96YT+G!R969S+G-A=F4N=F%L=64])SP_
M<&AP(&5C:&\@7R@B0W)E871E(BD@/SXG.R(@=F%L=64](CP_<&AP(&5C:&\@
M7R@B4F5S970B*2`_/B(@+SXF;F)S<#L*(#QI;G!U="!T>7!E/2)B=71T;VXB
M(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F-A;F-E;%-U8FUI=#UT<G5E.V1O
M8W5M96YT+FQO8V%T:6]N+FAR968])SP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*%5T:6PZ.F%D9%!A<F%M971E<B@G<V5R=FEC97,O<')E9G,N
M<&AP)RP@)V%P<"<L("=H;W)D92<I+"!T<G5E*2`_/B<B('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(E)E='5R;B!T;R!/<'1I;VYS(BD@/SXB("\^"CPO<#X*"CPO
M9F]R;3X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8P``````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#,Q(#$P-3$U-#,T
M,30U(#`R,C0V-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\9&EV(&ED/2)M96YU(CX*(#QH,2!C;&%S<STB;&5F=$9L;V%T
M(CX\/W!H<"!P<FEN=&8H7R@B5V5L8V]M92P@)7,B*2P@:'1M;'-P96-I86QC
M:&%R<R@D9G5L;&YA;64I*2`_/CPO:#$^"B`\9&EV(&-L87-S/2)R:6=H=$9L
M;V%T(CX*/#]P:'`*)&UE;G4@/2`F;F5W($UE;G4H*3L*)&UE;G4M/F%D9"A(
M;W)D93HZ87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"\G*2P@7R@B
M2&]?;64B*2P@)VAO<F1E+G!N9R<I.PII9B`H(21P<F5F<RT^:7-,;V-K960H
M)W!O<G1A;%]L87EO=70G*2D@>PH@("`@)&UE;G4M/F%D9"A(;W)D93HZ87!P
M;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<"<I+"!?*"),
M85]Y;W5T(BDL("=L87EO=70N<&YG)RD["GT*:68@*$%U=&@Z.FES061M:6XH
M*2D@>PH@("`@)&UE;G4M/F%D9"A(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D
M;6EN+R<I+"!?*")?061M:6YI<W1R871I;VXB*2P@)V%D;6EN:7-T<F%T:6]N
M+G!N9R<I.PI]"F5C:&\@)&UE;G4M/G)E;F1E<B@I.PH_/@H@/"]D:78^"CPO
M9&EV/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN
M8P``````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#,R(#$P
M-3$U-#,T,30U(#`R,C0U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\=&%B;&4@8VQA<W,](FYO<&%D9&EN9R(@8V5L;'-P
M86-I;F<](C8B('=I9'1H/2(Q,#`E(CX*/#]P:'`*)')O=W,@/2`D;&%Y;W5T
M+3YR;W=S*"D["FQI<W0H)&-U<G)E;G1?<F]W+"`D8W5R<F5N=%]C;VPI(#T@
M)&QA>6]U="T^9V5T0W5R<F5N=$)L;V-K*"D["B1A;&QO=U]A9&0@/2`H(65M
M<'1Y*"1C;VYF6R=H;V]K<R==6R=P97)M<V1E;FEE9"==*2!\?`H@("`@("`@
M("`@("`@($AO<F1E.CIH87-097)M:7-S:6]N*"=M87A?8FQO8VMS)RD@/3T]
M('1R=64@?'P*("`@("`@("`@("`@("!(;W)D93HZ:&%S4&5R;6ES<VEO;B@G
M;6%X7V)L;V-K<R<I(#X@)&QA>6]U="T^8V]U;G0H*2D["B1C;VQU;6YS(#T@
M,#L*9F]R("@D<F]W(#T@,#L@)')O=R`\("1R;W=S.R`K*R1R;W<I.@H_/@H@
M(#QT<CX*/#]P:'`*)&-O;'5M;G,@/2`D;&%Y;W5T+3YC;VQU;6YS*"1R;W<I
M.PII9B`H:7-?82@D8V]L=6UN<RP@)U!%05)?17)R;W(G*2D@>PH@("`@)&-O
M;'5M;G,@/2`P.PI]"F9O<B`H)&-O;"`](#`[("1C;VP@/"`D8V]L=6UN<SL@
M*RLD8V]L*3H*("`@("1I<T5D:71I;F<@/2`H)&-U<G)E;G1?<F]W(#T]/2`D
M<F]W("8F("1C=7)R96YT7V-O;"`]/3T@)&-O;"D["B`@("!I9B`H)&QA>6]U
M="T^:7-#;W9E<F5D*"1R;W<L("1C;VPI*3H*/SX*("`@(#PA+2T@8V]V97)E
M9"!C96QL(&AE<F4@+2T^"CP_<&AP(&5L<V4Z(#\^"B`@("`\=&0@8VQA<W,]
M(CP_<&AP(&5C:&\@)&ES161I=&EN9R`_("=C=7)R96YT0FQO8VLG(#H@)VAE
M861E<F)O>"<@/SXB('9A;&EG;CTB=&]P(B!W:61T:#TB/#]P:'`@96-H;R!F
M;&]O<B@Q,#`@+R`H)&-O;'5M;G,@*R`Q*2D@/SXE(B!R;W=S<&%N/2(\/W!H
M<"!E8VAO("1L87EO=70M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`_/B(@8V]L
M<W!A;CTB/#]P:'`@96-H;R`D;&%Y;W5T+3YG9717:61T:"@D<F]W+"`D8V]L
M*2`_/B(^"CP_<&AP"B1B;&]C:TEN9F\@/2`D;&%Y;W5T+3YG971";&]C:TEN
M9F\H)')O=RP@)&-O;"D["FEF("@A)&QA>6]U="T^:7-%;7!T>2@D<F]W+"`D
M8V]L*2`F)B`A:7-?82@D8FQO8VM);F9O+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("!I9B`H)&ES161I=&EN9RD@>PH@("`@("`@("1E9&ET7VQI;FL@/2`G)FYB
M<W`[)SL*("`@('T@96QS92!["B`@("`@("`@)&5D:71?;&EN:R`]("<\<VUA
M;&P^)R`N($AO<F1E.CIL:6YK*"1L87EO=70M/F=E=$%C=&EO;E5R;"@G961I
M="<L("1R;W<L("1C;VPI*2`N(%\H(F5D:70B*2`N("<\+V$^/"]S;6%L;#XG
M.PH@("`@?0H@("`@<F5Q=6ER92!D:7)N86UE*%]?1DE,15]?*2`N("<O;&%Y
M;W5T+FEN8R<["GT@96QS92!["B`@("!I9B`H)&%L;&]W7V%D9"D@>PH@("`@
M("`@(')E<75I<F4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+V%D9"YI;F,G.PH@
M("`@?0I]"C\^"B`@("`\+W1D/@H\/W!H<"!E;F1I9CL@96YD9F]R.R!I9B`H
M)&%L;&]W7V%D9"DZ(#\^"B`@("`\=&0@=F%L:6=N/2)T;W`B(&-L87-S/2)H
M96%D97)B;W@B/@H@("`@("`\/W!H<"!R97%U:7)E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]A9&0N:6YC)SL@/SX*("`@(#PO=&0^"CP_<&AP(&5N9&EF.R`_
M/@H@(#PO='(^"CP_<&AP(&5N9&9O<CL@:68@*"1A;&QO=U]A9&0I.B`_/@H@
M(#QT<CX*/#]P:'`*9F]R("@D8V]L(#T@,#L@)&-O;"`\/2`D8V]L=6UN<SL@
M*RLD8V]L*3H*/SX*("`@(#QT9"!V86QI9VX](G1O<"(@8VQA<W,](FAE861E
M<F)O>"(^"B`@("`@(#P_<&AP(')E<75I<F4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+V%D9"YI;F,G.R`_/@H@("`@/"]T9#X*/#]P:'`@96YD9F]R.R`_/@H@
M(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H\+W1A8FQE/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,`
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C$R-B`Q,#4Q-30S
M-#$T-2`P,C,Q-#8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&1I=B!I9#TB97AP86YD9613:61E8F%R(B!S='EL93TB;W9E
M<F9L;W<Z:&ED9&5N(CX*(#QD:78@:60](FUE;G4B('-T>6QE/2)O=F5R9FQO
M=SIH:61D96XB/@H@(#P_<&AP(&EF("@A96UP='DH)&-O;F9;)VQO9V\G75LG
M:6UA9V4G72D@?'P@(55T:6PZ.F=E=$9O<FU$871A*"=M;WIB87(G*2DZ(#\^
M"B`@/'-P86X@8VQA<W,](FQE9G1&;&]A="(\/W!H<"!I9B`H96UP='DH)&-O
M;F9;)VQO9V\G75LG:6UA9V4G72DI(&5C:&\@)R!I9#TB=&AE;65L;V=O(B<@
M/SX^"B`@/#]P:'`*("!I9B`H(65M<'1Y*"1C;VYF6R=L;V=O)UU;)VEM86=E
M)UTI*2!["B`@("`@(&EF("@A96UP='DH)&-O;F9;)VQO9V\G75LG;&EN:R==
M*2D@>PH@("`@("`@("`@96-H;R!(;W)D93HZ;&EN:R@D8V]N9ELG;&]G;R==
M6R=L:6YK)UTL(&YU;&PL(&YU;&PL("=?=&]P)RD["B`@("`@('T*("`@("`@
M96-H;R!(;W)D93HZ:6UG*"1C;VYF6R=L;V=O)UU;)VEM86=E)UTL("<G+"`G
M)RP@)R<I.PH@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=L;V=O)UU;)VQI;FLG
M72DI('L*("`@("`@("`@(&5C:&\@)SPO83XG.PH@("`@("!]"B`@?2!E;'-E
M('L*("`@("`@96-H;R`G)FYB<W`[)SL*("!]"B`@/SX*("`\+W-P86X^"B`@
M/'-P86X@8VQA<W,](FQE9G1&;&]A="(@:60](FQO9V]P860B/B9N8G-P.SPO
M<W!A;CX*("`\9&EV(&-L87-S/2)C;&5A<B(^)FYB<W`[/"]D:78^"B`@/#]P
M:'`@96YD:68[(#\^"B`\+V1I=CX*(#QS<&%N(&ED/2)E>'!A;F1"=71T;VXB
M(&-L87-S/2)R:6=H=$9L;V%T(CX\/W!H<"!I9B`H(21I<U]M;WIB87(I(&5C
M:&\@2&]R9&4Z.FQI;FLH)R,G+"!?*")#;VQL87!S92!3:61E8F%R(BDL("<G
M+"`G)RP@)W1O9V=L94UE;G5&<F%M92@I.R!R971U<FX@9F%L<V4[)RP@7R@B
M0V]L;&%P<V4@4VED96)A<B(I*2`N($AO<F1E.CII;6<H)VAI9&5?<&%N96PN
M<&YG)RD@+B`G/"]A/B<@/SX\+W-P86X^"B`\9&EV(&ED/2)S:61E8F%R4&%N
M96PB/@H@(#P_<&AP("1T<F5E+3YR96YD97)4<F5E*"D@/SX*(#PO9&EV/@H*
M/"$M+2!N97=S9F5E9',@+2T^"CQS8W)I<'0@;&%N9W5A9V4](FIA=F%S8W)I
M<'0B('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"F1O8W5M96YT+G=R:71E*"<\
M<V-R:7!T(&QA;F=U86=E/2)J879A<V-R:7!T(B!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B('-R8STB:'1T<#HO+R<*("`@("L@;&]C871I;VXN:&]S=&YA;64@
M*R`G.C@X.#`O:F%V87-C<FEP="]N97=S9F5E9',N:G,N<&AP(CX\+R<@*R`G
M<V-R:7!T/EQN)RD["CPO<V-R:7!T/@H\<V-R:7!T(&QA;F=U86=E/2)J879A
M<V-R:7!T(B!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@IF=6YC=&EO;B!C<F5A
M=&5#;V]K:64H;F%M92QV86QU92QD87ES*2!["B`@:68@*&1A>7,I('L*("`@
M('9A<B!D871E(#T@;F5W($1A=&4H*3L*("`@(&1A=&4N<V5T5&EM92AD871E
M+F=E=%1I;64H*2LH9&%Y<RHR-"HV,"HV,"HQ,#`P*2D["B`@("!V87(@97AP
M:7)E<R`]("([(&5X<&ER97,](BMD871E+G1O1TU44W1R:6YG*"D["B`@?0H@
M(&5L<V4@=F%R(&5X<&ER97,@/2`B(CL*("!D;V-U;65N="YC;V]K:64@/2!N
M86UE*R(](BMV86QU92ME>'!I<F5S*R([('!A=&@]+R(["GT*"F9U;F-T:6]N
M(')E861#;V]K:64H;F%M92D@>PH@('9A<B!N86UE15$@/2!N86UE("L@(CTB
M.PH@('9A<B!C82`](&1O8W5M96YT+F-O;VMI92YS<&QI="@G.R<I.PH@(&9O
M<BAV87(@:3TP.VD@/"!C82YL96YG=&@[:2LK*2!["B`@("!V87(@8R`](&-A
M6VE=.PH@("`@=VAI;&4@*&,N8VAA<D%T*#`I/3TG("<I(&,@/2!C+G-U8G-T
M<FEN9R@Q+&,N;&5N9W1H*3L*("`@(&EF("AC+FEN9&5X3V8H;F%M9451*2`]
M/2`P*2!R971U<FX@8RYS=6)S=')I;F<H;F%M9451+FQE;F=T:"QC+FQE;F=T
M:"D["B`@?0H@(')E='5R;B!N=6QL.PI]"@IF=6YC=&EO;B!E<F%S94-O;VMI
M92AN86UE*2!["B`@8W)E871E0V]O:VEE*&YA;64L(B(L+3$I.PI]"F9U;F-T
M:6]N(&AA<T-L87-S*&5L96UE;G0L(&-L87-S3F%M92D*>PH@("`@=F%R(&-L
M87-S97,@/2!E;&5M96YT+F-L87-S3F%M92YS<&QI="@G("<I.PH@(&9O<B`H
M=F%R(&D@:6X@8VQA<W-E<RD@>PH@("`@:68@*&-L87-S97-;:5T@/3T@8VQA
M<W-.86UE*0H@("`@("!R971U<FX@=')U93L*("!]"B`@<F5T=7)N(&9A;'-E
M.PI]"@IF=6YC=&EO;B!A9&1#;&%S<RAE;&5M96YT+"!C;&%S<TYA;64I"GL*
M("!I9B`H(6AA<T-L87-S*&5L96UE;G0L(&-L87-S3F%M92DI"B`@("!E;&5M
M96YT+F-L87-S3F%M92`]("AE;&5M96YT+F-L87-S3F%M92`]/2`G)R`_(&-L
M87-S3F%M92`Z(&5L96UE;G0N8VQA<W-.86UE("L@)R`G("L@8VQA<W-.86UE
M*3L*?0H*9G5N8W1I;VX@<F5M;W9E0VQA<W,H96QE;65N="P@8VQA<W-.86UE
M*0I["B`@=F%R(&YE=U9A;'5E(#T@)R<["B`@("!V87(@8VQA<W-E<R`](&5L
M96UE;G0N8VQA<W-.86UE+G-P;&ET*"<@)RD["B`@9F]R("AV87(@:2!I;B!C
M;&%S<V5S*2!["B`@("!I9B`H8VQA<W-E<UMI72`A/2!C;&%S<TYA;64I"B`@
M("`@(&YE=U9A;'5E("L](&YE=U9A;'5E+FQE;F=T:"`_("<@)R`K(&-L87-S
M97-;:5T@.B!C;&%S<V5S6VE=.PH@('T*("!E;&5M96YT+F-L87-S3F%M92`]
M(&YE=U9A;'5E.PI]"@H*9G5N8W1I;VX@3D9C;VQL87!S94QI<W0H*2!["B`@
M=F%R($Y&8V]N=&5N="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=.1F-O
M;G1E;G0G*0H@(&EF("AW:6YD;W<N3D9O<&5N*2!["B`@("!A9&1#;&%S<R`H
M3D9C;VYT96YT+"`G3D9C;&]S92<I.PH@("`@<F5M;W9E0VQA<W,@*$Y&8V]N
M=&5N="P@)TY&;W!E;B<I.PH@("`@8W)E871E0V]O:VEE*"=P;&5S:U]N97=S
M9F5E9%]V:7-I8FQE)RP@)V9A;'-E)RP@,S`I.PH@("`@=VEN9&]W+DY&;W!E
M;B`](&9A;'-E.PH@('T@96QS92!["B`@("!I9B`H(7=I;F1O=RYA<G1I8VQE
M*0H@("`@("!.1F=E=$QI<W0H*3L*("`@(&%D9$-L87-S("A.1F-O;G1E;G0L
M("=.1F]P96XG*3L*("`@(')E;6]V94-L87-S("A.1F-O;G1E;G0L("=.1F-L
M;W-E)RD["B`@("!C<F5A=&5#;V]K:64H)W!L97-K7VYE=W-F965D7W9I<VEB
M;&4G+"`G=')U92<L(#,P*3L*("`@('=I;F1O=RY.1F]P96X@/2!T<G5E.PH@
M('T*?0II9B`H=VEN9&]W+DYE=W-&965D<RD@>PH@('=I;F1O=RY.1F]P96X@
M/2`H<F5A9$-O;VMI92@G<&QE<VM?;F5W<V9E961?=FES:6)L92<I(#T]("=F
M86QS92<I(#\@9F%L<V4@.B!T<G5E.PH@(&1O8W5M96YT+G=R:71E*"<\9&EV
M(&ED/2).1F-O;G1E;G0B(&-L87-S/2)S:61E8F%R4&%N96P@)R`K("A.1F]P
M96X@/R`G3D9O<&5N)R`Z("=.1F-L;W-E)RD@*R<B/B<I.PH@(&1O8W5M96YT
M+G=R:71E*"<\=&%B;&4@8V5L;'-P86-I;F<](C`B(&-E;&QP861D:6YG/2(B
M('=I9'1H/2(Q,#`E(B!B;W)D97(](C`B(&-L87-S/2)S:61E8F%R2&5A9&5R
M(CX\=&)O9'D^)RD["B`@9&]C=6UE;G0N=W)I=&4H)SQT<CXG*3L*("!D;V-U
M;65N="YW<FET92@G/'1D(&-L87-S/2)H96%D97)4:71L92(^/#]P:'`@96-H
M;R!?*"=4;W`@3F5W<R<I.R`_/CPO=&0^)RD["B`@9&]C=6UE;G0N=W)I=&4H
M)SQT9"!C;&%S<STB:&5A9&5R0G5T=&]N<R(^/&$@:')E9CTB:F%V87-C<FEP
M=#I.1F=E=$QI<W0H*3LB(&-L87-S/2)B=&XM<F5F<F5S:"(@=&ET;&4](CP_
M<&AP(&5C:&\@7R@G4F5F<F5S:"<I.R`_/B(^/'-P86X^/#]P:'`@96-H;R!?
M*"=2969R97-H)RD[(#\^/"]S<&%N/CPO83X\82!H<F5F/2)J879A<V-R:7!T
M.DY&8V]L;&%P<V5,:7-T*"D[(B!C;&%S<STB8G1N+6]P96XM8VQO<V4B('1I
M=&QE/2(\/W!H<"!E8VAO(%\H)T]P96XO0VQO<V4G*3L@/SXB/CQS<&%N/CP_
M<&AP(&5C:&\@7R@G3W!E;B]#;&]S92<I.R`_/CPO<W!A;CX\+V$^/"]T9#XG
M*3L*("!D;V-U;65N="YW<FET92@G/"]T<CXG*3L*("!D;V-U;65N="YW<FET
M92@G/"]T8F]D>3X\+W1A8FQE/B<I.PH@(&1O8W5M96YT+G=R:71E*"<\9&EV
M(&ED/2)N97=S1F5E9',B/CPO9&EV/B<I.PH@(&1O8W5M96YT+G=R:71E*"<\
M+V1I=CXG*3L*("!I9B`H=VEN9&]W+DY&;W!E;B`F)B!R96%D0V]O:VEE*"=H
M;W)D95]S:61E8F%R7V5X<&%N9&5D)RD@(3T@)V9A;'-E)RD*("`@($Y&9V5T
M3&ES="@I.PI]"CPO<V-R:7!T/@H\(2TM("]N97=S9F5E9',@+2T^"CPO9&EV
M/@H*/&1I=B!I9#TB:&ED9&5N4VED96)A<B(^"B`\9&EV(&ED/2)M96YU(CX*
M(#PO9&EV/@H@(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)R<L
M("<G+"`G=&]G9VQE365N=49R86UE*"D[(')E='5R;B!F86QS93LG*2`N($AO
M<F1E.CII;6<H)W-H;W=?<&%N96PN<&YG)RD@+B`G/"]A/B<@/SX*/"]D:78^
M"@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"@IV87(@<G1L(#T@
M/#]P:'`@96-H;R`D<G1L(#\@)W1R=64G(#H@)V9A;'-E)R`_/CL*=F%R(&5X
M<&%N9&5D4VED96)A<B`](&YE=R!(;W)D95](:61E86)L92@G97AP86YD9613
M:61E8F%R)RD["G9A<B!H:61D96Y3:61E8F%R(#T@;F5W($AO<F1E7TAI9&5A
M8FQE*"=H:61D96Y3:61E8F%R)RD["FAI9&1E;E-I9&5B87(N:&ED92@I.PH*
M9G5N8W1I;VX@9V5T0V]O:VEE*&YA;64L(&1E9FQT*0I["B`@("!V87(@9&,@
M/2!D;V-U;65N="YC;V]K:64["B`@("!V87(@<')E9FEX(#T@;F%M92`K("<]
M)SL*("`@('9A<B!B96=I;B`](&1C+FEN9&5X3V8H)SL@)R`K('!R969I>"D[
M"B`@("!I9B`H8F5G:6X@/3T@+3$I('L*("`@("`@("!B96=I;B`](&1C+FEN
M9&5X3V8H<')E9FEX*3L*("`@("`@("!I9B`H8F5G:6X@(3T@,"D@>PH@("`@
M("`@("`@("!R971U<FX@9&5F;'0["B`@("`@("`@?0H@("`@?2!E;'-E('L*
M("`@("`@("!B96=I;B`K/2`R.PH@("`@?0H@("`@=F%R(&5N9"`](&1O8W5M
M96YT+F-O;VMI92YI;F1E>$]F*"<[)RP@8F5G:6XI.PH@("`@:68@*&5N9"`]
M/2`M,2D@>PH@("`@("`@(&5N9"`](&1C+FQE;F=T:#L*("`@('T*("`@(')E
M='5R;B!U;F5S8V%P92AD8RYS=6)S=')I;F<H8F5G:6X@*R!P<F5F:7@N;&5N
M9W1H+"!E;F0I*3L*?0H*9G5N8W1I;VX@=&]G9VQE365N=49R86UE*"D*>PH@
M("`@:68@*'!A<F5N="`F)B!P87)E;G0N9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)VAF)RDI('L*("`@("`@("!I9B`H97AP86YD9613:61E8F%R+G-H;W=N
M*"DI('L*("`@("`@("`@("`@<&%R96YT+F1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*"=H9B<I+F-O;',@/2!R=&P@/R`G*BPR,"<@.B`G,C`L*B<["B`@("`@
M("`@("`@(&5X<&%N9&5D4VED96)A<BYH:61E*"D["B`@("`@("`@("`@(&AI
M9&1E;E-I9&5B87(N<VAO=R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@('!A<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)9"@G:&8G*2YC;VQS
M(#T@*')T;"`_("<J+"<@.B`G)RD@*R`\/W!H<"!E8VAO("AI<W-E="@D<')E
M9G,I(#\@)'!R969S+3YG971686QU92@G<VED96)A<E]W:61T:"<I(#H@,34P
M*2`_/B`K("AR=&P@/R`G)R`Z("<L*B<I.PH@("`@("`@("`@("!I9B`H=VEN
M9&]W+DY&;W!E;B`F)B`A=VEN9&]W+F%R=&EC;&4I"B`@("`@("`@("`@("`@
M3D9G971,:7-T*"D["B`@("`@("`@("`@(&AI9&1E;E-I9&5B87(N:&ED92@I
M.PH@("`@("`@("`@("!E>'!A;F1E9%-I9&5B87(N<VAO=R@I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@17AP:7)E(&EN(&]N92!Y96%R+@H@("`@("`@('9A
M<B!E>'!I<F5S(#T@;F5W($1A=&4H*3L*("`@("`@("!E>'!I<F5S+G-E=%1I
M;64H97AP:7)E<RYG9714:6UE*"D@*R`S,34S-C`P,#`P,"D["B`@("`@("`@
M9&]C=6UE;G0N8V]O:VEE(#T@)VAO<F1E7W-I9&5B87)?97AP86YD960])R`K
M(&5X<&%N9&5D4VED96)A<BYS:&]W;B@I("L@)SM$3TU!24X]/#]P:'`@96-H
M;R`D1TQ/0D%,4ULG8V]N9B==6R=C;V]K:64G75LG9&]M86EN)UT@/SX[4$%4
M2#T\/W!H<"!E8VAO("1'3$]"04Q36R=C;VYF)UU;)V-O;VMI92==6R=P871H
M)UT@/SX[97AP:7)E<STG("L@97AP:7)E<RYT;T=-5%-T<FEN9R@I.PH@("`@
M?0I]"@II9B`H9V5T0V]O:VEE*"=H;W)D95]S:61E8F%R7V5X<&%N9&5D)RP@
M=')U92DN=&]3=')I;F<H*2`A/2!E>'!A;F1E9%-I9&5B87(N<VAO=VXH*2YT
M;U-T<FEN9R@I*2!["B`@("!T;V=G;&5-96YU1G)A;64H*3L*?0H*=F%R($UE
M;G55<&1A=&5(86YD;&5R(#T@>PH@("`@;VY,;V%D.B!F=6YC=&EO;BAR97-U
M;'0I"B`@("!["B`@("`@("`@+R\@4G5N('1H92!J879A<V-R:7!T('=E(&=O
M="!B86-K+@H@("`@("`@(&5V86PH<F5S=6QT*3L*("`@('T*?3L*"F9U;F-T
M:6]N('5P9&%T92@I"GL*("`@('9A<B!C;&EE;G0@/2!N97<@2%144$-L:65N
M="@I.PH@("`@8VQI96YT+FEN:70H(CP_<&AP(&5C:&\@2&]R9&4Z.F%P<&QI
M8V%T:6]N57)L*"=S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`_:'1T<&-L
M:65N=#TQ)RP@=')U92D@/SXB*3L*"B`@("!T<GD@>PH@("`@("`@(&-L:65N
M="YA<WEN8T=%5"A-96YU57!D871E2&%N9&QE<BD["B`@("!](&-A=&-H("AE
M*2!["B`@("`@("`@+R\@1&]N)W0@9&\@86YY=&AI;F<@;VX@97)R;W)S.R!P
M<F]B86)L>2!A('1R86YS:65N="!F86EL=7)E+`H@("`@("`@("\O(&%N9"!W
M92=L;"!T<GD@86=A:6X@869T97(@=&AE(&YE>'0@:6YT97)V86PN"B`@("!]
M"B`@("!W:6YD;W<N<V5T5&EM96]U="@G=7!D871E*"D[)RP@/#]P:'`@96-H
M;R`D<')E9G,M/F=E=%9A;'5E*"=M96YU7W)E9G)E<VA?=&EM92<I(#\^("H@
M,3`P,"D["GT*"CP_<&AP(&EF("@D<')E9G,M/F=E=%9A;'5E*"=M96YU7W)E
M9G)E<VA?=&EM92<I*3H@/SX*+R\@57!D871E('1H92!M96YU(&EF('-E="!I
M;B!U<V5R('!R969S+@H\/W!H<"!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^
M:&%S1F5A='5R92@G>&UL:'1T<')E<2<I*3H@/SX*=VEN9&]W+G-E=%1I;65O
M=70H)W5P9&%T92@I.R<L(#P_<&AP(&5C:&\@)'!R969S+3YG971686QU92@G
M;65N=5]R969R97-H7W1I;64G*2`_/B`J(#$P,#`I.PH\/W!H<"!E;'-E.B`_
M/@IW:6YD;W<N<V5T5&EM96]U="@G=VEN9&]W+FQO8V%T:6]N+G)E;&]A9"AT
M<G5E*3LG+"`\/W!H<"!E8VAO("1P<F5F<RT^9V5T5F%L=64H)VUE;G5?<F5F
M<F5S:%]T:6UE)RD@/SX@*B`Q,#`P*3L*/#]P:'`@96YD:68[(&5N9&EF.R`_
M/@H*/"]S8W)I<'0^"@H\/W!H<"!I9B`H:7-S970H)$=,3T)!3%-;)VYO=&EF
M:6-A=&EO;B==*2D@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YN;W1I9GDH
M87)R87DH)VQI<W1E;F5R<R<@/3X@87)R87DH)VIA=F%S8W)I<'0G*2DI(#\^
M"@H\+V)O9'D^"CPO:'1M;#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#<S(#$P-3$U
M-#,T,30U(#`R,C(V,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<"!I9B`H)&QA>6]U="T^:7-#:&%N9V5D*"1R;W<L
M("1C;VPI*3H@/SX*/&$@:60](F)L;V-K(CX\+V$^"CP_<&AP(&5N9&EF.R`_
M/@H*/'`@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R!?*")!9&0@2&5R93HB
M*2`_/CPO<#X*"CQD:78@<W1Y;&4](G!A9&1I;F<Z,G!X(CX*(#QF;W)M(&%C
M=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(V)L;V-K(B!M
M971H;V0](G!O<W0B/@H@/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"B`\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)R;W<B('9A;'5E/2(\/W!H<"!E
M8VAO("1R;W<@/SXB("\^"B`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)C
M;VPB('9A;'5E/2(\/W!H<"!E8VAO("1C;VP@/SXB("\^"B`\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)A8W1I;VXB('9A;'5E/2)S879E+7)E<W5M92(@
M+SX*(#P_<&AP(&5C:&\@)&)L;V-K<RT^9V5T0FQO8VMS5VED9V5T*"D@/SX*
M(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(D%D9"(I(#\^(B`O/@H@/"]F;W)M/@H\+V1I=CX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P,3(Q
M(#$P-3$U-#,T,30U(#`R,S`S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<"!I9B`H)&QA>6]U="T^:7-#:&%N9V5D
M*"1R;W<L("1C;VPI*3H@/SX*/&$@:60](F)L;V-K(CX\+V$^"CP_<&AP(&5N
M9&EF.R`_/@H*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!C;&%S<STB:&5A9&5R
M(B!W:61T:#TB,3`P)2(^/'1R/@H@(#QT9#X*("`@(#P_<&AP(&5C:&\@)')E
M9VES=')Y+3YG970H)VYA;64G+"`D8FQO8VM);F9O6R=A<'`G72D@+B`G.B`G
M("X@)&)L;V-K<RT^9V5T3F%M92@D8FQO8VM);F9O6R=A<'`G72P@)&)L;V-K
M26YF;ULG8FQO8VLG72D@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB<FEG:'1!
M;&EG;B(^"B`@("`F;F)S<#L\/W!H<"!E8VAO("1E9&ET7VQI;FL@/SX*("`@
M(#P_<&AP(&EF("@D;&%Y;W5T+3YI<U)E;6]V86)L92@D<F]W+"`D8V]L*2D@
M96-H;R!(;W)D93HZ;&EN:R@D;&%Y;W5T+3YG971!8W1I;VY5<FPH)W)E;6]V
M94)L;V-K)RP@)')O=RP@)&-O;"DL(%\H(E)E;6]V92!";&]C:R(I+"`G)RP@
M)R<L("<G+"!?*")296UO=F4@0FQO8VLB*2D@+B!(;W)D93HZ:6UG*"=C;&]S
M92YP;F<G+"!?*")296UO=F4@0FQO8VLB*2P@)V%L:6=N/2)M:61D;&4B)RD@
M+B`G/"]A/B<@/SX*("`\+W1D/@H\+W1R/CPO=&%B;&4^"@H\=&%B;&4@8V5L
M;'-P86-I;F<](C`B(&-L87-S/2)N;W!A9&1I;F<B('=I9'1H/2(Q,#`E(CX*
M("`\='(^"B`@("`\=&0@8V]L<W!A;CTB,R(@86QI9VX](F-E;G1E<B(^"B`@
M("`@(#P_<&AP(&EF("@D<F]W(#X@,"D@96-H;R`D;&%Y;W5T+3YG971#;VYT
M<F]L*"=E>'!A;F0O=7`G+"`D<F]W+"`D8V]L*2`_/B9N8G-P.PH@("`@("`\
M/W!H<"!I9B`H)&QA>6]U="T^9V5T2&5I9VAT*"1R;W<L("1C;VPI(#X@,2D@
M96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=S:')I;FLO=7`G+"`D<F]W+"`D
M8V]L*2`_/@H@("`@/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!C;&%S
M<STB;&5F=$%L:6=N(B!W:61T:#TB,3$B/@H@("`@("`\/W!H<"!I9B`H)&-O
M;"`^(#`I(&5C:&\@)&QA>6]U="T^9V5T0V]N=')O;"@G97AP86YD+VQE9G0G
M+"`D<F]W+"`D8V]L*2`_/@H@("`@("`\/W!H<"!I9B`H)&QA>6]U="T^9V5T
M5VED=&@H)')O=RP@)&-O;"D@/B`Q*2!E8VAO("1L87EO=70M/F=E=$-O;G1R
M;VPH)W-H<FEN:R]L969T)RP@)')O=RP@)&-O;"D@/SX*("`@(#PO=&0^"B`@
M("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@(#QT86)L93X*("`@("`@("`\
M='(^"B`@("`@("`@("`\=&0@=VED=&@](C$Q(CXF;F)S<#L\+W1D/@H@("`@
M("`@("`@/'1D('=I9'1H/2(Q,2(^/#]P:'`@96-H;R`D<F]W(#X@,"`_("1L
M87EO=70M/F=E=$-O;G1R;VPH)VUO=F4O=7`G+"`D<F]W+"`D8V]L*2`Z("<F
M;F)S<#LG(#\^/"]T9#X*("`@("`@("`@(#QT9"!W:61T:#TB,3$B/B9N8G-P
M.SPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@("`@("`@("`\
M=&0^/#]P:'`@96-H;R`D8V]L(#X@,"`_("1L87EO=70M/F=E=$-O;G1R;VPH
M)VUO=F4O;&5F="<L("1R;W<L("1C;VPI(#H@)R9N8G-P.R<@/SX\+W1D/@H@
M("`@("`@("`@/'1D/B9N8G-P.SPO=&0^"B`@("`@("`@("`\=&0^/#]P:'`@
M96-H;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=M;W9E+W)I9VAT)RP@)')O=RP@
M)&-O;"D@/SX\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@("`@
M("`@("`@/'1D/B9N8G-P.SPO=&0^"B`@("`@("`@("`\=&0^/#]P:'`@96-H
M;R`D;&%Y;W5T+3YG971#;VYT<F]L*"=M;W9E+V1O=VXG+"`D<F]W+"`D8V]L
M*2`_/CPO=&0^"B`@("`@("`@("`\=&0^)FYB<W`[/"]T9#X*("`@("`@("`\
M+W1R/@H@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`@(#QT9"!C;&%S<STB
M<FEG:'1!;&EG;B(@=VED=&@](C$Q(CX*("`@("`@/#]P:'`@:68@*"1L87EO
M=70M/F=E=%=I9'1H*"1R;W<L("1C;VPI(#X@,2D@96-H;R`D;&%Y;W5T+3YG
M971#;VYT<F]L*"=S:')I;FLO<FEG:'0G+"`D<F]W+"`D8V]L*2`_/@H@("`@
M("`\/W!H<"!E8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)V5X<&%N9"]R:6=H
M="<L("1R;W<L("1C;VPI(#\^"B`@("`\+W1D/@H@(#PO='(^"B`@/'1R/@H@
M("`@/'1D(&-O;'-P86X](C,B(&%L:6=N/2)C96YT97(B/@H@("`@("`@(#P_
M<&AP(&EF("@D;&%Y;W5T+3YG971(96EG:'0H)')O=RP@)&-O;"D@/B`Q*2!E
M8VAO("1L87EO=70M/F=E=$-O;G1R;VPH)W-H<FEN:R]D;W=N)RP@)')O=RP@
M)&-O;"D@/SX*("`@("`@("`\/W!H<"!E8VAO("1L87EO=70M/F=E=$-O;G1R
M;VPH)V5X<&%N9"]D;W=N)RP@)')O=RP@)&-O;"D@/SX*("`@(#PO=&0^"B`@
M/"]T<CX*/"]T86)L93X*"CP_<&AP(&EF("@D:7-%9&ET:6YG*3H@/SX*/&$@
M:60](F)L;V-K(CX\+V$^"CQT86)L92!C;&%S<STB;F]P861D:6YG(B!C96QL
M<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H@(#QT<CX*("`@(#QT9#XF;F)S
M<#L\+W1D/@H@(#PO='(^"B`@/'1R/@H@("`@/'1D('9A;&EG;CTB;6ED9&QE
M(B!C;&%S<STB;&5F=$%L:6=N(B!W:61T:#TB,3`P)2(^"B`@("`@(#QF;W)M
M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(V)L;V-K
M(B!M971H;V0](G!O<W0B(&YA;64](F)L;V-K9F]R;2(^"B`@("`@("`@/#]P
M:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"B`@("`@("`@/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB<F]W(B!V86QU93TB/#]P:'`@96-H;R`D<F]W(#\^
M(B`O/@H@("`@("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F-O;"(@
M=F%L=64](CP_<&AP(&5C:&\@)&-O;"`_/B(@+SX*("`@("`@("`\:6YP=70@
M='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VXB('9A;'5E/2)S879E(B`O/@H@
M("`@("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(@=VED=&@](C$P,"4B/@H@
M("`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0@8VQA<W,](G-M86QL:&5A
M9&5R(B!C;VQS<&%N/2(R(CX\/W!H<"!E8VAO(%\H(D)L;V-K(%1Y<&4B*2`_
M/CPO=&0^"B`@("`@("`@("`\+W1R/@H@("`@("`@("`@/'1R/@H@("`@("`@
M("`@("`\=&0@8V]L<W!A;CTB,B(^"B`@("`@("`@("`@("`@/#]P:'`@96-H
M;R`D8FQO8VMS+3YG971";&]C:W-7:61G970H)&)L;V-K26YF;ULG87!P)UTL
M("1B;&]C:TEN9F];)V)L;V-K)UTL('1R=64I(#\^"B`@("`@("`@("`@(#PO
M=&0^"B`@("`@("`@("`\+W1R/@H\/W!H<`II9B`H)&)L;V-K<RT^:7-%9&ET
M86)L92@D8FQO8VM);F9O6R=A<'`G72P@)&)L;V-K26YF;ULG8FQO8VLG72DI
M.@H@("`@)&)L;V-K(#T@)B1L87EO=70M/F=E=$)L;V-K*"1R;W<L("1C;VPI
M.PH@("`@)&1E9F%U;'1S(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1B;&]C
M:RT^7W!A<F%M<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`D9&5F875L
M='-;)&ME>5T@/2`D=F%L.PH@("`@?0H_/@H@("`@("`@("`@/'1R/@H@("`@
M("`@("`@("`\=&0@8V]L<W!A;CTB,B(@8VQA<W,](G-M86QL:&5A9&5R(CX\
M/W!H<"!E8VAO(%\H(D)L;V-K(%-E='1I;F=S(BD@/SX\+W1D/@H@("`@("`@
M("`@/"]T<CX*/#]P:'`@)&D@/2`P.R!F;W)E86-H("@D8FQO8VMS+3YG9710
M87)A;7,H)&)L;V-K26YF;ULG87!P)UTL("1B;&]C:TEN9F];)V)L;V-K)UTI
M(&%S("1I9"DZ("1I*RL[(#\^"B`@("`@("`@("`\='(^"B`@("`@("`@("`@
M(#QT9"!C;&%S<STB/#]P:'`@96-H;R`H)&D@)2`R*2`_("=T97AT)R`Z("=I
M=&5M,"<@/SX@<FEG:'1!;&EG;B(@=F%L:6=N/2)T;W`B/CP_<&AP(&5C:&\@
M)&)L;V-K<RT^9V5T4&%R86U.86UE*"1B;&]C:TEN9F];)V%P<"==+"`D8FQO
M8VM);F9O6R=B;&]C:R==+"`D:60I(#\^.B9N8G-P.SPO=&0^"B`@("`@("`@
M("`@(#QT9"!C;&%S<STB/#]P:'`@96-H;R`H)&D@)2`R*2`_("=T97AT)R`Z
M("=I=&5M,"<@/SXB('9A;&EG;CTB=&]P(CX\/W!H<"!E8VAO("1B;&]C:W,M
M/F=E=$]P=&EO;G-7:61G970H)&)L;V-K26YF;ULG87!P)UTL("1B;&]C:TEN
M9F];)V)L;V-K)UTL("1I9"P@)&1E9F%U;'1S*2`_/CPO=&0^"B`@("`@("`@
M("`\+W1R/@H\/W!H<"!E;F1F;W)E86-H.R!E;F1I9CL@/SX*("`@("`@("`\
M+W1A8FQE/@H@("`@("`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B
M=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(E-A=F4B*2`_/B(@+SX*("`@
M("`@/"]F;W)M/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A8FQE/@H\/W!H<"!E
M;F1I9CL@/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<&]R=&%L+V)L;V-K+FEN8P``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,C<@,3`U,34T,S0Q
M-#4@,#(R-C(S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#QT9"!C;&%S<STB:&5A9&5R8F]X(B!V86QI9VX](G1O<"(@<W1Y
M;&4](G=I9'1H.CP_<&AP(&5C:&\@)'=I9'1H(#\^)2(@<F]W<W!A;CTB/#]P
M:'`@96-H;R`D<F]W<W!A;B`_/B(@8V]L<W!A;CTB/#]P:'`@96-H;R`D8V]L
M<W!A;B`_/B(^"B`\:#$@8VQA<W,](FAE861E<B(^/#]P:'`@96-H;R`D:&5A
M9&5R(#\^/"]H,3X*(#P_<&AP(&5C:&\@)&-O;G1E;G0@/SX*/"]T9#X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS`````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`S-S<T(#$P-3$U-#,T,30T(#`R-S(S-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O+R!)
M,3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX
M('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O
M9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O
M("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/
M5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E
M<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@1D]2($5.
M0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE
M87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A=&5S('=H
M870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"D%N<V5L26UA9V4N23$X3B`]
M('L*"2\O($ET96US('1H870@87!P96%R(&EN(&UE;G4N("!0;&5A<V4@;F]T
M92!T:&%T(&%N('5N9&5R<V-O<F4@*%\I"@DO+R!C:&%R86-T97(@:6X@=&AE
M('1R86YS;&%T:6]N("AR:6=H="!C;VQU;6XI('=I;&P@8V%U<V4@=&AE(&9O
M;&QO=VEN9PH)+R\@;&5T=&5R('1O(&)E8V]M92!U;F1E<FQI;F5D(&%N9"!B
M92!S:&]R=&-U="!F;W(@=&AA="!M96YU(&]P=&EO;BX*"@DB26YS97)T($EM
M86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!);6%G92(I*2`_/B(L
M"@DB26UA9V4@55),.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(%52
M3#HB*2D@/SXB+`H)(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B*2D@/SXB+`H)(E!R979I97<B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0<F5V:65W(BDI(#\^(BP*"2)0
M<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B("`@("`@("`@("`@
M("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W(BDI(#\^(BP*"2)!;'1E<FYA=&4@=&5X
M=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B06QT97)N871E('1E>'0Z(BDI(#\^(BP*
M"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B*2D@/SXB+`H)(E!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4B("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E(BDI(#\^(BP*"2));6%G92!0<F5V:65W.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B26UA9V4@4')E=FEE=SHB*2D@/SXB+`H)(D=A;&QE<GDZ(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")'86QL97)Y.B(I*2`_/B(L"@DB1V%L
M;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(BDI(#\^(BP*"2));6%G92!F<F]M(&=A;&QE<GDZ(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B26UA9V4@9G)O;2!G86QL97)Y.B(I*2`_/B(L"@DB26UA
M9V4@9G)O;2!G86QL97)Y(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E(&9R;VT@9V%L
M;&5R>2(I*2`_/B(*?3L*`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,`
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C`P,B`Q,#4Q-30S-#$T-"`P,C8W-C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+R\@23$X3B!C
M;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M."!\($E3
M3RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R
M8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3.@HO+PHO+R`@(#$N
M(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@5$A%($%"3U9%($Q)
M3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R97-S*0HO
M+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX($9/4B!%3D-/1$E.
M1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L96%S92!I
M;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T871E<R!W:&%T(&5N
M8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I,:7-T5'EP92Y),3A.(#T@>PH)(D1E
M8VEM86PB("`@("`@("`@("`@("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")$96-I;6%L(&YU;6)E<G,B*2D@/SXB+`H)(DQO=V5R(')O;6%N
M(B`@("`@("`@("`@(#H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),
M;W=E<B!R;VUA;B!N=6UB97)S(BDI(#\^(BP*"2)5<'!E<B!R;VUA;B(@("`@
M("`@("`@("`Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B57!P97(@
M<F]M86X@;G5M8F5R<R(I*2`_/B(L"@DB3&]W97(@;&%T:6XB("`@("`@("`@
M("`@.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQO=V5R(&QA=&EN
M(&QE='1E<G,B*2D@/SXB+`H)(E5P<&5R(&QA=&EN(B`@("`@("`@("`@(#H@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")5<'!E<B!L871I;B!L971T
M97)S(BDI(#\^(BP*"2),;W=E<B!G<F5E:R(@("`@("`@("`@("`Z("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3&]W97(@9W)E96L@;&5T=&5R<R(I
M*2`_/B(L"@DB3&ES=%-T>6QE5&]O;'1I<"(@("`@("`@.B`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(I*2`_/B(*?3L*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]G;V]G;&5?=VEN+FIS````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,C0U(#$P
M-3$U-#,T,30T(#`R-30Q,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!F=6YC=&EO;B!O<&5N7V=O;V=L95]W:6XH87)G<RD*
M>PH@("`@=F%R('9A;"P@=7)L(#T@)R<["@H@("`@9F]R("AV87(@:2`](#`[
M(&D@/"!D;V-U;65N="YG;V]G;&4N87)E82YL96YG=&@[(&DK*RD@>PH@("`@
M("`@(&EF("AD;V-U;65N="YG;V]G;&4N87)E85MI72YC:&5C:V5D*2!["B`@
M("`@("`@("`@('9A;"`](&1O8W5M96YT+F=O;V=L92YA<F5A6VE=+G9A;'5E
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@<W=I
M=&-H("AV86PI('L*"6-A<V4@)W=E8B<Z"B`@("`)=7)L(#T@)VAT='`Z+R]W
M=W<N9V]O9VQE+F-O;2]S96%R8V@_)SL*"2`@("!B<F5A:SL*"@EC87-E("=I
M;6%G97,G.@H)("`@('5R;"`]("=H='1P.B\O:6UA9V5S+F=O;V=L92YC;VTO
M:6UA9V5S/R<["B`@("`@("`@8G)E86L["@H)8V%S92`G9W)O=7!S)SH*"2`@
M("!U<FP@/2`G:'1T<#HO+V=R;W5P<RYG;V]G;&4N8V]M+V=R;W5P<S\G.PH@
M("`@("`@(&)R96%K.PH*"6-A<V4@)V1I<F5C=&]R>2<Z"@D@("`@=7)L(#T@
M)VAT='`Z+R]W=W<N9V]O9VQE+F-O;2]S96%R8V@_8V%T/6=W9"4R1E1O<"8G
M.PH@("`@("`@(&)R96%K.PH*"6-A<V4@)VYE=W,G.@H)("`@('5R;"`]("=H
M='1P.B\O;F5W<RYG;V]G;&4N8V]M+VYE=W,_)SL*("`@("`@("!B<F5A:SL*
M"@ED969A=6QT.@H@("`@"75R;"`]("=H='1P.B\O=W=W+F=O;V=L92YC;VTO
M<V5A<F-H/R<["B`@("!]"B`@("!U<FP@*ST@)W$])SL*("`@(&EF("AT>7!E
M;V8@96YC;V1E55))0V]M<&]N96YT(#T]("=U;F1E9FEN960G*2!["B`@("`@
M("`@=7)L("L](&5S8V%P92AD;V-U;65N="YG;V]G;&4N<2YV86QU92D["B`@
M("!](&5L<V4@>PH@("`@("`@('5R;"`K/2!E;F-O9&554DE#;VUP;VYE;G0H
M9&]C=6UE;G0N9V]O9VQE+G$N=F%L=64I.PH@("`@?0H*("`@('9A<B!N86UE
M(#T@)T=O;V=L92<["B`@("!V87(@<&%R86T@/2`G=&]O;&)A<CUY97,L;&]C
M871I;VX]>65S+'-T871U<SUY97,L<V-R;VQL8F%R<SUY97,L<F5S:7IA8FQE
M/7EE<RQW:61T:#TX,#`L:&5I9VAT/38P,"QL969T/3`L=&]P/3`G.PH*("`@
M(&5V86PH)VYA;64@/2!W:6YD;W<N;W!E;BAU<FPL(&YA;64L('!A<F%M*2<I
M.PH@("`@:68@*"%E=F%L*"=N86UE+F]P96YE<B<I*2!["B`@("`@("`@979A
M;"@G;F%M92YO<&5N97(@/2!S96QF)RD["B`@("!]"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,30T-C,@,3`U,34T,S0Q-#0@,#(V,C$S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\O($DQ.$X@
M8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@551&+3@@?"!)
M4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT='`Z+R]D>6YA
M<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*+R\*+R\@("`Q
M+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(12!!0D]612!,
M24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@861D<F5S<RD*
M+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&3U(@14Y#3T1)
M3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE+"!P;&5A<V4@
M:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T97,@=VAA="!E
M;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*5&%B;&5/<&5R871I;VYS+DDQ.$X@
M/2!["@DB06QI9VXB.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D%L:6=N(BDI(#\^(BP*"2)!;&P@9F]U<B!S:61E<R(Z"0D)"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")!;&P@9F]U<B!S:61E<R(I*2`_/B(L"@DB
M0F%C:V=R;W5N9"(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M0F%C:V=R;W5N9"(I*2`_/B(L"@DB0F%S96QI;F4B.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0F%S96QI;F4B*2D@/SXB+`H)(D)O<F1E<B(Z"0D)"0D@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0F]R9&5R(BDI(#\^(BP*"2)";W)D97)S
M(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")";W)D97)S(BDI
M(#\^(BP*"2)";W1T;VTB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")";W1T;VTB
M*2D@/SXB+`H)(D-34R!3='EL92(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B4W1Y;&4@6T-34UTB*2D@/SXB+`H)(D-A<'1I;VXB.@D)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-A<'1I;VXB*2D@/SXB+`H)
M(D-E;&P@4')O<&5R=&EE<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-E;&P@4')O<&5R=&EE
M<R(I*2`_/B(L"@DB0V5N=&5R(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#96YT97(B*2D@/SXB+`H)(D-H87(B.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D-H87(B*2D@/SXB+`H)(D-O;&QA<'-E9"!B;W)D97)S(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(D-O;&QA<'-E9"!B;W)D97)S(BDI(#\^(BP*"2)#;VQO<B(Z
M"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0V]L;W(B*2D@/SXB
M+`H)(D1E<V-R:7!T:6]N(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")$97-C<FEP=&EO;B(I*2`_/B(L"@DB1D<@0V]L;W(B.@D)"0D)("`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D9'($-O;&]R(BDI(#\^(BP*"2)&
M;&]A="(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")&;&]A="(I*2`_/B(L"@DB
M1G)A;65S(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")&<F%M
M97,B*2D@/SXB+`H)(DAE:6=H="(Z("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAE
M:6=H="(I*2`_/B(L"@DB2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B.B`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B*2D@
M/SXB+`H)(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(CH@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(BDI(#\^(BP*"2));6%G
M92!54DPB.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEM86=E
M(%523"(I*2`_/B(L"@DB2G5S=&EF>2(Z("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M2G5S=&EF>2(I*2`_/B(L"@DB3&%Y;W5T(CH)"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*"),87EO=70B*2D@/SXB+`H)(DQE9G0B.@D)"0D)"2`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),969T(BDI(#\^(BP*"2)-87)G
M:6XB.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")-87)G:6XB*2D@/SXB+`H)(DUI
M9&1L92(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DUI9&1L92(I*2`_/B(L"@DB
M3F\@<G5L97,B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYO
M(')U;&5S(BDI(#\^(BP*"2).;R!S:61E<R(Z"0D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B3F\@<VED97,B*2D@/SXB+`H)(DYO;F4B.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(DYO;F4B*2D@/SXB+`H)(E!A9&1I;F<B.@D)
M"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!A9&1I;F<B*2D@/SXB
M+`H)(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(Z("`@("`@("`@("`@
M("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;"(I*2`_/B(L"@DB4FEG:'0B.@D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)I9VAT(BDI(#\^(BP*"2)2;W<@4')O
M<&5R=&EE<R(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")2;W<@4')O<&5R=&EE<R(I*2`_/B(L
M"@DB4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<R(Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(I*2`_/B(L"@DB
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB.@D@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB*2D@/SXB+`H)(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY(CH)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(I*2`_
M/B(L"@DB4G5L97,B.@D)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E)U;&5S(BDI(#\^(BP*"2)3<&%C:6YG(&%N9"!P861D:6YG(CH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")3<&%C:6YG(&%N9"!P861D:6YG(BDI(#\^(BP*"2)3<&%C:6YG(CH)"0D)
M"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3<&%C:6YG(BDI(#\^(BP*
M"2)3=6UM87)Y(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3
M=6UM87)Y(BDI(#\^(BP*"2)43RUC96QL+61E;&5T92(Z"0D)"2`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")$96QE=&4@8V5L;"(I*2`_/B(L"@DB5$\M
M8V5L;"UI;G-E<G0M869T97(B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B26YS97)T(&-E;&P@869T97(B*2D@/SXB+`H)(E1/+6-E;&PM:6YS
M97)T+6)E9F]R92(Z"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN
M<V5R="!C96QL(&)E9F]R92(I*2`_/B(L"@DB5$\M8V5L;"UM97)G92(Z"0D)
M"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")-97)G92!C96QL<R(I*2`_
M/B(L"@DB5$\M8V5L;"UP<F]P(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")#96QL('!R;W!E<G1I97,B*2D@/SXB+`H)(E1/+6-E;&PM<W!L
M:70B.@D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4W!L:70@8V5L
M;"(I*2`_/B(L"@DB5$\M8V]L+61E;&5T92(Z"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")$96QE=&4@8V]L=6UN(BDI(#\^(BP*"2)43RUC;VPM
M:6YS97)T+6%F=&5R(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DEN<V5R="!C;VQU;6X@869T97(B*2D@/SXB+`H)(E1/+6-O;"UI;G-E<G0M
M8F5F;W)E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R
M="!C;VQU;6X@8F5F;W)E(BDI(#\^(BP*"2)43RUC;VPM<W!L:70B.@D)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-P;&ET(&-O;'5M;B(I*2`_
M/B(L"@DB5$\M<F]W+61E;&5T92(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")$96QE=&4@<F]W(BDI(#\^(BP*"2)43RUR;W<M:6YS97)T+6%B
M;W9E(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!R
M;W<@8F5F;W)E(BDI(#\^(BP*"2)43RUR;W<M:6YS97)T+75N9&5R(CH)"0D)
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!R;W<@869T97(B
M*2D@/SXB+`H)(E1/+7)O=RUP<F]P(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")2;W<@<')O<&5R=&EE<R(I*2`_/B(L"@DB5$\M<F]W+7-P
M;&ET(CH)"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3<&QI="!R
M;W<B*2D@/SXB+`H)(E1/+71A8FQE+7!R;W`B.@D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B5&%B;&4@<')O<&5R=&EE<R(I*2`_/B(L"@DB5&%B
M;&4@4')O<&5R=&EE<R(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")486)L92!0<F]P97)T:65S(BDI(#\^(BP*"2)497AT(&%L:6=N(CH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")497AT(&%L:6=N(BDI(#\^(BP*"2)4:&4@8F]T=&]M
M('-I9&4@;VYL>2(Z"0D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4
M:&4@8F]T=&]M('-I9&4@;VYL>2(I*2`_/B(L"@DB5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB.@D)"2`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(I*2`_/B(L"@DB5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB.@D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(BDI(#\^(BP*"2)4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'DB.@D)"2`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB*2D@/SXB+`H)(E1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(CH)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(I
M*2`_/B(L"@DB5&AE('1O<"!S:61E(&]N;'DB.@D)"0D@("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B5&AE('1O<"!S:61E(&]N;'DB*2D@/SXB+`H)(E1O
M<"(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1O<"(I*2`_/B(L"@DB56YS
M970@8V]L;W(B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B56YS970@8V]L;W(B*2D@/SXB
M+`H)(E9E<G1I8V%L(&%L:6=N(CH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E9E<G1I8V%L(&%L
M:6=N(BDI(#\^(BP*"2)7:61T:"(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L
M87-H97,H7R@B5VED=&@B*2D@/SXB+`H)(FYO="UD96PM;&%S="UC96QL(CH)
M"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(I
M*2`_/B(L"@DB;F]T+61E;"UL87-T+6-O;"(Z"0D)"2`@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(BDI(#\^(BP*"2)N;W0M
M9&5L+6QA<W0M<F]W(CH)"0D)("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(')O=R!I;B!T86)L92XB*2D@/SXB+`H)(G!E<F-E;G0B.@D)"0D)("`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(G!E<F-E;G0B*2D@/SXB+`H)(G!I>&5L
M<R(Z"0D)"0D@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B<&EX96QS(BDI
M(#\^(@I].PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O=')E92YJ<P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4P-#0T(#$P-3$U-#,T,30T
M(#`R,S(P-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O*BH*("H@2&]R9&4@5')E92!*879A<V-R:7!T($-L87-S"B`J"B`J
M(%!R;W9I9&5S('1H92!J879A<V-R:7!T(&-L87-S('1O(&-R96%T92!D>6YA
M;6EC('1R965S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J
M=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)
M9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@)$AO<F1E
M.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]T<F5E+FIS+'8@,2XV,BXR
M+C$Q(#(P,#8O,#$O,#$@,C$Z,CDZ,34@:F%N($5X<"`D"B`J"B`J($!A=71H
M;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E
M($AO<F1E7U1R964*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIF=6YC=&EO
M;B!(;W)D95]4<F5E*&EN<W1A;F-E3F%M92D*>PH@("`@+RH@4V5T('5P('1H
M:7,@8VQA<W,@:6YS=&%N8V4@9F]R(&9U;F-T:6]N(&-A;&QS(&9R;VT@=&AE
M('!A9V4N("HO"B`@("!T:&ES+E]I;G-T86YC94YA;64@/2!I;G-T86YC94YA
M;64["@H@("`@+RH@26UA9V4@=F%R:6%B;&5S+B`J+PH@("`@=&AI<RYI;6=$
M:7(@("`@("`@("`]("<\/W!H<"!E8VAO("1'3$]"04Q36R=R96=I<W1R>2==
M+3YG971);6%G941I<B@G:&]R9&4G*2`N("<O=')E92<[(#\^)SL*("`@('1H
M:7,N:6UG0FQA;FL@("`@("`@/2`G8FQA;FLN<&YG)SL*("`@('1H:7,N:6UG
M1F]L9&5R("`@("`@/2`G9F]L9&5R+G!N9R<["B`@("!T:&ES+FEM9T9O;&1E
M<D]P96X@(#T@)V9O;&1E<F]P96XN<&YG)SL*"B`@("`O*B!687)I86)L97,@
M=&AA="!C:&%N9V4@8F%S960@;VX@=&5X="!D:7)E8W1I;VXN("HO"CP_<&AP
M(&EF("AE;7!T>2@D1TQ/0D%,4ULG;FQS)UU;)W)T;"==6R1'3$]"04Q36R=L
M86YG=6%G92==72DI.B`_/@H@("`@=&AI<RYF;&]A=$1I<B`@("`@("`]("=F
M;&]A=#IL969T.R<["B`@("!T:&ES+FEM9TQI;F4@("`@("`@(#T@)VQI;F4N
M<&YG)SL*("`@('1H:7,N:6UG2F]I;B`@("`@("`@/2`G:F]I;BYP;F<G.PH@
M("`@=&AI<RYI;6=*;VEN0F]T=&]M("`]("=J;VEN8F]T=&]M+G!N9R<["B`@
M("!T:&ES+FEM9U!L=7,@("`@("`@(#T@)W!L=7,N<&YG)SL*("`@('1H:7,N
M:6UG4&QU<T)O='1O;2`@/2`G<&QU<V)O='1O;2YP;F<G.PH@("`@=&AI<RYI
M;6=0;'5S3VYL>2`@("`]("=P;'5S;VYL>2YP;F<G.PH@("`@=&AI<RYI;6=-
M:6YU<R`@("`@("`]("=M:6YU<RYP;F<G.PH@("`@=&AI<RYI;6=-:6YU<T)O
M='1O;2`]("=M:6YU<V)O='1O;2YP;F<G.PH@("`@=&AI<RYI;6=-:6YU<T]N
M;'D@("`]("=M:6YU<V]N;'DN<&YG)SL*("`@('1H:7,N:6UG3G5L;$]N;'D@
M("`@/2`G;G5L;&]N;'DN<&YG)SL*("`@('1H:7,N:6UG3&5A9B`@("`@("`@
M/2`G;&5A9BYP;F<G.PH\/W!H<"!E;'-E.B`_/@H@("`@=&AI<RYF;&]A=$1I
M<B`@("`@("`]("=F;&]A=#IR:6=H=#LG.PH@("`@=&AI<RYI;6=,:6YE("`@
M("`@("`]("=R978M;&EN92YP;F<G.PH@("`@=&AI<RYI;6=*;VEN("`@("`@
M("`]("=R978M:F]I;BYP;F<G.PH@("`@=&AI<RYI;6=*;VEN0F]T=&]M("`]
M("=R978M:F]I;F)O='1O;2YP;F<G.PH@("`@=&AI<RYI;6=0;'5S("`@("`@
M("`]("=R978M<&QU<RYP;F<G.PH@("`@=&AI<RYI;6=0;'5S0F]T=&]M("`]
M("=R978M<&QU<V)O='1O;2YP;F<G.PH@("`@=&AI<RYI;6=0;'5S3VYL>2`@
M("`]("=R978M<&QU<V]N;'DN<&YG)SL*("`@('1H:7,N:6UG36EN=7,@("`@
M("`@/2`G<F5V+6UI;G5S+G!N9R<["B`@("!T:&ES+FEM9TUI;G5S0F]T=&]M
M(#T@)W)E=BUM:6YU<V)O='1O;2YP;F<G.PH@("`@=&AI<RYI;6=-:6YU<T]N
M;'D@("`]("=R978M;6EN=7-O;FQY+G!N9R<["B`@("!T:&ES+FEM9TYU;&Q/
M;FQY("`@(#T@)W)E=BUN=6QL;VYL>2YP;F<G.PH@("`@=&AI<RYI;6=,96%F
M("`@("`@("`]("=R978M;&5A9BYP;F<G.PH\/W!H<"!E;F1I9CL@/SX*"B`@
M("`O*B!4<F5E(&)U:6QD:6YG('9A<FEA8FQE<RX@*B\*("`@('1H:7,N<F5N
M9&5R4W1A=&EC("`@/2!F86QS93L*("`@('1H:7,N=&%R9V5T("`@("`@("`@
M/2`G)SL*("`@('1H:7,N:&5A9&5R("`@("`@("`@/2!N97<@07)R87DH*3L*
M("`@('1H:7,N<F]O=$YO9&5S("`@("`@/2!N97<@07)R87DH*3L*("`@('1H
M:7,N;F]D97,@("`@("`@("`@/2!N97<@07)R87DH*3L*("`@('1H:7,N;F]D
M95]P;W,@("`@("`@/2!N97<@07)R87DH*3L*("`@('1H:7,N9')O<&QI;F4@
M("`@("`@/2!N97<@07)R87DH*3L*("`@('1H:7,N;W5T<'5T("`@("`@("`@
M/2`G)SL*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N<V5T26UG1&ER(#T@9G5N
M8W1I;VXH:6UG1&ER*0I["B`@("!T:&ES+FEM9T1I<B`](&EM9T1I<CL*?0H*
M2&]R9&5?5')E92YP<F]T;W1Y<&4N<F5N9&5R5')E92`](&9U;F-T:6]N*')O
M;W1.;V1E<RP@<F5N9&5R4W1A=&EC*0I["B`@("!T:&ES+G)O;W1.;V1E<R`]
M(')O;W1.;V1E<SL*("`@('1H:7,N<F5N9&5R4W1A=&EC(#T@<F5N9&5R4W1A
M=&EC.PH@("`@=&AI<RYN;V1E<R`](&5V86PH)VY?)R`K('1H:7,N7VEN<W1A
M;F-E3F%M92D["B`@("!T:&ES+FAE861E<B`](&5V86PH)VA?)R`K('1H:7,N
M7VEN<W1A;F-E3F%M92D["B`@("!T:&ES+F]P=&EO;G,@/2!E=F%L*"=O7R<@
M*R!T:&ES+E]I;G-T86YC94YA;64I.PH@("`@=&AI<RYT87)G970@/2`G=%\G
M("L@=&AI<RY?:6YS=&%N8V5.86UE.PH@("`@=&AI<RY?<F5N9&5R5')E92@I
M.PI]"@I(;W)D95]4<F5E+G!R;W1O='EP92Y?<F5N9&5R5')E92`](&9U;F-T
M:6]N*"D*>PH@("`@=&AI<RYO=71P=70@/2`G)SL*("`@(&EF("@A=&AI<RYO
M<'1I;VYS6R=H:61E2&5A9&5R<R==*2!["B`@("`@("`@=&AI<RYO=71P=70@
M/2!T:&ES+E]B=6EL9$AE861E<B@I.PH@("`@?0H@("`@9F]R("AV87(@:2`]
M(#`[(&D@/"!T:&ES+G)O;W1.;V1E<RYL96YG=&@[(&DK*RD@>PH@("`@("`@
M('1H:7,N8G5I;&14<F5E*'1H:7,N<F]O=$YO9&5S6VE=*3L*("`@('T*("`@
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1H:7,N=&%R9V5T*2YI;FYE<DA4
M34P@/2!T:&ES+F]U='!U=#L*("`@('1H:7,N7V-O<G)E8W17:61T:$9O<E-C
M<F]L;&)A<B@I.PH@("`@+R\@268@=7-I;F<@86QT97)N871I;F<@<F]W('-H
M861I;F<L('=O<FL@;W5T(&-O<G)E8W0@<VAA9&4N"B`@("!I9B`H=&AI<RYO
M<'1I;VYS6R=A;'1E<FYA=&4G72D@>PH@("`@("`@('1H:7,N<W1R:7!E*"D[
M"B`@("!]"GT*"B\J*@H@*B!2971U<FYS('1H92!(5$U,(&-O9&4@9F]R(&$@
M:&5A9&5R(')O=RP@:68@;F5C97-S87)Y+@H@*@H@*B!`86-C97-S('!R:79A
M=&4*("H*("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&-O9&4@;V8@=&AE
M(&AE861E<B!R;W<@;W(@86X@96UP='D@<W1R:6YG+@H@*B\*2&]R9&5?5')E
M92YP<F]T;W1Y<&4N7V)U:6QD2&5A9&5R(#T@9G5N8W1I;VXH*0I["B`@("!I
M9B`H(71H:7,N:&5A9&5R+FQE;F=T:"D@>PH@("`@("`@(')E='5R;B`G)SL*
M("`@('T*"B`@("!V87(@:'1M;"`]("<\9&EV/B<["B`@("!F;W(@*'9A<B!I
M(#T@,#L@:2`\('1H:7,N:&5A9&5R+FQE;F=T:#L@:2LK*2!["B`@("`@("`@
M:'1M;"`K/2`G/&1I=B<["B`@("`@("`@:68@*'1H:7,N:&5A9&5R6VE=6R=C
M;&%S<R==*2!["B`@("`@("`@("`@(&AT;6P@*ST@)R!C;&%S<STB)R`K('1H
M:7,N:&5A9&5R6VE=6R=C;&%S<R==("L@)R(G.PH@("`@("`@('T*"B`@("`@
M("`@=F%R('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*("`@("`@("!I9B`H=&AI
M<RYH96%D97);:5U;)W=I9'1H)UTI('L*("`@("`@("`@("`@<W1Y;&4@*ST@
M)W=I9'1H.B<@*R!T:&ES+FAE861E<EMI75LG=VED=&@G72`K("<[)SL*("`@
M("`@("!]"B`@("`@("`@:68@*'1H:7,N:&5A9&5R6VE=6R=A;&EG;B==*2![
M"B`@("`@("`@("`@('-T>6QE("L]("=T97AT+6%L:6=N.B<@*R!T:&ES+FAE
M861E<EMI75LG86QI9VXG72`K("<[)SL*("`@("`@("!]"@H@("`@("`@(&AT
M;6P@*ST@)R!S='EL93TB)R`K('-T>6QE("L@)R(G.PH@("`@("`@(&AT;6P@
M*ST@)SXG.PH@("`@("`@(&AT;6P@*ST@=&AI<RYH96%D97);:5U;)VAT;6PG
M72`_('1H:7,N:&5A9&5R6VE=6R=H=&UL)UT@.B`G)FYB<W`[)SL*("`@("`@
M("!H=&UL("L]("<\+V1I=CXG.PH@("`@?0H*("`@(')E='5R;B!H=&UL("L@
M)SPO9&EV/B<["GT*"B\J*@H@*B!296-U<G-I=F4@9G5N8W1I;VX@=&\@=V%L
M:R!T:')O=6=H('1H92!T<F5E(&%R<F%Y(&%N9"!B=6EL9`H@*B!T:&4@;W5T
M<'5T+@H@*B\*2&]R9&5?5')E92YP<F]T;W1Y<&4N8G5I;&14<F5E(#T@9G5N
M8W1I;VXH;F]D94ED*0I["B`@("!T:&ES+F]U='!U="`K/2!T:&ES+F)U:6QD
M3&EN92AN;V1E260I.PH*("`@(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E
M261=6R=C:&EL9')E;B==*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@('9A
M<B!N=6U3=6)N;V1E<R`]('1H:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG
M72YL96YG=&@["B`@("`@("`@:68@*&YU;5-U8FYO9&5S(#X@,"D@>PH@("`@
M("`@("`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==*2![
M"B`@("`@("`@("`@("`@("!R;W=3='EL92`]("=D:7-P;&%Y.F)L;V-K.R<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R;W=3='EL
M92`]("=D:7-P;&%Y.FYO;F4[)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!T:&ES+F]U='!U="`K/2`G/&1I=B!I9#TB;F]D94-H:6QD<F5N7R<@*R!N
M;V1E260@*R`G(B!S='EL93TB)R`K(')O=U-T>6QE("L@)R(^)SL*"B`@("`@
M("`@("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@;G5M4W5B;F]D97,[(&,K*RD@
M>PH@("`@("`@("`@("`@("`@=F%R(&-H:6QD3F]D94ED(#T@=&AI<RYN;V1E
M<UMN;V1E261=6R=C:&EL9')E;B==6V-=.PH@("`@("`@("`@("`@("`@=&AI
M<RYN;V1E7W!O<UMC:&EL9$YO9&5)9%T@/2!N97<@07)R87DH*3L*("`@("`@
M("`@("`@("`@('1H:7,N;F]D95]P;W-;8VAI;&1.;V1E261=6R=P;W,G72`]
M(&,@*R`Q.PH@("`@("`@("`@("`@("`@=&AI<RYN;V1E7W!O<UMC:&EL9$YO
M9&5)9%U;)V-O=6YT)UT@/2!N=6U3=6)N;V1E<SL*("`@("`@("`@("`@("`@
M('1H:7,N8G5I;&14<F5E*&-H:6QD3F]D94ED*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@=&AI<RYO=71P=70@*ST@)SPO9&EV/B<["B`@("`@("`@
M?0H@("`@?0H*("`@(')E='5R;B!T<G5E.PI]"@I(;W)D95]4<F5E+G!R;W1O
M='EP92YB=6EL9$QI;F4@/2!F=6YC=&EO;BAN;V1E260I"GL*("`@('9A<B!S
M='EL92`]("<G.PH@("`@=F%R(')O=T-L87-S(#T@)W1R9652;W<G.PH@("`@
M:68@*'1H:7,N;F]D97-;;F]D94ED75LG8VQA<W,G72D@>PH@("`@("`@(')O
M=T-L87-S("L]("<@)R`K('1H:7,N;F]D97-;;F]D94ED75LG8VQA<W,G73L*
M("`@('T*"B`@("!V87(@;&EN92`]("<\9&EV(&-L87-S/2(G("L@<F]W0VQA
M<W,@*R`G(CXG.PH*("`@("\O($EF('=E(&AA=F4@:&5A9&5R<RP@=')A8VL@
M=VAI8V@@;&]G:6-A;"`B8V]L=6UN(B!W92=R92!I;B!F;W(*("`@("\O(&%N
M>2!G:79E;B!C96QL(&]F(&-O;G1E;G0N"B`@("!V87(@8V]L=6UN(#T@,#L*
M"B`@("!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG97AT<F$G72D@
M(3T@)W5N9&5F:6YE9"<@)B8*("`@("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN
M;V1E261=6R=E>'1R82==6S!=*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@
M('9A<B!E>'1R82`]('1H:7,N;F]D97-;;F]D94ED75LG97AT<F$G75LP73L*
M("`@("`@("!F;W(@*'9A<B!C(#T@,#L@8R`\(&5X=')A+FQE;F=T:#L@8RLK
M*2!["B`@("`@("`@("`@('-T>6QE(#T@=&AI<RYF;&]A=$1I<CL*("`@("`@
M("`@("`@:68@*'1H:7,N:&5A9&5R6V-O;'5M;ET@)B8@=&AI<RYH96%D97);
M8V]L=6UN75LG=VED=&@G72D@>PH@("`@("`@("`@("`@("`@<W1Y;&4@*ST@
M)W=I9'1H.B<@*R!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==("L@)SLG
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI;F4@*ST@)SQD:78@<W1Y
M;&4](B<@*R!S='EL92`K("<B/B<@*R!E>'1R85MC72`K("<\+V1I=CXG.PH@
M("`@("`@("`@("!C;VQU;6XK*SL*("`@("`@("!]"B`@("`@("`@9F]R("AV
M87(@9"`](&,[(&0@/"!E>'1R84-O;'-,969T.R!D*RLI('L*("`@("`@("`@
M("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@("`@("!I9B`H=&AI
M<RYH96%D97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T
M:"==*2!["B`@("`@("`@("`@("`@("!S='EL92`K/2`G=VED=&@Z)R`K('1H
M:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@;&EN92`K/2`G/&1I=B!S='EL93TB)R`K('-T>6QE
M("L@)R(^)FYB<W`[/"]D:78^)SL*("`@("`@("`@("`@8V]L=6UN*RL["B`@
M("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!F;W(@*'9A<B!C(#T@,#L@
M8R`\(&5X=')A0V]L<TQE9G0[(&,K*RD@>PH@("`@("`@("`@("!S='EL92`]
M('1H:7,N9FQO871$:7(["B`@("`@("`@("`@(&EF("AT:&ES+FAE861E<EMC
M;VQU;6Y=("8F('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UTI('L*("`@
M("`@("`@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);
M8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!L:6YE("L]("<\9&EV('-T>6QE/2(G("L@<W1Y;&4@*R`G(CXF;F)S
M<#L\+V1I=CXG.PH@("`@("`@("`@("!C;VQU;6XK*SL*("`@("`@("!]"B`@
M("!]"@H@("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@:68@*'1H:7,N
M:&5A9&5R6V-O;'5M;ET@)B8@=&AI<RYH96%D97);8V]L=6UN75LG=VED=&@G
M72D@>PH@("`@("`@('-T>6QE("L]("=W:61T:#HG("L@=&AI<RYH96%D97);
M8V]L=6UN75LG=VED=&@G72`K("<[)SL*("`@('T*("`@(&QI;F4@*ST@)SQD
M:78@<W1Y;&4](B<@*R!S='EL92`K("<B/B<["@H@("`@:68@*'1H:7,N;W!T
M:6]N<ULG;75L=&EL:6YE)UTI('L*("`@("`@("!L:6YE("L]("<\=&%B;&4@
M8V5L;'-P86-I;F<](C`B/CQT<CX\=&0^)SL*("`@('T*"B`@("!F;W(@*'9A
M<B!I(#T@=&AI<RYR96YD97)3=&%T:6,@/R`Q(#H@,#L@:2`\('1H:7,N;F]D
M97-;;F]D94ED75LG:6YD96YT)UT[(&DK*RD@>PH@("`@("`@(&EF("AT:&ES
M+F1R;W!L:6YE6VE=("8F('1H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@("`@
M("`@("`@("!L:6YE("L]("<\:6UG('-R8STB)R`K('1H:7,N:6UG1&ER("L@
M)R\G("L@=&AI<RYI;6=,:6YE("L@)R(@86QT/2)\)FYB<W`[)FYB<W`[)FYB
M<W`[(B!H96EG:'0](C(P(B!W:61T:#TB,C`B("\^)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!L:6YE("L]("<\:6UG('-R8STB)R`K('1H:7,N
M:6UG1&ER("L@)R\G("L@=&AI<RYI;6=";&%N:R`K("<B(&%L=#TB)FYB<W`[
M)FYB<W`[)FYB<W`[(B!H96EG:'0](C(P(B!W:61T:#TB,C`B("\^)SL*("`@
M("`@("!]"B`@("!]"B`@("!L:6YE("L]('1H:7,N7W-E=$YO9&54;V=G;&4H
M;F]D94ED*3L*("`@(&EF("AT:&ES+F]P=&EO;G-;)VUU;'1I;&EN92==*2![
M"B`@("`@("`@;&EN92`K/2`G/"]T9#X\=&0^)SL*("`@('T*("`@(&QI;F4@
M*ST@=&AI<RY?<V5T3&%B96PH;F]D94ED*3L*"B`@("!I9B`H=&AI<RYO<'1I
M;VYS6R=M=6QT:6QI;F4G72D@>PH@("`@("`@(&QI;F4@*ST@)SPO=&0^/"]T
M<CX\+W1A8FQE/B<["B`@("!]"@H@("`@;&EN92`K/2`G/"]D:78^)SL*("`@
M(&-O;'5M;BLK.PH*("`@(&EF("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=
M6R=E>'1R82==*2`A/2`G=6YD969I;F5D)R`F)@H@("`@("`@('1Y<&5O9BAT
M:&ES+FYO9&5S6VYO9&5)9%U;)V5X=')A)UU;,5TI("$]("=U;F1E9FEN960G
M*2!["B`@("`@("`@=F%R(&5X=')A(#T@=&AI<RYN;V1E<UMN;V1E261=6R=E
M>'1R82==6S%=.PH@("`@("`@(&9O<B`H=F%R(&,@/2`P.R!C(#P@97AT<F$N
M;&5N9W1H.R!C*RLI('L*("`@("`@("`@("`@<W1Y;&4@/2!T:&ES+F9L;V%T
M1&ER.PH@("`@("`@("`@("!I9B`H=&AI<RYH96%D97);8V]L=6UN72`F)B!T
M:&ES+FAE861E<EMC;VQU;6Y=6R=W:61T:"==*2!["B`@("`@("`@("`@("`@
M("!S='EL92`K/2`G=VED=&@Z)R`K('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I
M9'1H)UT@*R`G.R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@;&EN92`K
M/2`G/&1I=B!S='EL93TB)R`K('-T>6QE("L@)R(^)R`K(&5X=')A6V-=("L@
M)SPO9&EV/B<["B`@("`@("`@("`@(&-O;'5M;BLK.PH@("`@("`@('T*("`@
M("`@("!F;W(@*'9A<B!D(#T@8SL@9"`\(&5X=')A0V]L<U)I9VAT.R!D*RLI
M('L*("`@("`@("`@("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@
M("`@("!I9B`H=&AI<RYH96%D97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC
M;VQU;6Y=6R=W:61T:"==*2!["B`@("`@("`@("`@("`@("!S='EL92`K/2`G
M=VED=&@Z)R`K('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@;&EN92`K/2`G/&1I=B!S='EL
M93TB)R`K('-T>6QE("L@)R(^)FYB<W`[/"]D:78^)SL*("`@("`@("`@("`@
M8V]L=6UN*RL["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!F;W(@
M*'9A<B!C(#T@,#L@8R`\(&5X=')A0V]L<U)I9VAT.R!C*RLI('L*("`@("`@
M("`@("`@<W1Y;&4@/2!T:&ES+F9L;V%T1&ER.PH@("`@("`@("`@("!I9B`H
M=&AI<RYH96%D97);8V]L=6UN72`F)B!T:&ES+FAE861E<EMC;VQU;6Y=6R=W
M:61T:"==*2!["B`@("`@("`@("`@("`@("!S='EL92`K/2`G=VED=&@Z)R`K
M('1H:7,N:&5A9&5R6V-O;'5M;EU;)W=I9'1H)UT@*R`G.R<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@;&EN92`K/2`G/&1I=B!S='EL93TB)R`K('-T
M>6QE("L@)R(^)FYB<W`[/"]D:78^)SL*("`@("`@("`@("`@8V]L=6UN*RL[
M"B`@("`@("`@?0H@("`@?0H@("`@;&EN92`K/2`G/"]D:78^)SL*"B`@("!R
M971U<FX@;&EN93L*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N7W-E=$QA8F5L
M(#T@9G5N8W1I;VXH;F]D94ED*0I["B`@("!L86)E;"`]('1H:7,N;F]D97-;
M;F]D94ED75LG;&%B96PG73L*"B`@("!I9B`H=&AI<RYN;V1E<UMN;V1E261=
M6R=U<FPG72D@>PH@("`@("`@('9A<B!U<FQ#;&%S<R`]("<G.PH@("`@("`@
M(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)W5R;&-L87-S)UTI('L*("`@("`@
M("`@("`@=7)L0VQA<W,@/2`G(&-L87-S/2(G("L@=&AI<RYN;V1E<UMN;V1E
M261=6R=U<FQC;&%S<R==("L@)R(G.PH@("`@("`@('T@96QS92!I9B`H=&AI
M<RYO<'1I;VYS6R=U<FQC;&%S<R==*2!["B`@("`@("`@("`@('5R;$-L87-S
M(#T@)R!C;&%S<STB)R`K('1H:7,N;W!T:6]N<ULG=7)L8VQA<W,G72`K("<B
M)SL*("`@("`@("!]"@H@("`@("`@('9A<B!T87)G970@/2`G)SL*("`@("`@
M("!I9B`H=&AI<RYN;V1E<UMN;V1E261=6R=T87)G970G72D@>PH@("`@("`@
M("`@("!T87)G970@/2`G('1A<F=E=#TB)R`K('1H:7,N;F]D97-;;F]D94ED
M75LG=&%R9V5T)UT@*R`G(B<["B`@("`@("`@?2!E;'-E(&EF("AT:&ES+F]P
M=&EO;G-;)W1A<F=E="==*2!["B`@("`@("`@("`@('1A<F=E="`]("<@=&%R
M9V5T/2(G("L@=&AI<RYO<'1I;VYS6R=T87)G970G72`K("<B)SL*("`@("`@
M("!]"@H@("`@("`@('9A<B!O;F-L:6-K(#T@)R<["B`@("`@("`@:68@*'1H
M:7,N;F]D97-;;F]D94ED75LG;VYC;&EC:R==*2!["B`@("`@("`@("`@(&]N
M8VQI8VL@/2`G(&]N8VQI8VL](B<@*R!T:&ES+FYO9&5S6VYO9&5)9%U;)V]N
M8VQI8VLG72`K("<B)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`G/&$G
M("L@=7)L0VQA<W,@*R`G(&AR968](B<@*R!T:&ES+FYO9&5S6VYO9&5)9%U;
M)W5R;"==("L@)R(G("L@=&%R9V5T("L@;VYC;&EC:R`K("<^)R`K('1H:7,N
M7W-E=$YO9&5)8V]N*&YO9&5)9"D@*R!L86)E;"`K("<\+V$^)SL*("`@('T@
M96QS92!["B`@("`@("`@<F5T=7)N("<\<W!A;B!C;&%S<STB=&]G9VQE(B!O
M;F-L:6-K/2(G("L@=&AI<RY?:6YS=&%N8V5.86UE("L@)RYT;V=G;&4H7"<G
M("L@;F]D94ED("L@)UPG*2(^)R`K('1H:7,N7W-E=$YO9&5)8V]N*&YO9&5)
M9"D@*R!L86)E;"`K("<\+W-P86X^)SL*("`@('T*?0H*2&]R9&5?5')E92YP
M<F]T;W1Y<&4N7W-E=$YO9&54;V=G;&4@/2!F=6YC=&EO;BAN;V1E260I"GL*
M("`@('9A<B!A='1R:6(@/2`G)SL*("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)
M9%U;)VEN9&5N="==(#T]("<P)R`F)@H@("`@("`@('1Y<&5O9BAT:&ES+FYO
M9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI("$]("=U;F1E9FEN960G*2!["B`@
M("`@("`@+R\@5&]P(&QE=F5L('=I=&@@8VAI;&1R96XN"B`@("`@("`@=&AI
M<RYD<F]P;&EN95LP72`](&9A;'-E.PH@("`@("`@(&EF("AT:&ES+G)E;F1E
M<E-T871I8RD@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@871T<FEB(#T@)R!S='EL93TB8W5R<V]R.G!O
M:6YT97(B(&]N8VQI8VL](B<@*R!T:&ES+E]I;G-T86YC94YA;64@*R`G+G1O
M9V=L92A<)R<@*R!N;V1E260@*R`G7"<I(B<["B`@("`@("`@?0H@("`@?2!E
M;'-E(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==("$]("<P)R`F
M)@H@("`@("`@("`@("`@("!T>7!E;V8H=&AI<RYN;V1E<UMN;V1E261=6R=C
M:&EL9')E;B==*2`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@("\O($YO9&4@
M;F\@8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N;F]D95]P;W-;;F]D94ED
M75LG<&]S)UT@/"!T:&ES+FYO9&5?<&]S6VYO9&5)9%U;)V-O=6YT)UTI('L*
M("`@("`@("`@("`@+R\@3F]T(&QA<W0@;F]D92X*("`@("`@("`@("`@=&AI
M<RYD<F]P;&EN95MT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==72`]('1R
M=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=&AI<RYD<F]P;&EN
M95MT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==72`](&9A;'-E.PH@("`@
M("`@('T*("`@('T@96QS92!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED
M75LG8VAI;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`O+R!.
M;V1E('=I=&@@8VAI;&1R96XN"B`@("`@("`@:68@*'1H:7,N;F]D95]P;W-;
M;F]D94ED75LG<&]S)UT@/"!T:&ES+FYO9&5?<&]S6VYO9&5)9%U;)V-O=6YT
M)UTI('L*("`@("`@("`@("`@+R\@3F]T(&QA<W0@;F]D92X*("`@("`@("`@
M("`@=&AI<RYD<F]P;&EN95MT:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==
M72`]('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@3&%S
M="!N;V1E+@H@("`@("`@("`@("!T:&ES+F1R;W!L:6YE6W1H:7,N;F]D97-;
M;F]D94ED75LG:6YD96YT)UU=(#T@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M(&EF("@A=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@871T<FEB
M(#T@)R!S='EL93TB8W5R<V]R.G!O:6YT97(B(&]N8VQI8VL](B<@*R!T:&ES
M+E]I;G-T86YC94YA;64@*R`G+G1O9V=L92A<)R<@*R!N;V1E260@*R`G7"<I
M(B<["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("`O+R!4;W`@;&5V
M96P@;F]D92!W:71H(&YO(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES+G)E
M;F1E<E-T871I8RD@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@
M?0H@("`@("`@('1H:7,N9')O<&QI;F5;,%T@/2!F86QS93L*("`@('T*"B`@
M("!N;V1E5&]G9VQE(#T@=&AI<RY?9V5T3F]D951O9V=L92AN;V1E260I.PH@
M("`@:6UG(#T@)SQI;6<@:60](FYO9&54;V=G;&5?)R`K(&YO9&5)9"`K("<B
M('-R8STB)R`K('1H:7,N:6UG1&ER("L@)R\G("L@;F]D951O9V=L95LP72`K
M("<B("<["B`@("!I9B`H;F]D951O9V=L95LQ72D@>PH@("`@("`@(&EM9R`K
M/2`G86QT/2(G("L@;F]D951O9V=L95LQ72`K("<B("<["B`@("!]"B`@("!I
M;6<@*ST@871T<FEB("L@)R!H96EG:'0](C(P(B!W:61T:#TB,C`B("\^)SL*
M("`@(')E='5R;B!I;6<["GT*"DAO<F1E7U1R964N<')O=&]T>7!E+E]G971.
M;V1E5&]G9VQE(#T@9G5N8W1I;VXH;F]D94ED*0I["B`@("!V87(@;F]D951O
M9V=L92`](&YE=R!!<G)A>2@G)RP@)R<I.PH@("`@:68@*'1H:7,N;F]D97-;
M;F]D94ED75LG:6YD96YT)UT@/3T@)S`G("8F"B`@("`@("`@='EP96]F*'1H
M:7,N;F]D97-;;F]D94ED75LG8VAI;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I
M('L*("`@("`@("`O+R!4;W`@;&5V96P@=VET:"!C:&EL9')E;BX*("`@("`@
M("!I9B`H=&AI<RYR96YD97)3=&%T:6,I('L*("`@("`@("`@("`@<F5T=7)N
M(&YO9&54;V=G;&4["B`@("`@("`@?2!E;'-E(&EF("@A=&AI<RYO<'1I;VYS
M6R=L:6YE<R==*2!["B`@("`@("`@("`@(&YO9&54;V=G;&5;,%T@/2!T:&ES
M+FEM9T)L86YK.PH@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)R9N8G-P
M.R9N8G-P.R9N8G-P.R<*("`@("`@("!](&5L<V4@:68@*'1H:7,N;F]D97-;
M;F]D94ED75LG97AP86YD960G72D@>PH@("`@("`@("`@("!N;V1E5&]G9VQE
M6S!=(#T@=&AI<RYI;6=-:6YU<T]N;'D["B`@("`@("`@("`@(&YO9&54;V=G
M;&5;,5T@/2`G+2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;F]D
M951O9V=L95LP72`]('1H:7,N:6UG4&QU<T]N;'D["B`@("`@("`@("`@(&YO
M9&54;V=G;&5;,5T@/2`G*R<["B`@("`@("`@?0H@("`@?2!E;'-E(&EF("AT
M:&ES+FYO9&5S6VYO9&5)9%U;)VEN9&5N="==("$]("<P)R`F)@H@("`@("`@
M('1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)V-H:6QD<F5N)UTI(#T]("=U
M;F1E9FEN960G*2!["B`@("`@("`@+R\@3F]D92!N;R!C:&EL9')E;BX*("`@
M("`@("!I9B`H=&AI<RYN;V1E7W!O<UMN;V1E261=6R=P;W,G72`\('1H:7,N
M;F]D95]P;W-;;F]D94ED75LG8V]U;G0G72D@>PH@("`@("`@("`@("`O+R!.
M;W0@;&%S="!N;V1E+@H@("`@("`@("`@("!I9B`H=&AI<RYO<'1I;VYS6R=L
M:6YE<R==*2!["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI
M<RYI;6=*;VEN.PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LQ72`]("=\
M+2<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!N;V1E
M5&]G9VQE6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@("`@("`@("`@(&YO
M9&54;V=G;&5;,5T@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($QA<W0@;F]D
M92X*("`@("`@("`@("`@:68@*'1H:7,N;W!T:6]N<ULG;&EN97,G72D@>PH@
M("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG2F]I;D)O
M='1O;3L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G8"TG.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L
M95LP72`]('1H:7,N:6UG0FQA;FL["B`@("`@("`@("`@("`@("!N;V1E5&]G
M9VQE6S%=(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!](&5L<V4@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO
M9&5)9%U;)V-H:6QD<F5N)UTI("$]("=U;F1E9FEN960G*2!["B`@("`@("`@
M+R\@3F]D92!W:71H(&-H:6QD<F5N+@H@("`@("`@(&EF("AT:&ES+FYO9&5?
M<&]S6VYO9&5)9%U;)W!O<R==(#P@=&AI<RYN;V1E7W!O<UMN;V1E261=6R=C
M;W5N="==*2!["B`@("`@("`@("`@("\O($YO="!L87-T(&YO9&4N"B`@("`@
M("`@("`@(&EF("@A=&AI<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@("`@
M("`@("`@("!N;V1E5&]G9VQE6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@
M("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G)FYB<W`[)FYB<W`[)FYB<W`[
M)SL*("`@("`@("`@("`@?2!E;'-E(&EF("AT:&ES+G)E;F1E<E-T871I8RD@
M>PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG2F]I
M;CL*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;,5T@/2`G?"TG.PH@("`@
M("`@("`@("!](&5L<V4@:68@*'1H:7,N;F]D97-;;F]D94ED75LG97AP86YD
M960G72D@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H:7,N
M:6UG36EN=7,["B`@("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RTG
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LP72`]('1H:7,N:6UG4&QU<SL*("`@("`@("`@("`@("`@(&YO9&54
M;V=G;&5;,5T@/2`G*R<["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!,87-T(&YO9&4N"B`@("`@("`@("`@(&EF("@A
M=&AI<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@("`@("`@("`@("!N;V1E
M5&]G9VQE6S!=(#T@=&AI<RYI;6=";&%N:SL*("`@("`@("`@("`@("`@(&YO
M9&54;V=G;&5;,5T@/2`G)FYB<W`[)SL*("`@("`@("`@("`@?2!E;'-E(&EF
M("AT:&ES+G)E;F1E<E-T871I8RD@>PH@("`@("`@("`@("`@("`@;F]D951O
M9V=L95LP72`]('1H:7,N:6UG2F]I;D)O='1O;3L*("`@("`@("`@("`@("`@
M(&YO9&54;V=G;&5;,5T@/2`G8"TG.PH@("`@("`@("`@("!](&5L<V4@:68@
M*'1H:7,N;F]D97-;;F]D94ED75LG97AP86YD960G72D@>PH@("`@("`@("`@
M("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG36EN=7-";W1T;VT["B`@
M("`@("`@("`@("`@("!N;V1E5&]G9VQE6S%=(#T@)RTG.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;F]D951O9V=L95LP72`]('1H
M:7,N:6UG4&QU<T)O='1O;3L*("`@("`@("`@("`@("`@(&YO9&54;V=G;&5;
M,5T@/2`G*R<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!](&5L<V4@
M>PH@("`@("`@("\O(%1O<"!L979E;"!N;V1E('=I=&@@;F\@8VAI;&1R96XN
M"B`@("`@("`@:68@*'1H:7,N<F5N9&5R4W1A=&EC*2!["B`@("`@("`@("`@
M(')E='5R;B!N;V1E5&]G9VQE.PH@("`@("`@('T*("`@("`@("!I9B`H=&AI
M<RYO<'1I;VYS6R=L:6YE<R==*2!["B`@("`@("`@("`@(&YO9&54;V=G;&5;
M,%T@/2!T:&ES+FEM9TYU;&Q/;FQY.PH@("`@("`@("`@("!N;V1E5&]G9VQE
M6S%=(#T@)R9N8G-P.R9N8G-P.R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@;F]D951O9V=L95LP72`]('1H:7,N:6UG0FQA;FL["B`@("`@("`@
M("`@(&YO9&54;V=G;&5;,5T@/2`G)FYB<W`[)FYB<W`[)FYB<W`[)SL*("`@
M("`@("!]"B`@("!]"@H@("`@<F5T=7)N(&YO9&54;V=G;&4["GT*"DAO<F1E
M7U1R964N<')O=&]T>7!E+E]S971.;V1E26-O;B`](&9U;F-T:6]N*&YO9&5)
M9"D*>PH@("`@=F%R(&EM9T1I<B`]("AT>7!E;V8H=&AI<RYN;V1E<UMN;V1E
M261=6R=I8V]N9&ER)UTI("$]("=U;F1E9FEN960G*2`_"B`@("`@("`@=&AI
M<RYN;V1E<UMN;V1E261=6R=I8V]N9&ER)UT@.@H@("`@("`@('1H:7,N:6UG
M1&ER.PH@("`@:68@*&EM9T1I<BD@>PH@("`@("`@(&EM9T1I<B`K/2`G+R<[
M"B`@("!]"@H@("`@:68@*'1Y<&5O9BAT:&ES+FYO9&5S6VYO9&5)9%U;)VEC
M;VXG72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`O+R!.;V1E(&AA<R!A
M('5S97(@9&5F:6YE9"!I8V]N+@H@("`@("`@(&EF("@A=&AI<RYN;V1E<UMN
M;V1E261=6R=I8V]N)UTI('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*("`@("`@("!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG
M:6-O;F]P96XG72D@(3T@)W5N9&5F:6YE9"<@)B8@=&AI<RYN;V1E<UMN;V1E
M261=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@(&EM9R`]('1H:7,N;F]D
M97-;;F]D94ED75LG:6-O;F]P96XG73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I;6<@/2!T:&ES+FYO9&5S6VYO9&5)9%U;)VEC;VXG73L*("`@
M("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("\O(%5S92!S=&%N9&%R9"!I
M8V]N('-E="X*("`@("`@("!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED
M75LG8VAI;&1R96XG72D@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@("`@
M+R\@3F]D92!W:71H(&-H:6QD<F5N+@H@("`@("`@("`@("!I;6<@/2`H=&AI
M<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==*2`_('1H:7,N:6UG1F]L9&5R
M3W!E;@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z('1H:7,N:6UG1F]L9&5R.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O($YO9&4@;F\@8VAI;&1R96XN"B`@("`@("`@("`@
M(&EM9R`]('1H:7,N:6UG3&5A9CL*("`@("`@("!]"B`@("!]"@H@("`@=F%R
M(&EM9W1X="`]("<\:6UG('-R8STB)R`K(&EM9T1I<B`K(&EM9R`K("<B)SL*
M"B`@("!I9B`H='EP96]F*'1H:7,N;F]D97-;;F]D94ED75LG:6-O;F%L="==
M*2`A/2`G=6YD969I;F5D)RD@>PH@("`@("`@(&EM9W1X="`K/2`G(&%L=#TB
M)R`K('1H:7,N;F]D97-;;F]D94ED75LG:6-O;F%L="==("L@)R(G.PH@("`@
M?0H*("`@(')E='5R;B!I;6=T>'0@*R`G("\^("<["GT*"DAO<F1E7U1R964N
M<')O=&]T>7!E+G1O9V=L92`](&9U;F-T:6]N*&YO9&5)9"D*>PH@("`@=&AI
M<RYN;V1E<UMN;V1E261=6R=E>'!A;F1E9"==(#T@(71H:7,N;F]D97-;;F]D
M94ED75LG97AP86YD960G73L*("`@(&EF("AT:&ES+FYO9&5S6VYO9&5)9%U;
M)V5X<&%N9&5D)UTI('L*("`@("`@("!I9B`H;F]D92`](&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*"=N;V1E0VAI;&1R96Y?)R`K(&YO9&5)9"DI('L*("`@
M("`@("`@("`@;F]D92YS='EL92YD:7-P;&%Y(#T@)V)L;V-K)SL*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@(&EF("AN;V1E(#T@9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)VYO9&5#:&EL9')E;E\G("L@;F]D94ED*2D@>PH@
M("`@("`@("`@("!N;V1E+G-T>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("`@
M("`@?0H@("`@?0H*("`@("\O($EF('5S:6YG(&%L=&5R;F%T:6YG(')O=R!S
M:&%D:6YG+"!W;W)K(&]U="!C;W)R96-T('-H861E+@H@("`@:68@*'1H:7,N
M;W!T:6]N<ULG86QT97)N871E)UTI('L*("`@("`@("!T:&ES+G-T<FEP92@I
M.PH@("`@?0H*("`@(&YO9&54;V=G;&4@/2!T:&ES+E]G971.;V1E5&]G9VQE
M*&YO9&5)9"D["B`@("!I9B`H=&]G9VQE(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H)VYO9&54;V=G;&5?)R`K(&YO9&5)9"DI('L*("`@("`@("!T;V=G
M;&4N<W)C(#T@=&AI<RYI;6=$:7(@*R`G+R<@*R!N;V1E5&]G9VQE6S!=.PH@
M("`@("`@('1O9V=L92YA;'0@/2!N;V1E5&]G9VQE6S%=.PH@("`@?0H*("`@
M('1H:7,N<V%V95-T871E*&YO9&5)9"P@=&AI<RYN;V1E<UMN;V1E261=6R=E
M>'!A;F1E9"==*0I]"@I(;W)D95]4<F5E+G!R;W1O='EP92YS=')I<&4@/2!F
M=6YC=&EO;B@I"GL*("`@("\O(%1H92!E;&5M96YT('1O('-T87)T('-T<FEP
M:6YG+@H@("`@=F%R(&ED(#T@87)G=6UE;G1S6S!=(#\@87)G=6UE;G1S6S!=
M(#H@=&AI<RYT87)G970["@H@("`@+R\@5&AE(&9L86<@=V4G;&P@=7-E('1O
M(&ME97`@=')A8VL@;V8@=VAE=&AE<B!T:&4@8W5R<F5N="!R;W<@:7,*("`@
M("\O(&]D9"!O<B!E=F5N+@H@("`@=F%R(&5V96X@/2!A<F=U;65N='-;,5T@
M/R!A<F=U;65N='-;,5T@.B!F86QS93L*"B`@("`O+R!/8G1A:6X@82!R969E
M<F5N8V4@=&\@=&AE('1R964@<&%R96YT(&5L96UE;G0N"B`@("!V87(@=')E
M92`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&ED*3L*("`@(&EF("@A=')E
M92D@>PH@("`@("`@(')E='5R;B!E=F5N.PH@("`@?0H*("`@("\O($ET97)A
M=&4@;W9E<B!E86-H(&-H:6QD(&1I=BX*("`@(&9O<B`H=F%R(&D@/2`P.R!I
M(#P@=')E92YC:&EL9$YO9&5S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@:68@
M*'1R964N8VAI;&1.;V1E<UMI72YI9"YI;F1E>$]F*"=N;V1E0VAI;&1R96XG
M*2`A/2`M,2D@>PH@("`@("`@("`@("!I9B`H=&AI<RYN;V1E<UMT<F5E+F-H
M:6QD3F]D97-;:5TN:60N<F5P;&%C92@G;F]D94-H:6QD<F5N7R<L("<G*5U;
M)V5X<&%N9&5D)UTI('L*("`@("`@("`@("`@("`@(&5V96X@/2!T:&ES+G-T
M<FEP92AT<F5E+F-H:6QD3F]D97-;:5TN:60L(&5V96XI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=')E92YC:&EL9$YO
M9&5S6VE=+F-L87-S3F%M92`]('1R964N8VAI;&1.;V1E<UMI72YC;&%S<TYA
M;64N<F5P;&%C92@G(')O=T5V96XG+"`G)RDN<F5P;&%C92@G(')O=T]D9"<L
M("<G*3L*("`@("`@("`@("`@=')E92YC:&EL9$YO9&5S6VE=+F-L87-S3F%M
M92`K/2!E=F5N(#\@)R!R;W=%=F5N)R`Z("<@<F]W3V1D)SL*"B`@("`@("`@
M("`@("\O($9L:7`@9G)O;2!O9&0@=&\@979E;BP@;W(@=FEC92UV97)S82X*
M("`@("`@("`@("`@979E;B`]("%E=F5N.PH@("`@("`@('T*("`@('T*"B`@
M("!R971U<FX@979E;CL*?0H*2&]R9&5?5')E92YP<F]T;W1Y<&4N<V%V95-T
M871E(#T@9G5N8W1I;VXH;F]D94ED+"!E>'!A;F1E9"D*>PH@("`@=F%R(&YE
M=T-O;VMI92`]("<G.PH@("`@=F%R(&]L9$-O;VMI92`]('1H:7,N7V=E=$-O
M;VMI92AT:&ES+E]I;G-T86YC94YA;64@*R`G7V5X<&%N9&5D)RD["B`@("!I
M9B`H97AP86YD960I('L*("`@("`@("`O+R!%>'!A;F0@<F5Q=65S=&5D('-O
M(&%D9"!T;R!C;V]K:64N"B`@("`@("`@;F5W0V]O:VEE(#T@*&]L9$-O;VMI
M92D@/R!O;&1#;V]K:64@*R`G+"<@.B`G)SL*("`@("`@("!N97=#;V]K:64@
M/2!N97=#;V]K:64@*R!N;V1E260["B`@("!](&5L<V4@>PH@("`@("`@("\O
M($-O;&QA<'-E(')E<75E<W1E9"!S;R!R96UO=F4@9G)O;2!C;V]K:64N"B`@
M("`@("`@=F%R(&YO9&5S(#T@;VQD0V]O:VEE+G-P;&ET*"<L)RD["B`@("`@
M("`@=F%R(&YE=TYO9&5S(#T@;F5W($%R<F%Y*"D["B`@("`@("`@9F]R("AV
M87(@:2`](#`[(&D@/"!N;V1E<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@
M("!I9B`H;F]D97-;:5T@(3T@;F]D94ED*2!["B`@("`@("`@("`@("`@("!N
M97=.;V1E<UMN97=.;V1E<RYL96YG=&A=(#T@;F]D97-;:5T["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@;F5W0V]O:VEE(#T@;F5W3F]D97,N
M:F]I;B@G+"<I.PH@("`@?0H@("`@=&AI<RY?<V5T0V]O:VEE*'1H:7,N7VEN
M<W1A;F-E3F%M92`K("=?97AP86YD960G+"!N97=#;V]K:64I.PI]"@I(;W)D
M95]4<F5E+G!R;W1O='EP92Y?9V5T0V]O:VEE(#T@9G5N8W1I;VXH;F%M92D*
M>PH@("`@=F%R(&1C(#T@9&]C=6UE;G0N8V]O:VEE.PH@("`@=F%R('!R969I
M>"`](&YA;64@*R`G/65X<"<["B`@("!V87(@8F5G:6X@/2!D8RYI;F1E>$]F
M*"<[("<@*R!P<F5F:7@I.PH@("`@:68@*&)E9VEN(#T]("TQ*2!["B`@("`@
M("`@8F5G:6X@/2!D8RYI;F1E>$]F*'!R969I>"D["B`@("`@("`@:68@*&)E
M9VEN("$](#`I('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*
M("`@('T@96QS92!["B`@("`@("`@8F5G:6X@*ST@,CL*("`@('T*("`@('9A
M<B!E;F0@/2!D;V-U;65N="YC;V]K:64N:6YD97A/9B@G.R<L(&)E9VEN*3L*
M("`@(&EF("AE;F0@/3T@+3$I('L*("`@("`@("!E;F0@/2!D8RYL96YG=&@[
M"B`@("!]"B`@("!R971U<FX@=6YE<V-A<&4H9&,N<W5B<W1R:6YG*&)E9VEN
M("L@<')E9FEX+FQE;F=T:"P@96YD*2D["GT*"DAO<F1E7U1R964N<')O=&]T
M>7!E+E]S971#;V]K:64@/2!F=6YC=&EO;BAN86UE+"!V86QU92D*>PH@("`@
M=F%R(&-U<D-O;VMI92`](&YA;64@*R`G/65X<"<@*R!E<V-A<&4H=F%L=64I
M.PH@("`@8W5R0V]O:VEE("L]("<[1$]-04E./3P_<&AP(&5C:&\@)$=,3T)!
M3%-;)V-O;F8G75LG8V]O:VEE)UU;)V1O;6%I;B==.R`_/CM0051(/3P_<&AP
M(&5C:&\@)$=,3T)!3%-;)V-O;F8G75LG8V]O:VEE)UU;)W!A=&@G73L@/SX[
M)SL*("`@(&1O8W5M96YT+F-O;VMI92`](&-U<D-O;VMI93L*?0H*2&]R9&5?
M5')E92YP<F]T;W1Y<&4N7V-O<G)E8W17:61T:$9O<E-C<F]L;&)A<B`](&9U
M;F-T:6]N*"D*>PH\/W!H<"!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S
M475I<FLH)W-C<F]L;&)A<E]I;E]W87DG*2DZ(#\^"B`@("`O+R!#;W)R96-T
M(&9O<B!F<F%M92!S8W)O;&QB87(@:6X@244@8GD@9&5T97)M:6YI;F<@:68@
M82!S8W)O;&QB87(@:7,@<')E<V5N="P*("`@("\O(&%N9"!I9B!N;W0@<F5A
M9&IU<W1I;F<@=&AE(&UA<F=I;E)I9VAT('!R;W!E<G1Y('1O(#`*("`@("\O
M(%-E92!H='1P.B\O=W=W+GAS-&%L;"YN;"]^<'!K+VIS+V1O8W1Y<&5S+FAT
M;6P@9F]R('=H>2!T:&ES('=O<FMS"B`@("!I9B`H9&]C=6UE;G0N9&]C=6UE
M;G1%;&5M96YT+F-L:65N=$AE:6=H="`]/2!D;V-U;65N="YD;V-U;65N=$5L
M96UE;G0N;V9F<V5T2&5I9VAT*2!["B`@("`@("`@+R\@;F\@<V-R;VQL8F%R
M('!R97-E;G0L('1A:V4@87=A>2!E>'1R82!M87)G:6X*("`@("`@("!D;V-U
M;65N="YB;V1Y+G-T>6QE+FUA<F=I;E)I9VAT(#T@)S`G.PH@("`@?2!E;'-E
M('L*("`@("`@("!D;V-U;65N="YB;V1Y+G-T>6QE+FUA<F=I;E)I9VAT(#T@
M)S$U<'@G.PH@("`@?0H\/W!H<"!E;F1I9CL@/SX*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96$N:G,`````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,34S(#$P-3$U-#,T,30T(#`R-#`S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!V
M87(@7V5D:71O<E]U<FP@/2`B/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@/SXO<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+R(["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S4V,B`Q,#4Q-30S-#$T-"`P,C,T,#``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/'-C<FEP="!T>7!E
M/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IV87(@9&$@/2`H9&]C=6UE;G0N
M86QL*2`_(#$@.B`P.PIV87(@<'(@/2`H=VEN9&]W+G!R:6YT*2`_(#$@.B`P
M.PIV87(@;6%C(#T@*&YA=FEG871O<BYU<V5R06=E;G0N:6YD97A/9B@B36%C
M(BD@(3T@+3$I.PH*:68@*'=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*2!["B`@
M("!W:6YD;W<N861D179E;G1,:7-T96YE<B@G;&]A9"<L('!R:6YT5VEN+"!F
M86QS92D["GT@96QS92!I9B`H=VEN9&]W+F%T=&%C:$5V96YT*2!["B`@("!W
M:6YD;W<N871T86-H179E;G0H)V]N;&]A9"<L('!R:6YT5VEN*3L*?2!E;'-E
M(&EF("AW:6YD;W<N;VYL;V%D("$](&YU;&PI('L*("`@('9A<B!O;&1/;DQO
M860@/2!W:6YD;W<N;VYL;V%D.PH@("`@=VEN9&]W+F]N;&]A9"`](&9U;F-T
M:6]N*&4I"B`@("!["B`@("`@("`@;VQD3VY,;V%D*&4I.PH@("`@("`@('!R
M:6YT5VEN*"D["B`@("!].PI](&5L<V4@>PH@("`@=VEN9&]W+F]N;&]A9"`]
M('!R:6YT5VEN.PI]"@IF=6YC=&EO;B!P<FEN=%=I;B@I"GL*("`@(&EF("AP
M<BD@>PH@("`@("`@("\O($Y3-"LL($E%-2L*("`@("`@("!W:6YD;W<N<')I
M;G0H*3L*("`@('T@96QS92!I9B`H(6UA8RD@>PH@("`@("`@("\O($E%,R!A
M;F0@244T(&]N(%!#"B`@("`@("`@5D)P<FEN=%=I;B@I.PH@("`@?2!E;'-E
M('L*("`@("`@("`O+R!E=F5R>71H:6YG(&5L<V4*("`@("`@("!H86YD;&5?
M97)R;W(H*3L*("`@('T*?0H*=VEN9&]W+F]N97)R;W(@/2!H86YD;&5?97)R
M;W(["G=I;F1O=RYO;F%F=&5R<')I;G0@/2!F=6YC=&EO;B@I('MW:6YD;W<N
M8VQO<V4H*7T*"F9U;F-T:6]N(&AA;F1L95]E<G)O<B@I"GL*("`@('=I;F1O
M=RYA;&5R="@G/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(EEO=7(@8G)O=W-E
M<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#
M;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+B(I*2`_/B<I.PH@("`@<F5T
M=7)N('1R=64["GT*"FEF("@A<'(@)B8@(6UA8RD@>PH@("`@:68@*&1A*2![
M"B`@("`@("`@+R\@5&AI<R!M=7-T(&)E($E%-"!O<B!G<F5A=&5R"B`@("`@
M("`@=V)V97)S(#T@(C@X-39&.38Q+3,T,$$M,3%$,"U!.39"+3`P0S`T1D0W
M,#5!,B(["B`@("!](&5L<V4@>PH@("`@("`@("\O('1H:7,@;75S="!B92!)
M13,N>`H@("`@("`@('=B=F5R<R`](")%04(R,D%#,RTS,$,Q+3$Q0T8M03=%
M0BTP,#`P0S`U0D%%,$(B.PH@("`@?0H*("`@(&1O8W5M96YT+G=R:71E*"(\
M3T)*14-4($E$/5PB5T)<(B!724142#U<(C!<(B!(14E'2%0]7"(P7"(@0TQ!
M4U-)1#U<(D-,4TE$.B(I.PH@("`@9&]C=6UE;G0N=W)I=&4H=V)V97)S("L@
M(EPB/B`\+T]"2D5#5#XB*3L*?0H*+R\@+2T^"CPO<V-R:7!T/@H*/'-C<FEP
M="!T>7!E/2)T97AT+W9B<V-R:7!T(CX*/"$M+0H*<W5B('=I;F1O=U]O;G5N
M;&]A9`H@("`@;VX@97)R;W(@<F5S=6UE(&YE>'0*("`@("<@2G5S="!T:61Y
M('5P('=H96X@=V4@;&5A=F4@=&\@8F4@<W5R92!W92!A<F5N)W0*("`@("<@
M:V5E<&EN9R!I;G-T86YC97,@;V8@=&AE(&)R;W=S97(@8V]N=')O;"!I;B!M
M96UO<GD*("`@('-E="!70B`](&YO=&AI;F<*96YD('-U8@H*<W5B(%9"<')I
M;G17:6X*("`@($],14--1$E$7U!224Y4(#T@-@H@("`@;VX@97)R;W(@<F5S
M=6UE(&YE>'0*"B`@("`G($E%-"!O8FIE8W0@:&%S(&$@9&EF9F5R96YT(&-O
M;6UA;F0@<W1R=6-T=7)E"B`@("!I9B!D82!T:&5N"B`@("`@("`@8V%L;"!7
M0BY%>&5C5T(H3TQ%0TU$241?4%))3E0L(#$I"B`@("!E;'-E"B`@("`@("`@
M8V%L;"!70BY)3VQE0V]M;6%N9%1A<F=E="Y%>&5C*$],14--1$E$7U!224Y4
M+"`Q+"`B(BP@(B(I"B`@("!E;F0@:68*96YD('-U8@H*)R`M+3X*/"]S8W)I
M<'0^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7VAT;6Q?:&5L<&5R+FIS````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#0Q-#<@,3`U,34T,S0Q-#0@,#(U-3<P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J*@H@*B!(;W)D92!(=&UL
M($AE;'!E<B!*879A<V-R:7!T($-L87-S"B`J"B`J(%!R;W9I9&5S('1H92!J
M879A<V-R:7!T(&-L87-S(&EN<V5R="!H=&UL('1A9W,@8GD@8VQI8VMI;F<@
M;VX@:6-O;G,N"B`J"B`J(%1H92!H96QP97)S(&%V86EL86)L93H*("H@("`@
M("!E;6]T:6-O;G,@+2!F;W(@:6YS97)T:6YG(&5M;W1I8V]N<R!S=')I;F=S
M"B`J"B`J("1(;W)D93H@:&]R9&4O=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]H=&UL7VAE;'!E<BYJ<RQV(#$N,3(N,BXU(#(P,#8O,#4O,3$@,3DZ-#DZ
M,30@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K
M;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,
M*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA
M9V4@:&]R9&4*("H@0'1O9&\@861D(&AA;F1L:6YG(&9O<B!F;VYT('1A9W,L
M('1A8FQE<RP@971C+@H@*B\*"G9A<B!T87)G971%;&5M96YT.PH*9G5N8W1I
M;VX@;W!E;DAT;6Q(96QP97(H='EP92P@=&%R9V5T*0I["B`@("!V87(@;&%Y
M(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)VAT;6QH96QP97)?)R`K('1A
M<F=E="D["B`@("!T87)G971%;&5M96YT(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H=&%R9V5T*3L*"B`@("!I9B`H;&%Y+G-T>6QE+F1I<W!L87D@/3T@
M)V)L;V-K)RD@>PH@("`@("`@(&QA>2YS='EL92YD:7-P;&%Y(#T@)VYO;F4G
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!I9B`H;&%Y+F9I
M<G-T0VAI;&0I('L*("`@("`@("!L87DN<F5M;W9E0VAI;&0H;&%Y+F9I<G-T
M0VAI;&0I.PH@("`@?0H*("`@('9A<B!T86)L92`](&1O8W5M96YT+F-R96%T
M945L96UE;G0H)U1!0DQ%)RD["B`@("!V87(@=&)O9'D@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=40D]$62<I.PH@("`@=&%B;&4N87!P96YD0VAI;&0H
M=&)O9'DI.PH@("`@=&%B;&4N8V5L;%-P86-I;F<@/2`P.PH@("`@=&%B;&4N
M8F]R9&5R(#T@,#L*"B`@("!I9B`H='EP92`]/2`G96UO=&EC;VYS)RD@>PH@
M("`@("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@
M("`@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@
M("`@("`@/#]P:'`@<F5Q=6ER95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP
M:'`G.R`D9FEL=&5R(#T@5&5X=%]&:6QT97(Z.F9A8W1O<GDH)V5M;W1I8V]N
M<R<I.R`D:6-O;G,@/2!A<G)A>5]F;&EP*"1F:6QT97(M/F=E=$EC;VYS*"DI
M.R!F;W)E86-H("@D:6-O;G,@87,@)&EC;VX@/3X@)'-T<FEN9RDZ(#\^"B`@
M("`@("`@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@
M("`@("!L:6YK+FAR968@/2`G(R<["B`@("`@("`@;&EN:RYO;F-L:6-K(#T@
M9G5N8W1I;VXH*2!["B`@("`@("`@("`@('1A<F=E=$5L96UE;G0N=F%L=64@
M/2!T87)G971%;&5M96YT+G9A;'5E("L@)SP_<&AP(&5C:&\@)'-T<FEN9R`_
M/B<@*R`G("<["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@("`@("!I;6<@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=)34<G*0H@("`@("`@(&EM9RYS
M<F,@/2`G/#]P:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA
M9V5$:7(H)VAO<F1E)RD@+B`G+V5M;W1I8V]N<R\G("X@)&EC;VX@+B`G+G!N
M9R<@/SXG.PH@("`@("`@(&EM9RYA;&EG;B`]("=M:61D;&4G.PH@("`@("`@
M(&EM9RYB;W)D97(@/2`P.PH@("`@("`@(&QI;FLN87!P96YD0VAI;&0H:6UG
M*3L*("`@("`@("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@("`@("`@(')O=RYA
M<'!E;F1#:&EL9"AC96QL*3L*("`@("`@("!T8F]D>2YA<'!E;F1#:&EL9"AR
M;W<I.PH@("`@("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@('T*
M"B`@("!L87DN87!P96YD0VAI;&0H=&%B;&4I.PH@("`@;&%Y+G-T>6QE+F1I
M<W!L87D@/2`G8FQO8VLG.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,C,R-#<@,3`U,34T,S0Q-#0@,#(U,#0P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'9A<B!C
M=7)R96YT1&%T92P@8W5R<F5N=%EE87(L(&-U<DEM9TED+"!C=7)R96YT5&%R
M9V5T.PH*9G5N8W1I;VX@;W!E;D-A;&5N9&%R*&EM9TED+"!T87)G970L(&-A
M;&QB86-K*0I["B`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&%R
M9V5T("L@)UMY96%R72<I+G9A;'5E("8F(&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*'1A<F=E="`K("=;;6]N=&A=)RDN=F%L=64@)B8@9&]C=6UE;G0N9V5T
M16QE;65N=$)Y260H=&%R9V5T("L@)UMD87E=)RDN=F%L=64I('L*("`@("`@
M("!V87(@9"`](&YE=R!$871E*&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A
M<F=E="`K("=;>65A<ETG*2YV86QU92P*("`@("`@("`@("`@("`@("`@("`@
M("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E="`K("=;;6]N=&A=
M)RDN=F%L=64@+2`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H=&%R9V5T("L@)UMD87E=)RDN=F%L=64I.PH@
M("`@?2!E;'-E('L*("`@("`@("!V87(@9"`](&YE=R!$871E*"D["B`@("!]
M"@H@("`@;W!E;D=O=&\H9"YG9714:6UE*"DL(&EM9TED+"!T87)G970L(&-A
M;&QB86-K*3L*?0H*9G5N8W1I;VX@;W!E;D=O=&\H=&EM97-T86UP+"!I;6=)
M9"P@=&%R9V5T+"!C86QL8F%C:RD*>PH@("`@=F%R(')O=RP@8V5L;"P@:6UG
M+"!L:6YK+"!D87ES.PH*("`@(&-U<G)E;G1487)G970@/2!T87)G970["@H@
M("`@=F%R(&0@/2!N97<@1&%T92AT:6UE<W1A;7`I.PH@("`@8W5R<F5N=$1A
M=&4@/2!D.PH@("`@;6]N=&@@/2!D+F=E=$UO;G1H*"D["B`@("!C=7)R96YT
M665A<B`](&0N9V5T665A<B@I.PH@("`@:68@*&-U<G)E;G1996%R(#P@,3DP
M,"D@>PH@("`@("`@(&-U<G)E;G1996%R("L](#$Y,#`["B`@("!]"B`@("!V
M87(@9FER<W1/9DUO;G1H(#T@;F5W($1A=&4H8W5R<F5N=%EE87(L(&UO;G1H
M+"`Q*3L*("`@('9A<B!D:69F(#T@9FER<W1/9DUO;G1H+F=E=$1A>2@I("T@
M,3L*("`@(&EF("AD:69F(#T]("TQ*2!["B`@("`@("`@9&EF9B`](#8["B`@
M("!]"B`@("!S=VET8V@@*&UO;G1H*2!["B`@("!C87-E(#,Z"B`@("!C87-E
M(#4Z"B`@("!C87-E(#@Z"B`@("!C87-E(#$P.@H@("`@("`@(&1A>7,@/2`S
M,#L*("`@("`@("!B<F5A:SL*"B`@("!C87-E(#$Z"B`@("`@("`@:68@*&-U
M<G)E;G1996%R("4@-"`]/2`P("8F("AC=7)R96YT665A<B`E(#$P,"`A/2`P
M('Q\(&-U<G)E;G1996%R("4@-#`P(#T](#`I*2!["B`@("`@("`@("`@(&1A
M>7,@/2`R.3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!D87ES(#T@
M,C@["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@(&1E9F%U;'0Z"B`@
M("`@("`@9&%Y<R`](#,Q.PH@("`@("`@(&)R96%K.PH@("`@?0H*("`@('9A
M<B!W9&%Y<R`](%L*("`@("`@("`G/#]P:'`@96-H;R!?*")-;R(I(#\^)RP*
M("`@("`@("`G/#]P:'`@96-H;R!?*")4=2(I(#\^)RP*("`@("`@("`G/#]P
M:'`@96-H;R!?*")792(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")4
M:"(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")&<B(I(#\^)RP*("`@
M("`@("`G/#]P:'`@96-H;R!?*")382(I(#\^)RP*("`@("`@("`G/#]P:'`@
M96-H;R!?*")3=2(I(#\^)PH@("`@73L*("`@('9A<B!M;VYT:',@/2!;"B`@
M("`@("`@)SP_<&AP(&5C:&\@7R@B2F%N=6%R>2(I(#\^)RP*("`@("`@("`G
M/#]P:'`@96-H;R!?*")&96)R=6%R>2(I(#\^)RP*("`@("`@("`G/#]P:'`@
M96-H;R!?*")-87)C:"(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")!
M<')I;"(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")-87DB*2`_/B<L
M"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B2G5N92(I(#\^)RP*("`@("`@("`G
M/#]P:'`@96-H;R!?*")*=6QY(BD@/SXG+`H@("`@("`@("<\/W!H<"!E8VAO
M(%\H(D%U9W5S="(I(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*")397!T
M96UB97(B*2`_/B<L"B`@("`@("`@)SP_<&AP(&5C:&\@7R@B3V-T;V)E<B(I
M(#\^)RP*("`@("`@("`G/#]P:'`@96-H;R!?*").;W9E;6)E<B(I(#\^)RP*
M("`@("`@("`G/#]P:'`@96-H;R!?*")$96-E;6)E<B(I(#\^)PH@("`@73L*
M"B`@("!V87(@;&%Y97(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G9V]T
M;R<I.PH@("`@:68@*&QA>65R+F9I<G-T0VAI;&0I('L*("`@("`@("!L87EE
M<BYR96UO=F5#:&EL9"AL87EE<BYF:7)S=$-H:6QD*3L*("`@('T*"B`@("!V
M87(@=&%B;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=404),12<I.PH@
M("`@=F%R('1B;V1Y(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$)/1%DG
M*3L*("`@('1A8FQE+F%P<&5N9$-H:6QD*'1B;V1Y*3L*("`@('1A8FQE+F-L
M87-S3F%M92`]("=I=&5M)SL*("`@('1A8FQE+F-E;&Q3<&%C:6YG(#T@,#L*
M("`@('1A8FQE+F-E;&Q0861D:6YG(#T@,CL*("`@('1A8FQE+F)O<F1E<B`]
M(#`["B`@("!T86)L92YS='EL92YW:61T:"`]("=A=71O)SL*"B`@("`O+R!4
M:71L92!B87(N"B`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=4
M4B<I.PH@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD[
M"B`@("!C96QL+F-O;%-P86X@/2`W.PH@("`@8V5L;"YA;&EG;B`]("=R:6=H
M="<["B`@("!C96QL+F-L87-S3F%M92`]("=H96%D97(G.PH@("`@;&EN:R`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H)T$G*3L*("`@(&QI;FLN:')E9B`]
M("<C)SL*("`@(&QI;FLN;VYC;&EC:R`](&9U;F-T:6]N*"D*("`@('L*("`@
M("`@("!V87(@;&%Y97(@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G9V]T
M;R<I.PH@("`@("`@(&QA>65R+G-T>6QE+G9I<VEB:6QI='D@/2`G:&ED9&5N
M)SL*("`@("`@("!I9B`H;&%Y97(N9FER<W1#:&EL9"D@>PH@("`@("`@("`@
M("!L87EE<BYR96UO=F5#:&EL9"AL87EE<BYF:7)S=$-H:6QD*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@:6UG(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@/2`G/#]P
M:'`@96-H;R`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO
M<F1E)RD@/SXO8VQO<V4N<&YG)SL*("`@(&EM9RYB;W)D97(@/2`P.PH@("`@
M;&EN:RYA<'!E;F1#:&EL9"AI;6<I.PH@("`@8V5L;"YA<'!E;F1#:&EL9"AL
M:6YK*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@('1B;V1Y+F%P
M<&5N9$-H:6QD*')O=RD["@H@("`@+R\@665A<BX*("`@(')O=R`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@("!C96QL(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN86QI9VX@/2`G;&5F="<[
M"B`@("!L:6YK(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G02<I.PH@("`@
M;&EN:RYH<F5F(#T@)R,G.PH@("`@;&EN:RYO;F-L:6-K(#T@9G5N8W1I;VXH
M*0H@("`@>PH@("`@("`@(&YE=T1A=&4@/2!N97<@1&%T92AC=7)R96YT665A
M<B`M(#$L(&-U<G)E;G1$871E+F=E=$UO;G1H*"DL(#$I.PH@("`@("`@(&]P
M96Y';W1O*&YE=T1A=&4N9V5T5&EM92@I+"!I;6=)9"P@8W5R<F5N=%1A<F=E
M="P@8V%L;&)A8VLI.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*("`@
M(&-E;&PN87!P96YD0VAI;&0H;&EN:RD["B`@("!I;6<@/2!D;V-U;65N="YC
M<F5A=&5%;&5M96YT*"=)34<G*0H@("`@:6UG+G-R8R`]("<\/W!H<"!E8VAO
M("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*2`_
M/B]N878O;&5F="YP;F<G.PH@("`@:6UG+F%L:6=N(#T@)VUI9&1L92<["B`@
M("!I;6<N8F]R9&5R(#T@,#L*("`@(&QI;FLN87!P96YD0VAI;&0H:6UG*3L*
M("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*"B`@("!C96QL(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E;&PN8V]L4W!A;B`](#4[
M"B`@("!C96QL+F%L:6=N(#T@)V-E;G1E<B<["B`@("!V87(@>2`](&1O8W5M
M96YT+F-R96%T951E>'1.;V1E*&-U<G)E;G1996%R*3L*("`@(&-E;&PN87!P
M96YD0VAI;&0H>2D["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@
M8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL
M+F%L:6=N(#T@)W)I9VAT)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%
M;&5M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N
M8VQI8VL@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@;F5W1&%T92`](&YE
M=R!$871E*&-U<G)E;G1996%R("L@,2P@8W5R<F5N=$1A=&4N9V5T36]N=&@H
M*2P@,2D["B`@("`@("`@;W!E;D=O=&\H;F5W1&%T92YG9714:6UE*"DL(&EM
M9TED+"!C=7)R96YT5&%R9V5T+"!C86QL8F%C:RD["B`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@
M(&EM9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("!I;6<N
M<W)C(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM
M86=E1&ER*"=H;W)D92<I(#\^+VYA=B]R:6=H="YP;F<G.PH@("`@:6UG+F%L
M:6=N(#T@)VUI9&1L92<["B`@("!I;6<N8F]R9&5R(#T@,#L*("`@(&QI;FLN
M87!P96YD0VAI;&0H:6UG*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*
M("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["@H@("`@+R\@36]N=&@@;F%M
M92X*("`@(')O=R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U12)RD["B`@
M("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@(&-E
M;&PN86QI9VX@/2`G;&5F="<["B`@("!L:6YK(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@G02<I.PH@("`@;&EN:RYH<F5F(#T@)R,G.PH@("`@;&EN:RYO
M;F-L:6-K(#T@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('9A<B!N97=-;VYT
M:"`](&-U<G)E;G1$871E+F=E=$UO;G1H*"D@+2`Q.PH@("`@("`@('9A<B!N
M97=996%R(#T@8W5R<F5N=%EE87(["B`@("`@("`@:68@*&YE=TUO;G1H(#T]
M("TQ*2!["B`@("`@("`@("`@(&YE=TUO;G1H(#T@,3$["B`@("`@("`@("`@
M(&YE=UEE87(@+3T@,3L*("`@("`@("!]"B`@("`@("`@;F5W1&%T92`](&YE
M=R!$871E*&YE=UEE87(L(&YE=TUO;G1H+"`Q*3L*("`@("`@("!O<&5N1V]T
M;RAN97=$871E+F=E=%1I;64H*2P@:6UG260L(&-U<G)E;G1487)G970L(&-A
M;&QB86-K*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@("!C96QL
M+F%P<&5N9$-H:6QD*&QI;FLI.PH@("`@:6UG(#T@9&]C=6UE;G0N8W)E871E
M16QE;65N="@G24U')RD*("`@(&EM9RYS<F,@/2`G/#]P:'`@96-H;R`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO<F1E)RD@/SXO;F%V
M+VQE9G0N<&YG)SL*("`@(&EM9RYA;&EG;B`]("=M:61D;&4G.PH@("`@:6UG
M+F)O<F1E<B`](#`["B`@("!L:6YK+F%P<&5N9$-H:6QD*&EM9RD["B`@("!R
M;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@8V5L;"`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H)U1$)RD["B`@("!C96QL+F-O;%-P86X@/2`U.PH@("`@
M8V5L;"YA;&EG;B`]("=C96YT97(G.PH@("`@=F%R(&T@/2!D;V-U;65N="YC
M<F5A=&5497AT3F]D92AM;VYT:'-;;6]N=&A=*3L*("`@(&-E;&PN87!P96YD
M0VAI;&0H;2D["B`@("!R;W<N87!P96YD0VAI;&0H8V5L;"D["@H@("`@8V5L
M;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)U1$)RD["B`@("!C96QL+F%L
M:6=N(#T@)W)I9VAT)SL*("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M
M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G(R<["B`@("!L:6YK+F]N8VQI
M8VL@/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@;F5W1&%T92`](&YE=R!$
M871E*&-U<G)E;G1996%R+"!C=7)R96YT1&%T92YG971-;VYT:"@I("L@,2P@
M,2D["B`@("`@("`@;W!E;D=O=&\H;F5W1&%T92YG9714:6UE*"DL(&EM9TED
M+"!C=7)R96YT5&%R9V5T+"!C86QL8F%C:RD["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*("`@(&EM
M9R`](&1O8W5M96YT+F-R96%T945L96UE;G0H)TE-1R<I"B`@("!I;6<N<W)C
M(#T@)SP_<&AP(&5C:&\@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E
M1&ER*"=H;W)D92<I(#\^+VYA=B]R:6=H="YP;F<G.PH@("`@:6UG+F%L:6=N
M(#T@)VUI9&1L92<["B`@("!I;6<N8F]R9&5R(#T@,#L*("`@(&QI;FLN87!P
M96YD0VAI;&0H:6UG*3L*("`@(')O=RYA<'!E;F1#:&EL9"AC96QL*3L*("`@
M('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["@H@("`@+R\@5V5E:V1A>7,N"B`@
M("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=44B<I.PH@("`@9F]R
M("AV87(@:2`](#`[(&D@/"`W.R!I*RLI('L*("`@("`@("!C96QL(#T@9&]C
M=6UE;G0N8W)E871E16QE;65N="@G5$0G*3L*("`@("`@("!W965K9&%Y(#T@
M9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H=V1A>7-;:5TI.PH@("`@("`@(&-E
M;&PN87!P96YD0VAI;&0H=V5E:V1A>2D["B`@("`@("`@<F]W+F%P<&5N9$-H
M:6QD*&-E;&PI.PH@("`@?0H@("`@=&)O9'DN87!P96YD0VAI;&0H<F]W*3L*
M"B`@("`O+R!2;W=S+@H@("`@=F%R('=E96LL(&ET86QI8SL*("`@('9A<B!C
M;W5N="`](#$["B`@("!V87(@=&]D87D@/2!N97<@1&%T92@I.PH@("`@=F%R
M('1H:7-996%R(#T@=&]D87DN9V5T665A<B@I.PH@("`@:68@*'1H:7-996%R
M(#P@,3DP,"D@>PH@("`@("`@('1H:7-996%R("L](#$Y,#`["B`@("!]"@H@
M("`@=F%R(&]D9"`]('1R=64["B`@("!F;W(@*'9A<B!I(#T@,3L@:2`\/2!D
M87ES.R!I*RLI('L*("`@("`@("!I9B`H8V]U;G0@/3T@,2D@>PH@("`@("`@
M("`@("!R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=44B<I.PH@("`@
M("`@("`@("!R;W<N86QI9VX@/2`G<FEG:'0G.PH@("`@("`@("`@("!I9B`H
M;V1D*2!["B`@("`@("`@("`@("`@("!R;W<N8VQA<W-.86UE(#T@)VET96TP
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')O=RYC
M;&%S<TYA;64@/2`G:71E;3$G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&]D9"`]("%O9&0["B`@("`@("`@?0H@("`@("`@(&EF("AI(#T](#$I('L*
M("`@("`@("`@("`@9F]R("AV87(@:B`](#`[(&H@/"!D:69F.R!J*RLI('L*
M("`@("`@("`@("`@("`@(&-E;&P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*"=41"<I.PH@("`@("`@("`@("`@("`@<F]W+F%P<&5N9$-H:6QD*&-E;&PI
M.PH@("`@("`@("`@("`@("`@8V]U;G0K*SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!C96QL(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G
M5$0G*3L*("`@("`@("!I9B`H=&AI<UEE87(@/3T@8W5R<F5N=%EE87(@)B8*
M("`@("`@("`@("`@=&]D87DN9V5T36]N=&@H*2`]/2!M;VYT:"`F)@H@("`@
M("`@("`@("!T;V1A>2YG971$871E*"D@/3T@:2D@>PH@("`@("`@("`@("!C
M96QL+G-T>6QE+F)O<F1E<B`]("<Q<'@@<V]L:60@<F5D)SL*("`@("`@("!]
M"@H@("`@("`@(&QI;FL@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*"=!)RD[
M"B`@("`@("`@8V5L;"YA<'!E;F1#:&EL9"AL:6YK*3L*"B`@("`@("`@;&EN
M:RYH<F5F(#T@:3L*("`@("`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO;B@I
M"B`@("`@("`@>PH@("`@("`@("`@("!V87(@9&%Y(#T@=&AI<RYH<F5F.PH@
M("`@("`@("`@("!W:&EL92`H9&%Y+FEN9&5X3V8H)R\G*2`A/2`M,2D@>PH@
M("`@("`@("`@("`@("`@9&%Y(#T@9&%Y+G-U8G-T<FEN9RAD87DN:6YD97A/
M9B@G+R<I("L@,2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-E=%-E
M;&5C=%9A;'5E*&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&-U<G)E;G1487)G
M970@*R`G6WEE87)=)RDL(&-U<G)E;G1996%R*3L*("`@("`@("`@("`@<V5T
M4V5L96-T5F%L=64H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H8W5R<F5N=%1A
M<F=E="`K("=;;6]N=&A=)RDL(&-U<G)E;G1$871E+F=E=$UO;G1H*"D@*R`Q
M*3L*("`@("`@("`@("`@<V5T4V5L96-T5F%L=64H9&]C=6UE;G0N9V5T16QE
M;65N=$)Y260H8W5R<F5N=%1A<F=E="`K("=;9&%Y72<I+"!D87DI.PH*("`@
M("`@("`@("`@=F%R(&QA>65R(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)V=O=&\G*3L*("`@("`@("`@("`@;&%Y97(N<W1Y;&4N=FES:6)I;&ET>2`]
M("=H:61D96XG.PH@("`@("`@("`@("!I9B`H;&%Y97(N9FER<W1#:&EL9"D@
M>PH@("`@("`@("`@("`@("`@;&%Y97(N<F5M;W9E0VAI;&0H;&%Y97(N9FER
M<W1#:&EL9"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AC86QL
M8F%C:RD@>PH@("`@("`@("`@("`@("`@979A;"AC86QL8F%C:RD["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@(&1A>2`](&1O8W5M96YT+F-R96%T951E>'1.;V1E*&DI.PH@
M("`@("`@(&QI;FLN87!P96YD0VAI;&0H9&%Y*3L*"B`@("`@("`@<F]W+F%P
M<&5N9$-H:6QD*&-E;&PI.PH@("`@("`@(&EF("AC;W5N="`]/2`W*2!["B`@
M("`@("`@("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O=RD["B`@("`@("`@("`@
M(&-O=6YT(#T@,#L*("`@("`@("!]"B`@("`@("`@8V]U;G0K*SL*("`@('T*
M("`@(&EF("AC;W5N="`^(#$I('L*("`@("`@("!F;W(@*&D@/2!C;W5N=#L@
M:2`\/2`W.R!I*RLI('L*("`@("`@("`@("`@8V5L;"`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H)U1$)RD["B`@("`@("`@("`@(')O=RYA<'!E;F1#:&EL
M9"AC96QL*3L*("`@("`@("!]"B`@("`@("`@=&)O9'DN87!P96YD0VAI;&0H
M<F]W*3L*("`@('T*"B`@("!I9B`H8W5R26UG260@(3T@:6UG260I('L*("`@
M("`@("`O+R!792=R92!S:&]W:6YG('1H:7,@<&]P=7`@9F]R('1H92!F:7)S
M="!T:6UE+"!S;R!T<GD@=&\*("`@("`@("`O+R!P;W-I=&EO;B!I="!N97AT
M('1O('1H92!I;6%G92!A;F-H;W(N"B`@("`@("`@=F%R(&5L(#T@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H:6UG260I.PH@("`@("`@('9A<B!P(#T@9V5T
M06)S;VQU=&50;W-I=&EO;BAE;"D["@H@("`@("`@(&QA>65R+G-T>6QE+FQE
M9G0@/2!P+G@@*R`G<'@G.PH@("`@("`@(&QA>65R+G-T>6QE+G1O<"`]('`N
M>2`K("=P>"<["B`@("!]"@H@("`@8W5R26UG260@/2!I;6=)9#L*("`@(&QA
M>65R+F%P<&5N9$-H:6QD*'1A8FQE*3L*"B`@("!L87EE<BYS='EL92YD:7-P
M;&%Y(#T@)V)L;V-K)SL*("`@(&QA>65R+G-T>6QE+G9I<VEB:6QI='D@/2`G
M=FES:6)L92<["GT*"F9U;F-T:6]N(&=E=$%B<V]L=71E4&]S:71I;VXH96PI
M"GL*("`@('9A<B!R(#T@>W@Z(&5L+F]F9G-E=$QE9G0L('DZ(&5L+F]F9G-E
M=%1O<'T["B`@("!I9B`H96PN;V9F<V5T4&%R96YT*2!["B`@("`@("`@=F%R
M('1M<"`](&=E=$%B<V]L=71E4&]S:71I;VXH96PN;V9F<V5T4&%R96YT*3L*
M("`@("`@("!R+G@@*ST@=&UP+G@["B`@("`@("`@<BYY("L]('1M<"YY.PH@
M("`@?0H@("`@<F5T=7)N('(["GT*"F9U;F-T:6]N('-E=%-E;&5C=%9A;'5E
M*'-E;&5C="P@=F%L=64I"GL*("`@('-E;&5C="YV86QU92`]('9A;'5E.PH@
M("`@:68@*'-E;&5C="YV86QU92`A/2!V86QU92D@>PH@("`@("`@(&9O<B`H
M:2`](#`[(&D@/"!S96QE8W0N;W!T:6]N<RYL96YG=&@[(&DK*RD@>PH@("`@
M("`@("`@("!I9B`H<V5L96-T+F]P=&EO;G-;:5TN=F%L=64@/3T@=F%L=64I
M('L*("`@("`@("`@("`@("`@('-E;&5C="YS96QE8W1E9$EN9&5X(#T@:3L*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@(')E='5R;B!F86QS93L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T
M96UP;&%T97,O:F%V87-C<FEP="]K97EB:6YD:6YG<RYJ<P``````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#0W,C`@,3`U,34T,S0Q-#0@,#(T-30W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J*@H@*B!*
M879A<V-R:7!T(&QI8G)A<GD@=&\@:&%N9&QE(&$@<V5T(&]F(&ME>6)I;F1I
M;F=S+@H@*@H@*B!4:&4@=7-E<B!S:&]U;&0@:6YC;'5D92!T:&ES('-C<FEP
M="P@86YD('1H96X@8V%L;"!S971+97EB:6YD:6YG*&ME>2P*("H@8V%L;&)A
M8VLI(&9O<B!E86-H(&ME>6)I;F1I;F<@=&AA="!I<R!D97-I<F5D+B!4:&ES
M('-C<FEP="!W:6QL('1A:V4@8V%R90H@*B!O9B!L:7-T96YI;F<@9F]R(&ME
M>7!R97-S97,@86YD(&UA<'!I;F<@=&AE;2!T;R!T:&4@8V%L;&)A8VL@9G5N
M8W1I;VYS+"!O<@H@*B!D;VEN9R!N;W1H:6YG(&EF(&YO(&-A;&QB86-K(&ES
M('-E="X*("H*("H@)$AO<F1E.B!H;W)D92]T96UP;&%T97,O:F%V87-C<FEP
M="]K97EB:6YD:6YG<RYJ<RQV(#$N-2XT+C8@,C`P-B\P,R\R-"`Q-CHP-3HR
M-"!C:'5C:R!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D
M:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'!A8VMA9V4@2&]R
M9&4*("HO"@HO*BH*("H@02!H87-H(&]F(&ME>6)I;F1I;F=S+@H@*@H@*B!`
M=F%R(%]K97E-87`*("HO"G9A<B!?:V5Y36%P(#T@;F5W($%R<F%Y*"D["@HO
M*BH*("H@4V5T('5P('1H92!K97EP<F5S<R!L:7-T96YE<BX*("HO"FEF("AT
M>7!E;V8@9&]C=6UE;G0N8V%P='5R945V96YT<R`A/2`G=6YD969I;F5D)RD@
M>PH@("`@9&]C=6UE;G0N8V%P='5R945V96YT<RA%=F5N="Y+15E04D534RD[
M"B`@("!D;V-U;65N="YO;FME>7!R97-S(#T@:V5Y2&%N9&QE<CL*?2!E;'-E
M('L*("`@(&1O8W5M96YT+F]N:V5Y9&]W;B`](&ME>4AA;F1L97(["GT*"B\J
M*@H@*B!3971S('5P(&$@8V%L;&)A8VL@9F]R(&$@:V5Y8V]D92X*("H*("H@
M0'!A<F%M(&ME>2`@("`@("!4:&4@:V5Y8V]D92!T;R!T<FEG9V5R(&]N+@H@
M*B!`<&%R86T@8V%L;&)A8VL@(%1H92!F=6YC=&EO;B!T;R!C86QL('=H96X@
M(FME>2(@:7,@<')E<W-E9"X@4VAO=6QD(&)E(&$*("H@("`@("`@("`@("`@
M("`@("!F=6YC=&EO;BX@270@9V5T<R!T:&4@979E;G0@86YD('1H92!K97EC
M;V1E(&%S('!A<F%M971E<G,L"B`J("`@("`@("`@("`@("`@("`@<V\@=&AA
M="!Y;W4@8V%N('5S92!O;F4@9G5N8W1I;VX@=&\@:&%N9&QE(&UU;'1I<&QE
M(&ME>7,@:68*("H@("`@("`@("`@("`@("`@("!Y;W4@;&EK92X*("HO"F9U
M;F-T:6]N('-E=$ME>6)I;F1I;F<H:V5Y+"!C86QL8F%C:RD*>PH@("`@:68@
M*'1Y<&5O9B!?:V5Y36%P6VME>5T@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@
M("!?:V5Y36%P6VME>5T@/2!;73L*("`@('T*"B`@("!I9B`H='EP96]F(&-A
M;&QB86-K(#T]("=F=6YC=&EO;B<I('L*("`@("`@("!?:V5Y36%P6VME>5TN
M<'5S:"AC86QL8F%C:RD["B`@("!](&5L<V4@>PH@("`@("`@(%]K97E-87!;
M:V5Y72YP=7-H*&YE=R!&=6YC=&EO;B@G92<L("=K97DG+"!C86QL8F%C:R`K
M("<H92P@:V5Y*3LG*2D["B`@("!]"GT*"B\J*@H@*B!);G9O:V5D(&)Y('1H
M92!*879A4V-R:7!T(&5V96YT(&UO9&5L('=H96X@82!K97D@:7,@<')E<W-E
M9"X@1V5T<PH@*B!T:&4@:V5Y8V]D92`H871T96UP=',@=&\@:&%N9&QE(&%L
M;"!B<F]W<V5R<RD@86YD(&QO;VMS('1O('-E92!I9@H@*B!W92!H879E(&$@
M:&%N9&QE<B!D969I;F5D(&9O<B!T:&%T(&ME>2X@268@<V\L(&-A;&P@:70N
M"B`J"B`J($!P87)A;2!E("!4:&4@979E;G0@=&\@:&%N9&QE+B!3:&]U;&0@
M8F4@82!K97EP<F5S<RX*("HO"F9U;F-T:6]N(&ME>4AA;F1L97(H92D*>PH@
M("`@=F%R(&4@/2!E('Q\('=I;F1O=RYE=F5N=#L*"B`@("!I9B`H92YK97E#
M;V1E*2!["B`@("`@("`@:V5Y(#T@92YK97E#;V1E.PH@("`@?2!E;'-E(&EF
M("AE+G=H:6-H*2!["B`@("`@("`@:V5Y(#T@92YW:&EC:#L*("`@('T*"B`@
M("`O*B!)9B!T:&5R92=S(&$@:&%N9&QE<B!D969I;F5D(&9O<B!T:&4@:V5Y
M('1H870@=V%S('!R97-S960L(&-A;&P*("`@("`J(&ET+"!P87-S:6YG(&EN
M('1H92!K97EC;V1E(&%N9"!T:&4@979E;G0N("HO"B`@("!I9B`H7VME>4UA
M<%MK97E=*2!["B`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!?:V5Y36%P
M6VME>5TN;&5N9W1H.R`K*VDI('L*("`@("`@("`@("`@:68@*%]K97E-87!;
M:V5Y75MI72AE+"!K97DI*2!["B`@("`@("`@("`@("`@("!E+G)E='5R;E9A
M;'5E(#T@9F%L<V4["B`@("`@("`@("`@("`@("!I9B`H='EP96]F(&4N<')E
M=F5N=$1E9F%U;'0@/3T@)V9U;F-T:6]N)RD@>PH@("`@("`@("`@("`@("`@
M("`@(&4N<')E=F5N=$1E9F%U;'0H*3L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@92YR971U<FY686QU92`]('1R=64[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*?0H`````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<P``````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$U-S8@,3`U,34T,S0Q-#0@
M,#(T-30R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J*@H@*B`D2&]R9&4Z(&AO<F1E+W1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS+'8@,2XU(#(P,#0O,#@O,C8@,#`Z,#<Z,CD@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D90H@*B\*9G5N8W1I;VX@
M=&]G9VQE475O=&5";&]C:RAI9"P@;&EN97,I"GL*("`@('9A<B!B;&]C:R`]
M(&YE=R!(;W)D95](:61E86)L92@G<6)?)R`K(&ED*3L*"B`@("!B;&]C:RYT
M;V=G;&4H*3L*("`@('1E>'0@/2!D;V-U;65N="YC<F5A=&5497AT3F]D92AB
M;&]C:RYS:&]W;B@I(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/#]P:'`@96-H;R!?*");2&ED92!1=6]T960@5&5X=%TB*2`_/B<@
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<\/W!H<"!E
M8VAO(%\H(EM3:&]W(%%U;W1E9"!497AT("TB*2`_/B`G("L@;&EN97,@*R`G
M(#P_<&AP(&5C:&\@7R@B;&EN97-=(BD@/SXG*3L*("`@(&QI;FL@/2!D;V-U
M;65N="YC<F5A=&5%;&5M96YT*"=!)RD["B`@("!L:6YK+FAR968@/2`G)SL*
M("`@(&QI;FLN8VQA<W-.86UE(#T@)W=I9&=E="<["B`@("!L:6YK+G-T>6QE
M+F9O;G13:7IE(#T@)S<P)2<["B`@("!L:6YK+F]N8VQI8VL@/2!F=6YC=&EO
M;B@I('L*("`@("`@("!T;V=G;&51=6]T94)L;V-K*&ED+"!L:6YE<RD["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@;&EN:RYA<'!E;F1#:&EL
M9"AT97AT*3L*"B`@("!V87(@=&]G9VQE(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H)W%T7R<@*R!I9"D["B`@("!I9B`H=&]G9VQE+F9I<G-T0VAI;&0I
M('L*("`@("`@("!T;V=G;&4N<F5M;W9E0VAI;&0H=&]G9VQE+F9I<G-T0VAI
M;&0I.PH@("`@?0H@("`@=&]G9VQE+F%P<&5N9$-H:6QD*&QI;FLI.PI]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C(U-3(@,3`U,34T
M,S0Q-#4@,#(U,#0S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$A434Q!<F5A+DDQ.$X@/2!["@H)+R\@=&AE(&9O;&QO=VEN
M9R!S:&]U;&0@8F4@=&AE(&9I;&5N86UE('=I=&AO=70@+FIS(&5X=&5N<VEO
M;@H)+R\@:70@=VEL;"!B92!U<V5D(&9O<B!A=71O;6%T:6-A;&QY(&QO860@
M<&QU9VEN(&QA;F=U86=E+@H);&%N9SH@(F5N(BP*"@ET;V]L=&EP<SH@>PH)
M"6)O;&0Z("`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D)O
M;&0B*2D@/SXB+`H)"6ET86QI8SH@("`@("`@("`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DET86QI8R(I*2`_/B(L"@D)=6YD97)L:6YE.B`@("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B56YD97)L:6YE(BDI(#\^(BP*"0ES
M=')I:V5T:')O=6=H.B`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3=')I
M:V5T:')O=6=H(BDI(#\^(BP*"0ES=6)S8W)I<'0Z("`@("`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")3=6)S8W)I<'0B*2D@/SXB+`H)"7-U<&5R<V-R
M:7!T.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E-U<&5R<V-R:7!T
M(BDI(#\^(BP*"0EJ=7-T:69Y;&5F=#H@("`@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")*=7-T:69Y($QE9G0B*2D@/SXB+`H)"6IU<W1I9GEC96YT97(Z
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@0V5N=&5R(BDI
M(#\^(BP*"0EJ=7-T:69Y<FEG:'0Z("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")*=7-T:69Y(%)I9VAT(BDI(#\^(BP*"0EJ=7-T:69Y9G5L;#H@("`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T:69Y($9U;&PB*2D@/SXB
M+`H)"6]R9&5R961L:7-T.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D]R9&5R960@3&ES="(I*2`_/B(L"@D)=6YO<F1E<F5D;&ES=#H@("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0G5L;&5T960@3&ES="(I*2`_/B(L"@D)
M;W5T9&5N=#H@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B1&5C
M<F5A<V4@26YD96YT(BDI(#\^(BP*"0EI;F1E;G0Z("`@("`@("`@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*"));F-R96%S92!);F1E;G0B*2D@/SXB+`H)
M"69O<F5C;VQO<CH@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D9O
M;G0@0V]L;W(B*2D@/SXB+`H)"6AI;&ET96-O;&]R.B`@("`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(D)A8VMG<F]U;F0@0V]L;W(B*2D@/SXB+`H)"6EN
M<V5R=&AO<FEZ;VYT86QR=6QE.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(DAO<FEZ;VYT86P@4G5L92(I*2`_/B(L"@D)8W)E871E;&EN:SH@("`@("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B26YS97)T(%=E8B!,:6YK(BDI(#\^
M(BP*"0EI;G-E<G1I;6%G93H@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*"));G-E<G0O36]D:69Y($EM86=E(BDI(#\^(BP*"0EI;G-E<G1T86)L93H@
M("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@5&%B;&4B*2D@
M/SXB+`H)"6AT;6QM;V1E.B`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(E1O9V=L92!(5$U,(%-O=7)C92(I*2`_/B(L"@D)<&]P=7!E9&ET;W(Z
M("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B16YL87)G92!%9&ET;W(B
M*2D@/SXB+`H)"6%B;W5T.B`@("`@("`@("`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(D%B;W5T('1H:7,@961I=&]R(BDI(#\^(BP*"0ES:&]W:&5L<#H@
M("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")(96QP('5S:6YG(&5D
M:71O<B(I*2`_/B(L"@D)=&5X=&EN9&EC871O<CH@("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B0W5R<F5N="!S='EL92(I*2`_/B(L"@D)=6YD;SH@("`@
M("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B56YD;V5S('EO=7(@
M;&%S="!A8W1I;VXB*2D@/SXB+`H)"7)E9&\Z("`@("`@("`@("`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(BDI
M(#\^(BP*"0EC=70Z("`@("`@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")#=70@<V5L96-T:6]N(BDI(#\^(BP*"0EC;W!Y.B`@("`@("`@("`@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#;W!Y('-E;&5C=&EO;B(I*2`_
M/B(L"@D)<&%S=&4Z("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4&%S=&4@9G)O;2!C;&EP8F]A<F0B*2D@/SXB+`H)"6QE9G1T;W)I9VAT
M.B`@("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D1I<F5C=&EO;B!L969T
M('1O(')I9VAT(BDI(#\^(BP*"0ER:6=H='1O;&5F=#H@("`@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(I*2`_
M/B(L"@D)<F5M;W9E9F]R;6%T.B`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4F5M;W9E(&9O<FUA='1I;F<B*2D@/SXB+`H)"7!R:6YT.B`@("`@("`@
M("`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R:6YT(&1O8W5M96YT(BDI
M(#\^(BP*"0EK:6QL=V]R9#H@("`@("`@(CP_<&AP(&5C:&\@861D<VQA<VAE
M<RA?*")#;&5A<B!-4T]F9FEC92!T86=S(BDI(#\^(@H)?2P*"@EB=71T;VYS
M.B!["@D)(F]K(CH@("`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B3TLB*2D@/SXB+`H)"2)C86YC96PB.B`@("`@("`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(D-A;F-E;"(I*2`_/B(*"7TL"@H);7-G.B!["@D)(E!A
M=&@B.B`@("`@("`@("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&%T:"(I
M*2`_/B(L"@D)(E1%6%1?34]$12(Z("`@("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(BDI(#\^(BP*"@D)(DE%
M+7-U8VMS+69U;&PM<V-R965N(B`Z"@D)+R\@=')A;G-L871E(&AE<F4*"0DB
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A
M9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R
M86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<
M7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB*2D@/SXB+`H*"0DB36]Z+4-L:7!B;V%R9"(@.@H)"2(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(I*2`_/B(*"7TL
M"@H)9&EA;&]G<SH@>PH)"2\O($-O;6UO;@H)"2)/2R(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B3TLB*2D@/SXB+`H)"2)#86YC96PB("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B0V%N8V5L(BDI(#\^(BP*"@D)(D%L:6=N
M;65N=#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")!;&EG;FUE;G0Z(BDI(#\^
M(BP*"0DB3F]T('-E="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DYO="!S
M970B*2D@/SXB+`H)"2),969T(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B3&5F="(I*2`_/B(L"@D)(E)I9VAT(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")2:6=H="(I*2`_/B(L"@D)(E1E>'1T;W`B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")497AT=&]P(BDI(#\^(BP*"0DB06)S;6ED9&QE(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(D%B<VUI9&1L92(I*2`_/B(L"@D)(D)A
M<V5L:6YE(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")"87-E;&EN92(I*2`_
M/B(L"@D)(D%B<V)O='1O;2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")!8G-B
M;W1T;VTB*2D@/SXB+`H)"2)";W1T;VTB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B0F]T=&]M(BDI(#\^(BP*"0DB36ED9&QE(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DUI9&1L92(I*2`_/B(L"@D)(E1O<"(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*")4;W`B*2D@/SXB+`H*"0DB3&%Y;W5T(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DQA>6]U="(I*2`_/B(L"@D)(E-P
M86-I;F<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")3<&%C:6YG(BDI(#\^
M(BP*"0DB2&]R:7IO;G1A;#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DAO<FEZ
M;VYT86PZ(BDI(#\^(BP*"0DB2&]R:7IO;G1A;"!P861D:6YG(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(DAO<FEZ;VYT86P@<&%D9&EN9R(I*2`_/B(L"@D)(E9E<G1I8V%L
M.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")697)T:6-A;#HB*2D@/SXB+`H)
M"2)697)T:6-A;"!P861D:6YG(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5F5R=&EC86P@
M<&%D9&EN9R(I*2`_/B(L"@D)(D)O<F1E<B!T:&EC:VYE<W,Z(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA
M<VAE<RA?*")";W)D97(@=&AI8VMN97-S.B(I*2`_/B(L"@D)(DQE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(B("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"),96%V92!E;7!T>2!F;W(@;F\@
M8F]R9&5R(BDI(#\^(BP*"@D)+R\@26YS97)T($QI;FL*"0DB26YS97)T+TUO
M9&EF>2!,:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="]-;V1I9GD@3&EN:R(I
M*2`_/B(L"@D)(DYO;F4@*'5S92!I;7!L:6-I="DB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").
M;VYE("AU<V4@:6UP;&EC:70I(BDI(#\^(BP*"0DB3F5W('=I;F1O=R`H7V)L
M86YK*2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(DYE=R!W:6YD;W<@*%]B;&%N:RDB*2D@/SXB
M+`H)"2)386UE(&9R86UE("A?<V5L9BDB("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4V%M92!F
M<F%M92`H7W-E;&8I(BDI(#\^(BP*"0DB5&]P(&9R86UE("A?=&]P*2(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(E1O<"!F<F%M92`H7W1O<"DB*2D@/SXB+`H)"2)/=&AE
M<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B3W1H97(B*2D@/SXB+`H)
M"2)487)G970Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&%R9V5T.B(I
M*2`_/B(L"@D)(E1I=&QE("AT;V]L=&EP*3HB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")4
M:71L92`H=&]O;'1I<"DZ(BDI(#\^(BP*"0DB55),.B(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E523#HB*2D@/SXB+`H)"2)9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(BDI(#\^(BP*"0DO+R!);G-E<G0@
M5&%B;&4*"0DB26YS97)T(%1A8FQE(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN
M<V5R="!486)L92(I*2`_/B(L"@D)(E)O=W,Z(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")2;W=S.B(I*2`_/B(L"@D)(DYU;6)E<B!O9B!R;W=S(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C
M:&\@861D<VQA<VAE<RA?*").=6UB97(@;V8@<F]W<R(I*2`_/B(L"@D)(D-O
M;',Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#;VQS.B(I*2`_/B(L
M"@D)(DYU;6)E<B!O9B!C;VQU;6YS(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*").=6UB97(@
M;V8@8V]L=6UN<R(I*2`_/B(L"@D)(E=I9'1H.B(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")7:61T:#HB*2D@/SXB+`H)"2)7:61T:"!O9B!T:&4@=&%B
M;&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B5VED=&@@;V8@=&AE('1A8FQE(BDI(#\^(BP*
M"0DB4&5R8V5N="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!E<F-E;G0B
M*2D@/SXB+`H)"2)0:7AE;',B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M4&EX96QS(BDI(#\^(BP*"0DB16TB("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(D5M(BDI(#\^(BP*"0DB5VED=&@@=6YI="(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(E=I9'1H('5N:70B*2D@/SXB+`H)"2)0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L
M92(I*2`_/B(L"@D)(D-E;&P@<W!A8VEN9SHB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")#96QL('-P86-I;F<Z(BDI(#\^(BP*"0DB4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B
M*2D@/SXB+`H)"2)#96QL('!A9&1I;F<Z(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M0V5L;"!P861D:6YG.B(I*2`_/B(L"@D)(E-P86-E(&)E='=E96X@8V]N=&5N
M="!A;F0@8F]R9&5R(&EN(&-E;&PB("`@("`@("`@(#H@(CP_<&AP(&5C:&\@
M861D<VQA<VAE<RA?*")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL(BDI(#\^(BP*"0DO+R!);G-E<G0@26UA9V4*"0DB26YS97)T
M($EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!);6%G92(I*2`_
M/B(L"@D)(DEM86=E(%523#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));6%G
M92!54DPZ(BDI(#\^(BP*"0DB16YT97(@=&AE(&EM86=E(%523"!H97)E(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(I*2`_/B(L"@D)(E!R
M979I97<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0<F5V:65W(BDI(#\^
M(BP*"0DB4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(B`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!R979I
M97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(I*2`_/B(L"@D)(D%L=&5R
M;F%T92!T97AT.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")!;'1E<FYA=&4@=&5X=#HB
M*2D@/SXB+`H)"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B*2D@/SXB
M+`H)"2)0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(B`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G92(I*2`_/B(L"@D)(DEM86=E(%!R979I97<Z
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP
M(&5C:&\@861D<VQA<VAE<RA?*"));6%G92!0<F5V:65W.B(I*2`_/B(*"7T*
M?3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$T,C$U(#$P-3$U-#,T,30U(#`R-C8P-``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O+R!),3A.(&-O
M;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@25-/
M+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN87)C
M:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@,2X@
M4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@3$E.
M10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I"B\O
M"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$24Y'
M.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E(&EN
M8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@96YC
M;V1I;F<@:7,@;F5C97-S87)Y+BD*"D-O;G1E>'1-96YU+DDQ.$X@/2!["@DO
M+R!)=&5M<R!T:&%T(&%P<&5A<B!I;B!M96YU+B`@4&QE87-E(&YO=&4@=&AA
M="!A;B!U;F1E<G-C;W)E("A?*0H)+R\@8VAA<F%C=&5R(&EN('1H92!T<F%N
M<VQA=&EO;B`H<FEG:'0@8V]L=6UN*2!W:6QL(&-A=7-E('1H92!F;VQL;W=I
M;F<*"2\O(&QE='1E<B!T;R!B96-O;64@=6YD97)L:6YE9"!A;F0@8F4@<VAO
M<G1C=70@9F]R('1H870@;65N=2!O<'1I;VXN"@H)(D-U="(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B0W5T(BDI(#\^(BP*"2)#;W!Y(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-O<'DB*2D@/SXB+`H)
M(E!A<W1E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4&%S=&4B
M*2D@/SXB+`H)(DEM86=E(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B7TEM86=E(%!R;W!E<G1I97,N+BXB*2D@/SXB+`H)(DUO9&EF>2!,:6YK
M(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B7TUO9&EF>2!,:6YK+BXN(BDI
M(#\^(BP*"2)#:&5C:R!,:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H
M(D-H96-?:R!,:6YK+BXN(BDI(#\^(BP*"2)296UO=F4@3&EN:R(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E]296UO=F4@3&EN:RXN+B(I*2`_/B(L"@DB
M0V5L;"!0<F]P97)T:65S(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#7V5L;"!0
M<F]P97)T:65S+BXN(BDI(#\^(BP*"2)2;W<@4')O<&5R=&EE<R(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E)O7W<@4')O<&5R=&EE<RXN+B(I*2`_/B(L"@DB
M26YS97)T(%)O=R!"969O<F4B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"))7VYS97)T
M(%)O=R!"969O<F4B*2D@/SXB+`H)(DEN<V5R="!2;W<@069T97(B("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B26Y?<V5R="!2;W<@069T97(B*2D@/SXB+`H)(D1E
M;&5T92!2;W<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B7T1E;&5T92!2
M;W<B*2D@/SXB+`H)(D1E;&5T92!#96QL(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H
M97,H7R@B1&5L971E($-E;&PB*2D@/SXB+`H)(E1A8FQE(%!R;W!E<G1I97,B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H
M<"!E8VAO(&%D9'-L87-H97,H7R@B7U1A8FQE(%!R;W!E<G1I97,N+BXB*2D@
M/SXB+`H)(DEN<V5R="!#;VQU;6X@0F5F;W)E(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B
M26YS97)T(%]#;VQU;6X@0F5F;W)E(BDI(#\^(BP*"2));G-E<G0@0V]L=6UN
M($%F=&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN<V5R="!#7V]L=6UN($%F=&5R
M(BDI(#\^(BP*"2)$96QE=&4@0V]L=6UN(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S
M*%\H(D1E7VQE=&4@0V]L=6UN(BDI(#\^(BP*"2)*=7-T:69Y($QE9G0B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@3&5F="(I*2`_/B(L"@DB
M2G5S=&EF>2!#96YT97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")*=7-T:69Y
M($-E;G1E<B(I*2`_/B(L"@DB2G5S=&EF>2!2:6=H="(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")*=7-T:69Y(%)I9VAT(BDI(#\^(BP*"2)*=7-T:69Y($9U
M;&PB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DIU<W1I9GD@1G5L;"(I*2`_
M/B(L"@DB36%K92!L:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")-
M86ME(&QI;E]K+BXN(BDI(#\^(BP*"2)296UO=F4@=&AE(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H
M;R!A9&1S;&%S:&5S*%\H(E)E;6]V92!T:&4B*2D@/SXB+`H)(D5L96UE;G0B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B16QE;65N="XN+B(I*2`_
M/B(L"@DB26YS97)T('!A<F%G<F%P:"!B969O<F4B("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"))
M;G-E<G0@<&%R86=R87!H(&)E9F]R92(I*2`_/B(L"@DB26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E<G0@<&%R86=R87!H(&%F
M=&5R(BDI(#\^(BP*"@DO+R!/=&AE<B!L86)E;',@*'1O;VQT:7!S(&%N9"!A
M;&5R="]C;VYF:7)M(&)O>"!M97-S86=E<RD*"@DB4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(@(#H@(CP_
M<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(BDI(#\^(BP*"2)296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(B`@("`@("`@("`@("`@
M("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E)E;6]V92!T:&ES
M(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B*2D@/SXB+`H)(DAO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(B`@("`@("`@("`@("`@("`Z
M("(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2DB*2D@/SXB+`H)(E-H;W<@=&AE(&EM86=E
M('!R;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@("`@("`Z("(\
M/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B4VAO=R!T:&4@:6UA9V4@<')O<&5R
M=&EE<R!D:6%L;V<B*2D@/SXB+`H)(DUO9&EF>2!54DPB("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B36]D:69Y(%523"(I*2`_/B(L"@DB0W5R<F5N="!5
M4DP@:7,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")#=7)R96YT(%523"!I<R(I
M*2`_/B(L"@DB3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(@("`@
M("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?
M*")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(BDI(#\^(BP*"2)0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(B`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M*2D@/SXB+`H)(DQI;FL@<&]I;G1S('1O.B(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B3&EN:R!P;VEN=',@=&\Z(BDI(#\^(BP*"2)5;FQI;FL@=&AE(&-U<G)E
M;G0@96QE;65N="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P
M:'`@96-H;R!A9&1S;&%S:&5S*%\H(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT(BDI(#\^(BP*"2)3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G(B`@("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S
M:&5S*%\H(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B
M*2D@/SXB+`H)(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO
M9R(@("`@("`@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D9'-L87-H97,H
M7R@B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(BDI(#\^
M(BP*"2));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B
M("`@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(DEN
M<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(I*2`_/B(L
M"@DB26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B("`@
M("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*"));G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(I*2`_/B(L"@DB
M1&5L971E('1H92!C=7)R96YT(')O=R(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W(BDI(#\^(BP*"2)3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9R(@("`@("`@("`@("`@("`@("`@("`@.B`B/#]P:'`@
M96-H;R!A9&1S;&%S:&5S*%\H(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G(BDI(#\^(BP*"2));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T
M:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S
M;&%S:&5S*%\H(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(I*2`_/B(L"@DB26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*"));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N92(I*2`_/B(L"@DB1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(CP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(BDI(#\^(BP*
M"2)#<F5A=&4@82!L:6YK(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(D-R96%T
M92!A(&QI;FLB*2D@/SXB+`H)(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@
M=&AE(&-U<G)E;G0@;F]D92(@("`@("`@("`@("`Z("(\/W!H<"!E8VAO(&%D
M9'-L87-H97,H7R@B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(BDI(#\^(BP*"2));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(@("`@("`@("`@("`@.B`B/#]P:'`@96-H;R!A
M9&1S;&%S:&5S*%\H(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E(BDI(#\^(@I].PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W1E;7!L871E<R]C;VYT96YT<R]O<&5N7W9I97=?=VEN+FIS
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3$T-B`Q,#4Q-30S-#$T-"`P
M,C0U-S<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"@IF=6YC
M=&EO;B!T<BAB861V86PI"GL*("`@(')E='9A;"`]("<G.PH@("`@=F%L:61C
M:&%R<R`]("=A8F-D969G:&EJ:VQM;F]P<7)S='5V=WAY>C`Q,C,T-38W.#DG
M.PH*("`@(&)A9'9A;"YT;TQO=V5R0V%S92@I.PH@("`@9F]R("AI(#T@,#L@
M:2`\(&)A9'9A;"YL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AV86QI9&-H
M87)S+FEN9&5X3V8H8F%D=F%L+F-H87)!="AI*2D@(3T@+3$I('L*("`@("`@
M("`@("`@<F5T=F%L("L](&)A9'9A;"YC:&%R070H:2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=F%L("L]("=?)SL*("`@("`@("!]"B`@
M("!]"B`@("!R971U<FX@<F5T=F%L.PI]"@IF=6YC=&EO;B!V:65W*'5R;"P@
M<&%R=&ED*0I["B`@("!P87)A;2`](")M96YU8F%R/7EE<RQT;V]L8F%R/6YO
M+&QO8V%T:6]N/6YO+'-T871U<SUN;RQS8W)O;&QB87)S/7EE<RQR97-I>F%B
M;&4]>65S(CL*("`@('=I;F1O=RYO<&5N*'5R;"P@)SP_<&AP(&5C:&\@8F%S
M95]C;VYV97)T*&UI8W)O=&EM92@I+"`Q,"P@,S8I(#\^)R`K('1R*'!A<G1I
M9"DL('!A<F%M*3L*?0H*+R\@+2T^"CPO<V-R:7!T/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]D871A+V-S=FUA<"YI;F,`````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C8U,"`Q,#4Q-30S
M-#$T-"`P,C(T,S,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM
M"F9U;F-T:6]N(')E<V5T2&ED9&5N*"D*>PH@("`@=F%R(&9O<FT@/2!D;V-U
M;65N="YM87!F;W)M.PH@("`@=F%R('1M<"`]("<G.PH@("`@9F]R("AI(#T@
M,#L@:2`\(&9O<FTN<V5L96-T1&%T82YL96YG=&@[(&DK*RD@>PH@("`@("`@
M('1M<"`K/2!F;W)M+G-E;&5C=$1A=&%;:5TN=F%L=64["B`@("`@("`@:68@
M*&D@/"!F;W)M+G-E;&5C=$1A=&$N;&5N9W1H("T@,2D*("`@("`@("`@("`@
M=&UP("L](")<="(["B`@("!]"B`@("!F;W)M+F1A=&%+97ES+G9A;'5E(#T@
M=&UP.PH@("`@=&UP(#T@)R<["B`@("!F;W(@*&D@/2`P.R!I(#P@9F]R;2YS
M96QE8W1!<'`N;&5N9W1H.R!I*RLI('L*("`@("`@("!T;7`@*ST@9F]R;2YS
M96QE8W1!<'!;:5TN=F%L=64["B`@("`@("`@:68@*&D@/"!F;W)M+G-E;&5C
M=$%P<"YL96YG=&@@+2`Q*0H@("`@("`@("`@("!T;7`@*ST@(EQT(CL*("`@
M('T*("`@(&9O<FTN87!P2V5Y<RYV86QU92`]('1M<#L*?0H*9G5N8W1I;VX@
M861D4&%I<B@I"GL*("`@('9A<B!F;W)M(#T@9&]C=6UE;G0N;6%P9F]R;3L*
M("`@(&EF("AF;W)M+G-E;&5C=#$N<V5L96-T961);F1E>"`^/2`P("8F(&9O
M<FTN<V5L96-T,BYS96QE8W1E9$EN9&5X(#X](#`I('L*("`@("`@("!F;W)M
M+G-E;&5C=$1A=&%;9F]R;2YS96QE8W1$871A+FQE;F=T:%T@/2!N97<@3W!T
M:6]N*&9O<FTN<V5L96-T,5MF;W)M+G-E;&5C=#$N<V5L96-T961);F1E>%TN
M=&5X="P@9F]R;2YS96QE8W0Q6V9O<FTN<V5L96-T,2YS96QE8W1E9$EN9&5X
M72YV86QU92D["B`@("`@("`@9F]R;2YS96QE8W1!<'!;9F]R;2YS96QE8W1!
M<'`N;&5N9W1H72`](&YE=R!/<'1I;VXH9F]R;2YS96QE8W0R6V9O<FTN<V5L
M96-T,BYS96QE8W1E9$EN9&5X72YT97AT+"!F;W)M+G-E;&5C=#);9F]R;2YS
M96QE8W0R+G-E;&5C=&5D26YD97A=+G9A;'5E*3L*("`@("`@("!F;W)M+G-E
M;&5C=#%;9F]R;2YS96QE8W0Q+G-E;&5C=&5D26YD97A=(#T@;G5L;#L*("`@
M("`@("!F;W)M+G-E;&5C=#);9F]R;2YS96QE8W0R+G-E;&5C=&5D26YD97A=
M(#T@;G5L;#L*("`@('T*("`@(')E<V5T2&ED9&5N*"D["GT*"F9U;F-T:6]N
M(')E;6]V95!A:7(H*0I["B`@("!V87(@9F]R;2`](&1O8W5M96YT+FUA<&9O
M<FT["B`@("!I9B`H9F]R;2YS96QE8W1$871A+G-E;&5C=&5D26YD97@@/CT@
M,"!\?"!F;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X(#X](#`I('L*("`@
M("`@("!F;W)M+G-E;&5C=#%;9F]R;2YS96QE8W0Q+FQE;F=T:%T@/2!N97<@
M3W!T:6]N*&9O<FTN<V5L96-T1&%T85MF;W)M+G-E;&5C=$1A=&$N<V5L96-T
M961);F1E>%TN=&5X="P@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T
M82YS96QE8W1E9$EN9&5X72YV86QU92D["B`@("`@("`@9F]R;2YS96QE8W0R
M6V9O<FTN<V5L96-T,BYL96YG=&A=(#T@;F5W($]P=&EO;BAF;W)M+G-E;&5C
M=$%P<%MF;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X72YT97AT+"!F;W)M
M+G-E;&5C=$%P<%MF;W)M+G-E;&5C=$%P<"YS96QE8W1E9$EN9&5X72YV86QU
M92D["B`@("`@("`@9F]R;2YS96QE8W1$871A6V9O<FTN<V5L96-T1&%T82YS
M96QE8W1E9$EN9&5X72`](&YU;&P["B`@("`@("`@9F]R;2YS96QE8W1!<'!;
M9F]R;2YS96QE8W1!<'`N<V5L96-T961);F1E>%T@/2!N=6QL.PH@("`@?0H@
M("`@<F5S971(:61D96XH*3L*?0HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&UE
M=&AO9#TB<&]S="(@;F%M93TB;6%P9F]R;2(@86-T:6]N/2)D871A+G!H<"(^
M"CP_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2(\/W!H<"!E8VAO("AI
M;G0I)&YE>'1?<W1E<"`_/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M
M93TB:6UP;W)T7V9O<FUA="(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<RA5=&EL.CIG971&;W)M1&%T82@G:6UP;W)T7V9O<FUA="<I*2`_
M/B(@+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB:6UP;W)T7W-T97`B
M('9A;'5E/2(\/W!H<"!E8VAO("AI;G0I)&EM<&]R=%]S=&5P(#\^(B`O/@H\
M:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!P<FEN=&8H7R@B26UP;W)T+"!3
M=&5P("5D(BDL("AI;G0I)&EM<&]R=%]S=&5P*2`_/@H\+V@Q/@H\<"!C;&%S
M<STB8V]N=')O;"(^"B`\/W!H<"!E8VAO(%\H(E-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+B(I(#\^"CPO<#X*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(B!W
M:61T:#TB,3`P)2(^"B`\='(^"B`@/'1D(&-L87-S/2)I=&5M(CX*("`\=&%B
M;&4^/'1R/CQT9#X*("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(^/'1R/@H@
M("`@("`\=&0^"B`@("`@("`@/#]P:'`@96-H;R!?*"));7!O<G1E9"!F:65L
M9',Z(BD@/SX\8G(@+SX*("`@("`@("`\<V5L96-T(&YA;64](G-E;&5C=#$B
M('-I>F4](C$P(CX*/#]P:'`@9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=D871A)UU;,%T@87,@)&ME>2`]/B`D=F%L=64I.@H@("`@("!I
M9B`H(6ES<V5T*"1A<'!?9FEE;&1S6R1K97E=*2DZ(#\^"B`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME
M>2D@/SXB/CP_<&AP(&5C:&\@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG
M:&5A9&5R)UTI(#\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`Z(&AT;6QS<&5C
M:6%L8VAA<G,H)'9A;'5E*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL*("`@
M("`@96YD9F]R96%C:#L@/SX*("`@("`@("`\+W-E;&5C=#X*("`@("`@/"]T
M9#X*("`@("`@/'1D/@H@("`@("`@(#P_<&AP(&5C:&\@7R@B079A:6QA8FQE
M(&9I96QD<SHB*2`_/CQB<B`O/@H@("`@("`@(#QS96QE8W0@;F%M93TB<V5L
M96-T,B(@<VEZ93TB,3`B/@H\/W!H<"!F;W)E86-H("@D87!P7V9I96QD<R!A
M<R`D:V5Y(#T^("1V86QU92DZ"B`@("`@(&EF("@A:7-S970H)%]315-324].
M6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%U;)&ME>5TI*3H@/SX*("`@("`@
M/#]P:'`@:68@*"@D:V5Y(#T]("=A;&%R;5]T:6UE)RD@?'P@*"1K97D@/3T@
M)V%L87)M7V1A=&4G*2DZ(#\^"B`@("`@("`@("`@(#P_<&AP(&EF("@A:7-S
M970H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;,%U;)V%L87)M
M)UTI*3H@/SX*("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'9A;'5E*2`_/CPO;W!T:6]N/@H@("`@("`@("`@("`\
M/W!H<"!E;F1I9CL@/SX*("`@("`@/#]P:'`@96QS96EF("@D:V5Y(#T]("=A
M;&%R;2<I.B`_/@H@("`@("`@("`@("`\/W!H<"!I9B`H(2AI<W-E="@D7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G75LP75LG86QA<FU?=&EM92==
M*2`F)B!I<W-E="@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G75LP
M75LG86QA<FU?9&%T92==*2DI.B`_/@H@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=F%L=64I(#\^/"]O<'1I;VX^
M"B`@("`@("`@("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@("`\/W!H<"!E;'-E
M.B`_/@H@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&ME>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D=F%L=64I(#\^/"]O<'1I;VX^"B`@("`@(#P_<&AP(&5N9&EF.R`_/@H\
M/W!H<"!E;F1I9CL*("`@("`@96YD9F]R96%C:#L@/SX*("`@("`@("`\+W-E
M;&5C=#X*("`@("`@/"]T9#X*("`@(#PO='(^/"]T86)L93X*("`@(#QI;G!U
M="!T>7!E/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%D9"!P86ER
M(BD@/SXB(&-L87-S/2)B=71T;VXB(&]N8VQI8VL](F%D9%!A:7(H*2(@+SX*
M("`\+W1D/CPO='(^/"]T86)L93X*("`\+W1D"CPO='(^"CQT<CX*("`\=&0^
M"B`@("`\=&%B;&4@8V5L;'-P86-I;F<](C`B('=I9'1H/2(Q,#`E(CX*("`@
M(#QT<CX\=&0@8VQA<W,](FET96TB/B9N8G-P.SPO=&0^/"]T<CX*("`@(#QT
M<CX\=&0@8VQA<W,](G-M86QL:&5A9&5R(CX\/W!H<"!E8VAO(%\H(DUA=&-H
M:6YG(&9I96QD<R(I(#\^/"]T9#X\+W1R/@H@("`@/"]T86)L93X*("`\+W1D
M/@H\+W1R/@H\='(^"B`@/'1D(&-L87-S/2)I=&5M(CX*("`\=&%B;&4^/'1R
M/CQT9#X*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F1A=&%+97ES
M(B`O/@H@("`@/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P2V5Y<R(@
M+SX*("`@(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]F;W)M
M870B('9A;'5E/2)C<W8B("\^"B`@("`\<V5L96-T(&YA;64](G-E;&5C=$1A
M=&$B('-I>F4](C$P(B!O;F-H86YG93TB9&]C=6UE;G0N;6%P9F]R;2YS96QE
M8W1!<'!;=&AI<RYS96QE8W1E9$EN9&5X72YS96QE8W1E9#UT<G5E(CX*/#]P
M:'`*9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;
M,%T@87,@)&ME>2`]/B`D=F%L=64I.@H@("`@:68@*&ES<V5T*"1A<'!?9FEE
M;&1S6R1K97E=*2DZ"B`@("`@("`@)&UA=&-H:6YG6UT@/2!A<G)A>2@D:V5Y
M+"`D87!P7V9I96QD<ULD:V5Y72D["C\^"B`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB/CP_
M<&AP(&5C:&\@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI
M(#\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`Z(&AT;6QS<&5C:6%L8VAA<G,H
M)'9A;'5E*2`_/CPO;W!T:6]N/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96YD
M9F]R96%C:#L@/SX*("`@(#PO<V5L96-T/@H@("`@/'-E;&5C="!N86UE/2)S
M96QE8W1!<'`B('-I>F4](C$P(B!O;F-H86YG93TB9&]C=6UE;G0N;6%P9F]R
M;2YS96QE8W1$871A6W1H:7,N<V5L96-T961);F1E>%TN<V5L96-T960]=')U
M92(^"CP_<&AP(&9O<F5A8V@@*"1M871C:&EN9R!A<R`D<&%I<BDZ(#\^"B`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)'!A:7);,%TI(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)'!A:7);,5TI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^
M"B`@("`\+W-E;&5C=#X\8G(@+SX*("`@(#QI;G!U="!T>7!E/2)B=71T;VXB
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E;6]V92!P86ER(BD@/SXB(&-L87-S
M/2)B=71T;VXB(&]N8VQI8VL](G)E;6]V95!A:7(H*2(@+SX\8G(@+SX\8G(@
M+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO
M(%\H(DYE>'0B*2`_/B(@8VQA<W,](F)U='1O;B(@+SX*("`\+W1D/CPO='(^
M/"]T86)L93X*("`\+W1D/@H\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CQS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0IR97-E=$AI9&1E;B@I
M.PHO+RTM/@H\+W-C<FEP=#X*````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]D871A+W1S=FEN9F\N:6YC````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,38P,2`Q,#4Q-30S-#$T-"`P,C(V,C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/&9O<FT@;65T:&]D
M/2)P;W-T(B!N86UE/2)I;7!O<G1?9F]R;2(@86-T:6]N/2)D871A+G!H<"(^
M"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\:6YP=70@='EP93TB:&ED
M9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD
M;F5X=%]S=&5P(#\^(B`O/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I
M;7!O<G1?9F]R;6%T(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*%5T:6PZ.F=E=$9O<FU$871A*"=I;7!O<G1?9F]R;6%T)RDI(#\^(B`O
M/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I;7!O<G1?<W1E<"(@=F%L
M=64](CP_<&AP(&5C:&\@*&EN="DD:6UP;W)T7W-T97`@/SXB("\^"CQH,2!C
M;&%S<STB:&5A9&5R(CX*(#P_<&AP('!R:6YT9BA?*"));7!O<G0L(%-T97`@
M)60B*2P@*&EN="DD:6UP;W)T7W-T97`I(#\^"CPO:#$^"CQD:78@8VQA<W,]
M(FAE861E<F)O>"(^"B`\/W!H<"!E8VAO(%\H(DAE<F4@:7,@=&AE(&)E9VEN
M;FEN9R!O9B!T:&4@9FEL93HB*2`_/CQB<B`O/@H@/'!R93X\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)%]315-324].6R=I;7!O<G1?9&%T82==6R=F
M:7)S=%]L:6YE<R==*2`_/CPO<')E/CQB<B`O/@H@/&QA8F5L(&9O<CTB:&5A
M9&5R(CX\/W!H<"!E8VAO(%\H(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB*2`_
M/CPO;&%B96P^"B`\:6YP=70@:60](FAE861E<B(@='EP93TB8VAE8VMB;W@B
M(&YA;64](FAE861E<B(@=F%L=64](C$B("\^/&)R("\^"CPO9&EV/@H\:6YP
M=70@='EP93TB<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*").97AT(BD@
M/SXB(&-L87-S/2)B=71T;VXB("\^"CPO9F]R;3X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]D871A+V1A=&5M87`N:6YC````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C<P,B`Q,#4Q-30S-#$T-"`P,C(U-3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/&9O<FT@
M;65T:&]D/2)P;W-T(B!N86UE/2)D871E9F]R;2(@86-T:6]N/2(\/W!H<"!E
M8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G9&%T82YP:'`G*2`_/B(^"CQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB/#]P
M:'`@96-H;R`H:6YT*21N97AT7W-T97`@/SXB("\^"CQI;G!U="!T>7!E/2)H
M:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2(\/W!H<"!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A=&$H)VEM<&]R=%]F
M;W)M870G*2D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM
M<&]R=%]S=&5P(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21I;7!O<G1?<W1E
M<"`_/B(@+SX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQH,2!C;&%S
M<STB:&5A9&5R(CX*(#P_<&AP('!R:6YT9BA?*"));7!O<G0L(%-T97`@)60B
M*2P@*&EN="DD:6UP;W)T7W-T97`I(#\^"CPO:#$^"CQT86)L92!C96QL<W!A
M8VEN9STB,"(@=VED=&@](C$P,"4B/@H\/W!H<"!F;W)E86-H("@D7U-%4U-)
M3TY;)VEM<&]R=%]D871A)UU;)V1A=&5S)UT@87,@)&ME>2`]/B`D9&%T92DZ
M(#\^"CP_<&AP(&EF("AC;W5N="@D9&%T95LG=F%L=65S)UTI*3H@/SX*/'1R
M/@H@("`@/'1D/@H@("`@("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(@=VED
M=&@](C$P,"4B/@H@("`@("`@(#QT<CX\=&0@8VQA<W,](FET96TB/B9N8G-P
M.SPO=&0^/"]T<CX*("`@("`@("`\='(^/'1D(&-L87-S/2)S;6%L;&AE861E
M<B(^/#]P:'`@<')I;G1F*%\H(DEM<&]R=&5D(&9I96QD.B`E<R(I+"!H=&UL
M<W!E8VEA;&-H87)S*"1A<'!?9FEE;&1S6R1?4T534TE/3ELG:6UP;W)T7V1A
M=&$G75LG;6%P)UU;)&ME>5U=*2D@/SX\+W1D/CPO='(^"B`@("`@("`@/"]T
M86)L93X*("`@(#PO=&0^"CPO='(^"CQT<CX*("`@(#QT9"!C;&%S<STB:71E
M;2(^"B`@("`\=&%B;&4^"B`@("`\='(^"B`@("`@("`@/'1D/CP_<&AP(&5C
M:&\@7R@B17AA;7!L92!V86QU97,Z(BD@/SX\+W1D/@H@("`@("`@(#QT9#X*
M("`@("`@("`@("`@/'-E;&5C=#X*/#]P:'`@9F]R96%C:"`H)&1A=&5;)W9A
M;'5E<R==(&%S("1V86PI.B`_/@H@("`@("`@("`@("`@("`@/&]P=&EO;CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P=&EO;CX*
M/#]P:'`@96YD9F]R96%C:#L@/SX*("`@("`@("`@("`@/"]S96QE8W0^"B`@
M("`@("`@/"]T9#X*("`@(#PO='(^"CP_<&AP(&EN8VQU9&4@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+R<@+B!B87-E;F%M92@D9&%T95LG='EP92==*2`N("<N
M:6YC)R`_/@H@("`@/"]T86)L93X*("`@(#PO=&0^"CPO='(^"CP_<&AP(&5N
M9&EF.R`_/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H*/&EN<'5T
M('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C
M:&\@7R@B3F5X="(I(#\^(B`O/@H\+V9O<FT^"@``````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,`````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,#$W
M(#$P-3$U-#,T,30T(#`R,C`U-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HD:2`](#`["G=H:6QE("@D:2`\(&-O
M=6YT*"1D871E6R=V86QU97,G72D@)B8@96UP='DH)&1A=&5;)W9A;'5E<R==
M6R1I72DI('L*("`@("1I*RL["GT*:68@*'-T<G!O<R@D9&%T95LG=F%L=65S
M)UU;)&E=+"`G+R<I("$]/2!F86QS92D@>PH@("`@)&1E;"`]("<O)SL*?2!E
M;'-E:68@*'-T<G!O<R@D9&%T95LG=F%L=65S)UU;)&E=+"`G+B<I("$]/2!F
M86QS92D@>PH@("`@)&1E;"`]("<N)SL*?2!E;'-E:68@*'-T<G!O<R@D9&%T
M95LG=F%L=65S)UU;)&E=+"`G+2<I("$]/2!F86QS92D@>PH@("`@)&1E;"`]
M("<M)SL*?2!E;'-E('L*("`@("1D96P@/2`G)SL*?0H*+R\@5')Y('1O(&=U
M97-S('1H92!D871E(&9O<FUA="!A<R!M=6-H(&%S('!O<W-I8FQE"B1F;W)M
M(#T@;G5L;#L*:68@*"%E;7!T>2@D9&5L*2`F)B!I<W-E="@D9&%T95LG=F%L
M=65S)UTI("8F(&ES<V5T*"1D871E6R=V86QU97,G75LD:5TI*2!["B`@("`D
M<&%R=',@/2!E>'!L;V1E*"1D96PL("1D871E6R=V86QU97,G75LD:5TI.PH@
M("`@:68@*&-O=6YT*"1P87)T<RD@/CT@,RD@>PH@("`@("`@("1F;W)M(#T@
M)VUD>2<["B`@("`@("`@:68@*"AS=')L96XH)'!A<G1S6S!=*2`]/2`T*2!\
M?"`H)'!A<G1S6S!=(#X@,S$I*2!["B`@("`@("`@("`@("1F;W)M(#T@)WEM
M9"<["B`@("`@("`@("`@(&EF("@D<&%R='-;,5T@/B`Q,BD@>PH@("`@("`@
M("`@("`@("`@)&9O<FT@/2`G>61M)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS96EF("@D<&%R='-;,%T@/B`Q,BD@>PH@("`@("`@("`@("`D9F]R
M;2`]("=D;7DG.PH@("`@("`@('T*("`@('T*?0H_/@H\='(^"B`@/'1D/CP_
M<&AP(&5C:&\@7R@B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB*2`_/CPO
M=&0^"B`@/'1D/@H@("`@/'-E;&5C="!N86UE/2)D96QI;6ET97);/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I
M;VX@=F%L=64](B\B/#]P:'`@96-H;R`D9&5L(#T]("<O)R`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CXO/"]O<'1I;VX^"B`@("`@(#QO<'1I
M;VX@=F%L=64](BXB/#]P:'`@96-H;R`D9&5L(#T]("<N)R`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CXN/"]O<'1I;VX^"B`@("`@(#QO<'1I
M;VX@=F%L=64](BTB/#]P:'`@96-H;R`D9&5L(#T]("<M)R`_("<@<V5L96-T
M960](G-E;&5C=&5D(B<@.B`G)R`_/CXM/"]O<'1I;VX^"B`@("`\+W-E;&5C
M=#X*("`\+W1D/@H\+W1R/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@7R@B4V5L
M96-T('1H92!D871E(&9O<FUA=#HB*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E
M;&5C="!N86UE/2)F;W)M871;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@=F%L=64](FUD87DO;6]N=&@O
M>65A<B(\/W!H<"!E8VAO("1F;W)M(#T]("=D;7DG(#\@)R!S96QE8W1E9#TB
M<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B1$0B*2`N("1D96P@
M+B!?*")-32(I("X@)&1E;"`N(%\H(EE9(BD@/SX\+V]P=&EO;CX*("`@("`@
M/&]P=&EO;B!V86QU93TB;6]N=&@O;61A>2]Y96%R(CP_<&AP(&5C:&\@)&9O
M<FT@/3T@)VUD>2<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^
M/#]P:'`@96-H;R!?*")-32(I("X@)&1E;"`N(%\H(D1$(BD@+B`D9&5L("X@
M7R@B65DB*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)Y96%R
M+VUO;G1H+VUD87DB/#]P:'`@96-H;R`D9F]R;2`]/2`G>6UD)R`_("<@<V5L
M96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\/W!H<"!E8VAO(%\H(EE9(BD@
M+B`D9&5L("X@7R@B34TB*2`N("1D96P@+B!?*")$1"(I(#\^/"]O<'1I;VX^
M"B`@("`@(#QO<'1I;VX@=F%L=64](GEE87(O;61A>2]M;VYT:"(\/W!H<"!E
M8VAO("1F;W)M(#T]("=Y9&TG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z
M("<G(#\^/CP_<&AP(&5C:&\@7R@B65DB*2`N("1D96P@+B!?*")$1"(I("X@
M)&1E;"`N(%\H(DU-(BD@/SX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO
M=&0^"CPO='(^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,`````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R,3,W(#$P-3$U-#,T,30T(#`R,C`W-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HD:2`](#`["G=H
M:6QE("@D:2`\/2!C;W5N="@D9&%T95LG=F%L=65S)UTI("8F(&5M<'1Y*"1D
M871E6R=V86QU97,G75LD:5TI*2!["B`@("`D:2LK.PI]"FEF("AS=')P;W,H
M)&1A=&5;)W9A;'5E<R==6R1I72P@)SHG*2`A/3T@9F%L<V4I('L*("`@("1D
M96P@/2`G.B<["GT@96QS96EF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I
M72P@)RXG*2`A/3T@9F%L<V4I('L*("`@("1D96P@/2`G+B<["GT@96QS92![
M"B`@("`D9&5L(#T@)R<["GT*)&%M<&T@/2`H<W1R<&]S*%-T<FEN9SHZ;&]W
M97(H)&1A=&5;)W9A;'5E<R==6S!=*2P@)V%M)RD@(3T](&9A;'-E('Q\('-T
M<G!O<RA3=')I;F<Z.FQO=V5R*"1D871E6R=V86QU97,G75LP72DL("=P;2<I
M("$]/2!F86QS92D["C\^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!?*")396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.B(I(#\^/"]T9#X*("`\=&0^"B`@("`\
M<V5L96-T(&YA;64](F1E;&EM:71E<EL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB.B(\/W!H
M<"!E8VAO("1D96P@/3T@)SHG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z
M("<G(#\^/CH\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB+B(\/W!H
M<"!E8VAO("1D96P@/3T@)RXG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z
M("<G(#\^/BX\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^
M"CQT<CX*("`\=&0^/#]P:'`@96-H;R!?*")396QE8W0@=&AE('1I;64@9F]R
M;6%T.B(I(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&YA;64](F9O<FUA
M=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@
M("`@/&]P=&EO;B!V86QU93TB,C1H<B(\/W!H<"!E8VAO("1A;7!M(#\@)R<@
M.B`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^/CP_<&AP(&5C:&\@7R@B,C0@
M:&]U<G,B*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)A;7!M
M(CP_<&AP(&5C:&\@)&%M<&T@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@
M)R<@/SX^/#]P:'`@96-H;R!?*")!32]032(I(#\^/"]O<'1I;VX^"B`@("`\
M+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8P``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,P-#,@,3`U,34T,S0Q
M-#0@,#(R-C`U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#QF;W)M(&UE=&AO9#TB<&]S="(@;F%M93TB:6UP;W)T7V9O<FTB
M(&%C=&EO;CTB9&%T82YP:'`B/@H\/W!H<"!E8VAO(%5T:6PZ.F9O<FU);G!U
M="@I(#\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V
M86QU93TB/#]P:'`@96-H;R`H:6YT*21N97AT7W-T97`@/SXB("\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]F;W)M870B('9A;'5E/2)C
M<W8B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](FEM<&]R=%]S=&5P
M(B!V86QU93TB/#]P:'`@96-H;R`H:6YT*21I;7!O<G1?<W1E<"`_/B(@+SX*
M/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H(DEM<&]R="P@
M4W1E<"`E9"(I+"`H:6YT*21I;7!O<G1?<W1E<"D@/SX*/"]H,3X*/&1I=B!C
M;&%S<STB:&5A9&5R8F]X('1E>'0B/@H@("`@/#]P:'`@96-H;R!?*")(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(BD@/SX\8G(@+SX*("`@
M(#QP<F4^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG9FER<W1?;&EN97,G72D@/SX\+W!R93X\8G(@+SX*
M("`@(#QL86)E;"!F;W(](FAE861E<B(^/#]P:'`@96-H;R!?*")$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z(BD@/SX\+VQA8F5L/@H@("`@/&EN<'5T(&ED/2)H
M96%D97(B('1Y<&4](F-H96-K8F]X(B!N86UE/2)H96%D97(B('9A;'5E/2(Q
M(B!C:&5C:V5D/2)C:&5C:V5D(B`O/CQB<B`O/@H@("`@/#]P:'`@96-H;R!?
M*")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(I(#\^"B`@("`\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB<V5P(B!S:7IE/2(Q(B!V86QU93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1?4T534TE/3ELG:6UP;W)T
M7V1A=&$G75LG<V5P)UTI(#\^(B`O/CQB<B`O/@H@("`@/#]P:'`@:68@*&ES
M<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG<75O=&4G72DI.B`_/@H@
M("`@/#]P:'`@96-H;R!?*")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_
M(BD@/SX*("`@(#QI;G!U="!T>7!E/2)T97AT(B!N86UE/2)Q=6]T92(@<VEZ
M93TB,2(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D7U-%
M4U-)3TY;)VEM<&]R=%]D871A)UU;)W%U;W1E)UTI(#\^(B`O/CQB<B`O/@H@
M("`@/#]P:'`@96YD:68[(#\^"B`@("`\/W!H<"!I9B`H:7-S970H)%]315-3
M24].6R=I;7!O<G1?9&%T82==6R=F:65L9',G72DI.B`_/@H@("`@/#]P:'`@
M96-H;R!?*")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M*2`_/@H@("`@/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F9I96QD<R(@<VEZ
M93TB,B(@=F%L=64](CP_<&AP(&5C:&\@*&EN="DD7U-%4U-)3TY;)VEM<&]R
M=%]D871A)UU;)V9I96QD<R==(#\^(B`O/CQB<B`O/@H@("`@/#]P:'`@96YD
M:68[(#\^"CPO9&EV/@H\:6YP=70@='EP93TB<W5B;6ET(B!V86QU93TB/#]P
M:'`@96-H;R!?*").97AT(BD@/SXB(&-L87-S/2)B=71T;VXB("\^"CPO9F]R
M;3X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V1A=&$O9&%T971I;64N:6YC````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,3,V(#$P-3$U-#,T,30T(#`R
M,C<S-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HD:2`](#`["G=H:6QE("@D:2`\(&-O=6YT*"1D871E6R=V86QU
M97,G72D@)B8@96UP='DH)&1A=&5;)W9A;'5E<R==6R1I72DI('L*("`@("1I
M*RL["GT*)&1A>5]D96P@/2`D=&EM95]D96P@/2`G)SL*:68@*'-T<G!O<R@D
M9&%T95LG=F%L=65S)UU;)&E=+"`G("<I("$]/2!F86QS92D@>PH@("`@9F]R
M("@D;W)D97(@/2`P.R`H96UP='DH)'1I;65?9&5L*2!\?"!E;7!T>2@D9&%Y
M7V1E;"DI("8F("1O<F1E<B`\/2`Q.R`D;W)D97(K*RD@>PH@("`@("`@(&EF
M("@D;W)D97(I('L*("`@("`@("`@("`@;&ES="@D=&EM92P@)&1A>2D@/2!E
M>'!L;V1E*"<@)RP@)&1A=&5;)W9A;'5E<R==6R1I72P@,BD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D9&%Y+"`D=&EM92D@/2!E>'!L
M;V1E*"<@)RP@)&1A=&5;)W9A;'5E<R==6R1I72P@,BD["B`@("`@("`@?0H@
M("`@("`@(&EF("AS=')P;W,H)&1A>2P@)R\G*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)&1A>5]D96P@/2`G+R<["B`@("`@("`@?2!E;'-E:68@*'-T
M<G!O<R@D9&%Y+"`G+B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D9&%Y
M7V1E;"`]("<N)SL*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1D87DL("<M
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1D87E?9&5L(#T@)RTG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D87E?9&5L(#T@)R<["B`@
M("`@("`@?0H@("`@("`@(&EF("AS=')P;W,H)'1I;64L("<Z)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("1T:6UE7V1E;"`]("<Z)SL*("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1T:6UE+"`G+B<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D=&EM95]D96P@/2`G+B<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1I;65?9&5L(#T@)R<["B`@("`@("`@?0H@("`@?0H@("`@
M)&]R9&5R+2T["GT*"B\O(%1R>2!T;R!G=65S<R!T:&4@9&%T92!F;W)M870@
M87,@;75C:"!A<R!P;W-S:6)L90HD9F]R;2`](&YU;&P["FEF("@A96UP='DH
M)&1A>5]D96PI("8F(&ES<V5T*"1D871E6R=V86QU97,G72D@)B8@:7-S970H
M)&1A=&5;)W9A;'5E<R==6R1I72DI('L*("`@("1P87)T<R`](&5X<&QO9&4H
M)&1A>5]D96PL("1D871E6R=V86QU97,G75LD:5TI.PH@("`@:68@*&-O=6YT
M*"1P87)T<RD@/CT@,RD@>PH@("`@("`@("1F;W)M(#T@)VUD>2<["B`@("`@
M("`@:68@*"AS=')L96XH)'!A<G1S6S!=*2`]/2`T*2!\?"`H)'!A<G1S6S!=
M(#X@,S$I*2!["B`@("`@("`@("`@("1F;W)M(#T@)WEM9"<["B`@("`@("`@
M("`@(&EF("@D<&%R='-;,5T@/B`Q,BD@>PH@("`@("`@("`@("`@("`@)&9O
M<FT@/2`G>61M)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D
M<&%R='-;,%T@/B`Q,BD@>PH@("`@("`@("`@("`D9F]R;2`]("=D;7DG.PH@
M("`@("`@('T*("`@('T*?0HD86UP;2`]("AS=')P;W,H4W1R:6YG.CIL;W=E
M<B@D9&%T95LG=F%L=65S)UU;,%TI+"`G86TG*2`A/3T@9F%L<V4@?'P@<W1R
M<&]S*%-T<FEN9SHZ;&]W97(H)&1A=&5;)W9A;'5E<R==6S!=*2P@)W!M)RD@
M(3T](&9A;'-E*3L*"FEF("AS=')P;W,H)&1A=&5;)W9A;'5E<R==6R1I72P@
M)R`G*2`]/3T@9F%L<V4I.@H_/@H\='(^"B`@/'1D/CP_<&AP(&5C:&\@2&]R
M9&4Z.FQA8F5L*"=O<F1E<E\G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P@
M7R@B4V5L96-T('1H92!D871E(&%N9"!T:6UE(&9O<FUA=#HB*2D@/SX\+W1D
M/@H@(#QT9#X*("`@(#QS96QE8W0@:60](F]R9&5R7SP_<&AP(&5C:&\@:'1M
M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB;W)D97);/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@
M=F%L=64](BTQ(B!S96QE8W1E9#TB<V5L96-T960B/CP_<&AP(&5C:&\@7R@B
M5&EM97-T86UP(&]R('5N:VYO=VXB*2`_/CPO;W!T:6]N/@H@("`@/"]S96QE
M8W0^"B`@/"]T9#X*/"]T<CX*/#]P:'`@96QS93H@/SX*/'1R/@H@(#QT9#X\
M/W!H<"!E8VAO($AO<F1E.CIL86)E;"@G;W)D97)?)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%Y(&%N9"!T:6UE(&]R9&5R
M.B(I*2`_/CPO=&0^"B`@/'1D/@H@("`@/'-E;&5C="!I9#TB;W)D97)?/#]P
M:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(B!N86UE/2)O<F1E
M<EL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=(CX*("`@
M("`@/&]P=&EO;B!V86QU93TB+3$B/#]P:'`@96-H;R`H)&]R9&5R("8F("AE
M;7!T>2@D9&%Y7V1E;"D@?'P@96UP='DH)'1I;65?9&5L*2DI(#\@)R!S96QE
M8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B5&EM97-T
M86UP(&]R('5N:VYO=VXB*2`_/CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A
M;'5E/2(P(CP_<&AP(&5C:&\@*"$D;W)D97(I(#\@)R!S96QE8W1E9#TB<V5L
M96-T960B)R`Z("<G(#\^/CP_<&AP('!R:6YT9BA?*")$871E.B`E<SL@=&EM
M93H@)7,B*2P@)&1A>2P@)'1I;64I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I
M;VX@=F%L=64](C$B/#]P:'`@96-H;R`D;W)D97(@/R`G('-E;&5C=&5D/2)S
M96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@<')I;G1F*%\H(D1A=&4Z("5S.R!T
M:6UE.B`E<R(I+"`D9&%Y+"`D=&EM92D@/SX\+V]P=&EO;CX*("`@(#PO<V5L
M96-T/@H@(#PO=&0^"CPO='(^"CQT<CX*("`\=&0^/#]P:'`@96-H;R!(;W)D
M93HZ;&%B96PH)V1A>5]D96QI;6ET97)?)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(BDI(#\^/"]T
M9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)D87E?9&5L:6UI=&5R7SP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/B(@;F%M93TB9&%Y7V1E
M;&EM:71E<EL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SY=
M(CX*("`@("`@/&]P=&EO;B!V86QU93TB+R(\/W!H<"!E8VAO("1D87E?9&5L
M(#T]("<O)R`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CXO/"]O
M<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](BXB/#]P:'`@96-H;R`D9&%Y
M7V1E;"`]/2`G+B<@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^
M+CPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2(M(CP_<&AP(&5C:&\@
M)&1A>5]D96P@/3T@)RTG(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G
M(#\^/BT\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CQT
M<CX*("`\=&0^/#]P:'`@96-H;R!(;W)D93HZ;&%B96PH)V1A>5]F;W)M871?
M)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(BDI(#\^/"]T9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)D
M87E?9F]R;6%T7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_
M/B(@;F%M93TB9&%Y7V9O<FUA=%L\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&ME>2D@/SY=(CX*("`@("`@/&]P=&EO;B!V86QU93TB;61A>2]M;VYT
M:"]Y96%R(CP_<&AP(&5C:&\@)&9O<FT@/3T@)V1M>2<@/R`G('-E;&5C=&5D
M/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?*")$1"(I("X@)&1A
M>5]D96P@+B!?*")-32(I("X@)&1A>5]D96P@+B!?*")962(I(#\^/"]O<'1I
M;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](FUO;G1H+VUD87DO>65A<B(\/W!H
M<"!E8VAO("1F;W)M(#T]("=M9'DG(#\@)R!S96QE8W1E9#TB<V5L96-T960B
M)R`Z("<G(#\^/CP_<&AP(&5C:&\@7R@B34TB*2`N("1D87E?9&5L("X@7R@B
M1$0B*2`N("1D87E?9&5L("X@7R@B65DB*2`_/CPO;W!T:6]N/@H@("`@("`\
M;W!T:6]N('9A;'5E/2)Y96%R+VUO;G1H+VUD87DB/#]P:'`@96-H;R`D9F]R
M;2`]/2`G>6UD)R`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)R`_/CX\
M/W!H<"!E8VAO(%\H(EE9(BD@+B`D9&%Y7V1E;"`N(%\H(DU-(BD@+B`D9&%Y
M7V1E;"`N(%\H(D1$(BD@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU
M93TB>65A<B]M9&%Y+VUO;G1H(CP_<&AP(&5C:&\@)&9O<FT@/3T@)WED;2<@
M/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^/#]P:'`@96-H;R!?
M*")962(I("X@)&1A>5]D96P@+B!?*")$1"(I("X@)&1A>5]D96P@+B!?*")-
M32(I(#\^/"]O<'1I;VX^"B`@("`\+W-E;&5C=#X*("`\+W1D/@H\+W1R/@H\
M='(^"B`@/'1D/CP_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"=T:6UE7V1E;&EM
M:71E<E\G("X@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P@7R@B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB*2D@/SX\+W1D/@H@(#QT9#X*("`@(#QS96QE
M8W0@:60](G1I;65?9&5L:6UI=&5R7SP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D:V5Y*2`_/B(@;F%M93TB=&EM95]D96QI;6ET97);/#]P:'`@96-H
M;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^72(^"B`@("`@(#QO<'1I;VX@
M=F%L=64](CHB/#]P:'`@96-H;R`D=&EM95]D96P@/3T@)SHG(#\@)R!S96QE
M8W1E9#TB<V5L96-T960B)R`Z("<G(#\^/CH\+V]P=&EO;CX*("`@("`@/&]P
M=&EO;B!V86QU93TB+B(\/W!H<"!E8VAO("1T:6UE7V1E;"`]/2`G+B<@/R`G
M('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX^+CPO;W!T:6]N/@H@("`@
M/"]S96QE8W0^"B`@/"]T9#X*/"]T<CX*/'1R/@H@(#QT9#X\/W!H<"!E8VAO
M($AO<F1E.CIL86)E;"@G=&EM95]F;W)M871?)R`N(&AT;6QS<&5C:6%L8VAA
M<G,H)&ME>2DL(%\H(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(BDI(#\^/"]T
M9#X*("`\=&0^"B`@("`\<V5L96-T(&ED/2)T:6UE7V9O<FUA=%\\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@/SXB(&YA;64](G1I;65?9F]R
M;6%T6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2`_/ETB/@H@
M("`@("`\;W!T:6]N('9A;'5E/2(R-&AR(CP_<&AP(&5C:&\@)&%M<&T@/R`G
M)R`Z("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@96-H;R!?*"(R
M-"!H;W5R<R(I(#\^/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](F%M
M<&TB/#]P:'`@96-H;R`D86UP;2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@
M.B`G)R`_/CX\/W!H<"!E8VAO(%\H(D%-+U!-(BD@/SX\+V]P=&EO;CX*("`@
M(#PO<V5L96-T/@H@(#PO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R
M969S+VUU;'1I96YU;2YI;F,`````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q,#0W(#$P-3$U-#,T,30T(#`R,S,V-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<"!E8VAO($AO<F1E.CIL
M86)E;"@D<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\
M/W!H<"!E8VAO("1H96QP;&EN:R`_/CQB<B`O/@H\<V5L96-T(&ED/2(\/W!H
M<"!E8VAO("1P<F5F(#\^(B!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4](CP_
M<&AP(&5C:&\@;6EN*#0L(&-O=6YT*"1?<')E9G-;)'!R969=6R=E;G5M)UTI
M*2`_/B(@;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/EM=(CX*/#]P:'`@)'-E
M;&5C=&5D(#T@0'5N<V5R:6%L:7IE*"1P<F5F<RT^9V5T5F%L=64H)'!R968I
M*3L@9F]R96%C:"`H)%]P<F5F<ULD<')E9EU;)V5N=6TG72!A<R`D:V5Y(#T^
M("1V86PI.B`_/@H\;W!T:6]N/#]P:'`@96-H;R!I;E]A<G)A>2@D:V5Y+"`D
M<V5L96-T960I(#\@)R!S96QE8W1E9#TB<V5L96-T960B("<@.B`G)R`_/B!V
M86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'9A;"D@/SX\+V]P=&EO;CX*
M/#]P:'`@96YD9F]R96%C:"`_/@H\+W-E;&5C=#X*/&)R("\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,`````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$Q-C$S(#$P-3$U-#,T,30T(#`R-3(R,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@<F5M;W9E*&-A=&5G
M;W)Y*0I["B`@("!D;V-U;65N="YP<F5F<RYC06-T:6]N+G9A;'5E(#T@)W)E
M;6]V92<["B`@("!D;V-U;65N="YP<F5F<RYC871E9V]R>2YV86QU92`](&-A
M=&5G;W)Y.PH@("`@9&]C=6UE;G0N<')E9G,N<W5B;6ET*"D["GT*"F9U;F-T
M:6]N(&%D9"@I"GL*("`@('9A<B!C871E9V]R>2`]('=I;F1O=RYP<F]M<'0H
M)SP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(I*2`_/B<L("<G*3L*("`@(&EF("AC
M871E9V]R>2`A/2!N=6QL("8F(&-A=&5G;W)Y("$]("<G*2!["B`@("`@("`@
M9&]C=6UE;G0N<')E9G,N8T%C=&EO;BYV86QU92`]("=A9&0G.PH@("`@("`@
M(&1O8W5M96YT+G!R969S+F-A=&5G;W)Y+G9A;'5E(#T@8V%T96=O<GD["B`@
M("`@("`@9&]C=6UE;G0N<')E9G,N<W5B;6ET*"D["B`@("!]"GT*+R\M+3X*
M/"]S8W)I<'0^"CQI;G!U="!N86UE/2)C06-T:6]N(B!V86QU93TB(B!T>7!E
M/2)H:61D96XB("\^"CQI;G!U="!N86UE/2)C871E9V]R>2(@=F%L=64](B(@
M='EP93TB:&ED9&5N(B`O/@H\=&%B;&4^"B`\='(^"B`@/'1D(&-O;'-P86X]
M(C(B/@H@("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!V
M86QU93TB/#]P:'`@96-H;R!?*").97<@0V%T96=O<GDB*2`_/B(@;VYC;&EC
M:STB861D*"D[(B`O/@H@(#PO=&0^"B`\+W1R/@H\/W!H<`H*<F5Q=6ER95]O
M;F-E("=(;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP)SL*)&--86YA
M9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*)&-A=&5G;W)I
M97,@/2`D8TUA;F%G97(M/F=E="@I.PHD8V]L;W)S(#T@)&--86YA9V5R+3YC
M;VQO<G,H*3L*)&9G8V]L;W)S(#T@)&--86YA9V5R+3YF9T-O;&]R<R@I.PHD
M=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H
M;W)D92<I("X@)R]S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP)RD[
M"B1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)V9O<FTG+"`G<')E
M9G,G*3L*"B\O($1E9F%U;'0@0V]L;W(*)&-O;&]R(#T@:7-S970H)&-O;&]R
M<ULG7V1E9F%U;'1?)UTI(#\@)&-O;&]R<ULG7V1E9F%U;'1?)UT@.B`G(T9&
M1D9&1B<["B1F9V-O;&]R(#T@:7-S970H)&9G8V]L;W)S6R=?9&5F875L=%\G
M72D@/R`D9F=C;VQO<G-;)U]D969A=6QT7R==(#H@)R,P,#`P,#`G.PHD8U]U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W1A<F=E="<L("=C;VQO
M<E\G("X@8F%S938T7V5N8V]D92@G7V1E9F%U;'1?)RDI.PH_/@H@/'1R/@H@
M(#QT9"!S='EL93TB8F%C:V=R;W5N9#H\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&-O;&]R*2`_/CL@8V]L;W(Z/#]P:'`@96-H;R`D9F=C;VQO<B`_
M/B(^/'-T<F]N9SX\/W!H<"!E8VAO(%\H(D1E9F%U;'0@0V]L;W(B*2`_/CPO
M<W1R;VYG/CPO=&0^"B`@/'1D/@H@("`\/W!H<"!I9B`H(21P<F5F<RT^:7-,
M;V-K960H)V-A=&5G;W)Y7V-O;&]R<R<I*3H@/SX*("`@(#QI;G!U="!C;&%S
M<STB9FEX960B('-I>F4](C<B('-T>6QE/2)B86-K9W)O=6YD.CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D8V]L;W(I(#\^.R!C;VQO<CH\/W!H<"!E
M8VAO("1F9V-O;&]R(#\^(B!N86UE/2)C;VQO<E\\/W!H<"!E8VAO(&)A<V4V
M-%]E;F-O9&4H)U]D969A=6QT7R<I(#\^(B!V86QU93TB/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1C;VQO<BD@/SXB("\^"B`@("`\82!H<F5F/2(\
M/W!H<"!E8VAO("1C7W5R;"`_/B(@;VYC;&EC:STB=VEN9&]W+F]P96XH)SP_
M<&AP(&5C:&\@)&-?=7)L(#\^)RP@)V-O;&]R<&EC:V5R)RP@)W1O;VQB87(]
M;F\L;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L;&)A<G,];F\L<F5S:7IA
M8FQE/6YO+'=I9'1H/3$R,"QH96EG:'0],C4P+&QE9G0],3`P+'1O<#TQ,#`G
M*3L@<F5T=7)N(&9A;'-E.R(@;VYM;W5S96]U=#TB=VEN9&]W+G-T871U<STG
M)SLB(&]N;6]U<V5O=F5R/2)W:6YD;W<N<W1A='5S/2<\/W!H<"!E8VAO(%\H
M(D-O;&]R(%!I8VME<B(I(#\^)SL@<F5T=7)N('1R=64[(B!C;&%S<STB=VED
M9V5T(B!T87)G970](F-O;&]R<&EC:V5R(CX*("`@(#P_<&AP(&5C:&\@2&]R
M9&4Z.FEM9R@G8V]L;W)P:6-K97(N<&YG)RP@7R@B0V]L;W(@4&EC:V5R(BDL
M("=H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E
M)RDI(#\^/"]A/@H@("`\/W!H<"!E;F1I9CL@/SX*("`\+W1D/@H@/"]T<CX*
M/#]P:'`*+R\@56YF:6QE9"!#;VQO<@HD8V]L;W(@/2!I<W-E="@D8V]L;W)S
M6R=?=6YF:6QE9%\G72D@/R`D8V]L;W)S6R=?=6YF:6QE9%\G72`Z("<C1D9&
M1D9&)SL*)&9G8V]L;W(@/2!I<W-E="@D9F=C;VQO<G-;)U]U;F9I;&5D7R==
M*2`_("1F9V-O;&]R<ULG7W5N9FEL961?)UT@.B`G(S`P,#`P,"<["B1C7W5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G=&%R9V5T)RP@)V-O;&]R
M7R<@+B!B87-E-C1?96YC;V1E*"=?=6YF:6QE9%\G*2D["C\^"B`\='(^"B`@
M/'1D('-T>6QE/2)B86-K9W)O=6YD.CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D8V]L;W(I(#\^.R!C;VQO<CH\/W!H<"!E8VAO("1F9V-O;&]R(#\^
M(CX\<W1R;VYG/CP_<&AP(&5C:&\@7R@B56YF:6QE9"(I(#\^/"]S=')O;F<^
M/"]T9#X*("`\=&0^"B`@(#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G
M8V%T96=O<GE?8V]L;W)S)RDI.B`_/@H@("`@/&EN<'5T(&-L87-S/2)F:7AE
M9"(@<VEZ93TB-R(@<W1Y;&4](F)A8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1C;VQO<BD@/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G
M8V]L;W(@/SXB(&YA;64](F-O;&]R7SP_<&AP(&5C:&\@8F%S938T7V5N8V]D
M92@G7W5N9FEL961?)RD@/SXB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&-O;&]R*2`_/B(@+SX*("`@(#QA(&AR968](CP_<&AP(&5C
M:&\@)&-?=7)L(#\^(B!O;F-L:6-K/2)W:6YD;W<N;W!E;B@G/#]P:'`@96-H
M;R`D8U]U<FP@/SXG+"`G8V]L;W)P:6-K97(G+"`G=&]O;&)A<CUN;RQL;V-A
M=&EO;CUN;RQS=&%T=7,];F\L<V-R;VQL8F%R<SUN;RQR97-I>F%B;&4];F\L
M=VED=&@],3(P+&AE:6=H=#TR-3`L;&5F=#TQ,#`L=&]P/3$P,"<I.R!R971U
M<FX@9F%L<V4[(B!O;FUO=7-E;W5T/2)W:6YD;W<N<W1A='5S/2<G.R(@;VYM
M;W5S96]V97(](G=I;F1O=RYS=&%T=7,])SP_<&AP(&5C:&\@7R@B0V]L;W(@
M4&EC:V5R(BD@/SXG.R!R971U<FX@=')U93LB(&-L87-S/2)W:61G970B('1A
M<F=E=#TB8V]L;W)P:6-K97(B/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG
M*"=C;VQO<G!I8VME<BYP;F<G+"!?*")#;VQO<B!0:6-K97(B*2P@)VAE:6=H
M=#TB,38B)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\
M+V$^"B`@(#P_<&AP(&5N9&EF.R`_/@H@(#PO=&0^"B`\+W1R/@H\/W!H<`IF
M;W)E86-H("@D8V%T96=O<FEE<R!A<R`D;F%M92DZ"B`@("`D8V]L;W(@/2!I
M<W-E="@D8V]L;W)S6R1N86UE72D@/R`D8V]L;W)S6R1N86UE72`Z("<C1D9&
M1D9&)SL*("`@("1F9V-O;&]R(#T@:7-S970H)&9G8V]L;W)S6R1N86UE72D@
M/R`D9F=C;VQO<G-;)&YA;65=(#H@)R,P,#`P,#`G.PH@("`@)&-?=7)L(#T@
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=T87)G970G+"`G8V]L;W)?)R`N
M(&)A<V4V-%]E;F-O9&4H)&YA;64I*3L*/SX*(#QT<CX*("`\=&0@<W1Y;&4]
M(F)A8VMG<F]U;F0Z/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1C;VQO
M<BD@/SX[(&-O;&]R.CP_<&AP(&5C:&\@)&9G8V]L;W(@/SXB/CQS=')O;F<^
M/#]P:'`@96-H;R`H)&YA;64@/3T@)U]D969A=6QT7R<@/R!?*")$969A=6QT
M($-O;&]R(BD@.B!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2D@/SX\+W-T<F]N
M9SX\+W1D/@H@(#QT9#X*("`@/#]P:'`@:68@*"$D<')E9G,M/FES3&]C:V5D
M*"=C871E9V]R>5]C;VQO<G,G*2DZ(#\^"B`@("`\:6YP=70@8VQA<W,](F9I
M>&5D(B!S:7IE/2(W(B!S='EL93TB8F%C:V=R;W5N9#H\/W!H<"!E8VAO(&AT
M;6QS<&5C:6%L8VAA<G,H)&-O;&]R*2`_/CL@8V]L;W(Z/#]P:'`@96-H;R`D
M9F=C;VQO<B`_/B(@;F%M93TB8V]L;W)?/#]P:'`@96-H;R!B87-E-C1?96YC
M;V1E*"1N86UE*2`_/B(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D8V]L;W(I(#\^(B`O/@H@("`@/&$@:')E9CTB/#]P:'`@96-H;R`D
M8U]U<FP@/SXB(&]N8VQI8VL](G=I;F1O=RYO<&5N*"<\/W!H<"!E8VAO("1C
M7W5R;"`_/B<L("=C;VQO<G!I8VME<B<L("=T;V]L8F%R/6YO+&QO8V%T:6]N
M/6YO+'-T871U<SUN;RQS8W)O;&QB87)S/6YO+')E<VEZ86)L93UN;RQW:61T
M:#TQ,C`L:&5I9VAT/3(U,"QL969T/3$P,"QT;W`],3`P)RD[(')E='5R;B!F
M86QS93LB(&]N;6]U<V5O=70](G=I;F1O=RYS=&%T=7,])R<[(B!O;FUO=7-E
M;W9E<CTB=VEN9&]W+G-T871U<STG/#]P:'`@96-H;R!?*")#;VQO<B!0:6-K
M97(B*2`_/B<[(')E='5R;B!T<G5E.R(@8VQA<W,](G=I9&=E="(@=&%R9V5T
M/2)C;VQO<G!I8VME<B(^"B`@("`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V-O
M;&]R<&EC:V5R+G!N9R<L(%\H(D-O;&]R(%!I8VME<B(I+"`G:&5I9VAT/2(Q
M-B(G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`_/CPO83X*
M("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@/&$@:')E9CTB(R(@;VYC;&EC:STB
M<F5M;W9E*&1E8V]D955224-O;7!O;F5N="@G/#]P:'`@96-H;R!R87=U<FQE
M;F-O9&4H4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;F%M92P@3DQ3.CIG971#
M:&%R<V5T*"DL("=55$8M."<I*2`_/B<I*3L@<F5T=7)N(&9A;'-E.R(^/#]P
M:'`@96-H;R!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RD@/SX\+V$^"B`@/"]T
M9#X*(#PO='(^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO=&%B;&4^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W1E;7!L871E<R]P<F5F<R]P87-S=V]R9"YI;F,`````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#0S,"`Q,#4Q-30S-#$T-"`P,C,R,#,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`@
M96-H;R!(;W)D93HZ;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C
M)UTI(#\^)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/&EN
M<'5T('1Y<&4](G!A<W-W;W)D(B!I9#TB/#]P:'`@96-H;R`D<')E9B`_/B(@
M;F%M93TB/#]P:'`@96-H;R`D<')E9B`_/B(@<VEZ93TB,S`B(&UA>&QE;F=T
M:#TB-C`B(&-L87-S/2)F:7AE9"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2D@/SXB("\^/&)R
M("\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M<')E9G,O96YD+FEN8P``````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`W,S$@,3`U,34T,S0Q-#0@,#(R,3$S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#PO9&EV/@H*/&)R(&-L87-S
M/2)S<&%C97(B("\^"CQD:78@8VQA<W,](FYO=W)A<"(^"B`\:6YP=70@='EP
M93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?
M*")3879E($]P=&EO;G,B*2`_/B(@+SXF;F)S<#L*(#QI;G!U="!T>7!E/2)R
M97-E="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B56YD
M;R!#:&%N9V5S(BD@/SXB("\^)FYB<W`["B`\/W!H<"!I9B`H8V]U;G0H)'!R
M969'<F]U<',I(#X@,2DZ(#\^/&EN<'5T('1Y<&4](F)U='1O;B(@8VQA<W,]
M(F)U='1O;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5T=7)N('1O($]P=&EO
M;G,B*2`_/B(@;VYC;&EC:STB9&]C=6UE;G0N<')E9G,N86-T:6]N240N=F%L
M=64],#L@9&]C=6UE;G0N<')E9G,N9W)O=7`N=F%L=64])R<[(&1O8W5M96YT
M+G!R969S+G-U8FUI="@I.R(@+SX\/W!H<"!E;F1I9CL@/SX*/"]D:78^"CPO
M9F]R;3X*````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V]V97)V
M:65W+FEN8P``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-3$V
M(#$P-3$U-#,T,30T(#`R,S(Q-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\9&EV(&-L87-S/2)P<F5F<T]V97)V:65W(CX*
M/#]P:'`@9F]R96%C:"`H)&-O;'5M;G,@87,@)&ME>2`]/B`D8V]L=6UN*3H@
M/SX*(#QD:78@<W1Y;&4](G=I9'1H.CP_<&AP(&5C:&\@)'-P86X@+2`Q(#\^
M)2(^"B`@/&1I=CX*("`@/&@R/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D:V5Y*2`_/CPO:#(^"@H@("`\9&P^"B`@(#P_<&AP(&9O<F5A8V@@*"1C
M;VQU;6X@87,@)&=R;W5P(#T^("1G=F%L<RDZ(#\^"B`@("`\/W!H<"!I9B`H
M4')E9G-?54DZ.F=R;W5P27-%9&ET86)L92@D9W)O=7`I*3H@/SX*("`@("`\
M/W!H<"!I9B`H(65M<'1Y*"1G=F%L<ULG=7)L)UTI*3H@/SX*("`@("`@/&1T
M/CP_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A(;W)D93HZ87!P;&EC871I;VY5
M<FPH)&=V86QS6R=U<FPG72P@)&%P<"DL("1G=F%L<ULG;&%B96PG72P@)R<L
M("<G+"`G)RP@)&=V86QS6R=L86)E;"==*2`_/CPO9'0^"B`@("`@/#]P:'`@
M96QS93H@/SX*("`@("`@/&1T/CP_<&AP(&5C:&\@2&]R9&4Z.G=I9&=E="A5
M=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G-E;&95<FPH*2P@87)R87DH)V=R
M;W5P)R`]/B`D9W)O=7`L("=A<'`G(#T^("1'3$]"04Q36R=A<'`G72DI+"`D
M9W9A;'-;)VQA8F5L)UTL("<G+"`G)RP@)R<L("1G=F%L<ULG;&%B96PG72D@
M/SX\+V1T/@H@("`@(#P_<&AP(&5N9&EF.R`_/@H@("`@(#QD9#X\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=V86QS6R=D97-C)UTI(#\^/"]D9#X*
M("`@(#P_<&AP(&5N9&EF.R`_/@H@("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@
M("`\+V1L/@H@(#PO9&EV/@H@/"]D:78^"CP_<&AP(&5N9&9O<F5A8V@[(#\^
M"CPO9&EV/@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S
M+W-E;&5C="YI;F,`````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,C`P(#$P-3$U-#,T,30T(#`R,C8Q-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<"!E8VAO($AO<F1E.CIL86)E
M;"@D<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S<#L\/W!H
M<"!E8VAO("1H96QP;&EN:R`_/CQB<B`O/@H\<V5L96-T(&ED/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R968I(#\^(B!N86UE/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R968I(#\^(CX*/#]P:'`@)&5S8R`]
M("%E;7!T>2@D7W!R969S6R1P<F5F75LG97-C87!E9"==*3L@)&-U<G9A;"`]
M("1P<F5F<RT^9V5T5F%L=64H)'!R968I.R`D<V5L96-T7W9A<B`](%5T:6PZ
M.FYO;DEN<'5T5F%R*"1P<F5F("X@)U]O<'1I;VYS)RD[(&9O<F5A8V@@*"1S
M96QE8W1?=F%R(&%S("1S96QE8W1?:V5Y(#T^("1S96QE8W1?=F%L*3H@/SX*
M(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@)&5S8R`_("1S96QE8W1?:V5Y
M(#H@:'1M;'-P96-I86QC:&%R<R@D<V5L96-T7VME>2D@/SXB/#]P:'`@:68@
M*"1S96QE8W1?:V5Y(#T]("1C=7)V86PI(&5C:&\@)R!S96QE8W1E9#TB<V5L
M96-T960B)R`_/CX\/W!H<"!E8VAO("1E<V,@/R`D<V5L96-T7W9A;"`Z(&AT
M;6QS<&5C:6%L8VAA<G,H)'-E;&5C=%]V86PI(#\^/"]O<'1I;VX^"CP_<&AP
M(&5N9&9O<F5A8V@[(#\^"CPO<V5L96-T/@H\8G(@+SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+W!R969S+W1E>'0N:6YC````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P-#$P(#$P-3$U-#,T,30T(#`R,C,R,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<"!E8VAO($AO<F1E
M.CIL86)E;"@D<')E9BP@)%]P<F5F<ULD<')E9EU;)V1E<V,G72D@/SXF;F)S
M<#L\/W!H<"!E8VAO("1H96QP;&EN:R`_/CQB<B`O/@H\:6YP=70@:60](CP_
M<&AP(&5C:&\@)'!R968@/SXB(&YA;64](CP_<&AP(&5C:&\@)'!R968@/SXB
M('-I>F4](C,P(B!M87AL96YG=&@](C8P(B!C;&%S<STB9FEX960B('9A;'5E
M/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R969S+3YG971686QU
M92@D<')E9BDI(#\^(B`O/CQB<B`O/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]N=6UB
M97(N:6YC````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#,W
M-B`Q,#4Q-30S-#$T-"`P,C(V-#(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/&EN<'5T('1Y<&4](G1E>'0B(&ED/2(\/W!H
M<"!E8VAO("1P<F5F(#\^(B!N86UE/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!S
M:7IE/2(S(B!M87AL96YG=&@](C,B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'!R969S+3YG971686QU92@D<')E9BDI(#\^(B`O/@H\
M/W!H<"!E8VAO($AO<F1E.CIL86)E;"@D<')E9BP@)%]P<F5F<ULD<')E9EU;
M)V1E<V,G72D@/SXF;F)S<#L\/W!H<"!E8VAO("1H96QP;&EN:R`_/CQB<B`O
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q,S,@,3`U,34T,S0Q
M-#0@,#(T,S4V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP(&EF("@A)'!R969S+3YI<TQO8VME9"@G9&5F875L=%]I
M9&5N=&ET>2<I*3H@/SX*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/@H\(2TM"F9U;F-T:6]N(&1E;&5T94ED96YT:71Y*"D*>PH@("`@=F%R(&EN
M9&5X(#T@9&]C=6UE;G0N<')E9G,N:61E;G1I='DN<V5L96-T961);F1E>#L*
M("`@('9A<B!I9"`](&1O8W5M96YT+G!R969S+FED96YT:71Y+F]P=&EO;G-;
M:6YD97A=+G9A;'5E.PH@("`@:68@*&ED(#X](#`I('L*("`@("`@("!D;V-U
M;65N="YL;V-A=&EO;BYH<F5F(#T@(CP_<&AP(&5C:&\@<W1R7W)E<&QA8V4H
M)R9A;7`[)RP@)R8G+"!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G-E;&95
M<FPH=')U92DL(&%R<F%Y*"=A8W1I;VY)1"<@/3X@)V1E;&5T95]I9&5N=&ET
M>2<L("=I9"<@/3X@)R<I*2D@/SXB("L@:60["B`@("!]"GT*+R\M+3X*/"]S
M8W)I<'0^"CQB<B`O/@H\:6YP=70@='EP93TB8G5T=&]N(B!O;F-L:6-K/2)D
M96QE=&5)9&5N=&ET>2@I(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@
M96-H;R!?*")$96QE=&4@<V5L96-T960@:61E;G1I='DB*2`_/B(@+SX\8G(@
M+SX\8G(@+SX*/#]P:'`@96YD:68[(#\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O<')E9G,O=&5X=&%R96$N
M:6YC````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T-30@,3`U
M,34T,S0Q-#0@,#(S,38T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP(&5C:&\@2&]R9&4Z.FQA8F5L*"1P<F5F+"`D
M7W!R969S6R1P<F5F75LG9&5S8R==*2`_/B9N8G-P.SP_<&AP(&5C:&\@)&AE
M;'!L:6YK(#\^/&)R("\^"CQD:78@8VQA<W,](F9I>&5D(CX*/'1E>'1A<F5A
M('=R87`](FAA<F0B(&ED/2(\/W!H<"!E8VAO("1P<F5F(#\^(B!N86UE/2(\
M/W!H<"!E8VAO("1P<F5F(#\^(B!R;W=S/2(V(B!C;VQS/2(X,"(@8VQA<W,]
M(F9I>&5D(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R969S+3YG
M971686QU92@D<')E9BDI(#\^/"]T97AT87)E83X\8G(@+SX*/"]D:78^"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+W!R969S+V-H96-K8F]X+FEN8P``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,S<V(#$P-3$U-#,T,30T(#`R
M,S$T,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\:6YP=70@='EP93TB8VAE8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@:60]
M(CP_<&AP(&5C:&\@)'!R968@/SXB(&YA;64](CP_<&AP(&5C:&\@)'!R968@
M/SXB/#]P:'`@96-H;R`D<')E9G,M/F=E=%9A;'5E*"1P<F5F*2`_("<@8VAE
M8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX*/#]P:'`@96-H;R!(;W)D93HZ
M;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI(#\^)FYB<W`[
M/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX*/&)R("\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]P<F5F<R]E;G5M+FEN8P``````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,3`T-2`Q,#4Q-30S-#$T-"`P,C(S,3``(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`@96-H
M;R!(;W)D93HZ;&%B96PH)'!R968L("1?<')E9G-;)'!R969=6R=D97-C)UTI
M(#\^)FYB<W`[/#]P:'`@96-H;R`D:&5L<&QI;FL@/SX\8G(@+SX*/'-E;&5C
M="!I9#TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F*2`_/B(@
M;F%M93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1P<F5F*2`_/B(^
M"CP_<&AP("1E<V,@/2`A96UP='DH)%]P<F5F<ULD<')E9EU;)V5S8V%P960G
M72D[("1C=7)V86P@/2`D<')E9G,M/F=E=%9A;'5E*"1P<F5F*3L@9F]R96%C
M:"`H)%]P<F5F<ULD<')E9EU;)V5N=6TG72!A<R`D:V5Y(#T^("1V86PI.B`_
M/@H\;W!T:6]N/#]P:'`@96-H;R`D8W5R=F%L(#T]("1K97D@/R`G('-E;&5C
M=&5D/2)S96QE8W1E9"(G(#H@)R<@/SX@=F%L=64](CP_<&AP(&5C:&\@)&5S
M8R`_("1K97D@.B!H=&UL<W!E8VEA;&-H87)S*"1K97DI(#\^(CX\/W!H<"!E
M8VAO("1E<V,@/R`D=F%L(#H@:'1M;'-P96-I86QC:&%R<R@D=F%L*2`_/CPO
M;W!T:6]N/@H\/W!H<"!E;F1F;W)E86-H(#\^"CPO<V5L96-T/@H\8G(@+SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]P<F5F<R]B96=I;BYI;F,`````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<W-R`Q,#4Q-30S-#$T-"`P,C(T-#,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&9O
M<FT@;65T:&]D/2)P;W-T(B!N86UE/2)P<F5F<R(@86-T:6]N/2(\/W!H<"!E
M8VAO($AO<F1E.CIS96QF57)L*"D@/SXB/@H\/W!H<"!5=&EL.CIP9F]R;4EN
M<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B
M('9A;'5E/2)U<&1A=&5?<')E9G,B("\^"CQI;G!U="!T>7!E/2)H:61D96XB
M(&YA;64](F=R;W5P(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1G<F]U<"D@/SXB("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64]
M(F%P<"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D87!P
M*2`_/B(@+SX*"CQD:78@8VQA<W,](FAE861E<B(^"B`\/W!H<"!0<F5F<U]5
M23HZ9V5N97)A=&5.879I9V%T:6]N0V5L;"@D9W)O=7`I(#\^"B`\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'!R969'<F]U<'-;)&=R;W5P75LG;&%B
M96PG72D@/SX*(#QB<B!C;&%S<STB8VQE87(B("\^"CPO9&EV/@H*/&1I=B!C
M;&%S<STB:71E;2(^"@!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T
M97,O<')E9G,O87!P+FEN8P``````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(Q,S4@,3`U,34T,S0Q-#0@,#(R,3(U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#QF;W)M(&UE=&AO9#TB
M9V5T(B!N86UE/2)A<'!S=VET8V@B(&%C=&EO;CTB/#]P:'`@96-H;R`D<F5G
M:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]P
M<F5F<RYP:'`G(#\^(CX*/#]P:'`@96-H;R!5=&EL.CIF;W)M26YP=70H*2`_
M/@H\9&EV(&-L87-S/2)H96%D97(B/@H@/'-P86X@8VQA<W,](G-M86QL:&5A
M9&5R(')I9VAT1FQO870B/@H@(#P_<&AP(&5C:&\@7R@B161I="!O<'1I;VYS
M(&9O<CHB*2`_/@H@(#QS96QE8W0@;F%M93TB87!P(B!O;F-H86YG93TB9&]C
M=6UE;G0N87!P<W=I=&-H+G-U8FUI="@I.R(^"B`@("`\;W!T:6]N('9A;'5E
M/2(B/CP_<&AP(&5C:&\@7R@B0VAO;W-E($%P<&QI8V%T:6]N.B(I(#\^/"]O
M<'1I;VX^"CP_<&AP(&EF("@A96UP='DH)&%P<'-;)VAO<F1E)UTI*3H@/SX*
M("`@(#QO<'1I;VX@=F%L=64](B(^+2TM+3PO;W!T:6]N/@H@("`@/&]P=&EO
M;B!V86QU93TB:&]R9&4B/CP_<&AP(&5C:&\@7R@B1VQO8F%L($]P=&EO;G,B
M*2`_/CPO;W!T:6]N/@H@("`@/&]P=&EO;B!V86QU93TB(CXM+2TM/"]O<'1I
M;VX^"CP_<&AP(&5N9&EF.R`_/@H@("`\/W!H<"!F;W)E86-H("@D87!P<R!A
M<R`D:V5Y(#T^("1V86PI.B!I9B`H)&ME>2`]/2`G:&]R9&4G*2!C;VYT:6YU
M93L@/SX*("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I
M86QC:&%R<R@D:V5Y*2`_/B(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S
M*"1V86PI(#\^/"]O<'1I;VX^"B`@(#P_<&AP(&5N9&9O<F5A8V@[(#\^"B`@
M/"]S96QE8W0^"B`@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4](G-U8FUI
M="(@;VYC;&EC:STB<F5T=7)N(&1O8W5M96YT+F%P<'-W:71C:"YA<'`N<V5L
M96-T961);F1E>"`A/2`P.R(@=F%L=64](CP_<&AP(&5C:&\@7R@B1V\B*2`_
M/B(@+SX*(#PO<W!A;CX*(#P_<&AP(&EF("@D<F5G:7-T<GDM/F=E=$%P<"@I
M(#T]("=H;W)D92<I(&5C:&\@7R@B1VQO8F%L($]P=&EO;G,B*3L@96QS92!P
M<FEN=&8H7R@B3W!T:6]N<R!F;W(@)7,B*2P@)')E9VES=')Y+3YG970H)VYA
M;64G*2D@/SX*(#QB<B!C;&%S<STB8VQE87(B("\^"CPO9&EV/@H\+V9O<FT^
M"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]P<F5F<R]L:6YK+FEN8P``````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#4R,R`Q,#4Q-30S
M-#$T-"`P,C(S,#$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&$@:')E9CTB/#]P:'`@96-H;R`H:7-S970H)%]P<F5F<ULD
M<')E9EU;)W5R;"==*2D@/PI(;W)D93HZ87!P;&EC871I;VY5<FPH)%]P<F5F
M<ULD<')E9EU;)W5R;"==*2`Z("1?<')E9G-;)'!R969=6R=X=7)L)UT*/SXB
M/CP_<&AP(&EF("AI<W-E="@D7W!R969S6R1P<F5F75LG:6UG)UTI*2!E8VAO
M"DAO<F1E.CII;6<H)%]P<F5F<ULD<')E9EU;)VEM9R==+"`D7W!R969S6R1P
M<F5F75LG9&5S8R==+"`G:'-P86-E/2(S(B<I"C\^/'-T<F]N9SX\/W!H<"!E
M8VAO("1?<')E9G-;)'!R969=6R=D97-C)UT@/SX\+W-T<F]N9SX\+V$^)FYB
M<W`[/#]P:'`@96-H;PHD:&5L<&QI;FL@/SX\8G(@+SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4W,S(@,3`U,34T,S0Q-#0@,#(T-#`T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP(&EF("@D<')E9G,M/FES3&]C:V5D*"=D969A=6QT7VED96YT:71Y)RDI
M.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I9&5N=&ET>2(@=F%L
M=64](CP_<&AP(&5C:&\@*&EN="DD1TQ/0D%,4ULG:61E;G1I='DG72T^9V5T
M1&5F875L="@I(#\^(B`O/@H\/W!H<"!E;'-E.B`_/@H\<V-R:7!T('1Y<&4]
M(G1E>'0O:F%V87-C<FEP="(^"CPA+2T*"G9A<B!I9&5N=&ET:65S(#T@;F5W
M($%R<F%Y*"D["CP_<&AP"F=L;V)A;"`D:61E;G1I='D["B1I9&5N=&ET:65S
M(#T@)&ED96YT:71Y+3YG971!;&PH)VED)RD["B1D969A=6QT7VED96YT:71Y
M(#T@)&ED96YT:71Y+3YG971$969A=6QT*"D["B1M96UB97)S(#T@)'!R969'
M<F]U<'-;)VED96YT:71I97,G75LG;65M8F5R<R==.PIF;W(@*"1I(#T@,#L@
M)&D@/"!C;W5N="@D:61E;G1I=&EE<RD[("LK)&DI.@H_/@II9&5N=&ET:65S
M6SP_<&AP(&5C:&\@)&D@/SY=(#T@;F5W($%R<F%Y*"D["CP_<&AP"B1K(#T@
M,#L*9F]R96%C:"`H)&UE;6)E<G,@87,@)&UE;6)E<BDZ"B`@("!I9B`H)&UE
M;6)E<B`]/2`G9&5F875L=%]I9&5N=&ET>2<@?'P*("`@("`@("`A96UP='DH
M)%]P<F5F<ULD;65M8F5R75LG;&]C:V5D)UTI('Q\"B`@("`@("`@)%]P<F5F
M<ULD;65M8F5R75LG='EP92==(#T]("=S<&5C:6%L)R!\?`H@("`@("`@("1?
M<')E9G-;)&UE;6)E<EU;)W1Y<&4G72`]/2`G;&EN:R<I('L*("`@("`@("!C
M;VYT:6YU93L*("`@('T*/SX*:61E;G1I=&EE<UL\/W!H<"!E8VAO("1I(#\^
M75L\/W!H<"!E8VAO("1K*RL@/SY=(#T@;F5W($%R<F%Y*"(\/W!H<"!E8VAO
M("1M96UB97(@/SXB+"`B/#]P:'`@96-H;R`D7W!R969S6R1M96UB97)=6R=T
M>7!E)UT@/SXB+"`\/W!H<`HD=F%L(#T@)&ED96YT:71Y+3YG971686QU92@D
M;65M8F5R+"`D:2D["G-W:71C:"`H)%]P<F5F<ULD;65M8F5R75LG='EP92==
M*2!["F-A<V4@)V-H96-K8F]X)SH*("`@(&5C:&\@)'9A;"`_("=T<G5E)R`Z
M("=F86QS92<["B`@("!B<F5A:SL*"F-A<V4@)VYU;6)E<B<Z"B`@("!E8VAO
M("AI;G0I)'9A;#L*("`@(&)R96%K.PH*8V%S92`G=&5X=&%R96$G.@H@("`@
M:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@)'9A;"`](&EM<&QO9&4H
M(EQN(BP@)'9A;"D["B`@("!]"B`@("`D=F%L(#T@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D=F%L+"!.3%,Z.F=E=$-H87)S970H*2P@)U541BTX)RD["B`@
M("!E8VAO("=D96-O9&554DE#;VUP;VYE;G0H(B<@+B!R87=U<FQE;F-O9&4H
M)'9A;"D@+B`G(BDG.PH@("`@8G)E86L["@ID969A=6QT.@H@("`@)'9A;"`]
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;"P@3DQ3.CIG971#:&%R<V5T
M*"DL("=55$8M."<I.PH@("`@96-H;R`G9&5C;V1E55))0V]M<&]N96YT*"(G
M("X@<F%W=7)L96YC;V1E*"1V86PI("X@)R(I)SL*?0H_/BD["CP_<&AP(&5N
M9&9O<F5A8V@[(&5N9&9O<CL@/SX*"F9U;F-T:6]N(&YE=T-H;VEC92@I"GL*
M("`@('9A<B!F:65L9"P@=F%L.PH@("`@=F%R(&EN9&5X(#T@9&]C=6UE;G0N
M<')E9G,N:61E;G1I='DN<V5L96-T961);F1E>#L*("`@('9A<B!I9"`](&1O
M8W5M96YT+G!R969S+FED96YT:71Y+F]P=&EO;G-;:6YD97A=+G9A;'5E.PH@
M("`@:68@*&ED(#P@,"D@>PH@("`@("`@(&1O8W5M96YT+G!R969S+G)E<V5T
M*"D["B`@("`@("`@9&]C=6UE;G0N<')E9G,N:61E;G1I='DN<V5L96-T961)
M;F1E>"`](&EN9&5X.PH@("`@("`@(')E='5R;CL*("`@('T*("`@(&9O<B`H
M=F%R(&D@/2`P.R!I(#P@:61E;G1I=&EE<UMI9%TN;&5N9W1H.R!I*RLI('L*
M("`@("`@("!F:65L9"`](&1O8W5M96YT+G!R969S6VED96YT:71I97-;:61=
M6VE=6S!=73L*("`@("`@("!V86P@/2!I9&5N=&ET:65S6VED75MI75LR73L*
M("`@("`@("!S=VET8V@@*&ED96YT:71I97-;:61=6VE=6S%=*2!["B`@("`@
M("`@8V%S92`B96YU;2(Z"B`@("`@("`@("`@(&9O<B`H=F%R(&H@/2`P.R!J
M(#P@9FEE;&0N;W!T:6]N<RYL96YG=&@[(&HK*RD@>PH@("`@("`@("`@("`@
M("`@:68@*&9I96QD+F]P=&EO;G-;:ETN=F%L=64@/3T@=F%L*2!["B`@("`@
M("`@("`@("`@("`@("`@9FEE;&0N<V5L96-T961);F1E>"`](&H["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@(F-H
M96-K8F]X(CH*("`@("`@("`@("`@9FEE;&0N8VAE8VME9"`]('9A;#L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@(FEM<&QI8VET(CH*("`@
M("`@("`@("`@979A;"@B;F5W0VAO:6-E7R(@*R!I9&5N=&ET:65S6VED75MI
M75LP72`K("(H=F%L*2(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@9FEE;&0N=F%L=64@/2!V86P["B`@("`@
M("`@?0H@("`@?0I]"@HO+RTM/@H\+W-C<FEP=#X*/&)R("\^"CP_<&AP(&5C
M:&\@2&]R9&4Z.FQA8F5L*"=I9&5N=&ET>2<L(%\H(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(I*2`_/CQB<B`O/@H\<V5L96-T
M(&YA;64](FED96YT:71Y(B!I9#TB:61E;G1I='DB(&]N8VAA;F=E/2)J879A
M<V-R:7!T.FYE=T-H;VEC92@I(CX*("`\;W!T:6]N('9A;'5E/2(M,B(@<V5L
M96-T960](G-E;&5C=&5D(@H^/#]P:'`@96-H;R!?*").;VYE(BD@/SX\+V]P
M=&EO;CX*("`\;W!T:6]N('9A;'5E/2(M,2(^/#]P:'`@96-H;R!?*")#<F5A
M=&4@82!N97<@;VYE(BD@/SX\+V]P=&EO;CX*/#]P:'`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)&ED96YT:71I97,I.R`D:2LK*3H@/SX*("`\;W!T:6]N
M('9A;'5E/2(\/W!H<"!E8VAO("1I(#\^(CP_<&AP(&EF("@D:2`]/2`D9&5F
M875L=%]I9&5N=&ET>2D@96-H;R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#\^
M/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:61E;G1I=&EE<ULD:5TI
M(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<CL@/SX*/"]S96QE8W0^/&)R("\^
M"CP_<&AP(&5N9&EF.R`_/@H`````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]S
M:&%R97,O961I="YI;F,`````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R-C4R-R`Q,#4Q-30S-#$T-"`P,C(T-3,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/&9O<FT@;F%M93TB961I="(@
M;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D7U-%4E9%4ELG4$A07U-%3$8G72D@/SXB/@H\/W!H<"!5=&EL.CIP
M9F]R;4EN<'5T*"D@/SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T
M:6]N240B('9A;'5E/2)E9&ET9F]R;2(@+SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB8VED(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1S:&%R92T^9V5T260H*2D@/SXB("\^"CP_<&AP(&EF("@A96UP='DH
M)&%P<"DI.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A<'`B('9A
M;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&%P<"D@/SXB("\^
M"CP_<&AP(&5N9&EF.R`_/@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C
M:6YG/2(P(CX*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@=VED=&@](C$P
M,"4B(&-O;'-P86X](C8B(&-L87-S/2)H96%D97(B/@H@("`@/'-P86X@8VQA
M<W,](G)I9VAT1FQO870B/@H@("`@("`\82!H<F5F/2(C(B!O;F-L:6-K/2)J
M879A<V-R:7!T.G=I;F1O=RYC;&]S92@I.R(@<W1Y;&4](F-U<G-O<CIP;VEN
M=&5R(CX\/W!H<"!E8VAO($AO<F1E.CII;6<H)V-L;W-E+G!N9R<L(%\H(D-L
M;W-E(%=I;F1O=R(I+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2D@/SX\+V$^"B`@("`\+W-P86X^"B`@("`\/W!H<"!E8VAO($AO<F1E
M.CII;6<H)W!E<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2D@/SXF;F)S<#L\/W!H<"!P<FEN=&8H7R@B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B*2P@:'1M;'-P96-I86QC:&%R<R@D<VAA<F4M
M/F=E="@G;F%M92<I*2D@/SX*("`\+W1D/@H\+W1R/@H\='(^/'1D/B9N8G-P
M.SPO=&0^/"]T<CX*"CP_<&AP("1O=VYE<B`]("1S:&%R92T^9V5T*"=O=VYE
M<B<I.R`_/@H\/W!H<"`D=7-E<G!E<FUS(#T@)'!E<FTM/F=E=%5S97)097)M
M:7-S:6]N<R@I.R`_/@H*/"$M+2!/=VYE<G-H:7`@+2T^"CP_<&AP"FEF("AI
M<W-E="@D=7-E<G!E<FUS6R1O=VYE<ETI*2!["B`@("`D;W!E<FT@/2`D=7-E
M<G!E<FUS6R1O=VYE<ET["GT@96QS92!["B`@("`D;W!E<FT@/2!015)-4U]3
M2$]7('P@4$5235-?4D5!1"!\(%!%4DU37T5$250@?"!015)-4U]$14Q%5$4[
M"GT*/SX*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,](FAE861E
M<B!L969T06QI9VXB('=I9'1H/2(U-24B/@H@("`@/#]P:'`@96-H;R!(;W)D
M93HZ:6UG*"=P97)M<RYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H)VAO<F1E)RDI("X@)R9N8G-P.R<@+B!?*")/=VYE<B!097)M:7-S
M:6]N<R(I(#\^"B`@/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX]
M(F-E;G1E<B(@=VED=&@](C$E(CX\/W!H<"!E8VAO(%\H(E-H;W<B*2`_/CPO
M=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B('=I9'1H
M/2(Q)2(^/#]P:'`@96-H;R!?*")296%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S
M<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(B!W:61T:#TB,24B/CP_<&AP(&5C
M:&\@7R@B161I="(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI
M9VX](F-E;G1E<B(@=VED=&@](C$E(CX\/W!H<"!E8VAO(%\H(D1E;&5T92(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B!R:6=H=$%L:6=N(B!W:61T
M:#TB-#`E(CXF;F)S<#L\+W1D/@H\+W1R/@H\='(^"CP_<&AP(&EF("@D875T
M:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I*3H@/SX*("`\=&0@8VQA<W,](FQI
M9VAT(CX*("`@(#QS96QE8W0@;F%M93TB;W=N97(B/@H@("`@("`\;W!T:6]N
M('9A;'5E/2(B/CP_<&AP(&5C:&\@7R@B4V5L96-T(&$@;F5W(&]W;F5R(BD@
M+B`G.B<@/SX\+V]P=&EO;CX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1O=VYE<BD@/SXB('-E;&5C=&5D/2)S
M96QE8W1E9"(^/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*$%U=&@Z.G)E
M;6]V94AO;VLH)&]W;F5R*2D@/SX\+V]P=&EO;CX*("`@(#P_<&AP(&9O<F5A
M8V@@*"1U<V5R3&ES="!A<R`D=7-E<BD@>R!I9B`H)'5S97(@(3T@)&]W;F5R
M*2![(#\^"B`@("`@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P
M96-I86QC:&%R<R@D=7-E<BD@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<RA!=71H.CIR96UO=F5(;V]K*"1U<V5R*2D@/SX\+V]P=&EO;CX*("`@
M(#P_<&AP('T@?2`_/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*/#]P:'`@96QS
M93H@/SX*("`\=&0@8VQA<W,](FQI9VAT(CX\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB;W=N97(B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&]W;F5R*2`_/B(@+SX\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\=&0@
M86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)O
M=VYE<E]S:&]W(CP_<&AP(&5C:&\@*"1O<&5R;2`F(%!%4DU37U-(3U<I(#\@
M)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L
M:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB;W=N
M97)?<F5A9"(\/W!H<"!E8VAO("@D;W!E<FT@)B!015)-4U]214%$*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG
M;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F]W;F5R
M7V5D:70B/#]P:'`@96-H;R`H)&]P97)M("8@4$5235-?141)5"D@/R`G(&-H
M96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX]
M(F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)O=VYE<E]D
M96QE=&4B/#]P:'`@96-H;R`H)&]P97)M("8@4$5235-?1$5,151%*2`_("<@
M8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H\+W1R/@H*/"$M
M+2!3<&%C97(@+2T^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H*/"$M+2!$
M969A=6QT(%!E<FUI<W-I;VYS("TM/@H\='(@=F%L:6=N/2)M:61D;&4B/@H@
M(#QT9"!C;&%S<STB:&5A9&5R(&QE9G1!;&EG;B(^"B`@("`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)W!E<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG
M971);6%G941I<B@G:&]R9&4G*2D@+B`G)FYB<W`[)R`N(%\H(D%L;"!!=71H
M96YT:6-A=&5D(%5S97)S(BD@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB:&5A
M9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E-H;W<B*2`_/CPO
M=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP
M(&5C:&\@7R@B4F5A9"(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@
M86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")%9&ET(BD@/SX\+W1D/@H@
M(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO
M(%\H(D1E;&5T92(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B!R:6=H
M=$%L:6=N(CXF;F)S<#L\+W1D/@H\+W1R/@H\/W!H<"`D9'!E<FT@/2`D<&5R
M;2T^9V5T1&5F875L=%!E<FUI<W-I;VYS*"D[(#\^"CQT<CX*("`\=&0@8VQA
M<W,](FQI9VAT(CXF;F)S<#L\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F1E9F%U;'1?<VAO=R(\/W!H
M<"!E8VAO("@D9'!E<FT@)B!015)-4U]32$]7*2`_("<@8VAE8VME9#TB8VAE
M8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F1E9F%U;'1?<F5A9"(\/W!H
M<"!E8VAO("@D9'!E<FT@)B!015)-4U]214%$*2`_("<@8VAE8VME9#TB8VAE
M8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F1E9F%U;'1?961I="(\/W!H
M<"!E8VAO("@D9'!E<FT@)B!015)-4U]%1$E4*2`_("<@8VAE8VME9#TB8VAE
M8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F1E9F%U;'1?9&5L971E(CP_
M<&AP(&5C:&\@*"1D<&5R;2`F(%!%4DU37T1%3$5412D@/R`G(&-H96-K960]
M(F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*/"]T<CX*"CPA+2T@4W!A8V5R
M("TM/@H\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CX*"CPA+2T@1W5E<W0@4&5R
M;6ES<VEO;G,@+2T^"CQT<B!V86QI9VX](FUI9&1L92(^"B`@/'1D(&-L87-S
M/2)H96%D97(@;&5F=$%L:6=N(CX*("`@(#P_<&AP(&5C:&\@7R@B1W5E<W0@
M4&5R;6ES<VEO;G,B*2`_/@H@(#PO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B
M(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4VAO=R(I(#\^/"]T9#X*
M("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H
M;R!?*")296%D(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG
M;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D5D:70B*2`_/CPO=&0^"B`@/'1D
M(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B
M1&5L971E(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(')I9VAT06QI
M9VXB/B9N8G-P.SPO=&0^"CPO='(^"CP_<&AP("1G<&5R;2`]("1P97)M+3YG
M971'=65S=%!E<FUI<W-I;VYS*"D[(#\^"CQT<CX*("`\=&0@8VQA<W,](FQI
M9VAT(CXF;F)S<#L\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@
M='EP93TB8VAE8VMB;W@B(&YA;64](F=U97-T7W-H;W<B/#]P:'`@96-H;R`H
M)&=P97)M("8@4$5235-?4TA/5RD@/R`G(&-H96-K960](F-H96-K960B)R`Z
M("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y
M<&4](F-H96-K8F]X(B!N86UE/2)G=65S=%]R96%D(CP_<&AP(&5C:&\@*"1G
M<&5R;2`F(%!%4DU37U)%040I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G
M)R`_/B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB9W5E<W1?961I="(\/W!H<"!E8VAO("@D9W!E
M<FT@)B!015)-4U]%1$E4*2`_("<@8VAE8VME9#TB8VAE8VME9"(G(#H@)R<@
M/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB
M8VAE8VMB;W@B(&YA;64](F=U97-T7V1E;&5T92(\/W!H<"!E8VAO("@D9W!E
M<FT@)B!015)-4U]$14Q%5$4I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G
M)R`_/B`O/CPO=&0^"CPO='(^"@H\(2TM(%-P86-E<B`M+3X*/'1R/CQT9#XF
M;F)S<#L\+W1D/CPO='(^"@H\(2TM($-R96%T;W(@4&5R;6ES<VEO;G,@+2T^
M"CQT<B!V86QI9VX](FUI9&1L92(^"B`@/'1D(&-L87-S/2)H96%D97(@;&5F
M=$%L:6=N(CX*("`@(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G=7-E<BYP;F<G
M+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@
M)R9N8G-P.R<@+B!?*")/8FIE8W0@0W)E871O<B(I(#\^"B`@/"]T9#X*("`\
M=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?
M*")3:&]W(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E)E860B*2`_/CPO=&0^"B`@/'1D(&-L
M87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B161I
M="(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E
M<B(^/#]P:'`@96-H;R!?*")$96QE=&4B*2`_/CPO=&0^"B`@/'1D(&-L87-S
M/2)H96%D97(@<FEG:'1!;&EG;B(^/"]T9#X*/"]T<CX*/#]P:'`@)&-P97)M
M(#T@)'!E<FTM/F=E=$-R96%T;W)097)M:7-S:6]N<R@I.R`_/@H\='(^"B`@
M/'1D(&-L87-S/2)L:6=H="(^)FYB<W`[/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)C<F5A=&]R7W-H
M;W<B/#]P:'`@96-H;R`H)&-P97)M("8@4$5235-?4TA/5RD@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)C<F5A=&]R7W)E
M860B/#]P:'`@96-H;R`H)&-P97)M("8@4$5235-?4D5!1"D@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)C<F5A=&]R7V5D
M:70B/#]P:'`@96-H;R`H)&-P97)M("8@4$5235-?141)5"D@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)C<F5A=&]R7V1E
M;&5T92(\/W!H<"!E8VAO("@D8W!E<FT@)B!015)-4U]$14Q%5$4I(#\@)R!C
M:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"CPO='(^"@H\(2TM
M(%-P86-E<B`M+3X*/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^"@H\(2TM(%5S
M97(@4&5R;6ES<VEO;G,@+2T^"CQT<B!V86QI9VX](FUI9&1L92(^"B`@/'1D
M(&-L87-S/2)H96%D97(@;&5F=$%L:6=N(CX*("`@(#P_<&AP(&5C:&\@2&]R
M9&4Z.FEM9R@G=7-E<BYP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA
M9V5$:7(H)VAO<F1E)RDI("X@)R9N8G-P.R<@+B!?*"));F1I=FED=6%L(%5S
M97)S(BD@/SX*("`\+W1D/@H@(#QT9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB
M8V5N=&5R(CX\/W!H<"!E8VAO(%\H(E-H;W<B*2`_/CPO=&0^"B`@/'1D(&-L
M87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C:&\@7R@B4F5A
M9"(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI9VX](F-E;G1E
M<B(^/#]P:'`@96-H;R!?*")%9&ET(BD@/SX\+W1D/@H@(#QT9"!C;&%S<STB
M:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H(D1E;&5T92(I
M(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B!R:6=H=$%L:6=N(CX\+W1D
M/@H\+W1R/@H\/W!H<"!F;W)E86-H("@D=7-E<G!E<FUS(&%S("1U<V5R(#T^
M("1U<&5R;2D@>R!I9B`H)'5S97(@(3T@)&]W;F5R*2![(#\^"CQT<CX*("`\
M=&0@8VQA<W,](FQI9VAT(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M075T:#HZ<F5M;W9E2&]O:R@D=7-E<BDI(#\^/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB=5]N86UE<UL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'5S97(I(#\^72(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R
M<R@D=7-E<BD@/SXB("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN
M<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7W-H;W=;/#]P:'`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_/ETB/#]P:'`@96-H;R`H)'5P97)M
M("8@4$5235-?4TA/5RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^
M("\^/"]T9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H
M96-K8F]X(B!N86UE/2)U7W)E861;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H
M87)S*"1U<V5R*2`_/ETB/#]P:'`@96-H;R`H)'5P97)M("8@4$5235-?4D5!
M1"D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\
M=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE
M/2)U7V5D:71;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`_
M/ETB/#]P:'`@96-H;R`H)'5P97)M("8@4$5235-?141)5"D@/R`G(&-H96-K
M960](F-H96-K960B)R`Z("<G(#\^("\^/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7V1E;&5T95L\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^72(\/W!H<"!E
M8VAO("@D=7!E<FT@)B!015)-4U]$14Q%5$4I(#\@)R!C:&5C:V5D/2)C:&5C
M:V5D(B<@.B`G)R`_/B`O/CPO=&0^"CPO='(^"CP_<&AP('T@?2`_/@H\(2TM
M($YE=R!U<V5R(')O=R`M+3X*/'1R/@H\/W!H<"!I9B`H)&%U=&@M/FAA<T-A
M<&%B:6QI='DH)VQI<W0G*2DZ(#\^"B`@/'1D(&-L87-S/2)L:6=H="(^"B`@
M("`\<V5L96-T(&YA;64](G5?;F%M97-;?'QN97==(CX*("`@("`@/&]P=&EO
M;B!V86QU93TB(CX\/W!H<"!E8VAO(%\H(E-E;&5C="!A('5S97(@=&\@861D
M(BD@+B`G.B<@/SX\+V]P=&EO;CX*("`@(#P_<&AP(&9O<F5A8V@@*"1U<V5R
M3&ES="!A<R`D=7-E<BD@>R!I9B`H(6ES<V5T*"1U<V5R<&5R;7-;)'5S97)=
M*2D@>R`_/@H@("`@("`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'5S97(I(#\^(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H075T:#HZ<F5M;W9E2&]O:R@D=7-E<BDI(#\^/"]O<'1I;VX^"B`@
M("`\/W!H<"!]('T@/SX*("`@(#PO<V5L96-T/@H@(#PO=&0^"CP_<&AP(&5L
M<V4Z(#\^"B`@/'1D(&-L87-S/2)L:6=H="(^/&EN<'5T('1Y<&4](G1E>'0B
M(&YA;64](G5?;F%M97-;?'QN97==(B`O/CPO=&0^"CP_<&AP(&5N9&EF.R`_
M/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&YA;64](G5?<VAO=UM\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)U7W)E861;?'QN
M97==(B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E
M/2)C:&5C:V)O>"(@;F%M93TB=5]E9&ET6WQ\;F5W72(@+SX\+W1D/@H@(#QT
M9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64]
M(G5?9&5L971E6WQ\;F5W72(@+SX\+W1D/@H\+W1R/@H*/"$M+2!3<&%C97(@
M+2T^"CQT<CX\=&0^)FYB<W`[/"]T9#X\+W1R/@H*/"$M+2!'<F]U<"!097)M
M:7-S:6]N<R`M+3X*/'1R('9A;&EG;CTB;6ED9&QE(CX*("`\=&0@8VQA<W,]
M(FAE861E<B!L969T06QI9VXB/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG
M*"=G<F]U<"YP;F<G+"`G)RP@)R<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI("X@)R9N8G-P.R<@+B!?*")'<F]U<',B*2`_/@H@(#PO=&0^
M"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C96YT97(B/CP_<&AP(&5C
M:&\@7R@B4VAO=R(I(#\^/"]T9#X*("`\=&0@8VQA<W,](FAE861E<B(@86QI
M9VX](F-E;G1E<B(^/#]P:'`@96-H;R!?*")296%D(BD@/SX\+W1D/@H@(#QT
M9"!C;&%S<STB:&5A9&5R(B!A;&EG;CTB8V5N=&5R(CX\/W!H<"!E8VAO(%\H
M(D5D:70B*2`_/CPO=&0^"B`@/'1D(&-L87-S/2)H96%D97(B(&%L:6=N/2)C
M96YT97(B/CP_<&AP(&5C:&\@7R@B1&5L971E(BD@/SX\+W1D/@H@(#QT9"!C
M;&%S<STB:&5A9&5R(')I9VAT06QI9VXB/B9N8G-P.SPO=&0^"CPO='(^"CP_
M<&AP("1G<F]U<'!E<FUS(#T@)'!E<FTM/F=E=$=R;W5P4&5R;6ES<VEO;G,H
M*3L@9F]R96%C:"`H)&=R;W5P<&5R;7,@87,@)&=R;W5P(#T^("1G<&5R;2DZ
M(&EF("@A)&=R;W5P<RT^97AI<W1S*"1G<F]U<',M/F=E=$=R;W5P3F%M92@D
M9W)O=7`I*2D@8V]N=&EN=64[(#\^"CQT<CX*("`\=&0@8VQA<W,](FQI9VAT
M(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P<RT^9V5T1W)O
M=7!.86UE*"1G<F]U<"DI(#\^/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB
M9U]N86UE<UL\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P*2`_
M/ETB('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&=R;W5P
M*2`_/B(@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&YA;64](F=?<VAO=UL\/W!H<"!E8VAO(&AT;6QS<&5C
M:6%L8VAA<G,H)&=R;W5P*2`_/ETB/#]P:'`@96-H;R`H)&=P97)M("8@4$52
M35-?4TA/5RD@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G(#\^("\^/"]T
M9#X*("`\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X
M(B!N86UE/2)G7W)E861;/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G
M<F]U<"D@/SY=(CP_<&AP(&5C:&\@*"1G<&5R;2`F(%!%4DU37U)%040I(#\@
M)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)R`_/B`O/CPO=&0^"B`@/'1D(&%L
M:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]E
M9&ET6SP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^72(\
M/W!H<"!E8VAO("@D9W!E<FT@)B!015)-4U]%1$E4*2`_("<@8VAE8VME9#TB
M8VAE8VME9"(G(#H@)R<@/SX@+SX\+W1D/@H@(#QT9"!A;&EG;CTB8V5N=&5R
M(CX\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](F=?9&5L971E6SP_<&AP
M(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9W)O=7`I(#\^72(\/W!H<"!E8VAO
M("@D9W!E<FT@)B!015)-4U]$14Q%5$4I(#\@)R!C:&5C:V5D/2)C:&5C:V5D
M(B<@.B`G)R`_/B`O/CPO=&0^"CPO='(^"CP_<&AP(&5N9&9O<F5A8V@[(#\^
M"CPA+2T@3F5W(&=R;W5P(')O=R`M+3X*/'1R/@H@(#QT9"!C;&%S<STB;&EG
M:'0B/@H@("`@/'-E;&5C="!N86UE/2)G7VYA;65S6WQ\;F5W72(^"B`@("`@
M(#QO<'1I;VX@=F%L=64](B(^/#]P:'`@96-H;R!?*")396QE8W0@82!G<F]U
M<"!T;R!A9&0B*2`N("<Z)R`_/CPO;W!T:6]N/@H@("`@/#]P:'`@9F]R96%C
M:"`H)&=R;W5P3&ES="!A<R`D9VED(#T^("1G<F]U<"D@>R!I9B`H96UP='DH
M)&=R;W5P<&5R;7-;)&=I9%TI*2![(#\^"B`@("`@(#QO<'1I;VX@=F%L=64]
M(CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9VED*2`_/B(^/#]P:'`@
M96-H;R!H=&UL<W!E8VEA;&-H87)S*"1G<F]U<"D@/SX\+V]P=&EO;CX*("`@
M(#P_<&AP('T@?2`_/@H@("`@/"]S96QE8W0^"B`@/"]T9#X*("`\=&0@86QI
M9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7W-H
M;W=;?'QN97==(B`O/CPO=&0^"B`@/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U
M="!T>7!E/2)C:&5C:V)O>"(@;F%M93TB9U]R96%D6WQ\;F5W72(@+SX\+W1D
M/@H@(#QT9"!A;&EG;CTB8V5N=&5R(CX\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&YA;64](F=?961I=%M\?&YE=UTB("\^/"]T9#X*("`\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2)G7V1E;&5T95M\
M?&YE=UTB("\^/"]T9#X*/"]T<CX*"CQT<CX*(#QT9#XF;F)S<#L\+W1D/@H\
M+W1R/@H*/'1R/@H@/'1D(&-O;'-P86X](C<B/@H@(#QI;G!U="!T>7!E/2)S
M=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!P<FEN=&8H7R@B
M4V%V92`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"1S:&%R92T^9V5T*"=N86UE
M)RDI*2`_/B(@+SX*/#]P:'`@:68@*$!C;W5N="@D8VAI;&1R96XI*3H@/SX*
M("`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K
M/2)D;V-U;65N="YE9&ET+F%C=&EO;DE$+G9A;'5E(#T@)V5D:71F;W)M:6YH
M97)I="<[(B!V86QU93TB/#]P:'`@96-H;R!?*")!<'!L>2!T;R!#:&EL9"!3
M:&%R97,B*2`_/B(@+SX*/#]P:'`@96YD:68[(#\^"B`\+W1D/@H\+W1R/@H*
M/"]T86)L93X*/"]F;W)M/@H\8G(@+SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E
M<R]I;F1E>"]F<F%M97-?:6YD97@N:6YC````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C(U,R`Q,#4Q-30S-#$T-"`P,C0P,#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`@)')T;"`](&ES
M<V5T*"1N;'-;)W)T;"==6R1L86YG=6%G95TI(#\^"CPA1$]#5%E012!H=&UL
M(%!50DQ)0R`B+2\O5S-#+R]$5$0@6$A434P@,2XP($9R86UE<V5T+R]%3B(@
M(D141"]X:'1M;#$M9G)A;65S970N9'1D(CX*/&AT;6P^"CQH96%D/@H@/&QI
M;FL@<F5L/2)32$]25$-55"!)0T].(B!H<F5F/2(\/W!H<"!E8VAO("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H*2`_/B]F879I8V]N+FEC;R(@+SX*(#QT:71L
M93X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)')E9VES=')Y+3YG970H
M)VYA;64G*2D@/SX\+W1I=&QE/@H\+VAE860^"@H\9G)A;65S970@:60](FAF
M(B!C;VQS/2(\/W!H<"!E8VAO("@D<G1L(#\@)RHL)R`Z("<G*2`N("AI<W-E
M="@D<')E9G,I(#\@)'!R969S+3YG971686QU92@G<VED96)A<E]W:61T:"<I
M(#H@,34P*2`N("@D<G1L(#\@)R<@.B`G+"HG*2`_/B(@9G)A;65S<&%C:6YG
M/2(P(B!F<F%M96)O<F1E<CTB,"(^"CP_<&AP(&EF("@D<G1L*3H@/SX*("`\
M9G)A;64@;F%M93TB:&]R9&5?;6%I;B(@<W)C/2(\/W!H<"!E8VAO(%5T:6PZ
M.F%D9%!A<F%M971E<BAH=&UL<W!E8VEA;&-H87)S*"1M86EN7W!A9V4I+"`G
M9G)A;65S971?;&]A9&5D)RP@,2D@/SXB('-C<F]L;&EN9STB/#]P:'`@96-H
M;R`D<V-R;VQL8F%R(#\^(B!N;W)E<VEZ93TB;F]R97-I>F4B("\^"B`@/&9R
M86UE(&YA;64](FAO<F1E7VUE;G4B('-R8STB/#]P:'`@96-H;R!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)W-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<"<I
M(#\^(B!S8W)O;&QI;F<](F%U=&\B(&YO<F5S:7IE/2)N;W)E<VEZ92(@+SX*
M/#]P:'`@96QS93H@/SX*("`\9G)A;64@;F%M93TB:&]R9&5?;65N=2(@<W)C
M/2(\/W!H<"!E8VAO($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP)RD@/SXB('-C<F]L;&EN9STB875T;R(@;F]R
M97-I>F4](FYO<F5S:7IE(B`O/@H@(#QF<F%M92!N86UE/2)H;W)D95]M86EN
M(B!S<F,](CP_<&AP(&5C:&\@571I;#HZ861D4&%R86UE=&5R*&AT;6QS<&5C
M:6%L8VAA<G,H)&UA:6Y?<&%G92DL("=F<F%M97-E=%]L;V%D960G+"`Q*2`_
M/B(@<V-R;VQL:6YG/2(\/W!H<"!E8VAO("1S8W)O;&QB87(@/SXB(&YO<F5S
M:7IE/2)N;W)E<VEZ92(@+SX*/#]P:'`@96YD:68[(#\^"CPO9G)A;65S970^
M"@H\+VAT;6P^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(`````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,30T(#`R,34R,0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M
M:6XO<V5T=7``````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q-#0@,#(Q-S`S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',`````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-"`P,C(P-C(`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH
M96%D97(N:6YC````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S(S(#$P
M-3$U-#,T,30T(#`R-#`S-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\9&EV(&ED/2)M96YU(CX*(#QS<&%N(&-L87-S/2)L
M969T1FQO870B/@H\/W!H<`HD;65N=2`]("9N97<@365N=2@I.PHD;65N=2T^
M861D*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G<V5R=FEC97,O<&]R=&%L+R<I
M+"!?*")(;U]M92(I+"`G:&]R9&4N<&YG)RD["F9O<F5A8V@@*"1R96=I<W1R
M>2T^;&ES=$%P<',H*2!A<R`D87!P*2!["B`@("!I9B`H)')E9VES=')Y+3YH
M87--971H;V0H)V%D;6EN7VQI<W0G+"`D87!P*2D@>PH@("`@("`@("1L:7-T
M(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"1A<'`L("=A9&UI;E]L:7-T
M)RD["B`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D;&ES="!A<R`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H)&%P<"`A
M/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("1R96=I<W1R
M>2T^9V5T*"=N86UE)RP@)&%P<"D["B`@("`@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1V86QS6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&YA
M;64@+CT@)R`G("X@)'9A;'-;)VYA;64G73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N86UE(#T@
M)'9A;'-;)VYA;64G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6UG
M(#T@:7-S970H)'9A;'-;)VEC;VXG72D@/R`D<F5G:7-T<GDM/F=E=$EM86=E
M1&ER*"1A<'`I("X@)R\G("X@)'9A;'-;)VEC;VXG72`Z("1R96=I<W1R>2T^
M9V5T*"=I8V]N)RP@)&%P<"D["B`@("`@("`@("`@("1M96YU+3YA9&0H2&]R
M9&4Z.G5R;"@D<F5G:7-T<GDM/F%P<&QI8V%T:6]N5V5B4&%T:"@D=F%L<ULG
M;&EN:R==+"`D87!P*2DL("1N86UE+"`D:6UG+"`G)RD["B`@("`@("`@?0H@
M("`@?0I]"F5C:&\@)&UE;G4M/G)E;F1E<B@I.PH_/@H@/"]S<&%N/@H\+V1I
M=CX*````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8P``````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M-C`W(#$P-3$U-#,T,30T(#`R,S4V-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\9F]R;2!N86UE/2)E9&ET7V=R;W5P(B!M
M971H;V0](G!O<W0B(&%C=&EO;CTB9W)O=7!S+G!H<"(^"CQI;G!U="!T>7!E
M/2)H:61D96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB961I=&9O<FTB("\^
M"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F-I9"(@=F%L=64](CP_<&AP
M(&5C:&\@)&=R;W5P+3YG971)9"@I(#\^(B`O/@H\/W!H<"!5=&EL.CIP9F]R
M;4EN<'5T*"D@/SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@
M2&]R9&4Z.FEM9R@G=7-E<BYP;F<G*2`N("<@)R`N(&AT;6QS<&5C:6%L8VAA
M<G,H)&=R;W5P+3YG9713:&]R=$YA;64H*2D@/SX*/"]H,3X*"CQL86)E;"!F
M;W(](F5M86EL(CX\/W!H<"!E8VAO(%\H(D5M86EL($%D9')E<W,B*2`_/CPO
M;&%B96P^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)E;6%I;"(@:60](F5M
M86EL(B!S:7IE/2(U,"(@=F%L=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC
M:&%R<R@D9W)O=7`M/F=E="@G96UA:6PG*2D@/SXB("\^"CQB<B`O/@H\8G(@
M+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM
M9R@G9W)O=7`N<&YG)RD@+B`G("<@+B!?*")-96UB97)S(BD@/SX*/"]H,3X*
M"CQT86)L92!C;&%S<STB;&EN9612;W<@;F]W<F%P(B!C96QL<W!A8VEN9STB
M,"(@=VED=&@](C$P,"4B/@H@/'1R(&-L87-S/2)C;VYT<F]L(CX*("`\=&@@
M=VED=&@](C$P)2(@8VQA<W,](FQE9G1!;&EG;B(^/#]P:'`@96-H;R!?*")5
M<V5R(BD@/SX\+W1H/@H@(#QT:"!W:61T:#TB.3`E(B!C;&%S<STB;&5F=$%L
M:6=N(CX\/W!H<"!E8VAO(%\H(E)E;6]V92(I(#\^/"]T:#X*(#PO='(^"CP_
M<&AP(&9O<F5A8V@@*"1U<V5R<R!A<R`D=7-E<BDZ(#\^"B`\='(^"B`@/'1D
M/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@/SX\+W1D/@H@
M(#QT9#X\:6YP=70@='EP93TB8VAE8VMB;W@B(&YA;64](G)E;6]V95L\/W!H
M<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5S97(I(#\^72(@+SX\+W1D/@H@
M/"]T<CX*/#]P:'`@96YD9F]R96%C:#L@/SX*/"]T86)L93X*/&)R("\^"@H\
M/W!H<"!I9B`H8V]U;G0H)&EN:&5R:71E9%]U<V5R<RDI.B`_/@H\:#$@8VQA
M<W,](FAE861E<B(^"B`\/W!H<"!E8VAO($AO<F1E.CII;6<H)V=R;W5P+G!N
M9R<I("X@)R`G("X@7R@B26YH97)I=&5D($UE;6)E<G,B*2`_/@H\+V@Q/@H\
M=6P^"CP_<&AP(&9O<F5A8V@@*"1I;FAE<FET961?=7-E<G,@87,@)'5S97(I
M.B`_/@H@/&QI/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D=7-E<BD@
M/SX\+VQI/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W5L/@H\8G(@+SX*/#]P
M:'`@96YD:68[(#\^"@H\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO
M($AO<F1E.CII;6<H)W5S97(N<&YG)RD@+B`G("<@+B!?*")!9&0@365M8F5R
M<R(I(#\^"CPO:#$^"CP_<&AP(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G
M;&ES="<I*3H@/SX*/'-E;&5C="!N86UE/2)N97=?=7-E<EM=(B!M=6QT:7!L
M93TB;75L=&EP;&4B/@H\/W!H<"!F;W)E86-H("@D=7-E<E]L:7-T(&%S("1U
M<V5R*2![(&EF("@A:6Y?87)R87DH)'5S97(L("1A;&Q?=7-E<G,I*2![(#\^
M"B`\;W!T:6]N('9A;'5E/2(\/W!H<"!E8VAO("1U<V5R(#\^(CX\/W!H<"!E
M8VAO("1U<V5R(#\^/"]O<'1I;VX^"CP_<&AP('T@?2`_/@H\+W-E;&5C=#X*
M/#]P:'`@96QS93H@/SX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](FYE=U]U
M<V5R(B`O/@H\/W!H<"!E;F1I9CL@/SX*/&EN<'5T('1Y<&4](G-U8FUI="(@
M8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP('!R:6YT9BAH=&UL<W!E8VEA
M;&-H87)S*%\H(E-A=F4@7"(E<UPB(BDL($5.5%]#3TU0050L($Y,4SHZ9V5T
M0VAA<G-E="@I*2P@)&=R;W5P+3YG9713:&]R=$YA;64H*2D@/SXB("\^"CQB
M<B`O/@H\8G(@+SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]A9&UI;B]G<F]U<',O
M861D8VAI;&0N:6YC````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#<Q,R`Q
M,#4Q-30S-#$T-"`P,C0S-S$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/&9O<FT@;F%M93TB861D7V-H:6QD(B!M971H;V0]
M(G!O<W0B(&%C=&EO;CTB9W)O=7!S+G!H<"(^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F%C=&EO;DE$(B!V86QU93TB861D8VAI;&1F;W)M(B`O/@H\
M:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)C:60B('9A;'5E/2(\/W!H<"!E
M8VAO("1C:60@/SXB("\^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H*
M/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=G
M<F]U<"YP;F<G*2`_/B9N8G-P.SP_<&AP('!R:6YT9BA?*")!9&0@82!C:&EL
M9"!G<F]U<"!T;R!<(B5S7"(B*2P@)&=N86UE*2`_/@H\+V@Q/@H*/&EN<'5T
M('1Y<&4](G1E>'0B(&YA;64](F-H:6QD(B`O/@H\:6YP=70@='EP93TB<W5B
M;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")!9&0B
M*2`_/B(@+SX*/"]F;W)M/@H\8G(@+SX*````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,`
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q,#<@,3`U,34T,S0Q-#0@
M,#(T,#<U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#QF;W)M(&YA;64](F1E;&5T92(@;65T:&]D/2)P;W-T(B!A8W1I;VX]
M(F=R;W5P<RYP:'`B/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I
M;VY)1"(@=F%L=64](F1E;&5T969O<FTB("\^"CQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](F-I9"(@=F%L=64](CP_<&AP(&5C:&\@)&=R;W5P+3YG971)
M9"@I(#\^(B`O/@H\/W!H<"!5=&EL.CIP9F]R;4EN<'5T*"D@/SX*"CQH,2!C
M;&%S<STB:&5A9&5R(CX*(#P_<&AP(&5C:&\@2&]R9&4Z.FEM9R@G9W)O=7`N
M<&YG)RD@/SXF;F)S<#L\/W!H<"!P<FEN=&8H7R@B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(I
M+"`D9W)O=7`M/F=E=%-H;W)T3F%M92@I*2`_/@H\+V@Q/@H*/&EN<'5T('1Y
M<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB8V]N9FER;2(@=F%L
M=64](CP_<&AP(&5C:&\@7R@B1&5L971E(BD@/SXB("\^"CQI;G!U="!T>7!E
M/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](F-O;F9I<FTB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"(I(#\^(B`O/@H\+V9O<FT^"CQB<B`O
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;```````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P-C,@,3`U,34T
M,S0Q-#0@,#(S-S8P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QT86<Z;F]T:69Y("\^"@H\=&%B;&4@8VQA<W,](G-T<FEP
M960B(&-E;&QS<&%C:6YG/2(P(B!W:61T:#TB,3`P)2(^"B`@/'1R/@H@("`@
M/'1D(&-L87-S/2)H96%D97(B/@H@("`@("`\9V5T=&5X=#Y!<'!L:6-A=&EO
M;CPO9V5T=&5X=#X*("`@(#PO=&0^"B`@("`\=&0@8VQA<W,](FAE861E<B(^
M"B`@("`@("9N8G-P.PH@("`@/"]T9#X*("`@(#QT9"!C;&%S<STB:&5A9&5R
M(CX*("`@("`@/&=E='1E>'0^4W1A='5S/"]G971T97AT/@H@("`@/"]T9#X*
M("`\+W1R/@H@(#QL;V]P.F%P<',^"B`@/'1R/@H@("`@/'1D/@H@("`@("`\
M=&%G.F%P<',N;F%M92`O/@H@("`@("`\=&%G.F%P<',N=F5R<VEO;B`O/@H@
M("`@/"]T9#X*("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@/'1A9SIA
M<'!S+F-O;F8@+SX*("`@(#PO=&0^"B`@("`\=&0^"B`@("`@(#QT86<Z87!P
M<RYS=&%T=7,@+SX*("`@(#PO=&0^"B`@/"]T<CX*("`\+VQO;W`Z87!P<SX*
M/"]T86)L93X*/&)R("\^"@H\=&%B;&4@:60](G5P9&%T92(@8V5L;'-P86-I
M;F<](C`B('=I9'1H/2(Q,#`E(CX*("`\='(@=F%L:6=N/2)T;W`B/@H@("`@
M/'1D('=I9'1H/2(U,"4B/@H@("`@("`\:68Z86-T:6]N<SX*("`@("`@/&@Q
M(&-L87-S/2)H96%D97(B/@H@("`@("`@/&=E='1E>'0^4V5T=7`@=7!G<F%D
M92!S8W)I<'1S(&%V86EL86)L93PO9V5T=&5X=#X*("`@("`@/"]H,3X*("`@
M("`@/'1A8FQE(&-L87-S/2)S=')I<&5D(B!C96QL<W!A8VEN9STB,"(@=VED
M=&@](C$P,"4B/@H@("`@("`@/&QO;W`Z86-T:6]N<SX*("`@("`@("`\='(^
M"B`@("`@("`@(#QT9#X*("`@("`@("`@(#QT86<Z86-T:6]N<RYI8V]N("\^
M(#QT86<Z86-T:6]N<RYL:6YK("\^"B`@("`@("`@(#PO=&0^"B`@("`@("`@
M/"]T<CX*("`@("`@(#PO;&]O<#IA8W1I;VYS/@H@("`@("`\+W1A8FQE/@H@
M("`@("`\+VEF.F%C=&EO;G,^"B`@("`\+W1D/@H@("`@/'1D('=I9'1H/2(U
M,"4B/@H@("`@("`\:68Z9G1P9F]R;3X*("`@("`@("`\=&%G.F9T<&9O<FT@
M+SX*("`@("`@/"]I9CIF='!F;W)M/@H@("`@/"]T9#X*("`\+W1R/@H\+W1A
M8FQE/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;```````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#,S,B`Q,#4Q-30S-#$T-"`P,C0Q,3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/'1A9SIN;W1I9GD@
M+SX*"CQT86<Z9F]R;2`O/@H*/&EF.G!H<#X*/&)R("\^"CQH,2!C;&%S<STB
M:&5A9&5R(CX*(#QG971T97AT/D=E;F5R871E9"!#;V1E/"]G971T97AT/@H@
M/'-M86QL/EL@/'1A9SID:69F7W!O<'5P("\^(%T\+W-M86QL/@H\+V@Q/@H\
M=&5X=&%R96$@<W1Y;&4](G=I9'1H.C$P,"4B(')O=W,](C(P(CX\=&%G.G!H
M<"`O/CPO=&5X=&%R96$^"CPO:68Z<&AP/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`U,3<@,3`U,34T,S0Q-#0@,#(S-38S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#QI9CID:69F<SX*/&QO;W`Z9&EF9G,^
M"CQH,2!C;&%S<STB:&5A9&5R(B!I9#TB/'1A9SID:69F<RYA<'`@+SXB/@H@
M/'1A9SID:69F<RYA<'`@+SX@/'-M86QL/EL@/'1A9SID:69F<RYT;V=G;&5?
M<F5N9&5R97(@+SX@73PO<VUA;&P^"CPO:#$^"CQP<F4@8VQA<W,](G1E>'0B
M/CQT86<Z9&EF9G,N9&EF9B`O/CPO<')E/@H\+VQO;W`Z9&EF9G,^"CQE;'-E
M.F1I9F9S/@H\<"!C;&%S<STB;F]T:6-E(CX\9V5T=&5X=#Y.;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+CPO9V5T=&5X=#X\+W`^"CPO96QS93ID:69F<SX*/"]I9CID:69F<SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O861D+FEN
M8P``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<T(#$P-3$U
M-#,T,30T(#`R,S`R-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HD<F5N9&5R97(@/2`F;F5W($AO<F1E7T9O<FU?
M4F5N9&5R97(H*3L*)&%D9$9O<FTM/G)E;F1E<D%C=&EV92@D<F5N9&5R97(L
M("1V87)S+"!(;W)D93HZ<V5L9E5R;"@I+"`G<&]S="<I.PH_/@H\8G(@+SX*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4W-2`Q,#4Q-30S-#$T-"`P,C,W
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")096YD:6YG(%-I
M9VYU<',Z(BD@/SX*/"]H,3X*"CP_<&AP("1A;&Q1=65U960@/2`D<VEG;G5P
M+3YG9711=65U9613:6=N=7!S*"D[(&EF("@A8V]U;G0H)&%L;%%U975E9"DI
M.B`_/@H\9&EV(&-L87-S/2)T97AT(CX\96T^/#]P:'`@96-H;R!?*").;R!P
M96YD:6YG('-I9VYU<',N(BD@/SX\+V5M/CPO9&EV/@H\/W!H<"!E;'-E.B`_
M/@H\=&%B;&4@8VQA<W,](G-T<FEP960B('=I9'1H/2(Q,#`E(B!C96QL<W!A
M8VEN9STB,"(^"B`\='(@8VQA<W,](FET96TB/@H@(#QT:#XF;F)S<#L\+W1H
M/@H@(#QT:#XF;F)S<#L\+W1H/@H@(#QT:#X\/W!H<"!E8VAO(%\H(E5S97)N
M86UE(BD@/SX\+W1H/@H@(#QT:"!W:61T:#TB,3`P)2(^/#]P:'`@96-H;R!?
M*")$871E(%)E8V5I=F5D(BD@/SX\+W1H/@H@/"]T<CX*/#]P:'`@9F]R96%C
M:"`H)&%L;%%U975E9"!A<R`D<VEG;G5P*3H@:68@*"1S:6=N=7`M/F=E=$YA
M;64H*2`A/2!$051!5%)%15]23T]4*3H@)&1A=&$@/2`D<VEG;G5P+3YG971$
M871A*"D[(#\^"B`\='(^"B`@/'1D/@H@("`\9F]R;2!M971H;V0](G!O<W0B
M(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*("`@
M(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@=F%L=64]
M(CP_<&AP(&5C:&\@)'-I9VYU<"T^9V5T3F%M92@I(#\^(B`O/@H@("`@/&EN
M<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L=64](F%P<')O=F5?
M9B(@+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB
M('9A;'5E/2(\/W!H<"!E8VAO(%\H(D%P<')O=F4B*2`_/B(@+SX*("`@/"]F
M;W)M/@H@(#PO=&0^"B`@/'1D/@H@("`\9F]R;2!M971H;V0](G!O<W0B(&%C
M=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L9E5R;"@I(#\^(CX*("`@(#QI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@=F%L=64](CP_
M<&AP(&5C:&\@)'-I9VYU<"T^9V5T3F%M92@I(#\^(B`O/@H@("`@/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB9F]R;2(@=F%L=64](G)E;6]V97%U975E
M9%]F(B`O/@H@("`@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O
M;B(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5M;W9E(BD@/SXB("\^"B`@(#PO
M9F]R;3X*("`\+W1D/@H@(#QT9#X\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)'-I9VYU<"T^9V5T3F%M92@I*2`_/CPO=&0^"B`@/'1D/CP_<&AP(&5C
M:&\@9&%T92@G62U-+60@2#II.G,G+"`D9&%T85LG9&%T95)E8V5I=F5D)UTI
M(#\^/"]T9#X*(#PO='(^"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!E;F1F;W)E
M86-H.R`_/@H\+W1A8FQE/@H\/W!H<"!E;F1I9CL@/SX*/&)R(&-L87-S/2)S
M<&%C97(B("\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,#(R(#$P-3$U-#,T,30T(#`R,S,U-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\9F]R;2!N86UE/2)C;&5A<G5S97(B
M(&UE=&AO9#TB<&]S="(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O
M<FTB('9A;'5E/2)C;&5A<B(@+SX*"CQH,2!C;&%S<STB:&5A9&5R(CX*(#P_
M<&AP('!R:6YT9BA?*")#;&5A<B!O=70@=7-E<CH@)7,B*2P@)&9?=7-E<E]N
M86UE*2`_/@H\+V@Q/@H\<"!C;&%S<STB:71E;2(^"B`\<W1R;VYG/CP_<&AP
M('!R:6YT9BA?*")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E
M<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB*2P@)&9?=7-E
M<E]N86UE*2`_/CPO<W1R;VYG/@H\+W`^"CQP(&-L87-S/2)C;VYT<F]L(CX*
M(#QI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB(&YA;64](G-U
M8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B0VQE87(@=7-E<B(I(#\^(B`O
M/@H@/&EN<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@;F%M93TB
M<W5B;6ET(B!V86QU93TB/#]P:'`@96-H;R!?*")#86YC96PB*2`_/B(@+SX*
M/"]P/@H\+V9O<FT^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8P``````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`T-#0P(#$P-3$U-#,T,30T(#`R,S4U-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"CPA+2T*"F9U;F-T:6]N('9A;&ED871E7W5P9&%T
M92@I"GL*("`@(&EF("AD;V-U;65N="YU<&1A=&5U<V5R+G5S97)?;F%M92YV
M86QU92`]/2`B(BD@>PH@("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E
M<E]N86UE+F9O8W5S*"D["B`@("`@("`@86QE<G0H)SP_<&AP(&5C:&\@861D
M<VQA<VAE<RA?*")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(BDI(#\^)RD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?2!E;'-E
M(&EF("AD;V-U;65N="YU<&1A=&5U<V5R+G5S97)?<&%S<U\Q("8F"B`@("`@
M("`@("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N=F%L
M=64@(3T@9&]C=6UE;G0N=7!D871E=7-E<BYU<V5R7W!A<W-?,BYV86QU92D@
M>PH@("`@("`@(&1O8W5M96YT+G5P9&%T975S97(N=7-E<E]P87-S7S$N=F%L
M=64@/2`B(CL*("`@("`@("!D;V-U;65N="YU<&1A=&5U<V5R+G5S97)?<&%S
M<U\R+G9A;'5E(#T@(B(["B`@("`@("`@9&]C=6UE;G0N=7!D871E=7-E<BYU
M<V5R7W!A<W-?,2YF;V-U<R@I.PH@("`@("`@(&%L97)T*"<\/W!H<"!E8VAO
M(&%D9'-L87-H97,H7R@B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(BDI(#\^)RD[
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@(')E='5R;B!T<G5E
M.PI]"@HO+RTM/@H\+W-C<FEP=#X*"CQF;W)M(&YA;64](G5P9&%T975S97(B
M(&UE=&AO9#TB<&]S="(^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](F9O
M<FTB('9A;'5E/2)U<&1A=&4B/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2)U<V5R7VYA;64B('9A;'5E/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA
M<G,H)&9?=7-E<E]N86UE*2`_/B(@+SX*/&@Q(&-L87-S/2)H96%D97(B/@H@
M/#]P:'`@<')I;G1F*%\H(E5P9&%T92`E<R(I+"`D9E]U<V5R7VYA;64I(#\^
M"CPO:#$^"CQT86)L92!C;&%S<STB<W1R:7!E9"!N;W=R87`B(&-E;&QS<&%C
M:6YG/2(P(B!W:61T:#TB,3`P)2(^"CP_<&AP(&EF("@D875T:"T^:&%S0V%P
M86)I;&ET>2@G=7!D871E)RDI.B`_/@H@/'1R/@H@(#QT9"!W:61T:#TB,24B
M(&-L87-S/2)L:6=H="!R:6=H=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?*").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(I(#\^"B`@/"]T9#X*("`\=&0^"B`@
M(#QI;G!U="!T>7!E/2)T97AT(B!N86UE/2)U<V5R7VYA;64R(B!V86QU93TB
M/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1F7W5S97)?;F%M92D@/SXB
M("\^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L
M:6=N(CX*("`@/#]P:'`@96-H;R!?*")087-S=V]R9"(I(#\^"B`@/"]T9#X*
M("`\=&0^"B`@(#QI;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB=7-E<E]P
M87-S7S$B("\^"B`@/"]T9#X*(#PO='(^"B`\='(^"B`@/'1D(&-L87-S/2)R
M:6=H=$%L:6=N(CX*("`@/#]P:'`@96-H;R!?*")#;VYF:7)M(%!A<W-W;W)D
M(BD@/SX*("`\+W1D/@H@(#QT9#X*("`@/&EN<'5T('1Y<&4](G!A<W-W;W)D
M(B!N86UE/2)U<V5R7W!A<W-?,B(@+SX*("`\+W1D/@H@/"]T<CX*/#]P:'`@
M96YD:68[(#\^"B`\='(^"B`@/'1D(&-L87-S/2)R:6=H=$%L:6=N(CX*("`@
M/#]P:'`@96-H;R!?*")&=6QL($YA;64B*2`_/@H@(#PO=&0^"B`@/'1D/@H@
M("`\:6YP=70@='EP93TB=&5X="(@;F%M93TB=7-E<E]F=6QL;F%M92(@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D:61E;G1I='DM/F=E
M=%9A;'5E*"=F=6QL;F%M92<I*2`_/B(@+SX*("`\+W1D/@H@/"]T<CX*(#QT
M<CX*("`\=&0@8VQA<W,](G)I9VAT06QI9VXB/@H@("`\/W!H<"!E8VAO(%\H
M(D5M86EL($%D9')E<W,B*2`_/@H@(#PO=&0^"B`@/'1D/@H@("`\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB=7-E<E]E;6%I;"(@('9A;'5E/2(\/W!H<"!E
M8VAO(&AT;6QS<&5C:6%L8VAA<G,H)&ED96YT:71Y+3YG971686QU92@G9G)O
M;5]A9&1R)RDI(#\^(B`O/@H@(#PO=&0^"B`\+W1R/@H@/'1R/@H@(#QT9"!C
M;&%S<STB8V]N=')O;"!L969T06QI9VXB(&-O;'-P86X](C(B/@H@("`\:6YP
M=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)S=6)M:70B
M(&]N8VQI8VL](G)E='5R;B!V86QI9&%T95]U<&1A=&4H*3LB('9A;'5E/2(\
M/W!H<"!E8VAO(%\H(E5P9&%T92!U<V5R(BD@/SXB("\^"B`@(#QI;G!U="!T
M>7!E/2)R97-E="(@8VQA<W,](F)U='1O;B(@;F%M93TB<F5S970B('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(E)E<V5T(BD@/SXB("\^"B`@/"]T9#X*(#PO='(^
M"CPO=&%B;&4^"CPO9F]R;3X*/&)R("\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8P``````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#`Q(#$P-3$U-#,T,30T(#`R-#<W,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\9F]R
M;2!M971H;V0](G!O<W0B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L
M9E5R;"@I(#\^(CX*/#]P:'`@571I;#HZ<&9O<FU);G!U="@I(#\^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F9O<FTB('9A;'5E/2)R96UO=F5Q=65U
M960B("\^"CQI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5S97)?;F%M92(@
M=F%L=64](CP_<&AP(&5C:&\@)&9?=7-E<E]N86UE(#\^(B`O/@H*/&@Q(&-L
M87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")096YD:6YG(%-I9VYU<',Z
M(BD@/SX*/"]H,3X*/'`@8VQA<W,](FET96TB/@H@/#]P:'`@<')I;G1F*%\H
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_(BDL("1F7W5S97)?;F%M92D@/SX*/"]P/@H\<"!C
M;&%S<STB8V]N=')O;"(^"B`@/&EN<'5T(&-L87-S/2)B=71T;VXB('1Y<&4]
M(G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@7R@B4F5M;W9E(BD@/SXB("\^
M"CPO<#X*/"]F;W)M/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8P``````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S<W(#$P-3$U-#,T,30T(#`R
M,S8P,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\9F]R;2!N86UE/2)R96UO=F5U<V5R(B!M971H;V0](G!O<W0B/@H\:6YP
M=70@='EP93TB:&ED9&5N(B!N86UE/2)F;W)M(B!V86QU93TB<F5M;W9E(B`O
M/@H*/&@Q(&-L87-S/2)H96%D97(B/@H@/#]P:'`@<')I;G1F*%\H(E)E;6]V
M92!U<V5R.B`E<R(I+"`D9E]U<V5R7VYA;64I(#\^"CPO:#$^"CQP(&-L87-S
M/2)I=&5M(CX*(#QS=')O;F<^/#]P:'`@<')I;G1F*%\H(E)E86QL>2!D96QE
M=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(BDL("1F
M7W5S97)?;F%M92D@/SX\+W-T<F]N9SX*/"]P/@H\<"!C;&%S<STB8V]N=')O
M;"(^"B`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE
M/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(E)E;6]V92!U<V5R(BD@
M/SXB("\^"B`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!N
M86UE/2)S=6)M:70B('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-A;F-E;"(I(#\^
M(B`O/@H\+W`^"CPO9F]R;3X*`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8P``````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#0R-R`Q,#4Q-30S-#$T-"`P,C,S-C,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/&@Q(&-L87-S
M/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(BD@/SX*/"]H,3X*/'`@8VQA<W,](F-O;G1R;VPB/@H@/#]P:'`@
M96-H;R!?*")9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+B(I(#\^"CPO<#X*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`S-3(@,3`U,34T,S0Q-#0@,#(S-C`S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#QH,2!C;&%S<STB:&5A9&5R(CX*
M(#P_<&AP(&5C:&\@7R@B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB*2`_
M/@H\+V@Q/@H\<"!C;&%S<STB8V]N=')O;"(^"B`\/W!H<"!E8VAO(%\H(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI
M<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB*2`_/@H\+W`^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,`````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S`P(#$P
M-3$U-#,T,30T(#`R,S(T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\:#$@8VQA<W,](FAE861E<B(^"B`\/W!H<"!E8VAO
M(%\H(E5S97)S(&EN('1H92!S>7-T96TZ(BD@/SX*(#P_<&AP(&EF("@D;G5M
M:71E;2DZ(#\^"B`@/'-M86QL/EL\/W!H<"!P<FEN=&8H7R@B)7,@=&\@)7,@
M;V8@)7,B*2P@)'-T87)T+"`D96YD+"`D;G5M:71E;2D@/SY=/"]S;6%L;#X*
M(#P_<&AP(&5N9&EF.R`_/@H\+V@Q/@H*/&1I=B!C;&%S<STB:&5A9&5R8F]X
M(CX*"CQD:78@8VQA<W,](F-O;G1R;VPB/@H@/&9O<FT@;65T:&]D/2)P;W-T
M(B!N86UE/2)S96%R8V@B(&%C=&EO;CTB/#]P:'`@96-H;R!(;W)D93HZ<V5L
M9E5R;"@I(#\^(CX*(#P_<&AP(&5C:&\@571I;#HZ9F]R;4EN<'5T*"D@/SX*
M(#QI;G!U="!T>7!E/2)H:61D96XB(&YA;64](G!A9V4B('9A;'5E/2(P(CX*
M(#QS=')O;F<^/#]P:'`@96-H;R!?*")396%R8V@B*2`_/CH\+W-T<F]N9SXF
M;F)S<#L*(#QI;G!U="!N86UE/2)S96%R8VA?<&%T=&5R;B(@='EP93TB=&5X
M="(@=F%L=64](B(@<VEZ93TB-3`B(&UA>&QE;F=T:#TB,3`P(B`O/@H@/&EN
M<'5T('1Y<&4](G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](CP_<&AP
M(&5C:&\@7R@B4V5A<F-H(BD@/SXB("\^"B`\+V9O<FT^"CPO9&EV/@H*/'1A
M8FQE(&-L87-S/2)S=')I<&5D(B!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<]
M(C`B/@H\/W!H<`HD<F5M;W9E(#T@)&%U=&@M/FAA<T-A<&%B:6QI='DH)W)E
M;6]V92<I.PHD=&]T86P@/2`P.PIF;W)E86-H("@D=7-E<G,@87,@)'5S97(I
M.@H@("`@:68@*"1T;W1A;"LK(#P@)&UI;B!\?"`D=&]T86P@/B`D;6%X*2![
M"B`@("`@("`@8V]N=&EN=64["B`@("!]"C\^"B`\='(^"CP_<&AP(&EF("@D
M<F5M;W9E*3H@/SX*("`\=&0@=VED=&@](C$E(CX\/W!H<"!E8VAO($AO<F1E
M.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO=7-E<BYP:'`_
M9F]R;3UR96UO=F5?9B9U<V5R7VYA;64])R`N("1U<V5R*2P@7R@B1&5L971E
M(BDI("X@2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L(%\H(D1E;&5T92(I*2`_
M/CPO83X\+W1D/@H\/W!H<"!E;F1I9CL@/SX*("`\=&0@=VED=&@](C$E(CX\
M/W!H<"!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G
M861M:6XO=7-E<BYP:'`_9F]R;3UU<&1A=&5?9B9U<V5R7VYA;64])R`N("1U
M<V5R*2P@7R@B57!D871E(BDI("X@($AO<F1E.CII;6<H)V5D:70N<&YG)RP@
M7R@B57!D871E(BDI(#\^/"]A/CPO=&0^"B`@/'1D('=I9'1H/2(Q)2(^/#]P
M:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D
M;6EN+W5S97(N<&AP/V9O<FT]8VQE87)?9B9U<V5R7VYA;64])R`N("1U<V5R
M*2P@7R@B0VQE87(@=7-E<B!D871A(BDI("X@($AO<F1E.CII;6<H)W)E;&]A
M9"YP;F<G+"!?*")#;&5A<B!U<V5R(&1A=&$B*2D@/SX\+V$^/"]T9#X*("`\
M=&0@8VQA<W,](FQE9G1!;&EG;B(^/#]P:'`@96-H;R`D=7-E<B`_/CPO=&0^
M"B`\+W1R/@H\/W!H<"!E;F1F;W)E86-H.R`_/@H\+W1A8FQE/@H\/W!H<`II
M9B`H)&YU;6ET96TI('L*("`@("1P86=E<B`]("9N97<@2&]R9&5?54E?4&%G
M97(H)W!A9V4G+"`D=F%R<RP@87)R87DH)VYU;2<@/3X@)'1O=&%L+"`G=7)L
M)R`]/B`D=FEE=W5R;"P@)W!A9V5?8V]U;G0G(#T^(#$P+"`G<&5R<&%G92<@
M/3X@)'!E<G!A9V4I*3L*("`@(&5C:&\@)'!A9V5R+3YR96YD97(H)'!A9V4L
M("1T;W1A;"P@)'9I97=U<FPI.PI]"C\^"CPO9&EV/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#`Q-B`Q,#4Q-30S
M-#$T-"`P,C4Q-C4`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&1I=B!I9#TB;65N=2(^/&@Q/B9N8G-P.SQT86<Z:&5A9&5R
M("\^/"]H,3X\+V1I=CX*"CQF;W)M(&UE=&AO9#TB<&]S="(@86-T:6]N/2(\
M=&%G.FUA:6YT7W5R;"`O/B(@;F%M93TB;6%I;G1?8V]N9FER;2(^"CQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](FQO861?9G)A;65S970B('9A;'5E/2(B
M("\^"CQT86<Z;6%I;G1?<&]S=&1A=&$@+SX*"CQI9CIJ879A<V-R:7!T/@H\
M<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@
M=6YC:&5C:T%L;"@I"GL*("`@(&9O<B`H=F%R(&D@/2`P.R!I(#P@9&]C=6UE
M;G0N;6%I;G1?8V]N9FER;2YE;&5M96YT<RYL96YG=&@[(&DK*RD@>PH@("`@
M("`@(&1O8W5M96YT+FUA:6YT7V-O;F9I<FTN96QE;65N='-;:5TN8VAE8VME
M9"`](&9A;'-E.PH@("`@?0I]"B\O+2T^"CPO<V-R:7!T/@H\+VEF.FIA=F%S
M8W)I<'0^"@H\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(R(CX*
M(#QT<CX*("`\=&0^/'1A9SIN;W1I9GD@+SX\+W1D/@H@/"]T<CX*"CQL;V]P
M.G1A<VMS/@H@/'1R/@H@(#QT9"!C;&%S<STB;&EG:'0B/@H\:68Z8V]N9FER
M;3X*("`@/&EN<'5T('1Y<&4](F-H96-K8F]X(B!N86UE/2(\=&%G.G1A<VMS
M+G!R968@+SY?8V]N9FER;2(\=&%G.G1A<VMS+F-H96-K960@+SX^)FYB<W`[
M)FYB<W`["CPO:68Z8V]N9FER;3X*/&EF.F%G<F5E/@H@("`\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2(\=&%G.G1A<VMS+G!R968@+SY?8V]N9FER;2(@
M=F%L=64](C$B("\^"CPO:68Z86=R964^"CQI9CIN;W1I8V4^"B`@(#QI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](CQT86<Z=&%S:W,N<')E9B`O/E]C;VYF
M:7)M(B!V86QU93TB,2(@+SX*/"]I9CIN;W1I8V4^"B`@(#QT86<Z=&%S:W,N
M9&5S8W)I<"`O/@H@(#PO=&0^"B`\+W1R/@H\+VQO;W`Z=&%S:W,^"@H@/'1R
M/@H@(#QT9#XF;F)S<#L\+W1D/@H@/"]T<CX*"B`\='(^"B`@/'1D/@H\:68Z
M8V]N9FER;3X*("`@/&EN<'5T(&YA;64](F]K(B!T>7!E/2)S=6)M:70B(&-L
M87-S/2)B=71T;VXB('9A;'5E/2(\9V5T=&5X=#Y097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,\+V=E='1E>'0^(B!O;F-L:6-K/2)D;V-U;65N="YM
M86EN=%]C;VYF:7)M+G-U8FUI="@I.R(@+SX*/&EF.FIA=F%S8W)I<'0^"B`@
M("9N8G-P.R9N8G-P.PH@("`\:6YP=70@='EP93TB8G5T=&]N(B!C;&%S<STB
M8G5T=&]N(B!V86QU93TB/&=E='1E>'0^4VMI<"!-86EN=&5N86YC93PO9V5T
M=&5X=#XB(&]N8VQI8VL](G5N8VAE8VM!;&PH*3L@9&]C=6UE;G0N;6%I;G1?
M8V]N9FER;2YS=6)M:70H*3LB("\^"CPO:68Z:F%V87-C<FEP=#X*/"]I9CIC
M;VYF:7)M/@H\:68Z86=R964^"B`@(#QI;G!U="!N86UE/2)O:R(@='EP93TB
M<W5B;6ET(B!N86UE/2)A9W)E92(@8VQA<W,](F)U='1O;B(@=F%L=64](CQG
M971T97AT/EEE<RP@22!!9W)E93PO9V5T=&5X=#XB(&]N8VQI8VL](F1O8W5M
M96YT+FUA:6YT7V-O;F9I<FTN<W5B;6ET*"D[(B`O/@H@("`\:6YP=70@='EP
M93TB<W5B;6ET(B!N86UE/2)N;W1?86=R964B(&-L87-S/2)B=71T;VXB('9A
M;'5E/2(\9V5T=&5X=#Y.3RP@22!$;R!.3U0@06=R964\+V=E='1E>'0^(B!O
M;F-L:6-K/2)D;V-U;65N="YM86EN=%]C;VYF:7)M+G-U8FUI="@I.R(@+SX*
M/"]I9CIA9W)E93X*/&EF.FYO=&EC93X*("`@/&EN<'5T(&YA;64](F]K(B!T
M>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\9V5T=&5X=#Y#
M;&EC:R!T;R!#;VYT:6YU93PO9V5T=&5X=#XB(&]N8VQI8VL](F1O8W5M96YT
M+FUA:6YT7V-O;F9I<FTN<W5B;6ET*"D[(B`O/@H\+VEF.FYO=&EC93X*("`\
M+W1D/@H@/"]T<CX*/"]T86)L93X*"CPO9F]R;3X*"CQS8W)I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(CX*/"$M+0ID;V-U;65N="YM86EN=%]C;VYF:7)M
M+F]K+F9O8W5S*"D["FEF("AT>7!E;V8@=VEN9&]W+G!A<F5N="YF<F%M97,N
M:&]R9&5?;65N=2`]/2`G=6YD969I;F5D)RD@9&]C=6UE;G0N;6%I;G1?8V]N
M9FER;2YL;V%D7V9R86UE<V5T+G9A;'5E(#T@,3L*+R\M+3X*/"]S8W)I<'0^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]T97-T+W9E
M<G-I;VXN:6YC````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#$V-"`Q,#4Q-30S-#$T-"`P,C(V-S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&@Q/CP_<&AP(&5C:&\@)&UO9'5L92`_
M/B!697)S:6]N/"]H,3X*/'5L/@H@("`@/&QI/CP_<&AP(&5C:&\@)&UO9'5L
M92`_/CH@/#]P:'`@96-H;R`D;6]D=6QE7W9E<G-I;VX@/SX\+VQI/@H\+W5L
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]P:'!?=F5R<VEO;BYI
M;F,`````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W-C(@,3`U,34T
M,S0Q-#0@,#(S-30V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#QH,3Y02%`@5F5R<VEO;CPO:#$^"CQU;#X*("`@(#QL:3X\
M82!H<F5F/2(\/W!H<"!E8VAO("1P:'!?:6YF;RT^<&AP:6YF;R`_/B(^5FEE
M=R!P:'!I;F9O*"D@<V-R965N/"]A/CPO;&D^"B`@("`\;&D^/&$@:')E9CTB
M/#]P:'`@96-H;R`D<&AP7VEN9F\M/F5X=&5N<VEO;G,@/SXB/E9I97<@;&]A
M9&5D(&5X=&5N<VEO;G,\+V$^/"]L:3X*("`@(#QL:3Y02%`@5F5R<VEO;CH@
M/#]P:'`@96-H;R`D<&AP7VEN9F\M/G9E<G-I;VX@/SX\+VQI/@H@("`@/&QI
M/E!(4"!-86IO<B!697)S:6]N.B`\/W!H<"!E8VAO("1P:'!?:6YF;RT^;6%J
M;W(@/SX\+VQI/@H\/W!H<"!I9B`H:7-S970H)'!H<%]I;F9O+3YM:6YO<BDI
M.B`_/@H@("`@/&QI/E!(4"!-:6YO<B!697)S:6]N.B`\/W!H<"!E8VAO("1P
M:'!?:6YF;RT^;6EN;W(@/SX\+VQI/@H\/W!H<"!E;F1I9CL@/SX*/#]P:'`@
M:68@*&ES<V5T*"1P:'!?:6YF;RT^<W5B;6EN;W(I*3H@/SX*("`@(#QL:3Y0
M2%`@4W5B;6EN;W(@5F5R<VEO;CH@/#]P:'`@96-H;R`D<&AP7VEN9F\M/G-U
M8FUI;F]R(#\^/"]L:3X*/#]P:'`@96YD:68[(#\^"B`@("`\;&D^4$A0(%9E
M<G-I;VX@0VQA<W-I9FEC871I;VXZ(#P_<&AP(&5C:&\@)'!H<%]I;F9O+3YC
M;&%S<R`_/CPO;&D^"B`@("`\;&D@<W1Y;&4](F-O;&]R.CP_<&AP(&5C:&\@
M)'!H<%]I;F9O+3YS=&%T=7-?8V]L;W(@/SXB/CQS=')O;F<^/#]P:'`@96-H
M;R`D<&AP7VEN9F\M/G-T871U<R`_/CPO<W1R;VYG/CPO;&D^"CP_<&AP(&EF
M("AI<W-E="@D<&AP7VEN9F\M/G9E<G-I;VY?8VAE8VLI*3H@/SX*("`@(#QL
M:3X\/W!H<"!E8VAO("1P:'!?:6YF;RT^=F5R<VEO;E]C:&5C:R`_/CPO;&D^
M"CP_<&AP(&5N9&EF.R`_/@H\/W!H<"!I9B`H:7-S970H)'!H<%]I;F9O+3YI
M;G-E8W5R92DI.B`_/@H@("`@/&QI('-T>6QE/2)C;VQO<CIO<F%N9V4B/CQS
M=')O;F<^/#]P:'`@96-H;R`D<&AP7VEN9F\M/FEN<V5C=7)E(#\^/'-T<F]N
M9SX\+VQI/@H\/W!H<"!E;F1I9CL@/SX*/"]U;#X*``````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O=&5S="]E>'1E;G-I
M;VYS+FEN8P``````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0R,S$@
M,3`U,34T,S0Q-#0@,#(S-#`S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#QH=&UL/@H\:&5A9#X*/'1I=&QE/E!(4"!%>'1E
M;G-I;VYS/"]T:71L93X*/'-T>6QE/@IB;V1Y('L@8F%C:V=R;W5N9"UC;VQO
M<CH@=VAI=&4[(&UA<F=I;BUT;W`Z(#`[(&UA<F=I;BUL969T.B`R,#L@;6%R
M9VEN+7)I9VAT.B`R,#L@?0IT86)L92![(&9O;G0M9F%M:6QY.B!!<FEA;"P@
M2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$R<'@[(&UA<F=I
M;BUT;W`Z(#`[(&UA<F=I;BUL969T.B`P.R!]"F$@>R!T97AT+61E8V]R871I
M;VXZ(&YO;F4[(&9O;G0M9F%M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS
M+7-E<FEF.R!F;VYT+7-I>F4Z(#$R<'@[(&UA<F=I;BUT;W`Z(#`[(&UA<F=I
M;BUL969T.B`P.R!]"F$Z86-T:79E('L@8V]L;W(Z(",R-#4W9F8[('T*83IH
M;W9E<B![(&-O;&]R.B`C,C0U-V9F.R!T97AT+61E8V]R871I;VXZ('5N9&5R
M;&EN93L@?0IA.FQI;FL@>R!C;VQO<CH@(S(T-3=F9CL@?0IA.G9I<VET960@
M>R!C;VQO<CH@(S(T-3=F9CL@?0HN8FQA8VL@>R!B86-K9W)O=6YD+6-O;&]R
M.B`C,#`P,#`P.R!C;VQO<CH@(V9F9F9F9CL@?0H\+W-T>6QE/@H\+VAE860^
M"CQB;V1Y/@H\82!H<F5F/2(\/W!H<"!E8VAO(&ES<V5T*"1?1T546R=U<FPG
M72D@/R!H=&UL<W!E8VEA;&-H87)S*"1?1T546R=U<FPG72D@.B`G=&5S="YP
M:'`G(#\^/VUO9&4]=&5S="(^)FQT.R9L=#L@0F%C:R!T;R!T97-T+G!H<#PO
M83X*/&)R("\^"CQT86)L92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C`B
M/CQT<CX\=&0@8V]L<W!A;CTB,B(^/'1A8FQE/@H\='(^/'1D/G!H<"!V97)S
M:6]N.CPO=&0^/'1D/CQS=')O;F<^/#]P:'`@96-H;R!P:'!V97)S:6]N*"D@
M/SX\+W-T<F]N9SX\+W1D/CPO='(^"CQT<CX\=&0^<V5R=F5R(&%P:3H\+W1D
M/CQT9#X\<W1R;VYG/CP_<&AP(&5C:&\@0'!H<%]S87!I7VYA;64H*2`_/CPO
M<W1R;VYG/CPO=&0^/"]T<CX*/'1R/CQT9#YL;V%D960@97AT96YS:6]N<SH\
M+W1D/CQT9#X\<W1R;VYG/CP_<&AP("1E>'1E;G-I;VYS(#T@0&=E=%]L;V%D
M961?97AT96YS:6]N<R@I.R!E8VAO(&-O=6YT*"1E>'1E;G-I;VYS*3L@/SX\
M+W-T<F]N9SX\+W1D/CPO='(^"CQT<CX\=&0^<WES=&5M.CPO=&0^/'1D/CQS
M=')O;F<^/#]P:'`@96-H;R!`<&AP7W5N86UE*"D@/SX\+W-T<F]N9SX\+W1D
M/CPO='(^"CPO=&%B;&4^/&)R("\^/"]T9#X\+W1R/@H\='(@8VQA<W,](F)L
M86-K(CX*/'1D/CQS=')O;F<^86-T:79A=&5D(&5X=&5N<VEO;G,Z/"]S=')O
M;F<^/"]T9#X*/'1D/CQS=')O;F<^/#]P:'`@96-H;R!I<W-E="@D7T=%5%LG
M97AT)UTI(#\@)%]'151;)V5X="==(#H@)R<@/SX@9G5N8W1I;VX@;&ES=#H\
M+W-T<F]N9SX\+W1D/@H\+W1R/@H\='(^/'1D('9A;&EG;CTB=&]P(B!W:61T
M:#TB-3`E(CX\=&%B;&4@=VED=&@](C$P,"4B/@H\/W!H<`H@("`@0'-O<G0H
M)&5X=&5N<VEO;G,I.PH@("`@9F]R96%C:"`H)&5X=&5N<VEO;G,@87,@)&5X
M=&5N<VEO;BD@>PH@("`@("`@(&5C:&\@)SQT<CX\=&0@=VED=&@](C,P)2(^
M)R`N("1E>'1E;G-I;VX@+B`G/"]T9#X\=&0^/&$@:')E9CTB/VUO9&4]97AT
M96YS:6]N<R9A;7`[97AT/2<@+B`D97AT96YS:6]N("X@)R9A;7`[=7)L/2<@
M+B!U<FQE;F-O9&4H:7-S970H)%]'151;)W5R;"==*2`_("1?1T546R=U<FPG
M72`Z("<G*2`N("<B/F9U;F-T:6]N(&QI<W0\+V$^/"]T9#X\+W1R/B<["B`@
M("!]"C\^"CPO=&%B;&4^/"]T9#X\=&0@=F%L:6=N/2)T;W`B('=I9'1H/2(U
M,"4B/CQT86)L93X*/#]P:'`*("`@(&EF("AI<W-E="@D7T=%5%LG97AT)UTI
M*2!["B`@("`@("`@)&9U;F-T:6]N<R`]($!G971?97AT96YS:6]N7V9U;F-S
M*"1?1T546R=E>'0G72D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1F=6YC=&EO
M;G,I*2!["B`@("`@("`@("`@('-O<G0H)&9U;F-T:6]N<RD["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1F=6YC=&EO;G,@87,@)&9U;F-T:6]N*2!["B`@("`@
M("`@("`@("`@("!E8VAO("(\='(^/'1D/CQA(&AR968]7")H='1P.B\O=W=W
M+G!H<"YN970O;6%N=6%L+V9U;F-T:6]N+B(@+B!S=')?<F5P;&%C92@G7R<L
M("<M)RP@)&9U;F-T:6]N*2`N("(N<&AP7"(@=&%R9V5T/5PB7V)L86YK7"(^
M)&9U;F-T:6]N/"]A/CPO=&0^/"]T<CY<;B(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"C\^"CPO=&%B;&4^/"]T9#X\+W1R/CPO=&%B;&4^/"]B
M;V1Y/CPO:'1M;#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O
M=&5S="]F;V]T97(N:6YC````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,C`@,3`U,34T,S0Q-#0@,#(R-#<R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#PO8F]D>3X*/"]H=&UL/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S+W1E<W0O:&5A9&5R
M+FEN8P``````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S8R
M(#$P-3$U-#,T,30T(#`R,C0T,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\(41/0U194$4@:'1M;"!054),24,@(BTO+U<S
M0R\O1%1$(%A(5$U,(#$N,"!4<F%N<VET:6]N86PO+T5.(B`B1%1$+WAH=&UL
M,2UT<F%N<VET:6]N86PN9'1D(CX*/&AT;6P^"CQH96%D/@H\=&ET;&4^/#]P
M:'`@96-H;R`D;6]D=6QE(#\^.B!3>7-T96T@0V%P86)I;&ET:65S(%1E<W0\
M+W1I=&QE/@H\<W1Y;&4@='EP93TB=&5X="]C<W,B/@H\(2TM"F)O9'D@>R!F
M;VYT+69A;6EL>3H@1V5N979A+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF
M.R!F;VYT+7-I>F4Z(#$P<'0[('T*=&0@>R!F;VYT+69A;6EL>3H@1V5N979A
M+$%R:6%L+$AE;'9E=&EC82QS86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$P<'0[
M('UH,2![(&9O;G0M<VEZ93H@,3)P=#L@8V]L;W(Z(&)L86-K.R!F;VYT+69A
M;6EL>3H@5F5R9&%N82Q'96YE=F$L07)I86PL2&5L=F5T:6-A+`IS86YS+7-E
M<FEF.R!]"BTM/@H\+W-T>6QE/@H\+VAE860^"@H\8F]D>2!B9V-O;&]R/2)W
M:&ET92(@=&5X=#TB8FQA8VLB/@H``````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W1E;7!L871E<R]M96YU+VUE;G4N:6YC````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$S,"`Q,#4Q-30S-#$T
M-"`P,C(Q,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/&1I=B!I9#TB;65N=2(^"B`\9&EV(&-L87-S/2)L969T1FQO870B
M/@H@(#P_<&AP(&5C:&\@)&UE;G4M/G)E;F1E<B@I(#\^"B`\+V1I=CX*/"]D
M:78^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]T96UP;&%T97,O:&5L<"]M96YU+FEN8P``````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`T,3`@,3`U,34T,S0Q-#0@,#(R,3$T`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#QD:78@
M8VQA<W,](FAE861E<B(^"B`\<W!A;B!C;&%S<STB;&5F=$9L;V%T(CX*("`\
M/W!H<"!E8VAO("1T;W!I8W-?;&EN:R`_/@H@/"]S<&%N/@H\/W!H<"!I9B`H
M)&-O;F9;)VUE;G4G75LG;&EN:W,G75LG:&5L<%]A8F]U="==*3H@/SX*(#QS
M<&%N(&-L87-S/2)R:6=H=$9L;V%T(CX*("`\/W!H<"!E8VAO("1A8F]U=%]L
M:6YK(#\^"B`\+W-P86X^"CP_<&AP(&5N9&EF.R`_/@H@/'-P86X@<W1Y;&4]
M(F-L96%R.F)O=&@B/B9N8G-P.SPO<W!A;CX*/"]D:78^"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O=&5M<&QA=&5S
M+VAE;'`O:6YD97@N:6YC````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P-S`T(#$P-3$U-#,T,30T(#`R,C(V-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\(41/0U194$4@:'1M;"!0
M54),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,"!&<F%M97-E="\O14XB(")$
M5$0O>&AT;6PQ+69R86UE<V5T+F1T9"(^"CQH=&UL/@H\:&5A9#X*(#QT:71L
M93X\/W!H<"!E8VAO(%\H(DAE;'`B*2`_/CPO=&ET;&4^"CPO:&5A9#X*"CQF
M<F%M97-E="!R;W=S/2(S,"PJ(B!F<F%M96)O<F1E<CTB;F\B(&)O<F1E<CTB
M,"(@9G)A;65S<&%C:6YG/2(P(CX*(#QF<F%M92!N86UE/2)H96QP7VUE;G4B
M('-C<F]L;&EN9STB;F\B(&UA<F=I;FAE:6=H=#TB,"(@;6%R9VEN=VED=&@]
M(C`B('-R8STB/#]P:'`@96-H;R`D;65N=5]U<FP@/SXB("\^"B`\9G)A;64@
M;F%M93TB:&5L<%]M86EN(B!R97-I>F5A8FQE/2)Y97,B(&UA<F=I;FAE:6=H
M=#TB,B(@;6%R9VEN=VED=&@](C(B('-R8STB/#]P:'`@96-H;R`D;6%I;E]U
M<FP@/SXB("\^"CPO9G)A;65S970^"@H\+VAT;6P^"@``````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W1E;7!L871E<R]H96QP+V%B;W5T
M+FEN8P``````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(Q
M-B`Q,#4Q-30S-#$T-"`P,C(R-C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/&@R(&%L:6=N/2)C96YT97(B/CP_<&AP('!R
M:6YT9BA?*")4:&ES(&ES("5S+B(I+"`D=F5R<VEO;BD@/SX\+V@R/@H\<')E
M('-T>6QE/2)D:7)E8W1I;VXZ;'1R(CX\/W!H<"!E8VAO(&AT;6QS<&5C:6%L
M8VAA<G,H)&-R961I=',I(#\^/"]P<F4^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8P``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q-3(@,3`U,34T,S0Q
M-#0@,#(R-C`S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@HD;2`]("9N97<@2&]R9&5?36]B:6QE*%\H(DQO9R!I
M;B(I*3L*)&TM/F%D9"AN97<@2&]R9&5?36]B:6QE7W1E>'0H<W!R:6YT9BA?
M*")796QC;VUE('1O("5S(BDL("1R96=I<W1R>2T^9V5T*"=N86UE)RDI*2D[
M"@HD9B`]("9N97<@2&]R9&5?36]B:6QE7V9O<FTH)VQO9VEN+G!H<"<I.PHD
M9BT^861D*&YE=R!(;W)D95]-;V)I;&5?:&ED9&5N*"=U<FPG+"!5=&EL.CIG
M971&;W)M1&%T82@G=7)L)RP@)R<I*2D["B1F+3YA9&0H;F5W($AO<F1E7TUO
M8FEL95]I;G!U="@G:&]R9&5?=7-E<B<L("<G+"!?*")5<V5R;F%M93H@(BDI
M*3L*"B\O($%D9"!A('!A<W-W;W)D(&EN<'5T+"!A;F0@<V5T('1H92!T>7!E
M(&%C8V]R9&EN9VQY+@HD<"`]("8D9BT^861D*&YE=R!(;W)D95]-;V)I;&5?
M:6YP=70H)VAO<F1E7W!A<W,G+"`G)RP@7R@B4&%S<W=O<F0Z("(I*2D["B1P
M+3YS970H)W1Y<&4G+"`G<&%S<W=O<F0G*3L*"B\O(%-U8FUI="!B=71T;VXN
M"B1F+3YA9&0H;F5W($AO<F1E7TUO8FEL95]S=6)M:70H7R@B3&]G(&EN(BDI
M*3L*"B\O($%D9"!T:&4@9F]R;2!T;R!T:&4@<&%G92X*)&TM/F%D9"@D9BD[
M"@HO+R!$:7-P;&%Y(&5V97)Y=&AI;F<N"B1M+3YD:7-P;&%Y*"D["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(R-S8@,3`U
M,34T,S0Q-#0@,#(R-#4U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B1R:6=H=$%L:6=N(#T@96UP='DH)&YL<ULG
M<G1L)UU;)&QA;F=U86=E72D@/R`G<FEG:'0G(#H@)VQE9G0G.PHD;&5F=$%L
M:6=N(#T@96UP='DH)&YL<ULG<G1L)UU;)&QA;F=U86=E72D@/R`G;&5F="<@
M.B`G<FEG:'0G.PH_/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"CPA+2T*9G5N8W1I;VX@<V5T1F]C=7,H*0I["B`@("!I9B`H9&]C=6UE;G0N
M:&]R9&5?;&]G:6XN:&]R9&5?=7-E<BYV86QU92`]/2`B(BD@>PH@("`@("`@
M(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W5S97(N9F]C=7,H*3L*("`@
M('T@96QS92!["B`@("`@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN:&]R9&5?
M<&%S<RYF;V-U<R@I.PH@("`@?0I]"F9U;F-T:6]N('-U8FUI=%]L;V=I;BAE
M*0I["B`@("!I9B`H='EP96]F(&4@(3T@)W5N9&5F:6YE9"<@)B8@(65N=&5R
M7VME>5]T<F%P*&4I*2!["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF
M("AD;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]U<V5R+G9A;'5E(#T]("(B
M*2!["B`@("`@("`@86QE<G0H(CP_<&AP(&5C:&\@861D<VQA<VAE<RA?*")0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(I*2`_
M/B(I.PH@("`@("`@(&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W5S97(N
M9F]C=7,H*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!](&5L<V4@:68@
M*&1O8W5M96YT+FAO<F1E7VQO9VEN+FAO<F1E7W!A<W,N=F%L=64@/3T@(B(I
M('L*("`@("`@("!A;&5R="@B/#]P:'`@96-H;R!A9&1S;&%S:&5S*%\H(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(BDI(#\^
M(BD["B`@("`@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN:&]R9&5?<&%S<RYF
M;V-U<R@I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T@96QS92!["B`@
M("`@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN;&]G:6Y"=71T;VXN9&ES86)L
M960@/2!T<G5E.PH\/W!H<"!I9B`H(65M<'1Y*"1I95]C;&EE;G1C87!S*2DZ
M(#\^"B`@("`@("`@=')Y('L*("`@("`@("`@("`@9&]C=6UE;G0N:&]R9&5?
M;&]G:6XN:65?=F5R<VEO;BYV86QU92`](&]B:D-#87!S+F=E=$-O;7!O;F5N
M=%9E<G-I;VXH(GLX.3@R,#(P,"U%0T)$+3$Q0T8M.$(X-2TP,$%!,#`U0C0S
M.#-](BP@(F-O;7!O;F5N=&ED(BD["B`@("`@("`@?2!C871C:"`H92D@>PH@
M("`@("`@('T*/#]P:'`@96YD:68[(#\^"B`@("`@("`@9&]C=6UE;G0N:&]R
M9&5?;&]G:6XN<W5B;6ET*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"GT*+R\M+3X*/"]S8W)I<'0^"@H\9F]R;2!N86UE/2)H;W)D95]L;V=I;B(@
M;65T:&]D/2)P;W-T(B!A8W1I;VX](CP_<&AP(&5C:&\@2&]R9&4Z.G-E;&95
M<FPH9F%L<V4L('1R=64L(&9A;'-E+"!T<G5E*2`_/B(\/W!H<"!E8VAO("1C
M;VYF6R=M96YU)UU;)V%L=V%Y<R==(#\@)R!T87)G970](E]P87)E;G0B)R`Z
M("<G(#\^/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)U<FPB('9A;'5E
M/2(\/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H571I;#HZ9V5T1F]R;41A
M=&$H)W5R;"<I*2`_/B(@+SX*/#]P:'`@:68@*"%E;7!T>2@D:65?8VQI96YT
M8V%P<RDI.B`_/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)I95]V97)S
M:6]N(B!V86QU93TB(B`O/@H\/W!H<"!E;F1I9CL@/SX*"CQD:78@:60](FUE
M;G4B/@H\/W!H<`HD;65N=2`]("9N97<@365N=2A(3U)$15]-14Y57TU!4TM?
M3D].12D["B1H;65N=2`]("1M96YU+3YR96YD97(H*3L*:68@*"1H;65N=2DZ
M(#\^"B`\<W!A;B!S='EL93TB9FQO870Z/#]P:'`@96-H;R`D<FEG:'1!;&EG
M;B`_/B(^/#]P:'`@96-H;R`D:&UE;G4@/SX\+W-P86X^"CP_<&AP(&5N9&EF
M.R`_/@H@/&@Q('-T>6QE/2)T97AT+6%L:6=N.F-E;G1E<B(^/#]P:'`@<')I
M;G1F*%\H(E=E;&-O;64@=&\@)7,B*2P@)')E9VES=')Y+3YG970H)VYA;64G
M*2D@/SX\+V@Q/@H\+V1I=CX*"CQB<B!C;&%S<STB<W!A8V5R(B`O/@H\/W!H
M<"`D;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@
M)W-T871U<R<I*2`_/@H*/'1A8FQE('=I9'1H/2(Q,#`E(CX\='(^/'1D(&%L
M:6=N/2)C96YT97(B/CQT86)L92!W:61T:#TB,S`P(B!A;&EG;CTB8V5N=&5R
M(CX*"CP_<&AP(&EF("@A96UP='DH)')E87-O;BDI.B`_/@H\='(^"B`@/'1D
M(&-O;'-P86X](C(B(&-L87-S/2)N;W1I8V4B/CP_<&AP(&5C:&\@)')E87-O
M;B`_/CPO=&0^"CPO='(^"CP_<&AP(&5N9&EF.R`_/@H*/'1R/@H@("`@/'1D
M(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H=$%L:6=N(#\^(B!C;&%S<STB;&EG
M:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?*")5<V5R;F%M92(I(#\^/"]S=')O
M;F<^)FYB<W`[/"]T9#X*("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D;&5F
M=$%L:6=N(#\^(CX\:6YP=70@8VQA<W,](F9I>&5D(B!T>7!E/2)T97AT(B!N
M86UE/2)H;W)D95]U<V5R(B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA
M;&-H87)S*%5T:6PZ.F=E=$9O<FU$871A*"=H;W)D95]U<V5R)RDI(#\^(B!S
M='EL93TB9&ER96-T:6]N.FQT<B(@+SX\+W1D/@H\+W1R/@H*/'1R/@H@("`@
M/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1R:6=H=$%L:6=N(#\^(B!C;&%S<STB
M;&EG:'0B/CQS=')O;F<^/#]P:'`@96-H;R!?*")087-S=V]R9"(I(#\^/"]S
M=')O;F<^)FYB<W`[/"]T9#X*("`@(#QT9"!A;&EG;CTB/#]P:'`@96-H;R`D
M;&5F=$%L:6=N(#\^(CX\:6YP=70@8VQA<W,](F9I>&5D(B!T>7!E/2)P87-S
M=V]R9"(@;F%M93TB:&]R9&5?<&%S<R(@=F%L=64](B(@<W1Y;&4](F1I<F5C
M=&EO;CIL='(B("\^/"]T9#X*/"]T<CX*"CP_<&AP(&EF("@A)'!R969S+3YI
M<TQO8VME9"@G;&%N9W5A9V4G*2DZ(#\^"CQT<CX*("`@(#QT9"!A;&EG;CTB
M/#]P:'`@96-H;R`D<FEG:'1!;&EG;B`_/B(@8VQA<W,](FQI9VAT(CX\<W1R
M;VYG/CP_<&AP(&5C:&\@7R@B3&%N9W5A9V4B*2`_/CPO<W1R;VYG/CPO=&0^
M"B`@("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(@8VQA
M<W,](FQI9VAT(B!S='EL93TB9&ER96-T:6]N.FQT<B(^/#]P:'`@96-H;R`D
M;&%N9W,@/SX\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CQT<CX*("`@
M(#QT9#XF;F)S<#L\+W1D/@H@("`@/'1D(&%L:6=N/2(\/W!H<"!E8VAO("1L
M969T06QI9VX@/SXB(&-L87-S/2)L:6=H="(^/&EN<'5T(&YA;64](FQO9VEN
M0G5T=&]N(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*"),
M;V<@:6XB*2`_/B(@='EP93TB<W5B;6ET(B!O;F-L:6-K/2)R971U<FX@<W5B
M;6ET7VQO9VEN*"D[(B`O/CPO=&0^"CPO='(^"@H\/W!H<"!I9B`H(65M<'1Y
M*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72D@)B8@)&%U=&@M/FAA<T-A<&%B
M:6QI='DH)V%D9"<I*3H@/SX*/'1R/@H@("`@/'1D/B9N8G-P.SPO=&0^"B`@
M("`\=&0@86QI9VX](CP_<&AP(&5C:&\@)&QE9G1!;&EG;B`_/B(@8VQA<W,]
M(FQI9VAT(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M
M971E<BA(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-I9VYU<"YP:'`G*2P@)W5R;"<L(%5T:6PZ.F=E=$9O<FU$
M871A*"=U<FPG*2DL(%\H(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"XB*2P@)VQI9VAT)RD@+B!?*")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I
M9VX@=7`N(BD@/SX\+V$^/"]T9#X*/"]T<CX*/#]P:'`@96YD:68[(#\^"CP_
M<&AP(&EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G<F5S971P87-S=V]R9"<I
M*3H@/SX*/'1R/@H@("`@/'1D/B9N8G-P.SPO=&0^"B`@("`\=&0@8VQA<W,]
M(FQI9VAT(CX\/W!H<"!E8VAO($AO<F1E.CIL:6YK*%5T:6PZ.F%D9%!A<F%M
M971E<BA(;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP)RDL("=U<FPG
M+"!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI+"!?*")&;W)G;W0@>6]U<B!P
M87-S=V]R9#\B*2P@)VQI9VAT)RD@+B!?*")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B*2`_/CPO83X\+W1D/@H\+W1R/@H\/W!H<"!E;F1I9CL@/SX*"CPO=&%B
M;&4^/"]T9#X\+W1R/CPO=&%B;&4^"CPO9F]R;3X*"CP_<&AP(&EF("A`:7-?
M<F5A9&%B;&4H2$]21$5?0D%312`N("<O8V]N9FEG+VUO=&0N<&AP)RDI(')E
M<75I<F4@2$]21$5?0D%312`N("<O8V]N9FEG+VUO=&0N<&AP)SL@/SX*"CQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*/"$M+0H\/W!H<"!I9B`H
M(21P<F5F<RT^:7-,;V-K960H)VQA;F=U86=E)RDI.@H@("`@)&QA;F=?=7)L
M(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L;V=I;BYP:'`G+"!T<G5E*3L*
M("`@(&EF("@H)'5R;"`](%5T:6PZ.F=E=$9O<FU$871A*"=U<FPG*2DI('L*
M("`@("`@("`D;&%N9U]U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)&QA;F=?
M=7)L+"`G=7)L)RP@)'5R;"P@9F%L<V4I.PH@("`@?0H@("`@)&QA;F=?=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1L86YG7W5R;"P@)VYE=U]L86YG)RP@
M)R<L(&9A;'-E*3L*/SX*9G5N8W1I;VX@<V5L96-T3&%N9R@I"GL*("`@("\O
M(%=E(&YE960@=&\@<F5L;V%D('1H92!L;V=I;B!P86=E(&AE<F4L(&)U="!O
M;FQY(&EF('1H92!U<V5R"B`@("`O+R!H87-N)W0@86QR96%D>2!E;G1E<F5D
M(&$@=7-E<FYA;64@86YD('!A<W-W;W)D+@H@("`@:68@*&1O8W5M96YT+FAO
M<F1E7VQO9VEN+FAO<F1E7W5S97(N=F%L=64@/3T@)R<@)B8*("`@("`@("!D
M;V-U;65N="YH;W)D95]L;V=I;BYH;W)D95]P87-S+G9A;'5E(#T]("<G*2![
M"B`@("`@("`@=F%R(&QA;F=?<&%G92`]("<\/W!H<"!E8VAO("1L86YG7W5R
M;"`_/B<@*R!D;V-U;65N="YH;W)D95]L;V=I;BYN97=?;&%N9UMD;V-U;65N
M="YH;W)D95]L;V=I;BYN97=?;&%N9RYS96QE8W1E9$EN9&5X72YV86QU93L*
M("`@("`@("!S96QF+FQO8V%T:6]N(#T@;&%N9U]P86=E.PH@("`@?0I]"CP_
M<&AP(&5N9&EF.R`_/@H*:68@*'!A<F5N="YF<F%M97,N:&]R9&5?;6%I;BD@
M>PH@("`@9&]C=6UE;G0N:&]R9&5?;&]G:6XN=&%R9V5T(#T@)U]P87)E;G0G
M.PI]"@HO+R!3970@=7`@=&AE(&5N=&5R(&ME>71R87`@8V]D92X*:68@*'1Y
M<&5O9B!D;V-U;65N="YC87!T=7)E179E;G1S("$]("=U;F1E9FEN960G*2![
M"B`@("!D;V-U;65N="YC87!T=7)E179E;G1S*$5V96YT+DM%65!215-3*3L*
M("`@(&1O8W5M96YT+F]N:V5Y<')E<W,@/2!S=6)M:71?;&]G:6X["GT*+R\M
M+3X*/"]S8W)I<'0^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(`````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#,@,#(P-38U`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;```````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T-"`P,C`V,#$`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<VAA
M<F5S````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30T(#`R,#4V-0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]D;W=N;&]A9```````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#0@,#(Q,3`W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V]B<F]W<V5R````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T-"`P,C$Q-#(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O:6UA9V5S````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30T(#`R,#4T-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]H96QP````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#0@
M,#(P,C,P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<```````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C4T-R`Q,#4Q-30S-#$T-"`P,C(S-C8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP+'8@,2XS,2XR+C,@,C`P-B\P
M,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAA<FQE<R!*+B!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#$M,C`P
M-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-86EN=&5N86YC92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U1E;7!L871E+G!H<"<["@HO*B!-86ME('-U
M<F4@=&AE<F4@:7,@82!U<V5R(&QO9V=E9"!I;BX@*B\*:68@*"%!=71H.CIG
M971!=71H*"DI('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52
M961I<F5C="@I.PI]"@HO*B!)9B!N;R`G;6]D=6QE)R!P87)A;65T97(@<&%S
M<V5D(&EN+"!D:64@=VET:"!A;B!E<G)O<BX@*B\*:68@*"$H)&UO9'5L92`]
M(&)A<V5N86UE*%5T:6PZ.F=E=$9O<FU$871A*"=M;V1U;&4G*2DI*2!["B`@
M("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BA?*")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(I*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*?0HD87!P7VYA;64@/2`D<F5G:7-T<GDM/F=E="@G;F%M92<L
M("1M;V1U;&4I.PH*+RH@3&]A9"!T:&4@;6]D=6QE('-P96-I9FEC(&UA:6YT
M96YA;F-E(&-L87-S(&YO=RX@*B\*:68@*"$H)&UA:6YT(#T@)DUA:6YT96YA
M;F-E.CIF86-T;W)Y*"1M;V1U;&4I*2D@>PH@("`@2&]R9&4Z.F9A=&%L*%!%
M05(Z.G)A:7-E17)R;W(H7R@B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED
M(&YO="!L;V%D('-U8V-E<W-F=6QL>2(I*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*?0H*+RH@0W)E871E('1H92!(;W)D95]496UP;&%T92!I=&5M+B`J+PHD
M=&5M<&QA=&4@/2`F;F5W($AO<F1E7U1E;7!L871E*"D["B1T96UP;&%T92T^
M<V5T*"=J879A<V-R:7!T)RP@)&)R;W=S97(M/FAA<T9E871U<F4H)VIA=F%S
M8W)I<'0G*2P@=')U92D["@HO*B!(879E('1H92!M86EN=&5N86YC92!M;V1U
M;&4@9&\@86QL(&YE8V5S<V%R>2!P<F]C97-S:6YG+B`J+PIL:7-T*"1A8W1I
M;VXL("1T87-K;&ES="D@/2`D;6%I;G0M/G)U;DUA:6YT96YA;F-E4&%G92@I
M.PH*<W=I=&-H("@D86-T:6]N*2!["F-A<V4@34%)3E1%3D%.0T5?3U544%54
M7T-/3D9)4DTZ"B`@("`O*B!#;VYF:7)M871I;VXM<W1Y;&4@;W5T<'5T+B`J
M+PH@("`@)'1E;7!L871E+3YS970H)V-O;F9I<FTG+"!T<G5E+"!T<G5E*3L*
M("`@("1T96UP;&%T92T^<V5T*"=A9W)E92<L(&9A;'-E+"!T<G5E*3L*("`@
M("1T96UP;&%T92T^<V5T*"=N;W1I8V4G+"!F86QS92P@=')U92D["@H@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@
M=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB*2P@)&%P<%]N86UE*2P@
M)VAO<F1E+FUE<W-A9V4G*3L*("`@("1T96UP;&%T92T^<V5T*"=H96%D97(G
M+"!S<')I;G1F*%\H(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB*2P@)&%P<%]N86UE*2D["B`@("!B<F5A:SL*"F-A<V4@34%)
M3E1%3D%.0T5?3U544%547T%'4D5%.@H@("`@+RH@06=R965M96YT+7-T>6QE
M(&]U='!U="X@*B\*("`@("1T96UP;&%T92T^<V5T*"=C;VYF:7)M)RP@9F%L
M<V4L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)V%G<F5E)RP@=')U92P@
M=')U92D["B`@("`D=&5M<&QA=&4M/G-E="@G;F]T:6-E)RP@9F%L<V4L('1R
M=64I.PH*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE('-Y<W1E;2XB*2P@)VAO<F1E+FUE<W-A9V4G*3L*
M("`@("1T96UP;&%T92T^<V5T*"=H96%D97(G+"!S<')I;G1F*%\H(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(I+"`D87!P7VYA;64I*3L*("`@(&)R96%K.PH*
M8V%S92!-04E.5$5.04Y#15]/5510551?3D]424-%.@H@("`@+RH@3F]T:6-E
M+7-T>6QE(&]U='!U="X@*B\*("`@("1T96UP;&%T92T^<V5T*"=C;VYF:7)M
M)RP@9F%L<V4L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)V%G<F5E)RP@
M9F%L<V4L('1R=64I.PH@("`@)'1E;7!L871E+3YS970H)VYO=&EC92<L('1R
M=64L('1R=64I.PH*("`@("1T96UP;&%T92T^<V5T*"=H96%D97(G+"!S<')I
M;G1F*%\H(B5S("T@3F]T:6-E(BDL("1A<'!?;F%M92DI.PH@("`@8G)E86L[
M"GT*"B\J($UA:V4@=F%R:6%B;&4@87)R87D@;F5E9&5D(&9O<B!T96UP;&%T
M97,N("HO"B1T87-K<R`](&%R<F%Y*"D["F9O<F5A8V@@*"1T87-K;&ES="!A
M<R`D<')E9BD@>PH@("`@;&ES="@D9&5S8W)I<"P@)&-H96-K960I(#T@)&UA
M:6YT+3YI;F9O36%I;G1E;F%N8V4H)'!R968I.PH@("`@)'1A<VMS6UT@/2!A
M<G)A>2@G<')E9B<@/3X@)'!R968L("=D97-C<FEP)R`]/B`D9&5S8W)I<"P@
M)V-H96-K960G(#T^("1C:&5C:V5D(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)RD["GT*"B1T96UP;&%T92T^<V5T3W!T:6]N*"=G971T97AT)RP@=')U
M92D["B1T96UP;&%T92T^<V5T*"=T87-K<R<L("1T87-K<RD["B1T96UP;&%T
M92T^<V5T*"=M86EN=%]U<FPG+"`D;6%I;G0M/F=E=$UA:6YT96YA;F-E1F]R
M;5523"@I*3L*)'1E;7!L871E+3YS970H)VUA:6YT7W!O<W1D871A)RP@)&UA
M:6YT+3YG9710;W-T1&%T82@I*3L*)'1E;7!L871E+3YS970H)VYO=&EF>2<L
M(%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D;F]T:69I8V%T:6]N+"`G;F]T
M:69Y)RDL(&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2DI.PH*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D97(N:6YC)SL*
M96-H;R`D=&5M<&QA=&4M/F9E=&-H*$A/4D1%7U1%35!,051%4R`N("<O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;"<I.PIR97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]L86YG=6%G
M92YP:'``````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$S-3<@,3`U,34T,S0Q-#0@,#(Q-C8Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!38W)I<'0@=&\@
M<V5T('1H92!N97<@;&%N9W5A9V4N"B`J"B`J("1(;W)D93H@:&]R9&4O<V5R
M=FEC97,O;&%N9W5A9V4N<&AP+'8@,2XU+C$R+C,@,C`P-B\P,2\P,2`R,3HR
M.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K
M;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`
M9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G
M.PH*+RH@4V5T('1H92!L86YG=6%G92X@*B\*)%]315-324].6R=H;W)D95]L
M86YG=6%G92==(#T@3DQ3.CIS96QE8W0H*3L*)'!R969S+3YS971686QU92@G
M;&%N9W5A9V4G+"`D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UTI.PH*+RH@
M4F5D:7)E8W0@=&\@=&AE('5R;"!O<B!L;V=I;B!P86=E(&EF(&YO;F4@9VEV
M96XN("HO"B1U<FP@/2!5=&EL.CIG971&;W)M1&%T82@G=7)L)RD["FEF("AE
M;7!T>2@D=7)L*2D@>PH@("`@)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R
M;"@G:6YD97@N<&AP)RP@=')U92D["GT*:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M("1U<FPI.PH`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'``````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#<R-38@,3`U,34T,S0Q-#0@,#(S,3$R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<"QV(#$N,2XR
M+C(@,C`P-B\P,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#4M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO
M<WES+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G
M.PH*:68@*"%!=71H.CII<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z
M.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\O($UA:V4@
M<W5R92!A=71H(&)A8VME;F0@86QL;W=S('!A<W-W;W)D<R!T;R!B92!R97-E
M="X*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R
M:79E<B==*3L*:68@*"$D875T:"T^:&%S0V%P86)I;&ET>2@G=7!D871E)RDI
M('L*("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(I+"`G
M:&]R9&4N97)R;W(G*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!!=71H
M.CIG971,;V=I;E-C<F5E;B@G)RP@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I
M*2D["B`@("!E>&ET.PI]"@HD=F%R<R`]("9687)I86)L97,Z.F=E=$1E9F%U
M;'1687)I86)L97,H*3L*"B1T:71L92`](%\H(D-H86YG92!9;W5R(%!A<W-W
M;W)D(BD["B1F;W)M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G2&]R9&53
M:6=N=7!&;W)M)RP@)'9A<G,L("1T:71L92D["B1F;W)M+3YS971"=71T;VYS
M*%\H(D-O;G1I;G5E(BDI.PH*)&9O<FTM/F%D9$AI9&1E;B@G)RP@)W)E='5R
M;E]T;R<L("=T97AT)RP@9F%L<V4I.PHD9F]R;2T^861D5F%R:6%B;&4H7R@B
M3VQD('!A<W-W;W)D(BDL("=O;&1?<&%S<W=O<F0G+"`G<&%S<W=O<F0G+"!T
M<G5E*3L*)&9O<FTM/F%D9%9A<FEA8FQE*%\H(DYE=R!P87-S=V]R9"(I+"`G
M<&%S<W=O<F1?,2<L("=P87-S=V]R9"<L('1R=64I.PHD9F]R;2T^861D5F%R
M:6%B;&4H7R@B4F5T>7!E(&YE=R!P87-S=V]R9"(I+"`G<&%S<W=O<F1?,B<L
M("=P87-S=V]R9"<L('1R=64I.PH*:68@*"1V87)S+3YE>&ES=',H)V9O<FUN
M86UE)RDI('L*("`@("1F;W)M+3YV86QI9&%T92@D=F%R<RD["B`@("!I9B`H
M)&9O<FTM/FES5F%L:60H*2D@>PH@("`@("`@("1F;W)M+3YG971);F9O*"1V
M87)S+"`D:6YF;RD["B`@("`@("`@9&\@>PH@("`@("`@("`@("!I9B`H)&%U
M=&@M/F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RD@(3T@)&EN9F];)V]L9%]P
M87-S=V]R9"==*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"1I;F9O6R=P87-S=V]R9%\Q)UT@(3T@)&EN9F];)W!A<W-W
M;W)D7S(G72D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&EN9F];)V]L9%]P87-S=V]R9"==(#T]("1I;F9O6R=P87-S=V]R
M9%\Q)UTI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!&25A-13H@3F5E9"!T;R!C;&5A
M;B!U<"!P87-S=V]R9"!P;VQI8WD@<&%T8V@@86YD(&-O;6UI="!B969O<F4*
M("`@("`@("`@("`@("H@96YA8FQI;F<@=&AI<RXN+B`M2DU&"@H@("`@("`@
M("`@("`D<F5S(#T@075T:#HZ=&5S=%!A<W-W;W)D4W1R96YG=&@H)&EN9F];
M)W!A<W-W;W)D7S$G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;VYF6R=A=71H)UU;)W!A<W-W;W)D7W!O;&EC
M>2==*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D<F5S
M+3YG971-97-S86=E*"DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@*B\*"B`@("`@
M("`@("`@("1R97,@/2`D875T:"T^=7!D871E57-E<BA!=71H.CIG971!=71H
M*"DL($%U=&@Z.F=E=$%U=&@H*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=P87-S=V]R9"<@/3X@)&EN9F];)W!A<W-W
M;W)D7S$G72DI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E
M<RT^9V5T365S<V%G92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"A?*")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N<W5C8V5S<R<I
M.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R=R971U<FY?=&\G72DI
M('L*("`@("`@("`@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D:6YF
M;ULG<F5T=7)N7W1O)UTI.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]('=H:6QE("AF
M86QS92D["B`@("!]"GT*"B1V87)S+3YR96UO=F4H)V]L9%]P87-S=V]R9"<I
M.PHD=F%R<RT^<F5M;W9E*"=P87-S=V]R9%\Q)RD["B1V87)S+3YR96UO=F4H
M)W!A<W-W;W)D7S(G*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A
M>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PHD<F5N9&5R97(@/2`F;F5W
M($AO<F1E7T9O<FU?4F5N9&5R97(H*3L*)&9O<FTM/G)E;F1E<D%C=&EV92@D
M<F5N9&5R97(L("1V87)S+"`G8VAA;F=E<&%S<W=O<F0N<&AP)RP@)W!O<W0G
M*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]J879A<V-R:7!T+G!H<```````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-C(@,3`U,34T,S0Q-#0@,#(R
M,C0R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VIA=F%S8W)I
M<'0N<&AP+'8@,2XS-RXQ,"XT(#(P,#8O,#$O,#$@,C$Z,CDZ,3`@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@0VAA<FQE<R!*+B!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E
M9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I
M.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*
M"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N*$A/4D1%7U-%4U-)
M3TY?4D5!1$].3%DI.PH*+R\@1FEG=7)E(&]U="!I9B!W92=V92!B965N(&EN
M;&EN960L(&]R(&-A;&QE9"!D:7)E8W1L>2X*)'-E;F1?:&5A9&5R<R`]('-T
M<G-T<B@D7U-%4E9%4ELG4$A07U-%3$8G72P@)VIA=F%S8W)I<'0N<&AP)RD[
M"@HD87!P(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P<"<L(%5T:6PZ.FYO;DEN
M<'5T5F%R*"=A<'`G*2D["B1F:6QE(#T@571I;#HZ9V5T1F]R;41A=&$H)V9I
M;&4G+"!5=&EL.CIN;VY);G!U=%9A<B@G9FEL92<I*3L*:68@*"%E;7!T>2@D
M87!P*2`F)B`A96UP='DH)&9I;&4I("8F('-T<G!O<R@D9FEL92P@)RXN)RD@
M/3T](&9A;'-E*2!["B`@("`D<V-R:7!T7V9I;&4@/2`D<F5G:7-T<GDM/F=E
M="@G=&5M<&QA=&5S)RP@)&%P<"D@+B`G+VIA=F%S8W)I<'0O)R`N("1F:6QE
M.PH@("`@:68@*$!F:6QE7V5X:7-T<R@D<V-R:7!T7V9I;&4I*2!["B`@("`@
M("`@)')E9VES=')Y+3YP=7-H07!P*"1A<'`L(&9A;'-E*3L*("`@("`@("`D
M<V-R:7!T(#T@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@)'-C<FEP
M=%]F:6QE*3L*"B`@("`@("`@:68@*"1S96YD7VAE861E<G,I('L*("`@("`@
M("`@("`@+RH@0V]M<')E<W,@=&AE($I3+B!792!N965D('1H:7,@97AP;&EC
M:70@8V%L;"!S:6YC92!W90H@("`@("`@("`@("`@*B!D;VXG="!I;F-L=61E
M(&)A<V4N<&AP(&EN('1H:7,@9FEL92X@*B\*("`@("`@("`@("`@2&]R9&4Z
M.F-O;7!R97-S3W5T<'5T*"D["@H@("`@("`@("`@("!H96%D97(H)T-A8VAE
M+4-O;G1R;VPZ(&YO+6-A8VAE)RD["B`@("`@("`@("`@(&AE861E<B@G0V]N
M=&5N="U4>7!E.B!T97AT+VIA=F%S8W)I<'0G*3L*("`@("`@("!]"@H@("`@
M("`@(&5C:&\@)'-C<FEP=#L*("`@('T*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VME>6)O
M87)D+G!H<```````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`Q,S4T-R`Q,#4Q-30S-#$T-"`P,C$W,#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RH*("H@)$AO<F1E.B!H
M;W)D92]S97)V:6-E<R]K97EB;V%R9"YP:'`L=B`Q+C$S+C$P+C,@,C`P-B\P
M,2\P,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G
M+VQI8B]B87-E+G!H<"<["@HD=&ET;&4@/2!?*")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N
M+6AE861E<BYI;F,G.PH*/SX*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CX*"G9A<B!T87)G970["@IF=6YC=&EO;B!H86YD;&5,:7-T0VAA;F=E
M*'1H94QI<W0I('L*("`@('9A<B!N=6U396QE8W1E9"`]('1H94QI<W0N<V5L
M96-T961);F1E>#L*"B`@("!I9B`H;G5M4V5L96-T960@(3T@,"D@>PH@("`@
M("`@(&1O8W5M96YT+F-H87)A8W1E<G,N=&5X=&)O>"YV86QU92`K/2!T:&5,
M:7-T+F]P=&EO;G-;;G5M4V5L96-T961=+G9A;'5E.PH@("`@("`@('1H94QI
M<W0N<V5L96-T961);F1E>"`](#`["B`@("!]"GT*/"]S8W)I<'0^"@H\9F]R
M;2!N86UE/2)C:&%R86-T97)S(CX*/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX*
M("`\='(^"B`@("`\=&0@8VQA<W,](FET96T@;&5F=$%L:6=N(CX*("`@("`@
M/'`^/#]P:'`@96-H;R!?*")396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB*2`_/CPO<#X*("`@
M(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@8VQA<W,](FQE9G1!;&EG
M;B(^"B`@("`@(#QT86)L92!C96QL<W!A8VEN9STB,"(^"B`@("`@("`@/'1R
M/@H@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`@("`@("`\
M<V5L96-T(&YA;64](F$B(&]N8VAA;F=E/2)H86YD;&5,:7-T0VAA;F=E*'1H
M:7,I(CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2)A(B!S96QE8W1E
M9#X@82`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S$Y,CLB/B`F(S$Y,CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,R,C0[(CX@)B,R,C0[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,3DS.R(^("8C,3DS.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(R-3LB/B`F(S(R-3L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q.30[
M(CX@)B,Q.30[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,C(V.R(^("8C,C(V.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(F(S$Y-3LB/B`F(S$Y-3L@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,C<[(CX@)B,R,C<[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,3DV.R(^("8C
M,3DV.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S(R.#LB/B`F(S(R.#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,Q.3<[(CX@)B,Q.3<[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,C(Y.R(^("8C,C(Y.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@/"]S96QE8W0^"B`@("`@("`@("`\+W1D/@H@("`@("`@
M("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`@("`@("`\<V5L96-T(&YA
M;64](F4B(&]N8VAA;F=E/2)H86YD;&5,:7-T0VAA;F=E*'1H:7,I(CX*("`@
M("`@("`@("`@("`\;W!T:6]N('9A;'5E/2)E(B!S96QE8W1E9#X@92`\+V]P
M=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(P,#LB/B`F
M(S(P,#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB
M)B,R,S([(CX@)B,R,S([(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I
M;VX@=F%L=64](B8C,C`Q.R(^("8C,C`Q.R`\+V]P=&EO;CX*("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2(F(S(S,SLB/B`F(S(S,SL@/"]O<'1I;VX^
M"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#([(CX@)B,R,#([
M(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C,T
M.R(^("8C,C,T.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2(F(S(P,SLB/B`F(S(P,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@
M/&]P=&EO;B!V86QU93TB)B,R,S4[(CX@)B,R,S4[(#PO;W!T:6]N/@H@("`@
M("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^"B`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(^"B`@("`@("`@("`@(#QS96QE8W0@;F%M93TB
M:2(@;VYC:&%N9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI<RDB/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](FDB('-E;&5C=&5D/B!I(#PO;W!T:6]N
M/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C`T.R(^("8C,C`T
M.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S
M-CLB/B`F(S(S-CL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V
M86QU93TB)B,R,#4[(CX@)B,R,#4[(#PO;W!T:6]N/@H@("`@("`@("`@("`@
M(#QO<'1I;VX@=F%L=64](B8C,C,W.R(^("8C,C,W.R`\+V]P=&EO;CX*("`@
M("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(P-CLB/B`F(S(P-CL@/"]O
M<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,S@[(CX@
M)B,R,S@[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M(B8C,C`W.R(^("8C,C`W.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2(F(S(S.3LB/B`F(S(P-SL@/"]O<'1I;VX^"B`@("`@("`@
M("`@(#PO<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@("`@("`@(#QT9"!A
M;&EG;CTB8V5N=&5R(CX*("`@("`@("`@("`@/'-E;&5C="!N86UE/2)O(B!O
M;F-H86YG93TB:&%N9&QE3&ES=$-H86YG92AT:&ES*2(^"B`@("`@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB;R(@<V5L96-T960^(&\@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,3`[(CX@)B,R,3`[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0R.R(^
M("8C,C0R.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E
M/2(F(S(Q,3LB/B`F(S(Q,3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P
M=&EO;B!V86QU93TB)B,R-#,[(CX@)B,R-#,[(#PO;W!T:6]N/@H@("`@("`@
M("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C$R.R(^("8C,C$R.R`\+V]P=&EO
M;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(T-#LB/B`F(S(T
M-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R
M,3,[(CX@)B,R,3,[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@
M=F%L=64](B8C,C0U.R(^("8C,C0U.R`\+V]P=&EO;CX*("`@("`@("`@("`@
M("`\;W!T:6]N('9A;'5E/2(F(S(Q-#LB/B`F(S(Q-#L@/"]O<'1I;VX^"B`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R-#8[(CX@)B,R-#8[(#PO
M;W!T:6]N/@H@("`@("`@("`@("`\+W-E;&5C=#X*("`@("`@("`@(#PO=&0^
M"B`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(^"B`@("`@("`@("`@(#QS
M96QE8W0@;F%M93TB=2(@;VYC:&%N9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI
M<RDB/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](G4B('-E;&5C=&5D
M/B!U(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C
M,C$W.R(^("8C,C$W.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N
M('9A;'5E/2(F(S(T.3LB/B`F(S(T.3L@/"]O<'1I;VX^"B`@("`@("`@("`@
M("`@/&]P=&EO;B!V86QU93TB)B,R,3@[(CX@)B,R,3@[(#PO;W!T:6]N/@H@
M("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C4P.R(^("8C,C4P.R`\
M+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(Q.3LB
M/B`F(S(Q.3L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU
M93TB)B,R-3$[(CX@)B,R-3$[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO
M<'1I;VX@=F%L=64](B8C,C(P.R(^("8C,C(P.R`\+V]P=&EO;CX*("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(U,CLB/B`F(S(U,CL@/"]O<'1I
M;VX^"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@("`@("`@/"]T9#X*("`@
M("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(CX*("`@("`@("`@("`@/'-E;&5C
M="!N86UE/2)/=&AE<B(@;VYC:&%N9V4](FAA;F1L94QI<W1#:&%N9V4H=&AI
M<RDB/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](FUI<V,B('-E;&5C
M=&5D/B`\/W!H<"!E8VAO(%\H(D]T:&5R(BD[(#\^/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,Q-C([(CX@)B,Q-C([(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,38S.R(^("8C
M,38S.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S$V-#LB/B`F(S$V-#L@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,Q-C4[(CX@)B,Q-C4[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,3DX.R(^("8C,3DX.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S(S,#LB/B`F(S(S,#L@
M/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,C,[
M(CX@)B,R,C,[(#PO;W!T:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L
M=64](B8C,3DY.R(^("8C,3DY.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\
M;W!T:6]N('9A;'5E/2(F(S(S,3LB/B`F(S(S,3L@/"]O<'1I;VX^"B`@("`@
M("`@("`@("`@/&]P=&EO;B!V86QU93TB)B,R,#D[(CX@)B,R,#D[(#PO;W!T
M:6]N/@H@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64](B8C,C0Q.R(^("8C
M,C0Q.R`\+V]P=&EO;CX*("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F
M(S(U,SLB/B`F(S(U,SL@/"]O<'1I;VX^"B`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TB)B,R-34[(CX@)B,R-34[(#PO;W!T:6]N/@H@("`@("`@("`@
M("`@(#QO<'1I;VX@=F%L=64](B8C,3DQ.R(^("8C,3DQ.R`\+V]P=&EO;CX*
M("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2(F(S$V,3LB/B`F(S$V,3L@
M/"]O<'1I;VX^"B`@("`@("`@("`@(#PO<V5L96-T/@H@("`@("`@("`@/"]T
M9#X*("`@("`@("`\+W1R/@H@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*("`\
M+W1R/@H@(#QT<CX*("`@(#QT9"!C;&%S<STB9FEX960@;&5F=$%L:6=N(CX*
M("`@("`@/'1E>'1A<F5A(')O=W,](C0B(&-O;',](C(U(B!C;&%S<STB9FEX
M960B(&YA;64](G1E>'1B;W@B/CPO=&5X=&%R96$^"B`@("`\+W1D/@H@(#PO
M='(^"B`@/'1R/@H@("`@/'1D(&%L:6=N/2)C96YT97(B/@H@("`@("`\:6YP
M=70@='EP93TB8G5T=&]N(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)W:6YD
M;W<N8VQO<V4H*3LB(&YA;64](F-L;W-E(B!V86QU93TB/#]P:'`@96-H;R!?
M*")#;&]S92!7:6YD;W<B*2`_/B(@+SX*("`@(#PO=&0^"B`@/"]T<CX*/"]T
M86)L93X*/"]F;W)M/@H\+V)O9'D^"CPO:'1M;#X*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O8V%C:&5V:65W
M+G!H<```````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M-#<V(#$P-3$U-#,T,30T(#`R,C`S-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D
M92]S97)V:6-E<R]C86-H979I97<N<&AP+'8@,2XY+C$P+C,@,C`P-B\P,2\P
M,2`R,3HR.3HQ,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#86-H92YP:'`G.PH*
M)&-I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=C:60G*3L*:68@*&5M<'1Y*"1C
M:60I*2!["B`@("!E>&ET.PI]"@HD8V%C:&4@/2`F2&]R9&5?0V%C:&4Z.G-I
M;F=L971O;B@D8V]N9ELG8V%C:&4G75LG9')I=F5R)UTL($AO<F1E.CIG971$
M<FEV97)#;VYF:6<H)V-A8VAE)RP@)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==
M*2D["B1C9&%T82`]($!U;G-E<FEA;&EZ92@D8V%C:&4M/F=E="@D8VED+"`D
M8V]N9ELG8V%C:&4G75LG9&5F875L=%]L:69E=&EM92==*2D["FEF("@A)&-D
M871A*2!["B`@("!E>&ET.PI]"@HD8G)O=W-E<BT^9&]W;FQO861(96%D97)S
M*"=C86-H94]B:F5C="<L("1C9&%T85LG8W1Y<&4G72P@=')U92P@<W1R;&5N
M*"1C9&%T85LG9&%T82==*2D["F5C:&\@)&-D871A6R=D871A)UT["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'``````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$P,#(P(#$P-3$U-#,T,30T(#`R,C<V-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E
M.B!H;W)D92]S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<"QV(#$N-2XQ,"XW
M(#(P,#8O,#4O,C0@,C(Z-#4Z,3,@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#0M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E
M*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M5F%R:6%B;&5S+G!H<"<["@HO+R!-86ME('-U<F4@875T:"!B86-K96YD(&%L
M;&]W<R!P87-S=V]R9',@=&\@8F4@<F5S970N"B1A=71H(#T@)D%U=&@Z.G-I
M;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["FEF("@A)&%U=&@M
M/FAA<T-A<&%B:6QI='DH)W)E<V5T<&%S<W=O<F0G*2D@>PH@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*")#86YN;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($%U=&@Z.F=E
M=$QO9VEN4V-R965N*"<G+"!5=&EL.CIG971&;W)M1&%T82@G=7)L)RDI*3L*
M("`@(&5X:70["GT*"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A
M<FEA8FQE<R@I.PH*)'1I=&QE(#T@7R@B4F5S970@66]U<B!087-S=V]R9"(I
M.PHD9F]R;2`]("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)TAO<F1E4VEG;G5P
M1F]R;2<L("1V87)S+"`D=&ET;&4I.PHD9F]R;2T^<V5T0G5T=&]N<RA?*")#
M;VYT:6YU92(I*3L*"B\J(%-E="!U<"!T:&4@9FEE;&1S(&9O<B!T:&4@=7-E
M<FYA;64@86YD(&%L=&5R;F%T92!E;6%I;"X@*B\*)&9O<FTM/F%D9$AI9&1E
M;B@G)RP@)W5R;"<L("=T97AT)RP@9F%L<V4I.PHD=B`]("8D9F]R;2T^861D
M5F%R:6%B;&4H7R@B57-E<FYA;64B*2P@)W5S97)N86UE)RP@)W1E>'0G+"!T
M<G5E*3L*)'8M/G-E=$]P=&EO;B@G=')A8VMC:&%N9V4G+"!T<G5E*3L*)&9O
M<FTM/F%D9%9A<FEA8FQE*%\H(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(BDL
M("=E;6%I;"<L("=E;6%I;"<L('1R=64I.PHD8V%N7W9A;&ED871E(#T@9F%L
M<V4["@HO*B!)9B!A('5S97)N86UE(&AA<R!B965N('-U<'!L:65D('1R>2!F
M971C:&EN9R!T:&4@<')E9G,@<W1O<F5D(&EN9F\N("HO"FEF("@D=7-E<FYA
M;64@/2`D=F%R<RT^9V5T*"=U<V5R;F%M92<I*2!["B`@("`D=7-E<FYA;64@
M/2!!=71H.CIA9&1(;V]K*"1U<V5R;F%M92D["B`@("`D<')E9G,@/2`F4')E
M9G,Z.G-I;F=L971O;B@D8V]N9ELG<')E9G,G75LG9')I=F5R)UTL("=H;W)D
M92<L("1U<V5R;F%M92P@)R<L(&YU;&PL(&9A;'-E*3L*("`@("1P<F5F<RT^
M<F5T<FEE=F4H*3L*("`@("1E;6%I;"`]("1P<F5F<RT^9V5T5F%L=64H)V%L
M=&5R;F%T95]E;6%I;"<I.PH@("`@+RH@1&]E<R!T:&4@86QT97)N871E(&5M
M86EL('-T;W)E9"!I;B!P<F5F<R!M871C:"!T:&4@;VYE('-U8FUI='1E9#\@
M*B\*("`@(&EF("@D=F%R<RT^9V5T*"=E;6%I;"<I(#T]("1E;6%I;"D@>PH@
M("`@("`@("1C86Y?=F%L:61A=&4@/2!T<G5E.PH@("`@("`@("1F;W)M+3YS
M971"=71T;VYS*%\H(E)E<V5T(%!A<W-W;W)D(BDI.PH@("`@("`@("1Q=65S
M=&EO;B`]("1P<F5F<RT^9V5T5F%L=64H)W-E8W5R:71Y7W%U97-T:6]N)RD[
M"B`@("`@("`@)&9O<FTM/F%D9%9A<FEA8FQE*"1Q=65S=&EO;BP@)W%U97-T
M:6]N)RP@)V1E<V-R:7!T:6]N)RP@9F%L<V4I.PH@("`@("`@("1F;W)M+3YA
M9&1687)I86)L92A?*")!;G-W97(B*2P@)V%N<W=E<B<L("=T97AT)RP@=')U
M92D["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*
M?0H*+RH@5F%L:61A=&4@=&AE(&9O<FTN("HO"FEF("@D8V%N7W9A;&ED871E
M("8F("1F;W)M+3YV86QI9&%T92@D=F%R<RDI('L*("`@("1F;W)M+3YG971)
M;F9O*"1V87)S+"`D:6YF;RD["@H@("`@+RH@1F5T8V@@=F%L=65S(&9R;VT@
M<')E9G,@9F]R('-E;&5C=&5D('5S97(N("HO"B`@("`D86YS=V5R(#T@)'!R
M969S+3YG971686QU92@G<V5C=7)I='E?86YS=V5R)RD["@H@("`@+RH@0VAE
M8VL@=&AE(&=I=F5N('9A;'5E<R!W:71H="!T:&4@<')E9G,@<W1O<F5D(&]N
M97,N("HO"B`@("!I9B`H)&5M86EL(#T]("1I;F9O6R=E;6%I;"==("8F(%-T
M<FEN9SHZ;&]W97(H)&%N<W=E<BD@/3T@4W1R:6YG.CIL;W=E<B@D:6YF;ULG
M86YS=V5R)UTI*2!["B`@("`@("`@+RH@26YF;R!M871C:&5S+"!S;R!R97-E
M="!T:&4@<&%S<W=O<F0N("HO"B`@("`@("`@)'!A<W-W;W)D(#T@)&%U=&@M
M/G)E<V5T4&%S<W=O<F0H)&EN9F];)W5S97)N86UE)UTI.PH*("`@("`@("!R
M97%U:7)E7V]N8V4@)TUA:6PN<&AP)SL*("`@("`@("`D;6%I;&5R(#T@36%I
M;#HZ9F%C=&]R>2@D8V]N9ELG;6%I;&5R)UU;)W1Y<&4G72P@)&-O;F9;)VUA
M:6QE<B==6R=P87)A;7,G72D["@H@("`@("`@("\J(%-E="!U<"!T:&4@96UA
M:6P@:&5A9&5R<R!A;F0@8F]D>2X@*B\*("`@("`@("`D:&5A9&5R<ULG1G)O
M;2==(#T@)&5M86EL.PH@("`@("`@("1H96%D97)S6R=4;R==(#T@)&5M86EL
M.PH@("`@("`@("1R96-I<&EE;G1S6UT@/2`D:&5A9&5R<ULG5&\G73L*("`@
M("`@("`D:&5A9&5R<ULG4W5B:F5C="==(#T@7R@B66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="(I.PH@("`@("`@("1B;V1Y(#T@<W!R:6YT9BA?*")9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(BDL("1R96=I<W1R>2T^
M9V5T*"=N86UE)RP@)VAO<F1E)RDL("1P87-S=V]R9"D["B`@("`@("`@)&UA
M:6QE<BT^<V5N9"@D<F5C:7!I96YT<RP@)&AE861E<G,L("1B;V1Y*3L*"B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R!P87-S=V]R9"XB*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@
M("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@075T:#HZ9V5T3&]G:6Y38W)E
M96XH)R<L("1I;F9O6R=U<FPG72DI.PH@("`@("`@(&5X:70["B`@("!](&5L
M<V4@>PH@("`@("`@("\J($EN9F\@<W5B;6ET=&5D(&1O97,@;F]T(&UA=&-H
M('=H870@:7,@:6X@<')E9G,L(')E9&ER96-T('5S97(@8F%C:PH@("`@("`@
M("`J('1O(&QO9VEN+B`J+PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H
M7R@B0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E
M<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T
M(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(BDL("=H;W)D92YE<G)O
M<B<I.PH@("`@?0I]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH
M)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*<F5Q=6ER95]O;F-E("=(;W)D
M92]&;W)M+U)E;F1E<F5R+G!H<"<["B1R96YD97)E<B`]("9N97<@2&]R9&5?
M1F]R;5]296YD97)E<B@I.PHD9F]R;2T^<F5N9&5R06-T:79E*"1R96YD97)E
M<BP@)'9A<G,L("=R97-E='!A<W-W;W)D+G!H<"<L("=P;W-T)RD["G)E<75I
M<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P<F5F<RYP:'``````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`T-30@
M,3`U,34T,S0Q-#0@,#(Q,C$S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E
M<G9I8V5S+W!R969S+G!H<"QV(#$N,3DN,BXQ,"`R,#`V+S`R+S`W(#(S.C4P
M.C`P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H87)L
M97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O
M4')E9G,O54DN<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE
M=&]N*"D["@HO*B!&:6=U<F4@;W5T('=H:6-H(&%P<&QI8V%T:6]N('=E)W)E
M('-E='1I;F<@<')E9F5R96YC97,@9F]R+B`J+PHD87!P(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V%P<"<L(%!R969S7U5).CIG971$969A=6QT07!P*"DI.PHD
M87!P8F%S92`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I.PH*
M+RH@4V5E(&EF('=E(&AA=F4@82!P<F5F97)E;F-E<R!G<F]U<"!S970N("HO
M"B1G<F]U<"`](%5T:6PZ.F=E=$9O<FU$871A*"=G<F]U<"<I.PH*+RH@3&]A
M9"`D87!P)W,@8F%S92!E;G9I<F]N;65N="P@8G5T(&1O;B=T(')E<75E<W0@
M=&AA="!T:&4@87!P('!E<F9O<FT*("H@875T:&5N=&EC871I;VX@8F5Y;VYD
M($AO<F1E)W,N("HO"B1A=71H96YT:6-A=&EO;B`]("=N;VYE)SL*<F5Q=6ER
M95]O;F-E("1A<'!B87-E("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@4V5T('1I
M=&QE+B`J+PHD=&ET;&4@/2!S<')I;G1F*%\H(D]P=&EO;G,@9F]R("5S(BDL
M("1R96=I<W1R>2T^9V5T*"=N86UE)RDI.PH*+RH@4W!E8VEA;"!C87-E('=H
M97)E('=E(&YE960@=&AE($ED96YT:71Y(&]B:F5C="!I;B!(;W)D92=S('!R
M969S+G!H<"X@*B\*:68@*"1G<F]U<"`]/2`G:61E;G1I=&EE<R<@)B8@)&%P
M<"`]/2`G:&]R9&4G*2!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT
M:71Y+G!H<"<["B`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O
M;B@D87!P(#T]("=H;W)D92<@/R!N=6QL(#H@87)R87DH)&%P<"P@)&%P<"DI
M.PI]"@HO*B!,;V%D("1A<'`G<R!P<F5F97)E;F-E<RP@:68@86YY+B`J+PHD
M<')E9D=R;W5P<R`](&%R<F%Y*"D["FEF("AF:6QE7V5X:7-T<R@D87!P8F%S
M92`N("<O8V]N9FEG+W!R969S+G!H<"<I*2!["B`@("!R97%U:7)E("1A<'!B
M87-E("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*?0H*+RH@3&]A9"!C=7-T;VT@
M<')E9F5R96YC92!H86YD;&5R<R!F;W(@)&%P<"P@:68@<')E<V5N="X@*B\*
M:68@*&9I;&5?97AI<W1S*"1A<'!B87-E("X@)R]L:6(O<')E9G,N<&AP)RDI
M('L*("`@(')E<75I<F5?;VYC92`D87!P8F%S92`N("<O;&EB+W!R969S+G!H
M<"<["GT*"B\J($EF('1H97)E)W,@;VYL>2!O;F4@<')E9D=R;W5P+"!J=7-T
M('-H;W<@:70N("HO"FEF("AE;7!T>2@D9W)O=7`I("8F(&-O=6YT*"1P<F5F
M1W)O=7!S*2`]/2`Q*2!["B`@("`D9W)O=7`@/2!A<G)A>5]K97ES*"1P<F5F
M1W)O=7!S*3L*("`@("1G<F]U<"`](&%R<F%Y7W!O<"@D9W)O=7`I.PI]"@II
M9B`H)&=R;W5P(#T]("=I9&5N=&ET:65S)RD@>PH@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@)&ED96YT:71Y(#T@)DED96YT
M:71Y.CIS:6YG;&5T;VXH)&%P<"`]/2`G:&]R9&4G(#\@;G5L;"`Z(&%R<F%Y
M*"1A<'`L("1A<'`I*3L*("`@(&EF("@D87!P("$]("=H;W)D92<I('L*("`@
M("`@("!I9B`H571I;#HZ;F]N26YP=71687(H)W!R969'<F]U<',G*2D@>PH@
M("`@("`@("`@("`D:V5E<%!R969'<F]U<',@/2`D<')E9D=R;W5P<SL*("`@
M("`@("`@("`@=6YS970H)'!R969'<F]U<',I.PH@("`@("`@('T*("`@("`@
M("!R97%U:7)E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]P<F5F<RYP:'`G.PH@
M("`@("`@("1H;W)D95]M96UB97)S(#T@)'!R969'<F]U<'-;)VED96YT:71I
M97,G75LG;65M8F5R<R==.PH@("`@("`@(&EF("A5=&EL.CIN;VY);G!U=%9A
M<B@G:V5E<%!R969'<F]U<',G*2D@>PH@("`@("`@("`@("`D<')E9D=R;W5P
M<R`]("1K965P4')E9D=R;W5P<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!U;G-E="@D<')E9D=R;W5P<RD["B`@("`@("`@?0H@("`@?0H*("`@
M(&EF("AI<W-E="@D:&]R9&5?;65M8F5R<RDI('L*("`@("`@("`D<')E9D=R
M;W5P<ULG:61E;G1I=&EE<R==6R=M96UB97)S)UT@/2!A<G)A>5]M97)G92@D
M:&]R9&5?;65M8F5R<RP@)'!R969'<F]U<'-;)VED96YT:71I97,G75LG;65M
M8F5R<R==*3L*("`@('T*"B`@("!S=VET8V@@*%5T:6PZ.F=E=$9O<FU$871A
M*"=A8W1I;VY)1"<I*2!["B`@("!C87-E("=U<&1A=&5?<')E9G,G.@H@("`@
M("`@(&EF("@D<')E9G,M/FES3&]C:V5D*"=D969A=6QT7VED96YT:71Y)RDI
M('L*("`@("`@("`@("`@)&1E9F%U;'0@/2`D:61E;G1I='DM/F=E=$1E9F%U
M;'0H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&5F875L="`]
M(%5T:6PZ.F=E=%!O<W0H)V1E9F%U;'1?:61E;G1I='DG*3L*("`@("`@("`@
M("`@)&ED(#T@571I;#HZ9V5T4&]S="@G:61E;G1I='DG*3L*("`@("`@("`@
M("`@:68@*"1I9"`]/2`M,2D@>PH@("`@("`@("`@("`@("`@)&ED(#T@)&ED
M96YT:71Y+3YA9&0H*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1I9"`]/2`M
M,BD@>PH@("`@("`@("`@("`@("`@)'!R969'<F]U<'-;)VED96YT:71I97,G
M75LG;65M8F5R<R==(#T@87)R87DH)V1E9F%U;'1?:61E;G1I='DG*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:61E;G1I='DM/G-E=$1E9F%U;'0H
M)&ED*3L*("`@("`@("!]"B`@("`@("`@:68@*%!R969S7U5).CIH86YD;&5&
M;W)M*"1G<F]U<"P@)&ED96YT:71Y*2D@>PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)&ED96YT:71Y+3YV97)I9GDH*3L*("`@("`@("`@("`@)&ED96YT:71Y
M+3YS971$969A=6QT*"1D969A=6QT*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"@D<F5S=6QT+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I9&5N=&ET>2T^
M<V%V92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&ED96YT:71Y+3YS971$969A=6QT*"1D969A=6QT*3L*("`@("`@
M("`@("`@)&ED96YT:71Y+3YS879E*"D["B`@("`@("`@?0H@("`@("`@('5N
M<V5T*"1P<F5F1W)O=7!S*3L*("`@("`@("!R97%U:7)E("1A<'!B87-E("X@
M)R]C;VYF:6<O<')E9G,N<&AP)SL*("`@("`@("!B<F5A:SL*"B`@("!C87-E
M("=D96QE=&5?:61E;G1I='DG.@H@("`@("`@("1I9"`]("AI;G0I571I;#HZ
M9V5T1F]R;41A=&$H)VED)RD["B`@("`@("`@)&1E;&5T961?:61E;G1I='D@
M/2`D:61E;G1I='DM/F1E;&5T92@D:60I.PH@("`@("`@('5N<V5T*"1?<')E
M9G-;)V1E9F%U;'1?:61E;G1I='DG75LG96YU;2==6R1I9%TI.PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@:61E;G1I='D@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(BDL("1D96QE=&5D7VED96YT:71Y
M6S!=6R=I9"==*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!B<F5A:SL*
M"B`@("!C87-E("=C:&%N9V5?9&5F875L=%]I9&5N=&ET>2<Z"B`@("`@("`@
M)&1E9F%U;'1?:61E;G1I='D@/2`D:61E;G1I='DM/G-E=$1E9F%U;'0H571I
M;#HZ9V5T1F]R;41A=&$H)VED)RDI.PH@("`@("`@("1I9&5N=&ET>2T^<V%V
M92@I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U<B!D969A
M=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@(&)R
M96%K.PH@("`@?0I](&5L<V5I9B`H4')E9G-?54DZ.FAA;F1L949O<FTH)&=R
M;W5P+"`D<')E9G,I*2!["B`@("!R97%U:7)E("1A<'!B87-E("X@)R]C;VYF
M:6<O<')E9G,N<&AP)SL*?0H*+RH@4VAO=R!T:&4@54DN("HO"E!R969S7U5)
M.CIG96YE<F%T955)*"1G<F]U<"D["@IR97%U:7)E("1R96=I<W1R>2T^9V5T
M*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI;F,G
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V=O+G!H<```````````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-38U,"`Q,#4Q-30S-#$T
M-"`P,C`U,#,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($$@<V-R:7!T('1O(')E9&ER96-T('1O(&$@
M9VEV96X@55),+"!U<V5D(&9O<B!E>&%M<&QE(&EN($E-4"!T;R!H:61E(&%N
M>0H@*B!R969E<G)E<B!D871A(&)E:6YG('!A<W-E9"!T;R!T:&4@<F5M;W1E
M('-E<G9E<B!A;F0@<&]T96YT:6%L;'D@97AP;W-I;F<*("H@86YY('-E<W-I
M;VX@241S+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI
M8R`\;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z
M(&AO<F1E+W-E<G9I8V5S+V=O+G!H<"QV(#$N-BXR+C$V(#(P,#8O,#8O,C(@
M,#(Z-#,Z,C0@8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K
M:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B\*"FEF("AE;7!T>2@D7T=%5%LG=7)L
M)UTI*2!["B`@("!E>&ET.PI]"@HD=7)L(#T@=')I;2@D7T=%5%LG=7)L)UTI
M.PII9B`H<')E9U]M871C:"@G+SM<<RIU<FQ<<RH]+VDG+"`D=7)L*2D@>PH@
M("`@+RH@244@=VEL;"!P<F]C97-S('1H92!L87-T(#M54DP]('-T<FEN9RP@
M;F]T('1H92!F:7)S="P@86QL;W=I;F<*("`@("`J('!R;W1O8V]L<R!T:&%T
M('-H;W5L9&XG="!B92!L970@=&AR;W5G:"X@*B\*("`@(&5X:70["GT*"FEF
M("AG971?;6%G:6-?<75O=&5S7V=P8R@I*2!["B`@("`D<&%R<V5D7W5R;"`]
M($!P87)S95]U<FPH<W1R:7!S;&%S:&5S*"1U<FPI*3L*?2!E;'-E('L*("`@
M("1P87)S961?=7)L(#T@0'!A<G-E7W5R;"@D=7)L*3L*?0H*:68@*&5M<'1Y
M*"1P87)S961?=7)L*2!\?"!E;7!T>2@D<&%R<V5D7W5R;%LG:&]S="==*2D@
M>PH@("`@97AI=#L*?0II9B`H96UP='DH)'!A<G-E9%]U<FQ;)W!A=&@G72DI
M('L*("`@("1P87)S961?=7)L6R=P871H)UT@/2!F86QS93L*?0H*+R\@1&\@
M82!L:71T;&4@9'5E(&1I;&EG96YC92!O;B!T:&4@=&%R9V5T(%523"X@268@
M:70G<R!O;B!T:&4@<V%M92!S97)V97(*+R\@=&AA="!W92=R92!A;')E861Y
M(&]N+"!D:7-P;&%Y(&%N(&EN=&5R;65D:6%T92!P86=E(&%S:VEN9R!P96]P
M;&4@:68*+R\@=&AE>2=R92!S=7)E('1H97D@=V%N="!T;R!C;&EC:R!T:')O
M=6=H+@II9B`H<W5B<W1R*'!H<%]S87!I7VYA;64H*2P@,"P@,RD@/3T@)V-G
M:2<I('L*("`@("\O(%=H96X@=7-I;F<@0T=)(%!(4"P@4T-225!47TY!344@
M;6%Y(&-O;G1A:6X@=&AE('!A=&@@=&\@=&AE(%!(4"!B:6YA<GD*("`@("\O
M(&EN<W1E860@;V8@=&AE('-C<FEP="!B96EN9R!R=6X[('5S92!02%!?4T5,
M1B!I;G-T96%D+@H@("`@)&UY=7)L(#T@)%]315)615);)U!(4%]314Q&)UT[
M"GT@96QS92!["B`@("`D;7EU<FP@/2!I<W-E="@D7U-%4E9%4ELG4T-225!4
M7TY!344G72D@/PH@("`@("`@("1?4T525D526R=30U))4%1?3D%-12==(#H*
M("`@("`@("`D7U-%4E9%4ELG4$A07U-%3$8G73L*?0HO+R`Q-B!I<R!T:&4@
M;&5N9W1H(&]F("(O<V5R=FEC97,O9V\N<&AP(BX*)'=E8G)O;W0@/2!S=6)S
M='(H)&UY=7)L+"`P+"`M,38I.PH*+R\@0G5I;&0@82!L:7-T(&]F(&AO<W1S
M(&-O;G-I9&5R960@9&%N9V5R;W5S("AL;V-A;"!H;W-T<RP@=&AE('5S97(G
M<PHO+R!H;W-T+"!E=&,I+@HD9&%N9V5R;W5S7VAO<W1S(#T@87)R87DH)VQO
M8V%L:&]S="<L("=L;V-A;&AO<W0N;&]C86QD;VUA:6XG+"`G,3(W+C`N,"XQ
M)RD["FEF("@A96UP='DH)%]315)615);)U-%4E9%4E].04U%)UTI*2!["B`@
M("`D9&%N9V5R;W5S7VAO<W1S6UT@/2`D7U-%4E9%4ELG4T525D527TY!344G
M73L*?0II9B`H(65M<'1Y*"1?4T525D526R=(5%107TA/4U0G72DI('L*("`@
M("1D86YG97)O=7-?:&]S='-;72`]("1?4T525D526R=(5%107TA/4U0G73L*
M?0H*+R\@3&ES="!O9B!A;&QO=V5D('-E<G9I8V5S+@HD86QL;W=E9%]U<FES
M(#T@87)R87DH*3L*"B\O($-H96-K(&%G86EN<W0@;W5R(&QI<W1S+@II9B`H
M*&5M<'1Y*"1W96)R;V]T*2!\?"!S=')P;W,H)'!A<G-E9%]U<FQ;)W!A=&@G
M72P@)'=E8G)O;W0I(#T]/2`P*2`F)@H@("`@(65M<'1Y*"1P87)S961?=7)L
M6R=Q=65R>2==*2`F)@H@("`@(6EN7V%R<F%Y*"1P87)S961?=7)L6R=P871H
M)UTL("1A;&QO=V5D7W5R:7,I("8F"B`@("!I;E]A<G)A>2@D<&%R<V5D7W5R
M;%LG:&]S="==+"`D9&%N9V5R;W5S7VAO<W1S*2D@>PH_/@H\:'1M;#X*/&AE
M860^"CQT:71L93Y0;W1E;G1I86QL>2!$86YG97)O=7,@55),/"]T:71L93X*
M/"]H96%D/@H\8F]D>3X*(#QH,3Y0;W1E;G1I86QL>2!$86YG97)O=7,@55),
M/"]H,3X*"B`\<#X*("!!(')E9F5R<FEN9R!S:71E+"!A;B!E;6%I;"!Y;W4@
M=V5R92!R96%D:6YG+"!O<B!S;VUE(&]T:&5R"B`@<&]T96YT:6%L;'D@=6YT
M<G5S=&5D('-O=7)C92!H87,@871T96UP=&5D('1O('-E;F0@>6]U('1O(#P_
M<&AP(&5C:&\*("!H=&UL<W!E8VEA;&-H87)S*"1U<FPI(#\^+B!4:&ES(&UA
M>2!B92!A;B!A='1E;7!T('1O"B`@9&5L971E(&1A=&$@;W(@8VAA;F=E('-E
M='1I;F=S('=I=&AO=70@>6]U<B!K;F]W;&5D9V4N($EF"B`@>6]U(&AA=F4@
M86YY(&-O;F-E<FYS(&%B;W5T('1H:7,@55),+"!P;&5A<V4@8V]N=&%C="!Y
M;W5R"B`@4WES=&5M($%D;6EN:7-T<F%T;W(N($EF('EO=2!A<F4@8V]N9FED
M96YT('1H870@:70@:7,@<V%F92P*("!Y;W4@;6%Y(&9O;&QO=R!T:&4@;&EN
M:R!B>2!C;&EC:VEN9R!B96QO=RX*(#PO<#X*"B`\<#X*("`\82!H<F5F/2(\
M/W!H<"!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'5R;"D@/SXB/CP_<&AP(&5C
M:&\@:'1M;'-P96-I86QC:&%R<R@D=7)L*2`_/CPO83X*(#PO<#X*"CPO8F]D
M>3X*/"]H=&UL/@H\/W!H<`H@("`@97AI=#L*?0H*:&5A9&5R*"=2969R97-H
M.B`P.R!54DP])R`N("1U<FPI.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O<')O8FQE;2YP:'``````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$R-38V(#$P-3$U-#,T,30T(#`R,34T,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P<F]B;&5M+G!H<"QV(#(N,3$T
M+C@N."`R,#`V+S`Q+S$V(#$T.C(T.C`S(&-H=6-K($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E
M(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*B!396YD('1H
M92!B<F]W<V5R(&)A8VL@=&\@=&AE(&-O<G)E8W0@<&%G92X@*B\*9G5N8W1I
M;VX@7W)E='5R;E1O4&%G92@I"GL*("`@("1U<FP@/2!5=&EL.CIG971&;W)M
M1&%T82@G<F5T=7)N7W5R;"<L($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES
M=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]L;V=I;BYP:'`G
M+"!T<G5E*2D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@<W1R7W)E<&QA
M8V4H)R9A;7`[)RP@)R8G+"`D=7)L*2D["B`@("!E>&ET.PI]"@I`9&5F:6YE
M*"=!551(7TA!3D1,15(G+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E($A/4D1%
M7T)!4T4@+B`G+VQI8B]V97)S:6]N+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O261E;G1I='DN<&AP)SL*"FEF("@A2&]R9&4Z.G-H;W=397)V:6-E*"=P
M<F]B;&5M)RDI('L*("`@(%]R971U<FY4;U!A9V4H*3L*?0H*)&ED96YT:71Y
M(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*)&5M86EL(#T@)&ED96YT:71Y
M+3YG971686QU92@G9G)O;5]A9&1R)RD["FEF("@A)&5M86EL*2!["B`@("`D
M96UA:6P@/2!5=&EL.CIG971&;W)M1&%T82@G96UA:6PG+"!!=71H.CIG971!
M=71H*"DI.PI]"B1M97-S86=E(#T@571I;#HZ9V5T1F]R;41A=&$H)VUE<W-A
M9V4G+"`G)RD["B1N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)VYA;64G+"`D
M:61E;G1I='DM/F=E=%9A;'5E*"=F=6QL;F%M92<I*3L*)'-U8FIE8W0@/2!5
M=&EL.CIG971&;W)M1&%T82@G<W5B:F5C="<L("<G*3L*"B1A8W1I;VY)1"`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=A8W1I;VY)1"<I.PIS=VET8V@@*"1A8W1I
M;VY)1"D@>PIC87-E("=S96YD7W!R;V)L96U?<F5P;W)T)SH*("`@(&EF("@D
M<W5B:F5C="`F)B`D;65S<V%G92D@>PH@("`@("`@("\O(%1H:7,@:7,@;F]T
M(&$@9V5T=&5X="!S=')I;F<@;VX@<'5R<&]S92X*("`@("`@("`D<F5M;W1E
M(#T@*"%E;7!T>2@D7U-%4E9%4ELG4D5-3U1%7TA/4U0G72DI(#\@)%]315)6
M15);)U)%34]415](3U-4)UT@.B`D7U-%4E9%4ELG4D5-3U1%7T%$1%(G73L*
M("`@("`@("`D=7-E<E]A9V5N="`]("1?4T525D526R=(5%107U5315)?04=%
M3E0G73L*("`@("`@("`D8F]D>2`](")4:&ES('!R;V)L96T@<F5P;W)T('=A
M<R!R96-E:79E9"!F<F]M("1R96UO=&4N("(@+@H@("`@("`@("`@("`B5&AE
M('5S97(@8VQI8VME9"!T:&4@<')O8FQE;2!R97!O<G0@;&EN:R!F<F]M('1H
M92!F;VQL;W=I;F<@;&]C871I;VXZ7&XB("X*("`@("`@("`@("`@571I;#HZ
M9V5T1F]R;41A=&$H)W)E='5R;E]U<FPG+"`G3F\@<F5Q=65S=&EN9R!P86=E
M)RD@+@H@("`@("`@("`@("`B7&YA;F0@:7,@=7-I;F<@=&AE(&9O;&QO=VEN
M9R!B<F]W<V5R.EQN)'5S97)?86=E;G1<;EQN(B`N"B`@("`@("`@("`@('-T
M<E]R97!L86-E*")<<EQN(BP@(EQN(BP@)&UE<W-A9V4I.PH*("`@("`@("`O
M+R!$969A=6QT('1O(&$@<F5L871I=F5L>2!R96%S;VYA8FQE(&5M86EL(&%D
M9')E<W,N"B`@("`@("`@:68@*"$D96UA:6PI('L*("`@("`@("`@("`@)&5M
M86EL(#T@)VAO<F1E+7!R;V)L96U`)R`N("1C;VYF6R=P<F]B;&5M<R==6R=M
M86EL9&]M86EN)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C
M;VYF6R=P<F]B;&5M<R==6R=T:6-K971S)UTI("8F"B`@("`@("`@("`@("1R
M96=I<W1R>2T^:&%S365T:&]D*"=T:6-K971S+V%D9%1I8VME="<I*2!["B`@
M("`@("`@("`@("1I;F9O(#T@87)R87E?;65R9V4H)&-O;F9;)W!R;V)L96US
M)UU;)W1I8VME=%]P87)A;7,G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G<W5M;6%R>2<@/3X@)'-U8FIE8W0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;6UE;G0G(#T^("1B
M;V1Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<V5R7V5M86EL)R`]/B`D96UA:6PI*3L*("`@("`@("`@("`@)')E<W5L="`]
M("1R96=I<W1R>2T^8V%L;"@G=&EC:V5T<R]A9&14:6-K970G+"!A<G)A>2@D
M:6YF;RDI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*"1R97-U;'0I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@7W)E='5R;E1O4&%G92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H
M<"<["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12](96%D
M97)S+G!H<"<["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-
M12]-97-S86=E+G!H<"<["@H@("`@("`@("`@("`O+R!!9&0@=7-E<B=S(&YA
M;64@=&\@=&AE(&5M86EL(&%D9')E<W,@:68@<')O=FED960N"B`@("`@("`@
M("`@(&EF("@D;F%M92D@>PH@("`@("`@("`@("`@("`@0&QI<W0H)&UA:6QB
M;W@L("1H;W-T*2`]($!E>'!L;V1E*"=`)RP@)&5M86EL+"`R*3L*("`@("`@
M("`@("`@("`@(&EF("AE;7!T>2@D:&]S="DI('L*("`@("`@("`@("`@("`@
M("`@("`D:&]S="`]("1C;VYF6R=P<F]B;&5M<R==6R=M86EL9&]M86EN)UT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D96UA:6P@/2!-
M24U%.CIR9F,X,C)7<FET94%D9')E<W,H)&UA:6QB;W@L("1H;W-T+"`D;F%M
M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1M<V=?:&5A9&5R<R`]
M("9N97<@34E-15](96%D97)S*"D["B`@("`@("`@("`@("1M<V=?:&5A9&5R
M<RT^861D4F5C96EV961(96%D97(H*3L*("`@("`@("`@("`@)&US9U]H96%D
M97)S+3YA9&1-97-S86=E261(96%D97(H*3L*("`@("`@("`@("`@)&US9U]H
M96%D97)S+3YA9&1!9V5N=$AE861E<B@I.PH@("`@("`@("`@("`D;7-G7VAE
M861E<G,M/F%D9$AE861E<B@G1&%T92<L(&1A=&4H)W(G*2D["B`@("`@("`@
M("`@("1M<V=?:&5A9&5R<RT^861D2&5A9&5R*"=4;R<L("1C;VYF6R=P<F]B
M;&5M<R==6R=E;6%I;"==*3L*("`@("`@("`@("`@)&US9U]H96%D97)S+3YA
M9&1(96%D97(H)U-U8FIE8W0G+"!?*");4')O8FQE;2!297!O<G1=(BD@+B`G
M("<@+B`D<W5B:F5C="D["B`@("`@("`@("`@("1M<V=?:&5A9&5R<RT^861D
M2&5A9&5R*"=&<F]M)RP@)&5M86EL*3L*("`@("`@("`@("`@)&US9U]H96%D
M97)S+3YA9&1(96%D97(H)U-E;F1E<B<L("=H;W)D92UP<F]B;&5M0"<@+B`D
M8V]N9ELG<')O8FQE;7,G75LG;6%I;&1O;6%I;B==*3L*"B`@("`@("`@("`@
M("1M:6UE(#T@)FYE=R!-24U%7TUE<W-A9V4H*3L*("`@("`@("`@("`@)&UI
M;64M/F%D9%!A<G0H;F5W($U)345?4&%R="@G=&5X="]P;&%I;B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4W1R:6YG.CIW
M<F%P*"1B;V1Y+"`X,"P@(EQN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@3DQ3.CIG971#:&%R<V5T*"DI*3L*("`@("`@
M("`@("`@)&US9U]H96%D97)S+3YA9&1-24U%2&5A9&5R<R@D;6EM92D["@H@
M("`@("`@("`@("`D;6%I;%]D<FEV97(@/2`D8V]N9ELG;6%I;&5R)UU;)W1Y
M<&4G73L*("`@("`@("`@("`@)&UA:6Q?<&%R86US(#T@)&-O;F9;)VUA:6QE
M<B==6R=P87)A;7,G73L*("`@("`@("`@("`@:68@*"1M86EL7V1R:79E<B`]
M/2`G<VUT<"<@)B8@)&UA:6Q?<&%R86US6R=A=71H)UT@)B8*("`@("`@("`@
M("`@("`@(&5M<'1Y*"1M86EL7W!A<F%M<ULG=7-E<FYA;64G72DI('L*("`@
M("`@("`@("`@("`@(&EF("A!=71H.CIG971!=71H*"DI('L*("`@("`@("`@
M("`@("`@("`@("`D;6%I;%]P87)A;7-;)W5S97)N86UE)UT@/2!!=71H.CIG
M971!=71H*"D["B`@("`@("`@("`@("`@("`@("`@)&UA:6Q?<&%R86US6R=P
M87-S=V]R9"==(#T@075T:#HZ9V5T0W)E9&5N=&EA;"@G<&%S<W=O<F0G*3L*
M("`@("`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)&-O;F9;)W!R;V)L
M96US)UU;)W5S97)N86UE)UTI("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(65M<'1Y*"1C;VYF6R=P<F]B;&5M<R==6R=P87-S=V]R9"==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1M86EL7W!A<F%M<ULG=7-E<FYA;64G72`]
M("1C;VYF6R=P<F]B;&5M<R==6R=U<V5R;F%M92==.PH@("`@("`@("`@("`@
M("`@("`@("1M86EL7W!A<F%M<ULG<&%S<W=O<F0G72`]("1C;VYF6R=P<F]B
M;&5M<R==6R=P87-S=V]R9"==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES7V$H)'-E;G0@/2`D;6EM92T^
M<V5N9"@D8V]N9ELG<')O8FQE;7,G75LG96UA:6PG72P@)&US9U]H96%D97)S
M+"`D;6%I;%]D<FEV97(L("1M86EL7W!A<F%M<RDL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("\J(%=E('-U8V-E961E9"X@4F5T=7)N('1O
M('!R979I;W5S('!A9V4@86YD(&5X:70@=&AI<R!S8W)I<'0N("HO"B`@("`@
M("`@("`@("`@("!?<F5T=7)N5&]086=E*"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1S96YT
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*
M8V%S92`G8V%N8V5L7W!R;V)L96U?<F5P;W)T)SH*("`@(%]R971U<FY4;U!A
M9V4H*3L*?0H*)'1I=&QE(#T@7R@B4')O8FQE;2!$97-C<FEP=&EO;B(I.PHD
M;65N=2`]("9N97<@365N=2A(3U)$15]-14Y57TU!4TM?04Q,("8@?DA/4D1%
M7TU%3E5?34%32U]04D5&4RD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]M96YU+VUE;G4N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R
M<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["G)E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]P<F]B;&5M+W!R;V)L96TN:6YC)SL*<F5Q=6ER92!(
M3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:&5L<"]I;F1E>"YP:'``
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-30U(#$P
M-3$U-#,T,30T(#`R,C$T,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<"QV(#(N.#`N,3`N.2`R,#`V+S`W+S`V(#(R
M.C(X.C`R(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N
M+B\N+B<I.PI`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*"G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+TAE;'`N<&AP)SL*"B1T:71L92`](%\H(DAE;'`B*3L*
M)'-H;W<@/2!3=')I;F<Z.FQO=V5R*%5T:6PZ.F=E=$9O<FU$871A*"=S:&]W
M)RP@)VEN9&5X)RDI.PHD;6]D=6QE(#T@4W1R:6YG.CIL;W=E<BAP<F5G7W)E
M<&QA8V4H)R]<5R\G+"`G)RP@571I;#HZ9V5T1F]R;41A=&$H)VUO9'5L92<L
M("=H;W)D92<I*2D["B1T;W!I8R`](%5T:6PZ.F=E=$9O<FU$871A*"=T;W!I
M8R<I.PH*:68@*"1M;V1U;&4@/3T@)V%D;6EN)RD@>PH@("`@)&9I;&5R;V]T
M(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RD["B`@("`D:&5L<%]F:6QE
M(#T@)&9I;&5R;V]T("X@(B]A9&UI;B]L;V-A;&4O)&QA;F=U86=E+VAE;'`N
M>&UL(CL*("`@("1H96QP7V9I;&5?9F%L;&)A8VL@/2`D9FEL97)O;W0@+B`G
M+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM;"<["GT@96QS92!["B`@("`D
M9FEL97)O;W0@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D;6]D=6QE
M*3L*("`@("1H96QP7V9I;&4@/2`D9FEL97)O;W0@+B`B+VQO8V%L92\D;&%N
M9W5A9V4O:&5L<"YX;6PB.PH@("`@)&AE;'!?9FEL95]F86QL8F%C:R`]("1F
M:6QE<F]O="`N("<O;&]C86QE+V5N7U53+VAE;'`N>&UL)SL*?0H*:68@*"1S
M:&]W(#T]("=I;F1E>"<I('L*("`@("1B87-E7W5R;"`]("1R96=I<W1R>2T^
M9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VAE;'`O)SL*
M("`@("1M86EN7W5R;"`]($AO<F1E.CIU<FPH)&)A<V5?=7)L*3L*("`@("1M
M86EN7W5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D;6%I;E]U<FPL(&%R<F%Y
M*"=S:&]W)R`]/B`G96YT<GDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUO9'5L92<@/3X@)&UO9'5L
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T;W!I8R<@/3X@)'1O<&EC*2D["B`@("`D;65N=5]U<FP@
M/2!(;W)D93HZ=7)L*"1B87-E7W5R;"D["B`@("`D;65N=5]U<FP@/2!5=&EL
M.CIA9&1087)A;65T97(H)&UE;G5?=7)L+"!A<G)A>2@G;6]D=6QE)R`]/B`D
M;6]D=6QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-H;W<G(#T^("=M96YU)RDI.PH@("`@<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+VAE;'`O:6YD97@N:6YC)SL*("`@(&5X
M:70["GT*"B1B;V1Y0VQA<W,@/2`G:&5L<"<["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["FEF("@D<VAO=R`]/2`G
M;65N=2<I('L*("`@("\J(%-E="!U<"!U<FQS+B`J+PH@("`@)'5R;"`]($AO
M<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M("<O<V5R=FEC97,O:&5L<"\G*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)'5R;"P@)VUO9'5L92<L("1M;V1U;&4I.PH@("`@)'1O<&EC<U]L
M:6YK(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=S:&]W)RP@)W1O<&EC
M<R<I.PH@("`@)'1O<&EC<U]L:6YK(#T@2&]R9&4Z.FQI;FLH)'1O<&EC<U]L
M:6YK+"!N=6QL+"`G:&5A9&5R)RP@)VAE;'!?;6%I;B<I("X@7R@B3&ES="!(
M96QP(%1O<&EC<R(I("X@)SPO83XG.PH@("`@)&%B;W5T7VQI;FL@/2!5=&EL
M.CIA9&1087)A;65T97(H)'5R;"P@)W-H;W<G+"`G86)O=70G*3L*("`@("1A
M8F]U=%]L:6YK(#T@2&]R9&4Z.FQI;FLH)&%B;W5T7VQI;FLL(&YU;&PL("=H
M96%D97(G+"`G:&5L<%]M86EN)RD@+B!?*")!8F]U="XN+B(I("X@)SPO83XG
M.PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+VAE;'`O;65N=2YI
M;F,G.PI](&5L<V5I9B`H)'-H;W<@/3T@)V%B;W5T)RD@>PH@("`@<F5Q=6ER
M92`D9FEL97)O;W0@+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`D;6]D7W9E
M<G-I;VY?8V]N<W1A;G0@/2!3=')I;F<Z.G5P<&5R*"1M;V1U;&4I("X@)U]6
M15)324].)SL*("`@(&EF("@A9&5F:6YE9"@D;6]D7W9E<G-I;VY?8V]N<W1A
M;G0I*2!["B`@("`@("`@97AI=#L*("`@('T*("`@("1V97)S:6]N(#T@4W1R
M:6YG.CIU8V9I<G-T*"1M;V1U;&4I("X@)R`G("X@8V]N<W1A;G0H)&UO9%]V
M97)S:6]N7V-O;G-T86YT*3L*("`@("1C<F5D:71S(#T@571I;#HZ8G5F9F5R
M3W5T<'5T*"=I;F-L=61E)RP@)&9I;&5R;V]T("X@)R]D;V-S+T-2141)5%,G
M*3L*("`@("1C<F5D:71S(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D8W)E
M9&ET<RP@)VES;RTX.#4Y+3$G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("!R
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O:&5L<"]A8F]U="YI;F,G.PI]
M(&5L<V4@>PH@("`@)&AE;'`@/2`F;F5W($AE;'`H2$5,4%]33U520T5?1DE,
M12P@87)R87DH)&AE;'!?9FEL92P@)&AE;'!?9FEL95]F86QL8F%C:RDI.PH@
M("`@:68@*"@D<VAO=R`]/2`G96YT<GDG*2`F)B`A96UP='DH)'1O<&EC*2D@
M>PH@("`@("`@("1H96QP+3YL;V]K=7`H)'1O<&EC*3L*("`@("`@("`D:&5L
M<"T^9&ES<&QA>2@I.PH@("`@?2!E;'-E('L*("`@("`@("`D=&]P:6-S(#T@
M)&AE;'`M/G1O<&EC<R@I.PH@("`@("`@(&9O<F5A8V@@*"1T;W!I8W,@87,@
M)&ED(#T^("1T:71L92D@>PH@("`@("`@("`@("`D;&EN:R`]($AO<F1E.CIU
M<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R
M=FEC97,O:&5L<"\G*3L*("`@("`@("`@("`@)&QI;FL@/2!5=&EL.CIA9&10
M87)A;65T97(H)&QI;FLL(&%R<F%Y*"=S:&]W)R`]/B`G96YT<GDG+"`G;6]D
M=6QE)R`]/B`D;6]D=6QE+"`G=&]P:6,G(#T^("1I9"DI.PH@("`@("`@("`@
M("!E8VAO($AO<F1E.CIL:6YK*"1L:6YK*3L*("`@("`@("`@("`@96-H;R`D
M=&ET;&4@+B`B/"]A/CQB<B`O/EQN(CL*("`@("`@("!]"B`@("!]"B`@("`D
M:&5L<"T^8VQE86YU<"@I.PI]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'``````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S0Q,R`Q
M,#4Q-30S-#$T-"`P,C,V-38`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<"QV(#$N,3DN,3`N-"`R,#`V
M+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)'1I=&QE(#T@7R@B0V]L
M;W(@4&EC:V5R(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM
M;VXM:&5A9&5R+FEN8R<["@HD9F]R;2`](%5T:6PZ.F=E=$9O<FU$871A*"=F
M;W)M)RD["B1T87)G970@/2!5=&EL.CIG971&;W)M1&%T82@G=&%R9V5T)RD[
M"@IE8VAO($AO<F1E.CII;6<H)V-O;&]R<V-A;&4N<&YG)RP@)R<L("=I9#TB
M8V]L;W)P:6-K97(B(&]N8VQI8VL](F-H86YG94-O;&]R*&=E=$-O;&]R*&5V
M96YT*2D[(')E='5R;B!F86QS93LB(&]N;6]U<V5M;W9E/2)D96UO0V]L;W(H
M9V5T0V]L;W(H979E;G0I*3L@<F5T=7)N(&9A;'-E.R(@<W1Y;&4](F-U<G-O
M<CIC<F]S<VAA:7([8F%C:V=R;W5N9"UC;VQO<CIW:&ET93MP861D:6YG.C%P
M>"(G*3L*/SX*"CQD:78@:60](F-O;&]R1&5M;R(@<W1Y;&4](F)A8VMG<F]U
M;F0M8V]L;W(Z=VAI=&4[=VED=&@Z,3`P<'@[:&5I9VAT.C(P<'@[<&%D9&EN
M9SHQ<'@B/CPO9&EV/@H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^
M"CPA+2T*9G5N8W1I;VX@8VAA;F=E0V]L;W(H8V]L;W(I"GL*("`@(&EF("AP
M87)E;G0N;W!E;F5R+F-L;W-E9"D@>PH@("`@("`@(&%L97)T*"(\/W!H<"!E
M8VAO(&%D9'-L87-H97,H7R@B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N(BDI(#\^(BD["B`@("`@("`@=&AI<RYC;&]S92@I.PH@
M("`@("`@(')E='5R;CL*("`@('T*"B`@("!I9B`H(7!A<F5N="YO<&5N97(N
M9&]C=6UE;G0N/#]P:'`@96-H;R`D9F]R;2`_/BD@>PH@("`@("`@(&%L97)T
M*"(\/W!H<"!E8VAO(&%D9'-L87-H97,H7R@B5&AI<R!W:6YD;W<@;75S="!B
M92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(I*2`_/B(I.PH@("`@
M("`@('1H:7,N8VQO<V4H*3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@
M<&%R96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E8VAO("1F;W)M(#\^6R(\
M/W!H<"!E8VAO("1T87)G970@/SXB72YV86QU92`](&-O;&]R.PH@("`@<&%R
M96YT+F]P96YE<BYD;V-U;65N="X\/W!H<"!E8VAO("1F;W)M(#\^6R(\/W!H
M<"!E8VAO("1T87)G970@/SXB72YS='EL92YB86-K9W)O=6YD0V]L;W(@/2!C
M;VQO<CL*("`@('!A<F5N="YO<&5N97(N9&]C=6UE;G0N/#]P:'`@96-H;R`D
M9F]R;2`_/ELB/#]P:'`@96-H;R`D=&%R9V5T(#\^(ETN<W1Y;&4N8V]L;W(@
M/2!B<FEG:'1N97-S*&-O;&]R*2`\(#$R."`_("=W:&ET92<@.B`G8FQA8VLG
M.PH*("`@('1H:7,N8VQO<V4H*3L*?0H*9G5N8W1I;VX@9&5M;T-O;&]R*&-O
M;&]R*0I["B`@("!V87(@=&%R9V5T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H)V-O;&]R1&5M;R<I.PH@("`@=&%R9V5T+G-T>6QE+F)A8VMG<F]U;F1#
M;VQO<B`](&-O;&]R.PH@("`@=&%R9V5T+G-T>6QE+F-O;&]R(#T@8G)I9VAT
M;F5S<RAC;VQO<BD@/"`Q,C@@/R`G=VAI=&4G(#H@)V)L86-K)SL*("`@('1A
M<F=E="YI;FYE<DA434P@/2!C;VQO<CL*?0H*9G5N8W1I;VX@9V5T0V]L;W(H
M979E;G0I"GL*("`@('9A<B!I;6<@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@G8V]L;W)P:6-K97(G*3L*"B`@("!V87(@>"`](&5V96YT+F-L:65N=%@@
M+2`Q,#L*("`@('9A<B!Y(#T@979E;G0N8VQI96YT62`M(#$P.PH*("`@('9A
M<B!R;6%X(#T@,#L*("`@('9A<B!G;6%X(#T@,#L*("`@('9A<B!B;6%X(#T@
M,#L*"B`@("!I9B`H>2`\/2`S,BD@>PH@("`@("`@(')M87@@/2`R-34["B`@
M("`@("`@9VUA>"`]("AY("\@,S(N,"D@*B`R-34["B`@("`@("`@8FUA>"`]
M(#`["B`@("!](&5L<V4@:68@*'D@/#T@-C0I('L*("`@("`@("!Y(#T@>2`M
M(#,R.PH@("`@("`@(')M87@@/2`R-34@+2`H>2`O(#,R+C`I("H@,C4U.PH@
M("`@("`@(&=M87@@/2`R-34["B`@("`@("`@8FUA>"`](#`["B`@("!](&5L
M<V4@:68@*'D@/#T@.38I('L*("`@("`@("!Y(#T@>2`M(#8T.PH@("`@("`@
M(')M87@@/2`P.PH@("`@("`@(&=M87@@/2`R-34["B`@("`@("`@8FUA>"`]
M("AY("\@,S(N,"D@*B`R-34["B`@("!](&5L<V4@:68@*'D@/#T@,3(X*2![
M"B`@("`@("`@>2`]('D@+2`Y-CL*("`@("`@("!R;6%X(#T@,#L*("`@("`@
M("!G;6%X(#T@,C4U("T@*'D@+R`S,BXP*2`J(#(U-3L*("`@("`@("!B;6%X
M(#T@,C4U.PH@("`@?2!E;'-E(&EF("AY(#P](#$V,"D@>PH@("`@("`@('D@
M/2!Y("T@,3(X.PH@("`@("`@(')M87@@/2`H>2`O(#,R+C`I("H@,C4U.PH@
M("`@("`@(&=M87@@/2`P.PH@("`@("`@(&)M87@@/2`R-34["B`@("!](&5L
M<V4@>PH@("`@("`@('D@/2!Y("T@,38P.PH@("`@("`@(')M87@@/2`R-34[
M"B`@("`@("`@9VUA>"`](#`["B`@("`@("`@8FUA>"`](#(U-2`M("AY("\@
M,S(N,"D@*B`R-34["B`@("!]"@H@("`@:68@*'@@/#T@-3`I('L*("`@("`@
M("!V87(@<B`]($UA=&@N86)S*$UA=&@N9FQO;W(H<FUA>"`J('@@+R`U,"XP
M*2D["B`@("`@("`@=F%R(&<@/2!-871H+F%B<RA-871H+F9L;V]R*&=M87@@
M*B!X("\@-3`N,"DI.PH@("`@("`@('9A<B!B(#T@36%T:"YA8G,H36%T:"YF
M;&]O<BAB;6%X("H@>"`O(#4P+C`I*3L*("`@('T@96QS92!["B`@("`@("`@
M>"`M/2`U,#L*("`@("`@("!V87(@<B`]($UA=&@N86)S*$UA=&@N9FQO;W(H
M<FUA>"`K("AX("\@-3`N,"D@*B`H,C4U("T@<FUA>"DI*3L*("`@("`@("!V
M87(@9R`]($UA=&@N86)S*$UA=&@N9FQO;W(H9VUA>"`K("AX("\@-3`N,"D@
M*B`H,C4U("T@9VUA>"DI*3L*("`@("`@("!V87(@8B`]($UA=&@N86)S*$UA
M=&@N9FQO;W(H8FUA>"`K("AX("\@-3`N,"D@*B`H,C4U("T@8FUA>"DI*3L*
M("`@('T*"B`@("!R971U<FX@;6%K94-O;&]R*'(L(&<L(&(I.PI]"@IF=6YC
M=&EO;B!M86ME0V]L;W(H<BP@9RP@8BD*>PH@("`@8V]L;W(@/2`G(R<["B`@
M("!C;VQO<B`K/2!H97@H36%T:"YF;&]O<BAR("\@,38I*3L*("`@(&-O;&]R
M("L](&AE>"AR("4@,38I.PH@("`@8V]L;W(@*ST@:&5X*$UA=&@N9FQO;W(H
M9R`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H9R`E(#$V*3L*("`@(&-O;&]R
M("L](&AE>"A-871H+F9L;V]R*&(@+R`Q-BDI.PH@("`@8V]L;W(@*ST@:&5X
M*&(@)2`Q-BD["B`@("!R971U<FX@8V]L;W(["GT*"F9U;F-T:6]N(&)R:6=H
M=&YE<W,H8V]L;W(I"GL*("`@('9A<B!R(#T@;F5W($YU;6)E<B@B,'@B("L@
M8V]L;W(N<W5B<W1R*#$L(#(I*3L*("`@('9A<B!G(#T@;F5W($YU;6)E<B@B
M,'@B("L@8V]L;W(N<W5B<W1R*#,L(#(I*3L*("`@('9A<B!B(#T@;F5W($YU
M;6)E<B@B,'@B("L@8V]L;W(N<W5B<W1R*#4L(#(I*3L*("`@(')E='5R;B`H
M*'(@*B`R.3DI("L@*&<@*B`U.#<I("L@*&(@*B`Q,30I*2`O(#$P,#`["GT*
M"F9U;F-T:6]N(&AE>"AD96,I"GL*("`@(')E='5R;B`H9&5C*2YT;U-T<FEN
M9R@Q-BD["GT*+R\M+3X*/"]S8W)I<'0^"CPO8F]D>3X*/"]H=&UL/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+VEM86=E<R]P:7AE;"YP:'``````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C$W-2`Q,#4Q-30S-#$T-"`P,C(T-C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O<V5R=FEC97,O:6UA9V5S+W!I>&5L+G!H<"QV(#$N
M,30N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*"FAE861E<B@G0V]N
M=&5N="UT>7!E.B!I;6%G92]G:68G*3L*:&5A9&5R*"=%>'!I<F5S.B!7960L
M(#(Q($%U9R`Q.38Y(#$Q.C$Q.C$Q($=-5"<I.PIH96%D97(H)T-A8VAE+4-O
M;G1R;VPZ(&YO+6-A8VAE)RD["FAE861E<B@G0V%C:&4M0V]N=')O;#H@;75S
M="UR979A;&ED871E)RD["@HD<F=B(#T@<W1R7W)E<&QA8V4H)R,G+"`G)RP@
M571I;#HZ9V5T1F]R;41A=&$H)V,G*2D["@HD<B`](&AE>&1E8RAS=6)S='(H
M)')G8BP@,"P@,BDI.PHD9R`](&AE>&1E8RAS=6)S='(H)')G8BP@,BP@,BDI
M.PHD8B`](&AE>&1E8RAS=6)S='(H)')G8BP@-"P@,BDI.PH*:68@*"1R9V(I
M('L*("`@('!R:6YT9B@G)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R<L"B`@
M("`@("`@("`@-S$L-S,L-S`L-38L-3<L.3<L,2PP+#$L,"PQ,C@L,"PP+"1R
M+"1G+"1B+#`L,"PP+#0T+#`L,"PP+#`L,2PP+#$L,"PP+#(L,BPV."PQ+#`L
M-3DI.PI](&5L<V4@>PH@("`@<')I;G1F*"<E8R5C)6,E8R5C)6,E8R5C)6,E
M8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C)6,E8R5C
M)6,E8R5C)6,E8R5C)6,E8R5C)6,E)RP*("`@("`@("`@("`W,2PW,RPW,"PU
M-BPU-RPY-RPQ+#`L,2PP+#$R."PR-34L,"PQ.3(L,3DR+#$Y,BPP+#`L,"PS
M,RPR-#DL-"PQ+#`L,"PP+#`L-#0L,"PP+#`L,"PQ+#`L,2PP+#`L,BPR+#8X
M+#$L,"PU.2D["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O:6UA9V5S+W9I97<N<&AP````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-38T(#$P-3$U
M-#,T,30T(#`R,C,R,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@1&ES<&QA>7,@86X@:6UA9V4@86YD
M(&%L;&]W<R!M;V1I9FEC871I;VYS(&EF(')E<75I<F5D+@H@*@H@*B!#;W!Y
M<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+VEM
M86=E<R]V:65W+G!H<"QV(#$N,C`N,3`N-B`R,#`V+S`U+S(T(#`R.C(R.C`S
M('-E;'-K>2!%>'`@)`H@*@H@*B!`875T:&]R($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?
M0D%312`N("<O;&EB+V)A<V4N<&AP)SL*"B\J($=E="!F:6QE(&EN9F\N(%1H
M92!F;VQL;W=I;F<@<&%R86UE=&5R<R!A<F4@879A:6QA8FQE.@H@*B`@)V8G
M("T@=&AE(&9I;&5N86UE+@H@*B`@)W,G("T@=&AE('-O=7)C92P@96ET:&5R
M('1H92`G=&UP)R!D:7)E8W1O<GD@;W(@5D93+@H@*B`@)V,G("T@=VAI8V@@
M87!P)W,@8V]N9FEG('1O('5S92!F;W(@5D93+"!D969A=6QT<R!T;R!(;W)D
M92X*("H@("=P)R`M('1H92!D:7)E8W1O<GD@;V8@=&AE(&9I;&4N"B`J("`G
M;B<@+2!T:&4@;F%M92!T;R!S970@=&\@=&AE(&9I;&5N86UE(&]R(&1E9F%U
M;'0@=&\@<V%M92!A<R!F:6QE;F%M92X*("H@("=A)R`M('!E<F9O<FT@<V]M
M92!A8W1I;VX@;VX@=&AE(&EM86=E+"!S=6-H(&%S('-C86QI;F<N("HO"B1F
M:6QE(#T@8F%S96YA;64H571I;#HZ9V5T1F]R;41A=&$H)V8G*2D["B1S;W5R
M8V4@/2!S=')T;VQO=V5R*%5T:6PZ.F=E=$9O<FU$871A*"=S)RP@)W1M<"<I
M*3L*)&%P<%]C;VYF(#T@<W1R=&]L;W=E<BA5=&EL.CIG971&;W)M1&%T82@G
M8R<L("=H;W)D92<I*3L*)&YA;64@/2!5=&EL.CIG971&;W)M1&%T82@G;B<L
M("1F:6QE*3L*)&%C=&EO;B`]('-T<G1O;&]W97(H571I;#HZ9V5T1F]R;41A
M=&$H)V$G*2D["@IS=VET8V@@*"1S;W5R8V4I('L*8V%S92`G=F9S)SH*("`@
M("\J($-H86YG92!A<'`@:68@;F5E9&5D('1O(&=E="!T:&4@<FEG:'0@5D93
M(&-O;F9I9RX@*B\*("`@("1C:&%N9V5D7V-O;F8@/2`D<F5G:7-T<GDM/G!U
M<VA!<'`H)&%P<%]C;VYF*3L*"B`@("`O*B!'971T:6YG(&$@9FEL92!F<F]M
M($AO<F1E)W,@5D93+B`J+PH@("`@<F5Q=6ER95]O;F-E("=61E,N<&AP)SL*
M("`@("1V9G,@/2`F5D93.CIS:6YG;&5T;VXH)&-O;F9;)W9F<R==6R=T>7!E
M)UTL($AO<F1E.CIG971$<FEV97)#;VYF:6<H)W9F<R<L("1C;VYF6R=V9G,G
M75LG='EP92==*2D["B`@("`D<&%T:"`](%5T:6PZ.F=E=$9O<FU$871A*"=P
M)RD["B`@("`D9FEL95]D871A(#T@)'9F<RT^<F5A9"@D<&%T:"P@)&9I;&4I
M.PH@("`@:68@*&ES7V$H)&9I;&5?9&%T82P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)T5R<F]R(&1I<W!L
M87EI;F<@:6UA9V4@6R5S73H@)7,G+"`D<&%T:"`N("<O)R`N("1F:6QE+"`D
M9FEL95]D871A+3YG971-97-S86=E*"DI+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*B!2
M971U<FX@=&AE(&]R:6=I;F%L(&%P<"!I9B!C:&%N9V5D('!R979I;W5S;'DN
M("HO"B`@("!I9B`H)&-H86YG961?8V]N9BD@>PH@("`@("`@("1R96=I<W1R
M>2T^<&]P07!P*"1A<'!?8V]N9BD["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@
M)W1M<"<Z"B`@("`O*B!'971T:6YG(&$@9FEL92!F<F]M($AO<F1E)W,@=&5M
M<"!D:7(N("HO"B`@("`D=&UP9&ER(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*3L*
M("`@(&EF("AE;7!T>2@D86-T:6]N*2!\?"`D86-T:6]N(#T]("=R97-I>F4G
M*2!["B`@("`@("`@+RH@57-E(&]R:6=I;F%L(&EF(&YO(&%C=&EO;B!O<B!I
M9B!R97-I>FEN9RX@*B\*("`@("`@("`D9FEL95]N86UE(#T@)'1M<&1I<B`N
M("<O)R`N("1F:6QE.PH@("`@?2!E;'-E('L*("`@("`@("`D9FEL95]N86UE
M(#T@)'1M<&1I<B`N("<O;6]D7R<@+B`D9FEL93L*("`@("`@("!I9B`H(69I
M;&5?97AI<W1S*"1F:6QE7VYA;64I*2!["B`@("`@("`@("`@(&-O<'DH)'1M
M<&1I<B`N("<O)R`N("1F:6QE+"`D9FEL95]N86UE*3L*("`@("`@("!]"B`@
M("!]"B`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE7VYA;64I*2!["B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G26UA9V4@;F]T(&9O=6YD
M(%LE<UTG+"`D9FEL95]N86UE*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@(&5X:70["B`@("!]"B`@("`D9FEL95]D871A
M(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&5?;F%M92D["B`@("!B<F5A:SL*
M?0H*+RH@3&]A9"!T:&4@:6UA9V4@;V)J96-T+B`J+PIR97%U:7)E7V]N8V4@
M)TAO<F1E+TEM86=E+G!H<"<["B1P87)A;7,@/2!A<G)A>2@G=&5M<"<@/3X@
M2&]R9&4Z.F=E=%1E;7!$:7(H*2D["FEF("@A96UP='DH)&-O;F9;)VEM86=E
M)UU;)V-O;G9E<G0G72DI('L*("`@("1I;6%G92`]("9(;W)D95]);6%G93HZ
M<VEN9VQE=&]N*"=I;2<L("1P87)A;7,I.PI](&5L<V4@>PH@("`@)&EM86=E
M(#T@)DAO<F1E7TEM86=E.CIS:6YG;&5T;VXH)V=D)RP@)'!A<F%M<RD["GT*
M)&EM86=E+3YL;V%D4W1R:6YG*"1F:6QE+"`D9FEL95]D871A*3L*"B\J($-H
M96-K(&EF(&YO(&5D:71I;F<@86-T:6]N(')E<75I<F5D(&%N9"!S96YD('1H
M92!I;6%G92!T;R!B<F]W<V5R+B`J+PII9B`H96UP='DH)&%C=&EO;BDI('L*
M("`@("1I;6%G92T^9&ES<&QA>2@I.PH@("`@97AI=#L*?0H*+RH@26UA9V4@
M961I=&EN9R!R97%U:7)E9"X@*B\*<W=I=&-H("@D86-T:6]N*2!["F-A<V4@
M)W)O=&%T92<Z"B`@("`D:6UA9V4M/G)O=&%T92A5=&EL.CIG971&;W)M1&%T
M82@G=B<I*3L*("`@(&)R96%K.PH*8V%S92`G9FQI<"<Z"B`@("`D:6UA9V4M
M/F9L:7`H*3L*("`@(&)R96%K.PH*8V%S92`G;6ER<F]R)SH*("`@("1I;6%G
M92T^;6ER<F]R*"D["B`@("!B<F5A:SL*"F-A<V4@)V=R87ES8V%L92<Z"B`@
M("`D:6UA9V4M/F=R87ES8V%L92@I.PH@("`@8G)E86L["@IC87-E("=R97-I
M>F4G.@H@("`@;&ES="@D=VED=&@L("1H96EG:'0L("1R871I;RD@/2!E>'!L
M;V1E*"<N)RP@571I;#HZ9V5T1F]R;41A=&$H)W8G*2D["@H@("`@+RH@268@
M;F\@=VED=&@@;W(@:&5I9VAT(&AA<R!B965N('!A<W-E9"P@9V5T('1H92!O
M<FEG:6YA;`H@("`@("H@;VYE<RX@*B\*("`@(&EF("AE;7!T>2@D=VED=&@I
M('Q\(&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@)&]R:6<@/2`D:6UA9V4M
M/F=E=$1I;65N<VEO;G,H*3L*("`@('T*("`@(&EF("AE;7!T>2@D=VED=&@I
M*2!["B`@("`@("`@)'=I9'1H(#T@)&]R:6=;)W=I9'1H)UT["B`@("!]"B`@
M("!I9B`H96UP='DH)&AE:6=H="DI('L*("`@("`@("`D:&5I9VAT(#T@)&]R
M:6=;)VAE:6=H="==.PH@("`@?0H*("`@("1I;6%G92T^<F5S:7IE*"1W:61T
M:"P@)&AE:6=H="P@)')A=&EO*3L*"B`@("`O*B!3:6YC92!T:&4@;W)I9VEN
M86P@:7,@86QW87ES('5S960@9F]R(')E<VEZ:6YG(&UA:V4@<W5R92!T:&4*
M("`@("`J('=R:71E(&ES('1O("=M;V1?)RX@*B\*("`@("1F:6QE7VYA;64@
M/2`D=&UP9&ER("X@)R]M;V1?)R`N("1F:6QE.PH@("`@8G)E86L["GT*"B\J
M(%=R:71E(&]U="!A;GD@8VAA;F=E<R!T;R!T:&4@=&5M<&]R87)Y(&9I;&4N
M("HO"B1F<"`]($!F;W!E;B@D9FEL95]N86UE+"`G=V(G*3L*9G=R:71E*"1F
M<"P@)&EM86=E+3YR87<H*2D["F9C;&]S92@D9G`I.PH*)&EM86=E+3YD:7-P
M;&%Y*"D["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M;V)R;W=S97(O:6YD97@N<&AP````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`V,#4U(#$P-3$U-#,T,30T(#`R,S`T-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@)$AO
M<F1E.B!H;W)D92]S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`L=B`Q+C8N
M,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($-H87)L97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!
M4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O
M;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC
M92`G2&]R9&4O5&5M<&QA=&4N<&AP)SL*"B1P871H(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W!A=&@G*3L*"FEF("AE;7!T>2@D<&%T:"DI('L*("`@("1L:7-T
M(#T@87)R87DH*3L*("`@("1A<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAN
M=6QL+"!F86QS92P@4$5235-?4D5!1"D["B`@("!F;W)E86-H("@D87!P<R!A
M<R`D87!P*2!["B`@("`@("`@:68@*"1R96=I<W1R>2T^:&%S365T:&]D*"=B
M<F]W<V4G+"`D87!P*2D@>PH@("`@("`@("`@("`D;&ES=%LD87!P72`](&%R
M<F%Y*"=N86UE)R`]/B`D<F5G:7-T<GDM/F=E="@G;F%M92<L("1A<'`I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G
M:7-T<GDM/F=E="@G:6-O;B<L("1A<'`I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=B<F]W<V5A8FQE)R`]/B!T<G5E*3L*("`@("`@("!]
M"B`@("!]"GT@96QS92!["B`@("`D<&EE8V5S(#T@97AP;&]D92@G+R<L("1P
M871H*3L*("`@("1L:7-T(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"1P
M:65C97-;,%TL("=B<F]W<V4G+"!A<G)A>2@G<&%T:"<@/3X@)'!A=&@I*3L*
M?0H*:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R)RDI('L*("`@($AO<F1E
M.CIF871A;"@D;&ES="P@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0II9B`H(6-O
M=6YT*"1L:7-T*2D@>PH@("`@2&]R9&4Z.F9A=&%L*%\H(DYO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]"@HD
M='!L(#T@/#P\5%!,"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*
M9G5N8W1I;VX@8VAO;W-E3V)J96-T*&]I9"D*>PH@("`@:68@*"%W:6YD;W<N
M;W!E;F5R('Q\("%W:6YD;W<N;W!E;F5R+F]B<F]W<V5R0V%L;&)A8VLI('L*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@=F%R(')E<W5L="`]
M('=I;F1O=RYO<&5N97(N;V)R;W=S97)#86QL8F%C:RAW:6YD;W<N;F%M92P@
M;VED*3L*("`@(&EF("@A<F5S=6QT*2!["B`@("`@("`@=VEN9&]W+F-L;W-E
M*"D["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&%L97)T*')E<W5L="D[
M"B`@("!R971U<FX@9F%L<V4["GT*/"]S8W)I<'0^"@H\9&EV(&-L87-S/2)H
M96%D97(B/@H@/'-P86X@8VQA<W,](G)I9VAT1FQO870B/CQT86<Z8VQO<V4@
M+SX\+W-P86X^"B`\9V5T=&5X=#Y/8FIE8W0@0G)O=W-E<CPO9V5T=&5X=#X*
M/"]D:78^"CQD:78@8VQA<W,](FAE861E<F)O>"(^"B`\=&%B;&4@8VQA<W,]
M(G-T<FEP960B(&-E;&QS<&%C:6YG/2(P(B!S='EL93TB=VED=&@Z,3`P)2(^
M"B`\;&]O<#IR;W=S/@H@(#QT<CX*("`@/'1D/@H@("`@/'1A9SIR;W=S+FEC
M;VX@+SX*("`@(#QT86<Z<F]W<RYN86UE("\^"B`@(#PO=&0^"B`@/"]T<CX*
M(#PO;&]O<#IR;W=S/@H@/"]T86)L93X*/"]D:78^"E103#L*"B1R;W=S(#T@
M87)R87DH*3L*9F]R96%C:"`H)&QI<W0@87,@)'!A=&@@/3X@)'9A;'5E<RD@
M>PH@("`@)')O=R`](&%R<F%Y*"D["@H@("`@+R\@4V5T('1H92!I8V]N+@H@
M("`@:68@*"%E;7!T>2@D=F%L=65S6R=I8V]N)UTI*2!["B`@("`@("`@)')O
M=ULG:6-O;B==(#T@2&]R9&4Z.FEM9R@D=F%L=65S6R=I8V]N)UTL("1V86QU
M97-;)VYA;64G72P@)R<L("<G*3L*("`@('T@96QS96EF("@A96UP='DH)'9A
M;'5E<ULG8G)O=W-E86)L92==*2D@>PH@("`@("`@("1R;W=;)VEC;VXG72`]
M($AO<F1E.CII;6<H)W1R964O9F]L9&5R+G!N9R<I.PH@("`@?2!E;'-E('L*
M("`@("`@("`D<F]W6R=I8V]N)UT@/2!(;W)D93HZ:6UG*"=T<F5E+VQE868N
M<&YG)RD["B`@("!]"@H@("`@+R\@4V5T('1H92!N86UE+VQI;FLN"B`@("!I
M9B`H(65M<'1Y*"1V86QU97-;)V)R;W=S96%B;&4G72DI('L*("`@("`@("`D
M=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S97)V:6-E<R]O8G)O=W-E
M<B\G*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL
M("=P871H)RP@)'!A=&@I.PH@("`@("`@("1R;W=;)VYA;64G72`]($AO<F1E
M.CIL:6YK*"1U<FPI("X@)'9A;'5E<ULG;F%M92==("X@)SPO83XG.PH@("`@
M?2!E;'-E('L*("`@("`@("`D:G,@/2`B<F5T=7)N(&-H;V]S94]B:F5C="@G
M(B`N(&%D9'-L87-H97,H)'!A=&@I("X@(B<I.R(["B`@("`@("`@)')O=ULG
M;F%M92==(#T@2&]R9&4Z.FQI;FLH)R,G+"!S<')I;G1F*%\H(D-H;V]S92`E
M<R(I+"`D=F%L=65S6R=N86UE)UTI+"`G)RP@)R<L("1J<RD@+B`D=F%L=65S
M6R=N86UE)UT@+B`G/"]A/B<["B`@("!]"@H@("`@)')O=W-;72`]("1R;W<[
M"GT*"B1T96UP;&%T92`]("9N97<@2&]R9&5?5&5M<&QA=&4H*3L*)'1E;7!L
M871E+3YS971/<'1I;VXH)V=E='1E>'0G+"!T<G5E*3L*)'1E;7!L871E+3YS
M970H)W)O=W,G+"`D<F]W<RD["B1T96UP;&%T92T^<V5T*"=C;&]S92<L("<\
M82!H<F5F/2(C(B!O;F-L:6-K/2)W:6YD;W<N8VQO<V4H*3L@<F5T=7)N(&9A
M;'-E.R(^)R`N($AO<F1E.CII;6<H)V-L;W-E+G!N9R<I("X@)SPO83XG*3L*
M"DAO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R9&4G+"!T
M<G5E*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*96-H;R`D=&5M<&QA=&4M/G!A<G-E*"1T<&PI.PIR97%U:7)E
M($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V1O=VYL;V%D+VEN9&5X+G!H<```````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3,R,"`Q,#4Q-30S-#$T-"`P,C,P,#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J("1(
M;W)D93H@:&]R9&4O<V5R=FEC97,O9&]W;FQO860O:6YD97@N<&AP+'8@,2XY
M+C$P+C,@,C`P-B\P,2\P,2`R,3HR.3HQ,2!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*
M)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH2$]21$5?4T534TE/
M3E]214%$3TY,62D["@II9B`H(2@D;6]D=6QE(#T@571I;#HZ9V5T1F]R;41A
M=&$H)VUO9'5L92<I*2!\?`H@("`@(69I;&5?97AI<W1S*"1R96=I<W1R>2T^
M9V5T*"=F:6QE<F]O="<L("1M;V1U;&4I*2D@>PH@("`@2&]R9&4Z.F9A=&%L
M*"=$;R!N;W0@8V%L;"!T:&ES('-C<FEP="!D:7)E8W1L>2XG+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PI]"FEN8VQU9&4@)')E9VES=')Y+3YG970H)V9I;&5R
M;V]T)RP@)&UO9'5L92D@+B`G+W9I97<N<&AP)SL*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<```````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`R,S$P-R`Q,#4Q-30S-#$T-"`P,C(S,#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP+'8@
M,2XR-BXQ,"XX(#(P,#8O,#4O,#$@,C$Z,38Z-#$@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B1F:65L9'-,:7-T6R=S
M:&]W)UT@/2`P.PHD9FEE;&1S3&ES=%LG<F5A9"==(#T@,3L*)&9I96QD<TQI
M<W1;)V5D:70G72`](#(["B1F:65L9'-,:7-T6R=D96QE=&4G72`](#,["@I`
M9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]3:&%R92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T=R
M;W5P+G!H<"<["@HD87!P(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P<"<I.PHD
M<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)&%P<"D["B1G<F]U
M<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PHD875T:"`]("9!=71H.CIS:6YG
M;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*)&9O<FT@/2!N=6QL
M.PHD<F5L;V%D(#T@9F%L<V4["B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=A8W1I;VY)1"<L("=E9&ET)RD["G-W:71C:"`H)&%C=&EO;DE$*2![
M"F-A<V4@)V5D:70G.@H@("`@)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E
M0GE)9"A5=&EL.CIG971&;W)M1&%T82@G8VED)RDI.PH@("`@:68@*"%I<U]A
M*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1F;W)M(#T@)V5D
M:70N:6YC)SL*("`@("`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I
M;VXH*3L*("`@('T@96QS96EF("@H)&-A=&5G;W)Y(#T@571I;#HZ9V5T1F]R
M;41A=&$H)W-H87)E)RDI("$]/2!N=6QL*2!["B`@("`@("`@)'-H87)E(#T@
M)B1S:&%R97,M/F=E=%-H87)E*"1C871E9V]R>2D["B`@("`@("`@:68@*"%I
M<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9F]R
M;2`]("=E9&ET+FEN8R<["B`@("`@("`@("`@("1P97)M(#T@)B1S:&%R92T^
M9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@('T*("`@('T*("`@(&EF("AI<U]A
M*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H)'-H87)E+"`G:&]R9&4N97)R;W(G*3L*("`@('T@96QS96EF
M("AI<W-E="@D<VAA<F4I("8F($%U=&@Z.F=E=$%U=&@H*2`A/2`D<VAA<F4M
M/F=E="@G;W=N97(G*2D@>PH@("`@("`@(&5X:70H)W!E<FUI<W-I;VX@9&5N
M:65D)RD["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@)V5D:71F;W)M)SH*("`@
M("1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R94)Y260H571I;#HZ9V5T1F]R
M;41A=&$H)V-I9"<I*3L*("`@(&EF("AI<U]A*"1S:&%R92P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@('T@96QS92!["B`@("`@("`@:68@*$%U=&@Z.F=E=$%U=&@H
M*2`A/2`D<VAA<F4M/F=E="@G;W=N97(G*2D@>PH@("`@("`@("`@("!E>&ET
M*"=P97)M:7-S:6]N(&1E;FEE9"<I.PH@("`@("`@('T*("`@("`@("`D<&5R
M;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*"B`@("`@("`@+R\@4')O
M8V5S<R!O=VYE<B!A;F0@;W=N97(@<&5R;6ES<VEO;G,N"B`@("`@("`@)&]L
M9%]O=VYE<B`]("1S:&%R92T^9V5T*"=O=VYE<B<I.PH@("`@("`@("1N97=?
M;W=N97(@/2!5=&EL.CIG971&;W)M1&%T82@G;W=N97(G+"`D;VQD7V]W;F5R
M*3L*("`@("`@("!I9B`H)&]L9%]O=VYE<B`A/3T@)&YE=U]O=VYE<B`F)B`A
M96UP='DH)&YE=U]O=VYE<BDI('L*("`@("`@("`@("`@:68@*"1O;&1?;W=N
M97(@(3T@075T:#HZ9V5T075T:"@I("8F("%!=71H.CII<T%D;6EN*"DI('L*
M("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<VAA<F4M/G-E="@G;W=N97(G+"`D;F5W7V]W;F5R*3L*("`@
M("`@("`@("`@("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@("`@("`@("`@
M:68@*%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<E]S:&]W)RDI('L*("`@("`@
M("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)&YE=U]O
M=VYE<BP@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E
M<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?4TA/5RP@9F%L<V4I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O
M<FU$871A*"=O=VYE<E]R96%D)RDI('L*("`@("`@("`@("`@("`@("`@("`D
M<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?4D5!
M1"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)&YE=U]O
M=VYE<BP@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<E]E
M9&ET)RDI('L*("`@("`@("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E
M<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?141)5"P@9F%L<V4I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<&5R
M;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)&YE=U]O=VYE<BP@4$5235-?141)
M5"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M:68@*%5T:6PZ.F=E=$9O<FU$871A*"=O=VYE<E]D96QE=&4G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D;F5W
M7V]W;F5R+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V955S
M97)097)M:7-S:6]N*"1N97=?;W=N97(L(%!%4DU37T1%3$5412P@9F%L<V4I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!0<F]C97-S(&1E9F%U;'0@<&5R;6ES<VEO;G,N"B`@("`@
M("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=D969A=6QT7W-H;W<G*2D@>PH@
M("`@("`@("`@("`D<&5R;2T^861D1&5F875L=%!E<FUI<W-I;VXH4$5235-?
M4TA/5RP@9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M97)M+3YR96UO=F5$969A=6QT4&5R;6ES<VEO;BA015)-4U]32$]7+"!F86QS
M92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G
M9&5F875L=%]R96%D)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$1E9F%U
M;'1097)M:7-S:6]N*%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1&5F875L=%!E<FUI<W-I
M;VXH4$5235-?4D5!1"P@9F%L<V4I.PH@("`@("`@('T*("`@("`@("!I9B`H
M571I;#HZ9V5T1F]R;41A=&$H)V1E9F%U;'1?961I="<I*2!["B`@("`@("`@
M("`@("1P97)M+3YA9&1$969A=6QT4&5R;6ES<VEO;BA015)-4U]%1$E4+"!F
M86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!E<FTM/G)E
M;6]V941E9F%U;'1097)M:7-S:6]N*%!%4DU37T5$250L(&9A;'-E*3L*("`@
M("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=D969A=6QT
M7V1E;&5T92<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1$969A=6QT4&5R
M;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1&5F875L=%!E<FUI<W-I;VXH
M4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`O+R!0
M<F]C97-S(&=U97-T('!E<FUI<W-I;VYS+@H@("`@("`@(&EF("A5=&EL.CIG
M971&;W)M1&%T82@G9W5E<W1?<VAO=R<I*2!["B`@("`@("`@("`@("1P97)M
M+3YA9&1'=65S=%!E<FUI<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5'=65S=%!E
M<FUI<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I.PH@("`@("`@('T*("`@("`@
M("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V=U97-T7W)E860G*2D@>PH@("`@
M("`@("`@("`D<&5R;2T^861D1W5E<W1097)M:7-S:6]N*%!%4DU37U)%040L
M(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^
M<F5M;W9E1W5E<W1097)M:7-S:6]N*%!%4DU37U)%040L(&9A;'-E*3L*("`@
M("`@("!]"B`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A*"=G=65S=%]E
M9&ET)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D9$=U97-T4&5R;6ES<VEO
M;BA015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'!E<FTM/G)E;6]V94=U97-T4&5R;6ES<VEO;BA015)-4U]%1$E4
M+"!F86QS92D["B`@("`@("`@?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M
M1&%T82@G9W5E<W1?9&5L971E)RDI('L*("`@("`@("`@("`@)'!E<FTM/F%D
M9$=U97-T4&5R;6ES<VEO;BA015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W5E<W1097)M
M:7-S:6]N*%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@('T*"B`@("`@
M("`@+R\@4')O8V5S<R!C<F5A=&]R('!E<FUI<W-I;VYS+@H@("`@("`@(&EF
M("A5=&EL.CIG971&;W)M1&%T82@G8W)E871O<E]S:&]W)RDI('L*("`@("`@
M("`@("`@)'!E<FTM/F%D9$-R96%T;W)097)M:7-S:6]N*%!%4DU37U-(3U<L
M(&9A;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&5R;2T^
M<F5M;W9E0W)E871O<E!E<FUI<W-I;VXH4$5235-?4TA/5RP@9F%L<V4I.PH@
M("`@("`@('T*("`@("`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V-R96%T
M;W)?<F5A9"<I*2!["B`@("`@("`@("`@("1P97)M+3YA9&1#<F5A=&]R4&5R
M;6ES<VEO;BA015)-4U]214%$+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'!E<FTM/G)E;6]V94-R96%T;W)097)M:7-S:6]N*%!%
M4DU37U)%040L(&9A;'-E*3L*("`@("`@("!]"B`@("`@("`@:68@*%5T:6PZ
M.F=E=$9O<FU$871A*"=C<F5A=&]R7V5D:70G*2D@>PH@("`@("`@("`@("`D
M<&5R;2T^861D0W)E871O<E!E<FUI<W-I;VXH4$5235-?141)5"P@9F%L<V4I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P97)M+3YR96UO=F5#
M<F5A=&]R4&5R;6ES<VEO;BA015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@
M?0H@("`@("`@(&EF("A5=&EL.CIG971&;W)M1&%T82@G8W)E871O<E]D96QE
M=&4G*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D0W)E871O<E!E<FUI<W-I
M;VXH4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'!E<FTM/G)E;6]V94-R96%T;W)097)M:7-S:6]N*%!%4DU3
M7T1%3$5412P@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@+R\@4')O8V5S
M<R!U<V5R('!E<FUI<W-I;VYS+@H@("`@("`@("1U7VYA;65S(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W5?;F%M97,G*3L*("`@("`@("`D=5]S:&]W(#T@571I
M;#HZ9V5T1F]R;41A=&$H)W5?<VAO=R<I.PH@("`@("`@("1U7W)E860@/2!5
M=&EL.CIG971&;W)M1&%T82@G=5]R96%D)RD["B`@("`@("`@)'5?961I="`]
M(%5T:6PZ.F=E=$9O<FU$871A*"=U7V5D:70G*3L*("`@("`@("`D=5]D96QE
M=&4@/2!5=&EL.CIG971&;W)M1&%T82@G=5]D96QE=&4G*3L*"B`@("`@("`@
M9F]R96%C:"`H)'5?;F%M97,@87,@)&ME>2`]/B`D=7-E<BD@>PH@("`@("`@
M("`@("`O+R!)9B!T:&4@=7-E<B!I<R!E;7!T>2P@;W(@=V4G=F4@86QR96%D
M>2!S970@<&5R;6ES<VEO;G,*("`@("`@("`@("`@+R\@=FEA('1H92!O=VYE
M<E\@;W!T:6]N<RP@9&]N)W0@9&\@86YY=&AI;F<@:&5R92X*("`@("`@("`@
M("`@:68@*&5M<'1Y*"1U<V5R*2!\?"`D=7-E<B`]/2`D;F5W7V]W;F5R*2![
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=5]S:&]W6R1K97E=*2D@>PH@("`@("`@
M("`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R+"!015)-
M4U]32$]7+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%
M4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(65M<'1Y*"1U7W)E861;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D
M<&5R;2T^861D57-E<E!E<FUI<W-I;VXH)'5S97(L(%!%4DU37U)%040L(&9A
M;'-E*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P
M97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?4D5!1"P@
M9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH
M)'5?961I=%LD:V5Y72DI('L*("`@("`@("`@("`@("`@("1P97)M+3YA9&15
M<V5R4&5R;6ES<VEO;B@D=7-E<BP@4$5235-?141)5"P@9F%L<V4I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V
M955S97)097)M:7-S:6]N*"1U<V5R+"!015)-4U]%1$E4+"!F86QS92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D=5]D96QE=&5;
M)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D<&5R;2T^861D57-E<E!E<FUI
M<W-I;VXH)'5S97(L(%!%4DU37T1%3$5412P@9F%L<V4I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FTM/G)E;6]V955S97)0
M97)M:7-S:6]N*"1U<V5R+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@4')O8V5S<R!G<F]U<"!P
M97)M:7-S:6]N<RX*("`@("`@("`D9U]N86UE<R`](%5T:6PZ.F=E=$9O<FU$
M871A*"=G7VYA;65S)RD["B`@("`@("`@)&=?<VAO=R`](%5T:6PZ.F=E=$9O
M<FU$871A*"=G7W-H;W<G*3L*("`@("`@("`D9U]R96%D(#T@571I;#HZ9V5T
M1F]R;41A=&$H)V=?<F5A9"<I.PH@("`@("`@("1G7V5D:70@/2!5=&EL.CIG
M971&;W)M1&%T82@G9U]E9&ET)RD["B`@("`@("`@)&=?9&5L971E(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V=?9&5L971E)RD["@H@("`@("`@(&9O<F5A8V@@
M*"1G7VYA;65S(&%S("1K97D@/3X@)&=R;W5P*2!["B`@("`@("`@("`@(&EF
M("AE;7!T>2@D9W)O=7`I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D9U]S:&]W
M6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R
M;6ES<VEO;B@D9W)O=7`L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F5'<F]U
M<%!E<FUI<W-I;VXH)&=R;W5P+"!015)-4U]32$]7+"!F86QS92D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D9U]R96%D6R1K97E=
M*2D@>PH@("`@("`@("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R;6ES<VEO
M;B@D9W)O=7`L(%!%4DU37U)%040L(&9A;'-E*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F5'<F]U<%!E<FUI
M<W-I;VXH)&=R;W5P+"!015)-4U]214%$+"!F86QS92D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"%E;7!T>2@D9U]E9&ET6R1K97E=*2D@>PH@
M("`@("`@("`@("`@("`@)'!E<FTM/F%D9$=R;W5P4&5R;6ES<VEO;B@D9W)O
M=7`L(%!%4DU37T5$250L(&9A;'-E*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH
M)&=R;W5P+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D9U]D96QE=&5;)&ME>5TI*2!["B`@("`@
M("`@("`@("`@("`D<&5R;2T^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@
M4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G
M<F]U<"P@4$5235-?1$5,151%+"!F86QS92D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1S:&%R92T^<V5T4&5R;6ES<VEO;B@D<&5R;2P@
M9F%L<V4I.PH@("`@("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")5<&1A=&5D(%PB)7-<(BXB*2P@
M)'-H87)E+3YG970H)VYA;64G*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@
M("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@?0H@("`@8G)E86L["GT*"FEF
M("AI<U]A*"1S:&%R92P@)U!%05)?17)R;W(G*2D@>PH@("`@)'1I=&QE(#T@
M7R@B161I="!097)M:7-S:6]N<R(I.PI](&5L<V4@>PH@("`@)'1I=&QE(#T@
M<W!R:6YT9BA?*")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(I+"`D<VAA<F4M
M/F=E="@G;F%M92<I*3L*?0H*:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L
M:7-T)RDI('L*("`@("1U<V5R3&ES="`]("1A=71H+3YL:7-T57-E<G,H*3L*
M("`@(&EF("AI<U]A*"1U<V5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1U<V5R3&ES="P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("1U<V5R3&ES="`](&%R
M<F%Y*"D["B`@("!]"B`@("!S;W)T*"1U<V5R3&ES="D["GT@96QS92!["B`@
M("`D=7-E<DQI<W0@/2!A<G)A>2@I.PI]"@HD9W)O=7!,:7-T(#T@)&=R;W5P
M<RT^9V5T1W)O=7!-96UB97)S:&EP<RA!=71H.CIG971!=71H*"DL('1R=64I
M.PII9B`H:7-?82@D9W)O=7!,:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("!(
M;W)D93HZ;&]G365S<V%G92@D9W)O=7!,:7-T+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7TY/5$E#12D["B`@("`D9W)O=7!,:7-T(#T@87)R87DH
M*3L*?0IA<V]R="@D9W)O=7!,:7-T*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO
M=&EF>2AA<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PII9B`H(65M
M<'1Y*"1F;W)M*2D@>PH@("`@<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+W-H87)E<R\G("X@)&9O<FT["GT*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53
M("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+W!O<G1A;"]E9&ET+G!H<```````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S$R-R`Q,#4Q-30S-#$T-"`P,C(S,C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP+'8@,2XT
M-"XX+C4@,C`P-B\P,R\P."`Q.#HP,#HU-B!C:'5C:R!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T
M:6]N+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G
M.PH*:68@*"%!=71H.CII<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z
M.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\O($=E="!F
M=6QL(&YA;64@9F]R('1I=&QE+@HD:61E;G1I='D@/2`F261E;G1I='DZ.G-I
M;F=L971O;B@I.PHD9G5L;&YA;64@/2`D:61E;G1I='DM/F=E=%9A;'5E*"=F
M=6QL;F%M92<I.PII9B`H96UP='DH)&9U;&QN86UE*2D@>PH@("`@)&9U;&QN
M86UE(#T@075T:#HZ9V5T075T:"@I.PI]"@HO+R!);G-T86YT:6%T92!T:&4@
M8FQO8VMS(&]B:F5C=',N"B1B;&]C:W,@/2`F2&]R9&5?0FQO8VM?0V]L;&5C
M=&EO;CHZ<VEN9VQE=&]N*"=P;W)T86PG*3L*)&QA>6]U="`]("9(;W)D95]"
M;&]C:U],87EO=71?36%N86=E<CHZ<VEN9VQE=&]N*"=P;W)T86PG+"`D8FQO
M8VMS+"`D<')E9G,M/F=E=%9A;'5E*"=P;W)T86Q?;&%Y;W5T)RDI.PH*+R\@
M2&%N9&QE(')E<75E<W1E9"!A8W1I;VYS+@HD;&%Y;W5T+3YH86YD;&4H571I
M;#HZ9V5T1F]R;41A=&$H)V%C=&EO;B<I+`H@("`@("`@("`@("`@("`@*&EN
M="E5=&EL.CIG971&;W)M1&%T82@G<F]W)RDL"B`@("`@("`@("`@("`@("`H
M:6YT*55T:6PZ.F=E=$9O<FU$871A*"=C;VPG*2D["FEF("@D;&%Y;W5T+3YU
M<&1A=&5D*"DI('L*("`@("1P<F5F<RT^<V5T5F%L=64H)W!O<G1A;%]L87EO
M=70G+"`D;&%Y;W5T+3YS97)I86QI>F4H*2D["GT*"B1T:71L92`](%\H(DUY
M(%!O<G1A;"!,87EO=70B*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+W!O<G1A;"]M96YU+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA
M<G)A>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PIR97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O<&]R=&%L+V5D:70N:6YC)SL*<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<```````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(U-S`@,3`U,34T,S0Q-#0@,#(R-C0T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R
M9&4Z(&AO<F1E+W-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP+'8@,BXQ-2XQ
M,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,30@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D
M:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/
M4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O261E;G1I='DN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-;V)I;&4N
M<&AP)SL*"FEF("@A075T:#HZ9V5T075T:"@I*2!["B`@("!H96%D97(H)TQO
M8V%T:6]N.B`G("X@571I;#HZ861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A
M=&EO;E5R;"@G;&]G:6XN<&AP)RP@=')U92DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FPG+"!(;W)D93HZ<V5L
M9E5R;"@I+"!F86QS92DI.PH@("`@97AI=#L*?0H*)&ED96YT:71Y(#T@)DED
M96YT:71Y.CIS:6YG;&5T;VXH*3L*)&9U;&QN86UE(#T@)&ED96YT:71Y+3YG
M971686QU92@G9G5L;&YA;64G*3L*:68@*&5M<'1Y*"1F=6QL;F%M92DI('L*
M("`@("1F=6QL;F%M92`]($%U=&@Z.F=E=$%U=&@H*3L*?0H*)&T@/2`F;F5W
M($AO<F1E7TUO8FEL92A?*")796QC;VUE(BDI.PHD;2T^861D*&YE=R!(;W)D
M95]-;V)I;&5?=&5X="AS<')I;G1F*%\H(E=E;&-O;64L("5S(BDL("1F=6QL
M;F%M92DI*3L*"B\O($UE<W-Y('=A>2!O9B!L:6YK:6YG('1O(&%C=&EV92!A
M<'!S('1H870@<W5P<&]R="!M;V)I;&4*+R\@9&5V:6-E<RX@4VAO=6QD(&)E
M(&UA9&4@;6]R92!E;&5G86YT(&%T('-O;64@<&]I;G0N"FEF("@A96UP='DH
M)')E9VES=')Y+3YA<'!L:6-A=&EO;G-;)VUI;7`G75LG<W1A='5S)UTI("8F
M"B`@("`D<F5G:7-T<GDM/F%P<&QI8V%T:6]N<ULG;6EM<"==6R=S=&%T=7,G
M72`A/2`G:6YA8W1I=F4G*2!["B`@("`D;2T^861D*&YE=R!(;W)D95]-;V)I
M;&5?;&EN:R@D<F5G:7-T<GDM/F=E="@G;F%M92<L("=M:6UP)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ=7)L*"1R96=I
M<W1R>2T^9V5T*"=W96)R;V]T)RP@)VUI;7`G*2`N("<O)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5G:7-T<GDM/F=E="@G;F%M
M92<L("=M:6UP)RDI*3L*?0H*)&TM/F1I<W!L87DH*3L*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C$T,B`Q,#4Q-30S-#$T
M-"`P,C(W,#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`L=B`R+C(V+C8N,R`R,#`V+S`Q+S`Q(#(Q.C(Y.C$T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F
M:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN
M)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U)00RYP:'`G.PH*:68@*"%!=71H.CII
M<T%U=&AE;G1I8V%T960H*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N
M1F%I;'5R95)E9&ER96-T*"D["GT*"B1R<&-?<V5R=F5R<R`]($!U;G-E<FEA
M;&EZ92@D<')E9G,M/F=E=%9A;'5E*"=R96UO=&5?<W5M;6%R:65S)RDI.PII
M9B`H(6ES7V%R<F%Y*"1R<&-?<V5R=F5R<RDI('L*("`@("1R<&-?<V5R=F5R
M<R`](&%R<F%Y*"D["GT*"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$871A
M*"=A8W1I;VY)1"<I.PH*+R\@2&%N9&QE(&-L:65N=',@=VET:&]U="!J879A
M<V-R:7!T+@II9B`H:7-?;G5L;"@D86-T:6]N240I*2!["B`@("!I9B`H571I
M;#HZ9V5T4&]S="@G961I="<I*2!["B`@("`@("`@)&%C=&EO;DE$(#T@)V5D
M:70G.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=%!O<W0H)W-A=F4G*2D@>PH@
M("`@("`@("1A8W1I;VY)1"`]("=S879E)SL*("`@('T@96QS96EF("A5=&EL
M.CIG9710;W-T*"=D96QE=&4G*2D@>PH@("`@("`@("1A8W1I;VY)1"`]("=D
M96QE=&4G.PH@("`@?0I]"@HO*B!2=6X@=&AR;W5G:"!T:&4@86-T:6]N(&AA
M;F1L97)S("HO"G-W:71C:"`H)&%C=&EO;DE$*2!["F-A<V4@)W-A=F4G.@H@
M("`@:68@*"@D=&]?961I="`](%5T:6PZ.F=E=$9O<FU$871A*"=E9&ET7W-E
M<G9E<B<I*2`]/2!N=6QL*2!["B`@("`@("`@)'1O7V5D:70@/2!C;W5N="@D
M<G!C7W-E<G9E<G,I.PH@("`@("`@("1R<&-?<V5R=F5R<UM=(#T@87)R87DH
M*3L*("`@('T*("`@("1R<&-?<V5R=F5R<ULD=&]?961I=%U;)W5R;"==("`@
M(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PH@("`@)')P8U]S97)V97)S
M6R1T;U]E9&ET75LG=7-E<B==("`@/2!5=&EL.CIG971&;W)M1&%T82@G=7-E
M<B<I.PH@("`@)')P8U]S97)V97)S6R1T;U]E9&ET75LG<&%S<W=D)UT@/2!5
M=&EL.CIG971&;W)M1&%T82@G<&%S<W=D)RD["B`@("`D<')E9G,M/G-E=%9A
M;'5E*"=R96UO=&5?<W5M;6%R:65S)RP@<V5R:6%L:7IE*"1R<&-?<V5R=F5R
M<RDI.PH@("`@)'!R969S+3YS=&]R92@I.PH@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A
M=F5D+B(I+"`D<G!C7W-E<G9E<G-;)'1O7V5D:71=6R=U<FPG72DL("=H;W)D
M92YS=6-C97-S)RD["B`@("!B<F5A:SL*"F-A<V4@)V1E;&5T92<Z"B`@("`D
M=&]?9&5L971E(#T@571I;#HZ9V5T1F]R;41A=&$H)W-E<G9E<B<I.PH@("`@
M:68@*"1T;U]D96QE=&4@(3T@+3$I('L*("`@("`@("`D9&5L971E9%]S97)V
M97(@/2`D<G!C7W-E<G9E<G-;)'1O7V1E;&5T95U;)W5R;"==.PH@("`@("`@
M("1S97)V97)?;&ES="`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@8V]U;G0H)')P8U]S97)V97)S*3L@)&DK*RD@>PH@("`@("`@("`@
M("!I9B`H)&D@/3T@)'1O7V1E;&5T92D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-E<G9E<E]L:7-T
M6UT@/2`D<G!C7W-E<G9E<G-;)&E=.PH@("`@("`@('T*("`@("`@("`D<')E
M9G,M/G-E=%9A;'5E*"=R96UO=&5?<W5M;6%R:65S)RP@<V5R:6%L:7IE*"1S
M97)V97)?;&ES="DI.PH@("`@("`@("1C:&]S96Y#;VQU;6YS(#T@97AP;&]D
M92@G.R<L("1P<F5F<RT^9V5T5F%L=64H)W-H;W=?<W5M;6%R:65S)RDI.PH@
M("`@("`@(&EF("@D8VAO<V5N0V]L=6UN<R`A/2!A<G)A>2@G)RDI('L*("`@
M("`@("`@("`@)&YE=T-O;'5M;G,@/2!A<G)A>2@I.PH@("`@("`@("`@("!F
M;W)E86-H("@D8VAO<V5N0V]L=6UN<R!A<R`D8VAO<V5N0V]L=6UN*2!["B`@
M("`@("`@("`@("`@("`D8VAO<V5N0V]L=6UN(#T@97AP;&]D92@G+"<L("1C
M:&]S96Y#;VQU;6XI.PH@("`@("`@("`@("`@("`@)')E;6]T92`](&5X<&QO
M9&4H)WPG+"`D8VAO<V5N0V]L=6UN6S!=*3L*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D<F5M;W1E*2`A/2`S('Q\("1R96UO=&5;,ET@/3T@)&1E;&5T
M961?<V5R=F5R*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=T-O;'5M;G-;
M72`](&EM<&QO9&4H)RPG+"`D8VAO<V5N0V]L=6UN*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<')E9G,M/G-E=%9A
M;'5E*"=S:&]W7W-U;6UA<FEE<R<L(&EM<&QO9&4H)SLG+"`D;F5W0V]L=6UN
M<RDI.PH@("`@("`@('T*("`@("`@("`D<')E9G,M/G-T;W)E*"D["B`@("`@
M("`@)')P8U]S97)V97)S(#T@)'-E<G9E<E]L:7-T.PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&4@<V5R=F5R(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(I+"`D9&5L971E9%]S97)V97(I+"`G:&]R9&4N
M<W5C8V5S<R<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*%\H(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"XB*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@('T*("`@(&)R96%K.PI]
M"@HO*B!3:&]W('1H92!H96%D97(N("HO"G)E<75I<F5?;VYC92`G2&]R9&4O
M4')E9G,O54DN<&AP)SL*<F5Q=6ER92!(3U)$15]"05-%("X@)R]C;VYF:6<O
M<')E9G,N<&AP)SL*)&%P<"`]("=H;W)D92<["E!R969S7U5).CIG96YE<F%T
M94AE861E<B@G<F5M;W1E)RD["@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O<G!C<W5M+W)P8W-U;2YI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%
M4R`N("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C4R,S0@,3`U,34T,S0Q
M-#0@,#(S,#$P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<"QV(#$N-"XR+C$S(#(P,#8O,#,O,C`@,34Z,#`Z
M,#8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE
M<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4&%W;&]W<VMY(#QM:G!A=VQO=W-K
M>4!Y86AO;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*BH*("H@1&5T97)M
M:6YE(&EF('1H92!C=7)R96YT('5S97(@8V%N('-E92!A;B!A<'!L:6-A=&EO
M;BX*("H*("H@0'!A<F%M('-T<FEN9R`@)&%P<"`@("`@("`@("!4:&4@87!P
M;&EC871I;VX@;F%M92X*("H@0'!A<F%M(&%R<F%Y("`@)'!A<F%M<R`@("`@
M("!4:&4@87!P;&EC871I;VXG<R!P87)A;65T97)S+@H@*B!`<&%R86T@87)R
M87D@("8D:&%S0VAI;&1R96X@(%)E9F5R96YC92!T;R!A;B!A<G)A>2!T;R!S
M970@8VAI;&1R96X@9FQA9W,@:6XN"B`J+PIF=6YC=&EO;B!C86Y3964H)&%P
M<"P@)'!A<F%M<RP@)B1H87-#:&EL9')E;BD*>PH@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("!S=&%T:6,@)&-A8VAE(#T@87)R87DH*3L*("`@('-T871I
M8R`D:7-!9&UI;CL*("`@('-T871I8R`D=7-E<CL*"B`@("`O+R!)9B!W92!H
M879E(&$@8V%C:&5D('9A;'5E(&9O<B!T:&ES(&%P<&QI8V%T:6]N+"!R971U
M<FX@:70@;F]W+@H@("`@:68@*&ES<V5T*"1C86-H95LD87!P72DI('L*("`@
M("`@("!R971U<FX@)&-A8VAE6R1A<'!=.PH@("`@?0H*("`@("\O($EN:71I
M86QI>F4@=F%R:6%B;&5S('=E)VQL(&ME97`@=7-I;F<@:6X@<W5C8V5S<VEV
M92!C86QL<R!O;@H@("`@+R\@=&AE(&9I<G-T(&-A;&PN"B`@("!I9B`H:7-?
M;G5L;"@D:7-!9&UI;BDI('L*("`@("`@("`D:7-!9&UI;B`]($%U=&@Z.FES
M061M:6XH*3L*("`@("`@("`D=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@
M('T*"B`@("`O+R!#:&5C:R!I9B!T:&4@8W5R<F5N="!U<V5R(&AA<R!P97)M
M:7-S;VX@=&\@<V5E('1H:7,@87!P;&EC871I;VXL(&%N9"!I9@H@("`@+R\@
M=&AE(&%P<&QI8V%T:6]N(&ES(&%C=&EV92X@2&5A9&EN9W,@87)E('9I<VEB
M;&4@=&\@979E<GEO;F4@*&)U="!G970*("`@("\O(&9I;'1E<F5D(&]U="!L
M871E<B!I9B!T:&5Y(&AA=F4@;F\@8VAI;&1R96XI+B!!9&UI;FES=')A=&]R
M<R!A;'=A>7,@<V5E"B`@("`O+R!A;&P@87!P;&EC871I;VYS(&5X8V5P="!T
M:&]S92!M87)K960@)VEN86-T:79E)RX@06YY;VYE('=I=&@@4TA/5PH@("`@
M+R\@<&5R;6ES<VEO;G,@8V%N('-E92!A;B!A<'!L:6-A=&EO;BP@8G5T(%)%
M040@:7,@;F5E9&5D('1O(&%C='5A;&QY('5S90H@("`@+R\@=&AE(&%P<&QI
M8V%T:6]N+B!9;W4@8V%N('5S92!T:&ES(&1I<W1I;F-T:6]N('1O('-H;W<@
M87!P;&EC871I;VYS('1O"B`@("`O+R!G=65S=',@=&AA="!T:&5Y(&YE960@
M=&\@;&]G(&EN('1O('5S92X@268@>6]U(&1O;B=T('=A;G0@=&AE;2!T;R!S
M964*("`@("\O(&%P<',@=&AE>2!C86XG="!U<V4L('1H96X@9&]N)W0@9VEV
M92!G=65S=',@4TA/5R!P97)M:7-S:6]N<R!T;PH@("`@+R\@86YY=&AI;F<N
M"B`@("!I9B`H+R\@1&]N)W0@<VAO=R!A<'!L:6-A=&EO;G,@=&AA="!A<F5N
M)W0@:6YS=&%L;&5D+"!E=F5N(&EF('1H97DG<F4*("`@("`@("`O+R!C;VYF
M:6=U<F5D+@H@("`@("`@("AI<W-E="@D<&%R86US6R=F:6QE<F]O="==*2`F
M)B`A:7-?9&ER*"1P87)A;7-;)V9I;&5R;V]T)UTI*2!\?`H*("`@("`@("`O
M+R!$;VXG="!S:&]W(&)L;V-K<R!O9B!A<'!L:6-A=&EO;G,@=&AA="!A<F5N
M)W0@:6YS=&%L;&5D+@H@("`@("`@("@D<&%R86US6R=S=&%T=7,G72`]/2`G
M8FQO8VLG("8F"B`@("`@("`@("%I<U]D:7(H)')E9VES=')Y+3YG970H)V9I
M;&5R;V]T)RP@)'!A<F%M<ULG87!P)UTI*2D@?'P*"B`@("`@("`@+R\@1FEL
M=&5R(&]U="!E;G1R:65S('1H870@87)E(&1I<V%B;&5D+"!H:61D96X@;W(@
M<VAO=6QD;B=T('-H;W<@=7`*("`@("`@("`O+R!I;B!T:&4@;65N=2X*("`@
M("`@("`D<&%R86US6R=S=&%T=7,G72`]/2`G;F]T;V]L8F%R)R!\?"`D<&%R
M86US6R=S=&%T=7,G72`]/2`G:&ED9&5N)R!\?`H@("`@("`@("1P87)A;7-;
M)W-T871U<R==(#T]("=I;F%C=&EV92<I('L*"B`@("`@("`@)&-A8VAE6R1A
M<'!=(#T@9F%L<V4["@H@("`@?2!E;'-E:68@*"\O($AE861I;F=S(&-A;B!A
M;'=A>7,@8F4@<V5E;BX*("`@("`@("`@("`@("`H)'!A<F%M<ULG<W1A='5S
M)UT@/3T@)VAE861I;F<G*2!\?`H*("`@("`@("`@("`@("`O+R!!9&UI;G,@
M<V5E(&5V97)Y=&AI;F<@=&AA="!M86ME<R!I="!T;R!T:&ES('!O:6YT+@H@
M("`@("`@("`@("`@("@D:7-!9&UI;B!\?`H*("`@("`@("`@("`@("`@+R\@
M57-E<G,@=VAO(&AA=F4@4TA/5R!P97)M:7-S:6]N<R!T;R!A8W1I=F4@;W(@
M8FQO8VL@96YT<FEE<PH@("`@("`@("`@("`@("`O+R!S964@=&AE;2X*("`@
M("`@("`@("`@("`@*"1R96=I<W1R>2T^:&%S4&5R;6ES<VEO;B@D87!P+"!0
M15)-4U]32$]7*2`F)@H@("`@("`@("`@("`@("`@*"1P87)A;7-;)W-T871U
M<R==(#T]("=A8W1I=F4G('Q\"B`@("`@("`@("`@("`@("`@)'!A<F%M<ULG
M<W1A='5S)UT@/3T@)V)L;V-K)RDI*2D@>PH*("`@("`@("`D8V%C:&5;)&%P
M<%T@/2!T<G5E.PH*("`@("`@("`O+R!.;W1E('1H870@=&AE('!A<F5N="!N
M;V1E+"!I9B!A;GDL(&AA<R!C:&EL9')E;BX*("`@("`@("!I9B`H:7-S970H
M)'!A<F%M<ULG;65N=5]P87)E;G0G72DI('L*("`@("`@("`@("`@)&AA<T-H
M:6QD<F5N6R1P87)A;7-;)VUE;G5?<&%R96YT)UU=(#T@=')U93L*("`@("`@
M("!]"B`@("!](&5L<V4@>PH@("`@("`@("\O($-A=&-H(&%N>71H:6YG('1H
M870@9F5L;"!T:')O=6=H+"!A;F0@9&]N)W0@<VAO=R!I="X*("`@("`@("`D
M8V%C:&5;)&%P<%T@/2!F86QS93L*("`@('T*"B`@("!R971U<FX@)&-A8VAE
M6R1A<'!=.PI]"@HO*BH*("H@0G5I;&1S('1H92!M96YU('-T<G5C='5R92!D
M97!E;F1I;F<@;VX@87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"B`J+PIF=6YC
M=&EO;B!B=6EL9$UE;G4H*0I["B`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R
M>3L*"B`@("`D87!P<R`](&%R<F%Y*"D["B`@("`D8VAI;&1R96X@/2!A<G)A
M>2@I.PH@("`@9F]R96%C:"`H)')E9VES=')Y+3YA<'!L:6-A=&EO;G,@87,@
M)&%P<"`]/B`D<&%R86US*2!["B`@("`@("`@:68@*&-A;E-E92@D87!P+"`D
M<&%R86US+"`D8VAI;&1R96XI*2!["B`@("`@("`@("`@("1A<'!S6R1A<'!=
M(#T@)'!A<F%M<SL*("`@("`@("!]"B`@("!]"@H@("`@)&UE;G4@/2!A<G)A
M>2@I.PH@("`@9F]R96%C:"`H)&%P<',@87,@)&%P<"`]/B`D<&%R86US*2![
M"B`@("`@("`@+R\@1FEL=&5R(&]U="!A;&P@:&5A9&EN9W,@=VET:&]U="!C
M:&EL9')E;BX*("`@("`@("!I9B`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)VAE
M861I;F<G("8F(&5M<'1Y*"1C:&EL9')E;ELD87!P72DI('L*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H*("`@("`@("`D;65N=5LD87!P72`]
M("1P87)A;7,["B`@("!]"@H@("`@+R\@061D('1H92!A9&UI;FES=')A=&EO
M;B!M96YU(&EF('1H92!U<V5R(&ES(&%N(&%D;6EN+@H@("`@:68@*$%U=&@Z
M.FES061M:6XH*2D@>PH@("`@("`@("1M96YU6R=A9&UI;FES=')A=&EO;B==
M(#T@87)R87DH)VYA;64G(#T^(%\H(D%D;6EN:7-T<F%T:6]N(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@
M)')E9VES=')Y+3YG971);6%G941I<B@I("X@)R]A9&UI;FES=')A=&EO;BYP
M;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-T871U<R<@/3X@)VAE861I;F<G*3L*"B`@("`@("`@9F]R96%C:"`H)')E
M9VES=')Y+3YL:7-T07!P<R@I(&%S("1A<'`I('L*("`@("`@("`@("`@:68@
M*"$D<F5G:7-T<GDM/FAA<TUE=&AO9"@G861M:6Y?;&ES="<L("1A<'`I*2![
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&QI<W0@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)&%P
M<"P@)V%D;6EN7VQI<W0G*3L*("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D
M;65T:&]D(#T^("1V86QS*2!["B`@("`@("`@("`@("`@("!I9B`H)&%P<"`A
M/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`D<F5G
M:7-T<GDM/F=E="@G;F%M92<L("1A<'`I.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A96UP='DH)'9A;'-;)VYA;64G72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&YA;64@+CT@)R`G("X@)'9A;'-;)VYA;64G73L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@2&]R9&4Z.G-T<FEP06-C97-S2V5Y
M*"1V86QS6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&EC;VX@/2!I<W-E="@D=F%L<ULG:6-O;B==*2`_("1R96=I<W1R
M>2T^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D=F%L<ULG:6-O;B==(#H@
M)')E9VES=')Y+3YG970H)VEC;VXG+"`D87!P*3L*"B`@("`@("`@("`@("`@
M("`D;65N=5LG861M:6YI<W1R871I;VY?)R`N("1A<'`@+B`G7R<@+B`D;65T
M:&]D72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D
M;F%M92P*("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)&EC;VXL"B`@
M("`@("`@("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@
M("`@("`@("`@("`@("`@)VUE;G5?<&%R96YT)R`]/B`G861M:6YI<W1R871I
M;VXG+`H@("`@("`@("`@("`@("`@("`@("=U<FPG(#T^($AO<F1E.CIU<FPH
M)')E9VES=')Y+3YA<'!L:6-A=&EO;E=E8E!A=&@H)'9A;'-;)VQI;FLG72P@
M)&%P<"DI+`H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@:68@*$AO<F1E.CIS:&]W4V5R=FEC92@G
M;W!T:6]N<R<I("8F"B`@("`@("`@)&-O;F9;)W!R969S)UU;)V1R:79E<B==
M("$]("<G("8F("1C;VYF6R=P<F5F<R==6R=D<FEV97(G72`A/2`G;F]N92<I
M('L*("`@("`@("`D;65N=5LG;W!T:6]N<R==(#T@87)R87DH)VYA;64G(#T^
M(%\H(D]P=&EO;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM/F=E=$EM86=E1&ER
M*"D@+B`G+W!R969S+G!N9R<I.PH*("`@("`@("`O*B!'970@82!L:7-T(&]F
M(&-O;F9I9W5R86)L92!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@)'!R969S
M7V%P<',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1R96=I<W1R>2T^
M87!P;&EC871I;VYS(&%S("1A<'!L:6-A=&EO;B`]/B`D<&%R86US*2!["B`@
M("`@("`@("`@(&EF("@D<&%R86US6R=S=&%T=7,G72`]/2`G:&5A9&EN9R<@
M?'P*("`@("`@("`@("`@("`@("1P87)A;7-;)W-T871U<R==(#T]("=B;&]C
M:R<@?'P*("`@("`@("`@("`@("`@("%F:6QE7V5X:7-T<R@D<F5G:7-T<GDM
M/F=E="@G9FEL97)O;W0G+"`D87!P;&EC871I;VXI("X@)R]C;VYF:6<O<')E
M9G,N<&AP)RDI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!#:&5C:R!I9B!T:&4@8W5R<F5N="!U
M<V5R(&AA<R!P97)M:7-S:6]N('1O('-E92!T:&ES"B`@("`@("`@("`@("`J
M(&%P<&QI8V%T:6]N+"!A;F0@:68@=&AE(&%P<&QI8V%T:6]N(&ES(&%C=&EV
M92X*("`@("`@("`@("`@("H@061M:6YI<W1R871O<G,@86QW87ES('-E92!A
M;&P@87!P;&EC871I;VYS+B`J+PH@("`@("`@("`@("!I9B`H*$%U=&@Z.FES
M061M:6XH*2`F)B`D<&%R86US6R=S=&%T=7,G72`A/2`G:6YA8W1I=F4G*2!\
M?`H@("`@("`@("`@("`@("`@*"1R96=I<W1R>2T^:&%S4&5R;6ES<VEO;B@D
M87!P;&EC871I;VXI("8F"B`@("`@("`@("`@("`@("`@*"1P87)A;7-;)W-T
M871U<R==(#T]("=A8W1I=F4G*2DI('L*("`@("`@("`@("`@("`@("1P<F5F
M<U]A<'!S6R1A<'!L:6-A=&EO;ET@/2!?*"1P87)A;7-;)VYA;64G72D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'!R
M969S7V%P<'-;)VAO<F1E)UTI*2!["B`@("`@("`@("`@("1M96YU6R=O<'1I
M;VYS7R<@+B`G:&]R9&4G72`](&%R<F%Y*"=N86UE)R`]/B!?*")';&]B86P@
M3W!T:6]N<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<W1A='5S)R`]/B`G86-T:79E)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUE;G5?
M<&%R96YT)R`]/B`G;W!T:6]N<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`D<F5G:7-T<GDM
M/F=E="@G:6-O;B<L("=H;W)D92<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=7)L)R`]/B!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)W-E<G9I8V5S+W!R969S+G!H<#]A<'`]:&]R9&4G*2D[
M"B`@("`@("`@("`@('5N<V5T*"1P<F5F<U]A<'!S6R=H;W)D92==*3L*("`@
M("`@("!]"@H@("`@("`@(&%S;W)T*"1P<F5F<U]A<'!S*3L*("`@("`@("!F
M;W)E86-H("@D<')E9G-?87!P<R!A<R`D87!P(#T^("1N86UE*2!["B`@("`@
M("`@("`@("1M96YU6R=O<'1I;VYS7R<@+B`D87!P72`](&%R<F%Y*"=N86UE
M)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-T871U<R<@/3X@)V%C=&EV92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M96YU7W!A<F5N
M="<@/3X@)V]P=&EO;G,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)')E9VES=')Y+3YG970H)VEC
M;VXG+"`D87!P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W5R;"<@/3X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=S
M97)V:6-E<R]P<F5F<RYP:'`_87!P/2<@+B`D87!P*2D["B`@("`@("`@?0H@
M("`@?0H*("`@(&EF("A!=71H.CII<T%U=&AE;G1I8V%T960H*2D@>PH@("`@
M("`@("1M96YU6R=L;V=O=70G72`](&%R<F%Y*"=N86UE)R`]/B!?*"),;V<@
M;W5T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T871U
M<R<@/3X@)V%C=&EV92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VEC;VXG(#T^("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2`N("<O;&]G
M;W5T+G!N9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R
M;"<@/3X@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=L;V=O=70G+"`G:&]R9&4G
M+"!T<G5E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&%R
M9V5T)R`]/B`G7W!A<F5N="<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;65N
M=5LG;&]G:6XG72`](&%R<F%Y*"=N86UE)R`]/B!?*"),;V<@:6XB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%T=7,G(#T^("=A8W1I
M=F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^
M("1R96=I<W1R>2T^9V5T26UA9V5$:7(H*2`N("<O;&]G:6XN<&YG)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FPG(#T^($AO<F1E.CIG
M971397)V:6-E3&EN:R@G;&]G:6XG+"`G:&]R9&4G+"!T<G5E+"!F86QS92DI
M.PH@("`@?0H*("`@(')E='5R;B`D;65N=3L*?0H*0&1E9FEN92@G05542%](
M04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE
M*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5')E
M92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`G.PH*:68@*"%!
M=71H.CIG971!=71H*"D@)B8@(21C;VYF6R=M96YU)UU;)V%L=V%Y<R==*2![
M"B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*
M?0H*)&ES7VUO>F)A<B`]("AB;V]L*55T:6PZ.F=E=$9O<FU$871A*"=M;WIB
M87(G*3L*"B\O(%-E="!U<"!T:&4@=')E92X*)'1R964@/2`F2&]R9&5?5')E
M93HZ<VEN9VQE=&]N*"=H;W)D95]M96YU)RP@)VIA=F%S8W)I<'0G*3L*)'1R
M964M/G-E=$]P=&EO;BAA<G)A>2@G=&%R9V5T)R`]/B`D:7-?;6]Z8F%R(#\@
M)U]C;VYT96YT)R`Z("=H;W)D95]M86EN)RDI.PH*)&UE;G4@/2!B=6EL9$UE
M;G4H*3L*9F]R96%C:"`H)&UE;G4@87,@)&%P<"`]/B`D<&%R86US*2!["B`@
M("!I9B`H)'!A<F%M<ULG<W1A='5S)UT@/3T@)V)L;V-K)RD@>PH@("`@("`@
M("1B;&]C:R`]("9(;W)D95]";&]C:U]#;VQL96-T:6]N.CIG971";&]C:R@D
M<&%R86US6R=A<'`G72P@)'!A<F%M<ULG8FQO8VMN86UE)UTI.PH@("`@("`@
M(&EF("AI<U]A*"1B;&]C:RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH)&)L;V-K+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*("`@("`@("`D8FQO8VLM/F)U:6QD5')E92@D=')E92P@,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D<&%R86US6R=M96YU
M7W!A<F5N="==*2`_("1P87)A;7-;)VUE;G5?<&%R96YT)UT@.B!N=6QL*3L*
M("`@('T@96QS92!["B`@("`@("`@+R\@3F5E9"!T;R!R=6X@=&AE(&YA;64@
M=&AR;W5G:"!G971T97AT('-I;F-E('1H92!U<V5R)W,*("`@("`@("`O+R!L
M;V-A;&4@;6%Y(&YO="!H879E(&)E96X@;&]A9&5D('=H96X@<F5G:7-T<GDN
M<&AP('=A<PH@("`@("`@("\O('!A<G-E9"X*("`@("`@("`D;F%M92`](%\H
M)'!A<F%M<ULG;F%M92==*3L*"B`@("`@("`@+R\@2&5A9&EN9W,@:&%V92!N
M;R!W96)R;V]T.R!T:&5Y)W)E(&IU<W0@8V]N=&%I;F5R<R!F;W(@;W1H97(*
M("`@("`@("`O+R!M96YU(&ET96US+@H@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=U<FPG72DI('L*("`@("`@("`@("`@)'5R;"`]("1P87)A;7-;)W5R
M;"==.PH@("`@("`@('T@96QS96EF("@D<&%R86US6R=S=&%T=7,G72`]/2`G
M:&5A9&EN9R<@?'P@(6ES<V5T*"1P87)A;7-;)W=E8G)O;W0G72DI('L*("`@
M("`@("`@("`@)'5R;"`](&YU;&P["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'5R;"`]($AO<F1E.CIU<FPH)'!A<F%M<ULG=V5B<F]O="==("X@
M)R\G("X@*&ES<V5T*"1P87)A;7-;)VEN:71I86Q?<&%G92==*2`_("1P87)A
M;7-;)VEN:71I86Q?<&%G92==(#H@)R<I*3L*("`@("`@("!]"@H@("`@("`@
M("1N;V1E7W!A<F%M<R`](&%R<F%Y*"=U<FPG(#T^("1U<FPL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1A<F=E="<@/3X@:7-S970H)'!A<F%M
M<ULG=&%R9V5T)UTI(#\@)'!A<F%M<ULG=&%R9V5T)UT@.B!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B!I<W-E="@D<&%R
M86US6R=I8V]N)UTI(#\@)'!A<F%M<ULG:6-O;B==(#H@)')E9VES=')Y+3YG
M970H)VEC;VXG+"`D87!P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G:6-O;F1I<B<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*3L*("`@("`@("`D=')E92T^861D3F]D92@D87!P+"`A96UP='DH)'!A
M<F%M<ULG;65N=5]P87)E;G0G72D@/R`D<&%R86US6R=M96YU7W!A<F5N="==
M(#H@;G5L;"P@)&YA;64L(#`L(&9A;'-E+"`D;F]D95]P87)A;7,I.PH@("`@
M?0I]"@HO+R!)9B!W92=R92!S97)V:6YG(&$@<F5Q=65S="!T;R!T:&4@2E,@
M=7!D871E(&-L:65N="P@:G5S="!R96YD97(@=&AE"B\O('5P9&%T960@;F]D
M92!J879A<V-R:7!T+@II9B`H571I;#HZ9V5T1F]R;41A=&$H)VAT='!C;&EE
M;G0G*2D@>PH@("`@:&5A9&5R*"=#;VYT96YT+51Y<&4Z('1E>'0O:F%V87-C
M<FEP=#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@2&]R
M9&4Z.FEN;&EN95-C<FEP=$9I;&5S*"D["B`@("!E8VAO("1T<F5E+3YR96YD
M97).;V1E1&5F:6YI=&EO;G,H*3L*("`@(&5X:70["GT*"B1R=&P@/2!I<W-E
M="@D;FQS6R=R=&PG75LD;&%N9W5A9V5=*3L*)&)O9'E#;&%S<R`]("=S:61E
M8F%R)SL*:68@*"1B<F]W<V5R+3YH87-1=6ER:R@G<V-R;VQL8F%R7VEN7W=A
M>2<I*2!["B`@("`D8F]D>4-L87-S("X]("<@<V-R;VQL8F%R+7%U:7)K)SL*
M?0I(;W)D93HZ861D4V-R:7!T1FEL92@G:'1T<&-L:65N="YJ<R<L("=H;W)D
M92<L('1R=64I.PI(;W)D93HZ861D4V-R:7!T1FEL92@G:&ED96%B;&4N:G,G
M+"`G:&]R9&4G+"!T<G5E*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+W!O<G1A;"]S:61E8F%R+FEN8R<["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<```````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S,#$P(#$P-3$U-#,T,30T(#`R,C0W,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@)$AO<F1E.B!H;W)D92]S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M+'8@,2XS.2XQ,"XW(#(P,#8O,#,O,#@@,3@Z,#`Z-38@8VAU8VL@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE
M*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD[
M"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["@II9B`H(4%U=&@Z.FES
M075T:&5N=&EC871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&
M86EL=7)E4F5D:7)E8W0H*3L*?0H*+R\@1V5T(&9U;&P@;F%M92!F;W(@=&ET
M;&4*)&ED96YT:71Y(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*3L*)&9U;&QN
M86UE(#T@)&ED96YT:71Y+3YG971686QU92@G9G5L;&YA;64G*3L*:68@*&5M
M<'1Y*"1F=6QL;F%M92DI('L*("`@("1F=6QL;F%M92`]($%U=&@Z.F=E=$%U
M=&@H*3L*?0H*+R\@1V5T(')E9G)E<V@@:6YT97)V86PN"FEF("@D<')E9G,M
M/F=E=%9A;'5E*"=S=6UM87)Y7W)E9G)E<VA?=&EM92<I*2!["B`@("`D<F5F
M<F5S:%]T:6UE(#T@)'!R969S+3YG971686QU92@G<W5M;6%R>5]R969R97-H
M7W1I;64G*3L*("`@("1R969R97-H7W5R;"`]($AO<F1E.CIA<'!L:6-A=&EO
M;E5R;"@G<V5R=FEC97,O<&]R=&%L+R<I.PI]"@HO+R!,;V%D(&QA>6]U="!F
M<F]M('!R969E<F5N8V5S+@HD;&%Y;W5T7W!R968@/2`D<')E9G,M/F=E=%9A
M;'5E*"=P;W)T86Q?;&%Y;W5T)RD["FEF("@A)&QA>6]U=%]P<F5F*2!["B`@
M("`D;&%Y;W5T7W!R968@/2!(;W)D95]";&]C:U]#;VQL96-T:6]N.CIG971&
M:7AE9$)L;V-K<R@I.PI]"B1V:65W(#T@;F5W($AO<F1E7T)L;V-K7TQA>6]U
M=%]6:65W*"1L87EO=71?<')E9BD["B1L87EO=71?:'1M;"`]("1V:65W+3YT
M;TAT;6PH*3L*)&-S<T%P<',@/2`D=FEE=RT^9V5T07!P;&EC871I;VYS*"D[
M"B1L:6YK5&%G<R`]("1V:65W+3YG971,:6YK5&%G<R@I.PH*)'1I=&QE(#T@
M7R@B37D@4&]R=&%L(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@
M)R]P;W)T86PO;65N=2YI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R
M87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*96-H;R`D;&%Y;W5T7VAT
M;6P["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM9F]O=&5R
M+FEN8R<["@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`R,C4P-"`Q,#4Q-30S-#$T-"`P,C(W,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M("1(;W)D93H@:&]R9&4O<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`L=B`Q
M+C,N,BXV(#(P,#8O,#4O,CD@,38Z-#`Z-#D@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N(&QO861#871E
M9V]R:65S*"1D979I8V4I"GL*("`@(&=L;V)A;"`D9'0L("1C871E9V]R:65S
M36%P+"`D;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,["B`@("`D;6%P(#T@)&1T
M+3YG971/8FIE8W0H)&1E=FEC90H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("<Z8V%T96=O<FEE<R<I.PH@("`@:68@*&ES7V$H)&UA<"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`D
M8V%T96=O<FEE<TUA<"`]("1M87`M/F=E="@G;6%P)RD["B`@("`D;6ES<VEN
M9U-E<G9E<D-A=&5G;W)I97,@/2`D;6%P+3YG970H)VUI<W-I;F=397)V97)#
M871E9V]R:65S)RD["@H@("`@<F5T=7)N('1R=64["GT*"F9U;F-T:6]N('-T
M;W)E0V%T96=O<FEE<R@D9&5V:6-E*0I["B`@("!G;&]B86P@)&1T+"`D8V%T
M96=O<FEE<TUA<"P@)&UI<W-I;F=397)V97)#871E9V]R:65S.PH*("`@(&EF
M("@A:7-?87)R87DH)&-A=&5G;W)I97--87`I*2!["B`@("`@("`@<F5T=7)N
M.R`O+R!N;W1H:6YG('1O(&1O"B`@("!]"@H@("`@)&UA<"`]("9N97<@1&%T
M851R965/8FIE8W0H)&1E=FEC92`N("<Z8V%T96=O<FEE<R<I.PH@("`@)&UA
M<"T^<V5T*"=M87`G+"`D8V%T96=O<FEE<TUA<"D["B`@("`D;6%P+3YS970H
M)VUI<W-I;F=397)V97)#871E9V]R:65S)RP@)&UI<W-I;F=397)V97)#871E
M9V]R:65S*3L*"B`@("`D<B`]("1D="T^861D*"1M87`I.PH@("`@:68@*&ES
M7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@("`@("`O+R!/8FIE8W0@86QR
M96%D>2!E>&ES=',Z('5P9&%T92!I;G-T96%D+@H@("`@("`@("1R(#T@)&1T
M+3YU<&1A=&5$871A*"1M87`I.PH@("`@?0I]"@I`9&5F:6YE*"=(3U)$15]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U!R969S+U5)+G!H<"<["@II9B`H(4%U=&@Z.FES075T:&5N
M=&EC871E9"@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E
M4F5D:7)E8W0H*3L*?0H*)&1R:79E<B`]("1'3$]"04Q36R=C;VYF)UU;)V1A
M=&%T<F5E)UU;)V1R:79E<B==.PHD<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E
M<D-O;F9I9R@G9&%T871R964G+"`D9')I=F5R*3L*)'!A<F%M<R`](&%R<F%Y
M7VUE<F=E*"1P87)A;7,L(&%R<F%Y*"`G9W)O=7`G(#T^("=S>6YC;6PG("DI
M.PH*)&1T(#T@)D1A=&%4<F5E.CIS:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M
M<RD["@HO*B!5<V5R;F%M92!I<R!U<V5D(&%S(')O;W0@9F]R('-Y;F-M;"!D
M871A=')E92X@("A&;W(@:&ES=&]R:6,*("H@<F5A<V]N<RXI("HO"B1U<V5R
M;F%M92`]($%U=&@Z.F=E=$%U=&@H*3L*)&=R;W5P(#T@)W-Y;F-M;"<[("\O
M('!R969E<F5N8V4@9W)O=7`*"B1A8W1I;VY)1"`](%5T:6PZ.F=E=$9O<FU$
M871A*"=A8W1I;VY)1"<I.PIS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=D
M96QE=&5A;F-H;W(G.@H@("`@)&1E=FEC96ED(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V1E=FEC96ED)RD["B`@("`D9&(@/2!5=&EL.CIG971&;W)M1&%T82@G
M9&(G*3L*("`@("1I9"`]("1U<V5R;F%M92`N("<Z)R`N("1D979I8V5I9"`N
M("<Z<W5M;6%R>3HG("X@)&1B.PH@("`@)&ED(#T@)&1T+3YR96UO=F4H)&ED
M+&9A;'-E*3L*("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")%<G)O<B!D
M96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B*2P@)&ED+3YG971-97-S86=E*"DI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+F5R<F]R)RD[
M"B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B
M)&ED(%-Y;F,@86YC:&]R(&9O<B!D979I8V4@)R1D979I8V5I9"<@9&%T86)A
M<V4@)R1D8B<@9&5L971E9"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=H;W)D92YS=6-C97-S)RD["B`@("!]"B`@("!B<F5A:SL*"F-A<V4@
M)V1E;&5T96QO9R<Z"B`@("`D:60@/2`D9'0M/G)E;6]V92@G<')E=FEO=7-3
M>6YC3&]G)RP@9F%L<V4I.PH@("`@:68@*&ES7V$H)&ED+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(I+"`D:60M/F=E=$UE<W-A
M9V4H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N97)R
M;W(G*3L*("`@('T@96QS92!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"A?*")3>6YC(&QO9R!D96QE=&5D(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?0H@("`@8G)E86L["@H@
M8V%S92`G=7!D871E7V-A=&5G;W)I97,G.@H@("`@)&1E=FEC92`](%5T:6PZ
M.F=E=$9O<FU$871A*"=D979I8V4G*3L*("`@(&QO861#871E9V]R:65S*"1D
M979I8V4I.PH*("`@(&9O<F5A8V@@*"1?4$]35"!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@(&EF("AS=6)S='(H)&ME>2P@,"P@.2D@/3T@)V-A=&5G
M;W)Y.B<I('L*("`@("`@("`@("`@)&-A=&5G;W)Y(#T@<W5B<W1R*"1K97DL
M.2D["B`@("`@("`@("`@(&QI<W0H+"1C871E9V]R>2D@/2!E>'!L;V1E*"<Z
M)RP@)&ME>2PR*3L*("`@("`@("`@("`@)'9A;'5E(#T@571I;#HZ9V5T1F]R
M;41A=&$H)&ME>2D["B`@("`@("`@("`@("1C871E9V]R:65S36%P6R1C871E
M9V]R>5T@/2`D=F%L=64["B`@("`@("`@("`@('5N<V5T*"1M:7-S:6YG4V5R
M=F5R0V%T96=O<FEE<ULD=F%L=65=*3L*("`@("`@("!]"B`@("!]"B`@("!S
M=&]R94-A=&5G;W)I97,H)&1E=FEC92D["B`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(DUA<'!I;F=S('-T;W)E9"XB*2D["@H@("`@8G)E86L["GT*"B\J
M(%-H;W<@=&AE(&AE861E<BX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F
M<R]522YP:'`G.PIR97%U:7)E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]P<F5F
M<RYP:'`G.PHD87!P(#T@)VAO<F1E)SL*"E!R969S7U5).CIH86YD;&5&;W)M
M*"1G<F]U<"P@)'!R969S*3L*4')E9G-?54DZ.F=E;F5R871E2&5A9&5R*"1G
M<F]U<"D["@HO+R!`=&]D;SH@;6]V92!T:&ES('1O('1E;7!L871E"C\^"@H\
M9F]R;2!M971H;V0](G!O<W0B(&YA;64](G!R969S(B!A8W1I;VX](CP_<&AP
M(&5C:&\@2&]R9&4Z.D%P<&QI8V%T:6]N55),*"<O<V5R=FEC97,O<')E9G,N
M<&AP)RD@/SXB/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)
M1"(@=F%L=64](G5P9&%T95]P<F5F<R(@+SX*/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB9W)O=7`B('9A;'5E/2(\/W!H<"!E8VAO("1G<F]U<"`_/B(@
M+SX*/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB87!P(B!V86QU93TB:&]R
M9&4B("\^"E-O<G)Y+"!N;R!C;VYF:6=U<F%B;&4@;W!T:6]N<R!Y970N"E-E
M92`\82!H<F5F/2)H='1P.B\O=VEK:2YH;W)D92YO<F<O4WEN8TAO=U1O(CY3
M>6YC($AO=U1O/"]A/B!F;W(@9G5R=&AE<B!I;F9O<FUA=&EO;BX*/#]P:'`@
M+RH@)&AE;'!L:6YK/2<G.R`D<')E9CTG<WEN8VUL7V-R96%T95]L;V<G.R!R
M97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N
M("<O<')E9G,O8VAE8VMB;W@N:6YC)R`J+R`_/@H*/'`@8VQA<W,](FYO=W)A
M<"(^"B`\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU
M93TB4V%V92!/<'1I;VYS(B`O/@H@/&EN<'5T('1Y<&4](G)E<V5T(B!C;&%S
M<STB8G5T=&]N(B!V86QU93TB56YD;R!#:&%N9V5S(B`O/@H@/&EN<'5T('1Y
M<&4](F)U='1O;B(@8VQA<W,](F)U='1O;B(@=F%L=64](E)E='5R;B!T;R!/
M<'1I;VYS(B!O;F-L:6-K/2)D;V-U;65N="YP<F5F<RYA8W1I;VY)1"YV86QU
M93TP.R!D;V-U;65N="YP<F5F<RYG<F]U<"YV86QU93TG)SL@9&]C=6UE;G0N
M<')E9G,N<W5B;6ET*"D[(B`O/@H\+W`^"CPO9F]R;3X*/#]P:'`*)&ED(#T@
M)&1T+3YG971)9"@D=7-E<FYA;64I.PHD9&5V:6-E<R`]("1D="T^9V5T0GE)
M9"A$051!5%)%15]&3U)-051?1DQ!5"P@)&ED+"!T<G5E+"!$051!5%)%15]2
M3T]4+"`Q*3L*:68@*&ES7V%R<F%Y*"1D979I8V5S*2`F)B!C;W5N="@D9&5V
M:6-E<RD@/B`Q*2!["B`@("!A<G)A>5]S:&EF="@D9&5V:6-E<RD["@HO+R!`
M=&]D;SH@;6]V92!T;R!T96UP;&%T90H_/@H\9&EV(&-L87-S/2)H96%D97(B
M/@H@/#]P:'`@96-H;R!(;W)D93HZ;&EN:RA(;W)D93HZ<V5L9E523"@I+"!?
M*")2969R97-H(BDI("X@2&]R9&4Z.FEM9R@G<F5L;V%D+G!N9R<L(%\H(E)E
M;&]A9"(I+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2D@
M/SX\+V$^"B!4:6UE<W1A;7!S(&]F('-U8V-E<W-F=6P@<WEN8R!S97-S:6]N
M<PH\+V1I=CX*/'1A8FQE(&-L87-S/2)S=')I<&5D(B`^"B`\='(^"B`@/'1H
M/D1E=FEC93PO=&@^/'1H/D1A=&%B87-E/"]T:#X\=&@^4V5R=F5R+513/"]T
M:#X\=&@^0VQI96YT+513/"]T:#X*("`\=&@^1&5L971E/"]T:#X*(#PO='(^
M"@H\/W!H<`H@("`@9F]R96%C:"`H)&1E=FEC97,@87,@)&1E=FEC92D@>PH@
M("`@("`@("1T;7`@/2!E>'!L;V1E*"<Z)RP@)&1E=FEC92D["B`@("`@("`@
M)&1E=FEC95]N86UE(#T@87)R87E?<&]P*"1T;7`I.PH*("`@("`@("`D:60@
M/2`D9'0M/F=E=$ED*"1D979I8V4@+B`G.G-U;6UA<GDG*3L*("`@("`@("!I
M9B`H:7-?82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@?0H@("`@("`@("1S=6UM87)I97,@/2`D9'0M/F=E
M=$)Y260H1$%40512145?1D]234%47U12144L("1I9"P@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$051!5%)%15]23T]4+"`R
M*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1S=6UM87)I97-;)&ED72DI('L*
M("`@("`@("`@("`@)&\@/2`F("1D="T^9V5T3V)J96-T<RAA<G)A>5]K97ES
M*"1S=6UM87)I97-;)&ED72DI.PH*("`@("`@("`@("`@9F]R96%C:"`H)&\@
M87,@)&]O*2!["B`@("`@("`@("`@("`@("`D="`](&5X<&QO9&4H)SHG+"`D
M;V\M/F=E=$YA;64H*2D["B`@("`@("`@("`@("`@("`D9&(@/2!A<G)A>5]P
M;W`H)'0I.PH@("`@("`@("`@("`@("`@)'-A(#T@)&]O+3YG970H)U-E<G9E
M<D%N8VAO<B<I.PH@("`@("`@("`@("`@("`@)&-A(#T@)&]O+3YG970H(D-L
M:65N=$%N8VAO<B(I.PH*("`@("`@("`@("`@("`@("\O($!T;V1O.B!M;W9E
M('1O('1E;7!L871E"B`@("`@("`@("`@("`@("!E8VAO("<\='(^/'1D/B<@
M+B`D9&5V:6-E7VYA;64@+B`G/"]T9#X\=&0^)R`N("1D8B`N("<\+W1D/CQT
M9#XG("X*("`@("`@("`@("`@("`@("`@("!S=')F=&EM92@D<')E9G,M/F=E
M=%9A;'5E*"=D871E7V9O<FUA="<I("X@)R`E2#HE32<L(&%R<F%Y7W!O<"@D
M<V$I*2`N"B`@("`@("`@("`@("`@("`@("`@)SPO=&0^/'1D/B<@+B!A<G)A
M>5]P;W`H)&-A*2`N("<\+W1D/CQT9#XG("X*("`@("`@("`@("`@("`@("`@
M("`G/&9O<FT@;65T:&]D/2)P;W-T(CX\:6YP=70@='EP93TB:&ED9&5N(B!N
M86UE/2)D979I8V5I9"(@=F%L=64](B<@+@H@("`@("`@("`@("`@("`@("`@
M("1D979I8V5?;F%M92`N("<B+SXG("X*("`@("`@("`@("`@("`@("`@("`G
M/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB86-T:6]N240B('9A;'5E/2)D
M96QE=&5A;F-H;W(B("\^)R`N"B`@("`@("`@("`@("`@("`@("`@)SQI;G!U
M="!T>7!E/2)H:61D96XB(&YA;64](F1B(B!V86QU93TB)R`N("1D8B`N("<B
M("\^)R`N"B`@("`@("`@("`@("`@("`@("`@)SQI;G!U="!T>7!E/2)S=6)M
M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2)$96QE=&4B("\^/"]F;W)M/B<@
M+@H@("`@("`@("`@("`@("`@("`@("<\+W1D/CPO='(^)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*("`@(&5C:&\@)SPO=&%B;&4^)SL*?0H*
M+R\@0V%T96=O<GD@:&%N9&QI;F<N"G)E<75I<F5?;VYC92`G2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<"<["B1C36%N86=E<B`]("9N97<@4')E
M9G-?0V%T96=O<GE-86YA9V5R*"D["@IF;W)E86-H("@D9&5V:6-E<R!A<R`D
M9&5V:6-E*2!["B`@("`D=&UP(#T@97AP;&]D92@G.B<L("1D979I8V4I.PH@
M("`@)&1E=FEC95]N86UE(#T@87)R87E?<&]P*"1T;7`I.PH*("`@(&EF("@A
M;&]A9$-A=&5G;W)I97,H)&1E=FEC92DI('L*("`@("`@("!C;VYT:6YU93L*
M("`@('T*+R]V87)?9'5M<"@D8VQI96X*("`@("1I(#T@,#L*+R\@0'1O9&\Z
M(&UO=F4@=&\@=&5M<&QA=&4*/SX*/&9O<FT@;65T:&]D/2)P;W-T(B!N86UE
M/2)P<F5F<R(@86-T:6]N/2(\/W!H<"!E8VAO($AO<F1E.CIS96QF55),*"D@
M/SXB/@H\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I;VY)1"(@=F%L
M=64](G5P9&%T95]C871E9V]R:65S(B`O/@H\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2)D979I8V4B('9A;'5E/2(\/W!H<"!E8VAO("1D979I8V4@/SXB
M("\^"@H\9&EV(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!(;W)D93HZ
M;&EN:RA(;W)D93HZ<V5L9E523"@I+"!?*")2969R97-H(BDI("X@2&]R9&4Z
M.FEM9R@G<F5L;V%D+G!N9R<L(%\H(E)E;&]A9"(I+"`G)RP@)')E9VES=')Y
M+3YG971);6%G941I<B@G:&]R9&4G*2D@/SX\+V$^"B!-87!P:6YG(&]F($-A
M=&5G;W)I97,@9F]R($1E=FEC92`\/W!H<"!E8VAO("1D979I8V5?;F%M92`_
M/@H\+V1I=CX*/'1A8FQE(&-L87-S/2)S=')I<&5D(B`^"CQT<CX\=&@^1&5V
M:6-E($-A=&5G;W)Y/"]T:#X\=&@^2&]R9&4@0V%T96=O<GD\+W1H/@H\=&@^
M4W5M;6%R>2!O9B!L87-T(&5N8V]U;G1E<F5D(&5N=')Y/"]T:#X\+W1R/@H\
M/W!H<`H@("`@9F]R96%C:"`H)&-A=&5G;W)I97--87`@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("!E8VAO("(\='(@8VQA<W,]7")I=&5M(B`N("@K
M*R1I("4@,BD@+B`B7"(^/'1D/B(*("`@("`@("`N("1K97DN("<\+W1D/CQT
M9#XG.PH@("`@("`@("1V(#T@:7-?87)R87DH)'9A;'5E*2`_("<G(#H@)'9A
M;'5E.PH@("`@("`@(&5C:&\@)&--86YA9V5R+3YG971396QE8W0H)V-A=&5G
M;W)Y.B<@+B`D:V5Y+"`D=BD["B`@("`@("`@96-H;R`G/"]T9#X\=&0^)SL*
M("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("!E
M8VAO("1V86QU95LP73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E
M8VAO("(F;F)S<#LB.PH@("`@("`@('T*("`@("`@("!E8VAO("<\+W1D/CPO
M='(^)SL*"B`@("!]"B`@("!F;W)E86-H("@D;6ES<VEN9U-E<G9E<D-A=&5G
M;W)I97,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("!E8VAO("<\='(^
M/'1D/CQE;3YT;R!B92!D969I;F5D/"]E;3X\+W1D/CQT9#XG("X@)&ME>2`N
M("<\+W1D/CQT9#XG("X@)'9A;'5E("X@)SPO=&0^/"]T<CXG.PH@("`@?0H*
M("`@(&5C:&\@(CPO=&%B;&4^7&XB.PH@("`@96-H;R`G/&EN<'5T('1Y<&4]
M(G-U8FUI="(@8VQA<W,](F)U='1O;B(@=F%L=64](E5P9&%T92!#871E9V]R
M:65S(B`O/CPO9F]R;3XG.PI]"@HO*B!$:7-P;&%Y(&QO9R!O9B!P<F5V:6]U
M<R!S>6YC+B`J+PHD;F%M92`]("=P<F5V:6]U<U-Y;F-,;V<G.PHD:6YF;R`]
M("8D9'0M/F=E=$]B:F5C="@D;F%M92D["@II9B`H(6ES7V$H)&EN9F\L("=0
M14%27T5R<F]R)RD@)B8@:7-?87)R87DH)&QO9R`]("1I;F9O+3YG970H)VQO
M9R<I*2D@>PH@("`@+R\@0'1O9&\@;6]V92!T;R!T96UP;&%T90H_/@H\9&EV
M(&-L87-S/2)H96%D97(B/@H@/#]P:'`@96-H;R!?*"),;V<@;V8@<')E=FEO
M=7,@<WEN8R!S97-S:6]N(BD@/SX*(#P_<&AP(&5C:&\@2&]R9&4Z.FQI;FLH
M2&]R9&4Z.G-E;&954DPH*2P@7R@B4F5F<F5S:"(I*2`N($AO<F1E.CII;6<H
M)W)E;&]A9"YP;F<G+"!?*")2969R97-H(BDI(#\^/"]A/@H@/&9O<FT@;65T
M:&]D/2)P;W-T(CX*("`\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2)A8W1I
M;VY)1"(@=F%L=64](F1E;&5T96QO9R(@+SX*("`\:6YP=70@='EP93TB<W5B
M;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?*")$96QE
M=&4@3&]G(BD@/SXB("\^"B`\+V9O<FT^"CPO9&EV/@H*/'1A8FQE(&-L87-S
M/2)S=')I<&5D(B!W:61T:#TB,3`P)2(^"B`\='(@8VQA<W,](FYO=W)A<"(^
M"B`@/'1H('=I9'1H/2(U)2(^/#]P:'`@96-H;R!?*")4:6UE(BD@/SX\+W1H
M/CQT:#X\/W!H<"!E8VAO(%\H(DQE=F5L(BD@/SX\+W1H/CQT:#X\/W!H<"!E
M8VAO(%\H(D9I;&4B*2`_/CPO=&@^/'1H/CP_<&AP(&5C:&\@7R@B365S<V%G
M92(I(#\^/"]T:#X*(#PO='(^"CP_<&AP(&9O<F5A8V@@*"1L;V<@87,@)&QO
M9V5N=')Y*3H@/SX*(#QT<CX*("`\=&0^"B`@(#P_<&AP(&5C:&\@<W1R9G1I
M;64H)'!R969S+3YG971686QU92@G9&%T95]F;W)M870G*2`N("<@)4@Z)4TZ
M)5,G+"`D;&]G96YT<GE;)W1S)UTI(#\^"B`@/"]T9#X*("`\=&0^"B`@(#P_
M<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D;&]G96YT<GE;)VQE=F5L)UTI
M(#\^"B`@/"]T9#X*("`\=&0^"B`@/#]P:'`*("!I9B`H<')E9U]M871C:"@G
M+UPO4WEN8TU,7"YP:'`D+R<L("1L;V=E;G1R>5LG9FEL92==*2D@>PH@("`@
M("`D9FEL92`]("=F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"YP:'`G.PH@('T@
M96QS92!["B`@("`@("1F:6QE(#T@<')E9U]R97!L86-E*"<O7BXJ7"]3>6YC
M34Q<+R@N*BDD+R<L("=F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"\D,2<L("1L
M;V=E;G1R>5LG9FEL92==*3L*("!]"B`@96-H;R!(;W)D93HZ;&EN:R@G:'1T
M<#HO+V-V<RYH;W)D92YO<F<O8V\N<&AP+R<*("`@("`@("`@("`@("`@("`@
M("X@)&9I;&4@("X@)S]R/4A%040C)R`N('1R:6TH)&QO9V5N=')Y6R=L:6YE
M)UTI+"`G)RP@)R<L("=C=G,G*0H@("`@("`N('!R96=?<F5P;&%C92@G+UXN
M*EPO*%M>7"]=*BDD+R<L("<D,2<L("1L;V=E;G1R>5LG9FEL92==*0H@("`@
M("`N("<Z)R`N('1R:6TH)&QO9V5N=')Y6R=L:6YE)UTI"B`@/SX*("`\+W1D
M/@H@(#QT9#X*("`@/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1L;V=E
M;G1R>5LG;65S<V%G92==*2`_/@H@(#PO=&0^"B`\+W1R/@H\/W!H<"!E;F1F
M;W)E86-H.R`_/@H\+W1A8FQE/@H*/#]P:'`*?0H*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$`
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q-#0@,#(R,S8S`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]L86YG````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,R`P,C,S,#,`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,`````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30S(#`R
M-#`T,P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q-#,@,#(S-S$P`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,`````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T-"`P,C,V,S``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+V1I86QO
M9RYJ<P``````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-3<T(#$P-3$U-#,T
M,30T(#`R-#(U,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````O+R!H=&UL07)E82!V,RXP("T@0V]P>7)I9VAT("AC*2`R,#`S
M+3(P,#4@9'EN87)C:"YC;VT*+R\@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,C`P,BTR,#`S(&EN=&5R86-T:79E=&]O;',N8V]M+"!I;F,N"B\O
M(%1H:7,@8V]P>7)I9VAT(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U
M<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O(%!O<G1I;VYS("AC*2!D>6YA
M<F-H+F-O;2P@,C`P,RTR,#`T"B\O"B\O($$@9G)E92!765-)5UE'(&5D:71O
M<B!R97!L86-E;65N="!F;W(@/'1E>'1A<F5A/B!F:65L9',N"B\O($9O<B!F
M=6QL('-O=7)C92!C;V1E(&%N9"!D;V-S+"!V:7-I="!H='1P.B\O=W=W+FEN
M=&5R86-T:79E=&]O;',N8V]M+PHO+PHO+R!697)S:6]N(#,N,"!D979E;&]P
M960@8GD@36EH86D@0F%Z;VXN"B\O("`@:'1T<#HO+V1Y;F%R8V@N8V]M+VUI
M<VAO;PHO+PHO+R`D260Z(&1I86QO9RYJ<RQV(#$N-R`R,#`U+S`Q+S(P(#$W
M.C0Y.C`T(&UI<VAO;R!%>'`@)`H*+R\@5&AO=6=H(")$:6%L;V<B(&QO;VMS
M(&QI:V4@86X@;V)J96-T+"!I="!I<VXG="!R96%L;'D@86X@;V)J96-T+B`@
M26YS=&5A9`HO+R!I="=S(&IU<W0@;F%M97-P86-E(&9O<B!P<F]T96-T:6YG
M(&=L;V)A;"!S>6UB;VQS+@H*9G5N8W1I;VX@1&EA;&]G*'5R;"P@86-T:6]N
M+"!I;FET*2!["@EI9B`H='EP96]F(&EN:70@/3T@(G5N9&5F:6YE9"(I('L*
M"0EI;FET(#T@=VEN9&]W.PDO+R!P87-S('1H:7,@=VEN9&]W(&]B:F5C="!B
M>2!D969A=6QT"@E]"@E$:6%L;V<N7V=E8VMO3W!E;DUO9&%L*'5R;"P@86-T
M:6]N+"!I;FET*3L*?3L*"D1I86QO9RY?<&%R96YT179E;G0@/2!F=6YC=&EO
M;BAE=BD@>PH)<V5T5&EM96]U="@@9G5N8W1I;VXH*2![(&EF("A$:6%L;V<N
M7VUO9&%L("8F("%$:6%L;V<N7VUO9&%L+F-L;W-E9"D@>R!$:6%L;V<N7VUO
M9&%L+F9O8W5S*"D@?2!]+"`U,"D["@EI9B`H1&EA;&]G+E]M;V1A;"`F)B`A
M1&EA;&]G+E]M;V1A;"YC;&]S960I('L*"0E(5$U,07)E82Y?<W1O<$5V96YT
M*&5V*3L*"7T*?3L*"@HO+R!S:&]U;&0@8F4@82!F=6YC=&EO;BP@=&AE(')E
M='5R;B!H86YD;&5R(&]F('1H92!C=7)R96YT;'D@;W!E;F5D(&1I86QO9RX*
M1&EA;&]G+E]R971U<FX@/2!N=6QL.PH*+R\@8V]N<W1A;G0L('1H92!C=7)R
M96YT;'D@;W!E;F5D(&1I86QO9PI$:6%L;V<N7VUO9&%L(#T@;G5L;#L*"B\O
M('1H92!D:6%L;V<@=VEL;"!R96%D(&ET)W,@87)G<R!F<F]M('1H:7,@=F%R
M:6%B;&4*1&EA;&]G+E]A<F=U;65N=',@/2!N=6QL.PH*1&EA;&]G+E]G96-K
M;T]P96Y-;V1A;"`](&9U;F-T:6]N*'5R;"P@86-T:6]N+"!I;FET*2!["@EV
M87(@9&QG(#T@=VEN9&]W+F]P96XH=7)L+"`B:&%D:6%L;V<B+`H)"0D@("`@
M("`B=&]O;&)A<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I9'1H
M/3$P+&AE:6=H=#TQ,"PB("L*"0D)("`@("`@(G-C<F]L;&)A<G,];F\L<F5S
M:7IA8FQE/7EE<RQM;V1A;#UY97,L9&5P96YD86)L93UY97,B*3L*"41I86QO
M9RY?;6]D86P@/2!D;&<["@E$:6%L;V<N7V%R9W5M96YT<R`](&EN:70["@H)
M+R\@8V%P='5R92!S;VUE('=I;F1O=R=S(&5V96YT<PH)9G5N8W1I;VX@8V%P
M=VEN*'<I('L*"0E(5$U,07)E82Y?861D179E;G0H=RP@(F-L:6-K(BP@1&EA
M;&]G+E]P87)E;G1%=F5N="D["@D)2%1-3$%R96$N7V%D9$5V96YT*'<L(")M
M;W5S961O=VXB+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,07)E82Y?
M861D179E;G0H=RP@(F9O8W5S(BP@1&EA;&]G+E]P87)E;G1%=F5N="D["@E]
M.PH)+R\@<F5L96%S92!T:&4@8V%P='5R960@979E;G1S"@EF=6YC=&EO;B!R
M96QW:6XH=RD@>PH)"4A434Q!<F5A+E]R96UO=F5%=F5N="AW+"`B8VQI8VLB
M+"!$:6%L;V<N7W!A<F5N=$5V96YT*3L*"0E(5$U,07)E82Y?<F5M;W9E179E
M;G0H=RP@(FUO=7-E9&]W;B(L($1I86QO9RY?<&%R96YT179E;G0I.PH)"4A4
M34Q!<F5A+E]R96UO=F5%=F5N="AW+"`B9F]C=7,B+"!$:6%L;V<N7W!A<F5N
M=$5V96YT*3L*"7T["@EC87!W:6XH=VEN9&]W*3L*"2\O(&-A<'1U<F4@;W1H
M97(@9G)A;65S"@EF;W(@*'9A<B!I(#T@,#L@:2`\('=I;F1O=RYF<F%M97,N
M;&5N9W1H.R!C87!W:6XH=VEN9&]W+F9R86UE<UMI*RM=*2D["@DO+R!M86ME
M('5P(&$@9G5N8W1I;VX@=&\@8F4@8V%L;&5D('=H96X@=&AE($1I86QO9R!E
M;F1S+@H)1&EA;&]G+E]R971U<FX@/2!F=6YC=&EO;B`H=F%L*2!["@D):68@
M*'9A;"`F)B!A8W1I;VXI('L*"0D)86-T:6]N*'9A;"D["@D)?0H)"7)E;'=I
M;BAW:6YD;W<I.PH)"2\O(&-A<'1U<F4@;W1H97(@9G)A;65S"@D)9F]R("AV
M87(@:2`](#`[(&D@/"!W:6YD;W<N9G)A;65S+FQE;F=T:#L@<F5L=VEN*'=I
M;F1O=RYF<F%M97-;:2LK72DI.PH)"41I86QO9RY?;6]D86P@/2!N=6QL.PH)
M?3L*?3L*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+W!O<'5P=VEN+FIS````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W
M,S4S(#$P-3$U-#,T,30T(#`R-#8W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````O+R`H8RD@9'EN87)C:"YC;VT@,C`P,RTR
M,#`U"B\O($1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE('1E<FUS(&%S($A4
M34Q!<F5A(&ET<V5L9BX*"F9U;F-T:6]N(%!O<'5P5VEN*&5D:71O<BP@=&ET
M;&4L(&AA;F1L97(L(&EN:71&=6YC=&EO;BD@>PH)=&AI<RYE9&ET;W(@/2!E
M9&ET;W(["@ET:&ES+FAA;F1L97(@/2!H86YD;&5R.PH)=F%R(&1L9R`]('=I
M;F1O=RYO<&5N*"(B+"`B7U]H85]D:6%L;V<B+`H)"0D@("`@("`B=&]O;&)A
M<CUN;RQM96YU8F%R/6YO+'!E<G-O;F%L8F%R/6YO+'=I9'1H/38P,"QH96EG
M:'0]-C`P+&QE9G0],C`L=&]P/30P(B`K"@D)"2`@("`@(")S8W)O;&QB87)S
M/6YO+')E<VEZ86)L93UN;R(I.PH)=&AI<RYW:6YD;W<@/2!D;&<["@EV87(@
M9&]C(#T@9&QG+F1O8W5M96YT.PH)=&AI<RYD;V,@/2!D;V,["@EV87(@<V5L
M9B`]('1H:7,["@H)=F%R(&)A<V4@/2!D;V-U;65N="YB87-E55))('Q\(&1O
M8W5M96YT+E523#L*"6EF("AB87-E("8F(&)A<V4N;6%T8V@H+R@N*BE<+RA;
M7EPO72LI+RDI('L*"0EB87-E(#T@4F5G17AP+B0Q("L@(B\B.PH)?0H):68@
M*'1Y<&5O9B!?961I=&]R7W5R;"`A/2`B=6YD969I;F5D(B`F)B`A+UY<+R\N
M=&5S="A?961I=&]R7W5R;"D@)B8@(2]H='1P.EPO7"\O+G1E<W0H7V5D:71O
M<E]U<FPI*2!["@D)+R\@7V5D:71O<E]U<FP@9&]E<VXG="!S=&%R="!W:71H
M("<O)R!W:&EC:"!M96%N<R!I="=S(')E;&%T:79E"@D)+R\@1DE8344Z('1H
M97)E)W,@82!P<F]B;&5M(&AE<F4L(&ET(&-O=6QD(&)E(&AT='`Z+R\@=VAI
M8V@*"0DO+R!D;V5S;B=T('-T87)T('=I=&@@<VQA<V@@8G5T(&ET)W,@;F]T
M(')E;&%T:79E(&5I=&AE<BX*"0EB87-E("L](%]E9&ET;W)?=7)L.PH)?2!E
M;'-E"@D)8F%S92`](%]E9&ET;W)?=7)L.PH):68@*"$O7"\D+RYT97-T*&)A
M<V4I*2!["@D)+R\@8F%S92!D;V5S(&YO="!E;F0@:6X@<VQA<V@L(&%D9"!I
M="!N;W<*"0EB87-E("L]("<O)SL*"7T*"71H:7,N8F%S95523"`](&)A<V4[
M"@H)9&]C+F]P96XH*3L*"79A<B!H=&UL(#T@(CQH=&UL/CQH96%D/CQT:71L
M93XB("L@=&ET;&4@*R`B/"]T:71L93Y<;B(["@DO+R!H=&UL("L]("(\8F%S
M92!H<F5F/2<B("L@8F%S92`K(")H=&UL87)E82YJ<R<@+SY<;B(["@EH=&UL
M("L]("(\<W1Y;&4@='EP93TG=&5X="]C<W,G/D!I;7!O<G0@=7)L*"(@*R!B
M87-E("L@(FAT;6QA<F5A+F-S<RD[/"]S='EL93X\+VAE860^7&XB.PH):'1M
M;"`K/2`B/&)O9'D@8VQA<W,])V1I86QO9R!P;W!U<'=I;B<@:60])RTM2$$M
M8F]D>2<^/"]B;V1Y/CPO:'1M;#XB.PH)9&]C+G=R:71E*&AT;6PI.PH)9&]C
M+F-L;W-E*"D["@H)+R\@<V]M971I;65S($D@2&%T92!-;WII;&QA+BXN(#LM
M*`H)9G5N8W1I;VX@:6YI=#(H*2!["@D)=F%R(&)O9'D@/2!D;V,N8F]D>3L*
M"0EI9B`H(6)O9'DI('L*"0D)<V5T5&EM96]U="AI;FET,BP@,C4I.PH)"0ER
M971U<FX@9F%L<V4["@D)?0H)"61L9RYT:71L92`]('1I=&QE.PH)"61O8RYD
M;V-U;65N=$5L96UE;G0N<W1Y;&4N<&%D9&EN9R`]("(P<'@B.PH)"61O8RYD
M;V-U;65N=$5L96UE;G0N<W1Y;&4N;6%R9VEN(#T@(C!P>"(["@D)=F%R(&-O
M;G1E;G0@/2!D;V,N8W)E871E16QE;65N="@B9&EV(BD["@D)8V]N=&5N="YC
M;&%S<TYA;64@/2`B8V]N=&5N="(["@D)<V5L9BYC;VYT96YT(#T@8V]N=&5N
M=#L*"0EB;V1Y+F%P<&5N9$-H:6QD*&-O;G1E;G0I.PH)"7-E;&8N96QE;65N
M="`](&)O9'D["@D):6YI=$9U;F-T:6]N*'-E;&8I.PH)"61L9RYF;V-U<R@I
M.PH)?3L*"6EN:70R*"D["GT["@I0;W!U<%=I;BYP<F]T;W1Y<&4N8V%L;$AA
M;F1L97(@/2!F=6YC=&EO;B@I('L*"79A<B!T86=S(#T@6R)I;G!U="(L(")T
M97AT87)E82(L(")S96QE8W0B73L*"79A<B!P87)A;7,@/2!N97<@3V)J96-T
M*"D["@EF;W(@*'9A<B!T:2`]('1A9W,N;&5N9W1H.R`M+71I(#X](#`[*2![
M"@D)=F%R('1A9R`]('1A9W-;=&E=.PH)"79A<B!E;',@/2!T:&ES+F-O;G1E
M;G0N9V5T16QE;65N='-">51A9TYA;64H=&%G*3L*"0EF;W(@*'9A<B!J(#T@
M,#L@:B`\(&5L<RYL96YG=&@[("LK:BD@>PH)"0EV87(@96P@/2!E;'-;:ET[
M"@D)"79A<B!V86P@/2!E;"YV86QU93L*"0D):68@*&5L+G1A9TYA;64N=&],
M;W=E<D-A<V4H*2`]/2`B:6YP=70B*2!["@D)"0EI9B`H96PN='EP92`]/2`B
M8VAE8VMB;W@B*2!["@D)"0D)=F%L(#T@96PN8VAE8VME9#L*"0D)"7T*"0D)
M?0H)"0EP87)A;7-;96PN;F%M95T@/2!V86P["@D)?0H)?0H)=&AI<RYH86YD
M;&5R*'1H:7,L('!A<F%M<RD["@ER971U<FX@9F%L<V4["GT["@I0;W!U<%=I
M;BYP<F]T;W1Y<&4N8VQO<V4@/2!F=6YC=&EO;B@I('L*"71H:7,N=VEN9&]W
M+F-L;W-E*"D["GT["@I0;W!U<%=I;BYP<F]T;W1Y<&4N861D0G5T=&]N<R`]
M(&9U;F-T:6]N*"D@>PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&1I=B`]('1H
M:7,N9&]C+F-R96%T945L96UE;G0H(F1I=B(I.PH)=&AI<RYC;VYT96YT+F%P
M<&5N9$-H:6QD*&1I=BD["@ED:78N8VQA<W-.86UE(#T@(F)U='1O;G,B.PH)
M9F]R("AV87(@:2`](#`[(&D@/"!A<F=U;65N=',N;&5N9W1H.R`K*VDI('L*
M"0EV87(@8G1N(#T@87)G=6UE;G1S6VE=.PH)"79A<B!B=71T;VX@/2!T:&ES
M+F1O8RYC<F5A=&5%;&5M96YT*")B=71T;VXB*3L*"0ED:78N87!P96YD0VAI
M;&0H8G5T=&]N*3L*"0EB=71T;VXN:6YN97)(5$U,(#T@2%1-3$%R96$N23$X
M3BYB=71T;VYS6V)T;ET["@D)<W=I=&-H("AB=&XI('L*"0D@("`@8V%S92`B
M;VLB.@H)"0EB=71T;VXN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)"0D)<V5L
M9BYC86QL2&%N9&QE<B@I.PH)"0D)<V5L9BYC;&]S92@I.PH)"0D)<F5T=7)N
M(&9A;'-E.PH)"0E].PH)"0EB<F5A:SL*"0D@("`@8V%S92`B8V%N8V5L(CH*
M"0D)8G5T=&]N+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0D)"7-E;&8N8VQO
M<V4H*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?3L*"0D)8G)E86L["@D)?0H)
M?0I].PH*4&]P=7!7:6XN<')O=&]T>7!E+G-H;W=!=$5L96UE;G0@/2!F=6YC
M=&EO;B@I('L*"79A<B!S96QF(#T@=&AI<SL*"2\O($UO>FEL;&$@;F5E9',@
M<V]M92!T:6UE('1O(')E86QI>F4@=VAA="=S(&=O:6XG(&]N+BX*"7-E=%1I
M;65O=70H9G5N8W1I;VXH*2!["@D)=F%R('<@/2!S96QF+F-O;G1E;G0N;V9F
M<V5T5VED=&@@*R`T.PH)"79A<B!H(#T@<V5L9BYC;VYT96YT+F]F9G-E=$AE
M:6=H="`K(#0["@D)+R\@<VEZ92!T;R!C;VYT96YT("TM('1H870G<R!F=6-K
M:6XG(&)U9V=Y(&EN(&%L;"!F=6-K:6XG(&)R;W=S97)S(2$A"@D)+R\@<V\@
M=&AA="!W92!S970@82!L87)G97(@<VEZ92!F;W(@=&AE(&1I86QO9R!W:6YD
M;W<@86YD('1H96X@8V5N=&5R"@D)+R\@=&AE(&5L96UE;G0@:6YS:61E+BXN
M('!H=6-K(0H*"0DO+R!C96YT97(N+BX*"0EV87(@96P@/2!S96QF+F-O;G1E
M;G0["@D)=F%R(',@/2!E;"YS='EL93L*"0DO+R!S+G=I9'1H(#T@96PN;V9F
M<V5T5VED=&@@*R`B<'@B.PH)"2\O(',N:&5I9VAT(#T@96PN;V9F<V5T2&5I
M9VAT("L@(G!X(CL*"0ES+G!O<VET:6]N(#T@(F%B<V]L=71E(CL*"0ES+FQE
M9G0@/2`H=R`M(&5L+F]F9G-E=%=I9'1H*2`O(#(@*R`B<'@B.PH)"7,N=&]P
M(#T@*&@@+2!E;"YO9F9S971(96EG:'0I("\@,B`K(")P>"(["@D):68@*$A4
M34Q!<F5A+FES7V=E8VMO*2!["@D)"7-E;&8N=VEN9&]W+FEN;F5R5VED=&@@
M/2!W.PH)"0ES96QF+G=I;F1O=RYI;FYE<DAE:6=H="`](&@["@D)?2!E;'-E
M('L*"0D)<V5L9BYW:6YD;W<N<F5S:7IE5&\H=R`K(#@L(&@@*R`S-2D["@D)
M?0H)?2P@,C4I.PI].PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P9&EV+FIS````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#(R-C<V(#$P-3$U-#,T,30T(#`R-#8V,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O*BH@5&AI
M<R!F:6QE(&ES(&1E<FEV960@9G)O;2!0;W!U<$1I=BP@9&5V96QO<&5D(&)Y
M($UI:&%I($)A>F]N(&9O<@H@*B!386U787)E+FYE="X@($UO9&EF:6-A=&EO
M;G,@=V5R92!N965D960@=&\@;6%K92!I="!U<V%B;&4@:6X@2%1-3$%R96$N
M"B`J($A434Q!<F5A(&ES(&$@9G)E92!765-)5UE'(&]N;&EN92!(5$U,(&5D
M:71O<B!F<F]M($EN=&5R86-T:79E5&]O;',N8V]M+@H@*@H@*B!4:&ES(&9I
M;&4@9&]E<R!N;W0@9G5N8W1I;VX@<W1A;F1A;&]N92X@($ET(&ES(&1E<&5N
M9&5N="!O9B!G;&]B86P@9G5N8W1I;VYS"B`J(&1E9FEN960@:6X@2%1-3$%R
M96$M,RXP("AH=&UL87)E82YJ<RDN"B`J"B`J(%!L96%S92!S964@9FEL92!H
M=&UL87)E82YJ<R!F;W(@9G5R=&AE<B!D971A:6QS+@H@*BHO"@IV87(@:7-?
M:64@/2`H("AN879I9V%T;W(N=7-E<D%G96YT+G1O3&]W97)#87-E*"DN:6YD
M97A/9B@B;7-I92(I("$]("TQ*2`F)@H)("`@("`@*&YA=FEG871O<BYU<V5R
M06=E;G0N=&],;W=E<D-A<V4H*2YI;F1E>$]F*")O<&5R82(I(#T]("TQ*2`I
M.PIV87(@:7-?8V]M<&%T(#T@*&1O8W5M96YT+F-O;7!A=$UO9&4@/3T@(D)A
M8VM#;VUP870B*3L*"F9U;F-T:6]N(%!O<'5P1&EV*&5D:71O<BP@=&ET;&54
M97AT+"!H86YD;&5R+"!I;FET1G5N8W1I;VXI('L*"79A<B!S96QF(#T@=&AI
M<SL*"@ET:&ES+F5D:71O<B`](&5D:71O<CL*"71H:7,N9&]C(#T@961I=&]R
M+E]M9&]C.PH)=&AI<RYH86YD;&5R(#T@:&%N9&QE<CL*"@EV87(@96P@/2!T
M:&ES+F1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"65L+F-L87-S3F%M92`]
M(")C;VYT96YT(CL*"@EV87(@<&]P=7`@/2!T:&ES+F1O8RYC<F5A=&5%;&5M
M96YT*")D:78B*3L*"7!O<'5P+F-L87-S3F%M92`](")D:6%L;V<@<&]P=7!D
M:78B.PH)=&AI<RYE;&5M96YT(#T@<&]P=7`["@EV87(@<R`]('!O<'5P+G-T
M>6QE.PH)<RYP;W-I=&EO;B`](")A8G-O;'5T92(["@ES+FQE9G0@/2`B,'!X
M(CL*"7,N=&]P(#T@(C!P>"(["@H)=F%R('1I=&QE(#T@=&AI<RYD;V,N8W)E
M871E16QE;65N="@B9&EV(BD["@ET:71L92YC;&%S<TYA;64@/2`B=&ET;&4B
M.PH)=&AI<RYT:71L92`]('1I=&QE.PH)<&]P=7`N87!P96YD0VAI;&0H=&ET
M;&4I.PH*"4A434Q!<F5A+E]A9&1%=F5N="AT:71L92P@(FUO=7-E9&]W;B(L
M(&9U;F-T:6]N*&5V*2!["@D)<V5L9BY?9')A9U-T87)T*&ES7VEE(#\@=VEN
M9&]W+F5V96YT(#H@978I.PH)?2D["@H)=F%R(&)U='1O;B`]('1H:7,N9&]C
M+F-R96%T945L96UE;G0H(F1I=B(I.PH)8G5T=&]N+F-L87-S3F%M92`](")B
M=71T;VXB.PH)=&ET;&4N87!P96YD0VAI;&0H8G5T=&]N*3L*"6)U='1O;BYI
M;FYE<DA434P@/2`B)B-X,#!D-SLB.PH)=&ET;&4N87!P96YD0VAI;&0H=&AI
M<RYD;V,N8W)E871E5&5X=$YO9&4H=&ET;&5497AT*2D["@ET:&ES+G1I=&QE
M5&5X="`]('1I=&QE5&5X=#L*"@EB=71T;VXN;VYM;W5S96]V97(@/2!F=6YC
M=&EO;B@I('L*"0ET:&ES+F-L87-S3F%M92`K/2`B(&)U='1O;BUH:6QI=&4B
M.PH)?3L*"6)U='1O;BYO;FUO=7-E;W5T(#T@9G5N8W1I;VXH*2!["@D)=&AI
M<RYC;&%S<TYA;64@/2!T:&ES+F-L87-S3F%M92YR97!L86-E*"]<<RIB=71T
M;VXM:&EL:71E7',J+V<L("(@(BD["@E].PH)8G5T=&]N+F]N8VQI8VL@/2!F
M=6YC=&EO;B@I('L*"0ET:&ES+F-L87-S3F%M92`]('1H:7,N8VQA<W-.86UE
M+G)E<&QA8V4H+UQS*F)U='1O;BUH:6QI=&5<<RHO9RP@(B`B*3L*"0ES96QF
M+F-L;W-E*"D["@E].PH*"7!O<'5P+F%P<&5N9$-H:6QD*&5L*3L*"71H:7,N
M8V]N=&5N="`](&5L.PH*"71H:7,N9&]C+F)O9'DN87!P96YD0VAI;&0H<&]P
M=7`I.PH*"71H:7,N9')A9V=I;F<@/2!F86QS93L*"71H:7,N;VY3:&]W(#T@
M;G5L;#L*"71H:7,N;VY#;&]S92`](&YU;&P["@ET:&ES+FUO9&%L(#T@9F%L
M<V4["@H):6YI=$9U;F-T:6]N*'1H:7,I.PI].PH*4&]P=7!$:78N8W5R<F5N
M=%!O<'5P(#T@;G5L;#L*"E!O<'5P1&EV+G!R;W1O='EP92YS:&]W071%;&5M
M96YT(#T@9G5N8W1I;VXH96PL(&UO9&4I('L*"71H:7,N9&5F875L=%-I>F4H
M*3L*"79A<B!P;W,L(&5W+"!E:#L*"79A<B!P;W!U<"`]('1H:7,N96QE;65N
M=#L*"7!O<'5P+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB.PH)=F%R('<@/2!P
M;W!U<"YO9F9S9717:61T:#L*"79A<B!H(#T@<&]P=7`N;V9F<V5T2&5I9VAT
M.PH)<&]P=7`N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"6EF("AE;"`A/2!W
M:6YD;W<I('L*"0EP;W,@/2!0;W!U<$1I=BYG971!8G-O;'5T95!O<RAE;"D[
M"@D)97<@/2!E;"YO9F9S9717:61T:#L*"0EE:"`](&5L+F]F9G-E=$AE:6=H
M=#L*"7T@96QS92!["@D)<&]S(#T@>W@Z,"P@>3HP?3L*"0EV87(@<VEZ92`]
M(%!O<'5P1&EV+F=E=%=I;F1O=U-I>F4H*3L*"0EE=R`]('-I>F4N>#L*"0EE
M:"`]('-I>F4N>3L*"7T*"79A<B!&6"`](&9A;'-E+"!&62`](&9A;'-E.PH)
M:68@*&UO9&4N:6YD97A/9B@B;"(I("$]("TQ*2!["@D)<&]S+G@@+3T@=SL*
M"0E&6"`]('1R=64["@E]"@EI9B`H;6]D92YI;F1E>$]F*")R(BD@(3T@+3$I
M('L*"0EP;W,N>"`K/2!E=SL*"0E&6"`]('1R=64["@E]"@EI9B`H;6]D92YI
M;F1E>$]F*")T(BD@(3T@+3$I('L*"0EP;W,N>2`M/2!H.PH)"499(#T@=')U
M93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H(F(B*2`A/2`M,2D@>PH)"7!O<RYY
M("L](&5H.PH)"499(#T@=')U93L*"7T*"6EF("AM;V1E+FEN9&5X3V8H(F,B
M*2`A/2`M,2D@>PH)"498('Q\("AP;W,N>"`K/2!-871H+G)O=6YD*"AE=R`M
M('<I("\@,BDI.PH)"499('Q\("AP;W,N>2`K/2!-871H+G)O=6YD*"AE:"`M
M(&@I("\@,BDI.PH)?0H)=&AI<RYS:&]W070H<&]S+G@L('!O<RYY*3L*?3L*
M"E!O<'5P1&EV+G!R;W1O='EP92YD969A=6QT4VEZ92`](&9U;F-T:6]N*"D@
M>PH)=F%R(',@/2!T:&ES+F5L96UE;G0N<W1Y;&4["@EV87(@8W,@/2!T:&ES
M+F5L96UE;G0N8W5R<F5N=%-T>6QE.PH)=F%R(&%D9%@@/2`H:7-?:64@)B8@
M:7-?8V]M<&%T*2`_("AP87)S94EN="AC<RYB;W)D97),969T5VED=&@I("L*
M"0D)"0D@("!P87)S94EN="AC<RYB;W)D97)2:6=H=%=I9'1H*2`K"@D)"0D)
M("`@<&%R<V5);G0H8W,N<&%D9&EN9TQE9G0I("L*"0D)"0D@("!P87)S94EN
M="AC<RYP861D:6YG4FEG:'0I*2`Z(#`["@EV87(@861D62`]("AI<U]I92`F
M)B!I<U]C;VUP870I(#\@*'!A<G-E26YT*&-S+F)O<F1E<E1O<%=I9'1H*2`K
M"@D)"0D)("`@<&%R<V5);G0H8W,N8F]R9&5R0F]T=&]M5VED=&@I("L*"0D)
M"0D@("!P87)S94EN="AC<RYP861D:6YG5&]P*2`K"@D)"0D)("`@<&%R<V5)
M;G0H8W,N<&%D9&EN9T)O='1O;2DI(#H@,#L*"7,N9&ES<&QA>2`](")B;&]C
M:R(["@ES+G=I9'1H(#T@*'1H:7,N8V]N=&5N="YO9F9S9717:61T:"`K(&%D
M9%@I("L@(G!X(CL*"7,N:&5I9VAT(#T@*'1H:7,N8V]N=&5N="YO9F9S971(
M96EG:'0@*R!T:&ES+G1I=&QE+F]F9G-E=$AE:6=H="D@*R`B<'@B.PH)<RYD
M:7-P;&%Y(#T@(FYO;F4B.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+G-H;W=!
M="`](&9U;F-T:6]N*'@L('DI('L*"71H:7,N9&5F875L=%-I>F4H*3L*"79A
M<B!S(#T@=&AI<RYE;&5M96YT+G-T>6QE.PH)<RYD:7-P;&%Y(#T@(F)L;V-K
M(CL*"7,N;&5F="`]('@@*R`B<'@B.PH)<RYT;W`@/2!Y("L@(G!X(CL*"71H
M:7,N:&ED95-H;W=#;W9E<F5D*"D["@H)4&]P=7!$:78N8W5R<F5N=%!O<'5P
M(#T@=&AI<SL*"4A434Q!<F5A+E]A9&1%=F5N=',H=&AI<RYD;V,N8F]D>2P@
M6R)M;W5S961O=VXB+"`B8VQI8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U<"D[
M"@E(5$U,07)E82Y?861D179E;G1S*'1H:7,N961I=&]R+E]D;V,N8F]D>2P@
M6R)M;W5S961O=VXB+"`B8VQI8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U<"D[
M"@EI9B`H:7-?:64@)B8@=&AI<RYM;V1A;"D@>PH)"71H:7,N9&]C+F)O9'DN
M<V5T0V%P='5R92AF86QS92D["@D)=&AI<RYD;V,N8F]D>2YO;FQO<V5C87!T
M=7)E(#T@9G5N8W1I;VXH*2!["@D)"2A0;W!U<$1I=BYC=7)R96YT4&]P=7`I
M("8F("AT:&ES+F1O8RYB;V1Y+G-E=$-A<'1U<F4H9F%L<V4I*3L*"0E].PH)
M?0H)=VEN9&]W+F5V96YT("8F($A434Q!<F5A+E]S=&]P179E;G0H=VEN9&]W
M+F5V96YT*3L*"@EI9B`H='EP96]F('1H:7,N;VY3:&]W(#T](")F=6YC=&EO
M;B(I('L*"0ET:&ES+F]N4VAO=R@I.PH)?2!E;'-E(&EF("AT>7!E;V8@=&AI
M<RYO;E-H;W<@/3T@(G-T<FEN9R(I('L*"0EE=F%L*'1H:7,N;VY3:&]W*3L*
M"7T*"@EV87(@9FEE;&0@/2!T:&ES+F5L96UE;G0N9V5T16QE;65N='-">51A
M9TYA;64H(FEN<'5T(BE;,%T["@EI9B`H(69I96QD*2!["@D)9FEE;&0@/2!T
M:&ES+F5L96UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G-E;&5C="(I6S!=
M.PH)?0H):68@*"%F:65L9"D@>PH)"69I96QD(#T@=&AI<RYE;&5M96YT+F=E
M=$5L96UE;G1S0GE486=.86UE*")T97AT87)E82(I6S!=.PH)?0H):68@*&9I
M96QD*2!["@D)9FEE;&0N9F]C=7,H*3L*"7T*?3L*"E!O<'5P1&EV+G!R;W1O
M='EP92YC;&]S92`](&9U;F-T:6]N*"D@>PH)=&AI<RYE;&5M96YT+G-T>6QE
M+F1I<W!L87D@/2`B;F]N92(["@E0;W!U<$1I=BYC=7)R96YT4&]P=7`@/2!N
M=6QL.PH)=&AI<RYH:61E4VAO=T-O=F5R960H*3L*"4A434Q!<F5A+E]R96UO
M=F5%=F5N=',H=&AI<RYD;V,N8F]D>2P@6R)M;W5S961O=VXB+"`B8VQI8VLB
M72P@4&]P=7!$:78N8VAE8VM0;W!U<"D["@E(5$U,07)E82Y?<F5M;W9E179E
M;G1S*'1H:7,N961I=&]R+E]D;V,N8F]D>2P@6R)M;W5S961O=VXB+"`B8VQI
M8VLB72P@4&]P=7!$:78N8VAE8VM0;W!U<"D["@EI<U]I92`F)B!T:&ES+FUO
M9&%L("8F('1H:7,N9&]C+F)O9'DN<F5L96%S94-A<'1U<F4H*3L*"6EF("AT
M>7!E;V8@=&AI<RYO;D-L;W-E(#T](")F=6YC=&EO;B(I('L*"0ET:&ES+F]N
M0VQO<V4H*3L*"7T@96QS92!I9B`H='EP96]F('1H:7,N;VY#;&]S92`]/2`B
M<W1R:6YG(BD@>PH)"65V86PH=&AI<RYO;D-L;W-E*3L*"7T*"71H:7,N96QE
M;65N="YP87)E;G1.;V1E+G)E;6]V94-H:6QD*'1H:7,N96QE;65N="D["GT[
M"@I0;W!U<$1I=BYP<F]T;W1Y<&4N9V5T1F]R;2`](&9U;F-T:6]N*"D@>PH)
M=F%R(&9O<FUS(#T@=&AI<RYC;VYT96YT+F=E=$5L96UE;G1S0GE486=.86UE
M*")F;W)M(BD["@ER971U<FX@*&9O<FUS+FQE;F=T:"`^(#`I(#\@9F]R;7-;
M,%T@.B!N=6QL.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+F-A;&Q(86YD;&5R
M(#T@9G5N8W1I;VXH*2!["@EV87(@=&%G<R`](%LB:6YP=70B+"`B=&5X=&%R
M96$B+"`B<V5L96-T(ET["@EV87(@<&%R86US(#T@;F5W($]B:F5C="@I.PH)
M9F]R("AV87(@=&D@/2!T86=S+FQE;F=T:#L@+2UT:2`^/2`P.RD@>PH)"79A
M<B!T86<@/2!T86=S6W1I73L*"0EV87(@96QS(#T@=&AI<RYC;VYT96YT+F=E
M=$5L96UE;G1S0GE486=.86UE*'1A9RD["@D)9F]R("AV87(@:B`](#`[(&H@
M/"!E;',N;&5N9W1H.R`K*VHI('L*"0D)=F%R(&5L(#T@96QS6VI=.PH)"0EP
M87)A;7-;96PN;F%M95T@/2!E;"YV86QU93L*"0E]"@E]"@ET:&ES+FAA;F1L
M97(H=&AI<RP@<&%R86US*3L*"7)E='5R;B!F86QS93L*?3L*"E!O<'5P1&EV
M+F=E=$%B<V]L=71E4&]S(#T@9G5N8W1I;VXH96PI('L*"79A<B!R(#T@>R!X
M.B!E;"YO9F9S971,969T+"!Y.B!E;"YO9F9S9714;W`@?3L*"6EF("AE;"YO
M9F9S971087)E;G0I('L*"0EV87(@=&UP(#T@4&]P=7!$:78N9V5T06)S;VQU
M=&50;W,H96PN;V9F<V5T4&%R96YT*3L*"0ER+G@@*ST@=&UP+G@["@D)<BYY
M("L]('1M<"YY.PH)?0H)<F5T=7)N('(["GT["@I0;W!U<$1I=BYG9717:6YD
M;W=3:7IE(#T@9G5N8W1I;VXH*2!["@EI9B`H=VEN9&]W+FEN;F5R2&5I9VAT
M*2!["@D)<F5T=7)N('L@>3H@=VEN9&]W+FEN;F5R2&5I9VAT+"!X.B!W:6YD
M;W<N:6YN97)7:61T:"!].PH)?0H):68@*'1H:7,N9&]C+F)O9'DN8VQI96YT
M2&5I9VAT*2!["@D)<F5T=7)N('L@>3H@=&AI<RYD;V,N8F]D>2YC;&EE;G1(
M96EG:'0L('@Z('1H:7,N9&]C+F)O9'DN8VQI96YT5VED=&@@?3L*"7T*"7)E
M='5R;B![('DZ('1H:7,N9&]C+F1O8W5M96YT16QE;65N="YC;&EE;G1(96EG
M:'0L('@Z('1H:7,N9&]C+F1O8W5M96YT16QE;65N="YC;&EE;G17:61T:"!]
M.PI].PH*4&]P=7!$:78N<')O=&]T>7!E+FAI9&53:&]W0V]V97)E9"`](&9U
M;F-T:6]N("@I('L*"79A<B!S96QF(#T@=&AI<SL*"69U;F-T:6]N(&ES0V]N
M=&%I;F5D*&5L*2!["@D)=VAI;&4@*&5L*2!["@D)"6EF("AE;"`]/2!S96QF
M+F5L96UE;G0I('L*"0D)"7)E='5R;B!T<G5E.PH)"0E]"@D)"65L(#T@96PN
M<&%R96YT3F]D93L*"0E]"@D)<F5T=7)N(&9A;'-E.PH)?3L*"79A<B!T86=S
M(#T@;F5W($%R<F%Y*")A<'!L970B+"`B<V5L96-T(BD["@EV87(@96P@/2!T
M:&ES+F5L96UE;G0["@H)=F%R('`@/2!0;W!U<$1I=BYG971!8G-O;'5T95!O
M<RAE;"D["@EV87(@15@Q(#T@<"YX.PH)=F%R($58,B`](&5L+F]F9G-E=%=I
M9'1H("L@15@Q.PH)=F%R($59,2`]('`N>3L*"79A<B!%63(@/2!E;"YO9F9S
M971(96EG:'0@*R!%63$["@H):68@*&5L+G-T>6QE+F1I<W!L87D@/3T@(FYO
M;F4B*2!["@D)15@Q(#T@15@R(#T@15DQ(#T@15DR(#T@,#L*"7T*"@EF;W(@
M*'9A<B!K(#T@=&%G<RYL96YG=&@[(&L@/B`P.R`I('L*"0EV87(@87(@/2!T
M:&ES+F1O8RYG971%;&5M96YT<T)Y5&%G3F%M92AT86=S6RTM:UTI.PH)"79A
M<B!C8R`](&YU;&P["@H)"69O<B`H=F%R(&D@/2!A<BYL96YG=&@[(&D@/B`P
M.RD@>PH)"0EC8R`](&%R6RTM:5T["@D)"6EF("AI<T-O;G1A:6YE9"AC8RDI
M('L*"0D)"6-C+G-T>6QE+G9I<VEB:6QI='D@/2`B=FES:6)L92(["@D)"0EC
M;VYT:6YU93L*"0D)?0H*"0D)<"`](%!O<'5P1&EV+F=E=$%B<V]L=71E4&]S
M*&-C*3L*"0D)=F%R($-8,2`]('`N>#L*"0D)=F%R($-8,B`](&-C+F]F9G-E
M=%=I9'1H("L@0U@Q.PH)"0EV87(@0UDQ(#T@<"YY.PH)"0EV87(@0UDR(#T@
M8V,N;V9F<V5T2&5I9VAT("L@0UDQ.PH*"0D):68@*"A#6#$@/B!%6#(I('Q\
M("A#6#(@/"!%6#$I('Q\("A#63$@/B!%63(I('Q\("A#63(@/"!%63$I*2![
M"@D)"0EC8RYS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB;&4B.PH)"0E](&5L
M<V4@>PH)"0D)8V,N<W1Y;&4N=FES:6)I;&ET>2`](")H:61D96XB.PH)"0E]
M"@D)?0H)?0I].PH*4&]P=7!$:78N<')O=&]T>7!E+E]D<F%G4W1A<G0@/2!F
M=6YC=&EO;B`H978I('L*"6EF("AT:&ES+F1R86=G:6YG*2!["@D)<F5T=7)N
M(&9A;'-E.PH)?0H)=&AI<RYD<F%G9VEN9R`]('1R=64["@E0;W!U<$1I=BYC
M=7)R96YT4&]P=7`@/2!T:&ES.PH)=F%R('!O<U@@/2!E=BYC;&EE;G18.PH)
M=F%R('!O<UD@/2!E=BYC;&EE;G19.PH):68@*&ES7VEE*2!["@D)<&]S62`K
M/2!T:&ES+F1O8RYB;V1Y+G-C<F]L;%1O<#L*"0EP;W-8("L]('1H:7,N9&]C
M+F)O9'DN<V-R;VQL3&5F=#L*"7T@96QS92!["@D)<&]S62`K/2!W:6YD;W<N
M<V-R;VQL63L*"0EP;W-8("L]('=I;F1O=RYS8W)O;&Q8.PH)?0H)=F%R('-T
M(#T@=&AI<RYE;&5M96YT+G-T>6QE.PH)=&AI<RYX3V9F<R`]('!O<U@@+2!P
M87)S94EN="AS="YL969T*3L*"71H:7,N>4]F9G,@/2!P;W-9("T@<&%R<V5)
M;G0H<W0N=&]P*3L*"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F1O8RP@(FUO
M=7-E;6]V92(L(%!O<'5P1&EV+F1R86=)="D["@E(5$U,07)E82Y?861D179E
M;G0H=&AI<RYD;V,L(")M;W5S96]V97(B+"!(5$U,07)E82Y?<W1O<$5V96YT
M*3L*"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F1O8RP@(FUO=7-E=7`B+"!0
M;W!U<$1I=BYD<F%G16YD*3L*"4A434Q!<F5A+E]S=&]P179E;G0H978I.PI]
M.PH*4&]P=7!$:78N9')A9TET(#T@9G5N8W1I;VX@*&5V*2!["@EV87(@<&]P
M=7`@/2!0;W!U<$1I=BYC=7)R96YT4&]P=7`["@EI9B`H(2AP;W!U<"`F)B!P
M;W!U<"YD<F%G9VEN9RDI('L*"0ER971U<FX@9F%L<V4["@E]"@EI<U]I92`F
M)B`H978@/2!W:6YD;W<N979E;G0I.PH)=F%R('!O<U@@/2!E=BYC;&EE;G18
M.PH)=F%R('!O<UD@/2!E=BYC;&EE;G19.PH):68@*&ES7VEE*2!["@D)<&]S
M62`K/2!T:&ES+F1O8RYB;V1Y+G-C<F]L;%1O<#L*"0EP;W-8("L]('1H:7,N
M9&]C+F)O9'DN<V-R;VQL3&5F=#L*"7T@96QS92!["@D)<&]S62`K/2!W:6YD
M;W<N<V-R;VQL63L*"0EP;W-8("L]('=I;F1O=RYS8W)O;&Q8.PH)?0H)<&]P
M=7`N:&ED95-H;W=#;W9E<F5D*"D["@EV87(@<W0@/2!P;W!U<"YE;&5M96YT
M+G-T>6QE.PH)<W0N;&5F="`]("AP;W-8("T@<&]P=7`N>$]F9G,I("L@(G!X
M(CL*"7-T+G1O<"`]("AP;W-9("T@<&]P=7`N>4]F9G,I("L@(G!X(CL*"4A4
M34Q!<F5A+E]S=&]P179E;G0H978I.PI].PH*4&]P=7!$:78N9')A9T5N9"`]
M(&9U;F-T:6]N("@I('L*"79A<B!P;W!U<"`](%!O<'5P1&EV+F-U<G)E;G10
M;W!U<#L*"6EF("@A<&]P=7`I('L*"0ER971U<FX@9F%L<V4["@E]"@EP;W!U
M<"YD<F%G9VEN9R`](&9A;'-E.PH)2%1-3$%R96$N7W)E;6]V945V96YT*'!O
M<'5P+F1O8RP@(FUO=7-E=7`B+"!0;W!U<$1I=BYD<F%G16YD*3L*"4A434Q!
M<F5A+E]R96UO=F5%=F5N="AP;W!U<"YD;V,L(")M;W5S96]V97(B+"!(5$U,
M07)E82Y?<W1O<$5V96YT*3L*"4A434Q!<F5A+E]R96UO=F5%=F5N="AP;W!U
M<"YD;V,L(")M;W5S96UO=F4B+"!0;W!U<$1I=BYD<F%G270I.PH)<&]P=7`N
M:&ED95-H;W=#;W9E<F5D*"D["GT["@I0;W!U<$1I=BYC:&5C:U!O<'5P(#T@
M9G5N8W1I;VX@*&5V*2!["@EI<U]I92`F)B`H978@/2!W:6YD;W<N979E;G0I
M.PH)=F%R(&5L(#T@:7-?:64@/R!E=BYS<F-%;&5M96YT(#H@978N=&%R9V5T
M.PH)=F%R(&-P(#T@4&]P=7!$:78N8W5R<F5N=%!O<'5P.PH)9F]R("@[("AE
M;"`A/2!N=6QL*2`F)B`H96P@(3T@8W`N96QE;65N="D[(&5L(#T@96PN<&%R
M96YT3F]D92D["@EI9B`H96P@/3T@;G5L;"D@>PH)"6-P+FUO9&%L('Q\(&5V
M+G1Y<&4@/3T@(FUO=7-E;W9E<B(@?'P@8W`N8VQO<V4H*3L*"0E(5$U,07)E
M82Y?<W1O<$5V96YT*&5V*3L*"7T*?3L*"E!O<'5P1&EV+G!R;W1O='EP92YA
M9&1"=71T;VYS(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]('1H:7,["@EV
M87(@9&EV(#T@=&AI<RYD;V,N8W)E871E16QE;65N="@B9&EV(BD["@ET:&ES
M+F-O;G1E;G0N87!P96YD0VAI;&0H9&EV*3L*"61I=BYC;&%S<TYA;64@/2`B
M8G5T=&]N<R(["@EF;W(@*'9A<B!I(#T@,#L@:2`\(&%R9W5M96YT<RYL96YG
M=&@[("LK:2D@>PH)"79A<B!B=&X@/2!A<F=U;65N='-;:5T["@D)=F%R(&)U
M='1O;B`]('1H:7,N9&]C+F-R96%T945L96UE;G0H(F)U='1O;B(I.PH)"61I
M=BYA<'!E;F1#:&EL9"AB=71T;VXI.PH)"6)U='1O;BYI;FYE<DA434P@/2!(
M5$U,07)E82Y),3A.+F)U='1O;G-;8G1N73L*"0ES=VET8V@@*&)T;BD@>PH)
M"2`@("!C87-E(")O:R(Z"@D)"6)U='1O;BYO;F-L:6-K(#T@9G5N8W1I;VXH
M*2!["@D)"0ES96QF+F-A;&Q(86YD;&5R*"D["@D)"0ES96QF+F-L;W-E*"D[
M"@D)"7T["@D)"6)R96%K.PH)"2`@("!C87-E(")C86YC96PB.@H)"0EB=71T
M;VXN;VYC;&EC:R`](&9U;F-T:6]N*"D@>PH)"0D)<V5L9BYC;&]S92@I.PH)
M"0E].PH)"0EB<F5A:SL*"0E]"@E]"GT["@``````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]H=&UL87)E82YJ<P``````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#(S-S(S
M,B`Q,#4Q-30S-#$T-"`P,C0V,#8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+R\@:'1M;$%R96$@=C,N,"`M($-O<'ER:6=H
M="`H8RD@,C`P,RTR,#`U(&1Y;F%R8V@N8V]M"B\O("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#(P,#(M,C`P,R!I;G1E<F%C=&EV971O;VQS+F-O
M;2P@:6YC+@HO+R!4:&ES(&-O<'ER:6=H="!N;W1I8V4@35535"!S=&%Y(&EN
M=&%C="!F;W(@=7-E("AS964@;&EC96YS92YT>'0I+@HO+PHO+R!!(&9R964@
M5UE325=91R!E9&ET;W(@<F5P;&%C96UE;G0@9F]R(#QT97AT87)E83X@9FEE
M;&1S+@HO+R!&;W(@9G5L;"!S;W5R8V4@8V]D92!A;F0@9&]C<RP@=FES:70@
M:'1T<#HO+W=W=RYI;G1E<F%C=&EV971O;VQS+F-O;2\*+R\*+R\@5F5R<VEO
M;B`S+C`@9&5V96QO<&5D(&)Y($UI:&%I($)A>F]N+@HO+R`@(&AT='`Z+R]D
M>6YA<F-H+F-O;2]M:7-H;V\O"B\O"B\O("1)9#H@:'1M;&%R96$N:G,L=B`Q
M+CDW(#(P,#4O,#$O,CD@,#`Z-#8Z-3$@:71O;VQS($5X<"`D"@II9B`H='EP
M96]F(%]E9&ET;W)?=7)L(#T](")S=')I;F<B*2!["@DO+R!,96%V92!E>&%C
M=&QY(&]N92!B86-K<VQA<V@@870@=&AE(&5N9"!O9B!?961I=&]R7W5R;`H)
M7V5D:71O<E]U<FP@/2!?961I=&]R7W5R;"YR97!L86-E*"]<>#)F*B0O+"`G
M+R<I.PI](&5L<V4@>PH)86QE<G0H(E=!4DY)3D<Z(%]E9&ET;W)?=7)L(&ES
M(&YO="!S970A("!9;W4@<VAO=6QD('-E="!T:&ES('9A<FEA8FQE('1O('1H
M92!E9&ET;W(@9FEL97,@<&%T:#L@:70@<VAO=6QD('!R969E<F%B;'D@8F4@
M86X@86)S;VQU=&4@<&%T:"P@;&EK92!I;B`G+VAT;6QA<F5A+R<L(&)U="!I
M="!C86X@8F4@<F5L871I=F4@:68@>6]U('!R969E<BX@($9U<G1H97(@=V4@
M=VEL;"!T<GD@=&\@;&]A9"!T:&4@961I=&]R(&9I;&5S(&-O<G)E8W1L>2!B
M=70@=V4G;&P@<')O8F%B;'D@9F%I;"XB*3L*"5]E9&ET;W)?=7)L(#T@)R<[
M"GT*"B\O(&UA:V4@<W5R92!W92!H879E(&$@;&%N9W5A9V4*:68@*'1Y<&5O
M9B!?961I=&]R7VQA;F<@/3T@(G-T<FEN9R(I('L*"5]E9&ET;W)?;&%N9R`]
M(%]E9&ET;W)?;&%N9RYT;TQO=V5R0V%S92@I.PI](&5L<V4@>PH)7V5D:71O
M<E]L86YG(#T@(F5N(CL*?0H*+R\@8G)O=W-E<B!I9&5N=&EF:6-A=&EO;@I(
M5$U,07)E82YA9W0@/2!N879I9V%T;W(N=7-E<D%G96YT+G1O3&]W97)#87-E
M*"D["DA434Q!<F5A+FES7VEE"2`@(#T@*"A(5$U,07)E82YA9W0N:6YD97A/
M9B@B;7-I92(I("$]("TQ*2`F)B`H2%1-3$%R96$N86=T+FEN9&5X3V8H(F]P
M97)A(BD@/3T@+3$I*3L*2%1-3$%R96$N:7-?;W!E<F$@(#T@*$A434Q!<F5A
M+F%G="YI;F1E>$]F*")O<&5R82(I("$]("TQ*3L*2%1-3$%R96$N:7-?;6%C
M"2`@(#T@*$A434Q!<F5A+F%G="YI;F1E>$]F*")M86,B*2`A/2`M,2D["DA4
M34Q!<F5A+FES7VUA8U]I92`]("A(5$U,07)E82YI<U]I92`F)B!(5$U,07)E
M82YI<U]M86,I.PI(5$U,07)E82YI<U]W:6Y?:64@/2`H2%1-3$%R96$N:7-?
M:64@)B8@(4A434Q!<F5A+FES7VUA8RD["DA434Q!<F5A+FES7V=E8VMO("`]
M("AN879I9V%T;W(N<')O9'5C="`]/2`B1V5C:V\B*3L*"B\O($-R96%T97,@
M82!N97<@2%1-3$%R96$@;V)J96-T+B`@5')I97,@=&\@<F5P;&%C92!T:&4@
M=&5X=&%R96$@=VET:"!T:&4@9VEV96X*+R\@240@=VET:"!I="X*9G5N8W1I
M;VX@2%1-3$%R96$H=&5X=&%R96$L(&-O;F9I9RD@>PH@("`@("`@(&EF("@A
M2%1-3$%R96$N7VEN:71?8V%L;&5D*2!["@D@86QE<G0H(D5R<F]R.B!9;W4@
M;75S="!C86QL960@2%1-3$%R96$N:6YI="@I(&9I<G-T+B`@3&EK92!T:&ES
M.EQN7&XB("L*"2`@("`@("`B2%1-3$%R96$N:6YI="@I.UQN(B`K"@D@("`@
M("`@(DA434Q!<F5A+F]N;&]A9"`](&9U;F-T:6]N*"D@>UQN(B`K"@D@("`@
M("`@(B`@=F%R(&5D:71O<B`](&YE=R!(5$U,07)E82@G961I=&]R)RD[7&XB
M("L*"2`@("`@("`B("!E9&ET;W(N9V5N97)A=&4H*3M<;B(@*PH)("`@("`@
M(")].UQN(BD["@D@(')E='5R;CL*"7T*"@EI9B`H2%1-3$%R96$N8VAE8VM3
M=7!P;W)T961"<F]W<V5R*"DI('L*"0EI9B`H='EP96]F(&-O;F9I9R`]/2`B
M=6YD969I;F5D(BD@>PH)"0ET:&ES+F-O;F9I9R`](&YE=R!(5$U,07)E82Y#
M;VYF:6<H*3L*"0E](&5L<V4@>PH)"0ET:&ES+F-O;F9I9R`](&-O;F9I9SL*
M"0E]"@D)=&AI<RY?:'1M;$%R96$@/2!N=6QL.PH)"71H:7,N7W1E>'1!<F5A
M(#T@=&5X=&%R96$["@D)=&AI<RY?961I=$UO9&4@/2`B=WES:7=Y9R(["@D)
M=&AI<RYP;'5G:6YS(#T@>WT["@D)=&AI<RY?=&EM97)4;V]L8F%R(#T@;G5L
M;#L*"0ET:&ES+E]T:6UE<E5N9&\@/2!N=6QL.PH)"71H:7,N7W5N9&]1=65U
M92`](&YE=R!!<G)A>2AT:&ES+F-O;F9I9RYU;F1O4W1E<',I.PH)"71H:7,N
M7W5N9&]0;W,@/2`M,3L*"0ET:&ES+E]C=7-T;VU5;F1O(#T@9F%L<V4["@D)
M=&AI<RY?;61O8R`](&1O8W5M96YT.R`O+R!C86-H92!T:&4@9&]C=6UE;G0L
M('=E(&YE960@:70@:6X@<&QU9VEN<PH)"71H:7,N9&]C='EP92`]("<G.PH)
M?0I].PH*2%1-3$%R96$N;VYL;V%D(#T@9G5N8W1I;VXH*7M].PI(5$U,07)E
M82Y?<V-R:7!T<R`](%M=.PI(5$U,07)E82YL;V%D4V-R:7!T(#T@9G5N8W1I
M;VXH=7)L+"!P;'5G:6XI('L*"6EF("AP;'5G:6XI"@D)=7)L(#T@2%1-3$%R
M96$N9V5T4&QU9VEN1&ER*'!L=6=I;BD@*R`G+R<@*R!U<FP["@ET:&ES+E]S
M8W)I<'1S+G!U<V@H=7)L*3L*?3L*"DA434Q!<F5A+FEN:70@/2!F=6YC=&EO
M;B@I('L*"79A<B!H96%D(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA
M;64H(FAE860B*5LP73L*"79A<B!C=7)R96YT(#T@,#L*"79A<B!S879E=&ET
M;&4@/2!D;V-U;65N="YT:71L93L*"79A<B!E=G0@/2!(5$U,07)E82YI<U]I
M92`_(")O;G)E861Y<W1A=&5C:&%N9V4B(#H@(F]N;&]A9"(["@EF=6YC=&EO
M;B!L;V%D3F5X=%-C<FEP="@I('L*"0EI9B`H8W5R<F5N="`^(#`@)B8@2%1-
M3$%R96$N:7-?:64@)B8*"0D@("`@(2]L;V%D961\8V]M<&QE=&4O+G1E<W0H
M=VEN9&]W+F5V96YT+G-R8T5L96UE;G0N<F5A9'E3=&%T92DI"@D)"7)E='5R
M;CL*"0EI9B`H8W5R<F5N="`\($A434Q!<F5A+E]S8W)I<'1S+FQE;F=T:"D@
M>PH)"0EV87(@=7)L(#T@2%1-3$%R96$N7W-C<FEP='-;8W5R<F5N="LK73L*
M"0D)9&]C=6UE;G0N=&ET;&4@/2`B6TA434Q!<F5A.B!L;V%D:6YG('-C<FEP
M="`B("L@8W5R<F5N="`K("(O(B`K($A434Q!<F5A+E]S8W)I<'1S+FQE;F=T
M:"`K(")=(CL*"0D)=F%R('-C<FEP="`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H(G-C<FEP="(I.PH)"0ES8W)I<'0N='EP92`](")T97AT+VIA=F%S8W)I
M<'0B.PH)"0ES8W)I<'0N<W)C(#T@=7)L.PH)"0ES8W)I<'1;979T72`](&QO
M861.97AT4V-R:7!T.PH)"0EH96%D+F%P<&5N9$-H:6QD*'-C<FEP="D["@D)
M?2!E;'-E('L*"0D)9&]C=6UE;G0N=&ET;&4@/2!S879E=&ET;&4["B`@("`@
M("`@("`@("`@("`@("`@("`@($A434Q!<F5A+E]I;FET7V-A;&QE9"`](#$[
M"@D)"4A434Q!<F5A+F]N;&]A9"@I.PH)"7T*"7T["@EL;V%D3F5X=%-C<FEP
M="@I.PH*?3L*"DA434Q!<F5A+FQO86138W)I<'0H7V5D:71O<E]U<FP@*R`B
M9&EA;&]G+FIS(BD["DA434Q!<F5A+FQO86138W)I<'0H7V5D:71O<E]U<FP@
M*R`B<&]P=7!W:6XN:G,B*3L*2%1-3$%R96$N;&]A9%-C<FEP="A?961I=&]R
M7W5R;"`K(")L86YG+R(@*R!?961I=&]R7VQA;F<@*R`B+FIS(BD["@HO+R!C
M86-H92!S;VUE(')E9V5X<',*2%1-3$%R96$N4D5?=&%G3F%M92`]("\H/%PO
M?#PI7',J*%M>(%QT7&X^72LI+VEG.PI(5$U,07)E82Y215]D;V-T>7!E(#T@
M+R@\(61O8W1Y<&4H*"Y\7&XI*C\I/BE<;C\O:3L*2%1-3$%R96$N4D5?:&5A
M9"`@("`]("\\:&5A9#XH*"Y\7&XI*C\I/%PO:&5A9#XO:3L*2%1-3$%R96$N
M4D5?8F]D>2`@("`]("\\8F]D>3XH*"Y\7&XI*C\I/%PO8F]D>3XO:3L*"DA4
M34Q!<F5A+D-O;F9I9R`](&9U;F-T:6]N("@I('L*"71H:7,N=F5R<VEO;B`]
M("(S+C`B.PH*"71H:7,N=VED=&@@/2`B875T;R(["@ET:&ES+FAE:6=H="`]
M(")A=71O(CL*"@DO+R!E;F%B;&4@8W)E871I;VX@;V8@82!S=&%T=7,@8F%R
M/PH)=&AI<RYS=&%T=7-"87(@/2!T<G5E.PH*"2\O(&EN=&5R8V5P="!>5B!A
M;F0@=7-E('1H92!(5$U,07)E82!P87-T92!C;VUM86YD"@DO+R!)9B!F86QS
M92P@=&AE;B!P87-S97,@7E8@=&AR;W5G:"!T;R!B<F]W<V5R(&5D:71O<B!W
M:61G970*"71H:7,N:'1M;&%R96%087-T92`](&9A;'-E.PH*"2\O(&UA>&EM
M=6T@<VEZ92!O9B!T:&4@=6YD;R!Q=65U90H)=&AI<RYU;F1O4W1E<',@/2`R
M,#L*"@DO+R!T:&4@=&EM92!I;G1E<G9A;"!A="!W:&EC:"!U;F1O('-A;7!L
M97,@87)E('1A:V5N"@ET:&ES+G5N9&]4:6UE;W5T(#T@-3`P.PDO+R`Q+S(@
M<V5C+@H*"2\O('1H92!N97AT('!A<F%M971E<B!S<&5C:69I97,@=VAE=&AE
M<B!T:&4@=&]O;&)A<B!S:&]U;&0@8F4@:6YC;'5D960*"2\O(&EN('1H92!S
M:7IE(&]R(&YO="X*"71H:7,N<VEZ94EN8VQU9&5S5&]O;&)A<B`]('1R=64[
M"@H)+R\@:68@=')U92!T:&5N($A434Q!<F5A('=I;&P@<F5T<FEE=F4@=&AE
M(&9U;&P@2%1-3"P@<W1A<G1I;F<@=VET:"!T:&4*"2\O(#Q(5$U,/B!T86<N
M"@ET:&ES+F9U;&Q086=E(#T@9F%L<V4["@H)+R\@<W1Y;&4@:6YC;'5D960@
M:6X@=&AE(&EF<F%M92!D;V-U;65N=`H)=&AI<RYP86=E4W1Y;&4@/2`B(CL*
M"@DO+R!S970@=&\@=')U92!I9B!Y;W4@=V%N="!7;W)D(&-O9&4@=&\@8F4@
M8VQE86YE9"!U<&]N(%!A<W1E"@ET:&ES+FMI;&Q7;W)D3VY087-T92`]('1R
M=64["@H)+R\@96YA8FQE('1H92`G5&%R9V5T)R!F:65L9"!I;B!T:&4@36%K
M92!,:6YK(&1I86QO9PH)=&AI<RYM86ME3&EN:U-H;W=S5&%R9V5T(#T@=')U
M93L*"@DO+R!"87-E55),(&EN8VQU9&5D(&EN('1H92!I9G)A;64@9&]C=6UE
M;G0*"71H:7,N8F%S95523"`](&1O8W5M96YT+F)A<V554DD@?'P@9&]C=6UE
M;G0N55),.PH):68@*'1H:7,N8F%S95523"`F)B!T:&ES+F)A<V554DPN;6%T
M8V@H+R@N*BE<+RA;7EPO72LI+RDI"@D)=&AI<RYB87-E55),(#T@4F5G17AP
M+B0Q("L@(B\B.PH*"2\O(%523"US"@ET:&ES+FEM9U523"`](")I;6%G97,O
M(CL*"71H:7,N<&]P=7!54DP@/2`B<&]P=7!S+R(["@H)+R\@<F5M;W9E('1A
M9W,@*'1H97-E(&AA=F4@=&\@8F4@82!R96=E>'`L(&]R(&YU;&P@:68@=&AI
M<R!F=6YC=&EO;F%L:71Y(&ES(&YO="!D97-I<F5D*0H)=&AI<RYH=&UL4F5M
M;W9E5&%G<R`](&YU;&P["@H)+RHJ($-54U1/34E:24Y'(%1(12!43T],0D%2
M"@D@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@D@*@H)("H@270@:7,@
M<F5C;VUM96YD960@=&AA="!Y;W4@8W5S=&]M:7IE('1H92!T;V]L8F%R(&-O
M;G1E;G1S(&EN(&%N"@D@*B!E>'1E<FYA;"!F:6QE("AI+F4N('1H92!O;F4@
M8V%L;&EN9R!(5$U,07)E82D@86YD(&QE879E('1H:7,@;VYE"@D@*B!U;F-H
M86YG960N("!4:&%T)W,@8F5C875S92!W:&5N('=E("A);G1E<F%C=&EV951O
M;VQS+F-O;2D@<F5L96%S92!A"@D@*B!N97<@;V9F:6-I86P@=F5R<VEO;BP@
M:70G<R!L97-S(&QI:V5L>2!T:&%T('EO=2!W:6QL(&AA=F4@<')O8FQE;7,*
M"2`J('5P9W)A9&EN9R!(5$U,07)E82X*"2`J+PH)=&AI<RYT;V]L8F%R(#T@
M6PH)"5L@(F9O;G1N86UE(BP@(G-P86-E(BP*"0D@(")F;VYT<VEZ92(L(")S
M<&%C92(L"@D)("`B9F]R;6%T8FQO8VLB+"`B<W!A8V4B+`H)"2`@(F)O;&0B
M+"`B:71A;&EC(BP@(G5N9&5R;&EN92(L(")S=')I:V5T:')O=6=H(BP@(G-E
M<&%R871O<B(L"@D)("`B<W5B<V-R:7!T(BP@(G-U<&5R<V-R:7!T(BP@(G-E
M<&%R871O<B(L"@D)("`B8V]P>2(L(")C=70B+"`B<&%S=&4B+"`B<W!A8V4B
M+"`B=6YD;R(L(")R961O(BP@(G-P86-E(BP@(G)E;6]V969O<FUA="(L(")K
M:6QL=V]R9"(@72P*"@D)6R`B:G5S=&EF>6QE9G0B+"`B:G5S=&EF>6-E;G1E
M<B(L(")J=7-T:69Y<FEG:'0B+"`B:G5S=&EF>69U;&PB+"`B<V5P87)A=&]R
M(BP*"0D@(")L969T=&]R:6=H="(L(")R:6=H='1O;&5F="(L(")S97!A<F%T
M;W(B+`H)"2`@(F]R9&5R961L:7-T(BP@(G5N;W)D97)E9&QI<W0B+"`B;W5T
M9&5N="(L(")I;F1E;G0B+"`B<V5P87)A=&]R(BP*"0D@(")F;W)E8V]L;W(B
M+"`B:&EL:71E8V]L;W(B+"`B<V5P87)A=&]R(BP*"0D@(")I;G-E<G1H;W)I
M>F]N=&%L<G5L92(L(")C<F5A=&5L:6YK(BP@(FEN<V5R=&EM86=E(BP@(FEN
M<V5R='1A8FQE(BP@(FAT;6QM;V1E(BP@(G-E<&%R871O<B(L"@D)("`B<&]P
M=7!E9&ET;W(B+"`B<V5P87)A=&]R(BP@(G-H;W=H96QP(BP@(F%B;W5T(B!=
M"@E=.PH*"71H:7,N9F]N=&YA;64@/2!["@D)(B9M9&%S:#L@9F]N="`F;61A
M<V@[(CH@("`@("`@("`G)RP*"0DB07)I86PB.@D@("`G87)I86PL:&5L=F5T
M:6-A+'-A;G,M<V5R:68G+`H)"2)#;W5R:65R($YE=R(Z"2`@("=C;W5R:65R
M(&YE=RQC;W5R:65R+&UO;F]S<&%C92<L"@D)(D=E;W)G:6$B.@D@("`G9V5O
M<F=I82QT:6UE<R!N97<@<F]M86XL=&EM97,L<V5R:68G+`H)"2)486AO;6$B
M.@D@("`G=&%H;VUA+&%R:6%L+&AE;'9E=&EC82QS86YS+7-E<FEF)RP*"0DB
M5&EM97,@3F5W(%)O;6%N(CH@)W1I;65S(&YE=R!R;VUA;BQT:6UE<RQS97)I
M9B<L"@D)(E9E<F1A;F$B.@D@("`G=F5R9&%N82QA<FEA;"QH96QV971I8V$L
M<V%N<RUS97)I9B<L"@D)(FEM<&%C="(Z"2`@("=I;7!A8W0G+`H)"2)7:6YG
M1&EN9W,B.@D@("`G=VEN9V1I;F=S)PH)?3L*"@ET:&ES+F9O;G1S:7IE(#T@
M>PH)"2(F;61A<V@[('-I>F4@)FUD87-H.R(@(#H@(B(L"@D)(C$@*#@@<'0I
M(B`Z("(Q(BP*"0DB,B`H,3`@<'0I(CH@(C(B+`H)"2(S("@Q,B!P="DB.B`B
M,R(L"@D)(C0@*#$T('!T*2(Z("(T(BP*"0DB-2`H,3@@<'0I(CH@(C4B+`H)
M"2(V("@R-"!P="DB.B`B-B(L"@D)(C<@*#,V('!T*2(Z("(W(@H)?3L*"@ET
M:&ES+F9O<FUA=&)L;V-K(#T@>PH)"2(F;61A<V@[(&9O<FUA="`F;61A<V@[
M(B`@.B`B(BP*"0DB2&5A9&EN9R`Q(CH@(F@Q(BP*"0DB2&5A9&EN9R`R(CH@
M(F@R(BP*"0DB2&5A9&EN9R`S(CH@(F@S(BP*"0DB2&5A9&EN9R`T(CH@(F@T
M(BP*"0DB2&5A9&EN9R`U(CH@(F@U(BP*"0DB2&5A9&EN9R`V(CH@(F@V(BP*
M"0DB3F]R;6%L(B`@(#H@(G`B+`H)"2)!9&1R97-S(B`@.B`B861D<F5S<R(L
M"@D)(D9O<FUA='1E9"(Z(")P<F4B"@E].PH*"71H:7,N8W5S=&]M4V5L96-T
M<R`]('M].PH*"69U;F-T:6]N(&-U=%]C;W!Y7W!A<W1E*&4L(&-M9"P@;V)J
M*2!["@D)92YE>&5C0V]M;6%N9"AC;60I.PH)?3L*"@ET:&ES+F1E8G5G(#T@
M=')U93L*"@DO+R!!1$1)3D<@0U535$]-($)55%1/3E,Z('!L96%S92!R96%D
M(&)E;&]W(0H)+R\@9F]R;6%T(&]F('1H92!B=&Y,:7-T(&5L96UE;G1S(&ES
M("))1#H@6R!4;V]L5&EP+"!)8V]N+"!%;F%B;&5D(&EN('1E>'0@;6]D93\L
M($%#5$E/3B!=(@H)+R\@("`@+2!)1#H@=6YI<75E($E$(&9O<B!T:&4@8G5T
M=&]N+B`@268@=&AE(&)U='1O;B!C86QL<R!D;V-U;65N="YE>&5C0V]M;6%N
M9`H)+R\)("`@(&ET)W,@=VES92!T;R!G:79E(&ET('1H92!S86UE(&YA;64@
M87,@=&AE(&-A;&QE9"!C;VUM86YD+@H)+R\@("`@+2!!0U1)3TXZ(&9U;F-T
M:6]N('1H870@9V5T<R!C86QL960@=VAE;B!T:&4@8G5T=&]N(&ES(&-L:6-K
M960N"@DO+R`@("`@("`@("`@("`@:70@:&%S('1H92!F;VQL;W=I;F<@<')O
M=&]T>7!E.@H)+R\@("`@("`@("`@("`@("`@(&9U;F-T:6]N*&5D:71O<BP@
M8G5T=&]N3F%M92D*"2\O("`@("`@("`@("`@("`M(&5D:71O<B!I<R!T:&4@
M2%1-3$%R96$@;V)J96-T('1H870@=')I9V=E<F5D('1H92!C86QL"@DO+R`@
M("`@("`@("`@("`@+2!B=71T;VY.86UE(&ES('1H92!)1"!O9B!T:&4@8VQI
M8VME9"!B=71T;VX*"2\O("`@("`@("`@("`@("!4:&5S92`R('!A<F%M971E
M<G,@;6%K97,@:70@<&]S<VEB;&4@9F]R('EO=2!T;R!U<V4@=&AE('-A;64*
M"2\O("`@("`@("`@("`@("!H86YD;&5R(&9O<B!M;W)E($A434Q!<F5A(&]B
M:F5C=',@;W(@9F]R(&UO<F4@9&EF9F5R96YT(&)U='1O;G,N"@DO+R`@("`M
M(%1O;VQ4:7`Z(&1E9F%U;'0@=&]O;'1I<"P@9F]R(&-A<V5S('=H96X@:70@
M:7,@;F]T(&1E9FEN960@:6X@=&AE("UL86YG+2!F:6QE("A(5$U,07)E82Y)
M,3A.*0H)+R\@("`@+2!)8V]N.B!P871H('1O(&%N(&EC;VX@:6UA9V4@9FEL
M92!F;W(@=&AE(&)U='1O;B`H5$]$3SH@=7-E(&]N92!I;6%G92!F;W(@86QL
M(&)U='1O;G,A*0H)+R\@("`@+2!%;F%B;&5D(&EN('1E>'0@;6]D93H@:68@
M9F%L<V4@=&AE(&)U='1O;B!G971S(&1I<V%B;&5D(&9O<B!T97AT+6]N;'D@
M;6]D93L@;W1H97)W:7-E(&5N86)L960@86QL('1H92!T:6UE+@H)=&AI<RYB
M=&Y,:7-T(#T@>PH)"6)O;&0Z(%L@(D)O;&0B+"`B961?9F]R;6%T7V)O;&0N
M9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")B;VQD
M(BD[?2!=+`H)"6ET86QI8SH@6R`B271A;&EC(BP@(F5D7V9O<FUA=%]I=&%L
M:6,N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")I
M=&%L:6,B*3M](%TL"@D)=6YD97)L:6YE.B!;(")5;F1E<FQI;F4B+"`B961?
M9F]R;6%T7W5N9&5R;&EN92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N
M97AE8T-O;6UA;F0H(G5N9&5R;&EN92(I.WT@72P*"0ES=')I:V5T:')O=6=H
M.B!;(")3=')I:V5T:')O=6=H(BP@(F5D7V9O<FUA=%]S=')I:V4N9VEF(BP@
M9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")S=')I:V5T:')O
M=6=H(BD[?2!=+`H)"7-U8G-C<FEP=#H@6R`B4W5B<V-R:7!T(BP@(F5D7V9O
M<FUA=%]S=6(N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM
M86YD*")S=6)S8W)I<'0B*3M](%TL"@D)<W5P97)S8W)I<'0Z(%L@(E-U<&5R
M<V-R:7!T(BP@(F5D7V9O<FUA=%]S=7`N9VEF(BP@9F%L<V4L(&9U;F-T:6]N
M*&4I('ME+F5X96-#;VUM86YD*")S=7!E<G-C<FEP="(I.WT@72P*"0EJ=7-T
M:69Y;&5F=#H@6R`B2G5S=&EF>2!,969T(BP@(F5D7V%L:6=N7VQE9G0N9VEF
M(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")J=7-T:69Y
M;&5F="(I.WT@72P*"0EJ=7-T:69Y8V5N=&5R.B!;(")*=7-T:69Y($-E;G1E
M<B(L(")E9%]A;&EG;E]C96YT97(N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I
M('ME+F5X96-#;VUM86YD*")J=7-T:69Y8V5N=&5R(BD[?2!=+`H)"6IU<W1I
M9GER:6=H=#H@6R`B2G5S=&EF>2!2:6=H="(L(")E9%]A;&EG;E]R:6=H="YG
M:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(FIU<W1I
M9GER:6=H="(I.WT@72P*"0EJ=7-T:69Y9G5L;#H@6R`B2G5S=&EF>2!&=6QL
M(BP@(F5D7V%L:6=N7VIU<W1I9GDN9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I
M('ME+F5X96-#;VUM86YD*")J=7-T:69Y9G5L;"(I.WT@72P*"0EO<F1E<F5D
M;&ES=#H@6R`B3W)D97)E9"!,:7-T(BP@(F5D7VQI<W1?;G5M+F=I9B(L(&9A
M;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:6YS97)T;W)D97)E
M9&QI<W0B*3M](%TL"@D)=6YO<F1E<F5D;&ES=#H@6R`B0G5L;&5T960@3&ES
M="(L(")E9%]L:7-T7V)U;&QE="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@
M>V4N97AE8T-O;6UA;F0H(FEN<V5R='5N;W)D97)E9&QI<W0B*3M](%TL"@D)
M;W5T9&5N=#H@6R`B1&5C<F5A<V4@26YD96YT(BP@(F5D7VEN9&5N=%]L97-S
M+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B;W5T
M9&5N="(I.WT@72P*"0EI;F1E;G0Z(%L@(DEN8W)E87-E($EN9&5N="(L(")E
M9%]I;F1E;G1?;6]R92YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N97AE
M8T-O;6UA;F0H(FEN9&5N="(I.WT@72P*"0EF;W)E8V]L;W(Z(%L@(D9O;G0@
M0V]L;W(B+"`B961?8V]L;W)?9F<N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I
M('ME+F5X96-#;VUM86YD*")F;W)E8V]L;W(B*3M](%TL"@D):&EL:71E8V]L
M;W(Z(%L@(D)A8VMG<F]U;F0@0V]L;W(B+"`B961?8V]L;W)?8F<N9VEF(BP@
M9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")H:6QI=&5C;VQO
M<B(I.WT@72P*"0EI;G-E<G1H;W)I>F]N=&%L<G5L93H@6R`B2&]R:7IO;G1A
M;"!2=6QE(BP@(F5D7VAR+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE
M>&5C0V]M;6%N9"@B:6YS97)T:&]R:7IO;G1A;')U;&4B*3M](%TL"@D)8W)E
M871E;&EN:SH@6R`B26YS97)T(%=E8B!,:6YK(BP@(F5D7VQI;FLN9VEF(BP@
M9F%L<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")C<F5A=&5L:6YK
M(BP@=')U92D[?2!=+`H)"6EN<V5R=&EM86=E.B!;("));G-E<G0O36]D:69Y
M($EM86=E(BP@(F5D7VEM86=E+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![
M92YE>&5C0V]M;6%N9"@B:6YS97)T:6UA9V4B*3M](%TL"@D):6YS97)T=&%B
M;&4Z(%L@(DEN<V5R="!486)L92(L(")I;G-E<G1?=&%B;&4N9VEF(BP@9F%L
M<V4L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")I;G-E<G1T86)L92(I
M.WT@72P*"0EH=&UL;6]D93H@6R`B5&]G9VQE($A434P@4V]U<F-E(BP@(F5D
M7VAT;6PN9VEF(BP@=')U92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H
M(FAT;6QM;V1E(BD[?2!=+`H)"7!O<'5P961I=&]R.B!;(")%;FQA<F=E($5D
M:71O<B(L(")F=6QL<V-R965N7VUA>&EM:7IE+F=I9B(L('1R=64L(&9U;F-T
M:6]N*&4I('ME+F5X96-#;VUM86YD*")P;W!U<&5D:71O<B(I.WT@72P*"0EA
M8F]U=#H@6R`B06)O=70@=&AI<R!E9&ET;W(B+"`B961?86)O=70N9VEF(BP@
M=')U92P@9G5N8W1I;VXH92D@>V4N97AE8T-O;6UA;F0H(F%B;W5T(BD[?2!=
M+`H)"7-H;W=H96QP.B!;(")(96QP('5S:6YG(&5D:71O<B(L(")E9%]H96QP
M+F=I9B(L('1R=64L(&9U;F-T:6]N*&4I('ME+F5X96-#;VUM86YD*")S:&]W
M:&5L<"(I.WT@72P*"0EU;F1O.B!;(")5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;B(L(")E9%]U;F1O+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C
M0V]M;6%N9"@B=6YD;R(I.WT@72P*"0ER961O.B!;(")2961O97,@>6]U<B!L
M87-T(&%C=&EO;B(L(")E9%]R961O+F=I9B(L(&9A;'-E+"!F=6YC=&EO;BAE
M*2![92YE>&5C0V]M;6%N9"@B<F5D;R(I.WT@72P*"0EC=70Z(%L@(D-U="!S
M96QE8W1I;VXB+"`B961?8W5T+F=I9B(L(&9A;'-E+"!C=71?8V]P>5]P87-T
M92!=+`H)"6-O<'DZ(%L@(D-O<'D@<V5L96-T:6]N(BP@(F5D7V-O<'DN9VEF
M(BP@9F%L<V4L(&-U=%]C;W!Y7W!A<W1E(%TL"@D)<&%S=&4Z(%L@(E!A<W1E
M(&9R;VT@8VQI<&)O87)D(BP@(F5D7W!A<W1E+F=I9B(L(&9A;'-E+"!C=71?
M8V]P>5]P87-T92!=+`H)"6QE9G1T;W)I9VAT.B!;(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(L(")E9%]L969T7W1O7W)I9VAT+F=I9B(L(&9A;'-E+"!F
M=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B;&5F='1O<FEG:'0B*3M](%TL
M"@D)<FEG:'1T;VQE9G0Z(%L@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(BP@
M(F5D7W)I9VAT7W1O7VQE9G0N9VEF(BP@9F%L<V4L(&9U;F-T:6]N*&4I('ME
M+F5X96-#;VUM86YD*")R:6=H='1O;&5F="(I.WT@72P*"0ER96UO=F5F;W)M
M870Z(%L@(E)E;6]V92!F;W)M871T:6YG(BP@(F5D7W)M9F]R;6%T+F=I9B(L
M(&9A;'-E+"!F=6YC=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B<F5M;W9E9F]R
M;6%T(BD[?2!=+`H)"7!R:6YT.B!;(")0<FEN="!D;V-U;65N="(L(")E9%]P
M<FEN="YG:68B+"!F86QS92P@9G5N8W1I;VXH92D@>V4N7VEF<F%M92YC;VYT
M96YT5VEN9&]W+G!R:6YT*"D[?2!=+`H)"6MI;&QW;W)D.B!;(")#;&5A<B!-
M4T]F9FEC92!T86=S(BP@(F5D7VMI;&QW;W)D+F=I9B(L(&9A;'-E+"!F=6YC
M=&EO;BAE*2![92YE>&5C0V]M;6%N9"@B:VEL;'=O<F0B*3M](%T*"7T["@DO
M*B!!1$1)3D<@0U535$]-($)55%1/3E,*"2`J("TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0H)("H*"2`J($ET(&ES(')E8V]M;65N9&5D('1H870@>6]U(&%D9"!T
M:&4@8W5S=&]M(&)U='1O;G,@:6X@86X@97AT97)N86P*"2`J(&9I;&4@86YD
M(&QE879E('1H:7,@;VYE('5N8VAA;F=E9"X@(%1H870G<R!B96-A=7-E('=H
M96X@=V4*"2`J("A);G1E<F%C=&EV951O;VQS+F-O;2D@<F5L96%S92!A(&YE
M=R!O9F9I8VEA;"!V97)S:6]N+"!I="=S(&QE<W,*"2`J(&QI:V5L>2!T:&%T
M('EO=2!W:6QL(&AA=F4@<')O8FQE;7,@=7!G<F%D:6YG($A434Q!<F5A+@H)
M("H*"2`J($5X86UP;&4@;VX@:&]W('1O(&%D9"!A(&-U<W1O;2!B=71T;VX@
M=VAE;B!Y;W4@8V]N<W1R=6-T('1H92!(5$U,07)E83H*"2`J"@D@*B`@('9A
M<B!E9&ET;W(@/2!N97<@2%1-3$%R96$H(GEO=7)?=&5X=%]A<F5A7VED(BD[
M"@D@*B`@('9A<B!C9F<@/2!E9&ET;W(N8V]N9FEG.R`O+R!T:&ES(&ES('1H
M92!D969A=6QT(&-O;F9I9W5R871I;VX*"2`J("`@8V9G+F)T;DQI<W1;(FUY
M+6AI;&ET92)=(#T*"2`J"5L@9G5N8W1I;VXH961I=&]R*2![(&5D:71O<BYS
M=7)R;W5N9$A434PH)SQS<&%N('-T>6QE/2)B86-K9W)O=6YD.GEE;&QO=R(^
M)RP@)SPO<W!A;CXG*3L@?2P@+R\@86-T:6]N"@D@*@D@(")(:6=H;&EG:'0@
M<V5L96-T:6]N(BP@+R\@=&]O;'1I<`H)("H)("`B;7E?:&EL:71E+F=I9B(L
M("\O(&EM86=E"@D@*@D@(&9A;'-E("\O(&1I<V%B;&5D(&EN('1E>'0@;6]D
M90H)("H)73L*"2`J("`@8V9G+G1O;VQB87(N<'5S:"A;(FQI;F5B<F5A:R(L
M(")M>2UH:6QI=&4B72D[("\O(&%D9"!T:&4@;F5W(&)U='1O;B!T;R!T:&4@
M=&]O;&)A<@H)("H*"2`J($%N(&%L=&5R;F%T92`H86QS;R!M;W)E(&-O;G9E
M;FEE;G0@86YD(')E8V]M;65N9&5D*2!W87D@=&\*"2`J(&%C8V]M<&QI<V@@
M=&AI<R!I<R!T;R!U<V4@=&AE(')E9VES=&5R0G5T=&]N(&9U;F-T:6]N(&)E
M;&]W+@H)("HO"@DO+R!I;FET:6%L:7IE('1O;VQT:7!S(&9R;VT@=&AE($DQ
M.$X@;6]D=6QE(&%N9"!G96YE<F%T92!C;W)R96-T(&EM86=E('!A=&@*"69O
M<B`H=F%R(&D@:6X@=&AI<RYB=&Y,:7-T*2!["@D)=F%R(&)T;B`]('1H:7,N
M8G1N3&ES=%MI73L*"0EB=&Y;,5T@/2!?961I=&]R7W5R;"`K('1H:7,N:6UG
M55),("L@8G1N6S%=.PH)"6EF("AT>7!E;V8@2%1-3$%R96$N23$X3BYT;V]L
M=&EP<UMI72`A/2`B=6YD969I;F5D(BD@>PH)"0EB=&Y;,%T@/2!(5$U,07)E
M82Y),3A.+G1O;VQT:7!S6VE=.PH)"7T*"7T*?3L*"B\J*B!(96QP97(@9G5N
M8W1I;VXZ(')E9VES=&5R(&$@;F5W(&)U='1O;B!W:71H('1H92!C;VYF:6=U
M<F%T:6]N+B`@270@8V%N(&)E"B`J(&-A;&QE9"!W:71H(&%L;"`U(&%R9W5M
M96YT<RP@;W(@=VET:"!O;FQY(&]N92`H9FER<W0@;VYE*2X@(%=H96X@8V%L
M;&5D('=I=&@*("H@;VYL>2!O;F4@87)G=6UE;G0@:70@;75S="!B92!A;B!O
M8FIE8W0@=VET:"!T:&4@9F]L;&]W:6YG('!R;W!E<G1I97,Z(&ED+`H@*B!T
M;V]L=&EP+"!I;6%G92P@=&5X=$UO9&4L(&%C=&EO;BX@($5X86UP;&5S.@H@
M*@H@*B`Q+B!C;VYF:6<N<F5G:7-T97)"=71T;VXH(FUY+6AI;&ET92(L(")(
M:6QI=&4@=&5X="(L(")M>2UH:6QI=&4N9VEF(BP@9F%L<V4L(&9U;F-T:6]N
M*&5D:71O<BD@>RXN+GTI.PH@*B`R+B!C;VYF:6<N<F5G:7-T97)"=71T;VXH
M>PH@*B`@("`@(&ED("`@("`@(#H@(FUY+6AI;&ET92(L("`@("`@+R\@=&AE
M($E$(&]F('EO=7(@8G5T=&]N"B`J("`@("`@=&]O;'1I<"`@.B`B2&EL:71E
M('1E>'0B+"`@("`O+R!T:&4@=&]O;'1I<`H@*B`@("`@(&EM86=E("`@(#H@
M(FUY+6AI;&ET92YG:68B+"`@+R\@:6UA9V4@=&\@8F4@9&ES<&QA>65D(&EN
M('1H92!T;V]L8F%R"B`J("`@("`@=&5X=$UO9&4@.B!F86QS92P@("`@("`@
M("`@("`O+R!D:7-A8FQE9"!I;B!T97AT(&UO9&4*("H@("`@("!A8W1I;VX@
M("`Z(&9U;F-T:6]N*&5D:71O<BD@>R`O+R!C86QL960@=VAE;B!T:&4@8G5T
M=&]N(&ES(&-L:6-K960*("H@("`@("`@("`@("`@("`@("`@961I=&]R+G-U
M<G)O=6YD2%1-3"@G/'-P86X@8VQA<W,](FAI;&ET92(^)RP@)SPO<W!A;CXG
M*3L*("H@("`@("`@("`@("`@("`@('TL"B`J("`@("`@8V]N=&5X="`@.B`B
M<"(@("`@("`@("`@("`@("`O+R!W:6QL(&)E(&1I<V%B;&5D(&EF(&]U='-I
M9&4@82`\<#X@96QE;65N=`H@*B`@("!]*3L*("HO"DA434Q!<F5A+D-O;F9I
M9RYP<F]T;W1Y<&4N<F5G:7-T97)"=71T;VX@/2!F=6YC=&EO;BAI9"P@=&]O
M;'1I<"P@:6UA9V4L('1E>'1-;V1E+"!A8W1I;VXL(&-O;G1E>'0I('L*"79A
M<B!T:&5?:60["@EI9B`H='EP96]F(&ED(#T](")S=')I;F<B*2!["@D)=&AE
M7VED(#T@:60["@E](&5L<V4@:68@*'1Y<&5O9B!I9"`]/2`B;V)J96-T(BD@
M>PH)"71H95]I9"`](&ED+FED.PH)?2!E;'-E('L*"0EA;&5R="@B15)23U(@
M6TA434Q!<F5A+D-O;F9I9SHZ<F5G:7-T97)"=71T;VY=.EQN:6YV86QI9"!A
M<F=U;65N=',B*3L*"0ER971U<FX@9F%L<V4["@E]"@DO+R!C:&5C:R!F;W(@
M97AI<W1I;F<@:60*"6EF("AT>7!E;V8@=&AI<RYC=7-T;VU396QE8W1S6W1H
M95]I9%T@(3T@(G5N9&5F:6YE9"(I('L*"0DO+R!A;&5R="@B5T%23DE.1R!;
M2%1-3$%R96$N0V]N9FEG.CIR96=I<W1E<D1R;W!D;W=N73I<;D$@9')O<&1O
M=VX@=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T<RXB*3L*"7T*"6EF
M("AT>7!E;V8@=&AI<RYB=&Y,:7-T6W1H95]I9%T@(3T@(G5N9&5F:6YE9"(I
M('L*"0DO+R!A;&5R="@B5T%23DE.1R!;2%1-3$%R96$N0V]N9FEG.CIR96=I
M<W1E<D1R;W!D;W=N73I<;D$@8G5T=&]N('=I=&@@=&AE('-A;64@240@86QR
M96%D>2!E>&ES=',N(BD["@E]"@ES=VET8V@@*'1Y<&5O9B!I9"D@>PH)("`@
M(&-A<V4@(G-T<FEN9R(Z('1H:7,N8G1N3&ES=%MI9%T@/2!;('1O;VQT:7`L
M(&EM86=E+"!T97AT36]D92P@86-T:6]N+"!C;VYT97AT(%T[(&)R96%K.PH)
M("`@(&-A<V4@(F]B:F5C="(Z('1H:7,N8G1N3&ES=%MI9"YI9%T@/2!;(&ED
M+G1O;VQT:7`L(&ED+FEM86=E+"!I9"YT97AT36]D92P@:60N86-T:6]N+"!I
M9"YC;VYT97AT(%T[(&)R96%K.PH)?0I].PH*+RHJ(%1H92!F;VQL;W=I;F<@
M:&5L<&5R(&9U;F-T:6]N(')E9VES=&5R<R!A(&1R;W!D;W=N(&)O>"!W:71H
M('1H92!E9&ET;W(*("H@8V]N9FEG=7)A=&EO;BX@(%EO=2!S=&EL;"!H879E
M('1O(&%D9"!I="!T;R!T:&4@=&]O;&)A<BP@<V%M92!A<R!W:71H('1H90H@
M*B!B=71T;VYS+B`@0V%L;"!I="!L:6ME('1H:7,Z"B`J"B`J($9)6$U%.B!A
M9&0@97AA;7!L90H@*B\*2%1-3$%R96$N0V]N9FEG+G!R;W1O='EP92YR96=I
M<W1E<D1R;W!D;W=N(#T@9G5N8W1I;VXH;V)J96-T*2!["@DO+R!C:&5C:R!F
M;W(@97AI<W1I;F<@:60*"6EF("AT>7!E;V8@=&AI<RYC=7-T;VU396QE8W1S
M6V]B:F5C="YI9%T@(3T@(G5N9&5F:6YE9"(I('L*"0DO+R!A;&5R="@B5T%2
M3DE.1R!;2%1-3$%R96$N0V]N9FEG.CIR96=I<W1E<D1R;W!D;W=N73I<;D$@
M9')O<&1O=VX@=VET:"!T:&4@<V%M92!)1"!A;')E861Y(&5X:7-T<RXB*3L*
M"7T*"6EF("AT>7!E;V8@=&AI<RYB=&Y,:7-T6V]B:F5C="YI9%T@(3T@(G5N
M9&5F:6YE9"(I('L*"0DO+R!A;&5R="@B5T%23DE.1R!;2%1-3$%R96$N0V]N
M9FEG.CIR96=I<W1E<D1R;W!D;W=N73I<;D$@8G5T=&]N('=I=&@@=&AE('-A
M;64@240@86QR96%D>2!E>&ES=',N(BD["@E]"@ET:&ES+F-U<W1O;5-E;&5C
M='-;;V)J96-T+FED72`](&]B:F5C=#L*?3L*"B\J*B!#86QL('1H:7,@9G5N
M8W1I;VX@=&\@<F5M;W9E('-O;64@8G5T=&]N<R]D<F]P+61O=VX@8F]X97,@
M9G)O;2!T:&4@=&]O;&)A<BX*("H@4&%S<R!A<R!T:&4@;VYL>2!P87)A;65T
M97(@82!S=')I;F<@8V]N=&%I;FEN9R!B=71T;VXO9')O<"UD;W=N(&YA;65S
M"B`J(&1E;&EM:71E9"!B>2!S<&%C97,N("!.;W1E('1H870@=&AE('-T<FEN
M9R!S:&]U;&0@86QS;R!B96=I;B!W:71H(&$@<W!A8V4*("H@86YD(&5N9"!W
M:71H(&$@<W!A8V4N("!%>&%M<&QE.@H@*@H@*B`@(&-O;F9I9RYH:61E4V]M
M94)U='1O;G,H(B!F;VYT;F%M92!F;VYT<VEZ92!T97AT:6YD:6-A=&]R("(I
M.PH@*@H@*B!)="=S('5S969U;"!B96-A=7-E(&ET)W,@96%S:65R('1O(')E
M;6]V92!S='5F9B!F<F]M('1H92!D969A=6P@=&]O;&)A<B!T:&%N"B`J(&-R
M96%T92!A(&)R86YD(&YE=R!T;V]L8F%R(#LM*0H@*B\*2%1-3$%R96$N0V]N
M9FEG+G!R;W1O='EP92YH:61E4V]M94)U='1O;G,@/2!F=6YC=&EO;BAR96UO
M=F4I('L*"79A<B!T;V]L8F%R(#T@=&AI<RYT;V]L8F%R.PH)9F]R("AV87(@
M:2`]('1O;VQB87(N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0EV87(@;&EN92`]
M('1O;VQB87);:5T["@D)9F]R("AV87(@:B`](&QI;F4N;&5N9W1H.R`M+6H@
M/CT@,#L@*2!["@D)"6EF("AR96UO=F4N:6YD97A/9B@B("(@*R!L:6YE6VI=
M("L@(B`B*2`^/2`P*2!["@D)"0EV87(@;&5N(#T@,3L*"0D)"6EF("@O<V5P
M87)A=&]R?'-P86-E+RYT97-T*&QI;F5;:B`K(#%=*2D@>PH)"0D)"6QE;B`]
M(#(["@D)"0E]"@D)"0EL:6YE+G-P;&EC92AJ+"!L96XI.PH)"0E]"@D)?0H)
M?0I].PH*+RHJ($AE;'!E<B!F=6YC=&EO;CH@<F5P;&%C92!A;&P@5$585$%2
M14$M<R!I;B!T:&4@9&]C=6UE;G0@=VET:"!(5$U,07)E82US+B`J+PI(5$U,
M07)E82YR97!L86-E06QL(#T@9G5N8W1I;VXH8V]N9FEG*2!["@EV87(@=&%S
M(#T@9&]C=6UE;G0N9V5T16QE;65N='-">51A9TYA;64H(G1E>'1A<F5A(BD[
M"@EF;W(@*'9A<B!I(#T@=&%S+FQE;F=T:#L@:2`^(#`[("AN97<@2%1-3$%R
M96$H=&%S6RTM:5TL(&-O;F9I9RDI+F=E;F5R871E*"DI.PI].PH*+RHJ($AE
M;'!E<B!F=6YC=&EO;CH@<F5P;&%C97,@=&AE(%1%6%1!4D5!('=I=&@@=&AE
M(&=I=F5N($E$('=I=&@@2%1-3$%R96$N("HO"DA434Q!<F5A+G)E<&QA8V4@
M/2!F=6YC=&EO;BAI9"P@8V]N9FEG*2!["@EV87(@=&$@/2!(5$U,07)E82YG
M971%;&5M96YT0GE)9"@B=&5X=&%R96$B+"!I9"D["@ER971U<FX@=&$@/R`H
M;F5W($A434Q!<F5A*'1A+"!C;VYF:6<I*2YG96YE<F%T92@I(#H@;G5L;#L*
M?3L*"B\O($-R96%T97,@=&AE('1O;VQB87(@86YD(&%P<&5N9',@:70@=&\@
M=&AE(%]H=&UL87)E80I(5$U,07)E82YP<F]T;W1Y<&4N7V-R96%T951O;VQB
M87(@/2!F=6YC=&EO;B`H*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@=&\@
M86-C97-S('1H:7,@:6X@;F5S=&5D(&9U;F-T:6]N<PH*"79A<B!T;V]L8F%R
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B9&EV(BD["@ET:&ES+E]T;V]L
M8F%R(#T@=&]O;&)A<CL*"71O;VQB87(N8VQA<W-.86UE(#T@(G1O;VQB87(B
M.PH)=&]O;&)A<BYU;G-E;&5C=&%B;&4@/2`B,2(["@EV87(@=&)?<F]W(#T@
M;G5L;#L*"79A<B!T8E]O8FIE8W1S(#T@;F5W($]B:F5C="@I.PH)=&AI<RY?
M=&]O;&)A<D]B:F5C=',@/2!T8E]O8FIE8W1S.PH*"2\O(&-R96%T97,@82!N
M97<@;&EN92!I;B!T:&4@=&]O;&)A<@H)9G5N8W1I;VX@;F5W3&EN92@I('L*
M"0EV87(@=&%B;&4@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")T86)L92(I
M.PH)"71A8FQE+F)O<F1E<B`]("(P<'@B.PH)"71A8FQE+F-E;&Q3<&%C:6YG
M(#T@(C!P>"(["@D)=&%B;&4N8V5L;%!A9&1I;F<@/2`B,'!X(CL*"0ET;V]L
M8F%R+F%P<&5N9$-H:6QD*'1A8FQE*3L*"0DO+R!40D]$62!I<R!R97%U:7)E
M9"!F;W(@244L(&]T:&5R=VES92!Y;W4@9&]N)W0@<V5E(&%N>71H:6YG"@D)
M+R\@:6X@=&AE(%1!0DQ%+@H)"79A<B!T8E]B;V1Y(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@B=&)O9'DB*3L*"0ET86)L92YA<'!E;F1#:&EL9"AT8E]B
M;V1Y*3L*"0ET8E]R;W<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")T<B(I
M.PH)"71B7V)O9'DN87!P96YD0VAI;&0H=&)?<F]W*3L*"7T[("\O($5.1"!O
M9B!F=6YC=&EO;CH@;F5W3&EN90H)+R\@:6YI="!F:7)S="!L:6YE"@EN97=,
M:6YE*"D["@H)+R\@=7!D871E<R!T:&4@<W1A=&4@;V8@82!T;V]L8F%R(&5L
M96UE;G0N("!4:&ES(&9U;F-T:6]N(&ES(&UE;6)E<B!O9@H)+R\@82!T;V]L
M8F%R(&5L96UE;G0@;V)J96-T("AU;FYA;65D(&]B:F5C=',@8W)E871E9"!B
M>2!C<F5A=&5"=71T;VX@;W(*"2\O(&-R96%T95-E;&5C="!F=6YC=&EO;G,@
M8F5L;W<I+@H)9G5N8W1I;VX@<V5T0G5T=&]N4W1A='5S*&ED+"!N97=V86PI
M('L*"0EV87(@;VQD=F%L(#T@=&AI<UMI9%T["@D)=F%R(&5L(#T@=&AI<RYE
M;&5M96YT.PH)"6EF("AO;&1V86P@(3T@;F5W=F%L*2!["@D)"7-W:71C:"`H
M:60I('L*"0D)("`@(&-A<V4@(F5N86)L960B.@H)"0D):68@*&YE=W9A;"D@
M>PH)"0D)"4A434Q!<F5A+E]R96UO=F5#;&%S<RAE;"P@(F)U='1O;D1I<V%B
M;&5D(BD["@D)"0D)96PN9&ES86)L960@/2!F86QS93L*"0D)"7T@96QS92![
M"@D)"0D)2%1-3$%R96$N7V%D9$-L87-S*&5L+"`B8G5T=&]N1&ES86)L960B
M*3L*"0D)"0EE;"YD:7-A8FQE9"`]('1R=64["@D)"0E]"@D)"0EB<F5A:SL*
M"0D)("`@(&-A<V4@(F%C=&EV92(Z"@D)"0EI9B`H;F5W=F%L*2!["@D)"0D)
M2%1-3$%R96$N7V%D9$-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I.PH)"0D)
M?2!E;'-E('L*"0D)"0E(5$U,07)E82Y?<F5M;W9E0VQA<W,H96PL(")B=71T
M;VY0<F5S<V5D(BD["@D)"0E]"@D)"0EB<F5A:SL*"0D)?0H)"0ET:&ES6VED
M72`](&YE=W9A;#L*"0E]"@E].R`O+R!%3D0@;V8@9G5N8W1I;VXZ('-E=$)U
M='1O;E-T871U<PH*"2\O('1H:7,@9G5N8W1I;VX@=VEL;"!H86YD;&4@8W)E
M871I;VX@;V8@8V]M8F\@8F]X97,N("!296-E:79E<R!A<PH)+R\@<&%R86UE
M=&5R('1H92!N86UE(&]F(&$@8G5T=&]N(&%S(&1E9FEN960@:6X@=&AE('1O
M;VQ"87(@8V]N9FEG+@H)+R\@5&AI<R!F=6YC=&EO;B!I<R!C86QL960@9G)O
M;2!C<F5A=&5"=71T;VXL(&%B;W9E+"!I9B!T:&4@9VEV96X@(G1X="(*"2\O
M(&1O97-N)W0@;6%T8V@@82!B=71T;VXN"@EF=6YC=&EO;B!C<F5A=&5396QE
M8W0H='AT*2!["@D)=F%R(&]P=&EO;G,@/2!N=6QL.PH)"79A<B!E;"`](&YU
M;&P["@D)=F%R(&-M9"`](&YU;&P["@D)=F%R(&-U<W1O;5-E;&5C=',@/2!E
M9&ET;W(N8V]N9FEG+F-U<W1O;5-E;&5C=',["@D)=F%R(&-O;G1E>'0@/2!N
M=6QL.PH)"79A<B!T;V]L=&EP(#T@(B(["@D)<W=I=&-H("AT>'0I('L*"0D@
M("`@8V%S92`B9F]N='-I>F4B.@H)"2`@("!C87-E(")F;VYT;F%M92(Z"@D)
M("`@(&-A<V4@(F9O<FUA=&)L;V-K(CH*"0D)+R\@=&AE(&9O;&QO=VEN9R!L
M:6YE(')E=')I979E<R!T:&4@8V]R<F5C=`H)"0DO+R!C;VYF:6=U<F%T:6]N
M(&]P=&EO;B!B96-A=7-E('1H92!V87)I86)L92!N86UE"@D)"2\O(&EN<VED
M92!T:&4@0V]N9FEG(&]B:F5C="!I<R!N86UE9"!T:&4@<V%M92!A<R!T:&4*
M"0D)+R\@8G5T=&]N+W-E;&5C="!I;B!T:&4@=&]O;&)A<BX@($9O<B!I;G-T
M86YC92P@:68@='AT"@D)"2\O(#T](")F;W)M871B;&]C:R(@=V4@<F5T<FEE
M=F4@8V]N9FEG+F9O<FUA=&)L;V-K("AO<@H)"0DO+R!A(&1I9F9E<F5N="!W
M87D@=&\@=W)I=&4@:70@:6X@2E,@:7,*"0D)+R\@8V]N9FEG6R)F;W)M871B
M;&]C:R)=+@H)"0EO<'1I;VYS(#T@961I=&]R+F-O;F9I9UMT>'1=.PH)"0EC
M;60@/2!T>'0["@D)"6)R96%K.PH)"2`@("!D969A=6QT.@H)"0DO+R!T<GD@
M=&\@9F5T8V@@:70@9G)O;2!T:&4@;&ES="!O9B!R96=I<W1E<F5D('-E;&5C
M=',*"0D)8VUD(#T@='AT.PH)"0EV87(@9')O<&1O=VX@/2!C=7-T;VU396QE
M8W1S6V-M9%T["@D)"6EF("AT>7!E;V8@9')O<&1O=VX@(3T@(G5N9&5F:6YE
M9"(I('L*"0D)"6]P=&EO;G,@/2!D<F]P9&]W;BYO<'1I;VYS.PH)"0D)8V]N
M=&5X="`](&1R;W!D;W=N+F-O;G1E>'0["@D)"0EI9B`H='EP96]F(&1R;W!D
M;W=N+G1O;VQT:7`@(3T@(G5N9&5F:6YE9"(I('L*"0D)"0ET;V]L=&EP(#T@
M9')O<&1O=VXN=&]O;'1I<#L*"0D)"7T*"0D)?2!E;'-E('L*"0D)"6%L97)T
M*")%4E)/4B!;8W)E871E4V5L96-T73I<;D-A;B=T(&9I;F0@=&AE(')E<75E
M<W1E9"!D<F]P9&]W;B!D969I;FET:6]N(BD["@D)"7T*"0D)8G)E86L["@D)
M?0H)"6EF("AO<'1I;VYS*2!["@D)"65L(#T@9&]C=6UE;G0N8W)E871E16QE
M;65N="@B<V5L96-T(BD["@D)"65L+G1I=&QE(#T@=&]O;'1I<#L*"0D)=F%R
M(&]B:B`]('L*"0D)"6YA;64).B!T>'0L("\O(&9I96QD(&YA;64*"0D)"65L
M96UE;G0@.B!E;"P)+R\@=&AE(%5)(&5L96UE;G0@*%-%3$5#5"D*"0D)"65N
M86)L960@.B!T<G5E+"`O+R!I<R!I="!E;F%B;&5D/PH)"0D)=&5X=`DZ(&9A
M;'-E+"`O+R!E;F%B;&5D(&EN('1E>'0@;6]D93\*"0D)"6-M9`DZ(&-M9"P@
M+R\@8V]M;6%N9"!)1`H)"0D)<W1A=&4).B!S971"=71T;VY3=&%T=7,L("\O
M(&9O<B!C:&%N9VEN9R!S=&%T90H)"0D)8V]N=&5X="`Z(&-O;G1E>'0*"0D)
M?3L*"0D)=&)?;V)J96-T<UMT>'1=(#T@;V)J.PH)"0EF;W(@*'9A<B!I(&EN
M(&]P=&EO;G,I('L*"0D)"79A<B!O<"`](&1O8W5M96YT+F-R96%T945L96UE
M;G0H(F]P=&EO;B(I.PH)"0D);W`N:6YN97)(5$U,(#T@:3L*"0D)"6]P+G9A
M;'5E(#T@;W!T:6]N<UMI73L*"0D)"65L+F%P<&5N9$-H:6QD*&]P*3L*"0D)
M?0H)"0E(5$U,07)E82Y?861D179E;G0H96PL(")C:&%N9V4B+"!F=6YC=&EO
M;B`H*2!["@D)"0EE9&ET;W(N7V-O;6)O4V5L96-T960H96PL('1X="D["@D)
M"7TI.PH)"7T*"0ER971U<FX@96P["@E].R`O+R!%3D0@;V8@9G5N8W1I;VXZ
M(&-R96%T95-E;&5C=`H*"2\O(&%P<&5N9',@82!N97<@8G5T=&]N('1O('1O
M;VQB87(*"69U;F-T:6]N(&-R96%T94)U='1O;BAT>'0I('L*"0DO+R!T:&4@
M96QE;65N="!T:&%T('=I;&P@8F4@8W)E871E9`H)"79A<B!E;"`](&YU;&P[
M"@D)=F%R(&)T;B`](&YU;&P["@D)<W=I=&-H("AT>'0I('L*"0D@("`@8V%S
M92`B<V5P87)A=&]R(CH*"0D)96P@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")D:78B*3L*"0D)96PN8VQA<W-.86UE(#T@(G-E<&%R871O<B(["@D)"6)R
M96%K.PH)"2`@("!C87-E(")S<&%C92(Z"@D)"65L(#T@9&]C=6UE;G0N8W)E
M871E16QE;65N="@B9&EV(BD["@D)"65L+F-L87-S3F%M92`](")S<&%C92([
M"@D)"6)R96%K.PH)"2`@("!C87-E(")L:6YE8G)E86LB.@H)"0EN97=,:6YE
M*"D["@D)"7)E='5R;B!F86QS93L*"0D@("`@8V%S92`B=&5X=&EN9&EC871O
M<B(Z"@D)"65L(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B9&EV(BD["@D)
M"65L+F%P<&5N9$-H:6QD*&1O8W5M96YT+F-R96%T951E>'1.;V1E*")!(BDI
M.PH)"0EE;"YC;&%S<TYA;64@/2`B:6YD:6-A=&]R(CL*"0D)96PN=&ET;&4@
M/2!(5$U,07)E82Y),3A.+G1O;VQT:7!S+G1E>'1I;F1I8V%T;W(["@D)"79A
M<B!O8FH@/2!["@D)"0EN86UE"3H@='AT+"`O+R!T:&4@8G5T=&]N(&YA;64@
M*&DN92X@)V)O;&0G*0H)"0D)96QE;65N="`Z(&5L+"`O+R!T:&4@54D@96QE
M;65N="`H1$E6*0H)"0D)96YA8FQE9"`Z('1R=64L("\O(&ES(&ET(&5N86)L
M960_"@D)"0EA8W1I=F4).B!F86QS92P@+R\@:7,@:70@<')E<W-E9#\*"0D)
M"71E>'0).B!F86QS92P@+R\@96YA8FQE9"!I;B!T97AT(&UO9&4_"@D)"0EC
M;60).B`B=&5X=&EN9&EC871O<B(L("\O('1H92!C;VUM86YD($E$"@D)"0ES
M=&%T90DZ('-E=$)U='1O;E-T871U<R`O+R!F;W(@8VAA;F=I;F<@<W1A=&4*
M"0D)?3L*"0D)=&)?;V)J96-T<UMT>'1=(#T@;V)J.PH)"0EB<F5A:SL*"0D@
M("`@9&5F875L=#H*"0D)8G1N(#T@961I=&]R+F-O;F9I9RYB=&Y,:7-T6W1X
M=%T["@D)?0H)"6EF("@A96P@)B8@8G1N*2!["@D)"65L(#T@9&]C=6UE;G0N
M8W)E871E16QE;65N="@B9&EV(BD["@D)"65L+G1I=&QE(#T@8G1N6S!=.PH)
M"0EE;"YC;&%S<TYA;64@/2`B8G5T=&]N(CL*"0D)+R\@;&5T)W,@:G5S="!P
M<F5T96YD('=E(&AA=F4@82!B=71T;VX@;V)J96-T+"!A;F0*"0D)+R\@87-S
M:6=N(&%L;"!T:&4@;F5E9&5D(&EN9F]R;6%T:6]N('1O(&ET+@H)"0EV87(@
M;V)J(#T@>PH)"0D);F%M90DZ('1X="P@+R\@=&AE(&)U='1O;B!N86UE("AI
M+F4N("=B;VQD)RD*"0D)"65L96UE;G0@.B!E;"P@+R\@=&AE(%5)(&5L96UE
M;G0@*$1)5BD*"0D)"65N86)L960@.B!T<G5E+"`O+R!I<R!I="!E;F%B;&5D
M/PH)"0D)86-T:79E"3H@9F%L<V4L("\O(&ES(&ET('!R97-S960_"@D)"0ET
M97AT"3H@8G1N6S)=+"`O+R!E;F%B;&5D(&EN('1E>'0@;6]D93\*"0D)"6-M
M9`DZ(&)T;ELS72P@+R\@=&AE(&-O;6UA;F0@240*"0D)"7-T871E"3H@<V5T
M0G5T=&]N4W1A='5S+"`O+R!F;W(@8VAA;F=I;F<@<W1A=&4*"0D)"6-O;G1E
M>'0@.B!B=&Y;-%T@?'P@;G5L;"`O+R!E;F%B;&5D(&EN(&$@8V5R=&%I;B!C
M;VYT97AT/PH)"0E].PH)"0ET8E]O8FIE8W1S6W1X=%T@/2!O8FH["@D)"2\O
M(&AA;F1L97)S('1O(&5M=6QA=&4@;FEC92!F;&%T('1O;VQB87(@8G5T=&]N
M<PH)"0E(5$U,07)E82Y?861D179E;G0H96PL(")M;W5S96]V97(B+"!F=6YC
M=&EO;B`H*2!["@D)"0EI9B`H;V)J+F5N86)L960I('L*"0D)"0E(5$U,07)E
M82Y?861D0VQA<W,H96PL(")B=71T;VY(;W9E<B(I.PH)"0D)?0H)"0E]*3L*
M"0D)2%1-3$%R96$N7V%D9$5V96YT*&5L+"`B;6]U<V5O=70B+"!F=6YC=&EO
M;B`H*2!["@D)"0EI9B`H;V)J+F5N86)L960I('=I=&@@*$A434Q!<F5A*2![
M"@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N2&]V97(B*3L*"0D)"0E?
M<F5M;W9E0VQA<W,H96PL(")B=71T;VY!8W1I=F4B*3L*"0D)"0DH;V)J+F%C
M=&EV92D@)B8@7V%D9$-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I.PH)"0D)
M?0H)"0E]*3L*"0D)2%1-3$%R96$N7V%D9$5V96YT*&5L+"`B;6]U<V5D;W=N
M(BP@9G5N8W1I;VX@*&5V*2!["@D)"0EI9B`H;V)J+F5N86)L960I('=I=&@@
M*$A434Q!<F5A*2!["@D)"0D)7V%D9$-L87-S*&5L+"`B8G5T=&]N06-T:79E
M(BD["@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N4')E<W-E9"(I.PH)
M"0D)"5]S=&]P179E;G0H:7-?:64@/R!W:6YD;W<N979E;G0@.B!E=BD["@D)
M"0E]"@D)"7TI.PH)"0DO+R!W:&5N(&-L:6-K960L(&1O('1H92!F;VQL;W=I
M;F<Z"@D)"4A434Q!<F5A+E]A9&1%=F5N="AE;"P@(F-L:6-K(BP@9G5N8W1I
M;VX@*&5V*2!["@D)"0EI9B`H;V)J+F5N86)L960I('=I=&@@*$A434Q!<F5A
M*2!["@D)"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N06-T:79E(BD["@D)
M"0D)7W)E;6]V94-L87-S*&5L+"`B8G5T=&]N2&]V97(B*3L*"0D)"0EO8FHN
M8VUD*&5D:71O<BP@;V)J+FYA;64L(&]B:BD["@D)"0D)7W-T;W!%=F5N="AI
M<U]I92`_('=I;F1O=RYE=F5N="`Z(&5V*3L*"0D)"7T*"0D)?2D["@D)"79A
M<B!I;6<@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")I;6<B*3L*"0D):6UG
M+G-R8R`](&)T;ELQ73L*"0D):6UG+G-T>6QE+G=I9'1H(#T@(C$X<'@B.PH)
M"0EI;6<N<W1Y;&4N:&5I9VAT(#T@(C$X<'@B.PH)"0EE;"YA<'!E;F1#:&EL
M9"AI;6<I.PH)"7T@96QS92!I9B`H(65L*2!["@D)"65L(#T@8W)E871E4V5L
M96-T*'1X="D["@D)?0H)"6EF("AE;"D@>PH)"0EV87(@=&)?8V5L;"`](&1O
M8W5M96YT+F-R96%T945L96UE;G0H(G1D(BD["@D)"71B7W)O=RYA<'!E;F1#
M:&EL9"AT8E]C96QL*3L*"0D)=&)?8V5L;"YA<'!E;F1#:&EL9"AE;"D["@D)
M?2!E;'-E('L*"0D)86QE<G0H(D9)6$U%.B!5;FMN;W=N('1O;VQB87(@:71E
M;3H@(B`K('1X="D["@D)?0H)"7)E='5R;B!E;#L*"7T["@H)=F%R(&9I<G-T
M(#T@=')U93L*"69O<B`H=F%R(&D@/2`P.R!I(#P@=&AI<RYC;VYF:6<N=&]O
M;&)A<BYL96YG=&@[("LK:2D@>PH)"6EF("@A9FER<W0I('L*"0D)8W)E871E
M0G5T=&]N*")L:6YE8G)E86LB*3L*"0E](&5L<V4@>PH)"0EF:7)S="`](&9A
M;'-E.PH)"7T*"0EV87(@9W)O=7`@/2!T:&ES+F-O;F9I9RYT;V]L8F%R6VE=
M.PH)"69O<B`H=F%R(&H@/2`P.R!J(#P@9W)O=7`N;&5N9W1H.R`K*VHI('L*
M"0D)=F%R(&-O9&4@/2!G<F]U<%MJ73L*"0D):68@*"]>*%M)5%TI7%LH+BH_
M*5Q=+RYT97-T*&-O9&4I*2!["@D)"0DO+R!S<&5C:6%L(&-A<V4L(&-R96%T
M92!T97AT(&QA8F5L"@D)"0EV87(@;#=E9"`](%)E9T5X<"XD,2`]/2`B22([
M("\O(&QO8V%L:7IE9#\*"0D)"79A<B!L86)E;"`](%)E9T5X<"XD,CL*"0D)
M"6EF("AL-V5D*2!["@D)"0D);&%B96P@/2!(5$U,07)E82Y),3A.+F-U<W1O
M;5ML86)E;%T["@D)"0E]"@D)"0EV87(@=&)?8V5L;"`](&1O8W5M96YT+F-R
M96%T945L96UE;G0H(G1D(BD["@D)"0ET8E]R;W<N87!P96YD0VAI;&0H=&)?
M8V5L;"D["@D)"0ET8E]C96QL+F-L87-S3F%M92`](")L86)E;"(["@D)"0ET
M8E]C96QL+FEN;F5R2%1-3"`](&QA8F5L.PH)"0E](&5L<V4@>PH)"0D)8W)E
M871E0G5T=&]N*&-O9&4I.PH)"0E]"@D)?0H)?0H*"71H:7,N7VAT;6Q!<F5A
M+F%P<&5N9$-H:6QD*'1O;VQB87(I.PI].PH*2%1-3$%R96$N<')O=&]T>7!E
M+E]C<F5A=&53=&%T=7-"87(@/2!F=6YC=&EO;B@I('L*"79A<B!S=&%T=7-B
M87(@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")D:78B*3L*"7-T871U<V)A
M<BYC;&%S<TYA;64@/2`B<W1A='5S0F%R(CL*"71H:7,N7VAT;6Q!<F5A+F%P
M<&5N9$-H:6QD*'-T871U<V)A<BD["@ET:&ES+E]S=&%T=7-"87(@/2!S=&%T
M=7-B87(["@DO+R!S=&%T=7-B87(N87!P96YD0VAI;&0H9&]C=6UE;G0N8W)E
M871E5&5X=$YO9&4H2%1-3$%R96$N23$X3BYM<V=;(E!A=&@B72`K("(Z("(I
M*3L*"2\O(&-R96%T97,@82!H;VQD97(@9F]R('1H92!P871H('9I97<*"61I
M=B`](&1O8W5M96YT+F-R96%T945L96UE;G0H(G-P86XB*3L*"61I=BYC;&%S
M<TYA;64@/2`B<W1A='5S0F%R5')E92(["@ED:78N:6YN97)(5$U,(#T@2%1-
M3$%R96$N23$X3BYM<V=;(E!A=&@B72`K("(Z("(["@ET:&ES+E]S=&%T=7-"
M87)4<F5E(#T@9&EV.PH)=&AI<RY?<W1A='5S0F%R+F%P<&5N9$-H:6QD*&1I
M=BD["@EI9B`H(71H:7,N8V]N9FEG+G-T871U<T)A<BD@>PH)"2\O(&1I<V%B
M;&4@:70N+BX*"0ES=&%T=7-B87(N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*
M"7T*?3L*"B\O($-R96%T97,@=&AE($A434Q!<F5A(&]B:F5C="!A;F0@<F5P
M;&%C97,@=&AE('1E>'1A<F5A('=I=&@@:70N"DA434Q!<F5A+G!R;W1O='EP
M92YG96YE<F%T92`](&9U;F-T:6]N("@I('L*"79A<B!E9&ET;W(@/2!T:&ES
M.PDO+R!W92=L;"!N965D(")T:&ES(B!I;B!S;VUE(&YE<W1E9"!F=6YC=&EO
M;G,*"2\O(&=E="!T:&4@=&5X=&%R96$*"79A<B!T97AT87)E82`]('1H:7,N
M7W1E>'1!<F5A.PH):68@*'1Y<&5O9B!T97AT87)E82`]/2`B<W1R:6YG(BD@
M>PH)"2\O(&ET)W,@;F]T(&5L96UE;G0@8G5T($E$"@D)=&AI<RY?=&5X=$%R
M96$@/2!T97AT87)E82`]($A434Q!<F5A+F=E=$5L96UE;G1">4ED*")T97AT
M87)E82(L('1E>'1A<F5A*3L*"7T*"71H:7,N7W1A7W-I>F4@/2!["@D)=SH@
M=&5X=&%R96$N;V9F<V5T5VED=&@L"@D):#H@=&5X=&%R96$N;V9F<V5T2&5I
M9VAT"@E].PH)=&5X=&%R96$N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*"@DO
M+R!C<F5A=&4@=&AE(&5D:71O<B!F<F%M97=O<FL*"79A<B!H=&UL87)E82`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H(F1I=B(I.PH):'1M;&%R96$N8VQA
M<W-.86UE(#T@(FAT;6QA<F5A(CL*"71H:7,N7VAT;6Q!<F5A(#T@:'1M;&%R
M96$["@H)+R\@:6YS97)T('1H92!E9&ET;W(@8F5F;W)E('1H92!T97AT87)E
M82X*"71E>'1A<F5A+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*&AT;6QA<F5A
M+"!T97AT87)E82D["@H):68@*'1E>'1A<F5A+F9O<FTI('L*"0DO+R!W92!H
M879E(&$@9F]R;2P@;VX@<W5B;6ET(&=E="!T:&4@2%1-3$%R96$@8V]N=&5N
M="!A;F0*"0DO+R!U<&1A=&4@;W)I9VEN86P@=&5X=&%R96$N"@D)=F%R(&8@
M/2!T97AT87)E82YF;W)M.PH)"6EF("AT>7!E;V8@9BYO;G-U8FUI="`]/2`B
M9G5N8W1I;VXB*2!["@D)"79A<B!F=6YC<F5F(#T@9BYO;G-U8FUI=#L*"0D)
M:68@*'1Y<&5O9B!F+E]?;7-H7W!R979/;E-U8FUI="`]/2`B=6YD969I;F5D
M(BD@>PH)"0D)9BY?7VUS:%]P<F5V3VY3=6)M:70@/2!;73L*"0D)?0H)"0EF
M+E]?;7-H7W!R979/;E-U8FUI="YP=7-H*&9U;F-R968I.PH)"7T*"0EF+F]N
M<W5B;6ET(#T@9G5N8W1I;VXH*2!["@D)"65D:71O<BY?=&5X=$%R96$N=F%L
M=64@/2!E9&ET;W(N9V5T2%1-3"@I.PH)"0EV87(@82`]('1H:7,N7U]M<VA?
M<')E=D]N4W5B;6ET.PH)"0DO+R!C86QL('!R979I;W5S('-U8FUI="!M971H
M;V1S(&EF('1H97D@=V5R92!T:&5R92X*"0D):68@*'1Y<&5O9B!A("$](")U
M;F1E9FEN960B*2!["@D)"0EF;W(@*'9A<B!I(#T@82YL96YG=&@[("TM:2`^
M/2`P.RD@>PH)"0D)"6%;:5TH*3L*"0D)"7T*"0D)?0H)"7T["@D):68@*'1Y
M<&5O9B!F+F]N<F5S970@/3T@(F9U;F-T:6]N(BD@>PH)"0EV87(@9G5N8W)E
M9B`](&8N;VYR97-E=#L*"0D):68@*'1Y<&5O9B!F+E]?;7-H7W!R979/;E)E
M<V5T(#T](")U;F1E9FEN960B*2!["@D)"0EF+E]?;7-H7W!R979/;E)E<V5T
M(#T@6UT["@D)"7T*"0D)9BY?7VUS:%]P<F5V3VY297-E="YP=7-H*&9U;F-R
M968I.PH)"7T*"0EF+F]N<F5S970@/2!F=6YC=&EO;B@I('L*"0D)961I=&]R
M+G-E=$A434PH961I=&]R+E]T97AT07)E82YV86QU92D["@D)"65D:71O<BYU
M<&1A=&54;V]L8F%R*"D["@D)"79A<B!A(#T@=&AI<RY?7VUS:%]P<F5V3VY2
M97-E=#L*"0D)+R\@8V%L;"!P<F5V:6]U<R!R97-E="!M971H;V1S(&EF('1H
M97D@=V5R92!T:&5R92X*"0D):68@*'1Y<&5O9B!A("$](")U;F1E9FEN960B
M*2!["@D)"0EF;W(@*'9A<B!I(#T@82YL96YG=&@[("TM:2`^/2`P.RD@>PH)
M"0D)"6%;:5TH*3L*"0D)"7T*"0D)?0H)"7T["@E]"@H)+R\@861D(&$@:&%N
M9&QE<B!F;W(@=&AE(")B86-K+V9O<G=A<F0B(&-A<V4@+2T@;VX@8F]D>2YU
M;FQO860@=V4@<V%V90H)+R\@=&AE($A434P@8V]N=&5N="!I;G1O('1H92!O
M<FEG:6YA;"!T97AT87)E82X*"71R>2!["@D)=VEN9&]W+F]N=6YL;V%D(#T@
M9G5N8W1I;VXH*2!["@D)"65D:71O<BY?=&5X=$%R96$N=F%L=64@/2!E9&ET
M;W(N9V5T2%1-3"@I.PH)"7T["@E](&-A=&-H*&4I('M].PH*"2\O(&-R96%T
M97,@)B!A<'!E;F1S('1H92!T;V]L8F%R"@ET:&ES+E]C<F5A=&54;V]L8F%R
M*"D["@H)+R\@8W)E871E('1H92!)1E)!344*"79A<B!I9G)A;64@/2!D;V-U
M;65N="YC<F5A=&5%;&5M96YT*")I9G)A;64B*3L*"@DO+R!W;W)K87)O=6YD
M(&9O<B!T:&4@2%144%,@<')O8FQE;0H)+R\@:69R86UE+G-E=$%T=')I8G5T
M92@B<W)C(BP@(FIA=F%S8W)I<'0Z=F]I9"@P*3LB*3L*"6EF<F%M92YS<F,@
M/2!?961I=&]R7W5R;"`K(")P;W!U<',O8FQA;FLN:'1M;"(["@H):'1M;&%R
M96$N87!P96YD0VAI;&0H:69R86UE*3L*"@ET:&ES+E]I9G)A;64@/2!I9G)A
M;64["@H)+R\@8W)E871E<R`F(&%P<&5N9',@=&AE('-T871U<R!B87(L(&EF
M('1H92!C87-E"@ET:&ES+E]C<F5A=&53=&%T=7-"87(H*3L*"@DO+R!R96UO
M=F4@=&AE(&1E9F%U;'0@8F]R9&5R(&%S(&ET(&ME97!S('5S(&9R;VT@8V]M
M<'5T:6YG(&-O<G)E8W1L>0H)+R\@=&AE('-I>F5S+B`@*'-O;65B;V1Y('1E
M;&P@;64@=VAY(&1O97-N)W0@=&AI<R!W;W)K(&EN($E%*0H*"6EF("@A2%1-
M3$%R96$N:7-?:64I('L*"0EI9G)A;64N<W1Y;&4N8F]R9&5R5VED=&@@/2`B
M,7!X(CL*"2\O(&EF<F%M92YF<F%M94)O<F1E<B`]("(Q(CL*"2\O(&EF<F%M
M92YM87)G:6Y(96EG:'0@/2`B,"(["@DO+R!I9G)A;64N;6%R9VEN5VED=&@@
M/2`B,"(["@E]"@H)+R\@<VEZ92!T:&4@249204U%(&%C8V]R9&EN9R!T;R!U
M<V5R)W,@<')E9G,@;W(@:6YI=&EA;"!T97AT87)E80H)=F%R(&AE:6=H="`]
M("AT:&ES+F-O;F9I9RYH96EG:'0@/3T@(F%U=&\B(#\@*'1H:7,N7W1A7W-I
M>F4N:"`K(")P>"(I(#H@=&AI<RYC;VYF:6<N:&5I9VAT*3L*"6AE:6=H="`]
M('!A<G-E26YT*&AE:6=H="D["@EV87(@=VED=&@@/2`H=&AI<RYC;VYF:6<N
M=VED=&@@/3T@(F%U=&\B(#\@*'1H:7,N7W1A7W-I>F4N=R`K(")P>"(I(#H@
M=&AI<RYC;VYF:6<N=VED=&@I.PH)=VED=&@@/2!P87)S94EN="AW:61T:"D[
M"@H):68@*"%(5$U,07)E82YI<U]I92D@>PH)"6AE:6=H="`M/2`R.PH)"7=I
M9'1H("T](#(["@E]"@H):69R86UE+G-T>6QE+G=I9'1H(#T@=VED=&@@*R`B
M<'@B.PH):68@*'1H:7,N8V]N9FEG+G-I>F5);F-L=61E<U1O;VQB87(I('L*
M"0DO+R!S=6)S=')A8W0@=&]O;&)A<B!H96EG:'0*"0EH96EG:'0@+3T@=&AI
M<RY?=&]O;&)A<BYO9F9S971(96EG:'0["@D):&5I9VAT("T]('1H:7,N7W-T
M871U<T)A<BYO9F9S971(96EG:'0["@E]"@EI9B`H:&5I9VAT(#P@,"D@>PH)
M"6AE:6=H="`](#`["@E]"@EI9G)A;64N<W1Y;&4N:&5I9VAT(#T@:&5I9VAT
M("L@(G!X(CL*"@DO+R!T:&4@961I=&]R(&EN8VQU9&EN9R!T:&4@=&]O;&)A
M<B!N;W<@:&%V92!T:&4@<V%M92!S:7IE(&%S('1H90H)+R\@;W)I9VEN86P@
M=&5X=&%R96$N+B!W:&EC:"!M96%N<R!T:&%T('=E(&YE960@=&\@<F5D=6-E
M('1H870@82!B:70N"@ET97AT87)E82YS='EL92YW:61T:"`](&EF<F%M92YS
M='EL92YW:61T:#L*(`ET97AT87)E82YS='EL92YH96EG:'0@/2!I9G)A;64N
M<W1Y;&4N:&5I9VAT.PH*"2\O($E-4$]25$%.5#H@=V4@:&%V92!T;R!A;&QO
M=R!-;WII;&QA(&$@<VAO<G0@=&EM92!T;R!R96-O9VYI>F4@=&AE"@DO+R!N
M97<@9G)A;64N("!/=&AE<G=I<V4@=V4@9V5T(&$@<W1U<&ED(&5X8V5P=&EO
M;BX*"69U;F-T:6]N(&EN:71)9G)A;64H*2!["@D)=F%R(&1O8R`](&5D:71O
M<BY?:69R86UE+F-O;G1E;G17:6YD;W<N9&]C=6UE;G0["@D):68@*"%D;V,I
M('L*"0D)+R\@5')Y(&%G86EN+BX*"0D)+R\@1DE8344Z(&1O;B=T(&MN;W<@
M=VAA="!E;'-E('1O(&1O(&AE<F4N("!.;W)M86QL>0H)"0DO+R!W92=L;"!N
M979E<B!R96%C:"!T:&ES('!O:6YT+@H)"0EI9B`H2%1-3$%R96$N:7-?9V5C
M:V\I('L*"0D)"7-E=%1I;65O=70H:6YI=$EF<F%M92P@,3`P*3L*"0D)"7)E
M='5R;B!F86QS93L*"0D)?2!E;'-E('L*"0D)"6%L97)T*")%4E)/4CH@2492
M04U%(&-A;B=T(&)E(&EN:71I86QI>F5D+B(I.PH)"0E]"@D)?0H)"6EF("A(
M5$U,07)E82YI<U]G96-K;RD@>PH)"0DO+R!E;F%B;&4@961I=&%B;&4@;6]D
M92!F;W(@36]Z:6QL80H)"0ED;V,N9&5S:6=N36]D92`](")O;B(["@D)?0H)
M"65D:71O<BY?9&]C(#T@9&]C.PH)"6EF("@A961I=&]R+F-O;F9I9RYF=6QL
M4&%G92D@>PH)"0ED;V,N;W!E;B@I.PH)"0EV87(@:'1M;"`]("(\:'1M;#Y<
M;B(["@D)"6AT;6P@*ST@(CQH96%D/EQN(CL*"0D):68@*&5D:71O<BYC;VYF
M:6<N8F%S95523"D*"0D)"6AT;6P@*ST@)SQB87-E(&AR968](B<@*R!E9&ET
M;W(N8V]N9FEG+F)A<V554DP@*R`G(B`O/B<["@D)"6AT;6P@*ST@(CQS='EL
M93XB("L@961I=&]R+F-O;F9I9RYP86=E4W1Y;&4@*PH)"0D)(B!H=&UL+&)O
M9'D@>R!B;W)D97(Z(#!P>#L@?3PO<W1Y;&4^7&XB.PH)"0EH=&UL("L]("(\
M+VAE860^7&XB.PH)"0EH=&UL("L]("(\8F]D>3Y<;B(["@D)"6AT;6P@*ST@
M961I=&]R+E]T97AT07)E82YV86QU93L*"0D):'1M;"`K/2`B/"]B;V1Y/EQN
M(CL*"0D):'1M;"`K/2`B/"]H=&UL/B(["@D)"61O8RYW<FET92AH=&UL*3L*
M"0D)9&]C+F-L;W-E*"D["@D)?2!E;'-E('L*"0D)=F%R(&AT;6P@/2!E9&ET
M;W(N7W1E>'1!<F5A+G9A;'5E.PH)"0EI9B`H:'1M;"YM871C:"A(5$U,07)E
M82Y215]D;V-T>7!E*2D@>PH)"0D)961I=&]R+G-E=$1O8W1Y<&4H4F5G17AP
M+B0Q*3L*"0D)"6AT;6P@/2!H=&UL+G)E<&QA8V4H2%1-3$%R96$N4D5?9&]C
M='EP92P@(B(I.PH)"0E]"@D)"61O8RYO<&5N*"D["@D)"61O8RYW<FET92AH
M=&UL*3L*"0D)9&]C+F-L;W-E*"D["@D)?0H*"0EI9B`H2%1-3$%R96$N:7-?
M:64I('L*"0D)+R\@96YA8FQE(&5D:71A8FQE(&UO9&4@9F]R($E%+@D@1F]R
M('-O;64@<F5A<V]N('1H:7,*"0D)+R\@9&]E<VXG="!W;W)K(&EF(&1O;F4@
M:6X@=&AE('-A;64@<&QA8V4@87,@9F]R($=E8VMO"@D)"2\O("AA8F]V92DN
M"@D)"61O8RYB;V1Y+F-O;G1E;G1%9&ET86)L92`]('1R=64["@D)?0H*"0EE
M9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0DO+R!I;G1E<F-E<'0@<V]M92!E=F5N
M=',[(&9O<B!U<&1A=&EN9R!T:&4@=&]O;&)A<B`F(&ME>6)O87)D(&AA;F1L
M97)S"@D)2%1-3$%R96$N7V%D9$5V96YT<PH)"0DH9&]C+"!;(FME>61O=VXB
M+"`B:V5Y<')E<W,B+"`B;6]U<V5D;W=N(BP@(FUO=7-E=7`B+"`B9')A9R)=
M+`H)"0D@9G5N8W1I;VX@*&5V96YT*2!["@D)"0D@<F5T=7)N(&5D:71O<BY?
M961I=&]R179E;G0H2%1-3$%R96$N:7-?:64@/R!E9&ET;W(N7VEF<F%M92YC
M;VYT96YT5VEN9&]W+F5V96YT(#H@979E;G0I.PH)"0D@?2D["@H)"2\O(&-H
M96-K(&EF(&%N>2!P;'5G:6YS(&AA=F4@<F5G:7-T97)E9"!R969R97-H(&AA
M;F1L97)S"@D)9F]R("AV87(@:2!I;B!E9&ET;W(N<&QU9VEN<RD@>PH)"0EV
M87(@<&QU9VEN(#T@961I=&]R+G!L=6=I;G-;:5TN:6YS=&%N8V4["@D)"6EF
M("AT>7!E;V8@<&QU9VEN+F]N1V5N97)A=&4@/3T@(F9U;F-T:6]N(BD*"0D)
M"7!L=6=I;BYO;D=E;F5R871E*"D["@D)"6EF("AT>7!E;V8@<&QU9VEN+F]N
M1V5N97)A=&5/;F-E(#T](")F=6YC=&EO;B(I('L*"0D)"7!L=6=I;BYO;D=E
M;F5R871E3VYC92@I.PH)"0D)<&QU9VEN+F]N1V5N97)A=&5/;F-E(#T@;G5L
M;#L*"0D)?0H)"7T*"@D)<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0D)961I
M=&]R+G5P9&%T951O;VQB87(H*3L*"0E]+"`R-3`I.PH*"0EI9B`H='EP96]F
M(&5D:71O<BYO;D=E;F5R871E(#T](")F=6YC=&EO;B(I"@D)"65D:71O<BYO
M;D=E;F5R871E*"D["@E].PH)<V5T5&EM96]U="AI;FET269R86UE+"`Q,#`I
M.PH)<F5T=7)N('1H:7,["GT["@HO+R!3=VET8VAE<R!E9&ET;W(@;6]D93L@
M<&%R86UE=&5R(&-A;B!B92`B=&5X=&UO9&4B(&]R(")W>7-I=WEG(BX@($EF
M(&YO"B\O('!A<F%M971E<B!W87,@<&%S<V5D('1H:7,@9G5N8W1I;VX@=&]G
M9VQE<R!B971W965N(&UO9&5S+@I(5$U,07)E82YP<F]T;W1Y<&4N<V5T36]D
M92`](&9U;F-T:6]N*&UO9&4I('L*"6EF("AT>7!E;V8@;6]D92`]/2`B=6YD
M969I;F5D(BD@>PH)"6UO9&4@/2`H*'1H:7,N7V5D:71-;V1E(#T](")T97AT
M;6]D92(I(#\@(G=Y<VEW>6<B(#H@(G1E>'1M;V1E(BD["@E]"@ES=VET8V@@
M*&UO9&4I('L*"2`@("!C87-E(")T97AT;6]D92(Z"@D)=&AI<RY?=&5X=$%R
M96$N=F%L=64@/2!T:&ES+F=E=$A434PH*3L*"0ET:&ES+E]I9G)A;64N<W1Y
M;&4N9&ES<&QA>2`](")N;VYE(CL*"0ET:&ES+E]T97AT07)E82YS='EL92YD
M:7-P;&%Y(#T@(F)L;V-K(CL*"0EI9B`H=&AI<RYC;VYF:6<N<W1A='5S0F%R
M*2!["@D)"71H:7,N7W-T871U<T)A<BYI;FYE<DA434P@/2!(5$U,07)E82Y)
M,3A.+FUS9ULB5$585%]-3T1%(ET["@D)?0H)"6)R96%K.PH)("`@(&-A<V4@
M(G=Y<VEW>6<B.@H)"6EF("A(5$U,07)E82YI<U]G96-K;RD@>PH)"0DO+R!D
M:7-A8FQE(&1E<VEG;B!M;V1E(&)E9F]R92!C:&%N9VEN9R!I;FYE<DA434P*
M"0D)=')Y('L*"0D)"71H:7,N7V1O8RYD97-I9VY-;V1E(#T@(F]F9B(["@D)
M"7T@8V%T8V@H92D@>WT["@D)?0H)"6EF("@A=&AI<RYC;VYF:6<N9G5L;%!A
M9V4I"@D)"71H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"`]('1H:7,N9V5T2%1-
M3"@I.PH)"65L<V4*"0D)=&AI<RYS971&=6QL2%1-3"AT:&ES+F=E=$A434PH
M*2D["@D)=&AI<RY?:69R86UE+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB.PH)
M"71H:7,N7W1E>'1!<F5A+G-T>6QE+F1I<W!L87D@/2`B;F]N92(["@D):68@
M*$A434Q!<F5A+FES7V=E8VMO*2!["@D)"2\O('=E(&YE960@=&\@<F5F<F5S
M:"!T:&%T(&EN9F\@9F]R($UO>BTQ+C-A"@D)"71R>2!["@D)"0ET:&ES+E]D
M;V,N9&5S:6=N36]D92`](")O;B(["@D)"7T@8V%T8V@H92D@>WT["@D)?0H)
M"6EF("AT:&ES+F-O;F9I9RYS=&%T=7-"87(I('L*"0D)=&AI<RY?<W1A='5S
M0F%R+FEN;F5R2%1-3"`]("<G.PH)"0DO+R!T:&ES+E]S=&%T=7-"87(N87!P
M96YD0VAI;&0H9&]C=6UE;G0N8W)E871E5&5X=$YO9&4H2%1-3$%R96$N23$X
M3BYM<V=;(E!A=&@B72`K("(Z("(I*3L*"0D)=&AI<RY?<W1A='5S0F%R+F%P
M<&5N9$-H:6QD*'1H:7,N7W-T871U<T)A<E1R964I.PH)"7T*"0EB<F5A:SL*
M"2`@("!D969A=6QT.@H)"6%L97)T*")-;V1E(#PB("L@;6]D92`K("(^(&YO
M="!D969I;F5D(2(I.PH)"7)E='5R;B!F86QS93L*"7T*"71H:7,N7V5D:71-
M;V1E(#T@;6]D93L*"71H:7,N9F]C=7-%9&ET;W(H*3L*"@EF;W(@*'9A<B!I
M(&EN('1H:7,N<&QU9VEN<RD@>PH)"79A<B!P;'5G:6X@/2!T:&ES+G!L=6=I
M;G-;:5TN:6YS=&%N8V4["@D):68@*'1Y<&5O9B!P;'5G:6XN;VY-;V1E(#T]
M(")F=6YC=&EO;B(I('!L=6=I;BYO;DUO9&4H;6]D92D["@E]"GT["@I(5$U,
M07)E82YP<F]T;W1Y<&4N<V5T1G5L;$A434P@/2!F=6YC=&EO;BAH=&UL*2![
M"@EV87(@<V%V95]M=6QT:6QI;F4@/2!296=%>'`N;75L=&EL:6YE.PH)4F5G
M17AP+FUU;'1I;&EN92`]('1R=64["@EI9B`H:'1M;"YM871C:"A(5$U,07)E
M82Y215]D;V-T>7!E*2D@>PH)"71H:7,N<V5T1&]C='EP92A296=%>'`N)#$I
M.PH)"6AT;6P@/2!H=&UL+G)E<&QA8V4H2%1-3$%R96$N4D5?9&]C='EP92P@
M(B(I.PH)?0H)4F5G17AP+FUU;'1I;&EN92`]('-A=F5?;75L=&EL:6YE.PH)
M:68@*"%(5$U,07)E82YI<U]I92D@>PH)"6EF("AH=&UL+FUA=&-H*$A434Q!
M<F5A+E)%7VAE860I*0H)"0ET:&ES+E]D;V,N9V5T16QE;65N='-">51A9TYA
M;64H(FAE860B*5LP72YI;FYE<DA434P@/2!296=%>'`N)#$["@D):68@*&AT
M;6PN;6%T8V@H2%1-3$%R96$N4D5?8F]D>2DI"@D)"71H:7,N7V1O8RYG971%
M;&5M96YT<T)Y5&%G3F%M92@B8F]D>2(I6S!=+FEN;F5R2%1-3"`](%)E9T5X
M<"XD,3L*"7T@96QS92!["@D)=F%R(&AT;6Q?<F4@/2`O/&AT;6P^*"@N?%QN
M*2H_*3Q<+VAT;6P^+VD["@D):'1M;"`](&AT;6PN<F5P;&%C92AH=&UL7W)E
M+"`B)#$B*3L*"0ET:&ES+E]D;V,N;W!E;B@I.PH)"71H:7,N7V1O8RYW<FET
M92AH=&UL*3L*"0ET:&ES+E]D;V,N8VQO<V4H*3L*"0ET:&ES+E]D;V,N8F]D
M>2YC;VYT96YT161I=&%B;&4@/2!T<G5E.PH)"7)E='5R;B!T<G5E.PH)?0I]
M.PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*@H@*B`@0V%T96=O<GDZ(%!,54=)3E,*("HJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"B\O
M($-R96%T92!T:&4@<W!E8VEF:65D('!L=6=I;B!A;F0@<F5G:7-T97(@:70@
M=VET:"!T:&ES($A434Q!<F5A"DA434Q!<F5A+G!R;W1O='EP92YR96=I<W1E
M<E!L=6=I;B`](&9U;F-T:6]N*"D@>PH)=F%R('!L=6=I;B`](&%R9W5M96YT
M<ULP73L*"79A<B!A<F=S(#T@6UT["@EF;W(@*'9A<B!I(#T@,3L@:2`\(&%R
M9W5M96YT<RYL96YG=&@[("LK:2D*"0EA<F=S+G!U<V@H87)G=6UE;G1S6VE=
M*3L*"71H:7,N<F5G:7-T97)0;'5G:6XR*'!L=6=I;BP@87)G<RD["GT["@HO
M+R!T:&ES(&ES('1H92!V87)I86YT(&]F('1H92!F=6YC=&EO;B!A8F]V92!W
M:&5R92!T:&4@<&QU9VEN(&%R9W5M96YT<R!A<F4*+R\@86QR96%D>2!P86-K
M960@:6X@86X@87)R87DN("!%>'1E<FYA;&QY+"!I="!S:&]U;&0@8F4@;VYL
M>2!U<V5D(&EN('1H90HO+R!F=6QL+7-C<F5E;B!E9&ET;W(@8V]D92P@:6X@
M;W)D97(@=&\@:6YI=&EA;&EZ92!P;'5G:6YS('=I=&@@=&AE('-A;64*+R\@
M<&%R86UE=&5R<R!A<R!I;B!T:&4@;W!E;F5R('=I;F1O=RX*2%1-3$%R96$N
M<')O=&]T>7!E+G)E9VES=&5R4&QU9VEN,B`](&9U;F-T:6]N*'!L=6=I;BP@
M87)G<RD@>PH):68@*'1Y<&5O9B!P;'5G:6X@/3T@(G-T<FEN9R(I"@D)<&QU
M9VEN(#T@979A;"AP;'5G:6XI.PH):68@*'1Y<&5O9B!P;'5G:6X@/3T@(G5N
M9&5F:6YE9"(I('L*"0DO*B!&25A-13H@5&AI<R!S:&]U;&0@;F5V97(@:&%P
M<&5N+B!"=70@=VAY(&1O97,@:70@9&\_("HO"@D)<F5T=7)N(&9A;'-E.PH)
M?0H)=F%R(&]B:B`](&YE=R!P;'5G:6XH=&AI<RP@87)G<RD["@EI9B`H;V)J
M*2!["@D)=F%R(&-L;VYE(#T@>WT["@D)=F%R(&EN9F\@/2!P;'5G:6XN7W!L
M=6=I;DEN9F\["@D)9F]R("AV87(@:2!I;B!I;F9O*0H)"0EC;&]N95MI72`]
M(&EN9F];:5T["@D)8VQO;F4N:6YS=&%N8V4@/2!O8FH["@D)8VQO;F4N87)G
M<R`](&%R9W,["@D)=&AI<RYP;'5G:6YS6W!L=6=I;BY?<&QU9VEN26YF;RYN
M86UE72`](&-L;VYE.PH)?2!E;'-E"@D)86QE<G0H(D-A;B=T(')E9VES=&5R
M('!L=6=I;B`B("L@<&QU9VEN+G1O4W1R:6YG*"D@*R`B+B(I.PI].PH*+R\@
M<W1A=&EC(&9U;F-T:6]N('1H870@;&]A9',@=&AE(')E<75I<F5D('!L=6=I
M;B!A;F0@;&%N9R!F:6QE+"!B87-E9"!O;B!T:&4*+R\@;&%N9W5A9V4@;&]A
M9&5D(&%L<F5A9'D@9F]R($A434Q!<F5A+B`@66]U(&)E='1E<B!M86ME('-U
M<F4@=&AA="!T:&4@<&QU9VEN"B\O(%]H87-?('1H870@;&%N9W5A9V4L(&]T
M:&5R=VES92!S:&ET(&UI9VAT(&AA<'!E;B`[+2D*2%1-3$%R96$N9V5T4&QU
M9VEN1&ER(#T@9G5N8W1I;VXH<&QU9VEN3F%M92D@>PH)<F5T=7)N(%]E9&ET
M;W)?=7)L("L@(G!L=6=I;G,O(B`K('!L=6=I;DYA;64["GT["@I(5$U,07)E
M82YL;V%D4&QU9VEN(#T@9G5N8W1I;VXH<&QU9VEN3F%M92D@>PH)=F%R(&1I
M<B`]('1H:7,N9V5T4&QU9VEN1&ER*'!L=6=I;DYA;64I.PH)=F%R('!L=6=I
M;B`]('!L=6=I;DYA;64N<F5P;&%C92@O*%MA+7I=*2A;02U:72DH6V$M>ETI
M+V<L"@D)"0D)9G5N8W1I;VX@*'-T<BP@;#$L(&PR+"!L,RD@>PH)"0D)"0ER
M971U<FX@;#$@*R`B+2(@*R!L,BYT;TQO=V5R0V%S92@I("L@;#,["@D)"0D)
M?2DN=&],;W=E<D-A<V4H*2`K("(N:G,B.PH)=F%R('!L=6=I;E]F:6QE(#T@
M9&ER("L@(B\B("L@<&QU9VEN.PH)=F%R('!L=6=I;E]L86YG(#T@9&ER("L@
M(B]L86YG+R(@*R!?961I=&]R7VQA;F<@*R`B+FIS(CL*"2\O9&]C=6UE;G0N
M=W)I=&4H(CQS8W)I<'0@='EP93TG=&5X="]J879A<V-R:7!T)R!S<F,])R(@
M*R!P;'5G:6Y?9FEL92`K("(G/CPO<V-R:7!T/B(I.PH)+R]D;V-U;65N="YW
M<FET92@B/'-C<FEP="!T>7!E/2=T97AT+VIA=F%S8W)I<'0G('-R8STG(B`K
M('!L=6=I;E]L86YG("L@(B<^/"]S8W)I<'0^(BD["@ET:&ES+FQO86138W)I
M<'0H<&QU9VEN7V9I;&4I.PH)=&AI<RYL;V%D4V-R:7!T*'!L=6=I;E]L86YG
M*3L*?3L*"DA434Q!<F5A+FQO8613='EL92`](&9U;F-T:6]N*'-T>6QE+"!P
M;'5G:6XI('L*"79A<B!U<FP@/2!?961I=&]R7W5R;"!\?"`G)SL*"6EF("AT
M>7!E;V8@<&QU9VEN("$](")U;F1E9FEN960B*2!["@D)=7)L("L](")P;'5G
M:6YS+R(@*R!P;'5G:6X@*R`B+R(["@E]"@EU<FP@*ST@<W1Y;&4["@EI9B`H
M+UY<+R\N=&5S="AS='EL92DI"@D)=7)L(#T@<W1Y;&4["@EV87(@:&5A9"`]
M(&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE*")H96%D(BE;,%T["@EV
M87(@;&EN:R`](&1O8W5M96YT+F-R96%T945L96UE;G0H(FQI;FLB*3L*"6QI
M;FLN<F5L(#T@(G-T>6QE<VAE970B.PH);&EN:RYH<F5F(#T@=7)L.PH):&5A
M9"YA<'!E;F1#:&EL9"AL:6YK*3L*"2\O9&]C=6UE;G0N=W)I=&4H(CQS='EL
M92!T>7!E/2=T97AT+V-S<R<^0&EM<&]R="!U<FPH(B`K('5R;"`K("(I.SPO
M<W1Y;&4^(BD["GT["DA434Q!<F5A+FQO8613='EL92AT>7!E;V8@7V5D:71O
M<E]C<W,@/3T@(G-T<FEN9R(@/R!?961I=&]R7V-S<R`Z(")H=&UL87)E82YC
M<W,B*3L*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH*("H@($-A=&5G;W)Y.B!%1$E43U(@551)3$E42453
M"B`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHO"@I(5$U,07)E82YP<F]T;W1Y<&4N9&5B=6=4<F5E(#T@9G5N
M8W1I;VXH*2!["@EV87(@=&$@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")T
M97AT87)E82(I.PH)=&$N<W1Y;&4N=VED=&@@/2`B,3`P)2(["@ET82YS='EL
M92YH96EG:'0@/2`B,C!E;2(["@ET82YV86QU92`]("(B.PH)9G5N8W1I;VX@
M9&5B=6<H:6YD96YT+"!S='(I('L*"0EF;W(@*#L@+2UI;F1E;G0@/CT@,#LI
M"@D)"71A+G9A;'5E("L]("(@(CL*"0ET82YV86QU92`K/2!S='(@*R`B7&XB
M.PH)?3L*"69U;F-T:6]N(%]D="AR;V]T+"!L979E;"D@>PH)"79A<B!T86<@
M/2!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2P@:3L*"0EV87(@;G,@/2!(
M5$U,07)E82YI<U]I92`_(')O;W0N<V-O<&5.86UE(#H@<F]O="YP<F5F:7@[
M"@D)9&5B=6<H;&5V96PL("(M("(@*R!T86<@*R`B(%LB("L@;G,@*R`B72(I
M.PH)"69O<B`H:2`](')O;W0N9FER<W1#:&EL9#L@:3L@:2`](&DN;F5X=%-I
M8FQI;F<I"@D)"6EF("AI+FYO9&54>7!E(#T](#$I"@D)"0E?9'0H:2P@;&5V
M96P@*R`R*3L*"7T["@E?9'0H=&AI<RY?9&]C+F)O9'DL(#`I.PH)9&]C=6UE
M;G0N8F]D>2YA<'!E;F1#:&EL9"AT82D["GT["@I(5$U,07)E82YG971);FYE
M<E1E>'0@/2!F=6YC=&EO;BAE;"D@>PH)=F%R('1X="`]("<G+"!I.PH)9F]R
M("AI(#T@96PN9FER<W1#:&EL9#L@:3L@:2`](&DN;F5X=%-I8FQI;F<I('L*
M"0EI9B`H:2YN;V1E5'EP92`]/2`S*0H)"0ET>'0@*ST@:2YD871A.PH)"65L
M<V4@:68@*&DN;F]D951Y<&4@/3T@,2D*"0D)='AT("L]($A434Q!<F5A+F=E
M=$EN;F5R5&5X="AI*3L*"7T*"7)E='5R;B!T>'0["GT["@I(5$U,07)E82YP
M<F]T;W1Y<&4N7W=O<F1#;&5A;B`](&9U;F-T:6]N*"D@>PH)=F%R"@D)961I
M=&]R(#T@=&AI<RP*"0ES=&%T<R`]('L*"0D)96UP='E?=&%G<R`Z(#`L"@D)
M"6US;U]C;&%S<R`@.B`P+`H)"0EM<V]?<W1Y;&4@(#H@,"P*"0D);7-O7WAM
M;&5L("`Z(#`L"@D)"6]R:6=?;&5N("`@.B!T:&ES+E]D;V,N8F]D>2YI;FYE
M<DA434PN;&5N9W1H+`H)"0E4("`@("`@("`@(#H@*&YE=R!$871E*"DI+F=E
M=%1I;64H*0H)"7TL"@D)<W1A='-?='AT(#T@>PH)"0EE;7!T>5]T86=S(#H@
M(D5M<'1Y('1A9W,@<F5M;W9E9#H@(BP*"0D);7-O7V-L87-S("`Z(")-4T\@
M8VQA<W,@;F%M97,@<F5M;W9E9#H@(BP*"0D);7-O7W-T>6QE("`Z(")-4T\@
M:6YL:6YE('-T>6QE(')E;6]V960Z("(L"@D)"6US;U]X;6QE;"`@.B`B35-/
M(%A-3"!E;&5M96YT<R!S=')I<'!E9#H@(@H)"7T["@EF=6YC=&EO;B!S:&]W
M4W1A=',H*2!["@D)=F%R('1X="`](")(5$U,07)E82!W;W)D(&-L96%N97(@
M<W1A=',Z(%QN7&XB.PH)"69O<B`H=F%R(&D@:6X@<W1A=',I"@D)"6EF("AS
M=&%T<U]T>'1;:5TI"@D)"0ET>'0@*ST@<W1A='-?='AT6VE=("L@<W1A='-;
M:5T@*R`B7&XB.PH)"71X="`K/2`B7&Y);FET:6%L(&1O8W5M96YT(&QE;F=T
M:#H@(B`K('-T871S+F]R:6=?;&5N("L@(EQN(CL*"0ET>'0@*ST@(D9I;F%L
M(&1O8W5M96YT(&QE;F=T:#H@(B`K(&5D:71O<BY?9&]C+F)O9'DN:6YN97)(
M5$U,+FQE;F=T:"`K(")<;B(["@D)='AT("L](")#;&5A;BUU<"!T;V]K("(@
M*R`H*"AN97<@1&%T92@I*2YG9714:6UE*"D@+2!S=&%T<RY4*2`O(#$P,#`I
M("L@(B!S96-O;F1S(CL*"0EA;&5R="AT>'0I.PH)?3L*"69U;F-T:6]N(&-L
M96%R0VQA<W,H;F]D92D@>PH)"79A<B!N97=C(#T@;F]D92YC;&%S<TYA;64N
M<F5P;&%C92@O*%Y\7',I;7-O+BH_*%QS?"0I+VEG+"`G("<I.PH)"6EF("AN
M97=C("$](&YO9&4N8VQA<W-.86UE*2!["@D)"6YO9&4N8VQA<W-.86UE(#T@
M;F5W8SL*"0D):68@*"$O7%,O+G1E<W0H;F]D92YC;&%S<TYA;64I*2!["@D)
M"0EN;V1E+G)E;6]V94%T=')I8G5T92@B8VQA<W-.86UE(BD["@D)"0DK*W-T
M871S+FUS;U]C;&%S<SL*"0D)?0H)"7T*"7T["@EF=6YC=&EO;B!C;&5A<E-T
M>6QE*&YO9&4I('L*(`D)=F%R(&1E8VQA<F%T:6]N<R`](&YO9&4N<W1Y;&4N
M8W-S5&5X="YS<&QI="@O7',J.UQS*B\I.PH)"69O<B`H=F%R(&D@/2!D96-L
M87)A=&EO;G,N;&5N9W1H.R`M+6D@/CT@,#LI"@D)"6EF("@O7FUS;WQ>=&%B
M+7-T;W!S+VDN=&5S="AD96-L87)A=&EO;G-;:5TI('Q\"@D)"2`@("`O7FUA
M<F=I;EQS*CI<<RHP+BY<<RLP+BY<<RLP+BXO:2YT97-T*&1E8VQA<F%T:6]N
M<UMI72DI('L*"0D)"2LK<W1A=',N;7-O7W-T>6QE.PH)"0D)9&5C;&%R871I
M;VYS+G-P;&EC92AI+"`Q*3L*"0D)?0H)"6YO9&4N<W1Y;&4N8W-S5&5X="`]
M(&1E8VQA<F%T:6]N<RYJ;VEN*"([("(I.PH)?3L*"69U;F-T:6]N('-T<FEP
M5&%G*&5L*2!["@D):68@*$A434Q!<F5A+FES7VEE*0H)"0EE;"YO=71E<DA4
M34P@/2!(5$U,07)E82YH=&UL16YC;V1E*&5L+FEN;F5R5&5X="D["@D)96QS
M92!["@D)"79A<B!T>'0@/2!D;V-U;65N="YC<F5A=&5497AT3F]D92A(5$U,
M07)E82YG971);FYE<E1E>'0H96PI*3L*"0D)96PN<&%R96YT3F]D92YI;G-E
M<G1"969O<F4H='AT+"!E;"D["@D)"65L+G!A<F5N=$YO9&4N<F5M;W9E0VAI
M;&0H96PI.PH)"7T*"0DK*W-T871S+FUS;U]X;6QE;#L*"7T["@EF=6YC=&EO
M;B!C:&5C:T5M<'1Y*&5L*2!["@D):68@*"]>*&%\<W!A;GQB?'-T<F]N9WQI
M?&5M?&9O;G0I)"]I+G1E<W0H96PN=&%G3F%M92D@)B8*"0D@("`@(65L+F9I
M<G-T0VAI;&0I('L*"0D)96PN<&%R96YT3F]D92YR96UO=F5#:&EL9"AE;"D[
M"@D)"2LK<W1A=',N96UP='E?=&%G<SL*"0E]"@E].PH)9G5N8W1I;VX@<&%R
M<V54<F5E*')O;W0I('L*"0EV87(@=&%G(#T@<F]O="YT86=.86UE+G1O3&]W
M97)#87-E*"DL(&DL(&YE>'0["@D):68@*"A(5$U,07)E82YI<U]I92`F)B!R
M;V]T+G-C;W!E3F%M92`A/2`G2%1-3"<I('Q\("@A2%1-3$%R96$N:7-?:64@
M)B8@+SHO+G1E<W0H=&%G*2DI('L*"0D)<W1R:7!486<H<F]O="D["@D)"7)E
M='5R;B!F86QS93L*"0E](&5L<V4@>PH)"0EC;&5A<D-L87-S*')O;W0I.PH)
M"0EC;&5A<E-T>6QE*')O;W0I.PH)"0EF;W(@*&D@/2!R;V]T+F9I<G-T0VAI
M;&0[(&D[(&D@/2!N97AT*2!["@D)"0EN97AT(#T@:2YN97AT4VEB;&EN9SL*
M"0D)"6EF("AI+FYO9&54>7!E(#T](#$@)B8@<&%R<V54<F5E*&DI*0H)"0D)
M"6-H96-K16UP='DH:2D["@D)"7T*"0E]"@D)<F5T=7)N('1R=64["@E].PH)
M<&%R<V54<F5E*'1H:7,N7V1O8RYB;V1Y*3L*"2\O('-H;W=3=&%T<R@I.PH)
M+R\@=&AI<RYD96)U9U1R964H*3L*"2\O('1H:7,N<V5T2%1-3"AT:&ES+F=E
M=$A434PH*2D["@DO+R!T:&ES+G-E=$A434PH=&AI<RYG971);FYE<DA434PH
M*2D["@DO+R!T:&ES+F9O<F-E4F5D<F%W*"D["@ET:&ES+G5P9&%T951O;VQB
M87(H*3L*?3L*"DA434Q!<F5A+G!R;W1O='EP92YF;W)C95)E9')A=R`](&9U
M;F-T:6]N*"D@>PH)=&AI<RY?9&]C+F)O9'DN<W1Y;&4N=FES:6)I;&ET>2`]
M(")H:61D96XB.PH)=&AI<RY?9&]C+F)O9'DN<W1Y;&4N=FES:6)I;&ET>2`]
M(")V:7-I8FQE(CL*"2\O('1H:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3"`]('1H
M:7,N9V5T26YN97)(5$U,*"D["GT["@HO+R!F;V-U<V5S('1H92!I9G)A;64@
M=VEN9&]W+B`@<F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@961I=&]R(&1O
M8W5M96YT+@I(5$U,07)E82YP<F]T;W1Y<&4N9F]C=7-%9&ET;W(@/2!F=6YC
M=&EO;B@I('L*"7-W:71C:"`H=&AI<RY?961I=$UO9&4I('L*"2`@("`O+R!N
M;W1I8V4@=&AE('1R>2![("XN+B!](&-A=&-H(&)L;V-K('1O(&%V;VED('-O
M;64@<F%R92!E>&-E<'1I;VYS(&EN($9I<F5&;W@*"2`@("`O+R`H<&5R:&%P
M<R!A;'-O(&EN(&]T:&5R($=E8VMO(&)R;W=S97)S*2X@36%N=6%L(&9O8W5S
M(&)Y('5S97(@:7,@<F5Q=6ER960@:6X*("`@("`@("`O+R!C87-E(&]F(&%N
M(&5R<F]R+B!3;VUE8F]D>2!H87,@86X@:61E83\*"2`@("!C87-E(")W>7-I
M=WEG(B`Z('1R>2![('1H:7,N7VEF<F%M92YC;VYT96YT5VEN9&]W+F9O8W5S
M*"D@?2!C871C:"`H92D@>WT@8G)E86L["@D@("`@8V%S92`B=&5X=&UO9&4B
M.B!T<GD@>R!T:&ES+E]T97AT07)E82YF;V-U<R@I('T@8V%T8V@@*&4I('M]
M(&)R96%K.PH)("`@(&1E9F%U;'0)("`@.B!A;&5R="@B15)23U(Z(&UO9&4@
M(B`K('1H:7,N7V5D:71-;V1E("L@(B!I<R!N;W0@9&5F:6YE9"(I.PH)?0H)
M<F5T=7)N('1H:7,N7V1O8SL*?3L*"B\O('1A:V5S(&$@<VYA<'-H;W0@;V8@
M=&AE(&-U<G)E;G0@=&5X="`H9F]R('5N9&\I"DA434Q!<F5A+G!R;W1O='EP
M92Y?=6YD;U1A:V53;F%P<VAO="`](&9U;F-T:6]N*"D@>PH)*RMT:&ES+E]U
M;F1O4&]S.PH):68@*'1H:7,N7W5N9&]0;W,@/CT@=&AI<RYC;VYF:6<N=6YD
M;U-T97!S*2!["@D)+R\@<F5M;W9E('1H92!F:7)S="!E;&5M96YT"@D)=&AI
M<RY?=6YD;U%U975E+G-H:69T*"D["@D)+2UT:&ES+E]U;F1O4&]S.PH)?0H)
M+R\@=7-E('1H92!F87-T960@;65T:&]D("AG971);FYE<DA434PI.PH)=F%R
M('1A:V4@/2!T<G5E.PH)=F%R('1X="`]('1H:7,N9V5T26YN97)(5$U,*"D[
M"@EI9B`H=&AI<RY?=6YD;U!O<R`^(#`I"@D)=&%K92`]("AT:&ES+E]U;F1O
M475E=65;=&AI<RY?=6YD;U!O<R`M(#%=("$]('1X="D["@EI9B`H=&%K92D@
M>PH)"71H:7,N7W5N9&]1=65U95MT:&ES+E]U;F1O4&]S72`]('1X=#L*"7T@
M96QS92!["@D)=&AI<RY?=6YD;U!O<RTM.PH)?0I].PH*2%1-3$%R96$N<')O
M=&]T>7!E+G5N9&\@/2!F=6YC=&EO;B@I('L*"6EF("AT:&ES+E]U;F1O4&]S
M(#X@,"D@>PH)"79A<B!T>'0@/2!T:&ES+E]U;F1O475E=65;+2UT:&ES+E]U
M;F1O4&]S73L*"0EI9B`H='AT*2!T:&ES+G-E=$A434PH='AT*3L*"0EE;'-E
M("LK=&AI<RY?=6YD;U!O<SL*"7T*?3L*"DA434Q!<F5A+G!R;W1O='EP92YR
M961O(#T@9G5N8W1I;VXH*2!["@EI9B`H=&AI<RY?=6YD;U!O<R`\('1H:7,N
M7W5N9&]1=65U92YL96YG=&@@+2`Q*2!["@D)=F%R('1X="`]('1H:7,N7W5N
M9&]1=65U95LK*W1H:7,N7W5N9&]0;W-=.PH)"6EF("AT>'0I('1H:7,N<V5T
M2%1-3"AT>'0I.PH)"65L<V4@+2UT:&ES+E]U;F1O4&]S.PH)?0I].PH*+R\@
M=7!D871E<R!E;F%B;&5D+V1I<V%B;&4O86-T:79E('-T871E(&]F('1H92!T
M;V]L8F%R(&5L96UE;G1S"DA434Q!<F5A+G!R;W1O='EP92YU<&1A=&54;V]L
M8F%R(#T@9G5N8W1I;VXH;F]3=&%T=7,I('L*"79A<B!D;V,@/2!T:&ES+E]D
M;V,["@EV87(@=&5X="`]("AT:&ES+E]E9&ET36]D92`]/2`B=&5X=&UO9&4B
M*3L*"79A<B!A;F-E<W1O<G,@/2!N=6QL.PH):68@*"%T97AT*2!["@D)86YC
M97-T;W)S(#T@=&AI<RYG971!;&Q!;F-E<W1O<G,H*3L*"0EI9B`H=&AI<RYC
M;VYF:6<N<W1A='5S0F%R("8F("%N;U-T871U<RD@>PH)"0ET:&ES+E]S=&%T
M=7-"87)4<F5E+FEN;F5R2%1-3"`]($A434Q!<F5A+DDQ.$XN;7-G6R)0871H
M(ET@*R`B.B`B.R`O+R!C;&5A<@H)"0EF;W(@*'9A<B!I(#T@86YC97-T;W)S
M+FQE;F=T:#L@+2UI(#X](#`[*2!["@D)"0EV87(@96P@/2!A;F-E<W1O<G-;
M:5T["@D)"0EI9B`H(65L*2!["@D)"0D)+R\@:&5L;"!K;F]W<R!W:'D@=V4@
M9V5T(&AE<F4[('1H:7,*"0D)"0DO+R!C;W5L9"!B92!A(&-L87-S:6,@97AA
M;7!L92!O9B!W:'D*"0D)"0DO+R!I="=S(&=O;V0@=&\@8VAE8VL@9F]R(&-O
M;F1I=&EO;G,*"0D)"0DO+R!T:&%T(&%R92!I;7!O<W-I8FQE('1O(&AA<'!E
M;B`[+2D*"0D)"0EC;VYT:6YU93L*"0D)"7T*"0D)"79A<B!A(#T@9&]C=6UE
M;G0N8W)E871E16QE;65N="@B82(I.PH)"0D)82YH<F5F(#T@(B,B.PH)"0D)
M82YE;"`](&5L.PH)"0D)82YE9&ET;W(@/2!T:&ES.PH)"0D)82YO;F-L:6-K
M(#T@9G5N8W1I;VXH*2!["@D)"0D)=&AI<RYB;'5R*"D["@D)"0D)=&AI<RYE
M9&ET;W(N<V5L96-T3F]D94-O;G1E;G1S*'1H:7,N96PI.PH)"0D)"71H:7,N
M961I=&]R+G5P9&%T951O;VQB87(H=')U92D["@D)"0D)<F5T=7)N(&9A;'-E
M.PH)"0D)?3L*"0D)"6$N;VYC;VYT97AT;65N=2`](&9U;F-T:6]N*"D@>PH)
M"0D)"2\O(%1/1$\Z(&%D9"!C;VYT97AT(&UE;G4@:&5R90H)"0D)"71H:7,N
M8FQU<B@I.PH)"0D)"79A<B!I;F9O(#T@(DEN;&EN92!S='EL93I<;EQN(CL*
M"0D)"0EI;F9O("L]('1H:7,N96PN<W1Y;&4N8W-S5&5X="YS<&QI="@O.UQS
M*B\I+FIO:6XH(CM<;B(I.PH)"0D)"6%L97)T*&EN9F\I.PH)"0D)"7)E='5R
M;B!F86QS93L*"0D)"7T["@D)"0EV87(@='AT(#T@96PN=&%G3F%M92YT;TQO
M=V5R0V%S92@I.PH)"0D)82YT:71L92`](&5L+G-T>6QE+F-S<U1E>'0["@D)
M"0EI9B`H96PN:60I('L*"0D)"0ET>'0@*ST@(B,B("L@96PN:60["@D)"0E]
M"@D)"0EI9B`H96PN8VQA<W-.86UE*2!["@D)"0D)='AT("L]("(N(B`K(&5L
M+F-L87-S3F%M93L*"0D)"7T*"0D)"6$N87!P96YD0VAI;&0H9&]C=6UE;G0N
M8W)E871E5&5X=$YO9&4H='AT*2D["@D)"0ET:&ES+E]S=&%T=7-"87)4<F5E
M+F%P<&5N9$-H:6QD*&$I.PH)"0D):68@*&D@(3T@,"D@>PH)"0D)"71H:7,N
M7W-T871U<T)A<E1R964N87!P96YD0VAI;&0H9&]C=6UE;G0N8W)E871E5&5X
M=$YO9&4H4W1R:6YG+F9R;VU#:&%R0V]D92@P>&)B*2DI.PH)"0D)?0H)"0E]
M"@D)?0H)?0H*"69O<B`H=F%R(&D@:6X@=&AI<RY?=&]O;&)A<D]B:F5C=',I
M('L*"0EV87(@8G1N(#T@=&AI<RY?=&]O;&)A<D]B:F5C='-;:5T["@D)=F%R
M(&-M9"`](&D["@D)=F%R(&EN0V]N=&5X="`]('1R=64["@D):68@*&)T;BYC
M;VYT97AT("8F("%T97AT*2!["@D)"6EN0V]N=&5X="`](&9A;'-E.PH)"0EV
M87(@8V]N=&5X="`](&)T;BYC;VYT97AT.PH)"0EV87(@871T<G,@/2!;73L*
M"0D):68@*"\H+BHI7%LH+BH_*5Q=+RYT97-T*&-O;G1E>'0I*2!["@D)"0EC
M;VYT97AT(#T@4F5G17AP+B0Q.PH)"0D)871T<G,@/2!296=%>'`N)#(N<W!L
M:70H(BPB*3L*"0D)?0H)"0EC;VYT97AT(#T@8V]N=&5X="YT;TQO=V5R0V%S
M92@I.PH)"0EV87(@;6%T8V@@/2`H8V]N=&5X="`]/2`B*B(I.PH)"0EF;W(@
M*'9A<B!K(#T@,#L@:R`\(&%N8V5S=&]R<RYL96YG=&@[("LK:RD@>PH)"0D)
M:68@*"%A;F-E<W1O<G-;:UTI('L*"0D)"0DO+R!T:&4@:6UP;W-S:6)L92!R
M96%L;'D@:&%P<&5N<RX*"0D)"0EC;VYT:6YU93L*"0D)"7T*"0D)"6EF("AM
M871C:"!\?"`H86YC97-T;W)S6VM=+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]
M/2!C;VYT97AT*2D@>PH)"0D)"6EN0V]N=&5X="`]('1R=64["@D)"0D)9F]R
M("AV87(@:V$@/2`P.R!K82`\(&%T=')S+FQE;F=T:#L@*RMK82D@>PH)"0D)
M"0EI9B`H(65V86PH(F%N8V5S=&]R<UMK72XB("L@871T<G-;:V%=*2D@>PH)
M"0D)"0D):6Y#;VYT97AT(#T@9F%L<V4["@D)"0D)"0EB<F5A:SL*"0D)"0D)
M?0H)"0D)"7T*"0D)"0EI9B`H:6Y#;VYT97AT*2!["@D)"0D)"6)R96%K.PH)
M"0D)"7T*"0D)"7T*"0D)?0H)"7T*"0EB=&XN<W1A=&4H(F5N86)L960B+"`H
M(71E>'0@?'P@8G1N+G1E>'0I("8F(&EN0V]N=&5X="D["@D):68@*'1Y<&5O
M9B!C;60@/3T@(F9U;F-T:6]N(BD@>PH)"0EC;VYT:6YU93L*"0E]"@D)+R\@
M;&]O:RUI="UU<"!I;B!T:&4@8W5S=&]M(&1R;W!D;W=N(&)O>&5S"@D)=F%R
M(&1R;W!D;W=N(#T@=&AI<RYC;VYF:6<N8W5S=&]M4V5L96-T<UMC;61=.PH)
M"6EF("@H(71E>'0@?'P@8G1N+G1E>'0I("8F("AT>7!E;V8@9')O<&1O=VX@
M(3T@(G5N9&5F:6YE9"(I*2!["@D)"61R;W!D;W=N+G)E9G)E<V@H=&AI<RD[
M"@D)"6-O;G1I;G5E.PH)"7T*"0ES=VET8V@@*&-M9"D@>PH)"2`@("!C87-E
M(")F;VYT;F%M92(Z"@D)("`@(&-A<V4@(F9O;G1S:7IE(CH*"0D@("`@8V%S
M92`B9F]R;6%T8FQO8VLB.@H)"0EI9B`H(71E>'0I('1R>2!["@D)"0EV87(@
M=F%L=64@/2`H(B(@*R!D;V,N<75E<GE#;VUM86YD5F%L=64H8VUD*2DN=&],
M;W=E<D-A<V4H*3L*"0D)"6EF("@A=F%L=64I('L*"0D)"0EB=&XN96QE;65N
M="YS96QE8W1E9$EN9&5X(#T@,#L*"0D)"0EB<F5A:SL*"0D)"7T*"0D)"2\O
M($A!0TL@+2T@<F5T<FEE=F4@=&AE(&-O;F9I9R!O<'1I;VX@9F]R('1H:7,*
M"0D)"2\O(&-O;6)O(&)O>"X@(%=E(')E;'D@;VX@=&AE(&9A8W0@=&AA="!T
M:&4*"0D)"2\O('9A<FEA8FQE(&EN(&-O;F9I9R!H87,@=&AE('-A;64@;F%M
M92!A<PH)"0D)+R\@8G5T=&]N(&YA;64@:6X@=&AE('1O;VQB87(N"@D)"0EV
M87(@;W!T:6]N<R`]('1H:7,N8V]N9FEG6V-M9%T["@D)"0EV87(@:R`](#`[
M"@D)"0EF;W(@*'9A<B!J(&EN(&]P=&EO;G,I('L*"0D)"0DO+R!&25A-13H@
M=&AE(&9O;&QO=VEN9R!L:6YE(&ES('-C87)Y+@H)"0D)"6EF("@H:BYT;TQO
M=V5R0V%S92@I(#T]('9A;'5E*2!\?`H)"0D)"2`@("`H;W!T:6]N<UMJ72YS
M=6)S='(H,"P@=F%L=64N;&5N9W1H*2YT;TQO=V5R0V%S92@I(#T]('9A;'5E
M*2D@>PH)"0D)"0EB=&XN96QE;65N="YS96QE8W1E9$EN9&5X(#T@:SL*"0D)
M"0D)=&AR;W<@(F]K(CL*"0D)"0E]"@D)"0D)*RMK.PH)"0D)?0H)"0D)8G1N
M+F5L96UE;G0N<V5L96-T961);F1E>"`](#`["@D)"7T@8V%T8V@H92D@>WT[
M"@D)"6)R96%K.PH)"2`@("!C87-E(")T97AT:6YD:6-A=&]R(CH*"0D):68@
M*"%T97AT*2!["@D)"0ET<GD@>W=I=&@@*&)T;BYE;&5M96YT+G-T>6QE*2![
M"@D)"0D)8F%C:V=R;W5N9$-O;&]R(#T@2%1-3$%R96$N7VUA:V5#;VQO<B@*
M"0D)"0D)9&]C+G%U97)Y0V]M;6%N9%9A;'5E*$A434Q!<F5A+FES7VEE(#\@
M(F)A8VMC;VQO<B(@.B`B:&EL:71E8V]L;W(B*2D["@D)"0D):68@*"]T<F%N
M<W!A<F5N="]I+G1E<W0H8F%C:V=R;W5N9$-O;&]R*2D@>PH)"0D)"0DO+R!-
M;WII;&QA"@D)"0D)"6)A8VMG<F]U;F1#;VQO<B`]($A434Q!<F5A+E]M86ME
M0V]L;W(H9&]C+G%U97)Y0V]M;6%N9%9A;'5E*")B86-K8V]L;W(B*2D["@D)
M"0D)?0H)"0D)"6-O;&]R(#T@2%1-3$%R96$N7VUA:V5#;VQO<BAD;V,N<75E
M<GE#;VUM86YD5F%L=64H(F9O<F5C;VQO<B(I*3L*"0D)"0EF;VYT1F%M:6QY
M(#T@9&]C+G%U97)Y0V]M;6%N9%9A;'5E*")F;VYT;F%M92(I.PH)"0D)"69O
M;G1796EG:'0@/2!D;V,N<75E<GE#;VUM86YD4W1A=&4H(F)O;&0B*2`_(")B
M;VQD(B`Z(")N;W)M86PB.PH)"0D)"69O;G13='EL92`](&1O8RYQ=65R>4-O
M;6UA;F13=&%T92@B:71A;&EC(BD@/R`B:71A;&EC(B`Z(")N;W)M86PB.PH)
M"0D)?7T@8V%T8V@@*&4I('L*"0D)"0DO+R!A;&5R="AE("L@(EQN7&XB("L@
M8VUD*3L*"0D)"7T*"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`B:'1M;&UO
M9&4B.B!B=&XN<W1A=&4H(F%C=&EV92(L('1E>'0I.R!B<F5A:SL*"0D@("`@
M8V%S92`B;&5F='1O<FEG:'0B.@H)"2`@("!C87-E(")R:6=H='1O;&5F="(Z
M"@D)"79A<B!E;"`]('1H:7,N9V5T4&%R96YT16QE;65N="@I.PH)"0EW:&EL
M92`H96P@)B8@(4A434Q!<F5A+FES0FQO8VM%;&5M96YT*&5L*2D*"0D)"65L
M(#T@96PN<&%R96YT3F]D93L*"0D):68@*&5L*0H)"0D)8G1N+G-T871E*")A
M8W1I=F4B+"`H96PN<W1Y;&4N9&ER96-T:6]N(#T]("@H8VUD(#T](")R:6=H
M='1O;&5F="(I(#\@(G)T;"(@.B`B;'1R(BDI*3L*"0D)8G)E86L["@D)("`@
M(&1E9F%U;'0Z"@D)"6-M9"`](&-M9"YR97!L86-E*"\H=6XI/V]R9&5R961L
M:7-T+VDL(")I;G-E<G0D,6]R9&5R961L:7-T(BD["@D)"71R>2!["@D)"0EB
M=&XN<W1A=&4H(F%C=&EV92(L("@A=&5X="`F)B!D;V,N<75E<GE#;VUM86YD
M4W1A=&4H8VUD*2DI.PH)"0E](&-A=&-H("AE*2![?0H)"7T*"7T*"2\O('1A
M:V4@=6YD;R!S;F%P<VAO=',*"6EF("AT:&ES+E]C=7-T;VU5;F1O("8F("%T
M:&ES+E]T:6UE<E5N9&\I('L*"0ET:&ES+E]U;F1O5&%K95-N87!S:&]T*"D[
M"@D)=F%R(&5D:71O<B`]('1H:7,["@D)=&AI<RY?=&EM97)5;F1O(#T@<V5T
M5&EM96]U="AF=6YC=&EO;B@I('L*"0D)961I=&]R+E]T:6UE<E5N9&\@/2!N
M=6QL.PH)"7TL('1H:7,N8V]N9FEG+G5N9&]4:6UE;W5T*3L*"7T*"@DO+R!C
M:&5C:R!I9B!A;GD@<&QU9VEN<R!H879E(')E9VES=&5R960@<F5F<F5S:"!H
M86YD;&5R<PH)9F]R("AV87(@:2!I;B!T:&ES+G!L=6=I;G,I('L*"0EV87(@
M<&QU9VEN(#T@=&AI<RYP;'5G:6YS6VE=+FEN<W1A;F-E.PH)"6EF("AT>7!E
M;V8@<&QU9VEN+F]N57!D871E5&]O;&)A<B`]/2`B9G5N8W1I;VXB*0H)"0EP
M;'5G:6XN;VY5<&1A=&54;V]L8F%R*"D["@E]"GT["@HO*BH@4F5T=7)N<R!A
M(&YO9&4@869T97(@=VAI8V@@=V4@8V%N(&EN<V5R="!O=&AE<B!N;V1E<RP@
M:6X@=&AE(&-U<G)E;G0*("H@<V5L96-T:6]N+B`@5&AE('-E;&5C=&EO;B!I
M<R!R96UO=F5D+B`@270@<W!L:71S(&$@=&5X="!N;V1E+"!I9B!N965D960N
M"B`J+PI(5$U,07)E82YP<F]T;W1Y<&4N:6YS97)T3F]D94%T4V5L96-T:6]N
M(#T@9G5N8W1I;VXH=&]"94EN<V5R=&5D*2!["@EI9B`H(4A434Q!<F5A+FES
M7VEE*2!["@D)=F%R('-E;"`]('1H:7,N7V=E=%-E;&5C=&EO;B@I.PH)"79A
M<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@D)+R\@<F5M;W9E
M('1H92!C=7)R96YT('-E;&5C=&EO;@H)"7-E;"YR96UO=F5!;&Q286YG97,H
M*3L*"0ER86YG92YD96QE=&5#;VYT96YT<R@I.PH)"79A<B!N;V1E(#T@<F%N
M9V4N<W1A<G1#;VYT86EN97(["@D)=F%R('!O<R`](')A;F=E+G-T87)T3V9F
M<V5T.PH)"7-W:71C:"`H;F]D92YN;V1E5'EP92D@>PH)"2`@("!C87-E(#,Z
M("\O($YO9&4N5$585%].3T1%"@D)"2\O('=E(&AA=F4@=&\@<W!L:70@:70@
M870@=&AE(&-A<F5T('!O<VET:6]N+@H)"0EI9B`H=&]"94EN<V5R=&5D+FYO
M9&54>7!E(#T](#,I('L*"0D)"2\O(&1O(&]P=&EM:7IE9"!I;G-E<G1I;VX*
M"0D)"6YO9&4N:6YS97)T1&%T82AP;W,L('1O0F5);G-E<G1E9"YD871A*3L*
M"0D)"7)A;F=E(#T@=&AI<RY?8W)E871E4F%N9V4H*3L*"0D)"7)A;F=E+G-E
M=$5N9"AN;V1E+"!P;W,@*R!T;T)E26YS97)T960N;&5N9W1H*3L*"0D)"7)A
M;F=E+G-E=%-T87)T*&YO9&4L('!O<R`K('1O0F5);G-E<G1E9"YL96YG=&@I
M.PH)"0D)<V5L+F%D9%)A;F=E*')A;F=E*3L*"0D)?2!E;'-E('L*"0D)"6YO
M9&4@/2!N;V1E+G-P;&ET5&5X="AP;W,I.PH)"0D)=F%R('-E;&YO9&4@/2!T
M;T)E26YS97)T960["@D)"0EI9B`H=&]"94EN<V5R=&5D+FYO9&54>7!E(#T]
M(#$Q("\J($YO9&4N1$]#54U%3E1?1E)!1TU%3E1?3D]$12`J+RD@>PH)"0D)
M"7-E;&YO9&4@/2!S96QN;V1E+F9I<G-T0VAI;&0["@D)"0E]"@D)"0EN;V1E
M+G!A<F5N=$YO9&4N:6YS97)T0F5F;W)E*'1O0F5);G-E<G1E9"P@;F]D92D[
M"@D)"0ET:&ES+G-E;&5C=$YO9&5#;VYT96YT<RAS96QN;V1E*3L*"0D)"71H
M:7,N=7!D871E5&]O;&)A<B@I.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E
M(#$Z("\O($YO9&4N14Q%345.5%].3T1%"@D)"79A<B!S96QN;V1E(#T@=&]"
M94EN<V5R=&5D.PH)"0EI9B`H=&]"94EN<V5R=&5D+FYO9&54>7!E(#T](#$Q
M("\J($YO9&4N1$]#54U%3E1?1E)!1TU%3E1?3D]$12`J+RD@>PH)"0D)<V5L
M;F]D92`]('-E;&YO9&4N9FER<W1#:&EL9#L*"0D)?0H)"0EN;V1E+FEN<V5R
M=$)E9F]R92AT;T)E26YS97)T960L(&YO9&4N8VAI;&1.;V1E<UMP;W-=*3L*
M"0D)=&AI<RYS96QE8W1.;V1E0V]N=&5N=',H<V5L;F]D92D["@D)"71H:7,N
M=7!D871E5&]O;&)A<B@I.PH)"0EB<F5A:SL*"0E]"@E](&5L<V4@>PH)"7)E
M='5R;B!N=6QL.PDO+R!T:&ES(&9U;F-T:6]N(&YO="!Y970@=7-E9"!F;W(@
M244@/$9)6$U%/@H)?0I].PH*+R\@4F5T=7)N<R!T:&4@9&5E<&5S="!N;V1E
M('1H870@8V]N=&%I;G,@8F]T:"!E;F1P;VEN=',@;V8@=&AE('-E;&5C=&EO
M;BX*2%1-3$%R96$N<')O=&]T>7!E+F=E=%!A<F5N=$5L96UE;G0@/2!F=6YC
M=&EO;B@I('L*"79A<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*"79A
M<B!R86YG92`]('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@EI9B`H2%1-3$%R
M96$N:7-?:64I('L*"0ES=VET8V@@*'-E;"YT>7!E*2!["@D)("`@(&-A<V4@
M(E1E>'0B.@H)"2`@("!C87-E(").;VYE(CH*"0D)+R\@270@<V5E;7,@=&AA
M="!E=F5N(&9O<B!S96QE8W1I;VX@;V8@='EP92`B3F]N92(L"@D)"2\O('1H
M97)E(%]I<U\@82!P87)E;G0@96QE;65N="!A;F0@:70G<R!V86QU92!I<R!N
M;W0*"0D)+R\@;VYL>2!C;W)R96-T+"!B=70@=F5R>2!I;7!O<G1A;G0@=&\@
M=7,N("!-4TE%(&ES"@D)"2\O(&-E<G1A:6YL>2!T:&4@8G5G9VEE<W0@8G)O
M=W-E<B!I;B!T:&4@=V]R;&0@86YD($D*"0D)+R\@=V]N9&5R+"!';V0L(&AO
M=R!C86X@16%R=&@@<W1A;F0@:70_"@D)"7)E='5R;B!R86YG92YP87)E;G1%
M;&5M96YT*"D["@D)("`@(&-A<V4@(D-O;G1R;VPB.@H)"0ER971U<FX@<F%N
M9V4N:71E;2@P*3L*"0D@("`@9&5F875L=#H*"0D)<F5T=7)N('1H:7,N7V1O
M8RYB;V1Y.PH)"7T*"7T@96QS92!T<GD@>PH)"79A<B!P(#T@<F%N9V4N8V]M
M;6]N06YC97-T;W)#;VYT86EN97(["@D):68@*"%R86YG92YC;VQL87!S960@
M)B8@<F%N9V4N<W1A<G1#;VYT86EN97(@/3T@<F%N9V4N96YD0V]N=&%I;F5R
M("8F"@D)("`@(')A;F=E+G-T87)T3V9F<V5T("T@<F%N9V4N96YD3V9F<V5T
M(#P](#$@)B8@<F%N9V4N<W1A<G1#;VYT86EN97(N:&%S0VAI;&1.;V1E<R@I
M*0H)"0EP(#T@<F%N9V4N<W1A<G1#;VYT86EN97(N8VAI;&1.;V1E<UMR86YG
M92YS=&%R=$]F9G-E=%T["@D)+RH*"0EA;&5R="AR86YG92YS=&%R=$-O;G1A
M:6YE<B`K("(Z(B`K(')A;F=E+G-T87)T3V9F<V5T("L@(EQN(B`K"@D)("`@
M("`@<F%N9V4N96YD0V]N=&%I;F5R("L@(CHB("L@<F%N9V4N96YD3V9F<V5T
M*3L*"0DJ+PH)"7=H:6QE("AP+FYO9&54>7!E(#T](#,I('L*"0D)<"`]('`N
M<&%R96YT3F]D93L*"0E]"@D)<F5T=7)N('`["@E](&-A=&-H("AE*2!["@D)
M<F5T=7)N(&YU;&P["@E]"GT["@HO+R!2971U<FYS(&%N(&%R<F%Y('=I=&@@
M86QL('1H92!A;F-E<W1O<B!N;V1E<R!O9B!T:&4@<V5L96-T:6]N+@I(5$U,
M07)E82YP<F]T;W1Y<&4N9V5T06QL06YC97-T;W)S(#T@9G5N8W1I;VXH*2![
M"@EV87(@<"`]('1H:7,N9V5T4&%R96YT16QE;65N="@I.PH)=F%R(&$@/2!;
M73L*"7=H:6QE("AP("8F("AP+FYO9&54>7!E(#T](#$I("8F("AP+G1A9TYA
M;64N=&],;W=E<D-A<V4H*2`A/2`G8F]D>2<I*2!["@D)82YP=7-H*'`I.PH)
M"7`@/2!P+G!A<F5N=$YO9&4["@E]"@EA+G!U<V@H=&AI<RY?9&]C+F)O9'DI
M.PH)<F5T=7)N(&$["GT["@HO+R!396QE8W1S('1H92!C;VYT96YT<R!I;G-I
M9&4@=&AE(&=I=F5N(&YO9&4*2%1-3$%R96$N<')O=&]T>7!E+G-E;&5C=$YO
M9&5#;VYT96YT<R`](&9U;F-T:6]N*&YO9&4L('!O<RD@>PH)=&AI<RYF;V-U
M<T5D:71O<B@I.PH)=&AI<RYF;W)C95)E9')A=R@I.PH)=F%R(')A;F=E.PH)
M=F%R(&-O;&QA<'-E9"`]("AT>7!E;V8@<&]S("$](")U;F1E9FEN960B*3L*
M"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)A;F=E(#T@=&AI<RY?9&]C+F)O
M9'DN8W)E871E5&5X=%)A;F=E*"D["@D)<F%N9V4N;6]V951O16QE;65N=%1E
M>'0H;F]D92D["@D)*&-O;&QA<'-E9"D@)B8@<F%N9V4N8V]L;&%P<V4H<&]S
M*3L*"0ER86YG92YS96QE8W0H*3L*"7T@96QS92!["@D)=F%R('-E;"`]('1H
M:7,N7V=E=%-E;&5C=&EO;B@I.PH)"7)A;F=E(#T@=&AI<RY?9&]C+F-R96%T
M95)A;F=E*"D["@D)<F%N9V4N<V5L96-T3F]D94-O;G1E;G1S*&YO9&4I.PH)
M"2AC;VQL87!S960I("8F(')A;F=E+F-O;&QA<'-E*'!O<RD["@D)<V5L+G)E
M;6]V94%L;%)A;F=E<R@I.PH)"7-E;"YA9&1286YG92AR86YG92D["@E]"GT[
M"@HO*BH@0V%L;"!T:&ES(&9U;F-T:6]N('1O(&EN<V5R="!(5$U,(&-O9&4@
M870@=&AE(&-U<G)E;G0@<&]S:71I;VXN("!)="!D96QE=&5S"B`J('1H92!S
M96QE8W1I;VXL(&EF(&%N>2X*("HO"DA434Q!<F5A+G!R;W1O='EP92YI;G-E
M<G1(5$U,(#T@9G5N8W1I;VXH:'1M;"D@>PH)=F%R('-E;"`]('1H:7,N7V=E
M=%-E;&5C=&EO;B@I.PH)=F%R(')A;F=E(#T@=&AI<RY?8W)E871E4F%N9V4H
M<V5L*3L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)A;F=E+G!A<W1E2%1-
M3"AH=&UL*3L*"7T@96QS92!["@D)+R\@8V]N<W1R=6-T(&$@;F5W(&1O8W5M
M96YT(&9R86=M96YT('=I=&@@=&AE(&=I=F5N($A434P*"0EV87(@9G)A9VUE
M;G0@/2!T:&ES+E]D;V,N8W)E871E1&]C=6UE;G1&<F%G;65N="@I.PH)"79A
M<B!D:78@/2!T:&ES+E]D;V,N8W)E871E16QE;65N="@B9&EV(BD["@D)9&EV
M+FEN;F5R2%1-3"`](&AT;6P["@D)=VAI;&4@*&1I=BYF:7)S=$-H:6QD*2![
M"@D)"2\O('1H92!F;VQL;W=I;F<@8V%L;"!A;'-O(')E;6]V97,@=&AE(&YO
M9&4@9G)O;2!D:78*"0D)9G)A9VUE;G0N87!P96YD0VAI;&0H9&EV+F9I<G-T
M0VAI;&0I.PH)"7T*"0DO+R!T:&ES(&%L<V\@<F5M;W9E<R!T:&4@<V5L96-T
M:6]N"@D)=F%R(&YO9&4@/2!T:&ES+FEN<V5R=$YO9&5!=%-E;&5C=&EO;BAF
M<F%G;65N="D["@E]"GT["@HO*BH*("H@($-A;&P@=&AI<R!F=6YC=&EO;B!T
M;R!S=7)R;W5N9"!T:&4@97AI<W1I;F<@2%1-3"!C;V1E(&EN('1H92!S96QE
M8W1I;VX@=VET:`H@*B`@>6]U<B!T86=S+B`@1DE8344Z(&)U9V=Y(2`@5&AI
M<R!F=6YC=&EO;B!W:6QL(&)E(&1E<')E8V%T960@(G-O;VXB+@H@*B\*2%1-
M3$%R96$N<')O=&]T>7!E+G-U<G)O=6YD2%1-3"`](&9U;F-T:6]N*'-T87)T
M5&%G+"!E;F1486<I('L*"79A<B!H=&UL(#T@=&AI<RYG971396QE8W1E9$A4
M34PH*3L*"2\O('1H92!F;VQL;W=I;F<@86QS;R!D96QE=&5S('1H92!S96QE
M8W1I;VX*"71H:7,N:6YS97)T2%1-3"AS=&%R=%1A9R`K(&AT;6P@*R!E;F14
M86<I.PI].PH*+R\O(%)E=')I979E('1H92!S96QE8W1E9"!B;&]C:PI(5$U,
M07)E82YP<F]T;W1Y<&4N9V5T4V5L96-T961(5$U,(#T@9G5N8W1I;VXH*2![
M"@EV87(@<V5L(#T@=&AI<RY?9V5T4V5L96-T:6]N*"D["@EV87(@<F%N9V4@
M/2!T:&ES+E]C<F5A=&5286YG92AS96PI.PH)=F%R(&5X:7-T:6YG(#T@;G5L
M;#L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"65X:7-T:6YG(#T@<F%N9V4N
M:'1M;%1E>'0["@E](&5L<V4@>PH)"65X:7-T:6YG(#T@2%1-3$%R96$N9V5T
M2%1-3"AR86YG92YC;&]N94-O;G1E;G1S*"DL(&9A;'-E+"!T:&ES*3L*"7T*
M"7)E='5R;B!E>&ES=&EN9SL*?3L*"B\O+R!2971U<FX@=')U92!I9B!W92!H
M879E('-O;64@<V5L96-T:6]N"DA434Q!<F5A+G!R;W1O='EP92YH87-396QE
M8W1E9%1E>'0@/2!F=6YC=&EO;B@I('L*"2\O($9)6$U%.B!C;VUE(%]O;E\@
M;6ES:&]O+"!Y;W4@8V%N(&1O(&)E='1E<B!T:&%N('1H:7,@.RTI"@ER971U
M<FX@=&AI<RYG971396QE8W1E9$A434PH*2`A/2`G)SL*?3L*"DA434Q!<F5A
M+G!R;W1O='EP92Y?8W)E871E3&EN:R`](&9U;F-T:6]N*&QI;FLI('L*"79A
M<B!E9&ET;W(@/2!T:&ES.PH)=F%R(&]U='!A<F%M(#T@;G5L;#L*"6EF("AT
M>7!E;V8@;&EN:R`]/2`B=6YD969I;F5D(BD@>PH)"6QI;FL@/2!T:&ES+F=E
M=%!A<F5N=$5L96UE;G0H*3L*"0EI9B`H;&EN:RD@>PH)"0EI9B`H+UYI;6<D
M+VDN=&5S="AL:6YK+G1A9TYA;64I*0H)"0D);&EN:R`](&QI;FLN<&%R96YT
M3F]D93L*"0D):68@*"$O7F$D+VDN=&5S="AL:6YK+G1A9TYA;64I*0H)"0D)
M;&EN:R`](&YU;&P["@D)?0H)?0H):68@*"%L:6YK*2!["@D)=F%R('-E;"`]
M(&5D:71O<BY?9V5T4V5L96-T:6]N*"D["@D)=F%R(')A;F=E(#T@961I=&]R
M+E]C<F5A=&5286YG92AS96PI.PH)"79A<B!C;VUP87)E(#T@,#L*"0EI9B`H
M2%1-3$%R96$N:7-?:64I('L*"0D)8V]M<&%R92`](')A;F=E+F-O;7!A<F5%
M;F10;VEN=',H(E-T87)T5&]%;F0B+"!R86YG92D["@D)?2!E;'-E('L*"0D)
M8V]M<&%R92`](')A;F=E+F-O;7!A<F5";W5N9&%R>5!O:6YT<RAR86YG92Y3
M5$%25%]43U]%3D0L(')A;F=E*3L*"0E]"@D):68@*&-O;7!A<F4@/3T@,"D@
M>PH)"0EA;&5R="@B66]U(&YE960@=&\@<V5L96-T('-O;64@=&5X="!B969O
M<F4@8W)E871I;F<@82!L:6YK(BD["@D)"7)E='5R;CL*"0E]"@D);W5T<&%R
M86T@/2!["@D)"69?:')E9B`Z("<G+`H)"0EF7W1I=&QE(#H@)R<L"@D)"69?
M=&%R9V5T(#H@)R<L"@D)"69?=7-E=&%R9V5T(#H@961I=&]R+F-O;F9I9RYM
M86ME3&EN:U-H;W=S5&%R9V5T"@D)?3L*"7T@96QS90H)"6]U='!A<F%M(#T@
M>PH)"0EF7VAR968@("`Z($A434Q!<F5A+FES7VEE(#\@961I=&]R+G-T<FEP
M0F%S95523"AL:6YK+FAR968I(#H@;&EN:RYG971!='1R:6)U=&4H(FAR968B
M*2P*"0D)9E]T:71L92`@.B!L:6YK+G1I=&QE+`H)"0EF7W1A<F=E="`Z(&QI
M;FLN=&%R9V5T+`H)"0EF7W5S971A<F=E="`Z(&5D:71O<BYC;VYF:6<N;6%K
M94QI;FM3:&]W<U1A<F=E=`H)"7T["@ET:&ES+E]P;W!U<$1I86QO9R@B;&EN
M:RYH=&UL(BP@9G5N8W1I;VXH<&%R86TI('L*"0EI9B`H(7!A<F%M*0H)"0ER
M971U<FX@9F%L<V4["@D)=F%R(&$@/2!L:6YK.PH)"6EF("@A82D@=')Y('L*
M"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!F86QS
M92P@<&%R86TN9E]H<F5F*3L*"0D)82`](&5D:71O<BYG971087)E;G1%;&5M
M96YT*"D["@D)"79A<B!S96P@/2!E9&ET;W(N7V=E=%-E;&5C=&EO;B@I.PH)
M"0EV87(@<F%N9V4@/2!E9&ET;W(N7V-R96%T95)A;F=E*'-E;"D["@D)"6EF
M("@A2%1-3$%R96$N:7-?:64I('L*"0D)"6$@/2!R86YG92YS=&%R=$-O;G1A
M:6YE<CL*"0D)"6EF("@A+UYA)"]I+G1E<W0H82YT86=.86UE*2D@>PH)"0D)
M"6$@/2!A+FYE>'13:6)L:6YG.PH)"0D)"6EF("AA(#T](&YU;&PI"@D)"0D)
M"6$@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYP87)E;G1.;V1E.PH)"0D)?0H)
M"0E]"@D)?2!C871C:"AE*2![?0H)"65L<V4@>PH)"0EV87(@:')E9B`]('!A
M<F%M+F9?:')E9BYT<FEM*"D["@D)"65D:71O<BYS96QE8W1.;V1E0V]N=&5N
M=',H82D["@D)"6EF("AH<F5F(#T]("(B*2!["@D)"0EE9&ET;W(N7V1O8RYE
M>&5C0V]M;6%N9"@B=6YL:6YK(BP@9F%L<V4L(&YU;&PI.PH)"0D)961I=&]R
M+G5P9&%T951O;VQB87(H*3L*"0D)"7)E='5R;B!F86QS93L*"0D)?0H)"0EE
M;'-E('L*"0D)"6$N:')E9B`](&AR968["@D)"7T*"0E]"@D):68@*"$H82`F
M)B`O7F$D+VDN=&5S="AA+G1A9TYA;64I*2D*"0D)<F5T=7)N(&9A;'-E.PH)
M"6$N=&%R9V5T(#T@<&%R86TN9E]T87)G970N=')I;2@I.PH)"6$N=&ET;&4@
M/2!P87)A;2YF7W1I=&QE+G1R:6TH*3L*"0EE9&ET;W(N<V5L96-T3F]D94-O
M;G1E;G1S*&$I.PH)"65D:71O<BYU<&1A=&54;V]L8F%R*"D["@E]+"!O=71P
M87)A;2D["GT["@HO+R!#86QL960@=VAE;B!T:&4@=7-E<B!C;&EC:W,@;VX@
M(DEN<V5R=$EM86=E(B!B=71T;VXN("!)9B!A;B!I;6%G92!I<R!A;')E861Y
M"B\O('1H97)E+"!I="!W:6QL(&IU<W0@;6]D:69Y(&ET)W,@<')O<&5R=&EE
M<RX*2%1-3$%R96$N<')O=&]T>7!E+E]I;G-E<G1);6%G92`](&9U;F-T:6]N
M*&EM86=E*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@9F]R(&YE<W1E9"!F
M=6YC=&EO;G,*"79A<B!O=71P87)A;2`](&YU;&P["@EI9B`H='EP96]F(&EM
M86=E(#T](")U;F1E9FEN960B*2!["@D):6UA9V4@/2!T:&ES+F=E=%!A<F5N
M=$5L96UE;G0H*3L*"0EI9B`H:6UA9V4@)B8@(2]>:6UG)"]I+G1E<W0H:6UA
M9V4N=&%G3F%M92DI"@D)"6EM86=E(#T@;G5L;#L*"7T*"6EF("AI;6%G92D@
M;W5T<&%R86T@/2!["@D)9E]B87-E("`@.B!E9&ET;W(N8V]N9FEG+F)A<V55
M4DPL"@D)9E]U<FP@("`@.B!(5$U,07)E82YI<U]I92`_(&5D:71O<BYS=')I
M<$)A<V554DPH:6UA9V4N<W)C*2`Z(&EM86=E+F=E=$%T=')I8G5T92@B<W)C
M(BDL"@D)9E]A;'0@("`@.B!I;6%G92YA;'0L"@D)9E]B;W)D97(@.B!I;6%G
M92YB;W)D97(L"@D)9E]A;&EG;B`@.B!I;6%G92YA;&EG;BP*"0EF7W9E<G0@
M("`Z(&EM86=E+G9S<&%C92P*"0EF7VAO<FEZ("`Z(&EM86=E+FAS<&%C90H)
M?3L*"71H:7,N7W!O<'5P1&EA;&]G*")I;G-E<G1?:6UA9V4N:'1M;"(L(&9U
M;F-T:6]N*'!A<F%M*2!["@D):68@*"%P87)A;2D@>PDO+R!U<V5R(&UU<W0@
M:&%V92!P<F5S<V5D($-A;F-E;`H)"0ER971U<FX@9F%L<V4["@D)?0H)"79A
M<B!I;6<@/2!I;6%G93L*"0EI9B`H(6EM9RD@>PH)"0EV87(@<V5L(#T@961I
M=&]R+E]G971396QE8W1I;VXH*3L*"0D)=F%R(')A;F=E(#T@961I=&]R+E]C
M<F5A=&5286YG92AS96PI.PH)"0EE9&ET;W(N7V1O8RYE>&5C0V]M;6%N9"@B
M:6YS97)T:6UA9V4B+"!F86QS92P@<&%R86TN9E]U<FPI.PH)"0EI9B`H2%1-
M3$%R96$N:7-?:64I('L*"0D)"6EM9R`](')A;F=E+G!A<F5N=$5L96UE;G0H
M*3L*"0D)"2\O('=O;F1E<B!I9B!T:&ES('=O<FMS+BXN"@D)"0EI9B`H:6UG
M+G1A9TYA;64N=&],;W=E<D-A<V4H*2`A/2`B:6UG(BD@>PH)"0D)"6EM9R`]
M(&EM9RYP<F5V:6]U<U-I8FQI;F<["@D)"0E]"@D)"7T@96QS92!["@D)"0EI
M;6<@/2!R86YG92YS=&%R=$-O;G1A:6YE<BYP<F5V:6]U<U-I8FQI;F<["@D)
M"7T*"0E](&5L<V4@>PH)"0EI;6<N<W)C(#T@<&%R86TN9E]U<FP["@D)?0H*
M"0EF;W(@*'9A<B!F:65L9"!I;B!P87)A;2D@>PH)"0EV87(@=F%L=64@/2!P
M87)A;5MF:65L9%T["@D)"7-W:71C:"`H9FEE;&0I('L*"0D)("`@(&-A<V4@
M(F9?86QT(B`@("`Z(&EM9RYA;'0)(#T@=F%L=64[(&)R96%K.PH)"0D@("`@
M8V%S92`B9E]B;W)D97(B(#H@:6UG+F)O<F1E<B`]('!A<G-E26YT*'9A;'5E
M('Q\("(P(BD[(&)R96%K.PH)"0D@("`@8V%S92`B9E]A;&EG;B(@(#H@:6UG
M+F%L:6=N"2`]('9A;'5E.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?=F5R="(@
M("`Z(&EM9RYV<W!A8V4@/2!P87)S94EN="AV86QU92!\?"`B,"(I.R!B<F5A
M:SL*"0D)("`@(&-A<V4@(F9?:&]R:7HB("`Z(&EM9RYH<W!A8V4@/2!P87)S
M94EN="AV86QU92!\?"`B,"(I.R!B<F5A:SL*"0D)?0H)"7T*"7TL(&]U='!A
M<F%M*3L*?3L*"B\O($-A;&QE9"!W:&5N('1H92!U<V5R(&-L:6-K<R!T:&4@
M26YS97)T(%1A8FQE(&)U='1O;@I(5$U,07)E82YP<F]T;W1Y<&4N7VEN<V5R
M=%1A8FQE(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L(#T@=&AI<RY?9V5T4V5L
M96-T:6]N*"D["@EV87(@<F%N9V4@/2!T:&ES+E]C<F5A=&5286YG92AS96PI
M.PH)=F%R(&5D:71O<B`]('1H:7,["2\O(&9O<B!N97-T960@9G5N8W1I;VYS
M"@ET:&ES+E]P;W!U<$1I86QO9R@B:6YS97)T7W1A8FQE+FAT;6PB+"!F=6YC
M=&EO;BAP87)A;2D@>PH)"6EF("@A<&%R86TI('L)+R\@=7-E<B!M=7-T(&AA
M=F4@<')E<W-E9"!#86YC96P*"0D)<F5T=7)N(&9A;'-E.PH)"7T*"0EV87(@
M9&]C(#T@961I=&]R+E]D;V,["@D)+R\@8W)E871E('1H92!T86)L92!E;&5M
M96YT"@D)=F%R('1A8FQE(#T@9&]C+F-R96%T945L96UE;G0H(G1A8FQE(BD[
M"@D)+R\@87-S:6=N('1H92!G:79E;B!A<F=U;65N=',*"@D)9F]R("AV87(@
M9FEE;&0@:6X@<&%R86TI('L*"0D)=F%R('9A;'5E(#T@<&%R86U;9FEE;&1=
M.PH)"0EI9B`H(79A;'5E*2!["@D)"0EC;VYT:6YU93L*"0D)?0H)"0ES=VET
M8V@@*&9I96QD*2!["@D)"2`@("!C87-E(")F7W=I9'1H(B`@(#H@=&%B;&4N
M<W1Y;&4N=VED=&@@/2!V86QU92`K('!A<F%M6R)F7W5N:70B73L@8G)E86L[
M"@D)"2`@("!C87-E(")F7V%L:6=N(B`@(#H@=&%B;&4N86QI9VX)(#T@=F%L
M=64[(&)R96%K.PH)"0D@("`@8V%S92`B9E]B;W)D97(B("`Z('1A8FQE+F)O
M<F1E<@D@/2!P87)S94EN="AV86QU92D[(&)R96%K.PH)"0D@("`@8V%S92`B
M9E]S<&%C:6YG(B`Z('1A8FQE+F-E;&Q3<&%C:6YG(#T@<&%R<V5);G0H=F%L
M=64I.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?<&%D9&EN9R(@.B!T86)L92YC
M96QL4&%D9&EN9R`]('!A<G-E26YT*'9A;'5E*3L@8G)E86L["@D)"7T*"0E]
M"@D)=F%R(&-E;&QW:61T:"`](#`["@D):68@*'!A<F%M+F9?9FEX960I"@D)
M"6-E;&QW:61T:"`]($UA=&@N9FQO;W(H,3`P("\@<&%R<V5);G0H<&%R86TN
M9E]C;VQS*2D["@D)=F%R('1B;V1Y(#T@9&]C+F-R96%T945L96UE;G0H(G1B
M;V1Y(BD["@D)=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH)"69O<B`H=F%R
M(&D@/2`P.R!I(#P@<&%R86U;(F9?<F]W<R)=.R`K*VDI('L*"0D)=F%R('1R
M(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@D)"71B;V1Y+F%P<&5N9$-H
M:6QD*'1R*3L*"0D)9F]R("AV87(@:B`](#`[(&H@/"!P87)A;5LB9E]C;VQS
M(ET[("LK:BD@>PH)"0D)=F%R('1D(#T@9&]C+F-R96%T945L96UE;G0H(G1D
M(BD["@D)"0EI9B`H8V5L;'=I9'1H*0H)"0D)"71D+G-T>6QE+G=I9'1H(#T@
M8V5L;'=I9'1H("L@(B4B.PH)"0D)='(N87!P96YD0VAI;&0H=&0I.PH)"0D)
M+R\@36]Z:6QL82!L:6ME<R!T;R!S964@<V]M971H:6YG(&EN<VED92!T:&4@
M8V5L;"X*"0D)"2A(5$U,07)E82YI<U]G96-K;RD@)B8@=&0N87!P96YD0VAI
M;&0H9&]C+F-R96%T945L96UE;G0H(F)R(BDI.PH)"0E]"@D)?0H)"6EF("A(
M5$U,07)E82YI<U]I92D@>PH)"0ER86YG92YP87-T94A434PH=&%B;&4N;W5T
M97)(5$U,*3L*"0E](&5L<V4@>PH)"0DO+R!I;G-E<G0@=&AE('1A8FQE"@D)
M"65D:71O<BYI;G-E<G1.;V1E071396QE8W1I;VXH=&%B;&4I.PH)"7T*"0ER
M971U<FX@=')U93L*"7TL(&YU;&PI.PI].PH*+RHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@*B`@0V%T96=O
M<GDZ($5614Y4($A!3D1,15)3"B`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHO"@HO+R!E;"!I<R!R969E<F5N
M8V4@=&\@=&AE(%-%3$5#5"!O8FIE8W0*+R\@='AT(&ES('1H92!N86UE(&]F
M('1H92!S96QE8W0@9FEE;&0L(&%S(&EN(&-O;F9I9RYT;V]L8F%R"DA434Q!
M<F5A+G!R;W1O='EP92Y?8V]M8F]396QE8W1E9"`](&9U;F-T:6]N*&5L+"!T
M>'0I('L*"71H:7,N9F]C=7-%9&ET;W(H*3L*"79A<B!V86QU92`](&5L+F]P
M=&EO;G-;96PN<V5L96-T961);F1E>%TN=F%L=64["@ES=VET8V@@*'1X="D@
M>PH)("`@(&-A<V4@(F9O;G1N86UE(CH*"2`@("!C87-E(")F;VYT<VEZ92(Z
M('1H:7,N97AE8T-O;6UA;F0H='AT+"!F86QS92P@=F%L=64I.R!B<F5A:SL*
M"2`@("!C87-E(")F;W)M871B;&]C:R(Z"@D)*$A434Q!<F5A+FES7VEE*2`F
M)B`H=F%L=64@/2`B/"(@*R!V86QU92`K("(^(BD["@D)=&AI<RYE>&5C0V]M
M;6%N9"AT>'0L(&9A;'-E+"!V86QU92D["@D)8G)E86L["@D@("`@9&5F875L
M=#H*"0DO+R!T<GD@=&\@;&]O:R!I="!U<"!I;B!T:&4@<F5G:7-T97)E9"!D
M<F]P9&]W;G,*"0EV87(@9')O<&1O=VX@/2!T:&ES+F-O;F9I9RYC=7-T;VU3
M96QE8W1S6W1X=%T["@D):68@*'1Y<&5O9B!D<F]P9&]W;B`A/2`B=6YD969I
M;F5D(BD@>PH)"0ED<F]P9&]W;BYA8W1I;VXH=&AI<RD["@D)?2!E;'-E('L*
M"0D)86QE<G0H(D9)6$U%.B!C;VUB;R!B;W@@(B`K('1X="`K("(@;F]T(&EM
M<&QE;65N=&5D(BD["@D)?0H)?0I].PH*+R\@=&AE(&5X96-#;VUM86YD(&9U
M;F-T:6]N("AI;G1E<F-E<'1S('-O;64@8V]M;6%N9',@86YD(')E<&QA8V5S
M('1H96T@=VET:`HO+R!O=7(@;W=N(&EM<&QE;65N=&%T:6]N*0I(5$U,07)E
M82YP<F]T;W1Y<&4N97AE8T-O;6UA;F0@/2!F=6YC=&EO;BAC;61)1"P@54DL
M('!A<F%M*2!["@EV87(@961I=&]R(#T@=&AI<SL)+R\@9F]R(&YE<W1E9"!F
M=6YC=&EO;G,*"71H:7,N9F]C=7-%9&ET;W(H*3L*"6-M9$E$(#T@8VUD240N
M=&],;W=E<D-A<V4H*3L*"6EF("A(5$U,07)E82YI<U]G96-K;RD@=')Y('L@
M=&AI<RY?9&]C+F5X96-#;VUM86YD*"=U<V5#4U,G+"!F86QS92P@=')U92D[
M('T@8V%T8V@@*&4I('M].PH)<W=I=&-H("AC;61)1"D@>PH)("`@(&-A<V4@
M(FAT;6QM;V1E(B`Z('1H:7,N<V5T36]D92@I.R!B<F5A:SL*"2`@("!C87-E
M(")H:6QI=&5C;VQO<B(Z"@D)*$A434Q!<F5A+FES7VEE*2`F)B`H8VUD240@
M/2`B8F%C:V-O;&]R(BD["@D@("`@8V%S92`B9F]R96-O;&]R(CH*"0ET:&ES
M+E]P;W!U<$1I86QO9R@B<V5L96-T7V-O;&]R+FAT;6PB+"!F=6YC=&EO;BAC
M;VQO<BD@>PH)"0EI9B`H8V]L;W(I('L@+R\@<V5L96-T:6]N(&YO="!C86YC
M96QE9`H)"0D)961I=&]R+E]D;V,N97AE8T-O;6UA;F0H8VUD240L(&9A;'-E
M+"`B(R(@*R!C;VQO<BD["@D)"7T*"0E]+"!(5$U,07)E82Y?8V]L;W)4;U)G
M8BAT:&ES+E]D;V,N<75E<GE#;VUM86YD5F%L=64H8VUD240I*2D["@D)8G)E
M86L["@D@("`@8V%S92`B8W)E871E;&EN:R(Z"@D)=&AI<RY?8W)E871E3&EN
M:R@I.PH)"6)R96%K.PH)("`@(&-A<V4@(G!O<'5P961I=&]R(CH*"0DO+R!T
M:&ES(&]B:F5C="!W:6QL(&)E('!A<W-E9"!T;R!T:&4@;F5W;'D@;W!E;F5D
M('=I;F1O=PH)"4A434Q!<F5A+E]O8FIE8W0@/2!T:&ES.PH)"6EF("A(5$U,
M07)E82YI<U]I92D@>PH)"0DO+VEF("AC;VYF:7)M*$A434Q!<F5A+DDQ.$XN
M;7-G6R))12US=6-K<RUF=6QL+7-C<F5E;B)=*2D*"0D)>PH)"0D)=VEN9&]W
M+F]P96XH=&AI<RYP;W!U<%523"@B9G5L;'-C<F5E;BYH=&UL(BDL(")H85]F
M=6QL<V-R965N(BP*"0D)"0D@("`@(G1O;VQB87(];F\L;&]C871I;VX];F\L
M9&ER96-T;W)I97,];F\L<W1A='5S/6YO+&UE;G5B87(];F\L(B`K"@D)"0D)
M("`@(")S8W)O;&QB87)S/6YO+')E<VEZ86)L93UY97,L=VED=&@]-C0P+&AE
M:6=H=#TT.#`B*3L*"0D)?0H)"7T@96QS92!["@D)"7=I;F1O=RYO<&5N*'1H
M:7,N<&]P=7!54DPH(F9U;&QS8W)E96XN:'1M;"(I+"`B:&%?9G5L;'-C<F5E
M;B(L"@D)"0D@("`@(G1O;VQB87(];F\L;65N=6)A<CUN;RQP97)S;VYA;&)A
M<CUN;RQW:61T:#TV-#`L:&5I9VAT/30X,"PB("L*"0D)"2`@("`B<V-R;VQL
M8F%R<SUN;RQR97-I>F%B;&4]>65S(BD["@D)?0H)"6)R96%K.PH)("`@(&-A
M<V4@(G5N9&\B.@H)("`@(&-A<V4@(G)E9&\B.@H)"6EF("AT:&ES+E]C=7-T
M;VU5;F1O*0H)"0ET:&ES6V-M9$E$72@I.PH)"65L<V4*"0D)=&AI<RY?9&]C
M+F5X96-#;VUM86YD*&-M9$E$+"!522P@<&%R86TI.PH)"6)R96%K.PH)("`@
M(&-A<V4@(FEN<V5R='1A8FQE(CH@=&AI<RY?:6YS97)T5&%B;&4H*3L@8G)E
M86L["@D@("`@8V%S92`B:6YS97)T:6UA9V4B.B!T:&ES+E]I;G-E<G1);6%G
M92@I.R!B<F5A:SL*"2`@("!C87-E(")A8F]U="(@("`@.B!T:&ES+E]P;W!U
M<$1I86QO9R@B86)O=70N:'1M;"(L(&YU;&PL('1H:7,I.R!B<F5A:SL*"2`@
M("!C87-E(")S:&]W:&5L<"(@.B!W:6YD;W<N;W!E;BA?961I=&]R7W5R;"`K
M(")R969E<F5N8V4N:'1M;"(L(")H85]H96QP(BD[(&)R96%K.PH*"2`@("!C
M87-E(")K:6QL=V]R9"(Z('1H:7,N7W=O<F1#;&5A;B@I.R!B<F5A:SL*"@D@
M("`@8V%S92`B8W5T(CH*"2`@("!C87-E(")C;W!Y(CH*"2`@("!C87-E(")P
M87-T92(Z"@D)=')Y('L*"0D)=&AI<RY?9&]C+F5X96-#;VUM86YD*&-M9$E$
M+"!522P@<&%R86TI.PH)"0EI9B`H=&AI<RYC;VYF:6<N:VEL;%=O<F1/;E!A
M<W1E*0H)"0D)=&AI<RY?=V]R9$-L96%N*"D["@D)?2!C871C:"`H92D@>PH)
M"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0D)"6EF("AT>7!E;V8@2%1-
M3$%R96$N23$X3BYM<V=;(DUO>BU#;&EP8F]A<F0B72`]/2`B=6YD969I;F5D
M(BD@>PH)"0D)"4A434Q!<F5A+DDQ.$XN;7-G6R)-;WHM0VQI<&)O87)D(ET@
M/0H)"0D)"0DB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@(B`K"@D)"0D)"2)F;W(@
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G("(@*PH)"0D)"0DB=VAI8V@@<VAO=W,@
M>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B
M;V%R9"Y<;EQN(B`K"@D)"0D)"2);1DE8344Z('!L96%S92!T<F%N<VQA=&4@
M=&AI<R!M97-S86=E(&EN('EO=7(@;&%N9W5A9V4@9&5F:6YI=&EO;B!F:6QE
M+ETB.PH)"0D)?0H)"0D):68@*&-O;F9I<FTH2%1-3$%R96$N23$X3BYM<V=;
M(DUO>BU#;&EP8F]A<F0B72DI"@D)"0D)=VEN9&]W+F]P96XH(FAT='`Z+R]M
M;WII;&QA+F]R9R]E9&ET;W(O;6ED87-D96UO+W-E8W5R:71Y<')E9G,N:'1M
M;"(I.PH)"0E]"@D)?0H)"6)R96%K.PH)("`@(&-A<V4@(FQE9G1T;W)I9VAT
M(CH*"2`@("!C87-E(")R:6=H='1O;&5F="(Z"@D)=F%R(&1I<B`]("AC;61)
M1"`]/2`B<FEG:'1T;VQE9G0B*2`_(")R=&PB(#H@(FQT<B(["@D)=F%R(&5L
M(#T@=&AI<RYG971087)E;G1%;&5M96YT*"D["@D)=VAI;&4@*&5L("8F("%(
M5$U,07)E82YI<T)L;V-K16QE;65N="AE;"DI"@D)"65L(#T@96PN<&%R96YT
M3F]D93L*"0EI9B`H96PI('L*"0D):68@*&5L+G-T>6QE+F1I<F5C=&EO;B`]
M/2!D:7(I"@D)"0EE;"YS='EL92YD:7)E8W1I;VX@/2`B(CL*"0D)96QS90H)
M"0D)96PN<W1Y;&4N9&ER96-T:6]N(#T@9&ER.PH)"7T*"0EB<F5A:SL*"2`@
M("!D969A=6QT.B!T<GD@>R!T:&ES+E]D;V,N97AE8T-O;6UA;F0H8VUD240L
M(%5)+"!P87)A;2D[('T*"0EC871C:"AE*2![(&EF("AT:&ES+F-O;F9I9RYD
M96)U9RD@>R!A;&5R="AE("L@(EQN7&YB>2!E>&5C0V]M;6%N9"@B("L@8VUD
M240@*R`B*3LB*3L@?2!]"@E]"@ET:&ES+G5P9&%T951O;VQB87(H*3L*"7)E
M='5R;B!F86QS93L*?3L*"B\J*B!!(&=E;F5R:6,@979E;G0@:&%N9&QE<B!F
M;W(@=&AI;F=S('1H870@:&%P<&5N(&EN('1H92!)1E)!344G<R!D;V-U;65N
M="X*("H@5&AI<R!F=6YC=&EO;B!A;'-O(&AA;F1L97,@:V5Y(&)I;F1I;F=S
M+B`J+PI(5$U,07)E82YP<F]T;W1Y<&4N7V5D:71O<D5V96YT(#T@9G5N8W1I
M;VXH978I('L*"79A<B!E9&ET;W(@/2!T:&ES.PH)=F%R(&ME>45V96YT(#T@
M*$A434Q!<F5A+FES7VEE("8F(&5V+G1Y<&4@/3T@(FME>61O=VXB*2!\?"`H
M(4A434Q!<F5A+FES7VEE("8F(&5V+G1Y<&4@/3T@(FME>7!R97-S(BD["@H)
M:68@*&ME>45V96YT*0H)"69O<B`H=F%R(&D@:6X@961I=&]R+G!L=6=I;G,I
M('L*"0D)=F%R('!L=6=I;B`](&5D:71O<BYP;'5G:6YS6VE=+FEN<W1A;F-E
M.PH)"0EI9B`H='EP96]F('!L=6=I;BYO;DME>5!R97-S(#T](")F=6YC=&EO
M;B(I"@D)"0EI9B`H<&QU9VEN+F]N2V5Y4')E<W,H978I*0H)"0D)"7)E='5R
M;B!F86QS93L*"0E]"@EI9B`H:V5Y179E;G0@)B8@978N8W1R;$ME>2`F)B`A
M978N86QT2V5Y*2!["@D)=F%R('-E;"`](&YU;&P["@D)=F%R(')A;F=E(#T@
M;G5L;#L*"0EV87(@:V5Y(#T@4W1R:6YG+F9R;VU#:&%R0V]D92A(5$U,07)E
M82YI<U]I92`_(&5V+FME>4-O9&4@.B!E=BYC:&%R0V]D92DN=&],;W=E<D-A
M<V4H*3L*"0EV87(@8VUD(#T@;G5L;#L*"0EV87(@=F%L=64@/2!N=6QL.PH)
M"7-W:71C:"`H:V5Y*2!["@D)("`@(&-A<V4@)V$G.@H)"0EI9B`H(4A434Q!
M<F5A+FES7VEE*2!["@D)"0DO+R!+15D@<V5L96-T(&%L;`H)"0D)<V5L(#T@
M=&AI<RY?9V5T4V5L96-T:6]N*"D["@D)"0ES96PN<F5M;W9E06QL4F%N9V5S
M*"D["@D)"0ER86YG92`]('1H:7,N7V-R96%T95)A;F=E*"D["@D)"0ER86YG
M92YS96QE8W1.;V1E0V]N=&5N=',H=&AI<RY?9&]C+F)O9'DI.PH)"0D)<V5L
M+F%D9%)A;F=E*')A;F=E*3L*"0D)"4A434Q!<F5A+E]S=&]P179E;G0H978I
M.PH)"0E]"@D)"6)R96%K.PH*"0D)+R\@<VEM<&QE(&ME>2!C;VUM86YD<R!F
M;VQL;W<*"@D)("`@(&-A<V4@)V(G.B!C;60@/2`B8F]L9"([(&)R96%K.PH)
M"2`@("!C87-E("=I)SH@8VUD(#T@(FET86QI8R([(&)R96%K.PH)"2`@("!C
M87-E("=U)SH@8VUD(#T@(G5N9&5R;&EN92([(&)R96%K.PH)"2`@("!C87-E
M("=S)SH@8VUD(#T@(G-T<FEK971H<F]U9V@B.R!B<F5A:SL*"0D@("`@8V%S
M92`G;"<Z(&-M9"`](")J=7-T:69Y;&5F="([(&)R96%K.PH)"2`@("!C87-E
M("=E)SH@8VUD(#T@(FIU<W1I9GEC96YT97(B.R!B<F5A:SL*"0D@("`@8V%S
M92`G<B<Z(&-M9"`](")J=7-T:69Y<FEG:'0B.R!B<F5A:SL*"0D@("`@8V%S
M92`G:B<Z(&-M9"`](")J=7-T:69Y9G5L;"([(&)R96%K.PH)"2`@("!C87-E
M("=Z)SH@8VUD(#T@(G5N9&\B.R!B<F5A:SL*"0D@("`@8V%S92`G>2<Z(&-M
M9"`](")R961O(CL@8G)E86L["@D)("`@(&-A<V4@)W8G.B!I9B`H2%1-3$%R
M96$N:7-?:64@?'P@961I=&]R+F-O;F9I9RYH=&UL87)E85!A<W1E*2![(&-M
M9"`](")P87-T92([('T@8G)E86L["@D)("`@(&-A<V4@)VXG.B!C;60@/2`B
M9F]R;6%T8FQO8VLB.R!V86QU92`]($A434Q!<F5A+FES7VEE(#\@(CQP/B(@
M.B`B<"([(&)R96%K.PH*"0D@("`@8V%S92`G,"<Z(&-M9"`](")K:6QL=V]R
M9"([(&)R96%K.PH*"0D)+R\@:&5A9&EN9W,*"0D@("`@8V%S92`G,2<Z"@D)
M("`@(&-A<V4@)S(G.@H)"2`@("!C87-E("<S)SH*"0D@("`@8V%S92`G-"<Z
M"@D)("`@(&-A<V4@)S4G.@H)"2`@("!C87-E("<V)SH*"0D)8VUD(#T@(F9O
M<FUA=&)L;V-K(CL*"0D)=F%L=64@/2`B:"(@*R!K97D["@D)"6EF("A(5$U,
M07)E82YI<U]I92D*"0D)"79A;'5E(#T@(CPB("L@=F%L=64@*R`B/B(["@D)
M"6)R96%K.PH)"7T*"0EI9B`H8VUD*2!["@D)"2\O(&5X96-U=&4@<VEM<&QE
M(&-O;6UA;F0*"0D)=&AI<RYE>&5C0V]M;6%N9"AC;60L(&9A;'-E+"!V86QU
M92D["@D)"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"7T*"7T*"65L<V4@
M:68@*&ME>45V96YT*2!["@D)+R\@;W1H97(@:V5Y<R!H97)E"@D)<W=I=&-H
M("AE=BYK97E#;V1E*2!["@D)("`@(&-A<V4@,3,Z("\O($M%62!E;G1E<@H)
M"0EI9B`H2%1-3$%R96$N:7-?9V5C:V\@)B8@(65V+G-H:69T2V5Y*2!["@D)
M"0ET:&ES+F1O;5]C:&5C:TEN<V5R=%`H*3L*"0D)"4A434Q!<F5A+E]S=&]P
M179E;G0H978I.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(#@Z("\O($M%
M62!B86-K<W!A8V4*"0D@("`@8V%S92`T-CH@+R\@2T59(&1E;&5T90H)"0EI
M9B`H2%1-3$%R96$N:7-?9V5C:V\@)B8@(65V+G-H:69T2V5Y*2!["@D)"0EI
M9B`H=&AI<RYD;VU?8VAE8VM"86-K<W!A8V4H*2D*"0D)"0E(5$U,07)E82Y?
M<W1O<$5V96YT*&5V*3L*"0D)?2!E;'-E(&EF("A(5$U,07)E82YI<U]I92D@
M>PH)"0D):68@*'1H:7,N:65?8VAE8VM"86-K<W!A8V4H*2D*"0D)"0E(5$U,
M07)E82Y?<W1O<$5V96YT*&5V*3L*"0D)?0H)"0EB<F5A:SL*"0E]"@E]"@H)
M+R\@=7!D871E('1H92!T;V]L8F%R('-T871E(&%F=&5R('-O;64@=&EM90H)
M:68@*&5D:71O<BY?=&EM97)4;V]L8F%R*2!["@D)8VQE87)4:6UE;W5T*&5D
M:71O<BY?=&EM97)4;V]L8F%R*3L*"7T*"65D:71O<BY?=&EM97)4;V]L8F%R
M(#T@<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0EE9&ET;W(N=7!D871E5&]O
M;&)A<B@I.PH)"65D:71O<BY?=&EM97)4;V]L8F%R(#T@;G5L;#L*"7TL(#4P
M*3L*?3L*"DA434Q!<F5A+G!R;W1O='EP92YS8W)O;&Q4;T-A<F5T(#T@9G5N
M8W1I;VXH*2!["@EV87(*"0EE(#T@=&AI<RYG971087)E;G1%;&5M96YT*"DL
M"@D)=R`]('1H:7,N7VEF<F%M92YC;VYT96YT5VEN9&]W+`H)"6@@/2!W+FEN
M;F5R2&5I9VAT('Q\('<N:&5I9VAT+`H)"60@/2!T:&ES+E]D;V,L"@D)="`]
M(&0N9&]C=6UE;G1%;&5M96YT+G-C<F]L;%1O<"!\?"!D+F)O9'DN<V-R;VQL
M5&]P.PH):68@*'1Y<&5O9B!H(#T](")U;F1E9FEN960B*0H)"7)E='5R;B!F
M86QS93L*"6EF("AE+F]F9G-E=%1O<"`^(&@@*R!T*0H)"7<N<V-R;VQL5&\H
M92YO9F9S971,969T+"!E+F]F9G-E=%1O<"`M(&@@*R!E+F]F9G-E=$AE:6=H
M="D["GT["@I(5$U,07)E82YP<F]T;W1Y<&4N8V]N=F5R=$YO9&4@/2!F=6YC
M=&EO;BAE;"P@;F5W5&%G3F%M92D@>PH)=F%R(&YE=V5L(#T@=&AI<RY?9&]C
M+F-R96%T945L96UE;G0H;F5W5&%G3F%M92DL('`@/2!E;"YP87)E;G1.;V1E
M.PH)=VAI;&4@*&5L+F9I<G-T0VAI;&0I"@D);F5W96PN87!P96YD0VAI;&0H
M96PN9FER<W1#:&EL9"D["@EP+FEN<V5R=$)E9F]R92AN97=E;"P@96PI.PH)
M<"YR96UO=F5#:&EL9"AE;"D["@ER971U<FX@;F5W96P["GT["@I(5$U,07)E
M82YP<F]T;W1Y<&4N:65?8VAE8VM"86-K<W!A8V4@/2!F=6YC=&EO;B@I('L*
M"79A<B!S96P@/2!T:&ES+E]G971396QE8W1I;VXH*3L*"79A<B!R86YG92`]
M('1H:7,N7V-R96%T95)A;F=E*'-E;"D["@EV87(@<C(@/2!R86YG92YD=7!L
M:6-A=&4H*3L*"7(R+FUO=F53=&%R="@B8VAA<F%C=&5R(BP@+3$I.PH)=F%R
M(&$@/2!R,BYP87)E;G1%;&5M96YT*"D["@EI9B`H82`A/2!R86YG92YP87)E
M;G1%;&5M96YT*"D@)B8*"2`@("`O7F$D+VDN=&5S="AA+G1A9TYA;64I*2![
M"@D)<C(N8V]L;&%P<V4H=')U92D["@D)<C(N;6]V945N9"@B8VAA<F%C=&5R
M(BP@,2D["@D)<C(N<&%S=&5(5$U,*"<G*3L*"0ER,BYS96QE8W0H*3L*"0ER
M971U<FX@=')U93L*"7T*?3L*"DA434Q!<F5A+G!R;W1O='EP92YD;VU?8VAE
M8VM"86-K<W!A8V4@/2!F=6YC=&EO;B@I('L*"79A<B!S96QF(#T@=&AI<SL*
M"7-E=%1I;65O=70H9G5N8W1I;VXH*2!["@D)=F%R('-E;"`]('-E;&8N7V=E
M=%-E;&5C=&EO;B@I.PH)"79A<B!R86YG92`]('-E;&8N7V-R96%T95)A;F=E
M*'-E;"D["@D)=F%R(%-#(#T@<F%N9V4N<W1A<G1#;VYT86EN97(["@D)=F%R
M(%-/(#T@<F%N9V4N<W1A<G1/9F9S970["@D)=F%R($5#(#T@<F%N9V4N96YD
M0V]N=&%I;F5R.PH)"79A<B!%3R`](')A;F=E+F5N9$]F9G-E=#L*"0EV87(@
M;F5W<B`](%-#+FYE>'13:6)L:6YG.PH)"6EF("A30RYN;V1E5'EP92`]/2`S
M*0H)"0E30R`](%-#+G!A<F5N=$YO9&4["@D):68@*"$O7%,O+G1E<W0H4T,N
M=&%G3F%M92DI('L*"0D)=F%R('`@/2!D;V-U;65N="YC<F5A=&5%;&5M96YT
M*")P(BD["@D)"7=H:6QE("A30RYF:7)S=$-H:6QD*0H)"0D)<"YA<'!E;F1#
M:&EL9"A30RYF:7)S=$-H:6QD*3L*"0D)4T,N<&%R96YT3F]D92YI;G-E<G1"
M969O<F4H<"P@4T,I.PH)"0E30RYP87)E;G1.;V1E+G)E;6]V94-H:6QD*%-#
M*3L*"0D)=F%R('(@/2!R86YG92YC;&]N95)A;F=E*"D["@D)"7(N<V5T4W1A
M<G1"969O<F4H;F5W<BD["@D)"7(N<V5T16YD069T97(H;F5W<BD["@D)"7(N
M97AT<F%C=$-O;G1E;G1S*"D["@D)"7-E;"YR96UO=F5!;&Q286YG97,H*3L*
M"0D)<V5L+F%D9%)A;F=E*'(I.PH)"7T*"7TL(#$P*3L*?3L*"DA434Q!<F5A
M+G!R;W1O='EP92YD;VU?8VAE8VM);G-E<G10(#T@9G5N8W1I;VXH*2!["@EV
M87(@:2P@4T,L(&QE9G0L(')I9VAT+"!R,BP*"0ES96P@("`]('1H:7,N7V=E
M=%-E;&5C=&EO;B@I+`H)"7(@("`@(#T@=&AI<RY?8W)E871E4F%N9V4H<V5L
M*2P*"0EP("`@("`]('1H:7,N9V5T06QL06YC97-T;W)S*"DL"@D)8FQO8VL@
M/2!N=6QL+`H)"61O8R`@(#T@=&AI<RY?9&]C+`H)"6)O9'D@(#T@9&]C+F)O
M9'D["@H)9F]R("AI(#T@,#L@:2`\('`N;&5N9W1H.R`K*VDI"@D):68@*$A4
M34Q!<F5A+FES0FQO8VM%;&5M96YT*'!;:5TI("8F("$O8F]D>7QH=&UL+VDN
M=&5S="AP6VE=+G1A9TYA;64I*2!["@D)"6)L;V-K(#T@<%MI73L*"0D)8G)E
M86L["@D)?0H*"6EF("@A<BYC;VQL87!S960I"@D)<BYD96QE=&5#;VYT96YT
M<R@I.PH)<V5L+G)E;6]V94%L;%)A;F=E<R@I.PH)4T,@/2!R+G-T87)T0V]N
M=&%I;F5R.PH*"6EF("@A8FQO8VLI('L*"0EL969T(#T@4T,["@D)9F]R("AI
M(#T@4T,[(&D@)B8@:2`A/2!B;V1Y("8F("%(5$U,07)E82YI<T)L;V-K16QE
M;65N="AI*3L@:2`]($A434Q!<F5A+F=E=%!R979.;V1E*&DI*0H)"0EL969T
M(#T@:3L*"0ER:6=H="`](%-#.PH)"69O<B`H:2`](%-#.R!I("8F(&D@(3T@
M8F]D>2`F)B`A2%1-3$%R96$N:7-";&]C:T5L96UE;G0H:2D[(&D@/2!(5$U,
M07)E82YG971.97AT3F]D92AI*2D*"0D)<FEG:'0@/2!I.PH)"6EF("AL969T
M("$](&)O9'D@)B8@<FEG:'0@(3T@8F]D>2D@>PH)"0ER,B`]('(N8VQO;F52
M86YG92@I.PH)"0ER,BYS9713=&%R=$)E9F]R92AL969T*3L*"0D)<C(N<W5R
M<F]U;F1#;VYT96YT<RAB;&]C:R`](&1O8RYC<F5A=&5%;&5M96YT*")P(BDI
M.PH)"0EI9B`H(2]<4R\N=&5S="A(5$U,07)E82YG971);FYE<E1E>'0H8FQO
M8VLI*2D*"0D)"6)L;V-K+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)"0EB;&]C
M:RYN;W)M86QI>F4H*3L*"0D)<BYS971%;F1!9G1E<BAR:6=H="D["@D)"7(N
M<W5R<F]U;F1#;VYT96YT<RAB;&]C:R`](&1O8RYC<F5A=&5%;&5M96YT*")P
M(BDI.PH)"0EI9B`H(2]<4R\N=&5S="A(5$U,07)E82YG971);FYE<E1E>'0H
M8FQO8VLI*2D*"0D)"6)L;V-K+FEN;F5R2%1-3"`]("(\8G(@+SXB.PH)"0EB
M;&]C:RYN;W)M86QI>F4H*3L*"0E](&5L<V4@>PH)"0ER(#T@9&]C+F-R96%T
M95)A;F=E*"D["@D)"7(N<V5T4W1A<G0H8F]D>2P@,"D["@D)"7(N<V5T16YD
M*&)O9'DL(#`I.PH)"0ER+FEN<V5R=$YO9&4H8FQO8VL@/2!D;V,N8W)E871E
M16QE;65N="@B<"(I*3L*"0D)8FQO8VLN:6YN97)(5$U,(#T@(CQB<B`O/B([
M"@D)?0H)"7(N<V5L96-T3F]D94-O;G1E;G1S*&)L;V-K*3L*"7T@96QS92![
M"@D)<BYS971%;F1!9G1E<BAB;&]C:RD["@D)=F%R(&1F(#T@<BYE>'1R86-T
M0V]N=&5N=',H*2P@;&5F=%]E;7!T>2`](&9A;'-E.PH)"6EF("@A+UQ3+RYT
M97-T*&)L;V-K+FEN;F5R2%1-3"DI('L*"0D)8FQO8VLN:6YN97)(5$U,(#T@
M(CQB<B`O/B(["@D)"6QE9G1?96UP='D@/2!T<G5E.PH)"7T*"0EP(#T@9&8N
M9FER<W1#:&EL9#L*"0EI9B`H<"D@>PH)"0EI9B`H(2]<4R\N=&5S="A(5$U,
M07)E82YG971);FYE<E1E>'0H<"DI*2!["B`)"0D):68@*"]>:%LQ+39=)"]I
M+G1E<W0H<"YT86=.86UE*2D*(`D)"0D)<"`]('1H:7,N8V]N=F5R=$YO9&4H
M<"P@(G`B*3L*"0D)"7`N:6YN97)(5$U,(#T@(CQB<B`O/B(["@D)"7T*"0D)
M:68@*"]>;&DD+VDN=&5S="AP+G1A9TYA;64I("8F(&QE9G1?96UP='D@)B8@
M(6)L;V-K+FYE>'13:6)L:6YG*2!["@D)"0EL969T(#T@8FQO8VLN<&%R96YT
M3F]D93L*"0D)"6QE9G0N<F5M;W9E0VAI;&0H8FQO8VLI.PH)"0D)<BYS971%
M;F1!9G1E<BAL969T*3L*"0D)"7(N8V]L;&%P<V4H9F%L<V4I.PH)"0D)<"`]
M('1H:7,N8V]N=F5R=$YO9&4H<"P@+UY;=6]=;"0O:2YT97-T*&QE9G0N<&%R
M96YT3F]D92YT86=.86UE*2`_(")L:2(@.B`B<"(I.PH)"0E]"@D)"7(N:6YS
M97)T3F]D92AD9BD["@D)"7(N<V5L96-T3F]D94-O;G1E;G1S*'`I.PH)"7T*
M"7T*"7(N8V]L;&%P<V4H=')U92D["@ES96PN861D4F%N9V4H<BD["@ET:&ES
M+F9O<F-E4F5D<F%W*"D["@ET:&ES+G-C<F]L;%1O0V%R970H*3L*?3L*"B\O
M(')E=')I979E('1H92!(5$U,"DA434Q!<F5A+G!R;W1O='EP92YG971(5$U,
M(#T@9G5N8W1I;VXH*2!["@ES=VET8V@@*'1H:7,N7V5D:71-;V1E*2!["@D@
M("`@8V%S92`B=WES:7=Y9R(@(#H*"0EI9B`H(71H:7,N8V]N9FEG+F9U;&Q0
M86=E*2!["@D)"7)E='5R;B!(5$U,07)E82YG971(5$U,*'1H:7,N7V1O8RYB
M;V1Y+"!F86QS92P@=&AI<RD["@D)?2!E;'-E"@D)"7)E='5R;B!T:&ES+F1O
M8W1Y<&4@*R`B7&XB("L@2%1-3$%R96$N9V5T2%1-3"AT:&ES+E]D;V,N9&]C
M=6UE;G1%;&5M96YT+"!T<G5E+"!T:&ES*3L*"2`@("!C87-E(")T97AT;6]D
M92(@.B!R971U<FX@=&AI<RY?=&5X=$%R96$N=F%L=64["@D@("`@9&5F875L
M=`D@("`@.B!A;&5R="@B36]D92`\(B`K(&UO9&4@*R`B/B!N;W0@9&5F:6YE
M9"$B*3L*"7T*"7)E='5R;B!F86QS93L*?3L*"B\O(')E=')I979E('1H92!(
M5$U,("AF87-T97-T('9E<G-I;VXL(&)U="!U<V5S(&EN;F5R2%1-3"D*2%1-
M3$%R96$N<')O=&]T>7!E+F=E=$EN;F5R2%1-3"`](&9U;F-T:6]N*"D@>PH)
M<W=I=&-H("AT:&ES+E]E9&ET36]D92D@>PH)("`@(&-A<V4@(G=Y<VEW>6<B
M("`Z"@D):68@*"%T:&ES+F-O;F9I9RYF=6QL4&%G92D*"0D)<F5T=7)N('1H
M:7,N7V1O8RYB;V1Y+FEN;F5R2%1-3#L*"0EE;'-E"@D)"7)E='5R;B!T:&ES
M+F1O8W1Y<&4@*R`B7&XB("L@=&AI<RY?9&]C+F1O8W5M96YT16QE;65N="YI
M;FYE<DA434P["@D@("`@8V%S92`B=&5X=&UO9&4B(#H@<F5T=7)N('1H:7,N
M7W1E>'1!<F5A+G9A;'5E.PH)("`@(&1E9F%U;'0)("`@(#H@86QE<G0H(DUO
M9&4@/"(@*R!M;V1E("L@(CX@;F]T(&1E9FEN960A(BD["@E]"@ER971U<FX@
M9F%L<V4["GT["@HO+R!C;VUP;&5T96QY(&-H86YG92!T:&4@2%1-3"!I;G-I
M9&4*2%1-3$%R96$N<')O=&]T>7!E+G-E=$A434P@/2!F=6YC=&EO;BAH=&UL
M*2!["@ES=VET8V@@*'1H:7,N7V5D:71-;V1E*2!["@D@("`@8V%S92`B=WES
M:7=Y9R(@(#H*"0EI9B`H(71H:7,N8V]N9FEG+F9U;&Q086=E*0H)"0ET:&ES
M+E]D;V,N8F]D>2YI;FYE<DA434P@/2!H=&UL.PH)"65L<V4*"0D)+R\@=&AI
M<RY?9&]C+F1O8W5M96YT16QE;65N="YI;FYE<DA434P@/2!H=&UL.PH)"0ET
M:&ES+E]D;V,N8F]D>2YI;FYE<DA434P@/2!H=&UL.PH)"6)R96%K.PH)("`@
M(&-A<V4@(G1E>'1M;V1E(B`Z('1H:7,N7W1E>'1!<F5A+G9A;'5E(#T@:'1M
M;#L@8G)E86L["@D@("`@9&5F875L=`D@("`@.B!A;&5R="@B36]D92`\(B`K
M(&UO9&4@*R`B/B!N;W0@9&5F:6YE9"$B*3L*"7T*"7)E='5R;B!F86QS93L*
M?3L*"B\O('-E=',@=&AE(&=I=F5N(&1O8W1Y<&4@*'5S969U;"!W:&5N(&-O
M;F9I9RYF=6QL4&%G92!I<R!T<G5E*0I(5$U,07)E82YP<F]T;W1Y<&4N<V5T
M1&]C='EP92`](&9U;F-T:6]N*&1O8W1Y<&4I('L*"71H:7,N9&]C='EP92`]
M(&1O8W1Y<&4["GT["@HO*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ"B`J("!#871E9V]R>3H@551)3$E462!&
M54Y#5$E/3E,*("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B\*"B\O('9A<FEA8FQE('5S960@=&\@<&%S<R!T
M:&4@;V)J96-T('1O('1H92!P;W!U<"!E9&ET;W(@=VEN9&]W+@I(5$U,07)E
M82Y?;V)J96-T(#T@;G5L;#L*"B\O(&9U;F-T:6]N('1H870@<F5T=7)N<R!A
M(&-L;VYE(&]F('1H92!G:79E;B!O8FIE8W0*2%1-3$%R96$N8VQO;F5/8FIE
M8W0@/2!F=6YC=&EO;BAO8FHI('L*"6EF("@A;V)J*2!R971U<FX@;G5L;#L*
M"79A<B!N97=/8FH@/2!N97<@3V)J96-T.PH*"2\O(&-H96-K(&9O<B!A<G)A
M>2!O8FIE8W1S"@EI9B`H;V)J+F-O;G-T<G5C=&]R+G1O4W1R:6YG*"DN:6YD
M97A/9B@B9G5N8W1I;VX@07)R87DH(BD@/3T@,2D@>PH)"6YE=T]B:B`](&]B
M:BYC;VYS=')U8W1O<B@I.PH)?0H*"2\O(&-H96-K(&9O<B!F=6YC=&EO;B!O
M8FIE8W1S("AA<R!U<W5A;"P@244@:7,@9G5C:V5D('5P*0H):68@*&]B:BYC
M;VYS=')U8W1O<BYT;U-T<FEN9R@I+FEN9&5X3V8H(F9U;F-T:6]N($9U;F-T
M:6]N*"(I(#T](#$I('L*"0EN97=/8FH@/2!O8FH[("\O(&IU<W0@8V]P>2!R
M969E<F5N8V4@=&\@:70*"7T@96QS92!F;W(@*'9A<B!N(&EN(&]B:BD@>PH)
M"79A<B!N;V1E(#T@;V)J6VY=.PH)"6EF("AT>7!E;V8@;F]D92`]/2`G;V)J
M96-T)RD@>R!N97=/8FI;;ET@/2!(5$U,07)E82YC;&]N94]B:F5C="AN;V1E
M*3L@?0H)"65L<V4@("`@("`@("`@("`@("`@("`@("`@("`@>R!N97=/8FI;
M;ET@/2!N;V1E.R!]"@E]"@H)<F5T=7)N(&YE=T]B:CL*?3L*"B\O($9)6$U%
M(2$A('1H:7,@<VAO=6QD(')E='5R;B!F86QS92!F;W(@244@/"`U+C4*2%1-
M3$%R96$N8VAE8VM3=7!P;W)T961"<F]W<V5R(#T@9G5N8W1I;VXH*2!["@EI
M9B`H2%1-3$%R96$N:7-?9V5C:V\I('L*"0EI9B`H;F%V:6=A=&]R+G!R;V1U
M8W13=6(@/"`R,#`R,3(P,2D@>PH)"0EA;&5R="@B66]U(&YE960@870@;&5A
M<W0@36]Z:6QL82TQ+C,@06QP:&$N7&XB("L*"0D)("`@("`@(E-O<G)Y+"!Y
M;W5R($=E8VMO(&ES(&YO="!S=7!P;W)T960N(BD["@D)"7)E='5R;B!F86QS
M93L*"0E]"@D):68@*&YA=FEG871O<BYP<F]D=6-T4W5B(#P@,C`P,S`R,3`I
M('L*"0D)86QE<G0H(DUO>FEL;&$@/"`Q+C,@0F5T82!I<R!N;W0@<W5P<&]R
M=&5D(5QN(B`K"@D)"2`@("`@(")))VQL('1R>2P@=&AO=6=H+"!B=70@:70@
M;6EG:'0@;F]T('=O<FLN(BD["@D)?0H)?0H)<F5T=7)N($A434Q!<F5A+FES
M7V=E8VMO('Q\($A434Q!<F5A+FES7VEE.PI].PH*+R\@<V5L96-T:6]N("8@
M<F%N9V5S"@HO+R!R971U<FYS('1H92!C=7)R96YT('-E;&5C=&EO;B!O8FIE
M8W0*2%1-3$%R96$N<')O=&]T>7!E+E]G971396QE8W1I;VX@/2!F=6YC=&EO
M;B@I('L*"6EF("A(5$U,07)E82YI<U]I92D@>PH)"7)E='5R;B!T:&ES+E]D
M;V,N<V5L96-T:6]N.PH)?2!E;'-E('L*"0ER971U<FX@=&AI<RY?:69R86UE
M+F-O;G1E;G17:6YD;W<N9V5T4V5L96-T:6]N*"D["@E]"GT["@HO+R!R971U
M<FYS(&$@<F%N9V4@9F]R('1H92!C=7)R96YT('-E;&5C=&EO;@I(5$U,07)E
M82YP<F]T;W1Y<&4N7V-R96%T95)A;F=E(#T@9G5N8W1I;VXH<V5L*2!["@EI
M9B`H2%1-3$%R96$N:7-?:64I('L*"0ER971U<FX@<V5L+F-R96%T95)A;F=E
M*"D["@E](&5L<V4@>PH)"71H:7,N9F]C=7-%9&ET;W(H*3L*"0EI9B`H='EP
M96]F('-E;"`A/2`B=6YD969I;F5D(BD@>PH)"0ET<GD@>PH)"0D)<F5T=7)N
M('-E;"YG971286YG94%T*#`I.PH)"0E](&-A=&-H*&4I('L*"0D)"7)E='5R
M;B!T:&ES+E]D;V,N8W)E871E4F%N9V4H*3L*"0D)?0H)"7T@96QS92!["@D)
M"7)E='5R;B!T:&ES+E]D;V,N8W)E871E4F%N9V4H*3L*"0E]"@E]"GT["@HO
M+R!E=F5N="!H86YD;&EN9PH*2%1-3$%R96$N7V%D9$5V96YT(#T@9G5N8W1I
M;VXH96PL(&5V;F%M92P@9G5N8RD@>PH):68@*$A434Q!<F5A+FES7VEE*2![
M"@D)96PN871T86-H179E;G0H(F]N(B`K(&5V;F%M92P@9G5N8RD["@E](&5L
M<V4@>PH)"65L+F%D9$5V96YT3&ES=&5N97(H979N86UE+"!F=6YC+"!T<G5E
M*3L*"7T*?3L*"DA434Q!<F5A+E]A9&1%=F5N=',@/2!F=6YC=&EO;BAE;"P@
M979S+"!F=6YC*2!["@EF;W(@*'9A<B!I(#T@979S+FQE;F=T:#L@+2UI(#X]
M(#`[*2!["@D)2%1-3$%R96$N7V%D9$5V96YT*&5L+"!E=G-;:5TL(&9U;F,I
M.PH)?0I].PH*2%1-3$%R96$N7W)E;6]V945V96YT(#T@9G5N8W1I;VXH96PL
M(&5V;F%M92P@9G5N8RD@>PH):68@*$A434Q!<F5A+FES7VEE*2!["@D)96PN
M9&5T86-H179E;G0H(F]N(B`K(&5V;F%M92P@9G5N8RD["@E](&5L<V4@>PH)
M"65L+G)E;6]V945V96YT3&ES=&5N97(H979N86UE+"!F=6YC+"!T<G5E*3L*
M"7T*?3L*"DA434Q!<F5A+E]R96UO=F5%=F5N=',@/2!F=6YC=&EO;BAE;"P@
M979S+"!F=6YC*2!["@EF;W(@*'9A<B!I(#T@979S+FQE;F=T:#L@+2UI(#X]
M(#`[*2!["@D)2%1-3$%R96$N7W)E;6]V945V96YT*&5L+"!E=G-;:5TL(&9U
M;F,I.PH)?0I].PH*2%1-3$%R96$N7W-T;W!%=F5N="`](&9U;F-T:6]N*&5V
M*2!["@EI9B`H2%1-3$%R96$N:7-?:64I('L*"0EE=BYC86YC96Q"=6)B;&4@
M/2!T<G5E.PH)"65V+G)E='5R;E9A;'5E(#T@9F%L<V4["@E](&5L<V4@>PH)
M"65V+G!R979E;G1$969A=6QT*"D["@D)978N<W1O<%!R;W!A9V%T:6]N*"D[
M"@E]"GT["@I(5$U,07)E82Y?<F5M;W9E0VQA<W,@/2!F=6YC=&EO;BAE;"P@
M8VQA<W-.86UE*2!["@EI9B`H(2AE;"`F)B!E;"YC;&%S<TYA;64I*2!["@D)
M<F5T=7)N.PH)?0H)=F%R(&-L<R`](&5L+F-L87-S3F%M92YS<&QI="@B("(I
M.PH)=F%R(&%R(#T@;F5W($%R<F%Y*"D["@EF;W(@*'9A<B!I(#T@8VQS+FQE
M;F=T:#L@:2`^(#`[*2!["@D):68@*&-L<ULM+6E=("$](&-L87-S3F%M92D@
M>PH)"0EA<EMA<BYL96YG=&A=(#T@8VQS6VE=.PH)"7T*"7T*"65L+F-L87-S
M3F%M92`](&%R+FIO:6XH(B`B*3L*?3L*"DA434Q!<F5A+E]A9&1#;&%S<R`]
M(&9U;F-T:6]N*&5L+"!C;&%S<TYA;64I('L*"2\O(')E;6]V92!T:&4@8VQA
M<W,@9FER<W0L(&EF(&%L<F5A9'D@=&AE<F4*"4A434Q!<F5A+E]R96UO=F5#
M;&%S<RAE;"P@8VQA<W-.86UE*3L*"65L+F-L87-S3F%M92`K/2`B("(@*R!C
M;&%S<TYA;64["GT["@I(5$U,07)E82Y?:&%S0VQA<W,@/2!F=6YC=&EO;BAE
M;"P@8VQA<W-.86UE*2!["@EI9B`H(2AE;"`F)B!E;"YC;&%S<TYA;64I*2![
M"@D)<F5T=7)N(&9A;'-E.PH)?0H)=F%R(&-L<R`](&5L+F-L87-S3F%M92YS
M<&QI="@B("(I.PH)9F]R("AV87(@:2`](&-L<RYL96YG=&@[(&D@/B`P.RD@
M>PH)"6EF("AC;'-;+2UI72`]/2!C;&%S<TYA;64I('L*"0D)<F5T=7)N('1R
M=64["@D)?0H)?0H)<F5T=7)N(&9A;'-E.PI].PH*2%1-3$%R96$N7V)L;V-K
M5&%G<R`]("(@8F]D>2!F;W)M('1E>'1A<F5A(&9I96QD<V5T('5L(&]L(&1L
M(&QI(&1I=B`B("L*(G`@:#$@:#(@:#,@:#0@:#4@:#8@<75O=&4@<')E('1A
M8FQE('1H96%D("(@*PHB=&)O9'D@=&9O;W0@='(@=&0@:69R86UE(&%D9')E
M<W,@(CL*2%1-3$%R96$N:7-";&]C:T5L96UE;G0@/2!F=6YC=&EO;BAE;"D@
M>PH)<F5T=7)N(&5L("8F(&5L+FYO9&54>7!E(#T](#$@)B8@*$A434Q!<F5A
M+E]B;&]C:U1A9W,N:6YD97A/9B@B("(@*R!E;"YT86=.86UE+G1O3&]W97)#
M87-E*"D@*R`B("(I("$]("TQ*3L*?3L*"DA434Q!<F5A+E]C;&]S:6YG5&%G
M<R`]("(@:&5A9"!S8W)I<'0@<W1Y;&4@9&EV('-P86X@='(@=&0@=&)O9'D@
M=&%B;&4@96T@<W1R;VYG(&(@:2!C;V1E(&-I=&4@9&9N(&%B8G(@86-R;VYY
M;2!F;VYT(&$@=&ET;&4@(CL*2%1-3$%R96$N;F5E9'-#;&]S:6YG5&%G(#T@
M9G5N8W1I;VXH96PI('L*"7)E='5R;B!E;"`F)B!E;"YN;V1E5'EP92`]/2`Q
M("8F("A(5$U,07)E82Y?8VQO<VEN9U1A9W,N:6YD97A/9B@B("(@*R!E;"YT
M86=.86UE+G1O3&]W97)#87-E*"D@*R`B("(I("$]("TQ*3L*?3L*"B\O('!E
M<F9O<FUS($A434P@96YC;V1I;F<@;V8@<V]M92!G:79E;B!S=')I;F<*2%1-
M3$%R96$N:'1M;$5N8V]D92`](&9U;F-T:6]N*'-T<BD@>PH)+R\@=V4@9&]N
M)W0@;F5E9"!R96=E>'`@9F]R('1H870L(&)U="XN('-O(&)E(&ET(&9O<B!N
M;W<N"@ES='(@/2!S='(N<F5P;&%C92@O)B]I9RP@(B9A;7`[(BD["@ES='(@
M/2!S='(N<F5P;&%C92@O/"]I9RP@(B9L=#LB*3L*"7-T<B`]('-T<BYR97!L
M86-E*"\^+VEG+"`B)F=T.R(I.PH)<W1R(#T@<W1R+G)E<&QA8V4H+UQX,C(O
M:6<L("(F<75O=#LB*3L*"2\O(%QX,C(@;65A;G,@)R(G("TM('=E('5S92!H
M97@@<F5P<F5Z96YT871I;VX@<V\@=&AA="!W92!D;VXG="!D:7-T=7)B"@DO
M+R!*4R!C;VUP<F5S<V]R<R`H=V5L;"P@870@;&5A<W0@;6EN92!F86EL<RXN
M(#LI"@ER971U<FX@<W1R.PI].PH*+R\@4F5T<FEE=F5S('1H92!(5$U,(&-O
M9&4@9G)O;2!T:&4@9VEV96X@;F]D92X)(%1H:7,@:7,@82!R97!L86-E;65N
M="!F;W(*+R\@9V5T=&EN9R!I;FYE<DA434PL('5S:6YG('-T86YD87)D($1/
M32!C86QL<RX*+R\@5W)A<'!E<B!C871C:"!A($UO>FEL;&$M17AC97!T:6]N
M('=I=&@@;F]N('=E;&P@9F]R;65D(&AT;6P@<V]U<F-E(&-O9&4*2%1-3$%R
M96$N9V5T2%1-3"`](&9U;F-T:6]N*')O;W0L(&]U='!U=%)O;W0L(&5D:71O
M<BE["B`@("!T<GE["B`@("`@("`@<F5T=7)N($A434Q!<F5A+F=E=$A434Q7
M<F%P<&5R*')O;W0L;W5T<'5T4F]O="QE9&ET;W(I.PH@("`@?0H@("`@8V%T
M8V@H92E["B`@("`@("`@86QE<G0H)UEO=7(@1&]C=6UE;G0@:7,@;F]T('=E
M;&P@9F]R;65D+B!#:&5C:R!*879A4V-R:7!T(&-O;G-O;&4@9F]R(&1E=&%I
M;',N)RD["B`@("`@("`@<F5T=7)N(&5D:71O<BY?:69R86UE+F-O;G1E;G17
M:6YD;W<N9&]C=6UE;G0N8F]D>2YI;FYE<DA434P["B`@("!]"GT*"DA434Q!
M<F5A+F=E=$A434Q7<F%P<&5R(#T@9G5N8W1I;VXH<F]O="P@;W5T<'5T4F]O
M="P@961I=&]R*2!["@EV87(@:'1M;"`]("(B.PH)<W=I=&-H("AR;V]T+FYO
M9&54>7!E*2!["@D@("`@8V%S92`Q.B`O+R!.;V1E+D5,14U%3E1?3D]$10H)
M("`@(&-A<V4@,3$Z("\O($YO9&4N1$]#54U%3E1?1E)!1TU%3E1?3D]$10H)
M"79A<B!C;&]S960["@D)=F%R(&D["@D)=F%R(')O;W1?=&%G(#T@*')O;W0N
M;F]D951Y<&4@/3T@,2D@/R!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2`Z
M("<G.PH)"6EF("AR;V]T7W1A9R`]/2`G8G(G("8F("%R;V]T+FYE>'13:6)L
M:6YG*0H)"0EB<F5A:SL*"0EI9B`H;W5T<'5T4F]O="D*"0D);W5T<'5T4F]O
M="`]("$H961I=&]R+F-O;F9I9RYH=&UL4F5M;W9E5&%G<R`F)B!E9&ET;W(N
M8V]N9FEG+FAT;6Q296UO=F5486=S+G1E<W0H<F]O=%]T86<I*3L*"0EI9B`H
M2%1-3$%R96$N:7-?:64@)B8@<F]O=%]T86<@/3T@(FAE860B*2!["@D)"6EF
M("AO=71P=712;V]T*0H)"0D):'1M;"`K/2`B/&AE860^(CL*"0D)+R\@;&]W
M97)C87-I>F4*"0D)=F%R('-A=F5?;75L=&EL:6YE(#T@4F5G17AP+FUU;'1I
M;&EN93L*"0D)4F5G17AP+FUU;'1I;&EN92`]('1R=64["@D)"79A<B!T>'0@
M/2!R;V]T+FEN;F5R2%1-3"YR97!L86-E*$A434Q!<F5A+E)%7W1A9TYA;64L
M(&9U;F-T:6]N*'-T<BP@<#$L('`R*2!["@D)"0ER971U<FX@<#$@*R!P,BYT
M;TQO=V5R0V%S92@I.PH)"0E]*3L*"0D)4F5G17AP+FUU;'1I;&EN92`]('-A
M=F5?;75L=&EL:6YE.PH)"0EH=&UL("L]('1X=#L*"0D):68@*&]U='!U=%)O
M;W0I"@D)"0EH=&UL("L]("(\+VAE860^(CL*"0D)8G)E86L["@D)?2!E;'-E
M(&EF("AO=71P=712;V]T*2!["@D)"6-L;W-E9"`]("@A*')O;W0N:&%S0VAI
M;&1.;V1E<R@I('Q\($A434Q!<F5A+FYE961S0VQO<VEN9U1A9RAR;V]T*2DI
M.PH)"0EH=&UL(#T@(CPB("L@<F]O="YT86=.86UE+G1O3&]W97)#87-E*"D[
M"@D)"79A<B!A='1R<R`](')O;W0N871T<FEB=71E<SL*"0D)9F]R("AI(#T@
M,#L@:2`\(&%T=')S+FQE;F=T:#L@*RMI*2!["@D)"0EV87(@82`](&%T=')S
M+FET96TH:2D["@D)"0EI9B`H(6$N<W!E8VEF:65D*2!["@D)"0D)8V]N=&EN
M=64["@D)"0E]"@D)"0EV87(@;F%M92`](&$N;F]D94YA;64N=&],;W=E<D-A
M<V4H*3L*"0D)"6EF("@O7VUO>E]E9&ET;W)?8F]G=7-?;F]D92\N=&5S="AN
M86UE*2D@>PH)"0D)"6AT;6P@/2`B(CL*"0D)"0EB<F5A:SL*"0D)"7T*"0D)
M"6EF("@O7VUO>GQC;VYT96YT961I=&%B;&5\7VUS:"\N=&5S="AN86UE*2D@
M>PH)"0D)"2\O(&%V;VED(&-E<G1A:6X@871T<FEB=71E<PH)"0D)"6-O;G1I
M;G5E.PH)"0D)?0H)"0D)=F%R('9A;'5E.PH)"0D):68@*&YA;64@(3T@(G-T
M>6QE(BD@>PH)"0D)"2\O($E%-2XU(')E<&]R=',@,C4@=VAE;B!C96QL4W!A
M8VEN9R!I<PH)"0D)"2\O(#$[(&]T:&5R('9A;'5E<R!M:6=H="!B92!D;V]M
M960@=&]O+@H)"0D)"2\O($9O<B!T:&ES(')E87-O;B!W92!E>'1R86-T('1H
M90H)"0D)"2\O('9A;'5E<R!D:7)E8W1L>2!F<F]M('1H92!R;V]T(&YO9&4N
M"@D)"0D)+R\@22=M('-T87)T:6YG('1O($A!5$4@2F%V85-C<FEP=`H)"0D)
M"2\O(&1E=F5L;W!M96YT+B`@0G)O=W-E<B!D:69F97)E;F-E<PH)"0D)"2\O
M('-U8VLN"@D)"0D)+R\*"0D)"0DO+R!5<VEN9R!'96-K;R!T:&4@=F%L=65S
M(&]F(&AR968@86YD('-R8R!A<F4@8V]N=F5R=&5D('1O(&%B<V]L=71E(&QI
M;FMS"@D)"0D)+R\@=6YL97-S('=E(&=E="!T:&5M('5S:6YG(&YO9&5686QU
M92@I"@D)"0D):68@*'1Y<&5O9B!R;V]T6V$N;F]D94YA;65=("$](")U;F1E
M9FEN960B("8F(&YA;64@(3T@(FAR968B("8F(&YA;64@(3T@(G-R8R(@)B8@
M(2]>;VXO+G1E<W0H;F%M92DI('L*"0D)"0D)=F%L=64@/2!R;V]T6V$N;F]D
M94YA;65=.PH)"0D)"7T@96QS92!["@D)"0D)"79A;'5E(#T@82YN;V1E5F%L
M=64["@D)"0D)"2\O($E%('-E96US(&YO="!W:6QL:6YG('1O(')E='5R;B!T
M:&4@;W)I9VEN86P@=F%L=65S("T@:70@8V]N=F5R=',@=&\@86)S;VQU=&4*
M"0D)"0D)+R\@;&EN:W,@=7-I;F<@82YN;V1E5F%L=64L(&$N=F%L=64L(&$N
M<W1R:6YG5F%L=64L(')O;W0N9V5T071T<FEB=71E*")H<F5F(BD*"0D)"0D)
M+R\@4V\@=V4@:&%V92!T;R!S=')I<"!T:&4@8F%S975R;"!M86YU86QL>2`Z
M+2\*"0D)"0D):68@*$A434Q!<F5A+FES7VEE("8F("AN86UE(#T](")H<F5F
M(B!\?"!N86UE(#T](")S<F,B*2D@>PH)"0D)"0D)=F%L=64@/2!E9&ET;W(N
M<W1R:7!"87-E55),*'9A;'5E*3L*"0D)"0D)?0H)"0D)"7T*"0D)"7T@96QS
M92![("\O($E%(&9A:6QS('1O('!U="!S='EL92!I;B!A='1R:6)U=&5S(&QI
M<W0*"0D)"0DO+R!&25A-13H@8W-S5&5X="!R97!O<G1E9"!B>2!)12!I<R!5
M4%!%4D-!4T4*"0D)"0EV86QU92`](')O;W0N<W1Y;&4N8W-S5&5X=#L*"0D)
M"7T*"0D)"6EF("@O*%]M;WI\7B0I+RYT97-T*'9A;'5E*2D@>PH)"0D)"2\O
M($UO>FEL;&$@<F5P;W)T<R!S;VUE('-P96-I86P@=&%G<PH)"0D)"2\O(&AE
M<F4[('=E(&1O;B=T(&YE960@=&AE;2X*"0D)"0EC;VYT:6YU93L*"0D)"7T*
M"0D)"6AT;6P@*ST@(B`B("L@;F%M92`K("<](B<@*R!V86QU92`K("<B)SL*
M"0D)?0H)"0EI9B`H:'1M;"`A/2`B(BD@>PH)"0D):'1M;"`K/2!C;&]S960@
M/R`B("\^(B`Z("(^(CL*"0D)?0H)"7T*"0EF;W(@*&D@/2!R;V]T+F9I<G-T
M0VAI;&0[(&D[(&D@/2!I+FYE>'13:6)L:6YG*2!["@D)"6AT;6P@*ST@2%1-
M3$%R96$N9V5T2%1-3%=R87!P97(H:2P@=')U92P@961I=&]R*3L*"0E]"@D)
M:68@*&]U='!U=%)O;W0@)B8@(6-L;W-E9"D@>PH)"0EH=&UL("L]("(\+R(@
M*R!R;V]T+G1A9TYA;64N=&],;W=E<D-A<V4H*2`K("(^(CL*"0E]"@D)8G)E
M86L["@D@("`@8V%S92`S.B`O+R!.;V1E+E1%6%1?3D]$10H)"2\O($EF(&$@
M=&5X="!N;V1E(&ES(&%L;VYE(&EN(&%N(&5L96UE;G0@86YD(&%L;"!S<&%C
M97,L(')E<&QA8V4@:70@=VET:"!A;B!N;VX@8G)E86MI;F<@;VYE"@D)+R\@
M5&AI<R!P87)T:6%L;'D@=6YD;V5S('1H92!D86UA9V4@9&]N92!B>2!M;WHL
M('=H:6-H('1R86YS;&%T97,@)R9N8G-P.R=S(&EN=&\@<W!A8V5S(&EN('1H
M92!D871A(&5L96UE;G0*"0DO*B!I9B`H("%R;V]T+G!R979I;W5S4VEB;&EN
M9R`F)B`A<F]O="YN97AT4VEB;&EN9R`F)B!R;V]T+F1A=&$N;6%T8V@H+UY<
M<RHD+VDI("D@:'1M;"`]("<F;F)S<#LG.PH)"2`@(&5L<V4@*B\*"0EH=&UL
M(#T@+UYS8W)I<'1\<W1Y;&4D+VDN=&5S="AR;V]T+G!A<F5N=$YO9&4N=&%G
M3F%M92D@/R!R;V]T+F1A=&$@.B!(5$U,07)E82YH=&UL16YC;V1E*')O;W0N
M9&%T82D["@D)8G)E86L["@D@("`@8V%S92`T.B`O+R!.;V1E+D-$051!7U-%
M0U1)3TY?3D]$10H)"2\O($9)6$U%.B!I="!S965M<R!W92!N979E<B!G970@
M:&5R92P@8G5T($D@8F5L:65V92!W92!S:&]U;&0N+@H)"2\O("`@("`@("!M
M87EB92!A(&)R;W=S97(@<')O8FQE;3\M+4-$051!('-E8W1I;VYS(&%R92!C
M;VYV97)T960@=&\@<&QA:6X@=&5X="!N;V1E<R!A;F0@;F]R;6%L:7IE9`H)
M"2\O($-$051!('-E8W1I;VYS('-H;W5L9"!G;R`B87,@:7,B('=I=&AO=70@
M9G5R=&AE<B!E;F-O9&EN9PH)"6AT;6P@/2`B/"%;0T1!5$%;(B`K(')O;W0N
M9&%T82`K(")=73XB.PH)"6)R96%K.PH)("`@(&-A<V4@.#H@+R\@3F]D92Y#
M3TU-14Y47TY/1$4*"0EH=&UL(#T@(CPA+2TB("L@<F]O="YD871A("L@(BTM
M/B(["@D)8G)E86L["0DO+R!S:VEP(&-O;6UE;G1S+"!F;W(@;F]W+@H)?0H)
M<F5T=7)N(&AT;6P["GT["@I(5$U,07)E82YG9710<F5V3F]D92`](&9U;F-T
M:6]N*&YO9&4I('L*"6EF("@A;F]D92D@("`@("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["@EI9B`H;F]D92YP<F5V:6]U<U-I8FQI;F<I(')E='5R;B!N;V1E
M+G!R979I;W5S4VEB;&EN9SL*"6EF("AN;V1E+G!A<F5N=$YO9&4I("`@("`@
M<F5T=7)N(&YO9&4N<&%R96YT3F]D93L*"7)E='5R;B!N=6QL.PI].PH*2%1-
M3$%R96$N9V5T3F5X=$YO9&4@/2!F=6YC=&EO;BAN;V1E*2!["@EI9B`H(6YO
M9&4I("`@("`@("`@("`@<F5T=7)N(&YU;&P["@EI9B`H;F]D92YN97AT4VEB
M;&EN9RD@<F5T=7)N(&YO9&4N;F5X=%-I8FQI;F<["@EI9B`H;F]D92YP87)E
M;G1.;V1E*2`@<F5T=7)N(&YO9&4N<&%R96YT3F]D93L*"7)E='5R;B!N=6QL
M.PI].PH*2%1-3$%R96$N<')O=&]T>7!E+G-T<FEP0F%S95523"`](&9U;F-T
M:6]N*'-T<FEN9RD@>PH)=F%R(&)A<V5U<FP@/2!T:&ES+F-O;F9I9RYB87-E
M55),.PH*"2\O('-T<FEP('1O(&QA<W0@9&ER96-T;W)Y(&EN(&-A<V4@8F%S
M975R;"!P;VEN=',@=&\@82!F:6QE"@EB87-E=7)L(#T@8F%S975R;"YR97!L
M86-E*"];7EPO72LD+RP@)R<I.PH)=F%R(&)A<V5R92`](&YE=R!296=%>'`H
M8F%S975R;"D["@ES=')I;F<@/2!S=')I;F<N<F5P;&%C92AB87-E<F4L("(B
M*3L*"@DO+R!S=')I<"!H;W-T+7!A<G0@;V8@55),('=H:6-H(&ES(&%D9&5D
M(&)Y($U3244@=&\@;&EN:W,@<F5L871I=F4@=&\@<V5R=F5R(')O;W0*"6)A
M<V5U<FP@/2!B87-E=7)L+G)E<&QA8V4H+UXH:'1T<',_.EPO7"];7EPO72LI
M*"XJ*20O+"`G)#$G*3L*"6)A<V5R92`](&YE=R!296=%>'`H8F%S975R;"D[
M"@ER971U<FX@<W1R:6YG+G)E<&QA8V4H8F%S97)E+"`B(BD["GT["@I3=')I
M;F<N<')O=&]T>7!E+G1R:6T@/2!F=6YC=&EO;B@I('L*"7)E='5R;B!T:&ES
M+G)E<&QA8V4H+UY<<RLO+"`G)RDN<F5P;&%C92@O7',K)"\L("<G*3L*?3L*
M"B\O(&-R96%T97,@82!R9V(M<W1Y;&4@8V]L;W(@9G)O;2!A(&YU;6)E<@I(
M5$U,07)E82Y?;6%K94-O;&]R(#T@9G5N8W1I;VXH=BD@>PH):68@*'1Y<&5O
M9B!V("$](")N=6UB97(B*2!["@D)+R\@86QR96%D>2!I;B!R9V(@*&AO<&5F
M=6QL>2D[($E%(&1O97-N)W0@9V5T(&AE<F4N"@D)<F5T=7)N('8["@E]"@DO
M+R!)12!S96YD<R!N=6UB97([(&-O;G9E<G0@=&\@<F=B+@H)=F%R('(@/2!V
M("8@,'A&1CL*"79A<B!G(#T@*'8@/CX@."D@)B`P>$9&.PH)=F%R(&(@/2`H
M=B`^/B`Q-BD@)B`P>$9&.PH)<F5T=7)N(")R9V(H(B`K('(@*R`B+"(@*R!G
M("L@(BPB("L@8B`K("(I(CL*?3L*"B\O(')E='5R;G,@:&5X861E8VEM86P@
M8V]L;W(@<F5P<F5S96YT871I;VX@9G)O;2!A(&YU;6)E<B!O<B!A(')G8BUS
M='EL92!C;VQO<BX*2%1-3$%R96$N7V-O;&]R5&]29V(@/2!F=6YC=&EO;BAV
M*2!["@EI9B`H(78I"@D)<F5T=7)N("<G.PH*"2\O(')E='5R;G,@=&AE(&AE
M>"!R97!R97-E;G1A=&EO;B!O9B!O;F4@8GET92`H,B!D:6=I=',I"@EF=6YC
M=&EO;B!H97@H9"D@>PH)"7)E='5R;B`H9"`\(#$V*2`_("@B,"(@*R!D+G1O
M4W1R:6YG*#$V*2D@.B!D+G1O4W1R:6YG*#$V*3L*"7T["@H):68@*'1Y<&5O
M9B!V(#T](")N=6UB97(B*2!["@D)+R\@=V4G<F4@=&%L:VEN9R!T;R!)12!H
M97)E"@D)=F%R('(@/2!V("8@,'A&1CL*"0EV87(@9R`]("AV(#X^(#@I("8@
M,'A&1CL*"0EV87(@8B`]("AV(#X^(#$V*2`F(#!X1D8["@D)<F5T=7)N("(C
M(B`K(&AE>"AR*2`K(&AE>"AG*2`K(&AE>"AB*3L*"7T*"@EI9B`H=BYS=6)S
M='(H,"P@,RD@/3T@(G)G8B(I('L*"0DO+R!I;B!R9V(H+BXN*2!F;W)M("TM
M($UO>FEL;&$*"0EV87(@<F4@/2`O<F=B7',J7"A<<RHH6S`M.5TK*5QS*BQ<
M<RHH6S`M.5TK*5QS*BQ<<RHH6S`M.5TK*5QS*EPI+SL*"0EI9B`H=BYM871C
M:"AR92DI('L*"0D)=F%R('(@/2!P87)S94EN="A296=%>'`N)#$I.PH)"0EV
M87(@9R`]('!A<G-E26YT*%)E9T5X<"XD,BD["@D)"79A<B!B(#T@<&%R<V5)
M;G0H4F5G17AP+B0S*3L*"0D)<F5T=7)N("(C(B`K(&AE>"AR*2`K(&AE>"AG
M*2`K(&AE>"AB*3L*"0E]"@D)+R\@9&]E<VXG="!M871C:"!213\A("!M87EB
M92!U<V5S('!E<F-E;G1A9V5S(&]R(&9L;V%T(&YU;6)E<G,*"0DO+R`M+2!&
M25A-13H@;F]T('EE="!I;7!L96UE;G1E9"X*"0ER971U<FX@;G5L;#L*"7T*
M"@EI9B`H=BYS=6)S='(H,"P@,2D@/3T@(B,B*2!["@D)+R\@86QR96%D>2!H
M97@@<F=B("AH;W!E9G5L;'D@.D0@*0H)"7)E='5R;B!V.PH)?0H*"2\O(&EF
M(&5V97)Y=&AI;F<@96QS92!F86EL<R`[*0H)<F5T=7)N(&YU;&P["GT["@HO
M+R!M;V1A;"!D:6%L;V=S(&9O<B!-;WII;&QA("AF;W(@244@=V4G<F4@=7-I
M;F<@=&AE('-H;W=-;V1A;$1I86QO9R@I(&-A;&PI+@H*+R\@<F5C96EV97,@
M86X@55),('1O('1H92!P;W!U<"!D:6%L;V<@86YD(&$@9G5N8W1I;VX@=&AA
M="!R96-E:79E<R!O;F4@=F%L=64["B\O('1H:7,@9G5N8W1I;VX@=VEL;"!G
M970@8V%L;&5D(&%F=&5R('1H92!D:6%L;V<@:7,@8VQO<V5D+"!W:71H('1H
M92!R971U<FX*+R\@=F%L=64@;V8@=&AE(&1I86QO9RX*2%1-3$%R96$N<')O
M=&]T>7!E+E]P;W!U<$1I86QO9R`](&9U;F-T:6]N*'5R;"P@86-T:6]N+"!I
M;FET*2!["@E$:6%L;V<H=&AI<RYP;W!U<%523"AU<FPI+"!A8W1I;VXL(&EN
M:70I.PI].PH*+R\@<&%T:',*"DA434Q!<F5A+G!R;W1O='EP92YI;6=54DP@
M/2!F=6YC=&EO;BAF:6QE+"!P;'5G:6XI('L*"6EF("AT>7!E;V8@<&QU9VEN
M(#T](")U;F1E9FEN960B*0H)"7)E='5R;B!?961I=&]R7W5R;"`K(&9I;&4[
M"@EE;'-E"@D)<F5T=7)N(%]E9&ET;W)?=7)L("L@(G!L=6=I;G,O(B`K('!L
M=6=I;B`K("(O:6UG+R(@*R!F:6QE.PI].PH*2%1-3$%R96$N<')O=&]T>7!E
M+G!O<'5P55),(#T@9G5N8W1I;VXH9FEL92D@>PH)=F%R('5R;"`]("(B.PH)
M:68@*&9I;&4N;6%T8V@H+UYP;'5G:6XZ7"]<+R@N*C\I7"\H+BHI+RDI('L*
M"0EV87(@<&QU9VEN(#T@4F5G17AP+B0Q.PH)"79A<B!P;W!U<"`](%)E9T5X
M<"XD,CL*"0EI9B`H(2]<+FAT;6PD+RYT97-T*'!O<'5P*2D*"0D)<&]P=7`@
M*ST@(BYH=&UL(CL*"0EU<FP@/2!?961I=&]R7W5R;"`K(")P;'5G:6YS+R(@
M*R!P;'5G:6X@*R`B+W!O<'5P<R\B("L@<&]P=7`["@E](&5L<V4*"0EU<FP@
M/2!?961I=&]R7W5R;"`K('1H:7,N8V]N9FEG+G!O<'5P55),("L@9FEL93L*
M"7)E='5R;B!U<FP["GT["@HO*BH*("H@1DE8.B!);G1E<FYE="!%>'!L;W)E
M<B!R971U<FYS(&%N(&ET96T@:&%V:6YG('1H92!?;F%M95\@97%U86P@=&\@
M=&AE(&=I=F5N"B`J(&ED+"!E=F5N(&EF(&ET)W,@;F]T(&AA=FEN9R!A;GD@
M:60N("!4:&ES('=A>2!I="!C86X@<F5T=7)N(&$@9&EF9F5R96YT(&9O<FT*
M("H@9FEE;&0@979E;B!I9B!I="=S(&YO="!A('1E>'1A<F5A+B`@5&AI<R!W
M;W)K87)O=6YD<R!T:&4@<')O8FQE;2!B>0H@*B!S<&5C:69I8V%L;'D@;&]O
M:VEN9R!T;R!S96%R8V@@;VYL>2!E;&5M96YT<R!H879I;F<@82!C97)T86EN
M('1A9R!N86UE+@H@*B\*2%1-3$%R96$N9V5T16QE;65N=$)Y260@/2!F=6YC
M=&EO;BAT86<L(&ED*2!["@EV87(@96PL(&DL(&]B:G,@/2!D;V-U;65N="YG
M971%;&5M96YT<T)Y5&%G3F%M92AT86<I.PH)9F]R("AI(#T@;V)J<RYL96YG
M=&@[("TM:2`^/2`P("8F("AE;"`](&]B:G-;:5TI.RD*"0EI9B`H96PN:60@
M/3T@:60I"@D)"7)E='5R;B!E;#L*"7)E='5R;B!N=6QL.PI].PH*"@HO+R!%
M3T8*+R\@3&]C86P@=F%R:6%B;&5S.B`O+PHO+R!C+6)A<VEC+6]F9G-E=#HX
M("\O"B\O(&EN9&5N="UT86)S+6UO9&4Z="`O+PHO+R!%;F0Z("\O"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:'1M
M;&%R96$N8W-S````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P-S(@,3`U,34T
M,S0Q-#0@,#(T-S4Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"YH=&UL87)E82![(&)A8VMG<F]U;F0Z("-F9F8[('T*"BYH
M=&UL87)E82`N=&]O;&)A<B!["B`@8W5R<V]R.B!D969A=6QT.PH@(&)A8VMG
M<F]U;F0Z($)U='1O;D9A8V4["B`@<&%D9&EN9SH@,W!X.PH@(&)O<F1E<CH@
M,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T=&]N2&EG:&QI9VAT($)U
M='1O;E-H861O=R!"=71T;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT.PI]"BYH
M=&UL87)E82`N=&]O;&)A<B!T86)L92![(&9O;G0M9F%M:6QY.B!T86AO;6$L
M=F5R9&%N82QS86YS+7-E<FEF.R!F;VYT+7-I>F4Z(#$Q<'@[('T*+FAT;6QA
M<F5A("YT;V]L8F%R(&EM9R![(&)O<F1E<CH@;F]N93L@?0HN:'1M;&%R96$@
M+G1O;VQB87(@+FQA8F5L('L@<&%D9&EN9SH@,'!X(#-P>#L@?0H*+FAT;6QA
M<F5A("YT;V]L8F%R("YB=71T;VX@>PH@(&)A8VMG<F]U;F0Z($)U='1O;D9A
M8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@8F]R9&5R.B`Q<'@@<V]L:60@
M0G5T=&]N1F%C93L*("!P861D:6YG.B`Q<'@["B`@;6%R9VEN.B`P<'@["B`@
M=VED=&@Z(#$X<'@["B`@:&5I9VAT.B`Q.'!X.PI]"BYH=&UL87)E82`N=&]O
M;&)A<B`N8G5T=&]N2&]V97(@>PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@(&)O
M<F1E<BUC;VQO<CH@0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=R!"=71T
M;VY3:&%D;W<@0G5T=&]N2&EG:&QI9VAT.PI]"BYH=&UL87)E82`N=&]O;&)A
M<B`N8G5T=&]N06-T:79E+"`N:'1M;&%R96$@+G1O;VQB87(@+F)U='1O;E!R
M97-S960@>PH@('!A9&1I;F<Z(#)P>"`P<'@@,'!X(#)P>#L*("!B;W)D97(Z
M(#%P>"!S;VQI9#L*("!B;W)D97(M8V]L;W(Z($)U='1O;E-H861O=R!"=71T
M;VY(:6=H;&EG:'0@0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=SL*?0HN
M:'1M;&%R96$@+G1O;VQB87(@+F)U='1O;E!R97-S960@>PH@(&)A8VMG<F]U
M;F0Z($)U='1O;DAI9VAL:6=H=#L*?0HN:'1M;&%R96$@+G1O;VQB87(@+FEN
M9&EC871O<B!["B`@<&%D9&EN9SH@,'!X(#-P>#L*("!O=F5R9FQO=SH@:&ED
M9&5N.PH@('=I9'1H.B`R,'!X.PH@('1E>'0M86QI9VXZ(&-E;G1E<CL*("!C
M=7)S;W(Z(&1E9F%U;'0["B`@8F]R9&5R.B`Q<'@@<V]L:60@0G5T=&]N4VAA
M9&]W.PI]"@HN:'1M;&%R96$@+G1O;VQB87(@+F)U='1O;D1I<V%B;&5D(&EM
M9R!["B`@9FEL=&5R.B!G<F%Y*"D@86QP:&$H;W!A8VET>2`](#(U*3L*("`M
M;6]Z+6]P86-I='DZ(#`N,C4["GT*"BYH=&UL87)E82`N=&]O;&)A<B`N<V5P
M87)A=&]R('L*("!P;W-I=&EO;CH@<F5L871I=F4["B`@;6%R9VEN.B`S<'@[
M"B`@8F]R9&5R+6QE9G0Z(#%P>"!S;VQI9"!"=71T;VY3:&%D;W<["B`@8F]R
M9&5R+7)I9VAT.B`Q<'@@<V]L:60@0G5T=&]N2&EG:&QI9VAT.PH@('=I9'1H
M.B`P<'@["B`@:&5I9VAT.B`Q-G!X.PH@('!A9&1I;F<Z(#!P>#L*?0H*+FAT
M;6QA<F5A("YT;V]L8F%R("YS<&%C92![('=I9'1H.B`U<'@[('T*"BYH=&UL
M87)E82`N=&]O;&)A<B!S96QE8W0@>R!F;VYT.B`Q,7!X(%1A:&]M82Q697)D
M86YA+'-A;G,M<V5R:68[('T*"BYH=&UL87)E82`N=&]O;&)A<B!S96QE8W0L
M"BYH=&UL87)E82`N=&]O;&)A<B!S96QE8W0Z:&]V97(L"BYH=&UL87)E82`N
M=&]O;&)A<B!S96QE8W0Z86-T:79E('L@8F%C:V=R;W5N9#H@1FEE;&1&86-E
M.R!C;VQO<CH@0G5T=&]N5&5X=#L@?0H*+FAT;6QA<F5A("YS=&%T=7-"87(@
M>PH@(&)O<F1E<CH@,7!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T=&]N
M4VAA9&]W($)U='1O;DAI9VAL:6=H="!"=71T;VY(:6=H;&EG:'0@0G5T=&]N
M4VAA9&]W.PH@('!A9&1I;F<Z(#)P>"`T<'@["B`@8F%C:V=R;W5N9"UC;VQO
M<CH@0G5T=&]N1F%C93L*("!C;VQO<CH@0G5T=&]N5&5X=#L*("!F;VYT.B`Q
M,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["GT*"BYH=&UL87)E82`N
M<W1A='5S0F%R("YS=&%T=7-"87)4<F5E(&$@>PH@('!A9&1I;F<Z(#)P>"`U
M<'@["B`@8V]L;W(Z(",P,&8["GT*"BYH=&UL87)E82`N<W1A='5S0F%R("YS
M=&%T=7-"87)4<F5E(&$Z=FES:71E9"![(&-O;&]R.B`C,#!F.R!]"BYH=&UL
M87)E82`N<W1A='5S0F%R("YS=&%T=7-"87)4<F5E(&$Z:&]V97(@>PH@(&)A
M8VMG<F]U;F0M8V]L;W(Z($AI9VAL:6=H=#L*("!C;VQO<CH@2&EG:&QI9VAT
M5&5X=#L*("!P861D:6YG.B`Q<'@@-'!X.PH@(&)O<F1E<CH@,7!X('-O;&ED
M($AI9VAL:6=H=%1E>'0["GT*"@HO*B!(:61D96X@1$E6('!O<'5P(&1I86QO
M9W,@*%!O<'5P1&EV*2`J+PH*+F1I86QO9R!["B`@8V]L;W(Z($)U='1O;E1E
M>'0["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*?0H*+F1I86QO9R`N8V]N
M=&5N="![('!A9&1I;F<Z(#)P>#L@?0H*+F1I86QO9RP@+F1I86QO9R!B=71T
M;VXL("YD:6%L;V<@:6YP=70L("YD:6%L;V<@<V5L96-T+"`N9&EA;&]G('1E
M>'1A<F5A+"`N9&EA;&]G('1A8FQE('L*("!F;VYT.B`Q,7!X(%1A:&]M82Q6
M97)D86YA+'-A;G,M<V5R:68["GT*"BYD:6%L;V<@=&%B;&4@>R!B;W)D97(M
M8V]L;&%P<V4Z(&-O;&QA<'-E.R!]"@HN9&EA;&]G("YT:71L92!["B`@8F%C
M:V=R;W5N9#H@(S`P.#L*("!C;VQO<CH@(V9F.#L*("!B;W)D97(M8F]T=&]M
M.B`Q<'@@<V]L:60@(S`P,#L*("!P861D:6YG.B`Q<'@@,'!X(#)P>"`U<'@[
M"B`@9F]N="US:7IE.B`Q,G!X.PH@(&9O;G0M=V5I9VAT.B!B;VQD.PH@(&-U
M<G-O<CH@9&5F875L=#L*?0H*+F1I86QO9R`N=&ET;&4@+F)U='1O;B!["B`@
M9FQO870Z(')I9VAT.PH@(&)O<F1E<CH@,7!X('-O;&ED(",V-F$["B`@<&%D
M9&EN9SH@,'!X(#%P>"`P<'@@,G!X.PH@(&UA<F=I;BUR:6=H=#H@,7!X.PH@
M(&-O;&]R.B`C9F9F.PH@('1E>'0M86QI9VXZ(&-E;G1E<CL*?0H*+F1I86QO
M9R`N=&ET;&4@+F)U='1O;BUH:6QI=&4@>R!B;W)D97(M8V]L;W(Z(",X.&8[
M(&)A8VMG<F]U;F0Z(",T-&,[('T*"BYD:6%L;V<@8G5T=&]N('L*("!W:61T
M:#H@-65M.PH@('!A9&1I;F<Z(#!P>#L*?0H*+F1I86QO9R`N8G5T=&]N0V]L
M;W(@>PH@('!A9&1I;F<Z(#%P>#L*("!C=7)S;W(Z(&1E9F%U;'0["B`@8F]R
M9&5R.B`Q<'@@<V]L:60["B`@8F]R9&5R+6-O;&]R.B!"=71T;VY(:6=H;&EG
M:'0@0G5T=&]N4VAA9&]W($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG:'0[
M"GT*"BYD:6%L;V<@+F)U='1O;D-O;&]R+6AI;&ET92!["B`@8F]R9&5R+6-O
M;&]R.B`C,#`P.PI]"@HN9&EA;&]G("YB=71T;VY#;VQO<B`N8VAO;W-E<BP@
M+F1I86QO9R`N8G5T=&]N0V]L;W(@+FYO8V]L;W(@>PH@(&AE:6=H=#H@,"XV
M96T["B`@8F]R9&5R.B`Q<'@@<V]L:60["B`@<&%D9&EN9SH@,'!X(#%E;3L*
M("!B;W)D97(M8V]L;W(Z($)U='1O;E-H861O=R!"=71T;VY(:6=H;&EG:'0@
M0G5T=&]N2&EG:&QI9VAT($)U='1O;E-H861O=SL*?0H*+F1I86QO9R`N8G5T
M=&]N0V]L;W(@+FYO8V]L;W(@>R!P861D:6YG.B`P<'@[('T*+F1I86QO9R`N
M8G5T=&]N0V]L;W(@+FYO8V]L;W(M:&EL:71E('L@8F%C:V=R;W5N9"UC;VQO
M<CH@(V9F9CL@8V]L;W(Z("-F,#`[('T*"BYD:6%L;V<@+FQA8F5L('L@=&5X
M="UA;&EG;CH@<FEG:'0[('=I9'1H.B`V96T[('T*+F1I86QO9R`N=F%L=64@
M:6YP=70@>R!W:61T:#H@,3`P)3L@?0HN9&EA;&]G("YB=71T;VYS('L@=&5X
M="UA;&EG;CH@<FEG:'0[('!A9&1I;F<Z(#)P>"`T<'@@,'!X(#1P>#L@?0H*
M+F1I86QO9R!L96=E;F0@>R!F;VYT+7=E:6=H=#H@8F]L9#L@?0HN9&EA;&]G
M(&9I96QD<V5T('1A8FQE('L@;6%R9VEN.B`R<'@@,'!X.R!]"@HN<&]P=7!D
M:78@>PH@(&)O<F1E<CH@,G!X('-O;&ED.PH@(&)O<F1E<BUC;VQO<CH@0G5T
M=&]N2&EG:&QI9VAT($)U='1O;E-H861O=R!"=71T;VY3:&%D;W<@0G5T=&]N
M2&EG:&QI9VAT.PI]"@HN<&]P=7!W:6X@>PH@('!A9&1I;F<Z(#!P>#L*("!M
M87)G:6XZ(#!P>#L*?0H*+G!O<'5P=VEN("YT:71L92!["B`@8F%C:V=R;W5N
M9#H@(V9F9CL*("!C;VQO<CH@(S`P,#L*("!F;VYT+7=E:6=H=#H@8F]L9#L*
M("!F;VYT+7-I>F4Z(#$R,"4["B`@<&%D9&EN9SH@,W!X(#$P<'@["B`@;6%R
M9VEN+6)O='1O;3H@,3!P>#L*("!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@
M8FQA8VL["B`@;&5T=&5R+7-P86-I;F<Z(#)P>#L*?0H*9F]R;2![(&UA<F=I
M;CH@,'!X.R!B;W)D97(Z(&YO;F4[('T*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?86QI
M9VY?;&5F="YG:68````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$P-2`Q,#4Q-30S-#$T,R`P,C<Q
M-#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(<C(^IR^T!
MHISS/4JMAKAOUDG?%69C4@+GRK9(`0`[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V
M:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VMI;&QW;W)D+F=I9@``
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`R,S(@,3`U,34T,S0Q-#,@,#(V-C<Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=)1C@Y81(`$@#"
M!@```````/__``!-34VJJJK_Z,W_______\A^00!"@`'`"P!````$``2```#
M7WBZW$PP2D>,O98,%4#_'I`9FXA=@36L`^@"16P40VAXQF<5,YYVMP)L-JO=
M7#F>T@?S\&`RH8AI$5P$M-3)`L!:I2^=M;>H8`I>LL)\O=+*L;@\!BC7:@!\
M'E!W^!4)`#L`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+VEM86=E<R]E9%]C=7-T;VTN9VEF````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,3`S(#$P-3$U-#,T,30S(#`R-C,U,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$2`!(`@`$`````____(?D$
M`0```0`L`````!(`$@```AJ,CZG+[0_C`D`&2B6N<=O\<=9XB9U)INIJ%``[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I
M;6%G97,O961?8FQA;FLN9VEF````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`W,"`Q,#4Q
M-30S-#$T,R`P,C8Q,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````1TE&.#EA$@`2`(```/___P```"'Y!`$`````+``````2
M`!(```(/A(^IR^T/HYRTVHNSWIP7`#L`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEN
M9&5N=%]L97-S+F=I9@``````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,C<@,3`U,34T,S0Q-#,@,#(W
M,S4T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`$=)1C@Y81(`$@"1`@```(0```#___\````A^00!```"`"P`````$@`2```"
M*)2/J1GKKX)LLTJ(!4"V'K`=W62`9E:&1K>H`HMBWGC%R]S8^KKW4`$`.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R
M=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]I;F1E;G1?;6]R92YG
M:68``````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,3(W(#$P-3$U-#,T,30S(#`R-S,U,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!'248X.6$2`!(`
MD0(```"$````____````(?D$`0```@`L`````!(`$@```BB4CZD9ZZ^";+-*
MB`5`MB*P&=UD@&9V@$>WA**%9MYXQ<O<V+JX]U`!`#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]I;6%G97,O961?86QI9VY?:G5S=&EF>2YG:68`````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#$P-2`Q,#4Q-30S-#$T,R`P,C<W,3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````1TE&.#EA$@`2`(`!`````/___R'Y
M!`$```$`+``````2`!(```(<C(^IR^T!HISS/8JE=3GOUF$?$U+C4E;GRK9'
M`0`[````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M:6UA9V5S+V5D7V9O<FUA=%]I=&%L:6,N9VEF````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,34@,3`U
M,34T,S0Q-#,@,#(W-C4W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````$=)1C@Y81(`$@"1`P![>WN$A(0```#___\A^00!```#
M`"P`````$@`2```"'IR/J<OM#XV8,XX9+*AV`LU%'BA8E_!!%&6V[@M'!0`[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C
M:&%R;6%P+F=I9@```````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C$W(#$P-3$U-#,T,30S(#`R
M-C0V,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!'248X.6$2`!(`H@<`@`"`P,#`@("`_P````#_````________(?D$`0``
M!P`L`````!(`$@```U1XNMS>(CX7@Y6SAL&OH,;%#8(5?(P0>J5E&.C1OJ8+
M"\52$D1`OP)`)"<S$6:1H)"X._9\$8`0IVA9CM#H4&?MW9(%(M?T#4]D)9CY
MS!6SW_`X/`$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O9G5L;'-C<F5E;E]M:6YI
M;6EZ92YG:68````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#$T,2`Q,#4Q-30S-#$T,R`P,S`T,S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`(`!`````/___R'Y!`$```$`+``````2`!(```(XC(^I".V_`HASU=.D>8[E
M>FU8II781I83N::J='6,R+JB]N4<#9U):POQ."L%<"<T68S$7>29*```.P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O:6UA9V5S+V5D7W!A<W1E+F=I9@``````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`R,3,@,3`U,34T,S0Q-#,@,#(V,34U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@"B!@"`@`"`@(``
M`(#__P#___\```#___\````A^00!```&`"P`````$@`2```#4&BZW/[0E5FB
MH7,,7%D!`5!L8Q$&G6*B4IA>($<%[&*"^(F_GR[\0`%/%Q`0CL>?)P<P(@E&
M@8T8_4&!*J;SF511KT&H#;/E2A_!]-G";BL2`#L`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+VEM86=E<R]E9%]C=70N9VEF````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3,S(#$P
M-3$U-#,T,30S(#`R-38S-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`D0(```"`````____````(?D$`0``
M`@`L`````!(`$@```BR4CZG+&_<:G-)$<65XN\Y<;6#H(4``E$8*M%7+KDTJ
MQ/4LT_2BKSOC4@F'!0`[````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?
M<VAO=U]B;W)D97(N9VEF```````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$U,"`Q,#4Q-30S-#$T-"`P
M,C<S-3<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`)$"```SF0```/___P```"'Y!`$```(`+``````2`!(`
M``(YE(^IR^T/8YBTVF`"V+QW+&C>N($8&![HE*7M&YIG.I\LK>:9Z?:KC*O%
M>"M=K%6$W5C"VO("914``#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7W)E9&\N9VEF````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`Q,C`@,3`U,34T,S0Q-#0@,#(U-S<P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@"1`@"`@(```(#___\````A^00!```"`"P`````$@`2```"(92/J<OM[T"8
M`4HT3TV;B^PME-)A8W*9)P=`[@O'\DR_!0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L:6YK+F=I9@``````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,30Q(#$P-3$U-#,T,30T(#`R-3<W-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`D0``____@("`
M````____(?D$!10``P`L`````!(`$@```C*<CZG+[0_C"*)68VLX%(!3>>`V
M"%^&"A@&J.9G4.5,I]DZJ9R&"&1^*V5^DJ+QB$PR"@`[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]I;6%G97,O961?:&5L<"YG:68`````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$P-B`Q
M,#4Q-30S-#$T-"`P,C4W-S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`+```
M```2`!(```(=C(^IR^T/`Y@@3G-?SE'6SD&A^'7F,6KER;;N4@``.P``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D
M7V9O<FUA=%]B;VQD+F=I9@``````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,3(@,3`U,34T,S0Q-#0@
M,#(W,S,P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````$=)1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```"(8R/
MJ<OM_X"<,M8P7<:7[>U170@8X/*-2EJ2(@3'\DPS!0`[````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]L969T7W1O7W)I
M9VAT+F=I9@```````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,3,Q(#$P-3$U-#,T,30T(#`R-S8W,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!'248X.6$2
M`!(`D0(`!`*$````____````(?D$`0```@`L`````!(`$@```BJ4CZG+[0]3
MF`R@&41>P!JL5=U';4HW:IF9H%?(><=:*704LL^-]_X/*0``.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]I;6%G97,O961?=6YD;RYG:68`````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#$R,2`Q,#4Q-30S-#$T-"`P,C8P,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````1TE&.#EA$@`2`)$"`("`@```
M@/___P```"'Y!`$```(`+``````2`!(```(BE(^IR^T/8PLT@!4.15;M['D;
M)HX)R%6HT4G`*L7R3-=,`0`[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O:6UA9V5S+V5D7V9O<FUA=%]S=6(N9VEF````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,38@
M,3`U,34T,S0Q-#0@,#(W,C`U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$=)1C@Y81(`$@"1`@```(````#___\````A^00!
M```"`"P`````$@`2```"'Y2/J<OM[T(P$@I9[9T:\Y=5`*`A9'EJJ3J6[@O'
M30$`.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]I
M;G-E<G1?=&%B;&4N9VEF`````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<Q(#$P-3$U-#,T,30T
M(#`R-S`U,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!'248X.6$2`!(`H@``____S,S,`#.9````____````````````(?D$
M!10`!``L`````!(`$@```SY(NMS^D(Q)JQUJB,U[QY(G<N``!$"*JNE9GNT*
MJV5@WSC^RGR\QT!:)D>\_5A(5V;&Y-6*Q-)E.HE8K]AL`@`[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?9F]R;6%T7W-U
M<"YG:68````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#$Q-2`Q,#4Q-30S-#$T-"`P,C<R,C(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1TE&.#EA
M$@`2`)$"`(```````/___P```"'Y!`$```(`+``````2`!(```(>E(^IRVT`
M'(L2T?JPA2P$XV%>J)'B>(*?QK;N"[<%`#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VEM86=E+F=I9@``````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`R,C0@,3`U,34T,S0Q-#0@,#(V,3(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81(`$@"B!P``@`"`
M``"`@`"`@(#__P``__\```#___\A^00!```'`"P`````$@`2```#67BZW/Y0
MF4&KI8:-(+CO8+8,@F&>:"`J6U8<+R$?I5:^^$$HJM:_`YBP-KH=@I1"L#?J
M!5E((JOT/!XI3%:@>B&MC@+`04P>MWR`M'HM!7_>G2]J/H_8[Y`$`#L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+VEM86=E<R]E9%]H<BYG:68`````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3`V
M(#$P-3$U-#,T,30T(#`R-30U-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$2`!(`D0(`,S,SF9F9____````(?D$
M`0```@`L`````!(`$@```A>4CZG+[0^CG+2!B[,^H?L/5N)(EN:I%``[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O
M961?<FEG:'1?=&]?;&5F="YG:68````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$S,"`Q,#4Q-30S-#$T
M-"`P,C<V-S$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````1TE&.#EA$@`2`)$"``0"A````/___P```"'Y!`$```(`+``````2
M`!(```(IE(^IR^W_@@QP"HK`LM@`K7#'!X841I;A-7[-F:D)G+TL9-#XSO=^
M4@``.P``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7VAT;6PN9VEF
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`Q,3,@,3`U,34T,S0Q-#0@,#(V,#`U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$=)1C@Y
M81(`$@"``0````#___\A^00!```!`"P`````$@`2```"(HR/J<OM#P$P\M5S
M5\93;?1]2=AY)7A2*<HZEPC%\DS71P$`.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]S879E+F=I9@``````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,C$W(#$P-3$U-#,T,30T(#`R-C`P-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`H@4`W-S<
M@("`@(``____````____````````(?D$`0``!0`L`````!(`$@```U18NMS^
M4)%)*VU$D,'[(`41,-GF<50`+.6):BJKN1^\2K-;QKAF93:98$@LBFZAX6\2
M[$T"$]Q1**I*>4D?%)2<*K;+%+(`")C/:/-8`6B[W^V(/`$`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]I;6%G97,O961?9F]R;6%T7W-T<FEK92YG:68`````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$Q
M-B`Q,#4Q-30S-#$T-"`P,C<W,34`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$@`2`(`!`````/___R'Y!`$```$`
M+``````2`!(```(EC(^IR^T*(@C3Q7-M-9M)_%!9(Y5F^#U;2B*CMW;+5(;V
MC>=,`0`[````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S
M+V5D7V1E;&5T92YG:68`````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,S(@,3`U,34T,S0Q
M-#0@,#(V,S`T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@"1``#___\```#___\````A^00%%``"`"P`````
M$@`2```"*Y2/J<OM%@)@<9Y84];8BKUTG]=@H",^GTF&V<E)EZRD5PO!8XBK
M5.\+'@H`.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C;VQO<E]B
M9RYG:68``````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,C8U(#$P-3$U-#,T,30T(#`R-C8S-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`LPL``(0``'L`A(2$>WM[_P#_`/___P``__\```#_____````____
M````````````````(?D$`0``"P`L`````!(`$@``!&)PR4FKE4K=K?.VGO=-
M6J((VEB:RY"EU;HH@U`/.(XM28()AN"@0!Q@>B1@4$`L&'<2G&UZ$U`TM=-A
M*P@``D^2J[4]#+Z`,"DJF+H_`X1\0*BK*P(Y0E`GW"E25#8CA(44$0`[````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?86)O=70N9VEF````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#$R-R`Q,#4Q-30S-#$T-"`P,C8Q-C``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`(`!````
M`/___R'Y!`$```$`+``````2`!(```(NC(^)P.T/3%1T3IJL8EON>VA8YBT<
M&8"2FI9FUV:L^*+S[(9X/(9Y;X$(3SU*`0`[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O:6UA9V5S+V5D7VQI<W1?8G5L;&5T+F=I9@``````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q
M,C`@,3`U,34T,S0Q-#0@,#(W,S8Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$=)1C@Y81(`$@"1`@```(0```#___\````A
M^00!```"`"P`````$@`2```"(92/J<L&W]0#)MA[T8R\^[1](49JT(>FX.F-
M9':$ZDQS!0`[````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+VEM86=E
M<R]E9%]C;VQO<E]F9RYG:68`````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C4S(#$P-3$U-#,T
M,30T(#`R-C8T,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!'248X.6$2`!(`LPH``(0``'L`A(2$>WM[_P#_`/___P``__\`
M``#_````____````````````````````(?D$`0``"@`L`````!(`$@``!%A0
MR4DK33AK*]/$'Z=X'3F*EXFFJP4.<!R[WF#<0Z$/M&+?`EV!5WD)!#`DDC+0
M"`Y000`0('(&T,.`"K!:!D>P4H`:(,X#@MI;$9P1`C6!S12#[ZV\7A$!`#L`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G97,O961?86QI9VY?
M<FEG:'0N9VEF```````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$P-"`Q,#4Q-30S-#$T-"`P,C<S,S``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````1TE&
M.#EA$@`2`(`!`````/___R'Y!`$```$`+``````2`!(```(;C(^IR^T!HISS
MV4/I;;F#;7D1N(@:R8GHRK8%`#L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E
M<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V9O<FUA=%]U;F1E<FQI;F4N
M9VEF````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`Q,C4@,3`U,34T,S0Q-#0@,#,P-#`Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````$=)1C@Y81(`$@"1`@![
M>WL```#___\````A^00!```"`"P`````$@`2```")I2/J<OM_X(,8M(F3W:[
M7OQU3"<NY#>&J!D``E"R$T0CUEWG.ET``#L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT
M;6QA<F5A+VEM86=E<R]F=6QL<V-R965N7VUA>&EM:7IE+F=I9@``````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,30Q(#$P-3$U-#,T,30T(#`S,#0S-P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!'248X.6$2`!(`@`$`````____(?D$`0``
M`0`L`````!(`$@```CB,CZD&[=\46&>F"5VP<&?,5)?&B=6SA:J'@:FJ>:^5
MQG)YTO=J7W#TB=2$"%V(6)105KF@<;DL```[````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]I;6%G
M97,O961?<FUF;W)M870N9VEF````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$V-B`Q,#4Q-30S
M-#$T-"`P,C8W,#``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````1TE&.#EA$@`2`/(%`````!D``&9F9LS,S/___P``````````
M`"'Y!`$```4`+``````2`!(```,[6+K<_C#*29<`&`@AP2#?,`"1!YX79(:$
M1CKKJ6TP^\TO$]];;GDB$>X!#(Y21*/0U[AD,)R*=$I=)```.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA9V5S+V5D7V%L:6=N
M7V-E;G1E<BYG:68`````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q,#4@,3`U,34T,S0Q-#0@,#(W-#<T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$=)
M1C@Y81(`$@"``0````#___\A^00!```!`"P`````$@`2```"'(R/J<OM`:*<
M\UE(ZW6Y@\UY'\B(%%F*Z,JV1@$`.P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+VEM86=E<R]E9%]C;W!Y+F=I9@``````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,34V(#$P-3$U-#,T,30T(#`R-C`R,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!'248X.6$2`!(`D0,`
M``"`````________(?D$`0```P`L`````!(`$@```C^<CZG+%@_;":**)P>U
M-,C>`>*H;!9@"6("/NBI(F:%/BKI7-";QGE:@U``$V&`!VP$(;X%\J0<28F9
MJO6**```.P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]I;6%G97,O961?;&ES=%]N=6TN9VEF````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#$R,B`Q,#4Q-30S-#$T-"`P,C8V-S,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`)$"````A````/___P``
M`"'Y!`$```(`+``````2`!(```(CE(^IRPB]P#.A6ILF=')[V'T.=5V9:$@:
MBJJL5IJG&+*V6```.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O:6UA
M9V5S+V5D7W-P;&ET8V5L+F=I9@``````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,3<@,3`U,34T
M,S0Q-#0@,#(V-C8U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````$=)1C@Y81<`%@"B!````(``______\```#___\`````````
M```A^00!```$`"P`````%P`6```#5$BZW/XPRDFKG2/KS<<;@@"&X4AZSFB6
M9/EU</:5@1``]9VCC6H+@%^PQF.H`,BD$E!<;(10XDR4P]FL@:;BN%QJ":JJ
MV/;UU8;`7SD&N[C?\'@E`0`[````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!O<'5P<R]F=6QL<V-R
M965N+FAT;6P``````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-S8P(#$P-3$U-#,T,30S(#`R-S`R
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M(41/0U194$4@:'1M;"!054),24,@(BTO+U<S0R\O1%1$(%A(5$U,(#$N,2\O
M14XB(")H='1P.B\O=W=W+G<S+F]R9R]44B]X:'1M;#$Q+T141"]X:'1M;#$Q
M+F1T9"(^"CQH=&UL/@H@(#QH96%D/@H@("`@/'1I=&QE/D9U;&QS8W)E96X@
M2%1-3$%R96$\+W1I=&QE/@H@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/@H@("`@("!?961I=&]R7W5R;"`]('=I;F1O=RYO<&5N97(N7V5D
M:71O<E]U<FP@?'P@)RXN+R<["B`@("`@(%]E9&ET;W)?;&%N9R`]('=I;F1O
M=RYO<&5N97(N7V5D:71O<E]L86YG.PH@("`@("!?961I=&]R7V-S<R`]('=I
M;F1O=RYO<&5N97(N7V5D:71O<E]C<W,["B`@("`@('9A<B!"05-%(#T@=VEN
M9&]W+F]P96YE<BYD;V-U;65N="YB87-E55))('Q\('=I;F1O=RYO<&5N97(N
M9&]C=6UE;G0N55),.PH@("`@("!V87(@:&5A9"`](&1O8W5M96YT+F=E=$5L
M96UE;G1S0GE486=.86UE*")H96%D(BE;,%T["B`@("`@('9A<B!B87-E(#T@
M9&]C=6UE;G0N8W)E871E16QE;65N="@B8F%S92(I.PH@("`@("!B87-E+FAR
M968@/2!"05-%.PH@("`@("!H96%D+F%P<&5N9$-H:6QD*&)A<V4I.PH@("`@
M/"]S8W)I<'0^"@H@("`@/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B
M/@H@("`@("`@(&1O8W5M96YT+G=R:71E*"<\<V-R)R`K("=I<'0@='EP93TB
M=&5X="]J879A<V-R:7!T(B!S<F,](B<@*R!?961I=&]R7W5R;"`K("=H=&UL
M87)E82YJ<R(^/"]S8W(G("L@)VEP=#XG*3L*("`@(#PO<V-R:7!T/@H@("`@
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H)+R\@;&]A9"!(5$U,
M07)E82!S8W)I<'1S('1H870@87)E('!R97-E;G0@:6X@=&AE(&]P96YE<B!F
M<F%M90H)=F%R('-C<FEP=',@/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A+E]S
M8W)I<'1S.PH)9F]R("AV87(@:2`](#,[(&D@/"!S8W)I<'1S+FQE;F=T:#L@
M*RMI*2!["B`@("`@("`@("`@+R]D;V-U;65N="YW<FET92@B/'-C<B(@*R`B
M:7!T('1Y<&4])W1E>'0O:F%V87-C<FEP="<@<W)C/2<B("L@<V-R:7!T<UMI
M72`K("(G/CPO<V-R(B`K(")I<'0^(BD["B`@("`@("`@("`@2%1-3$%R96$N
M;&]A9%-C<FEP="AS8W)I<'1S6VE=*3L*("`@("`@("!]"B`@("`\+W-C<FEP
M=#X*"B`@("`\(2TM(&)R;W=S97(@=&%K97,@82!C;V9F964@8G)E86L@:&5R
M92`M+3X*("`@(#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*=F%R
M('!A<F5N=%]O8FIE8W0@(#T@;G5L;#L*=F%R(&5D:71O<@D@("`](&YU;&P[
M"2\O('1O(&)E(&EN:71I86QI>F5D(&QA=&5R(%L@9G5N8W1I;VX@:6YI="@I
M(%T*"B\J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@*EP*("`@1G5N8W1I
M;VX@("`@.@H@("!$97-C<FEP=&EO;B`Z"EPJ("TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T@*B\*"F9U;F-T:6]N(%]#;&]S94]N17-C*&5V*2!["@EE=B!\
M?"`H978@/2!W:6YD;W<N979E;G0I('Q\("AE=B`](&5D:71O<BY?:69R86UE
M+F-O;G1E;G17:6YD;W<N979E;G0I.PH):68@*&5V+FME>4-O9&4@/3T@,C<I
M('L*"0DO+R!U<&1A=&5?<&%R96YT*"D["@D)=VEN9&]W+F-L;W-E*"D["@D)
M<F5T=7)N.PH)?0I]"@HO*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM("I<
M"B`@($9U;F-T:6]N("`@(#H@<F5S:7IE7V5D:71O<@H@("!$97-C<FEP=&EO
M;B`Z(')E<VEZ92!T:&4@961I=&]R('=H96X@=&AE('5S97(@<F5S:7IE<R!T
M:&4@<&]P=7`*7"H@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J+PH*9G5N
M8W1I;VX@<F5S:7IE7V5D:71O<B@I('L@("\O(')E<VEZ92!E9&ET;W(@=&\@
M9FEX('=I;F1O=PH*("!V87(@;F5W2&5I9VAT.PH@(&EF("AD;V-U;65N="YA
M;&PI('L@+R\@244*("`@(&YE=TAE:6=H="`](&1O8W5M96YT+F)O9'DN;V9F
M<V5T2&5I9VAT("T@961I=&]R+E]T;V]L8F%R+F]F9G-E=$AE:6=H=#L*("`@
M(&EF("AN97=(96EG:'0@/"`P*2![(&YE=TAE:6=H="`](#`[('T*("!](&5L
M<V4@>R`O+R!'96-K;PH@("`@;F5W2&5I9VAT(#T@=VEN9&]W+FEN;F5R2&5I
M9VAT("T@961I=&]R+E]T;V]L8F%R+F]F9G-E=$AE:6=H=#L*("!]"B`@:68@
M*&5D:71O<BYC;VYF:6<N<W1A='5S0F%R*2!["B`@("!N97=(96EG:'0@+3T@
M961I=&]R+E]S=&%T=7-"87(N;V9F<V5T2&5I9VAT.PH@('T*"B`@+R\@5$]$
M3SH@22=M(&YO="!S=7)E(&5X86-T;'D@=VAA="!T:&5S92!A<F4@861J=7-T
M:6YG(&9O<BP@8G5T(&EF"B`@+R\@>6]U(&1O;B=T(&%D:G5S="!T:&4@:&5I
M9VAT(&9O<B!)12!T:&5N(&1O8W5M96YT+F)O9'DN;V9F<V5T2&5I9VAT"B`@
M+R\@=VEL;"!G970@;&%R9V5R(&5V97)Y('1I;64@86YD('1H92`H<&]P=7`I
M(&5D:71O<B!W:6QL(&=E="!S='5C:PH@("\O(&EN(&$@=&EG:'0@;&]O<"!A
M;F0@=&AE(&)R;W=S97(@=V]N)W0@8F4@<F5S<&]N<VEV92X@($EN(&9U='5R
M92!W92=L;`H@("\O('=A;G0@=&\@9V5T('1H97-E(&UE87-U<F5M96YT<R!D
M>6YA;6EC86QL>2!I;B!C87-E(&5L96UE;G1S(&-H86YG92!S:7IE"B`@+R\@
M:6X@=&AE(&9U='5R92X*"B`@:68@*$A434Q!<F5A+FES7V=E8VMO*2![(&YE
M=TAE:6=H="`M/2`X.R!]"B`@96QS92`@("`@("`@("`@("`@("`@("![(&YE
M=TAE:6=H="`M/2`Q,#L@?0H*("`O+R!A9&IU<W0@96QE;65N="!H96EG:'0*
M("!V87(@;F5W2&5I9VAT5VET:%!X(#T@;F5W2&5I9VAT("L@(G!X(CL*("!E
M9&ET;W(N7W1E>'1!<F5A+G-T>6QE+FAE:6=H="`](&YE=TAE:6=H=%=I=&A0
M>#L*("!E9&ET;W(N7VEF<F%M92YS='EL92YH96EG:'0@("`](&YE=TAE:6=H
M=%=I=&A0>#L*?0H*+RH@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2`J7`H@
M("!&=6YC=&EO;B`@("`Z(&EN:70*("`@1&5S8W)I<'1I;VX@.B!R=6X@=&AI
M<R!C;V1E(&]N('!A9V4@;&]A9`I<*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM("HO"@IF=6YC=&EO;B!I;FET*"D@>PH)<&%R96YT7V]B:F5C=`D@("`]
M(&]P96YE<BY(5$U,07)E82Y?;V)J96-T.PH)=F%R(&-O;F9I9PD@("`]($A4
M34Q!<F5A+F-L;VYE3V)J96-T*"!P87)E;G1?;V)J96-T+F-O;F9I9R`I.PH)
M8V]N9FEG+G=I9'1H"2`@(#T@(C$P,"4B.PH)8V]N9FEG+FAE:6=H=`D@("`]
M(")A=71O(CL*"@DO+R!C:&%N9V4@;6%X:6UI>F4@8G5T=&]N('1O(&UI;FEM
M:7IE(&)U='1O;@H)8V]N9FEG+F)T;DQI<W1;(G!O<'5P961I=&]R(ET@/2!;
M("=-:6YI;6EZ92!%9&ET;W(G+"!?961I=&]R7W5R;"`K("=I;6%G97,O9G5L
M;'-C<F5E;E]M:6YI;6EZ92YG:68G+"!T<G5E+`H)"0D)"2`@9G5N8W1I;VXH
M*2![('=I;F1O=RYC;&]S92@I.R!](%T["@H)+R\@9V5N97)A=&4@961I=&]R
M(&%N9"!R97-I>F4@:70*"65D:71O<B`](&YE=R!(5$U,07)E82@B961I=&]R
M(BP@8V]N9FEG*3L*"@DO+R!R96=I<W1E<B!T:&4@<&QU9VEN<RP@:68@86YY
M"@EF;W(@*'9A<B!I(&EN('!A<F5N=%]O8FIE8W0N<&QU9VEN<RD@>PH)"79A
M<B!P;'5G:6X@/2!P87)E;G1?;V)J96-T+G!L=6=I;G-;:5T["@D)=')Y('L*
M"0D)979A;"AP;'5G:6XN;F%M92D["@D)"65D:71O<BYR96=I<W1E<E!L=6=I
M;C(H<&QU9VEN+FYA;64L('!L=6=I;BYA<F=S*3L*"0E](&-A=&-H*&4I('M]
M.PH)?0H)+R\@86YD(')E<W1O<F4@=&AE(&]R:6=I;F%L('1O;VQB87(*("`@
M("`@("!C;VYF:6<N=&]O;&)A<B`]('!A<F5N=%]O8FIE8W0N8V]N9FEG+G1O
M;VQB87(["@EE9&ET;W(N9V5N97)A=&4H*3L*"65D:71O<BY?:69R86UE+G-T
M>6QE+G=I9'1H(#T@(C$P,"4B.PH)961I=&]R+E]T97AT07)E82YS='EL92YW
M:61T:"`]("(Q,#`E(CL*"7)E<VEZ95]E9&ET;W(H*3L*"@EE9&ET;W(N9&]C
M='EP92`]('!A<F5N=%]O8FIE8W0N9&]C='EP93L*"@DO+R!S970@8VAI;&0@
M=VEN9&]W(&-O;G1E;G1S(&%N9"!E=F5N="!H86YD;&5R<RP@869T97(@82!S
M;6%L;"!D96QA>0H)<V5T5&EM96]U="AF=6YC=&EO;B@I('L*"0D)("`@961I
M=&]R+G-E=$A434PH<&%R96YT7V]B:F5C="YG971);FYE<DA434PH*2D["@H)
M"0D@("`O+R!S=VET8V@@;6]D92!I9B!N965D960*"0D)("`@:68@*'!A<F5N
M=%]O8FIE8W0N7VUO9&4@/3T@(G1E>'1M;V1E(BD@>R!E9&ET;W(N<V5T36]D
M92@B=&5X=&UO9&4B*3L@?0H*"0D)("`@+R\@8V]N=&EN=6]U<VQY('5P9&%T
M92!P87)E;G0@961I=&]R('=I;F1O=PH)"0D@("!S971);G1E<G9A;"AU<&1A
M=&5?<&%R96YT+"`U,#`I.PH*"0D)("`@+R\@<V5T=7`@979E;G0@:&%N9&QE
M<G,*"0D)("`@9&]C=6UE;G0N8F]D>2YO;FME>7!R97-S(#T@7T-L;W-E3VY%
M<V,["@D)"2`@(&5D:71O<BY?9&]C+F)O9'DN;VYK97EP<F5S<R`](%]#;&]S
M94]N17-C.PH)"0D@("!E9&ET;W(N7W1E>'1!<F5A+F]N:V5Y<')E<W,@/2!?
M0VQO<V5/;D5S8SL*"0D)("`@=VEN9&]W+F]N<F5S:7IE(#T@<F5S:7IE7V5D
M:71O<CL*"0D@("!]+"`S,S,I.PD)"2`O+R!G:79E(&ET('-O;64@=&EM92!T
M;R!M965T('1H92!N97<@9G)A;64*?0H*+RH@+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2`J7`H@("!&=6YC=&EO;B`@("`Z('5P9&%T95]P87)E;G0*("`@
M1&5S8W)I<'1I;VX@.B!U<&1A=&4@<&%R96YT('=I;F1O=R!E9&ET;W(@9FEE
M;&0@=VET:"!C;VYT96YT<R!F<F]M(&-H:6QD('=I;F1O=PH@("!<*B`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM("HO"@IF=6YC=&EO;B!U<&1A=&5?<&%R
M96YT*"D@>PH*"2\O('5S92!T:&4@9F%S="!V97)S:6]N"@EP87)E;G1?;V)J
M96-T+G-E=$A434PH961I=&]R+F=E=$EN;F5R2%1-3"@I*3L*?0H*("`@(#PO
M<V-R:7!T/@H@("`@/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX@:'1M;"P@8F]D
M>2![(&AE:6=H=#H@,3`P)3L@;6%R9VEN.B`P<'@[(&)O<F1E<CH@,'!X.R!B
M86-K9W)O=6YD+6-O;&]R.B!B=71T;VYF86-E.R!](#PO<W1Y;&4^"B`@/"]H
M96%D/@H@(#QB;V1Y('-C<F]L;#TB;F\B(&]N;&]A9#TB2%1-3$%R96$N;VYL
M;V%D(#T@:6YI=#L@2%1-3$%R96$N:6YI="@I.R(@;VYU;FQO860](G5P9&%T
M95]P87)E;G0H*2(^"B`@("`\9F]R;2!S='EL93TB;6%R9VEN.B`P<'@[(&)O
M<F1E<CH@,7!X('-O;&ED.R!B;W)D97(M8V]L;W(Z('1H<F5E9'-H861O=R!T
M:')E961H:6=H;&EG:'0@=&AR965D:&EG:&QI9VAT('1H<F5E9'-H861O=SLB
M/@H@("`@("`\=&5X=&%R96$@;F%M93TB961I=&]R(B!I9#TB961I=&]R(B!S
M='EL93TB=VED=&@Z,3`P)3L@:&5I9VAT.C,P,'!X(CXF;F)S<#L\+W1E>'1A
M<F5A/@H@("`@/"]F;W)M/@H@(#PO8F]D>3X*/"]H=&UL/@H`````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!O<'5P<R]P;W!U<"YJ<P``````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`V,C(U(#$P-3$U-#,T,30S(#`R-30W-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O+R!H=&UL07)E82!V,RXP("T@0V]P
M>7)I9VAT("AC*2`R,#`R+"`R,#`S(&EN=&5R86-T:79E=&]O;',N8V]M+"!I
M;F,N"B\O(%1H:7,@8V]P>7)I9VAT(&YO=&EC92!-55-4('-T87D@:6YT86-T
M(&9O<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O(%!O<G1I;VYS("AC
M*2!D>6YA<F-H+F-O;2P@,C`P,PHO+PHO+R!!(&9R964@5UE325=91R!E9&ET
M;W(@<F5P;&%C96UE;G0@9F]R(#QT97AT87)E83X@9FEE;&1S+@HO+R!&;W(@
M9G5L;"!S;W5R8V4@8V]D92!A;F0@9&]C<RP@=FES:70@:'1T<#HO+W=W=RYH
M=&UL87)E82YC;VTO"B\O"B\O(%9E<G-I;VX@,RXP(&1E=F5L;W!E9"!B>2!-
M:6AA:2!"87IO;BX*+R\@("!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"B\O
M"B\O("1)9#H@<&]P=7`N:G,L=B`Q+C$R(#(P,#4O,#$O,C0@,3@Z,CDZ-#@@
M:71O;VQS($5X<"`D"@IF=6YC=&EO;B!G971!8G-O;'5T95!O<RAE;"D@>PH)
M=F%R('(@/2![('@Z(&5L+F]F9G-E=$QE9G0L('DZ(&5L+F]F9G-E=%1O<"!]
M.PH):68@*&5L+F]F9G-E=%!A<F5N="D@>PH)"79A<B!T;7`@/2!G971!8G-O
M;'5T95!O<RAE;"YO9F9S971087)E;G0I.PH)"7(N>"`K/2!T;7`N>#L*"0ER
M+GD@*ST@=&UP+GD["@E]"@ER971U<FX@<CL*?3L*"F9U;F-T:6]N(&-O;6)O
M4V5L96-T5F%L=64H8RP@=F%L*2!["@EV87(@;W!S(#T@8RYG971%;&5M96YT
M<T)Y5&%G3F%M92@B;W!T:6]N(BD["@EF;W(@*'9A<B!I(#T@;W!S+FQE;F=T
M:#L@+2UI(#X](#`[*2!["@D)=F%R(&]P(#T@;W!S6VE=.PH)"6]P+G-E;&5C
M=&5D(#T@*&]P+G9A;'5E(#T]('9A;"D["@E]"@EC+G9A;'5E(#T@=F%L.PI]
M.PH*9G5N8W1I;VX@7U]D;&=?;VYC;&]S92@I('L*"6]P96YE<BY$:6%L;V<N
M7W)E='5R;BAN=6QL*3L*?3L*"F9U;F-T:6]N(%]?9&QG7VEN:70H8F]T=&]M
M*2!["@EV87(@8F]D>2`](&1O8W5M96YT+F)O9'D["@EV87(@8F]D>5]H96EG
M:'0@/2`P.PH):68@*'1Y<&5O9B!B;W1T;VT@/3T@(G5N9&5F:6YE9"(I('L*
M"0EV87(@9&EV(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@B9&EV(BD["@D)
M8F]D>2YA<'!E;F1#:&EL9"AD:78I.PH)"79A<B!P;W,@/2!G971!8G-O;'5T
M95!O<RAD:78I.PH)"6)O9'E?:&5I9VAT(#T@<&]S+GD["@E](&5L<V4@>PH)
M"79A<B!P;W,@/2!G971!8G-O;'5T95!O<RAB;W1T;VTI.PH)"6)O9'E?:&5I
M9VAT(#T@<&]S+GD@*R!B;W1T;VTN;V9F<V5T2&5I9VAT.PH)?0H)=VEN9&]W
M+F1I86QO9T%R9W5M96YT<R`](&]P96YE<BY$:6%L;V<N7V%R9W5M96YT<SL*
M"6EF("@A9&]C=6UE;G0N86QL*2!["@D)=VEN9&]W+G-I>F54;T-O;G1E;G0H
M*3L*"0EW:6YD;W<N<VEZ951O0V]N=&5N="@I.PDO+R!F;W(@<F5A<V]N<R!B
M97EO;F0@=6YD97)S=&%N9&EN9RP*"0D)"0DO+R!O;FQY(&EF('=E(&-A;&P@
M:70@='=I8V4@=V4@9V5T('1H90H)"0D)"2\O(&-O<G)E8W0@<VEZ92X*"0EW
M:6YD;W<N861D179E;G1,:7-T96YE<B@B=6YL;V%D(BP@7U]D;&=?;VYC;&]S
M92P@=')U92D["@D)=VEN9&]W+FEN;F5R5VED=&@@/2!B;V1Y+F]F9G-E=%=I
M9'1H("L@-3L*"0EW:6YD;W<N:6YN97)(96EG:'0@/2!B;V1Y7VAE:6=H="`K
M(#(["@D)+R\@8V5N=&5R(&]N('!A<F5N=`H)"79A<B!X(#T@;W!E;F5R+G-C
M<F5E;E@@*R`H;W!E;F5R+F]U=&5R5VED=&@@+2!W:6YD;W<N;W5T97)7:61T
M:"D@+R`R.PH)"79A<B!Y(#T@;W!E;F5R+G-C<F5E;ED@*R`H;W!E;F5R+F]U
M=&5R2&5I9VAT("T@=VEN9&]W+F]U=&5R2&5I9VAT*2`O(#(["@D)=VEN9&]W
M+FUO=F54;RAX+"!Y*3L*"7T@96QS92!["@D)+R\@=VEN9&]W+F1I86QO9TAE
M:6=H="`](&)O9'DN;V9F<V5T2&5I9VAT("L@-3`@*R`B<'@B.PH)"2\O('=I
M;F1O=RYD:6%L;V=7:61T:"`](&)O9'DN;V9F<V5T5VED=&@@*R`B<'@B.PH)
M"7=I;F1O=RYR97-I>F54;RAB;V1Y+F]F9G-E=%=I9'1H+"!B;V1Y7VAE:6=H
M="D["@D)=F%R(&-H(#T@8F]D>2YC;&EE;G1(96EG:'0["@D)=F%R(&-W(#T@
M8F]D>2YC;&EE;G17:61T:#L*"0EW:6YD;W<N<F5S:7IE0GDH8F]D>2YO9F9S
M9717:61T:"`M(&-W+"!B;V1Y7VAE:6=H="`M(&-H*3L*"0EV87(@5R`](&)O
M9'DN;V9F<V5T5VED=&@["@D)=F%R($@@/2`R("H@8F]D>5]H96EG:'0@+2!C
M:#L*"0EV87(@>"`]("AS8W)E96XN879A:6Q7:61T:"`M(%<I("\@,CL*"0EV
M87(@>2`]("AS8W)E96XN879A:6Q(96EG:'0@+2!(*2`O(#(["@D)=VEN9&]W
M+FUO=F54;RAX+"!Y*3L*"7T*"61O8W5M96YT+F)O9'DN;VYK97EP<F5S<R`]
M(%]?9&QG7V-L;W-E7V]N7V5S8SL*?3L*"F9U;F-T:6]N(%]?9&QG7W1R86YS
M;&%T92AI,3AN*2!["@EV87(@='EP97,@/2!;(FEN<'5T(BP@(G-E;&5C="(L
M(")L96=E;F0B+"`B<W!A;B(L(")O<'1I;VXB+"`B=&0B+"`B8G5T=&]N(BP@
M(F1I=B)=.PH)9F]R("AV87(@='EP92`](#`[('1Y<&4@/"!T>7!E<RYL96YG
M=&@[("LK='EP92D@>PH)"79A<B!S<&%N<R`](&1O8W5M96YT+F=E=$5L96UE
M;G1S0GE486=.86UE*'1Y<&5S6W1Y<&5=*3L*"0EF;W(@*'9A<B!I(#T@<W!A
M;G,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)=F%R('-P86X@/2!S<&%N<UMI
M73L*"0D):68@*'-P86XN9FER<W1#:&EL9"`F)B!S<&%N+F9I<G-T0VAI;&0N
M9&%T82D@>PH)"0D)=F%R('1X="`](&DQ.&Y;<W!A;BYF:7)S=$-H:6QD+F1A
M=&%=.PH)"0D):68@*'1X="D*"0D)"0ES<&%N+F9I<G-T0VAI;&0N9&%T82`]
M('1X=#L*"0D)?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W!A;BYT
M:71L92D@>PH)"0D)=F%R('1X="`](&DQ.&Y;<W!A;BYT:71L95T["@D)"0EI
M9B`H='AT*0H)"0D)"7-P86XN=&ET;&4@/2!T>'0["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*"0E]"@E]"@EV87(@='AT(#T@:3$X;EMD;V-U;65N="YT
M:71L95T["@EI9B`H='AT*0H)"61O8W5M96YT+G1I=&QE(#T@='AT.PI].PH*
M+R\@8VQO<V5S('1H92!D:6%L;V<@86YD('!A<W-E<R!T:&4@<F5T=7)N(&EN
M9F\@=7!P97(N"F9U;F-T:6]N(%]?9&QG7V-L;W-E*'9A;"D@>PH);W!E;F5R
M+D1I86QO9RY?<F5T=7)N*'9A;"D["@EW:6YD;W<N8VQO<V4H*3L*?3L*"F9U
M;F-T:6]N(%]?9&QG7V-L;W-E7V]N7V5S8RAE=BD@>PH)978@?'P@*&5V(#T@
M=VEN9&]W+F5V96YT*3L*"6EF("AE=BYK97E#;V1E(#T](#(W*2!["@D)=VEN
M9&]W+F-L;W-E*"D["@D)<F5T=7)N(&9A;'-E.PH)?0H)<F5T=7)N('1R=64[
M"GT["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;W!U<',O86)O=70N:'1M;```````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`S,#$P-2`Q,#4Q-30S-#$T,R`P,C4W-C8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/"$M+0H**&,I(&1Y;F%R8V@N8V]M
M+"`R,#`S+3(P,#4*075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R
M8V@N8V]M+VUI<VAO;PI$:7-T<FEB=71E9"!A<R!P87)T(&]F($A434Q!<F5A
M(#,N,`H*(EEO=2!A<F4@;F]T(&5X<&5C=&5D('1O('5N9&5R<W1A;F0@=&AI
M<RXN+B`@22!D;VXG="!N96ET:&5R+B(*"B`@("`@("`@("`@("`@("`@("`@
M("`H9G)O;2!4:&4@3&EN=7@@2V5R;F5L(%-O=7)C92!#;V1E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B]A<F-H+W@X-E\V-"]I83,R+W!T<F%C
M92YC.CDP*0H*.RTI"@HM+3X*"CQH=&UL('-T>6QE/2)H96EG:'0Z(#$P,"4B
M/@H\:&5A9#X*/&UE=&$@:'1T<"UE<75I=CTB0V]N=&5N="U4>7!E(B!C;VYT
M96YT/2)T97AT+VAT;6P[(&-H87)S970]=71F+3@B("\^"CQT:71L93Y!8F]U
M="!(5$U,07)E83PO=&ET;&4^"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(B!S<F,](G!O<'5P+FIS(CX\+W-C<FEP=#X*/'-C<FEP="!T>7!E/2)T
M97AT+VIA=F%S8W)I<'0B/@IW:6YD;W<N<F5S:7IE5&\H-#4P+"`R-3`I.PIV
M87(@5$%"4R`](%M=.PIV87(@0U524D5.5%]404(@/2`P.PIV87(@0T].5$5.
M5%](14E'2%1?1$E&1B`](#`["G9A<B!#3TY414Y47U=)1%1(7T1)1D8@/2`P
M.PIF=6YC=&EO;B!S96QE8W1486(H:61X*2!["B`@=F%R(&-T(#T@5$%"4UM#
M55)214Y47U1!0ET["B`@8W0N8VQA<W-.86UE(#T@8W0N8VQA<W-.86UE+G)E
M<&QA8V4H+UQS*G1A8BUC=7)R96YT7',J+RP@)R`G*3L*("!C="`](%1!0E-;
M0U524D5.5%]404(@/2!I9'A=.PH@(&-T+F-L87-S3F%M92`K/2`G('1A8BUC
M=7)R96YT)SL*("!F;W(@*'9A<B!I(#T@5$%"4RYL96YG=&@[("TM:2`^/2`P
M.RD@>PH@("`@=F%R(&%R96$@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B
M=&%B+6%R96$M(B`K(&DI.PH@("`@:68@*$-54E)%3E1?5$%"(#T](&DI('L*
M("`@("`@87)E82YS='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*("`@('T@96QS
M92!["B`@("`@(&%R96$N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*("`@('T*
M("!]"B`@9&]C=6UE;G0N8F]D>2YS='EL92YV:7-I8FEL:71Y(#T@(FAI9&1E
M;B(["B`@9&]C=6UE;G0N8F]D>2YS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB
M;&4B.PH@(&1O8W5M96YT+F-O;VMI92`](")(5$U,05)%02U!0D]55"U404(]
M(B`K(&ED>#L*?0IV87(@961I=&]R(#T@;G5L;#L*9G5N8W1I;VX@:6YI=$1O
M8W5M96YT*"D@>PH@(&5D:71O<B`]('=I;F1O=RYD:6%L;V=!<F=U;65N=',[
M"B`@2%1-3$%R96$@/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A.PH*("!V87(@
M<&QU9VEN<R`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")P;'5G:6YS(BD[
M"B`@=F%R(&H@/2`P.PH@('9A<B!H=&UL(#T@(CQT86)L92!W:61T:#TG.3DE
M)R!C96QL<&%D9&EN9STG,"<@<W1Y;&4])VUA<F=I;BUT;W`Z(#%E;3L@8V]L
M;&%P<V4M8F]R9&5R<SH@8V]L;&%P<V4[(&)O<F1E<CH@,7!X('-O;&ED(",X
M8C@[)SXB("L*"2`@(CQT:&5A9#X\='(^(B`K"@D@("(\=&0^3F%M93PO=&0^
M(B`K"@D@("(\=&0^1&5V96QO<&5R/"]T9#XB("L*"2`@(CQT9#Y3<&]N<V]R
M960@8GD\+W1D/B(@*PH)("`B/'1D/DQI8V5N<V4\<W5P/BH\+W-U<#X\+W1D
M/B(@*PH)("`B/"]T<CX\+W1H96%D/CQT8F]D>3XB.PH@(&9O<B`H=F%R(&D@
M:6X@961I=&]R+G!L=6=I;G,I('L*("`@('9A<B!I;F9O(#T@961I=&]R+G!L
M=6=I;G-;:5T["B`@("!H=&UL("L]("(\='(^/'1D/B(@*R!I;F9O+FYA;64@
M*R`B('8B("L@:6YF;RYV97)S:6]N("L@(CPO=&0^(B`K"B`@("`@("`@("`@
M("(\=&0^/&$@:')E9CTG(B`K(&EN9F\N9&5V96QO<&5R7W5R;"`K("(G('1A
M<F=E=#TG7V)L86YK)R!T:71L93TG5FES:70@9&5V96QO<&5R('=E8G-I=&4G
M/B(@*PH)("`@(&EN9F\N9&5V96QO<&5R("L@(CPO83X\+W1D/B(@*PH)("`@
M("(\=&0^/&$@:')E9CTG(B`K(&EN9F\N<W!O;G-O<E]U<FP@*R`B)R!T87)G
M970])U]B;&%N:R<@=&ET;&4])U9I<VET('-P;VYS;W(@=V5B<VET92<^(B`K
M"@D@("`@:6YF;RYS<&]N<V]R("L@(CPO83X\+W1D/B(@*PH)("`@("(\=&0^
M(B`K(&EN9F\N;&EC96YS92`K("(\+W1D/CPO='(^(CL*("`@("LK:CL*("!]
M"@H@(&EF("AJ*2!["B`@("`@("`@("!H=&UL("L]("(\+W1B;V1Y/CPO=&%B
M;&4^(B`K"@D)("`B/'`^/'-U<#XJ/"]S=7`^($QI8V5N<V4@7")H=&UL07)E
M85PB(&UE86YS('1H870@=&AE('!L=6=I;B!I<R!D:7-T<FEB=71E9"!U;F1E
M<B!T:&4@<V%M92!T97)M<R`B("L*"0D@(")A<R!(5$U,07)E82!I='-E;&8N
M("!3=6-H('!L=6=I;G,@87)E(&QI:V5L>2!T;R!B92!T:&]S92!I;F-L=61E
M9"!I;B!T:&4@;V9F:6-I86P@(B`K"@D)("`B2%1-3$%R96$@9&ES=')I8G5T
M:6]N/"]P/B(["@D@('!L=6=I;G,N:6YN97)(5$U,(#T@(CQP/E1H92!F;VQL
M;W=I;F<@<&QU9VEN<R!H879E(&)E96X@;&]A9&5D+CPO<#XB("L@:'1M;#L*
M("!](&5L<V4@>PH)("!P;'5G:6YS+FEN;F5R2%1-3"`]("(\<#Y.;R!P;'5G
M:6YS(&AA=F4@8F5E;B!L;V%D960\+W`^(CL*("!]"@H@('!L=6=I;G,N:6YN
M97)(5$U,("L]("(\<#Y5<V5R(&%G96YT(')E<&]R=',Z/&)R+SXB("L@;F%V
M:6=A=&]R+G5S97)!9V5N="`K("(\+W`^(CL*"B`@=F%R(&-O;G1E;G0@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@B8V]N=&5N="(I.PH@(&EF("AW:6YD
M;W<N:6YN97)(96EG:'0I('L*("`@($-/3E1%3E1?2$5)1TA47T1)1D8@/2!W
M:6YD;W<N:6YN97)(96EG:'0@+2`R-3`["B`@("!#3TY414Y47U=)1%1(7T1)
M1D8@/2!W:6YD;W<N:6YN97)7:61T:"`M(&-O;G1E;G0N;V9F<V5T5VED=&@[
M"B`@?2!E;'-E('L*("`@($-/3E1%3E1?2$5)1TA47T1)1D8@/2!D;V-U;65N
M="YB;V1Y+F]F9G-E=$AE:6=H="`M(#(U,#L*("`@($-/3E1%3E1?5TE$5$A?
M1$E&1B`](&1O8W5M96YT+F)O9'DN;V9F<V5T5VED=&@@+2`T,#`["B`@?0H@
M('=I;F1O=RYO;G)E<VEZ92@I.PH@('9A<B!B87(@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"@B=&%B8F%R(BD["B`@:B`](#`["B`@9F]R("AV87(@:2`]
M(&)A<BYF:7)S=$-H:6QD.R!I.R!I(#T@:2YN97AT4VEB;&EN9RD@>PH@("`@
M5$%"4RYP=7-H*&DI.PH@("`@:2Y?7VUS:%]T86(@/2!J.PH@("`@:2YO;FUO
M=7-E9&]W;B`](&9U;F-T:6]N*&5V*2![('-E;&5C=%1A8BAT:&ES+E]?;7-H
M7W1A8BD[($A434Q!<F5A+E]S=&]P179E;G0H978@?'P@=VEN9&]W+F5V96YT
M*3L@?3L*("`@('9A<B!A<F5A(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M(G1A8BUA<F5A+2(@*R!J*3L*("`@(&EF("@O=&%B+6-U<G)E;G0O+G1E<W0H
M:2YC;&%S<TYA;64I*2!["B`@("`@($-54E)%3E1?5$%"(#T@:CL*("`@("`@
M87)E82YS='EL92YD:7-P;&%Y(#T@(F)L;V-K(CL*("`@('T@96QS92!["B`@
M("`@(&%R96$N<W1Y;&4N9&ES<&QA>2`](")N;VYE(CL*("`@('T*("`@("LK
M:CL*("!]"B`@:68@*&1O8W5M96YT+F-O;VMI92YM871C:"@O2%1-3$%214$M
M04)/550M5$%"/2A;,"TY72LI+RDI"B`@("!S96QE8W1486(H4F5G17AP+B0Q
M*3L*?0IW:6YD;W<N;VYR97-I>F4@/2!F=6YC=&EO;B@I('L*("!V87(@8V]N
M=&5N="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")C;VYT96YT(BD["B`@
M:68@*'=I;F1O=RYI;FYE<DAE:6=H="D@>PH@("`@8V]N=&5N="YS='EL92YH
M96EG:'0@/2`H=VEN9&]W+FEN;F5R2&5I9VAT("T@0T].5$5.5%](14E'2%1?
M1$E&1BD@*R`B<'@B.PH@("`@8V]N=&5N="YS='EL92YW:61T:"`]("AW:6YD
M;W<N:6YN97)7:61T:"`M($-/3E1%3E1?5TE$5$A?1$E&1BD@*R`B<'@B.PH@
M('T@96QS92!["B`@("!C;VYT96YT+G-T>6QE+FAE:6=H="`]("AD;V-U;65N
M="YB;V1Y+F]F9G-E=$AE:6=H="`M($-/3E1%3E1?2$5)1TA47T1)1D8I("L@
M(G!X(CL*("`@("\O8V]N=&5N="YS='EL92YW:61T:"`]("AD;V-U;65N="YB
M;V1Y+F]F9G-E=%=I9'1H("T@0T].5$5.5%]724142%]$249&*2`K(")P>"([
M"B`@?0I]"CPO<V-R:7!T/@H\<W1Y;&4^"B`@:'1M;"QB;V1Y+'1E>'1A<F5A
M+'1A8FQE('L@9F]N="UF86UI;'DZ('1A:&]M82QV97)D86YA+&%R:6%L.R!F
M;VYT+7-I>F4Z(#$Q<'@["G!A9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@[('T*
M("!T="![(&9O;G0M<VEZ93H@,3(P)3L@?0H@(&)O9'D@>R!P861D:6YG.B`P
M<'@[(&)A8VMG<F]U;F0Z("-C96$[(&-O;&]R.B`P,#`[('T*("!A.FQI;FLL
M(&$Z=FES:71E9"![(&-O;&]R.B`C,#!F.R!]"B`@83IH;W9E<B![(&-O;&]R
M.B`C9C`P.R!]"B`@83IA8W1I=F4@>R!C;VQO<CH@(V8X,#L@?0H@(&)U='1O
M;B![(&9O;G0Z(#$Q<'@@=&%H;VUA+'9E<F1A;F$L<V%N<RUS97)I9CL@8F%C
M:V=R;W5N9"UC;VQO<CH@(V-E83L*("`@("`@8F]R9&5R+7=I9'1H.B`Q<'@[
M('T*"B`@<"![(&UA<F=I;CH@,"XU96T@,'!X.R!]"@H@(&@Q('L@9F]N=#H@
M8F]L9"`Q,S`E(&=E;W)G:6$L(G1I;65S(&YE=R!R;VUA;B(L<V5R:68[(&UA
M<F=I;CH@,'!X.R!B;W)D97(M8F]T=&]M.B`Q<'@@<V]L:60@(S9A-CL@?0H@
M(&@R('L@9F]N=#H@8F]L9"`Q,3`E(&=E;W)G:6$L(G1I;65S(&YE=R!R;VUA
M;B(L<V5R:68[(&UA<F=I;CH@,"XW96T@,'!X.R!]"@H@('1H96%D('L*("`@
M(&9O;G0M=V5I9VAT.B!B;VQD.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(V1F
M8CL*("!]"@H@("YL;V=O+"`N;&]G;RUH;W9E<B!["B`@("!W:&ET92US<&%C
M93H@;F]W<F%P.PH@("`@8F%C:V=R;W5N9"UC;VQO<CH@(SAF-#L@8V]L;W(Z
M(",P-#`[('!A9&1I;F<Z(#-P>#L@8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED
M(",U-34["B`@("!H96EG:'0Z(#5E;3L*("!]"B`@+FQO9V\@+F)R86YD+"`N
M;&]G;RUH;W9E<B`N8G)A;F0@>PH@("`@;6%R9VEN+6QE9G0Z(#`N-65M.R!M
M87)G:6XM<FEG:'0Z(#`N-65M.R!P861D:6YG+6)O='1O;3H@,"XQ96T["B`@
M("!F;VYT+69A;6EL>3H@:6UP86-T+"=A<FEA;"!B;&%C:R<L87)I86PL<V%N
M<RUS97)I9CL@9F]N="US:7IE.B`R.'!X.PH@("`@8F]R9&5R+6)O='1O;3H@
M,7!X('-O;&ED(",U.34[('1E>'0M86QI9VXZ(&-E;G1E<CL*("`@(&-U<G-O
M<CH@<&]I;G1E<CL*("!]"B`@+FQO9V\M:&]V97(@>PH@("`@8F%C:V=R;W5N
M9"UC;VQO<CH@(V9F9CL*("!]"B`@+FQO9V\M:&]V97(@+F)R86YD('L*("`@
M(&-O;&]R.B`C.#`P.PH@("`@8F]R9&5R+6-O;&]R.B`C,#1F.PH@('T*("`N
M;&]G;R`N;&5T=&5R+"`N;&]G;RUH;W9E<B`N;&5T=&5R('L@<&]S:71I;VXZ
M(')E;&%T:79E.R!F;VYT+69A;6EL>3H@;6]N;W-P86-E.R!]"B`@+FQO9V\@
M+FQE='1E<C$@>R!T;W`Z(#`N,65M.R!]"B`@+FQO9V\@+FQE='1E<C(@>R!T
M;W`Z(#`N,#5E;3L@?0H@("YL;V=O("YL971T97(S('L@=&]P.B`M,"XP-65M
M.R!]"B`@+FQO9V\@+FQE='1E<C0@>R!T;W`Z("TP+C%E;3L@?0H*("`N;&]G
M;RUH;W9E<B`N;&5T=&5R,2![('1O<#H@+3`N,65M.R!]"B`@+FQO9V\M:&]V
M97(@+FQE='1E<C(@>R!T;W`Z("TP+C`U96T[('T*("`N;&]G;RUH;W9E<B`N
M;&5T=&5R,R![('1O<#H@,"XP-65M.R!]"B`@+FQO9V\M:&]V97(@+FQE='1E
M<C0@>R!T;W`Z(#`N,65M.R!]"B`@+FQO9V\@+G9E<G-I;VXL("YL;V=O+6AO
M=F5R("YV97)S:6]N('L@9F]N="UF86UI;'DZ(&=E;W)G:6$L(G1I;65S(&YE
M=R!R;VUA;B(L<V5R:68[('T*("`N;&]G;R`N<F5L96%S92!["B`@("!F;VYT
M+7-I>F4Z(#DP)3L@;6%R9VEN+6)O='1O;3H@,65M.PH@("`@=&5X="UA;&EG
M;CH@8V5N=&5R.R!C;VQO<CH@(S0X-#L*("!]"B`@+FQO9V\@+G9I<VET('L@
M9&ES<&QA>3H@;F]N93L@?0H@("YL;V=O+6AO=F5R("YR96QE87-E('L@9&ES
M<&QA>3H@;F]N93L@?0H@("YL;V=O+6AO=F5R("YV:7-I="!["B`@("!F;VYT
M+7-I>F4Z(#DP)3L@;6%R9VEN+6)O='1O;3H@,65M.PH@("`@=&5X="UA;&EG
M;CH@8V5N=&5R.R!C;VQO<CH@(S0T.#L*("!]"B`@+F)U='1O;G,@>PH@("`@
M=&5X="UA;&EG;CH@<FEG:'0[('!A9&1I;F<Z(#-P>#L@8F%C:V=R;W5N9"UC
M;VQO<CH@(SAF-#L*("`@(&)O<F1E<BUT;W`Z(#%P>"!S;VQI9"`C-34U.PH@
M('T*("`C=&%B8F%R('L*("`@('!O<VET:6]N.B!R96QA=&EV93L*("`@(&QE
M9G0Z(#$P<'@["B`@?0H@("YT86(@>PH@("`@8V]L;W(Z(",T-30["B`@("!C
M=7)S;W(Z('!O:6YT97(["B`@("!M87)G:6XM;&5F=#H@+35P>#L*("`@(&9L
M;V%T.B!L969T.R!P;W-I=&EO;CH@<F5L871I=F4["B`@("!B;W)D97(Z(#%P
M>"!S;VQI9"`C-34U.PH@("`@=&]P.B`M,W!X.R!L969T.B`M,G!X.PH@("`@
M<&%D9&EN9SH@,G!X(#$P<'@@,W!X(#$P<'@["B`@("!B;W)D97(M=&]P.B!N
M;VYE.R!B86-K9W)O=6YD+6-O;&]R.B`C.6(W.PH@("`@+6UO>BUB;W)D97(M
M<F%D:75S.B`P<'@@,'!X(#1P>"`T<'@["B`@("!Z+6EN9&5X.B`P.PH@('T*
M("`N=&%B+6-U<G)E;G0@>PH@("`@8V]L;W(Z(",P,#`["B`@("!T;W`Z("TT
M<'@["B`@("!B86-K9W)O=6YD+6-O;&]R.B`C8V5A.PH@("`@<&%D9&EN9SH@
M,W!X(#$P<'@@-'!X(#$P<'@["B`@("!Z+6EN9&5X.B`Q,#L*("!]"B`@=&%B
M;&4N<W!O;G-O<G,@>R!B;W)D97(M=&]P.B`Q<'@@<V]L:60@(V%C83L@?0H@
M('1A8FQE+G-P;VYS;W)S('1D('L*("`@(&)O<F1E<BUB;W1T;VTZ(#%P>"!S
M;VQI9"`C86-A.R!V97)T:6-A;"UA;&EG;CH@=&]P.PH@('T*("!T86)L92YS
M<&]N<V]R<R!T<B!T9"![('!A9&1I;F<Z(#)P>"`P<'@[('T*("!T86)L92YS
M<&]N<V]R<R!T<B!T9"YS<&]N<V]R('L@=&5X="UA;&EG;CH@<FEG:'0[('!A
M9&1I;F<M<FEG:'0Z(#`N,V5M.R!W:&ET92US<&%C93H@;F]W<F%P.R!]"B`@
M;&DL(&]L+"!U;"![(&UA<F=I;BUT;W`Z(#!P>#L@;6%R9VEN+6)O='1O;3H@
M,'!X.R!]"CPO<W1Y;&4^/"]H96%D/@H\8F]D>2!O;FQO860](E]?9&QG7VEN
M:70H*3L@:6YI=$1O8W5M96YT*"D[(@H^/'1A8FQE(&-E;&QS<&%C:6YG/2(P
M(B!C96QL<&%D9&EN9STB,"(@<W1Y;&4](F)O<F1E<BUC;VQL87!S93H@8V]L
M;&%P<V4["B`@("`@('=I9'1H.B`Q,#`E.R!H96EG:'0Z(#$P,"4[(CX*"CQT
M<B!S='EL93TB:&5I9VAT.B`Q96TB/CQT9"!I9#TB=&1H96%D97(B/@H*/&1I
M=B!C;&%S<STB;&]G;R(^"CQD:78@8VQA<W,](F)R86YD(@IO;FUO=7-E;W9E
M<CTB=&AI<RYP87)E;G1.;V1E+F-L87-S3F%M93TG;&]G;RUH;W9E<B<[(@IO
M;FUO=7-E;W5T/2)T:&ES+G!A<F5N=$YO9&4N8VQA<W-.86UE/2=L;V=O)SLB
M"F]N8VQI8VL](G=I;F1O=RYO<&5N*"=H='1P.B\O=W=W+FAT;6QA<F5A+F-O
M;2\G*3LB/@H\<W!A;B!C;&%S<STB;&5T=&5R(&QE='1E<C$B/B9L=#M(/"]S
M<&%N/CQS<&%N"F-L87-S/2)L971T97(@;&5T=&5R,B(^5#PO<W!A;CX\<W!A
M;@IC;&%S<STB;&5T=&5R(&QE='1E<C,B/DT\+W-P86X^/'-P86X*8VQA<W,]
M(FQE='1E<B!L971T97(T(CY,/"]S<&%N/D%R96$@/'-P86X@8VQA<W,](FQE
M='1E<B(^+R9G=#L\+W-P86X^"CQS<&%N(&-L87-S/2)V97)S:6]N(CXS+C`@
M/'-P86X@<W1Y;&4](G!O<VET:6]N.B!R96QA=&EV93L@=&]P.B`M,"XV96T[
M(&9O;G0M<VEZ93H@-3`E.R!F;VYT+7=E:6=H=#H@;F]R;6%L(CY;(')E=BX@
M8F5T82L@73PO<W!A;CX\+W-P86X^/"]D:78^"CQD:78@8VQA<W,](G)E;&5A
M<V4B/D-O;7!I;&5D(&]N($UA>2`Q-RP@,C`P-2`P,3HP."!'350\+V1I=CX*
M/&1I=B!C;&%S<STB=FES:70B/D=O('1O(&AT='`Z+R]W=W<N:'1M;&%R96$N
M8V]M+R!;;&%T97-T(&UI;&5S=&]N92!R96QE87-E73PO9&EV/@H\+V1I=CX*
M"CPO=&0^/"]T<CX*/'1R/CQT9"!I9#TB=&1C;VYT96YT(B!S='EL93TB<&%D
M9&EN9SH@,"XU96T[(CX*"CQD:78@<W1Y;&4](F]V97)F;&]W.B!A=71O.R!H
M96EG:'0Z(#(U,'!X.R(@:60](F-O;G1E;G0B/@H\9&EV(&ED/2)T86(M87)E
M87,B/@H*/&1I=B!I9#TB=&%B+6%R96$M,"(^"@H@(#QH,3Y(5$U,07)E83PO
M:#$^"@H@(#QP/D$@9G)E92!765-)5UE'(&5D:71O<B!R97!L86-E;65N="!F
M;W(@/'1T/B9L=#MT97AT87)E829G=#L\+W1T/B!F:65L9',N/&)R("\^"B`@
M1F]R($UO>FEL;&$@,2XS*R`H86YY('!L871F;W)M*2!O<B!);G1E<FYE="!%
M>'!L;W)E<B`U+C4K("A7:6YD;W=S*2X*("`\+W`^"@H@(#QP('-T>6QE/2)T
M97AT+6%L:6=N.B!C96YT97(B"B`@/L*I(#(P,#(M,C`P-"`\82!H<F5F/2)H
M='1P.B\O:6YT97)A8W1I=F5T;V]L<RYC;VTB('1A<F=E=#TB7V)L86YK(CYI
M;G1E<F%C=&EV971O;VQS+F-O;3PO83XL(&EN8RX\8G(@+SX*("#"J2`R,#`S
M+3(P,#4@/&$@:')E9CTB:'1T<#HO+V1Y;F%R8V@N8V]M(B!T87)G970](E]B
M;&%N:R(^9'EN87)C:"YC;VT\+V$^($Q,0RX\8G(@+SX*("!!;&P@4FEG:'1S
M(%)E<V5R=F5D+CPO<#X*"B`@/&@R/E!R;VIE8W0@<F5S;W5R8V5S/"]H,CX*
M"B`@/'5L/@H@(#QL:3X\82!H<F5F/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T
M+W!R;VIE8W1S+VET;V]L<RUH=&UL87)E82\B('1A<F=E=#TB7V)L86YK(@H@
M(#Y0<F]J96-T('!A9V4\+V$^("A`('-O=7)C969O<F=E+FYE="D\+VQI/@H@
M(#QL:3X\82!H<F5F/2)H='1P.B\O<V]U<F-E9F]R9V4N;F5T+V-V<R\_9W)O
M=7!?:60]-CDW-3`B('1A<F=E=#TB7V)L86YK(@H@(#Y!;F]N>6UO=7,@0U93
M(&%C8V5S<SPO83X@*$`@<V]U<F-E9F]R9V4N;F5T*3PO;&D^"B`@/&QI/CQA
M(&AR968](FAT='`Z+R]S;W5R8V5F;W)G92YN970O=')A8VME<B\_871I9#TU
M,C4V-38F9W)O=7!?:60]-CDW-3`F9G5N8SUB<F]W<V4B('1A<F=E=#TB7V)L
M86YK(@H@(#Y"=6<@<WES=&5M/"]A/B`H0"!S;W5R8V5F;W)G92YN970I/"]L
M:3X*("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYH=&UL87)E82YC;VTO9F]R
M=6TO(B!T87)G970](E]B;&%N:R(*("`^1F]R=6T\+V$^("A`(&EN=&5R86-T
M:79E=&]O;',N8V]M*3PO;&D^"B`@/&QI/CQA(&AR968](FAT='`Z+R]W=W<N
M:'1M;&%R96$N8V]M+R(@=&%R9V5T/2)?8FQA;FLB"B`@/DQA<W0@<'5B;&EC
M(')E;&5A<V4\+V$^/"]L:3X*("`\+W5L/@H*("`\<#X*("!&;W(@9&]W;FQO
M860@<V5C=&EO;B!P;&5A<V4@<V5E('1H92`\82!H<F5F/2)H='1P.B\O<V]U
M<F-E9F]R9V4N;F5T+W!R;VIE8W1S+VET;V]L<RUH=&UL87)E82\B('1A<F=E
M=#TB7V)L86YK(@H@(#YP<F]J96-T('!A9V4@0"!3;W5R8V5&;W)G93PO83XN
M"B`@/"]P/@H*/"]D:78^"@H\9&EV(&ED/2)T86(M87)E82TQ(CX*/&@Q/E1H
M86YK('EO=3PO:#$^"@H@(#QP/@H@(#QA(&AR968](FAT='`Z+R]D>6YA<F-H
M+F-O;2(@=&%R9V5T/2)?8FQA;FLB/F1Y;F%R8V@N8V]M/"]A/B!W;W5L9"!L
M:6ME('1O('1H86YK('1H92!F;VQL;W=I;F<*("!C;VUP86YI97,O<&5R<V]N
M<R!F;W(@=&AE:7(@/&5M/F1O;F%T:6]N<SPO96T^('1O('-U<'!O<G0@9&5V
M96QO<&UE;G0@;V8@2%1-3$%R96$@*&QI<W1E9"!A;'!H86)E=&EC86QL>2DZ
M"B`@/"]P/@H*("`\=6P^"B`@("`\;&D^/&$@:')E9CTB:'1T<#HO+W=W=RYC
M;VUP=71E<FQO=F4N8V\N=6LB('1A<F=E=#TB7V)L86YK(CY#;V1E($-O;7!U
M=&5R($QO=F4@3'1D+CPO83X@*%5+*3PO;&D^"B`@("`\;&D^/&$@:')E9CTB
M:'1T<#HO+W=W=RYN96]M961I82YR;R(@=&%R9V5T/2)?8FQA;FLB/DYE;VUE
M9&EA/"]A/B`H4F]M86YI82D\+VQI/@H@("`@/&QI/CQA(&AR968](FAT='`Z
M+R]W=W<N;W,S+FET(B!T87)G970](E]B;&%N:R(^3U,S/"]A/B`H271A;'DI
M/"]L:3X*("`@(#QL:3X\82!H<F5F/2)H='1P.B\O=W=W+G-O9G1W97)K+FYE
M="(@=&%R9V5T/2)?8FQA;FLB/E-O9G1797)K/"]A/B`H271A;'DI/"]L:3X*
M("`\+W5L/@H*("`\<#Y!;'-O(&UA;GD@=&AA;FMS('1O(&%L;"!P96]P;&4@
M870@26YT97)A8W1I=F54;V]L<RYC;VT*("`\82!H<F5F/2)H='1P.B\O=W=W
M+FAT;6QA<F5A+F-O;2]F;W)U;2\B/DA434Q!<F5A(&9O<G5M<SPO83X@9F]R
M"B`@8V]N=')I8G5T:6YG('1R86YS;&%T:6]N<RP@9F5E9&)A8VLL(&)U9R!R
M97!O<G1S(&%N9"!F:7AE<RX\+W`^"@H@(#QP/@H@($QA<W0@8G5T(&YO="!L
M96%S="P@=&AI<R!P<F]J96-T('=O=6QD;B=T(&AA=F4@97AI<W1E9"!W:71H
M;W5T"B`@/&$@:')E9CTB:'1T<#HO+VEN=&5R86-T:79E=&]O;',N8V]M(B!T
M87)G970](E]B;&%N:R(^26YT97)A8W1I=F54;V]L<RYC;VT\+V$^+@H@(#PO
M<#X*"CPO9&EV/@H*/&1I=B!I9#TB=&%B+6%R96$M,B(^"CQH,3YH=&UL07)E
M82!,:6-E;G-E("AB87-E9"!O;B!"4T0@;&EC96YS92D\+V@Q/@H*/'`@<W1Y
M;&4](G1E>'0M86QI9VXZ(&-E;G1E<B(^PJD@,C`P,BTR,#`T+"!I;G1E<F%C
M=&EV971O;VQS+F-O;2P@:6YC+CQB<B`O/@H@(,*I(#(P,#,M,C`P-"!D>6YA
M<F-H+F-O;2!,3$,\8G(@+SX*("!!;&P@<FEG:'1S(')E<V5R=F5D+CPO<#X*
M"CQP/@I2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS(&%R92!M970Z"CPO<#X*"CQO;#X*/&QI/@I2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"G1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"CPO;&D^"@H\;&D^"E)E9&ES=')I8G5T:6]N
M<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P
M>7)I9VAT(&YO=&EC92P*=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@IA
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BX*/"]L:3X*"CQL:3X*3F5I=&AE<B!T:&4@;F%M92!O9B!I;G1E
M<F%C=&EV971O;VQS+F-O;2P@:6YC+B!N;W(@=&AE(&YA;65S(&]F(&ET<PIC
M;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E
M('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES"G-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H\+VQI/@H\+V]L
M/@H*/'`^"E1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E2
M24=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@(D%3($E3(@I!3D0@04Y9
M($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)5
M5"!.3U0@3$E-251%1"!43RP@5$A%"DE-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%"D%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@
M0T]065))1TA4($]73D52($]2($-/3E1224)55$]24R!"10I,24%"3$4@1D]2
M($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2"D-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+"!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&"E-50E-42515
M5$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!0
M4D]&2513.R!/4B!"55-)3D534PI)3E1%4E)54%1)3TXI($A/5T5615(@0T%5
M4T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)
M3@I#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*0I!4DE324Y'($E.($%.62!7
M05D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!
M1%9)4T5$($]&(%1(10I03U-324))3$E462!/1B!354-(($1!34%'12X*/"]P
M/@H*/"]D:78^"@H\9&EV(&ED/2)T86(M87)E82TS(CX*/&@Q/E!L=6=I;G,\
M+V@Q/@H\9&EV(&ED/2)P;'5G:6YS(CX*/"]D:78^"CPO9&EV/@H*/"]D:78^
M/"]D:78^"@H*/"]T<CX\+W1D/@H\='(@<W1Y;&4](FAE:6=H=#H@,65M(CX\
M=&0@:60](G1D9F]O=&5R(CX*"@H\9&EV(&-L87-S/2)B=71T;VYS(CX*/&1I
M=B!I9#TB=&%B8F%R(@H^/&1I=B!C;&%S<STB=&%B('1A8BUC=7)R96YT(@H^
M06)O=70\+V1I=CX\9&EV(&-L87-S/2)T86(B"CY4:&%N:W,\+V1I=CX\9&EV
M(&-L87-S/2)T86(B"CY,:6-E;G-E/"]D:78^/&1I=B!C;&%S<STB=&%B(@H^
M4&QU9VEN<SPO9&EV/CPO9&EV/@H\8G5T=&]N('1Y<&4](F)U='1O;B(@;VYC
M;&EC:STB7U]D;&=?8VQO<V4H;G5L;"D[(CY)(&%G<F5E(&ET)W,@8V]O;#PO
M8G5T=&]N/@H\+V1I=CX*"CPO=&0^/"]T<CX\+W1A8FQE/@H*/"]B;V1Y/CPO
M:'1M;#X*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R
M96$O<&]P=7!S+W-E;&5C=%]C;VQO<BYH=&UL````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-S`Q-#(@
M,3`U,34T,S0Q-#,@,#(W,S,V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#PA+2T@;F]T93H@=&AI<R!V97)S:6]N(&]F('1H
M92!C;VQO<B!P:6-K97(@:7,@;W!T:6UI>F5D(&9O<B!)12`U+C4K(&]N;'D@
M+2T^#0H-"CQH=&UL/CQH96%D/CQT:71L93Y396QE8W0@0V]L;W(\+W1I=&QE
M/@T*#0H\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2)P;W!U
M<"YJ<R(^/"]S8W)I<'0^#0H-"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R
M:7!T(CX-"@T*=VEN9&]W+G)E<VEZ951O*#(T,"P@,3@R*3L-"F9U;F-T:6]N
M(%]#;&]S94]N17-C*"D@>PT*("!I9B`H979E;G0N:V5Y0V]D92`]/2`R-RD@
M>R!W:6YD;W<N8VQO<V4H*3L@<F5T=7)N.R!]#0I]#0H-"F9U;F-T:6]N($EN
M:70H*2![("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(')U;B!O;B!P86=E(&QO860-"B`@7U]D;&=?
M:6YI="@I.R`@("`O+R`\(2TM('1H:7,@8V%N(&)E(&9O=6YD(&EN('!O<'5P
M+FIS("TM/@T*("!D;V-U;65N="YB;V1Y+F]N:V5Y<')E<W,@/2!?0VQO<V5/
M;D5S8SL-"@T*("!V87(@8V]L;W(@/2!W:6YD;W<N9&EA;&]G07)G=6UE;G1S
M.PT*("!C;VQO<B`](%9A;&ED871E0V]L;W(H8V]L;W(I('Q\("<P,#`P,#`G
M.PT*("!6:65W*&-O;&]R*3L@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<V5T(&1E9F%U;'0@
M8V]L;W(-"GT-"@T*9G5N8W1I;VX@5FEE=RAC;VQO<BD@>R`@("`@("`@("`@
M("`@("`@("\O('!R979I97<@8V]L;W(-"B`@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H(D-O;&]R4')E=FEE=R(I+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`]
M("<C)R`K(&-O;&]R.PT*("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B0V]L
M;W)(97@B*2YV86QU92`]("<C)R`K(&-O;&]R.PT*?0T*#0IF=6YC=&EO;B!3
M970H<W1R:6YG*2![("`@("`@("`@("`@("`@("`@("\O('-E;&5C="!C;VQO
M<@T*("!V87(@8V]L;W(@/2!686QI9&%T94-O;&]R*'-T<FEN9RD[#0H@(&EF
M("AC;VQO<B`]/2!N=6QL*2![(&%L97)T*"));G9A;&ED(&-O;&]R(&-O9&4Z
M("(@*R!S=')I;F<I.R!]("`@("`@("`O+R!I;G9A;&ED(&-O;&]R#0H@(&5L
M<V4@>R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!V86QI9"!C;VQO<@T*("`@(%9I
M97<H8V]L;W(I.R`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VAO=R!S
M96QE8W1E9"!C;VQO<@T*("`@(%]?9&QG7V-L;W-E*&-O;&]R*3L-"B`@?0T*
M?0T*#0IF=6YC=&EO;B!686QI9&%T94-O;&]R*'-T<FEN9RD@>R`@("`@("`@
M("`@("`@("`O+R!R971U<FX@=F%L:60@8V]L;W(@8V]D90T*("!S=')I;F<@
M/2!S=')I;F<@?'P@)R<[#0H@('-T<FEN9R`]('-T<FEN9R`K("(B.PT*("!S
M=')I;F<@/2!S=')I;F<N=&]5<'!E<D-A<V4H*3L-"B`@=F%R(&-H87)S(#T@
M)S`Q,C,T-38W.#E!0D-$148G.PT*("!V87(@;W5T("`@/2`G)SL-"@T*("!F
M;W(@*'9A<B!I/3`[(&D\<W1R:6YG+FQE;F=T:#L@:2LK*2![("`@("`@("`@
M("`@("\O(')E;6]V92!I;G9A;&ED(&-O;&]R(&-H87)S#0H@("`@=F%R('-C
M:&%R(#T@<W1R:6YG+F-H87)!="AI*3L-"B`@("!I9B`H8VAA<G,N:6YD97A/
M9BAS8VAA<BD@(3T@+3$I('L@;W5T("L]('-C:&%R.R!]#0H@('T-"@T*("!I
M9B`H;W5T+FQE;F=T:"`A/2`V*2![(')E='5R;B!N=6QL.R!]("`@("`@("`@
M("`@+R\@8VAE8VL@;&5N9W1H#0H@(')E='5R;B!O=70[#0I]#0H-"CPO<V-R
M:7!T/@T*/"]H96%D/@T*/&)O9'D@<W1Y;&4](F)A8VMG<F]U;F0Z0G5T=&]N
M1F%C93L@;6%R9VEN.C!P>#L@<&%D9&EN9SHP<'@B(&]N;&]A9#TB26YI="@I
M(CX-"@T*/&9O<FT@;65T:&]D/2)G970B('-T>6QE/2)M87)G:6XZ,'!X.R!P
M861D:6YG.C!P>"(@;VY3=6)M:70](E-E="AD;V-U;65N="YG971%;&5M96YT
M0GE)9"@G0V]L;W)(97@G*2YV86QU92D[(')E='5R;B!F86QS93LB/@T*/'1A
M8FQE(&)O<F1E<CTB,'!X(B!C96QL<W!A8VEN9STB,'!X(B!C96QL<&%D9&EN
M9STB-"(@=VED=&@](C$P,"4B/@T*(#QT<CX-"B`@/'1D('-T>6QE/2)B86-K
M9W)O=6YD.F)U='1O;F9A8V4B('9A;&EG;CUC96YT97(^/&1I=B!S='EL93TB
M8F%C:V=R;W5N9"UC;VQO<CH@(S`P,#`P,#L@<&%D9&EN9SH@,3L@:&5I9VAT
M.B`R,7!X.R!W:61T:#H@-3!P>"(^/&1I=B!I9#TB0V]L;W)0<F5V:65W(B!S
M='EL93TB:&5I9VAT.B`Q,#`E.R!W:61T:#H@,3`P)2(^/"]D:78^/"]D:78^
M/"]T9#X-"B`@/'1D('-T>6QE/2)B86-K9W)O=6YD.F)U='1O;F9A8V4B('9A
M;&EG;CUC96YT97(^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](D-O;&]R2&5X
M(@T*("`@(&ED/2)#;VQO<DAE>"(@=F%L=64](B(@<VEZ93TQ-2!S='EL93TB
M9F]N="US:7IE.B`Q,G!X(CX\+W1D/@T*("`\=&0@<W1Y;&4](F)A8VMG<F]U
M;F0Z8G5T=&]N9F%C92(@=VED=&@],3`P)3X\+W1D/@T*(#PO='(^#0H\+W1A
M8FQE/@T*/"]F;W)M/@T*#0H\=&%B;&4@8F]R9&5R/2(P(B!C96QL<W!A8VEN
M9STB,7!X(B!C96QL<&%D9&EN9STB,'!X(B!W:61T:#TB,3`P)2(@8F=C;VQO
M<CTB(S`P,#`P,"(@<W1Y;&4](F-U<G-O<CH@:&%N9#LB/@T*/'1R/@T*/'1D
M(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O
M;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE
M=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P(&]N
M36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L:6-K
M/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,#,S,#`@;VY-;W5S94]V97(]5FEE=R@G,#`S
M,S`P)RD@;VY#;&EC:SU3970H)S`P,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-C`P(&]N36]U<V5/
M=F5R/59I97<H)S`P-C8P,"<I(&]N0VQI8VL]4V5T*"<P,#8V,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P
M.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<P,#DY,#`G*2!O;D-L:6-K/5-E="@G
M,#`Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,P,$-#,#`@;VY-;W5S94]V97(]5FEE=R@G,#!#0S`P)RD@
M;VY#;&EC:SU3970H)S`P0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1C`P(&]N36]U<V5/=F5R/59I
M97<H)S`P1D8P,"<I(&]N0VQI8VL]4V5T*"<P,$9&,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,#`P,"!O
M;DUO=7-E3W9E<CU6:65W*"<S,S`P,#`G*2!O;D-L:6-K/5-E="@G,S,P,#`P
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,S,S,#`@;VY-;W5S94]V97(]5FEE=R@G,S,S,S`P)RD@;VY#;&EC
M:SU3970H)S,S,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S,V-C`P(&]N36]U<V5/=F5R/59I97<H)S,S
M-C8P,"<I(&]N0VQI8VL]4V5T*"<S,S8V,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3DP,"!O;DUO=7-E
M3W9E<CU6:65W*"<S,SDY,#`G*2!O;D-L:6-K/5-E="@G,S,Y.3`P)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S
M,T-#,#`@;VY-;W5S94]V97(]5FEE=R@G,S-#0S`P)RD@;VY#;&EC:SU3970H
M)S,S0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC,S-&1C`P(&]N36]U<V5/=F5R/59I97<H)S,S1D8P,"<I
M(&]N0VQI8VL]4V5T*"<S,T9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#`P,"!O;DUO=7-E3W9E<CU6
M:65W*"<V-C`P,#`G*2!O;D-L:6-K/5-E="@G-C8P,#`P)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C,S,#`@
M;VY-;W5S94]V97(]5FEE=R@G-C8S,S`P)RD@;VY#;&EC:SU3970H)S8V,S,P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C8V-C`P(&]N36]U<V5/=F5R/59I97<H)S8V-C8P,"<I(&]N0VQI
M8VL]4V5T*"<V-C8V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<V
M-CDY,#`G*2!O;D-L:6-K/5-E="@G-C8Y.3`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#,#`@;VY-;W5S
M94]V97(]5FEE=R@G-C9#0S`P)RD@;VY#;&EC:SU3970H)S8V0T,P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M-C9&1C`P(&]N36]U<V5/=F5R/59I97<H)S8V1D8P,"<I(&]N0VQI8VL]4V5T
M*"<V-D9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]
M5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,S,S
M(&]N36]U<V5/=F5R/59I97<H)S,S,S,S,R<I(&]N0VQI8VL]4V5T*"<S,S,S
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O;D-L
M:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,S,@;VY-;W5S94]V97(]5FEE=R@G
M,#`P,#,S)RD@;VY#;&EC:SU3970H)S`P,#`S,R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S,S,S(&]N36]U
M<V5/=F5R/59I97<H)S`P,S,S,R<I(&]N0VQI8VL]4V5T*"<P,#,S,S,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P-C8S,R!O;DUO=7-E3W9E<CU6:65W*"<P,#8V,S,G*2!O;D-L:6-K/5-E
M="@G,#`V-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,#DY,S,@;VY-;W5S94]V97(]5FEE=R@G,#`Y.3,S
M)RD@;VY#;&EC:SU3970H)S`P.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0S,S(&]N36]U<V5/=F5R
M/59I97<H)S`P0T,S,R<I(&]N0VQI8VL]4V5T*"<P,$-#,S,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P1D8S
M,R!O;DUO=7-E3W9E<CU6:65W*"<P,$9&,S,G*2!O;D-L:6-K/5-E="@G,#!&
M1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,S`P,S,@;VY-;W5S94]V97(]5FEE=R@G,S,P,#,S)RD@;VY#
M;&EC:SU3970H)S,S,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,S,S(&]N36]U<V5/=F5R/59I97<H
M)S,S,S,S,R<I(&]N0VQI8VL]4V5T*"<S,S,S,S,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S-C8S,R!O;DUO
M=7-E3W9E<CU6:65W*"<S,S8V,S,G*2!O;D-L:6-K/5-E="@G,S,V-C,S)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,S,SDY,S,@;VY-;W5S94]V97(]5FEE=R@G,S,Y.3,S)RD@;VY#;&EC:SU3
M970H)S,S.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC,S-#0S,S(&]N36]U<V5/=F5R/59I97<H)S,S0T,S
M,R<I(&]N0VQI8VL]4V5T*"<S,T-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D8S,R!O;DUO=7-E3W9E
M<CU6:65W*"<S,T9&,S,G*2!O;D-L:6-K/5-E="@G,S-&1C,S)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C`P
M,S,@;VY-;W5S94]V97(]5FEE=R@G-C8P,#,S)RD@;VY#;&EC:SU3970H)S8V
M,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C8S,S,S(&]N36]U<V5/=F5R/59I97<H)S8V,S,S,R<I(&]N
M0VQI8VL]4V5T*"<V-C,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C8S,R!O;DUO=7-E3W9E<CU6:65W
M*"<V-C8V,S,G*2!O;D-L:6-K/5-E="@G-C8V-C,S)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-CDY,S,@;VY-
M;W5S94]V97(]5FEE=R@G-C8Y.3,S)RD@;VY#;&EC:SU3970H)S8V.3DS,R<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC-C9#0S,S(&]N36]U<V5/=F5R/59I97<H)S8V0T,S,R<I(&]N0VQI8VL]
M4V5T*"<V-D-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S8V1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<V-D9&
M,S,G*2!O;D-L:6-K/5-E="@G-C9&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO<CTC,#`P
M,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P
M,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S8V-C8V-B!O;DUO=7-E3W9E<CU6:65W*"<V-C8V-C8G*2!O
M;D-L:6-K/5-E="@G-C8V-C8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]5FEE
M=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#8V(&]N
M36]U<V5/=F5R/59I97<H)S`P,#`V-B<I(&]N0VQI8VL]4V5T*"<P,#`P-C8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<P,#,S-C8G*2!O;D-L:6-K
M/5-E="@G,#`S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,#8V-C8@;VY-;W5S94]V97(]5FEE=R@G,#`V
M-C8V)RD@;VY#;&EC:SU3970H)S`P-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.38V(&]N36]U<V5/
M=F5R/59I97<H)S`P.3DV-B<I(&]N0VQI8VL]4V5T*"<P,#DY-C8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P
M0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<P,$-#-C8G*2!O;D-L:6-K/5-E="@G
M,#!#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,P,$9&-C8@;VY-;W5S94]V97(]5FEE=R@G,#!&1C8V)RD@
M;VY#;&EC:SU3970H)S`P1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P,#8V(&]N36]U<V5/=F5R/59I
M97<H)S,S,#`V-B<I(&]N0VQI8VL]4V5T*"<S,S`P-C8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,S,V-B!O
M;DUO=7-E3W9E<CU6:65W*"<S,S,S-C8G*2!O;D-L:6-K/5-E="@G,S,S,S8V
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,S8V-C8@;VY-;W5S94]V97(]5FEE=R@G,S,V-C8V)RD@;VY#;&EC
M:SU3970H)S,S-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.38V(&]N36]U<V5/=F5R/59I97<H)S,S
M.3DV-B<I(&]N0VQI8VL]4V5T*"<S,SDY-C8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T,V-B!O;DUO=7-E
M3W9E<CU6:65W*"<S,T-#-C8G*2!O;D-L:6-K/5-E="@G,S-#0S8V)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,S
M,T9&-C8@;VY-;W5S94]V97(]5FEE=R@G,S-&1C8V)RD@;VY#;&EC:SU3970H
M)S,S1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C8P,#8V(&]N36]U<V5/=F5R/59I97<H)S8V,#`V-B<I
M(&]N0VQI8VL]4V5T*"<V-C`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,S,V-B!O;DUO=7-E3W9E<CU6
M:65W*"<V-C,S-C8G*2!O;D-L:6-K/5-E="@G-C8S,S8V)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C8V-C8@
M;VY-;W5S94]V97(]5FEE=R@G-C8V-C8V)RD@;VY#;&EC:SU3970H)S8V-C8V
M-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C8Y.38V(&]N36]U<V5/=F5R/59I97<H)S8V.3DV-B<I(&]N0VQI
M8VL]4V5T*"<V-CDY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S8V0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<V
M-D-#-C8G*2!O;D-L:6-K/5-E="@G-C9#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&-C8@;VY-;W5S
M94]V97(]5FEE=R@G-C9&1C8V)RD@;VY#;&EC:SU3970H)S8V1D8V-B<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R/@T*
M/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G
M*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY.3D@;VY-;W5S94]V97(]
M5FEE=R@G.3DY.3DY)RD@;VY#;&EC:SU3970H)SDY.3DY.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,#`P
M(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P,#`P
M,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<P,#`P.3DG*2!O;D-L
M:6-K/5-E="@G,#`P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#,S.3D@;VY-;W5S94]V97(]5FEE=R@G
M,#`S,SDY)RD@;VY#;&EC:SU3970H)S`P,S,Y.2<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`V-CDY(&]N36]U
M<V5/=F5R/59I97<H)S`P-C8Y.2<I(&]N0VQI8VL]4V5T*"<P,#8V.3DG*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<P,#DY.3DG*2!O;D-L:6-K/5-E
M="@G,#`Y.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,$-#.3D@;VY-;W5S94]V97(]5FEE=R@G,#!#0SDY
M)RD@;VY#;&EC:SU3970H)S`P0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!&1CDY(&]N36]U<V5/=F5R
M/59I97<H)S`P1D8Y.2<I(&]N0VQI8VL]4V5T*"<P,$9&.3DG*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,#`Y
M.2!O;DUO=7-E3W9E<CU6:65W*"<S,S`P.3DG*2!O;D-L:6-K/5-E="@G,S,P
M,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,S,S.3D@;VY-;W5S94]V97(]5FEE=R@G,S,S,SDY)RD@;VY#
M;&EC:SU3970H)S,S,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,V-CDY(&]N36]U<V5/=F5R/59I97<H
M)S,S-C8Y.2<I(&]N0VQI8VL]4V5T*"<S,S8V.3DG*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S.3DY.2!O;DUO
M=7-E3W9E<CU6:65W*"<S,SDY.3DG*2!O;D-L:6-K/5-E="@G,S,Y.3DY)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,S,T-#.3D@;VY-;W5S94]V97(]5FEE=R@G,S-#0SDY)RD@;VY#;&EC:SU3
M970H)S,S0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC,S-&1CDY(&]N36]U<V5/=F5R/59I97<H)S,S1D8Y
M.2<I(&]N0VQI8VL]4V5T*"<S,T9&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,#`Y.2!O;DUO=7-E3W9E
M<CU6:65W*"<V-C`P.3DG*2!O;D-L:6-K/5-E="@G-C8P,#DY)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C,S
M.3D@;VY-;W5S94]V97(]5FEE=R@G-C8S,SDY)RD@;VY#;&EC:SU3970H)S8V
M,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C8V-CDY(&]N36]U<V5/=F5R/59I97<H)S8V-C8Y.2<I(&]N
M0VQI8VL]4V5T*"<V-C8V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V.3DY.2!O;DUO=7-E3W9E<CU6:65W
M*"<V-CDY.3DG*2!O;D-L:6-K/5-E="@G-C8Y.3DY)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D-#.3D@;VY-
M;W5S94]V97(]5FEE=R@G-C9#0SDY)RD@;VY#;&EC:SU3970H)S8V0T,Y.2<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC-C9&1CDY(&]N36]U<V5/=F5R/59I97<H)S8V1D8Y.2<I(&]N0VQI8VL]
M4V5T*"<V-D9&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#
M0T-#(&]N36]U<V5/=F5R/59I97<H)T-#0T-#0R<I(&]N0VQI8VL]4V5T*"=#
M0T-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G*2!O
M;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P0T,@;VY-;W5S94]V97(]5FEE
M=R@G,#`P,$-#)RD@;VY#;&EC:SU3970H)S`P,#!#0R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`S,T-#(&]N
M36]U<V5/=F5R/59I97<H)S`P,S-#0R<I(&]N0VQI8VL]4V5T*"<P,#,S0T,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](S`P-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<P,#8V0T,G*2!O;D-L:6-K
M/5-E="@G,#`V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,P,#DY0T,@;VY-;W5S94]V97(]5FEE=R@G,#`Y
M.4-#)RD@;VY#;&EC:SU3970H)S`P.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#!#0T-#(&]N36]U<V5/
M=F5R/59I97<H)S`P0T-#0R<I(&]N0VQI8VL]4V5T*"<P,$-#0T,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S`P
M1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<P,$9&0T,G*2!O;D-L:6-K/5-E="@G
M,#!&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2,S,S`P0T,@;VY-;W5S94]V97(]5FEE=R@G,S,P,$-#)RD@
M;VY#;&EC:SU3970H)S,S,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,S,T-#(&]N36]U<V5/=F5R/59I
M97<H)S,S,S-#0R<I(&]N0VQI8VL]4V5T*"<S,S,S0T,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S-C9#0R!O
M;DUO=7-E3W9E<CU6:65W*"<S,S8V0T,G*2!O;D-L:6-K/5-E="@G,S,V-D-#
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2,S,SDY0T,@;VY-;W5S94]V97(]5FEE=R@G,S,Y.4-#)RD@;VY#;&EC
M:SU3970H)S,S.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC,S-#0T-#(&]N36]U<V5/=F5R/59I97<H)S,S
M0T-#0R<I(&]N0VQI8VL]4V5T*"<S,T-#0T,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S1D9#0R!O;DUO=7-E
M3W9E<CU6:65W*"<S,T9&0T,G*2!O;D-L:6-K/5-E="@G,S-&1D-#)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V
M-C`P0T,@;VY-;W5S94]V97(]5FEE=R@G-C8P,$-#)RD@;VY#;&EC:SU3970H
M)S8V,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC-C8S,T-#(&]N36]U<V5/=F5R/59I97<H)S8V,S-#0R<I
M(&]N0VQI8VL]4V5T*"<V-C,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V-C9#0R!O;DUO=7-E3W9E<CU6
M:65W*"<V-C8V0T,G*2!O;D-L:6-K/5-E="@G-C8V-D-#)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-CDY0T,@
M;VY-;W5S94]V97(]5FEE=R@G-C8Y.4-#)RD@;VY#;&EC:SU3970H)S8V.3E#
M0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC-C9#0T-#(&]N36]U<V5/=F5R/59I97<H)S8V0T-#0R<I(&]N0VQI
M8VL]4V5T*"<V-D-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](S8V1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<V
M-D9&0T,G*2!O;D-L:6-K/5-E="@G-C9&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO<CTC
M,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T
M*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](T9&1D9&1B!O;DUO=7-E3W9E<CU6:65W*"=&1D9&1D8G
M*2!O;D-L:6-K/5-E="@G1D9&1D9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V97(]
M5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P,$9&
M(&]N36]U<V5/=F5R/59I97<H)S`P,#!&1B<I(&]N0VQI8VL]4V5T*"<P,#`P
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](S`P,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<P,#,S1D8G*2!O;D-L
M:6-K/5-E="@G,#`S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#8V1D8@;VY-;W5S94]V97(]5FEE=R@G
M,#`V-D9&)RD@;VY#;&EC:SU3970H)S`P-C9&1B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`Y.49&(&]N36]U
M<V5/=F5R/59I97<H)S`P.3E&1B<I(&]N0VQI8VL]4V5T*"<P,#DY1D8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(S`P0T-&1B!O;DUO=7-E3W9E<CU6:65W*"<P,$-#1D8G*2!O;D-L:6-K/5-E
M="@G,#!#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2,P,$9&1D8@;VY-;W5S94]V97(]5FEE=R@G,#!&1D9&
M)RD@;VY#;&EC:SU3970H)S`P1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,P,$9&(&]N36]U<V5/=F5R
M/59I97<H)S,S,#!&1B<I(&]N0VQI8VL]4V5T*"<S,S`P1D8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S,S-&
M1B!O;DUO=7-E3W9E<CU6:65W*"<S,S,S1D8G*2!O;D-L:6-K/5-E="@G,S,S
M,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2,S,S8V1D8@;VY-;W5S94]V97(]5FEE=R@G,S,V-D9&)RD@;VY#
M;&EC:SU3970H)S,S-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC,S,Y.49&(&]N36]U<V5/=F5R/59I97<H
M)S,S.3E&1B<I(&]N0VQI8VL]4V5T*"<S,SDY1D8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S,S0T-&1B!O;DUO
M=7-E3W9E<CU6:65W*"<S,T-#1D8G*2!O;D-L:6-K/5-E="@G,S-#0T9&)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2,S,T9&1D8@;VY-;W5S94]V97(]5FEE=R@G,S-&1D9&)RD@;VY#;&EC:SU3
M970H)S,S1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC-C8P,$9&(&]N36]U<V5/=F5R/59I97<H)S8V,#!&
M1B<I(&]N0VQI8VL]4V5T*"<V-C`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V,S-&1B!O;DUO=7-E3W9E
M<CU6:65W*"<V-C,S1D8G*2!O;D-L:6-K/5-E="@G-C8S,T9&)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-C8V
M1D8@;VY-;W5S94]V97(]5FEE=R@G-C8V-D9&)RD@;VY#;&EC:SU3970H)S8V
M-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC-C8Y.49&(&]N36]U<V5/=F5R/59I97<H)S8V.3E&1B<I(&]N
M0VQI8VL]4V5T*"<V-CDY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](S8V0T-&1B!O;DUO=7-E3W9E<CU6:65W
M*"<V-D-#1D8G*2!O;D-L:6-K/5-E="@G-C9#0T9&)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,V-D9&1D8@;VY-
M;W5S94]V97(]5FEE=R@G-C9&1D9&)RD@;VY#;&EC:SU3970H)S8V1D9&1B<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*/'1R
M/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1C`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G1D8P,#`P)RD@;VY#;&EC:SU3970H)T9&,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC,#`P
M,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T*"<P
M,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<Y.3`P,#`G*2!O
M;D-L:6-K/5-E="@G.3DP,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S,#`@;VY-;W5S94]V97(]5FEE
M=R@G.3DS,S`P)RD@;VY#;&EC:SU3970H)SDY,S,P,"<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DV-C`P(&]N
M36]U<V5/=F5R/59I97<H)SDY-C8P,"<I(&]N0VQI8VL]4V5T*"<Y.38V,#`G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY.3DP,"!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY,#`G*2!O;D-L:6-K
M/5-E="@G.3DY.3`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,Y.4-#,#`@;VY-;W5S94]V97(]5FEE=R@G.3E#
M0S`P)RD@;VY#;&EC:SU3970H)SDY0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1C`P(&]N36]U<V5/
M=F5R/59I97<H)SDY1D8P,"<I(&]N0VQI8VL]4V5T*"<Y.49&,#`G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M,#`P,"!O;DUO=7-E3W9E<CU6:65W*"=#0S`P,#`G*2!O;D-L:6-K/5-E="@G
M0T,P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0S,S,#`@;VY-;W5S94]V97(]5FEE=R@G0T,S,S`P)RD@
M;VY#;&EC:SU3970H)T-#,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-C`P(&]N36]U<V5/=F5R/59I
M97<H)T-#-C8P,"<I(&]N0VQI8VL]4V5T*"=#0S8V,#`G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#.3DP,"!O
M;DUO=7-E3W9E<CU6:65W*"=#0SDY,#`G*2!O;D-L:6-K/5-E="@G0T,Y.3`P
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-#0T-#,#`@;VY-;W5S94]V97(]5FEE=R@G0T-#0S`P)RD@;VY#;&EC
M:SU3970H)T-#0T,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC0T-&1C`P(&]N36]U<V5/=F5R/59I97<H)T-#
M1D8P,"<I(&]N0VQI8VL]4V5T*"=#0T9&,#`G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`P,"!O;DUO=7-E
M3W9E<CU6:65W*"=&1C`P,#`G*2!O;D-L:6-K/5-E="@G1D8P,#`P)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1C,S,#`@;VY-;W5S94]V97(]5FEE=R@G1D8S,S`P)RD@;VY#;&EC:SU3970H
M)T9&,S,P,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D8V-C`P(&]N36]U<V5/=F5R/59I97<H)T9&-C8P,"<I
M(&]N0VQI8VL]4V5T*"=&1C8V,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3DP,"!O;DUO=7-E3W9E<CU6
M:65W*"=&1CDY,#`G*2!O;D-L:6-K/5-E="@G1D8Y.3`P)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D-#,#`@
M;VY-;W5S94]V97(]5FEE=R@G1D9#0S`P)RD@;VY#;&EC:SU3970H)T9&0T,P
M,"<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C
M;VQO<CTC1D9&1C`P(&]N36]U<V5/=F5R/59I97<H)T9&1D8P,"<I(&]N0VQI
M8VL]4V5T*"=&1D9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S
M94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#!&1C`P(&]N36]U<V5/=F5R/59I97<H)S`P1D8P,"<I(&]N0VQI8VL]4V5T
M*"<P,$9&,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P,#`G
M*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P,S,@;VY-;W5S94]V97(]
M5FEE=R@G.3DP,#,S)RD@;VY#;&EC:SU3970H)SDY,#`S,R<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DS,S,S
M(&]N36]U<V5/=F5R/59I97<H)SDY,S,S,R<I(&]N0VQI8VL]4V5T*"<Y.3,S
M,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY-C8S,R!O;DUO=7-E3W9E<CU6:65W*"<Y.38V,S,G*2!O;D-L
M:6-K/5-E="@G.3DV-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY,S,@;VY-;W5S94]V97(]5FEE=R@G
M.3DY.3,S)RD@;VY#;&EC:SU3970H)SDY.3DS,R<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#0S,S(&]N36]U
M<V5/=F5R/59I97<H)SDY0T,S,R<I(&]N0VQI8VL]4V5T*"<Y.4-#,S,G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(SDY1D8S,R!O;DUO=7-E3W9E<CU6:65W*"<Y.49&,S,G*2!O;D-L:6-K/5-E
M="@G.3E&1C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0S`P,S,@;VY-;W5S94]V97(]5FEE=R@G0T,P,#,S
M)RD@;VY#;&EC:SU3970H)T-#,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,S,S(&]N36]U<V5/=F5R
M/59I97<H)T-#,S,S,R<I(&]N0VQI8VL]4V5T*"=#0S,S,S,G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#-C8S
M,R!O;DUO=7-E3W9E<CU6:65W*"=#0S8V,S,G*2!O;D-L:6-K/5-E="@G0T,V
M-C,S)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-#0SDY,S,@;VY-;W5S94]V97(]5FEE=R@G0T,Y.3,S)RD@;VY#
M;&EC:SU3970H)T-#.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0S,S(&]N36]U<V5/=F5R/59I97<H
M)T-#0T,S,R<I(&]N0VQI8VL]4V5T*"=#0T-#,S,G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#1D8S,R!O;DUO
M=7-E3W9E<CU6:65W*"=#0T9&,S,G*2!O;D-L:6-K/5-E="@G0T-&1C,S)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1C`P,S,@;VY-;W5S94]V97(]5FEE=R@G1D8P,#,S)RD@;VY#;&EC:SU3
M970H)T9&,#`S,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D8S,S,S(&]N36]U<V5/=F5R/59I97<H)T9&,S,S
M,R<I(&]N0VQI8VL]4V5T*"=&1C,S,S,G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C8S,R!O;DUO=7-E3W9E
M<CU6:65W*"=&1C8V,S,G*2!O;D-L:6-K/5-E="@G1D8V-C,S)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1CDY
M,S,@;VY-;W5S94]V97(]5FEE=R@G1D8Y.3,S)RD@;VY#;&EC:SU3970H)T9&
M.3DS,R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC1D9#0S,S(&]N36]U<V5/=F5R/59I97<H)T9&0T,S,R<I(&]N
M0VQI8VL]4V5T*"=&1D-#,S,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D8S,R!O;DUO=7-E3W9E<CU6:65W
M*"=&1D9&,S,G*2!O;D-L:6-K/5-E="@G1D9&1C,S)RD@:&5I9VAT/2(Q,'!X
M(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C;VQO
M<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]
M4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P,#!&1B!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M1D8G*2!O;D-L:6-K/5-E="@G,#`P,$9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S94]V
M97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DP
M,#8V(&]N36]U<V5/=F5R/59I97<H)SDY,#`V-B<I(&]N0VQI8VL]4V5T*"<Y
M.3`P-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY,S,V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S-C8G*2!O
M;D-L:6-K/5-E="@G.3DS,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V-C8@;VY-;W5S94]V97(]5FEE
M=R@G.3DV-C8V)RD@;VY#;&EC:SU3970H)SDY-C8V-B<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY.38V(&]N
M36]U<V5/=F5R/59I97<H)SDY.3DV-B<I(&]N0VQI8VL]4V5T*"<Y.3DY-C8G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY0T,V-B!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#-C8G*2!O;D-L:6-K
M/5-E="@G.3E#0S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2,Y.49&-C8@;VY-;W5S94]V97(]5FEE=R@G.3E&
M1C8V)RD@;VY#;&EC:SU3970H)SDY1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,#8V(&]N36]U<V5/
M=F5R/59I97<H)T-#,#`V-B<I(&]N0VQI8VL]4V5T*"=#0S`P-C8G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M,S,V-B!O;DUO=7-E3W9E<CU6:65W*"=#0S,S-C8G*2!O;D-L:6-K/5-E="@G
M0T,S,S8V)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0S8V-C8@;VY-;W5S94]V97(]5FEE=R@G0T,V-C8V)RD@
M;VY#;&EC:SU3970H)T-#-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.38V(&]N36]U<V5/=F5R/59I
M97<H)T-#.3DV-B<I(&]N0VQI8VL]4V5T*"=#0SDY-C8G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#0T,V-B!O
M;DUO=7-E3W9E<CU6:65W*"=#0T-#-C8G*2!O;D-L:6-K/5-E="@G0T-#0S8V
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-#0T9&-C8@;VY-;W5S94]V97(]5FEE=R@G0T-&1C8V)RD@;VY#;&EC
M:SU3970H)T-#1D8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D8P,#8V(&]N36]U<V5/=F5R/59I97<H)T9&
M,#`V-B<I(&]N0VQI8VL]4V5T*"=&1C`P-C8G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S,V-B!O;DUO=7-E
M3W9E<CU6:65W*"=&1C,S-C8G*2!O;D-L:6-K/5-E="@G1D8S,S8V)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1C8V-C8@;VY-;W5S94]V97(]5FEE=R@G1D8V-C8V)RD@;VY#;&EC:SU3970H
M)T9&-C8V-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D8Y.38V(&]N36]U<V5/=F5R/59I97<H)T9&.3DV-B<I
M(&]N0VQI8VL]4V5T*"=&1CDY-C8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&0T,V-B!O;DUO=7-E3W9E<CU6
M:65W*"=&1D-#-C8G*2!O;D-L:6-K/5-E="@G1D9#0S8V)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&-C8@
M;VY-;W5S94]V97(]5FEE=R@G1D9&1C8V)RD@;VY#;&EC:SU3970H)T9&1D8V
M-B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R/@T*
M/'1R/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P
M,#`P,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&,#`@;VY-;W5S
M94]V97(]5FEE=R@G1D9&1C`P)RD@;VY#;&EC:SU3970H)T9&1D8P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI8VL]4V5T
M*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3`P.3DG
M*2!O;D-L:6-K/5-E="@G.3DP,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3,S.3D@;VY-;W5S94]V97(]
M5FEE=R@G.3DS,SDY)RD@;VY#;&EC:SU3970H)SDY,S,Y.2<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DV-CDY
M(&]N36]U<V5/=F5R/59I97<H)SDY-C8Y.2<I(&]N0VQI8VL]4V5T*"<Y.38V
M.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY.3DY.2!O;DUO=7-E3W9E<CU6:65W*"<Y.3DY.3DG*2!O;D-L
M:6-K/5-E="@G.3DY.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.4-#.3D@;VY-;W5S94]V97(]5FEE=R@G
M.3E#0SDY)RD@;VY#;&EC:SU3970H)SDY0T,Y.2<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E&1CDY(&]N36]U
M<V5/=F5R/59I97<H)SDY1D8Y.2<I(&]N0VQI8VL]4V5T*"<Y.49&.3DG*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#,#`Y.2!O;DUO=7-E3W9E<CU6:65W*"=#0S`P.3DG*2!O;D-L:6-K/5-E
M="@G0T,P,#DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0S,S.3D@;VY-;W5S94]V97(]5FEE=R@G0T,S,SDY
M)RD@;VY#;&EC:SU3970H)T-#,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,V-CDY(&]N36]U<V5/=F5R
M/59I97<H)T-#-C8Y.2<I(&]N0VQI8VL]4V5T*"=#0S8V.3DG*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#.3DY
M.2!O;DUO=7-E3W9E<CU6:65W*"=#0SDY.3DG*2!O;D-L:6-K/5-E="@G0T,Y
M.3DY)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-#0T-#.3D@;VY-;W5S94]V97(]5FEE=R@G0T-#0SDY)RD@;VY#
M;&EC:SU3970H)T-#0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-&1CDY(&]N36]U<V5/=F5R/59I97<H
M)T-#1D8Y.2<I(&]N0VQI8VL]4V5T*"=#0T9&.3DG*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,#`Y.2!O;DUO
M=7-E3W9E<CU6:65W*"=&1C`P.3DG*2!O;D-L:6-K/5-E="@G1D8P,#DY)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1C,S.3D@;VY-;W5S94]V97(]5FEE=R@G1D8S,SDY)RD@;VY#;&EC:SU3
M970H)T9&,S,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D8V-CDY(&]N36]U<V5/=F5R/59I97<H)T9&-C8Y
M.2<I(&]N0VQI8VL]4V5T*"=&1C8V.3DG*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&.3DY.2!O;DUO=7-E3W9E
M<CU6:65W*"=&1CDY.3DG*2!O;D-L:6-K/5-E="@G1D8Y.3DY)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D-#
M.3D@;VY-;W5S94]V97(]5FEE=R@G1D9#0SDY)RD@;VY#;&EC:SU3970H)T9&
M0T,Y.2<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@
M8F=C;VQO<CTC1D9&1CDY(&]N36]U<V5/=F5R/59I97<H)T9&1D8Y.2<I(&]N
M0VQI8VL]4V5T*"=&1D9&.3DG*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X
M(CX\+W1D/@T*/"]T<CX-"CQT<CX-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-
M;W5S94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I
M(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO
M<CTC,#!&1D9&(&]N36]U<V5/=F5R/59I97<H)S`P1D9&1B<I(&]N0VQI8VL]
M4V5T*"<P,$9&1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D
M/@T*/'1D(&)G8V]L;W(](S`P,#`P,"!O;DUO=7-E3W9E<CU6:65W*"<P,#`P
M,#`G*2!O;D-L:6-K/5-E="@G,#`P,#`P)RD@:&5I9VAT/2(Q,'!X(B!W:61T
M:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3`P0T,@;VY-;W5S94]V
M97(]5FEE=R@G.3DP,$-#)RD@;VY#;&EC:SU3970H)SDY,#!#0R<I(&AE:6=H
M=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DS
M,T-#(&]N36]U<V5/=F5R/59I97<H)SDY,S-#0R<I(&]N0VQI8VL]4V5T*"<Y
M.3,S0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D
M(&)G8V]L;W(](SDY-C9#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.38V0T,G*2!O
M;D-L:6-K/5-E="@G.3DV-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P
M>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.3DY0T,@;VY-;W5S94]V97(]5FEE
M=R@G.3DY.4-#)RD@;VY#;&EC:SU3970H)SDY.3E#0R<I(&AE:6=H=#TB,3!P
M>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3E#0T-#(&]N
M36]U<V5/=F5R/59I97<H)SDY0T-#0R<I(&]N0VQI8VL]4V5T*"<Y.4-#0T,G
M*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L
M;W(](SDY1D9#0R!O;DUO=7-E3W9E<CU6:65W*"<Y.49&0T,G*2!O;D-L:6-K
M/5-E="@G.3E&1D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T
M9#X-"CQT9"!B9V-O;&]R/2-#0S`P0T,@;VY-;W5S94]V97(]5FEE=R@G0T,P
M,$-#)RD@;VY#;&EC:SU3970H)T-#,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED
M=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,S,T-#(&]N36]U<V5/
M=F5R/59I97<H)T-#,S-#0R<I(&]N0VQI8VL]4V5T*"=#0S,S0T,G*2!H96EG
M:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#
M-C9#0R!O;DUO=7-E3W9E<CU6:65W*"=#0S8V0T,G*2!O;D-L:6-K/5-E="@G
M0T,V-D-#)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT
M9"!B9V-O;&]R/2-#0SDY0T,@;VY-;W5S94]V97(]5FEE=R@G0T,Y.4-#)RD@
M;VY#;&EC:SU3970H)T-#.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P
M<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T-#0T-#(&]N36]U<V5/=F5R/59I
M97<H)T-#0T-#0R<I(&]N0VQI8VL]4V5T*"=#0T-#0T,G*2!H96EG:'0](C$P
M<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#1D9#0R!O
M;DUO=7-E3W9E<CU6:65W*"=#0T9&0T,G*2!O;D-L:6-K/5-E="@G0T-&1D-#
M)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O
M;&]R/2-&1C`P0T,@;VY-;W5S94]V97(]5FEE=R@G1D8P,$-#)RD@;VY#;&EC
M:SU3970H)T9&,#!#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO
M=&0^#0H\=&0@8F=C;VQO<CTC1D8S,T-#(&]N36]U<V5/=F5R/59I97<H)T9&
M,S-#0R<I(&]N0VQI8VL]4V5T*"=&1C,S0T,G*2!H96EG:'0](C$P<'@B('=I
M9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&-C9#0R!O;DUO=7-E
M3W9E<CU6:65W*"=&1C8V0T,G*2!O;D-L:6-K/5-E="@G1D8V-D-#)RD@:&5I
M9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&
M1CDY0T,@;VY-;W5S94]V97(]5FEE=R@G1D8Y.4-#)RD@;VY#;&EC:SU3970H
M)T9&.3E#0R<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\
M=&0@8F=C;VQO<CTC1D9#0T-#(&]N36]U<V5/=F5R/59I97<H)T9&0T-#0R<I
M(&]N0VQI8VL]4V5T*"=&1D-#0T,G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q
M,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&1D9#0R!O;DUO=7-E3W9E<CU6
M:65W*"=&1D9&0T,G*2!O;D-L:6-K/5-E="@G1D9&1D-#)RD@:&5I9VAT/2(Q
M,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CPO='(^#0H\='(^#0H\=&0@8F=C
M;VQO<CTC,#`P,#`P(&]N36]U<V5/=F5R/59I97<H)S`P,#`P,"<I(&]N0VQI
M8VL]4V5T*"<P,#`P,#`G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\
M+W1D/@T*/'1D(&)G8V]L;W(](T9&,#!&1B!O;DUO=7-E3W9E<CU6:65W*"=&
M1C`P1D8G*2!O;D-L:6-K/5-E="@G1D8P,$9&)RD@:&5I9VAT/2(Q,'!X(B!W
M:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,P,#`P,#`@;VY-;W5S
M94]V97(]5FEE=R@G,#`P,#`P)RD@;VY#;&EC:SU3970H)S`P,#`P,"<I(&AE
M:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC
M.3DP,$9&(&]N36]U<V5/=F5R/59I97<H)SDY,#!&1B<I(&]N0VQI8VL]4V5T
M*"<Y.3`P1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*
M/'1D(&)G8V]L;W(](SDY,S-&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.3,S1D8G
M*2!O;D-L:6-K/5-E="@G.3DS,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB
M,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.38V1D8@;VY-;W5S94]V97(]
M5FEE=R@G.3DV-D9&)RD@;VY#;&EC:SU3970H)SDY-C9&1B<I(&AE:6=H=#TB
M,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC.3DY.49&
M(&]N36]U<V5/=F5R/59I97<H)SDY.3E&1B<I(&]N0VQI8VL]4V5T*"<Y.3DY
M1D8G*2!H96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G
M8V]L;W(](SDY0T-&1B!O;DUO=7-E3W9E<CU6:65W*"<Y.4-#1D8G*2!O;D-L
M:6-K/5-E="@G.3E#0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^
M/"]T9#X-"CQT9"!B9V-O;&]R/2,Y.49&1D8@;VY-;W5S94]V97(]5FEE=R@G
M.3E&1D9&)RD@;VY#;&EC:SU3970H)SDY1D9&1B<I(&AE:6=H=#TB,3!P>"(@
M=VED=&@](C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,P,$9&(&]N36]U
M<V5/=F5R/59I97<H)T-#,#!&1B<I(&]N0VQI8VL]4V5T*"=#0S`P1D8G*2!H
M96EG:'0](C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(]
M(T-#,S-&1B!O;DUO=7-E3W9E<CU6:65W*"=#0S,S1D8G*2!O;D-L:6-K/5-E
M="@G0T,S,T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-
M"CQT9"!B9V-O;&]R/2-#0S8V1D8@;VY-;W5S94]V97(]5FEE=R@G0T,V-D9&
M)RD@;VY#;&EC:SU3970H)T-#-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@]
M(C$P<'@B/CPO=&0^#0H\=&0@8F=C;VQO<CTC0T,Y.49&(&]N36]U<V5/=F5R
M/59I97<H)T-#.3E&1B<I(&]N0VQI8VL]4V5T*"=#0SDY1D8G*2!H96EG:'0]
M(C$P<'@B('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T-#0T-&
M1B!O;DUO=7-E3W9E<CU6:65W*"=#0T-#1D8G*2!O;D-L:6-K/5-E="@G0T-#
M0T9&)RD@:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B
M9V-O;&]R/2-#0T9&1D8@;VY-;W5S94]V97(]5FEE=R@G0T-&1D9&)RD@;VY#
M;&EC:SU3970H)T-#1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B
M/CPO=&0^#0H\=&0@8F=C;VQO<CTC1D8P,$9&(&]N36]U<V5/=F5R/59I97<H
M)T9&,#!&1B<I(&]N0VQI8VL]4V5T*"=&1C`P1D8G*2!H96EG:'0](C$P<'@B
M('=I9'1H/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&,S-&1B!O;DUO
M=7-E3W9E<CU6:65W*"=&1C,S1D8G*2!O;D-L:6-K/5-E="@G1D8S,T9&)RD@
M:&5I9VAT/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R
M/2-&1C8V1D8@;VY-;W5S94]V97(]5FEE=R@G1D8V-D9&)RD@;VY#;&EC:SU3
M970H)T9&-C9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^
M#0H\=&0@8F=C;VQO<CTC1D8Y.49&(&]N36]U<V5/=F5R/59I97<H)T9&.3E&
M1B<I(&]N0VQI8VL]4V5T*"=&1CDY1D8G*2!H96EG:'0](C$P<'@B('=I9'1H
M/2(Q,'!X(CX\+W1D/@T*/'1D(&)G8V]L;W(](T9&0T-&1B!O;DUO=7-E3W9E
M<CU6:65W*"=&1D-#1D8G*2!O;D-L:6-K/5-E="@G1D9#0T9&)RD@:&5I9VAT
M/2(Q,'!X(B!W:61T:#TB,3!P>"(^/"]T9#X-"CQT9"!B9V-O;&]R/2-&1D9&
M1D8@;VY-;W5S94]V97(]5FEE=R@G1D9&1D9&)RD@;VY#;&EC:SU3970H)T9&
M1D9&1B<I(&AE:6=H=#TB,3!P>"(@=VED=&@](C$P<'@B/CPO=&0^#0H\+W1R
M/@T*/"]T86)L93X-"@T*/"]B;V1Y/CPO:'1M;#X-"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P
M;W!U<',O:6YS97)T7W1A8FQE+FAT;6P`````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,34R-2`Q,#4Q
M-30S-#$T,R`P,C<S,S0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/&AT;6P^"@H\:&5A9#X*("`\=&ET;&4^26YS97)T(%1A
M8FQE/"]T:71L93X*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S
M<F,](G!O<'5P+FIS(CX\+W-C<FEP=#X*"CQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CX*"G=I;F1O=RYR97-I>F54;R@T,#`L(#$P,"D["@IF=6YC
M=&EO;B!);FET*"D@>PH@(&DQ.&X@/2!W:6YD;W<N;W!E;F5R+DA434Q!<F5A
M+DDQ.$XN9&EA;&]G<SL@+R\@;&]A9"!T:&4@2%1-3$%R96$@<&QU9VEN(&%N
M9"!L86YG(&9I;&4*("!?7V1L9U]T<F%N<VQA=&4H:3$X;BD["B`@7U]D;&=?
M:6YI="@I.PH@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W)O=W,B*2YF
M;V-U<R@I.PI].PH*9G5N8W1I;VX@;VY/2R@I('L*("!V87(@<F5Q=6ER960@
M/2!["B`@("`B9E]R;W=S(CH@(EEO=2!M=7-T(&5N=&5R(&$@;G5M8F5R(&]F
M(')O=W,B+`H@("`@(F9?8V]L<R(Z(")9;W4@;75S="!E;G1E<B!A(&YU;6)E
M<B!O9B!C;VQU;6YS(@H@('T["B`@9F]R("AV87(@:2!I;B!R97%U:7)E9"D@
M>PH@("`@=F%R(&5L(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:2D["B`@
M("!I9B`H(65L+G9A;'5E*2!["B`@("`@(&%L97)T*')E<75I<F5D6VE=*3L*
M("`@("`@96PN9F]C=7,H*3L*("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@
M('T*("!V87(@9FEE;&1S(#T@6R)F7W)O=W,B+"`B9E]C;VQS(BP@(F9?=VED
M=&@B+"`B9E]U;FET(BP@(F9?9FEX960B+`H@("`@("`@("`@("`@("`@(F9?
M86QI9VXB+"`B9E]B;W)D97(B+"`B9E]S<&%C:6YG(BP@(F9?<&%D9&EN9R)=
M.PH@('9A<B!P87)A;2`](&YE=R!/8FIE8W0H*3L*("!F;W(@*'9A<B!I(&EN
M(&9I96QD<RD@>PH@("`@=F%R(&ED(#T@9FEE;&1S6VE=.PH@("`@=F%R(&5L
M(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I.PH@("`@<&%R86U;:61=
M(#T@*&5L+G1Y<&4@/3T@(F-H96-K8F]X(BD@/R!E;"YC:&5C:V5D(#H@96PN
M=F%L=64["B`@?0H@(%]?9&QG7V-L;W-E*'!A<F%M*3L*("!R971U<FX@9F%L
M<V4["GT["@IF=6YC=&EO;B!O;D-A;F-E;"@I('L*("!?7V1L9U]C;&]S92AN
M=6QL*3L*("!R971U<FX@9F%L<V4["GT["@H\+W-C<FEP=#X*"CQS='EL92!T
M>7!E/2)T97AT+V-S<R(^"FAT;6PL(&)O9'D@>PH@(&)A8VMG<F]U;F0Z($)U
M='1O;D9A8V4["B`@8V]L;W(Z($)U='1O;E1E>'0["B`@9F]N=#H@,3%P>"!4
M86AO;6$L5F5R9&%N82QS86YS+7-E<FEF.PH@(&UA<F=I;CH@,'!X.PH@('!A
M9&1I;F<Z(#!P>#L*?0IB;V1Y('L@<&%D9&EN9SH@-7!X.R!]"G1A8FQE('L*
M("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["GT*9F]R
M;2!P('L*("!M87)G:6XM=&]P.B`U<'@["B`@;6%R9VEN+6)O='1O;3H@-7!X
M.PI]"BYF;"![('=I9'1H.B`Y96T[(&9L;V%T.B!L969T.R!P861D:6YG.B`R
M<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@?0HN9G(@>R!W:61T:#H@-V5M
M.R!F;&]A=#H@;&5F=#L@<&%D9&EN9SH@,G!X(#5P>#L@=&5X="UA;&EG;CH@
M<FEG:'0[('T*9FEE;&1S970@>R!P861D:6YG.B`P<'@@,3!P>"`U<'@@-7!X
M.R!]"G-E;&5C="P@:6YP=70L(&)U='1O;B![(&9O;G0Z(#$Q<'@@5&%H;VUA
M+%9E<F1A;F$L<V%N<RUS97)I9CL@?0IB=71T;VX@>R!W:61T:#H@-S!P>#L@
M?0HN<W!A8V4@>R!P861D:6YG.B`R<'@[('T*"BYT:71L92![(&)A8VMG<F]U
M;F0Z("-D9&8[(&-O;&]R.B`C,#`P.R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N
M="US:7IE.B`Q,C`E.R!P861D:6YG.B`S<'@@,3!P>#L@;6%R9VEN+6)O='1O
M;3H@,3!P>#L*8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L86-K.R!L971T
M97(M<W!A8VEN9SH@,G!X.PI]"F9O<FT@>R!P861D:6YG.B`P<'@[(&UA<F=I
M;CH@,'!X.R!]"CPO<W1Y;&4^"@H\+VAE860^"@H\8F]D>2!O;FQO860](DEN
M:70H*2(^"@H\9&EV(&-L87-S/2)T:71L92(^26YS97)T(%1A8FQE/"]D:78^
M"@H\9F]R;2!A8W1I;VX](B(@;65T:&]D/2)G970B/@H\=&%B;&4@8F]R9&5R
M/2(P(B!S='EL93TB<&%D9&EN9SH@,'!X.R!M87)G:6XZ(#!P>"(^"B`@/'1B
M;V1Y/@H*("`\='(^"B`@("`\=&0@<W1Y;&4](G=I9'1H.B`T96T[('1E>'0M
M86QI9VXZ(')I9VAT(CY2;W=S.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4]
M(G1E>'0B(&YA;64](G)O=W,B(&ED/2)F7W)O=W,B('-I>F4](C4B('1I=&QE
M/2).=6UB97(@;V8@<F]W<R(@=F%L=64](C(B("\^/"]T9#X*("`@(#QT9"!S
M='EL93TB=VED=&@Z(#1E;3L@=&5X="UA;&EG;CH@<FEG:'0B/E=I9'1H.CPO
M=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G=I9'1H(B!I
M9#TB9E]W:61T:"(@<VEZ93TB-2(@=&ET;&4](E=I9'1H(&]F('1H92!T86)L
M92(@=F%L=64](C$P,"(@+SX\+W1D/@H@("`@/'1D/CQS96QE8W0@<VEZ93TB
M,2(@;F%M93TB=6YI="(@:60](F9?=6YI="(@=&ET;&4](E=I9'1H('5N:70B
M/@H@("`@("`\;W!T:6]N('9A;'5E/2(E(B!S96QE8W1E9#TB,2(@(#Y097)C
M96YT/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](G!X(B`@("`@("`@
M("`@("`@/E!I>&5L<SPO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E/2)E
M;2(@("`@("`@("`@("`@(#Y%;3PO;W!T:6]N/@H@("`@/"]S96QE8W0^/"]T
M9#X*("`\+W1R/@H@(#QT<CX*("`@(#QT9"!S='EL93TB=VED=&@Z(#1E;3L@
M=&5X="UA;&EG;CH@<FEG:'0B/D-O;',Z/"]T9#X*("`@(#QT9#X\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB8V]L<R(@:60](F9?8V]L<R(@<VEZ93TB-2(@
M=&ET;&4](DYU;6)E<B!O9B!C;VQU;6YS(B!V86QU93TB-"(@+SX\+W1D/@H@
M("`@/'1D('-T>6QE/2)T97AT+6%L:6=N.B!R:6=H="(^/&EN<'5T('1Y<&4]
M(F-H96-K8F]X(B!C:&5C:V5D/2)C:&5C:V5D(B!N86UE/2)F:7AE9"(@:60]
M(F9?9FEX960B("\^/"]T9#X*("`@(#QT9"!C;VQS<&%N/2(R(CX\;&%B96P@
M9F]R/2)F7V9I>&5D(@H@("`@/D9I>&5D('=I9'1H(&-O;'5M;G,\+VQA8F5L
M/CPO=&0^"B`@/"]T<CX*("`\+W1B;V1Y/@H\+W1A8FQE/@H*/'`@+SX*"CQF
M:65L9'-E="!S='EL93TB9FQO870Z(&QE9G0[(&UA<F=I;BUL969T.B`U<'@[
M(CX*/&QE9V5N9#Y,87EO=70\+VQE9V5N9#X*"CQD:78@8VQA<W,](G-P86-E
M(CX\+V1I=CX*"CQD:78@8VQA<W,](F9L(CY!;&EG;FUE;G0Z/"]D:78^"CQS
M96QE8W0@<VEZ93TB,2(@;F%M93TB86QI9VXB(&ED/2)F7V%L:6=N(@H@('1I
M=&QE/2)0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(CX*("`\;W!T:6]N('9A
M;'5E/2(B('-E;&5C=&5D/2(Q(B`@("`@("`@("`@("`@("`^3F]T('-E=#PO
M;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](FQE9G0B("`@("`@("`@("`@("`@
M("`@("`@("`@(#Y,969T/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB<FEG
M:'0B("`@("`@("`@("`@("`@("`@("`@("`@/E)I9VAT/"]O<'1I;VX^"B`@
M/&]P=&EO;B!V86QU93TB=&5X='1O<"(@("`@("`@("`@("`@("`@("`@("`@
M/E1E>'1T;W`\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)A8G-M:61D;&4B
M("`@("`@("`@("`@("`@("`@("`^06)S;6ED9&QE/"]O<'1I;VX^"B`@/&]P
M=&EO;B!V86QU93TB8F%S96QI;F4B("`@("`@("`@("`@("`@("`@("`@/D)A
M<V5L:6YE/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU93TB86)S8F]T=&]M(B`@
M("`@("`@("`@("`@("`@("`@/D%B<V)O='1O;3PO;W!T:6]N/@H@(#QO<'1I
M;VX@=F%L=64](F)O='1O;2(@("`@("`@("`@("`@("`@("`@("`@(#Y";W1T
M;VT\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)M:61D;&4B("`@("`@("`@
M("`@("`@("`@("`@("`^36ED9&QE/"]O<'1I;VX^"B`@/&]P=&EO;B!V86QU
M93TB=&]P(B`@("`@("`@("`@("`@("`@("`@("`@("`@/E1O<#PO;W!T:6]N
M/@H\+W-E;&5C=#X*"CQP("\^"@H\9&EV(&-L87-S/2)F;"(^0F]R9&5R('1H
M:6-K;F5S<SH\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F)O<F1E
M<B(@:60](F9?8F]R9&5R(B!S:7IE/2(U(B!V86QU93TB,2(*=&ET;&4](DQE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B("\^"CPA+2T*/'`@+SX*"CQD:78@
M8VQA<W,](F9L(CY#;VQL87!S92!B;W)D97)S.CPO9&EV/@H\:6YP=70@='EP
M93TB8VAE8VMB;W@B(&YA;64](F-O;&QA<'-E(B!I9#TB9E]C;VQL87!S92(@
M+SX*+2T^"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CPO9FEE;&1S970^
M"@H\9FEE;&1S970@<W1Y;&4](F9L;V%T.G)I9VAT.R!M87)G:6XM<FEG:'0Z
M(#5P>#LB/@H\;&5G96YD/E-P86-I;F<\+VQE9V5N9#X*"CQD:78@8VQA<W,]
M(G-P86-E(CX\+V1I=CX*"CQD:78@8VQA<W,](F9R(CY#96QL('-P86-I;F<Z
M/"]D:78^"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)S<&%C:6YG(B!I9#TB
M9E]S<&%C:6YG(B!S:7IE/2(U(B!V86QU93TB,2(*=&ET;&4](E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B("\^"@H\<"`O/@H*/&1I=B!C;&%S<STB
M9G(B/D-E;&P@<&%D9&EN9SH\+V1I=CX*/&EN<'5T('1Y<&4](G1E>'0B(&YA
M;64](G!A9&1I;F<B(&ED/2)F7W!A9&1I;F<B('-I>F4](C4B('9A;'5E/2(Q
M(@IT:71L93TB4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@
M8V5L;"(@+SX*"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*"CPO9FEE;&1S
M970^"@H\9&EV('-T>6QE/2)M87)G:6XM=&]P.B`X-7!X.R!B;W)D97(M=&]P
M.B`Q<'@@<V]L:60@(SDY.3L@<&%D9&EN9SH@,G!X.R!T97AT+6%L:6=N.B!R
M:6=H=#LB/@H\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB;VLB(&]N8VQI
M8VL](G)E='5R;B!O;D]+*"D[(CY/2SPO8G5T=&]N/@H\8G5T=&]N('1Y<&4]
M(F)U='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC
M96PH*3LB/D-A;F-E;#PO8G5T=&]N/@H\+V1I=CX*"CPO9F]R;3X*"CPO8F]D
M>3X*/"]H=&UL/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M
M;&%R96$O<&]P=7!S+VQI;FLN:'1M;```````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`T
M,S8@,3`U,34T,S0Q-#,@,#(U-C$V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#QH=&UL/@H*/&AE860^"B`@/'1I=&QE/DEN
M<V5R="]-;V1I9GD@3&EN:SPO=&ET;&4^"B`@/'-C<FEP="!T>7!E/2)T97AT
M+VIA=F%S8W)I<'0B('-R8STB<&]P=7`N:G,B/CPO<V-R:7!T/@H@(#QS8W)I
M<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@('=I;F1O=RYR97-I>F54
M;R@T,#`L(#(P,"D["@I),3A.(#T@=VEN9&]W+F]P96YE<BY(5$U,07)E82Y)
M,3A.+F1I86QO9W,["@IF=6YC=&EO;B!I,3AN*'-T<BD@>PH@(')E='5R;B`H
M23$X3EMS=')=('Q\('-T<BD["GT["@IF=6YC=&EO;B!O;E1A<F=E=$-H86YG
M960H*2!["B`@=F%R(&8@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]O
M=&AE<E]T87)G970B*3L*("!I9B`H=&AI<RYV86QU92`]/2`B7V]T:&5R(BD@
M>PH@("`@9BYS='EL92YV:7-I8FEL:71Y(#T@(G9I<VEB;&4B.PH@("`@9BYS
M96QE8W0H*3L*("`@(&8N9F]C=7,H*3L*("!](&5L<V4@9BYS='EL92YV:7-I
M8FEL:71Y(#T@(FAI9&1E;B(["GT["@IF=6YC=&EO;B!);FET*"D@>PH@(%]?
M9&QG7W1R86YS;&%T92A),3A.*3L*("!?7V1L9U]I;FET*"D["B`@=F%R('!A
M<F%M(#T@=VEN9&]W+F1I86QO9T%R9W5M96YT<SL*("!V87(@=&%R9V5T7W-E
M;&5C="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W1A<F=E="(I.PH@
M('9A<B!U<V5?=&%R9V5T(#T@=')U93L*("!I9B`H<&%R86TI('L*("`@(&EF
M("@@='EP96]F('!A<F%M6R)F7W5S971A<F=E=")=("$](")U;F1E9FEN960B
M("D@>PH@("`@("!U<V5?=&%R9V5T(#T@<&%R86U;(F9?=7-E=&%R9V5T(ET[
M"B`@("!]"B`@("!I9B`H('1Y<&5O9B!P87)A;5LB9E]H<F5F(ET@(3T@(G5N
M9&5F:6YE9"(@*2!["B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F
M7VAR968B*2YV86QU92`]('!A<F%M6R)F7VAR968B73L*("`@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H(F9?=&ET;&4B*2YV86QU92`]('!A<F%M6R)F
M7W1I=&QE(ET["B`@("`@(&-O;6)O4V5L96-T5F%L=64H=&%R9V5T7W-E;&5C
M="P@<&%R86U;(F9?=&%R9V5T(ETI.PH@("`@("!I9B`H=&%R9V5T7W-E;&5C
M="YV86QU92`A/2!P87)A;2YF7W1A<F=E="D@>PH@("`@("`@('9A<B!O<'0@
M/2!D;V-U;65N="YC<F5A=&5%;&5M96YT*")O<'1I;VXB*3L*("`@("`@("!O
M<'0N=F%L=64@/2!P87)A;2YF7W1A<F=E=#L*("`@("`@("!O<'0N:6YN97)(
M5$U,(#T@;W!T+G9A;'5E.PH@("`@("`@('1A<F=E=%]S96QE8W0N87!P96YD
M0VAI;&0H;W!T*3L*("`@("`@("!O<'0N<V5L96-T960@/2!T<G5E.PH@("`@
M("!]"B`@("!]"B`@?0H@(&EF("@A('5S95]T87)G970I('L*("`@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")F7W1A<F=E=%]L86)E;"(I+G-T>6QE+G9I
M<VEB:6QI='D@/2`B:&ED9&5N(CL*("`@(&1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*")F7W1A<F=E="(I+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*
M("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F7W1A<F=E=%]O=&AE<B(I
M+G-T>6QE+G9I<VEB:6QI='D@/2`B:&ED9&5N(CL*("!]"B`@=F%R(&]P="`]
M(&1O8W5M96YT+F-R96%T945L96UE;G0H(F]P=&EO;B(I.PH@(&]P="YV86QU
M92`](")?;W1H97(B.PH@(&]P="YI;FYE<DA434P@/2!I,3AN*")/=&AE<B(I
M.PH@('1A<F=E=%]S96QE8W0N87!P96YD0VAI;&0H;W!T*3L*("!T87)G971?
M<V5L96-T+F]N8VAA;F=E(#T@;VY487)G971#:&%N9V5D.PH@(&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YF;V-U<R@I.PH@(&1O8W5M96YT
M+F=E=$5L96UE;G1">4ED*")F7VAR968B*2YS96QE8W0H*3L*?3L*"F9U;F-T
M:6]N(&]N3TLH*2!["B`@=F%R(')E<75I<F5D(#T@>PH@("`@+R\@9E]H<F5F
M('-H;W5L9&XG="!B92!R97%U:7)E9"!O<B!O=&AE<G=I<V4@<F5M;W9I;F<@
M=&AE(&QI;FL@8GD@96YT97)I;F<@86X@96UP='D-"B`@("`O+R!U<FP@:7-N
M)W0@<&]S<VEB;&4@86YY;6]R92X-"B`@("`O+R`B9E]H<F5F(CH@:3$X;B@B
M66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S
M('1O(BD-"B`@?3L*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D*2!["B`@("!V
M87(@96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"AI*3L*("`@(&EF("@A
M96PN=F%L=64I('L*("`@("`@86QE<G0H<F5Q=6ER961;:5TI.PH@("`@("!E
M;"YF;V-U<R@I.PH@("`@("!R971U<FX@9F%L<V4["B`@("!]"B`@?0H@("\O
M('!A<W,@9&%T82!B86-K('1O('1H92!C86QL:6YG('=I;F1O=PH@('9A<B!F
M:65L9',@/2!;(F9?:')E9B(L(")F7W1I=&QE(BP@(F9?=&%R9V5T(B!=.PH@
M('9A<B!P87)A;2`](&YE=R!/8FIE8W0H*3L*("!F;W(@*'9A<B!I(&EN(&9I
M96QD<RD@>PH@("`@=F%R(&ED(#T@9FEE;&1S6VE=.PH@("`@=F%R(&5L(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:60I.PH@("`@<&%R86U;:61=(#T@
M96PN=F%L=64["B`@?0H@(&EF("AP87)A;2YF7W1A<F=E="`]/2`B7V]T:&5R
M(BD*("`@('!A<F%M+F9?=&%R9V5T(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y
M260H(F9?;W1H97)?=&%R9V5T(BDN=F%L=64["B`@7U]D;&=?8VQO<V4H<&%R
M86TI.PH@(')E='5R;B!F86QS93L*?3L*"F9U;F-T:6]N(&]N0V%N8V5L*"D@
M>PH@(%]?9&QG7V-L;W-E*&YU;&PI.PH@(')E='5R;B!F86QS93L*?3L*"CPO
M<V-R:7!T/@H*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*:'1M;"P@8F]D>2![
M"B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO<CH@0G5T=&]N5&5X
M=#L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68["B`@
M;6%R9VEN.B`P<'@["B`@<&%D9&EN9SH@,'!X.PI]"F)O9'D@>R!P861D:6YG
M.B`U<'@[('T*=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L
M<V%N<RUS97)I9CL*?0IS96QE8W0L(&EN<'5T+"!B=71T;VX@>R!F;VYT.B`Q
M,7!X(%1A:&]M82Q697)D86YA+'-A;G,M<V5R:68[('T*8G5T=&]N('L@=VED
M=&@Z(#<P<'@[('T*=&%B;&4@+FQA8F5L('L@=&5X="UA;&EG;CH@<FEG:'0[
M('=I9'1H.B`X96T[('T*"BYT:71L92![(&)A8VMG<F]U;F0Z("-D9&8[(&-O
M;&]R.B`C,#`P.R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US:7IE.B`Q,C`E
M.R!P861D:6YG.B`S<'@@,3!P>#L@;6%R9VEN+6)O='1O;3H@,3!P>#L*8F]R
M9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L86-K.R!L971T97(M<W!A8VEN9SH@
M,G!X.PI]"@HC8G5T=&]N<R!["B`@("`@(&UA<F=I;BUT;W`Z(#%E;3L@8F]R
M9&5R+71O<#H@,7!X('-O;&ED(",Y.3D["B`@("`@('!A9&1I;F<Z(#)P>#L@
M=&5X="UA;&EG;CH@<FEG:'0["GT*/"]S='EL93X*"CPO:&5A9#X*"CQB;V1Y
M(&]N;&]A9#TB26YI="@I(CX*/&1I=B!C;&%S<STB=&ET;&4B/DEN<V5R="]-
M;V1I9GD@3&EN:SPO9&EV/@H\9F]R;3X*/'1A8FQE(&)O<F1E<CTB,"(@<W1Y
M;&4](G=I9'1H.B`Q,#`E.R(^"B`@/'1R/@H@("`@/'1D(&-L87-S/2)L86)E
M;"(^55),.CPO=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&ED/2)F
M7VAR968B('-T>6QE/2)W:61T:#H@,3`P)2(@+SX\+W1D/@H@(#PO='(^"B`@
M/'1R/@H@("`@/'1D(&-L87-S/2)L86)E;"(^5&ET;&4@*'1O;VQT:7`I.CPO
M=&0^"B`@("`\=&0^/&EN<'5T('1Y<&4](G1E>'0B(&ED/2)F7W1I=&QE(B!S
M='EL93TB=VED=&@Z(#$P,"4B("\^/"]T9#X*("`\+W1R/@H@(#QT<CX*("`@
M(#QT9"!C;&%S<STB;&%B96PB/CQS<&%N(&ED/2)F7W1A<F=E=%]L86)E;"(^
M5&%R9V5T.CPO<W!A;CX\+W1D/@H@("`@/'1D/CQS96QE8W0@:60](F9?=&%R
M9V5T(CX*("`@("`@/&]P=&EO;B!V86QU93TB(CY.;VYE("AU<V4@:6UP;&EC
M:70I/"]O<'1I;VX^"B`@("`@(#QO<'1I;VX@=F%L=64](E]B;&%N:R(^3F5W
M('=I;F1O=R`H7V)L86YK*3PO;W!T:6]N/@H@("`@("`\;W!T:6]N('9A;'5E
M/2)?<V5L9B(^4V%M92!F<F%M92`H7W-E;&8I/"]O<'1I;VX^"B`@("`@(#QO
M<'1I;VX@=F%L=64](E]T;W`B/E1O<"!F<F%M92`H7W1O<"D\+V]P=&EO;CX*
M("`@(#PO<V5L96-T/@H@("`@/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F9?
M;W1H97)?=&%R9V5T(B!I9#TB9E]O=&AE<E]T87)G970B('-I>F4](C$P(B!S
M='EL93TB=FES:6)I;&ET>3H@:&ED9&5N(B`O/@H@("`@/"]T9#X*("`\+W1R
M/@H\+W1A8FQE/@H*/&1I=B!I9#TB8G5T=&]N<R(^"B`@/&)U='1O;B!T>7!E
M/2)S=6)M:70B(&YA;64](F]K(B!O;F-L:6-K/2)R971U<FX@;VY/2R@I.R(^
M3TL\+V)U='1O;CX*("`\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB8V%N
M8V5L(B!O;F-L:6-K/2)R971U<FX@;VY#86YC96PH*3LB/D-A;F-E;#PO8G5T
M=&]N/@H\+V1I=CX*/"]F;W)M/@H\+V)O9'D^"CPO:'1M;#X*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;W!U
M<',O8FQA;FLN:'1M;```````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`Q-R`Q,#4Q-30S
M-#$T,R`P,C4W-#(`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&AT;6P^#0H\+VAT;6P^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&]P=7!S+VEN<V5R=%]I
M;6%G92YH=&UL````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(S-3`@,3`U,34T,S0Q-#,@,#(W,S(T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#QH
M=&UL/@T*#0H\:&5A9#X-"B`@/'1I=&QE/DEN<V5R="!);6%G93PO=&ET;&4^
M#0H-"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](G!O<'5P
M+FIS(CX\+W-C<FEP=#X-"@T*/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I
M<'0B/@T*#0IW:6YD;W<N<F5S:7IE5&\H-#`P+"`Q,#`I.PT*#0IF=6YC=&EO
M;B!);FET*"D@>PT*("!?7V1L9U]I;FET*"D[#0H@('9A<B!P87)A;2`]('=I
M;F1O=RYD:6%L;V=!<F=U;65N=',[#0H@(&EF("AP87)A;2D@>PT*("`@("`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=7)L(BDN=F%L=64@/2!P87)A
M;5LB9E]U<FPB73L-"B`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*")F
M7V%L="(I+G9A;'5E(#T@<&%R86U;(F9?86QT(ET[#0H@("`@("!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@B9E]B;W)D97(B*2YV86QU92`]('!A<F%M6R)F
M7V)O<F1E<B)=.PT*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?
M86QI9VXB*2YV86QU92`]('!A<F%M6R)F7V%L:6=N(ET[#0H@("`@("!D;V-U
M;65N="YG971%;&5M96YT0GE)9"@B9E]V97)T(BDN=F%L=64@/2!P87)A;5LB
M9E]V97)T(ET[#0H@("`@("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]H
M;W)I>B(I+G9A;'5E(#T@<&%R86U;(F9?:&]R:7HB73L-"B`@("`@('=I;F1O
M=RYI<')E=FEE=RYL;V-A=&EO;BYR97!L86-E*'!A<F%M+F9?=7)L*3L-"B`@
M?0T*("!D;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]U<FPB*2YF;V-U<R@I
M.PT*?3L-"@T*9G5N8W1I;VX@;VY/2R@I('L-"B`@=F%R(')E<75I<F5D(#T@
M>PT*("`@(")F7W5R;"(Z(")9;W4@;75S="!E;G1E<B!T:&4@55),(@T*("!]
M.PT*("!F;W(@*'9A<B!I(&EN(')E<75I<F5D*2![#0H@("`@=F%R(&5L(#T@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H:2D[#0H@("`@:68@*"%E;"YV86QU
M92D@>PT*("`@("`@86QE<G0H<F5Q=6ER961;:5TI.PT*("`@("`@96PN9F]C
M=7,H*3L-"B`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H@('T-"B`@+R\@
M<&%S<R!D871A(&)A8VL@=&\@=&AE(&-A;&QI;F<@=VEN9&]W#0H@('9A<B!F
M:65L9',@/2!;(F9?=7)L(BP@(F9?86QT(BP@(F9?86QI9VXB+"`B9E]B;W)D
M97(B+`T*("`@("`@("`@("`@("`@(")F7VAO<FEZ(BP@(F9?=F5R=")=.PT*
M("!V87(@<&%R86T@/2!N97<@3V)J96-T*"D[#0H@(&9O<B`H=F%R(&D@:6X@
M9FEE;&1S*2![#0H@("`@=F%R(&ED(#T@9FEE;&1S6VE=.PT*("`@('9A<B!E
M;"`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*&ED*3L-"B`@("!P87)A;5MI
M9%T@/2!E;"YV86QU93L-"B`@?0T*("!?7V1L9U]C;&]S92AP87)A;2D[#0H@
M(')E='5R;B!F86QS93L-"GT[#0H-"F9U;F-T:6]N(&]N0V%N8V5L*"D@>PT*
M("!?7V1L9U]C;&]S92AN=6QL*3L-"B`@<F5T=7)N(&9A;'-E.PT*?3L-"@T*
M9G5N8W1I;VX@;VY0<F5V:65W*"D@>PT*("!V87(@9E]U<FP@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@B9E]U<FPB*3L-"B`@=F%R('5R;"`](&9?=7)L
M+G9A;'5E.PT*("!I9B`H(75R;"D@>PT*("`@(&%L97)T*")9;W4@:&%V92!T
M;R!E;G1E<B!A;B!54DP@9FER<W0B*3L-"B`@("!F7W5R;"YF;V-U<R@I.PT*
M("`@(')E='5R;B!F86QS93L-"B`@?0T*("!W:6YD;W<N:7!R979I97<N;&]C
M871I;VXN<F5P;&%C92AU<FPI.PT*("!R971U<FX@9F%L<V4[#0I].PT*/"]S
M8W)I<'0^#0H-"CQS='EL92!T>7!E/2)T97AT+V-S<R(^#0IH=&UL+"!B;V1Y
M('L-"B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L-"B`@8V]L;W(Z($)U='1O
M;E1E>'0[#0H@(&9O;G0Z(#$Q<'@@5&%H;VUA+%9E<F1A;F$L<V%N<RUS97)I
M9CL-"B`@;6%R9VEN.B`P<'@[#0H@('!A9&1I;F<Z(#!P>#L-"GT-"F)O9'D@
M>R!P861D:6YG.B`U<'@[('T-"G1A8FQE('L-"B`@9F]N=#H@,3%P>"!486AO
M;6$L5F5R9&%N82QS86YS+7-E<FEF.PT*?0T*9F]R;2!P('L-"B`@;6%R9VEN
M+71O<#H@-7!X.PT*("!M87)G:6XM8F]T=&]M.B`U<'@[#0I]#0HN9FP@>R!W
M:61T:#H@.65M.R!F;&]A=#H@;&5F=#L@<&%D9&EN9SH@,G!X(#5P>#L@=&5X
M="UA;&EG;CH@<FEG:'0[('T-"BYF<B![('=I9'1H.B`V96T[(&9L;V%T.B!L
M969T.R!P861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@?0T*
M9FEE;&1S970@>R!P861D:6YG.B`P<'@@,3!P>"`U<'@@-7!X.R!]#0IS96QE
M8W0L(&EN<'5T+"!B=71T;VX@>R!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA
M+'-A;G,M<V5R:68[('T-"F)U='1O;B![('=I9'1H.B`W,'!X.R!]#0HN<W!A
M8V4@>R!P861D:6YG.B`R<'@[('T-"@T*+G1I=&QE('L@8F%C:V=R;W5N9#H@
M(V1D9CL@8V]L;W(Z(",P,#`[(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-I
M>F4Z(#$R,"4[('!A9&1I;F<Z(#-P>"`Q,'!X.R!M87)G:6XM8F]T=&]M.B`Q
M,'!X.PT*8F]R9&5R+6)O='1O;3H@,7!X('-O;&ED(&)L86-K.R!L971T97(M
M<W!A8VEN9SH@,G!X.PT*?0T*9F]R;2![('!A9&1I;F<Z(#!P>#L@;6%R9VEN
M.B`P<'@[('T-"CPO<W1Y;&4^#0H-"CPO:&5A9#X-"@T*/&)O9'D@;VYL;V%D
M/2));FET*"DB/@T*#0H\9&EV(&-L87-S/2)T:71L92(^26YS97)T($EM86=E
M/"]D:78^#0H\(2TM+2!N97<@<W1U9F8@+2TM/@T*/&9O<FT@86-T:6]N/2(B
M(&UE=&AO9#TB9V5T(CX-"CQT86)L92!B;W)D97(](C`B('=I9'1H/2(Q,#`E
M(B!S='EL93TB<&%D9&EN9SH@,'!X.R!M87)G:6XZ(#!P>"(^#0H@(#QT8F]D
M>3X-"@T*("`\='(^#0H@("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T97AT
M+6%L:6=N.B!R:6=H="(^26UA9V4@55),.CPO=&0^#0H@("`@/'1D/CQI;G!U
M="!T>7!E/2)T97AT(B!N86UE/2)U<FPB(&ED/2)F7W5R;"(@<W1Y;&4](G=I
M9'1H.C<U)2(-"B`@("`@('1I=&QE/2)%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4B("\^#0H@("`@("`\8G5T=&]N(&YA;64](G!R979I97<B(&]N8VQI8VL]
M(G)E='5R;B!O;E!R979I97<H*3LB#0H@("`@("!T:71L93TB4')E=FEE=R!T
M:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(CY0<F5V:65W/"]B=71T;VX^#0H@
M("`@/"]T9#X-"B`@/"]T<CX-"B`@/'1R/@T*("`@(#QT9"!S='EL93TB=VED
M=&@Z(#=E;3L@=&5X="UA;&EG;CH@<FEG:'0B/D%L=&5R;F%T92!T97AT.CPO
M=&0^#0H@("`@/'1D/CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)A;'0B(&ED
M/2)F7V%L="(@<W1Y;&4](G=I9'1H.C$P,"4B#0H@("`@("!T:71L93TB1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B("\^/"]T9#X-
M"B`@/"]T<CX-"@T*("`\+W1B;V1Y/@T*/"]T86)L93X-"@T*/'`@+SX-"@T*
M/&9I96QD<V5T('-T>6QE/2)F;&]A=#H@;&5F=#L@;6%R9VEN+6QE9G0Z(#5P
M>#LB/@T*/&QE9V5N9#Y,87EO=70\+VQE9V5N9#X-"@T*/&1I=B!C;&%S<STB
M<W!A8V4B/CPO9&EV/@T*#0H\9&EV(&-L87-S/2)F;"(^06QI9VYM96YT.CPO
M9&EV/@T*/'-E;&5C="!S:7IE/2(Q(B!N86UE/2)A;&EG;B(@:60](F9?86QI
M9VXB#0H@('1I=&QE/2)0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(CX-"B`@
M/&]P=&EO;B!V86QU93TB(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/DYO="!S970\+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB;&5F="(@("`@
M("`@("`@("`@("`@("`@("`@("`@/DQE9G0\+V]P=&EO;CX-"B`@/&]P=&EO
M;B!V86QU93TB<FEG:'0B("`@("`@("`@("`@("`@("`@("`@("`@/E)I9VAT
M/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L=64](G1E>'1T;W`B("`@("`@("`@
M("`@("`@("`@("`@(#Y497AT=&]P/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L
M=64](F%B<VUI9&1L92(@("`@("`@("`@("`@("`@("`@(#Y!8G-M:61D;&4\
M+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB8F%S96QI;F4B('-E;&5C=&5D
M/2(Q(B`@("`@("`@/D)A<V5L:6YE/"]O<'1I;VX^#0H@(#QO<'1I;VX@=F%L
M=64](F%B<V)O='1O;2(@("`@("`@("`@("`@("`@("`@(#Y!8G-B;W1T;VT\
M+V]P=&EO;CX-"B`@/&]P=&EO;B!V86QU93TB8F]T=&]M(B`@("`@("`@("`@
M("`@("`@("`@("`@/D)O='1O;3PO;W!T:6]N/@T*("`\;W!T:6]N('9A;'5E
M/2)M:61D;&4B("`@("`@("`@("`@("`@("`@("`@("`^36ED9&QE/"]O<'1I
M;VX^#0H@(#QO<'1I;VX@=F%L=64](G1O<"(@("`@("`@("`@("`@("`@("`@
M("`@("`@(#Y4;W`\+V]P=&EO;CX-"CPO<V5L96-T/@T*#0H\<"`O/@T*#0H\
M9&EV(&-L87-S/2)F;"(^0F]R9&5R('1H:6-K;F5S<SH\+V1I=CX-"CQI;G!U
M="!T>7!E/2)T97AT(B!N86UE/2)B;W)D97(B(&ED/2)F7V)O<F1E<B(@<VEZ
M93TB-2(-"G1I=&QE/2),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(B`O/@T*
M#0H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^#0H-"CPO9FEE;&1S970^#0H-
M"CQF:65L9'-E="!S='EL93TB9FQO870Z<FEG:'0[(&UA<F=I;BUR:6=H=#H@
M-7!X.R(^#0H\;&5G96YD/E-P86-I;F<\+VQE9V5N9#X-"@T*/&1I=B!C;&%S
M<STB<W!A8V4B/CPO9&EV/@T*#0H\9&EV(&-L87-S/2)F<B(^2&]R:7IO;G1A
M;#H\+V1I=CX-"CQI;G!U="!T>7!E/2)T97AT(B!N86UE/2)H;W)I>B(@:60]
M(F9?:&]R:7HB('-I>F4](C4B#0IT:71L93TB2&]R:7IO;G1A;"!P861D:6YG
M(B`O/@T*#0H\<"`O/@T*#0H\9&EV(&-L87-S/2)F<B(^5F5R=&EC86PZ/"]D
M:78^#0H\:6YP=70@='EP93TB=&5X="(@;F%M93TB=F5R="(@:60](F9?=F5R
M="(@<VEZ93TB-2(-"G1I=&QE/2)697)T:6-A;"!P861D:6YG(B`O/@T*#0H\
M9&EV(&-L87-S/2)S<&%C92(^/"]D:78^#0H-"CPO9FEE;&1S970^#0H\8G(@
M8VQE87(](F%L;"(@+SX-"CQT86)L92!W:61T:#TB,3`P)2(@<W1Y;&4](FUA
M<F=I;BUB;W1T;VTZ(#`N,F5M(CX-"B`\='(^#0H@(#QT9"!V86QI9VX](F)O
M='1O;2(^#0H@("`@26UA9V4@4')E=FEE=SH\8G(@+SX-"B`@("`\:69R86UE
M(&YA;64](FEP<F5V:65W(B!I9#TB:7!R979I97<B(&9R86UE8F]R9&5R/2(P
M(B!S='EL93TB8F]R9&5R(#H@,7!X('-O;&ED(&=R87D[(B!H96EG:'0](C(P
M,"(@=VED=&@](C,P,"(@<W)C/2(B/CPO:69R86UE/@T*("`\+W1D/@T*("`\
M=&0@=F%L:6=N/2)B;W1T;VTB('-T>6QE/2)T97AT+6%L:6=N.B!R:6=H="(^
M#0H@("`@/&)U='1O;B!T>7!E/2)B=71T;VXB(&YA;64](F]K(B!O;F-L:6-K
M/2)R971U<FX@;VY/2R@I.R(^3TL\+V)U='1O;CX\8G(^#0H@("`@/&)U='1O
M;B!T>7!E/2)B=71T;VXB(&YA;64](F-A;F-E;"(@;VYC;&EC:STB<F5T=7)N
M(&]N0V%N8V5L*"D[(CY#86YC96P\+V)U='1O;CX-"B`@/"]T9#X-"B`\+W1R
M/@T*/"]T86)L93X-"CPO9F]R;3X-"CPO8F]D>3X-"CPO:'1M;#X-"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O
M:'1M;&%R96$O<&QU9VEN<R]!;G-E;$EM86=E````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q-#,@,#(V,#4P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O;G1E>'1-96YU
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,R`P,C8S,30`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L
M=6=I;G,O5&%B;&5/<&5R871I;VYS````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,30S(#`R-S$S-@`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T5'EP90``````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#,@,#(U-C(P`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+TQI<W14
M>7!E+VQA;F<````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,R`P,C8U
M-#$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O3&ES=%1Y<&4O;&ES="UT>7!E+FIS````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,38S
M(#$P-3$U-#,T,30S(#`S,#$W-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````O+R!,:7-T5'EP92!0;'5G:6X@9F]R($A434Q!
M<F5A+3,N,`HO+R!3<&]N<V]R960@8GD@345D5&5C:"!5;FET("T@475E96XG
M<R!5;FEV97)S:71Y"B\O($EM<&QE;65N=&%T:6]N(&)Y($UI:&%I($)A>F]N
M+"!H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O+PHO+PHO+R`H8RD@9'EN87)C
M:"YC;VT@,C`P,RTR,#`U+@HO+R!$:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M
M92!T97)M<R!A<R!(5$U,07)E82!I='-E;&8N"B\O(%1H:7,@;F]T:6-E($U5
M4U0@<W1A>2!I;G1A8W0@9F]R('5S92`H<V5E(&QI8V5N<V4N='AT*2X*+R\*
M+R\@)$ED.B!L:7-T+71Y<&4N:G,L=B`Q+C(@,C`P-2\P,2\R,"`Q-SHT.3HP
M,R!M:7-H;V\@17AP("0*"F9U;F-T:6]N($QI<W14>7!E*&5D:71O<BD@>PH)
M=&AI<RYE9&ET;W(@/2!E9&ET;W(["@EV87(@8V9G(#T@961I=&]R+F-O;F9I
M9SL*"79A<B!T;V]L8F%R(#T@8V9G+G1O;VQB87(["@EV87(@<V5L9B`]('1H
M:7,["@EV87(@:3$X;B`]($QI<W14>7!E+DDQ.$X["@EV87(@;W!T:6]N<R`]
M('M].PH);W!T:6]N<UMI,3AN6R)$96-I;6%L(EU=(#T@(F1E8VEM86PB.PH)
M;W!T:6]N<UMI,3AN6R),;W=E<B!R;VUA;B)=72`](")L;W=E<BUR;VUA;B([
M"@EO<'1I;VYS6VDQ.&Y;(E5P<&5R(')O;6%N(EU=(#T@(G5P<&5R+7)O;6%N
M(CL*"6]P=&EO;G-;:3$X;ELB3&]W97(@;&%T:6XB75T@/2`B;&]W97(M86QP
M:&$B.PH);W!T:6]N<UMI,3AN6R)5<'!E<B!L871I;B)=72`](")U<'!E<BUA
M;'!H82(["@EI9B`H(4A434Q!<F5A+FES7VEE*0H)"2\O($E%(&1O97-N)W0@
M<W5P<&]R="!T:&ES('!R;W!E<G1Y.R!E=F5N('=O<G-E+"!I="!C;VUP;&%I
M;G,*"0DO+R!W:71H(&$@9W)O<W,@97)R;W(@;65S<V%G92!W:&5N('=E('1R
M:65D('1O('-E;&5C="!I="P*"0DO+R!T:&5R969O<F4@;&5T)W,@:&ED92!I
M="!F<F]M('1H92!D86UN(")B<F]W<V5R(BX*"0EO<'1I;VYS6VDQ.&Y;(DQO
M=V5R(&=R965K(EU=(#T@(FQO=V5R+6=R965K(CL*"79A<B!O8FH@/2!["@D)
M:60@("`@("`@("`@("`Z("),:7-T5'EP92(L"@D)=&]O;'1I<"`@("`@("`Z
M(&DQ.&Y;(DQI<W13='EL951O;VQT:7`B72P*"0EO<'1I;VYS("`@("`@(#H@
M;W!T:6]N<RP*"0EA8W1I;VX@("`@("`@(#H@9G5N8W1I;VXH961I=&]R*2![
M('-E;&8N;VY396QE8W0H961I=&]R+"!T:&ES*3L@?2P*"0ER969R97-H("`@
M("`@(#H@9G5N8W1I;VXH961I=&]R*2![('-E;&8N=7!D871E5F%L=64H961I
M=&]R+"!T:&ES*3L@?2P*"0EC;VYT97AT("`@("`@(#H@(F]L(@H)?3L*"6-F
M9RYR96=I<W1E<D1R;W!D;W=N*&]B:BD["@EV87(@82P@:2P@:BP@9F]U;F0@
M/2!F86QS93L*"69O<B`H:2`](#`[("%F;W5N9"`F)B!I(#P@=&]O;&)A<BYL
M96YG=&@[("LK:2D@>PH)"6$@/2!T;V]L8F%R6VE=.PH)"69O<B`H:B`](#`[
M(&H@/"!A+FQE;F=T:#L@*RMJ*2!["@D)"6EF("AA6VI=(#T](")U;F]R9&5R
M961L:7-T(BD@>PH)"0D)9F]U;F0@/2!T<G5E.PH)"0D)8G)E86L["@D)"7T*
M"0E]"@E]"@EI9B`H9F]U;F0I"@D)82YS<&QI8V4H:BP@,"P@(G-P86-E(BP@
M(DQI<W14>7!E(BP@(G-P86-E(BD["GT["@I,:7-T5'EP92Y?<&QU9VEN26YF
M;R`]('L*"6YA;64@("`@("`@("`@.B`B3&ES=%1Y<&4B+`H)=F5R<VEO;B`@
M("`@("`Z("(Q+C`B+`H)9&5V96QO<&5R("`@("`Z(")-:6AA:2!"87IO;B(L
M"@ED979E;&]P97)?=7)L(#H@(FAT='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\O
M(BP*"6-?;W=N97(@("`@("`@.B`B9'EN87)C:"YC;VTB+`H)<W!O;G-O<B`@
M("`@("`Z(")-161496-H(%5N:70@+2!1=65E;B=S(%5N:79E<G-I='DB+`H)
M<W!O;G-O<E]U<FP@("`Z(")H='1P.B\O=W=W+G%U965N<W4N8V$O(BP*"6QI
M8V5N<V4@("`@("`@.B`B:'1M;$%R96$B"GT["@I,:7-T5'EP92YP<F]T;W1Y
M<&4N;VY396QE8W0@/2!F=6YC=&EO;BAE9&ET;W(L(&-O;6)O*2!["@EV87(@
M=&)O8FH@/2!E9&ET;W(N7W1O;VQB87)/8FIE8W1S6V-O;6)O+FED72YE;&5M
M96YT.PH)=F%R('!A<F5N="`](&5D:71O<BYG971087)E;G1%;&5M96YT*"D[
M"@EW:&EL92`H(2]>;VPD+VDN=&5S="AP87)E;G0N=&%G3F%M92DI('L*"0EP
M87)E;G0@/2!P87)E;G0N<&%R96YT3F]D93L*"7T*"7!A<F5N="YS='EL92YL
M:7-T4W1Y;&54>7!E(#T@=&)O8FHN=F%L=64["GT["@I,:7-T5'EP92YP<F]T
M;W1Y<&4N=7!D871E5F%L=64@/2!F=6YC=&EO;BAE9&ET;W(L(&-O;6)O*2![
M"@EV87(@=&)O8FH@/2!E9&ET;W(N7W1O;VQB87)/8FIE8W1S6V-O;6)O+FED
M72YE;&5M96YT.PH)=F%R('!A<F5N="`](&5D:71O<BYG971087)E;G1%;&5M
M96YT*"D["@EW:&EL92`H<&%R96YT("8F("$O7F]L)"]I+G1E<W0H<&%R96YT
M+G1A9TYA;64I*2!["@D)<&%R96YT(#T@<&%R96YT+G!A<F5N=$YO9&4["@E]
M"@EI9B`H(7!A<F5N="D@>PH)"71B;V)J+G-E;&5C=&5D26YD97@@/2`P.PH)
M"7)E='5R;CL*"7T*"79A<B!T>7!E(#T@<&%R96YT+G-T>6QE+FQI<W13='EL
M951Y<&4["@EI9B`H(71Y<&4I('L*"0ET8F]B:BYS96QE8W1E9$EN9&5X(#T@
M,#L*"7T@96QS92!["@D)9F]R("AV87(@:2`]('1B;V)J+F9I<G-T0VAI;&0[
M(&D[(&D@/2!I+FYE>'13:6)L:6YG*2!["@D)"6DN<V5L96-T960@/2`H='EP
M92YI;F1E>$]F*&DN=F%L=64I("$]("TQ*3L*"0E]"@E]"GT["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R],:7-T
M5'EP92]L86YG+V5N+FIS````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T-3$@,3`U,34T,S0Q-#,@,#(W
M-38Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\O($DQ.$X@8V]N<W1A;G1S"@HO+R!,04Y'.B`B96XB+"!%3D-/1$E.1SH@
M551&+3@@?"!)4T\M.#@U.2TQ"B\O($%U=&AO<CH@36EH86D@0F%Z;VXL(&AT
M='`Z+R]D>6YA<F-H+F-O;2]M:7-H;V\*"B\O($9/4B!44D%.4TQ!5$]24SH*
M+R\*+R\@("`Q+B!03$5!4T4@4%54(%E/55(@0T].5$%#5"!)3D9/($E.(%1(
M12!!0D]612!,24Y%"B\O("`@("`@*&%T(&QE87-T(&$@=F%L:60@96UA:6P@
M861D<F5S<RD*+R\*+R\@("`R+B!03$5!4T4@5%)9(%1/(%5312!55$8M."!&
M3U(@14Y#3T1)3D<["B\O("`@("`@*&EF('1H:7,@:7,@;F]T('!O<W-I8FQE
M+"!P;&5A<V4@:6YC;'5D92!A(&-O;6UE;G0*+R\@("`@("`@=&AA="!S=&%T
M97,@=VAA="!E;F-O9&EN9R!I<R!N96-E<W-A<GDN*0H*3&ES=%1Y<&4N23$X
M3B`]('L*"2)$96-I;6%L(B`@("`@("`@("`@("`@("`Z("`@(")$96-I;6%L
M(&YU;6)E<G,B+`H)(DQO=V5R(')O;6%N(B`@("`@("`@("`@(#H@("`@(DQO
M=V5R(')O;6%N(&YU;6)E<G,B+`H)(E5P<&5R(')O;6%N(B`@("`@("`@("`@
M(#H@("`@(E5P<&5R(')O;6%N(&YU;6)E<G,B+`H)(DQO=V5R(&QA=&EN(B`@
M("`@("`@("`@(#H@("`@(DQO=V5R(&QA=&EN(&QE='1E<G,B+`H)(E5P<&5R
M(&QA=&EN(B`@("`@("`@("`@(#H@("`@(E5P<&5R(&QA=&EN(&QE='1E<G,B
M+`H)(DQO=V5R(&=R965K(B`@("`@("`@("`@(#H@("`@(DQO=V5R(&=R965K
M(&QE='1E<G,B+`H)(DQI<W13='EL951O;VQT:7`B("`@("`@(#H@("`@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*?3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M-#,@,#(W-S$R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O
M<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]L86YG````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$T,R`P,S`P-3<`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+W1A8FQE+6]P97)A=&EO;G,N:G,``````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,3`P,C(P(#$P-3$U-#,T,30S(#`S,S`Q-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O+R!4
M86)L92!/<&5R871I;VYS(%!L=6=I;B!F;W(@2%1-3$%R96$M,RXP"B\O($EM
M<&QE;65N=&%T:6]N(&)Y($UI:&%I($)A>F]N+B`@4W!O;G-O<F5D(&)Y(&AT
M='`Z+R]W=W<N>F%P871E8RYC;VT*+R\*+R\@0V]P>7)I9VAT("AC*2!D>6YA
M<F-H+F-O;2`R,#`S+3(P,#4*+R\@5&AI<R!C;W!Y<FEG:'0@;F]T:6-E(&UU
M<W0@<W1A>2!I;G1A8W0@9F]R('5S92X*+R\*+R\@)$ED.B!T86)L92UO<&5R
M871I;VYS+FIS+'8@,2XW(#(P,#4O,#$O,C`@,3<Z-#DZ,#(@;6ES:&]O($5X
M<"`D"@HO+R!/8FIE8W0@=&AA="!W:6QL(&5N8V%P<W5L871E(&%L;"!T:&4@
M=&%B;&4@;W!E<F%T:6]N<R!P<F]V:61E9"!B>0HO+R!(5$U,07)E82TS+C`@
M*&5X8V5P="`B:6YS97)T('1A8FQE(B!W:&EC:"!I<R!I;F-L=61E9"!I;B!T
M:&4@;6%I;B!F:6QE*0IF=6YC=&EO;B!486)L94]P97)A=&EO;G,H961I=&]R
M*2!["@ET:&ES+F5D:71O<B`](&5D:71O<CL*"@EV87(@8V9G(#T@961I=&]R
M+F-O;F9I9SL*"79A<B!T="`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)=F%R
M(&)L(#T@5&%B;&5/<&5R871I;VYS+F)T;DQI<W0["@EV87(@<V5L9B`]('1H
M:7,["@H)+R\@<F5G:7-T97(@=&AE('1O;VQB87(@8G5T=&]N<R!P<F]V:61E
M9"!B>2!T:&ES('!L=6=I;@H)=F%R('1O;VQB87(@/2!;(FQI;F5B<F5A:R)=
M.PH)9F]R("AV87(@:2`](#`[(&D@/"!B;"YL96YG=&@[("LK:2D@>PH)"79A
M<B!B=&X@/2!B;%MI73L*"0EI9B`H(6)T;BD@>PH)"0ET;V]L8F%R+G!U<V@H
M(G-E<&%R871O<B(I.PH)"7T@96QS92!["@D)"79A<B!I9"`](")43RTB("L@
M8G1N6S!=.PH)"0EC9F<N<F5G:7-T97)"=71T;VXH:60L('1T6VED72P@961I
M=&]R+FEM9U523"AB=&Y;,%T@*R`B+F=I9B(L(")486)L94]P97)A=&EO;G,B
M*2P@9F%L<V4L"@D)"0D)("`@9G5N8W1I;VXH961I=&]R+"!I9"D@>PH)"0D)
M"0D@("`O+R!D:7-P871C:"!B=71T;VX@<')E<W,@979E;G0*"0D)"0D)("`@
M<V5L9BYB=71T;VY0<F5S<RAE9&ET;W(L(&ED*3L*"0D)"0D@("!]+"!B=&Y;
M,5TI.PH)"0ET;V]L8F%R+G!U<V@H:60I.PH)"7T*"7T*"@DO+R!A9&0@82!N
M97<@;&EN92!I;B!T:&4@=&]O;&)A<@H)8V9G+G1O;VQB87(N<'5S:"AT;V]L
M8F%R*3L*?3L*"E1A8FQE3W!E<F%T:6]N<RY?<&QU9VEN26YF;R`]('L*"6YA
M;64@("`@("`@("`@.B`B5&%B;&5/<&5R871I;VYS(BP*"79E<G-I;VX@("`@
M("`@.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B36EH86D@0F%Z;VXB+`H)
M9&5V96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O+R(L
M"@EC7V]W;F5R("`@("`@(#H@(DUI:&%I($)A>F]N(BP*"7-P;VYS;W(@("`@
M("`@.B`B6F%P871E8R!);F,N(BP*"7-P;VYS;W)?=7)L("`@.B`B:'1T<#HO
M+W=W=RYB;&]K:2YC;VTB+`H);&EC96YS92`@("`@("`Z(")H=&UL07)E82(*
M?3L*"B\J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH*("H@551)3$E42453"B`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHO"@HO+R!R971R:65V97,@=&AE(&-L
M;W-E<W0@96QE;65N="!H879I;F<@=&AE('-P96-I9FEE9"!T86=.86UE(&EN
M('1H92!L:7-T(&]F"B\O(&%N8V5S=&]R<R!O9B!T:&4@8W5R<F5N="!S96QE
M8W1I;VXO8V%R970N"E1A8FQE3W!E<F%T:6]N<RYP<F]T;W1Y<&4N9V5T0VQO
M<V5S="`](&9U;F-T:6]N*'1A9TYA;64I('L*"79A<B!E9&ET;W(@/2!T:&ES
M+F5D:71O<CL*"79A<B!A;F-E<W1O<G,@/2!E9&ET;W(N9V5T06QL06YC97-T
M;W)S*"D["@EV87(@<F5T(#T@;G5L;#L*"71A9TYA;64@/2`H(B(@*R!T86=.
M86UE*2YT;TQO=V5R0V%S92@I.PH)9F]R("AV87(@:2`](#`[(&D@/"!A;F-E
M<W1O<G,N;&5N9W1H.R`K*VDI('L*"0EV87(@96P@/2!A;F-E<W1O<G-;:5T[
M"@D):68@*&5L+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]/2!T86=.86UE*2![
M"@D)"7)E="`](&5L.PH)"0EB<F5A:SL*"0E]"@E]"@ER971U<FX@<F5T.PI]
M.PH*+R\@=&AI<R!F=6YC=&EO;B!R97%U:7)E<R!T:&4@9FEL92!0;W!U<$1I
M=B]0;W!U<%=I;B!T;R!B92!L;V%D960@9G)O;2!B<F]W<V5R"E1A8FQE3W!E
M<F%T:6]N<RYP<F]T;W1Y<&4N9&EA;&]G5&%B;&50<F]P97)T:65S(#T@9G5N
M8W1I;VXH*2!["@EV87(@:3$X;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)
M+R\@<F5T<FEE=F4@97AI<W1I;F<@=F%L=65S"@EV87(@=&%B;&4@/2!T:&ES
M+F=E=$-L;W-E<W0H(G1A8FQE(BD["@DO+R!T:&ES+F5D:71O<BYS96QE8W1.
M;V1E0V]N=&5N=',H=&%B;&4I.PH)+R\@=&AI<RYE9&ET;W(N=7!D871E5&]O
M;&)A<B@I.PH*"79A<B!D:6%L;V<@/2!N97<@4&]P=7!7:6XH=&AI<RYE9&ET
M;W(L(&DQ.&Y;(E1A8FQE(%!R;W!E<G1I97,B72P@9G5N8W1I;VXH9&EA;&]G
M+"!P87)A;7,I('L*"0E486)L94]P97)A=&EO;G,N<')O8V5S<U-T>6QE*'!A
M<F%M<RP@=&%B;&4I.PH)"69O<B`H=F%R(&D@:6X@<&%R86US*2!["@D)"79A
M<B!V86P@/2!P87)A;7-;:5T["@D)"7-W:71C:"`H:2D@>PH)"0D@("`@8V%S
M92`B9E]C87!T:6]N(CH*"0D)"6EF("@O7%,O+G1E<W0H=F%L*2D@>PH)"0D)
M"2\O(&-O;G1A:6YS(&YO;B!W:&ET92US<&%C92!C:&%R86-T97)S"@D)"0D)
M=F%R(&-A<'1I;VX@/2!T86)L92YG971%;&5M96YT<T)Y5&%G3F%M92@B8V%P
M=&EO;B(I6S!=.PH)"0D)"6EF("@A8V%P=&EO;BD@>PH)"0D)"0EC87!T:6]N
M(#T@9&EA;&]G+F5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(F-A<'1I;VXB
M*3L*"0D)"0D)=&%B;&4N:6YS97)T0F5F;W)E*&-A<'1I;VXL('1A8FQE+F9I
M<G-T0VAI;&0I.PH)"0D)"7T*"0D)"0EC87!T:6]N+FEN;F5R2%1-3"`]('9A
M;#L*"0D)"7T@96QS92!["@D)"0D)+R\@<V5A<F-H(&9O<B!C87!T:6]N(&%N
M9"!D96QE=&4@:70@:68@9F]U;F0*"0D)"0EV87(@8V%P=&EO;B`]('1A8FQE
M+F=E=$5L96UE;G1S0GE486=.86UE*")C87!T:6]N(BE;,%T["@D)"0D):68@
M*&-A<'1I;VXI('L*"0D)"0D)8V%P=&EO;BYP87)E;G1.;V1E+G)E;6]V94-H
M:6QD*&-A<'1I;VXI.PH)"0D)"7T*"0D)"7T*"0D)"6)R96%K.PH)"0D@("`@
M8V%S92`B9E]S=6UM87)Y(CH*"0D)"71A8FQE+G-U;6UA<GD@/2!V86P["@D)
M"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?=VED=&@B.@H)"0D)=&%B;&4N<W1Y
M;&4N=VED=&@@/2`H(B(@*R!V86PI("L@<&%R86US+F9?=6YI=#L*"0D)"6)R
M96%K.PH)"0D@("`@8V%S92`B9E]A;&EG;B(Z"@D)"0ET86)L92YA;&EG;B`]
M('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B9E]S<&%C:6YG(CH*"0D)
M"71A8FQE+F-E;&Q3<&%C:6YG(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C
M87-E(")F7W!A9&1I;F<B.@H)"0D)=&%B;&4N8V5L;%!A9&1I;F<@/2!V86P[
M"@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?8F]R9&5R<R(Z"@D)"0ET86)L
M92YB;W)D97(@/2!V86P["@D)"0EB<F5A:SL*"0D)("`@(&-A<V4@(F9?9G)A
M;65S(CH*"0D)"71A8FQE+F9R86UE(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@
M("!C87-E(")F7W)U;&5S(CH*"0D)"71A8FQE+G)U;&5S(#T@=F%L.PH)"0D)
M8G)E86L["@D)"7T*"0E]"@D)+R\@=F%R:6]U<R!W;W)K87)O=6YD<R!T;R!R
M969R97-H('1H92!T86)L92!D:7-P;&%Y("A'96-K;RP*"0DO+R!W:&%T)W,@
M9V]I;F<@;VX_(2!D;R!N;W0@9&ES87!P;VEN="!M92$I"@D)9&EA;&]G+F5D
M:71O<BYF;W)C95)E9')A=R@I.PH)"61I86QO9RYE9&ET;W(N9F]C=7-%9&ET
M;W(H*3L*"0ED:6%L;V<N961I=&]R+G5P9&%T951O;VQB87(H*3L*"0EV87(@
M<V%V95]C;VQL87!S92`]('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E.PH)
M"71A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(F-O;&QA<'-E(CL*"0ET
M86)L92YS='EL92YB;W)D97)#;VQL87!S92`](")S97!A<F%T92(["@D)=&%B
M;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2!S879E7V-O;&QA<'-E.PH)?2P*
M"@DO+R!T:&ES(&9U;F-T:6]N(&=E=',@8V%L;&5D('=H96X@=&AE(&1I86QO
M9R!N965D<R!T;R!B92!I;FET:6%L:7IE9`H)9G5N8W1I;VX@*&1I86QO9RD@
M>PH*"0EV87(@9E]C87!T:6]N(#T@(B(["@D)=F%R(&-A<&5L(#T@=&%B;&4N
M9V5T16QE;65N='-">51A9TYA;64H(F-A<'1I;VXB*5LP73L*"0EI9B`H8V%P
M96PI('L*"0D)9E]C87!T:6]N(#T@8V%P96PN:6YN97)(5$U,.PH)"7T*"0EV
M87(@9E]S=6UM87)Y(#T@=&%B;&4N<W5M;6%R>3L*"0EV87(@9E]W:61T:"`]
M('!A<G-E26YT*'1A8FQE+G-T>6QE+G=I9'1H*3L*"0EI<TYA3BAF7W=I9'1H
M*2`F)B`H9E]W:61T:"`]("(B*3L*"0EV87(@9E]U;FET(#T@+R4O+G1E<W0H
M=&%B;&4N<W1Y;&4N=VED=&@I(#\@)W!E<F-E;G0G(#H@)W!I>&5L<R<["@D)
M=F%R(&9?86QI9VX@/2!T86)L92YA;&EG;CL*"0EV87(@9E]S<&%C:6YG(#T@
M=&%B;&4N8V5L;%-P86-I;F<["@D)=F%R(&9?<&%D9&EN9R`]('1A8FQE+F-E
M;&Q0861D:6YG.PH)"79A<B!F7V)O<F1E<G,@/2!T86)L92YB;W)D97(["@D)
M=F%R(&9?9G)A;65S(#T@=&%B;&4N9G)A;64["@D)=F%R(&9?<G5L97,@/2!T
M86)L92YR=6QE<SL*"@D)9G5N8W1I;VX@<V5L96-T960H=F%L*2!["@D)"7)E
M='5R;B!V86P@/R`B('-E;&5C=&5D(B`Z("(B.PH)"7T["@H)"2\O(&1I86QO
M9R!C;VYT96YT<PH)"61I86QO9RYC;VYT96YT+G-T>6QE+G=I9'1H(#T@(C0P
M,'!X(CL*"0ED:6%L;V<N8V]N=&5N="YI;FYE<DA434P@/2`B(%P*/&1I=B!C
M;&%S<STG=&ET;&4G7`H@<W1Y;&4])V)A8VMG<F]U;F0Z('5R;"@B("L@9&EA
M;&]G+F)A<V554DP@*R!D:6%L;V<N961I=&]R+FEM9U523"@B=&%B;&4M<')O
M<"YG:68B+"`B5&%B;&5/<&5R871I;VYS(BD@*R`B*2`C9F9F(#DX)2`U,"4@
M;F\M<F5P96%T)SXB("L@:3$X;ELB5&%B;&4@4')O<&5R=&EE<R)=("L@(EP*
M/"]D:78^(%P*/'1A8FQE('-T>6QE/2=W:61T:#HQ,#`E)SX@7`H@(#QT<CX@
M7`H@("`@/'1D/B!<"B`@("`@(#QF:65L9'-E=#X\;&5G96YD/B(@*R!I,3AN
M6R)$97-C<FEP=&EO;B)=("L@(CPO;&5G96YD/B!<"B`@("`@("`\=&%B;&4@
M<W1Y;&4])W=I9'1H.C$P,"4G/B!<"B`@("`@("`@/'1R/B!<"B`@("`@("`@
M("`\=&0@8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB0V%P=&EO;B)=("L@(CH\
M+W1D/B!<"B`@("`@("`@("`\=&0@8VQA<W,])W9A;'5E)SX\:6YP=70@='EP
M93TG=&5X="<@;F%M93TG9E]C87!T:6]N)R!V86QU93TG(B`K(&9?8V%P=&EO
M;B`K("(G+SX\+W1D/B!<"B`@("`@("`@/"]T<CX\='(^(%P*("`@("`@("`@
M(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)3=6UM87)Y(ET@*R`B.CPO
M=&0^(%P*("`@("`@("`@(#QT9"!C;&%S<STG=F%L=64G/CQI;G!U="!T>7!E
M/2=T97AT)R!N86UE/2=F7W-U;6UA<GDG('9A;'5E/2<B("L@9E]S=6UM87)Y
M("L@(B<O/CPO=&0^(%P*("`@("`@("`\+W1R/B!<"B`@("`@("`\+W1A8FQE
M/B!<"B`@("`@(#PO9FEE;&1S970^(%P*("`@(#PO=&0^(%P*("`\+W1R/B!<
M"B`@/'1R/CQT9"!I9#TG+2U(02UL87EO=70G/CPO=&0^/"]T<CX@7`H@(#QT
M<CX@7`H@("`@/'1D/B!<"B`@("`@(#QF:65L9'-E=#X\;&5G96YD/B(@*R!I
M,3AN6R)3<&%C:6YG(&%N9"!P861D:6YG(ET@*R`B/"]L96=E;F0^(%P*("`@
M("`@(#QT86)L92!S='EL93TG=VED=&@Z,3`P)2<^(%P*("`@("`@("`\='(^
M(%P*("`@("`@("`@(#QT9"!C;&%S<STG;&%B96PG/B(@*R!I,3AN6R)3<&%C
M:6YG(ET@*R`B.CPO=&0^(%P*("`@("`@("`@(#QT9#X\:6YP=70@='EP93TG
M=&5X="<@;F%M93TG9E]S<&%C:6YG)R!S:7IE/2<U)R!V86QU93TG(B`K(&9?
M<W!A8VEN9R`K("(G("\^("9N8G-P.R(@*R!I,3AN6R)0861D:6YG(ET@*R`B
M.EP*("`@("`@("`@("`@/&EN<'5T('1Y<&4])W1E>'0G(&YA;64])V9?<&%D
M9&EN9R<@<VEZ93TG-2<@=F%L=64])R(@*R!F7W!A9&1I;F<@*R`B)R`O/B`F
M;F)S<#LF;F)S<#LB("L@:3$X;ELB<&EX96QS(ET@*R`B7`H@("`@("`@("`@
M/"]T9#X@7`H@("`@("`@(#PO='(^(%P*("`@("`@(#PO=&%B;&4^(%P*("`@
M("`@/"]F:65L9'-E=#X@7`H@("`@/"]T9#X@7`H@(#PO='(^(%P*("`\='(^
M(%P*("`@(#QT9#X@7`H@("`@("`\9FEE;&1S970^/&QE9V5N9#Y&<F%M92!A
M;F0@8F]R9&5R<SPO;&5G96YD/B!<"B`@("`@("`@/'1A8FQE('=I9'1H/2<Q
M,#`E)SX@7`H@("`@("`@("`@/'1R/B!<"B`@("`@("`@("`@(#QT9"!C;&%S
M<STG;&%B96PG/B(@*R!I,3AN6R)";W)D97)S(ET@*R`B.CPO=&0^(%P*("`@
M("`@("`@("`@/'1D/CQI;G!U="!N86UE/2=F7V)O<F1E<G,G('1Y<&4])W1E
M>'0G('-I>F4])S4G('9A;'5E/2<B("L@9E]B;W)D97)S("L@(B<@+SX@)FYB
M<W`[)FYB<W`[(B`K(&DQ.&Y;(G!I>&5L<R)=("L@(CPO=&0^(%P*("`@("`@
M("`@(#PO='(^(%P*("`@("`@("`@(#QT<CX@7`H@("`@("`@("`@("`\=&0@
M8VQA<W,])VQA8F5L)SXB("L@:3$X;ELB1G)A;65S(ET@*R`B.CPO=&0^(%P*
M("`@("`@("`@("`@/'1D/B!<"B`@("`@("`@("`@("`@/'-E;&5C="!N86UE
M/2=F7V9R86UE<R<^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64]
M)W9O:60G(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")V;VED(BD@*R`B/B(@
M*R!I,3AN6R).;R!S:61E<R)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@
M("`@("`\;W!T:6]N('9A;'5E/2=A8F]V92<B("L@<V5L96-T960H9E]F<F%M
M97,@/3T@(F%B;W9E(BD@*R`B/B(@*R!I,3AN6R)4:&4@=&]P('-I9&4@;VYL
M>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A
M;'5E/2=B96QO=R<B("L@<V5L96-T960H9E]F<F%M97,@/3T@(F)E;&]W(BD@
M*R`B/B(@*R!I,3AN6R)4:&4@8F]T=&]M('-I9&4@;VYL>2)=("L@(CPO;W!T
M:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T:6]N('9A;'5E/2=H<VED97,G
M(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")H<VED97,B*2`K("(^(B`K(&DQ
M.&Y;(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(ET@*R`B/"]O<'1I
M;VX^(%P*("`@("`@("`@("`@("`@(#QO<'1I;VX@=F%L=64])W9S:61E<R<B
M("L@<V5L96-T960H9E]F<F%M97,@/3T@(G9S:61E<R(I("L@(CXB("L@:3$X
M;ELB5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB72`K("(\+V]P=&EO
M;CX@7`H@("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG;&AS)R(@*R!S
M96QE8W1E9"AF7V9R86UE<R`]/2`B;&AS(BD@*R`B/B(@*R!I,3AN6R)4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@
M("`@("`@("`\;W!T:6]N('9A;'5E/2=R:',G(B`K('-E;&5C=&5D*&9?9G)A
M;65S(#T](")R:',B*2`K("(^(B`K(&DQ.&Y;(E1H92!R:6=H="UH86YD('-I
M9&4@;VYL>2)=("L@(CPO;W!T:6]N/B!<"B`@("`@("`@("`@("`@("`\;W!T
M:6]N('9A;'5E/2=B;W@G(B`K('-E;&5C=&5D*&9?9G)A;65S(#T](")B;W@B
M*2`K("(^(B`K(&DQ.&Y;(D%L;"!F;W5R('-I9&5S(ET@*R`B/"]O<'1I;VX^
M(%P*("`@("`@("`@("`@("`\+W-E;&5C=#X@7`H@("`@("`@("`@("`\+W1D
M/B!<"B`@("`@("`@("`\+W1R/B!<"B`@("`@("`@("`\='(^(%P*("`@("`@
M("`@("`@/'1D(&-L87-S/2=L86)E;"<^(B`K(&DQ.&Y;(E)U;&5S(ET@*R`B
M.CPO=&0^(%P*("`@("`@("`@("`@/'1D/B!<"B`@("`@("`@("`@("`@/'-E
M;&5C="!N86UE/2=F7W)U;&5S)SX@7`H@("`@("`@("`@("`@("`@/&]P=&EO
M;B!V86QU93TG;F]N92<B("L@<V5L96-T960H9E]R=6QE<R`]/2`B;F]N92(I
M("L@(CXB("L@:3$X;ELB3F\@<G5L97,B72`K("(\+V]P=&EO;CX@7`H@("`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG<F]W<R<B("L@<V5L96-T960H
M9E]R=6QE<R`]/2`B<F]W<R(I("L@(CXB("L@:3$X;ELB4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB72`K("(\+V]P=&EO;CX@7`H@("`@
M("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG8V]L<R<B("L@<V5L96-T960H
M9E]R=6QE<R`]/2`B8V]L<R(I("L@(CXB("L@:3$X;ELB4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB72`K("(\+V]P=&EO;CX@7`H@
M("`@("`@("`@("`@("`@/&]P=&EO;B!V86QU93TG86QL)R(@*R!S96QE8W1E
M9"AF7W)U;&5S(#T](")A;&PB*2`K("(^(B`K(&DQ.&Y;(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B72`K("(\+V]P
M=&EO;CX@7`H@("`@("`@("`@("`@(#PO<V5L96-T/B!<"B`@("`@("`@("`@
M(#PO=&0^(%P*("`@("`@("`@(#PO='(^(%P*("`@("`@("`\+W1A8FQE/B!<
M"B`@("`@(#PO9FEE;&1S970^(%P*("`@(#PO=&0^(%P*("`\+W1R/B!<"B`@
M/'1R/B!<"B`@("`\=&0@:60])RTM2$$M<W1Y;&4G/CPO=&0^(%P*("`\+W1R
M/B!<"CPO=&%B;&4^(%P*(CL*"0EV87(@<W1?<')O<"`](%1A8FQE3W!E<F%T
M:6]N<RYC<F5A=&53='EL949I96QD<V5T*&1I86QO9RYD;V,L(&1I86QO9RYE
M9&ET;W(L('1A8FQE*3L*"0EV87(@<"`](&1I86QO9RYD;V,N9V5T16QE;65N
M=$)Y260H(BTM2$$M<W1Y;&4B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7W!R;W`I
M.PH)"79A<B!S=%]L87EO=70@/2!486)L94]P97)A=&EO;G,N8W)E871E4W1Y
M;&5,87EO=71&:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I=&]R+"!T
M86)L92D["@D)<"`](&1I86QO9RYD;V,N9V5T16QE;65N=$)Y260H(BTM2$$M
M;&%Y;W5T(BD["@D)<"YA<'!E;F1#:&EL9"AS=%]L87EO=70I.PH)"61I86QO
M9RYM;V1A;"`]('1R=64["@D)9&EA;&]G+F%D9$)U='1O;G,H(F]K(BP@(F-A
M;F-E;"(I.PH)"61I86QO9RYS:&]W071%;&5M96YT*&1I86QO9RYE9&ET;W(N
M7VEF<F%M92P@(F,B*3L*"7TI.PI].PH*+R\@=&AI<R!F=6YC=&EO;B!R97%U
M:7)E<R!T:&4@9FEL92!0;W!U<$1I=B]0;W!U<%=I;B!T;R!B92!L;V%D960@
M9G)O;2!B<F]W<V5R"E1A8FQE3W!E<F%T:6]N<RYP<F]T;W1Y<&4N9&EA;&]G
M4F]W0V5L;%!R;W!E<G1I97,@/2!F=6YC=&EO;BAC96QL*2!["@EV87(@:3$X
M;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH)+R\@<F5T<FEE=F4@97AI<W1I
M;F<@=F%L=65S"@EV87(@96QE;65N="`]('1H:7,N9V5T0VQO<V5S="AC96QL
M(#\@(G1D(B`Z(")T<B(I.PH)=F%R('1A8FQE(#T@=&AI<RYG971#;&]S97-T
M*")T86)L92(I.PH)+R\@=&AI<RYE9&ET;W(N<V5L96-T3F]D94-O;G1E;G1S
M*&5L96UE;G0I.PH)+R\@=&AI<RYE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH*
M"79A<B!D:6%L;V<@/2!N97<@4&]P=7!7:6XH=&AI<RYE9&ET;W(L(&DQ.&Y;
M8V5L;"`_(")#96QL(%!R;W!E<G1I97,B(#H@(E)O=R!0<F]P97)T:65S(ETL
M(&9U;F-T:6]N*&1I86QO9RP@<&%R86US*2!["@D)5&%B;&5/<&5R871I;VYS
M+G!R;V-E<W-3='EL92AP87)A;7,L(&5L96UE;G0I.PH)"69O<B`H=F%R(&D@
M:6X@<&%R86US*2!["@D)"79A<B!V86P@/2!P87)A;7-;:5T["@D)"7-W:71C
M:"`H:2D@>PH)"0D@("`@8V%S92`B9E]A;&EG;B(Z"@D)"0EE;&5M96YT+F%L
M:6=N(#T@=F%L.PH)"0D)8G)E86L["@D)"2`@("!C87-E(")F7V-H87(B.@H)
M"0D)96QE;65N="YC:"`]('9A;#L*"0D)"6)R96%K.PH)"0D@("`@8V%S92`B
M9E]V86QI9VXB.@H)"0D)96QE;65N="YV06QI9VX@/2!V86P["@D)"0EB<F5A
M:SL*"0D)?0H)"7T*"0DO+R!V87)I;W5S('=O<FMA<F]U;F1S('1O(')E9G)E
M<V@@=&AE('1A8FQE(&1I<W!L87D@*$=E8VMO+`H)"2\O('=H870G<R!G;VEN
M9R!O;C\A(&1O(&YO="!D:7-A<'!O:6YT(&UE(2D*"0ED:6%L;V<N961I=&]R
M+F9O<F-E4F5D<F%W*"D["@D)9&EA;&]G+F5D:71O<BYF;V-U<T5D:71O<B@I
M.PH)"61I86QO9RYE9&ET;W(N=7!D871E5&]O;&)A<B@I.PH)"79A<B!S879E
M7V-O;&QA<'-E(#T@=&%B;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4["@D)=&%B
M;&4N<W1Y;&4N8F]R9&5R0V]L;&%P<V4@/2`B8V]L;&%P<V4B.PH)"71A8FQE
M+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(G-E<&%R871E(CL*"0ET86)L92YS
M='EL92YB;W)D97)#;VQL87!S92`]('-A=F5?8V]L;&%P<V4["@E]+`H*"2\O
M('1H:7,@9G5N8W1I;VX@9V5T<R!C86QL960@=VAE;B!T:&4@9&EA;&]G(&YE
M961S('1O(&)E(&EN:71I86QI>F5D"@EF=6YC=&EO;B`H9&EA;&]G*2!["@H)
M"79A<B!F7V%L:6=N(#T@96QE;65N="YA;&EG;CL*"0EV87(@9E]V86QI9VX@
M/2!E;&5M96YT+G9!;&EG;CL*"0EV87(@9E]C:&%R(#T@96QE;65N="YC:#L*
M"@D)9G5N8W1I;VX@<V5L96-T960H=F%L*2!["@D)"7)E='5R;B!V86P@/R`B
M('-E;&5C=&5D(B`Z("(B.PH)"7T["@H)"2\O(&1I86QO9R!C;VYT96YT<PH)
M"61I86QO9RYC;VYT96YT+G-T>6QE+G=I9'1H(#T@(C0P,'!X(CL*"0ED:6%L
M;V<N8V]N=&5N="YI;FYE<DA434P@/2`B(%P*/&1I=B!C;&%S<STG=&ET;&4G
M7`H@<W1Y;&4])V)A8VMG<F]U;F0Z('5R;"@B("L@9&EA;&]G+F)A<V554DP@
M*R!D:6%L;V<N961I=&]R+FEM9U523"AC96QL(#\@(F-E;&PM<')O<"YG:68B
M(#H@(G)O=RUP<F]P+F=I9B(L(")486)L94]P97)A=&EO;G,B*2`K("(I("-F
M9F8@.3@E(#4P)2!N;RUR97!E870G/B(@*R!I,3AN6V-E;&P@/R`B0V5L;"!0
M<F]P97)T:65S(B`Z(")2;W<@4')O<&5R=&EE<R)=("L@(CPO9&EV/B!<"CQT
M86)L92!S='EL93TG=VED=&@Z,3`P)2<^(%P*("`\='(^(%P*("`@(#QT9"!I
M9#TG+2U(02UL87EO=70G/B!<"B`@("`\+W1D/B!<"B`@/"]T<CX@7`H@(#QT
M<CX@7`H@("`@/'1D(&ED/2<M+4A!+7-T>6QE)SX\+W1D/B!<"B`@/"]T<CX@
M7`H\+W1A8FQE/B!<"B(["@D)=F%R('-T7W!R;W`@/2!486)L94]P97)A=&EO
M;G,N8W)E871E4W1Y;&5&:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I
M=&]R+"!E;&5M96YT*3L*"0EV87(@<"`](&1I86QO9RYD;V,N9V5T16QE;65N
M=$)Y260H(BTM2$$M<W1Y;&4B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7W!R;W`I
M.PH)"79A<B!S=%]L87EO=70@/2!486)L94]P97)A=&EO;G,N8W)E871E4W1Y
M;&5,87EO=71&:65L9'-E="AD:6%L;V<N9&]C+"!D:6%L;V<N961I=&]R+"!E
M;&5M96YT*3L*"0EP(#T@9&EA;&]G+F1O8RYG971%;&5M96YT0GE)9"@B+2U(
M02UL87EO=70B*3L*"0EP+F%P<&5N9$-H:6QD*'-T7VQA>6]U="D["@D)9&EA
M;&]G+FUO9&%L(#T@=')U93L*"0ED:6%L;V<N861D0G5T=&]N<R@B;VLB+"`B
M8V%N8V5L(BD["@D)9&EA;&]G+G-H;W=!=$5L96UE;G0H9&EA;&]G+F5D:71O
M<BY?:69R86UE+"`B8R(I.PH)?2D["GT["@HO+R!T:&ES(&9U;F-T:6]N(&=E
M=',@8V%L;&5D('=H96X@<V]M92!B=71T;VX@9G)O;2!T:&4@5&%B;&5/<&5R
M871I;VYS('1O;VQB87(*+R\@=V%S('!R97-S960N"E1A8FQE3W!E<F%T:6]N
M<RYP<F]T;W1Y<&4N8G5T=&]N4')E<W,@/2!F=6YC=&EO;BAE9&ET;W(L(&)U
M='1O;E]I9"D@>PH)=&AI<RYE9&ET;W(@/2!E9&ET;W(["@EV87(@;6]Z8G(@
M/2!(5$U,07)E82YI<U]G96-K;R`_("(\8G(@+SXB(#H@(B(["@EV87(@:3$X
M;B`](%1A8FQE3W!E<F%T:6]N<RY),3A..PH*"2\O(&AE;'!E<B!F=6YC=&EO
M;B!T:&%T(&-L96%R<R!T:&4@8V]N=&5N="!I;B!A('1A8FQE(')O=PH)9G5N
M8W1I;VX@8VQE87)2;W<H='(I('L*"0EV87(@=&1S(#T@='(N9V5T16QE;65N
M='-">51A9TYA;64H(G1D(BD["@D)9F]R("AV87(@:2`]('1D<RYL96YG=&@[
M("TM:2`^/2`P.RD@>PH)"0EV87(@=&0@/2!T9'-;:5T["@D)"71D+G)O=U-P
M86X@/2`Q.PH)"0ET9"YI;FYE<DA434P@/2!M;WIB<CL*"0E]"@E].PH*"69U
M;F-T:6]N('-P;&ET4F]W*'1D*2!["@D)=F%R(&X@/2!P87)S94EN="@B(B`K
M('1D+G)O=U-P86XI.PH)"79A<B!N8R`]('!A<G-E26YT*"(B("L@=&0N8V]L
M4W!A;BD["@D)=&0N<F]W4W!A;B`](#$["@D)='(@/2!T9"YP87)E;G1.;V1E
M.PH)"79A<B!I='(@/2!T<BYR;W=);F1E>#L*"0EV87(@=')S(#T@='(N<&%R
M96YT3F]D92YR;W=S.PH)"79A<B!I;F1E>"`]('1D+F-E;&Q);F1E>#L*"0EW
M:&EL92`H+2UN(#X@,"D@>PH)"0ET<B`]('1R<ULK*VET<ET["@D)"79A<B!O
M=&0@/2!E9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"0EO=&0N
M8V]L4W!A;B`]('1D+F-O;%-P86X["@D)"6]T9"YI;FYE<DA434P@/2!M;WIB
M<CL*"0D)='(N:6YS97)T0F5F;W)E*&]T9"P@='(N8V5L;'-;:6YD97A=*3L*
M"0E]"@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+G5P9&%T951O
M;VQB87(H*3L*"7T["@H)9G5N8W1I;VX@<W!L:71#;VPH=&0I('L*"0EV87(@
M;F,@/2!P87)S94EN="@B(B`K('1D+F-O;%-P86XI.PH)"71D+F-O;%-P86X@
M/2`Q.PH)"71R(#T@=&0N<&%R96YT3F]D93L*"0EV87(@<F5F(#T@=&0N;F5X
M=%-I8FQI;F<["@D)=VAI;&4@*"TM;F,@/B`P*2!["@D)"79A<B!O=&0@/2!E
M9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"0EO=&0N<F]W4W!A
M;B`]('1D+G)O=U-P86X["@D)"6]T9"YI;FYE<DA434P@/2!M;WIB<CL*"0D)
M='(N:6YS97)T0F5F;W)E*&]T9"P@<F5F*3L*"0E]"@D)961I=&]R+F9O<F-E
M4F5D<F%W*"D["@D)961I=&]R+G5P9&%T951O;VQB87(H*3L*"7T["@H)9G5N
M8W1I;VX@<W!L:71#96QL*'1D*2!["@D)=F%R(&YC(#T@<&%R<V5);G0H(B(@
M*R!T9"YC;VQ3<&%N*3L*"0ES<&QI=$-O;"AT9"D["@D)=F%R(&ET96US(#T@
M=&0N<&%R96YT3F]D92YC96QL<SL*"0EV87(@:6YD97@@/2!T9"YC96QL26YD
M97@["@D)=VAI;&4@*&YC+2T@/B`P*2!["@D)"7-P;&ET4F]W*&ET96US6VEN
M9&5X*RM=*3L*"0E]"@E].PH*"69U;F-T:6]N('-E;&5C=$YE>'1.;V1E*&5L
M*2!["@D)=F%R(&YO9&4@/2!E;"YN97AT4VEB;&EN9SL*"0EW:&EL92`H;F]D
M92`F)B!N;V1E+FYO9&54>7!E("$](#$I('L*"0D);F]D92`](&YO9&4N;F5X
M=%-I8FQI;F<["@D)?0H)"6EF("@A;F]D92D@>PH)"0EN;V1E(#T@96PN<')E
M=FEO=7-3:6)L:6YG.PH)"0EW:&EL92`H;F]D92`F)B!N;V1E+FYO9&54>7!E
M("$](#$I('L*"0D)"6YO9&4@/2!N;V1E+G!R979I;W5S4VEB;&EN9SL*"0D)
M?0H)"7T*"0EI9B`H(6YO9&4I('L*"0D);F]D92`](&5L+G!A<F5N=$YO9&4[
M"@D)?0H)"65D:71O<BYS96QE8W1.;V1E0V]N=&5N=',H;F]D92D["@E].PH*
M"7-W:71C:"`H8G5T=&]N7VED*2!["@D)+R\@4D]74PH*"2`@("!C87-E(")4
M3RUR;W<M:6YS97)T+6%B;W9E(CH*"2`@("!C87-E(")43RUR;W<M:6YS97)T
M+75N9&5R(CH*"0EV87(@='(@/2!T:&ES+F=E=$-L;W-E<W0H(G1R(BD["@D)
M:68@*"%T<BD@>PH)"0EB<F5A:SL*"0E]"@D)=F%R(&]T<B`]('1R+F-L;VYE
M3F]D92AT<G5E*3L*"0EC;&5A<E)O=RAO='(I.PH)"71R+G!A<F5N=$YO9&4N
M:6YS97)T0F5F;W)E*&]T<BP@+W5N9&5R+RYT97-T*&)U='1O;E]I9"D@/R!T
M<BYN97AT4VEB;&EN9R`Z('1R*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*
M"0EE9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0EB<F5A:SL*"2`@("!C87-E(")4
M3RUR;W<M9&5L971E(CH*"0EV87(@='(@/2!T:&ES+F=E=$-L;W-E<W0H(G1R
M(BD["@D):68@*"%T<BD@>PH)"0EB<F5A:SL*"0E]"@D)=F%R('!A<B`]('1R
M+G!A<F5N=$YO9&4["@D):68@*'!A<BYR;W=S+FQE;F=T:"`]/2`Q*2!["@D)
M"6%L97)T*&DQ.&Y;(FYO="UD96PM;&%S="UR;W<B72D["@D)"6)R96%K.PH)
M"7T*"0DO+R!S970@=&AE(&-A<F5T(&9I<G-T('1O(&$@<&]S:71I;VX@=&AA
M="!D;V5S;B=T"@D)+R\@9&ES87!P96%R+@H)"7-E;&5C=$YE>'1.;V1E*'1R
M*3L*"0EP87(N<F5M;W9E0VAI;&0H='(I.PH)"65D:71O<BYF;W)C95)E9')A
M=R@I.PH)"65D:71O<BYF;V-U<T5D:71O<B@I.PH)"65D:71O<BYU<&1A=&54
M;V]L8F%R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M<F]W+7-P;&ET(CH*
M"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@
M>PH)"0EB<F5A:SL*"0E]"@D)<W!L:712;W<H=&0I.PH)"6)R96%K.PH*"0DO
M+R!#3TQ534Y3"@H)("`@(&-A<V4@(E1/+6-O;"UI;G-E<G0M8F5F;W)E(CH*
M"2`@("!C87-E(")43RUC;VPM:6YS97)T+6%F=&5R(CH*"0EV87(@=&0@/2!T
M:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D):68@*"%T9"D@>PH)"0EB<F5A:SL*
M"0E]"@D)=F%R(')O=W,@/2!T9"YP87)E;G1.;V1E+G!A<F5N=$YO9&4N<F]W
M<SL*"0EV87(@:6YD97@@/2!T9"YC96QL26YD97@["@D)9F]R("AV87(@:2`]
M(')O=W,N;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)=F%R('1R(#T@<F]W<UMI
M73L*"0D)=F%R(')E9B`]('1R+F-E;&QS6VEN9&5X("L@*"]A9G1E<B\N=&5S
M="AB=71T;VY?:60I(#\@,2`Z(#`I73L*"0D)=F%R(&]T9"`](&5D:71O<BY?
M9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6]T9"YI;FYE<DA434P@/2!M
M;WIB<CL*"0D)='(N:6YS97)T0F5F;W)E*&]T9"P@<F5F*3L*"0E]"@D)961I
M=&]R+F9O8W5S161I=&]R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V]L
M+7-P;&ET(CH*"0EV87(@=&0@/2!T:&ES+F=E=$-L;W-E<W0H(G1D(BD["@D)
M:68@*"%T9"D@>PH)"0EB<F5A:SL*"0E]"@D)<W!L:71#;VPH=&0I.PH)"6)R
M96%K.PH)("`@(&-A<V4@(E1/+6-O;"UD96QE=&4B.@H)"79A<B!T9"`]('1H
M:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2!["@D)"6)R96%K.PH)
M"7T*"0EV87(@:6YD97@@/2!T9"YC96QL26YD97@["@D):68@*'1D+G!A<F5N
M=$YO9&4N8V5L;',N;&5N9W1H(#T](#$I('L*"0D)86QE<G0H:3$X;ELB;F]T
M+61E;"UL87-T+6-O;")=*3L*"0D)8G)E86L["@D)?0H)"2\O('-E="!T:&4@
M8V%R970@9FER<W0@=&\@82!P;W-I=&EO;B!T:&%T(&1O97-N)W0@9&ES87!P
M96%R"@D)<V5L96-T3F5X=$YO9&4H=&0I.PH)"79A<B!R;W=S(#T@=&0N<&%R
M96YT3F]D92YP87)E;G1.;V1E+G)O=W,["@D)9F]R("AV87(@:2`](')O=W,N
M;&5N9W1H.R`M+6D@/CT@,#LI('L*"0D)=F%R('1R(#T@<F]W<UMI73L*"0D)
M='(N<F5M;W9E0VAI;&0H='(N8V5L;'-;:6YD97A=*3L*"0E]"@D)961I=&]R
M+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I=&]R*"D["@D)961I
M=&]R+G5P9&%T951O;VQB87(H*3L*"0EB<F5A:SL*"@D)+R\@0T5,3%,*"@D@
M("`@8V%S92`B5$\M8V5L;"US<&QI="(Z"@D)=F%R('1D(#T@=&AI<RYG971#
M;&]S97-T*")T9"(I.PH)"6EF("@A=&0I('L*"0D)8G)E86L["@D)?0H)"7-P
M;&ET0V5L;"AT9"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V5L;"UI;G-E
M<G0M8F5F;W)E(CH*"2`@("!C87-E(")43RUC96QL+6EN<V5R="UA9G1E<B(Z
M"@D)=F%R('1D(#T@=&AI<RYG971#;&]S97-T*")T9"(I.PH)"6EF("@A=&0I
M('L*"0D)8G)E86L["@D)?0H)"79A<B!T<B`]('1D+G!A<F5N=$YO9&4["@D)
M=F%R(&]T9"`](&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M;W1D+FEN;F5R2%1-3"`](&UO>F)R.PH)"71R+FEN<V5R=$)E9F]R92AO=&0L
M("]A9G1E<B\N=&5S="AB=71T;VY?:60I(#\@=&0N;F5X=%-I8FQI;F<@.B!T
M9"D["@D)961I=&]R+F9O<F-E4F5D<F%W*"D["@D)961I=&]R+F9O8W5S161I
M=&]R*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V5L;"UD96QE=&4B.@H)
M"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B*3L*"0EI9B`H(71D*2![
M"@D)"6)R96%K.PH)"7T*"0EI9B`H=&0N<&%R96YT3F]D92YC96QL<RYL96YG
M=&@@/3T@,2D@>PH)"0EA;&5R="AI,3AN6R)N;W0M9&5L+6QA<W0M8V5L;")=
M*3L*"0D)8G)E86L["@D)?0H)"2\O('-E="!T:&4@8V%R970@9FER<W0@=&\@
M82!P;W-I=&EO;B!T:&%T(&1O97-N)W0@9&ES87!P96%R"@D)<V5L96-T3F5X
M=$YO9&4H=&0I.PH)"71D+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H=&0I.PH)
M"65D:71O<BYF;W)C95)E9')A=R@I.PH)"65D:71O<BYU<&1A=&54;V]L8F%R
M*"D["@D)8G)E86L["@D@("`@8V%S92`B5$\M8V5L;"UM97)G92(Z"@D)+R\@
M(2$@1DE8344Z($UO>FEL;&$@<W!E8VEF:6,@(2$*"0EV87(@<V5L(#T@961I
M=&]R+E]G971396QE8W1I;VXH*3L*"0EV87(@<F%N9V4L(&D@/2`P.PH)"79A
M<B!R;W=S(#T@6UT["@D)=F%R(')O=R`](&YU;&P["@D)=F%R(&-E;&QS(#T@
M;G5L;#L*"0EI9B`H(4A434Q!<F5A+FES7VEE*2!["@D)"71R>2!["@D)"0EW
M:&EL92`H<F%N9V4@/2!S96PN9V5T4F%N9V5!="AI*RLI*2!["@D)"0D)=F%R
M('1D(#T@<F%N9V4N<W1A<G1#;VYT86EN97(N8VAI;&1.;V1E<UMR86YG92YS
M=&%R=$]F9G-E=%T["@D)"0D):68@*'1D+G!A<F5N=$YO9&4@(3T@<F]W*2![
M"@D)"0D)"7)O=R`]('1D+G!A<F5N=$YO9&4["@D)"0D)"2AC96QL<RD@)B8@
M<F]W<RYP=7-H*&-E;&QS*3L*"0D)"0D)8V5L;',@/2!;73L*"0D)"0E]"@D)
M"0D)8V5L;',N<'5S:"AT9"D["@D)"0E]"@D)"7T@8V%T8V@H92D@>R\J(&9I
M;FES:&5D('=A;&MI;F<@=&AR;W5G:"!S96QE8W1I;VX@*B]]"@D)"7)O=W,N
M<'5S:"AC96QL<RD["@D)?2!E;'-E('L*"0D)+R\@26YT97)N970@17AP;&]R
M97(@(F)R;W=S97(B"@D)"79A<B!T9"`]('1H:7,N9V5T0VQO<V5S="@B=&0B
M*3L*"0D):68@*"%T9"D@>PH)"0D)86QE<G0H:3$X;ELB4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(ETI.PH)"0D)8G)E86L["@D)"7T*"0D)=F%R('1R
M(#T@=&0N<&%R96YT16QE;65N=#L*"0D)=F%R(&YO7V-O;',@/2!P<F]M<'0H
M:3$X;ELB2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B72P@,BD["@D)"6EF("@A;F]?8V]L<RD@>PH)"0D)+R\@8V%N8V5L;&5D
M"@D)"0EB<F5A:SL*"0D)?0H)"0EV87(@;F]?<F]W<R`]('!R;VUP="AI,3AN
M6R)(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R)=+"`R
M*3L*"0D):68@*"%N;U]R;W=S*2!["@D)"0DO+R!C86YC96QL960*"0D)"6)R
M96%K.PH)"0E]"@D)"79A<B!C96QL7VEN9&5X(#T@=&0N8V5L;$EN9&5X.PH)
M"0EW:&EL92`H;F]?<F]W<RTM(#X@,"D@>PH)"0D)=&0@/2!T<BYC96QL<UMC
M96QL7VEN9&5X73L*"0D)"6-E;&QS(#T@6W1D73L*"0D)"69O<B`H=F%R(&D@
M/2`Q.R!I(#P@;F]?8V]L<SL@*RMI*2!["@D)"0D)=&0@/2!T9"YN97AT4VEB
M;&EN9SL*"0D)"0EI9B`H(71D*2!["@D)"0D)"6)R96%K.PH)"0D)"7T*"0D)
M"0EC96QL<RYP=7-H*'1D*3L*"0D)"7T*"0D)"7)O=W,N<'5S:"AC96QL<RD[
M"@D)"0ET<B`]('1R+FYE>'13:6)L:6YG.PH)"0D):68@*"%T<BD@>PH)"0D)
M"6)R96%K.PH)"0D)?0H)"0E]"@D)?0H)"79A<B!(5$U,(#T@(B(["@D)9F]R
M("AI(#T@,#L@:2`\(')O=W,N;&5N9W1H.R`K*VDI('L*"0D)+R\@:2`F)B`H
M2%1-3"`K/2`B/&)R("\^(BD["@D)"79A<B!C96QL<R`](')O=W-;:5T["@D)
M"69O<B`H=F%R(&H@/2`P.R!J(#P@8V5L;',N;&5N9W1H.R`K*VHI('L*"0D)
M"2\O(&H@)B8@*$A434P@*ST@(B9N8G-P.R(I.PH)"0D)=F%R(&-E;&P@/2!C
M96QL<UMJ73L*"0D)"4A434P@*ST@8V5L;"YI;FYE<DA434P["@D)"0DH:2!\
M?"!J*2`F)B`H8V5L;"YP87)E;G1.;V1E+G)E;6]V94-H:6QD*&-E;&PI*3L*
M"0D)?0H)"7T*"0EV87(@=&0@/2!R;W=S6S!=6S!=.PH)"71D+FEN;F5R2%1-
M3"`]($A434P["@D)=&0N<F]W4W!A;B`](')O=W,N;&5N9W1H.PH)"71D+F-O
M;%-P86X@/2!R;W=S6S!=+FQE;F=T:#L*"0EE9&ET;W(N<V5L96-T3F]D94-O
M;G1E;G1S*'1D*3L*"0EE9&ET;W(N9F]R8V52961R87<H*3L*"0EE9&ET;W(N
M9F]C=7-%9&ET;W(H*3L*"0EB<F5A:SL*"@D)+R\@4%)/4$525$E%4PH*"2`@
M("!C87-E(")43RUT86)L92UP<F]P(CH*"0ET:&ES+F1I86QO9U1A8FQE4')O
M<&5R=&EE<R@I.PH)"6)R96%K.PH*"2`@("!C87-E(")43RUR;W<M<')O<"(Z
M"@D)=&AI<RYD:6%L;V=2;W=#96QL4')O<&5R=&EE<RAF86QS92D["@D)8G)E
M86L["@H)("`@(&-A<V4@(E1/+6-E;&PM<')O<"(Z"@D)=&AI<RYD:6%L;V=2
M;W=#96QL4')O<&5R=&EE<RAT<G5E*3L*"0EB<F5A:SL*"@D@("`@9&5F875L
M=#H*"0EA;&5R="@B0G5T=&]N(%LB("L@8G5T=&]N7VED("L@(ET@;F]T('EE
M="!I;7!L96UE;G1E9"(I.PH)?0I].PH*+R\@=&AE(&QI<W0@;V8@8G5T=&]N
M<R!A9&1E9"!B>2!T:&ES('!L=6=I;@I486)L94]P97)A=&EO;G,N8G1N3&ES
M="`](%L*"2\O('1A8FQE('!R;W!E<G1I97,@8G5T=&]N"@E;(G1A8FQE+7!R
M;W`B+"`@("`@("`B=&%B;&4B72P*"6YU;&PL"0D)+R\@<V5P87)A=&]R"@H)
M+R\@4D]74PH)6R)R;W<M<')O<"(L("`@("`@("`@(G1R(ETL"@E;(G)O=RUI
M;G-E<G0M86)O=F4B+"`B='(B72P*"5LB<F]W+6EN<V5R="UU;F1E<B(L(")T
M<B)=+`H)6R)R;W<M9&5L971E(BP@("`@("`@(G1R(ETL"@E;(G)O=RUS<&QI
M="(L("`@("`@("`B=&1;<F]W4W!A;B$],5TB72P*"6YU;&PL"@H)+R\@0T],
M4PH)6R)C;VPM:6YS97)T+6)E9F]R92(L(")T9")=+`H)6R)C;VPM:6YS97)T
M+6%F=&5R(BP@(")T9")=+`H)6R)C;VPM9&5L971E(BP@("`@("`@(")T9")=
M+`H)6R)C;VPM<W!L:70B+"`@("`@("`@(")T9%MC;VQ3<&%N(3TQ72)=+`H)
M;G5L;"P*"@DO+R!#14Q,4PH)6R)C96QL+7!R;W`B+"`@("`@("`@("`B=&0B
M72P*"5LB8V5L;"UI;G-E<G0M8F5F;W)E(BP@(G1D(ETL"@E;(F-E;&PM:6YS
M97)T+6%F=&5R(BP@(")T9")=+`H)6R)C96QL+61E;&5T92(L("`@("`@("`B
M=&0B72P*"5LB8V5L;"UM97)G92(L("`@("`@("`@(G1R(ETL"@E;(F-E;&PM
M<W!L:70B+"`@("`@("`@(")T9%MC;VQ3<&%N(3TQ+')O=U-P86XA/3%=(ET*
M"5T["@H*"B\O+R\@1T5.15))0R!#3T1%(%MS='EL92!O9B!A;GD@96QE;65N
M=#L@=&AI<R!S:&]U;&0@8F4@;6]V960@:6YT;R!A('-E<&%R871E"B\O+R\@
M9FEL92!A<R!I="=L;"!B92!V97)Y('5S969U;%T*+R\O+R!"14=)3B!'14Y%
M4DE#($-/1$4@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*"E1A8FQE3W!E<F%T:6]N<RYG971,96YG=&@@
M/2!F=6YC=&EO;BAV86QU92D@>PH)=F%R(&QE;B`]('!A<G-E26YT*'9A;'5E
M*3L*"6EF("AI<TYA3BAL96XI*2!["@D);&5N(#T@(B(["@E]"@ER971U<FX@
M;&5N.PI].PH*+R\@07!P;&EE<R!T:&4@<W1Y;&4@9F]U;F0@:6X@(G!A<F%M
M<R(@=&\@=&AE(&=I=F5N(&5L96UE;G0N"E1A8FQE3W!E<F%T:6]N<RYP<F]C
M97-S4W1Y;&4@/2!F=6YC=&EO;BAP87)A;7,L(&5L96UE;G0I('L*"79A<B!S
M='EL92`](&5L96UE;G0N<W1Y;&4["@EF;W(@*'9A<B!I(&EN('!A<F%M<RD@
M>PH)"79A<B!V86P@/2!P87)A;7-;:5T["@D)<W=I=&-H("AI*2!["@D)("`@
M(&-A<V4@(F9?<W1?8F%C:V=R;W5N9$-O;&]R(CH*"0D)<W1Y;&4N8F%C:V=R
M;W5N9$-O;&]R(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]C
M;VQO<B(Z"@D)"7-T>6QE+F-O;&]R(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@
M8V%S92`B9E]S=%]B86-K9W)O=6YD26UA9V4B.@H)"0EI9B`H+UQ3+RYT97-T
M*'9A;"DI('L*"0D)"7-T>6QE+F)A8VMG<F]U;F1);6%G92`](")U<FPH(B`K
M('9A;"`K("(I(CL*"0D)?2!E;'-E('L*"0D)"7-T>6QE+F)A8VMG<F]U;F1)
M;6%G92`](")N;VYE(CL*"0D)?0H)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S
M=%]B;W)D97)7:61T:"(Z"@D)"7-T>6QE+F)O<F1E<E=I9'1H(#T@=F%L.PH)
M"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]B;W)D97)3='EL92(Z"@D)"7-T
M>6QE+F)O<F1E<E-T>6QE(#T@=F%L.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B
M9E]S=%]B;W)D97)#;VQO<B(Z"@D)"7-T>6QE+F)O<F1E<D-O;&]R(#T@=F%L
M.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]B;W)D97)#;VQL87!S92(Z
M"@D)"7-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@=F%L(#\@(F-O;&QA<'-E(B`Z
M("(B.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]W:61T:"(Z"@D)"6EF
M("@O7%,O+G1E<W0H=F%L*2D@>PH)"0D)<W1Y;&4N=VED=&@@/2!V86P@*R!P
M87)A;7-;(F9?<W1?=VED=&A5;FET(ET["@D)"7T@96QS92!["@D)"0ES='EL
M92YW:61T:"`]("(B.PH)"0E]"@D)"6)R96%K.PH)"2`@("!C87-E(")F7W-T
M7VAE:6=H="(Z"@D)"6EF("@O7%,O+G1E<W0H=F%L*2D@>PH)"0D)<W1Y;&4N
M:&5I9VAT(#T@=F%L("L@<&%R86US6R)F7W-T7VAE:6=H=%5N:70B73L*"0D)
M?2!E;'-E('L*"0D)"7-T>6QE+FAE:6=H="`]("(B.PH)"0E]"@D)"6)R96%K
M.PH)"2`@("!C87-E(")F7W-T7W1E>'1!;&EG;B(Z"@D)"6EF("AV86P@/3T@
M(F-H87(B*2!["@D)"0EV87(@8V@@/2!P87)A;7-;(F9?<W1?=&5X=$%L:6=N
M0VAA<B)=.PH)"0D):68@*&-H(#T]("<B)RD@>PH)"0D)"6-H(#T@)UQ<(B<[
M"@D)"0E]"@D)"0ES='EL92YT97AT06QI9VX@/2`G(B<@*R!C:"`K("<B)SL*
M"0D)?2!E;'-E('L*"0D)"7-T>6QE+G1E>'1!;&EG;B`]('9A;#L*"0D)?0H)
M"0EB<F5A:SL*"0D@("`@8V%S92`B9E]S=%]V97)T:6-A;$%L:6=N(CH*"0D)
M<W1Y;&4N=F5R=&EC86Q!;&EG;B`]('9A;#L*"0D)8G)E86L["@D)("`@(&-A
M<V4@(F9?<W1?9FQO870B.@H)"0ES='EL92YC<W-&;&]A="`]('9A;#L*"0D)
M8G)E86L["B\O(`D)("`@(&-A<V4@(F9?<W1?;6%R9VEN(CH*+R\@"0D)<W1Y
M;&4N;6%R9VEN(#T@=F%L("L@(G!X(CL*+R\@"0D)8G)E86L["B\O(`D)("`@
M(&-A<V4@(F9?<W1?<&%D9&EN9R(Z"B\O(`D)"7-T>6QE+G!A9&1I;F<@/2!V
M86P@*R`B<'@B.PHO+R`)"0EB<F5A:SL*"0E]"@E]"GT["@HO+R!2971U<FYS
M(&%N($A434P@96QE;65N="!F;W(@82!W:61G970@=&AA="!A;&QO=W,@8V]L
M;W(@<V5L96-T:6]N+B`@5&AA="!I<RP*+R\@82!B=71T;VX@=&AA="!C;VYT
M86EN<R!T:&4@9VEV96X@8V]L;W(L(&EF(&%N>2P@86YD('=H96X@<')E<W-E
M9"!W:6QL('!O<'5P"B\O('1H92!S;V]N97(M;W(M;&%T97(M=&\M8F4M<F5W
M<FET=&5N('-E;&5C=%]C;VQO<BYH=&UL(&1I86QO9R!A;&QO=VEN9R!U<V5R
M"B\O('1O('-E;&5C="!S;VUE(&-O;&]R+B`@268@82!C;VQO<B!I<R!S96QE
M8W1E9"P@86X@:6YP=70@9FEE;&0@=VET:"!T:&4@;F%M90HO+R`B9E]S=%\B
M*VYA;64@=VEL;"!B92!U<&1A=&5D('=I=&@@=&AE(&-O;&]R('9A;'5E(&EN
M(",Q,C,T-38@9F]R;6%T+@I486)L94]P97)A=&EO;G,N8W)E871E0V]L;W)"
M=71T;VX@/2!F=6YC=&EO;BAD;V,L(&5D:71O<BP@8V]L;W(L(&YA;64I('L*
M"6EF("@A8V]L;W(I('L*"0EC;VQO<B`]("(B.PH)?2!E;'-E(&EF("@A+R,O
M+G1E<W0H8V]L;W(I*2!["@D)8V]L;W(@/2!(5$U,07)E82Y?8V]L;W)4;U)G
M8BAC;VQO<BD["@E]"@H)=F%R(&1F(#T@9&]C+F-R96%T945L96UE;G0H(G-P
M86XB*3L*(`EV87(@9FEE;&0@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B
M*3L*"69I96QD+G1Y<&4@/2`B:&ED9&5N(CL*"61F+F%P<&5N9$-H:6QD*&9I
M96QD*3L*(`EF:65L9"YN86UE(#T@(F9?<W1?(B`K(&YA;64["@EF:65L9"YV
M86QU92`](&-O;&]R.PH)=F%R(&)U='1O;B`](&1O8RYC<F5A=&5%;&5M96YT
M*")S<&%N(BD["@EB=71T;VXN8VQA<W-.86UE(#T@(F)U='1O;D-O;&]R(CL*
M"61F+F%P<&5N9$-H:6QD*&)U='1O;BD["@EV87(@<W!A;B`](&1O8RYC<F5A
M=&5%;&5M96YT*")S<&%N(BD["@ES<&%N+F-L87-S3F%M92`](")C:&]O<V5R
M(CL*"2\O('-P86XN:6YN97)(5$U,(#T@(B9N8G-P.R9N8G-P.R9N8G-P.R9N
M8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R(["@ES<&%N+G-T>6QE+F)A8VMG<F]U
M;F1#;VQO<B`](&-O;&]R.PH)8G5T=&]N+F%P<&5N9$-H:6QD*'-P86XI.PH)
M8G5T=&]N+F]N;6]U<V5O=F5R(#T@9G5N8W1I;VXH*2![(&EF("@A=&AI<RYD
M:7-A8FQE9"D@>R!T:&ES+F-L87-S3F%M92`K/2`B(&)U='1O;D-O;&]R+6AI
M;&ET92([('U].PH)8G5T=&]N+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L@
M:68@*"%T:&ES+F1I<V%B;&5D*2![('1H:7,N8VQA<W-.86UE(#T@(F)U='1O
M;D-O;&]R(CL@?7T["@ES<&%N+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*"0EI
M9B`H=&AI<RYP87)E;G1.;V1E+F1I<V%B;&5D*2!["@D)"7)E='5R;B!F86QS
M93L*"0E]"@D)961I=&]R+E]P;W!U<$1I86QO9R@B<V5L96-T7V-O;&]R+FAT
M;6PB+"!F=6YC=&EO;BAC;VQO<BD@>PH)"0EI9B`H8V]L;W(I('L*"0D)"7-P
M86XN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@(B,B("L@8V]L;W(["@D)"0EF
M:65L9"YV86QU92`]("(C(B`K(&-O;&]R.PH)"0E]"@D)?2P@8V]L;W(I.PH)
M?3L*"79A<B!S<&%N,B`](&1O8RYC<F5A=&5%;&5M96YT*")S<&%N(BD["@ES
M<&%N,BYI;FYE<DA434P@/2`B)B-X,#!D-SLB.PH)<W!A;C(N8VQA<W-.86UE
M(#T@(FYO8V]L;W(B.PH)<W!A;C(N=&ET;&4@/2!486)L94]P97)A=&EO;G,N
M23$X3ELB56YS970@8V]L;W(B73L*"6)U='1O;BYA<'!E;F1#:&EL9"AS<&%N
M,BD["@ES<&%N,BYO;FUO=7-E;W9E<B`](&9U;F-T:6]N*"D@>R!I9B`H(71H
M:7,N<&%R96YT3F]D92YD:7-A8FQE9"D@>R!T:&ES+F-L87-S3F%M92`K/2`B
M(&YO8V]L;W(M:&EL:71E(CL@?7T["@ES<&%N,BYO;FUO=7-E;W5T(#T@9G5N
M8W1I;VXH*2![(&EF("@A=&AI<RYP87)E;G1.;V1E+F1I<V%B;&5D*2![('1H
M:7,N8VQA<W-.86UE(#T@(FYO8V]L;W(B.R!]?3L*"7-P86XR+F]N8VQI8VL@
M/2!F=6YC=&EO;B@I('L*"0ES<&%N+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`]
M("(B.PH)"69I96QD+G9A;'5E(#T@(B(["@E].PH)<F5T=7)N(&1F.PI].PH*
M5&%B;&5/<&5R871I;VYS+F-R96%T95-T>6QE3&%Y;W5T1FEE;&1S970@/2!F
M=6YC=&EO;BAD;V,L(&5D:71O<BP@96PI('L*"79A<B!I,3AN(#T@5&%B;&5/
M<&5R871I;VYS+DDQ.$X["@EV87(@9FEE;&1S970@/2!D;V,N8W)E871E16QE
M;65N="@B9FEE;&1S970B*3L*"79A<B!L96=E;F0@/2!D;V,N8W)E871E16QE
M;65N="@B;&5G96YD(BD["@EF:65L9'-E="YA<'!E;F1#:&EL9"AL96=E;F0I
M.PH);&5G96YD+FEN;F5R2%1-3"`](&DQ.&Y;(DQA>6]U=")=.PH)=F%R('1A
M8FQE(#T@9&]C+F-R96%T945L96UE;G0H(G1A8FQE(BD["@EF:65L9'-E="YA
M<'!E;F1#:&EL9"AT86)L92D["@ET86)L92YS='EL92YW:61T:"`]("(Q,#`E
M(CL*"79A<B!T8F]D>2`](&1O8RYC<F5A=&5%;&5M96YT*")T8F]D>2(I.PH)
M=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH*"79A<B!T86=N86UE(#T@96PN
M=&%G3F%M92YT;TQO=V5R0V%S92@I.PH)=F%R('1R+"!T9"P@:6YP=70L('-E
M;&5C="P@;W!T:6]N+"!O<'1I;VYS+"!I.PH*"6EF("AT86=N86UE("$](")T
M9"(@)B8@=&%G;F%M92`A/2`B='(B("8F('1A9VYA;64@(3T@(G1H(BD@>PH)
M"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@D)=&)O9'DN87!P96YD
M0VAI;&0H='(I.PH)"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)
M=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"0ET<BYA<'!E;F1#:&EL9"AT9"D[
M"@D)=&0N:6YN97)(5$U,(#T@:3$X;ELB1FQO870B72`K("(Z(CL*"0ET9"`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)"71R+F%P<&5N9$-H:6QD*'1D
M*3L*"0ES96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@D)
M=&0N87!P96YD0VAI;&0H<V5L96-T*3L*"0ES96QE8W0N;F%M92`](")F7W-T
M7V9L;V%T(CL*"0EO<'1I;VYS(#T@6R).;VYE(BP@(DQE9G0B+"`B4FEG:'0B
M73L*"0EF;W(@*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H.R`K*VDI
M('L*"0D)=F%R(%9A;"`](&]P=&EO;G-;:5T["@D)"79A<B!V86P@/2!O<'1I
M;VYS6VE=+G1O3&]W97)#87-E*"D["@D)"6]P=&EO;B`](&1O8RYC<F5A=&5%
M;&5M96YT*")O<'1I;VXB*3L*"0D);W!T:6]N+FEN;F5R2%1-3"`](&DQ.&Y;
M5F%L73L*"0D);W!T:6]N+G9A;'5E(#T@=F%L.PH)"0EO<'1I;VXN<V5L96-T
M960@/2`H*"(B("L@96PN<W1Y;&4N8W-S1FQO870I+G1O3&]W97)#87-E*"D@
M/3T@=F%L*3L*"0D)<V5L96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD["@D)?0H)
M?0H*"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R(BD["@ET8F]D>2YA<'!E
M;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)
M=&0N8VQA<W-.86UE(#T@(FQA8F5L(CL*"71R+F%P<&5N9$-H:6QD*'1D*3L*
M"71D+FEN;F5R2%1-3"`](&DQ.&Y;(E=I9'1H(ET@*R`B.B(["@ET9"`](&1O
M8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH)
M:6YP=70@/2!D;V,N8W)E871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G1Y
M<&4@/2`B=&5X="(["@EI;G!U="YV86QU92`](%1A8FQE3W!E<F%T:6]N<RYG
M971,96YG=&@H96PN<W1Y;&4N=VED=&@I.PH):6YP=70N<VEZ92`]("(U(CL*
M"6EN<'5T+FYA;64@/2`B9E]S=%]W:61T:"(["@EI;G!U="YS='EL92YM87)G
M:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AI;G!U="D["@ES
M96QE8W0@/2!D;V,N8W)E871E16QE;65N="@B<V5L96-T(BD["@ES96QE8W0N
M;F%M92`](")F7W-T7W=I9'1H56YI="(["@EO<'1I;VX@/2!D;V,N8W)E871E
M16QE;65N="@B;W!T:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB
M<&5R8V5N=")=.PH);W!T:6]N+G9A;'5E(#T@(B4B.PH);W!T:6]N+G-E;&5C
M=&5D(#T@+R4O+G1E<W0H96PN<W1Y;&4N=VED=&@I.PH)<V5L96-T+F%P<&5N
M9$-H:6QD*&]P=&EO;BD["@EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B
M;W!T:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB<&EX96QS(ET[
M"@EO<'1I;VXN=F%L=64@/2`B<'@B.PH);W!T:6]N+G-E;&5C=&5D(#T@+W!X
M+RYT97-T*&5L+G-T>6QE+G=I9'1H*3L*"7-E;&5C="YA<'!E;F1#:&EL9"AO
M<'1I;VXI.PH)=&0N87!P96YD0VAI;&0H<V5L96-T*3L*"@ES96QE8W0N<W1Y
M;&4N;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H9&]C
M+F-R96%T951E>'1.;V1E*&DQ.&Y;(E1E>'0@86QI9VXB72`K("(Z(BDI.PH)
M<V5L96-T(#T@9&]C+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T
M+G-T>6QE+FUA<F=I;DQE9G0@/2!S96QE8W0N<W1Y;&4N;6%R9VEN4FEG:'0@
M/2`B,"XU96TB.PH)=&0N87!P96YD0VAI;&0H<V5L96-T*3L*"7-E;&5C="YN
M86UE(#T@(F9?<W1?=&5X=$%L:6=N(CL*"6]P=&EO;G,@/2!;(DQE9G0B+"`B
M0V5N=&5R(BP@(E)I9VAT(BP@(DIU<W1I9GDB73L*"6EF("AT86=N86UE(#T]
M(")T9"(I('L*"0EO<'1I;VYS+G!U<V@H(D-H87(B*3L*"7T*"6EN<'5T(#T@
M9&]C+F-R96%T945L96UE;G0H(FEN<'5T(BD["@EI;G!U="YN86UE(#T@(F9?
M<W1?=&5X=$%L:6=N0VAA<B(["@EI;G!U="YS:7IE(#T@(C$B.PH):6YP=70N
M<W1Y;&4N9F]N=$9A;6EL>2`](")M;VYO<W!A8V4B.PH)=&0N87!P96YD0VAI
M;&0H:6YP=70I.PH)9F]R("AV87(@:2`](#`[(&D@/"!O<'1I;VYS+FQE;F=T
M:#L@*RMI*2!["@D)=F%R(%9A;"`](&]P=&EO;G-;:5T["@D)=F%R('9A;"`]
M(%9A;"YT;TQO=V5R0V%S92@I.PH)"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M
M96YT*")O<'1I;VXB*3L*"0EO<'1I;VXN=F%L=64@/2!V86P["@D);W!T:6]N
M+FEN;F5R2%1-3"`](&DQ.&Y;5F%L73L*"0EO<'1I;VXN<V5L96-T960@/2`H
M96PN<W1Y;&4N=&5X=$%L:6=N+G1O3&]W97)#87-E*"D@/3T@=F%L*3L*"0ES
M96QE8W0N87!P96YD0VAI;&0H;W!T:6]N*3L*"7T*"69U;F-T:6]N('-E=$-H
M87)6:7-I8FEL:71Y*'9A;'5E*2!["@D):6YP=70N<W1Y;&4N=FES:6)I;&ET
M>2`]('9A;'5E(#\@(G9I<VEB;&4B(#H@(FAI9&1E;B(["@D):68@*'9A;'5E
M*2!["@D)"6EN<'5T+F9O8W5S*"D["@D)"6EN<'5T+G-E;&5C="@I.PH)"7T*
M"7T["@ES96QE8W0N;VYC:&%N9V4@/2!F=6YC=&EO;B@I('L@<V5T0VAA<E9I
M<VEB:6QI='DH=&AI<RYV86QU92`]/2`B8VAA<B(I.R!].PH)<V5T0VAA<E9I
M<VEB:6QI='DH<V5L96-T+G9A;'5E(#T](")C:&%R(BD["@H)='(@/2!D;V,N
M8W)E871E16QE;65N="@B='(B*3L*"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*
M"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@ET9"YC;&%S<TYA;64@
M/2`B;&%B96PB.PH)='(N87!P96YD0VAI;&0H=&0I.PH)=&0N:6YN97)(5$U,
M(#T@:3$X;ELB2&5I9VAT(ET@*R`B.B(["@ET9"`](&1O8RYC<F5A=&5%;&5M
M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH):6YP=70@/2!D;V,N
M8W)E871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G1Y<&4@/2`B=&5X="([
M"@EI;G!U="YV86QU92`](%1A8FQE3W!E<F%T:6]N<RYG971,96YG=&@H96PN
M<W1Y;&4N:&5I9VAT*3L*"6EN<'5T+G-I>F4@/2`B-2(["@EI;G!U="YN86UE
M(#T@(F9?<W1?:&5I9VAT(CL*"6EN<'5T+G-T>6QE+FUA<F=I;E)I9VAT(#T@
M(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*"7-E;&5C="`](&1O
M8RYC<F5A=&5%;&5M96YT*")S96QE8W0B*3L*"7-E;&5C="YN86UE(#T@(F9?
M<W1?:&5I9VAT56YI="(["@EO<'1I;VX@/2!D;V,N8W)E871E16QE;65N="@B
M;W!T:6]N(BD["@EO<'1I;VXN:6YN97)(5$U,(#T@:3$X;ELB<&5R8V5N=")=
M.PH);W!T:6]N+G9A;'5E(#T@(B4B.PH);W!T:6]N+G-E;&5C=&5D(#T@+R4O
M+G1E<W0H96PN<W1Y;&4N:&5I9VAT*3L*"7-E;&5C="YA<'!E;F1#:&EL9"AO
M<'1I;VXI.PH);W!T:6]N(#T@9&]C+F-R96%T945L96UE;G0H(F]P=&EO;B(I
M.PH);W!T:6]N+FEN;F5R2%1-3"`](&DQ.&Y;(G!I>&5L<R)=.PH);W!T:6]N
M+G9A;'5E(#T@(G!X(CL*"6]P=&EO;BYS96QE8W1E9"`]("]P>"\N=&5S="AE
M;"YS='EL92YH96EG:'0I.PH)<V5L96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD[
M"@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH*"7-E;&5C="YS='EL92YM87)G
M:6Y2:6=H="`]("(P+C5E;2(["@ET9"YA<'!E;F1#:&EL9"AD;V,N8W)E871E
M5&5X=$YO9&4H:3$X;ELB5F5R=&EC86P@86QI9VXB72`K("(Z(BDI.PH)<V5L
M96-T(#T@9&]C+F-R96%T945L96UE;G0H(G-E;&5C="(I.PH)<V5L96-T+FYA
M;64@/2`B9E]S=%]V97)T:6-A;$%L:6=N(CL*"7-E;&5C="YS='EL92YM87)G
M:6Y,969T(#T@(C`N-65M(CL*"71D+F%P<&5N9$-H:6QD*'-E;&5C="D["@EO
M<'1I;VYS(#T@6R)4;W`B+"`B36ED9&QE(BP@(D)O='1O;2(L(")"87-E;&EN
M92)=.PH)9F]R("AV87(@:2`](#`[(&D@/"!O<'1I;VYS+FQE;F=T:#L@*RMI
M*2!["@D)=F%R(%9A;"`](&]P=&EO;G-;:5T["@D)=F%R('9A;"`](%9A;"YT
M;TQO=V5R0V%S92@I.PH)"6]P=&EO;B`](&1O8RYC<F5A=&5%;&5M96YT*")O
M<'1I;VXB*3L*"0EO<'1I;VXN=F%L=64@/2!V86P["@D);W!T:6]N+FEN;F5R
M2%1-3"`](&DQ.&Y;5F%L73L*"0EO<'1I;VXN<V5L96-T960@/2`H96PN<W1Y
M;&4N=F5R=&EC86Q!;&EG;BYT;TQO=V5R0V%S92@I(#T]('9A;"D["@D)<V5L
M96-T+F%P<&5N9$-H:6QD*&]P=&EO;BD["@E]"@H)<F5T=7)N(&9I96QD<V5T
M.PI].PH*+R\@4F5T=7)N<R!A;B!(5$U,(&5L96UE;G0@8V]N=&%I;FEN9R!T
M:&4@<W1Y;&4@871T<FEB=71E<R!F;W(@=&AE(&=I=F5N"B\O(&5L96UE;G0N
M("!4:&ES(&-A;B!B92!E87-I;'D@96UB961D960@:6YT;R!A;GD@9&EA;&]G
M.R!T:&4@9G5N8W1I;VYA;&ET>2!I<PHO+R!A;'-O('!R;W9I9&5D+@I486)L
M94]P97)A=&EO;G,N8W)E871E4W1Y;&5&:65L9'-E="`](&9U;F-T:6]N*&1O
M8RP@961I=&]R+"!E;"D@>PH)=F%R(&DQ.&X@/2!486)L94]P97)A=&EO;G,N
M23$X3CL*"79A<B!F:65L9'-E="`](&1O8RYC<F5A=&5%;&5M96YT*")F:65L
M9'-E="(I.PH)=F%R(&QE9V5N9"`](&1O8RYC<F5A=&5%;&5M96YT*")L96=E
M;F0B*3L*"69I96QD<V5T+F%P<&5N9$-H:6QD*&QE9V5N9"D["@EL96=E;F0N
M:6YN97)(5$U,(#T@:3$X;ELB0U-3(%-T>6QE(ET["@EV87(@=&%B;&4@/2!D
M;V,N8W)E871E16QE;65N="@B=&%B;&4B*3L*"69I96QD<V5T+F%P<&5N9$-H
M:6QD*'1A8FQE*3L*"71A8FQE+G-T>6QE+G=I9'1H(#T@(C$P,"4B.PH)=F%R
M('1B;V1Y(#T@9&]C+F-R96%T945L96UE;G0H(G1B;V1Y(BD["@ET86)L92YA
M<'!E;F1#:&EL9"AT8F]D>2D["@H)=F%R('1R+"!T9"P@:6YP=70L('-E;&5C
M="P@;W!T:6]N+"!O<'1I;VYS+"!I.PH*"71R(#T@9&]C+F-R96%T945L96UE
M;G0H(G1R(BD["@ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC
M<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH)=&0N
M8VQA<W-.86UE(#T@(FQA8F5L(CL*"71D+FEN;F5R2%1-3"`](&DQ.&Y;(D)A
M8VMG<F]U;F0B72`K("(Z(CL*"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D
M(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@EV87(@9&8@/2!486)L94]P97)A
M=&EO;G,N8W)E871E0V]L;W)"=71T;VXH9&]C+"!E9&ET;W(L(&5L+G-T>6QE
M+F)A8VMG<F]U;F1#;VQO<BP@(F)A8VMG<F]U;F1#;VQO<B(I.PH)9&8N9FER
M<W1#:&EL9"YN97AT4VEB;&EN9RYS='EL92YM87)G:6Y2:6=H="`]("(P+C5E
M;2(["@ET9"YA<'!E;F1#:&EL9"AD9BD["@ET9"YA<'!E;F1#:&EL9"AD;V,N
M8W)E871E5&5X=$YO9&4H:3$X;ELB26UA9V4@55),(ET@*R`B.B`B*2D["@EI
M;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PH):6YP=70N='EP
M92`](")T97AT(CL*"6EN<'5T+FYA;64@/2`B9E]S=%]B86-K9W)O=6YD26UA
M9V4B.PH):68@*&5L+G-T>6QE+F)A8VMG<F]U;F1);6%G92YM871C:"@O=7)L
M7"A<<RHH+BH_*5QS*EPI+RDI('L*"0EI;G!U="YV86QU92`](%)E9T5X<"XD
M,3L*"7T*"2\O(&EN<'5T+G-T>6QE+G=I9'1H(#T@(C$P,"4B.PH)=&0N87!P
M96YD0VAI;&0H:6YP=70I.PH*"71R(#T@9&]C+F-R96%T945L96UE;G0H(G1R
M(BD["@ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@ET9"`](&1O8RYC<F5A=&5%
M;&5M96YT*")T9"(I.PH)='(N87!P96YD0VAI;&0H=&0I.PH)=&0N8VQA<W-.
M86UE(#T@(FQA8F5L(CL*"71D+FEN;F5R2%1-3"`](&DQ.&Y;(D9'($-O;&]R
M(ET@*R`B.B(["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N
M87!P96YD0VAI;&0H=&0I.PH)=&0N87!P96YD0VAI;&0H5&%B;&5/<&5R871I
M;VYS+F-R96%T94-O;&]R0G5T=&]N*&1O8RP@961I=&]R+"!E;"YS='EL92YC
M;VQO<BP@(F-O;&]R(BDI.PH*"2\O(&9O<B!B971T97(@86QI9VYM96YT('=E
M(&EN8VQU9&4@86X@:6YV:7-I8FQE(&9I96QD+@H):6YP=70@/2!D;V,N8W)E
M871E16QE;65N="@B:6YP=70B*3L*"6EN<'5T+G-T>6QE+G9I<VEB:6QI='D@
M/2`B:&ED9&5N(CL*"6EN<'5T+G1Y<&4@/2`B=&5X="(["@ET9"YA<'!E;F1#
M:&EL9"AI;G!U="D["@H)='(@/2!D;V,N8W)E871E16QE;65N="@B='(B*3L*
M"71B;V1Y+F%P<&5N9$-H:6QD*'1R*3L*"71D(#T@9&]C+F-R96%T945L96UE
M;G0H(G1D(BD["@ET<BYA<'!E;F1#:&EL9"AT9"D["@ET9"YC;&%S<TYA;64@
M/2`B;&%B96PB.PH)=&0N:6YN97)(5$U,(#T@:3$X;ELB0F]R9&5R(ET@*R`B
M.B(["@ET9"`](&1O8RYC<F5A=&5%;&5M96YT*")T9"(I.PH)='(N87!P96YD
M0VAI;&0H=&0I.PH*"79A<B!C;VQO<D)U='1O;B`](%1A8FQE3W!E<F%T:6]N
M<RYC<F5A=&5#;VQO<D)U='1O;BAD;V,L(&5D:71O<BP@96PN<W1Y;&4N8F]R
M9&5R0V]L;W(L(")B;W)D97)#;VQO<B(I.PH)=F%R(&)T;B`](&-O;&]R0G5T
M=&]N+F9I<G-T0VAI;&0N;F5X=%-I8FQI;F<["@ET9"YA<'!E;F1#:&EL9"AC
M;VQO<D)U='1O;BD["@DO+R!B;W)D97)&:65L9',N<'5S:"AB=&XI.PH)8G1N
M+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"@ES96QE8W0@/2!D;V,N
M8W)E871E16QE;65N="@B<V5L96-T(BD["@EV87(@8F]R9&5R1FEE;&1S(#T@
M6UT["@ET9"YA<'!E;F1#:&EL9"AS96QE8W0I.PH)<V5L96-T+FYA;64@/2`B
M9E]S=%]B;W)D97)3='EL92(["@EO<'1I;VYS(#T@6R)N;VYE(BP@(F1O='1E
M9"(L(")D87-H960B+"`B<V]L:60B+"`B9&]U8FQE(BP@(F=R;V]V92(L(")R
M:61G92(L(")I;G-E="(L(")O=71S970B73L*"79A<B!C=7)R96YT0F]R9&5R
M4W1Y;&4@/2!E;"YS='EL92YB;W)D97)3='EL93L*"2\O($=E8VMO(')E<&]R
M=',@(G-O;&ED('-O;&ED('-O;&ED('-O;&ED(B!F;W(@(F)O<F1E<BUS='EL
M93H@<V]L:60B+@H)+R\@5&AA="!I<RP@(G1O<"!R:6=H="!B;W1T;VT@;&5F
M="(@+2T@=V4@;VYL>2!C;VYS:61E<B!T:&4@9FER<W0*"2\O('9A;'5E+@H)
M*&-U<G)E;G1";W)D97)3='EL92YM871C:"@O*%M>7'-=*BE<<R\I*2`F)B`H
M8W5R<F5N=$)O<F1E<E-T>6QE(#T@4F5G17AP+B0Q*3L*"69O<B`H=F%R(&D@
M:6X@;W!T:6]N<RD@>PH)"79A<B!V86P@/2!O<'1I;VYS6VE=.PH)"6]P=&EO
M;B`](&1O8RYC<F5A=&5%;&5M96YT*")O<'1I;VXB*3L*"0EO<'1I;VXN=F%L
M=64@/2!V86P["@D);W!T:6]N+FEN;F5R2%1-3"`]('9A;#L*"0DH=F%L(#T]
M(&-U<G)E;G1";W)D97)3='EL92D@)B8@*&]P=&EO;BYS96QE8W1E9"`]('1R
M=64I.PH)"7-E;&5C="YA<'!E;F1#:&EL9"AO<'1I;VXI.PH)?0H)<V5L96-T
M+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*"69U;F-T:6]N('-E=$)O
M<F1E<D9I96QD<U-T871U<RAV86QU92D@>PH)"69O<B`H=F%R(&D@/2`P.R!I
M(#P@8F]R9&5R1FEE;&1S+FQE;F=T:#L@*RMI*2!["@D)"79A<B!E;"`](&)O
M<F1E<D9I96QD<UMI73L*"0D)96PN<W1Y;&4N=FES:6)I;&ET>2`]('9A;'5E
M(#\@(FAI9&1E;B(@.B`B=FES:6)L92(["@D)"6EF("@A=F%L=64@)B8@*&5L
M+G1A9TYA;64N=&],;W=E<D-A<V4H*2`]/2`B:6YP=70B*2D@>PH)"0D)96PN
M9F]C=7,H*3L*"0D)"65L+G-E;&5C="@I.PH)"0E]"@D)?0H)?3L*"7-E;&5C
M="YO;F-H86YG92`](&9U;F-T:6]N*"D@>R!S971";W)D97)&:65L9'-3=&%T
M=7,H=&AI<RYV86QU92`]/2`B;F]N92(I.R!].PH*"6EN<'5T(#T@9&]C+F-R
M96%T945L96UE;G0H(FEN<'5T(BD["@EB;W)D97)&:65L9',N<'5S:"AI;G!U
M="D["@EI;G!U="YT>7!E(#T@(G1E>'0B.PH):6YP=70N;F%M92`](")F7W-T
M7V)O<F1E<E=I9'1H(CL*"6EN<'5T+G9A;'5E(#T@5&%B;&5/<&5R871I;VYS
M+F=E=$QE;F=T:"AE;"YS='EL92YB;W)D97)7:61T:"D["@EI;G!U="YS:7IE
M(#T@(C4B.PH)=&0N87!P96YD0VAI;&0H:6YP=70I.PH):6YP=70N<W1Y;&4N
M;6%R9VEN4FEG:'0@/2`B,"XU96TB.PH)=F%R('-P86X@/2!D;V,N8W)E871E
M16QE;65N="@B<W!A;B(I.PH)<W!A;BYI;FYE<DA434P@/2!I,3AN6R)P:7AE
M;',B73L*"71D+F%P<&5N9$-H:6QD*'-P86XI.PH)8F]R9&5R1FEE;&1S+G!U
M<V@H<W!A;BD["@H)<V5T0F]R9&5R1FEE;&1S4W1A='5S*'-E;&5C="YV86QU
M92`]/2`B;F]N92(I.PH*"6EF("AE;"YT86=.86UE+G1O3&]W97)#87-E*"D@
M/3T@(G1A8FQE(BD@>PH)"2\O('1H92!B;W)D97(M8V]L;&%P<V4@<W1Y;&4@
M:7,@;VYL>2!F;W(@=&%B;&5S"@D)='(@/2!D;V,N8W)E871E16QE;65N="@B
M='(B*3L*"0ET8F]D>2YA<'!E;F1#:&EL9"AT<BD["@D)=&0@/2!D;V,N8W)E
M871E16QE;65N="@B=&0B*3L*"0ET9"YC;&%S<TYA;64@/2`B;&%B96PB.PH)
M"71R+F%P<&5N9$-H:6QD*'1D*3L*"0EI;G!U="`](&1O8RYC<F5A=&5%;&5M
M96YT*")I;G!U="(I.PH)"6EN<'5T+G1Y<&4@/2`B8VAE8VMB;W@B.PH)"6EN
M<'5T+FYA;64@/2`B9E]S=%]B;W)D97)#;VQL87!S92(["@D):6YP=70N:60@
M/2`B9E]S=%]B;W)D97)#;VQL87!S92(["@D)=F%R('9A;"`]("@O8V]L;&%P
M<V4O:2YT97-T*&5L+G-T>6QE+F)O<F1E<D-O;&QA<'-E*2D["@D):6YP=70N
M8VAE8VME9"`]('9A;"`_(#$@.B`P.PH)"71D+F%P<&5N9$-H:6QD*&EN<'5T
M*3L*"@D)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*"0ET<BYA<'!E
M;F1#:&EL9"AT9"D["@D)=F%R(&QA8F5L(#T@9&]C+F-R96%T945L96UE;G0H
M(FQA8F5L(BD["@D);&%B96PN:'1M;$9O<B`](")F7W-T7V)O<F1E<D-O;&QA
M<'-E(CL*"0EL86)E;"YI;FYE<DA434P@/2!I,3AN6R)#;VQL87!S960@8F]R
M9&5R<R)=.PH)"71D+F%P<&5N9$-H:6QD*&QA8F5L*3L*"7T*"B\O(`ET<B`]
M(&1O8RYC<F5A=&5%;&5M96YT*")T<B(I.PHO+R`)=&)O9'DN87!P96YD0VAI
M;&0H='(I.PHO+R`)=&0@/2!D;V,N8W)E871E16QE;65N="@B=&0B*3L*+R\@
M"71D+F-L87-S3F%M92`](")L86)E;"(["B\O(`ET<BYA<'!E;F1#:&EL9"AT
M9"D["B\O(`ET9"YI;FYE<DA434P@/2!I,3AN6R)-87)G:6XB72`K("(Z(CL*
M+R\@"71D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["B\O(`ET<BYA<'!E
M;F1#:&EL9"AT9"D["B\O(`EI;G!U="`](&1O8RYC<F5A=&5%;&5M96YT*")I
M;G!U="(I.PHO+R`):6YP=70N='EP92`](")T97AT(CL*+R\@"6EN<'5T+G-I
M>F4@/2`B-2(["B\O(`EI;G!U="YN86UE(#T@(F9?<W1?;6%R9VEN(CL*+R\@
M"71D+F%P<&5N9$-H:6QD*&EN<'5T*3L*+R\@"6EN<'5T+G-T>6QE+FUA<F=I
M;E)I9VAT(#T@(C`N-65M(CL*+R\@"71D+F%P<&5N9$-H:6QD*&1O8RYC<F5A
M=&5497AT3F]D92AI,3AN6R)0861D:6YG(ET@*R`B.B(I*3L*"B\O(`EI;G!U
M="`](&1O8RYC<F5A=&5%;&5M96YT*")I;G!U="(I.PHO+R`):6YP=70N='EP
M92`](")T97AT(CL*+R\@"6EN<'5T+G-I>F4@/2`B-2(["B\O(`EI;G!U="YN
M86UE(#T@(F9?<W1?<&%D9&EN9R(["B\O(`ET9"YA<'!E;F1#:&EL9"AI;G!U
M="D["B\O(`EI;G!U="YS='EL92YM87)G:6Y,969T(#T@(C`N-65M(CL*+R\@
M"6EN<'5T+G-T>6QE+FUA<F=I;E)I9VAT(#T@(C`N-65M(CL*+R\@"71D+F%P
M<&5N9$-H:6QD*&1O8RYC<F5A=&5497AT3F]D92AI,3AN6R)P:7AE;',B72DI
M.PH*"7)E='5R;B!F:65L9'-E=#L*?3L*"B\O+R\@14Y$($=%3D5224,@0T]$
M12`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I
M;VYS+VQA;F<O96XN:G,``````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$P,#<V(#$P-3$U-#,T,30S(#`S,3$P,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O+R!),3A.
M(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z(%541BTX('P@
M25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H='1P.B\O9'EN
M87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z"B\O"B\O("`@
M,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!42$4@04)/5D4@
M3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL(&%D9')E<W,I
M"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@1D]2($5.0T]$
M24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L92P@<&QE87-E
M(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A=&5S('=H870@
M96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"E1A8FQE3W!E<F%T:6]N<RY),3A.
M(#T@>PH)(D%L:6=N(CH)"0D)"2`@(D%L:6=N(BP*"2)!;&P@9F]U<B!S:61E
M<R(Z"0D)"2`@(D%L;"!F;W5R('-I9&5S(BP*"2)"86-K9W)O=6YD(CH)"0D)
M"2`@(D)A8VMG<F]U;F0B+`H)(D)A<V5L:6YE(CH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B0F%S96QI;F4B+`H)(D)O<F1E<B(Z
M"0D)"0D@(")";W)D97(B+`H)(D)O<F1E<G,B.@D)"0D)("`B0F]R9&5R<R(L
M"@DB0F]T=&]M(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(")";W1T;VTB+`H)(D-34R!3='EL92(Z"0D)"0D@(")3='EL92!;
M0U-372(L"@DB0V%P=&EO;B(Z"0D)"0D@(")#87!T:6]N(BP*"2)#96QL(%!R
M;W!E<G1I97,B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(D-E
M;&P@4')O<&5R=&EE<R(L"@DB0V5N=&5R(CH)"0D)"2`@(D-E;G1E<B(L"@DB
M0VAA<B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(")#:&%R(BP*"2)#;VQL87!S960@8F]R9&5R<R(Z("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(D-O;&QA<'-E9"!B;W)D97)S(BP*"2)#;VQO
M<B(Z"0D)"0D@(")#;VQO<B(L"@DB1&5S8W)I<'1I;VXB.@D)"0D)("`B1&5S
M8W)I<'1I;VXB+`H)(D9'($-O;&]R(CH)"0D)"2`@(D9'($-O;&]R(BP*"2)&
M;&]A="(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(D9L;V%T(BP*"2)&<F%M97,B.@D)"0D)("`B1G)A;65S(BP*"2)(96EG
M:'0B.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(DAE:6=H="(L"@DB2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B.B`@("`@(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(L"@DB2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B.B`@("`@("`@(")(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/R(L"@DB26UA9V4@55),(CH)"0D)"2`@(DEM86=E
M(%523"(L"@DB2G5S=&EF>2(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(")*=7-T:69Y(BP*"2),87EO=70B.@D)"0D)("`B3&%Y
M;W5T(BP*"2),969T(CH)"0D)"0D@("),969T(BP*"2)-87)G:6XB.B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(DUA<F=I;B(L
M"@DB36ED9&QE(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(")-:61D;&4B+`H)(DYO(')U;&5S(CH)"0D)"2`@(DYO(')U;&5S
M(BP*"2).;R!S:61E<R(Z"0D)"0D@(").;R!S:61E<R(L"@DB3F]N92(Z("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(").;VYE
M(BP*"2)0861D:6YG(CH)"0D)"2`@(E!A9&1I;F<B+`H)(E!L96%S92!C;&EC
M:R!I;G1O('-O;64@8V5L;"(Z("`@("`@("`@("`@("`@("`@("`B4&QE87-E
M(&-L:6-K(&EN=&\@<V]M92!C96QL(BP*"2)2:6=H="(Z"0D)"0D@(")2:6=H
M="(L"@DB4F]W(%!R;W!E<G1I97,B.B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(")2;W<@4')O<&5R=&EE<R(L"@DB4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(Z(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(BP*"2)2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(Z"2`@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(BP*"2)2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(Z"0D@(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(L"@DB4G5L97,B.@D)"0D)("`B
M4G5L97,B+`H)(E-P86-I;F<@86YD('!A9&1I;F<B.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`B4W!A8VEN9R!A;F0@<&%D9&EN9R(L"@DB4W!A8VEN
M9R(Z"0D)"0D@(")3<&%C:6YG(BP*"2)3=6UM87)Y(CH)"0D)"2`@(E-U;6UA
M<GDB+`H)(E1/+6-E;&PM9&5L971E(CH)"0D)("`B1&5L971E(&-E;&PB+`H)
M(E1/+6-E;&PM:6YS97)T+6%F=&5R(CH)"0D)("`B26YS97)T(&-E;&P@869T
M97(B+`H)(E1/+6-E;&PM:6YS97)T+6)E9F]R92(Z"0D)("`B26YS97)T(&-E
M;&P@8F5F;W)E(BP*"2)43RUC96QL+6UE<F=E(CH)"0D)("`B365R9V4@8V5L
M;',B+`H)(E1/+6-E;&PM<')O<"(Z"0D)"0D@(")#96QL('!R;W!E<G1I97,B
M+`H)(E1/+6-E;&PM<W!L:70B.@D)"0D@(")3<&QI="!C96QL(BP*"2)43RUC
M;VPM9&5L971E(CH)"0D)("`B1&5L971E(&-O;'5M;B(L"@DB5$\M8V]L+6EN
M<V5R="UA9G1E<B(Z"0D)"2`@(DEN<V5R="!C;VQU;6X@869T97(B+`H)(E1/
M+6-O;"UI;G-E<G0M8F5F;W)E(CH)"0D)("`B26YS97)T(&-O;'5M;B!B969O
M<F4B+`H)(E1/+6-O;"US<&QI="(Z"0D)"0D@(")3<&QI="!C;VQU;6XB+`H)
M(E1/+7)O=RUD96QE=&4B.@D)"0D@(")$96QE=&4@<F]W(BP*"2)43RUR;W<M
M:6YS97)T+6%B;W9E(CH)"0D)("`B26YS97)T(')O=R!B969O<F4B+`H)(E1/
M+7)O=RUI;G-E<G0M=6YD97(B.@D)"0D@("));G-E<G0@<F]W(&%F=&5R(BP*
M"2)43RUR;W<M<')O<"(Z"0D)"0D@(")2;W<@<')O<&5R=&EE<R(L"@DB5$\M
M<F]W+7-P;&ET(CH)"0D)"2`@(E-P;&ET(')O=R(L"@DB5$\M=&%B;&4M<')O
M<"(Z"0D)"2`@(E1A8FQE('!R;W!E<G1I97,B+`H)(E1A8FQE(%!R;W!E<G1I
M97,B.@D)"0D@(")486)L92!0<F]P97)T:65S(BP*"2)497AT(&%L:6=N(CH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E1E>'0@86QI
M9VXB+`H)(E1H92!B;W1T;VT@<VED92!O;FQY(CH)"0D)("`B5&AE(&)O='1O
M;2!S:61E(&]N;'DB+`H)(E1H92!L969T+6AA;F0@<VED92!O;FQY(CH)"0D@
M(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(L"@DB5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB.@D)("`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'DB+`H)(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(Z"0D)("`B5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY(BP*"2)4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>2(Z"0D@(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(L"@DB5&AE('1O<"!S:61E(&]N;'DB.@D)"0D@(")4:&4@=&]P('-I9&4@
M;VYL>2(L"@DB5&]P(CH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(")4;W`B+`D*"2)5;G-E="!C;VQO<B(Z("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(E5N<V5T(&-O;&]R(BP*"2)6
M97)T:6-A;"!A;&EG;B(Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(E9E<G1I8V%L(&%L:6=N(BP*"2)7:61T:"(Z"0D)"0D@(")7:61T:"(L
M"@DB;F]T+61E;"UL87-T+6-E;&PB.@D)"0D@(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB+`H)
M(FYO="UD96PM;&%S="UC;VPB.@D)"0D@(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(BP*
M"2)N;W0M9&5L+6QA<W0M<F]W(CH)"0D)("`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(L"@DB
M<&5R8V5N="(Z"0D)"0D@(")P97)C96YT(BP*"2)P:7AE;',B.@D)"0D)("`B
M<&EX96QS(@I].PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E
M9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-E
M;&PM9&5L971E+F=I9@``````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`Q-#4@,3`U,34T,S0Q-#,@,#,R-C,W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=)1C@Y81(`$@"A``````#_
M____``#___\A^00!```#`"P`````$@`2```"-IR/J<L##]L!H08@#;4XB02%
MT2!\"R`$*5J6IZIV[B2&ACE95^;HG53C;2J_QG"7"?*6S*:D```[````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA
M<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C;VPM<W!L:70N9VEF
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C$T
M(#$P-3$U-#,T,30S(#`S,C,W,``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!'248X.6$2`!(`YP``````@````(``@(````"`
M@`"``("`P,#`P-S`ILKP0"``8"``@"``H"``P"``X"```$``($``0$``8$``
M@$``H$``P$``X$```&``(&``0&``8&``@&``H&``P&``X&```(``((``0(``
M8(``@(``H(``P(``X(```*``(*``0*``8*``@*``H*``P*``X*```,``(,``
M0,``8,``@,``H,``P,``X,```.``(.``0.``8.``@.``H.``P.``X.````!`
M(`!`0`!`8`!`@`!`H`!`P`!`X`!``"!`("!`0"!`8"!`@"!`H"!`P"!`X"!`
M`$!`($!`0$!`8$!`@$!`H$!`P$!`X$!``&!`(&!`0&!`8&!`@&!`H&!`P&!`
MX&!``(!`((!`0(!`8(!`@(!`H(!`P(!`X(!``*!`(*!`0*!`8*!`@*!`H*!`
MP*!`X*!``,!`(,!`0,!`8,!`@,!`H,!`P,!`X,!``.!`(.!`0.!`8.!`@.!`
MH.!`P.!`X.!```"`(`"`0`"`8`"`@`"`H`"`P`"`X`"``""`(""`0""`8""`
M@""`H""`P""`X""``$"`($"`0$"`8$"`@$"`H$"`P$"`X$"``&"`(&"`0&"`
M8&"`@&"`H&"`P&"`X&"``("`(("`0("`8("`@("`H("`P("`X("``*"`(*"`
M0*"`8*"`@*"`H*"`P*"`X*"``,"`(,"`0,"`8,"`@,"`H,"`P,"`X,"``."`
M(."`0."`8."`@."`H."`P."`X."```#`(`#`0`#`8`#`@`#`H`#`P`#`X`#`
M`"#`("#`0"#`8"#`@"#`H"#`P"#`X"#``$#`($#`0$#`8$#`@$#`H$#`P$#`
MX$#``&#`(&#`0&#`8&#`@&#`H&#`P&#`X&#``(#`((#`0(#`8(#`@(#`H(#`
MP(#`X(#``*#`(*#`0*#`8*#`@*#`H*#`P*#`X*#``,#`(,#`0,#`8,#`@,#`
MH,#`__OPH*"D@("`_P```/\`__\```#__P#_`/______(?D$`0``_0`L````
M`!(`$@``"&D`^PD<2+"@P8,(^P%8R+"A0P`"`?S[)W'BQ(H6(2J\:)%C1XT/
M0S*,>-'?/W\$3*)4"9*C20(G_\$TV9*BRI0G<?H#R3#F3)DQ:P*X2?2D4)](
M:9*TF;/HSJ427R:E&%%DR(18LVK=&A``.P``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R
M+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]C96QL+6UE
M<F=E+F=I9@```````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q-C`P(#$P-3$U-#,T,30S(#`S,C0W,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!'248X.6$2`!(`YP``````@````(``
M@(````"`@`"``("`P,#`P-S`ILKP0"``8"``@"``H"``P"``X"```$``($``
M0$``8$``@$``H$``P$``X$```&``(&``0&``8&``@&``H&``P&``X&```(``
M((``0(``8(``@(``H(``P(``X(```*``(*``0*``8*``@*``H*``P*``X*``
M`,``(,``0,``8,``@,``H,``P,``X,```.``(.``0.``8.``@.``H.``P.``
MX.````!`(`!`0`!`8`!`@`!`H`!`P`!`X`!``"!`("!`0"!`8"!`@"!`H"!`
MP"!`X"!``$!`($!`0$!`8$!`@$!`H$!`P$!`X$!``&!`(&!`0&!`8&!`@&!`
MH&!`P&!`X&!``(!`((!`0(!`8(!`@(!`H(!`P(!`X(!``*!`(*!`0*!`8*!`
M@*!`H*!`P*!`X*!``,!`(,!`0,!`8,!`@,!`H,!`P,!`X,!``.!`(.!`0.!`
M8.!`@.!`H.!`P.!`X.!```"`(`"`0`"`8`"`@`"`H`"`P`"`X`"``""`(""`
M0""`8""`@""`H""`P""`X""``$"`($"`0$"`8$"`@$"`H$"`P$"`X$"``&"`
M(&"`0&"`8&"`@&"`H&"`P&"`X&"``("`(("`0("`8("`@("`H("`P("`X("`
M`*"`(*"`0*"`8*"`@*"`H*"`P*"`X*"``,"`(,"`0,"`8,"`@,"`H,"`P,"`
MX,"``."`(."`0."`8."`@."`H."`P."`X."```#`(`#`0`#`8`#`@`#`H`#`
MP`#`X`#``"#`("#`0"#`8"#`@"#`H"#`P"#`X"#``$#`($#`0$#`8$#`@$#`
MH$#`P$#`X$#``&#`(&#`0&#`8&#`@&#`H&#`P&#`X&#``(#`((#`0(#`8(#`
M@(#`H(#`P(#`X(#``*#`(*#`0*#`8*#`@*#`H*#`P*#`X*#``,#`(,#`0,#`
M8,#`@,#`H,#`__OPH*"D@("`_P```/\`__\```#__P#_`/______(?D$`0``
M_0`L`````!(`$@``"%T`^PD<2+"@P8,(^P%8R+"A0P`"`?S[)W'BQ(H6(2J\
M:)%C1XT/0S*,>-'?/Y,H3YX$R3&E2XHD*;YTR9*BRIDP%3+$B;*F1)XY*P(`
MZL_GS:,F08H,F;"ITZ=0`P(`.P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O
M961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R
M;W<M:6YS97)T+6%B;W9E+F=I9@```#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,38T(#$P-3$U-#,T,30S(#`S,S8V-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!'248X.6$2`!(`P@```/__
M``"$X8"`____````____________(?D$`0``!P`L`````!(`$@```SEXNMS^
M,`9%:I7S$#`X#"!(=!U&<9Y$6<3*MM$AS#0<T74LXX(-O9?88$CT/8A%'7)H
M=`";NJB4D0``.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL
M87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+61E;&5T92YG
M:68````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$U
M,"`Q,#4Q-30S-#$T,R`P,S(U,C,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````1TE&.#EA$@`2`*$``````/____\``/___R'Y
M!`$```,`+``````2`!(```(YG(^IRP,/7QNAV@#FM;GMVC'1*`T"(@3IJF*&
M<!HMNP+P_<YZ!Q_D^$)\7)Y/:#$\*G[*B?,)?18``#L`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN
M<R]486)L94]P97)A=&EO;G,O:6UG+V-E;&PM:6YS97)T+6)E9F]R92YG:68`
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q-C8@,3`U,34T,S0Q
M-#,@,#,T,30T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$=)1C@Y81(`$@#"`````(#A@(``______\```#___________\A
M^00!```'`"P`````$@`2```#.WBZW.[@R0,BN5C62H;PQ%0=Q/>%(HE=RLI.
M;2`'*$S,--RZ.CG\@]JD`Q1*7,8'\9=T+(,]9&]*E20``#L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R
M871I;VYS+VEM9R]C96QL+6EN<V5R="UA9G1E<BYG:68``#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,38V(#$P-3$U-#,T,30S(#`S-#`P,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!'248X
M.6$2`!(`P@````"`X8"``/______````____________(?D$`0``!P`L````
M`!(`$@```SMXNMS^\)!)XR(C#V(5UEQ'56)@!J%%G&@GC2'@,H`,ITU=8\(@
MX#E;KQ>Z*6PPCV;C^F2`#^-L2F4D```[````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S
M+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O
M8V5L;"US<&QI="YG:68````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,38Q,R`Q,#4Q-30S-#$T,R`P,S(U,S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````1TE&.#EA$@`2`.<`````
M`(````"``("`````@(``@`"`@,#`P,#<P*;*\$`@`&`@`(`@`*`@`,`@`.`@
M``!``"!``$!``&!``(!``*!``,!``.!```!@`"!@`$!@`&!@`(!@`*!@`,!@
M`.!@``"``""``$"``&"``("``*"``,"``."```"@`""@`$"@`&"@`("@`*"@
M`,"@`."@``#``"#``$#``&#``(#``*#``,#``.#```#@`"#@`$#@`&#@`(#@
M`*#@`,#@`.#@````0"``0$``0&``0(``0*``0,``0.``0``@0"`@0$`@0&`@
M0(`@0*`@0,`@0.`@0`!`0"!`0$!`0&!`0(!`0*!`0,!`0.!`0`!@0"!@0$!@
M0&!@0(!@0*!@0,!@0.!@0`"`0""`0$"`0&"`0("`0*"`0,"`0."`0`"@0""@
M0$"@0&"@0("@0*"@0,"@0."@0`#`0"#`0$#`0&#`0(#`0*#`0,#`0.#`0`#@
M0"#@0$#@0&#@0(#@0*#@0,#@0.#@0```@"``@$``@&``@(``@*``@,``@.``
M@``@@"`@@$`@@&`@@(`@@*`@@,`@@.`@@`!`@"!`@$!`@&!`@(!`@*!`@,!`
M@.!`@`!@@"!@@$!@@&!@@(!@@*!@@,!@@.!@@`"`@""`@$"`@&"`@("`@*"`
M@,"`@."`@`"@@""@@$"@@&"@@("@@*"@@,"@@."@@`#`@"#`@$#`@&#`@(#`
M@*#`@,#`@.#`@`#@@"#@@$#@@&#@@(#@@*#@@,#@@.#@@```P"``P$``P&``
MP(``P*``P,``P.``P``@P"`@P$`@P&`@P(`@P*`@P,`@P.`@P`!`P"!`P$!`
MP&!`P(!`P*!`P,!`P.!`P`!@P"!@P$!@P&!@P(!@P*!@P,!@P.!@P`"`P""`
MP$"`P&"`P("`P*"`P,"`P."`P`"@P""@P$"@P&"@P("@P*"@P,"@P."@P`#`
MP"#`P$#`P&#`P(#`P*#`P/_[\*"@I("`@/\```#_`/__````__\`_P#_____
M_R'Y!`$``/T`+``````2`!(```AH`/L)'$BPH,&#"/L!6,BPH4,``@'\^R=Q
MXL2*%B$JO&B18T>-#T,RC'C1WS]_!$RB5`F2HTD")__!--F2(H&;.',2`,DP
MYDR9,6L"4)GR9%%_0G4J%4JTZ4FA/J/2C"@R9,*K6+-J#0@`.P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E
M<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N
M<R]I;6<O8V]L+6EN<V5R="UA9G1E<BYG:68````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#$U-R`Q,#4Q-30S-#$T,R`P,S,V-#$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````1TE&.#EA$@`2
M`,(``.&`@```@`#______P```/___________R'Y!`$```<`+``````2`!(`
M``,T>+K<_E"100FX),YZ089$*(I1>01F$ZRILKZM&R]H/'XF(0P"7DX[GV;7
M:P$'0A`Q.6L>$@`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET
M;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO;G,O:6UG+V-O;"UI
M;G-E<G0M8F5F;W)E+F=I9@``,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`Q-38@,3`U,34T,S0Q-#,@,#,T,#`Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$=)1C@Y81(`$@#"``````#A@(#_
M__\``(``______________\A^00!```'`"P`````$@`2```#,WBZW/[P@4"!
MN"#.>D6&0"B*SA`]0WHR:;NR;V/&Q_BM`"$0]VGI/8V.%_MYBL,@;1E+```[
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A
M+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]R;W<M<')O<"YG:68`````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C(U(#$P
M-3$U-#,T,30S(#`S,C(T-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!'248X.6$2`!(`H@<```"`X8"`P,#``#.9S,S,____
M````____(?D$`0``!P`L`````!(`$@```UIXNMSN)LH#P#M&Z&WJR]FF>0TH
MA)LG16>+=I8Q#"#M1H,ZX_M)[[$"H4`<%HE"@\(@1!J;125F15T1I(:`=LO=
M7I?=L/8[K5;)S*?:B86ZU5B"?$ZG8\WX0P(`.P``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+U1A
M8FQE3W!E<F%T:6]N<R]I;6<O8V]L+61E;&5T92YG:68````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$T-"`Q,#4Q-30S-#$T,R`P
M,S(T-S0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA$@`2`*$``````/____\``/___R'Y!`$```,`+``````2`!(`
M``(UG(^IRP8!GP@OIDJGP.!"&DS<!92`9I:-1#7(&7:N$[;S`&\WGNZ&X#L`
M?8)BD7@,#H/,6P$`.P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU9VEN<R]486)L94]P97)A=&EO
M;G,O:6UG+V-E;&PM<')O<"YG:68`````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`R,S,@,3`U,34T,S0Q-#,@,#,R,S4S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81(`
M$@"B!P#A@(```(#`P,``,YG,S,S___\```#___\A^00!```'`"P`````$@`2
M```#8'BZW.XFRA/".T;H;>K+V:9Y#2B$FR=%9XMVEC$,(.U&@SKC^TGOL0*A
M0!P6B<(.1H@T,HM*`V$E)5BO4X6A8`!XMT>HENL%@)])[72%Q1K&SGCSO92'
MTYBV_DJG^JD'"0`[````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I
M=&]R+VAT;6QA<F5A+W!L=6=I;G,O5&%B;&5/<&5R871I;VYS+VEM9R]T86)L
M92UP<F]P+F=I9@```````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,C(Q(#$P-3$U-#,T,30S(#`S,C4R,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!'248X.6$2`!(`H@8```"`P,#`
M`#.9____S,S,````____````(?D$`0``!@`L`````!(`$@```U9HNMSN)4H#
MP#,EZ%WJR]FF>0T8A)LG16>+=E8A""#M1H(ZX_M)[[$!84`<%HG"@J(@1!J;
M126&0*U:K5+F<^O,0K_;['5<]7*/T278V5V2R=F5?&Y(```[````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E
M82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+7-P;&ET+F=I9@``
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,34W-R`Q
M,#4Q-30S-#$T,R`P,S(T,S(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````1TE&.#EA$@`2`.<``````(````"``("`````@(``
M@`"`@,#`P,#<P*;*\$`@`&`@`(`@`*`@`,`@`.`@``!``"!``$!``&!``(!`
M`*!``,!``.!```!@`"!@`$!@`&!@`(!@`*!@`,!@`.!@``"``""``$"``&"`
M`("``*"``,"``."```"@`""@`$"@`&"@`("@`*"@`,"@`."@``#``"#``$#`
M`&#``(#``*#``,#``.#```#@`"#@`$#@`&#@`(#@`*#@`,#@`.#@````0"``
M0$``0&``0(``0*``0,``0.``0``@0"`@0$`@0&`@0(`@0*`@0,`@0.`@0`!`
M0"!`0$!`0&!`0(!`0*!`0,!`0.!`0`!@0"!@0$!@0&!@0(!@0*!@0,!@0.!@
M0`"`0""`0$"`0&"`0("`0*"`0,"`0."`0`"@0""@0$"@0&"@0("@0*"@0,"@
M0."@0`#`0"#`0$#`0&#`0(#`0*#`0,#`0.#`0`#@0"#@0$#@0&#@0(#@0*#@
M0,#@0.#@0```@"``@$``@&``@(``@*``@,``@.``@``@@"`@@$`@@&`@@(`@
M@*`@@,`@@.`@@`!`@"!`@$!`@&!`@(!`@*!`@,!`@.!`@`!@@"!@@$!@@&!@
M@(!@@*!@@,!@@.!@@`"`@""`@$"`@&"`@("`@*"`@,"`@."`@`"@@""@@$"@
M@&"@@("@@*"@@,"@@."@@`#`@"#`@$#`@&#`@(#`@*#`@,#`@.#`@`#@@"#@
M@$#@@&#@@(#@@*#@@,#@@.#@@```P"``P$``P&``P(``P*``P,``P.``P``@
MP"`@P$`@P&`@P(`@P*`@P,`@P.`@P`!`P"!`P$!`P&!`P(!`P*!`P,!`P.!`
MP`!@P"!@P$!@P&!@P(!@P*!@P,!@P.!@P`"`P""`P$"`P&"`P("`P*"`P,"`
MP."`P`"@P""@P$"@P&"@P("@P*"@P,"@P."@P`#`P"#`P$#`P&#`P(#`P*#`
MP/_[\*"@I("`@/\```#_`/__````__\`_P#______R'Y!`$``/T`+``````2
M`!(```A<`/L)'$BPH,&#"/L!6,BPH4,``@'\FSA1(L5_%B$JO(B18\:(#T,N
MC.CO7\F3)DU^W(BR94>,$0G(G$F3P$J)+E$V))DRY\V:0&_F['FSI]&2-T6&
M3,BTJ=.G`0$`.P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H
M=&UL87)E82]P;'5G:6YS+U1A8FQE3W!E<F%T:6]N<R]I;6<O<F]W+6EN<V5R
M="UU;F1E<BYG:68````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#$V,R`Q,#4Q-30S-#$T,R`P,S,W,#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````1TE&.#EA$@`2`,(```#__P``A.&`@/__
M_P```/___________R'Y!`$```<`+``````2`!(```,X>+K<_O"024E4(VM[
M];Z'EW%118%"JI*0NJ*NP#[F!$*!8D9!+@$#(*[7(P2#/!\!*.3I*K?H+0$`
M.P``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]#;VYT97AT365N=2]L86YG````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q-#,@,#(W,C,U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;'5G:6YS+T-O;G1E>'1-96YU+VUE;G4N8W-S````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,C0U-R`Q,#4Q-30S-#$T,R`P,S`P-C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RH@<W1Y;&5S(&9O<B!T:&4@
M0V]N=&5X=$UE;G4@+TA434Q!<F5A("HO"B\J(%1H92!#;VYT97AT365N=2!P
M;'5G:6X@:7,@*&,I(&1Y;F%R8V@N8V]M(#(P,#,N("HO"B\J($1I<W1R:6)U
M=&5D('5N9&5R('1H92!S86UE('1E<FUS(&%S($A434Q!<F5A(&ET<V5L9B`J
M+PH*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!["B`@<&]S:71I;VXZ(&%B
M<V]L=71E.PH@(&)O<F1E<CH@,7!X('-O;&ED("-A8V$X.3D["B`@<&%D9&EN
M9SH@,G!X.PH@(&)A8VMG<F]U;F0M8V]L;W(Z("-F9F8["B`@8V]L;W(Z(",P
M,#`["B`@8W5R<V]R.B!D969A=6QT.PH@('HM:6YD97@Z(#$P,#`["GT*"F1I
M=BYH=&UL87)E82UC;VYT97AT+6UE;G4@=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@
M=&%H;VUA+'9E<F1A;F$L<V%N<RUS97)I9CL*("!B;W)D97(M8V]L;&%P<V4Z
M(&-O;&QA<'-E.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R+FET
M96T@=&0N:6-O;B!I;6<@>PH@('=I9'1H.B`Q.'!X.PH@(&AE:6=H=#H@,3AP
M>#L*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYI=&5M('1D+FEC
M;VX@>PH@('!A9&1I;F<Z(#!P>"`S<'@["B`@:&5I9VAT.B`Q.'!X.PH@(&)A
M8VMG<F]U;F0M8V]L;W(Z("-C9&8["GT*"F1I=BYH=&UL87)E82UC;VYT97AT
M+6UE;G4@='(N:71E;2!T9"YL86)E;"!["B`@<&%D9&EN9SH@,7!X(#$P<'@@
M,7!X(#-P>#L*?0H*9&EV+FAT;6QA<F5A+6-O;G1E>'0M;65N=2!T<BYS97!A
M<F%T;W(@=&0@>PH@('!A9&1I;F<Z(#)P>"`P<'@["GT*"F1I=BYH=&UL87)E
M82UC;VYT97AT+6UE;G4@='(N<V5P87)A=&]R('1D(&1I=B!["B`@8F]R9&5R
M+71O<#H@,7!X('-O;&ED("-A8V$X.3D["B`@;W9E<F9L;W<Z(&AI9&1E;CL*
M("!P;W-I=&EO;CH@<F5L871I=F4["GT*"F1I=BYH=&UL87)E82UC;VYT97AT
M+6UE;G4@='(N<V5P87)A=&]R('1D+FEC;VX@>PH@(&)A8VMG<F]U;F0M8V]L
M;W(Z("-C9&8["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N<V5P
M87)A=&]R('1D+FEC;VX@9&EV('L*+RH@(&UA<F=I;BUL969T.B`S<'@[("HO
M"B`@8F]R9&5R+6-O;&]R.B`C9F9F.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X
M="UM96YU('1R+G-E<&%R871O<B!T9"YL86)E;"!D:78@>PH@(&UA<F=I;BUR
M:6=H=#H@,W!X.PI]"@ID:78N:'1M;&%R96$M8V]N=&5X="UM96YU('1R+FET
M96TN:&]V97(@>PH@(&)A8VMG<F]U;F0M8V]L;W(Z(",S,39A8S4["B`@8V]L
M;W(Z("-F9F8["GT*"F1I=BYH=&UL87)E82UC;VYT97AT+6UE;G4@='(N:71E
M;2YH;W9E<B!T9"YI8V]N('L*("!B86-K9W)O=6YD+6-O;&]R.B`C-C$Y868U
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O
M0V]N=&5X=$UE;G4O8V]N=&5X="UM96YU+FIS`````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,S-34V(#$P-3$U-#,T,30S
M(#`S,3,W,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````O+R!#;VYT97AT($UE;G4@4&QU9VEN(&9O<B!(5$U,07)E82TS+C`*
M+R\@4W!O;G-O<F5D(&)Y('=W=RYA;65R:6-A;F)I8FQE+F]R9PHO+R!);7!L
M96UE;G1A=&EO;B!B>2!-:6AA:2!"87IO;BP@:'1T<#HO+V1Y;F%R8V@N8V]M
M+VUI<VAO;R\*+R\*+R\@*&,I(&1Y;F%R8V@N8V]M(#(P,#,M,C`P-2X*+R\@
M1&ES=')I8G5T960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@2%1-3$%R96$@
M:71S96QF+@HO+R!4:&ES(&YO=&EC92!-55-4('-T87D@:6YT86-T(&9O<B!U
M<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O("1)9#H@8V]N=&5X="UM96YU
M+FIS+'8@,2XV(#(P,#4O,#$O,C`@,3<Z-#DZ,#,@;6ES:&]O($5X<"`D"@I(
M5$U,07)E82YL;V%D4W1Y;&4H(FUE;G4N8W-S(BP@(D-O;G1E>'1-96YU(BD[
M"@IF=6YC=&EO;B!#;VYT97AT365N=2AE9&ET;W(I('L*"71H:7,N961I=&]R
M(#T@961I=&]R.PI].PH*0V]N=&5X=$UE;G4N7W!L=6=I;DEN9F\@/2!["@EN
M86UE("`@("`@("`@(#H@(D-O;G1E>'1-96YU(BP*"79E<G-I;VX@("`@("`@
M.B`B,2XP(BP*"61E=F5L;W!E<B`@("`@.B`B36EH86D@0F%Z;VXB+`H)9&5V
M96QO<&5R7W5R;"`Z(")H='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O+R(L"@EC
M7V]W;F5R("`@("`@(#H@(F1Y;F%R8V@N8V]M(BP*"7-P;VYS;W(@("`@("`@
M.B`B06UE<FEC86X@0FEB;&4@4V]C:65T>2(L"@ES<&]N<V]R7W5R;"`@(#H@
M(FAT='`Z+R]W=W<N86UE<FEC86YB:6)L92YO<F<B+`H);&EC96YS92`@("`@
M("`Z(")H=&UL07)E82(*?3L*"D-O;G1E>'1-96YU+G!R;W1O='EP92YO;D=E
M;F5R871E(#T@9G5N8W1I;VXH*2!["@EV87(@<V5L9B`]('1H:7,["@EV87(@
M9&]C(#T@=&AI<RYE9&ET;W)D;V,@/2!T:&ES+F5D:71O<BY?:69R86UE+F-O
M;G1E;G17:6YD;W<N9&]C=6UE;G0["@E(5$U,07)E82Y?861D179E;G1S*&1O
M8RP@6R)C;VYT97AT;65N=2)=+`H)"0D@("`@9G5N8W1I;VX@*&5V96YT*2![
M"@D)"0D@("`@<F5T=7)N('-E;&8N<&]P=7!-96YU*$A434Q!<F5A+FES7VEE
M(#\@<V5L9BYE9&ET;W(N7VEF<F%M92YC;VYT96YT5VEN9&]W+F5V96YT(#H@
M979E;G0I.PH)"0D@("`@?2D["@ET:&ES+F-U<G)E;G1-96YU(#T@;G5L;#L*
M?3L*"D-O;G1E>'1-96YU+G!R;W1O='EP92YG971#;VYT97AT365N=2`](&9U
M;F-T:6]N*'1A<F=E="D@>PH)=F%R('-E;&8@/2!T:&ES.PH)=F%R(&5D:71O
M<B`]('1H:7,N961I=&]R.PH)=F%R(&-O;F9I9R`](&5D:71O<BYC;VYF:6<[
M"@EV87(@;65N=2`](%M=.PH)=F%R('1B;R`]('1H:7,N961I=&]R+G!L=6=I
M;G,N5&%B;&5/<&5R871I;VYS.PH):68@*'1B;RD@=&)O(#T@=&)O+FEN<W1A
M;F-E.PH)=F%R(&DQ.&X@/2!#;VYT97AT365N=2Y),3A..PH*"79A<B!S96QE
M8W1I;VX@/2!E9&ET;W(N:&%S4V5L96-T961497AT*"D["@EI9B`H<V5L96-T
M:6]N*0H)"6UE;G4N<'5S:"A;(&DQ.&Y;(D-U=")=+"!F=6YC=&EO;B@I('L@
M961I=&]R+F5X96-#;VUM86YD*")C=70B*3L@?2P@;G5L;"P@8V]N9FEG+F)T
M;DQI<W1;(F-U=")=6S%=(%TL"@D)"2`@6R!I,3AN6R)#;W!Y(ETL(&9U;F-T
M:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-O<'DB*3L@?2P@;G5L;"P@
M8V]N9FEG+F)T;DQI<W1;(F-O<'DB75LQ72!=*3L*"6UE;G4N<'5S:"A;(&DQ
M.&Y;(E!A<W1E(ETL(&9U;F-T:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H
M(G!A<W1E(BD[('TL(&YU;&PL(&-O;F9I9RYB=&Y,:7-T6R)P87-T92)=6S%=
M(%TI.PH*"79A<B!C=7)R96YT5&%R9V5T(#T@=&%R9V5T.PH)=F%R(&5L;65N
M=7,@/2!;73L*"79A<B!T;7`["@H)=F%R(&QI;FL@/2!N=6QL.PH)=F%R('1A
M8FQE(#T@;G5L;#L*"79A<B!T<B`](&YU;&P["@EV87(@=&0@/2!N=6QL.PH)
M=F%R(&EM9R`](&YU;&P["@H)9G5N8W1I;VX@=&%B;&5/<&5R871I;VXH;W!C
M;V1E*2!["@D)=&)O+F)U='1O;E!R97-S*&5D:71O<BP@;W!C;V1E*3L*"7T[
M"@H)9G5N8W1I;VX@:6YS97)T4&%R82AC=7)R96YT5&%R9V5T+"!A9G1E<BD@
M>PH)"79A<B!E;"`](&-U<G)E;G1487)G970["@D)=F%R('!A<B`](&5L+G!A
M<F5N=$YO9&4["@D)=F%R('`@/2!E9&ET;W(N7V1O8RYC<F5A=&5%;&5M96YT
M*")P(BD["@D)<"YA<'!E;F1#:&EL9"AE9&ET;W(N7V1O8RYC<F5A=&5%;&5M
M96YT*")B<B(I*3L*"0EP87(N:6YS97)T0F5F;W)E*'`L(&%F=&5R(#\@96PN
M;F5X=%-I8FQI;F<@.B!E;"D["@D)=F%R('-E;"`](&5D:71O<BY?9V5T4V5L
M96-T:6]N*"D["@D)=F%R(')A;F=E(#T@961I=&]R+E]C<F5A=&5286YG92AS
M96PI.PH)"6EF("@A2%1-3$%R96$N:7-?:64I('L*"0D)<V5L+G)E;6]V94%L
M;%)A;F=E<R@I.PH)"0ER86YG92YS96QE8W1.;V1E0V]N=&5N=',H<"D["@D)
M"7)A;F=E+F-O;&QA<'-E*'1R=64I.PH)"0ES96PN861D4F%N9V4H<F%N9V4I
M.PH)"7T@96QS92!["@D)"7)A;F=E+FUO=F54;T5L96UE;G1497AT*'`I.PH)
M"0ER86YG92YC;VQL87!S92AT<G5E*3L*"0D)<F%N9V4N<V5L96-T*"D["@D)
M?0H)?3L*"@EF;W(@*#L@=&%R9V5T.R!T87)G970@/2!T87)G970N<&%R96YT
M3F]D92D@>PH)"79A<B!T86<@/2!T87)G970N=&%G3F%M93L*"0EI9B`H(71A
M9RD*"0D)8V]N=&EN=64["@D)=&%G(#T@=&%G+G1O3&]W97)#87-E*"D["@D)
M<W=I=&-H("AT86<I('L*"0D@("`@8V%S92`B:6UG(CH*"0D):6UG(#T@=&%R
M9V5T.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN6R))
M;6%G92!0<F]P97)T:65S(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2!["@D)
M"0D)("`@("`@(&5D:71O<BY?:6YS97)T26UA9V4H:6UG*3L*"0D)"2`@("`@
M("!]+`H)"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G(ETL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FEN<V5R
M=&EM86=E(EU;,5T@70H)"0D)*3L*"0D)8G)E86L["@D)("`@(&-A<V4@(F$B
M.@H)"0EL:6YK(#T@=&%R9V5T.PH)"0EE;&UE;G5S+G!U<V@H;G5L;"P*"0D)
M"2`@("`@6R!I,3AN6R)-;V1I9GD@3&EN:R)=+`H)"0D)("`@("`@(&9U;F-T
M:6]N*"D@>R!E9&ET;W(N97AE8T-O;6UA;F0H(F-R96%T96QI;FLB+"!T<G5E
M*3L@?2P*"0D)"2`@("`@("!I,3AN6R)#=7)R96YT(%523"!I<R)=("L@)SH@
M)R`K(&QI;FLN:')E9BP*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES=%LB8W)E
M871E;&EN:R)=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(D-H96-K($QI;FLB
M72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L@=VEN9&]W+F]P96XH;&EN:RYH
M<F5F*3L@?2P*"0D)"2`@("`@("!I,3AN6R)/<&5N<R!T:&ES(&QI;FL@:6X@
M82!N97<@=VEN9&]W(ET@72P*"@D)"0D@("`@(%L@:3$X;ELB4F5M;W9E($QI
M;FLB72P*"0D)"2`@("`@("!F=6YC=&EO;B@I('L*"0D)"0D@("`@("`@:68@
M*&-O;F9I<FTH:3$X;ELB4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B)=("L@(EQN(B`K"@D)"0D)"0D@("!I
M,3AN6R),:6YK('!O:6YT<R!T;SHB72`K("(@(B`K(&QI;FLN:')E9BDI('L*
M"0D)"0D)("`@("`@('=H:6QE("AL:6YK+F9I<G-T0VAI;&0I"@D)"0D)"0D@
M("`@("`@;&EN:RYP87)E;G1.;V1E+FEN<V5R=$)E9F]R92AL:6YK+F9I<G-T
M0VAI;&0L(&QI;FLI.PH)"0D)"0D@("`@("`@;&EN:RYP87)E;G1.;V1E+G)E
M;6]V94-H:6QD*&QI;FLI.PH)"0D)"2`@("`@("!]"@D)"0D@("`@("`@?2P*
M"0D)"2`@("`@("!I,3AN6R)5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=")=
M(%T*"0D)"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")T9"(Z"@D)"71D(#T@
M=&%R9V5T.PH)"0EI9B`H(71B;RD@8G)E86L["@D)"65L;65N=7,N<'5S:"AN
M=6QL+`H)"0D)("`@("!;(&DQ.&Y;(D-E;&P@4')O<&5R=&EE<R)=+`H)"0D)
M("`@("`@(&9U;F-T:6]N*"D@>R!T86)L94]P97)A=&EO;B@B5$\M8V5L;"UP
M<F]P(BD[('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,
M:7-T6R)43RUC96QL+7!R;W`B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;(D1E
M;&5T92!#96QL(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E
M<F%T:6]N*")43RUC96QL+61E;&5T92(I.R!]+"!N=6QL+`H)"0D)("`@("`@
M(&-O;F9I9RYB=&Y,:7-T6R)43RUC96QL+61E;&5T92)=6S%=(%T*"0D)"2D[
M"@D)"6)R96%K.PH)"2`@("!C87-E(")T<B(Z"@D)"71R(#T@=&%R9V5T.PH)
M"0EI9B`H(71B;RD@8G)E86L["@D)"65L;65N=7,N<'5S:"AN=6QL+`H)"0D)
M("`@("!;(&DQ.&Y;(E)O=R!0<F]P97)T:65S(ETL"@D)"0D@("`@("`@9G5N
M8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUR;W<M<')O<"(I.R!]+`H)
M"0D)("`@("`@(&DQ.&Y;(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,:7-T6R)43RUR;W<M
M<')O<")=6S%=(%TL"@H)"0D)("`@("!;(&DQ.&Y;(DEN<V5R="!2;W<@0F5F
M;W)E(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N
M*")43RUR;W<M:6YS97)T+6%B;W9E(BD[('TL"@D)"0D@("`@("`@:3$X;ELB
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(ETL"@D)
M"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUI;G-E<G0M86)O=F4B
M75LQ72!=+`H*"0D)"2`@("`@6R!I,3AN6R));G-E<G0@4F]W($%F=&5R(ETL
M"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUR
M;W<M:6YS97)T+75N9&5R(BD[('TL"@D)"0D@("`@("`@:3$X;ELB26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B72P*"0D)"2`@("`@
M("!C;VYF:6<N8G1N3&ES=%LB5$\M<F]W+6EN<V5R="UU;F1E<B)=6S%=(%TL
M"@H)"0D)("`@("!;(&DQ.&Y;(D1E;&5T92!2;W<B72P*"0D)"2`@("`@("!F
M=6YC=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+7)O=RUD96QE=&4B*3L@
M?2P*"0D)"2`@("`@("!I,3AN6R)$96QE=&4@=&AE(&-U<G)E;G0@<F]W(ETL
M"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(E1/+7)O=RUD96QE=&4B75LQ
M72!="@D)"0DI.PH)"0EB<F5A:SL*"0D@("`@8V%S92`B=&%B;&4B.@H)"0ET
M86)L92`]('1A<F=E=#L*"0D):68@*"%T8F\I(&)R96%K.PH)"0EE;&UE;G5S
M+G!U<V@H;G5L;"P*"0D)"2`@("`@6R!I,3AN6R)486)L92!0<F]P97)T:65S
M(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![('1A8FQE3W!E<F%T:6]N*")4
M3RUT86)L92UP<F]P(BD[('TL"@D)"0D@("`@("`@:3$X;ELB4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B72P*"0D)"2`@("`@("!C;VYF:6<N
M8G1N3&ES=%LB5$\M=&%B;&4M<')O<")=6S%=(%TL"@H)"0D)("`@("!;(&DQ
M.&Y;(DEN<V5R="!#;VQU;6X@0F5F;W)E(ETL"@D)"0D@("`@("`@9G5N8W1I
M;VXH*2![('1A8FQE3W!E<F%T:6]N*")43RUC;VPM:6YS97)T+6)E9F]R92(I
M.R!]+`H)"0D)("`@("`@(&DQ.&Y;(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F
M;W)E('1H92!C=7)R96YT(&]N92)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,
M:7-T6R)43RUC;VPM:6YS97)T+6)E9F]R92)=6S%=(%TL"@H)"0D)("`@("!;
M(&DQ.&Y;(DEN<V5R="!#;VQU;6X@069T97(B72P*"0D)"2`@("`@("!F=6YC
M=&EO;B@I('L@=&%B;&5/<&5R871I;VXH(E1/+6-O;"UI;G-E<G0M869T97(B
M*3L@?2P*"0D)"2`@("`@("!I,3AN6R));G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N92)=+`H)"0D)("`@("`@(&-O;F9I9RYB=&Y,
M:7-T6R)43RUC;VPM:6YS97)T+6%F=&5R(EU;,5T@72P*"@D)"0D@("`@(%L@
M:3$X;ELB1&5L971E($-O;'5M;B)=+`H)"0D)("`@("`@(&9U;F-T:6]N*"D@
M>R!T86)L94]P97)A=&EO;B@B5$\M8V]L+61E;&5T92(I.R!]+`H)"0D)("`@
M("`@(&DQ.&Y;(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB72P*"0D)"2`@
M("`@("!C;VYF:6<N8G1N3&ES=%LB5$\M8V]L+61E;&5T92)=6S%=(%T*"0D)
M"2D["@D)"6)R96%K.PH)"2`@("!C87-E(")B;V1Y(CH*"0D)96QM96YU<RYP
M=7-H*&YU;&PL"@D)"0D@("`@(%L@:3$X;ELB2G5S=&EF>2!,969T(ETL"@D)
M"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B:G5S
M=&EF>6QE9G0B*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N8G1N3&ES
M=%LB:G5S=&EF>6QE9G0B75LQ72!=+`H)"0D)("`@("!;(&DQ.&Y;(DIU<W1I
M9GD@0V5N=&5R(ETL"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE
M>&5C0V]M;6%N9"@B:G5S=&EF>6-E;G1E<B(I.R!]+"!N=6QL+`H)"0D)("`@
M("`@(&-O;F9I9RYB=&Y,:7-T6R)J=7-T:69Y8V5N=&5R(EU;,5T@72P*"0D)
M"2`@("`@6R!I,3AN6R)*=7-T:69Y(%)I9VAT(ETL"@D)"0D@("`@("`@9G5N
M8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B:G5S=&EF>7)I9VAT(BD[
M('TL(&YU;&PL"@D)"0D@("`@("`@8V]N9FEG+F)T;DQI<W1;(FIU<W1I9GER
M:6=H=")=6S%=(%TL"@D)"0D@("`@(%L@:3$X;ELB2G5S=&EF>2!&=6QL(ETL
M"@D)"0D@("`@("`@9G5N8W1I;VXH*2![(&5D:71O<BYE>&5C0V]M;6%N9"@B
M:G5S=&EF>69U;&PB*3L@?2P@;G5L;"P*"0D)"2`@("`@("!C;VYF:6<N8G1N
M3&ES=%LB:G5S=&EF>69U;&PB75LQ72!="@D)"0DI.PH)"0EB<F5A:SL*"0E]
M"@E]"@H):68@*'-E;&5C=&EO;B`F)B`A;&EN:RD*"0EM96YU+G!U<V@H;G5L
M;"P@6R!I,3AN6R)-86ME(&QI;FLB72P*"0D)"2`@9G5N8W1I;VXH*2![(&5D
M:71O<BYE>&5C0V]M;6%N9"@B8W)E871E;&EN:R(L('1R=64I.R!]+`H)"0D)
M("!I,3AN6R)#<F5A=&4@82!L:6YK(ETL"@D)"0D@(&-O;F9I9RYB=&Y,:7-T
M6R)C<F5A=&5L:6YK(EU;,5T@72D["@H)9F]R("AV87(@:2`](#`[(&D@/"!E
M;&UE;G5S+FQE;F=T:#L@*RMI*0H)"6UE;G4N<'5S:"AE;&UE;G5S6VE=*3L*
M"@EI9B`H(2]H=&UL?&)O9'DO:2YT97-T*&-U<G)E;G1487)G970N=&%G3F%M
M92DI('L*"0ET86)L92`_("AT;7`@/2!T86)L92P@=&%B;&4@/2!N=6QL*2`Z
M("AT;7`@/2!C=7)R96YT5&%R9V5T*3L*"0EM96YU+G!U<V@H;G5L;"P*"0D)
M("!;(&DQ.&Y;(E)E;6]V92!T:&4B72`K("(@)FQT.R(@*R!T;7`N=&%G3F%M
M92`K("(F9W0[("(@*R!I,3AN6R)%;&5M96YT(ETL"@D)"2`@("!F=6YC=&EO
M;B@I('L*"0D)"2`@("!I9B`H8V]N9FER;2AI,3AN6R)0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(ET@*R`B
M("(@*PH)"0D)"0ET;7`N=&%G3F%M92DI('L*"0D)"0D@("`@=F%R(&5L(#T@
M=&UP.PH)"0D)"2`@("!V87(@<"`](&5L+G!A<F5N=$YO9&4["@D)"0D)("`@
M('`N<F5M;W9E0VAI;&0H96PI.PH)"0D)"2`@("!I9B`H2%1-3$%R96$N:7-?
M9V5C:V\I('L*"0D)"0D)("`@(&EF("AP+G1A9TYA;64N=&],;W=E<D-A<V4H
M*2`]/2`B=&0B("8F("%P+FAA<T-H:6QD3F]D97,H*2D*"0D)"0D)"2`@("!P
M+F%P<&5N9$-H:6QD*&5D:71O<BY?9&]C+F-R96%T945L96UE;G0H(F)R(BDI
M.PH)"0D)"0D@("`@961I=&]R+F9O<F-E4F5D<F%W*"D["@D)"0D)"2`@("!E
M9&ET;W(N9F]C=7-%9&ET;W(H*3L*"0D)"0D)("`@(&5D:71O<BYU<&1A=&54
M;V]L8F%R*"D["@D)"0D)"2`@("!I9B`H=&%B;&4I('L*"0D)"0D)"2`@("!V
M87(@<V%V95]C;VQL87!S92`]('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E
M.PH)"0D)"0D)("`@('1A8FQE+G-T>6QE+F)O<F1E<D-O;&QA<'-E(#T@(F-O
M;&QA<'-E(CL*"0D)"0D)"2`@("!T86)L92YS='EL92YB;W)D97)#;VQL87!S
M92`](")S97!A<F%T92(["@D)"0D)"0D@("`@=&%B;&4N<W1Y;&4N8F]R9&5R
M0V]L;&%P<V4@/2!S879E7V-O;&QA<'-E.PH)"0D)"0D@("`@?0H)"0D)"2`@
M("!]"@D)"0D@("`@?0H)"0D@("`@?2P*"0D)("`@(&DQ.&Y;(E)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B72!=+`H)"0D@(%L@:3$X;ELB
M26YS97)T('!A<F%G<F%P:"!B969O<F4B72P*"0D)("`@(&9U;F-T:6]N*"D@
M>R!I;G-E<G1087)A*'1M<"P@9F%L<V4I.R!]+`H)"0D@("`@:3$X;ELB26YS
M97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(ET@72P*
M"0D)("!;(&DQ.&Y;(DEN<V5R="!P87)A9W)A<&@@869T97(B72P*"0D)("`@
M(&9U;F-T:6]N*"D@>R!I;G-E<G1087)A*'1M<"P@=')U92D[('TL"@D)"2`@
M("!I,3AN6R));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D92)=(%T*"0D)*3L*"7T*"7)E='5R;B!M96YU.PI].PH*0V]N=&5X=$UE
M;G4N<')O=&]T>7!E+G!O<'5P365N=2`](&9U;F-T:6]N*&5V*2!["@EV87(@
M<V5L9B`]('1H:7,["@EV87(@:3$X;B`]($-O;G1E>'1-96YU+DDQ.$X["@EI
M9B`H=&AI<RYC=7)R96YT365N=2D*"0ET:&ES+F-U<G)E;G1-96YU+G!A<F5N
M=$YO9&4N<F5M;W9E0VAI;&0H=&AI<RYC=7)R96YT365N=2D["@EF=6YC=&EO
M;B!G9710;W,H96PI('L*"0EV87(@<B`]('L@>#H@96PN;V9F<V5T3&5F="P@
M>3H@96PN;V9F<V5T5&]P('T["@D):68@*&5L+F]F9G-E=%!A<F5N="D@>PH)
M"0EV87(@=&UP(#T@9V5T4&]S*&5L+F]F9G-E=%!A<F5N="D["@D)"7(N>"`K
M/2!T;7`N>#L*"0D)<BYY("L]('1M<"YY.PH)"7T*"0ER971U<FX@<CL*"7T[
M"@EF=6YC=&EO;B!D;V-U;65N=$-L:6-K*&5V*2!["@D)978@?'P@*&5V(#T@
M=VEN9&]W+F5V96YT*3L*"0EI9B`H(7-E;&8N8W5R<F5N=$UE;G4I('L*"0D)
M86QE<G0H:3$X;ELB2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P
M;W)T(2DB72D["@D)"7)E='5R;B!F86QS93L*"0E]"@D)=F%R(&5L(#T@2%1-
M3$%R96$N:7-?:64@/R!E=BYS<F-%;&5M96YT(#H@978N=&%R9V5T.PH)"69O
M<B`H.R!E;"`A/2!N=6QL("8F(&5L("$]('-E;&8N8W5R<F5N=$UE;G4[(&5L
M(#T@96PN<&%R96YT3F]D92D["@D):68@*&5L(#T](&YU;&PI"@D)"7-E;&8N
M8VQO<V5-96YU*"D["@D)+R](5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0DO
M+W)E='5R;B!F86QS93L*"7T["@EV87(@:V5Y<R`](%M=.PH)9G5N8W1I;VX@
M:V5Y4')E<W,H978I('L*"0EE=B!\?"`H978@/2!W:6YD;W<N979E;G0I.PH)
M"4A434Q!<F5A+E]S=&]P179E;G0H978I.PH)"6EF("AE=BYK97E#;V1E(#T]
M(#(W*2!["@D)"7-E;&8N8VQO<V5-96YU*"D["@D)"7)E='5R;B!F86QS93L*
M"0E]"@D)=F%R(&ME>2`](%-T<FEN9RYF<F]M0VAA<D-O9&4H2%1-3$%R96$N
M:7-?:64@/R!E=BYK97E#;V1E(#H@978N8VAA<D-O9&4I+G1O3&]W97)#87-E
M*"D["@D)9F]R("AV87(@:2`](&ME>7,N;&5N9W1H.R`M+6D@/CT@,#LI('L*
M"0D)=F%R(&L@/2!K97ES6VE=.PH)"0EI9B`H:ULP72YT;TQO=V5R0V%S92@I
M(#T](&ME>2D*"0D)"6M;,5TN7U]M<V@N86-T:79A=&4H*3L*"0E]"@E].PH)
M<V5L9BYC;&]S94UE;G4@/2!F=6YC=&EO;B@I('L*"0ES96QF+F-U<G)E;G1-
M96YU+G!A<F5N=$YO9&4N<F5M;W9E0VAI;&0H<V5L9BYC=7)R96YT365N=2D[
M"@D)<V5L9BYC=7)R96YT365N=2`](&YU;&P["@D)2%1-3$%R96$N7W)E;6]V
M945V96YT*&1O8W5M96YT+"`B;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD[
M"@D)2%1-3$%R96$N7W)E;6]V945V96YT*'-E;&8N961I=&]R9&]C+"`B;6]U
M<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD["@D):68@*&ME>7,N;&5N9W1H(#X@
M,"D*"0D)2%1-3$%R96$N7W)E;6]V945V96YT*'-E;&8N961I=&]R9&]C+"`B
M:V5Y<')E<W,B+"!K97E0<F5S<RD["@D):68@*$A434Q!<F5A+FES7VEE*0H)
M"0ES96QF+FEE4&]P=7`N:&ED92@I.PH)?3L*"79A<B!T87)G970@/2!(5$U,
M07)E82YI<U]I92`_(&5V+G-R8T5L96UE;G0@.B!E=BYT87)G970["@EV87(@
M:69P;W,@/2!G9710;W,H<V5L9BYE9&ET;W(N7VEF<F%M92D["@EV87(@>"`]
M(&5V+F-L:65N=%@@*R!I9G!O<RYX.PH)=F%R('D@/2!E=BYC;&EE;G19("L@
M:69P;W,N>3L*"@EV87(@9&EV.PH)=F%R(&1O8SL*"6EF("@A2%1-3$%R96$N
M:7-?:64I('L*"0ED;V,@/2!D;V-U;65N=#L*"7T@96QS92!["@D)+R\@244@
M<W1I;FMS"@D)=F%R('!O<'5P(#T@=&AI<RYI95!O<'5P(#T@=VEN9&]W+F-R
M96%T95!O<'5P*"D["@D)9&]C(#T@<&]P=7`N9&]C=6UE;G0["@D)9&]C+F]P
M96XH*3L*"0ED;V,N=W)I=&4H(CQH=&UL/CQH96%D/CQS='EL92!T>7!E/2=T
M97AT+V-S<R<^0&EM<&]R="!U<FPH(B`K(%]E9&ET;W)?=7)L("L@(G!L=6=I
M;G,O0V]N=&5X=$UE;G4O;65N=2YC<W,I.R!H=&UL+"!B;V1Y('L@<&%D9&EN
M9SH@,'!X.R!M87)G:6XZ(#!P>#L@;W9E<F9L;W<Z(&AI9&1E;CL@8F]R9&5R
M.B`P<'@[('T\+W-T>6QE/CPO:&5A9#X\8F]D>2!U;G-E;&5C=&%B;&4])WEE
M<R<^/"]B;V1Y/CPO:'1M;#XB*3L*"0ED;V,N8VQO<V4H*3L*"7T*"61I=B`]
M(&1O8RYC<F5A=&5%;&5M96YT*")D:78B*3L*"6EF("A(5$U,07)E82YI<U]I
M92D*"0ED:78N=6YS96QE8W1A8FQE(#T@(F]N(CL*"61I=BYO;F-O;G1E>'1M
M96YU(#T@9G5N8W1I;VXH*2![(')E='5R;B!F86QS93L@?3L*"61I=BYC;&%S
M<TYA;64@/2`B:'1M;&%R96$M8V]N=&5X="UM96YU(CL*"6EF("@A2%1-3$%R
M96$N:7-?:64I"@D)9&EV+G-T>6QE+FQE9G0@/2!D:78N<W1Y;&4N=&]P(#T@
M(C!P>"(["@ED;V,N8F]D>2YA<'!E;F1#:&EL9"AD:78I.PH*"79A<B!T86)L
M92`](&1O8RYC<F5A=&5%;&5M96YT*")T86)L92(I.PH)9&EV+F%P<&5N9$-H
M:6QD*'1A8FQE*3L*"71A8FQE+F-E;&Q3<&%C:6YG(#T@,#L*"71A8FQE+F-E
M;&Q0861D:6YG(#T@,#L*"79A<B!P87)E;G0@/2!D;V,N8W)E871E16QE;65N
M="@B=&)O9'DB*3L*"71A8FQE+F%P<&5N9$-H:6QD*'!A<F5N="D["@H)=F%R
M(&]P=&EO;G,@/2!T:&ES+F=E=$-O;G1E>'1-96YU*'1A<F=E="D["@EF;W(@
M*'9A<B!I(#T@,#L@:2`\(&]P=&EO;G,N;&5N9W1H.R`K*VDI('L*"0EV87(@
M;W!T:6]N(#T@;W!T:6]N<UMI73L*"0EV87(@:71E;2`](&1O8RYC<F5A=&5%
M;&5M96YT*")T<B(I.PH)"7!A<F5N="YA<'!E;F1#:&EL9"AI=&5M*3L*"0EI
M9B`H2%1-3$%R96$N:7-?:64I"@D)"6ET96TN=6YS96QE8W1A8FQE(#T@(F]N
M(CL*"0EE;'-E(&ET96TN;VYM;W5S961O=VX@/2!F=6YC=&EO;BAE=BD@>PH)
M"0E(5$U,07)E82Y?<W1O<$5V96YT*&5V*3L*"0D)<F5T=7)N(&9A;'-E.PH)
M"7T["@D):68@*"%O<'1I;VXI('L*"0D):71E;2YC;&%S<TYA;64@/2`B<V5P
M87)A=&]R(CL*"0D)=F%R('1D(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD[
M"@D)"71D+F-L87-S3F%M92`](")I8V]N(CL*"0D)=F%R($E%7TE37T%?1E5#
M2TE.1U]32$E4(#T@)SXG.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I('L*"0D)
M"71D+G5N<V5L96-T86)L92`](")O;B(["@D)"0E)15])4U]!7T950TM)3D=?
M4TA)5"`]("(@=6YS96QE8W1A8FQE/2=O;B<@<W1Y;&4])VAE:6=H=#TQ<'@G
M/B9N8G-P.R(["@D)"7T*"0D)=&0N:6YN97)(5$U,(#T@(CQD:78B("L@245?
M25-?05]&54-+24Y'7U-(250@*R`B/"]D:78^(CL*"0D)=F%R('1D,2`]('1D
M+F-L;VYE3F]D92AT<G5E*3L*"0D)=&0Q+F-L87-S3F%M92`](")L86)E;"([
M"@D)"6ET96TN87!P96YD0VAI;&0H=&0I.PH)"0EI=&5M+F%P<&5N9$-H:6QD
M*'1D,2D["@D)?2!E;'-E('L*"0D)=F%R(&QA8F5L(#T@;W!T:6]N6S!=.PH)
M"0EI=&5M+F-L87-S3F%M92`](")I=&5M(CL*"0D):71E;2Y?7VUS:"`]('L*
M"0D)"6ET96TZ(&ET96TL"@D)"0EL86)E;#H@;&%B96PL"@D)"0EA8W1I;VXZ
M(&]P=&EO;ELQ72P*"0D)"71O;VQT:7`Z(&]P=&EO;ELR72!\?"!N=6QL+`H)
M"0D):6-O;CH@;W!T:6]N6S-=('Q\(&YU;&PL"@D)"0EA8W1I=F%T93H@9G5N
M8W1I;VXH*2!["@D)"0D)<V5L9BYC;&]S94UE;G4H*3L*"0D)"0ES96QF+F5D
M:71O<BYF;V-U<T5D:71O<B@I.PH)"0D)"71H:7,N86-T:6]N*"D["@D)"0E]
M"@D)"7T["@D)"6QA8F5L(#T@;&%B96PN<F5P;&%C92@O7RA;82UZ02U:,"TY
M72DO+"`B/'4^)#$\+W4^(BD["@D)"6EF("AL86)E;"`A/2!O<'1I;VY;,%TI
M"@D)"0EK97ES+G!U<V@H6R!296=%>'`N)#$L(&ET96T@72D["@D)"6QA8F5L
M(#T@;&%B96PN<F5P;&%C92@O7U\O+"`B7R(I.PH)"0EV87(@=&0Q(#T@9&]C
M+F-R96%T945L96UE;G0H(G1D(BD["@D)"6EF("A(5$U,07)E82YI<U]I92D*
M"0D)"71D,2YU;G-E;&5C=&%B;&4@/2`B;VXB.PH)"0EI=&5M+F%P<&5N9$-H
M:6QD*'1D,2D["@D)"71D,2YC;&%S<TYA;64@/2`B:6-O;B(["@D)"6EF("AI
M=&5M+E]?;7-H+FEC;VXI"@D)"0ET9#$N:6YN97)(5$U,(#T@(CQI;6<@86QI
M9VX])VUI9&1L92<@<W)C/2<B("L@:71E;2Y?7VUS:"YI8V]N("L@(B<@+SXB
M.PH)"0EV87(@=&0R(#T@9&]C+F-R96%T945L96UE;G0H(G1D(BD["@D)"6EF
M("A(5$U,07)E82YI<U]I92D*"0D)"71D,BYU;G-E;&5C=&%B;&4@/2`B;VXB
M.PH)"0EI=&5M+F%P<&5N9$-H:6QD*'1D,BD["@D)"71D,BYC;&%S<TYA;64@
M/2`B;&%B96PB.PH)"0ET9#(N:6YN97)(5$U,(#T@;&%B96P["@D)"6ET96TN
M;VYM;W5S96]V97(@/2!F=6YC=&EO;B@I('L*"0D)"71H:7,N8VQA<W-.86UE
M("L]("(@:&]V97(B.PH)"0D)<V5L9BYE9&ET;W(N7W-T871U<T)A<E1R964N
M:6YN97)(5$U,(#T@=&AI<RY?7VUS:"YT;V]L=&EP('Q\("<F;F)S<#LG.PH)
M"0E].PH)"0EI=&5M+F]N;6]U<V5O=70@/2!F=6YC=&EO;B@I('L@=&AI<RYC
M;&%S<TYA;64@/2`B:71E;2([('T["@D)"6ET96TN;VYC;VYT97AT;65N=2`]
M(&9U;F-T:6]N*&5V*2!["@D)"0ET:&ES+E]?;7-H+F%C=&EV871E*"D["@D)
M"0EI9B`H(4A434Q!<F5A+FES7VEE*0H)"0D)"4A434Q!<F5A+E]S=&]P179E
M;G0H978I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0EI=&5M+F]N;6]U
M<V5U<"`](&9U;F-T:6]N*&5V*2!["@D)"0EV87(@=&EM95-T86UP(#T@*&YE
M=R!$871E*"DI+F=E=%1I;64H*3L*"0D)"6EF("AT:6UE4W1A;7`@+2!S96QF
M+G1I;653=&%M<"`^(#4P,"D*"0D)"0ET:&ES+E]?;7-H+F%C=&EV871E*"D[
M"@D)"0EI9B`H(4A434Q!<F5A+FES7VEE*0H)"0D)"4A434Q!<F5A+E]S=&]P
M179E;G0H978I.PH)"0D)<F5T=7)N(&9A;'-E.PH)"0E].PH)"0DO+VEF("AT
M>7!E;V8@;W!T:6]N6S)=(#T](")S=')I;F<B*0H)"0DO+VET96TN=&ET;&4@
M/2!O<'1I;VY;,ET["@D)?0H)?0H*"6EF("@A2%1-3$%R96$N:7-?:64I('L*
M"0EV87(@9'@@/2!X("L@9&EV+F]F9G-E=%=I9'1H("T@=VEN9&]W+FEN;F5R
M5VED=&@@*R`T.PH)"79A<B!D>2`]('D@*R!D:78N;V9F<V5T2&5I9VAT("T@
M=VEN9&]W+FEN;F5R2&5I9VAT("L@-#L*"0EI9B`H9'@@/B`P*2!X("T](&1X
M.PH)"6EF("AD>2`^(#`I('D@+3T@9'D["@D)9&EV+G-T>6QE+FQE9G0@/2!X
M("L@(G!X(CL*"0ED:78N<W1Y;&4N=&]P(#T@>2`K(")P>"(["@E](&5L<V4@
M>PH)"2\O(&1E=&5R;6EN92!T:&4@<VEZ92`H9&ED($D@;65N=&EO;B!T:&%T
M($E%('-T:6YK<S\I"@D)=F%R(&9O;V)A<B`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H(F1I=B(I.PH)"69O;V)A<BYC;&%S<TYA;64@/2`B:'1M;&%R96$M
M8V]N=&5X="UM96YU(CL*"0EF;V]B87(N:6YN97)(5$U,(#T@9&EV+FEN;F5R
M2%1-3#L*"0ED;V-U;65N="YB;V1Y+F%P<&5N9$-H:6QD*&9O;V)A<BD["@D)
M=F%R('<@/2!F;V]B87(N;V9F<V5T5VED=&@["@D)=F%R(&@@/2!F;V]B87(N
M;V9F<V5T2&5I9VAT.PH)"61O8W5M96YT+F)O9'DN<F5M;W9E0VAI;&0H9F]O
M8F%R*3L*"0ET:&ES+FEE4&]P=7`N<VAO=RAE=BYS8W)E96Y8+"!E=BYS8W)E
M96Y9+"!W+"!H*3L*"7T*"@ET:&ES+F-U<G)E;G1-96YU(#T@9&EV.PH)=&AI
M<RYT:6UE4W1A;7`@/2`H;F5W($1A=&4H*2DN9V5T5&EM92@I.PH*"4A434Q!
M<F5A+E]A9&1%=F5N="AD;V-U;65N="P@(FUO=7-E9&]W;B(L(&1O8W5M96YT
M0VQI8VLI.PH)2%1-3$%R96$N7V%D9$5V96YT*'1H:7,N961I=&]R9&]C+"`B
M;6]U<V5D;W=N(BP@9&]C=6UE;G1#;&EC:RD["@EI9B`H:V5Y<RYL96YG=&@@
M/B`P*0H)"4A434Q!<F5A+E]A9&1%=F5N="AT:&ES+F5D:71O<F1O8RP@(FME
M>7!R97-S(BP@:V5Y4')E<W,I.PH*"4A434Q!<F5A+E]S=&]P179E;G0H978I
M.PH)<F5T=7)N(&9A;'-E.PI].PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]P;'5G:6YS+T-O
M;G1E>'1-96YU+VQA;F<O96XN:G,````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,3(W-2`Q,#4Q-30S-#$T,R`P
M,S`R-C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+R\@23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'
M.B!55$8M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@
M:'1T<#HO+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3
M.@HO+PHO+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@
M5$A%($%"3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I
M;"!A9&1R97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX
M($9/4B!%3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB
M;&4L('!L96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T
M871E<R!W:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I#;VYT97AT365N
M=2Y),3A.(#T@>PH)+R\@271E;7,@=&AA="!A<'!E87(@:6X@;65N=2X@(%!L
M96%S92!N;W1E('1H870@86X@=6YD97)S8V]R92`H7RD*"2\O(&-H87)A8W1E
M<B!I;B!T:&4@=')A;G-L871I;VX@*')I9VAT(&-O;'5M;BD@=VEL;"!C875S
M92!T:&4@9F]L;&]W:6YG"@DO+R!L971T97(@=&\@8F5C;VUE('5N9&5R;&EN
M960@86YD(&)E('-H;W)T8W5T(&9O<B!T:&%T(&UE;G4@;W!T:6]N+@H*"2)#
M=70B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B0W5T(BP*"2)#;W!Y(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0V]P>2(L"@DB4&%S
M=&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(E!A<W1E(BP*"2));6%G92!0<F]P97)T:65S(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B7TEM86=E(%!R;W!E
M<G1I97,N+BXB+`H)(DUO9&EF>2!,:6YK(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")?36]D:69Y($QI;FLN+BXB+`H)
M(D-H96-K($QI;FLB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z(")#:&5C7VL@3&EN:RXN+B(L"@DB4F5M;W9E($QI;FLB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E]296UO=F4@3&EN:RXN+B(L"@DB0V5L;"!0<F]P97)T:65S(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-?96QL(%!R;W!E
M<G1I97,N+BXB+`H)(E)O=R!0<F]P97)T:65S(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")2;U]W(%!R;W!E<G1I97,N+BXB
M+`H)(DEN<V5R="!2;W<@0F5F;W)E(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("))7VYS97)T(%)O=R!"969O<F4B+`H)(DEN<V5R
M="!2;W<@069T97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("));E]S97)T(%)O=R!!9G1E<B(L"@DB1&5L971E(%)O=R(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E]$
M96QE=&4@4F]W(BP*"2)$96QE=&4@0V5L;"(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B1&5L971E($-E;&PB+`H)(E1A
M8FQE(%!R;W!E<G1I97,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")?5&%B;&4@4')O<&5R=&EE<RXN+B(L"@DB26YS97)T($-O
M;'5M;B!"969O<F4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(DEN<V5R="!?0V]L=6UN($)E9F]R92(L"@DB26YS97)T($-O;'5M;B!!
M9G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEN
M<V5R="!#7V]L=6UN($%F=&5R(BP*"2)$96QE=&4@0V]L=6UN(B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B1&5?;&5T92!#
M;VQU;6XB+`H)(DIU<W1I9GD@3&5F="(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")*=7-T:69Y($QE9G0B+`H)(DIU<W1I
M9GD@0V5N=&5R(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z(")*=7-T:69Y($-E;G1E<B(L"@DB2G5S=&EF>2!2:6=H="(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DIU<W1I
M9GD@4FEG:'0B+`H)(DIU<W1I9GD@1G5L;"(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")*=7-T:69Y($9U;&PB+`H)(DUA
M:V4@;&EN:R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")-86ME(&QI;E]K+BXN(BP*"2)296UO=F4@=&AE(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B4F5M
M;W9E('1H92(L"@DB16QE;65N="(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(D5L96UE;G0N+BXB+`H)(DEN<V5R
M="!P87)A9W)A<&@@8F5F;W)E(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("));G-E<G0@<&%R86=R87!H(&)E9F]R92(L"@DB26YS97)T('!A
M<F%G<F%P:"!A9G1E<B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(DEN<V5R="!P87)A9W)A<&@@869T97(B+`H*"2\O($]T:&5R(&QA8F5L
M<R`H=&]O;'1I<',@86YD(&%L97)T+V-O;F9I<FT@8F]X(&UE<W-A9V5S*0H*
M"2)0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES
M(&5L96UE;G0Z(B`@.B`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.B(L"@DB4F5M;W9E('1H:7,@;F]D92!F
M<F]M('1H92!D;V-U;65N="(@("`@("`@("`@("`@("`@("`@(#H@(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B+`H)(DAO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(B`@("`@("`@("`@("`@("`Z
M(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(L"@DB
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B("`@("`@("`@("`@
M("`@("`@("`@(#H@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M(BP*"2)-;V1I9GD@55),(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B36]D:69Y(%523"(L"@DB0W5R<F5N="!54DP@
M:7,B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(D-U<G)E;G0@55),(&ES(BP*"2)/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W(B`@("`@("`@("`@("`@("`@("`@("`@.B`B3W!E;G,@=&AI<R!L
M:6YK(&EN(&$@;F5W('=I;F1O=R(L"@DB4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(@(#H@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB
M+`H)(DQI;FL@<&]I;G1S('1O.B(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("),:6YK('!O:6YT<R!T;SHB+`H)(E5N;&EN:R!T
M:&4@8W5R<F5N="!E;&5M96YT(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(L"@DB4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(@("`@("`@("`@("`@("`@
M(#H@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B+`H)
M(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(@("`@("`@
M("`@("`@("`@("`Z(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B+`H)(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N92(@("`@("`@("`@("`@("`Z("));G-E<G0@82!N97<@<F]W(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B+`H)(DEN<V5R="!A(&YE=R!R;W<@869T97(@
M=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@("`@("`Z("));G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(L"@DB1&5L971E('1H92!C
M=7)R96YT(')O=R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B+`H)(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(B`@("`@("`@("`@("`@("`@("`@("`Z(")3:&]W
M('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(L"@DB26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(B`@("`@("`@("`@(#H@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(L
M"@DB26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B
M("`@("`@("`@("`@(#H@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(BP*"2)$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;B(L"@DB0W)E871E(&$@;&EN:R(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D-R96%T92!A(&QI;FLB+`H)
M(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(@
M("`@("`@("`@("`Z("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B+`H)(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E(B`@("`@("`@("`@("`Z("));G-E<G0@82!P87)A9W)A
M<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*?3L*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O<&QU
M9VEN<R]!;G-E;$EM86=E+VQA;F<`````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q-#,@,#(V-S<Q`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-E<G9I8V5S+V5D
M:71O<B]H=&UL87)E82]P;'5G:6YS+T%N<V5L26UA9V4O86YS96PM:6UA9V4N
M:G,````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-3$P,2`Q,#4Q-30S-#$T,R`P,S`V-#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+R\@06YS96P@26UA9V4@4&QU
M9VEN(&9O<B!(5$U,07)E82TS+C`*+R\@4&QU9VEN('1H870@86QL;W=S('1H
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@=&AE"B\O($AO<F1E(&9R86UE
M=V]R:R!M;V1U;&4@06YS96P@:6YT;R!A('1E>'0*+R\*+R\@36]D=6QE(')E
M=7-E<R!(5$U,07)E82!C;V1E"B\O"B\O($EM<&QE;65N=&%T:6]N.B!2;V5L
M($=L;W5D96UA;G,@/')O96Q`9VQO=61E;6%N<RYI;F9O/@HO+PHO+R`H8RD@
M,C`P-"X*+R\@1&ES=')I8G5T960@=6YD97(@=&AE('-A;64@=&5R;7,@87,@
M2%1-3$%R96$@:71S96QF+@HO+R!4:&ES(&YO=&EC92!-55-4('-T87D@:6YT
M86-T(&9O<B!U<V4@*'-E92!L:6-E;G-E+G1X="DN"B\O"B\O("1)9#H@86YS
M96PM:6UA9V4N:G,L=B`Q+C$@,C`P-"\P.2\P."`Q-CHP-CHQ,R!L86YC97(@
M17AP("0*"@IF=6YC=&EO;B!!;G-E;$EM86=E*&5D:71O<BD*>PH)=&AI<RYE
M9&ET;W(@/2!E9&ET;W(["@EV87(@:3$X;B`]($%N<V5L26UA9V4N23$X3CL*
M?3L*"@I!;G-E;$EM86=E+E]P;'5G:6Y);F9O(#T@>PH);F%M92`@("`@("`@
M("`Z(")!;G-E;$EM86=E(BP*"79E<G-I;VX@("`@("`@.B`B,2XP(BP*"61E
M=F5L;W!E<B`@("`@.B`B4F]E;"!';&]U9&5M86YS(BP*"61E=F5L;W!E<E]U
M<FP@.B`B:'1T<#HO+W=W=RYG;&]U9&5M86YS+FEN9F\O(BP*("`@("`@("!S
M<&]N<V]R("`@("`@(#H@(DAO<F1E(%!R;VIE8W0B+`H@("`@("`@('-P;VYS
M;W)?=7)L("`@.B`B:'1T<#HO+W=W=RYH;W)D92YO<F<O(BP*"6QI8V5N<V4@
M("`@("`@.B`B:'1M;$%R96$B"GT["@H*+R\@0V%L;&5D('=H96X@=&AE('5S
M97(@8VQI8VMS(&]N("));G-E<G1);6%G92(@8G5T=&]N+B`@268@86X@:6UA
M9V4@:7,@86QR96%D>0HO+R!T:&5R92P@:70@=VEL;"!J=7-T(&UO9&EF>2!I
M="=S('!R;W!E<G1I97,N"B\O(%1H:7,@9G5N8W1I;VX@;W9E<G)I9&5S('1H
M92!N871I=F4@2%1-3$%R96$@9G5N8W1I;VX*2%1-3$%R96$N<')O=&]T>7!E
M+E]I;G-E<G1);6%G92`](&9U;F-T:6]N*&EM86=E*2!["@EV87(@961I=&]R
M(#T@=&AI<SL)+R\@9F]R(&YE<W1E9"!F=6YC=&EO;G,*"79A<B!O=71P87)A
M;2`](&YU;&P["@H):68@*'1Y<&5O9B!I;6%G92`]/2`B=6YD969I;F5D(BD@
M>PH)"6EM86=E(#T@=&AI<RYG971087)E;G1%;&5M96YT*"D["@D):68@*&EM
M86=E("8F("$O7FEM9R0O:2YT97-T*&EM86=E+G1A9TYA;64I*0H)"0EI;6%G
M92`](&YU;&P["@E]"@EI9B`H:6UA9V4I(&]U='!A<F%M(#T@>PH)"69?8F%S
M92`@(#H@961I=&]R+F-O;F9I9RYB87-E55),+`H)"69?=7)L("`@(#H@2%1-
M3$%R96$N:7-?:64@/R!E9&ET;W(N<W1R:7!"87-E55),*&EM86=E+G-R8RD@
M.B!I;6%G92YG971!='1R:6)U=&4H(G-R8R(I+`H)"69?86QT("`@(#H@:6UA
M9V4N86QT+`H)"69?8F]R9&5R(#H@:6UA9V4N8F]R9&5R+`H)"69?86QI9VX@
M(#H@:6UA9V4N86QI9VXL"@D)9E]V97)T("`@.B!I;6%G92YV<W!A8V4L"@D)
M9E]H;W)I>B`@.B!I;6%G92YH<W!A8V4*"7T["@H@("`@=F%R(&UA;F%G97(@
M/2!?961I=&]R7W5R;"`K("=P;'5G:6YS+T%N<V5L26UA9V4O:6YS97)T7VEM
M86=E+G!H<"<["@H)1&EA;&]G*&UA;F%G97(L(&9U;F-T:6]N*'!A<F%M*2![
M"B\O"71H:7,N7W!O<'5P1&EA;&]G*&UA;F%G97(L(&9U;F-T:6]N*'!A<F%M
M*2!["@D):68@*"%P87)A;2D@>PDO+R!U<V5R(&UU<W0@:&%V92!P<F5S<V5D
M($-A;F-E;`H)"0ER971U<FX@9F%L<V4["@D)?0H)"79A<B!I;6<@/2!I;6%G
M93L*"0EI9B`H(6EM9RD@>PH)"0EV87(@<V5L(#T@961I=&]R+E]G971396QE
M8W1I;VXH*3L*"0D)=F%R(')A;F=E(#T@961I=&]R+E]C<F5A=&5286YG92AS
M96PI.PH)"0EE9&ET;W(N7V1O8RYE>&5C0V]M;6%N9"@B:6YS97)T:6UA9V4B
M+"!F86QS92P@<&%R86TN9E]U<FPI.PH)"0EI9B`H2%1-3$%R96$N:7-?:64I
M('L*"0D)"6EM9R`](')A;F=E+G!A<F5N=$5L96UE;G0H*3L*"0D)"2\O('=O
M;F1E<B!I9B!T:&ES('=O<FMS+BXN"@D)"0EI9B`H:6UG+G1A9TYA;64N=&],
M;W=E<D-A<V4H*2`A/2`B:6UG(BD@>PH)"0D)"6EM9R`](&EM9RYP<F5V:6]U
M<U-I8FQI;F<["@D)"0E]"@D)"7T@96QS92!["@D)"0EI;6<@/2!R86YG92YS
M=&%R=$-O;G1A:6YE<BYP<F5V:6]U<U-I8FQI;F<["@D)"7T*"0E](&5L<V4@
M>PH)"0EI;6<N<W)C(#T@<&%R86TN9E]U<FP["@D)?0H*"0EF;W(@*'9A<B!F
M:65L9"!I;B!P87)A;2D@>PH)"0EV87(@=F%L=64@/2!P87)A;5MF:65L9%T[
M"@D)"7-W:71C:"`H9FEE;&0I('L*"0D)("`@(&-A<V4@(F9?86QT(B`@("`Z
M(&EM9RYA;'0)(#T@=F%L=64[(&)R96%K.PH)"0D@("`@8V%S92`B9E]B;W)D
M97(B(#H@:6UG+F)O<F1E<B`]('!A<G-E26YT*'9A;'5E('Q\("(P(BD[(&)R
M96%K.PH)"0D@("`@8V%S92`B9E]A;&EG;B(@(#H@:6UG+F%L:6=N"2`]('9A
M;'5E.R!B<F5A:SL*"0D)("`@(&-A<V4@(F9?=F5R="(@("`Z(&EM9RYV<W!A
M8V4@/2!P87)S94EN="AV86QU92!\?"`B,"(I.R!B<F5A:SL*"0D)("`@(&-A
M<V4@(F9?:&]R:7HB("`Z(&EM9RYH<W!A8V4@/2!P87)S94EN="AV86QU92!\
M?"`B,"(I.R!B<F5A:SL*"0D)?0H)"7T*"7TL(&]U='!A<F%M*3L*?3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L
M=6=I;G,O06YS96Q);6%G92]I;G-E<G1?:6UA9V4N<&AP````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$V,S`U(#$P-3$U
M-#,T,30S(#`S,3,Q,P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V5R=FEC
M97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS96Q);6%G92]I;G-E<G1?
M:6UA9V4N<&AP+'8@,2XU+C8N-2`R,#`U+S$P+S$X(#$Q.C,T.C`R(&IA;B!%
M>'`@)`H@*B\*"B\O($-H96-K(&9O<B!A('!R:6]R(&1E9FEN:71I;VX@;V8@
M2$]21$5?0D%312`H<&5R:&%P<R!B>2!A;B!A=71O7W!R97!E;F1?9FEL90HO
M+R!D969I;FET:6]N(&9O<B!S:71E(&-U<W1O;6EZ871I;VXI+@II9B`H(61E
M9FEN960H)TA/4D1%7T)!4T4G*2D@>PH@("`@0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B\N+B\N+B\N+B<I.PI]
M"@HO+R!,;V%D('1H92!(;W)D92!&<F%M97=O<FL@8V]R92P@86YD('-E="!U
M<"!I;F-L=7-I;VX@<&%T:',N"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@
M)R]L:6(O8V]R92YP:'`G.PH*+R\@4F5G:7-T<GD*)')E9VES=')Y(#T@)E)E
M9VES=')Y.CIS:6YG;&5T;VXH*3L*"B\J($1E=&5R;6EN92!H;W<@=V4@=V5R
M92!C86QL960[('=I=&@@82!54DPL(&]R('=I=&@@82!G86QL97)Y(&ED("HO
M"B1G86QL97)Y;&ES="`]("1R96=I<W1R>2T^8V%L;"@G:6UA9V5S+VQI<W1'
M86QL97)I97,G+"!A<G)A>2AN=6QL*2D["B1G86QL97)Y7VED(#T@571I;#HZ
M9V5T1F]R;41A=&$H)V=A;&QE<GDG+"!K97DH)&=A;&QE<GEL:7-T*2D["B1I
M;6%G96QI<W0@/2`D<F5G:7-T<GDM/F-A;&PH)VEM86=E<R]L:7-T26UA9V5S
M)RP@87)R87DH;G5L;"P@)&=A;&QE<GE?:60L(%!%4DU37U-(3U<L("=S8W)E
M96XG+"!T<G5E*2D["B1F:7)S=%]I;6%G92`](&-O=6YT*"1I;6%G96QI<W0I
M(#\@)&EM86=E;&ES=%MK97DH)&EM86=E;&ES="E=6R=U<FPG72`Z("<G.PH*
M/SX*/&AT;6P^"@H\:&5A9#X*("`\=&ET;&4^26YS97)T($EM86=E/"]T:71L
M93X*"CQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(B!S<F,](BXN+RXN
M+W!O<'5P<R]P;W!U<"YJ<R(^/"]S8W)I<'0^"@H\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"@IW:6YD;W<N<F5S:7IE5&\H-#`P+"`R,#`I.PH*
M9G5N8W1I;VX@26YI="@I('L*("!?7V1L9U]I;FET*"D["B`@=F%R('!A<F%M
M(#T@=VEN9&]W+F1I86QO9T%R9W5M96YT<SL*("!I9B`H<&%R86TI('L*("`@
M("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=7)L(BDN=F%L=64@/2!P
M87)A;5LB9E]U<FPB73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M(F9?86QT(BDN=F%L=64@/2!P87)A;5LB9E]A;'0B73L*("`@("`@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H(F9?8F]R9&5R(BDN=F%L=64@/2!P87)A;5LB
M9E]B;W)D97(B73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?
M86QI9VXB*2YV86QU92`]('!A<F%M6R)F7V%L:6=N(ET["B`@("`@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*")F7W9E<G0B*2YV86QU92`]('!A<F%M6R)F
M7W9E<G0B73L*("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?:&]R
M:7HB*2YV86QU92`]('!A<F%M6R)F7VAO<FEZ(ET["B`@("`@('=I;F1O=RYI
M<')E=FEE=RYL;V-A=&EO;BYR97!L86-E*'!A<F%M+F9?=7)L*3L*("!]"B`@
M9&]C=6UE;G0N9V5T16QE;65N=$)Y260H(F9?=7)L(BDN9F]C=7,H*3L*?3L*
M"F9U;F-T:6]N(&]N3TLH*2!["B`@=F%R(')E<75I<F5D(#T@>PH@("`@(F9?
M=7)L(CH@(EEO=2!M=7-T(&5N=&5R('1H92!54DPB"B`@?3L*("!F;W(@*'9A
M<B!I(&EN(')E<75I<F5D*2!["B`@("!V87(@96P@/2!D;V-U;65N="YG971%
M;&5M96YT0GE)9"AI*3L*("`@(&EF("@A96PN=F%L=64I('L*("`@("`@86QE
M<G0H<F5Q=6ER961;:5TI.PH@("`@("!E;"YF;V-U<R@I.PH@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"B`@?0H@("\O('!A<W,@9&%T82!B86-K('1O('1H
M92!C86QL:6YG('=I;F1O=PH@('9A<B!F:65L9',@/2!;(F9?=7)L(BP@(F9?
M86QT(BP@(F9?86QI9VXB+"`B9E]B;W)D97(B+`H@("`@("`@("`@("`@("`@
M(F9?:&]R:7HB+"`B9E]V97)T(ET["B`@=F%R('!A<F%M(#T@;F5W($]B:F5C
M="@I.PH@(&9O<B`H=F%R(&D@:6X@9FEE;&1S*2!["B`@("!V87(@:60@/2!F
M:65L9'-;:5T["B`@("!V87(@96P@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"AI9"D["B`@("!P87)A;5MI9%T@/2!E;"YV86QU93L*("!]"B`@7U]D;&=?
M8VQO<V4H<&%R86TI.PH@(')E='5R;B!F86QS93L*?3L*"F9U;F-T:6]N(&]N
M0V%N8V5L*"D@>PH@(%]?9&QG7V-L;W-E*&YU;&PI.PH@(')E='5R;B!F86QS
M93L*?3L*"F9U;F-T:6]N(&]N4')E=FEE=R@I('L*("!V87(@9E]U<FP@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@B9E]U<FPB*3L*("!V87(@=7)L(#T@
M9E]U<FPN=F%L=64["B`@:68@*"%U<FPI('L*("`@(&%L97)T*")9;W4@:&%V
M92!T;R!E;G1E<B!A;B!54DP@9FER<W0B*3L*("`@(&9?=7)L+F9O8W5S*"D[
M"B`@("!R971U<FX@9F%L<V4["B`@?0H@('=I;F1O=RYI<')E=FEE=RYL;V-A
M=&EO;BYR97!L86-E*"=S:&]W:6UA9V4N:'1M;#\G("L@=7)L*3L*("!R971U
M<FX@9F%L<V4["GT["@IF=6YC=&EO;B!C:&%N9V5'86QL97)Y*"D@>PH@('9A
M<B!R96QO861?=7)L(#T@9&]C=6UE;G0N;&]C871I;VXN:')E9CL*"B`@<F5L
M;V%D7W5R;"`@("`@/2!R96QO861?=7)L+G-U8G-T<FEN9R@P+')E;&]A9%]U
M<FPN;&%S=$EN9&5X3V8H)S\G*2D["B`@<F5L;V%D7W5R;"`@("`@/2!R96QO
M861?=7)L("L@)S]G86QL97)Y/2<@*R!D;V-U;65N="YF;W)M<ULP72YG86QL
M97)Y+G9A;'5E.PH*("!D;V-U;65N="YL;V-A=&EO;BYR97!L86-E*')E;&]A
M9%]U<FPI.PI]"CPO<V-R:7!T/@H*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX*
M:'1M;"P@8F]D>2!["B`@8F%C:V=R;W5N9#H@0G5T=&]N1F%C93L*("!C;VQO
M<CH@0G5T=&]N5&5X=#L*("!F;VYT.B`Q,7!X(%1A:&]M82Q697)D86YA+'-A
M;G,M<V5R:68["B`@;6%R9VEN.B`P<'@["B`@<&%D9&EN9SH@,'!X.PI]"F)O
M9'D@>R!P861D:6YG.B`U<'@[('T*=&%B;&4@>PH@(&9O;G0Z(#$Q<'@@5&%H
M;VUA+%9E<F1A;F$L<V%N<RUS97)I9CL*?0IF;W)M('`@>PH@(&UA<F=I;BUT
M;W`Z(#5P>#L*("!M87)G:6XM8F]T=&]M.B`U<'@["GT*+F9L('L@=VED=&@Z
M(#EE;3L@9FQO870Z(&QE9G0[('!A9&1I;F<Z(#)P>"`U<'@[('1E>'0M86QI
M9VXZ(')I9VAT.R!]"BYF<B![('=I9'1H.B`V96T[(&9L;V%T.B!L969T.R!P
M861D:6YG.B`R<'@@-7!X.R!T97AT+6%L:6=N.B!R:6=H=#L@?0IF:65L9'-E
M="![('!A9&1I;F<Z(#!P>"`Q,'!X(#5P>"`U<'@[('T*<V5L96-T+"!I;G!U
M="P@8G5T=&]N('L@9F]N=#H@,3%P>"!486AO;6$L5F5R9&%N82QS86YS+7-E
M<FEF.R!]"F)U='1O;B![('=I9'1H.B`W,'!X.R!]"BYS<&%C92![('!A9&1I
M;F<Z(#)P>#L@?0H*+G1I=&QE('L@8F%C:V=R;W5N9#H@(V1D9CL@8V]L;W(Z
M(",P,#`[(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-I>F4Z(#$R,"4[('!A
M9&1I;F<Z(#-P>"`Q,'!X.R!M87)G:6XM8F]T=&]M.B`Q,'!X.PIB;W)D97(M
M8F]T=&]M.B`Q<'@@<V]L:60@8FQA8VL[(&QE='1E<BUS<&%C:6YG.B`R<'@[
M"GT*9F]R;2![('!A9&1I;F<Z(#!P>#L@;6%R9VEN.B`P<'@[('T*/"]S='EL
M93X*"CPO:&5A9#X*"CQB;V1Y(&]N;&]A9#TB26YI="@I(CX*"CQD:78@8VQA
M<W,](G1I=&QE(CY);G-E<G0@26UA9V4\+V1I=CX*/"$M+2T@;F5W('-T=69F
M("TM+3X*/&9O<FT@86-T:6]N/2(B(&UE=&AO9#TB9V5T(CX*/'1A8FQE(&)O
M<F1E<CTB,"(@=VED=&@](C$P,"4B('-T>6QE/2)P861D:6YG.B`P<'@[(&UA
M<F=I;CH@,'!X(CX*("`\=&)O9'D^"B`@/'1R/@H@("`@/'1D('-T>6QE/2)W
M:61T:#H@-V5M.R!T97AT+6%L:6=N.B!R:6=H="(^1V%L;&5R>3H\+W1D/@H@
M("`@/'1D/CQS96QE8W0@<VEZ93TB,2(@;F%M93TB9V%L;&5R>2(@:60](F9?
M9V%L;&5R>2(@=&ET;&4](D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(B!O
M;D-H86YG93TB8VAA;F=E1V%L;&5R>2@I.R(^"CP_<&AP(&9O<F5A8V@@*"1G
M86QL97)Y;&ES="!A<R`D9V%L;&5R>2DZ(#\^"B`@("`@(#QO<'1I;VX@=F%L
M=64](CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D9V%L;&5R>2T^9V5T
M240H*2D@/SXB/#]P:'`@:68@*"1G86QL97)Y7VED(#T]("1G86QL97)Y+3YG
M971)9"@I*2!E8VAO("<@<V5L96-T960](G-E;&5C=&5D(B<@/SX^/#]P:'`@
M96-H;R!S=')?<F5P96%T*"<F;F)S<#LG+"`R("H@)&=A;&QE<GDM/F=E=$QE
M=F5L*"DI("X@:'1M;'-P96-I86QC:&%R<R@D9V%L;&5R>2T^9V5T*"=N86UE
M)RDI(#\^/"]O<'1I;VX^"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E
M;&5C=#X*("`@(#PO=&0^"B`@/"]T<CX*("`\='(^"B`@("`\=&0@<W1Y;&4]
M(G=I9'1H.B`W96T[('1E>'0M86QI9VXZ(')I9VAT(CY);6%G92!F<F]M(&=A
M;&QE<GDZ/"]T9#X*("`@(#QT9#X\<V5L96-T('-I>F4](C$B(&YA;64](FEM
M9U]G86QL97)Y(B!I9#TB9E]I;6=?9V%L;&5R>2(@=&ET;&4](DEM86=E(&9R
M;VT@9V%L;&5R>2(@;VY#:&%N9V4](F1O8W5M96YT+F9O<FUS6S!=+G5R;"YV
M86QU92`](&1O8W5M96YT+F9O<FUS6S!=+FEM9U]G86QL97)Y+G9A;'5E(CX*
M/#]P:'`@9F]R96%C:"`H)&EM86=E;&ES="!A<R`D:60@/3X@)&EM86=E*3H@
M/SX*("`@("`@/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R`D:6UA9V5;)W5R
M;"==(#\^(CX\/W!H<"!E8VAO("1I;6%G95LG;F%M92==(#\^/"]O<'1I;VX^
M"CP_<&AP(&5N9&9O<F5A8V@[(#\^"B`@("`\+W-E;&5C=#X*("`@(#PO=&0^
M"B`@/"]T<CX*"B`@/'1R/@H@("`@/'1D('-T>6QE/2)W:61T:#H@-V5M.R!T
M97AT+6%L:6=N.B!R:6=H="(^26UA9V4@55),.CPO=&0^"B`@("`\=&0^/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](G5R;"(@:60](F9?=7)L(B!S='EL93TB
M=VED=&@Z-S4E(@H@("`@("!T:71L93TB16YT97(@=&AE(&EM86=E(%523"!H
M97)E(B!V86QU93TB/#]P:'`@96-H;R`D9FER<W1?:6UA9V4@/SXB("\^"B`@
M("`@(#QB=71T;VX@;F%M93TB<')E=FEE=R(@;VYC;&EC:STB<F5T=7)N(&]N
M4')E=FEE=R@I.R(*("`@("`@=&ET;&4](E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(^4')E=FEE=SPO8G5T=&]N/@H@("`@/"]T9#X*("`\
M+W1R/@H@(#QT<CX*("`@(#QT9"!S='EL93TB=VED=&@Z(#=E;3L@=&5X="UA
M;&EG;CH@<FEG:'0B/D%L=&5R;F%T92!T97AT.CPO=&0^"B`@("`\=&0^/&EN
M<'5T('1Y<&4](G1E>'0B(&YA;64](F%L="(@:60](F9?86QT(B!S='EL93TB
M=VED=&@Z,3`P)2(*("`@("`@=&ET;&4](D9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S(B`O/CPO=&0^"B`@/"]T<CX*"B`@/"]T8F]D
M>3X*/"]T86)L93X*"CQP("\^"@H\9FEE;&1S970@<W1Y;&4](F9L;V%T.B!L
M969T.R!M87)G:6XM;&5F=#H@-7!X.R(^"CQL96=E;F0^3&%Y;W5T/"]L96=E
M;F0^"@H\9&EV(&-L87-S/2)S<&%C92(^/"]D:78^"@H\9&EV(&-L87-S/2)F
M;"(^06QI9VYM96YT.CPO9&EV/@H\<V5L96-T('-I>F4](C$B(&YA;64](F%L
M:6=N(B!I9#TB9E]A;&EG;B(*("!T:71L93TB4&]S:71I;VYI;F<@;V8@=&AI
M<R!I;6%G92(^"B`@/&]P=&EO;B!V86QU93TB(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/DYO="!S970\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E
M/2)L969T(B`@("`@("`@("`@("`@("`@("`@("`@("`^3&5F=#PO;W!T:6]N
M/@H@(#QO<'1I;VX@=F%L=64](G)I9VAT(B`@("`@("`@("`@("`@("`@("`@
M("`@(#Y2:6=H=#PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](G1E>'1T;W`B
M("`@("`@("`@("`@("`@("`@("`@(#Y497AT=&]P/"]O<'1I;VX^"B`@/&]P
M=&EO;B!V86QU93TB86)S;6ED9&QE(B`@("`@("`@("`@("`@("`@("`@/D%B
M<VUI9&1L93PO;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](F)A<V5L:6YE(B!S
M96QE8W1E9#TB,2(@("`@("`@(#Y"87-E;&EN93PO;W!T:6]N/@H@(#QO<'1I
M;VX@=F%L=64](F%B<V)O='1O;2(@("`@("`@("`@("`@("`@("`@(#Y!8G-B
M;W1T;VT\+V]P=&EO;CX*("`\;W!T:6]N('9A;'5E/2)B;W1T;VTB("`@("`@
M("`@("`@("`@("`@("`@("`^0F]T=&]M/"]O<'1I;VX^"B`@/&]P=&EO;B!V
M86QU93TB;6ED9&QE(B`@("`@("`@("`@("`@("`@("`@("`@/DUI9&1L93PO
M;W!T:6]N/@H@(#QO<'1I;VX@=F%L=64](G1O<"(@("`@("`@("`@("`@("`@
M("`@("`@("`@(#Y4;W`\+V]P=&EO;CX*/"]S96QE8W0^"@H\<"`O/@H*/&1I
M=B!C;&%S<STB9FPB/D)O<F1E<B!T:&EC:VYE<W,Z/"]D:78^"CQI;G!U="!T
M>7!E/2)T97AT(B!N86UE/2)B;W)D97(B(&ED/2)F7V)O<F1E<B(@<VEZ93TB
M-2(*=&ET;&4](DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B("\^"@H\9&EV
M(&-L87-S/2)S<&%C92(^/"]D:78^"@H\+V9I96QD<V5T/@H*/&9I96QD<V5T
M('-T>6QE/2)F;&]A=#IR:6=H=#L@;6%R9VEN+7)I9VAT.B`U<'@[(CX*/&QE
M9V5N9#Y3<&%C:6YG/"]L96=E;F0^"@H\9&EV(&-L87-S/2)S<&%C92(^/"]D
M:78^"@H\9&EV(&-L87-S/2)F<B(^2&]R:7IO;G1A;#H\+V1I=CX*/&EN<'5T
M('1Y<&4](G1E>'0B(&YA;64](FAO<FEZ(B!I9#TB9E]H;W)I>B(@<VEZ93TB
M-2(*=&ET;&4](DAO<FEZ;VYT86P@<&%D9&EN9R(@+SX*"CQP("\^"@H\9&EV
M(&-L87-S/2)F<B(^5F5R=&EC86PZ/"]D:78^"CQI;G!U="!T>7!E/2)T97AT
M(B!N86UE/2)V97)T(B!I9#TB9E]V97)T(B!S:7IE/2(U(@IT:71L93TB5F5R
M=&EC86P@<&%D9&EN9R(@+SX*"CQD:78@8VQA<W,](G-P86-E(CX\+V1I=CX*
M"CPO9FEE;&1S970^"CQB<B!C;&5A<CTB86QL(B`O/@H\=&%B;&4@=VED=&@]
M(C$P,"4B('-T>6QE/2)M87)G:6XM8F]T=&]M.B`P+C)E;2(^"B`\='(^"B`@
M/'1D('9A;&EG;CTB8F]T=&]M(CX*("`@($EM86=E(%!R979I97<Z/&)R("\^
M"B`@("`\:69R86UE(&YA;64](FEP<F5V:65W(B!I9#TB:7!R979I97<B(&9R
M86UE8F]R9&5R/2(P(B!S='EL93TB8F]R9&5R(#H@,7!X('-O;&ED(&=R87D[
M(B!H96EG:'0](C(P,"(@=VED=&@](C,P,"(@<W)C/2(B/CPO:69R86UE/@H@
M(#PO=&0^"B`@/'1D('9A;&EG;CTB8F]T=&]M(B!S='EL93TB=&5X="UA;&EG
M;CH@<FEG:'0B/@H@("`@/&)U='1O;B!T>7!E/2)B=71T;VXB(&YA;64](F]K
M(B!O;F-L:6-K/2)R971U<FX@;VY/2R@I.R(^3TL\+V)U='1O;CX\8G(^"B`@
M("`\8G5T=&]N('1Y<&4](F)U='1O;B(@;F%M93TB8V%N8V5L(B!O;F-L:6-K
M/2)R971U<FX@;VY#86YC96PH*3LB/D-A;F-E;#PO8G5T=&]N/@H@(#PO=&0^
M"B`\+W1R/@H\+W1A8FQE/@H\+V9O<FT^"CPO8F]D>3X*/"]H=&UL/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]S97)V:6-E<R]E9&ET;W(O:'1M;&%R96$O
M<&QU9VEN<R]!;G-E;$EM86=E+W-H;W=I;6%G92YH=&UL````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R,#,@,3`U
M,34T,S0Q-#,@,#,P-S<S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#QB;V1Y/@H\<V-R:7!T/@H@9&]C=6UE;G0N=W)I=&4H
M)SQI;6<@:'-P86-E/2(P(B!V<W!A8V4](C`B('-R8STB)R`K(&1O8W5M96YT
M+FQO8V%T:6]N+G-E87)C:"YS=6)S='(H,2D@*R`G(CXG*3L*/"]S8W)I<'0^
M"CPO8F]D>3X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V5R=FEC97,O961I=&]R+VAT;6QA<F5A+W!L=6=I;G,O06YS
M96Q);6%G92]L86YG+V5N+FIS`````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,34Q(#$P-3$U-#,T,30S(#`S
M,#`Q,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O+R!),3A.(&-O;G-T86YT<PH*+R\@3$%.1SH@(F5N(BP@14Y#3T1)3D<Z
M(%541BTX('P@25-/+3@X-3DM,0HO+R!!=71H;W(Z($UI:&%I($)A>F]N+"!H
M='1P.B\O9'EN87)C:"YC;VTO;6ES:&]O"@HO+R!&3U(@5%)!3E-,051/4E,Z
M"B\O"B\O("`@,2X@4$Q%05-%(%!55"!93U52($-/3E1!0U0@24Y&3R!)3B!4
M2$4@04)/5D4@3$E.10HO+R`@("`@("AA="!L96%S="!A('9A;&ED(&5M86EL
M(&%D9')E<W,I"B\O"B\O("`@,BX@4$Q%05-%(%1262!43R!54T4@551&+3@@
M1D]2($5.0T]$24Y'.PHO+R`@("`@("AI9B!T:&ES(&ES(&YO="!P;W-S:6)L
M92P@<&QE87-E(&EN8VQU9&4@82!C;VUM96YT"B\O("`@("`@('1H870@<W1A
M=&5S('=H870@96YC;V1I;F<@:7,@;F5C97-S87)Y+BD*"D%N<V5L26UA9V4N
M23$X3B`]('L*"2\O($ET96US('1H870@87!P96%R(&EN(&UE;G4N("!0;&5A
M<V4@;F]T92!T:&%T(&%N('5N9&5R<V-O<F4@*%\I"@DO+R!C:&%R86-T97(@
M:6X@=&AE('1R86YS;&%T:6]N("AR:6=H="!C;VQU;6XI('=I;&P@8V%U<V4@
M=&AE(&9O;&QO=VEN9PH)+R\@;&5T=&5R('1O(&)E8V]M92!U;F1E<FQI;F5D
M(&%N9"!B92!S:&]R=&-U="!F;W(@=&AA="!M96YU(&]P=&EO;BX*"@DB26YS
M97)T($EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B26YS97)T($EM86=E(BP*"2));6%G92!54DPZ(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("));6%G92!54DPZ(BP*
M"2)%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B+`H)(E!R979I
M97<B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(E!R979I97<B+`H)(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=R(@("`@("`@("`@("`@("`@(#H@(E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(L"@DB06QT97)N871E('1E>'0Z(B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`B06QT97)N871E('1E>'0Z(BP*
M"2)&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(@("`@
M("`@("`@("`Z(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(L"@DB4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(L
M"@DB26UA9V4@4')E=FEE=SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B26UA9V4@4')E=FEE=SHB+`H)(D=A;&QE<GDZ(B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D=A;&QE
M<GDZ(BP*"2)'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(@("`@("`@("`@
M("`@("`@("`@("`@("`Z(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(L
M"@DB26UA9V4@9G)O;2!G86QL97)Y.B(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@.B`B26UA9V4@9G)O;2!G86QL97)Y.B(L"@DB26UA9V4@9G)O
M;2!G86QL97)Y(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B
M26UA9V4@9G)O;2!G86QL97)Y(@I].PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]L86YG+V5N+FIS````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-34R-2`Q,#4Q-30S-#$T,R`P,C0S,S(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+R\@
M23$X3B!C;VYS=&%N=',*"B\O($Q!3D<Z(")E;B(L($5.0T]$24Y'.B!55$8M
M."!\($E33RTX.#4Y+3$*+R\@075T:&]R.B!-:6AA:2!"87IO;BP@:'1T<#HO
M+V1Y;F%R8V@N8V]M+VUI<VAO;PH*+R\@1D]2(%1204Y33$%43U)3.@HO+PHO
M+R`@(#$N(%!,14%312!0550@64]54B!#3TY404-4($E.1D\@24X@5$A%($%"
M3U9%($Q)3D4*+R\@("`@("`H870@;&5A<W0@82!V86QI9"!E;6%I;"!A9&1R
M97-S*0HO+PHO+R`@(#(N(%!,14%312!44ED@5$\@55-%(%541BTX($9/4B!%
M3D-/1$E.1SL*+R\@("`@("`H:68@=&AI<R!I<R!N;W0@<&]S<VEB;&4L('!L
M96%S92!I;F-L=61E(&$@8V]M;65N=`HO+R`@("`@("!T:&%T('-T871E<R!W
M:&%T(&5N8V]D:6YG(&ES(&YE8V5S<V%R>2XI"@I(5$U,07)E82Y),3A.(#T@
M>PH*"2\O('1H92!F;VQL;W=I;F<@<VAO=6QD(&)E('1H92!F:6QE;F%M92!W
M:71H;W5T("YJ<R!E>'1E;G-I;VX*"2\O(&ET('=I;&P@8F4@=7-E9"!F;W(@
M875T;VUA=&EC86QL>2!L;V%D('!L=6=I;B!L86YG=6%G92X*"6QA;F<Z(")E
M;B(L"@H)=&]O;'1I<',Z('L*"0EB;VQD.B`@("`@("`@("`@(D)O;&0B+`H)
M"6ET86QI8SH@("`@("`@("`B271A;&EC(BP*"0EU;F1E<FQI;F4Z("`@("`@
M(E5N9&5R;&EN92(L"@D)<W1R:6ME=&AR;W5G:#H@(")3=')I:V5T:')O=6=H
M(BP*"0ES=6)S8W)I<'0Z("`@("`@(E-U8G-C<FEP="(L"@D)<W5P97)S8W)I
M<'0Z("`@(")3=7!E<G-C<FEP="(L"@D):G5S=&EF>6QE9G0Z("`@(")*=7-T
M:69Y($QE9G0B+`H)"6IU<W1I9GEC96YT97(Z("`B2G5S=&EF>2!#96YT97(B
M+`H)"6IU<W1I9GER:6=H=#H@("`B2G5S=&EF>2!2:6=H="(L"@D):G5S=&EF
M>69U;&PZ("`@(")*=7-T:69Y($9U;&PB+`H)"6]R9&5R961L:7-T.B`@("`B
M3W)D97)E9"!,:7-T(BP*"0EU;F]R9&5R961L:7-T.B`@(D)U;&QE=&5D($QI
M<W0B+`H)"6]U=&1E;G0Z("`@("`@("`B1&5C<F5A<V4@26YD96YT(BP*"0EI
M;F1E;G0Z("`@("`@("`@(DEN8W)E87-E($EN9&5N="(L"@D)9F]R96-O;&]R
M.B`@("`@(")&;VYT($-O;&]R(BP*"0EH:6QI=&5C;VQO<CH@("`@(D)A8VMG
M<F]U;F0@0V]L;W(B+`H)"6AO<FEZ;VYT86QR=6QE.B`B2&]R:7IO;G1A;"!2
M=6QE(BP*"0EC<F5A=&5L:6YK.B`@("`@(DEN<V5R="!796(@3&EN:R(L"@D)
M:6YS97)T:6UA9V4Z("`@("));G-E<G0O36]D:69Y($EM86=E(BP*"0EI;G-E
M<G1T86)L93H@("`@(DEN<V5R="!486)L92(L"@D):'1M;&UO9&4Z("`@("`@
M(")4;V=G;&4@2%1-3"!3;W5R8V4B+`H)"7!O<'5P961I=&]R.B`@("`B16YL
M87)G92!%9&ET;W(B+`H)"6%B;W5T.B`@("`@("`@("`B06)O=70@=&AI<R!E
M9&ET;W(B+`H)"7-H;W=H96QP.B`@("`@("`B2&5L<"!U<VEN9R!E9&ET;W(B
M+`H)"71E>'1I;F1I8V%T;W(Z("`B0W5R<F5N="!S='EL92(L"@D)=6YD;SH@
M("`@("`@("`@(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(L"@D)<F5D;SH@
M("`@("`@("`@(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(L"@D)8W5T.B`@
M("`@("`@("`@(")#=70@<V5L96-T:6]N(BP*"0EC;W!Y.B`@("`@("`@("`@
M(D-O<'D@<V5L96-T:6]N(BP*"0EP87-T93H@("`@("`@("`@(E!A<W1E(&9R
M;VT@8VQI<&)O87)D(BP*"0EL969T=&]R:6=H=#H@("`@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(BP*"0ER:6=H='1O;&5F=#H@("`@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(BP*"0ER96UO=F5F;W)M870Z("`@(E)E;6]V92!F;W)M
M871T:6YG(BP*"0EP<FEN=#H@("`@("`@("`@(E!R:6YT(&1O8W5M96YT(BP*
M"0EK:6QL=V]R9#H@("`@("`@(D-L96%R($U33V9F:6-E('1A9W,B"@E]+`H*
M"6)U='1O;G,Z('L*"0DB;VLB.B`@("`@("`@("`@(D]+(BP*"0DB8V%N8V5L
M(CH@("`@("`@(D-A;F-E;"(*"7TL"@H);7-G.B!["@D)(E!A=&@B.B`@("`@
M("`@(")0871H(BP*"0DB5$585%]-3T1%(CH@("`@(EEO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+B(L"@H)"2))12US=6-K<RUF=6QL+7-C<F5E;B(@.@H)"2\O
M('1R86YS;&%T92!H97)E"@D)(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN
M;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L
M("(@*PH)"2)D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B
M86=E("(@*PH)"2)D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@
M86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX("(@*PH)"2)I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN(B`K"@D)(EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T
M:&4@9G5L;"!S8W)E96X@961I=&]R+B(L"@H)"2)-;WHM0VQI<&)O87)D(B`Z
M"@D)(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY("(@*PH)"2)F;W(@<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G("(@*PH)"2)W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L
M;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*"7TL"@H)
M9&EA;&]G<SH@>PH)"2\O($-O;6UO;@H)"2)/2R(@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")/2R(L"@D)(D-A
M;F-E;"(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#H@(D-A;F-E;"(L"@H)"2)!;&EG;FUE;G0Z(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")!;&EG;FUE;G0Z(BP*"0DB
M3F]T('-E="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B3F]T('-E="(L"@D)(DQE9G0B("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DQE9G0B+`H)"2)2:6=H
M="(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z(")2:6=H="(L"@D)(E1E>'1T;W`B("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(E1E>'1T;W`B+`H)"2)!8G-M:61D
M;&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")!8G-M:61D;&4B+`H)"2)"87-E;&EN92(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")"87-E;&EN92(L"@D)(D%B<V)O
M='1O;2(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(D%B<V)O='1O;2(L"@D)(D)O='1O;2(@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(D)O='1O;2(L"@D)(DUI9&1L
M92(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#H@(DUI9&1L92(L"@D)(E1O<"(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@(E1O<"(L"@H)"2),87EO=70B("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("),
M87EO=70B+`H)"2)3<&%C:6YG(B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z(")3<&%C:6YG(BP*"0DB2&]R:7IO;G1A;#HB
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B2&]R
M:7IO;G1A;#HB+`H)"2)(;W)I>F]N=&%L('!A9&1I;F<B("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")(;W)I>F]N=&%L('!A9&1I;F<B+`H)
M"2)697)T:6-A;#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`Z(")697)T:6-A;#HB+`H)"2)697)T:6-A;"!P861D:6YG(B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")697)T:6-A;"!P
M861D:6YG(BP*"0DB0F]R9&5R('1H:6-K;F5S<SHB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B0F]R9&5R('1H:6-K;F5S<SHB+`H)"2),
M96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(B`@("`@("`@("`@("`@("`@("`@
M("`@("`Z("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(BP*"@D)+R\@26YS
M97)T($QI;FL*"0DB26YS97)T+TUO9&EF>2!,:6YK(B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@.B`B26YS97)T+TUO9&EF>2!,:6YK(BP*"0DB
M3F]N92`H=7-E(&EM<&QI8VET*2(@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B3F]N92`H=7-E(&EM<&QI8VET*2(L"@D)(DYE=R!W:6YD;W<@
M*%]B;&%N:RDB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DYE
M=R!W:6YD;W<@*%]B;&%N:RDB+`H)"2)386UE(&9R86UE("A?<V5L9BDB("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")386UE(&9R86UE("A?
M<V5L9BDB+`H)"2)4;W`@9G)A;64@*%]T;W`I(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Z(")4;W`@9G)A;64@*%]T;W`I(BP*"0DB3W1H
M97(B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@.B`B3W1H97(B+`H)"2)487)G970Z(B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")487)G970Z(BP*"0DB5&ET;&4@
M*'1O;VQT:7`I.B(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M.B`B5&ET;&4@*'1O;VQT:7`I.B(L"@D)(E523#HB("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E523#HB+`H)"2)9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\B("`Z(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B+`H)"2\O($EN<V5R="!486)L90H)"2));G-E<G0@5&%B
M;&4B("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("))
M;G-E<G0@5&%B;&4B+`H)"2)2;W=S.B(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Z(")2;W=S.B(L"@D)(DYU;6)E<B!O
M9B!R;W=S(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(DYU;6)E<B!O9B!R;W=S(BP*"0DB0V]L<SHB("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0V]L<SHB+`H)"2).=6UB
M97(@;V8@8V]L=6UN<R(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Z(").=6UB97(@;V8@8V]L=6UN<R(L"@D)(E=I9'1H.B(@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@(E=I9'1H.B(L
M"@D)(E=I9'1H(&]F('1H92!T86)L92(@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#H@(E=I9'1H(&]F('1H92!T86)L92(L"@D)(E!E<F-E;G0B
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M(E!E<F-E;G0B+`H)"2)0:7AE;',B("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(")0:7AE;',B+`H)"2)%;2(@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")%
M;2(L"@D)(E=I9'1H('5N:70B("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@(E=I9'1H('5N:70B+`H)"2)0;W-I=&EO;FEN9R!O
M9B!T:&ES('1A8FQE(B`@("`@("`@("`@("`@("`@("`@("`@("`Z(")0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE(BP*"0DB0V5L;"!S<&%C:6YG.B(@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B0V5L;"!S<&%C
M:6YG.B(L"@D)(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B("`@("`@
M("`@("`@("`@("`@("`@(#H@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',B+`H)"2)#96QL('!A9&1I;F<Z(B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z(")#96QL('!A9&1I;F<Z(BP*"0DB4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(@("`@("`@("`@.B`B
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(L"@D)
M+R\@26YS97)T($EM86=E"@D)(DEN<V5R="!);6%G92(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#H@(DEN<V5R="!);6%G92(L"@D)
M(DEM86=E(%523#HB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#H@(DEM86=E(%523#HB+`H)"2)%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4B("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B+`H)"2)0<F5V:65W(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Z(")0<F5V:65W(BP*"0DB4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(B`@("`@("`@("`@("`@
M("`@.B`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(BP*"0DB
M06QT97)N871E('1E>'0Z(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`B06QT97)N871E('1E>'0Z(BP*"0DB1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,B("`@("`@("`@("`@.B`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B+`H)"2)0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E(B`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(BP*"0DB26UA9V4@4')E=FEE
M=SHB("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`B26UA
M9V4@4')E=FEE=SHB"@E]"GT["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O;&1A
M<```````````````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,R`P,C`P-C,`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<V-R:7!T<R]U<&=R861E<P``````````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30S(#`R,#<U
M-0`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;```````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q-#,@,#$W-S0R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP
M=',O8W)O;F0`````````````````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,38Q,2`Q,#4Q-30S-#$T,R`P,C`R-30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````(R$O=7-R+VQO8V%L
M+W!S82]A9&UI;B]B:6XO<&AP"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E
M+W-C<FEP=',O8W)O;F0L=B`Q+C0N,3`N-2`R,#`V+S`V+S$V(#`X.C(T.C(Y
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H87)L97,@
M2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@IR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U-C:&5D=6QE<BYP:'`G.PH*+R\@36%K92!S=7)E(&YO(&]N
M92!R=6YS('1H:7,@9G)O;2!T:&4@=V5B+@II9B`H(4AO<F1E7T-,23HZ<G5N
M;FEN9T9R;VU#3$DH*2D@>PH@("`@97AI="@B375S="!B92!R=6X@9G)O;2!T
M:&4@8V]M;6%N9"!L:6YE7&XB*3L*?0H*+R\@3&]A9"!T:&4@0TQ)(&5N=FER
M;VYM96YT("T@;6%K92!S=7)E('1H97)E)W,@;F\@=&EM92!L:6UI="P@:6YI
M=`HO+R!S;VUE('9A<FEA8FQE<RP@971C+@I(;W)D95]#3$DZ.FEN:70H*3L*
M"B\O($=E="!A;B!I;G-T86YC92!O9B!T:&4@8W)O;B!S8VAE9'5L97(N"B1D
M865M;VX@/2`F2&]R9&5?4V-H961U;&5R.CIS:6YG;&5T;VXH)V-R;VXG*3L*
M"B\O($YO=R!A9&0@<V]M92!C<F]N(&IO8G,@=&\@9&\L(&]R(&%D9"!P87)S
M:6YG('1O(')E860@82!C;VYF:6<@9FEL92X*+R\@)&1A96UO;BT^861D5&%S
M:R@G;',G+"`G,"PU+#$P+#$U+#(P+#,P+#0P("H@*B`J("HG*3L*"B\O(%-T
M87)T('1H92!D865M;VX@9V]I;F<N"B1D865M;VXM/G)U;B@I.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O=&AE;65S7V-H96-K+G!H<```````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`Q-#4V-B`Q,#4Q-30S-#$T,R`P,C(S-S0`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(R$O=7-R
M+VQO8V%L+W!S82]A9&UI;B]B:6XO<&AP"CP_<&AP"B\J*@H@*B!4:&ES('-C
M<FEP="!D;V5S('-O;64@8VAE8VMI;F<@;V8@=&AE;65S+"!T;R!M86ME('-U
M<F4@:6UA9V5S(&%R90H@*B!S>6YC:')O;FES960@86-R;W-S('1H96UE<RX*
M("H*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W1H96UE<U]C:&5C:RYP:'`L
M=B`Q+C,N,3`N-2`R,#`V+S`T+S$X(#$V.C(V.C`U(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V(%1H92!(;W)D92!0<F]J96-T("AH='1P
M.B\O=W=W+FAO<F1E+F]R9R\I"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J+PH*0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D[
M"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXG*3L*"B\J($-,22!C:&5C:W,@86YD(&5N=FER;VYM96YT('-E='5P(&9I
M<G-T+B`J+PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B\J($UA:V4@
M<W5R92!N;R!O;F4@<G5N<R!T:&ES(&9R;VT@=&AE('=E8BX@*B\*:68@*"%(
M;W)D95]#3$DZ.G)U;FYI;F=&<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU<W0@
M8F4@<G5N(&9R;VT@=&AE(&-O;6UA;F0@;&EN95QN(BD["GT*"B\J($=E="!A
M;GD@;W!T:6]N<RX@*B\*)'-I;7!L92`](&9A;'-E.PHD:6=N;W)E(#T@87)R
M87DH*3L*:68@*&ES<V5T*"1A<F=V*2D@>PH@("`@+RH@1V5T(')I9"!O9B!T
M:&4@9FER<W0@87)G('=H:6-H(&ES('1H92!S8W)I<'0@;F%M92X@*B\*("`@
M(&%R<F%Y7W-H:69T*"1A<F=V*3L*("`@('=H:6QE("@D87)G(#T@87)R87E?
M<VAI9G0H)&%R9W8I*2!["B`@("`@("`@:68@*"1A<F<@/3T@)RTM:&5L<"<I
M('L*("`@("`@("`@("`@<')I;G1?=7-A9V4H*3L*("`@("`@("!](&5L<V5I
M9B`H)&%R9R`]/2`G+7,G*2!["B`@("`@("`@("`@("1S:6UP;&4@/2!T<G5E
M.PH@("`@("`@('T@96QS96EF("AS=')P;W,H)&%R9RP@)RUI)RD@/3T](#`I
M('L*("`@("`@("`@("`@;&ES="@L)&EG;F]R95M=*2`](&5X<&QO9&4H)STG
M+"`D87)G*3L*("`@("`@("`@("`@+R\D:6=N;W)E6UT@/2`D:3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN=%]U<V%G92@B56YR96-O9VYI
M<V5D(&]P=&EO;B`D87)G(BD["B`@("`@("`@?0H@("`@?0I]"@HO*B!3970@
M=7`@0TQ)+B`J+PHD8VQI(#T@)FYE=R!(;W)D95]#3$DH*3L*"B\J($-H96-K
M(&EF(&%T(&QE87-T('1H92!R96=I<W1R>2!I<R!A=F%I86)L92X@*B\*:68@
M*"%`9FEL95]E>&ES=',H2$]21$5?0D%312`N("<O8V]N9FEG+W)E9VES=')Y
M+G!H<"<I*2!["B`@("`D8VQI+3YW<FET96QN*"1C;&DM/G)E9"@G3F\@2&]R
M9&4@<F5G:7-T<GD@9FEL92XG*2D["B`@("!E>&ET.PI]"@HO+R1C;&DM/G=R
M:71E;&XH)&-L:2T^9W)E96XH)U)E861I;F<N+BXG*2D["G)E<75I<F5?;VYC
M92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@1V5T('1H92!A
M<'!S(&%N9"!S=&%R="!D;VEN9R!C:&5C:W,N("HO"B1A<'!S(#T@)')E9VES
M=')Y+3YL:7-T07!P<RAA<G)A>2@G:&ED9&5N)RP@)VYO=&]O;&)A<B<L("=A
M8W1I=F4G+"`G861M:6XG*2D["@HO*B!'970@82!L:7-T(&]F('1H96UE<RX@
M*B\*)'1H96UE<R`](&%R<F%Y*"D["B1T:&5M97-?9&ER(#T@)')E9VES=')Y
M+3YG970H)W1H96UE<V9S)RP@)VAO<F1E)RD["FEF("@D:&%N9&QE(#T@;W!E
M;F1I<B@D=&AE;65S7V1I<BDI('L*("`@('=H:6QE("@D9FEL92`](')E861D
M:7(H)&AA;F1L92DI('L*("`@("`@("!I9B`H)&9I;&4@/3T@)RXG('Q\("1F
M:6QE(#T]("<N+B<@?'P@)&9I;&4@/3T@)T-64R<@?'P*("`@("`@("`@("`@
M)&9I;&4@/3T@)RYS=FXG('Q\"B`@("`@("`@("`@("%`9FEL95]E>&ES=',H
M(B1T:&5M97-?9&ER+R1F:6QE+VEN9F\N<&AP(BD@?'P*("`@("`@("`@("`@
M(4!F:6QE7V5X:7-T<R@B)'1H96UE<U]D:7(O)&9I;&4O9W)A<&AI8W,B*2D@
M>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("\J
M($1O;B=T(&)O=&AE<B!C:&5C:VEN9R!U;FQE<W,@=&AE('1H96UE(&5X<&QI
M8VET;'D@<W1A=&5S('1H870*("`@("`@("`@*B!I8V]N<R!W:6QL(&)E(')E
M<&QA8V5D(&9O<B!T:&ES(&%P<&QI8V%T:6]N+B`J+PH@("`@("`@(&EN8VQU
M9&4@(B1T:&5M97-?9&ER+R1F:6QE+VEN9F\N<&AP(CL*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&5M95]I8V]N<RDI('L*("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T:&4@87!P<R!A;F0@=&AE
M:7(@=&AE;64@9&ER96-T;W)I97,N("HO"B`@("`@("`@9F]R96%C:"`H)'1H
M96UE7VEC;VYS(&%S("1A<'`I('L*("`@("`@("`@("`@)&%P<%]T:&5M97-?
M9&ER(#T@)')E9VES=')Y+3YG970H)W1H96UE<V9S)RP@)&%P<"D["B`@("`@
M("`@("`@("1T:&5M97-;)&%P<%U;)&9I;&5=(#T@(B1A<'!?=&AE;65S7V1I
M<B\D9FEL92]G<F%P:&EC<R(["B`@("`@("`@?0H*("`@("`@("`O*B!5;G-E
M="!T:&ES+"!T;R!M86ME('-U<F4@:70@:7,@8VAE8VME9"!T:&4@;F5X="!T
M:6UE(&%R;W5N9"X@*B\*("`@("`@("!U;G-E="@D=&AE;65?:6-O;G,I.PH@
M("`@?0I]"@IF;W)E86-H("@D87!P<R!A<R`D87!P*2!["B`@("`O*B!3970@
M=7`@<V]M92!D:7)S+B`J+PH@("`@)'1H96UE<U]D:7(@/2`D<F5G:7-T<GDM
M/F=E="@G=&AE;65S9G,G+"`D87!P*3L*("`@("1H;W)D95]T:&5M95]D:7(@
M/2`D=&AE;65S7V1I<B`N("<O:&]R9&4G.PH@("`@)&AO<F1E7VEC;VY?9&ER
M(#T@)&AO<F1E7W1H96UE7V1I<B`N("<O9W)A<&AI8W,G.PH*("`@("\J(%-A
M;FET>2!C:&5C:R!F;W(@=&AE(&1I<F5C=&]R:65S+B`J+PH@("`@:68@*"%`
M9FEL95]E>&ES=',H)&AO<F1E7W1H96UE7V1I<BD@?'P@(4!F:6QE7V5X:7-T
M<R@D:&]R9&5?:6-O;E]D:7(I*2!["B`@("`@("`@8V]N=&EN=64["B`@("!]
M"@H@("`@+RH@1V5T(&$@;&ES="!O9B!A;&P@:&]R9&4@:6UA9V5S(')E8W5R
M<VEV96QY+B`J+PH@("`@)&AO<F1E7VEC;VY?;&ES="`](&%R<F%Y*"D["B`@
M("!R96%D1&ER4F5C=7)S:79E;'DH)&AO<F1E7VEC;VY?9&ER+"`D:&]R9&5?
M:6-O;E]D:7(L("1H;W)D95]I8V]N7VQI<W0I.PH*("`@("\J($QO;W`@=&AR
M;W5G:"!T:&5M97,@=&AA="!R97!L86-E(&EC;VYS(&%N9"!C:&5C:R!F;W(@
M9&EF9F5R96YC97,N("HO"B`@("!F;W)E86-H("@D=&AE;65S6R1A<'!=(&%S
M("1T:&5M92`]/B`D=&AE;65?:6-O;E]D:7(I('L*("`@("`@("`D=&AE;65?
M:6-O;E]L:7-T(#T@87)R87DH*3L*("`@("`@("!R96%D1&ER4F5C=7)S:79E
M;'DH)'1H96UE7VEC;VY?9&ER+"`D=&AE;65?:6-O;E]D:7(L("1T:&5M95]I
M8V]N7VQI<W0I.PH*("`@("`@("`O*B!#:&5C:R!F;W(@:6-O;G,@=&AA="!A
M<F4@:6X@=&AE($AO<F1E(&)A<V4@=&AE;64@86YD(&YO="!I;B!T:&4*("`@
M("`@("`@*B!C=7-T;VT@=&AE;64N("HO"B`@("`@("`@)&1I9F8@/2!A<G)A
M>5]D:69F*"1H;W)D95]I8V]N7VQI<W0L("1T:&5M95]I8V]N7VQI<W0I.PH@
M("`@("`@("\J($1O;B=T(&)O=&AE<B!R97!O<G1I;F<@86YY=&AI;F<@9F]R
M('1H96UE<R!T:&%T(&AA=F4@86QL('1H92!H;W)D90H@("`@("`@("`J(&)A
M<V4@:6-O;G,N("HO"B`@("`@("`@:68@*&5M<'1Y*"1D:69F*2D@>PH@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@("1C;&DM/G=R
M:71E;&XH)&-L:2T^<F5D*'-P<FEN=&8H)ULE<UT@(B5S(B!T:&5M92!M:7-S
M:6YG('1H97-E(&EC;VYS.B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R=&]U<'!E<B@D87!P*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AE;64I*2D["B`@("`@("`@9F]R96%C:"`H)&1I9F8@
M87,@)&EC;VXI('L*("`@("`@("`@("`@)&-L:2T^=W)I=&5L;B@D:6-O;BD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!O;FQY(&1O:6YG(&$@
M2&]R9&4@8F%S92!T:&5M92!T;R!C=7-T;VT@=&AE;64@8VAE8VLN(%-K:7`*
M("`@("`@("`@*B!T:&4@<F5V97)S92!C:&5C:VEN9R!I9B!T<G5E+B`J+PH@
M("`@("`@(&EF("@D<VEM<&QE*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(&EC;VYS('1H870@87)E
M(&EN('1H92!(;W)D92!B87-E('1H96UE(&%N9"!N;W0@:6X@=&AE"B`@("`@
M("`@("H@8W5S=&]M('1H96UE+B`J+PH@("`@("`@("1D:69F(#T@87)R87E?
M9&EF9B@D=&AE;65?:6-O;E]L:7-T+"`D:&]R9&5?:6-O;E]L:7-T*3L*("`@
M("`@("`O*B!$;VXG="!B;W1H97(@<F5P;W)T:6YG(&%N>71H:6YG(&9O<B!T
M:&5M97,@=&AA="!D;VXG="!H879E(&%N>2!I8V]N<PH@("`@("`@("`J(&UO
M<F4@=&AA;B!T:&4@8F%S92!T:&5M92X@*B\*("`@("`@("!I9B`H96UP='DH
M)&1I9F8I*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*"B`@
M("`@("`@)&-L:2T^=W)I=&5L;B@D8VQI+3YB;'5E*'-P<FEN=&8H)ULE<UT@
M(B5S(B!T:&5M92!H87,@=&AE<V4@97AT<F$@:6-O;G,Z)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S=')T;W5P<&5R*"1A<'`I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&5M92DI*3L*("`@("`@
M("!F;W)E86-H("@D9&EF9B!A<R`D:6-O;BD@>PH@("`@("`@("`@("`D8VQI
M+3YW<FET96QN*"1I8V]N*3L*("`@("`@("!]"B`@("!]"GT*"B1C;&DM/G=R
M:71E;&XH)&-L:2T^9W)E96XH)T1O;F4N)RDI.PIE>&ET.PH*+RHJ"B`J($QO
M;W!S('1H<F]U9V@@=&AE(&1I<F5C=&]R>2!R96-U<G-I=F5L>2!A;F0@<W1O
M<F5S('1H92!F;W5N9"!G<F%P:&EC<R!I;G1O"B`J(&%N(&%R<F%Y+@H@*B\*
M9G5N8W1I;VX@<F5A9$1I<E)E8W5R<VEV96QY*"1P871H+"`D8F%S97!A=&@L
M("8D;&ES="D*>PH@("`@9VQO8F%L("1I9VYO<F4["@H@("`@:68@*"1H86YD
M;&4@/2!O<&5N9&ER*"1P871H*2D@>PH@("`@("`@('=H:6QE("@D9FEL92`]
M(')E861D:7(H)&AA;F1L92DI('L*("`@("`@("`@("`@:68@*"1F:6QE(#T]
M("<N)R!\?"`D9FEL92`]/2`G+BXG('Q\("1F:6QE(#T]("=#5E,G"B`@("`@
M("`@("`@("`@("!\?"`D9FEL92`]/2`G+G-V;B<I('L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI
M<U]D:7(H(B1P871H+R1F:6QE(BDI('L*("`@("`@("`@("`@("`@(')E861$
M:7)296-U<G-I=F5L>2@B)'!A=&@O)&9I;&4B+"`D8F%S97!A=&@L("1L:7-T
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1I9VYO<F4@87,@)'!A='1E<FXI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@D<&%T=&5R;BP@)&9I;&4I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QI<W1;
M72`]('-U8G-T<B@D<&%T:"P@<W1R;&5N*"1B87-E<&%T:"DI("X@(B\D9FEL
M92(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@8VQO<V5D:7(H
M)&AA;F1L92D["B`@("!]"@I]"@IF=6YC=&EO;B!P<FEN=%]U<V%G92@D;65S
M<V%G92`]("<G*2!["@H@("`@:68@*"%E;7!T>2@D;65S<V%G92DI('L*("`@
M("`@("!P<FEN="`B=&AE;65S7V-H96-K+G!H<#H@)&UE<W-A9V5<;EQN(CL*
M("`@('T*"B`@("!P<FEN="`\/#Q54T%'10I5<V%G93H@=&AE;65S7V-H96-K
M+G!H<"!;3U!424].70H*4&]S<VEB;&4@;W!T:6]N<SH*("`M<R`@("`@("`@
M("`@($1O(&]N;'D@82!S:6UP;&4@8VAE8VL@9F]R(&%N>2!(;W)D92!B87-E
M('1H96UE(&=R87!H:6-S('1H870*("`@("`@("`@("`@("`@(&%R92!M:7-S
M:6YG(&9R;VT@=&AE(&]T:&5R('1H96UE<RP@86YD(&YO(&-H96-K(&]F('1H
M90H@("`@("`@("`@("`@("`@;W!P;W-I=&4N"B`@+6D]4$%45$523B`@("!)
M;G-E<G0@86YY('9A;&ED(')E9V5X('!A='1E<FX@=&\@:6=N;W)E(&9I;&5S
M(&9R;VT@8F5I;F<*("`@("`@("`@("`@("`@(&-H96-K960N(%EO=2!C86X@
M96YT97(@;75L=&EP;&4@+6D@;W!T:6]N<R!T;R!I;F-L=61E(&UU;'1I<&QE
M"B`@("`@("`@("`@("`@("!P871T97)N<RX@1F]R(&5X86UP;&4Z("UI/2(O
M>&-F)"\@=&\@:6=N;W)E(&%N>2!O<FEG:6YA;`H@("`@("`@("`@("`@("`@
M1TE-4"!F:6QE<RX*"E5304=%.PH@("`@97AI=#L*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]S8W)I<'1S+V-O=6YT7W-E<W-I;VYS+G!H<```````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0Q-3(@,3`U,34T,S0Q
M-#,@,#(S,#$V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",A+W5S<B]B:6XO<&AP"CP_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+W-C<FEP=',O8V]U;G1?<V5S<VEO;G,N<&AP+'8@,2XU+C(N,R`R,#`V
M+S`T+S$X(#$V.C(T.C4X(&IA;B!%>'`@)`H@*@H@*B!4:&ES('-C<FEP="!C
M;W5N=',@=&AE(&YU;6)E<B!O9B!A8W1I=F4@875T:&5N=&EC871E9"!U<V5R
M('-E<W-I;VYS+@H@*@H@*B!#;VUM86YD(&QI;F4@;W!T:6]N<SH*("H@("`G
M+6PG("`@3&ES="!T:&4@=7-E<FYA;64@;V8@86-T:79E(&%U=&AE;G1I8V%T
M960@=7-E<G,*("H@("`G+6QL)R`@3&ES="!T:&4@=7-E<FYA;64@86YD(&QO
M9VEN('1I;64@;V8@86-T:79E(&%U=&AE;G1I8V%T960@=7-E<G,*("HO"@HO
M+R!.;R!A=71H+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*"B\O
M($9I;F0@=&AE(&)A<V4@9FEL92!P871H(&]F($AO<F1E+@I`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!$
M;R!#3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S="X*<F5Q
M=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I
M<F5?;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO+R!-86ME('-U<F4@;F\@;VYE
M(')U;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN
M:6YG1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H
M92!C;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV:7)O
M;FUE;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET
M"B\O('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I.PHD
M8VQI(#T@)FYE=R!(;W)D95]#3$DH*3L*"G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PH*+RH@36%K92!S=7)E('1H97)E)W,@
M;F\@8V]M<')E<W-I;VXN("HO"D!O8E]E;F1?8VQE86XH*3L*"B1T>7!E(#T@
M(65M<'1Y*"1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UTI(#\*("`@
M("1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UT@.B`G8G5I;'1I;B<[
M"@II9B`H)'1Y<&4@/3T@)V5X=&5R;F%L)RD@>PH@("`@2&]R9&4Z.F9A=&%L
M*%!%05(Z.G)A:7-E17)R;W(H)U-E<W-I;VX@8V]U;G1I;F<@:7,@;F]T('-U
M<'!O<G1E9"!I;B!T:&4@7"=E>'1E<FYA;%PG(%-E<W-I;VY(86YD;&5R(&%T
M('1H:7,@=&EM92XG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["GT@
M96QS92!["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<"<["B`@("`D7W-E<W-I;VY?:&%N9&QE<B`]("9397-S:6]N2&%N9&QE
M<CHZ<VEN9VQE=&]N*"1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UTI
M.PH@("`@:68@*&ES7V$H)%]S97-S:6]N7VAA;F1L97(L("=014%27T5R<F]R
M)RDI('L*("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS
M<')I;G1F*")(;W)D92!I<R!U;F%B;&4@=&\@;&]A9"!S97-S:6]N(&AA;F1L
M97(@;V8@='EP92!<(B5S7"(N(BP@)'1Y<&4I*2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!F86QS92D["B`@("!]"@H@("`@:68@*"1A<F=C(#P@,B!\?"`H)&%R
M9W9;,5T@(3T@)RUL)R`F)B`D87)G=ELQ72`A/2`G+6QL)RDI('L*("`@("`@
M("`D8V]U;G0@/2`D7W-E<W-I;VY?:&%N9&QE<BT^8V]U;G1!=71H96YT:6-A
M=&5D57-E<G,H*3L*("`@("`@("!I9B`H:7-?82@D8V]U;G0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1C;W5N="P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@("`@?0H*("`@("`@("`D
M8VQI+3YW<FET96QN*"1C;W5N="D["B`@("!](&5L<V4@>PH@("`@("`@("1U
M<V5R<R`]("1?<V5S<VEO;E]H86YD;&5R+3YL:7-T075T:&5N=&EC871E9%5S
M97)S*"1A<F=V6S%=(#T]("<M;&PG*3L*("`@("`@("!I9B`H:7-?82@D=7-E
M<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@("`@
M?0H*("`@("`@("!F;W)E86-H("@D=7-E<G,@87,@)'5S97(I('L*("`@("`@
M("`@("`@)&-L:2T^=W)I=&5L;B@D=7-E<BD["B`@("`@("`@?0H@("`@?0I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+RYH=&%C8V5S<P``
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,38@,3`U,34T,S0Q-#,@,#(Q,#$U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````$1E;GD@9G)O;2!A;&P*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]H='1P7VQO9VEN7W)E9F5R+G!H<```
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S$T(#$P-3$U-#,T
M,30S(#`R,S(W,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+VAT
M='!?;&]G:6Y?<F5F97(N<&AP+'8@,2XS+C$R+C,@,C`P-B\P,2\P,2`R,3HR
M.3HP.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*"G)E<75I<F5?;VYC92`G+BXO;&EB+V)A<V4N<&AP)SL*
M"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D<FEV
M97(G72D["@HO+R!#:&5C:R!F;W(@2%144"!A=71H+@II9B`H96UP='DH)%]3
M15)615);)U!(4%]!551(7U5315(G72D@?'P*("`@(&5M<'1Y*"1?4T525D52
M6R=02%!?05542%]05R==*2!\?`H@("`@(21A=71H+3YA=71H96YT:6-A=&4H
M)%]315)615);)U!(4%]!551(7U5315(G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=P87-S=V]R9"<@/3X@)%]315)615);)U!(4%]!551(
M7U!7)UTI*2D@>PH*("`@(&AE861E<B@G5U=7+4%U=&AE;G1I8V%T93H@0F%S
M:6,@<F5A;&T](B<@+B`D875T:"T^9V5T4&%R86TH)W)E86QM)RD@+B`G(B<I
M.PH@("`@:&5A9&5R*"=(5%10+S$N,"`T,#$@56YA=71H;W)I>F5D)RD["B`@
M("!E>&ET*"=&;W)B:61D96XG*3L*?0H*:68@*"1U<FP@/2!5=&EL.CIG971&
M;W)M1&%T82@G=7)L)RDI('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D
M=7)L*3L*?2!E;'-E('L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)VQO9VEN+G!H<"<I*3L*?0H`````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]M:6=R871E7W5S97)?8V%T
M96=O<FEE<RYP:'``````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-38U(#$P
M-3$U-#,T,30S(#`R-#8T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C(2]U<W(O;&]C86PO<'-A+V%D;6EN+V)I;B]P:'`@
M+7$*/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]M:6=R871E
M7W5S97)?8V%T96=O<FEE<RYP:'`L=B`Q+C4N,3`N,2`R,#`U+S$P+S$X(#$Q
M.C,T.C`P(&IA;B!%>'`@)`H@*@H@*B!!('-C<FEP="!T;R!U<&1A=&4@=7-E
M<G,@<')E9F5R96YC97,@=&\@8V]M8FEN92!T:&5I<B!C871E9V]R:65S"B`J
M(&%N9"!C871E9V]R>2!C;VQO<G,@9G)O;2!'96YI92P@2W)O;F]L:71H+"!-
M;F5M;RP@86YD($YA9R!I;G1O('1H90H@*B!N97<@2&]R9&4M=VED92!P<F5F
M97)E;F-E<RX@17AP96-T<R!T;R!B92!G:79E;B!A(&QI<W0@;V8@=7-E<G,@
M;VX*("H@4U1$24XL(&]N92!U<V5R;F%M92!P97(@;&EN92P@=&\@8V]N=F5R
M="X@57-E<FYA;65S(&YE960@=&\@;6%T8V@*("H@=&AE('9A;'5E<R!S=&]R
M960@:6X@=&AE('!R969E<F5N8V5S(&)A8VME;F0N"B`J+PH*+R\@1FEN9"!T
M:&4@8F%S92!F:6QE('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)T%55$A?2$%.
M1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!$;R!#3$D@8VAE8VMS(&%N9"!E;G9I
M<F]N;65N="!S971U<"!F:7)S="X*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0TQ)+G!H
M<"<["@HO+R!-86ME('-U<F4@;F\@;VYE(')U;G,@=&AI<R!F<F]M('1H92!W
M96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG1G)O;4-,22@I*2!["B`@("!E
M>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F5<;B(I.PI]
M"@HO+R!,;V%D('1H92!#3$D@96YV:7)O;FUE;G0@+2!M86ME('-U<F4@=&AE
M<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET"B\O('-O;64@=F%R:6%B;&5S+"!E
M=&,N"DAO<F1E7T-,23HZ:6YI="@I.PH*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<"<["B1C;&D@/2`F2&]R9&5?0TQ).CIS
M:6YG;&5T;VXH*3L*)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A
M=71H)UU;)V1R:79E<B==*3L*)&--86YA9V5R(#T@)FYE=R!0<F5F<U]#871E
M9V]R>4UA;F%G97(H*3L*)&%P<',@/2`D<F5G:7-T<GDM/FQI<W1!<'!S*&%R
M<F%Y*"=H:61D96XG+"`G;F]T;V]L8F%R)RP@)V%C=&EV92<L("=A9&UI;B<I
M*3L*"B\O(%)E860@:6X@=&AE(&QI<W0@;V8@=7-E<FYA;65S(&]N(%-41$E.
M+@HD=7-E<G,@/2!A<G)A>2@I.PIW:&EL92`H(69E;V8H4U1$24XI*2!["B`@
M("`D;&EN92`](&9G971S*%-41$E.*3L*("`@("1L:6YE(#T@=')I;2@D;&EN
M92D["B`@("!I9B`H(65M<'1Y*"1L:6YE*2D@>PH@("`@("`@("1U<V5R<UM=
M(#T@)&QI;F4["B`@("!]"GT*"B\O($QO;W`@=&AR;W5G:"!U<V5R<R!A;F0@
M8V]N=F5R="!P<F5F<R!F;W(@1V5N:64L($UN96UO+"!.86<L(&%N9`HO+R!+
M<F]N;VQI=&@N"F9O<F5A8V@@*"1U<V5R<R!A<R`D=7-E<BD@>PH@("`@96-H
M;R`G36EG<F%T:6YG('!R969S(&9O<B`G("X@)&-L:2T^8F]L9"@D=7-E<BD[
M"@H@("`@+R\@4V5T("1U<V5R(&%S('1H92!C=7)R96YT('5S97(N"B`@("`D
M875T:"T^<V5T075T:"@D=7-E<BP@87)R87DH*2P@)R<I.PH*("`@("\O($9E
M=&-H(&-U<G)E;G0@8V%T96=O<FEE<R!A;F0@8V]L;W)S+@H@("`@)&-O;&]R
M<R`]("1C36%N86=E<BT^8V]L;W)S*"D["@H@("`@+R\@1V5N:64N"B`@("!I
M9B`H:6Y?87)R87DH)V=E;FEE)RP@)&%P<',I*2!["B`@("`@("`@96-H;R`G
M("X@9V5N:64G.PH@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!
M<'`H)V=E;FEE)RP@9F%L<V4I.PH@("`@("`@(&EF("@A:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1G7V-A=&5G;W)I97,@
M/2!L:7-T0V%T96=O<FEE<R@G=VES:%]C871E9V]R:65S)RD["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1G7V-A=&5G;W)I97,@87,@)&-A=&5G;W)Y*2!["B`@
M("`@("`@("`@("`@("`D8TUA;F%G97(M/F%D9"@D8V%T96=O<GDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\O($UN96UO+@H@("`@
M:68@*&EN7V%R<F%Y*"=M;F5M;R<L("1A<'!S*2D@>PH@("`@("`@(&5C:&\@
M)R`N(&UN96UO)SL*("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YP=7-H
M07!P*"=M;F5M;R<L(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;5]C871E9V]R:65S
M(#T@;&ES=$-A=&5G;W)I97,H)VUE;6]?8V%T96=O<FEE<R<I.PH@("`@("`@
M("`@("`D;5]C;VQO<G,@/2!L:7-T0V]L;W)S*"=M96UO7V-O;&]R<R<I.PH@
M("`@("`@("`@("!F;W)E86-H("@D;5]C871E9V]R:65S(&%S("1K97D@/3X@
M)&-A=&5G;W)Y*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&U?8V]L
M;W)S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1C;VQO<G-;)&-A
M=&5G;W)Y72`]("1M7V-O;&]R<ULD:V5Y73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1C36%N86=E<BT^861D*"1C871E9V]R>2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@3F%G+@H@("`@
M:68@*&EN7V%R<F%Y*"=N86<G+"`D87!P<RDI('L*("`@("`@("!E8VAO("<@
M+B!N86<G.PH@("`@("`@("1R97-U;'0@/2`D<F5G:7-T<GDM/G!U<VA!<'`H
M)VYA9R<L(&9A;'-E*3L*("`@("`@("!I9B`H(6ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;E]C871E9V]R:65S(#T@;&ES
M=$-A=&5G;W)I97,H)W1A<VM?8V%T96=O<FEE<R<I.PH@("`@("`@("`@("!F
M;W)E86-H("@D;E]C871E9V]R:65S(&%S("1C871E9V]R>2D@>PH@("`@("`@
M("`@("`@("`@)&--86YA9V5R+3YA9&0H)&-A=&5G;W)Y*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O+R!+<F]N;VQI=&@N"B`@("!I
M9B`H:6Y?87)R87DH)VMR;VYO;&ET:"<L("1A<'!S*2D@>PH@("`@("`@(&5C
M:&\@)R`N(&MR;VYO;&ET:"<["B`@("`@("`@)')E<W5L="`]("1R96=I<W1R
M>2T^<'5S:$%P<"@G:W)O;F]L:71H)RP@9F%L<V4I.PH@("`@("`@(&EF("@A
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1K
M7V-A=&5G;W)I97,@/2!L:7-T0V%T96=O<FEE<R@G979E;G1?8V%T96=O<FEE
M<R<I.PH@("`@("`@("`@("!I9B`H8V]U;G0H)&M?8V%T96=O<FEE<RDI('9A
M<E]D=6UP*"1K7V-A=&5G;W)I97,I.PH@("`@("`@("`@("`D:U]C;VQO<G,@
M/2!L:7-T0V]L;W)S*"=E=F5N=%]C;VQO<G,G*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)&M?8V%T96=O<FEE<R!A<R`D:V5Y(#T^("1C871E9V]R>2D@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1K7V-O;&]R<ULD:V5Y72DI('L*
M("`@("`@("`@("`@("`@("`@("`D8V]L;W)S6R1C871E9V]R>5T@/2`D:U]C
M;VQO<G-;)&ME>5T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D8TUA;F%G97(M/F%D9"@D8V%T96=O<GDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("1C36%N86=E<BT^<V5T0V]L;W)S*"1C;VQO
M<G,I.PH@("`@)'!R969S+3YS=&]R92@I.PH@("`@)&-L:2T^=W)I=&5L;B@I
M.PI]"@HD8VQI+3YW<FET96QN*"D["B1C;&DM/G=R:71E;&XH)&-L:2T^9W)E
M96XH)T1/3D4G*2D["F5X:70["@IF=6YC=&EO;B!L:7-T0V%T96=O<FEE<R@D
M<')E9FYA;64I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@)'-T<FEN9R`]
M("1P<F5F<RT^9V5T5F%L=64H)'!R969N86UE*3L*("`@(&EF("AE;7!T>2@D
M<W1R:6YG*2D@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@
M("1C871S(#T@97AP;&]D92@G?"<L("1S=')I;F<I.PH@("`@9F]R96%C:"`H
M)&-A=',@87,@)&-A="D@>PH@("`@("`@(&QI<W0H)&ME>2P@)'9A;"D@/2!E
M>'!L;V1E*"<Z)RP@)&-A="D["B`@("`@("`@)&-A=&5G;W)I97-;)&ME>5T@
M/2`D=F%L.PH@("`@?0H*("`@(')E='5R;B`D8V%T96=O<FEE<SL*?0H*9G5N
M8W1I;VX@;&ES=$-O;&]R<R@D<')E9FYA;64I"GL*("`@(&=L;V)A;"`D<')E
M9G,["@H@("`@)'-T<FEN9R`]("1P<F5F<RT^9V5T5F%L=64H)'!R969N86UE
M*3L*("`@(&EF("AE;7!T>2@D<W1R:6YG*2D@>PH@("`@("`@(')E='5R;B!A
M<G)A>2@I.PH@("`@?0H@("`@)&-O;',@/2!E>'!L;V1E*"=\)RP@)'-T<FEN
M9RD["B`@("`D8V]L;W)S(#T@87)R87DH*3L*("`@(&9O<F5A8V@@*"1C;VQS
M(&%S("1C;VPI('L*("`@("`@("!L:7-T*"1K97DL("1V86PI(#T@97AP;&]D
M92@G.B<L("1C;VPI.PH@("`@("`@("1C;VQO<G-;)&ME>5T@/2`D=F%L.PH@
M("`@?0H*("`@(')E='5R;B`D8V]L;W)S.PI]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]S8W)I<'1S+W)E;6]V95]P<F5F<RYP:'``````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0V,C(@,3`U,34T,S0Q-#,@
M,#(R-#,V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H<`H\/W!H<`HO*BH*
M("H@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W)E;6]V95]P<F5F<RYP:'`L=B`Q
M+C,N,3`N-R`R,#`V+S`T+S$X(#$V.C(U.C,Q(&IA;B!%>'`@)`H@*@H@*B!4
M:&ES('-C<FEP="!R96UO=F5S(&$@<')E9B!F<F]M('5S97)S)R!S971T:6YG
M<RX@2&5L<',@=VAE;B!A('-E='1I;F<@:7,*("H@=&\@8F4@;6]V960@9G)O
M;2!L;V-K960@/2!F86QS92P@=&\@;&]C:V5D(#T@=')U92!A;F0@=&AE<F4@
M:&%V92!A;')E861Y"B`J(&)E96X@<')E9G,@<V5T(&)Y('1H92!U<V5R<RX*
M("HO"@HO*BH*("HJ(%-E="!T:&ES('1O('1R=64@:68@>6]U('=A;G0@1$(@
M;6]D:69I8V%T:6]N<R!D;VYE+@H@*BHO"B1L:79E(#T@9F%L<V4["@HO+R!.
M;R!A=71H+@I`9&5F:6YE*"=!551(7TA!3D1,15(G+"!T<G5E*3L*"B\O($9I
M;F0@=&AE(&)A<V4@9FEL92!P871H(&]F($AO<F1E+@I`9&5F:6YE*"=(3U)$
M15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["@HO+R!$;R!#
M3$D@8VAE8VMS(&%N9"!E;G9I<F]N;65N="!S971U<"!F:7)S="X*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]C;W)E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O0TQ)+G!H<"<["@HO+R!-86ME('-U<F4@;F\@;VYE(')U
M;G,@=&AI<R!F<F]M('1H92!W96(N"FEF("@A2&]R9&5?0TQ).CIR=6YN:6YG
M1G)O;4-,22@I*2!["B`@("!E>&ET*")-=7-T(&)E(')U;B!F<F]M('1H92!C
M;VUM86YD(&QI;F5<;B(I.PI]"@HO+R!,;V%D('1H92!#3$D@96YV:7)O;FUE
M;G0@+2!M86ME('-U<F4@=&AE<F4G<R!N;R!T:6UE(&QI;6ET+"!I;FET"B\O
M('-O;64@=F%R:6%B;&5S+"!E=&,N"DAO<F1E7T-,23HZ:6YI="@I.PHD8VQI
M(#T@)FYE=R!(;W)D95]#3$DH*3L*"G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4
M<F5E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH*+RH@36%K92!S=7)E('1H
M97)E)W,@;F\@8V]M<')E<W-I;VXN("HO"F]B7V5N9%]C;&5A;B@I.PH*"B1S
M8V]P92`]("1C;&DM/G!R;VUP="A?*")%;G1E<B!V86QU92!F;W(@<')E9E]S
M8V]P93HB*2D["B1N86UE(#T@)&-L:2T^<')O;7!T*%\H(D5N=&5R('9A;'5E
M(&9O<B!P<F5F7VYA;64Z(BDI.PH*+RH@3W!E;B!T:&4@9&%T86)A<V4N("HO
M"B1D8B`]("9$0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI.PII9B`H:7-?82@D
M9&(L("=014%27T5R<F]R)RDI('L*("`@=F%R7V1U;7`H)&1B*3L@97AI=#L*
M?0H*+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"G-W:71C:"`H)&1B
M+3YP:'!T>7!E*2!["F-A<V4@)VUS<W%L)SH*("`@("1D8BT^<V5T3W!T:6]N
M*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"
M7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*
M("`@(&)R96%K.PID969A=6QT.@H@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A
M8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"
M24Q)5%E?15)23U)3*3L*?0H*:68@*"1L:79E*2!["B`@("`D<W%L(#T@)T1%
M3$5412!&4D]-(&AO<F1E7W!R969S(%=(15)%('!R969?<V-O<&4@/2`_($%.
M1"!P<F5F7VYA;64@/2`_)SL*("`@("1V86QU97,@/2!A<G)A>2@D<V-O<&4L
M("1N86UE*3L*("`@("1R97-U;'0@/2`D9&(M/F=E=$%L;"@D<W%L+"`D=F%L
M=65S*3L*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("!V87)?9'5M<"@D<F5S=6QT*3L*("`@('T@96QS96EF("AE;7!T
M>2@D<F5S=6QT*2D@>PH@("`@("`@("1C;&DM/G=R:71E;&XH<W!R:6YT9BA?
M*").;R!P<F5F97)E;F-E(%PB)7-<(B!F;W5N9"!I;B!S8V]P92!<(B5S7"(N
M(BDL("1N86UE+"`D<V-O<&4I*3L*("`@('T@96QS92!["B`@("`@("`@)&-L
M:2T^=W)I=&5L;BAS<')I;G1F*%\H(E!R969E<F5N8V5S(%PB)7-<(B!D96QE
M=&5D(&EN('-C;W!E(%PB)7-<(BXB*2P@)&YA;64L("1S8V]P92DI.PH@("`@
M?0I](&5L<V4@>PH@("`@)'-Q;"`]("=314Q%0U0@*B!&4D]-(&AO<F1E7W!R
M969S(%=(15)%('!R969?<V-O<&4@/2`_($%.1"!P<F5F7VYA;64@/2`_)SL*
M("`@("1V86QU97,@/2!A<G)A>2@D<V-O<&4L("1N86UE*3L*("`@("1R97-U
M;'0@/2`D9&(M/F=E=$%L;"@D<W%L+"`D=F%L=65S*3L*("`@(&EF("AE;7!T
M>2@D<F5S=6QT*2D@>PH@("`@("`@("1C;&DM/G=R:71E;&XH<W!R:6YT9BA?
M*").;R!P<F5F97)E;F-E(%PB)7-<(B!F;W5N9"!I;B!S8V]P92!<(B5S7"(N
M(BDL("1N86UE+"`D<V-O<&4I*3L*("`@('T@96QS92!["B`@("`@("`@=F%R
M7V1U;7`H)')E<W5L="D["B`@("!]"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-E='5P+G!H<```````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0U-#0@
M,3`U,34T,S0Q-#,@,#(Q,3`U`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",A+W5S<B]L;V-A;"]P<V$O861M:6XO8FEN+W!H
M<`H\/W!H<`HO*BH*("H@5&AE(&UA:6X@2&]R9&4@<V5T=7`@<V-R:7!T('=H
M:6-H(&%L;&]W<R!F;W(@82!S=&5P(&)Y('-T97`@<V5T=7`*("H@;W(@<F5C
M;VYF:6=U<F%T:6]N(&]F(&$@2&]R9&4@:6YS=&%L;&%T:6]N+@H@*@H@*B`D
M2&]R9&4Z(&AO<F1E+W-C<FEP=',O<V5T=7`N<&AP+'8@,2XR-2XQ,"XQ,"`R
M,#`V+S`U+S$X(#$U.C0W.C,R(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!#:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!A=71H;W(@($-H87)L
M97,@2BX@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B\*"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I
M.PI`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8V]R92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T-,22YP:'`G.PH*)&-L:2`](&YE
M=R!(;W)D95]#3$DH*3L*"B\J($-H96-K(&9O<B!C;VYF:6<@9FEL97,N("HO
M"B1F:6QE<R`](&%R<F%Y*"=C;VYF+G!H<"<L"B`@("`@("`@("`@("`@("=M
M:6UE7V1R:79E<G,N<&AP)RP*("`@("`@("`@("`@("`@)VYL<RYP:'`G+`H@
M("`@("`@("`@("`@("`G<')E9G,N<&AP)RP*("`@("`@("`@("`@("`@)W)E
M9VES=')Y+G!H<"<I.PIF;W)E86-H("@D9FEL97,@87,@)&9I;&5N86UE*2![
M"B`@("`D9FEL92`]($A/4D1%7T)!4T4@+B`G+V-O;F9I9R\G("X@)&9I;&5N
M86UE.PH@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2D@>PH@("`@("`@(&-L
M:5]L;V<H<W!R:6YT9BA?*")&:6QE(%PB)7-<(B!I<R!A=F%I;&%B;&4N(BDL
M("1F:6QE;F%M92DL("=M97-S86=E)RD["B`@("`@("`@8V]N=&EN=64["B`@
M("!]"@H@("`@8VQI7VQO9RAS<')I;G1F*%\H(D9I;&4@7"(E<UPB(&ES(&UI
M<W-I;F<N(BDL("1F:6QE;F%M92DL("=W87)N:6YG)RD["@H@("`@)&1I<W1F
M:6QE(#T@)&9I;&4@+B`G+F1I<W0G.PH@("`@:68@*&9I;&5?97AI<W1S*"1D
M:7-T9FEL92DI('L*("`@("`@("`D8W)E871E7V-O;F9I9R`]("1C;&DM/G!R
M;VUP="AS<')I;G1F*%\H(D-R96%T92!<(B5S7"(@9G)O;2!D969A=6QT<R!N
M;W<_(BDL("1F:6QE;F%M92DL(&%R<F%Y*"=Y)R`]/B!?*")997,B*2P@)VXG
M(#T^(%\H(DYO(BDI*3L*("`@("`@("!I9B`H)&-R96%T95]C;VYF:6<@/3T@
M)WDG*2!["B`@("`@("`@("`@(&EF("@A8V]P>2@D9&ES=&9I;&4L("1F:6QE
M*2D@>PH@("`@("`@("`@("`@("`@)&-L:2T^9F%T86PH<W!R:6YT9BA?*")#
M;W!Y:6YG(%PB)3$D<RYD:7-T7"(@=&\@7"(E,21S7"(@9F%I;&5D+B!#:&5C
M:R!Y;W5R(&EN<W1A;&QA=&EO;BXB*2P@)&9I;&5N86UE*2D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8VQI7VQO9RAS<')I;G1F*%\H(D9I;&4@)7,@
M8W)E871E9"XB*2P@)&9I;&5N86UE*2P@)W-U8V-E<W,G*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D8VQI+3YF871A;"AS<')I;G1F*%\H(EEO
M=2!N965D('1H92!<(B5S7"(@9FEL92!T;R!C;VYT:6YU92!S971U<"!A;F0@
M=&\@=7-E($AO<F1E+B(I+"`D9FEL96YA;64I*3L*("`@("`@("!]"B`@("!]
M(&5L<V4@>PH@("`@("`@("1C;&DM/F9A=&%L*'-P<FEN=&8H7R@B0V%N;F]T
M(&9I;F0@7"(E<UPB+"!C:&5C:R!Y;W5R(&EN<W1A;&QA=&EO;BXB*2P@)&1I
M<W1F:6QE*2D["B`@("!]"GT*"F-L:5]L;V<H7R@B26YI=&EA;"!S971U<"!C
M;VUP;&5T960N($YO=R!C;VYT:6YU92!T:&4@<V5T=7`@=VET:"!Y;W5R(&)R
M;W=S97(L(&=O('1O.B!H='1P.B\O/%EO=7(@2&]R9&4@:6YS=&%L;"!54DP^
M+V%D;6EN+R(I+"`G<W5C8V5S<R<I.PIE>&ET.PH*+RHJ"B`J(%=R87`@=&AE
M(&UE<W-A9V5S('=I=&@@86X@:6YD96YT+"!N96%T97(@<V-R965N(&1I<W!L
M87DN"B`J+PIF=6YC=&EO;B!C;&E?;&]G*"1M97-S86=E+"`D='EP92`]("=M
M97-S86=E)RD*>PH@("`@)&UE<W-A9V4@/2!W;W)D=W)A<"@D;65S<V%G92P@
M-CDL(")<;B`@("`@("`@("`@(BD["B`@("`D1TQ/0D%,4ULG8VQI)UTM/FUE
M<W-A9V4H)&UE<W-A9V4L("=C;&DN)R`N("1T>7!E*3L*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W1E
M;7`M8VQE86YU<"YC<F]N````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#,P,#,@,3`U,34T,S0Q-#,@,#(R-#<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",A+V)I;B]S:`H*(R!4:&ES
M(&ES(&%N(&5X86UP;&4@8W)O;B!J;V(@<VAE;&P@<V-R:7!T('=H:6-H('=I
M;&P@8VQE86X@=7`@86YY"B,@=&5M<&]R87)Y(&9I;&5S('=H:6-H(&UA>2!G
M970@<W1R86YD960@8GD@2&]R9&4@=7-E<G,@:6X@=&AE"B,@=V5B<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X*(PHC(%EO=2!M87D@:&%V92!T;R!C
M:&%N9V4@+W1M<"!T;R!A;F]T:&5R(&QO8V%T:6]N(&1E<&5N9&EN9R!O;B!Y
M;W5R"B,@8V]N9FEG=7)A=&EO;BX@($]T:&5R(&UO9&EF:6-A=&EO;G,@;6%Y
M(&%L<V\@8F4@<F5Q=6ER960N"B,*(R!4:&ES('-C<FEP="!I<R!P<F]V:61E
M9"!A<RUI<R!A;F0@:7,@=&\@8F4@=7-E9"!A="!Y;W5R(&]W;B!R:7-K+B`*
M(R!(;W)D92!A;F0@=&AE(&%U=&AO<G,@86-C97!T(&YO(')E<W!O;G-I8FEL
M:71Y(&9O<B!A;GD@9&%M86=E<R!O<@HC(&QO<V5S(&-A=7-E9"!B>2!T:&ES
M('-C<FEP="!W:&5T:&5R(&EN9&ER96-T+"!I;F-I9&5N=&%L+"!O<@HC(&-O
M;G-E<75E;G1I86PL("!W:&5T:&5R(&]R(&YO="!S=6-H(&1A;6%G97,@8V]U
M;&0@8F4@9F]R<V5E;BX*(PHC($AO=R!T;R!U<V4@=&AI<R!S8W)I<'0@=VEL
M;"!D97!E;F0@;VX@>6]U<B!S>7-T96TN("!&;W(@<V]M92!S>7-T96US+`HC
M(&ET(&ES(&%S('-I;7!L>2!A<R!P=71T:6YG('1H:7,@9FEL92!I;B!T:&4@
M+V5T8R]C<F]N+F1A:6QY(&1I<F5C=&]R>2X*(R!&;W(@;W1H97)S+"!M;W)E
M(&]R(&1I9F9E<F5N="!S971U<"!W:6QL(&)E(')E<75I<F5D+B`@4V5E('1H
M90HC(&1O8W5M96YT871I;VX@9F]R('EO=7(@<WES=&5M<R!J;V(@<V-H961U
M;&5R(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@HC"@HC(%1H92!L;V-A=&EO;B!O
M9B!02%`G<R!T96UP;W)A<GD@9&ER96-T;W)Y"E1-4%]$25(]+W1M<`H*"B,@
M35-7;W)D(&%T=&%C:&UE;G1S("AG96YE<F%T960@8GD@=&AE($U3=V]R9"!V
M:65W97(I"F9O<B!-4U=/4D1?1DE,12!I;B!@9FEN9"`D5$U07T1)4B`M='EP
M92!F("UN86UE(&US=V]R9%PJ("UC=&EM92`K,B!@.R!D;PH)<FT@+68@)$U3
M5T]21%]&24Q%"F1O;F4*"B,@24U0(&%T=&%C:&UE;G1S"F9O<B!)35!?1DE,
M12!I;B!@9FEN9"`D5$U07T1)4B`M='EP92!F("UN86UE(&EM<&%T=%PJ("UC
M=&EM92`K,B!@.R!D;PH)<FT@+68@)$E-4%]&24Q%"F1O;F4*"B,@2VQU='H@
M=&5M<&]R87)Y(&9I;&5S"F9O<B!+3%546E]&24Q%(&EN(&!F:6YD("1435!?
M1$E2("UT>7!E(&8@+6YA;64@2VQU='I<*B`M8W1I;64@*S(@8#L@9&\*"7)M
M("UF("1+3%546E]&24Q%"F1O;F4*"B,@4W!E;&P@8VAE8VMI;F<@=&5M<&]R
M87)Y(&9I;&5S"F9O<B!34$5,3%]&24Q%(&EN(&!F:6YD("1435!?1$E2("UT
M>7!E(&8@+6YA;64@<W!E;&Q<*B`M8W1I;64@*S(@8#L@9&\*"7)M("UF("13
M4$5,3%]&24Q%"F1O;F4*"B,@5D93('1E;7!O<F%R>2!F:6QE<PIF;W(@24U0
M7T9)3$4@:6X@8&9I;F0@)%1-4%]$25(@+71Y<&4@9B`M;F%M92!V9G-<*B`M
M8W1I;64@*S(@8#L@9&\*"7)M("UF("1)35!?1DE,10ID;VYE"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S971?<&5R
M;7,N<V@`````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`S-C`Q(#$P-3$U-#,T,30S(#`R,34V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C(2]B:6XO<V@*(PHC('-E=%]P97)M
M<RYS:"`M($IO;B!087)I<V4@/&IO;D!C<V@N<FET+F5D=3X*(PHC("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]S971?<&5R;7,N<V@L=B`Q+C<@,C`P,2\P-"\Q
M-2`P,3HU-3HS,B!C:'5C:R!%>'`@)`H*(R`B1&%N9V5R;W5S(B!02%`@<V-R
M:7!T<PHC"D1!3D=%4D]54U]&24Q%4STB=&5S="YP:'`B"@HC($1E9F%U;'0@
M;F]N+7=E8B!S97)V97(@=7-E<B!W:&\@=VEL;"!O=VX@=&AE('1R964N"B,*
M3U=.15(]<F]O=`H*(R!);G1R;V1U8W1O<GD@=&5X=`HC"F-A="`\/"!%3T8*
M"E1H:7,@<V-R:7!T('=I;&P@<V5T('1H92!P97)M:7-S:6]N<R!O;B!Y;W5R
M($AO<F1E"G1R964@<V\@=&AA="!T:&4@9FEL97,@=VEL;"!B92!A8V-E<W-I
M8FQE(&)Y('1H92!W96(*<V5R=F5R+@H*66]U(&-A;B!C86YC96P@=&AI<R!S
M8W)I<'0@870@86YY('1I;64@=7-I;F<@0W1R;"U#+@H*14]&"@HC(%9E<FEF
M>2!T:&%T('=E)W)E(&%T('1H92!T;W`@;V8@=&AE($AO<F1E('1R964N"B,*
M<'=D"F5C:&\*96-H;R`M;B`B27,@=&AI<R!D:7)E8W1O<GD@=&AE('1O<"!O
M9B!Y;W5R($AO<F1E(&EN<W1A;&QA=&EO;C\@6WDL3ET@(@IR96%D(%)%4U!/
M3E-%(`II9B!;("(D4D534$].4T4B("$](")Y(B`M82`B)%)%4U!/3E-%(B`A
M/2`B62(@73L@=&AE;@H@("`@96-H;PH@("`@96-H;R`M;B`B16YT97(@>6]U
M<B!(;W)D92!D:7)E8W1O<GDZ("(*("`@(')E860@1$E2("`*"6EF(%L@(G@D
M1$E2(B`](")X(B!=.R!T:&5N"@D)96-H;R`B17AI=&EN9RXN+B(*"0EE>&ET
M"@EE;'-E"B`@("`)8V0@)$1)4@H)9FD*9FD*96-H;PH*(R!'970@=&AE('=E
M8B!S97)V97(G<R!G<F]U<"X*(PIE8VAO("UN(")5;F1E<B!W:&%T(&=R;W5P
M(&1O97,@=&AE('=E8B!P<F]C97-S(')U;C\@6VYO8F]D>5T@(@IR96%D(%=%
M0E]'4D]54`II9B!;(")X)%=%0E]'4D]54"(@/2`B>"(@73L@=&AE;@H@("`@
M5T5"7T=23U50/2)N;V)O9'DB(`IF:0H*(R!!<VL@8F5F;W)E('!R;V-E961I
M;F<N"B,*96-H;PIE8VAO("UN(")0<F]C965D('=I=&@@8VAA;F=I;F<@;W=N
M97)S:&EP(&%N9"!P97)M:7-S:6]N<S\@6WDL3ET@(@IR96%D(%)%4U!/3E-%
M(`II9B!;("(D4D534$].4T4B("$]("=Y)R`M82`B)%)%4U!/3E-%(B`A/2`G
M62<@73L@=&AE;@H@("`@96-H;R`B17AI=&EN9RXN+B(*("`@(&5X:70*9FD*
M"B,@4V5T('1H92!U<V5R(&%N9"!G<F]U<"!O=VYE<G-H:7`@<F5C=7)S:79E
M;'DN"B,*96-H;PIE8VAO("UN(")3971T:6YG(&]W;F5R<VAI<"!R96-U<G-I
M=F5L>2XN+B`B"F-H;W=N("U2("1/5TY%4B`N"F-H9W)P("U2("1714)?1U)/
M55`@+@IE8VAO(")D;VYE+B(*"B,@4V5T('1H92!P97)M:7-S:6]N<R!O;B!F
M:6QE<R`H,#8T,"D@86YD(&1I<F5C=&]R:65S("@P-S4P*2X*(PIE8VAO("UN
M(")3971T:6YG('!E<FUI<W-I;VYS(')E8W5R<VEV96QY+BXN("(*9FEN9"`N
M("UT>7!E(&8@+65X96,@8VAM;V0@,#8T,"![?2!<.PIF:6YD("X@+71Y<&4@
M9"`M97AE8R!C:&UO9"`P-S4P('M](%P["F5C:&\@(F1O;F4N(@H*(R!$:7-A
M8FQE(&%N>2`B9&%N9V5R;W5S(B!02%`@<V-R:7!T<R!I;B!T:&4@9&ES=')I
M8G5T:6]N("@P,#`P*2X*(PIE8VAO("UN(")$:7-A8FQI;F<@<&]T96YT:6%L
M;'D@7")D86YG97)O=7-<(B!02%`@<V-R:7!T<RXN+B`B"F9O<B!&24Q%(&EN
M("1$04Y'15)/55-?1DE,15,[(&1O"@EI9B!;("UF("1&24Q%(%T[('1H96X*
M"0EC:&UO9"`P,#`P("1&24Q%"@EF:0ID;VYE"F5C:&\@(F1O;F4N(@H*(R!3
M87D@9V]O9"UB>64N"B,*96-H;PIE8VAO("))9B!Y;W4@<F5C96EV960@86YY
M(&5R<F]R<RP@>6]U(&UA>2!N;W0@:&%V92!S=69F:6-I96YT(&%C8V5S<R(*
M96-H;R`B=&\@8VAA;F=E(&9I;&4@;W=N97)S:&EP(&%N9"!P97)M:7-S:6]N
M<RXB"F5C:&\*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O8W)E871E+7-Y;6QI
M;FMS+G!H<```````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S,V
M,B`Q,#4Q-30S-#$T,R`P,C,P-C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R$O=7-R+VQO8V%L+W!S82]A9&UI;B]B:6XO
M<&AP"CP_<&AP"B\J*@H@*B!4:&ES('-C<FEP="!C<F5A=&5S('-O9G1L:6YK
M<R!T;R!T:&4@;&EB<F%R>2!F:6QE<R!Y;W4@<F5T<FEE=F5D(&9R;VT*("H@
M=&AE($-64R`B9G)A;65W;W)K(B!M;V1U;&4N"B`J"B`J($ET(&-R96%T97,@
M=&AE('-A;64@9&ER96-T;W)Y('-T<G5C='5R92!T:&4@<&%C:V%G97,@=V]U
M;&0@:&%V92!I9B!T:&5Y"B`J('=E<F4@:6YS=&%L;&5D('=I=&@@(G!E87(@
M:6YS=&%L;"!P86-K86=E+GAM;"(N"B`J($9O<B!C<F5A=&EN9R!T:&ES('-T
M<G5C='5R92!I="!U<V5S('1H92!I;F9O<FUA=&EO;B!G:79E;B!I;B!T:&4*
M("H@<&%C:V%G92YX;6P@9FEL97,@:6YS:61E(&5A8V@@<&%C:V%G92!D:7)E
M8W1O<GDN"B`J"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]C<F5A=&4M<WEM
M;&EN:W,N<&AP+'8@,2XQ-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,CDZ,#D@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R(%=O;&9R86T@2W)I97-I;F<@
M/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@5V]L9G)A;2!+<FEE<VEN9R`\=V]L9G)A;4!K<FEE<VEN
M9RYD93X*("H@0&%U=&AO<B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@2&]R9&4@,RXP"B`J+PH*+R\@1FEN9"!T:&4@8F%S92!F
M:6QE('!A=&@@;V8@2&]R9&4N"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXG*3L*"B\O($-O;F9I9W5R871I;VXN"B\O
M($5N=&5R(&1I<F5C=&]R:65S('=I=&AO=70@=')A:6QI;F<@<VQA<VAE<RX*
M"B\O(%1H92!D:7)E8W1O<GD@=VET:"!T:&4@0U93(&-H96-K;W5T+@HD<W)C
M1&ER(#T@2$]21$5?0D%312`N("<O9G)A;65W;W)K)SL*"B\O(%1H92!D:7)E
M8W1O<GD@=VAE<F4@=&AE('-O9G1L:6YK<R!A<F4@8W)E871E9"X*+R\@5&AI
M<R!I<R!A;'-O('1H92!D:7)E8W1O<GD@=VAI8V@@>6]U('-H;W5L9"!P=70@
M:6X@>6]U<B!I;F-L=61E('!A=&@*+R\@869T97(@8W)E871I;F<@=&AE(&QI
M;FMS+@HD9&5S=$1I<B`]($A/4D1%7T)!4T4@+B`G+VQI8G,G.PH*)&-O<'D@
M/2!F86QS93L*"FEF("AI<W-E="@D87)G=BDI('L*("`@("\J($=E="!R:60@
M;V8@=&AE(&9I<G-T(&%R9R!W:&EC:"!I<R!T:&4@<V-R:7!T(&YA;64N("HO
M"B`@("!A<G)A>5]S:&EF="@D87)G=BD["B`@("!W:&EL92`H)&%R9R`](&%R
M<F%Y7W-H:69T*"1A<F=V*2D@>PH@("`@("`@(&EF("@D87)G(#T]("<M+6AE
M;'`G*2!["B`@("`@("`@("`@('!R:6YT7W5S86=E*"D["B`@("`@("`@?2!E
M;'-E:68@*"1A<F<@/3T@)RTM8V]P>2<I('L*("`@("`@("`@("`@)&-O<'D@
M/2!T<G5E.PH@("`@("`@('T@96QS96EF("AS=')S='(H)&%R9RP@)RTM<W)C
M)RDI('L*("`@("`@("`@("`@;&ES="@L)'-R8T1I<BD@/2!E>'!L;V1E*"<]
M)RP@)&%R9RD["B`@("`@("`@?2!E;'-E:68@*'-T<G-T<B@D87)G+"`G+2UD
M97-T)RDI('L*("`@("`@("`@("`@;&ES="@L)&1E<W1$:7(I(#T@97AP;&]D
M92@G/2<L("1A<F<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R
M:6YT7W5S86=E*")5;G)E8V]G;FES960@;W!T:6]N("1A<F<B*3L*("`@("`@
M("!]"B`@("!]"GT*"B\O($1O($-,22!C:&5C:W,@86YD(&5N=FER;VYM96YT
M('-E='5P(&9I<G-T+@IR97%U:7)E7V]N8V4@)'-R8T1I<B`N("<O0TQ)+T-,
M22YP:'`G.PH*+R\@36%K92!S=7)E(&YO(&]N92!R=6YS('1H:7,@9G)O;2!T
M:&4@=V5B+@II9B`H(4AO<F1E7T-,23HZ<G5N;FEN9T9R;VU#3$DH*2D@>PH@
M("`@97AI="@B375S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE7&XB
M*3L*?0H*+R\@3&]A9"!T:&4@0TQ)(&5N=FER;VYM96YT("T@;6%K92!S=7)E
M('1H97)E)W,@;F\@=&EM92!L:6UI="P@:6YI=`HO+R!S;VUE('9A<FEA8FQE
M<RP@971C+@I(;W)D95]#3$DZ.FEN:70H*3L*"D!I;F-L=61E7V]N8V4@)U1R
M964O5')E92YP:'`G.PII9B`H(6-L87-S7V5X:7-T<R@G5')E92<I*2!["B`@
M("!E>&ET*")9;W4@;F5E9"!T:&4@4$5!4B`G5')E92<@<&%C:V%G92!I;G-T
M86QL961<;B(I.PI]"@HD;&EN:V5R(#T@)FYE=R!,:6YK97(H)&-O<'DI.PII
M9B`H)&AA;F1L92`](&]P96YD:7(H)'-R8T1I<BDI('L*("`@('=H:6QE("@D
M9FEL92`](')E861D:7(H)&AA;F1L92DI('L*("`@("`@("!I9B`H)&9I;&4@
M(3T@)RXG("8F"B`@("`@("`@("`@("1F:6QE("$]("<N+B<@)B8*("`@("`@
M("`@("`@)&9I;&4@(3T@)T-64R<@)B8*("`@("`@("`@("`@:7-?9&ER*"(D
M<W)C1&ER+R1F:6QE(BDI('L*("`@("`@("`@("`@)&QI;FME<BT^<')O8V5S
M<R@B)'-R8T1I<B\D9FEL92(L("1D97-T1&ER*3L*("`@("`@("!]"B`@("!]
M"B`@("!C;&]S961I<B@D:&%N9&QE*3L*('T*"F5C:&\@(EQN(CL*"B\O("!P
M;W-S:6)L92!X;6PM<W1R=6-T<PHO+R`@/&9I;&5L:7-T/@HO+R`@("`@(#QD
M:7(@;F%M93TB+R(@8F%S96EN<W1A;&QD:7(](EA-3"(^"B\O("`@("`@("`@
M(#QF:6QE(')O;&4](G!H<"(^4&%R<V5R+G!H<#PO9FEL93X*+R\@("`@("`@
M("`@/&9I;&4@<F]L93TB<&AP(B!N86UE/2)24U,N<&AP(B`O/@HO+R`@("`@
M(#PO9&ER/@HO+R`@/"]F:6QE;&ES=#X*+R\*+R\@(#QF:6QE;&ES=#X*+R\@
M("`@("`\9FEL92!R;VQE/2)P:'`B(&)A<V5I;G-T86QL9&ER/2(O(CY$0BYP
M:'`\+V9I;&4^"B\O("`@("`@/&1I<B!N86UE/2)$0B(^"B\O("`@("`@("`@
M(#QF:6QE(')O;&4](G!H<"(^8V]M;6]N+G!H<#PO9FEL93X*+R\@("`@("`\
M+V1I<CX*+R\@(#PO9FEL96QI<W0^"F-L87-S($QI;FME<B!["@H@("`@=F%R
M("1?<W)C1&ER.PH*("`@('9A<B`D7V)A<V5);G-T86QL1&ER.PH*("`@('9A
M<B`D7V9I;&5R;VQE<R`](&%R<F%Y*"=P:'`G*3L*"B`@("!V87(@)%]R;VQE
M.PH*("`@('9A<B`D7V-O<'D["@H@("`@9G5N8W1I;VX@3&EN:V5R*"1C;W!Y
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;W!Y(#T@)&-O<'D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<')O8V5S<R@D<W)C1&ER+"`D9&5S=$1I
M<BD*("`@('L*("`@("`@("`D=&AI<RT^7W-R8T1I<B`]("1S<F-$:7(["B`@
M("`@("`@)'!A8VMA9V5&:6QE(#T@)'1H:7,M/E]S<F-$:7(@+B`G+W!A8VMA
M9V4N>&UL)SL*("`@("`@("`D8VQI(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N
M*"D["@H@("`@("`@(&EF("@A:7-?9FEL92@D<&%C:V%G949I;&4I*2!["B`@
M("`@("`@("`@("1C;&DM/FUE<W-A9V4H)TYO('!A8VMA9V4N>&UL(&EN("<@
M+B`D=&AI<RT^7W-R8T1I<BP@)V-L:2YW87)N:6YG)RD["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T<F5E(#T@5')E
M93HZ<V5T=7!-96UO<GDH)UA-3"<L("1P86-K86=E1FEL92D["B`@("`@("`@
M)'1R964M/G-E='5P*"D["@H@("`@("`@("\O(')E860@<&%C:V%G92!N86UE
M"B`@("`@("`@)'!A8VMA9V5.86UE(#T@=')I;2@D=')E92T^9V5T16QE;65N
M=$-O;G1E;G0H)R]P86-K86=E+VYA;64G+"`G8V1A=&$G*2D["B`@("`@("`@
M)&-L:2T^=W)I=&5L;B@B4')O8V5S<VEN9R!P86-K86=E("1P86-K86=E3F%M
M92XB*3L*"B`@("`@("`@+R\@;&]O:R!F;W(@9FEL96QI<W0@:6X@)R]P86-K
M86=E+W)E;&5A<V4O9FEL96QI<W0G"B`@("`@("`@)&9I;&5L:7-T(#T@)'1R
M964M/F=E=$5L96UE;G1">5!A=&@H)R]P86-K86=E+W)E;&5A<V4O9FEL96QI
M<W0G*3L*"B`@("`@("`@:68@*"1F:6QE;&ES="D@>PH@("`@("`@("`@("`O
M+R!D;R!T:&ES(&)E='1E<BP@;6%K92!T:&4@=')E92!C;&%S<R!W;W)K(&-A
M<V4@:6YS96YS:71I=F4*("`@("`@("`@("`@)&)A<V5);G-T86QL1&ER(#T@
M)&9I;&5L:7-T6R=C:&EL9"==6R=A='1R:6)U=&5S)UU;)V)A<V5I;G-T86QL
M9&ER)UT["@H@("`@("`@("`@("`D=&AI<RT^7V)A<V5);G-T86QL1&ER(#T@
M)&1E<W1$:7(["B`@("`@("`@("`@(&EF("@D8F%S94EN<W1A;&Q$:7(@(3T@
M)R\G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V)A<V5);G-T86QL1&ER
M("X]("<O)R`N("1B87-E26YS=&%L;$1I<CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7V)A<V5);G-T86QL1&ER(#T@<')E9U]R97!L86-E
M*"=\+RM\)RP@)R\G+"`D=&AI<RT^7V)A<V5);G-T86QL1&ER*3L*"B`@("`@
M("`@("`@(&EF("@A:7-?9&ER*"1T:&ES+3Y?8F%S94EN<W1A;&Q$:7(I*2![
M"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PH@
M("`@("`@("`@("`@("`@4WES=&5M.CIM:V1I<B@G+7`@)R`N("1T:&ES+3Y?
M8F%S94EN<W1A;&Q$:7(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M=&AI<RT^7VAA;F1L949I;&5L:7-T5&%G*"1F:6QE;&ES="D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&-L:2T^;65S<V%G92@G3F\@9FEL96QI
M<W0@=&%G(&9O=6YD(&EN<VED93H@)R`N("1P86-K86=E1FEL92P@)V-L:2YW
M87)N:6YG)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]H86YD
M;&5&:6QE;&ES=%1A9R@D96QE;65N="P@)&-U<D1I<B`]("<G*0H@("`@>PH@
M("`@("`@(&9O<F5A8V@@*"1E;&5M96YT6R=C:&EL9')E;B==(&%S("1C:&EL
M9"D@>PH@("`@("`@("`@("!S=VET8V@@*"1C:&EL9%LG;F%M92==*2!["B`@
M("`@("`@("`@(&-A<V4@)V9I;&4G.@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]H86YD;&5&:6QE5&%G*"1C:&EL9"P@)&-U<D1I<BD["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G9&ER)SH*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:&%N9&QE1&ER5&%G*"1C:&EL9"P@)&-U<D1I<BD[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@("1C;&D@/2`F2&]R9&5?0TQ).CIS:6YG;&5T;VXH
M*3L*("`@("`@("`@("`@("`@("1C;&DM/FUE<W-A9V4H)T=O="!N;R!H86YD
M;&5R(&9O<B!T86<Z("<@+B`D8VAI;&1;)VYA;64G72P@)V-L:2UW87)N:6YG
M)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("!]"@H@("`@9G5N8W1I;VX@7VAA;F1L941I<E1A9R@D96QE
M;65N="P@)&-U<D1I<BD*("`@('L*("`@("`@("!I9B`H)&5L96UE;G1;)V%T
M=')I8G5T97,G75LG;F%M92==("$]("<O)RD@>PH@("`@("`@("`@("!I9B`H
M<W5B<W1R*"1C=7)$:7(L("TQ*2`A/2`G+R<I('L*("`@("`@("`@("`@("`@
M("1C=7)$:7(@/2`D8W5R1&ER("X@)R\G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1C=7)$:7(@/2`D8W5R1&ER("X@)&5L96UE;G1;)V%T=')I8G5T
M97,G75LG;F%M92==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D
M96QE;65N=%LG871T<FEB=71E<R==6R=R;VQE)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<F]L92`]("1E;&5M96YT6R=A='1R:6)U=&5S)UU;)W)O;&4G
M73L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?9&ER*"1T:&ES+3Y?8F%S
M94EN<W1A;&Q$:7(@+B`D8W5R1&ER*2D@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U-Y<W1E;2YP:'`G.PH@("`@("`@("`@("!3>7-T96TZ.FUK9&ER
M*"<M<"`G("X@)'1H:7,M/E]B87-E26YS=&%L;$1I<B`N("1C=7)$:7(I.PH@
M("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]H86YD;&5&:6QE;&ES=%1A9R@D
M96QE;65N="P@)&-U<D1I<BD["B`@("!]"@H@("`@9G5N8W1I;VX@7VAA;F1L
M949I;&5486<H)&5L96UE;G0L("1D:7(I"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D96QE;65N=%LG871T<FEB=71E<R==6R=R;VQE)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<F]L92`]("1E;&5M96YT6R=A='1R:6)U=&5S)UU;
M)W)O;&4G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A:6Y?87)R87DH)'1H
M:7,M/E]R;VQE+"`D=&AI<RT^7V9I;&5R;VQE<RDI('L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D96QE;65N
M=%LG871T<FEB=71E<R==6R=N86UE)UTI*2!["B`@("`@("`@("`@("1F:6QE
M;F%M92`]("1E;&5M96YT6R=A='1R:6)U=&5S)UU;)VYA;64G73L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL96YA;64@/2`D96QE;65N=%LG
M8V1A=&$G73L*("`@("`@("!]"B`@("`@("`@)&9I;&5N86UE(#T@=')I;2@D
M9FEL96YA;64I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C;W!Y*2!["B`@("`@
M("`@("`@("1C;60@/2`B8W`@>R1T:&ES+3Y?<W)C1&ER?21D:7(O)&9I;&5N
M86UE('LD=&AI<RT^7V)A<V5);G-T86QL1&ER?21D:7(O)&9I;&5N86UE(CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R96YT(#T@)'1H:7,M
M/E]F:6YD0V]M;6]N4&%R96YT*"1T:&ES+3Y?<W)C1&ER("X@)&1I<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V)A<V5);G-T86QL1&ER("X@)&1I<BD["B`@("`@("`@("`@("1D
M:7)S(#T@<W5B<W1R7V-O=6YT*'-U8G-T<B@D=&AI<RT^7V)A<V5);G-T86QL
M1&ER("X@)&1I<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<FQE;B@D<&%R96YT*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<O)RD["B`@("`@("`@("`@("1S<F,@/2!S=')?<F5P
M96%T*"<N+B\G+"`D9&ER<RD@+@H@("`@("`@("`@("`@("`@<W5B<W1R*"1T
M:&ES+3Y?<W)C1&ER("X@)&1I<BP@<W1R;&5N*"1P87)E;G0I("L@,2D["B`@
M("`@("`@("`@("1C;60@/2`B;&X@+7-F("1S<F,O)&9I;&5N86UE('LD=&AI
M<RT^7V)A<V5);G-T86QL1&ER?21D:7(O)&9I;&5N86UE(CL*("`@("`@("!]
M"B`@("`@("`@97AE8R@D8VUD*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9FEN
M9$-O;6UO;E!A<F5N="@D82P@)&(I"B`@("!["B`@("`@("`@9F]R("@D8V]M
M;6]N(#T@)R<L("1L87-T<&]S(#T@,"P@)'!O<R`]('-T<G!O<R@D82P@)R\G
M+"`Q*3L*("`@("`@("`@("`@("1P;W,@(3T](&9A;'-E("8F('-T<G!O<R@D
M8BP@<W5B<W1R*"1A+"`P+"`D<&]S*2D@/3T](#`["B`@("`@("`@("`@("`D
M<&]S(#T@<W1R<&]S*"1A+"`G+R<L("1P;W,@*R`Q*2D@>PH@("`@("`@("`@
M("`D8V]M;6]N("X]('-U8G-T<B@D82P@)&QA<W1P;W,L("1P;W,@+2`D;&%S
M='!O<RD["B`@("`@("`@("`@("1L87-T<&]S(#T@)'!O<SL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1C;VUM;VX["B`@("!]"@I]"@IF=6YC=&EO;B!P
M<FEN=%]U<V%G92@D;65S<V%G92`]("<G*2!["@H@("`@:68@*"%E;7!T>2@D
M;65S<V%G92DI('L*("`@("`@("!P<FEN="`B8W)E871E+7-Y;6QI;FMS+G!H
M<#H@)&UE<W-A9V5<;EQN(CL*("`@('T*"B`@("!P<FEN="`\/#Q54T%'10I5
M<V%G93H@8W)E871E+7-Y;6QI;FMS+G!H<"!;3U!424].70H*4&]S<VEB;&4@
M;W!T:6]N<SH*("`M+6-O<'D@("`@("`@($1O(&YO="!C<F5A=&4@<WEM8F]L
M:6,@;&EN:W,L(&)U="!A8W1U86QL>2!C;W!Y('1H92!L:6)R87)I97,N"B`@
M+2US<F,]1$E2("`@("!4:&4@<V]U<F-E(&1I<F5C=&]R>2!F;W(@=&AE(&9R
M86UE=V]R:R!L:6)R87)I97,N"B`@+2UD97-T/41)4B`@("!4:&4@9&5S=&EN
M871I;VX@9&ER96-T;W)Y(&9O<B!T:&4@9G)A;65W;W)K(&QI8G)A<FEE<RX*
M"E5304=%.PH@("`@97AI=#L*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+V-O;VMI95]L;V=I;BYP:'``````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$V,3<@,3`U,34T,S0Q-#,@,#(R-#`Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O8V]O:VEE7VQO9VEN+G!H<"QV
M(#$N,BXR+C(@,C`P-B\P,2\P,2`R,3HR.3HP.2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#4M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=!551(7TA!3D1,15(G
M+"!T<G5E*3L*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG
M875T:"==6R=D<FEV97(G72D["@HO+R!#:&5C:R!F;W(@0T]/2TE%(&%U=&@N
M"FEF("AE;7!T>2@D7T-/3TM)15LG=7-E<B==*2!\?"!E;7!T>2@D7T-/3TM)
M15LG<&%S<W=O<F0G72D@?'P*("`@("$D875T:"T^875T:&5N=&EC871E*"1?
M0T]/2TE%6R=U<V5R)UTL(&%R<F%Y*"=P87-S=V]R9"<@/3X@)%]#3T]+245;
M)W!A<W-W;W)D)UTI*2D@>PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N($AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@G;&]G:6XN<&AP/VQO9V]U=%]R96%S;VX]
M)R`N($%55$A?4D5!4T].7T)!1$Q/1TE.+"!T<G5E*2D["B`@("!E>&ET.PI]
M"@HD=7)L(#T@571I;#HZ9V5T1F]R;41A=&$H)W5R;"<I.PII9B`H96UP='DH
M)'5R;"DI('L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)VEN
M9&5X+G!H<"<L('1R=64I.PI]"FAE861E<B@G3&]C871I;VXZ("<@+B`D=7)L
M*3L*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]S8W)I<'1S+U-#4DE05%,`````````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0T,C,@,3`U,34T,S0Q-#,@,#(P,C<W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B!(;W)D92!5=&EL:71Y(%-C<FEP=',*
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DEN=')O9'5C=&EO;@I^?GY^?GY^
M?GY^?GX*5&AI<R!D:7)E8W1O<GD@8V]N=&%I;G,@=F%R:6]U<R!U=&EL:71Y
M('-C<FEP=',@9F]R('1H92!(;W)D92!D:7-T<FEB=71I;VXN"E1H97D@87)E
M(&AE<F4@9F]R('EO=7(@8V]N=F5N:65N8V4N"@H*4V-R:7!T($EN9&5X"GY^
M?GY^?GY^?GY^?@IC;VUP87)E7W)E=FES:6]N<RYS:`H@("`@0V]M<&%R97,@
M9&EF9F5R96YT($-64R!R979I<VEO;G,@;V8@=&AE('-A;64@9FEL92X*"F-O
M;VMI95]L;V=I;BYP:'`*("`@($%L;&]W<R!T;R!L;V=I;B!W:71H('5S97(@
M8W)E9&5N=&EA;',@<')O=FED960@8GD@8V]O:VEE<RX*"F-R96%T92US>6UL
M:6YK<RYP:'`*("`@($-R96%T97,@<WEM8F]L:6,@;&EN:W,@;F5C97-S87)Y
M(&9O<B!D979E;&]P97)S('1O('=O<FL@9&ER96-T;'D@;VX@=&AE"B`@("!F
M:6QE<R!I;B!T:&4@9G)A;65W;W)K(&UO9'5L92!W:71H;W5T(&YE961I;F<@
M=&\@:6YS=&%L;"!T:&4@8VAA;F=E9`H@("`@<&%C:V%G97,N"@IC<F]N9`H@
M("`@=&)D"@IG971?;&]G:6XN<&AP"B`@("!!;&QO=W,@=&\@;&]G:6X@=VET
M:"!U<V5R(&-R961E;G1I86QS('!R;W9I9&5D(&)Y($=%5"!P87)A;65T97)S
M+@H*:&EG:&QI9VAT+G!H<`H@("`@2&EG:&QI9VAT<R!S;W5R8V4@9FEL97,@
M;VX@=&AE(&-O;G-O;&4N"@IH;W)D92UR<WEN8RYS:`H@("`@4&5R9F]R;7,@
M82!C:&5C:V]U="!O9B!T:&4@;&%T97-T($AO<F1E(&-V<R!S;W5R8V5S('5S
M:6YG(')S>6YC+@H*:'1T<%]L;V=I;E]R969E<BYP:'`*("`@('1B9`H*;6%K
M92US;F%P<RYP:'`*("`@('1B9`H*;6%K92UR96QE87-E+G!H<`H@("`@0G5I
M;&1S(&1I<W1R:6)U=&EO;B!T87)B86QL<R!F;W(@2&]R9&4@86YD($AO<F1E
M(&UO9'5L97,N"@IM97)G92YP:'`*("`@($UE<F=E<R!C;VUM:71S(&9R;VT@
M82!C;VUM:70@;65S<V%G92!I;G1O('1H92!#5E,@=')E92!O9B!T:&4@8W5R
M<F5N=`H@("`@9&ER96-T;W)Y+@H*;6EG<F%T95]C871E9V]R:65S+G!H<`H@
M("`@36EG<F%T97,@;VQD(&-A=&5G;W)I97,@=&\@=&AE(&YE=R!H;W)D95]C
M871E9V]R>5]A='1R:6)U=&5S('1A8FQE+@H*;6EG<F%T95]L:6YK<RYP:'`*
M("`@($UI9W)A=&5S(&]L9"!(;W)D95],:6YK<R!T;R!T:&4@:&]R9&5?8V%T
M96=O<GE?871T<FEB=71E<R!T86)L92X*"G!A8VMA9V4N9'1D"B`@("!4:&4@
M4$5!4B!P86-K86=E(&1E<V-R:7!T:6]N+@H*<G!C+71E<W0N<&AP"B`@("!0
M<F]V:61E<R!T97-T<R!F;W(@=&AE(%)00R!C;&EE;G0@86=A:6YS="!S979E
M<F%L("AI;F-L=61I;F<@;W5R(&]W;BD@4E!#"B`@("!S97)V97)S+@H*<V5T
M7W!E<FUS+G-H"B`@("!3971S(&9I;&4@;W=N97)S:&EP(&%N9"!P97)M:7-S
M:6]N<R!O;B!T:&4@2&]R9&4@=')E92!F;W(@:&EG:"!S96-U<FET>2X*"G-E
M='5P+G!H<`H@("`@5&AE(&UA:6X@2&]R9&4@<V5T=7`@<V-R:7!T('=H:6-H
M(&%L;&]W<R!F;W(@82!S=&5P(&)Y('-T97`@<V5T=7`@;W(*("`@(')E8V]N
M9FEG=7)A=&EO;B!O9B!A($AO<F1E(&EN<W1A;&QA=&EO;BX*"G1E;7`M8VQE
M86YU<"YC<F]N"B`@("!!;B!E>&%M<&QE(&-R;VX@:F]B('-H96QL('-C<FEP
M="!W:&EC:"!W:6QL(&-L96%N('5P(&%N>2!T96UP;W)A<GD@9FEL97,*("`@
M('=H:6-H(&UA>2!G970@<W1R86YD960@8GD@2&]R9&4@=7-E<G,@:6X@=&AE
M('=E8B!S97)V97(G<R!T96UP;W)A<GD*("`@(&1I<F5C=&]R>2X*"G5P9&%T
M95]H;W)D92YS:`H@("`@1F%C:6QI=&%T97,@=&AE('5P9&%T:6YG(&%N9"]O
M<B!I;G-T86QL871I;VX@;V8@:&]R9&4@86YD(&ET<PH@("`@87!P;&EC871I
M;VYS+@H*;6EM95]M87!P:6YG+PH@("`@5&AI<R!S8W)I<'0@8V]N=F5R=',@
M86X@07!A8VAE+7-T>6QE(&UI;64N='EP97,@9FEL92!I;G1O(&$*("`@(&UI
M;64N;6%P<&EN9RYP:'`@9')I=F5R(&9I;&4@<W5I=&%B;&4@9F]R('5S92!W
M:71H($AO<F1E+B`@270@:7,@=7-E9G5L"B`@("!F;W(@<WEN8VEN9R!!<&%C
M:&4@=7!D871E<R!T;R!T:&5I<B!-24U%('1Y<&5S('=I=&@@2&]R9&4N"@H*
M1&%T86)A<V4@4V-R:7!T<PI^?GY^?GY^?GY^?GY^?GY^"D1A=&%B87-E('1A
M8FQE('-C:&5M87,@86YD(&%S<V]C:6%T960@=71I;&ET>2!S8W)I<'1S(&%R
M92!L;V-A=&5D(&EN('1H92!S<6PO"G-U8F1I<F5C=&]R>2X*"@I,1$%0(%-C
M:&5M87,*?GY^?GY^?GY^?GY^"DQ$05`@<V-H96UA<R!A<F4@;&]C871E9"!I
M;B!T:&4@;&1A<"\@<W5B9&ER96-T;W)Y+@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+V=E=%]L;V=I;BYP:'``````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$S-S4@,3`U,34T
M,S0Q-#,@,#(Q-S$P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M9V5T7VQO9VEN+G!H<"QV(#$N,RXQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,#D@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F]E;"!686YD
M86P@/&IV86YD86Q`:6YF;W1E8VLN<6,N8V$^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*
M"D!D969I;F4H)T%55$A?2$%.1$Q%4B<L('1R=64I.PI`9&5F:6YE*"=(3U)$
M15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?
M;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PH*)&%U=&@@/2`F
M075T:#HZ<VEN9VQE=&]N*"1C;VYF6R=A=71H)UU;)V1R:79E<B==*3L*"B\O
M($-H96-K(&9O<B!'150@875T:"X*:68@*&5M<'1Y*"1?1T546R=U<V5R)UTI
M('Q\("$D875T:"T^875T:&5N=&EC871E*"1?1T546R=U<V5R)UTL(&%R<F%Y
M*"=P87-S=V]R9"<@/3X@)%]'151;)W!A<W,G72DI*2!["B`@("!H96%D97(H
M)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=L;V=I;BYP
M:'`_;&]G;W5T7W)E87-O;CUL;V=O=70G*2D["B`@("!E>&ET.PI]"@IH96%D
M97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=I;F1E
M>"YP:'`G*2D["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N;V-I
M."YS<6P`````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,Q,#4@
M,3`U,34T,S0Q-#,@,#(R-C0V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'-E="!D;V,@;V9F.PIS970@<W%L8FQA;FML:6YE
M<R!O;CL*"B\J*@H@*B!/<F%C;&4@5&%B;&4@0W)E871I;VX@4V-R:7!T<RX*
M("H@"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+F]C:3@N
M<W%L+'8@,2XT+C@N,3`@,C`P-B\P-B\R.2`Q-CHR.3HP,R!J86X@17AP("0*
M("H@"B`J($!A=71H;W(@36EG=65L(%=A<F0@/&UW87)D0&%L=6%R+F-O;2YA
M<CX*("H@"B`J(%1H:7,@<W%L(&-R96%T97,@=&AE($AO<F1E(%-13"!T86)L
M97,@:6X@86X@3W)A8VQE(#@N>"!D871A8F%S92X@4VAO=6QD"B`J('=O<FL@
M=VET:"!/<F%C;&4@.2YX("AA;F0@3W)A8VQE-R!U<VEN9R!V87)C:&%R,BDN
M"B`J(`H@*B!.;W1E<SH*("H@"B`J("`J($]B=FEO=7-L>2!Y;W4@;75S="!H
M879E($]R86-L92!I;G-T86QL960@;VX@=&AI<R!M86-H:6YE($%.1"!Y;W4@
M;75S=`H@*B`@("!H879E(&-O;7!I;&5D(%!(4"!W:71H($]R86-L92`H>6]U
M(&EN8VQU9&5D("TM=VET:"UO8VDX+6EN<W1A;G0*("H@("`@+2UW:71H+6]C
M:3@@;W(@:6X@=&AE(&)U:6QD(&%R9W5M96YT<R!F;W(@4$A0+"!O<B!U;F-O
M;6UE;G1E9"!T:&4@;V-I.`H@*B`@("!E>'1E;G-I;VX@:6X@<&AP+FEN:2DN
M"B`J(`H@*B`@*B!)9B!Y;W4@9&]N)W0@=7-E('1H92!);G-T86YT($-L:65N
M="P@;6%K92!S=7)E('1H870@=&AE('5S97(@=&AA="!S=&%R=',*("H@("`@
M=7`@07!A8VAE("AU<W5A;&QY(&YO8F]D>2!O<B!W=W<M9&%T82D@:&%S('1H
M92!F;VQL;W=I;F<@96YV:7)O;FUE;G0*("H@("`@=F%R:6%B;&5S(&1E9FEN
M960Z"B`J(`H@*B`@("!E>'!O<G0@3U)!0TQ%7TA/344]+VAO;64O;W)A8VQE
M+T]R84AO;64Q"B`J("`@(&5X<&]R="!/4D%?3DQ3/2]H;VUE+V]R86-L92]/
M<F%(;VUE,2]O8V]M;6]N+VYL<R]A9&UI;B]D871A"B`J("`@(&5X<&]R="!/
M4D%?3DQ3,S,]+VAO;64O;W)A8VQE+T]R84AO;64Q+V]C;VUM;VXO;FQS+V%D
M;6EN+V1A=&$*("H@("`@97AP;W)T($Q$7TQ)0E)!4EE?4$%42#TD3U)!0TQ%
M7TA/344O;&EB.B1,1%],24)205)97U!!5$@*("H@"B`J("`@(%E/52!-55-4
M($-54U1/34E:12!42$5312!604Q515,@5$\@0D4@05!04D]04DE!5$4@5$\@
M64]54B!)3E-404Q,051)3TX*("H@"B`J("`@(%EO=2!C86X@:6YC;'5D92!T
M:&5S92!V87)I86)L97,@:6X@=&AE('5S97(G<R!L;V-A;"`N<')O9FEL92!O
M<B!I;@H@*B`@("`O971C+W!R;V9I;&4L(&5T8RX*("H@"B`J("`J($YO(&=R
M86YT<R!A<F4@;F5C97-S87)Y('-I;F-E('=E(&-O;FYE8W0@87,@=&AE(&]W
M;F5R(&]F('1H92!T86)L97,N($EF"B`J("`@('EO=2!W:7-H('EO=2!C86X@
M861A<'0@=&AE(&-R96%T:6]N(&]F('1A8FQE<R!T;R!I;F-L=61E('1A8FQE
M<W!A8V4@86YD"B`J("`@('-T;W)A9V4@:6YF;W)M871I;VXN(%-I;F-E('=E
M(&EN8VQU9&4@;F]N92!I="!W:6QL('5S92!T:&4@9&5F875L=`H@*B`@("!T
M86)L97-P86-E('9A;'5E<R!F;W(@=&AE('5S97(@8W)E871I;F<@=&AE<V4@
M=&%B;&5S+B!386UE('=I=&@@=&AE"B`J("`@(&EN9&5X97,@*&EN('1H96]R
M>2!T:&5S92!S:&]U;&0@=7-E(&$@9&EF9F5R96YT('1A8FQE<W!A8V4I+@H@
M*B`*("H@("H@5&AE<F4@:7,@;F\@;F5E9"!T;R!S:'5T(&1O=VX@86YD('-T
M87)T('5P('1H92!D871A8F%S92$*("HO"@IR96T@8V]N;B!H;W)D92\F:&]R
M9&5?<&%S<W=O<F1`9&%T86)A<V4*"B\J*@H@*B!4:&ES(&ES('1H92!(;W)D
M92!U<V5R<R!T86)L92P@;F5E9&5D(&]N;'D@:68@>6]U(&%R92!U<VEN9R!3
M44P*("H@875T:&5N=&EC871I;VXN("!.;W1E('1H870@<&%S<V]W<F1S(&EN
M('1H:7,@=&%B;&4@;F5E9"!T;R!B92!M9#4M96YC;V1E9"X*("HO"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?=7-E<G,@*`H@("`@=7-E<E]U:60@("`@("`@("`@
M("`@("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W!A
M<W,@("`@("`@("`@("`@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*
M("`@('5S97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@("!.54U"15(H,38I+`H@
M("`@=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92`@($Y534)%4B@Q-BDL"@H@
M("`@4%))34%262!+15D@*'5S97)?=6ED*0HI.PH*"B\J*@H@*B!4:&ES(&ES
M('1H92!(;W)D92!P<F5F97)E;F-E<R!T86)L92P@:&]L9&EN9R!A;&P@;V8@
M=&AE('5S97(M<W!E8VEF:6,*("H@;W!T:6]N<R!F;W(@979E<GD@2&]R9&4@
M=7-E<BX*("H@"B`J('!R969?=6ED("`@:7,@=&AE('5S97)N86UE+@H@*B!P
M<F5F7W-C;W!E(&ES('1H92!A<'!L:6-A=&EO;B!T:&4@<')E9B!B96QO;F=S
M('1O+@H@*B!P<F5F7VYA;64@(&ES('1H92!N86UE(&]F('1H92!V87)I86)L
M92!T;R!S879E+@H@*B!P<F5F7W9A;'5E(&ES('1H92!V86QU92!S879E9"`H
M8V%N(&)E('9E<GD@;&]N9RDN"B`J(`H@*B!792!U<V4@82!#3$]"(&-O;'5M
M;B!S;R!T:&%T(&QO;F=E<B!C;VQU;6X@=F%L=65S(&%R92!S=7!P;W)T960N
M"B`J(`H@*B!)9B!S=&EL;"!U<VEN9R!/<F%C;&4@-R!T:&ES('-H;W5L9"!W
M;W)K(&)U="!Y;W4@:&%V92!T;R!U<V4*("H@5D%20TA!4C(H,C`P,"D@=VAI
M8V@@:7,@=&AE(&QI;6ET(&EM<&]S960@8GD@<V%I9"!V97)S:6]N+@H@*B\*
M"D-214%412!404),12!H;W)D95]P<F5F<R`H"B`@("!P<F5F7W5I9"`@("!6
M05)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@<')E9E]S8V]P92`@5D%20TA!
M4C(H,38I($Y/5"!.54Q,+`H@("`@<')E9E]N86UE("`@5D%20TA!4C(H,S(I
M($Y/5"!.54Q,+`HM+2`@4V5E(&%B;W9E(&YO=&5S(&]N($-,3T)S+@H@("`@
M<')E9E]V86QU92`@0TQ/0BP*"B`@("!04DE-05)9($M%62`H<')E9E]U:60L
M('!R969?<V-O<&4L('!R969?;F%M92D**3L*"D-214%412!)3D1%6"!P<F5F
M7W5I9%]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?=6ED*3L*0U)%051%($E.
M1$58('!R969?<V-O<&5?:61X($].(&AO<F1E7W!R969S("AP<F5F7W-C;W!E
M*3L*"@HO*BH*("H@5&AE($1A=&%4<F5E('1A8FQE<R!A<F4@=7-E9"!F;W(@
M:&]L9&EN9R!H:65R87)C:&EC86P@9&%T82!S=6-H(&%S($=R;W5P<RP*("H@
M4&5R;6ES<VEO;G,L(&%N9"!D871A(&9O<B!S;VUE($AO<F1E(&%P<&QI8V%T
M:6]N<RX*("HO"@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@
M9&%T871R965?:60@("`@("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@
M(&=R;W5P7W5I9"`@("`@("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL
M"B`@("!U<V5R7W5I9"`@("`@("`@("`@("!605)#2$%2,B@R-34I+`H@("`@
M9&%T871R965?;F%M92`@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*
M("`@(&1A=&%T<F5E7W!A<F5N=',@("`@(%9!4D-(05(R*#(U-2DL"B`@("!D
M871A=')E95]O<F1E<B`@("`@("!.54U"15(H,38I+`H@("`@9&%T871R965?
M9&%T82`@("`@("`@0TQ/0BP*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@($Y5
M34)%4B@X*2!$149!54Q4(#`@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@
M*&1A=&%T<F5E7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T
M<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D
M871A=')E92`H9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S
M97)?:61X($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)
M3D1%6"!D871A=')E95]O<F1E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A
M=&%T<F5E7V]R9&5R*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ
M961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D
M*3L*"D-214%412!404),12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*
M("`@(&1A=&%T<F5E7VED("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@
M(&%T=')I8G5T95]N86UE("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@
M(&%T=')I8G5T95]K97D@("`@5D%20TA!4C(H,C4U*2P*("`@(&%T=')I8G5T
M95]V86QU92`@5D%20TA!4C(H-#`P,"D**3L*"D-214%412!)3D1%6"!D871A
M=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I
M8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA
M='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U
M=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R
M:6)U=&5?:V5Y*3L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K96YS("@*("`@
M('1O:V5N7V%D9')E<W,@("`@5D%20TA!4C(H,3`P*2!.3U0@3E5,3"P*("`@
M('1O:V5N7VED("`@("`@("`@5D%20TA!4C(H,S(I($Y/5"!.54Q,+`H@("`@
M=&]K96Y?=&EM97-T86UP("!.54U"15(H,38I($Y/5"!.54Q,+`H*("`@(%!2
M24U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*"@I#4D5!
M5$4@5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"`@("`@("`@3E5-0D52
M*#$V*2!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@("`@3E5-0D52*#@I($Y/
M5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!605)#2$%2,B@R-34I+`H@("`@
M=F9S7VYA;64@("`@("!605)#2$%2,B@R-34I($Y/5"!.54Q,+`H@("`@=F9S
M7VUO9&EF:65D("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R
M("`@("!605)#2$%2,B@R-34I+`H@("`@=F9S7V1A=&$@("`@("!"3$]"+`H*
M("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D**3L*"D-214%412!)3D1%6"!V
M9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D["D-214%412!)
M3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?=F9S("AV9G-?;F%M92D["@H*
M0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED
M("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@
M("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V%C=&EO
M;B`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@
M("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@
M0TQ/0BP*("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4C(H,C4U*2P*("`@
M(&AI<W1O<GE?97AT<F$@("`@0TQ/0BP*"B`@("!04DE-05)9($M%62`H:&ES
M=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@
M3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-214%412!)
M3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O
M<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO<F1E
M7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@H*0U)%051%(%1!0DQ%(&AO<F1E
M7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@("`@("`@("`@("`@
M5D%20TA!4C(H,S(I($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I
M960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@
M($),3T(L"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I"BD["@H*97AI
M=`H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YM>7-Q;"YS
M<6P`````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C,P-R`Q,#4Q
M-30S-#$T,R`P,C,Q-30`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]C<F5A
M=&4N;7ES<6PN<W%L+'8@,2XT+C8N.2`R,#`V+S`W+S`U(#$U.C4S.C$P(&IA
M;B!%>'`@)`HM+0HM+2!)9B!Y;W4@87)E(&EN<W1A;&QI;F<@2&]R9&4@9F]R
M('1H92!F:7)S="!T:6UE+"!Y;W4@8V%N('-I;7!L>0HM+2!D:7)E8W0@=&AI
M<R!F:6QE('1O(&UY<W%L(&%S(%-41$E..@HM+0HM+2`D(&UY<W%L("TM=7-E
M<CUR;V]T("TM<&%S<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O<F0^(#P@8W)E
M871E+FUY<W%L+G-Q;`HM+0HM+2!)9B!Y;W4@87)E('5P9W)A9&EN9R!F<F]M
M(&$@<')E=FEO=7,@=F5R<VEO;BP@>6]U('=I;&P@;F5E9"!T;R!C;VUM96YT
M"BTM(&]U="!T:&4@=&AE('5S97(@8W)E871I;VX@<W1E<',@8F5L;W<L(&%S
M('=E;&P@87,@=&AE('-C:&5M87,@9F]R(&%N>0HM+2!T86)L97,@=&AA="!A
M;')E861Y(&5X:7-T+@HM+0HM+2!)9B!Y;W4@8VAO;W-E('1O(&=R86YT('!E
M<FUI<W-I;VYS(&UA;G5A;&QY+"!N;W1E('1H870@=VET:"!->5-13"P@4$5!
M4B!$0@HM+2!E;75L871E<R!S97%U96YC97,@8GD@875T;VUA=&EC86QL>2!C
M<F5A=&EN9R!E>'1R82!T86)L97,@96YD:6YG(&EN(%]S97$L"BTM('-O('1H
M92!->5-13"`B:&]R9&4B('5S97(@;75S="!H879E($-214%412!P<FEV:6QE
M9V4@;VX@=&AE(")H;W)D92(*+2T@9&%T86)A<V4N"BTM"BTM($EF('EO=2!A
M<F4@=7!G<F%D:6YG(&9R;VT@2&]R9&4@,2YX+"!T:&4@2&]R9&4@=&%B;&5S
M('EO=2!H879E(&9R;VT*+2T@=&AA="!V97)S:6]N(&%R92!N;R!L;VYG97(@
M=7-E9#L@>6]U(&UA>2!W:7-H('1O(&5I=&AE<B!D96QE=&4@=&AO<V4*+2T@
M=&%B;&5S(&]R('-I;7!L>2!R96-R96%T92!T:&4@9&%T86)A<V4@86YE=RX*
M"E5312!M>7-Q;#L*"E)%4$Q!0T4@24Y43R!U<V5R("AH;W-T+"!U<V5R+"!P
M87-S=V]R9"D*("`@(%9!3%5%4R`H"B`@("`@("`@)VQO8V%L:&]S="<L"B`@
M("`@("`@)VAO<F1E)RP*"5!!4U-73U)$*"=`5T5"34%)3%]005-35T]21$`G
M*0HI.PH*4D503$%#12!)3E1/(&1B("AH;W-T+"!D8BP@=7-E<BP@<V5L96-T
M7W!R:78L(&EN<V5R=%]P<FEV+"!U<&1A=&5?<')I=BP*("`@("`@("`@("`@
M("`@("!D96QE=&5?<')I=BP@8W)E871E7W!R:78L(&1R;W!?<')I=BP@:6YD
M97A?<')I=BD*("`@(%9!3%5%4R`H"B`@("`@("`@)VQO8V%L:&]S="<L"B`@
M("`@("`@)VAO<F1E)RP*("`@("`@("`G:&]R9&4G+`H@("`@("`@("=9)RP@
M)UDG+"`G62<L("=9)RP*("`@("`@("`G62<L("=9)RP@)UDG"BD["@HM+2!-
M86ME('-U<F4@=&AA="!P<FEV:6QI9V5S(&%R92!R96QO861E9"X*1DQ54T@@
M4%))5DE,14=%4SL*"BTM($UY4U%,(#,N,C,N>"!A<'!E87)S('1O(&AA=F4@
M(D-214%412!$051!0D%312!)1B!.3U0@15A)4U13(B!A;F0*+2T@(D-214%4
M12!404),12!)1B!.3U0@15A)4U13(B!W:&EC:"!W;W5L9"!B92!A(&YI8V4@
M=V%Y('1O(&AA;F1L90HM+2!R96EN<W1A;&QS(&=R86-E9G5L;'D@*'-O;65D
M87DI+B`@1F]R(&YO=RP@9')O<"!T:&4@9&%T86)A<V4*+2T@;6%N=6%L;'D@
M=&\@879O:60@0U)%051%(&5R<F]R<RX*0U)%051%($1!5$%"05-%(&AO<F1E
M.PH*55-%(&AO<F1E.PH*0U)%051%(%1!0DQ%(&AO<F1E7W5S97)S("@*("`@
M('5S97)?=6ED("`@("`@("`@("`@("`@("`@("!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!U<V5R7W!A<W,@("`@("`@("`@("`@("`@("`@5D%20TA!
M4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]S;V9T7V5X<&ER871I;VY?9&%T
M92`@($E.5"P*("`@('5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4@("!)3E0L
M"@H@("`@4%))34%262!+15D@*'5S97)?=6ED*0HI.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W5S97)S(%1/(&AO
M<F1E0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]P<F5F<R`H"B`@
M("!P<F5F7W5I9"`@("`@("`@5D%20TA!4B@R,#`I($Y/5"!.54Q,+`H@("`@
M<')E9E]S8V]P92`@("`@(%9!4D-(05(H,38I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"B`@("!P<F5F7VYA;64@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL
M"B`@("!P<F5F7W9A;'5E("`@("`@3$].1U1%6%0@3E5,3"P*"B`@("!04DE-
M05)9($M%62`H<')E9E]U:60L('!R969?<V-O<&4L('!R969?;F%M92D**3L*
M"D-214%412!)3D1%6"!P<F5F7W5I9%]I9'@@3TX@:&]R9&5?<')E9G,@*'!R
M969?=6ED*3L*0U)%051%($E.1$58('!R969?<V-O<&5?:61X($].(&AO<F1E
M7W!R969S("AP<F5F7W-C;W!E*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!5
M4$1!5$4L($1%3$5412!/3B!H;W)D95]P<F5F<R!43R!H;W)D94!L;V-A;&AO
M<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@("`@9&%T
M871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@("`@9W)O=7!?=6ED(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@("`@('5S97)?=6ED(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?<&%R96YT<R!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("`@("!D871A=')E95]O<F1E<B!)3E0L"B`@("`@
M("!D871A=')E95]D871A(%1%6%0L"B`@("`@("!D871A=')E95]S97)I86QI
M>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*"B`@("`@("!04DE-
M05)9($M%62`H9&%T871R965?:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R
M965?9&%T871R965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T
M<F5E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T
M871R965?=7-E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*
M0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"D-214%412!404),
M12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED
M($E.5"!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I($1%
M1D%53%0@)R<@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI
M.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R
M9&5?9&%T871R965?871T<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!5$4@
M24Y$15@@9&%T871R965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%($E.
M1$58(&1A=&%T<F5E7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A=&%T
M<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]K97DI.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E(%1/
M(&AO<F1E0&QO8V%L:&]S=#L*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@5$\@:&]R
M9&5`;&]C86QH;W-T.PH*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@
M("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(H,3`P*2!.3U0@3E5,3"P*("`@
M('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!T
M;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*"B`@("!04DE-05)9
M($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD["@I'4D%.5"!314Q%
M0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=&]K96YS(%1/
M(&AO<F1E0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]V9G,@*`H@
M("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?='EP
M92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4($Y/
M5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`H*("`@(%!224U!4ED@
M2T59("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].
M(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?
M:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W9F<R!43R!H;W)D94!L
M;V-A;&AO<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@
M(&AI<W1O<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J96-T
M7W5I9"`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T;W)Y
M7V%C=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]T
M<R`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@("`@
M(%1%6%0L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@
M(&AI<W1O<GE?97AT<F$@("`@5$585"P*"B`@("!04DE-05)9($M%62`H:&ES
M=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO;E]I9'@@
M3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD["D-214%412!)
M3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O
M<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X($].(&AO<F1E
M7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?:&ES=&]R:65S(%1/(&AO<F1E
M0&QO8V%L:&]S=#L*"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE
M<B`H"B`@("!S97-S:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/
M5"!.54Q,+`H@("`@<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y5
M3$PL"B`@("!S97-S:6]N7V1A=&$@("`@("`@("`@($Q/3D="3$]"+`H*("`@
M(%!224U!4ED@2T59("AS97-S:6]N7VED*0HI($5.1TE.12`]($EN;F]$0CL*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]S97-S:6]N:&%N9&QE<B!43R!H;W)D94!L;V-A;&AO<W0["@I&3%532"!0
M4DE624Q%1T53.PH*+2T@1&]N92$*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-Q;```````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#8U,"`Q,#4Q-30S-#$T,R`P,C0W-#4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2T@)$AO<F1E
M.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS<6PL
M=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%051%
M(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@
M("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N
M7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T
M82`@("`@("`@("`@3$].1T),3T(L"BTM($]R+"!O;B!S;VUE($1"35,@<WES
M=&5M<SH*+2T@('-E<W-I;VY?9&%T82`@("`@("`@("`@24U!1T4L"@H@("`@
M4%))34%262!+15D@*'-E<W-I;VY?:60I"BD["@I'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<V5S<VEO;FAA;F1L97(@
M5$\@:&]R9&4["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]C
M<F5A=&4N;7-D92YS<6P`````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#8T,3`@,3`U,34T,S0Q-#,@,#(R-S,U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]S<6PO8W)E871E+FUS9&4N<W%L+'8@,2XQ+C(N-2`R,#`V+S`V+S(Y
M(#$V.C(Y.C`R(&IA;B!%>'`@)`H*55-%(&UA<W1E<@I'3PH*0U)%051%($1!
M5$%"05-%(&AO<F1E"D=/"@I%6$5#('-P7V%D9&QO9VEN("=H;W)D92<L("=H
M;W)D95]M9W(G+"`G:&]R9&4G"D=/"@I54T4@:&]R9&4*1T\*"D5814,@<W!?
M9W)A;G1D8F%C8V5S<R`G:&]R9&4G"D=/"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M=7-E<G,@*`H@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@
M("`@=7-E<E]P87-S(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*"B`@("!04DE-
M05)9($M%62`H=7-E<E]U:60I"BD*1T\*"D=204Y4(%-%3$5#5"P@24Y315)4
M+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]U<V5R<R!43R!H;W)D90I'3PH*
M0U)%051%(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R969?=6ED(%9!4D-(
M05(H,C`P*2!.3U0@3E5,3"P*("`@('!R969?<V-O<&4@5D%20TA!4B@Q-BD@
M3D]4($Y53$P@1$5&055,5"`G)RP*("`@('!R969?;F%M92!605)#2$%2*#,R
M*2!.3U0@3E5,3"P*("`@('!R969?=F%L=64@5$585"!.54Q,+`H*("`@(%!2
M24U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E9E]N86UE*0HI
M"D=/"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:&]R9&5?<')E9G,@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!P<F5F7W5I
M9%]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?=6ED*0I#4D5!5$4@24Y$15@@
M<')E9E]S8V]P95]I9'@@3TX@:&]R9&5?<')E9G,@*'!R969?<V-O<&4I"D=/
M"@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@9&%T871R965?
M:60@24Y4($Y/5"!.54Q,+`H@("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@('5S97)?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@(&1A=&%T<F5E7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M9&%T871R965?<&%R96YT<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D
M871A=')E95]O<F1E<B!)3E0L"B`@("!D871A=')E95]D871A(%1%6%0L"B`@
M("!D871A=')E95]S97)I86QI>F5D(%--04Q,24Y4($1%1D%53%0@,"!.3U0@
M3E5,3"P*"B`@("!04DE-05)9($M%62`H9&%T871R965?:60I"BD*1T\*"D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D
M871A=')E92!43R!H;W)D90I'3PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A
M=&%T<F5E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N
M86UE*0I#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AG<F]U<%]U:60I"D-214%412!)3D1%6"!D871A=')E95]U
M<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U:60I"D-214%412!)
M3D1%6"!D871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E
M92`H9&%T871R965?<V5R:6%L:7IE9"D*1T\*"D-214%412!404),12!H;W)D
M95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.
M3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I($1%1D%53%0@
M)R<@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI"D=/"@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M9&%T871R964@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!D871A=')E95]A
M='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&1A
M=&%T<F5E7VED*0I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VYA
M;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T
M95]N86UE*0I#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VME>5]I
M9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E7VME
M>2D*1T\*"D-214%412!404),12!H;W)D95]T;VME;G,@*`H@("`@=&]K96Y?
M861D<F5S<R!605)#2$%2*#$P,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"!6
M05)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('1O:V5N7W1I;65S=&%M<"!"24=)
M3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N7V%D9')E<W,L
M('1O:V5N7VED*0HI"D=/"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?=&]K96YS(%1/(&AO<F1E"D=/"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"!"24=)3E0@3D]4($Y53$PL
M"B`@("!V9G-?='EP92!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P871H
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M=F9S7V1A=&$@5$585"P*"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD*
M1T\*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H
M;W)D95]V9G,@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!V9G-?<&%T:%]I
M9'@@3TX@:&]R9&5?=F9S("AV9G-?<&%T:"D*0U)%051%($E.1$58('9F<U]N
M86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*0I'3PH*0U)%051%(%1!
M0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))
M1TE.5"!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R
M*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.
M54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!415A4+`H@("`@:&ES=&]R>5]W
M:&\@("`@("!605)#2$%2*#(U-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%
M6%0L"@H@("`@4%))34%262!+15D@*&AI<W1O<GE?:60I"BD*1T\*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T
M;W)I97,@5$\@:&]R9&4*1T\*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C=&EO
M;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD*0U)%
M051%($E.1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H
M:&ES=&]R>5]T<RD*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H
M;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U:60I"D=/"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO
M4D5!1$U%````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$R-34S(#$P-3$U-#,T,30S(#`R,#<P-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&%T86)A<V4@26YS=&%L;&%T:6]N
M($=U:61E"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ
M3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#4O,3`O,3@@,3$Z,S0Z,#`@)`HZ
M4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C(N,3`N,R`D"CI#;VYT86-T
M.B`@("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"@I0=7)P;W-E(&]F('1H
M:7,@9FEL90I^?GY^?GY^?GY^?GY^?GY^?GY^?@H*5&AI<R!F:6QE('=I;&P@
M:&]P969U;&QY(&5A<V4@=&AE(&EN<W1A;&QA=&EO;B!A;F0@8V]N9FEG=7)A
M=&EO;B!O9B!Y;W5R"F1A=&%B87-E(&9O<B!U<V4@=VET:"!(;W)D92X@(%1H
M92!S8V]P92!O9B!T:&4@9&]C=6UE;G0@9&5A;',@<')I;6%R:6QY('=I=&@*
M=7-I;F<@>6]U<B!D871A8F%S92!W:71H($AO<F1E(&%N9"!S:&]U;&0@;F]T
M(&)E(&-O;G-I9&5R960@82!R97-O=7)C92!F;W(*9V5N97)A;"!D871A8F%S
M92!T87-K<RX*"@I297%U:7)E;65N=',@9F]R($AO<F1E"GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GX*"DAO<F1E(&-U<G)E;G1L>2!S=7!P;W)T<R!A="!L96%S
M="`W(&1A=&%B87-E<SH*"B`@("`M($UY4U%,("`@("`@("`@:'1T<#HO+W=W
M=RYM>7-Q;"YC;VTO"B`@("`M(%!O<W1G<F5344P@("`@:'1T<#HO+W=W=RYP
M;W-T9W)E<W%L+F]R9R\*("`@("T@3W)A8VQE("`@("`@("!H='1P.B\O=W=W
M+F]R86-L92YC;VTO"B`@("`M(%-Y8F%S92`@("`@("`@:'1T<#HO+W=W=RYS
M>6)A<V4N8V]M+PH@("`@+2!344QI=&4@("`@("`@(&AT='`Z+R]W=W<N<W%L
M:71E+F]R9R\*("`@("T@35,@4U%,("`@("`@("!H='1P.B\O=W=W+FUI8W)O
M<V]F="YC;VTO<W%L+PH@("`@+2!-4T1%("`@("`@("`@(&AT='`Z+R]W=W<N
M;6EC<F]S;V9T+F-O;2]S<6PO;7-D92\*"DUY4U%,(&%N9"!0;W-T9W)E4U%,
M(&%R92!R96=U;&%R;'D@=7-E9"!B>2!T:&4@9&5V96QO<&UE;G0@=&5A;2P@
M86YD('=I;&P@=V]R:PIW:71H(&YO('!R;V)L96US+B`@3W)A8VQE(&%N9"!3
M44QI=&4@<W5P<&]R="!H87,@8F5E;B!M=6-H(&EM<')O=F5D(')E8V5N=&QY
M"F%N9"!W;W)K<R!F:6YE('1O;RX@(%-Y8F%S92!W97)E(')E<&]R=&5D('=O
M<FMI;F<@:6X@=&AE('!R979I;W5S('9E<G-I;VX@;V8*2&]R9&4O24U0(&)Y
M('-O;64@;V8@;W5R('5S97)S+"!A;F0@87)E(&%S<W5M960@=&\@<W1I;&P@
M=V]R:RXN+B!B=70@=&AA=`IH87-N)W0@8F5E;B!V97)I9FEE9"!R96-E;G1L
M>2X*"@I"969O<F4@66]U($)E9VEN"GY^?GY^?GY^?GY^?GY^?GX*"EEO=2!W
M:6QL(&YE960@=&\@:&%V92!Y;W5R(&1A=&%B87-E('!R96-O;F9I9W5R960@
M86YD('=O<FMI;F<@;VX@>6]U<B!S>7-T96T*8F5F;W)E('EO=2!E=F5N(&=E
M="!T;R!T:&ES('-T86=E+B`@1F]R(&AE;'`@=VET:"!T:&ES+"!P;&5A<V4@
M8V]N<W5L="!Y;W5R"F1A=&%B87-E('-P96-I9FEC(&AE;'`@9FEL97,N"@I"
M969O<F4@=7-I;F<@86YY(&]F('1H92!S8W)I<'1S(&QI<W1E9"!B96QO=RP@
M<&QE87-E(&QO;VL@;W9E<B!T:&5M('1O(&5N<W5R90IT:&%T(&%N>2!S>7-T
M96TM<W!E8VEF:6,@<V5T=&EN9W,@*&]R('!E<G-O;F%L(&-H;VEC97,I(&%R
M92!S970@=&\@>6]U<@ID97-I<F5D('-E='1I;F=S("AE9RX@8&!U<V5R;F%M
M96!@+"!E=&,N*2X*"BHJ4$Q%05-%($Y/5$4J*B!T:&%T('1H92!D871A8F%S
M92!C;VYF:6=U<F%T:6]N('-T97!S(&QI<W1E9"!B96QO=R`J*DU54U0J*@IM
M871C:"!W:&%T(&ES(&-O;F9I9W5R960@=VET:&EN($AO<F1E+@H*4W!E8VEF
M:6-A;&QY+"!I9B!Y;W4@8VAA;F=E('1H92!D871A8F%S92!N86UE+"!U<V5R
M+"!O<B!P87-S=V]R9"!W:&EL90IC;VYF:6=U<FEN9R!T:&4@9&%T86)A<V4@
M*&)E;&]W*2P@>6]U('=I;&P@;F5E9"!T;R!M86ME('1H92!S86UE(&-H86YG
M97,@=&\*>6]U<B!(;W)D92!C;VYF:6=U<F%T:6]N(&9I;&5S(&%S('=E;&PN
M"@H*37E344P*?GY^?GX*"E1H92!M>7-Q;%]C<F5A=&4N<W%L('-C<FEP="!W
M:6QL(&-R96%T92!A(&1A=&%B87-E(&-A;&QE9"!@8&AO<F1E8&`L(&%N9"!A
M"G5S97(@8V%L;&5D(&!@:&]R9&5@8"`H=VET:"!P87-S=V]R9"!@8&AO<F1E
M8&`I('1H870@:&%S(&9U;&P@<FEG:'1S('1O('1H90ID871A8F%S92X@("I.
M;W1E('1H870@=VET:"!->5-13"P@4$5!4B!$0B!E;75L871E<R!S97%U96YC
M97,@8GD@875T;VUA=&EC86QL>0IC<F5A=&EN9R!E>'1R82!T86)L97,@96YD
M:6YG(&EN(%]S97$L('-O('1H92!->5-13"!@8&AO<F1E8&`@=7-E<B!M=7-T
M(&AA=F4*8&!#4D5!5$5@8"!P<FEV:6QE9V4@;VX@=&AE(&!@:&]R9&5@8"!D
M871A8F%S92X*"E1H:7,@<V-R:7!T(&YE961S('1O(&)E(')U;B!A<R!T:&4@
M37E344P@<F]O="!U<V5R("AW:&EC:"!I<R`J3D]4*B!T:&4@<V%M92!A<PIT
M:&4@54Y)6"],:6YU>"!R;V]T('5S97(I.CH*"B`@)"!M>7-Q;"`M+75S97(]
M<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W9#X@/"!C<F5A=&4N
M;7ES<6PN<W%L"@I!9G1E<B!R=6YN:6YG('1H:7,@<V-R:7!T+"!I="=S(&$@
M9V]O9"!I9&5A('1O(')E<W1A<G0@>6]U<B!->5-13"!S97)V97(Z.@H*("`D
M(&UY<W%L861M:6X@+2UU<V5R/7)O;W0@+2UP87-S=V]R9#T\37E344PM<F]O
M="UP87-S=V0^(')E;&]A9`H*5&\@8VAE8VL@=&AA="!T:&ES(&ES('=O<FMI
M;F<L('1H92!F;VQL;W=I;F<@8V]M;6%N9"!S:&]U;&0@8V]N;F5C="!W:71H
M;W5T"F5R<F]R<SHZ"@H@("0@;7ES<6P@+2UU<V5R/6AO<F1E("TM<&%S<W=O
M<F0]:&]R9&4@:&]R9&4*"E1Y<&4@8&!Q=6ET8&`@=&\@<75I="!->5-13"X*
M"@I0;W-T9W)E4U%,"GY^?GY^?GY^?GX*"B`@(R!S=2`M('!O<W1G<F5S("`H
M;W(@=VAA=&5V97(@>6]U<B!D871A8F%S92!R=6YS(&%S+BXN('5S=6%L;'D@
M<&]S=&=R97,I"B`@)"!P<W%L("UD('1E;7!L871E,2`M9B!C<F5A=&4N<&=S
M<6PN<W%L"@I4:&ES('-C<FEP="!W:6QL(&-R96%T92!A(&!@:&]R9&5@8"!D
M871A8F%S92!A;F0@82!@8&AO<F1E8&`@=7-E<BX@(%EO=2!S:&]U;&0*<V5T
M(&$@<&%S<W=O<F0@9F]R('1H:7,@=7-E<B!W:71H('1H:7,@8V]M;6%N9"`H
M:68@>6]U(&1I9&XG="!U;F-O;6UE;G0@=&AE"F]N92!I;B!P9W-Q;%]C<F5A
M=&4N<W%L*3HZ"@H@("0@<'-Q;"`M<6,@(D%,5$52(%5315(@:&]R9&4@5TE4
M2"!005-35T]21"`G<&%S<R<[(B!T96UP;&%T93$@<&]S=&=R97,*"E1H96X@
M8W)E871E('1H92!T86)L97,@=VET:&EN('1H92!@8&AO<F1E8&`@9&%T86)A
M<V4Z.@H*("`D('!S<6P@+60@:&]R9&4@+68@:&]R9&5?=7-E<G,N<W%L"B`@
M)"!P<W%L("UD(&AO<F1E("UF(&AO<F1E7W!R969S+G-Q;`H@("0@<'-Q;"`M
M9"!H;W)D92`M9B!H;W)D95]D871A=')E92YS<6P*"E1H97-E('-C<FEP=',@
M=VEL;"!A;'-O(&=R86YT('1H92!@8&AO<F1E8&`@=7-E<B!T:&4@;F5C97-S
M87)Y('!R:79I;&5G97,@=&\*96%C:"!O9B!T:&4@=&%B;&5S+@H*"D]R86-L
M90I^?GY^?GX*"E)U;B!@8'-Q;'!L=7-@8"X@($QO9VEN+"!T:&5N(%MW92!N
M965D(&EN<W1R=6-T:6]N<R!F;W(@8W)E871I;F<@=&AE(&1A=&%B87-E"F%N
M9"!U<V5R(&AE<F5=+@H*5&AA="!S:&]U;&0@8F4@:70N("!297-T87)T($]R
M86-L92!J=7-T('1O(&)E('-U<F4L(&%N9"!T<GD@:70N("!4:&5N(&-R96%T
M90IT:&4@=&%B;&5S('=I=&AI;B!T:&4@8&!H;W)D96!@(&1A=&%B87-E.CH*
M"EM!;'-O(&YE960@=&AO<V4@:6YS=')U8W1I;VYS(&AE<F4N70H*"E-Y8F%S
M90I^?GY^?GX*"E1O(&-R96%T92!T:&4@9&%T86)A<V4L(&9R;VT@8&!I<W%L
M8&`@<G5N.CH*"B`@8W)E871E(&1A=&%B87-E(&AO<F1E"@I.97AT+"!Y;W4@
M<VAO=6QD("AR96-O;6UE;F1E9"D@8W)E871E(&$@;&]G:6X@=&\@=7-E('=I
M=&@@=&AI<R!D871A8F%S92X@(%1H90I@8&ES<6Q@8"!C;VUM86YD(&9O<B!T
M:&ES(&ES.CH*"B`@<W!?861D;&]G:6X@/'5S97)N86UE/B`\<&%S<W=O<F0^
M"@I.97AT('EO=2!N965D('1O(&-H86YG92!T:&4@;W=N97)S:&EP(&]F('1H
M92!D871A8F%S92!T;R!T:&ES(&YE=R!U<V5R+B`@5&AE"F!@:7-Q;&!@(&-O
M;6UA;F0@9F]R('1H:7,@:7,Z.@H*("!S<%]C:&%N9V5D8F]W;F5R(#QU<V5R
M;F%M93X*"D%F=&5R('1H870L('EO=2!J=7-T(&YE960@=&\@<V5T('5P('EO
M=7(@=&%B;&5S('=I=&AI;B!T:&4@9&%T86)A<V4N("!4;R!D;PIT:&%T+"!J
M=7-T(')U;B!T:&ES(&-O;6UA;F0@9G)O;2!T:&4@8V]M;6%N9"!L:6YE.CH*
M"B`@:7-Q;"`M:2!H;W)D95]U<V5R<RYS<6P@+54\=7-E<FYA;64^("U0/'!A
M<W-W;W)D/@H@(&ES<6P@+6D@:&]R9&5?<')E9G,N<W%L("U5/'5S97)N86UE
M/B`M4#QP87-S=V]R9#X*"@I-4T1%(#(P,#`@*&%N9"!P;W-S:6)L>2!-4R!3
M44P@4V5R=F5R*0I^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?@H*5&\@8W)E871E('5S97(@86YD(&1A=&%B87-E+"!U<V4@=&AE(&]S
M<6P@8V]M;6%N9#HZ"@H@($,Z7#YO<W%L("U5('-A("U0(&%D;6EN7W!A<W-W
M;W)D("U3(&QO8V%L:&]S="`M:2!C<F5A=&4N;7-D92YS<6P*"D)E('-U<F4@
M=&\@8VAA;F=E('1H92!P87-S=V]R9"!F;W(@=&AE(&AO<F1E('5S97(@:6X@
M=&AE('-C<FEP="!F:6QE+B`@5&\*<W!E8VEF>2!A('!A<G1I8W5L87(@:6YS
M=&%N8V4@;V8@=&AE(%-13"!S97)V97(@=7-E('1H90H\<V5R=F5R;F%M93XO
M/&EN<W1A;F-E/B!F;W(@=&AE("U3(&9L86<N("!)9B!Y;W4@87)E;B=T('5S
M:6YG(&UI>&5D(%-13`IA=71H96YT:6-A=&EO;BP@=&AE;B!Y;W4G;&P@;F5E
M9"!T;R!M;V1I9GD@=&AE('-C<FEP="!T;R!A<W-O8VEA=&4@=&AE(&AO<F1E
M"G5S97(@=VET:"!A('=I;F1O=W,@=7-E<B!A8V-O=6YT(&%N9"!R=6X@=&AE
M('-C<FEP="!I;B!T:&4@9F]L;&]W:6YG(&UA;FYE<B!A<PIT:&4@061M:6YI
M<W1R871O<CHZ"@H@($,Z7#YO<W%L("U%("U3(&QO8V%L:&]S="`M:2!C<F5A
M=&4N;7-D92YS<6P*"DEF('EO=2=R92!H879I;F<@<')O8FQE;7,@<G5N;FEN
M9R!T:&ES('-C<FEP="!O;B!A(%-13"!S97)V97(@;VX@=&AE(&YE='=O<FLL
M"F)E('-U<F4@=&AE('-E<G9E<B!I<R!S970@=7`@=&\@86QL;W<@;F5T=V]R
M:R!A8V-E<W,N"@H*061D:71I;VYA;"!.;W1E<PI^?GY^?GY^?GY^?GY^?GY^
M"@I4:&ES(&ES(&)Y(&9A<B!N;W0@82!C;VUP;&5T92!(3U=43RX@(%1H:7,@
M:7,@:G5S="!A(&-O;7!I;&5D(&QI<W0@;V8@=VAA=`IP96]P;&4@:&%V92!C
M;VYT<FEB=71E9"!S;R!F87(N("!)9B!Y;W4@:&%V92!T:7!S+"!I9&5A<RP@
M<W5G9V5S=&EO;G,@;W(*86YY=&AI;F<@96QS92!T:&%T('EO=2!T:&EN:R!C
M;W5L9"!H96QP(&]T:&5R<R!I;B!S971T:6YG('5P('1H96ER(&1A=&%B87-E
M"F9O<B!U<V4@=VET:"!(;W)D92P@<&QE87-E(&QE="!U<R!K;F]W+@H*/&1E
M=D!L:7-T<RYH;W)D92YO<F<^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO<V-R:7!T+FEN:71I86Q?:&]R9&5?
M=7-E<BYS<6P``````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-3,S(#$P-3$U-#,T,30S
M(#`R-3<Q-@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+W-C<FEP="YI;FET
M:6%L7VAO<F1E7W5S97(N<W%L+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@
M8VAU8VL@17AP("0*+2T*+2T@5&AI<R!S8W)I<'0@=VEL;"!C<F5A=&4@86X@
M:6YI=&EA;"!U<V5R(&EN(&$@:&]R9&5?=7-E<G,@=&%B;&4N(%1H90HM+2!P
M87-S=V]R9"!B96EN9R!U<V5D(&ES("=A9&UI;B<L('=H:6-H('EO=2!S:&]U
M;&0@8VAA;F=E"BTM($E-345$24%414Q9+@H*24Y315)4($E.5$\@:&]R9&5?
M=7-E<G,@*'5S97)?=6ED+"!U<V5R7W!A<W,I(%9!3%5%4R`H)V%D;6EN)RP@
M)S(Q,C,R9C(Y-V$U-V$U83<T,S@Y-&$P931A.#`Q9F,S)RD["@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7VAI<W1O<FEE<RYM<W-Q;"YS<6P`````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3(V,B`Q,#4Q-30S-#$T,R`P,C4P-S,`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]H:7-T;W)I97,N;7-S<6PN
M<W%L+'8@,2XQ+C(N,2`R,#`V+S`Q+S$X(#$Y.C4X.C0R(&)E;B!%>'`@)`H*
M0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE<R`H"B`@("!H:7-T;W)Y7VED
M("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@(&]B:F5C=%]U:60@("`@("`@
M5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]A8W1I;VX@("!6
M05)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?=',@("`@("`@0DE'
M24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D97-C("`@("!605)#2$%2*$U!
M6"DL"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*("`@(&AI
M<W1O<GE?97AT<F$@("`@5D%20TA!4BA-05@I+`HM+0H@("`@4%))34%262!+
M15D@*&AI<W1O<GE?:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I
M;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#
M4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S
M("AH:7-T;W)Y7W1S*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/
M3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4
M+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!4
M3R!H;W)D93L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YS<6P`````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S0V-R`Q,#4Q-30S-#$T,R`P,C(P
M,C,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<W%L+'8@,2XQ
M+C(N,R`R,#`V+S`U+S(R(#(Q.C(W.C,S(&IA;B!%>'`@)`H*0U)%051%(%1!
M0DQ%(&AO<F1E7W5S97)S("@*("`@('5S97)?=6ED("`@("`@("`@("`@("`@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W!A<W,@("`@
M("`@("`@("`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E
M<E]S;V9T7V5X<&ER871I;VY?9&%T92`@($E.5$5'15(L"B`@("!U<V5R7VAA
M<F1?97AP:7)A=&EO;E]D871E("`@24Y414=%4BP*+2T*("`@(%!224U!4ED@
M2T59("AU<V5R7W5I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!
M5$4L($1%3$5412!/3B!H;W)D95]U<V5R<R!43R!H;W)D93L*"@I#4D5!5$4@
M5$%"3$4@:&]R9&5?<')E9G,@*`H@("`@<')E9E]U:60@("`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('!R969?<V-O<&4@("`@("!605)#2$%2
M*#$V*2!$149!54Q4("<G($Y/5"!.54Q,+`H@("`@<')E9E]N86UE("`@("`@
M(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@<')E9E]V86QU92`@("`@(%1%
M6%0L"BTM"B`@("!04DE-05)9($M%62`H<')E9E]U:60L('!R969?<V-O<&4L
M('!R969?;F%M92D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L
M($1%3$5412!/3B!H;W)D95]P<F5F<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"
M3$4@:&]R9&5?9&%T871R964@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.
M54Q,+`H@("`@9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@
M('5S97)?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E
M7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?<&%R
M96YT<R!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]O<F1E
M<B!)3E0L"@HM+2!4:&5R92!I<R!N;R!P;W)T86)L92!W87D@=&\@9&\@=&AI
M<R!A<'!A<F5N=&QY+B!)9B!Y;W5R(&1B(&1O97-N)W0*+2T@86QL;W<@5$58
M5"!C;VQU;6YS+"!T:&5N(&UA>6)E(&ET(&%L;&]W<R!L87)G92!605)#2$%2
M(&-O;'5M;G,L('-O"BTM('1R>2!T:&4@<V5C;VYD(&QI;F4N"BTM"B`@("!D
M871A=')E95]D871A(%1%6%0L"BTM("!D871A=')E95]D871A(%9!4D-(05(H
M-#`Y-BDL"@H@("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.5"!$149!
M54Q4(#`@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED
M*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X
M($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.
M1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O
M=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E
M95]O<F1E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7V]R9&5R
M*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"D-214%412!4
M04),12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E
M7VED($E.5"!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I
M+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0**3L*"D-214%412!)3D1%6"!D
M871A=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T
M=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M("AA='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A='1R
M:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA
M='1R:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L
M($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D93L*1U)!3E0@4T5,
M14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E
M7V%T=')I8G5T97,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7W1O
M:V5N<R`H"B`@("!T;VME;E]A9&1R97-S("`@(%9!4D-(05(H,3`P*2!.3U0@
M3E5,3"P*("`@('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!T;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*+2T*
M("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME;E]I9"D**3L*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]T;VME;G,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H
M"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T
M>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@
M3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"P*("`@('9F<U]D871A("`@("`@3$].1T),3T(L"BTM($]R+"!O;B!S
M;VUE($1"35,@<WES=&5M<SH*+2T@('9F<U]D871A("`@("`@24U!1T4L"B`@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S
M7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$
M15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!
M3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W9F
M<R!43R!H;W)D93L*"@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*
M("`@(&AI<W1O<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@;V)J
M96-T7W5I9"`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!H:7-T
M;W)Y7V%C=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@:&ES=&]R
M>5]T<R`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y7V1E<V,@
M("`@(%1%6%0L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H,C4U*2P*
M("`@(&AI<W1O<GE?97AT<F$@("`@5$585"P*+2T*("`@(%!224U!4ED@2T59
M("AH:7-T;W)Y7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?86-T:6]N
M7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N*3L*0U)%
M051%($E.1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H
M:&ES=&]R>5]T<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I9'@@3TX@
M:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%3$5#5"P@
M24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I97,@5$\@
M:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*
M("`@('-E<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@3$].1T),3T(L"BTM($]R+"!O
M;B!S;VUE($1"35,@<WES=&5M<SH*+2T@('-E<W-I;VY?9&%T82`@("`@("`@
M("`@24U!1T4L"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I"BD["@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4["@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YX
M;6P`````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S,U
M-2`Q,#4Q-30S-#$T,R`P,C(P,C$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN
M9STB25-/+3@X-3DM,2(@/SX*/&1A=&%B87-E/@H*(#QN86UE/CQV87)I86)L
M93YN86UE/"]V87)I86)L93X\+VYA;64^"B`\8W)E871E/CQV87)I86)L93YC
M<F5A=&4\+W9A<FEA8FQE/CPO8W)E871E/@H*(#QT86)L93X*"B`@/&YA;64^
M:&]R9&5?9&%T871R964\+VYA;64^"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF
M:65L9#X*("`@(#QN86UE/F1A=&%T<F5E7VED/"]N86UE/@H@("`@/'1Y<&4^
M:6YT96=E<CPO='EP93X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@
M(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YG<F]U<%]U:60\+VYA
M;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE
M;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^
M"@H@("`\9FEE;&0^"B`@("`\;F%M93YU<V5R7W5I9#PO;F%M93X*("`@(#QT
M>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H/C(U-3PO;&5N9W1H/@H@("`@
M/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L
M9#X*("`@(#QN86UE/F1A=&%T<F5E7VYA;64\+VYA;64^"B`@("`\='EP93YT
M97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N
M=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@
M("`\;F%M93YD871A=')E95]P87)E;G1S/"]N86UE/@H@("`@/'1Y<&4^=&5X
M=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L
M;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@
M/&YA;64^9&%T871R965?;W)D97(\+VYA;64^"B`@("`\='EP93YI;G1E9V5R
M/"]T>7!E/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^9&%T
M871R965?9&%T83PO;F%M93X*("`@(#QT>7!E/F-L;V(\+W1Y<&4^"B`@(#PO
M9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YD871A=')E95]S97)I86QI
M>F5D/"]N86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@(#QL96YG
M=&@^,CPO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@
M/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/F1A=&%T<F5E7V1A=&%T
M<F5E7VYA;64\+VYA;64^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^9&%T871R
M965?;F%M93PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\
M:6YD97@^"B`@("`\;F%M93YD871A=')E95]G<F]U<#PO;F%M93X*("`@(#QF
M:65L9#X*("`@("`\;F%M93YG<F]U<%]U:60\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@("`@/&YA;64^9&%T871R965?
M=7-E<CPO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YU<V5R7W5I9#PO
M;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@
M("`\;F%M93YD871A=')E95]S97)I86QI>F5D/"]N86UE/@H@("`@/&9I96QD
M/@H@("`@(#QN86UE/F1A=&%T<F5E7W-E<FEA;&EZ960\+VYA;64^"B`@("`\
M+V9I96QD/@H@("`\+VEN9&5X/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I
M;6%R>3PO;F%M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\
M9FEE;&0^"B`@("`@/&YA;64^9&%T871R965?:60\+VYA;64^"B`@("`\+V9I
M96QD/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^
M"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D95]D871A=')E95]A='1R:6)U=&5S
M/"]N86UE/@H*("`\9&5C;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M
M93YD871A=')E95]I9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^
M"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@
M/&9I96QD/@H@("`@/&YA;64^871T<FEB=71E7VYA;64\+VYA;64^"B`@("`\
M='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@
M(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE
M;&0^"B`@("`\;F%M93YA='1R:6)U=&5?:V5Y/"]N86UE/@H@("`@/'1Y<&4^
M=&5X=#PO='EP93X*("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^871T<FEB=71E7W9A;'5E/"]N86UE/@H@("`@/'1Y<&4^8VQO
M8CPO='EP93X*("`@/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/F1A
M=&%T<F5E7V%T=')I8G5T93PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M
M93YD871A=')E95]I9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^
M"@H@("`\:6YD97@^"B`@("`\;F%M93YD871A=')E95]A='1R:6)U=&5?;F%M
M93PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YA='1R:6)U=&5?;F%M
M93PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^
M"B`@("`\;F%M93YD871A=')E95]A='1R:6)U=&5?:V5Y/"]N86UE/@H@("`@
M/&9I96QD/@H@("`@(#QN86UE/F%T=')I8G5T95]K97D\+VYA;64^"B`@("`\
M+V9I96QD/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B
M;&4^"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D95]H:7-T;W)I97,\+VYA;64^
M"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@(#QN86UE/FAI<W1O
M<GE?:60\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&YO
M=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*
M("`@(#QN86UE/F]B:F5C=%]U:60\+VYA;64^"B`@("`\='EP93YT97AT/"]T
M>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R
M=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M
M93YH:7-T;W)Y7V%C=&EO;CPO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^
M"B`@("`\;&5N9W1H/C,R/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N
M;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^:&ES
M=&]R>5]T<SPO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\
M;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD
M/@H@("`@/&YA;64^:&ES=&]R>5]D97-C/"]N86UE/@H@("`@/'1Y<&4^8VQO
M8CPO='EP93X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/FAI
M<W1O<GE?=VAO/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL
M96YG=&@^,C4U/"]L96YG=&@^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@
M("`\;F%M93YH:7-T;W)Y7V5X=')A/"]N86UE/@H@("`@/'1Y<&4^8VQO8CPO
M='EP93X*("`@/"]F:65L9#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/FAI<W1O
M<GE?86-T:6]N/"]N86UE/@H@("`@/&9I96QD/@H@("`@(#QN86UE/FAI<W1O
M<GE?86-T:6]N/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@
M(#QI;F1E>#X*("`@(#QN86UE/FAI<W1O<GE?=',\+VYA;64^"B`@("`\9FEE
M;&0^"B`@("`@/&YA;64^:&ES=&]R>5]T<SPO;F%M93X*("`@(#PO9FEE;&0^
M"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@("`\;F%M93YH:7-T;W)Y7W5I
M9#PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M93YO8FIE8W1?=6ED/"]N
M86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI;F1E>#X*("`@
M(#QN86UE/G!R:6UA<GD\+VYA;64^"B`@("`\<')I;6%R>3YT<G5E/"]P<FEM
M87)Y/@H@("`@/&9I96QD/@H@("`@(#QN86UE/FAI<W1O<GE?:60\+VYA;64^
M"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*
M(#PO=&%B;&4^"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D95]P<F5F<SPO;F%M
M93X*"B`@/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^<')E
M9E]U:60\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T
M:#XR,#`\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@
M(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YP<F5F7W-C;W!E/"]N
M86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,38\+VQE
M;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^
M"@H@("`\9FEE;&0^"B`@("`\;F%M93YP<F5F7VYA;64\+VYA;64^"B`@("`\
M='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XS,CPO;&5N9W1H/@H@("`@
M/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L
M9#X*("`@(#QN86UE/G!R969?=F%L=64\+VYA;64^"B`@("`\='EP93YC;&]B
M/"]T>7!E/@H@("`\+V9I96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I
M;6%R>3PO;F%M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\
M9FEE;&0^"B`@("`@/&YA;64^<')E9E]U:60\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G!R969?<V-O<&4\+VYA;64^"B`@
M("`\+V9I96QD/@H@("`@/&9I96QD/@H@("`@(#QN86UE/G!R969?;F%M93PO
M;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@("`\:6YD97@^"B`@
M("`\;F%M93YP<F5F7W5I9#PO;F%M93X*("`@(#QF:65L9#X*("`@("`\;F%M
M93YP<F5F7W5I9#PO;F%M93X*("`@(#PO9FEE;&0^"B`@(#PO:6YD97@^"@H@
M("`\:6YD97@^"B`@("`\;F%M93YP<F5F7W-C;W!E/"]N86UE/@H@("`@/&9I
M96QD/@H@("`@(#QN86UE/G!R969?<V-O<&4\+VYA;64^"B`@("`\+V9I96QD
M/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@
M/'1A8FQE/@H*("`\;F%M93YH;W)D95]S97-S:6]N:&%N9&QE<CPO;F%M93X*
M"B`@/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^<V5S<VEO
M;E]I9#PO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N9W1H
M/C,R/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\
M+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^<V5S<VEO;E]L87-T;6]D
M:69I960\+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`@/&YO
M=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF:65L9#X*
M("`@(#QN86UE/G-E<W-I;VY?9&%T83PO;F%M93X*("`@(#QT>7!E/F)L;V(\
M+W1Y<&4^"B`@(#PO9FEE;&0^"@H@("`\:6YD97@^"B`@("`\;F%M93YP<FEM
M87)Y/"]N86UE/@H@("`@/'!R:6UA<GD^=')U93PO<')I;6%R>3X*("`@(#QF
M:65L9#X*("`@("`\;F%M93YS97-S:6]N7VED/"]N86UE/@H@("`@/"]F:65L
M9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A8FQE/@H*
M(#QT86)L93X*"B`@/&YA;64^:&]R9&5?=&]K96YS/"]N86UE/@H*("`\9&5C
M;&%R871I;VX^"@H@("`\9FEE;&0^"B`@("`\;F%M93YT;VME;E]A9&1R97-S
M/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*("`@(#QL96YG=&@^,3`P
M/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I
M96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^=&]K96Y?:60\+VYA;64^"B`@
M("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XS,CPO;&5N9W1H/@H@
M("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*("`@/"]F:65L9#X*"B`@(#QF
M:65L9#X*("`@(#QN86UE/G1O:V5N7W1I;65S=&%M<#PO;F%M93X*("`@(#QT
M>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL
M/@H@("`\+V9I96QD/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I;6%R>3PO
M;F%M93X*("`@(#QP<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^
M"B`@("`@/&YA;64^=&]K96Y?861D<F5S<SPO;F%M93X*("`@(#PO9FEE;&0^
M"B`@("`\9FEE;&0^"B`@("`@/&YA;64^=&]K96Y?:60\+VYA;64^"B`@("`\
M+V9I96QD/@H@("`\+VEN9&5X/@H*("`\+V1E8VQA<F%T:6]N/@H*(#PO=&%B
M;&4^"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D95]U<V5R<SPO;F%M93X*"B`@
M/&1E8VQA<F%T:6]N/@H*("`@/&9I96QD/@H@("`@/&YA;64^=7-E<E]U:60\
M+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\
M+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE
M;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YU<V5R7W!A<W,\+VYA;64^"B`@
M("`\='EP93YT97AT/"]T>7!E/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*
M("`@(#QN;W1N=6QL/G1R=64\+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\
M9FEE;&0^"B`@("`\;F%M93YU<V5R7W-O9G1?97AP:7)A=&EO;E]D871E/"]N
M86UE/@H@("`@/'1Y<&4^:6YT96=E<CPO='EP93X*("`@/"]F:65L9#X*"B`@
M(#QF:65L9#X*("`@(#QN86UE/G5S97)?:&%R9%]E>'!I<F%T:6]N7V1A=&4\
M+VYA;64^"B`@("`\='EP93YI;G1E9V5R/"]T>7!E/@H@("`\+V9I96QD/@H*
M("`@/&EN9&5X/@H@("`@/&YA;64^<')I;6%R>3PO;F%M93X*("`@(#QP<FEM
M87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^=7-E
M<E]U:60\+VYA;64^"B`@("`\+V9I96QD/@H@("`\+VEN9&5X/@H*("`\+V1E
M8VQA<F%T:6]N/@H*(#PO=&%B;&4^"@H@/'1A8FQE/@H*("`\;F%M93YH;W)D
M95]V9G,\+VYA;64^"@H@(#QD96-L87)A=&EO;CX*"B`@(#QF:65L9#X*("`@
M(#QN86UE/G9F<U]I9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^
M"B`@("`\;F]T;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@
M/&9I96QD/@H@("`@/&YA;64^=F9S7W1Y<&4\+VYA;64^"B`@("`\='EP93YI
M;G1E9V5R/"]T>7!E/@H@("`@/&QE;F=T:#XQ/"]L96YG=&@^"B`@("`\;F]T
M;G5L;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@
M("`@/&YA;64^=F9S7W!A=&@\+VYA;64^"B`@("`\='EP93YT97AT/"]T>7!E
M/@H@("`@/&QE;F=T:#XR-34\+VQE;F=T:#X*("`@(#QN;W1N=6QL/G1R=64\
M+VYO=&YU;&P^"B`@(#PO9FEE;&0^"@H@("`\9FEE;&0^"B`@("`\;F%M93YV
M9G-?;F%M93PO;F%M93X*("`@(#QT>7!E/G1E>'0\+W1Y<&4^"B`@("`\;&5N
M9W1H/C(U-3PO;&5N9W1H/@H@("`@/&YO=&YU;&P^=')U93PO;F]T;G5L;#X*
M("`@/"]F:65L9#X*"B`@(#QF:65L9#X*("`@(#QN86UE/G9F<U]M;V1I9FEE
M9#PO;F%M93X*("`@(#QT>7!E/FEN=&5G97(\+W1Y<&4^"B`@("`\;F]T;G5L
M;#YT<G5E/"]N;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@
M/&YA;64^=F9S7V]W;F5R/"]N86UE/@H@("`@/'1Y<&4^=&5X=#PO='EP93X*
M("`@(#QL96YG=&@^,C4U/"]L96YG=&@^"B`@("`\;F]T;G5L;#YT<G5E/"]N
M;W1N=6QL/@H@("`\+V9I96QD/@H*("`@/&9I96QD/@H@("`@/&YA;64^=F9S
M7V1A=&$\+VYA;64^"B`@("`\='EP93YB;&]B/"]T>7!E/@H@("`\+V9I96QD
M/@H*("`@/&EN9&5X/@H@("`@/&YA;64^<')I;6%R>3PO;F%M93X*("`@(#QP
M<FEM87)Y/G1R=64\+W!R:6UA<GD^"B`@("`\9FEE;&0^"B`@("`@/&YA;64^
M=F9S7VED/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I;F1E>#X*"B`@(#QI
M;F1E>#X*("`@(#QN86UE/G9F<U]P871H/"]N86UE/@H@("`@/&9I96QD/@H@
M("`@(#QN86UE/G9F<U]P871H/"]N86UE/@H@("`@/"]F:65L9#X*("`@/"]I
M;F1E>#X*"B`@(#QI;F1E>#X*("`@(#QN86UE/G9F<U]N86UE/"]N86UE/@H@
M("`@/&9I96QD/@H@("`@(#QN86UE/G9F<U]N86UE/"]N86UE/@H@("`@/"]F
M:65L9#X*("`@/"]I;F1E>#X*"B`@/"]D96-L87)A=&EO;CX*"B`\+W1A8FQE
M/@H*/"]D871A8F%S93X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYP9W-Q;"YS<6P`````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`U-3$@,3`U,34T,S0Q-#,@,#(V,#<R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM("1(;W)D
M93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA;F1L97(N<&=S
M<6PN<W%L+'8@,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*
M"D-214%412!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S
M:6]N7VED("`@("`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@
M<V5S<VEO;E]L87-T;6]D:69I960@("!)3E0@3D]4($Y53$PL"B`@("!S97-S
M:6]N7V1A=&$@("`@("`@("`@(%1%6%0L"B`@("!04DE-05)9($M%62`H<V5S
M<VEO;E]I9"D**3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%
M3$5412!/3B!H;W)D95]S97-S:6]N:&%N9&QE<B!43R!H;W)D93L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?9&%T871R964N<W%L````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S,#,T(#$P-3$U-#,T,30S(#`R,S4Q-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7V1A=&%T<F5E+G-Q;"QV(#$N,2XQ,"XQ(#(P,#8O
M,#4O,C(@,C$Z,C<Z,S,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?
M9&%T871R964@*`H@("`@9&%T871R965?:60@24Y4($Y/5"!.54Q,+`H@("`@
M9W)O=7!?=6ED(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?=6ED
M(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7VYA;64@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@9&%T871R965?<&%R96YT<R!605)#
M2$%2*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]O<F1E<B!)3E0L"@HM
M+2!4:&5R92!I<R!N;R!P;W)T86)L92!W87D@=&\@9&\@=&AI<R!A<'!A<F5N
M=&QY+B!)9B!Y;W5R(&1B(&1O97-N)W0*+2T@86QL;W<@5$585"!C;VQU;6YS
M+"!T:&5N(&UA>6)E(&ET(&%L;&]W<R!L87)G92!605)#2$%2(&-O;'5M;G,L
M('-O"BTM('1R>2!T:&4@<V5C;VYD(&QI;F4N"BTM"B`@("!D871A=')E95]D
M871A(%1%6%0L"BTM("!D871A=')E95]D871A(%9!4D-(05(H-#`Y-BDL"@H@
M("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.5"!$149!54Q4(#`@3D]4
M($Y53$PL"@H@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED*0HI.PH*0U)%
M051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X($].(&AO<F1E
M7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T
M<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O=7!?=6ED*3L*
M0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO<F1E7V1A=&%T
M<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E95]O<F1E<E]I
M9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7V]R9&5R*3L*0U)%051%
M($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A=&%T
M<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"@I#4D5!5$4@5$%"3$4@:&]R
M9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)3E0@
M3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@3D]4
M($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2P*("`@(&%T
M=')I8G5T95]V86QU92!415A4"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?
M871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AD
M871A=')E95]I9"D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U=&5?
M;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB
M=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VME
M>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H871T<FEB=71E
M7VME>2D["@H*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%
M($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E.PI'4D%.5"!314Q%0U0L($E.
M4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R965?871T<FEB
M=71E<R!43R!H;W)D93L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7W-E<W-I;VYH86YD;&5R+FUY<W%L+G-Q;```````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#8Q,R`Q,#4Q-30S-#$T,R`P,C8Q,3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYM>7-Q;"YS<6PL=B`Q+C$N,BXQ
M(#(P,#8O,#,O,C(@,3@Z,S`Z,C,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@
M:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@("`@<V5S<VEO;E]I9"`@("`@("`@
M("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?;&%S=&UO
M9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A("`@("`@
M("`@("!,3TY'0DQ/0BP*"B`@("!04DE-05)9($M%62`H<V5S<VEO;E]I9"D*
M*2!%3D=)3D4@/2!);FYO1$(["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$
M051%+"!$14Q%5$4@3TX@:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&5`
M;&]C86QH;W-T.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]D871A=')E92YM
M<W-Q;"YS<6P`````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(U-#<@,3`U,34T
M,S0Q-#,@,#(T-C8R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M9&%T871R964N;7-S<6PN<W%L+'8@,2XQ+C(N,B`R,#`V+S`U+S(R(#(Q.C(W
M.C,S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*
M("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&=R;W5P7W5I9"!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W5I9"!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@9&%T871R965?;W)D97(@24Y4+`H@("`@9&%T871R965?
M9&%T82!605)#2$%2*$U!6"DL"B`@("!D871A=')E95]S97)I86QI>F5D(%--
M04Q,24Y4($1%1D%53%0@,"!.3U0@3E5,3"P*"B`@("!04DE-05)9($M%62`H
M9&%T871R965?:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R
M965?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I
M.PI#4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A
M=&%T<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E
M<E]I9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.
M1$58(&1A=&%T<F5E7V]R9&5R7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?;W)D97(I.PI#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE
M9%]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I
M.PH*"D-214%412!404),12!H;W)D95]D871A=')E95]A='1R:6)U=&5S("@*
M("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]N
M86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&%T=')I8G5T95]K97D@
M5D%20TA!4B@R-34I+`H@("`@871T<FEB=71E7W9A;'5E(%9!4D-(05(H34%8
M*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@
M:&]R9&5?9&%T871R965?871T<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!
M5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E
M7V1A=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%
M($E.1$58(&1A=&%T<F5E7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A
M=&%T<F5E7V%T=')I8G5T97,@*&%T=')I8G5T95]K97DI.PH*"D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D871A=')E
M92!43R!H;W)D93L*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,
M151%($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@5$\@:&]R9&4["@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP
M=',O<W%L+VAO<F1E7VUU=F9S+G-Q;```````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3$R-2`Q,#4Q-30S-#$T,R`P,C,P-C(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2T@)$AO<F1E.B!H
M;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]M=79F<RYS<6PL=B`Q+C$@,C`P-"\P
M.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E
M7VUU=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F<U]P
M871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA;64@
M("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I960@
M($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7W!E<FUS("`@("!334%,3$E.5"!.3U0@
M3E5,3"P*("`@('9F<U]D871A("`@("`@3$].1T),3T(L"BTM($]R+"!O;B!S
M;VUE($1"35,@<WES=&5M<SH*+2T@('9F<U]D871A("`@("`@24U!1T4L"B`@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S
M7W!A=&A?:61X($].(&AO<F1E7VUU=F9S("AV9G-?<&%T:"D["D-214%412!)
M3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?;75V9G,@*'9F<U]N86UE*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYP9W-Q;"YS<6P`````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,3`V,B`Q,#4Q-30S-#$T,R`P,C,V-#4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N<&=S<6PN<W%L+'8@
M,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%412!4
M04),12!H;W)D95]V9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4
M($Y53$PL"B`@("!V9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@
M("`@=F9S7W!A=&@@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V
M9G-?;F%M92`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M
M;V1I9FEE9"`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@(%1%6%0L
M"@H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58
M('9F<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%
M($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*
M"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D
M95]V9G,@5$\@:&]R9&4["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VQO9RYS<6P`````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#8R-R`Q,#4Q-30S-#$T,R`P,C(U
M,3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]L;V<N<W%L+'8@
M,2XQ(#(P,#0O,#DO,3@@,3<Z,C`Z-3D@8VAU8VL@17AP("0*"D-214%412!4
M04),12!H;W)D95]L;V<@*`H@("`@:60@("`@("`@("`@24Y4($Y/5"!.54Q,
M+`H@("`@;&]G=&EM92`@("`@5$E-15-404U0($Y/5"!.54Q,+`H@("`@:61E
M;G0@("`@("`@0TA!4B@Q-BD@3D]4($Y53$PL"B`@("!P<FEO<FET>2`@("!)
M3E0@3D]4($Y53$PL"B`@("`M+2!&;W(@1$)S('1H870@9&]N)W0@<W5P<&]R
M="!T:&4@5$585"!F:65L9"!T>7!E.@H@("`@+2T@;65S<V%G92`@5D%20TA!
M4B@R,#0X*2P*("`@(&UE<W-A9V4@("`@(%1%6%0L"B`@("!04DE-05)9($M%
M62`H:60I"BD["@I'4D%.5"!)3E-%4E0@3TX@:&]R9&5?;&]G(%1/(&AO<F1E
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]214%$344N3T-).```````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,C,T,S8@,3`U,34T,S0Q-#,@,#(Q-#$R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$9)4E-4($]&($%,
M3#H*5&AI<R!I<R!N;W0@;7D@9FER<W0@9&]C=6UE;G1A=&EO;B$@8G5T(&UY
M(&9I<G-T(&EN(&5N9VQI<V@N"D9E96P@9G)E92!T;R!C;VYT86-T(&UE(&%T
M('1O<G-T96Y`9FQA;6UI9V5R+F]R9R!I9B!Y;W4@:&%V92`*86YY('-U9V=E
M<W1I;VYS(&]R('!R;V)L96US(')E;&%T960@=&\@=&AI<R!D;V-S"@I!;&P@
M:2!W:6QL('=R:71E(&%B;W5T($]R86-L92!W:71H($AO<F1E(&ES(&)A<V5D
M(&]N($]R86-L92`^/2`X:0IT:&]U9V@@:70@<VAO=6QD('=O<FL@=VET:"`Y
M:2!T;V\N(`H*22!T:&EN:R`H:2=M('-U<F4I("=5<"!T;R!D871E)R!A=F%I
M;&%B;&4@9&ES=')I8G5T:6]N<PIA<F4@8V%P86)L92!T;R!R=6X@3W)A8VQE
M+B!)(&AA=F4@=&5S=&5D(&ET(&]N"E-L86-K=V%R92`W+C$O."XP("@X+C$N
M-BD@86YD(&AA=F4@<G5N;FEN9R!I="!O;B!'96YT;V\@,2XR("@X+C$N-RXT
M*0IW:71H;W5T(&%N>2!0<F]B;&5M<RX@4V]M92!D:7-T<FEB=71I;VYS(&%R
M92!C97)T:69I960@;&EK92!3=5-%(&]R(`I2961(870N($]N($1E8FEA;B!I
M="!S:&]U;&0@86QS;R!R=6XN"@I&=7)T:&5R;6]R92!I)VQL(&%S<W5M92P@
M=&AA="!N;R`B;F]R;6%L(B!U<V5R(&ES(&=O:6YG('1O(&EN<W1A;&P*;W(@
M:7,@:6X@;F5E9"!T;R!I;G-T86QL(&%N($]R86-L92!$0B`H;V8@8V]U<G-E
M('1H97)E(&%R92!S;VUE(&9R96%K<R`[*0IS;R!K;F]W;&5D9V4@86)O=70@
M<V5T=&EN9R!U<"!A;F0@;6%I;G1A:6X@86X@3W)A8VQE"D1"(&ES(&EN9&ES
M<&5N<V%B;&4A($UA>6)E('1H:7,@:7,@=&AE(')E87-O;B!W:'D@;F\@061M
M:6X*:&%S(&5V97(@<&]S=&5D(&%N>2!D;V-S(&%B;W5T(&=E='1I;F<@2&]R
M9&4@=V]R:R!W:71H($]R86-L90H*3D]413H@86QL(&1O8W,@87)E(&%V86EL
M86)L92!F<F]M('=W=RYO<F%C;&4N8V]M(&9O<B!F<F5E("A!1D%)2RD*"DYO
M=R!L970G<R!B96=I;CH*"D-A<V4@,2D@"DDG;&P@87-S=6UE('1H870@>6]U
M(&1O(&YO="!H879E(&%N(&EN<W1A;F-E(')U;FYI;F<@86YD('1H97)E9F]R
M90IA<F4@86)O=70@=&\@:6YS=&%L;"!A(&9R97-H(&EN<W1A;F-E(")H;W)D
M92(@+@H*+2T)8VAE8VL@86YD(&EF(&YE961E9"!C:&%N9V4@<VAA<F5D(&UE
M;6]R>2!P87)A;65T97)S"BTM"6-R96%T92!A="!L96%S="!T:&4@9&)A(&=R
M;W5P"BTM"6-R96%T92!Y;W5R(&]R86-L92!U<V5R+"!N86UE(&ET(&%S('EO
M=2!L:6ME"@EM86ME('-U<F4@>6]U<B!O<F$M=7-E<B!I<R!I;B!T:&4@9W)O
M=7`@9&)A"BTM"7-U("T@/'EO=7(@9G)E<V@@;W)A8VQE('5S97(^"BTM(`ES
M970@=7`@86QL('1H92!A<'!R;W!R:6%T92!E;G9I<F]N;65N="!V87)I86)L
M97,@9F]R(&]R86-L90H)=&%K92!A(&-L;W-E(&QO;VL@870@=&AE(&EN<W1A
M;&P@:&]W=&\@<')O=FED960@8GD@;W)A8VQE"BTM"6UO=6YT('1H92!#1"`H
M:68@:70@:7,@>6]U<B!S;W5R8V4@;65D:6$I"BTM"7)U;B!T:&4@<V-R:7!T
M(')U;DEN<W1A;&QE<B`M(&)E='1E<B!T;R!H879E(%@Q,2!I;G-T86QL960@
M.RD*"4%T=&5N=&EO;CH@268@>6]U(&%R92!A8F]U="!T;R!I;G-T86QL($]R
M86-L92`Y:0H)9&\@3D]4(')U;B!T:&4@:6YS=&%L;&5R(&9R;VT@9&ER96-T
M;'D@9G)O;2!Y;W5R($-$(0H);&EK92!C9"`O8V1R;VT@86YD('1H96X@<W1A
M<G0@:70@8GD@='EP:6YG("XO<G5N26YS=&%L;&5R"@EY;W4@=V]N)W0@8F4@
M86)L92!T;R!U;FUO=6YT('1H92!#1"!L871E<B!O;B!B=70@>6]U(&AA=F4@
M=&\*"6)E8V%U<V4@.6D@:7,@82`S0T0M4V5T"BTM"69O;&QO=R!T:&4@:6YS
M=')U8W1I;VYS(&=I=F5N(&)Y('1H92!I;G-T86QL871I;VX@<')O9W)A;6T*
M"6%T('1H92!P;VEN="!W:&5R92!Y;W4@87)E(&%S:V5D(&9O<B!A;B!I;G-T
M86QL871I;VX@;65T:&]D"@EC:&]O<V4@(G5S97(M9&5F:6YE9"(N(%1H:7,@
M:7-T(&5S<&5C:6%L;'D@5D5262!)35!/4E1%3E0@:68@>6]U"@EA<F4@86)O
M=70@=&\@:6YS=&%L;"`X:2!S:6YC92!Y;W4@:&%V92!T;R!P871C:"!T:&4@
M:6YS=&%L;&%T:6]N"@E"149/4D4@>6]U(&-R96%T92!Y;W5R(&1A=&%B87-E
M(2!)9B!Y;W4@;F]T(&-H;V]S92`B=7-E<BUD969I;F5D(@H)=&AE('!R;V=R
M86T@(F1B87-S:7-T(B!W:6QL(&%U=&]M871I8V%L;'D@<W1A<G0@870@=&AE
M(&5N9"!O9@H)=&AE(&EN<W1A;&QA=&EO;B!P<F]C97-S(&%N9"!W:6QL(&AA
M;F<@86YD+V]R(&9A:6PN"BTM"6%T('1H92!E;F0@;V8@>6]U<B!I;G-T86QL
M871I;VX@>6]U(&AA=F4@=&\@8V]N9FEG=7)E('EO=7(@;&ES=&5N97(N;W)A
M+`H)=&YS;F%M97,N;W)A(&%N9"!Y;W5R('-Q;&YE="YO<F$@5&AI<R!I<R!A
M;&P@9&]N92!B>2!T:&4*"6EN<W1A;&QA=&EO;B!P<F]G<F%M;2X@"BTM"4YO
M=SH@:68@>6]U('5S92`X+C$N-R!G970@=&AE('!A=&-H(&=L:6)C+3(N,2XS
M+7-T=6)S+G1A<BYG>B!F<F]M($]R86-L92X@"@E)="=S(&%T('1H92!S86UE
M('!A9V4@;&EK92!T:&4@9&(M<V]U<F-E+B!);G-T86QL(&%S(&1E<V-R:6)E
M9"!I;B!214%$344N<W1U8@H)*&ET)W,@:6X@=&AE('!A8VMA9V4@<V\@9FER
M<W0@=6YT87(@:70@<V]M97=H97)E(&5L<V4@;W(@=7-E("=M8R<@*0HM+0E.
M;W<@8W)E871E('EO=7(@9&%T86)A<V4N(%)U;B`B9&)A<W-I<W0B"@E)="=S
M(&YO=R!O;B!Y;W4@=&\@9&5C:61E(&AO=R!B:6<@=&AE(&EN:71I86P@=&%B
M;&5S<&%C97,@87)E+"!H;W<@;6%N>0H)8V]N=')O;"!F:6QE<R!Y;W4@;&EK
M92P@;V8@8V]U<G-E(&AO=R!I="=S(&YA;64@=VEL;"!B92!A;F0@=VAA=`H)
M;W!T:6]N('EO=2!P;&%N('1O('5S92!L:6ME($EN=&5R365D:6$N($ET)W,@
M66]U<B!$96-I<VEO;B`A"@DH0E17.B!T:&4@9&5F875L=',@=VEL;"!W;W)K
M(&%N9"!A<F4@=F5R>2!T:6UE(&-O;G-U;6EN9R`[*0H)070@=&AE(&5N9"!L
M970@=&AE(&1B87-I<W0@<')O9W)A;2!S879E('1H92!C;VYF:6=U<F%T:6]N
M+B!9;W4@8V%N(&-H;V]S90H);&]C871I;VX@86YD(&YA;64N($YO=R!Y;W4@
M8V%N(&-L;W-E(&1B87-S:7-T+@HM+0EC:&%N9V4@=&\@=&AE(&QO8V%T:6]N
M('=H97)E('EO=2!S=&]R960@=&AE('-C<FEP=',@86YD('1A:V4@82!S:&]R
M="!L;V]K"@EA="!L96%S="!I;G1O(&]R86-L97)U;BYS:"!A;F0@;W)A8VQE
M<G5N,2YS:"X@268@86QL(&ES($]+(&-R96%T92!T:&4@9&%T86)A<V4Z"@ER
M=6X@+B]O<F%C;&5R=6XN<V@N(`H)4VET(&)A8VL@=&%K92!A(&-U<"!O9B!C
M;V9F964@86YD(&AO<&4@86QL('=I;&P@8F4@9V]O9"`[*0H*"4EF('EO=2!C
M:&]O<V5D('1H92!);G1E<DUE9&EA(&]P=&EO;B!T:&4@8W)E871I;VX@<')O
M8V5S<R!W:6QL('1A:V4*"6%B;W5T(#(@86YD(&$@:&%L9B!H;W5R("AO;B!M
M>2`U,#!-2'HM4#,@.BTI+B!7:71H;W5T($IA=F$@:70@=VEL;"!T86ME"@EA
M8F]U="`Q(&AO=7(N("AT:&ES(&)O=&@@:7-T('-H;W)T("T@.6D@=&%K97,@
M87,@;6EN+B!T=VEC92!T:&%T('1I;64@(2D*"0H)3D]413H@8VAO;W-I;F<@
M26YT97)-961I82!W:6QL(&=I=F4@>6]U(&5N:&%N8V5D('!O<W-I8FEL:71I
M97,@9F]R('-T;W)I;F<*"6%N9"!M86YI<'5L871I;F<@;65D:6$@9FEL97,N
M($QO;VL@870@:'1T<#HO+VEN=&5R;65D:6$N87,M9&%T87-E<G9I8V4N9&4O
M"@EF;W(@86X@97AA;7!L92XN+@H)"@E!3D]42$52($Y/5$4Z(&EF('EO=2!I
M;G-T86QL960@."XQ+C<@86YD(&%F=&5R=V%R9',@87!P;&EE9"!A;B!U<"!T
M;R!D871E"@EP871C:'-E="`H;&EK92`X+C$N-RXT*2!Y;W4@35535"!R97!A
M=&-H('EO=7(@:6YS=&%L;&%T:6]N('=I=&@@=&AE(`H)9VQI8F,M<W1U8G,@
M<&%T8V@@;W(@>6]U<B!$0B!W;VXG="!R=6X*"0H)4%)/0DQ%35,@/SH@3&]O
M:R!A="!W=W<N;W)A9F%Q+F-O;2!F;W(@>6]U<B!A;G-W97(*"D%L;"!W96YT
M(&9I;F4_($=O;V0L(&QE=',@9V\@86AE860@86YD(&-R96%T92!A(&YE=R!T
M86)L97-P86-E(&-A;&QE9"!H;W)D90H*+2T)5&AE(&1A=&%B87-E('-H;W5L
M9"!R=6X@869T97(@:70@=V%S('-U8V-E<V9U;&QY(&-R96%T960N($QO9VEN
M(&%S('5S97(@<WES=&5M"@EO<B!S>7,@*&QI:V4@>6]U('!R969E<BDN(%1H
M92!P87-S=V]R9',@=VAE<F4@=W)I='1E;B!T;R!Y;W4@;VX@4U1$3U54+@H)
M4&QE87-E(&-H86YG92!T:&5M(2!)(&MN;W<@9&%T86)A<V5S(')U;FYI;F<@
M9F]R('EE87)S('-T;W)I;F<@:6UP;W)T86YT(&1A=&$*"6%N9"!S=&EL;"!H
M879E('1H92!D969A=6QT('!A<W-W;W)D("$A"@DH;6%N86=E<B!F;W(@<WES
M=&5M(&%N9"!C:&%N9V5?;VY?:6YS=&%L;"!F;W(@<WES*0H*+2T)<W%L<&QU
M<R!S>7,O8VAA;F=E7V]N7VEN<W1A;&Q`/'EO=7(@4TE$/@H):68@>6]U('!R
M;W!E<FQY('-E="!T:&4@3U)!0TQ%7U-)1"!E;G9I<F]N;65N="!V87)I86)L
M92!Y;W4@8V%N(&]M;6ET('1H90H)=')A:6QI;F<@0#QY;W5R('-I9#X@=VAE
M;B!Y;W4@87)E(&QO9V=E9"!O;B!T;R!T:&4@;6%C:&EN92!W:&EC:"!I<R!R
M=6YN:6YG('1H92!$0BX*"BTM"6-R96%T92!T:&4@=&%B;&5S<&%C92!F;W(@
M:&]R9&4*"7-Q;#X@0U)%051%(%1!0DQ%4U!!0T4@2$]21$4*("`@("`@("`@
M("`@("!,3T='24Y'"B`@("`@("`@("`@("`@1$%4049)3$4@)SQ93U52(%!!
M5$@@2$5213XO2$]21$4N9&)F)R!325I%(#Q!4R!93U4@3$E+13Y-.PH*"51H
M:7,@:7,@:6YD965D('9E<GD@<VEM<&QE(&)U="!I="!W;W)K<R!A;F0@;F]T
M:&EN9R!H87,@=&\@8F4@:6X@=7!P97)C87-E"@EL971T97)S+B!!9G1E<B!A
M(&9E=R!S96-O;F1S(&]R(&UI;G5T97,@+2!D97!E;F1S(&]N(&AO=R!M86YY
M(&UE9V%B>71E<PH)>6]U(&=A=F4@=&\@=&AA="!T86)L97-P86-E("T@82!N
M97<@9&%T869I;&4@:&%S(&)E96X@8W)E871E9"X*"BTM"5=E(&-A;B!N;W<@
M8W)E871E(&$@=7-E<B!W:71H(&1E9F%U;'0@=&%B;&5S<&%C92!(3U)$12P@
M;&5T<R!N86UE(&AI;2!H;W)D93H*"@E#4D5!5$4@55-%4B!(3U)$12!04D]&
M24Q%($1%1D%53%0@241%3E1)1DE%1"!"62`\>6]U<B!P87-S=V]R9"!H97)E
M/B`*("`@("`@("!404),15-004-%($A/4D1%(%1%35!/4D%262!404),15-0
M04-%(%1%35`@455/5$$@54Y,24U)5$5$($].(%1%35`*"5%53U1!(%5.3$E-
M251%1"!/3B!(3U)$12!!0T-/54Y4(%5.3$]#2SL*"4=204Y4($-/3DY%0U0@
M5$\@2$]21$4["@HM+0EC;VUM:70@>6]U<B!W;W)K.B`^(&-O;6UI=#L*"6%N
M9"!L;V<@;W5T"BTM"6QO9VEN(&%S('5S97(@:&]R9&4Z('-Q;'!L=7,@:&]R
M9&4O/'!A<W-W;W)D/D`\>6]U<B!S:60^(&%N9"!C<F5A=&4@=&AE('1A8FQE
M<PH)(3QP871H('1O(&AO<F1E/B]S8W)I<'1S+V1B+V]R86-L95]C<F5A=&4N
M<W%L(&%N9"!C;VUM:70@>6]U<B!A:W1I;VXZ(#X@8V]M;6ET.PH)=&AE('1A
M8FQE<R!W:6QL(&)E(&-R96%T960@:6X@=&AE(&1E9F%U;'0@=&%B;&5S<&%C
M92!F;W(@>6]U<B!H;W)D92!U<V5R"@D*3TL@;F]W('EO=2!C86X@8V]N9FEG
M=7)E($AO<F1E('1O('5S92!Y;W5R(&EN<W1A;F-E(&)U="!A9G1E<B!A(')E
M8F]O="!/<F%C;&4*=VEL;"!N;W0@<W1A<G0@875T;VUA=&EC;'DN(%1H870@
M:7,@=VAA="!W92!A<F4@9V]I;F<@=&\@8V]N9FEG=7)E(&YO=RX*"BTM"6QO
M9V]U="!O9B!O<F%C;&4L(&QO9VEN(&%S('5S97(@<WES(&]R(#QY;W5R(&]R
M86-L92!U<V5R/B`*"6%N9"!S:'5T9&]W;B!Y;W5R(&EN<W1A;F-E.B`H:&]P
M92!Y;W5R(&]R86-L92!U<V5R(&ES(&EN('1H92!G<F]U<"!D8F$@+0H):68@
M;F]T(&AE(&-A;B=T('-H=70@9&]W;B!Y;W5R(&EN<W1A;F-E*0H)/B!C;VYN
M96-T(&EN=&5R;F%L"@D^('-H=71D;W=N(&EM;65D:6%T90H)86YD(&QO9V]U
M="XN+@H)"BTM"71E<W0@=&AE('-C<FEP="`B9&)S=&%R="(@:6X@)$]204-,
M15](3TU%+V)I;B!)9B!T:&4@1$(@9&]E<R!N;W0@<W1A<G0*"7EO=2!H879E
M('1O(&5D:70@:70@;W(@8W)E871E(&$@;&EN:R!F<F]M("1/4D%#3$5?2$]-
M12]D8G,O:6YI=#QS:60M;F%M93XN;W)A"@ET;R`D3U)!0TQ%7TA/344O861M
M:6XO/'-I9"!N86UE/B]P9FEL92]I;FET/'-I9"UN86UE/BYO<F$*"2@@9&)S
M=&%R="!W:6QL(&QO;VL@9F]R('EO=7(@<VED+69I;&5S(&EN('-U8F1I<B`B
M9&)S(B!B=70@=&AE<V4@87)E('-T;W)E9`H)=6YD97(@)$]204-,15](3TU%
M+V%D;6EN+SQS:60@;F%M93XO<&9I;&4O("T@=&AI<R!M87EB92!I<R!A(&)U
M9R!O<B!A"@EF96%T=7)E(&EN('1H92!O<F%C;&4@:6YS=&%L;&5R("D*"71E
M<W0@(F1B<W1A<G0B(&%G86EN("T@;F]W(&ET('-H;W5L9"!W;W)K+"!I(&AO
M<&4*"BTM"65D:70@=&AE(&9I;&4@+V5T8R]O<F%T86(*"4-H86YG92!T:&4@
M;&EN90H)/'-I9"UN86UE/CH\>6]U<B!/<F%C;&4@2&]M92`M($9U;&P@<75A
M;&EF:65D('!A=&@^.DX@("!T;PH)/'-I9"UN86UE/CH\>6]U<B!/<F%C;&4@
M2&]M92`M($9U;&P@<75A;&EF:65D('!A=&@^.ED*"BTM"6YO=R!C:&%N9V4@
M;W(@8W)E871E(&$@<W1A<G1U<"!S8W)I<'0@=VAI8V@@:7,@97AE8W5T960@
M870@8F]O="!T:6UE+B!)="!S:&]U;&0@8V]N=&%I;@H)<V]M971H:6YG(&QI
M:V4@=&AI<SH*"0H)<W4@+2`\>6]U<B!O<F%C;&4@=7-E<CX@+6,@(CQH;W5R
M('!A=&@@:&5R93XO8FEN+VQS;G)C=&P@<W1A<G0B"@ES=2`M(#QY;W5R(&]R
M86-L92!U<V5R/B`M8R`B/'EO=7(@<&%T:"!H97)E/B]B:6XO9&)S=&%R="(*
M"@EA;F0@;V8@8V]U<G-E('EO=7(@:6YS=&%N8V4@<VAO=6QD(&)E('-T;W!P
M960@82!R96=U;&%R('=A>2X@4&QA8V4@=&AI<PH):6X@=&AE(&%P<')O<')I
M871E('-C<FEP="!W:&EC:"!I<R!E>&5C=71E9"!A="!S:'5T9&]W;B!T:6UE
M"@H)<W4@+2`\>6]U<B!O<F%C;&4@=7-E<CX@+6,@(CQH;W5R('!A=&@@:&5R
M93XO8FEN+VQS;G)C=&P@<W1O<"(*"7-U("T@/'EO=7(@;W)A8VQE('5S97(^
M("UC("(\>6]U<B!P871H(&AE<F4^+V)I;B]D8G-H=70B"@HM+0ET97-T(&ET
M"@I%;F0@;V8@0V%S92`Q*0H*"D-A<V4@,BD*"E!R;V)L96TZ(%EO=2!H879E
M(&%N(&%L;')E861Y(')U;FYI;F<@;W)A8VQE(&1A=&%B87-E(&%N9"!W;W5L
M9"!L:6ME"G1O(&%D9"!A(&YE=R!I;G-T86YC92X@4V]L=71I;VX@:7,@<75I
M970@96%S>2X*1F]R(&YO=RP@=&AE(&YE=R!D871A8F%S92<@;F%M92!W:6QL
M(&)E("TM/B!H;W)D90H*0F5F;W)E(&D@<W1A<G0@:2=L;"!M86ME('-O;64@
M87-S=6UP=&EO;G,Z"BA03$5!4T4@0TA!3D=%(%1(12!0051(3D%-15,@05,@
M3D5#15-305)9("D*"C$N"21/4D%#3$5?2$]-13TO:&]M92]O<F%C;&4*,BX)
M)$]204-,15]"05-%(#T@)$]204-,15](3TU%"C,N"5EO=7(@97AI<W1I;F<@
M1&%T86)A<V4@:7,@:6YS=&%L;&5D('5N9&5R("1/4D%#3$5?2$]-12]O<F%D
M871A+SQY;W5R(&EN<W1A;F-E(&YA;64^"C0N"5EO=7(@97AI<W1I;F<@5')A
M8V4O1'5M<"]P9FEL92]B9'5M<"XN+B`M(&1I<F5C=&]R:65S(&%R92!I;G-T
M86QL960@=6YD97(*"2`D3U)!0TQ%7TA/344O861M:6XO/'EO=7(@:6YS=&%N
M8V4@;F%M93XO"@H)5&AE<F5F;W)E('EO=7(@;F5W(&AO<F1E(&1A=&%B87-E
M(&9I;&5S('=I;&P@9V\@:6YT;R!A;F]T:&5R(&1I<F5C=&]R>3H*"21/4D%#
M3$5?2$]-12]O<F%D871A+VAO<F1E+PH*"51H92!4<F%C92]$=6UP+W!F:6QE
M+V)D=6UP+BXN("T@9&ER<R!G;R!T;SH*"21/4D%#3$5?2$]-12]A9&UI;B]H
M;W)D92\*"@E4:&4@:6YI=&AO<F1E+F]R82!F:6QE(&EN("1/4D%#3$5?2$]-
M12]D8G,@<VAO=6QD(&)E(&$@;&EN:R!T;SH*"21/4D%#3$5?2$]-12]A9&UI
M;B]H;W)D92]P9FEL92]I;FET+F]R80H*3&5T<R!B96=I;CH*"BTM"6-R96%T
M92!T:&4@9&ER96-T;W)I97,@9F]R('EO=7(@;F5W(&1B("AA<R!Y;W5R($]2
M04-,12!U<V5R*3H*"2,^(&UK9&ER("UP("1/4D%#3$5?2$]-12]O<F%D871A
M+VAO<F1E+V%R8VAI=F4*"2,^(&UK9&ER("UP("1/4D%#3$5?2$]-12]A9&UI
M;B]H;W)D92]A9&AO8R!<"@D)("`@("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D
M92]B9'5M<"!<"@D)("`@("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]C9'5M
M<"!<"@D)("`@("1/4D%#3$5?2$]-12]A9&UI;B]H;W)D92]C<F5A=&4@7`H)
M"2`@("`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O97AP(%P*"0D@("`@)$]2
M04-,15](3TU%+V%D;6EN+VAO<F1E+W!F:6QE(%P*"0D@("`@)$]204-,15](
M3TU%+V%D;6EN+VAO<F1E+W5D=6UP"@HM+0EC;W!Y('EO=7(@97AI<W1I;F<@
M:6YI="YO<F$@9FEL92!F<F]M("1/4D%#3$5?2$]-12]A9&UI;B\\97AI<W1I
M;F<@:6YS=&%N8V4^+W!F:6QE+PH)=&\@)$]204-,15](3TU%+V%D;6EN+VAO
M<F1E+W!F:6QE+R!A;F0@;6%K92!T:&4@87!P<F]P<FEA=&4@8VAA;F=E<R!I
M;B!I=`H)0TA!3D=%($%4($Q%05-4(%1(12!0051(3D%-15,@(2$A"@HM+0EM
M86ME('1H92!L:6YK(&9R;VT@)$]204-,15](3TU%+V1B<R]I;FET:&]R9&4N
M;W)A('1O"@DD3U)!0TQ%7TA/344O861M:6XO:&]R9&4O<&9I;&4O:6YI="YO
M<F$*"@DC/B!L;B`M<R`D3U)!0TQ%7TA/344O861M:6XO:&]R9&4O<&9I;&4O
M:6YI="YO<F$@)$]204-,15](3TU%+V1B<R]I;FET:&]R9&4N;W)A"@HM+0ES
M970@3U)!0TQ%7U-)1"!T;R!H;W)D90H)(SX@3U)!0TQ%7U-)1#UH;W)D90H*
M+2T);&]G:6X@86YD('-T87)T=7`@=&AE(&EN<W1A;F-E"@DC/B!S<6QP;'5S
M("]N;VQO9PH)<W%L/B!S=&%R='5P('!F:6QE/2]H;VUE+V]R86-L92]A9&UI
M;B]H;W)D92]P9FEL92]I;FET+F]R82!N;VUO=6YT"@HM+0EC<F5A=&4@=&AE
M(&1A=&%B87-E(&9R;VT@8W)E871E7VAO<F1E7V1B+G-Q;"`M('EO=2!S:&]U
M;&0@;V8@8V]U<G-E(&AA=F4@<V%V960@:70@<V]M=VAE<F4@.RD*"7-Q;#X@
M(2]P871H+W1O+V-R96%T95]H;W)D95]D8BYS<6P*"@EA<R!T96UP;&%T92!I
M('1O;VL@=&AE('-C<FEP="!F<F]M"@EH='1P.B\O=W=W+F%D<"UG;6)H+F-H
M+V]R82]A9&UI;B]C<F5A=&EN9V1B;6%N=6%L;'DN:'1M;"-S86UP;&5C<F5A
M=&5D871A8F%S90H)86YD(&UA9&4@<V]M92!M:6YO<B!C:&%N9V5S+@H*+2T)
M8W)E871E('1H92!D871A(&1I8W1I;VYA<GDL(&5T8RX*"7-Q;#X@(2]H;VUE
M+V]R86-L92]R9&)M<R]A9&UI;B]C871A;&]G+G-Q;`H)<W%L/B`A+VAO;64O
M;W)A8VQE+W)D8FUS+V%D;6EN+V-A='!R;V,N<W%L"@ES<6P^("$O:&]M92]O
M<F%C;&4O<F1B;7,O861M:6XO8V%T:',N<W%L"@ES<6P^(&-O;6UI=#L*"7-Q
M;#X@97AI=`H*+2T);F]W(&%D9"!A(&YE=R!L:6YE('1O("]E=&,O;W)A=&%B
M"@H);VQD("@@;VYL>2`Q(&EN<W1A;F-E("DZ"@D\>6]U<B!I;G-T86QL960@
M:6YS=&%N8V4@;F%M93XZ+VAO;64O;W)A8VQE.ED*"@EN97<@*"!W:71H('1H
M92!N97<@;VYE("DZ"@D\>6]U<B!I;G-T86QL960@:6YS=&%N8V4@;F%M93XZ
M+VAO;64O;W)A8VQE.ED*"6AO<F1E.B]H;VUE+V]R86-L93I9"@HM+0EA9&0@
M=&AE(&YE=R!I;G-T86YC92!T;R!Y;W5R('1N<VYA;65S+F]R80H)=7-E('1H
M92!J879A(&=U:2!N970X87-S:7-T(&]R(&-O<'D@86YD('!A<W1E('1H92!S
M=&%T96UE;G1S(&)Y('EO=7)S96QF(&%N9`H);6%K92!T:&4@8VAA;F=E<R!A
M<R!N965D960*"BTM"6%F=&5R(&%L;"P@=&AE('-C<FEP=',@9&)S=&%R="!U
M;F0@9&)S:'5T('=I;&P@=&AE;B!A=71O;6%T:6-L>2!S=&%R="!A;F0@<VAU
M=&1O=VX@86QL"@EI;G-T86YC97,@870@;VYC90H*0W)E871I;F<@=&AE(%1A
M8FQE<W!A8V4@86YD(')E<75I<F5D('5S97(@:7,@=&AE('-A;64@87,@(&1E
M<V-R:6)E9"!A8F]V90H*"DD@:&]P92!T:&%T('1H97)E(&%R92!N;W0@<V\@
M;6%N>2!S<&5L;&EN9R!M:7-T86ME<R`H(&UY(&YA=&EV92!L86YG=6%G92!I
M<R!G97)M86X@*2`*86YD('1H870@=&AI<R!W:6QL(&)E(&AE;'!F=6QL(&9O
M<B!S;VUE;VYE"@I%;F0@;V8@0V%S92`R*0H*)$AO<F1E.B!H;W)D92]S8W)I
M<'1S+W-Q;"]214%$344N3T-)."QV(#$N,B`R,#`T+S`Y+S(U(#$Y.C4V.C$R
M(&-H=6-K($5X<"`D"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]U<V5R<RYS<6P`````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`V,C(@,3`U,34T,S0Q-#,@,#(S,#8T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM("1(;W)D93H@:&]R
M9&4O<V-R:7!T<R]S<6PO:&]R9&5?=7-E<G,N<W%L+'8@,2XR+C$P+C(@,C`P
M-2\Q,"\Q."`Q,3HS-#HP,"!J86X@17AP("0*"D-214%412!404),12!H;W)D
M95]U<V5R<R`H"B`@("!U<V5R7W5I9"`@("`@("`@("`@("`@("`@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P87-S("`@("`@("`@("`@
M("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('5S97)?<V]F=%]E
M>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`H@("`@=7-E<E]H87)D7V5X<&ER
M871I;VY?9&%T92`@($E.5$5'15(L"BTM"B`@("!04DE-05)9($M%62`H=7-E
M<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%
M5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&4["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?
M:&ES=&]R:65S+G-Q;```````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,C,T(#$P-3$U-#,T,30S(#`R,S<S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7VAI<W1O<FEE<RYS<6PL=B`Q+C$N,BXQ(#(P,#4O,3`O,3@@
M,3$Z,S0Z,#`@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R
M:65S("@*("`@(&AI<W1O<GE?:60@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@
M("`@;V)J96-T7W5I9"`@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@
M("!H:7-T;W)Y7V%C=&EO;B`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@
M:&ES=&]R>5]T<R`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!H:7-T;W)Y
M7V1E<V,@("`@(%1%6%0L"B`@("!H:7-T;W)Y7W=H;R`@("`@(%9!4D-(05(H
M,C4U*2P*("`@(&AI<W1O<GE?97AT<F$@("`@5$585"P*+2T*("`@(%!224U!
M4ED@2T59("AH:7-T;W)Y7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?
M86-T:6]N7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N
M*3L*0U)%051%($E.1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O
M<FEE<R`H:&ES=&]R>5]T<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I
M9'@@3TX@:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*"D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]H:7-T;W)I
M97,@5$\@:&]R9&4["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?<V5S<VEO;FAA;F1L97(N;V-I."YS<6P`````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-38P(#$P-3$U-#,T,30S(#`R-38P-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+F]C:3@N<W%L+'8@,2XR
M+C$P+C$@,C`P-2\Q,"\Q."`Q,3HS-#HP,"!J86X@17AP("0*"D-214%412!4
M04),12!H;W)D95]S97-S:6]N:&%N9&QE<B`H"B`@("!S97-S:6]N7VED("`@
M("`@("`@("`@(%9!4D-(05(R*#,R*2!.3U0@3E5,3"P*("`@('-E<W-I;VY?
M;&%S=&UO9&EF:65D("`@24Y4($Y/5"!.54Q,+`H@("`@<V5S<VEO;E]D871A
M("`@("`@("`@("!"3$]"+`HM+0H@("`@4%))34%262!+15D@*'-E<W-I;VY?
M:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@
M3TX@:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7W9F<RYO
M8VDX+G-Q;```````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`U-2`Q
M,#4Q-30S-#$T,R`P,C,S-C,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H
M;W)D95]V9G,N;V-I."YS<6PL=B`Q+C,@,C`P-"\P.2\R,2`P,SHS-#HP-B!C
M:'5C:R!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V9G-?
M:60@("`@("`@($Y534)%4B@Q-BD@3D]4($Y53$PL"B`@("!V9G-?='EP92`@
M("`@($Y534)%4B@X*2!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%2
M0TA!4C(H,C4U*2P*("`@('9F<U]N86UE("`@("`@5D%20TA!4C(H,C4U*2!.
M3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@3E5-0D52*#$V*2!.3U0@3E5,
M3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!4C(H,C4U*2P*("`@('9F<U]D
M871A("`@("`@0DQ/0BP*+2T*("`@(%!224U!4ED@2T59("`@*'9F<U]I9"D*
M*3L*"D-214%412!)3D1%6"!V9G-?<&%T:%]I9'@@3TX@:&]R9&5?=F9S("AV
M9G-?<&%T:"D["D-214%412!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?
M=F9S("AV9G-?;F%M92D["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%
M+"!$14Q%5$4@3TX@:&]R9&5?=F9S(%1/(&AO<F1E.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO<F1E
M7W!R969S+FUS<W%L+G-Q;```````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3`Q,2`Q,#4Q-30S-#$T,R`P,C0Q-S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]P<F5F<RYM<W-Q;"YS<6PL=B`Q+C$N,BXR(#(P,#8O,#8O
M,CD@,38Z,CDZ,#,@:F%N($5X<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E
M9G,@*`H@("`@<')E9E]U:60@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"P*("`@('!R969?<V-O<&4@("`@("!605)#2$%2*#$V*2!.3U0@3E5,3"!$
M149!54Q4("<G+`H@("`@<')E9E]N86UE("`@("`@(%9!4D-(05(H,S(I($Y/
M5"!.54Q,+`H@("`@<')E9E]V86QU92`@("`@(%9!4D-(05(H34%8*2P*+2T*
M("`@(%!224U!4ED@2T59("AP<F5F7W5I9"P@<')E9E]S8V]P92P@<')E9E]N
M86UE*0HI.PH*0U)%051%($E.1$58('!R969?=6ED7VED>"!/3B!H;W)D95]P
M<F5F<R`H<')E9E]U:60I.PI#4D5!5$4@24Y$15@@<')E9E]S8V]P95]I9'@@
M3TX@:&]R9&5?<')E9G,@*'!R969?<V-O<&4I.PH*1U)!3E0@4T5,14-4+"!)
M3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7W!R969S(%1/(&AO<F1E
M.PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L
M+VAO<F1E7W1O:V5N<RYS<6P`````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#4T,2`Q,#4Q-30S-#$T,R`P,C,R,C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W-Q;"]H;W)D95]T;VME;G,N<W%L+'8@,2XR+C$P+C(@,C`P-2\Q
M,"\Q."`Q,3HS-#HP,"!J86X@17AP("0*"D-214%412!404),12!H;W)D95]T
M;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#$P,"D@3D]4
M($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(H,S(I($Y/5"!.
M54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!"24=)3E0@3D]4($Y53$PL"BTM
M"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD[
M"@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R
M9&5?=&]K96YS(%1/(&AO<F1E.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S
M:6]N:&%N9&QE<BYM<W-Q;"YS<6P`````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U-C<@
M,3`U,34T,S0Q-#,@,#(V,3$R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?<V5S<VEO;FAA;F1L97(N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R,#`V
M+S`Q+S$X(#$Y.C4Y.C$P(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO<F1E
M7W-E<W-I;VYH86YD;&5R("@*("`@('-E<W-I;VY?:60@("`@("`@("`@("`@
M5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE
M9"`@($E.5"!.3U0@3E5,3"P*("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@
M5D%20DE.05)9*$U!6"DL"@H@("`@4%))34%262!+15D@*'-E<W-I;VY?:60I
M"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@
M:&]R9&5?<V5S<VEO;FAA;F1L97(@5$\@:&]R9&4["@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?;&]G+FUS<W%L+G-Q;```
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-C4W(#$P-3$U-#,T,30S
M(#`R,S8U,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O<W%L+VAO<F1E7VQO9RYM
M<W-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O,3@@,3DZ-3@Z-#@@8F5N($5X
M<"`D"@I#4D5!5$4@5$%"3$4@:&]R9&5?;&]G("@*("`@(&ED("`@("`@("`@
M($E.5"!.3U0@3E5,3"P*("`@(&QO9W1I;64@("`@(%1)34535$%-4"!.3U0@
M3E5,3"P*("`@(&ED96YT("`@("`@($-(05(H,38I($Y/5"!.54Q,+`H@("`@
M<')I;W)I='D@("`@24Y4($Y/5"!.54Q,+`H@("`@+2T@1F]R($1"<R!T:&%T
M(&1O;B=T('-U<'!O<G0@=&AE(%9!4D-(05(H34%8*2!F:65L9"!T>7!E.@H@
M("`@+2T@;65S<V%G92`@5D%20TA!4B@R,#0X*2P*("`@(&UE<W-A9V4@("`@
M(%9!4D-(05(H34%8*2P*("`@(%!224U!4ED@2T59("AI9"D**3L*"D=204Y4
M($E.4T525"!/3B!H;W)D95]L;V<@5$\@:&]R9&4["@``````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R+G-A<&1B+G-Q;```
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#0T-B`Q,#4Q-30S-#$T,R`P,C8P-#``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2T@)$AO
M<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS
M87!D8BYS<6PL=B`Q+C$@,C`P-"\P.2\Q."`Q-SHR,#HU.2!C:'5C:R!%>'`@
M)`H*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*("`@('-E
M<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@
M("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*("`@('-E
M<W-I;VY?9&%T82`@("`@("`@("`@3$].1R!"651%+`H@("`@4%))34%262!+
M15D@*'-E<W-I;VY?:60I"BD*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q
M;"]H;W)D95]M=79F<RYM<W-Q;"YS<6P`````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#$P-34@,3`U,34T,S0Q-#,@,#(T,C(R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM("1(;W)D93H@:&]R9&4O
M<V-R:7!T<R]S<6PO:&]R9&5?;75V9G,N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R
M,#`V+S`Q+S$X(#$Y.C4X.C4T(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO
M<F1E7VUU=F9S("@*("`@('9F<U]I9"`@("`@("`@0DE'24Y4($Y/5"!.54Q,
M+`H@("`@=F9S7W1Y<&4@("`@("!334%,3$E.5"!.3U0@3E5,3"P*("`@('9F
M<U]P871H("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VYA
M;64@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;6]D:69I
M960@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]O=VYE<B`@("`@5D%20TA!
M4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7W!E<FUS("`@("!334%,3$E.5"!.
M3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5D%20DE.05)9*$U!6"DL"B`@
M("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S
M7W!A=&A?:61X($].(&AO<F1E7VUU=F9S("AV9G-?<&%T:"D["D-214%412!)
M3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?;75V9G,@*'9F<U]N86UE*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I
M<'1S+W-Q;"]C<F5A=&4N<WEB87-E+G-Q;```````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,3`Q-3<@,3`U,34T,S0Q-#,@,#(S,C<V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"TM("1(;W)D93H@
M:&]R9&4O<V-R:7!T<R]S<6PO8W)E871E+G-Y8F%S92YS<6PL=B`Q+C$N,3`N
M-2`R,#`V+S`V+S(Y(#$V.C(Y.C`S(&IA;B!%>'`@)`HM+0HM+2!H;W)D92!T
M86)L97,@9&5F:6YI=&EO;G,@.B!S<6P@<V-R:7!T"BTM(#`Q+S(R+S(P,#,@
M+2!&+B!(96QL>2`\9G)A;F-O:7,N:&5L;'E`=V%N861O;RYF<CX*+2T@8V]M
M;6%N9"!L:6YE('-Y;G1A>"`Z("!I<W%L("UI:&]R9&5?<WEB87-E+G-Q;`HM
M+2!W87)N:6YG(#H@=7-E(&YV87)C:&%R(&]N;'D@:68@>6]U(&YE960@=6YI
M8V]D92!E;F-O9&EN9R!F;W(@<V]M92!S=')I;F=S"@IU<V4@:&]R9&4*9V\*
M"@I$4D]0(%1!0DQ%(&AO<F1E7V1A=&%T<F5E"F=O"@I$4D]0(%1!0DQ%(&AO
M<F1E7W!R969S"F=O"@I$4D]0(%1!0DQ%(&AO<F1E7W5S97)S"F=O"@I$4D]0
M(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R"F=O"@HM+2!$4D]0(%1!0DQ%
M(&AO<F1E7V1A=&%T<F5E7W-E<0HM+2!G;PH*+2T@1%)/4"!404),12!H;W)D
M95]T;VME;G,*+2T@9V\*"BTM($123U`@5$%"3$4@:&]R9&5?=F9S"BTM(&=O
M"@HM+2!$4D]0(%1!0DQ%(&AO<F1E7VUU=F9S"BTM(&=O"@H*0U)%051%(%1!
M0DQ%(&AO<F1E7W5S97)S("@*("!U<V5R7W5I9"!V87)C:&%R*#(U-BD@3D]4
M($Y53$PL"B`@=7-E<E]P87-S('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!U
M<V5R7W-O9G1?97AP:7)A=&EO;E]D871E(&YU;65R:6,H,3`L,"DL"B`@=7-E
M<E]H87)D7V5X<&ER871I;VY?9&%T92!N=6UE<FEC*#$P+#`I+`H@(%!224U!
M4ED@2T59("`H=7-E<E]U:60I"BD*9V\*"D-214%412!404),12!H;W)D95]D
M871A=')E92`H"B`@9&%T871R965?:60@;G5M97)I8R@Q,2PP*2!)1$5.5$E4
M62!.3U0@3E5,3"P*("!G<F]U<%]U:60@=F%R8VAA<B@R-38I($Y/5"!.54Q,
M+`H@('5S97)?=6ED('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!D871A=')E
M95]N86UE('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!D871A=')E95]P87)E
M;G1S('9A<F-H87(H,C4V*2!.54Q,+`H@(&1A=&%T<F5E7V1A=&$@=&5X="!.
M54Q,+`H@(&1A=&%T<F5E7W-E<FEA;&EZ960@<VUA;&QI;G0@1$5&055,5"`P
M($Y/5"!.54Q,+`H@(%!224U!4ED@2T59("`H9&%T871R965?:60I+`H@($9/
M4D5)1TX@2T59("AU<V5R7W5I9"D*("`@(%)%1D5214Y#15,@:&]R9&5?=7-E
M<G,H=7-E<E]U:60I"B`I"F=O"@I#4D5!5$4@5$%"3$4@:&]R9&5?<')E9G,@
M*`H@('!R969?=6ED('9A<F-H87(H,C4V*2!.3U0@3E5,3"P*("!P<F5F7W-C
M;W!E('9A<F-H87(H,38I($Y/5"!.54Q,+`H@('!R969?;F%M92!V87)C:&%R
M*#,R*2!.3U0@3E5,3"P*("!P<F5F7W9A;'5E('1E>'0@3E5,3"P*("!04DE-
M05)9($M%62`@*'!R969?=6ED+'!R969?<V-O<&4L<')E9E]N86UE*0HI"F=O
M"@I#4D5!5$4@5$%"3$4@:&]R9&5?<V5S<VEO;FAA;F1L97(@*`H@('-E<W-I
M;VY?:60@=F%R8VAA<B@S,BD@3D]4($Y53$PL"B`@<V5S<VEO;E]L87-T;6]D
M:69I960@;G5M97)I8R@Q,2PP*2!.3U0@3E5,3"P*("!S97-S:6]N7V1A=&$@
M:6UA9V4@3E5,3"P*("!04DE-05)9($M%62`@*'-E<W-I;VY?:60I"BD*9V\*
M"@HM+2!#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?<V5Q("@*+2T@("!I
M9"!N=6UE<FEC*#$P+#`I($E$14Y42519($Y/5"!.54Q,+`HM+2`@(%!224U!
M4ED@2T59("`H:60I"BTM("D*+2T@9V\*"BTM($-214%412!404),12!H;W)D
M95]T;VME;G,@*`HM+2`@('1O:V5N7V%D9')E<W,@=F%R8VAA<B@Q,#`I($Y/
M5"!.54Q,+`HM+2`@('1O:V5N7VED('9A<F-H87(H,S(I($Y/5"!.54Q,+`HM
M+2`@('1O:V5N7W1I;65S=&%M<"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,+`HM
M+2`@(%!224U!4ED@2T59("`H=&]K96Y?861D<F5S<RQT;VME;E]I9"D*+2T@
M*0HM+2!G;PH*+2T@0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"BTM("`@=F9S
M7VED(&YU;65R:6,H,C`L,"D@3D]4($Y53$PL"BTM("`@=F9S7W1Y<&4@;G5M
M97)I8R@X+#`I($Y/5"!.54Q,+`HM+2`@('9F<U]P871H('9A<F-H87(H,C4V
M*2!.3U0@3E5,3"P*+2T@("!V9G-?;F%M92!N=F%R8VAA<B@R-38I($Y/5"!.
M54Q,+`HM+2`@('9F<U]M;V1I9FEE9"!N=6UE<FEC*#(P+#`I($Y/5"!.54Q,
M+`HM+2`@('9F<U]O=VYE<B!V87)C:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@
M=F9S7V1A=&$@:6UA9V4@3E5,3"P*+2T@("!04DE-05)9($M%62`@*'9F<U]I
M9"D*+2T@*0HM+2!G;PH*+2T@0U)%051%(%1!0DQ%(&AO<F1E7VUU=F9S("@*
M+2T@("!V9G-?:60@(&YU;65R:6,H,C`L,"D@3D]4($Y53$PL"BTM("`@=F9S
M7W1Y<&4@("`@("!N=6UE<FEC*#@L,"D@3D]4($Y53$PL"BTM("`@=F9S7W!A
M=&@@("`@("!V87)C:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7VYA;64@
M("`@("!V87)C:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7VUO9&EF:65D
M("!N=6UE<FEC*#@L,"D@3D]4($Y53$PL"BTM("`@=F9S7V]W;F5R("`@("!V
M87)C:&%R*#(U-BD@3D]4($Y53$PL"BTM("`@=F9S7W!E<FUS("`@("!S;6%L
M;&EN="!.3U0@3E5,3"P*+2T@("!V9G-?9&%T82`@("`@(&EM86=E($Y53$PL
M"BTM("`@4%))34%262!+15D@("`H=F9S7VED*0HM+2`@("D*+2T@9V\*"@I#
M4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO<F1E7W!R969S("AP<F5F
M7W5I9"D*9V\*"D-214%412!)3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H;W)D
M95]P<F5F<R`H<')E9E]S8V]P92D*9V\*"D-214%412!)3D1%6"!D871A=')E
M95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R
M965?;F%M92D*9V\*"D-214%412!)3D1%6"!D871A=')E95]G<F]U<%]I9'@@
M3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D*9V\*"D-214%412!)3D1%
M6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E<E]U
M:60I"F=O"@I#4D5!5$4@24Y$15@@9&%T871R965?<V5R:6%L:7IE9%]I9'@@
M3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7W-E<FEA;&EZ960I"F=O"@HM
M+2!#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S
M7W!A=&@I"BTM(&=O"@HM+2!#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].
M(&AO<F1E7W9F<R`H=F9S7VYA;64I"BTM(&=O"@HM+2!#4D5!5$4@24Y$15@@
M=F9S7W!A=&A?:61X($].(&AO<F1E7VUU=F9S("AV9G-?<&%T:"D*+2T@9V\*
M"BTM($-214%412!)3D1%6"!V9G-?;F%M95]I9'@@3TX@:&]R9&5?;75V9G,@
M*'9F<U]N86UE*0HM+2!G;PH*"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE
M=&4L('5P9&%T92!O;B!E9&ET;W(@=&\@:&]R9&4*9V\*9W)A;G0@<V5L96-T
M+"!I;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<W0@=&\@:&]R9&4*9V\*
M9W)A;G0@<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&1B87-E
M('1O(&AO<F1E"F=O"F=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P
M9&%T92!O;B!S:71E('1O(&AO<F1E"F=O"F=R86YT('-E;&5C="P@:6YS97)T
M+"!D96QE=&4L('5P9&%T92!O;B!C;VYN96-T:6]N('1O(&AO<F1E"F=O"F=R
M86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P9&%T92!O;B!H;W)D95]D
M871A=')E92!T;R!H;W)D90IG;PIG<F%N="!S96QE8W0L(&EN<V5R="P@9&5L
M971E+"!U<&1A=&4@;VX@:&]R9&5?<')E9G,@=&\@:&]R9&4*9V\*9W)A;G0@
M<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7W-E<W-I
M;VYH86YD;&5R('1O(&AO<F1E"F=O"@HM+2!G<F%N="!S96QE8W0L(&EN<V5R
M="P@9&5L971E+"!U<&1A=&4@;VX@:&]R9&5?9&%T871R965?<V5Q('1O(&AO
M<F1E"BTM(&=O"BTM(&=R86YT('-E;&5C="P@:6YS97)T+"!D96QE=&4L('5P
M9&%T92!O;B!H;W)D95]T;VME;G,@=&\@:&]R9&4*+2T@9V\*+2T@9W)A;G0@
M<V5L96-T+"!I;G-E<G0L(&1E;&5T92P@=7!D871E(&]N(&AO<F1E7W9F<R!T
M;R!H;W)D90HM+2!G;PHM+2!G<F%N="!S96QE8W0L(&EN<V5R="P@9&5L971E
M+"!U<&1A=&4@;VX@:&]R9&5?;75V9G,@=&\@:&]R9&4*+2T@9V\*"@H*+2T@
M861D('EO=2!A9&UI;E]U<V5R7W5I9"!A;F0@861M:6Y?=7-E<E]P87-S"@HM
M+2!I;G-E<G0@:6YT;R!H;W)D95]U<V5R<R!V86QU97,@*"=Y;W5R7V%D;6EN
M7W5S97)?=6ED)RP@)WEO=7)?861M:6Y?=7-E<E]P87-S7VUD-5]E;F-R>7!T
M960G*0HM+2!G;PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O<W%L+VAO
M<F1E7W9F<RYS<6P`````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3$U,"`Q,#4Q-30S-#$T,R`P,C(U,38`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+2T@)$AO<F1E.B!H;W)D92]S8W)I
M<'1S+W-Q;"]H;W)D95]V9G,N<W%L+'8@,2XQ+C$P+C(@,C`P-2\Q,"\Q."`Q
M,3HS-#HP,"!J86X@17AP("0*"D-214%412!404),12!H;W)D95]V9G,@*`H@
M("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?='EP
M92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A=&@@("`@("!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@0DE'24Y4($Y/
M5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!V9G-?9&%T82`@("`@($Q/3D="3$]"+`HM+2!/<BP@;VX@<V]M
M92!$0DU3('-Y<W1E;7,Z"BTM("!V9G-?9&%T82`@("`@($E-04=%+`H@("`@
M4%))34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P
M871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58
M('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4
M(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@
M5$\@:&]R9&4["@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O
M<W%L+VAO<F1E7W9F<RYM<W-Q;"YS<6P`````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,3`W-2`Q,#4Q-30S-#$T,R`P,C,V-C(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2T@)$AO<F1E.B!H;W)D
M92]S8W)I<'1S+W-Q;"]H;W)D95]V9G,N;7-S<6PN<W%L+'8@,2XQ+C(N,2`R
M,#`V+S`Q+S$X(#$Y.C4Y.C$V(&)E;B!%>'`@)`H*0U)%051%(%1!0DQ%(&AO
M<F1E7W9F<R`H"B`@("!V9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*
M("`@('9F<U]T>7!E("`@("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?
M<&%T:"`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D
M("!"24=)3E0@3D]4($Y53$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H
M,C4U*2!.3U0@3E5,3"P*("`@('9F<U]D871A("`@("`@5D%20DE.05)9*$U!
M6"DL"B`@("!04DE-05)9($M%62`@("AV9G-?:60I"BD["@I#4D5!5$4@24Y$
M15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H=F9S7W!A=&@I.PI#4D5!
M5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E7W9F<R`H=F9S7VYA;64I
M.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO
M<F1E7W9F<R!43R!H;W)D93L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C
M<FEP=',O<W%L+VAO<F1E7W!R969S+G-Q;```````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#<W-"`Q,#4Q-30S-#$T,R`P,C,P-3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````+2T@)$AO<F1E
M.B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]P<F5F<RYS<6PL=B`Q+C(N,3`N
M,2`R,#`V+S`V+S(Y(#$V.C(Y.C`S(&IA;B!%>'`@)`H*0U)%051%(%1!0DQ%
M(&AO<F1E7W!R969S("@*("`@('!R969?=6ED("`@("`@("!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E("`@("`@5D%20TA!4B@Q-BD@
M3D]4($Y53$P@1$5&055,5"`G)RP*("`@('!R969?;F%M92`@("`@("!605)#
M2$%2*#,R*2!.3U0@3E5,3"P*("`@('!R969?=F%L=64@("`@("!415A4+`HM
M+0H@("`@4%))34%262!+15D@*'!R969?=6ED+"!P<F5F7W-C;W!E+"!P<F5F
M7VYA;64I"BD["@I#4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO<F1E
M7W!R969S("AP<F5F7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E7VED
M>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S8V]P92D["@I'4D%.5"!314Q%0U0L
M($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?<')E9G,@5$\@:&]R
M9&4["@````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W-Q;"]H
M;W)D95]D871A=')E92YM>7-Q;"YS<6P`````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#(U,C0@,3`U,34T,S0Q-#,@,#(T-C8S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]S<6PO:&]R9&5?9&%T871R964N;7ES<6PN<W%L+'8@,2XQ+C$P+C$@
M,C`P-B\P-2\R,B`R,3HR-SHS,R!J86X@17AP("0*"D-214%412!404),12!H
M;W)D95]D871A=')E92`H"B`@("`@("!D871A=')E95]I9"!)3E0@3D]4($Y5
M3$PL"B`@("`@("!G<F]U<%]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@
M("`@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@("`@
M9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("`@("!D
M871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@("`@
M(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@("`@(&1A=&%T<F5E7V1A=&$@5$58
M5"P*("`@("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!3$Q)3E0@1$5&055,
M5"`P($Y/5"!.54Q,+`H@("`@("`@4%))34%262!+15D@*&1A=&%T<F5E7VED
M*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?:61X
M($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%($E.
M1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H9W)O
M=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A=')E
M95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R965?
M<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?871T
M<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!A
M='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!A='1R
M:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2!$149!54Q4("<G($Y/5"!.54Q,+`H@
M("`@871T<FEB=71E7W9A;'5E(%1%6%0**3L*"D-214%412!)3D1%6"!D871A
M=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T=')I
M8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA
M='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A='1R:6)U
M=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA='1R
M:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%
M3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D94!L;V-A;&AO<W0["D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S(%1/(&AO<F1E0&QO8V%L:&]S=#L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W-C<FEP=',O<W%L+V-R96%T92YP9W-Q;"YS<6P`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S4P-2`Q,#4Q-30S-#$T,R`P
M,C,Q-#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+2T@)$AO<F1E.B!H;W)D92]S8W)I<'1S+W-Q;"]C<F5A=&4N<&=S<6PN
M<W%L+'8@,2XQ+C$P+C4@,C`P-B\P."\P-"`R,#HT.3HT,R!J86X@17AP("0*
M+2T*+2T@56YC;VUM96YT('1H92!!3%1%4B!L:6YE(&)E;&]W+"!A;F0@8VAA
M;F=E('1H92!P87-S=V]R9"X@(%1H96X@<G5N(&%S.@HM+0HM+2`D('!S<6P@
M+60@=&5M<&QA=&4Q("UF(&-R96%T92YP9W-Q;"YS<6P*"D-214%412!$051!
M0D%312!H;W)D93L*"EQC(&AO<F1E.PH*0U)%051%(%5315(@:&]R9&4["@HM
M+2!!3%1%4B!54T52(&AO<F1E(%=)5$@@4$%34U=/4D0@)W!A<W,G.PH*"D-2
M14%412!404),12!H;W)D95]U<V5R<R`H"B`@("!U<V5R7W5I9"`@("`@("`@
M("`@("`@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=7-E<E]P
M87-S("`@("`@("`@("`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('5S97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@("!)3E1%1T52+`H@("`@
M=7-E<E]H87)D7V5X<&ER871I;VY?9&%T92`@($E.5$5'15(L"BTM"B`@("!0
M4DE-05)9($M%62`H=7-E<E]U:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T52
M5"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=7-E<G,@5$\@:&]R9&4["@H*
M0U)%051%(%1!0DQ%(&AO<F1E7W!R969S("@*("`@('!R969?=6ED("`@("`@
M("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!P<F5F7W-C;W!E("`@("`@
M5D%20TA!4B@Q-BD@1$5&055,5"`G)R!.3U0@3E5,3"P*("`@('!R969?;F%M
M92`@("`@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@('!R969?=F%L=64@
M("`@("!415A4+`HM+0H@("`@4%))34%262!+15D@*'!R969?=6ED+"!P<F5F
M7W-C;W!E+"!P<F5F7VYA;64I"BD["@I#4D5!5$4@24Y$15@@<')E9E]U:61?
M:61X($].(&AO<F1E7W!R969S("AP<F5F7W5I9"D["D-214%412!)3D1%6"!P
M<F5F7W-C;W!E7VED>"!/3B!H;W)D95]P<F5F<R`H<')E9E]S8V]P92D["@I'
M4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?
M<')E9G,@5$\@:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E
M("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,3"P*("`@(&=R;W5P7W5I
M9"!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W5I9"!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@9&%T871R965?;W)D97(@24Y4+`H@("`@9&%T871R
M965?9&%T82!415A4+`H@("`@9&%T871R965?<V5R:6%L:7IE9"!334%,3$E.
M5"!$149!54Q4(#`@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*&1A=&%T
M<F5E7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA
M;65?:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%
M051%($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E
M92`H9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X
M($].(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D
M871A=')E95]O<F1E<E]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E
M7V]R9&5R*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X
M($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]S97)I86QI>F5D*3L*"@I#
M4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?871T<FEB=71E<R`H"B`@("!D
M871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92!6
M05)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y(%9!4D-(
M05(H,C4U*2P*("`@(&%T=')I8G5T95]V86QU92!415A4"BD["@I#4D5!5$4@
M24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D871A=')E
M95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%6"!D871A
M=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R965?871T
M<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?871T<FEB
M=71E<R`H871T<FEB=71E7VME>2D["@I'4D%.5"!314Q%0U0L($E.4T525"P@
M55!$051%+"!$14Q%5$4@3TX@:&]R9&5?9&%T871R964@5$\@:&]R9&4["D=2
M04Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S(%1/(&AO<F1E.PH*"D-214%412!404),12!H
M;W)D95]T;VME;G,@*`H@("`@=&]K96Y?861D<F5S<R`@("!605)#2$%2*#$P
M,"D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@("`@("`@(%9!4D-(05(H,S(I
M($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!"24=)3E0@3D]4($Y5
M3$PL"BTM"B`@("!04DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?
M:60I"BD["@I'4D%.5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@
M3TX@:&]R9&5?=&]K96YS(%1/(&AO<F1E.PH*"D-214%412!404),12!H;W)D
M95]V9G,@*`H@("`@=F9S7VED("`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@
M("!V9G-?='EP92`@("`@(%--04Q,24Y4($Y/5"!.54Q,+`H@("`@=F9S7W!A
M=&@@("`@("!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!V9G-?;F%M92`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]M;V1I9FEE9"`@
M0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7V]W;F5R("`@("!605)#2$%2*#(U
M-2D@3D]4($Y53$PL"B`@("!V9G-?9&%T82`@("`@(%1%6%0L"@H@("`@4%))
M34%262!+15D@("`H=F9S7VED*0HI.PH*0U)%051%($E.1$58('9F<U]P871H
M7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P871H*3L*0U)%051%($E.1$58('9F
M<U]N86UE7VED>"!/3B!H;W)D95]V9G,@*'9F<U]N86UE*3L*"D=204Y4(%-%
M3$5#5"P@24Y315)4+"!54$1!5$4L($1%3$5412!/3B!H;W)D95]V9G,@5$\@
M:&]R9&4["@H*0U)%051%(%1!0DQ%(&AO<F1E7W-E<W-I;VYH86YD;&5R("@*
M("`@('-E<W-I;VY?:60@("`@("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y5
M3$PL"B`@("!S97-S:6]N7VQA<W1M;V1I9FEE9"`@($E.5"!.3U0@3E5,3"P*
M("`@('-E<W-I;VY?9&%T82`@("`@("`@("`@5$585"P*("`@(%!224U!4ED@
M2T59("AS97-S:6]N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7W-E<W-I;VYH86YD;&5R(%1/(&AO<F1E
M.PH*"D-214%412!404),12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES=&]R
M>5]I9"`@("`@("!"24=)3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@
M("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N
M("`@5D%20TA!4B@S,BD@3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@("`@
M($))1TE.5"!.3U0@3E5,3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5$585"P*
M("`@(&AI<W1O<GE?=VAO("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES=&]R
M>5]E>'1R82`@("!415A4+`HM+0H@("`@4%))34%262!+15D@*&AI<W1O<GE?
M:60I"BD["@I#4D5!5$4@24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X($].(&AO
M<F1E7VAI<W1O<FEE<R`H:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@24Y$15@@
M:&ES=&]R>5]T<U]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7W1S
M*3L*0U)%051%($E.1$58(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H:7-T
M;W)I97,@*&]B:F5C=%]U:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D93L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W-C<FEP=',O=7!G<F%D97,O
M;6]V95]H:7-T;W)Y7V]U=%]O9E]D871A=')E92YP:'``````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C0T,"`Q,#4Q-30S-#$T,R`P,C<U,C<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````(R$O=7-R+V)I;B]P:'`@+7$*/#]P:'`*
M+RHJ"B`J("1(;W)D93H@:&]R9&4O<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI
M<W1O<GE?;W5T7V]F7V1A=&%T<F5E+G!H<"QV(#$N,RXR+C$@,C`P-2\Q,"\Q
M."`Q,3HS-#HP,2!J86X@17AP("0*("H*("H@5&AI<R!I<R!A('-C<FEP="!T
M;R!M:6=R871E($AI<W1O<GD@:6YF;W)M871I;VX@;W5T(&]F('1H92!D871A
M=')E90H@*B!T86)L97,@86YD(&EN=&\@:71S(&]W;B!D871A8F%S92!T86)L
M92X*("HO"@HO+R!&:6YD('1H92!B87-E(&9I;&4@<&%T:"!O9B!(;W)D92X*
M0&1E9FEN92@G05542%](04Y$3$52)RP@=')U92D["D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*"B\O($1O
M($-,22!C:&5C:W,@86YD(&5N=FER;VYM96YT('-E='5P(&9I<G-T+@IR97%U
M:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]#3$DN<&AP)SL*"B\O($UA:V4@<W5R92!N;R!O;F4@
M<G5N<R!T:&ES(&9R;VT@=&AE('=E8BX*:68@*"%(;W)D95]#3$DZ.G)U;FYI
M;F=&<F]M0TQ)*"DI('L*("`@(&5X:70H(DUU<W0@8F4@<G5N(&9R;VT@=&AE
M(&-O;6UA;F0@;&EN95QN(BD["GT*"B\O($QO860@=&AE($-,22!E;G9I<F]N
M;65N="`M(&UA:V4@<W5R92!T:&5R92=S(&YO('1I;64@;&EM:70L(&EN:70*
M+R\@<V]M92!V87)I86)L97,L(&5T8RX*2&]R9&5?0TQ).CII;FET*"D["B1C
M;&D@/2!(;W)D95]#3$DZ.G-I;F=L971O;B@I.PH*)&-L:2T^=W)I=&5L;B@D
M8VQI+3YY96QL;W<H(D)E9VEN;FEN9R!M:6=R871I;VXN(%1H:7,@;6%Y('1A
M:V4@82!V97)Y(&QO;F<@=&EM92!T;R!C;VUP;&5T92XB*2D["B1C;&DM/G=R
M:71E;&XH*3L*"G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S
M92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["@IC
M;&%S<R!$871A5')E94]B:F5C=%](:7-T;W)Y(&5X=&5N9',@1&%T851R965/
M8FIE8W0@>PH*("`@(&9U;F-T:6]N(%]F<F]M071T<FEB=71E<R@D871T<FEB
M=71E<RD*("`@('L*("`@("`@("`O*B!);FET:6%L:7IE(&1A=&$@87)R87DN
M("HO"B`@("`@("`@)'1H:7,M/F1A=&$@/2!A<G)A>2@I.PH*("`@("`@("!F
M;W)E86-H("@D871T<FEB=71E<R!A<R`D871T<BD@>PH@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3YD871A6R1A='1R6R=N86UE)UU=*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75T@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YD871A6R1A
M='1R6R=N86UE)UU=6R1A='1R6R=K97DG75T@/2`D871T<ELG=F%L=64G73L*
M("`@("`@("!]"B`@("!]"@I]"@HD9&%T871R964@/2`F1&%T851R964Z.F9A
M8W1O<GDH)W-Q;"<L(&%R<F%Y7VUE<F=E*$AO<F1E.CIG971$<FEV97)#;VYF
M:6<H)V1A=&%T<F5E)RP@)W-Q;"<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=G<F]U<"<@/3X@
M)VAO<F1E+FAI<W1O<GDG*2DI.PHD9&(@/2`F)&1A=&%T<F5E+3Y?9&(["@HD
M:7-Q;"`]("=)3E-%4E0@24Y43R!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?
M:60L(&]B:F5C=%]U:60L(&AI<W1O<GE?86-T:6]N+"!H:7-T;W)Y7V1E<V,L
M(&AI<W1O<GE?=VAO+"!H:7-T;W)Y7W1S+"!H:7-T;W)Y7V5X=')A*2<@+@H@
M("`@("`@("<@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_+"`_*2<["@HD86QL
M(#T@)&1A=&%T<F5E+3YG970H1$%40512145?1D]234%47T9,050L($1!5$%4
M4D5%7U)/3U0L('1R=64I.PIU;G-E="@D86QL6T1!5$%44D5%7U)/3U1=*3L*
M)&ED<R`](&%R<F%Y7VME>7,H)&%L;"D["@IF;W)E86-H("@D:61S(&%S("1I
M9"D@>PH@("`@)&]B(#T@)&1A=&%T<F5E+3YG971/8FIE8W1">4ED*"1I9"P@
M)T1A=&%4<F5E3V)J96-T7TAI<W1O<GDG*3L*("`@(&9O<F5A8V@@*"1O8BT^
M9V5T1&%T82@I(&%S("1R;W<I('L*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)&1B+3YN97AT260H)VAO<F1E7VAI<W1O<FEE<R<I+"`@("`@("`@("`@("`@
M("`@("\O(&AI<W1O<GE?:60*("`@("`@("`@("`@("`@("`@("`@("`@)&]B
M+3YG971.86UE*"DL("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&]B:F5C=%]U:60*("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H
M)')O=ULG86-T:6]N)UTI(#\@)')O=ULG86-T:6]N)UT@.B!N=6QL+"`@("\O
M(&AI<W1O<GE?86-T:6]N"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T
M*"1R;W=;)V1E<V,G72D@/R`D<F]W6R=D97-C)UT@.B!N=6QL+"`@("`@("`O
M+R!H:7-T;W)Y7V1E<V,*("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H
M)')O=ULG=VAO)UTI(#\@)')O=ULG=VAO)UT@.B!N=6QL+"`@("`@("`@("\O
M(&AI<W1O<GE?=VAO"B`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1R
M;W=;)W1S)UTI(#\@)')O=ULG=',G72`Z(&YU;&PL("`@("`@("`@("`O+R!H
M:7-T;W)Y7W1S"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@
M('5N<V5T*"1R;W=;)V%C=&EO;B==*3L*("`@("`@("!U;G-E="@D<F]W6R=D
M97-C)UTI.PH@("`@("`@('5N<V5T*"1R;W=;)W=H;R==*3L*("`@("`@("!U
M;G-E="@D<F]W6R=T<R==*3L*("`@("`@("!I9B`H8V]U;G0H)')O=RDI('L*
M("`@("`@("`@("`@)'9A;'5E<UM=(#T@<V5R:6%L:7IE*"1R;W<I.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&AI<W1O<GE?97AT<F$*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L=65S6UT@/2!N=6QL
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@:&ES=&]R>5]E>'1R80H@("`@("`@('T*"B`@("`@("`@8VAE8VLH)&1B
M+3YQ=65R>2@D:7-Q;"P@)'9A;'5E<RDI.PH@("`@?0H*("`@(&-H96-K*"1D
M8BT^<75E<GDH)T1%3$5412!&4D]-(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,@5TA%4D4@9&%T871R965?:60@/2`_)RP@87)R87DH)&ED*2DI.PH@("`@
M8VAE8VLH)&1B+3YQ=65R>2@G1$5,151%($923TT@:&]R9&5?9&%T871R964@
M5TA%4D4@9&%T871R965?:60@/2`_)RP@87)R87DH)&ED*2DI.PI]"@HD8VQI
M+3YW<FET96QN*"1C;&DM/F=R965N*")$;VYE+B!-:6=R871E9"`B("X@8V]U
M;G0H)&ED<RD@+B`B(&]B:F5C=',N(BDI.PH*9G5N8W1I;VX@8VAE8VLH)')E
M<W5L="D*>PH@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@('9A<E]D=6UP*"1R97-U;'0I.PH@("`@("`@(&5X:70["B`@
M("!]"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]S8W)I<'1S+W5P9W)A9&5S
M+S(P,#8M,#8M,CE?:&]R9&5?<')E9G-?:6YD97AE<RYS<6P`````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`U-3$@,3`U,34T,S0Q-#,@,#(V-S$W`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM(%1H:7,@<V-R:7!T(&%D9',@861D
M:71I;VYA;"!I;F1E>&5S('1O('1H92!H;W)D95]P<F5F<R!T86)L92!T:&%T
M('-H;W5L9`HM+2!I;7!R;W9E(&QO861I;F<@;V8@<')E9F5R96YC97,@9G)O
M;2!T:&4@<')E9F5R96YC92!T86)L92X*+2T*+2T@)$AO<F1E.B!H;W)D92]S
M8W)I<'1S+W5P9W)A9&5S+S(P,#8M,#8M,CE?:&]R9&5?<')E9G-?:6YD97AE
M<RYS<6PL=B`Q+C$N,BXQ(#(P,#8O,#8O,CD@,38Z,CDZ,#,@:F%N($5X<"`D
M"@I#4D5!5$4@24Y$15@@<')E9E]U:61?:61X($].(&AO<F1E7W!R969S("AP
M<F5F7W5I9"D["D-214%412!)3D1%6"!P<F5F7W-C;W!E7VED>"!/3B!H;W)D
M95]P<F5F<R`H<')E9E]S8V]P92D["@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP
M+G!G<W%L+G-Q;```````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-S$P(#$P-3$U
M-#,T,30S(#`R-#(V-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+2!9;W4@8V%N('-I;7!L>2!E>&5C=71E('1H:7,@9FEL
M92!I;B!Y;W5R(&1A=&%B87-E+@HM+0HM+2!2=6X@87,Z"BTM"BTM("0@<'-Q
M;"`\9&(@;F%M93X@+68@,BXR7W1O7S,N,"YP;W-T9W)E<W%L+G-Q;`H*0D5'
M24X["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($%$1"!#3TQ534X@<')E9E]U
M:61?;F5W(%9!4D-(05(H,C`P*3L*55!$051%(&AO<F1E7W!R969S(%-%5"!P
M<F5F7W5I9%]N97<@/2!P<F5F7W5I9#L*04Q415(@5$%"3$4@:&]R9&5?<')E
M9G,@1%)/4"!P<F5F7W5I9#L*04Q415(@5$%"3$4@:&]R9&5?<')E9G,@4D5.
M04U%('!R969?=6ED7VYE=R!43R!P<F5F7W5I9#L*04Q415(@5$%"3$4@:&]R
M9&5?<')E9G,@04Q415(@0T],54U.('!R969?=6ED(%-%5"!.3U0@3E5,3#L*
M0T]-34E4.PI$14Q%5$4@1E)/32!H;W)D95]P<F5F<R!72$5212!P<F5F7VYA
M;64@/2`G;&%S=%]L;V=I;B<@04Y$('!R969?<V-O<&4@/2`G:6UP)SL*"D-2
M14%412!404),12!H;W)D95]D871A=')E92`H"B`@("`@("!D871A=')E95]I
M9"!)3E0@3D]4($Y53$PL"B`@("`@("!G<F]U<%]U:60@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@("`@=7-E<E]U:60@5D%20TA!4B@R-34I($Y/5"!.
M54Q,+`H@("`@("`@9&%T871R965?;F%M92!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("`@("!D871A=')E95]P87)E;G1S(%9!4D-(05(H,C4U*2!.3U0@
M3E5,3"P*("`@("`@(&1A=&%T<F5E7V]R9&5R($E.5"P*("`@("`@(&1A=&%T
M<F5E7V1A=&$@5$585"P*("`@("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@4TU!
M3$Q)3E0@1$5&055,5"`P($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?=7!D
M871E9"!424U%4U1!35`L"@H@("`@("`@4%))34%262!+15D@*&1A=&%T<F5E
M7VED*0HI.PH*0U)%051%($E.1$58(&1A=&%T<F5E7V1A=&%T<F5E7VYA;65?
M:61X($].(&AO<F1E7V1A=&%T<F5E("AD871A=')E95]N86UE*3L*0U)%051%
M($E.1$58(&1A=&%T<F5E7V=R;W5P7VED>"!/3B!H;W)D95]D871A=')E92`H
M9W)O=7!?=6ED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7W5S97)?:61X($].
M(&AO<F1E7V1A=&%T<F5E("AU<V5R7W5I9"D["D-214%412!)3D1%6"!D871A
M=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T871R
M965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"!)3E0@3D]4($Y53$PL"B`@
M("!A='1R:6)U=&5?;F%M92!605)#2$%2*#(U-2D@3D]4($Y53$PL"B`@("!A
M='1R:6)U=&5?:V5Y(%9!4D-(05(H,C4U*2!$149!54Q4("<G($Y/5"!.54Q,
M+`H@("`@871T<FEB=71E7W9A;'5E(%1%6%0**3L*"D-214%412!)3D1%6"!D
M871A=')E95]A='1R:6)U=&5?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@*&1A=&%T<F5E7VED*3L*0U)%051%($E.1$58(&1A=&%T<F5E7V%T
M=')I8G5T95]N86UE7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S
M("AA='1R:6)U=&5?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]A='1R
M:6)U=&5?:V5Y7VED>"!/3B!H;W)D95]D871A=')E95]A='1R:6)U=&5S("AA
M='1R:6)U=&5?:V5Y*3L*"D=204Y4(%-%3$5#5"P@24Y315)4+"!54$1!5$4L
M($1%3$5412!/3B!H;W)D95]D871A=')E92!43R!H;W)D93L*1U)!3E0@4T5,
M14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E
M7V%T=')I8G5T97,@5$\@:&]R9&4["@I#4D5!5$4@5$%"3$4@:&]R9&5?=&]K
M96YS("@*("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4B@X*2!.3U0@3E5,
M3"P*("`@('1O:V5N7VED("`@("`@("`@5D%20TA!4B@S,BD@3D]4($Y53$PL
M"B`@("!T;VME;E]T:6UE<W1A;7`@($))1TE.5"!.3U0@3E5,3"P*"B`@("!0
M4DE-05)9($M%62`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60I"BD["@I'4D%.
M5"!314Q%0U0L($E.4T525"P@55!$051%+"!$14Q%5$4@3TX@:&]R9&5?=&]K
M96YS(%1/(&AO<F1E.PH*0U)%051%(%1!0DQ%(&AO<F1E7W9F<R`H"B`@("!V
M9G-?:60@("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@('9F<U]T>7!E("`@
M("`@4TU!3$Q)3E0@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(
M05(H,C4U*2!.3U0@3E5,3"P*("`@('9F<U]N86UE("`@("`@5D%20TA!4B@R
M-34I($Y/5"!.54Q,+`H@("`@=F9S7VUO9&EF:65D("!"24=)3E0@3D]4($Y5
M3$PL"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@('9F<U]D871A("`@("`@5$585"P*"B`@("!04DE-05)9($M%62`@("AV
M9G-?:60I"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E
M7W9F<R`H=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].
M(&AO<F1E7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L
M(%501$%412P@1$5,151%($].(&AO<F1E7W9F<R!43R!H;W)D93L*"@``````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E
M<R\R+C)?=&]?,RXP+FUY<W%L+G-Q;```````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`T-C<W(#$P-3$U-#,T,30S(#`R-#,R,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP
M=',O=7!G<F%D97,O,BXR7W1O7S,N,"YM>7-Q;"YS<6PL=B`Q+C(N."XR(#(P
M,#4O,3`O,3@@,3$Z,S0Z,#$@:F%N($5X<"`D"BTM"BTM(%EO=2!C86X@<VEM
M<&QY(&5X96-U=&4@=&AI<R!F:6QE(&EN('EO=7(@9&%T86)A<V4N"BTM"BTM
M(%)U;B!A<SH*+2T*+2T@)"!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D
M/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"`R+C)?=&]?,RXP
M+FUY<W%L+G-Q;`H*55-%(&AO<F1E.PH*04Q415(@5$%"3$4@:&]R9&5?<')E
M9G,@0TA!3D=%($-/3%5-3B!P<F5F7W5I9"!P<F5F7W5I9"!605)#2$%2*#(P
M,"D@3D]4($Y53$P["D1%3$5412!&4D]-(&AO<F1E7W!R969S(%=(15)%('!R
M969?;F%M92`]("=L87-T7VQO9VEN)R!!3D0@<')E9E]S8V]P92`]("=I;7`G
M.PH*0U)%051%(%1!0DQ%(&AO<F1E7V1A=&%T<F5E("@*("`@("`@(&1A=&%T
M<F5E7VED($E.5"!.3U0@3E5,3"P*("`@("`@(&=R;W5P7W5I9"!605)#2$%2
M*#(U-2D@3D]4($Y53$PL"B`@("`@("!U<V5R7W5I9"!605)#2$%2*#(U-2D@
M3D]4($Y53$PL"B`@("`@("!D871A=')E95]N86UE(%9!4D-(05(H,C4U*2!.
M3U0@3E5,3"P*("`@("`@(&1A=&%T<F5E7W!A<F5N=',@5D%20TA!4B@R-34I
M($Y/5"!.54Q,+`H@("`@("`@9&%T871R965?;W)D97(@24Y4+`H@("`@("`@
M9&%T871R965?9&%T82!415A4+`H@("`@("`@9&%T871R965?<V5R:6%L:7IE
M9"!334%,3$E.5"!$149!54Q4(#`@3D]4($Y53$PL"B`@("`@("!D871A=')E
M95]U<&1A=&5D(%1)34535$%-4"P*"B`@("`@("!04DE-05)9($M%62`H9&%T
M871R965?:60I"BD["@I#4D5!5$4@24Y$15@@9&%T871R965?9&%T871R965?
M;F%M95]I9'@@3TX@:&]R9&5?9&%T871R964@*&1A=&%T<F5E7VYA;64I.PI#
M4D5!5$4@24Y$15@@9&%T871R965?9W)O=7!?:61X($].(&AO<F1E7V1A=&%T
M<F5E("AG<F]U<%]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?=7-E<E]I
M9'@@3TX@:&]R9&5?9&%T871R964@*'5S97)?=6ED*3L*0U)%051%($E.1$58
M(&1A=&%T<F5E7W-E<FEA;&EZ961?:61X($].(&AO<F1E7V1A=&%T<F5E("AD
M871A=')E95]S97)I86QI>F5D*3L*"D-214%412!404),12!H;W)D95]D871A
M=')E95]A='1R:6)U=&5S("@*("`@(&1A=&%T<F5E7VED($E.5"!.3U0@3E5,
M3"P*("`@(&%T=')I8G5T95]N86UE(%9!4D-(05(H,C4U*2!.3U0@3E5,3"P*
M("`@(&%T=')I8G5T95]K97D@5D%20TA!4B@R-34I($1%1D%53%0@)R<@3D]4
M($Y53$PL"B`@("!A='1R:6)U=&5?=F%L=64@5$585`HI.PH*0U)%051%($E.
M1$58(&1A=&%T<F5E7V%T=')I8G5T95]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H9&%T871R965?:60I.PI#4D5!5$4@24Y$15@@9&%T871R
M965?871T<FEB=71E7VYA;65?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@*&%T=')I8G5T95]N86UE*3L*0U)%051%($E.1$58(&1A=&%T<F5E
M7V%T=')I8G5T95]K97E?:61X($].(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T
M97,@*&%T=')I8G5T95]K97DI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7V1A=&%T<F5E(%1/(&AO<F1E0&QO8V%L
M:&]S=#L*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].
M(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@5$\@:&]R9&5`;&]C86QH;W-T
M.PH*0U)%051%(%1!0DQ%(&AO<F1E7W1O:V5N<R`H"B`@("!T;VME;E]A9&1R
M97-S("`@(%9!4D-(05(H."D@3D]4($Y53$PL"B`@("!T;VME;E]I9"`@("`@
M("`@(%9!4D-(05(H,S(I($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T86UP
M("!"24=)3E0@3D]4($Y53$PL"@H@("`@4%))34%262!+15D@*'1O:V5N7V%D
M9')E<W,L('1O:V5N7VED*0HI.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%50
M1$%412P@1$5,151%($].(&AO<F1E7W1O:V5N<R!43R!H;W)D94!L;V-A;&AO
M<W0["@I#4D5!5$4@5$%"3$4@:&]R9&5?=F9S("@*("`@('9F<U]I9"`@("`@
M("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@("`@("!334%,3$E.
M5"!.3U0@3E5,3"P*("`@('9F<U]P871H("`@("`@5D%20TA!4B@R-34I($Y/
M5"!.54Q,+`H@("`@=F9S7VYA;64@("`@("!605)#2$%2*#(U-2D@3D]4($Y5
M3$PL"B`@("!V9G-?;6]D:69I960@($))1TE.5"!.3U0@3E5,3"P*("`@('9F
M<U]O=VYE<B`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@=F9S7V1A
M=&$@("`@("!,3TY'0DQ/0BP*"B`@("!04DE-05)9($M%62`@("AV9G-?:60I
M"BD["@I#4D5!5$4@24Y$15@@=F9S7W!A=&A?:61X($].(&AO<F1E7W9F<R`H
M=F9S7W!A=&@I.PI#4D5!5$4@24Y$15@@=F9S7VYA;65?:61X($].(&AO<F1E
M7W9F<R`H=F9S7VYA;64I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%4
M12P@1$5,151%($].(&AO<F1E7W9F<R!43R!H;W)D94!L;V-A;&AO<W0["@``
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R
M:7!T<R]U<&=R861E<R\R+C)?=&]?,RXP+F]C:3@N<W%L````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`T-#<S(#$P-3$U-#,T,30S(#`R-#`Q,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+2`D2&]R9&4Z
M(&AO<F1E+W-C<FEP=',O=7!G<F%D97,O,BXR7W1O7S,N,"YO8VDX+G-Q;"QV
M(#$N,2XR+C$@,C`P-B\P-"\P-B`R,CHU,SHT,"!J86X@17AP("0*"D%,5$52
M(%1!0DQ%(&AO<F1E7W!R969S($U/1$E&62!P<F5F7W5I9"!605)#2$%2,B@R
M-34I.PI!3%1%4B!404),12!H;W)D95]P<F5F<R!-3T1)1ED@<')E9E]S8V]P
M92!605)#2$%2,B@Q-BD["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($U/1$E&
M62!P<F5F7VYA;64@5D%20TA!4C(H,S(I.PI54$1!5$4@:&]R9&5?<')E9G,@
M4T54('!R969?=6ED(#T@4E1224TH<')E9E]U:60I.PI54$1!5$4@:&]R9&5?
M<')E9G,@4T54('!R969?<V-O<&4@/2!25%))32AP<F5F7W-C;W!E*3L*55!$
M051%(&AO<F1E7W!R969S(%-%5"!P<F5F7VYA;64@/2!25%))32AP<F5F7VYA
M;64I.PH*1$5,151%($923TT@:&]R9&5?<')E9G,@5TA%4D4@<')E9E]N86UE
M(#T@)VQA<W1?;&]G:6XG($%.1"!P<F5F7W-C;W!E(#T@)VEM<"<["@I#4D5!
M5$4@5$%"3$4@:&]R9&5?9&%T871R964@*`H@("`@9&%T871R965?:60@("`@
M("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&=R;W5P7W5I9"`@("`@
M("`@("`@(%9!4D-(05(R*#(U-2D@3D]4($Y53$PL"B`@("!U<V5R7W5I9"`@
M("`@("`@("`@("!605)#2$%2,B@R-34I+`H@("`@9&%T871R965?;F%M92`@
M("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@(&1A=&%T<F5E7W!A
M<F5N=',@("`@(%9!4D-(05(R*#(U-2DL"B`@("!D871A=')E95]O<F1E<B`@
M("`@("!.54U"15(H,38I+`H@("`@9&%T871R965?9&%T82`@("`@("`@0TQ/
M0BP*("`@(&1A=&%T<F5E7W-E<FEA;&EZ960@($Y534)%4B@X*2!$149!54Q4
M(#`@3D]4($Y53$PL"B`@("!D871A=')E95]U<&1A=&5D("`@("!$051%+`H*
M("`@(%!224U!4ED@2T59("AD871A=')E95]I9"D**3L*"D-214%412!)3D1%
M6"!D871A=')E95]D871A=')E95]N86UE7VED>"!/3B!H;W)D95]D871A=')E
M92`H9&%T871R965?;F%M92D["D-214%412!)3D1%6"!D871A=')E95]G<F]U
M<%]I9'@@3TX@:&]R9&5?9&%T871R964@*&=R;W5P7W5I9"D["D-214%412!)
M3D1%6"!D871A=')E95]U<V5R7VED>"!/3B!H;W)D95]D871A=')E92`H=7-E
M<E]U:60I.PI#4D5!5$4@24Y$15@@9&%T871R965?;W)D97)?:61X($].(&AO
M<F1E7V1A=&%T<F5E("AD871A=')E95]O<F1E<BD["D-214%412!)3D1%6"!D
M871A=')E95]S97)I86QI>F5D7VED>"!/3B!H;W)D95]D871A=')E92`H9&%T
M871R965?<V5R:6%L:7IE9"D["@I#4D5!5$4@5$%"3$4@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H"B`@("!D871A=')E95]I9"`@("`@($Y534)%4B@Q
M-BD@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?;F%M92`@(%9!4D-(05(R*#(U
M-2D@3D]4($Y53$PL"B`@("!A='1R:6)U=&5?:V5Y("`@(%9!4D-(05(R*#(U
M-2DL"B`@("!A='1R:6)U=&5?=F%L=64@(%9!4D-(05(R*#0P,#`I"BD["@I#
M4D5!5$4@24Y$15@@9&%T871R965?871T<FEB=71E7VED>"!/3B!H;W)D95]D
M871A=')E95]A='1R:6)U=&5S("AD871A=')E95]I9"D["D-214%412!)3D1%
M6"!D871A=')E95]A='1R:6)U=&5?;F%M95]I9'@@3TX@:&]R9&5?9&%T871R
M965?871T<FEB=71E<R`H871T<FEB=71E7VYA;64I.PI#4D5!5$4@24Y$15@@
M9&%T871R965?871T<FEB=71E7VME>5]I9'@@3TX@:&]R9&5?9&%T871R965?
M871T<FEB=71E<R`H871T<FEB=71E7VME>2D["@I#4D5!5$4@5$%"3$4@:&]R
M9&5?=&]K96YS("@*("`@('1O:V5N7V%D9')E<W,@("`@5D%20TA!4C(H,3`P
M*2!.3U0@3E5,3"P*("`@('1O:V5N7VED("`@("`@("`@5D%20TA!4C(H,S(I
M($Y/5"!.54Q,+`H@("`@=&]K96Y?=&EM97-T86UP("!.54U"15(H,38I($Y/
M5"!.54Q,+`H*("`@(%!224U!4ED@2T59("AT;VME;E]A9&1R97-S+"!T;VME
M;E]I9"D**3L*"D-214%412!404),12!H;W)D95]V9G,@*`H@("`@=F9S7VED
M("`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@=F9S7W1Y<&4@("`@
M("!.54U"15(H."D@3D]4($Y53$PL"B`@("!V9G-?<&%T:"`@("`@(%9!4D-(
M05(R*#(U-2DL"B`@("!V9G-?;F%M92`@("`@(%9!4D-(05(R*#(U-2D@3D]4
M($Y53$PL"B`@("!V9G-?;6]D:69I960@($Y534)%4B@Q-BD@3D]4($Y53$PL
M"B`@("!V9G-?;W=N97(@("`@(%9!4D-(05(R*#(U-2DL"B`@("!V9G-?9&%T
M82`@("`@($),3T(L"@H@("`@4%))34%262!+15D@("`H=F9S7VED*0HI.PH*
M0U)%051%($E.1$58('9F<U]P871H7VED>"!/3B!H;W)D95]V9G,@*'9F<U]P
M871H*3L*0U)%051%($E.1$58('9F<U]N86UE7VED>"!/3B!H;W)D95]V9G,@
M*'9F<U]N86UE*3L*"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+FUY<W%L+G-Q
M;````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-S(T(#$P-3$U-#,T,30S(#`R
M-#,Q,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O=7!G<F%D97,O,RXP7W1O7S,N
M,2YM>7-Q;"YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#$O,#8@,3`Z-#$Z,3,@:F%N
M($5X<"`D"BTM"BTM(%EO=2!C86X@<VEM<&QY(&5X96-U=&4@=&AI<R!F:6QE
M(&EN('EO=7(@9&%T86)A<V4N"BTM"BTM(%)U;B!A<SH*+2T*+2T@)"!M>7-Q
M;"`M+75S97(]<F]O="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D
M/B`\9&(@;F%M93X@/"`S+C!?=&]?,RXQ+FUY<W%L+G-Q;`H*04Q415(@5$%"
M3$4@:&]R9&5?=7-E<G,@041$($-/3%5-3B!U<V5R7W-O9G1?97AP:7)A=&EO
M;E]D871E($E.5#L*04Q415(@5$%"3$4@:&]R9&5?=7-E<G,@041$($-/3%5-
M3B!U<V5R7VAA<F1?97AP:7)A=&EO;E]D871E($E.5#L*"D-214%412!404),
M12!H;W)D95]H:7-T;W)I97,@*`H@("`@:&ES=&]R>5]I9"`@("`@("!"24=)
M3E0@3D]4($Y53$PL"B`@("!O8FIE8W1?=6ED("`@("`@(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"P*("`@(&AI<W1O<GE?86-T:6]N("`@5D%20TA!4B@S,BD@
M3D]4($Y53$PL"B`@("!H:7-T;W)Y7W1S("`@("`@($))1TE.5"!.3U0@3E5,
M3"P*("`@(&AI<W1O<GE?9&5S8R`@("`@5$585"P*("`@(&AI<W1O<GE?=VAO
M("`@("`@5D%20TA!4B@R-34I+`H@("`@:&ES=&]R>5]E>'1R82`@("!415A4
M+`HM+0H@("`@4%))34%262!+15D@*&AI<W1O<GE?:60I"BD["@I#4D5!5$4@
M24Y$15@@:&ES=&]R>5]A8W1I;VY?:61X($].(&AO<F1E7VAI<W1O<FEE<R`H
M:&ES=&]R>5]A8W1I;VXI.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]T<U]I9'@@
M3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7W1S*3L*0U)%051%($E.1$58
M(&AI<W1O<GE?=6ED7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&]B:F5C=%]U
M:60I.PH*1U)!3E0@4T5,14-4+"!)3E-%4E0L(%501$%412P@1$5,151%($].
M(&AO<F1E7VAI<W1O<FEE<R!43R!H;W)D94!L;V-A;&AO<W0["@``````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S+C!?=&]?,RXQ+F]C
M:3@N<W%L````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,S4T(#$P-3$U-#,T
M,30S(#`R-#`P-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O=7!G<F%D97,O,RXP
M7W1O7S,N,2YO8VDX+G-Q;"QV(#$N,2XR+C$@,C`P-B\P-"\P-B`R,CHU,SHU
M-"!J86X@17AP("0*"D%,5$52(%1!0DQ%(&AO<F1E7W5S97)S($%$1"!U<V5R
M7W-O9G1?97AP:7)A=&EO;E]D871E($Y534)%4B@Q-BD["D%,5$52(%1!0DQ%
M(&AO<F1E7W5S97)S($%$1"!U<V5R7VAA<F1?97AP:7)A=&EO;E]D871E($Y5
M34)%4B@Q-BD["@I#4D5!5$4@5$%"3$4@:&]R9&5?:&ES=&]R:65S("@*("`@
M(&AI<W1O<GE?:60@("`@("`@3E5-0D52*#$V*2!.3U0@3E5,3"P*("`@(&]B
M:F5C=%]U:60@("`@("`@5D%20TA!4C(H,C4U*2!.3U0@3E5,3"P*("`@(&AI
M<W1O<GE?86-T:6]N("`@5D%20TA!4C(H,S(I($Y/5"!.54Q,+`H@("`@:&ES
M=&]R>5]T<R`@("`@("!.54U"15(H,38I($Y/5"!.54Q,+`H@("`@:&ES=&]R
M>5]D97-C("`@("!#3$]"+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2
M,B@R-34I+`H@("`@:&ES=&]R>5]E>'1R82`@("!#3$]"+`H*("`@(%!224U!
M4ED@2T59("AH:7-T;W)Y7VED*0HI.PH*0U)%051%($E.1$58(&AI<W1O<GE?
M86-T:6]N7VED>"!/3B!H;W)D95]H:7-T;W)I97,@*&AI<W1O<GE?86-T:6]N
M*3L*0U)%051%($E.1$58(&AI<W1O<GE?='-?:61X($].(&AO<F1E7VAI<W1O
M<FEE<R`H:&ES=&]R>5]T<RD["D-214%412!)3D1%6"!H:7-T;W)Y7W5I9%]I
M9'@@3TX@:&]R9&5?:&ES=&]R:65S("AO8FIE8W1?=6ED*3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\R,#`U+3`Y
M+3(R7VAO<F1E7W!R969S7W9A<F-H87(R+F]C:3@N<W%L````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,3<S(#$P
M-3$U-#,T,30S(#`R-S8R-0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````M+2!5<V4@=&AI<R!S8W)I<'0@=&\@8V]N=F5R="!#
M2$%2(&-O;'5M;G,@:6X@:&]R9&5?<')E9G,@=&\@5D%20TA!4C(@86YD('1R
M:6T*+2T@=&AE('-P86-E('!A9&1I;F<N("!4:&ES(&ES(&]N;'D@;F5C97-S
M87)Y(&EF(&AO<F1E7W!R969S('=A<R!C<F5A=&5D('5S:6YG"BTM('-C<FEP
M=',O<W%L+V-R96%T92YO8VDX+G-Q;`HM+0HM+2`D2&]R9&4Z(&AO<F1E+W-C
M<FEP=',O=7!G<F%D97,O,C`P-2TP.2TR,E]H;W)D95]P<F5F<U]V87)C:&%R
M,BYO8VDX+G-Q;"QV(#$N,2XR+C$@,C`P-2\Q,"\Q."`Q,3HS-#HP,2!J86X@
M17AP("0*+2T*04Q415(@5$%"3$4@:&]R9&5?<')E9G,@34]$2499('!R969?
M=6ED(%9!4D-(05(R*#(U-2D["D%,5$52(%1!0DQ%(&AO<F1E7W!R969S($U/
M1$E&62!P<F5F7W-C;W!E(%9!4D-(05(R*#$V*3L*04Q415(@5$%"3$4@:&]R
M9&5?<')E9G,@34]$2499('!R969?;F%M92!605)#2$%2,B@S,BD["E501$%4
M12!H;W)D95]P<F5F<R!3150@<')E9E]U:60@/2!25%))32AP<F5F7W5I9"D[
M"E501$%412!H;W)D95]P<F5F<R!3150@<')E9E]S8V]P92`](%)44DE-*'!R
M969?<V-O<&4I.PI54$1!5$4@:&]R9&5?<')E9G,@4T54('!R969?;F%M92`]
M(%)44DE-*'!R969?;F%M92D["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]U<&=R861E<R\S
M+C!?=&]?,RXQ+G-Q;```````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M,S,V(#$P-3$U-#,T,30S(#`R,S$T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+2`D2&]R9&4Z(&AO<F1E+W-C<FEP=',O
M=7!G<F%D97,O,RXP7W1O7S,N,2YS<6PL=B`Q+C$N,BXQ(#(P,#8O,#,O,CD@
M,C$Z,C<Z-3(@:F%N($5X<"`D"@I!3%1%4B!404),12!H;W)D95]U<V5R<R!!
M1$0@0T],54U.('5S97)?<V]F=%]E>'!I<F%T:6]N7V1A=&4@24Y4.PI!3%1%
M4B!404),12!H;W)D95]U<V5R<R!!1$0@0T],54U.('5S97)?:&%R9%]E>'!I
M<F%T:6]N7V1A=&4@24Y4.PH*0U)%051%(%1!0DQ%(&AO<F1E7VAI<W1O<FEE
M<R`H"B`@("!H:7-T;W)Y7VED("`@("`@($))1TE.5"!.3U0@3E5,3"P*("`@
M(&]B:F5C=%]U:60@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,+`H@("`@
M:&ES=&]R>5]A8W1I;VX@("!605)#2$%2*#,R*2!.3U0@3E5,3"P*("`@(&AI
M<W1O<GE?=',@("`@("`@0DE'24Y4($Y/5"!.54Q,+`H@("`@:&ES=&]R>5]D
M97-C("`@("!415A4+`H@("`@:&ES=&]R>5]W:&\@("`@("!605)#2$%2*#(U
M-2DL"B`@("!H:7-T;W)Y7V5X=')A("`@(%1%6%0L"BTM"B`@("!04DE-05)9
M($M%62`H:&ES=&]R>5]I9"D**3L*"D-214%412!)3D1%6"!H:7-T;W)Y7V%C
M=&EO;E]I9'@@3TX@:&]R9&5?:&ES=&]R:65S("AH:7-T;W)Y7V%C=&EO;BD[
M"D-214%412!)3D1%6"!H:7-T;W)Y7W1S7VED>"!/3B!H;W)D95]H:7-T;W)I
M97,@*&AI<W1O<GE?=',I.PI#4D5!5$4@24Y$15@@:&ES=&]R>5]U:61?:61X
M($].(&AO<F1E7VAI<W1O<FEE<R`H;V)J96-T7W5I9"D["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<V-R:7!T<R]L9&%P
M+VAO<F1E+G-C:&5M80``````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#,T-3`V(#$P-3$U-#,T,30S(#`R,C0S-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C("1(;W)D93H@:&]R9&4O<V-R
M:7!T<R]L9&%P+VAO<F1E+G-C:&5M82QV(#$N,C`N,3`N-2`R,#`U+S$P+S$X
M(#$Q.C,T.C`P(&IA;B!%>'`@)`HC"B,@5&AE(&]F9FEC86P@:&]R9&4@3TE$
M(&%S<VEG;F5D(&)Y($E!3D$@:7,@,3,P-#`N"B,*(R!4:&ES('-C:&5M82!D
M97!E;F1S(&]N.@HC"2T@8V]R92YS8VAE;6$*(PHC(`HC($AO<F1E(&%T=')I
M8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,BXQ+BH*(R!)35`@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS+C$N*@HC(%1U<F)A
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*(R!+
M<F]N;VQI=&@@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU
M+C$N*@HC($YA9R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C8N,2XJ"B,@1V]L;&5M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N-RXQ+BH*(R!#:&]R82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C@N,2XJ"B,@36YE;6\@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XY+C$N*@HC(%1R;VQL(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,3`N,2XJ"B,@2VQU='H@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,2XQ+BH*(R!*;VYA:"!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$R+C$N*@HC($AE<FUE<R!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C$N*@HC($IU
M;F\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XQ+BH*
M(R!4<F5A;B!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$U
M+C$N*@HC(%=H=7!S(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,38N,2XJ"B,@26YG;R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$W+C$N*@HC($%N<V5L(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,3@N,2XJ"B,@1V5N:64@871T<FEB=71E(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XQ.2XQ+BH*(R!38W)Y(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N,2XJ"B,@5VEC:V5D(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C$N,2XJ"B,@06=O<F$@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,BXQ+BH*(R!';V]P
M<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C$N*@HC
M($UE<FL@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-2XQ
M+BH*(R!-:6UP(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,C8N,2XJ"B,@36]T=&QE(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,C<N,2XJ"B,@3FEC(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C@N,2XJ"B,@3V-C86T@871T<FEB=71E(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR.2XQ+BH*(R!/9&EN(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,S`N,2XJ"B,@4F%K:6T@871T<FEB=71E(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,2XQ+BH*(R!397-H82!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,R+C$N*@HC(%-W;V]S:"!A
M='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,S+C$N*@HC(%1H
M;W(@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-"XQ+BH*
M(R!5;&%F;W)M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N
M,S4N,2XJ"B,@5F]L;W,@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XS-BXQ+BH*(R`*(R!(;W)D92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,BXR+BH*(R!)35`@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C,N,BXJ"B,@5'5R8F$@;V)J96-T8VQA<W,@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C0N,BXJ"B,@2W)O;F]L:71H(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C(N*@HC($Y!
M1R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-BXR+BH*
M(R!';VQL96T@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C<N,BXJ"B,@0VAO<F$@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C@N,BXJ"B,@36YE;6\@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+CDN,BXJ"B,@5')O;&P@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C$P+C(N*@HC($ML=71Z(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,2XR+BH*(R!*;VYA:"!O8FIE
M8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3(N,BXJ"B,@2&5R
M;65S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ,RXR
M+BH*(R!*=6YO(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XQ-"XR+BH*(R!4<F5A;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,34N,BXJ"B,@5VAU<',@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$V+C(N*@HC($EN9V\@;V)J96-T8VQA<W,@8G)A
M;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C$W+C(N*@HC($%N<V5L(&]B:F5C=&-L
M87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ."XR+BH*(R!'96YI92!O
M8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3DN,BXJ"B,@
M4V-R>2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N
M,BXJ"B,@5VEC:V5D(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XR,2XR+BH*(R!!9V]R82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,C(N,BXJ"B,@1V]O<',@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C(N*@HC($UE<FL@;V)J96-T8VQA<W,@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(U+C(N*@HC($UI;7`@;V)J96-T
M8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(V+C(N*@HC($UO='1L
M92!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C<N,BXJ
M"B,@3FEC(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR
M."XR+BH*(R!/8V-A;2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,CDN,BXJ"B,@3V1I;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N
M,2XT+C$N,3,P-#`N,S`N,BXJ"B,@4F%K:6T@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C(N*@HC(%-E<VAA(&]B:F5C=&-L87-S
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,BXR+BH*(R!3=V]O<V@@;V)J
M96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,S+C(N*@HC(%1H
M;W(@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,T+C(N
M*@HC(%5L869O<FT@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C,U+C(N*@HC(%9O;&]S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ
M+C0N,2XQ,S`T,"XS-BXR+BH*"B,*(R!(;W)D92!A='1R:6)U=&4@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C(N,2XQ"@E.04U%("=H;W)D95!R969S)PH)1$53
M0R`G2&]R9&4@4')E9F5R96YC97,G"@E%455!3$E462!C87-E26=N;W)E24$U
M36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ
M,#(T?2`I"@HC"B,@24U0(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,RXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P
M-#`N,RXQ+C$*"4Y!344@)VEM<%!R969S)PH)1$530R`G24U0(%!R969E<F5N
M8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1U<F)A
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+BH*(PIA
M='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C$*"4Y!344@
M)W1U<F)A4')E9G,G"@E$15-#("=4=7)B82!0<F5F97)E;F-E<R<*"45154%,
M2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T
M-C8N,3$U+C$R,2XQ+C(V>S$P,C1]("D*"F%T=')I8G5T971Y<&4@*"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XT+C$N,@H)3D%-12`G='5R8F%4>7!E)PH)1$530R`G
M5'5R8F$@3V)J96-T(%1Y<&4Z($-O;G1A8W0O3&ES="<*"45154%,2519(&-A
M<V5)9VYO<F5)035-871C:`H)4U5"4U12(&-A<V5)9VYO<F5)0353=6)S=')I
M;F=S36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR
M-GLX?2`I"@IA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ
M+C,*"4Y!344@)W1U<F)A365M8F5R<R<*"41%4T,@)T5N8V]D960@;65M8F5R
M<R!O9B!A(%1U<F)A(&QI<W0G"@E355`@;F%M92`I"@IA='1R:6)U=&5T>7!E
M("@@,2XS+C8N,2XT+C$N,3,P-#`N-"XQ+C0*"4Y!344@)W1U<F)A4$=04'5B
M;&EC2V5Y)PH)1$530R`G4$=0+T=01R!0=6)L:6,@2V5Y)PH@("`@("`@($51
M54%,2519(&-A<V5)9VYO<F5)035-871C:`H)4UE.5$%8(#$N,RXV+C$N-"XQ
M+C$T-C8N,3$U+C$R,2XQ+C(V>S0P,#!]("D*"B,*(R!+<F]N;VQI=&@@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N*@HC"F%T=')I
M8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XU+C$N,0H)3D%-12`G:W)O
M;F]L:71H4')E9G,G"@E$15-#("=+<F]N;VQI=&@@4')E9F5R96YC97,G"@E%
M455!3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q+C,N-BXQ+C0N
M,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@3F%G(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-BXQ+BH*(PIA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N-BXQ+C$*"4Y!344@)VYA9U!R969S
M)PH)1$530R`G3F%G(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R
M94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N
M,C9[,3`R-'T@*0H*(PHC($=O;&QE;2!A='1R:6)U=&4@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C<N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C<N,2XQ"@E.04U%("=G;VQL96U0<F5F<R<*"41%4T,@)T=O
M;&QE;2!0<F5F97)E;F-E<R<*"45154%,2519(&-A<V5)9VYO<F5)035-871C
M:`H)4UE.5$%8(#$N,RXV+C$N-"XQ+C$T-C8N,3$U+C$R,2XQ+C(V>S$P,C1]
M("D*"B,*(R!#:&]R82!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C@N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C@N,2XQ"@E.04U%("=C:&]R85!R969S)PH)1$530R`G0VAO<F$@4')E9F5R
M96YC97,G"@E%455!3$E462!C87-E26=N;W)E24$U36%T8V@*"5-93E1!6"`Q
M+C,N-BXQ+C0N,2XQ-#8V+C$Q-2XQ,C$N,2XR-GLQ,#(T?2`I"@HC"B,@36YE
M;6\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N*@HC
M"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XY+C$N,0H)3D%-
M12`G;6YE;6]0<F5F<R<*"41%4T,@)TUN96UO(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1R;VQL(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3`N,2XJ"B,*871T<FEB=71E
M='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$P+C$N,0H)3D%-12`G=')O;&Q0
M<F5F<R<*"41%4T,@)U1R;VQL(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S
M94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N
M,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($ML=71Z(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,3$N,2XJ"B,*871T<FEB=71E='EP92`H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$Q+C$N,0H)3D%-12`G:VQU='I0<F5F<R<*"41%
M4T,@)TML=71Z(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($IO;F%H(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,3(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C$R+C$N,0H)3D%-12`G:F]N86A0<F5F<R<*"41%4T,@)TIO;F%H
M(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E3
M64Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*
M(PHC($AE<FUE<R!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C$S+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ
M,RXQ+C$*"4Y!344@)VAE<FUE<U!R969S)PH)1$530R`G2&5R;65S(%!R969E
M<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($IU
M;F\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-"XQ+BH*
M(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,30N,2XQ"@E.
M04U%("=J=6YO4')E9G,G"@E$15-#("=*=6YO(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%1R96%N(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N,2XJ"B,*871T<FEB=71E
M='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$U+C$N,0H)3D%-12`G=')E86Y0
M<F5F<R<*"41%4T,@)U1R96%N(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S
M94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N
M,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%=H=7!S(&%T=')I8G5T92!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N,38N,2XJ"B,*871T<FEB=71E='EP92`H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C$V+C$N,0H)3D%-12`G=VAU<'-0<F5F<R<*"41%
M4T,@)U=H=7!S(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($EN9V\@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XQ-RXQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N
M,3,P-#`N,3<N,2XQ"B`@("`@("!.04U%("=I;F=O4')E9G,G"B`@("`@("!$
M15-#("=);F=O(%!R969E<F5N8V5S)PH@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"B`@("`@("!364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($%N<V5L(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3@N,2XJ"B,*871T<FEB=71E='EP92`H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C$X+C$N,0H@("`@("`@3D%-12`G86YS96Q0
M<F5F<R<*("`@("`@($1%4T,@)T%N<V5L(%!R969E<F5N8V5S)PH@("`@("`@
M15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"B`@("`@("!364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=E;FEE
M(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3DN,2XJ"B,*
M871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C$Y+C$N,0H)3D%-
M12`G9V5N:650<F5F<R<*"41%4T,@)T=E;FEE(%!R969E<F5N8V5S)PH)15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%-C<GD@871T<FEB=71E
M(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,"XQ+BH*(PIA='1R:6)U=&5T
M>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C`N,2XQ"@E.04U%("=S8W)Y4')E
M9G,G"@E$15-#("=38W)Y(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%=I8VME9"!A='1R:6)U=&4@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+C(Q+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR,2XQ+C$*"4Y!344@)W=I8VME9%!R969S)PH)1$53
M0R`G5VEC:V5D(%!R969E<F5N8V5S)PH)15%504Q)5%D@8V%S94EG;F]R94E!
M-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[
M,3`R-'T@*0H*(PHC($%G;W)A(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,C(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(R+C$N,0H@("`@("`@($Y!344@)V%G;W)A4')E9G,G"B`@("`@
M("`@1$530R`G06=O<F$@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@
M8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($=O;W!S(&%T=')I8G5T92!B<F%N
M8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C0N,2XJ"B,*871T<FEB=71E='EP92`H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(T+C$N,0H@("`@("`@($Y!344@)V=O;W!S
M4')E9G,G"B`@("`@("`@1$530R`G1V]O<',@4')E9F5R96YC97,G"B`@("`@
M("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N
M,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($UE<FL@871T
M<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-2XQ+BH*(PIA='1R
M:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C4N,2XQ"B`@("`@("`@
M3D%-12`G;65R:U!R969S)PH@("`@("`@($1%4T,@)TUE<FL@4')E9F5R96YC
M97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M($UI;7`@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR-BXQ
M+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N,2XQ
M"B`@("`@("`@3D%-12`G;6EM<%!R969S)PH@("`@("`@($1%4T,@)TU)35`@
M4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC($UO='1L92!A='1R:6)U=&4@8G)A;F-H(#$N,RXV+C$N-"XQ
M+C$S,#0P+C(W+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XR-RXQ+C$*("`@("`@("!.04U%("=M;W1T;&50<F5F<R<*("`@("`@
M("!$15-#("=-;W1T;&4@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@
M8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ
M,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($YI8R!A='1R:6)U=&4@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C(X+C$N*@HC"F%T=')I8G5T971Y<&4@*"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XR."XQ+C$*("`@("`@("!.04U%("=N:6-0<F5F
M<R<*("`@("`@("!$15-#("=.24,@4')E9F5R96YC97,G"B`@("`@("`@15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($]C8V%M(&%T=')I8G5T
M92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,CDN,2XJ"B,*871T<FEB=71E
M='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C(Y+C$N,0H@("`@("`@($Y!344@
M)V]C8V%M4')E9G,G"B`@("`@("`@1$530R`G3V-C86T@4')E9F5R96YC97,G
M"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@
M,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($]D
M:6X@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,"XQ+BH*
M(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S`N,2XQ"B`@
M("`@("`@3D%-12`G;V1I;E!R969S)PH@("`@("`@($1%4T,@)T]D:6X@4')E
M9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H
M"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@
M*0H*(PHC(%)A:VEM(&%T=')I8G5T92!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P
M-#`N,S$N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV+C$N-"XQ+C$S,#0P
M+C,Q+C$N,0H@("`@("`@($Y!344@)W)A:VEM4')E9G,G"B`@("`@("`@1$53
M0R`G4F%K:6T@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG
M;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q
M+C$N,C9[,3`R-'T@*0H*(PHC(%-E<VAA(&%T=')I8G5T92!B<F%N8V@@,2XS
M+C8N,2XT+C$N,3,P-#`N,S(N,2XJ"B,*871T<FEB=71E='EP92`H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C,R+C$N,0H@("`@("`@($Y!344@)W-E<VAA4')E9G,G
M"B`@("`@("`@1$530R`G4V5S:&$@4')E9F5R96YC97,G"B`@("`@("`@15%5
M04Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N
M,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%-W;V]S:"!A='1R:6)U
M=&4@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,S+C$N*@HC"F%T=')I8G5T
M971Y<&4@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS,RXQ+C$*("`@("`@("!.04U%
M("=S=V]O<VA0<F5F<R<*("`@("`@("!$15-#("=3=V]O<V@@4')E9F5R96YC
M97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y4
M05@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC
M(%1H;W(@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XS-"XQ
M+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N,3,P-#`N,S0N,2XQ
M"B`@("`@("`@3D%-12`G=&AO<E!R969S)PH@("`@("`@($1%4T,@)U1H;W(@
M4')E9F5R96YC97,G"B`@("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA
M=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R
M-'T@*0H*(PHC(%5L869O<FT@871T<FEB=71E(&)R86YC:"`Q+C,N-BXQ+C0N
M,2XQ,S`T,"XS-2XQ+BH*(PIA='1R:6)U=&5T>7!E("@@,2XS+C8N,2XT+C$N
M,3,P-#`N,S4N,2XQ"B`@("`@("`@3D%-12`G=6QA9F]R;5!R969S)PH@("`@
M("`@($1%4T,@)U5L869O<FT@4')E9F5R96YC97,G"B`@("`@("`@15%504Q)
M5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS+C8N,2XT+C$N,30V
M-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC(%9O;&]S(&%T=')I8G5T92!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S8N,2XJ"B,*871T<FEB=71E='EP
M92`H(#$N,RXV+C$N-"XQ+C$S,#0P+C,V+C$N,0H@("`@("`@($Y!344@)W9O
M;&]S4')E9G,G"B`@("`@("`@1$530R`G5F]L;W,@4')E9F5R96YC97,G"B`@
M("`@("`@15%504Q)5%D@8V%S94EG;F]R94E!-4UA=&-H"@E364Y405@@,2XS
M+C8N,2XT+C$N,30V-BXQ,34N,3(Q+C$N,C9[,3`R-'T@*0H*(PHC($AO<F1E
M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR+C(N*@HC
M"F]B:F5C=&-L87-S("@@,2XS+C8N,2XT+C$N,3,P-#`N,BXR+C$*("`@($Y!
M344@)VAO<F1E4&5R<V]N)PH@("`@1$530R`G2&]R9&4@4')E9F5R96YC97,G
M"B`@("!355`@=&]P"B`@("!!55A)3$E!4ED*("`@($U!62`H(&UA:6P@)"!H
M;W)D95!R969S("0@:6UP4')E9G,@)"!T=7)B85!R969S("0*("`@("`@("!G
M;VQL96U0<F5F<R`D(&MR;VYO;&ET:%!R969S("0@;6YE;6]0<F5F<R`D"B`@
M("`@("`@=')O;&Q0<F5F<R`D(&YA9U!R969S("0@:VQU='I0<F5F<R`D"B`@
M("`@("`@:F]N86A0<F5F<R`D(&AE<FUE<U!R969S("0@:G5N;U!R969S("0*
M("`@("`@("!T<F5A;E!R969S("0@=VAU<'-0<F5F<R`D(&EN9V]0<F5F<R`D
M"B`@("`@("`@9V5N:650<F5F<R`D('-C<GE0<F5F<R`D(&%N<V5L4')E9G,@
M)`H@("`@("`@('=I8VME9%!R969S("0@8VAO<F%0<F5F<R`D(&%G;W)A4')E
M9G,@)`H@("`@("`@(&=O;W!S4')E9G,@)"!M97)K4')E9G,@)"!V;VQO<U!R
M969S("0*("`@("`@("!M:6UP4')E9G,@)"!M;W1T;&50<F5F<R`D(&YI8U!R
M969S("0*("`@("`@("!O8V-A;5!R969S("0@;V1I;E!R969S("0@<F%K:6U0
M<F5F<R`D"B`@("`@("`@<V5S:&%0<F5F<R`D('-W;V]S:%!R969S("0@=&AO
M<E!R969S("0*("`@("`@("!U;&%F;W)M4')E9G,*("`@("D@*0H*;V)J96-T
M8VQA<W,@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR+C(N,@H@("`@3D%-12`G:&]R
M9&5'<F]U<"<*("`@($1%4T,@)TAO<F1E($=R;W5P)PH@("`@4U50('1O<`H@
M("`@055824Q)05)9"B`@("!-05D@*"!M86EL("D@*0H*(PHC($E-4"!O8FIE
M8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,RXR+BH*(PH*(R!4
M=7)B82!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-"XR
M+BH*;V)J96-T8VQA<W,@*"`Q+C,N-BXQ+C0N,2XQ,S`T,"XT+C(N,0H@($Y!
M344@)W1U<F)A0V]N=&%C="<*("!$15-#("=4=7)B82!#;VYT86-T)PH@(%-5
M4"!T;W`*("!!55A)3$E!4ED*("!-05D@*"!T=7)B851Y<&4@)"!T=7)B84UE
M;6)E<G,@*0H@*0H*(PHC($MR;VYO;&ET:"!O8FIE8W1C;&%S<R!B<F%N8V@@
M,2XS+C8N,2XT+C$N,3,P-#`N-2XR+BH*(PH*(PHC($YA9R!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-BXR+BH*(PH*(PHC($=O;&QE
M;2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N-RXR+BH*
M(PH*(PHC($-H;W)A(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ
M,S`T,"XX+C(N*@HC"@HC"B,@36YE;6\@;V)J96-T8VQA<W,@8G)A;F-H(#$N
M,RXV+C$N-"XQ+C$S,#0P+CDN,BXJ"B,*"B,*(R!4<F]L;"!O8FIE8W1C;&%S
M<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3`N,BXJ"B,*"B,*(R!+;'5T
M>B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,3$N,BXJ
M"B,*"B,*(R!*;VYA:"!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N
M,3,P-#`N,3(N,BXJ"B,*"B,*(R!(97)M97,@;V)J96-T8VQA<W,@8G)A;F-H
M(#$N,RXV+C$N-"XQ+C$S,#0P+C$S+C(N*@HC"@HC"B,@2G5N;R!O8FIE8W1C
M;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,30N,BXJ"B,*"B,*(R!4
M<F5A;B!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,34N
M,BXJ"B,*"B,*(R!7:'5P<R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,38N,BXJ"B,*"B,*(R!);F=O(&]B:F5C=&-L87-S(&)R86YC
M:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ-RXR+BH*(PH*(PHC($%N<V5L(&]B:F5C
M=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ."XR+BH*(PH*(PHC
M($=E;FEE(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XQ
M.2XR+BH*(PH*(PHC(%-C<GD@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N
M-"XQ+C$S,#0P+C(P+C(N*@HC"@HC"B,@5VEC:V5D(&]B:F5C=&-L87-S(&)R
M86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,2XR+BH*(PH*(PHC($%G;W)A(&]B
M:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T,"XR,BXR+BH*(PH*
M(PHC($=O;W!S(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR-"XR+BH*(PH*(PHC($UE<FL@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV
M+C$N-"XQ+C$S,#0P+C(U+C(N*@HC"@HC"B,@36EM<"!O8FIE8W1C;&%S<R!B
M<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,C8N,BXJ"B,*"B,*(R!-;W1T;&4@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C(W+C(N*@HC
M"@HC"B,@3FEC(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N-BXQ+C0N,2XQ,S`T
M,"XR."XR+BH*(PH*(PHC($]C8V%M(&]B:F5C=&-L87-S(&)R86YC:"`Q+C,N
M-BXQ+C0N,2XQ,S`T,"XR.2XR+BH*(PH*(PHC($]D:6X@;V)J96-T8VQA<W,@
M8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,P+C(N*@HC"@HC"B,@4F%K:6T@
M;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,Q+C(N*@HC
M"@HC"B,@4V5S:&$@;V)J96-T8VQA<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S
M,#0P+C,R+C(N*@HC"@HC"B,@4W=O;W-H(&]B:F5C=&-L87-S(&)R86YC:"`Q
M+C,N-BXQ+C0N,2XQ,S`T,"XS,RXR+BH*(PH*(PHC(%1H;W(@;V)J96-T8VQA
M<W,@8G)A;F-H(#$N,RXV+C$N-"XQ+C$S,#0P+C,T+C(N*@HC"@HC"B,@56QA
M9F]R;2!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT+C$N,3,P-#`N,S4N
M,BXJ"B,*"B,*(R!6;VQO<R!O8FIE8W1C;&%S<R!B<F%N8V@@,2XS+C8N,2XT
M+C$N,3,P-#`N,S8N,BXJ"B,*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&\O9F%?25(N<&\`````````````````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`Q,#`U,S`S(#$P-3$U-#,T,30R(#`Q-S0W,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($AO
M<F1E(%!E<G-I86X@=')A;G-L871I;VYS+@HC(%1H:7,@9FEL92!I<R!D:7-T
M<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P
M86-K86=E+@HC(`HC($-O<'ER:6=H="`H0RD@,C`P-"!(:6=H($-O;F-I;"!O
M9B!);F9O<FUA=&EC<R`H=W=W+G-H8VDN:7(I"B,@4')O=FED960@8GD@($%M
M:7)K86)I<B!-971A;F5T=V]R:VEN9R!,=&0L(#(P,#0@/'!E<G-I86XM:&]R
M9&5`;65T86YE='=O<FMI;F<N8V]M/@HC($UO:'-E;B!.861E<BU"861R("`@
M("`@(#QN861E<FE`;65T86YE='=O<FMI;F<N8V]M/@HC($-H86-K86UE:"!-
M;W)T97IA;FEA("`@(#QM;W)T97IA;FEA0&UE=&%N971W;W)K:6YG+F-O;3X*
M(R!386QM86X@3FEK<V5F870@("`@("`@("`\;FEK<V5F871`;65T86YE='=O
M<FMI;F<N8V]M/@HC($AA;65D($=H97EB:2`@("`@("`@("`@(#QG:&5Y8FE`
M;65T86YE='=O<FMI;F<N8V]M/@HC(%9A:&ED($=H869A<G!O=7(@("`@("`@
M(#QG:&%F87)P;W5R0&UE=&%N971W;W)K:6YG+F-O;3X*(R!:86AR82!!:&UA
M9&D@("`@("`@("`@("`\86AM861I0&UE=&%N971W;W)K:6YG+F-O;3X*(R`*
M;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E
M(#,@7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-RTP."`Q-3HR-RLP
M,C`P7&XB"B),87-T+51R86YS;&%T;W(Z06UI<FMA8FER($UE=&%N971W;W)K
M:6YG(&QT9"X@/'!E<G-I86XM:&]R9&5`;65T86YE='=O<FMI;F<N(@HB8V]M
M/EQN(@HB3&%N9W5A9V4M5&5A;3H@4&5R<VEA;B`\:3$X;D!L:7-T<RYH;W)D
M92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/5541BTX7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B`HV+'9B-BR(-F"V*C9A"`E<RDB"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(BC:J=F$VXS8KR#8K]BSV*K8
ML=BSVXP@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(BC8
MK]BQ("5S(-BQV8C8LBDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*-BGV878L=F(V+(I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO
M<G)O=RDB"FUS9W-T<B`B("C9@=BQV*_8IRDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B
M("C8K]N,V+'9B-BR*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S
M='(@(B#8K]BQ("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@
M9&ER96-T;W)Y+B(*;7-G<W1R("+;C-JI(-BTV*?8KMF'(-F&VXS8L]BJ(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS
M9W-T<B`B)R5S)R#8I]F&V*K8KMBGV*@@V878N=BJV*C8L=N,(-F&VXS8L]BJ
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(-BO
MV+$@V+'8K-N,V+/8JMBQ(-F'V8C8L=BO(-F^VXS:J=BQV*C9AMBOVXP@V8;8
MM-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD
M97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(B<E<R<@V*?8K-BQV*<@VJG9AMF&
MV*_9AR#8K]BQV*[8JB#9OMN,V*_8IR#9AMBTV*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B#8J-F'(-JOV+'9B-F'XH",V8?8I]N,(-BSV*?9A=BGV8;9AR#8I]BVV*?9
M@=F'(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@V*C9AR#8
ML]BGV878I]F&V8<@V878K-F(V++B@(S9A]BG(-BGV+;8I]F!V8<@V+38KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(@V*?;C-BLV*?8KR#9
MAMBTV*_9AR#8J-F(V*\Z("5S+B(*"B,@"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E
M+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@V*?8L]BJ
MV8'8I]BOV8<@V+38K]F'(-BGV+(@)2XR9DU"(-F%V*S8I]BR("@E+C)F34(I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@V8@@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("+8
MI]BSV84@V+'9A=BR(-BTV878IR`E9"#8L=F(V+(@V*_;C-JOV+$@V878N=BJ
MV*C8L2#8I]BSV*HN(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A
M<W0B"FUS9W-T<B`BV;[;C-BTPJW8J-N,V8;;C"`E9"W8L=F(V++9AR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(-BJV8C8K-F'
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`BV*?8
MJ]BQ(-BGV8;:K]BTV*H@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(MJI
MVXS9A-F(V*C8I]N,V*H@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R#8N=F%
MV83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@+2#8JMBCVXS;C-BO(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B#8
ML=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C"`E<R`B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@V*O8J-BJ(-F&V*?9A2(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`BV+38L=F(
MV+<@V*K9B-BGV8'9@B`E<R(*"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R("(E<R#8I]BR(-F"V*C9A"#9A=F(V*S9B-BO(-BG
MV+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@
M(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@
M(B5S(-BOV+$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R#8
MHMF%V*?8K]F'(-BGV*S8L=BGVXP@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8
ML=N,(-BGV8;8JMBNV*?8J"#8M-BOV8<@V*?8L]BJ+B#8K-BYV*C9AR#9A]BQ
M(-BYV879A-N,V*?8JMN,(-BQV*<@VJG9AR#9A]F%(-BGVJG9AMF(V88@(@HB
MV87;C.*`C-BNV8C8I]F'VXS8KR#8I]BLV+'8IR#:J=F&VXS8KR#8N=F$V*?9
MA=BJ(-BHV++9AMN,V*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S
M='(@(B5S(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JB(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&UI;G5T97,B"FUS9W-T<B`B)7,@V*_9@MN,V8+9AR(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R#9OMN,V*_8IR#9
MAMBTV*\B"@HC(`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(B5S(-BHV8<@)7,@V*?8LB`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(R"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!"
M;V]K(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4(-BBV*_8L=BS("5S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("+8JMF"V8C;C-F%("5S(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S)W,@3F]T
M97!A9"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`BV8'9A]BQ
MV+/8JB#9B-BXV*?;C-F!("5S(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F
M<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG
M("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E
M<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@
M(@IM<V=S='(@(MB,(-BHV*?8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("+8C"#8J-BGV*\@
M)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B
MV(P@V878JMBZVXS;C-BQ(-BGV+(@)7,@V*C9AR`E<R(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B(-BGV8;8JMBNV*?8J"`B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(MF"V*?9
MA-BH(-NQV[(@V+/8I]BYV*K;C"(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`BV8+8I]F$V*@@V[+;
MM"#8L]BGV+G8JMN,(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*
M;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(MNRV[0@V+/8I]BYV*K9AR(*"B,Z
M(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("+8M=F!V*W9AR#9@MBHV83;C"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(MN,VJD@
MV;[8M-BJVXS8J-BGV88@V*_8I]BOVJ_8I]F&(-BHV+'8I]N,(-BGVXS9AB#8
MJ-F$V*?:J2#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960B"FUS9W-T<B`BVXS:J2#8KMBWV*?;C"#8K-BOVXP@V+'8
MKB#8K]BGV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(MN,VJD@VJG9A-N,
MV*\@V+G9A=F(V87;C"!01U`@V*C8L=BGVXP@V+'9A=BRV*C9AMBOVXP@VXS:
MJ2#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(MN,VJD@VJG9A-N,V*\@V+G9A=F(V87;C"!01U`@
MV*C8L=BGVXP@V*C8I]BRV*C;C-F&VXP@VXS:J2#9OMN,V+K8I]F%(-BGV878
MMMBGV*$@V+38K]F'(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B+;C-JI(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI(-JIV83;
MC-BO(-BNV+79B-BUVXP@4$=0(-F((-N,VJD@V+G8J-BGV+'8JB#:K]BPV+$@
MV*C8L=BGVXP@V+'9A=BRVJ_8M-BGVXS;C"#;C-JI(-F^VXS8NMBGV84@V879
MB-BQV*\@(@HBV8;;C-BGV+(@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(MN,VJD@VJG9
MA-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!0
M1U`@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8I]F%V+;8
MI]BA(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR`B"B+9AMN,V*?8LB#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(MN,VJD@VJG9A-N,V*\@V+G9A=F(
MV87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!3+TU)344@V8@@VXS:
MJ2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8L=F%V++:K]BTV*?;C-N,
M(-F^VXS8NMBGV84@V879B-BQV*\@(@HBV8;;C-BGV+(@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"B+;C-JI(-JIV83;C-BO(-BYV879B-F%VXS8C"#;C-JI
M(-JIV83;C-BO(-BNV+79B-BUVXP@4R]-24U%(-F((-N,VJD@V+G8J-BGV+'8
MJB#:K]BPV+$@V*C8L=BGVXP@V*?9A=BVV*?8H2#;C-JI(-F^VXS8NMBGV84@
MV879B-BQV*\@(@HBV8;;C-BGV+(@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`BVXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,(%,O34E-12#8J-BQV*?;C"#8
ML=F%V++8J-F&V*_;C"#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BG
MV+/8JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("+8I]BHV+'9
MA]BG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`BV*C8I]BQV*?9AB#8
ML]BHVJD@V+78J-BMVJ_8I]F'VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("+8
MJ-BGV+'8I]F&(-BUV*C8K=JOV*?9A]N,(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS
M9W-T<B`BV+':K]BHV*?8L2#8M=BHV*W:K]BGV8?;C"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W
M(%-H;W=E<G,B"FUS9W-T<B`BV*K:K]BQVJ\@V+78J-BMVJ_8I]F'VXPB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS
M9W-T<B`BV+78J-BM+]BYV+78L2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(MBOV+'8
MJ-BGV+'9AR#8I]N,V88@V8C;C-BQV*?8L]BJV*?8L2(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("+8
MK]BQV*C8I]BQV8<N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`BV;[8
MI]N,VXS9AB#9A=BWV839@B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("+9
MB-BSV+<@V878M]F$V8(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(MBGVXS8K-BGV*\@V+38I]BNV8<@5D93(-F%V*S9
MB-BR(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`BV*?;C-BLV*?8KR#9OMBQV8C9AMBO
MV8<@5D93(-F%V*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBOV*?8L=BO(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*H@V*W8L]BGV*@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O
M<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8K=BSV*?8J"(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I
M9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(MBMV+/8I]BH(-F%V+/8K]F(
MV*\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"FUS9VED(")!
M8V-O=6YT:6YG(@IM<V=S='(@(MBMV+/8I]BHV*_8I]BQVXPB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8
MK]F&(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H
M<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("+8I]BVV*?9
M@=F'(-JIV+'8K]F&(-JOV+'9B-F'(-F!V+'8N=N,(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R
M("+8I]BVV*?9@=F'(-JIV+'8K]F&(-F%V*S9B-BR(-F!V+'8N=N,XH",(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E
M.B(*;7-G<W1R("+8I]N,V8;8K-BG(-BGV+;8I]F!V8<@VJG9ACHB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&
M(-JOV+'9B-F'(-BLV*_;C-BO(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS
M9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`BV*?8MMBGV8'9AR#:
MJ=BQV*_9AB#9A=BLV8C8LB#8K-BOVXS8KR(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R("+8
MI]BVV*?9@=F'(-JIV+'8K]F&(-N,VJD@VJ_8L=F(V8<@V8'8L=BYVXP@V*C9
MAR`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R!<(B5S7"(B"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-F%
MV*S9B-BR(-F!V+'8N=N,(-BHV8<@7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+8I]BVV*?9
M@=F'(-JIV+'8K]F&(-N,VJD@VJG8I]BQV*C8L2#8K-BOVXS8KSHB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED
M(")!9&0@8V]L=6UN(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V+/8
MJMF(V88B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T
M"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`BV*?8MMBGV8'9AR#:
MJ=BQV*_9AB#8I]BYV+;8I]N,(-BLV*_;C-BO(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BV*?8
MMMBGV8'9AR#:J=BQV*_9AB#8LMF(V*PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N
M=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(@V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#:K]BRVXS9AMJOV*?9AB`E<R#8J-BYV8;9B-BGV88@V8;9B-BG
MV+$@V*S8I]F&V*C;C"#9A=F(V++;C-F$V*<B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R
M97-S(&)O;VLZ(@IM<V=S='(@(MBGV+;8I]F!V8<@VJG8L=BOV88@V*C9AR#:
MJ=BJV*?8J-J&V8?9E"#8HMBOV+'8LSHB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R
M97-S(&)O;VLB"FUS9W-T<B`BV*?8MMBGV8'9AR#:J=BQV*_9AB#8J-F'(-JI
MV*K8I]BHVH;9A]F4(-BBV*_8L=BS(-F%V88B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`BV*?8MMBGV8'9AR#9@]BQ
MV*_9AB#:J=BGV+'8J-BQ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z-SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I
M9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(B<E<R<@V*C9
MAR#8L]BGV878I]F&V8<@V*?8MMBGV8'9AR#8M-BOV(P@V*?9A=BG(-F&V87;
MC.*`C-BJV8C8I]F&(-BGV+?9A-BGV+G8I]BJ(-BOVXS:K]BQ(-BGV8'8JMBJ
MV*?8K2#8K=BSV*?8J"#8L=BG(-BGV+;8I]F!V8<@VJG8L=BO(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RXB"FUS9W-T<B`B)R5S)R#8J-F'(-BSV*?9A=BGV8;9AR#8I]BVV*?9@=F'
M(-BTV*\N(-BGVJG9AMF(V88@V+39A=BG(-F%VXSB@(S8JMF(V*?9AMN,V*\@
MV8C8I]BQV*\@V+39B-N,V*\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("+8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-F!
MV+G8I]F$(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*
M;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS
M9W-T<B`BVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM
M<V=S='(@(MBSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<M(-BJV+G;C-N,V88@
MV878K-F(V++9A]BGVXP@VJG8I]BQV*C8L=BGV88@V*_;C-JOV+$B"@HC.B!A
M9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BV+/8L=F^V+'8
ML]BJVXPB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED
M(")!9',B"FUS9W-T<B`BV*K8J-F$VXS8NMBGV*HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"B,L
M(&9U>GIY"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("+8L]BGV++9A=BG
MV88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S
M='(@(MF%V+G8I]BOV80B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!
M;&=E<FEA(@IM<V=S='(@(MF%V+G8I]BOV80B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G
M<W1R("+9A=BYV*?8K]F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B
MV*K8L=BGV+(@VJG8L=BOV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(MBJV+'8I]BR.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I
M9"`B06QL(@IM<V=S='(@(MF'V879AR(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*
M;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(MBJV878
MI]F%VXP@VJG8I]BQV*C8L=BGV88@V*K8H]N,VXS8KR#8M=F$V*?8K=N,V*H@
MV+38K]F'(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N
M<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("+9A]F%V8<@VJ_8
ML=F(V8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`BV8?9A=F'(-F%V*S9B-BR
MXH",V8?8IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@
M(MF'V879A]F4(-J&V8?8I]BQ(-BSV878JB(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E
M<R(*;7-G<W1R("+8I]BLV*?8LMF'(-J&V8;8KR#8HMBOV+'8L]N,(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`BV*+;C-BG(-BGV*S8
MI]BRV8<@V*K9AMBXVXS9A2#9AMF(V+D@V8'9A]BQV+/8JB#9A=BQV*K8J"#8
MK]BGV*_9AR#8M-F(V*_8GR(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T
M<B`BV*?8LB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I
M;B(*;7-G<W1R("+9B-BQV8C8KR!)35-0(-BLV*?;C-JOV++;C-F&(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB!)35-0(-BLV*?;
MC-JOV++;C-F&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I
M9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`BV8;8I]F%(-JI
MV*?8L=BHV+';C"!)35-0(-BLV*?;C-JOV++;C-F&(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9
MAMN,VJD@V*S8I]N,VJ_8LMN,V88B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("+8I]F$
MVJ_9B.*`C-F'V*?;C"#8K-BGVXS:K]BRVXS9AB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I
M9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(MF%V*K9AB#8K-BGVXS:K]BR
MVXS9ACHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(MN,VJD@V879@MBO
MV*?8L2#9AMBGV*_8L=BSV*H@V*K8N=N,VXS9AB#8M-BOV8<@V*C9B-BO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM
M<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B
MVXS:J2#8KMBWV*?;C"#8K-BOVXP@V+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B
MV;[;C-BTVJG8I]BQ(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("+9OMBGV+/8KB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S
M='(@(MBHV+'9AMBGV879A]F4XH",(-JIV*?8L=BHV+'8K]N,(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(MF!V8?8L=BSV*H@V*C8L=F&V*?9A=F'XH",V8?8I]N,(-JI
MV*?8L=BHV+'8K]N,(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM
M<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(MBHV+'9AMBG
MV879AR#8HMF%V*?8K]F'(-BGV+/8JB(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS
M9W-T<B`BV*?8N=F%V*?9A"#8J-BQ(-BQV8C;C"#8I]BTV*K8L=BGVJG9A]BG
MVXP@V8'8L=BYVXPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("+8JMBUV8C;C-BH(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED
M(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(MBGV8;8K]BGV++9AR#8JMF"
MV+';C-BHVXPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`BV*+9B-BQVXS9A"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B07)A8FEC("A7:6YD;W=S+3$R-38I(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL
M92!3:7IE(@IM<V=S='(@(MBGV8;8K]BGV++9AR#9OMBQV8C9AMBOV8<@V*+8
ML=BTVXS9B"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED
M(")!<F-H:79E($YA;64B"FUS9W-T<B`BV8;8I]F%(-BBV+'8M-N,V8@B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(MBB
MVXS8IR#8M-F%V*<@V878M]F%V*;9AMN,V*\@VJG9AR#9A=N,XH",V*[9B-BG
MV8?;C-BO(-BGV+?9A-BGV+G8I]BJ(-BGV8'8JMBJV*?8K2#8K=BSV*?8J"`E
M<R#8L=BG(-F^V*?:J2#:J=F&VXS8K]B?(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E
M<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BV*+;C-BG(-BTV878
MIR#9A=BWV878IMF&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@)R5S
M)R#9B"#8JMF%V*?9A2#8LMN,V+$@VJ_8L=F(V8?B@(S9A]BGVXS8M"#8L=BG
M(-BMV+#9@2#:J=F&VXS8K]B?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R
M;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;65N:6%N("A!4DU30TE)
M+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B
M"FUS9W-T<B`BV8?9AMBQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I
M9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O
M4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(MBBVXS8
MIR#9@MBHV80@V*?8LB#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP@V*C8
ML=BGVXP@V*K8H]N,VXS8KR#8HMF&(-BSV*;9B-BGV80@V+39B-BOV)\@(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N
M;65N="!C;VQU;6YS(@IM<V=S='(@(MBGV8;8JMBSV*?8J"#8L]BJV8C9AMF'
MV*<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`BV+/8N=N,
M(-BOV+$@V*W8L-F!(-JOV+'9B-F'VXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%
MV8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("+8L]BYVXP@V*_8L2#8K=BPV8$@V878K-F(
MV++;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8JB(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BV+/8
MN=N,(-BOV+$@V8C;C-BQV*?;C-BT(-F%V*S9B-BRVXP@V+38K]F'(-BGV+/8
MJB#:J=F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!S:&%R92XB"FUS9W-T<B`BV+/8N=N,(-BOV+$@V8C;C-BQV*?;
MC-BT(-BGV+38JMBQV*?:J=N,(-BTV*_9AR#8I]BSV*H@VJG9AR#9A=F(V*S9
MB-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*
M;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`BXH",V8C;C-J8VJ_;C-F'V*<B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM
M<V=I9"`B075G=7-T(@IM<V=S='(@(MBBVJ_9B-BSV*HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F
M=7IZ>0IM<V=I9"`B075S=')I82(*;7-G<W1R("+8HMJOV8C8L]BJ(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T
M:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]C>7)S<6PZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,V*?8
MLB!)34%0(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D
M;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!
M=71H7V-Y<G-Q;#H@V+/8I]F%V*?9AMF'(-F^V+38JMN,V*C8I]F&(-F"V*?8
MJ-F$VXS8JMF'V*?;C"#9A=F(V+'8KR#9AMN,V*?8LB#8L=BG(-F&V*_8I]BQ
MV*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G
M:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:&EM<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8
MI]BR($E-05`@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@
M1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE
M("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(D%U=&A?9G1P.B#8
MJ-BSV+<@V879B-BQV*\@V8;;C-BGV+(@1E10(-F^VXS8K]BG(-F&V+38KR(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VEM<#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-
M05`@V;[;C-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@V*C8L]BW
M(-F%V8C8L=BO(-F&VXS8I]BR(&MR8C4@V;[;C-BOV*<@V8;8M-BO(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS
M9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B#8J-BSV+<@V879B-BQV*\@V8;;
MC-BGV+(@3$1!4"#9OMN,V*_8IR#9AMBTV*\B"@HC(`HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#K8I]BV
MV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BS
MV*HN(-BGVXS9AB#:AMN,V++;C"#8I]BSV*H@VJG9AR#:J=BGV+'8L]BGV+(@
MVJ_9@=BJV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.MBMV+#9
M@2#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#K8J-BQV8C8LMBQV+/8I]F&VXP@VJG8I]BQV*C8L2`E
M<R#9A=F%VJG9AB#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G
M:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(-BHV+/8MR#9A=F(V+'8KR#9AMN,
MV*?8LB!-0T%,(-F^VXS8K]BG(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M<VUB875T:#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR('-M8F%U=&@@V;[;
MC-BOV*<@V8;8M-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960B"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(
MVXS9D=BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KRX@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("+8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@V*?8LB#8M]BQV8$@VJG8I]BQV+/8I]BR(%)!
M1$E54R#8L=BO(-BTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8JB#8
MK]BQ(-JIV*?8L=BSV*?8LB!&5%`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO("(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BOV+$@VJG8I]BQV+/8
MI]BR($944"#9AMBGV879B-F!V9'9@B#8J-F(V*\@(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB
M"FUS9W-T<B`BV8';C-F$V*_9A]BGVXP@V8+8I]BHV80@V*_8L]BJV+'8L]N,
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M("+9OMBSXH",V++9A=N,V8;9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B
M"FUS9W-T<B`BV+'9AMJO(-F^V+/B@(S8LMF%VXS9AMF'(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-F&V*?8K]BQV+/8
MJB!K97)B97)O<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`BV8;8
MI]F%(-JIV*?8L=BHV+$@V8;8I]BOV+'8L]BJ(&ME<F)E<F]S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"B,L
M(&9U>GIY"FUS9VED(")"86AR86EN(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M
M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`BV+38I]BNV8<@VJ_8L=BGV8';C-JIVXP@V878J-F&V*?;C"`G)7,G(-N,
MV*?9@=BJ(-F&V+38KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B
MV*[8MR#9A=BHV8;8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B"FUS9W-T<B`B
MV*[8MR#9A=BHV8;8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)E
M;FEN(@IM<V=S='(@(MJOV+'8K]F'V878I]N,VXPB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H
M=71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO
M;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+8J-F$V8C:J2!<(B5S7"(@
MV*?8LB#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"!<(B5S7"(@VXS8
MI]F!V*H@V8;8M-BO(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("+8JMF&V+C;C-F%
MV*?8JB#8J-F$V8C:J2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("+9AMF(V+D@V*C9A-F(
MVJDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`BV+/;C-BGV8<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("+:AMF(
MV*@@V*?9A-F!(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(MF$V*C9
MAR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(MF^V8?9AMBG
MVXP@V838J-F'.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BV838
MJ-F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDV"FUS9VED(")";W1H(@IM<V=S='(@(MF'V+$@V*_9B"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T
M=&]M(@IM<V=S='(@(MF^V*?;C-N,V88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D)R87II;"(*;7-G<W1R("+9AMBGV879AR#8I]F$VJG8JMBQV8C9
MAMN,VJG;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*
M;7-G<W1R("+9A-N,V+/8JB#8J-F(V838JN*`C-BOV*?8L2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#
M4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM
M<V=S='(@(MF&V8+8I]BW(-BJV8C8LMN,V+D@0U),(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED
M(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(MBNV+79B-BUVXS8I]BJ
M(-BSV839B-F$+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PHC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"XB"FUS9W-T<B`BV8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878M-BN
MV+4@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N
M9&%R(@IM<V=S='(@(MBJV8+9B-N,V84B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(MBBV+'8I]F%
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(MF%
MV*_;C-BQ(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G
M:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(MF&V87;C.*`
MC-BJV8C8I]F&(-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BWV8C8L2#8KMF(V*_:
MJ=BGV+$@V*_9B-BHV*?8L=F'(-BHV*?8LMF&V+38I]F&V*_8C"#8J-BG(-BS
MV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V*[9B-BO(-BJV878I]BS("(*(MBH
MVJ_;C-BQVXS8KR(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@
M7"(E<UPB(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(
MV8;8K]F'(%PB)7-<(B#9AMF(V+38JB(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N
M(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8J-F'
M(-JIV*?8L=BSV*?8LB#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JI(-F%V*K8
MM=F$(-BTV*\Z("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!<
M(B5S7"(@V+'8IR#8J-BGV+(@VJG8L=BO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(MBJV8+9B-N,V84B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+8I]F&V+78L=BGV8$B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B
M0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(MBGV8;8M=BQV*?9@2#8
MI]BR(-BGV+'8L]BGV80@VJ_8LMBGV+'8M"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D
M96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F^V+'9B-F&V*_9AR!<(B5S7"(@V+'8IR#8K=BPV8$@VJG8L=BO("`B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#;C-JI(-BTV*?8KMF'(-F%V8C9@MBJ
M(-F^VXS8K]BG(-JIV+'8KR(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V*C8K]F(V88@V;[8I]BQV*?9A=BJV+$@)]F^V+'9B-F&V*_9
MAR#9A=F"V+78KR<@V*?8K]BGV879AR#8K]BGV*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%PB)7-<(MBQV*<@V*W8L-F!(-JI
MV+'8KR`B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R
M."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@
M97AI<W0N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BMV+#9@2#9AMF%
MV8C8K]B,("5D(-F!V+'8LMF&V*\@V879B-BLV8C8KR#8I]BSV*HB"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@
M(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D
M+B(*;7-G<W1R("(B"B+9AMF%VXSB@(S8JMF(V*?9AB#8K]F(V*C8I]BQV8<@
MV878L=BJV*@@V8;9A=F(V*_8C"#8J-BQV*[;C"#8I]BR(-F(V+'9B-BOVXS9
MA]BGVXP@V8'8L=BGV8?9A2#8M-BOV8<@V*C8L=BGVXP@V878L=BJV*@@V+/8
MI]BRVXP@V*C8IR`B"B+8M-F%V*?8L=F'XH",V8?8I]N,(-BPV*[;C-BQV8<@
MV+38K]F'V(P@V+/8I]BRVJ_8I]BQ(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#
M86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,V+K8I]F%(-BQV*<@V*C9AR#8
MM-F%V*?8L=F'(-BJV+G;C-N,V88@V+38K]F'(-JOV+#8L2#8K]BGV*\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*
M;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BV+G9AMF(V*?9AB(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R("+8K=BGV879A"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(MJOV+'9B-F'XH",V8?8IR#9B"#8J-BQVH;8L]BHV8?8IR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED
M(")#96QL(%!H;VYE(@IM<V=S='(@(MF%V8C8J-BGVXS9A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G
M:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8
ML]F$V8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(MF!V*?8
MM=F$V8<@V+/9A-F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B
M"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V+/9A-F(V80B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L
M;"!S<&%C:6YG.B(*;7-G<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8
ML]F$V8C9A"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G
M:60@(D-E;&QP:&]N92(*;7-G<W1R("+9A=F(V*C8I]N,V80B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ
M-"DB"FUS9W-T<B`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED
M(")#96YT97(B"FUS9W-T<B`BV878L=JIV+(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED
M(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I(@IM<V=S='(@(D-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`BV*S8LMBF
MVXS8I]BJ(-JOV8C8I]F'VXP@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@(D-E<G1I9FEC871E($]W
M;F5R(@IM<V=S='(@(MBLV++8IMN,V*?8JB#:K]F(V*?9A]N,("(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T
M:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("+8L]N,V*?8L]BJV8?8I]N,(-JO
MV8C8I]F'VXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B
M"FUS9W-T<B`BV8;9B-N,V+/9AR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G
M:60@(D-H86YG92(*;7-G<W1R("+8JMBZVXS;C-BQ("(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB#8KMF(V*\@V+'8IR#8JMBZ
MVXS;C-BQ(-BOV8?;C-BO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V
M"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P
M96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*
M(F5M86EL<RXB"FUS9W-T<B`B(@HBV*K8NMN,VXS8L=BOV*?8K]F&(-F&V*?9
MA2#9B"#8HMBOV+'8L]N,(-JIV8<@V*?9@=BQV*?8KR#9A]F&VJ_8I]F%(-BN
MV8C8I]F&V*_9AB#9B"#9OMBGV+/8KB#8K]BGV*_9AB#8J-F'(-F&V*?9A=F'
MV90@V+39A=BG(-BNV8C8I]F'V8;8KR`B"B+8K]N,V*\@(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(MBJV+K;C-N,V+'8K]BGV*_9AB#8I]BSV84@V+'9
MA=BR(-BTV878IR#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@V8'8N=F$VXP@V;[8
MM-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N(-BHV*<@V+/8L=F^V+'8
ML]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@(@HBV*K9A=BGV+,@V*C:K]N,V+';
MC-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R("+9AMF(VXS8L]F'(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("+8J-BQV+'8
ML]N,(-F^VXS9B-F&V*\N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*
M;7-G<W1R("+B@(PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EN
M82(*;7-G<W1R("+9AMF(VXS8L]F'(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G
M<W1R(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#
M:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:J2#8
MI]BSV84@V+'9A=BR(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`BV*?9
MAMBJV*[8I]BH(-N,VJD@V8;8I]F%(-JIV*?8L=BHV+';C"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES
M<&QA>2!D871E<SHB"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-J&VJ_9B-F&VJ_;
MC"#9AMF%V*?;C-BT(-BJV*?8L=N,V*XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO
M;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S
M='(@(MBGV8;8JMBNV*?8J"#9AMF(V+D@V+/8J-JI(-F!V8?8L=BSV*H@*-BH
MV+'8I]N,(-F!V8?8L=BSV*K9A]BGVXP@V878L=BJV*@I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+8JMBYV+';C-F!(-JIV838I]BS
M("5S(-N,V*?9@=BJ(-F&V+38KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R("+8M=BG
MV8$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(MF^V*?:
MJ2#:J=BQV*_9AB#8JMJOV8?8I]N,($U33V9F:6-E(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS
M9W-T<B`BV;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`BV;[8I]JI(-JI
MV+'8K]F&(-JIV*?8L=BHV+$@.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("+9
MOMBGVJD@VJG8L=BOV88@VJG8I]BQV*C8L2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS
M9W-T<B`BV;[8I]JI(-JIV+'8K]F&(-BOV*?8K]F'V90@VJG8I]BQV*C8L2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L
M(&9U>GIY"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(MBHV*?8L=BG
MV88@V*_;C-BQV8?9AMJOV*?9A2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU
M92(*;7-G<W1R("+8J-BQV*?;C"#8I]BOV*?9A=F'V(P@VJG9A-N,VJD@VJG9
MAMN,V*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B0VQI8VMA=&5L;"#8I]BR(-BWV+';C-F"($A45%`B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+8J-BSV*K9AB#9OMF&
MV*S8L=F'(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L
M;W5D<R(*;7-G<W1R("+8I]BHV+'9A]BG(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D
M<R!%87)L>2(*;7-G<W1R("+8I]BHV+';C"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T
M<B`BV*?8J-BQVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@
M(MBLV878N2#8M-BOV88@V8;9B-BGV+$@VJG9AMBGV+';C"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G
M:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(MJ&V878N2#8M-BOV88@
MV838J-F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(MBQV8;:KR(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO
M<B(*;7-G<W1R("+8L=F&VJ\B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N
M<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`BV*?9AMBJV*[8
MI]BH(-JIV8;9AMBOV8<@V+'9AMJO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("+8
MI]F&V*K8KMBGV*@@V+'9AMJO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(MBS
MV*K9B-F&V8?8ISHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V
M"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(MBYV8;8I]F(VXS9AB#8
ML]BJV8C9AMF'V*<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`BV878MMBMVJDB"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BV8'8L=F%
MV*?9AB(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N
M9"!3:&5L;"(*;7-G<W1R("+9OMF(V+/8JMF'(-F!V+'9A=BGV88B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE
M;G0B"FUS9W-T<B`BV*K9B-BVVXS8K2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M("+9AMBGV84@V+G9A=F(V87;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS
M9VED(")#;VUO<F]S(@IM<V=S='(@(MF!V+'8K]BG(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N
M>2(*;7-G<W1R("+8M-BQVJG8JB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(MBQV*?;C-BGV8;9A^*`
MC-F'V*<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"FUS
M9VED(")#;VYD:71I;VXB"FUS9W-T<B`BV+38L=BW(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BV+38
ML=BGVXS8MR(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(MBJV8'8I]F(V*K9
MA]BGVXP@V;[;C-JIV+'8J-F&V*_;C"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET
M:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`BV;[;C-JI
MV+'8J-F&V*_;C"#8J-F'(-BHV+'9B-BRV+'8L]BGV8;;C"#9AMN,V*?8LB#8
MK]BGV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(MF^
MVXS:J=BQV*C9AMBOVXP@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@
M(MBJV*/;C-N,V*\@V*?8L]F%(-BQV878LB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*(RP@9G5Z
M>GD*;7-G:60@(D-O;F=O(@IM<V=S='(@(MBQV8;:KR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(MBG
MV*K8M=BGV80@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("(*;7-G<W1R("+8I]BJV+78I]F$(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y
M,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B(*;7-G<W1R("+8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR
M(-JIV83;C-BO(-BYV879B-F%VXP@V+'8KR#8M-BO(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(MBGV*K8M=BGV80@V*C9AR#:J=BG
MV+'8L]BGV+(@VJG9A-N,V*\@V+G9A=F(V87;C"#8L=BO(-BTV*\N(-BOV83;
MC-F$.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX
M-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(MBGV*K8M=BGV80@V*C9AR#:J=BGV+'8L]BGV+(@1E10(-F&V*?9
MA=F(V8'9D=F"(-BHV8C8KR(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ
M,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("+9AMF%V*?8L]F'V*<B"@HC
M(`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*
M;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+8JMF%V*?8L]F'V*<@V*C8IR#9
MA=F(V8'9D=F"VXS9D=BJ(-BHV8<@VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@
MV+39A=BG(-BGV+;8I]F!V8<@V+38K]F'(-BHV8C8KR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`BV878K=BJV8C8I]N,("<E
M<R<@(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G
M<W1R("+8I]BOV*?9A=F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM
M<V=I9"`B0V]O:VEE(@IM<V=S='(@(MJIV8C:J=N,(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(MBQV8C9AMF(V+38JB(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`BV*?8JMBUV*?9A"#9AMBGV879
MB-F!V9'9@B#8J-F(V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R
M("+8L=F(V8;9B-BTV*H@V*C8L=BOV*?8M-BJV88@V*?8LB#8J-BNV+0@V*?9
MAMBJV*[8I]BHVXPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV8;8KR#9
MOMN,V+K8I]F%(-BQV*<@V+'9A=BRV*C9AMBOVXP@VJG9AMBO(%!'4"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8I]F%V+;8I]BA(-JIV8;8KR!0
M1U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(MF&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BQV878
MLMBHV8;8K]N,(-JIV8;8KR!3+TU)344B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&V*\@V;[;
MC-BZV*?9A2#8L=BG(-BGV878MMBGV*$@VJG9AMBO(%,O34E-12(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*K9A=BGV+/9A]BG
M(-BQV*<@V*?8MMBGV8'9AR#:J=BQV*\@)7,B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8
MLB!,1$%0(-F^VXS9B-BSV*H@(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*C9AR#:J=BGV+'8L]BGV+(@;&1A
M<"#9OMN,V8C8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("+9AMF%
MVXSB@(S8JMF(V*?9AB#8J-BGV838I]F&V+,@V+'8IR#:AMJI(-JIV+'8KR`E
M<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(&QD87`@V878JMBUV80@V+38
MKR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC
M+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R
M=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BHV*<@V*?8L]BJV8'8I]BOV8<@V*?8LB!&5%`@V*C9AR#:J=BG
MV+'8L]BGV+(@)R5S)R#9B-BUV80@V+38KSH@)7,B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8
ML]BJ(-BJV8C8LMN,V+G;C"#8I]N,V*S8I]BO(-JIV+'8KRX@)7,B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`BV8;9A=N,
MXH",V*K9B-BGV88@V*_8I]BOV8<@4$=0(-BQV*<@V+'9A=BRVJ_8M-BGVXS;
MC"#9AMF%V8C8KR`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(%,O34E-12#8
ML=BG(-BQV878LMJOV+38I]N,VXP@V8;9A=F(V*\@(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8JMF%V*?8LR#8L=BG(-BM
MV+#9@2#9AMF%V8C8KRX@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,
MV+G;C"#8L=BG(-BMV+#9@2#9AMF%V8C8KRX@)7,B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BGV+/:J=BQVXS9
MOMBJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BRVXP@
MV+'8IR#8K=BPV8$@V8;9A=F(V*\@)R5S)RXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8HMBOV+'8LR#:K]N,V+'9AMBOV8<@V8;8I]F%V8?9E"#8I]F$
MVJG8JMBQV8C9AMN,VJG;C"#8L=BG(-BJV+38KMN,V+4@V*_8I]BO(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-JIV80@VJG8JMBGV*C:AMF'
MV90@V*+8K]BQV+,@V+'8IR#9B-BGVJG8M-N,(-F&V879B-BO(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VJG9A"#9@=F'V+'8L]BJ
M(-BJV8C8LMN,V+G;C"#8L=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV8'9A]BQV+/8JB#:J=BGV879A"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8
ML=BG(-F(V*?:J=BTVXP@V8;9A=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-BGV+/8JMBQV*?8JMJ8VXP@V+'8IR#8J-BG
MV+$@VJG8L=BO("<E<R<B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V+38I]BNV8<@)R5S)]BGVXS8K-BGV*\@VJG8L=BO("(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@VJG9A-N,V*\@V+G9A=F(V87;
MC"#8L=BG(-BGV+(@VJG8I]BQV+/8I]BR(-JIV83;C-BO(-BHV*_8L]BJ(-BB
MV8C8L=BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I
M("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O
M<B!W<FET:6YG+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB`G)7,G(-BQ
MV*<@V*C8L=BGVXP@V8;9B-BTV*K9AB#8J-BGV+(@VJG8L=BO("(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8J-BGV+(@VJG8
ML=BO(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9
MB-BGV88@V878K]F(V80@V8C8N-BGVXS9@2#9AMJOV8?8K]BGV+';C"`E<R#8
ML=BG(-BHV*?8LB#9AMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@V+38I]BNV8<@)R5S)R#8L=BG(-BHV*?8LB#9AMF%V8C8KR(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BG
MV88@VJG8I]BQV+/8I]BR($Q$05`@V+'8IR#8K-BSV*K8K-F((-JIV+'8KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB`E<R#8L=BG(-BNV8C8I]F&V*\B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(MF&V87;
MC.*`C-BJV8C8I]F&(-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BQV*?;C"#:J=BG
MV+'8J-BQ(-F%V8C8L=BO(-F&V+C8L2#8J-BGV++9AMBTV*?9AMBO+B#8J-BY
MV+;;C"#;C-BG(-F'V879AR#8K-BRV*;;C-BGV*H@V878L=BHV8C8MR#8J-F'
M("(*(MBBV88@V8;8I]BOV+'8L]BJ(-F%VXSB@(S8J-BGV+38KRX@V*_9B-BH
MV*?8L=F'(-BSV+G;C"#:J=F&VXS8KR#;C-BG(-BHV+'8I]N,(-JIV87:J2#8
MJ-N,V+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(
MV*\@(@HBV*K9A=BGV+,@V*C:K]N,V+';C-BO(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M($%#3"(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB!!0TP@V+'8IR#8K]F(
MV*C8I]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:J=BJV*?8J-J&V8?9
ME"#8HMBOV+'8LR#8L=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8
MKRX@)7,B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@
MV*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BBV8C8L=BO+B`E<R(*"B,@(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BH
MV*_8L]BJ(-BBV8C8L=BO+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F"V*?8J-F$VXS8JMF'V*?;C"#:J=BGV+'8L]BGV+(@V+'8IR#8K]F(V*C8
MI]BQV8<@V*C8K]BSV*H@V*+9B-BQV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQ
MV*C9AMBOVXP@V+'8IR#8J-BGV++:K]BQV*_8I]F&V*\B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-BTV*?8KMF'("<E<R<@V+'8IR#8K=BPV8$@V8;9A=F(V*\@+B(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8
MIR#8K]BNVXS8L=F'(-JIV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,
MV*C8I]F&(-BQV*<@V*W9@=BX(-JIV+'8KR(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BG
MV88@V+'8IR#8K=F!V+@@VJG8L=BO.B`E<R`B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB
M)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*?8L]JIV+';C-F^
MV*H@V*C8L=F(V++8L=BSV*?9AMN,(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8
ML=BG(-BMV8'8N"#9AMF%V8C8KSH@)R5S)RXB"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@V;[8M-BJ
MVXS8J-BGV88@V;[;C-JIV+'8J-F&V*_;C"`E<R#8L=BG(-BMV8'8N"#:J=BQ
MV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M
M(RTC+2,M(PHC(`HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE
M("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O
M<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*
M(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#9OMN,VJG8L=BHV8;8
MK]N,("5S(-BQV*<@V*W9@=BX(-F&V879B-BO+B#8M-F%V*<@V87;C"#8JMF(
MV*?9AMN,V*\@V*?8LB#;C-JIVXP@V*?8LB#:K]BRVXS9AMF'XH",V8?8IR#8
MJ-BQV*?;C"`B"B+8K=F!V+@@VJG8KR#8J-BQ(-BQV8C;C"`E<R#8I]BSV*K9
M@=BGV*_9AR#9AMF%V*?;C-N,V*\@V8@@VXS8IR#8I]N,V8;:J=F'(-BGV+(@
MVJG8KR#8J-F'(-BUV8C8L=BJ(-BOV+/8JMN,(-BOV+$E<R#8L=F(V8;9B-BT
MV*H@(@HBV*K9A]N,V8<@V8;9A=BGVXS;C-BO(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#:
MJ=BGV+'8L]BGV+(@3$1!4"#8L=BG(-BLV+/8JMBLV8@@VJG8L=BO(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",
MV*K9B-BGV88@V;[;C-F(V8;8KR`G)7,G(-BQV*<@V8+8M]BY(-JIV+'8KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*K9
MA=BGV+,@(-BQV*<@V*C8L=F(V++8L=BSV*?9AMN,(-JIV+'8KRX@)7,B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+9AMF%VXSB@(S8JMF(
MV*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BHV+'9B-BRV+'8
ML]BGV8;;C"#:J=BQV*\N("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-BQV*<@V*C8
ML=BGVXP@)R5S)R#9AMF(V+38JCH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M("(B"B+9AMF%VXSB@(S8JMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%
MV8C8LMN,V838IR#8L=BG(-F^VXS8K]BG(-JIV+'8KRX@V878M]F%V*;9AB#8
MM-F(VXS8KR#:J=F'(-F&V8C8I]BQ(-BLV*?9AMBHVXP@V*C8I]BR(-BGV+/8
MJB(*"B,@"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@
M9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE
M(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-BHV8<@VJG8I]BQV*C8L2`G)7,G(-BOV+/8JMBQV+/;C-F'V*?;C"#8LMN,
MV+$@V*C8L=BGVXP@V;[9B-BTV8<@)R5S)R#8K]BGV*\Z("5S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT
M(@IM<V=S='(@(MF%V*K9AB#8M-F%V*?8L=BT(-BTV*_9AR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y
M(@IM<V=S='(@(MJIV+39B-BQ(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("+8K]F(V+'9A^*`C-F'
MV*<B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("+8I]N,V*S8
MI]BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(MBG
MVXS8K-BGV*\@VXS:J2#9OMN,V8C9AMBO(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N
M92(*;7-G<W1R("+8I]N,V*S8I]BO(-N,VJG;C"#8K-BOVXS8KR(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#
M<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`BV*?;C-BLV*?8KR#8LMN,V+'9
MOMF(V+39A^*`C-F'V*<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("+9
MA=BLV8C8LMF'V*?;C"#8I]N,V*S8I]BO(-JIV8;9AMBOV8<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`BV+39A=BGV+'9AR#:J=BGV+'8JB#8I]BYV*K8J-BG
MV+';C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM
M<V=S='(@(MBGVXS8K-BGV*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM
M<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("+9@=BGV+(@V8'8N=F$
MVXPB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@
M(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`BV878K-F(V++9A]BGVXP@V*?;
MC-BLV*?8KR#:J=F&V8;8K]F'(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@
M;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS
M9W-T<B`BV+/8I]BYV*H@V8'8N=F$VXPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E
M;G0@55),(&ES(@IM<V=S='(@(E523"#9@=BYV83;C"#9A]BSV*HB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@
M57-E<G,B"FUS9W-T<B`BV8'8I]BR(-F!V+G9A-N,(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@
M(MBBV*@@V8@@V8?9B-BGVXP@V8'8N=F$VXPB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@
M(@IM<V=S='(@(MBTV+'8I]N,V+<@V8'8N=F$VXPZ("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E
M;G0@<W1Y;&4B"FUS9W-T<B`BV+/8J-JI(-F!V+G9A-N,(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(MBSV8'8I]BQV+3;C"#:J=BQV*_9AB#9B-BXV*?;C-F!(-F'V8;:K]BGV84@
MV8C8L=F(V*\@V*C9AR`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@
M(MBHV+';C-BOV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(MBH
MV+';C-BOV88@V*?9AMBJV*[8I]BH(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP
M<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#>7)I;&QI8R`H2T])
M."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I
M;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#
M>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(MBQV8C8LMBG
MV8;9AR(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R
M964@0G)O=W-E<B(*;7-G<W1R("+9A=BQV8C8L=JOV+$@V*_8L=BNV*H@V*_8
MI]BOV8<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED
M(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(MBJV*?8L=N,V*XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I
M9"`B1&%T92!296-E:79E9"(*;7-G<W1R("+8JMBGV+';C-BN(-BOV+';C-BG
MV8'8JB#8M-BOV8<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W
M"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("+8JMBGV+';C-BN(-BG
MV8;8JMBNV*?8J"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@IM<V=I9"`B1&%Y
M(@IM<V=S='(@(MBQV8C8LB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`BV*W8L-F!(-BSV*K9B-F&(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(MBOV+/8I]F%V*C8L2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R("+8I]BYV*_8I]BO(-BOV8?8K]F'VXPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED
M(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`BVJG9A2#:J=BQV*_9AB#8JMF(
MV+'9@=BJVJ_;C"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@
M(MF^VXS8M"#9@=BQV+8B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M("+8L=F&VJ\@V;[;C-BT(-F!V+'8MB(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS
M9W-T<B`BV8?9B-N,V9'8JB#9OMN,V+0@V8'8L=BV(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@
M(MF^V8C8L]BJV8?9E"#9OMN,V+0@V8'8L=BV(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("+8JMBY
MV*?8L=N,V8$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`BV*W8L-F!(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("+8K=BPV8$@
MV+/9A-F(V80B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U
M<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(MBMV+#9
M@2#:K]BQV8C9AR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("+8K=BPV8$@
MV+/8M]BQ(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E
M(%!E<FUI<W-I;VXB"FUS9W-T<B`BV*W8L-F!(-F%V*S9B-BR(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BV*W8L-F!(-F((-F^
MV*?:J=BSV*?8LMN,(-F^VXS8NMBGV879A]BG(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L
M971E(&-E;&PB"FUS9W-T<B`BV*W8L-F!(-BSV839B-F$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I
M9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("+8K=BPV8$@V+/8JMF(V88B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T
M:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("+8K=BPV8$@V*?9A-JO
MV8C;C"#8K-BGVXS:K]BRVXS9AB#9A=F(V*S9B-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B
MV*W8L-F!(-F%V*S9B-BRV8?8IR#8J-BQV*?;C"`@7"(E<UPB(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(MBBVXS8IR#9A=BLV8C8LMF'V*<@
MV8@@V++;C-BQV878K-F(V++9A]BG(-BHV+'8I]N,(%PB)7-<(B#8K=BPV8$@
MV+39B-BOV)\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(MBM
MV+#9@2#8L]BWV+$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I
M='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS
M9W-T<B`BV*W8L-F!(-F'V8C;C-F1V*H@V*?9AMBJV*[8I]BH(-BTV*_9AR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G
M<W1R("+8K=BPV8$@V+/8JMF(V88@V8'8N=F$VXPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BV*W8L-F!(-BSV+?8
ML2#9@=BYV83;C"(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`BV*?8L]JIV+';C-F^
MV*H@V*W8L-F!(-BTV*_9A]F4(-BHV+'9B-BRV+'8L]BGV8;;C"#8JMF&V+C;
MC-F%V*?8JB`G)7,G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y
M('1I;64B"FUS9W-T<B`BV++9A=BGV88@V*?8L=BSV*?9A"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*(RP@9G5Z>GD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`BV*K9B-BVVXS8
MK=BGV*HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`BV+38L=BM(-F%
MV+3:J=F$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G
M:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(MBJV8C8MMN,V*TB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("+8K-BRV9#8IMN,V*?8
MJCHB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(-BLV++8IMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8L=BS
MV*H@V+/8I]F%V*?9AMF'(-BKV*C8JB#8M-BOV8<@V*?8L]BJ(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B
M"FUS9W-T<B`BVJ_8L]BJV+'8M"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`BV8;9@MBWV8<@V+38J-F&
MV84B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O
M:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("+9AMF"V+?9AR#8M-BHV8;9
MA2#8J-BQV*?;C"#8L]BGV+G8JB#:K]BPV+38JMF'.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*
M;7-G<W1R("+9AMF"V+?9AR#8M-BHV8;9A3H@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`BV*S9A]BJ(-BGV+(@VH;9OB#8J-F'
M(-BQV*?8L]BJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS
M9W-T<B`BV*S9A]BJ(-BGV+(@V+'8I]BSV*H@V*C9AR#:AMF^(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R
M("+8M-BGV*[9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G
M:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`BV*+;C-BG(-BR
MV878I]F&(#(T(-BSV*?8N=BJV8<@V8;9A=BGVXS8M"#8K]BGV*_9AR#8M-F(
MV*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES
M<&QA>2!/<'1I;VYS(@IM<V=S='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@V8;9
MA=BGVXS8M"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@IM
M<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("+9AMF%
MV*?;C-BT(-BLV++8IMN,V*?8JB#9OMN,V+3"K=BHVXS9AMN,(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*2(*;7-G<W1R("+9AMF%V*?;C-BT(-F^VXS8M,*MV*C;C-F&VXPB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y
M(&9O<FUA="(*;7-G<W1R("+9AMF%V*?;C-BT(-F"V*?9A-BH(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I
M;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(MBMV*?9A-BJ(-BJV+#:J=BQ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`BV*W8L-F!(-F&V+39B-BO(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R("+8K]BSV*K8L=BSVXP@V878
ML]BJV8+;C-F%(-BHV8<@;6%I;G1E;F%N8V4N<&AP(-F%V87:J=F&(-F&VXS8
ML]BJ(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#HB"FUS9W-T<B`B(@HBV*+;C-BG(-BSV+?8L2#8I]F(V80@V+38
MI]F%V80@V8';C-F$V*\@V8;8I]F%(-F%VXSB@(S8J-BGV+38K]B?(-BGVJ_8
ML2#:AMF&VXS9AB#8I]BSV*K8C"#8I]N,V88@V*S8N=BHV8<@V+'8IR#8N=F$
MV*?9A=BJ(-BHV++9AMN,V*\Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E
M<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("+8I]BSV*K9@MBQV*?8
ML2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+8I]BS
MV*K9@MBQV*?8L2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*
M;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N(@IM<V=S='(@(MBGV+/8JMF"V+'8I]BQ(-F^VXS:J=BQV*C9
MAMBOVXP@V*K9B-F$VXS8KR#8M-BOV8<@V*C8N=F&V8C8I]F&(-BOV+/8JB#9
MAMF(VXS8LR!02%`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W
M"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("+9@=F'V+'8L]BJ(-F^
MV*?;C-N,V8;B@(S9OMBQ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T
M"FUS9VED(")$<G5G<R(*;7-G<W1R("+8K]BGV+'9B-F'V*<B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*
M;7-G<W1R("+9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;C"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED
M(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G
M:60@(D5D:70B"FUS9W-T<B`BV8C;C-BQV*?;C-BT(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(MF(VXS8L=BGVXS8
MM"#8J-F$V8C:J2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(MF(VXS8
ML=BGVXS8M"#:K]BQV8C9AR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("+9B-N,V+'8I]N,V+0@V878
MK-F(V+(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9A=BL
MV8C8LMF'V*<B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@
M,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9A=BLV8C8LMF'V*<@V*C8L=BG
MVXP@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%
M9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+:K]BRVXS9AMF'XH",V8?8I]N,
M(-F(VXS8L=BGVXS8M#HB"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BV8C;C-BQV*?;C-BT(-F%V*S9
MB-BRXH",V8?8IR#8J-BQV*?;C"!<(B5S7"(B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(MF(VXS8L=BGVXS8M"#9
MA=BLV8C8LN*`C-F'V*<@V*C8L=BGVXP@)7,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("+8JMBMV+7;
MC-F$V*?8JB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T
M:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`BV+G9AMBUV+$N+BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I
M9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9
MB-F&VXS:J=N,(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I
M;"!!9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-F&V*?9A=F'V90@V*?9A-JI
MV*K8L=F(V8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T
M<B`BV*+8K]BQV+/9A]BGVXP@V8;8I]F%V8?B@(S9A]BGVXP@V*?9A-JIV*K8
ML=F(V8;;C-JIVXP@V*C8I]N,V*\@V879AMBWV*C9@B#8J-BGV+38KR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*;7-G:60@(D5M86EL('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(MF&V*?9A=F'V90@V*?9A-JIV*K8
ML=F(V8;;C-JIVXP@V*C8IR#8JMBCVXS;C-BO(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R("+8I]BMV+/8I]BSV*?8JB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G
M92XB"FUS9W-T<B`BV*[8I]F$VXP@VJG8L=BOV88@V;[;C-BZV*?9A2`B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P
M"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(MBNV*?9A-N,(-JIV+'8
MK]F&(-F&V*K;C-BLV8<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
MV*[8I]F$VXP@VJG8L=BOV88@V879B-BGV+'8KR#8K-BSV*K8K-F((@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B
M"FUS9W-T<B`BV*+;C-BG(-BOV+'8K"#8JMBUV*?9B-N,V+$@V*?8LB#:K]BG
MV838L=N,V8?8I]N,(-BYVJG8LR#8K]BQ(-F%V*K9AB#9@=BYV*?9A"#8M-F(
MV*_8GR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N
M86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(MBBVXS8
MIR#:K]BRVXS9AMJOV*?9AB#8LMF%VXS9AMF'(-BQV8C;C"#:J=F$VXS:J2#8
ML=BGV+/8JB#9@=BYV*?9A"#8M-F(V*_8GR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM
M<V=I9"`B16YD('EE87(B"FUS9W-T<B`BV*?9AMBJV8?8I]N,(-BSV*?9A"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*
M;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(MBHV++8L=JO(-JIV+'8
MK]F&(-F(VXS8L=BGV+/8JMBGV+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SHB"FUS9W-T<B`B(@HBVXS:J2#8L]BFV8C8I]F$(-BGV879AMN,
MV*K;C"#8J-BQV*?;C"#9OMBQV+/8M"#8I]BR(-BTV878IR#8J-F'(-F'V8;:
MK]BGV84@V*C8I]BRV8;8M-BGV8;8K]F&(-BGV+/9A2#8L=F%V+(@V8C8I]BQ
MV*\@VJG9AMN,V*_8C"#9A=BKV838I]F2("(*(B?9AMBGV84@V*W;C-F(V*?9
MAB#8KMBGV8;:K]N,(-BTV878IR#:AMN,V+/8JMB?)R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM
M<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(E523"#8
MJMBUV8C;C-BQ(-BQV*<@V*?;C-F&V*S8IR#9B-BGV+'8KR#:J=F&VXS8KR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*
M;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G
M:60@(D5R<F]R(@IM<V=S='(@(MBNV+?8IR(*"B,@"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("+8J-F$V8C:J2#8
MI]N,V*S8I]BO(-BNV+?8ISH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(MBNV+?8IR#8K]BQ
M(-BHV+'9B-BRV+'8L]BGV8;;C"#8I]BSV84@V+'9A=BR(#H@)7,B"@HC(`HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM
M<V=S='(@(MBHV839B-JI(-BGVXS8K-BGV*\@V*[8M]BG.B`E<R(*"B,@"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`BV*[8M]BG(-BOV+$@VJG8L]BH(-F%V*W8JMF(V*<Z)7,B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(MBNV+?8
MIR#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#8I]BSV84@V+'9A=BR(#H@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`BV*[8M]BG(-BHV*<@V;[;C-BZV*?9A2#9AMBGV879A]F4(-BGV83:J=BJ
MV+'9B-F&VXS:J=N,(@H*(R`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N
M(@IM<V=S='(@(MBNV+?8I]N,(-F&V8C8M-BJV88@)R5S)R`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"B,L(&9U>GIY"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(MBYV*K;C-F"
MV8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G
M<W1R("+8N=BJVXS9@MF'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`BV*?8L=F(V;[8IR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI
M;G5T97,B"FUS9W-T<B`BV8?8L2#9OMBGV8;8LMBOV8<@V*_9@MN,V8+9AR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R("+9A]BQ(-BOV8@@V*_9@MN,V8+9AR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+9A]BQ(-BS
MVXP@V*_9@MN,V8+9AR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(MF'V+$@V;[9AMBL(-BOV8+;C-F"V8<B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%
M=F5R>2!,;V=I;B(*;7-G<W1R("+8K]BQ(-F'V+$@V8C8L=F(V*\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO
M=7(B"FUS9W-T<B`BV8?8L2#9AMN,V84@V+/8I]BYV*HB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*
M;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+9A]BQ(-BOV8+;C-F"V8<B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#9A=BKV*?9A#HB
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP
M.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS
M9W-T<B`BV*?8K-BQV*<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("+8J-BGV+(@VJG8
ML=BOV88B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS
M9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("+8J-BGV++:J=BQV*_9AB#9
MAMF(V*?8L2#:J=F&V*?8L=N,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(MBG
MV8;8JMBXV*?8L2#8J-BQV*?;C"`G*"<B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(MBJV*?8L=N,V*X@V*?9AMF"V+;8I]BA(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N
M96YT(@IM<V=S='(@(MF&V878I]N,V8;8K]F'(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`BV+'9AMJO(-F^VXS8M.*`C-BRV87;C-F&V8<B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D
M(&]F('-E='5P(@IM<V=S='(@(D944"!U<&QO860@;V8@<V5T=7`B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE
M9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("(@V*C8I]BRVXS8
MI]BHVXP@V*K9@MBOV878I]BJ(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(-BGV*K8M=BGV80@V*C9AR#:
MJ=BGV+'8L]BGV+(@3$1!4"#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T
M;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(B#8I]BJV+78I]F$
M(-BHV8<@VJG8I]BQV+/8I]BR(%--0B#9AMBGV879B-F!V9'9@B#8J-F(V*\@
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S
M='(@(B#8JMF'VXS9AR#8L=F(V8;9B-BTV*H@V*?8LB!<(B5S7"(@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R("+8I]N,V*S8I]BO(-BQV8C9AMF(V+38
MJB#8K]BQ(%PB)7-<(B#9AMBGV879B-F!V9'9@B#8J-F(V*\B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B#8I]N,V*S8
MI]BO(-N,VJD@V*?8JMBUV*?9A"#8K-BOVXS8KR!305-,(-F&V*?9A=F(V8'9
MD=F"(-BHV8C8KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B(-BG
MV8;8JMF"V*?9A"#8J-F'(%PB)7-<(B#9AMBGV879B-F!V9'9@B#8J-F(V*\B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G
M<W1R("(@V*?9AMBJV8+8I]F$(-BHV8<@7"(E<UPB(-F&V*?9A=F(V8'9D=F"
M(-BHV8C8KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(MF$V+?;C-F!(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(MBNV+?8I]N,(-BLV*_;C#H@(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(MF!VJG8LR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@(MF!VJG8
MLR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V
M"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("+9@=F(V+';C-F'(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*
M;7-G<W1R("+8L=JOV*C8I]BQ(-BNV8';C-F!(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`BVJG9A=N,(-BJVJ_8L=JO(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@
M(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE
M(@IM<V=S='(@(MF^V+'9B-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&4B"FUS9W-T<B`BV+39A=BGV+'8M"#9OMBQV8C9AMBOV8<Z("5S(-F^
MV+'9B-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(MBTV878I]BQV+0@V;[8L=F(V8;8K]F'.B`E<R#9OMBQV8C9AMBOV8<B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`BV878K]N,V+$@V;[8L=F(V8;8K]F'(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*
M;7-G<W1R("+9AMBGV84@V;[8L=F(V8;8K]F'(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-F^V+'9B-F&V*_9AR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@
M(MBGV+'8L]BGV80@V;[8L=F(V8;8K]F'(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`BV*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@V;[8
MM-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+9
M@=N,V838JMBQV8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D9I
M;FQA;F0B"FUS9W-T<B`BV*_8L=BNV+<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(MF&VXS9A=F'(-BG
MV8C9A"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`BV+'8J-BY
M(-BGV8C9A"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("+9AMBSV*C8JB#8
MJ]BGV*C8JB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B
M1FQO870B"FUS9W-T<B`BV*?8N=BTV*?8L=N,(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R
M("+9A=F'XH",V*+9A-F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G
M<W1R("+9OMF(V+39AR`E<R#9A=F(V*S9B-BO(-F&VXS8L]BJ("(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@
M(D9O;G0@0V]L;W(B"FUS9W-T<B`BV+'9AMJO(-F"V839A2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("+8NMBP
MV*<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(MBHV+'8I]N,(-F%V+'9B-BQVJ_8
ML=F'V*?;C-N,(-JIV8<@V*K8M=BGV8C;C-BQ(-BQV*<@V;[8M-BJVXS8J-BG
MV8;;C"#9AMF%VXSB@(S:J=F&V8;8KR(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("+9OMN,V+3"
MK=BHVXS9AMN,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y
M"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*
M(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`BV*?8
ML]F%(-BQV878LB#8KMF(V*\@V+'8IR#9@=BQV*?9A=F(V+0@VJG8L=BOV8?B
M@(S8I^*`C-N,V*_8GR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(MF!V+'9A=F'V*<B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B
MV+?8I]F$V+DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@
M(D9O<G1U;F4@='EP92(*;7-G<W1R("+9AMF(V+D@V+?8I]F$V+DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S
M='(@(MBWV*?9A-BYV8?8IR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("+8M]BGV838N=F'V*<@V[(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U
M;7,B"FUS9W-T<B`BV*?9AMBLV879AMF'V*<B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("+8I]BQ
MV*S8I]BYV8?8IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(MBLV878N=F'(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(MJ&V*?8L=J&V8C8J-F'V*<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")&<F%N8V4B"FUS9W-T<B`BVH;8
MI]BQVH;9B-BHV8?8IR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(MBGV+(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(MBGV+(@(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BV+38L=BM(-JIV*?9A=F$(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*
M;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("+9A=BGV8<@VJG8I]F%V80B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(MF&
MV*?9A2#:J=BGV879A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VTB"FUS9W-T<B`BVJ_8I]F$V+';C"#8J-BQV*?;C"#8K]BQVXS8I]F!
MV*H@V*K8M=F(VXS8L2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM
M<V=S='(@(MJOV*?9A-BQVXPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA
M(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R("+8JMF(V83;C-BO(-F^VXS:J=BQV*C9AMBOVXP@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I
M9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`BVJG8KR#8JMF(V83;C-BO(-BT
MV*_9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B
MV8;8I]F%(-BOV*?8K]F'(-BTV*_9AR(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("+8J-BQV8@B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R
M.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`BV*S8L]F&
MV*S9B-N,(-JOV8C:K]F$(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("+8K-BSV8;8K-F(VXP@
MVJ_9B-JOV80B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`BV*_8L=BLV8<@
MV*[8I]JIV+/8JMBQVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'
M<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)E96L@*$E33RTX.#4Y+3<I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(MBSV+'9OMBQV+/8JMN,(-JOV+'9B-F'(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>2(*;7-G<W1R("+9AMBGV84@VJ_8L=F(V8<@V8;8J-BGVXS8KR#8KMBGV83;
MC"#8J-BGV+38KR(*"B,@"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@
M<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`ZV*?8MMBGV8'9
MAR#:J=BQV*_9AB#:J=BGV+'8J-BQ("5S(-F%V87:J=F&(-F&VXS8L]BJ+B#8
MI]N,V88@VH;;C-BRVXP@V*?8L]BJ(-JIV8<@VJG8I]BQV+/8I]BR(-JOV8'8
MJMF'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E
M(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#K8J-BQV8C8LMBQV+/8I]F&
MVXP@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JB(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R(")!=71H7VQD87`ZV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$@
M)7,@V879A=JIV88@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(MJOV+'9B-F')B-X,C`P8SO9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*(RP@
M9G5Z>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(MBRVXS8L=F^VXS8L=BG
MV8?9AMN,(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`BV878K-F(V++9A]BGVXP@V879A]F%V*?9AB(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R("+:J=BJV*?8J-J&V8?9E"#;C-BGV*_8J-F(V*\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'=6EN96$B"FUS9W-T<B`BVIC9
MB-BFV88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,
M(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS
M9W-T<B`B2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+/9A-F(V80@V+'8
MIR#8K]BQ(-BQV*_;C-F!(-BQV*\@V87;C.*`C-JIV8;8KR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G
M:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@V*W8L-F!
M(-BBV*[8L=N,V88@V+/8JMF(V88@V+'8IR#8K]BQ(-BLV*_9B-F$(-BQV*\@
MV87;C.*`C-JIV8;8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS
M9W-T<B`B2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+'8K]N,V8$@V+'8
MIR#8K]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE
M;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(
MVXS9D=BJ($A45%`@VXS8I]F!V*K9AR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M(RP@9G5Z>GD*;7-G:60@(DAA:71I(@IM<V=S='(@(MF&V+/8J-BJ(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H
M+4%L9V]R:71H;2(*;7-G<W1R("+8I]F$VJ_9B-BQVXS8JMF%($AA<V@B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I
M9"`B2&%Z92(*;7-G<W1R("+9A=F'XH",V*+9A-F(V*\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(MBSV+'8HMF%V*\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U
M>GIY"FUS9VED(")(96%D97)S(@IM<V=S='(@(MBSV+'8HMF%V*\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PHC+"!F=7IZ>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*
M;7-G<W1R(")4+5-T;W)M<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V
M"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5W
M("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@
M(MBHV839AMBOVXPB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP
M:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD
M97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BV+'8I]F'V8;9A=BG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`BV+'8I]F'V8;9A=BG
MVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#9B-N,V+'8I]N,V+3:K]BQ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM
M<V=S='(@(MJIV87:J2#:J=F&V8;8K]F'(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(MF&VXS9A>*`C-JI
MV+'9AR(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(MBGVXS9AMBLV*<@V*?8
MJ-BJV*_8I]N,(-F^V+'9B-F&V*_9A^*`C"#9A=N,XH",V*C8I]BTV*\Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G
M:60@(DAI9V@B"FUS9W-T<B`BV*C8I]F$V*<B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N
M:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(MBNV*?9AMF'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U
M"FUS9VED(")(;VUE(@IM<V=S='(@(MBNV*?9AMF'(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D
M9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@V*[8I]F&V8<B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S
M='(@(MBTV*?8KMF'V90@V*?8M=F$VXPB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM
M<V=S='(@(MBTV878I]BQV8<@V*K9A-F!V88@V879AMBRV80B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`BV8?9B-BQ
MV*\B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B`E<R#8J-BG(-BOV*?8K]F'(-F&V*?8K]BQV+/8JB!834P@V*_8L2#9
MOMN,V+K8I]F%("5S(-F%V8C8I]BLV8<@V+38K]F'(-BGV+/8JB(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@V8?;C-J&(-F^VXS8NMBG
MV87;C"#9A=BWV*?8J-F"V*H@V*C8IR#8M-N,V*$@)7,@V8;8K]BGV+'8KR(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#9A]N,
MVH8@V+3;C-BFVXP@V*?8LB#9AMF(V+D@)7,@V*_8L2#9OMN,V+K8I]F%("5S
M(-N,V*?9@=BJ(-F&V+38KR(*"B,@"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@)7,@7"(E<UPB(-BMV+#9
M@2#8M-BO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G
M:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I
M<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#8JMF(
MV83;C-BO(-N,VJD@V*_8L=BNV*H@V*S8K]N,V*\@6$U,(-BHV+'8I]N,(-BT
MVXS8H2`E<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ("(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B#8K=BPV8$@)7,@7"(E<UPB.B5S(-F%V8+8K]F(
MV+$@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(-BHV*?8LMN,V*?8J-N,("!-24U%($E$(-BH
MV+'8I]N,(-F"V+/9A=BJVXP@V*?8LB#9AMF(V+D@)7,@V879@MBOV8C8L2#9
MAMN,V+/8JB`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@)7,@7"(E<UPB.B`E<R#9A=F"V*_9
MB-BQ(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@V+/9AMJIV+'9B-F&(-JIV+'8K]F&(-BGV+38JMBQV*?:J=F'V*<@V879
M@MBOV8C8L2#9AMN,V+/8JCH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-BG
MV+38JMBQV*?:J2#9AMBGV+39AMBGV*[8JMF'(%PB)7-<(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R("+9@MBGV8;9B-F&(-BGV8'9@MN,(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM
M<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(MF!V*?8M=F$V8?B
M@(S:K]BPV*?8L=N,(-BGV8'9@MN,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS
M9W-T<B`B.MBGV8'9@MN,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*;7-G<W1R("+:AMJOV8C9AMF'
M(-BHV*<@V*?;C-F&V*S8IR#8HMBTV8;8IR#8M-BOVXS8K]B?("C9A-BWV8'8
MI]F+(-JOV++8I]BQV+0@V*_9A]N,V*\I(2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@
M(MJ&V8;8KR#8L]BJV8C9AB#8L=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8
MK]BZV*?9A2#:J=F&VXS8K]B?(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/R(*;7-G<W1R("+:AMF&V*\@V8';C-F$V*\@*-BSV*K9B-F&*2#9
MB-BLV8C8KR#8K]BGV+'8K]B?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W
M<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BVH;9AMBO(-BS
MV+?8L2#8L=BG(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*?8K]BZV*?9A2#:J=F&
MVXS8K]B?(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T
M<B`BV+'8M]F(V*C8JB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`BV+'8M]F(V*C8JCH@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W
M,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF
M;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S
M(@IM<V=S='(@(MBGVXS8K-BGV*\@V8;8I]F%V8?B@(S8K]BGV88@24U!4"#9
MAMBGV879B-F!V9'9@B#8J-F(V*\Z("`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(MBMV+#9@2#9AMBGV879A^*`
MC-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR`Z("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`BV*?;C-BLV*?8KR#9A=BMV*_9B-BOVXS9D=BJ(-F&V*?9A=F'XH",V*_8
MI]F&($E-05`@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(#H@)7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM
M<V=S='(@(MBBV*_8L=BS($E0(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("+8HMBOV+'8LR!)4"#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@
MV8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP
M.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412
M(&)L;V-K+B(*;7-G<W1R("+8HMBOV+'8LR!)4"#8K]BQ(-BOV*?8KMF$(-BH
MV839B-JI($-)1%(@V*?8K-BGV++9AR#8K]BGV*_9AR#9AMF%VXSB@(S8M-F(
MV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T
M<B`BV*?8J-BJV*_8IR#8L]BWV+$@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM
M<V=S='(@(MF!V8+8MR#8HMN,VJG9B-F&V8?8IR(*"B,@(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N
M<R!F;W(@)7,B"FUS9W-T<B`BV*+;C-JIV8C9AMF'V*<@V*C8L=BGVXP@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`BV*+;C-JIV8C9AMF'V*<@V*C8IR#9A=BJV88B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(MF&V*?9A2#9A]F(VXS9D=BJ.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(MBGVJ_8
ML2#8HMF&(-BHV8<@V*_8L=BSV*K;C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-F&
MV+38K]B,("5S("#8J-BQV*?;C"#8J-BGV+(@VJG8L=BOV88@V*+9AB#8K]BQ
M(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@HBV*?:K]BQ(-BTV878IR#9A]N,VH8@V*+;C-JIV8C9
MAMN,(-BQV*<@V*_8L2#9A=BQV8C8L=JOV+$@V8;8J-N,V8;;C-BOV(P@V879
MA=JIV88@V*?8L]BJ(-F$V*?8LMF%(-BHV*?8M-BO(-JIV8<@4$Y'("(*(E1R
M86YS<&%R96YC>2#8L=BG(-BNV*?9A=F(V+0@VJG9AMN,V*\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HBV*?:K]BQ(-BTV878IR#8
MI]N,V88@V;[;C-BZV*?9A2#8L=BG(-F%V+38I]F'V*_9AR#:J=F&VXS8KR#8
MI]F%V*<@V*K8M=F(VXS8L=N,(-BQV*<@V878M-BGV8?8K]F'(-F&VJG9AMN,
MV*_8C"#8I]N,V88@V*C9AR#8I]N,V88@V+G9A-BJ("(*(MBNV8C8I]F'V*\@
MV*C9B-BO(-JIV8<@V878L=F(V+':K]BQ(-BTV878IR#9@=BGV*_8L2#8J-F'
M(-F&V878I]N,V+0@V*K8M=F(VXS8L2#9AMN,V+/8JB`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*
M;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(MF^VXS8M.*`C-F&V878
MI]N,(-BJV+79B-N,V+$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S
M='(@(E523"#8JMBUV8C;C-BQ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!5
M4DPZ(@IM<V=S='(@(E523"#8JMBUV8C;C-BQ.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(MBJV+79B-N,V+$@V*?8
MLB#:K]BGV838L=N,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDZ(@IM<V=S='(@(MBJV+79B-N,V+$@V*?8LB#:K]BGV838L=N,.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E
M('5P;&]A9"(*;7-G<W1R("+8I]BQV+/8I]F$(-BJV+79B-N,V+$B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@
M(MBJV+78I]F(VXS8L2(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D
M(@IM<V=S='(@(MBOV+'9B-F&XH",V*C8L=BOV(P@VJ_8I]F%("5D(@H*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*
M(R`*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(MF!VXS9
MA-BO(-BOV+'9B-F&XH",V*C8L=BO(-BTV*_9ASH@)7,B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z
M(@IM<V=S='(@(MF!VXS9A-BOXH",V8?8I]N,(-BOV+'9B-F&XH",V*C8L=BO
M(-BTV*_9ASHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(MBHV+G8K]BGV8L@V+/8M]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,
MV*\B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T
M<B`BVJG8KR#8N=F%V83:J=BQV*\@V8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BT
MV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B(-F&V*?9A2#:J=BGV+'8J-BQ+]BG
MV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8JB#8I]BSV*HB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S
M97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N
M=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+B(*;7-G<W1R("(B"B+9AMBGV84@VJG8I]BQV*C8L2#;C-BG(-BB
MV*_8L=BS(-BLV*?;C-JOV++;C-F&(-F&V*?8K]BQV+/8JB#9A=N,XH",V*C8
MI]BTV*\N(-F$V+?9@=BG(-F%V*S8K]BOV*?9DB#8L]BYVXP@VJG9AMN,V*\@
MV8@@VXS8IR#8K]BQ(-BUV8C8L=BJ("(*(MF&VXS8I]BR(-BHV8<@VJG9A=JI
M(-BHVXS8M-BJV+$@V*C8IR#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BJ
MV878I]BS(-BHVJ_;C-BQVXS8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*
M;7-G<W1R("+8I]F!V++8I]N,V+0@V*K9B-BQV8'8JMJOVXPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(MJIV*?8
ML=BHV+'8I]F&(-BNV*?8M2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`BV*?8M]F$V*?8
MN=BGV*HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED
M("));F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T
M:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(MBGV+?9A-BGV+G8
MI]BJ(-BOVXS:K]BQ(-BOV+$@V*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`BV*_8L=BL
M(-BSV*K9B-F&(-BHV+G8KR#8I]BR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`BV*_8L=BL(-BJV+79B-N,V+$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("))
M;G-E<G0@5&%B;&4B"FUS9W-T<B`BV*_8L=BL(-BLV*_9B-F$(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B
M26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(MBOV+'8K"#9OMN,V8C9AMBO(-F(
MV*@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R("+8I]BHV*K8K]BG(-BSV*K9B-F&(-BQV*<@V*_8L=BL(-JIV8;;C-BO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("+;C-JI(-BSV*K9B-F&(-BLV*_;C-BO
M(-BHV+G8KR#8I]BR(-BSV*K9B-F&(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8
MKR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(MN,VJD@V+/8JMF(V88@V*S8K]N,
MV*\@V8+8J-F$(-BGV+(@V+/8JMF(V88@V8'8N=F$VXP@V*_8L=BL(-JIV8;;
MC-BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("+;C-JI(-BSV+?8L2#8K-BOVXS8KR#8
MJ-BYV*\@V*?8LB#8L]BWV+$@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`BVXS:J2#8L]BWV+$@V*S8K]N,V*\@V8+8J-F$
M(-BGV+(@V+/8M]BQ(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW
M,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT
M(&YO9&4B"FUS9W-T<B`BVXS:J2#9OMBGV+'8I]JOV+'8I]F!(-BHV+G8KR#8
MI]BR(-JOV+'9AR#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*
M;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D92(*;7-G<W1R("+;C-JI(-F^V*?8L=BGVJ_8L=BGV8$@V8+8J-F$(-BG
MV+(@VJ_8L=F'(-F!V+G9A-N,(-BOV+'8K"#:J=F&VXS8KR(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(MBOV+'8K"#8I]F$VJ_9B-N,(-BLV*?;C-JOV++;
MC-F&(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(MN,VJD@V*+8K]BQV+,@V;[8
ML]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@
MV*?8L]F%(-BQV878LB`@V*S8K]N,V*\@V*_8L=BL(-JIV8;;C-BO("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(MBOV+'8K"#8
ML]F$V8C9A"#8J-BYV*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O
M<F4B"FUS9W-T<B`BV*_8L=BL(-BSV839B-F$(-F"V*C9A"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`BV*_8L=BL(-BSV*K9
MB-F&(-BHV+G8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(MBOV+'8K"#8L]BJV8C9AB#9@MBHV80B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T
M(&UE<W-A9V5S(@IM<V=S='(@(MBOV+'8K"#9OMN,V+K8I]F%(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(MBOV+'8
MK"#9OMBGV+'8I]JOV+'8I]F!(-BHV+G8KR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`BV*_8L=BL(-F^V*?8L=BG
MVJ_8L=BGV8$@V8+8J-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E
M<B(*;7-G<W1R("+8K]BQV*P@V+/8M]BQ(-BHV+G8KR`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED
M("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("+8K]BQV*P@V+/8M]BQ(-F"
MV*C9A"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN
M<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S
M=&EO;CHB"FUS9W-T<B`BV;[8I]BSV*X@V879B-BQV*\@V8;;C-BGV+(@V+'8
MIR#8J-BQV*?;C"#8L]BFV8C8I]F$(-BGV879AMN,V*K;C"#8K]BQV*P@VJG9
MAMN,V*\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("+8
MK]BQV*POV*K8NMN,VXS8L2#8JMBUV8C;C-BQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(MBOV+'8K"_8JMBZVXS;C-BQ(-F^VXS9B-F&
MV*\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BV*?8N=BJV*C8I]BQ
M(-F&V*?:J=BGV8';C"#8J-BQV*?;C"#8I]BQV+/8I]F$(-BHV8<@V8'9A]BQ
MV+/8JB#8JMF(V++;C-BYVXPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`BV*?8N=BJV*C8I]BQ(-F&V*?:J=BGV8';C"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B
M"FUS9W-T<B`BV+G8K]BO(-BUV*W;C-BM(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(MF!
MV8?8L=BSV*H@V+G8K]BO(-BUV*W;C-BM(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")51$@@V8;8I]F%
MV+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C(Q,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R
M("+8K]BGV*_9AR#;C-F(V8;;C-JIV*\@V8;8I]F%V+G8JMBHV+$@(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`BV*C8L=F&V*?9A=F'V90@VJG8I]BQV*C8L=BO
MVXP@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(MBOV+/8JMF'($E$(-F&V*?9A=BYV*K8J-BQ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+B(*;7-G<W1R("+8K]BGV*_9A]F4(-F&V*?9A=BYV*K8
MJ-BQ(-BGV+'8I]BFV8<@V+38K]F'(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(MBBV*_8L=BS(-F%V8+8M=BO
M(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D
M8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R
M("+9@MBGV838J"#9OMBQV8C9AMBOV8?9E"#9AMBGV878N=BJV*C8L2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(MBHV+'9AMBGV879
MA]F4(-JIV*?8L=BHV+'8K]N,(-F&V*?9A=BYV*K8J-BQ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BV*C8L=F&V*?9A=F'
MV90@VJG8I]BQV*C8L=BOVXP@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@
M(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(MF&V8C8N2#9OMN,V+K8I]F%
M(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+B(*;7-G<W1R(")A<&E?:60@V8;8I]F%V+G8JMBHV+$@V*?8
ML]BJ(-F((-N,V*<@V*?8LB#8J-N,V88@V+'9@=BJV8<@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`BV;[8I]BQV*?9A=BJV+$@V8;8I]F%V+G8JMBHV+$@V8@@VXS8IR#8I]BR
M(-BHVXS9AB#8L=F!V*K9AR(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`BV878K-F(V+(@V;[8K]BQ(-F&V*?9A=BYV*K8J-BQ(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("+9A=BLV8C8LB#9OMBOV+$@V8;8
MI]F%V+G8JMBHV+$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<U"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS
M9W-T<B`BV;[8L=F(V*K:J=F$(-F&V*?9A=BYV*K8J-BQ(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("+9OMBQV8C8JMJIV80@V8;8
MI]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@
M7"(E<UPB(@IM<V=S='(@(MJOVXS8L=F&V*_9A]F4(-F&V*?9A=BYV*K8J-BQ
M.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A;&ED
M('-H87)E(&]B:F5C="(*;7-G<W1R("+8M-N,V*$@V*C9AR#8I]BTV*K8L=BG
MVJD@VJ_8L-BGV+38JMF'(-BTV*_9A]F4(-F&V*?9A=BYV*K8J-BQ(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q
M"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("+8HMBO
MV+'8LR#8L]BQVH;8M-F%V8<@V8;8I]F%V+G8JMBHV+$B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@
M(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("+8K]BGV*_9AR#;C-F(
MV8;;C-JIV*\@V8;8I]F%V+G8JMBHV+$@(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(MF%V8C8
MK-F(V*_;C"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`BV*C8
ML=JOV+'8K]BGV8;8K]F&(-BGV8;8JMBNV*?8J"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B5"U3=&]R;7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(MF%V8;8JMBTV+$@VJG9AMF&V*_9AR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A
M;&EC(@IM<V=S='(@(MBMV+'9B-F!(-JIV*PB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@
M9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(MBMV+'9B-F!(-JIV*PB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA
M;G5A<GDB"FUS9W-T<B`BVIC8I]F&V8C;C-F'(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*
M87!A;F5S92`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES
M86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B
M92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G
M<W1R("+8LMN,V+'9OMN,V+'8I]F'V8;;C"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(MJ8V8C8
MIMN,V8<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("+:F-F(V*;9AB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G
M:60@(DIU<W1I9GDB"FUS9W-T<B`BV8?9A>*`C-BJV+'8I]BR(-JIV+'8K]F&
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(MF'V87B
M@(S8JMBQV*?8LMN,(-F(V+/8MR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`BV8?9A>*`C-BJV+'8I]BRVXP@VJG8I]F%V80B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(MF'V87B@(S8JMBQV*?8
MLMN,(-J&V;XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R
M("+9A]F%XH",V*K8L=BGV++;C"#8L=BGV+/8JB`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG
M:6YA;#\B"FUS9W-T<B`BV*?8M=F$VXP@V8;:K]F'(-BOV*?8M-BJV8<@V+39
MB-BOV)\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`BVJG8I]BQV+/8I]BR(&ME<F)E<F]S92#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@V+'8IR#8L=BO(-JIV+'8KR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`BV*?;C-BLV*?8KR#:J=F$VXS8KR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E
M<G!R:6YT(@IM<V=S='(@(MBGV*O8L2#8I]F&VJ_8M-BJ(-JIV83;C-BO(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(MBWV8C9A"#:J=F$VXS8KR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B
M"FUS9W-T<B`BV8;9B-BY(-JIV83;C-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R
M("+:J=BGV+'8J-BQV*\@VJG9A-N,V*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BVJG9A-N,V*\@V8+8
MJ-F$V*?9BR#8K]BQ(-JIV*?8L=BSV*?8LB#8N=F%V8C9A=N,(-JIV83;C-BO
M(-F%V8C8K-F(V*\@V*?8L]BJ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0S"FUS9VED(")+:61S(@IM<V=S='(@(N*`C-BHVH;9A^*`C-F'V*<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E
M86X@*$550RU+4BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),
M85]Y;W5T(@IM<V=S='(@(MBLV*?9AMF%V*?;C-N,(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B
MV++8J-BGV88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$
M96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("+9AMN,V879
MA]F4(-BBV*[8L2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I
M9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`BV*K8NMN,VXS8L2#8
MHMBNV+';C-F&(-BGV+/9A2#8L=F%V+(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T
M97(B"FUS9W-T<B`BV+'8J-BY(-BBV*[8L2(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(MBBV*[8
ML=N,V88@V*C8L=F(V++8L=BSV*?9AMN,.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R(*;7-G<W1R("+8HMBNV+';C-F&(-F(V+'9B-BO.B`E<R(*"B,@"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(MBBV*[8L=N,
MV88@V8C8L=F(V*\@.B`E<R#8I]BR("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R
M("+8HMBNV+';C-F&(-F(V+'9B-BO.B#9A]BQVJ_8LB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0HC+"!F=7IZ>0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(MBOV*?8K]F'(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`BV*W9@MF(V8(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("+8K-BG
MV8;9A=BGVXS;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("+:AMF^(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B
M"FUS9W-T<B`BV+/8L=BBV878KR#:AMF^(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`BV879
M@MBGV*_;C-BQ(-J&V;XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@
M(DQE<V]T:&\B"FUS9W-T<B`BV+'9B-BT(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R
M("+8N=BTV8(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS
M=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("+9
MAMF%XH",V8;9A2#8J-BGV+'8I]F&(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T
M<B`BV*C8I]BQV8;8K]JOVXP@V+/8J-JI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`BV*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BRV8C8K]F'V8;:
MK]BGV84B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(MBHV*?8L=F&
MV*_:K]N,(-BSV*C:J2#8K]N,V+'9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A
M:6X@4VAO=V5R(@IM<V=S='(@(MBHV*?8L=F&V*_:K]N,(-F((-BQVJ_8J-BG
MV+$@V+/8J-JI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(MBHV*?8L=BGV88@V+/8J-JI(-BHV8<@V8?9A=BQV*?9AR#8L=BYV*\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM
M<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("+8J-BQV8$@V+/8J-JI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@
M(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(MBHV+'9@2#9B"#8L=JOV*C8
MI]BQ(-BSV*C:J2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I
M9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@Q-`IM<V=I9"`B3&EN:R(*;7-G<W1R("+9OMN,V8C9AMBO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`BV8;9@MBG
MV+<@V;[;C-F(V8;8KR#8J-F'.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE
M(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`BV*+8K]BQ
MV+,@V;[8L]BJ(-BGV83:J=BJV+'9B-F&VXS:J2#8L=BG(-BHV8<@V+79@=BM
MV8<@V*?;C-BLV*?8KR#9OMN,V+K8I]F%V(P@V*C9AR#9A]F&VJ_8I]F%(-F%
MV+38I]F'V*_9A]B,(-F^VXS9B-F&V*\@V*_9A]N,V*\B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED
M("),:6YK<R(*;7-G<W1R("+9OMN,V8C9AMBOXH",V8?8IR(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S
M='(@(MJIV8C:J=N,(-F$VXS9AMF(VJG8LR(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`BV8'9A]BQV+/8JB`M(-JIV*?8
ML=BHV+$@V87;C.*`C-BJV8C8I]F&V*\@V;[9B-BTV8<@V+'8IR#8J-BHVXS9
MAMBO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$
M871A8F%S97,B"FUS9W-T<B`BV8'9A]BQV+/8JB#8K]BGV*_:K]BGV8;9A]BG
MXH",(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI
M<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BV8'9A]BQV+/8JB#8N=F&V*?9B-N,
MV88@V+'8I]F'V8;9A=BG(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM
M<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`BV8'9A]BQV+/8JB#8K-BOV*?9
MB-F$(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*
M;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("+9@=F'V+'8L]BJ(-BBV+'8
MM-N,V8@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X
M.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(MF!V8?8L=BSV*H@V+'8I]F'
MV8;9A=BG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`BV8'9A]BQV+/8JB!)9"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),
M:7-T+4]W;F5R(@IM<V=S='(@(MF!V8?8L=BSV*H@V878I]F$VJDB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES
M="U0;W-T(@IM<V=S='(@(MF!V8?8L=BSV*H@V;[8L]BJVXPB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3
M=6)S8W)I8F4B"FUS9W-T<B`BV8'9A]BQV+/8JB#8N=BVV8C;C-F1V*HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B
M3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("+9@=F'V+'8L]BJ(-BYV*_9A2#8
MN=BVV8C;C-F1V*HB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D
M.B`E<R(*;7-G<W1R("+9@=F'V+'8L]BJ(-JIV*?8L=BHV+'8I]F&(-F!V+G8
MI]F$(-F&V87;C.*`C-BHV*?8M-BO(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`BV8'9A]BQV+/8JB#:J=BGV+'8J-BQV*?9
MAB#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KR(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`BV8'9A]BQV+/8JB#:J=BGV+'8J-BQV*?9
MAB#9@=BYV*?9A"#9AMF%VXSB@(S8J-BGV+38KR(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("+8I]BO
MV*C;C-BGV*HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DQI=&AU
M86YI82(*;7-G<W1R("+9B-BGV*W8KR#9OMF'V8;8IR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I
M;F<N+BXB"FUS9W-T<B`BV*C8I]BQVJG8L=BOV88N+BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B
M"FUS9W-T<B`BV+/8I]BYV*H@V878K=F$VXPZ("(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@
M(MF%V*W9A-N,V9'8JB#9B"#8L]BGV+G8JB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BV879B-F"
MV+G;C-BJ(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(MF(V+'9B-BO
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`BV*[8L=F(V*PB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-3D*;7-G:60@(DQO9VEN(@IM<V=S='(@(MF(V+'9B-BO(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T
M<B`BV8C8N-BGVXS9@2#9B-BQV8C8KR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB
M"FUS9W-T<B`BV8C8L=F(V*\@V8;8I]F%V8C9@=F1V8(@V*C9B-BO(-BRVXS8
ML=BG(-F&V*?9A2#:J=BGV+'8J-BQ(-F((-N,V*<@V*?8L]F%(-BQV878LB#9
MB-BGV+'8KR#8M-BOV8<@V*?8M-BJV*C8I]F'(-BHV8C8KR`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB
M"FUS9W-T<B`BV8C8L=F(V*\@V8;8I]F%V8C9@=F1V8(@V*C9B-BO+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X
M="(*;7-G<W1R("+9A=BJV88@V*C9A-F&V*\B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`BV+G8M-F"(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@
M(DQO=R(*;7-G<W1R("+9OMBGVXS;C-F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W
M97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("+8K=BQV8C9@2#:J=F(VH;:J2#;
MC-F(V8;8I]F&VXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(MBMV+'9B-F!(-JIV8C:AMJI(-F$V*?8JMN,V88B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(MBG
MV+G8K]BGV*\@VJG9B-J&VJD@VXS9B-F&V*?9AMN,(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(MF^VXS8
MNMBGV84@V+'9B-BR(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`BV;[;C-F(V+/8JB!-4RU43D5&(-BTV*?9
MA=F$(-F'VXS:AB#8K]BGV*_9A^*`C-BGXH",VXS;C"#9AMN,V+/8JB(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA8V%O(@IM<V=S='(@(MBJV+G8
MM]N,V838I]BJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B
MV*S8I]BOV8@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G
M:60@(DUA:6PB"FUS9W-T<B`BV8;8I]F%V8<@V*?9A-JIV*K8L=F(V8;;C-JI
MVXPB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(MBSV+'9OMBQV+/8JB#9AMBGV879AR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("+8L]BGV*[8JMF&
M(-F^VXS9B-F&V*\N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R("+9AMBGV879AR#8I]F$VJG8JMBQV8C9AMN,VJG;
MC"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`BV8;8I]F%
MV8<@V*?9A-JIV*K8L=F(V8;;C-JIVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z
M>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(MF&V*?9A=F'(-BGV83:J=BJV+'9
MB-F&VXS:J=N,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("+9A=BOVXS8L=N,V*H@
MV8@@V*K8N=N,VXS9AB#8L=F&VJ\@V*_8L]BJV8?B@(S9A]BGVXS;C"#:J=F'
M(-BTV878IR#9A=F(V*?8L=BO(-BQV*<@V*C8IR#8HMF&V8?8IR#9AMBGV87B
M@(S:K]BPV*?8L=N,(-F%VXSB@(S:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M
M87`B"FUS9W-T<B`B36%P,C0@;6%P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*
M;7-G<W1R(")-87!1=65S="!M87`B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*
M;7-G:60@(DUA<F-H(@IM<V=S='(@(MF%V*?8L=BS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%R9VEN(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S(@IM<V=S='(@(MBYV838I]F%V*H@VJ_8L-BGV+';
MC"#8J-BG(-F^V+':AMF%(-F%V+38I]F'V*_9AR#8M-BOV8<O(-F%V+38I]F'
MV*_9AR#9AMBTV*_9AR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N
M9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(@V+G9A-BGV878JB#:
MK]BPV*?8L=N,(-BHV*<@V+G9A-BGV*;9A2#8K]N,VJ_8L2`HV878I]F&V8;8
MKR#9A=F'V84OV;[8I]BSV*X@V*_8I]BOV8<@V+38K]F'*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B
MV*W8I]BTVXS9AR(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S
M"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BV8';C-F$V*_B@(S9
MA]BGVXP@V*?9AMBWV*C8I]F"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS
M9VED(")-875R:71A;FEA(@IM<V=S='(@(MBMV*?8M-N,V8<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`BV*C;C-BTVXS9AMF'(-BG
MV+G8JMBHV*?8L2#9A=BLV*?8LB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(MBJV*[8M]N,(-BGV+(@V*C;C-BT
MVXS9AMF'(-F"V+/9A=BJV8?8I]N,(-F^VXS8NMBGV84B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@(@IM<V=S='(@(MBHVXS8M-N,V8;9AR#8K]F%V*<@V*_8L2#;LMNT(-BS
MV*?8N=BJ(-JOV+#8M-BJV8<Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("+8
MJ-N,V+3;C-F&V8<@V*_9A=BG(-BOV+$@V[8@V+/8I]BYV*H@VJ_8L-BTV*K9
MASH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU
M;2!L96YG=&@B"FUS9W-T<B`BV*C;C-BTVXS9AMF'(-BWV8C9A"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-
M87DB"FUS9W-T<B`BV87;C"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G
M:60@(DUA>6]T=&4B"FUS9W-T<B`BV*S8I]F&V878I]N,VXPB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@
M(MF^V++8M-JIVXPB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(MBGV+G8MMBGV*$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z
M(@IM<V=S='(@(MF%V*\@VJ_8LMN,V8;:K]BGV8;;C#HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED
M(")-97)G92!C96QL<R(*;7-G<W1R("+8I]BOV+K8I]F%(-BSV839B-F$V8?8
MIR(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(MF^VXS8NMBGV84B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I
M9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(MF^VXS8NMBGV84@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BH
MV*?8LMBHVXS9AMN,(-BTV*\@V*?9A=BG(-JOV8C8I]F'VXP@V*?9A=BVV*?8
MH2#:J=F&V8;8K]F'(-F&V87;C.*`C-BJV8C8I]F&V*\@V*C8I]BRV*C;C-F&
MVXP@V+39B-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S
M='(@(MF^VXS8NMBGV84@V879AMF"V+;;C"#8M-BO(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V
M,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(MF&V8C8N2#9OMN,V+K8
MI]F%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!7
M96%T:&5R(@IM<V=S='(@(MBBV*@@V8@@V8?9B-BGVXP@365T87(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("+8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8
MK]BSV*K8L=BS(-F&VXS8L]BJ(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(MBHV839B-JI($UE=&%R(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;
MC-BSV*HN(-BLV++8IMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8
MI]F%V*?9AMF'(-BKV*C8JB#8M-BOV8<@V*?8L]BJ(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0HC+"!F=7IZ>0IM<V=I9"`B365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#9
M@MBOVXS9A=N,(-F&V*?8K]BQV+/8JB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("+8
ML=F(V+0B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R
M86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R("+8L=F(V+0@)R5S)R#8JMBYV+';C-F!(-F&V+38K]F'(-BGV+/8JB(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G
M<W1R("+8I]F&V*_8I]BRV8?B@(S8I]N,(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"B,L(&9U
M>GIY"FUS9VED(")-97AI8V\B"FUS9W-T<B`BV*?9AMBOV*?8LMF'XH",V*?;
MC"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S
M='(@(MF(V+/8MR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`BV8;9B-BY($UI
M;64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B#:J=F%VXS9AMF'(-BOV878
MI]N,(-NRV[0@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B#:J=F%VXS9AMF'(-BOV878I]N,(-NV(-BSV*?8N=BJ(-JO
MV+#8M-BJV8<Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#,Y"B,L(&9U>GIY"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@
M;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-BTV878
MIR#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"FUS9VED(")-:7)R;W(B"FUS
M9W-T<B`BV*+;C-F&V8<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*
M;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`BV878JMF!V+'9@MF'(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G
M:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N
M97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI
M8V%T:6]N+B(*;7-G<W1R("(B"B+9OMN,VJG8L=BHV8;8K]N,(-F%V8C8K-F(
MV*\@V8;;C-BSV*HN(-BTV878IR#8I]JOV+$@V87;C.*`C-BNV8C8I]F'VXS8
MKR#8I]BR(-BGVXS9AB#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#8
MI]BSV*K9@=BGV*_9AR#:J=F&VXS8KR`B"B+8J-BGVXS8KR#8HMF&V+'8IR#8
MJMF(V83;C-BO(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A
M9V4@240N(@IM<V=S='(@(MBGV+(@V*C;C-F&(-BQV8'8JMF&($E$(-F^VXS8
MNMBGV84B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E
M<W-I;VX@240N(@IM<V=S='(@(MBGV+(@V*C;C-F&(-BQV8'8JMF&($E$(-F&
MV+38L]BJ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(MBOV8C8M-F&V*C9AR(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA
M:6PB"FUS9W-T<B`BV;[8L]BJ(-BSV839B-F$VXPB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B
M"FUS9W-T<B`BV878N=BJV*_9A"#:J=BQV*_9AB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(MBJV*?8L=N,V*X@V*K8NMN,VXS8L2#;C-BGV8'8JMF'(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS
M9VED(")-;V1I9GD@55),(@IM<V=S='(@(MBJV+K;C-N,V+$@55),(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO
M9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A
M+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(MF%V*?9AR#9B"#8
ML]BGV80B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(MF%V*?9A]BGV8;9AR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36]N='-E<G)A="(*;7-G
M<W1R("+9A=BYV*K8K]F$(-JIV+'8K]F&(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E
M<R(*;7-G<W1R("+9@=BGV++9A]BGVXP@V878I]F'(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N
M9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@
M(DUO<W1L>2!#;&5A<B(*;7-G<W1R("+8J-N,V+38JMBQ(-BUV*?9@2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED
M(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(MBHVXS8M-BJV+$@V*?8J-BQVXPB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM
M<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(MBHVXS8M-BJV+$@V*+9@=BJ
MV*?8J-N,(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`BV*?9AMBJV8+8I]F$(-BH
MV8<@V;[8I]N,VXS9AB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S='(@(MBGV8;8JMF"
MV*?9A"#8J-F'(-BHV*?9A-BG(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(MBG
MV8;8JMF"V*?9A"#8J-F'(-BQV*?8L]BJ(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@
M(MBGV8;8JMF"V*?9A"#8J-F'(-BHV*?9A-BG(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(MBGV8;8JMF"V*?9A"#8J-F'(-F^V*?;C-N,V88B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@
M(DUO=F4@=7`B"FUS9W-T<B`BV*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(MF!V8?8L=BSV*H@V;[8
MI]N,VXS9AN*`C-F^V+$@VH;9AMBO(-BSV+?8K=N,(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I
M;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B
MVH;9AMBO(-BGV8;8JMBNV*?8J-N,(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("+8K=BSV*?8
MJ"#9A=F&(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(MBGV+?9A-BGV+G8I]BJ
M(-BMV+/8I]BH(-F%V88B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`BV*_8L=JOV*?9AR#9A=F&
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@
M4&]R=&%L($QA>6]U="(*;7-G<W1R("+8K-BGV8;9A=BGVXS;C"#8K]BQVJ_8
MI]F'(-F%V88B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("+9AMF'
MV(P@V879AB#9A=F(V*?9@=F"(-F&VXS8L]BJV84B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+9AMBGV84B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R(")54DP@V;[8I]N,V8<@3F5T<V-A<&4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G
M<W1R(").971S8V%P92!#02!P;VQI8WD@55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W
M86P@55),(@IM<V=S='(@(DYE='-C87!E(%)E;F5W86P@55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C
M87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(%)E=F]C871I
M;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("+8JMF(
MV+;;C-BM(-JOV8C8I]F'VXP@3F5T<V-A<&4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP92(*;7-G<W1R("+9AMF(V+D@VJ_9B-BGV8?;C"!.971S8V%P
M92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE
M='=O<FLB"FUS9W-T<B`BV+38J-JIV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G
M<W1R("+9A]BQVJ_8LB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R("+8K]BSV*K9AR#8K-BOVXS8KR(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V
M"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`BV*_8L]BJV8<@V*S8K]N,
MV*\B"@HC(`HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@
M365S<V%G92!T;R`E<R(*;7-G<W1R("+8I]N,V*S8I]BO(-F^VXS8NMBGV84@
M*"5S*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO
M;VXB"FUS9W-T<B`BV878I]F'(-F&V8@B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO
M;F%L*2(*;7-G<W1R("+9AMBGV84@VJG8I]BQV*C8L=N,(-BLV*_;C-BO("C8
MI]BNV*K;C-BGV+';C"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L
M86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(MBGV+/9A2#8L=F%
MV+(@V*S8K]N,V*\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X
M<&ER92!O;B`E>"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LB#9A-BZV8@@V*[9
MB-BGV8?8KR#8M-BO(-BOV+$@)7@@(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H
M+B(*;7-G<W1R("+8I]BSV84@V+'9A=BRV8?8I]N,(-BLV*_;C-BO(-BJV+?8
MI]BHV8(@V8;8K]BGV+'8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB
M"FUS9W-T<B`BV;[9AMBLV+'9AR#8K-BOVXS8KR`HV*[8I]F$VXPI(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(DYE
M=W,B"FUS9W-T<B`BV*?8KMBHV*?8L2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`BVJ_8L=F(
MV8?B@(S9A]BGVXP@V*[8J-BQVXPB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("+8J-BYV*_;C"(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X
M="`T(%!H87-E<R(*;7-G<W1R("+9@=BGV+(@V*C8N=BOVXPB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@
M(MJOV++;C-F&V8?B@(S9A]BGVXP@V*C8N=BOVXPB"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS
M9W-T<B`BV*C8N=BOVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI
M9V5R(@IM<V=S='(@(MBTV*@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`BV+38J"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PHC+"!F=7IZ>0IM<V=I9"`B3FEU92(*;7-G<W1R("+8N=BOV*\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED
M(").;R(*;7-G<W1R("+9AMF'(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("+8K]BG
MV*_9AR#9OMN,VJG8L=BHV8;8K]N,(-BOV+$@V*_8L]BJV+'8L]N,(-BHV+'8
MI]N,(-F&V+38I]F&(-BOV*?8K]F&(-BJV8'8I]F(V*K9A]BG(-F(V*S9B-BO
M(-F&V*_8I]BQV*\B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O
M<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B25-/(-F&VXS8L]BJ(-BG
MV+/8JMBQV*?8JMJ8VXP@V*_8L2#8K]BSV*K8L=BSVXP@V*C8L=BGVXP@V+/8
MI]BNV*K9AB#8JMBUV8C;C-BQ("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M
M<&QA=&4N(@IM<V=S='(@(MBGV83:K]F(VXP@V*_8L]BJV8?B@(S8I]N,VXP@
MV8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G
M<W1R("+8J-F$V*?:J=N,(-BOV+$@V879B-F"V+G;C-BJ(-BOV+'8KMF(V*?8
ML]BJ(-BTV*_9AR#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MV8?;C-J&(-F&V*?9A2#8JMF"V8C;C-F%VXP@V*C8L=BGVXP@V*K8M=BOVXS9
M@B#9A]F(VXS9D=BJ($U#04P@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E
M+B(*;7-G<W1R("+8J-BOV8C9AB#8JMBZVXS;C-BQ(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A
M;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(MF'VXS:
MAB#9A=BLV8C8LB#9@=BQV+G;C.*`C-BGVXP@V8;9A=N,XH",V*K9B-BGV8;8
MKR#8J-F'(-BGVXS9AB#9A=BLV8C8LB#8I]BVV*?9@=F'(-BTV8C8KR(*"B,@
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38W(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(MF'VXS:AB#8
MI]BWV838I]BYV*?8JB#9OMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,("5S(-F%
MV+38KMBU(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`BV8?;C-J&(-BGV+?9A-BGV+G8
MI]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@1E10(%9&4R#9A=BTV*[8
MM2#9AMBTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N(@IM<V=S='(@(MF'VXS:AB#8I]BWV838I]BYV*?8JB#9
MOMN,VJG8L=BHV8;8K]N,(-BHV+'8I]N,(%-13"!61E,@V878M-BNV+4@V8;8
MM-BO(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`BV8?;C-J&(-BGV+?9A-BGV+G8
MI]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@4U%,+49I;&4@5D93(-F%
MV+38KMBU(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM
M<V=S='(@(MF'VXS:AB#8I]BYV*K8J-BGV+';C"#8J-BGV8+;C"#9AMF%V*?9
MAMBO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("+9A]N,VH8@V879@MBUV*_;C"#9@=BQV*?9A]F%(-F&V+38KR(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("+9A]N,VH8@V;[8L=F(V8;8K]F'XH",
MV*?;C-N,(-BGV+'8L]BGV80@V8;8M-BO(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`BV8?;
MC-J&(-BBVXS:J=F(V8;;C.*`C"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("+9A]N,VH8@V87:J=BGV8;;C"#8
MJMF&V+C;C-F%(-F&V+38K]F'(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(MF'VXS:AB#9A=JIV*?9AMN,(-BJV8;8N-N,V84@V8;8
MM-BOV8<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T
M<B`BV8?;C-J&(-F^VXS8NMBGV87;C"#9@=BQV*?9A]F%(-F&V+38KR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V
M"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`BV8?;C-J&(-F&
MV*?9A=N,(-F%V+38KMBU(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@
M<W!E8VEF:65D+B(*;7-G<W1R("+9A]N,VH8@V+39A=BGV+'9A^*`C-BGXH",
MVXS;C"#9A=BTV*[8M2#9AMBTV*\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("+8
MHMN,V8;8K]F'(-F&V*?9A=BWV*C9B-BYVXP@V8;;C-BSV*HB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
MV*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($A45%`@V*?8L]F%(-BQ
MV878LMN,(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+8
MJ-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@24U!4"#8I]BSV84@V+'9
MA=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(MBHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB!+97)B97)O<R#8I]BS
MV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M
M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+8J-BQV*?;C"#8JMBUV*_;C-F"
M(-F'V8C;C-F1V*H@V8C8L=F(V*\@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'
MV84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BV*C8L=BGVXP@V*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(%!!4U-71"#8I]BSV84@V+'9A=BRVXP@V8'8
ML=BGV8?9A2#9AMBTV*_9AR#8I]BSV*HB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(MBHV+'8I]N,(-BJV+78
MK]N,V8(@V8?9B-N,V9'8JB!334(@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'
MV84@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS
M9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(MBJV8+8I]BVV*?;
MC"#8J]BHV*H@V8;8I]F%VXP@V*_8L2#8I]F&V*K8N-BGV+$@V*K8H]N,VXS8
MKR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T
M<B`BV*K9AMBXVXS9A2#9AMBTV*_9AR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S
M(@IM<V=S='(@(MBHV*_9B-F&(-F"V8C8I]BYV*\B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#D*;7-G:60@(DYO('-E<&%R871O<B!S<&5C
M:69I960N(@IM<V=S='(@(MF'VXS:AB#8K-BOV*?:J=F&V8;8K]F'XH",V*?B
M@(S;C-N,(-F%V+38KMBU(-F&V+38KR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S
M(@IM<V=S='(@(MBHV*_9B-F&(-BSV878JB(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@S"B,L(&9U>GIY"FUS9VED(").;R!S=6-H(&9I;&4B
M"FUS9W-T<B`BV*C8K]F(V88@V+/9A=BJ(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("+8M-BGV*[9AR#9A=F(
MV8+8JMN,(-BHV+'8I]N,(-JIV*?8M-F'(-F%V8C8K-F(V*\@V8;;C-BSV*HB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(MF'VXS:AB#9AMBGV84@VJG8I]BQV*C8L=N,(-F((-N,V*<@V*?8
ML]F%(-BQV878LMN,(-BGV+'8L]BGV80@V8;8M-BO(@H*(SH@9G)A;65W;W)K
M+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D
M871A(')E='5R;F5D(@IM<V=S='(@(MF'VXS:AB#8K]BGV*_9AR!834P@V878
MN=BJV*C8L=N,(-BHV*?8LMJOV+'8K]BGV8;8K]F'(-F&V+38K]F'(-BGV+/8
MJB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y
M"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`BV*C8K]F(V88@V879@MBOV*?8
ML2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9AMBSV*[9A^*`C"#8K]BQ
M(-F^VXS:J=BQV*C9AMBOVXP@V*?8M=F$VXP@V;[;C-BOV*<@V8;8M-BO+B#9
MOMN,VJG8L=BHV8;8K]N,(-BQV*<@V*_9B-BHV*?8L=F'(-BJV8C9A-N,V*\@
MVJG9AMN,V*\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED
M(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9AMBSV*[9A^*`C"#8
MK]BQ(-F^VXS:J=BQV*C9AMBOVXP@V+39A=BG(-F^VXS8K]BG(-F&V+38K]F'
M(-BGV+/8JBX@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BGV+'9AR#8
MJMF(V83;C-BO(-JIV8;;C-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R("+9A]N,VH;B@(S:
MJ=BOV*?9A2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B
MV8?;C-J&XH",VJG8K]BGV84@*-BVV879AMN,(-BGV+/8JMF!V*?8K]F'(-JI
MV8;;C-BO*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").
M;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").;W)D:6,@*$E33RTX.#4Y
M+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M
M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R
M("+9AMN,V84@VJG8L=F'(-BTV878I]F$VXPB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($%F=&5R
M(@IM<V=S='(@(MF&V8<@V*C8N=BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B
MV8;9AR#9@MBHV80B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT
M,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("+;C-JI(-BTV*?8
MKMF'(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`BV;[;C-BGV*_9A^*`C-BSV*?8
MLMN,(-F&V+38K]F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R("+8JMF&V+C;
MC-F%(-F&V+38K]F'(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(MF^V+38JMN,
MV*C8I]F&VXP@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S
M(@IM<V=S='(@(MN,V*?8K]BOV*?8M-BJV8?8IR(*"B,Z('-E<G9I8V5S+V]B
M<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN(@IM<V=S='(@(MJ&VXS8LMN,(-BHV+'8I]N,(-F%V+'9B-BQ
M(-F&VXS8L]BJV(P@V*C9AR#8N=F"V*@@V*C8L=JOV+'8KR(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E
M;6)E<B(*;7-G<W1R("+9AMF(V*?9A=BHV+$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB97(B"FUS9W-T<B`BV+G8K]BO
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M
M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BV*K8N=BOV*?8KR#9AMF(VXS8
ML]F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M("+8JMBYV*_8I]BO(-BSV*K9B-F&V8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@
M<F]W<R(*;7-G<W1R("+8JMBYV*_8I]BO(-BSV+?8L=F'V*<B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I
M9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BV*?8N=BOV*?8KR#8J-BQV*?;C"#8
MJ-BQV8C8LMBQV+/8I]F&VXP@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878
MM-BNV+4@V8;8M-BOV8;8KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`BV*K8H]N,VXS8
MKR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("+8M-N,V*$B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`BV*?;C-BLV*?8KR#:J=F&V8;8K]F'(-BTVXS8H2(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L
M(@IM<V=S='(@(MF'V+38JMBGVXS;C"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@
M(MBGVJG8JMBHV+$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G
M:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(MF!VXS9A-BJV+$@V*C;C.*`
MC-BMV+'9A=BJVXPB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`BV*_9@=BJV+$@VJG8I]BQ(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(MBG
MV+/9A2#8L=F%V+(@V*S8K]N,V*\@V8@@V*?8L]F%(-BQV878LB#9@=BYV83;
MC"#8J-BGVXS8KR#9A=BJV8'8I]F(V*H@V*C8I]BTV8;8KR(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V8+8K]N,V87;C"(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("+8I]BSV84@V+'9A=BR("#9@MBO
MVXS9A=N,(-F&V*?8K]BQV+/8JB#8I]BSV*HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U
M<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(MBJV8;9A]BG(-JIV*?8
ML=BSV*?8LMF'V*?;C"!)34%0V;[9B-BTV8?B@(S9A]BGVXP@V878M-BJV+':
MJ2#8L=BG(-F^V+38JMN,V*C8I]F&VXP@V87;C.*`C-JIV8;9AMBO("(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`BV8'9@MBW(-BBVXS9AMBOV8<@V8;8I]F%
MV+?8J-F(V+DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M
M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`BV*K9AMF'V*<@VXS:J2#8
MHMBOV+'8LR#9OMBSV*H@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V878K-BGV+(@
MV*?8L]BJ(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED
M("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M
M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F
M;W(@82!S:&%R92(*;7-G<W1R("(B"B+8JMF&V8?8IR#9A=BGV83:J2#;C-BG
M(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V87;C.*`C-BJV8C8I]F&V*\@
MV878I]F$VJG;C-BJ(-N,V*<@V878K-F(V++9A]BGVXP@V878I]F$VJD@V+'8
MIR#8J-BQV*?;C"#;C-JI(-BGV+38JMBQV*?:J2`B"B+8JMBZVXS;C-BQ(-BO
MV8?8KR(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+8K]BQ(-N,VJD@V;[9AMBLV+'9
MAR#8K-BOVXS8KR#8J-BGV+(@V+39B-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O
M=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("+8I]N,V88@V;[;C-F(V8;8KR#8K]BQ
M(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR#8J-BGV+(@V+39B-BO(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(MBSVXS8L]BJV84@V+G8I]F%V80B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S
M='(@(MJOV++;C-F&V8<F(W@R,#!C.]F'V*<B"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`BVJ_8
MLMN,V8;9A^*`C-F'V*?;C"`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R("+9A-N,V+/8JB#9A=BQV*K8J"#8M-BOV8<B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N
M(@IM<V=S='(@(MBSV*?8LMF%V*?9AB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET
M(@IM<V=S='(@(MF(V*?8K=BO(-BSV*?8LMF%V*?9AMN,(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*;7-G
M<W1R("+8L]BGV++9A=BGV8;8K]F'VXPB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B
M"FUS9W-T<B`BV*?9A-JOV8C;C"#8I]BUV83;C"#8J-BQV8;8I]F%V8?9E"#:
MJ=BGV+'8J-BQV*_;C"(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I
M;B`E<SHB"FUS9W-T<B`BV*?9A-JOV8C9A]BGVXP@V*?8M=F$VXP@V*_8L2`E
M<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`BV*_;
MC-JOV+$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/
M=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("+8I]BWV838I]BYV*?8JB#8K]N,
MVJ_8L2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@
M(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(MF%V*S9B-BRXH",V8?8I]N,
M(-F%V*?9A-JI(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y
M"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`BV*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%!!32#9@MBGV*C9A"#8
MK]BSV*K8L=BSVXP@V8;;C-BSV*HB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C
M:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T
M<B`BV*?9A=BVV*?8H>*`C"#8K]N,V*S;C-BJV*?9A-N,(%!'4"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%
M;F-R>7!T960@1&%T82(*;7-G<W1R("+9OMN,V+K8I]F%(-BQV878LMBHV8;8
MK]N,(-BTV*_9A]F4(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B#:
MJ=F$VXS8KR#8N=F%V8C9A=N,(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`BV;[;C-BZV*?9A2#8L=F%V++8J-F&V*_;C"#8M-BO
MV8<OV*?9A=BVV*?8H2#8M-BOV8<@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R("+:J=BO(%!(4"(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S
M='(@(MF^V8C8L]BJV8<@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T
M<B`BV*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BYV+78L=JOV*?9A]N,(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@
M(E!-(%-H;W=E<G,B"FUS9W-T<B`BV+':K]BHV*?8L2#8N=BUV+':K]BGV8?;
MC"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y
M"FUS9VED(")032!3;F]W(@IM<V=S='(@(MBHV+'9@2#8N=BUV+':K]BGV8?;
MC"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P
M"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BV*K:K]BQVJ\@V+G8
MM=BQVJ_8I]F'VXPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,0HC+"!F=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(MBH
MV+'9@2#8N=BUV+':K]BGV8?;C"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R
M(")4+5-T;W)M<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G
M:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(MBHV+/8
MMR!03U-)6"#8I]BR(-BHVXS9AB#8L=F!V*K9AR#B@(S8I]BSV*HB"@HC.B!L
M:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`BV;[9
MB-BSV*K9AR!02%`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(MF!
MV*?8M=F$V8?B@(S:K]BPV*?8L=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY
M"FUS9VED(")086MI<W1A;B(*;7-G<W1R("+:AMBSV*C8I]F&V*_9AB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")086YA
M;6$B"FUS9W-T<B`BV8;8I]F%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U
M82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(MF"V+/9A=BJVXP@V*?8J-BQVXPB"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G
M<W1R("+8I]BSV84@V+'9A=BR("(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@V*C8IR#9A=F(V8'9D=F"VXS9
MD=BJ(-BJV+K;C-N,V+$@VXS8I]F!V*HN(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"FUS9VED(")087-S=V]R9"!I;F-O<G)E
M8W0B"FUS9W-T<B`BV*?8L]F%(-BQV878LB`@V8;8I]BOV+'8L]BJ(-BGV+/8
MJB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-BHV8<@V*K8M=BOVXS9@B#9
MA]F(VXS9D=BJ(%)!1$E54R#9AMN,V*?8LB#8K]BGV+'8KR(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@(-BHV*<@V*K8
MH]N,VXS8KR(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM
M<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(MBGV+/9A2#8L=F%V+(@.B`B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R
M9',@;75S="!M871C:"XB"FUS9W-T<B`BV*?8L]F%(-BQV878LN*`C-F'V*<@
MV*C8I]N,V*\@V879AMBWV*C9@B#8J-BGV+39AMBO(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(MJ&V+/8
MJ-BGV8;8K]F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`BVH;8L]BHV*?9AMBOV88@V*?8LB#8JMBNV*K9AR#8L=BSV84B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED
M(")0871H(@IM<V=S='(@(MF%V+/;C-BQ(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T
M<B`BV*O8J-BJ(-F&V*?9A=F'V*?;C"#9AMBGV878N=F$V8C9A2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(MF%V+'8K]F%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`BV*_8L=BUV*\B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT
M.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S
M='(@(MBGV*S8L=BGVXP@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M
M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("+8HMN,
MV*<@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BOV+$@V838K=BXV8<@
MV8C8L=F(V*\@V*?8K-BQV*<@V+39B-BOV)\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R
M("+9A=BLV8C8LB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T
M(&1E;&5T960N(@IM<V=S='(@(MF%V*S9B-BR("!<(B5S7"(@V*W8L-F!(-F&
MV+38KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U
M>GIY"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("+9A=BLV8C8
MLB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N
M<R(*;7-G<W1R("+9A=BLV8C8LMF'V*<B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X
M"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+8
ML]BQV;[8L=BSV*K;C"#9A=BLV8C8LMF'V*<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S
M='(@(MBGV+?9A-BGV+G8I]BJ(-BTV*[8M=N,(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("+8K=N,V8C8I]F&V*?8JB#8KMBG
MV8;:K]N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("+8JMF$V8'9AB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G
M<W1R("+8N=JIV+/9A]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I
M<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("+9OMN,VJG8
ML]F$V8?8IR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`BV838M]F!V*?9BR#8K]BGV*[9
MA"#:AMF&V*\@V+/9A-F(V80@VJG9A-N,VJD@VJG9AMN,V*\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`BV838M]F!V*?9BR#8JMBCVXS;C-BO
M(-JIV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@V+G9
MAMBUV+$@V+'8IR#8K=BPV8$@VJG9AMN,V*\Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(MF$V+?9@=BGV8L@V*K8H]N,VXS8KR#:J=F&VXS8
MKR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V;[;C-F(V8;8KR#8I]N,V88@
MV+G9AMBUV+'9A]BG(-BQV*<@V8+8M]BY(-JIV8;;C-BO(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`BV838M]F!V*?9BR#;C-JI(-F%
MV*?9AR#9B"#;C-JI(-BSV*?9A"#9B-BGV+'8KR#:J=F&VXS8KRXB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M"FUS9W-T<B`BV838M]F!V*?9BR#9AMBGV87;C"#8J-BQV*?;C"#8K]BSV*K9
MAR#8K-BOVXS8KR#9B-BGV+'8KR#:J=F&VXS8KSHB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+B(*;7-G<W1R("+9A-BWV8'8I]F+(-BBV*_8L=BS($E0
M(-F%V+G8JMBHV+';C"#9B-BGV+'8KR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N(@IM<V=S='(@(MF$V+?9@=BGV8L@VXS:J2#8JMBGV+';C-BN(-F%V+G8
MJMBHV+$@V8C8I]BQV*\@VJG9AMN,V*_8C"#8JMBYV*_8I]BO(-BQV8C8LMF'
MV*<@V*_8L2#9A=BGV8<@V+'8IR#:J=F&V*K8L=F$(-JIV8;;C-BO(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BV838M]F!V*?9BR#;C-JI(-BR
MV878I]F&(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*\B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(MF$V+?9
M@=BGV8L@V*[9A-BGV+79A^*`C-BGXH",VXS;C"#8I]BR(-F%V+3:J=F$(-BQ
MV*<@V*C9AMF(VXS8L]N,V*\B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(MF$V+?9@=BGV8L@V8;8I]F%(-JIV*?8L=BHV+$@V8@@V*?8L]F%(-BQ
MV878LB`@V*[9B-BO(-BQV*<@V*+9A=BGV*_9AR#:J=F&VXS8KR(*"B,@(RTC
M+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HBV838M]F!V*?9BR#9A=BJV88@V++;C-BQ(-BQV*<@V*C8KMF(V*?9AMN,
MV*\N(-BTV878IR#8J-BQV*?;C"#8I]BSV*K9@=BGV*_9AR#8I]BR(-BSV*?9
MA=BGV8;9AR#8J-BGVXS8KR#8M-BQV8C8MR#8L=BG(-F"V*C9B-F$(-JIV8;;
MC-BO(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`BV838M]F!V*?9BR#9AMBGV84@V*_8L]BJV8<@V*S8
MK]N,V*\@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KSHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M(RP@9G5Z>GD*;7-G:60@(E!O;&%N9"(*;7-G<W1R("+9@=BQV878I]F&(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*
M;7-G<W1R("+8L]N,V*?8L]BJV8?8IR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(MBBV+'8I]BA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4&]R='5G86PB"FUS9W-T
M<B`BV*_8L=JOV*?9AR#9A=F&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO
M;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(MF%V*W9A"#9@MBQV*?8L=JO
MV+'9@=BJV88@V*?;C-F&(-BJV+79B-N,V+$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("+9A=BMV80@V8+8L=BGV+':K]BQ
MV8'8JMF&(-BGVXS9AB#8K-BOV8C9A"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`BV;[8L]BJ(-BH
MV8<@V*?;C-F&(-F^V8C8M-F'(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T
M<B`BV*_8L=BUV*\@V+'8M]F(V*C8JB#8K]BQ("5S(-BSV*?8N=BJ(-F"V*C9
MA#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED
M(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0<F5F<U]L9&%P.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@3$1!
M4"#9OMN,V*_8IR#9AMBTV*\B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?
M<V5S<VEO;CH@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR('-E<W-I;VX@V;[;
MC-BOV*<@V8;8M-BO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(MF!V+38I]BQ(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@
M(@IM<V=S='(@(MF!V+38I]BQ(-BOV+$@V+/8M]BM(-BOV+';C-BG.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S
M<W5R93H@(@IM<V=S='(@(MF!V+38I]BQ.B`B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4')E=FEE=R(*;7-G<W1R("+9OMN,V+3B@(S9AMF%V*?;C-BT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`BV;[;C-BTXH",V8;9A=BGVXS8M"#8JMBUV8C;C-BQ(-BOV+$@
MVXS:J2#9OMF&V*S8L=F'(-BLV*_;C-BO("(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(MJOV++;
MC-F&V8?B@(S9A]BGVXP@V8+8J-F$VXPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N
M="(*;7-G<W1R("+:AMBGV;X@V+/9AMBO(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R
M("+:J=F$VXS8KR#8M-BNV+7;C"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BV878M-JI
MV80B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L
M96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`BV*K9B-BVVXS8K2#9A=BTVJG9A"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(MF^V+'9B-J8V8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3@X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R
M;VUP="!T97AT(@IM<V=S='(@(MF%V*K9AB#8I]BYV838I]F&(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@
M2V5Y(@IM<V=S='(@(MJIV83;C-BO(-BYV879B-F%VXPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!!;&=O<FET:&TB"FUS9W-T<B`BV*?9A-JOV8C8L=N,V*K9A2#:J=F$VXS8
MKR#8N=F%V8C9A=N,(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#0*(RP@9G5Z>GD*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G
M<W1R("+:J=F$VXS8KR#8N=F%V8C9A=N,(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP
M86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+8K-F!
MV*H@VJG9A-N,V*\@V+G9A=F(V87;C"_8KMBUV8C8M=N,(-BHV*<@V879B-F!
MV9'9@MN,V9'8JB#8JMF(V83;C-BO(-F&V+38KR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*
M;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M(RP@9G5Z>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@(MBOV*?8K]F'(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("+9
MOMBQV+/B@(S9B-BLV8@B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*
M;7-G:60@(E%U;W1A(@IM<V=S='(@(MBSV8?9A=N,V8<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(@VJG9A-N,
MV*\@V+G9A=F(V87;C"!24T$@*"5D(-BHVXS8JBDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS
M9W-T<B`BV*?9AMBJV*[8I]BH(-BQV*?8K]N,V8@B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G
M<W1R("+8J-BGV+'8I]F&(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`BV*C8
MI]BQV*?9AB#8LMF(V*_9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R("+8J-BGV+'8I]F&(-BOVXS8L=F'V8;:K]BGV84B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!3
M:&]W97(B"FUS9W-T<B`BV*C8I]BQV*?9AB#9B"#8L=JOV*C8I]BQ(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`BV*C8I]BQV*?9AB#9B"#8J-BQV8$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM
M<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(MBHV*?8L=BGV88@V*C9AR#8
MJ-BQV8$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N
M9&]M($9O<G1U;F4B"FUS9W-T<B`BV+?8I]F$V+D@V*K8M=BGV*_9@=N,(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I
M;R(*;7-G<W1R("+9AMBSV*C8JB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(MBNV8C8I]F&
MV*_9AB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(MBNV8C8I]F&V*_9
MAB#9OMN,V+K8I]F%V8?8IR`B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB
M"FUS9W-T<B`BV8C8I]F"V+G8I]F2("5S(-BMV+#9@2#8M-F(V*_8GR#8I]N,
MV88@V+G9A=F$(-F"V*?8J-F$(-F(V*?:K]BQV*\@V8;;C-BSV*HB"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`BV8C8I]F"V+G8I]F+(-BOV*?8K]F'V90@VJG8I]BQV*C8L=N,(-BHV+'8
MI]N,(-JIV*?8L=BHV+$@)7,@V*W8L-F!(-BTV8C8K]B?(-BGVXS9AB#8N=F%
MV80@V8+8I]BHV80@V8C8I]JOV+'8KR#9AMN,V+/8JB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(MBGV8;8K-BGV84@V*+8KMBQ
MVXS9AB#8N=F%V80@V+39A=BG(-BGV+(@V8;9B"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED
M(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*
M;7-G<W1R("+8J-BGV++8HMF(V+';C"#8N=F&V*?8M=BQ(-JOV++;C-F&VJ_8
MI]F&(-BOVXS9AMBGV87;C-JIVXPZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B
MV*C8I]BRV*+9B-BQVXP@V8;9A=BGVXP@V*_8L=JOV*?9ASHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"B,L(&9U
M>GIY"FUS9VED(")296=E>"(*;7-G<W1R("+8J-BGV++9AMBTV*?9AMN,(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`BV878L=F(V+':K]BQ(-BQV*?8J-BW
MV8?B@(S8I^*`C-N,VXPB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY
M"FUS9VED(")296QO860B"FUS9W-T<B`BV*[9B-BGV8;8K]F&(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B
MV*K9B-BVVXS8K=BGV*HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T
M"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("+:J=BGV+'8L]BGV++9
MA]BGVXP@V+'8I]F'XH",V*_9B-BQ(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X
M86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`BV*W8L-F!
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")2
M96UO=F4@0FQO8VLB"FUS9W-T<B`BV*W8L-F!(-BHV839B-JI(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B
M4F5M;W9E(&-O;'5M;B(*;7-G<W1R("+8K=BPV8$@V+/8JMF(V88B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED
M(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("+8K=BPV8$@V8+8I]F$V*@@
MV*C9AMBOVXPB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM
M<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BV*W8L-F!(-BRV8C8K"(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("+8K=BPV8$@V*_8L]BJ(.*`C-F&V8C;C-BSV8?8I]N,(-BMV8'8
MN"#8M-BOV8<@V*_8L2#8M-BGV*[9AR#9A=F(V8+8JB#:J=BGV+'8L]BGV+(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BV*W8L-F!(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(MBMV+#9@2#8I]N,V88@VJ_8L=F'(-BGV+(@V+/9AMBO
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I
M9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BV*W8L-F!(-JIV*?8L=BHV+$B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(MBM
MV+#9@2#:J=BGV+'8J-BQ.B`E<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("+8JMF"V*?8MMBG
M(-F"V*?8J-F$(-F^V*?8L]BNVJ_9B-N,VXP@V8;;C-BSV*HN(-JIV*\@V*[8
MM]BGVXP@V*C8L=JOV+'8K]BGV8;8K]F'(-BTV*_9ASHB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")297%U
M97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(MF^
MV+'9B-F&V*_9AR#8I]BQV+/8I]F$(-BTV*_9AR#9AMF%VXSB@(S8JMF(V*?9
MAMBO(-BMV8'8N"#8M-F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S
M)R#9A=F(V+'8KR#9AMN,V*?8LB#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@)7,@
MV878M-BNV+4@V8;8M-BOV8<@V*?8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B<E
M<R<@V879B-BQV*\@V8;;C-BGV+(@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(%9&
M4R#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*HB"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B<E<R<@V879B-BQV*\@V8;;C-BGV+(@V*_8L2#9
MOMN,VJG8L=BHV8;8K]N,(-F%V+38KMBU(-F&V+38K]F'(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`BV8';C-F$V*_9A]BGVXP@V879B-BQ
MV*\@V8;;C-BGV+(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B
M4F5S970B"FUS9W-T<B`BV*C8I]BRV8;8M-BGV8;;C"(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*
M;7-G<W1R("+8J-BGV++9AMBTV*?9AMN,(-BGV+/9A2#8L=F%V+(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R("+8I]BSV84@V+'9A=BR(-BNV8C8KR#8L=BG
M(-BHV*?8LMF&V+38I]F&VXP@VJG9AMN,V*\B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB
M"FUS9W-T<B`BV+'8J-BY(-BBV*[8L2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP
M.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(MF&V*K8I]N,V*PB"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@
M(MBHV*?8LMJOV+38JB#8J-F'(-JOV++;C-F&V8?B@(S9A]BG(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W
M('!A<W-W;W)D(@IM<V=S='(@(MBJV*?;C-F^(-BOV8C8J-BGV+'9AR#8I]BS
MV84@V+'9A=BR("#8K-BOVXS8KR`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M975N:6]N(@IM<V=S='(@(MJOV+'8K]F'V878I]N,VXPB"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(MBH
MV*?8LMJOV+'8K]BGV8;8K]F&(-F^VXS:J=BQV*C9AMBOVXPB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,R"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`BVJ_8LMN,V8;9A^*`C-F'V*?;C"#9B-N,V+'8
MI]N,V+3:K]BQ(-F%V*K9AB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("+9A=BYV878I]F'V*<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*
M;7-G:60@(E)I9VAT(@IM<V=S='(@(MBQV*?8L]BJ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S
M='(@(MBSV+'8HMF%V*\@V+'8I]BSV*HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`BV879
M@MBGV*_;C-BQ(-BQV*?8L]BJ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V+/8M]BQ+BXN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM
M<V=I9"`B4F]L92(*;7-G<W1R("+9AMF"V+0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS
M9W-T<B`BVH;8L=BNV+0@V[';N-NP(-BOV+'8K-F'(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E
M($QE9G0B"FUS9W-T<B`BVH;8L=BNV+0@V*C9AR#:AMF^(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T
M871E(%)I9VAT(@IM<V=S='(@(MJ&V+'8KMBT(-BHV8<@V+'8I]BSV*HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,
MV*?8JB#8L]BWV+$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R("+8KMBUV8C8M=N,V*?8JB#8L]BWV+$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS
M9W-T<B`BV+/8M]BQV8?8ISHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R
M("+9@MF(V*?8N=BO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("+9@MF(V*?8
MN=BO(-BHVXS9AB#8JMF%V*?9A2#8L]BWV+'9A]BG(-F((-BSV*K9B-F&V8?8
MIR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8KR#8M-BO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T
M<B`BV8+9B-BGV+G8KR#9@=F"V+<@V*C;C-F&(-BJV878I]F%(-BSV*K9B-F&
MV8?8IR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8KR#8M-BO(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I
M9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T
M<B`BV8+9B-BGV+G8KR#9@=F"V+<@V*C;C-F&(-BJV878I]F%(-BSV+?8L=F'
MV*<@V8;9A=BGVXS8I]F&(-BNV8C8I]F'V*\@V+38KR(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("+8I]BLV+'8IR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(")2=V%N9&$B
M"FUS9W-T<B`BV*[9B-BGV8;8K]F&(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S
M86=E(@IM<V=S='(@(MF^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@(-BTV*_9
MA]F4(%,O34E-12`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(MBJV+78K]N,V8(@V8?9B-N,V9'8JB!305-,(-F"V*?8
MJ-F$(-BOV+/8JMBQV+/;C"#9AMN,V+/8JB(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B
MV;[;C-BZV*?9A2!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G
M:60@(E-13"!3:&5L;"(*;7-G<W1R("+9OMF(V+/8JMF'(%-13"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE
M;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BV879
MB-F!V9'9@MN,V9'8JB(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]1
M3"!3:&5L;"(*;7-G<W1R("+9OMF(V+/8JMF'(%-13"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM
M<V=S='(@(MBTV8;8J-F'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@
M2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PHC+"!F
M=7IZ>0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`BV*C8I]BQV*?9AB#8
MK]N,V+'9A]F&VJ_8I]F%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@
M4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`BV8?9
MA=BGV88@VH;8I]BQVH;9B-BH("C8KMF(V*_8M"DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"B,L(&9U>GIY"FUS9VED(")386UO82(*;7-G<W1R("+9A]BQV++9AMBGV879
MAR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-A;B!-87)I;F\B
M"FUS9W-T<B`BV*W8I]BTVXS9AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A
M;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")3871E;&QI
M=&4@4')O=FED97(B"FUS9W-T<B`BV8C8MMBYVXS8JB#8K=F(V++9A^*`C-F'
MV*<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED
M(")3879E(@IM<V=S='(@(MBMV8'8N"#:J=BQV*_9AB(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(MBMV8'8N"#:
MJ=BQV*_9AB`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B
MV*W9@=BX(-JIV+'8K]F&("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(MBMV8'8N"#:K]BR
MVXS9AMF'XH",V8?8IR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*
M;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C
M=&]R>2XB"FUS9W-T<B`BV;[;C-JIV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BT
MV*_9AR#8J-BYV8;9B-BGV88@V*_8L]BJ(.*`C-F&V8C;C-BS(%!(4"#8K]BQ
M(-BTV*?8KMF'V90@V879B-F"V*H@VJG8I]BQV+/8I]BR(-BTV878IR#8K=F!
MV+@@V+39B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BV;[;C-JIV+'8J-F&V*_;C"`E<R#8K=F!V+@@V+38KR(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@7"(E<UPB+B(*;7-G<W1R("+8K]BSV*H@XH",V8;9B-N,V+,@V*C8
ML=F(V++8L=BSV*?9AMN,(-BQV*?9A^*`C-BGV8;8K]BGV++;C"#8K=F!V+@@
MV+38KR#8K]BQ(#HG)7,G("XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M
M4W1O<FUS(@IM<V=S='(@(E0M4W1O<FUS(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(MBYV839A2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B
MV*S8L]BJXH",V8C8K-F((@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`BV*S9B-N,V+3:
MK]BQV8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G
M:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V;[8L=F(
MV8;8K]F'XH",V8?8IR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-N,VJD@V*K8I]BQVXS8KB(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A
M9&0B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@VJ_8L=F(V8<@V*C8L=BG
MVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M("+8I]F&V*K8KMBGV*@@VXS:J2#9A=BGV83:J2#8K-BOVXS8KR(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@
M<V5R=F5R(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#;C-JI(-JIV*?8L=BSV*?8
MLB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")3
M96QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("+8I]F&V*K8KMBGV*@@VXS:
MJ2#:J=BGV+'8J-BQ(-BHV+'8I]N,(-BGV+;8I]F!V8<@VJG8L=BOV88B"@HC
M(",M(RTC+2,M(R`@9F%?25(N<&\@*%1U<F)A(#$N,BXR*2`@(RTC+2,M(RTC
M"B,@;7-G:60@(E-E87)C:"!297-U;'1S(@HC(&US9W-T<B`BV8;8JMBGVXS8
MK"#8K-BSV*K8K-F((@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(MBGV8;8
MJMBNV*?8J"#9A]F%V8<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T
M<B`BV*?9AMBJV*[8I]BH(-BJV878I]F%(-F%V*39A-F!V8?B@(S9A]BGVXP@
MV*K8I]BQVXS8KB(*"B,@(RTC+2,M(RTC("!F85])4BYP;R`H5'5R8F$@,2XR
M+C(I("`C+2,M(RTC+2,*(R!M<V=I9"`B4V5A<F-H(%)E<W5L=',B"B,@;7-G
M<W1R("+9AMBJV*?;C-BL(-BLV+/8JMBLV8@B"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O
M8FIE8W0B"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-N,VJD@V+38IB(*"B,@(RTC
M+2,M(RTC("!F85])4BYP;R`H5'5R8F$@,2XR+C(I("`C+2,M(RTC+2,*(R!M
M<V=I9"`B4V5A<F-H(%)E<W5L=',B"B,@;7-G<W1R("+9AMBJV*?;C-BL(-BL
MV+/8JMBLV8@B"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S@*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(MBGV8;8JMBN
MV*?8J"#9A]N,VH;B@(S:J=BOV*?9A2(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@
M(B(*(MF&V8C;C-BSV8?B@(S9A]BGVXS;C"#:J=F'(-F$V*?8LMF%(-BOV*?8
ML=N,V*\@V+'8IR#8I]BR(-BLV+G8J-F'(-BRVXS8L2#8I]F&V*K8KMBGV*@@
MVJG9AMN,V*\N(-BSV;[8LR#8M-F%V*<@V87;C.*`C-BJV8C8I]F&VXS8KR#8
MI]BR(-BBV8;9A]BG("(*(MBOV+$@V879AMBWV8+9AR#9A=BJV88@V8;8L]BN
MV8?B@(S8J-BQV*_8I]BQVXP@VJG8L=BOV8<@V8@@V*_8L2#9A=BMV80@V*_;
MC-JOV+$@V*C:AMBSV*C8I]F&VXS8KR(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R("+8I]F&V*K8KMBGV*@@V878K=BOV8C8K]F'(-BJV*?8L=N,V*XZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C
M="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9@MBG
MV838J"#8JMBGV+';C-BN.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8?9B-N,
MV9'8JMN,(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8JMBZVXS;C-BQ(-BO
MV8?;C-BO.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("+8I]F&V*K8
MKMBGV*@@V878K=BOV8C8K]F'V90@V++9A=BGV88Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M
M870Z(@IM<V=S='(@(MBGV8;8JMBNV*?8J"#9@MBGV838J"#8LMF%V*?9ACHB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`BV*?9AMBJV*[8I]BH
M(-BOV8@@V8';C-F$V*\@V879AMBWV*C9@B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB
M"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-BWV+'8K2#8L=F&VJ\@V+39A=BG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@
MV++8J-BGV88@V879B-BQV*\@V8;8N-BQ(-BTV878ISHB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R("+8I]BQV+/8I]F$(-JOV++8I]BQV+0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I
M9"`B4V5N9"!335,B"FUS9W-T<B`BV*?8L=BSV*?9A"!335,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("+8K=BS
MVJ_8L3H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+8L]F^V*K8I]F%V*C8
ML2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS
M9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA
M;"!.=6UB97(B"FUS9W-T<B`BV*?8N=BOV*?8KR#8JMBQV*K;C-BHVXPB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS
M9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("+8J-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8
ML]BJ(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED
M(")397-S:6]N($%D;6EN(@IM<V=S='(@(MBSV+'9OMBQV+/8JMN,(-F%V*S9
MB-BRV8?8IR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R("))1"#9AMBTV+/8JB#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*HB"@HC
M.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM
M<V=S='(@(MF%V*S9B-BRV8?8IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("+8JMF&V+C;C-F%(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T
M;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E
M<B!F;W)G970@:70N(@IM<V=S='(@(B(*(MBJV8;8N-N,V84@VJ_8LMN,V8;9
MA^*`C-F'V*<@V*C8L=BGVXP@V*?8K-BGV++9AR#8K]BGV*_9AB#8J-F'(-BT
MV878IR#8J-BQV*?;C"#8J-BGV++9AMBTV*?9AMN,(-BGV+/9A2#8L=F%V+(@
MV*C9AR#9A]F&VJ_8I]F%(-F!V+'8I]F%V8C8M-N,("(*(MBBV88@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN(@IM<V=S='(@(B(*(MBJV8;8N-N,V84@VJG8I]BQV+/8I]BRV8?8
MI]N,(-BQV*?9AR#8K]F(V+';C"#:J=F'(-BTV878IR#9A=N,XH",V*[9B-BG
MV8?;C-BO(-BGV+(@V*_8L=JOV*?9AR#8KMF(V*\@V*C9AR#8HMF&(-BOV+/8
MJMBQV+/;C"#8K]BGV+38JMF'("(*(MBHV*?8M-N,V*\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B
MV*?9AMBJV*[8I]BH(-BRV*C8I]F&(-F%V8C8L=BO(-F&V+C8L=B,(-BSV*?8
MN=BJ(-F((-JOV++;C-F&V8?B@(S9A]BGVXP@V*K8I]BQVXS8KB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(MBG
MV8;8JMBNV*?8J"#8J-BQV8;8I]F%V8<@V++9A=BGV88@V+38L=F(V+G8C"#8
MM]BQV*T@V+'9AMJOV(P@V*C8I]BRV*+9B-BQVXP@V+79@=BMV8<@V8@@V*C9
M@MN,V8<@VJ_8LMN,V8;9A^*`C-F'V*?;C"#9AMF%V*?;C-BT(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B
MV+'8I]F')B-X,C`P8SO8I]F&V*_8I]BRVXPB"@HC(",M(RTC+2,M(R`@8V]M
M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("+8K]BSV*H@XH",V8;9
MB-N,V+,@(-BHV+'9B-BRV+'8L]BGV8;;C"#8L=BGV8?B@(S8I]F&V*_8I]BR
MVXP@V*_8L2#8K]BSV*K8L=BS(-BGV+/8JB(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(MJ&V8;8K]N,
MV88@V879B-F"V+G;C-F1V*H@V*C8IR#9OMBGV+'8I]F%V*K8L2#9A=F%VJG9
MAB#8I]BSV*HZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS
M9VED(")3:&]P<&EN9R(*;7-G<W1R("+8KMBQVXS8KR(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y
M(@IM<V=S='(@(MBNV838I]BUV8<@VJG9B-BJV*?9AR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("+8HMN,V*<@VJG9
MA-N,V*_9A]BGVXP@V*_8L]BJV+'8L]N,(-BHV*?;C-BO(-BHV+'8I]N,(-BH
MVXS8M-BJV+$@V;[;C-F(V8;8K]F'V*<@V*K8N=BQVXS9@2#8M-F(V8;8K]B?
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G
M:60@(E-H;W<B"FUS9W-T<B`BV8;9A=BGVXS8M"(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(-F&V878I]N,V+0@V*K9@=BG
MV8C8JMF'V*?;C"#9A=N,V*?9AB#9OMN,VJG8L=BHV8;8K]N,(-BMV8'8N"#8
MM-BOV8<@V8'8N=F$VXP@V8@@V*K9B-F$VXS8KR#8M-BOV8<@V*S8K]N,V*\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(MBBVXS8
MIR#8LMF%V*?9AB#8HMBNV+';C-F&(-F(V+'9B-BO(-BHV8<@V8?9AMJOV*?9
MA2#9B-BQV8C8KR#9AMBTV*?9AB#8K]BGV*_9AR#8M-F(V*_8GR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N
M('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`BV8;9A=BGVXS8M"#:K]BRVXS9
MAMF'XH",V8?8IR#8J-BQV*?;C"#9AMJOV8?8K]BGV+';C"#8I]BUV80B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I
M8VME<B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V8/9AMF&V*_9AR#9AMF%V*?;
MC-BT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("+8HMN,V*<@
MV87;C-F$V8<@VJ_8LMN,V8;:K]BGV88@V+G9A=F$VXS8I]BJ(-BLV*_9B-F$
MXH",(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BOV)\B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(MBBVXS8
MIR#:K]BRVXS9AMJOV*?9AB`E<R#8L]F%V*H@V+'8I]BSV*H@V8;8M-BGV88@
MV*_8I]BOV8<@V+39B-BOV)\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BV8;9A=BGVXS8
MM"#:K]F!V*KB@(S9B-JOV8C;C"#8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A"#8
MK-BOV8C9A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`BV8;9A=BGVXS8M"#:K]F!V*K:K]F(VXP@
MV*[8M=F(V+7;C-BGV*H@V*S8K]F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("+9AMF%
MV*?;C-BT(-JOV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8JB#8L]BWV+$@V*S8
MK]F(V80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(MF&V878I]N,V+0@VJ_9@=BJVJ_9B-N,(-BN
MV+79B-BUVXS8I]BJ(-BJV+79B-N,V+$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("+9AMF%
MV*?;C-BT(-BGV+'8L]BGV80B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("+8JMJO
MV+':KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(MBQVJ_8J-BGV+$@
MV++9B-BOV8?9AMJOV*?9A2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
MV+':K]BHV*?8L2#8K]N,V+'9A]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(MBL
MV878N2#8M-BOV88B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG
M(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(MBLV878
MN2#8M-BOV88@VXS8IR#8I]F&V*K9@MBGV80@V*C9A-F(VJG9A]BGVXP@V878
MK-BGV8C8L2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(MBKV*C8JB#9AMBGV84B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B
M4VEG;F%T=7)E(@IM<V=S='(@(MBGV878MMBGV*$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L
M9V]R:71H;2(*;7-G<W1R("+8I]F$VJ_9B-BQVXS8JMF%(-BGV878MMBGV*$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`BV*?9A=BVV*?8H2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C,*;7-G:60@(E-I>F4B"FUS9W-T<B`BV*?9AMBOV*?8LMF'(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G
M:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BV+78L=F!V8;8N-BQ(-BG
MV+(@V8;:K]F'V*_8I]BQVXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R("+8J-BQV8$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B
M4VYO=R!3:&]W97(B"FUS9W-T<B`BV*K:K]BQVJ\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W
M97)S(@IM<V=S='(@(MBJVJ_8L=JO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("+8L=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B
M4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`BV+':K]BHV*?8L2#8K]N,V+'9
MA]F&VJ_8I]F%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@
M(E-N;W<@9&5P=&@Z("(*;7-G<W1R("+8N=F%V8(@V*C8L=F!.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B`B"FUS9W-T<B`BV878N=BGV*_9A"#8J-BQV8$@V*_8L2#8
MHMBH.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O
M;F=S("8@4&]E;7,B"FUS9W-T<B`BV+38N=BQV8?8IR#9B"#8HMF(V*?8LMF'
MV*<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3
M;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("+8I]F&V*K8KMBGV*@@V*S9
MA]BJ(-F%V+'8JMBH(-BSV*?8LMN,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E
M(&%D9')E<W,B"FUS9W-T<B`BV*+8K]BQV+,@V+/8L=J&V+39A=F'(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A
M;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B4V]U=&@@175R;W!E86X@*$E33RTX
M.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS
M9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(MF&VXS9A2#:J=BQ
MV8<@V*S9AMF(V*C;C"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS(@IM<V=S='(@(MF!V*?8M=F$V8?9E"#8J-N,V88@V+/9A-F(V839
MA]BGVXP@V878K-BGV8C8L2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(MF!V*?8M=F$V8?9E"#8
MJ-N,V88@V878K=BJV8C8IR#9B"#9A-BHV8<@V*_8L2#8L]F$V8C9A"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(MF!V*?8M=F$V8?B@(S:K]BPV*?8L2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A
M8VEN9R(*;7-G<W1R("+9@=BGV+79A-F'(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R("+9@=BGV+79A-F'XH",VJ_8L-BGV+';
MC"#9B"#8K]BQV++:K]BPV*?8L=N,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*(RP@9G5Z>GD*
M;7-G:60@(E-P86EN(@IM<V=S='(@(MF!V*?8M=F$V8<B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`BV8?8
ML=BRV8;8I]F%V8<B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(MJIV*?8L=BG
MVJG8JMBQ(-BNV*?8M2#9B-BGV+'8KR#8M-BO(@H*(R`C+2,M(RTC+2,@(&9A
M7TE2+G!O("A4=7)B82`Q+C(N,BD@(",M(RTC+2,M(PHC(&US9VED(")396%R
M8V@@4F5S=6QT<R(*(R!M<V=S='(@(MF&V*K8I]N,V*P@V*S8L]BJV*S9B"(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("+8JMF"V+/;C-F%(-BS
MV839B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(MBJ
MV8+8L]N,V84@V+/8JMF(V88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`BV*K9@MBSVXS9A2#8L]BWV+$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("+9B-BQV++8M-N,(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"B,L(&9U>GIY"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T
M<B`BV*S9A=BY(-BTV*_9AB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R("+8I]BSV*K8I]F&V*_8I]BQV*\B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("+8L]BJ
MV*?8L=F'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM
M<V=S='(@(MBSV*?9A"#8M-BQV8C8N2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*
M;7-G<W1R("+9B-BVV+G;C-BJ(-BMV8C8LMF'XH",V8?8IR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`BV8C8MMBYVXS8JN*`C"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(MF"
MV*?9A-BH(-BPV*[;C-BQV8<@V+/8I]BRVXPB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D9')E<W,B
M"FUS9W-T<B`BV*+8K]BQV+,@V*[;C-BGV*C8I]F&(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME
M=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("+9@=F'V+'8L]BJ
M(-BQV+38JMF'(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM
M<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`BV+3;C-F(V8<@
M6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("+;C-JIV+39AMBHV8<B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(@V++;C-BQV+38I]BNV8<@)R5S)R#9OMN,V*_8IR#9AMBTV*\N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I
M9"`B4W5B:F5C="(*;7-G<W1R("+8N=F&V8C8I]F&(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(MBGV+'8L]BGV80B
M"@HC.B!S:6=N=7`N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(MBJV8+8I]BVV*?;
MC"#8I]BVV*?9@=F'(-BTV*_9AB`G)7,G(-BHV8<@V+/8I]F%V*?9AMF'(-BG
MV+'8I]BFV8<@V+38KRX@V*K8IR#9A]F&VJ_8I]F%VXP@VJG9AR#8JMF"V*?8
MMMBGVXP@V+39A=BG(-BJV*/;C-N,V*\@(@HBV8;:K]BQV*_8KR#9AMF%VXSB
M@(S8JMF(V*?9AMN,V*\@V*C9AR#8L]BGV878I]F&V8<@V8C8I]BQV*\@V+39
MB-N,V*\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BV++;C-BQV8;9B-N,
MV+,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BV879B-F!V9'9@MN,V9'8JB(*
M"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M
M(RTC"B,@"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S
M>7-T96TN(@IM<V=S='(@(B<E<R<@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BH
MV8<@V+/8I]F%V*?9AMF'(-BGV+;8I]F!V8<@V+38KR(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R("(@V*_8I]BOV8?9E"#:J=BGV+'8J-BQ
M("<E<R?8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*?8LB#8L]BGV878I]F&V8<@
MV;[8I]JI(-BTV*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R
M9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BMV+#9@2#8M-BO(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M+B(*;7-G<W1R("(G)7,G(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8I]BR(-BS
MV*?9A=BGV8;9AR#9OMBGVJD@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@
M(B(*(MF^VXS:J=BQV*C9AMBOVXP@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BH
MV*?8LMJOV+'8K]BGV8;8K]F'(-BTV*\N(-BHV+'8I]N,(-F%V+38I]F'V*_9
MAR#8JMBZVXS;C-BQV*?8JB#9A=BLV*_8K]BGV9(@V*+9AMBQV*<@V*C8I]BQ
M(-F&V878I]N,VXS8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(
M;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+9
MOMN,VJG8L=BHV8;8K]N,(-F^V+38JMN,V*C8I]F&(-BHV*<@V879B-F!V9'9
M@MN,V9'8JB#8K=F!V+@@V+38KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("+9OMBQV8C9AMBOV8<@V;[8M-BJVXS8J-BGV88@V;[;C-JIV+'8J-F&
MV*_;C"`E<R#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*W9@=BX(-BTV*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R
M("(G)7,G(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-F'(-BQV8C8LB#8M-BO
M(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M
M(RTC+2,*(R`*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S(-BHV*<@V879B-F!V9'9@MN,
MV9'8JB#9AMF(V+38JMF'(-BTV*\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY
M"FUS9VED(")3=61A;B(*;7-G<W1R("+8HMF!V*K8I]BHVXPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS
M9VED(")3=6UM87)Y(@IM<V=S='(@(MBNV838I]BUV8<B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(MBW
MV839B-BY(-BBV8'8JMBGV*@B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`BV+K8L=F(V*@@V*+9@=BJV*?8
MJ"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y
M"FUS9VED(")3=6YN>2(*;7-G<W1R("+8HMF!V*K8I]BHVXPB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM
M<V=S='(@(MBWV839B-BY(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E
M="(*;7-G<W1R("+8M]F$V8C8N2_8NMBQV8C8J"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R
M("+8M]F$V8C8N3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(MBZV+'9B-BH(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`BV+K8L=F(V*@Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(MBHV*?9A-BGV8;9B-N,V+,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(MF^V+38JMN,V*C8
MI]F&VXPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M
M92(*;7-G<W1R("+9AMBGV84@V*[8I]F&V8C8I]BOVJ_;C"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")3=7)N86UE
M(@IM<V=S='(@(MF&V*?9A2#8KMBGV8;9B-BGV*_:K]N,(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN
M8R!L;V<@9&5L971E9"(*;7-G<W1R("+8K=BPV8$@V8;8M-F(V*\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS
M9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(MBN
MV+?8I]N,(-F&V*W9B-N,(-BOV+$@V879B-BGV+'8KR#8K-BSV*K8K-F((@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B5"U3=&]R;7,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM
M<V=S='(@(E0M4W1O<FUS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY
M(@IM<V=S='(@(MBQVJ_8J-BGV+$@V++9B-BOV8?9AMJOV*?9A2(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE
M(@IM<V=S='(@(MF^V+'9B-F&V*_9AR!44U8B"@HC.B!F<F%M97=O<FLO54DO
M54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BV*S8K]F(
MV80B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(MBN
MV+79B-BUVXS8I]BJ(-BLV*_9B-F$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@
M4V5T(@IM<V=S='(@(MBLV*_9B-F$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O
M<&5R=&EE<R(*;7-G<W1R("+8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R("+8J-BGV+'8I]F&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS
M9W-T<B`BV8?8K]F!.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS
M9W-T<B`BV8C8N-BGVXS9@2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(MBTV878I]BQV8<@V*K9A-F!V88B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`BV*_9
MA=BGVXP@V+/8I]BYV*H@V*?8KMN,V+$Z("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("+8K]BQV*S9
MAR#8K=BQV*?8L=BJ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R,PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("+8K]BQV*S9AR#8
MK=BQV*?8L=BJ.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B`H)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<R#8K]F%V*<B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(-BGV83:
MK]F(VXP@)R5S)]F^VXS8K]BG(-F&V+38KR(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("+8I]F$VJ_9B-N,(-BSV+'9OMBQV+/8JMN,(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,V"FUS9VED(")497AT(@IM<V=S='(@(MF%V*K9AB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("+9
M@=F"V+<@V878JMF&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M("+8JMBQV*?8LB#9A=BJV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(MBH
MV*?9A-BGVXP@V878JMF&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`BV;[9AMBLV+39
MAMBHV8<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:2`H5$E3+38R,"DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`BV*?8LB#8M-F%V*<@V*C9AR#8KMBG
MV+?8L2#8I]BSV*K9@=BGV*_9AR#8I]BR(-BSV*?9A=BGV8;9AR#9A=BJV+3:
MJ=BQVXS9A2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("+8J-BSV+<@1E10(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE
M(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G
M:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM
M<V=S='(@(MF^V+'9B-F&V*_9AR#8I]BQV+/8I]F$(-BTV*_9AR#9AMF%VXSB
M@(S8JMF(V*?9AMBO(-BMV8'8N"#8M-F(V*\B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`BV8;:K]F'V*_8
MI]BQVXPZ.B#:J=F$V*?8LR#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C8I]BQ
M(-F&V+38KR(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z
M,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+B(*;7-G<W1R("+9OMF&V*S8L=F'V90@VJ_8LMN,V8;9A^*`C-F'V*<@
MV*C8L]BJV8<@V+38KRX@V*[8L=F(V*PB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B+8
ML]BQV;[8L=BSV*H@V*C8I]N,V*\@VXS:J2#9OMBTV*K;C-BHV*?9AB#9A=BL
MV8C8LMF'V*<@V+'8I]B,("#8K]BQ(-BUV8C8L=BJ(-BJV878I]N,V80@V+39
MA=BG(-BHV8<@V*?8L]BJV8'8I]BOV8<@V*?8LB#9A=BLV8C8LMF'V*?8C"`B
M"B+9OMN,VJG8L=BHV8;8K]N,(-JIV8;8KRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@
M8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%V*H@V;[8
MI]N,VXS9AB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(MBTV878I]BQV8<@240@
MV*K9A=BGV+,@V878M-BNV+4@V8;8M-BOV8<@V*?8L]BJV(P@V*?;C-F&(-BT
MV878I]BQV8<@V*_8L2#8K]BGV*_:K]BGV88@VXS8I]F!V*H@V8;8M-BO(@H*
M(R`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("+8JMF%V*?8LR`@)7,@V*C8
MIR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@VJG8JMBGV*C:AMF'(-BBV*_8L=BS
M(-BTV878IR#8I]BVV*?9@=F'(-BTV*\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("+;C-JI(-BHV839B-JI(-BGV878MMBG
MVXP@4$=0(-BHV+'8I]N,(-BHV*?8LMBHVXS9AMN,(-N,VJD@V;[;C-BZV*?9
MA2#8I]F%V+;8I]BA(-BTV*_9AR#9A=F(V+'8KR#9AMN,V*?8LB#8I]BSV*HB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("))1"#9@=F'V+'8L]BJ(-BJ
MV8C8LMN,V+G;C"#9A=BTV*[8M2#9AMBTV*_9AR#8I]BSV*H@V8@@VXS8IR#8
MK]BQ(-BOV*?8K]JOV*?9AB#9A=F(V*S9B-BO(-F&VXS8L]BJ(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G
M:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB
M"FUS9W-T<B`BV8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@V8;8
MM-BOV8<@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ
M,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S
M96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(MF%V+38KMBUV8?B@(SB
M@(S9A]BGVXP@V+'9A=BRV*C9AMBOVXP@V8;;C-BGV++9A=F&V*\@VXS:J2#8
MI]BQV*K8M=BGV80@V*?9A=F&(-F(V*@@V87;C.*`C-BHV*?8M-F&V*\B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(MF^
MV+'9B-F&V*_9AR`E<R#8J-BGVXS8KR#8K]BGV+'8I]N,(-BJV8;8N-N,V84@
M)7,@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V
M."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*W8
MI]F(VXP@V*K9AMBXVXS9A=BGV*H@)7,@V*C8I]BTV*\B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("+9OMBQV8C9AMBO
MV8<@V*C8L2#8L=F(VXP@V*[9B-BOV+0@V8;9A=N,XH",V*K9B-BGV8;8KR#8
ML=F(V8;9B-BTV*H@V+39B-BO(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`BV;[8L=F(V8;8K]F'(-BMV*?9B-N,(-BOV*?8K]F'XH",V*?B@(S;
MC-N,(-F&VXS8L]BJ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@HBV878KR#8JMF%V*?9A2#8M=F!V*W9AR#8
MJ-BG($E%(-F%V+3:J=F$(-BOV*?8L=BO(-F((-BGVXS9AB#8I]BR(-F%V+3:
MJ=F$V*?8JB#9A=BQV8C8L=JOV+$@V87;C.*`C-BHV*?8M-BO+B#8I]JOV+$@
MV8?9AMF(V+(@(@HBV87;C.*`C-BNV8C8I]F'VXS8KR#8K=BGV838JB#9B-N,
MV+'8I]N,V+3:K]BQ(-BJV878I]F%(-BUV8'8K=F'(-BQV*<@V*?9A=BJV*W8
MI]F&(-JIV8;;C-BOV(P@V838M]F!V*?9BR#:J=F$VXS8KR#8JMBCVXS;C-BO
M(-BQV*<@V8'8M-BGV+$@(@HBV*_9A]N,V*\@(@H*(R`*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET
M>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BV8?9B-N,V9'8
MJB!<(B5S7"(@V*W8L-F!(-BTV*_9AR#8I]BSV*HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4
M:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%
MV*H@VH;9OB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U
M-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T
M;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<
M;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S
M(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B+9OMN,V+K8
MI]F%(-F!V+'8L]BJV*?8K]F'(-BTV*_9AR#8L=F(VXP@)7,@V*C9AR`E<R#8
MJ-BG(-F%V8C8MMF(V+D@7"(E<UPB(-F&V878I]N,V+0@V*_8I]BOV8<@V+38
MK]F'(-BGV+/8JBY<;B(*(MBJV+;9A=N,V8;;C"#8J-BQV*?;C"#8KMF(V*?9
MAMBOV8<@V+38K]F&(-F((-N,V*<@V*_8L=JI(-BBV88@V8C8K-F(V*\@V8;8
MK]BGV+'8KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G
M:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O
M<V4@<&%G92(*;7-G<W1R("+9AMBGV87;C"#:J=F'(-BHV8<@V8?9AMJOV*?9
MA2#9OMN,V8C9AMBOV*_9A]N,(-BHV8<@V+79@=BMV8<@V*?;C-BLV*?8KR#9
MAMBGV879AR#8I]BSV*K9@=BGV*_9AR#9A=N,XH",V+39B-BO(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"FUS9VED(")4:&4@;G5M8F5R
M(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(MBJV+G8K]BG
MV*\@V8';C-F$V*_B@(S9A]BG(-BHV*?;C-BO(-N,VJD@V+G8K]BO(-BHV*?8
MM-BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q
M"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H
M92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@
M86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HBV*?9B-F$V8C;C-BJ(%PB)7-<
M(B#9AMF%VXSB@(S8JMF(V*?9AMBO(-BMV8'8N"#:K]BQV*_8KR#8LMN,V+'8
MIR#9A=F"V*_8I]BQ(-BOV*?8K]F'(-BBV88@V*?8LB#8K=BO(-F%V*S8I]BR
M(-BHVXS8M-BJV+$@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B+8J-BQ
MV8;8I]F%V8?B@(S8I^*`C-N,VXP@VJG9AR#8J-BQV*?;C"#9A=BTV*?9A]BO
MV8<@V*?;C-F&(-F&V8C8N2#8K]BGV*_9AR`H)7,I(-F"V*C9A-BGV8L@V879
MB-BQV*\@V*?8L]BJV8'8I]BOV8<@V8+8L=BGV+$@V87;C.*`C-JOV+'9@=BJ
MV(P@V*_8L2`B"B+8L]BGV878I]F&V8<@V879B-BLV8C8KR#9AMN,V+/8JB(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+B(*;7-G<W1R("+8K-BOV*<@VJG9AMF&V*_9AR#8J-BGVXS8
MKR#;C-JI(-F&V8C;C-BSV8<@V*C8I]BTV*\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8
ML]F%V*H@V+'8I]BSV*H@V8@@VH;9OB(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H
M="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8L]F%V*H@V+'8
MI]BSV*HB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G
M:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BXB"FUS9W-T<B`BV*S8K]BG(-JIV8;9AMBOV8<@V*C8I]N,V*\@VXS:J2#9
MAMF(VXS8L]F'(-BHV*?8M-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BVJG8I]BQV+/8
MI]BR(%PB)7-<(B#8K=BPV8$@V+38K]F'(-BGV+/8JB(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R
M("+:J=BGV+'8L]BGV+(@7"(E<UPB(-BMV8'8N"#8M-BOV8<@V*?8L]BJ(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"XB"FUS9W-T<B`BV*_8L=BNV8C8I]BSV*H@V*?9@=BJV*K8I]BM(-BMV+/8
MI]BH(-BHV+'8I]N,("5S(-BMV+#9@2#8M-BOV8<@V*?8L]BJ(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BV+'8K]N,
MV8$@V878M-BNV+4@V+38K]F'(-F(V*S9B-BO(-F&V*_8I]BQV*\B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("+9OMBQV8C9AMBOV8<@V879B-F"V*K;C"`@7"(E<UPBV879
MB-BLV8C8KR#9AMN,V+/8JB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T
M8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM
M<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B
MV*K9AMF'V*<@V+/9A=BJ(-BHV*?9A-BG(-F((-F^V*?;C-N,V88B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P
M"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("+8JMF&V8?8IR#8
ML]F%V*H@V*C8I]F$V*<B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("+8K]BGV*_9A]F4(-BGV+'8L]BG
MV80@V+38K]F'(-BGV+(@VJ_8I]F%(-F"V*C9A-N,(-BGV+(@V*_8L]BJ(-BQ
MV8'8JMF'(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H
M<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R
M("+9OMBQV8C9AMBOV8<@V*?8L=BSV*?9A"#8M-BOV8<@V8;9A=N,XH",V*K9
MB-BGV8;8KR#8K=F!V+@@V+39B-BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+8J-F$V8C:J2!W96%T
M:&5R+F-O;2#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(MBTV*?8KMF'(-BJV84@)R5S)R#;C-BGV8'8JB#9AMBTV*\B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("+:K]BRVXS9AMF'
MXH",V*?B@(SB@(S;C-N,(-BOV+$@V*_8L]BJV+'8LR#9AMN,V+/8JB(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(MBHV*[8M-N,(-JIV8<@V*C8JMF(V*?9AMBO(-BHV+'8
MKMBW(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BO(-F%V8C8K-F(V*\@V8;;
MC-BSV*HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T
M97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C
M=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R
M("(B"B+9AMF(VXS8L]F'XH",V8?8I]N,(-BRVXS8I]BOVXP@V*_8L2#8I]N,
MV88@V8';C-F$V*\@V8+8L=BGV+$@V*_8I]BQV*\N(-BTV878IR`E<R#9AMF(
MVXS8L]F'(-F(V*?8L=BO(-JIV+'8K]F'XH",V*?B@(S;C-BO(-BOV+$@V*W8
MI]F$VXP@VJG9AR`B"B+8M-F%V*<@V*C8I]N,V*\@VJG9A=BJV+$@V*?8LB`E
M<R#9AMF(VXS8L]F'(-F(V*?8L=BO(-JIV8;;C-BO(@H*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB
M('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(MF%V+3:J=F$VXP@V*_8L2#8
MI]BVV*?9@=F'(-JIV+'8K]F&("<E<R<@V*C9AR#8L]BGV878I]F&V8<@V+'8
MKB#8K]BGV*_9AR#8I]BSV*HZ("5S(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@861M:6XO=7-E<BYP
M:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(MF%V+3:J=F$VXP@V*_8L2#9OMBGVJD@
MVJG8L=BOV88@V*_8I]BOV8?9E"#:J=BGV+'8J-BQ("<E<R<@V*?8LB#8L]BG
MV878I]F&V8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`BV878M-JIV83;C"#8K]BQ(-BMV+#9@2`G)7,G
M(-BGV+(@V+/8I]F%V*?9AMF'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ.B`B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB
M.B`E<R(*;7-G<W1R("+9A=BTVJG9A-N,(-BOV+$@V*C8L=F(V++8L=BSV*?9
MAMN,("<E<R<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`BV878M-JIV83;C"#8K]BQ
M(-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-BQV*X@V*_8I]BOV8<@V*?8L]BJ
M.B`E<R#8I]BQV+/8I]F$(-F&V+38KR(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R
M+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@
M=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H
M)60@8GET97,I+B(*;7-G<W1R("(B"B+9A=BTVJG9A-N,(-BOV+$@V*?8L=BS
MV*?9A"#9OMBQV8C9AMBOV8<@V+'8KB#8K]BGV*_9AR#8I]BSV*HZ(-BGV8;8
MK]BGV++9AR`E<R#8J-N,V+38JMBQ(-BGV+(@V*W8KR#9A=BLV*?8LB#8J-F(
MV*_9AR#8I]BSV*H@*"`E9"`B"B+8J-BGVXS8JBDN(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@
M(B(*(MF%V+3:J=F$VXP@V*_8L2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#9
MB-BLV8C8KR#8K]BGV+38JMF'(-BGV+/8JCH@("5S(-BHV8<@V+79B-BQV*H@
MV*K:J=F'XH",V*?B@(S;C-N,(-BGV+'8L]BGV80@V+38K]F'(-BGV+/8JB`B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R("+8KMBWV*?;C-N,(-BOV+$@V8;9A=BGVXS8
MM"#8I]N,V88@V*C8KMBT(-F^VXS8NMBGV84@V+'8KB#8K]BGV*_9AR#8I]BS
MV*HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT
M86-T(&1A=&$N(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`
MC-BHV+'8KR#:J=BQV*_9AB#8K]BGV*_9AR#8JMF%V*?8LR#8L=BN(-BOV*?8
MK]F'(-BGV+/8JB(*"B,@"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H
M<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(MBNV+?8I]N,VXP@V*_8L2#8K]BQ
MV8C9AN*`C-BHV+'8KR#:J=BQV*_9AB#8K]BGV*_9A]F4(-BJV8+9B-N,V84@
MV+'8KB#8K]BGV*_9AR#8I]BSV*HB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R
M97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HBV*[8M]BGVXS;C"#8K]BQ(-F^
MVXS:J=BQV*C9AMBOVXP@V8'8L=F%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#8
MM-BGVXS8KR#9@=N,V838KR#9A=F(V+'8KR#9AMN,V*?8LMN,(-BQV*<@V*S8
MIR#8I]F&V*_8I]BNV*K9A^*`C-BGXH",VXS8KR(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D
M9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E
M<BXB"FUS9W-T<B`B(@HBV*[8M]BGVXS;C"#8K]BQ(-BGV*S8L=BG(-JIV+'8
MK]F&(-BYV879A-N,V*?8JB#9A=BTV*[8M2#8M-BOV8?9E"#:J=BJV*?8J-J&
MV8<@V*+8K]BQV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@
MV*_9B-BHV*?8L=F'(-BSV+G;C"`B"B+:J=F&VXS8KR(*"B,@"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BV*[8
MM]BGVXS;C"#8K]BQ(-BHV+'9B-BRV+'8L]BGV8;;C"#8K-BRV*;;C-BGV*H@
MV*K9A=BGV+,@V+'8KB#8K]BGV*_9AR#8I]BSV*HN(-F$V+?9@=BGV8L@V*_9
MB-BHV*?8L=F'(-BSV+G;C"#:J=F&VXS8KR(*"B,@"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("+8KMBWV*?;C-N,
M(-BOV+$@V*C8L=F(V++8L=BSV*?9AMN,(-F!V8?8L=BSV*H@V*K9B-BRVXS8
MN=N,(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BG
MV+'9AR#8L]BYVXP@VJG9AMN,V*\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B#:
MJ=BGV+'8L]BGV+(@24U!4-F^V8C8M-F'XH",V8?8I]N,(-F%V+38JMBQVJD@
MV+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8KR(*"B,@"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N(@IM<V=S='(@(B#8J-F'(-F&V+C8L2#9AMF%VXSB@(S8L=BSV*\@VJG9
MAR#8HMBQV+3;C-F((')A<B#9A=BYV*K8J-BQVXP@V*C8I]BTV*\B"@HC(`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+B(*;7-G<W1R("(@V*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@
MV;[8L=F(V8;8K]F'('II<"#9A=BYV*K8J-BQVXP@V*C8I]BTV*\B"@HC(`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O
M97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T
M<B`BV*C9AR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V+39A=BGV+'9
MAR#:J=BGV+'8JB#9A=BYV*K8J-BQVXP@V*C8I]BTV*\B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`BV*?;C-F&(-F!VXS9
MA-BO(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8JB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`BV*?;C-F&(-F!VXS9A-BO(-F%
MV87:J=F&(-BGV+/8JB#8M-BGV879A"#8I]BYV*_8I]BO(-BUV*W;C-BM(-BH
MV*?8M-BO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BXB"FUS9W-T<B`BV*?;C-F&(-F!VXS9A-BO(-F%V87:J=F&(-BG
MV+/8JB#8M-BGV879A"#8I]BYV*_8I]BO(-F((-F(VXS8L=JOV8C9A"#8J-BG
MV+38KR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@
M(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM
M<V=S='(@(MBGVXS9AB#9@=N,V838KR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%
MV80@V879@MBGV*_;C-BQ(-F'V+38JB#9A]BTV*K;C"#8J-BGV+38KR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*(MBGVXS9AB#9@=N,V838KR#8J-BGVXS8
MKR#8K=BGV8C;C"#:J=BGV878IR#9B"#;C-BG(-F!V8?8L=BSV*K;C"#8I]BR
M(-BGV+G8K]BGV*\@V+78K=N,V*T@V*S8K]BG(-BTV*_9AR#8J-BG(-F&V8C;
MC-BSV8<@V*[8I]F$VXP@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED
M(&YU;6)E<BXB"FUS9W-T<B`BV*?;C-F&(-F!VXS9A-BO(-BHV*?;C-BO(-N,
MVJD@V+G8K]BO(-F%V+G8JMBHV+$@V*C8I]BTV*\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@
M8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F
M;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC(",M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!T
M96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&ES("5S+B(*;7-G<W1R("+8I]N,V88@)7,@V87;C.*`C-BHV*?8
MM-BO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O
M8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E
M;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O
M=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L
M:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HBV*?;
MC-F&(-F^VXS8NMBGV84@V*C8IR#9A=BLV879B-BYV8<@VJG8I]BQV*?:J=BJ
MV+$@)7,@V8;9B-BTV*K9AR#8M-BOV8<@V*?8L]BJ(-JIV8<@V*C8IR#9A=BL
MV879B-BYV8<@VJG8I]BQV*?:J=BJV+$@V+39A=BG(-F%V*K9@=BGV8C8JB`B
M"B+8I]BSV*HB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM
M<V=S='(@(MBGVXS9AB#8N=BOV*\@V*W8K]BGV8+9A"#8J-BGVXS8KR#;C-JI
M(-BHV*?8M-BO(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z
M:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`BV*?;C-F&(-JIV*?8L=BS
MV*?8LB#9OMBQV8C9AMBOV8?B@(S9A]BGVXP@>FEP(-F((&=Z:7`@V+'8IR#8
MJ-BGV+(@V8;9A=N,XH",VJG9AMBO(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`BV*?;C-F&(-BSV*?9A=BG
MV8;9AR#8K]BQ(-BMV*?9A"#8K=BGV+;8L2#8NMN,V+$@V8'8N=BGV80@V*?8
ML]BJ(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G
M:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`BV*?;
MC-F&(-F%V8+8K]BGV+$@V*C8I]N,V*\@V+G8K]BO(-BHV*?8M-BO(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=R(*;7-G<W1R("+8I]N,V88@V;[9AMBLV+'9AR#8J-BGVXS8KR#8I]BR(-F^
MV8;8K-BQV8?9E"#:K]BRVXS9AMF'XH",XH",V8?8IR#9@=BQV*?8KMF(V*?9
MAMN,(-BTV8C8KR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(MBQV+G8KR(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B
M"FUS9W-T<B`BV*C9A-N,V+?9A]BG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(E1I;64B"FUS9W-T<B`BV++9A=BGV88B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@
M(MBQV*_;C-BGV*C;C"#8LMF%V*?9AB(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`BV8+8I]F$V*@@V++9
MA=BGV88B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED
M(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(@V*?9AMBJV*[8I]BH(-BRV878
MI]F&("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM
M<V=S='(@(MBYV8;9B-BGV88B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM
M<V=S='(@(MBYV8;9B-BGV88@*-BQV*?9A]F&V878I]N,(-BBV8;;C"DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`BV*C9AR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*(MBHV+'8I]N,(-BGV8;8JMBNV*?8J"#:AMF&V*\@V8';C-F$V*_8C"#8
MK]JIV879AR!#=')L(-BQV8C;C"`H4$,I(-N,V*<@0V]M;6%N9"#8L=F(VXP@
M*$UA8RD@V+'8IR#8K]BQ(-F%V*_8JB#:J=F$VXS:J2`B"B+:J=BQV*_9AB#9
MAMJOV8?8K]BGV+';C-BO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`BV*?9A=BQV8C8LB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G
M:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"B,L(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S='(@(MBHV8<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(MF!V+'8K]BG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I
M9"`B5&]N9V$B"FUS9W-T<B`BV*?9A=BQV8C8LB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P
M(@IM<V=S='(@(MBHV*?9A-BG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*
M;7-G<W1R("+:AMBGV+':AMF(V*@@V*C8I]F$V*<@*-BHV*?9A-BG*2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(MBJV+'8K-F%V8?B@(S9A]BG(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(MBOV+'8L]BJ(-F((-N,V*<@V8;8I]BOV+'8L]BJ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I
M9"`B5'4B"FUS9W-T<B`BV+/9AR#8M-F&V*C9AR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)K
M:7-H("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM
M96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("+8I]F&V*K8KMBGV*@@V*[9B-BO(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B
M52Y6+B!I;F1E>#H@(@IM<V=S='(@(MBTV*?8KMBU(%4N5BX@.B`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R("+8
MLMN,V+'8KMBWXH",V*_8I]BQ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(MBGV87:J=BGV88@V*_8L]BJV+'8L]N,(-BHV8<@V+38
MI]BNV8<@5D93(-F&VXS8L]BJ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@
M:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("+8I]F%VJG8
MI]F&(-BGV+;8I]F!V8<@VJG8L=BOV88@V*?8M]F$V*?8N=BGV*H@V*?8MMBG
MV8';C"#:J=BGV+'8J-BQ(-BHV8<@V8?9AMJOV*?9A2#8J]BHV*H@V8;8I]F%
M(-F&VXS8L]BJ(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(MF&V87;
MC.*`C-BJV8C8I]F&(-F%V*S9B-BRV8?8IR#8L=BG(-BHV+'8I]N,(-F^V+'9
MB-F&V*_9AR!<(B5S7"(@V*K8NMN,VXS8L2#8K]BGV*\B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9
MOMBQV8C9AMBOV8<@)7,O)7,@5D93("#8JMBZVXS;C-BQ(-BOV*?8KR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(-BOV+$@)7,@V*K8NMN,VXS8L2#8K]BGV*\B
M"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC
M+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^
MV+'9B-F&V*_9AR!61E,@7"(E<UPB(-BQV*<@V*C8I]BR(-F&V879B-BO(@H*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC
M+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`E<R\E
M<R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-BHV8<@VJG8I]BQV+/8I]BR(%-13-F%V*K8M=F$(-BTV*\B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BH
MV*<@4U-,(-F%V*K8M=F$(-BTV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*?8LB#9OMBQV8C9
MAMBOV8<@5D93(-BQV8C9AMF(V+38JB#8JMF'VXS9AR#9AMF%V8C8KR(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R!<(B5S
M7"(@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8I]N,V*S8
MI]BO(-F&V879B-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO
M<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB
M"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8
ML=BG(-BGVXS8K-BGV*\@V8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R!<(B5S7"(@V+'8IR#8
MJMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&
MV*_9AR#8KMBGV83;C"!61E,@(-BGVXS8K-BGV*\@V8;9A=F(V*\B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(MF&V87;C.*`C-BJ
MV8C8I]F&(-BOV*?8K]F'(-BQV*<@V*C8I]BR(-JIV+'8KR`B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S
M='(@(MBMV+#9@2!<(B5S7"(@V879A=JIV88@V8;;C-BSV*K8C"#8M-BGV*[9
MAR#8KMBGV83;C"#9AMN,V+/8JB(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@
M(MF&V87;C.*`C-BJV8C8I]F&(%PB)7-<(B#8L=BG(-BMV+#9@2#:J=BQV*\Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`BV*W8L-F!
M("5S(-F%V87:J=F&(-F&VXS8L]BJV(P@V+38I]BNV8<@V*[8I]F$VXP@V8;;
MC-BSV*HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS
M9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*C9
MAR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9A=F(V*\B"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8K=BPV8$@V8;9
MA=F(V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8
MK=BPV8$@V8;9A=F(V*\Z("5S+B(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG(-BMV+#9@2#9
MAMF%V8C8KR(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S
M*2`@(RTC+2,M(RTC"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&
M(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8K=BPV8$@V8;9A=F(V*\B"@HC(",M
M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC
M(`HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R
M(%PB)7-<(BXB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8
MK]F'(%9&4R!<(B5S7"(@V+'8IR#8K=BPV8$@V8;9A=F(V*\B"@HC(",M(RTC
M+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M(@IM<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(%9&4R#8L=BG(-BHV8<@V+79
MB-BQV*H@V*K9B"#8K]BQ(-BJV8@@V*W8L-F!(-F&V879B-BO.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B56YA8FQE
M('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`BV8;9
MA=N,XH",V*K9B-BGV88@V+38I]BNV8?9E"#9@=BYV83;C"#8L=BG(-BJV+38
MKMN,V+4@V*_8I]BO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V*S8LMBFVXS8
MI]BJ(-JOV8C8I]F'VXP@V+'8IR#8I]BSV*K8KMBQV*?8K"#9AMF%V8C8KR(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8JMBYV+';C-F!("5S("#8L=BG(-BH
MV*?8L2#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'
M(%9&4R#8L=BG(-BGV8;8JMF"V*?9A"#8K]BGV*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(%PB)7-<(B#8L=BG
M(-BHV*?8LB#9AMF%V8C8KR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*C8L=BG
MVXP@V8;9B-BTV*K9AB#8J-BGV+(@VJG8L=BO(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,@IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(MF&V87;C.*`
MC-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8J-BGV+(@V8;9A=F(
MV*\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BBV+'8M-N,V8@@V8'8M-BQV*_9
MAR#8L=BG(-BHV*?8LB#:J=BQV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#,U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(@V8;9A=N,XH",V*K9
MB-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@5D93(-F&V8C8M-BJ+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM
M<V=S='(@(B#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR!6
M1E,@V8;9B-BTV*HN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`BV8;9A=N,XH",V*K9B-BGV88@
MV;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8
MKR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R
M("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!V9G-R;V]T(-BQV*<@V*[9
MB-BGV8;8KR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
MV8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8J-F'("5S("#8JMBZVXS;C-BQ
M(-F&V*?9A2#8K]BGV*\Z(-F^V8C8M-F'(-F%V8+8M=BO(-BGV+(@V8+8J-F$
M(-F%V8C8K-F(V*\@V*?8L]BJ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!6
M1E,@V+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+9
MAMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@V+'8IR#8JMBZVXS;C-BQ
M(-F&V*?9A2#8K]BGV*\Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBOV8<@
M5D93(%PB)7-<(B#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KR(*"B,@
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC
M"B,@"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(MF&
MV87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@)7,O)7,@V+'8IR#8
MJMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+B(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#9OMBQV8C9AMBO
MV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`BV8;9A=N,XH",V*K9B-BGV88@)VUK:7-O9G,G(-BQV*<@V*?8K-BQV*<@
MV8;9A=F(V*\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O
M<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N="(*;7-G<W1R("+9AMF%VXSB@(S8JMF(V*?9AB#8I]N,V88@
MV+/9AMBO(%=O<F0@V+'8IR#8JMBQV*S9A=F'(-F&V879B-BO(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(-F&V87;C.*`
MC-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%PB)7-<(B!61E,@(-F&V8C8
MM-BJ(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*
M;7-G<W1R("(@V8;9A=N,XH",V*K9B-BGV88@V*_8L2#9OMBQV8C9AMBOV8<@
M5D93(-F&V8C8M-BJ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("+9AMF%VXSB@(S8
MJMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9A]F4(-BOV*?8K]F'(%9&4R#9AMF(
MV+38JB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B
M92!E>&-E961E9"XB"FUS9W-T<B`B(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@
MV;[8L=F(V8;8K]F'(%9&4R#9AMF(V+38JBXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`BV++;C-BQV*[8M^*`C-BOV*?8L2(*"B,Z('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+9
MB-BGVJ_8L=BOV*?9AMBOV88@V*K8NMN,VXS8L=BGV*HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O
M97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+9B-BGVJ_8L=BOV*?9AMBO
MV88@V*+8KMBQVXS9AB#8N=F%V80@V+39A=BG(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R
M97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B
MV;[8I]BSV*X@V+K;C-BQ(-F%V8;8JMBXV+'9AR#8I]BR(-JIV*?8L=BSV*?8
MLB#8J-BQ(-BQV8C;C"#8I]BJV+78I]F$.B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(MF^V*?8L]BN(-BZVXS8L2#9
MA=F&V*K8N-BQV8<@V*?8LB#:J=BGV+'8L]BGV+(@V*C9ASHB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I
M9"`B56YF:6QE9"(*;7-G<W1R("+8NMN,V+$@V*W9B-BRV8<B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM
M<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G
M<W1R("+9B-BGV*W8K]F'V*<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P
M"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(MBOV*?8K]F'(-F&V*?8M-F&V*?8
MKMBJV8<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US
M9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(MF'VXS:AB#9A=JI
MV*?9AMN,(-BJV8;8N-N,V84@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(MF&V*?9A2#:J=BG
MV+'8J-BQ(-F((-N,V*<@V*?8L]F%(-BQV878LB#9AMBGV+39AMBGV*[8JMF'
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R("+9@MBWV+D@V;[;C-F(V8;8KR#8N=F&V+78L2#9@=BYV83;C"(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(MBHVXP@V8;8I]F%(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP
M<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T
M92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#
M;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R
M9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O
M(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B+8K]BSV*H@XH",
MV8;9B-N,V+/9A]BGVXP@V*C8K]F(V88@V*?9A=BJVXS8I]BR(-BHV8<@V*_9
MA-N,V80@V*?9A=F&VXS8JMN,(-F&V87;C.*`C-BJV8C8I]F&V8;8KR#8I]BR
M(-BWV+';C-F"(-BHV+'9AMBGV879AR#9AMF(VXS8L]N,(-BHV+';C-BOV8<O
M(@HBV+'9B-F&V8C8M-BJ(-JOV+'9@=BJV8<OVH;8L]BHVXS8K]F'(-BTV8C9
MAMBO+B#:J=F$VXS8KR#8JMBCVXS;C-BO(-BQV*<@V8'8M-BGV+$@V*_9A]N,
MV*\@V*K8IR#9A=BJV88@V8'9AMN,XH",V*?B@(S;C-N,(-BQV*<@V*_8L2`B
M"B)M;WII;&QA+F]R9R#8J-BG(-BYV8;9B-BGV88@VH;:K]F(V8;:K]N,(-BO
MV+/8JMBQV+/;C"#;C-JI(-BOV+/8JB#B@(S9AMF(VXS8LR#8J-F'(-BJV*[8
MJMF'V90@V+'8L]F%(-BQV*<@V878M-BGV8?8K]F'(-JIV8;;C-BO(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BV+'9AMJO(-BJV8;8N-N,
MV84@V8;8M-BOV8<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B
M56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(MBHV+/8MR#8J-BOV8C9
MAB#9OMBTV*K;C-BHV*?9AMN,(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*
M;7-G:60@(E5P9&%T92(*;7-G<W1R("+8J-BQV8C8LMBQV+/8I]F&VXPB"@HC
M(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M
M(PHC(`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("+8J-BQV8C8
MLMBQV+/8I]F&VXP@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("+8J-BQV8C8
MLMBQV+/8I]F&VXP@VJG8I]BQV*C8L2(*"B,@(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@V*C8L=F(V++8L=BSV*?9AMN,
M(-BTV*\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B
M57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`BV*_8L]BJXH",(-F&
MV8C;C-BS(-BHV8?;C-F&V8?B@(S8L]BGV++;C"#8K=BPV8$@V+38KR(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@
M(MBGV+'8L]BGV80@VJG8L=BOV88B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`BV*K9A=BGV84@V;[8L=F(
MV8;8K]F'XH",XH",V8?8I]N,(-BJV8;8N-N,V84@V*C8L=F&V*?9A=F'XH",
MV8?8I]N,(-JIV*?8L=BHV+'8K]N,(-BHV8<@VJG8I]BQV+/8I]BR(-BGV+'8
ML]BGV80@V+38KR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`BV*W8L=F(V8$@V*C8LMBQVJ\@V838I]BJVXS9AB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`BV*?8
MN=BOV*?8KR#;C-F(V8;8I]F&VXP@V*C8LMBQVJ\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(@V*?8L]BJV8'8I]BO
MV8<@V8'8N=F$VXPZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B
MV*?8L]BJV8'8I]BOV8<@V*?8LB!34TPB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("+8I]JOV+$@V8;8I]F%
M+]BGV+/9A2#8L=F%V+(@V*C8L=BGVXP@VJG8I]BQV+/8I]BR($E-4U`@V878
MJMF!V*?9B-BJ(-BGV+/8JMB,(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B57-E<B(*;7-G<W1R("+:J=BGV+'8J-BQV*?9AB(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+B(*;7-G<W1R("+:J=BGV+'8J-BQ("5S("#8J-BQV*?;C"`E<R#8I]BMV+'8
MI]BR(-F'V8C;C-F1V*H@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(MBSV+'9OMBQV+/8JMN,(-JIV*?8L=BHV+$B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S
M='(@(MJOV++;C-F&V8?B@(S9A]BGVXP@VJG8I]BQV*C8L2(*"B,Z('-I9VYU
M<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(MBK
MV*C8JB#9AMBGV84@VJG8I]BQV*C8L2(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(MBKV*C8JB#:J=BGV+'8J-BQ(-BHV+'8I]N,
M(-BGVXS9AB#9OMBGVXS:K]BGV8<@V+K;C-BQ(-F!V+G8I]F$(-BTV*_9AR#8
MI]BSV*HB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(MBMV+/8I]BH(-JIV*?8
ML=BHV+$@V;[;C-BOV*<@V8;8M-BO(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BV8;8I]F%(-JIV*?8L=BHV+$B"@HC
M(`HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(MF&V*?9A2#:J=BGV+'8J-BQ("<E<R<@V*?8
MLB#9@MBHV80@V879B-BLV8C8KR#8I]BSV*HB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+9
MAMBGV84@VJG8I]BQV*C8L3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(MF&V*?9A2#:J=BG
MV+'8J-BQ.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("+:J=BGV+'8
MJ-BQV*?9AB#8L]BGV878I]F&V8<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U"FUS
M9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+8
MM-BGV*[9AR!61E,@V8C8K-F(V*\@V8;8K]BGV+'8KR(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@
M(MBJV+G8M]N,V838I]BJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM
M<V=S='(@(MF%V8C9@MBYVXS8JMF'V*?;C"#9A=BYV*K8J-BQ(-N,V*?9@=BJ
MV8<@V+38K]F'(-BYV*C8I]BQV*K9AMBO(-BGV+(Z(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM
M<V=S='(@(MBGV+G8JMBHV*?8L2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`BV879@MBOV*?8L2#8J-F'(-BO
MV8+;C-F"V8<@V*?8LB#8K=BGV838IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H
M<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N
M9W1H(&]F("5S+B(*;7-G<W1R("+9A=F"V*_8I]BQ(-BGV+(@V*C;C-BTVXS9
MAMF'(-BWV8C9A"#9A=BLV*?8LB`E<R#8J-N,V+38JMBQ(-BGV+/8JB(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM
M<V=S='(@(MF%V8+8I]BOVXS8L2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B
M5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(MF%V8+8I]BOVXS8L2#8
MJ-BQV*?;C"#8I]F&V*K8KMBGV*@@V*?8LB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`BV878JMBZ
MVXS;C-BQ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`BV8;8L]BNV8<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`BVJG9
MAMBJV+'9A"#9AMBSV*[9AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N
M(@IM<V=S='(@(MBJV+'8I]BR(-BYV879B-BOVXPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(MF!V*?8M=F$V8?B@(S:K]BPV*?8L=N,(-BY
MV879B-BOVXPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`BV+G9A=F(V*_;
MC#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(MBNVXS9A-N,(-BHV*?9A-BG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS
M9W-T<B`BV8;8I]F%(-F^V+'9B-F&V*_9AR(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@
M(E9I971N86UE<V4@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R(*;7-G<W1R("+9AMF%V*?;C"`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T
M<B`BV8;9A=BGVXP@VXS:J2#8M=F!V*W9AR#9B-BH(-BNV*?8L=BLVXPB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(@V8;9A=BG(-BH
MV8<@V+G9AMF(V*?9AB`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*
M;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S
M='(@(MF"V*?8J-F$VXS8JB#9A=BTV*?9A]BOV8<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS
M9W-T<B`BV8+8I]BHV83;C-BJ(-F%V+38I]F'V*_9ASH@(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G
M:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N
M(@IM<V=S='(@(MBGV*[8M]BGV+$A(2$@V*_8L]BJ(.*`C-F&V8C;C-BS(-BQ
MV*<@V*C8M]F(V+$@V*_8L]BJVXP@V*?8LB`E<R#8K=BPV8$@VJG9AMN,V*\B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM
M<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN
M9R(*;7-G<W1R("+8I]BNV+?8I]BQ.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("+:
MAMF'V*?8L=BTV8;8J-F'(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(MF^VXS8
MM.*`C-BHVXS9AMN,(-F'V8C8IR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*
M;7-G<W1R("+8K]BGV*_9AR#8HMBH(-F((-F'V8C8I]N,VXP@V8'8L=BGV8?9
MA2#8M-BOV8<@V*C9AR#9B-BSVXS9A-F'(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")W96%T
M:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")7
M96(B"FUS9W-T<B`BV8C8J"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(MF(V*CB@(S:K]BGV8<B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED(")7965K;'DB"FUS9W-T<B`BV8?9@=BJVJ_;C"(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S
M='(@(MBNV8C8M"#8HMF%V*_;C-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(R`C+2,M(RTC+2,@
M(&9A7TE2+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S
M='(@(MBHV8<@)7,@V*[9B-BT(-BBV878K]N,V*\B"@HC(",M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@(",M(RTC+2,M(PHC(`HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS
M9W-T<B`B)7/8C"#8KMF(V+0@V*+9A=BOVXS8KR(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G
M<W1R(")797-T97)N("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T
M<B`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS
M9W-T<B`BVH;9AR#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"#8L=BG
M("5S(-BHV*?;C-BO(-BHV+G8KR#8I]BR(-F(V+'9B-BO(-F&V+38I]F&(-BO
MV8?8K]B?(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G
M:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@
M(MF&V8C;C-BSV8?9E.*`C"#8K=BGV*;9A"#:AMN,V+/8JMB?(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`BV8;9B-N,V+/9A^*`C-N,(-F&
MV8+9A"#9@MF(V80@VH;;C-BSV*K8GR(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7:&5R96ES($%U<W1R
M86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S
M"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`BVJG8K]BGV84@V8'8I]BR
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*
M;7-G<W1R("+:J=BOV*?9A2#8J-BQV8;8I]F%V8?B@(S9A]BGVXP@V878JMBU
MV83B@(S:J=F&V8;8K]F'(.*`C-BHV+'8I]N,(-F(VXS8L=BGVXS8M-JOV+$@
MV878JMF&(-F!V+G8I]F$(-BHV*?8M-F&V*\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T
M:"(*;7-G<W1R("+8N=BQV+8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(-F^
MV8?9AMBG(-BOV+$@V8C8I]BMV*\@0U-3("(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(MF^V8?9AMBGVXP@VJ_8LMN,V8;:K]BGV88@)7,@
MV*_8L2#8L=BGV+/8JB`HV*_8L2#9B-BQV8C8KR#8J-BYV*_;C"#9A=F(V*O8
ML2#9A=N,XH",VJ_8L=BOV*\I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B
M;&4B"FUS9W-T<B`BV;[9A]F&V*?;C"#8K-BOV8C9A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T
M:"!U;FET(@IM<V=S='(@(MF(V*?8K=BO(-F^V8?9AMBG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I
M9'1H.B(*;7-G<W1R("+9OMF'V8;8ISHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@
M(MBHV*?8KSHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("+8J-BGV*\@V++9
MB-BOV8?9AMJOV*?9A3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("+8L]BQV+G8JB#8
MJ-BGV*\@V*C8L=BMV+/8J"#9@=F(V*H@V*C8L2#8L]BGV+G8JB(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("+8
MJ-BGV*\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM
M<V=I9"`B5VEN9#H@(@IM<V=S='(@(MBHV*?8KSH@(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`BV+G9@MF$
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`BV83;C-BSV*H@V*+8L=BRV8C9A]BG
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM
M<V=S='(@(MJIV*?8L2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(MBB
MV*_8L=BS(-F%V*W9A"#:J=BGV+$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S
M='(@(MBJV839@=F&(-F%V*W9A"#:J=BGV+$B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L
M9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM
M<V=S='(@(MBGVXS8K-BGV*\@V;[8L=F(V8;8K]F'(%9&4R#9A=BLV8C8LB#8
MK]BSV*K8L=BSVXP@V8;8K]BGV+'8KR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS
M9W-T<B`BXH",65DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T<B`B65E962(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED
M(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R
M("+8L]BGV838I]F&V8<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`BV*+8L=N,(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@
M(EEE<RP@22!!9W)E92(*;7-G<W1R("+8J-F$V8?8C"#9A=F(V*?9@=F"V84B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R
M"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`BV+39
MA=BG(-BOV+$@V878KR#9A=BJV88@V8?8L]BJVXS8KRX@V*?8LB#8K]JIV879
MAR`@6SP^72#8J-BQV*?;C"#8J-BQVJ_8M-BJV88@V*C9AR!765-)5UE'(-BG
MV+/8JMF!V*?8K]F'(-JIV8;;C-BO(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B
M66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`BV+39A=BG(-BJ
MV+78K]N,V8(@V8?9B-N,V9'8JB#9AMBTV*_;C-BO(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T
M(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*
M;7-G<W1R("+8M-F%V*<@V8;9A=N,XH",V*K9B-BGV8;;C-BO(-F&V8C;C-BS
MV8<@)UQ<)R#8L=BG(-BOV+$@V8;8I]F%(-JIV*?9A=F$(-BNV8C8KR#8K]BG
MV+38JMF'(-BHV*?8M-N,V*\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`BV+39A=BG(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8JMBQV8C9AMN,VJD@
MV878N=BJV*C8L=N,(-F(V*?8L=BO(-F&VJG8L=BOV8?B@(S8I]N,V*\B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I
M;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I
M;B`E<RXB"FUS9W-T<B`B(@HBV+39A=BG(-F'VXS:AB#9@=N,V838K]N,(-BQ
MV*<@V*_8L2#9OMBQV8C9AMBOV8<@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'
M(-BHV8<@V8';C-F$V*\@V878JMF"V*?8J-F$VXP@V*_8L2`E<R#9AMJOV*?8
MM-BJ(-F&VJG8L=BOV8?B@(S8I]N,V*\B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB
M"FUS9W-T<B`BV+39A=BG(-BNV*?8L=BL(-BTV*_;C-BO(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@
M9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*(MBTV878IR#9A=BLV*C9B-BQ
M(-F'V+/8JMN,V*\@VXS:J2#8M-F%V*?8L=F'(-BJV839@=F&(-F%V+G8JMBH
MV+$@V8C8I]BQV*\@VJG9AMN,V*_8C"#8I]BR(-BYV838I]F%V*H@)RLG(-BH
MV+'8I]N,(-BTV878I]BQV8?B@(S9A]BGVXP@(@HBV*C;C-F&(-BGV839A=F$
MV83;C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(MBTV878IR#9A=BLV*C9B-BQ(-F'V+/8
MJMN,V*\@VXS:J2#9A=F"V*_8I]BQ(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9
MAMN,V*\B"@HC(",M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@,RD@
M(",M(RTC+2,M(PHC(`HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(MBTV878IR#8J-BGVXS8
MKR#;C-JI(-F^V+38JMN,V*C8I]F&(-BOV+'8KMBJ(-BOV*?8K]F'(-BHV+'8
MI]N,(-BGV+/8JMF!V*?8K]F'(-BGV+(@V*O8J-BJ(-F&V*?9A2#9OMN,VJG8
ML=BHV8;8K]N,(-JIV8;;C-BO(@H*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#8L]BG
MV878I]F&V8<@V;[8M-BJVXS8J-BGV88@5D93(-BQV*<@V;[;C-JIV+'8J-F&
MV*_;C"#:J=F&VXS8KR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T
M<B`BV8+8J-F$(-BGV+(@V*?8L=BSV*?9A"#:K]BRV*?8L=BTV(P@V*C8I]N,
MV*\@V878M-JIV80@V+'8IR#8M-BQV*T@V*_9A]N,V*\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`BV+39A=BG(-BHV*?;C-BO(%523-BGVXP@VJG9AR#8I]N,V88@
MV;[;C-F(V8;8KR#8J-F'(-BBV88@V*?8M-BGV+'9AR#9A=N,XH",VJG9AMBO
M(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E
M<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:
MJ2#:J=BGV+'8L]BGV++8C"#8J-BQV*?;C"#8K=BPV8$@VJG8L=BOV88@V*?9
MAMBJV*[8I]BH(-JIV8;;C-BO(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+B(*;7-G<W1R("+8M-F%V*<@V*C8I]N,V*\@VXS:J2#9AMBGV84@VJG8I]BQ
MV*C8L=B,(-BHV+'8I]N,(-BMV+#9@2#:J=BQV*_9AB#9A=BTV*[8M2#:J=F&
MVXS8KR(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`BV+39A=BG
M(-BHV*?;C-BO(-N,VJD@V8;8I]F%(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8
MK=BPV8$@V+38K]F&(-F%V+38KMBU(-JIV8;;C-BO(@H*(SH@861M:6XO=7-E
M<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM
M<V=S='(@(MBTV878IR#8J-BGVXS8KR#;C-JI(-F&V*?9A2#:J=BGV+'8J-BQ
MV(P@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9AB#9A=BTV*[8M2#:J=F&
MVXS8KR(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("+8M-F%
MV*<@V*C8I]N,V*\@VXS:J2#8M-F&V*?8L]F'(-JIV*?8L=BHV+'8C"#8J-BQ
MV*?;C"#8J-BQV8C8LMBQV+/8I]F&VXP@V*?9AMBJV*[8I]BH(-JIV8;;C-BO
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O
M<FTN(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#9A=BTV*[8M2#:J=F&VXS8
MKR#:J=F'(-J&V8<@V+G9A=F$VXP@V*C8I]N,V*\@V*?9AMBLV*?9A2#:K]N,
MV+'8KR(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y
M(&YA;64N(@IM<V=S='(@(MBTV878IR#8J-BGVXS8KR#9AMBGV84@V*S8K]N,
MV*\@V*_8L]BJV8<@V+'8IR#8JMBGVXS9OB#:J=F&VXS8KR(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS
M9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M
M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BV8;8M-BSV*H@
M)7,@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8JBX@V838M]F!V*?9
MBR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(MBBV*_8L=BS(-BGV83:J=BJV+'9B-F&VXS:J=N,
M(-BTV878IR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BV*+8K]BQV+,@V8'8L=BS
MV*K9AMBOV8<Z(-BTV878ISHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`BV*?8M]F$V*?8N=BGV*H@V+39A=BG
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HBV*+8K]BQV+,@V*?;C-F&V*K8L=F&V*K;C"#8M-F%
MV*<@V8;8L]BHV*H@V*C9AR#8I]BHV*K8K]BGVXP@V8;8M-BSV*H@)7,@V+39
MA=BG(-BJV+K;C-N,V+$@VJG8L=BOV8<@V*?8L]BJ+MBHV+'8I]N,(-BQV+G8
MI]N,V*H@V878L]BGV*;9A"`B"B+8I]F%V8;;C-BJVXP@V*C8I]N,V*\@V*_9
MB-BHV*?8L=F'(-F(V*?8L=BO(-BTV8C;C-BO(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R
M("+9AMBGV84@V+39A=BG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A
M8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I
M8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(MBSV*?9A=BGV8;9AR#9OMBT
MV*K;C-BHV*?9AB#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V+39A=BG(-BGV+;8
MI]F!V8<@VJG8L=BOV88@VJG8I]BQV*C8L=BGV88@V+'8IR#9OMBTV*K;C-BH
MV*?9AMN,(-F&V87;C.*`C-JIV8;8K]B,(-N,V*<@V+38I]N,V*\@(@HBV*C9
MAMBG(-BHV8<@V*_9A-N,V80@V*_;C-JOV+';C"#8I]N,V88@VJG8I]BQ(-BG
MV8;8K-BGV84@V8;9A=N,XH",V+39B-BO(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(MBSV*?9A=BGV8;9AR#9OMBTV*K;
MC-BHV*?9AB#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V+39A=BG(-F!V8?8L=BS
MV*H@VJG8L=BOV88@VJG8I]BQV*C8L=BGV88@V+'8IR#9OMBTV*K;C-BHV*?9
MAMN,(-F&V87;C.*`C-JIV8;8K]B,(-N,V*<@V+38I]N,V*\@(@HBV*C9AMBG
M(-BHV8<@V*_9A-N,V80@V*_;C-JOV+';C"#8I]N,V88@VJG8I]BQ(-BGV8;8
MK-BGV84@V8;9A=N,XH",V+39B-BO(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HBV+C8I]F'
MV+$@V878L=F(V+':K]BQ(-BTV878IR#9AMBSV*C8JB#8J-F'(-BGV*C8JMBO
MV*?;C"#9AMBTV+/8JB`E<R#8M-F%V*<@V*K8NMN,VXS8L2#:J=BQV*_9AR#8
MI]BSV*HNV*C8L=BGVXP@V+'8N=BGVXS8JB#9A=BSV*?8IMF$("(*(MBGV879
MAMN,V*K;C"#8J-BGVXS8KR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,
MV*\B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M("+9A=BQV8C8L=JOV+$@V+39A=BG(-BGVXS9AB#9A=BTV*[8M=F'(-BQV*<@
MV;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V*\N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T
M:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*
M;7-G<W1R("(B"B+9A=BQV8C8L=JOV+$@V+39A=BG(-BGVXS9AB#:K]BRVXS9
MAMF'V93B@(P@VH;8I]F^(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB
M@(S:J=F&V*\N($-O;G1R;VPO3W!T:6]N("L@4"#8L=BG(-BHV+'8I]N,(-J&
MV*?9OB`B"B+9@=BTV*?8L2#8K]F'VXS8KR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM
M<V=S='(@(MBRV878I]F&(-F!V+G9A-N,(-F%V8;8M]F"V8<@V*S8NMBQV*?9
M@=N,V*?;C-N,(-BTV878ISHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E
M;B!C:&%N9V5D+B(*;7-G<W1R("+9A]F(VXS9D=BJ(-F^VXS8M"#9@=BQV+8@
MV+39A=BG.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BV8?9B-N,V9'8JB#9
MOMN,V+0@V8'8L=BV(-BTV878ISHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`Q"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BV8;8I]F%
M(-JIV*?9A=F$(-BTV878ISHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HQ,#`P"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R
M("+9B-BQV8C8KR#8M-F%V*<@V879AMF"V+;;C"#8M-BOV8<@V*?8L]BJ(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G
M<W1R("+8I]BSV84@V+'9A=BR("#8K-BOVXS8KR#8M-F%V*<@V*C8L=BGVXP@
M)7,@V8?8L]BJ.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(MJO
MV++;C-F&V8?B@(S9A]BGVXP@V+39A=BG(-BHV+'8I]N,(-BWV8C9A"#8I]N,
MV88@V8;8M-BSV*H@V*C8L=F(V++8L=BSV*?9AMN,(-BTV*_9AR#8I]BSV*H@
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BVJ_8
MLMN,V8;9A^*`C-F'V*?;C"#8M-F%V*<@V*C8L=F(V++8L=BSV*?9AMN,(-BT
MV*_9AR#8I]BSV*HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R
M("+8I]BSV84@V+'9A=BR("#8M-F%V*<@V*C8I]BRV8;8M-BGV8;;C"#8M-BO
MV8<@V*?8L]BJ(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"B+8I]BSV84@V+'9A=BR(-BTV878IR#8J-BGV++9
MAMBTV*?9AMN,(-BTV*_9AR#8I]BSV*K8C"#9OMBSV*H@V*?9A-JIV*K8L=F(
MV8;;C-JI(-BNV8C8KR#8L=BG(-J&VJD@VJG9AMN,V*\@V8@@V*C8IR#8I]BS
MV84@V+'9A=BR(-BLV*_;C-BO("(*(MBNV8C8KR#9B-BGV+'8KR#8M-F(VXS8
MKR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U
M<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`BV*?8L]F%(-BQV878
MLB`@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8JB(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@
M<V5R=F5R<SHB"FUS9W-T<B`BVJG8I]BQV+/8I]BRXH",V8?8I]N,(-BQV*?9
MA^*`C-BOV8C8L2#8M-F%V*<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"B,L(&9U>GIY"FUS9VED("):86ER92(*;7-G<W1R
M("+9A-BWVXS9@2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT
M72(*;7-G<W1R(");V;[9AMF'V*?9AB#:J=BQV*_9AB#9A=BJV88@V8;9@MF$
M(-F"V8C9A"#8M-BOV8==(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*
M;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6]JOV++8I]BQV+0@
MV878M-JIV81=("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@
M(EO9AMF%V*?;C-BT(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BTV*_9AR`M(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("+9AMF%V*?;C-BT(-F%V*K9AB#9
MAMF"V80@V8+9B-F$(-BTV*_9AUL@+2`E<R#8KMBW72(*"B,@(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");V*[8MR`E<R#8I]BR("5S
M(%T@(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("+8L]BQV;[8L=BSV*K;C"(*"B,Z(&QI8B]A<&DN<&AP.C$U
M-PIM<V=I9"`B7T-,22(*;7-G<W1R(")#3$DB"@HC.B!L:6(O87!I+G!H<#HQ
M-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R("+8K]BQV*[8JB#8K]BGV*_9
MAR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`BV*W8L-F!
M(-BSV+?8L2(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*
M;7-G<W1R("+:K]BQV8C9AR8C>#(P,&,[V8?8IR(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@
M(MBQV*?9A]F&V878IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`BV*[8M=F(V+7;C-BGV*H@V*K8M=F(VXS8L2XN+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@
M(E],;V<@:6XB"FUS9W-T<B`BV8C8L=F(V*\B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R
M("+8KMBQV8C8K"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM
M<V=S='(@(MBJV+K;C-N,V+$@V;[;C-F(V8;8KRXN+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM
M<V=S='(@(MJOV++;C-F&V8?B@(S9A]BG(@H*(SH@;&EB+V%P:2YP:'`Z,3,W
M"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`BV878K-F(V++9A]BG(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BV*W8L-F!
M(-F^VXS9B-F&V*\N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3
M971U<"(*;7-G<W1R("+8L=BGV8<F(W@R,#!C.]BGV8;8K]BGV++;C"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`BV*[8
MM=F(V+7;C-BGV*H@V*S8K]F(V80N+BXB"@HC.B!L:6(O87!I+G!H<#HQ,CD*
M;7-G:60@(E]5<V5R<R(*;7-G<W1R("+:J=BGV+'8J-BQV*?9AB(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"FUS9VED(")A9&1R97-S(&)O
M;VLB"FUS9W-T<B`BVJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G
M:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(MJIV*K8I]BHVH;9A]F4
M(-BBV*_8L=BS("(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S
M"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("+8JMF"V8C;C-F%(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("+8HMBQ
MV*?9A2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X
M"B,L(&9U>GIY"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM
M<V=S='(@(MF&V87;C.*`C-BJV8C8I]F&(-BOV+$@V;[8L=F(V8;8K]F'(%PB
M)7-<(B#9AMF(V+38JB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G
M:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`BV*?;C-F&V*S8IR#8L=BG(-F!V+38
MI]BQ(-BOV8?;C-BO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M("+8JMF!V*?9B-BJV8?8I]N,(-F^VXS:J=BQV*C9AMBOVXPB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M
M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R("(E<R#9OMN,V*_8IR#9AMBTV*\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX
M-34*;7-G:60@(F9I;&4B"FUS9W-T<B`BV;[8L=F(V8;8K]F'(@H*(R`C+2,M
M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E(#,I("`C+2,M(RTC+2,*(R`*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("+8I]BR
M("5S("@E<RD@V*_8L2`E<R`E<R(*"B,@(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A(;W)D92`S*2`@(RTC+2,M(RTC"B,@"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`BV*C8
MI]BO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM
M<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")I;6UE9&EA=&4B"FUS9W-T<B`BV8'9B-BQV*?9BR(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`BV*_8L=BNV+<B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(MBNV+?9B-BW72(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(MF&
MV*?9A2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO
M="!I;7!L96UE;G1E9"(*;7-G<W1R("+9OMN,V*?8K]F'(-BSV*?8LMN,(-F&
MV+38K]F'(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ
M,C$Y"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(MF'V8;9
MB-BR(-F^VXS8I]BOV8<@V+/8I]BRVXP@V8;8M-BOV8<@V*?8L]BJ(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@(FYO=&5P860B
M"FUS9W-T<B`B;F]T97!A9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T
M<B`BV*_8L=BUV*\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`BV878K-F(V+(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
MV;[;C-JIV+/9A-F'V*<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BV+?9A-F(V+DB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC+"!F=7IZ>0IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R("+8J-F$V8C:J2!-
M971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*
M;7-G<W1R("+9AMF%V*?;C-BT(-BJV8'8I]F(V*K9A]BG(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@
M(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(MF^VXSB@(S8K]BQV;[;C"(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET
M8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM
M<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(MF!V8?8L=BSV*H@V8C8N-N,V8'9
MAR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G
M86EN(@IM<V=S='(@(MBOV+$@V8?8L2#9B-BQV8C8KR(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS
M9W-T<B`BV*?8L]F%(-BQV878LB#8L=BG(-BHV+'8I]N,(-BJV*/;C-N,V*\@
MV*_9B-BHV*?8L2#9B-BGV+'8KR#:J=F&VXS8KR(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U
M;FEF:65D(@IM<V=S='(@(MN,VJ_8I]F&V8<@V+38K]F'(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R("+8J-N,(-F&V*?9A2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B
M"FUS9W-T<B`BV*?9AMBJV*[8I]BH(-JIV*?8L=BHV+$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&\O97-?15,N<&\`````````````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P-S$V,C<S(#$P-3$U-#,T,30R(#`Q-S4R
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M(%-P86YI<V@@=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E"B,@5')A
M9'5C8VEO;F5S(&%L(&5S<&'Q;VP@<&%R82!E;"!P87%U971E(&AO<F1E+@HC
M($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE
M(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE
M(&AO<F1E('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P
M,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`
M;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M-2TQ."`P.#HQ-RLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R
M+3$U(#$W.C(T*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@36%N=65L(%`N
M($%Y86QA(#QM87EA;&%`=6YE>"YE<SY<;B(*(DQA;F=U86=E+51E86TZ(&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A
M;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN("$](#$I.UQN(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AH86-E("5S(&3M87,I(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C
M97-S:V5Y("5S*2(*;7-G<W1R("(@*$%C8V5D:65N9&\@82`E<RDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H96X@)7,@9.UA<RDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B
M("AH;WDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H
M=&]M;W)R;W<I(@IM<V=S='(@(B`H;6'Q86YA*2(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AA
M>65R*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(F5N("(*
M"B,Z(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&YO
M(&5S('5N(&1I<F5C=&]R:6\N(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C
M:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!N;R!E<R!U;F$@96QE8V-I\VX@=N%L
M:61A+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S$P(&QI8B](;W)D
M92]296=I<W1R>2YP:'`Z,3`Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*
M;7-G<W1R(").;R!S92!H82!C;VYF:6=U<F%D;R!<(B5S7"(@96X@96P@<F5G
M:7-T<F\@9&4@2&]R9&4N(@H*(SH@;&EB+TAO<F1E+U1R964N<&AP.C$W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@
M9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N='+S(&5L(&=E;F5R861O<B!D
M92#A<F)O;&5S(&1E(%PB)7-<(BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE
M(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(E-E(&AA(&'Q861I9&\@7"(E<UPB
M(&%L('-I<W1E;6$@9&4@9W)U<&]S+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(E-E(&AA
M(&'Q861I9&\@7"(E<UPB(&%L('-I<W1E;6$@9&4@<')I=FEL96=I;W,N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(DYO('-E(&AA(&-R96%D;R!<(B5S7"(Z("5S
M+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E
M*2(*;7-G<W1R(")5<V%D;W,@)2XR9DU"(&1E("4N,F9-0B!P97)M:71I9&]S
M("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B
M)60@)7,@>2`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.30@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R
M(")1=65D86X@)60@9.UA<R!H87-T82!Q=64@97AP:7)E(&QA(&-O;G1R87-E
M\6$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60@
M<')O;O-S=&EC;W,@9&EA<FEO<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G
M<W1R("(E<R`M($%V:7-O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B2'5E;&QA(&1I9VET86P@9&4@)7,B"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.#0R(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@
M2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I
M<FUA=&EO;B(*;7-G<W1R("(E<R!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE
M;G1O("T@0V]N9FER;6%C:?-N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(D-O;F9I9W5R86-I\VX@9&4@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(D9I<FUA(&1E("5S(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R(")!8W5E<F1O
M<R!D92!L:6-E;F-I82!D92`E<R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV.3`@
M;&EB+U9&4R]F='`N<&AP.C<V,R!L:6(O5D93+W-M8BYP:'`Z-#0Q"B,Z(&QI
M8B]61E,O<VUB+G!H<#HU,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(EEA(&5X:7-T92`E<RXB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!A(&QA<R`E<R`E<R(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC
M92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&5S=.$@<')E<&%R861O('!A<F$@
M<F5A;&EZ87(@;&%S(&]P97)A8VEO;F5S(&1E(&UA;G1E;FEM:65N=&\@(@HB
M<V5L96-C:6]N861A<RY!8W1I=F4@;&%S(&-A<VEL;&%S(&1E(&QA<R!O<&5R
M86-I;VYE<R!Q=64@9&5S96$@96IE8W5T87(@96X@(@HB97-T82!O8V%S:?-N
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(DAA8V4@9F%L=&$@)7,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T;W,B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@:&$@96YC;VYT
M<F%D;R`E<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(B5S(&%L("5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T
M<B`B1&ER96-C:6]N97,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S
M='(@(D%G96YD82!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$P
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("),
M:6)R971A(&1E(&YO=&%S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G
M<W1R(")487)E87,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z
M(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@
M=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET
M(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@17-T92!M96YS86IE('!U
M961E('%U92!N;R!P<F]C961A(&1E('%U:65N('!A<F5C92!S97(N($5V:71E
M('-E9W5I<B`B"B)C=6%L<75I97(@=NUN8W5L;R!I;F-L=>UD;R!O('-U;6EN
M:7-T<F%R(&-U86QQ=6EE<B!I;F9O<FUA8VGS;B!P97)S;VYA;"!A;"`B"B)R
M96UI=&5N=&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U
M-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U
M<W1I;F<@(@IM<V=S='(@(BP@=F5N=&]S;R`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!V96YT;W-O
M("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@
M(BP@=F%R:6%B;&4@9&4@)7,@82`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#8Y(&QI8B](;W)D92]&;W)M+G!H<#HR,3(X"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HW-#@@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@*;7-G:60@
M(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!S96QE8V-I;VYA<B`M+2(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B
M"FUS9W-T<B`B1F]R;6%T;R!D92`Q,B!H;W)A<R(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R
M;6%T;R!D92`R-"!H;W)A<R(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!H;W)A<R(*"B,Z(&QI
M8B](;W)D92]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G
M<W1R("(\06YT97)I;W(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM
M<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+B(*;7-G<W1R(")087)A(&5S=&4@8FQO<75E(&AA8V4@9F%L=&$@
M=6X@;6]T;W(@9&4@8F%S92!D92!D871O<RXB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T
M<B`B4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&ER<F5P87)A8FQE(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R(")(86-E(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-I
M9G)A<B!U;B!M96YS86IE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(DAA8V4@9F%L=&$@
M=6YA(&-L879E(%!'4"!P^F)L:6-A('!A<F$@8V]M<')O8F%R('5N(&UE;G-A
M:F4@9FER;6%D;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@HB2&%C96X@9F%L=&$@=6YA(&-L879E(%!'
M4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0('!R:79A9&$@>2!U;F$@9G)A<V4@
M8VQA=F4@(@HB<&%R82!D97-C:69R87(@=6X@;65N<V%J92XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB2&%C
M96X@9F%L=&$@=6YA(&-L879E(%!'4"!P^F)L:6-A+"!U;F$@8VQA=F4@4$=0
M('!R:79A9&$@>2!U;F$@9G)A<V4@8VQA=F4@(@HB<&%R82!F:7)M87(@=6X@
M;65N<V%J92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(DAA8V5N(&9A;'1A('5N82!C;&%V
M92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P<FEV861A('D@
M=6YA(&9R87-E("(*(F-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E
M+B(*;7-G<W1R("(B"B)(86-E;B!F86QT82!U;F$@8VQA=F4@4R]-24U%('#Z
M8FQI8V$L('5N82!C;&%V92!3+TU)344@<')I=F%D82!Y('5N82!F<F%S92`B
M"B)C;&%V92!P87)A(&9I<FUA<B!U;B!M96YS86IE+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(DAA8V4@9F%L=&$@=6YA(&-L879E(%--24U%('#Z8FQI8V$@<&%R82!C:69R
M87(@=6X@;65N<V%J92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3G5B97,@
M;6%T:6YA;&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B3&EG97)A
M(&QL=79I82!M871I;F%L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B3&QU=FEA
M(&UA=&EN86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!9W5A8V5R;W,@
M;6%T:6YA;&5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!9W5A
M8V5R;R!M871I;F%L(&1E(&YI979E(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)
M1"(*;7-G<W1R("))1"!D92!!4$DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R(")!8V5R8V$@9&5L(&5D:71O<B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")!8V5R
M8V$@9&4N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B26YF97)I;W(@
M06)S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")%;B!M961I;R!!8G,N
M(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C@R"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E-E(&AA(&1E
M;F5G861O(&5L(&%C8V5S;R!A;"!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4RXB
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E-E(&AA(&1E;F5G861O
M(&5L(&%C8V5S;R!A;"!C<F5A<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R("))9&5N=&ED860B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP
M:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R(")#
M;VYT<F%S9?%A(&1E(&%C8V5S;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B261E;G1I9&%D(&)L;W%U96%D82XB"@HC.B!C;VYF:6<O+F)A:R]R96=I
M<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B
M0V]N=&%B:6QI9&%D(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B
M0?%A9&ER(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S
M+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!\6%D
M:7(@9W)U<&\@9&5S8V5N9&EE;G1E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!\6%D:7(@<')I=FEL96=I;R!D
M97-C96YD:65N=&4B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM
M<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D'Q861I<B!A<77M.B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED
M(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(D'Q861I<B!G<G5P;R(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D'Q861I
M<B!P<FEV:6QE9VEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B0?%A9&ER(&$@7"(E<UPB('5N(&=R
M=7!O(&1E<V-E;F1I96YT92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(D'Q861I<B!A(%PB)7-<(B!U;B!P<FEV
M:6QE9VEO(&1E<V-E;F1I96YT92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS
M9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B0?%A9&ER('5N('5S=6%R
M:6\Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")!\6%D:7(@8V]L=6UN82(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@
M(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!\6%D:7(@;6EE;6)R;W,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I
M<B(*;7-G<W1R(")!\6%D:7(@<&%R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")!\6%D:7(@96P@
M;65N^B`E<R!C;VUO('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T
M;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D'Q861I<B!A(&QA<R!D:7)E8V-I
M;VYE<SHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X
M"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D'Q861I
M<B!A(&QA<R!D:7)E8V-I;VYE<SHB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM
M<V=I9"`B061D('5S97(B"FUS9W-T<B`B0?%A9&ER('5S=6%R:6\B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"B)392!H82!A\6%D:61O(%PB)7-<(B!A;"!S:7-T96UA+"!P97)O(&YO('-E
M('!U961E(&'Q861I<B!L82!I;F9O<FUA8VGS;B`B"B)A9&EC:6]N86P@9&4@
M86QT83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@
M:6X@;F]W+B(*;7-G<W1R(")392!H82!A\6%D:61O(%PB)7-<(B!A;"!S:7-T
M96UA+B!982!P=65D92!I;FEC:6%R(&QA('-E<VGS;BXB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),82!A9&EC:?-N(&1E('5S=6%R:6]S
M(&5S=.$@9&5S:&%B:6QI=&%D82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30T,2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")$:7)E8V-I\VXB"@HC.B!C;VYF:6<O+F)A:R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R
M(")$:7)E8V-I;VYE<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*;7-G
M:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S
M97)S(@IM<V=S='(@(D%D;6EN:7-T<F%D;W(@+2!D969I;F4@<')I=FEL96=I
M;W,@9&4@;W1R;W,@=7-U87)I;W,B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q-PIM<V=I9"`B061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-I\VXB"@HC.B!C;VYF:6<O
M+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R
M(")!;G5N8VEO<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N
M:7-TX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T"FUS9VED
M(")!;&=E<FEA(@IM<V=S='(@(D%R9V5L:6$B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B
M06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EN96%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM
M<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")!;&EN96%C:?-N.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1O
M9&]S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@
M57-E<G,B"FUS9W-T<B`B5&]D;W,@;&]S('5S=6%R:6]S(&%U=&5N=&EF:6-A
M9&]S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP
M.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")4;V1O<R!L;W,@9W)U
M<&]S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-2!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.CDQ"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B5&]D;W,@;&]S('!R:79I;&5G:6]S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5&]D;W,@;&]S(&QA9&]S(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<R(*;7-G<W1R(")097)M:71I<B!V87)I87,@9&ER96-C:6]N
M97,B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@
M(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@
M(K]097)M:71I<B!C;VYF:6=U<F%C:?-N(&1E('1I<&\@9&4@;&ES=&%S(&]R
M9&5N861A<S\B"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*
M;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(EEA(&5X:7-T92(*"B,Z
M(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N
M871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06-C97-O($E-4U`@86QT97)N871I
M=F\B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(D-L879E($E-4U`@
M86QT97)N871I=F$B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HU
M,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(E5S
M=6%R:6\@24U04R!A;'1E<FYA=&EV;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*
M;7-G<W1R(")$:7)E8V-I\VX@96QE8W1R\VYI8V$@86QT97)N871I=F$B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E
M;7!L871E<R(*;7-G<W1R(")0;&%N=&EL;&%S(&%L=&5R;F%T:79A<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,@IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E1E>'1O
M(&%L=&5R;F%T:79O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-PIM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B
M4V%M;V$@06UE<FEC86YA(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HY
M-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")392!H82!I;F1I8V%D
M;R!U;B!V86QO<B!I;&5G86PN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E
M9"XB"FUS9W-T<B`B4V4@:&$@<')O9'5C:61O('5N(&5R<F]R(&1E<V-O;F]C
M:61O+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0*;7-G:60@
M(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P"FUS9VED(")!;F=U:6QL82(*;7-G
M<W1R(")!;F=U:6QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B4')O>'D@86[S;FEM
M;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!
M;G-W97(B"FUS9W-T<B`B4F5S<'5E<W1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-0IM<V=I9"`B06YT87)C=&EC82(*
M;7-G<W1R(")!;G3A<G1I9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(D%N=&EG=6$@>2!"87)B861O<R(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&QI8B](;W)D92]"
M;&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L:6-A8VGS
M;B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC
M871I;VX@3&ES="(*;7-G<W1R("),:7-T82!D92!A<&QI8V%C:6]N97,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!<'!L:6-A=&EO
M;B!I<R!R96%D>2XB"FUS9W-T<B`B3&$@87!L:6-A8VGS;B!E<W3A(&QI<W1A
M+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!
M<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B07!L:6-A<B!A(')E8W5R
M<V]S(&-O;7!A<G1I9&]S(&1E<V-E;F1I96YT97,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G
M<W1R(")!<')O8F%R(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C@T,@IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")486UA\6\@
M87!R;WAI;6%D;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X
M"FUS9VED(")!<')I;"(*;7-G<W1R(")!8G)I;"(*"B,Z(&-O;F9I9R\N8F%K
M+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R(")!<N%B:6=O("A7:6YD;W=S+3$R-38I(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(E1A;6'Q
M;R!D96P@87)C:&EV;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED(")!<F-H:79E
M($YA;64B"FUS9W-T<B`B3F]M8G)E(&1E;"!A<F-H:79O(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("*_17-T82!S96=U
M<F\@9&4@<75E(&1E<V5A(&5L:6UI;F%R(&QA('-O;&EC:71U9"!D92!A;'1A
M(&1E("5S/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN
M8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES
M:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T
M<B`BOT5S=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B!<(B5S7"(@
M>2!T;V1O<R!S=7,@<W5B9W)U<&]S/R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R(")!<F=E;G1I;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N
M:6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FEO("A!4DU30TE)
M+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B
M"FUS9W-T<B`B07)T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@
M27-L86YD(@IM<V=S='(@(DES;&$@07-C96YS:?-N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B1W+A
M9FEC;W,@07-C:6DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")296=I\VX@9&4@
M07-I82]086/M9FEC;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*(K]3;VQI8VET
M87(@8V]N9FER;6%C:?-N(&%N=&5S(&1E(')E86QI>F%R(&]P97)A8VEO;F5S
M(&1E(&UA;G1E;FEM:65N=&\_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P
M.34*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")#;VQU;6YA
M<R!D92!A<VEG;F%C:?-N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I
M9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM
M<V=S='(@(DEN=&5N=&$@96QI;6EN87(@=6X@9W)U<&\@:6YE>&ES=&5N=&4N
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B26YT96YT82!E;&EM:6YA<B!U;B!P<FEV:6QE9VEO(&EN97AI<W1E;G1E
M+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M26YT96YT82!M;V1I9FEC87(@=6X@<')I=FEL96=I;R!I;F5X:7-T96YT92XB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B26YT
M96YT82!M;V1I9FEC87(@=6X@<F5C=7)S;R!C;VUP87)T:61O(&EN97AI<W1E
M;G1E+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<Q"FUS9VED(")!='1R:6)U=&5S(@IM<V=S
M='(@(D%T<FEB=71O<R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B06=O<W1O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.0IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(D%U<W1R86QI82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U<W1R:6$B"FUS
M9W-T<B`B075S=')I82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z
M,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@3F\@<V4@96YC
M;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA+B(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B075T:%]C>7)U<SH@16P@;6]T;W(@8V%R96-E(&1E(&QA<R!C87!A
M8VED861E<R!N96-E<V%R:6%S+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@3F\@<V4@
M96YC;VYT<O,@;&$@97AT96YS:?-N(&EM87`@;F5C97-A<FEA+B(*"B,Z(&QI
M8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB
M075T:%]F='`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!&5%`@;F5C
M97-A<FEA+B!#;VUP:6QE(%!(4"!C;VX@;&$@(@HB;W!C:?-N("TM96YA8FQE
M+69T<"XB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B
M075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?:6UA<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS
M:?-N($E-05`@;F5C97-A<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!.;R!S92!E;F-O
M;G1R\R!L82!E>'1E;G-I\VX@:W)B-2!N96-E<V%R:6$N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@3F\@97-TX2!S;W!O<G1A9&$@;&$@
M861I8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%P.B!.;R!E<W3A('-O<&]R
M=&%D82!L82!E;&EM:6YA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER
M96-T;W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@
M(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VQD87`Z($YO('-E(&5N8V]N='+S(&QA(&5X=&5N
M<VGS;B!,1$%0(&YE8V5S87)I82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`Z($YO('-E('!U961E(&'Q861I
M<B!E;"!U<W5A<FEO("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L("(*(G-E
M<G9I9&]R.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI
M;F%R(&5L('5S=6%R:6\@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!);F-A<&%Z
M(&1E(&%C='5A;&EZ87(@96P@=7-U87)I;R`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B)!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&%C
M='5A;&EZ86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>2(*
M"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]M8V%L.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@34-!
M3"!N96-E<V%R:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HV,`IM
M<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@3F\@<V4@96YC
M;VYT<O,@;&$@97AT96YS:?-N('-M8F%U=&@@;F5C97-A<FEA+B(*"B,Z(&QI
M8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1F%L;/,@;&$@
M875T96YT:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!)34%0+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B1F%L;/,@;&$@875T96YT:69I
M8V%C:?-N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T
M<B`B1F%L;/,@;&$@875T96YT:69I8V%C:?-N+B`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")%;"!S97)V:61O
M<B!2041)55,@:&$@<F5C:&%Z861O(&QA(&%U=&5N=&EF:6-A8VGS;BXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z.#DU"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1F%L;/,@;&$@875T96YT
M:69I8V%C:?-N(&-O;B!E;"!S97)V:61O<B!&5%`N(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(D9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS
M;B!C;VX@96P@<V5R=FED;W(@4TU"+B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@
M(D-A;7!O<R!D:7-P;VYI8FQE<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S
M='(@(D%Z97)B86EJ86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*
M;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")%>&-U<V%S($)/1D@B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9O;F1O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B
M0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")#;VQO<B!D92!F;VYD;R(*"B,Z
M(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R
M;W,@<&%S<W=O<F0N(@IM<V=S='(@(D-O;G1R87-E\6$@:V5R8F5R;W,@:6YC
M;W)R96-T82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I
M9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").;VUB<F4@9&4@
M=7-U87)I;R!K97)B97)O<R!I;F-O<G)E8W1O+B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B0F%H86UA<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H
M<F%I;B(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@
M(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D+A;'1I8V\@*$E33RTX
M.#4Y+3$S*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5S
M:"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S,*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(DYO('-E(&5N8V]N='+S(&5L(&1I<F5C=&]R:6\@8F%S92!D92!I;>%G
M96YE<R!<(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"87-E;&EN92(*;7-G<W1R("),
M[6YE82!B87-E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT.0IM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"96QA<G5S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-0IM
M<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"Z6QG:6-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#`*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;FEN
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M,0IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M=61A<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@(D)H
M=71A;B(*;7-G<W1R(")":'5T86XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B0W5M
M<&QE8?%O<R(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI
M8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N8V]N
M='+S(&5L(&)L;W%U92!<(B5S7"(@9&4@;&$@87!L:6-A8VGS;B!<(B5S7"(N
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R(")/<&-I;VYE<R!D92!B;&]Q=64B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K
M(%1Y<&4B"FUS9W-T<B`B5&EP;R!D92!B;&]Q=64B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS
M9W-T<B`B3F5G<FET82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I
M82(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I
M9"`B0F]O:VUA<FMS(@IM<V=S='(@(DUA<F-A9&]R97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED
M(")";W)D97(B"FUS9W-T<B`B0F]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN
M97-S.B(*;7-G<W1R(")'<F]S;W(@9&5L(&)O<F1E.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@
M(D)O<F1E<G,B"FUS9W-T<B`B0F]R9&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,@IM<V=I9"`B0F]S;FEA(&%N9"!(
M97)Z96=O=FEN82(*;7-G<W1R(")";W-N:6$@2&5R>F5G;W9I;F$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B
M06UB;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0X"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,@IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(DEN9F5R:6]R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-PIM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("))<VQA(&1E($)O=79E="(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@(D)R
M87II;"(*;7-G<W1R(")"<F%S:6PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-PIM<V=I9"`B0G)I=&ES:"!);F1I86X@
M3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(E1E<G)I=&]R:6\@;V-EX6YI8V\@
M9&4@;&$@26YD:6$@8G)I=.%N:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L
M86TB"FUS9W-T<B`B0G)U;F5I($1A<G5S<V%L86TB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W"FUS9VED(")"=6QG87)I
M82(*;7-G<W1R(")"=6QG87)I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B3&ES=&$@9&5S;W)D96YA9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R
M(")"=7)U;F1I(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z
M-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B4'5N=&]S(&1E(&1I<W1R
M:6)U8VGS;B!#4D,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B4')O<&EE9&%D97,@9&4@7V-E;&1A+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B3F\@<V4@:&$@9FEN86QI
M>F%D;R!E;"!I;FEC:6\@9&4@;&$@8V%C:.DN(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0HC.B!C;VYF:6<O+F)A:R]H;V]K<RYP:'`N9&ES=#HQ,#0P(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B06=E;F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X"FUS9VED(")#
M86UB;V1I82(*;7-G<W1R(")#86UB;WEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,`IM<V=I9"`B0V%M97)O;VXB"FUS
M9W-T<B`B0V%M97+Z;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R(&QI8B]6
M1E,O9G1P+G!H<#HV-S8@;&EB+U9&4R]S;6(N<&AP.C0S-0HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR,#,*;7-G:60@(D-A;B!N;W0@8V]P>2!F:6QE*',I
M("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(@IM<V=S
M='(@(B(*(DYO('-E('!U961E*&XI(&-O<&EA<B!E;"]L;W,@87)C:&EV;RAS
M*2`M(&]R:6=E;B!Y(&1E<W1I;F\@<V]N(&5L(&UI<VUO+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,C`R(&QI8B]61E,O9G1P+G!H<#HW-3(@;&EB+U9&4R]S
M;6(N<&AP.C4P,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C@*;7-G:60@
M(D-A;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN
M('-O=7)C92XB"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4H;BD@=')A<VQA9&%R
M(&5L+VQO<R!A<F-H:79O*',I("T@96P@9&5S=&EN;R!E<W3A(&1E;G1R;R!D
M96P@(@HB;W)I9V5N+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B).
M;R!S92!P=65D92!R96%J=7-T87(@;&$@8VQA=F4@875T;VWA=&EC86UE;G1E
M+"!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"`B"B)A9&UI;FES=')A9&]R
M(&1E;"!S:7-T96UA+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B
M"FUS9W-T<B`B3F\@<V4@<'5E9&4@97-C<FEB:7(@96X@96P@87)C:&EV;R!<
M(B5S7"(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T
M(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T
M<B`B3F\@<V4@<'5E9&5N(&%D;6EN:7-T<F%R(&UA;F5J861O<F5S(&1E('-E
M<VGS;B!E>'1E<FYO<RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C,Q.2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(DYO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($E-05`Z
M("5S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@
M<'5E9&4@86)R:7(@96P@87)C:&EV;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,0IM<V=I9"`B0V%N861A
M(@IM<V=S='(@(D-A;F%DX2(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI
M;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(D-A;F-E;&%R(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G
M<W1R(")#86YC96QA<B!I;F9O<FUE(&1E('!R;V)L96UA<R(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E
M;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@96QI;6EN
M87(@96P@87)C:&EV;R!<(B5S7"(N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(DYO
M('-E(&5N8W5E;G1R82!U;B!D:7)E8W1O<FEO('1E;7!O<F%L+B(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R(").;R!S
M92!P=65D92!C;VYT:6YU87(@<VEN(&5L('!A<N%M971R;R`G=&%R9V5T1FEL
M92<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(DYO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@7"(E<UPB+B(*
M"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D92]$871A
M5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@96QI;6EN87(L('1I96YE("5D(&1E<V-E;F1I96YT97,N(@H*(SH@;&EB
M+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B
M(@HB3F\@<V4@<'5E9&4@<F5O<F1E;F%R+"!E;"!N^FUE<F\@9&4@96YT<F%D
M87,@<75E('-E(&1E<V5A(&]R9&5N87(@;F\@(@HB8V]I;F-I9&4@8V]N(&QA
M<R!A;&UA8V5N861A<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@9&ER:6=I<B!E
M;"!M96YS86IE(&%L(&[Z;65R;R!E<W!E8VEF:6-A9&\N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-0IM<V=I9"`B0V%P
M92!697)D92(*;7-G<W1R(")#86)O(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R(")3=6)T[71U;&\B"@HC.B!L:6(O3F5T+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")0<F]V
M965D;W(B"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=&5G;W+M87,@
M>2!E=&EQ=65T87,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B
M27-L87,@0V%I;>%N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@
M;?-V:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B
M4')O<&EE9&%D97,@9&4@8V5L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*
M;7-G<W1R(")-87)G96X@9&4@8V5L9&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P
M<F]P97)T:65S(@IM<V=S='(@(E!R;W!I961A9&5S(&1E(&-E;&1A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G
M:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B17-P86-I861O(&1E(&-E;&1A
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO
M;F4B"FUS9W-T<B`B5&5LZ69O;F\@;?-V:6PB"@HC.B!C;VYF:6<O+F)A:R]N
M;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*
M;7-G<W1R(")#Z6QT:6-O("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#
M96YT97(B"FUS9W-T<B`B0V5N=')A<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0V5N=')O869R:6-A;F$B
M"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT
M<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")%=7)O<&$@0V5N
M=')A;"`H25-/+3@X-3DM,BDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")$
M971A;&QE<R!D96P@8V5R=&EF:6-A9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T
M<B`B4')O<&EE=&%R:6\@9&5L(&-E<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC
M:65S(@IM<V=S='(@(E!O;.UT:6-A<R!D96P@8V5R=&EF:6-A9&\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C$*;7-G
M:60@(D-H860B"FUS9W-T<B`B0VAA9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M;7-G:60@(D-H86YG92(*;7-G<W1R(")#86UB:6%R(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S
M=V]R9"(*;7-G<W1R(")#86UB:64@;&$@8V]N=')A<V7Q82(*"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB
M0V%M8FEA(&5L(&YO;6)R92!Y(&QA(&1I<F5C8VGS;B!E;&5C='+S;FEC82!V
M:7-I8FQE<R!A;"!L965R(&\@<F5S<&]N9&5R(&$@(@HB<W5S(&UE;G-A:F5S
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B
M(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B),82!C;VYF:6=U<F%C:?-N
M(&%C='5A;"!N;R!S;W!O<G1A(&5L(&-A;6)I;R!D92!C;VYT<F%S9?%A<RX@
M4/-N9V%S92!E;B`B"B)C;VYT86-T;R!C;VX@96P@861M:6YI<W1R861O<B!D
M96P@<VES=&5M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(D=RX69I
M8V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E9E
M<FEF:6-A<B!?=NUN8W5L;RXN+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-H
M:6QE(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HV,0IM<V=I9"`B0VAI;F$B"FUS9W-T<B`B0VAI;F$B"@HC.B!C;VYF:6<O
M+F)A:R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;F\@<VEM<&QI9FEC861O("A'0C(S
M,3(I(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B
M0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B0VAI;F\@=')A
M9&EC:6]N86P@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R(")!<&QI8V%C
M:?-N.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED
M(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")%;&EJ82!U;F$@8V]N=')A
M<V7Q82(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")%;&EJ82!U;B!N;VUB<F4@
M9&4@=7-U87)I;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,P
M,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R
M(")%;&EJ82!C\VUO(&UO<W1R87(@;&%S(&9E8VAA<SHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS
M9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T
M<RDB"FUS9W-T<B`B4V5L96-C:6]N87(@=&EP;R!D92!E<W1I;&\@9&4@;&ES
M=&$@*'!A<F$@;&ES=&%S(&]R9&5N861A<RDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V"FUS9VED(")#:')I<W1M87,@
M27-L86YD(@IM<V=S='(@(DES;&$@9&4@4&%S8W5A(@H*(SH@;&EB+U9&4RYP
M:'`Z.3$T(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@
M(DYO('-E(&5N8V]N='+S(&QA(&1E9FEN:6-I\VX@9&4@8VQA<V4@9&4@)7,N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*
M;7-G:60@(D-L96%R(@IM<V=S='(@(DQI;7!I87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-
M4T]F9FEC92!T86=S(@IM<V=S='(@(D5L:6UI;F%R(&5T:7%U971A<R!-4T]F
M9FEC92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(D)O<G)A<B!C;VYS=6QT82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")";W)R87(@=7-U87)I;SH@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G
M:60@(D-L96%R('5S97(B"FUS9W-T<B`B0F]R<F%R('5S=6%R:6\B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@
M=7-E<B!D871A(@IM<V=S='(@(D)O<G)A<B!D871O<R!D96P@=7-U87)I;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS
M9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D1E<W!E:F%D;R!T87)D[6\B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV
M,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2&%G82!C;&EC
M:R!P87)A('-E9W5I<B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(D-L:6-K871E;&P@<&]R($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L
M;W-E(%=I;F1O=R(*;7-G<W1R(")#97)R87(@=F5N=&%N82(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B3G5B
M97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DYU8F5S('1E;7!R86YA
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B;G5B;W-O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,@IM<V=I9"`B0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B27-L87,@9&4@8V]C;W,@*$ME
M96QI;F<I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")/8W5L=&%R(&)A<G)A
M(&QA=&5R86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R(")#;VQA<'-A<B!B;W)D97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8R"FUS9VED(")#;VQO;6)I82(*;7-G<W1R
M(")#;VQO;6)I82(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")#
M;VQO<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,#,@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G
M<W1R(")396QE8W1O<B!D92!C;VQO<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#(X"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C
M8VGS;B!D92!C;VQO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#;VQU;6YA
M<SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN
M('1I=&QE<R(*;7-G<W1R(")4[71U;&]S(&1E(&QA<R!C;VQU;6YA<R(*"B,Z
M(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M
M:6-S(@IM<V=S='(@(D/S;6EC<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M-@IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUA;F1O(@H*(SH@861M:6XO
M8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@
M(DEN=.ER<'(N(&-O;6%N9&]S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O;65N=&%R:6\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N
M($YA;64B"FUS9W-T<B`B3F]M8G)E(&-O;?IN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`*;7-G:60@(D-O;6]R;W,B
M"FUS9W-T<B`B0V]M;W)O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D-O;7!A\>UA
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E
M<G,B"FUS9W-T<B`B3W)D96YA9&]R97,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B0V]N
M9&EC:?-N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@(D-O
M;F1I=&EO;G,B"FUS9W-T<B`B0V]N9&EC:6]N97,B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<R(*;7-G<W1R(")$:69E<F5N8VEA<R!D92!L82!C;VYF:6=U<F%C:?-N(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN(@IM<V=S='(@(B(*(D-O;F9I9W5R86-I\VX@<&%R82!S
M:6YC<F]N:7IA8VGS;B!C;VX@4$1!<RP@3?-V:6QE<R!C;VX@86=E;F1A('D@
M3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,T"FUS9VED
M(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("),82!C
M;VYF:6=U<F%C:?-N(&5S=.$@9&5S86-T=6%L:7IA9&$N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A<B`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S
M<W=O<F0B"FUS9W-T<B`B0V]N9FER;6%R(&-O;G1R87-E\6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U"FUS9VED(")#
M;VYG;R(*;7-G<W1R(")#;VYG;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B0V]N9V\L(%)E</IB;&EC
M82!$96UO8W+A=&EC82!D96PB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")&86QL\R!L
M82!C;VYE>&GS;BXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DW(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B1F%L;/,@;&$@8V]N
M97AI\VXZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I
M9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R(")392!H82!R96-H87IA9&\@;&$@8V]N97AI\VX@86P@<V5R
M=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I(@IM<V=S='(@(B(*(E-E(&AA(')E8VAA>F%D;R!L82!C;VYE>&GS;B!A
M;"!S97)V:61O<B!D92!C;&%V97,@</IB;&EC;RX@36]T:79O.B`E<R`H)7,I
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@X.0IM<V=I9"`B0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B2&$@9F%L;&%D;R!L82!C
M;VYE>&GS;B!A;"!S97)V:61O<B!&5%`N(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,C0@8V]N9FEG+RYB86LO:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I
M9"`B0V]N=&%C=',B"FUS9W-T<B`B0V]N=&%C=&]S(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R
M92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM
M<V=S='(@(E-E(&AA;B!A\6%D:61O(&-O<G)E8W1A;65N=&4@;&]S(&-O;G1A
M8W1O<R!A('-U<R!D:7)E8V-I;VYE<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E
M<W-E9"!F:6QE.B`B"FUS9W-T<B`B5&EP;R!D92!C;VYT96YI9&\@9&5L(&%R
M8VAI=F\@8V]M<')I;6ED;SH@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1E
M;FED;R!D92!<(B5S7"(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S,@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O
M;G1I;G5E(@IM<V=S='(@(D-O;G1I;G5A<B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R("))<VQA<R!#;V]K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q
M"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA<B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HT.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S
M(@IM<V=S='(@(D9A;&SS(&QA(&-O<&EA.B`E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L
M96-T:6]N(@IM<V=S='(@(D-O<&EA<B!S96QE8V-I\VXB"@HC.B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B240@9&4@8V]S=&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(D-O<W1A(&1E($UA<F9I;"(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(").;R!S92!P=65D92!C:69R
M87(@96P@;65N<V%J92!M961I86YT92!01U`Z("(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M
M97-S86=E.B`B"FUS9W-T<B`B3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A
M:F4@;65D:6%N=&4@4$=0.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N(@IM<V=S='(@(DYO('-E('!U961E(&-I9G)A<B!E;"!M96YS86IE(&UE
M9&EA;G1E(%,O34E-12(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@9FER;6%R(&5L(&UE;G-A:F4@;65D:6%N=&4@
M(%,O34E-12(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!A\6%D:7(@96P@8V]N=&%C=&\N
M("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z.38*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@96YL87IA<B!A;"!S97)V:61O<B!,1$%0+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYO
M('-E('!U961E(&-O;7!R;V)A<B!E;"!S86QD;RX@)7,B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8V]N96-T87(@
M86P@<V5R=FED;W(@3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYO('-E('!U
M961E(&-O;F5C=&%R(&%L('-E<G9I9&]R(%PB)7-<(B!M961I86YT92!&5%`Z
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").;R!S92!P=65D92!C<F5A<B!L82!L
M:7-T82!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$Z("(*;7-G<W1R(").;R!S92!P=65D96X@9&5S8VEF<F%R(&QO<R!D871O
M<R!01U`Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(S"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B
M3F\@<V4@<'5E9&5N(&1E<V-I9G)A<B!L;W,@9&%T;W,@4R]-24U%+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G
M<W1R(").;R!S92!P=65D92!E;&EM:6YA<B!E;"!C;VYT86-T;RX@)7,B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DYO('-E('!U961E(&5L:6UI;F%R(&QA(&QI<W1A
M(&1E(&1I<W1R:6)U8VGS;BX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@HB3F\@
M<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D
M92!C;VYF:6=U<F%C:?-N(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HY-3,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R(").;R!S92!P=65D92!D971E<FUI;F%R82!L
M82!D:7)E8V-I\VX@9&4@8V]R<F5O(&1E;"!D97-T:6YA=&%R:6\N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<R!C
M;VUP;&5T82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(DYO('-E('!U961E('1R865R(&QA(&QI<W1A
M(&1E(&1I<W1R:6)U8VGS;B!C;VUP;&5T82XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G
M<W1R(").;R!S92!P=65D92!T<F%E<B!L82!L:7-T82!C;VUP;&5T82!D92!L
M:7-T87,@9&4@9&ES=')I8G5C:?-N+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@<V4@<'5E9&4@8V%R9V%R(&QA(&5S=')A=&5G:6$@7"(E<UPB+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N
M<&AP.C,P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;6MD:7(@7"(E<UPB+B(*;7-G<W1R(").;R!S92!P=65D92!C<F5A<B!E;"!D
M:7)E8W1O<FEO(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M
M('1H92!K97ES97)V97(N(@IM<V=S='(@(DYO('-E('!U961E(&]B=&5N97(@
M;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S
M7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(DYO('-E('!U961E(&%B<FER(%PB
M)7-<(B!P87)A(&5S8W)I8FER+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0U(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S<*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@86)R:7(@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3F\@<V4@<'5E
M9&4@86)R:7(@96P@;?-D=6QO(&1E('1A<F5A<R!D92!M86YT96YI;6EE;G1O
M("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@86)R
M:7(@96P@9&ER96-T;W)I;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY
M"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R=FED;W(@3$1!4"XB
M"@HC.B!L:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").;R!S92!P=65D92!L
M965R("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS
M9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@
M<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@HB3F\@<V4@<'5E9&4@<F5S=&%B;&5C97(@;&$@8V]N=')A<V7Q
M82!D96P@=7-U87)I;R!S;VQI8VET861O+B!087)T92!D92!L;W,@(@HB9&5T
M86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R<F5C=&]S+B!0<G5E8F4@;W1R82!V
M97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O(&-O;B`B"B)E;"!A9&UI;FES=')A
M9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN9F]R;6%C:?-N+B(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<U(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").;R!S92!P
M=65D92!O8G1E;F5R(&QA($%#3"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DYO('-E('!U
M961E(&]B=&5N97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE<RX@)7,B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@;V)T96YE<B!L82!L:7-T
M82!D92!D:7-T<FEB=6-I\VXN("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").
M;R!S92!P=65D96X@;V)T96YE<B!L87,@;&ES=&%S(&1E(&1I<W1R:6)U8VGS
M;BX@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").;R!S
M92!P=65D96X@;V)T96YE<B!L87,@8V%P86-I9&%D97,@9&5L('-E<G9I9&]R
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S92!P=65D
M92!R97-T875R87(@;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R
M(").;R!S92!P=65D92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%PB)7-<(BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(").;R!S92!P=65D92!G=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9&4@
M)7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYO('-E('!U961E(&=U87)D87(@
M=6YA(&-O<&EA(&1E(&QA(&-O;F9I9W5R86-I\VXN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B3F\@
M<V4@<'5E9&4@9W5A<F1A<B!U;F$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS
M;CH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"B).;R!S92!P=65D92!G=6%R
M9&%R(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A
M8VGS;B!E;CH@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DYO('-E('!U
M961E(&=U87)D87(@;&$@8V]P:6$@)7,@9&4@;&$@8V]N9FEG=7)A8VGS;BXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DYO('-E('!U
M961E(&=U87)D87(@96P@87)C:&EV;R`E<R!D92!C;VYF:6=U<F%C:?-N+B!0
M=65D92!U=&EL:7IA<B!U;F$@9&4@(@HB;&%S(&]P8VEO;F5S('!A<F$@<F5S
M=&%U<F%R(&5L(&/S9&EG;R!D92`E<R!O(&-O<&EA<B!M86YU86QM96YT92!A
M("5S(&5L("(*(F/S9&EG;R!S:6=U:65N=&4N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<V4@<'5E9&4@8G5S8V%R(&5N(&5L
M('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYO('-E('!U961E
M(&1E<W9I;F-U;&%R(%PB)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F\@<V4@<'5E9&4@86-T
M=6%L:7IA<B!E;"!C;VYT86-T;RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYO
M('-E('!U961E(&%C='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N
M+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M7"(E<UPB.B`E<R(*;7-G<W1R(").;R!S92!P=65D92!E<V-R:6)I<B!L82!C
M;VYF:6=U<F%C:?-N(&1E(%PB)7-<(CH@)7,B"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HS-S`*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO
M>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN
M(@IM<V=S='(@(B(*(DYO('-E('!U961E(&QO8V%L:7IA<B!E;"!P86YE;"!L
M871E<F%L(&1E($UO>FEL;&$N($-O;7!R=65B92!Q=64@97-TZ2`B"B)A8FEE
M<G1O+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB
M)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*(DYO('-E('!U961E;B!O=&]R9V%R(&%L('5S
M=6%R:6\@7"(E<UPB(&QO<R!S:6=U:65N=&5S(&1E<F5C:&]S('!A<F$@;&$@
M(@HB8V%R<&5T82!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")497AT;R!C;VYT
M861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@
M(D-O=6YT<GDB"FUS9W-T<B`B4&'M<R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#=7)S
M;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<F5A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<F5A('5N
M(';M;F-U;&\B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-R96%R
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(D-R96%R('-U8F-A<G!E=&%S(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4')I=FEL96=I;W,@9&4@8W)E861O<B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,C$R"FUS9VED(")#<F5D:70@8V%R9"!N=6UB
M97(B"FUS9W-T<B`B3OIM97)O(&1E('1A<FIE=&$@9&4@8W+I9&ET;R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y"FUS
M9VED(")#<F]A=&EA(@IM<V=S='(@(D-R;V%C:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T"FUS9VED(")#=6)A(@IM
M<V=S='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@
M(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B-"!&87-E<R!A8W1U86QE<R(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S
M:6]N<R(*;7-G<W1R(")397-I;VYE<R!A8W1U86QE<R(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R
M<F5N="!4:6UE(@IM<V=S='(@(DAO<F$@86-T=6%L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED
M(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")54DP@86-T=6%L(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(E5S=6%R:6]S(&%C='5A;&5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(E1I96UP;R!A
M8W1U86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS
M9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D-O;F1I8VGS;B!A
M8W1U86PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B17-T:6QO
M(&%C='5A;"(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E!E<G-O;F%L:7IA(&QA<R!T87)E
M87,@82!E:F5C=71A<B!A;"!I;FEC:6%R('-E<VGS;B!E;B`E<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C`*;7-G:60@(D-U="(*;7-G<W1R(")#;W)T87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L
M96-T:6]N(@IM<V=S='(@(D-O<G1A<B!S96QE8V-I\VXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`B0VAI<')E(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD
M:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0VER
M[6QI8V\@*$M/23@M4BDB"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z
M,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")#
M:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP
M:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5
M*2(*;7-G<W1R(")#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X"FUS9VED
M(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@0VAE8V$B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,C<R"FUS9VED("(B"B)$4TX@*'-E92!H
M='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E
M+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*(D133B`H=F5A(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5S+W!A8VMA9V4N9&%T86)A<V4N9&(N
M:6YT<F\M9'-N+G!H<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP
M.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$:6%R:6%M96YT92(*"B,Z(&%D
M;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*
M;7-G<W1R("+!<E]B;VP@9&%T;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(W,`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(D-O;G-U;'1A
M(&1E(&QA(&)A<V4@9&4@9&%T;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,Y."!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I
M9"`B1&%T92(*;7-G<W1R(")&96-H82(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S
M='(@(E-E(&AA(')E8VEB:61O(&QA(&9E8VAA(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(W.#D*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5C8VGS;B!D92!F96-H82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I
M9"`B1&%Y(@IM<V=S='(@(D3M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#
M;VQU;6XB"FUS9W-T<B`B15]L:6UI;F%R(&-O;'5M;F$B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T
M<B`B1&EC:65M8G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S
M(@IM<V=S='(@(D[Z;65R;W,@9&5C:6UA;&5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@
M26YD96YT(@IM<V=S='(@(E)E9'5C:7(@<V%N9W)A9&\B"@HC.B!L:6(O<')E
M9G,N<&AP.C$Q-R!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$X-PIM<V=I9"`B
M1&5F875L="(*;7-G<W1R(")0;W(@;VUI<VGS;B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT
M($-O;&]R(@IM<V=S='(@(D-O;&]R('!O<B!O;6ES:?-N(@H*(SH@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*
M;7-G<W1R("))9&5N=&ED860@<&]R(&]M:7-I\VXB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B
M4VAE;&P@<&]R(&]M:7-I\VXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:6-I;VYE<R(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E<FUS+G!H<#HS
M,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY."!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*;7-G:60@(D1E;&5T92(*;7-G<W1R
M("(F;F)S<#M%;&EM:6YA<B9N8G-P.R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`B16QI;6EN87(@8V5L9&$B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E
M($=R;W5P(@IM<V=S='(@(D5L:6UI;F%R(&=R=7!O(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S
M='(@(D5L:6UI;F%R(')E9VES=')O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L
M971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B16QI;6EN87(@<')I=FEL96=I;R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")%;&EM:6YA<B!Y
M('9A8VEA<B!M96YS86IE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(D5L:6UI;F%R(&-E;&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O
M;'5M;B(*;7-G<W1R(")%;&EM:6YA<B!C;VQU;6YA(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4B"FUS9W-T<B`B16QI;6EN87(@<&QA;G1I;&QA<R!A;'1E
M<FYA=&EV87,@97AI<W1E;G1E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@
M(D5L:6UI;F%R(&UE;G-A:F5S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B16QI;6EN87(@<')I=FEL96=I;W,@9&4@
M7"(E<UPB(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@
M86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(K]%;&EM:6YA<B!P
M<FEV:6QE9VEO<R!P87)A(%PB)7-<(B!Y(&-U86QQ=6EE<B!P<FEV:6QE9VEO
M(&1E<V-E;F1I96YT93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S
M='(@(D5L:6UI;F%R(&9I;&$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E
M:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I
M='DB"FUS9W-T<B`B16QI;6EN87(@:61E;G1I9&%D('-E;&5C8VEO;F%D82(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B
M1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(D5L:6UI;F%R('-U8F-A<G!E
M=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M(@IM<V=S='(@(D5L:6UI;F$@;&$@8V]L=6UN82!A8W1U86PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B16QI;6EN
M82!L82!F:6QA(&%C='5A;"(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@96P@
M9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N(%PB
M)7-<(BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS
M9W-T<B`B2&]R82!D92!E;G1R96=A.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B1&EN86UA<F-A(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D1E
M<V-R:6)A(&5L('!R;V)L96UA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDS
M."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP8VGS;B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,C`V"FUS9VED(")$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(D1E=&%L;&5S("AT86UB:>EN
M(&5N(&5L(&%R8VAI=F\@9&4@<F5G:7-T<F\@9&4@2&]R9&4I.B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")392!H86X@<F5G
M:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A9&]R+B(*
M"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B
M1&5V96QO<&UE;G0B"FUS9W-T<B`B1&5S87)R;VQL;R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4'5N
M=&\@9&4@8V]N9&5N<V%C:?-N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B
M4'5N=&\@9&4@8V]N9&5N<V%C:?-N(&1E(&QA(/IL=&EM82!H;W)A.B`B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@
M<&]I;G0Z("(*;7-G<W1R(")0=6YT;R!D92!C;VYD96YS86-I\VXZ("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G
M:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(D1E(&EZ<75I
M97)D82!A(&1E<F5C:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R(")$92!D97)E8VAA(&$@:7IQ=6EE<F1A(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$
M:7)E8W1O<FEO(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,C<P
M"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(K]-;W-T
M<F%R(&5N(&9O<FUA=&\@9&4@,C0M:&]R87,_(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS
M9W-T<B`B3W!C:6]N97,@9&4@5FES=6%L:7IA8VGS;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE
M9"!F;W)E8V%S="(*;7-G<W1R(")-;W-T<F%R('!R;V[S<W1I8V\@9&5T86QL
M861O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA
M>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")-;W-T<F%R('!R;V[S<W1I8V\@
M*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B1&ES
M<&QA>2!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D92!V:7-U>F%L:7IA8VGS
M;B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P
M;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B3F]T:69I8V%C:?-N(&1E
M(&-O;G-U;'1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T
M(&1E;&5T92(*;7-G<W1R(").;R!E;&EM:6YA<B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F\@86-C961E<B!D:7)E8W1A
M;65N=&4@82!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,@IM
M<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA
M;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B*_0V]N
M=&EE;F4@;&$@<')I;65R82!F:6QA(&QO<R!N;VUB<F5S(&1E(&QO<R!C86UP
M;W,_(%-I(&5S(&%S[2P@<V5L96-C:6]N92`B"B)E<W1A(&-A<VEL;&$Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,@IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($1O;6EN:6-A;F$B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG
M="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(K].;R!D:7-P
M;VYE(&1E(&-U96YT83\@4V]L:6/M=&5L82XB"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.#4S"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")$
M97-C87)G87(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4S
M"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(D1E
M<V-A<F=A<B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*;7-G
M:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S
M8W)I<'0N(@IM<V=S='(@(D1E<V-A<F=A<B!L82!C;VYF:6=U<F%C:?-N(&=E
M;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("),:7-T
M82!D97-P;&5G86)L92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM
M<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9V%S(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B0V]R<F5O
M(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B
M14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI
M8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*(D-O;G1R;VQA
M9&]R(&1E('!A<V%R96QA($-O<G)E;RUA+5--4R!P87)A('!R;W9E961O<F5S
M('%U92!P<F]P;W)C:6]N96X@97-T92`B"B)S97)V:6-I;RXB"@HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G
M:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<U"FUS9VED(")%8W5A9&]R(@IM<V=S='(@
M(D5C=6%D;W(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS
M9W-T<B`B)FYB<W`[36]D:69I8V%R)FYB<W`[(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")-;V1I
M9FEC87(@8FQO<75E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO
M9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B36]D
M:69I8V%R(&=R=7!O(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S
M:6]N(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV:6QE9VEO(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N
M<R(*;7-G<W1R(")-;V1I9FEC87(@<')I=FEL96=I;W,B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(DUO9&EF:6-A<B!P<FEV
M:6QE9VEO<R!D92`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*
M;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(DUO9&EF:6-A<B!O
M<&-I;VYE<R!D93HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B36]D:69I8V%R('!R:79I;&5G:6]S(&1E(%PB)7-<(B(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B36]D
M:69I8V%R('!R:79I;&5G:6]S(&1E("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B161U8V%C:?-N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW
M-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'1O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W"FUS9VED(")%;"!3
M86QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B
M16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT;RXN+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*
M;7-G<W1R(")%;2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#8Y(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")#;W)R96\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4V-B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*;7-G:60@(D5M86EL
M($%D9')E<W,B"FUS9W-T<B`B1&ER96-C:?-N(&1E(&-O<G)E;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`B3&%S(&1I<F5C8VEO;F5S(&1E(&-O<G)E
M;R!T:65N96X@<75E(&-O:6YC:61I<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T
M<B`B0V]R<F5O(&-O;B!C;VYF:7)M86-I\VXB"@HC.B!L:6(O3F5T+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A
M>2(*;7-G<W1R(")087-A<F5L82!#;W)R96\M82U335,B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O
M;G,B"FUS9W-T<B`B16UO=&EC;VYE<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G
M<W1R(")-96YS86IE(&5N(&)L86YC;R(*"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HR-#,@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C8R(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HW,#4*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,34P"FUS
M9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E)E<W5L=&%D;R!E;B!B;&%N
M8V\N(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED
M(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B3&EM<&EA<B!TZ7)M:6YO
M<R!D92!B^G-Q=65D82(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`BOU!E<FUI=&ER(&EN
M<V5R8VGS;B!D92!I;>%G96YE<R!D92!L87,@1V%L97+M87,@9&4@9F]T;W,_
M(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("*_4&5R
M;6ET:7(@;65N^B!D92!C;VYT97AT;R!D96P@8F]T\VX@9&5R96-H;R!D96P@
M<F%T\VX_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(W.3,*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D'Q;R!D
M92!T97)M:6YA8VGS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(D%G<F%N9&%R(&5D:71O<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD
M:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN=')O9'5Z8V$@=6YA('!R96=U;G1A
M(&1E('-E9W5R:61A9"!Q=64@<V4@;&4@9F]R;75L87+A('-I('!R96-I<V$@
M(@HB<F5A:G5S=&%R(&QA(&-O;G1R87-E\6$L('`N92X@)[]#=>%L(&5S(&5L
M(&YO;6)R92!D92!S=2!M87-C;W1A/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"FUS9VED(")%
M;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B26YT<F]D=7IC82!A
M<77M(&QA(%523"!D92!L82!I;6%G96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R
M<R!B96QO=SHB"FUS9W-T<B`B26YT<F]D=7IC82!L87,@;&5T<F%S(&1E(&1E
M8F%J;SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")'=6EN
M96$@16-U871O<FEA;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-SD*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E
M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+U9I97<N<&AP.CDT"FUS9VED(")%<G)O<B(*;7-G<W1R(")%<G)O<B(*"B,Z
M(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")%<G)O<B!A
M;"!C<F5A<B!E;"!B;&]Q=64Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(D5R<F]R(&%L(&5L:6UI;F%R
M(&%N8VQA(&1E('-I;F-R;VYI>F%C:?-N.B`E<R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")%<G)O<B!A;"!E;&EM
M:6YA<B!E;"!R96=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;CH@)7,B"@HC.B!L
M:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(D5R<F]R(&%L
M(&]B=&5N97(@8V]N=&5N:61O<SH@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D5R<F]R(&%L(&%C='5A;&EZ
M87(@;&$@8V]N=')A<V7Q83H@)7,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R(")%<G)O<B!C;VX@96P@;65N<V%J92!D92!C;W)R96\N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@
M7"(E<UPB+B(*;7-G<W1R(")%<G)O<B!A;"!E<V-R:6)I<B!<(B5S7"(N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-@IM
M<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1O;FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,0IM<V=I9"`B171H:6]P
M:6$B"FUS9W-T<B`B171I;W#M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(LET;FEC;R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B
M175R;W!A(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0S"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,34@;6EN=71O
M<R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B
M179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D-A9&$@,B!M:6YU=&]S(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G
M<W1R(")#861A(#,P('-E9W5N9&]S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N
M<&AP+F1I<W0Z,S0R(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C,Y-`IM
M<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU=&]S
M(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E
M<GD@3&]G:6XB"FUS9W-T<B`B0V%D82!I;FEC:6\@9&4@<V5S:?-N(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B0V%D82!M961I82!H;W)A(@H*(SH@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R\N8F%K+W!R969S+G!H
M<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(D-A9&$@
M;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G
M:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<F5S(&1E(&5J96UP
M;&\Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")%>&5C=71E
M(@IM<V=S='(@(D5J96-U=&%R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")%>'!A
M;F1I<B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G
M:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(DUO<W1R87(@8F%R<F$@;&%T
M97)A;"(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I
M9"`B17AP96-T960@)RDG(@IM<V=S='(@(G-E(&5S<&5R86)A("<I)R(*"B,Z
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")3
M92!E<W!E<F%B82!U;F$@^FYI8V$@<&%L86)R82!O('5N('3I<FUI;F\@9&4@
M8OIS<75E9&$@96YT<F5C;VUI;&QA9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")&
M96-H82!D92!V96YC:6UI96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")#;VQO<B!D92!L971R
M82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S8*;7-G:60@(D944"!U
M<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B0V%R9V%R(&QA(&-O;F9I9W5R86-I
M\VX@<&]R($944"(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP.C(R,`IM
M<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@
M(D9A;&QO(&%L('1R865R(&QA<R!P<F5F97)E;F-I87,N(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B26YC87!A>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R($Q$
M05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B26YC87!A
M>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R(%--0BXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z-S(U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")&86QL;R!A;"!C;W!I87(@9&4@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")&
M86QL;R!A;"!C;W!I87(@82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@
M8V]N;F5C=&EO;BXB"FUS9W-T<B`B1F%L;&\@86P@8W)E87(@=6YA(&-O;F5X
M:?-N(%-!4TPB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8X(&QI8B]61E,O<VUB
M+G!H<#HU,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@
M=&\@7"(E<UPB+B(*;7-G<W1R(")&86QL;R!A;"!T<F%S;&%D87(@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R(")&86QL;R!A;"!R
M96-U<&5R87(Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B1&5S<&5J861O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-`IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(DES
M;&%S($UA;'9I;F%S("A&86QK;&%N9"DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(DES;&%S($9A<F]E(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;W(@:7)R96-U
M<&5R86)L93HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B
M1F%X97,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I
M9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B<F5R;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E-E('-I
M96YT92!C;VUO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R
M,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E-E('-I96YT92!C;VUO
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B4&]C87,@;&QU=FEA<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D5S8V%S;R!A9W5A8V5R
M;R!D92!N:65V92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30T"FUS9VED
M(")&:65L9"!M871R:7@B"FUS9W-T<B`B36%T<FEZ(&1E(&-A;7!O<R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,S(U"FUS9VED(")&:6=L970@0T%05$-(
M02(*;7-G<W1R(")#05!40TA!(&1E($9I9VQE="(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,S(Y"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("),971R
M82!D92!&:6=L970B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@S"FUS9VED(")&:6II(@IM<V=S='(@(D9I:FDB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS
M9W-T<B`B07)C:&EV;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B3KH@9&4@87)C
M:&EV;W,Z("5S(&%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(").NB!D
M92!A<F-H:79O<SH@)7,@87)C:&EV;W,B"@HC.B!C;VYF:6<O+F)A:R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M(")!<F-H:79O<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B
M"FUS9W-T<B`B3F]M8G)E(&1E(&%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,CDW-PIM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L
M96-C:?-N(&1E(&%R8VAI=F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30X
M-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B0V%R9V%R(&%R8VAI=F\B
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`P"FUS9VED(")&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3&$@8V%R9V$@9&4@87)C
M:&EV;W,@;F\@97-TX2!S;W!O<G1A9&$N(@H*(SH@8V]N9FEG+RYB86LO<F5G
M:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL
M=')O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#(*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N9&EA(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R(")#=6%R=&\@8W)E8VEE;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R(")#=6%R=&\@8W)E8VEE;G1E(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-PIM<V=I9"`B1FEX(')A=&EO(@IM
M<V=S='(@(E)A>O-N(&9I:F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(E9O;'1E87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")$:7-P;W-I8VGS;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED
M(")&;V<B"FUS9W-T<B`B3FEE8FQA(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3`W(&QI8B]61E,O<W%L+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(DQA(&-A<G!E=&$@
M)7,@;F\@97AI<W1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B0V]L
M;W(@9&4@;&5T<F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G
M:60@(D9O;V0B"FUS9W-T<B`B0V]M:61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&
M;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R
M(")087)A(&YA=F5G861O<F5S('%U92!N;R!A9&UI=&%N(&EMX6=E;F5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4
M048I(@IM<V=S='(@(E!R;V[S<W1I8V\@*%1!1BDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@
M*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H
M(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@
M<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB1.UA<R!D96P@
M<')O;O-S=&EC;R`H=&5N9V$@96X@8W5E;G1A('%U92!E;"!P<F]N\W-T:6-O
M(&9A8VEL:71A9&\@:6YC;'5Y92`B"B)T86YT;R!E;"!D[6$@8V]M;R!L82!N
M;V-H93L@=6X@;OIM97)O(&=R86YD92!S92!T<F%D=6-I<N$@96X@=6X@8FQO
M<75E(&UU>2`B"B)A;F-H;RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(K](82!O;'9I9&%D;R!L82!C;VYT<F%S9?%A/R(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M1F]R;75L87)I;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G
M:60@(D9O<G1U;F4B"FUS9W-T<B`B1F]R='5N82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1I
M<&\@9&4@9F]R='5N82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B1F]R='5N87,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M1F]R='5N87,@,B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T
M.C0U-0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<F]S(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*
M;7-G<W1R(")2965N=NUO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E9I92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R(")&<F%M97,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W"FUS9VED(")&<F%N
M8V4B"FUS9W-T<B`B1G)A;F-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&
M<F%N8VEA+"!-971R;W!O;&ET86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R(")'=6%Y86YA(&9R86YC97-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B4&]L:6YE<VEA(&9R86YC97-A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R"FUS9VED(")&
M<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R<FET;W)I
M;W,@9G)A;F-E<V5S(&1E;"!S=7(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1&5L("(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!C:?-N(&-O;7!L971A(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ
M-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("),=6YA(&QL96YA(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VUB
M<F4@8V]M<&QE=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@X"FUS9VED(")'86)O;B(*;7-G<W1R(")'86+S;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS
M9W-T<B`B1V%L97+M82!D92!L82!Q=64@;V)T96YE<B!L82!I;6%G96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R[6$Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-@IM
M<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F%R(&-O;F9I9W5R86-I
M\VX@9&4@)7,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT
M;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B0_-D:6=O(&=E
M;F5R861O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'96]R9VEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.0IM<V=I
M9"`B1V5R;6%N>2(*;7-G<W1R(")!;&5M86YI82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H86YA(@IM
M<V=S='(@(D=H86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A
M;'1A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<V"FUS9VED
M(")':79E;B!.86UE(@IM<V=S='(@(DYO;6)R92!I;F1I8V%D;R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-SD@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G
M:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D]P8VEO;F5S(&=L;V)A;&5S
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O(@IM
M<V=S='(@(DER(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM
M<V=S='(@(DUA<&%S(&1E($=O;V=L92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B0OIS<75E
M9&$@96X@1V]O9VQE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(D5S8V%L82!D
M92!G<FES97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=R96-I82(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(D=R965K("A)
M4T\M.#@U.2TW*2(*;7-G<W1R(")'<FEE9V\@*$E33RTX.#4Y+3<I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(D=R;V5N;&%N9&EA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.0IM<V=I9"`B1W)E
M;F%D82(*;7-G<W1R(")'<F%N861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F%C:?-N(&1E(&=R=7!O<R(*"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z
M-3D@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B3&]S(&YO;6)R97,@
M9&4@9W)U<&\@;F\@<'5E9&5N(&1E:F%R<V4@96X@8FQA;F-O(@H*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A
M<#H@3F\@<V4@<'5E9&4@8?%A9&ER(&5L(&=R=7!O("5S+B#)<W1O(&5S(&QO
M('%U92!D:6IO(&5L('-E<G9I9&]R.B`B"@HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,3$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM
M<V=S='(@(D=R;W5P7VQD87`Z($EN8V%P87H@9&4@96QI;6EN87(@96P@9W)U
M<&\@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R
M(")'<F]U<%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@9W)U<&\@
M)7,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C,Q-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!O<R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@*;7-G:60@(D=U861E
M;&]U<&4B"FUS9W-T<B`B1W5A9&%L=7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS9W-T
M<B`B1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E
M>2(*;7-G<W1R(")'=65R;F5S97DB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")0<FEV:6QE9VEO<R!D92!I;G9I
M=&%D;R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM
M<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(DPN(&EN=FET861O<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<*;7-G:60@
M(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0*;7-G:60@(D=U:6YE82U":7-S
M874B"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y86YA(@IM
M<V=S='(@(D=U87EA;F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.38P"FUS
M9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RXB"FUS9W-T<B`B2%1-3"!S92!N:65G82!C;V)A<F1E;65N=&4@82!E
M;&EM:6YA<B!L82#Z;'1I;6$@8V5L9&$@9&4@;&$@9FEL82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*(DA434Q!<F5A('-E
M(&YI96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!C;VQU
M;6YA(&1E(&QA('1A8FQA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3"!S92!N:65G82!C;V)A<F1E;65N=&4@82!E;&EM:6YA
M<B!L82#Z;'1I;6$@9FEL82!D92!L82!T86)L82XB"@HC.B!L:6(O2&]R9&4O
M075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!L82!A=71E;G1I
M9FEC86-I\VX@2%144"XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,3`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:73M
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H
M+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FEM;R!(87-H(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B
M"FUS9W-T<B`B3F5B;&EN82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,3D@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,30*;7-G:60@(DAE861E<B(*;7-G<W1R
M(")#86)E8V5R82(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(D-A8F5C97)A<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-PIM
M<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S
M='(@(DES;&$@2&5A<F0@92!)<VQA<R!-8T1O;F%L9"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4
M+5-T;W)M(@IM<V=S='(@(E1O<FUE;G1A('1R;W!I8V%L(&EN=&5N<V$B"@HC
M.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5O("A)4T\M.#@U.2TX+4DI
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT
M(@IM<V=S='(@(D%L='5R82(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ.#0@
M;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L
M<"(*;7-G<W1R(")!>75D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM
M<V=S='(@(D%Y=61A(&1E;"!E9&ET;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(D%Y=61A;G1E(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S
M='(@(DAE;6ES9F5R:6\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")!<77M
M('1I96YE(&5L(&-O;6EE;GIO(&1E;"!A<F-H:79O.B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")(:6=H(@IM
M<V=S='(@(D%L=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@
M=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO
M7VUE(@IM<V=S='(@(E]);FEC:6\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R(")386YT82!3961E("A#:75D860M
M17-T861O(&1E;"!6871I8V%N;RDB"@HC.B!L:6(O2&]R9&4N<&AP.C$U-#@*
M;7-G:60@(DAO;64B"FUS9W-T<B`B26YI8VEO(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")$
M;VUI8VEL:6\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@
M(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5C=&]R:6\@<&5R<V]N86PB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R(")496SI9F]N;R!P87)T:6-U;&%R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`X
M"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-@IM<V=I9"`B
M2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*"B,Z(&-O;F9I9R\N8F%K
M+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(
M;W)D92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L
M86(Z(%-E(&AA;B!E;F-O;G1R861O(&1A=&]S(%A-3"`E<R!N;R!VX6QI9&]S
M(&5N(&5L(&UE;G-A:F4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G
M92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($YI;F?Z;B!M96YS86IE(&-O<G)E<W!O;F1E(&%L(&]B:F5T;R`E<R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0U"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.;R!S92!E;F-O
M;G1R\R!U;B!O8FIE=&\@9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%-E(&AA(&5L:6UI;F%D;R!C;W)R
M96-T86UE;G1E("5S(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN
M92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R
M("(B"B)(;W)D92]+;VQA8CH@16P@;6]T;W(@9&4@:6YT96=R86-I\VX@<')E
M8VES82!D92!L82!E>'1E;G-I\VX@4$A0("=D;VUX;6PG(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@8W)E87(@
M;G5E=F\@X7)B;VP@6$U,(&1E;"!O8FIE=&\@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@26YC87!A>B!D92!E;&EM:6YA<B`E<R!<(B5S7"(Z("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$
M(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!);F-A<&%Z(&1E(&]B=&5N97(@240@34E-12!D92!L82!P87)T92!D92!T
M:7!O("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI
M<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@26YC87!A
M>B!D92!S:6YC<F]N:7IA<B`E<R!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@26YC87!A>B!D92!S:6YC<F]N:7IA<B!E;&5M96YT
M;W,@8V]M<&%R=&ED;W,Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HS
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%;&5M96YT;R!C
M;VUP87)T:61O(&1E<V-O;F]C:61O(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT
M86P@4G5L92(*;7-G<W1R("),[6YE82!H;W)I>F]N=&%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R
M:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DUA<F=E;B!H;W)I>F]N=&%L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM
M<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO;G1A;#HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I(@IM<V=S='(@(K]#\VUO(&QL96?S(&AA<W1A(&%Q=>T_("BA0V]M=6[M
M<75E;&\L('!O<B!F879O<B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BOT-U86YT
M87,@8V]L=6UN87,@9&5S96$@8V]M8FEN87(_(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L
M=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("*_0W7A;G1O<R!C86UP;W,@*&-O
M;'5M;F%S*2!H87D_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`BOT-U86YT87,@9FEL87,@
M9&5S96$@8V]M8FEN87(_(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.0IM<V=I9"`B2'5M:61I
M='DB"FUS9W-T<B`B2'5M961A9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B2'5M961A
M9#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO
M<FES=',B"FUS9W-T<B`B2'5M;W)I<W1A<R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B2'5N9V%R>2(*
M;7-G<W1R(")(=6YG<NUA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H
M<#HR,S4@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(")(82!F86QL861O(&QA(&-R96%C:?-N(&1E;"!B=7KS;B!)34%0
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B2&$@
M9F%L;&%D;R!L82!E;&EM:6YA8VGS;B!D96P@8G5Z\VX@24U!4#H@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DAA(&9A
M;&QA9&\@;&$@8W)E86-I\VX@9&4@97-P86-I;R!A<VEG;F%D;R!D96P@8G5Z
M\VX@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q-@IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@25`B"@HC.B!L:6(O
M2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("),82!D:7)E8V-I\VX@25`@;F\@97-T
MX2!D:7-P;VYI8FQE+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP
M.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412
M(&)L;V-K+B(*;7-G<W1R("),82!D:7)E8V-I\VX@25`@;F\@97-TX2!E;G1R
M92!B;&]Q=65S($-)1%(@<&5R;6ET:61O<RXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+B(*;7-G<W1R(")6:6]L86-I\VX@;&]C:V1O=VX@25`N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B25]N<V5R
M=&%R(&9I;&$@96YC:6UA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES
M;&%N9&EA(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S@P"FUS
M9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E/S;&\@:6-O;F]S(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC
M;VYS(&9O<B`E<R(*;7-G<W1R("))8V]N;W,@9&4@)7,B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X
M="(*;7-G<W1R("))8V]N;W,@8V]N('1E>'1O(@H*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM
M<V=S='(@(DYO;6)R92!D92!L82!I9&5N=&ED860Z(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED("))
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(E-I(&YO('-E(&UU97-T<F$@
M8V]R<F5C=&%M96YT92P@)7,@<&%R82!A8G)I<FQO(&5N('5N82!V96YT86YA
M(&YU979A+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C0U.0IM
M<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B
M"B)3:2!N;R!V92!N:6YG^FX@:6-O;F\@;65D:6%N=&4@26YT97)N970@17AP
M;&]R97(L('!U961E('1E;F5R('%U92!A8W1I=F%R("(*(F5S=&$@8V%S:6QL
M82!P87)A(&1E<V%C=&EV87(@;&$@=')A;G-P87)E;F-I82!03D<N(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B
M(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE
M9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E-I('9E(&5S=&4@;65N
M<V%J92!S:6X@;FEN9W5N82!I;6%G96XL(&QA(&EM86=E;B!Q=64@<75I97)E
M(&-A<F=A<B!N;R!S92`B"B)P=65D92!M;W-T<F%R(&5N('-U(&YA=F5G861O
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C4*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@
M(E9I<W1A('!R979I83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T
M<B`B55),(&1E(&QA(&EM86=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`IM<V=I9"`B26UA9V4@
M55),.B(*;7-G<W1R(")54DP@9&4@;&$@:6UA9V5N.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM
M<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM86=E;B!D92!L
M82!G86QE<NUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE
M<GDZ(@IM<V=S='(@(DEM86=E;B!D92!L82!G86QE<NUA.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T
M<B`B4V4@:&$@8V%R9V%D;R!L82!I;6%G96XB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEMX6=E;F5S(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C4T"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)T87(L('!A
M<V\@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M0V%M<&\@:6UP;W)T861O.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M
M<&]S(&EM<&]R=&%D;W,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R("));E]S97)T87(@9FEL82!D96)A:F\B"@HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B4V4@:&$@:6YD:6-A9&\@=6X@
M8_-D:6=O(&1E(&%C8VGS;B!I;F-O<G)E8W1O+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYO;6)R92!D92!U<W5A
M<FEO('DO;R!C;VYT<F%S9?%A(&EN8V]R<F5C=&]S+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E
M<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N(@IM<V=S='(@(B(*(DYO;6)R92!D92!U<W5A<FEO(&\@9&ER96-C
M:?-N(&%L=&5R;F%T:79A(&EN8V]R<F5C=&]S+B!6=65L=F$@82!I;G1E;G1A
M<FQO(&\@(@HB</-N9V%S92!E;B!C;VYT86-T;R!C;VX@96P@861M:6YI<W1R
M861O<B!D92!S:7-T96UA<R!P87)A(&WA<R!I;F9O<FUA8VGS;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B075M96YT87(@<V%N9W)A9&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,38*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&EA(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B57-U87)I;W,@
M:6YD:79I9'5A;&5S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$R"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD
M;VYE<VEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M86-I\VXB"@HC.B!C;VYF
M:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T
M:6]N(@IM<V=S='(@(DEN9F]R;6%C:?-N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R
M(&%V86EL86)L92XB"FUS9W-T<B`B3&$@:6YF;W)M86-I\VX@>6$@;F\@97-T
MX2!D:7-P;VYI8FQE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@
M069T97(B"FUS9W-T<B`B26YS97)T87(@8U]O;'5M;F$@9&5T<N%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$W"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B26YS97)T87(@
M:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(DEN<V5R=&%R
M('1A8FQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<V5R
M=&%R(';M;F-U;&\@5V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M
M;B!"969O<F4B"FUS9W-T<B`B26YS97)T87(@7V-O;'5M;F$@9&5L86YT92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)T82!U;F$@;G5E=F$@8V]L=6UN
M82!D971RX7,@9&4@;&$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M26YS97)T82!U;F$@;G5E=F$@8V]L=6UN82!D96QA;G1E(&1E(&QA(&%C='5A
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)T82!U;F$@9FEL82!N=65V82!D
M96)A:F\@9&4@;&$@86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS97)T
M82!U;F$@9FEL82!N=65V82!E;F-I;6$@9&4@;&$@86-T=6%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D92(*;7-G<W1R("));G-E<G1A('5N('#A<G)A9F\@=')A<R!E;"!N;V1O
M(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R=&$@=6X@<.%R
M<F%F;R!A;G1E<R!D96P@;F]D;R!A8W1U86PB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("));G-E<G1A<B!P;&%N=&EL;&$@86QT97)N871I=F$B"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.B(*;7-G<W1R("));G-E<G1A<B!U;F$@9&ER96-C:?-N
M(&1E(&-O<G)E;R!E;B!L82!Q=64@<F5C:6)I<B!L82!C;VYT<F%S9?%A.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<V5R
M=&%R(&-E;&1A(&1E='+A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R("));G-E<G1A<B!C96QD82!A;G1E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B26YS97)T87(@8V]L
M=6UN82!D971RX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R
M92(*;7-G<W1R("));G-E<G1A<B!C;VQU;6YA(&%N=&5S(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP(&QI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S
M='(@(DEN<V5R=&%R(&UE;G-A:F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DEN<V5R=&%R('#A<G)A9F\@9&5T
M<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R("));G-E<G1A<B!PX7)R869O(&%N=&5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));G-E<G1A<B!F:6QA(&1E8F%J
M;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DEN
M<V5R=&%R(&9I;&$@96YC:6UA(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP
M+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(DEN<V5R=&%R(&QA
M(')E<W!U97-T82!N96-E<V%R:6$@82!L82!P<F5G=6YT82!D92!S96=U<FED
M860Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));G-E
M<G1A<B]-;V1I9FEC87(@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,
M:6YK(@IM<V=S='(@(DEN<V5R=&%R+TUO9&EF:6-A<B!V[6YC=6QO(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B4V%L9&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R
M(&$@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(E-A;&1O(&EN<W5F:6-I96YT92XB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")%
M;G1E<F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT
M96=E<B!L:7-T(@IM<V=S='(@(DQI<W1A(&1E(&5N=&5R;W,B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B541(("A#86)E
M8V5R82!D92!$871O<R!D92!5<W5A<FEO*2!N;R!VX6QI9&$N(@H*(SH@;&EB
M+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#;VUP<F5S
M<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR
M,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B1&%T;W,@6DE0
M(&YO(';A;&ED;W,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS
M9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")!<&QI8V%C:?-N
M(&YO(';A;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B240@
M9&4@;&]T92!N;R!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M.#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-3@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(R,S(*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.3D@;&EB+TAO<F1E+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(@IM<V=S='(@(E-E(&AA;B!E;G9I861O(&1A=&]S(&YO(';A
M;&ED;W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T
M<B`B1&ER96-C:?-N(&1E(&-O<G)E;R!N;R!VX6QI9&$N(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y(&QI8B](;W)D92]#;VUP<F5S<R]D
M8G@N<&AP.C$S.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F]R;6%T;R!D
M92!A<F-H:79O(&YO(';A;&ED;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S
M='(@(D-L879E(&1E(&QI8V5N8VEA(&YO(';A;&ED82XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")392!H82!I;F1I8V%D;R!U;F$@=6)I
M8V%C:?-N(&YO(';A;&ED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`B;7-G7W1Y<&4@;F\@=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+B(*;7-G<W1R(")A<&E?:60@;F\@=N%L:61O(&\@9&5S87!A<F5C
M:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@9&5S87!A<F5C:61O<RXB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@
M<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!R:79I;&5G:6\@9&5L('!A
M9')E(&YO(';A;&ED;W,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("))
M1"!D92!A<V]C:6%D;R!N;R!VX6QI9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N
M(@IM<V=S='(@(D/S9&EG;R!D92!P<F]D=6-T;R!N;R!VX6QI9&\N(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN
M=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E!R;W1O8V]L;R!N;R!VX6QI9&\N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS(&QI8B].
M970O4TU3+W=I;E]H='1P+G!H<#HW,0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R(")$97-T:6YA=&%R:6\@;F\@=N%L:61O.B!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P.#`@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*
M;7-G<W1R(")/8FIE=&\@8V]M<&%R=&ED;R!N;R!VX6QI9&\N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D1I<F5C8VGS;B!D96P@<F5M
M:71E;G1E(&YO(';A;&ED82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS
M9W-T<B`B1&%T;W,@=6YI8V]D92!N;R!VX6QI9&]S+B(*"B,Z(&-O;F9I9R\N
M8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(DEN=F5N=&%R:6\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S
M='(@(DEN=F5R=&ER('-E;&5C8VGS;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.0IM<V=I9"`B27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B(*;7-G<W1R("))<N%N+"!297#Z8FQI8V$@27-LX6UI
M8V$@9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3@*;7-G:60@(DER87$B"FUS9W-T<B`B27)A<2(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B
M27)E;&%N9"(*;7-G<W1R("))<FQA;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B27-L82!D
M92!-86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B0F]R<F%S
M8V%S(&%I<VQA9&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R865L
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES
M<W5E<B(*;7-G<W1R(")%;6ES;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")#
M=7)S:79A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(Q"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,*;7-G
M:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#(@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(D5N
M97)O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3(U"FUS9VED(")*87!A;B(*;7-G<W1R(")*87#S;B(*"B,Z(&-O;F9I
M9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M
M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;V[I<R`H25-/+3(P,C(M2E`I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S
M='(@(DIE<G-E>2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F3A;B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY
M(@IM<V=S='(@(DIU;&EO(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:6\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED
M(")*=7-T:69Y(@IM<V=S='(@(DIU<W1I9FEC87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B
M2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B06QI;F5A<B!A;"!C96YT<F\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(DIU<W1I9FEC87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(D%L:6YE87(@
M82!L82!I>G%U:65R9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R(")!;&EN96%R(&$@;&$@9&5R96-H82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-@IM<V=I9"`B2V%Z86MH
M<W1A;B(*;7-G<W1R(")+87IA:VAS=&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B
M"FUS9W-T<B`BOT-O;G-E<G9A<B!E;"!O<FEG:6YA;#\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8*;7-G:60@(DME
M;GEA(@IM<V=S='(@(DME;GEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B16P@<V5R=FED;W(@2V5R8F5R;W,@:&$@<F5C
M:&%Z861O(&QA(&%U=&5N=&EF:6-A8VGS;BXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DYO
M=F%T;W,@9&5L($ME<FYE;"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D-R96%C:?-N(&1E
M(&-L879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED
M(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B2'5E;&QA(&1I9VET86P@9&4@
M;&$@8VQA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B5&%M8?%O(&1E(&-L879E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*
M;7-G<W1R(")4:7!O(&1E(&-L879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")5<V\@9&4@
M;&$@8VQA=F4Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS
M9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(DQA(&-L879E('EA(&5X:7-T92!E;B!E;"!S97)V:61O
M<B!D92!C;&%V97,@</IB;&EC;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B3FGQ;W,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD*;7-G:60@(DMI
M<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R"FUS9VED(")+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")#;W)E82P@
M4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@9&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,*;7-G:60@(DMO
M<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R(")#;W)E82P@4F5P^F)L:6-A(&1E
M(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R
M96%N("A%54,M2U(I(@IM<V=S='(@(D-O<F5A;F\@*$550RU+4BDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0*;7-G
M:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C<*;7-G:60@(DMY<F=Y>G-T
M86XB"FUS9W-T<B`B2WER9WEZ<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?1&ES=')I8G5C
M:?-N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B
M3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86\L(%)E</IB;&EC
M82!$96UO8W+A=&EC82!0;W!U;&%R(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D-U87)T;R!M96YG=6%N
M=&4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA<W0@
M4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(MIL=&EM;R!C86UB:6\@9&4@8V]N
M=')A<V7Q82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")#=6%R
M=&\@;65N9W5A;G1E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BVFQT:6UA(&%C='5A;&EZ86-I
M\VXZ(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+:;'1I;6$@<V5S:?-N
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("+:;'1I
M;6$@<V5S:?-N.B`E<R!D97-D92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(MIL=&EM
M82!S97-I\VXZ($YU;F-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30V"FUS9VED("),871V:6$B"FUS9W-T<B`B3&%T
M=FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B
M"FUS9W-T<B`B3&5Y97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")$
M:7-T<FEB=6-I\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M(@IM<V=S='(@(D1E:F%R(&5N(&)L86YC;R!P87)A(&5L:6UI;F%R(&5L(&)O
M<F1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQE8F%N;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*
M;7-G:60@(DQE9G0B"FUS9W-T<B`B27IQ=6EE<F1A(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(D-A
M8F5C97)A(&EZ<75I97)D82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,#DW
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")686QO<F5S(&1E(&QA(&EZ
M<75I97)D82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E
M;"(*;7-G<W1R(").:79E;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),
M:6)E<FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S
M='(@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI96-H=&5N
M<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(DQI9V5R82!L;&]V:7IN82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN
M(@IM<V=S='(@(DQL=79I82!L:6=E<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L
M>2(*;7-G<W1R("),;'5V:6$@;&EG97)A(&UA='5T:6YA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT
M(%)A:6X@3&%T92(*;7-G<W1R("),;'5V:6$@;&EG97)A('9E<W!E<G1I;F$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B06=U86-E<F\@;&EG
M97)O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(DQL
M=79I87,@>2!T<G5E;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B3F5V
M861A('-U879E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DQI
M9V5R;R!A9W5A8V5R;R!D92!N:65V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B0VAA<V-A<G)I;&QO
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS
M9W-T<B`B5NUN8W5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z
M(@IM<V=S='(@(D5L(';M;F-U;&\@87!U;G1A(&$Z(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B
M5FEN8W5L87(@9&ER96-C:?-N(&1E(&-O<G)E;R!A(&QA('#A9VEN82!D92!C
M;VUP;W-I8VGS;B!A;"!M;W-T<F%R(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL
M=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G<W1R(")6
M[6YC=6QO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B
M3&EN=7@@0V]O:VEE(@IM<V=S='(@(D-O;VMI92!,:6YU>"(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<B(*;7-G<W1R("),:7-T87(@+2!E;"!U<W5A<FEO('!U961E
M(&5X86UI;F%R(&QA(&-A<G!E=&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),:7-T87(@8F%S
M97,@9&4@9&%T;W,B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM
M<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("),:7-T87(@=&5M87,@
M9&4@87EU9&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),
M:7-T(%1A8FQE<R(*;7-G<W1R("),:7-T87(@=&%B;&%S(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-C`Q"FUS9VED("),:7-T+4%R8VAI=F4B
M"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A
M9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES="U(
M96QP(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-C`S"FUS9VED
M("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.3D*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B
M3&ES="U/=VYE<B(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C8P
M,`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W0M4&]S="(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y.`IM<V=I9"`B3&ES="U3=6)S
M8W)I8F4B"FUS9W-T<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HU.3<*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B
M"FUS9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B2&$@9F%L;&%D;R!E;"!L:7-T861O(&1E
M(&QA<R!S97-I;VYE<SH@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M(@IM<V=S='(@(DAA(&9A;&QA9&\@96P@;&ES=&%D;R!D92!U<W5A<FEO<SH@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G
M:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D5L(&QI
M<W1A9&\@9&4@=7-U87)I;W,@97-TX2!D97-H86)I;&ET861O+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G
M<W1R("),:71E<F%T=7)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B
M3&ET=6%N:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H
M<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),97EE;F1O+BXN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C
M86P@=&EM93H@(@IM<V=S='(@(DAO<F$@;&]C86PZ("(*"B,Z(&-O;F9I9R\N
M8F%K+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B261I;VUA('D@:&]R82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S(@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4W,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B56)I8V%C:?-N(@H*(SH@
M;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`T
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,R!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ
M-0IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(DEN:6-I87(@<V5S:?-N(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@
M<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(E)E9VES=')O(&1E(&QA
M<R!S97-I;VYE<R!D92!S:6YC<F]N:7IA8VGS;B!A;G1E<FEO<F5S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y.`IM<V=I9"`B3&]G(&]U
M="(*;7-G<W1R(")386QI<B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M,0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B26YI8VEA<B!S97-I\VXB"@HC.B!C
M;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN(%1A
M<VMS(@IM<V=S='(@(E1A<F5A<R!D92!I;FEC:6\@9&4@<V5S:?-N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB1F%L;/,@96P@:6YI8VEO(&1E('-E
M<VGS;B!P;W)Q=64@:6YT<F]D=6IO(&EN8V]R<F5C=&%M96YT92!S=2!N;VUB
M<F4@9&4@(@HB=7-U87)I;R!O(&-O;G1R87-E\6$N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@N<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")&
M86QL\R!E;"!I;FEC:6\@9&4@<V5S:?-N+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B5&5X=&\@8V]M
M<&QE=&\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO
M=F4B"FUS9W-T<B`B06UO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B0F%J82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B06QF
M86)E=&\@9W)I96=O(&5N(&UI;OIS8RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(D%L9F%B971O(&QA=&EN;R!E;B!M
M:6[Z<V,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R(").^FUE<F]S(')O;6%N;W,@96X@;6EN^G-C+B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U<F=O(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(D5L(&%D:G5N=&\@35,M5$Y%1B!N;R!C;VYT96[M82!D871O<RXB"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*
M;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S
M='(@(DUA8V%O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34S"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%C961O;FEA+"!!;G1I9W5A
M(%)E</IB;&EC82!9=6=O<VQA=F$@9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$*;7-G:60@(DUA9&%G87-C87(B
M"FUS9W-T<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:6$B"@HC.B!C;VYF:6<O
M+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R
M(")#;W)R96\B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B061M+B!C;W)R96\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B0W)E87(@7W;M
M;F-U;&\N+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA=VDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<*
M;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;&%S:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C0*;7-G:60@(DUA
M;&1I=F5S(@IM<V=S='(@(DUA;&1I=F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34T"FUS9VED(")-86QI(@IM<V=S
M='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C(*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D=E<W1I;VYA(&QA(&QI<W1A(&1E
M(&-A=&5G;W+M87,@8V]N(&QA('%U92!E=&EQ=65T87(@96QE;65N=&]S('D@
M;&]S(&-O;&]R97,@(@HB87-O8VEA9&]S(&$@9&EC:&%S(&-A=&5G;W+M87,N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-38*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87!A(&UA<#(T(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U
M97-T(&UA<"(*;7-G<W1R(")-87!A(&UA<'%U97-T(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N
M(@IM<V=S='(@(D-O<G)E<W!O;F1E;F-I87,@86QM86-E;F%D87,N(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM
M<V=S='(@(DUA<GIO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA
M<F=E;B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX."!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*;7-G:60@(DUA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")-87)C87(@8V]N(&QA
M<R!B86YD97)A<R!D92!,9>UD;R]3:6X@;&5E<B(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M-#,Q-"YP:'`Z-#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG
M+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUA<F-A<B!C;VX@;W1R
M87(@8F%N9&5R87,@*'`N92X@26UP;W)T86YT92]297-P;VYD:61O*2(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,@IM
M<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("))<VQA<R!-87)S:&%L
M;"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI8V$B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI
M;F<@9FEE;&1S(@IM<V=S='(@(D-A;7!O<R!C;VEN8VED96YT97,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C`*;7-G
M:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B
M36%U<FET:75S(@IM<V=S='(@(DUA=7)I8VEO(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R
M961I="XB"FUS9W-T<B`B4V%L9&\@;>%X:6UO('!E<FUI=&ED;RXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(E-E(&AA('-O8G)E
M<&%S861O(&5L(&[Z;65R;R!MX7AI;6\@9&4@<&%R=&5S(&1E(&UE;G-A:F4N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UP+B!MX7AI;6$@^FQT:6UA
M<R`R-"!H;W)A<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#4*;7-G
M:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7`N(&WA
M>&EM82#Z;'1I;6%S(#8@:&]R87,Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS
M9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@
M(D[Z;65R;R!MX7AI;6\@9&4@8FQO<75E<R!D96P@<&]R=&%L(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B
M"FUS9W-T<B`B3&]N9VET=60@;>%X:6UA(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-87EO(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,PIM
M<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I
M8VEN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B36EE;6)R;W,B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`B1F]R;6%T;R!D96P@;65N^CHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C
M96QL<R(*;7-G<W1R(")#;VUB:6YA<B!C96QD87,B"@HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(DUE;G-A:F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q
M-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T
M('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R
M:69I960N(@IM<V=S='(@(B(*(E-E(&AA(&-O;7!R;V)A9&\@8V]R<F5C=&%M
M96YT92!E;"!M96YS86IE('!E<F\@;F\@<V4@<'5E9&4@=F5R:69I8V%R(&5L
M("(*(F-E<G1I9FEC861O(&1E;"!F:7)M86YT92XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I
M<F5D+B(*;7-G<W1R(")-96YS86IE(&-A9'5C861O+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P
M,@IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@;65N<V%J
M92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A
M=&AE<B(*;7-G<W1R(")4:65M<&\@9&4@365T87(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")";&]Q=64@365T87(@;F\@9&ES<&]N:6)L92XB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB0FQO<75E($UE=&%R(&YO
M(&1I<W!O;FEB;&4N(%-E(&AA;B!R96=I<W1R861O(&QO<R!D971A;&QE<R!P
M87)A(&5L("(*(F%D;6EN:7-T<F%D;W(N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C
M=&5D+B(*;7-G<W1R(").;R!E<W3A(&-O;F5C=&%D82!L82!-971A<D1"(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M(")-Z71O9&\B"@HC.B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP.C$Q-R!L:6(O
M2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")%;"!MZ71O
M9&\@7"(E<UPB(&YO(&5S=.$@9&5F:6YI9&\B"@HC.B!L:6(O2&]R9&4O4E!#
M+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@
M9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B3>ET;V1O(&YO
M(&1E9FEN:61O+B!-Z71O9&\@;&QA;6%D;SH@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-PIM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DWI=')I8V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8*;7-G:60@(DUE>&EC
M;R(*;7-G<W1R(")-Z6II8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX-0IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R;VYE<VEA+"!%<W1A9&]S($9E
M9&5R861O<R!D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D5N(&UE
M9&EO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5&EP;R!-:6UE(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R(")496UP+B!M[6XN(&QA<R#Z;'1I;6%S(#(T(&AO<F%S
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E
M;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<"X@;>UN+B!L87,@^FQT
M:6UA<R`V(&AO<F%S.B`B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT
M,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B5&]D87;M82!N;R!H82!E>'!I<F%D;R!L82!A;G1I
M9_QE9&%D(&WM;FEM82!D92!L82!C;VYT<F%S9?%A(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER<F]R(@IM
M<V=S='(@(E)E9FQE:F%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q
M"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUI<V-E;.%N96$B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,"!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B4&%Q=65T92!014%2($A45%!?4F5Q=65S
M="!D97-A<&%R96-I9&\N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D9A;'1A(&QA(&-O;F9I9W5R86-I
M\VXN(%1I96YE('%U92!G96YE<F%R;&$@86AO<F$@<VD@9&5S96$@=71I;&EZ
M87(@97-T82`B"B)A<&QI8V%C:?-N+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N
M(@IM<V=S='(@(DE$(&1E(&UE;G-A:F4@9&5S87!A<F5C:61O+B(*"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(E!A
M<75E=&4@4$5!4B!-86EL(&1E<V%P87)E8VED;RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R("))1"!D92!S97-I\VX@9&5S87!A<F5C:61O+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*
M;7-G:60@(DUO(@IM<V=S='(@(DQU;B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")#
M;W)R96\@;?-V:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HW,`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)A9&\B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M(")392!H82!M;V1I9FEC861O(&QA(&9E8VAA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-
M;V1I9GD@55),(@IM<V=S='(@(DUO9&EF:6-A<B!54DPB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R
M(")-\V1U;&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(DUO;&1A=FEA+"!297#Z8FQI8V$@9&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO;F%C;R(*
M;7-G<W1R(")-\VYA8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-38*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO
M;F=O;&EA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#0*;7-G:60@(DUO
M;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUE<R!Y(&'Q;R(*"B,Z(&QI8B](;W)D
M92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B
M365N<W5A;&UE;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO
M;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(D9A<V5S
M(&1E(&QA(&QU;F$B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL
M92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G
M<W1R(")392!H86X@96YC;VYT<F%D;R!MX7,@8V%M<&]S(&5N(&QA(&SM;F5A
M("5D('%U92!L;W,@)60@97-P97)A9&]S+B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R;V-C;R(*
M;7-G<W1R(")-87)R=65C;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@
M(D9U;F1A;65N=&%L;65N=&4@9&5S<&5J861O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U
M9'DB"FUS9W-T<B`B1G5N9&%M96YT86QM96YT92!N=6)O<V\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B1G5N9&%M96YT86QM96YT
M92!N=6)O<V\@>2!V96YT;W-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R
M(")&=6YD86UE;G1A;&UE;G1E('-O;&5A9&\B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM
M<V=S='(@(D1E<W!L87IA<B!H86-I82!A8F%J;R(*"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B1&5S<&QA>F%R(&$@;&$@:7IQ=6EE<F1A(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO=F4@
M4FEG:'0B"FUS9W-T<B`B1&5S<&QA>F%R(&$@;&$@9&5R96-H82(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS9VED(")-
M;W9E(%5P(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A<G)I8F$B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-
M;W9E(&1O=VXB"FUS9W-T<B`B1&5S<&QA>F%R(&AA8VEA(&%B86IO(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-2!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(D1E<W!L87IA<B!H86-I82!A<G)I8F$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C@*;7-G:60@(DUO
M>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES
M=',B"FUS9W-T<B`B3&ES=&%S(&1E<W!L96=A8FQE<R!M=6QT:2UN:79E;"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4Y"FUS
M9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B36%P82!52R!M^FQT:7!L
M92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L
M92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?-N(&WZ;'1I<&QE(@H*(SH@
M8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!
M8V-O=6YT(@IM<V=S='(@(DED96YT:61A9"(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R(")-:2!I9&5N=&ED860B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N
M<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36D@<&]R=&%L(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C0R"FUS9VED(")->2!0;W)T
M86P@3&%Y;W5T(@IM<V=S='(@(D1I<W1R:6)U8VGS;B!D92!M:2!P;W)T86PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-34*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D\L($Y/(&5S=&]Y(&1E(&%C
M=65R9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S='(@(DYO
M;6)R92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86UI8FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X"FUS
M9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB"FUS
M9W-T<B`B3F5P86PB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DAO
M;&%N9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B
M06YT:6QL87,@2&]L86YD97-A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(")5
M4DP@8F%S92!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@T"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M;7-G<W1R(")54DP@9&4@86YU;&%C:?-N(&1E($-!(&1E($YE='-C87!E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C
M87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B55),(&1E('!O;.UT:6-A<R!D
M92!#02!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(")5
M4DP@9&4@<F5N;W9A8VGS;B!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N
M(%523"(*;7-G<W1R(")54DP@9&4@86YU;&%C:?-N(&1E($YE='-C87!E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").;VUB<F4@9&4@<V5R=FED
M;W(@4U-,(&1E($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B
M"FUS9W-T<B`B0V]M96YT87)I;R!D96P@8V5R=&EF:6-A9&\@9&4@3F5T<V-A
M<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4:7!O(&1E(&-E
M<G1I9FEC861O(&1E($YE='-C87!E(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(E)E9"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I
M<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(").=6YC82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,`IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R(").=65V82!#86QE9&]N:6$B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B
M3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYU979A(&-A=&5G;W+M82(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B
M3'5N82!N=65V82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@
M(DYU979O(&YO;6)R92!D92!U<W5A<FEO("AO<&-I;VYA;"DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(DYU979A(%IE;&%N9&$B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R
M9"(*;7-G<W1R(")#;VYT<F%S9?%A(&YU979A(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("),82!N=65V82!C;VYT
M<F%S9?%A(&5X<&ER87+A(&5L("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"XB"FUS9W-T<B`B3&%S(&-O;G1R87-E\6%S(&YO(&-O:6YC:61E;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS
M9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYU979A('9E;G1A
M;F$@*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN
M<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYO=&EC:6%S(@H*
M(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(D<N(&1E(&YO=&EC:6%S(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B4VEG=6EE;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED
M(").97AT(#0@4&AA<V5S(@IM<V=S='(@(E!R\WAI;6%S(#0@9F%S97,B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(D]P8VEO
M;F5S('-I9W5I96YT97,B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P
M,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4VEG=6EE;G1E/B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-`IM<V=I9"`B
M3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,0IM<V=I9"`B3FEG97(B
M"FUS9W-T<B`B3FEG97(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG
M97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G
M:60@(DYI9VAT(@IM<V=S='(@(DYO8VAE(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E(@IM<V=S
M='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS
M9W-T<B`B3F\@:&%Y(&1A=&]S(&1E(&-O;F9I9W5R86-I\VX@<&%R82!M;W-T
M<F%R(&1I9F5R96YC:6%S+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ
M,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E3
M3R!I;6%G97,N(@IM<V=S='(@(DYO('-E(&1I<W!O;F4@9&4@97-T<F%T96=I
M82!D92!E;&%B;W)A8VGS;B!D92!I;>%G96YE<R!)4T\N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H
M('1E;7!L871E+B(*;7-G<W1R(").;R!H87D@<&QA;G1I;&QA(&1E(&QO=&5S
M(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@
M(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM
M<V=S='(@(DYO(&AA>2!B;&]Q=65S(&5N(&QA('!O<VEC:?-N(&EN9&EC861A
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O('5N(&YO;6)R92!D92!A
M9V5N9&$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@34-!3"XB"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R
M(")3:6X@8V%M8FEO<RXB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U
M-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B3F\@<V4@<'5E9&5N(&'Q861I<B!D97-C96YD
M:65N=&5S(&$@97-T92!P<FEV:6QE9VEO+B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3<X(&QI8B](;W)D92YP:'`Z-3$W(&QI8B](;W)D92]5=&EL+G!H<#HW.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").;R!S92!H82!E<W!E
M8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A("5S
M+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C@*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G
M<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N
M9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@1E10+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HV.#0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").;R!S92!H82!E<W!E
M8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&
M4R!P;W(@4U%,+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<U,PIM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B(@HB3F\@<V4@:&$@97-P96-I9FEC
M861O(&EN9F]R;6%C:?-N(&1E(&-O;F9I9W5R86-I\VX@<&%R82!61E,@<&]R
M(&%R8VAI=F\@4U%,+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3F\@
M<75E9&$@<V%L9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S
M='(@(DYO('-E(&AA(&EN=')O9'5C:61O(&5L(&1E<W1I;F\N(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.CDQ.`IM<V=I9"`B3F\@9FEL92!U<&QO861E
M9"(*;7-G<W1R(").;R!S92!H82!C87)G861O(&YI;F?Z;B!A<F-H:79O(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F
M;W5N9"XB"FUS9W-T<B`B3F\@<V4@:&%N(&5N8V]N=')A9&\@:6-O;F]S+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V"FUS
M9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(DYO('-E(&AA(&1E
M9FEN:61O(&QA('5B:6-A8VGS;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3F\@<V4@:&$@9&5F:6YI9&\@;&$@=6)I8V%C:?-N+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE
M<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(DYO('-E(&AA(&EN=')O9'5C:61O
M('5N(&UE;G-A:F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYO
M('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N;VUB<F4N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P
M96-I9FEE9"XB"FUS9W-T<B`B3F\@<V4@:&$@97-P96-I9FEC861O('5N(&[Z
M;65R;RXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").;R!O9F5N<VEV87,B"@HC
M.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DYO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@
M875T96YT:69I8V%C:?-N($A45%`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA
M<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!
M4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F\@<V4@:&$@:6YT<F]D=6-I
M9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E;G1I9FEC86-I\VX@24U!
M4"XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q
M82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW-0HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-PIM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P
M87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!D92!I;FEC:6\N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO
M('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T
M96YT:69I8V%C:?-N(%!!4U-71"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N
M<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S92!H82!I;G1R;V1U8VED;R!U
M;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!334(N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+B(*;7-G<W1R("(B"B).;R!S92!H82!I;F1I8V%D;R!V[6$@
M9&4@86-C97-O(&$@;&]S(&)I;F%R:6]S($]P96Y34TPN(%!A<F$@=')A8F%J
M87(@8V]N("(*(F1A=&]S(%!+0U,@,3(@:&%C96X@9F%L=&$@;&]S(&)I;F%R
M:6]S($]P96Y34TPN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")3
M:6X@86QT87,@<&5N9&EE;G1E<RXB"@HC.B!L:6(O5D93+G!H<#HW-C8*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B0V%R96-E(&1E('%U;W1A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E-I;B!R87EA<R(*"B,Z
M(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E
M8VEF:65D+B(*;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@=6X@<V5P
M87)A9&]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DYI;F=U
M;F\B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-C`P"FUS9VED(").;R!S=6-H(&9I
M;&4B"FUS9W-T<B`B3F\@97AI<W1E(&5L(&%R8VAI=F\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(DYO('-E
M(&1I<W!O;F4@9&4@=6X@9&ER96-T;W)I;R!D92!A;&UA8V5N86UI96YT;R!T
M96UP;W)A;"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").;R!S92!H
M82!E;G9I861O(&5L(&YO;6)R92!D92!U<W5A<FEO('DO;R!L82!C;VYT<F%S
M9?%A+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@
M(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(DYO('-E(&AA
M;B!D979U96QT;R!D871O<R!834P@=N%L:61O<R(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-S0@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3DU"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B4VEN('9A
M;&]R97,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3F\@<V4@96YC
M;VYT<O,@;&$@=F5R<VGS;B!E;B!L82!C;VYF:6=U<F%C:?-N(&]R:6=I;F%L
M+B!296=E;F5R87(@;&$@(@HB8V]N9FEG=7)A8VGS;BXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(W"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"B).;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N(&QA
M(&-O;F9I9W5R86-I\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C:?-N+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-R!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*;7-G:60@(DYO;F4B"FUS
M9W-T<B`B3FEN9W5N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS
M9W-T<B`B3FEN9W5N;R`H=7-O(&EM<&SM8VET;RDB"@HC.B!C;VYF:6<O+F)A
M:R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R(").\W)D:6-O("A)4T\M.#@U.2TQ,"DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(*;7-G:60@(DYO
M<F9O;&L@27-L86YD(@IM<V=S='(@(DES;&$@9&4@3F]R9F]L:R(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G
M:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-F97)I;R!N
M;W)T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(DES;&%S($UA<FEA;F%S(&1E;"!.;W)T92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-@IM<V=I9"`B3F]R=V%Y
M(@IM<V=S='(@(DYO<G5E9V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(DYO(&1E<W!UZ7,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($)E9F]R92(*;7-G<W1R(").;R!A;G1E<R(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z-#(Q"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3F\@97,@
M=6X@9&ER96-T;W)I;R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY
M-0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")3:6X@9&5S87)R
M;VQL87(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")3:6X@97-T86)L96-E
M<B(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,#@@;&EB+U9&
M4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,@HC.B!L:6(O5D93+G!H<#HR-CD@
M;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93+G!H<#HS
M,38*(SH@;&EB+U9&4RYP:'`Z,S,S(&QI8B]61E,N<&AP.C,V-B!L:6(O5D93
M+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI8B]61E,N<&AP.C4W-"!L
M:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y"B,Z(&QI8B](;W)D92]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S:6]N2&%N9&QE
M<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<U
M(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R(").;R!E<W3A('-O<&]R=&%D;RXB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDP."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(T-`HC.B!C;VYF:6<O+F)A:R]H;V]K<RYP:'`N9&ES=#HQ,#4X(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS
M9W-T<B`B3F]T87,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z
M,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R
M(").;R!H87D@;F%D82!V:7-U86QI>F%B;&4L(')E=')O8V5D82XB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B
M"FUS9W-T<B`B3F]V:65M8G)E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R(").^FUE<F\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B
M"FUS9W-T<B`B3OIM97)O(&1E(&-A<F%C=&5R97,B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,V.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS
M9W-T<B`B3OIM97)O(&1E(&-O;'5M;F%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$S-C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D[Z
M;65R;R!D92!F:6QA<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D
M871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*(DYO('-E
M(&AA;B!E<W!E8VEF:6-A9&\@;OIM97)O<R!A(&%C='5A;&EZ87(@96X@;&$@
M;&ES=&$@9&4@9&ES=')I8G5C:?-N+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B06-E
M<'1A<B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE=&\B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B0W)E861O<B!D92!O8FIE=&]S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B3V-T=6)R92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')A<B!O9F5N
M<V%S(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`B3V9I8VEN82(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O
M<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("),82!C;VYT<F%S9?%A
M(&%N=&EG=6$@>2!L82!N=65V82!D96)E;B!S97(@9&ES=&EN=&%S+B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A
M<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E\6$@86YT:6=U82(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("),82!C;VYT<F%S9?%A(&%N=&EG
M=6$@;F\@97,@8V]R<F5C=&$N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S='(@(D]M
MX6XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G
M:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M(@IM<V=S='(@(E/S;&\@;&]S('-E<G9I9&]R97,@24U!4"!S;W!O<G1A;B!L
M87,@8V%R<&5T87,@8V]M<&%R=&ED87,N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R(")3\VQO(&]F96YS:79A<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(E/S;&\@<V4@<&5R;6ET
M92!U;F$@9&ER96-C:?-N(&1E(&-O<G)E;RXB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y
M<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W
M;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(E/S
M;&\@96P@<')O<&EE=&%R:6\@;R!U;B!A9&UI;FES=')A9&]R(&1E('-I<W1E
M;6%S('!U961E(&-A;6)I87(@;&$@(@HB<')O<&EE9&%D(&\@;&]S('!R:79I
M;&5G:6]S(&1E('!R;W!I971A<FEO(&1E('5N(')E8W5R<V\@8V]M<&%R=&ED
M;R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")!8G)I<B!E;B!U;F$@;G5E=F$@=F5N=&%N82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R(")%<G)O<B!/<&5N4U-,.B!.;R!S92!P=65D96X@97AT<F%E<B!D
M871O<R!D92!L82!P87)T92!3+TU)344@9FER;6%D82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G
M:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M06)R:7(@97-T92!V[6YC=6QO(&5N('5N82!V96YT86YA(&YU979A(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(E-I<W1E;6$@;W!E<F%T:79O(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U-0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M(")/<&-I;VYE<R(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I
M;VYS(&9O<B`E<R(*;7-G<W1R(")/<&-I;VYE<R!D92`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R
M9&5R960@3&ES="(*;7-G<W1R("),:7-T82!O<F1E;F%D82(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB
M"FUS9W-T<B`B3W)G86YI>F%C:?-N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T
M<B`B56YI9&%D(&]R9V%N:7IA=&EV82(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/
M<F=A;FEZ86-I\VXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I
M9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B4&QA
M;G1I;&QA(&1E(&%P;&EC86-I\VX@;W)I9VEN86PB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(E!L86YT:6QL87,@;W)I9VEN86QE
M<R!E;B`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")/
M=')O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG
M+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C$Q-B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,C4*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R\N8F%K
M+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB
M"FUS9W-T<B`B3W1R82!I;F9O<FUA8VGS;B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(E!R:79I;&5G:6]S(&1E;"!P<F]P:65T87)I;R(*"B,Z(&QI8B](;W)D
M92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),82!A=71E;G1I9FEC86-I\VX@
M4$%-(&YO(&5S=.$@9&ES<&]N:6)L92XB"@HC.B!L:6(O3F5T+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM
M<V=S='(@(E!%05(Z.DUO=&]R(&1E(&-O<G)E;R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R
M92(*;7-G<W1R(")&:7)M82!D:6=I=&%L(%!'4"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*
M;7-G<W1R(")$871O<R!C:69R861O<R!C;VX@4$=0(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS
M9W-T<B`B0VQA=F4@4$=0('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(D1A=&]S(&9I<FUA9&]S+V-I9G)A9&]S(&-O;B!01U`B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@(E!(4"!#;V1E(@IM<V=S
M='(@(D/S9&EG;R!02%`B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G
M:60@(E!(4"!3:&5L;"(*;7-G<W1R("));G3I<G!R+B!02%`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@
M3&EG:'0@4F%I;B(*;7-G<W1R("),;&]V:7IN82!V97-P97)T:6YA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@
M(E!-(%)A:6XB"FUS9W-T<B`B3&QU=FEA('9E<W!E<G1I;F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@
M4VAO=V5R<R(*;7-G<W1R(")#:&%P87)R;VYE<R!V97-P97)T:6YO<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(DYI979E('9E<W!E<G1I;F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(D%G=6%C97)O(&1E(&YI979E('9E<W!E
M<G1I;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E-O;"!V97-P97)T:6YO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G
M:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(D)O<G)A<V-A<R!V97-P97)T:6YA
M<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(DYO('-E(&5N8W5E;G1R
M82!L82!E>'1E;G-I\VX@4$]325@B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G
M:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B26YTZ7)P<BX@4%](4"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B36%R9V5N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W"FUS9VED(")086MI
M<W1A;B(*;7-G<W1R(")086MI<W3A;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30*;7-G:60@(E!A;&%U(@IM<V=S
M='(@(E!A;&%U(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/
M8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;F]S+"!497)R:71O<FEO<R!/8W5P
M861O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X,@IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%MX2(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-0IM<V=I
M9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087#Z82!.=65V82!'=6EN
M96$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DU"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED
M(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E!A<F-I86QM96YT92!N=6)O<V\B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<Y"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C$U,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q.`HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN
M<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")#;VYT<F%S
M9?%A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3&$@
M8V]N=')A<V7Q82!S92!C86UB:6%D;R!C;W)R96-T86UE;G1E+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@
M:6YC;W)R96-T(@IM<V=S='(@(D-O;G1R87-E\6$@:6YC;W)R96-T82(*"B,Z
M(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R
M9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")(87D@<75E(&EN=')O9'5C:7(@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A
M=71E;G1I9FEC86-I\VX@4D%$2553+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R(")#;VYT<F%S9?%A(&-O;B!C;VYF:7)M86-I\VXB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G
M<W1R(")#;VYT<F%S9?%A.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(D-O;G1R87-E\6$Z
M("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS
M9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B3&%S(&-O;G1R
M87-E\6%S('1I96YE;B!Q=64@8V]I;F-I9&ER+B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")096=A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*
M;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E!E9V%R(&1E
M;"!P;W)T87!A<&5L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E;M82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG
M(%-I9VYU<',Z(@IM<V=S='(@(D%L=&%S('!E;F1I96YT97,Z(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B
M1V5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0;W)C96YT86IE(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*
M;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R
M(")296%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O(@H*(SH@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED(")097)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(K]2
M96%L:7IA<B!O<&5R86-I;VYE<R!D92!M86YT96YI;6EE;G1O(&%L(&EN:6-I
M87(@<V5S:?-N/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS
M9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!R:79I;&5G:6\B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E
M<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(").;R!S92!H
M82!E;&EM:6YA9&\@96P@<')I=FEL96=I;R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C8P,PIM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B4')I=FEL96=I;R!D96YE9V%D;R(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R(")0<FEV:6QE9VEO<R(*"B,Z(&%D;6EN+W!E
M<FUS+V%D9&-H:6QD+G!H<#HV,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]I;F1E
M>"YP:'`Z,C(*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E('!R:79I;&5G:6]S(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?-N('!E<G-O;F%L(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S"FUS
M9VED(")097)U(@IM<V=S='(@(E!E<OHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B36%S8V]T87,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YA<R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R(")496SI9F]N;R(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H
M<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]G<F%F[6%S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I
M9"`B4&EX96QS(@IM<V=S='(@(E#M>&5L97,B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B5/-P:6-O
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*
M;7-G<W1R(")0=6QS92!E;B!U;F$@8V5L9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#HB"FUS9W-T<B`B0V]N9FER;64@<75E(&1E<V5A(&5L:6UI;F%R(&5S
M=&4@96QE;65N=&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@
M(D-O;F9I<FUE('%U92!D97-E82!E;&EM:6YA<B!E;"!V[6YC=6QO(&$@97-T
M92!E;&5M96YT;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B
M26YT<F]D=7IC82!U;B!M97,@>2!U;B!A\6\N(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(DEN
M=')O9'5Z8V$@96P@;F]M8G)E(&1E(&QA(&YU979A(&-A=&5G;W+M83HB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B26YT<F]D=7IC82!U;F$@
M9&ER96-C:?-N($E0(';A;&ED82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C8T,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B26YT
M<F]D=7IC82!U;F$@9F5C:&$@=N%L:61A+"!C;VUP<G5E8F4@96P@;OIM97)O
M(&1E(&3M87,@9&5L(&UE<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0T
M-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B
M26YT<F]D=7IC82!U;F$@:&]R82!VX6QI9&$N(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]P;W)C:6]N92!U
M;B!R97-U;65N(&1E;"!P<F]B;&5M82XB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G
M:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M(@IM<V=S='(@(DEN=')O9'5Z8V$@<W4@;F]M8G)E(&1E('5S=6%R:6\@>2!C
M;VYT<F%S9?%A+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E
M;2XB"FUS9W-T<B`B(@HB3&5A(&5L('1E>'1O('-I9W5I96YT92X@1$5"12!A
M8V5P=&%R(&QO<R!TZ7)M:6YO<R!S:2!Q=6EE<F4@=7-A<B!E;"!S:7-T96UA
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P
M"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM
M<V=S='(@(DEN=')O9'5Z8V$@96P@;G5E=F\@;F]M8G)E(&1E(&-A=&5G;W+M
M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#@*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQO;FEA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R
M(")0;VSM=&EC82(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T
M.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B16YC=65S=&%S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,PIM<V=I
M9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B4&]S:6-I
M\VX@9&4@;&$@:6UA9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@
M=&%B;&4B"FUS9W-T<B`B4&]S:6-I\VX@9&4@;&$@=&%B;&$B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4Q"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B16YV:6%R(&$@97-T
M82!C87)P971A("AN;R!O8FQI9V%D;R!P;W(@24U!4"DB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ("(*;7-G<W1R(")0<F5C:7!I=&%C:6]N97,@9&4@;&$H<RD@^FQT
M:6UA*',I("5S(&AO<F$H<RDZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B
M"FUS9W-T<B`B4')O8F%B:6QI9&%D/&)R("\^9&4@<')E8VEP:71A8VGS;B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0<F5F<U]L9&%P.B!N;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M3$1!4"!R97%U97)I9&$N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN
M<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ
M(&YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!D92!S97-I\VX@<F5Q=65R
M:61A+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")0<F5S
M<W5R92(*;7-G<W1R(")0<F5S:?-N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@
M(E!R97-I\VX@86P@;FEV96P@9&5L(&UA<CH@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R
M(")0<F5S:?-N.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")6
M:7-T82!P<F5V:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*;7-G:60@(E!R979I97<@=&AE(&EM
M86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")6:7-T82!P<F5V:6$@9&4@
M;&$@:6UA9V5N(&5N('5N82!N=65V82!V96YT86YA(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HS-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C`*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N97,@86YT
M97)I;W)E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(DEM<')I
M;6ER(&1O8W5M96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B0VQA=F4@<')I=F%D82(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS
M9W-T<B`BOU!R;V)L96UA<S\B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ
M,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I
M<&-I\VX@9&5L('!R;V)L96UA(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN
M<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]Y96-T
M;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-@IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B5&5X=&\@9&5L(&EN9'5C=&]R(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM
M<V=S='(@(D-L879E(%!'4"!P^F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM
M<V=S='(@(D%L9V]R:71M;R!D92!C;&%V92!P^F)L:6-A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF
M;R(*;7-G<W1R("));F9O<FUA8VGS;B!D92!C;&%V92!P^F)L:6-A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(").;R!S92!G96YE<F%R;VX@8V]R<F5C=&%M96YT92!L87,@8VQA=F5S
M(%#Z8FQI8V$O4')I=F%D82XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0=65R=&\@4FEC;R(*;7-G
M<W1R(")0=65R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T
M,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T<B`B3&EM
M<&EA<B!M96YS86IE<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.38*;7-G:60@(E%A=&%R(@IM<V=S='(@(E%A=&%R
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8T"FUS9VED(")1=65R>2(*;7-G
M<W1R(")#;VYS=6QT82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`IM
M<V=I9"`B475O=&$B"FUS9W-T<B`B475O=&$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B
M;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")#;&%V92!24T$@</IB;&EC82`H
M)60@8FET*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8T"FUS9VED(")2
M861I;R!S96QE8W1I;VXB"FUS9W-T<B`B0F]T\VX@9&4@;W!C:?-N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E)A:6XB"FUS9W-T<B`B3&QU=FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B3&QU=FEA(&UA='5T:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("),
M;'5V:6$@=F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")!
M9W5A8V5R;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(DQL=79I82!Y
M($YI979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("),;'5V:6$@82!.
M:65V92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD
M;VT@1F]R='5N92(*;7-G<W1R(")2=65D82!D92!L82!F;W)T=6YA(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E)A
M>O-N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@
M(E)E860B"FUS9W-T<B`B)FYB<W`[3&5E<B9N8G-P.R(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
M3&5E<B!M96YS86IE<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("*_
M16QI;6EN87(@<F5A;&UE;G1E("5S/R!%<W1A(&]P97)A8VGS;B!N;R!S92!P
M=65D92!D97-H86-E<BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B(@HBOT5L:6UI;F%R(')E86QM96YT92!L;W,@
M9&%T;W,@9&5L('5S=6%R:6\@)7,_($5S=&$@;W!E<F%C:?-N(&YO('-E('!U
M961E("(*(F1E<VAA8V5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(E9U96QV92!A(')E86QI>F%R(&QA(/IL=&EM82!A8V-I
M\VXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!8W1U86QI
M>F%R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED
M(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B06-T
M=6%L:7IA<B!E;&5M96YT;W,@9&4@;65N^B!D:6[A;6EC;W,Z(@H*(SH@8V]N
M9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O
M<G1A;"!6:65W.B(*;7-G<W1R(")!8W1U86QI>F%R('9I<W1A(&1E;"!P;W)T
M86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E
M>"(*;7-G<W1R(")296=E>"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C,Q
M"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(").879E9V%D
M;W(@9&4@<F5L86-I;VYE<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R(")2969R97-C87(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")/8G-E<G9A8VEO
M;F5S(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED
M(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")397)V:61O<F5S(')E;6]T;W,B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G
M<W1R(")54DP@<F5M;W1A("AH='1P.B\O=W=W+F5J96UP;&\N8V]M+VAO<F1E
M*3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E;6]V
M92(*;7-G<W1R(")1=6ET87(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")1=6ET87(@
M8FQO<75E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")1=6ET87(@8V]L
M=6UN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D5L:6UI
M;F%R(&9O<FUA=&\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B475I=&%R('!A<B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#$*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R(")%;&EM:6YA<B!G=6GS;B!G=6%R9&%D;R!D96P@9&ER96-T;W)I
M;R!T96UP;W)A;"!D96P@<V5R=FED;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO
M=F4@=&AE(@IM<V=S='(@(D5L:6UI;F%R("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")%;&EM
M:6YA<B!E<W1E(&YO9&\@9&5L(&1O8W5M96YT;R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(D5L:6UI;F%R('5S=6%R:6\B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(D5L:6UI;F%R('5S=6%R:6\Z("5S(@H*(SH@
M;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B3F\@<V4@<'5E9&4@<F5S<&]N9&5R(&$@;&$@<V]L:6-I='5D+B!#
M\V1I9V\@9&4@97)R;W(@9&5V=65L=&\Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O
M=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3F\@<V4@96YC;VYT<O,@96P@
M<V5R=FEC:6\@<V]L:6-I=&%D;RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$X-2!L
M:6(O2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E
M9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(").;R!S92!H82!E<W!E8VEF:6-A9&\@96P@7"(E<UPB(')E<75E
M<FED;R!E;B!L82!C;VYF:6=U<F%C:?-N(&1E("5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX-S0@;&EB+U9&4R]S<6PN<&AP.C8Y,"!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DYO('-E(&AA(&5S<&5C:69I8V%D;R!E;"!<(B5S7"(@<F5Q=65R:61O
M(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@5D93+B(*"B,Z(&QI8B](;W)D92]5
M=&EL+G!H<#HW.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M3F\@<V4@:&$@97-P96-I9FEC861O(&5L(%PB)7-<(B!R97%U97)I9&\@96X@
M;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E
M<BYP:'`Z,S,V"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")#86UP
M;R!N96-E<V%R:6\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S,Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C`@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R,0HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(DQI
M;7!I87(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I
M9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B3&EM<&EA<B!C;VYT<F%S9?%A
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B3&EM<&EA<B!C;VYT<F%S9?%A
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,
M87-T(%%U97)Y(@IM<V=S='(@(E)E<W1A=7)A<B#Z;'1I;6$@8V]N<W5L=&$B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<&AP<VAE;&PN<&AP
M.C<R(&%D;6EN+W-Q;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT<R(*;7-G
M<W1R(")297-U;'1A9&]S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U
M<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")296=R97-A<B!A(&]P8VEO;F5S(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y
M<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E)E97-C<FEB:7(@8V]N=')A<V7Q
M82!N=65V82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FGS;B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T
M<B`B4F5S=&%U<F%R(&-O;F9I9W5R86-I\VXB"@HC.B!C;VYF:6<O+F)A:R]P
M<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<R(*;7-G<W1R(")/<&-I;VYE<R!D92!E9&EC:?-N(&1E('1E>'1O(&5N
M<FEQ=65C:61O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED
M(")2:61D;&5S(@IM<V=S='(@(D-R:6)A<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B4FEG:'0B
M"FUS9W-T<B`B1&5R96-H82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`S
M"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B0V%B96-E<F$@9&5R96-H
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,#DY"FUS9VED(")2:6=H="!V
M86QU97,B"FUS9W-T<B`B5F%L;W)E<R!D92!L82!D97)E8VAA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X
M"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<&EE9&%D
M97,@9&4@7V9I;&$N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6YC:?-N(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y.`IM
M<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UA;NUA(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X
M,"(*;7-G<W1R(")':7)A<B`Q.#`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R
M(")':7)A<B!A(&QA(&EZ<75I97)D82(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,CD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G
M<W1R(")':7)A<B!A(&QA(&1E<F5C:&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O
M<&5R=&EE<R(*;7-G<W1R(")0<F]P:65D861E<R!D92!F:6QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM
M<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&EE9&%D97,@9&4@
M9FEL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R(")&:6QA<SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS
M9VED(")2=6QE<R(*;7-G<W1R(")287EA<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS
M9W-T<B`B07!A<F5C97+A;B!R87EA<R!E;G1R92!T;V1A<R!L87,@9FEL87,@
M>2!C;VQU;6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(D%P87)E8V5RX6X@<F%Y87,@
M<_-L;R!E;G1R92!L87,@8V]L=6UN87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")!<&%R96-E
M<N%N(')A>6%S('/S;&\@96YT<F4@;&%S(&9I;&%S(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(D5J96-U=&%R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M.0IM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(D9E9&5R86-I
M\VX@4G5S82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#`*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N9&$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(D9I<FUA(&-R:7!T
M;V=RX69I8V$@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R
M(")-96YS86IE(&-I9G)A9&\@96X@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3F\@97-TX2!D:7-P;VYI8FQE(&QA
M(&%U=&5N=&EF:6-A8VGS;B!305-,+B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES
M=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M(")-96YS+B!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R("));G3I<G!R+B!344PB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(W-`IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L
M=64@;&]O:W5P<R(*;7-G<W1R(")396YT96YC:6$@4U%,('!A<F$@8V]N<W5L
M=&%S(&1E('9A;&]R97,B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N
M9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`BR5A)5$\B"@HC.B!L:6(O87!I+G!H<#HQ-3,*
M;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B26YTZ7)P<BX@4U]13"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G
M:60@(E-A(@IM<V=S='(@(E-A8B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE;&5N82(*
M;7-G<W1R(")386YT82!(96QE;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,S$*;7-G:60@(E-A:6YT($MI='1S(&%N
M9"!.979I<R(*;7-G<W1R(")386EN="!+:71T<R!Y($YE=FES(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y"FUS9VED
M(")386EN="!,=6-I82(*;7-G<W1R(")386YT82!,=6/M82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DR"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D*;7-G:60@
M(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE
M<G)E('D@36EQ=65L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0T"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")386X@5FEC96YT92!Y($=R86YA9&EN
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B36ES;6\@
M9G)A;64@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-@IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;G1O
M(%1O;>%S('D@4'+M;F-I<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")0<F]V
M965D;W(@9&4@<V%TZ6QI=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!<F%B:6$B"FUS
M9W-T<B`B07)A8FEA(%-A=61I=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B1W5A<F1A<B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B1W5A<F1A<B!<(B5S
M7"(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(D=U87)D87(@)7,B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO
M;G,B"FUS9W-T<B`B1W5A<F1A<B!O<&-I;VYE<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C8*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB1W5A<F1A<B!L82!C
M;VYF:6=U<F%C:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0(&5N(&5L
M(&1I<F5C=&]R:6\@(@HB=&5M<&]R86P@9&4@<W4@<V5R=FED;W(N(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4V4@:&$@9W5A
M<F1A9&\@;&$@8V]N9FEG=7)A8VGS;B!D92`E<RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")'=6%R
M9&%R(&=U:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS
M;B!E;CH@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T
M<B`B0F]R<F%S8V%S(&%I<VQA9&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(D-I96YC:6$B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(D)U
M<V-A<B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM
M<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B32X@8OIS<75E9&$B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L96-T($9I;&5S
M(@IM<V=S='(@(E-E;&5C8VEO;F%R(&%R8VAI=F]S(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@
M9&%T92(*;7-G<W1R(")396QE8V-I;VYE('5N82!F96-H82(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U
M<"!T;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N92!E;"!G<G5P;R!A(&'Q861I
M<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")396QE8V-I;VYE('5N(&YU979O
M('!R;W!I971A<FEO(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B4V5L96-C:6]N
M92!U;B!S97)V:61O<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")396QE
M8V-I;VYE(&5L('5S=6%R:6\@82!A\6%D:7(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM
M<V=S='(@(E-E;&5C8VEO;F%R('1O9&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C8T,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(E-E;&5C8VEO;F4@=&]D;W,@;&]S(&-O;7!O;F5N=&5S(&1E(&QA
M(&9E8VAA+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B4V5L96-C
M:6]N87(@=6X@;V)J971O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B4VEN
M('-E;&5C8VGS;B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I
M9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE
M(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C8VEO
M;F4@;&]S(&-A<N%C=&5R97,@<75E(&YE8V5S:71E(&1E(&QA<R!C87-I;&QA
M<R!D92!A8F%J;RX@4'5E9&4@(@HB8V]P:6%R;&]S('D@<&5G87)L;W,@9&5L
M(.%R96$@9&4@=&5X=&\N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(E-E;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@9F5C:&%S.B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&5L(&9O<FUA=&\@9&4@
M9F5C:&%S.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI
M;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@
M8VAA;F=E.B(*;7-G<W1R(")396QE8V-I;VYE(&QA(&ED96YT:61A9"!Q=64@
M<75I97)A(&-A;6)I87(Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@
M(E-E;&5C8VEO;F4@96P@9&5L:6UI=&%D;W(@9&4@:&]R87,Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@96P@9F]R;6%T;R!D92!H
M;W)A<SHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED
M(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L96-C
M:6]N92!D;W,@8V%M<&]S(&-O:6YC:61E;G1E<RXB"@HC.B!C;VYF:6<O+F)A
M:R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R
M('-C:&5M92XB"FUS9W-T<B`B4V5L96-C:6]N92!S=2!C;VUB:6YA8VGS;B!D
M92!C;VQO<F5S+B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C(U
M,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G
M<W1R(")396QE8V-I;VYE('-U(&ED:6]M82!P<F5F97)I9&\Z(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B16YV:6%R(&EN9F]R;64@9&4@<')O8FQE
M;6%S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(D5N=FEA<B!335,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S"FUS
M9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R
M.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B
M4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1I96UB<F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E
M;F5G<F\B"FUS9W-T<B`B4V5R8FEA('D@36]N=&5N96=R;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R
M(@IM<V=S='(@(D[Z;65R;R!D92!S97)I92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1A=&]S(&1E;"!S97)V:61O<B!E
M<G+S;F5O<R!O(&YO(&1I<W!O;FEB;&5S+B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES
M=')A8VGS;B!D92!S97-I\VXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R(")(82!C861U8V%D;R!E;"!)1"!D92!S97-I\VXN(@H*(SH@;&EB+V%P
M:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")397-I;VYE<R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S$T"FUS9VED(")3970B"FUS9W-T
M<B`B17-T86)L96-E<B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@
M(B(*(D5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R;6ET96X@<F5A:G5S
M=&%R('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A("(*(F]L=FED87)L82XB
M"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")#;VYF:6=U<F$@<V5R=FED;W)E
M<R!R96UO=&]S(&$@;&]S('%U92!D97-E92!A8V-E9&5R(&1E<V1E(&5L('!O
M<G1A;"XB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I
M9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+B(*;7-G<W1R(")$969I;F4@;&%S(&]P8VEO;F5S('!R
M969E<FED87,@9&4@:61I;VUA+"!Z;VYA(&AO<F%R:6$@>2!F96-H87,N(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB1&5F:6YE(&QA(&%P;&EC86-I\VX@9&4@:6YI8VEO+"!L
M82!C;VUB:6YA8VGS;B!D92!C;VQO<F5S+"!L82!A8W1U86QI>F%C:?-N("(*
M(F1E('#A9VEN82!Y(&]T<F%S(&]P8VEO;F5S(&1E('9I<W5A;&EZ86-I\VXN
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B
M"FUS9W-T<B`B0V]N9FEG=7)A8VGS;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE(@IM<V=S='(@(DAA>2!G=6EO;F5S(&1E(&%C='5A;&EZ
M86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O
M<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E9A<FEA<R!U
M8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@<&%RX6UE=')O.B`B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S
M"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97,B"@HC.B!C
M;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P
M:6YG(@IM<V=S='(@(D-O;7!R87,B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")2
M97-U;65N(&-O<G1O(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`BOT1E9FEN:7(@8VQA=F5S(&1E(&%C8V5S
M;R!P87)A(&QA(&UA>6]R[6$@9&4@;&]S(';M;F-U;&]S/R(*"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@
M(B9N8G-P.TUO<W1R87(F;F)S<#LB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,34T"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R
M<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DUU97-T<F$@;&%S(&1I9F5R96YC:6%S(&5N
M=')E(&QA(&YU979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA8V5N861A(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W
M(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(K]-
M;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA('-E<VGS;B!A;"!I;FEC:6%R/R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(DUO<W1R87(@;W!C:?-N(&1E
M(&-O;G-E<G9A<B!E;"!O<FEG:6YA;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-SDU"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")-;W-T<F%R('-E
M;&5C=&]R(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-3,P"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(K]-;W-T<F%R(&QA(&)A<G)A(&1E(&UE;OH@9&4@;W!E<F%C:6]N97,@9&4@
M=&%B;&$_(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_(@IM<V=S='(@(K]-;W-T<F%R(&5L(&UE;OH@)7,@82!L82!I>G%U:65R
M9&$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(DUU97-T<F$@96P@9&GA;&]G;R!D92!P
M<F]P:65D861E<R!D92!C96QD82!D92!T86)L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B375E
M<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S(&1E('1A8FQA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B375E<W1R82!E;"!D:>%L;V=O(&1E('!R;W!I961A9&5S
M(&1E(&9I;&$@9&4@=&%B;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUU97-T<F$@96P@9&GA
M;&]G;R!D92!P<F]P:65D861E<R!D92!I;6%G96XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B36]S
M=')A<B!C87)G82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(D%G=6%C97)O<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(DQL=79I87,@;6%T=71I;F%S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*
M;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("),;'5V:6%S('9E<W!E<G1I
M;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(D%G
M=6%C97)O<R!E;B!L82!V96-I;F1A9"(*"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B
M4F5D=6-I<B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M.3<R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U
M.`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0B"FUS9W-T<B`B4')I;65R;R!R961U>F-A(&\@<75I=&4@
M9&4@96YM961I;R!L;W,@8FQO<75E<R!C97)C86YO<R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$*;7-G:60@(E-I
M97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F$B"@HC.B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R
M(")!;'1A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R(")&:7)M82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM
M(@IM<V=S='(@(D%L9V]R:71M;R!D92!F:7)M82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I;F=A
M<&]R92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HX.38@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$R,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Y,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S(*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M8?%O(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@
M(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B3VUI=&ER(&UA;G1E;FEM:65N
M=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")%<VQO=F%Q=6EA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M.`IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B17-L;W9E;FEA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N
M;W<B"FUS9W-T<B`B3FEE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M06=U86-E<F\@9&4@;FEE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(D%G=6%C97)O(&1E(&YI979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*
M;7-G<W1R(")!9W5A8V5R;R!D92!N:65V92!M871U=&EN;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W
M(%-H;W=E<G,@3&%T92(*;7-G<W1R(")!9W5A8V5R;R!D92!N:65V92!V97-P
M97)T:6YO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N
M;W<@9&5P=&@Z("(*;7-G<W1R(")%<W!E<V]R(&1E(&QA(&YI979E.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B17%U:79A;&5N=&4@9&4@;&$@;FEE
M=F4@96X@86=U83H@(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,@IM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S
M='(@(DES;&%S(%-A;&]M\VXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@
M(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B0V%N8VEO;F5S("8@4&]E;6%S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,#@*;7-G:60@(E-O<G0@;W)D97(@
M<V5L96-T:6]N(@IM<V=S='(@(E-E;&5C8VGS;B!D96P@<V5N=&ED;R!D92!L
M82!C;&%S:69I8V%C:?-N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-#<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ-C8@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$X
M.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B4F5M:71E;G1E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(E-U9.%F<FEC82(*"B,Z
M(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U
M<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R(")%=7)O<&$@9&5L('-U<B`H
M25-/+3@X-3DM,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#$*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(D=E;W)G:6$@9&5L(%-U
M<B!E($ES;&%S(%-A;F1W:6-H(&1E;"!3=7(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9F5R:6\@<W5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@
M(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B17-P86-I
M861O(&5N=')E(&-E;&1A<R!A9'EA8V5N=&5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E
M='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B17-P
M86-I861O(&5N=')E(&5L(&-O;G1E;FED;R!Y(&5L(&)O<F1E(&1E('5N82!C
M96QD82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E
M<B(*;7-G<W1R(")397!A<F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*;7-G:60@(E-P86-I;F<B"FUS
M9W-T<B`B17-P86-I861O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D
M9&EN9R(*;7-G<W1R(")%<W!A8VEA9&\@>2!M87)G96XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,`IM<V=I9"`B4W!A
M:6XB"FUS9W-T<B`B17-P8?%A(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN
M<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C
M=&5R($EN<'5T(@IM<V=S='(@(D5S8W)I='5R82!D92!C87)A8W1E<F5S(&5S
M<&5C:6%L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(D1I
M=FED:7(@8V5L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T
M<B`B1&EV:61I<B!C;VQU;6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM
M<V=S='(@(D1I=FED:7(@9FEL82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(D1E<&]R=&5S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED
M(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8*
M;7-G:60@(E-T86YD87)D(@IM<V=S='(@(D5S=.%N9&%R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B
M4W1A<B!4<F5K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#8@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(W.3$*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B
M0?%O(&1E(&EN:6-I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")%<W1A9&\@
M;R!P<F]V:6YC:6$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(D5S=&%D;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")&;W)M871O(&1E(&%L;6%C96YA;6EE;G1O(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S
M(@IM<V=S='(@(D1I<F5C8VGS;B!D92!L82!C86QL92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`B5&%C:&%D82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("),:7-T82!D
M92!C861E;F%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(D5L:6UI
M;F%R(&1O;6EN:6\@9&4@;&$@9&ER96-C:?-N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y
M;&4@6T-34UTB"FUS9W-T<B`B17-T:6QO(%M#4U-=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS
M9W-T<B`B1&]M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!S=6)D:7)E8W1O<FEO(%PB
M)7-<(BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!<W5N=&\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS
M,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R(")%;G9I87(B"@HC.B!S:6=N=7`N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L
M;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D
M+B(*;7-G<W1R("(B"B)392!H82!E;G9I861O('5N82!S;VQI8VET=60@9&4@
M86QT82!D92!<(B5S7"(@96X@96P@<VES=&5M82X@3F\@<&]D<N$@(@HB:6YI
M8VEA<B!S97-I\VX@:&%S=&$@<75E('-E(&AA>6$@87!R;V)A9&\@;&$@<V]L
M:6-I='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")3=6+M;F1I8V4B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R("+)>&ET;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B4V4@:&$@8?%A9&ED;R!C;W)R96-T86UE;G1E
M(%PB)7-<(B!A;"!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*
M(E-E(&AA;B!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92!L;W,@9&%T;W,@9&5L
M('5S=6%R:6\@7"(E<UPB(&1E;"!S:7-T96UA+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(E-E(&AA(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E(%PB)7-<(BXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B4V4@:&$@96QI;6EN861O(&-O<G)E8W1A;65N=&4@7"(E<UPB(&1E
M;"!S:7-T96UA+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(E-E(&AA(')E<W1A=7)A
M9&\@8V]R<F5C=&%M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R97-Q=64@
M<&%R82!V97(@;&]S("(*(F-A;6)I;W,N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(E-E(&AA(&=U87)D861O(&-O<G)E8W1A;65N=&$@;&$@8V]P:6$@9&4@
M;&$@8V]N9FEG=7)A8VGS;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B4V4@
M:&$@9W5A<F1A9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C
M;VYF:6=U<F%C:?-N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS
M9W-T<B`B4V4@:&$@86-T=6%L:7IA9&\@8V]R<F5C=&%M96YT92!<(B5S7"(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M=W)O=&4@)7,B"FUS9W-T<B`B4V4@:&$@97-C<FET;R!C;W)R96-T86UE;G1E
M("<E<R<B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=63A;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*
M;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4F5S=6UE;B(*"B,Z(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B06UA
M;F5C97(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U
M;B!3970B"FUS9W-T<B`B071A<F1E8V5R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E-U;FYY(@IM<V=S='(@
M(E-O;&5A9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U
M"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D%M86YE8V5R(@H*(SH@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS
M9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R(")!;6%N96-E<B]!=&%R9&5C
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B06UA;F5C97(Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R
M(")!=&%R9&5C97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")!=&%R9&5C97(Z("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G
M:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(E-U<&5R[6YD:6-E(@H*(SH@8V]N
M9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T
M(@IM<V=S='(@(E-O<&]R=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U"FUS9VED(")3=7)I;F%M92(*;7-G<W1R
M(")3=7)I;F%M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*
M;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B07!E;&QI9&\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y"FUS9VED(")3
M=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D('D@2F%N
M($UA>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q.0IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-W87II;&%N
M9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P-0IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-U96-I82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4V"FUS9VED
M(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=6EZ82(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM
M<V=S='(@(E)E9VES=')O(&1E('-I;F-R;VYI>F%C:?-N(&5L:6UI;F%D;R(*
M"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN
M8TU,(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R
M9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(D5R<F]R(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M:6YO<R!D
M92!B^G-Q=65D82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(E)E</IB;&EC82#!<F%B92!D92!3:7)I82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(D-H=6)A<V-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM
M<V=S='(@(D)O<G)A<V-O<V\@>2!V96YT;W-O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FUS(@IM
M<V=S='(@(D)O<G)A<V-A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")";W)R87-C87,@;6%T=71I;F%S(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V
M+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(D%R8VAI=F\@5%-6
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P
M:65D861E<R!D92!T86)L82(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B;&$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!I
M961A9&5S(&1E('1A8FQA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0*;7-G:60@(E1A:7=A;B(*
M;7-G<W1R(")486EWX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S
M='(@(E1A:7?A;BP@4')O=FEN8VEA(&1E($-H:6YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-0IM<V=I9"`B5&%J
M:6MI<W1A;B(*;7-G<W1R(")487EI:VES=.%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YI82P@4F5P
M^F)L:6-A(%5N:61A(&1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")$97-T
M:6YO.B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,R(&-O;F9I9R\N8F%K
M+VAO;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R(")487)E87,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H
M;VYE($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@=&5LZ69O;F\B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M<"!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@9'5R86YT92!L82#Z;'1I;6$@
M:&]R83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E1E;7!E
M<F%T=7)A/&)R("\^*"5S3>%X)7,O)7--[6XE<RD@)F1E9SLE<R(*"B,Z(&QI
M8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO('-E(&5N
M8V]N='+S(&QA('!L86YT:6QL82!<(B5S7"(N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(D%D;6EN:7-T<F%C:?-N(&1E('!L86YT:6QL87,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(Q,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-PIM
M<V=I9"`B5&5X="(*;7-G<W1R(")497AT;R(*"B,Z(&-O;F9I9R\N8F%K+W!R
M969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E/S
M;&\@=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(D%L
M:6YE86-I\VX@9&4@=&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(D)O
M<F1E('-U<&5R:6]R(&1E;"!T97AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(DIU
M92(*"B,Z(&-O;F9I9R\N8F%K+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H
M86D@*%1)4RTV,C`I(@IM<V=S='(@(E1A:6QA;F3I<R`H5$E3+38R,"DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(T
M"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R(")486EL86YD:6$B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z.#8T"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(").;R!E<W3A(&1I<W!O;FEB;&4@;&$@
M97AT96YS:?-N($944"XB"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z-34*
M;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B16P@<VES=&5M82!H:7-T\W)I8V\@97-TX2!D97-H86)I;&ET861O+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B16P@;6]T;W(@9&4@:6YT96=R
M86-I\VX@2&]R9&4O2V]L86(@;F\@<V]P;W)T82!<(B5S7"(B"@HC.B!L:6(O
M3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B3F\@<V4@<'5E9&4@
M:6YI8VEA<B!E;"!R96=I<W1R;R!D92!)35-0+B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA
M<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(").;R!S92!H
M82!C87)G861O(&-O<G)E8W1A;65N=&4@;&$@8VQA<V4@36%I;G1E;F%N8V4Z
M.B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G
M:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R(")392!H82!C97)R861O(&QA('9E;G1A;F$@9&4@;W!C:6]N97,N
M(%-A;&EE;F1O+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](
M;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z
M,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(E-I(&1E<V5A('5T:6QI>F%R('!E
M<FUI<V]S+"!E;"!A9&UI;FES=')A9&]R('1I96YE('%U92!C;VYF:6=U<F%R
M('5N('-O<&]R=&4@(@HB9&4@<&5R;6ES;W,@<&5R;6%N96YT92XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U
M"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")3\VQO(&5L
M(&)O<F1E(&EN9F5R:6]R(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)%;"!)1"!D96P@8V]N
M=&%C=&\@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J\R!E;B!B;&%N8V\@;R!N
M;R!S92!E;F-O;G1R\R!E;B`B"B)L82!B87-E(&1E(&1A=&]S+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C
M;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S
M(&)O;VLN(@IM<V=S='(@(E-E(&AA(&'Q861I9&\@8V]R<F5C=&%M96YT92!E
M;"!C;VYT86-T;R!A('-U<R!D:7)E8V-I;VYE<RXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0
M('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)087)A(&-O;7!R;V)A<B!E;"!M
M96YS86IE(&9I<FUA9&\@:&%C92!F86QT82!E;"!B;&]Q=64@9&4@9FER;6$@
M<V5P87)A9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E
M:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@
M(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)%;"!)1"!D92!L82!L
M:7-T82!D92!D:7-T<FEB=6-I\VX@;F\@<V4@97-P96-I9FEC\RP@<V4@9&5J
M\R!E;B!B;&%N8V\@;R!N;R`B"B)S92!E;F-O;G1R\R!E;B!L82!B87-E(&1E
M(&1A=&]S+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I
M9FEE9"XB"FUS9W-T<B`B3F\@<V4@97-P96-I9FEC\R!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,38*;7-G
M:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(DQA<R!C87)A8W1E<NUS=&EC87,@
M9&4@8VEF<F%D;R!N96-E<VET86X@=6YA(&-O;F5X:?-N('=E8B!S96=U<F$N
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#8@;&EB+TAO<F1E+G!H<#HU,C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M82`E<R!S971T:6YG+B(*;7-G<W1R(")%;"!A<F-H:79O("5S('1E;F1R[6$@
M<75E(&-O;G1E;F5R('5N82!O<&-I\VX@)7,N(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ-SD@;&EB+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB
M"FUS9W-T<B`B16P@87)C:&EV;R`E<R!T96YD<NUA('%U92!C;VYT96YE<B!A
M;&=U;F%S(&]P8VEO;F5S("5S+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR
M.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M(")%;"!A<F-H:79O(&YO(&-O;G1I96YE(&1A=&]S+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+B(*;7-G<W1R(")!(&-O;G1I;G5A8VGS;B!T:65N92!L87,@8V%B
M96-E<F%S(&1E(&5S=&4@;65N<V%J92!M97-S86=E+W)F8S@R,BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED
M("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P
M<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O
M=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N
M("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA
M8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@
M8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0
M<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U
M(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U
M('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM
M<V=S='(@(B(*(E-E('-A8F4@<75E(&5L(&UO9&\@9&4@<&%N=&%L;&$@8V]M
M<&QE=&$@9&$@<')O8FQE;6%S(&-O;B!);G1E<FYE="!%>'!L;W)E<B`B"B)D
M96)I9&\@82!F86QL;W,@9&5L(&YA=F5G861O<B!Q=64@;F\@:&5M;W,@<&]D
M:61O('-O<VQA>6%R+B!0=65D92!S=69R:7(@(@HB=FES=6%L:7IA8VGS;B!D
M92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO;F5S(&1E;"!E9&ET;W(@>2]O
M(&-U96QG=65S("(*(F%L96%T;W)I;W,@9&5L(&YA=F5G861O<BX@4VD@<W4@
M<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y>"P@97,@;75Y("(*(G!R
M;V)A8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T96-C:?-N(&=E;F5R
M86P@>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L("(*(F5Q=6EP;RY<7&Y<7&Y9
M82!E<W3A(&%V:7-A9&\N(%!U;'-E($%C97!T87(@<VD@8?IN(&1E<V5A('!R
M;V)A<B!E;"!E9&ET;W(@96X@(@HB;6]D;R!D92!P86YT86QL82!C;VUP;&5T
M82XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B4V4@:&$@96QI;6EN861O(&QA(&ED96YT:61A9"!<(B5S7"(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B4_-L;R!E;"!B;W)D92!I>G%U:65R9&\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+B(*;7-G<W1R("(B"B)(87D@<75E(&EN9&EC87)L92!A(&QA(&-L
M87-E($-R>7!T7W!G<#HZ(&QA('5B:6-A8VGS;B!D92!L;W,@8FEN87)I;W,@
M1VYU4$<N(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HR,#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E
M<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*
M(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E
M96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)392!H82!M;W-T
M<F%D;R!E;"!M96YS86IE(&5N=FEA9&\@96P@)7,@82`E<R!C;VX@96P@87-U
M;G1O(%PB)7-<(BY<;B(*(LES=&\@;F\@9V%R86YT:7IA('%U92!E;"!M96YS
M86IE(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R96YD:61O+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE
M;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3F]M8G)E
M('5T:6QI>F%D;R!A;"!V:6YC=6QA<B!A(&QA('#A9VEN82!D92!C;VUP;W-I
M8VGS;B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D5L(&[Z
M;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E<B!U;B!N^FUE<F\N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+B(*;7-G<W1R(")(86-E(&9A;'1A(&5L(&WS9'5L;R!O
M<&5N<W-L('!A<F$@;&$@8VQA<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BXB"@HC
M.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL
M;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F\@<V4@<'5E9&4@9W5A<F1A<B!L
M82!P<F5F97)E;F-I82!<(B5S7"(@<&]R<75E('-U<R!D871O<R!S;V)R97!A
M<V%N(&5L("(*(G1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<G!M+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B(@HB3F\@<V4@96YC;VYT<O,@96X@96P@<VES
M=&5M82!E;"!P<F]G<F%M82!P87)A('9E<B!E<W1E('1I<&\@9&4@9&%T;W,@
M*"5S*2XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R(")%;"!C87+A8W1E<B!D92!C:71A(&1E8F4@<V5R('-E<B!S\VQO
M('5N;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>2(*;7-G<W1R(")3\VQO(&QO<R!L861O<R!I>G%U:65R9&\@>2!D97)E
M8VAO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM
M<V=S='(@(E/S;&\@96P@;&%D;R!D97)E8VAO(@H*(SH@;&EB+T9I;&4O0U-6
M+G!H<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B16P@<V5P87)A9&]R(&1E8F4@<V5R
M('/S;&\@=6YO+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N(&1E;&5T960N(@IM<V=S='(@(E-E(&AA(&5L:6UI;F%D;R!E;"!S97)V
M:61O<B!<(B5S7"(N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(E-E(&AA(&=U87)D861O(&5L('-E<G9I
M9&]R(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E
M;B!R96UO=F5D+B(*;7-G<W1R(")392!H82!E;&EM:6YA9&\@;&$@<V]L:6-I
M='5D(&1E(&%L=&$@9&4@)7,N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P
M96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3&$@
M9FEL82!E<W!E8VEF:6-A9&$@*"5D*2!N;R!E>&ES=&4N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R
M87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")%;"!A
M<F-H:79O('1E;7!O<F%L(%PB)7-<(B!N;R!E>&ES=&4N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,#(*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T
M<B`B16P@=&5X=&\@<75E(&AA(&EN=')O9'5C:61O(&YO(&-O:6YC:61E(&-O
M;B!E;"!D92!L82!P86YT86QL82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")3\VQO(&QO<R!L861O<R!S
M=7!E<FEO<B!E(&EN9F5R:6]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E
M(&]N;'DB"FUS9W-T<B`B4_-L;R!E;"!L861O('-U<&5R:6]R(@H*(SH@;&EB
M+TAO<F1E+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(E-E
M('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@9&5S9&4@96P@<&%S;R!A
M;G1E<FEO<BXB"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,B!L:6(O
M2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(").;R!S92!P=61O(&=U
M87)D87(@96P@87)C:&EV;R!C87)G861O+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U92!D
M92!W96%T:&5R+F-O;2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(").;R!S92!E;F-O;G1R\R!E;"!D:7)E8W1O
M<FEO(&1E(%1E;6%S(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN
M<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+B(*;7-G<W1R(").;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS-3`*;7-G:60@(E1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G
M<W1R(").;R!H87D@<&%R=&5S('%U92!S92!P=65D86X@;6]S=')A<B!E;B!L
M[6YE82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
M16X@97-T92!C86UP;R!H87D@9&5M87-I861O<R!C87)A8W1E<F5S+B!(82!I
M;G1R;V1U8VED;R`E<R!C87)A8W1E<F5S('D@(@HB=&EE;F4@<75E(&EN=')O
M9'5C:7(@;65N;W,@9&4@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U
M<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T
M<B`B4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A\6%D:7(@82!<(B5S7"(@
M86P@<VES=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"B)392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&)O<G)A<B!L;W,@9&%T
M;W,@9&5L('5S=6%R:6\@7"(E<UPB(&1E;"!S:7-T96UA.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!E;&EM:6YA<B!A
M(%PB)7-<(B!D96P@<VES=&5M83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")392!P<F]D=6IO('5N('!R;V)L
M96UA(&%L(&%C='5A;&EZ87(@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HY,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+B(*;7-G<W1R(")392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L
M82!C87)G82!D96P@87)C:&EV;SH@3F\@<V4@8V%R9_,@)7,N(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@
M<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N('!R
M;V)L96UA(&-O;B!L82!C87)G82!D96P@87)C:&EV;RX@16P@)7,@97)A(&WA
M<R!G<F%N9&4@<75E(&5L("(*(G1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O("@E
M9"!B>71E<RDN(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N('!R;V)L96UA(&-O
M;B!L82!C87)G82!D96P@87)C:&EV;RX@4_-L;R!S92!C87)G\R!P87)C:6%L
M;65N=&4@(@HB96P@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E-E('!R;V1U:F\@=6X@
M97)R;W(@86P@;6]S=')A<B!E<W1A('!A<G1E(&1E;"!M96YS86IE(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(E-E
M('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S(&1A=&]S(&1E;"!C
M;VYT86-T;RXB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED
M(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82XB"FUS9W-T<B`B4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I;7!O<G1A
M<B!L;W,@9&%T;W,@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*
M(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N(&5R
M<F]R(&5N(&5L(&9O<FUU;&%R:6\@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@
M<75E(&AA>6$@(@HB;VQV:61A9&\@<F5L;&5N87(@=6X@8V%M<&\@;F5C97-A
M<FEO+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)392!P<F]D=6IO('5N(&5R<F]R
M(&%L(&5J96-U=&%R(&QA(&9U;F-I\VX@97-P96-I9FEC861A(&1E(&QA(&QI
M8G)E=&$@9&4@(@HB9&ER96-C:6]N97,N(%9U96QV82!A('!R;V)A<B!MX7,@
M861E;&%N=&4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(E-E('!R;V1U:F\@=6X@97)R;W(@86P@86-T=6%L:7IA<B!L
M;W,@9&5T86QL97,@9&5L(&-O;G1A8W1O+B!6=65L=F$@82!P<F]B87(@(@HB
M;>%S(&%D96QA;G1E+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!A8W1U86QI>F%R(&QA(&QI<W1A(&1E
M(&1I<W1R:6)U8VGS;BX@5G5E;'9A(&$@<')O8F%R("(*(FWA<R!A9&5L86YT
M92XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R($E-05`@;F\@<V]P
M;W)T82!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(LES
M=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O(')A<B!VX6QI9&\N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S
M='(@(LES=&4@;F\@<&%R96-E('-E<B!U;B!A<F-H:79O('II<"!VX6QI9&\N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M("+)<W1E(&YO('!A<F5C92!S97(@=6X@;OIM97)O(&1E('1A<FIE=&$@=N%L
M:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"B)%<W1E(&-O;G1R;VQA9&]R('!E<FUI=&4@96YV:6%R(&UE;G-A:F5S
M(&$@=')A=NES(&1E(&QA('!A<V%R96QA($-L:6-K871E;&P@(@HB*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10(@H*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@<&5R;6ET
M92!E;G9I87(@;65N<V%J97,@82!T<F%VZ7,@9&4@;&$@<&%S87)E;&$@5TE.
M("AH='1P.B\O(@HB=VEN<&QC+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I
M9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D5S
M=&4@8V]N=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@82!T<F%V
MZ7,@9&4@;&$@<&%S87)E;&$@<VUS,F5M86EL("(*(BAH='1P.B\O<VUS,F5M
M86EL+F-O;2DL(&UE9&EA;G1E(&QA($%022!(5%10(@H*(SH@;&EB+TYE="]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR
M;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB
M"FUS9W-T<B`B(@HB17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M
M96YS86IE<R!V:6$@4TU44"!A('1R87;I<R!D92!L82!P87-A<F5L82!D92`B
M"B)6;V1A9F]N92!D92!)=&%L:6$L('/S;&\@82!N^FUE<F]S(%9O9&%F;VYE
M+B!(86-E(&9A;'1A('5N82!C=65N=&$@9&4@8V]R<F5O("(*(F1E(%9O9&%F
M;VYE(&1E($ET86QI82`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q
M,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-3<*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-3@@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P,#4*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q-#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(T,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(V,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,3D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#4@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,X,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@
M(DAA8V4@9F%L=&$@97-T92!C86UP;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN
M=&5G97)S+B(*;7-G<W1R(")%<W1E(&-A;7!O('/S;&\@<'5E9&4@8V]N=&5N
M97(@96YT97)O<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q-@IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BXB"FUS9W-T<B`B17-T92!C86UP;R!S\VQO('!U961E(&-O;G1E
M;F5R(&[Z;65R;W,@>2!L;W,@9&]S('!U;G1O<RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B17-T92!C86UP;R!S\VQO('!U
M961E(&-O;G1E;F5R('9A;&]R97,@;V-T86QE<RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T
M<B`B(@HB17-T92!C86UP;R!T:65N92!Q=64@<V5R('5N82!L:7-T82!D92!E
M;G1E<F]S('-E<&%R861O<R!P;W(@8V]M87,@;R!E<W!A8VEO<RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D5S=&4@8V%M<&\@=&EE;F4@
M<75E('-E<B!U;B!N^FUE<F\@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#$X"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@=&EE;F4@
M<75E(&-O;G1E;F5R('5N(&/S9&EF;R!D92!C;VQO<B!E;B!F;W)M871O(%)'
M0B!(97AA9&5C:6UA;"P@(@HB<&]R(&5J96UP;&\@)R,Q,C,T868G+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B66$@<V4@:&$@<')O
M8V5S861O(&5S=&4@9F]R;75L87)I;RXB"@HC.B!T96UP;&%T97,O:&5L<"]A
M8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*
M;7-G<W1R(")%<W1O(&5S("5S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B+)
M<W1O(&5S('5N(&]B:F5T;R!D92!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R
M;&\@;F5C97-I=&$@=6X@8VQI96YT92!D92`B"B)C;W)R96\@('%U92!E;G1I
M96YD82!E;"!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!V97(@=6YA
M(&QI<W1A(&1E("(*(F1I8VAO<R!C;&EE;G1E<R!V:7-I=&4@)7,B"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)%
M<W1E(&UE;G-A:F4@<V4@97-C<FEB:?,@8V]N('5N(&IU96=O(&1E(&-A<F%C
M=&5R97,@*"5S*2!D:7-T:6YT;R!A;"!S=7EO+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B17-T92!N^FUE<F\@9&5B92!S97(@<&]R
M(&QO(&UE;F]S('5N('5N;RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII
M<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")%<W1E('-E<G9I9&]R(&YO
M('!U961E(&1E<V-O;7!R:6UI<B!A<F-H:79O<R!Z:7`@>2!G>FEP+B(*"B,Z
M(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E
M;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D5S=&4@<VES
M=&5M82!A8W1U86QM96YT92!E<W3A(&1E<V%C=&EV861O+B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N(@IM<V=S='(@(D5S=&4@=F%L;W(@=&EE;F4@<75E('-E
M<B!U;B!N^FUE<F\N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O
M;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")%<W1A('9E;G1A;F$@<_-L
M;R!P=65D92!A8G)I<G-E(&1E<V1E('5N82!V96YT86YA(&1E(&]P8VEO;F5S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B5')U96YO(@H*(SH@8V]N9FEG+RYB
M86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C,V"FUS9VED(")4:6-K971S(@IM<V=S
M='(@(DEN8VED96YC:6%S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,C4@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM
M<V=S='(@(DAO<F$B"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B0RX@=&EE;7!O
M<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M
M870B"FUS9W-T<B`B1F]R;6%T;R!H;W)A<FEO(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U,S$*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E-E
M;&5C8VGS;B!D92!H;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T
M<B`B5&EM;W(M3&5S=&4B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HR,"!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0IM<V=I9"`B5&ET
M;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*
M;7-G<W1R(")4[71U;&\@*&-O;G-E:F\I.B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")087)A
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4&%R82!S96QE8V-I;VYA<B!V87)I
M;W,@8V%M<&]S+"!M86YT96YG82!P=6QS861A(&QA('1E8VQA($-O;G1R;VP@
M*%!#*2!O("(*(D-O;6%N9&\@*$UA8RD@86P@:&%C97(@8VQI8VLN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B2&]Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(D-O;FUU=&%R(&]R:6=E;B!(5$U,(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B5&]G;R(*;7-G
M<W1R(")4;V=O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B36'Q86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.0IM<V=I9"`B5&]N9V$B"FUS
M9W-T<B`B5&]N9V$B"@HC.B!L:6(O2&]R9&4O075T:"]K;VQA8BYP:'`Z,3`T
M"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA
M<W0@;6EN=71E<RXB"FUS9W-T<B`B1&5M87-I861O<R!I;G1E;G1O<R!F86QL
M:61O<R!E;B!L;W,@^FQT:6UO<R!M:6YU=&]S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I9"`B5&]P
M(@IM<V=S='(@(E-U<&5R:6]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*
M;7-G<W1R(")&<F%M92!S=7!E<FEO<B`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4
M<F%D=6-C:6]N97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,R"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(E1R:6YI9&%D('D@5&]B86=O(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5F5R9&%D
M97)O(&\@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R(")-87(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X"FUS9VED
M(")4=6YI<VEA(@IM<V=S='(@(E3Z;F5Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,0IM<V=I9"`B5'5R:V5Y(@IM
M<V=S='(@(E1U<G%U[6$B"@HC.B!C;VYF:6<O+F)A:R]N;',N<&AP+F1I<W0Z
M,3DU"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)C
M;R`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T
M<B`B5'5R:VUE;FES=.%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(DES;&%S(%1U<FMS('D@0V%I8V]S(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,PIM<V=I
M9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&QI8B](;W)D92]#3$DN
M<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(D5S
M8W)I8F$@<W4@96QE8V-I\VXZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("+-;F1I
M8V4@52Y6+CH@(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D*;7-G:60@(E523"(*;7-G
M<W1R(")54DPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U
M<R!R97!O<G0B"FUS9W-T<B`B55),(&1E('-U(&EN9F]R;64@9&4@97-T861O
M(&1E(&5N=NUO(&1E;"!G=6GS;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),
M.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S<*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,V"FUS9VED
M(")5:W)A:6YE(@IM<V=S='(@(E5C<F%N:6$B"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C0R-0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("));F-A<&%Z(&1E(&%C8V5D97(@86P@9&ER96-T;W)I;R!6
M1E,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@HB26YC87!A>B!D92!A\6%D:7(@:6YF;W)M
M86-I\VX@9&4@=7-U87)I;R!A9&EC:6]N86P@86P@<F5A;&EZ87(@96P@86QT
M82XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("));F-A<&%Z(&1E(&-A;6)I87(@;&]S('!R:79I
M;&5G:6]S(&1E;"!A<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HS.3@@;&EB+U9&4R]M=7-Q;"YP:'`Z-#@P"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(DEN8V%P87H@9&4@8V%M8FEA<B!L;W,@
M<')I=FEL96=I;W,@9&5L(&%R8VAI=F\@5D93("5S+R5S+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HW.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B26YC87!A>B!D92!C86UB:6%R(&$@
M)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B26YC87!A>B!D92!C;VUP<F]B87(@96P@=&%M8?%O(&1E(%PB)7-<
M(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C<P-R!L:6(O5D93+W-Q;"YP:'`Z
M,3`T,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N
M(@IM<V=S='(@(DEN8V%P87H@9&4@8V]M<')O8F%R(&5L('1A;6'Q;R!D92!<
M(B5S+R5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@
M(DEN8V%P87H@9&4@8V]N96-T87)S92!A;"!S97)V:61O<B!344PN(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C@X,PIM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(DEN8V%P87H@9&4@8V]N96-T87(@8V]N(%-3
M3"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S."!L:6(O5D93+V9I;&4N<&AP
M.C(T,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,30*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,C$Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(R-PIM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P87H@9&4@
M8V]P:6%R(&5L(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!C<F5A<B!E
M;"!D:7)E8W1O<FEO(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HS-C<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C<P(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C(W-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("));F-A<&%Z(&1E(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93
M+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A>B!D92!C<F5A<B!E
M;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@8W)E87(@;&$@8V%R<&5T82!6
M1E,@7"(E<UPB(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S@*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P
M87H@9&4@8W)E87(@=6X@87)C:&EV;R!61E,@=F%C[6\N(@H*(SH@;&EB+TAO
M<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y(&QI8B](;W)D92]#;VUP<F5S<R]T
M87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*
M;7-G<W1R("));F-A<&%Z(&1E(&1E<V-O;7!R:6UI<B!L;W,@9&%T;W,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C,P,R!L:6(O5D93+W-M8BYP:'`Z,C(X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B26YC87!A>B!D
M92!E;&EM:6YA<B!<(B5S7"(L(&5L(&1I<F5C=&]R:6\@;F\@97-TX2!V86/M
M;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!<(B5S7"(Z("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R(%PB
M)7-<(CH@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#0@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,S(S(&QI8B]61E,O<W%L+G!H<#HT,#<*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S
M='(@(DEN8V%P87H@9&4@96QI;6EN87(@)7,L(&5L(&1I<F5C=&]R:6\@;F\@
M97-TX2!V86/M;R(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,X-"!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS.#@*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B26YC87!A>B!D
M92!E;&EM:6YA<B!E;"!D:7)E8W1O<FEO(%9&4R!D92!F;W)M82!R96-U<G-I
M=F$N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-3`@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S,T(&QI8B]61E,O;75S<6PN<&AP.C,T-PHC.B!L:6(O5D93+VUU<W%L
M+G!H<#HS-34@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S@P"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@
M9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,N(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C0S,B!L:6(O5D93+W-Q;"YP:'`Z-#0T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,Z
M("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(DEN8V%P87H@9&4@96QI;6EN87(@96P@87)C:&EV;R!61E,@7"(E<UPB
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S$V(&QI8B]61E,O;75S<6PN<&AP
M.C$V-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3@W(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z-#$Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0R-PIM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B26YC87!A>B!D92!E
M;&EM:6YA<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@96QI;6EN87(@
M;&$@8V%R<&5T82!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("));F-A<&%Z(&1E(&5L:6UI;F%R
M(&5L(%9&4R!D92!F;W)M82!R96-U<G-I=F$Z("5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HX-#<*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N
M="!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@9&5T97)M:6YA<B!E
M;"!D:7)E8W1O<FEO(&%C='5A;"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A
M=&4@9&5T86EL<R(*;7-G<W1R("));F-A<&%Z(&1E(&5X=')A97(@;&]S(&1E
M=&%L;&5S(&1E;"!C97)T:69I8V%D;RXB"@HC.B!L:6(O3F5T+TE-4U`N<&AP
M.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R("));F-A<&%Z(&1E(&-A<F=A<B!L82!D969I;FEC:?-N(&1E("5S
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`X(&QI8B]61E,O9FEL92YP:'`Z
M,C$S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W.0HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HQ.#0*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*
M;7-G<W1R("));F-A<&%Z(&1E('1R87-L861A<B!E;"!A<F-H:79O(%9&4RXB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z.3@@;&EB+U9&4R]S;6(N<&AP.CDS(&QI
M8B]61E,O<VUB+G!H<#HQ,#8*(SH@;&EB+U9&4R]S;6(N<&AP.C8V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R:7(@96P@87)C:&EV;R!61E,@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,CDP(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("));F-A<&%Z(&1E(&%B<FER(&5L(&%R8VAI=F\@5D93('!A<F$@97-C<FEB
M:7(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP
M.C$S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DEN8V%P87H@9&4@86)R:7(@96P@
M87)C:&EV;R!61E,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV
M92XB"FUS9W-T<B`B26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(&-O;7!R
M:6UI9&\N(@H*(SH@;&EB+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("))
M;F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA9&\@9FEL
M97-I>F4H*2DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G
M<W1R("));F-A<&%Z(&1E(&QE97(@=6X@87)C:&EV;R!61E,@*&AA(&9A;&QA
M9&\@9V5T1FEL95-I>F4H*2DN(@H*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B
M"FUS9W-T<B`B26YC87!A>B!D92!L965R('5N(&%R8VAI=F\Z("(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-C@X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@
M=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@;&5E<B!E
M;"!D:7)E8W1O<FEO('9F<W)O;W0N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*
M;7-G<W1R("));F-A<&%Z(&1E(')E;F]M8G)A<B`E<R!C;VUO("5S.B!L82!C
M87)P971A(&1E<W1I;F\@>6$@97AI<W1E(@H*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,S(S"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DEN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&1I<F5C=&]R
M:6\@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R87(@96P@9&ER96-T;W)I;R!6
M1E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-3$@;&EB+U9&4R]S;6(N
M<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!R96YO;6)R
M87(@96P@87)C:&EV;R!61E,@7"(E<UPB(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HV,CD@;&EB+U9&4R]M=7-Q;"YP:'`Z,C0Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(DEN8V%P87H@9&4@<F5N;VUB<F%R(&5L(&%R8VAI=F\@5D93("5S+R5S+B(*
M"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HT
M-C0@;&EB+U9&4R]S<6PN<&AP.C,S.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS,34@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S,W"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("));F-A<&%Z(&1E(')E;F]M
M8G)A<B!E;"!A<F-H:79O(%9&4RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M(@IM<V=S='(@(DEN8V%P87H@9&4@96IE8W5T87(@)VUK:7-O9G,G+B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3@Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(*
M;7-G<W1R("(B"B).;R!S92!P=65D92!A8W1I=F%R(&QA(&%C='5A;&EZ86-I
M\VX@9&4@:6YF;W)M86-I\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@9&4@)2(*
M(G,B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26YC87!A>B!D92!E<V-R:6)I<B!E;"!A
M<F-H:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.#8*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN(@IM<V=S='(@(DEN8V%P87H@9&4@97-C<FEB:7(@=6X@87)C:&EV;R!6
M1E,@*&AA(&9A;&QA9&\@8V]P>2@I*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(Y-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`B26YC87!A>B!D92!E<V-R:6)I<B!L;W,@9&%T;W,@9&5L
M(&%R8VAI=F\@5D93+B(*"B,Z(&QI8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D
M+B(*;7-G<W1R("));F-A<&%Z(&1E(&5S8W)I8FER('5N(&%R8VAI=F\@5D93
M+"!S92!S=7!E<F%RX2!L82!Q=6]T82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS
M9W-T<B`B4W5B<F%Y861A(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E<VAA8V5R(&-A;6)I
M;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$
M97-H86-E(&QA(/IL=&EM82!A8V-I\VXB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#@*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(E)E<W!U97-T82!I;F5S<&5R
M861A(&1E;"!S97)V:61O<B!E;B!L82!C;VYE>&GS;CH@(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-R!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S8@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M(@IM<V=S='(@(E)E<W!U97-T82!I;F5S<&5R861A(&1E;"!S97)V:61O<B!A
M.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")3:6X@8V%T96=O<NUA(@H*(SH@
M8V]N9FEG+RYB86LO;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H
M551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W"FUS9VED(")5;FET
M960@07)A8B!%;6ER871E<R(*;7-G<W1R(")%;6ER871O<R#!<F%B97,@56YI
M9&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,X"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("));F=L871E
M<G)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(T,`IM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")%<W1A9&]S
M(%5N:61O<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI
M;F<@27-L86YD<R(*;7-G<W1R(")%<W1A9&]S(%5N:61O<R!M96YO<R!L87,@
M:7-L87,@<&5R:6;I<FEC87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B
M"FUS9W-T<B`B56YI9&%D97,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HU."!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,CD*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S
M='(@(D1E<V-O;F]C:61O(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2XB"FUS9W-T<B`B07!I;7-G:60@9&5S8V]N;V-I9&\@*$E$(&1E
M(&UE;G-A:F4@9&4@;&$@05!)*2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")#;&EM<V=I9"!D97-C;VYO8VED
M;R`H240@9&4@;65N<V%J92!D96P@8VQI96YT92DN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B4V4@:&$@9&5F:6YI9&\@=6YA('5B:6-A
M8VGS;B!D97-C;VYO8VED82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S
M=V]R9"XB"FUS9W-T<B`B57-U87)I;R!O(&-O;G1R87-E\6$@9&5S8V]N;V-I
M9&]S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0B"FUS9W-T<B`B16QI;6EN87(@=NUN8W5L;R!D96P@96QE;65N=&\@86-T
M=6%L(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N
M;F%M960B"FUS9W-T<B`B4VEN(&YO;6)R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB3&]S(&=U:6]N97,@<VEN
M('!R:79I;&5G:6]S(&YO('!U961E;B!A8V-E9&5R(&1E(&9O<FUA('!R;V=R
M86WA=&EC82!A($-O<G1A<B\B"B)#;W!I87(O4&5G87(@<&]R(')A>F]N97,@
M9&4@<V5G=7)I9&%D+B!0=6QS92!!8V5P=&%R('!A<F$@=F5R(&5N(&UO>FEL
M;&$N;W)G("(*(G5N82!N;W1A('3I8VYI8V$@<75E(&QE(&UU97-T<F4@8_-M
M;R!P97)M:71I<B!Q=64@=6X@9W5I\VX@86-C961A(&%L("(*(G!O<G1A<&%P
M96QE<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")!;G5L
M87(@8V]L;W(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-R!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N
M(@IM<V=S='(@(D5X=&5N<VGS;B!N;R!S;W!O<G1A9&$B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%C='5A;&EZ87(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!8W1U86QI>F%R("5S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I
M9"`B57!D871E('5S97(B"FUS9W-T<B`B06-T=6%L:7IA<B!U<W5A<FEO(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(E-E(&AA(&%C='5A
M;&EZ861O(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4V4@
M:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VXN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS9W-T<B`B0V%R
M9V%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-0IM<V=I9"`B57!L
M;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V
M97(N(@IM<V=S='(@(B(*(E-E(&AA;B!C87)G861O(&5N(&5L('-E<G9I9&]R
M('1O9&]S(&QO<R!A<F-H:79O<R!D92!C;VYF:6=U<F%C:?-N(&1E("(*(F%P
M;&EC86-I;VYE<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(D%L9F%B971O(&QA=&EN;R!E;B!M87GZ<V,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(").^FUE
M<F]S(')O;6%N;W,@96X@;6%Y^G-C+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$*;7-G:60@(E5R=6=U87DB"FUS
M9W-T<B`B57)U9W5A>2(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R(")5<V%R(&%C='5A;#H@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(E5S87(@4U-,(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@
M9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")392!U<V$@<VD@96P@=7-U87)I
M;R]C;VYT<F%S9?%A('-O;B!D:7-T:6YT;W,@96X@96P@<V5R=FED;W(@24U3
M4"XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS
M9VED(")5<V5R(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B16P@=7-U87)I;R`E
M<R!C87)E8V4@9&4@875T;W)I>F%C:?-N('!A<F$@)7,N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%C:?-N(&1E('5S=6%R:6]S(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M(")/<&-I;VYE<R!D92!U<W5A<FEO(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T<F\@9&4@=7-U
M87)I;W,B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R
M(")%<W1A('-E9&4@=&EE;F4@9&5S86-T:79A9&\@96P@<F5G:7-T<F\@9&4@
M=7-U87)I;W,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0Y-`IM<V=I
M9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R(").;R!S92!H82!E
M;F-O;G1R861O(&QA(&ED96YT:61A9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3@@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S-@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDX(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ-3`*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B57-U87)I;R(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B66$@
M97AI<W1E(&5L(&YO;6)R92!D92!U<W5A<FEO(%PB)7-<(BXB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*
M;7-G<W1R(")5<W5A<FEO.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B57-U87)I;SH@(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E
M<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B57-U87)I;W,@96X@96P@<VES
M=&5M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z8F5K:7-T
MX6XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP
M.C(V.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B3F\@97AI<W1E(&5L(&1I<F5C=&]R:6\@5D93+B(*"B,Z(&-O;F9I
M9R\N8F%K+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB
M"FUS9W-T<B`B075S96YC:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8V
M"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S
M='(@(DQA<R!U8FEC86-I;VYE<R!VX6QI9&%S(&5N8V]N=')A9&%S(&EN8VQU
M>65N.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I
M9"`B5F%L:61I='DB"FUS9W-T<B`B5F%L:61E>B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.3<*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N(@IM<V=S='(@(E9A;&]R(&5N(&UI;G5T;W,@82!P87)T:7(@9&4@86AO
M<F$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B16P@=F%L;W(@
M97AC961E(&5L('1A;6'Q;R!MX7AI;6\@9&4@)7,N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(R-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C8@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3`@
M;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A
M;'5E<R(*;7-G<W1R(")686QO<F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R(")686QO<F5S(&$@<V5L96-C:6]N87(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0Y"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*
M;7-G<W1R(")687)I86)L92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#4*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R
M(")696YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q
M.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(DAA(&9A;&QA
M9&\@;&$@8V]M<')O8F%C:?-N("T@97-T92!M96YS86IE('!U961E(&AA8F5R
M<V4@9F]R>F%D;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P
M,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:?-N(@H*(SH@8V]N9FEG
M+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O
M;G1R;VPB"FUS9W-T<B`B0RX@=F5R<VEO;F5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`B06QI;F5A8VGS;B!V97)T:6-A;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G
M:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B36%R9V5N('9E<G1I8V%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I8V%L.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B375Y(&%L=&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6:65T($YA
M;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+RYB86LO;FQS+G!H<"YD
M:7-T.C$Y-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6
M:65T;F%M:71A("A625-#24DI(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.CDW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(E9E<B`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@
M(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B5F5R('5N82!P
MX6=I;F$@=V5B(&5X=&5R;F$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.#,P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS
M9W-T<B`B5F5R(&-O;6\@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:"(*;7-G<W1R("))<VQA<R!6[7)G96YE<RP@0G)I=.%N:6-A<R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DES;&%S
M(%;M<F=E;F5S+"!5+E,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*
M;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ED860B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL
M:71Y.B`B"FUS9W-T<B`B5FES:6)I;&ED860Z("(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET
M86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE(&1E($ET86QI82!M961I
M86YT92!33510(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(D%625-/(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(J&AH4%$5D525$5.0TE!(2$A($5,24U)3D4@34%.54%,
M345.5$4@14P@1U5)TTX@1$4@)7,N(@H*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!P
M;W(@2%144"(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@
M(E=A;&QI<R!Y($9U='5N82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY
M-2!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-PIM<V=I
M9"`B5V%R;FEN9R(*;7-G<W1R(")!9'9E<G1E;F-I82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM
M<V=S='(@(DUI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0<F5V:7-I\VX@
M9&5L('1I96UP;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")$
M871O<R!D96P@=&EE;7!O('-U;6EN:7-T<F%D;W,@<&]R(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B
M5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I
M9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R\N8F%K+W)E9VES=')Y
M+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B4V5D92!7
M96(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7
M965K;'DB"FUS9W-T<B`B4V5M86YA;&UE;G1E(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B0FEE
M;G9E;FED;R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE('1O("5S(@IM<V=S='(@(D)I96YV96YI9&]S(&$@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`B0FEE;G9E;FED;RP@)7,B"@HC.B!C;VYF:6<O+F)A:R]N
M;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*
M;7-G<W1R(")/97-T92`H25-/+3@X-3DM,2DB"@HC.B!C;VYF:6<O+F)A:R]N
M;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB
M"FUS9W-T<B`B3V5S=&4@*$E33RTX.#4Y+3$U*2(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X"FUS9VED(")797-T97)N
M(%-A:&%R82(*;7-G<W1R(")3X6AA<F$@3V-C:61E;G1A;"(*"B,Z(&-O;F9I
M9R\N8F%K+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO
M9VEN/R(*;7-G<W1R("*_477I(&%P;&EC86-I\VX@9&5B97+M82!M;W-T<F%R
M("5S(&%L(&EN:6-I87(@;&$@<V5S:?-N/R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/R(*;7-G<W1R("*_0W7A;"!E<R!E;"!C87+A8W1E<B!D96QI
M;6ET861O<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("*_
M0W7A;"!E<R!E;"!C87+A8W1E<B!D92!C:71A9&\_(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@
M075S=')A;&EA(&UA<"(*;7-G<W1R(")-87!A(&1E(&QO8V%L:7IA8VGS;B!D
M92!!=7-T<F%L:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R(")1=>D@9F%S97,B"@HC.B!C;VYF:6<O
M+F)A:R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M4&QU9VEN<R!H86)I;&ET861O<R!D96P@961I=&]R(&1E('1E>'1O(&5N<FEQ
M=65C:61O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D%N8VAU<F$B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B5VED=&@@:6X@
M0U-3('5N:71S(@IM<V=S='(@(D%N8VAU<F$@96X@=6YI9&%D97,@0U-3(@H*
M(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R(")!;F-H=7)A
M(&1E;"!M96[Z("5S(&EZ<75I97)D;R`H9&ES<&]N:6)L92!E;B!L82!P<O-X
M:6UA('-E<VGS;BDZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G
M<W1R(")!;F-H=7)A(&1E(&QA('1A8FQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B
M"FUS9W-T<B`B56YI9&%D97,@9&4@86YC:'5R82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB
M"FUS9W-T<B`B06YC:'5R83HB"@HC.B!C;VYF:6<O+F)A:R]R96=I<W1R>2YP
M:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS9W-T<B`B
M5FEE;G1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5FEE;G1O(&UA='5T
M:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S
M<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")696QO8VED860@9&5L('9I96YT;R!E
M;B!N=61O<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7
M:6YD.B(*;7-G<W1R(")6:65N=&\Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9I96YT;SH@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB
M"FUS9W-T<B`B4V%B:61U<NUA(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN
M<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")$97-E;W,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B16UP;&5O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")$:7)E8V-I\VX@9&5L('1R
M86)A:F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496SI9F]N;R!D96P@=')A
M8F%J;R(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP
M:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F
M:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R(").^FUE<F\@97)R\VYE;R!D92!C86UP;W,@96X@;&$@;.UN96$@)60N
M(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E9"XB"@HC.B!L:6(O1FEL92]#4U8N
M<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D[Z;65R
M;R!E<G+S;F5O(&1E(&-A;7!O<RX@4V4@97-P97)A8F%N("5D('D@:&%Y("5D
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N
M(@IM<V=S='(@(D]F9G-E="`E9"!E<G+S;F5O(&%L(&QE97(@=6X@87)C:&EV
M;R!61E,N(@H*(SH@8V]N9FEG+RYB86LO<F5G:7-T<GDN<&AP+F1I<W0Z,C0U
M"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R
M86EN=',B"FUS9W-T<B`B3&EM:71A8VEO;F5S(&+A<VEC87,@6#4P.78S(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B57-O(&1E(&-L879E(&5X
M=&5N9&ED82!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*
M;7-G<W1R(").;VUB<F4@86QT97)N871I=F\@9&4@87-U;G1O(%@U,#EV,R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A
M9&]R(&1E(&-L879E(&1E(&%S=6YT;R!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B17AT96YS:6]N97,@6#4P.78S(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S='(@(D%!
M04$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$Q
M,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("*A36%P82!D92!986AO;R$B
M"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R
M;'DB"FUS9W-T<B`B06YU86QM96YT92(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N(@IM<V=S
M='(@(EEE;65N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV-@IM<V=I9"`B665S(@IM<V=S='(@(E/M(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@
M22!!9W)E92(*;7-G<W1R(")3[2P@;&\@86-E<'1O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(D5S=.$@96X@34]$3R!4
M15A43RX@571I;&EC92!E;"!B;W3S;B!;/#Y=('!A<F$@<F5G<F5S87(@86P@
M;6]D;R!765-)5UE'+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T
M(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S
M='(@(DYO(&1I<W!O;F4@9&4@<')I=FEL96=I;W,@<&%R82!C<F5A<B!MX7,@
M9&4@)60@8FQO<75E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,C0*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYO(&5S=.$@
M875T96YT:69I8V%D;RXB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P
M.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I
M;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B3F\@<'5E9&4@:6YC;'5I<B!E
M;"!C87+A8W1E<B!<(EQ<7"(@96X@96P@;F]M8G)E(&-O;7!L971O+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4U(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.3<U"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D
M9')E<W,N(@IM<V=S='(@(DYO(&EN=')O9'5J;R!U;F$@9&ER96-C:?-N(&1E
M(&-O<G)E;R!VX6QI9&$N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).;R!A<V]C:?,@;FEN
M9W5N;R!D92!L;W,@8V%M<&]S(&1E;"!A<F-H:79O(&EM<&]R=&%D;R!A(&QO
M<R!C86UP;W,@(@HB8V]R<F5S<&]N9&EE;G1E<R!D92`E<RXB"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N(@IM<V=S='(@(DAA('-A;&ED;R!D92!L82!S97-I\VXN(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O
M(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@
M=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L
M(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)4:65N92!Q=64@:6YT<F]D
M=6-I<B!U;B!N^FUE<F\@9&4@=&5LZ69O;F\@;?-V:6P@=N%L:61O+"!S\VQO
M(&3M9VET;W,@8V]N('5N("(*(B<K)R!O<&-I;VYA;"!P87)A(&5L('!R969I
M:F\@9&4@;&QA;6%D82!I;G1E<FYA8VEO;F%L+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+B(*;7-G<W1R(")4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!V86QO
M<B!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS-PIM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T
M;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B4&%R82!U<V%R($%L=&%S('1I96YE
M('%U92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!6
M1E,@8F%C:V5N9"XB"FUS9W-T<B`B5&EE;F4@<75E(&-O;F9I9W5R87(@=6X@
M;6]T;W(@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B
M1&5B92!D97-C<FEB:7(@96P@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&5L
M(&EN9F]R;64N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R
M92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(E1I96YE('%U92!I;G1R
M;V1U8VER(&QA(%523"!A(&QA('%U92!A<'5N=&$@97-T92!V[6YC=6QO(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B
M5&EE;F4@<75E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R(&$@96QI;6EN87(N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")4:65N92!Q
M=64@97-P96-I9FEC87(@=6X@=7-U87)I;R!A(&5L:6UI;F%R+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B5&EE;F4@<75E(&5S<&5C:69I
M8V%R('5N('5S=6%R:6\@82!E;&EM:6YA<BXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T
M<B`B5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@82!A\6%D:7(N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(E1I96YE('%U
M92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@86-T=6%L:7IA<BXB"@HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B5&EE
M;F4@<75E(&5S<&5C:69I8V%R('%UZ2!A8V-I\VX@<V4@96IE8W5T87+A+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS
M9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S
M='(@(E1I96YE('%U92!I;G1R;V1U8VER('5N(&YU979O(&YO;6)R92!D92!C
M871E9V]R[6$N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N
M('!H;VYE(&YU;6)E<B(*;7-G<W1R(")4:65N92!Q=64@:6YT<F]D=6-I<B!U
M;B!N^FUE<F\@9&4@=&5LZ69O;F\@:71A;&EA;F\B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R
M(")(82!E>'!I<F%D;R!S=2!S97-I\VX@)7,N(%9U96QV82!A(&EN:6-I87(@
M<V5S:?-N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X
M"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B4W4@9&ER96-C
M:?-N(&1E(&-O<G)E;R(*"B,Z(&-O;F9I9R\N8F%K+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")$:7)E
M8V-I\VX@1&4Z(@H*(SH@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-C<@
M8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z-S<*(SH@8V]N9FEG+RYB86LO
M<')E9G,N<&AP+F1I<W0Z.#4@8V]N9FEG+RYB86LO<')E9G,N<&AP+F1I<W0Z
M.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B4W4@:6YF;W)M
M86-I\VXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E
M9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@
M(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BXB"FUS9W-T<B`B(@HB2&$@8V%M8FEA9&\@<W4@9&ER96-C:?-N(&1E($EN
M=&5R;F5T(&1E<V1E(&5L(&-O;6EE;GIO(&1E('-U('-E<VGS;B`E<RX@4&]R
M("(*(G)A>F]N97,@9&4@<V5G=7)I9&%D('1I96YE('%U92!V;VQV97(@82!I
M;FEC:6%R(&QA('-E<VGS;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(E-U(&YO;6)R
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"B)3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!A
M\6%D:7(@=7-U87)I;W,N(%-I('%U:7-I97)A('5S87(@(@HB2&]R9&4@<&%R
M82!A9&UI;FES=')A<B!C=65N=&%S(&1E('5S=6%R:6\L('1E;F1RX2!Q=64@
M=71I;&EZ87(@=6X@;6]T;W(@9&4@(@HB875T96YT:69I8V%C:?-N(&1I<W1I
M;G1O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B)3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!L
M:7-T87(@=7-U87)I;W,L(&\@<V4@:&$@(@HB9&5S:&%B:6QI=&%D;R!L82!C
M87)A8W1E<NUS=&EC82!P;W(@86QG^FX@;6]T:79O+B(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)0
M87)E8V4@<75E(&AA(&-A;6)I861O('-U(&YA=F5G861O<B!D97-D92!E;"!C
M;VUI96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B`B"B)R87IO;F5S(&1E('-E
M9W5R:61A9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@8G)O
M=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B
M4W4@;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A(&-A<F%C=&5R[7-T:6-A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@HB16P@;F%V96=A9&]R(&YO(&%D;6ET92!E<W1A(&]P8VGS
M;B!D92!I;7!R97-I\VXN(%!R97-I;VYE($-O;G1R;VPO0V]M86YD;R`K("(*
M(E`@<&%R82!I;7!R:6UI<BXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N
M9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(EIO;F$@:&]R87)I82!A8W1U86PZ(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(E-E(&AA(&-A;6)I861O('-U(&ED96YT:61A
M9"!P;W(@;VUI<VGS;BXB"@HC.B!C;VYF:6<O+F)A:R]P<F5F<RYP:'`N9&ES
M=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B
M261E;G1I9&%D('!O<B!O;6ES:?-N.B(*"B,Z(&-O;F9I9R\N8F%K+W!R969S
M+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@
M(DYO;6)R92!C;VUP;&5T;SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DY
M"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")392!H
M82!A9V]T861O('-U('1I96UP;R!D92!C;VYE>&GS;BXB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9
M;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(DQA(&YU
M979A(&-O;G1R87-E\6$@<&%R82`E<R!E<SH@)7,B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*
M;7-G<W1R(")392!H86X@86-T=6%L:7IA9&\@<W5S(&]P8VEO;F5S('/S;&\@
M<&]R(&QA(&1U<F%C:?-N(&1E(&QA('-E<VGS;BXB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+B(*;7-G<W1R(")392!H86X@86-T=6%L:7IA9&\@<W5S(&]P
M8VEO;F5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E-E
M(&AA(')E86IU<W1A9&\@<W4@8V]N=')A<V7Q82(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET
M:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB4V4@:&$@<F5A
M:G5S=&%D;R!S=2!C;VYT<F%S9?%A+"!C;VUP<G5E8F4@96P@8V]R<F5O(&4@
M:6YI8VEE('-E<VGS;B!C;VX@<W4@(@HB;G5E=F$@8V]N=')A<V7Q82XB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z-S,S"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+B(*;7-G<W1R("),82!C;VYT<F%S9?%A(&AA(&5X<&ER
M861O+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I
M9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B4V5R=FED;W)E<R!R
M96UO=&]S.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q."!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(EEU9V]S;&%V:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7)E(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-@IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(EIA;6)I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S
M='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS
M9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&QI8B](;W)D92]497AT
M+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O
M=&5D(%1E>'1=(@IM<V=S='(@(EM/8W5L=&%R('1E>'1O(&-I=&%D;UTB"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P
M;W)T72(*;7-G<W1R(");26YF;W)M92!D92!P<F]B;&5M85TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");36]S=')A<B!T97AT;R!C:71A
M9&\@+2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");36]S=')A<B!T97AT;R!C:71A
M9&\@+2`E<R!L[6YE87-=(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML[6YE
M82`E<R!D92`E<UTB"@HC.B!L:6(O2&]R9&4N<&AP.C$U-30@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E]!9&UI;FES=')A8VGS;B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM
M<V=I9"`B7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q
M"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BP7)?8F]L(&1A=&]S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")%7VQI;6EN87(@9FEL
M82(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R
M(")?1W)U<&]S(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B
M7TAE;'`B"FUS9W-T<B`B05]Y=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P:65D861E<R!D92!?:6UA9V5N
M+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I
M;B(*;7-G<W1R(")?26YI8VEA<B!S97-I\VXB"@HC.B!L:6(O2&]R9&4O365N
M=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R(")?4V%L:7(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R(")-;V1I9FEC
M87(@7W;M;F-U;&\N+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS
M9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W!C:6]N97,B"@HC.B!L:6(O87!I
M+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")?4')I=FEL
M96=I;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R
M(")?16QI;6EN87(@=NUN8W5L;RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(D-O;E]F:6=U<F%C+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM
M<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<&EE9&%D
M97,@9&4@7W1A8FQA+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`B7U5S=6%R:6]S(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")D:7)E8V-I
M;VYE<R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I
M9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B9&5S=&EN871A<FEO(&1E
M<V-O;F]C:61O(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3<*;7-G:60@
M(F-A;&5N9&%R(@IM<V=S='(@(F%G96YD82(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M
M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6$B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T
M<'5T(&9I;&4B"FUS9W-T<B`B;F\@<V4@<'5E9&4@8W)E87(@96P@87)C:&EV
M;R!D92!D97-T:6YO(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")N;R!S92!P
M=65D92!A8G)I<B!E;"!O<FEG96XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(G!U;'-E
M(&%Q=>TB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G
M:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R(")E<G)O<B!D
M92!L[6YE82!D92!C;VUA;F1O(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@
M(F5R<F]R(&1E(&-O;F9I9W5R86-I\VXB"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI
M<W-I;F<B"FUS9W-T<B`B9F%L=&$@=6X@87)C:&EV;R!C<NUT:6-O(&1E;"!S
M:7-T96UA(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")E<G)O<B!D92!F;W)M
M871O(&1E(&1A=&]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS
M,`IM<V=I9"`B961I="(*;7-G<W1R(")M;V1I9FEC87(B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R(")E;G1R861A(&YO(&5N8V]N=')A9&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN
M9R(*;7-G<W1R(")D97-C96YS;R(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HX.38*;7-G:60@(F9I;&4B"FUS9W-T<B`B87)C:&EV;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI
M8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B9&5L("5S("@E<RD@
M82!L87,@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G9E;G1O<V\B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*
M;7-G<W1R(")H.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R(")N;VUB<F4@9&4@86YF:71R:?-N(&1E<V-O;F]C:61O(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM<V=I9"`B:6UM961I871E
M(@IM<V=S='(@(FEN;65D:6%T86UE;G1E(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN;&EN
M92(*;7-G<W1R(")E;B!L[6YE82(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@
M(F5R<F]R(&1E(&5N=')A9&$O<V%L:61A(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O
M<B(*;7-G<W1R(")E<G)O<B!D92!S;V9T=V%R92!I;G1E<FYO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R(")L[6YE87-=(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(F/S9&EG
M;R!D92!E<G)O<B!M:VES;V9S("5D(&%L(')E86QI>F%R($E33RXB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<P"FUS9VED(")M
M;2(*;7-G<W1R(")M;2(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@U
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S0*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I9"`B;F%M92(*;7-G<W1R(")N
M;VUB<F4B"@HC.B!L:6(O2&]R9&4O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I
M;7!L96UE;G1E9"(*;7-G<W1R(")S:6X@9&5S87)R;VQL87(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP
M;&5M96YT960B"FUS9W-T<B`B8?IN(&YO('-E(&AA(&1E<V%R<F]L;&%D;R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM
M<V=S='(@(FYO=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P
M;W)C96YT86IE(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<T
M"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R(")P<FEV:6QE9VEO
M(&1E;F5G861O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G#M>&5L
M97,B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@
M(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")E<G)O<B!R96UO
M=&\@9&4@<')O=&]C;VQO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")E;B!A=6UE
M;G1O(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED
M(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G-E<G9I8VEO(&YO(&1I
M<W!O;FEB;&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G
M:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B;6]S=')A<B!D:69E<F5N
M8VEA<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*
M;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@
M<&]R($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS
M9W-T<B`B97-T86)L92(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP
M.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(F5R<F]R(&1E;"!S
M:7-T96UA(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A
M<VL@;&ES="(*;7-G<W1R(")T87)E87,B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S
M='(@(F9A;&QO('1E;7!O<F%L(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B97-C<FEB82!D;W,@
M=F5C97,@;&$@8V]N=')A<V7Q82!P87)A(&-O;F9I<FUA<FQA(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEC861O(@H*(SH@;&EB+TAO
M<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M<VEN(&YO;6)R92(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G
M:60@(G5S97(@<V5L96-T(@IM<V=S='(@(G5S=6%R:6\@<V5L96-C:6]N861O
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R(")W.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T
M:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!O+WIH7T-.+G!O````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8U,38W,2`Q,#4Q
M-30S-#$T,B`P,3<U,S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!(;W)D92!3:6UP;&EF:65D($-H:6YE<V4@5')A;G-L
M871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@5V%N9TAE;F=796XN"B,@5V%N
M9TAE;F=796X@/'=H=T!M>3$V.2YC;VT^+"`R,#`Q+@HC($1A=FED($-H86YG
M(#QD879I9$!T;78N9V]V+G1W/BP@,C`P,2X*(R!L:6%O8FEN(#QL:6%O8FEN
M0&II=&4N;F5T/BPR,#`T+@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,BXP7&XB"B)297!O<G0M37-G:60M0G5G
M<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T
M93H@,C`P,2TP-BTQ."`R,CHP-2LP.#`P7&XB"B),87-T+51R86YS;&%T;W(Z
M(&QI86]B:6X@/&QI86]B:6Y`:FET92YN970^7&XB"B),86YG=6%G92U496%M
M.B!#:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R
M<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]1T(R,S$R7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I
M=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(,SL
MQ[`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*+_L
MO=V\_"`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B`H)7,@S.S'L"DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*+WQS.PI(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0HC+"!F=7IZ>0IM<V=I9"`B("AT
M;VUO<G)O=RDB"FUS9W-T<B`BP_?,["(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*-?R
MS.PI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`BT]HB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BLKO*Q]*[N/;$O\*\(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B)R5S)R"RN\K'TKNX]M/0T*>U
MQ-&AU/$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ
M,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G
M)7,G(,G0SK34VB!(3U)$12"UQ->BLN'.Q+S^*%)E9VES=')Y*=;0Q>36PRXB
M"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"XB"FUS9W-T<B`BU=*RN[6]("5S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D
M960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@TM&SR;FF
MO-/(Z[6]T\.[I]?IS[7-L];0+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G
M)7,G(-+1O-/(Z\BHS][/M<VS+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T
M<B`B)R5S)R"RHLZTO:C!HCH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E<R#2T<BAS_L@)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES
M('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`BU^Z]_"`E9"#,[,;X
MS_/4I+&H(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@L;C-
M_,*\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M)7,@UKC.QB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*
M;7-G<W1R("(E<R#.K+NDLMG7]R`M(,BWR,\B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(->BLN$B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S(,VLTN+/[L2_(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(-+1M.;4
MVB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(-3:("5S
M("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M
M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H
M96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(M&AU/'$^L_KTJJR
MV=?WM<3,]<2_+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B
ML=C0Z-*J("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R"WUB(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[
MM;T@)7,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(@
M)7,@M;T@)7,@N;(@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`BS:C1MK*^(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M0V%L96YD87(B"FUS9W-T<B`BR-7`^B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($YO=&5P860B"FUS9W-T<B`B)7,@+2"QN,W\PKPB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD
M97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0Q,`HC+"!F=7IZ>0IM<V=I9"`B+"!G=7-T
M:6YG("(*;7-G<W1R("(L(-7SM^<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"#5\[?G("5S
M("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BRQ
MY+NOP;^TTR`E<R"UO2`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@
MT:'4\2`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM
M<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`BQ/JUQ-#%SZ(B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@
M1F]R;6%T(@IM<V=S='(@(L3ZM<30Q<^B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(-"ARK'6
MQB(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*
M;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("+)S]*[TK,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("*TR\?XO^FQV-#K
MTJK6N+:HROV^W;_BM_[.\;;++B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*
M;7-G<W1R("*WHLGZP<O2N[CVT<_6V+7$M.W.\R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
MT_N\T\/<T\J\_BR[N=#HTJK3T-*[N/8@4$=0(+FKOZK#W-2_+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(M/[T>G6I-+1QZG#^[7$T\J\_BR[N=#HTJK3T-*[
MN/8@4$=0(+FKOZK#W-2_+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("+3^[WBP]S3RKS^++NYT.C2
MJM/0TKNX]KFKOZH@4$=0(,/<U+\LR[W#W"!01U`@P]S4ORS2U+RPO]K![BXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`BT_O6M-#0T\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!01U`@
MP]S4ORS+O</<(%!'4"##W-2_+-+4O+"_VL'N+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`BT_N]XL/<T\J\_BR[N=#HTJK3T-*[N/:YJ[^J(%--24U%(,/<U+\LR[W#
MW"!334E-12##W-2_+-+4O+"_VL'N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`BT_O6M-#0
MT\J\_L>IP_LLN[G0Z-*JT]#2N[CVN:N_JB!3+TU)344@P]S4ORS+O</<(%,O
M34E-12##W-2_+-+4O+"_VL'N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(M/[O-/#
MW-/*O/XLN[G0Z-*JT]#2N[CV(%--24U%(+FKOZK#W-2_+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*(RP@9G5Z>GD*;7-G
M:60@(D%-($-L;W5D<R(*;7-G<W1R("+4QL&_(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B
M04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R(")!4$D@L>"ZQ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S
M='(@(KG8T]K5XKCVL>"\K<;W(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(KG8T]HN+BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED
M(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BR*C/WK*[U^,LSMZWJ+VHP:(@5D93(,2_PKPN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`BR*C/WK*[U^,LSMZWJ+VH
MP:(@5D93(,[$O/XN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*(RP@
M9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`BQ/JU
MQ-#%SZ(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*
M;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`BR+?(S\/<PNLB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("+5R[K%TM&VL[WA
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C
M8V]U;G1I;F<B"FUS9W-T<B`BO>'5RB(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I
M9"`B061D(@IM<V=S='(@(M#"U/8B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R
M-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P
M(@IM<V=S='(@(M#"U/;/PKRVU^DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*
M;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(M#"U/;/PKRV
MR*C/WB(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`BU-JTR]#"U/:CNB(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W
M($=R;W5P(@IM<V=S='(@(M#"U/;3P[NGU^DB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("+0PM3V
MR*C/WB(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC
M.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R
M;W5P('1O(%PB)7-<(B(*;7-G<W1R("+0PM3VS\*\MM/#NZ?7Z2`G)7,G(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M7"(E<UPB(@IM<V=S='(@(M#"U/;/PKRVR*C/WM;!("<E<R<B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@
M(M#"U/;2N[CVT\.[ISHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@
M(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("+0PM3VTKNX]K/)U+$Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B
M"FUS9W-T<B`BT,+4]K;4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`BT,+4]B`E<R#.JB!-;WII;&QA(%-I
M9&5B87(@LLNUI2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O
M:SHB"FUS9W-T<B`BT,+4]K6]SM*UQ,VHT;:ROB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B
M061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("+0PM3VM;W.TK7$S:C1
MMK*^(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM
M<V=S='(@(M#"U/;3P[NG(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I
M;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(M+1T,+4]B`G)7,G(+6]S[7-
ML];0+B"UJ\[>MZC0PM3VMN[-XK7$UZ*RX=#%SZ(Z("5S+B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S
M='(@(M+1T,+4]B`G)7,G(+6]S[7-L];0+B#$^L_6U-J_R=+4O?C0T+7'PKS!
MRRXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I
M9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+0PM3VT\.[
MI[7$N:;$W+6QQ["QN[G8L=4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BM=C6MR(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R("+-J-&VLKXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N
M<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`BL\G.JKG<P.W4L2`M(,ZJQN3+
M_-/#NZ?%Y-;#R*C/WB(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("*YW,#M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(KGCN.:YW,#M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`BL**XN[JY(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R("*PHK;[L,W$X=''(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("*PHK;[O+#`^]''(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM
M<V=I9"`B06QI87,B"FUS9W-T<B`BL?##^R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G
M:60@(D%L:6=N(@IM<V=S='(@(K'PP_LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")!;&EG
M;FUE;G0Z(@IM<V=S='(@(K_-NZ>VRR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(LOYT]#2T='IUJ2UQ-/#NZ<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@
M(LOYT]#3P[NGU^DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G
M:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("++^=/0R*C/WB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*
M;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D
M9')E<W-E<R(*;7-G<W1R("+4RM#MMN"X]K7GU]/3RKS^M=C6MR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`BTM&TYM3:(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T
M<B`BL>2X_"!)35-0(+7'PKPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("*Q
MY+C\($E-4U`@P]S"ZR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3D*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(K'DN/P@
M24U34"#3P[NG(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*
M(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S
M='(@(K'DN/S$H[#F(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G
M:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`BL>2X_,2CL.8B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G
M<W1R("*QY+C\Q*.PYB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(L/`RO3(^,2FT<<B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM
M<V=S='(@(M*[N/:RN[K/MZBUQ-:UL;O*N=/#+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO
M=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(K>BR?K!R]*[N/:T[<[S
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`BL+*UP+;[
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(K"RN.?`K2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(K"RN>?`K2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N
M;VYY;6]U<R!0<F]X>2(*;7-G<W1R("+$Y,/[M/K`[2(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("+$S[RK
MUMXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(K"RS.&YS[RPL,VV^[*\M.\B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E
M>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(M.FT\.SS-#R
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"B,L(&9U>GIY"FUS9VED
M(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(M.FT\.SS-#R(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(M.FT\.SS-#RTM&^S=#W(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H
M87)E<R(*;7-G<W1R("+3IM/#M;W+^=/0S\*\MKFRS^TB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*
M;7-G<W1R("+%^M>\(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R("++Q-3"(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M("*PHL"MLJ[.Q"`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("+1N<OUSL2\_K3ST*$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(M&YR_7.Q+S^P_NSQB(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B
MQ/K(M[:HTJK)OK/]("5S(+7$UZ*RX<+P(#\B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@
M86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+$^LBWMJC2JLF^L_T@)R5S
M)R#2U+RPR,ZZSM?3T\.[I]?I(#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E
M;G1I;F$B"FUS9W-T<B`BL**X^<VB(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M
M96YI82(*;7-G<W1R("+1Q\/`Q.'1QR(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("+1
MQ\/`Q.'1Q\[$("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07)U8F$B"FUS9W-T<B`BL*+"L[#-(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R
M("*PHLFMR\G(NK6Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS
M9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM
M<V=S='(@(M''UMXOS*O&O='SM=C'^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R("+6M-#0SJR[
MI++9U_?'L,_4RK[(M\C/MM2[L+_R/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`BRM3-O,F^
ML_W2N[CVLKNTYM3:M<33P[NGU^DN(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BRM3-O,F^L_W2N[CVLKNTYM3:M<3(
MJ,_>+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`BRM3-O+'@O*W2N[CVLKNTYM3:M<33P[NGU^DN(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N
M;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(LK4S;RQX+RMTKNX]K*[M.;4
MVK7$N;+/[2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I
M9"`B071T<FEB=71E<R(*;7-G<W1R("+*]-#4(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R("*PR]3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S
M='(@(K#$M//`^]''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G
M<W1R("*PPK78P/LB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-R>7-Q;#H@U=*RN[6]
MR_G0Z-*JM<0@:6UA<"#`J=6YU^F\_BXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@
M9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B
M075T:%]C>7)U<SH@M_[.\;;+LJ+.M,SAN:FXP\_NUJ>SUBXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]C<GEU<SH@U=*RN[6]R_G0Z-*JM<0@:6UA<"#`J=6YU^F\_BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B(@HB075T:%]F='`Z(-72LKNUO<OYT.C2JK7$($944"#`J=6Y
MU^F\_B['Z];8T,*QX-+K(%!(4""RHL?2O-/(ZR`M+65N86)L92UF='`@T:$B
M"B+/[BS`_<CG(&-O;F9I9W5R92`M+65N86)L92UF='`B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]I;6%P.B#5TK*[M;W+^=#HTJJUQ"!)34%0(,"IU;G7Z;S^+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B
M-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VMR8C4Z(-72LKNUO<OYT.C2JK7$(&MR8C4@P*G5N=?IO/XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U
M=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S
M"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B#5TK*[M;W+^=#HTJJUQ"!,
M1$%0(,"IU;G7Z;S^+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HT,+4]M/#NZ<@)7,N(+?^SO'&
M][O8TZ8Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M
M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(,[>MZBX_-#"T\.[IR`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER
M960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC
M86PZ(-72LKNUO<OYT.C2JK7$($U#04P@P*G5N=?IO/XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]S;6)A=71H.B#5TK*[M;W+^=#HTJJUQ"!S;6)A=71H(,"IU;G7
MZ;S^+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(M'IUJ3*I[#<+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`BT>G6I,JGL-PN("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B4D%$2553(-'IUJ2T[<[S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1E10(-'IUJ2T[<[S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B1E10(-'IUJ2T[<[S+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(K_)T\.U
MQ-?6MLXZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M("*PHLC[L-V]KB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I
M9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G
M:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BL;.^L-'5R:LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(K&SOK#1U<FK(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(*;7-G<W1R(")K97)B97)O<R##W,+KM.W.\RXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(@IM<V=S='(@(FME<F)E<F]S(-/#NZ?#^[3MSO,N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("*PS;G^PNW(NK6Z
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("*PS<'6(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@IM<V=S='(@(K*HPMZUQ+JCSL0@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`BP\^\T\"M
MN?HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("*PS;#-
MMN#+N2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BU=*RN[6]("5S(+7$P."Q\+:HTN4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<S"B,L(&9U>GIY"FUS9VED(")"87-E;&EN92(*;7-G<W1R("*RKL#[
MU\@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(K#7MNW"
MWLNY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("*QR,#[
MRK$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`BLJ[`^]?(
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`BL;3$_B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`BL-G$O;3SR+JUNB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("*RN[6D(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`BR?K(U2(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,@M<3`X+'PMJC2Y2XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K
M(%-E='1I;F=S(@IM<V=S='(@(L?XO^G%Y-;#(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(L?XO^G`X-#-(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(K36S.4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(K*CP/O.K-''(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(LKIQZDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DAO
M<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN
M82(*;7-G<W1R("*RJ,NYQ.'1Q[K-NMK(^[CGSJS$QR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B0F]T:"(*;7-G<W1R
M("+4PB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(K*I
MM,3-W\3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("*RJ,ZLS-BUNB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R("*PS<[W(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R
M>2(*;7-G<W1R("+3HLKTTZ&VR-'SP>RUV"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(L[$P+,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=6QG87)I82(*;7-G<W1R("*QH[S3P/O1QR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U
M;&QE=&5D($QI<W0B"FUS9W-T<B`BS^[$O[?[NL4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`BLKR\JL3)MZC+]R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`BLKS"H;7/(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@
M(L3:R-VYW,#MS[7-LR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),(+?6LKRUXR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I
M;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U
M-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`BR-7`^B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS9W-T<B`B
MP>.\MK?G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(KSMQM+5KR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@
M(K^FPO/"H2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS
M9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T
M<B`BSMZWJ,F^L_W.Q+S^(%PB)7-<(BXB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO
M;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H
M<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,B"FUS9W-T<B`BSMZWJ,&JN_K6P2!)34%0(+?^SO'&
M]SH@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(L[>MZC)OK/]SL2\_B!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(KS3Q,.T\R(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(LBAS_LB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(LBAS_O.RLSBL:BXYB(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(L[>MZC)OK/]SL2\
M_B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO
M8V]P>2YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ,F^L_W$O\*\(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO
M=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ,F^L_W$O\*\(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R
M."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+B(*;7-G<W1R("+.WK>HR;ZS_3O3T,_"O+:TYM3:("@E
M<RDB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("+.WK>HUMC7Z:&CR_G,X;FIM<2\Q\*\ROW$
MO]/KS\C'L,OYL:.TYK7$ROV^W;*[M_LN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("+.
MWK>HM*O+S=#%SZ*UO=:XMJBUQ+K%PNLN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0V%P92!697)D92(*;7-G<W1R("*W\+7#O<<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS
M9VED(")#87!T:6]N(@IM<V=S='(@(M&AS^XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@
M(D-A<G)I97(B"FUS9W-T<B`BM]NZ[,FK(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S
M='(@(K^JPOS(NK6Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("+2QK:O
MM>>[L"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*
M;7-G<W1R("+2QK:OM>>[L"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL<&AO
M;F4B"FUS9W-T<B`BTL:VK[7GN[`B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`BR/NV
M^\S8SL0@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(D-E
M;G1E<B(*;7-G<W1R("*]J,&B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(M;0M\>YLKK-N?HB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A
M;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`BUM#%MR`H25-/+3@X-3DM,BDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B
M0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("+&OM:DS[B]VB(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"B,L(&9U>GIY"FUS
M9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("+&OM:DS[B]VB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#
M97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("+&OM:DLM_"U"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("+5I[7#(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(KC\N,0B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(LBWR,_#W,+K(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@
M(D-H87(B"FUS9W-T<B`BU:>UPR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI
M;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS
M9W-T<B`BUL?`^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(M;0N?HB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI
M;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(KSRS.76T,[$("A'
M0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H
M:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(K>QS.76T,[$("A"
M:6<U*2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(M&AU/'#W,+K(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.`IM<V=I9"`B
M0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`BT:'4\=*[N/;3P[NGP_LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(LC5QMK/U,J^M[W*O3HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR
M:7-T;6%S($ES;&%N9"(*;7-G<W1R("+*I;6NM;HB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DS
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@)7,@M<3`X+'PMJC2Y2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F
M=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`BR-7`^B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R
M($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R.`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
MROV^W;_BLNG1KR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E
M<CH@)7,B"FUS9W-T<B`BR;ZS_=/#NZ<Z("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"B,L
M(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BT:'4\=*[
MSKO3P[NGT\/2U-#"U/8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV
M,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`BL+3*\['JO/R\
MS-#X(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@
M(KG8L=6TL+_:(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@
M(D-L;W5D<R(*;7-G<W1R("+4QL&_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%
M87)L>2(*;7-G<W1R("+4QL&_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G
M<W1R("+4QL&_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',B"FUS9W-T<B`BO\:_QLNYR+JUNB(*"B,Z('1E;7!L871E<R]P
M;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B
MN.?"U['(T<<B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`BT=7)
MJR(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS
M,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O
M;&]R(%!I8VME<B(*;7-G<W1R("*U]\FKQ<PB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#0V"B,L(&9U>GIY"FUS9VED(")#;VQO=7(@<V5L96-T
M:6]N(@IM<V=S='(@(KSTQ]#1H=3Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*(RP@9G5Z>GD*;7-G:60@(D-O;',Z
M(@IM<V=S='(@(LVVQK$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R
M("*_J,VH(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM
M86YD(@IM<V=S='(@(L/\P>XB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*
M;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`BP_S![KW%L;XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE
M;G0B"FUS9W-T<B`BQL#"VR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("+-J-/#
MP_LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("*_QL2F
MPMXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(KFKR[XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R("+2T<WJL\DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`BS/6\
M_B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I
M;VYS(@IM<V=S='(@(LSUO/XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*
M;7-G<W1R("+%Y-;#(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M
M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("+%Y-;#(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`BQ>36PR`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B
M"FUS9W-T<B`BR+?(S\/<PNLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*
M;7-G<W1R("*XU;G[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("*XU;G[N;*ZS;GZ
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(L&L
MO=/*I[#<.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(L&L
MO=/*I[#<.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M.3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BP:R]T];!N:N_JL/<U+^W_L[Q
MQO?*L=3BOMR^^"X@U*W2\CH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*2(*;7-G<W1R("+!K+W3UL&YJ[^JP]S4O[?^SO'&]\JQU.*^
MW+[X+B#4K=+R.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(L&LO=/6P2!&5%`@SL2\_K?^SO'&]\JGL-PN(@H*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(LVH
MT;;*_;[=TM&SR;FFM<34]KS3M;W$^K7$S:C1MK*^UM`NT\/*\['JL+3/PL'0
MS^[$O]+4O.S*TSHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB
M(@IM<V=S='(@(B<E<R<@SL2\_L3:R-TB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(LSUO/XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`BO^*_R\BZM;HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T
M<B`BN:O+OB(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS
M9W-T<B`BP:R]T\JGL-PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(KBTUL;1H=3Q(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("*XY\NYM._`Z+S3(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("*_QLS8M<_-
MWR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(L[>
MMZC2U"!01U`@O-/#W-/*O/XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4N(@IM<V=S='(@(L[>MZC.JB!01U`@UK30T-/*O/['J</[+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BSMZWJ-+4
M(%,O34E-12"\T\/<T\J\_BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(L[>MZC.JB!3+TU)344@T\J\_L>IP_LN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N
M=&%C="X@)7,B"FUS9W-T<B`BSMZWJ+3ROZH@)7,N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`BSMZWJ+#SMJ@@3$1!4""W_L[QQO<B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#4W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("+.WK>HL/.VJ"!,1$%0
M(+?^SO'&]R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(L[>MZBVP<BA
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S
M='(@(L[>MZC!K+W3(%--0B"W_L[QQO<N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS
M9W-T<B`BSMZWJ,&LO=/6P;?^SO'&]R`G)7,G(,JYT\,@1E10.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+.WK>HO:C!HK&^M=C3
M[]'4("5S(,OYT.C2JK7$Q+_"O#HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T82XB"FUS9W-T<B`BSMZWJ+WBP]P@4$=0(,K]OMTN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("+.WK>HO>+#W"!3+TU)
M344@ROV^W2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("+.WK>HR;ZS_;C\
MT,*SS-#R("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(L[>MZC)OK/]N/S0PK/,T/(@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(L[>MZC)OK/]N/S0PK/,T/(@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("+.WK>HOO:V
MJ,K5O/[(R[7$M>?7T]/*O/ZUV-:W+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("+.WK>HOO:VJ,K5O/[(R[7$M>?7T]/*O/ZUV-:W+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(L[>MZBP_+JLU];,Y;:HTN7.Q+S^+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS
M9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES
M=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV
M.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(L[>
MMZBVP<BA("5S+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("+.WK>HML'(H2`E<RXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@
M(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V
M97(N(@IM<V=S='(@(L[>MZC7U,/<U+^W_L[QQO?(H;7#N:N_JL/<U+\N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G
M<W1R("+.WK>HM/*_JB`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(L[>MZBT\K^J("5S+B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(L[>MZBT\K^JSJR[I+FDU_?$H[_I
M("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R("+.WK>HR;ZS_<2_PKP@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`BSMZWJ++IU=(@3$1!4"`@M_[.\<;W+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R("+.WK>H
MML'(H2`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`BSMZWJ+;!
MR*&TYLBAO]C6QK'M*$%#3"DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS
M9W-T<B`BSMZWJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BSMZWJ+;!R*&W_L[QQO>UQ,_@N=C,
MV-#4(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(L[>
MMZBVP<BAM_[.\<;WM<3/X+G8S-C0U"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(L[>MZBVP<BAM_[.\<;W
MM<3/X+G8S-C0U"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`BSMZWJ+&CM.8@)7,@M<3%Y-;#+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+;!R*$@)7,N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BSMZW
MJ+&CM.8@)7,@M<3%Y-;#+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R
M("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(L[>MZBQ
MH[3F("5S(+7$Q>36PRXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BSMZW
MJ+&CM.:X_-#"L\S0\K6].B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("+.WK>HL:.TYB`E<R"UQ,7DUL,N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H
M92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B
M96QO=R!T;R`E<RXB"FUS9W-T<B`BSMZWJ-"TR.LN(,3ZO\G2U,JYT\/(SKK.
MM<3)_;RVL\S0\KORRM:VK[BTUL;/PL/FL\S0\K3ZPNNUO2`E<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(L[>MZBRZ=72
M($Q$05`@(+?^SO'&]RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB
M+B(*;7-G<W1R("+.WK>HM/*_JB`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G
M<W1R("+.WK>HM/*_JB`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`BSMZWJ+#\NJS7ULSEMJC2Y<[$O/XN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*
M;7-G<W1R("+.WK>HN+*XQR`G)7,G.B`E<R"UQ,7DUL,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`BU=*RN[6]($UO>FEL;&$@4VED96)A<BX@Q^O(M\C/('-I
M9&5B87(@RL>W\;3ROZHN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`BSMZWJ+BS
MT^C3P[NG("<E<R<@S\+!T,BHS]ZUO<[$O/Z\T"`G)7,G.B`E<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*(RP@9G5Z>GD*;7-G:60@(D-O
M=6YT960@=&5X="(*;7-G<W1R("+,X<J^Q-K(W2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S
M='(@(KGZO-(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"B,L
M(&9U>GIY"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(M"ARK$B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("*]J,&B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"B,L(&9U
M>GIY"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(KVHP:(B"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"B,L(&9U>GIY
M"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(M&AU/'2N\Z[T,*U
MQ-.UT]#5WR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`BO:C!
MHM?3SL2\_KS0(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BO:C!HM7?
MM<3(J,_>(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(M#%T\._J+K%PNLB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("*_R\+>M=C1QR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`BN<6PS2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T
M(%!H87-E<R(*;7-G<W1R("*UL<>PS^#.NR(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G
M<W1R("*]J,&BU=^UQ,BHS]XB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G
M<W1R("*UL<>PRK&\Y"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!54DP@:7,B"FUS9W-T<B`BM;''L,JQO.0B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T
M<B`BM;''L,_@SKLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`BM;''L,SLQO@B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(K6QQ[#7M+_V.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT
M('-T>6QE(@IM<V=S='(@(K6QQ["WY[CQ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,`HC+"!F=7IZ>0IM<V=I9"`B0W5T(@IM<V=S='(@(KGZO-(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#
M=70@<V5L96-T:6]N(@IM<V=S='(@(KSTQ]#1H=3Q(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0WEP<G5S(@IM<V=S='(@(LC[QM;"M\NY(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S
M='(@(L[WP.^V^\[$("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@
M(L[WP.^V^\[$("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*
M;7-G<W1R("+.]\#OMOO.Q"_.VK_+P+S.Q"`H2T])."U5*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(KW=O\NYLKK-N?HB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("+(
MU2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*
M(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I
M9"`B1&%I;'DB"FUS9W-T<B`BP[_(U2(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H
M<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY
M"FUS9VED(")$871E(@IM<V=S='(@(LC5QMHB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R("+*U;6]R-7&VB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(M&AU/'(U<;:
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED(")$87DB"FUS9W-T<B`B
ML-?,["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`BR;ZS_=/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("+*
MKK;^U,(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$V"B,L(&9U>GIY"FUS9VED(")$96-I;6%L(&YU;6)E
M<G,B"FUS9W-T<B`BT/*ZQ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G
M<W1R("*\]<G9R_7%Q2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT(@IM<V=S='(@(LF^L_TB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R("+7UM#-T=7)JR(*"B,Z(&9R86UE=V]R:R])9&5N=&ET
M>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS
M9W-T<B`BQ*S(S\GMM]W*MK'P(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(L2L
MR,_)[;?=RK:Q\"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`BS/6\_B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS
M,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z
M,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E
M;&5T92(*;7-G<W1R("+)OK/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@0V5L;"(*;7-G<W1R("+)OK/](@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U
M<"(*;7-G<W1R("+)OK/]T\.[I]?I(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S
M='(@(LF^L_TB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE
M=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+)OK/]R*C/WB(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(LF^L_VAHL?EO]73RKS^(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`BR;ZS
M_2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T
M<B`BR;ZS_=/#NZ?7Z2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"B,L
M(&9U>GIY"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(K+ER.N_R<SFM/K$H[#F(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(LF^
ML_T@)R5S)[7$R*C/WB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B
M"FUS9W-T<B`BR+>VJ-*JR;ZS_2`G)7,GM<3(J,_>TM2\L,_"O+;(J,_>(#\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(LF^
ML_W3P[NGU^DB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I
M='DB"FUS9W-T<B`BT:'4\<C5QMHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T
M<B`BN/S0PK/,T/(@)R5S)R#2T<F^L_TN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I
M9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("*UW<O-RK&\Y"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`BM:3"\R(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@
M4')O8FQE;2(*;7-G<W1R("+.RLSBP^C*]B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R("+#
MZ,KV(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@
M(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B
MS[B]VB`HQ^NRSK^\($AO<F1E(+S'PKS.Q+S^*3HB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BS[B]VL?K
MLLZ_O,^US;.YW,#MM<?"O"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("+1T+>B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R("+"MK7CSL*VR"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS
M9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(M?NNO/2
MN]"ARK&UQ,*VM>/.PK;(.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("+"MK7CSL*V
MR#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B
MM-/7\];!T](B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G
M<W1R("*TT]/2UL'7\R(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS
M9VED(")$:7)E8W1O<GDB"FUS9W-T<B`BQ+_"O"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B
M"FUS9W-T<B`BTM0@,C0@T*'*L=;&S]3*OC\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+/
MU,J^T:'/[B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G
M<W1R("+/U,J^N/'*O2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*(RP@
M9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
MS]3*OKCQRKTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS
M9VED(")$:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+/U,J^N/'*O2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$:FEB;W5T:2(*;7-G<W1R("*\JK*\S.$B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R("*RN\F^L_TB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*
M;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M(@IM<V=S='(@(K*[TJK6L;W3M.;(H2!M86EN=&5N86YC92YP:'`B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*
M;7-G<W1R("*UVM*[L<J\Q\*\RL>W\;#\NJS7UK;.P_NSQC\@R.>Y^\K'Q^O1
MH=3Q+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(K;@
MP]?$X;S3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC
M(@IM<V=S='(@(K;@P]?$X;S3N;*ZS;GZ(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(L_"U-@B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`BS\+4V"`E
M<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL
M;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM
M<V=S='(@(L_"U-C)^K/)M<3%Y-;#SL2\_LZJ(%!(4""SS-#R+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L
M:7-T(@IM<V=S='(@(L_"P*VRR[6E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R
M("*UY]?3T\J\_B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV
M97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S
M='(@(K3MSO,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@
M(K;RN<^VX+;[(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B
ML>"\K2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R("*QX+RMQ_B_Z2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@
M(K'@O*W3P[NGU^DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BL>"\K<BHS]XB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(K'@O*W(J,_>(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(&9O<B`E<R(*;7-G<W1R("*QX+RM("5S(+7$R*C/WB(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM
M<V=S='(@(K'@O*W1H<_N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("*QX+RM("5S(+7$R*C/WB(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BL>"\
MK2`E<R"UQ,BHS]XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R("*UV,?X(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`BL*.\L"(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I
M=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-
M3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")%;"!386QV861O<B(*;7-G<W1R("+(^+;[S=^VX"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*
M;7-G<W1R("*UY]?3T\J\_B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I
M9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("*UY]?3T\J\_K78UK<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R
M97-S97,@;75S="!M871C:"XB"FUS9W-T<B`BM>?7T]/*O/ZUV-:WL=C0Z\['
MNL\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B
M16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BM>?7T]/*O/[(M\C/
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R("*Q[<?IM_NZQ2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B
M16UP='D@;65S<V%G92XB"FUS9W-T<B`BO]6PU]#%O/XN(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P
M-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B
M16UP='D@<F5S=6QT+B(*;7-G<W1R("*_U;#7O>&Y^RXB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4T,PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0
M:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS
M9VED(")%;F0@>65A<B(*;7-G<W1R("+$ZK77(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%
M9&ET;W(B"FUS9W-T<B`BM\6T\['@O*W&]R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`BL^"UP+RXQ-K1QR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`BMO+!HLS8P._1
MQR(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP
M:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(K3MSO,B"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@
M(K2KR\V[V+BTRK&WHLGZM.W.\SH@)7,N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L
M971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`BM*O+
MS;O8N+3*L;>BR?JT[<[S.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O
M5&5M<&QA=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("*TJ\O-N]BXM,JQ
MMZ+)^K3MSO,Z("5S+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I
M;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(K2KR\V[V+BTRK&WHLGZM.W.\SH@
M)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R
M("*TJ\O-N]BXM,JQMZ+)^K3MSO,Z("5S+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5S=&]N:6$B"FUS9W-T<B`BL*[)L\3AT<<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R("*PH\C[MNVQR-''(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`BL*[)L\3AT<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("+%M];>(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R("+#OR`Q-2"WUM;3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M.0HC+"!F=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(L._
M(#4@M];6TR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*
M;7-G<W1R("+#OR`S,"##Z];3(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U
M(&UI;G5T97,B"FUS9W-T<B`BP[\@-2"WUM;3(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G
M:6XB"FUS9W-T<B`BP[^TSK7'PKPB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BP[\@,S`@
MM];6TR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@
M(L._(#$@M];6TR(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T
M"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BM[;`_=:U.B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@
M861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R
M("+6M-#0(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BU;F_JB(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*(RP@9G5Z>GD*;7-G:60@(D5X<&%N
M9"!3:61E8F%R(@IM<V=S='(@(L3JM=<B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,38X"B,L(&9U>GIY"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`BUK30T"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T
M960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS
M9W-T<B`BM;W&VLC5(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(KWBR[74L2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S$*(RP@9G5Z>GD*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(M?6T,W1U<FK
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P
M;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`@R<^TJ\7DUL,N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BML'(H<:KNL/%Y-;#
MRJ>PW"(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BSMZWJ,&LO=,@
M3$1!4""W_L[QQO<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R("+.WK>HP:R]TR!334(@M_[.\<;W+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("*XM-;&RJ>PW-?4(%PB
M)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM
M<V=S='(@(KBTUL;*I[#<M;T@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`BSMZWJ+VHP:+2N[CVT,*UQ"!3
M05-,(,&LO=,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("+2QK:O
MM;T@7"(E<UPBRJ>PW"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E
M=')I979E.B`E<R(*;7-G<W1R("+2QK:OM;T@7"(E<UPBRJ>PW"XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`HC+"!F=7IZ
M>0IM<V=I9"`B1F%I<B(*;7-G<W1R("+4^M+!MOLB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`BMZC`
MO+_+N*/(NK6Z("C"[;;[SJS$R<NYR+JUNBDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&87)O92!)<VQA;F1S(@IM<V=S='(@(K>HPM[(NK6Z(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R
M;W(Z(@IM<V=S='(@(M'/UMBT[<[S(2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("*T
MJ]7F(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ
M>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`BM*O5YB(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*
M;7-G<W1R("*V_M3"(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*;7-G
M:60@(D9E96QS($QI:V4B"FUS9W-T<B`BN-"^]<_QRL<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L:6ME.B`B
M"FUS9W-T<B`BN-"^]<_QRL<Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM
M<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S.`HC+"!F=7IZ>0IM<V=I9"`B1FEG;&5T(&9O
M;G0B"FUS9W-T<B`BU=*RN[6]SL2\_B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I
M:FDB"FUS9W-T<B`B[+.\PR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("+.Q+S^(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("+.Q+S^ROW$OSH@
M)7,@N/;.Q+S^(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T
M<B`BSL2\_LK]Q+\Z("5S(,[$O/XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`BSL2\_KG<
MP.W&]R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`BSL2\_L/[L\8B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3DU"B,L(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO
M;B(*;7-G<W1R("+*L<?XT:'4\2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(L[$O/[)S[2K
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BSL2\_LG/
MM*NYIL3<SK2QN]:GL]8N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(KG]PLO&]R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`BM]+`O"(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`BR<^P
MZ]3"(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("+)S\_2U,(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V
M"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`BN<RVJ+'(P/TB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&
M;&EP(@IM<V=S='(@(K>MUZHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T
M(@IM<V=S='(@(L2_PKP@)7,@LKNTYM3:(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R("+7UM#-T=7)JR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*
M;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M(@IM<V=S='(@(L3ZM<3DK\#`QO>RHLZTUJ>SUM7BN/:YIL3<+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*
M;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RDB"FUS9W-T<B`B(@HBU*2QJ,SLROT@*-2DL:C,[,K]L/S`J+#7S.S2U+RP
MTKF\Y+7$ROV^W3O(Y[G[U*2QJ,SLROV]S[.DO:O5O-/#L<B]S[_MM_FUQ+#F
M(@HBP^8I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*(RP@
M9G5Z>GD*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("+1
MH=3QP]S"ZR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G
M:60@(D9O<FUS(@IM<V=S='(@(K2PS.4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BR^/#_"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM
M<V=S='(@(LOCP_S`X-#-(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X
M"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("++X\/\(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R`R(@IM
M<V=S='(@(LOCP_PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S
M"FUS9VED(")&;W)U;7,B"FUS9W-T<B`BPMO,LR(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(M?4
MMJ_7JM#%(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`BT,?&VL[E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(K2PS.4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`BMZBY^B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N
M82(*;7-G<W1R("*WJ,KTN>?1Q\3'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R
M96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`BMZC*]+*CP/O$X<[WT<<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(KS$O/[(RR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`BM-,B"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C
M<FEP=&EO;B(*;7-G<W1R("+-ZM7[P^C*]B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO
M;VXB"FUS9W-T<B`BPOK4PB(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV
M,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&
M=6QL($YA;64B"FUS9W-T<B`BR*O#^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A
M8F]N(@IM<V=S='(@(KS3Q>XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I
M9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M
M8FEA(@IM<V=S='(@(KC4L<C1QR(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R("*R^LGZ("5S(+7$S[7-L\7DUL,B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A
M=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I
M82(*;7-G<W1R("*X\<*SO*K1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA
M;GDB"FUS9W-T<B`BM<*Y^B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM
M<V=S='(@(N7(Q,DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`BUK&RO,+>S=,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("+#^R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R
M("+7JK6](@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")'
M;V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-87!S
M(@IM<V=S='(@(D=O;V=L92#+T<OW(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@
MR]'+]R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("*[TK;((@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("+/H\"P(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*
M;7-G<W1R("+/H\"PSL0@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(KCQP>K`O"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D=R96YA9&$B"FUS9W-T<B`BN/'!UL3)M.\B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`BT\.[I]?IN=S`[2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z
M-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B
M1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`BT\.[I]?I
MP_NSQK*[M<._U;#7(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ-#"U/;3P[NG
M("5S+B"W_L[QQO>[V-.F.B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ+C\T,+3
MP[NG("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D
M871E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ+C\T,+3P[NG
M("5S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("+3P[NGU^DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(KG/M<+"WL;5M;HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("*YV+6Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("+.H[78PNW`K2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N
M<V5Y(@IM<V=S='(@(KCQMO?.][6Z(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM
M<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`BM\._S<BHS]XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S=&)O
M;VLB"FUS9W-T<B`BM\._S<'TT=0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN
M96$B"FUS9W-T<B`BO+C$VM''(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(KRXQ-K1Q['(R=RYLKK-N?HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("*YY]''Q,<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B
M2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC
M871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("+5TK*[M;T@2%144"#1Z=:D+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`BNJ.UV"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`BU-.TU2W+X[>H(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*(RP@9G5Z>GD*;7-G:60@
M(DAA>F4B"FUS9W-T<B`BL>W-MR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(
M96%D97(B"FUS9W-T<B`BL>W-MR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B
M"FUS9W-T<B`BL>W-MR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(KK5M<*ZS<+TM;'`
MS<BZM;HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(L^CLJ[`M,[$("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC
M+"!F=7IZ>0IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(LWMR<\B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B
M"FUS9W-T<B`BL._6^B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(K'@O*W&]\JYT\.P[];Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(K#OUOHB"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(DAE;6ES<&AE<F4B
M"FUS9W-T<B`BL;&PZ\?R(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`BU>+`
M[\K'SL2\_K7$OZK*O#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B2&EG:"(*;7-G<W1R("+-
M[<G/(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E
M<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(
M;U]M92(*;7-G<W1R("+*U]*S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`BZ/.UV;C4(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(;VUE
M(@IM<V=S='(@(LK7TK,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R("+*
MU]*SM=C6MR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`BQ+_"O"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@
M(DAO;64@4&AO;F4B"FUS9W-T<B`BRM?2L[7GN[`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(KKIMKS`K<NY(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`BUM"Y^L_CN-LB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(M+1L\FYIKBR
MN,<@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I
M9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,C0W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(D%U=&A?;&1A<#H@SMZWJ,F^L_W3P[NG("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,S,V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(LNNQKW/WR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*(RP@
M9G5Z>GD*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("++KL:]
MS]\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@Q"B,L(&9U>GIY"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("++KL:]
MS]\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*(RP@9G5Z>GD*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(M?6ML[*_<2_N;*\QC\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(M?6ML[*_<2_N;*\QC\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED
M(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R
M("+*JK;((@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM
M<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("+*JK;(.B`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`BT-G1P,#[
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B24U!4"#3RL_DO:C!HLJGL-PZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4"#3RL_DR;ZS_<JGL-PZ
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B24U!4"#3RL_DM,7%S,7DUL.]J,&BRJ>PW#H@)7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED
M("))4"!!9&1R97-S(@IM<V=S='(@(K78UK<B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(DE0(+78UK?.WK>HRKG3PRXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R
M97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("))
M4""UV-:WLJ*RN]3:($-)1%(@M<2]T\K<Q_B_Z=;0+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B
M25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G
M:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`BL?FUNB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B
MUKO3T,V\L>HB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(E
M<R"UQ-&AS^XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED
M("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`BS;RQZKRPSL37UB(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M
M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U
M-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@
M:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@
M(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(X"B,L(&9U>GIY"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R
M("+4I,#`(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-PHC+"!F=7IZ>0IM<V=I9"`B26UA9V4@55),(@IM<V=S
M='(@(LV\QJPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%52
M3#HB"FUS9W-T<B`BS;S&K"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`BR<^T
MJ\V\QJPB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA
M9V5S(@IM<V=S='(@(LV\QJPB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*
M;7-G<W1R("*[X\CK+""RO=;H("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE
M;&0Z("5S(@IM<V=S='(@(KOCR.O7UK;..B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`BN^/(Z]?6MLXZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!
M9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G
M:79E;BXB"FUS9W-T<B`BRN3(Z[*[U?W(M[7$U_?3P\+K+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U
M>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+B(*;7-G<W1R("+.M-:JM<33P[NGP_N[\L/<PNLN(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S
M='(@(M3VO-/+]<7%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G
M<W1R("+3H;;((@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`BN/:Q\-/#NZ<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("+3H;;(Q.'.]]''(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M26YF;R(*;7-G<W1R("+0Q<^B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`BT,7/HB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(P"B,L(&9U>GIY"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B
MLN7(Z]/*O/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BLN7(Z['M
MN/$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BLN7(Z\WXPN?!
MK+W3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T
M97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R
M('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN
M<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BLN7(Z[_)S.:T^L2C
ML.8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E
M<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@
M=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`BLN7(Z]/*O/XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T
M<B`BLN7(Z['MN/$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS9W-T<B`BLN7(
MZ]/*O/XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(K+ER.NQ[;CQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BLN7(Z['MN/$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B
MLN7(ZR^QY+C\S;S&K"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G
M<W1R("*RY<CK+['DN/S-^,+GP:R]TR(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE
M;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I
M9"`B26YT96=E<B(*;7-G<W1R("+5^\K](@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(M7[
MROW!T"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"FUS9W-T<B`BSM[0I[7$(%5$2"C3P[NGROV^W;'MS;<I+B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY
M"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(L[>T*>UQ,WRT\/"
MZ\K]OMTN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B
M26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BSM[0I[7$TZ;3P[/,T/(N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("+.WM"G
MM<3%^K3.NL7"ZRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*
M;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(LSAO;NU
MQ,K]OMW.WM"G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+B(*;7-G<W1R("+.WM"GM<3$O['JUZ'6MR(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL
M92!F;W)M870B"FUS9W-T<B`BLKNZS[>HM<3.Q+S^N/'*O2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(L[>T*>UQ-.FT\.SS-#R+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(L[>
MT*>UQ-.FT\.SS-#R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB
M"FUS9W-T<B`BSM[0I[7$(&US9U]T>7!E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`BSM[0I[7$N_+5TK*[M;T@
M87!I7VED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N(@IM<V=S='(@(L[>T*>UQ+ORU=*RN[6]LL[*_2XB"@HC.B!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(K*[NL^WJ+7$N+C(J,_>+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`BLKNZS[>HM<2XN,BHS]XN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(L[>T*>U
MQ,VHT;;0K=+I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`BSM[0I[7$S:C1MM"MTNDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`BSM[0I[7$L.:QOKK%
MPNLB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("*RN[K/MZBUQ,[$O/ZX\<J](@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("+.
MWM"GM<3`M-2TUZ'6MRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D
M871A+B(*;7-G<W1R("+.WM"GM<3-\M/#PNO*_;[=+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<Y"B,L(&9U>GIY"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@
M(KSTQ]#1H=3Q(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(M+!P,K2P<NYP+RYLKK-N?HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`BTL'`K;_+(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(K"NMOO`O"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA
M;B(*;7-G<W1R("+"_+6Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(M+4
MR:O!T"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U
M"FUS9VED("))<W-U97(B"FUS9W-T<B`BQZFWHM7?(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`BT+',Y2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS
M9W-T<B`BTN*T\\#[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM
M<V=S='(@(M'`PO*\TR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(M*[U,(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&%N("C(U;&^
M*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S
M92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(LC5SL0@*$E33RTR,#(R+4I0*2(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*
M879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A
M;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`BU//.][6Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`BU+RUJ2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(L;?U,(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("+!^=3"(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`HC
M+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("*_O]?SMM3&ZR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("+6P];0(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("+7\]/2MM3&ZR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BO[_7\[;4QNLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("*_O]/2MM3&ZR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("*Y_LCX
MO\O+N<RY(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`BL:/!]-2M
MT?D@/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`BO\_$
MX=''(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I
M9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")+97)B97)O<R#(S]:DM.W.\RXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B
M2V5Y($-R96%T:6]N(@IM<V=S='(@(L/<U+^]J,&B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I
M;G0B"FUS9W-T<B`BP]S4O\S8U?<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`BP]S4
MO[.DML@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(L/<U+_`X-#-(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R("+#W-2_T^^WJ"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*UL<>PM<2YJ[^JP]S4O[?^
MSO'&]];0+-+1OJVTYM3:Q/JUQ,/<U+\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`BN_G`[[#-R[FYLKK-N?HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(K.OS\HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("*ZJ[GZ(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*
M;7-G<W1R("*ZJ\[$("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`BO\;-_LS8(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M>7)G>7IS=&%N(@IM<V=S='(@(KRJMON\JLNYS+DB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS
M9W-T<B`BL.;#YL7DUL,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("+3[]'4(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*
M;7-G<W1R("+`S\[.(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I
M9"`B3&%S="!(86QF(@IM<V=S='(@(L_"L.O4PB(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R9"!#
M:&%N9V4B"FUS9W-T<B`BP]S"ZSH@(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R
M(@IM<V=S='(@(L_"S]+4PB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q
M"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(LG/M,ZX_-#".B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("+)S]*[M,ZUQ\*\.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(LG/TKNT
MSK7'PKPZ("5S(-?4("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("+)S]*[M,ZU
MQ\*\.B"UVM*[M,ZUQ\*\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B
M"FUS9W-T<B`BP*W-T<ZLT<<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*
M;7-G<W1R("*PYL/FQ>36PR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B
M;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N
M(@IM<V=S='(@(L#HL,W$VR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0HC+"!F=7IZ>0IM<V=I9"`B3&5F="(*
M;7-G<W1R("+7\]+&(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q
M.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU
M97,B"FUS9W-T<B`BO]6PU]:U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O
M=&AO(@IM<V=S='(@(L"SR_?-T"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BM-/.
MM"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("+`^['(
MP._1QR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI
M<FEY82(*;7-G<W1R("+`^['(T<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI
M96-H=&5N<W1E:6XB"FUS9W-T<B`BP=#6I[;8RK^UQR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"B,L(&9U>GIY"FUS9VED
M("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(K6MP+8B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B
M3&EG:'0@4F%I;B(*;7-G<W1R("*UQ\*\(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED("),
M:6=H="!3;F]W(@IM<V=S='(@(K6MP+8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"B,L
M(&9U>GIY"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("+`^['(P._1QR(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS
M9W-T<B`BP:R]TR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G
M:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN
M:W,B"FUS9W-T<B`BP:R]TR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`BP="S]B`M(-/#NZ>_
MR=+4O[2UO=7BN/;.Q+S^O-`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S
M"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*
M;7-G<W1R("+!T+/VR[7#]['JS.(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,R"B,L(&9U>GIY"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("*RY<CK
ML>VX\2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT
M"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`BS-;"V]/#NZ?7Z2W.Q+S^
MN?$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(LS6PMO3P[NGU^DMQ_/6^B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),
M:7-T+4ED(@IM<V=S='(@(LS6PMO3P[NGU^DMRK:Q\+K%PNLB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/
M=VYE<B(*;7-G<W1R("+,UL+;T\.[I]?I+=.UT]#5WR(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`BS-;"V]/#NZ?7Z2V\Q+S^R,LB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B
M"FUS9W-T<B`BS-;"V]/#NZ?7Z2VVJ=3$(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B
M"FUS9W-T<B`BS-;"V]/#NZ?7Z2W(H<_[MJG4Q"(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(L'0L_;3P[NGM<2YIL3<
ML;NYV+'5(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS
M9W-T<B`BP="S]M/#NZ>UQ+FFQ-RQN[G8L=4B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(L'0L_;3P[NGM<2YIL3<L;NYV+'5(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM
M<V=S='(@(L[$T:<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*
M;7-G<W1R("+!HLS5S?`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I;6%G97,N<&AP.C@S"B,L(&9U>GIY"FUS9VED("),;V%D:6YG+BXN(@IM
M<V=S='(@(M38R.NZK\J]O^+6T"XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("*U
ML;78RK&\Y#H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED
M("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`BM=C'^-/KRK&\Y"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`BM=C'^"(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("*UQ\*\
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`BUZ+/^B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM
M<V=I9"`B3&]G:6XB"FUS9W-T<B`BM<?"O"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(L&LO=,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(K7'PKS*
MI[#<+"#'Z[SLLNG$^K7$T\.[I\/[NLW#W,+K+"#(N[KSUMC*U"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE
M9"XB"FUS9W-T<B`BM<?"O,JGL-PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@
M(M>BS_HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*
M;7-G:60@(DQO=F4B"FUS9W-T<B`BR;ZS_2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(L*LR:VQI"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB
M"FUS9W-T<B`BU,(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q
M"FUS9VED(")-3U1$(@IM<V=S='(@(L._R-70Q<^B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%
M1B"XO;S3SL2\_M;0P[O3T,K]OMTN(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C
M86\B"FUS9W-T<B`BUM"Y^K#$P\4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("+"[<;DMMFYLKK-N?HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G
M87-C87(B"FUS9W-T<B`BPNVT[[S3R[F\T[6Z(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R("+"
M[<#[(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-
M86EL(@IM<V=S='(@(M/*O/XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(M/*O/ZYW,#M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(L+MP*W-_B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`BPNW`M,[WT<<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(L+MMONT^K?R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(L+MP/LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(L+MMOK+^R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`BR/W4PB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R("+"[<SAQ.&_R[6Z
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*
M;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("*Q
MZKS'L\D@O[2Y_2_.M+^TN?TB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`BL>J\Q[/)QN3+
M_+7$RK:Q\"`HP/W(YRX@UMC2JB_2T;O8N+0I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(L+MR=RV^\BZM;HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`BPNW,X<3A
MO\NUNB(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BU?W4VL:EQ>37UK;.(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(L.KP._+_L3A
MT<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("+#
MJ\#OQ_/+N2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+B(*;7-G<W1R("*XO;S^ROW$O]+1LZRS]KW3RMS)S\_>+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO
M=7)S.B`B"FUS9W-T<B`BU^Z]_"`R-"#0H<JQM<37[KC?SL*VR#H@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@(@IM<V=S='(@(M?NO?P@-B#0H<JQM<37[KC?SL*VR#H@(@H*
M(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG
M=&@B"FUS9W-T<B`BO=/*W-?NM/.SI+;((@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("+.
MY=3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("+"
M[=2\S-C(NK6Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"B,L(&9U
M>GIY"FUS9VED(")-961I8VEN92(*;7-G<W1R("+0N[[X(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R("*SR=2Q(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM
M<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("+1H;6EQ*/*O3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S
M<V%G92(*;7-G<W1R("+3RKS^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C
M8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@
M;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("+3RKS^T>G6I-+1S>JSR2RU
MJ\K'T\.[I[7$QZG#^\BTSMZWJ,VHN?W1Z=:D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S
M<V%G92!E>'!I<F5D+B(*;7-G<W1R("+0Q<^BTM&Y_<;:+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R("+0Q<^BP.#0S2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365T
M87(@5V5A=&AE<B(*;7-G<W1R("*UL<>PS.S&^"(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(DUE=&%R(,?XO^G.WK>HRKG3PRXB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B365T87(@Q_B_Z<[>MZC*N=/#+B#/N+W:Q^NR
MSK^\S[7-L[G<P.VUQ\*\+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS
M9VED(")-971H;V0B"FUS9W-T<B`BM[VWJ"(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z
M,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB
M(&ES(&YO="!D969I;F5D(@IM<V=S='(@(K>]MZ@@)R5S)R#.M+&[MJC2Y2(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G
M<W1R("*YJ];&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T
M<B`BQ*O.][CG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`BP]R_R\+>Q.'.]]''P:JP[KGZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<V"B,L(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`BQ*._Z2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B36EM92#`X-#-(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U
M<G,Z("(*;7-G<W1R("+7[KW\(#(T(-"ARK&UQ-?NM<W.PK;(.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`BU^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B`B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,T"FUS9VED(")-:7)R;W(B"FUS9W-T<B`BT[/)Y"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q
M=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q
M-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB
M87!P;&EC871I;VXN(@IM<V=S='(@(L7DUL/.Q+S^TL7*IRX@R.>Y^]*JRKG3
MP]7BN/;3IM/#L\S0\L3ZL=C0Z\_6U-J^S;+ZR?K+^RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@
M(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`BU=*RN[6]T,7/HK7$($E$
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO
M;B!)1"XB"FUS9W-T<B`BU=*RN[6]N^'&VK7$($E$+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM
M<V=S='(@(M#'QMK2NR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW
M-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`BT-"VK]/*O/XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`HC+"!F=7IZ
M>0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`BP\G,V,C[P*W,V"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E
M(@IM<V=S='(@(KC\T,+(U<;:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(L2CO^DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(L2F
MMONVX,W?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B
MQ*;$R;CG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M("+#R;G%(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM<V=I
M9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`BU,*ZS<3J(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N
M=&AL>2(*;7-G<W1R("+#O]3"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT
M<V5R<F%T(@IM<V=S='(@(L/)S-C(^\"MS-@B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA
M<V5S(@IM<V=S='(@(M3"P<'3K[_W(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`BQ*;"Y;CG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO
M<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$
M;W=N(@IM<V=S='(@(L_"TL8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+7\]+&
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(M/2TL8B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS
M9W-T<B`BR<_2QB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("+/PM+&(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(LG/TL8B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`BQ*K)H['(O\LB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@T"B,L(&9U>GIY"FUS9VED(")-=6QT:2UL
M979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`BS\+`K;++M:4B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I
M9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*
M;7-G<W1R("*XM-&A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P
M,`IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("+.TK7$U<NZQ2(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("+$^K7$T,7/HB(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G
M<W1R("+.TK7$P\6[IR(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ
M,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`BSM*UQ,/%NZ?2
ML\/FQ>36PR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R
M("+#Y;7I(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("*R
MNRS.TK*[S:S2XB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(L/[L\8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`BQ,G#U['(T<<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYA=7)U(@IM<V=S='(@(NBGPK,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYE<&%L(@IM<V=S='(@(L3ALK2V^R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F5T:&5R;&%N9',B"FUS9W-T<B`BNLG`O"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("*ZR<KTL+*UV,'0R[DB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$
MS?C6MR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S
M"B,L(&9U>GIY"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M;7-G<W1R("*[^=/:3F5T<V-A<&4@M<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*(RP@9G5Z>GD*;7-G:60@(DYE='-C
M87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`BN_G3VDYE='-C87!E(+7$S?C6
MMR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"B,L
M(&9U>GIY"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("*[
M^=/:3F5T<V-A<&4@M<3-^-:W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#(*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E(%)E=F]C
M871I;VX@55),(@IM<V=S='(@(KOYT]I.971S8V%P92"UQ,WXUK<B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-33""W
M_L[QQO?#^[/&(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS
M9W-T<B`B3F5T<V-A<&4@R,_6I+7$Q?K7HB(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I
M8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E(,C/UJ3`X-#-(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G
M<W1R("+-^,+G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`BM-/.M"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("+0PK^F
MP.^VX,3AT<<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHR-@HC+"!F=7IZ>0IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM
M<V=S='(@(M#"OZ;`[[;@Q.'1QR(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(M#%SZ+`X-#-
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H
M<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*
M;7-G<W1R("+0PM3"(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T
M<B`BT,+3P[NGP_L@*+?'L=C2JBDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(M#"SO?`O"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D
M(@IM<V=S='(@(L/<PNLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP
M:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R("+#W,+KL=C0Z\['NL\N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B
M3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("+0PK2PO]H@*%]B;&%N:RDB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I
M9"`B3F5W<R(*;7-G<W1R("+0PL[%(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,P-0HC+"!F=7IZ>0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R
M("+3P[NGU^DB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR
M-0IM<V=I9"`B3F5X="(*;7-G<W1R("+/PM*[LKTB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS
M9W-T<B`BS\+2N]*S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@
M(DYE>'0@;W!T:6]N<R(*;7-G<W1R("+/PM*[N/;1H<_N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^
M(@IM<V=S='(@(L_"TKNRO2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A
M9W5A(@IM<V=S='(@(L3AO-/`K;G/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R("+$X<C5MOLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M9V5R:6$B"FUS9W-T<B`BQ.'(U<#[T<<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G<W1R("+-[<G/(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(L6FL*.UNB(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*(RP@
M9G5Z>GD*;7-G:60@(DYO(@IM<V=S='(@(L[>(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N
M9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N
M<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI
M;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C
M:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`BR_G6N+:HM<3.N];#R<_#N]/0Q_B_Z;3FU-HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("+#N]/0S.&YJ<C5P/K#^[/&TM2YJ2!-0T%,(-'IUJ0N
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@
M(DYO(&-H86YG92XB"FUS9W-T<B`BSK2QY+C\+B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(").;R!C:&EL
M9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R
M("*UL<>PR_FTIK7$U>*X]K7(O+;.WK>HU/:\T[3.R*C/WBXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R("+#N]/0UKBVJ+7$("5S(,7D
MUL/0Q<^B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB"FUS9W-T<B`BP[O3T-:XMJBUQ"!&5%`@5D93(,7DUL/0
MQ<^B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RXB"FUS9W-T<B`BP[O3T-:XMJBUQ"!344P@5D93Q>36P]#%SZ(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`BP[O3T-:XMJBUQ"!344PM1FEL92!6
M1E/%Y-;#T,7/HBXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N(@IM<V=S='(@(L.[T]##Z,KV(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM
M<V=S='(@(L[$O/[.M,G/M*LB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("+#
MN]/0P^C*]B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(LZ[
MUL/0Q<^BR=#.M,7DUL,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`BSKO6P]#%SZ+)T,ZTQ>36PR(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS9VED
M(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("+0Q<^BTM&Y_<;:+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,V"B,L(&9U>GIY"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T
M<B`BSK36N+:HM;&UV-/OT=0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@(DYO(&YU
M;6)E<B!S<&5C:69I960N(@IM<V=S='(@(LZTUKBVJ+6QM=C3[]'4+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E
M(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBVJ,/<PNO2U+FI
M($A45%`@T>G6I"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:HP]S"Z]+4N:D@24U!4"#1
MZ=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!+97)B97)O<R#1
MZ=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A
M;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:H
MP]S"Z]+4N:D@3&]G:6X@T>G6I"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+#N]/0UKBVJ,/<
MPNO2U+FI(%!!4U-71"#1Z=:D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BP[O3T-:XMJC#W,+KTM2YJ2!3
M34(@T>G6I"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y
M('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O
M("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E
M;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BP[O3T+3]R?.UQ->BLN')ZL?K+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`BSKO6P]#%SZ+)
MT,ZTQ>36PR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S
M='(@(K_5L-?6M2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS
M9W-T<B`BSK36N+:HM;&UV-/OT=0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@<VED97,B"FUS9W-T<B`BL;C-_,*\(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(L[>U-VTYL2_PKR_R;FIO^S(H2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(LZT
MUJJUQ-/#NZ?#^[ORP]S"ZRXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B
M"FUS9W-T<B`BP[O3T+K/MZBUQ"!834P@ROV^W;&[M*N[V"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS9VED(").;R!V
M86QU97,B"FUS9W-T<B`BO]6PU]:U(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(M2MRKS%Y-;#SL2\_M;0U=*RN[6]L.:QOM#%SZ(N(-;8T,*R^LGZQ>36
MP\[$O/XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B
M3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BU-K$^K7$Q>36P\[$O/[6
MT-72LKNUO;#FL;[0Q<^B+B#6V-#"LOK)^L7DUL/.Q+S^+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS
M9W-T<B`BSMXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@
M*$E33RTX.#4Y+3$P*2(*;7-G<W1R("+(U;;ZPOS.Q"`H25-/+3@X-3DM,3`I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R
M("+%M;BCO\NUNB(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`BL;&PZ\?R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-
M87)I86YA($ES;&%N9',B"FUS9W-T<B`BL;'"[<#OT<?$R<BZM;HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("+%LLW^(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!
M9G1E<B(*;7-G<W1R("*WQ]:NNO,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("*W
MQ]:NQ[`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G
M:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("*RN\K'TKNX]L2_PKPB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&EM
M<&QE;65N=&5D+B(*;7-G<W1R("+)T,ZTRK7/UBXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"B,L(&9U>GIY"FUS9VED
M(").;W0@<V5T(@IM<V=S='(@(K&XS?S"O"(*"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("+.M+&[UJ>SUB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS
M9W-T<B`BL;C-_,*\(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP
M.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(LJNTKO4PB(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G<W1R
M("+*_=?6(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I
M9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`BU]:W^\K](@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G
M:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(M?6ML[*_<2_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(K'*ROTB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R("+6]]:\(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A
M=&]R(@IM<V=S='(@(K;4S_.]J,&BU=\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("*PR[WXSKLB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I
M9"`B3V-T;V)E<B(*;7-G<W1R("+*KM3"(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B
M"FUS9W-T<B`BL.RYJ\K2(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S
M='(@(L/<PNLB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(K"BPOPB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`BUKO3T"!)34%0(+?^SO'&]]:GL];.Q+S^O-"YLL_MN:;$W"XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM
M<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R
M("+6N[W3RMS2N[CVT\J\_K78UK<N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B
M"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("+6N]/0T[73T-7?
MT^O/M<VSN=S`[=2QO\G2U+'DN/RYLL_MR*C/WB(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("+4VM#"M+"_VM;0M/*_JB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*(RP@9G5Z>GD*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BU-K0PK2PO]K6T+3ROZHB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3
M>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+1H<_N(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@
M(B5S(+7$T:'/[B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("+/[L2_
ML>"ZQ2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W
M"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BU^G6KR(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(M?IUJ^UI<Z[(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI>FEN
M9R(*;7-G<W1R("+7Z=:O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(M2MRKS3IM/#L\S0\L2CL.8B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(M3:("5S.B#6T+7$U*W*O,2CL.8N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(L;DR_PB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*
M;7-G<W1R("+&Y,O\T,7/HB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(M.UT]#5
MW\BHS]XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G
M:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")004T@T>G6I,[>T*<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@
M(E!'4"#*_=?6QZG#^R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R(")0
M1U`@O-/#W-?*P<\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R(")01U`@N:N_
MJL/<U+\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'
M4"#2T<>IP_LOTM&\T\/<(-?*P<\B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4""SS-#RM/K"ZR(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S
M='(@(E!(4""]Q;&^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@
M4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*(RP@9G5Z>GD*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$A0(+W%
ML;XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BL,V[^<NYS+DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("+%P<#-(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R("*PS<#5R[G,N;&[U;S![,?X(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")086YA;6$B"FUS9W-T<B`BL,W$P\+M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(K#-LKS1Q]#"O+C$VM''
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`BL,W`
MK;GG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S
M<W=O<F0B"FUS9W-T<B`BP]S"ZR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(L/<PNLZ("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D
M:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L.[T]#6N+:HP]S"Z]+4N:D@
M4D%$2553(-'IUJ0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U
M,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
MP]S"Z\BWR,\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*
M;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+#W,+K.B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S
M='(@(L/<PNLZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R("+#W,+KL=C0Z\['NL\N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q
M.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(LSYR<\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T
M92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("+,^<G/(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*
M;7-G<W1R("+"M[ZV(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`BM/W)\[7'PKRC
MNB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B4&5O<&QE(@IM<V=S='(@(KW'R:LB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M(@IM<V=S='(@(M:TT-#.K+NDLMG7]R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,#8*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!O;B!L;V=I;C\B"FUS9W-T<B`BM<?"O+KSUK30T,ZLNZ2RV=?W/R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(LBHS]XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B)R5S)R"UQ,BHS][.M+&[
MR;ZS_2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@IM<V=I
M9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BM.;(H=3BOMPB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T
M<B`BR*C/WB(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(LBHS]ZYW,#M(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA
M=&EO;B(*;7-G<W1R("+.TK7$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U
M(@IM<V=S='(@(L/8PK,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M(RP@9G5Z>GD*;7-G:60@(E!E=',B"FUS9W-T<B`BUZBPN"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`BM\;"R;'V(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`BM>>[L"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("+5U<:L(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`BQJ3,V+^UM;HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W
M"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM
M<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+B(*;7-G<W1R("+'Z\KDR.O2N[CVU,*WW;RPQ.JWW2XB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@HC+"!F
M=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C
M871E9V]R>3HB"FUS9W-T<B`BQ^O*Y,CKTKNX]M3"M]V\L,3JM]TN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`BQ^O*
MY,CKNL^WJ+7$RK&\Y"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T
M:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("+'Z\KD
MR.O2N[CVNL^WJ+7$R-7&VCO1H=3QM,O4PK?=M<3(U<;:+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED('1I;64N(@IM<V=S='(@(L?KRN3(Z[K/MZBUQ,JQO.0N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("+'
MZ\SAN:G.RLSBM<35JM*J+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE
M87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T
M<B`BQ^O*Y,CKQ/JUQ-/#NZ?#^[RPP]S"ZR(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T
M97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`BQ^O4Q+;!S\+!
MT,3:R-TNQ/JQV-#KS:S2XM7BT*G*PL_NLL7$W,JYT\//M<VS+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(K*H
MP+PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(E!O;&ET:6-S(@IM<V=S='(@(LVVQK$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G<W1R("+-ML:Q(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`BQL_,T='`
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF
M;W)C960@8GD@24U!4"DB"FUS9W-T<B`BM=W+S=/*O/ZUO=7BN/;.Q+S^O-`@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM
M<V=S='(@(M?NO?P@)7,@T*'*L;7$O;73ZL&_.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R
M("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B#5
MTK*[M;W+^=#HTJJUQ"!,1$%0(,"IU;G7Z;S^+B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0<F5F<U]S97-S:6]N.B#5TK*[M;W+^=#HTJJUQ"!S97-S:6]N(,"I
MU;G7Z;S^+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0
M<F5S<W5R92(*;7-G<W1R("+&^-&Y(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@
M(KJCQKW#YL;XT;DZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`BQOC1N3H@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`BU*3`P"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(M3:T,*TL+_:UM"T\K^J(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C8*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
MR<_2N[CVT:'/[B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4')I=F%T92!+97DB"FUS9W-T<B`BR[W#W,/<U+\B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B
M;&5M(@IM<V=S='(@(L[*S.(_(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(L[*S.+#
MZ,KV(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B
M4')O:F5C=',B"FUS9W-T<B`BUZBPN"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X
M="(*;7-G<W1R("+,X<J^Q-K(W2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("*YJ[^J
MP]S4OR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U
M"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("*YJ[^JP]S4
MO]'=R^,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-`HC+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(KFK
MOZK#W-2_(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q
M"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*YJ[^J+\N]P]S#W-2_MM2RHLZTL;NR
M^LGZ+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S
M='(@(K*HMN#`Z+CW(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS
M9W-T<B`BOZC+_K;[(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"B,L(&9U
M>GIY"FUS9VED(")1=65R>2(*;7-G<W1R("+*_;[=O^*RZ=&O(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")1=6]T82(*
M;7-G<W1R("*_J,O^MOLB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME
M>2`H)60@8FET*2(*;7-G<W1R(")24T$@N:N_JL/<U+\@*"5D(,Z[*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E
M;&5C=&EO;B(*;7-G<W1R("*UI=&A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B4W!A:6X@*,[WL.#1P"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-0HC+"!F=7IZ>0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(LJEPJS.]]''
MM;HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD
M(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B
M4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`BR^/#_"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`BL<C"
MRB(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS
M9VED(")296%D(@IM<V=S='(@(K;!R*$B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*
M;7-G<W1R("*VP<BAT\J\_B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M("+5YK7$TJK)OK/]("5S(,+P/R#5XL_NLMG7][VKSMZWJ+O6N+0N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U
M<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R("+5YK7$TJK)OK/]("5S(,+P/R#5XL_NLMG7][VKSMZWJ+O6N+0N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM
M<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BR*'/^[BT
MU*TB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS
M9W-T<B`BRZ+0PL/%NZ?*T\V\.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@
M(KGFU/*Q[;3ORKTB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y
M"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T
M<B`BML'(H2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")2
M96UA<FMS(@IM<V=S='(@(L;`PMLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("+4MK/,M_[.
M\<;W(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED
M(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB
M"FUS9W-T<B`BU+:SS,WXUK<@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M
M;W9E(@IM<V=S='(@(LF^L_TB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+)OK/]Q_B_
MZ2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`BR;ZS
M_=/#NZ<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R("+)OK/]MM0B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BR;ZS_;;4(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(M?4M_[.\<;WU-VTYL2_PKS6T,F^L_W2T;&CM.:UQ,7DUL.SS-#R+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R("+)
MOK/]T\.[IR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M
M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M("+)OK/]T\.[IR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS
M9W-T<B`BR;ZS_=/#NZ<Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL
M<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R
M960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(M#HQ_/.M+&[S^S3
MICH@M.W.\[K%PNLZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+B(*;7-G<W1R("+)S[2KSL2\_K*BSK2QN[&CM.8N(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B4R)',@M<3%Y-;#L=C0Z]:XMJ@@)R4Q)',G(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER
M960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E9&4R"UQ,7DUL.QV-#KUKBVJ"`G)7,G(@H*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("+%Y-;#ROV^W;'8T.O6N+:H("<E<R<B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E
M<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<W"FUS9VED(")297-E="(*;7-G<W1R("+6V,GH(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A
M<W-W;W)D(@IM<V=S='(@(L/<PNLB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R("+(M\C/P]S"ZR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S`*(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R
M("+/PL_2U,(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD
M<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S
M=6QT<R(*;7-G<W1R("*]X;G[(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2
M971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("*WM;O8T:'/[B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B4F5T
M>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("+1H=3QP]S"ZR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B`HP?3$X<WZ
MM;HI(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2979E<G0@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R("*R^LGZ("5S(+7$S[7-L\7DUL,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`BM[6[V-&AS^XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2:6=H="(*;7-G<W1R("+-[<G/(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3<*(RP@9G5Z>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("*U
MK<"V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("*]Q\FK(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2;VUA;FEA("C"WL+MQ.'1QRDB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U
M"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(M#]UZH@,3@P(+;((@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I
M9"`B4F]T871E($QE9G0B"FUS9W-T<B`BS_+7\]#]UZHB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A
M=&4@4FEG:'0B"FUS9W-T<B`BS_+3TM#]UZHB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`BO<?)JR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N
M(@IM<V=S='(@(M:TT-`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B4G5S<VEA;B!&961E<F%T:6]N("BV[<+>
MR[DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W
M86YD82`HPJRPLK3O*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4B"FUS9W-T<B`B4R]-24U%(+S3P]S'J</[(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R("+3RKS^TM'*N=/#(%,O34E-12"\T\/<(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")3
M05-,(-'IUJ3.WM"G+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`BT,7/HB(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@
M(LK]OMV_XKW%L;XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S
M"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@
M(E-32"(*;7-G<W1R("*\T\/<UM6VR[OZ(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM
M<V=I9"`B4U5#0T534R(*;7-G<W1R("*SR;FF(@H*(SH@;&EB+V%P:2YP:'`Z
M,34S"B,L(&9U>GIY"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(LK]OMV_
MXKW%L;XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8Q"FUS9VED(")382(*;7-G<W1R("+0Q\;:P?DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`BRJ6ZU<#5Q,.UNB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM
M<V=S='(@(LJEN_FUPKK-P=#.K,NY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")3
M86EN="!,=6-I82(*;7-G<W1R("+*I<*LSO?1Q[6Z(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("+*
MI<:DL*.V^[K-PO._R\+7R+JUNB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A
M:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(LJESL3)
MK<S8NLVX\<'6Q,FT[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G
M<W1R("+-K-*[N/:TL+_:("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")386UO82(*;7-G<W1R("+(^,2FT<<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")386X@36%R:6YO(@IM<V=S='(@(LJEPNW!IL6U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(LJEMN##
MP+K-QM7!UL[WL<@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`BSL#0Q\SA
MN:G5WR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G
M<W1R("+)L\S8L*+`K;*N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(K&CM.8B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("*QH[3F("5S(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R("*QH[3F("5S(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@
M(K&CM.;1H<_N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I
M9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y
M+B(*;7-G<W1R("*]J[+ZR?JUQ,7DUL/.Q+S^TM0@4$A0(-/OT=2X\<J]L:.T
MYK6]Q/JUQ+?^SO'&]]3=M.;$O\*\UM`N(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ>36PR`E<R#2T;&CM.8N(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(KC\T,*SS-#RTM&QH[3FM;TZ("<E<R<N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R("++T=&P(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,`HC+"!F=7IZ>0IM<V=I
M9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`BR]'1L"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&
M:6QE<R(*;7-G<W1R("+1H=3QTKNX]LC5QMHB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"FUS9VED(")396QE8W0@82!D
M871E(@IM<V=S='(@(M&AU/'2N[CVR-7&VB(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B
M"FUS9W-T<B`BT:'4\=*[N/;3P[NGU^G3P]+4T,+4]B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE
M<B(*;7-G<W1R("+1H=3QTKO.N]#"M<33M=/0U=\B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*
M;7-G<W1R("+1H=3QTKNRO[?^SO'&]R(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G
M<W1R("+1H=3QTKO.N]/#NZ?3P]+4T,+4]B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;&PB"FUS9W-T<B`BT:'4\=*[N/;(U<;:(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(M&AU/'+^=/0R-7&VM?IO/XN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("+1H=3QTKO.N]#"
MM<33M=/0U=\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R
M("+1H=3QTKO.N]#"M<33M=/0U=\B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E
M9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD
M("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("+3
MVM+4S\*UQ+2PO]K6T-&AR*'$^M*JM<37UK?[+M+4RO.QZKBTUL;+^=&ASL37
MUBS(N[KSS/G)S\[$O/ZQX+RMQ_@N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM
M<V=S='(@(M&AU/'(U<;:M]:X]#HB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T
M<B`BT:'4\<C5QMK(U<;:N/'*O3HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y
M('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(M&AU/'*L;SDM]:X]#HB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA
M=#HB"FUS9W-T<B`BT:'4\<C5QMK*L;SDN/'*O3HB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RXB"FUS9W-T<B`BT:'4\<_@NZ7&I<7DM<2V_KCVU]:VSBXB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(M&AU/'$^K7$T=7)J\7DUL,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED(")396QE8W0@>6]U
M<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(M&AU/'&J[K#T^_1U#HB
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B
M4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*TJ\O-SLK,XK>TTZ8B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM
M<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I
M9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L("C(^\3:O-.V^RDB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T
M<B`BM*NXT,;W.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(K[%U,(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B
M4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I82!A;F0@36]N
M=&5N96=R;R`HR/NV^\ZLT<?3Z\/)S-C$X;CGPMXI(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.=6UB
M97(B"FUS9W-T<B`BT/*ZQ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C$*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R(,?XO^G.WK>HRKG3PRXB
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E
M<W-I;VX@061M:6XB"FUS9W-T<B`BR*C/WKG<P.TB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E
M<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`BN^'&VB!)1"#2T;G]QMHN(@H*
M(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*
M;7-G<W1R("+(J,_>(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-`IM<V=I9"`B4V5T(@IM<V=S='(@(L7DUL,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(L7DUL/4MK/,M_[.\<;W
MR<_*]-/:Q/JUQ+CVR,O5OLRH+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE
M>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("+%Y-;#Q/JUQ,:KNL/3
M[]'4+"#*L<?XTM2\L,C5QMJX\<J]+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B
M"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(L7DUL/$^K7$QO3*O-.FT\.S
MS-#R+-'5R:O%Y-;#+-*SP^:X_-#"QK7"RBR\L,;DR_S/U,J^T:'/[BXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")3
M971U<"(*;7-G<W1R("+%Y-;#(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,S<*(RP@9G5Z>GD*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`BN/S0PK/,T/+2T;&CM.:UO3H@
M)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS
M9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z("(*;7-G<W1R("+3T+K#O+BX]K78M>.ZS=7BN/:RSLK]T]"YV#H@
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")3
M97EC:&5L;&5S("C(^\[TMOLI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`BN;K.[R(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3
M=6UM87)Y(@IM<V=S='(@(KSRMLS5JM*J(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN
M960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(LK'M_'.JK3SLK^WW;7$P:R]
MT[:HTN6_[+W=N:;$W+S\/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(L_4RKXB"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`BP[^TSK7'PKRZ\\_4
MRK[)S]*[M,ZUQ+7'PKS*L;SD(#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(L_4RKZUX]&AQO<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`BT]K7\['?S]3*OB`E<R"R
MR[6E/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,PHC+"!F=7IZ>0IM<V=I9"`B4VAO=R!U<&QO860B"FUS
M9W-T<B`BSL2\_LG/M*LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R
M("+/U,J^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B
MO/*VS-6JTJHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3
M:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*
M;7-G<W1R("+*U<OU(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S
M-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE
M<G)A($QE;VYE("C*J-?3R;VY^BDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(M>BLN$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(L>IP_LB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R
M:71H;2(*;7-G<W1R("+'J</[T=W+XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@
M(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!O<F4@*-#"O-/&PBDB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S
M='(@(K3ST*$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("+"
MU+G]SJR[I"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(E-L;W9A:VEA("C+N<+EMZ6_RRDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3;&]V96YI82(*;7-G<W1R(")3;&]V96YI82`HR[G"Y;>EQ.'1QRDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B4VYO=R(*;7-G<W1R("+/U,J^(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G
M:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3
M:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("*[_=&IR>ZVR#H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U
M:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")3;VQO;6]N($ES;&%N
M9',@*,OWPM[#Q<BZM;HI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI
M82(*;7-G<W1R(")3;VUA;&EA("C+]\+MP/O1QRDB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R
M="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`BQ<7!T+>]S_+1H=3Q(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`BP+34M+78UK<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B
M4V]U=&@@069R:6-A("C$S[?'*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T
M<B`BQ,_%MR`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM
M<V=S='(@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M
M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R
M("+$S[#KQ_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N
M9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*;7-G<W1R
M("+`K+OXT\J\_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R(")3<&%I;B`HSO>PX-'`*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD
M('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN
M(@IM<V=S='(@(E-P86EN("C.][#@T<`I(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM<V=S='(@(L"LN_C3RKS^(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H
M87)A8W1E<B!);G!U="(*;7-G<W1R("+,V,KBU]:W^\KDR.LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS
M9VED(")3<&QI="!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L(&9U>GIY
M"FUS9VED(")3<&]R=',B"FUS9W-T<B`BUJ>SUB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82`HR[G`[\"\OZ@I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S0*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(K'JU[PB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R("+&],J\Q.JWW2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R("+&],J\Q.JWW2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T
M92!O<B!0<F]V:6YC92(*;7-G<W1R("+*H2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B
MU[3,K"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@
M(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(K&CM.:X\<J](@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!
M9&1R97-S(@IM<V=S='(@(KW6M<`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM
M<V=S='(@(LF^L_W/WR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(M?6M_NTKL'0(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`BT,?&
MVLSL(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`BU=*RN[6]("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T
M<B`BUO?6O"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI
M="(*;7-G<W1R("+,X;V[(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G
M:60@(E-U8G-C<FEP="(*;7-G<W1R("+/PK'J(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM
M<V=S='(@(K/)N:8B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B(*;7-G<W1R("*SR;FFO-/(ZR`G)7,G(+6]S[7-L];0
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("*SR;FFU]3/M<VSUM#)
MOK/]("<E<R<@+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("*SR;FFR;ZS
M_2`G)7,G("XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(K/)N:;7U,^US;/6T,F^L_T@)R5S
M)R`N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S
M964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"B,L(&9U>GIY"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(L7DUL,@)7,@TM&QH[3F+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G
M<W1R("*SR;FFN/S0PB`G)7,G(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(M+1L\FYIKBR
MN,<@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3
M=61A;B`HR]6UI"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(M6J
MTJHB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2
M:7-E(@IM<V=S='(@(LC5L_8B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`BR-7"Y"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"B,L(&9U>GIY"FUS9VED
M(")3=6YN>2(*;7-G<W1R(")3=61A;B`HR]6UI"DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@
M(LC5L_8B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@
M(LC5L_8OR-7"Y"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("+(U;/V.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS
M9W-T<B`BR-7"Y"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(LC5PN0Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U
M<&5R<V-R:7!T(@IM<V=S='(@(LG/L>HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(M:GL]8B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M
M92`HR]7`^\3/*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM<V=S='(@(K3"NL4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@
M(E-V86QB87)D(&%N9"!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED
M(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL86YD("C*M\W?O,/`O"DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4W=E9&5N("C(
M\+7D*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R
M(")3=VET>F5R;&%N9"`HR/#*ORDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*
M;7-G<W1R("*RN\F^L_TB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R
M"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y
M<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FEA;B!!<F%B(%)E<'5B
M;&EC("C0\,#[T<<I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M
M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")4+5-T
M;W)M<R(*;7-G<W1R("*TL,SE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G
M:60@(E135B!F:6QE(@IM<V=S='(@(E1!0B"WUKCTN/'*O<[$O/XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B
M5&%B;&4B"FUS9W-T<B`B5&5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(LRHS>4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I
M9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("+,J,WE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")486II
M:VES=&%N("C+_KRJR[G,N2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ
M86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;GIA;FEA+"!5
M;FET960@4F5P=6)L:6,@;V8@*,RYR=#$X=''*2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB
M"FUS9W-T<B`BQ+^QZCHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(K3]L.S*PL_N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B
MM>>[L+K%PNLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B
M5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`BU^Z]_-*[T*'*L;7$SL*V
MR#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E
M<F%T=7)E(@IM<V=S='(@(L["ML@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(L["
MML@Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S
M3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BU=*RN[6]
MQ*.PYB`G)7,G+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+$H[#FN=S`[2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("+$VLC=(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(K2_SL37UB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@
M86QI9VXB"FUS9W-T<B`BM+_.Q-?6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F=7IZ>0IM<V=I9"`B5&5X='1O
M<"(*;7-G<W1R("+$VLC=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`BT,?&VLO$(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(LRISL0@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0@*,RIN?HI(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")4:&%N:R!Y;W4@
M9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(M"[T+O$^LJYT\.QOL^U
MS;,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*;7-G:60@
M(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(D944"#1T\GL*&5X=&5N<VEO;BG.WM"G+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M0F]O:RYP:'`Z,3(Y,@HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`BR<^TJ\[$O/ZRHLZT
ML;NQH[3F+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I
M9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>2(*;7-G<W1R(")-86EN=&5N86YC92#`X+'PLJ+.M+/)N:;4V,CK
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I
M9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM
M<V=S='(@(M&AS^ZTL+_:TM2YV+'5+L#KOZK6T"XB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E
M9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME
M;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(LVHT;;*_;[=TM&SR;FFM<34]KS3M;W$^K7$
MS:C1MK*^UM`NT\/*\['JL+3/PL'0S^[$O]+4O.S*TSHB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("+1Z=:DT\J\_L>IP_O0
MZ-*JT]#2N[CVTM&]XK^JM<0@4$=0(,?XO^DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#(*(RP@9G5Z>GD*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`BM,O7]]/#
MSK2QN]:GL]8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*
M;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U
M<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(M#HTJK2N[CVOJVY_;S3P]RU
MQ,WXPN?!K+W3+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN
M9RXB"FUS9W-T<B`BSL2\_B`E<R#3IKC#L/RZK-*[N/8@)7,@Q>36PRXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R
M("+.Q+S^("5S(-.FN,.P_+JLTKO0J2`E<R#%Y-;#+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&9I
M;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(K3+
MSL2\_M;0P[O3T,K]OMTN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`BM,O.Q+S^UM##N]/0ROV^W2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R
M92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E
M+B(*;7-G<W1R("+2U,_"RL<@<F9C.#(R(-/*O/ZUQ+'MS;<N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B
M(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S
M97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@
M66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K
M(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R
M87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@
M=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O
M=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H
M879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S
M=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@
M9&5L971E9"XB"FUS9W-T<B`BM,NW_L[QQO<@7"(E<UPB(-+1L;O)OK/]+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I
M9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(D=N
M=5!'(+;^U*K.Q+S^M<3"M[ZVL=C0Z[:HTN74VB!#<GEP=%]P9W`Z.B#`X+'P
MUM`N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN
M(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S
M92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*
M;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB
M"FUS9W-T<B`BL=C0Z\K'TKNX]LK]U]8N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+B(*;7-G<W1R(")(;W)D95]#<GEP=%]S;6EM93HZ(,#@L?`LL=C0Z-*J
MT]`@;W!E;G-S;"#$H[_I+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E
M(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R
M("*TR\:KNL,@7"(E<UPB(,K]OMW2\LZJLZRY_=?NM/.]T\K<UK4LR_G2U,[>
MMZBQN[&CM.8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T
M+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R
M<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL
M:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(M/#TM2\[,K3M,O*_;[=P.#0
MS2`H)7,I(+7$L\S0\K*BLKNTYM3:T]K/M<VSR<\N(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C
M=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`BM,NW_L[QQO<@7"(E<UPB
M(-+1L;O)OK/]+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B
M965N('-A=F5D+B(*;7-G<W1R("*TR[?^SO'&]R!<(B5S7"(@TM&QN[&CM.8N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB
M"FUS9W-T<B`B)7,@M<37HK+AT.C'\]+1L;O)OK/]+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(M:XMJBUQ+S'PKRR
MHK*[M.;4VBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`BUKBVJ+7$O,?"O+*B
MLKNTYM3:+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G
M:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E
M>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE
M('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM
M<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B
MM-/)S]*[N/:RO=;HUJZZ\\G/M*NUQ,K]OMW2Q<JG+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+B(*;7-G<W1R("+)S[2KSL2\_K*BSK2QN[&CM.8N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@
M(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")W96%T:&5R+F-O;2#'^+_ISMZWJ,JYT\,N(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M72
MLKNUO<2CL.8@)R5S)RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+B(*;7-G<W1R(")-971A<B#'^+_ISMZWJ,JYT\,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92XB"FUS9W-T<B`BSMZXO;S^O\G6L;W3M/*_JBXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("*TR]?6ML[6T+#\NJS,J[;@M<37
MULK]+L3ZTM'*Y,CK("5S(+CVU];*_3O$^LKDR.NUQ-?6ROVQV-#KT*'3VB`E
M<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D
M9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`BT,+4]B`G
M)7,G(+6]S[7-LSH@)7,@RK&WHLGZTKNX]L[*S.(N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(M?4S[7-L\F^L_T@)R5S)R#*L;>B
MR?K2N[CVSLK,XCHB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(M?4S[7-L\F^
ML_T@)R5S)R#*L;>BR?K2N[CVSLK,XCHB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("*X_-#"("<E<R<Z
M("5S(,JQMZ+)^M*[N/;.RLSB(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"XB"FUS9W-T<B`BR<^TJ\[$O/[*L;>BR?K2N[CVSLK,XCH@)7,@SK2Q
MN\G/M*LN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@
M=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S
M='(@(LG/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z("5S(+3ST*&SK+G]O=/*W-?N
MM//6M2`H)60@8GET97,I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("+)S[2KSL2\_LJQMZ+)
M^M*[N/;.RLSB.B"]]K*_M]:UQ"`E<R#.Q+S^L;O)S[2K+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M(@IM<V=S='(@(KSLRM/3RKS^RK&WHLGZTKNX]K3MSO,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R("*[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RXB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*
M;7-G<W1R("*[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`BU-K%Y-;#
MM+#,Y=;0MZ+)^L'+TKNX]K3MSO,NT]"_R<3<Q/K2Q<*IP<NQV-#KS.[0M+7$
MU]:VSBXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`BN^/(Z[3+S:C1MK*^ROV^W<JQMZ+)^K3MSO,N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*(RP@9G5Z>GD*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(KOCR.NTR\VHT;:ROLK]OMW*L;>BR?JT[<[S+B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB
M"FUS9W-T<B`BM,L@24U!4""W_L[QQO>RHLZTUJ>SUL[$O/Z\T+?6S^VYIL3<
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N(@IM<V=S='(@(M7BR\:Z];*[RL?5_<BWM<0@<F%R(-&YR_7.
MQ+S^+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N(@IM<V=S='(@(M7BR\:Z];*[RL?5_<BWM<0@>FEP(-&YR_7.
MQ+S^+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R
M+B(*;7-G<W1R("+5XLO&NO6RN\K'U?W(M[7$T,73P[^HNL7"ZRXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`BM,O7UK;.
MRL>QV-#HTJJUQ"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N
M(@IM<V=S='(@(K3+U]:VSL3:R-W6N[W3RMS5^\K]ROW7UBXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R
M("*TR]?6ML[$VLC=UKN]T\K<ROW7UKRPP["ZQ2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("*TR]?6ML[$VLC=UKN]
MT\K<L,N]^-;&ROW6M2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("*TR]?6ML[$
MVLC=L=C0Z\ZJMKJZQ;ORO]6PU[?6N/2UQ,K]U]8B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`BL=C0Z\K'TKNX]LK]U]8N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F
M:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X
M(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("*T
MR]?6ML[$VLC=L=C0Z[#\NJS2N]?IRJ[!^;WXUL:UQ"!21T(@T=7)J[3ZPNLL
MP/W(YR`G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S
M960N(@IM<V=S='(@(M7BN/:TL,SETM&QN[2FP.VY_2XB"@HC.B!T96UP;&%T
M97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M(&ES("5S+B(*;7-G<W1R("+5XLK'("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`BM,O*_=:UU^[)V;'8T.O*QR`Q+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M(@IM<V=S='(@(K3+M_[.\<;WSMZWJ+;4('II<""\L"!G>FEP(+CQRKW.Q+S^
MO?C0T+WBT;G+]2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A
M8W1I=F%T960N(@IM<V=S='(@(K3+S[7-L[6QQ[#*Q\VCT\.UQ->TS*PN(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`BL=C0Z\K'TKNX
M]LK]U]8N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS
M-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/
M<'1I;VYS('=I;F1O=R(*;7-G<W1R("*TR[2PO]JQV-#KTJK3R=&AS^ZTL+_:
M*$]P=&EO;BG+^;KTO=`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"B,L(&9U>GIY"FUS9VED(")4
M:6-K971S(@IM<V=S='(@(K_-NZ>YI-?WM:4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B5&EM92(*;7-G<W1R("+*L;SD(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M("+*L;SDU[?7V2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B
M5&EM92!F;W)M870B"FUS9W-T<B`BRK&\Y+CQRKTB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G
M<W1R("+*L<?XT:'4\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE
M<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BL>K,XB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`BRM6\
M_LC+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B
M"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HBR.>Y^]*JN+31H2S'Z]3:
MM>/1H<KSL>JUQ,VLRK&PM"!#;VYT<F]LO/PHN/;(R[S&R^.[^BD@N_(@0V]M
M;6%N9+S\*,:[N?N\QLOC(@HBN_HI+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(KWQS.PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS
M9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B2%1-3"#4K<J\SL2\
M_B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`BMN"XYR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`BS="_R\#-
MR+JUNB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G
M:60@(E1O;6]R<F]W(@IM<V=S='(@(L/WS.PB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VYG82(*;7-G<W1R("+,P+S3(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,L(&9U>GIY"FUS9VED
M(")4;W`B"FUS9W-T<B`BRM6\_LC+(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@
M9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("+7Z=:O(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R
M("+,V,&BQ.&T[[K-MN"PS;CG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("+5YKORO-DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W
M"FUS9VED(")4=2(*;7-G<W1R("+0Q\;:MOXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=6YI<VEA(@IM<V=S='(@(LV[Q.'+N2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1U<FME>2(*;7-G<W1R("+-P;;ZQN0B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS
M9W-T<B`BS<&V^L;DSL0@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(LW!O^+"_,NYS+DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS
M9W-T<B`BS-B_R\NYNLV_K;_&R[G(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5V86QU(@IM<V=S='(@(LV\S=_"K"(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("+*Y,CKQ/JUQ-&AU/$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("+7S\WBS]_6
MN,K].B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS
M9W-T<B`BS?C6MR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*
M;7-G<W1R("+-^-:W.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*
M;7-G<W1R("+.VKC)M.\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(L[:O\O`O"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0Q,@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("+.WK>HM.;(H2!61E,@Q+_"O"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S
M='(@(M>BLN'*L<[>MZC4]KS3MN[-XK7$T\.[I]#%SZ(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(L[>MZBXQ+'D(%9&4R#.Q+S^(%PB)7-<(B"UQ,BHS]XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,[$O/X@)7,O)7,@M<3(J,_>+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(L[>
MMZBQY+C\SJH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C
M:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+.WK>HM/*_JB!61E,@
MSL2\_B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O
M)7-<(BXB"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,[$O/X@)7,O)7,@M<3#^[/&
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(L[>
MMZC!K+W3UL$@4U%,(+?^SO'&]RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(L[>MZC*N=/#(%-33"#!K+W3+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HN+36QB!61E,@SL2\_BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("+.WK>HO:C!HB!61E,@Q+_"O"!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("+.WK>HO:C!HB!61E,@Q+_"O"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+B(*;7-G<W1R("+.WK>HO:C!HB!61E,@SL2\_BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<
M(BXB"FUS9W-T<B`BSMZWJ+'DN/P@5D93(,[$O/X@7"(E<UPB(+7$P_NSQBXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S
M='(@(L[>MZB]J,&B(%9&4R#.Q+S^+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82XB"FUS9W-T<B`BSMZWJ+VKROV^W;WBT;G+]2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R("+.WK>HR;ZS_2`E<RRTR\2_PKRRHK?'O]6PUR(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(Z("5S+B(*;7-G<W1R("+.WK>HR;ZS_2`G)7,G.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(L[>MZC)OK/]("5S++3+Q+_"
MO+*BM\>_U;#7(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN
M(@IM<V=S='(@(L[>MZBUW;GIR;ZS_<2_PKPN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BSMZWJ,F^L_T@5D93(,2_PKPN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BSMZWJ,F^
ML_T@5D93(,2_PKPZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HR;ZS_2!61E,@SL2\_B!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`BSMZWJ,F^L_T@5D93(,[$O/XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(L[>MZC)OK/](%9&4R#.Q+S^(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM
M<V=S='(@(L[>MZBUW;GIR;ZS_2!61E,Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE
M(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("+.WK>HQ="VS[6QQ["UQ,2_
MPKPN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*
M;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B
M"FUS9W-T<B`BSMZWJ+WBOZK&OM:DS[B]VB(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T
M:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+.WK>HO-/4V"`E<R"U
MQ+:HTN7*_;[=+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y
M-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL
M92XB"FUS9W-T<B`BSMZWJ-+&MJ\@5D93(,[$O/XN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+3R
MOZH@5D93(,[$O/X@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("+.WK>HT+3(ZR!61E,@SL2\_BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`BSMZWJ+3ROZH@5D93(,[$
MO/XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("+.WK>HM/*_JM&YR_7.Q+S^+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(L[>MZBQY+C\
M(%9&4R#.Q+S^(%PB)7-<(B"UQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`BSMZWJ-"T
MR.L@5D93(,[$O/[*_;[=+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#.
MQ+S^M<3#^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V
M.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y
M+B(*;7-G<W1R("+.WK>HML'(H2!V9G-R;V]T(,2_PKPN(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(L[>MZBQY+C\(%9&4R#$O\*\M<3#
M^[/&+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R
M>3H@)7,N(@IM<V=S='(@(L[>MZC)OK/](%9&4R#$O\*\.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BSMZWJ+'DN/P@5D93
M(,[$O/X@7"(E<UPB(+7$P_NSQBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R("+.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"UQ,/[
ML\8N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C,@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`BSMZW
MJ+'DN/P@5D93(,[$O/ZUQ,/[L\8N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`BSMZWJ+'DN/S.
MJB`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N="(*;7-G<W1R("+.WK>HUZJ[NR!7;W)D(,[$O/XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+.WK>HT+3(ZR!61E,@7"(E
M<UPB(,[$O/XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+B(*;7-G<W1R("+.WK>HT+3(ZR!61E,@SL2\_LK]OMTN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(@IM<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^ROV^W2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC
M965D960N(@IM<V=S='(@(L[>MZC0M,CK(%9&4R#.Q+S^ROV^W2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED
M(")5;F1E<FQI;F4B"FUS9W-T<B`BS\*[KL_?(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(LBA
MS_NX_+C$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`BN+34K2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(K?^SO'&]\&LO=/*L;>BR?K.M-2D
MQMJUQ+O8TZ8Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@(@IM<V=S='(@(K>BR?K.M-2DQMJUQ+O8TZ8LT\FW_L[QQO<Z("(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"B,L(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(LJGL-PB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I
M(@IM<V=S='(@(LWRT\/"ZR`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@
M(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(K"BP*VRKL&JNL_'];.D
MN?HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S
M='(@(M.BN?HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S
M(@IM<V=S='(@(L/`N?HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*
M;7-G:60@(E5N:71S(@IM<V=S='(@(K6EU*HB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(LZTUJJUQ"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U.0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`BSKO6P]#%SZ+)T,ZTQ>36PR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T
M<B`BSK36JK7$T\.[I\/[N_+#W,+K+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(E5N
M;F%M960B"FUS9W-T<B`BSK3#_,/[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B
M"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"B,L(&9U>GIY"FUS9VED
M(")5;G-E="!C;VQO<B(*;7-G<W1R("+7UM#-T=7)JR(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS
M9W-T<B`BSK36I[/6M<3`J=6YP_LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS
M,PIM<V=I9"`B57!D871E(@IM<V=S='(@(K'DN/PB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5P9&%T92`E<R(*;7-G<W1R("*X_-#"("5S(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`BN/S0PM/#NZ<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(M+1N/S0PB`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*
M;7-G<W1R("*X_-#"L\S0\M+1R;ZS_2XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("+)S[2K(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(M+1
MR<^TJ\OYT]#3IM/#L\S0\K7$Q>36P\[$O/ZUO;?^SO'&]RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P
M"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("+.VL"MN><B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(K6QQ[#/X,Z[(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("+3P[NG(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N(@IM<V=S='(@(M/#NZ<@)7,@SK3-J+G]("5S(+7$RMK(J-'IUJ0N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(M/#NZ>YW,#M(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M("+3P[NGT:'/[B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G
M:7-T<F%T:6]N(@IM<V=S='(@(M/#NZ?7HK+A(@H*(SH@<VEG;G5P+G!H<#HR
M,@IM<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@
M9F]R('1H:7,@<VET92XB"FUS9W-T<B`BM,O5OLRHM<33P[NGUZ*RX<^US;/2
MT<VCT\,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0HC+"!F=7IZ
M>0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("+5TK*[
MM;T@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`BT\.[I\/[(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA
M;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("+3P[NGP_L@)R5S
M)R#2T;3FU-HN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BT\.[I\/[.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS
M9W-T<B`BT\.[ISH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`BS[7-
ML];0M<33P[NG.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB
M"FUS9W-T<B`BSMK7R+'PO\O+N<RY(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M5D93(,2_PKRRHK*[M.;4VBXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R("*\V<;:(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(M+1U=*UO=/0T*>UQ+78M>,Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS
M9VED(")686QI9&ET>2(*;7-G<W1R("+3T-"GT-0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(M+4M];6T\ZJ
MM:7.NRBTT\_6U-K&\,OC*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M
M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+6M2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`BS=_"L["BS;PB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")6
M87)I86)L92(*;7-G<W1R("*QY+NO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B
M5F5N97IU96QA(@IM<V=S='(@(LZOQ-K(\,"M(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F
M86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W
M:71H+B(*;7-G<W1R("+1Z=:DRJ>PW"`M(+3+T\J\_K_)Q-S2T=3BR,O)P]?4
MM-NXQ"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("*PYK&^(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM
M<V=S='(@(K#FL;Z_V-;&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G
M<W1R("+4O<3/(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@
M(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`BU+W$S\[$("A625-#24DI
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L
M('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`BO.S*TR`E<R(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT
M97)N86P@=V5B('!A9V4B"FUS9W-T<B`BU-K0PK2PO]JT\K^J(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`BTM0@)7,@LNF_M"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(M.BRO3.K+;[OJG(NK6Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`BP\#*],ZLOJG(NK6Z(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB
M"FUS9W-T<B`BQ-R\^[;((@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(L3<O/NVR#H@
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S
M='(@(M+BM//`^[?\M<*WY[7GT,6YJ\N^S;BY_2!33510(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("*^K[CF(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S
M='(@(KZON.8A(2$@M-,@)7,@RM:VK\F^L_VSS-#R+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES
M(&%N9"!&=71U;F$B"FUS9W-T<B`BS=_`^\NYNLVXN\V\R+JUNB(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R("*^K[CF(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`BT,?&VLC]
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")7
M96%T:&5R($9O<F5C87-T(@IM<V=S='(@(LSLQOC4I++B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A
M('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y,@HC+"!F=7IZ>0IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B=V5A=&AE<BYC;VT@S?C5OB(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`BS?C5OB(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(LWX
MU;XB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BP[_6W"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@
M(KNVTZTB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92!T;R`E<R(*;7-G<W1R("*[MM.MM;T@)7,B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T
M<B`BN[;3K2P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I
M9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`BSO?%MR`H25-/+3@X
M-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(L[WQ;<@*$E33RTX.#4Y+3$U
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R
M("+.]\CVN?[`K2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BM<?"O+KSTZ:XP\_(S]3*
MOB`E<R#$Q-*[N/;3IM/#L\S0\C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\B"FUS9W-T<B`BU]:VSK7$M]:X]-?6M_L_(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E
M(&-H87)A8W1E<C\B"FUS9W-T<B`BTOW*]K7$Q["UO+?[/R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"B,L(&9U>GIY
M"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`BL,2T\\#[
MT<<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H
M87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S
M"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@
M5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(K?GR]DZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED
M(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@9G5Z>GD*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`BP:+,U<WP(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R("*WY\O9.B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5VEN9"(*
M;7-G<W1R("*WY\O9.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S
M='(@(K?GR]DZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`BM^?+V2B]VBDB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B
MM^?+V3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS
M9VED(")7:6YD.B`B"FUS9W-T<B`BM^?+V3H@(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B5VES
M:&QI<W0B"FUS9W-T<B`BQMJT_<_NQ+\B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D
M9')E<W,B"FUS9W-T<B`BL.RYJ\K2M=C6MR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B
M"FUS9W-T<B`BL.RYJ\K2M>>[L"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B
MR*C/WK*[U^,LSMZWJ+VHP:(@5D93(,[$O/XN(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS
M(@IM<V=S='(@(E@U,#EV,R#`J=6YP_LB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BQ.HB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T
M<B`BQ.HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R`A(+78
MS;PB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`BP[_$ZB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(M*RP\4B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("+*Q[7$+,[2
MS:S2XB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R
M("+$^K6QQ[#*N=/#M+_.Q-?6L>#0M,2CRKTN(,JYT\,@6SP^72"PM,6EO\G'
MT+N[SJK-^-*SL>#0M,2CRKTN(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U
M(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@
M;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`BQ/JR
MHLZTRN3(Z]*[N/:ZS[>HM<2UY]?3T\J\_K78UK<N(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO
M=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL
M92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S
M='(@(L3ZLJ+.M-/)M;S(Z[7$SL2\_M;0MM33L\C.NL[7UK;.M;T@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`BQ/K2T;ZMUZ+/^BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O
M;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!V86QU92XB"FUS9W-T<B`BQ/JQV-#KRN3(Z]*[N/:ZS[>HM<36
MM2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G
M:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@
M=7-E(%-I9VYU<',N(@IM<V=S='(@(L3ZL=C0Z\_(N>:[KKK#ROV^W<KW*$1A
M=&%4<F5E*;?^SO&VR[+%Q-R\S-#XRKG3P]#"T\.[I]>BLN&W_L[Q+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"B,L(&9U>GIY"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B
MQ/JQV-#KS\BYYKNNNL/*_;[=RO<H1&%T851R964IM_[.\;;+LL7$W+S,T/C*
MN=/#($AO<F1E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B
MQ^O#Z,KVSLK,XJ.LU-K$^K2KR\W.RLSBL:BXYM:NQ[`N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(L3ZL=C0Z\KDR.NTR\&LO=/+^=:XS_*UQ,WXUK<B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("+'Z]:X
MMJC2JLF^L_VUQ+?^SO'&]RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C
M;&5A<B!O=70N(@IM<V=S='(@(L?KUKBVJ-*JR;ZS_;7$T\.[IRXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(L?KUKBVJ-*JR;ZS_;7$T\.[
MIRXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"XB"FUS9W-T<B`BQ^O6N+:HTJK0PM3VM<33P[NG+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("+'Z]:XMJC2JKC\
MT,*UQ-/#NZ<N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN(@IM<V=S='(@(L?KUKBVJ-*JUK30T+7$U_?3PRXB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+B(*;7-G<W1R("+'Z]:XMJC2JLF^L_VUQ-/#NZ<N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*
M;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("+$^K7$("5S
M(+OAQMK2T;G]RK$NQ^O6V-#"M<?"O"XB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(L3ZM<2UY]?3T\J\_K78UK<B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z
M(@IM<V=S='(@(L3ZM<2UY]?3T\J\_K78UK<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*
M;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`BQ/JUQ-#%SZ(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"B+7U+33Q/JUQ"`E<R"[X<;:OZK*O-+4P+3$^K7$TO+,V,WX
MM=C6M]+1L>2X_"X@SJJQH[NDQ/JUQ+"RR*O&\+S[HZS$^K'8T.O6V-#"(@HB
MM<?"O"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM
M<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(L3ZM<30U</[(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(L3Z
MM<31Z=:DMLNRHLZTUJ>SUM#"U/;3P[NGN_*XP[FFQ-S2T;&[N=BQU2XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`BQ/JUQ-'I
MUJ2VR[*BSK36I[/6P="S]M/#NZ>[\KC#N:;$W-+1L;NYV+'5+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(M?4M-/$^K7$("5S(+OAQMJ_JLJ\TM3`M,3ZM<3DK\#`QO?+
MQKKUTM&QY+C\+B#.JK&CNZ3$^K7$L++(J\;PO/NCK,3ZL=C0Z];8T,(B"B*U
MQ\*\+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S
M='(@(L3ZM<3DK\#`QO>RHLZTUJ>SUM7BN/:YIL3<+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS
M9W-T<B`BQ/JUQ.2OP,#&][*BSK36I[/6M/+3H=&AS^XNQ^NPM"!#5%),*U`@
MTM2T\M.A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@
M(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(L3ZM;''L,OYQ>36
MP[7$RK''^#HB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D
M+B(*;7-G<W1R("+$^K7$T:'/[M+1N/S0PBXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ(@IM<V=S='(@(L2LR,_)[;?=RK:Q\"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE
M.B(*;7-G<W1R("+$^K7$T-7#^R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER
M960N(@IM<V=S='(@(L3ZM<31H<_NTM&X_-#"+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`BQ/JUQ-&AS^[2T;C\T,(N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BQ/JU
MQ-&AS^[2T;C\T,(N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R
M96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BQ/JUQ-2VL\RW_L[QQO<Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("+$
MS\NYP*VW\B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA:7)E(@IM<V=S='(@(M3ZTL&V^R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("+4WK'(T<<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("*]\K#-LKS.I"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!2
M97!O<G1=(@IM<V=S='(@(EO.RLSBL:BXYETB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF
M;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");SKO3VM#0
M("5S(+FR("5S(-#072(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`BN=S`[2(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ-#$*(RP@9G5Z>GD*;7-G:60@(E]$871A5')E92(*;7-G<W1R("+*
M_;[=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")?1&5L971E(%)O=R(*;7-G
M<W1R("+)OK/](@H*(SH@;&EB+V%P:2YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(M/#NZ?7Z2(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM
M<V=S='(@(K#OUOHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`BM<?"
MO"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@
M9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(M>BS_HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M(RP@9G5Z>GD*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("*RY<CK
M+['DN/S-^,+GP:R]TR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(M&A
MS^XB"@HC.B!L:6(O87!I+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G:60@(E]097)M
M:7-S:6]N<R(*;7-G<W1R("+(J,_>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED
M(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BR;ZS_;;4(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(U"B,L(&9U>GIY"FUS9VED(")?4V5T=7`B"FUS9W-T<B`BQ>36
MPR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"B,L(&9U>GIY"FUS9VED(")?57-E
M<G,B"FUS9W-T<B`BT\.[IR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(Q"B,L(&9U>GIY"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B
MS:C1MK*^(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C
M86QE;F1A<B(*;7-G<W1R("+(U<#Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`BP>.\MK?G(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN
M<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M
M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C
M;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(L7DUL,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R("+5TK*[M;TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*;7-G:60@(F9I;&4B
M"FUS9W-T<B`BSL2\_B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V
M"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@
M)7,B"FUS9W-T<B`BM-,@)7,@*"5S*2#3VB`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I
M;F<B"FUS9W-T<B`B+"#5\[?G("5S("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B
MRK$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@
M(L&BO+0B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@
M(L_"NZ[/WR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L(&9U>GIY"FUS9VED
M(")L:6YE<UTB"FUS9W-T<B`BM]8B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S
M,@IM<V=I9"`B;F%M92(*;7-G<W1R("+#^[/&(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(LG0SK3*M<_6+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("+)
MT,ZTRK7/UBXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM
M<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R("*TYLBAU.*^W"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY
M"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BR*C/WB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(DUE=&%R(,?XO^G.WK>HRKG3PRXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I
M9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA
M($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*(RP@9G5Z>GD*
M;7-G:60@(G-T96%D>2(*;7-G<W1R("*VP<BA(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"B,L(&9U>GIY"FUS9VED(")T
M87-K(&QI<W0B"FUS9W-T<B`BU]:W^[2NP=`B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS
M,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("+#O[3.M<?"
MO"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FTB"FUS9W-T<B`BU-FTSLKDR.O$^K7$P]S"Z]+4R+?(S\[>
MSO,B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("+*
MI[#<(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I
M9"`B=6YN86UE9"(*;7-G<W1R("+.M,/\P_LB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S
M97(@<V5L96-T(@IM<V=S='(@(M/#NZ?1H=3Q(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G
M<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(M#'QMHZ(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M
M(@IM<V=S='(@(G=E871H97(N8V]M(,WXU;XB"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O>FA?5%<N<&\`
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P-C0P-#(S(#$P-3$U-#,T,30R(#`Q-S4U-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C($AO<F1E(%1R861I=&EO;F%L
M($-H:6YE<V4@5')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q($1A
M=FED($-H86YG+B"Q::A]I.4LI7C&5PHC($1A=FED($-H86YG(#QD879I9$!T
M;78N9V]V+G1W/BP@,C`P,2X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`V+3`Q+3`U(#$U.C`T*S`X,#!<;B(*(E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#$M,3(M,C`@,3(Z,#`K,#@P,%QN(@HB3&%S="U4<F%N<VQA
M=&]R.B!$879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SY<;B(*(DQA;F=U
M86=E+51E86TZ(%1R861I=&EO;F%L($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R
M9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#U"24<U7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B("@E<R"DT:ME*2(*"B,Z(&QI8B](;W)D92YP:'`Z,3,W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("BG
MUK&VP>0@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S.#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*"5S(*31
MI+HI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D
M87DI(@IM<V=S='(@(B`HI+6DT2DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("BI^J31*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'EE<W1E<F1A>2DB
M"FUS9W-T<B`B("BL4:31*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM
M<V=S='(@(JGS(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R
M(")<(B5S7"(@I*.L3Z1`K=.EV+_](@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B"DHZQ/I$"MTZ:SKL2JNK_OOMPN
M(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HV-3(@;&EB+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ,#0P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(EPB)7-<(B"I?*6\IF(@2$]21$4@JKJU^:55P,DH4F5G:7-T<GDII*2S
M7:EW+B(*"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G
M<W1R("*GY*2CJ.P@7"(E<UPB('1R964@<F5N9&5R97(N(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"*D
M=Z:HI5RJNJ5;I$JH[+ASLM6H=++.I*0N(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@
M861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPBI'>E6Z1*Q7:MK:ATLLXN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<
M(JC#I;RKV*7?.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2DB"FUS9W-T<B`BI'>HSZ7.("4N,F9-0B`LKF6V<2`E
M+C)F34(@++/1OFP@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(E9"`E<R"E2*3.("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X
M<&ER97,N(@IM<V=S='(@(K/,JO&D0*:XL4N]6,7<I_.I\R`E9""DT:ME+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(K/,JO$@)60@
MI-&N\+9(N7>S^"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M
M(+/&I]&__2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S
M(*O\K[XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R"Z
M^\5`OMZG0"`M(+U4NWLB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@LUVI=R(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B)7,@M?FE52(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`B)7,@IE"W3K:UI=@B"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z-#,R(&QI8B]61E,O<VUB+G!H<#HT.30@;&EB+U9&4R]F='`N<&AP
M.C8W,0HC.B!L:6(O5D93+V9T<"YP:'`Z-S,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R"D=Z9SIF(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R"F8B`E<R`E<R(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(B5S(*1WM$ZD5:9#J,:VM:JZNOO%0+[>
MIT"T3KK\+B"]T*GSIKFNR:3$O^^G0;=1K6Z^WJ=`JKJVM:78+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(')E<75I<F5D(@IM<V=S='(@(J6RN]VM;B`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T
M97,B"FUS9W-T<B`B)7,@I,`B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`BI^2DHZCL("5S+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@
M;V8@)7,B"FUS9W-T<B`B("5S(*CL("5S(*9`("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B)7.JNK-QL%2__2(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.3$S"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD
M87(B"FUS9W-T<B`B)7.JNJ;FJ,:^Y"(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.3`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G
M<W1R("(E<ZJZL\:GT;_](@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E
M<ZJZJ]V_[,.O(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*
M;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE
M<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"
M97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@HB)7,Z(+-OJ\JK2*7SI*.D0*EWKW6ET:M(I*2J
MNK%(I?.D2*G2L4BU;RX@O="J8+=.I%6F0ZG2IK.JNKKTN/2S<[6RIK.E::_@
MK*JZ?"(*(J=!JKJMTZ1(N.JNQBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*
M;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+""P?:VW("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L
M('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L
M(+!]K;<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS
M9W-T<B`B+,7<I,:V<;%Q("5S(*CL("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,S(@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR.30*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-#@@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T-0IM<V=I9"`B
M+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(+_OOMP@+2TB"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@
M(C$R(*1PKLFH[B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@I'"NR:CN(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@
M(C(T(*1PKLFH[B(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*;7-G
M:60@(CQ0<F5V:6]U<R(*;7-G<W1R("*D5Z1`K;8B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("*FN;#/MO2ELK:WK6ZK
M_*EWN.JNQJYWIOBJ0;K=+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38R"FUS9VED
M(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("*U;Z7-I$:D
M0*W3Q%FMJZJZO_F[?B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92XB"FUS9W-T<B`BL?VE6[%+MFRE\RS!V;O=K6ZFLZ1`
MK=,@4$=0(*2]MGVJ]\9?+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(K']Q>?#TJ1WP[&S
MN:JZMFRE\RS!V;O=K6ZFLZ1`K=,@4$=0(*2]MGVJ]\9?+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("*Q_;C1
ML4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&
M7RRE2*3.LW'#]J1FI4\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(K']L/6FYK9LI?/#L;.Y+,'9N]VM;J:SI$"M
MTZ2]MGT@4$=0(*KWQE\LJ'"Q2R!01U`@JO?&7RRE2*3.LW'#]J1FI4\N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@
M<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("*Q_;C1L4NV;*7S+,'9N]VM;J:SI$"MTZ2]MGT@4TU)344@
MJO?&7RRH<+%+(%--24U%(*KWQE\LI4BDSK-QP_:D9J5/+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3
M+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B
M(@HBL?VP]:;FMFRE\\.QL[DLP=F[W:UNIK.D0*W3I+VV?2!3+TU)344@JO?&
M7RRH<+%+(%,O34E-12"J]\9?+*5(I,ZS<</VI&:E3RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("*Q_:5;L4NV;*7S+,'9N]VM;J:SI$"MTR!334E-12"DO;9]JO?&7RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED
M(")!32!#;&]U9',B"FUS9W-T<B`BI,BK9::SMK,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@
M4F%I;B(*;7-G<W1R("*DR*MEI'"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@
M(J3(JV6FLZM"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`BI,BK9;!]JT(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM
M<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(J3(JV6P?;.W(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S
M='(@(J3(JV4OI,BKX2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)(+USN+DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS
M9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("+#]JGSLV^MT[USO^B^
MN2(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R("+#]JGS+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S
M='(@(J6_I%6DZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("*EOZ2DI:$B
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BQ7:MK:2CJ*PL
MM4RJ:ZO8I=\@5D93(*78O_TN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3,V
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G
M<W1R("+%=JVMI*.HK"RU3*IKJ]BEWR!61E,@P,FNURXB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*
M;7-G<W1R("*Q8KBYN.JP5"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("*Q8KBYNU"Q2[U8
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G
M:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("*Q8KBYI'>MX;6R+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I
M;F<B"FUS9W-T<B`BM;*Q8B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S
M='(@(K=SO%<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U
M<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(K=S
MO%>FN+ASLM4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](
M;W)D92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(K=SO%>D;,5VK:TB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(J9BIKFW<[Q7
M.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(K=SO%>X<[+5(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B
MMW.\5\5VK:TB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P
M('1O(%PB)7-<(B(*;7-G<W1R("*W<[Q7IKBX<[+5J.P@7"(E<UPB(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B
MMW.\5Z:XQ7:MK:;<7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G
M:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("*W<[Q7I$"MTZC/I<ZJS#HB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34S"FUS
M9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(K=SO%?$YJ;L(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(K=SO%>D0*W3IJBM^SHB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("*W
M<[Q7N>\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("*W<[Q7("5S(*RP($UO>FEL;&$@JKJDP*VV(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D
M('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BMW.\5ZCLJKJS<;!4O_TZ(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B
M061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("*W<[Q7J.RGVJJZLW&P
M5+_](@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM
M<V=S='(@(K=SO%>HSZ7.JLPB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("(*(B5S+B(*;7-G<W1R("*D=[=SO%<@7"(E<UPB(*CLJ'2RSJ2D
M+B"F_;5,JFNW<[Q7PT*E?JJZM?FE5;CJL%0Z("5S+B(*"B,Z('-I9VYU<"YP
M:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`BI'>W<[Q7
M(%PB)7-<(B"H[*ATLLZDI"X@IT&R>Z9BI6FE2+9IIN:U;J1*I$8N(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN
M9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BMW.\5ZC/I<ZJS*JZI5RO
MX*78JV6S4</VLZPN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS
M9W-T<B`BIF&G?2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*
M;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*S<;!4O_TB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@
M(J:HK+"ZWK)ZK?L@+2"LL*CDI4RHSZ7.JLRS7:EWQ7:MK2(*"B,Z(&%D;6EN
M+VEN9&5X+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S
M"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R("*ZWK)Z(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@
M(KQSIVDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=H86YI<W1A
M;B`HJORT2::]*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI82`H
MJORZN*3:I:>HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9V5R:6$@
M**K\NKBDSJ=1J,@I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(K9LI?.G3Z97(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`BN>^[]"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N
M=#HB"FUS9W-T<B`BN>^[]*3HIJ$Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`BJ=*FLR(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(JG2
MIK.D=\7GP]*JNJC/I<ZJS"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M
M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B
MJ=*FL[ASLM4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDQ(&QI8B](
M;W)D92]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S
M:6]N<R(*;7-G<W1R("*ITJ:SQ7:MK2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R
M('-I9&5S(@IM<V=S='(@(J5^KMB]=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T
M<B`BI+FS7*9NM%BMT[EQI&RV;*7SIF&G?2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(J2YLUS%W*?SMK6EV+USN+FJNJNLND$_(@H*
M(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E
M861Y(&5X:7-T<R(*;7-G<W1R("*D=Z9SIF(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R("+%W*?S($E-4U`@M6ZD2B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@
M(L7<I_,@24U34""Q2[U8(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`BQ=RG
M\R!)35-0(*C/I<ZJS"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+%
MW*?SN7&D;+9LI?.F[:=](@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*
M;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`BQ=RG\[S+JD\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("*T
MP*5.I.6F<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I
M8V%N(%-A;6]A("BL_,12L.W"Q+ROJ,@I(@H*(SH@;&EB+TAO<F1E+U!R969S
M+U5)+G!H<#HY-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("*D0*W3
MM4RNQ*JZK<BS4:C/I<XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB
M"FUS9W-T<B`BM6^ES:1&I$"MTZ6\JKZJNK_YNWXN(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R
M82(*;7-G<W1R(")!;F1O<G)A("BF=[E$IM4I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(D%N9V]L82`HIG>M]*G4*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA("BF=Z9CJ=2N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("*P
MSJ97I4ZR>J9SJ/HB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(K6JKM<B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T
M:6-A(@IM<V=S='(@(D%N=&%R8W1I8V$@**MNMZ6D:K.P*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N
M=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!A;F0@0F%R8G5D
M82`HIG>THZ7*KG&DSJ3:NKBEK+E&KG$I(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K
M+U5)+G!H<#HU.`HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M
M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("+`LZ7.M7NFH2(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R("+`LZ7.M7NFH;)-L^8B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`BP+.ESK5[IJ&D=[1.NOPB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S
M='(@(JY-I<ZH[*G2IK.JNJ:XID"HR2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(J?E
MK>,B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED
M(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(KEWIO2D:J1P(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S
M='(@(J5\I.LB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W,0IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(JK\J=2G0J3E("A7:6YD
M;W=S+3$R-38I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-3D@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL
M92!3:7IE(@IM<V=S='(@(L"CP5G`R:1JI'`B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW-PIM
M<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(L"CP5G`R:97NMDB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(J=!O52I
M=ZUNIU*PHR`E<R"JNK7YI56VW"`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M
M9W)O=7!S/R(*;7-G<W1R("*G0;U4J7>M;J=2L*,@7"(E<UPB(*5(I,ZE]*;S
MJKJFN+ASLM4@/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I
M;F$@**K\KMJGRBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N:6$@
M**C(K/REIZC(*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<R"FUS9VED
M(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("*HR*S\I:>HR*3E("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`BP\"S3B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R
M=6)A("BJ_+Y\I-JN<2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*
M;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B07-C96YS:6]N($ES
M;&%N9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C
M:6D@07)T(@IM<V=S='(@(J3EIG+#P+-.(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T
M<B`BJ,BL=R^DTZ6MK':F8;#/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(K#UIN:^WJ=`NOO%
M0*MEQ>.EW+U4NWNY[[C</R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`R
M"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`BI,"P=,3FINPB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`BP'RXU:=2L*.D
M0*W3I*.F<Z9BJKJX<[+5+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(L!\N-6G4K"CI$"MTZ2CIG.F8JJZQ7:MK2XB
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(L!\
MN-6]<[_HI$"MTZ2CIG.F8JJZN'.RU2XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92XB"FUS9W-T<B`BP'RXU;USO^BD0*W3I*.F<Z9BJKJF0*C)
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@
M(L3=J<HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I
M9"`B075G=7-T(@IM<V=S='(@(J1+I.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS
M9W-T<B`B075S=')A;&EA("B_1*1JIU&HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM
M<V=S='(@(D%U<W1R:6$@*+;XIF&G42DB"@HC.B!L:6(O2&]R9&4O075T:"]C
M>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C<GES<6PZ
M(*?DI*.H[*G2N]VM;JJZ(&EM87`@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N
M9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R
M(")!=71H7V-Y<G5S.B"F^*I!NMVHPZ6\M*.HT;C3MK6DY+2I+B(*"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C<GEU<SH@I^2DHZCLJ=*[W:UNJKH@:6UA<""IM:;YKDVE\RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T
M<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@
M4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@
M(B(*(D%U=&A?9G1P.B"GY*2CJ.RITKO=K6ZJNB!&5%`@J;6F^:Y-I?,NO="M
MJ[=SO7/$MB!02%`@J,.E0J5;I$H@+2UE;F%B;&4M9G1P(+_O(@HBMK4LJ-*F
M<"!C;VYF:6=U<F4@+2UE;F%B;&4M9G1P(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(*?DI*.H
M[*G2N]VM;JJZ($E-05`@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(*?DI*.H
M[*G2N]VM;JJZ(&MR8C4@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(D%U=&A?;&1A<#H@MW.\5ZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B_
M_:I!L,@B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z(*=2L*.H
MSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ0;#((@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD
M87`Z(*?DI*.H[*G2N]VM;JJZ($Q$05`@J;6F^:Y-I?,N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B"U3*IKMW.\
M5ZC/I<ZJS"`E<RX@IOBJ0;ZYIE[`LSHB"@HC.B!L:6(O2&]R9&4O075T:"]L
M9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5
M;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B"U
M3*IKLKZPHZC/I<ZJS"`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z(+5,JFNG\[=S
MJ,^ESJK,("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS
M9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(D%U=&A?;&1A<#H@
MI_.W<ZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2II=B__:I!L,@B"@HC.B!L
M:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;#H@I^2DHZCLJ=*[W:UNJKH@34-!3""IM:;YKDVE\RXB"@HC.B!L
M:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]S;6)A=71H.B"GY*2CJ.RITKO=K6ZJNB!S;6)A=71H(*FUIOFN
M3:7S+B(*"B,Z(&QI8B](;W)D92])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B24U!4""F^*I!OKG%Y\/2O_F[?BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I
M;&5D(@IM<V=S='(@(L7GP]*EHK'1+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960N("5S(@IM<V=S='(@(L7GP]*EHK'1+B`E<R(*"B,Z(&QI8B](;W)D
M92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")2041)55,@Q>?#
MTK_YNWXN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@W,0IM<V=I9"`B075T:&5N
M=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D944"#%
MY\/2O_F[?BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M4TU"(,7GP]*_^;M^+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(J5II<ZJNL3F
MINPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I:F%N("BH
MR+;KJ_2U32DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(JU)M+HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM
M<V=S='(@(JU)M+K#0Z;B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B:V5R
M8F5R;W,@L4N]6+_YNWXN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B:V5R
M8F5R;W,@J,^ESJK,IE>ZV;_YNWXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R
M(")"86AA;6%S("BDVJNBL*@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"
M86AR86EN("BDVJI,*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<S"FUS
M9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("*J:<.YJKJN_*3E
M("A)4T\M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A
M;F=L861E<V@@**ESI5NIU"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"
M87)B861O<R`HI-JHJ:9H*2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.RYSZ7<I=B__2!<
M(B5S7"(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("*P\KUU(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"96QA<G5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU
M;2(*;7-G<W1R(")"96QG:75M("BD\:=1KLDI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM
M<V=S='(@(D)E;&EZ92`HJ*FHO;2U*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(D)E;FEN("BHJ;GG*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D
M82`HILJ\?;E&*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86X@**2C
MI*8I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(J7-I.DB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("*GY*2CJ.S`LZ7.M7NFH5PB)3(D<UPBJKJPS[;T7"(E,21S
M7"(N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED
M(")";&]C:R!3971T:6YG<R(*;7-G<W1R("*PS[;TLUVI=R(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R("*PS[;TJZRZ02(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("*RRL7I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEA("BLP:=1NONHR"DB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R
M:W,B"FUS9W-T<B`BKM'%TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R
M("*NV+UU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`BKMB]
M=:1JI'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(J[8O74B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$@**III&BEIZC(I,ZVPL')K?2Z^ZBZ*2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("*E
M_K.A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$@**III;ZH
MNBDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("*IL[.A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F]U=F5T($ES;&%N9"(*;7-G<W1R(")";W5V970@27-L86YD(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)A>FEL(@IM<V=S='(@(D)R87II;"`HI-JFZ"DB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R:71I<V@@26YD
M:6%N($]C96%N(%1E<G)I=&]R>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M
M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M("BH6K7<*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEA("BK3Z5;IU&HR"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"
M=6QL971E9"!,:7-T(@IM<V=S='(@(K:UI=BRQ;BY(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R`HI:RT6*_'JFNOP2DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&D@*+M:MJFF82DB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T
M<B`BJJFML;K>LGHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R(")#4DP@I,"SH<))(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(L!XIG.NYJ2ZKF4N+BY?92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE
M(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(J?6J/JJ[*ELI,:I
M?*6\I[FFJ"XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#@R(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
MIN:HQK[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM
M<V=I9"`B0V%L;2(*;7-G<W1R("*Y<Z_%K;<B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B
M"FUS9W-T<B`B0V%M8F]D:6$@**Q:KDBYZRDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*
M;7-G<W1R(")#86UE<F]O;B`HL]BSP;:I*2(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("*U3*IKIMNPRJVKN&VQ2[U8++W0P7"UN*=!JKJH=++.NMZR>JW[
M+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`BM4RJ
M:[QGI$K`R:[7(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM
M<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,C,U(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(K5,JFNS<[UUIMP@24U!4""F^*I!OKDZ("5S(@H*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:[9]L=+`R:[7(%PB)7-<(BXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%N861A("BE6ZZSI&HI(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`BJ/JN^"(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC
M96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`BJ/JN^+#=PT2F7K/X(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKIU*PH\#)KM<@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("*GY*2CJ.R\R*9SI=B__2XB
M"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T
M<B`BK\JDUB`G=&%R9V5T1FEL92<@L-&\QK5,JFO$?L3RLT*R>BXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:[*^L*.E
MV+_](%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$R."!L
M:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(K5,JFNROK"C.R`E9""MTZ1LMK"D=Z9SIF(N(@H*(SH@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E
M<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E
M<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`BM4RJ:ZVK
MLM6A0ZG2M*.HT:JZL$^__;S&I=B[4*7]JV6ITL!XIG.JNKCJKL:DH[+%+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED
M(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*
M;7-G<W1R("*U3*IKML>P9<*RL%2H[*O\J7>JNKBYO5@N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P
M92!697)D92(*;7-G<W1R(")#87!E(%9E<F1E("BZ^[QWJ*0I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM
M<V=I9"`B0V%P=&EO;B(*;7-G<W1R("*[H:GZI.6F<B(*"B,Z(&QI8B].970O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")#87)R
M:65R(@IM<V=S='(@(J^[K/6FXB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(J3`
MP_Z[4+S0Q=(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B0V%Y
M;6%N($ES;&%N9',@*+9]L-*X<ZYQ*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@
M(J;FL,JY<;C<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S
M='(@(L!XIG.NYJ2ZKF4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R
M("+`>*9SKN:YU*52.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("+`>*9SKN:DNJYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS
M9W-T<B`BP'BF<Z[FMJ&V6CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W
M.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(J;FL,JY<;C<(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S0*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@IM<V=S='(@(K;KNKBO4Z3E("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS
M9VED(")#96YT97(B"FUS9W-T<B`BN&VDI"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R
M:6-A;B!297!U8FQI8R(*;7-G<W1R(")#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,@**2DJT2F0*E-L.HI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*
M;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@
M(J2DO-H@*$E33RTX.#4Y+3(P(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
MOLS#TK+3N&`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`BOLS#TK[6IK.JS"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T
M:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("*^S,/2K$:UIB(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M0VAA9"(*;7-G<W1R(")#:&%D("BL9+QW*2(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*;7-G:60@(D-H86YG92(*;7-G<W1R("*G\Z?O(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S
M=V]R9"(*;7-G<W1R("*G\Z?OIT&JNK%+O5@B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("*G\Z?OIT&JNJJZI?ZF5Z5(
MI,ZF7K9LIF&G?2XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`BI=BK9:JZLUVI
M=ZC#I;RDY+2IL4N]6,7<I_,N(+W0P7"UN*=!JKJZWK)ZK?LN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM
M<V=I9"`B0VAA<B(*;7-G<W1R("*F<J2X(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C
M7VL@3&EN:RXN+B(*;7-G<W1R("+`RZQDLW.ULBXN+E]K(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;&4B"FUS9W-T<B`B0VAI;&4@*+2\IU$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T
M<B`B0VAI;F$@**2DL.HI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*
M;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("+"
MLL7II*2DY2`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W
M"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("*E
MO\7II*2DY2`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW
M"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(K_OOMS`LZ7.
MM7NFH3HB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I
M9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BO^^^W+%+O5@B"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@
M=7-E<FYA;64B"FUS9W-T<B`BO^^^W*1`K=.HSZ7.JLRF5[K9(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("*DZ;3!Q>.EW*3HIJ$Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@
M;&ES=',I(@IM<V=S='(@(K_OOMRVM:78JZRZ0:JZK;>NYB(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H
M<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B0VAR:7-T;6%S($ES;&%N9"`HN'2]
MSZYQ*2(*"B,Z(&QI8B]61E,N<&AP.CDQ,R!L:6(O3F5T+U--4RYP:'`Z,CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.P@)7,@JKK#_J=/J7>X<2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I
M9"`B0VQE87(B"FUS9W-T<B`BM+@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(K)-L*.W3+-N($]F9FEC92"\T,72(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B
MLDVPHZQDN-\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS
M9W-T<B`BLDVPHZC/I<ZJS#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`BLDVP
MHZC/I<ZJS"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T
M"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BLDVPHZC/I<ZJS*JZ
MN.JNQB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(K'?PN"TN"(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS
M9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("*K]K?&N:O!Y*5(Q'[$
M\B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@
MLWJY3"!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B
M"FUS9W-T<B`BP_:SK+7XM:$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T
M-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(K:SMG$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A
M<FQY(@IM<V=S='(@(J:MIFBVLR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BL[$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B
MI^G%?+CJKL:GJ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM
M<V=S='(@(J?IQ7S#Y*S)(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B0V]L
M;VUB:6$@**WTK=ND\:C(*2(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G
M<W1R("+#0Z;B(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-2!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(V"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R
M(@IM<V=S='(@(KW5IN*]3"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#,U
M"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(C$VMFFF[,-#IN*E
M3KU8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(L3F.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@
M(L3FINR\T,-$(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(J5DLW$B"@HC.B!A9&UI;B]C;61S:&5L
M;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BJ5*E3R(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G
M<W1R("*GY::XJ5*E3R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R("*U^[W7(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S
M='(@(KK9J4DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R(")#;VUO<F]S("BL
M[+ROP[DI(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BI+VE<2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(KEQ
MN*,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED
M(")#;VYD:71I;VXB"FUS9W-T<B`BP/2YTB(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(K'XI?,B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<R(*;7-G<W1R("*N=+*G(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN
M9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R
M("*[4"!01$$@M'BD5ZNLN7&XHRRTO+QZJZRDXK[WI4BDSB!/=71L;V]K(*JZ
MIE"H0K-=J7<N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`BLUVI
M=[CJKL:Y3+3!+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(K-=J7<@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS
M9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(KU4NWNQ2[U8(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B0V]N9V\B"FUS9W-T<B`B0V]N9V\@**WHJD<I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE("BMZ*I'ID"I3;#J
M*2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C
M=&EO;B!F86EL960N(@IM<V=S='(@(K-SM;*EHK'1+B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*
M;7-G<W1R("*S<[6RI:*QT3H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(K-SM;*FW*2]MGVJ]\9?IOBJ0;ZYKLF^
M1*G:+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("*S<[6RIMRD
MO;9]JO?&7Z;XJD&^N:[)OD2IVBX@K>RF73H@)7,@*"5S*2(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HX-C4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(K-SM;*FW"!&5%`@P,FNUZ;XJD&^N:6BL=$N
M(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A
M8W1S(@IM<V=S='(@(K-SM;BD2"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("*P3[_]
MI'>FJ*5<IF&W<[Q7IMRG0:JZLW&P5+_]I*0N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C
M;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("+`H\%9P,FNUZJZI+JN9:NLND$Z
M("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E
M;G1S(&]F(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@P,FNUZ2ZKF4B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(L1^Q/(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:R!)<VQA;F1S("BL
M[*=*N'.N<2DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*(RP@9G5Z
M>GD*;7-G:60@(D-O;VMI92(*;7-G<W1R("+#0Z;B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED
M(")#;W!Y(@IM<V=S='(@(KW&NW,B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#<R
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R
M("*]QKMSI:*QT3H@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R
M("*]QKMS(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82`H
MK?2TM:1JOJ2E6RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D-O
M=&4@9"=)=F]I<F4@*+9(I/JN_*FD*2(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A
M9V4Z("(*;7-G<W1R("*U3*IKI4@@4$=0(*5;L4NV;*7S.B`B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0
M('-I9VX@;65S<V%G93H@(@IM<V=S='(@(K5,JFNE2"!01U`@L/6FYK9LI?/#
ML;.Y.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(K5,JFNE2"!3+TU)344@I5NQ2[9LI?,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R("*U3*IKK+`@4R]-24U%(+9LI?/#L;.Y+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M("*U3*IKMW.\5[-SM;BD2"X@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BM4RJ:\.T
MM;(@3$1!4""F^*I!OKDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W
M"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G<W1R
M("*U3*IKP[2ULB!L9&%P(*;XJD&^N2(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S(@IM<V=S='(@(K5,JFO`RZQDMVRO<2X@)7,B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N
M;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("*U3*IKLW.ULJ;<(&QD87`@
MIOBJ0;ZY(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S
M7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R("*U3*IKLW.ULJ;<IOBJ0;ZY(%PB
M)7-<(B"HSZ7.($944#H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(K5,JFNKV*7?
ML'2X;;ASLM4N("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R
M.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R
M("*U3*IKN-&Q2R!01U`@N.JNQCH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D
M871A+B(*;7-G<W1R("*U3*IKN-&Q2R!3+TU)344@N.JNQBXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
MM4RJ:Z=2L*.S<[6XI$@N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*U3*IKIU*P
MH[!TN&VR3;/F+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("*U3*IKIU*PHZ?SMW.U
M>Z:A(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X
M,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*
M;7-G<W1R("*U3*IKJ$VI=Z:LI?.D2*JZN7&D;+9LI?.F[*=]+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(K5,
MJFO`\JCZI[F^XZJZLW&P5+_]+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BM4RJ:\#RJ/JGN;[CJKJP
M=+AMLDVSYBXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("*U3*IKP/*H^K!TN&VR
M3;/FI*2JNKASLM4N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HV.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("*U3*IKN/RD2K6F
MLJ0@7"(E<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("*U3*IKJ]BE
MWZ78O_T@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<Q
M.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BXB"FUS9W-T<B`BM4RJ:Z;;JO?&7Z;XJD&^N:CZL6^DO;9]
MJO?&7RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("*U3*IKMGVQTB!<
M(B5S7"(@I4B\9Z1*+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BM4RJ:[9]L=(@
M)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S
M:R!M;V1U;&4@)7,B"FUS9W-T<B`BM4RJ:[9]L=*Z^\5`I'6G0+S2LM4@)7,B
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("*U3*IKMGVQTJ78O_T@7"(E<UPB
M+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3$@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z,C,W(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C4Q-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C$R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-38@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BM4RJ:[-SL;4@3$1!4"`@IOBJ
M0;ZY+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(K5,JFO%JJCZ
M("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HBM4RJ:ZVKMW.S7:EWJ,^ESJK,JKJQ2[U8+B"SH:3`JKJRT[A@I*.E
MO[U4+B"]T,%PM;BG0:JZJ'2RSKK>LGJM^Z5(J/.G5;-"LGHN(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(K5,JFO%JJCZ
MIG.H^K&QJ.ZJ[2A!8V-E<W,@0V]N=')O;"!,:7-T*2(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T
M<B`BM4RJ:\6JJ/JS<;!4O_TN("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(K5,
MJFO%JJCZL'2X;;)-I54N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("*U3*IK
MQ:JH^K!TN&VR3:55+B`E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(K5,JFO%JJCZIOBJ0;ZYJKJLV\/VKU.IRB(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BM4RJ:Z9>M%^S7:EW+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM
M<V=S='(@(K5,JFNG4K"CI=B__2!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BM4RJ:\!XIG,@)7,@
MJKJS7:EW+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("*U3*IKP'BF<[/&I?>S7:EW
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(K5,JFO`>*9SL\:E][-=J7<Z("5S+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(K5,JFO`>*9SI_.W<[5[IJ&H[#H@7"(E<UPB+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(K5,JFO`>*9SL\:E][-=J7<@)7,N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B*U3*IKP'BF<[-=J7?`R25S+B"G
M0:5II4BHSZ7.)7.DI*JZJ.2E3*5<K^#`>*9SLUVI=ZG.I.*PRKW&NW.D5:VQ
MM7NFH;U8J.P@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,30S
M"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`BM4RJ:[=JM$T@3$1!4"`@IOBJ0;ZY+B(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("*U3*IKIU*PHR!<(B5S7"(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(K5,JFNG\[=SLW.UN*1(+B`E
M<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`BM4RJ:Z?SMW.P=+AMLDVE52X@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@
M)7,B"FUS9W-T<B`BM4RJ:\+0O&<@7"(E<UPB.B`E<R"JNK-=J7<N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`BI^2DHZCL($UO>FEL;&$@JKJDP*VV+B"]T+U4
MNWNDP*VVK$^G7[9]L=(N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G
M:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@
M9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`BM4RJ:[WAI*FHSZ7.JLP@7"(E
M<UPB(*15ID/%=JVMJ.RK2*7SIU@@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#(S"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B
MI]ZS3J5Y(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G
M:60@(D-O=6YT<GDB"FUS9W-T<B`BL.JN82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`BO=*J[2(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(JO8I=\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`BJ]BEWZ1`K=.S<[6R
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM
M<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("*KV*7?I$"MT[=SJKHB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@
M(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("*KV*7?IKBK2*7SIU@B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!0
M97)M:7-S:6]N<R(*;7-G<W1R("*KV*7?JLRJNL5VK:TB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(Q.0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM
M<V=S='(@(JM(I<ZE9+BYO5@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")#
M<F]A=&EA("BG2L.YINBHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(D-U8F$@
M**5JI-HI(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(J78JV6JNJ3KK-LB"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO
M;G,B"FUS9W-T<B`BI=BK9;=\M,$B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*
M;7-G<W1R("*EV*MEKLFVH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@
M:7,B"FUS9W-T<B`BI=BK9;KTIWTB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`BI=BK9:JZJ,^ESJK,
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!7
M96%T:&5R(@IM<V=S='(@(J78JV6DT:[P(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*
M;7-G<W1R("*EV*MEJKJJK*IP.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(J78JV6JNJVWKN8B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`BIMNM<:1`J,>U;J1*)7.K
MX:G2K6ZP]:;FJKJD=:=`+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@
M(K#%I%4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(K#%I%4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B0WEP<G5S("C!R;2VL,>TM2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0WER:6QL:6,@*$M/23@M
M4BDB"FUS9W-T<B`BINBHO;JXI.4@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"FUS9W-T<B`BINBHO;JXI.4@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I(@IM<V=S='(@(J;HJ+VZN*3E+Z]1ITK$]:3E("A+3TDX+54I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B0WIE8V@@4F5P=6)L:6,@
M*+&VITJF0*E-L.HI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B
M"FUS9W-T<B`BI.DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W,`IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"B*XZJ[&J-.WO:97NMD@*+W0L-&FTB!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+2(*(F1S;BYP:'`I
M(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I
M;'DB"FUS9W-T<B`BJ$.DZ2(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM
M<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("*^\*JLN.JNQL)SQ/TB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(V.`IM<V=I9"`B1&%T86)A<V4@
M3&]O:W5P(@IM<V=S='(@(KCJKL:N=[=JM$TB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0P,B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,@IM<V=I9"`B1&%T92(*;7-G<W1R("*DZ;3!(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B
M"FUS9W-T<B`BIJRH[*3IM,$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y
M-@IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BO^^^W*3IM,$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R("*EU:31
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R("*G4K"C
MQ.:F[%]L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(J11I$>DZR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@
M(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R("*D4;9IINR\QJ9R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B
M1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(K3NI-;!6;'&(@H*(SH@;&EB+W!R
M969S+G!H<#HQ,3<@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*;7-G:60@
M(D1E9F%U;'0B"FUS9W-T<B`BN7>S72(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(KEWLUW#0Z;B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("*Y=[-=JKJH
MK:7WP]&G3R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B
M1&5F875L="!3:&5L;"(*;7-G<W1R("*Y=[-=J5*E3[C1JE*^N2A3:&5L;"DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I
M;VYS(@IM<V=S='(@(JEWN'$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&QI
M8B](;W)D92]097)M<RYP:'`Z,S(V(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-#(R"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#,Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`BIU*PHR(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L
M971E($-E;&PB"FUS9W-T<B`BIU*PH\!XIG.NYB(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@
M1W)O=7`B"FUS9W-T<B`BIU*PH[ASLM4B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`BIU*P
MHZSVO_TB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*
M;7-G<W1R("*G4K"CQ7:MK2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R("*G4K"CH4*R3:K%MFRE\R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C
M96QL(@IM<V=S='(@(J=2L*/`>*9SKN8B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@
M8V]L=6UN(@IM<V=S='(@(J=2L*/$YJ;L(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`BIU*PH[)[IG.JNK3`I4Z\RZI/(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`BIU*PHUPB)7-<
M(JJZQ7:MK2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("*]5*EWK6ZG4K"C
M7"(E<UPBJKK%=JVMI4BDSJ:XQ7:MK2`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E
M(')O=R(*;7-G<W1R("*G4K"CID,B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L
M971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E
M;G1I='DB"FUS9W-T<B`BIU*PHZG2O^^^W*JZJ*VE]\/1IT^XZJ[&(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@
M(J=2L*.EV*MEJKK$YJ;L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U
M<G)E;G0@<F]W(@IM<V=S='(@(J=2L*.EV*MEJKJF0R(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("*G\[=S
MM7NFH2!<(B5S7"(@I'>G4K"C+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L
M:79E<GD@=&EM92(*;7-G<W1R("*[O+!EKLFVH2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1&5N;6%R:R`HI*:SP2DB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`BL-W#1+1YK7HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.30R
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(K1YK7HB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.B(*;7-G<W1R("*RT[A@("B]T+#1IM(@2&]R9&4@L$^__<#)
MKM<I.B(*"B,Z(&QI8B](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("*RT[A@O="PT:;2J'2RSKK>LGJU;K_]+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(JSC
MM6\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O
M:6YT(@IM<V=S='(@(L53PDFWQ:O7(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T
M<B`BL\RKX:1`I'"NR:JZQ5/"2;?%J]<Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@
M(L53PDFWQ:O7.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*
M;7-G<W1R("*Q<:6JIMRE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L
M969T(@IM<V=S='(@(K%QI6NFW*6J(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("*EV+_](@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R
M('1I;65S/R(*;7-G<W1R("*E2"`R-""D<*[)J.[%XZ7</R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R("+%XZ7<O^^VM2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G
M<W1R("+%XZ7<N-2RTZJZN7>S^"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`BQ>.E
MW+EWL_@@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-@IM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BQ>.EW*[FIJ$B"@HC.B!L:6(O
M2&]R9&4O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(K;'L&6F7K'X(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB
M"FUS9W-T<B`B1&II8F]U=&D@**9.I:RF82DB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("*D
MHZ=2L*,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@
M(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S
M='(@(J2CK6ZJO;&UIG.H^B!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R
M("*RQ*1`M:>P3[_]K$^G7Z5=IW3$YJ;LIE>ZV3\@IG"J1ZQ/O="DQ+_O+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN:6-A("BF:*GZI:>E6RDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI8V%N
M(%)E<'5B;&EC("BF:*GZI:>E6Z9`J4VPZBDB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_
M(%-I9VX@=7`N(@IM<V=S='(@(L'9J%.FL[%BN+FVW#\@M?FE52XB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("*D5;C\(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G
M<W1R("*D5;C\("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM
M<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="XB"FUS9W-T<B`BI%6X_+-=J7?`R:[7I72F<ZRP(%!(4""U>Z:A
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O
M=VX@;&ES="(*;7-G<W1R("*D5:G4I5ROX*KM(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("+#Q*M^(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS
M9W-T<B`BN7&D;+9LI?,B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N
M<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O
M<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`BO_F[?B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C
M=6%D;W(B"FUS9W-T<B`B16-U861O<B`HI,RERJ9HNK@I(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G
M:60@(D5D:70B"FUS9W-T<B`BO7._Z"(*"B,Z(&QI8B](;W)D92]";&]C:R]5
M22YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B
M161I="!";&]C:R(*;7-G<W1R("*]<[_HL,^V]"(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R
M;W5P(@IM<V=S='(@(KUSO^BX<[+5(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I
M="!097)M:7-S:6]N(@IM<V=S='(@(KUSO^C%=JVM(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*
M;7-G<W1R("*]<[_HQ7:MK2(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`BO7._Z"5SJKK%=JVM(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T
M<B`BO7._Z+_OMK4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`BO7._Z%PB)7-<(JJZQ7:MK2(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BO7._Z"5SJKK%=JVM(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS
M9W-T<B`BL="H?"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G>7!T("BN2J3.
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(@
M*,+$NKBERZ9H*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R
M("*DN*7S+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#<S(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G<W1R("*Y<:1LMFRE\R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("*Y<:1L
MMFRE\Z;MIWTB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DV-PIM<V=I9"`B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(KEQI&RV;*7S
MINVG?:6RMK>G:Z98+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("*Y<:1LMFRE
M\[U4NWLB"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS
M9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")%;6%I;"UT;RU3
M35,@N6BY1+ZY(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Y-PIM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(JKML:&RQ;BY(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@
M(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(JK%I=6K2*7S+B(*"B,Z(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HR-#,@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C0X-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C8R(&QI8B](
M;W)D92]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(JK%I=6U
MLJI'+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I
M9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(JK%I=6W:K1-MK6EV"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*;7-G:60@(D5N86)L92!I
M;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E
M>'0_(@IM<V=S='(@(J2YLURFV\/`M%FTH:1*M].D^:CLJTBE\Z2D*+KTK;:]
M<[QGO-*FH2D@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(K'2L,JWQKFKI6O!Y*5<K^"J[3\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C4Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,`IM<V=I9"`B16YD('EE87(B
M"FUS9W-T<B`BM;*G]*9^I?<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R("*I\:1JO7._Z+ZY(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(J9PJD>G0;O=K6ZMJ[-=L4N]6"R]T+_II$JD0*W3IG>E
M_K#=I7DLJ-*F<"`GIT'#9*JKJKJF5[K9(#\G.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I
M9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(J9BIKF_Z:1*
MO':YLZJZNO2G?2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HX.#D*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")%<75A
M=&]R:6%L($=U:6YE82`HJ*JY1+18I+JHR"DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(D5R:71R96$@**3,I=^O4ZB]IG<I(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT."!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(K_YNWXB"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`BJ]BEW[#/MO0E<Z[)M6^ES;_YNWXB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`BIU*PHZ90
MJ$+!X\)).B`E<R"NR;5OI<V_^;M^(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(J=2L*.F4*A"L$^__3H@)7,@KLFU
M;Z7-O_F[?B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS
M9W-T<B`BQ:JH^J2ZKF4Z)7,@KLFU;Z7-O_F[?B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`BI_.W<[%+O5@Z("5S
M(*[)M6^ES;_YNWXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S
M86=E+B(*;7-G<W1R("*]<[_HI$"K:+!4KJ<B"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(KQG
MI$H@7"(E<UPB(*[)M6^ES;_YNWXN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R
M(")%<W1O;FEA("BW4JA&I:>HR"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M(")%=&AI;W!I82`HIN>OP:3QJ,@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`BNMBQVB(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B
M175R;W!E("B\VJQW*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*
M;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`BJ$,@,34@I,#$P2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R("*H0R`R(*3`Q,$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@
M(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BJ$,@,S`@K.W$P2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(JA#(#4@I,#$
MP2(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V
M97)Y($QO9VEN(@IM<V=S='(@(JA#IKBU;J1*(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(JA#(#,P(*3`Q,$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*
M;7-G<W1R("*H0R`Q(*3`Q,$B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(KUDJ-*M
MR#HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN
M<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B
M"FUS9W-T<B`BL/6FYB(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(JYIMGTB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R("*N:;9]N.JNQJ>H(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW
M;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`BK6ZH
M1"`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G
M:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS
M9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`BJ.RTP:3I(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM
M<V=S='(@(KC1NZ&M^R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@
M(JMEM+K#0Z;B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I
M9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`@I%>VQ[-=J7<N
M(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`BQ:JH^K"^IFZS
M7:EWI:*QT2(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW-2!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(K5,JFNS<[UUIMP@3$1!4""F
M^*I!OKDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`BM4RJ
M:[-SO76FW"!334(@IOBJ0;ZY+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(@IM<V=S='(@(KW&NW.EHK'1IML@7"(E<UPB+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R("*]QKMSI:*QT:CL(%PB)7-<(BXB"@HC
M.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O
M(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("*U3*IKJ]BE
MWZ1`K=.W<ZJZ(%-!4TP@LW.QM2XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3`Q
M(&QI8B]61E,O9G1P+G!H<#HW-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("*W:+*^I:*QT:CL(%PB
M)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`BPEZH^J6B
ML=$Z("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`BM+:S<2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9"!)<VQA
M;F1S(*IKQ/6G2KK6N'.N<2`HL*BZN+K[K\>TM;ASKG$I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R
M;V4@27-L86YD<R(*;7-G<W1R(")&87)O92!)<VQA;F1S(@H*(SH@;&EB+TAO
M<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B
MQ%FMJ[_YNWXZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("*VQZ]U(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`BML>O
M=2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&
M96)R=6%R>2(*;7-G<W1R("*D1Z3K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`BMU#$L2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI
M:V4Z("(*;7-G<W1R("*W4,2Q.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T
M<B`BI/*D\JM"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`BM76\
MR+!]L[<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT.`IM<V=I9"`B1FEE
M;&0@;6%T<FEX(@IM<V=S='(@(L3FINRP?:9#(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,S,C,*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S(W"B,L(&9U>GIY"FUS9VED(")&
M:6=L970@9F]N="(*;7-G<W1R("*_[[[<P,FNUZ5(MM>D2CHB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&
M:6II(@IM<V=S='(@(D9I:FD@*+2TP-DI(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@
M(L#)KM<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L#)KM>\QJ78.B`E<R"MT\#)
MKM<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("+`R:[7O,:EV#H@)7,@P,FNUR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@
M36%N86=E<B(*;7-G<W1R("+`R:[7P6"ZWB(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS
M9VED(")&:6QE($YA;64B"FUS9W-T<B`BP,FNUZ97NMDB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDX-`IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`BP,FNU[_OOMPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30Y,`IM<V=I
M9"`B1FEL92!U<&QO860B"FUS9W-T<B`BP,FNUZ17ML<B"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.#@U"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`BP,FNUZ17ML>E7*_@I;RS4:3DM*DN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM
M<V=S='(@(KE,PF^^N2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN;&%N
M9"`HJN+$]2DB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&
M:7)S="!(86QF(@IM<V=S='(@(J17I6*DZR(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`BI%>IMB(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("*I
M5*EWI/&HTB(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S`*;7-G:60@(D9L:7`B"FUS9W-T<B`BI%>D5<1!K<LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS
M9VED(")&;&]A="(*;7-G<W1R("*O0K#*(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("+#
M^B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR,S<@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R("*EV+_]("5S(*2CIG.F8B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`BIG*KK,-#IN(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`BK;FJJR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM
M<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M"FUS9W-T<B`BIEVLL,)SQ/V^N:C#I;RDY+2IO':YLZ5<K^`N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM
M<V=S='(@(J[PMDBY=[/X("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H
M870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD
M(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(KEWL_BDT;S&("BY=[/XI-&\
MQJ5=K$&EU:31I4BDSJE=MJ&JNKCJKL8[IG"J1[EWL_BDT;S&N/NJ^+%.IONE
MSJ3QN/N\9;14JKJJJ2(*(JVQ*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T
M<B`BI]&P3[%+O5@@/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(JKML^8B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BI'"[>2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(J1PNWG#_JNL(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("*D<+MY(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S
M='(@(J1PNWD@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R("*]U[["(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`BIMNP
MRL+@JT@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("*L4+3!I*TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`BKMBL6R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R
M(")&<F%N8V4@**IKL.HI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(D9R86YC
M92P@365T<F]P;VQI=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R
M(")&<F5N8V@@1W5I86YA("BJ:\3=NURHR*BZ*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@
M4&]L>6YE<VEA(@IM<V=S='(@(D9R96YC:"!0;VQY;F5S:6$@**IKQ-VLP:=1
MI:>FZ*C(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M(@IM<V=S='(@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M
M(@IM<V=S='(@(K%(I?.D2"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T.0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDU"FUS9VED(")&<F]M('1H
M92`B"FUS9W-T<B`BL7$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("*GN;[C
MM'FM>B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`BNJ&DZR(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`BI?ZF
M5R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N("BE6[1>*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("+#P+19
M.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:6$@**7,I/&HR"DB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G
M:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`BLJ.ES2`E
M<R"MTZATLLZS7:EW(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I
M9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(J1WLJ.E
MS:JZLUVI=[CJKL8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E;W)G:6$@
M*+/LJG:HR*9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D=E<FUA
M;GD@*+QWL.HI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$@**U[K\<I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B`HJKVEK,.Y
MJOLI(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@
M(D=I=F5N($YA;64B"FUS9W-T<B`BIE>ZV2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("*K9:FY(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B
MK?2\=[JX(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92"F8;G/
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R(")';V]G;&4@MVJT32(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S8*;7-G:60@(D=R87ES8V%L92(*
M;7-G<W1R("*FQ[:E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'<F5E8V4@
M**?&P[XI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D=R
M965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("*GQL.^I.4@*$E33RTX.#4Y+3<I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R965N;&%N9"`HKN:SKL3U
MKG$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")G<F5N861A("BNYK?GK\>Y
M1BDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`BN'.RU;K>LGHB"@HC.B!L:6(O2&]R9&4O
M1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G
M:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(KAS
MLM6F5[K9I*.Q;ZK%I=4B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z
M,S`W"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M("(*;7-G<W1R(")'<F]U<%]L9&%P.B"U3*IKMW.\5[ASLM4@)7,N(*;XJD&^
MN:9>P+,Z("(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A
M<#H@M4RJ:Z=2L*.X<[+5("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@M4RJ:Z?SMW.X<[+5("5S(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R("*X<[+5(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*
M;7-G<W1R(")'=6%D96QO=7!E("BM]+QWK*6TMBDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*
M;7-G<W1R(")'=6%M("C#]JYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T
M<B`B1W5A=&5M86QA("BERJ9AL*BIU"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(J[FKJ:FZ*YQ(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`BJ-.[J\5VK:TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`BLUBKR*]DJ*4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'
M=6EN96$B"FUS9W-T<B`B1W5I;F5A("BT6*2ZJ,@I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN
M96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U":7-S874@*+18I+JHR*3QK\&F
M0*E-L.HI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA("B[7*C(
MJ+HI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*
M;7-G<W1R("*V5Z3ELW.ULKMYJ*4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H["!(
M5%10(,7GP](N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2`HKORF
M82DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA
M<V@M06QG;W)I=&AM(@IM<V=S='(@(L+XM.HMNG2ZXB(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(L9'(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDR,R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDR,0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(JKMP%DB
M"@HC.B!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I
M9"`B2&5A9&5R<R(*;7-G<W1R("*J[<!9(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA
M;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0@27-L86YD
M(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS
M9W-T<B`BI&JY<*M"(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("*GQJ="J-.DY2`H
M25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("*P
MJJO7(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L
M<"YP:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(KNA
MJ?HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("*]<[_HOKFH
MSZ7.NZ&I^B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<U"FUS9VED(")(
M96QP97(B"FUS9W-T<B`BNZ&I^B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("*E8K)Y(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`BLV^XS*Q/P,FNUZJZMGVI;#HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*
M;7-G<W1R("*PJB(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T
M96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?
M;64B"FUS9W-T<B`BKF%?;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I(@IM<V=S='(@(DAO;'D@4V5E("BQZ[_-J:,I(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED(")(;VUE(@IM<V=S='(@(JYA(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D
M<F5S<R(*;7-G<W1R("*F[:YAIF&G?2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`BKF&EV+_]
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BINVN8;EQN-PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO
M;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S("BGN[.CJ=2TM2DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<@**V[M.0I(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R
M(")(;W)D92(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(+9LI?,@)3(D<R"DI+E*J.RU3*[$JKH@)3$D<R!834RXZJ[&(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"U3+9LI?.^0:98JJNE\R`E<R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"V;*7S("4R)',@
MI*2GY*2CJ.RJJZ7SJZRZ02`E,21S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,C0V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(*1WIJBE7*JZLKZPHR`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+[CIEBD=;5[N]VM;B`G9&]M>&UL)R"J
MNB!02%`@J;6F^2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-3`R"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B"U3*IKJ]BEWR`E<R"JJZ7SJKH@6$U,(+[P(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(+5,JFNROK"C("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(+5,JFO`\JCZ
MLZ&E]R`E<R"KK+I!JKH@34E-12##T:=/N+F]6"(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(+5,JFNF4*A"("5S(%PB)7-<(CH@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$S,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"U3*IKIE"H0J3`J,DZ("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B"EO*J^JKJDP*C)(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT
M86P@4G5L92(*;7-G<W1R("*D]*6MO74B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A
M9&1I;F<B"FUS9W-T<B`BI/2EK;G4I5(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R("*D]*6M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`BIT&F<*;SJ.RFN2`_
M("B]T+'4K7HA*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(J=!K6ZF6*C6IFBDUJW3
MQ.:F[*E//R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS
M9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS
M9W-T<B`BQ.:F[+S&I=BF0*UP/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(J=!K6ZF6*C6
MIFBDUJ9#J4\_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS
M9W-T<B`BM\.KUR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`BM\.KUSH@(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T
M<B`BM\:]7:1JKG8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B2'5N9V%R
M>2`HIDFD^J=1*2(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B24U!4""V;+UCJ]BEWZ6BL=$Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M8WER=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("))34%0(+9LO6.G4K"CI:*QT3H@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](;W)D92]!=71H+V-Y
M<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@MFR]
M8[K/NM"P=+AMJ]BEWZ6BL=$Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@INRG?2(*"B,Z
M(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0(*;LIWVU3*IKJ,^ESBXB
M"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T
M<B`B25`@INRG?:C#I*.F8B!#2412(*JZI+FS7+#/MO2DI"XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?
M;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("*F8JOAK;&TH:1*ID-?;B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B26-E;&%N9"(*;7-G<W1R("))8V5L86YD("BF0JYQ*2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS
M9W-T<B`BK\*YSZ7<(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(E<ZJZ
MN<^EW"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC
M;VYS('=I=&@@=&5X="(*;7-G<W1R("*YSZ7<I,ZDY:9R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*
M;7-G<W1R("*HK:7WP]&G3ZJZIE>ZV3HB"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RXB"FUS9W-T<B`BIG"J1[5,JFNEO[U4IF'%XZ7<+"`E<R"E
M2*5TMGVQTK9LI?.I\[=SM?BUH;?MI*0N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O
M;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C
M:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y
M+B(*;7-G<W1R("(B"B*HSZ7.($EN=&5R;F5T($5X<&QO<F5R(,)SQ/V^N:[)
MIG"J1ZA3IK.LW:CLI?2F\ZJZI'"YSZ7<+""G0:5IK^"[W:UNI,2_[[-OK=.V
MM2(*(J78I4C#]K.L(%!.1R"\=KFSJKK!],+#KL2J1RXB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO
M=7(@8G)O=W-E<BXB"FUS9W-T<B`BIG"J1ZS=J.RS;ZMHJ%.FL[QVN;.JNK!4
MKJ<LLV^J[:7<IT&JNL)SQ/V^N;5,JFO%XZ7<I%>VQZJZO':YLRXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(KQVN;.Y=\3]
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("*\=KFSNO2G?2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("*\=KFSNO2G
M?3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G
M<W1R("*\=KFSJ-.FV\/`M%DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R
M;VT@9V%L;&5R>3HB"FUS9W-T<B`BO':YLZC3IMO#P+19.B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G92!U<&QO860B"FUS9W-T
M<B`BI%>VQ[QVN;,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I
M9"`B26UA9V5S(@IM<V=S='(@(KQVN;,B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R("*VUZ1*+""H0L9*("5D(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M960@9FEE;&0Z("5S(@IM<V=S='(@(K;7I$K$YJ;L.B`E<R(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD
M<SHB"FUS9W-T<B`BMM>D2L3FINPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T
M(%)O=R!!9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*ID-?<R(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("*_Z:1*I*.EO[U4JKJG0*7.O5@N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I
M9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T
M<B`BO=#`RZQDIT&JNJC/I<ZJS*97NMFDSK%+O5@B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("*HSZ7.JLRF5[K9I*.EO[U4J<ZJS+EQI&RV;*7SINVG
M?:1WQ=RG\RZ]T,%PM;BG0:JZJ'2RSKK>LGJM^Z5(J/.G5;-"LGHN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I
M9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(KQ7I5O!6;'&(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("));F1I82(*;7-G<W1R("));F1I82`HIDRKURDB"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("*MTZ=/J,^ESJK,
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE<VEA("BF3*6G
M*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS
M9VED("));F9O(@IM<V=S='(@(KCJL%0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("*XZK!4
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B
M26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`BM4RE
M::7.JKJXZK!4+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T
M97(B"FUS9W-T<B`BIF*KX:VQM*&D2L3FINQ?;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I
M9"`B26YS97)T($EM86=E(@IM<V=S='(@(K2AI$JYSZ3Y(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS
M97)T(%1A8FQE(@IM<V=S='(@(K2AI$JJ[:[F(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E
M8B!,:6YK(@IM<V=S='(@(K2AI$JZ]+CTLW.ULB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B
M26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(J9BJV6ML;2AI$K$YJ;L
M7T,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(J9BI=BK9<3FINRKX:VQM*&D2J1`
MK=.W<\3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("*F8J78JV7$YJ;LJV6M
ML;2AI$JD0*W3MW/$YJ;L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("*F8J78JV6F0ZOA
MK;&TH:1*I$"MT[=SID,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("*F8J78JV6F0ZME
MK;&TH:1*I$"MT[=SID,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(J9BI=BK9;A@
MPDFKX:VQM*&D2J1`K=.L<;BH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BIF*E
MV*MEN&#"2:MEK;&TH:1*I$"MTZQQN*@B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R("*TH:1*I6FTP*5.O,NJ3R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H
M('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("*W
M<[%+O5BQ3K%(M6^H[+-OK=.V;*7SIF&G?3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*P'BF<Z[F(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(J9BJV6ML;2A
MI$K`>*9SKN8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM
M<V=S='(@(J9BJ^&ML;2AI$K$YJ;L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`BIF*K9:VQM*&D2L3FINPB"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M
M97-S86=E<R(*;7-G<W1R("*TH:1*MFRE\R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("*F8JOAK;&TH:1*K'&XJ"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T
M<B`BIF*K9:VQM*&D2JQQN*@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F
M=&5R(@IM<V=S='(@(J9BJ^&ML;2AI$JF0R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R
M="!R;W<@8F5F;W)E(@IM<V=S='(@(J9BJV6ML;2AI$JF0R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
MIG>E_K#=I7FJNK6JKM<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*
M;7-G<W1R("*TH:1*+\7<I_.\=KFS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,
M:6YK(@IM<V=S='(@(K2AI$HOQ=RG\[KTN/2S<[6R(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT
M(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`BPDF\QJ2CJ*RE2*;<J?.U3*IKML>P9;6YL'2X;;ASLM4N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS
M=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`BPDF\QJ2CJ*PN(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
MON.\QB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,W"FUS9VED("));G1E
M9V5R(&QI<W0B"FUS9W-T<B`BON.\QJ9#(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN(@IM<V=S='(@(K5,KL2JNB!51$@HJ,^ESJK,N.JN
MQJKMP%DI+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$V-R!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM
M<V=S='(@(K5,KL2JNB!:25`@N.JNQBXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M("*U3*[$JKK`LZ7.M7NFH2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T
M<B`BM4RNQ*JZI^6FN+BYO5@N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P
M.3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-C(@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(R,S8*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,#,@;&EB+TAO<F1E+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(@IM<V=S='(@(K!EI5BJNKCJKL:U3*[$+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(K5,KL2JNJ78O-"F[:=]
M(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T
M<B`BM4RNQ*JZP,FNUZ[FIJ$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M("*U3*[$JKJQPL5VO5@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`BM4RNQ*JZIF&PSRXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T
M<B`BM4RNQ*JZ(&US9U]T>7!E+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R("*U3*[$JKJISJ?DI*.H["!A<&E?:60N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("*U3*[$JKJISJ?D
MI*.H[+#1O,8N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("*U3*[$
MJKJD]\5VK:TN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("*U3*[$JKJY
MV:;QP]&G3[U8+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("*U3*[$
MJKJRHZM^O5@N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(K5,KL2J
MNK-QL%2H\ZEW+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`BM4RNQ*JZIJRE\Z1(.EPB
M)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`W-2!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$R-3@*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM
M<V=S='(@(K5,KL2JNJ3`J,FJJZ7S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R
M97-S+B(*;7-G<W1R("*U3*[$JKJHT[>]INVG?2XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC
M;V1E(&1A=&$N(@IM<V=S='(@(K5,KL2JNKA5L.J]6+CJKL8N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(KCJLJ,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<U"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(J9>
MM%^_[[[<(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8@**7LKM0I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED("))<F%Q(@IM<V=S='(@(DER87$@**7LJ=2G2BDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER
M96QA;F0B"FUS9W-T<B`B27)E;&%N9"`HMU*ZN,3U*2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@
M(DES;&4@;V8@36%N("BPTJYQ*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R("*GO;.AN7"K0B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES
M<F%E;"`HI4BFXJ9#*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C(V"FUS9VED("))<W-U97(B"FUS9W-T<B`BP[&U;ZK,(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L
M:6,B"FUS9W-T<B`BL=?%Z2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B271A
M;'D@*+AQI&JG42DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC
M82`HI/JV4J5;*2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS.3D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U
M"FUS9VED(")*86YU87)Y(@IM<V=S='(@(J1`I.LB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N
M(@IM<V=S='(@(DIA<&%N("BDZ:6[*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@S"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@
M(J3II.4@*$E33RTR,#(R+4I0*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("*_0:;HKG$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R(")*;W)D86X@**SYI;DI(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`BI$.D
MZR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*
M=6YE(@IM<V=S='(@(J2[I.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(KGON_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T
M<B`BN&VDI"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B
MI:JE:[GON_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@
M(KYAI:JY[[OT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T
M<B`BOF&E:[GON_0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z
M86MH<W1A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(JM/KV2M[+S+
M(#\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;GEA("BJUJC(*2(*"B,Z
M(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E
M<F]S(+M[P]*_^;M^+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM
M<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`BKM:DW[=SI.(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R("*J]\9?J]BEWR(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(JKWQE^O
M4[QX(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(JKWQE^J^*O7(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("*J]\9?
MJZRZ02(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED
M(")+97D@57-A9V4B"FUS9W-T<B`BJO?&7[MYJFLB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BI=BK9:JZI+VV?:KW
MQE^F^*I!OKFDI"RD=[AGIG.F8J=!JKJJ]\9?+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("*HX+6C(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS
M9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2`HL/*HO:3:M+4I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O
M9B(*;7-G<W1R(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B`HI5_!^BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G
M<W1R(")+;W)E82P@4F5P=6)L:6,@;V8@**MNP?HI(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M("+!^J3E("A%54,M2U(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W
M86ET("BL[*O"KU,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMY
M<F=Y>G-T86XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G
M:60@(DQA7WEO=70B"FUS9W-T<B`BJJFML;!TN&U?>2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@
M(KMYJ*4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC(@IM<V=S='(@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M("B\9+#J*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA
M<W0@2&%L9B(*;7-G<W1R("*D5:5BI.LB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@
M(K/,JO&D0*:XL4N]6,7<I_.I\R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R("*D5:FVI.LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("*D5Z:XI_.W<SHB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(@IM<V=S='(@(J17I$"FN+5NI$HZ("5S(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(J17I$"FN+5NI$HZ("5S(*;;
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L
M;V=I;CH@3F5V97(B"FUS9W-T<B`BI%>D0*:XM6ZD2CH@LL2D0*:XM6ZD2B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQA='9I82`HJ=2RYKK[J,@I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`BJFNKWR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(JJIK;&P=+AM
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3&5B86YO;B`HOJ2DVKG@*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("*EJL/D(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,#@*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(J6J
MP^2J[<!9(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#0*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(J6JP^2MR"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*
M;7-G<W1R("),97-O=&AO("B_X*_!IJLI(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R
M("*W4K&A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R:6$@*+_@
MI/&WYZC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G
M<W1R("),:6)Y86X@07)A8B!*86UA:&ER:7EA("BG4:3QJ,@I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED
M("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6X@**9#I.2T
ML+2UM6XI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`BMTRK0B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED
M("),:6=H="!286EN(@IM<V=S='(@(J1PJT(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%
M87)L>2(*;7-G<W1R("*FK::SI'"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B
M"FUS9W-T<B`BL=^FLZ1PJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS
M9W-T<B`BI'"P?:M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM
M<V=S='(@(J1PJT*FL[EP(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`BI'"S
MMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R
M"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("*D<+!]L[<B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM
M<V=S='(@(J6TJF^XUB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$X"FUS
M9VED("),:6YK(@IM<V=S='(@(K-SM;(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@
M<&]I;G1S('1O.B(*;7-G<W1R("*S<[6RPDFH[#HB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@W.0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("+%
MXZ7<KLFS<[6RMFRE\Z;MIWVH[+USO&>V;*7SK;:ML2(*"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B
M"FUS9W-T<B`BLW.ULB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@HC
M+"!F=7IZ>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(L-#IN(B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("*F0Z58("T@
MJ,^ESJK,I6FE2*S=J.RS;ZW3JTBE\Z=8(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`BID.E6+CJ
MKL:N=R(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),
M:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(J9#I5B[H:GZO-##1"(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(J9#I5BJ[:[F(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`BL%&]U[ASLM4MP,FN
MU\)D(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED
M("),:7-T+4AE;'`B"FUS9W-T<B`BL%&]U[ASLM4MJ$2G52(*"B,Z(&QI8B](
M;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R("*P4;W7N'.RU2W#T:=/N+F]6"(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("*P4;W7
MN'.RU2V^UJ:SJLPB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("*P4;W7N'.RU2VQ2*7SI$@B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI
M<W0M4W5B<V-R:6)E(@IM<V=S='(@(K!1O=>X<[+5+:UQOEPB"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S
M8W)I8F4B"FUS9W-T<B`BL%&]U[ASLM4MJ/JN^*UQOEPB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S
M97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(J9#I5BW?+3!I:*QT3H@)7,B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(J9#I5BHSZ7.
MJLREHK'1.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI
M;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`BID.E6*C/I<ZJS*JZI5ROX+-1P_:SK"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("*DY;['(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET:'5A;FEA("BEW[.SJ7LI
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G
M:60@(DQO861I;F<N+BXB"FUS9W-T<B`BN/RD2J2D+BXN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@
M(@IM<V=S='(@(K?MIF&NR;:A.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("*F8;#/NU"N
MR;:A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("*F8;#/(@H*(SH@;&]G:6XN<&AP.C$X-B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@
M(K5NI$HB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R("*U;J58(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("*U;J1*(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B
MM6ZD2J1UIT`B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DR"FUS9VED("),
M;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D
M('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("*U;J1*I:*QT2P@
MO=#`RZQDN]6D5:JZI<ZDX:97J4VQ2[U8+""U3:OAK:NXU2XB"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.3@X"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(K5NI$JEHK'1+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`BJOBE>2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("*W4K&A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@
M(DQO=R(*;7-G<W1R("*G0R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K
M(&QE='1E<G,B"FUS9W-T<B`BI'"\9Z?&P[Z\QJ9R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I
M9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("*D<+QGJ=2D0KS&IG(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(J1PO&?#N;"HO,:F<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),
M=7AE;6)O=7)G("B_8[3+L_DI(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,Y."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#,V"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*
M;7-G<W1R("*DZR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*
M;7-G:60@(DU/5$0B"FUS9W-T<B`BJ$.DZ;!4KJ<B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B"J_J5;
MP,FNUZ2DJ%.FL[CJKL8N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A;R`HOT2J^2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9B(*;7-G<W1R(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8@*+"HJ.2Y>:9`J4VPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B
M"FUS9W-T<B`B36%D86=A<V-A<B`HL*BY1J5;M+6E6RDB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(L5=LTXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB
M"FUS9W-T<B`BMFRE\R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`BMFRE\[K>LGHB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`BJ]BEW[-SM;)?:RXN
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2`HL*BIU*O"*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L87ES:6$@*+"HJ-.FZ*C(
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV97,@*+"HNKBF
M8:32*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI("BPJ*=1*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$@*+"HNKBE3"DB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES
M="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L
M(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I
M97,N(@IM<V=S='(@(KK>LGJG0:JZI,##_BRHPZ5"K+"DP,/^LUVI=\-#IN(N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-""F8;G/(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U
M97-T(&UA<"(*;7-G<W1R(")-87!1=65S=""F8;G/(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R("*D5*3K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R
M9VEN(@IM<V=S='(@(L/DK,DB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G
M<R(*;7-G<W1R("*\T+!/IJ@@K-VY3"^EO*S=N4PB"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(KS0
ML$^FJ*CDI4RJNL/1IT\@**C2IG`N(*VKK6XOI'>F7L+0*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87)S:&%L;"!)<VQA;F1S("BP
MJ*Y,NKBX<ZYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T
M:6YI<75E("BPJ+2CI:>G2JYQ*2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`BI,>P
M=,3FINRDI"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A
M;FEA("BM5*=1MO"EIZC(*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@
M(DUA=7)I=&EU<R`HO*^HO:;HM+4I(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB
M"FUS9W-T<B`BI+FS7*JZL\RD:L))O,8N(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R("*J_J7SO,:EV*1WME>E6*2YLURD5ZVM+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`BL\RJ\2`R-""D<*[)JKJSS+"JM\6K
MUSH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(K/,JO$@-B"D<*[)JKJSS+"J
MM\6KUSH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`BL,^V]*17K:V\QJ78(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(R,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L
M96YG=&@B"FUS9W-T<B`BI+FS7+/,I&JJ^*O7(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("*DK:3K(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E("BPJ*SYKU.N<2DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE
M(@IM<V=S='(@(L+EOL<B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C$V"FUS9VED(")-96UB97)S(@IM<V=S='(@(J:HK?LB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM
M<V=S='(@(K_OL^:\TJ:A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM
M<V=S='(@(J98J-;`>*9SKN8B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(K9LI?,B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(K9LI?/%Y\/2I'>GN::H+*;]K$^HSZ7.JLRJNL.QL[FK;[5,JFNS<;E,Q>?#
MTBXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM
M<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("+"LK!4I'>Y3+3!+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(L*R
ML%2KK+I!(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"B,L(&9U>GIY"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(J78JV6DT:[P(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B365T87(@L,^V]+5,JFNHSZ7.+B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")-971A<B"PS[;TM4RJ:ZC/I<XN
M(++3N&"]T+#1IM*H=++.NMZR>K5NO_TN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C
M=&5D+B(*;7-G<W1R(")-971A<D1"(*E\I;RS<[&U+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`BI.BJ:R(*"B,Z
M(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#+W-O
M87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB
M(&ES(&YO="!D969I;F5D(@IM<V=S='(@(J3HJFL@7"(E<UPB(*6\LU&I=[AQ
M(@H*(SH@;&EB+TAO<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S
M(@IM<V=S='(@(J3HJFNEO*EWN'$N(*5(J4FE<Z3HJFLZ("5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("*DO:CN(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B365X:6-O("B^I:;HK?0I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]N97-I
M82P@1F5D97)A=&5D(%-T871E<R!O9B`HL4NG2L.YI:>FZ*C(*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM
M<V=I9"`B36ED9&QE(@IM<V=S='(@(J2DMJ$B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R
M(")-:6UE(*NLND$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I
M9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(K/,JO$@,C0@
MI'"NR:JZL\RG0[?%J]<Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R
M"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("*SS*KQ
M(#8@I'"NR:JZL\RPJK?%J]<Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9"(*;7-G<W1R("*SS+5UL4N]6*[$M,&I?*6\J.RTP2(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S,*;7-G:60@
M(DUI<G)O<B(*;7-G<W1R("*L3:YG(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(L+XMK4B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`BI^2DHZCL(%!%05(@I5VXRR!(5%107U)E
M<75E<W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(K-=J7?`R;_RI:(N(*9PJD>M;JC/I<ZS;ZW3P+.ESK5[
MIJ&G0:6RMK>R>Z9BM$ZRHZ7-I4PN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`BI^2DHZCLPK*P5*JZ($E$+B(*"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER
M960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(J?DI*.H[*6RMK>JNB!0
M14%2(*5=N,L@36%I;"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R
M("*GY*2CJ.RW?+3!JKH@240N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`BK%"TP:1`
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I
M;&4@36%I;"(*;7-G<W1R("*FYK#*MFRE\R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G
M<W1R("*WQ:E-(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C8@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A
M=&4B"FUS9W-T<B`BI_.W<Z3IM,$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!5
M4DPB"FUS9W-T<B`BK=>G[[KTIWTB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU<R(*;7-G<W1R("*\TK+5(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A+"!2
M97!U8FQI8R!O9B`HO*^ZN*9HI<LI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T
M<B`B36]N86-O("B\KZ_'K?0I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M(")-;VYG;VQI82`HNUBE:BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X
M.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`BI.NDSJ9^(@H*(SH@
M;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*
M;7-G<W1R("*H0Z3K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(KM8
MMNNIU*]3(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("*DZZS;(@H*
M(SH@;&EB+T9I;&4O0U-6+G!H<#HQ.38@;&EB+T9I;&4O0U-6+G!H<#HR.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`BIF*RQ"5DIN:G
MY*CLJKK$YJ;LO,:EV*1WME>E6+EWM,$E9"XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B
M"FUS9W-T<B`BO*^LI:WT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("*F
M:+:SKLFTN"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(J9HMK.NR;.Q
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*
M;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("*TN*[)IFBVLR(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N
M(@IM<V=S='(@(J15LKXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HU,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("*EJK*^(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT
M(@IM<V=S='(@(J5KLKXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`BI%>ROB(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R("*D5;*^(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(S"FUS9VED(")-;W9E('5P(@IM<V=S='(@(J17LKXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]Z86UB:7%U92`HLO:D5*3QITHI
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#@*;7-G:60@(DUU;'1I+6QE
M=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("*]QK_OIJ&D5:G4I5ROX*KM
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*
M(RP@9G5Z>GD*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("*F:+QV
MN;,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP
M;&4@<V5L96-T:6]N(@IM<V=S='(@(KW&O^\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(J?:
MJKJQ8KBY(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")-
M>2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(J?:JKJQ8KBYN.JP5"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O
M<G1A;"(*;7-G<W1R("*MTZ1(K[BE>"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B
MK=.D2*^XI7BMMJVQL'2X;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-
M>6%N;6%R("B]<:AL*2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS
M9W-T<B`BI*,LI]JDHZ90MTXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE
M(@IM<V=S='(@(J97NMDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M
M:6)I82`HJ+JFS*3QJ,@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R
M=2`HO]6^?"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L("BEIZIY
MNK@I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(").971H97)L86YD
M<R`HLOS$]2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`B3F5T:&5R;&%N9',@06YT:6QL97,@*++\Q-VF=Z9AID.TM2DB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@K+"P\L*FJKJZ]*=](@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(+[,P]*G0+QO
MNO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED
M(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E(+[,
MP]*L1K6FNO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U
M"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P
M92"G\[=SNO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S
M"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S
M8V%P92"G0+QONO2G?2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M3F5T<V-A<&4@4U-,(*;XJD&^N:97NMDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N="(*;7-G<W1R(").971S8V%P92"^S,/2JKJU^;C1(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@OLS#TJNLND$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM
M<V=S='(@(KKTN/2D=:CC(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BL7&EO"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").97<@0V%L961O;FEA("BW
M<[/8J+VF:*6GJ,@I(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E
M;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("*W<[Q7
MI,##_B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q
M(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](
M;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@365S<V%G92!T;R`E<R(*;7-G<W1R("*\9ZM(M;D@)7,B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]"
M;&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(K=S
MI.LB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS
M9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("*W<ZC/I<ZJ
MS*97NMD@**M$I;*M;BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@
M(DYE=R!:96%L86YD("BOPZ;HQ/4I(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BMW.Q
M2[U8(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*
M;7-G<W1R("*W<[%+O5BQ3JGS)7BH[+3!+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`BMW.Q2[U8I*.RQ:98+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD
M;W<@*%]B;&%N:RDB"FUS9W-T<B`BMW.U^+6A("A?8FQA;FLI(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B
M"FUS9W-T<B`BMW.[1"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`BMW.[1+ASLM4B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*
M;7-G<W1R("*D5:1`J$(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@
M9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`BI%6MTZ3KK-LB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W,B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(J15
MI$"MT[_OMK4B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`BI%6D0*VV(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B
M"FUS9W-T<B`B3FEC87)A9W5A("BEIZ5;J=2ERBDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(DYI9V5R("BEIZ3I*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R(").:6=E<FEA("BI8*3.IU&HR"DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R("*QWZ17(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").:75E(@IM<V=S='(@(DYI=64@**_#KDJN<2DB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*
M;7-G<W1R("*G7R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT
M;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`BM4RE::C1Q>.EW*YT
MLJ>JNK-=J7>XZJ[&+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HQ,#8*
M;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I
M;6%G97,N(@IM<V=S='(@(K5,I6FESJJZM::RI*O8LWD@25-/(+QVN;,N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("*H4Z:SI^6FN+S+IJ$N(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`BJ=*K_*EWJKJF[+AMI%>H4Z:SL,^V]*9S
MIF(B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@
M8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`BJ%.FL[2CJ-&FYJC&ON2F5[K9I4BHT2!-0T%,(,7GP](N
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`BJ%.FL\7<I_,N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T
M:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(K5,JFNF8J78JV7%=JVMI*2\5Z5;
MIKC%=JVM+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38Y(&QI8B](;W)D92YP:'`Z
M-3`X(&QI8B](;W)D92]5=&EL+G!H<#HW-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M("5S+B(*;7-G<W1R("*H4Z:SJ_RI=ZJZ("5S(+-=J7>XZK!4+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HX-#0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("*H4Z:S
MJ_RI=ZJZ($944"!61E,@LUVI=[CJL%0N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(JA3IK.K_*EWJKH@4U%,(%9&
M4[-=J7>XZK!4+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`BJ%.FLZO\J7>JNB!344PM1FEL92!6
M1E.S7:EWN.JP5"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(K5,L]&^
M;,))O,8N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(J6\
MM*.HT:78JKHN(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,PIM<V=I
M9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("+`R:[7I;RD5[;'(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N
M9"XB"FUS9W-T<B`BI^2DHZCLN<^EW"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@
M<V5T+B(*;7-G<W1R("*F[+AMN.JP5*E\I;RS7:EW(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(JE\I;RTHZC1INRX;;CJL%0N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G
M92!S=7!P;&EE9"XB"FUS9W-T<B`BI;RTHZC1PK*P5"XB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P
M96-I9FEE9"XB"FUS9W-T<B`BI;RK_*EWIE>ZV2XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E
M8VEF:65D+B(*;7-G<W1R("*EO*O\J7>XN;U8+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B3F\@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(J?DI*.H[+G/I=PN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*H4Z:SJ_RI=[%+O5BE
M2*C1($A45%`@Q>?#TBXB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ
M,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("*H4Z:SJ_RI=[%+O5BE2*C1($E-05`@Q>?#
MTBXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("*H4Z:SJ_RI=[%+O5BE2*C1($ME<F)E<F]S(,7GP](N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<@;&EB+TAO<F1E+T%U=&@O
M;&]G:6XN<&AP.C@T"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-S4*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`BJ%.FLZO\J7>Q2[U8I4BHT2!,;V=I;B#%Y\/2+B(*
M"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("*H4Z:SJ_RI=[%+O5BE2*C1(%!!4U-71"#%Y\/2+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K
M_*EWL4N]6*5(J-$@4TU"(,7GP](N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B
M"B*EO+_II$H@3W!E;E-33""D1Z2XL/6FYL#)JKJE_KCTKGPN(%!+0U,@,3(@
MLU>NYJJZI5NQ2[CJKL:[W:UNI<ZH[+C3M7NFH2XB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I
M9VYU<',N(@IM<V=S='(@(JA3IK.KW;QFJKJU^:55I=.]T"XB"@HC.B!L:6(O
M5D93+G!H<#HW-C4*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`BNL^Z
MT+!TPT*EO+-=J7<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R("*U
M3*[FO74B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`BJ7REO*O\J7?$YJ;LI,"Y:J9R
MI+@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`BM4RNV+UU(@H*
M(SH@;&EB+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM
M<V=S='(@(K5,IKG`R:[7(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R("*U3+S(IG.EV+_]I6FHT:?6J/HN(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,2!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`BI;RVQ[!EJ,^ESJK,IE>ZV:G.
ML4N]6"XB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED
M(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("*U3*5II<ZJ
MNB!834P@N.JNQK-1ML>F7B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-S$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDX,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3DR"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y
M"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`BJL6EU:W((@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(JWLJ6RS7:EWP,FDI*?DI*.H[*JII;NXZK!4+B"M
MJ[=SLJ.ES;-=J7?`R2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*F8J=!JKJS
M7:EWP,FDI*?DI*.H[*JII;NXZK!4+B"MJ[=SLJ.ES;-=J7?`R2XB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@
M(K5,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("*U3"`H
M=7-E(&EM<&QI8VET*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS
M9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("*DZ:;5L-*DY2`H
M25-/+3@X-3DM,3`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R
M(").;W)F;VQK($ES;&%N9"`HO]6ZUJ=*KG$I(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R("*E7Z5BLGDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)W87D@**Z_
MJ\(I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@
M(DYO="!!9G1E<B(*;7-G<W1R("*K1*2GJ^$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R("*K
M1*2GJV4B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B3F]T(&$@
M9&ER96-T;W)Y(@IM<V=S='(@(J2CK$^D0*W3I=B__2(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.34*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R("*U>Z:AJ7REO*>YIJ@N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R
M("*DH[-=J7<B"@HC.B!L:6(O5D93+G!H<#HQ.3,@;&EB+U9&4RYP:'`Z,C`X
M(&QI8B]61E,N<&AP.C(S,R!L:6(O5D93+G!H<#HR-3$*(SH@;&EB+U9&4RYP
M:'`Z,C8X(&QI8B]61E,N<&AP.C(X-"!L:6(O5D93+G!H<#HS,#`@;&EB+U9&
M4RYP:'`Z,S$U"B,Z(&QI8B]61E,N<&AP.C,S,B!L:6(O5D93+G!H<#HS-C4@
M;&EB+U9&4RYP:'`Z-#(U(&QI8B]61E,N<&AP.C4P-`HC.B!L:6(O5D93+G!H
M<#HU-S,@;&EB+U9&4RYP:'`Z-3DP(&QI8B]61E,N<&AP.C8V.`HC.B!L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T-2!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C$V,`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N
M<&AP.C$W-2!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!L
M:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`BI;RS4:3DM*DB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").
M;W1E<R(*;7-G<W1R("*SQJ?1O_TB"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I
M;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+B(*;7-G<W1R("*H4Z:SI6G"<\3]JKHLIEZE:"XB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B
MI%&D0*3K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3`*;7-G:60@(DYU
M;6)E<B(*;7-G<W1R("*\QJ9R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(J9RI+B\
MQB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<S(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB
M97(@;V8@8V]L=6UN<R(*;7-G<W1R("*F<J2XO&6KUR(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G
M<W1R("*FYKS&(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`BI_.W<[!TN&VX<[+5
MKLFEO*O\J7>\QJ78+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<P"FUS9VED(")/8FIE
M8W0B"FUS9W-T<B`BJJNE\R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("*JJZ7SJ]BE
MWZK,(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#@*;7-G:60@(D]C=&%L
M(@IM<V=S='(@(J1+MFFF["(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(J11I.LB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G
M:60@(D]F9FEC92(*;7-G<W1R("*_[*2]J\<B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D
M<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`BMW.Q2[U8I;*VM[M0PL*Q
M2[U8I*.F4"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*
M;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("+"PK%+O5@B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BPL*Q2[U8I*.EO[U4(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(D]M86X@**K\L-(I(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("*E=::S($E-
M05`@IOBJ0;ZYI.2TJ:M(I?.G6*3`J,FE7*_@+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`BI^2DHZCLN<^EW"XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B
M3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("*E=:2Y
MLURD0*W3MFRE\Z;MIWTN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M
M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("*E=::SOM:FLZK,NU"H=++.
MNMZR>JW[I6FE2,7<I_.F0*C)Q7:MK2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P"FUS9VED(")/<&5N(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("*F8K=SJKJU^+6AMGVQTB(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R
M<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-
M12!P87)T+B(*;7-G<W1R(")/<&5N4U-,(+_YNWXZ(+5,JFNQ<2!3+TU)344@
MP[&SN:K^I?.XT;9]N.JNQBXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@
M;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BIF*W<ZJZM?BUH;9]L=*S
M<[6R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R
M871I;F<@4WES=&5M(@IM<V=S='(@(J=`MWZH=++.(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M("*_[[:U(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@
M9F]R("5S(@IM<V=S='(@(B5SO^^VM2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*
M;7-G<W1R("*VM:78O7.XN2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BLM7"M"(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES
M871I;VYA;"!5;FET(@IM<V=S='(@(K+5PK2SYJ;L(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R
M("*RU<*T(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(JWLJ6S`LZ7.
MM7NFH;S+JD\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(J9B("5S.B"DI*JZK>RI;+S+JD\N(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B
M3W1H97(B"FUS9W-T<B`BJ.2E3"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(JCDI4RX
MZK!4(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B
M3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BOM:FLZK,Q7:MK2(*"B,Z(&QI
M8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004T@Q>?#TK5,KL0N
M(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@
M(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CJV;*7SIOBJ0;K=
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B4$=0
M($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(E!'4""\QJ;LP[&SN2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R
M>7!T960@1&%T82(*;7-G<W1R(")01U`@I5NQ2[CJKL8B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*
M;7-G<W1R(")01U`@I+VV?:KWQE\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(E!'4""D=\.QL[DOI'>E6[%+(+CJKL8B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4""U>Z:A
MO5@B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L
M;"(*;7-G<W1R(")02%`@K_.]6B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(J3(J^&D<*M"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`BI,BKX;!]
MJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("*DR*OAIK.SMR(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`BI,BKX;!]L[<B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM
M<V=S='(@(J3(J^&TN"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("*DR*OA
MN7"K0B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8(&5X=&5N
M<VEO;B"_\J6B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H
M96QL(@IM<V=S='(@(E!(4""O\[U:7T@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG
M(@IM<V=S='(@(KG4I5(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A
M:VES=&%N("BDVK#RM+6I6BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QA=2(*;7-G<W1R(")0
M86QA=2`HJ:VO6RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C
M=7!I960@**3:L,>TM:E:ION[XK#/*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S
M='(@(E!A;F%M82`HI-JNL["H*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R(")087!U82!.97<@1W5I;F5A("BDVJ6LJ,BW<[18I+JHR"DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2`HI-JIU*9C
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(J9HMK,B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#(R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3D*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U,2!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<W"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-#,@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I
M9"`B4&%S<W=O<F0B"FUS9W-T<B`BL4N]6"(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(K%+O5C%W*?SI[FFJ"XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R
M<F5C="(*;7-G<W1R("*Q2[U8I*.EO[U4(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(JA3IK.K_*EWL4N]6*5(
MJ-$@4D%$2553(,7GP](N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3<*
M;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(K%+
MO5B]5+M[(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS
M9VED(")087-S=V]R9#HB"FUS9W-T<B`BL4N]6#HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M("*Q2[U8.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(K%+
MO5BELK:WIVNF6"XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM
M<V=I9"`B4&%S=&4B"FUS9W-T<B`BMDND5R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@
M8VQI<&)O87)D(@IM<V=S='(@(K9+I%<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@
M(KCTKGPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("*KW;QFM6Z__:%'(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T
M<B`BIJBM^R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(J;*I,"D\2(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS
M9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B
ML/6FYKK[Q4"^WJ=`(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R("*U;J1*J^&P]:;FNOO%0+[>IT`_(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
MQ7:MK2(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(EPB)7-<(JJZQ7:MK:6\LU&G4K"C+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(J9S
MJ/J^1*G:(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S
M='(@(L5VK:TB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H
M<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S
M:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+%=JVMNMZR>B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M
M871I;VXB"FUS9W-T<B`BI]JJNB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")0
M97)U("BOM;Y\*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I
M9"`B4&5T<R(*;7-G<W1R("+#9*JK(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R(")0:&EL:7!P:6YE<R`HM>&KW[NK*2(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M("*Y<;C<(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I
M9"`B4&AO=&]S(@IM<V=S='(@(L/`M%DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*
M;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`BN;.O
MP"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`BO="V::1*P'BF<Z[FPDF_[R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO
M=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("*]T+U4J7>M;K*^L*.FN:2XI?,Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(KW0O52I=Z=!K6ZD
MI,)?IKFDN*7SJKJS<[6R+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-38V
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R("*]T+_II$JD0*W3I.NE]Z3.IGZE]RXB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`BO="_
MZ:1*MW.\5Z3`P_ZJNJ97NMDZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M,#4*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM
M<V=S='(@(KW0O^FD2J1`K=.FLZ[$JKH@25`@INRG?2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-C0W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*
M;7-G<W1R("*]T+_II$JD0*W3IK.NQ*JZI.FTP3NDQ+_OIKFDZZ7WJKJDZ;3!
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("*]T+_II$JD0*W3IK.NQ*JZ
MKLFVH2XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS
M9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M(@IM<V=S='(@(KW0M*.HT;#=PT2JNKI+K6XN(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V
M"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S
M=V]R9"(*;7-G<W1R("*]T+_II$JG0:JZJ,^ESJK,IE>ZV:3.L4N]6"(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E
M(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H
M('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`BO="^
M7,6JI%6F0Z2ZKF4NIT&ELK:WIE"W3K-OJ,>HQK:UI'ZOX*C/I<ZH=++.+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS
M9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S
M='(@(KW0O^FD2K=SJKJDP,/^IE>ZV3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G
M<W1R(")0;VQA;F0@**IIQ/4I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("*L1JIV(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B
MI^NRO"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L("BX
MLK7EI/HI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(@IM<V=S='(@(KQVN;.F[+AM(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`BJNVNYJ;LN&TB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI
M<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("*[O+!E
MMFRE\ZCLLV^MTZM(I?.G6"`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S
M="`E<R!H;W5R*',I.B`B"FUS9W-T<B`BL\RJ\2`E<R"D<*[)JKJML*M"MG$Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@
M(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`BK;"K0CQB<B`O
M/K[WLG8B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@
M(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@I^2DHZCLJ=*[W:UNJKH@3$1!4""I
MM:;YKDVE\RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*
M;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@I^2DHZCL
MJ=*[W:UNJKH@<V5S<VEO;B"IM:;YKDVE\RXB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`BKO#`HR(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S
M96$@;&5V96PZ("(*;7-G<W1R("*N_*6MK;&N\,"C.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(J[PP*,Z("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@
M(KEWQ/TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("*F8K=SJKJU^+6AN7?$_;QVN;,B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("*D
M5Z1`K=._[[:U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`BID.F
M3*3EI?,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(JAPL4NJ]\9?(@H*(SH@;&EB+TAO<F1E
M+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("*PW<-$(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E
M<V-R:7!T:6]N(@IM<V=S='(@(K#=PT2T>:UZ(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`BL4VN
MUR(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$U(&QI8B](;W)D92]&;W)M
M+G!H<#HR,3DR(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")0<F]M
M<'0@=&5X="(*;7-G<W1R("*THZ7<I+JN92(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("*DO;9]
MJO?&7R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("*DO;9]JO?&7[ITNN(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(J2]MGVJ]\9?N.JP5"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
MI+VV?2^H<+%+JO?&7[GOJ,.EO+-1LJ.ES2XB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R`HJFFF:+ZDIE4I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B46%T87(B"FUS9W-T<B`B46%T87(@**5DN48I(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("*L9+C?(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R
M("*ZS[K0L'2X;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(E)302"DO;9]JO?&7R`H)60@INRDN"DB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(V.`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S
M='(@(K_OOMRV<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(JM"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@
M16%R;'DB"FUS9W-T<B`BIJVFLZM"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R
M("*QWZ:SJT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`BL'VK0B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED
M(")286EN(&%N9"!3;F]W(@IM<V=S='(@(JM"IK.SMR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O
M(%-N;W<B"FUS9W-T<B`BJT+"X+.W(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(L!(OO>D<+MY
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S
M='(@(J3QLG8B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM
M<V=I9"`B4F5A9"(*;7-G<W1R("+%JJCZ(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S
M='(@(L6JJ/JV;*7S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(J]U
MJKJM;J=2L*,@)7,@MMP_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RXB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`BKW6JNJUN
MLDVPHZC/I<ZJS"`E<R"JNKCJKL:VW"`_(+-OMK6^WJ=`L4ZU3*IKJ^RT7RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("*H^J[X
MM%^M["(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(JVKMW.^
MX[)Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(JVKMW.^X[)Z
ML,JZ0:78O_VDN*7S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#4*
M;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(JVKMW.^X[)Z
MK=.D2*^XI7BDNJYE.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*
M;7-G:60@(E)E9V5X(@IM<V=S='(@(K%@LU>J[:7<IJ$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(S.`IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B
M"FUS9W-T<B`BP_;!<,)SQ/V^N2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G
M:60@(E)E;&]A9"(*;7-G<W1R("*MJ\6J(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`BM?N]UR(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S
M(@IM<V=S='(@(KNWNMVF^*I!OKDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("*[M[K=NO2G?2`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`BLKZPHR(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K
M(@IM<V=S='(@(K*^L*.PS[;T(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R
M("*ROK"CQ.:F["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(J5HL*.NYJ:A(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*
M;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(K*^L*.Y[R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("*FVZ;XJD&^N;S(IG.EV+_]I*2ROK"CI'?`>*9SJKJS7:EWM7NFH2XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`BLKZPHR(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*
M;7-G<W1R("*FVZ3EI?.DI+*^L*.FN:1`N&#"22(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(K*^L*.HSZ7.JLPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(K*^L*.HSZ7.JLPZ("5S(@H*(SH@;&EB+TAO<F1E+U)0
M0R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A
M;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`BN]VH1*6\
MLU&F7L"S.B"_^;M^N+F]6#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30U"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(J?DI*.H[*G2N]VJNJI!L,@N(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ-S8@;&EB+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)3(D<R"JNK-=J7>ELK:WJ_RI=R!<
M(B4Q)'-<(B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV-S@@;&EB+U9&4R]F='`N
M<&AP.C@U,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E9&4R"JNK-=J7>ELK:WJ_RI=R!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(K-=J7>XZJ[&I;*VMZO\J7<@7"(E<UPB
M(@H*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`BI;*VM\3FINPB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W
M"FUS9VED(")297-E="(*;7-G<W1R("*MJ[-=(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S
M='(@(JVKLUVQ2[U8(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`BK:NS7:=!
MJKJQ2[U8.B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E
M<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("*F7J9SL\RKX:1`K=.L9+C?(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`BM;*J1R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`BJO"F7K_OMK4B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`BID&FN+_II$JW<[%+O5@B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(E)E=6YI;VX@**]DI:>I]*YQ*2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V
M97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`BIEZT7[-=J7<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`BNO2MMKUSO^B^N;_OMK4B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`BP;R[
M>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BI6O#Y"(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`BI6O#Y*KMP%DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-@IM<V=I
M9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(J5KP^2MR"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I
M9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(J9#I+JN95]W+BXN(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@
M(E)O;&4B"FUS9W-T<B`BJ*2FXB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T
M<B`B4F]M86YI82`HP[FPJ*6GJ,@I(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M("*QV\+@(#$X,""KUR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C$*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(K!FKLFP
M=R`Y,""KU[';PN`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(W"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`BMK:NR;!W
M(#DP(*O7L=O"X"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S
M='(@(J9#I+JN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S
M='(@(J9#I+JN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("*F0R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*
M;7-G:60@(E)U;&5S(@IM<V=S='(@(J[FO74B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM
M<V=S='(@(L3FINR[4*9#KN:]=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(L3FINRNYKUU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`BID.NYKUU(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(K#UIN8B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4G5S<VEA;B!&961E<F%T:6]N("BK
M6,.YM+4I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD82`HOV.F
M=[E&*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-
M24U%(*5;L4O#L;.Y(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS
M,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("*V
M;*7SI'>HSZ7.(%,O34E-12"E6[%+(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S
M;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B4T%33"#%Y\/2M4RNQ"XB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(L*RL%0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R("*XZJ[&KG>O\[U:(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,R-S(*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E
M(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(J5;L4NRU[K=OO<B"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*
M;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BIJBE7"(*"B,Z(&QI8B]A<&DN<&AP
M.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("*XZJ[&KG>O\[U:7U$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q
M"FUS9VED(")382(*;7-G<W1R("*L4+3!I+LB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(
M96QE;F$B"FUS9W-T<B`B4V%I;G0@2&5L96YA("BX=+NNL,>OQRDB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+:71T
M<R!A;F0@3F5V:7,@*+ATITJHO;2UIFBZUJ3.I:>Z^[2U*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B
M4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$@*+ATQ5.FZ*C(*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S("BX=*3EM,NDSJ[FM^>HNJ1"*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G
M:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("*F4*1`K=.U^+6A("A?
M<V5L9BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82`HPL2\KZC(
MN'.N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I
M;F\@*+ATL*BG4;_5*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(*;7-G<W1R(")386\@5&]M92!A;F0@4')I;F-I<&4@*+ATIFBL_*3.M+:J
M3*;HI/$I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`BO<.L4+2CJ-&JS"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*
M;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")3875D:2!!<F%B:6$@**A&
MKU&F8:K\J=2G0BDB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`BP'BF<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92!<(B5S7"(B"FUS9W-T<B`BP'BF<R!<(B5S7"(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E("5S(@IM<V=S='(@(L!XIG,@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BP'BF<[_O
MMK4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3
M879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T
M;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S
M='(@(K%.LJ.ES:JZLUVI=\#)I4@@4$A0(+MYJ*6NYJ:AP'BF<ZCLIT&JNJ;X
MJD&^N;S(IG.EV+_]I*0N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`BLUVI=R`E<R"D=\!XIG,N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BI_.W<[5[
MIJ&D=\!XIG.H[#H@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B
M"FUS9W-T<B`BN7.L4+EPJT(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`BK.R^QR(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`BMVJT32(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%
M;F=I;F5S(@IM<V=S='(@(K=JM$VDWL"Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y-C(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("*_[[[<P,FN
MUR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.#(*
M;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BO^^^W*1`K=.DZ;3!(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C
M="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("*_[[[<I$"MT[ASLM6ESJ5(MW.\
M5R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E
M;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("*_[[[<I$"F[+=SJKJ^UJ:SJLPB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R("*_[[[<I$"SH:;XJD&^N2(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U
M<V5R('1O(&%D9"(*;7-G<W1R("*_[[[<I$"F[*C/I<ZJS*7.I4BW<[Q7(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W,PIM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R("*_[[[<J=*FLR(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-C4P"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RXB"FUS9W-T<B`BO^^^W*G2IK.DZ;3!I+BE\RXB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<P"FUS9VED(")396QE8W0@
M86X@;V)J96-T(@IM<V=S='(@(K_OOMRD0*W3JJNE\R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S0*;7-G:60@(E-E;&5C="!N
M;VYE(@IM<V=S='(@(J2CO^^^W"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(JGS
MI4BD5:JZM?BUH:2DO^^H^J=!K6ZJNJ9RI+@NI4BWQKFKO<:[<ZG2O^^DY:9R
M++5-J^&V2Z17I.6E\[USO^BPSRXB"@HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS
M9W-T<B`BO^^^W*3IM,&DP+EJ.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R
M("*_[[[<I.FTP:3IM,&NYJ:A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("*_[[[<L?W%W*?SJKJHK:7W
MP]&G3SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B
M4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`BO^^^W*[)MJ&D
MP+EJ.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("*_[[[<I.FTP:[)MJ&N
MYJ:A.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@
M(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("*_[[[<K-ND
MK*3'L'2JNJ1'K=/$YJ;L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B
MO^^^W*=!JKK#0Z;BL'2X;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS
M9W-T<B`BO^^^W+"^IFZ[>:BE.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(K;'L&6PW<-$I,_`LR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("*VQ[!E
MPK*P5"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"`HMNND
MNJ5;NK@I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E
M;G-O<CH@(@IM<V=S='(@(K=0M/J^N3H@(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("*D1:3K
M(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B
M4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I82!A;F0@36]N
M=&5N96=R;R`HMNNZN+K[J,B[4+M8KU.EIZWTP[DI(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`BI\>XN2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(J;XJD&^N;CJKL:_^;M^J<ZJS+5,JFNHSZ7.+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("*W?+3!NMZR>B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(K=\M,$@240@I'>Y3+3!+B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B
M4V5S<VEO;G,B"FUS9W-T<B`BMWRTP2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S$X"FUS9VED(")3970B"FUS9W-T<B`BKM:H^J3HMO0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L
M;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O
M<F=E="!I="XB"FUS9W-T<B`BI+FS7*=!J?.GT;!/L4N]6*JZKLFMU"RE::5(
MIMNFYJVKLUVQ2[U8+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("*S7:EWN[>ZW:;X
MJD&^N:17Q-VI\Z=!JKJMTZ1(K[BE>"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@
M=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`BLUVI=Z=!JKJP
MOJ9NNWFHI2P@KLFPSZ5(I,ZDZ;3!KN:FH2XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`BLUVI=Z=!JKJQTJEL
MP+.ESK5[IJ$LPT.FXK!TN&TLK;:ML:?SMW/`5[)V+*3.J.2E3,7CI=R_[[:U
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P
M(@IM<V=S='(@(K-=J7<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD
M97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L92(*;7-G<W1R("*G\[=SM7NFH;1.NOPB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("*FLZ9NM%BM
MTZ9APDFI3;-OK=.PT;S&IK/#]CH@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*
M;7-G<W1R(")397EC:&5L;&5S("BVZZGUNK@I(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`BP<JJ
MJR(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED
M(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(L*RM76Z2ZUN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(JQ/IU^LL*1J
MLZ&E]ZJZLW.ULJEWN'&GUK&VI5ROX,'D/R(*"B,Z(&QI8B](;W)D92]097)M
M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(L7CI=PB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(L7CI=RW
M<[*CI<V[4*WLP'BF<[-=J7?`R:JZKG2RIRXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(JA#IKBU;J1*J^'%XZ7<I%>D0*:XJKJU
M;J1*KLFVH2`_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*;7-G:60@
M(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#(*;7-G:60@(E-H;W<@<&EC:V5R(@IM
M<V=S='(@(L7CI=S"2;_OOKDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(L7CI=RJ[:[FOMZG0*5<K^"J[2`_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E
M<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("*I\Z6JP^3%XZ7<("5S(*5<
MK^"J[3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>.EW,!XIG.NYJ2ZKF6Y[[C<I.BV
M]"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`BQ>.EW*KMKN:DNJYEN>^XW*3HMO0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("+%XZ7<ID.DNJYEN>^XW*3HMO0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L7CI=R\
M=KFSI+JN9;GON-RDZ+;T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C<*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(L7CI=RD5[;'(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H
M;W=E<G,B"FUS9W-T<B`BJ_G$\K!]JT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*
M;7-G<W1R("*FK::SL'VK0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
ML=^FL[!]JT(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`BN[>DZ*:SL'VK0B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(J:LP5DB"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HW-S0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.#,V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDR,B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z,3`T-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#@W"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q,38@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R
M(")3:65R<F$@3&5O;F4@*+?@I&RD<[#J*2(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(K7YI54B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B4VEG
M;F%T=7)E(@IM<V=S='(@(L.QL[DB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R
M("+#L;.YNG2ZXB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG
M87!O<F4@*+=SI5NI62DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0Q
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H
M<#HR.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HS,3$R"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T
M"FUS9VED(")3:7IE(@IM<V=S='(@(J1JI'`B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN
M=&5N86YC92(*;7-G<W1R("*RI+E,NOO%0"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA
M(@IM<V=S='(@(E-L;W9A:VEA("BTM:REI>^G2BDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M96YI82(*;7-G<W1R(")3;&]V96YI82`HM+6LI:7OI:>HR"DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO
M=R(*;7-G<W1R("*SMR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("*P?;.W
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*
M;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("*P?;.W(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@
M4VAO=V5R<R!%87)L>2(*;7-G<W1R("*FK::SL'VSMR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R("*QWZ:SL'VSMR(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`BOVZS
MM[)@J]<Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V]L;VUO;B!)<VQA;F1S("BO
MP<.YJOFX<ZYQ*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI
M82`HK\&PJ*=1J,@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS
M9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(KIQNU"XUB(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR.3$U"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO
M;B(*;7-G<W1R("*QQJ9#I.BF5K_OOMPB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.#D*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("*HT[>]
MIF&G?2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3;W5T:"!!
M9G)I8V$@**MNJT0I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G
M:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("*K;KS:
M("A)4T\M.#@U.2TS*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE
M(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3
M;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(JMNI6*R>2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,3D*;7-G:60@(E-P
M86-E<B(*;7-G<W1R("*JQ:75IN8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS
M9W-T<B`BMJ&V6B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B
M"FUS9W-T<B`BMJ&V6KM0N=2E4B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")3
M<&%I;B`HINBO6J3Z*2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,#`*;7-G:60@(E-P86TB"FUS9W-T<B`BJ56GH[9LI?,B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN
M<'5T(@IM<V=S='(@(J]3KNVF<J2XO^FD2B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET
M(&-E;&PB"FUS9W-T<B`BI,"SSL!XIG,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C
M;VQU;6XB"FUS9W-T<B`BI,"SSL3FINPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R
M;W<B"FUS9W-T<B`BI,"SSJ9#(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`BN4*PRB(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I
M($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82`HM+6HO<3UI60I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(KS0M\<B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R
M("*L4+O:JJ?%4;[4(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3`@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(W.3@*;7-G:60@(E-T87)T('EE87(B"FUS9W-T
M<B`BL=*I;*9^I?<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W
M,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BK-DB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A
M='5S(@IM<V=S='(@(JJLND$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M-`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`BP'BF<Z[FIJ$B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T
M($%D9')E<W,B"FUS9W-T<B`BM?.Y1"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B
M"FUS9W-T<B`BIU*PH[UU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S<*
M;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(J9RINJF0R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R("*FV[9LI?.F8:=]I*2E:+"CNO2P[*97NMDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("*\RZ:A(%M#4U-=
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,@IM<V=I9"`B4W4B"FUS9W-T<B`BK%"TP:31(@H*(SH@=71I;"]I8V]N7V)R
M;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*GY*2CJ.RFN*78O_T@7"(E
M<UPB(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*
M;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BI42FKB(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(K!EI5@B"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G
M<W1R("*\5Z5;(%PB)7-<(B"H[*ATLLZJNJ73O="D=[!EI5@N(*=!I;*VM[6E
MJ.RXTZ73O="S4:[6K>.KX:1^K^"U;J1*+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*
M;7-G<W1R("*D5;S0(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-"!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G
M:60@(E-U8V-E<W,B"FUS9W-T<B`BIJBE7"(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`BIJBE7*JZI5ND2B!<(B5S
M7"(@J.RH=++.I*0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BIJBE7*JZIMNH
M=++.I*2R3;"CJ,^ESJK,(%PB)7-<(B"JNKCJKL8N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B7"(E<UPBI'>G4K"CI[FFJ"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BIJBE7*JZIMNH=++.
MI*2ROK"C(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("*D=Z:HI5RJNJ9>M%^S
M7:EW+B"]T*VKMW.X_*1*P,NU^*YTLJ<N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3
M=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(J1WIJBE7*JZL\:E][-=J7>XZJ[&+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("*D=Z:HI5RJNK/&I?>S7:EWN.JNQB`E<RXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(J:HI5RJNJ?SMW,@7"(E<UPB(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(J1WIJBE7*JZPM"\9R`E<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N
M(@IM<V=S='(@(E-U9&%N("C$K*2F*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`BNDNM;B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM
M<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`BI.FE6"(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("*DZ;BH(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G
M:60@(E-U;FYY(@IM<V=S='(@(K2X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R("*DZ:58(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("*DZ:58+Z3I
MN*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`BI.FE6#H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(J3I
MN*@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R("*DZ;BH.B`B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP
M="(*;7-G<W1R("*D5[S0(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("*DY+2I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;64@*,2LIU&K;BDB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G
M<W1R("*Z[[BY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*
M;7-G<W1R(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A
M>FEL86YD(@IM<V=S='(@(E-W87II;&%N9"`HI7:ER\#9Q/4I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4W=E9&5N(@IM<V=S='(@(E-W961E;B`HM^>HY2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I
M='IE<FQA;F0B"FUS9W-T<B`B4W=I='IE<FQA;F0@*+?GI&@I(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E
M;&5T960B"FUS9W-T<B`BIE"H0K!/O_VD=Z=2L*,B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`BIE"H0J;F
ML,JXR[AM(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G
M:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`BMVJT
M3;:UI=BDI*JZNWFJ:[_YNWXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U
M8FQI8R(*;7-G<W1R(")3>7)I86X@07)A8B!297!U8FQI8R`HL=2G4:C(*2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(KEPJT(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`BN7"K0J:SK;<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T
M<B`BN7"K0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("*FK::SJ_G$
M\KEPJT(B"@HC.B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B
M5%-6(&9I;&4B"FUS9W-T<B`B5$%"(*3`N6JNYJ:AP,FNUR(*"B,Z(&QI8B](
M;W)D92]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R("*J
M[;/F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("*J
M[:[FI+JN92(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")486)L92!3970B"FUS9W-T<B`BJNVSYB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`BJNVNYJ2Z
MKF4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(J5XQE<B
M"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")4
M86EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(J5XQE<B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")486II:VES=&%N(@IM<V=S='(@(E1A:FEK:7-T86X@*+;PIDZTM:E:
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HJ5JI?*6GJ,@I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("*EV+S0.B(*"B,Z(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X
M.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`BJ]V_[*C&MK4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E
M<B(*;7-G<W1R("*Y<;C<N+F]6"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDP"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("*SS*KQ
MI$"D<*[)JKJWQ:O7.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM
M<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`BM\6KUR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B
M"FUS9W-T<B`BM\6KUSH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O
M/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(K?%J]<\8G(@+SXH
M)7.PJB5S+R5SIT,E<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D92]496UP;&%T
M92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(J?DI*.H[+S+JD\@7"(E<UPB+B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("*\RZI/NMZR>B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H<#HS,S(U"FUS9VED(")4
M97AT(@IM<V=S='(@(J2ZKF4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BK\*DY:9R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM
M<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("*Y[[OTI.6F<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E
M>'1T;W`B"FUS9W-T<B`BN>^[]*3EIG*SN[K=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`BK%"TP:5\(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@
M(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(J[UI.4@*%1)4RTV,C`I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0@**[UL.HI(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C@T,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1E10(*FUIODH97AT96YS:6]N
M*;5,KL0N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8B"^XZ98I'6U>ZC#I;RDY+2I(%PB)7-<(B(*"B,Z(&QI8B].970O24U34"]"
M;V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R("))35-0(*SVO_VU3*IKLU&J[*EL+B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA
M:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*
M;7-G<W1R(")-86EN=&5N86YC92##_J=/J,.EO*:HI5RX_*1*(@H*(SH@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P
M=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(K_O
MMK6U^+6AI4C#]K.L+L+WMGVDI"XB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C$X.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,R!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(U,@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,P,PIM
M<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("*G0:JZJ'2RSKK>LGJM
M^Z6RMK>E_;-=J7>F;J1`K=/%=JVMJ^&ZW:1^K^#%_:=!J,^ESL5VK:VH=++.
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@
M(JFSKMB]=2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B
M"B)D871A8F%S92XB"FUS9W-T<B`BP7"UN+BYO5BEO*O\J7<LJL6EU:G.IF*X
MZJ[&KG>DI*?DI*.H["XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("*D=Z:HI5RJ
MNK%.P7"UN*1(MW.\5Z;<LW&P5+_]I*0N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N
M871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@
M;65S<V%G92XB"FUS9W-T<B`BQ>?#TK9LI?/#L;.YN]VM;J:SI$"MTZ1WN-&V
M?:JZ(%!'4""PS[;T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`BL'2X;;ASLM6JNL/1
MIT^XN;U8*$E$*:2CK$^EO*O\J7<LM$ZL3ZK%I=6ISJK,I*.F8KCJKL:N=Z2D
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G
M:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB
M"FUS9W-T<B`BL'2X;;ASLM6EO*O\J7<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(KO=K6ZD0*W3
MN&>Y3*5;L4NJNKKTN/2S<[6R+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI
M8B](;W)D92YP:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`BP,FN
MUR`E<R#`L[C3I5VG=*1`K=,@)7,@LUVI=RXB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$W,"!L:6(O2&]R9&4N<&AP.C4P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*
M;7-G<W1R("+`R:[7("5S(,"SN-.E7:=TI$"HQR`E<R"S7:EW+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C(S"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("*U3*IKO<:[<ZCLIMNHK<#)
MKM<N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(J:YP,FNUZ2DJ%.FL[CJ
MKL8N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES
M(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(J5(I%6L3R!R9F,X
M,C(@MFRE\ZJZJNW`62XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B
M"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES
M=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L
M;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E
M9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(JBMI??#T:=/("5S
M(*1WLU&G4K"C+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(J6JKMB]=2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M(@IM<V=S='(@(D=N=5!'(*1'I+C`R:JZN/2N?*6RMK>I=[AQIF(@0W)Y<'1?
M<&=P.CH@P_ZG3Z2D+B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y
M960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HBIT&T
MOZGS("5S(+%(M;D@)7,@I$"KRJ5$IJZLL"!<(B5S7"(@JKJK2*7SI'>S4;9]
ML=(N7&XB"B*F_;-OJ,.DHZ_@JT_#TKC3JTBE\ZJZI+JN9:1WI[FE_K-1IJRE
M\Z1(K-VGN:G.I$:XT2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@X,0IM
M<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M
M<&]S92!P86=E(@IM<V=S='(@(K-SM;*H[+USO&>V;*7SK;:ML:G2J,^ESJJZ
MIE>ZV2(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(J6RMK>L
M3Z1`K=.\QJ9R+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(S
M,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T
M:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?
M0W)Y<'1?<VUI;64Z.B##_J=/+*6RN]VM;J:S(&]P96YS<VP@O-*RU2XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D
M(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL
M;W=A8FQE('-I>F4B"FUS9W-T<B`BIKFPOJ9N(%PB)7-<(B"XZJ[&IEVLL+97
MN4RSS*1JI+FS7*W(+*G2I4BU3*IKLU'`>*9S(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N
M<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E
M<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y
M<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@
M(J7.I4C`R[7XIKFXZJ[&P_ZKK"`H)7,I(*JZM7NFH:C#I*.F<Z9BJ?.H=++.
MI%<N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`BI-ZM>J9RI;*VMZRPL^:D0*9RI+@N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE
M(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`BI:JE:Z[8O74B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`BI6NNV+UU(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-SD*;7-G:60@(E1H
M92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`BQ.:F[*3`N6JF<J6RMK>LL+/FI$"F<J2X+B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(J:Y
MIOBJ0;ZY(%PB)7-<(B"D=[-1IU*PHRXB"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`BIKFF^*I!OKD@7"(E
M<UPB(*1WLU'`>*9S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B
M965N(')E;6]V960N(@IM<V=S='(@(B5S(*JZM?FE5;O=J$2D=[-1LKZPHRXB
M"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("*K_*EW
MJKJP3[_]J,.DHZ9SIF(N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O
M97,@;F]T(&5X:7-T+B(*;7-G<W1R("*\R*9SP,FNUUPB)7-<(J2CIG.F8BXB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,`IM<V=I9"`B5&AE('1E>'0@
M>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R
M965N+B(*;7-G<W1R("*G0:G2O^FD2JJZN.JNQKM0M66ML;CJKL:DH[+%+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM
M<V=S='(@(J17I%6NV+UU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N
M;'DB"FUS9W-T<B`BI%>NV+UU(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C,R
M-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N(@IM<V=S='(@(K%QI%>D0*W3J$+&2J2GJ^&D5[;'
MJKJXZJ[&O_*EHBXB"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(V,B!L
M:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("*D5[;'P,FNUZC#
MI;RS4<!XIG,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")W
M96%T:&5R+F-O;2"PS[;TM4RJ:ZC/I<XN(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BI^2DHZCLO,NFH;!TN&VE
MV+_](%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM
M<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R
M("*U3*5II<ZJNK_OMK4N(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(K5,JOZE\Z5IJKVQM;9]L=(N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(J:YQ.:F[*2D
MI5VG=*33IFBJNJ9RO,8NIT&D=[_II$H@)7,@K=.F<KS&.Z=!O^FD2JJZIG*\
MQJ6RMK>D<*GS("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP
M:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(K=S
MO%<@7"(E<UPB(*CLJ'2RSCH@)7,@KLFU;Z7-I$"MT[#=PT0N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BIMNH=++.LDVPHR!<(B5S7"(@JKJX
MZJ[&KLFU;Z7-I$"MT[#=PT0Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(J;;J'2RSK*^
ML*,@7"(E<UPB(*[)M6^ES:1`K=.PW<-$.B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`BI_.W<R!<(B5S7"(Z("5S
M(*[)M6^ES:1`K=.PW<-$(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(J17ML?`R:[7KLFU;Z7-I$"MT[#=PT0Z("5S(*6\LU&D5[;'+B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`BI%>VQ\#)KM>NR;5OI<VD
M0*W3L-W#1#H@)7,@I&JD<+97N4RDN;-<L\RD:JW(("@E9"!B>71E<RDN(@H*
M(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G
M<W1R("*D5[;'P,FNUZ[)M6^ES:1`K=.PW<-$.B"VR+.AI,"JNB`E<R#`R:[7
MLU&D5[;'+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R("+`R[7XMFRE\Z[)M6^ES:1`K=._^;M^
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G
M<W1R("*VUZ1*IKFS<;!4O_VXZJ[&KLFU;Z7-O_F[?BXB"@HC.B!L:6(O2&]R
M9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`BMM>D2B!I
M0V%L96YD87(@N.JNQJ[)M6^ES:1`K=._^;M^+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z.#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I
M;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U
M="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("*F8K-=J7>J[;/FI*2U
M;Z7-I$:D0*W3O_F[?BZFLZ5IK^"G0;_RNGRD1J6RMK>V\;QGJKK$YJ;L+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("*P]:;FLW&P5+_]J_RI=Z5<K^"NR;5OI<VD0*W3
MO_F[?BX@O="U>:OAID&XU:1`IK@N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(J?SMW/!<+6XI$BXZJ[&KLFU;Z7-I$:D0*W3
MO_F[?BX@O="U>:OAID&XU2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(J?SMW.P=+AMN'.RU:[)M6^ES:1&I$"MT[_YNWXN(+W0M7FKX:9!N-4N(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B
M5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L
M9&5R<RXB"FUS9W-T<B`BIKD@24U!4""F^*I!OKFHPZ6\I.2TJ:M(I?.G6*3`
MJ,FE7*_@+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C0X
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+B(*;7-G<W1R("*S;Z;\I4>DHZQ/I;^]5*JZ(')A<B#`H\%9
MP,FNURXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU,@IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`BLV^F_*5'I*.L3Z6_O52JNB!Z:7`@P*/!6<#)KM<N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,S0*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M("*S;Z;\I4>DHZQ/I;^]5*JZJTBESJ5DN+F]6"XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E
M;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.3@R(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-#`R(&QI8B](;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#0S(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#$R(&QI8B](;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-C0T(&QI8B](;W)D92]&;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3(V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,CDU(&QI8B](
M;W)D92]&;W)M+G!H<#HS.#`S(&QI8B](;W)D92]&;W)M+G!H<#HS.#$Q"FUS
M9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("*FN<3FINRL
M3Z6RN]VM;JJZ+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Y"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S
M='(@(J:YQ.:F[*2ZKF6E=:2YLUR^X[S&O,:F<BXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C0R,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`BIKG$YJ;LI+JN
M9:5UI+FS7+S&IG*DSJM?N+DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N(@IM<V=S='(@(J:YQ.:F[*2ZKF6E=:2YLURD2[9IINR\QJW(+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<R(*;7-G<W1R("*FN<3FINRDNJYEI;*VMZRPLW*XN:G.JL6EU:3`
MN6JJNKS&IG(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3DS"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(J6R
MMK>L3Z1`K=.\QJ9R+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#(U"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(J:YQ.:F[*2ZKF6ELK:WI5VG=*1`LM6D4:2[MFFF[*JZ
M(%)'0B##0Z;BI4Z]6"RHTJ9P("<C,3(S-&%F)RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z-38U"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E
M;B!P<F]C97-S960N(@IM<V=S='(@(K-OK=.J[;/FI'>S4;-"LGJY3"XB"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("*S;ZQ/("5S+B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@
M;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@
M=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A
M(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E
M<R(*;7-G<W1R("(B"B*S;ZQ/($MO;&%B(+ASLM6JNJ1`K=.JJZ7S+B"Q_<#+
MM?BFN:JKI?.[W:UNK^"DY+2I2V]L86(@N'.RU:[FIJ&JNKEQI&RV;*7SLVXB
M"B+%Z2Z]T+#1IM(@)7,@I4BD1KC1LV^HQ[9LI?.S;L7I(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`BLV^KRK9LI?.H
MPZM$I4BG0;I$I<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@KM&\9Z;3IJ@N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("*FN;S&K<BSS*36
MI;*VMZQ/(#$N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U
M"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RXB"FUS9W-T<B`BIKFF^*I!OKFU3*IKN>\@>FEP(*3.(&=Z
M:7`@KN:FH<#)KM>V::;FN-'`H\%9(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ.#(*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C
M=&EV871E9"XB"FUS9W-T<B`BIKFH=++.I=BK9:Q/L+&ESJJZJJRZ02XB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("*ELK:WK$^D0*W3O,:F<BXB
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W(@IM<V=S='(@(J:YM?BUH:6RMK>M;J71O^^VM;7XM:$H3W!T:6]N
M*:G2J4FE<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(KEP(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R
M("*PW<-$L&S"W"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#(Y('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R
M("*NR;:A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM<V=I
M9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("*NR;:AJ_RK;B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
MKLFVH:[FIJ$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S-0IM<V=I9"`B
M5&EM92!S96QE8W1I;VXB"FUS9W-T<B`BKLFPS[_OOMPB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,97-T92(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("*\T,-$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R("*\T,-$("AT;V]L=&EP*3HB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B
M"FUS9W-T<B`BIJRE\Z1((@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8U,0IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET
M96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-
M86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HBIG"J1ZUN
MO<:_[RR]T*9BPDF_[[?&N:NJNJ90KLFK]B!#;VYT<F]LP>0HK=.D2+EQN*,I
M(*G.($-O;6UA;F3!Y"C$JZI'N7&XHRDN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`BI+6DT2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*
M;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(*WLJ6S`
MR2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R`HIFBM]"DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M("*I^J31(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$@**I&I5LI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`BL[NSH2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F
M<F%M92`H7W1O<"DB"FUS9W-T<B`BL\RD5[QHKMBL6R`H7W1O<"DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS
M;&%T:6]N<R(*;7-G<W1R("+%W*3&(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD
M(%1O8F%G;R(*;7-G<W1R("*D9*B]N4:DSJ:KJ*FM]"(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@
M(J]UJ<ZPL"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(JQ0M,&D1R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U;FES:6$B"FUS9W-T<B`B5'5N:7-I82`HK/"EIZ;HJ,@I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5R:V5Y(@IM<V=S='(@(E1U<FME>2`HI&>FU:CD*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R("*D9Z;5J.2DY2`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B
M5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A
M;'4@**1GI<N^?"DB"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@
M(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("*_Z:1*IT&JNK_OOMPZ("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N
M5BX@:6YD97@Z("(*;7-G<W1R("*UM:5^O76K_+S&.B`B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(KKTIWTB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM
M<V=I9"`B55),.B(*;7-G<W1R("*Z]*=].B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*
M;7-G<W1R(")59V%N9&$@**]1I'JY1BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM
M<V=S='(@(E5K<F%I;F4@**]1ITK$]2DB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C0Q-@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R("*U3*IKIG.H^B!61E,@I=B__2XB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S
M97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("*U^:55
MKLFU3*IKO%>E6\-"I7ZJNJC/I<ZJS+CJL%0N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ
M:Z?OQ=P@5D93(,#)KM<@7"(E<UPB(*JZQ7:MK2XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,X.2!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`BM4RJ:\7<I_,@5D93(,#)KM<@)7,O)7,@
MJKK%=JVM+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`BM4RJ
M:\7<I_.LL"`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<UPB+B(*;7-G<W1R("*U3*IKP,NL9,#)KM>D:J1P(%PB)7-<(BXB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C8Y,B!L:6(O5D93+W-Q;"YP:'`Z,3`Q.2!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@
M(K5,JFO`RZQDP,FNUZ1JI'`@7"(E<R\E<UPB+B(*"B,Z(&QI8B](;W)D92]!
M=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R("*U3*IKLW.ULB!344P@IOBJ0;ZY+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HX-3D*;7-G:60@(E5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+B(*;7-G<W1R("*U3*IKJ,^ESB!34TP@LW.ULBXB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C(R.2!L:6(O5D93+V9I;&4N<&AP.C(S-"!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR,#0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O
M(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(K5,JFN]QKMS(%9&4R#`R:[7+B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`BM4RJ:ZO8I=\@5D93(*78O_T@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,S4X(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`BM4RJ:ZO8I=\@5D93(*78O_TN(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R("*U3*IKJ]BEWR!61E,@P,FNURXB"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(K5,JFNKV*7?(%9&
M4R"EV+_](%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(V.0IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B
MM4RJ:ZO8I=^JQ:75JKH@5D93(,#)KM<N(@H*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("*U
M3*IKL4ZXZJ[&N-'`H\%9+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,C@@;&EB
M+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M(@IM<V=S='(@(K5,JFNG4K"C(%PB)7-<(BRFN:78O_VHPZM$JL6EU2XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(Z("5S+B(*;7-G<W1R("*U3*IKIU*PHR!<(B5S7"(Z("5S(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HS,S4@;&EB+U9&4R]S<6PN<&AP.C,Y-2!L:6(O5D93
M+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(K5,JFNG4K"C("5S+*:Y
MI=B__:C#JT2JQ:75(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("*U3*IKN[RP
M:J=2L*.EV+_]+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S0Q(&QI8B]61E,O
M;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("*U
M3*IKIU*PHR!61E,@I=B__2XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI
M8B]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BM4RJ:Z=2
ML*,@5D93(*78O_TZ("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR,3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(K5,JFNG4K"C(%9&4R#`R:[7(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C,P-R!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI
M8B]61E,O;75S<6PN<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y
M,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(K5,JFNG4K"C(%9&4R#`R:[7
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`BM4RJ:Z=2L*,@5D93(*78O_T@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<W%L
M+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("*U3*IKN[RP:J=2L*,@
M5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#(S"FUS9VED(")5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("*U
M3*IKIU#"7Z78JV6JNJ78O_TN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV,#0*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E
M(&1E=&%I;',B"FUS9W-T<B`BM4RJ:[C1MGV^S,/2LM.X8"(*"B,Z(&QI8B].
M970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I
M;VX@;V8@)7,N(@IM<V=S='(@(K5,JFNX_*1*)7.JNJEWN'$N(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HR,#`@;&EB+U9&4R]F:6QE+G!H<#HR,#4@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W
M.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(K5,
MJFNW:+*^(%9&4R#`R:[7+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O
M5D93+W-M8BYP:'`Z,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&
M4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BM4RJ:[9]L=(@5D93(,#)
MKM<@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@Q(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G
M<W1R("*U3*IKO&>D2B!61E,@P,FNURXB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,T(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B
MM4RJ:[9]L=(@5D93(,#)KM<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`BM4RJ:[9]L=+`H\%9P,DN(@H*(SH@;&EB+U9&
M4RYP:'`Z.#4U"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL
M97-I>F4H*2!F86EL960I+B(*;7-G<W1R("*U3*IKQ:JH^B!61E,@P,FNUR`H
M9FEL97-I>F4H*2!F86EL960I+B(*"B,Z(&QI8B]61E,N<&AP.C@X-@IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`BM4RJ:\6JJ/H@5D93(,#)KM<@*&=E=$9I;&53:7IE
M*"D@9F%I;&5D*2XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N
M92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R
M("*U3*IKQ:JH^L#)KM<Z("(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C<S"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM
M<V=S='(@(K5,JFO%JJCZ('9F<W)O;W0@I=B__2XB"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(K5,JFNG\Z97("5S(*RP("5S.B"F7:RPI=B\T*M(
MI?.G6*1WIG.F8B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("*U
M3*IKQ=RG\R!61E,@I=B__:JZIE>ZV2XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(K5,JFNROK"C(%9&4R"EV+_].B`E
M<RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C<Q(&QI8B]61E,O9G1P+G!H<#HS
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(K5,JFO%W*?S(%9&4R#`R:[7(%PB)7-<
M(B"JNJ97NMDN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV,30@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(K5,JFO%W*?S(%9&4R#`
MR:[7("5S+R5S(*JZIE>ZV2XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S(V(&QI
M8B]61E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HT-3(*(SH@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`BM4RJ:\7<I_,@5D93(,#)KM>JNJ97NMDN(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+B(*;7-G<W1R("*U3*IKL/6FYB`G;6MI<V]F<R<N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L
M92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(K5,
MJFO"X+2K(%=O<F0@I.6E\R(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@;&EB
M+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*U3*IKO&>D2B!6
M1E,@7"(E<UPB(,#)KM<N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ.#,*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M(@IM<V=S='(@(K5,JFN\9Z1*(%9&4R#`R:[7("AC;W!Y*"D@9F%I;&5D*2XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X-2!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`BM4RJ:[QGI$H@5D93
M(,#)KM>XZJ[&+B(*"B,Z(&QI8B]61E,N<&AP.C@V,0IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*
M;7-G<W1R("*U3*IKO&>D2B!61E,@P,FNURP@NL^ZT+!TPT*D=[JA+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G
M:60@(E5N9&5R;&EN92(*;7-G<W1R("*IL[UU(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(JCZ
MKOBG\Z?O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`BM%^M["(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B`B"FUS9W-T<B`BIOBJ0;ZYLW.ULJ[)M6^ES:6\N7>TP:JZIE[`LSH@(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-S@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!T;SH@(@IM<V=S='(@(K5OI<VEO+EWM,&JNJ9>P+,LI=&F^*I!OKDZ
M("(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(J6\I,##_B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T
M<B`BN%6PZKU8("A55$8M."DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B56YI=&5D($%R86(@16UI<F%T97,@**K\J=2G0L%PIEBD
M:J2]L.HI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R(")5;FET
M960@2VEN9V1O;2`HK5ZPZBDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(E5N:71E9"!3=&%T97,@**S\L.HI(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP.C<Q
M"FUS9VED(")5;FET<R(*;7-G<W1R("*SYJ;L(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0S,`HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK
M;F]W;B(*;7-G<W1R("*EO*J^JKHB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+B(*;7-G<W1R("*EO*J^JKH@05!)(+!4KJ>]<[BY("A!
M4$D@365S<V%G92!)1"DN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2XB"FUS9W-T<B`BI;RJOJJZJ\BDX;!4KJ>]<[BY("A!4$D@
M365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T
M<B`BI;RJOJJZINRX;;CJL%0N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S
M<W=O<F0N(@IM<V=S='(@(J6\JKZJNJC/I<ZJS*97NMFISK%+O5@N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M("*DI,)?I=BK9:2XI?.JNK-SM;(B"@HC.B!L:6(O2&]R9&4O261E;G1I='DN
M<&AP.C,P,0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("*EO*E2IE<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(J9=
MIG>E_L55O'NDHZ2YLUREO+'"Q7:JNK5[IJ&P]:;FL,6D52^]QKMS+[9+I%<N
M(,))O^^]5*EWI4C`R[7X(&UO>FEL;&$N;W)G(*G2(@HBM*.HT:JZK-O#]J?>
MLTZDY:7S+,7]IT&E::5(N-&PHZ:YI$"MK:CNJ,.FVZ;FMGVI\;5[IJ&F<ZCZ
ML,6V2\.O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(JCZ
MKOC#0Z;B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*
M;7-G<W1R("*EO*3DM*FJNK#&P,FF5R(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS
M9VED(")5<&1A=&4B"FUS9W-T<B`BQ=RG\R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D
M871E("5S(@IM<V=S='(@(J?SMW,@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M("*G\[=SJ,^ESJK,(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(J1WI_.W<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B
MI_.W<[5[IJ&D=Z=2L*,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED
M(")5<&QO860B"FUS9W-T<B`BI%>VQR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U
M<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("*D=Z17ML>ITJ:SP+.E
MSK5[IJ&JNK-=J7?`R:CLIOBJ0;ZY+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BI&J\9ZG4I$*\QJ9R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("*D:KQGP[FP
MJ+S&IG(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87D@**]1
MJ=2F8RDB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS
M9W-T<B`BJ,^ESJ78JV6JNCH@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(JC/I<X@
M4U-,(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BXB"FUS9W-T<B`BIG"J1Z=!JKJHSZ7.JLRF5[K9+[%+O5B[4"!)35-0(*;X
MJD&^N:2CIE`LI6FF8J:YLUVI=RXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(JC/I<ZJS"(*
M"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S$V"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G
M<W1R("*HSZ7.JLP@)7,@I;RS<;E,("5S(*JZL<+%=L7GP](N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(JC/I<ZJS+K>LGHB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(JC/I<ZJS+_OMK4B
M"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*
M;7-G<W1R("*HSZ7.JLRU^:55(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`BIKFON*5XJKJHSZ7.JLRU^:55J'2RSJ1WL+&ESBXB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(J?DI*.H[*C/I<ZJS+%BN+DB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8@;&EB+TYE
M="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@
M(JC/I<ZJS*97NMDB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(JC/I<ZJS*97NMD@7"(E<UPB(*1WIG.F8BXB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S
M97)N86UE.B(*;7-G<W1R("*HSZ7.JLRF5[K9.B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B
MJ,^ESJK,.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("*H=++.I*2J
MNJC/I<ZJS#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z8F5K
M:7-T86X@**]1K_>G3Z=**2(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,38W(&QI
M8B]61E,O9FEL92YP:'`Z,C4Y"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R(")61E,@I=B__:C#I*.F<Z9B+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(K"RM,$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(J1W
MI^2H[*:SKL2JNJ9APDDZ("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R("*FLZ[$J<HB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+B(*;7-G<W1R("*E2*3`Q,&LL+/FINPHL7&R>Z9BL%^Z
MXBDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@
M=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(T."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(W,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDQ-R!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I
M9"`B5F%L=65S(@IM<V=S='(@(JW((@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3`*;7-G:60@(E9A;'5E<R!T
M;R!S96QE8W0@9G)O;2(*;7-G<W1R("*_[ZCZK<BFVR(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A
M;G5A='4B"FUS9W-T<B`B5F%N=6%T=2`HI<NEHZK\N<\I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS
M9W-T<B`BQ=RDQB(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE
M>G5E;&$@**EEI+JWYZG4*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S
M86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`BQ>?#
MTJ6BL=$@+2"FN;9LI?.E::_@I'>^1*1(OM6FV[]YI^\N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T
M<B`BJJFENR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("*JJ:6[L;&H[B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*
M;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(JNKJKVY[[OT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I
M9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("*KJZJ]N=2E4B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@
M(E9E<G1I8V%L.B(*;7-G<W1R("*KJZJ].B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS
M9W-T<B`BJT2Q8+"J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE
M="!.86T@*+96JVXI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`BME:K;J3E("A625-#
M24DI(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDV.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(L#+M?@@)7,B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E(@IM<V=S='(@(J9BMW.U^+6AMGVQTB(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R!A<R`E<R(*;7-G<W1R("*E2"`E<R#`R[7X(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B5FER9VEN($ES;&%N
M9',L($)R:71I<V@@**U>Q-VZ^ZC*N'.N<2DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@52Y3+B(*;7-G<W1R(")6:7)G:6X@27-L86YD<RP@52Y3+B`H
MK/S$W;K[J,JX<ZYQ*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS
M9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(J_@J*.KUR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI='DZ("(*
M;7-G<W1R("*OX*BCJ]<Z("(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510
M(@IM<V=S='(@(KAQI&JG4:7QO'>MM[EQJTBDO:5QLWJY3"!33510(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(L2UIVDB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`BQ+6G
M:2$A(2"Q<2`E<R"DXK#*LKZPH[5[IJ$N(@H*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)
M3B"X9Z71($A45%`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G
M<W1R(")786QL:7,@86YD($9U='5N82(*"B,Z(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(T(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX
M,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+$M:=I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS
M9W-T<B`BK%"TP:14(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(J31KO"Y=[3Z
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(J[PMDBXZJ[&M*.H
MT2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.38*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(G=E871H97(N8V]M(+KTK[@B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(KKTK[@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*
M;7-G<W1R("*Z]*^X(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU
M.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(JA#MF<B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R("+%
M=ZKO(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64@=&\@)7,B"FUS9W-T<B`BQ7>J[ZCL("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@
M(L5WJN\L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(J;HO-H@*$E33RTX.#4Y
M+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("*FZ+S:("A)4T\M.#@U.2TQ-2DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B5V5S=&5R;B!386AA
M<F$@**;HO+NKHJG4*2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`BM6ZD2JOAP+.XTZ7]
MQ>.EW"`E<R"M_J1`K=/`LZ7.M7NFH3\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\B"FUS9W-T<B`BQ.:F[*JZI,"Y:J9RI+@_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U
M;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`BI-ZM>JJZJV6X;:9RI+@_(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@
M(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES($%U<W1R
M86QI82"F8;G/(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7
M:&EC:"!P:&%S97,B"FUS9W-T<B`BK?ZMTZ3KK-LB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L
M92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(KKTK;:]<[_H
MOKFJNK2AI?,H<&QU9VEN<RFQTK#*L;&H[BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T
M:"(*;7-G<W1R("*\9:O7(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,30*
M;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("*E2"!#4U,@K+"S
MYJ;LJKJ\9:O7(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@
M;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B
MI:K#Y"5SI5ROX*KMJKJ\9:O7**15IKBU;J1*J6RES:[$*3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B
M5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(JKMKN:\9:O7(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@
M(E=I9'1H('5N:70B"FUS9W-T<B`BO&6KU[/FINPB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(KQEJ]<Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R("*VL,7IL]"G0"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`BK;<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM
M<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R("*FK::SK;<B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM
M<V=S='(@(JVWLW0HN&`I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*
M;7-G:60@(E=I;F0Z(@IM<V=S='(@(JVWLW0Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(JVW
MLW0Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES
M9&]M(@IM<V=S='(@(K2\O'HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("*TP:O=PJ>JJR(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R
M("*D=:=`(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@
M(E=O<FL@061D<F5S<R(*;7-G<W1R("*_[*2]J\>F8:=](@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`BO^RDO:O'N7&XW"(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z
M,3DS(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R("*RQ"5DIN:JNL3FINR\QJ78I*.EO[U4
M+B#`L[C3K6ZFLR5DK=/$YJ;L+*5UI^2H["5DK=/$YJ;L+B(*"B,Z(&QI8B]&
M:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU
M;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T
M<B`BQ.:F[+S&I=BDHZ6_O50N(,"SN-.M;J:S)62MT\3FINPLI76GY*CL)62M
MT\3FINPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,3@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N(@IM<V=S='(@(K5,JFO%W*?S(%9&4R#`R:[7JKJF5[K9
M+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M
M4F5F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S(*FUIOFJ
M]\9?NWFJ:R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@
M(E@U,#EV,R"E1*:NM,"E3J97NMDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I
M97(B"FUS9W-T<B`B6#4P.78S(*5$IJZJ]\9?P]&G3ZK,(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I
M;VYS(@IM<V=S='(@(E@U,#EV,R"PQL#)IE<B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`BIGXB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3,*;7-G:60@(EE965DB"FUS9W-T<B`BIGXB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM
M<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R`A(*9AN<\B"@HC.B!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS
M9W-T<B`BJ$.F?B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(EEE;65N("BX
MK:KY*2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C,*;7-G:60@(EEE<R(*;7-G<W1R("*L3R(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R
M964B"FUS9W-T<B`BK$^JNBRGVJ90MTXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RXB"FUS9W-T<B`BIT&EV*MEJ,^ESJ_"I.6F<KUSO&>\TJ:A
M+B"HSZ7.(%L\/ET@J_:V<Z5II,&TJZRPNO2MMKUSO&>\TJ:A+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+B(*;7-G<W1R("*DHZ2YLURG0:O8I=\E9*5(I%>JNK#/MO0N(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-#$U"FUS9VED(")9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+B(*;7-G<W1R("*G0:6\LU&QPL5V+B(*"B,Z(&QI8B](;W)D
M92])9&5N=&ET>2YP:'`Z,S`W"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("*G
M0:JZI?ZF5Z2DI*.E:::S("=<7"<@LV^\RZJZIG*DN"X@(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-SD*;7-G
M:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB
M"FUS9W-T<B`BIT&HPZ6\O^FD2J1`K=.FLZ[$JKJY<:1LMFRE\Z;LIWTN(@H*
M(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R
M=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S
M+B(*;7-G<W1R("*G0:C#I;RET;;7I$JJNL#)KM>DI+GOK$VE]*;SQ.:F[*CL
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDX-`IM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("*G0:1WN&>U;J58+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY
M('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA
M;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HBO="_Z:1*I$"MTZ:SKL2J
MNKEQN-RXN;U8++#JN]JY<;C<N+F]6+;(I76DN;-<O,:F<KBYO5@LJ,.U^+&A
MJG"E::GSJV6ML:9!I5ND0"(*(JW3("<K)RXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V
M86QU92XB"FUS9W-T<B`BIT&ELK:WO^FD2J1`K=.FLZ[$JKJMR"XB"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*
M;7-G<W1R("*G0:6RMK>E_;-7N;JF;K[PJJRXZJ[&*$1A=&%4<F5E*:;XJD&Z
MW:1^K^#$?L3RJ,^ESK=SI<ZDX;7YI56J0;#(+B(*"B,Z(&QI8B](;W)D92YP
M:'`Z-#8R"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`BIT&ELK:WI?VS5[FZI$"MT[7JP,#`R:[7J'2RSBA61E,I
MIOBJ0;K=+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q
M"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@
M>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`BO="T
M>:UZL-W#1*%!IF*G0;;'L&6PW<-$L_BG::2GJV4N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM
M<V=S='(@(J=!I;*VM[_II$JFN;-SM;*ITJO\IE:JNKKTIWTB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R("*]T*O\J7>M
M;J=2L*.JNJ;XJD&^N2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM
M<V=S='(@(KW0J_RI=ZUNLDVPHZJZJ,^ESJK,+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92XB"FUS9W-T<B`BO="K_*EWK6ZROK"CJKJHSZ7.JLPN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N(@IM<V=S='(@(KW0J_RI=ZUNMW.\5ZJZJ,^ESJK,+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("*]T*O\J7>M;J?SMW.JNJC/
MI<ZJS"XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB
M"FUS9W-T<B`BO="K_*EWK6ZP]:;FJKJG0*7.+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T
M>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(J=!I;*VM[_II$JW
M<Z3`P_ZJNJ97NMDN(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L
M:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("*G0:6RMK>THZC1I$"MT[AQI&JG
M4;G2I+JJNKEQN-RXN;U8(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER
M960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`BIT&JNB`E<R"W?+3!
MI'>Y3*[)+KW0K:NW<[5NI$HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R
M("*G0:JZN7&D;+9LI?.F[:=](@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("*G0:JZ
ML4BE\Z1(N7&D;+9LI?.F[:=].B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S<@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,@IM<V=I9"`B
M66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("*G0:JZN.JP5"(*"B,Z(&QI8B](
M;W)D92]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B*F
MV[%QIT&JNB`E<R"W?+3!MGVI;*5(J-.G0:JZNO2[VKKTN/2F[*=]I'?%W*?S
M+B"LL*M/Q4"G0:JZIG>E_K!?J*.A0:=!I;*VMZVK(@HBMW.U;J1*+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R
M($YA;64B"FUS9W-T<B`BIT&JNJ97NMDB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y
M;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C
M8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC
M871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HBIT&JNL7GP]*F^*I!NMVHPZ2C
MI.2TJ;=SO%>HSZ7.JLPN(*9PJD>G0:?&L>:ZWK)ZJ,^ESJK,L6*XN2RG0:6R
MMK>E=+_OJ.2E3*JZQ><B"B+#TJ;XJD&ZW2XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC
M871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L
M(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE
M(&]T:&5R(')E87-O;BXB"FUS9W-T<B`BIT&JNL7GP]*ZW:C#I;RDY+2IID.E
M6*C/I<ZJS*G.N-.E7*_@I'>S4</VLZPN(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(J;;L7&G0:JZ
M("5S(+=\M,&V?:ELI4BHTZ=!JKK"<\3]OKFF_*5'I'?%W*?S+B"LL*M/Q4"G
M0:JZIG>E_K!?J*.A0:=!I;*VMZVKMW,B"B*U;J1*+B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C4U"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(J=!JKK"<\3]OKFHPZ6\
MI.2TJ;-OK=.E7*_@+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT
M+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`BIT&JNL)SQ/V^N:C#I;RDY+2IID.F
M3+_OMK4NO="K]B!#5%),+T-O;6UA;F0@*R!0(*9#IDPN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB"FUS9W-T<B`BIT&EV*MEJ=*S7:EWJKJNR;#/.B(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HY.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(KO5I%6Y=[-=JKJHK:7WP]&G
M3Z1WQ=RG\RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(KO5I%6Y=[-=JKJH
MK:7WP]&G3SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED
M(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BIT&JNJ7^IE<Z(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.CDY-@IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP
M:7)E9"XB"FUS9W-T<B`BIT&JNK5NI$JD=ZCLM,$N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("*G0:9B("5S
M(*2DJKJW<[%+O5BL3SH@)7,B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("*G0:9B
MM6ZD2K3!MJ&JNK_OMK6D=[-1I_.W<RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A
M=&5D+B(*;7-G<W1R("*G0:JZO^^VM:1WI_.W<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="(*;7-G<W1R("*G0:JZL4N]6*1WK:NW<[-=J7<B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@
M;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(K%+
MO5BD=[-1K:NW<[-=J7<LMW.JNK%+O5BD=[-ZN4RY<:1LMFRE\[%(M6^]T*5(
MN-.Q2[U8M6ZD2BXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S,P"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("*G0:JZL4N]
M6*1WJ.RTP2XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*
M;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(J=!JKJ[M[K=
MIOBJ0;ZY.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-30@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(EEU9V]S;&%V:6$@**MNM+6IU*32*2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F4@*,+$
MI>PI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82`HJ7RD\:C(
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E("BHKZ3:
MJ\(I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G
M<W1R(");P?3"PZ3>K7I=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*
M;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6[#=PT2DSZQ-72(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EO%XZ7<I-ZM>B`M
M(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(EO%XZ7<I-ZM>B`M("5S(*;F72(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE
M("5S(&]F("5S72(*;7-G<W1R(");INRI\Z;F("5S(*9`("5S(*;F72(*"B,Z
M(&QI8B](;W)D92YP:'`Z,34T-2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`BNMZR>E]!(@H*
M(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(JE2I4^F
M0U]#(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS
M9W-T<B`BOO"JK+CJKL9?1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B
M"FUS9W-T<B`BIU*PHZ9#7T0B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@
M(E]'<F]U<',B"FUS9W-T<B`BN'.RU5]'(@H*(SH@;&EB+TAO<F1E+TUE;G4N
M<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BNZ&I^E]((@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S
M"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("*\=KFSI+JN
M95])+BXN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R("*U;J1*7TPB"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z
M,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("*U;J587TPB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*
M;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("*MUZ?OLW.ULE]-+BXN
M(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B
M"FUS9W-T<B`BO^^VM5]/(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ7:MK5]0(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BLKZPH[GOLW.ULE]2+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`BLUVI=U]3
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("*J[:[FI+JN95]4+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`BJ,^ESJK,7U4B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDR,`IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(K-QL%2__2(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`BLW&P5+_](@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3(*;7-G:60@(F-A;&5N9&%R(@IM<V=S
M='(@(J;FJ,:^Y"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S4X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")C86QM(@IM<V=S='(@(KESK\6MMR(*"B,Z(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M92(*;7-G<W1R("*U3*IKJ]BEW[_II5C`R:[7(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("*U3*IKMGVQTK_II$HB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z-3DY"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(JOVIKDB
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("*Q2Z5/ID.[>:IKO_F[
M?B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B
M8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("*S7:EWO_F[?B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@
M<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("*_\J6BK:NM;JJZJ'2RSL#)
MKM<B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@
M(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(KCJKL:NYJ:AO_F[?B(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@
M;F]T(&9O=6YD(@IM<V=S='(@(J?DI*.H[+!/O_TB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B
M9F%L;&EN9R(*;7-G<W1R("*U^Z3`(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.C@X,0IM<V=I9"`B9FEL92(*;7-G<W1R("+`R:[7(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("*Q<2`E<R`H)7,I(*GS
M("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S.0IM
M<V=I9"`B9W5S=&EN9R(*;7-G<W1R("*P?:VW(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.`IM<V=I9"`B:#HB"FUS9W-T<B`B
MKLDZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U
M-PIM<V=I9"`B:&@B"FUS9W-T<B`BKLDB"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S
M='(@(J6\JKZJNK9LI?.E1+[WIE>ZV2(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("*EWZ=9(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R("*JO;&UQ>.EW*GSI;NDY;#/(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U
M="]O=71P=70@97)R;W(B"FUS9W-T<B`BO^FD2B^_Z:58O_F[?B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`BI+JSH;-NQ>F_^;M^(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI
M;F5S72(*;7-G<W1R("*FYETB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES
M;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R
M(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM<V=I9"`B;6TB
M"FUS9W-T<B`BI,`B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(Y,2!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`BIE>Z
MV2(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(JE\I;RYZJ=`+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*
M;7-G<W1R("*I?*6\N>JG0"XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP
M-`IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("*SQJ?1O_TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED
M(")P97)C96YT(@IM<V=S='(@(J;*I,"D\2(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`BIG.H^KY$J=HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B
MN;.OP"(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(K-QJTBH\ZEW
MN[>ZW;_YNWXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(J17I,DB"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA
M=F%I;&%B;&4B"FUS9W-T<B`BM4RE::7.JKJJ0;#((@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G
M<W1R("+%XZ7<KG2RIR(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S
M;7,R96UA:6P@N&>ET2!(5%10(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-`IM<V=I9"`B<W,B"FUS9W-T<B`BK.TB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B
M<W1E861Y(@IM<V=S='(@(L.MJ7<B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("*H=++.
MO_F[?B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(X"FUS9VED(")T87-K
M(&QI<W0B"FUS9W-T<B`BJ]V_[,.O(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M("*\R*[)J<JJNJ6BL=$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("*F0::XO^FD2J=!JKJQ2[U8
MI4B]5+M[M4R[?B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(K[C
MIE@B"@HC.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN
M86UE9"(*;7-G<W1R("*EO*E2IE<B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("*HSZ7.JLR_[[[<
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0P"FUS9VED(")W.B(*;7-G<W1R("*L4+3!
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W
M96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2"Z]*^X(@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]H=5](52YP;P``````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W
M,3<R-S8@,3`U,34T,S0Q-#(@,#$W-30T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",@2&]R9&4@2'5N9V%R:6%N('1R86YS
M;&%T:6]N(&9I;&4N"B,@0V]P>7)I9VAT("A#*2`R,#`R+3(P,#8@3&%S>FQO
M($PN(%1O<FYO8VD*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@
M=&AE('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!,871E
M<W0@=F5R<VEO;G,Z(&9T<#HO+WAE;FEA+G-O=&4N:'4O<'5B+VQI;G5X+VAO
M<F1E+PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!(;W)D92`S+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ
M-R`Q,#HP,"LP,3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`R+3$W
M(#$P.C,X*S`Q,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&%S>FQO($PN(%1O
M<FYO8VD@/'1O<FQA<WI`>&5N:6$N<V]T92YH=3Y<;B(*(DQA;F=U86=E+51E
M86TZ($AU;F=A<FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/6ES;RTX.#4Y+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<S"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@
M;F%P<&%L(&5Z96SU='0I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S<T"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$%L
M="UB:6QL96YT>?L@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@
M*"5S(&YA<"!M^FQV82DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PIM
M<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AM82DB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AH
M;VQN87`I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@*'1E9VYA<"DB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM
M<V=I9"`B(&%T("(*;7-G<W1R("(@.B`B"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E
M8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!N96T@86QK]FYY=G3A<BXB"@HC.B!L
M:6(O2&]R9&4O0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&YE
M;2#I<G;I;GEE<R!VX6QA<WITX7,N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y
M+G!H<#HW,3`@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@
M2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!N:6YC<R!K;VYF:6=U
M<N%L=F$@82!(;W)D92!296=I<W1R>6)E;BXB"@HC.B!L:6(O2&]R9&4O5')E
M92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E
M;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB(&9A<W1R=6MT^G)A
M+6UE9VIE;&5N[73U(&YE;2!T86SA;&AA=/,N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(M="!H;WIZ
MX6%D='5K(&$@8W-O<&]R=&]K:&]Z+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(BUT(&AO>GKA861T=6L@82!J;V=O<W5L='/A9VD@<F5N9'-Z97)H97HN(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(BUT(&YE;2!H;WIT=6L@;.ET<F4Z
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(E+C)F34(@9F5L:&%S>F[A;'0@82`E+C)F34(@;65G
M96YG961E='1B]6P@*"4N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(E9"`E<R#I<R`E<R(*"B,Z(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(E9"!N87`@;?IL=F$@;&5JX7(@:F5L<WIA=N%N86L@
MZ7)VZ6YY97-SZ6=E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM
M<V=S='(@(B5D(&YA<&]S(&5L]7)E:F5L>NES(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T
M:6-E(@IM<V=S='(@(B5S("T@1FEG>65L;65Z=&5TZ7,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!L96YY;VUA="(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#$@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C@T,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!K87)B86YT87)TX7-I(&9E;&%D871O
M:R`M(&UE9V5R]7/M=.ES(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&)EX6QL[73A<R(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@;&]G:6X@;NEV(&EGZ6YY;.ES(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!S>F]L
M9^%L=&%TX7-I(&9E;'3I=&5L96LB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-#,R
M(&QI8B]61E,O<VUB+G!H<#HT.30@;&EB+U9&4R]F='`N<&AP.C8X,@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L
M<F5A9'D@97AI<W1S+B(*;7-G<W1R(")!(%PB)7-<(B!N97;[(.%L;&]MX6YY
M(&WA<B!LZ71E>FEK+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S
M='(@(B5S(#H@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B)!*'HI
M("5S(&OI<WIE;B#A;&P@87H@86SA8F)I(&MA<F)A;G1A<G3A<VD@9F5L861A
M=&]K(&5L=NEG>NESZ7)E+DIE;/9L:F4@:VD@(@HB87IO:V%T(&$@9F5L861A
M=&\H:V$I="P@86UI*&ME*70@;6]S="!E;"!K[7;A;B!VZ6=E>FYI+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,S0T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&MI=/9L=.ES92!S>OQK<^EG
M97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S('!E<F,B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;F5M('1A;.%L:&%T
M\RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S("T@
M)7,@*/9S<WIE<V5N("5S*2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(V
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S
M='(@(B5S(&/M;6IE9WEZZ6ME(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M("(E<R!N87!TX7)A(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S(&9E
M;&IE9WEZZ7-E:2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,@9F5L
M861A=&QI<W3A:F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H
M<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(B"B(E<SH@3&5H971SZ6=E<RP@:&]G>2!E>B!A(&QE=NEL
M('9A;/-JX6)A;B!N96T@82!M96=A9&]T="!F96QA9/-T\VP@(@HB<WKA<FUA
M>FEK+B!';VYD;VQJ82!M96<L(&UI96SU='0@<N%K871T:6YT('9A;&%M:7)E
M+"!V86=Y('-Z96WI;'EE<R`B"B)I;F9O<FWA8VGS="!A9"!M96<N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@
M(BP@<WKI;&SV:^ES96LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"`E<R`E<RUS('-ZZ6QL]FOI<V5K
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=N%L
M=&]Z\R`E<R#I<R`E<R!K]GKV='0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C`W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T."!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0X"FUS9VED("(M+2!S
M96QE8W0@+2TB"FUS9W-T<B`B+2T@=N%L87-S>F]N("TM(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R
M("(Q,B#S<N%S(&9O<FWA='5M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y
M"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"#S<N%S(&9O<FWA
M='5M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T
M(&AO=7)S(@IM<V=S='(@(C(T(/-R82(*"B,Z(&QI8B](;W)D92]522]086=E
M<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\16SU>O4B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")%
M>F5N(&)L;VMK(&AA<WINX6QA=.%H;WH@96=Y(&%D871BX7II<R!A;')E;F1S
M>F5R('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$V,@IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B2&5L>7)E:&]Z
M:&%T871L86X@:&EB82!T]G)TZ6YT(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")!(&QE=NEL('1I=&MO
M<^UTX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU;&-S('-Z_&MSZ6=E<RXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R("(B"B)!(&1I9VETX6QI<V%N(&%LX>UR="!L97;I
M;"!E;&QE;O5R>NESZ6AE>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<R!S>OQK
M<^EG97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(D$@=&ET:V]S[71O='0@;&5VZ6P@9&5K\V1O;.%S
MX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<RP@96=Y('1I=&MO<R!01U`@
M(@HB:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D$@
M;&5VZ6P@9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0
M(&MU;&-S+"!E9WD@=&ET:V]S(%!'4"!K=6QC<R`B"B+I<R!E9WD@:F5L;6]N
M9&%T('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB
M9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@=&ET:V]S[71O='0@
M;&5VZ6P@9&5K\V1O;.%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC
M<RP@96=Y('1I=&MO<R!3+R(*(DU)344@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A
M="!S>OQK<^EG97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT
M,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)!(&QE=NEL(&1I9VETX6QI<R!A
M;.'M<N%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<RP@96=Y('1I
M=&MO<R!3+TU)344@(@HB:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG
M97,N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B02!L97;I;"!T:71K;W/M=.%SX6AO>B!E9WD@
M;GEI;';A;F]S(%,O34E-12!K=6QC<R!S>OQK<^EG97,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO
M=61S(@IM<V=S='(@(D3I;&5L]71T(&)O<G5L="#I9R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H
M="!286EN(@IM<V=S='(@(D3I;&5L]71T(&=Y96YG92!E<_4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@
M4F%I;B(*;7-G<W1R(")$Z6QE;/5T="!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*
M;7-G<W1R(")$Z6QE;/5T=&D@>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B1.EL96SU='0@:/-ZX7!O<F]K(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(F1E+V1U
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G
M:60@(D%022!)1"(*;7-G<W1R(")!4$D@240@*&$@<')O9W)A;6]ZX7-I(&9E
M;/QL970@87IO;F]S[73S:F$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B
M"FUS9W-T<B`B17)R]6P@87H@961I=&]R<O-L(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D[I=FIE
M9WDN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B86)S>B!A;'5L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM
M<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(F%B<WH@:_9ZZ7`B"@HC.B!L:6(O
M5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEN8W,@:F]G;W-U;'1SX6=A
M(&$@5D93(&%L:_9N>79TX7(@;.ET<F5H;WKA<^%H;WHN(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+B(*;7-G<W1R(").:6YC<R!J;V=O<W5L='/A9V$@82!61E,@
M9N%J;"!LZ71R96AO>N%SX6AO>BXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")"96IE
M;&5N=&ME>NES:2!I;F9O<FWA8VGS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DIE;'-Z
M\R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS
M9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B02!J;V=O<W5L='/A9R!F
M96P@=F%N(&;\9V=E<WIT=F4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")0Z6YZ_&=Y96LB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")"979I=&5L(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G
M:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!;&-S;W!O<G0@;.ET<F5H
M;WKA<V$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](;W)D
M92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(DIO9V]S=6QT<^%G:2!A;&-S;W!O<G0@;.ET<F5H;WKA<V$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE
M<F4Z(@IM<V=S='(@(D%D9&IU:R!H;WIZX2!I='0Z(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.
M97<@1W)O=7`B"FUS9W-T<B`BVFH@8W-O<&]R="!LZ71R96AO>N%S82(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(MIJ
M(&IO9V]S=6QT<^%G(&SI=')E:&]ZX7-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!
M9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B06QC<V]P;W)T
M(&AO>GKA863A<V$@7"(E<UPB+6AE>B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(DIO9V]S=6QT<^%G:2!A;&-S
M;W!O<G0@:&]Z>N%A9.%S82!<(B5S7"(M:&5Z(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+::B!F96QH
M87-Z;N%L\R!LZ71R96AO>N%S83HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(MIJ(&]S>FQO<"!H;WIZX6%DX7-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(MIJ('1A9V]K(&9E;';I=&5L92(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(MIJ('#A<B!H
M;WIZX6%DX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA
M(%-I9&5B87(B"FUS9W-T<B`B02AZ*2`E<R!M96[\="!A9&IU:R!H;WIZX2!A
M($UO>FEL;&$@;65N_'-O<FAO>B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM
M<V=S='(@(D%D:G5K(&AO>GKA(&$@8^UM:F5G>7KI:VAE>CHB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@
M;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D:G5K(&AO>GKA(&$@8^UM:F5G
M>7KI:V5M:&5Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U
M<V5R(@IM<V=S='(@(MIJ(&9E;&AA<WINX6SS(&AO>GKA863A<V$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"B)<(B5S7"(@9F5L:&%S>F[A;/-T(&AO>GKA861T=6L@82!R96YD<WIE<FAE
M>BP@9&4@;F5M('-I:V5R_&QT(&$@=/9B8FD@(@HB8F5J96QE;G1K97KI<VD@
M861A="!TX7)O;.%S83H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")<(B5S7"(@9F5L:&%S>F[A;/-T
M(&9E;'9E='3I:R!A(')E;F1S>F5R8F4N($UO<W0@;>%R(&)E:F5L96YT:V5Z
M:&5T+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS
M9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(D$@<F5N
M9'-Z97)H97H@;F5M(&%D:&%T\VL@:&]Z>N$@^FH@9F5L:&%S>F[A;/-K+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D/M;2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@
M0F]O:R(*;7-G<W1R(")#[6UJ96=Y>NEK(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4V(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F
M;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B061M:6YI<WIT<N%C:?,@+2!J;V=O
M<W5L='/A9V]K(&%DX7-A('1O=N%B8FD@9F5L:&%S>F[A;/-K;F%K(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-Z
M='+A8VGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I
M9"`B061S(@IM<V=S='(@(DAI<F1E=.ES96LB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A
M;B(*;7-G<W1R(")!9F=A;FES>G3A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B06QBX6YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QGZ7)I82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM
M<V=S='(@(D5L:&5L>65ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@
M(E)E;F1E>NES.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I
M9"`B06QL(@IM<V=S='(@(F%Z(/9S<WIE<V5T(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM
M<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B36EN9&5N
M(&YE;2!V96YDZ6<@9F5L:&%S>F[A;/,B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM
M<V=S='(@(DUI;F1E;B!C<V]P;W)T(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED
M(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B36EN9&5N(&IO9V]S=6QT<^%G
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B36EN9"!A
M(&[I9WD@;VQD86QO;B!L96=Y96X@:V5R970B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(D5N9V5D:OQN:R!M96<@=/9B8B!C[6UE="!I<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(D$@<V]R<WKA;6]S(&9E;'-O
M<F]LX7,@=.UP=7-A(';A;'1O>G1A=&AA=/,@;&5G>65N/R(*"B,Z(&QI8B](
M;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B3>%R(&SI=&5Z:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R
M("))35-0(&)E:F5L96YT:V5ZZ7-I('!A<F%MZ71E<F5K(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S
M<W=O<F0B"FUS9W-T<B`B3>%S:6LL($E-4U`@:F5L<WKS(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E
M<FYA;64B"FUS9W-T<B`B3>%S:6LL($E-4U`@8F5J96QE;G1K97KI<VD@;NEV
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L
M=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DWA<VEK(&5M86EL(&/M
M;2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T[78@<V%B;&]N;VLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")!;'1E
M<FYA=.UV('-Z]G9E9SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R
M(")!;65R:6MA:2!3>F%M;V$B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D$@;65G861O='0@
MZ7)TZ6L@;F5M(&9O9V%D:&%T\R!E;"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(*;7-G<W1R("))<VUE<F5T;&5N(&AI8F$@=/9R=.EN="XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B
M"FUS9W-T<B`B06YG;VQA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG
M=6EL;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N:6T@<')O>'EN(&ME<F5S
M>G3\;&D@:6YT97)N970@96SI<NES(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")6X6QA<WHB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I<WHB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@Z7,@0F%R8G5D
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN
M<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB
M"FUS9W-T<B`B06QK86QM87KA<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")!;&MA;&UA
M>N%S;VL@;&ES=.%J82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*
M;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!>B!A;&MA
M;&UA>N%S(&OI<WHN(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!(&OV
M>O9S('3A<G1E<OQL970@86QC<V]P;W)T:F%I<F$@:7,@Z7)VZ6YY97,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B
M07!P<F]V92(*;7-G<W1R(")*\W;A:&%G>>%S(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@T,0IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*
M;7-G<W1R(")+]G+\;&)E;/QL:2!MZ7)E="(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("+A<')I;&ES
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H
M5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")A<F%B("A7:6YD;W=S+3$R-38I(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S
M='(@(D$@=/9M]G+M=&5T="#A;&QO;>%N>2!MZ7)E=&4B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D$@=/9M]G+M=&5T
M="#A;&QO;>%N>2!N979E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@/R(*;7-G<W1R(")":7IT;W,@8F5N;F4L(&AO9WD@=/9R]FQN:2!K
M[7;A;FIA("5S(&)E:F5L96YT:V5ZZ7-I(&EGZ6YYZ70_(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@
M86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")":7IT;W,L(&AO9WD@=/9R
M]FQN:2!A:V%R:F$@7"(E<UPB+70@86QC<V]P;W)T:F%I=F%L(&5G>?QT=#\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT[6YA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M07)M96YI82(*;7-G<W1R("+6<FWI;GEO<G-ZX6<B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS
M9W-T<B`B]G)MZ6YY("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B3?MVZ7-Z970B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")0;VAN
M<&5I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I
M:2!!<G0B"FUS9W-T<B`B07-C:6D@<F%J>F]K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`BP7IS:6$O0W-E;F1E<RWS8V7A;FD@<NEG:?,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T
M<B`B(@HB2^ER:F5N(&$@<F5N9'-Z97(@;65G97+U<^UTZ7-T(&$@:V%R8F%N
M=&%R=.%S:2!F96QA9&%T;VL@96QVZ6=ZZ7-E(&5L]71T/R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,#DY"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B2&]Z>N%R96YD96SI<VD@;W-Z;&]P;VLB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B3F5M;.ET97KU(&-S;W!O<G1O="!K
M[7/I<F5L="!M96<@=/9R]FQN:2XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R(").96ULZ71E>O4@:F]G;W-U;'1SX6=O
M="!K[7/I<F5L="!M96<@=/9R]FQN:2XB"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE;6SI=&5Z]2!J;V=O<W5L='/A9V]T
M(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N:2XB"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B3F5M;.ET97KU(&OV>O9S('3A
M<G1E<OQL971E="!K[7/I<F5L="!M96<@;65G=N%L=&]Z=&%T;FDN(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B5'5L86ID
M;VYSX6=O:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#D@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS
M9VED(")!=6=U<W0B"FUS9W-T<B`B875G=7-Z='5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A
M;&EA(@IM<V=S='(@(D%U<WIT<N%L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S
M='(@(D%U<WIT<FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ
M-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!A('-Z_&MSZ6=E
M<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD
M(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@
M(B(*(D%U=&A?8WER=7,Z(&$@:.%T=.ER<WIO;&?A;'1A=.%S(&YE;2!R96YD
M96QK97II:R!A(&OM=N%N="!KZ7!E<W/I9V5K:V5L+B(*"B,Z(&QI8B](;W)D
M92]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)U<SH@82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G
M<W1R("(B"B)!=71H7V9T<#H@82!S>OQK<^EG97,@9G1P(&+U=NUTZ7,@;F5M
M('1A;.%L:&%T\RX@1F]R9.UT<V$@;&4@82!02%`M="!A>B`M+2(*(F5N86)L
M92UF='`@;W!C:?-V86PN(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z
M-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z(&$@<WK\:W/I9V5S(&EM
M87`@8O5V[73I<R!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!A('-Z
M_&MSZ6=E<R!K<F(U(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D
M:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O
M<GDB"FUS9W-T<B`B075T:%]L9&%P.B!N96T@:&]Z:&%T\VL@;.ET<F4@^FH@
M9F5L:&%S>F[A;/-K($%C=&EV92!$:7)E8W1O<GD@97-E=.EN(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E
M;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!F96QH87-Z;N%L\VL@;F5M('3V
M<O9L:&5T]6L@06-T:79E($1I<F5C=&]R>2!E<V5TZ6XB"@HC.B!L:6(O2&]R
M9&4O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A
M<#H@82!S>OQK<^EG97,@3$1!4"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P
M.B`E<R!F96QH87-Z;N%L\R!H;WIZX6%DX7-A(&YE;2!S:6ME<OQL="X@02!S
M>F5R=F5R(';A;&%S>F$Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z("5S(&9E;&AA
M<WINX6SS('3V<FSI<V4@;F5M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A
M<#H@)7,@9F5L:&%S>F[A;/,@861A=&%I;F%K(&UE9_IJ[73A<V$@;F5M('-I
M:V5R_&QT(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED
M(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(D%U=&A?;&1A<#H@82!F
M96QH87-Z;N%L\VL@;F5M(&WS9&]S[71H873S:R!!8W1I=F4@1&ER96-T;W)Y
M(&5S973I;B(*"B,Z(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C0V"FUS9VED
M(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]M8V%L.B!A('-Z_&MSZ6=E<R!-0T%,(&+U=NUT
MZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP
M.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!A('-Z
M_&MSZ6=E<R!S;6)A=71H(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYE;2!S:6ME
M<OQL="!A>B!)34%0('-Z97)V97)E;B!V86SS(&9E;&AA<WINX6SS87IO;F]S
M[73A<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D$@9F5L
M:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME<OQL="XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")!(&9E;&AA<WINX6SS87IO
M;F]S[73A<R!N96T@<VEK97+\;'0N("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@87IO
M;F]S[73A<^%T(&$@4D%$2553('-Z97)V97(@96QU=&%S[71O='1A+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(").96T@<VEK97+\;'0@87H@
M1E10('-Z97)V97)H97H@=F%L\R!F96QH87-Z;N%L\V%Z;VYO<^UTX7,N(@H*
M(SH@;&EB+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T
M;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(DYE;2!S:6ME<OQL
M="!A>B!334(@<WIE<G9E<F5N('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V
M86EL86)L92!F:65L9',Z(@IM<V=S='(@(D$@<F5N9&5L:V5ZZ7-R92#A;&SS
M(&UE>O5K.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE<F)A:F1Z
M<^%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(
M($5X8W5S97,B"FUS9W-T<B`B02!G;VYO<WH@<F5N9'-Z97)G87ID82!M96YT
M<^EG96DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(DCA='3I
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B2.%T=.ER('-Z
M[6XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(").96T@;65G9F5L96SU(&ME
M<F)E<F]S(&IE;'-Z\RXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX
M,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").96T@
M;65G9F5L96SU(&ME<F)E<F]S(&9E;&AA<WINX6SS;NEV+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A
M:&%M87,B"FUS9W-T<B`B0F%H86WA:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T
M<B`B0F%H<F5I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED
M(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")B86QT:2`H25-/+3@X
M-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D97,B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!(&=R869I:W5S(.%L;&]MX6YY;VL@7"(E<UPB(&%L:_9N>79TX7)A(&YE
M;2!T86SA;&AA=/,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")A
M;&%P=F]N86QO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B1F5HZ7)O<F]S
M>F]R<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEU;2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G
M<W1R(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5TX6XB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS
M9W-T<B`B4WK\;&5TZ7-N87`B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S8P"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<
M(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M(%PB)7-<(B!B;&]K:R!A(%PB)7-<(B!P<F]G<F%M;6%L(&YE;2!T86SA;&AA
M=/,N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED
M(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")+Z7!E<FYY]7+I<WH@8F7A;&SM
M=.%S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED
M(")";&]C:R!4>7!E(@IM<V=S='(@(DOI<&5R;GGU<NES>B!T[7!U<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I
M9"`B0F]L9"(*;7-G<W1R(")FZ6QK]G;I<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS
M9W-T<B`B0F]L[79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")+961V96YC('=E8F/M;65K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DME<F5T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B
M0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B2V5R971V87-T86=SX6<Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")+97)E=&5K(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-Z;FEA+4AE<F-E
M9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")"
M;W1H(@IM<V=S='(@(DUI;F1K971T]2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S
M='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B86QU
M;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T+7-Z:6=E
M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z[6QI82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I="!)
M;F1I86DM\V-EX6YI(%1E<OQL970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA
M;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(D)U;&?A<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R(")&96QS;W)O;.%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@
M(D)U<FMI;F$@1F%S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G:60@(D--
M4R(*;7-G<W1R(")796)O;&1A;"!K87)B86YT87)TX7,B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@
M(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED
M(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")!('1A;OIS[71V
MX6YY=FES<WIA=F]NX7-I(&QI<W3A:R`H0U),*2!C[6UE:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM
M<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")#96QL82!T=6QA
M:F1O;G/A9V]K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M,0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B02!C86-H92!I;FEC:6%L:7KA;.%S82!N96T@9F5J97KU9/9T="!B92XB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DYA<'3A<B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B3GEU9V]D="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R
M(")+86UB;V1Z<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<G5N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A(&IE
M;'-Z\W0@X73A;&SM=&%N:2P@9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO
M>BXB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(D$H
M>BD@7"(E<UPB(.%L;&]MX6YY(&YE;2#M<FAA=/,N(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(D$@:_QL<_4@9F5L:&%S>F[A
M;/-K87!C<V]L870M:V5Z96SU:R!N96T@861M:6YI<WIT<N%L:&%T\VLN(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O075T
M:"]C>7)S<6PN<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C
M;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(")!(&OV=F5T:V5Z
M]2!)34%0('-Z97)V97(@;F5M(.ER:&5T]2!E;#H@)7,B"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N>2!N
M96T@;GEI=&AA=/,@;65G+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA
M9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")-
MZ6=S92(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS
M9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B3>EG<V4@:_QL
M9/9K(&AI8F%J96QE;G3I<W0B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(D$H>BD@7"(E<UPB(.%L;&]MX6YY(&YE;2!T]G+V;&AE=/4N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-#8*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R
M>2!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!T86SA;&AA=/,@87H@:61E:6=L
M96YE<R#A;&QO;>%N>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV=.%R+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R(")!
M("=T87)G971&:6QE)R!P87)A;>ET97(@;65G863A<V$@;NEL:_QL(&YE;2!F
M;VQY=&%T:&%T:G5K+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE
M=/4N(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").96T@
M=/9R]FQH973U+"`E9"!A;&-S;W!O<G1J82!V86XN(@H*(SH@;&EB+TAO<F1E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E
M<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E
M<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB07H@
M^FH@<V]R8F%R96YD97KI<R!N96T@;&5H971SZ6=E<RP@82!M96=A9&]T="!A
M9&%T;VL@<WKA;6$@;F5M(&5G>65Z:6L@82`B"B)TX7)O;'1A:^EV86PN(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@
M(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM
M<V=S='(@(D$@;65G861O='0@<WKA;7)A(&YE;2!K_&QD:&5T]2!E;"!A>B#\
M>F5N970N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("):]FQD+69O:VDM
M<WII9V5T96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(L%B<F%S
M>O9V96<B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM
M<V=I9"`B0V%R<FEE<B(*;7-G<W1R(")3>F]L9^%L=&%T\R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B
M96QS(@IM<V=S='(@(DMA=&5G\W)IX6L@Z7,@:F5L]FSI<_QK(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DMA:FWA;BUS>FEG971E:R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#
M96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL('1E;&5F;VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED
M(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B0V5L;&%T=6QA:F1O;G/A9V]K
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B0V5L;&$@8F5L<_4@
M;6%R9_,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@
M(D-E;&QA='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM
M<V=S='(@(D-E;&SA:R!K]GKV='1I('+I<SHB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(W.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL('1E
M;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L
M=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B:V5L=&$@*$E33RTX.#4Y+3$T
M*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")K]GKI<"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")+]GKI<"UA9G)I
M:V%I($OV>G3A<G-A<^%G(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*
M;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@
M(FME;&5T+65U<O-P86D@*$E33RTX.#4Y+3(I(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B
M"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!RZ7-Z;&5T96DB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N
M97(B"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!T=6QA:F1O;F]S82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T
M92!0;VQI8VEE<R(*;7-G<W1R(")486[Z<^UT=N%N>2!F96QH87-Z;N%LX7-I
M(&ERX6YY96QV96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B0W/A9"(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")6X6QT
M;WIT873A<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM
M<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B02!J96QS>O,@
MX73A;&SM=.%S82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(D%Z(-9N(.%L=&%L(&5L:_QL9/9T="!L979E;&5K96X@
M<WIE<F5P;/4@;NEV(.ES(&/M;2!M96=VX6QT;WIT873A<V$N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(D$@:F5L96X@:V]N9FEG=7+A8VGS8F%N(&YE
M;2!L96AE='/I9V5S(&$@:F5L<WIA=F%K(&WS9&]S[73A<V$N($9O<F1U;&IO
M;B!A("(*(G)E;F1S>F5R9V%Z9.%H;WHN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*
M;7-G<W1R(")+87)A:W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN
M+BXB"FUS9W-T<B`B3&EN7VME;&QE;O5R>NES+BXN(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`B0VAI;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R(")+[6YA(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")K[6YA:2P@96=Y<WIE<OMS[71E
M='0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I
M9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B:^UN86DL
M(&AA9WEO;>%N>6]S("A":6<U*2(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B5N%L
M87-S>F]N(&MI(&5G>2!A;&MA;&UA>N%S=#HB"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B5N%L87-S>F]N(&IE;'-Z\W0B"@HC.B!L:6(O2&]R9&4O075T:"]3
M:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T
M<B`B5N%L87-S>F]N(&5G>2!F96QH87-Z;N%L\VYE=F5T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P
M;&%Y(&1A=&5S.B(*;7-G<W1R(")6X6QA<W-Z82!K:2!A(&3A='5M;VL@;65G
M:F5L96[M=.ES:2!F;W)MX6KA=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B
M5N%L87-S>F$@:VD@82!F96QS;W)O;.%S('3M<'5SX70@*'-ZX6UO>F]T="!L
M:7-TX6MNX6PI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R(")+
M87+A8W-O;GDM<WII9V5T96LB"@HC.B!L:6(O5D93+G!H<#HY,30@;&EB+TYE
M="]335,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B02AZ*2`E<R!C;&%S
M<R!D969I;NUC:?-J82!N96T@=&%LX6QH873S+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G
M<W1R(")$97+\;'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S
M='(@(E3V<FQI(&%Z($U33V9F:6-E('1A9V5K970B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")!(&QE
M:^ER9&5ZZ7,@=/9R;.ES92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R
M.B`E<R(*;7-G<W1R("(E<R!F96QH87-Z;N%L\R!T]G)LZ7-E(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U
M<V5R(@IM<V=S='(@(D$@9F5L:&%S>F[A;/,@=/9R;.ES92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R
M(&1A=&$B"FUS9W-T<B`B02!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U
M"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(D5S=.ER92!D97+\;'0@
MZ6<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B02!F;VQY
M=&%TX7-H;WH@:V%T=&EN='-O;B!A>B!E9^ER<F5L(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@
M=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!S>F]L9^%L=&%TX7,@2%14
M4"UN(&ME<F5S>G3\;"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN
M9&]W(@IM<V=S='(@(D%Z(&%B;&%K(&)E>N%RX7-A(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")";W)U;'0@
MZ6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(E)E9V=E;"!F96QH]7,@
M:63U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")&96QH]7,@:63U(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B2_-K=7-Z+7-Z:6=E
M=&5K(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I
M9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")4_&YT97-S_&L@96P@87H@
M;VQD86QS\R!M96[\="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S
M(@IM<V=S='(@(M9S<WIE>N%R="!K97)E=&5K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B
M"FUS9W-T<B`B2V]L=6UB:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS
M9W-T<B`B4WKM;B(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,S$@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S,@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`S('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME
M<B(*;7-G<W1R(")3>NUN=N%L87-Z=/,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@S,@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")3>NUN
M=N%L87-Z=.%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D]S>FQO<&]K.B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(D%Z(&]S>FQO<&]K(&/M;65I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(E9I
M8V-E:R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N
M9"(*;7-G<W1R(")087)A;F-S(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(E!A<F%N8W/I<G1E;&UE
M>O4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O
M;6UE;G0B"FUS9W-T<B`B365G:F5G>7KI<R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(").
MZ78L(&5L;F5V97KI<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R
M92US>FEG971E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D/I9R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@
M(E-ZX6WM=/-GZ7!E:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("))9/5JX7+A<VD@:&5L
M>7IE="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#;VYD
M:71I;VYS(@IM<V=S='(@(DED]6KA<N%S:2!H96QY>F5T(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,B"FUS9W-T<B`B2_QL]FYB<^EG96L@82!K;VYF:6=U<N%C:?-B86XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U
M<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD
M($]U=&QO;VLN(@IM<V=S='(@(B(*(DOI>FES>N%M[73S9^EP96MK96PL(&]K
M;W-T96QE9F]N;VMK86PL($]U=&QO;VMK86P@=F%L\R!A9&%T<WII;FMR;VYI
M>N%LX7,@(@HB:V]N9FEG=7+A8VGS:F$B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+B(*;7-G<W1R(")!(&MO;F9I9W5RX6-I\R!MX7(@;F5M(.ER=NEN>65S+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B5S(&MO;F9I9W5RX6-I\VIA
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I
M9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")!(&IE;'-Z\R!M96=E<O5S
M[73I<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG\R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O
M;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B
M2V]N9_-I($1E;6]K<F%T:6MU<R!+]GITX7)S87/A9R(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM
M<V=S='(@(E-I:V5R=&5L96X@82!K87!C<V]L870N(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM
M<V=S='(@(E-I:V5R=&5L96X@82!K87!C<V]L870Z("(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D
M('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!(&YY:6QVX6YO
M<R!K=6QC<V]K('-Z97)V97)E(&5L=71A<^UT:F$@82!K87!C<V]L871O="XB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B02!N>6EL=N%N;W,@
M:W5L8W-O:R!S>F5R=F5R92!E;'5T87/M=&IA(&$@:V%P8W-O;&%T;W0N($]K
M83H@)7,@*"5S*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O
M;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E-I:V5R
M=&5L96X@87H@1E10('-Z97)V97)R96P@=F%L\R!K87!C<V]L870N(@H*(SH@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM
M<V=S='(@(E!A<G1N97)E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")!('!A<G1N
M97)E:V5T('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI:^EH97HN
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@
M(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")!
M('3V;?9R[71E='0@X6QL;VWA;GD@=.UP=7-A.B`B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HU-B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS
M9W-T<B`B7"(E<UPB('1A<G1A;&UA(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS
M9VED(")#;VYT:6YU92(*;7-G<W1R(")&;VQY=&%TX7,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K
M($ES;&%N9',B"FUS9W-T<B`B0V]O:RUS>FEG971E:R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(E/\=&DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B3>%S;VQJ=6L@X70B"@HC
M.B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")!(&WA<V]LX7,@;F5M('-I:V5R_&QT
M.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(D$@:VEJ96SV
M;'0@<NES>B!MX7-O;.%S82(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S
M="!)1"(*;7-G<W1R(")3>N%M;.%ZX7-I(&%Z;VYO<^UT\R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M<W1A(%)I8V$B"FUS9W-T<B`B0V]S=&$@4FEC82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)
M=F]I<F4B"FUS9W-T<B`B16QE9N%N=&-S;VYT<&%R="(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4Z("(*;7-G<W1R(").96T@<VEK97+\;'0@4$=0+79E;"!T
M:71K;W/M=&%N:2!A(&QE=F5L970Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E
M.B`B"FUS9W-T<B`B02!L979E;&5T(&YE;2!S:6ME<OQL="!01U`@86SA[7+A
M<W-A;"!E;&SA=&YI.B`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(D$@;&5V96QE="!N96T@<VEK97+\;'0@87H@4R]-24U%('-Z
M86)VX6YY('-Z97)I;G0@=&ET:V]S[71A;FDN(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+B(*;7-G<W1R(")!(&QE=F5L970@;F5M('-I:V5R_&QT(%,O
M34E-12!A;.'M<N%S<V%L(&5L;.%T;FDN(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(D$@<&%R=&YE<B!A9&%T
M86ET(&YE;2!S:6ME<OQL="!E;'3A<F]L;FDN("5S(@H*(SH@;&EB+TAO<F1E
M+T=R;W5P+VQD87`N<&AP.CDV(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$R
M,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N
M;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B07H@3$1!4"!S>F5R
M=F5R(&YE;2#I<FAE=/4@96PN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L;&5N]7)I>FYI(&$@
M<WKA;6SA:N%N(')E;F1E;&ME>NES<F4@X6QL\R#V<W-Z96=E="X@)7,B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT
M(&%Z($Q$05`@<WIE<G9E<FAE>B!K87!C<V]L\V1N:2XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM
M<V=S='(@(DYE;2!S:6ME<OQL="!A*'HI(%PB)7-<(B!S>F5R=F5R<F5L($94
M4"!K87!C<V]L871O="!F96QV96YN:3H@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@:_9R;&5VZ6QL:7-TX70N("5S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R(")!>B!A9&%T;VL@
M4$=0('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS9&]LX7-A(&YE;2!S:6ME
M<OQL=#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G
M:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(")!
M>B!A9&%T;VL@4R]-24U%('1I=&MO<^UTX7-B\VP@=/9R=.EN]2!D96OS9&]L
MX7-A(&YE;2!S:6ME<OQL="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B02!P87)T;F5R('3V<FSI<V4@
M;F5M('-I:V5R_&QT+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B02!K]G)L97;I
M;&QI<W1A('3V<FSI<V4@;F5M('-I:V5R_&QT+B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R(").96T@<VEK97+\;'0@=/9R]FQN:2!A*'HI(%PB)7-<(B!S971U<"!U
M<&=R861E('!R;V=R86UO="XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+B(*;7-G<W1R(").96T@<VEK97+\;'0@;65GX6QL87#M=&%N:2!A(&/M
M;7IE='0@96UA:6P@8^UMZ70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&)E;VQV87-N
M:2!A('1E;&IE<R!C[6UJ96=Y>NEK970N(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@8F5O;'9A<VYI(&$@=&5L:F5S(&OV<FQE=NEL;&ES=.%T+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD
M(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@
M;&ES=',N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L
M97;I;&QI<W3A:R!T96QJ97,@9F5L<V]R;VSA<^%T+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB
M"FUS9W-T<B`B02AZ*2!<(B5S7"(@<W1R873I9VEA(&YE;2!T86SA;&AA=/,N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N
M>79TX7(@;F5M(&AO>FAA=/,@;.ET<F4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")!(&YY:6QVX6YO<R!K
M=6QC<V]T(&YE;2!S:6ME<OQL="!M96=S>F5R97IN:2!A(&MU;&-S<WIE<G9E
M<G+U;"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@7"(E<UPB+70@[7+A<VD@8^EL;&%L(&UE9VYY:71N:2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="`E<RUT(&UE9VYY:71N:2XB"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<R(*;7-G<W1R(")!("5S(&MA<F)A;G1A<G3A<VD@;6]D=6P@;F5M(&YY
M:71H873S(&UE9R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E
M<UPB(&%L:_9N>79TX7(@;F5M(&YY:71H873S(&UE9RXB"@HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(D%Z($Q$05`@<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*
M"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(B5S(&YE;2!O;'9A<VAA
M=/,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@
M(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"B).96T@<VEK97+\;'0@82!K[7;A;G0@9F5L:&%S>F[A;/,@:F5L<WIA
M=N%T(.%TX6QL[71A;FDN($%Z(&UE9V%D;W1T(&%D871O:R`B"B)N96T@=F%G
M>2!N96T@=&5L:F5S96X@9F5L96QN96L@;65G+B!0<O-BX6QJ82#Z:G)A+"!V
M86=Y(&AA('1O=N%B8FD@(@HB<V5G[71SZ6=R92!V86X@<WK\:W/I9V4L(&9O
M<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H;WHN(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,P-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S,X"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S4@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,0HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYE;2!S:6ME<OQL="!M96=H
M873A<F]Z;FD@87H@96SI<NES:2!J;V=O<W5L='/A9V]K870@*$%#3"DB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!C[6UJ96=Y
M>NEK970N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B
M96]L=F%S;FD@82!K]G)L97;I;&QI<W3A="X@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM
M<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A
M:V%T+B`E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DYE
M;2!S:6ME<OQL="!M96=H873A<F]Z;FD@82!S>F5R=F5R(&OI<&5S<^EG96ET
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@
M;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").96T@<VEK97+\
M;'0@=FES<WIAX6QL[71A;FD@97H@97)E9&5T:2!K;VYF:6=U<N%C:?-T+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<
M(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(&%L:_9N>79TX7(@;F5M('3V
M<O9L:&5T]2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(").96T@<VEK97+\;'0@96QM96YT96YI("5S(&MO;F9I
M9W5RX6-I\W0N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYE;2!S:6ME<OQL="!E
M;&UE;G1E;FD@82!B86-K=7`@:V]N9FEG=7+A8VGS="XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R(").
M96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P(&MO;F9I9W5RX6-I\W0Z
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&5L;65N=&5N
M:2!A*'HI(%PB)7-<(B!S971U<"!U<&=R861E('!R;V=R86UO="XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R(").96T@<VEK97+\;'0@96QM96YT96YI(&$H>BD@)7,@
M8F%C:W5P(&MO;F9I9W5RX6-I\W0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+B(*;7-G<W1R("(B"B)!*'HI("5S(&MO;F9I9W5RX6-I\W,@X6QL;VWA;GET
M(&YE;2!S:6ME<OQL="!E;&UE;G1E;FDN(%9A9WD@:&%S>F[A;&IA(&$@)7,@
M(@HB;VQD86QO;B!L97;U(&QE:&5T]7/I9V5K970L('9A9WD@;>%S;VQJ82#A
M="!A>B!A;.%B8FD@:_-D;W0@:61E.B`E<RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")!>B!,1$%0('-Z97)V97)E;B!N96T@<VEK
M97+\;'0@96QVZ6=E>FYI(&$@:V5R97/I<W0N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@
M(EPB)7-<(B!N96T@=F]L="!T]G+V;&AE=/4N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(D$@<&%R=&YE
M<B!A9&%T86ET(&YE;2!S:6ME<OQL="!M\V1O<^UT86YI+B`E<R(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$@:_9R;&5VZ6QL:7-T82!M\V1O
M<^UTX7-A+B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").96T@<VEK97+\;'0@96QM96YT
M96YI(%PB)7-<(B!K;VYF:6=U<N%C:?-JX70Z("5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB
M"FUS9W-T<B`B02!-;WII;&QA(&UE;OQS;W(@;F5M('1A;.%L:&%T\RX@16QL
M96[U<FEZ>F4L(&AO9WD@;65G('9A;BUE(&YY:71V82XB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B
M"B).96T@<VEK97+\;'0@7"(E<UPB(&9E;&AA<WINX6SS;F%K(&IO9V]S=6QT
M<^%G;W0@861N:2!A*'HI(%PB)7-<(B!M87!PX6AO>CH@)2(*(G,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30R,PIM<V=I9"`B0V]U;G1E9"!T97AT(@IM
M<V=S='(@(DMO<FSA=&]S('-Z]G9E9R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(D]R<WKA9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S4*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B5.%V;VMT873A<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(DSI=')E:&]ZX7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`B3&EN:R!LZ71R96AO>N%S82(*"B,Z('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T
M92!A(&YE=R!O;F4B"FUS9W-T<B`BVFH@;.ET<F5H;WKA<V$B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B
M"FUS9W-T<B`B06QM87!PX6L@;.ET<F5H;WKA<V$B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*
M;7-G<W1R(")!>B!O8FIE:W1U;2!LZ71R96AO>O-JX6YA:R!J;V=O<W5L='/A
M9V%I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,38*;7-G:60@(D-R961I
M="!C87)D(&YU;6)E<B(*;7-G<W1R(")(:71E;&OA<G1Y87-ZX6TB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B0W)O871I82(*;7-G<W1R(")(;W)VX71O<G-ZX6<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A
M(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B2F5L96YL96=I(#0@9N%Z
M:7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@
M4V5S<VEO;G,B"FUS9W-T<B`B02!J96QE;FQE9VD@9F5L:&%S>F[A;/-K87!C
M<V]L871O:R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(E!O;G1O
M<R!I9/4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(D$@:F5L96YL96=I(%523"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM
M<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")*96QE;FQE9VD@9F5L:&%S
M>F[A;/-K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R
M<F5N="!796%T:&5R(@IM<V=S='(@(DIE;&5N;&5G:2!I9/5JX7+A<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E
M;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B02!J96QE;FQE9VD@:63U:N%RX7-I
M(&AE;'EZ970Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")*96QE
M;FQE9VD@<W3M;'5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*(DUI;'EE;B!P87)A;F-S;VL@
M9G5S<V%N86L@;&4@875T;VUA=&EK=7-A;B!A("5S8F4@=/9R=.EN]2!B96IE
M;&5N=&ME>NES:V]R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DMI
M=N%GX7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(D$@:VEJ96SV
M;'0@<NES>B!K:7;A9^%S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#:7!R
M=7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL
M:6,@*$M/23@M4BDB"FUS9W-T<B`B8VER:6QL("A+3TDX+5(I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S
M+3$R-3$I(@IM<V=S='(@(F-I<FEL;"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB"FUS9W-T<B`B8VER:6QL+75K<N%N("A+3TDX+54I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B0W-E:"!+]GITX7)S87/A
M9R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-S8*;7-G:60@(B(*(D133B`H
M<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AA9&%T
M9F]R<N%S;&7M<O,@+2!LX7-D.B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+B(*(F1B+FEN=')O+61S;BYP:'`I(@H*
M(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB
M"FUS9W-T<B`B;F%P;VYT82(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM
M<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!B]FYG
MZ7-Z]2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")$871A
M8F%S92!,;V]K=7`B"FUS9W-T<B`B061A=&+A>FES8F%N('9A;/,@:V5R97/I
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D3A
M='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*
M;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B02!B9>ER:V5ZZ7,@;F%P
M:F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y,PIM<V=I9"`B1&%T92!S
M96QE8W1I;VXB"FUS9W-T<B`B1.%T=6T@:VEVX6QA<WITX7-A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B;F%P<&%L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")/<WIL;W`@
M=/9R;.ES92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R(")D96-E;6)E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G
M:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(")S>N%M;VLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$
M96-R96%S92!);F1E;G0B"FUS9W-T<B`B0F5K97IDZ7,@:VEJ:F5B8B(*"B,Z
M(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(D%L87#I<G1E;&UE>F5T="(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS
M9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D%Z(&%L87#I<G1E;&UE>NES
M('-Z97)I;G1I('-Z[6XB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDV
M"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(D%L87#I<G1E;&UE
M>NES('-Z97)I;G1I(&%Z;VYO<^UT\R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")!;&%PZ7)T
M96QM97IE='0@<VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN[6-I\VLB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<Q(&QI8B](;W)D92]097)M<RYP:'`Z,S(V(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDS"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW
M,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B5/9R
M;.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")!(&-E
M;&QA('3V<FSI<V4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(D$@
M8W-O<&]R="!T]G)LZ7-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(D$@;F%P;//A;&QO
M;>%N>2!T]G)LZ7-E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B02!J;V=O<W5L='/A9R!T]G)LZ7-E(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(DQE=F5L96L@=/9R;.ES92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D$@8V5L;&$@=/9R
M;.ES92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B07H@
M;W-Z;&]P('3V<FSI<V4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM
M<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R(")4]G+V;&K\:R!K:2!A(&UE9VSI=O4@86QT97)N873M=B!S86)L;VYT
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS9VED
M(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B02!L979E;&5K('3V<FSI<V4B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")<(B5S7"(@:F]G;W-U;'1SX6=A:6YA:R!T]G)LZ7-E(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES
M<VEO;G,_(@IM<V=S='(@(E3V<O9L:OQK(%PB)7-<(B!J;V=O<W5L='/A9V%I
M="#I<R!E;FYE:R!E<V5T;&5G97,@86QC<V]P;W)T:F%I=#\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(D$@<V]R('3V<FSI<V4B"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B02!K:7;A;&%S>G1O
M='0@87IO;F]S[73S('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R<R(*;7-G
M<W1R(")!>B!A;&UA<'#A:R!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(D$@:F5L96YL96=I(&]S
M>FQO<"!T]G)LZ7-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@<F]W(@IM<V=S='(@(D$@:F5L96YL96=I('-O<B!T]G)LZ7-E(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(E3V<O9L=/QK(&$H>BD@7"(E<UPB('-E='5P('5P9W)A9&4@<')O9W)A
M;6]T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G
M<W1R(")!(&OI>F)E<^UTZ7,@:61E:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S
M='(@(D3A;FEA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D%D:F]N
M(&QE[7+A<W0@82!P<F]B;.EMX7+S;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B3&7M<N%S(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B4NES>FQE=&5K("AA($AO<F1E
M(&QO9V;A:FQB86X@:7,@;65G=&%LX6QH873S*3HB"@HC.B!L:6(O2&]R9&4N
M<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B02!RZ7-Z;&5T96L@82!R96YD
M<WIE<F=A>F1A('-ZX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\;'1E
M:RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R(")&96IL97-Z=.ES(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")(87)M
M871P;VYT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E
M=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B2&%R;6%T<&]N="!J
M96QE;FQE9SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B2&%R;6%T<&]N=#H@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM
M<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B8F%L<O-L
M(&IO8F)R82#M<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B
M"FUS9W-T<B`B:F]B8G+S;"!B86QR82#M<N%S(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")#[6UTX7(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y
M(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(D%Z(&ED]7!O;G1O:V%T(#(T(/-R
MX7,@9F]R;>%T=6UB86X@:F5L96[M='/\:R!M96<_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(DUE9VIE;&5N[73I<VD@8F7A;&SM=.%S;VLB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@(D1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0B"FUS9W-T<B`B02!RZ7-Z;&5T97,@96SU<F5J96QZZ7,@;65G
M:F5L96[M=.ES92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@
M(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B16SU<F5J96QZZ7,@
M;65G:F5L96[M=.ES92`H<F5P_&SU=.ER:2DB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C@P,PIM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B365G
M:F5L96[M=.ES:2!F;W)MX71U;2(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP
M:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T
M<B`BR7)T97/M=.ES(&$@:^EZ8F5S[71E='0@;&5VZ6P@<V]R<^%R\VPB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$:FEB;W5T:2(*;7-G<W1R(")$>G-I8G5T:2(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S
M='(@(DYE('3V<O9L:OQK(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<"(*;7-G<W1R(")!(&UA:6YT96YA;F-E+G!H<"!N96T@Z7)H973U(&5L
M(&OV>G9E=&QE;OQL+B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(D%Z(&5L<_4@<V]R(&$@;65Z
M]6L@;F5V96ET('1A<G1A;&UA>GIA/R!(82!I9V5N+"!J96SV;&IE(&MI(&5Z
M=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEK82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK86D@2_9Z=.%R
M<V%SX6<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED
M(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(DYI
M;F-S(&WI9R!L;V=I;B!N979E/R!)9^EN>65L:F5N(&5G>65T+B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3(*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(DQE=/9L=.ES(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*
M;7-G<W1R(")4]FQT<_QK(&QE("5S+70B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")4]FQT<_QK(&QE(%!(4"!P
M<F]G<F%M(&9O<FWA:N%B86X@87H@96QKZ7-Z_&QT(&MO;F9I9W5RX6-I\W0N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@9&]W
M;B!L:7-T(@IM<V=S='(@(DQE9_9R9/QL]2!L:7-T82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B2^%B[73S
M<WIE<F5K(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")%+4UA:6PB"FUS9W-T<B`B96UA:6PB"@HC.B!L:6(O3F5T+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92XB"FUS9W-T<B`B(@HB16UA:6QB]6P@4TU3+6O\;&3U(&UE9VAA:G3S+"!H
M82!A('1E;&5F;VYTX7)S87/A9R!B:7IT;W/M=&IA(&5Z="!A("(*(G-Z;VQG
MX6QT873A<W0N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B2$E"02(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O<B(*"B,Z(&QI8B](;W)D92]0
M97)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,@IM<V=I9"`B161I="(*;7-G<W1R(")-\V1O<^UTX7,B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S
M='(@(D)L;VMK(&WS9&]S[73A<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(D-S;W!O<G0@;?-D;W/M=.%S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I
M="!097)M:7-S:6]N(@IM<V=S='(@(DIO9V]S=6QT<^%G(&WS9&]S[73A<R(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B2F]G;W-U;'1SX6=O:R!M\V1O<^UTX7-A
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E
M<R!J;V=O<W5L='/A9V%I;F%K(&WS9&]S[73A<V$B"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R(")-96QY:6L@;W!C:?-K870@=N%L=&]Z=&%S<W5K.B(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@:F]G
M;W-U;'1SX6=A:6YA:R!M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!J;V=O<W5L='/A9V%I;F%K(&WS
M9&]S[73A<V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@
M(D5D=6-A=&EO;B(*;7-G<W1R(")/:W1A=.%S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS
M9W-T<B`B16=Y:7!T;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@
M(E-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@
M(D5L96TN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B87H@)VTG(&)E=/L@<WKI
M;&5S<^EG92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<S(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")%;6%I;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D
M<F5S<R(*;7-G<W1R(")%;6%I;"!C[6TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DV-PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(D%Z(&5M86EL(&/M;65K;F5K(&5G>65Z;FG\:R!K96QL+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3DS"FUS9VED(")%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;B(*;7-G<W1R(")%;6%I;"!V:7-S>F%I9V%Z;VSA<W-A;"(*
M"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M
M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D5M86EL+5--4R#A=&KA<O,B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS
M9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B2&%N9W5L871I:V]N;VLB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`BW')E<R#\>F5N970N(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B3FEN8W,@
M:6QY96XN(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS
M9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5/9R]FQJ_&L@:VD@
M82!K97)E<^ES96ME="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*
M;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(D5N9V5D:OQK(&UE9RP@:&]G
M>2!KZ7!E:V5T(&EL;&5S<WK\;FL@82!S>O9V96=B92!A($9O=/-G86SI<FGA
M:V+S;#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("),96=Y
M96X@:F]B8B!E9^ER9V]M8F)A;"!E;.ER:&5T]2P@:V]N=&5X='5S9OQG9_4@
M;65N_#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B07H@=71O
M;'/S(.EV(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`BP71VX6QT
MX7,@:_QL]FX@86)L86MR82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@
M>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B
M"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E
M=#\G.B(*;7-G<W1R("(B"B)!9&IA(&UE9R!A>G0@82!B:7IT;VYSX6=I(&OI
M<F3I<W0L(&%M96QY<F4@;6%J9"!VX6QA<WIO;&YI82!K96QL(&IE;'-Z87;A
M;F%K("(*(N%TX6QL[73A<^%H;WHL('!L+B`G:&]G>2!H[79JX6L@82!K=71Y
MX6KA=#\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%52
M3"!H97)E(@IM<V=S='(@(D%D:F$@;65G(&$@:^EP(%523"UJZ70@:71T(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,@IM<V=I
M9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(LUR:F$@8F4@
M87H@86SA8F)I(&)E=/MK970Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B
M"FUS9W-T<B`B16=Y96YL[73U:2U'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(D5R:71R96$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R;W(B"FUS9W-T
M<B`B2&EB82(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G
M<W1R(")(:6)A('3V<G3I;G0@82!B;&]K:R!LZ71R96AO>N%S86MO<CH@)7,B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B2&EB82!T]G)TZ6YT(&%Z(&%D871S>FEN:W)O;FEZX6-I\W,@:F5L
M('3V<FSI<V5K;W(Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN
M8R!L;V<Z("5S(@IM<V=S='(@(D%Z(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P
M;//A;&QO;>%N>2!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!L:6(O
M2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN
M="!A>B!A9&%T;&5KZ7+I<V)E;CH@)7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D
M871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(DAI8F$@=/9R=.EN="!A(&IE
M;'-Z\R!M96=VX6QT;WIT873A<V%K;W(Z("5S(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92XB"FUS9W-T<B`B2&EB82!A>B!E;6%I;"#\>F5N971B96XN
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@
M7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B#A;&QO;>%N>7)A(&YE;2!S
M:6ME<OQL="#M<FYI+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`BR7-Z=&]R
M<WKA9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:?-P:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R
M(").96UZ971I<^EG96LB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<O-P82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`B,34@<&5R8V5N:^EN="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("(R('!E<F-E
M;FOI;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS
M9W-T<B`B,S`@;>%S;V1P97)C96YKZ6YT(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%
M=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B-2!P97)C96YKZ6YT(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB
M"FUS9W-T<B`B;6EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS
M9W-T<B`B9NEL\W+A;FOI;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI
M;G5T92(*;7-G<W1R(")P97)C96YKZ6YT(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")0Z6QD82#I<G3I:V5K.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM
M<V=I9"`B17AE8W5T92(*;7-G<W1R(")6Z6=R96AA:G3A<R(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A
M;F0B"FUS9W-T<B`B3GEI<W-U:R!S>NET(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T
M<B`B2F5L96[M='/\:R!M96<@87H@;VQD86QS\R!M96[\="(*"B,Z(&QI8B](
M;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG
M(@IM<V=S='(@(DET="`G*2<@:V5L;&5N92!K]G9E=&ME>GIE;B(*"B,Z(&QI
M8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"B))
M='0@8W-U<&%S>B!S>O-N86L@=F%G>2!I9.EZ]6IE;&)E;B!L97;U(&ME<F5S
MZ7-I(&MI9F5J97KI<VYE:R!K96QL96YE(&QE;FYI92(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM
M<V=S='(@(D%Z(.ER=NEN>65S<^EG(&QE:N%R871A(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(DMI=&5V]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E-Z[6XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L
M;V%D(&]F('-E='5P(@IM<V=S='(@(D$@:V]N9FEG=7+A8VGS($944"UN(.%T
M('9A;/,@9F5L=/9L=.ES92(*"B,Z(&QI8B](;W)D92]0<F5F<R]S<6PN<&AP
M.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM
M<V=S='(@(D$@<WIE;>EL>65S(&)EX6QL[73A<V]K870@;F5M('-I:V5R_&QT
M(&)E;VQV87-N:2XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S4@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")!>B!,1$%0('-Z97)V
M97(@;F5M(.ER:&5T]2!E;"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(")!>B!334(@<WIE<G9E<B!N96T@Z7)H973U(&5L+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A
M*'HI(%PB)7-<(BUB]6P@=/9R=.EN]2!MX7-O;.%S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R(").96T@<VEK97+\;'0@82AZ*2!<(B5S
M7"(M8F4@=/9R=.EN]2!MX7-O;.%S+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A
M<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(DYE;2!S:6ME<OQL="#Z:B!305-,(&MA<&-S
M;VQA=&]T(&SI=')E:&]Z;FDN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4P,2!L
M:6(O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3F5M('-I:V5R_&QT(&$H
M>BD@7"(E<UPB+6)E('3V<G3I;O4@X71H96QY97KI<RXB"@HC.B!L:6(O5D93
M+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R
M971R:65V93H@)7,B"FUS9W-T<B`BP6QL;VWA;GEH;WIZX6;I<NES:2!H:6)A
M.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$X"FUS9VED(")&86ER(@IM<V=S='(@(E1I<WIT82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9"US>FEG
M971E:R`H36%L=FEN87,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R
M(")&87)O92US>FEG971E:R(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM
M<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(DAE;'ER96AO>FAA=&%T;&%N
M(&AI8F$Z(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&87@B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A
M<GDB"FUS9W-T<B`B9F5B<G7A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(DCU;>ER<^EK;&5TZ7)Z
M970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED
M(")&965L<R!L:6ME.B`B"FUS9W-T<B`B2/5MZ7)SZ6ML973I<GIE=#H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G
M:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D5G>2UE9WD@>N%P;W(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B
M1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")3>O-R=N%N>6]S86X@:/-ZX7!O
M<F]K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD
M(&UA=')I>"(*;7-G<W1R(")-97KU(&WA=')I>"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,S(Y"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&
M:6=L970@0T%05$-(02`H8F5T^VMI<F%K\R!H=6WA;G1E<WIT*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,S,S"FUS9VED(")&:6=L970@9F]N="(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9'IS:2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R
M(")&X6IL(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!(&;A:FQO:R!S>N%M83H@
M)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")!(&;A:FQO:R!S>N%M83H@)7,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B1N%J;"!M96YE9'IS97(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D;A:FQNZ78B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDX,0IM<V=I9"`B1FEL92!S96QE8W1I;VXB
M"FUS9W-T<B`B1N%J;"!K:6IE;/9LZ7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30Y,`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B1N%J;"!F96QT
M]FQTZ7-E(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D;A:FQO:R!F
M96QT]FQTZ7-E(&YE;2!L96AE='/I9V5S+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")3>OMR]6LB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FYO<G-ZX6<B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@
M(F5L<_4@9NEL(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C
M:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")E
M;'/U(&YE9WEE9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")6X6QT;WIA=&QA
M;B!MZ7)E=&%RX6YY(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")4_&MR]GKI<R`H9O9L
M+VQE*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B
M"FUS9W-T<B`B2_9D(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C(S-R!L:6(O5D93
M+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B5S(&UA<'!A(&YE;2!LZ71E>FEK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")"973[<WKM;B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R("+)
M=&5L96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(D]L>6%N(&+V;F?I<WKU:R!S
M>N%MX7)A+"!A;6EK(&YE;2!J96QE;NUT:6L@;65G(&$@:^EP96ME="(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")%;/5R96IE;'KI<R`H<F5P_&SU=.ER:2DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB07H@
M96SU<F5J96QZZ7,@:63U=&%R=&%M82!N87!O:V)A;B`H87H@96SU<F5J96QZ
MZ7,@;F%P<&%L:2#I<R#I:G-Z86MA:2`B"B)A9&%T;VMA="!T87)T86QM87HL
M(&5ZZ7)T(&$@;F%G>2!S>N%M;VL@<WKI;&5S(&)L;VMK;W0@97)E9&WI;GEE
M>FYE:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I
M9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(D5L9F5L96IT971T
M92!A(&IE;'-Z87;A=#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R("+;<FQA<&ME>F5LZ7,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T
M<B`B263I>F5T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B263I>F5T(&9A:G3A:F$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S
M='(@(DEDZ7IE=&5K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS
M9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(DEDZ7IE=&5K(#(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T
M<B`B1O-R=6UO:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3$*
M;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E1O=N%B8NUTX7-O:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@
M(D9R(@IM<V=S='(@(E#I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(D9R86UE+65K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E(@IM<V=S='(@(D9R86YC:6%O<G-Z
MX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I86]R<WKA9R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;F-I82!'=7EA;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N8VEA(%!O;&EN
MZ7II82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM
M<V=S='(@(D9R86YC:6$@1.EL:2!497+\;&5T96LB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R
M(")&96QA9/,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S
M='(@(DERX6YY.B`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")2Z7-Z;&5T
M97,@;&7M<N%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")T96QI
M:&]L9"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS
M9W-T<B`B5&5L:F5S(&[I=B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;2(*;7-G<W1R(")-96QY:6L@9V%LZ7)IX6+S;"!V96=Y_&L@82!KZ7!E="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B2^EP9V%LZ7)I
M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(DAO>GIU:R!LZ71R92!A
M*'HI("5S(&MO;F9I9W5RX6-I\VKA="(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G
M<W1R(")!(&ME;&5T:V5Z971T(&OS9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B1W+Z>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(").Z6UE=&]R<WKA
M9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=HX6YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(D=I8G)A;'3A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DME<F5S
M>G1NZ78B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")';&]B
MX6QI<R!B9>%L;.UTX7-O:R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$W"FUS9VED(")';R(*;7-G<W1R(")-96AE="(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D?V9&5L(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G
M:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!TZ7)KZ7`B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H
M(@IM<V=S='(@(D=O;V=L92!K97)E<^ES(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S
M='(@(D9E:V5T92]F96CI<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1_9R
M]F=O<G-ZX6<B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(F?V<O9G("A)4T\M.#@U.2TW
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<O9N;&%N9"(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")#
M<V]P;W)T(&%D;6EN:7-Z='+A8VGS(@H*(SH@;&EB+TAO<F1E+T=R;W5P+G!H
M<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")!(&-S;W!O<G1N
MZ78@;6%R861H870@_')E<V5N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N
M<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!H;WIZX6%D
MX7-A(&YE;2!S:6ME<OQL="X@02!S>F5R=F5R(';A;&%S>F$Z("(*"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,3@@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C$R-`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@)7,@8W-O<&]R="!T
M]G)LZ7-E(&YE;2!S:6ME<OQL="(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z("5S(&-S;W!O<G0@861A=&%I
M;F%K(&UE9_IJ[73A<V$@;F5M('-I:V5R_&QT(@H*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G
M<W1R(")#<V]P;W)T;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U
M861E;&]U<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N
M<V5Y(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B5F5N9.EG(&IO9V]S=6QT<^%G;VLB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B
M5F5N9.EG:_9N>78B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D)I<W-A=2U'=6EN96$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.38T"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R(")(5$U,07)E82!G>>%V87/A
M9V+S;"!N96T@:&%J;&%N9/,@82!S;W(@=71O;'/S(&-E;&SA:N%T('3V<O9L
M;FDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(
M5$U,07)E82!G>>%V87/A9V+S;"!N96T@:&%J;&%N9/,@82!TX6)LX7IA="!U
M=&]L<_,@;W-Z;&]PX70@=/9R]FQN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL
M86YD\R!A('3A8FSA>F%T('5T;VQS\R!S;W+A="!T]G+V;&YI+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT
M:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D$@2%144"!F96QH87-Z;N%L
M\V%Z;VYO<^UTX7,@;F5M('1A;.%L:&%T\RXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM
M<V=S='(@(DAA:71I(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")(87-H(&%L9V]R:71M
M=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")+]F0B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.3(S(&QI8B](;W)D92]&;W)M+G!H<#HR.3$X"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B1F5J;.EC(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B1F5J;.EC
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B
M"FUS9W-T<B`B2&5A<F0M(.ES($UC1&]N86QD+7-Z:6=E=&5K(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE
M879Y(%0M4W1O<FTB"FUS9W-T<B`B17+U<R!Z:79A=&%R(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)
M*2(*;7-G<W1R(")HZ6)E<B`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@
M(DAE:6=H="(*;7-G<W1R(")-86=A<W/A9R(*"B,Z(&QI8B](;W)D92](96QP
M+G!H<#HQ.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM
M<V=I9"`B2&5L<"(*;7-G<W1R(")396?M='/I9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I
M;F<@961I=&]R(@IM<V=S='(@(E-E9^UT<^EG(&$@<WIE<FME<WIT]2!H87-Z
M;N%L873A:&]Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S4*;7-G:60@
M(DAE;'!E<B(*;7-G<W1R(")396?M='/I9R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")&Z6QT96ME(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B17H@82!FX6IL(&5L96IE.B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED
M(")(:6=H(@IM<V=S='(@(FYA9WDB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE
M;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*
M;7-G:60@(DAO7VUE(@IM<V=S='(@(DME>F3U;&%P(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5F%T:6OA;G;A
M<F]S(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED(")(;VUE(@IM<V=S
M='(@(DME>F3U;&%P(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")/='1H;VYI(&/M;2(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O
M<GDB"FUS9W-T<B`B4WIE;>EL>65S(&%L:_9N>79TX7(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R(")/='1H;VYI('1E;&5F;VXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S
M(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T
M<B`B2&]N9VMO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*
M;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@:&EBX7,@)7,@6$U,(&%D870@=F%N
M(&$H>BD@)7,@_'IE;F5T8F5N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!N:6YC<R!A*'HI("5S(&]B:F5K='5M;F%K(&UE9V9E;&5L]2#\>F5N
M970B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U
M;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@;FEN8W,@
M)7,@=.UP=7/Z(&]B:F5K='5M(&$H>BD@)7,@_'IE;F5T8F5N(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z(%-I:V5R97-E;B!T]G+V;'3\:R!E>G0Z("5S
M(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S"FUS9VED(")(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@87H@:6YT96=RX6SS('!R;V=R86UH;WH@<WK\:W/I9V5S(&$@)V1O;7AM
M;"<@4$A0(&+U=NUTZ7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C4Q,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@;F5M('-I:V5R_&QT(/IJ(%A-3"!FX70@;.ET<F5H;WIN:2!A
M*'HI("5S(&]B:F5K='5M:&]Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,C0X"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($YE;2!S:6ME<OQL="!T]G+V;&YI("5S+70@7"(E<UPB.B`E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@;F5M
M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A($U)344@240M:N%T(&$@:_9V971K
M97KU('3M<'5S^B`B"B)M96QLZ6ML971N96LZ("5S(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT('-Z:6YK<F]N:7KA;&YI
M("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B
M.B!.96T@<VEK97+\;'0@82!K]G9E=&ME>O4@:_9Z]G,@=.%R=&5R_&QE="!S
M>FEN:W)O;FEZX6SA<V$Z("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HS
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!I<VUE<F5T;&5N
M(&OV>O9S('3A<G1E<OQL970@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2
M=6QE(@IM<V=S='(@(E;M>G-Z:6YT97,@=F]N86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N
M=&%L('!A9&1I;F<B"FUS9W-T<B`B5NUZ<WII;G1E<R!M87)G\R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@
M(DAO<FEZ;VYT86PZ(@IM<V=S='(@(E;M>G-Z:6YT97,Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q"FUS
M9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*2(*
M;7-G<W1R(")(;V=Y(&IU=&]T="!I9&4_("A+Z7)J_&L@[7)J82!M96<A*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(DCA;GD@;W-Z;&]P;W0@:^UVX6X@]G-S>F5O
M;'9A<WIT86YI/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`B2.%N>2!M97KU("AO<WIL;W`I('9A;C\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED
M(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R(")(X6YY('-O<G0@:^UVX6X@]G-S>F5O;'9A<WIT86YI/R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,S<*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E#A<F%T87)T86QO
M;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@
M(DAU;6ED:71Y.B`B"FUS9W-T<B`B4.%R871A<G1A;&]M.B`B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R
M(")(=6UO<FES=.%K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DUA9WEA
M<F]R<WKA9R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
M07H@24U!4"!L97;I;&SA9&$@;.ET<F5H;WKA<V$@;F5M('-I:V5R_&QT.B`E
M<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B07H@24U!
M4"!L97;I;&SA9&$@=/9R;.ES92!N96T@<VEK97+\;'0Z("5S(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S
M<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")!>B!)34%0(&QE
M=NEL;.%DX6AO>B!T87)T;WKS(&MV\W1A(&SI=')E:&]ZX7-A(&YE;2!S:6ME
M<OQL=#H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,R,`IM<V=I9"`B
M25`@061D<F5S<R(*;7-G<W1R("))4"!C[6TB"@HC.B!L:6(O2&]R9&4O075T
M:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")!>B!)4"!C[6T@;F5M(&AA=.%R;WIH873S(&UE9RXB
M"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T
M<B`B07H@25`@8^UM(&YI;F-S(&$@;65G96YG961E='0@0TE$4B!T87)T;VWA
M;GEB86XN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B5&EL
M=&]T="]M96=VX6QT;WIO='0@25`@8^UM+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N
M<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(E-O<B!B96EL;&5S>G3I<V4@96;V
M;.DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27IL86YD(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G
M<W1R(")C<V%K(&EK;VYO:R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B
M)7,@:6MO;FIA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G
M:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")I:V]N;VL@Z7,@<WKV=F5G
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R(")!>B!A>F]N;W/M=/-H;WH@=N%L87-Z=&]T
M="!E;&YE=F5ZZ7,Z(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP
M.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA
M>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N
M(@IM<V=S='(@(DAA(&$@;65G:F5L96[M=.ES(&YE;2!M96=F96QE;/4L("5S
M(&5G>2#Z:B!A8FQA:V)A;B!V86SS(&UE9VYY:73A<VAO>BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@
M<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA
M>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(DAA(-9N($EN=&5R;F5T($5X<&QO
M<F5R="!H87-Z;N%L+"#I<R!N96T@:F5L96YN96L@;65G(&%Z(&EK;VYO:RP@
M86MK;W(@(@HB=N%L87-S>F$@97IT(&%Z(&]P8VGS="P@;65L;'EE;"!K:6MA
M<&-S;VQJ82!A(%!.1R!KZ7!E:R!T<F%N<WIP87)E;F-IX6KA="XB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2&$@;.%T:F$@97IT(&$@
M<WKV=F5G970L(&1E(&$@:^EP970@;F5M+"!A:VMO<B!B]FYGZ7-Z]7!R;V=R
M86UJ82!N96T@:^EP97,@(@HB;65G:F5L96[M=&5N:2!A('-Z97)V97)R92!K
M_&QD96YD]2!KZ7!E="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I
M97<Z(@IM<V=S='(@(D5L]7IE=&5S(&[I>F5T.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM
M86=E(%523"(*;7-G<W1R(")!(&OI<"!54DPM:F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B02!KZ7`@55),+6IE.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DUE;'EI
M:R!G86SI<FGA8O-L('9A;B!A(&OI<"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R(")+Z7`@96)B]6P@82!G86SI<FGA
M8O-L.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`B2^EP(&9E;'3V;'3I<V4B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DOI<&5K
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP;W)TX6SA
M<RP@)60N(&SI<.ES(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM
M<V=S='(@(D%Z(&EM<&]R=.%L="!M97KU.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B07H@:6UP;W)TX6QT(&UE>O5K.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?
M<V5R="!2;W<@069T97(B"FUS9W-T<B`B4V]R(&)E:6QL97-Z=.ES92!E>F%L
MX2(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")(:6+A<R!P
M87)A;F-S<&%R86WI=&5R+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(DYE;2!M96=F96QE;/4@82!B96IE;&5N=&ME
M>NES:2!NZ78@Z7,O=F%G>2!A(&IE;'-Z\RXB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+B(*;7-G<W1R("(B"B).96T@;65G9F5L96SU(&$@9F5L:&%S>F[A;/-I(&[I
M=B!V86=Y(&%Z(&%L=&5R;F%T[78@8^UM+B!0<O-BX6QJ82#Z:G)A('9A9WD@
M(@HB9F]R9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BP@:&$@=&]VX6)B:2!S
M96?M='/I9W)E('9A;B!S>OQK<^EG92XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!);F1E
M;G0B"FUS9W-T<B`B0F5K97IDZ7,@8F5L:F5B8B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B
M"FUS9W-T<B`B26YD:6$B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I
M9'5A;"!5<V5R<R(*;7-G<W1R(")%9WEE<R!F96QH87-Z;N%L\VLB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;NEZ:6$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G
M<W1R("));F9O<FWA8VGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)MX6-I\R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(D%Z(&EN
M9F]R;>%C:?,@;>%R(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(D]S>FQO<"!B
M97-Z^G+A<V$@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA
M9V4B"FUS9W-T<B`B2^EP(&)E:6QL97-Z=.ES92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!4
M86)L92(*;7-G<W1R(")4X6)LX7IA="!B96EL;&5S>G3I<V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("))
M;G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B3&EN:R!LZ71R96AO>N%S82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(D]S
M>FQO<"!B97-Z^G+A<V$@97IE;.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D]S
M>FQO<"!B97-Z^G+A<V$@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M3W-Z;&]P(&)E<WKZ<N%S82!E>F5LZ2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V]R
M(&)E<WKZ<N%S82!E>F%LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E-O<B!B97-Z
M^G+A<V$@96;V;.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(D)E:V5Z9.ES(&)E
M:6QL97-Z=.ES92!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")"96ME
M>F3I<R!B96EL;&5S>G3I<V4@97IE;.DB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R(")(;WIZ=6YK(&SI=')E(&%L=&5R;F%T[78@<V%B;&]N="(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R(")!9&IO;B!M96<@96=Y(&5M86EL(&/M;65T+"!M
M96QY<F4@96QK_&QD:&5T]2!A>B#6;B#Z:B!J96QS>F%V83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS
M9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")#96QL82!B96EL;&5S
M>G3I<V4@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E
M(@IM<V=S='(@(D-E;&QA(&)E:6QL97-Z=.ES92!E>F5LZ2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G
M:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B3W-Z;&]P(&)E<WKZ
M<N%S82!E>G5TX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R
M92(*;7-G<W1R(")/<WIL;W`@8F5S>OIRX7-A(&5Z96SI(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4P(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S
M='(@(DQE=F5L96L@8F5MX7-O;.%S82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T
M('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")"96ME>F3I<R!B96EL;&5S>G3I
M<V4@97IU=.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R(")"96ME>F3I<R!B96EL;&5S>G3I<V4@97IE;.DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E-O<B!B97-Z
M^G+A<V$@97IA;.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*
M;7-G<W1R(")3;W(@8F5S>OIRX7-A(&5F]FSI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")!9&IA(&UE
M9R!A(&OM=N%N="!VX6QA<WIT(&$@8FEZ=&]N<^%G:2!KZ7)DZ7-R93HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS
M9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DOI<"!B96EL;&5S
M>G3I<V4O;?-D;W/M=.%S82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*
M;7-G<W1R("),:6YK(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B02!S>N%M;.%JX6X@;FEN8W,@96SI9R!F961E>F5T(/QZ
M96YE=&5T(&O\;&1E;FD@82!K]G)L97;I;&QI<W3A<F$N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I
M96YT(&-R961I="XB"FUS9W-T<B`B02!S>N%M;.%JX6X@;FEN8W,@96SI9R!F
M961E>F5T+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<Y"FUS9VED("))
M;G1E9V5R(@IM<V=S='(@(D5GZ7-Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")%9^ES>B!S>N%M
M;VL@;&ES=.%J82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@541(("A5<V5R($1A
M=&$@2&5A9&5R*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ
M-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T
M82(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@6DE0('3V;?9R[73I
M<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L
M:60@87!P;&EC871I;VXN(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA
M;B!A;&MA;&UA>N%S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")(
M:6+A<R]E;&9O9V%D:&%T871L86X@8F%T8V@@87IO;F]S[73S+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,#DQ(&QI8B](;W)D92]&;W)M+G!H<#HR,38R
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C,V"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S`S(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS
M9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R(")!(&O\;&3V
M='0@861A="!H:6+A<R]E;&9O9V%D:&%T871L86XN(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T
M;&%N(&/M;7KI<RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ
M,#D@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O
M<FUA="(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@9N%J;"!F;W)M
MX71U;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G
M:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DAI8N%S+V5L9F]G
M861H871A=&QA;B!L:6-E;G-Z:W5L8W,N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`B2&EBX7,O96QF;V=A9&AA=&%T;&%N(';A<F]S+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED
M("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T
M871L86X@_'IE;F5T=.UP=7,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?
M:60N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!V86=Y(&AIX6YY
M>O,@<')O9W)A;6]ZX7-I9F5L_&QE="UA>F]N;W/M=/,N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D
M:&%T871L86X@<&%R86WI=&5R96LN(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")(:6+A<R!A>B!O8FIE:W1U;2!E;.ERZ7-I(&IO9V]S=6QT<^%G
M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED
M("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H
M871A=&QA;B!P87)T;F5R87IO;F]S[73S+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E
M+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T871L86X@=&5R;>EK:_-D+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED
M("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")(:6+A<R]E;&9O9V%D:&%T
M871L86X@<')O=&]K;VQL+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B2&EBX7,O96QF
M;V=A9&AA=&%T;&%N(&/M;7IE='0Z(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3`X,"!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-C,*;7-G:60@
M(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(DAI8N%S+V5L9F]G861H
M871A=&QA;B!M96=O<WIT;W1T(&]B:F5K='5M(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E
M(&%D9')E<W,N(@IM<V=S='(@(DAI8N%S+V5L9F]G861H871A=&QA;B!F96QA
M9/-I(&/M;2XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(DAI
M8N%S+V5L9F]G861H871A=&QA;B!U;FEC;V1E(&%D870N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S
M='(@(DYY:6QVX6YT87)TX7,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<X"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S
M='(@(D$@:VEJ96SV;.ES(&EN=F5R=.%LX7-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)
M<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DERX6YI($ES>FSA;2!+]GIT
MX7)S87/A9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<F5L86YD(@IM<V=S='(@(LUR;W)S>N%G(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B36%N
M+7-Z:6=E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")3>O-R
M=N%N>6]S('II=F%T87)O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DEZ
M<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED
M("))<W-U97(B"FUS9W-T<B`B02!T86[Z<^UT=N%N>2!K:6%D\VIA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED
M("))=&%L:6,B"FUS9W-T<B`B9/5L="(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T
M<B`B3VQA<WIO<G-ZX6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M
M86EC82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED
M(")*86YU87)Y(@IM<V=S='(@(FIA;G7A<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS
M9W-T<B`B2F%PX6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")J87#A;B`H25-/
M+3(P,C(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I
M9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM
M<V=S='(@(DIO<F3A;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B:OIL:75S(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-R!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B
M:OIN:75S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")3;W)K:7KA
M<N%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(FOV
M>NEP<F4@<F5N9&5ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM
M<V=S='(@(G-O<FMI>N%RX7,@;6EN9&OI="!O;&1A;')A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G
M:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")S;W)K:7KA<N%S(&)A;')A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B<V]R:VEZX7+A
M<R!J;V)B<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86AS
M>G3A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-C4*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E1A<G1S=6L@;65G
M(&%Z(&5R961E=&ET/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N>6$B
M"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!
M(&ME<F)E<F]S('-Z97)V97(@96QU=&%S[71O='1A(&$@9F5L:&%S>F[A;/-A
M>F]N;W/M=.%S="XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G
M:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME>F3U(&ME<FYE;&9E:FQE
M<WIT]6LB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@
M(DME>2!#<F5A=&EO;B(*;7-G<W1R(")+=6QC<R!LZ71R96AO>N%S82(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E
M<G!R:6YT(@IM<V=S='(@(D$@:W5L8W,@;&5N>6]M871A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S
M='(@(DMU;&-S:&]S<WKZ<^%G(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")+=6QC<R!T[7!U<R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@
M57-A9V4B"FUS9W-T<B`B02!K=6QC<R!H87-Z;N%L871A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D$@:W5L8W,@
M;>%R(&SI=&5Z:6L@82!N>6EL=N%N;W,@:W5L8W-S>F5R=F5R96XN(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@
M(D=Y97)E:V5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T
M:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B2V]R96%I($[I<&D@1&5M;VMR871I:W5S($OV>G3A
M<G-A<^%G(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M2V]R96%I($OV>G3A<G-A<^%G(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")K;W)E86D@*$55
M0RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=79A:70B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VEZ:7-Z=.%N(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S
M='(@(E]497)V97KI<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DYY96QV(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S
M>FD@3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B=71O
M;'/S(&;I;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B
M3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B07H@=71O;'/S(&IE;'-Z
M\W;A;'3A<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")U=&]L
M<_,@;F5G>65D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@
M(DQA<W0@57!D871E9#HB"FUS9W-T<B`B571O;'/S(';A;'1O>G1A=.%S.B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`B571O;'/S(&)E:F5L96YT:V5Z
MZ7,Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E5T
M;VQS\R!B96IE;&5N=&ME>NES.B`E<RP@)7,@8^UM<O5L(@H*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS
M9W-T<B`B571O;'/S(&)E:F5L96YT:V5ZZ7,Z(&WI9R!S;VAA(&YE;2!V;VQT
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&5T=&]R<WKA9R(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(DIO
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D5L:&5L>65ZZ7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS
M9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DAA9WEJ
M82#\<F5S96XL(&AA(&YE;2!A:V%R(&ME<F5T970B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N
M;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R
M(")B86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-0IM<V=I9"`B3&5F
M="!H96%D97(B"FUS9W-T<B`B0F%L(&]L9&%L:2!F96ILZ6,B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T
M<B`B0F%L(&]L9&%L:2#I<G3I:V5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S
M='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(E-Z:6YT(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E
M<FEA(@IM<V=S='(@(DQI8NER:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA
M;6%H:7)I>6$B"FUS9W-T<B`B3.UB:6%I($%R86(@4WIO8VEA;&ES=&$@3F%G
M>2!.Z7!I($OV>O9S<^EG(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S
M='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M(")'>65N9V4@<WII=.%L\R!E<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R
M(")'>65N9V4@97/U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B
M1.EL96SU='0@9WEE;F=E(&5S]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS
M9W-T<B`B1.EL=73A;B]E<W1E(&=Y96YG92!E<_4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I
M;B!3:&]W97(B"FUS9W-T<B`B1WEE;F=E('KA<&]R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A
M:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(D=Y96YG92!Z:79A=&%R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@
M(DQI9VAT(%-N;W<B"FUS9W-T<B`B1WEE;F=E(&AA=F%ZX7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B1WEE;F=E(&CS>N%P;W(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK
M(@IM<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O
M.B(*;7-G<W1R(")!(&QI;FL@:61E(&UU=&%T.B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(DUE
M9VIE;&5N[73I<VMO<B!M=71A<W-O;B!E9WD@;&EN:R!A(&QE=NEL8^UM<O5L
M(&$@;&5VZ6SM<O,@86)L86MH;WHB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI
M;FME:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN
M=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C0V(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M(@IM<V=S='(@(DQI<W3A>N%S("T@82!F96QH87-Z;N%L\R!LX71J82!A(&UA
M<'#A="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@
M1&%T86)A<V5S(@IM<V=S='(@(D%Z(&%D871BX7II<V]K(&QI<W3A:F$B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP
M(%1O<&EC<R(*;7-G<W1R(")!>F]K;F%K(&$@=.EMX6MN86L@82!L:7-TX6IA
M(&%M:7+U;"!S96?M='/I9R!K87!H873S(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B07H@861A='3A
M8FSA:R!L:7-TX6IA(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&$@87)C:.UV
M=6TB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R("),:7-T82!S96?M='/I9VOI<NES(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(DQI<W1A(&%Z;VYO<^UT\R(*"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),
M:7-T82!T=6QA:F1O;F]S(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B3&ES=&$@;&5VZ6SM
M<N%S(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED
M("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T82!F96QI<F%T:V]ZX7,@
M*'-U8G-C<FEB92DB"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU
M.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES=&$@;&5I
M<F%T:V]ZX7,@*'5N<W5B<V-R:6)E*2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B02!F96QH87-Z;N%L\VMA<&-S;VQA=&]K(&MI
M;&ES=.%ZX7-A(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S(@IM<V=S='(@(D$@9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A
M(&YE;2!S:6ME<OQL=#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(D$@9F5L:&%S>F[A;/-K(&MI;&ES=.%ZX7-A('1I;'1V82!V
M86XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E
M<F%T=7)E(@IM<V=S='(@(DER;V1A;&]M(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B
M"FUS9W-T<B`B3&ET=N%N:6$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),973V
M;'3I<RXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*
M;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")(96QY:2!I9/4Z("(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4
M:6UE(@IM<V=S='(@(DYY96QV+"!DX71U;2P@:63U(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")(96QY(@H*
M(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C`P('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O
M9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B07H@96SU>O4@861A
M='-Z:6YK<F]N:7KA8VGS(&YA<&SSX6QL;VWA;GEA(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R
M(")+:6IE;&5N=&ME>NES(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"FUS9VED("),;V=I;B(*;7-G<W1R(")"96IE;&5N=&ME>NES(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`B0F5J96QE;G1K97KI<W-E;"!K87!C<V]L871O<R!F96QA9&%T;VLB
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)!(&)E:F5L96YT:V5ZZ7,@
M;F5M('-I:V5R_&QT+"!M97)T(')O<W-Z(&9E;&AA<WINX6SS;F5V970@=F%G
M>2!J96QS>O-T(&%D;W1T("(*(FUE9RXB"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(D$@8F5J96QE
M;G1K97KI<R!N96T@<VEK97+\;'0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")(;W-S>OH@<WKV=F5G
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM
M<V=S='(@(E-Z97)E;&5M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R(")A;&%C<V]N>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B
M9_9R]F<@:VES8F5T^VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(FQA=&EN(&MI<V)E=/MK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")K:7-B973[<R!R\VUA
M:2!S>N%M;VLB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB
M=7)G(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS
M9W-T<B`B3F%P:2#\>F5N971E:R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A
M:6YE9"!N;R!D871A+B(*;7-G<W1R(")!>B!-4RU43D5&(&UE;&SI:VQE=&)E
M;B!N:6YC<R!A9&%T+B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(MQ:14Y%
M5"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B36%K8?,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R(")-86ME9/-N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B
M36%D86=A<WIKX7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G
M:60@(DUA9VEC(@IM<V=S='(@(E9A<N%Z<VQA="(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R("),979E;&5Z
MZ7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(D5M86EL(&1O;6%I;B!K97IE;.ES(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(DQI;FL@:^ES>NUT
MZ7-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-86QA>7-I82(*;7-G<W1R(")-86QA:GII82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV
M97,B"FUS9W-T<B`B36%L9.UV+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM
M<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DWA;'1A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+B(*;7-G<W1R("(B"B)!9&%T86ET(&MA=&5G\W)IX6MB82!S
M;W)O;&AA=&IA+B!%>F5K(&ET="!D969I;FGA;&AA=/-K+"!M\V1O<^UT:&%T
M\VLL("(*(G1O=N%B8N$@<WKM;F5K(')E;F1E;&AE=/5K(&AO>GKA:G5K+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS
M9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@=.ER:^EP(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U
M97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!TZ7)KZ7`B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E
M9"XB"FUS9W-T<B`B02!H;WIZX7)E;F1E;.ES96ME="!E;&UE;G1E='3\:RXB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R
M8V@B"FUS9W-T<B`B;>%R8VEU<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G
M<W1R(")-87)G\R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H
M<#HT."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")!>B!/;'9A
M<V]T="]/;'9A<V%T;&%N(&IE;'IE=&5K(&AA<WINX6QA=&$B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-X7,@:F5L
M>F5T96L@*'!L+B!&;VYT;W,O365G=N%L87-Z;VQT*2!H87-Z;N%L871A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL+7-Z
M:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ
M=64B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B
M36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D5G>6WA<VYA:R!M96=F96QE;/4@
M;65Z]6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FETX6YI
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-
M87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(DUA>&EMX6QI<R!R96YD96QK
M97KI<W)E(.%L;/,@<WKA;6QA]G-S>F5G+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"XB"FUS9W-T<B`B07H@_'IE;F5T('3Z;"!S;VL@<NES>F+U
M;"#A;&PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@(DUA
M>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")!>B!E;&WZ;'0@,C0@
M\W)A(&UA>&EMX6QI<R!H]6WI<G/I:VQE=&4Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*
M;7-G<W1R(")!>B!E;&WZ;'0@-B#S<F$@;6%X:6WA;&ES(&CU;>ER<^EK;&5T
M93H@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B07H@]G-S>F5G]6]L9&%L(&)L
M;VMK:F%I;F%K(&UA>&EMX6QI<R!S>N%M82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY,#(@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,C$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA
M>&EMX6QI<R!H;W-S>B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B;>%J=7,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO
M='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(D]R=F]S='5D;VWA;GDB
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED
M(")-96UB97)S(@IM<V=S='(@(E1A9V]K(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")!(&UE;OP@
M;65G:F5L96[I<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T
M<B`B0V5L;.%K(&5G>6)E;VQV87-Z=.%S82(*"B,Z(&QI8B](;W)D92].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B
MW'IE;F5T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G
M:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@
M<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("(B"B)!(&1I9VETX6QI<V%N(&%LX>UR="#\>F5N970@:&ET
M96QE<RP@9&4@87H@86SA[7+S('1A;OIS[71VX6YYX70@;F5M('-I:V5R_&QT
M("(*(F5L;&5N]7)I>FYI+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@
M(DQE:N%R="!A>B#\>F5N970@Z7)VZ6YY97-SZ6=E+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V
M,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(D%Z(/QZ96YE="!T[7!U
M<V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B365T87(@:63U:N%RX7-J96QE;G3I<R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D$@365T87(@8FQO:VL@;F5M(.%L;"!R96YD
M96QK97KI<W)E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"B)!($UE=&%R(&)L;VMK(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X@02!RZ7-Z
M;&5T96L@82!R96YD<WIE<F=A>F1A('-ZX6WA<F$@(@HB:^ES>OQL]2!N87!L
M\V;A:FQB82!K97+\;'1E:RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM
M<V=S='(@(D$@365T87)$0B!N96T@Z7)H973U(&5L+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B3?-D<WIE<B(*
M"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#
M+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(D$H>BD@7"(E<UPB(&WS9'-Z
M97(@9&5F:6YIX6QA=&QA;B(*"B,Z(&QI8B](;W)D92]24$,O<F5S="YP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")!(&WS9'-Z97(@9&5F:6YIX6QA
M=&QA;BX@02!M96=H[79O='0@;?-D<WIE<CH@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I:W5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI
M8V\B"FUS9W-T<B`B365X:6OS(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]NZ7II86D@4WKV=F5T<^EG
M:2#!;&QA;6]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B:_9ZZ7`B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DUI;64@5'EP92(*;7-G<W1R(")-24U%('3M<'5S(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R(")!>B!E;&WZ;'0@,C0@\W)A(&QE9V%L86-S;VYY86)B(&CU
M;>ER<^EK;&5T93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G
M:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(D%Z(&5L;?IL
M="`V(/-R82!L96=A;&%C<V]N>6%B8B!H]6WI<G/I:VQE=&4Z("(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-Z6<@;F5M
M('1E;'0@96P@82!M:6YI;>%L:7,@:63U(&$@:F5L<WKS(&UE9W;A;'1O>G1A
M=.%SX6AO>B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")4_&MR]GKI<R`H:F]B8B]B
M86PI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C
M96QL86YE;W5S(@IM<V=S='(@(E9E9WEE<R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(U,`IM
M<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G
M<W1R(")(:>%N>7II:R!A($A45%!?4F5Q=65S="!014%2(&-S;VUA9RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG
M(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I
M9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`B(@HB2V]N9FEG=7+A8VGS('-Z_&MSZ6=E<RX@17IT(&UO<W0@:V5L;"!L
MZ71R96AO>FYI82P@:&$@:&%S>F[A;&YI(&%K87)J82!A>B`B"B)A;&MA;&UA
M>N%S="XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")(:>%N>7II
M:R!A>B#\>F5N970@87IO;F]S[73S:F$N(@H*(SH@;&EB+TYE="]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B2&GA;GEZ:6L@82!-86EL
M(%!%05(@8W-O;6%G+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@
M(DAIX6YY>FEK(&$@9F5L:&%S>F[A;/-K87!C<V]L870@87IO;F]S[73S:F$@
M*'-E<W-I;VX@240I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DCI(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*
M;7-G<W1R("),979E;&5ZZ7,@;6]B:6QT96QE9F]N<O-L(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DUO9&5R
M871E(@IM<V=S='(@(DOV>F5P97,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R(")!(&WS9&]S[73A<R!DX71U;6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B07H@55),(&WS9&]S
M[73A<V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I
M9"`B36]D=6QU<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A
M+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A:2!+]GITX7)S87/A9R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N
M9V]L:6$B"FUS9W-T<B`B36]N9_-L:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4X.`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B2/-N87`@
MZ7,@Z78B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(FAA=F]N=&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R
M870B"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B
M"FUS9W-T<B`B2&]L9&;A>FES;VLB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y
M-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D
M("5D+B(*;7-G<W1R(")!("5D+B!S;W)B86X@=/9B8B!M97KU('9O;'0L(&UI
M;G0@82!VX7)T("5D+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O
M:VOS(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")4]F)B;GEI<F4@9&5R
M_&QT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B5/9B8FYY:7)E(&)O
M<G5L="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B5/9B8FYY:7)E(&YA
M<&]S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")V:6=Y_&L@;&4B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B
M36]V92!,969T(@IM<V=S='(@(G9I9WG\:R!B86QR82(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I
M9VAT(@IM<V=S='(@(G9I9WG\:R!J;V)B<F$B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G
M<W1R(")V:6=Y_&L@9O9L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(G9I9WG\
M:R!L92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I
M9"`B36]V92!U<"(*;7-G<W1R(")V:6=Y_&L@9O9L(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA
M;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.#@*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*
M;7-G<W1R(")4]F)B<WII;G3[(&QE9_9R9/QL]2!L:7-TX6LB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U.`IM<V=I9"`B375L
M=&EM87`@54L@;6%P(@IM<V=S='(@(DUU;'1I;6%P($YA9WDM0G)I=&%N;FEA
M('3I<FOI<"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B5/9B8G-Z]G+V<R!VX6QA<WIT
MX7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")-
M>2!!8V-O=6YT(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-I(&)EX6QL[73A<V]K
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O
M=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(D)E:F5L96YT:V5ZZ7-I(&%D871A
M:6TB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B4V%JX70@]G-S>F5G>O4@;VQD86QA;2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L
M($QA>6]U="(*;7-G<W1R(")386KA="#V<W-Z96=Z]2!O;&1A;&%M('1E<G9E
M>NES92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-:6%N;6%R(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G
M:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").14TL(&YE;2!E9WEE
M>F5M(&)E;&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R
M(").Z78B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M[6)I82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM
M<V=S='(@(DYE<.%L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(")(
M;VQL86YD:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`B2&]L;&%N9"!!;G1I;&SA:R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(").
M971S8V%P92!BX7II<RU54DPB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GEK:6%DX7-I:F]G*$-!*2UV:7-S
M>F%V;V[A<VD@55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@=&%N^G/M=';A;GEF96QH87-Z;N%LX7-I(&ERX6YY96QV(%523"(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S
M8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!T86[Z<^UT=N%N
M>6UE9_IJ[73A<VD@55),(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(DYE='-C87!E('1A;OIS[71VX6YY=FES<WIA=F]NX7-I(%523"(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!3
M4TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B3F5T<V-A<&4@4U-,('-Z97)V97)N
MZ78B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P
M92!T86[Z<^UT=N%N>2!M96=J96=Y>NES(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B3F5T<V-A<&4@=&%N^G/M=';A;GET[7!U<R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB"FUS
M9W-T<B`B2.%L\WIA="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R
M-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(G-O:&$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`BVFHM2V%L963S;FEA(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@
M(DYE=R!#871E9V]R>2(*;7-G<W1R("+::B!K871E9_-R:6$B"@HC.B!L:6(O
M2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O96UA:6QS+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@
M)7,B"FUS9W-T<B`BVFH@;&5VZ6P@)7,@8^UM<F4B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(OIJ:&]L9"(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@
M(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(MIJ(&9E;&AA<WIN
MX6SS;NEV("AO<&-I;V[A;&ES*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS
M9W-T<B`BVFHM6NEL86YD(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`BVFH@:F5L<WKS
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G
M<W1R(")!>B#Z:B!J96QS>O,@Z7)VZ6YY97-SZ6=E(&5K:V]R(&KA<B!L93H@
M)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED
M(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(")!(&UE9V%D
M;W1T(/IJ(&IE;'-Z879A:R!N96T@96=Y97IN96LN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I
M;F1O=R`H7V)L86YK*2(*;7-G<W1R("+::B!A8FQA:R`H_')E<RDB"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W
M<R(*;7-G<W1R(")([7)E:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B2.UR8W-O<&]R=&]K
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@
M(DYE>'0B"FUS9W-T<B`B2_9V971K97KU(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DOV=F5T:V5Z
M]2`T(&;A>FES(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C8@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R(")+]G9E=&ME>O4@;W!C:?-K(@H*(SH@;&EB+TAO<F1E+U5)+U!A
M9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(DOV=F5T:V5Z]3XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G
M:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(DYI9^ER:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R("+I:G-Z86MA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").96TB"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO
M(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E
M;F-E<R!F;W(N(@IM<V=S='(@(B(*(DYI;F-S(')E;F1E;&ME>NES<F4@X6QL
M\R!K;VYF:6=U<N%C:?,L(&%M:6AE>B!KZ7!E<W0@82!K_&SV;F)SZ6=E:V5T
M(&UE9R`B"B)L96AE=&YE(&UU=&%T;FDN(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B3FEN8W,@;&5H973U<^EG($E3
M3R#A;&QO;>%N>6]K(&SI=')E:&]ZX7/A<F$N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L
M871E+B(*;7-G<W1R(")(:>%N>7II:R!A(&OV=&5G96QT(&9E;&1O;&=O>N%S
M:&]Z('-Z_&MSZ6=E<R!M:6YT82`H8F%T8V@@=&5M<&QA=&4I+B(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")!
M(&OM=N%N="!H96QY96X@;FEN8W,@8FQO:VLB"@HC.B!L:6(O2&]R9&4O075T
M:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E
M9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B07H@34-!3"!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7-H;WH@;FEN8W,@;65G861V82!A(&YA<'3A
M<B!N979E+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(DYI;F-S(';A;'1O>N%S+B(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")%:&AE>B!A
M(&IO9V]S=6QT<^%G:&]Z(&YE;2!H;WIH873S(&SI=')E(&IO9V]S=6QT<^%G
M:2!A;&-S;W!O<G0N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E
M+G!H<#HU,#@@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(DAIX6YY;WIN86L@82!K;VYF:6=U<N%C:?-S
M(&%D871O:R`E<RUH97HN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@U-0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N(@IM<V=S='(@(D%Z($944"!61E,@;FEN8W,@:V]N9FEG=7+A
M;'9A+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R(")!>B!344P@5D93(&YI;F-S(&MO;F9I9W5RX6QV82XB"@HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM
M<V=S='(@(D%Z(%-13"U&:6QE(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@
M(DYO(&-R961I="!L969T+B(*;7-G<W1R(")!>B#6;B!S>N%M;.%JX6X@96QF
M;V=Y;W1T(&$@<F5N9&5L:V5ZZ7-R92#A;&SS(/9S<WIE9RXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T
M:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B3FEN8W,@8^UM>NES+B(*"B,Z
M(&QI8B](;W)D92]"<F]W<V5R+G!H<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L
M;V%D960B"FUS9W-T<B`B02!S>F5R=F5R<F4@;F5M('3V;'3U9/9T="!F96P@
M<V5M;6EL>65N(.%L;&]MX6YY(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B07H@:6MO;F]K
M(&YE;2!T86SA;&AA=/-K+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3,P"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM
M<V=S='(@(DYI;F-S(&UE9V%D=F$@82!H96QY+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(").:6YC<R!M96=A9'9A(&$@:&5L>2XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S
M86=E('-U<'!L:65D+B(*;7-G<W1R(")!>B#\>F5N970@_')E<RXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3FEN8W,@;65G861V82!A(&[I=BXB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED
M(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R(").:6YC<R!M96=A9'9A
M(&$@<WKA;2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@
M(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(").92!L96=Y96X@;65G
M8F]T<N%N:V]Z=&%T\R!I9.EZ970B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P
M+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI;F-S(&IE;'-Z\R!M96=A9'9A
M(&$@2%144"!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB"@HC
M.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(").:6YC<R!J96QS>O,@;65G861V82!A>B!)34%0(&%L87#Z(&9E;&AA<WIN
MX6SS:2!A>F]N;W/M=.%S:&]Z+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI;F-S(&IE;'-Z\R!M96=A
M9'9A(&$@2V5R8F5R;W,@86QA</H@9F5L:&%S>F[A;/-I(&%Z;VYO<^UTX7-H
M;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z-S<@;&EB+TAO<F1E
M+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z
M-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!,
M;V=I;B!A;&%P^B!F96QH87-Z;N%L\VD@87IO;F]S[73A<VAO>BXB"@HC.B!L
M:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!005-35T0@86QA</H@9F5L:&%S
M>F[A;/-I(&%Z;VYO<^UTX7-H;WHN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB
M+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEN8W,@:F5L<WKS(&UE9V%D=F$@
M87H@4TU"(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@HB3FEN8W,@;65G861V82!A>B!/<&5N4U-,
M('!R;V=R86T@96SI<NES:2#Z='9O;F%L82X@07H@3W!E;E-33"!P<F]G<F%M
M("(*(G-Z_&MSZ6=E<R!A(%!+0U,@,3(@861A=&]K(&ME>F5LZ7/I:&5Z+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@
M(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B3FEN8W,@^FH@8F5J96QE
M;G1K97KI<VD@:6?I;GDN(@H*(SH@;&EB+U9&4RYP:'`Z-S8V"FUS9VED(").
M;R!Q=6]T82!S970N(@IM<V=S='(@(DYI;F-S(&MV\W1A(&)EX6QL[71V82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").92!L96=Y96YE:R!V
M;VYA;&%K('-E:&]L+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R"FUS9VED
M(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R(").:6YC<R!D969I
M;FGA;'9A(&5L=N%L87-Z=/,@:V%R86MT97(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@
M<VED97,B"FUS9W-T<B`B3F4@;&5G>65N(&ME<F5T(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DYI;F-S
M(&EL>65N(&;A:FPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F
M;W(@8V%C:&4N(@IM<V=S='(@(DYI;F-S(&ED96EG;&5N97,@X6QL;VWA;GEO
M:R!TX7)O;.%SX7)A('-Z;VQGX6SS(&%L:_9N>79TX7(N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,2!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0@<V5N="XB"FUS9W-T<B`B2&GA;GEZ:6L@82!F96QH87-Z;N%L\V[I=B#I
M<R]V86=Y(&$@:F5L<WKS+B(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S
M='(@(D$@=FES<WIA:V%P;W1T(&%D871O:R!N96T@Z7)VZ6YY97,@6$U,(&%D
M871O:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").;R!V
M86QU97,B"FUS9W-T<B`B3FEN8W,@861A="(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(").:6YC<R!MZ6<@:V]N9FEG=7+A8VGS+"!G96YE<N%L:F]N(&5G
M>65T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYI;F-S(&WI9R!K;VYF:6=U
M<N%C:?-J82P@9V5N97+A;&IO;B!E9WEE="XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(FYI;F-S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I
M9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")N:6YC<R!M96=A9'9A
M("AL96=Y96X@86QA<.ER=&5L;65Z971T*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DR"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R
M(")N;W)D:6MU<R`H25-/+3@X-3DM,3`I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES
M;&%N9"(*;7-G<W1R(").;W)F;VQK+7-Z:6=E="(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BR7-Z86MI(&;I;'1E:V4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("+)<WIA:VDM
M36%R:6%N82US>FEG971E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO
M<G;I9VEA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G
M:60@(DYO="!!9G1E<B(*;7-G<W1R(").96T@:^ES]6)B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B3F5M(&MO<N%B8F%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT,34*
M;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").96T@86QK]FYY=G3A
M<B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(")!('!R;V=R86UN86L@97H@82!RZ7-Z
M92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS
M9W-T<B`B3FEN8W,@8F7A;&SM='9A(@H*(SH@;&EB+U9&4RYP:'`Z,3DS(&QI
M8B]61E,N<&AP.C(P."!L:6(O5D93+G!H<#HR,S0@;&EB+U9&4RYP:'`Z,C4R
M"B,Z(&QI8B]61E,N<&AP.C(V.2!L:6(O5D93+G!H<#HR.#4@;&EB+U9&4RYP
M:'`Z,S`Q(&QI8B]61E,N<&AP.C,Q-@HC.B!L:6(O5D93+G!H<#HS,S,@;&EB
M+U9&4RYP:'`Z,S8V(&QI8B]61E,N<&AP.C0R-B!L:6(O5D93+G!H<#HU,#4*
M(SH@;&EB+U9&4RYP:'`Z-3<T(&QI8B]61E,N<&AP.C4Y,2!L:6(O5D93+G!H
M<#HV-CD*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4@;&EB
M+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-S4@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYE;2!TX6UO9V%T;W1T
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(D9E;&IE9WEZZ7-E
M:R(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B
M3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYI;F-S(&+V
M;F?I<WIH973U(&%D870L('3I<FIE;B!V:7-S>F$N(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@
M(FYO=F5M8F5R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3`*;7-G:60@
M(DYU;6)E<B(*;7-G<W1R(")3>N%M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$T,CD*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(DMA
M<F%K=&5R96L@<WKA;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3W-Z;&]P;VL@
M<WKA;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B
M3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B4V]R;VL@<WKA;6$B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S
M(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L
M:7-T+B(*;7-G<W1R(")!(&OV<FQE=NEL;&ES=&$@;?-D;W/M=.%SX6AO>B!N
M96T@861O='0@;65G('-ZX6UO:V%T+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS
M9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT=6TB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS
M9W-T<B`B07H@;V)J96MT=6T@;.ET<F5H;WKS:F$B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMTX6QI<R!S
M>N%M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@
M(D]C=&]B97(B"FUS9W-T<B`B;VMT\V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B4WK[
M<NES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B
M3V9F:6-E(@IM<V=S='(@(DAI=F%T86PO;75N:V%H96QY(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P
M87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(D$@<NEG:2#I
M<R!A>B#Z:B!J96QS>O-N86L@:_QL]FYB]GIN:64@:V5L;"XB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R
M9"(*;7-G<W1R(")!('+I9VD@:F5L<WKS(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N(@IM<V=S='(@(D$@<NEG:2!J96QS>O,@;F5M(&UE9V9E;&5L]2XB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VWA;B(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B0W-A:R!A>B!)
M34%0('-Z97)V97)E:R!TX6UO9V%T:N%K(&$@;6%P<.%K(&UE9V]S>G3A<^%T
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B0W-A:R!M96=B;W1RX6YK;WIT
M873S(&EDZ7IE="!L96=Y96XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")#<V%K(&5G>2!E;6%I;"!C
M[6T@861H873S(&UE9RXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES
M=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D-S86L@82!T=6QA:F1O
M;F]S('9A9WD@82!R96YD<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA(&UE9R!E
M9WD@:_9Z]G,@(@HB=.%R=&5R_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E;.ER
MZ7-I(&IO9V]S=6QT<^%G86ET(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(DYY:7-S=6L@;65G(/IJ(&%B;&%K8F%N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D]P96Y34TP@:&EB83H@3F5M('-I
M:V5R_&QT(&MI;GEE<FYI(&%Z(&%D871O:V%T(&%Z(&%LX>UR="!3+TU)344@
M<NES>F+U;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(").>6ES<W5K(&UE9R!E>G0@82!C[6UE="!E
M9WD@^FH@86)L86MB86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B3W!E<N%C:?-S(')E
M;F1S>F5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM
M<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<&-I\VLB"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@8F7A
M;&SM=.%S86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B4V]R<WKA
M;6]S(&9E;'-O<F]LX7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(E-Z97)V97IE="(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A
M;FES871I;VYA;"!5;FET(@IM<V=S='(@(E-Z97)V97IE=&D@96=Y<^EG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI
M>FEN9R(*;7-G<W1R(")-=6YK87-Z97)V97KI<R(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP
M;&%T92(*;7-G<W1R(")!>B!A;&MA;&UA>N%S(&5R961E=&D@<V%B;&]N:F$B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B5S(&5R
M961E=&D@<V%B;&]N:F%I.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM
M<V=S='(@(D5G>>EB(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM
M<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B16=YZ6(@:6YF;W)M
MX6-I\R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@
M(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D$@='5L86ID;VYO<R!J;V=O
M<W5L='/A9V%I(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW.0IM<V=I
M9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D$@4$%-(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@X6QL(')E;F1E
M;&ME>NES<F4N(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ
M,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.CI-
M86EL(&%L<F5N9'-Z97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B4$=0
M(&1I9VETX6QI<R!A;.'M<N%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'
M4"UV96P@=&ET:V]S[71O='0@861A="(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'
M4"!N>6EL=N%N;W,@:W5L8W,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S
M='(@(E!'4"UV96P@86SA[7)T+W1I=&MO<^UT;W1T(&%D870B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(
M4"!K\V0B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")$
MZ6QU=.%N+V5S=&4@9WEE;F=E(&5S]2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!286EN(@IM<V=S='(@
M(D3I;'5TX6X@97/U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B1.EL=73A
M;B]E<W1E('KA<&]R;VLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(")$Z6QU=.%N
M+V5S=&4@:&%V87KA<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M1.EL=73A;B]E<W1E(&CS>N%P;W)O:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M1.EL=73A;B!N87!S_'3I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")$
MZ6QU=.%N+V5S=&4@>FEV871A<F]K(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS
M9W-T<B`B2&GA;GEZ:6L@82!03U-)6"!B]7;M=.ES(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G
M:60@(E!A9&1I;F<B"FUS9W-T<B`B8F5L<_4@;6%R9_,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A
M:VES=&%N(@IM<V=S='(@(E!A:VES>G3A;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM
M<V=S='(@(E!A;&%U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<WIT:6X@5&5R_&QE="`H;65G<WKA
M;&QT*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")0X7!U82#::BU'=6EN96$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")0
M87)T;'D@0VQO=61Y(@IM<V=S='(@(DWI<G/I:V5L=&5N(&)O<G5L="(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U
M"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")*96QS>O,B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")!(&IE;'-Z\W0@<VEK97)E<V5N
M(&UE9W;A;'1O>G1A='1U:RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(").
M96T@;65G9F5L96SU(&IE;'-Z\R(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU
M<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")!(%)!1$E54R!F96QH87-Z;N%L
M\V%Z;VYO<^UTX7-H;WH@:F5L<WKS('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B2F5L<WKS(&UE9V5R]7/M=.ES<V5L(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`B2F5L<WKS.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(DIE;'-Z\SH@(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#,X
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@
M(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")!(&IE;'-Z879A:VYA
M:R!E9WEE>FYI_&L@:V5L;"XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B0F5I;&QE<WITZ7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED
M(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")"96EL;&5S>G3A<R!A
M(';A9_-A<WIT86QR\VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(MIT=F]N86PB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R("+::B!F96QH87-Z;N%L\VYA:R!B96IE
M;&5N=&ME>F5T=&5K.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM
M<V=I9"`B4&5O<&QE(@IM<V=S='(@(D5M8F5R96LB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R(")S>N%Z86SI:R(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA
M;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B2V%R8F%N=&%R=.%S:2!F96QA9&%T
M;VL@=NEG<F5H86ITX7-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q
M,`IM<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO
M9VEN/R(*;7-G<W1R(")"96IE;&5N=&ME>NES:V]R(&AA:G1S=6L@=NEG<F4@
M82!K87)B86YT87)TX7-I(&9E;&%D871O:V%T/R(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(DIO
M9V]S=6QT<^%G(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B02AZ*2!<(B5S7"(@:F]G;W-U;'1SX6=O="!N96T@=/9R
M]FQT_&LN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`BUFYN96L@;FEN8W,@96AH97H@96QE9V5N
M9/4@:F]G;W-U;'1SX6=A(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(DIO9V]S=6QT<^%G;VLB"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D
M;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")*;V=O<W5L='/A9R!A9&UI;FES>G1RX6-I\R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS
M9W-T<B`B4WIE;>EL>65S(&%D871O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R
M(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0
M971S(@IM<V=S='(@(L%L;&%T:V5D=F5N8V5K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P
M:6YE<R(*;7-G<W1R(")&_&SV<"US>FEG971E:R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(D;I;GEKZ7!G86SI<FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(G!I>&5L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V
M"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(DOV>FAE;'EE:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*
M;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")+
M871T:6YT<V]N('9A;&%M96QY:6L@8V5L;.%R82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E
M;&5M96YT.B(*;7-G<W1R(")":7IT;W-A;B!T]G+V;&YI(&%K87)J82!E>G0@
M87H@96QE;65T.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")+
MZ7)E;2!E<O5S[71S92!M96<L(&AO9WD@=F%L\V)A;B!T]G+V;&YI(&OM=N%N
M:F$@97IT(&%Z(&5L96UE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V
M-@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS
M9W-T<B`B2^ER96T@861J;VX@;65G(&5G>2!H\VYA<&]T(.ES(&5G>2#I=F5T
M+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.B(*;7-G<W1R(")+Z7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R
M:6$@;F5VZ70Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(DOI
M<F5M('9A;/-S($E0(&/M;65T(&%D:F]N(&UE9RXB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C8T-`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS
M9W-T<B`B2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<L(&5L;&5N]7)I
M>GIE(&$@:/-N87`@;F%P:F%I="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B2^ER96T@=F%L\W,@9.%T=6UO="!A9&IO;B!M96<N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I
M9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")+Z7)E;2!R
M]G9I9&5N(.UR:F$@;&4@82!P<F]B;.EM82!LZ6YY96?I="XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(DOI<F5M(&%D:F$@;65G(&$@8F5J96QE
M;G1K97KI<VD@;F5VZ70@Z7,@:F5L<WIA=N%T(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)+Z7)E;2!O;'9A<W-A
M(&5L(&$@:_9V971K97KU('-Z]G9E9V5T+B!!(')E;F1S>F5R(&AA<WINX6QA
M=.%N86L@9F5L=.ET96QE:70@(@HB96P@2T5,3"!F;V=A9&YI82XB"@HC.B!L
M:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")+
MZ7)E;2!A9&IA(&UE9R!A>B#Z:B!K871E9_-R:6$@;F5VZ70Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0;VQA;F0B"FUS9W-T<B`B3&5N9WEE;&]R<WKA9R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L
M:71I:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED
M(")0;VQL<R(*;7-G<W1R(")3>F%V87KA<V]K(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G
M86PB"FUS9W-T<B`B4&]R='5GX6QI82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")!(&OI<"!E;&AE;'EE
M>NES92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S
M='(@(D$@=.%B;.%Z870@96QH96QY97KI<V4B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF
M;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@HB2_9Z=F5T;&5N(&QE=NEL:_QL
M9.ES(&5B8F4@82!M87!PX6)A("A)34%0(&YE;2!M:6YD:6<@=F5S>FD@9FEG
M>65L96UB92DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")!>B!E;&WZ
M;'0@)7,@\W)A(&-S87!A9.EK;65N;GEI<^EG93H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB
M<B`O/F-H86YC92(*;7-G<W1R(")#<V%P863I:SQB<B`O/G9A;/-S>NUN^W/I
M9R(*"B,Z(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")0<F5F<U]L9&%P.B!N96T@=&%LX6QH873S(&$@<WK\:W/I9V5S
M($Q$05`@:VET97)J97-Z=.ES+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]S97-S
M:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]S97-S
M:6]N.B!N96T@=&%LX6QH873S(&$@<WK\:W/I9V5S("AS97-S:6]N*2!K:71E
M<FIE<WITZ7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@
M(E!R97-S=7)E(@IM<V=S='(@(DSI9VYY;VWA<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*
M;7-G<W1R(")!('1E;F=E<G-Z:6YT;F5K(&UE9V9E;&5L]2!LZ6=N>6]MX7,Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@
M(E!R97-S=7)E.B`B"FUS9W-T<B`B3.EG;GEO;>%S.B`B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R(")%;/5Z971E<R!M96=T96MI;G3I<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(D$@:^EP(&5L]7IE=&5S(&UE9W1E:VEN=.ES92#Z:B!A
M8FQA:V)A;B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(D5L]7KU(&]P8VGS:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT
M(@IM<V=S='(@(D$@9&]K=6UE;G1U;2!K:6YY;VUT873A<V$B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM
M<V=S='(@(E1I=&MO<R!K=6QC<R(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ
M-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B2&EB86)E:F5L96YTZ7,B"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B02!H:6)A(&QE[7+A<V$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R
M(")0<F]J96MT(&ME>F5LZ7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Q
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S(X,`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B02!P<F]M<'0@<WKV
M=F5G92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4'5B;&EC($ME>2(*;7-G<W1R(").>6EL=N%N;W,@:W5L8W,B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!
M;&=O<FET:&TB"FUS9W-T<B`B3GEI;';A;F]S(&MU;&-S^B!A;&=O<FET;75S
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U
M8FQI8R!+97D@26YF;R(*;7-G<W1R(").>6EL=N%N;W,@:W5L8W,@:6YF;W)M
MX6-I\R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B02!N>6EL=N%N;W,O=&ET:V]S(&MU;&-S<.%R="!N
M96T@<VEK97+\;'0@;.ET<F5H;WIN:2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC
M;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@;65S<V%G97,B"FUS9W-T
M<B`B02!L979E;&5K(';I9VQE9V5S('3V<FSI<V4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DV(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A
M<B(*;7-G<W1R(")+871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM
M<V=I9"`B475E<GDB"FUS9W-T<B`B2V5R97/U+W!A<F%N8W,@<W1R:6YG(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G
M<W1R(")+=O-T82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I
M(@IM<V=S='(@(E)302!N>6EL=N%N;W,@:W5L8W,@*"5D(&)I=&5S*2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B4N%D:?-G;VUB;W,@:VEVX6QA<WITX7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I
M;B(*;7-G<W1R(")%<_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")%<_4@
M9.EL96SU='0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(D5S]2!DZ6QU=.%N
M+V5S=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B6N%P;W(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B
M4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")%<_4@Z7,@:&%V87KA<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")2
M86EN('1O(%-N;W<B"FUS9W-T<B`B2&%V87-E<_4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B
M5NEL971L96X@:63I>F5T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G
M:60@(E)A=&EO(@IM<V=S='(@(D%RX6YY(@H*(SH@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3VQV87/A<R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-R!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G
M97,B"FUS9W-T<B`B3&5V96QE:R!O;'9A<^%S82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+B(*;7-G<W1R("(B"B)4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA<WIN
MX6SS=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R!V:7-S>F$N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S
M='(@(B(*(E3I;GEL96<@=/9R]FQJ_&L@)7,@9F5L:&%S>F[A;/,@861A=&%I
M=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R`B"B)V:7-S>F$N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BVFIR
M82!VZ6=R96AA:G1J82!A>B!U=&]L<_,@=N%L=&]Z=&%TX7-T(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B1G)I<W/M=.ES(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(@IM<V=S='(@(D$@;65N_"!D:6YA;6EK=7,@96QE
M;65I;F5K(&9R:7-S[73I<VD@9WEA:V]R:7/A9V$Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB
M"FUS9W-T<B`B07H@]G-S>F5G>O5O;&1A;"!F<FES<^UTZ7/I;F5K(&=Y86MO
M<FESX6=A.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.3@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R,3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,SD*;7-G:60@
M(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C,U
M"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R(")/8FIE:W1U
M;2!B]FYGZ7-Z]2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T
M-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A
M9"(*;7-G<W1R(")&<FES<^UTZ7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,S,PIM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")-96=J96=Y>NES96LB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R
M=F5R<R(*;7-G<W1R(")4X79O;&D@<WIE<G9E<F5K(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B02!TX79O;&D@
M55),("AP;"X@:'1T<#HO+W=W=RYV86QA;6DN:'4O;65G=F%L86UI*3HB"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G
M<W1R(")4]G)LZ7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")";&]K:R!T]G)LZ7-E
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")/<WIL;W`@=/9R;.ES92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D$@9F]R;6%T=.%L
MX7,@=/9R;.ES92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")!('#A<B!T]G)LZ7-E(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*(E3V<O9L:OQK(&%Z(&5L;65N=&5T="!P<F]G<F%M;W0@
M82!S>F5R=F5R(&ED96EG;&5N97,@X6QL;VWA;GEO:V%T('1A<G1A;&UA>O,@
M(@HB86QK]FYY=G3A<N%B\VPN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE
M(@IM<V=S='(@(E9E9WG\:R!K:2`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T
M:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B5F5G>?QK(&MI
M(&5Z="!A('+I<WIT(&$@9&]K=6UE;G1U;6+S;"(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM
M<V=S='(@(D$@9F5L:&%S>F[A;/,@=/9R;.ES92(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B)7,@9F5L:&%S>F[A;/,@=/9R;.ES
M92(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(D$@:^ERZ7,@;F5M('1E;&IE<^UT:&5T]2X@02!K87!O
M='0@:&EB86OS9#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+B(*;7-G<W1R(")!(&ME<F5S971T('-Z;VQGX6QT873A<R!N96T@=&%L
MX6QH873S+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<V(&QI8B](;W)D92YP:'`Z
M-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D$@:_9T
M96QE>O5E;B!M96=A9&%N9/,@7"(E<UPB(&YE;2!S>F5R97!E;"`E<R!K;VYF
M:6=U<N%C:?-JX6)A;BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C<X(&QI8B]6
M1E,O9G1P+G!H<#HX-C$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")!(&OV=&5L97KU96X@
M;65G861A;F3S(%PB)7-<(B!N96T@<WIE<F5P96P@82!61E,@:V]N9FEG=7+A
M8VGS:N%B86XN(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")!(&OV=&5L97KU96X@;65G861A
M;F3S(%PB)7-<(B!N96T@<WIE<F5P96P@82!K;VYF:6=U<N%C:?-B86XN(@H*
M(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q
M=6ER960@1FEE;&0B"FUS9W-T<B`B4WK\:W/I9V5S(&UE>O4B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S(&QI8B](;W)D
M92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*
M;7-G:60@(E)E<V5T(@IM<V=S='(@(E)E<V5T(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S
M='(@(D$@:F5L<WKS(.%TX6QL[73A<V$B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G
M<W1R(")!>B#6;B!J96QS>F%VX6YA:R#A=.%L;.UTX7-A(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM
M<V=S='(@(D%Z('5T;VQS\R!K97)E<^ES('9I<W-Z8>%L;.UTX7-A(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B
M17)E9&WI;GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/
M<'1I;VYS(@IM<V=S='(@(E9I<W-Z82!A>B!O<&-I\VMH;WHB"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@
M<&%S<W=O<F0B"FUS9W-T<B`B07H@^FH@:F5L<WKS="#M<FIA(&)E(&ES;>ET
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2Z75N:6]N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("+!;&SM
M='-U:R!V:7-S>F$@82!K;VYF:6=U<N%C:?-T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M(@IM<V=S='(@(E)I8V@@5&5X="!%9&ET;W(@;W!C:?-K(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E1A
M;.%L\W,@:^ER9.ES96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(FIO
M8F(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-PIM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(DIO8F(@;VQD86QI(&9E:FSI8R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T
M<B`B2F]B8B!O;&1A;&D@Z7)TZ6ME:R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E-O<B!T=6QA:F1O;G/A9V]K+BXN(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@
M(E)O;&4B"FUS9W-T<B`B4WIE<F5P(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G
M<W1R(")2;VWA;FEA(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")&;W)G873A
M<R`Q.#`@9F]K:V%L(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B0F%L<F$@
M9F]R9V%TX7,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B2F]B8G)A(&9O
M<F=A=.%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B
M4V]R('1U;&%J9&]N<^%G;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R(")3;W(@='5L86ID;VYSX6=O:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*
M;7-G<W1R(")3;W)O:SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")6
M;VYA;&%K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E
M;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")-:6YD96X@<V]R(.ES
M(&]S>FQO<"!K]GKV='0@;&5G>65N('9O;F%L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B
M0W-A:R!A>B!O<WIL;W!O:R!K]GKV='0@;&5G>65N('9O;F%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS
M9W-T<B`B0W-A:R!A('-O<F]K(&OV>O9T="!L96=Y96X@=F]N86PB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B1G5T
M=&%TX7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B
M3W)O<WH@1O9D97+A8VGS(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U
M86YD82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED
M(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-
M24U%(&1I9VETX6QI<R!A;.'M<N%S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*
M;7-G<W1R(")3+TU)344@<WIA8G;A;GD@<WIE<FEN="!T:71K;W/M=&]T="!L
M97;I;"(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(E-!4TP@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T86SA;&AA=/,N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE
M<W-A9VEN9R(*;7-G<W1R(")335,@:_QL9.ES(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,R-S@*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R
M('9A;'5E(&QO;VMU<',B"FUS9W-T<B`B4U%,('!A<F%N8W,@82!K97)E<^ES
M:&5Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I9"`B
M4U-((@IM<V=S='(@(E-32"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R
M(")324M%4MQ,5"(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")3>F\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4WIE;G0@26QO;F$M<WII9V5T
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I
M;G0@2VET=',@Z7,@3F5V:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S
M='(@(E-A:6YT($QU8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-
M:7%U96QO;B(*;7-G<W1R(")386EN="!0:65R<F4@Z7,@36EQ=65L;VXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U
M"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G
M<W1R(")386EN="!6:6YC96YT(.ES($=R96YA9&EN92US>FEG971E:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G
M:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")59WEA;F%Z(&$@9G)A
M;64@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-Z86UO82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M
MZ2#I<R!0<NUN8VEP92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(DW[:&]L9&%S
M(&EN=&5R;F5T96SI<NES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S
M='(@(E-Z8?ID+4%RX6)I82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")-96YTZ7,B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!M96YTZ7-E(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("(E<R!M96YTZ7-E(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM
M<V=S='(@(D$@8F7A;&SM=.%S;VL@;65N=.ES92(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB365N='/\:R!E;"!A
M>B!E;&OI<WK\;'0@:V]N9FEG=7+A8VGS="!02%`@<')O9W)A;2!F;W)MX6KA
M8F%N(&$@<WIE<G9E<B`B"B)I9&5I9VQE;F5S(.%L;&]MX6YY;VMA="!T87)T
M86QM87KS(&%L:_9N>79TX7+A8F%N+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B5S(&MO;F9I9W5RX6-I\VKA="!E;&UE;G1E
M='3\:RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R(")%;&UE;G1E='3\:R!A('-E='5P('5P9W)A9&4@
M<')O9W)A;6]T(&ED93H@7"(E<UPB(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T97)E9"!4+5-T;W)M
M<R(*;7-G<W1R(")3>O-R=N%N>6]S('II=F%T87)O:R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")4=61O
M;>%N>2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B
M"FUS9W-T<B`B2V5R97/I<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(DME<F5SZ7-I
M('-Z;VQGX6QT873A<V]K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-3D*
M;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("+!;&QO;>%N>6]K(&MI=N%L
M87-Z=.%S82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B5N%L87-S>F]N
M(&MI(&5G>2!DX71U;6]T(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")-
M96QY:6L@8W-O<&]R=&]T(&OM=N%N:F$@:&]Z>N%A9&YI(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W
M;F5R(@IM<V=S='(@(E;A;&%S<WIA(&MI(&%Z(/IJ('1U;&%J9&]N;W-T(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`B5N%L87-S>F]N('-Z97)V97)T(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A
M('5S97(@=&\@861D(@IM<V=S='(@(DUE;'EI:R!F96QH87-Z;N%L\W0@:^UV
MX6YJ82!H;WIZX6%D;FDB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(DUI;F1E
M="!K:6IE;/9L:OQK(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")6X6QA
M<W-Z82!K:2!A>B#V<W-Z97,@9.%T=6WV<W-Z971E=O5T+B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C
M="!A;B!O8FIE8W0B"FUS9W-T<B`B5N%L87-S>F]N(&5G>2!O8FIE:W1U;6]T
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B16=Y('-E(&QE9WEE;B!K:6IE
M;/9L=F4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*
M(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)6X6QA<W-Z82!K:2!A
M(&OM=N%N="!K87)A:W1E<BAE:V4I="!A>B!A;.%B8FD@;&5H973U<^EG96L@
M:_9Z_&PN($5Z=73A;B`B"B)<(F-O<'DO<&%S=&5<(B!M\V1S>F5R<F5L(&$@
M;65G9F5L96SU(&AE;'ER92!MX7-O;&AA=&IA(/5K970N(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@9.%T=6UE;';A;&%S
M>G3S(&MA<F%K=&5R=#HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5N%L
M87-S>F$@:VD@82!DX71U;2!F;W)MX71U;>%T.B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@
M:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")6X6QA<W-Z
M82!K:2P@;65L>6EK(&%Z;VYO<^UT\VKA="!K[7;A;FIA(&UE9W;A;'1O>G1A
M=&YI.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")6X6QA<W-Z82!K
M:2!A>B!I9/5E;';A;&%S>G3S(&MA<F%K=&5R=#HB"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA
M=#HB"FUS9W-T<B`B5N%L87-S>F$@:VD@87H@:63U(&9O<FWA='5MX70Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E;A;&%S<WIO;B!K:2!K
MZ70@96=Y;>%S;F%K(&UE9V9E;&5L]2!M97KU="XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N(@IM<V=S='(@(E;A;&%S<WIA(&MI(&$@:^UVX6YT('-Z[6YE9WG\='1E
M<W0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")6X6QA<W-Z
M82!K:2!A>B#6;FYE:R!M96=F96QE;/4@;GEE;'9E=#HB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R(")(:6)A:F5L96YTZ7,@:_QL9.ES92(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")3
M96YD(%--4R(*;7-G<W1R(")335,@:_QL9.ES92(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G
M86PB"FUS9W-T<B`B4WIE;F5GX6PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4WIE;GIO<CH@(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E
M<B(*;7-G<W1R(")S>F5P=&5M8F5R(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(E-Z97)B:6$@Z7,@36]N=&5N96=R\R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S
M='(@(E-O<F]Z871S>N%M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B02!S>F5R=F5R=/5L(&MA<&]T="!A9&%T(&AI8N%S
M+"!V86=Y(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92XB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B02!F
M96QH87-Z;N%L\VMA<&-S;VQA=&]K(&%D;6EN:7-Z='+A8VGS:F$B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S
M<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("),96KA<G0@82!F96QH87-Z;N%L
M\VMA<&-S;VQA="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN(@H*(SH@;&EB
M+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")&96QH87-Z
M;N%L\VMA<&-S;VQA=&]K(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S,3@*
M;7-G:60@(E-E="(*;7-G<W1R(")(86QM87HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B3&5H973U<^EG(&IE;'-Z87;A;F%K(.%TX6QL[73A<^%R82P@
M86)B86X@87H@97-E=&)E;BP@:&$@96QF96QE:G1E;NDN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M(@IM<V=S='(@(B(*(E3A=F]L:2!S>F5R=F5R96L@96SI<NES92#A;&SM=&AA
M=/,@8F4L(&UE;'EE:V5T(&%Z(&EN9'5L\V]L9&%LX6X@:^UVX6X@(@HB;65G
M:F5L96[M=&5N:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G
M:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD
M(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B02!K[7;A;G0@;GEE;'8L(&ED]7KS
M;F$@Z7,@9.%T=6UF;W)MX71U;2!B9>%L;.UTX7-A+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)"9>%L
M;.UT:&%T\RP@:&]G>2!M96QY:6L@86QK86QM87KA<R!J96QE;FIE;B!M96<@
M82!B96IE;&5N=&ME>NES('5TX6XL("(*(FUI;'EE;B!S>NUN96=Y_'1T97-T
M+"!O;&1A;&9R:7-S[73I<VD@9WEA:V]R:7/A9V]T(&EL;"X@96=YZ6(@8F7A
M;&SM=.%S;VMA="`B"B)S>F5R971N92XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")"9>%L;.UTX7-O:R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED
M(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(D$@
M8F7A;&SM=.%S;VMA="!M96?Z:NUT\R!P<F]G<F%M;VL@X6QL;F%K(')E;F1E
M;&ME>NES<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U
M"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P
M87)A;65T97(Z("(*;7-G<W1R(")!(&UE9V%D;W1T('!A<F%MZ71E<B!T]F)B
M(&AE;'EE="!I<R!J96QE;G1H970Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B
M"FUS9W-T<B`B4V5Y8VAE;&QE+7-Z:6=E=&5K(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B5N%S
MX7)LX7,B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM
M<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")2]G9I9"#V<W-Z969O9VQA
M;.%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM
M<V=S='(@(D5L(&OM=N%N:F$@Z7)N:2!A>B!E9WEE<R!F=6YK8VGS:V%T($%L
M="UB:6QL96YT>?LM:V]M8FENX6-I\VMK86P@:7,_(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B365G
M:F5L96[M=.ES(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I
M9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E
M9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B)-=71A<W-U:R!M96<@82!K_&SV;F)SZ6=E:V5T(&%Z(&5L
M;65N=&5T="#I<R!A>B#Z:F]N;F%N(&SI=')E:&]Z;W1T("(*(FMO;F9I9W5R
MX6-I\R!K]GKV='0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM
M<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*
M;7-G<W1R("(B"B)-:6YD96X@8F5J96QE;G1K97KI<VMO<B#M<O-D:NEK(&MI
M(&$@:V]RX6)B:2!U=&]L<_,@8F5J96QE;G1K97KI<R!I9&5J93\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<V.0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@
M:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")6X6QA<WIT:&%T\R!L96=Y96X@87H@
M97)E9&5T:2!M96=T87)TX7-A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W
M.3D*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DQE9WEE;B!DX71U;7;A
M;&%S>G3S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R("),96=Y
M96X@96=Y('3A8FSA>F%T:V5Z96SU(&UE;OQS;W(_(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")-=71A<W-U:R!A("5S
M(&UE;OQT(&$@8F%L(&]L9&%L;VX_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H
M92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D[I>GK\
M:R!M96<@=.%B;.%Z870@8V5L;.%I;F%K('1U;&%J9&]N<^%G86ET(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(").Z7IZ_&L@;65G('3A8FSA>F%T('1U;&%J9&]N<^%G86ET(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B3NEZ>OQK(&UE9R!TX6)LX7IA="!S;W)A:6YA:R!T
M=6QA:F1O;G/A9V%I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@
M<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B3NEZ>OQK(&UE9R!A(&OI<"!T
M=6QA:F1O;G/A9V%I="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8W"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")-=71A<W-U:R!A(&9E;'3V;'3I
M<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("):X7!O<F]K(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E
M<G,@16%R;'DB"FUS9W-T<B`B6N%P;W)O:R!DZ6QE;/5T="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W
M97)S($QA=&4B"FUS9W-T<B`B6N%P;W)O:R!DZ6QU=.%N+V5S=&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B2&5L>6D@>N%P;W)O
M:R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B2VEC<VEN>>UTZ7,B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S
M='(@(B(*(D5L]7-Z]G(@:VEC<VEN>>UT96YI92!K96QL+"!V86=Y(&5L(&ME
M;&P@;6]Z9.UT86YI82!A(&AE;'EE="!E;&9O9VQA;/,@(@HB8FQO:VMO:V%T
M+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O
M;F4B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B
M4VEG;B!U<"(*;7-G<W1R("+::B!F96QH87-Z;N%L\VL@8F5J96QE;G1K97KI
M<V4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I9"`B
M4VEG;F%T=7)E(@IM<V=S='(@(D1I9VETX6QI<R!A;.'M<N%S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!
M;&=O<FET:&TB"FUS9W-T<B`B02!D:6=I=.%L:7,@86SA[7+A<R!A;&=O<FET
M;75S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3>FEN9V%P^G(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0Q"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$V(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3`Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM
M<V=S='(@(DWI<F5T(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T
M<B`B02!K87)B86YT87)TX7,@:VEH86=YX7-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K
M:6$B"FUS9W-T<B`B4WIL;W;A:VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS
M9W-T<B`B4WIL;W;I;FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<B"FUS9W-T<B`B2&%V87KA<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")(\WKA<&]R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")(\WKA<&]R;VLB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S
M($5A<FQY(@IM<V=S='(@(DCS>N%P;W)O:R!DZ6QE;/5T="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W
M(%-H;W=E<G,@3&%T92(*;7-G<W1R(")+Z7/U(&3I;'5TX6YI+V5S=&D@:/-Z
MX7!O<F]K(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N
M;W<@9&5P=&@Z("(*;7-G<W1R(")!(&CS(&WI;'ESZ6=E.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN
M('=A=&5R.B`B"FUS9W-T<B`B2/,@=NUZ;65N;GEI<^EG96)E;B!K:69E:F5Z
M=F4Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")386QA
M;6]N+7-Z:6=E=&5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3>F]M
MX6QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N
M9W,@)B!0;V5M<R(*;7-G<W1R(")$86QO:RP@=F5R<V5K(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(Y,3(*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N
M(@IM<V=S='(@(D$@<V]R8F%R96YD97KI<R!I<N%N>>%N86L@:VEVX6QA<WIT
MX7-A(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ-C8@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U
M<F-E(&%D9')E<W,B"FUS9W-T<B`B1F5L863S:2!C[6TB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3
M;W5T:"!!9G)I8V$B"FUS9W-T<B`B1.EL+4%F<FEK82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RDB"FUS9W-T<B`B9.EL+65U<O-P86D@*$E33RTX.#4Y+3,I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R(")$Z6QI+4=E;W)G:6$@Z7,@1.EL:2!386YD=VEC:"US
M>FEG971E:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B1.EL:2!FZ6QT96ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E
M;G0@8V5L;',B"FUS9W-T<B`B4WIO;7-ZZ61O<R!C96QLX6L@:_9Z]G1T:2!T
MX79O;'/A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(D$@8V5L;&$@=&%R=&%L;6$@Z7,@:V5R
M971E(&OV>O9T=&D@=.%V;VQSX6<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#$Y"FUS9VED(")3<&%C97(B"FUS9W-T<B`B2&5L>6MI=/9L=/4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*
M;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B5.%V;VQSX6<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED
M(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(E3A=F]L<^%G(.ES(&)E
M;'/U(&UA<F?S(&)EX6QL[73A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R(")3
M<&%N>6]L;W)S>N%G(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P
M,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M87-S87-S:6YE(&)EX6QL[73A
M<V]K(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C
M:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3<&5C:>%L:7,@:V%R86MT
M97(@8F5V:71E;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@
M(D$@8V5L;&$@:V5T=.EB;VYTX7-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L
M=6UN(@IM<V=S='(@(D%Z(&]S>FQO<"!K971TZ6)O;G3A<V$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS
M9VED(")3<&QI="!R;W<B"FUS9W-T<B`B02!S;W(@:V5T=.EB;VYTX7-A(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS
M9W-T<B`B4W!O<G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<NT@
M3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B
M4W1A;F1A<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B
M4W1A<G0@>65A<B(*;7-G<W1R(")!>B!E;'/U(.EV(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(L%L;&%M('9A9WD@=&%R=&]MX6YY(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G
M<W1R("+!;&QA<&]T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#$*;7-G
M:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(DUE;G3I<VD@9F]R;>%T=6TB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R
M965T($%D9')E<W,B"FUS9W-T<B`B0^UM("AU=&-A*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`BX71H^GIO='0B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B4W1R:6YG
M(&QI<W1A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@(E-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(E3V<O9L:OQK
M(&$@8^UM8O5L(&$@0"!U=.%N:2!RZ7-Z="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(E-T[6QU<R!;0U-372(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S
M='(@(E9A(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!*'HI(%PB)7-<(B!A;&OV;GEV=.%R(&YE;2!T86SA;&AA=/,N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G
M:60@(E-U8FIE8W0B"FUS9W-T<B`B5.%R9WDB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,V(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G
M:60@(E-U8FUI="(*;7-G<W1R(")+_&QD:OQK(&5L(@H*(SH@<VEG;G5P+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G
M(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB
M"FUS9W-T<B`B(@HB7"(E<UPB(/IJ(&9E;&AA<WINX6SS(&)E:F5L96YT:V5Z
MZ7-I(&OI<F5L;>ET('1O=N%B8NUT;W1T=6LN(-9N(&-S86L@(@HB:^ER96QM
MZ6YE:R!E;&9O9V%DX7/A="!K]G9E=/5E;B!T=60@;6%J9"!B96IE;&5N=&ME
M>FYI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")A;'/S(&EN9&5X(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-"!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS
M9W-T<B`B4VEK97+\;'0B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H
M92!S>7-T96TN(@IM<V=S='(@(E-I:V5R97-E;B!H;WIZX6%D='5K(%PB)7-<
M(BUT(&$@<F5N9'-Z97)H97HN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB(&9E;&AA<WINX6SS(&%D871A:70@<VEK97)E<V5N('3V<O9L=/QK(&$@
M<F5N9'-Z97)B]6PN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B4VEK97)E<V5N('3V
M<O9L=/QK(%PB)7-<(BUT+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")3:6ME<F5S96X@96QTX79O;.UT
M;W1T=6L@7"(E<UPB+70@82!R96YD<WIE<F+U;"XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@
M8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R
M("(B"B)!(&MO;F9I9W5RX6-I\W0@<VEK97)E<V5N('9I<W-Z8>%L;.UT;W1T
M=6LN($$@=N%L=&]ZX7-O:R!M96=T96MI;G3I<^EH97H@(@HB9G)I<W/M='-E
M(&%Z(&]L9&%L="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B02!B86-K=7`@
M:V]N9FEG=7+A8VGS="!E;&UE;G1E='3\:RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS
M9W-T<B`B4VEK97)E<V5N(&5L;65N=&5T=/QK(&$H>BD@)7,@8F%C:W5P(&MO
M;F9I9W5RX6-I\W0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G
M<W1R(")<(B5S7"(@861A=&%I;F%K(&WS9&]S[73A<V$@<VEK97)E<V5N(&UE
M9W3V<G3I;G0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(E-I:V5R97-E;B!E;&UE;G1E
M='3\:R!A("5S(.%L;&]MX6YY="XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R
M(")3>G5DX6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(M9S<WIE
M9F]G;&%LX7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@
M(E-U;B!2:7-E(@IM<V=S='(@(DYA<&ME;'1E(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(DYA<&YY=6=T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P
M"FUS9VED(")3=6YN>2(*;7-G<W1R(")N87!O<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M3F%P:V5L=&4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(DYA<&ME;'1E+VYA<&YY=6=T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(").87!K
M96QT93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P.`IM
M<V=I9"`B4W5N<V5T(@IM<V=S='(@(DYA<&YY=6=T82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S
M='(@(DYA<&YY=6=T83H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B
M9F5L<_4@:6YD97@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P
M"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D]N;&EN92!K;VUM=6YI:^%C:?,@
M*&-H870I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;64B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R
M;F%M92(*;7-G<W1R(")#<V%LX61NZ78B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A
M;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(.ES($IA;B!-87EE;B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3>G;A>FEF]FQD(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-VZ61O<G-ZX6<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I
M='IE<FQA;F0B"FUS9W-T<B`B4W;A:F,B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R
M(")!>B!A9&%T<WII;FMR;VYI>N%C:?-S(&YA<&SSX6QL;VWA;GET('3V<O9L
M=/QK(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN
M8TU,(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP
M.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(E-Z:6YT86MT:6MA:2!H:6)A(&$@:V5R97/U:VEF96IE>NES8F5N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WKM<FEA
M:2!!<F%B($OV>G3A<G-A<^%G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B6FEV
M871A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8R"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")::79A=&%R
M+"!E<O5S('-ZZ6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B6FEV871A<F]K
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*
M;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(DMO<F%I('II=F%T87)O
M:R(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@
M9FEL92(*;7-G<W1R(")44U8@*%1!0B!K87)A:W1E<G)E;"!E;';A;&%S>G1O
M='0@Z7)TZ6ME:RD@X6QL;VWA;GDB"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N
M<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5.%B;.%Z870B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S
M"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(D$@=.%B;.%Z870@
M='5L86ID;VYSX6=A:2(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM
M<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")!('3A8FSA>F%T('1U
M;&%J9&]N<^%G86DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S
M='(@(E1A:G9A;B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B
M5&%J=F%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4861Z<VEK
M:7-Z=.%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R(")486YZX6YI86D@16=Y97/\;'0@2VERX6QY<^%G(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R(")!(&/I;#HB"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`T.2!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS
M9VED(")487-K<R(*;7-G<W1R(")&96QA9&%T;VLB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*
M;7-G<W1R(")496QE9F]N<WKA;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")!>B!E
M;&WZ;'0@\W)A(&CU;>ER<^EK;&5T93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(DCU;>ER<^EK
M;&5T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I
M9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")(]6WI<G/I:VQE=#H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(DCU;>ER<^EK;&5T/&)R("\^*"5S36%X)7,O)7--:6XE
M<RD@)F1E9SLE<R(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D$H>BD@7"(E<UPB('-A8FQO;B!N96T@=&%LX6QH873S+B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")386)L;VYO:R!A9&UI;FES>G3A8VGS
M:F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S,S,0IM<V=I9"`B5&5X="(*;7-G<W1R(")3>O9V96<B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS
M9W-T<B`B8W-A:R!S>O9V96<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM
M<V=S='(@(E-Z]G9E9V5L:&5L>65ZZ7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S
M='(@(G-Z]G9E9R!T971E:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")#<_PB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R
M,"DB"FUS9W-T<B`B=&AA:2`H5$E3+38R,"DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N
M9"(*;7-G<W1R(")4:&%I9O9L9"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-3$*
M;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D%Z(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N(@H*(SH@;&EB
M+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T
M96T@:7,@9&ES86)L960N(@IM<V=S='(@(D$@2&ES=&]R>2!R96YD<WIE<B!M
M^VOV9.ES92!N:6YC<R!E;F=E9.EL>65Z=F4N(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<
M(B(*;7-G<W1R(")!($AO<F1E+TMO;&%B(&EN=&5G<N%C:?,@97IT(&YE;2!T
MX6UO9V%T:F$Z(%PB)7-<(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ
M,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+B(*;7-G<W1R(")!>B!)35-0(&YA<&SS>N%S="!N96T@<VEK97+\;'0@
M;65G:V5Z9&5N:2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*
M;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S
M=6-C97-S9G5L;'DB"FUS9W-T<B`B02!-86EN=&5N86YC93HZ(&]S>G3A;'D@
M8F5T]FQTZ7-E(&YE;2!S:6ME<OQL="(*"B,Z('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H
M87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")!>B!/<&-I\R!A8FQA:R!B
M97KA<F]D;W1T+B!+:6SI<.ES(&OV=F5T:V5Z:6LN(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#`@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,C,@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB
M02!*;V=O<W5L='/A9V]K(&AA<WINX6QA=.%N86L@96SU9F5L=.ET96QE+"!H
M;V=Y(&$@<F5N9'-Z97)G87ID82`B"B)K;VYF:6=U<N%L:F]N(&5G>2!A(&IO
M9V]S=6QT<^%G:2!A9&%T;VMA="!T87)T\W-A;B!TX7)O;&YI(&OI<&5S(&%L
M<F5N9'-Z97)T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY
M(@IM<V=S='(@(D-S86L@86QU;"!L96=Y96X@:V5R970B"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*(D$@<&%R=&YE<B!A>F]N;W/M=/-S>N%M82!N96T@=F]L="!M96=A9'9A
M+_QR97-E;B!M87)A9'0@=F%G>2!A>B!A9&%T8N%Z:7-B86X@(@HB;F5M('9O
M;'0@;65G=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D$@<&%R
M=&YE<B!A9&%T86ET('-I:V5R97-E;B!H;WIZX6%D='5K(&$@8^UM:F5G>7KI
M:^EH97HN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@HB2_QL]F[A;&SS(%!'4"!A;.'M<N%S:2!B;&]K:R!S>OQK<^EG97,@82!D
M:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T("(*(FAI=&5L97-SZ6?I;F5K(&5L
M;&5N]7)ZZ7/I:&5Z+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB02!K]G)L97;I
M;&QI<W1A(&%Z;VYO<^UT\W-ZX6UA(&YE;2!V;VQT(&UE9V%D=F$O_')E<V5N
M(&UA<F%D="!V86=Y(&%Z("(*(F%D871BX7II<V)A;B!N96T@=F]L="!M96=T
M86SA;&AA=/,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+B(*;7-G<W1R(")!(&OV<FQE=NEL;&ES=&$@;F5M('9O;'0@;65G
M861V82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BXB"FUS9W-T<B`B(@HB02!T:71K;W/M=.%S:2!S>F]L9^%L=&%T
MX7-O:VAO>B!B:7IT;VYSX6=O<R`H=&ET:V]S[71O='0I('=E8B!K87!C<V]L
M870@:V5L;"XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-R!L:6(O2&]R9&4N<&AP
M.C4Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D$H>BD@)7,@X6QL;VWA
M;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!E9WD@)7,@8F7A;&SM=.%S;F%K
M+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3<P(&QI8B](;W)D92YP:'`Z-3`Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*(D$H>BD@)7,@X6QL;VWA
M;GEB86X@<WIE<F5P96QN:64@:V5L;&5N92!V86QA;6EL>65N("5S(&)EX6QL
M[73A<RAO:REN86LN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@
M(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S
M='(@(D$@9N%J;"!N96T@;>%S;VQH873S(/9N;6%GX7)A+B(*"B,Z(&QI8B](
M;W)D92]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R(")!(&;A:FQB86X@;F5M('9O;'0@861A="XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B07H@_'IE;F5T(&9E:FSI8W-O
M<F%I(&$@:_9V971K97KU:RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D$@=&5L:F5S(&OI
M<&5R;GGU<R#\>F5M;?-D('!R;V)LZ6WA:V%T(&]K;WIH870@87H@26YT97)N
M970@17AP;&]R97(@(@HB:&%S>F[A;&%T82!E<V5TZ6XL(&UE<G0@96)B96X@
M;VQY86X@<')O9W)A;6AI8N%K('9A;FYA:RP@86UI:V5T(&YE;2!T=61T=6YK
M("(*(FUE9VME<OQL;FDN($$@:^EP97)N>?5J92!O;'9A<VAA=&%T;&%N;N$@
M=N%L:&%T+"!B:7IO;GEO<R!E9&ET;W(@9G5N:V-I\VL@(@HB:&GA;GEO>FAA
M=&YA:R#I<R]V86=Y(';A<F%T;&%N=6P@;&5F86=Y:&%T(&$@8O9N9^ES>O5P
M<F]G<F%M+B!7:6YD;W=S(#EX("(*(FAA<WINX6QA=&$@97-E=.EN(&YA9WEO
M;B!V86SS<WKM;OLL(&AO9WD@)T=E;F5R86P@<')O=&5C=&EO;B!F875L="<@
M:&EB82`B"B)M:6%T="#Z:G)A(&ME;&P@:6YD[71A;FEA(&UA:F0@82!GZ7#I
M="Y<7&Y<7&Y&:6=Y96QM97IT971T_&LA($MA='1I;G1S;VX@87H@(@HB3TL@
M9V]M8G)A+"!H82!MZ6=I<R!M96<@:^UVX6YJ82!K[7/I<F5L;FD@82!T96QJ
M97,@:^EP97)N>?5S(/QZ96UM\V1O="XB"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B02!<(B5S7"(@87IO;F]S
M[73S="!K:73V<O9L=/QK+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(D-S86L@8F%L(&]L9&%L;VX@;&5G>65N(&ME
M<F5T(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B
M"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I
M=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB02!'
M;G501R!P<F]G<F%M(&AE;'GI="!M96<@:V5L;"!A9&YI(&$@0W)Y<'1?<&=P
M.CH@;W-Z=.%L>2!H87-Z;N%L873A:&]Z+B(*"B,Z(&QI8B](;W)D92]-24U%
M+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@
M8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS
M9W-T<B`B(@HB02!L97;I;"P@;65L>65T("5S(&YA<&KA;B!K_&QD]G1T("5S
M(&/M;7IE='1N96L@7"(E<UPB('3A<F=Y8F%N+"!A(&/M;7IE='0@(@HB<WKA
M;>UT\V?I<.EN(&UE9VIE;&5N="X@07)R82!N:6YC<R!G87)A;F-I82P@:&]G
M>2!E;"!I<R!O;'9A<W3A:R!I;&PN(&AO9WD@(@HB;65GZ7)T971TZ6LN(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X.#$*;7-G:60@(E1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R
M(")-:2!L96=Y96X@82!L97;I;.UR\R!A8FQA:VAO>B!M=71A=/,@;&EN:R!E
M;&YE=F5ZZ7-E(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B
M02!M97KU:R!S>N%M82!C<V%K(&YU;65R:6MU<R#I<G3I:R!L96AE="XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*(D%Z(&]P96YS<VP@;6]D=6P@
M<WK\:W/I9V5S(&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!O<WITX6QY(&AA<WIN
MX6QA=.%H;WHN(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H<#HR.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B
M"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*(D$@7"(E<UPB
M('-Z96WI;'EE<R!B9>%L;.UTX7,@;F5M(&UE;G1H973U(&5L+"!M97)T(&WI
M<F5T92!M96=H86QA9&IA(&$@(@HB;65G96YG961E='0@;6%X:6UU;6]T(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP
M.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*(DYE;2!T86SA;&AA=/,@87H@82!P<F]G<F%M
M(&$@<WIE<G9E<F5N+"!A;6D@<WK\:W/I9V5S(&5N;F5K(&%Z(&%D871T[7!U
M<VYA:R`B"B(H)7,I(&$@;65G:F5L96[M=.ESZ6AE>BXB"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")!>B!I9.EZ]6IE
M;"!K87)A:W1E<B!C<V%K(&5G>65T;&5N(&MA<F%K=&5R(&QE:&5T+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S
M='(@(DIO8F(@Z7,@8F%L(&]L9&%L;VX@;&5G>65N(&ME<F5T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM
M<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D-S86L@
M:F]B8B!O;&1A;&]N(&QE9WEE;B!K97)E="(*"B,Z(&QI8B]&:6QE+T-35BYP
M:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(D%Z(&5L=N%L87-Z=/,@:V%R86MT97(@
M8W-A:R!E9WEE=&QE;B!K87)A:W1E<B!L96AE="XB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!*'HI
M(%PB)7-<(B!S>F5R=F5R="!T]G+V;'3\:RXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B02AZ*2!<(B5S
M7"(@<WIE<G9E<G0@96QM96YT971T_&LN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B)7,@8F5J96QE;G1K
M97KI<VD@:^ER96QMZ70@=/9R]FQT_&LN(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B02!M96=A9&]T="!S;W(@*"5D*2!N96T@;.ET97II:RXB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D$H
M>BD@7"(E<UPB(&ED96EG;&5N97,@9N%J;"!N96T@;.ET97II:RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,P-@IM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R(")!(&)E[7)T('-Z]G9E9R!N96T@96=Y97II:R!A(&OI<&5R;GGU
M;B!L97;U=F5L+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(D%L=6P@Z7,@9O9L_&P@;&5G>65N(&ME<F5T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B0W-A
M:R!F96YT(&QE9WEE;B!K97)E="(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")!(&9E;'3V;'3V='0@861A=&]K
M(&%Z(&5L]7KU(&SI<.ES(/-T82!E;'9E<WIT96LN(@H*(SH@;&EB+TAO<F1E
M+T1A=&$O8W-V+G!H<#HR-C(@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S(*
M;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB
M"FUS9W-T<B`B02!F96QT]FQT]G1T(&;A:FQT(&YE;2!S:6ME<OQL="!E;&UE
M;G1E;FDN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!('=E
M871H97(N8V]M(&)L;VMK(&YE;2!H87-Z;N%L:&%T\RXB"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S
M(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!(&UE9VIE
M;&5NZ7-I('-T[6QU<R`H=&AE;65S*2!A;&OV;GEV=.%R(%PB)7-<(B!N96T@
M=&%LX6QH873S+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS
M9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@
M(DYI;F-S96X@=N%L87-Z=&AA=/,@;W!C:?,N(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S
M('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DYI;F-S
M(&$@;&5VZ6P@8F5L<V5JZ6)E;B!M96=J96QE;NUT:&5T]2!M96QLZ6ML970N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E3Z;"!S
M;VL@:V%R86MT97(@=F%N(&5B8F5N(&$@;65Z]6)E;BX@UFX@)7,@:V%R86MT
M97)T(&%D;W1T(&UE9SL@82`B"B)M87AI;>%L:7-A;B!M96=A9&AA=/,@<&5D
M:6<@:V5V97-E8F(L(&UI;G0@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI
M;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS
M9W-T<B`B7"(E<UPB(&9E;&AA<WINX6SS;F%K(&$@<F5N9'-Z97)H97H@863A
M<V%K;W(@:&EB82!T]G)TZ6YT+B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L
M96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@
M(@IM<V=S='(@(EPB)7-<(B!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES
M92!S;W+A;B!H:6)A(&SI<&5T="!F96PZ("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")<
M(B5S7"(@<F5N9'-Z97)B]6P@=F%L\R!T]G)LZ7-E:V]R(&AI8F$@;.EP971T
M(&9E;#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E
M<R(*;7-G<W1R(")<(B5S7"(@;?-D;W/M=.%S82!S;W+A;B!H:6)A(&SI<&5T
M="!F96PZ("5S(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*
M(D%Z(.%L;&]MX6YY="!N96T@<VEK97+\;'0@82!S>F5R=F5R<F4@9F5L=/9L
M=&5N:2X@)7,@;F5M('3V;'3U9/9T="!F96PN(@H*(SH@;&EB+TAO<F1E+T)R
M;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@
M8GET97,I+B(*;7-G<W1R("(B"B)!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT
M(&$@<WIE<G9E<G)E(&9E;'3V;'1E;FDN("5S(&YA9WEO8F(L(&UI;G0@82`B
M"B)M87AI;>%L:7-A;B!M96=E;F=E9&5T="!MZ7)E="`H)60@8N%J="DN(@H*
M(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G
M<W1R("(B"B)!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@<WIE<G9E<G)E
M(&9E;'3V;'1E;FDN($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G>2`B"B)RZ7-Z
M92!T]FQT]63V='0@9O9L+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")!(&QE=NEL(&4@<NES
M>NEN96L@;65G:F5L96[M=.ES96MO<B!H:6)A('3V<G3I;G0B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B02!P87)T
M;F5R(&%D871O:R!I;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N(@H*
M(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(D%Z(&E#86QE;F1A<B!A9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB
M82!T]G)TZ6YT+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I
M96QD+B(*;7-G<W1R("(B"B)(:6+A<R!A(&UE9V%D;W1T(&MO;F9I9W5RX6-I
M\RX@3&5H970L(&AO9WD@;F5M('3V;'3V='0@:VD@96=Y('-Z_&MSZ6=E<R`B
M"B)M97KU="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*
M(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB02!P87)T;F5R:F5G>7KI
M:VME;"!K87!C<V]L871O<R!F96QA9&%T(';I9W)E:&%J=.%S82!S;W+A;B!H
M:6)A(&SI<&5T="!F96PN("(*(DOI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M(DAI8F$@=/9R=.EN="!A('!A<G1N97(@861A=&%I;F%K(&9R:7-S[73I<V4@
M<V]RX6XN($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-2!L:6(O3F5T+U--4R]W:6Y?
M:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B)!(&OV<FQE=NEL;&ES=&$@861A=&%I;F%K
M(&9R:7-S[73I<V4@<V]RX6X@:&EB82!T]G)TZ6YT+B!+Z7)E;2!P<O-BX6QJ
M82!M96<@(@HB:^ES]6)B+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@
M<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*(D5Z(&%Z($E-
M05`@<WIE<G9E<B!N96T@=.%M;V=A=&IA(&$@;6%P<.%K:&]Z('9A;/,@:&]Z
M>N%FZ7+I<R!M96=O<WITX7/A="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B17H@;F5M('3[;FEK
M('-Z86+A;'EO<R!R87(@X6QL;VWA;GEN86LN(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(D5Z(&YE;2!T
M^VYI:R!S>F%BX6QY;W,@>FEP(.%L;&]MX6YY;F%K+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3,Q"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B17H@;F5M('3[;FEK
M(.ER=NEN>65S(&OA<G1Y87-ZX6UN86LN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D5Z(&$@;65G:&%J=/,@;&5H973U
M=ND@=&5S>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN
M:R!A("(*(D-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@<WIO
M;&?A;'1A=/-N(.%T+B(*"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ
M,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*
M(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)%>B!A
M(&UE9VAA:G3S(&QE:&5T]7;I('1E<WII+"!H;V=Y($A45%`M:V%P8W-O;&%T
M;VX@4TU3+70@:_QL9&K\;FL@82!724X@(@HB*&AT='`Z+R]W:6YP;&,N8V]M
M*2!S>F]L9^%L=&%T\VX@X70N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*(D5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S>FDL
M(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A>B`B"B)S
M;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!S>F]L9^%L=&%T\VX@
MX70N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB
M9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E
M<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT
M='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB17H@82!M96=H86IT\R!L
M96AE=/5VZ2!T97-Z:2P@:&]G>2!33510+6MA<&-S;VQA=&]N(%--4RUT(&O\
M;&1J_&YK(%9O9&%F;VYE("(*(G-ZX6UO:W)A(&$@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2!S>F]L9^%L=&%T\VX@X70N($$@(@HB<WIO
M;&?A;'1A=.%S(&EGZ6YY8F5VZ71E;.EH97H@5F]D869O;F4@271A;'D@96UA
M:6P@8^UM('-Z_&MSZ6=E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@R
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,#DP"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,3@V(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`Y(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-38Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#`Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#@R(&QI8B](;W)D92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,C(U(&QI8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI8B](
M;W)D92]&;W)M+G!H<#HR-#4T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0Q
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T(&QI8B](;W)D92]&;W)M+G!H<#HS
M,3(S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`Q(&QI8B](;W)D92]&;W)M
M+G!H<#HS.#`Y(&QI8B](;W)D92]&;W)M+G!H<#HS.#$W"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")%>B!A(&UE>O4@;F5M(&UA
M<F%D:&%T(/QR97,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-CD*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS
M9W-T<B`B16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA;6]K(.%L;&AA
M=&YA:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R,`IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BXB"FUS9W-T<B`B16)B96X@82!M97KU8F5N(&-S86L@96?I<WH@<WKA;6]K
M(.ES(&ME='3U<W!O;G0@;&5H970N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(D5B8F5N(&$@;65Z]6)E;B!C<V%K(&]K=.%L
M:7,@<WKA;6]K(.%L;&AA=&YA:RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A
M8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB17H@
M82!M97KU(&-S86L@=F5S<WKU=F5L('9A9WD@<WKS:_9Z>F5L(&5L=N%L87-Z
M=&]T="!E9^ES>B!S>N%M;VMA="`B"B)T87)T86QM87IH870B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D5Z(&%Z(.ER=.EK(&-S86L@<WKA
M;2!L96AE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R,@IM<V=I9"`B
M(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H
M92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*
M;7-G<W1R(")%8F)E;B!A(&UE>O5B96X@:&5X861E8VEMX6QI<R!21T(@<WKM
M;FOS9"#A;&QH870L('!L+B`G(S$R,S1A9B<N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@
M<')O8V5S<V5D+B(*;7-G<W1R(")%>F5N(&%D871O:VMA;"!K87!C<V]L871O
M<R!F96QA9&%T;VMA="!A('-Z97)V97(@;>%R(&5L=NEG97IT92XB"@HC.B!T
M96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&ES("5S+B(*;7-G<W1R(")%>B`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G
M<W1R("(B"B)%>B!E9WD@2V]L86(@1W)O=7!W87)E(&]B:F5K='5M+B!!>B!I
M;'EE;B!O8FIE:W1U;2!M96=J96QE;NUTZ7/I:&5Z(&]L>6%N("(*(F5M86EL
M(&ML:65N<W!R;V=R86T@<WK\:W/I9V5S+"!A;65L>2!KZ7!E<R!A($MO;&%B
M($=R;W5P=V%R92!F;W)MX71U;2`B"B)K97IE;.ESZ7)E+B!);'EE;B!E;6%I
M;"!K;&EE;G-E:R!L:7-TX6IA(&SA=&AA=/,@:71T.B`E<R(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(D5Z="!A(&QE
M=F5L970@;>%S(&MA<F%K=&5R:^ES>FQE='1E;"`H)7,I(.UR=.%K+"!M:6YT
M(&%M:70@UFX@:&%S>F[A;"XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N
M(@IM<V=S='(@(D5Z(&$@<WKA;2!N96T@;&5H970@96=Y;NEL(&MI<V5B8BXB
M"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R(")%>B!A('-Z97)V97(@;F5M(&OI<&5S(&MI8F]N=&%N:2!A
M('II<"!I;&PN(&=Z:7`@X6QL;VWA;GEO:V%T+B(*"B,Z(&QI8B](;W)D92]2
M96=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(D5Z(&$@<F5N9'-Z97(@:F5L96YL
M96<@:6YA:W1I=N%L=F$@=F%N+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM
M<V=S='(@(D5Z(&%Z(.ER=.EK(&-S86L@<WKA;2!L96AE="XB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM
M<V=S='(@(D5Z="!A>B!A8FQA:R!C<V%K(&%Z($]P8VGS:R!A8FQA:V+S;"!H
M[79H873S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C4*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B5FEL;.%M;.%S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R(")(:6)A8F5J96QE;G3I<RUK97IE;.ES(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(T,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")4:6UE(@IM<V=S='(@(DED]2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B
M375N:V%I9/4M;GEI;';A;G1A<G3A<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B263U(&9O<FWA='5M
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(DED]2!VX6QA<WITX7,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO
M<BU,97-T92(*;7-G<W1R(")+96QE="U4:6UO<B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U;'5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET
M;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")#[6T@*'1O;VQT:7`I(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM
M<V=S='(@(D/M;7IE='0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E
M;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA
M8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)(82!T]F)B
M(&5L96UE="!I<R!K:2!A:V%R(&IE;/9L;FDL('1A<G1S82!L96YY;VUV82!A
M($-O;G1R;VP@*%!#*2!V86=Y(&$@(@HB0V]M;6%N9"`H36%C*2!B:6QL96YT
M>?MT(&$@:V%T=&EN=.%S(&OV>F)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")-82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G
M:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(&9O<G+A<V[I
M>F5T(&MI+V)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T
M<B`B2&]L;F%P(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S<*;7-G:60@(E1O<"(*;7-G<W1R(")F]FS\;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M
M92`H7W1O<"DB"FUS9W-T<B`B3&5G9F5L<_4@9G)A;64@*%]T;W`I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B
M"FUS9W-T<B`B1F]R9.UTX7-O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B5')I;FED860@Z7,@5&]B86=O(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T
M<B`B26=A>B!V86=Y(&AA;6ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B2V4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;NEZ:6$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=7)K97DB"FUS9W-T<B`B5/9R]FMO<G-ZX6<B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T
M<B`B=/9R]FL@*$E33RTX.#4Y+3DI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(E3\<FMM96YI<WITX6XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,M(.ES($-A:6-O<RUS>FEG
M971E:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!L
M:6(O2&]R9&4O0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z
M("(*;7-G<W1R("+-<FIA(&)E+"!M:70@=N%L87-Z=&]T=#H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E
M>#H@(@IM<V=S='(@(E56(&EN9&5X.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"B)54DPL(&UE;'EE
M;B!E9WD@<')O9W)A;2!E;&9O9V%D:F$@82!S>F]L9^%L=&%T\R#A;'1A;"!K
M_&QD]G1T(&O\;&3V='0@(@HB:^EZ8F5S[73I<VD@:F5L96YTZ7-T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I
M9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S
M='(@(E5G86YD82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86IN
M82(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A
M(%9&4R!A;&OV;GETX7)B82!B96SI<&YI+B(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*(D$@
M8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6<@:6?I;GELZ7-E:V]R(&YE;2!S
M:6ME<OQL="!A>B!A9&%T;VL@96QTX7)O;.%S82XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B
M"B).96T@<VEK97+\;'0@82AZ*2!<(B5S7"(@5D93(&;A:FP@96SI<NES:2!J
M;V=O<W5L='/A9V%I="!M96=VX6QT;WIT871N:2XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,Y,B!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B(@HB3F5M('-I:V5R_&QT(&$H>BD@)7,O
M)7,@5D93(&;A:FP@96SI<NES:2!J;V=O<W5L='/A9V%I="!M96=VX6QT;WIT
M871N:2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DYE;2!S
M:6ME<OQL="!A*'HI("5S(&%L:_9N>79TX7)B82!B96SI<&YI+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(D$H>BD@
M7"(E<UPB(.%L;&]MX6YY(&WI<F5T92!N96T@X6QL87#M=&AA=/,@;65G+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-CDU(&QI8B]61E,O<W%L+G!H<#HQ,#(X
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS
M9W-T<B`B02AZ*2!<(B5S+R5S7"(@X6QL;VWA;GD@;>ER971E(&YE;2#A;&QA
M<.UT:&%T\R!M96<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S
M='(@(D%Z(%-13"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C@W,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!3
M4TPN(@IM<V=S='(@(D%Z(%-33"!K87!C<V]L870@;F5M(.EP[71H973U(&9E
M;"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(S,B!L:6(O5D93+V9I;&4N<&AP
M.C(S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(D$@5D93(&;A:FP@
M;F5M(&WA<V]L:&%T\R#A="XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S<P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!A*'HI(%PB)7-<
M(B!61E,@86QK]FYY=G3A<G0@;.ET<F5H;WIN:2XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,V,2!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@5D93
M(&%L:_9N>79TX7)T+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$R-`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B3F5M('-I
M:V5R_&QT(&SI=')E:&]Z;FD@82!61E,@9N%J;'0N(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<(B!6
M1E,@;6%P<&$@;F5M(&AO>FAA=/,@;.ET<F4N(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!LZ71R96AO>FYI(/QR97,@5D93
M(&;A:FQT+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]T87(N<&AP.C<V(&QI
M8B](;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O
M(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B02!T]FWV<NUT971T(.%L;&]M
MX6YY="!N96T@<VEK97+\;'0@:VEB;VYT86YI+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR,C@@;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(EPB)7-<(B!N96T@=/9R]FQH973U+"!A
M>B!A;&OV;GEV=.%R(&YE;2#\<F5S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(EPB
M)7-<(B!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HS,S@@;&EB+U9&4R]S<6PN<&AP.C,Y-2!L:6(O5D93+VUU<W%L
M+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S(&YE;2!T]G+V;&AE=/4L(&%Z
M(&%L:_9N>79TX7(@;F5M(/QR97,N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R
M(")!(%9&4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4@<F5K=7)Z[79A;BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,T-"!L:6(O5D93+VUU<W%L+G!H<#HS
M,C(@;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C,T,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B02!61E,@86QK]FYY
M=G3A<B!N96T@=/9R]FQH973U+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@
M;&EB+U9&4R]S<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")!(%9&
M4R!A;&OV;GEV=.%R(&YE;2!T]G+V;&AE=/4Z("5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB(%9&
M4R!FX6IL(&YE;2!T]G+V;&AE=/4N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS
M,3`@;&EB+U9&4R]S<6PN<&AP.C(Y,2!L:6(O5D93+VUU<W%L+G!H<#HQ-C<*
M(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P(&QI8B]61E,O;75S<6PN<&AP.C$X
M-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*
M;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!T]G+V;&AE=/4N(@H*(SH@;&EB+U9&
M4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")!*'HI(%PB)7-<
M(B!61E,@;6%P<&$@;F5M('3V<O9L:&5T]2XB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3F5M(';I9V5Z:&5T\R!R
M96MU<GKM=B!T]G)LZ7,@82!61E,M8F5N.B`E<RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z.#,T"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+B(*;7-G<W1R(").96T@:&%TX7)O>FAA=/,@;65G(&$@:F5L
M96YL96<@Z7)VZ6YY97,@86QK]FYY=.%R+B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS(@IM<V=S='(@(D$@=&%N^G/M=';A;GD@<NES>FQE
M=&5S(&%D871A:2!N96T@:&%TX7)O>FAA=/-K(&UE9R(*"B,Z(&QI8B].970O
M24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(DYE;2!S:6ME<OQL="!B96]L=F%S;FD@)7,@9&5F
M:6[M8VGS:N%T+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`S(&QI8B]61E,O
M9FEL92YP:'`Z,C`X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$W-`HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R(")!(%9&4R!FX6IL(&YE;2!H96QY97IH973S(.%T
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V
M(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP.CDX"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@5D93(&;A:FP@;F5M(&YY:71H
M873S(&UE9RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X-"!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B02!61E,@9N%J;"!N96T@;GEI=&AA=/,@;65G(.URX7-I(&/I;&QA;"XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP:'`Z,3,W
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`B02!61E,@9N%J;"!N96T@;GEI=&AA=/,@
M;65G("XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM
M<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G
M<W1R(")!('3V;?9R[71E='0@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RXB
M"@HC.B!L:6(O5D93+G!H<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(D$@5D93(&;A
M:FP@;F5M(&]L=F%S:&%T\R`H82!F:6QE<VEZ92@I('-I:V5R=&5L96X@=F]L
M="DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")!
M(%9&4R!FX6IL(&YE;2!O;'9A<VAA=/,@*&$@9V5T1FEL95-I>F4H*2!S:6ME
M<G1E;&5N('9O;'0I+B(*"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<B]N
M;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S
M='(@(D5Z(&$@9N%J;"!N96T@;VQV87-H873S.B`B"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@
M9&ER96-T;W)Y+B(*;7-G<W1R(")!('9F<W)O;W0@86QK]FYY=G3A<B!N96T@
M;VQV87-H873S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B)7,@
M;F5M(&YE=F5Z:&5T]2#A="`E<R!NZ79R93H@;>%R(&SI=&5Z:6L@:6QY96X@
M;F5V^R!M87!P82(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")!
M(%9&4R!A;&OV;GEV=.%R(&YE;2!N979E>FAE=/4@X70N(@H*(SH@;&EB+U9&
M4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")!(%9&4R!A;&OV
M;GEV=.%R(&YE;2!N979E>FAE=/4@X70Z("5S+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B02AZ*2!<(B5S7"(@5D93(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C8Q-R!L:6(O5D93+VUU<W%L+G!H<#HR,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B02AZ*2`E<R\E<R!61E,@9N%J;"!N96T@;F5V
M97IH973U(.%T+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,C8@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,C$S(&QI8B]61E,O;75S<6PN<&AP.C0U,@HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")!(%9&
M4R!FX6IL(&YE;2!N979E>FAE=/4@X70N(@H*(SH@;&EB+U9&4R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O
M9G,G+B(*;7-G<W1R(")!>B`G;6MI<V]F<R<@<')O9W)A;2!N96T@9G5T=&%T
M:&%T\RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU
M.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0B"FUS9W-T<B`B3F5M('-I:V5R_&QT(&QE9F]R9.UT86YI(&5Z="!A(%=O
M<F0@9&]K=6UE;G1U;6]T(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$U-"!L:6(O
M5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D$H>BD@7"(E<UPB
M(%9&4R!FX6IL(&YE;2#M<FAA=/,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(D$@5D93(&;A:FP@;F5M(.UR:&%T\R`H82!C;W!Y
M*"D@<VEK97)T96QE;B!V;VQT*2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X
M."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#8@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B02!61E,@9N%J;"!A9&%T86D@;F5M(.UR:&%T\VL@:VDN(@H*
M(SH@;&EB+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(D$@5D93
M(&;A:FP@[7+A<V$@:W;S=&%T^FQLZ7#I<R!M:6%T="!N96T@9F5J97IH973U
M(&)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")A;.%H^GIO='0B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`B3>EG<V4@;65N='/\:R!E;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(E9I<W-Z879O;FIA(&%Z('5T;VQS
M\R!VX6QT;WIT873A<W0B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C(Q(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(B(*(D$@:V%P8W-O;&%T(&9E;';I=&5LZ70@
M:_9V973U96X@=N%R871L86X@=N%L87-Z(.ER:V5Z971T(&$@<WIE<G9E<G3U
M;#H@(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-R!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E;A<F%T;&%N(';A;&%S>B#I<FME
M>F5T="!A('-Z97)V97)T]6P@97)R93H@(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T
M<B`B0F5S;W)O;&%T;&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M
M."DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B16=Y
M97/\;'0@07)A8B!%;>UR<^EG96LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M
M(@IM<V=S='(@(D5G>65S_&QT($MI<N%L>7/A9R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B16=Y97/\;'0@P6QL86UO:R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R
M(")%9WEE<_QL="#!;&QA;6]K+"!K:7-E8F(@:_QL<_4@<WII9V5T96LB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T<B`B96=Y<^EG(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU
M.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("))<VUE<F5T;&5N(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B27-M97)E
M=&QE;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(DES;65R971L
M96X@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!(&UE9V%D;W1T(&AE;'D@:7-M97)E
M=&QE;BXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T
M<B`B27-M97)E=&QE;B!F96QH87-Z;N%L\VD@;NEV('9A9WD@:F5L<WKS+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS
M9W-T<B`B5.%V;VSM='-U:R!E;"!I;FYE;B!A(&QI;FME="(*"B,Z(&QI8B](
M;W)D92])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@
M(DYI;F-S(&5L;F5V97IV92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E
M(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO
M=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L
M:7!B;V%R9"XB"FUS9W-T<B`B(@HB0FEZ=&]N<^%G:2!O:V]K8O-L(&$@9F5L
M:&%S>F[A;/-I('!R;V=R86UO:R!N96T@:&%S>F[A;&AA=&KA:R!A($MI=N%G
MX7,O(@HB3>%S;VSA<R]"96EL;&5S>G3I<R!M\V1S>F5R="X@2V%T=&EN='-O
M;B!A>B!/2R!G;VUB<F$L(&AA(&$@;6]Z:6QL82YO<F<@(@HB=V5B;VQD86QO
M;B!E;"!K[7;A;FIA(&]L=F%S;FD@82!T96-H;FEK86D@;&7M<N%S="!M96QY
M(&UE9V%D:F$L(&AO9WEA;B!L96AE="`B"B)E>G0@;>EG:7,@96YG963I;'EE
M>FYI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(D$@<WKM
M;B!V:7-S>F'A;&SM=.%S82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%
M>'1E;G-I;VXB"FUS9W-T<B`B3F5M('3A;6]G871O='0@97AT96YZ:?,B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(DWS9&]S
M[73A<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B5S(&%D
M871A:6YA:R!M\V1O<^UTX7-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B02!F
M96QH87-Z;N%L\R!A9&%T86EN86L@;?-D;W/M=.%S82(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@=N%L=&]ZX7-A:70@96QM
M96YT971T_&LN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G
M:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(D%Z('5P9W)A
M9&4@<')O9W)A;6]T('3V<O9L=/QK+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y
M.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(D9E;'3V;'3I<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")!
M>B#V<W-Z97,@86QK86QM87KA<R!K;VYF:6=U<N%C:?-JX70@9F5L=/9L=/9T
M=/QK(&$@<WIE<G9E<G)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B;&%T:6X@;F%G>6)E=/MK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")N86=Y8F5T^W,@
M<O-M86D@<WKA;6]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G
M=6%Y(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S
M='(@(DAA<WINX6QJ=6L@82!J96QE;FQE9VET.B`E<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS
M9W-T<B`B2&%S>F[A;&IU;FL@4U-,+70B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F
M97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B)!:VMO<B!H87-Z
M;N%L:G5K+"!H82!A>B!)35-0('-Z97)V97)E;B!MX7,@82!B96IE;&5N=&ME
M>NES:2!N97;\;FLO(@HB:F5L<WIA=G5N:RXB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(D9E
M;&AA<WINX6SS:2!NZ78B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`B)7,@9F5L:&%S>F[A;/,@;F5M(&IO9V]S
M=6QT("5S+7)E+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E
M<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")&96QH87-Z;N%L\VL@861M:6YI
M<WIT<N%LX7-A(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")&96QH87-Z;N%L\VD@8F7A;&SM
M=.%S;VLB"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B(*;7-G<W1R(")"96IE;&5N=&ME>NES(&IO9V]S=6QT<^%G(&EGZ6YY
M;.ES92(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T
M:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@
M(B(*(D5Z96X@82!R96YD<WIE<F5N(&YI;F-S(&5N9V5DZ6QY97IV92!A>B#Z
M:B!F96QH87-Z;N%L\VL@8F5J96QE;G1K97KI<VD@(@HB:F]G;W-U;'1SX6?A
M;F%K(&EGZ6YY;.ES92XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y
M"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(D%Z(&9E
M;&AA<WINX6SS:2!A>F]N;W/M=/,@;F5M('1A;.%L:&%T\R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DX(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ
M-3`*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B1F5L:&%S
M>F[A;/-I(&[I=B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B02AZ*2!<(B5S7"(@9F5L:&%S>F[A;/-I(&[I
M=B!MX7(@;.ET97II:RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")&96QH87-Z;N%L\VD@
M;NEV.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@
M(E5S97)N86UE.B`B"FUS9W-T<B`B1F5L:&%S>F[A;/-I(&[I=CH@(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@
M:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B02!R96YD<WIE<B!F96QH87-Z;N%L
M\VDZ(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("+<>F)E9VES>G3A
M;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]61E,O9FEL92YP:'`Z
M,C8R"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R(")!(%9&4R!A;&OV;GEV=.%R(&YE;2!LZ71E>FEK+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S
M='(@(E-Z86)A9'/A9R!A;&%T=&D@875T;VUA=&EK=7,@96UA:6PM=N%L87-Z
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")!(&OV=F5T:V5Z]2!H
M96QY96ME="!T86SA;'1U:SH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(LER=NEN>65S<^EG
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B07H@Z7)TZ6ME:V5T('!E
M<F-B96X@861J=6L@;65G+"!M;W-T86YT\VP@<WKA;>UT=F$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@V,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M
M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B02#I<G3I:R!N86=Y;V)B+"!M:6YT
M(&$@;&5G;F%G>6]B8B!M96=E;F=E9&5T="!H;W-S>OISX6<Z("5S+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C0X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C<P(&QI8B](;W)D92]&;W)M+G!H<#HR,S(P"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3$T(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y
M"FUS9VED(")686QU97,B"FUS9W-T<B`BR7)TZ6ME:R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS9VED
M(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5N%L87-Z=&AA=/,@
MZ7)TZ6ME:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(G;A;'1O>O,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B
M"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE
M<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B
M"B)!(&AI=&5L97/M=.ES(&YE;2!S:6ME<OQL="`M(&QE:&5T+"!H;V=Y(&$@
M;&5V96QE="!V86QA:VD@;65G=N%L=&]Z=&%T=&$N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B
M5F5R>FGS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I
M9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<GII\VOV=F5TZ7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")&_&=G+B!E;&AE
M;'EE>NES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")&_&=G
M]6QE9V5S(&)E;'/U(&UA<F?S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@
M(F;\9V?U;&5G97,Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S$*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")N86=Y;VX@
M;6%G87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@
M*%9)4T-)22DB"FUS9W-T<B`B=FEE=&YA;6D@*%9)4T-)22DB"@HC.B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.3<P"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`B)7,@;65G=&5K:6YTZ7-E(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G92(*;7-G<W1R(")+_&QS]2!W96)O;&1A;"!M96=J96QE;NUTZ7-E
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(DIE;&5N[71S_&L@
M;65G+"!M:6YT("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`B0G)I="!6:7)G:6XM<WII9V5T96LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")!;65R:6MA:2!6:7)G:6XM
M<WII9V5T96LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B
M5FES:6)I;&ET>2(*;7-G<W1R("),X73S=.%V;VQSX6<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B
M"FUS9W-T<B`B3.%T\W3A=F]L<^%G.B`B"@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V
M:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L>2!S>F]L9^%L=&%TX7,@
M4TU44"UN(&ME<F5S>G3\;"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")&
M24=914Q-15I4153)4R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")&24=914Q-15I4153)4R$@
M2\E:6D5,(%3!5D],S51302!%3"!!(%-#4DE05$54("5S+5+53"XB"@HC.B!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A4
M5%`B"FUS9W-T<B`B5TE.('-Z;VQGX6QT873A<R!(5%10+6X@X70B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@Z7,@1G5T
M=6YA(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM
M<V=S='(@(D9I9WEE;&UE>G1E=.ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B4WIE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")7
M96%T:&5R($9O<F5C87-T(@IM<V=S='(@(DED]6KA<N%S(&5L]7)E:F5L>NES
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D%Z(&ED]6KA<N%S
M:2!A9&%T;VL@9F]R<N%S82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.38*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS
M9W-T<B`B5V5B:&5L>65K(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(FAE=&5N=&4B"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G
M<W1R("+<9';V>O9L:OQK(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BW&1V]GKV;&K\:SH@
M)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92P@)7,B"FUS9W-T<B`BW&1V]GKV;&K\:RP@)7,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB
M"FUS9W-T<B`B;GEU9V%T+65U<O-P86D@*$E33RTX.#4Y+3$I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$U*2(*;7-G<W1R(")N>75G870M975R\W!A:2`H25-/+3@X-3DM,34I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(DYY=6=A="U3>F%H87)A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/R(*;7-G<W1R(")-:6QY96X@86QK86QM87KA<W0@;75T87-S
M;VX@)7,@82!B96IE;&5N=&ME>NES('5TX6X_(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E
M<B!C:&%R86-T97(_(@IM<V=S='(@(DUI(&%Z(&5L=N%L87-Z=/,@:V%R86MT
M97(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@
M(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B36D@87H@
M:63I>F5T:V%R86MT97(_(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C0*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*
M;7-G<W1R(")7:&5R96ES($%U<WIT<N%L:6$@=.ER:^EP(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B
M365L>6EK(&-I:VQU<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*
M;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB"FUS9W-T<B`B365L>6EK(&UO9'5L;VMA="!A:W1I=N%L
M:G5K(&$@4FEC:"!497AT(&5D:71O<F)A;C\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T
M:"(*;7-G<W1R(")3>NEL97-SZ6<B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$Q,0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(E-ZZ6QE
M<W/I9R!#4U,@96=Y<^EG8F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB
M"FUS9W-T<B`B(@HB02`E<R!M96[\('-ZZ6QE<W/I9V4@82!B86P@;VQD86QO
M;B`H82!K]G9E=&ME>O4@8F5J96QE;G1K97KI<W0@:_9V973U96X@;&5S>B`B
M"B+I<G;I;GEE<RDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S
M='(@(D$@=.%B;.%Z870@<WKI;&5S<^EG92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(D$@<WKI;&5S<^EG(&WI<G3I:V5G>7/I9V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B
M5VED=&@Z(@IM<V=S='(@(E-ZZ6QE<W/I9SHB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM<V=S
M='(@(E-ZZ6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-PIM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")3>NEL(&$@<F5G
M9V5L:2#S<N%K8F%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I
M9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")3>NEL<V5B97-SZ6<@
M8W-O;?-B86XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`B4WKI;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B4WKI;#H@(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS
M9W-T<B`B0O9L8W-E<W/I9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(DOM=N%N<^%G;&ES=&$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS
M9W-T<B`B375N:V$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(DUU;FMA:&5L>6D@8^UM(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@
M(E=O<FL@4&AO;F4B"FUS9W-T<B`B375N:V%H96QY:2!T96QE9F]N(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(D$@)60N
M('-O<F)A;B!N96T@;65G9F5L96SU(&$@;65Z]6L@<WKA;6$N(%;A<G0Z("5D
M+"!T86SA;'0Z("5D+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B3F5M(&UE9V9E;&5L]2!A(&UE
M>O5K('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"XB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S
M970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")(:6+A
M<R!O9F9S970@*"5D*2!A(%9&4R!FX6IL(&]L=F%SX7-A:V]R+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F(@IM<V=S
M='(@(DQI;G5X(&9O<G+A<VOS9"!K97)E<WIR969E<F5N8VEA(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@86QA<'9E=/4@:V]R;.%T
M;WKA<V]K(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S
M(&MI=&5R:F5S>G1E='0@:W5L8W-H87-Z;N%L870B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT
M97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@='5L86ID;VYO<R!A;'1E
M<FYA=.UV(&UE9VYE=F5ZZ7-E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(E@U,#EV,R!T=6QA:F1O;F]S(&MU;&-S87IO;F]S[73S(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV
M,R!E>'1E;G-I;VYS(@IM<V=S='(@(E@U,#EV,R!K:71E<FIE<WITZ7-E:R(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")9
M62(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,30@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B
M65E962(*;7-G<W1R(")965E9(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B
M66%H;V\A('3I<FOI<"(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+I=F5N=&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")9
M96UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R("))9V5N(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("))9V5N+"!B96QE9WEE>F5M
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B
M"B)-;W-T($A434P@5$585"!M\V1B86X@=F%N+B!(87-Z;N%L:F$@82!;/#Y=
M(&=O;6)O="P@:&$@=FES<WIA(&%K87(@=N%L=&%N:2!A("(*(G-Z;VOA<V]S
M(&=R869I:W5S("A765-)5UE'*2!M96=J96QE;NUTZ7-R92XB"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E
M('1H86X@)60@8FQO8VMS+B(*;7-G<W1R(").96T@:&]Z:&%T(&SI=')E("5D
M(&)L;VMK;N%L('3V8F)E="XB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,34*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D%Z(-9N
M(&9E;&AA<WINX6SS87IO;F]S[73A<V$@;F5M('3V<G3I;G0@;65G+B(*"B,Z
M(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T
M(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*
M;7-G<W1R(")!('1E;&IE<R!NZ79B96X@;F5M('-Z97)E<&5L:&5T(&$@)UQ<
M)R!K87)A:W1E<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").96T@861O='0@;65G
M(.ER=NEN>65S(&5M86EL(&/M;65T+B(*"B,Z(&QI8B](;W)D92]$871A+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB3F5M(&%D
M=&$@;65G(&$@;65G9F5L96QT973I<W0@87H@:6UP;W)TX6QT(&;A:FP@Z7,@
M82AZ*2`E<R!M97KU:2!K]GKV='0N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R
M(")3:6ME<F5S96X@:VEJ96QE;G1K97IE='0N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+B(*;7-G<W1R("(B"B)%9WD@;6]B:6QT96QE9F]N<WKA;6]T(&ME;&P@
M;65G861N:6$L(&-S86L@82!S>N%M:F5G>65K970L(&5S971L96<@96=Y("<K
M)R`B"B)K87)A:W1E<G)E;"!K97ID=F4L(&AA(&YE;7IE=&OV>FD@=.%R8W/A
M>N%S:2!M\V1O="!K[7;A;B!H87-Z;N%L;FDN(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M=F%L=64N(@IM<V=S='(@(D5L9F]G861H873S(.ER=.EK970@:V5L;"!M96=A
M9&YI82XB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S
M92!3:6=N=7!S+B(*;7-G<W1R("(B"B)!($1A=&%4<F5E(&%L<F5N9'-Z97)T
M(&)E(&ME;&P@X6QL[71A;FD@82!B96IE;&5N=&ME>NES:2!J;V=O<W5L='/A
M9V]K("(*(FEGZ6YY;.ESZ6AE>BXB"@HC.B!L:6(O2&]R9&4N<&AP.C0V,@IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(D$@5D93(&%L<F5N9'-Z97(@;FEN8W,@8F7A;&SM='9A+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB16SU8F(@;&4@:V5L;"#M
M<FYI82P@:&]G>2!M:6QY96X@<')O8FSI;>%T('1A<&%S>G1A;'0L(&UI96SU
M='0@96QK_&QD:2!A("(*(FAI8F%J96QE;G3I<W0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU
M<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM
M<V=S='(@(DUE9R!K96QL(&%D;FD@96=Y(%523"UT+"!A:&]V82!E>B!A(&QI
M;FL@;75T870B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM
M<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+B(*;7-G<W1R(")+:2!K96QL(';A;&%S>G1A;FD@96=Y('3V<FQE;F3U('-Z
M97)V97)T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M365G(&ME;&P@861N:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS(&%D871A
M:70@:^UVX6YJ82!T]G+V;&YI+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB
M"FUS9W-T<B`B365G(&ME;&P@861N:6$@87H@96QTX79O;.UT86YD\R!F96QH
M87-Z;N%L\VD@;F5V970N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DUE9R!K96QL
M(&%D;FEA(&$@:&]Z>N%A9&%N9/,@9F5L:&%S>F[A;/,@;F5VZ70N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DUE9R!K96QL(&%D;FEA
M+"!H;V=Y(&UE;'EI:R!F96QH87-Z;N%L\R!A9&%T86ET(&OM=N%N:F$@X73M
M<FYI+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*
M;7-G<W1R(")-96<@:V5L;"!A9&YI82!E9WD@<&%R86YC<V]T+B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DUE
M9R!K96QL(&%D;FEA(&%Z(/IJ(&MA=&5G\W)I82!N97;I="XB"@HC.B!L:6(O
M3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@
M;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S
M='(@(D]L87-Z;W)S>N%G:2!T96QE9F]N<WKA;6]T(&ME;&P@;65G861N:6$B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+B(*;7-G<W1R("(B"B)!>B#6;B`E<R!K87!C<V]L871A(&ED]73Z
M;&SI<.ES(&UI871T(&UE9W-Z86MA9'0N($OI<F5M(&IE;&5N=&ME>GIE;B!B
M92#Z:G)A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X
M"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B07H@UFX@96UA
M:6P@8^UM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B07H@UFX@9F5L863S:2`H
M1G)O;3HI(&/M;64Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.#4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN
M9F]R;6%T:6]N(@IM<V=S='(@(E-Z96WI;'EE<R!I;F9O<FWA8VGS(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*(D%Z(-9N("5S(&MA<&-S;VQA=.%N86L@:V5Z9&5T92#S=&$@;65G=N%L
M=&]Z;W1T(&%Z(&EN=&5R;F5T(&/M;64N("(*(D)I>G1O;G/A9^%N86L@Z7)D
M96OI8F5N(&ES;>ET(&)E(&ME;&P@:F5L96YT:V5Z;FEE+B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B
M"FUS9W-T<B`B07H@UFX@;F5V92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W
M:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N
M=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO
M;B!B86-K96YD+B(*;7-G<W1R("(B"B)!>B#6;B!F96QH87-Z;N%L\V%Z;VYO
M<^UT\R!A;')E;F1S>F5R92!N96T@=&5S>FD@;&5H973U=ND@87H@^FH@9F5L
M:&%S>F[A;/-K("(*(FSI=')E:&]ZX7/A="X@2&$@82!(;W)D92!R96YD<WIE
M<G)E;"!K[7;A;FIA(&ME>F5L;FD@82!F96QH87-Z;N%L\VD@(@HB861A=&]K
M870L(&%K:V]R(&WA<VEK(&9E;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z
M97)R92!V86X@<WK\:W/I9V4N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN(@IM<V=S='(@(B(*(D%Z(-9N(&9E;&AA<WINX6SS87IO;F]S[73S
M(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE=/5VZ2!A(&9E;&AA<WINX6SS
M:R`B"B)L:7-TX7KA<^%T+"!V86=Y('9A;&%M:2!O:V+S;"!L971I;'1O='3A
M:R!E>G0@82!L96AE=/5SZ6=E="XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z
M.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y
M;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB07H@UFX@8O9N9^ES
M>O5P<F]G<F%M:F$@;65G=N%L=&]Z;W1T(&%Z(-9N("5S(&UU;FMA:V%P8W-O
M;&%TX6YA:R!K97ID971E("(*(O-T82X@0FEZ=&]N<^%G82#I<F1E:^EB96X@
M:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN:64N(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B07H@UFX@8O9N9^ES>O5P<F]G
M<F%M:F$@;F5M('3A;6]G871J82!E>G0@82!L96AE=/5SZ6=E="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN
M(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S
M='(@(B(*(D%Z(-9N(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T:F$@
M97IT(&$@;GEO;71A=.%S:2!O<&-I\W0N(%!R\V+A;&IO;B!A("(*(D-T<FPM
M4"`H=F%G>2!#;VUM86YD+5`I(&QE;GEO;>%SX79A;"!N>6]M=&%T;FDN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U<B!C=7)R
M96YT('1I;64@>F]N93HB"FUS9W-T<B`B02!J96QE;FQE9R#I<G;I;GEE<R!I
M9/5Z\VYA.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M(")!>B#6;B!A;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J82!M
M96=VX6QT;WIO='0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")!>B#6;B!A
M;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!A>F]N;W/M=/-J83HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB
M"FUS9W-T<B`B07H@UFX@=&5L:F5S(&YE=F4Z(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B3&5JX7)T(&$@8F5J96QE;G1K97KI<VD@:F]G;W-U;'1SX6=A+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`B07H@UFX@)7,M<F4@:&%S>F[A;'0@^FH@:F5L<WIA=F$Z("5S(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B07H@UFX@^FH@8F7A;&SM=.%S86ET(.ER
M=NEN>65S[71E='3\:R!A(&UO<W1A;FD@8F5J96QE;G1K97KI<R!I9&5JZ7)E
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D%Z(-9N(/IJ
M(&)EX6QL[73A<V%I="!E;&UE;G1E='3\:RXB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="(*;7-G<W1R(")!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"B)!>B#6;B!J96QS>F%VX70@X73A;&SM=&]T='5K+"!NZ7IZ92!M
M96<@82!L979E;&5I="P@;6%J9"!J96QE;G1K97IZ96X@8F4@87H@(@HB^FH@
M:F5L<WKS=F%L+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S,*;7-G:60@
M(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(D%Z(-9N(&IE
M;'-Z87;A;F%K(&QE:N%R="!A>B#I<G;I;GEE<W/I9VD@:61E:F4N(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E
M;6]T92!S97)V97)S.B(*;7-G<W1R(")!>B#6;B#A;'1A;"!H87-Z;N%L="!T
MX79O;&D@<WIE<G9E<F5K.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(DIU9V]S>FSA=FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB
M86)W92(*;7-G<W1R(")::6UB86)W92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6TYE(&UU=&%S<W5K(&$@8F5I9.EZ
M971T('-Z]G9E9V5T72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@Y"FUS
M9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM(:6)A:F5L96YTZ7-=
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6TUU=&%S<W5K
M(&$@8F5I9.EZ971T('-Z]G9E9V5T("TB"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M6TUU=&%S<W5K(&$@8F5I9.EZ971T('-Z]G9E9V5T("T@)7,@<V]R72(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE
M("5S(&]F("5S72(*;7-G<W1R(");)7,O)7,@<V]R72(*"B,Z(&QI8B](;W)D
M92YP:'`Z,34T-2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED
M(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-Z='+A8VGS(@H*
M(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]087)A
M;F-S<V]R(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R
M(")3;W)T]G)LZ7,B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U
M<',B"FUS9W-T<B`B7T-S;W!O<G1O:R(*"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E-E7V?M='/I9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B02!KZ7`@
M='5L86ID;VYSX6=A:2XN+B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.30*
M;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B0F5J96QE;G1K97KI<R(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(E]+:6IE;&5N=&ME>NES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`B02!L:6YK(&WS9&]S[73A<V$N+BXB"@HC.B!L:6(O2&]R
M9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W!C
M:?-K(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B7TIO9V]S=6QT<^%G;VLB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R(")!(&QI;FL@=/9R;.ES92XN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]"9>%L;.UT
MX7-O:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B5.%B;.%Z870@='5L86ID;VYSX6=O:R(*"B,Z(&QI8B]A<&DN<&AP
M.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]&96QH87-Z;N%L\VLB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K
M(@IM<V=S='(@(F/M;6IE9WEZZ6LB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(F$@8^UM>F5T="!I<VUE<F5T;&5N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(FYA<'3A<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U
M"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B;GEU9V]D="(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(")A(&MI;65N971I(.%L
M;&]MX6YY(&YE;2!H;WIH873S(&SI=')E(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G
M<W1R(")A(&)E;65N]2#A;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B8VQI8VL@
M:&5R92(*;7-G<W1R(")K871T:6YT<V]N(&ED92(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(G!A<F%N8W-S;W)I(&AI8F$B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I;VX@
M97)R;W(B"FUS9W-T<B`B:V]N9FEG=7+A8VGS<R!H:6)A(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(FAIX6YY>FEK(&5G>2!F;VYT;W,@
M<F5N9'-Z97+A;&QO;>%N>2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B861A
M=&9O<FWA='5M(&AI8F$B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(FWS9&]S[73A<R(*"B,Z(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(F%Z(&%D870@;F5M('1A;.%L:&%T\R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")F86QL
M:6YG(@IM<V=S='(@(F-S]FMK96XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(F;A:FPB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N<&AP.C,V-R!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B5S("@E<RD@:7+A;GEB
M\VPL("5S("5S('-E8F5S<^EG9V5L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")S>NEL;/9K
MZ7-E:R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-3`*;7-G:60@(F@Z(@IM<V=S='(@(FTZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R(")A(&?I<"!N979E(&YE;2!I<VUE<G0B
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B87IO;FYA;&DB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V,@IM
M<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(FEN<'5T+V]U='!U
M="!H:6)A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS
M9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")B96QS]2!P
M<F]G<F%M:&EB82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B<V]R72(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R("(B"B)!>B!M:W-I;V9S('!R;V=R86T@)60@:&EB86OS9&1A
M;"!L9>%L;'0@87H@25-/(.%L;&]MX6YY(&OI<WKM=.ES92!K]GIB96XN(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I
M9"`B;6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR
M.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@
M(F[I=B(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(D$@<')O9W)A;6YA:R!E>B!A('+I<WIE(&WI
M9R!N:6YC<R!M96=V86SS<^UT=F$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S
M='(@(D$@<')O9W)A;6YA:R!E>B!A('+I<WIE(&WI9R!N:6YC<R!M96=V86SS
M<^UT=F$N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO
M=&5P860B"FUS9W-T<B`B:F5G>7IE='3V;6(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C
M96YT(@IM<V=S='(@(G-ZX7IA;.EK(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M(")N:6YC<R!M96=F96QE;/4@:F]G;W-U;'1SX6=A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B
M<&EX96QS(@IM<V=S='(@(G!I>&5L(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B861A=.%T=FET96QI("AP<F]T;VMO;&PI(&AI8F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B
M<FES:6YG(@IM<V=S='(@(F5M96QK961I:R(*"B,Z(&QI8B](;W)D92]-24U%
M+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*
M;7-G<W1R(")A('-Z;VQGX6QT873A<R!N96T@X6QL(')E;F1E;&ME>NES<F4B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P,0IM<V=I9"`B<VAO=R!D
M:69F97)E;F-E<R(*;7-G<W1R(")NZ7IZ_&L@;65G(&$@:_QL]FYB<^EG96ME
M="(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G
M:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA:6P@<WIO
M;&?A;'1A=.%S($A45%`M;B#A="(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")S
M=&5A9'DB"FUS9W-T<B`B=N%L=&]Z871L86XB"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R
M(")R96YD<WIE<FAI8F$B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PIM
M<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(F9E;&%D871L:7-T82(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`BX71M96YE=&D@:&EB82(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED
M(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@
M(FUE9V5R]7/M=.ES:^EN="!KZ71S>F5R(.UR:F$@8F4@82!J96QS>O-T(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B;NEV
M(&[I;&O\;"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(G5S97(@<V5L96-T(@IM<V=S='(@(F$@9F5L:&%S>F[A;/,@X6QT86P@=N%L
M87-Z=&AA=/,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM<V=S
M='(@(G-Z.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS
M9VED(")W96%T:&5R+F-O;2(*;7-G<W1R("(B"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P;R]F:5]&22YP;P``````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W,S(R,#`@,3`U,34T,S0Q
M-#(@,#$W-#<P`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````",@1FEN;FES:"!T<F%N<VQA=&EO;B!F;W(@2&]R9&4N"B,@0V]P
M>7)I9VAT("A#*0HC($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^+"`R,#`Q
M+3(P,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,BTR-R`Q.3HU,2LP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V
M+3`R+3(T(#$R.C4Y*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@3&5E;F$@
M2&5I;F\@/&QI:6YU0'5T82YF:3Y<;B(*(DQA;F=U86=E+51E86TZ($9I;FYI
M<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q
M+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M
M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S('#D:7;D
MY"!S:71T96XI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<T
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R
M("(@*%!I:V%NY'!PY&EN("5S*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(@*"5S('#D:7;D<W/D*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S<*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H=.1NY.1N
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-SD*;7-G:60@(B`H
M=&]M;W)R;W<I(@IM<V=S='(@(B`H:'5O;65N;F$I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S
M='(@(B`H96EL96XI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@(B!A="`B"FUS9W-T
M<B`B("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM
M<V=S='(@(EPB)7-<(B!E:2!O;&4@:&%K96UI<W1O(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@96D@:V5L
M<&%A('9A;&EN;F%K<VDN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HW,3`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(EPB)7-<(B!E:2!O;&4@87-E;FYE='1U($AO<F1E;B!R96MI<W1E<FES<^0N
M(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS
M9W-T<B`B7"(E<UPB('!U:61E;B!K=79A86IA82!E:2!L]GET>6YY="XB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B!L:7/D='1I:6X@<GEH;>1JY')J97-T96QMY.1N+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN
M(@IM<V=S='(@(EPB)7-<(B!L:7/D='1I:6X@;VEK975K<VEI;BXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D
M.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&5I(&QU;W1U.B`E<RXB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B
M)2XR9DU"(&OD>71E='1Y("4N,F9-0B!S86QL:71U<W1A("@E+C)F)24I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@:F$@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A
M>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R(")386QA
M<V%N87-I('9A;FAE;G1U=2`E9"!PY&EVY&X@<.3D<W3D+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D('#D:7;D;B!E;FYU<W1U
M<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M($EL;6]I='5S
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@
M4V]R;65N:N1L:VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#`@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VXB"FUS9W-T<B`B)7,@66QLY'!I=&]T;VEM96YP:71E970@+2!687)M:7-T
M=7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B
M"FUS9W-T<B`B)7,@87-E;FYU<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5
M<"(*;7-G<W1R("(E<R!K:7)J875T=6UI;F5N(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS
M(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!KY'ET=/9E:&1O="(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S4P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!O;B!J;R!O
M;&5M87-S82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E
M<R!S=75N=&$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!O
M;B!V86QM:7,@<W5O<FET=&%M86%N('EL;.1P:71O=&]I;65N<&ET96ETY"X@
M5F%L:71S92!V86QI;G1A<G5U9'5I<W1A("(*(G-U;W)I=&5T=&%V870@=&]I
M;65N<&ET965T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B
M)7,@;VX@<&%K;VQL:6YE;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@
M;6EN=75T=&EA(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(B5S(&5I(&SV>71Y;GET+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B)7,@+2`E<R`O("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B)7,Z;B!O<V]I=&5K:7)J82(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7,Z;B!K86QE;G1E<FDB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,Z;B!M=6ES=&EL
M:7-T82(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B)7,Z;B!T
M96ATY';D;&ES=&$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<R`Z(%3D
M;>0@=FEE<W1I(&5I(&]L92!VY&QT=.1MY'1TY"!S:6QTY"!LY&AE='3D:N1L
M=.0L(&IO:V$@;VX@;65R:VET='D@(@HB;.1H971TY&KD:W-I+B!3=6AT875D
M=2!V87)A=6MS96QL82!V:65S=&ES<^0@;VQE=FEI;B!L:6YK:V5I:&EN(&IA
M('9A<F\@(@HB86YT86UA<W1A(&SD:&5T=.1JY&QL92!M:73DY&X@>6MS:6SV
M:79IY"!T:65T;VIA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B
M+"!G=7-T:6YG("(*;7-G<W1R("(L('!U=7-K:71T86ES=&$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B
M+"!P=75S:VET=&%I<W1A("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S
M('1O("5S(@IM<V=S='(@(BP@=F%I:'1E;&5V86$@)7,@+2`E<R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3,R"FUS9VED("(M+2!S
M96QE8W0@+2TB"FUS9W-T<B`B+2T@=F%L:71S92`M+2(*"B,Z(&QI8B]";&]C
M:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
M,3(M='5N;FEN(&KD<FIE<W1E;&WD(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"UT=6YN:6X@
M:N1R:F5S=&5L;>0B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM
M<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@='5N=&EA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(CQ%9&5L;&EN96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM
M<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES
M(&)L;V-K+B(*;7-G<W1R(")4:65T;VMA;G1A=&%U<W1A:N1R:F5S=&5L;>3D
M(&5I(&]L92!MY.1R:71E;'1Y('3D;&QE(&]S:6]L;&4B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960B"FUS9W-T<B`B5&%P86AT=6D@=F%K879A('9I<FAE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(")6:65S=&EN('-A;&%U:W-E96X@=&%R=FET86%N(&IU
M;&MI;F5N(%!'4"UA=F%I;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")!;&QE
M:VER:F]I=&5T=6X@=FEE<W1I;B!T87)K:7-T=6MS965N('1A<G9I=&%A;B!J
M=6QK:6YE;B!01U`M879A:6XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E-A;&%T=6X@=FEE
M<W1I;B!A=F%A;6ES965N('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL
M('-A;&%I;F5N(%!'4"UA=F%I;B`B"B)J82!S86QA<V%N871E:W-T:2XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS
M9W-T<B`B(@HB5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES96MS:2!T87)V:71A
M86X@:G5L:VEN96X@4$=0+6%V86EN+"!S86QA:6YE;B!01U`M(@HB879A:6X@
M:F$@<V%L87-A;F%T96MS=&DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)6:65S
M=&EN(&%V86%M:7-E96X@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-12UA=F%I
M;BP@<V%L86EN96X@4R]-24U%+6%V86EN(&IA("(*(G-A;&%S86YA=&5K<W1I
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS
M9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@
M;65S<V%G92XB"FUS9W-T<B`B(@HB5FEE<W1I;B!A;&QE:VER:F]I='1A;6ES
M96MS:2!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE
M;B!3+R(*(DU)344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B5FEE<W1I;B!S86QA=6MS965N('1A<G9I=&%A;B!J=6QK
M:6YE;B!334E-12UA=F%I;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B04T@
M4&EL=FGD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B04T@:V5V>71T
MY"!S861E='1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B04T@<V%D92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED
M(")!32!3:&]W97)S(@IM<V=S='(@(D%-('-A=&5I=&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(D%-(&QU;6ES871E:71A(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-
M+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I
M9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B5&EE=&]J82!E9&ET;W)I
M<W1A(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B
M;W5T+BXN(@IM<V=S='(@(E1I971O:F$N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB
M"FUS9W-T<B`B06)S+B!A;&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@
M(D%B<RX@:V5S:V5L;.0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E-I;G5L;&$@96D@;VQE(&]I:V5U:W-I82!L=6]D
M82!61E,M:&%K96UI<W1O82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(*;7-G<W1R(")3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@
M5D93+71I961O<W1O82XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM
M<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")+Y'ET=.1JY'1U
M;FYU:W-E;B!T:65D;W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*
M;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B2^1Y='3D:N1T=6YN
M=6MS96X@<V%L87-A;F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*
M;7-G<W1R(")+Y'ET=.1JY'1I;&D@<W5L:F5T='4N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M(")+:7)J86YP:71O(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS
M9W-T<B`B3&ESY.0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G
M<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@
M(DQI<^3D(&%L:7)Y:&WD(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED
M(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("),:7/DY"!A;&EO:6ME
M=7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D
M($AE<F4Z(@IM<V=S='(@(DQI<^3D('3D:.1N.B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W
M($=R;W5P(@IM<V=S='(@(DQI<^3D('5U<VD@<GEH;>0B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R
M("),:7/DY"!U=7-I(&]I:V5U<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@
M8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(DQI<^3D(&%L:7)Y:&WD
M(')Y:&WDY&X@7"(E<UPB(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R
M;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B3&ESY.0@86QI;VEK975D970@
M7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE
M=R!U<V5R.B(*;7-G<W1R("),:7/DY"!U=7-I(&OD>71TY&KD.B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-38*;7-G:60@
M(D%D9"!C;VQU;6XB"FUS9W-T<B`B3&ESY.0@<V%R86ME(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M
M96UB97)S(@IM<V=S='(@(DQI<^3D('5U<VEA(&KD<V5N:>0B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G
M<W1R("),:7/DY"!P87)I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B3&ESY.0@)7,@=F%L:6MK;R!-;WII
M;&QA;B!3:61E8F%R(&]S:6]O;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O
M:SHB"FUS9W-T<B`B3&ESY.0@;W-O:71E:VER:F%A;CHB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T
M;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3&ESY.0@;W-O:71E:VER:F%A
M;FDZ(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM
M<V=S='(@(DQI<^3D(&OD>71TY&KD(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S
M>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN
M9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB3&ESY'1T:6EN(%PB)7-<
M(B!JY')J97-T96QMY.1N+"!M=71T82!E:2!V;VD@;&ESY'3D('-I<^3D;FMI
M<FIA=71U;6ES<'EY;F[V;B`B"B)L:7/D=&EE=&]J83H@)7,N(@H*(SH@<VEG
M;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("),
M:7/D='1I:6X@7"(E<UPB(&KD<FIE<W1E;&WDY&XN(%9O:70@;GET(&MI<FIA
M=71U82!S:7/DY&XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T
M<B`B2^1Y='3D:FEE;B!L:7/DY&UI;F5N(&]N(&5S=&5T='DN(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#4*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
M3W-O:71E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D]S;VET96MI<FIA(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.34*;7-G:60@(D%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S
M='(@(E9O:2!A<V5T=&%A('1A:2!MY.1R:71E;&SD(&]I:V5U:W-I82!T;VES
M:6QL92!KY'ET=.1J:6QL92(*"B,Z(&%D;6EN+VEN9&5X+G!H<#HQ.2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")9;&SD<&ET;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G<W1R(")-86EN;VMS970B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES
M=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A
M;FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&=E
M<FEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED
M(")!;&EG;B(*;7-G<W1R(")487-A82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS
M9W-T<B`B5&%S875S.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(DMA:6MK:2(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(DMA
M:6MK:2!A=71E;G1I:V]I9'5T(&OD>71TY&KD="(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B2V%I:VMI(')Y:&WD="(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]D871A=')E92YP:'`Z-S4@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HY,0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(DMA
M:6MK:2!O:6ME=61E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM
M<V=S='(@(DMA:6MI;'1A(&YE;&KD;'3D('-I=G5L=&$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A
M9&1R97-S97,B"FUS9W-T<B`B4V%L;&D@;6]N970@;W-O:71T965T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B4V%L;&D@:N1R:F5S
M=&5T>6X@;&ES=&%N('1Y>7!I;B!A<V5T=7,N(@H*(SH@9G)A;65W;W)K+T1A
M=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X
M:7-T<R(*;7-G<W1R(")/;B!J;R!O;&5M87-S82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM
M<V=S='(@(E9A:6AT;V5H=&]I;F5N($E-4U`M<VESY.1N:VER:F%U='5M:6YE
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R
M;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(E9A:6AT;V5H=&]I;F5N($E-
M4U`M<V%L87-A;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS
M9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")686EH=&]E
M:'1O:6YE;B!)35-0+6OD>71TY&KD='5N;G5S(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S(@IM<V=S='(@(E9A:6AT;V5H=&]I<V5T('/D:&OV<&]S=&EO<V]I='1E
M970B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R(")686EH=&]E:'1O:7-E="!M86QL:70B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")6
M86EH=&]E:'1O:6YE;B!T96MS=&DZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-PIM<V=I9"`B06UE
M<FEC86X@4V%M;V$B"FUS9W-T<B`B66AD>7-V86QT86EN(%-A;6]A(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+B(*;7-G<W1R(")!;FYE='1U(&%R=F\@96D@:V5L<&%A
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(G1A<&%H
M='5I('1U;G1E;6%T;VX@=FER:&4N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-@IM<V=I9"`B06YD
M;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-`IM<V=I9"`B06YG
M;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`*;7-G:60@(D%N9W5I
M;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@
M(D%N;VYY>6UI('!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")687-T875S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-0IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT:7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@
M(D%N=&EG=6$@:F$@0F%R8G5D82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HS
M-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B3VAJ96QM82(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@
M3&ES="(*;7-G<W1R(")/:&IE;&UA;&ES=&$B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B3VAJ96QM82!O;B!V86QM:7,N(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*
M;7-G<W1R("),86ET82!KY'ET=/;V;B!K86EK:VD@86QI:F%K;VEH:6XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B
M07!P<F]V92(*;7-G<W1R(")(>7;D:W-Y(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0P"FUS9VED(")!<'!R;WAI;6%T92!3:7IE
M(@IM<V=S='(@(D%R=FEO:71U(&MO:V\B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
M:'5H=&EK=74B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I82`H5VEN9&]W
M<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")086ME=&EN(&MO:V\B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0IM<V=I9"`B07)C:&EV92!.
M86UE(@IM<V=S='(@(E!A:V5T:6X@;FEM:2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B3VQE=&MO('9A<FUA+"!E='3D
M(&AA;'5A="!P;VES=&%A('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V;B`E<R`_
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@7"(E<UPB(&IA(&MA:6MK
M:2!S96X@86QI<GEH;>1T/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8*;7-G:60@(D%R9V5N=&EN
M82(*;7-G<W1R(")!9V5N=&EI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(D%R;65N:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M
M96YI82`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(E1A:61E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,`IM<V=I
M9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@
M(D%S8V5N<VEO;B!S86%R970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2UT86ED92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]0
M86-I9FEC(%)E9VEO;B(*;7-G<W1R(")!<VEA;B]4>7EN96YM97)E;B!A;'5E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_(@IM<V=S='(@(DMY<WD@=F%R;6ES='5S(&5N;F5N(&MU:6X@=&5H
M9.3D;B!Y;&SD<&ET;W1O:6UE;G!I=&5E="XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,#DY"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS
M9W-T<B`B5&5H=.1VY'-A<F%K:V5E="(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+B(*;7-G<W1R(")9<FET971T:6EN('!O:7-T86$@;VQE;6%T;VYT82!R
M>6AMY.0N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B67)I=&5T=&EI;B!P;VES=&%A(&]L96UA=&]N=&$@;VEK975T
M=&$N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M
M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")9<FET971T:6EN(&UU;VMA=&$@;VQE;6%T;VYT82!O:6ME=71T82XB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B67)I=&5T
M=&EI;B!M=6]K871A(&]L96UA=&]N=&$@:F%K;V$N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S$*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B
M3&ESY&WDY')I='EK<V5T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")E;&]K=74B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A
M;&EA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR.`IM<V=I9"`B075S=')I82(*;7-G<W1R("))=.1V
M86QT82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*
M;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!487)V:71T879A82!)
M34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G
M<W1R(")!=71H7V-Y<G5S.B!4875S=&%JY')J97-T96QMY"!E:2!T=64@=&%R
M=FET=&%V:6$@;VUI;F%I<W5U:W-I82XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U
M<SH@5&%R=FET=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B(@HB075T:%]F='`Z('1A<G9I='1A=F%A($944"UL86%J96YN
M=7-T82!E:2!L]GET>6YY="X@2^3D;F[D(%!(4"!KY'ET=.1E;B`M+2(*(F5N
M86)L92UF='`@87-E='5S=&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@5&%R=FET
M=&%V86$@24U!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z
M(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]K<F(U.B!487)V:71T879A82!K<F(U+6QA86IE;FYU<W1A(&5I(&SV
M>71Y;GET+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R
M"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(D%U=&A?;&1A<#H@
M:^1Y='3D:FEE;B!L:7/DY&UI;F5N($%C=&EV92!$:7)E8W1O<GEY;B!E:2!O
M;&4@='5E='1U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD
M87`Z($OD>71TY&II96X@<&]I<W1A;6EE;FX@06-T:79E($1I<F5C=&]R>7-T
MY"!E:2!O;&4@='5E='1U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@5&%R=FET=&%V
M86$@3$1!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@
M16D@=F]I9&$@;&ESY'3D(&OD>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H
M96EL;6]I='5S(&]L:3H@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!%:2!V
M;VED82!P;VES=&%A(&OD>71TY&KDY"`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?
M;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KDY"`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD
M87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDN(@IM<V=S='(@(D%U=&A?;&1A<#H@2^1Y='3D:FEE;B!P
MY&EV:71TY&UI;F5N($%C=&EV92!$:7)E8W1O<GEY;B!E:2!O;&4@='5E='1U
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@
M(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VUC86PZ(%1A<G9I='1A=F%A($U#04PM;&%A:F5N
M;G5S=&$@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U
M=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H
M.B!487)V:71T879A82!S;6)A=71H+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")!=71E;G1I:V]I;G1I($E-05`M<&%L=F5L:6UE;&QE(&5PY&]N;FES
M='5I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S
M='(@(D%U=&5N=&EK;VEN=&D@97#D;VYN:7-T=6DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S
M='(@(D%U=&5N=&EK;VEN=&D@97#D;VYN:7-T=6DN("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B075T
M96YT:6MO:6YT:2!2041)55,M<&%L=F5L:6UE;'1A(&5PY&]N;FES='5I+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@R"FUS9VED(")!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T
M96YT:6MO:6YT:2!&5%`M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T
M96YT:6MO:6YT:2!334(M<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L
M92!F:65L9',Z(@IM<V=S='(@(DOD>71E='3D=FES<^1O;&5V870@:V5N=.1T
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S$*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07IE
M<F)A:7ID86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(('-E;&ET>6MS970B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(E1A=7-T82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A
M8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B5&%U<W1A=N1R:2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`B5N3D<N0@:V5R8F5R;W,@<V%L87-A;F$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B
M0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")6Y.1RY"!K97)B97)O
M<R!KY'ET=.1JY'1U;FYU<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U"FUS9VED(")"86AA;6%S
M(@IM<V=S='(@(D)A:&%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB
M"FUS9W-T<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P
M"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:6$@
M*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B
M"FUS9W-T<B`B0F%N9VQA9&5S:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,*;7-G:60@(D)A<F)A
M9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D=R869I:6MO:61E
M;B!P97)U<VAA:V5M:7-T;V$@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B4&5R=7-V:6EV82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#D*;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B5F%L:V\M5F5NY&KD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-0IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4P"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,`IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V
M"FUS9VED(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B4WEN='EMY'#D:7;D(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,V-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")";&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B3W-I;W1A(%PB)7-<(B!O:&IE;&UA;&QE(%PB)7-<(B!E
M:2!L]GET>6YY="XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D]S:6]N(&%S971U
M:W-E="(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I
M9"`B0FQO8VL@5'EP92(*;7-G<W1R(")/<VEO;B!T>7EP<&DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`B3&EH879O:71U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,PIM<V=I9"`B0F]L
M:79I82(*;7-G<W1R(")";VQI=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(P-PIM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(DMI<FIA;FUE
M<FMI="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")2975N82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G
M:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(E)E=6YA;B!V86AV=75S
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4F5U;F%T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,@IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M(")";W-N:6$@2&5R>F5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B36]L96UM870B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0X"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0F]T=&]M(@IM<V=S='(@(D%L:6XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!S86%R970B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0T"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-PIM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(@IM<V=S='(@(D)R:71A;FYI86X@26YT:6%N('9A;'1A;65R96X@=&5R<FET
M;W)I;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(D)R=6YE:2!$87)U<V%L86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W"FUS9VED(")"
M=6QG87)I82(*;7-G<W1R(")"=6QG87)I82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI
M<W0B"FUS9W-T<B`B4&%L;'5K:V%L:7-T82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8*;7-G:60@
M(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Y"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B
M0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<R(*;7-G<W1R(")#4DPM:F%K96QU;W-O:71T965T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W
M"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E-?;VQU;B!T
M:65D;W0N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q
M"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R
M(")6Y&QI;75I<W1I;B!A;'5S='5S(&5I('9A;&UI<W1U;G5T+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,38*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$U-R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,`IM<V=I9"`B
M0V%L96YD87(B"FUS9W-T<B`B2V%L96YT97)I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")4>7EN
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(X"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UP
M=71S96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8P"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+
M86UE<G5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G
M:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E-A;&%S86YA82!E
M:2!V;VD@='EH:F5N=.3D(&%U=&]M86%T=&ES97-T:2P@;W1A('EH=&5Y='3D
M('EL;.1P:73D:N3D;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F
M:6QE(%PB)7-<(B(*;7-G<W1R(")%:2!V;VD@:VER:F]I='1A82!T:65D;W-T
M;V]N(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B
M0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*
M;7-G<W1R(")5;&MO:7-I82!I<W1U;G1O:^1S:71T96QI:O9I=.0@96D@;VQE
M(&UA:&1O;&QI<W1A(&AA;&QI=&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C,Q.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B24U!4"UP86QV96QI;65E;B!E:2!S
M86%T=2!Y:'1E>71TY#H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I(&%V871A('1I961O<W1O82!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,0IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D
M82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$R('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(E!E<G4B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B
M0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E!E<G4@;VYG96QM879I
M97-T:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(D5I('9O:61A('!O:7-T86$@=&EE9&]S=&]A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C4R"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R(")6Y&QI86EK86ES:&%K96UI<W1O82!E:2!L]GET>6YY="XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(D5I('9O:61A(&IA=&MA82!I;&UA;B`G=&%R9V5T1FEL
M92<@+7!A<F%M971R:6$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!P;VES=&%A(&AA:V5M
M:7-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP
M.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82P@)60@
M86QI=&%S;VIA(&]L96UA<W-A+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L
M(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@
M;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(D5I('9O
M:2!U=61E;&QE96YJY')J97-TY.0L(&%N;F5T='5J96X@=&EE='5E:61E;B!M
MY.1RY"!E:2!V87-T86$@(@HB=&%L;&5T971T=6IE;B!T:65T=65I9&5N(&WD
MY'+DY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P
M96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(D5I('9O:2!O:&IA=&$@=FEE<W1I
MY"!A;FYE='1U=6X@;G5M97)O;VXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-0IM<V=I9"`B0V%P
M92!697)D92(*;7-G<W1R(")+87`@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(DMU=F%T96MS=&DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS
M9W-T<B`B4&%L=F5L=6YT87)J;V%J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@
M(DMA=&5G;W)I870@:F$@;W1S:6MO="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R(")#87EM86X@<V%A<F5T(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B
M0V5L;"!0:&]N92(*;7-G<W1R(")0=6AE;&EN*$=332DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED
M(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4V]L=6X@=&EE9&]T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G
M:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B4V]L=6X@=.1Y=&4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(E-O;'5N('1I961O
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(E-O;'5N(';D;'ES
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E
M;&QP:&]N92(*;7-G<W1R(")-871K87!U:&5L:6XB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS
M9W-T<B`B2V5L='1I("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT
M97(B"FUS9W-T<B`B2V5S:VET971T>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30*;7-G:60@(D-E
M;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")+97-K:2U!9G)I:V%N
M('1A<V%V86QT82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED
M(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")+97-K
M:2U%=7)O;W!P82`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL
M<R(*;7-G<W1R(")687)M96YT965N('1I961O="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/
M=VYE<B(*;7-G<W1R(")687)M96YT965N(&]M:7-T86IA(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(E9A<FUE;G1E96X@<&]L:71I:6MA="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,0IM<V=I9"`B0VAA9"(*;7-G<W1R(")4<V%D(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(DUU=71A
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#
M:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")686EH9&$@<V%L87-A;F%S
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA
M;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S
M='(@(B(*(E9O:70@;75U='1A82!LY&AE='3D;6ES<^1S:2!SY&AK]G!O<W1E
M:7-S82!NY&MY=FGD(&YI;6DM('1A:2!O<V]I=&5T:65T;VIA+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I
M;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U
M<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)386QA<V%N86X@=F%I:'1O(&5I(&]L92!K
MY'ET]G-SY"!N>6MY:7-I;&SD(&%S971U:W-I;&QA+B!/=&$@>6AT97ET=.0@
M(@HB>6QLY'!I=.1J:6EN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B
M365R:VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M(")487)K:7-T7V$@;&EN:VMI+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.0IM<V=I9"`B0VAI
M;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#:&EN82(*
M;7-G<W1R(")+:6EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS
M9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B2VEI
M;F$@>6MS:6YK97)T86ES=&5T='4@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2DB"FUS9W-T<B`B2VEI;F$@<&5R:6YT96EN96X@*$)I9S4I(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T
M:6]N.B(*;7-G<W1R(")686QI='-E(&]H:F5L;6$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P87-S
M=V]R9"(*;7-G<W1R(")686QI='-E('-A;&%S86YA(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E
M<FYA;64B"FUS9W-T<B`B5F%L:71S92!KY'ET=.1JY'1U;FYU<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B5F%L:71S92!PY&EVY&WDY')I96X@
M97-I='ES87-U.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")686QI='-E(&QI
M<W1A;B!T>7EP<&D@*&KD<FIE<W1E='EI;&QE(&QI<W1O:6QL92DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8V"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(DIO=6QU
M<V%A<F5T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-"!F<F%M97=O
M<FLO3F5T7U--4R]335,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3'5O
M:VMA;>3D<FET>7-TY"`E<R!E:2!L]GET>6YY="XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS
M9W-T<B`B4V5L:V7D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G
M<W1R(")0;VES=&$@35-/9F9I8V4@=&%G:70B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")0;VES=&$@
M:WES96QY(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S
M='(@(E!O:7-T82!KY'ET=.1JY#H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B
M4&]I<W1A(&OD>71TY&KD(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")0;VES
M=&$@:^1Y='3D:N1N('1I961O="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S
M='(@(E-E;&ME;F5VY.0@;7GV:.3D;B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R(").87!S875T82!J871K86%K<V5S:2(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I
M9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EK871E;&P@2%14
M4#IN(&MA=71T82(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W
M(@IM<V=S='(@(E-U;&IE(&EK:W5N82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS9W-T<B`B4&EL=FGD(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L
M;W5D<R!%87)L>2(*;7-G<W1R(")0:6QV:6YE;B!A:6MA:7-I;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#
M;&]U9'DB"FUS9W-T<B`B4&EL=FEN96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R"FUS9VED(")#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")+;V]K;W,@*$ME96QI
M;F<I('-A87)E="(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B4&EE;F5N;N0@
M<VEV=79A;&EK:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*
M;7-G<W1R(")0:65N96YN971Y="!R975N870B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R"FUS9VED
M(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED
M(")#;VQO<B(*;7-G<W1R(")6Y')I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4P,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS,S8@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E;D<FEV
M86QI='-I;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S(*;7-G
M:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B5N1R:79A;&EN=&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM
M<V=I9"`B0V]L<SHB"FUS9W-T<B`B4V%R86LZ(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R
M(")387)A:VME:61E;B!O='-I:V]T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(E-A<FIA:W5V870B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B2V]M96YT;R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I
M9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUE;G1O='5L:VMI(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM
M96YT(@IM<V=S='(@(DMO;6UE;G1T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M(")9;&5I;F5N(&YI;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*
M;7-G<W1R(")+;VUO<FET(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")9<FET
M>7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U
M=&5R<R(*;7-G<W1R(")4:65T;VMO;F5E="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")/
M;&]S=6AD92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(D]L;W-U:'1E970B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<R(*;7-G<W1R(")!<V5T=6MS:65N(&5R;W0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@
M(D%S971U:W-E="!01$$M;&%I='1E:61E;BP@Y&QY<'5H96QI;6EE;B!J82!/
M=71L;V]K:6X@<WEN:W)O;F]I=&EI;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+B(*;7-G<W1R(")!<V5T=6MS:6$@<&ETY.0@<.1I=FET=.3D+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N9FEG=7)E("5S(@IM<V=S='(@(D%S971A(&%S971U:W-E="`E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O
M;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B5F%H=FES=&$@:VER:F]I='1A;6%L
M;&$@<V%L87-A;F$@=75D97-T86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-0IM<V=I9"`B0V]N
M9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S"FUS9VED(")#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(DMO;F=O
M;B!D96UO:W)A871T:6YE;B!T87-A=F%L=&$B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"FUS9VED(")#;VYN96-T:6]N(&9A
M:6QE9"XB"FUS9W-T<B`B66AT97ES(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B66AT97ES(&5PY&]N;FES='5I.B`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L
M;&4@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I
M(@IM<V=S='(@(EEH=&5Y<R!J=6QK:7-T96X@879A:6YT96X@<&%L=F5L:6UE
M;&QE(&5PY&]N;FES='5I+B!6:7)H93H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")9:'1E>7,@9G1P+7!A;'9E;&EM
M96QL92!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDR-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N
M=&%C=',B"FUS9W-T<B`B66AT97ES=&EE9&]T(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B66AT97ES=&EE9&]T(&QI<^1T=&EI;B!O<V]I=&5K:7)J86%S
M:2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P
M"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS
M9W-T<B`B5&EI=FES=&5T>6X@=&EE9&]S=&]N('1Y>7!P:3HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB.FX@<VESY&QT]B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,R!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR.0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
M2F%T:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4X"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T
M<B`B0V]O:R!S86%R970B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*
M;7-G:60@(D-O;VMI92(*;7-G<W1R(")%=N1S=&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@
M(D-O<'DB"FUS9W-T<B`B2V]P:6]I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z
M("5S(@IM<V=S='(@(DMO<&EO:6YT:2!E<.1O;FYI<W1U:3H@)7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED
M(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W!I;VD@=F%L:6YT82(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#
M;W-T($E$(@IM<V=S='(@(D-O<W0@240B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S"FUS9VED(")#
M;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(DYO<G-U;FQU=7)A;FYI:VMO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED
M(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(E9I
M97-T:6X@4$=0+7-A;&%U<W1A(&5I('9O:71U('1E:&3D.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(E9I97-T:6EN(&5I('9O
M:71U(&UU;V1O<W1A82!01U`M86QL96MI<FIO:71U<W1A.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(E9I97-T:6X@
M4R]-24U%+7-A;&%U<W1A(&5I('9O:71U('1E:&3D+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B5FEE<W1I:6X@96D@=F]I
M='4@;75O9&]S=&%A(%,O34E-12UA;&QE:VER:F]I='5S=&$N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R(")%:2!V;VET=2!O='1A82!Y:'1E>71TY"X@)7,B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U
M-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DQD87`M<&%L=F5L:6UE96X@96D@<V%A='4@875T;W)I<V]I='5A('EH
M=&5Y='3D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$W,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C$U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B16D@=F]I='4@=&%R:VES
M=&%A('-A;&1O82X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q
M"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3$1!4"UP86QV96QI;65E;B!E:2!S86%T=2!Y:'1E>71TY"XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&
M5%`Z("5S(@IM<V=S='(@(D5I('9O:71U(&]T=&%A('EH=&5Y='3D('!A;'9E
M;&EM965N(%PB)7-<(B!KY'ET=.1E;B!&5%`Z("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B16D@=F]I='4@;'5O9&$@:F%K96QU;&ES=&%A+B`E
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G
M:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B4$=0
M+7-A;&%T='5A('1I971O82!E:2!V;VET=2!A=6MA:7-T83H@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(")3+TU)344M<V%L
M871T=6$@=&EE=&]A(&5I('9O:71U(&%U:V%I<W1A+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B16D@=F]I='4@<&]I<W1A82!Y:'1E>7-T:65T;V$N("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B16D@=F]I='4@<&]I<W1A82!J86ME
M;'5L:7-T86$N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D5I('9O:71U('!O:7-T
M86$@<.1I=FET>7-S:W)I<'1IY"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R
M96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B5FEE<W1I;B!L
MY&AE='3D:N1N('/D:&OV<&]S=&EO<V]I=&5T=&$@96D@<'ES='ET='D@;>3D
M<FET=&5L96WDY&XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D5I('9O:71U(&AA:V5A(&MO
M:V\@;W-O:71E:VER:F%A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D5I('9O:71U
M(&AA:V5A(&MO:V\@:F%K96QU;&ES=&%A+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+B(*;7-G<W1R(")%:2!V;VET=2!H86ME82!K;VMO(&QI<W1A82!J86ME
M;'5L:7-T;VES=&$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2!<(B5S7"(N(@IM<V=S='(@(D5I('9O:71U(&QU:V5A('-T<F%T96=I
M86$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DMO;65N=&\@;6MD:7(@7"(E<UPB
M(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B2G5L:VES=&5N(&%V86EN=&5N
M('!A;'9E;&EM96QT82!E:2!S86%T=2!J=6QK:7-T82!A=F%I;G1A+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(")4:65D
M;W-T;V]N(%PB)7-<(B!E:2!V;VD@:VER:F]I='1A82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(D5I
M('9O:71U(&%U:V%I<W1A("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(EEL;.1P:71O;6]D=75L:6X@)7,@875K86ES=2!E<.1O;FYI<W1U:2(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")%:2!V
M;VD@875K86ES=&$@:&%K96UI<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("),1$%0+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L
M;&ES=&$@971S:>0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H
M<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N
M(@IM<V=S='(@(B5S.N3D(&5I('9O:71U(&QU:V5A+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB2^1Y='3D:N1N('-A
M;&%S86YA82!E:2!V;VET=2!N;VQL871A+B!*;W1K=70@=&%R=FET=&%V870@
M=&EE9&]T(&]V870@=N3D<FEN+B`B"B)9<FETY"!U=61E<W1A86X@=&%I(&]T
M82!Y:'1E>71TY"!Y;&SD<&ET;V]N(&IO<R!T87)V:71S970@;&ESY.0@87!U
M82XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(D5I('9O:71U(&AA
M:V5A($%#3"UT:65T;VIA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B16D@
M=F]I='4@:&%K96$@;W-O:71E:VER:F%A+B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B16D@=F]I='4@:&%K96$@:F%K96QU;&ES=&%A+B`E
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(D5I('9O:71U(&AA
M:V5A(&IA:V5L=6QI<W1O:F$N("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DX"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,C(*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S
M97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B16D@=F]I='4@:&%K96$@
M=&EE=&]J82!P86QV96QI;65N('1O:6UI;FYO:7-T82(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B16D@=F]I='4@<&%L875T=&%A(&%S971U
M:W-I82XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B2V]M96YT
M;R!R;61I<B!<(B5S7"(@97#D;VYN:7-T=6DN(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B16D@=F]I='4@=&%L
M;&5T=&%A("5S(&%S971U:W-I82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU.2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,*;7-G:60@(D-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B16D@
M=F]I='4@=&%L;&5T=&%A(&%S971U<W1E;B!V87)M=75S:V]P:6]T82XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(")%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K
M;W!I;W1A("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I='4@=&%L;&5T
M=&%A(&%S971U<W#D:79I='ES<VMR:7!T:>0Z(%PB)7-<(BXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B(*;7-G<W1R(")%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU
M=7-K;W!I;W1A("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@HB07-E='5S=&EE9&]S=&]N("5S('1A;&QE='5S(&5PY&]N;FES='5I
M+B!6;VET(&OD>71TY.0@:F]T86MI;B!A<V5T=7-T82`B"B)T86QL971T86%K
M<V5S:2!K;V]D:6X@=&%K86ES:6X@)7,@=&%I('1A:2!K;W!I;VED82!KY'-I
M;B!A;&QA(&]L979A;B!K;V]D:6X@(@HB=&EE9&]S=&]O;B`E<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`M<&%L
M=F5L:6UE;'1A(&5I(&]L92!M86AD;VQL:7-T82!E='-IY"XB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DMO;65N=&\@=6YL:6YK(%PB)7-<
M(B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(D5I('9O:71U('#D
M:79I='3DY"!Y:'1E>7-T:65T;VIA+B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(D5I('9O:71U('#D:79I='3DY"!J86ME;'5L:7-T86$N("5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(E9I97-T96KD(&5I('9O:71U('!O:7-T86$@:V%N
M<VEO<W1A(%PB)7-<(CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R(")-;WII
M;&QA(%-I9&5B87(@96D@;/9Y='EN>70N(%9A<FUI<W1A(&5T=.0@4VED96)A
M<B!O<VEO(&]N(&%U:VDN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B)+Y'ET=.1JY&QL
M92!<(B5S7"(@96D@=F]I='4@86YT86$@<V5U<F%A=FEA(&]I:V5U<VEA(&MA
M;G-I;V]N(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(S"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B3&%S:V5T='4@
M=&5K<W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B36%A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(W-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+
M=7)S<VET(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B3'5O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(DQU;R!U
M=7-I(&QI;FMK:2(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B3'5O
M('5U<VDB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(E9O:2!L=6]D
M82!U=7-I82!K86YS:6]I=&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R
M(")/:6ME=61E="!T96MI:N1L;.0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C$V"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B
M3'5O='1O:V]R=&EN;G5M97)O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D*;7-G:60@(D-R;V%T
M:6$B"FUS9W-T<B`B2W)O871I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0*;7-G:60@(D-U8F$B
M"FUS9W-T<B`B2W5U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B5.1MY&YH971K:6YE;B`T
M('9A:6AE='1A(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#
M=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(E3D;>1N:&5T:VES970@:7-T=6YN
M;W0B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP
M:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R(")+96QL;VYA:6MA
M('3D;&SD(&AE=&ME;&SD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I
M<R(*;7-G<W1R(")4Y&WD;FAE=&MI;F5N(%523"!O;B(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")4
MY&WD;FAE=&MI<V5T(&OD>71TY&KD="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")4Y&WD;FAE
M=&MI;F5N('/DY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B5.1MY&YH
M971K:6YE;B!T:6QA.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@
M(E3D;>1N:&5T:VEN96X@='EY;&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@HB5F]I="!M=6]K
M871A('1E:'3D=FGD+"!J;W1K82!S=6]R:71E=&%A;B!K=6X@:VER:F%U9'5T
M86%N('-I<^3D;B!O:&IE;&UA86X@)2(*(G,N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#
M=70B"FUS9W-T<B`B3&5I:VMA82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS
M9W-T<B`B3&5I:VMA82!V86QI='1U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-PIM<V=I9"`B0WEP
M<G5S(@IM<V=S='(@(DMY<')O<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+>7)I;&QI
M;F5N("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G
M:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMY<FEL;&EN
M96X@*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@
M(DMY<FEL;&EN96XO56MR86EN82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@*;7-G
M:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1S96MI;B!T87-A=F%L=&$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")0
M4"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S8*;7-G:60@(B(*
M(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.
M("AL:7/D=&EE=&]A(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+B(*(G!H<"DB"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")0Y&EV:71TY&EN(@H*(SH@861M:6XO9&%T871R964N
M<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1A=&%4
M<F5E+7-E;&%I;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S0*
M;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")4:65T;VMA;G1A:&%K
M=2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P,@IM<V=I9"`B1&%T92(*
M;7-G<W1R(")0Y&EVY'ES(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B4.1I
M=N1MY.1RY"!V87-T86%N;W1E='1U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y,PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B4.1I
M=N1MY.1RY&X@=F%L:6YT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I
M9"`B1&%Y(@IM<V=S='(@(E#D:7;D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R(")0;U]I<W1A('-A<F%K92(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E
M<B(*;7-G<W1R(")J;W5L=6MU=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R(")$97-I;6%A;&EN=6UE<F]T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(E!I96YE;F[D('-I<V5N;GES=.0B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")/;&5T=7,B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")/;&5T=7-VY')I(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L
M="!)9&5N=&ET>2(*;7-G<W1R(")/;&5T=7-P<F]F:6EL:2(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G
M<W1R(")/;&5T=7,@:V]M96YT;W1U;&MK:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B3>3D<FET
M96QMY'0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S$@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C$P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4&]I<W1A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS
M9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")0;VES=&$@<V]L=2(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED
M(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4&]I<W1A(')Y:&WD(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS9VED(")$96QE=&4@3&]G
M(@IM<V=S='(@(E!O:7-T82!L;VMI(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B4&]I<W1A(&]I
M:V5U<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDT"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(E9O:2!P;VES=&%A(&IA('1U:&]T82!P;VES=&5T='5J82!V:65S=&5JY"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E!O:7-T82!S;VQU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")0;VES=&$@
M<V%R86ME(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E
M;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4&]I
M<W1A(&]L96UA<W-A(&]L979A="!V86EH=&]E:'1O:6YE;B!M86QL:2(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4T"FUS9VED
M(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B5F]I('!O:7-T86$@=FEE<W1E
M:N0B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R(")0;VES=&$@7"(E<UPB.FX@;VEK975K<VEA(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S
M=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(D]L971K;R!V87)M82P@971TY"!H
M86QU870@<&]I<W1A82!<(B5S7"(@:F$@:V%I:VMI('-E;B!A;&EO:6ME=61E
M=#\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(E!O:7-T82!R
M:79I(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ
M-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(E!O
M:7-T82!V86QI='1U('!R;V9I:6QI(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3,*;7-G:60@(D1E;&5T92!S=6(@9F]L9&5R
M<R(*;7-G<W1R(")6;VD@;'5O9&$@=75S:6$@:V%N<VEO:71A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E!O
M:7-T82!V86QI='1U('-A<F%K92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H
M92!C=7)R96YT(')O=R(*;7-G<W1R(")0;VES=&$@=F%L:71T=2!R:79I(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(E!O:7-T971T=2!PY&EV:71Y<W-K<FEP=&D@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B5&]I
M;6ET=7-A:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M(")486YS:V$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR
M.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B3VYG96QM
M86X@:W5V875S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.30R('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*
M;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(DMU=F%U<R(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(E1A<FME;6UA="!T:65D
M;W0@*&SV>71Y=N1T(&UY]G,@2&]R9&4Z;B!L;VMI=&EE9&]S=&]S=&$I.B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`Q"FUS9VED(")$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R(")487)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I
M9&]N(&OD<VET96QTY';D:W-I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(DME:&ET>7,B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W(%!O:6YT
M(@IM<V=S='(@(DMO<W1E=7-P:7-T92(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`Q"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(D5D96QL:7-E;B!T=6YN:6X@:V]S=&5U<W!I<W1E.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z
M("(*;7-G<W1R(")+;W-T975S<&ES=&4Z("(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L
M969T('1O(')I9VAT(@IM<V=S='(@(E-U=6YT82!V87-E;6UA;'1A(&]I:V5A
M;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B
M4W5U;G1A(&]I:V5A;'1A('9A<V5M;6%L;&4B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DAA:V5M:7-T
M;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B2^1Y=.0@,C0M='5N;FEN(&%I
M:V%E<VET>7-TY"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS
M9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3N1K>6WD;B!A<V5T=6MS
M970B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B17-I='ES=&%P
M82!Y:W-I='EI<VMO:'1A:6YE;B!E;FYU<W1E(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G
M<W1R(")%<VET>7-T87!A(&5N;G5S=&5E;&QE("A4048I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,PIM<V=I9"`B1&ES<&QA>2!F;W)M870B
M"FUS9W-T<B`B17-I='ES=&%P82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*
M;7-G<W1R(")097)I;&QE;65N;VEL;6]I='5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,`IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R(")%:2!S86$@<&]I<W1A82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`BQ&SD(&OD>73D('-U;W)A86X@;6%I;G1E
M;F%N8V4N<&AP.G3D(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3(@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B2F]S(&5N<VEM;>1I;F5N(')I
M=FD@<VESY&QTY.0@<V%R86MK96ED96X@;W1S:6MO="P@;FEI;B!V86QI='-E
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S(*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(D1O;6EN
M:6MA86YI;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,PIM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D1O;6EN:6MA86YI;F5N('1A<V%V86QT82(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B16EK]B!O;&4@:^1Y='3D
M:N1T=6YN=7-T83\@2VER:F%U9'4@:^1Y='3D:N1K<VDN(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R(")486QL96YN82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R(")486QL96YN82`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E1A;&QE;FYA(&QU;W1U
M(&%S971U<R!02%`M<VMR:7!T:6[D+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(D%L
M87-V971O=F%L:6MK;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM
M<V=I9"`B1')U9W,B"FUS9W-T<B`B2'5U;65E="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@
M(E/D:&OV<&]S=&EO<V]I=&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*(D5-86EL+71O+5--4R!G871E=V%Y(&%J=7)I
M+"!N:6EL;&4@<&%L=F5L=6YT87)J;V%J:6QL92P@:F]T:V$@=&%R:F]A=F%T
M('3D=.0@(@HB<&%L=F5L=6$N(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B
M15)2(@IM<V=S='(@(E9)4DA%(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-0IM<V=I9"`B16-U861O
M<B(*;7-G<W1R(")%8W5A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R
M"FUS9VED(")%9&ET(@IM<V=S='(@(DUU;VMK86$B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S
M='(@(DUU;VMK86$@;W-I;W1A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@
M861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T
M<B`B375O:VMA82!R>6AMY.0B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B375O:VMA82!O:6ME=71T
M82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B375O:VMA82!O:6ME=6MS:6$B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(DUU;VMK
M86$@)R5S)SIN(&]I:V5U:W-I82(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(DUU;VMK
M86$@87-E='5K<VEA.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")-=6]K:V%A(%PB)7-<(CIN(&]I:V5U:W-I
M82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M375O:VMA82`E<SIN(&]I:V5U:W-I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(DMO=6QU='5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'1I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV
M861O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M
M96YT=&DN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(D5M86EL(@IM<V=S='(@(E/D:&OV
M<&]S=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*;7-G:60@(D5M86EL($%D
M9')E<W,B"FUS9W-T<B`B4^1H:_9P;W-T:6]S;VET92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")3Y&AK]G!O<W1I;W-O:71T96ED96X@<&ET
MY.0@;VQL82!S86UA="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.3DS"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")3
MY&AK]G!O<W1I('9A<FUI<W1U:W-E;&QA(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--
M4R!'871E=V%Y(@IM<V=S='(@(D5M86EL+71O+5--4R!'871E=V%Y(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I
M9"`B16UO=&EC;VYS(@IM<V=S='(@(DAY;6GV="(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`B5'EH:N0@=FEE<W1I+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@
M(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5'EH:N0@=F%S=&%U<RXB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T
M>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5'EH:N0@:&%K=71E<FUI(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R
M=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B
M"FUS9W-T<B`B4V%L;&D@:W5V:65N(&QA:71T86UI;F5N(&MU=F%G86QL97)I
M87-T82!T96MS=&EN(&IO=6MK;V]N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_(@IM<V=S='(@(DQA:71A('#DY&QL92!O:6ME86X@<&%I;FEK:V5E;B!K
M;VYT96MS=&EM96YU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M.3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B16YD('EE
M87(B"FUS9W-T<B`B4.3D='1Y;6ES=G5O<VDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D
M:71O<B(*;7-G<W1R(")3=75R96YN82!E9&ET;W)I82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@
M;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B)!;FYA(&MY<WEM>7,@
M:F]K82!K>7-Y=.3D;BP@:F]S('-A;&%S86YA<VD@:F]U9'5T86%N(&YO;&QA
M86UA86X@97-I;65R:VEK<VD@(@HB)VUI:^0@;VX@;&5M;6EK:VES:2!N:6UI
M/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4B"FUS9W-T<B`B3&%I=&$@:W5V82!54DP@=.1HY&XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B06YN82!K:7)J86EM970@
M86QL93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*
M;7-G<W1R(")%:W9A=&]R:6%A;&EN96X@1W5I;F5A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.0IM
M<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP
M.CDT(&QI8B]";&]C:R]M971A<BYP:'`Z,S8*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0X"FUS9VED(")%<G)O<B(*;7-G<W1R(")6:7)H92(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G
M<W1R(")6:7)H92!PY&EV:71E='3D97-SY"!O<VEO=&$Z("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(E9I
M<FAE('#D:79I=&5T=.1E<W/D('-Y;F,@86YC:&]R("UT:65T;V$Z("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@
M(E9I<FAE('!O:7-T971T865S<V$@<WEN8R!L;VMI83H@)7,B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(E9I
M<FAE(&AA971T865S<V$@<VESY&QT]N0Z("5S+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B5FER:&4@<.1I=FET
M971TY&5S<^0@<V%L87-A;F%A.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET
M:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")6:7)H92!SY&AK]G!O<W1I=FEE
M<W1I<W/D+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(E9I<FAE
M(&MI<FIO:71E='1A97-S82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-@IM<V=I9"`B
M17-T;VYI82(*;7-G<W1R(")%97-T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(D5T:6]P:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI;F5N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B
M"FUS9W-T<B`B175R;V]P<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(C$U(&UI;G5U
M=&EN(';D;&5I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("(R(&UI;G5U=&EN(';D;&5I
M;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R
M("(S,"!S96MU;FYI;B!VY&QE:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y
M(#4@;6EN=71E<R(*;7-G<W1R("(U(&UI;G5U=&EN(';D;&5I;B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@
M(D5V97)Y($QO9VEN(@IM<V=S='(@(DIO:V%I<V5L;&$@<VESY.1N:VER:F%U
M='5M:7-E;&QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(E!U;VQE;B!T=6YN:6X@=N1L
M96EN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B
M36EN=75T:6X@=N1L96EN(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")%<VEM97)K
M:VEA<G9O=#HB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<&AP
M<VAE;&PN<&AP.C@R(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X
M96-U=&4B"FUS9W-T<B`B4W5O<FET82(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS
M9W-T<B`B3&%A:F5N;F$B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("),86%J96YN
M82!S:79U=F%L:6MK;R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")/9&]T971T
M:6EN(&UE<FMK:>0@)RDG(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R
M9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E
M9"!S96%R8V@@=&5R;2(*;7-G<W1R(")386YA('-E;&QA:7-E;F%A;B!T86D@
M:&%K=71E<FUI(&QA:6YA=7-M97)K96ES<^0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R("),;W!P=7#D:7;D;>3D<N0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B
M16MS<&]N96YT=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")&
M1R!VY')I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B
M1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")!<V5T=7-T:65D;W-T;VIE
M;B!T=6]N=&D@1E10.FQLY"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S
M<6PN<&AP.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC
M97,N(@IM<V=S='(@(D%S971U<W1E;B!H86MU(&5PY&]N;FES='5I+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B66AT97ES($Q$05`M<&%L=F5L
M:6UE96X@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+B(*;7-G<W1R(")9:'1E>7,@4TU"+7!A;'9E;&EM965N(&5PY&]N;FES
M='5I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*
M;7-G<W1R(")+;W!I;VEN=&D@7"(E<UPB.FQTY"!E<.1O;FYI<W1U:2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DMO
M<&EO:6YT:2!<(B5S7"(Z;&QE(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A
M=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B575D96X@4T%33"UY
M:'1E>61E;B!L=6]M:6YE;B!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<U-2!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C4P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<
M(B5S7"(N(@IM<V=S='(@(E-I:7)T;R!<(B5S7"(ZY.1N(&5PY&]N;FES='5I
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M4VEI<G1O(&5PY&]N;FES='5I.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(DMA
M=6YI<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA
M;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9&EN('-A87)E="`H36%L=FEN87,I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-@IM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")&
MY'(@<V%A<F5T(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(E9A:V%V82!V:7)H93HB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED
M(")&87@B"FUS9W-T<B`B1F%K<VDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS:70B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B
M1F5B<G5A<GDB"FUS9W-T<B`B:&5L;6EK=74B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")4=6YT=74@
M:W5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G
M:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")4=6YT=74@:W5I;CH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(DUU=71A;6EA('-A=&5I=&$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B
M1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")-=75T86UI82!L=6UI<V%T96ET
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R(")+96YT=.1M871R:6ES:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,CD*;7-G:60@(D9I9VQE="!#05!40TA!
M(@IM<V=S='(@(D9I9VQE="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S,PIM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B1FEG
M;&5T(&MI<FIA<VEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,PIM<V=I9"`B1FEJ:2(*;7-G<W1R
M(")&:61Z:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM
M<V=I9"`B1FEL92(*;7-G<W1R(")4:65D;W-T;R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&4B"FUS9W-T<B`B5&EE9&]S=&]J96X@;'5K=6WDY'+D.B`E
M<R!T:65D;W-T;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(E1I961O<W1O:F5N(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&]A(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA
M9V5R(@IM<V=S='(@(E1I961O<W1O:F5N(&OD<VET=&5L>2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B5&EE9&]S=&]N(&YI;6DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3@Q"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")4:65D;W-T
M;VX@=F%L:6YT82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.3`*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E1I961O<W1O;B!T=6]N=&DB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#(*;7-G:60@
M(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")4:65D;W-T
M;VIE;B!T=6]N=&D@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S='(@
M(E-U;V1A='1I;65T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R(")3=6]M:2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B16YS:6UMY&EN96X@<'5O;&ES:V\B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V
M"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(D5N<VEM;>1I;F5N(&YE
M;&KD;FYE<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")+;W)J86$@<W5H
M9&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(DODY&YNY"!Y;7#D<FDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R
M"FUS9VED(")&;&]A="(*;7-G<W1R(")+96QL=79A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G
M<W1R(")3=6UU(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B2V%N
M<VEO=&$@)7,@96D@;VQE(&]L96UA<W-A+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B
M"FUS9W-T<B`B2VER:F%S:6UE;B!VY')I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(E)U;VMA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R(")396QA:6UI;&QE+"!J;W1K82!E:7;D="!T=64@:W5V
M:6$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B16YN=7-T92`H5$%&*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y
M<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O
M=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L
M9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)%;FYU<W1E
M='1A=F%T('9U;W)O:V%U9&5T("A(=6]M86%T:&%N(&5T=.0@96YN=7-T=6MS
M97-S82!O;B!T:65D;W0@<V5KY"`B"B)PY&EV:7-TY"!E='3D(/9I<W3D+"!J
M;W1E;B!S=75R:2!MY.1RY"!PY&EV:>0@86EH975T=&%A(&QI:6%N(&QE=F7D
M;B!O<VEO;BDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM
M<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(E5N;VAD:71K
M;R!S86QA<V%N87-I/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@(DQO;6%K:V5E="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")-
M:65T96QA=7-E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED
M(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B36EE=&5L875S965N('1Y>7!P:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B36EE=&5L875S965T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(DUI971E;&%U<V5E
M="`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B
M1F]R=6US(@IM<V=S='(@(D9O;W)U;6ET(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B575D96QL
M965N;VAJ875K<V5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B<&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS
M9VED(")&<F%M97,B"FUS9W-T<B`B2V5H>6MS970B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W"FUS
M9VED(")&<F%N8V4B"FUS9W-T<B`B4F%N<VMA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A
M;B(*;7-G<W1R(")286YS:V$L($UE=')O<&]L:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$*;7-G
M:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B4F%N<VMA;B!'=7EA;F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")2
M86YS:V%N(%!O;'EN97-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,@IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(E)A;G-K86X@971E;.1I
M<V5T('1E<G)I=&]R:6]T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("),Y&AE='3D
M:N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(E-U
M=6YN87-T82`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")0:61E;7!I(&MU
M=F%U<SHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(E3D>7-I:W5U
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R
M(")+;VMO(&YI;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X"FUS9VED(")'86)O;B(*;7-G<W1R
M(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM
M86=E(&9R;VTB"FUS9W-T<B`B1V%L;&5R:6$L(&IO<W1A(&MU=F$@;W1E=&%A
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L;&5R
M:6$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-@IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I
M82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")4
M964@)7,@87-E='5K<V5T(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D=E
M;F5R;VET=2!K;V]D:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`*;7-G:60@(D=E;W)G:6$B"FUS
M9W-T<B`B1V5O<F=I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B4V%K<V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS"FUS9VED(")':&%N82(*;7-G<W1R
M(")':&%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R
M(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")%='5N:6UI(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W-2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B66QE:7-E="!A<V5T
M=6MS970B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B
M1V\B"FUS9W-T<B`B365N92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D?V9&5L(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(D=O;V=L92!+87)T870B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@
M(D=O;V=L92!H86MU(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(DAA<FUA
M87/D=GDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,`IM<V=I9"`B1W)E96-E(@IM<V=S='(@(DMR
M96EK:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E
M96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(DMR96EK:V$@*$E33RTX.#4Y+3<I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(D=R]FYL
M86YT:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#D*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E
M;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")2>6AMY&X@>6QLY'!I=&\B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y(@IM<V=S='(@(E)Y:&UI96X@;FEM970@96EVY'0@<V%A(&]L
M;&$@='EH:FGD(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A<#H@16D@=F]I9&$@;&ESY'3D(&OD
M>71TY&KDY"`E<RX@4&%L=F5L:6UE;B!V:7)H96EL;6]I='5S(&]L:3H@(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'
M<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B1W)O=7!?;&1A<#H@16D@=F]I9&$@<.1I=N1T=.3D(&OD>71TY&KD
MY"`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B4GEH;>1T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY.`IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D96QO=7!E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#,*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`R"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E
M<FYS97DB"FUS9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X
M"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")6:65R86EL:6IA
M;B!O:6ME=61E="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*
M;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")6:65R87-K:7)J82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3<*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6EN96$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#0*;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I
M<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U
M>6%N82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV-`IM<V=I9"`B
M2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(DA434Q!<F5A('!E;&MU<FEM86ES97-T:2!K:65L=.1Y='EY
M('!O:7-T86UA<W1A(')I=FEN('9I:6UE:7-TY"!S;VQU82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*(DA434Q!<F5A('!E
M;&MU<FEM86ES97-T:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-T
MY"!S87)A:V5T=&$@(@HB=&%U;'5K;W-T82XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@
M:6X@=&%B;&4N(@IM<V=S='(@(B(*(DA434Q!<F5A('!E;&MU<FEM86ES97-T
M:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!R:79IY"!T875L
M=6MO<W1A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W
M"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B2%144"UA=71E;G1I:V]I;G1I82!E:2!L]GET>6YY="XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R
M:71H;2(*;7-G<W1R(")(87-H+6%L9V]R:71M:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S
M='(@(E5S=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,C,@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ.`IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(D]T<V%K92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B3W1S86ME(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`W"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',B"FUS9W-T<B`B2&5A<F0@:F$@36-$;VYA;&0@<V%A<F5T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G
M:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B5F]I;6%K87,@=6MK;W-M>7)S
M:WDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W
M("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE<')E82`H25-/+3@X-3DM."U)
M*2(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H
M="(*;7-G<W1R(")+;W)K975S(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(D]H:F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS
M9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")!<'5A(&5D:71O<FEN
M(&OD>71T]O9N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-0IM
M<V=I9"`B2&5L<&5R(@IM<V=S='(@(D]H:F4B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B4&%L;&]N<'5O
M;&ES:V\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B5.1S<^0@;VX@=&EE
M9&]S=&]N(&%L:W5O<V$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S$*;7-G:60@(DAI9V@B"FUS9W-T<B`B2V]R:V5A(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI
M;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")+
M;U]T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#,*;7-G:60@(DAO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I(@IM<V=S='(@(E!Y:.0@:7-T=6EN("A6871I:V%A;FEN
M(&MA=7!U;FMI=F%L=&EO*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,34T,0IM<V=I9"`B2&]M92(*;7-G<W1R(")+;W1I(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE
M($%D9')E<W,B"FUS9W-T<B`B2V]T:6]S;VET92(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B
M2V]T:6AA:V5M:7-T;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B4'5H
M96QI;B`H:V]T:2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V"FUS9VED(")(;VYG($MO
M;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5PY&ME
M;'!O82`E<R!834PM9&%T86$@=FEE<W1I<W/D("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!9:W-I:^3D;B!V:65S=&D@96D@=F%S
M=&%A(&]B:F5K=&EA("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B
M:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z(%EH=.1KY.1N(&]B:F5K=&EA("5S(&5I(&SV>71Y;GET
M('9I97-T:7-TY"`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S
M<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!0;VES=&5T=&EI;B`E<R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VXB"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($EN=&5G<F%A=&EO:V]N92!V
M86%T:6D@=&]I;6EA:W-E96X@)V1O;7AM;"<@4$A0+6QA86IE;FYU:W-E;B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%
M:2!V;VED82!L=6]D82!U=71T82!834PM<'5U=&$@;V)J96MT:6QL92`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%:2!V;VET=2!P;VES
M=&%A("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($5I('9O:61A(&AA:V5A($U)344@
M240ZY"!O<VEO;&QE('1Y>7!P:>0@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!%:2!V;VD@<WEK<F]N;VED82`E<R!<(B5S7"(Z
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,W"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@=F]I
M9&$@<WEN:W)O;F]I9&$@:F%K;VIA.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@5'5N=&5M871O;B!J86MO(%PB)7-<(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R(")686%K87-U;W)A('/DY&YT]B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R(")686%K87-U;W)A('3D>71E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I
M9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B5F%A:V%S=6]R83HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*
M;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M(@IM<V=S='(@(DUI=&5N('1U;&ET('3D;FYE/R`H4F%P;W)T;VD@:VEI=&]S
M(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+=6EN:V$@;6]N=&$@<V%R86ME='1A
M(&AA;'5A="!Y:&1I<W3DY#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_(@IM<V=S='(@(DME;G1T:65N("AS87)A:VME:61E;BD@;'5K=6WD
MY'+D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(@IM<V=S='(@(DMU:6YK82!M;VYT82!R:79IY"!H86QU
M870@>6AD:7-TY.0_(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.0IM<V=I9"`B2'5M:61I='DB
M"FUS9W-T<B`B2V]S=&5U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B2V]S=&5U<SH@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS9VED(")(=6UO<FES
M=',B"FUS9W-T<B`B2'5M;W)I<W1I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B
M2'5N9V%R>2(*;7-G<W1R(")5;FMA<FDB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0+7!O<W1I;&%A=&EK;VX@
M;'5O;G1I(&5PY&]N;FES='5I.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR.34@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`M<&]S=&EL86%T:6MO;B!P
M;VES=&\@97#D;VYN:7-T=6DZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(T,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HQ-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B24U!4"UP;W-T:6QA871I
M:V]N(&MI:6YT:?9N(&QU;VYT:2!E<.1O;FYI<W1U:3H@)7,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S(P"FUS9VED("))4"!!9&1R97-S(@IM
M<V=S='(@(DE0+6]S;VET92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B
M87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B25`M;W-O:71E(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(DE0+6]S;VET92!E:2!O;&4@<V%L;&ET=6X@0TE$4BUB;&]K:6X@<VES
MY&QLY"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("))4"USY.1N;O9S=/9N(')I:VMO;75S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))
M7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B3%]A:71A(')I=FD@96YN96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C`*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YT
M:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B5F%I;B!I:V]N:70B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S
M(@IM<V=S='(@(DEK;VYI="`E<SIL;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO
M;FET(&IA('1E:W-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*
M;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B4')O9FEI;&EN(&YI
M;6DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DX
M"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS
M9W-T<B`B2F]S('-I=G4@96D@;N1Y(&MU;FYO;&QA+"!N:6EN(&%U:V%I<V4@
M)7,@97)I;&QI<V5S<^0@:6MK=6YA<W-A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@HB2F]S(&5T(&[D92!I:V]N96ET82!KY'ET=.1E<W/D
M<VD@26YT97)N970@17AP;&]R97(@<V5L86EN=&$L(&YI:6X@<VEN=6X@(@HB
M<&ETY.0@;W1T86$@<&]I<R!PY.1L=.0@4$Y'(&SD<&ENY&MY=GEY<R!R87-T
M:71T86UA;&QA('3D;>0@;&%A=&EK:V\N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N(@IM<V=S='(@(B(*(DIO<R!NY&5T('3D;>1N('9I97-T:6XL(&UU
M='1A(&5T(&MU=F%A+"!N:6EN('1U;VUA87-I(&MU=F%A(&5I('9O:2!NY'ET
M=.3D("(*(FOD>71TY&WD<W/D<VD@<V5L86EM97-S82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*
M;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(DMU=FEE;B!E<VEK871S
M96QU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(DMU=F$@55),
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(DMU=F$@
M55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM
M<V=S='(@(DMU=F$@9V%L;&5R:6%S=&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B2W5V82!G86QL97)I87-T83HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`B2W5V86X@=FEE;G1I(@H*(SH@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")+=79A="(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHW('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(E1U;VYT:2P@87-K
M96P@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M5'5O='4@:V5N='3D.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B5'5O9'5T
M(&ME;G3D=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(DQA7VET82!R:79I(&KD;&ME96XB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A
M8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B5N3D<N0@=&]I;6EN=&]K;V]D
M:2!A;FYE='1U+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+B(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU<R!T86D@<V%L
M87-A;F$@;VX@=N3D<FEN+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(E;DY'+D(&OD>71TY&KD='5N;G5S('1A:2!V86EH=&]E:'1O:6YE;B!O
M<V]I=&4N(%ER:73D('5U9&5S=&%A;B!J82!O=&$@(@HB>6AT97ET=.0@>6QL
MY'!I=&]O;B!J;W,@=&%R=FET<V5T(&QI<^3D(&%P=6$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC
M<F5A<V4@26YD96YT(@IM<V=S='(@(DQI<^3D('-I<V5N;GES=.0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,38*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN=&EA(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T
M<B`B66MS:71TY&ES970@:^1Y='3D:N1T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R"FUS9VED
M("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE<VEA(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M86%T:6\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R(")4:65T;V$@
M96D@;VQE(&5NY.0@<V%A=&%V:6QL82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R
M="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DQA:71A('-?87)A:V4@:N1L:V5E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(DQA
M:71A(&MU=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B3&%I=&$@
M=&%U;'5K:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B3&%I
M=&$@=W=W+6QI;FMK:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(DQA:71A(%]S87)A:V4@96YN96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*
M;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE(@IM<V=S='(@(DQA:71A('5U<VD@<V%R86ME(&YY:WEI<V5N(&KD;&ME
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),86ET82!U=7-I('-A<F%K92!E
M;FYE;B!N>6MY:7-TY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B3&%I=&$@=75S:2!R
M:79I(&YY:WEI<V5N(&KD;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("),86ET
M82!U=7-I(')I=FD@96YN96X@;GEK>6ES=.0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S
M='(@(DQA:71A(&MA<'!A;&4@;GEK>6ES96X@;F]D96X@:N1L:V5E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(DQA:71A(&MA<'!A;&4@96YN96X@;GEK>6ES
M=.0@;F]D96$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("),86ET82!V86EH
M=&]E:'1O:6YE;B!M86QL:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")!;FYA
M('/D:&OV<&]S=&EO<V]I=&4@:F]H;VX@=75S:2!S86QA<V%N82!LY&AE=&5T
MY.1N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@
M(DQA:71A('-O;'4@:N1L:V5E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL
M(&)E9F]R92(*;7-G<W1R("),86ET82!S;VQU(&5N;F5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I
M9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("),86ET82!S;VQU(&KD
M;&ME96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G
M<W1R("),86ET82!S87)A:V4@96YN96XB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(E9O:2!L86ET=&%A('9I97-T96KD(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DQA:71A(&MA<'!A;&4@
M:N1L:V5E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O
M<F4B"FUS9W-T<B`B3&%I=&$@:V%P<&%L92!E;FYE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B3&%I=&$@<FEV:2!E;FYE;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DQA:71A
M(')I=FD@:N1L:V5E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*
M;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B06YN82!V86%D:71T879A('9A<W1A
M=7,@='5R=F%K>7-Y;7EK<V5E;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM
M86=E(@IM<V=S='(@(DQI:73D+TUU;VMK86$@:W5V:6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B3&EI=.0O375O:VMA82!L:6YK:VGD
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*(E-I;G5L;&$@96D@
M;VQE('1A<G!E96MS:2!K<F5D:6ET=&5JY"!LY&AE='3DY&MS97-I('9I97-T
M:6X@:F%K96QU;&ES=&%L;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(E)I:71TY&WD='3V;>1S=&D@:W)E9&EI='1E:N0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<Y"FUS9VED("));G1E
M9V5R(@IM<V=S='(@(DMO:V]N86ES;'5K=2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,S<*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")+
M;VMO;F%I<VQU:W5L:7-T82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B17#D:V5L<&\@(%5$2"`H57-E
M<B!$871A($AE861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B
M17#D:V5L<&]A(%I)4"UT:65T;V$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M17#D:V5L<&\@;VAJ96QM82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(D5PY&ME;'!O(&)A=&-H($E$+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P.3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$V,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,V(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI
M='1E9"XB"FUS9W-T<B`B3.1H971E='1I:6X@97#D:V5L<&]A('1I971O82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS
M9W-T<B`B17#D:V5L<&\@=F%S=&%A;F]T=&%J86X@;W-O:71E+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(D5PY&ME;'!O('1I961O<W1O;75O
M=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED
M("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")%<.1K96QP;R!L:7-E
M;G-S:6%V86EN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@
M(D5PY&ME;'!O('!A:6MK871I971O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B17#D:V5L<&\@;7-G7W1Y<&4@+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B17#D
M:V5L<&\@=&%I('!U=71T=79A(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(")%<.1K96QP;R!T
M86D@<'5U='1U=F$@<&%R86UE=')I+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B17#D:V5L=F]T(&]I:V5U9&5T('EL96UMY&QLY"!T87-O;&QA
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@
M(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B17#D:V5L<&\@<&%R;F5R
M(&ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G
M:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")%<.1K96QP;R!T
M=6]T96MO;V1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`B17#D:V5L<&\@<')O=&]K;VQL82XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A
M;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D5PY&ME;'!O('9A<W1A
M86YO='1A:F$Z(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C,*;7-G:60@
M(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(D5PY&ME;'!O(&IA:V\M
M;V)J96MT:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB
M"FUS9W-T<B`B17#D:V5L<&\@;.1H9&5O<V]I=&4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("))
M;G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B17#D:V5L<&]A('5N:6-O
M9&4M=&EE=&]A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*
M;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A87)I;R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@
M(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B2^3D;F[D('9A;&EN=&$@:^3D
M;G1E:7-E:W-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y"FUS9VED("))<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86XL($ES;&%M:6QA:6YE;B!T87-A
M=F%L=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3@*;7-G:60@(DER87$B"FUS9W-T<B`B27)A
M:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA
M;G1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(DUA;BUS86%R:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E
M9"!4+5-T;W)M<R(*;7-G<W1R(")%<FEL;&ES:>0@56MK;W-M>7)S:WEJY"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q-`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED
M("))<W-U97(B"FUS9W-T<B`B3&EI:VME96QL96QA<VMI:F$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET
M86QI8R(*;7-G<W1R(")+=7)S:79O:71U(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q"FUS9VED
M("))=&%L>2(*;7-G<W1R("))=&%L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,*;7-G:60@
M(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EK82(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S
M='(@(G1A;6UI:W5U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U"FUS9VED(")*87!A;B(*;7-G
M<W1R(")*87!A;FDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!A;FD@*$E3
M3RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R
M"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T
M"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&%N:6$B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R(")H96ENY&MU=2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(FME<^1K=74B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DME<VMI=.0B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.`IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B2V5S:VETY"!K97-K
M96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0P"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B2V5S
M:VETY"!TY'ES:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-PIM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S
M='(@(DME<VMI=.0@=F%S96UM86QL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"FUS9VED(")*=7-T:69Y
M(%)I9VAT(@IM<V=S='(@(DME<VMI=.0@;VEK96%L;&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86MS=&%N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I
M9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B4^1I;'ETY"!A;&MU<&5RY&EN
M96X_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(V"FUS9VED(")+96YY82(*;7-G<W1R(")+96YI
M82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@
M(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:2!+97)B97)O<RUP86QV
M96QI;65L;&4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED
M(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")+97)N96P@86QO:71T96QI:F%T
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@0W)E871I;VXB"FUS9W-T<B`B079A:6UE;B!L=6]N=&DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&
M:6YG97)P<FEN="(*;7-G<W1R(")!=F%I;65N('1U;FYI<W1E(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N
M9W1H(@IM<V=S='(@(D%V86EM96X@<&ET=75S(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R
M(")!=F%I;65N('1Y>7!P:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B079A:6UE
M;B!KY'ET=/8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B079A:6X@;VX@:F\@:G5L:VES=&5N(&%V86EN
M=&5N('!A;'9E;&EM96QL82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,PIM<V=I9"`B2VED<R(*;7-G<W1R("),87!S970B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD*
M;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,R"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B(*;7-G<W1R(")+;W)E82P@9&5M;VMR86%T=&EN96X@:V%N<V%N=&%S
M879A;'1A("A0;VAJ;VES+4MO<F5A*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,PIM<V=I9"`B
M2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A+"!T87-A=F%L=&$@
M*$5T96SD+4MO<F5A*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS
M9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B2V]R96$@*$550RU+4BDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S0*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C<*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER
M9VES=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED
M("),85]Y;W5T(@IM<V=S='(@(D%S7V5T=&5L=2(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DMI
M96QI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8R(*;7-G<W1R("),86]S+"!D96UO:W)A871T:6YE;B!K
M86YS86YT87-A=F%L=&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`B2N1L:VEM;>1I;F5N('!U;VQI<VMO
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A
M<W-W;W)D($-H86YG92(*;7-G<W1R(")%9&5L;&EN96X@<V%L87-A;F%N=F%I
M:'1O(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N
M+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(DKD;&MI;6WD
M:6YE;B!N96QJY&YN97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")0Y&EV:71E='1Y('9I:6UE
M:W-I.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")%9&5L;&EN
M96X@<VESY.1N:VER:F%U='5M:6YE;CH@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")%9&5L;&EN96X@<VESY.1N:VER:F%U
M='5M:6YE;CH@)7,L("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")%9&5L;&EN
M96X@<VESY.1N:VER:F%U='5M:6YE;CH@16D@;6EL;&]I;FMA86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*;7-G<W1R("),871V:6$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("),
M86MI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,Y"FUS9VED("),87EO=70B"FUS9W-T<B`B07-E='1E;'4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS
M9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(DKD=.0@
M='EH:N1K<VD@:F]S(&5I(')E=6YO:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`IM<V=I9"`B3&5F="(*
M;7-G<W1R(")687-E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,#4*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E9A<V5N(&]T<V%K92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#$*;7-G:60@(DQE9G0@
M=F%L=65S(@IM<V=S='(@(E9A<V5N(&%R=F]T(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T;R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B5&%S
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,@IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6)E
M<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER
M:7EA(@IM<V=S='(@(DQI8GEA($%R86(@2F%M86AI<FEY82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:6-H=&5N<W1A
M:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")+979Y='3D('+D;G3D
MY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V
M"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DMI<FIA=61U('-I<^3D;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS
M9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(DME=GET=.0@<V%D971T
M82!A:6MA:7-I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B2V5V
M>71TY"!S861E='1A(&UY]FAE;6UI;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E
M<B(*;7-G<W1R(")+979Y:73D('-A9&5K=75R;VIA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A
M:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(DME=GET=.0@<V%D971T82!J82!M
M>7)S:WEI<W3D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B2V5V>71TY"!L
M=6UI<V%D971T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")+
M979Y:73D(&QU;6EK=75R;VIA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEK:70B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM<V=S
M='(@(DQI;FMK:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM
M<V=S='(@(DQI;FMK:2!O<V]I='1A83HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(DQI
M;FMI=.0@<^1H:_9P;W-T:6]S;VET92!K:7)J;VET82!U=7-I('9I97-T:2!S
M:79U;&QE(&[D:WEMY'-SY"(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@
M(DQI;FMI="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B
M3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X('!I<&%R96ET82(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B5F]I(&QI<W1A
M=6MS97-S82!NY&ADY"!K86YS:6]N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S-`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3N1Y=.0@=&EE
M=&]K86YN870B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I
M9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(").Y'ETY"!O:&IE:61E;B!A
M:6AE970B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T
M(%1A8FQE<R(*;7-G<W1R(").Y'ETY"!T875L=70B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E
M(@IM<V=S='(@(DQI<W1A;BU!<FMI<W1O(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R
M("),:7-T86XM3VAJ92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W1A;BU)9"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED
M("),:7-T+4]W;F5R(@IM<V=S='(@(DQI<W1A;BU/;6ES=&%J82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B3&ES=&$M=FEE<W1I(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E
M(@IM<V=S='(@(DQI<W1A;BU4:6QA=7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*
M;7-G<W1R("),:7-T86XM5&EL875K<V5N+6QO<&5T=&%M:6YE;B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B27-T=6YT;VIE;B!L
M:7-T875S(&5PY&]N;FES='5I.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B2^1Y='3D:FEE;B!L:7-T875S(&5PY&]N;FES='5I
M.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM
M<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2^1Y
M='3D:N1T:65T;VIE;B!NY'ET=.1M:6YE;B!O;B!E<W1E='1Y+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G
M<W1R(")+:7)J86QL:7-U=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0*;7-G:60@(DQI=&AU
M86YI82(*;7-G<W1R("),:65T='5A(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G
M<W1R("),861A=&%A;BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")086EK86QL
M:7-T82!A:6MA83H@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS
M9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B3&]K86QI<V%A=&EO(&IA
M(&%I:V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*;7-G:60@
M(DQO8V%T:6]N(@IM<V=S='(@(E!A:6MK82(*"B,Z(&QO9VEN+G!H<#HQ.#D@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R(")+:7)J875D=2!S:7/DY&XB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VXB"FUS9W-T<B`B161E;&QI<V5N('-Y;FMR;VYO:6YT:7-E<W-I
M;VX@;&]K:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*
M;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B2VER:F%U9'4@=6QO<R(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B
M2VER:F%U9'4@<VESY.1N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&5H=.1VY'0@<VESY.1N
M:VER:F%U='5M:7-E<W-A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE
M(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R
M("(B"B)3:7/DY&YK:7)J875T=6UI<V5S:2!E<.1O;FYI<W1U:2X@5&]D96YN
MY&OV:7-E<W1I(&MI<FIO:71I="!VY.1R:6X@(@HB:^1Y='3D:N1T=6YN=6MS
M97-I('1A:2!S86QA<V%N87-I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")3:7/DY&YK
M:7)J875T=6UI;F5N(&5PY&]N;FES='5I+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-CD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")0:71K
MY"!T96MS=&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@
M(DQO=F4B"FUS9W-T<B`B4F%K:V%U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED("),;W<B"FUS9W-T<B`B36%T
M86QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G
M<W1R(")0:65N970@:W)E:6MK86QA:7-E="!K:7)J86EM970B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y
M"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(E!I96YE="!L
M871I;F%L86ES970@:VER:F%I;65T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@
M<F]M86X@;G5M8F5R<R(*;7-G<W1R(")0:65N970@<F]O;6%L86ES970@;G5M
M97)O="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R
M("),=7AE;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,SD@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-
M(@IM<V=S='(@(DM+(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X
M,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!L
M:6ET971I961O<W1O(&]L:2!T>6AJY"XB"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B5DE%4U1)(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W"FUS9VED
M(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,PIM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DUA:V5D;VYI82P@16YT:6YE;B!*=6=O<VQA=FEA;B!T87-A=F%L
M;&%N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U,0IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R
M(")-861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS
M9VED(")-86=I8R(*;7-G<W1R(")486EK=75S(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(E/D:&OV<&]S
M=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(E!O<W1I;B!Y;&SD<&ET;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")4964@;&EN:U]K:2XN+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L97-I
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L
M961I:79I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-`IM<V=I9"`B36%L:2(*;7-G<W1R(")0
M;W-T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L
M=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H
M;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(E9O:70@:&%L;&EN;F]I9&$@
M;&ES=&%A(&MA=&5G;W)I;VES=&$L(&IO:61E;B!A=G5L;&$@=F]I="!L:6ET
M=.3D(&%S:6]I=&$@(@HB>6AT965N('-A;6]J96X@;W1S86MK96ED96X@86QL
M92!J82!L:6ET=.3D(&YI:6AI;B!VY')E:N0N(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA
M<"(*;7-G<W1R(")-87`R-"!K87)T=&$B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P475E<W0@;6%P
M(@IM<V=S='(@(DUA<%%U97-T(&MA<G1T82(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G
M<W1R(")687-T86%V=75D970@=&%L;&5T971T=2XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS
M9W-T<B`B;6%A;&ES:W5U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@
M(DUA<F=I;F%A;&DB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T
M,S$T+G!H<#HT.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM
M<V=S='(@(E9O:2!M97)K:73D(%9A;FAA+U5U<VD@=&EE=&]J82(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED(")-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*
M;7-G<W1R(")6;VD@;65R:VETY"!V:65S=&5JY"`H97-I;2X@5.1R:V7D+U9A
M<W1A='1U*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,@IM<V=I9"`B36%R<VAA;&P@27-L86YD
M<R(*;7-G<W1R(")-87)S:&%L;"!S86%R970B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D*;7-G
M:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L
M9',B"FUS9W-T<B`B5.1S;>3D=N1T(&ME;G3D="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,`IM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A;FEA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38S"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B36%U<FET:75S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(E-U=7)I
M;B!S86QL:71T>2!K<F5D:6ET=&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B4W5U<FEN('-A;&QI='1U('9I
M97-T:6]S:6]MY.1RY"!Y;&ET971T>2XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,Q,PIM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S
M='(@(D5D96QL:7-E;B`R-"!T=6YN:6X@:V]R:V5I;B!LY&UP]G1I;&$Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L
M87-T(#8@:&]U<G,Z("(*;7-G<W1R(")%9&5L;&ES96X@-B!T=6YN:6X@:V]R
M:V5I;B!LY&UP]G1I;&$Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(E!O<G1A
M86QI;W-I;VED96X@96YI;6WD:7-MY.1RY"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDP,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(Q"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM=6T@
M;&5N9W1H(@IM<V=S='(@(E-U=7)I;B!S86QL:71T=2!P:71U=7,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B
M36%Y(@IM<V=S='(@(G1O=6MO:W5U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,PIM<V=I9"`B
M36%Y;W1T92(*;7-G<W1R(")-87EO;F5T=&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DSDY&ME=&EE
M9&4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS
M9VED(")-96UB97)S(@IM<V=S='(@(DKD<V5N970B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE
M;G5N(&UU;W1O.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@
M(EEH9&ES=.0@<V]L=70B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R
M(")6:65S=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@
M8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB
M=F5R:69I960N(@IM<V=S='(@(B(*(E9I97-T:6X@=&%R:VES='5S(&]N;FES
M='5I+"!M=71T82!A;&QE:VER:F]I='1A:F%N('9A<FUE;FYE='1A(&5I('9O
M:71U("(*(G1A<FMI<W1A82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E
M9"XB"FUS9W-T<B`B5FEE<W1I('9A;FAE;FDN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@IM
M<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E9I97-T:6X@='EY<'!I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(DUE=&%R('/DY"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(DUE=&%R+6]S:6\@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE=&%R+6]S:6\@96D@;VQE(&OD
M>71E='3D=FES<^0N(%1A<FME;6UA="!T:65D;W0@;VX@=&%L;&5T971T=2!Y
M;&SD<&ED;VX@(@HB:^1S:71E;'3D=N1K<VDN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N
M;F5C=&5D+B(*;7-G<W1R(")-971A<D1"(&5I(&]L92!Y:&1I<W1E='1Y+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T
M:&]D(@IM<V=S='(@(DUE=&]D:2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W-O
M87`N<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN
M960B"FUS9W-T<B`B365T;V1I82!<(B5S7"(@96D@;VQE(&WDY')I=&5L='DB
M"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z
M("5S(@IM<V=S='(@(DUE=&]D:6$@96D@;VQE(&WDY')I=&5L='DN($MU='-U
M=F$@;65T;V1I.B`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#(@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W"FUS9VED(")-971R:6,B"FUS
M9W-T<B`B365T<FEN96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8*;7-G:60@(DUE>&EC;R(*
M;7-G<W1R(")-96MS:6MO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4*;7-G:60@(DUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EK<F]N97-I82P@
M66AD:7-T>6YE970@=F%L=&EO="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B36ED9&QE(@IM<V=S
M='(@(DME<VME;&SD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-:6UE+71Y
M>7!P:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$W"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B161E;&QI<V5N(#(T('1U
M;FYI;B!M871A;&EN(&SD;7#V=&EL83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#D*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S
M='(@(D5D96QL:7-E;B`V('1U;FYI;B!M871A;&EN(&SD;7#V=&EL83H@(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI
M;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T
M<B`B4V%L87-A;F$@96D@;VQE('9I96SD('1A<G!E96MS:2!V86YH82(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G
M:60@(DUI<G)O<B(*;7-G<W1R(")096EL:6MU=F$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M4V5K86QA:7-E="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@
M2%144%]297%U97-T+B(*;7-G<W1R(")014%2+7!A:V5T=&D@2%144%]297%U
M97-T('!U=71T=74N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM
M<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P
M;&EC871I;VXN(@IM<V=S='(@(B(*(E!U=71T=79A="!A<V5T=7-T:65D;W-T
M;RX@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5S=&EE9&]S=&\@:F]S(&AA;'5A
M="`B"B)KY'ET=.3D('3D=.0@;VAJ96QM86$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(E!U=71T=79A(&UE<W-A9V4@240N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(@IM<V=S='(@(E;D;'1TY&WD=/9N(%!%05(M<&%K971T:2!-86EL
M('!U=71T=74N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM
M<V=S='(@(E!U=71T=79A('-E<W-I;VX@240N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T
M<B`B;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@
M(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEI;&ESY&AK]G!O<W1I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@
M(DUO9&5R871E(@IM<V=S='(@(DMO:'1A;&%I;F5N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S,*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`B375O:VMA=6MS96X@<.1I=N1MY.1RY"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")-=6]K:V%A(%523#II82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(DME<G)O:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`*;7-G:60@(DUO;&1O=F$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F$L('1A<V%V86QT82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T.0IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:6$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@X"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R(")K=75K875S:2!J82!V=6]S:2(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@
M(DUO;G1H;'DB"FUS9W-T<B`B2W5U:V%U<VET=&%I;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,0IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS
M9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")+=75N('9A:6AE970B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,C@P"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM
M<V=S='(@(E)I=FEL=.0@)60@;/9Y='EI(&5N96UMY&X@:V5N='1IY"!K=6EN
M(&]D;W1E='1U("5D+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R;V-C;R(*
M;7-G<W1R(")-87)O:VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")%
M;FEM;>1K<VD@<V5L:V7DY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@
M(D5N:6UMY&MS:2!P:6QV:7-TY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@0VQO=61Y(&%N9"!7
M:6YD>2(*;7-G<W1R(")%;FEM;>1K<V5E;B!P:6QV:7-TY"!J82!T=75L:7-T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B16YI;6WD:W-E96X@875R
M:6YK;VES=&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(E-I:7)R
MY"!A;&%S<.1I;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4VEI
M<G+D('9A<V5M;6%L;&4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R
M(")3:6ER<N0@;VEK96%L;&4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M(")3:6ER<N0@>6SV<W#D:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B
M4VEI<G+D(&%L87-PY&EN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S='(@(E-I:7)R
MY"!Y;/9S<.1I;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B36]Z86UB:7%U92(*
M;7-G<W1R(")-;W-A;6)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G
M<W1R(")-;VYI=&%S;VEN96X@86QA<W9E=&]V86QI:VMO(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3@*;7-G:60@(DUU
M;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"!)<V\M0G)I=&%N;FEA
M;B!K87)T=&$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V"FUS
M9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B36]N:79A;&EN=&$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!
M8V-O=6YT(@IM<V=S='(@(DOD>71TY&KD='5N;G5K<V5N:2(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA
M=&EO;B(*;7-G<W1R(")/;6%N(&OD>71TY&KD='5N;G5K<V5N('1I961O="(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*;7-G:60@(DUY(%!O
M<G1A;"(*;7-G<W1R(")/;6$@<&]R=&%A;&DB"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z-#,*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T
M<B`B3VUA;B!P;W)T86%L:6X@87-E='1E;'4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34*;7-G
M:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B`H0G5R;6$I(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@
M(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(")%22P@14X@<W5O<W1U(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DYA;64B"FUS
M9W-T<B`B3FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R(").86UI8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").875R=2(*;7-G
M<W1R(").875R=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-PIM<V=I9"`B3F5P86PB"FUS9W-T
M<B`B3F5P86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4*;7-G:60@(DYE=&AE<FQA;F1S(@IM
M<V=S='(@(D%L86YK;VUA870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,PIM<V=I9"`B3F5T:&5R
M;&%N9',@06YT:6QL97,B"FUS9W-T<B`B06QA;FMO;6%I9&5N($%N=&EL;&ET
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G
M:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(DYE='-C87!E($)A<V4@
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE
M='-C87!E($-!(%)E=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC
M>2!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S
M8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!296YE=V%L(%52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS
M9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P
M92!2979O8V%T:6]N(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B
M"FUS9W-T<B`B3F5T<V-A<&4@4U-,+7!A;'9E;&EM96X@;W-O:71E(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE
M='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A<&4@
M=F%R;65N=&5E;B!K;VUM96YT=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP92(*;7-G<W1R(").971S8V%P92!V87)M96YT965N('1Y>7!P:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O<FLB
M"FUS9W-T<B`B5F5R:VMO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B16D@
M:V]S:V%A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,`IM<V=I9"`B3F5W($-A;&5D;VYI82(*
M;7-G<W1R(")5=7-I+4MA;&5D;VYI82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O
M<GDB"FUS9W-T<B`B575S:2!L=6]K:71U<R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B575S:6MU=2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE
M=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(E5U<VD@:^1Y='3D:N1T
M=6YN=7,@*'9A<&%A96AT;VEN96XI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P"FUS9VED(").
M97<@6F5A;&%N9"(*;7-G<W1R(")5=7-I+5-E96QA;G1I(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B575S:2!S86QA<V%N82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(")5=7-I('-A;&%S86YA
M('9A;FAE;F5E("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T
M<B`B06YT86UA<VD@=75D970@<V%L87-A;F%T(&5I=N1T('3D<VWDY"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS
M9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(E5U<VD@:6MK=6YA
M("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B575T:7-E="(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B2V5S:W5S=&5L=7)Y:&WD="(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U"FUS9VED(").97AT(@IM<V=S='(@(E-E=7)A879A
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA
M<V5S(@IM<V=S='(@(E-E=7)A879A="`T('9A:6AE='1A(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")3
M975R86%V870@87-E='5K<V5T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R
M+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E-E=7)A879A/B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-`IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI8V%R86=U
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,0IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S,*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@
M(DYI9VAT(@IM<V=S='(@(EGV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y"FUS9VED(").:75E
M(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(")%:2(*"B,Z('1E
M;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A
M:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S
M(&9O<BXB"FUS9W-T<B`B07-E='5S=&EE=&]J82!E:2!O;&4@<V%A=&%V:6QL
M82P@:F]S=&$@=F]I<VD@;N1Y='3DY"!E<F]A=F%I<W5U:W-I82XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I
M9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E
M<RXB"FUS9W-T<B`B16D@;VQE('-A871A=FEL;&$@<W5U;FYI=&5L;6%A($E3
M3R!L979Y:W5V871I961O<W1O:F5N('1E:V5M:7-E:W-I+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(D5I(&5RY&UA;&QI82XB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U
M97-T960@<&]S:71I;VXB"FUS9W-T<B`B3W-I;W1A(&5I(&]L92!P>7ED971Y
M<W/D('!A:6MA<W-A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP
M:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DMA;&5N=&5R:6X@;FEM9>0@
M96D@;VQE(&%N;F5T='4@34-!3"UA=71E;G1I:V]I;FYI;&QE+B(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S
M='(@(D5I(&UU=71O<W1A+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@
M=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(")!;&ET87-O:F$@96D@=F]I(&QI
M<^1TY"!TY&QL92!O:6ME=61E;&QE+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T
M:6PN<&AP.C<V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V.0HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(D%S971U:W-I82!E:2!L]GET>6YY="`E<SIL;&4N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@;/9Y='EN>70@1E10(%9&4SIL
M;&4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S(*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@5D93+B(*;7-G<W1R(")!<V5T=6MS:6$@96D@;/9Y='EN>70@4U%,(%9&
M4SIL;&4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R
M-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B07-E='5K<VEA(&5I(&SV
M>71Y;GET(%-13"U&:6QE(%9&4SIL;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D
M:70@;&5F="XB"FUS9W-T<B`B2W)E9&EI=&ET(&QO<'!U+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B2V]H9&5T=&$@
M96D@86YN971T=2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HY,C`*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B16D@='5O
M='4@86EN=71T86MA86X@=&EE9&]S=&]A(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B26MO
M;F5I=&$@96D@;/9Y='EN>70N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M,S`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,38*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB
M"FUS9W-T<B`B4&%I:VMA82!E:2!O;&4@87-E=&5T='4N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(E!A:6MK86$@96D@;VQE(&%N;F5T='4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D5I(&%N
M;F5T='4@=FEE<W1IY"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N
M(@IM<V=S='(@(DYI;67D(&5I(&]L;'5T(&%N;F5T='4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DQU:W5MY.1RY.0@96D@
M;VQL=70@86YN971T=2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*
M;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")%:2!L;W5K
M:V%A=F%T(&UI971E;&%U<V5E="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(
M5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@96D@;VQE
M(&%N;F5T='4@2%144"UA=71E;G1I:V]I;FYI<W-A+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4V%L
M87-A;F%A(&5I(&]L92!A;FYE='1U($E-05`M875T96YT:6MO:6YN:7-S82XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E-A;&%S86YA82!E:2!O;&4@86YN971T=2!+97)B97)O
M<RUA=71E;G1I:V]I;FYI<W-A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&]G:6XN<&AP.C@T(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(E-A;&%S86YA82!E:2!O;&4@86YN971T=2!,;V=I;B!A=71E;G1I
M:V]I;FYI<W-A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-A;&%S86YA82!E:2!O;&4@86YN
M971T=2!005-35T0M875T96YT:6MO:6YN:7-S82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-A;&%S86YA
M82!E:2!O;&4@86YN971T=2!334(M875T96YT:6MO:6YN:7-S82XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*
M(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!0
M2T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(E!O;&MU82!/<&5N4U-,(&MO;65N
M=&]O;B!E:2!O;&4@;>3D<FET96QT>2X@3W!E;E-33"!P:73DY"!O;&QA(&OD
M>71E='3D=FES<^0@(@HB:F]S(&OD<VET96QLY.1N(%!+0U,@,3(@9&%T86$N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I
M9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")%:2!S:7/DY&YK:7)J
M875T=6UI<W!Y>6YT]FKD(&IO;F]S<V$N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")+:6EN
M=&GV=.0@96D@;VQE(&%S971E='1U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B
M"FUS9W-T<B`B16D@<^3D;G3V:N0B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM
M<V=S='(@(D5R;W1I;G1A(&5I(&]L92!MY.1R:71E;'1Y+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G
M:60@(DYO('-I9&5S(@IM<V=S='(@(D5I(')E=6YO:F$B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM
M<V=S='(@(D5I(&SV>71Y;GET('1I961O<W1O82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B5N1L:6UU:7-T
M:6QL92!E:2!O;&4@=N1L:6%I:V%I<VAA:V5M:7-T;V$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")+Y'ET
M=.1JY'1U;FYU<W1A('1A:2!S86QA<V%N86$@96D@;.1H971E='1Y+B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(")+86EK:VD@<&%L875T
M=6YU="!834PM9&%T82!O;&D@97#D:V5L<&]A(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*
M;7-G<W1R(")%:2!A<G9O:F$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@HB5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY="!A;&MU<&5RY&ES:73D(&%S
M971U:W-I<W1A+B!3:6YU;B!P:73DY"!T96ADY"`B"B)A<V5T=6MS970@=75D
M97-T86%N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E9E<G-I;W1I971O
M:F$@96D@;/9Y='EN>70@87-E='5K<VES=&$N(%-I;G5N('!I=.3D('1E:&3D
M(&%S971U:W-E="!U=61E<W1A86XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(W('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-0IM<V=I9"`B3F]N92(*;7-G<W1R(")%:2!M:73DY&XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(D5I(&UI=.3D
M;B`H2^1Y=.0@:6UP;&ES:6ET=&ES=.0I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(DQA<'!I+U!O:&IO:7-M86%T+T5S:VEM;R`H25-/+3@X-3DM,3`I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<R"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F
M;VQK('-A87)E="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B4&]H:F]I;F5N('!A;&QO;G!U;VQI<VMO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B4&]H
M:F]I<V5T($UA<FEA86YI96X@<V%A<F5T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V"FUS9VED
M(").;W)W87DB"FUS9W-T<B`B3F]R:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@
M(D5I(&KD;&ME96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(")%:2!E;FYE;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T
M(&$@9&ER96-T;W)Y(@IM<V=S='(@(D5I(&]L92!H86ME;6ES=&\B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX
M-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HY-0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*
M;7-G<W1R(")%:2!O;&4@=&]T975T971T=2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM
M<V=S='(@(D5I(&%S971E='1U(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C$Y,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U,@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S$V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,S,@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-#(V(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4W-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3DQ
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#4*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C`*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S4*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HR,S8*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D5I
M('1U971T=2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`X"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P-3@*;7-G:60@(DYO=&5S(@IM<V=S='(@(DUU:7-T:6EN<&%N;W0B
M"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(")%:2!M:73DY&X@
M<V5L871T879A82P@<&%L86$@=&%K86ES:6XN(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM
M<V=S='(@(FUA<G)A<VMU=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3`*;7-G:60@(DYU;6)E<B(*;7-G<W1R("),=6MU;>3D<N0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Y"FUS9VED(").=6UB97(@;V8@
M8VAA<F%C=&5R<R(*;7-G<W1R(")-97)K:VEE;B!L=6MU;>3D<N0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T.2!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I
M9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B4V%R86MK96ED96X@;'5K
M=6WDY'+D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(E)I=FEE
M;B!L=6MU;>3D<N0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B
M2F%K96QU;&ES=&%N(&YU;65R;VET82!E:2!O;&4@;>3D<FET96QT>2!PY&EV
M:71E='3D=N1K<VDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B
M:F5C="(*;7-G<W1R(")/8FIE:W1I(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B
M:F5K=&EN(&QU;VIA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P
M.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMT86%L:2(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R
M(@IM<V=S='(@(FQO:V%K=74B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(DQO=6MK86%V=75S
M<W5O9&%T:6XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS
M9VED(")/9F9I8V4B"FUS9W-T<B`B5&]I;6ES=&\B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B575S:2!S86QA<V%N
M82!E:2!S86$@;VQL82!S86UA(&MU:6X@;GEK>6EN96X@<V%L87-A;F%S:2XB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L
M9"!P87-S=V]R9"(*;7-G<W1R(")686YH82!S86QA<V%N82(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")686YH82!S86QA<V%N82!O;B!V
MY.1R:6XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S='(@(D]M
M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW
M,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`B5F%I;B!)34%0+7!A;'9E;&EM970@='5K979A="!J
M865T='5J82!K86YS:6]I=&$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")6
M86EN(&QO=6MK86%V870@;6EE=&5L875S965T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(E9O:70@;&%I='1A82!V86EN('EH9&5N('/D:&OV<&]S=&EO<V]I='1E
M96XN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B
M"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@
M8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@
M82!S:&%R92(*;7-G<W1R("(B"B)686EN(&]M:7-T86IA('1A:2!JY')J97-T
M96QMY&X@>6QLY'!I=.1JY"!V;VD@;75U='1A82!J86MO:F5N(&]M:7-T86II
M82!T86D@(@HB;VEK975K<VEA(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-#$@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#(*;7-G:60@(D]P96X@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(D%V86$@=75D97-S82!I:VMU;F%S<V$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B
M3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I
M9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"!V:7)H93H@
M5&EE=&]J82!E:2!S86%T=2!E<VEL;&4@86QL96MI<FIO:71E='5S=&$@4R]-
M24U%+6]S87-T82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B079A82!TY&WD;B!L:6YK:6X@=75D
M97-S82!I:VMU;F%S<V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B2^1Y='3V:N1R:F5S
M=&5L;>0B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS
M9VED(")/<'1I;VYS(@IM<V=S='(@(D%S971U:W-E="(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")!<V5T
M=6MS970@)7,Z;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(DKD
M<FIE<W1E='1Y(&QI<W1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A
M;FES86%T:6\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")/<F=A
M;FES86%T:6]Y:W-I:VOV(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FES;VEN=&DB
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B06QK=7!E<N1I;F5N(&]H
M:F5L;6%N(&UA;&QI(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*
M;7-G<W1R(")!;&MU<&5RY&ES970@;6%L;&ET("5S.G-SY#HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B375U(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB
M"FUS9W-T<B`B375U="!T:65D;W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")/
M;6ES=&%J86X@;VEK975D970B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")004TM875T96YT:6MO:6YT:6$@96D@;VQE(&OD
M>71E='3D=FES<^0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS
M9W-T<B`B4$5!4CHZ36%I;"!T875S=&%JY')J97-T96QMY"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R(")$:6=I=&%A;&EN96X@4$=0+6%L;&5K
M:7)J;VET=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+7-A
M;&%T='5A('1I971O82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(DIU;&MI
M;F5N(%!'4"UA=F%I;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B4$=0+6%L;&5K:7)J;VET971T=6$@:F$@<V%L871T=6$@=&EE=&]A
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@0V]D92(*
M;7-G<W1R(")02%`M:V]O9&DB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`M:V]M96YT;W1U;&MK:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS
M9VED(")032!,:6=H="!286EN(@IM<V=S='(@(E!-(&ME=GET=.0@<V%D971T
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y
M"FUS9VED(")032!286EN(@IM<V=S='(@(E!-('-A9&4B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VAO
M=V5R<R(*;7-G<W1R(")032!K=75R;VIA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B4$T@;'5M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4$T@
M;'5M:7-A=&5I=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E!-(&QU;6DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I
M9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4$T@=6MK;W-M>7)S:WEJY"(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N
M<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8+6QA86IE;FYU:W-E="!P
M=75T='5V870B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE
M;&PB"FUS9W-T<B`B4%](4"UK;VUE;G1O='5L:VMI(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R(")4Y'ET92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-PIM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
M4&%L97-T:6EN82`H;6EE:&ET971T>2!A;'5E*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,@IM
M<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-0IM
M<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!5=7-I+4=U
M:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.34*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S<*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B3W-I='1A
M:6X@<&EL=FES=.0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,#(R"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")386QA<V%N
M82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B
M4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E-A;&%S
M86YA;B!V86EH=&\@;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B
M"FUS9W-T<B`B5N3D<N0@<V%L87-A;F$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")386QA<V%N86$@
M=&%R=FET86%N(%)!1$E54RUA=71E;G1I:V]I;G1I:6XN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`U-PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VXB"FUS9W-T<B`B4V%L87-A;F$@=F%R;6ES='5K<V5L;&$B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A
M<W-W;W)D.B(*;7-G<W1R(")386QA<V%N83HB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")3
M86QA<V%N83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(E-A;&%S86YO:F5N('!I=.3D(&]L;&$@<V%M870N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(DQI
M:73D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B3&EI
M=.0@;&5I:V5P]GEDY&QTY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B4&]L:W4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N
M9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")*;VYO<W-A(&]L979A="!S:7/DY&YK
M:7)J875T=6UI<W!Y>6YN]G0Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B26AM:7-E="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(E!R;W-E;G1T:2(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA
M:6YT96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`B4W5O<FET82!Y;&SD<&ET
M;W1O:6UE;G!I=&5E="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`B4W5O<FET82!Y;&SD<&ET;W1O:6UE;G!I=&5E="!S:7/D
MY&YK:7)J875T=6UI<V5N('EH=&5Y9&5S<^0N(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T
M<B`B3VEK975S(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B3VEK975T=&$@7"(E<UPB(&5I('!O:7-T971T=2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B2^1Y='3V(&MI96QL971T>2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M(")/:6ME=61E="(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,"!A
M9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$P.2!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(*;7-G:60@(E!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D]I:V5U:W-I96X@>6QL
MY'!I=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E
M<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D]M870@=&EE9&]T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@S"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B3&5M
M;6EK:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#8*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S
M='(@(D9I;&EP<&EI;FET(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B4'5H96QI
M;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H
M;W1O<R(*;7-G<W1R(")686QO:W5V870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP"FUS9VED
M(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B
M"FUS9W-T<B`B4&EK<V5L:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")+;&ES965T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM
M<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DYA
M<'-A=71A(&IO=&%I;B!S;VQU82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*
M;7-G<W1R(")687)M:7-T82!E='3D(&AA;'5A="!P;VES=&%A('3D;>1N(&5L
M96UE;G1I;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B5F%R
M;6ES=&$@971TY"!H86QU870@<&]I<W1A82!L:6YK:71Y:W-E;B!TY&CD;B!E
M;&5M96YT=&EI;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-38V
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R(")!;FYA(&MU=6MA=7-I(&IA('9U;W-I+B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")!
M;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,#4*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(D%N;F$@;VEK96$@25`M;W-O:71E
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#0*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(D%N;F$@;VEK96$@<.1I=N1M
MY.1RY#L@5&%R:VES=&$@<.1I=FEE;B!L=6MU;>3D<N0@:W5U:V%U9&5S<V$N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B06YN82!A:6MA(&]I
M:V5A<W-A(&UU;V1O<W-A+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2XB"FUS9W-T<B`B06YN82!L>6AY="!K=79A=7,@;VYG96QM
M87-T82XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(D%N;F$@:^1Y
M='3D:N1T=6YN=6MS97-I(&IA('-A;&%S86YA<VDB"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DQU92!S975R86%V
M82!T96MS=&DN(%-I;G5N(%!)5,3$('-U;W-T=6$@:^1Y='3V96AT;VEH:6X@
M=F]I9&%K<V5S:2!KY'ET=.3D("(*(FKD<FIE<W1E;&WDY"XB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I
M9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R
M(")!;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!U;VQA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VQI=&EI:VMA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM
M<V=I9"`B4&]L;',B"FUS9W-T<B`B2WES96QY="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")4
MY&WD;B!K=79A;B!P86EK:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI
M<R!T86)L92(*;7-G<W1R(")4Y&WD;B!T875L=6MO;B!P86EK:V$B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S
M='(@(E9O:2!LY&AE='3DY"!V:65S=&5JY"!K86YS:6]O;B`H96D@:V]S:V4@
M24U!4"!Y:'1E>6MS:>0I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B
M4V%D96WDY'+D(&5D96QL:7-I;&QE("5S('1U;FYI;&QE.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DAA:6AT=79U=7,@/&)R("\^=&]D
M96YNY&OV:7-Y>7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP
M:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@5&%R=FET=&%V
M86$@3$1!4"UL86%J96YN=7-T82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E
M<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@5&%R=FET=&%V86$@<V5S<VEO;BUL
M86%J96YN=7-T82!E:2!L]GET>6YY="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("));&UA;G!A:6YE(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T
M('-E82!L979E;#H@(@IM<V=S='(@(DEL;6%N<&%I;F4@;65R96YP:6YN87-S
M83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("));&UA;G!A:6YE.B`B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`S"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")%<VEK871S96QU(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B17-I:V%T<V5L92!K=79A('5U9&5S<V$@:6MK=6YA<W-A(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO
M;G,B"FUS9W-T<B`B161E;&QI<V5T(&%S971U:W-E="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT
M(&1O8W5M96YT(@IM<V=S='(@(E1U;&]S=&$@9&]K=6UE;G1T:2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T
M92!+97DB"FUS9W-T<B`B4V%L86EN96X@879A:6XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(D]N9V5L;6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G
M:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B3VYG96QM86X@:W5V
M875S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B
M4')O:F5C=',B"FUS9W-T<B`B4')O:F5K=&ET(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C$Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DR
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#`*;7-G:60@(E!R;VUP
M="!T97AT(@IM<V=S='(@(DME:&]T=&5E;B!T96MS=&DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB
M"FUS9W-T<B`B2G5L:VEN96X@879A:6XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B2G5L:VES96X@879A:6UE;B!A;&=O<FET;6DB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B
M;&EC($ME>2!);F9O(@IM<V=S='(@(DIU;&MI<V5N(&%V86EM96X@=&EE9&]T
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED
M(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")*=6QK:7-E;B]S86QA:7-E;B!A=F%I;G!A<FEN
M(&QU;VYT:2!E<.1O;FYI<W1U:2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M
M97-S86=E<R(*;7-G<W1R(")6;VD@='5H;W1A('!O:7-T971T=6IA('9I97-T
M96KD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-@IM<V=I9"`B46%T87(B"FUS9W-T<B`B46%T
M87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM
M<V=S='(@(DMY<V5L92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM
M<V=I9"`B475O=&$B"FUS9W-T<B`B2VEI;G1I]B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@
M(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(E)302!*=6QK:6YE
M;B!A=F%I;B`H)60@8FET=&GD*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-C@*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")2861I
M;W!A:6YI:V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R(")3861E(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@
M16%R;'DB"FUS9W-T<B`B4V%D971T82!A:6MA:7-I;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN($QA
M=&4B"FUS9W-T<B`B4V%D971T82!M>?9HY.1N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R
M(@IM<V=S='(@(E-A9&5K=75R;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S
M='(@(E9E<VD@:F$@;'5M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B
M5F5D97-TY"!L=6UE96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM
M<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B4V%T=6YN86EN96X@;6EE
M=&5L875S92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM
M<V=I9"`B4F%T:6\B"FUS9W-T<B`B4W5H9&4B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),
M=6MU(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*
M;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B5F]I(&QU:V5A('9I97-T
M96KD(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(E!O:7-T971A86YK
M;R`E<S\@5.1TY"!T;VEM:6YT;V$@96D@=F]I('!E<G5U='1A82XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B4&]I
M<W1E=&%A;FMO('1I961O="!KY'ET=.1JY'-TY"`E<S\@5.1TY"!T;VEM:6YT
M;V$@96D@=F]I('!E<G5U='1A82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(")4964@;75U=&]K<V5T('5U9&5S=&%A;B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(E#D:79I=.0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B4.1I=N1T(&1Y;F%A;6ES970@
M=F%L:6MK;V5L96UE;G1I=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")0Y&EV
M:73D('!O<G1A86QI;N1K>6WDY#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R
M(")3Y.1N;O9L;&EN96X@;&%U<V5K92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,S4*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S
M='(@(E)E;&%A=&EO<V5L86EN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(DQA=&%A('5U9&5L;&5E;B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@(DUU
M:7-T:6EN<&%N;W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS
M9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")%=.1P86QV96QI;65T(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T
M<B`B173D<&%L=F5L=6X@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E
M;6]V92(*;7-G<W1R(")0;VES=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")0;VES
M=&$@;W-I;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B4&]I<W1A
M('-A<F%K92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E!O
M:7-T82!M=6]T;VEL=2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")0;VES=&$@<&%R:2(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S
M879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R(")0;VES=&$@=&%L;&5T971T=2!S:W)I<'1I('!A;'9E;&EM
M96X@=N1L:6%I:V%I<VAA:V5M:7-T;W-T82XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E
M;6]V92!T:&4B"FUS9W-T<B`B4&]I<W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E!O:7-T
M82!TY&WD(&YO;V1I(&1O:W5M96YT:7-T82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V92!U<V5R(@IM<V=S
M='(@(E!O:7-T82!KY'ET=.1JY"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E
M<CH@)7,B"FUS9W-T<B`B4&]I<W1A(&OD>71TY&KD.B`E<R(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G
M<W1R(")0>7EN=/;V;B!E:2!V;VET=2!V87-T871A+B!6:7)H96MO;V1I.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30U"FUS9VED(")2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@
M(E!Y>61E='1YY"!P86QV96QU82!E:2!L]GET>6YY="XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4
M87)V:71T879A82!<(B5S7"(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@
M)7,@87-E='5K<VES<V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-C$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&%R=FET=&%V86$@7"(E<UPB+71I971O
M82!E:2!O;&QU="!MY.1R:71E;'1Y(%9&4R!A<V5T=6MS:7-S82XB"@HC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5&%R=FET=&%V86$@7"(E<UPB+71I971O82!E:2!O
M;&QU="!MY.1R:71E;'1Y(&%S971U:W-I<W-A+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE
M;&0B"FUS9W-T<B`B4&%K;VQL:6YE;B!K96YT=.0B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,2!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T,R!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")4>6AJ96YNY"(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S
M=V]R9"(*;7-G<W1R(")4>6AJ96YNY"!S86QA<V%N82(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(E1Y:&IE;F[D('-A;&%S86YA<VDB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS
M9W-T<B`B4&%L875T82!E9&5L;&EN96X@:WES96QY(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(Y(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B5'5L;VMS970B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(E!A;&%A(&%S971U:W-I:6XB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`B5F%H=FES=&$@=75S:2!S86QA<V%N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<*
M;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM
M<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B4&%L875T82!A
M<V5T=6MS970B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED
M(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B4FEC:"!497AT
M($5D:71O<FEN(&%S971U:W-E="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")!<G9O:71U:W-E="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B3VEK96$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3`W"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`B3VEK96$@;W1S86ME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$P,PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(D]I:V5A(&%R=F]T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M4FEV:5]N('1I961O="XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]O;&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DX"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)O;6%N
M:6$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(DODY&YNY"`Q.#`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS
M9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")+Y.1N;N0@=F%S=&%PY&EVY.1N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(DODY&YNY"!M>?9TY'#D
M:7;DY&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")2
M:79I;B!T:65D;W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R(")2:79I;B!T:65D;W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B4FEV
M:70Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B5FEI=F]I=&EN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")6:6EV;VET:6X@;N1K>7D@:V%I:VMI
M96X@<FEV:65N(&IA('-A<F%K:V5I9&5N(';D;&EL;.0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G
M<W1R(")6:6EV;VET:6X@;N1K>7D@=F%I;B!S87)A:VME:61E;B!VY&QI;&SD
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S
M(&]N;'DB"FUS9W-T<B`B5FEI=F]I=&EN(&[D:WEY('9A:6X@<FEV:65N(';D
M;&EL;.0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB
M"FUS9W-T<B`B4W5O<FET82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D*;7-G:60@(E)U<W-I
M86X@1F5D97)A=&EO;B(*;7-G<W1R(")696[D:N1N($9E9&5R871I:79I;F5N
M('1A<V%V86QT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`*;7-G:60@(E)W86YD82(*;7-G
M<W1R(")2=6%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M(@IM<V=S='(@(E,O34E-12!K<GEP=&]G<F%A9FEN96X@86QL96MI<FIO:71U
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS
M9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%
M('-A;&%T='4@=FEE<W1I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")305-,+6%U=&5N=&EK;VEN=&D@96D@;VQE(&OD
M>71E='3D=FES<^0N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P
M-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")335,@5&5K<W1I=FEE
M<W1I="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H
M96QL(@IM<V=S='(@(E-13"UK;VUE;G1O='5L:VMI(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(W.`IM<V=I9"`B4U%,('-T871E;65N="!F;W(@
M=F%L=64@;&]O:W5P<R(*;7-G<W1R(")344PM;&%U<V4@87)V;VIE;B!H86ME
M;6ES965N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM<V=I
M9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`B3TY.25-454DB"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4U]13"UK;VUE;G1O='5L
M:VMI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W"FUS
M9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%I;G0@2&5L96YA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,Q"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T
M<B`B4V%I;G0@2VET=',@:F$@3F5V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD*;7-G:60@
M(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X.0IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R
M(")386EN="!0:65R<F4@:F$@36EQ=65L;VXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T"FUS
M9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R
M(")386EN="!6:6YC96YT(&IA($=R96YA9&EI;FET(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(E-A;6%A;B!K96AY:W-E96X@*%]S96QF
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")3
M86X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-@IM<V=I9"`B4V%O(%1O;64@86YD
M(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&IA(%!R:6YC:7!E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L;&EI='1I('!A;'9E;'5N=&%R
M:F]A:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q"FUS9VED(")3875D:2!!<F%B:6$B"FUS
M9W-T<B`B4V%U9&EA($%R86)I82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R(")486QL971A(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")486QL971A(%PB)7-<
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B5&%L;&5T82`E<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N
M<R(*;7-G<W1R(")486QL971A(&%S971U:W-E="(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M
M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB5&%L;&5T82!L=6]D
M=70@87-E='5K<V5T(%!(4"US:W)I<'1I;N0@<&%L=F5L:6UE<VD@=N1L:6%I
M:V%I<VAA:V5M:7-T;V]N+B`B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")486QL971E='1I:6X@)7,Z;B!A<V5T=6MS970N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B07-E='5S=&5N('#D:79I='ES<VMR:7!T:2!O;B!T86QL971E
M='1U('!A:6MK86%N.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-C871T97)E9"!4+5-T;W)M
M<R(*;7-G<W1R(")(86IA;F%I<VEA('5K:V]S;7ER<VMY:N0B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B
M5&EE9&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H
M(@IM<V=S='(@(DAA:W4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")(86MU:V]N965T
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDU.0IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(E9A;&ET<V4@=&EE9&]S=&]T(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM<V=I9"`B
M4V5L96-T(&$@9&%T92(*;7-G<W1R(")686QI='-E('#D:7;D;>3D<N0B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T
M(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E9A;&ET<V4@;&ESY'1TY';D(')Y
M:&WD(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B
M4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9A;&ET<V4@=75S:2!O;6ES
M=&%J82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(E9A;&ET<V4@<&%L=F5L:6XB
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L
M96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5F%L:71S92!L:7/D='3D=N0@
M:^1Y='3D:N0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(E9A;&ET<V4@
M:V%I:VMI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T-PIM<V=I
M9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E9A;&ET
M<V4@:V%I:VMI('#D:7;D;>3D<N1K;VUP;VYE;G1I="(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C
M="!A;B!O8FIE8W0B"FUS9W-T<B`B5F%L:71S92!O8FIE:W1I(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B
M4V5L96-T(&YO;F4B"FUS9W-T<B`B5'EH:F5N;N0@=F%L:6YT82(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(E9A;&ET<V4@=&%R=FET=&%V870@;65R:VET
M(&%L;&$@;VQE=FES=&$@=F%L:6MO:7-T82X@5F]I="!S96X@:N1L:V5E;B`B
M"B)K;W!I;VED82!J82!L:6ET=.3D(&UE<FMI="!T96MS=&EI<VDN(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E9A;&ET<V4@<.1I=N1Y:W-E;B!E
M<F]T:6YM97)K:VDZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*
M;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E9A;&ET
M<V4@<.1I=N1Y:W-E;B!E<VET>7-T87!A.B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")686QI='-E(&UU
M=71E='1A=F$@<')O9FEI;&DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(E9A;&ET<V4@:V5L;&]N86IA;B!E<F]T:6YM97)K:VDZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(E9A;&ET<V4@86IA;B!E<VET>7-T87!A.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")686QI='-E(&MA:W-I
M('EH=&5E;G-O<&EV86$@:V5N='3DY"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(E9A;&ET<V4@=N1R:71E96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93HB"FUS9W-T<B`B5F%L:71S92!KY'ET971TY';D(&MI96QI.B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(DSD:&5TY"!O;F=E;&UA=FEE<W1I
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(DSD:&5TY"!335,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B5'5N;FES=&EN.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(G-Y
M>7-K=74B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I
M82!J82!-;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B4V%R
M:F%N=6UE<F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y
M"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")086QV96QI;65N('1I961O="!O=F%T(';DY')IY"!T86D@96EV
MY'0@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(DES='5N=&]J96X@
M:&%L;&EN=&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B4V5S<VEO;B!)1"!O;B!V86YH96YT=6YU="XB"@HC.B!L:6(O87!I
M+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(DES='5N;F]T(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q.`IM<V=I9"`B4V5T(@IM
M<V=S='(@(D%S971A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS
M9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P
M87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(E-A
M;&%S86YA;B!R97-E=&]I;G1I:6X@;&EI='1Y=FGD(&%S971U:W-I82P@:F]S
M(&IO<VMU<R!U;F]H9&%T('-A;&%S86YA<VDN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S
M='(@(B(*(E9O:70@87-E='1A82!U;&MO:7-T96X@<&%L=F5L:6UI96X@87-E
M='5K<V5T+"!J;VET82!H86QU870@:^1Y='3DY"`B"B)P;W)T86%L:7-S82XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RXB"FUS9W-T<B`B(@HB5F]I="!A<V5T=&%A(&OD>71E='3D=N1N(&MI96QE
M;BP@86EK879Y]FAY:VME96X@:F$@;75I=&$@<.1I=N1MY.1RY&%S971U:W-I
M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB5F]I="!A<V5T=&%A(&%L;VET=7-O:&IE;&UA;BP@=N1R
M:71E96UA;BP@;N1K>6WD;B!PY&EV:71Y:W-E;B!J82!M=6ET82`B"B)NY&MY
M;>3D;B!L:6ET='EV:>0@87-E='5K<VEA+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(D%S96YN=7,B"@HC
M.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B
M4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")!<V5N
M;G5K<V5N('#D:79I='ES<VMR:7!T:2!O;B!S86%T879I;&QA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T
M<B`B57-E870@<&%I:V%T('-O<&EV870@86YN971T=75N('!A<F%M971R:6EN
M.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`S"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@
M(E-E>6-H96QL:70B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX
M"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")/<W1O:W-E="(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(DQY:'ET(&MU=F%U<SHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B07-E=&5T82!P:6MA=F%L
M:6YT86[D<'#D:6UE="!U<V5I;6UI;&QE(&QI;FME:6QL92XB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R(").Y'ETY"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*
M;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@HB3N1Y=.0@97)O879A:7-U=61E="!A<V5T=6MS:65N
M('1A;&QE=&5T=7-S82!J82!U=61E<W-A(&IU=7)I(&UU;VMA='5S<V$@(@HB
M=F5R<VEO<W-A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G
M:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS
M9W-T<B`B3N1Y=.0@961E;&QI<V5N('-I<^3D;FMI<FIA=71U;6ES96X@<.1I
M=N1Y<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Y"FUS9VED
M(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(D[D>73D
M(&%S971U<R!P:73DY&MS97-I(&%L:W5P97+D:7-E;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(W.3D*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S
M='(@(D[D>73D('9A;&ET<VEN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*
M;7-G<W1R(").Y'ETY"!T875L=6MK;W1O:6UI;FYO="!V86QI:VMO+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B3N1Y
M=.0@=F%S96UM86QL82`E<R!V86QI:VMO+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(").
MY'ETY"!T875L=6MO;B!S;VQU;B!T:65D;W0@9&EA;&]G:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM
M<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B3N1Y=.0@=&%U;'5K;VX@=&EE9&]T(&1I86QO9VDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G
M<W1R(").Y'ETY"!T875L=6MO;B!R:79I;B!T:65D;W0@9&EA;&]G:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B3N1Y=.0@:W5V86X@=&EE9&]T(&1I86QO9VDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8W"FUS9VED(")3:&]W('5P;&]A9"(*
M;7-G<W1R(").Y'ETY"!T=6]N=&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")3
M871E:71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3,*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B4V%T96ET82!A
M:6MA:7-I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4V%T96ET82!M
M>?9H96UM:6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B4V%T96ET82!LY&AE='1Y=FEL;&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM
M<V=S='(@(E!I96YE;F[D(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(U,@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R
M.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")0:65N96YNY"!T86D@
M<VEI<G+D('9I97)E:7-IY"!O<VEO:71A+"!J;W1T82!N92!E:7;D="!O;&4@
M=&EE;&SD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B2VER:F%U
M9'4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM
M<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(D%L;&5K:7)J;VET=7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG
M;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&QE:VER:F]I='5K<V5N(&%L
M9V]R:71M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I;F=A<&]R92(*;7-G
M<W1R(")3:6YG87!O<F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#`*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3`@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDQ-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3`Y"FUS9VED(")3:7IE(@IM<V=S='(@(DMO:V\B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-
M86EN=&5N86YC92(*;7-G<W1R(")/:&ET82!Y;&SD<&ET;W1E:'3D=N1T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q,`IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B4VQO=F%K
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`X"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3
M;&]V96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(DQU;6DB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B3'5M:7-A9&5T=&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S
M(@IM<V=S='(@(DQU;6ES871E:71A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("),=6UI<V%T96ET82!A:6MA:7-I;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H
M;W=E<G,@3&%T92(*;7-G<W1R("),=6UI<V%T96ET82!M>?9HY.1N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*
M;7-G<W1R("),=6UE;B!S>79Y>7,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G
M<W1R("),=6UE;B!MY.1RY"!V971E;N0Z("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(*;7-G
M:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")386QO;6]N('-A87)E="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,30*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI
M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@
M)B!0;V5M<R(*;7-G<W1R("),875L=70@:F$@4G5N;W5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,@IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B2N1R:F5S='EK<V5N('-U=6YN86X@=F%L:6YT82(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(DSD:&1E
M;W-O:71E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-0IM<V=I9"`B4V]U=&@@069R:6-A(@IM
M<V=S='(@(D5T96SD+4%F<FEK:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(D5T96SD+45U<F]O<'!A("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,0IM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',B"FUS9W-T<B`B171E;.0M1V5O<F=I82!J82!E=&5LY&ES970@
M4V%N9'=I8V@@<V%A<F5T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI
M8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R
M92(*;7-G<W1R(")%=&5LY&EN96X@<&%L;&]N<'5O;&ES:V\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")6Y&QI('9I
M97)E:7-E="!S;VQU:F5N(';D;&ES<^0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")6Y&QI('-O
M;'5N(&QE:7#D=&5K<W1I;B!J82!R975N86X@=N1L:7-SY"`B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R
M(")6Y&QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4U"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(E;D;&DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(E;D;&D@
M:F$@=.1Y=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,`IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M17-P86YJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G
M:60@(E-P86TB"FUS9W-T<B`B4F]S:V%P;W-T:2(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B
M"FUS9W-T<B`B17)I:V]I<VUE<FMK:65N('-Y]G1T]B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@
M(E-P;&ET(&-E;&PB"FUS9W-T<B`B2F%A('-O;'4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3
M<&QI="!C;VQU;6XB"FUS9W-T<B`B2F%A('-A<F%K92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R(")*86$@<FEV:2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E5R:&5I;'4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#$*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@
M3&%N:V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B
M4W1A;F1A<F1I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED
M(")3=&%R(%1R96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-SDU"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%L:V%M:7-V=6]S:2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED
M(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("),Y.1N:2!T86D@86QU92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED
M(")3=&%T=7,B"FUS9W-T<B`B5&EL82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,#$*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(E1A
M;&QE;FYU<VUU;W1O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(DMA='5O
M<V]I=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(DSD<&EL>?9N
M=&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"FUS9VED(")3
M=')I;F<@;&ES="(*;7-G<W1R(")-97)K:VEJ;VYO;&ES=&$B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")0;VES=&$@=&]I;6EA;'5E(&]S
M;VET=&5E<W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B
M5'EY;&D@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")S=2(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B06QI:&%K96UI
M<W1O82!<(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G
M<W1R(")/='-I:VMO(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B
M4W5B;6ET(@IM<V=S='(@(DSD:&5TY"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I
M;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@
M(B(*(DSD:&5T971T:6EN(%PB)7-<(CIN(&QI<^1Y<W!Y>6YT]BX@170@=F]I
M(&MI<FIA=71U82!S:7/DY&X@96YN96X@:W5I;B`B"B)P>7EN=/9S:2!O;B!K
MY'-I=&5L='D@:F$@:'EVY&MS>71T>2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS
M9W-T<B`B06QI:VER:F]I='5S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P
M-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(D]N
M;FES='5I(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(Z(&QI<^3D;6EN96X@:N1R:F5S=&5L;>3D;B!O
M;FYI<W1U:2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")+Y'ET=.1JY&X@7"(E
M<UPB(&OD>71TY&KD=&EE=&]J96X@<&]I<W1A;6EN96X@:N1R:F5S=&5L;>1S
M=.0@;VYN:7-T=6DN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB('!O:7-T
M971T:6EN(&]N;FES='5N965S=&DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(CH@;VYN:7-T
M=71T:6EN('!O:7-T86UA86X@:N1R:F5S=&5L;>1S=.0N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS
M9W-T<B`B(@HB4&%L871T:6EN(&]N;FES='5N965S=&D@=F%N:&]I:&EN(&%S
M971U:W-I:6XN($QA=&%A('-I=G4@=75D97-T86%N("(*(F[D:&3D:W-E<VD@
M;75U=&]K<V5T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HU.0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A
M=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")486QL96YN971T
M:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*
M;7-G<W1R(")486QL96YN971T:6EN(&%S971U:W-I96X@=F%R;75U<VMO<&EO
M("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B)R5S
M)SH@<.1I=FET>7,@;VYN:7-T=6DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B5S.FX@
M:VER:F]I='1A;6EN96X@;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-`IM<V=I
M9"`B4W5D86XB"FUS9W-T<B`B4W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(EEH=&5E;G9E=&\B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(D%U<FEN9V]N;F]U<W4B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B
M"FUS9W-T<B`B075R:6YG;VYL87-K=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")3=6YN>2(*;7-G<W1R(")!
M=7)I;FMO:6YE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B075R:6YG;VYN;W5S=2(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B075R:6YK;R!N
M;W5S964O;&%S:V5E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-`IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(D%U<FEN9V]N;F]U<W4Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@
M(E-U;G-E="(*;7-G<W1R(")!=7)I;F=O;FQA<VMU(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T
M<B`B075R:6YG;VYL87-K=3H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T
M<B`B4.3D;&QE:VER:F]I='5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")4=6MI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(E-U:W5N:6UI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.0IM<V=I
M9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")(=6EP<'5V=6]R
M970@:F$@2F%N($UA>65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.0IM<V=I9"`B4W=A>FEL
M86YD(@IM<V=S='(@(E-W87II;6%A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-0IM<V=I9"`B
M4W=E9&5N(@IM<V=S='(@(E)U;W1S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V"FUS9VED(")3
M=VET>F5R;&%N9"(*;7-G<W1R(")3=F5I='-I(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS
M9W-T<B`B4WEN8R!L;VMI('!O:7-T971T=2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y
M;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4WEN=&%K<VEV
M:7)H92!H86MU=&5R;65I<W/D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.`IM<V=I9"`B4WER
M:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4WEY<FEA+"!A<F%B:71A<V%V
M86QT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8R"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(E5K:V]S;7ER<VMY(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@
M(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(E5K:V]S;7ER<VMY:N0@:F$@
M='5U;&ES=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B56MK;W-M>7)S:WET
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*
M;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(E5K:V]S;7ER<VMY:N0@
M86EK86ES:6XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V
M"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")44U8M=&EE9&]S=&\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS
M9W-T<B`B5&%U;'5K:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S
M(@IM<V=S='(@(E1A=6QU:V]N('1I961O="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*
M;7-G<W1R(")4875L=6MO;B!A<V5T=6MS970B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L
M92!P<F]P97)T:65S(@IM<V=S='(@(E1A=6QU:V]N('1I961O="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S0*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486EW86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I
M9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL
M($MI:6YA;B!M86%K=6YT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4*;7-G:60@(E1A:FEK
M:7-T86XB"FUS9W-T<B`B5&%D>FEK:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U"FUS
M9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A
M;GIA;FEA+"!9:&1I<W1Y;GET('1A<V%V86QT82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB
M"FUS9W-T<B`B2V]H9&4Z(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S(@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0HC.B!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z,3`T.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&5H
M=.1VY'0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")0=6AE;&EN;G5M
M97)O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3<*;7-G:60@(E1E;7`@
M9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(DSD;7#V=&EL82!E9&5L;&ES96QL
M92!T=6YN:6QL93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(DSD;7#V=&EL82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E
M.B`B"FUS9W-T<B`B3.1M</9T:6QA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B3.1M
M</9T:6QA/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")-
M86QL:6$@7"(E<UPB(&5I(&SV>71Y;GET+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")-86QL:65N(&AA;&QI;G1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,Q"FUS9VED
M(")497AT(@IM<V=S='(@(E1E:W-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")686EN('1E:W-T
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B5&5K<W1I;B!T
M87-A=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E:W-T:71O<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G
M:60@(E1H(@IM<V=S='(@(G1O(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.30*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(E1H86D@*%1)4RTV
M,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-`IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B
M5&AA:6UA82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")&5%`M;&ESY'1O:6UI;G1O(&5I(&]L92!KY'ET971TY'9I<W/D+B(*
M"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4
M:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAI<W1O
M<GD@:N1R:F5S=&5L;>0@96D@;VQE(&OD>71E='3D=FES<^0N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8B!I;G1E9W)O
M:6YT:6UO;W1T;W)I(&5I('1U92!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@
M8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("))35-0(&QO:VEA
M(&5I('9O:71U(&%L=7-T86$N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T
M(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(DUA:6YT96YA;F-E.CH@+6QU
M;VMA;B!L871A86UI;F5N(&5PY&]N;FES='5I(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(D%S971U:W-E="!I
M:VMU;F$@;VX@<W5L:F5T='4N(%!O:7-T=71A86XN(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE
M961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K
M96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T
M<B`B(@HB66QLY'!I9&]N('!I=.3D(&]T=&%A(&OD>71T]O9N('!Y<WEVY"!T
M86QL971U<W1Y>7!P:2!097)M:7-S:6]N+"!J;W,@:&%L=6%T("(*(FOD>71T
MY.0@;FEI=.0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB
M"FUS9W-T<B`B5F%I;B!A;&%P=6]L:2(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*(D-O;G1A8W0@:60@;G5M97)O82!E:2!O;&4@;>3D<FET96QT>2P@;VX@
M='EH:N0@=&%I(&5I(&SV>71Y;GET('1I971O:V%N;F%S=&$N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(")9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]N
M;FES='5N965S=&D@;W-O:71E:VER:F%A<VDN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB5FEE<W1I;B!A;&QE:VER
M:F]I='5K<V5N('1A<FMI<W1A;6ES965N('1A<G9I=&%A;B!E<FEL;&EN96X@
M4$=0+2(*(F%L;&5K:7)J;VET=7-L;VAK;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE
M(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E
M+B(*;7-G<W1R("(B"B)*86ME;'5L:7-T86X@240@96D@;VQL=70@;>3D<FET
M96QT>2P@;VX@='EH:N0@=&%I(&5I(&SV>71Y;GET('1I971O:V%N;F%S=&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"XB"FUS9W-T<B`B2F%K96QU;&ES=&%A(&5I(&]L;'5T(&WDY')I
M=&5L='DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G
M:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@
M=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(E-A;&%U<W1O:6UI;FYO;B!KY'ET
M=/8@=F%A=&D@<V%L871T=6$@5U=7+7EH=&5Y='3D+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3<W(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-3$Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B5&EE9&]S=&]S<V$@
M)7,@<&ETY&ES:2!O;&QA("5S(&%S971U<RXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W,"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")4:65D;W-T;W-S82`E
M<R!P:73D:7-I(&]L;&$@:F]I=&%K:6X@)7,@87-E='5K<VEA+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@
M8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B5&EE9&]S
M=&]A(&5I('9O:61A(&MO<&EO:61A(&ET<V5N<^0@<.3D;&QE+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(E1I961O<W1O(&]L:2!T>6AJY"XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(")3975R86%V87-S
M82!O;B!O='-I:VMO=&EE9&]T('3D<W3D(&UE<W-A9V4O<F9C.#(R("UV:65S
M=&ES=.0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R
M97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E
M96X@961I=&]R+B(*;7-G<W1R("(B"B)+;VMO<G5U9'5N(&[D>71T]G1I;&$@
M86EH975T=&%A(&]N9V5L;6EA(&IO:6QL86MI;B!);G1E<FYE="!%>'!L;W)E
M<B`B"B)S96QA:6UE;B!KY'ET=.1J:6QLY"X@5F%L:71E='1A=F%S=&D@:WES
M96EN96X@<V5L86EN('-I<^1L=.3D('!I:7)T96ETY"!J82`B"B)V:7)H96ET
MY"!J;VEH:6X@96D@;VQE(&SV>71Y;GET(&MO<FIA=7-T82!T86D@:V5I;F]A
M(&MI97)TY.0@;VYG96QM82X@(@HB2'5O;6%A=&AA;B!E='3D(&IO<R!KY'ET
MY'0@=.1TY"!NY'ET=/9T:6QA82!J82!);G1E<FYE="!%>'!L;W)E<B!S96QA
M:6YT82P@(@HB;FEI;B!NY'ET=/8@<V%A='1A82!M96YNY"!S96MA:7-I;BP@
M:F]T:W5T('1O:6UI;FYO="!E:7;D="!T;VEM:2!T86D@<V5L86EN("(*(G-A
M871T86$@:V%A='5A+B!*;W,@:^1Y=.1T(%=I;F1O=W,@.7@@=&%I($U%('9E
M<G-I;W1A+"!N:6EN(&]N(&UA:&1O;&QI<W1A("(*(F5T=.0@:^1Y='3V:N1R
M:F5S=&5L;>0@:V%A='5U(&YS+B`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT
M)R`M=FER:&5E<V5E;B!J82`B"B)S:6YU;B!P:73DY"!KY'EN;FES=.3D(&MO
M;F4@=75D97-T86%N+EQ<;EQ<;B!-=6ES=&$@971TY"!S:6YU82!O;B`B"B)V
M87)O:71E='1U+B!.87!S875T82!/2RUN87!P=6QA82!J;W,@:&%L=6%T(&MO
M:V5I;&QE(&5D:71O<FEN(&MO:V]R=75T=2`B"B)NY'ET=/9T:6QA82XB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B4&]I<W1E='1I:6X@<')O9FEI;&D@7"(E<UPB+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@
M(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E9A:6X@=F%S96X@
M<'5O;&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M(")';G501R!O:&IE;&UA;B!S:6IA:6YT:2!P:73DY"!MY.1R:71E;&SD($-R
M>7!T7W!G<#HZ("UL=6]K87-S82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S
M86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@
M8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS
M9W-T<B`B(@HB5FEE<W1I(&SD:&5T971T>2`E<R!V87-T86%N;W1T86IA;&QE
M("5S(&]T<VEK:V]N82!<(B5S7"(@;VX@;N1Y=&5T='DN7&XB"B)%:2!O;&4@
M;6ETY.1N('1A:V5I=&$@<VEI=.0@971TY"!V:65S=&D@;VX@;'5E='1U('1A
M:2!Y;6WD<G)E='1Y+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M.#$*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G92(*;7-G<W1R(").:6UI(&IO=&$@:^1Y=&5TY.1N(&QI
M;FMI=&5T=.1E<W-A(&QU;R!S:79U;&QE(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(DME;G1T:65N(&WDY'+D('!I=.3D
M(&%N=&%A(&YU;65R;VEN82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R
M97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM
M<V=S='(@(DUO9'5U;&D@;W!E;G-S;"!T87)V:71A86X@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B`M;'5O:V%N(&OD>71TY&UI<V5K<VDN(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+G!H<#HR.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A
M=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L
M92!S:7IE(@IM<V=S='(@(B(*(D%S971U<W1A(%PB)7-<(B!K;W-K82!S96X@
M=&EE9&]T('EL:71T:7;D="!T86QL971U<W1A=F%N('-U=7)I;6UA;B!S86QL
M:71U;B`B"B)R86IA;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P
M;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R
M8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]W96)C<'`N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB3VAJ96QM86$L
M(&IO;&QA('9O:2!K871S;V$@=FEE<W1I='EY<'!IY"`H)7,I+"!E:2!L]GET
M>6YY="!JY')J97-T96QMY'-TY"XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B3&%I;F%U<VUE<FMK
M:2!P:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED
M(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")686EN
M(&]I:V5A(&IA('9A<V5N('!U;VQI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E9A:6X@;VEK96$@<'5O;&DB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S
M97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T
M<B`B17)O=&EN('!I=.3D(&]L;&$@>6MS:71TY&EN96X@;65R:VMI+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM
M<V=S='(@(E!A;'9E;&EN(%PB)7-<(B!O;B!P;VES=&5T='4N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@
M(E!A;'9E;&EN(%PB)7-<(B!O;B!T86QL971E='1U+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(E-I<^3D
M;FMI<FIA=71U;6ES<'EY;G3V("5S(&]N('!O:7-T971T=2XB"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@
M;F]T(&5X:7-T+B(*;7-G<W1R(")-Y.1R:71E;'1YY"!R:79IY"`H)60I(&5I
M(&]L92!O;&5M87-S82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@
M7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")686QIY&%I:V%I<W1I
M961O<W1O82!<(B5S7"(@96D@;VQE(&]L96UA<W-A+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,#8*;7-G:60@(E1H92!T97AT('EO=2!E;G1E
M<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS
M9W-T<B`B2VER:F]I='1A;6%S:2!T96MS=&D@96D@=F%S=&%A('1E:W-T:>0@
M<G5U9'5L;&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'DB"FUS9W-T<B`B5F%I;B!Y;.1P=6]L:2!J82!A;&%P=6]L:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E9A:6X@
M>6SD<'5O;&DB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G
M:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+B(*;7-G<W1R(")4=6]T=2!T:65T;R!HY'9I<VD@961E;&QI
M<V5N(&MO:&1A;B!A:6MA;F$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C
M<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS
M9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM
M<V=S='(@(E1U;W1U82!T:65D;W-T;V$@96D@=F]I='4@=&%L;&5T=&%A+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W-I;W1A('=E871H
M97(N8V]M(&5I(&]L92!KY'ET971TY'9I<W/D+B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E1E96UA:&%K96UI
M<W1O82!<(B5S7"(@96D@;/9Y='EN>70N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92XB"FUS9W-T<B`B07-E='5K<VEA(&5I(&]L92!S86%T879I
M;&QA+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T
M.`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(D5I(&]L92!O<VEO:71A+"!J;W1K82!V
M;VED86%N(&[D>71TY.0@=FEE<W1I96X@>6AT97ED97-SY"XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`U"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU
M<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)4Y'-SY"!K96YT
MY'-SY"!O;B!L:6EA;B!M;VYT82!M97)K:VGD+B!!;FYO:70@)7,@;65R:VMI
MY#L@<VEN=6X@<&ETY.0@86YT86$@(@HB=N1H96UMY&X@:W5I;B`E<R!M97)K
M:VGD+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(DIO:71A:VEN(&]N
M9V5L;6EA(%PB)7-<(B!L:7/DY&UI<V5S<^0@:N1R:F5S=&5L;>3D;CH@)7,B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)+Y'ET=.1JY&X@
M7"(E<UPB(&OD>71TY&KD=&EE=&]J96X@<&]I<W1A;6ES97-S82!JY')J97-T
M96QMY'-SY"!O;&D@;VYG96QM:6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")*;VET
M86MI;B!O;F=E;&UI82!<(B5S7"(@<&]I<W1A;6ES97-S82!JY')J97-T96QM
MY'-TY#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E
M<R(*;7-G<W1R(")*;VET86MI;B!O;F=E;&UI82!<(B5S7"(@<.1I=FET>6MS
M97-SY#H@)7,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY
M,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G
M<W1R(")4:65D;W-T;VX@='5O;FYI<W-A(&]L:2!O;F=E;&UI82X@66ATY.1N
M("5S.F$@96D@='5O='4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G
M97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S
M*2XB"FUS9W-T<B`B(@HB5&EE9&]S=&]N('1U;VYN:7-S82!O;&D@;VYG96QM
M:6$N("5S(&MO:V\@;VQI('-U=7)E;7!I(&MU:6X@<W5U<FEN('-A;&QI='1U
M("(*(FMO:V\@*"5D('1A=G5A*2XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B5&EE9&]S=&]N
M('1U;VYN:7-S82!O;&D@;VYG96QM:6$N("5S(&QA=&%U='5I('9A:6X@;W-A
M:W-I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H
M:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E1A<&%H='5I('9I<FAE(&[D>71E
M='3D97-SY"!V:65S=&EN('3D=.0@;W-I;W1A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")9
M:'1E>7-T:65T;VIE;B!T=6]N;FES<V$@=&%P86AT=6D@=FER:&4N(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B:4-A;&5N9&%R+71I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V
M:7)H92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED("(B
M"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB
M"FUS9W-T<B`B(@HB07-E='5S=&EE=&]L;VUA:VME97-S82!O;B!J;VMI;B!V
M:7)H92X@16AKY"!JY'1I="!J;VYK=6X@<&%K;VQL:7-E;B!K;VAD86X@(@HB
M=.1Y='3D;>1T=.0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)4
M87!A:'1U:2!V:7)H92!Y<FET971TY&5S<^0@<W5O<FET=&%A(&]S;VET96MI
M<FIA=&]I;6EN=&]A+B!9<FETY"!M>?9H96UM:6X@(@HB=75D97-T86%N+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@HB66AT97ES=&EE=&]J96X@<.1I=FET>6MS97-SY"!T87!A:'1U
M:2!V:7)H92X@67)I=.0@;7GV:&5M;6EN('5U9&5S=&%A;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B2F%K
M96QU;&ES=&%N('#D:79I='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D
M(&UY]FAE;6UI;B!U=61E<W1A86XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,30Y"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")4
MY&WD($E-05`@<&%L=F5L:6X@96D@='5E(&MA;G-I;VED96X@:F%K86UI<W1A
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N(@IM<V=S='(@(E3D;>0@=&EE9&]S=&\@96D@=F%I:W5T82!R
M87(M=&EE9&]S=&]L=&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B5.1MY"!T:65D;W-T;R!E
M:2!V86EK=71A('II<"UT:65D;W-T;VQT82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3,Q"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B5.1MY"!E:2!V86EK
M=71A(&]I:V5A;'1A(&MO<G1T:6YU;65R;VQT82XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E3D;&SD
M(&%J=7)I;&QA('9O:2!LY&AE='3DY"!V:65S=&5JY"!#;&EC:V%T96QL:6X@
M*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@(@HB9V%T97=A>2!P86QV96QU82!(
M5%10($%023IL;&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L
M8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"B)4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5TE.
M("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2`B"B)P86QV96QU;B!K875T
M=&$@2%144"!!4$DZ;&QA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB5.1L;.0@86IU<FEL;&$@=F]I(&SD
M:&5T=.3D('9I97-T96KD('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI("(*(F=A=&5W87D@<&%L=F5L=6X@:V%U='1A($A45%`@05!).FQL82XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB5.1L;.0@86IU
M<FEL;&$@=F]I(&SD:&5T=.3D('9I97-T96KD(%9O9&%F;VYE;B!N=6UE<F]I
M:&EN(%--5%`Z;&SD(&OD>71TY&5N("(*(E9O9&%F;VYE($ET86QY(&=A=&5W
M87D@<&%L=F5L=6$N(%3D=.0@<&%L=F5L=6$@=F]I(&OD>71TY.0@=F%I;B!6
M;V1A9F]N92`B"B))=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I('1U;FYU:W-I
M;&QA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#8Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P.3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`R"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$U-C$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,#D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@R"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q-3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#`Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,3<*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(@IM<V=S='(@(E3D;>0@:V5N='3D(&]N('!A:V]L;&EN96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")4Y'-SY"!K
M96YTY'-SY"!P:73DY"!O;&QA('9A:6X@:V]K;VYA:7-L=6MU:F$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R,`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B5.1S<^0@:V5N=.1S<^0@<&ETY.0@;VQL82!N=6UE<F]I=&$@:F$@
M<&EL:VMU+6UE<FMK96KD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A
M;"!V86QU97,N(@IM<V=S='(@(E3D<W/D(&ME;G3D<W/D('!I=.3D(&]L;&$@
M;VMT86%L:6QU:W5J82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3(W"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C
M92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)4Y'-S
MY"!K96YTY'-SY"!P:73DY"!O;&QA(&QI<W1A(&MO:V]N86ES;'5K=6IA+"!J
M;W1K82!P:73DY"!O;&QA(&5R;W1E='1U("(*(G!I;&MU;&QA('1A:2!VY&QI
M;'GV;FYI;&SD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3DS"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S
M='(@(D%R=F]N('!I=.3D(&]L;&$@;G5M97)O+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,C(*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB5.1S<^0@:V5N
M=.1S<^0@;VX@=N1R:6WDY')I='ES+"!J;VYK82!P:73DY"!O;&QA(%)'0B!(
M97@@;75O9&]S<RP@(@HB97-I;65R:VEK<VD@)R,Q,C,T868G+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")4Y&WD(&QO;6%K
M92!O;B!J;R!KY'-I=&5L='DN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N
M:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T
M<B`B5.1MY"!O;B`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H
M92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@
M96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB
M5.1MY"!O;B!+;VQA8B!'<F]U<'=A<F4@;V)J96MT:2X@2V%T<V]A:W-E<VD@
M=.1MY&X@;V)J96MT:6X@<VEN=6QL82!P:73DY"`B"B)O;&QA('/D:&OV<&]S
M=&EO:&IE;&UA+"!J;VMA('EM;>1R=.3D($MO;&%B($=R;W5P=V%R92!F;W)M
M86%T=&EA+B!,:7-T82`B"B)Y:'1E96YS;W!I=FES=&$@<^1H:_9P;W-T:6]H
M:F5L;6ES=&$@;/9Y='EY(&]S;VET=&5E<W1A("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DW"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)4Y&WD
M('9I97-T:2!O;B!K:7)J;VET971T=2!E<FD@;65R:VES=/9L;.0@*"5S*2!K
M=6EN(&UI:^0@<VEN=6QL82!O;B`B"B)KY'ET]G-SY"X@(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(").=6UE<F]N('!I=.3D
M(&]L;&$@=N1H:6YTY.1N('EK<VDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B5.1L
M;.0@<&%L=F5L:6UE;&QA(&5I('9O:2!A=6MA:7-T82!Z:7`M('1A:2!G>FEP
M+71I961O<W1O:F$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D
M96%C=&EV871E9"XB"FUS9W-T<B`B5.1MY"!JY')J97-T96QMY"!O;B!P;VES
M('#DY&QTY"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R
M(")!<G9O;B!P:73DY"!O;&QA(&YU;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(E3D
M;>1N(&EK:W5N86X@=F]I(&%U:V%I<W1A('9A:6X@07-E='5K<V5T(&EK:W5N
M87-T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(DUY<G-K>2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T
M<B`B5&EK971I="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,CD@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4:6UE(@IM
M<V=S='(@(D%I:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X
M"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(D%J86YS975R86YT82(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B
M"FUS9W-T<B`B06IA;B!E<VET>7-M=6]T;R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U,S4*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(D%J86X@=F%L:6YT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`*;7-G:60@(E1I;6]R+4QE
M<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET=&5L:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I
M=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B3W1S:6MK;R`H=&]O;'1I<"DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B5F%S=&%A;F]T=&%J82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N
M(@IM<V=S='(@(B(*(E9O:61A:W-E<VD@=F%L:71A('5S96%M<&EA('9A:6AT
M;V5H=&]J82P@<&EDY"!#;VYT<F]L+2`H4$,I('1A:2!#;VUM86YD+2`B"B(H
M36%C*2!NY'!PY&EN=.0@<&]H:F%S<V$@:W5N(&YA<'-A=71A="!H:6ER96X@
M<&%I;FEK971T82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")4Y&[DY&XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G
M;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B3N1Y=.0@2%1-3"ULY&AD96MO;V1I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,PIM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R(")4;VME;&%U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B2'5O;65N;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y"FUS
M9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI9"!L
M;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@(B(*(DQI
M:6%N(&UO;G1A(&5PY&]N;FES='5N=71T82!K:7)J875T=6UI<WER:71Y<W3D
M('9I:6UE:7-I;7!I96X@;6EN=75T=&EE;B`B"B)K=6QU97-S82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*
M;7-G:60@(E1O<"(*;7-G<W1R(")9;/9S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?
M=&]P*2(*;7-G<W1R(")9;&EM<.3D;B!K96AY:W-E96X@*%]T;W`I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B
M"FUS9W-T<B`B2^3D;F[V:W-E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(*;7-G:60@(E1R
M:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@:F$@5&]B86=O
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U
M92!O<B!F86QS92(*;7-G<W1R(")4;W-I('9A:2!E<.1T;W-I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X"FUS9VED(")4=6YI<VEA
M(@IM<V=S='(@(E1U;FES:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q"FUS9VED(")4=7)K
M97DB"FUS9W-T<B`B5'5R:VMI(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.34*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<FMK
M:2`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N
M:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,`IM
M<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS
M(&IA($-A:6-O<R!S86%R970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(DMI<FIO
M:71A('9A;&EN=&%S:3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N5BX@+6EN
M9&5K<VDZ("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(E523"!J;VAO;B!P86QA
M=71E=&%A;B!S:W)I<'1I;B!S=&%T=7,@<F%P;W)T=&DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ
M(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W"FUS9VED(")59V%N9&$B
M"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-@IM<V=I9"`B56MR86EN
M92(*;7-G<W1R(")5:W)A:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(E9&4RUH86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B2^1Y='3D:N1N(&QI<^1T:65T;VIE;B!L:7/D
M>7,@96D@;VYN:7-T=6YU="!K:7)J875T=6UI<V5S<V$N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(D5I('9O:2!V86EH=&%A(&]I:V5U:W-I82!61E,M=&EE
M9&]S=&]L;&4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,Y,B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D5I('9O:2!V86EH=&%A(&]I
M:V5U:W-I82!61E,M=&EE9&]S=&]L;&4@)7,O)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B16D@=F]I9&$@=F%I:'1A
M82`E<SIN+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<UPB+B(*;7-G<W1R(")4:65D;W-T;VX@7"(E<UPB(&MO:V]A(&5I
M('9O:71U('1A<FMI<W1A82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HV.34@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@U,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S
M7"(N(@IM<V=S='(@(D5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I
M961O<W1O82!<(B5S+R5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BXB"FUS9W-T<B`B4U%,+7!A;'9E;&EM965N(&5I('-A861A('EH=&5Y
M='3D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B66AT97ET
M=.0@96D@=F]I9&$@;75O9&]S=&%A(%-33"US86QA='1U;F$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,R(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA
M8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(E9&4RUT:65D;W-T;V$@
M96D@=F]I9&$@:V]P:6]I9&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@;'5O
M9&$@5D93+6AA:V5M:7-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M16D@=F]I9&$@;'5O9&$@5D93+6AA:V5M:7-T;V$N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92XB"FUS9W-T<B`B16D@=F]I='4@;'5O9&$@5D93+71I961O
M<W1O82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(D5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93
M+6MA;G-I;W1A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N(@IM<V=S='(@(D5I('9O:71U(&QU;V1A('1Y:&KDY"!61E,M=&EE9&]S
M=&]A+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW
M-@IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B
M5&EE=&]A(&5I('9O:61A(&QA86IE;G1A82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(D5I('9O
M:61A('!O:7-T86$@7"(E<UPB+"!H86ME;6ES=&\@96D@;VQE('1Y:&KD+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB
M)7-<(CH@)7,N(@IM<V=S='(@(D5I('9O:61A('!O:7-T86$@7"(E<UPB.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S@@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0R(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(D5I('9O:61A
M('!O:7-T86$@)7,L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(D5I('9O:61A
M('!O:7-T86$@5D93+6AA:V5M:7-T;V$@<F5K=7)S:6EV:7-E<W1I+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,T-"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D5I('9O:61A
M('!O:7-T86$@5D93+6AA:V5M:7-T;V$N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!61E,M:&%K
M96UI<W1O83H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I('9O:61A('!O:7-T86$@5D93+71I
M961O<W1O82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3@W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(Y,0IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A
M82!61E,M=&EE9&]S=&]A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D5I('9O:61A('!O:7-T86$@
M5D93+6MA;G-I;W1A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(D5I('9O:61A('!O
M:7-T86$@5D93.N3D(')E:W5R<VEI=FES97-T:3H@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYY:WEI<W3D(&AA
M:V5M:7-T;V$@96D@=F]I='4@<V5L=FET=.3D+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(E9A<FUE;G1E96X@
M=&EE=&]J82!E:2!V;VED82!E>'1R86MT;VED82(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")-Y.1R:71Y:W-E
M;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L
M92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VED82!S:6ER=.3D
M(%9&4RUT:65D;W-T;V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HY."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,3`V(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-C4R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B16D@=F]I9&$@<&]I<W1A82!61E,M
M=&EE9&]S=&]A(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
M16D@=F]I9&$@879A=&$@5D93+71I961O<W1O82!K:7)J;VET=7-T82!V87)T
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#,@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4N(@IM<V=S='(@(D5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I
M9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R
M(")4:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O;FYI<W1U:2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R
M(")%:2!V;VET=2!L=6ME82!61E,M=&EE9&]S=&]A("AF:6QE<VEZ92@I(&5P
MY&]N;FES='5I*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#@W"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+B(*;7-G<W1R(")%:2!V;VED82!L=6ME82!61E,M=&EE9&]S=&]A
M("AG971&:6QE4VEZ92@I(&5PY&]N;FES='5I*2XB"@HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G
M:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")%:2!V;VET=2!L
M=6ME82!T:65D;W-T;V$Z("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8W-@IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER
M96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V
M;VET=2!L=6ME82XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q
M,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S
M='(@(B(*(E5U9&5L;&5E;FYI;67D;6EN96X@)7,@)7,Z:W-I(&5PY&]N;FES
M='5I(&MO<VMA(&MO:&1E:&%K96UI<W1O(&]N(&IO(&]L96UA<W-A(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")%:2!V;VED
M82!N:6UE=.0@=75D96QL965N(%9&4RUH86ME;6ES=&]A+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(D5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6AA:V5M:7-T;V$Z("5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0X(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V
M;VED82!N:6UE=.0@=75D96QL965N(%9&4RUT:65D;W-T;V$@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q-R!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D5I('9O
M:61A(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT-3(*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Y,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(V"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")%:2!V;VET=2!N
M:6UE=.0@=75D96QL965N(%9&4RUT:65D;W-T;V$N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B16D@=F]I9&$@
M<W5O<FET=&%A(&MO;65N=&]A("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")7;W)D
M+61O:W5M96YT=&EA(&5I('9O:71U(&ODY&YTY.0B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!V;VED82!K:7)J;VET=&%A(%9&
M4RUT:65D;W-T;V$@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B16D@=F]I9&$@:VER:F]I='1A82!6
M1E,M=&EE9&]S=&]O;B`H8V]P>2@I(&5PY&]N;FES='5I*2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,34Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB"FUS9W-T<B`B16D@=F]I9&$@:VER:F]I='1A82!61E,M=&EE9&]S=&]N
M('1I971O:F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,@IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R(")%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D
M;W-T;V$L(&MI:6YT:?8@;VX@=.1Y;F[D+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*
M;7-G<W1R(")!;&QE=FEI=F%T='4B"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B4&5R=2!M=75T
M;VMS970B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R
M(")097)U=71T86$@961E;&QI<V5N('1O:6UE;G!I=&5E;B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM
M<V=S='(@(E1U;G1E;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$@>6AT97ET
M965N.B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(Q.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PIM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(E1U;G1E;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$Z("(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DQU;VMI='1E;&5M871O;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M
M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<*;7-G
M:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(EEH9&ES='EN965T
M(&%R86)I96UI<F%A=&ET(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R(")9:&1I<W1Y;F5E="!K=6YI;F=A<VMU;FYA="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#`*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B
M66AD>7-V86QL870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y"FUS9VED(")5;FET960@4W1A
M=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B66AD>7-V86QT
M;VIE;B!4>7EN96YM97)E;B!E<FEL;&ES<V%A<F5T(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(*
M;7-G:60@(E5N:71S(@IM<V=S='(@(DUI='1A>6MS:6OV="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")4=6YT96UA
M=&]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(E1U;G1E;6%T;VX@87!I;7-G:60@*$%022!-97-S
M86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N
M="!-97-S86=E($E$*2XB"FUS9W-T<B`B5'5N=&5M871O;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N
M(@IM<V=S='(@(D%N;F5T='4@<&%I:VMA=&EE=&\@;VX@='5N=&5M871O;BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM
M<V=S='(@(E1U;G1E;6%T;VX@:^1Y='3D:N1T=6YN=7,@=&%I('-A;&%S86YA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M"FUS9W-T<B`B4&]I<W1A(&YY:WEI<V5N(&5L96UE;G1I;B!L:6YK:71Y<R(*
M"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(DYI;65T]FXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K
M($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H
M:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(E1I971O='5R=F%S>6ES
M=.0@96DM<')I=FEL965G:7-E="!S:W)I<'1I="!E:7;D="!V;VD@:W5T<W5A
M($QE:6MK86$O2V]P:6]I+R(*(DQI:73D('1O:6UI;G1O:F$N($YA<'-A=71A
M($]++6YA<'!U;&%A(&[D:&3D:W-E<VD@;6]Z:6QL82YO<F<@<VEV=6EL;&$@
M(@HB;VQE=F%N(&]H:F5E;BP@:F]S<V$@;F5U=F]T86%N(&UI=&5N('-K<FEP
M=&ES:2!V;VEV870@:^1Y='3DY"!L96EK97#V>73DY"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED
M(")5;G-E="!C;VQO<B(*;7-G<W1R(")0;VES=&$@=N1R:2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB
M"FUS9W-T<B`B16DM='5E='1U(&QA86IE;FYU<R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B4.1I=FETY"(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(E#D:79I=.0@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5
M<&1A=&4@=7-E<B(*;7-G<W1R(")0Y&EV:73D(&OD>71TY&KD(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(E#D:79I=&5T=&EI;B!<(B5S
M7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E#D:79I='ES<VMR:7!T
M:2!P;VES=&5T=&EI;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G
M:60@(E5P;&]A9"(*;7-G<W1R(")4=6\B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B='5O(&MA:6MK:2!O
M:&IE;&UI96X@87-E;FYU<W1I961O<W1O="!P86QV96QI;65L;&4N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("))<V]T
M(&QA=&EN86QA:7-E="!K:7)J86EM970B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E
M<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DES;W0@<F]O;6%L86ES970@;G5M
M97)O="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#$*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M57)U9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R(")+Y'ETY"!N>6MY:7-TY#H@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B
M57-E(%-33"(*;7-G<W1R(")+Y'ETY"!34TPM<V%L875S=&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M92]P87-S
M=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")+
MY'ETY"!J;W,@='5N;G5S+W-A;&%S86YA(&]N(&5R:2!)35-0+7!A;'9E;&EM
M96QL92XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q
M"FUS9VED(")5<V5R(@IM<V=S='(@(DOD>71TY&KD(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S
M='(@(DOD>71TY&KD;&SD("5S(&5I(&]L92!O:6ME=6MS:6$@=&5H9.0@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(DOD>71TY&II96X@>6QLY'!I=&\B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(DOD>71TY&KD;B!A<V5T=6MS970B"@HC.B!S:6=N=7`N
M<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")+Y'ET
M=.1JY&X@<F5K:7-T97+V:6UI;F5N(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92XB"FUS9W-T<B`B5.1S<^0@:N1R:F5S=&5L;>1S<^0@96D@=F]I
M(')E:VES=&5R]FEDY"!KY'ET=.1J:>0N(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G
M<W1R(")+Y'ET=.1JY'1U;FYU<W1A(&5I(&SV>71Y;GET+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DOD>71T
MY&KD='5N;G5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR
M96%D>2!E>&ES=',N(@IM<V=S='(@(DOD>71TY&KD='5N;G5S(%PB)7-<(B!O
M;B!J;R!O;&5M87-S82XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")+Y'ET=.1JY'1U;FYU
M<SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5
M<V5R;F%M93H@(@IM<V=S='(@(DOD>71TY&KD='5N;G5S.B`B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T
M:&4@<WES=&5M.B(*;7-G<W1R(")*Y')J97-T96QMY&X@:^1Y='3D:N1T.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#(*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB
M96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,"!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E
M8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4RUH86ME;6ES=&]A
M(&5I(&]L92!O;&5M87-S82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")0;VES<V%O;&]V:65S
M=&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-S`*;7-G:60@(E9A
M;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B4&%I:VMO
M:F$@;/9Y='EI(&5S:6UE<FMI:W-I.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B
M5F]I;6%S<V%O;&]A:6MA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"FUS9VED(")686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")!<G9O(&UI;G5U=&5I<W-A(&YY:WEH
M971K97-TY"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS
M9W-T<B`B07)V;R!O;B!Y;&D@<&ET=75D96X@;6%K<VEM:6%R=F]N("5S+CPB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,R,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$T"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E
M<R(*;7-G<W1R(")!<G9O="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y,`IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9A;&ET=&%V870@87)V;W0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0Y"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A
M='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED
M(")687)I86)L92(*;7-G<W1R(")686EH=&5L979A82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#4*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(E1A<FMI<W1U<R!E<.1O;FYI<W1U
M:2`M(%3D=.0@=FEE<W1IY"!O;B!V;VET=2!KY'-I=&5L;.0N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I
M;VXB"FUS9W-T<B`B5F5R<VEO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I
M;VYH86QL:6YT82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S
M='(@(E!Y<W1Y<W5O<F$@=&%S875S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN
M9R(*;7-G<W1R(")0>7-T>7-U;W)A('3D>71E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(E!Y<W1Y<W5O<F$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R
M(")%<FET=.1I;B!K;W)K96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6:65T
M($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE
M=&YA;2`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV.0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(D[D>73D("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I
M9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(").Y'ETY"!E
M<FEL;&ES96[D('=W=RUS:79U;F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A
M<R`E<R(*;7-G<W1R(").Y'ETY"`E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(DYE:71S>71S86%R
M970L($)R:71T:6SD:6YE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DYE:71S>71S86%R970L(%EH9'ES
M=F%L=&%I;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6
M:7-I8FEL:71Y(@IM<V=S='(@(D[D:WEVY&ES>7ES(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(D[D:WEVY&ES>7ES.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@
M271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@271A;'D@4TU44#IN
M(&%V=6QL82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T
M<B`B5D%23TE455,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B5D%23TE455,A(2$@4$])4U1!
M(%-+4DE05$D@2^1324X@4$%,5D5,24U%3%1!("5S+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA
M($A45%`B"FUS9W-T<B`B5TE.($A45%`Z;B!A=G5L;&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4P"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@
M:F$@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E9A<F]I='5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I
M9"`B5V4B"FUS9W-T<B`B:V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B4^3D
M96YN=7-T92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*
M;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")3Y.1T
M:65D;W0@;VX@=&]I;6ET=&%N=70B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N
M8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R(")75U<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y
M"FUS9VED(")796(@4VET92(*;7-G<W1R(")75U<M<VEV=7-T;R(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(E=E96ML>2(*;7-G<W1R(")6:6EK;VET=&%I;B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(E1E
M<G9E='5L;V$B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")497)V971U;&]A(&]H:F5L;6%A
M;B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L
M871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M96QC;VUE+"`E<R(*;7-G<W1R(")497)V971U;&]A+"`E<R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M*2(*;7-G<W1R("),Y&YS:6UA:6YE;B`H25-/+3@X-3DM,2DB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,34I(@IM<V=S='(@(DSD;G-I;6%I;F5N+T5U<F\@*$E33RTX.#4Y+3$U*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<X"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("),
MY&YS:2U386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(DUI;FOD(&]H:F5L;6%N
M("5S(&OD>6YN:7-TY.0@<VESY.1N:VER:F%U='5M:7-E;B!JY&QK965N+B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")-:73D(&UE
M<FMK:>0@:^1Y=&5TY.1N(&5R;W1T:6UE;F$_(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\B"FUS9W-T<B`B36ETY"!M97)K:VGD(&OD>71E=.3D;B!L86EN
M875K<V5E;C\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`V-`IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S
M='(@(E=H97)E:7,@075S=')A;&EA;B!K87)T=&$B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")-:71K
MY"!V86EH965T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I
M9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@
M961I=&]R+B(*;7-G<W1R(")6;VET(&WDY')I=&5L;.0@;&ESY'1O:6UI;G1O
M:F$@;&%I=&5T86%N('#DY&QL92!2:6-H(%1E>'0@961I=&]R:7-S82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("),979E>7,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$Q"FUS9VED(")7:61T:"!I;B!#4U,@=6YI
M=',B"FUS9W-T<B`B3&5V97ES($-34R!M:71T87EK<VEK:_9I;N0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"B)687-E;6UA;&QA(&]L
M979A;B`E<R!V86QI:V]N(&QE=F5Y<R`H='5L964@=F]I;6%A;B!S975R86%V
M86QL82`B"B)S:7/DY&YK:7)J875T=6UI<V5L;&$I.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T
M:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B5&%U;'5K;VX@;&5V97ES(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B3&5V97ED96X@>6MS:6MK]B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS
M9VED(")7:61T:#HB"FUS9W-T<B`B3&5V97ES.B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS
M9W-T<B`B5'5U;&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")4=75L:7-T
M82!A:6MA:7-I;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5'5U;&5N;F]P975S('-O
M;&UU:7-S82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7
M:6YD.B(*;7-G<W1R(")4=75L:3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5'5U;&DZ("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM
M<V=S='(@(E9I:7-A=7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R(")4;VEV96QI<W1A="(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R
M(")4>?8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")/<V]I=&4@*'1Y
M]BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E!U:&5L:6X@*'1Y]BDB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(")6Y.1RY"!MY.1RY"!K96YT=&GD(')I=FEL
M;.0@)60N($]D;W1E='1I:6X@)60L(&SV>71Y:2`E9"XB"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R(")6Y.1RY"!MY.1RY"!K96YT=&GD+B!/9&]T971T:6EN("5D
M+"!L]GET>6D@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,3(Q"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL
M92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E;DY'+D('!O:6MK96%M
M82`E9"!L=65T=&%E<W-A(%9&4RUT:65D;W-T;V$N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2
M968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM
M<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV
M,R!P97)U<W)A:F]I='1E970B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*;7-G<W1R(")8-3`Y=C,@;&ESY'1O:6UI;FYO="!A=F%I;65N(&OD>73V
M;&QE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T
M<B`B6#4P.78S($MO:'1E96X@=F%I:'1O96AT;VEN96X@;FEM:2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@2V]H
M=&5E;B!A=F%I;65N('1U;FYI<W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM
M<V=S='(@(E@U,#EV,RUL86%J96YN=6MS970B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B5E8B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB"FUS
M9W-T<B`B5E965B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O
M(2!K87)T=&$B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B5G5O<VET=&%I;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM
M<V=I9"`B665S(@IM<V=S='(@(DMY;&SD(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E
M92(*;7-G<W1R(")+>6QLY"P@<W5O<W1U;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN
M(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A
M8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB2^1Y=.1T(%1%2U-4251)3$%!
M+B!+Y'ETY"!;/#Y=(&YA<'!U;&%A('9A:6AT86%K<V5S:2!T86MA:7-I;B!7
M65-)5UE'+71I;&%A;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS
M+B(*;7-G<W1R(")%="!V;VD@=&5H9.0@96YE;7#DY"!K=6EN("5D(&]S:6]T
M82XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,34*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D5T(&]L92!A
M=71E;G1I:V]I='5N=70N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C
M:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(DYI;65S<^1S
M:2!E:2!S86$@;VQL82`G7%PG+6UE<FMK:>0N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Y
M"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N(@IM<V=S='(@(D5T(&%N=&%N=70@;VEK96%N(&UU;W1O:7-T82!SY&AK
M]G!O<W1I;W-O:71E='1A+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B)%="!MY.1R
M:71E;&QY="!M:71KY"!T=6]D=6X@=&EE9&]S=&]N(&ME;G3D="!V87-T86%V
M870@;6ETY&MI;B!K96YT=&GD("5S.B(*(G-SY"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D
M(&]U="XB"FUS9W-T<B`B3VQE="!K:7)J875T=6YU="!U;&]S+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)3:6YU;B!P:73DY"!A
M;G1A82!O:6ME82!M871K87!U:&5L:6YN=6UE<F\L('9A:6X@;G5M97)O:71A
M(&IA(&UA:&1O;&QI<V5S=&D@(@HB)RLG(&IO<R!KY'ETY'0@:V%N<V%I;G;D
M;&ES=.0@<'5H96QI;FYU;65R;VUU;W1O82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3DR"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+B(*;7-G<W1R(")3:6YU;B!TY'ET>7D@86YT86$@;VEK96$@
M87)V;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(E-I;G5N('!I=.3D(&%S96YT
M86$@1&%T851R964M=&%U<W1A:N1R:F5S=&5L;>0@96YN96X@:W5I;B!V;VET
M(&OD>71TY.0@(@HB4VEG;G5P+71O:6UI;G1O:F$N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-C(*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")3:6YU;B!P:73DY"!A<V5N=&%A
M(%9&4RUT875S=&%JY')J97-T96QMY"XB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE
M('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O
M<G0N(@IM<V=S='(@(B(*(E-I;G5N('1U;&5E(&MU=F%I;&QA(&]N9V5L;6%T
M:6QA;FYE='1A(&5N;F5N(&MU:6X@=F]I="!LY&AE='3DY"`B"B)O;F=E;&UA
M=FEE<W1I;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E
M('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B4VEN=6X@<&ETY.0@86YT
M86$@55),(&UI:&EN('3D;>0@;&EN:VMI(&]S;VET=&%A(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C
M="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B4VEN=6X@<&ET
MY.0@=F%L:71A('!O:7-T971T879A('!A;'9E;&EN+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`B4VEN=6X@<&ETY.0@86YT86$@<&]I
M<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M
M;W9E+B(*;7-G<W1R(")3:6YU;B!P:73DY"!A;G1A82!P;VES=&5T=&%V82!K
MY'ET=.1JY'1U;FYU<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B4VEN=6X@<&ET
MY.0@86YT86$@;&ESY'1TY';D(&OD>71TY&KD='5N;G5S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")3:6YU;B!P:73DY"!A;G1A82!P
MY&EV:71E='3D=N0@:^1Y='3D:N1T=6YN=7,N(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(E-I;G5N
M('!I=.3D('9A;&ET82!S=6]R:71E='1A=F$@=&]I;6EN=&\N(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G
M:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T
M<B`B4VEN=6X@<&ETY.0@86YT86$@=75D96X@:V%T96=O<FEA;B!N:6UI+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R(@IM<V=S='(@(E-I;G5N('!I=.3D(&%N=&%A(&ET86QI
M86QA:6YE;B!P=6AE;&EN;G5M97)O(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("))
M<W1U;G1O<VD@)7,@;VX@=F%N:&5N='5N=70N($MI<FIA=61U('5U9&5L;&5E
M;B!S:7/DY&XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S@*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")3Y&AK]G!O
M<W1I;W-O:71T965S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*
M;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B4VEN=6X@;.1H
M971TY&KD;W-O:71T965S:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`B3VUA="!T:65T;W-I(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HB4VEN=6X@=&EE=&]K;VYE97-I(&OD>71TY&WD('1I971O=F5R:VMO
M+6]S;VET92!O;B!M=75T='5N=70@<V5N(&KD;&ME96X@:W5N("(*(F]L970@
M86QO:71T86YU="`E<R!I<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S:6YU
M;B!P:73DY"!K:7)J875T=6$@(@HB=75D97-T86%N(&KD<FIE<W1E;&WDY&XN
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R(").:6UE<VDB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB2^1Y='3D;>1S:2!A=71H
M96YT:6-A=&EO;B!T875S=&%JY')J97-T96QMY"!E:2!T=64@:^1Y='3D:FEE
M;B!L:7/DY&UI<W3D+B`B"B)*;W,@:&%L=6%T(&AA;&QI;FYO:61A(&OD>71T
MY&KD='5N;G5K<VEA+"!S:6YU;B!P:73DY"!KY'ET=.3D(&IO=&%K:6X@=&]I
M<W1A("(*(F%U=&AE;G1I8V%T:6]N('1A=7-T86KD<FIE<W1E;&WDY"XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB2^1Y
M='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T96QMY"!E:2!T
M=64@:^1Y='3D:N1T:65T;VIE;B`B"B)NY'ET=.1M:7-TY"!T86D@=.1MY"!P
M:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET971TY'9I<W/D+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*
M(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(E-I;G5N(&OD>71TY&WD<VD@=W=W+7-E;&%I;B!N
MY'ET=.3D(&]L979A;B!M=75T='5N=70@<V5N(&KD;&ME96X@:W5N(&]L970@
M(@HB86QO:71T86YU="`E<R!I<W1U;FYO;BX@5&EE=&]T=7)V87-Y:7-TY"!S
M:6YU;B!P:73DY"!K:7)J875T=6$@(@HB=75D97-T86%N:N1R:F5S=&5L;>3D
M;BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-PIM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M(")396QA:6UE<VD@96D@='5E('3D=.0@=&]I;6EN=&]A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B
M(@HB4V5L86EM97-I(&5I('1U92!T87)V:71T879A82!T=6QO<W1U<W1O:6UI
M;G1O82X@4&%I;F$@0V]N=')O;"]/<'1I;VX@*R!0("(*(G1U;&]S=&%A:W-E
M<VDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V,0IM<V=I9"`B66]U
M<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B06EK879Y]FAY:VME97-I
M.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,3<*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R(")/;&5T
M=7-P<F]F:6EL:7-I(&]N(&UU=71E='1U+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS
M9W-T<B`B3VQE='5S<')O9FEI;&ES:3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B3FEM
M97-I.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B27-T=6YT;W-I(&]N
M('9A;FAE;G1U;G5T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,B"FUS9W-T<B`B4VEN=6X@<V%L87-A;F%S:2`E<SIL;&4@
M;VXZ("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B07-E='5K<V5S
M:2!O;B!PY&EV:71E='1Y(&IA(&YE(&]V870@=F]I;6%S<V$@=.1MY&X@:7-T
M=6YN;VX@86IA;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*
M;7-G<W1R(")!<V5T=6MS97-I(&]N('#D:79I=&5T='DN(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970B"FUS9W-T<B`B4V%L87-A;F%S:2!O;B!N;VQL871T
M=2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B
M"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M
M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS
M9W-T<B`B(@HB4V%L87-A;F%S:2!O;B!N;VQL871T=2P@=&%R:VES=&$@<^1H
M:_9P;W-T:7-I(&IA(&MI<FIA=61U('-I<^3D;B!U=61E;&QA("(*(G-A;&%S
M86YA;&QA<VDN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")386QA
M<V%N87-I(&]N('9A;FAE;G1U;G5T+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS
M9W-T<B`B173D<&%L=F5L:6UE<VDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-`IM
M<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6=O<VQA=FEA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS
M9W-T<B`B6F%I<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B4V%M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-PIM<V=I9"`B6FEM8F%B=V4B
M"FUS9W-T<B`B6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I
M9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM0:6EL;W1A(&QA:6YA
M='1U('1E:W-T:5TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I
M9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");3VYG96QM85TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R(");3N1Y=.0@;&%I;F%T='4@
M=&5K<W1I("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM.Y'ETY"!L
M86EN871T=2!T96MS=&D@+2`E<R!R:79IY%TB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E
M<R!O9B`E<UTB"FUS9W-T<B`B6W)I=FEL;.0@)7,O)7-=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30W('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?66QL
MY'!I=&\B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7TMO;65N=&]T=6QK:VDB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@
M(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@
M(E]$96QE=&4@4F]W(@IM<V=S='(@(E]0;VES=&$@<FEV:2(*"B,Z(&QI8B]A
M<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?4GEH;>1T(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B
M7TAE;'`B"FUS9W-T<B`B7T]H:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(E]+=79A;B!T:65D;W0N+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G
M(&EN(@IM<V=S='(@(E]+:7)J875D=2!S:7/DY&XB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G
M<W1R(")?2VER:F%U9'4@=6QO<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(E]-=6]K:V%A(&QI;FMK:>0B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R(")?07-E='5K<V5T(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED
M(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7T]I:V5U9&5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS
M9VED(")?4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B4&]I<W1A(&QI;FMK:2XN
M+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(E]!<V5N;G5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")?5&%U;'5K;VX@=&EE9&]T+BXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7TOD>71TY&KD="(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B;W-O:71E:VER:F$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B=F%S=&%A;F]T=&%J82!T=6YT96UA=&]N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N9&%R(@IM
M<V=S='(@(FMA;&5N=&5R:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@
M(F-A;&TB"FUS9W-T<B`B='EY;G3D(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T
M(&9I;&4B"FUS9W-T<B`B96D@=F]I(&QU;V1A('1U;&]S=&EE9&]S=&]A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@
M(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(F5I('9O:2!A=6MA:7-T82!L
MY&AD971TY"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C4Y.`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")N87!S875T82!TY'-T
MY"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS
M9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B=FER:&4@
M:V]M96YT;W)I=FEL;.0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M(")A<V5T=7-V:7)H92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG
M(@IM<V=S='(@(FMR:6ET=&EN96X@:N1R:F5S=&5L;>1T:65D;W-T;R!P=75T
M='5U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*
M;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(FUU;W1O=FER:&4@
M=&EE9&]I<W-A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM
M<V=I9"`B961I="(*;7-G<W1R(")M=6]K:V%A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N
M9"(*;7-G<W1R(")T:65T=65T=&$@96D@;/9Y='EN>70B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN
M9R(*;7-G<W1R(")L87-K979A(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S='(@(G1I961O<W1O(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")S=75N
M;F%S=&$@)7,@*"5S*2!N;W!E=61E;&QA("5S("5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R
M(")P=75S:VET=&%I;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B
M:&@B"FUS9W-T<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B
M='5N=&5M871O;B!P86QV96QI;65N(&YI;6DB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(FEM
M;65D:6%T92(*;7-G<W1R(")VY&QI='3V;>1S=&DB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M:6YL:6YE(@IM<V=S='(@(FEN;&EN92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B
M"FUS9W-T<B`B:6\M=FER:&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B
M"FUS9W-T<B`B;VAJ96QM:7-T;VX@<VESY&EN96X@=FER:&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN
M97-=(@IM<V=S='(@(G)I=FET72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B;6MI<V]F<R!V:7)H96MO;V1I("5D($E33SIA('1E:&1E<W/D
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED
M(")N86UE(@IM<V=S='(@(FYI;6DB"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B96D@;VQE
M('1O=&5U=&5T='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B
M96D@;VQE('9I96SD('1O=&5U=&5T='4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")M=6ES=&EL
M:7-T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<')O<V5N='1I
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(FOD>71T]B!K:65L;&5T
M='DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B<&EK<V5L96ETY"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED
M(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B973D=FER:&4@
M<')O=&]K;VQL87-S82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B;F]U<V5V82(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED
M(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G!A;'9E;'4@96D@;VQE
M(&OD>71E='3D=FES<^0B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P
M,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")NY'ETY"!E<F]T
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R
M96UA:6P@2%144#IN(&%V=6QL82(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G
M:60@(G-T96%D>2(*;7-G<W1R(")V86MA82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS
M9W-T<B`B:N1R:F5S=&5L;>1V:7)H92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B=&5H=.1V
MY&QI<W1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(G;D;&EA:6MA
M:6YE;B!V:7)H92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B=F%R;6ES=&%A:W-E<VD@
M:VER:F]I=&$@<V%L87-A;F$@:V%H9&5S=&DB"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI
M9FEE9"(*;7-G<W1R(")U;FEF:65D(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")N:6UE=/9N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")KY'ET=.1J
MY&X@=F%L:6YT82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED
M(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O
M;2(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&\O971?144N<&\`````````````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P-S(P,C`Q(#$P-3$U-#,T,30R(#`Q-S0W
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````C
M($A/4D1%($535$].24%.(%1204Y33$%424].(`HC"B,@5&]O;6%S($%A<R`\
M=&]O;6%S+F%A<T!M86EL+F5E/BP@,C`P,B`M(#(P,#8@"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2UC=G-<
M;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G
M7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P
M7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`S+3,P(#$V.C$Q*S`S,#!<
M;B(*(DQA<W0M5')A;G-L871O<CH@5&]O;6%S($%A<R`\=&]O;6%S+F%A<T!M
M86EL+F5E/EQN(@HB3&%N9W5A9V4M5&5A;3H@17-T;VYI86X@/&1E=D!L:7-T
M<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$S7&XB"B)#
M;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@<.1E=F$@=&%G87-I*2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A+:6ER:VQA:'8@
M)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@<.1E
M=F$@<.1R87-T*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*
M;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H=.1N82DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G
M<W1R("(@*&AO;6UE*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&5I;&4I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(&MI:7)U<V5G82`B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<
M(B5S7"(@96D@;VQE(&MA=&%L;V]G+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A
M('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&5I(&]L92!V]6EM86QI
M:R!V86QI:RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$P-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF
M:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB
M(&5I(&]L92!(;W)D92!R96=I<W1R:7,@:.3D;&5S=&%T=60N(@H*(SH@9G)A
M;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E
M<UPB('!U=2!E<VET86IA="!E:2!L96ET=60N(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@;&ES871I
M(&=R=7!P:61E('/\<W1E96UI+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D
M('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!L
M:7-A=&D@]6EG=7-T92!S_'-T965M:2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M7"(E<UPB(&5I(&QO;V1U9#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!K87-U=&%T
M=60@:V]K:W4@)2XR9DU"+7-T("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E
M<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@:F$@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R(")3:6YU('!A<F]O;"!A96=U8B`E
M9"!PY&5V82!PY')A<W0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B
M"FUS9W-T<B`B)60@<.1E=F$@96YN=7-T=7,B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I
M8V4B"FUS9W-T<B`B)7,@+2!4Y&AE;&5P86YU(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@<_5R;65JY&QG(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(&AO;VQD
M=7-T]O9D("T@:VEN;FET=7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@<&%I9V%L9'5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(&MO;G1O('1A;W1L96UI
M;F4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S
M(&MA<W5T=7-T:6YG:6UU<V5D(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B5S(&]N(&IU8F$@;VQE;6%S+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&MI:7)U<V5G82`E<R`E<R(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&]N('9A;&UI<R!T96=E;6$@
M86QL<&]O;"!L;V5T;&5T=60@:&]O;&1U<W3V]F0N($WD<F=I<W1A('3V]F0L
M(&UI9&$@(@HB<V]O=FED('!R865G=2!T96AA+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@
M<F5Q=6ER960B"FUS9W-T<B`B)7,@;VX@:V]H=7-T=7-L:6LB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M
M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T:70B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@96D@;&5I='5D+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@:W5N:2`E<R`E
M<RUS="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(DMA
M<W5T86IA("5S(&%A9')E<W-I<F%A;6%T(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE
M;F1A<B(*;7-G<W1R(")+87-U=&%J82`E<R!K86QE;F1E<B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@3F]T97!A9"(*;7-G<W1R(")+87-U=&%J82`E<R!MY')K;65D(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R(")+87-U=&%J82`E<R#\
M;&5S86YD960B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I
M="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@4V5E('1E
M861E(&5I('!R=75G:2!O;&QA('-A871J86QT+"!K96QL96QT('-E92!P86ES
M=&%B(&]L979A="X@Q')A("(*(FMI:7)U<W1A(&ML]7!S86UA('-E;&QE<R!E
M<VEN979A:60@;&EN:V4@=O5I(&5S:71A;6$@<V%A=&IA;&4@(@HB;6EN9VET
M:7-I:VQI:VMU(&EN9F]T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`IM<V=I
M9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L('1U=6QE:6EL:60@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@
M(BP@='5U;&5I:6QI9"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(L('9A:&5M:6MU<R`E<R!K=6YI("5S(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E
M;&5C="`M+2(*;7-G<W1R("(M+2!V86QI("TM(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q,BUT
M=6YN:6YE(&5S:71U<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I
M9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M='5N;FEN92!E<VET=7,B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U
M<G,B"FUS9W-T<B`B,C0@='5N9&DB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B/$5E;&UI;F4B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S
M92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R
M(")3964@8FQO:VL@=F%J86(@86YD;65B86%S:2!T=6=E+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R
M(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")*=6AT=7,@:V]H=71A=B!V:6=A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(")+:7)J82!K<OQP=&5E<FEM:7-E:W,@;VX@=F%J82!A
M=F%L:6MK=2!01U`@=O5T:70N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U
M:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B06QL
M:VER:F$@:V]N=')O;&QI;6ES96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U
M=&ET+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B)+<OQP=&5E<FET=60@:VER:F$@879A;6ES
M96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U=&ET+"!S86QA:F%S="!01U`@
M=O5T:70@(@HB:F$@<V%L87/U;F$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(DMI<FIA(&%L;&MI
M<FIA<W1A;6ES96MS(&]N('9A:F$@879A;&EK:W4@4$=0(';U=&ET+"!S86QA
M:F%S="!01U`@=O5T:70@:F$@(@HB<V%L87/U;F$N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"B)+<OQP=&5E<FET=60@:VER:F$@879A;6ES96MS(&]N('9A:F$@
M879A;&EK:W4@4R]-24U%(';U=&ET+"!S86QA:F%S="!3+TU)344@(@HB=O5T
M:70@:F$@<V%L87/U;F$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)+:7)J82!A;&QK
M:7)J87-T86UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%,O34E-12!V]71I="P@
M<V%L86IA<W0@4R]-24U%(';U=&ET("(*(FIA('-A;&%S]6YA+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U
M8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(DMI<FIA(&MR_'!T965R:6UI<V5K<R!O;B!V86IA(&%V
M86QI:VMU(%,O34E-12!V]71I="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")%
M3"!P:6QV:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B14P@:V5R
M9V4@=FEH;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(D5,('9I:&TB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B
M04T@4VAO=V5R<R(*;7-G<W1R(")%3"!H;V]V:6AM(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R(")%3"!T=6=E=B!L=6UE<V%D=2(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")%
M3"]03"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G
M:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(E-E;&QE(&5D:71O<FD@
M:6YF;R(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!
M8F]U="XN+B(*;7-G<W1R("));F9O+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM
M<V=S='(@(D%B<V)O='1O;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")!
M8G-M:61D;&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(E9&4R!K871A;&]O9VD@;&]O;6ES96MS(&IU=7)D97#DY',@
M:V5E;&%T=60B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G
M<W1R(")61E,@9F%I;&D@;&]O;6ES96MS(&IU=7)D97#DY',@:V5E;&%T=60N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B2V]N=&\@:6YF;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G
M<W1R(")+;VYT;R!S86QA<_5N82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z
M96XN(@IM<V=S='(@(DMO;G1O(&QU:W5S=&%T=60N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M(")286%M871U<&ED86UI;F4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D
M9"(*;7-G<W1R("),:7-A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M
M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R("),:7-A(&%L86UG<G5P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM
M<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B3&ES82!A;&%M
M]6EG=7,B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B
M061D($AE<F4Z(@IM<V=S='(@(DQI<V$@<VEI83HB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE
M=R!'<F]U<"(*;7-G<W1R("),:7-A('5U<R!G<G5P<"(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(DQI<V$@=75S(/5I9W5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B3&ES82!G<G5P<"!<(B5S7"(@
M86QL82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@
M7"(E<UPB(@IM<V=S='(@(DQI<V$@]6EG=7,@7"(E<UPB(&%L;&$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S
M='(@(DQI<V$@=75S(&MA<W5T86IA.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B3&ES82!V965R9R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),
M:7-A('5U960@;&EI:VUE9"(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(DQI<V$@<&%A<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(E1E92`E<R!M96[\_"!-;WII;&QA(&O\;&=R:6)A:W,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(DQI<V$@86%D<F5S<VER86%M
M871U<W-E.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("),:7-A(&UI;G4@86%D<F5S<VER86%M871U<W-E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(DQI<V$@:V%S=71A
M:F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO
M="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*
M;7-G<W1R("(B"B)<(B5S7"(@;&ES871I('/\<W1E96UI+"!K=6ED('3D:65N
M9&%V870@;&EI='5M:7-I;F9O="!P;VQN=60@=O5I;6%L:6L@(@HB;&ES861A
M.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N
M;W<N(@IM<V=S='(@(EPB)7-<(B!L:7-A=&D@<_QS=&5E;6DN($[\_&0@=O5I
M9"!S:7-S92!L;V=I9&$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B2V%S=71A:F%T92!L:7-A;6EN92!P;VQE(&QU8F%T=60N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B06%D<F5S<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*
M;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!861R97-S:7)A86UA="(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS
M9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U
M<V5R<R(*;7-G<W1R(")(86QD=7,@+2!M=75D82!T96ES=&4@:V%S=71A:F%T
M92#U:6=U<VDB"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B2&%L9'5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,0IM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA86TB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A86YI82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QZ965R:6$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM
M<V=S='(@(DIO;VYD=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(DIO
M;VYD=7,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!
M;&PB"FUS9W-T<B`B2_5I:R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@
M(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(DOU:6L@<VES<V5L
M;V=I='5D(&MA<W5T86IA9"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M
M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B
M2_5I:R!G<G5P:60B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G
M:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")+]6EK(/5I9W5S960B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")+]6EK(&YE;&D@
M:_QL9V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED
M(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B3'5B82!M:71U
M="!A861R97-S:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(DQU8F$@;>3D<F%T82!JY')J97-T871U9"!L;V5N9&D@=/S\<"(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I
M9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B3VX@:G5B82!O;&5M87,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@
M24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA=&EI=FYE($E-4U`@:V]N=&\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA
M=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA=&EI=FYE($E-4U`@
M<V%L87/U;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED
M(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EI
M=FYE($E-4U`@:V%S=71A:F%N:6UI(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM
M<V=S='(@(D%L=&5R;F%T:6EV;F4@92UP;W-T:2!A861R97-S(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T
M97,B"FUS9W-T<B`B06QT97)N871I:79S960@;6%L;&ED(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U
M"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N871I:79N
M92!T96MS=#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*
M;7-G<W1R(")!;65E<FEK82!386UO82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS
M9W-T<B`B4VES97-T871I(&QU8F%M871U(';DY')T=7,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PIM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B2G5H='5S('1U;F1M871U('9I
M9V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R
M<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;V]L
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I
M;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;V[\_&UN92!V86AE;F1A
M:F$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B
M06YS=V5R(@IM<V=S='(@(E9A<W1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M=&%R8W1I8V$B"FUS9W-T<B`B06YT87)K=&EK82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G
M:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!J82!"
M87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU
M."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!
M<'!L:6-A=&EO;B(*;7-G<W1R(")286ME;F1U<R(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R
M(")286ME;F1U<W1E(&YI;65K:7)I(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(E)A:V5N9'5S(&]N('3V]G9A;&UI<RXB"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(E)A:V5N9&$@86QA;6IA9W5D96QE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T
M<B`B2VEN;FET82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("),:6=I
M:V%U9&YE('-U=7)U<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;&PB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD
M;W=S+3$R-38I(@IM<V=S='(@(D%R86%B:6$@*%=I;F1O=W,M,3(U-BDB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B07)H:6EV:2!S=75R=7,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S
M='(@(D%R:&EI=FD@;FEM:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(#\B"FUS9W-T<B`B3VQE9"!S82!K:6YD96P@970@<V]O=FED("5S
M(&QI:71U;6ES<V]O=FD@:W5S='5T861A/R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@
M<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@HB3VQE9"!S82!K:6YD96P@970@<V]O
M=FED(&MU<W1U=&%D82!G<G5P:2!<(B5S7"(@:F$@:_5I:R!T96UA(&%L86UG
M<G5P:60_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@
M(D%R9V5N=&EI;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S
M='(@(D%R;65E;FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G
M:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R;65E;FEA("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B2W5N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B
M82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B3&EH87;U
M='1E<V%A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B
M07-C:6D@07)T(@IM<V=S='(@(D%30TE)(&IO;VYI<W1U<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R(")!87-I82]686EK<V4@;V]K96%N:2!P:6ER:V]N
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/R(*;7-G<W1R(")+_'-I(&AO;VQD=7-T]O9D92!T96=E;6ES96MS
M(&MI;FYI='5S="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*
M;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")6965R=60B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B2V%T<V4@:W5S='5T
M861A(&]L96UA='5T(&=R=7!P:2XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R(")+871S92!K=7-T=71A9&$@;VQE;6%T
M=70@]6EG=7-T+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B2V%T<V4@;75U=&$@;VQE;6%T=70@]6EG=7-T+B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")+871S92!M=75T
M82!O;&5M871U="!J86=U+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB=75D:60B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I
M9"`B075G=7-T(@IM<V=S='(@(D%U9W5S="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<F%A;&EA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')I82(*;7-G<W1R(")!=7-T<FEA(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)S<6PZ('9A:F%L:6MK=2!)34%0(&QA:65N9'5S="!E:2!L96ET
M=60N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z('/\<W1E96UI
M;"!P=75D=79A9"!V86IA;&EK=60@=O5I;65D+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7V-Y<G5S.B!V86IA;&EK:W4@24U!4"!L86EE;F1U<W0@96D@;&5I='5D+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*
M;7-G<W1R("(B"B)!=71H7V9T<#H@5F%J86QI:VMU($944"!L86EE;F1U<W0@
M96D@;&5I='5D+B!+;VUP:6QE97)I(%!(4"!V]71M96=A("TM96YA8FQE+2(*
M(F9T<"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS
M9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!686IA;&EK:W4@24U!4"!L86EE
M;F1U<W0@96D@;&5I='5D+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z(%9A:F%L:6MK
M=2!K<F(U(&QA:65N9'5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y)W-S92!K87-U
M=&%J871E(&QI<V%M:7-E('1U9VD@<'5U9'5B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I
M;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R
M>2(*;7-G<W1R(")!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GES="!K87-U
M=&%J871E(&5E;6%L9&%M:7-E('1U9VD@<'5U9'5B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M;&1A<#H@5F%J86QI:VMU($Q$05`@;&%I96YD=7-T(&5I(&QE:71U9"XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?
M;&1A<#H@16D@<V%A(&QI<V%D82!K87-U=&%J870@)7,N(%-E<G9E<B#\=&QE
M<SH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!%:2!S86$@965M86QD861A
M(&MA<W5T86IA="`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@16D@<V%A
M(&UU=71A(&MA<W5T86IA="`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S
M='(@(D%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2!K87-U=&%J871E(&UU
M=71M:7-E('1U9VD@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(%9A:F%L
M:6MK=2!-0T%,(&QA:65N9'5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E
M<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]S;6)A=71H.B!686IA;&EK:W4@<VUB875T:"!L86EE;F1U<W0@96D@
M;&5I='5D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(E-I<W-E;&]G:6UI;F4@;G5R:G5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R
M(")3:7-S96QO9VEM:6YE(&YU<FIU<RX@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")2041)55,@<V5R
M=F5R(&5I(&QU8F%N=60@<VES<V4@;&]G:61A+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B1E10('-E<G9E<FES<V4@<VES
M<V5L;V=I;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R(")334(@<V5R=F5R:7-S92!S:7-S96QO9VEM
M:6YE(&YU<FIU<RXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U
M"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")+87-U=&%T879A
M9"!VY&QJ860Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G
M<W1R(")!<V5R8F%I9'IA86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")"3T9((&5T=&5KY.1N
M9&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")4875S="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*
M;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B5&%U<W1A(';D<G8B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"
M860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(E9A;&4@:V5R8F5R;W-E
M('-A;&%S]6YA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B5F%L
M92!K97)B97)O<V4@:V%S=71A:F%N:6UI+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B
M0F%H<F%I;B(*;7-G<W1R(")"86AR96EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@
M(D)A;'1I("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG
M;&%D97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H
M:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")'<F%A
M9FEK82!P]6AI:V%T86QO;V=I(%PB)7-<(B!E:2!L96ET=60N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS
M9VED(")"87-E;&EN92(*;7-G<W1R(")"87-E;&EN92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B5F%L9V5V96YE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")":'5T86XB"FUS9W-T<B`B0FAU=&%N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS
M9W-T<B`B4_QN;FEPY&5V(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<
M(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B0FQO:VMI(%PB)7-<(B!R86ME;F1U<V5S(%PB)7-<(B!E:2!L96ET=60N
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]K:2!HY.1L97-T=7,B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y
M<&4B"FUS9W-T<B`B0FQO:VD@=/S\<"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")0
M86MS(&MI<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@
M(D)O;&EI=FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM
M<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(DKD<FIE:&]I9&IA9"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*
M;7-G:60@(D)O<F1E<B(*;7-G<W1R(")0:6ER:F]O;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E
M<B!T:&EC:VYE<W,Z(@IM<V=S='(@(DIO;VYE('!A:W-U<SHB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS
M9VED(")";W)D97)S(@IM<V=S='(@(E!I:7)J;V]N960B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYI
M82!J82!(97)T<V5G;W9I:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDV"FUS9VED(")";W1H(@IM<V=S='(@(DWU;&5M860B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=V%N82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I
M9"`B0F]T=&]M(@IM<V=S='(@(D%L;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M;W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!S86%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I:6QI82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS
M9W-T<B`B0G)I=&D@26YD:6$@3V]K96%N:2!497)R:71O;W)I=6TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N
M96D@4W5L=&%N:7)I:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*
M;7-G<W1R(")"=6QG86%R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S
M='(@(DQO971E;'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B
M"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(E-I<W5H86QD=7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED
M(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(E3\:&ES='5S;FEM96MI<FIA(&IA;W1U<W!U;FMT:60B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B3%]A
M:'1R:2!O;6%D=7-E9"XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N
M(@IM<V=S='(@(E9A:&5MY&QU(&EN:71S:6%L:7-E97)I;6EN92!E:2!J]75D
M;G5D(&SU<'5L92XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS
M9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(E9A:6MN92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V1Z:&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<G5N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!A<F]O;&D@96D@<V%A(&%U=&]M
M86%T<V5L="!T_&AI<W1A9&$L(';U=&$@_&AE;F1U<W0@861M:6YI<W1R86%T
M;W)I9V$N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S
M7"(B"FUS9W-T<B`B16D@]6YN97-T=2!K:7)J=71A9&$@9F%I;&D@7"(E<UPB
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI
M;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(E;D
M;&ES96ED('-E<W-I;V]N:6AA;&1U<F5I9"!P;VQE(';U:6UA;&EK(&%D;6EN
M:7-T<F5E<FED82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R
M.B`E<R(*;7-G<W1R(")%:2!S86$@_&AE;F1U<W0@24U!4"!S97)V97)I9V$Z
M("5S(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(D5I(/5N;F5S='4@879A9&$@9F%I;&D@7"(E<UPB(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(DQO;V)U(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("),;V]B=2(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D
M96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(D5I(/5N;F5S='4@:W5S='5T
M861A(&9A:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")%:2!L96EA(&%J=71I<W0@:V%T
M86QO;V=I(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("));&UA("=T87)G971&:6QE)R!P
M87)A;65E=')I=&$@96D@<V%A(&KD=&MA=&$N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")%:2#U;FYE<W1U
M(&5E;6%L9&%D82!K871A;&]O9VD@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B16D@<V%A
M(&5E;6%L9&%D82P@)60M;"!O;B!A;&QU=F%I9"XB"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R
M("(B"B)%:2!S86$@_&UB97(@:N1R:F5S=&%D82P@_&UB97)JY')J97-T86UI
M<V5K<R!MY.1R871U9"!K86YN971E(&%R=B!E:2!K;&%P:2`B"B)S86QV97-T
M871U9"!A<G9U9V$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(")%:2!S86$@<W5U;F%T
M82!T96%D970@;>3D<F%T=60@;G5M8G)I;&4N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R(")2;VAE;&ES92!.965M92!S86%R960B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E!E86QK:7)I(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS
M9VED(")#87)R:65R(@IM<V=S='(@(E1E96YU<V5P86MK=6IA(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`B2V%T96=O;W)I860@:F$@;>1R9V5N9&ED(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(D-A>6UA
M;FD@4V%A<F5D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I:6QT
M96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(DQA:'1R:2!O;6%D=7-E9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S
M='(@(DQA:'1R:2!V;V]D97)D=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P
M97)T:65S(@IM<V=S='(@(DQA:'1R:2!O;6%D=7-E9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL
M('-P86-I;F<Z(@IM<V=S='(@(DQA:'1R:71E('9A:&5K875G=7,Z(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE
M(@IM<V=S='(@(DUO8FEI;'1E;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B
M2V5L=&D@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G
M<W1R(")+97-K96QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC(@IM<V=S='(@(DME<VLM06%F<FEK82!686)A<FEI:R(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U
M<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")+97-K+45U<F]O<&$@*$E3
M3RTX.#4Y+3(I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B4V5R
M=&EF:6MA861I(/QK<VEK87-J860B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS
M9W-T<B`B4V5R=&EF:6MA861I(&]M86YI:R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI
M8VEE<R(*;7-G<W1R(")397)T:69I:V%A9&D@<&]L:6ET:6MA9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")4<VAA860B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B375U9&$B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(DUU=61A('-A;&%S]6YA(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB
M375U9&$@;FEM92!J82!A861R97-S:2!M:61A(&EN:6UE<V5D(&[D979A9"!K
M=6D@;F%D('-I;G4@:VER:G4@;&]E=F%D(&IA("(*(FYE:6QE('9A<W1A=F%D
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B
M(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I
M=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)3_'-T965M:2!K;VYF:6=U
M<F%T<VEO;VX@96D@=O5I;6%L9&$@<V%L87/U;F$@;75U=&$N(%;U=&$@_&AE
M;F1U<W0@("(*(F%D;6EN:7-T<F%A=&]R:6=A+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H
M87(B"FUS9W-T<B`B3>1R:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN
M+BXB"FUS9W-T<B`B7TMO;G1R;VQL:2!L:6YK:2XN+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(E1S:&EI;&DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#:&EN82(*;7-G<W1R(")(:6EN82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB
M"FUS9W-T<B`B2&EI;F$@;&EH='-U<W1A='5D("A'0C(S,3(I(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I(@IM<V=S='(@(DAI:6YA('1R861I='-I;V]N:6QI;F4@*$)I
M9S4I(@H*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B5F%L
M:2!R86ME;F1U<SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")686QI
M('-A;&%S]6YA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B5F%L:2!K
M87-U=&%J86YI;6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS
M9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E9A
M;&D@:W5U<.1E=F%D92!E<VET=7-V:6ES.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G
M<W1R(")686QI(&QO96YD:2!S=&EI;"`H:N1R:F5S=&%T=60@;&]E;F1I=&4@
M:F%O:W,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*
M;7-G<W1R(")*]75L=7-A87)E9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(DML87-S:2`E<R!K:7)J96QD=7-T(&5I(&QE:71U9"XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I
M9"`B0VQE87(B"FUS9W-T<B`B4V5L9V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC
M92!T86=S(@IM<V=S='(@(D5E;6%L9&$@35-/9F9I8V4@;>1R9V5N9&ED(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`B5/QH:F5N9&$@<.1R:6YG(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(D5E;6%L9&$@:V%S=71A:F$Z("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#
M;&5A<B!U<V5R(@IM<V=S='(@(D5E;6%L9&$@:V%S=71A:F$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E
M<B!D871A(@IM<V=S='(@(E3\:&IE;F1A(&MA<W5T86IA(&%N9&UE9"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED
M(")#;&5A<FEN9R!,871E(@IM<V=S='(@(M5H='5L('-E;&=I;F5B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G
M:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(DML]7!S82!JY'1K86UI
M<V5K<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R
M(")#;&EC:V%T96QL(/QL92!(5%10(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#
M;&]S92!7:6YD;W<B"FUS9W-T<B`B4W5L92!A:V5N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")0:6QV960B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DAO;6UI:W5L('!I;'9E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS
M9VED(")#;&]U9'DB"FUS9W-T<B`B4&EL=F5S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B2V]O:V]S<V%A
M<F5D("A+965L:6YG:2!S86%R960I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R
M(")096ED82!K_&QG<FEB82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D
M97)S(@IM<V=S='(@(E!E:61E='5D('!I:7)J;V]N960B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQU;6)I82(*"B,Z(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y
M"FUS9VED(")#;VQO<B(*;7-G<W1R(")6Y')V(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O
M;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@
M(E;D<G9I=F%L:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V
M"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E;D<G9I('9A;&EK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(E9E97)G93HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM
M<V=S='(@(E9E97)G=61E('!E86QK:7)J860B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B2V]O;6EK
M<VED(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(DOD<VLB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G
M:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B2^1S=7)I9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`B2V]M;65N=&%A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("),
M:6AT;FEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@
M(DMO;6]O<FED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM
M<V=S='(@(D%R=G5T:60B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDW"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B26QM(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T
M<B`B26QM(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B2V]N9FEG=7)A='-I
M;V]N:2!E<FEN979U<V5D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R(")396%D:7-T=7,@
M<_QN:W)O;FES965R:6UI<V5K<R!01$%D92P@;G5T:71E;&5F;VYI9&4@:F$@
M3W5T;&]O:VEG82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R(")3
M96%D:7-T=7,@;VX@865G=6YU9"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G
M<W1R(")396%D:7-T82`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B
M2VEN;FET82!S86QA<_5N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM
M<V=S='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;R!$96UO
M:W)A871L:6L@5F%B87)I:6LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`BW&AE;F1U<R!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z
M("(*;7-G<W1R("+<:&5N9'5S(&YU<FIU<SH@(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D%V86QI:R!V
M]71M97-E<G9E<B!E:2!A;FYA(/QH96YD=7-T+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E
M87-O;CH@)7,@*"5S*2(*;7-G<W1R(")!=F%L:6L@=O5T;65S97)V97(@96D@
M86YN82#\:&5N9'5S="X@4/5H:G5S.B`E<R`H)7,I(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(MQH96YD=7,@1E10('-E<G9E<FEG
M82!N=7)J=7,N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G
M:60@(D-O;G1A8W1S(@IM<V=S='(@(DMO;G1A:W1I9"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(DMO;G1A:W1I9"#U;FYE<W1U<R!L:7-A9&$@<VEN=2!A
M861R97-S:7)A86UA='5S<V4N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB
M(@IM<V=S='(@(EPB)7-<(B!S:7-U(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS
M9VED(")#;VYT:6YU92(*;7-G<W1R(")*Y'1K82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K:2!386%R960B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R
M(")-]71T971E<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P
M965R:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+;W!E
M97)I;6EN92!N=7)J=7,Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS
M9W-T<B`B2V]P965R:2!V86QI:R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(D-O<W0@
M240B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO
M<W1A<FEI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM
M<V=S='(@(D-O=&4@9"=)=F]I<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R(")%:2!S86%N=60@:VER:F$@4$=09V$@:W+\<'1I
M9&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM
M<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(D5I
M('-A86YU9"!K:7)J82!01U!G82!A;&QK:7)J87-T861A+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B16D@<V%A;G5D
M(&MI<FIA(%,O34E-16=A(&MR_'!T:61A+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92XB"FUS9W-T<B`B16D@<V%A;G5D(&MI<FIA(%,O34E-
M16=A(&%L;&MI<FIA<W1A9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(")%:2!S86%N=60@
M;&ES861A(&MO;G1A:W1I+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R
M,0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(D5I('-A86YU9"!S:7-S92!,1$%0('-E<G9E<FES<V4N(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@
M=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B16D@<V%A;G5D('-I<W-E($Q$05`@
M<V5R=F5R:7-S92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B16D@<V%A;G5D(&MO
M;G1O:N3D:VD@:V]N=')O;&QI9&$N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C0T,0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N(@IM<V=S='(@(D5I('-A86YU9"#\:&5N9'5S="!,1$%0('-E<G9E
M<FEG82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<
M(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(D5I('-A86YU9"!S97)V97)I9V$@
M7"(E<UPB($944"!A8FEL(/QH96YD=7-T.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J82!L;V]M:6YE(&YU<FIU<RX@
M)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B16D@
M<V%A;G5D(%!'4"!A;F1M96ED(&1E:W+\<'1I9&$N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(")%:2!S86%N=60@4R]-24U%
M(&%N9&UE:60@9&5K<OQP=&ED82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(D5I('-A
M86YU9"!K=7-T=71A9&$@:V]N=&%K=&DN("5S(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B16D@<V%A;G5D(&MU<W1U=&%D82!J86]T=7-N:6UE:VER
M:F$N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E
M('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D5I('-A86YU9"!K=7-T=71A9&$@
M<&%I9V%L9'5S92!U=65N9&%M:7-E('-K<FEP=&D@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@
M(D5I('-U=71N=60@=N1L:F$@<V5L9VET861A(&%D<F5S<V%A9&D@92UP;W-T
M:2!A861R97-S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO9W4@86%D<F5S<VER86%M871U
M(&MO:&%L971I<FEM:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")+
M;V=U(&IA;W1U<VYI;65K:7)J82!K;VAA;&5T:7)I;6EN92!N=7)J=7,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DMO9W4@:F%O='5S;FEM
M96MI<FIA9&4@;FEM96MI<FIA(&MO:&%L971I<FEM:6YE(&YU<FIU<RXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS
M9W-T<B`B16D@]6YN97-T=6YU9"!L86%D:61A('-T<F%T965G:6%T(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T
M+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@
M7"(E<UPB+B(*;7-G<W1R(")M:V1I<B!<(B5S7"(@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@
M;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B16D@<V%A;G5D(';U=&UE<V5R=F5R:7-T(&%V86QI:VMU(';U=&ET
M(&OD='1E+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*
M;7-G<W1R(")<(B5S7"(@879A;6EN92!K:7)J=71A;6ES96MS(&YU<FIU<RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N
M(@IM<V=S='(@(B5S(&%V86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE
M("5S(@IM<V=S='(@(D5I('-U=71N=60@:^1I=FET861A(&AO;VQD=7-T]O8@
M;6]O9'5L:70@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B16D@<V%A;G5D(&%V861A(&MA=&%L;V]G:2!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@
M=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")%:2!S86%N=60@:^1T=&4@3$1!
M4"!S97)V97)I="XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP
M.C(S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB
M"FUS9W-T<B`B)7,@;'5G96UI;F4@;G5R:G5S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@
M=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@
M86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB4V]O=FET=60@:V%S=71A
M:F$@<&%R;V]L:2!T_&AJ96YD86UI;F4@;G5R:G5S+B!-]6YE9"!A;F1M960@
M96D@;VQE(/5I9V5D+B`B"B)0<F]O=FD@=75E<W1I(';U:2!V]71A(/QH96YD
M=7-T(&%D;6EN:7-T<F%A=&]R:6=A+"!K=6D@=F%J860@<VEI<VMI(&%B:2XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(D%#3&D@;&%A9&EM:6YE
M(&5B8?5N;F5S='5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B06%D<F5S
M<VER86%M871U(&QA861I;6EN92!E8F'U;FYE<W1U<RX@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J82!L86%D:6UI
M;F4@96)A]6YN97-T=7,N("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS
M9W-T<B`B2F%O='5S;FEM96MI<FIA9&4@;&%A9&EM:6YE(&5B8?5N;F5S='5S
M+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET
M:65S(@IM<V=S='(@(E-E<G9E<FD@=O5I;6%L=7-T92!L86%D:6UI;F4@96)A
M]6YN97-T=7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED
M(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMO
M;F9I9W5R871S:6]O;FD@=&%G87-I;75U=&UI;F4@;G5R:G5S+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(")R;61I<B!<(B5S7"(@96D@]6YN
M97-T=6YU9"XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(E<R!S96%D:7-T=7-E('-A;'9E<W1A;6EN92!N=7)J
M=7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DMO;F9I9W5R871S:6]O;FD@=F%R
M=6MO;W!I82!S86QV97-T86UI;F4@;G5R:G5S+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DMO;F9I
M9W5R871S:6]O;FD@=F%R=6MO;W!I82!S86QV97-T86UI;F4@;G5R:G5S.B`E
M<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(E!A:6=A;&1U<V4@=75E;F1A;6ES92!S
M:W)I<'1I(&5I('-A86YU9"!S86QV97-T861A(&MO:'1A.B!<(B5S7"(N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B16D@]6YN97-T=6YU9"!S86QV97-T861A(&MO
M;F9I9W5R871S:6]O;FEF86EL:2!V87)U:V]O<&EA="`E<RXB"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO
M=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DMO;F9I9W5R871S:6]O;FEF
M86EL:2`E<R!E:2#U;FYE<W1U;G5D('-A;'9E<W1A9&$N(%-A(';U:60@:V%S
M=71A9&$@_&AT("(*(G;U:6UA;'5S="!K;V]D:2!S86QV97-T86UI<V5K<R!T
M86=A<VD@9F%I;&D@)7,@=O5I(&MO<&5E<FED82!K;V]D(&OD<VET<VD@(@HB
M9F%I;&D@)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("),1$%0(&]T<VEN9R!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@
M7"(E<UPB+B(*;7-G<W1R(")U;FQI;FL@7"(E<UPB(&YU<FIU<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DMO;G1A:W1I('5U96YD86UI;F4@;G5R:G5S+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DIA;W1U<VYI;65K:7)J82!U
M=65N9&%M:6YE(&YU<FIU<RX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O
M;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB('-E
M861I<W1U<V4@<V%L=F5S=&%M:6YE(&YU<FIU<SH@)7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-
M;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N
M+B(*;7-G<W1R(")%:2!L96ED;G5D($UO>FEL;&$@:_QL9VER8F$N(%9A871A
M(&5T(&O\;&=R:6)A(&]L96MS(&%V871U9"XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(DMA
M<W5T86IA;&4@7"(E<UPB(&5I('-A86YU9"!A;F1A(&KD<F=M:7-I(/5I9W5S
M96ED(&MA=7-T86QE(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B4&EI
M<F%T=60@<&EK:W5S96=A('1E:W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B4FEI
M:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O
M=7)S97,B"FUS9W-T<B`B2W5R<W5S960B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R
M96%T92(*;7-G<W1R("),;V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B3&ES82!L:6YK(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*
M;7-G<W1R("),:7-A('5U<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B3&ES82!A;&%M:V%U<W1A9"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(D%U=&]R:2#U:6=U<V5D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@
M(DMR961I:71K86%R9&D@;G5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R
M;V%T:6$B"FUS9W-T<B`B2&]R=F%A=&EA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0W5B82(*;7-G<W1R(")+=75B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(")0<F%E9W5S960@
M-"!F86%S:2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R
M<F5N="!397-S:6]N<R(*;7-G<W1R(")!:W1I:79S960@<V5S<VEO;VYI9"(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS
M,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(DME;&QA865G(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R(")0<F%E9W5N92!5
M4DP@;VXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E
M;G0@57-E<G,B"FUS9W-T<B`B06MT:6EV<V5D(&MA<W5T86IA9"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*
M;7-G<W1R(")0<F%E9W5N92!I;&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S
M='(@(E!R865G=6YE(&EL;3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S
M='(@(E!R865G=6YE('-T:6EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(DCDY&QE<W1A('3V:60@
M;6ED82!T96AA:W-E('-I<V5N96UI<V5L("5S+6DN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED
M(")#=70B"FUS9W-T<B`B3/5I:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(DSU:6MA('9A;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(DO\<')O<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+:7)I;&QI='-A
M("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@
M(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMI<FEL;&ET<V$@
M*%=I;F1O=W,M,3(U,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM
M<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(DMI
M<FEL;&ET<V$O56MR86EN82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1S96AH:2!686)A<FEI:R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(E!0(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.
M("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@*'9A
M871A(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R
M("))9V$@<.1E=B(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B
M1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!S:7)V:6IA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A
M<V4@3&]O:W5P(@IM<V=S='(@(D%N9&UE8F%A<VEO='-I;F<B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B2W5U
M<.1E=B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S
M"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(E-A86)U;6ES92!K=75P
MY&5V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B
M1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B2W5U<.1E=F$@=F%L:6LB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*;7-G<W1R(")0Y&5V(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")+=5]S='5T
M82!V965R9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R(")$971S96UB97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B2_QM;F5N
M9&YU;6)R:60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B5N1H
M96YD82!T86%N9')I9&$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G
M<W1R(")686EK:6UI<VDB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M(")686EK:6UI<VD@=N1R=B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B
M5F%I:V5I9&5N=&ET965T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W
M"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E9A:6MI;6ES:2!S:&5L
M;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI
M=&EO;G,B"FUS9W-T<B`B4_5N87-E;&5T=7-E9"(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G
M<W1R(")+=7-T=71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G
M<W1R(")+=7-T=71A(&QA:'1E<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS
M9W-T<B`B2W5S='5T82!G<G5P<"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")+=7-T=71A
M(&QO9VDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@
M4&5R;6ES<VEO;B(*;7-G<W1R(")+=7-T=71A(/5I9W5S(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B2W5S='5T82!J82!E96UA
M;&1A(&MI<FIA9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@
M(DMU<W1U=&$@;&%H=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R(")+=7-T=71A('9E97)G(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B2W5S='5T82!O;&5M87-O;&5V(&%L=&5R;F%T:6EV;F4@
M;6%L;"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B2VER:F%D92!K
M=7-T=71A;6EN92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(DMU<W1U=&$@]6EG=7-E9"!<(B5S7"(M;&4B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B2W5S='5T82#U:6=U
M<V5D(%PB)7-<(BUL92!J82!K]6EK(&%L86WU:6=U<V5D/R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G
M:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B2W5S='5T82!R:61A(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L
M971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(DMU<W1U=&$@=F%L:71U
M9"!I9&5N=&ET965T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN(@IM<V=S='(@(DMU<W1U=&$@86MT:6EV;F4@=F5E<F<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M2W5S='5T82!A:W1I:79N92!R:61A(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DMU<W1U=&%S:6X@<&%I
M9V%L9'5S92!U=65N9&%M:7-E('-K<FEP=&D@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B2^1T=&5T;VEM
M971A;6ES92!A96<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S
M='(@(E1A86YI(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(DMI<FIE
M;&1A('!R;V)L965M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS
M."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")+:7)J96QD=7,B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("+<:W-I:V%S
M:F%D("AK86YT=60@:V$@2&]R9&4@;&]G:69A:6QI*3HB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BW&MS
M:6MA<VIA9"!L;V=I=&D@861M:6YI<W1R86%T;W)I(&IA;VMS+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(D%R96YD=7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q
M-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(DMA<W1E<'5N:W0B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R(")%96QM:7-E('1U;FYI(&MA<W1E<'5N:W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$
M97<@<&]I;G0Z("(*;7-G<W1R(")+87-T97!U;FMT.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C
M=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(E-U=6YD('9A<V%K=6QT('!A
M<F5M86QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T
M<B`B4W5U;F0@<&%R96UA;'0@=F%S86MU;&4B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V]G
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM<V=I9"`B1&ES<&QA
M>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")%<VET82!K96QL86%J860@,C0M
M='5N;FES96YA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED
M(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B16MR86%N:2!S96%D960B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*;7-G:60@(D1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B3N1I=&$@</5H:F%L:6MK
M=2!E;FYU<W1U<W0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED
M(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(D[D:71A(&5N;G5S
M='5S="`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*
M;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(D5K<F%A;FD@<V5A9&5D
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(D1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM
M<V=S='(@(D1J:6)O=71I(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`BQ')A(&MU
M<W1U=&$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@
M(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S
M='(@(L1R82#\<FET82!M86EN=&5N86YC92YP:'`@9F%I;&D@;W1S92!KY&EV
M:71A9&$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.B(*;7-G<W1R(")+=6D@97-I;65N92!R:61A('-I<V%L9&%B
M(';D;&IA9&4@;FEM97-I9"P@;>1R9VD@<V5E(')U=70Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI
M:V%A;FD@5F%B87)I:6LB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM
M<V=S='(@(E-U;"!P;VQE(&MO;G1O=#\@4F5G:7-T<F5E<G4N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N
M;&]A9"(*;7-G<W1R(")386QV97-T82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N
M;&]A9"`E<R(*;7-G<W1R(")386QV97-T82`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E-A;'9E<W1A(&QO
M;V1U9"!S96%D:7-T=7,@4$A0('-K<FEP=&EN82XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G
M<W1R(").:6UE:VER:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM
M<V=I9"`B1')U9W,B"FUS9W-T<B`B4F%V:6UI9"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@
M(D4M<&]S="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L
M(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS
M9W-T<B`B(@HB12UP;W-T+5--4VEL92!V86AE;F1U<V1R86EV97(L('1E96YU
M<V5P86MK=6IA=&5L92!K96QL96P@<V5L;&EN92!T965N=7,@;VXB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W5A9&]R(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B375U9&$B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B375U9&$@8FQO
M:VMI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B375U9&$@9W)U<'!I
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S
M:6]N(@IM<V=S='(@(DUU=61A(/5I9W5S="(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B375U9&$@]6EG=7-I(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R(")-=75D82`E<R#U:6=U<VDB"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G
M<W1R(")-=75D82!S96%D96ED.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")-=75D82!<(B5S7"(@]6EG=7-I
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")-
M=75D82`E<R#U:6=U<VDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*
M;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")(87)I9'5S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'1U<R(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I
M=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-
M3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B3/QL:71A('-E92!S:7-S92!J82!S
M:6ES.B`E<RP@=O5I(&MA<W5T82!L:6AT<V%T($A434P@=F5R<VEO;VYI.B`E
M<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@
M(D5L(%-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S
M='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@
M(D4M<&]S="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")%+7!O<W1I(&%A9')E<W,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`B12UP;W-T:2!A861R97-S:60@<&5A=F%D
M(&ML87!P:6UA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D4M<&]S
M="!K:6YN:71U<V5G82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*
M;7-G<W1R(")%+7!O<W0M4TU3:6QE(&S\_',B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"FUS9VED(")%;6]T:6-O;G,B
M"FUS9W-T<B`B4VUA:6QI9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB
M"FUS9W-T<B`B4_5N=6T@;VX@=/QH:2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V
M,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U
M;'0N(@IM<V=S='(@(E1U;&5M=7,@;VX@=/QH:2XB"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B3W1S:6YG=71I;F=I;75S(&]N('3\:&DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*
M;7-G<W1R("),=6)A('1E:W-T:2!S:7-S92!L:7-A9&$@<&EL=&4@9F]T;V=A
M;&5R:6ED97-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q.`IM<V=I
M9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B
M3'5B82!P87)E;6ML]7!S=6=A(&C\<&EK;65N_/PB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D%A<W1A(&SU<'`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED
M(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")3=75R96YD82!E9&ET;W(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB4VES
M97-T82!S86QA:F%N92!K_'-I;75S(&UI9&$@<VEN=6QT(&O\<VET86MS92!P
M87)O;VQI(&UU=71M:7-E:W,L(&[D:71E:W,@(@HB)VUI<R!O;B!S:6YU(&QE
M;6UI:VQO;VUA(&YI;6D_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H
M92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")3:7-E<W1A('-I:6$@<&EL9&D@
M55),(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(E-I<V5S=&$@86QL82!TY&AE9#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R(")%:W9A=&]R:6%A;"U':6YE82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E82(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(E9I9V$B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B5FEG82!B;&]K:2!L
M;V]M:7-E;#H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,B"FUS9W-T<B`B5FEG82!S_&YK<F]N:7-E97)I;6ES86YK<G4@
M:W5S='5T86UI<V5L.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y
M;F,@;&]G.B`E<R(*;7-G<W1R(")6:6=A('/\;FMR;VYI<V5E<FEM:7-E(&QO
M9VD@:W5S='5T86UI<V5L.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]4
M96UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B5FEG82!S:7-U(&QA861I;6ES
M96PZ("5S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<R(*;7-G<W1R(")6:6=A('-A;&%S]6YA(&UU=71M:7-E;#H@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*
M;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B5FEG
M82!E+7!O<W1I('1E871E<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G
M<W1R(")6:6=A(%PB)7-<(B!K:7)J=71A;6ES96PN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM
M<V=I9"`B17-T;VYI82(*;7-G<W1R(")%97-T:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]O<&EA(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B4F%H=G5S
M;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")%=7)O<&4B"FUS9W-T<B`B175R;V]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B
M26=A(#$U(&UI;G5T:2!T86=A;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B26=A(#(@
M;6EN=71I('1A9V%N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C
M;VYD<R(*;7-G<W1R("))9V$@,S`@<V5K=6YD:2!T86=A;G0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("))9V$@-2!M:6YU
M=&D@=&%G86YT(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B26=A;"!S
M:7-S96QO9VEM:7-E;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*
M;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("))9V$@<&]O;&4@='5N
M;FD@=&%G86YT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS
M9W-T<B`B2V]R9"!M:6YU=&ES(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(").Y&ED
M:7-VY.1R='5S960Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(DOD:79I=&$B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R
M("),86EE;F1A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS
M,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B3N1I=&$@:_QL9W)I
M8F$B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS
M9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B3V]T87-I;B`G*2<B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(D]O=&%S:6X@;&EH='-A="!S]6YA(';U:2!J=71U;>1R:VED97,@;W1S:6YG
M=69R86%S:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(D%E9W5M:7-E(&MU
M=7#D978B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B16MS<&]N96YT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM
M<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B5&5K<W1I(';D<G8B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E
M='5P(@IM<V=S='(@(E-E861I<W1U<V4@_&QE<VQA861I;6EN92!&5%`@:V%U
M9'4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G
M:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")(
MY.1L97-T=7-E(&QA861I;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R(")%:2!S86%N=60@_&AE;F1U<W0@3$1!4"!S97)V97)I
M9V$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED
M(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")%
M:2!S86%N=60@_&AE;F1U<W0@4TU"('-E<G9E<FEG82XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B16D@<V%A;G5D
M(&MO<&5E<FED82!<(B5S7"(M<W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")%:2!S86%N=60@:V]P965R:61A(%PB
M)7-<(BUI+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B575E(%-!4TP@_&AE;F1U<V4@;&]O;6EN92!N=7)J=7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")%:2!S86%N=60@=/5S=&$@
M7"(E<UPB+6DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*
M;7-G<W1R(")%:2!S86%N=60@=&ER:61A.B`E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S
M='(@(DAE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R(")&86QK;&%N9&D@<V%A<F5D("A-86QV:6EN
M:60I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R
M(")&Y.1R:2!S86%R960B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B2V]H=71A=B!V:6=A.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*
M;7-G:60@(D9A>"(*;7-G<W1R(")&86MS(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,T.0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%K<VED(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G
M:60@(D9E8G)U87)Y(@IM<V=S='(@(E9E96)R=6%R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B5'5N
M9'5B(&YA9W4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q
M"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B5'5N9'5B(&YA9W4Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("+<:W-I:W5D('9I:&UA:&]O9"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(MQK<VEK=60@;'5M97-A
M:G5H;V]D(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I
M9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(D9I96QD(&UA=')I>"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!4
M0TA!(@IM<V=S='(@(D9I9VQE="!#05!40TA!(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B
M1FEG;&5T(&9O;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@
M(D9I9'II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS
M9VED(")&:6QE(@IM<V=S='(@(D9A:6PB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(D9A:6QI9&4@87)V.B`E<R!F86EL(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B1F%I;&ED92!A<G8Z("5S
M(&9A:6QI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I
M9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D9A:6QI:&%L9'5R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G
M<W1R(")&86EL:2!N:6UI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B1F%I;&D@=F%L
M:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&
M:6QE('5P;&]A9"(*;7-G<W1R(")&86EL:2#\;&5S;&%A9&EM:6YE(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE
M('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1F%I;&ED92#\;&5S
M;&%A9&EM:7-T(&5I('1O971A=&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R:60B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(E-O;VUE(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R(")%<VEM96YE('!O;VPB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@
M;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM
M<V=S='(@(D5S:6UE;F4@=F5E<F%N9"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R(")3Y&EL:71A('-U:&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(E!E96=E
M;&1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B2/5L:G5V(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@
M(D9O9R(*;7-G<W1R(")59'4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G
M<W1R(")+871A;&]O9VD@)7,@<&]L92!O;&5M87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O
M;&]R(@IM<V=S='(@(E1E:W-T:2!VY')V(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(E1O:70B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S(@IM<V=S='(@(E9E96)I;&5H:71S96IA=&5L92!M:7,@<&EL=&4@96D@
M=&]E=&$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R
M96-A<W0@*%1!1BDB"FUS9W-T<B`B16YN=7-T=7,@*%1!1BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T
M($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N
M<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB4.1E
M=F%D92!A<G8@*&]L9W4@]F5L9'5D(&5T('1A9V%S=&%T878@96YN=7-T=7,@
M<VES86QD86(@;FEI('#D979I(&MU:2#V:60[("(*(G-U=7(@87)V(';U:6(@
M8FQO:VD@;&%I86MS('9E;FET861A*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS
M9W-T<B`B56YU<W1A<VED('-A;&%S]6YA/R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(E9O<FUI9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R(")+:6QD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS
M9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B2VEL;'4@=/S\<"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B"FUS9W-T
M<B`B2VEL;'5D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(DMI;&QU9"`R(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O
M;W)U;6ED(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I
M9"`B1F]R=V%R9',B"FUS9W-T<B`B161A<W1U<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(E)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(E)A86UI9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")0<F%N='-U<VUA
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B4')A;G1S=7-M86$L($5U
M<F]O<&$M;W-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R(")0<F%N='-U<V4@1W5A:F%A;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0<F%N='-U<V4@4&]L_&YE
M97-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S(@IM<V=S='(@(E!R86YT<W5S92!,]75N86%L860B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED
M(")&<F]M(@IM<V=S='(@(DME;&QE;'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B
M1G)O;2!T:&4@(@IM<V=S='(@(E-U=6YA9V$@(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB
M"FUS9W-T<B`B4/5H:F%L:6L@:VER:F5L9'5S(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@
M36]O;B(*;7-G<W1R(")4Y&ES:W5U(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G
M:60@(D9U;&P@3F%M92(*;7-G<W1R(")4Y&ES;FEM:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED
M(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QE<FEI
M+"!K=7-T('!I;'0@=O5T=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ
M(@IM<V=S='(@(D=A;&5R:6DZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA
M(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")'96YE<F5E<FD@)7,@:V]N9FEG=7)A='-I;V]N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@
M(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D=E;F5R965R:71U9"!K;V]D(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'<G5U<VEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R(")386MS86UA82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=A86YA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED
M(")':79E;B!.86UE(@IM<V=S='(@(D5E<VYI;6DB"@IM<V=I9"`B1VQO8F%L
M($]P=&EO;G,B"FUS9W-T<B`BW&QD:7-E9"!S96%D960B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B36EN92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM
M<V=S='(@(D?V9&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O
M;V=L92!K86%R9&ED(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM
M<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G;&4@;W1S:6YG(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM
M<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(DAA;&QT;V]N:61E<W-E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")+<F5E:V$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(DMR965K82`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+V]FYI;6%A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D=R=7!P:61E(&AA;&1U<R(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`B1W)U<'!I9&4@;FEM960@96D@=O5I(&]L;&$@=/QH:F%D(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S
M+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B1W)O
M=7!?;&1A<#H@16D@<V%A(&QI<V%D82!G<G5P<&D@)7,N(%-E<G9E<B#\=&QE
M<SH@(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G
M<W1R(")'<F]U<%]L9&%P.B!%:2!S86$@:W5S='5T861A(&=R=7!P:2`E<R(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM
M<V=S='(@(D=R;W5P7VQD87`Z($5I('-A82!M=75T82!G<G5P<&D@)7,B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!I9"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&5L;W5P92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=U871E;6%A;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(DO\;&%L:7-E(/5I9W5S960B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"FUS9VED(")'=65S
M=&)O;VLB"FUS9W-T<B`B2_QL86QI<W1E<F%A;6%T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=I;F5A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=I;F5A+4)I<W-A=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U86IA86YA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM
M<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T
M<B`B2%1-3$%R96$@:V5E;&1U8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T
M(')E82!V:6EM87-T(&QA:'1R:70N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!K965L9'5B(&%R9W#\:W-L:6MU
M;'0@:W5S='5T86UA<W0@=&%B96QI('9I:6UA<W0@=F5E<F=U+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@:V5E;&1U
M8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T('1A8F5L:2!V:6EM87-T(')I
M9&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G
M:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(
M5%10(&%U=&5N=&EM:7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DAA:71I(@IM<V=S='(@(DAA:6ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS
M9W-T<B`B4N1S:6%L9V]R:71M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B2.1G=2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B4.1I<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*
M;7-G:60@(DAE861E<G,B"FUS9W-T<B`B4.1I<V5D(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS
M9W-T<B`B2&5A<F1I('-A87(@:F$@36-$;VYA;&1I('-A87)E9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(
M96%V>2!4+5-T;W)M(@IM<V=S='(@(E+D;FL@Y&EK97-E=&]R;2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y
M+3@M22DB"FUS9W-T<B`B2&5E8G)E82`H25-/+3@X-3DM."U)*2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*
M;7-G:60@(DAE:6=H="(*;7-G<W1R(")+]7)G=7,B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@
M=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T
M<B`B06)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B161I
M=&]R:2!K87-U=&%M:7-E(&%B:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!8FEL:6YE(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S
M='(@(G!O;VQK97)A(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B4VEI;B!O
M;B!F86EL:2!A;&=U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(DOU<F=E(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R(")?079A
M;&5H="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N
M($-I='D@4W1A=&4I(@IM<V=S='(@(E#\:&$@5&]O;"`H5F%T:6MA;FD@3&EN
M;G)I:6LI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"FUS
M9VED(")(;VUE(@IM<V=S='(@(D%V86QE:&5L92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R
M97-S(@IM<V=S='(@(DMO9'5N92!A861R97-S(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")+
M;V1U:V%T86QO;V<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(DMO9'5N
M92!T96QE9F]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G
M<W1R(")(;VYD=75R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N
M9R(*;7-G<W1R(")(;VYG:V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!6:6=A<V5D
M("5S(%A-3"!A;F1M960@:VER:F%S("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S
M='(@(DAO<F1E+TMO;&%B.B!/8FIE:W1I;&4@)7,@96D@=F%S=&$@_&MS:VD@
M:VER:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!%:2!L96ET=60@_&AT:VD@)7,@=/S\<&D@;V)J96MT:2!K:7)J87,@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@U6YN97-T=7,@965M
M86QD861A("5S(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YT96=R871S:6]O;FEM;V]T;W(@=F%J86(@
M)V1O;7AM;"<@4$A0(&QA:65N9'5S="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%:2!S86$@;'5U82!U=70@6$U,('!U
M=60@;V)J96MT:2`E<R!J86]K<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!%:2!S86$@965M86QD861A("5S(%PB)7-<(CH@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($5I(/5N;F5S='4@:&%N:VED82!-24U%($E$+60@)7,@=/S\<&D@;W-A(&IA
M;VMS(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@
M<V%A('/\;FMR;VYI<V5E<FED82`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@16D@<V%A('/\;FMR;VYI<V5E<FED
M82!J86=U<VED.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@5'5N9&UA='4@
M:F%G=2!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B
M2&]R:7-O;G1A86QJ;V]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(DAO<FES;VYT86%L;F4@=F]O9&5R9'5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO
M;G1A;#HB"FUS9W-T<B`B2&]R:7-O;G1A86QN93HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@
M(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S
M='(@(DMU:61A<R!S82!S:6EA('-A='1U<VED/R`H4&%L=6X@=&5A=&$A*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@
M=&\@;65R9V4_(@IM<V=S='(@(DMU:2!P86QJ=2!V965R9V4@<V]O=FEK<VED
M(/QH96YD861A/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q
M"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B
M"FUS9W-T<B`B2W5I('!A;&IU(';D;&IU("AV965R9V4I(&]N/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(DMU:2!P86QJ=2!R:61U('-O;W9I:W-I9"#\:&5N9&%D83\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(").:6ES
M:W5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I
M9"`B2'5M:61I='DZ("(*;7-G<W1R(").:6ES:W5S.B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU
M;6]R:7-T:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T
M<B`B56YG87)I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B24U!4"!P;W-T:V%S=&D@;&]O;6EN92!N=7)J=7,Z("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B24U!4"!P;W-T:V%S=&D@:W5S='5T86UI;F4@;G5R:G5S.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(DE-05`@<&]S=&MA<W1I(&MV;V]D:2!L;V]M:6YE(&YU<FIU<SH@)7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!
M9&1R97-S(@IM<V=S='(@(DE0(&%A9')E<W,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(DE0(&%A9')E<W,@<&]L92!T96%D82XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G
M<W1R("))4"!A861R97-S(&5I(&MU=6QU(&QU8F%T=60@0TE$4B!B;&]K:VDN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@
M(DE0('!I:7)A;F=U(')I:VMU;6EN92XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E
M<G0@4F]W($)E9F]R92(*;7-G<W1R("),:7-A(')I9&$@7V5N;F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R(")!:6YU;'0@:6MO;VYI9"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS
M9W-T<B`B)7,@:6MO;VYI9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]O;FED(&IA
M('1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET965D:2!N:6UI.B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E
M8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@
M(DMU:2!S961A(/5I971I(&5I(&[D:61A=&$L("5S(&IA('-E92!A=F%T86MS
M92!U=65S(&%K;F%S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*
M;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B
M(@HB2W5I('-A(&MA<W5T860@26YT97)N970@17AP;&]R97)I="!J82!E:2!N
MY&4@_&QD<V4@:6MO;VYE+"!S:6ES('!R;V]V:2`B"B)MY')K:61A('-E92!R
M=75T+"!L_&QI=&%M86MS('-I<W-E(%!.1R!LY&)I<&%I<W1V=7,N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I
M9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(DMU:2!S82!NY&5D
M('-E9&$@=&5A9&5T(&%G82!P:6QT:2!E:2!NY&4L('-I:7,@96D@;W-K82!S
M:6YU('9E96)I;&5H:71S96IA("(*(F[D:61A=&$@<V5D82!P:6QT:2P@;6ED
M82!S;V]V:60@_&QE<R!L86%D:61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA
M9V4@4')E=FEE=SHB"FUS9W-T<B`B4&EL9&D@965L=F%A9&4Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM
M<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E!I;&1I(%523"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")0:6QD:2!54DPZ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B4&EL
M="!G86QE<FEI<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B4&EL="!G86QE<FEI<W0Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S
M='(@(E!I;&1I(/QL97-L86%D:6UI;F4B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(E!I;&1I9"(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R="P@<V%M;2`E9"(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M
M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<F1I
M='5D(';D;&DZ("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV
M-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("));7!O<F1I='5D
M(';D;&IA9#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(DQI<V$@<FED82!?<.1R87-T(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D5S:71A=&D@=F%L92!T96=E=G5S
M92!K;V]D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(")686QE(&MA<W5T86IA;FEM:2!J82]V]6D@
M<&%R;V]L+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS
M9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O
M<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(E9A;&4@
M:V%S=71A:F%N:6UI(';U:2!A;'1E<FYE=&EI=FYE(&%A9')E<W,N(%!R;V]V
M:2!U=65S=&D@=O5I(';U=&$@_&AE;F1U<W0@(@HB861M:6YI<W1R86%T;W)I
M9V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(E-U=7)E;F1A
M('1A86YD<FED82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T
M<B`B26YD:6$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I
M9'5A;"!5<V5R<R(*;7-G<W1R("+<:W-I:W5D(&MA<W5T86IA9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N965S:6$B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("))
M;F9O<FUA='-I;V]N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`B5&5A=F4@96D@;VQE(&5N86T@:^1T=&5S86%D878N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("),:7-A
M(%]V965R9R!PY')A<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G
M92(*;7-G<W1R("),:7-A('!I;'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS
M9W-T<B`B3&ES82!T86)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G
M<W1R("),:7-A(&C\<&5R;&EN:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#
M;VQU;6X@0F5F;W)E(@IM<V=S='(@(DQI<V$@=F5E7W)G(&5N;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DQI<V$@=75S('9E97)G(&%K=&EI=G-E('9E97)U
M(&KD<F5L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DQI<V$@=75S('9E97)G
M(&%K=&EI=G-E('9E97)U(&5T=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DQI<V$@
M=75S(')I9&$@86MT:6EV<V4@<F5A(&KD<F5L92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DQI<V$@=75S(')I9&$@86MT:6EV<V4@<F5A(&5T=&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*
M;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E(@IM<V=S='(@(DQI<V$@;/5I:R!P<F%E9W5S92!A<W5K;VAA(&KD<F5L
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DQI<V$@;/5I:R!P<F%E9W5S92!A
M<W5K;VAA(&5T=&4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I
M9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("),:7-A(&%L
M=&5R;F%T:6EV;F4@;6%L;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R(")3:7-E
M<W1A(&UA:6QI86%D<F5S<R!K=6AU('-A86MS('-U;&QE('5U92!P87)O;VQI
M('-A871A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S
M='(@(DQI<V$@;&%H=&5R('#D<F%S="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C
M96QL(&)E9F]R92(*;7-G<W1R("),:7-A(&QA:'1E<B!E;FYE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM
M<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("),:7-A('9E97)G
M('#D<F%S="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM
M<V=S='(@(DQI<V$@=F5E<F<@96YN92(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B
M"FUS9W-T<B`B3&ES82!K:7)J860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B3&ES82!L]6EK('#D<F%S="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B
M3&ES82!L]6EK(&5N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R
M(@IM<V=S='(@(DQI<V$@<FED82!PY')A<W0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R("),:7-A(')I9&$@96YN92(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q
M=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T
M<B`B2VER:G5T82!S86QA:_QS:6UU<V4@]6EG92!V87-T=7,Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B
M26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("),:7-A+VUU=61A('!I;'0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y
M"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B3&ES82]M=75D
M82!L:6YK(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DIA;W1U<VYI
M;65K:7)J86QE('-A871M:7-E:W,@96D@:N1T:W4@:W)E9&EI=&DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(DMR961I:71I
M(&5I(&KD=&MU+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*
M;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B5.1I<V%R=B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G
M<W1R(")4Y&ES87)V=61E(&YI;65K:7)I(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")6:6=A;F4@541(
M("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G
M<W1R(")6:6=A<V5D(%I)4"!A;F1M960N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`B5FEG86YE(')A:V5N9'5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C
M:"!)1"XB"FUS9W-T<B`B5F%L92!B871C:"!)1"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E
M9"XB"FUS9W-T<B`B4VES97-T871I('9I9V%S960@86YD;65D+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM
M<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")6
M:6=A;F4@<VEH=&%A9')E<W,N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G
M<W1R(")686QE(&9A:6QI9F]R;6%A="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM
M<V=S='(@(E9I9V%N92!L:71S96YT<VEV]71I+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S$*;7-G:60@(DEN=F%L:60@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(E-I<V5S=&%T:2!V:6=A;F4@87-U:V]H="(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B5FEG86YE
M(&US9U]T>7!E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R(")A<&E?:60@;VX@<'5U9'4@=O5I('9I9V%N92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G
M<W1R(")6:6=A<V5D(';U:2!P=75D=79A9"!P87)A;65E=')I9"XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E9I9V%N92#\;&5M]6EG=7,N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I9"`B26YV
M86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")6:6=A;F4@<&%R=&YE<FD@240B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("))
M;G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B5FEG86YE('1O;W1E:V]O
M9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E9I
M9V%N92!P<F]T;VMO;&PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE
M;G0Z(%PB)7-<(B(*;7-G<W1R(")6:6=A;F4@<V%A:F$Z(%PB)7-<(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T
M(@IM<V=S='(@(E9I9V%N92!J86=A='5D(&]B:F5K="(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B
M26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B5FEG86YE(&SD:'1E
M86%D<F5S<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*
M;7-G<W1R(")6:6=A<V5D('5N:6-O9&4@86YD;65D+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M(").:6UE:VER:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
M4/;V<F1V86QI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%A;FD@27-L86UI=F%B87)I:6LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A86LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B26ER:6UA82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE
M(&]F($UA;B(*;7-G<W1R(")-86YI('-A87(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3
M=&]R;7,B"FUS9W-T<B`BW&MS:6MU9"#D:6ME<V5T;W)M:60B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R(")):7-R865L(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E
M<B(*;7-G<W1R(")6Y&QJ86%N9&IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B
M2V%L9&MI<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@
M(DET86%L:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T
M<B`B2F%M86EK82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA86YU87(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA87!A;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/
M+3(P,C(M2E`I(@IM<V=S='(@(DIA87!A;FD@*$E33RTR,#(R+4I0*2(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A
M<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@
M=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN
M(@IM<V=S='(@(B(*(DMU;F$@<VEN=2!V965B:6QE:&ET<V5J87,@;VX@2F%V
M87-C<FEP="!K965L871U9"P@96D@<')U=6=I('-E92!L96AT(/5I971I("(*
M(G!A:7-T82XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM
M<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A86YI82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(DIU=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5U;FDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X
M"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(E+V]G!S96QT(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(DME<VME;&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(E+V]G!S96QT(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")687-A:W5L92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V
M"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(E!A<F5M86QE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA<V%H<W1A
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(E/D:6QI=&$@;W)I
M9VEN86%L/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B
M2V5E;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM
M<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")+97)B97)O<V4@<V5R=F5R(&5I(&QA<VMN=60@<VES<V4N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@
M3F5W8FEE<R(*;7-G<W1R(")+97)N96QI(';U:&EK=60B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R(")6]71M92!L;V]M:6YE(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B5O5T;64@<_5R;65JY&QG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(E;U
M=&UE('!I:VMU<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5O5T;64@=/S\<"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+
M97D@57-A9V4B"FUS9W-T<B`B5O5T;64@:V%S=71U<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")6]71I
M(&]N(&%V86QI:W5S('-E<G9E<FES(&IU8F$@;VQE;6%S+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("),87!S
M960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(DMI
M<FEB871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I
M8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")+;W)E82!286AV861E
M;6]K<F%A=&QI:R!686)A<FEI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<F5A(%9A8F%R:6EK(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2
M*2(*;7-G<W1R(")+;W)E82`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2W5W86ET(@IM<V=S='(@(DMU=F5I="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+]7)G]7IS=&%N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@
M(E]+=6IU;F1U<R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*
M;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DME96PB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S
M='(@(DQA;W-E(%)A:'9A9&5M;VMR86%T;&EK(%9A8F%R:6EK(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@
M(E9I:6UA;F4@<&]O;"(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B5FEI;6%N92!P
M87)O;VQI(&UU=71U<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R
M(")6:6EM86YE('9E97)A;F0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U
M,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")6:6EM871I(&UU=61E
M='5D.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")%96QM:6YE
M(&O\;&%S='5S.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S
M(@IM<V=S='(@(D5E;&UI;F4@:_QL87-T=7,Z("5S(&%A9')E<W-I;'0@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@
M;&]G:6XZ($YE=F5R(@IM<V=S='(@(D5E;&UI;F4@:_QL87-T=7,Z(&UI='1E
M(&MU;F%G:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@
M(DSD=&DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA
M=R(*;7-G<W1R(")396%D=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R
M(")+=6IU;F1U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`B5/QH:2!TY&AE;F1A8B!P:6ER:F]O;F4@<'5U9'5M:7-T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI:6)A;F]N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(E9A<V%K(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS
M9W-T<B`B5F%S86L@<.1I<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,34*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9A<V%K=60@=N3D
M<G1U<V5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@
M(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DQE=F5L(@IM<V=S='(@(E1A<V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQI8F5R:6$B"FUS9W-T<B`B3&EB965R:6$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EI8OQA
M($%R86%B:6$@5F%B87)I:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H
M=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$
M<FEZ>FQE(@IM<V=S='(@(E1I8G5T86(@=FEH;6$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I
M;B(*;7-G<W1R(")3965N979I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*
M;7-G<W1R(")(;VUM:6MU;"!T:6)U=&%B('9I:&UA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A
M:6X@3&%T92(*;7-G<W1R("+5:'1U;"!T:6)U=&%B('9I:&UA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI
M9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DME<F=E(&AO;W9I:&TB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B2V5R9V4@=FEH;2!J
M82#D:6ME(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B2V5R9V4@;'5M97-A
M9'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B2V5R9V4@;'5M
M971O<FTB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI
M;65R:6-K(@IM<V=S='(@(DQI;65R:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("),:6YK('9I:71A
M8B!A<W5K;VAT83HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U
M"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(D5S:71A;6ES96P@<V5O
M<W1A(&4M<&]S=&D@86%D<F5S<R!U=64@:VER:F$@86MN86=A(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM
M<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EN9VED(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN
M=7AI('!RY.1N:6LB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R(@IM<V=S='(@(DQI<W0@+2!K87-U=&%J82!V]6EB(&MA=7-T82!NY&AA
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A
M8F%S97,B"FUS9W-T<B`B06YD;65B86%S:61E(&QO971E;'4B"@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC
M<R(*;7-G<W1R(")!8FEI;F9O('1E96UA9&4@;FEM96MI<FDB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R
M(")486)E;&ET92!L;V5T96QU(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),
M:7-T+4%R8VAI=F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W0M2&5L<"(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED
M("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G
M<W1R("),:7-T+4]W;F5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("),:7-T+5!O
M<W0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM
M<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U3=6)S8W)I8F4B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I
M9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B<V-R:6)E
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED("),:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B4V5S<VEO;VYI9&4@;FEM96MI
M<FIA(&5S:71A;6EN92!N=7)J=7,Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<R(*;7-G<W1R(")+87-U=&%J871E(&YI;65K:7)J82!E<VET86UI
M;F4@;G5R:G5S.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B2V%S=71A:F%T92!N:6UE:VER:F$@<&]L92!L=6)A='5D(&[D:&$N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T
M=7)E(@IM<V=S='(@(DMI<FIA;F1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&ET:'5A;FEA(@IM<V=S='(@(DQE961U(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6UA9V5S+G!H<#HX,PIM<V=I9"`B3&]A9&EN9RXN+B(*
M;7-G<W1R("),865N+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(DMO:&%L:6L@
M865G.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO
M8V%L92!A;F0@5&EM92(*;7-G<W1R(")296=I;V]N(&IA(&%E9R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B07-U:V]H="(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("),
M;V=I('-I<W-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U
M"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@
M(D5E;&UI<V4@<_QN:W)O;FES965R:6UI<V4@;&]G:2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B"FUS9W-T
M<B`B3&]G:2!VY&QJ82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM
M<V=I9"`B3&]G:6XB"FUS9W-T<B`B2V%S=71A:F%N:6UI(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T
M<B`B5/;V9"!S:7-S96QO9VEM:7-E;"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB
M"FUS9W-T<B`B4VES<V5L;V=I;6EN92!N=7)J=7,L(&MU;F$@:V%S=71A:F%N
M:6UI(';U:2!P87)O;VP@<&]L;G5D(/5I9V4N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(E-I<W-E;&]G:6UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")0:6MK('1E
M:W-T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E
M(@IM<V=S='(@(D%R;6%S='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R(")-861A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B
M2W)E96MA(';D:6ME=.1H960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(DQA9&EN82!VY&EK973D:&5D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")6Y&EK97-E
M9"!R;V]M82!N=6UB<FED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(DQU:W-E;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(DU-(@IM<V=S='(@(DM+(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B35,M5$Y%1B!L:7-A;F0@96D@<VES86QD86YU9"!A;F1M96ED+B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA:V%O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;VYI82`H16YD:6YE($IU9V]S
M;&%A=FEA(%9A8F%R:6EK*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")-86%G:6$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T
M<B`B12UP;W-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM
M<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")0;W-T:2!A9&UI;FES=')A871O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")?5&5E
M(&QI;FLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-
M86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@
M(DUA;&%I<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G
M<W1R(")-86QD:6EV:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS
M9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T
M<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@
M(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O
M(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(E-E861I<W1A(&MA
M=&5G;V]R:6%I9"P@;6ED82!K87-U=&%T86MS92#\:W-U<W1E(&WD<F=E;F1A
M;6ES96MS(&IA(&YE;F1E;&4@(@HB:V%T96=O;W)I871E;&4@=F%S=&%V86ED
M(';D<G9E+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P,C0@:V%A
M<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<%%U97-T(&MA
M87)T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED
M(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(E9A<W1A=G5S960@<V%L=F5S
M=&%T=60N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DWD<G1S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I
M9"`B36%R9VEN(@IM<V=S='(@(E-E<G8B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO
M56YS965N(&9L86=S(@IM<V=S='(@(E3D:&ES=&$@;&]E='5D+VQU9V5M871A
M('-T86%T=7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM
M<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B5.1H:7-T82!M=74@<W1A871U
M<R`H;G0N('3D:'1I<R]V87-T871U9"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@
M(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&QI('-A87)E9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T
M:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G
M:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")3;V)I=F%D(';D;&IA9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R
M971A86YI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S
M='(@(DUA=7)I:71I=7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I
M="XB"FUS9W-T<B`B4W5U<FEM(&QU8F%T=60@:W)E9&EI="XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G
M:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R(")+:7)J
M82!O<V%D92!P:6ER86YG(/QL971A='5D+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B5FEI;6%S92`R-"!T=6YN:2!K]7)G96EM('1E;7!E<F%T=75R.B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@
M;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5FEI;6%S92`V('1U;FYI(&OU<F=E
M:6T@=&5M<&5R871U=7(Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(E-U=7)I
M;2!P;W)T86%L:2!B;&]K:VED92!A<G8B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE
M;F=T:"(*;7-G<W1R(")3=75R:6T@<&EK:W5S(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R
M(")-86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@
M(DUE9&EC:6YE(@IM<V=S='(@(DUE9&ET<VEI;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T
M<B`B3&EI:VUE9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G
M:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N_/P@97-I='5S.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*
M;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(MQH96YD82!L86AT<FED(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`B5&5A9&4B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(DMI<FD@;VX@961U:V%L="!K;VYT<F]L;&ET=60L(&5N="!A;&QK:7)J
M87-T86IA('-E<G1I9FEK86%T:2!E:2!S86%N=60@(@HB:V]N=')O;&QI9&$N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E1E861E
M(&]N(&%E9W5N=60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T
M>7!E(@IM<V=S='(@(E1E871E('3\_'`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B365T87(@:6QM
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T87(@8FQO:VL@96D@;VQE
M('-A861A=F%L+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED
M("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")-
M971A<B!B;&]K:R!E:2!O;&4@<V%A9&%V86PN(-QK<VEK87-J860@;&]G:71I
M(&%D;6EN:7-T<F%A=&]R:2!J86]K<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(DUE=&%R1$(@_&AE;F1U<R!P=75D=6(N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B365E=&]D(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R(")-965T;V0@7"(E<UPB(&5I(&]L92!D969I;F5E<FET=60B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM
M<V=S='(@(DUE971O9"!E:2!O;&4@9&5F:6YE97)I='5D+B!+Y&EV:71A='5D
M(&UE971O9#H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S
M='(@(DUE971E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S
M='(@(DUE:&AI:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE97-I82!&]F1E
M<F%T<VEO;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")+97-K96QE
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-24U%('3\_'`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(E9I:6UA<V4@,C0@='5N;FD@;6%D86QA:6T@=&5M
M<&5R871U=7(Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@
M(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E9I:6UA<V4@-B!T
M=6YN:2!M861A;&%I;2!T96UP97)A='5U<B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G
M92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(E!A<F]O;&D@;6EN:6UA
M86QN92!V86YU<R!P;VQE('9E96P@=.1I<R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*;7-G
M<W1R(")0965G96QD82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")-:71M97-U9W5S="(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U
M,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*
M;7-G<W1R(")0=75D=6(@4$5!4B!P86ME='0@2%144%]297%U97-T+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R
M("(B"B)+;VYF:6=U<F%T<VEO;VX@<'5U9'5B+B!+=6D@=&%H860@<V5D82!R
M86ME;F1U<W0@:V%S=71A9&$L('!E860@96YN92`B"B)G96YE<F5E<FEM82!K
M;VYF:6=U<F%T<VEO;VYI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R(")0=75D=6(@<_5N=6UI($E$+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M(")0=75D=6(@=F%J86QI:R!014%2('!A:V5T="!-86EL+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")0=75D=6(@<V5S<VEO
M;VYI($E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(D5S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R
M(")-;V)I:6QN92!E+7!O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B3?7U
M9'5K87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R(")-=75T;6ES92!K=75PY&5V(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(DUU=61A(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-
M;V1U;'5S(@IM<V=S='(@(DKDY&LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F$@5F%B87)I:6LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA:V\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O
M;VQI82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@
M(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DMU=2!J82!A87-T82(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@
M(DUO;G1H;'DB"FUS9W-T<B`B2V]R9"!K=75S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@
M(DUO;VX@4&AA<V5S(@IM<V=S='(@(DMU=69A87-I9"(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B
M4F5A<R`E9"!L96ET:2!R;VAK96T@=N1L:G4@:W5I(&5E;&1A=&%V("5D+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:V\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM
M<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E9A;&1A=F%L="!S96QG92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS
M9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E9A;&1A=F%L="!P:6QV97,B
M"@IM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B5F%L
M9&%V86QT('!I;'9E<R!J82!T=75L:6YE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*
M;7-G<W1R(")686QD879A;'0@<.1I:V5S97!A:7-T96QI;F4B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@
M1&]W;B(*;7-G<W1R(").:6AU=&$@86QL82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S
M='(@(DYI:'5T82!V87-A:W5L92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(").
M:6AU=&$@<&%R96UA;&4B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B3FEH=71A(/QL
M97,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(T"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B3FEH=71A(&%L;&$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B3FEH=71A(/QL97,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36]S86UB:6EK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(DUI=&UE=&%S96UE;&EN92!L
M;V5N9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM
M87`@54L@:V%A<G0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B5F%L:6LB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O
M=6YT(@IM<V=S='(@(DUI;G4@:V]N=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B36EN=2!K;VYT;R!I;F9O(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUI;G4@<&]R=&%A
M;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY
M(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B36EN=2!P;W)T86%L:2!K=6IU;F1U
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")->6%N
M;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(")%22P@
M;6$@14D@3TQ%(&[U=7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`IM<V=I9"`B3F%M92(*;7-G<W1R(").:6UI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EI8FEA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86%L(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").971H97)L86YD<R(*;7-G<W1R(")(;VQL86YD(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(DAO;&QA
M;F1I($%N=&EL;&ED(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(DYE
M='-C87!E($)A<V4@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(DYE='-C87!E($-!('3\:&ES='5S92!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8V%P92!#02!P;VQI8WD@
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E
M('5U96YD=7-E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G
M<W1R(").971S8V%P92!T_&AI<W1U<V4@55),(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S
M97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!34TP@<V5R=F5R:2!N:6UI
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T
M<V-A<&4@<V5R=&EF:6MA861I(&MO;6UE;G1A87(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP92(*;7-G<W1R(").971S8V%P92!S97)T:69I:V%A9&D@
M=/S\<"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@
M(DYE='=O<FLB"FUS9W-T<B`B5O5R:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(DUI='1E(&MU;F%G:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A
M;&5D;VYI82(*;7-G<W1R(")5=7,M2V%L961O;VYI82(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").
M97<@0V%T96=O<GDB"FUS9W-T<B`B575S(&MA=&5G;V]R:6$B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@
M(E5U<R!K:7)I("5S+6QE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI
M8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED(").97<@36]O;B(*;7-G<W1R(").;V]R:W5U(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE
M("AO<'1I;VYA;"DB"FUS9W-T<B`B575S(&MA<W5T86IA;FEM:2`H<&]L92!K
M;VAU<W1U<VQI:RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD
M(@IM<V=S='(@(E5U<RU-97)E;6%A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,W"FUS9VED(").97<@<&%S<W=O<F0B"FUS9W-T<B`B575S
M('-A;&%S]6YA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I
M<F4@;VX@)7@N(@IM<V=S='(@(E5U<R!S86QA<_5N82!A96=U8B`E>"XB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(E-A;&%S]6YA9"!P96%V
M860@:VQA<'!I;6$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G
M<W1R(")5=65S(&%K;F%S("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS9W-T<B`B575D
M:7-E9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@
M(DYE=W-G<F]U<',B"FUS9W-T<B`B1W)U<&ED(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B2N1R
M9VUI;F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@
M-"!0:&%S97,B"FUS9W-T<B`B2N1R9VUI<V5D(#0@9F%A<VDB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@
M(DKD<F=M:7-E9"!S96%D960B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N
M<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B2N1R9VUI;F4^(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEK87)A86=U
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG965R
M:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED
M(").:6=H="(*;7-G<W1R("+6]B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU
M92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B16DB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V
M86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E
M<R!F;W(N(@IM<V=S='(@(E!U=61U=F%D(&MO;F9I9W5R871S:6]O;FEA;F1M
M960@;6EL;&4@97)I;F5V=7-I(&[D:61A=&$N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@
M(E!U=61U8B!S=')A=&5E9VEA($E33V1E(&QO;VUI<V5K<RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G
M:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(")0=75D=6(@;6%L;"XB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E
M>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")396QL
M97,@87-U:V]H87,@96D@;VQE(&)L;VMK:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O
M=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DU#04P@
M875T96YT:6UI<V5K<R!V86IA;&EK(&MA;&5N9')I(&YI;6D@;VX@<'5U9'4N
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG
M92XB"FUS9W-T<B`B17)I;F5V=7-I(&5I(&]L92XB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4V5L;&5L
M92#U:6=U<V5L92!E:2!S86$@86QA;6%I9"!L:7-A9&$N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B)7,@:.3D;&5S='5S:6YF;R!P
M=75D=6(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+B(*;7-G<W1R(")&5%`@5D93(&CDY&QE<W1U<VEN9F\@<'5U
M9'5B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RXB"FUS9W-T<B`B4U%,(%9&4R!HY.1L97-T=7-I;F9O('!U=61U
M8BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")344PM1FEL92!61E,@:.3D;&5S
M='5S:6YF;R!P=75D=6(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B2W)E9&EI="!O;B!A;6UE;F1A='5D+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B4VEH=&MO:'0@;>3D
M<F%M871A+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W
M-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R(")&86EL:2!E:2!L
M865T=60B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO
M(&EC;VYS(&9O=6YD+B(*;7-G<W1R(")):V]O;F4@96D@;&5I='5D+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(D%S=6MO:'0@;>3D<F%M
M871A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!<W5K;VAT(&WD
MY')A;6%T82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G
M<W1R(")3]6YU;2!P=75D=6(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF
M:65D+B(*;7-G<W1R(").:6UI('!U=61U8BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3G5M8F5R('!U=61U8BXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F
M;W)T=6YE<R(*;7-G<W1R(")!:6YU;'0@=FEI<V%K860@:VEL;'5D(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DA45%`@875T96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B24U!4"!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")+97)B97)O<R!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO
M075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,
M;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3&]G:6X@875T96YT:6UI
M<V4@<V%L87/U;F$@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!!4U-71"!A=71E
M;G1I;6ES92!S86QA<_5N82!P=75D=6(N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")334(@875T96YT:6UI
M<V4@<V%L87/U;F$@<'5U9'5B+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E
M;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N
M96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T
M<B`B(@HB3W!E;E-33"!P<F]G<F%M;6D@87-U:V]H="!E:2!O;&4@;>3D<F%T
M=60N($]P96Y34TP@<')O9W)A;6T@;VX@=F%J86QI:R`B"B)02T-3(S$R(&%N
M9&UE=&5G82!T]O9T86UI<V5K<RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(D]O=&5L(&QI:71U;6ES<V]O=F4@96D@;VQE+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M<75O=&$@<V5T+B(*;7-G<W1R(")0:6ER86YG=70@96D@;VQE+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*
M;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E!U=61U=F%D(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS9VED(").;R!S97!A<F%T;W(@
M<W!E8VEF:65D+B(*;7-G<W1R(")%<F%L9&%J82!P;VQE(&WDY')A='5D+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DUI='1E(/QK<VMI(&O\
M;&<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B
M3F\@<W5C:"!F:6QE(@IM<V=S='(@(E-E;&QI<W0@9F%I;&D@96D@;VQE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@
M=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G
M<W1R(")0=6AV97)D86UI<V5K<R!P=75D=6(@86IU=&EN92!K871A;&]O9RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R
M,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(DMA<W5T86IA;FEM92!J82]V]6D@<V%L87/U;F$@96D@<V%A9&5T
M=60N(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G
M:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(D5I('1A
M9V%S=&%T=60@:V]R<F5K='-E:60@6$U,(&%N9&UE:60B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L
M=65S(@IM<V=S='(@(E;DY')T=7-E9"!P=75D=79A9"(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)!;&=N92!K;VYF:6=U<F%T<VEO;VX@96D@<VES
M86QD82!V97)S:6]O;FDN($QO;R!K;VYF:6=U<F%T<VEO;VX@=75E<W1I+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(E-I;G4@:V]N9FEG=7)A='-I;V]N(&5I
M('-I<V%L9&$@=F5R<VEO;VYI+B!,;V\@:V]N9FEG=7)A='-I;V]N('5U97-T
M:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS
M9VED(").;VYE(@IM<V=S='(@(DWDY')A;6%T82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S
M92!I;7!L:6-I="DB"FUS9W-T<B`B3>3D<F%M871A(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM
M<V=S='(@(E#U:&IA;6%A9"`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK:2!S86%R
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0]6AJ
M87!O;VQK97)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I
M86YA($ES;&%N9',B"FUS9W-T<B`B4/5H:F$M36%R:6%A;FD@<V%A<F5D(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R<F$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B
M3F]T($%F=&5R(@IM<V=S='(@(DUI='1E(&AI;&IE;2!K=6DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E
M9F]R92(*;7-G<W1R(")-:71T92!V87)E;2!K=6DB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*
M;7-G<W1R(")%:2!O;&4@:V%T86QO;V<B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")0;VQE('1E
M;W-T871U9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DWDY')A;6%T82(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").
M;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")%:2!O;&4@=&]E=&%T=60N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3<X"FUS9VED(").;W1E<R(*;7-G<W1R(")-Y')K;65D(@H*(SH@
M<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B4&]L92!M:61A9VD@<VER
M=FED82P@;6EN92!T86=A<VDN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO
M=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I
M9"`B3G5M8F5R(@IM<V=S='(@(D%R=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S
M='(@(DWD<FMI9&4@87)V(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM
M<V=S='(@(E9E97)G=61E(&%R=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*
M;7-G<W1R(")2:61A9&4@87)V(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DIA;W1U<VYI;65K:7)J87,@;75U=&UI<V5L92!K=75L=79A9"!N
M=6UB<FED('!O;&4@;>3D<F%T=60N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS
M9W-T<B`B3V)J96MT:2!L;V]J82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(DMA:&5K<V%N9&YU;6)E
M<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T
M"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]K=&]O8F5R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G
M<W1R(")6:6ES86MU<V4@87-T92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R(")+;VYT;W)I=/;V(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@
M86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@
M(E9A;F$@:F$@=75S('-A;&%S]6YA('!E879A9"!O;&5M82!E<FEN979A9"XB
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L
M9"!P87-S=V]R9"(*;7-G<W1R(")0<F%E9W5N92!S86QA<_5N82(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W
M;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")0<F%E9W5N92!S86QA<_5N
M82!E:2!O;&4@]6EG92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS
M9W-T<B`B3VUA86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S
M:&%R960@9F]L9&5R<RXB"FUS9W-T<B`BW&AI<VMA=7-T=2!V]6EM86QD879A
M9"!A:6YU;'0@24U!4"!S97)V97)I9"XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(D%I;G5L="!E8F%V:6ES86MA9"!K:6QL=60B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS
M9W-T<B`B3'5B871U9"!O;B!A:6YU;'0@_&MS(&4M<&]S=&D@86%D<F5S<RXB
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*(DIA;R!O;6%N:6MK=2!V]6D@;VUA;FEK=2#U:6=U
M<VD@<V%A8B!M=75T82!A:6YU;'0@;VUA;FEK(';U:2!S_'-T965M:2`B"B)A
M9&UI;FES=')A871O<BXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM
M<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B079A('5U97,@
M86MN87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T
M-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T
M82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B3W!E;E-33"!V
M:6=A.B!!;F1M971E(&5R86QD86UI;F4@86QL:VER:F%S=&%T=60@4R]-24U%
M(&]S87-T(&YU<FIU<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B079A8B!S96QL92!L:6YG:2!U
M=65S(&%K;F%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED
M(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(D]P97)A='-I;V]N:7/\<W1E
M96TB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(E-E861E9"(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")396%D:7-T=7,Z
M("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(DYU;6UE<F1A='5D
M(&QO971E;'4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A='-I
M;V]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*
M;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B06QL_&MS=7,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A
M;FEZ:6YG(@IM<V=S='(@(DEN9F\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`B4F%K96YD=7-E(&%L9VYE(&UA;&PB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z(@IM<V=S='(@(D%L9W-E9"!M86QL:60@:V%T86QO;V=I
M<R`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M375U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H
M97(@26YF;W)M871I;VXB"FUS9W-T<B`B375U(&EN9F\B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")/;6%N:6MU(/5I9W5S960B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")004T@875T96YT:6UI;F4@96D@
M;VQE('-A861A=F%L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM
M<V=S='(@(E!%05(Z.DUA:6P@='5G:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R
M92(*;7-G<W1R(")01U`@9&EG:71A86QA;&QK:7)I(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(E!'4"!K<OQP=&ET=60@86YD;65D(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,W,0IM<V=I9"`B4$=0(%!U
M8FQI8R!+97DB"FUS9W-T<B`B4$=0(&%V86QI:R!V]71I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`@86QL:VER:F%S=&%T=60O
M:W+\<'1I='5D(&%N9&UE9"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM
M<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(&MO;V0B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@
M:^1S=7)I9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")03"!K97)G
M92!V:6AM(@H*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B4$P@=FEH;2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED
M(")032!3:&]W97)S(@IM<V=S='(@(E!,(&AO;W9I:&UA9"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3
M;F]W(@IM<V=S='(@(E!,(&QU;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(E!,('1I:&4@;'5M97-A9'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@
M(E!,('#D:6ME(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E!,(.1I:V5S
M971O<FTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")0
M3U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")03U-)6"!L86EE
M;F1U<R!P=75D=6(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@
M4VAE;&PB"FUS9W-T<B`B4%](4"!KY'-U<FED82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A
M9&1I;F<B"FUS9W-T<B`B5.1I9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A
M:VES=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I
M9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A
M;&5S=&EI;F$@;VMU<&5E<FET=60@=&5R<FET;V]R:75M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A87!U82!5
M=7,M1VEN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G
M<W1R(")087)A9W5A:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(E9A
M:&5L9'5V('!I;'9I<W5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4V%L
M87/U;F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G
M:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")3
M86QA<_5N82!M=75D971U9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R(")686QE('-A;&%S]6YA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R
M861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!
M1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4D%$2553(&%U=&5N=&EM
M:7-E:W,@;VX@=F%J86QI:R!S86QA<_5N82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")386QA<_5N82!K:6YN:71U<V5G82(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM
M<V=S='(@(E-A;&%S]6YA.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E-A;&%S]6YA.B`B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U
M"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B4V%L87/U
M;F%D('!E879A9"!K;&%P<&EM82XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B07-E=&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")0
M87-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")!<V5T82!L]6EK97!U:'9R
M:7-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R(")!<W5K;VAT(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P
M<SHB"FUS9W-T<B`B3V]T96P@;&EI='5M:7-S;V]V:60Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B26YI
M;65S960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")0<F]T<V5N=&DB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM
M<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@
M(DOD:79I=&$@:&]O;&1U<W3V]F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_(@IM<V=S='(@(E1E92!S:7-S96QO9VEM:7-E;"!H;V]L9'5S
M=/9I9"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(")097)M:7-S:6]N(@IM<V=S='(@(M5I9W5S(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S
M:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`BU6EG=7-T(%PB)7-<
M(B!E:2!K=7-T=71A='5D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")*=75R
M9&5PY.1S(&ME96QA='5D(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G
M:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(M5I9W5S960B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("+5:6=U<W1E(&AA;&1U<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B
M27-I:VQI:R!I;F9O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S
M='(@(E!E<G5U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED
M(")0971S(@IM<V=S='(@(DQE;6UI:VQO;VUA9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I:6YI9"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@
M(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<X"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;V0B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4&EK<VQI="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R
M(")-]71T971U<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL(@IM<V=S='(@(DML]7!S82!M]6YD82!L86AT<FES<V4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B2VEN;FET82!E="!S;V]V
M:60@<V5L;&4@96QE;65N9&D@965M86QD861A.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(*;7-G<W1R(")+:6YN:71A(&5T('-O;W9I9"!S96QL92!E;&5M
M96YD:2!L86AT:2#\:&5N9&%D82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R(")3:7-E<W1A(&MU=2!J82!A87-T82XB"@HC.B!T96UP
M;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS
M9W-T<B`B4VES97-T82!S96QL92!U=64@:V%T96=O;W)I82!N:6UI.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E-I<V5S=&$@:V]R
M<F5K=&YE($E0(&%A9')E<W,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M4VES97-T82!K;W)R96MT;F4@:W5U<.1E=BP@:V]N=')O;&QI('#D979A9&4@
M87)V=2!K=75S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E-I
M<V5S=&$@:V]R<F5K=&YE(&%E9RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@
M;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(DMI<FIE;&1A('!R;V)L965M:2XB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E-I<V5S=&$@;VUA(&MA
M<W5T86IA;FEM:2!J82!S86QA<_5N82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN
M9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@
M=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB3&]E(&KD<F=N978@=&5K<W0@
M;.1B:2X@4_QS=&5E;6D@:V%S=71A;6ES96MS(%!%040@=&EN9VEM=7-T96=A
M(&[U=7-T=6UA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(DMI<FIU=&$@=75E(&MA=&5G;V]R:6$@
M;FEM:3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0
M;V]L82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B4&]L:6ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B2_QS:71L=7-E
M9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O
M<G1U9V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(@IM<V=S='(@(E-E;&QE('!I;&1I('!A:6=U='5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@
M(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B4V5L;&4@=&%B
M96QI('!A:6=U='5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")+:7)J=71A('-E;&QE<W-E(&MA
M=7-T82`H24U!4"!E:2!K;VYT<F]L;&DI(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B
M"FUS9W-T<B`B5FEI;6%S92`E<R!T=6YN:2!S861E;65D.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(E-A9&5M971E/&)R("\^=/5E;N1O
M<W5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS
M9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z(%9A:F%L:6MK=2!,1$%0(&QA
M:65N9'5S="!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S
M7W-E<W-I;VXZ(%9A:F%L:6MK=2!S97-S:6]N(&QA:65N9'5S="!E:2!L96ET
M=60N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S
M=7)E(@IM<V=S='(@(M5H=7+U:&LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B
MU6AU<O5H:R!M97)E<&EN;F%L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`BU6AU<O5H
M:SHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")%96QV86%D
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(E!I;&1I(&5E;'9A861E('5U97,@86MN87,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T
M:6]N<R(*;7-G<W1R(")%96QM:7-E9"!S96%D960B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D
M;V-U;65N="(*;7-G<W1R(")4<OQK:2!D;VMU;65N="(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB
M"FUS9W-T<B`B4V%L86IA;F4@=O5T:2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O
M8FQE96TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R
M;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE96UI(&MI<FIE;&1U
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R
M;VIE8W1S(@IM<V=S='(@(E!R;VIE:W1I9"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@
M=&5X="(*;7-G<W1R(")396QG:71A=B!T96MS="(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G
M<W1R(")!=F%L:6L@=O5T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R(")!=F%L:6MU(';U=&UE(&%L9V]R:71M(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF
M;R(*;7-G<W1R(")!=F%L:6MU(';U=&UE(&EN9F\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@
M(E;U=&UE<&%A<FD@9V5N97)E97)I;6EN92!E:2#U;FYE<W1U;G5D+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T
M;W)I:6MO(@H*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(DMU<W1U
M=&%T=60@:VER:F%D92!E96UA;&1A;6EN92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")0Y')I;F<B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(E!I
M:7)A;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET
M*2(*;7-G<W1R(")24T$@879A;&EK(';U=&D@*"5D(&)I='1I*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R(")686QI:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@(E9I:&TB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")(;VUM:6MU;"!V:6AM(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@
M(E)A:6X@3&%T92(*;7-G<W1R("+5:'1U;"!V:6AM(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO
M=V5R(@IM<V=S='(@(DAO;W9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G
M<W1R(")6:6AM(&IA(&QU;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@
M(E9I:&T@:F$@;'5M:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS
M9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(")*=6AU<VQI:R!K:6QD(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I
M;R(*;7-G<W1R(")0<F]T<V5N="(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(DQO92(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED
M(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DQO92!K:7)J=2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+B(*;7-G<W1R(")+87,@=/5E<W1I(&MU<W1U=&%D82`E<S\@
M4V5E('1O:6UI;F<@;VX@</;V<F1U;6%T=2XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B2V%S('3U97-T:2!K=7-T
M=71A9&$@:V%S=71A:F$@)7,@86YD;65D/R!3964@=&]I;6EN9R!O;B!P]O9R
M9'5M871U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S
M='(@(E1A87-T86(@=FEI;6%S92!T96=E=G5S92(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED
M(")2969R97-H(@IM<V=S='(@(E;D<G-K96YD82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.B(*;7-G<W1R(")6Y')S:V5N9&$@9/QN86%M:6QI<V5D(&UE;OS\
M(&5L96UE;F1I9#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS
M9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")6Y')S:V5N9&$@
M<&]R=&%A;&D@=F%A9&4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G
M=6QA87)A=F%L9&ES(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T
M.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B4W5H971E
M('-I<G9I:F$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B
M"FUS9W-T<B`B3&%E('5U97-T:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(DWD<FMU<V5D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B
M"FUS9W-T<B`B5N1L:7-E9"!S97)V97)I9"(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E;D;&EN92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D5E;6%L9&$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E
M;6]V92!";&]C:R(*;7-G<W1R(")%96UA;&1A(&)L;VMK(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M
M;W9E(&-O;'5M;B(*;7-G<W1R(")+=7-T=71A('9E97)G(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M
M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B165M86QD82!K=6IU;F1U<R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@
M<&%I<B(*;7-G<W1R(")%96UA;&1A('!A87(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2W5S='5T
M82!S86QV97-T871U9"!S:W)I<'0@<V5R=F5R:2!A:G5T:7-E<W0@:V%T86QO
M;V=I<W0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D5E
M;6%L9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0B"FUS9W-T<B`B165M86QD82!D;VMU;65N9&ES="(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E
M;6]V92!U<V5R(@IM<V=S='(@(DMU<W1U=&$@:V%S=71A:F$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(DMU<W1U=&$@:V%S=71A
M:F$Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*
M;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D
M(&5R<F]R8V]D93H@(@IM<V=S='(@(E#D<FEN9W5L92!P;VQN=60@=O5I;6%L
M:6L@=F%S=&%T82X@5&%G87-T871I('9E86MO;V0Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B4V]O=FET879A="!T
M965N=7-T(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")686IA;&EK(%PB)7-<(B!P
M=75D=6(@)7,@<V5A9&ES='5S97,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!6
M1E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5F%J86QI:R!<(B5S7"(@<'5U
M9'5B(%9&4R!S96%D:7-T=7-E<RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL
M+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5F%J
M86QI:R!<(B5S7"(@<'5U9'5B('-E861I<W1U<V5S+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@
M1FEE;&0B"FUS9W-T<B`B2V]H=7-T=7-L:6L@=N1L:2(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")4_&AJ96YD82(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E
M="!087-S=V]R9"(*;7-G<W1R(")-=75D82!S86QA<_5N82(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A
M<W-W;W)D(@IM<V=S='(@(E5N=7-T87-I;B!O;6$@<V%L87/U;F$B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B5&%A<W1A(&5E;&UI;F4@<.1R:6YG(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B5'5L96UU
M<V5D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N
M<R(*;7-G<W1R(")486=A<VD@<V5A9&ES='5S<V4B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O
M<F0B"FUS9W-T<B`B2V]R9&$@=75T('-A;&%S]6YA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X
M"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")6]71A(&MO
M;F9I9W5R871S:6]O;B!T86=A<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,R"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T
M<B`B4FEC:"!497AT($5D:71O<FD@<V5A9&ES='5S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(DWU:7-T
M871U<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")087)E;2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R(")087)E;2!PY&ES(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(E!A
M<F5M860@=N3D<G1U<V5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B7U)E82!S96%D960N+BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM
M<V=S='(@(E)O;&PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM
M<V=S='(@(E)U;65E;FEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")0
M]O9R82`Q.#`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")0]O9R82!V
M87-A:W5L92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")0]O9R82!P
M87)E;6%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@
M(E)E82!S96%D960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R(")296$@<V5A9&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)I9'4Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B2F]O;F5D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM
M<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@
M8V]L=6UN<R(*;7-G<W1R(")*;V]N960@=&5K:79A9"!K]6EG:2!R:61A9&4@
M:F$@=F5E<F=U9&4@=F%H96QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B2F]O;F5D('1E
M:VEV860@86EN=6QT('9E97)G=61E('9A:&5L92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(DIO
M;VYE9"!T96MI=F%D(&%I;G5L="!R:61A9&4@=F%H96QE(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(DOD:79I=&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS
M9W-T<B`B5F5N92!&]F1E<F%T<VEO;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@:W+\<'1O9W)A869I;&EN
M92!A;&QK:7)I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R
M(")3+TU)344@:W+\<'1I='5D(&MI<FDB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@875T96YT:6UI;F4@96D@
M;VQE('-A861A=F%L+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3(&S\:&ES]6YU
M;6ED(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE
M;&PB"FUS9W-T<B`B4U%,(&OD<W5R:61A(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<R(*;7-G<W1R(")344P@879A;&1I<R!VY.1R='5S=&4@;&5I9&UI
M<V5K<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@
M(E-32"(*;7-G<W1R(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")3
M54-#15-3(@IM<V=S='(@(M5.3D535%53(@H*(SH@;&EB+V%P:2YP:'`Z,34S
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@:^1S=7)I9&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS
M9VED(")382(*;7-G<W1R("),82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A
M:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN
M="!+:71T<R!J82!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@
M3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT
M(%!I97)R92!J82!-:7%U96QO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A
M:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT
M(%9I;F-E;G0@:F$@1W)E;F%D:6EN:60B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?
M<V5L9BDB"FUS9W-T<B`B4V%M87,@<F%A;6ES("A?<V5L9BDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*
M;7-G<W1R(")386\@5&]M92!J82!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R(")3871E;&QI:71S:61E(&MA<W5T86IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I($%R86%B
M:6$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@
M(E-A=F4B"FUS9W-T<B`B4V%L=F5S=&$@(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M(%PB)7-<(B(*;7-G<W1R(")386QV97-T82!<(B5S7"(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E("5S(@IM<V=S='(@(E-A;'9E<W1A("5S(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-A
M;'9E<W1A('-E861I<W1U<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-C<*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@HB4V%L=F5S=&$@9V5N97)E97)I='5D(&MO
M;F9I9W5R871S:6]O;B!02%`@<VMR:7!T:6YA('-E<G9E<FD@86IU=&ES<V4@
M(@HB:V%T86QO;V=I+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B5S(&MO;F9I9W5R871S:6]O;B!S86QV97-T871U9"XB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R(")086EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T('-A;'9E<W1A
M='5D(&9A:6QI.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*
M;7-G<W1R(")(86IU<V%D(.1I:V5S:&]O9"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")496%D=7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@
M(D]T<VEN9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(D]T<VEN9W5M;V]T;W)I9"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C
M="!&:6QE<R(*;7-G<W1R(")686QI(&9A:6QI9"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`B5F%L:2!K=75PY&5V(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D
M9"(*;7-G<W1R(")686QI(&QI<V%T878@9W)U<'`B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B
M"FUS9W-T<B`B5F%L:2!U=7,@;VUA;FEK(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T
M<B`B5F%L:2!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5F%L
M:2!L:7-A=&%V(&MA<W5T86IA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R
M(")686QI(&OU:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8S
M"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B
M5F%L:2!K]6EK(&MU=7#D979A(&MO;W-T:7-O<V%D+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C
M="!A;B!O8FIE8W0B"FUS9W-T<B`B5F%L:2!O8FIE:W0B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED(")396QE
M8W0@;F]N92(*;7-G<W1R("+$<F$@=F%L:2!M:61A9VDB"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R(")686QI('9A:F%L:6MU9"!MY')G:60@:V%S=&ED97-T+B!3
M:6ES('-A860@;F5E9"!K;W!E97)I9&$@:VER:F$@<VES<V4N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z(@IM<V=S='(@(E9A;&D@:W5U<.1E=F$@97)A;&1A:F$Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C
M="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E9A;&D@:W5U<.1E=F$@97-I
M='5S=FEI<SHB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93HB"FUS9W-T<B`B5F%L:2!I9&5N=&ET965T(&UI9&$@<V]O=FED
M(&UU=71A.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")686QI(&ME
M;&QA86IA(&5R86QD86IA.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC
M.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")6
M86QI(&ME;&QA86IA(&5S:71U<W9I:7,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(E9A;&D@:V%K<R!S;V)I=F%T(';D;&IA+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O
M;&]R('-C:&5M92XB"FUS9W-T<B`B5F%L:2!VY')V:7-K965M+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B5F%L:2!O;6$@;&5M;6EK:V5E
M;#HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I
M9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")386%D82!P<F]B;&5E
M;6D@:VER:F5L9'5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E-A861A
M(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B
M4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V"FUS9VED(")3
M96YS;W(Z("(*;7-G<W1R(")396YS;W(Z("(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B4V5P=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G
M<W1R(")397)B:6$@:F$@36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM
M<V=S='(@(DKD<FIE;G5M8F5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B4V5R=F5R:2!A;F1M960@;VX@=F%L960@=O5I
M('!U=61U=F%D+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B
M4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")397-S:6]O;FED92!H86QD=7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B4V5S<VEO
M;VYI($E$(&]N(&%E9W5N=60N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED
M(")397-S:6]N<R(*;7-G<W1R(")37V5S<VEO;VYI9"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R(")(=6QK
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T
M:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y
M;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DWDY')A(&%N9&UE9"!M
M:7,@=O5I;6%L9&%V860@<W5L(&]M82!P87)O;VQI(.1R82!M=75T82!K=6D@
M<V$@<V5L;&4@=6YU<W1A9"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N
M="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B4V5A9&ES
M=&$@=N1L:7-E9"!S97)V97)I9"!M:61A('-O;W9I9"!O;6$@<&]R=&%A;&ES
M(&MA<W5T861A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I
M9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+B(*;7-G<W1R(")086YE('!A:6MA(&]M82!K965L92P@
M86IA=O;V;F1I(&IA(&MU=7#D979A('-E861I<W1U<RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)-Y.1R
M82!O;6$@86QG<F%K96YD=7,L(';D<G9I<VME96TL(&QE:&5K_&QJ92!VY')S
M:V5N9&%M:7-E('-A9V5D=7,@:F$@;75U9"`@(@HB97-I='5S92!S96%D960N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B
M"FUS9W-T<B`B4&%I9V%L9'5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A
M=F%I;&%B;&4B"FUS9W-T<B`B3VQE;6%S;VQE=F%D('!A:6=A;&1U<V4@=75E
M;F1A;6ES92!S:W)I<'1I9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(E!A<F%M965T97(@;>3D<F%B
M(&UI='4@=O5I;6%L:6MK=2!A<W5K;VAT83H@(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")396ES:&5L;&ED(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS
M9W-T<B`B3W-T;&5M:6YE(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B3/QH:6MO
M:VMU=O5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@
M(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/R(*;7-G<W1R(")+87,@96YA;75S96QE(&QI;FMI9&5L92!T=6QE:W,@;>3D
M<F%T82!K:6ER:VQA:'9I9#\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(").Y&ET82(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3N1I=&$@
M;VQE;6%S;VQE=F$@:F$@Y'-J82!G96YE<F5E<FET=60@:V]N9FEG=7)A='-I
M;V]N:2!E<FEN979U<VDN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y
M,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/R(*;7-G<W1R(").Y&ET82!S:7-S96QO9VEM:7-E;"!E96QM:7-E('-I<W-E
M;&]G:6UI<V4@865G82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T
M<B`B4&%K=2!V]6EM86QU<W0@;W)I9VEN86%L:2!SY&EL:71A;6ES96MS(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO=R!P
M:6-K97(B"FUS9W-T<B`B3N1I=&$@=F%L:6IA="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\B"FUS9W-T<B`B3N1I=&$@=&%B96QI=&]I;6EN9W5T92!M96[\
M_')I8F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM
M<V=S='(@(D[D:71A('9A<V%K=6P@)7,@;65N_/QD(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED
M(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(D[D:71A('1A8F5L:2!L86AT<FD@;VUA9'5S=&4@9&EA;&]O9VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(D[D:71A('1A8F5L:2!O;6%D=7-T92!D:6%L;V]G:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(D[D:71A('1A8F5L:2!R96$@;VUA9'5S=&4@9&EA;&]O
M9VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(D[D:71A('!I;&1I(&]M861U<W1E(&1I86QO;V=I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO
M=R!U<&QO860B"FUS9W-T<B`B3N1I=&$@=7!L;V%D:2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(DAO;W9I:&TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R
M(")(;VUM:6MU;"!H;V]V:6AM860B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S
M='(@(M5H='5L(&AO;W9I:&UA9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I
M;FET>2(*;7-G<W1R(")(;V]V:6AM860@_&UB<G5S:V]N;F%S(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I
M;FLB"FUS9W-T<B`B2VET<V5N9&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY.#0*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`T-R!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S
M='(@(DMI='-E;F1A(&OU:6=E<&5A;'0@;F%A8F5R8FQO:VME(';U:2!N:6AU
M=&$@;F5E9"!E97-T(.1R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R
M82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(DQI:71U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")!;&QK:7)I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I
M9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QL:VER:F$@86QG;W)I=&TB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN
M9V%P=7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED
M(")3:7IE(@IM<V=S='(@(E-U=7)U<R(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA
M;F-E(@IM<V=S='(@(DKD=&$@:&]O;&1U<R!V86AE;&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]V86MK:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V965N:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM
M<V=I9"`B4VYO=R(*;7-G<W1R("),=6UI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM
M<V=S='(@(E1I:&4@;'5M97-A9'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(E1I:&5D860@;'5M97-A:G5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L
M>2(*;7-G<W1R(")(;VUM:6MU;"!T:6AE9&%D(&QU;65S86IU9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("+5:'1U;"!T:6AE9&%D(&QU;65S
M86IU9"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W
M(&1E<'1H.B`B"FUS9W-T<B`B3'5M92!P86MS=7,Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z("(*;7-G<W1R("),=6UE('9E92UE:W9I=F%L96YT.B`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B4V%A;&]M
M;VYI('-A87)E9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS
M9W-T<B`B4V]M86%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*
M;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B3&%U;'5D(&IA(&QU=6QE
M='5S960B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED
M(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R(")3;W)T965R:6UI<VKD
M<FIE:V]R<F$@=F%L:6LB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R("),Y&AT96%A9')E<W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B3/5U;F$M06%F<FEK82(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RDB"FUS9W-T<B`B3/5U;F$M175R;V]P82`H25-/+3@X-3DM
M,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(DSU=6YA+4=E;W)G
M:6$@:F$@3/5U;F$M4V%N9'=I8VAI(%-A87)E9"(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H
M97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B3/5U;F%P;V]L:V5R82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED
M(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E9A:&4@
M;&%H=')I=&4@=F%H96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT
M(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")686AE(&QA:'1R:2!S:7-U
M(&IA(.3D<F4@=F%H96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M,34*;7-G:60@(E-P86-E<B(*;7-G<W1R(")%<F%L9&%J82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R(")686AE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN
M9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")686AE9"!J82!V;V]D97)D=7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B2&ES<&%A;FEA(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M(@IM
M<V=S='(@(E+D;7!S<&]S="(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ
M-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B17)I
M;>1R:VED92!S:7-E<W1U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS
M9W-T<B`B17)A;&1A(&QA:'1R:60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B3&%H=71A('9E97)G(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(DQA:'5T82!R:61A(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A
M<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@
M5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B06QG=7-A87-T82(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O
M<B!0<F]V:6YC92(*;7-G<W1R(")/<V%R:6EK(';U:2!M86%K;VYD(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T
M871U<R(*;7-G<W1R(")/;&5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B4V%L=F5S
M='5S9F]R;6%A="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<R"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")4Y&YA=B!J
M82!M86IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("),Y&)I:F]O
M;FET=60@=&5K<W0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")3=')I;F=I9&4@;&]E;F0B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I
M<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")%<F%L9&$@9&]M
M965N(&%A9')E<W-I<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G
M<W1R(")3=&EI;"!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(E#\(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")!;&%M
M:V%T86QO;V=I(%PB)7-<(B!E:2!L96ET=60N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R(")4965M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@
M(E-U8FUI="(*;7-G<W1R(")+:6YN:71A(@H*(SH@<VEG;G5P+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A
M9&0@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U
M;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S
M='(@(B(*(E-O;W8@7"(E<UPB(&QI<V%M:7-E:W,@<_QS=&5E;6D@;VX@<V%L
M=F5S=&%T=60N(%-A(&5I('-A82!S:7-S92!L;V=I9&$@96YN92`B"B)K=6D@
M<VEN=2!S;V]V(&]N(&AE86MS(&MI:61E='5D+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R(")!;&%I;F1E:W,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B
M3.1K<R!K;W)D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&]N('/\<W1E96UI(&QI<V%T=60N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&%N9&UE9"!O;B!S_'-T965M
M:7-T(&5E;6%L9&%T=60N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&]N
M(&MU<W1U=&%T=60N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!O;B!S_'-T965M:7-T(&5E
M;6%L9&%T=60N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A='-I;V]N
M(&]N('1A9V%S:2!V]65T=60N($UU=71U<W1E(&[D9V5M:7-E:W,@=N1R<VME
M;F1A('9A861E="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG=7)A
M='-I;V]N:2!V87)U:V]O<&EA(/5N;F5S='5S('-A;'9E<W1A9&$N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(DMO;F9I9W5R871S:6]O;FEF86EL:2!V87)U
M:V]O<&EA("5S(/5N;F5S='5S('-A;'9E<W1A9&$N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U
M<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@;75U=&UI;F4@]6YN97-T
M=7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY('=R;W1E("5S(@IM<V=S='(@(B5S(&MI<FIU=&%M:6YE(/5N;F5S='5S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D86%N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3:7-U:V]K:W5V]71E
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R(")0Y&EK97-E=/5U<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")0Y&EK97-E;&]O:F%N
M9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y
M"FUS9VED(")3=6YN>2(*;7-G<W1R(")0Y&EK97-E<&%I<W1E;&EN92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I
M<V4B"FUS9W-T<B`B4.1I:V5S973U=7,B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I
M<V4O4W5N<V5T(@IM<V=S='(@(E#D:6ME<V5T]75S+VQO;VIA;F<B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E
M.B`B"FUS9W-T<B`B4.1I:V5S973U=7,Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R(")0Y&EK
M97-E;&]O:F%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(E#D:6ME<V5L;V]J86YG.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S
M"FUS9VED(")3=7!E<G-C<FEP="(*;7-G<W1R("+<;&%I;F1E:W,B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P;W)T(@IM
M<V=S='(@(E1U9VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*
M;7-G<W1R(")3=7)I;F%M:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E!E<F5K;VYN
M86YI;6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N
M($UA>65N(@IM<V=S='(@(E-V86QB87)D(&IA($IA;B!-87EE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=F%A<VEM86$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4F]O='-I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-H
M=F5I=',B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I
M9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3_&YK<F]N:7-E97)I;6ES
M92!L;V=I(&MU<W1U=&%T=60B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R
M;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(DMI<FIA=FEG82!O='-I;F=U
M=&EN9VEM=7-T97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A
M8B!297!U8FQI8R(*;7-G<W1R(")3_/QR:6$@07)A86)I82!686)A<FEI:R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS
M9VED(")4+5-T;W)M(@IM<V=S='(@(L1I:V5S971O<FTB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B5'5U;&EN92!J82#D:6ME<V5L:6YE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E0M4W1O<FUS(@IM<V=S='(@(L1I:V5S97!U:&%N9W5D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M
M4W1O<FUS($5A<FQY(@IM<V=S='(@(DAO;6UI:W5L(.1I:V5S97!U:&%N9W5D
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B
M5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&9A:6PB"@HC.B!F<F%M97=O<FLO54DO
M54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%B96PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E1A8F5L
M:2!O;6%D=7-E9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)E;&ET
M92!H=6QK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R
M(")486)E;&D@;VUA9'5S960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")486EW86XB"FUS9W-T<B`B5&%I=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@
M;V8@0VAI;F$B"FUS9W-T<B`B5&%I=F%N+"!(:6EN82!P<F]V:6YT<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%D>FEK
M:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E1A;G-A86YI82#<:&5N9'9A8F%R:6EK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")!=F%N96UI;F4Z(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")4]O9D(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N
M92!.=6UB97(B"FUS9W-T<B`B5&5L969O;FEN=6UB97(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B5FEI;6%S92!T=6YN:2!T96UP97)A='5U<CHB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T
M<B`B5&5M<&5R871U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T
M=75R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U=7(\8G(@+SXH)7--
M87@E<R\E<TUI;B5S*2`F9&5G.R5S(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA
M=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B36%L;&D@7"(E<UPB(&5I
M(&QE:71U9"XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B
M5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B36%L;&ED92!H86QD
M=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K
M<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT
M($]N;'DB"FUS9W-T<B`B06EN=6QT('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X
M="!A;&EG;B(*;7-G<W1R(")496MS=&D@:F]O;F1U<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T
M;W`B"FUS9W-T<B`B5&5X='1O<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(DYE(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV
M,C`I(@IM<V=S='(@(E1A:2`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R(")486DB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B5.1N86UE(&O\;&%S=&%M87-T+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")&5%`@;&%I96YD
M=7,@96D@;VQE('-A861A=F%L+B(*"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T
M96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAI<W1O<GD@<_QS=&5E;2!O;B!V
MY&QJ82!L_&QI=&%T=60N(@H*(R!P:'`M9F]R;6%T"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3,T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT
M96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S
M='(@(DAO<F1E+TMO;&%B(&EN=&5G<F%T<VEO;VYI;6]O=&]R(&5I('1O971A
M(%PB)7-<(BUI(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP
M:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET
M:6%L:7IE9"XB"FUS9W-T<B`B24U34"!L;V=I(&%L9W;DY')T=7-T86UI;F4@
M;G5R:G5S+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I
M9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>2(*;7-G<W1R(")-86EN=&5N86YC93HZ(&ML87-S:2!L86%D:6UI
M;F4@;G5R:G5S(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N(@IM<V=S='(@(E-E861E=&4@86ME;B!O;B!S=6QE='5D+B!6Y&QJ
M=6XN(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!0
M97)M:7-S:6]N<RXB"FUS9W-T<B`B(@HB2W5I('1A:&%D(&MA<W5T861A(/5I
M9W5S:2P@<&5A8B!A9&UI;FES=')A871O<B!S96%D:7-T86UA('#\<VEV82#U
M:6=U<W1E("(*(G/\<W1E96UI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@
M<VED92!O;FQY(@IM<V=S='(@(D%I;G5L="!A;'5M:6YE(&O\;&<B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM
M<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A
M=&%B87-E+B(*;7-G<W1R("(B"B)+;VYT86MT:2!)1"!N=6UB<FET(&5I(&WD
MY')A='5D+"!JY&5T:2!T_&AJ86MS(';U:2!S964@<'5U9'5B(&%N9&UE8F%A
M<VES+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2VER:F4@]6YN97-T
M=7,@;&ES861A('-I;G4@86%D<F5S<VER86%M871U<W-E+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D%L;&MI<FIA
M<W1A='5D(&MI<FIA(&MO;G1R;VQL:6UI<V5K<R!O;B!V86IA(&5R86QD:2!0
M1U`@86QL:VER:F%B;&]K:VDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T
M<B`B2F%O='5S;FEM96MI<FIA($E$(&]N(&WDY')A;6%T82P@:N1E=&D@=/QH
M:F%K<R!V]6D@<'5U9'5B(&%N9&UE8F%A<VES+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@
M(DIA;W1U<VYI;65K:7)I('!O;&4@;>3D<F%T=60N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(DMR_'!T:6UI<V5K<R!O;B!V86IA('1U<G9A;&ES="!(5%10(/QH96YD
M=7-T+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B1F%I;"`E<R!P96%K<R!S:7-A;&1A;6$@)7,@;>3D<F%N9W5T+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S
M='(@(D9A:6P@)7,@<&5A:W,@<VES86QD86UA(&UI;F=E:60@)7,@;>3D<F%N
M9W5I9"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G
M:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*
M;7-G<W1R(")&86EL:2!E:2!S86$@:V]P965R:61A(&ES965N9&%L92!O='-A
M+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D9A:6P@96D@<VES
M86QD86YU9"!A;F1M96ED+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM
M<V=S='(@(DKD<F=N979A9"!S96QL92!M97-S86=E+W)F8S@R,B!K:7)J82!P
MY&ES960N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO
M=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@
M9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7
M:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@
M)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R
M97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E
M96X@961I=&]R+B(*;7-G<W1R("(B"B)4Y&ES96MR86%N:7)E>FEI;6D@:V%S
M=71A;6EN92!T96MI=&%B('!R;V)L965M92!);G1E<FYE="!%>'!L;W)E<FES
M('3D;G4@(@HB<V5L;&4@=F5E8FEL96AI='-E:F$@=FEG861E;&4L(&UI9&$@
M;65I;"!E:2#U;FYE<W1U(&UA:&$@<W5R=61A+B!%<VEN961A("(*(G;U:6(@
M;.1B=2!K=6IU=&ES97,L(&5D:71O<FD@9G5N:W1S:6]O;FED92!P=75D=6UI
M<W0@:F$O=O5I('9E96)I;&5H:71S96IA("(*(FIU:'5S;&EK:W4@:VEN;FEJ
M;V]K<VUI<W0N($MU:2!S:6YU(&%R=G5T:2!O<&5R871S:6]O;FEK<R!O;B!7
M:6YD;W=S(#EX+"`B"B)S:6ES(&]N(';D9V$@=/5E;N1O;&EN92!E="!S86%D
M(%PB1V5N97)A;"!0<F]T96-T:6]N($9A=6QT7"(@=F5A=&5A=&4@:F$@(@HB
M<&5A9"!A<G9U=&D@=&%A<VOD:79I=&%M82Y<7&Y<7&Y3:6YD(&]N(&AO:6%T
M871U9"X@2VSU<'-A($]++"!K=6D@<V]O=FED("(*(G-I:7-K:2!TY&ES96MR
M86%N:7)E>FEI;6D@<')O;W9I9&$N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5E="!<(B5S7"(@
M;VX@:W5S='5T871U9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R(")!:6YU;'0@=F%S86L@:_QL9R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(D-R>7!T7W!G<#HZ(&ML
M87-S:2!J86]K<R!P96%B(&]L96UA(&WDY')A='5D($=N=5!'('!R;V=R86UM
M:2!A<W5K;VAT+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L
M87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)+
M:7)I(&UI<R!S86%D971I("5S(&%A9')E<W-I;&4@)7,@=&5E;6%G82!<(B5S
M7"(@;VX@879A='5D+EQN(@HB4V5E(&5I(&=A<F%N=&5E<FD@970@:VER:2!L
MY&)I(&QO971I(';U:2!S96QL97-T(&%R=2!S86%D:2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T;R!U<V4@
M=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3FEM
M:2!M:61A(&MA<W5T861A(&5D:71O<FD@;&5H96=A(&QI;FMI;6ES96PB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*;7-G:60@(E1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B5N1L
M:F%D92!A<G8@<&5A8B!O;&5M82!A<G8N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U
M;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L
M87-S+B(*;7-G<W1R(")(;W)D95]#<GEP=%]S;6EM93HZ(&ML87-S('9A:F%B
M(&]P96YS<VP@;6]O9'5L:70N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N
M8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A
M(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S
M='(@(B(*(D5E;&ES='5S="!<(B5S7"(@96D@]6YN97-T=6YU9"!S86QV97-T
M861A+"!K=6YA(&%N9&UE=&4@:'5L:R#\;&5T87,@<W5U<FEM82`B"B)L=6)A
M='5D(&WDY')A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP
M="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E
M<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P
M;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P
M+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H
M;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E
M>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R
M86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F
M;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)3961A('3\_'!I(&%N
M9&UE=&4@*"5S*2!V86%T86UI<V5K<R!V86IA;&EK:W4@<')O9W)A;6UI(&5I
M(&QE:71U9"!S_'-T965M:7-T+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E
M(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R(")*=71U;>1R:R!P96%B
M(&]L96UA(/QK<R!MY')K+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(D%I;G5L="!V87-A:R!J82!P87)E
M;2!K_&QG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(D%I;G5L="!P87)E;2!K_&QG(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D5R86QD86IA('!E
M86(@;VQE;6$@_&MS(&WD<FLN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R(%PB)7-<(B!O
M;B!K=7-T=71A='5D+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N('-A=F5D+B(*;7-G<W1R(")397)V97(@7"(E<UPB(&]N('-A;'9E
M<W1A='5D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N(@IM<V=S='(@(B5S(&QI:71U;6ES<V]O=B!O;B!E96UA;&1A='5D
M+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM
M<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S
M='(@(DWDY')A='5D(')I9&$@<&]L92!O;&5M87,N(@H*;7-G:60@(E1H92!S
M<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DWD
MY')A='5D(')I9&$@*"5D*2!P;VQE(&]L96UA<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")!:G5T:7-T(&9A:6QI(%PB)7-<(B!P;VQE(&]L96UA<RXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(E-I;G4@<VES97-T871U9"!T96MS="!E:2!K871T=2!E:W)A
M86YI;"!O;&5V86=A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O
M;2!S:61E<R!O;FQY(@IM<V=S='(@(D%I;G5L="#\;&5M:6YE(&IA(&%L=6UI
M;F4@:_QL9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S
M='(@(D%I;G5L="#\;&5M:6YE(&O\;&<B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")386%D971U9"!A
M;F1M960@;VX@=F%H97!E86P@:V%O='-I(&SD:6YU9"XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O
M='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO
M="!B92!S879E9"XB"FUS9W-T<B`B4V%A9&5T=60@9F%I;&D@96D@<V%A;G5D
M('-A;'9E<W1A9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")W96%T:&5R+F-O;2!B;&]K:R!E:2!O
M;&4@:^1T=&5S86%D878N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B2W5J=6YD=7-T92!K871A;&]O9VD@7"(E
M<UPB(&5I(&QE:71U9"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE
M+B(*;7-G<W1R(")%:2!O;&4@;6ED86=I('-E861I<W1A9&$N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`B2VER:F%L(&5I(&]L92!V86AE='5L="!E<VET871A=F%I9"!O
M<VDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B
M(@HB4V5L;&5S(';D;&IA<R!O;B!L:6EA;'0@<&%L:G4@;>1R:V4N(%-A('-I
M<V5S=&%S:60@)7,@;>1R:VD[(&QU8F%T=60@<&]L92`B"B)R;VAK96T@:W5I
M("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(EPB)7-<(B!L:7-A
M;6ES96P@<_QS=&5E;6D@=&5K:VES('!R;V)L965M.B`E<R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(DMA<W5T86IA(%PB)7-<(B!A;F1M971E
M('/\<W1E96UI<W0@965M86QD86UI<V5L('1E:VMI<R!P<F]B;&5E;3H@(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;3H@(@IM<V=S='(@(EPB)7-<(B!E96UA;&1A;6ES96P@<_QS=&5E;6ES
M="!T96MK:7,@<')O8FQE96TZ("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB(&UU=71M:7-E;"!T96MK
M:7,@<')O8FQE96TZ("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#@T"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"XB"FUS9W-T<B`B1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I<W-E('1E:VMI
M<R!P<F]B;&5E;3H@)7,@96D@;&%E='5D+B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ
M92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)&86EL:2!L86%D:6UI<V5L('-E
M<G9E<FES<V4@=&5K:VES('!R;V)L965M.B`E<R!O;&D@<W5U<F5M(&MU:2!V
M]6EM86QD86(@(@HB<&EI<F%N9R`H)60@8F%I=&DI+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R
M("(B"B)&86EL:2!L86%D:6UI<V5L('-E<G9E<FES<V4@=&5K:VES('!R;V)L
M965M.B`E<R!L865T:2!A:6YU;'0@;W-A;&ES96QT+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM
M<V=S='(@(E-E;&QE(&MI<FIA(&]S82!E<VET86UI<V5L('1E:VMI<R!V:6=A
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C
M="!D871A+B(*;7-G<W1R(")+;VYT86MT86YD;65T92!I;7!O<G1I;6ES96P@
M=&5K:VES('9I9V$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP
M.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82XB"FUS9W-T<B`B:4-A;&5N9&%R)VD@86YD;65T92!I
M;7!O<G1I;6ES96P@=&5K:VES('9I9V$N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(E-E861I<W1U<V4@=F]R
M;6EL(&5S:6YE<R!V:6=A+B!%:&L@:N1T<VED('3D:71M871A(&WU;F4@:V]H
M=7-T=7-L:6MU(';D;&IA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@HB4V]O=FET=60@86%D<F5S<VER86%M871U(&]P97)A='-I;V]N:2!S;V]R
M:71A;6ES96P@=&5K:VES('9I9V$N(%!A;'5N('!R;V]V:2`B"B)H:6QJ96T@
M=75E<W1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B2V]N=&%K=&%N9&UE=&4@=75E;F1A;6ES96P@=&5K
M:VES('9I9V$N(%!A;'5N('!R;V]V:2!H:6QJ96T@=75E<W1I+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")*
M86]T=7-N:6UE:VER:F$@=75E;F1A;6ES96P@=&5K:VES('9I9V$N(%!A;'5N
M('!R;V]V:2!H:6QJ96T@=75E<W1I+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E
M<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B
M4V5E($E-05`@<V5R=F5R(&5I(';U:6UA;&1A(&MA=7-T861E(&IA9V%M:7-T
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N(@IM<V=S='(@(E-E92!E:2!NY&D@;VQE=F%T(&MO<G)A;&EK
M(%)!4B!A<FAI:78N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B4V5E(&5I(&[D:2!O;&5V870@
M:V]R<F%L:6L@6DE0(&9A:6PN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L
M:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(E-E92!E:2!NY&D@;VQE=F%T(&ME
M:'1I=B!K86%R9&D@;G5M8F5R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB4V5E(&1R86EV97(@=O5I
M;6%L9&%B('-A871A('/U;G5M96ED(&SD8FD@0VQI8VMA=&5L;"`H:'1T<#HO
M+V-L:6-K871E;&PN8V]M*2`B"B)L_/QS:2P@:V%S=71A9&5S($A45%`@05!)
M="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB4V5E(&1R
M86EV97(@=O5I;6%L9&%B('-A871A('/U;G5M96ED(&SD8FD@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@;/S\<VDL("(*(FMA<W5T861E<R!(5%10($%0270N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M
M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"B)3964@9')A:79E<B!V]6EM86QD86(@<V%A=&$@<_5N=6UE:60@
M;.1B:2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2`B"B)L_/QS
M:2P@:V%S=71A9&5S($A45%`@05!)="XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@
M=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T
M;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O
M=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2XB"FUS9W-T<B`B(@HB4V5E(&1R86EV97(@=O5I;6%L9&%B('/U;G5M:71E
M('-A871M:7-T(%--5%`@<')O=&]K;VQL:6=A(&SD8FD@5F]D869O;F4@(@HB
M271A;'D@;/S\<VDL(&%I;G5L="!6;V1A9F]N92!N=6UB<FET96QE+B!396QL
M96MS(&]N('9A:F$@5F]D869O;F4@271A;'D@92TB"B)P;W-T:2!K;VYT;W0@
M*&AT='`Z+R]W=W<N,3DP+FET*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@
M9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(E-E92!VY&QI(&]N(&MO:'5S
M='5S;&EK+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS
M9W-T<B`B4V5E(';D;&D@=O5I8B!S:7-A;&1A9&$@=F%I9"!TY&ES87)V92XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R(")3964@=N1L:2!V]6EB('-I<V%L9&%D82!A:6YU;'0@;G5M
M8G)E:60@:F$@:V]O;&]N:70N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C
M=&%L('9A;'5E<RXB"FUS9W-T<B`B4V5E(';D;&D@=O5I8B!S:7-A;&1A9&$@
M86EN=6QT(&MA:&5K<V%N9&%R=F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@
M;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B
M4V5E(';D;&D@<&5A8B!O;&5M82!K;VUA9V$@=O5I('3\:&EK=6=A(&5R86QD
M871U9"!TY&ES87)V=61E(&QO96YD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(E-E92!VY&QI('!E86(@;VQE;6$@:V]R<F5K=&YE
M(&%R=BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED
M("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N
M(@IM<V=S='(@(E-E92!VY&QI('!E86(@<VES86QD86UA(';D<G9I:V]O9&D@
M4D="($AE>"!K=6IU;"P@;N1I=&5K<R`G(S$R,S1A9B<N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(E-E92!V;W)M(&]N(&IU
M8F$@;.1B:2!T]O9T871U9"XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI
M;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R
M(")3964@;VX@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@
M;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@
M2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M
M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(E-E
M92!O;B!+;VQA8B!'<F]U<'=A<F4@;V)J96MT+B!396QL92!O8FIE:W1I('9A
M871A;6ES96MS('9A:F%D(&4M<&]S=&D@(@HB:VQI96YT:2!M:7,@;?5I<W1A
M8B!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A=&DN(%-E;&QI<W1E(&4M<&]S=&D@
M:VQI96YT:61E("(*(FYI;65K:7)J82!L96EA9"!A861R97-S:6QT("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A
M(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G
M<W1R(")3964@:VER:2!O;B!K:7)J=71A='5D(&WD<F=I<W1I:W5S("@E<RD@
M;6ES(&5R:6YE8B!S:6YU(&]M87-T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B4V5E(&%R=B!P96%B(&]L96UA(';D:&5M
M86QT(/QK<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII
M<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")3964@<V5R=F5R(&5I(&WU
M:7-T82!L86AT:2!P86MK:61A('II<"!J82!G>FEP(&9A:6QE+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(E-E92!S_'-T965M(&]N('!R865G=2!VY&QJ82!L_&QI=&%T=60N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B4V5L;&4@:V]H82!P
M96%L('!E86(@;VQE;6$@87)V+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B4V5E(&%K96X@
M='5L96(@879A9&$@4V5A9&5T92!A:VYA<W0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G
M<W1R("+$:6ME(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM
M<V=I9"`B5&EC:V5T<R(*;7-G<W1R(")(96QP9&5S:R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"FUS9VED(")4:6UE(@IM<V=S='(@(D%E9R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS
M9W-T<B`B5/;V86IA=&%B96PB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*
M;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D%J82!E<VET=7,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C
M=&EO;B(*;7-G<W1R(")!:F$@=F%L:6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4:6UO<BU,97-T92(*;7-G<W1R("))9&$M5&EM;W(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")096%L:VER:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*
M;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B4&5A;&MI<FD@*'1O
M;VQT:7`I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B2V5L;&5L92(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*
M(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI
M;F<N(@IM<V=S='(@(B(*(DUI=&UE(&]B:F5K=&D@=F%L:6UI<V5K<R!H;VEA
M(&%L;"!#=')L("A00RD@=O5I($-O;6UA;F0@*$UA8RD@:VQA:'9I(&IA("(*
M(FML]7!S82!O8FIE:W1I9&5L+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(E3D;F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED
M(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B2%1-3"!K;V]D:2!R97II
M:6TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L
M874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED
M(")4;VUO<G)O=R(*;7-G<W1R(")(;VUM92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G
M:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*;7-G:60@(E1O;R!M86YY(&EN
M=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R
M(")6:6EM87-T96P@;6EN=71I=&5L(&]N(&QI:6=A('!A;&IU(&YU<FIU;G5D
M('-I<W-E;&]G:6UI<VDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`BW&QE
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B4&5A;&UI<V5S
M(')A86UI<R`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*
M;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4]6QK960B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R
M:6YI9&%D(&IA(%1O8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5/5D92!V]6D@
M=F%L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(E1E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YE97-I82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R(")4_')G:2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*
M;7-G<W1R(")4_')G:2`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM
M<V=S='(@(E1U<FMS(&IA($-A:6-O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M2VER:G5T82!O;6$@=F%L:6LZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E56+6EN
M9&5K<SH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B4VEN=2!S:W)I<'1I(&OD
M='1E=&]I;65T86UI<W)A<&]R=&D@55),(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),.B(*;7-G<W1R
M(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@
M(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T
M<B`B56MR86EN82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q
M,@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(")%:2!PY.1S92!L:6=I(%9&4R!K871A;&]O9VEL92XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M(@IM<V=S='(@(E3D:65N9&%V82!K87-U=&%J86EN9F\@;&ES86UI;F4@;&EI
M='5M:7-E;"!E:2#U;FYE<W1U+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%
M:2!S86$@;75U=&$@5D93(&9A:6QI(%PB)7-<(B#U:6=U<VDN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T
M<B`B16D@<V%A(&UU=71A(%9&4R!F86EL:2`E<R\E<R#U:6=U<VDN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B16D@<V%A
M(&UI;FYA(&MA=&%L;V]G:2`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B1F%I;&D@7"(E<UPB
M('-U=7)U<W0@<&]L92!V]6EM86QI:R!K;VYT<F]L;&ED82XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HX,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(D9A:6QI(%PB)7,O)7-<
M(B!S=75R=7-T('!O;&4@=O5I;6%L:6L@:V]N=')O;&QI9&$N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B16D@<V%A(/QH96YD
M=7-T(%-13"!S97)V97)I9V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*
M;7-G<W1R(")34TP@_&AE;F1U<V4@86QG871A;6EN92!N=7)J=7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!F86EL:2!K
M;W!E97)I;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B5D93(&MA=&%L;V]G
M:2!<(B5S7"(@;&]O;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")6
M1E,@:V%T86QO;V=I(&QO;VUI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N(@IM<V=S='(@(E9&4R!F86EL:2!L;V]M:6YE(&YU<FIU<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB
M+B(*;7-G<W1R(")61E,@:V%U<W1A(%PB)7-<(B!L;V]M:6YE(&YU<FIU<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(D5I('-A
M82!L=75A('3\:&IA(%9&4R!F86EL:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N(@IM<V=S='(@(DQA:'1I<&%K:VEM:6YE(&YU<FIU<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M(@IM<V=S='(@(EPB)7-<(B!E:2!S86$@:W5S='5T861A+"!K871A;&]O9R!E
M:2!O;&4@=/QH:2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")%:2!S86$@:W5S='5T
M861A(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,S-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B)7,@96D@<V%A
M(&MU<W1U=&%D82P@:V%T86QO;V<@96D@;VQE('3\:&DB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G
M:7!U=2!K=7-T=71A;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&MA=&%L;V]G:2!K=7-T=71A;6EN
M92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`B16D@<V%A(&MU<W1U=&%D82!61E,@:V%T86QO;V=I.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B16D@<V%A(&MU<W1U=&%D82!61E,@9F%I;&D@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(@IM<V=S='(@(E9&4R!F86EL:2!K=7-T=71A;6EN92!N=7)J=7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B16D@<V%A(&MU<W1U=&%D82!61E,@:V%U<W1A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M(@IM<V=S='(@(D5I('-A82!K=7-T=71A9&$@5D93:2!R96MU<G-I:79S96QT
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I
M9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B2F]O:W-V870@:V%T86QO;V=I(&5I(/5N;F5S='4@='5V87-T861A
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`S"FUS
M9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM
M<V=S='(@(D5I('-A82!KY'1T92!S97)T:69I:V%A9&D@_&MS:6MA<VIU(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(B5S(&1E9FEN:71S:6]O;FD@;&%A9&EM:6YE(&YU<FIU<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM
M<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R!F
M86EL:2#\;6)E<G3U<W1M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")%:2!S86$@879A
M9&$@5D93(&9A:6QI(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T
M<B`B16D@<V%A(&%V861A(%9&4R!F86EL:2!M=75T;6ES96MS+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,@9F%I;&D@879A;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P
M96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(")086MI='5D(&%R:&EI
M=FD@879A;6EN92!N=7)J=7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@S-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B16D@<V%A(&QU9V5D82!61E,@9F%I;&D@
M*&9I;&5S:7IE*"D@;G5R:G5S*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#8V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+B(*;7-G<W1R(")%:2!S86$@;'5G961A(%9&4R!F
M86EL:2`H9V5T1FEL95-I>F4H*2!N=7)J=7,I+B(*"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(D5I(/5N;F5S='4@
M;'5G961A(&9A:6QI.B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B=F9S<F]O="!K871A;&]O9VD@;'5G96UI;F4@;G5R
M:G5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B)7,@
M96D@<V%A(/QM8F5R(&YI;65T861A("5S+6MS.B!S:6AT:V%U<W0@;VX@:G5B
M82!O;&5M87,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*
M;7-G<W1R(")61E,@:V%T86QO;V=I(/QM8F5R;FEM971A;6EN92!N=7)J=7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B16D@<V%A(/QM8F5R(&YI;65T861A(%9&4R!K871A;&]O
M9VDZ("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(D5I('-A82#\;6)E<B!N:6UE=&%D82!61E,@9F%I;&D@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D5I('-U=61A
M(/QM8F5R(&YI;65T861A(%9&4R!F86EL:2`E<R\E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9F%I;&D@_&UB97)N:6UE
M=&%M:6YE(&YU<FIU<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+B(*;7-G<W1R(")%:2#U;FYE<W1U(&OD:79I=&%D82`G;6MI
M<V]F<R<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0B"FUS9W-T<B`B4V5D82!7;W)D:2!D;VMU;65N=&D@;VX@=O5I
M;6%T=2!T]6QG96YD861A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B16D@<V%A(&MI<FIU=&%D82!61E,@9F%I;&D@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T
M<B`B16D@<V%A(&MI<FIU=&%D82!61E,@9F%I;&D@*&-O<'DH*2!N=7)J=7,I
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R(")61E,@9F%I;&D@86YD;65T92!S86QV
M97-T86UI;F4@;G5R:G5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`B16D@<V%A(&MI<FIU=&%D82!61E,@
M9F%I;&DL(&ME='1A:W9O;W0@;.1H96(@;/5H:VDN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L
M:6YE(@IM<V=S='(@(D%L;&%J;V]N:71U9"!T96MS="(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R
M(")486%S=&$@86QG<V5I<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T
M:6]N(@IM<V=S='(@(E;U=&%B('9I:6UA<V4@=&5G979U<V4@=&%G87-I(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`B3V]T86UA='4@=F%S='5S('-E<G9E<FEL="#\:&5N
M9'5S92!L;V]M:7-E;#H@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B`B"FUS9W-T<B`B3V]T86UA='4@=F%S='5S('-E<G9E<FEL=#H@
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B2V%T96=O;W)I871A(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%54
M1BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B07)A86)I82#<
M:&5N9&5M:7)A861I9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI
M;F=D;VTB"FUS9W-T<B`B4W5U<F)R:71A;FYI82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B06UE97)I:V$@W&AE;F1R
M:6EG:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B06UE97)I:V$@W&AE;F1R
M:6EK:61E(';D:6ME<V%A<F5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S
M(@IM<V=S='(@(MQH:6MU9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*
M;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B5'5N9&UA='4B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M5'5N9&UA='4@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS
M9W-T<B`B5'5N9&UA='4@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")-Y.1R871I('1U
M;F1M871U(&%S=6MO:'0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+B(*;7-G<W1R(")4=6YD;6%T=2!K87-U=&%J86YI;6D@
M:F$@<V%L87/U;FYA+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R
M96YT(&5L96UE;G0B"FUS9W-T<B`BW&AE;F1A('-E92!E;&5M96YT(&QA:'1I
M+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS
M9VED(")5;FYA;65D(@IM<V=S='(@(DYI;65T=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HBU6EG=7-T971A('-K
M<FEP=&ED(&5I('-A82!T=7)V86MA86QU=&QU<W1E;"!P<F]G<F%M<V5L="!S
M;V]R:71A9&$@;/5I:V%M:7-T+R(*(FML965P:6UI<W0N($MU:2!K;/5P<V%D
M($]++"!NY&5D(&UO>FEL;&$N;W)G('1E:&YI;&ES="!S96QG:71U<W0@:W5I
M9&%S("(*(FQU8F%D82!S:W)I<'1I9&5L(&SU:6ME<'5H=G)I="!K87-U=&%D
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")%96UA;&1A
M(';D<G8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X
M-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(E1O971A;6%T82!L86EE;F1U<R(*
M"B,Z("TM+2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM
M<V=S='(@(DMI;FYI=&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G
M<W1R(")-=75D82`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(DUU=61A(&MA
M<W5T86IA(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O
M961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB
M)7-<(B!M=75D971U9"XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B575E
M;F1U<V4@<VMR:7!T(&MU<W1U=&%T=60N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B3&%E('-E<G9E<FES<V4B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB
M"FUS9W-T<B`B2_5I:R!R86ME;F1U<V4@<&%I9V%L9'5S9F%I;&ED(&]N('-E
M<G9E<FES<V4@;&%E='5D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B3&%D:6YA('-U=7)TY&AE9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*
M;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4W5U<F5D(')O
M;VUA(&YU;6)R:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM
M<V=S='(@(E5R=6=U86DB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@
M0W5R<F5N=#H@)7,B"FUS9W-T<B`B2V%S=71A('!R865G=7-T.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X
M"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(DMA<W5T82!34TQI(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B
M2V%S=71A(&IU:'5L(&MU:2!N:6UI+W-A;&%S]6YA($E-4U`@<V5R=F5R:7,@
M;VX@97)I;F5V+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B2V%S=71A:F$B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B2V%S=71A:F%L("5S(&5I(&]L92!L=6)A='5D("5S+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")+87-U=&%J86AA;&1U<R(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T
M<B`B2V%S=71A:F$@<V5A9&ES='5S(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B2V%S=71A:F$@<F5G:7-T
M<F5E<FEM:6YE(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B4V5L;&5S('-A:61I<R!K87-U=&%J871E(')E9VES=')E97)I;6ES
M="!E:2!V]6EM86QD871A+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B2V%S
M=71A:F%K;VYT;W0@96D@;&5I='5D(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B2V%S=71A:F%N:6UI(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S
M='(@(DMA<W5T86IA;FEM:2!<(B5S7"(@;VX@:G5B82!O;&5M87,N(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M
M93HB"FUS9W-T<B`B2V%S=71A:F%N:6UI.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B2V%S
M=71A:F%N:6UI.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(DMA<W5T
M86IA9"!S_'-T965M:7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI
M<W1A;B(*;7-G<W1R(")5<V)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U
M-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B5D93(&MA=&%L;V]G:2!P;VQE(&]L96UA<RXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")0
M=6AK=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@
M(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B3VQE
M;6%S;VQE=F%D(&MO<G)E:W1S960@87-U:V]H860@;VXZ("(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R(")+96AT:79U<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B36EN=71I=&4@87)V('!R865G
M=7-E<W0@:&5T:V5S="!A;&%T97,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG
M=&@@;V8@)7,N(@IM<V=S='(@(E;DY')T=7,@_&QE=&%B("5S(&UA:W-I;75M
M<&EK:W5S92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R(")6Y.1R='5S960B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")6Y.1R
M='5S960@;6EL;&4@:'5L9V%S="!V86QI9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R
M(")-=75T;&EK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(E9E;F5T<W5E96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G
M<W1R(")+;VYT<F]L;&EM:6YE(&YU<FIU<R`M('-E92!K:7)I(';U:6(@;VQL
M82!P86AA=&%H=&QI:W5L="!M=75D971U9"XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R
M(")*Y')J96YU;6)E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")697)S:6]O;FEH
M86QD=7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")6
M97)T:6MA86QN92!J;V]N9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*
M;7-G<W1R(")697)T:6MA86QN92!V;V]D97)D=7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;#HB"FUS9W-T<B`B5F5R=&EK86%L;F4Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G
M<W1R(")6Y&=A(&OU<F=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.
M86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DT"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(E9I971N
M86UI("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B5F%A=&$@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED
M(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(E9A871A(';D
M;&ES="!V965B:6QE:'1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B
M"FUS9W-T<B`B5F%A=&$@:W5I("5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B0G)I=&D@3F5I='-I
M<V%A<F5D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M(%4N4RXB"FUS9W-T<B`B55-!($YE:71S:7-A87)E9"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(D[D
M:'1A=G5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM
M<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(D[D:'1A=G5S.B`B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;F4@271A;'D@_&QE(%--5%`B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED
M(")705).(@IM<V=S='(@(DA/24%455,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B2$])0515
M4R$A(2!+55-4551!(%-+4DE05"!+Q%-)5%-)($M!5$%,3T]'25-4("5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS
M9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.(/QL92!(5%10(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B
M5V%L;&ES(&IA($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")(;VEA='5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.`IM<V=I9"`B5V4B"FUS9W-T<B`B2V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T
M<B`B26QM865N;G5S='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S
M='(@(DEL;6%A;F1M96ED('!A:W5B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R
M+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B
M"FUS9W-T<B`B5F5E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E9E96)I<V%I="(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@
M(E=E96ML>2(*;7-G<W1R(")+;W)D(&[D9&%L87,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")4
M97)E('1U;&5M87-T(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5&5R92!T=6QE;6%S="`E
M<RUI(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(E1E<F4@='5L96UA<W0L("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(DSDY&YE("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB
M"FUS9W-T<B`B3.3D;F4@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("),Y.1N92U386AA<F$B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@
M;&]G:6X_(@IM<V=S='(@(DUI;&QI<V4@<F%K96YD=7-E('!E86MS("5S('#D
M<F%S="!S:7-S96QO9VEM:7-T(&%V86UA/R(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@
M8VAA<F%C=&5R/R(*;7-G<W1R(")-:6QL:7-T(&WD<FMI(&MA<W5T871A:W-E
M(&5R86QD86IA;F$_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T
M<B`B36EL;&ES="!MY')K:2!K87-U=&%T86MS92!J=71U;>1R9VEN83\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM
M<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H97)E:7,@
M075S=')A;&EA(&MA87)T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS
M9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B36EL;&ES960@9F%A<VED(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G
M<W1R(")-:6QL:7-E:60@<&QU9VEN86ED(&QU8F%D82!2:6-H(%1E>'0@961I
M=&]R:7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&%I=7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I
M;B!#4U,@=6YI=',B"FUS9W-T<B`B3&%I=7,@0U-3(/QH:6MU=&5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F
M96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T<B`B)7,@;65N_/P@;&%I=7,@
M=F%S86MU;"`H:&%K:V%B(&WU:G5M82!JY')G;6ES96P@<VES<V5L;V=I;6ES
M96PI.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B5&%B
M96QI(&QA:75S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B3&%I=7/\
M:&EK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("),86EU<SHB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@
M(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7
M:6YD(@IM<V=S='(@(E1U=6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")(
M;VUM:6MU;"!T=75L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I
M9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")4=75L92!K:6ER=7,@
M<_5L;65D97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B
M5VEN9#HB"FUS9W-T<B`B5'5U;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5'5U;#H@(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS
M9W-T<B`B5&%R:W5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y
M-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B4V]O=FEN:6UE:VER:2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R
M(")4]O8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")4]O9K;VAA(&%A
M9')E<W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E3V]G1E;&5F;VXB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(")296%S("5D(&]N('9A;&4@87)V(';D;&IU
M+B!096%K<R!O;&5M82`E9"P@86=A(&]N("5D+B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(E9A;&4@87)V(';D;&IU+B!096%K<R!O;&5M82`E9"P@86=A(&]N
M("5D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")686QE(&%L9W5S<'5N:W0@)60@5D93
M(&9A:6QI(&QU9V5M:7-E;"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@
M0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B6#4P.78S('#U:&EL:7-E9"!P
M:6ER86YG=60B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R
M(")8-3`Y=C,@=O5T;64@;&%I96YD871U9"!K87-U='5S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S('-U8FIE
M:W1I(&%L=&5R;F%T:6EV;F4@;FEM:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@<W5B:F5K=&D@=O5T;64@:61E
M;G1I9FEK86%T;W(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P
M.78S(&QA:65N9'5S960B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T<B`B04%!02(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X
M"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA:&]O(2!K86%R="(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G
M:60@(EEE87)L>2(*;7-G<W1R(")+;W)D(&%A<W1A<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE96UE;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*
M;7-G<W1R(")*86@B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(DIA
M:"P@;VQE;B!N]75S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5
M<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N
M(@IM<V=S='(@(D]L960@5$5+4U1)4D5:24E-25,N($ML]7!S82!;/#Y=(&5T
M(&UI;FYA('1A9V%S:2!765-)5UE'(')E>FEI;6DN(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N
M(@IM<V=S='(@(D5I(&]L92!L=6)A='5D(&QU=6$@<F]H:V5M(&MU:2`E9"!B
M;&]K:VDN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")382!E
M:2!O;&4@<VES<V4@;&]G:71U9"XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E-I
M;G4@=.1I<VYI;6D@96D@=O5I('-I<V%L9&%D82`G7%PG(&WD<FMI+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")382!E:2!S:7-E<W1A;G5D(&MO
M<G)E:W1S970@92UP;W-T:2!A861R97-S:2XB"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B
M4V$@96D@<V5A9&YU9"!I;7!O<F1I='5D(&9A:6QI(';D;&IU('9A<W1A=G5S
M<V4@)7,@=N1L:F%D96=A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX.`IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R
M(")3:6YD(&QO9VET:2!VY&QJ82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@HB4V$@<&5A9"!S:7-E<W1A;6$@:V5H=&EV82!M;V)I
M:6QT96QE9F]N:2!N=6UB<FD@;6ES('-I<V%L9&%B(&%I;G5L="!N=6UB<F5I
M9"`B"B)J82!M:6QL92!A;&=U<V5S(';U:6(@;VQL82`G*R<@<F%H=G5S=F%H
M96QI<V4@<W5U;F%K;V]D:2!T=6YN=7-E;F$N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B4V$@<&5A9"!S:7-E<W1A;6$@:V]R<F5K
M='-E(';DY')T=7-E+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B3&EI='5M:7-E(&QU
M8F%M:7-E:W,@<&5A9"!S96%D:7-T86UA($1A=&%4<F5E('/\<W1E96UI+B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B4V$@<&5A
M9"!S96%D:7-T86UA(%9&4R!S_'-T965M:2XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(D5N;F4@<V%A=&UI<W0@;VQE:W,@=&%R:R!P<F]B
M;&5E;6D@:VER:F5L9&%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B4V$@<&5A
M9"!S:7-E<W1A;6$@55),:2!K=6AU('-E92!L:6YK('9I:71A8B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(E!E860@
M;>3D<F%M82!K=7-T=71A=&%V82!S97)V97)I+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B4&5A9"!MY.1R86UA(&MA<W5T86IA;FEM
M92!M:61A('3\:&IE;F1A9&$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*
M;7-G<W1R(")096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@965M86QD
M861A+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@
M=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")096%D(&WDY')A;6$@:V%S=71A
M:F%N:6UE(&UI9&$@;&ES861A+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+B(*;7-G<W1R(")096%D(&WDY')A;6$@:V%S=71A:F%N:6UE(&UI9&$@;75U
M=&$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN(@IM<V=S='(@(E!E860@;>3D<F%M82!T96=E=G5S92P@;6ED82!S
M;V]V:60@=&5H82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+B(*;7-G<W1R(")096%D('-I<V5S=&%M82!U=64@:V%T
M96=O;W)I82!N:6UE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E!E860@<VES
M97-T86UA($ET86%L:6$@=&5L969O;FEN=6UB<FDB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY-S8*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@
M97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")3:6YU("5S
M('-E<W-I;V]N(&]N(&%E9W5N=60N(%!A;'5N(&QO9VD@=75E<W1I('-I<W-E
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED
M(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B4VEN=2!E+7!O<W1I(&%A
M9')E<W,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B
M66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")3:6YU('-A871J82!A861R
M97-S.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")3:6YU(&EN9F\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)3:6YU(&EN=&5R
M;F5T:6%A9')E<W,@;VX@)7,@<V5S<VEO;VYI(&IO;VMS=6P@;75U='5N=60N
M(%1U<G9A;&ES=7-E("(*(G1A9V%M:7-E:W,@<&5A9"!U=65S=&D@<VES<V4@
M;&]G:6UA+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S
M"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B4VEN=2!N:6UI(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN
M9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN
M:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT
M("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(E-I;G4@
M875T96YT:6UI<W/\<W1E96T@96D@=O5I;6%L9&$@:V%S=71A:F%I9"!L:7-A
M9&$N($MU:2!S;V]V:60@2&]R9&4@86)I;"`B"B)K87-U=&%J86ED(&AA;&QA
M=&$L('!E860@:V%S=71A;6$@=&5I<W1S=6=U<W0@875T96YT:6UI<W/\<W1E
M96UI+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B)3:6YU(&%U=&5N=&EM:7-S_'-T965M(&5I(';U:6UA;&1A(&MA<W5T
M86IA=&4@;FEM96MI<FIA(&[D:&$L(';U:2!O;B!S964@(@HB=O5I;6%L=7,@
M;6EN9VEL(&UU=6P@</5H:G5S96P@=N1L:F$@;/QL:71A='5D+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(E-I;G4@=F5E8FEL96AI='-E:F$@;N1I8B!O;&5V870@)7,@
M<V5S<VEO;VYI(&IO;VMS=6P@;75U='5N=60N(%1U<G9A;&ES=7-E("(*(G1A
M9V%M:7-E:W,@<&5A9"!U=65S=&D@<VES<V4@;&]G:6UA+B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E-I;G4@=F5E8FEL
M96AI='-E:F$@96D@=O5I;6%L9&$@<V5D82!O;6%D=7-T(&MA<W5T861A+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@HB4VEN=2!V965B:6QE:&ET<V5J82!E:2!V]6EM86QD82!N
M:6EM;V]D:2!T<OQK:VED82X@5F%J=71A('1R_&MK:6UI<V5K<R`B"B)#;VYT
M<F]L*U`@=O5I($-O;6UA;F0K4"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R
M(")3:6YU(&%J87;V]FYD.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N
M(@IM<V=S='(@(E-I;G4@=F%I:V5I9&5N=&ET965T(&]N(&UU=61E='5D+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`B4VEN=2!V86EK96ED96YT:71E970Z
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F
M=6QL(&YA;64Z(@IM<V=S='(@(E-I;G4@=.1I96QI:R!N:6UI.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO=7(@;&]G:6X@
M:&%S(&5X<&ER960N(@IM<V=S='(@(E-I;G4@<VES<V5L;V=I;6EN92!O;B!A
M96=U;G5D+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,B"FUS9W-T<B`B4VEN=2!U=7,@)7,@<V%L87/U;F$@;VXZ("5S(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO
M=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N
M(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B375U9&%T=7-E9"!O;B!S86QV
M97-T871U9"!S96QL92!S97-S:6]O;FD@;/5P=6YI+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(DUU=61A='5S960@;VX@<V%L
M=F5S=&%T=60N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*
M;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B
M4VEN=2!S86QA<_5N82!O;B!V86AE=&%T=60B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@
M8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@
M>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(E-I;G4@<V%L87/U
M;F$@;VX@=F%H971A='5D+"!V86%T82!O;6$@92UP;W-T:2!J82!L;V=I('-I
M<W-E('5U92!S86QA<_5N86=A+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B4VEN=2!S86QA<_5N82!O;B!A96=U;G5D+B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R
M=F5R<SHB"FUS9W-T<B`B4VEN=2!VY&QI<V5D('-E<G9E<FED.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G
M;W-L86%V:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("):86ER(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM
M<V=I9"`B6F%M8FEA(@IM<V=S='(@(E-A;6)I82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")::7!P
M>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT
M<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R
M(");4&5I9&$@;W-U;F1A='5D('1E:W-T72(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM(
M;W)D92!P<F]B;&5E;5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G
M<W1R(");3N1I=&$@;W-U;F1A='5D('1E:W-T:2`M(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S72(*;7-G<W1R(");3N1I=&$@;W-U;F1A='5D('1E:W-T:2`M("5S(')I
M9&%=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EMR:61A
M("5S("5S+7-T72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T
M,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B7TAA;&1U<R(*"B,Z(&QI8B]A<&DN<&AP.C$U
M-PIM<V=I9"`B7T-,22(*;7-G<W1R(")+Y'-U7W)I9&$B"@HC.B!L:6(O87!I
M+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(E]+=7-T=71A
M(')I9&$B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS
M9W-T<B`B7T=R=7!I9"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(D%?8FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*
M;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(E]0:6QD:2!O
M;6%D=7-E9"XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7TQO9VD@<VES<V4B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?
M3&]G(&]U="(*;7-G<W1R(")?3&]G:2!VY&QJ82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B
M7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-=75D82!L:6YK:2XN+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/
M<'1I;VYS(@IM<V=S='(@(E]396%D:7-T=7,B"@HC.B!L:6(O87!I+G!H<#HQ
M,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("+5:6=?=7-E9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(E]%96UA;&1A
M(&QI;FLN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*
M;7-G<W1R(")?4&%I9V%L9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?5&%B96QI(&]M861U<V5D+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7TMA<W5T
M86IA9"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"FUS9VED
M(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B86%D<F5S<VER86%M870B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B861R97-S86%T('1U;F1M871U(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(FMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B8V%L;2(*;7-G<W1R(")V86EK;F4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R(")VY&QJ=6YD9F%I;&D@;&]O;6EN92!N=7)J
M=7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM
M<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B<VES96YD:2!A=F%M
M:6YE(&YU<FIU<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")K;/5P<V$@<VEI
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS
M9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B:^1S=7)E
M82!K87-U=&%M:7-E('9I9V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G
M<W1R(")S96%D:7-T=7-E('9I9V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@
M;6ES<VEN9R(*;7-G<W1R(")E;'5TY&AT:7,@<_QS=&5E;6EF86EL(&]N('!U
M=61U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*
M;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F%N9&UE=&4@9F]R
M;6%A9&D@=FEG82(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*
M;7-G:60@(F5D:70B"FUS9W-T<B`B;75U9&$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD
M(@IM<V=S='(@(FMA;FYE="!E:2!L96ET=60B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G
M<W1R(")L86YG96(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX-34*;7-G:60@(F9I;&4B"FUS9W-T<B`B9F%I;"(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B<W5U;F0@)7,@*"5S*2!J
M82!K:6ER=7,@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G!U:&%N9W5L:6YE(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM
M<V=I9"`B:#HB"FUS9W-T<B`B:SHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")H:"(*;7-G<W1R(")T="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED
M(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R(")T=6YD;6%T=2!H;W-T:6YI
M;6DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")V:6EV:71A
M;6%T=2(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B:6YL:6YE(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R(")S:7-E;F0O=N1L:G5N9"!V
M:6=A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*
M;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(G1A<FMV
M87)A('-E97-M:6YE('9I9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(G)I9&%=
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S('9E
M86MO;V0@)60@25-/(&QO;VUI<V5L+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(FUM
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(FYI;6DB"@HC
M.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M
M96YT960B"FUS9W-T<B`B<&]L92!T96]S=&%T=60B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP
M;&5M96YT960B"FUS9W-T<B`B<&]L92!V965L('1E;W-T871U9"(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM
M<V=S='(@(FWD<FMM:6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@
M(G!R;W1S96YT:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("+U:6=U
M<V5D('!U=61U=F%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!I
M:W-L:70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(G!R
M;W1O:V]L;&D@=FEG82!T96ES97,@;W1S87,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S
M='(@(G3U=7-E8B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G1E
M96YU<R!P;VQE(&OD='1E<V%A9&%V(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")NY&ET
M82!E<FEN979U<VDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM
M<V=S='(@(G-M<S)E;6%I;"#\;&4@2%144"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@
M(G-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("+\:'1L86YE(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V
M87-C<FEP="(*;7-G<W1R(")L_&QI=&$@:F%V87-C<FEP="!VY&QJ82(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S
M>7-T96T@97)R;W(B"FUS9W-T<B`B<_QS=&5E;6D@=FEG82(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B_&QE<V%N;F5T92!N:6UE:VER:2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R
M92(*;7-G<W1R(")A:G5T:6YE('3U<F=E(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,#4*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R(")P<F]O
M=FD@=75E<W1I(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")K:7)J=71A('-A;&%S]6YA
M(&5K<VET=7-E(';D;'1I;6ES96MS(&MA:W,@:V]R9&$B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B=6YI9FEE9"(*;7-G<W1R("+\:&ET871U9"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M;FEM971U(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")K
M87-U=&%J82!V86QI:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS
M9VED(")W.B(*;7-G<W1R(")L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R
M+F-O;2(*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P;R]214%$344`````````````````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C(W-S(@,3`U,34T,S0Q-#(@,#$W
M,#0R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#T]/3T]/3T]/3T]/3T]/3T]/3T*(%1R86YS;&%T:6]N($=U:61E(`H]/3T]
M/3T]/3T]/3T]/3T]/3T]"@HZ1&%T93H@("`@("1$871E.B`R,#`V+S`W+S(V
M(#$T.C`V.C4Q("0*.E)E=FES:6]N.B`D4F5V:7-I;VXZ(#$N,CDN-"XQ("0*
M.D%U=&AO<G,Z("!*86X@4V-H;F5I9&5R"CI#;VYT86-T.B`@:3$X;D!L:7-T
M<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH*+BX@<V5C=&EO;BUN=6UB97)I
M;F<Z.@H*5')A;G-L871I;VX@5&]O;`H]/3T]/3T]/3T]/3T]/3T]"@I@8'1R
M86YS;&%T:6]N+G!H<&!@(&ES(&$@<VUA;&P@4$A0('-C<FEP="!T:&%T('-H
M;W5L9"!H96QP('1R86YS;&%T;W)S(&1O:6YG"G1H96ER('=O<FLN"D%N>2!F
M965D8F%C:RP@8G5G(')E<&]R=',@86YD(&9E871U<F4@<F5Q=65S=',@<VAO
M=6QD(&)E('-E;F0@=&\@=&AE(&!I,3AN"FUA:6QI;F<@;&ES=&!?+B!4:&ES
M(&ES(&%L<V\@=&AE(')I9VAT('!L86-E(&9O<B!N97<@=')A;G-L871I;VYS
M(&%N9"!G96YE<F%L"F1I<V-U<W-I;VYS(&]F(&DQ.&X@86YD(&PQ,&X@<75E
M<W1I;VYS(&%N9"!P<F]B;&5M<RX*"D9O<B!A(&QI<W0@;V8@879A:6QA8FQE
M(&-O;6UA;F1S(')U;CHZ"@H@("XO=')A;G-L871I;VXN<&AP(&AE;'`*"D9O
M<B!D971A:6QE9"!H96QP(&]N(&$@8V5R=&%I;B!C;VUM86YD(')U;CHZ"@H@
M("XO=')A;G-L871I;VXN<&AP(&AE;'`@8V]M;6%N9`H*061D:71I;VYA;"!I
M;F9O<FUA=&EO;B!A8F]U="!C<F5A=&EN9R!T<F%N<VQA=&EO;G,@86YD(&9I
M>&EN9R!P<F]B;&5M<R!C86X@8F4*9F]U;F0@:6X@=&AE(&9I;&4@8&!H;W)D
M92]D;V-S+U1204Y33$%424].8&`N"@HN+B!?:3$X;B!M86EL:6YG(&QI<W0Z
M(&AT='`Z+R]H;W)D92YO<F<O;6%I;"\*"E!R97)E<75I<VET97,*?GY^?GY^
M?GY^?GY^?@H*5&\@<G5N('1H:7,@<V-R:7!T('EO=2=L;"!N965D(&$@4$A0
M(&5X96-U=&%B;&4@;&EK92!T:&4@0TQ)(&]R('1H92!#1TD@=F5R<VEO;@IW
M:71H(&!G971T97AT('-U<'!O<G1@7R!C;VUP:6QE9"!I;B!A;F0@=&AE(&)A
M<VEC(&!014%28%\@;&EB<F%R:65S+B!4:&4*<V-R:7!T(&5X<&5C=',@>6]U
M<B!02%`@97AE8W5T86)L92!T;R!B92!A="!@8"]U<W(O;&]C86PO<'-A+V%D
M;6EN+V)I;B]P:'!@8"X@268@>6]U<@IE>&5C=71A8FQE(&ES(&%T(&%N;W1H
M97(@<&QA8V4L(&5I=&AE<B!E9&ET('1H92!F:7)S="!L:6YE(&]F"F!@=')A
M;G-L871I;VXN<&AP8&`@=&\@<F5F;&5C="!Y;W5R(&QO8V%T:6]N(&]R(&-A
M;&P@=&AE('-C<FEP="!L:6ME.CH*"B`@+W5S<B]L;V-A;"]P<V$O861M:6XO
M8FEN+W!H<"`M9B!T<F%N<VQA=&EO;BYP:'`N"@I9;W4G;&P@;F5E9"!@9V5T
M=&5X=&!?(#`N,3$@;W(@9W)E871E<BP@8G5T('9E<G-I;VX@,"XQ,B!O<B!G
M<F5A=&5R(&ES('-T<F]N9VQY"G)E8V]M;65N9&5D(&%S('1H:7,@:7,@=&AE
M(&9I<G-T('9E<G-I;VX@=&AA="!S=7!P;W)T<R!02%`@;F%T:79E;'DN($]L
M9&5R"G9E<G-I;VYS(&UA>2!N;W0@97AT<F%C="!A;&P@=')A;G-L871E86)L
M92!S=')I;F=S(&-O<G)E8W1L>2X*02!W:6YD;W=S('9E<G-I;VX@;V8@=&AE
M(&=E='1E>'0@8FEN87)I97,@8V%N(&)E(&9O=6YD(&]N(&5V97)Y(&!'3E4@
M9G1P"FUI<G)O<F!?(&%S(&]F('9E<G-I;VX@,"XQ,BX*"EEO=2=L;"!N965D
M('1H92!014%2('!A8VMA9V5S(&!#;VYS;VQE7T=E=&]P=&!?(#`N,3$@;W(@
M9W)E871E<BP*8$-O;G-O;&5?5&%B;&5@7R!A;F0@8$9I;&5?1FEN9&!?+B!4
M;R!I;G-T86QL(&%L;"!N965D960@<&%C:V%G97,L(')U;CHZ"@H@('!E87(@
M=7!G<F%D92!014%2($-O;G-O;&5?1V5T;W!T"B`@<&5A<B!I;G-T86QL($-O
M;G-O;&5?5&%B;&4@1FEL95]&:6YD"@IO<B!D;W=N;&]A9"!T:&4@;F5W97-T
M('!A8VMA9V4@9G)O;2!T:&4@8%!%05)@7R!S97)V97(@86YD(&EN<W1A;&P@
M=&AE;0IM86YU86QL>2!I;B!Y;W5R(%!%05(@9&ER96-T;W)Y+@H*+BX@7V=E
M='1E>'0Z(&AT='`Z+R]W=W<N9VYU+F]R9R]S;V9T=V%R92]G971T97AT+PHN
M+B!?9V5T=&5X="!S=7!P;W)T.B!H='1P.B\O=W=W+G!H<"YN970O9V5T=&5X
M="\*+BX@7T=.52!F='`@;6ER<F]R.B!H='1P.B\O=W=W+F=N=2YO<F<O<')E
M<"]F='`N:'1M;`HN+B!?4$5!4CH@:'1T<#HO+W!E87(N<&AP+FYE="\*+BX@
M7T-O;G-O;&5?1V5T;W!T.B!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M0V]N<V]L95]'971O<'0O"BXN(%]#;VYS;VQE7U1A8FQE.B!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O0V]N<V]L95]486)L92\*+BX@7T9I;&5?1FEN
M9#H@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T9I;&5?1FEN9"\*"D-R
M96%T:6YG(&$@;F5W('1R86YS;&%T:6]N"GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^"@I4;R!C<F5A=&4@82!N97<@=')A;G-L871I;VX@>6]U(&9I<G-T
M(&AA=F4@=&\@97AT<F%C="!A;&P@9V5T=&5X="!M97-S86=E<R!F<F]M"G1H
M92!02%`@<V]U<F-E<RX@5&AE<F4@87)E(&%L<F5A9'D@=&5M<&QA=&4@9FEL
M97,@=VET:"!T:&4@8&`N<&]T8&`@<W5F9FEX(&EN"G1H92!@8'!O8&`@9&ER
M96-T;W)I97,@=&AA="!Y;W4@8V%N('5S92!I9B!Y;W4@:&%V92!T<F]U8FQE
M<R!E>'1R86-T:6YG('1H90IM97-S86=E<R!B=70@=&AE>2!M:6=H="!B92!O
M=71D871E9"X*4G5N.CH*"B`@+B]T<F%N<VQA=&EO;BYP:'`@97AT<F%C=`H*
M66]U(&YO=R!H879E('1O(&-R96%T92!A(&YE=R!03R!F:6QE(&9O<B!Y;W5R
M(&QO8V%L92X@02!L;V-A;&4@:&%S('1H92!F;W)M"F!@;&Q?0T-@8"!W:&5R
M92!@8&QL8&`@:7,@=&AE('1W;R!L971T97(@8$E33R`V,SE@7R!C;V1E(&]F
M('1H92!L86YG=6%G92!A;F0*8&!#0V!@('1H92!T=V\@;&5T=&5R(&!)4T\@
M,S$V-F!?(&-O9&4@;V8@=&AE(&-O=6YT<GDL(&4N9RX@8&!D95]$16!@+`I@
M8&5N7U538&`@;W(@8&!P=%]"4F!@+@I@8'1R86YS;&%T:6]N+G!H<&!@(&ES
M(&%B;&4@=&\@9W5E<W,@=&AE(&QO8V%L92!F<F]M('1H92!@8$Q!3D=@8"!E
M;G9I<F]N;65N=`IV87)I86)L92!B=70@:70@:7,@<V%F97(@=&\@<W!E8VEF
M>2!T:&4@;&]C86QE('=I=&@@=&AE(&!@+6Q@8"!P87)A;65T97(N"E1O(&-R
M96%T92!T:&4@4$\@9FEL92!R=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H<"!I
M;FET("UL(&QL7T-#"@I.;W<@>6]U(&-A;B!S=&%R="!T:&4@=')A;G-L871I
M;VX@8GD@961I=&EN9R!T:&4@8W)E871E9"!@8&QL7T-#+G!O8&`*9FEL97,N
M($ET(&ES(&EM<&]R=&%N="!T;R!S970@=&AE(&-O<G)E8W0@8VAA<G-E="!F
M;W(@=&AE(&QO8V%L92!I;B!T:&4*8&!#;VYT96YT+51Y<&4Z8&`@:&5A9&5R
M+@I9;W4@<VAO=6QD(&9I;&P@;W5T('1H92!T:&4@8V]M<&QE=&4@:&5A9&5R
M(&]F('1H92!C<F5A=&5D(&!@;&Q?0T,N<&]@8"!F:6QE+`IE+F<N.CH*"B`@
M(R!$=71C:"!T<F%N<VQA=&EO;B!F;W(@2&]R9&4N"B`@(R!#;W!Y<FEG:'0@
M*$,I(#(P,#0@2&]R9&4@4')O:F5C=`H@(",@5&AI<R!F:6QE(&ES(&1I<W1R
M:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A
M8VMA9V4N"B`@(R!*;W)I<R!"<F%A:VUA;B`\:F)R86%K;6%N0'EA:&]O+F-O
M;3XL(#(P,#0N"B`@(PH@(&US9VED("(B"B`@;7-G<W1R("(B"B`@(E!R;VIE
M8W0M260M5F5R<VEO;CH@2&]R9&4@,BXS7&XB"B`@(E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B`@(E!/5"U#<F5A=&EO
M;BU$871E.B`R,#`T+3`T+3$T(#$P.C,P*S`R,#!<;B(*("`B4$\M4F5V:7-I
M;VXM1&%T93H@,C`P-"TP-"TQ-"`Q-SHQ-RLP,CHP,%QN(@H@("),87-T+51R
M86YS;&%T;W(Z($IO<FES($)R86%K;6%N(#QJ8G)A86MM86Y`>6%H;V\N8V]M
M/EQN(@H@("),86YG=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN
M(@H@(")-24U%+59E<G-I;VXZ(#$N,%QN(@H@(")#;VYT96YT+51Y<&4Z('1E
M>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@H@(")#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*5&\@8V]M<&EL92!T:&4@=')A
M;G-L871I;VYS('1O(&$@8FEN87)Y(&9O<FUA="!R=6XZ.@H*("`N+W1R86YS
M;&%T:6]N+G!H<"!M86ME"@I!9G1E<B!Y;W4@8W)E871E9"!T:&4@;F5W('1R
M86YS;&%T:6]N('EO=2!H879E('1O(&%D9"!E;G1R:65S(&9O<B!T:&ES(&QO
M8V%L90II;B!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE(&AO<F1E+V-O;F9I9R]N
M;',N<&AP+@H*5$]$3SH@9FEL;&EN9R!N97<@<&\@9FEL97,@=VET:"!S=')I
M;F=S(&9R;VT@=&AE(&-O;7!E;F1I=6TN"@HN+B!?25-/(#8S.3H@:'1T<#HO
M+W=W=RYL;V,N9V]V+W-T86YD87)D<R]I<V\V,SDM,B\*+BX@7TE33R`S,38V
M.B!H='1P.B\O=W=W+FES;RYC:"]I<V\O96XO<')O9',M<V5R=FEC97,O:7-O
M,S$V-FUA+VEN9&5X+FAT;6P*"DUA:6YT86EN:6YG('1R86YS;&%T:6]N<PI^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GX*"E1H:7,@=&]O;"!I<R!D97-I9VYE
M9"!T;R!H96QP('EO=2!T<F%N<VQA=&]R<R!D;VEN9R!Y;W5R(&=R96%T('=O
M<FLN($ET(&-H86YG97,*82!L;W0@8V]M<&%R960@=&\@=&AE(&]L9"!M971H
M;V1S(&-R96%T:6YG(&%N9"!M86EN=&%I;FEG('EO=7(@=')A;G-L871I;VYS
M+B!4;PIM86ME('1H92!T<F%N<VET:6]N('1O('1H92!T;V]L(&%S('-M;V]T
M:"!A<R!P;W-S:6)L92!Y;W4@<VAO=6QD(')E860@8VAA<'1E<@HS+C$@8F5F
M;W)E('5S:6YG('1H:7,@=&]O;"!T:&4@9FER<W0@=&EM92X*"D9I<G-T('1I
M;64@=7-E(&]F('1R86YS;&%T:6]N+G!H<`HM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T*"E1H:7,@=&]O;"!I;G1R;V1U8V5S(&$@;FEC92!F
M96%T=7)E(&]F(&=E='1E>'0Z(&-O;7!E;F1I=6T@9FEL97,N($$@8V]M<&5N
M9&EU;0II<R!A('-P96-I86P@4$\@9FEL92!C;VYT86EN:6YG(&$@<V5T(&]F
M('1R86YS;&%T:6]N<R!R96-U<G)I;F<@:6X@;6%N>0ID:69F97)E;G0@<&%C
M:V%G97,N(%1H97-E(&-O;7!E;F1I82!W:6QL(&)E('5S960@:6X@=&AE(&)A
M8VMG<F]U;F0@=VET:&]U="!M=6-H"F9O<B!Y;W4@=&\@8V%R92!A8F]U="X@
M0G5T('EO=2!H879E('1O(&-R96%T92!A;F0@961I="!A(&-O;7!E;F1I=6T@
M8F5F;W)E('EO=0IC86X@=7-E(&ET+@H*5&\@8W)E871E(&$@8V]M<&5N9&EU
M;2!O9B!A;&P@>6]U<B!E>&ES=&EN9R!T<F%N<VQA=&EO;G,@<G5N.CH*"B`@
M+B]T<F%N<VQA=&EO;BYP:'`@8V]M<&5N9&EU;2`M;"!L;%]#0PH*5&AE(&!@
M8V]M<&5N9&EU;2YP;V!@(&)E:6YG(&-R96%T960@=VEL;"!C;VYT86EN(&%L
M;"!M;V1U;&5S)R!T<F%N<VQA=&EO;G,@;V8*=&AI<R!L;V-A;&4@;65R9V5D
M(&EN=&\@82!S:6YG;&4@9FEL92X@66]U('-H;W5L9"!T86ME(&$@8VQO<V5R
M(&QO;VL@870@=&AI<PIF:6QE(&)E8V%U<V4@>6]U(&UA>2!F:6YD(&$@;&]T
M(&]F('-P96-I86P@;6%R:V5D(&QI;F5S('=H97)E('EO=2!T<F%N<VQA=&5D
M"F-E<G1A:6X@<W1R:6YG<R!D:69F97)E;G1L>2!I;B!T:&4@=F%R:6]U<R!M
M;V1U;&5S+B!)="=S(&$@9V]O9"!I9&5A('1O(&9I>`IT:&4@;6]D=6QE<R<@
M=')A;G-L871I;VYS(&YO=R!S;R!T:&%T(&%L;"!M;V1U;&5S('5S92!T:&4@
M<V%M92!T<F%N<VQA=&EO;B!F;W(*=&AE('-A;64@<W1R:6YG+B!9;W4@8V%N
M(&%L=V%Y<R!R96-R96%T92!Y;W5R(&-O;7!E;F1I=6T@=VET:"!T:&4@86)O
M=F4*8V]M;6%N9"X*"DEF('EO=2=R92!M86EN=&%I;FEN9R!T<F%N<VQA=&EO
M;G,@9F]R(&1I9F9E<F5N="!@8G)A;F-H97-@7R!A;F0@87-S=6UE9"!T:&%T
M"GEO=2!H879E(&%L;"!M;V1U;&5S(&]F('1H92!@8$A%041@8"!B<F%N8VAE
M<R!I;B!O;F4@9&ER96-T;W)Y(&%N9"!A;&P@;V8@=&AE"F!@4D5,14Y'7RI@
M8"!B<F%N8VAE<R!I;B!A;F]T:&5R+"!Y;W4@<')O8F%B;'D@=V%N="!T;R!S
M:&%R92!A(&-O;7!E;F1I=6T*8F5T=V5E;B!T:&5S92!D:7)E8W1O<FEE<RX*
M"EEO=2!S:&]U;&0@9FER<W0@8W)E871E(&$@8V]M<&5N9&EU;2!I;B!T:&4@
M8&!214Q%3D=?*F!@(&)R86YC:"P@<F5V:65W(&ET(&%N9`IF:7@@86QL('1R
M86YS;&%T:6]N<R!U;G1I;"!Y;W4G<F4@:&%P<'D@=VET:"!T:&4@<F5S=6QT
M+B!4:&5N(&-R96%T92!A('-E8V]N9`IC;VUP96YD:75M(&EN('1H92!@8$A%
M041@8"!B<F%N8V@@86YD(&EN8VQU9&4@>6]U<B!F:7)S="!O;F4@=VET:"!T
M:&4@+2UA9&0*;W!T:6]N+@I.;W<@9FEX('1H92!T<F%N<VQA=&EO;G,@:6X@
M=&AI<R!B<F%N8V@N($EF('EO=2=R92!R96%D>2!Y;W4@8V%N(')E;6]V92!T
M:&4*9FER<W0@8V]M<&5N9&EU;2!A;F0@9F]R(&YO=R!O;B!U<V4@=&AE(&-O
M;7!E;F1I=6T@:6X@=&AE(&!@2$5!1&!@(&)R86YC:"!F;W(*8F]T:"!B<F%N
M8VAE<RX@5&\@9&\@<V\@=7-E('1H92!@8"TM8V]M<&5N9&EU;6!@(&]P=&EO
M;B!T;R!S<&5C:69Y(&$@<&%T:"!T;PIY;W5R(&-O;7!E;F1I=6TN"@HN+B!?
M8G)A;F-H97,Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W-O=7)C92\*"E5P9&%T
M:6YG('1R86YS;&%T:6]N<PHM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"E1H92!P
M<F]C97-S(&]F('5P9&%T:6YG('1R86YS;&%T:6]N<R!I<R!A(&-Y8VQE('=H
M97)E('EO=2!E>'1R86-T(&YE=R!G971T97AT"G-T<FEN9W,@9G)O;2!T:&4@
M<V]U<F-E<RP@=')A;G-L871E('1H;W-E(&YE=R!S=')I;F=S(&]R('5P9&%T
M92!T:&4@86QR96%D>0IT<F%N<VQA=&5D('-T<FEN9W,@86YD(&-O;7!I;&4@
M=&AE;2!A9G1E<BX*"E1O('5P9&%T92!T:&4@=')A;G-L871I;VX@9F]R(&$@
M;6]D=6QE+"!R=6XZ.@H*("`N+W1R86YS;&%T:6]N+G!H<"!U<&1A=&4@+6T@
M;6]D=6QE;F%M92`M;"!L;%]#0PH*5&AI<R!E>'1R86-T<R!T:&4@;F5W('-T
M<FEN9W,@9G)O;2!T:&4@<V]U<F-E<R!A;F0@=')I97,@=&\@=7!D871E('1H
M96T@9G)O;0IA;')E861Y(&5X:7-T:6YG('1R86YS;&%T:6]N<R!I;B!T:&4@
M8V]M<&5N9&EU;2X@66]U(&IU<W0@:&%V92!T;R!T<F%N<VQA=&4*86QL('5N
M<W1R86YS;&%T960@<W1R:6YG<R!I;B!T:&4@8&!L;%]#0RYP;V!@(&9I;&4@
M:6X@=&AE(&!@<&]@8"!D:7)E8W1O<GD@;V8*=&AE(&UO9'5L92!Y;W4@=7!D
M871E9"X*"D]N8V4@=&AI<R!I<R!D;VYE+"!Y;W4@8V%N(&-O;7!I;&4@=&AE
M('1R86YS;&%T:6]N(&)Y(&-A;&QI;F<Z.@H*("`N+W1R86YS;&%T:6]N+G!H
M<"!M86ME("UM(&UO9'5L96YA;64@+6P@;&Q?0T,*"D5X=&5N9&EN9R!E>&ES
M=&5N="!T<F%N<VQA=&EO;G,*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?@H*5&\@:&%V92!Y;W5R(&]W;B!T97AT<R`H87,@<W5P<&QI960@:6X@
M8V]N9FEG(&9I;&5S(&9O<B!E>&%M<&QE*2!D:7-P;&%Y960@:6X*<V5V97)A
M;"!L86YG=6%G97,L('EO=2!H879E('1O"@H@(#$N('-P96-I9GD@>6]U<B!T
M97AT<R!A<R!G971T97AT(&%R9W5M96YT<RP@:6X@16YG;&ES:"P*("`R+B!E
M9&ET('1H92!T<F%N<VQA=&EO;B!F:6QE<R!F;W(@=&AE(')E<75I<F5D(&YA
M=&EO;F%L(&QA;F=U86=E<RP*("`S+B!C;VUP:6QE('1H;W-E('1R86YS;&%T
M:6]N(&9I;&5S+@H*0F4@<W5R92!T;R!K965P(')E8V]R9',@;V8@>6]U<B!E
M>'1E;G-I;VYS+"!A<R!Y;W4@=VEL;"!P<F]B86)L>2!H879E('1O"G)E<&5A
M="!S=&5P<R`R(&%N9"`S(&%F=&5R('1H92!N97AT('5P9&%T92X*"D4N9RXL
M('EO=2!P;&%N('1O(&]F9F5R('1W;R!)34%0('-E<G9E<G,@=&\@<V5L96-T
M(&9R;VT@:6X@=&AE(%=E8FUA:6P@;&]G:6X*<V-R965N.@H*("`Q+B!);B!@
M8&AO<F1E+VEM<"]C;VYF:6<O<V5R=F5R<RYP:'!@8"P@>6]U('-P96-I9GDZ
M.@H*("`@("`@("1S97)V97)S6R=#96YT<F%L)UT@/2!A<G)A>2@*("`@("`@
M("`@("=N86UE)R`]/B!?*")#96YT<F%L($UA:6P@4V5R=FEC92(I+`H@("`@
M("`@+BXN"B`@("`@("`D<V5R=F5R<ULG0V]M<%-C:2==(#T@87)R87DH"B`@
M("`@("`@("`G;F%M92<@/3X@7R@B36%I;"!397)V:6-E(&]F($-O;7!U=&5R
M(%-C:65N8V4@1'!T+B(I"B`@("`@("`N+BX*"B`@,BX@26X@8&!H;W)D92]I
M;7`O<&\O9&5?1$4N<&]@8"!Y;W4@861D('1W;R!E;G1R:65S.CH*"B`@("`@
M("!M<V=I9"`B0V5N=')A;"!-86EL(%-E<G9I8V4B"B`@("`@("!M<V=S='(@
M(EIE;G1R86QE<B!-86EL<V5R=F5R(@H@("`@("`@;7-G:60@(DUA:6P@4V5R
M=FEC92!O9B!#;VUP=71E<B!38VEE;F-E($1P="XB"B`@("`@("!M<V=S='(@
M(DUA:6QS97)V97(@26YF;W)M871I:R(*"B`@("`@3&EK97=I<V4L('EO=2!A
M;65N9"!T:&4@=')A;G-L871I;VX@9FEL97,@9F]R(&]T:&5R(&QA;F=U86=E
M<RP@87,@;F5E9&5D+@H*("`S+B!9;W4@8V]M<&EL92!T:&4@=')A;G-L871I
M;VYS('5S:6YG('1H92!C;VUM86YD<SHZ"@H@("`@("`@+B]P;R]T<F%N<VQA
M=&EO;BYP:'`@;6%K92`M+6UO9'5L92!I;7`@+2UN;RUC;VUP96YD:75M"@I!
M8V-E<W,@2V5Y<PH]/3T]/3T]/3T]/0H*06-C97-S(&ME>7,L(&%L<V\@:VYO
M=VX@87,@<VAO<G1C=70@:V5Y<RP@86QL;W<@96%S>2!A8V-E<W,@=&\@:6UP
M;W)T86YT"F9U;F-T:6]N<RP@;F]R;6%L;'D@8GD@:&ET=&EN9R!T:&4@06QT
M+TUE=&$@:V5Y(&EN(&-O;6)I;F%T:6]N('=I=&@@86YO=&AE<@IK97DN(%1H
M:7,@:V5Y(&ES(&UA<FME9"!I;B!M;W-T('5S97(@:6YT97)F86-E<R!B>2!B
M96EN9R!U;F1E<FQI;F5D+@H*07,@=&AE(&%C8V5S<R!K97D@:7,@<&%R="!O
M9B!T:&4@=V]R9"!R97!R97-E;G1I;F<@=&AE(&%C=&EO;B!B96EN9R!E>&5C
M=71E9"P*:70@:7,@:6X@=&AE('1R86YS;&%T;W)S(')E<W!O;G-I8FEL:71Y
M('1O('-E;&5C="!A;B!A8V-E<W,@:V5Y('=H96X@:&4*=')A;G-L871E<R!T
M:&5S92!W;W)D<RX@5&AE(&%C=&EO;B!I<R!A;'=A>7,@82!L:6YK(&EN($AO
M<F1E+B!4:&4@86-C97-S(&ME>0IO9B!A(&QI;FL@:7,@<V5L96-T960@8GD@
M<')E9FEX:6YG(&ET('=I=&@@86X@=6YD97)S8V]R92X*"E1H92!H96QP(&QI
M;FL@:6X@=&AE(&UE;G4@9F]R(&5X86UP;&4@:7,@86QW87ES(")?2&5L<"(N
M(%1H:7,@;65A;G,@=&AA="!T:&4*(D@B(&]F('1H92!L:6YK('=I;&P@8F4@
M=6YD97)L:6YE9"!A;F0@=&AE(&AE;'`@8V%N(&)E(&]P96YE9"!B>2!H:71T
M:6YG"D%L="M(+B!);B!T:&4@4$\@9FEL92!T:&ES('-T<FEN9R!W:6QL(&%P
M<&5A<B!A<SHZ"@H@(",Z('1E;7!L871E<R]M96YU+VUE;G4N:6YC.C4S"B`@
M;7-G:60@(E](96QP(@H@(&US9W-T<B`B(@H*02!3<&%N:7-H('1R86YS;&%T
M;W(@;6EG:'0@=V%N="!T;R!T<F%N<VQA=&4@=&AI<R!T;SHZ"@H@(",Z('1E
M;7!L871E<R]M96YU+VUE;G4N:6YC.C4S"B`@;7-G:60@(E](96QP(@H@(&US
M9W-T<B`B7T%Y=61A(@H*5')A;G-L871O<G,@;V8@;75L=&EB>71E(&QA;F=U
M86=E<R!N965D('1O(&1O('1H:7,@82!B:70@9&EF9F5R96YT;'D@87,@;VYL
M>0I!4T-)22!C:&%R86-T97)S(&%R92!A;&QO=V5D(&9O<B!A8V-E<W,@:V5Y
M<RX@02!4<F%D:71I;VYA;"!#:&EN97-E('1R86YS;&%T;W(*;6EG:'0@=V%N
M="!T;R!U<V4Z.@H*("`C.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHU,PH@
M(&US9VED(")?2&5L<"(*("!M<V=S='(@(E](Z*JJYIB.(@H*5&AI<R!R96YD
M97)S('1O("+HJJKFF(XH2"DB(&EN('1H92!I;G1E<F9A8V4@86YD('EO=2!C
M86X*86-C97-S('1H:7,@;&EN:R!W:71H(")((B!A<R!T:&4@86-C97-S(&ME
M>2X*````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<G5?4E4N<&\`
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P-C8U,S(T(#$P-3$U-#,T,30R(#`Q-S4V-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````C($AO<F1E(%)U<W-I86X@=')A
M;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*0HC($EG;F%T($EK<GEA;F]V(#QI
M:6=N871`;F5W;6%I;"YR=3XL(#(P,#$*(R!&961O<B!!+B!&971I<V]V(#QF
M869`<W-C+G)U/BP@,C`P,@HC($%L97AE>2!:86MH87)O=B`\8F%B97)`;6]S
M9V$N;F5T/BP@,C`P-@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)
M9"U697)S:6]N.B!(;W)D92!V,RXQ+5)#,UQN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`V+3`R+3`W(#$Q.C$P*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,3<@,3<Z,#`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!!;&5X97D@6F%K:&%R;W8@/&)A8F5R0&UO<V=A+FYE=#Y<;B(*(DQA;F=U
M86=E+51E86TZ(%)U<W-I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB
M34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#U#4#$R-3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7W1O<"YI;F,Z,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B`F
M(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B(*;7-G<W1R("(B"B+/\.CK[N;E
M[>CE("5S(./N\N[B[B#J(.[Q\_GE\?+BZ^7MZ/X@[N_E\.#VZ.D@[^[DY.7P
MYNKH+"#N\NSE]^7M[?OU(.WHYN4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,X,0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S
M(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W
M"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C,W.0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H>65S=&5R9&%Y*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(B
M"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("+*
MX/+@Z^[C(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*
M"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-S$P(&QI8B](;W)D92]296=I
M<W1R>2YP:'`Z,3`Y.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB
M"FUS9W-T<B`BS_#HZ^[FY>WHY2`G)7,G(.WE(/'J[NWTZ./S\.CP[N+@[>X@
MXB!(;W)D92!296=I<W1R>2(*"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E
M<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E
M<R#MY2#MX.GDY>TN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E
M871E9#H@)7,N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T
M+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O
M("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B+/X._JX"!<(B5S7"(@
MX?OKX"#S\>_E^.WN(._E\.7H[.7M[N+@[>`@XB!<(B5S7"(N7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*
M(EOQ\O#NZN`@)7,@Z.<@)7-=7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=
M7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M
M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@
M)7,@Z.<@)7-=7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C8I("`C+2,M(RTC+2-<;B(*(EOQ\O#NZN`@)7,@Z.<@)7-=(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*
M;7-G<W1R("+(\>_NZ_SG[N+@[>XZ("4N,F;,X2#HYR`E+C)FS.$@*"4N,F8E
M)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B
M6_'R\.[JX"`E<R#HYR`E<UTB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X('1E;7!L871E
M<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("+'X.SE\NKH(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,"!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.2!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;B(*;7-G<W1R("+.[^7PX/;H_R#O[N3DY?#FZN@@)7,@+2#/[N3RXN7P
MYN3E[>CE(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E
M='5P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y('1E;7!L871E<R]M
M86EN=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!L
M:6(O5D93+W-M8BYP:'`Z-#,R(&QI8B]61E,O<VUB+G!H<#HT.30@;&EB+U9&
M4R]F='`N<&AP.C8X,@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE
M("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F
M;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BSO+LY?+\\N4@].O@YNK@[.@@
M[N_E\.#VZ/XHZ.@I+"#J[O+N\/OE(,+[(/7N\NCRY2#N\?/YY?'RXNCR_"XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[L
MZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S('1O
M("5S(&]F("5S(@IM<V=S='(@(EOQ\O#NZN`@)7,@Z.<@)7-=(@H*(R!F=7IZ
M>2P@<&AP+69O<FUA=`HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS
M9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDQ,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A
M<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDP-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D
M(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@
M8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO
M=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S
M96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0HC+"!F=7IZ>0IM<V=I9"`B+"!G
M=7-T:6YG("(*;7-G<W1R(");\?+P[NK@("5S(.CG("5S72(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#<S(&QI8B](;W)D92]&;W)M+G!H<#HR,3,R(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,S0X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HW
M-#8*(RP@9G5Z>GD*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN
M(@HBQ.7I\?+BZ.4Z(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+??@\>[B[NDB
M"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`B,C0M]^#Q[N+NZ2(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R
M-"#WX/'@(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ
M>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(L_PY>3[Y//YX/\@\?+PX.WH
M]N`B"@HC.B!L:6(O2&]R9&4N<&AP.C$V,@HC+"!F=7IZ>0IM<V=I9"`B02!F
M871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^S_#NZ.?N^.O@
M(.KPZ/+H]^7QZN#_(.[XZ.'JX#H\+V(^(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS
M9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV
M871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T
M<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G
M<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3$*(RP@9G5Z>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`BPNWH
M[.#MZ.4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,@HC+"!F=7IZ>0IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("+([._N
M\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ
M,PHC+"!F=7IZ>0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(LCL
M[^[P\B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R(")!32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I
M9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M(RP@9G5Z>GD*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("+"[.7Q\N4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"B,L
M(&9U>GIY"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B24U0(@H*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,C<P"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(M/WY?+M
MX/\@Y^#OZ/'\(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"B,L(&9U
M>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"B,L(&9U
M>GIY"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`BT^_PX.+KY>WH
MY2#Q]^7RX.SH(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0HC
M+"!F=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("+$\//CZ.4@__GH
MZN@B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(L3N
MX>#BZ/+\(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S
M+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ
M*2`@(RTC+2,M(RTC7&XB"B++Z/?M^^4B"@HC(&9U>GIY"B,Z('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B
MQ.[AX.+H\OPZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O
M=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB
M"FUS9W-T<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GDL('!H
M<"UF;W)M870*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,@9G5Z>GDL
M('!H<"UF;W)M870*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`HC+"!F
M=7IZ>0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D[N'@
MXNCR_"#Q\N[KX>7V(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S
M='(@(L3NX>#BZ/+\(._@\/,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+$[N'@XNCR_"#OX/#S
M(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@
M<&AP+69O<FUA=`HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"FUS9VED
M(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T
M<B`BQ.[AX.+H\OP@36]Z:6QL82!3:61E8F%R(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O
M(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BP.3PY?'MX/\@ZNWHX^`B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(L#D\.7Q[>#_
M(.KMZ./@(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!U<V5R(@IM<V=S='(@(L3NX>#BZ/+\(._@\/,B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED
M(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(L#D\.7Q(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM<V=I9"`B061D<F5S<R!";V]K
M(@IM<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(R!F=7IZ>2P@<&AP+69O<FUA
M=`HC(&9U>GIY"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`BS>#Q\O#NZ>KH("T@\_'RX.WNXNK@(._PX.(@
MY.O_(.3P\^/H]2#O[NO\Y^[BX/+EZ^7I(@H*(R!F=7IZ>0HC.B!A9&UI;B]I
M;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM
M<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BT^_PX.+KY>WHY2(*"B,@
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(PHC
M(&9U>GIY"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*(RP@9G5Z
M>GD*;7-G:60@(D%D<R(*;7-G<W1R("+$[N'@XNCR_"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*(RP@9G5Z>GD*;7-G
M:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+E
MZ_\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(L_QY>+D[NWH
M["(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S`*(RP@9G5Z>GD*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`BS_'EXN3N[>CL
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G
M:60@(D%L:6%S(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D%L:6=N(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BS_'EXN3N[>CL(@H*(R!F=7IZ>0HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*
M;7-G<W1R("+"\>4@XN[XY>3XZ.4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(L+QY2#C\//O[_LB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I
M9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(L+QY2#O\.#BX"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*
M(RP@9G5Z>GD*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(L?@[.7R
MZN@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B06QL;W<@
M;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E
M9"!L:7-T('1Y<&4_(@IM<V=S='(@(M#@Y_#E^.CR_"#N[^7PX/;HZ"#Q[B#Q
M[^CQZN#LZ"(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM
M<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB
M"FUS9W-T<B`BP.O\\N7P[>#RZ.+M^^D@25--4"(*"B,@9G5Z>GD*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@
M4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM
M<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\@25--4#HB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N
M871E('1E>'0Z(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A
M;B!386UO82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.CDU(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(L'[Z^X@\^K@Y^#M
M[B#MY>KN\/#EZO+M[N4@Y^W@]^7MZ.4N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U-0HC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B/&(^S_#NZ.?N^.O@(.KPZ/+H
M]^7QZN#_(.[XZ.'JX#H\+V(^(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD
M($)A<F)U9&$B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-2!L:6(O2&]R9&4O0FQO
M8VLO54DN<&AP.C4X"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(L_PZ.ONYN7MZ.4B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@
M(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(LW@\?+P[N7M[B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S0*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.2!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*(RP@9G5Z
M>GD*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("+([/\B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L
M971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(L+[(//B
MY?#E[?LL(/?R[B#U[O+H\N4@[O?H\?+H\OP@_?+S(._@[^KS/R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*(RP@9G5Z
M>GD*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("+/\>7BY.[MZ.PB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"B,L(&9U
M>GIY"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(L_QY>+D[NWH["(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<FUE;FEA;B`H05)-4T-)
M22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R
M(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<S\B"FUS9W-T<B`BQ^#O\.#XZ.+@\OP@[^[D\N+E\.;DY>WHY2#OY?#E
MY"#B^^_NZ^WE[>CE["#N[^7PX/;HZ2#NX?'K\^;HXN#MZ/\_(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,#(*(RP@9G5Z>GD*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D[N'@XNCR_"#Q\N[KX>7V
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(L_N[_OR
MZN`@\^3@Z^CR_"#MY?'S^>7Q\N+S_OGHY2#O\.#BX"(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BS^[O^_+JX"#PY>3@ZO+H
M\.[BX/+\(.WE\?/YY?'RXO/^^>CE(._PX.+@(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS
M9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@
M(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ
M,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R
M97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@
M4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0
M('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS,#(*;7-G
M:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*;7-G
M:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I
M9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z-C`*
M;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M9&UI;BYP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!A
M="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7D
MZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@
M[>4@[>#IY.7M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D
M+B`E<R(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E
M[2XB"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@HC+"!F=7IZ
M>0IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BXB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N
M["!,1$%0+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX.#(*(RP@9G5Z>GD*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*
M(SH@;&EB+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(LWE
M\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE
M;&1S.B(*;7-G<W1R("+$[O'R\^_M^^4@[^[K_SHB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*(RP@9G5Z>GD*;7-G:60@(D)A8VMG<F]U
M;F0B"FUS9W-T<B`BR/'O[NO\Y^[BX/+\(.?MX/?E[>CE(._N(//L[NOWX.WH
M_B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*(RP@9G5Z>GD*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B
MR/'O[NO\Y^[BX/+\(.?MX/?E[>CE(._N(//L[NOWX.WH_B(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S
M<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP
M.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*
M(RP@9G5Z>GD*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`BRN#KY>WDX/#\(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0HC
M+"!F=7IZ>0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("))35`B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ
M,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(L#D
M\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC+"!F=7IZ
M>0IM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M/DX.OE[>W[Y2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*
M;7-G:60@(D)E;&%R=7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`HC+"!F=7IZ>0IM<V=I9"`B0F5L
M9VEU;2(*;7-G<W1R("+0X.?LY?`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B
M"FUS9W-T<B`BT.#G[.7P(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F5N:6XB"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(M/DX.OE[>W[Y2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,PHC+"!F=7IZ>0IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(DE-4"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T
M:&1A>2(*;7-G<W1R("+$Y>W\(/#NYN3E[>C_(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,U-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#I
MY.7M+B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("+-X/'R\.[IZN`Z
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")"
M;&]C:R!4>7!E(@IM<V=S='(@(M#@\?CH\.7MZ.4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*(RP@9G5Z>GD*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B2&]R9&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O
M;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*(RP@9G5Z
M>GD*;7-G:60@(D)O='1O;2(*;7-G<W1R("+"[.7Q\N4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V
M970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II;"(*
M;7-G<W1R("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(L_Q
MY>+D[NWH["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0U]E
M;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G
M_"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*(RP@9G5Z
M>GD*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S
M='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M
M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC
M+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B
M0V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0HC+"!F=7IZ>0IM<V=I9"`B0V%L;2(*;7-G
M<W1R("+.\NSE[>`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,PHC+"!F=7IZ>0IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T
M<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V%M97)O;VXB"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(LOH]^W[Y2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I
M8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C,U,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R
M("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E
M<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y
M<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("+-Y?/DX/?M
M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+T9I;&4O
M0U-6+G!H<#HT-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CM
MZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A
M(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A
M9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B
M0V%N8V5L(@IM<V=S='(@(L[R[.7MX"(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`BSO+LY>W@(.[R]^7RX"#N(._P[N'KY>SE(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C,R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q
M[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*(RP@
M9G5Z>GD*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC
M95]487-K("5S(@H*(SH@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN
M=&5N86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+G!H<#HQ
M,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="XB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N
M86YC95]487-K("5S(@H*(SH@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@
M5F5R9&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO
M;B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD
M($QA8F5L<R(*;7-G<W1R("+*X/+EX^[PZ.@@Z"#LY?+JZ"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R
M("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@
M(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G
M_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*(RP@
M9G5Z>GD*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R[O?M
MX/\@\.#DZ.[QXO_G_"(*"B,@(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S
M+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!S
M<&%C:6YG.B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(.K@ZEQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBT>[U
M\.#MZ/+\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S@*(RP@9G5Z>GD*
M;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G
M_"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED
M(")#96YT97(B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HU-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R
M:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#`*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(R!F=7IZ
M>2P@<&AP+69O<FUA=`HC(&9U>GIY"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C$R"B,L(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*
M;7-G<W1R("+(\>K@\OP@XB#.\N+E\O'RXN7M[?OU(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC
M:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G<W1R
M(")V0V%R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@
M(D-H86YG92(*;7-G<W1R("+.\NSE[>CR_"#HY^SE[>7MZ/\B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-H
M86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(LW@\?+P[NGJ
MZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S
M=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG
M=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@(G9#
M87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*
M;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R("+.\NSE\OSRY2#TZ^#FZN#LZ"#N[^7PX/;H_BCH
MZ"DL(.KN\N[P^^4@POL@]>[RZ/+E(.[Q\_GE\?+BZ/+\+B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D-H:6QE(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D-H:6YA(@IM<V=S='(@(G9#87)D(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B
M0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(R!F=7IZ
M>0HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@
M07!P;&EC871I;VXZ(@IM<V=S='(@(L+[X>7PZ/+E(._PZ.ONYN7MZ.4Z(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+H
MY3HB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ
M>0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L3E
MZ?'RXNCE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*;7-G:60@
M(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`BU.[P[.#R
M(.[R[N'PX.;E[>C_(.3@\OLZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+U9&
M4RYP:'`Z.3$T(&QI8B].970O4TU3+G!H<#HR.30*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC
M+"!F=7IZ>0IM<V=I9"`B0VQE87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I
M9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*
M;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@
M;W5T('5S97(Z("5S(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B
M0VQE87(@=7-E<B(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@
M=7-E<B!D871A(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(L+U[N0B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`HC+"!F=7IZ>0IM<V=I9"`B
M0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K
M871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED
M(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BQ^#J\/OR_"#NZNWN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*
M;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"B,L(&9U>GIY
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E
M(%-I9&5B87(B"FUS9W-T<B`BT^'PX/+\(.SE[?XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"B,L(&9U>GIY
M"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT.#G
MXN7P[?/R_"#B\>4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#;VQO;6)I82(*;7-G<W1R
M("+*X.OE[>3@\/PB"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0HC+"!F=7IZ>0IM<V=I9"`B0V]L;W(B
M"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-2!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z
M,S(V"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,#$@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@HC+"!F=7IZ>0IM
M<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR.#,U"B,L(&9U>GIY"FUS9VED(")#;VQO=7(@<V5L
M96-T:6]N(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-
M4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$Y>GQ\N+HY3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]L<SHB"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@HC+"!F=7IZ>0IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&%D;6EN+V-M
M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M("+*[NSOX.WH_R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B
M0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B
MRN[L[^#MZ/\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-38W"B,L(&9U>GIY"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("+"
MX/CE(.CL_SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-`HC+"!F=7IZ>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+*
MX.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R("+*[NSOX.WH_R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*(RP@9G5Z>GD*;7-G:60@
M(D-O;F1I=&EO;B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA
M<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N(@IM<V=S='(@(LKN[?3HX_/PX/;H_R#S\?+@\.7KX"(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@(D-O;F9I<FT@
M4&%S<W=O<F0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B0V]N
M9V\B"FUS9W-T<B`BRN[L\R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`BS>7SY.#W[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,
M1$%0+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("+-Y?/DX/?M[N4@
M\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<V
M"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I
M;&5D+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L
M($Q$05`N(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*(RP@9G5Z
M>GD*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(L_NZN#GX/+\(,KN[?+@ZO+[
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I
M9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E
M<W-E9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R("+1[N3E\.;@[>CE("5S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"B,L(&9U
M>GIY"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS
M9VED(")#;W!Y(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+U9&4R]S;6(N
M<&AP.C0W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H
M24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B+.^.CA
MZN`@[_#H(//DX.OE[>CH7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@
M2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBS>7SY.#W[>[E(/'NY>3H[>7M
MZ.4@\2#QY?#BY?#N["!,1$%0+EQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LWE\^3@]^WNY2#Q[N7D
MZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")#;W!Y
M('-E;&5C=&EO;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z(@H*(SH@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C$W,"!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-S<*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS
M9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K
M("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R
M("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E
M<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#8W"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T
M<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<R(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA
M;F-E7U1A<VL@)7,B"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-3<*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q
M(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K
M(&)A;&%N8V4N("5S(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@
M36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E
M\.+E\.[L($Q$05`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`BS>7SY.#W
M[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`BS>4@[.[C
M\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("+-Y2#L[N/S
M(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#MX/'R\.[E[2(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@
M<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B2&]R9&4@[>4@[_#@XNCK_.WN(.W@
M\?+P[N7M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RXB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR.#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(L#D\.7Q[>#_
M(.KMZ./@(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D
M\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#0V"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E
M7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.C8X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S
M(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C
M="YP:'`Z,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3S
MZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C<Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`BS>7SY.#W
M[>[E(/'NY>3H[>7MZ.4@\2#QY?#BY?#N["!,1$%0+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB
M(&9O<B!W<FET:6YG+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\
M($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G
M<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@
M)7,B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K
M(&UO9'5L92`E<R(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA
M:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K
M("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M
M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]/
M8FIE8W0N<&AP.C(T,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')E860@)7,N(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3S
MZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR
M_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM
M<V=S='(@(L#D\.7Q[>#_(.KMZ./@(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<R(*;7-G<W1R(")(;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")(
M;W)D92#MY2#O\.#BZ.O\[>X@[>#Q\O#NY>TB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(.WE(._PX.+HZ_SM[B#M
MX/'R\.[E[2(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[
M\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C
M:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-#,*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R
M=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E\.+E\.[L
M($Q$05`N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[
M\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(LWE(.SNX_,@[O+J\/OR_"#L[N3S
MZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4@[>4@[_#@XNCK_.WN(.W@\?+P[N7M(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@
M7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M,C,*(RP@9G5Z>GD*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("+"^_7N
MY"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"B,L(&9U>GIY
M"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7M
MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"B,L(&9U>GIY
M"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(M/Q[^7X[>XB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M;7-G:60@(D-R96%T92(*;7-G<W1R("+1[N?DX/+\(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"B,L(&9U
M>GIY"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(M'NY^3@\OPB"@HC
M(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BT>[GY.#R_"#M
M[N+[Z2#O\.[TZ.O\(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*
M(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B
M0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R("+1[N?DX/+EZ_PB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q.0HC+"!F=7IZ>0IM<V=I9"`B0W)E9&ET
M(&-A<F0@;G5M8F5R(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")#
M<F]A=&EA(@IM<V=S='(@(M'NY^3@\OPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@
M(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(M+EZO/YX/\B"@HC
M(&9U>GIY"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("+1[N?DX/+EZ_PB"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G
M:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("+2Y>KS^>7E(.+PY>S_(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("+2
MY>KS^>7E(.+PY>S_(@H*(R!F=7IZ>0HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`BTN7J
M\_G@_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*(RP@
M9G5Z>GD*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`BS>#Q
M\O#NZ>KH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R
M("+2Y>KS^>7E(.+PY>S_(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF
M;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`BQ^#DX/?H+"#G
MX._S\>K@Y>S[Y2#O\.@@XO7NY.4@XB`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM
M<V=I9"`B0W5T(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO
M<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"B,L
M(&9U>GIY"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+$
MY>GQ\N+HY3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+
M3TDX+54I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3`@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@
M(L3$(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R-SD*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T
M<B`BQ>;EY.WEXNWN(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED
M(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,C<W"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,#(@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`BQ.#R
MX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS
M9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-SDV"B,L(&9U>GIY"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R("+/[NOM[N4@[N_H\>#MZ.4Z(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Q"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`BQ>;EY.WEXNWN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M("+3Y.#KZ/+\(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*
M(RP@9G5Z>GD*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(L?@[.7RZN@B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`BR.S_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z
M(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"B,L(&9U>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@(M/DX.OH\OPB"@HC
M(&9U>GIY"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(M;BY?(@[^X@
M\^SNZ_?@[>C^(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HY-@IM<V=I
M9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+/\.[TZ.O\(._N(//L[NOW
MX.WH_B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM
M<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW,2!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R-B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C0R,@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C0S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(M/DX.OH
M\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S
M='(@(M/DX.OH\OPB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM
M<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HW-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$P
M,0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B
MS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<R(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("+3Y.#KZ/+\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC
M7&XB"B+SX?#@\OP@\?+NZ^'E]B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("+-X/'R\.[IZN@@[^[K
M_.?NXN#RY>O_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(')O=R(*
M;7-G<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@
M:61E;G1I='DB"FUS9W-T<B`BT^3@Z^CR_"#B^^'PX.WM^^D@[_#N].CK_"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B
M82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+SX?#@\OP@\?+NZ^'E]B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G
M<W1R("+3Y.#KZ/+\(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@
M[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@
M9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`BT^3@Z^CR_"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M
M(@IM<V=S='(@(L[OZ/CH\N4@[_#NX>OE[/,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.30R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(L_NZ^WNY2#N[^CQX.WHY3HB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y-PIM
M<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4N<&AP.C(P,0IM<V=I9"`B1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`BS^[D\.[A[>[Q\N@@X?OKZ"#GX._H\>#M^R#B(.;S\.W@ZR#DZ_\@X.3L
MZ.WH\?+PX/+N\.`N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE9G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R("+*X/+@Z^[C(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM
M<V=S='(@(L[R[N'PX.;@\OP@XO#E[/\@XB`R-"WWX/'NXN[L(/3N\.S@\N4_
M(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED
M(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`BQ/#SX^CE(.W@\?+P[NGJZ"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0HC+"!F=7IZ>0IM
M<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("+-X/'R
M\.[IZN@@[N'NZ^[WZN@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P-@HC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BS>#Q\O#N
MZ>KH(.[A[NON]^KH(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H<#HQ.3$*
M;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R("+3Y.#KZ/+\(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U
M"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<"(*;7-G<W1R("+-Y2#B^^?[XN#I\N4@;6%I;G1E;F%N8V4N<&AP(.WE[^[Q
M\.7D\?+BY>WM[B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(L(@[^7PXN[I(/'R\.[JY2#SZN#G
MX.W[(.CLY>W@(._NZ^7I/R#%\>OH(.3@+"#O[O'RX.+\\N4@X^#K[O?J\SH@
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0HC+"!F=7IZ>0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@
M86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("+'X./P\^?H\OPB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S
M(@IM<V=S='(@(L?@X_#SY^CR_"`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3$Q"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G
M:60@(D4M36%I;"(*;7-G<W1R("))35`B"@HC.B!L:6(O3F5T+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G
M:60@(D5D:70B"FUS9W-T<B`BT.7DX.KRZ/#NXN#MZ.4B"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3`*;7-G:60@(D5D:70@0FQO8VLB
M"FUS9W-T<B`BT.7DX.KRZ/#NXN#R_"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S8@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PHC+"!F=7IZ>0IM<V=I9"`B
M161I="!097)M:7-S:6]N<R(*;7-G<W1R("+-X/'R\.[IZN@@[^[K_.?NXN#R
MY>O_(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`BT_'R
MX.WNXNK@(._PX.(@Y.O_("5S(@H*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U
M>GIY"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@
M;W!T:6]N<R!F;W(Z(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,@9G5Z>GDL('!H
M<"UF;W)M870*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC(&9U>GIY+"!P:'`M9F]R;6%T
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B
M"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.38W"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C
M:"XB"FUS9W-T<B`BPN#X($5M86EL.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.3DS"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("+/\.[WX/\@Z.WT[O#LX/;H_R(*"B,Z(&QI8B].970O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E
M=V%Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R
M("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T
M<B`BS?/KY>+NZ2#PY>?SZ_SRX/(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-3`*;7-G
M:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BS?/KY>+NZ2#PY>?SZ_SRX/(N
M(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%
M;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4T-PIM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`BRN[M\N7J\?+M[N4@
M[.7M_B#O[B#MX.;@\NCH(._PX.+NZ2#J[>[OZN@@[/OXZ"(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR-3DR(&QI8B](;W)D92]&;W)M+G!H<#HR.#`P"B,L
M(&9U>GIY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT.#GXN7P
M[?/R_"#B\>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y
M,`IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*
M;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R
M:71R96$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X
M"FUS9VED(")%<G)O<B(*;7-G<W1R("+.^.CAZN`B"@HC.B!L:6(O2&]R9&4O
M5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C
M<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@
M(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S
M(@IM<V=S='(@(LK@YN3[Y2`Q-2#LZ.WS\B(*"B,@9G5Z>GD*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(LK@YN3[Y2`R(.SH[?/R^R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E
M<GD@,S`@<V5C;VYD<R(*;7-G<W1R("+*X.;D^^4@,S`@\>7J\^WD(@H*(R!F
M=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M("+*X.;D^^4@-2#LZ.WS\B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(LK@YN3[Z2#PX.<@
M[_#H(.+U[N3E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(LK@YN3[Y2#O[NOWX/'@(@H*
M(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R
M("+*X.;D\_X@[.CM\_+S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R("+/\.CLY?`@
MY^W@]^7MZ.DZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M
M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%
M>&5C=71E(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-#<U(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BT.#Q^.CPZ/+\(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@HC+"!F=7IZ>0IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(M#@Y^+E\.WS
M\OP@XO'E(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS
M9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<W"FUS
M9VED(")%>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED
M(")&1R!#;VQO<B(*;7-G<W1R("+(\>_NZ_SG[N+@\OP@Y^W@]^7MZ.4@[^X@
M\^SNZ_?@[>C^(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I
M9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R("+"[O'Q\N#M[N+KY>WHY2#MX/'R\.[E
MZB#MY2#SY.#K[O'\+B(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW
M-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q
M[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!4"XB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WH
MY2#Q(/'E\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<Q-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O
M;2!<(B5S7"(N(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7P
MXN7P[NP@3$1!4"XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S(R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N
M(@IM<V=S='(@(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7PXN7P[NP@3$1!
M4"XB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PHC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<U
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@
M=&\@7"(E<UPB+B(*;7-G<W1R("+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q(/'E
M\.+E\.[L($Q$05`N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0V-0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*
M;7-G<W1R("+4X.GK(._PZ.W_\CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3@*(RP@9G5Z>GD*;7-G:60@(D9A:7(B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(L[R(.KNX^Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@
M27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!L:6(O2&]R
M9&4O0TQ)+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*
M;7-G<W1R("+.^.CAZN`@Z.SO[O#RX#H@(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("+4X.KQ
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0HC+"!F=7IZ>0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`BU.#J\2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L
M<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(P"B,L(&9U>GIY"FUS9VED(")&97<@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.30X"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,S(*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S,V"FUS9VED(")&:6=L
M970@9F]N="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,@
M9G5Z>GD*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")&:6QE(@IM<V=S='(@(M3@Z>LB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(M7PX.WHZ^CYX"(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L(&9U>GIY"FUS9VED
M(")&:6QE($YA;64B"FUS9W-T<B`BR.S_(@H*(R!F=7IZ>0HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDX-`HC+"!F=7IZ>0IM<V=I9"`B1FEL92!S96QE8W1I
M;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE(._P[N'KY>S[.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#DP"B,L(&9U>GIY"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z
M.#@U"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S
M+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,@9G5Z>GD*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S
M(@IM<V=S='(@(M3HZ_SR\/LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")&:6YL86YD(@IM
M<V=S='(@(LKN[._@[>C_(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@HC
M+"!F=7IZ>0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("+/\.CLY?`@Y^W@
M]^7MZ.DZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4U"FUS9VED
M(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@
M(B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR,S<@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#M
MY2#MX.GDY>TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R
M("+(\>_NZ_SG[N+@\OP@Y^W@]^7MZ.4@[^X@\^SNZ_?@[>C^(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"B,L(&9U>GIY"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O[N3DY?#F
MZ.+@Y?(@[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@0U123"M0
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B
M(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@HC+"!F
M=7IZ>0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(L_@
M\.[K_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*(RP@9G5Z
M>GD*;7-G:60@(D9O<FUS(@IM<V=S='(@(LCL_R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-34*(RP@9G5Z>GD*;7-G:60@(D9O<G5M<R(*;7-G
M<W1R("+'X.SE\NKH(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q
M,0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`BS^7PY?'KX/+\
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,`HC+"!F=7IZ>0IM<V=I9"`B1G(B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(L[R(.KNX^Y<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<
M;B(*(L[R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R("+([/\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-
M971R;W!O;&ET86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`HC
M+"!F=7IZ>0IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBSO(@ZN[C[EQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN
M(@HBSO(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-0HC+"!F=7IZ>0IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@
M(RTC+2,M(RTC7&XB"B+.\B#J[N/N7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.\B(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE(._P[N'KY>S[
M.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+"
MX/CE(.CL_SHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")'86)O;B(*;7-G<W1R(")V0V%R
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T
M92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D
M92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1VAA;F$B"FUS
M9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*(RP@9G5Z>GD*;7-G:60@
M(D=I=F5N($YA;64B"FUS9W-T<B`BR.S_(@H*(R!F=7IZ>0HC(&9U>GIY"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*
M;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(L_N\/+@ZR(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R("+/
MY?#EZ?+H(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,CD*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(L_N
MZ/'J(.(@1V]O9VQE(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM
M<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("+/[NCQZB#B($=O;V=L92(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S8*;7-G
M:60@(D=R87ES8V%L92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")'<F5E
M:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W)E
M96YL86YD(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D=R
M96YA9&$B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]'<F]U<"YP:'`Z-3D@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(L_P[N'KY>S@(._PZ"#O[N_[\NKE(.+[]^7PZNWS
M\OP@)7,N(-'E\.+E\"#QZN#GX.LB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z,3$X(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E
M<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP
M96YD:75M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M
M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["Y<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC
M+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N
M["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M
M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#B
MY?#N["Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@
M(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#Q
MY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`BP_#S[^_[(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B
M(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S
M:6]N<R(*;7-G<W1R("+#[O'R_"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY
M"FUS9VED(")'=6EN96$B"FUS9W-T<B`BTN7LX"(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D=U>6%N82(*
M;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C0*;7-G
M:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*(RP@9G5Z>GD*;7-G
M:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("+`
MY/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*
M;7-G:60@(DAA:71I(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C(*(RP@9G5Z>GD*;7-G:60@(DAA>F4B"FUS9W-T<B`BS^[D\>K@Y^K@
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDR,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,CDR,0HC+"!F=7IZ>0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(L_NY/'J
MX.?JX"(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q
M"FUS9VED(")(96%D97)S(@IM<V=S='(@(L?@X^[K[N+JZ"(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"B,L
M(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(LCL[^[P\B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")(96)R97<@*$E3
M3RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`HC+"!F=7IZ>0IM<V=I9"`B
M2&5I9VAT(@IM<V=S='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O2&5L<"YP
M:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ.#8@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C0*;7-G
M:60@(DAE;'`B"FUS9W-T<B`BS^[D\>K@Y^K@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U<VEN
M9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S4*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R("+/[N3QZN#GZN`B
M"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M
M:7-P:&5R92(*;7-G<W1R("+/[NOS^.#PZ.4B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R("+-Z.;E(._PY>3Q\N#BZ^7MX"#H[?3N\.S@]NC_(.CG(/'@[.[C
M[B#MX/?@Z^`@].#IZ^`Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(DAI9V@B"FUS9W-T<B`B
MS>CJ[N/DX"(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED
M(")(;U]M92(*;7-G<W1R("+/[O#RX.LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI
M8B](;W)D92YP:'`Z,34S.0IM<V=I9"`B2&]M92(*;7-G<W1R("+/[O#RX.LB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!
M9&1R97-S(@IM<V=S='(@(L3N[.#X[>CI(.#D\.7Q(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")(;VUE($1I<F5C=&]R
M>2(*;7-G<W1R("+*X/+@Z^[C(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BQ.[L
MX/CMZ.D@\N7KY?3N[2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@
M(L_N\/+@ZR(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#,U"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z,3(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<
M(B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N
M,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H(._P[O'L[O+PY2#GX._P
M[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R
M('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,3DR"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN
M;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L
M(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED
M(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y"FUS
M9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C,U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_
M("5S(.WE(.W@Z>3E[2XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z
M,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-SD@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P"B,L(&9U>GIY"FUS9VED
M("))4"!!9&1R97-S(@IM<V=S='(@(L#D\.7Q(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O:7!B87-I8RYP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[E
MZBXB"@HC.B!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0HC+"!F=7IZ
M>0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@
M(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G
M:60@(DEC96QA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(M+N
MZ_SJ[B#HZN[MZN@B"@HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M26-O;G,@9F]R("5S(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G
M<W1R("+(ZN[MZN@@\2#RY>KQ\N[L(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S
M='(@(LCL_R#O\.[TZ.O_.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I
M<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN
M9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y
M"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*
M;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G
M92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+-X.?@Y"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8U"B,L(&9U>GIY"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("+*X/#RZ.WJZ"(*
M"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B
M"FUS9W-T<B`BR.SO[O#R+"#XX.,@)60B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F
M:65L9#H@)7,B"FUS9W-T<B`BR.SO[O#RZ/#NXN#M[B#O[NOE.B`E<R(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D
M(&9I96QD<SHB"FUS9W-T<B`BR.SO[O#RZ/#NXN#M^R#O[NO_.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,`HC+"!F=7IZ>0IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B
MT>[NX?GE[>CE(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T
M"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@
M9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(L_NYN#K\^GQ\N`L(.+BY>3H\N4@PN#XZ"#H[/\@[^[K
M_.?NXN#RY>O_(.@@[^#P[NO\(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0HC+"!F
M=7IZ>0IM<V=I9"`B26YD:6$B"FUS9W-T<B`BTN7KY?3N[2(*"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(L_NZ_SG
M[N+@\N7KZ"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@
M(M+EZ^7T[NTB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PHC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBR./M
M[O#H\.[BX/+\(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0HC
M+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HBS_#N
M]^#_(.CM].[P[.#VZ/]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+([?3N\.S@]NC_(.X@\>7PXN7PY2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*(RP@9G5Z>GD*;7-G
M:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@
M(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"B,L(&9U>GIY"FUS
M9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("+1[N[A^>7MZ.4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!);6%G92(*;7-G
M<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED("));G-E<G0@5&%B;&4B
M"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(DEN
M<V5R="!796(@3&EN:R(*;7-G<W1R("+3Y.#KZ/+\(._@\/,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*
M;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,@HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HB\^'PX/+\(/'R[NOA
MY?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@
M(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("+1[N[A^>7M
MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("+1
M[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("+1
M[N[A^>7MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#4*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@869T97(B"FUS9W-T<B`BT>[NX?GE[>CE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"B,L
M(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(M'N[N'Y
MY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E
M(@IM<V=S='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`BT>[NX?GE
M[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S
M='(@(M/DX.OH\OP@[^#P\R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#,*(RP@9G5Z>GD*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(LWE(.SNX_,@[O+J\/OR_"#L[N3SZ_P@36%I;G1E;F%N8V5?5&%S:R`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,#<Y"B,L(&9U>GIY"FUS9VED("));G1E9V5R(@IM<V=S
M='(@(M'NY^3@\OPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S-PHC+"!F
M=7IZ>0IM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(M'NY^3@\OPB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,38W(&QI8B](;W)D92]#
M;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HR,3(*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS
M9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`Y,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$V,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(S-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,P,R!L
M:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV
M86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BT.#A[O?HZ2#@
MY/#E\2(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P.2!L:6(O
M2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+T-O;7!R
M97-S+V1B>"YP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&9I;&4@
M9F]R;6%T(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,@9G5Z>GD*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0HC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`BS>7J[O#PY>KR[>[E(.CL
M_RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;W(@;6ES
M<VEN9R!P87)A;65T97)S+B(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A
M<G1N97(@:60N(@IM<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@
M<')O9'5C="!C;V1E+B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F=7IZ>0IM<V=I9"`B
M26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BS>#Q\O#NZ>KH(@H*(R!F=7IZ
M>0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R
M96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("+-Y>KN\/#EZO+M[N4@Z.S_+B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`W-2!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$R-3@*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T
M(@IM<V=S='(@(M#@X>[WZ.D@X.3PY?$B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BT.#A[O?HZ2#@Y/#E\2(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`BT.#A[O?HZ2#@
MY/#E\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*(RP@9G5Z
M>GD*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("+-Y>KN\/#EZO+M[N4@Z.S_
M+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*
M(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<
M;B(*(L3EZ?'RXNCE.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"B,L
M(&9U>GIY"FUS9VED("))<F5L86YD(@IM<V=S='(@(LKN[._@[>C_(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,`HC+"!F=7IZ>0IM<V=I9"`B27-R865L(@IM<V=S='(@(LKN[._@[>C_(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CD*(RP@9G5Z>GD*;7-G:60@(DET86QI8R(*;7-G<W1R("+%
MYN7D[>7B[>XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(L7F
MY>3MY>+M[B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,*(RP@9G5Z>GD*;7-G:60@(DIA<&%N(@IM<V=S='(@(L+MZ.S@
M[>CE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(DIA<&%N
M97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<P"B,L(&9U>GIY"FUS9VED(")*=6YE(@IM
M<V=S='(@(M+E[.`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,X"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y(@IM
M<V=S='(@(M'NY^3@\OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0HC+"!F=7IZ>0IM<V=I9"`B2G5S=&EF
M>2!#96YT97(B"FUS9W-T<B`BT>[GY.#R_"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"B,L(&9U>GIY"FUS
M9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`BT>[GY.#R_"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"B,L
M(&9U>GIY"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`BT>[GY.#R_"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@
M(M'NY^3@\OPB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T
M<B`BQ.#RX"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
MS>#Q\O#NZ>KH(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T"FUS
M9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3D*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("+1[N[A
M^>7MZ.4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@
M(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")+;W)E86X@
M*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("+0
MX/'JZ^#DZN`B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("+?Y_OJ(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED("),87-T($AA;&8B
M"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N
M9V4B"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V
M(&QI8B]";&]C:R]M;V]N+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B3&%S="!1
M=6%R=&5R(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-
M4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+!^_'R\/OI(/'RX/#R(@H*(SH@;&EB
M+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R(*;7-G<W1R("+/\.7D^^3S^>CI(.+U[N0@X?OK.B`E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("+/\.7D^^3S^>CI
M(.+U[N0@X?OK.B`E<R#Q(.KN[._\_O+E\.`@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z-S$T"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R
M("+/\.7D^^3S^>CI(.+U[N0@[>4@Y^#TZ.KQZ/#NXN#M(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY
M"FUS9VED("),871V:6$B"FUS9W-T<B`BT>[GY.#R_"(*"B,@9G5Z>GD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y
M"FUS9VED("),87EO=70B"FUS9W-T<B`BPOOU[N0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DQE9G0B"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(N_E\.7LY?'RZ/+\(.+BY?#U(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,Q,#@*(RP@9G5Z>GD*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S
M='(@(L_PZ.SE\"#G[>#WY>WHZ3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$P-`HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`BS_#H
M[.7P(.?MX/?E[>CI.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G
M:60@(DQE=F5L(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM
M<V=I9"`B3&EB97)I82(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y
M86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@1')I>GIL
M92(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS
M9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(W"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN($5A<FQY(@IM
M<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM
M<V=S='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR.0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B
M"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN('=I=&@@
M5&AU;F1E<B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N
M;W<B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,R"B,L(&9U>GIY"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R("+"]>[D(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M,3@*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`BPO7NY"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R
M97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP
M.C$X,@HC+"!F=7IZ>0IM<V=I9"`B3&EN:W,B"FUS9W-T<B`BPO7NY"(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED
M("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(M'OZ/'NZB#PX.?DY>ONXB#O
M[N3QZN#GZN@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),
M:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y-`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U!<F-H
M:79E(@IM<V=S='(@(LCQZN#R_"(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E
M<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@
M(M'OZ/'NZB#PX.?DY>ONXB#O[N3QZN#GZN@B"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B(._NY/'JX.?JZ"(*"B,Z(&QI8B](;W)D
M92]-24U%+TAE861E<G,N<&AP.C4Y,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U/
M=VYE<B(*;7-G<W1R("+1[^CQ[NH@\.#GY.7K[N(@[^[D\>K@Y^KH(@H*(SH@
M;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"B,L(&9U>GIY"FUS9VED
M("),:7-T+5!O<W0B"FUS9W-T<B`BT>_H\>[J(/#@Y^3EZ^[B(._NY/'JX.?J
MZ"(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ
M"B,L(&9U>GIY"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("+(\>K@
M\OPB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M,`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("+(
M\>K@\OPB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HBSOCHX>K@(._PZ"#S
MY.#KY>WHZ%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N
M,RDI("`C+2,M(RTC+2-<;B(*(LWE\^3@]^WNY2#Q[N7DZ.WE[>CE(/$@\>7P
MXN7P[NP@3$1!4"Y<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H
M,BXP+C,I*2`@(RTC+2,M(RTC7&XB"B+-Y?/DX/?M[N4@\>[EY.CMY>WHY2#Q
M(/'E\.+E\.[L($Q$05`N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,B"FUS9W-T<B`BS^[H\>HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.0HC+"!F=7IZ>0IM<V=I9"`B3&ET:'5A;FEA(@IM
M<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@
M=&EM93H@(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`BR^[J
MX.OHY^#VZ/\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C(R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("+0X/'O[NON
MYN7MZ.4B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`BPO7NY"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F
M('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O
M=70B"FUS9W-T<B`BPOOU[N0B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`BT_?E\NW@_R#GX._H
M\?PB"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(L+U[N0B"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3DU"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960@8F5C
M875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+B(*;7-G<W1R("(B"B+/[B#JX.KH["WR[B#O\.CWZ.W@["#B
M]>[D(.(@\>CQ\N7L\R#MY2#SY.#K\?\N(,+E\.[_\NWEY2#B\>7C[BP@PN#X
MZ"#H[/\@(@HB[^[K_.?NXN#RY>O_(.CKZ"#OX/#NZ_P@X?OKZ"#BXN7DY>W[
M(.WEXN7P[>XN(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY,0HC+"!F=7IZ
M>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("))35`B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3,V.0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT
M(@IM<V=S='(@(L+[]>[D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q
M"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R("+([/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,Y.2!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,W"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("+,S"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I
M9"`B36%C86\B"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@(L_N
M]_+@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B
M36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN
M7VLN+BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS
M9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-86QA>7-I82(*;7-G<W1R
M("))35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DE-
M4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R("))35`B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*(RP@
M9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(DE-4"(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F
M(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD
M(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB
M"FUS9W-T<B`BS>#Q\O#NZ>K@(/'OZ/'JX"#JX/+EX^[PZ.D@Z"#VXN7R[N(@
MZ/4@[O+NX?#@YN7MZ/\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$U-`IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@U"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38Y"FUS9VED(")-
M87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"B,L(&9U>GIY
M"FUS9VED(")-87)C:"(*;7-G<W1R("+/[NCQZB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*
M;7-G:60@(DUA<F=I;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS
M9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM
M<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L
M9',B"FUS9W-T<B`BT>[B[^#DX/[YZ.4@[^[K_R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I
M9"`B36%U<FET86YI82(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B36%U<FET:75S(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO
M=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#@*(RP@9G5Z>GD*;7-G:60@(DUA>"!M97-S86=E
M('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O
M87!I+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<R(*;7-G<W1R("+,X.KQZ.S@Z_SM[N4@ZN[KZ/?E\?+B
M[B#Q\O#@[>CV(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDP,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(R,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,PIM<V=I
M9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-"!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DUA>2(*;7-G<W1R
M("+%YN7D[>7B[>XB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA>6]T
M=&4B"FUS9W-T<B`BPOOU[N0B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@
M(L?@[.7RZN@B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`BT.7FZ.P@[.7M_CHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8P"B,L(&9U>GIY"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("+3Y.#K
MZ/+\(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM
M<V=I9"`B365S<V%G92(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I
M9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T
M92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS
M9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S
M='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@;&EB
M+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B
MP.3PY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO
M<F1E+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H
M;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-PIM<V=I9"`B365T
M<FEC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(DE-4"(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B
M36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,S"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS
M9W-T<B`BSOCHX>K@(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W,B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I
M9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG
M(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO
M8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R("+([._N\/(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I
M960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(DUO
M9&EF>2!54DPB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S0*(RP@9G5Z>GD*;7-G:60@(DUO9'5L=7,B
M"FUS9W-T<B`BT?;E[>#PZ.DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY,`HC+"!F=7IZ>0IM<V=I9"`B36]N86-O(@IM<V=S
M='(@(DE-4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B
MRN[L\R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3@X"B,L(&9U>GIY"FUS
M9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT.#GXN7P[?/R
M_"#B\>4B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(L7FY>SE\?_W[>XB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S
M97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R
M("+4X.?[(,OS[?LB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL
M92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD
M<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B24U0
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("+*[NSOX.WH
M_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T
M"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(LKN[._@
M[>C_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S4*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("+*[NSO
MX.WH_R(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M-3`Y(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS
M9VED(")-;W9E($1O=VXB"FUS9W-T<B`B[^7PY>SE\?+H\OP@XNWHYR(*"B,@
M9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$S(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B[^7PY>SE\?+H\OP@XNOEXNXB"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4Q-R!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*
M;7-G<W1R("+OY?#E[.7Q\NCR_"#B[_#@XNXB"@HC(&9U>GIY"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C4P-2!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R("+O
MY?#E[.7Q\NCR_"#BXN7P]2(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(N_E\.7LY?'RZ/+\(.+MZ.<B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C,@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+O
MY?#E[.7Q\NCR_"#BXN7P]2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B36]Z86UB:7%U
M92(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,3@X"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-38*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0V"B,L(&9U>GIY"FUS9VED(")-
M=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`BS^[K[>[E(.[OZ/'@[>CE(._P
M[N'KY>S[.B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R("+3]^7R[>#_(.?@[^CQ
M_"(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(L+@^.`@Z.WT[O#L
MX/;H_R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*;7-G:60@
M(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z-#,*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR
M"B,L(&9U>GIY"FUS9VED(")->6%N;6%R(@IM<V=S='(@(LK@Z^7MY.#P_"(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN
M8SHW"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R("+([/\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B
M3F5T:&5R;&%N9',B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE
M<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I
M9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E
M($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS
M9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*(RP@9G5Z
M>GD*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`BS>[B^^4B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E<B(*
M;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`BS>[BX/\@ZN#RY>/N
M\.C_(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#$@
M;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#<*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.3<@;&EB+TAO<F1E+U1E>'0O
M1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("+-[N+[Y2#Q[N[A^>7M
MZ/\B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(L+E\.WS\OSQ_R#J(.W@\?+P[NGJX.PB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").
M97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*
M;7-G:60@(DYE=R!:96%L86YD(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B
M3F5W('!A<W-W;W)D(@IM<V=S='(@(L_@\.[K_"(*"B,Z(&QI8B](;W)D92]!
M=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S
M=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED(").97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM
M<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC(&9U>GIY
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`BS>[B[O'RZ"(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*(RP@9G5Z>GD*;7-G:60@
M(DYE=W-G<F]U<',B"FUS9W-T<B`BT^3@Z^CR_"(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(L3@
MZ^7E(@H*(R!F=7IZ>0HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`BT>OEY//^^>#_(@H*
M(R!F=7IZ>0HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S
M='(@(M'KY>3S_OG@_R#Q\O#@[>CVX"(*"B,Z(&QI8B](;W)D92]522]086=E
M<BYP:'`Z,3`S"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R("+$X.OE
MY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(DE-4"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@HC
M+"!F=7IZ>0IM<V=I9"`B3FEG97)I82(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0HC+"!F=7IZ>0IM<V=I
M9"`B3FEG:'0B"FUS9W-T<B`BS>CJ[N/DX"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B
M3FEU92(*;7-G<W1R("+-Z.KNX^3@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B3F\B"FUS9W-T<B`BS>7R(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP
M:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(T-0HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HR-C<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HS.#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VUC
M86PN<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@
M[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@8VAA;F=E+B(*;7-G<W1R("+.\NSE[>CR_"#HY^SE[>7MZ/\B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H<#HU,#@@;&EB+TAO
M<F1E+U5T:6PN<&AP.C<V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+B(*;7-G<W1R("+-Y2#A^^ON(//JX.?@[>X@\>[N\N+E\O'RXO/^^>7I(.CM
M].[P[.#VZ.@@Y.O_(.K@\N7C[O#HZ2!344PN(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(L3K_R#M
MX/'R\.[EZB!,1$%0(.WE(.'[Z^X@\^K@Y^#M[B#Q[N[RXN7R\?+B\_[YY>D@
MZ.WT[O#LX/;HZ"XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C<R"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`BS>4@X?OK[B#SZN#GX.WN(/'N[O+B
MY?+Q\N+S_OGEZ2#H[?3N\.S@]NCH(.3K_R#JX/+EX^[PZ.D@4U%,+B(*"B,Z
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<R-0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RXB"FUS9W-T<B`BS>4@X?OK[B#SZN#GX.WN(/'N[O+BY?+Q\N+S
M_OGEZ2#H[?3N\.S@]NCH(.3K_R#JX/+EX^[PZ.D@4U%,+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D
M:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B3F\@9&5S=&EN871I;VX@
M<W5P<&QI960N(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D92]"
M<F]W<V5R+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@(DYO(&9I;&4@=7!L;V%D
M960B"FUS9W-T<B`BR.S_(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"B,L(&9U>GIY"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`BP.3P
MY?'@\B#SXN7D[NSKY>WH_R`E<R#MY2#MX.GDY>TN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-#`*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T
M<B`BS>#Q\O#NZ>KH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(LW@\?+P[NGJZ"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI
M960N(@IM<V=S='(@(M'N[N'YY>WHY2(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA;64@<W!E
M8VEF:65D+B(*;7-G<W1R("+!^^ON(//JX.?@[>X@[>7J[O#PY>KR[>[E(.?M
MX/?E[>CE+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S<*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S
M='(@(L'[Z^X@\^K@Y^#M[B#MY>KN\/#EZO+M[N4@Y^W@]^7MZ.4N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJ
MX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O075T:"]I;6%P+G!H<#HQ,#@*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@Y.O_(._P
M[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("+-Y?(@[>#Q\O#NY>H@Y.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O
M[B!344PB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O2&]R
M9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-Y?(@[>#Q\O#NY>H@
MY.O_(._P[O;EY//P^R#@\_+E[?+H].CJX/;HZ"#O[B!344PB"@HC.B!L:6(O
M2&]R9&4O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[VY>3S\/L@X//RY>WRZ/3H
MZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HX-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BS>7R(.W@\?+P[N7J(.3K_R#O\.[V
MY>3S\/L@X//RY>WRZ/3HZN#VZ.@@[^X@4U%,(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV
M"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]61E,N<&AP.C<V-@HC+"!F=7IZ>0IM<V=I9"`B3F\@<75O=&$@<V5T+B(*
M;7-G<W1R("+'X.SE\NKH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L
M97,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#@R
M"B,L(&9U>GIY"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G
M<W1R("+"^R#MY2#SZN#GX.OH(._@[^KH(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@<VED97,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R
M("+'X.SE\NKH(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R
M-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@
M9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#BXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG
M[N+@\N7K_R#H(._@\.[K_"(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H
M<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S
M='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.3,*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,3`*;7-G
M:60@(DYO('9A;'5E<R(*;7-G<W1R("+-Y2#N[_#EY.7KY>WN(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@
M=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B
M3F]N92(*;7-G<W1R("(M[>4@XOOA\.#M+2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I
M;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#@*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS
M9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(M'EXN7P[>[E(._N
MZ_/XX/#HY2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C0Q"B,L(&9U>GIY"FUS9VED(").;W0@
M069T97(B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(L?@[.7RZN@B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C0Q-0HC+"!F=7IZ
M>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(LK@\N#K[N,B"@HC
M.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@
M(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'Y
MY>WHY2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`BQ^#LY?+J
MZ"(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,#@@;&EB+U9&
M4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,@HC.B!L:6(O5D93+G!H<#HR-CD@
M;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P,2!L:6(O5D93+G!H<#HS
M,38*(SH@;&EB+U9&4RYP:'`Z,S,S(&QI8B]61E,N<&AP.C,V-B!L:6(O5D93
M+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI8B]61E,N<&AP.C4W-"!L
M:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y"B,Z(&QI8B](;W)D92]3
M97-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S:6]N2&%N9&QE
M<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3<U
M(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"B,L(&9U>GIY"FUS9VED(").;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`BQ^#LY?+JZ"(*"B,Z('-E
M<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*(RP@9G5Z>GD*;7-G:60@
M(DYO=&EC92(*;7-G<W1R("+'X.SE\NKH(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M8F5R(@IM<V=S
M='(@(LWHZN[CY.`B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U,`HC+"!F
M=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#(Y"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R("+([/\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@
M(",M(RTC+2,M(UQN(@HB\^'PX/+\(/'R[NOAY?8B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`BR.S_(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T-`HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T
M<B`BS>4@[.[C\R#N\NKP^_+\(.SNY//K_"!-86EN=&5N86YC95]487-K("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T
M"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX-S$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*
M;7-G<W1R("+2Y>S@(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(LW@
M\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3$P.`HC+"!F=7IZ>0IM<V=I9"`B3V-T86PB"FUS9W-T<B`BQ>;EY.WEXNWN
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C
M=&]B97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,R.`HC+"!F=7IZ>0IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(L?@X^[K[N+N
MZB(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B
M3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@
M9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BS^#P
M[NO\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B
MPN#X(.'P[O/GY?`@[>4@[^[DY.7PYNCBX.7R(.[O]NC^(._E]^#RZ"X@Q.O_
M(._E]^#RZ"#MX.;LZ/+E($-44DPK4"XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0HC+"!F=7IZ>0IM<V=I
M9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("+"
MX/@@16UA:6PZ(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS
M9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O
M<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N
M<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,`IM<V=I9"`B3W!E;B!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO
M="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(LW@\?+P[NGJZ"(*
M"B,@9G5Z>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC.B!S
M97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T
M<B`BS>#Q\O#NZ>KH(.3K_SH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*(RP@
M9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("+-X/'R\.[IZN@@
M[^[K_.?NXN#RY>O_(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T
M<B`BS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_R(*"B,@9G5Z>GD*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G
M<W1R("+.\./@[>#IY^7P(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O
M<FUA=&EO;B(*;7-G<W1R("+/\.[WX/\@Z.WT[O#LX/;H_R(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\B
M"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"B,L(&9U>GIY"FUS9VED
M(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`BS>7R(.3N\?+S[^W[]2#MX/'R\.[EZBXB"@HC.B!L:6(O3F5T+U--4R]G
M96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*
M;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,3,W-`IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS
M9W-T<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")032!286EN(@IM<V=S='(@(L+M
MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*(RP@9G5Z>GD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`BR.SO
M[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#`*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`BR.SO[O#R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*(RP@
M9G5Z>GD*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("+([._N\/(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@HC
M+"!F=7IZ>0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(LCL[^[P\B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"B,L(&9U>GIY
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E>'1E;G-I;VX@
M:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#D*;7-G
M:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!A:VES=&%N(@IM<V=S
M='(@(L3@\N`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")086QA=2(*;7-G<W1R("))
M35`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`R"B,L(&9U>GIY"FUS9VED(")087)A9W5A>2(*;7-G<W1R("))35`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@HC
M+"!F=7IZ>0IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("+*[NSOX.WH
M_R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,C(*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34Q
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHT,R!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC(&9U
M>GIY"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(M'N[N'YY>WHY2#S\>_E^.WN(.[R[_#@XNOE[>XN(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BS^#P[NO\(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<F%D:75S+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(LWE\B#MX/'R\.[EZB#DZ_\@[_#N]N7D\_#[(.#S\N7M\NCTZ.K@]NCH(._N
M(%-13"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#4W"B,L(&9U>GIY"FUS
M9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+/\.[W
MX/\@Z.WT[O#LX/;H_R(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`BS^#P[NO\
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+/X/#NZ_PB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@HC+"!F=7IZ>0IM<V=I9"`B
M4&%S=&4B"FUS9W-T<B`BQ.#RX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O
M87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3$*(RP@9G5Z>GD*;7-G:60@(E!A=&@B"FUS9W-T<B`B
MQ.#RX"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M
M7V)O='1O;2YI;F,Z-@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(L[Q\_GE\?+BZ^7MZ.4@[N_E\.#VZ.D@[^[DY.7P
MYNKH(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS
M9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M(@IM<V=S='(@(L+[[^[K[>CR_"#N[^7PX/;HZ"#NX?'K\^;HXN#MZ/\@[_#H
M(.+U[N3E(.(@\>CQ\N7L\S\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("+/\.#BX"(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R
M("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M
M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC
M+2,M(UQN(@HBS>[B[N4@\>[NX?GE[>CE(@H*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E
M;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*
M(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@
M*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C8I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H
M,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5
M+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,RXP
M+C8I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M
M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP
M+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2,*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M
M(RTC"B,@9G5Z>GD*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(,R`H
M,BXP+C(I*2`@(RTC+2,M(RTC"B,@9G5Z>GD*(SH@;&EB+U9&4R]S;6(N<&AP
M.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-
M4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N
M9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC
M7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I
M("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0
M($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD
M:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@
M(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(
M,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S
M('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M
M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@
M=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB
M(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC
M+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V
M-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP
M;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C
M;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B+-
MX/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A-;F5M;R!(,R`H,BXP+C(I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O
M\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A-;F5M;R!(
M,R`H,BXP+C(I*2`@(RTC+2,M(RTC7&XB"B+(Y^SE[>CR_"#O\.#BX"#D[O'R
M\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A.86<@2#,@*#(N,"XS*2D@
M(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<
M;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%=H=7!S(#$N,"UC=G,I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJ
MZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%=H=7!S
M(#$N,"UC=G,I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+E
MZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%=H=7!S(#$N,"UC=G,I("`C
M+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*%=H=7!S(#$N,"UC=G,I("`C+2,M(RTC+2-<;B(*
M(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*%=H=7!S(#$N,"UC=G,I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O
M[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S
M+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R
M9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O
M[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S
M('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K
M_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@
M(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<
M;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#N
MZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R
M8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC7&XB"B+-X/'R\.[IZN@@[^[K_.?N
MXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(,R!V,BXP
M+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M
M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@*#(N,"XR*2D@
M(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H36YE;6\@2#,@*#(N,"XR*2D@(",M(RTC+2,M
M(UQN(@HBR.?LY>WH\OP@[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R
M=5]252YP;R`H3F%G($@S("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LCG[.7M
MZ/+\(._PX.+@(.3N\?+S[^!<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U
M<F)A($@S('8R+C`N-"D@(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG
M[N+@\N7K_UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV
M*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B82!(
M,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+E
MZ_]<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A($@S('8R+C`N-"D@
M(",M(RTC+2,M(UQN(@HBS>#Q\O#NZ>KH(._NZ_SG[N+@\N7K_UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H5'5R8F$@2#,@=C(N,"XT*2`@(RTC+2,M(RTC
M7&XB"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A4=7)B82!(,R!V,BXP+C0I("`C+2,M(RTC+2-<;B(*(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED
M(")097)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"#D[O'R\^_@(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(LOH
M]^W[Y2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI
M<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("+2Y>OE].[M(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(L3@\N`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G
M:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED
M(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-38V"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@
M82!Y96%R+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(L+B
MY>3H\N4@[>#GXN#MZ.4@[>[B[ND@ZN#RY>/N\.CH.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S`U"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#<*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#4Q
M"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R("+"X/@@16UA:6PZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+B(*;7-G<W1R("+/[N;@Z_/I\?+@+"#Q[N[A^>CRY2#Q
M\_+\(._P[N'KY>S[+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B
MS^[FX.OSZ?'RX"P@XN+EY.CRY2#"X/CH(.CL_R#O[NO\Y^[BX/+EZ_\@Z"#O
MX/#NZ_PB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O
M<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4&QE87-E(')E860@
M=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@
M=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@
M(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY"B,L(&9U>GIY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`BRN[L[^#MZ/\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"B,L(&9U>GIY"FUS
M9VED(")0;VQL<R(*;7-G<W1R("+1XN7P[?/R_"#B\>4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M;W)T=6=A;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*(RP@
M9G5Z>GD*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`BS^#P[NO\(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C,*(RP@9G5Z>GD*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(LW@
MY^#D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM
M<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("+/\.7D^^3S^>#_(/'R
M\.#MZ/;@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME
M>2(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ
M-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BS_#NX>OE[.`_(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E<V-R:7!T
M:6]N(@IM<V=S='(@(L[OZ/'@[>CE(._P[N'KY>S[(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,34@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q.3(@;&EB+TAO<F1E+T9O<FTN<&AP.C,R.#,*(RP@9G5Z>GD*;7-G
M:60@(E!R;VUP="!T97AT(@IM<V=S='(@(L+[]>[D(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0
M=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8T-0HC+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(L+@^.4@[^[K[>[E(.CL_SHB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*
M;7-G:60@(E%A=&%R(@IM<V=S='(@(DE-4"(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HV,PIM<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")1=6]T82(*;7-G<W1R
M("))35`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G
M<W1R("(B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8X"B,L
M(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`BS^[K[>[E
M(.[OZ/'@[>CE(._P[N'KY>S[.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0T"B,L(&9U>GIY"FUS9VED(")286EN(@IM<V=S
M='(@(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`BPO7NY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"B,L(&9U>GIY"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`BPO7N
MY"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W
M"B,L(&9U>GIY"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("+"]>[D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*(RP@
M9G5Z>GD*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`BPO7NY"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"B,L(&9U
M>GIY"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`BPO7NY"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<V"B,L(&9U>GIY"FUS9VED(")2871I;R(*;7-G
M<W1R("+-X/'R\.[IZN@B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(M?H\N#R_"(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM
M<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+1[N[A^>7MZ.4B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@
M(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(M/DX.OH\OP@[^#P
M\R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(L[A[>[BZ/+\
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(L[A[>[BZ__R_"#D
MZ.W@[.CWY?'JZ.4@[_/MZO+[(.SE[?XZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T
M<B`BSN'M[N+K__+\(.CM].[P[.#VZ/XZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S.0HC+"!F=7IZ>0IM<V=I9"`B4F5G97@B"FUS9W-T<B`BT>'P
M[O'H\OPB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(S.`IM<V=I9"`B4F5L
M871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@(L_P[O?H\N#M
M[?OE(@H*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W"FUS
M9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("+/[O?R[N+[Y2#QY?#BY?#@
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS
M9W-T<B`BP.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@:'1T<#HO+VUA:6PN<G4I
M(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@
M(E)E;6]V92(*;7-G<W1R("+3Y.#KZ/+\(@H*(R!F=7IZ>0HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*
M;7-G<W1R("+3Y.#KZ/+\(.'K[NHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED(")296UO=F4@8V]L
M=6UN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A
M('8Q+C$I("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q\N[KX>7V(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BT^3@Z^CR_"#O
MX/#S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@
M(E)E;6]V92!P86ER(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T
M<B`BT^3@Z^CR_"#OX/#S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!U<V5R(@IM<V=S='(@(M/DX.OH\OP@[^#P\R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(M/DX.OH\OP@[^#P
M\R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E
M<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`BP.3PY?'@\B#SXN7D[NSKY>WH_R`E
M<R#MY2#MX.GDY>TN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S8@;&EB+TAO<F1E
M+G!H<#HU,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(LWE[N'U[N3H[/OI(._@\.#LY?+P("=U:60G(.WE(//JX.?@[2#B
M(.KN[?3HX_/PX/;HZ"#MX/'R\.[EZBXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M-C<X(&QI8B]61E,O9G1P+G!H<#HX-C$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M-S,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`BS>7NX?7NY.CL^^D@[^#PX.SE\O`@)W5I9"<@[>4@\^K@Y^#M(.(@ZN[M
M].CC\_#@]NCH(.W@\?+P[N7J+B(*"B,Z(&QI8B](;W)D92]5=&EL+G!H<#HW
M-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(LWE
M[N'U[N3H[/OI(._@\.#LY?+P("=U:60G(.WE(//JX.?@[2#B(.KN[?3HX_/P
MX/;HZ"#MX/'R\.[EZBXB"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP
M:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R("+1X?#N\>CR_"(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")2
M97-E="!087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R("+/X/#NZ_PB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB
M"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW
M"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("+"Y?#M\_+\\?\@
MZB#MX/'R\.[IZN#L(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,X"B,L(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S
M='(@(L_@\.[K_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E)E=6YI;VXB"FUS9W-T
M<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC
M+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M
M(RTC+2-<;B(*(M/DX.OE[>W[Y2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,B"FUS9W-T<B`BS>#Q\O#NZ>KH(.+HY_/@Z_SM[N/N(/#EY.#J\N[P
MX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BS>CJ[N/D
MX"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3$P"B,L(&9U>GIY"FUS9VED
M(")2:6=H="!H96%D97(B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3`V"B,L(&9U>GIY"FUS9VED(")2:6=H
M="!V86QU97,B"FUS9W-T<B`BS_#H[.7P(.?MX/?E[>CI.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`HC
M+"!F=7IZ>0IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(LKK
MY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BT?;E[>#PZ.DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`R"B,L(&9U>GIY"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*
M(RP@9G5Z>GD*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC
M+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2-<;B(*(N_E
M\.7LY?'RZ/+\(.+BY?#U(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M
M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C
M+2,M(RTC+2-<;B(*(N_E\.7LY?'RZ/+\(.+BY?#U(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-PHC+"!F=7IZ>0IM<V=I9"`B
M4F]T871E(%)I9VAT(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@
M*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB"B+OY?#E[.7Q\NCR_"#BXN7P
M]2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S
M='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I
M9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_
MY_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,0HC+"!F=7IZ>0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`BRN#KY>WDX/#\
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`BT?;E[>#P
MZ.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L
M;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*
M;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R
M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4G=A;F1A(@IM
M<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS,C,*
M(RP@9G5Z>GD*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G
M<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@
M)7,B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ>0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,#8*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`BSO+O\.#BZ/+\(/'N[N'YY>WHY2(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C@Q"FUS9VED(")344P@<W1A=&5M
M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC
M("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"B,L(&9U
M>GIY"FUS9VED(")382(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(.K@ZEQN(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN
M(@HBT>[U\.#MZ/+\(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-PHC+"!F=7IZ>0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`BPO7NY"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G
M:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*
M"B,@(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I("`C+2,M(RTC+2,*
M(R!F=7IZ>0HC(&9U>GIY"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R("+1[O7PX.WH\OPB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("+1[O7PX.WH\OP@
M[>#Q\O#NZ>KH(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B
MT>[U\.#MZ/+\(.W@\?+P[NGJZ"(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+1[O7PX.WH\OP@
M[>#Q\O#NZ>KH(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I
M9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`BS>4@[.[C\R#N\NKP^_+\(.SN
MY//K_"!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R("+([._N\/(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(L_NZ/'J(@H*(R!F
M=7IZ>2P@<&AP+69O<FUA=`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(R"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("+/
M[NCQZB(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.38R"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`BPOOAY?#H\N4@].[P[.#R(.3@
M\OLZ(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("+"^^'E
M\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Y.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D
M(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A
M(&YE=R!O=VYE<B(*;7-G<W1R("+"^^'E\.CRY2#T[O#LX/(@Y.#R^SHB"@HC
M(&9U>GIY"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I
M9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(L+[X>7PZ/+E(/'E\.+E\"(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("+"^^'E\.CRY2#T
M[O#LX/(@Y.#R^SHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<T"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(L+[X?#@\OP@
MXO'E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-3`*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("+"^^'E
M\.CRY2#T[O#LX/(@Y.#R^SHB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#<Q"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@;V)J
M96-T(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#DX/+[.B(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S4*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(L[R[.7MZ/+\(.+[X>[P(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82XB"FUS9W-T<B`B(@HBPOOAY?#H\N4@[?/F[?OE(,+@["#QZ.SB
M[NO[(.CG(/3N\.P@XNWHY_,N(,?@\N7L(,+[(.SNYN7RY2#QZN[OZ/#NXN#R
M_"#H("(*(N+Q\N#BZ/+\(.CU(.(@\N7J\?(N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET
M97(Z(@IM<V=S='(@(L+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C
M="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(L+[X>7PZ/+E(/3N\.S@\B#D
MX/+[.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R("+"^^'E\.CRY2#O\.[TZ.O\(.3K_R#MX/'R\.[IZN@Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(L+[X>7P
MZ/+E(/#@Y^3EZ^CRY>O\(._NZ^7I(.3@\OLZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(L+[X>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@\B#B\.7LY>WH
M.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+"^^'E\.CRY2#D
MXN`@\>[B[^#DX/[YZ/4@[^[K_RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S
M='(@(L+@^.`@]N+E\N[BX/\@\?7E[.`B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z(@IM<V=S='(@(M_G^^H@[O+NX?#@YN7MZ/\B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R("+/[O'KX/+\(/'N[N'YY>WHY2#N(._P[N'KY>SE(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G
M:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*(RP@
M9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+'X.SE\NKH(@H*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA
M(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S`R"B,L(&9U>GIY"FUS9VED(")397)I86P@3G5M8F5R
M(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-#D*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")3
M97-S:6]N($%D;6EN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU
M;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB
M"B+-X/'R\.[IZN@@[^[K_.?NXN#RY>O_7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@
M[_#@XN`@Y.[Q\O/OX%QN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H3F%G($@S
M("@R+C`N,RDI("`C+2,M(RTC+2-<;B(*(LCG[.7MZ/+\(._PX.+@(.3N\?+S
M[^`B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@HC
M+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("+1
M[N[A^>7MZ.4B"@HC.B!L:6(O87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@
M(E-E<W-I;VYS(@IM<V=S='(@(L?@[.7MZ/+\(.W@(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(S,3@*(RP@9G5Z>GD*;7-G:60@(E-E="(*;7-G<W1R("+2
MY>S@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@
M;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I
M9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*
M;7-G<W1R("(B"B+$[N_NZ^WH\N7K_.W[Y2#O[O?R[N+[Y2#QY?#BY?#@+"#J
M(.KN\N[P^^P@XOL@]>[RZ/+E(.CLY?+\(.3N\?+S[R#HYR#/[O#RX.O@+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("+3\?+@[>[BZN`@_^?[ZN`@XOOB[N3@+"#B\.7LY>WM[ND@
MY^[M^R#H(/3N\.S@\N`@[O+NX?#@YN7MZ/\@XO#E[.7MZ"XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB
MT_'RX.WNXNK@(._PZ.ONYN7MZ/\@[^X@\^SNZ_?@[>C^+"#VXN7R[N+NZ2#Q
M]>7L^R#H(._P[O?H]2#N[_;HZ2#N\N[A\.#FY>WH_R(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(L_PZ.ON
MYN7MZ/\B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS
M-PHC+"!F=7IZ>0IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L92(*;7-G<W1R("+-Y2#L[N/S(.[RZO#[\OP@[.[D\^O\($UA:6YT96YA
M;F-E7U1A<VL@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<U"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S
M(@IM<V=S='(@(B(*"B,@(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2,*(R!F=7IZ>0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#DX"B,L(&9U>GIY"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MT>[U\.#MZ/+\(.K@ZEQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@
M=C$N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(@H*(R!F=7IZ>0HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@
M4W5M;6%R>2(*;7-G<W1R("+*\.#RZN[E(.[A[N'YY>WHY3HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`BSN_PY>3E
MZ^CR_"#A^_'R\/OE(.KKX.+H^.@@Y.O_(/'Q^^ONZC\B"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM
M<V=S='(@(L_NZN#GX/+\(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U
M-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT
M"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M(@IM<V=S='(@(L_NZN#G^^+@\OP@Z.WT[O#LX/;H_B#N(._PY>3[Y//YY>P@
MXO7NY.4_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H
M;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,#(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@<&EC
M:V5R(@IM<V=S='(@(LCL[^[P\B(*"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE
M;G4@8F%R/R(*;7-G<W1R("+/[NK@Y^#R_"#LY>W^(.[OY?#@]NCI(/$@\N#A
MZ^CVX.SH(@H*(R!P:'`M9F]R;6%T"B,@9G5Z>GDL('!H<"UF;W)M870*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("+.\N[A
M\.#FX/+\(.SE[?X@)7,@\>OEXN`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED
M(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"B,L(&9U>GIY"FUS
M9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`HC+"!F=7IZ>0IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(LKKY?+N]^W@_R#PX.3H[O'B_^?\(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"B,L(&9U>GIY"FUS
M9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-S8W"B,L(&9U>GIY"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("+(
M[/\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("+([._N\/(B"@HC
M(&9U>GIY"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4R"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(LKP
MX/+J[N4@[N'NX?GE[>CE.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4S"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($QA=&4B
M"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y
M(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z-#@P(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`BT?/GZ/+\(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C@S-@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,C(@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C$P-#<@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z,3`X-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C$Q-#D*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HY-S(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,#4X"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3$R,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$Q.#,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C(S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(U,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I
M9VYA='5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDP,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(T,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(U,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q
M,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV-2!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HX-`IM<V=I9"`B4VEZ92(*;7-G<W1R("+0X.?LY?`B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.CD*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BS_#N[_/Q\NCR
M_"#O[N3DY?#FZO,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0HC+"!F=7IZ>0IM<V=I9"`B4VYO
M=R(*;7-G<W1R("+([._N\/(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97(B
M"FUS9W-T<B`BR.SO[O#R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R(*
M;7-G<W1R("+([._N\/(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`BRO#@\NKNY2#NX>[A^>7MZ.4Z(@H*(R!F
M=7IZ>0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M.0HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B
MRO#@\NKNY2#NX>[A^>7MZ.4Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-O;6%L:6$B"FUS9W-T
M<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,34*(RP@
M9G5Z>GD*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC
M7&XB"B+$Y>GQ\N+HY3HB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y
M"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+0X.'N
M]^CI(.#D\.7Q(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'
M96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R
M("(B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`BWN;M[N4@[^[K\_C@\.CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@
M861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E
M96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(R`C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(PHC(&9U
M>GIY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,3D*(RP@9G5Z>GD*;7-G:60@
M(E-P86-E<B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@
M=C,N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(.K@ZEQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBT>[U
M\.#MZ/+\(@H*(R`C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M
M(RTC+2,M(PHC(&9U>GIY"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM<V=I9"`B4W!A8VEN9R(*
M;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M
M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(.K@ZEQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBT>[U\.#MZ/+\(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0HC
M+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"B,L(&9U>GIY"FUS9VED(")3
M<&%M(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R
M("+1[^7VZ.#K_.W[Y2#QZ.SB[NO[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@HC+"!F=7IZ>0IM<V=I9"`B
M4W!L:70@8V5L;"(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(
M;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O
M("A4=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+D[N'@XNCR_"#Q\N[KX>7V
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@
M(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M
M(RTC+2-<;B(*(N3NX>#BZ/+\(/'R[NOAY?8B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"B,L(&9U>GIY"FUS
M9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP
M;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]2
M52YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M(UQN(@HBY.[AX.+H\OP@\?+N
MZ^'E]B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(L+U
M[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8*(RP@9G5Z
M>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(LK@Z^7MY.#P_"(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3DP(&QI8B](;W)D92]&;W)M+G!H<#HR-SDX
M"B,L(&9U>GIY"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(LK@Z^7MY.#P
M_"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC(&9U>GIY"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`BT?+@\O/Q(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#0*
M(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(L+@^.`@
MZ.WT[O#LX/;H_R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S
M"B,L(&9U>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R("+0X.'N
M]^CI(.#D\.7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#I
MY.7M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S
M"FUS9VED(")3=6)J96-T(@IM<V=S='(@(M+E[.`B"@HC(&9U>GIY"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N
M<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(LCQZN#R_"(*"B,Z('-I
M9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N
M;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P
M<F]V960N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@HC+"!F=7IZ>0IM<V=I9"`B4W5B
M<V-R:7!T(@IM<V=S='(@(LCQZN#R_"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,#0@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(M/Q[^7X[>XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HX-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G
M<W1R("+/X._JX"!<(B5S7"(@X?OKX"#S\>_E^.WN(._E\.7H[.7M[N+@[>`@
MXB!<(B5S7"(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(R!F=7IZ>2P@
M<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB
M+B(*;7-G<W1R("+'X.SE\NK@("<E<R<@\_'OY?CM[B#Q[O7PX.WE[>`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R
M+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V
M,RXQ*2`@(RTC+2,M(RTC7&XB"B+/\.[AZ^7LX"#O\.@@[_#N\>SN\O#E(.?@
M[_#N^.7M[>[C[B#OZ/'\[.`N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+1\N#P
MX/\@ZN[M].CC\_#@]NC_(/'N]?#@[>7MX"#B(/3@Z>LZ("5S(@H*(R!F=7IZ
M>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&%D;6EN+W5S
M97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(L?@[.7RZN`@)R5S)R#S
M\>_E^.WN(/'N]?#@[>7MX"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("+-[N+@_R#J[NWT
MZ./S\.#VZ/\@\>[U\.#MY>W@(.(Z("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED
M(")3=6UM87)Y(@IM<V=S='(@(L/KX.+MX/\B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@
M(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-C@*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS9W-T<B`BTN7LX"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED
M(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`U"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(LCL
M_R#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES
M92]3=6YS970B"FUS9W-T<B`BPO#E[/\@XN[Q]>[DX"_GX.K@\N`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"B,L(&9U>GIY"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@
M(E-U;G-E="(*;7-G<W1R("+2Y>S@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P-PHC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T
M<B`BTN7LX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@
M(L_NZ^WNY2#N[^CQX.WHY3HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@P"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(LCL[^[P
M\B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(LCL_R#O
M[NO\Y^[BX/+EZ_\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W
M-0HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("+([/\@[^[K_.?N
MXN#RY>O_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
MRN[L[^#MZ/\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@V"B,L(&9U>GIY"FUS9VED(")3>6YC(&QO9R!D96QE=&5D
M(@IM<V=S='(@(L_NZN#GX/+\(//DX.OE[>W[Y2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I
M86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@
M(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(E0M
M4W1O<FUS($5A<FQY(@IM<V=S='(@(LKPX/+J[N4@[N'NX?GE[>CE.B(*"B,Z
M(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")4
M4U8@9FEL92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!L:6(O2&]R9&4O54DO
M5&%B;&4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B
MQ^#C[NONXN[J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,Z(&QI8B](
M;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"B,L(&9U>GIY"FUS9VED
M(")486)L92!3970B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@HC+"!F=7IZ
M>0IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("+*Z^7R[O?MX/\@
M\.#DZ.[QXO_G_"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"B,L(&9U>GIY"FUS9VED(")486EW
M86XB"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`BQ.#RX"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0HC+"!F=7IZ>0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R("+1[N[A^>7MZ.4B"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(L?@Y.#WZ"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<T"B,L(&9U>GIY"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(LCL_R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G
M:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_("5S(.WE(.W@Z>3E[2XB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,S0*(RP@9G5Z>GD*;7-G:60@
M(E1E>'0B"FUS9W-T<B`BQ.#KY>4B"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R("+2[NO\
MZNX@\N7J\?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")497AT(&%L:6=N(@IM
M<V=S='(@(M'KY>3S_OGE_R#Q\O#@[>CVX"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E
M>'1T;W`B"FUS9W-T<B`BQ.#KY>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B5&AA:2`H5$E3+38R
M,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#4Q"B,L(&9U
M>GIY"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("+-Y?(@Y.[Q\O/O[?OU(.W@\?+P[N7J+B(*"B,Z(&QI8B](
M;W)D92](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ,CDX"B,L(&9U
M>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+B(*;7-G<W1R("+/[N3OZ/'\(.WE(.SNYN7R(.'[\OP@Y^#LY>WE[>`N
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%
M>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X
M.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,"!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C(Q,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,R!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(S-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C(U,@HC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(V-"!L:6(O2&]R9&4O4&5R;7,N<&AP.C,P,PIM<V=I
M9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@
M=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4
M:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@
M(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)
M1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T
M(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I
M<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S<@;&EB+TAO<F1E
M+G!H<#HU,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4N<&AP.C$W,"!L:6(O2&]R9&4N<&AP.C4P.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(R-@IM
M<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(X,`IM<V=I9"`B
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@
M9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F
M8S@R,B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S
M8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN
M=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*
M(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*
M(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV
M96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H
M92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HT-S0*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BW?+N(.?MX/?E[>CE(.3NZ^;M[B#A
M^_+\(/?H\>ON["XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R
M,S(*;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N
M<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T
M97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<Y"FUS9VED(")4
M:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(M'E\.+E\"`E<R#A^^L@\^3@Z^7M(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(M'E\.+E\"`E<R#A^^L@\>[GY.#M(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@
M[>#IY.7M+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,S,`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M
M+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ-SD*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#I
MY.7M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`Y"FUS9VED(")4:&4@
M=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H
M92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H
M92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A
M+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1&%T82]C<W8N<&AP.C(V,B!L:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W
M,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`HC+"!F=7IZ>0IM
M<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(L#D\.7QX/(@\^+EY.[LZ^7MZ/\@)7,@[>4@[>#IY.7M+B(*"B,@9G5Z>GD*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BS>7R(.3N\?+S[^W[
M]2#MX/'R\.[EZBXB"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("+1[N[A^>7MZ.4@XB#M
MY>+E\.WN["#T[O#LX/+E(.@@[>4@[.[FY?(@X?OR_"#N\N[A\.#FY>WN(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F
M:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@
M;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU
M<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T
M;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H
M(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBS_#NX>OE[.`@[_#H
M(._P[O'L[O+PY2#GX._P[OCE[>WNX^X@[^CQ_.S@+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M
M.B`B"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N
M,2D@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S
M+C$I("`C+2,M(RTC+2-<;B(*(L_P[N'KY>S@(._PZ"#O\.[Q[.[R\.4@Y^#O
M\.[XY>WM[N/N(._H\?SLX"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("+/\.@@\^3@Z^7MZ.@@Y^#D
MX/?H(.+NY^WHZNOH(.[XZ.'JZ"XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES
M(&UE<W-A9V4@<&%R="(*;7-G<W1R("+.^.CAZN`@[_#H(.[R[N'PX.;E[>CH
M(/WR[ND@]^#Q\N@@\>[NX?GE[>C_(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(L[X
MZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@;&EB+TAO<F1E+T1A=&$O
M:6UC+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<
M;B(*(L[XZ.'JX"#O\.@@Z.SO[O#RY2#DX.WM^_4N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*(RP@9G5Z>GD*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I
M960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4
M=7)B82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H(.CL[^[P\N4@
MY.#M[?OU+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V
M,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5+G!O("A4=7)B
M82!V,2XQ*2`@(RTC+2,M(RTC7&XB"B+.^.CAZN`@[_#H(.CL[^[P\N4@Y.#M
M[?OU+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@(",M(RTC+2,M(UQN
M(@HB(RTC+2,M(RTC("!R=5]252YP;R`H5'5R8F$@=C$N,2D@(",M(RTC+2,M
M(UQN(@HBSOCHX>K@(._PZ"#H[._N\/+E(.3@[>W[]2XB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"B,L(&9U>GIY"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O[N3DY?#FZ.+@Y?(@[N_V
MZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@0U123"M0+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C0X"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+B(*;7-G<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@
M]^CQZ^[L+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3,T"B,L(&9U>GIY
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`BW?+N(.?MX/?E[>CE(.3NZ^;M[B#A^_+\(/?H
M\>ON["XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X
M-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K
M871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE
M(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B
M"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@R(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DP"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@V(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Y
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI8B](;W)D92]&;W)M+G!H<#HQ
M-38Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H<#HR,#`Y"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&;W)M+G!H<#HR,#@R(&QI8B](
M;W)D92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(U
M(&QI8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#4T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0T(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#$W(&QI8B](;W)D92]&;W)M+G!H<#HS,3(V"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S`T(&QI8B](;W)D92]&;W)M+G!H<#HS.#$R(&QI8B](
M;W)D92]&;W)M+G!H<#HS.#(P"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I
M<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V.0IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R,`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.3@*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU
M97,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(W"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3DS"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(MWR[B#G[>#WY>WHY2#D
M[NOF[>X@X?OR_"#WZ/'K[NPN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,C4*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@
M8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C
M,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V
M-0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@
M=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C4Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@
M;VYE+B(*;7-G<W1R("+=\NX@]^CQZ^X@[>4@[.[FY?(@X?OR_"#LY>W\^.4@
MY>3H[>CV^RXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T
M:79A=&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R("+=\NX@Y^W@]^7MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+B(*"B,Z('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C4*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R
M("+'X._P[O'[(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,CD@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")4:6UE
M(@IM<V=S='(@(L?@X^[K[N+NZB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(R!F
M=7IZ>0HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R
M;6%T(@IM<V=S='(@(M3N\.S@\B#N\N[A\.#FY>WH_R(*"B,@9G5Z>GD*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*(RP@9G5Z>GD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(L_NZ^WNY2#N[^CQX.WHY2#O\.[AZ^7L^SHB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BQ^#C[NONXN[J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I
M9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B
MRN[L\R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-3(*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB
M=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(M?R[N'[(.+[X?#@\OP@[>7QZN[K
M_.KN(/WKY>SE[?+NXBP@\^3E\.;HXN#I\N4@[>#FX/+NZ2#JZ^#BZ.;S($-T
M<FPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"B,L(&9U
M>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R("+*[NSS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE
M($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1O
M9V\B"FUS9W-T<B`BRN[L\R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,@HC+"!F=7IZ
M>0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`HC+"!F
M=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`BRN[L\R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC+"!F=7IZ
M>0IM<V=I9"`B5&]P(@IM<V=S='(@(LKN[/,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@
M*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A
M9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G
M:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*(RP@
M9G5Z>GD*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("+/\>7BY.[MZ.PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@
M(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@
M9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS
M9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5G
M86YD82(*;7-G<W1R("+*X.OE[>3@\/PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5
M:W)A:6YE(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#$Y
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7P
MXN7P[NPN(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Y
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HS.3(@;&EB+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("+-Y>+NY^SNYNWN
M(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HW.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CM
MZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV
M.34@;&EB+U9&4R]S<6PN<&AP.C$P,C@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M.#4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O
M075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q
M(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<P"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T
M<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C(S,B!L:6(O5D93+V9I;&4N<&AP.C(S-R!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Q-PHC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,W,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C,V,2!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C8T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E
M\.+E\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR.3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@
M\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S(*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S
M='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-S8@;&EB+TAO<F1E+T-O
M;7!R97-S+V=Z:7`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR
M_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,C@@
M;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@
M4U%,(/'E\.+E\.[L+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B"B(C
M+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC
M+2-<;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A(;W)D
M92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["Y<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B[N?L
M[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["Y<;B(*(B,M(RTC+2,M
M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HBS>7B
M[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["Y<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8S+C`N,RD@(",M(RTC+2,M(UQN(@HB
MS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C,S."!L:6(O5D93+W-Q;"YP:'`Z,SDU(&QI8B]6
M1E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(LWEXN[G
M[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S4V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,`HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_
M(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S0T(&QI
M8B]61E,O;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U
M,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E
M\.+E\.[L+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,C`@;&EB+U9&4R]S<6PN
M<&AP.C0S,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,C$R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M
M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C,Q,"!L:6(O5D93+W-Q;"YP:'`Z,CDQ(&QI8B]61E,O;75S<6PN
M<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC.B!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HS.3D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(T.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-#`Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[E
MY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C@S-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[O7PX.WH\OP@
M\_'RX.WNXNKH(.(@\>7Q\>CH+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T
M92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&QI8B].970O24U34"YP:'`Z-#,W
M(&QI8B].970O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(LWEXN[G[.[F[>X@Y^#C\//GZ/+\(.[O\.7DY>OE[>CE("5S+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C`S(&QI8B]61E,O9FEL92YP:'`Z,C`X(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C$W-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE
M+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E
M\.[L+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z
M,3`V(&QI8B]61E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP.CDX
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\
M\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR.#0@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$T,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@
M\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HX,R!L:6(O
M5D93+V9I;&4N<&AP.C$S-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW-@HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@
M(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC
M.B!L:6(O5D93+G!H<#HX-38*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(LWE
MXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB
M+U9&4RYP:'`Z.#@W"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](
M;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(LWEXN[G[.[F[>X@
M\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HV-S8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$Q,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E
M<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P,0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*
M"B,Z(&QI8B]61E,O<W%L+G!H<#HS,S(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(W,2!L:6(O5D93+V9T<"YP:'`Z,S0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BS>7B[N?L[N;M[B#Q[N7DZ.WH
M\OSQ_R#Q(%-13"#QY?#BY?#N["XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Q
M-R!L:6(O5D93+VUU<W%L+G!H<#HR,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*
M(SH@;&EB+U9&4R]S<6PN<&AP.C,R-B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@
M;&EB+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C(Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#D*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F
M[>X@\>[EY.CMZ/+\\?\@\2!344P@\>7PXN7P[NPN(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H
M[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("+=\N[R(.3NZO/LY>WR(%=O
M<F0@[>4@[.[FY?(@X?OR_"#OY?#EXN7DY>TN(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C$U-"!L:6(O5D93+V9T<"YP:'`Z,34W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3@V"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("+-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C@X(&QI8B]61E,O<W%L7V9I;&4N<&AP
M.C$T-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z(&QI8B]6
M1E,N<&AP.C@V,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("+-Y>+N
MY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*(RP@9G5Z>GD*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS
M9W-T<B`BSO+LY>WH\OP@Z.?LY>WE[>C_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,R!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R
M9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE
M9"(*;7-G<W1R("+/\_'R[NDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E
M9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV,@IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM
M<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"B,L(&9U>GIY"FUS9VED(")5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+-X/'R\.[IZN@B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F=7IZ
M>0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T
M<B`BS^[FX.OSZ?'RX"P@XN+EY.CRY2#"X/CH(.CL_R#O[NO\Y^[BX/+EZ_\@
MZ"#OX/#NZ_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3@*(RP@9G5Z>GD*;7-G:60@(E5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*(B,M(RTC+2,M(R`@<G5?4E4N
M<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@<G5?
M4E4N<&\@*%1U<F)A('8Q+C$I("`C+2,M(RTC+2-<;B(*(O/A\.#R_"#Q\N[K
MX>7V(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*(RP@9G5Z>GD*
M;7-G:60@(E5N;F%M960B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G
M:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T
M+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,@HC+"!F=7IZ>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BR/'O
M[NO\Y^[BX/+\(.?MX/?E[>CE(._N(//L[NOWX.WH_B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z.3(W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED
M(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(R!F=7IZ>0HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(L_PZ.SE
M[>CR_"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M("+1[O7PX.WH\OP@[>#Q\O#NZ>KH(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`BQ.[AX.+H\OP@[^#P\R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&5D(%PB)7-<(BXB"FUS9W-T<B`BT>[U\.#MZ/+\(.W@\?+P[NGJZ"(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C
M<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3<X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M.3@*(RP@9G5Z>GD*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"B(C+2,M(RTC
M+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<
M;B(*(B,M(RTC+2,M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!C;VUP96YD:75M+G!O("A)35`@
M2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(&-O;7!E;F1I
M=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M
M(R`@8V]M<&5N9&EU;2YP;R`H24U0($@S('8T+C`N-"D@(",M(RTC+2,M(UQN
M(@HBS_#N]^CRX.WM^^5<;B(*(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E
M('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H
M2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A(;W)D92!V,RXP+C8I("`C+2,M(RTC+2-<;B(*(B,M(RTC+2,M(R`@
M<G5?4E4N<&\@*$AO<F1E('8S+C`N-BD@(",M(RTC+2,M(UQN(@HB(RTC+2,M
M(RTC("!R=5]252YP;R`H2&]R9&4@=C,N,"XV*2`@(RTC+2,M(RTC7&XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"B,L(&9U>GIY"FUS9VED(")5<'!E<B!R;VUA
M;B!N=6UB97)S(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(E5R
M=6=U87DB"FUS9W-T<B`B24U0(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("+2Y>KS^>7E(.+PY>S_(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E
M(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W
M"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R
M($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"B+(\>_NZ_SG\^7R\?\@Y?'KZ"#B
MX/CH(.CL_R_OX/#NZ_P@Y.O_($E-4U`@\>7PXN7PX"#N\NOH]^#^\O'_(.[R
M(/+EZO/YZ/4B"@HC(&9U>GIY"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`BS^[K_.?NXN#RY>O\
M(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(LW@\?+P
M[NGJZ"#O[NO\Y^[BX/+EZ_\B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY
M"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("+-X/'R\.[IZN@@
M[^[K_.?NXN#RY>O_(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0HC+"!F
M=7IZ>0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("+.
M\NSE[>CR_"#HY^SE[>7MZ/\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S8@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HY.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y
M."!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,34P"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,S('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G
M:60@(E5S97)N86UE(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R("+/X._JX"!<(B5S7"(@\^;E(/'S^>7Q\N+SY?(B"@HC(&9U>GIY
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(LCL_R#O[NO\Y^[BX/+EZ_\B"@HC(&9U>GIY"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`BR.S_(._NZ_SG[N+@\N7K_R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T
M96TZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,30*(RP@9G5Z>GD*;7-G:60@(E5Z8F5K:7-T86XB
M"FUS9W-T<B`BQ.#RX"(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]6
M1E,O9FEL92YP:'`Z,C8R"B,L(&9U>GIY"FUS9VED(")61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+`Y/#E\>#R(//BY>3N[.OE[>C_
M("5S(.WE(.W@Z>3E[2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3(P"B,L(&9U>GIY"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"B(C+2,M
M(RTC+2,@(')U7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C
M+2,M(RTC+2,@(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HB
MQ.7I\?+BZ.4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED(")6
M86QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DW(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS
M9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#8P(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3@Q"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(T."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(W,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,R,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-R!L
M:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0HC+"!F=7IZ>0IM
M<V=I9"`B5F%L=65S(@IM<V=S='(@(L?@[.7RZN@B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$Y,`IM<V=I9"`B
M5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A
M;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,PHC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`BQ^#C
M[NONXN[J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,#$*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`BPNWH
M[.#MZ.4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"B,L(&9U
M>GIY"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`BPNWH[.#MZ.4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R
M("+1Z^7D\_[YY?\@\?+PX.WH]N`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@T"B,L(&9U>GIY"FUS9VED(")697)T:6-A
M;"!P861D:6YG(@IM<V=S='(@(M'KY>3S_OGE_R#Q\O#@[>CVX"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*(RP@9G5Z
M>GD*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("+1Z^7D\_[YY?\@\?+PX.WH
M]N`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,0HC+"!F=7IZ>0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(LWHZN[CY.`B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$V"B,L(&9U>GIY"FUS9VED(")6:65T($YA;2(*;7-G<W1R("+([/\B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B5FEE=&YA;65S92`H
M5DE30TE)*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT
M<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`BS_#N\>SN\O`@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS
M9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(L_NZN#G
MX/+\(.+EX2WQ\O#@[>CV\R(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX,C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@
M)7,B"FUS9W-T<B`BS_#N\>SN\O`@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I
M9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS
M9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%
M(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ
M,C$@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM
M<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O
M<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT,38*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV"FUS9VED(")796%T
M:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-@IM<V=I9"`B5V5B(@IM<V=S='(@(L+EX2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*
M;7-G<W1R("+%YN7MY>3EZ_SM[B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(L3N
MX?#N(._NYN#K[N+@\OPL("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`BQ.[A\.X@[^[F
MX.ONXN#R_"#B("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*
M;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(L3NX?#N(._NYN#K[N+@\OPL
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,@9G5Z
M>GDL('!H<"UF;W)M870*(R!F=7IZ>2P@<&AP+69O<FUA=`HC(&9U>GIY+"!P
M:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(M?R[B#N\N[A\.#FX/+\(._N\>OE(.+U[N3@(.(@\>CQ
M\N7L\SHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I
M9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H
M870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C(*;7-G:60@(E=H
M97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("+4X.?@
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@
M<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*
M;7-G<W1R("+*X.KHY2#N[_;HZ"#A\^3S\B#D[O'R\^_M^R#B(.+HY_/@Z_SM
M[NP@\.7DX.KR[O#E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5VED=&@B"FUS
M9W-T<B`BPNWH[.#MZ.4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q-`IM
M<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,@<&AP+69O
M<FUA=`HC(&9U>GIY+"!P:'`M9F]R;6%T"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ(@IM<V=S='(@(MCH\.CMX"#LY>W^("5S(/'KY>+@("CA\^3E\B#O\.CL
MY>WE[>`@[_#H(/'KY>3S_OGE["#B]>[DY2DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@
M=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"B,L(&9U>GIY"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*;7-G:60@(E=I9'1H
M.B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B5VEN9"(*;7-G<W1R
M("+"[>CLX.WHY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@
M(L+MZ.S@[>CE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M,0HC+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(L+MZ.S@[>CE(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*
M;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+0X.'N]^CI(.#D\.7Q(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@
M(E=O<FL@4&AO;F4B"FUS9W-T<B`BT.#A[O?HZ2#RY>OE].[M(@H*(SH@;&EB
M+T9I;&4O0U-6+G!H<#HQ.3,@;&EB+T9I;&4O0U-6+G!H<#HR.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG
M(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,C$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N(@IM<V=S='(@(LWEXN[G[.[F[>X@\>[EY.CMZ/+\\?\@
M\2!344P@\>7PXN7P[NPN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A
M:6YT<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S
M(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")962(*;7-G<W1R("+#PR(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-`HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R("+#PR(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`Y"FUS9VED
M(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+%YN7C[N3M[B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY-C0*;7-G:60@(EEE<R(*;7-G<W1R("+$
MX"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M
M+FEN8SHV"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N=&EC871E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO
M=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL
M(&YA;64N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4Y
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Y"B,L(&9U>GIY"FUS9VED(")9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@
M(L+@^"!%;6%I;#HB"@HC.B!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+B(*;7-G<W1R("+"^R#B^_CKZ"#HYR#QZ/'RY>S[+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C8U"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@
M86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q.3(*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@=F%L=64N(@IM<V=S='(@(L+@^"!%;6%I;#HB"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@
M82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="XB"FUS9W-T<B`B(@HBPOL@Y.[KYNW[(.[OZ/'@\OP@[_#NX>OE
M[/LL(._PY>;DY2#WY>P@\>SNYN7RY2#N\N[QZ^#R_"#Q[N[A^>7MZ.4@[B#M
MY>DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES
M(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O
M3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@
M;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(L+@^.`@)7,@\>7Q\>C_(.?@ZN[M]^CK
MX/'\+B#/[N;@Z_/I\?+@+"#B[NGDZ/+E(.(@\>CQ\N7L\R#GX.WNXNXN(@H*
M(R!F=7IZ>0HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM
M<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(L+@^"!%;6%I;#HB
M"@HC(&9U>GIY"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BPN#X(.#D\.7Q(.[R[_#@
MXNCRY>O_.B(*"B,@9G5Z>GD*(R!F=7IZ>0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G
M:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`BPN#XX"#H[?3N\.S@]NC_
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,@9G5Z>GD*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+"X/CE(.CL_SHB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@
M=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D
M:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+B(*;7-G<W1R("+"X/@@X?#N\^?E\"#MY2#O[N3DY?#FZ.+@Y?(@
M[N_VZ/X@[^7WX/+H+B#$Z_\@[^7WX/+H(.W@YNSH\N4@0U123"M0+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`BPN#X(.'P[O/GY?`@[>4@[^[DY.7PYNCBX.7R(.[O
M]NC^(._E]^#RZ"X@Q.O_(._E]^#RZ"#MX.;LZ/+E($-44DPK4"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@
M=&EM92!Z;VYE.B(*;7-G<W1R("+7X/'NXN[I(._N__$B"@HC(&9U>GIY"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("+"
MX/@@[_#N].CK_"#O[B#S[.[K]^#MZ/XZ(@H*(R!F=7IZ>0HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ(@IM<V=S='(@(L+@^"#O\.[TZ.O\(._N(//L[NOWX.WH_CHB"@HC(&9U
M>GIY"B,@9G5Z>GD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(L+@^.4@Z.S_.B(*"B,Z(&QI
M8B](;W)D92]!=71H+G!H<#HY.3D*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G
M:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(L+@^.@@[>#Q\O#NZ>KH(.'[Z^@@
M[N'M[N+KY>W[+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E
M<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ-30*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS
M9W-T<B`BPN#XZ"#MX/'R\.[IZN@@X?OKZ"#NX>WNXNOE[?LN(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`BPN#XZ"#MX/'R\.[IZN@@X?OK
MZ"#NX>WNXNOE[?LN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@
M(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@
M96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S,S"FUS9VED(")9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(M'R[O#N[>WHZ2#QY?#BY?`Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$X"B,L(&9U>GIY"FUS9VED("):86ER92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");T>[NX?GE
M[>CE(.X@[_#NX>OE[.5=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E
M9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*
M;7-G<W1R(");\?+P[NK@("5S(.CG("5S72(*"B,@9G5Z>GD*(SH@;&EB+TAO
M<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G
M:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("+3[_#@XNOE[>CE(@H*(SH@
M;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0HC+"!F=7IZ>0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S
M='(@(L3@\N`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W
M(@IM<V=S='(@(M/DX.OH\OPB"@HC(&9U>GIY"B,Z(&QI8B]A<&DN<&AP.C$S
M,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("+#\//O[_LB"@HC(&9U>GIY"B,Z
M(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@
M(L_N[.[Y_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I9"`B7TEM86=E(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`BRNOE\N[W[>#_(/#@Y.CN\>+_Y_PB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN
M(@IM<V=S='(@(L+U[N0B"@HC(&9U>GIY"B,Z(&QI8B](;W)D92]-96YU+G!H
M<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(L+[]>[D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T
M"B,L(&9U>GIY"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`BT^3@
MZ^CR_"#OX/#S(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38T
M"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("+-X/'R\.[IZN@B"@HC(&9U>GIY
M"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(L_PX.+@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI
M;FLN+BXB"FUS9W-T<B`BT^3@Z^CR_"#OX/#S(@H*(R!F=7IZ>0HC.B!L:6(O
M87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("+/\.CK[N;E[>C_
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("+*Z^7R[O?MX/\@\.#DZ.[QXO_G_"(*"B,@9G5Z>GD*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`BS^[K_.?N
MXN#RY>OH(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C`*(RP@9G5Z>GD*
M;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+`Y/#E\>W@_R#J[>CCX"(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`BP.3PY?'MX/\@ZNWH
MX^`B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ,@HC+"!F=7IZ>0IM<V=I
M9"`B8V%L96YD87(B"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E
M+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U
M='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S@*
M;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B
M"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(L_PX.+H\OPB"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N
M=')Y(&YO="!F;W5N9"(*;7-G<W1R("+.\NSE[>CR_"#HY^SE[>7MZ/\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I
M9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.#@Q"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(L?@X^[K[N+N
MZB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*(RP@9G5Z
M>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B6_'R\.[JX"`E<R#HYR`E<UTB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS
M9VED(")H.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U
M;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C4@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B
M:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT
M97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@
M(FQI;F5S72(*;7-G<W1R("+'X./NZ^[B[NHB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES
M;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.`IM
M<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"B,L(&9U>GIY"FUS9VED(")N
M86UE(@IM<V=S='(@(LCL_R(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R-`HC
M+"!F=7IZ>0IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*(B,M
M(RTC+2,M(R`@<G5?4E4N<&\@*$AO<F1E('8R+C$I("`C+2,M(RTC+2-<;B(*
M(B,M(RTC+2,M(R`@<G5?4E4N<&\@*$E-4"!V,RXQ*2`@(RTC+2,M(RTC7&XB
M"B+-[N+NY2#Q[N[A^>7MZ.4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C$R,C`*(RP@9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B
M"FUS9W-T<B`B(@HB(RTC+2,M(RTC("!R=5]252YP;R`H2&]R9&4@=C(N,2D@
M(",M(RTC+2,M(UQN(@HB(RTC+2,M(RTC("!R=5]252YP;R`H24U0('8S+C$I
M("`C+2,M(RTC+2-<;B(*(LWNXN[E(/'N[N'YY>WHY2(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3`T"B,L(&9U>GIY"FUS9VED(")N;W1E<&%D(@IM<V=S
M='(@(L?@[.7RZN@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM
M<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@HB(RTC+2,M(RTC
M("!C;VUP96YD:75M+G!O("A)35`@2#,@=C0N,"XT*2`@(RTC+2,M(RTC7&XB
M"B(C+2,M(RTC+2,@(&-O;7!E;F1I=6TN<&\@*$E-4"!(,R!V-"XP+C0I("`C
M+2,M(RTC+2-<;B(*(LW@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_]<;B(*(B,M(RTC
M+2,M(R`@<G5?4E4N<&\@*$YA9R!(,R`H,BXP+C,I*2`@(RTC+2,M(RTC7&XB
M"B+(Y^SE[>CR_"#O\.#BX"#D[O'R\^_@7&XB"B(C+2,M(RTC+2,@(')U7U)5
M+G!O("A.86<@2#,@*#(N,"XS*2D@(",M(RTC+2,M(UQN(@HBR.?LY>WH\OP@
M[_#@XN`@Y.[Q\O/OX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`HC+"!F=7IZ>0IM<V=I
M9"`B<FES:6YG(@IM<V=S='(@(L+MZ.S@[>CE(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")S97)V:6-E('5N
M879A:6QA8FQE(@IM<V=S='(@(LWE\B#D[O'R\^_M^_4@[>#Q\O#NY>HN(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF
M9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`BRN#KY>WDX/#\(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,34P"B,L(&9U>GIY"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T
M<B`B[O#T[N/PX/3H]^7QZN#_(.[XZ.'JX"(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.3(X"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")T
M96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("+/[NCQZB(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"B,L(&9U
M>GIY"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M
M(@IM<V=S='(@(L_P[O?@_R#H[?3N\.S@]NC_(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N
M:69I960B"FUS9W-T<B`B(@H*(R!F=7IZ>0HC.B!L:6(O2&]R9&4O34E-12]0
M87)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("+RY>KQ\B#Q[N[A
M^>7MZ/\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,L(&9U>GIY
M"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"B(C+2,M(RTC+2,@(')U
M7U)5+G!O("A(;W)D92!V,BXQ*2`@(RTC+2,M(RTC7&XB"B(C+2,M(RTC+2,@
M(')U7U)5+G!O("A)35`@=C,N,2D@(",M(RTC+2,M(UQN(@HBQ.7I\?+BZ.4Z
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C0P"FUS9VED(")W.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]G;%]%4RYP;P``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V,3,U
M,S`@,3`U,34T,S0Q-#(@,#$W-3$Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@2&]R9&4@,BXR+C0@1V%L:6-I86X@=')A
M;G-L871I;VXN"B,*(R!697)S:6]N(&EN:6-I86P@9&4Z"B,*(R!2869A96P@
M5F%R96QA(#QR869A96PN=F%R96QA0'5S8RYE<SX*(R!'=6EL;&5R;6\@365N
M9&5Z(#QG=6EL;&5`=7-C+F5S/@HC(%-E<G9I8VEO(&1E(&%T96YC:6]N(&$@
M=7-U87)I;W,@92!S:7-T96UA<PHC(%5N:79E<G-I9&%D92!D92!386YT:6%G
M;R!D92!#;VUP;W-T96QA"B,*(R!2979I<V%D82!Y(&-O<G)E9VED82!P;W(Z
M"B,@"B,@4V5R=FEC:6\@9&4@;F]R;6%L:7IA8VEO;B!L:6YG=6ES=&EC82`\
M<VYL=7-C0'5S8RYE<SX*(R!5;FEV97)S:61A9&4@9&4@4V%N=&EA9V\@9&4@
M0V]M<&]S=&5L80HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92`R+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`S
M+3`X+3$Y(#$S.C,U1TU4*S%<;B(*(DQA<W0M5')A;G-L871O<CH@4V5R=FEC
M:6\@9&4@3F]R;6%L:7IA8VEO;B!,:6YG=6ES=&EC82`\<VYL=7-C0'5S8RYE
M<SY<;B(*(DQA;F=U86=E+51E86TZ($=A;&5G;UQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)
M4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET
M7&XB"B)8+4=E;F5R871O<CH@2T)A8F5L(#`N.2XU7&XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME
M>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@
M(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B
M)R5S)R!N;VX@97-TX2!C;VYF:6=U<F%D;R!N;R!R97AI<W1R;R!D92!(;W)D
M92XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H
M92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@
M*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR
M-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B3W!E<F%C:?-N<R!D92!M86YT96UE
M;G1O("5S("T@0V]N9FER;6%C:?-N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R
M965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI
M<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L
M:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S
M.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@
M0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N
M="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB36%R<75E
M(&YA(&-U861R[6-U;&$@82!O<&5R86-I\VX@;W4@;W!E<F%C:?-N<R!Q=64@
M9&5S97AA(&5X96-U=&%R(&%G;W)A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B
M0V%D82`U(&UI;G5T;W,B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@
M;V8@)7,B"FUS9W-T<B`B6VQI\6$@)7,@9&4@)7-=(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%X96YD82!D92!E;F1E
M<F5Z;W,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M(")#86QE;F1A<FEO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z
M,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@
M;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@
M;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I
M;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V
M-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U
M<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS
M-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@
M(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(D$@<_IA(&EN9F]R;6%C:?-N(@H*
M(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"B,L(&9U>GIY"FUS9VED("(R-"!(
M;W5R($9O<FUA="(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G
M<W1R("(R-"!H;W)A<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z
M-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E
M<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B02!F871A
M;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B/&(^4')O9'5C:75S92!U
M;B!E<G)O(&=R879E.B`\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)
M344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N
M+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G
M:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(D$@<_IA(&EN9F]R;6%C:?-N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F
M<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A
M9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N
M:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T<B`B16YD97)E>F\B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R
M-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")%;F1E<F5Z;R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED
M(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS
M9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A
M:7(B"FUS9W-T<B`B16YG861I<B!U;B!P87(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%X96YD82!D
M92!E;F1E<F5Z;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B07AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R
M(")%;F=A9&ER('5N('!A<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B16YD97)E>F\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")!
M9&1R97-S($)O;VLB"FUS9W-T<B`B07AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED
M(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0HC
M+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(D5N9&5R97IO(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PHC+"!F=7IZ>0IM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&-U;64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L
M8W5M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L8W5M92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*(RP@
M9G5Z>GD*;7-G:60@(D%L:6=N(@IM<V=S='(@(D%L8W5M92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L
M:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM
M<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A
M=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT
M:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!
M;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS
M9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B
M06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B16YD97)E>F\@9&4@
M8V]R<F5O(&5L96-T<O-N:6-O.B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@
M=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B3R!V86QO<B!Q=64@97-P96-I9FEC
M;W4@;F]N(.D@=N%L:61O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@
M;V-C=7)E9"XB"FUS9W-T<B`B/&(^4')O9'5C:75S92!U;B!E<G)O(&=R879E
M.B`\+V(^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y
M"FUS9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I
M9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@
M=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,
M:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*
M;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@
M0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I
M9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R
M86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@
M(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R
M92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@
M<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@
M(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!
M<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F
M;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R
M871I;VYS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R
M,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U
M:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM
M<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!2
M96UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G
M:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED
M(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@9&ES<&_Q:6)L
M97,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC
M=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)
M4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N
M9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O
M<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(D%N:79E<G-A
M<FEO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,U,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB
M(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO
M;B!S92!A=&]P;W4@;R!A>&5N=&4@9&4@;F]T:69I8V%C:?-N("5S+B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@
M4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B
M0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED
M(")";W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN
M97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S
M(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N
M9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB
M"FUS9W-T<B`B0V]R<F5O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E
M9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@
M9G5Z>GD*;7-G:60@(D--4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@
M;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO
M="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(D9A;&QO
M=2#S(&-O;F5C=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M(RP@9G5Z>GD*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86QE;F1A<FEO(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E
M;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")#86YC96QA<B!O(&EN9F]R;64@
M9&4@<')O8FQE;6%S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z
M,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E
M;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T
M<B`B3W!C:?-N<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD
M($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R
M(")496SI9F]N;R!M\V)I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R(")496SI9F]N;R!M\V)I;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#
M96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U
M>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@;?-B:6PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W
M.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*
M;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I
M9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H
M860B"FUS9W-T<B`B5&%R>&5T82!D92!V:7-I=&$@*'9#87)D*2(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R
M(")$97-F86-E<B!O<R!C86UB:6]S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*
M(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*
M;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")487)X971A(&1E('9I<VET82`H
M=D-A<F0I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R
M(")4[71U;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3
M:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#
M:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T
M>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(").;VX@<V4@
M871O<&]U(&\@87AE;G1E(&1E(&YO=&EF:6-A8VGS;B`E<RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM
M<V=I9"`B0VQE87(B"FUS9W-T<B`B0V%L96YD87)I;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R
M($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A4
M5%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD
M;W<B"FUS9W-T<B`B4&5C:&%R(&$@>&%N96QA(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO
M=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED
M(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ
M-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-`IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#;VUP8?'M
M82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B0V]M<&'Q[6$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW
M"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R
M92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C4Q"B,L(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM
M<V=S='(@(D-H879E(&1E(&%C8V5S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;F=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@
M1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@T-0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@
M=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B
M"FUS9W-T<B`B0V]N=&ED;R!D92`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L
M(&9U>GIY"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O;7!A\>UA(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")#86UP;R!I;7!O
M<G1A9&\Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@
M(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@
M4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O
M:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y
M,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D
M9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O
M<B!,1$%0+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@
M(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A
M<"!S97)V97(B"FUS9W-T<B`B1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED
M;W(@3$1!4"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB
M)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4R,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T
M:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S
M"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R
M:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,B"FUS9W-T<B`B1F%L;&\@\R!A8G)I<B!O(&WS9'5L;R!D92!T87)E9F%S
M(&1E(&UA;G1E;65N=&\@)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(D9A;&QO(/,@86)R:7(@;R!M\V1U;&\@
M9&4@=&%R969A<R!D92!M86YT96UE;G1O("5S(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V
M:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DAO<F1E(&YO;B!S92!C;VYF:6=U<F]U(&-O<G)E8W1A;65N=&4B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A
M=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@
M=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A
M8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V
M:61O<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C
M;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<
M(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@
M(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI
M;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM
M<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I
M9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N
M.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM
M<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN
M9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S
M='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R(")$:6%R:6%M96YT92(*"B,Z(&%D;6EN
M+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED
M(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E
M8V5I=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@
M(D1I87)I86UE;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E
M87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5F875L="(*;7-G<W1R("))9&5N=&ED861E('!R961E=&5R;6EN861A
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B57-A
M<B!O('9A;&]R('!O<B!D969E8W1O(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G
M<W1R("))9&5N=&ED861E('!R961E=&5R;6EN861A(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT(%-H96QL
M(@IM<V=S='(@(DED96YT:61A9&4@<')E9&5T97)M:6YA9&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@(D1E
M;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS
M9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED
M(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*
M;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E
M;&5T92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0HC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S
M='(@(DED96YT:61A9&4@<')E9&5T97)M:6YA9&$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R:6-I\VX@9&\@
M<')O8FQE;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC
M+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I8VGS
M;B!C;VUP;&5T83HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM
M<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BXB"FUS9W-T<B`B4F5X:7-T<N%R;VYS92!O<R!D971A;&QE<R!P
M87)A(&\@861M:6YI<W1R861O<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED(")$97<@
M4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN=#H@(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O
M<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@IM
M<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R(")/<&-I\VYS(&1E('9I<W5A;&EZ86-I\VXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B3W!C:?-N<R!D92!V
M:7-U86QI>F%C:?-N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I
M9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P
M;&%Y(&9O<FUA="(*;7-G<W1R(")/<&-I\VYS(&1E('9I<W5A;&EZ86-I\VXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R(").;VX@86-C961A(&1I<F5C=&%M96YT92!A(%PB;6%I;G1E;F%N8V4N
M<&AP7"(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI
M;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G
M:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@
M(D-O<G)E;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L
M(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I
M="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N
M:6YC.C(U"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%
M9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I
M9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B
M87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I
M9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*
M;7-G<W1R(")#;W)R96\@96QE8W1R\VYI8V\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B
M16YD97)E>F\@9&4@8V]R<F5O(&5L96-T<O-N:6-O.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")/=71R82!I;F9O<FUA8VGS;B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%;6%I
M;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED(")%
M;6]T:6-O;G,B"FUS9W-T<B`B3W!C:?-N<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ>0IM<V=I
M9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B4V5N(')E<W5L=&%D;RXB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P
M"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E-E;B!R97-U;'1A9&\N
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I
M9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B
M16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT
M97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R
M('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(D5R<F\B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E<GD@
M,34@;6EN=71E<R(*;7-G<W1R(")#861A(#$U(&UI;G5T;W,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`B0V%D82`U(&UI;G5T;W,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=U
M;F1O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(D-A9&$@-2!M:6YU=&]S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B0V%D82!I;FEC:6\@9&4@<V5S:?-N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-A
M9&$@;65D:6$@:&]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E
M(@IM<V=S='(@(D-A9&$@;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")%
M>&5M<&QO(&1E('9A;&]R97,Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W
M"FUS9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@
M(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U
M"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T
M97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%
M>'!O;F5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N(@IM<V=S='(@(D9A;&QO=2#S(')E8W5P97)A<B!A
M<R!P<F5F97)E;F-I87,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(")&86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B1F%L
M;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B
M1F%L;&]U(/,@8V]N96-T87(@8V\@<V5R=FED;W(@3$1!4"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"B,L(&9U>GIY"FUS9VED(")&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(D9A;&QO=2#S(&%B<FER(&$@8V]N97AI\VX@3$1!4"!A("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D9A;&QO=2#S(&-O;F5C
M=&%R(&-O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B1F%L;&]U(/,@<F5C=7!E<F%R
M(&\@1$X@9&\@=7-U87)I;SH@6R5D72`E<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I
M;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*
M(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R(")%<G)O(&1E
M(&EM<&]R=&%C:?-N.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B
M1F%X97,B"FUS9W-T<B`B1F%X(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B
M1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE
M="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L
M(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(E3M='5L;R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`B3F]M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@
M=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@U.0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM
M<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*
M;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@
M475A<G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M,0IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T
M(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@
M9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B
M(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E
M8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N
M=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I
M9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G
M:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(DYO=&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&
M;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`B3F]M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&
M=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:6-I\VX@8V]M<&QE=&$Z
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DYO
M;64Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(D=I=F5N($YA
M;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3(*
M;7-G:60@(D=O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"FUS9VED(")';V]G;&4@
M36%P<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q
M"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES
M8V%L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'
M<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1W)E96YL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R
M96YA9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G
M:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T
M92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O
M=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S
M="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS9W-T
M<B`B07AE;F1A(&1E(&5N9&5R97IO<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U
M:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U"
M:7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS
M9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L
M86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V
M>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R
M(")!>'5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G
M:60@(DAE;'!E<B(*;7-G<W1R(")!>'5D82(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A
M=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T<B`B16YD97)E
M>F\@<&%R=&EC=6QA<B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM
M<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0
M:&]N92(*;7-G<W1R(")496SI9F]N;R!P87)T:6-U;&%R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC
M;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@
M(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@
M(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G
M:60@(DE0($%D9')E<W,B"FUS9W-T<B`B16YD97)E>F\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I
M9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T
M+"!3=&5P("5D(@IM<V=S='(@(D-A;7!O(&EM<&]R=&%D;SH@)7,B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B0V%M<&\@:6UP;W)T
M861O.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G
M:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M<&]S(&EM<&]R=&%D
M;W,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(D%C:&5G=64@;R!S974@;F]M92!D
M92!U<W5A<FEO(&4@8VAA=F4@9&4@86-C97-O(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4W"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*
M;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E
M<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T
M($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B
M871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y
M<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN
M=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN
M=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L
M>2(*;7-G<W1R(")$:6%R:6%M96YT92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M
M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N
M('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES
M<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I
M9"`B2G5S=&EF>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#
M96YT97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME
M>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F
M=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(DUE;G-A>&4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I
M8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA
M7WEO=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B3&EN9W5A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI
M8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED
M("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP
M.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U>GIY"FUS9VED("),87EO=70B"FUS
M9W-T<B`B4&5C:&%R(&$@<V5S:?-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R
M(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE
M8F%N;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(D5X
M96UP;&\@9&4@=F%L;W)E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T
M:&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R(").=6YC82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U
M"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED
M("),:6=H="!286EN(@IM<V=S='(@(D5N=')A<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),
M:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE
M<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(D5N=')A<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K
M:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS
M9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G
M<W1R("),:7-T87(@;W,@=&5M87,@9&4@87AU9&$B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B
M3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B
M"FUS9W-T<B`B3&ES=&%R(&]S('1E;6%S(&1E(&%X=61A(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI
M<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),
M:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D5N=')A
M<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(E!E8VAA<B!A('-E<VGS;B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B16YT
M<F%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM
M<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&%R969A<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4&]R(&%L9W5N:&$@
M<F%Z\VX@;F]N('-E(&1E=2!I;FEC:6%D;R!A('-E<VGS;BX@4')O8F%B;&5M
M96YT92!E<V-R:6)I=2`B"B)I;F-O<G)E8W1A;65N=&4@;R!N;VUE(&1E('5S
M=6%R:6\@;W4@82!C:&%V92!D92!A8V-E<V\N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*
M;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")096-H87(@82!S97-I\VXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E
M<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO
M=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*
M;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@
M(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B0V]R<F5O(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM
M<V=S='(@(D-O<G)E;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED
M(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F
M=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(D-O<G)E;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@
M9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B0V]R<F5O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R(")#;W)R96\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A
M=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*
M(RP@9G5Z>GD*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")!=FES;R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ
M=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")#86UP;W,@8V]R
M<F5S<&]N9&5N=&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I
M8VEN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")-96UB97)S(@IM<V=S='(@(DUE
M;6]R86YD;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED
M(")-96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E
M;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@
M(DUE;G-A>&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@
M8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB
M=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S
M<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-96YS87AE(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V
M,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DUE;G-A
M>&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM
M<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(B(*
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(E)E>&ES
M='+A<F]N<V4@;W,@9&5T86QL97,@<&%R82!O(&%D;6EN:7-T<F%D;W(N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T
M87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE
M=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*
M;7-G<W1R(")#;W)R96\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED
M(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")%<G)O
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL
M86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A
M8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I
M;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T
M;R!U<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS
M9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS
M9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I
M9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED
M(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I
M;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM
M<V=S='(@(DUE;G-U86QM96YT92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G
M:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!3=6YN
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3,*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-
M;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*
M;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU
M;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B
M37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")!('/Z82!I;F9O<FUA
M8VGS;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@
M(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I
M9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S='(@(DYO;64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S
M8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,
M('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T
M92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T
M>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B3G5N8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE
M9&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G
M;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E
M('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM
M<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I
M;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A
M;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")#
M:&%V92!D92!A8V-E<V\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP
M:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA
M=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM<V=S='(@(DYO=&%S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R(")296=R97-A<B#A<R!O<&-I\VYS(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97(B"FUS9W-T<B`B
M3G5N8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B
M3FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T
M8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@
M<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO
M;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R82!A(&%U=&5N=&EF
M:6-A8VGS;B!P;W(@4U%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D1E<V9A8V5R
M(&]S(&-A;6)I;W,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@)7,N(@IM<V=S='(@(DYO;B!E<W!E8VEF:6-O=2!A(&-O;F9I
M9W5R86-I\VX@<&%R82!A<R!C871E9V]R[6%S(%-13"XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M(@IM<V=S='(@(DYO;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R
M82!A<R!P<F5F97)E;F-I87,@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@
M(DYO;B!E<W!E8VEF:6-O=2!A(&-O;F9I9W5R86-I\VX@<&%R82!A<R!C871E
M9V]R[6%S(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S$W"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(").
M;VX@97-P96-I9FEC;W4@82!C;VYF:6=U<F%C:?-N('!A<F$@87,@8V%T96=O
M<NUA<R!344PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*
M;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0IM<V=I9"`B3F\@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M
M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@
M<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ
M,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T
M:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP
M.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B!E<W!E8VEF:6-O
M=2!A(&-O;F9I9W5R86-I\VX@<&%R82!A(&%U=&5N=&EF:6-A8VGS;B!P;W(@
M4U%,+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B!E<W!E8VEF:6-O=2!A
M(&-O;F9I9W5R86-I\VX@<&%R82!A(&%U=&5N=&EF:6-A8VGS;B!P;W(@4U%,
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3F]N(&5S<&5C:69I8V]U(&$@8V]N9FEG=7)A
M8VGS;B!P87)A(&$@875T96YT:69I8V%C:?-N('!O<B!344PN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).
M;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P
M96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#
M4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S
M"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").;W1A<R(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B3F]T87,B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4X,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G
M:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR,C$*(RP@9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")!8VAE9W5E(&\@<V5U(&YO
M;64@9&4@=7-U87)I;R!E(&-H879E(&1E(&%C8V5S;R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@
M9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDS"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(E1E;.EF;VYO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV
M,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE
M;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G
M<W1R(").;W1A<R(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%S(@H*(SH@<V5R=FEC
M97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R
M;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO=F5M
M8F5R(@IM<V=S='(@(DYU;F-A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYO;64B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB
M97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F
M(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G
M:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T
M($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED
M(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S
M97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL
M>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG
M92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,S4*;7-G
M:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H
M:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*
M;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!C:?-N<R(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T
M<B`B3W!C:?-N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B
M3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*
M;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L
M('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T
M:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D]U=')A(&EN9F]R;6%C:?-N(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*
M;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ
M>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I
M9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G
M:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B
M4&%S<W=O<F0B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N
M9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S
M=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I
M9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED
M(")087-S=V]R9#HB"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A
M<W-W;W)D.B`B"FUS9W-T<B`B0VAA=F4@9&4@86-C97-O(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED
M(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM
M<V=S='(@(D9U;F-I\VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM
M<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@
M(E)E86QI>F%R(&]P97)A8VGS;G,@9&4@;6%N=&5M96YT;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z>GD*;7-G:60@(E!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B4F5A
M;&EZ87(@;W!E<F%C:?-N<R!D92!M86YT96UE;G1O(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*
M;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C4*(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM
M<V=S='(@(D]U=')A(&EN9F]R;6%C:?-N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED
M(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@
M(E1E;.EF;VYO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U
M9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN(@IM<V=S='(@(D%C:&5G=64@=6X@<F5S=6UO(&1O('!R
M;V)L96UA+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B06-H96=U
M92!O('-E=2!N;VUE(&1E('5S=6%R:6\@92!C:&%V92!D92!A8V-E<V\B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L
M:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM
M<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T
M('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F
M<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS
M9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E
M=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N
M<R(*;7-G<W1R(")296=R97-A<B#A<R!O<&-I\VYS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@
M9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY
M"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(EM);F9O<FUE(&1O(%!R;V)L96UA
M72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE
M;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEC:?-N(&1O('!R;V)L96UA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B4')O
M:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM
M<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O
M<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@
M(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T
M;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I9"`B
M475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P
M"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@
M4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I
M;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED
M(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ>0IM
M<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")-96YS87AE(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F
M<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ
M"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B06-T=6%L:7IA
M<B!A('9I<W1A(&1O(')E<W5M;SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")2
M96QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E
M<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C$S"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B4V%C87(@;R!P
M87(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")386-A<B!O('!A<B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*
M;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E
M('!A:7(B"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@
M<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E-A8V%R
M(&\@<&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")2
M96UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4V%C87(@;R!P87(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3R!C86UP;R!R97%U:7)I
M9&\@)W5I9"<@;F]N(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A8VGS
M;B!D87,@(@HB<')E9F5R96YC:6%S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)/(&-A;7!O
M(')E<75I<FED;R`G=6ED)R!N;VX@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF
M:6=U<F%C:?-N(&1A<R`B"B)P<F5F97)E;F-I87,N(@H*(SH@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)/(&-A;7!O(')E<75I<FED;R`G=6ED)R!N;VX@
M9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F%C:?-N(&1A<R`B"B)P<F5F
M97)E;F-I87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D-H879E(&1E(&%C8V5S;R(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E
M="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP
M.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I
M;VYS(@IM<V=S='(@(E)E9W)E<V%R(.%S(&]P8VGS;G,B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO
M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R(")296=R97-A<B#A<R!O<&-I\VYS(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM
M<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A
M;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(D9U;F-I\VXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G
M:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G
M:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R
M(")&=6YC:?-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP
M=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(DUE;G-A>&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G
M:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U
M"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U
M,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@
M3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,
M=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*
M;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B4V%V92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E("5S(@IM<V=S='(@(D=A<F1A<B!A<R!O<&-I\VYS(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I
M;VYS(@IM<V=S='(@(D=A<F1A<B!A<R!O<&-I\VYS(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N
M9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T
M96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I
M9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E
M87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C8VEO
M;F4@;R!F;W)M871O(&1A(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS9VED
M(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-38*
M;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@
M(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&1A
M=&$Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("(B"B)396QE8V-I;VYE(&]S(&-A<F%C=&5R97,@<75E(&YE
M8V5S:71E(&1A<R!C=6%D<NUC=6QA<R!Q=64@871O<&%RX2!M86ES("(*(F%B
M86EX;RX@4&]D92!C;W!I86QO<R!E('!E9V%L;W,@9&5N9&4@82#A<F5A(&1E
M('1E>'1O+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED
M(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE8V-I
M;VYE(&\@9&5L:6UI=&%D;W(@9&$@9&%T83HB"@HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB
M"FUS9W-T<B`B4V5L96-C:6]N92!O(&9O<FUA=&\@9&$@9&%T83HB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E-E
M;&5C8VEO;F4@;R!D96QI;6ET861O<B!D82!D871A.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R
M;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!H;W)A.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8V-I;VYE(&1O
M=7,@8V%M<&]S('%U92!C;VEN8VED86XN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E
M;&5C8VEO;F4@82!L:6YG=6$Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B16YV:6%R(&\@:6YF;W)M92!D92!P<F]B;&5M87,B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N
M9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I
M9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM
M<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@
M(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")'87)D
M87(@87,@;W!C:?-N<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R("(B"B)%<W1A8FQE8V4@82!F<F5C=65N8VEA(&1E(&%C='5A;&EZ86-I
M\VX@9&%S('#A>&EN87,@92!O=71R87,@;W!C:?-N<R!D92`B"B)V:7-U86QI
M>F%C:?-N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`HC+"!F=7IZ
M>0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P
M;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D5S=&%B;&5C92!A(&9R96-U96YC
M:6$@9&4@86-T=6%L:7IA8VGS;B!D87,@<.%X:6YA<R!E(&]U=')A<R!O<&-I
M\VYS(&1E("(*(G9I<W5A;&EZ86-I\VXN(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P
M9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P
M<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R
M(")297-U;6\@8G)E=F4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@
M;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H
M92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G
M:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G
M:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W
M97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I
M;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W
M87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE
M<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I
M9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B
M4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I
M;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G
M<W1R(")/;6ET:7(@;R!M86YT96UE;G1O(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F%K:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VQO=F5N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@
M(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I
M9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-S@*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I
M=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@
M;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*
M;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D5N9&5R97IO(&1O('1R
M86)A;&QO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3
M;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N
M9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N
M(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS
M9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E
M<B!);G!U="(*;7-G<W1R(")%;G1R861A(&1E(&-A<F%C=&5R97,@97-P96-I
M86ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B
M4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(DEM<&]R=&%R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@
M(D-A;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`B02!S^F$@:6YF;W)M86-I\VXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B
M4W1R965T($%D9')E<W,B"FUS9W-T<B`B16YD97)E>F\@9&\@=')A8F%L;&\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM
M<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(DYO;B!S92!A=&]P;W4@;R!A>&5N=&4@9&4@;F]T
M:69I8V%C:?-N("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(B(*
M"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(D-O<G)E8W1A;65N=&4B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4F5S=6UO
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U
M;G)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z
M>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B26UP;W)T87(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")5<W5A
M<FEO(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*
M(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B57-U87)I;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@
M;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]344PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R
M(&EN('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3
M=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP
M:'`Z,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")4[71U
M;&\B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ
M>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B
M5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R(")487)E9F%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@
M(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP
M97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E
M9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@
M*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDX.`HC+"!F=7IZ>0IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@
M<WES=&5M+B(*;7-G<W1R(")&:6YA;&EZ;W4@82!S97-I\VXN/&)R("\^1W)A
M8VEA<R!P;W(@=7-A<B!O('-I<W1E;6$N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+
M;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O
M:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I
M;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@
M;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO
M="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I
M9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I
M9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@
M;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I
M;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@
M=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R
M>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S
M('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D
M+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H
M87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O
M('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z
M>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I
M8RXB"FUS9W-T<B`B3R!V86QO<B!D96)E('-E<B!U;B!N^FUE<F\N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE
M('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E
M;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S
M<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S
M(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C
M:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R
M(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R
M960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@
M;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*
M;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R
M>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R(").;VX@:&%I('!R
M969E<F5N8VEA<R!D:7-P;_%I8FQE<RXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T
M:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C
M;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ
M("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S
M7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O
M<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N
M=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U
M<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@
M=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B3R!V86QO<B!D
M96)E('-E<B!U;B!N^FUE<F\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC
M:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.
M("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S
M.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y
M"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N
M=6UB97(N(@IM<V=S='(@(D\@=F%L;W(@9&5B92!S97(@=6X@;OIM97)O+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H
M:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H
M870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O
M<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I
M="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T
M(&QE87-T(&]N92XB"FUS9W-T<B`B3R!N^FUE<F\@9&5B92!S97(@<&]L;R!M
M96YO<R!U;B`Q+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G
M>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4:&ES
M('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D\@=F%L;W(@9&5B
M92!S97(@=6X@;OIM97)O+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D
M(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD
M97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")4[71U;&\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K
M:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I
M9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T
M<B`B5.UT=6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U
M"FUS9VED(")4;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4
M;V1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R
M<F]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O
M<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4
M<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U=F%L=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP
M:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6
M+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*
M;7-G:60@(E523"(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y
M;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*
M(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C
M;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R
M82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").
M;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C@X
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`Q-@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R
M(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DYO
M;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").
M;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS
M-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO;B!F
M;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYO;B!F;VD@
M<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS
M9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!3
M44PN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z
M-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(").;VX@
M9F]I('!O<VEB;&4@;6]D:69I8V%R(&%S('!R969E<F5N8VEA<SH@6R5D72`E
M<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO
M;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R=FED;W(@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*
M;7-G<W1R(").;VX@9F]I('!O<VEB;&4@<F5X:7-T<F%R(&%S('!R969E<F5N
M8VEA<R!N82!S97-I\VXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H
M<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B3F]N(&9O
M:2!P;W-I8FQE(&-O;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O(&]P96X@5D93
M(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R
M(").;VX@9F]I('!O<VEB;&4@8V]N96-T87)S92#S('-E<G9I9&]R(%-13"XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N(@IM<V=S='(@(DYO;B!F;VD@<&]S:6)L92!C;VYE8W1A<G-E(/,@<V5R
M=FED;W(@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G
M:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*
M;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I
M(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE
M('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A
M9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F]N(&9O:2!P;W-I8FQE(&-O
M;F5C=&%R<V4@\R!S97)V:61O<B!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DYO;B!F
M;VD@<&]S:6)L92!T<F%D=6-I<B!E<W1E(&1O8W5M96YT;R!D92!7;W)D(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W
M:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I
M9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E<V9A8V5R(&]S(&-A;6)I;W,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S
M"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED
M(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I
M;VXZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D
M92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET
M960@07)A8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G
M:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@
M8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W
M;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5
M;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L
M(&9U>GIY"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E5S=6%R:6\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED
M("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A
M<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO
M>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS
M9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@
M(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R(")5
M<W5A<FEO(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T
M:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(D]P8VGS;G,@9&\@=7-U87)I;R(*"B,Z('-I
M9VYU<"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N
M(@IM<V=S='(@(D]P8VGS;G,@9&\@=7-U87)I;R(*"B,Z('-I9VYU<"YP:'`Z
M,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D
M(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`B57-U87)I;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE
M.B(*;7-G<W1R(")5<W5A<FEO(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")5
M<W5A<FEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N
M9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B
M5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L
M=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B
M5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE
M="!.86TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*
M;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M
M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I
M=&ES:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@
M27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I
M82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4
M($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A4
M5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N
M9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%V:7-O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@
M(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")7
M96(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(E-E;6%N86QM96YT92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(D)E
M;G9I9&\O82P@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")"96YV:61A(&$@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@
M)7,B"FUS9W-T<B`B0F5N=FED;R]A+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R
M;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE
M<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I
M;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N
M:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*
M;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS
M9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B
M5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B
M5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@
M(E=O<FL@061D<F5S<R(*;7-G<W1R(")%;F1E<F5Z;R!D;R!T<F%B86QL;R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*
M;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5LZ69O;F\@9&\@=')A8F%L
M;&\B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@
M82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"
M87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D
M($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N
M871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED
M96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G
M<W1R(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-0HC+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R(")!02(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS
M9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G
M<W1R(")!;G5A;&UE;G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D
M('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO
M="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"FUS9VED(")9;W4@9&ED(&YO
M="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM
M<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB
M"FUS9W-T<B`B06-T=6%L:7KA<F]N<V4@87,@<_IA<R!O<&-I\VYS+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9
M;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")$97-C<FEB82!O('!R
M;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(&EN9F]R;64N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM
M<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(D-A9'5C;W4@
M82!S^F$@<V5S:?-N(&5N("5S(&5X<&ER;W4N($EN:6-I92!U;FAA(&YO=F$@
M<V5S:?-N+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X
M"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B
M16YD97)E>F\@9&4@8V]R<F5O(&5L96-T<O-N:6-O.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,3(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O;3H@
M861D<F5S<SHB"FUS9W-T<B`B16YD97)E>F\@9&4@8V]R<F5O(&5L96-T<O-N
M:6-O.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")!('/Z82!I;F9O<FUA8VGS;B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS
M9VED(")9;W5R($YA;64B"FUS9W-T<B`B3F]M93HB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S
M+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U
M<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T
M:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R
M(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P
M=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I
M9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B06-T=6%L
M:7KA<F]N<V4@87,@<_IA<R!O<&-I\VYS+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>3HB"FUS9W-T<B`B261E;G1I9&%D92!P<F5D971E<FUI;F%D82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9G5L;"!N86UE.B(*;7-G<W1R(").;VUE.B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@
M:&%S(&5X<&ER960N(@IM<V=S='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z87,@
M;W!C:?-N<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(D%C='5A;&EZX7)O;G-E(&%S('/Z87,@;W!C:?-N<RXB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")!8W1U86QI
M>N%R;VYS92!A<R!S^F%S(&]P8VGS;G,N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*
M(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM
M<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X
M=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G
M:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6TEN9F]R;64@9&\@4')O
M8FQE;6%=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E
M<R!O9B`E<UTB"FUS9W-T<B`B6VQI\6$@)7,@9&4@)7-=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I
M9"`B7TAE;'`B"FUS9W-T<B`B07AU9&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G
M92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB
M"FUS9W-T<B`B16YT<F%R(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B
M4&5C:&%R(&$@<V5S:?-N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B3W!C
M:?-N<R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,
M:6YK+BXN(@IM<V=S='(@(E-A8V%R(&\@<&%R(@H*(SH@;&EB+V%P:2YP:'`Z
M,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?
M5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(D%X96YD82!D92!E;F1E<F5Z;W,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E
M('5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(D-A
M;&5N9&%R:6\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS
M9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B
M"FUS9W-T<B`B5.UT=6QO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK
M;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U
M="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E
M9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS
M9W-T<B`B3F]M92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G
M:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP
M;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I
M9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@
M(G)I<VEN9R(*;7-G<W1R(")!=FES;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G
M:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M
M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B
M=')Y(&%G86EN(@IM<V=S='(@(D-A9&$@:6YI8VEO(&1E('-E<VGS;B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O
M;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I
M9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L
M96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B5&%R>&5T82!D
M92!V:7-I=&$@*'9#87)D*2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O
M;2(*;7-G<W1R("(B"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V-A7T53+G!O````````````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#<Q,C8S
M,"`Q,#4Q-30S-#$T,B`P,3<T-S,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!(;W)D92!#871A;&%N('1R86YS;&%T:6]N
M+@HC($-O<'ER:6=H="`H0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($AO<F1E('!A8VMA9V4N"B,@2F]R9&D@1VER86QT(#QP<F]J96-T92YK
M,D!U<&-N970N97,^+"`R,#`V+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`U7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#8M,#4M,3$@,3(Z-3$K,#(P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP-RTQ-"`Q,3HP."LP,3`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($IO<F1I($=I<F%L="`\<')O:F5C=&4N:S)`=7!C;F5T+F5D=3Y<;B(*
M(DQA;F=U86=E+51E86TZ($-A=&%L86X@/&1E=D!L:7-T<RYH;W)D92YO<F<^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT
M.0IM<V=I9"`B(@HB("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES
M(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RXB
M"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4S"FUS9VED("(B
M"B(@("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE('1O
M('1H92!C;VUP96YD:75M+B!5<V5F=6P@=&]<;B(*(B`@("`@("`@("`@("`@
M("`@("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E
M;G0@8G)A;F-H('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M9V5N97)A=&5D(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,3,*;7-G:60@(B(*(B`@+6(L("TM8F%S93TO4$%42"`@
M1G5L;"!P871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@
M<VAO=6QD(&)E7&XB"B(@("`@("`@("`@("`@("`@("`@('5S960N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.0IM<V=I9"`B(@HB("`M
M8RP@+2UC;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@
M=&\@=&AI<R!C;VUP96YD:75M(&9I;&5<;B(*(B`@("`@("`@("`@("`@("`@
M("`@("`@("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU
M;2YP;R!I;B!T:&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!H;W)D
M92]P;R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HV,R!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$@<&\O=')A;G-L871I;VXN
M<&AP.C@W"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E
M('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'1<
M;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN
M<&\@:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,30*;7-G:60@(B`@+60L("TM9&5B=6<@
M("`@("`@4VAO=R!E<G)O<B!M97-S86=E<R!F<F]M('1H92!E>&5C=71E9"!B
M:6YA<FEE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4T
M"FUS9VED("(@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N
M9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$Q-0IM<V=I9"`B("`M:"P@+2UH96QP("`@("`@("!3
M:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#(@<&\O=')A;G-L871I;VXN<&AP.C8W('!O+W1R86YS
M;&%T:6]N+G!H<#HW-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@
M(%5S92!O;FQY('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#<@<&\O=')A;G-L871I;VXN<&AP.C8Q('!O+W1R86YS
M;&%T:6]N+G!H<#HW.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4*;7-G:60@
M(B`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-0IM<V=I9"`B("`M
M;"P@+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@*;7-G:60@(B`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-#,*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A
M;G5P(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.`IM<V=I9"`B(@HB
M("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@
M;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C8R"FUS9VED("(@("UM+"`M+6UO9'5L93U-
M3T153$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D
M92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M.#`*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F
M:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S8*;7-G:60@(B(*(B`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T
M:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z.#8*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5
M<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@*;7-G:60@(B`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R
M9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C<P"FUS9VED("(B"B(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@
M;65R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8T('!O+W1R86YS;&%T
M:6]N+G!H<#HX,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@*;7-G:60@(B`@+6XL
M("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$*;7-G:60@(B`@
M+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I
M<W1I8W,@:6X@82!L;V-A;"!F:6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3$V"FUS9VED("(@("UT+"`M+71E<W0@("`@("`@(%-H
M;W<@=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI
M;F<N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4*;7-G
M:60@(B(*(B`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F
M<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.`IM<V=I9"`B("!C;VUM
M:70@("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y"FUS9VED
M("(@(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3D*
M;7-G:60@(B(*(B`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU
M;2!F:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE7&XB"B(@("`@
M("`@("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P,`IM<V=I9"`B("!E>'1R86-T("`@("!'
M96YE<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY.`IM<V=I9"`B("!H96QP("`@("`@
M("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`Q"FUS9VED("(B"B(@(&EN:70@("`@("`@($-R
M96%T92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!7
M87)N:6YG.B!4:&ES7&XB"B(@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE
M(&5X:7-T:6YG(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V"FUS9VED("(@(&UA:V4@("`@
M("`@($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@
M4$\@9FEL97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#<*;7-G:60@(B(*(B`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I
M;B!T:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9%QN(@HB
M("`@("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X="!E
M>&5C=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=5QN(@HB("`@("`@("`@("`@
M("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH96QP($%&5$52('5P9&%T92UH96QP
M(&%N9"!R979I<VEN9R!T:&5<;B(*(B`@("`@("`@("`@("`@:&5L<"!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`R"FUS9VED
M("(B"B(@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@
M=VET:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`S"FUS9VED("(@('5P9&%T92`@
M("`@(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U96YT+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`T"FUS9VED("(B"B(@('5P9&%T
M92UH96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R
M;VT@=&AE($5N9VQI<V@@6$U,(&AE;'!<;B(*(B`@("`@("`@("`@("`@9FEL
M92!A;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N
M:6YC.C$Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(@)B,Q-3$[
M("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B(@HB36%R<75E=2!A(&QA
M(&-A<V5L;&$@;"=O<&5R86-I\R!O(&]P97)A8VEO;G,@<75E(&1E<VET9V5U
M(&5X96-U=&%R(&5N("(*(F%Q=65S=&$@;V-A<VGS+B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S8W"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y
M<R!A9V\I(@IM<V=S='(@(BAF82`E<R!D:65S*2(*"B,Z(&QI8B](;W)D92YP
M:'`Z,3(T-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB
M"FUS9W-T<B`B("A#;&%U(&0G86-CZ7,@)7,I(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES
M*2(*;7-G<W1R("(H96X@)7,@9&EE<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B*&%V=6DI(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]M;W)R;W<I(@IM
M<V=S='(@(BAD96W@*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S8Y"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B*&%H:7(I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,PIM<V=I9"`B(&%T("(*;7-G<W1R
M(")E;B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E
M<UPB(&YO(.ES('5N(&1I<F5C=&]R:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(E9"`E<R!I("5S(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$Q-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@8GET97,@=W)I='1E
M;BXB"FUS9W-T<B`B)60@8GET97,@97-C<FET<RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3(X-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!O9B`E9"!E
M;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E(@IM<V=S='(@(B5D(&1E("5D
M(&5N=')A9&5S(&UA<F-A9&5S(&-O;2!A8W1U86QI='IA9&5S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B<')E=FES:?,@<&5R(&%L
M(&1I82`E9"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S
M='(@(D%V[7,@+2`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8SHS,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@061M:6YI<W1R86-I\R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(D5M<')E;71A(&1A8W1I;&%R
M("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@R-B!L:6(O
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#(X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B3W!E<F%C:6]N<R!D92!M86YT96YI;65N="`E<R`M($-O;F9I<FUA
M8VGS(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q."!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P
M(@IM<V=S='(@(D-O;F9I9W5R86-I\R!D92`E<R(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I
M9VX@57`B"FUS9W-T<B`B06QT82!D92`E<R(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R(")#;VYD:6-I;VYS
M(&1E;"!C;VYT<F%C=&4@)7,B"@HC.B!L:6(O5D93+V9T<"YP:'`Z-38X(&QI
M8B]61E,O9G1P+G!H<#HV,S8@;&EB+U9&4R]S;6(N<&AP.C0S,`HC.B!L:6(O
M5D93+W-M8BYP:'`Z-#DR"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("(E<R!J82!E>&ES=&5I>"XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U-R!L:6(O0FQO8VLO;65T87(N<&AP.C$V,R!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S-PHC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,T,R!L:6(O0FQO8VLO;65T87(N<&AP.C,T.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!E;B`E<R`E<R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HR.#<@<&\O=')A;G-L871I;VXN<&AP.C,Q-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@;F]T('=R:71A8FQE
M+B(*;7-G<W1R("(G)7,G(&YO(.ES('5N82!O<&-I\R!VX&QI9&$N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`BR7,@;F5C97-S87)I("5S+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71S(@H*(SH@;&EB+TAO<F1E
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3,U,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(DYO(',G:&$@=')O8F%T("5S+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B!2=6X@
M)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+B(*;7-G<W1R("(E<R!N;R!T
M<F]B870N($5X96-U=&$@)W1R86YS;&%T:6]N(&5X=')A8W0G('!R:6UE<BXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S(&%L("5S
M(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B3&QI8G)E
M=&$@9"=A9')E8V5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M(")!9V5N9&$@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@W-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B0FQO
M8R!D92!N;W1E<R!D92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B
M3&QI<W1A(&1E('1A<W%U97,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D92]#
M3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@;F\@Z7,@=6YA
M(&]P8VGS(';@;&ED82XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C4U
M-"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.CDR.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;F\@97-TX"!C;VYF:6=U<F%T
M(&5N(&5L(')E9VES=')E(&1E($AO<F1E+B(*"B,Z(&QI8B](;W)D92]4<F5E
M+G!H<#HQ-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B<E<R<@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T
M(&5L(&=E;F5R861O<B!D)V%R8G)E<R`G)7,G+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")3)VAA(&%F
M96=I="`G)7,G(&%L('-I<W1E;6$@9&4@9W)U<',N(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(G)7,G('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*
M;7-G<W1R(")3)VAA(&%F96=I="`G)7,G(&%L('-I<W1E;6$@9&4@;&QI8^AN
M8VEE<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HX,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)R5S
M)R!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(G)7,G(&YO(&AA(&5S
M=&%T(&-R96%T.B`E<RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!V96YT\W,@)7,@)7,@(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:6%B;&4@
M9&4@)7,@82`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#8Y(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3(X"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV.#@*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M
M+2!S96QE8V-I;VYA<B`M+2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S(X
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,S,P"FUS9VED("(M+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TB"FUS9W-T<B`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(
M;W5R($9O<FUA="(*;7-G<W1R(")F;W)M870@9&4@,3(@:&]R97,B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM
M<V=S='(@(F9O<FUA="!D92`R-"!H;W)E<R(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!H;W)E
M<R(*"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V
M:6]U<R(*;7-G<W1R("(\06YT97)I;W(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,S0T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(CQG971T97AT/B!T86<@
M;F]T(&-L;W-E9"!I;B!F:6QE("5S+EQN(@HB3W!E;FEN9R!T86<@9F]U;F0@
M:6X@;&EN92`E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3<*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F
M;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B4&5R(&$@87%U97-T(&)L;V,@97,@
M;F5C97-S:71A('5N(&UO=&]R(&1E(&)A<V5S(&1E(&1A9&5S+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(")3)VAA('!R;V1U[W0@=6X@97)R;W(@:7)R97!A<F%B
M;&4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3(P"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(")%<R!N96-E<W-I=&$@=6YA(&-L874@4$=0('#Z8FQI
M8V$@<&5R('AI9G)A<B!U;B!M:7-S871G92XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,30U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")%
M<R!N96-E<W-I=&$@=6YA(&-L874@4$=0('#Z8FQI8V$@<&5R('9E<FEF:6-A
M<B!U;B!M:7-S871G92!S:6=N870N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3`W-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C
M<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5S(&YE8V5S<VET96X@
M=6YA(&-L874@4$=0('#Z8FQI8V$L('5N82!C;&%U(%!'4"!P<FEV861A(&D@
M=6YA(&-O;G1R87-E;GEA("(*(G!E<B!D97-X:69R87(@=6X@;6ES<V%T9V4N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3DU"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@HB17,@;F5C97-S:71E;B!U;F$@8VQA=2!01U`@</IB;&EC82P@=6YA
M(&-L874@4$=0('!R:79A9&$@:2!U;F$@8V]N=')A<V5N>6$@(@HB<&5R('-I
M9VYA<B!U;B!M:7-S871G92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5S(&YE8V5S<VET
M96X@=6YA(&-L874@4R]-24U%('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P
M<FEV861A(&D@=6YA("(*(F-O;G1R87-E;GEA('!E<B!D97-X:69R87(@=6X@
M;6ES<V%T9V4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT,S$*
M;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB
M82!M97-S86=E+B(*;7-G<W1R("(B"B)%<R!N96-E<W-I=&5N('5N82!C;&%U
M(%,O34E-12!P^F)L:6-A+"!U;F$@8VQA=2!3+TU)344@<')I=F%D82!I('5N
M82`B"B)C;VYT<F%S96YY82!P97(@<VEG;F%R('5N(&UI<W-A=&=E+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M(@IM<V=S='(@(D5S(&YE8V5S<VET82!U;F$@8VQA=2!334E-12!P^F)L:6-A
M('!E<B!X:69R87(@=6X@;6ES<V%T9V4N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-PIM<V=I9"`B04T@0VQO=61S(@IM<V=S
M='(@(D[Z=F]L<R!A;"!M873M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z.`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")0;'5J82!F96)L92!A;"!M873M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")0
M;'5J82!A;"!M873M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3`*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B4G5I>&%T
M<R!A;"!M873M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3$*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")8X&9E
M8W,@9&4@;F5U(&%L(&UA=.TN(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*;7-G:60@(D%022!)1"(*
M;7-G<W1R("))1"!D92!!4$DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*
M;7-G<W1R(")3;V)R92!A<75E<W0@961I=&]R(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D5N('%U
M86YT(&$N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B06QI;F5A8VGS
M(&EN9F5R:6]R(&5X86-T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R(")!
M;&EN96%C:?,@86P@;6EG(&5X86-T82(*"B,Z(&QI8B]61E,O;75S<6PN<&AP
M.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(")3)VAA(&1E;F5G870@;"=A8V/I<R!E;B!C<F5A<B!E
M;"!D:7)E8W1O<FD@5D93+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@IM
M<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T
M<B`B4R=H82!D96YE9V%T(&PG86-CZ7,@96X@8W)E87(@;"=A<GAI=2!61E,N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT
M(%!A<W-W;W)D(@IM<V=S='(@(D-O;G1R87-E;GEA(&1E;"!C;VUP=&4B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B
M06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(D-O;7!T92!C;VYG96QA="XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S$U"FUS9VED(")!8V-O=6YT
M:6YG(@IM<V=S='(@(D-O;7!T86)I;&ET>F%C:?,B"@HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-30@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,S(*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,38@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"FUS9VED(")!9&0B"FUS9W-T<B`B
M069E9VER(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,30@861M:6XO9W)O=7!S
M+G!H<#HR,34*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")!9F5G
M:7(@=6X@9W)U<"!D97-C96YD96YT(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@U"FUS9VED(")!9&0@
M0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")!9F5G:7(@=6YA(&%U=&]R:71Z
M86-I\R!D97-C96YD96YT(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!9F5G:7(@82!C;VYT:6YU
M86-I\SHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P."!A9&UI;B]G<F]U<',N
M<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")!9F5G:7(@
M=6X@;F]U(&=R=7`B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<S(&QI
M8B](;W)D92]097)M<R]522YP:'`Z-S0*;7-G:60@(D%D9"!.97<@4&5R;6ES
M<VEO;B(*;7-G<W1R(")!9F5G:7(@=6YA(&YO=F$@875T;W)I='IA8VGS("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.CD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O
M("<E<R<B"FUS9W-T<B`B069E9VER('5N(&=R=7`@9&5S8V5N9&5N="!A("<E
M<R<N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4S(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,3,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("<E<R<B"FUS9W-T<B`B069E
M9VER('5N82!A=71O<FET>F%C:?,@9&5S8V5N9&5N="!A("<E<R<N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G
M<W1R(")!9F5G:7(@=6X@;F]U('5S=6%R:3HB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")!9&0@8V]L=6UN(@IM
M<V=S='(@(D%F96=I<B!U;F$@8V]L=6UN82XB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C,U"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B
M"FUS9W-T<B`B069E9VER(&YO=7,@;65M8G)E<RXB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B
M069E9VER('5N82!P87)E;&QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@
M82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B069E9VER(&5L(&UE;OH@)7,@
M8V]M('5N82!B87)R82!L871E<F%L(&1E($UO>FEL;&$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D
M<F5S<R!B;V]K.B(*;7-G<W1R(")!9F5G96EX(&$@;&$@;&QI8G)E=&$@9"=A
M9')E8V5S.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B069E
M9V5I>"!A(&QA(&UE=F$@;&QI8G)E=&$@9"=A9')E8V5S(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D%F96=I<B!U
M;B!U<W5A<FDB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B
M=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO
M;CH@)2(*(G,N(@IM<V=S='(@(B(*(E,G:&$@869E9VET("<E<R<@86P@<VES
M=&5M82P@<&5R\B!N;R!S)VAA('!O9W5T(&%F96=I<B!MZ7,@9&%D97,@<V]B
M<F4@(@HB;"=A;'1A.B`E<R(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")3)VAA(&%F96=I="`G)7,G
M(&%L('-I<W1E;6$N($%R82!J82!P;W0@:6YI8VEA<B!L82!S97-S:?,N(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.CDV,@IM<V=I9"`B061D:6YG(&YE=R!F
M:6QE<R!T;R!R97!O<VET;W)Y.B(*;7-G<W1R(")!9F5G:6YT(&YO=7,@9FET
M>&5R<R!A;"!R97!O<VET;W)I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C0*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B4R=H82!I;FAA8FEL:71A="!L)V]P8VGS(&0G869E9VER('5S
M=6%R:7,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#8@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
M061R9>=A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-PIM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(DQL:6)R971A(&0G861R96-E<R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B
M"FUS9W-T<B`B061M:6YI<W1R861O<B`M(&1E9FEN96EX(&QE<R!A=71O<FET
M>F%C:6]N<R!P97(@82!A;'1R97,@=7-U87)I<R(*"B,Z(&%D;6EN+VEN9&5X
M+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VGS(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,PIM<V=I9"`B061S(@IM<V=S
M='(@(D%N=6YC:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A
M;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,0IM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&+@;FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-`IM<V=I
M9"`B06QG97)I82(*;7-G<W1R(")!;&?H<FEA(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@
M(L!L:65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T<B`B06QI;F5A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*
M;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B06QI;F5A8VGS.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1O
M=',B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E
M<G,B"FUS9W-T<B`B5&]T<R!E;',@=7-U87)I<R!A=71E;G1I8V%T<R(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,3(*;7-G
M:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5&]T<R!E;',@9W)U<',B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,S@@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HW-PIM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1O=',@
M96QS('!E<FUI<V]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B5&]T<R!Q=6%T<F4@8V]S=&%T<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS
M9W-T<B`B4&5R;65T(&UO;'1E<R!A9')E8V5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4R,PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\B"FUS9W-T<B`B17,@<&5R;65T(&QA(&-O;F9I9W5R86-I
M\R!D96P@=&EP=7,@9&4@;&QI<W1E<R!O<F1E;F%D97,_(@H*(SH@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-#`X"FUS9VED(")!;')E861Y(&5X:7-T
M<R(*;7-G<W1R(")*82!E>&ES=&5I>"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C(*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(D%C8^ES($E-4U`@86QT97)N871I=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S
M='(@(D-O;G1R87-E;GEA($E-4U`@86QT97)N871I=F$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#@X"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R
M;F%M92(*;7-G<W1R(").;VT@9"=U<W5A<FD@24U34"!A;'1E<FYA=&EU(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R
M;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%D<F7G82!E;&5C='+R;FEC
M82!A;'1E<FYA=&EV82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS
M9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(E!L86YT:6QL97,@
M86QT97)N871I=F5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X
M=#HB"FUS9W-T<B`B5&5X="!A;'1E<FYA=&EU.B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<*;7-G:60@(D%M97)I8V%N
M(%-A;6]A(@IM<V=S='(@(E-A;6]A($%M97)I8V%N82(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*
M;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T
M<B`B4R=H82!E<W!E8VEF:6-A="!U;B!V86QO<B!P<F]H:6)I="XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")!;B!U;FMN
M;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")3)VAA('!R;V1U[W0@
M=6X@97)R;W(@9&5S8V]N96=U="XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(D%N9&]R<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,`IM<V=I
M9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG=6EL;&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G
M<W1R(")397)V:61O<B!0<F]X>2!A;O)N:6TB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(E)E<W!O
M<W1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-0IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G3@<G1I9&$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y"FUS
M9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@:2!"
M87)B=61A(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S
M:&5L;"YP:'`Z,S4@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU.`HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A
M=&EO;B(*;7-G<W1R(")!<&QI8V%C:?,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B3&QI
M<W1A(&0G87!L:6-A8VEO;G,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,Y"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B3"=A
M<&QI8V%C:?,@Z7,@82!P=6YT+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T
M<B`B07!L:6-A<B!A(')E8W5R<V]S(&-O;7!A<G1I=',@9&5S8V5N9&5N=',N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G
M:60@(D%P<')O=F4B"FUS9W-T<B`B07!R;W9A<B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX,C8*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B36ED82!A<')O>&EM861A(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%B<FEL(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R(")!<N!B:6,@*%=I;F1O=W,M,3(U-B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S(&QI8B](;W)D92]-
M24U%+U9I97=E<B]T9WHN<&AP.C@Q"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4Y"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M(")-:61A(&1E(&PG87)X:74B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV,B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,`HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU.`IM<V=I9"`B07)C
M:&EV92!.86UE(@IM<V=S='(@(DYO;2!D92!L)V%R>&EU(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHY"B,L('!H<"UF;W)M
M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(E9O;&5U('-U<')I
M;6ER(&QA('-O;+=L:6-I='5D(&0G86QT82!A("5S/R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("<E
M<R<@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")6;VQE=2!E<V)O<G)A
M<B`G)7,G(&D@=&]T<R!E;',@<W5B9W)U<',_(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G96YT:6YA
M(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B
M07)MZ&YI82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!
M<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FD@*$%235-#24DM
M."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*
M;7-G<W1R(")!<G0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C,P"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES
M;&%N9"(*;7-G<W1R("));&QA(&1E(&PG07-C96YS:?,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")G
M<N!F:6,@05-#24DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")296=I\R!D96P@
M4&%C[69I8R!A<VG@=&EC(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q
M-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E9O;&5U(&-O;F9I<FUA
M8VGS(&%B86YS(&0G969E8W1U87(@;&5S(&]P97)A8VEO;G,@9&4@;6%N=&5N
M:6UE;G0_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3$*;7-G:60@(D%S
M<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")#;VQU;6YE<R!D)V%S<VEG;F%C
M:?,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<U"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B4R=H82!I
M;G1E;G1A="!S=7!R:6UI<B!U;B!G<G5P(&YO(&5X:7-T96YT+B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E,G:&$@
M:6YT96YT870@<W5P<FEM:7(@=6YA(&%U=&]R:71Z86-I\R!N;R!E>&ES=&5N
M="XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(E,G:&$@:6YT96YT870@961I=&%R('5N82!A=71O<FET>F%C:?,@;F\@97AI
M<W1E;G0N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S
M='(@(E,G:&$@:6YT96YT870@961I=&%R('5N(')E8W5R<R!C;VUP87)T:70@
M;F\@97AI<W1E;G0N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0*;7-G:60@(D%T=')I8G5T
M97,B"FUS9W-T<B`B071R:6)U=',B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@Q(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G;W-T(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1RX&QI82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`BP'5S=')I82(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@3F\@
M<R=H82!T<F]B870@;"=E>'1E;G-I\R!I;6%P(&YE8V5S<^!R:6$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U
M<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S
M+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!%;"!M;W1O<B!N;R!TZ2!L97,@8V%P
M86-I=&%T<R!N96-E<W/@<FEE<RXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U
M<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($YO(',G
M:&$@=')O8F%T(&PG97AT96YS:?,@24U!4"!N96-E<W/@<FEA+B(*"B,Z(&QI
M8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB
M075T:%]F='`Z($YO(',G:&$@=')O8F%T(&PG97AT96YS:?,@1E10(&YE8V5S
M<^!R:6$N($-A;"!C;VUP:6QA<B!02%`@86UB(&5L("(*(F-O;6UU=&%D;W(@
M+65N86)L92UF='`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*
M;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($YO(',G:&$@=')O8F%T(&PG
M97AT96YS:?,@24U!4"!N96-E<W/@<FEA+B(*"B,Z(&QI8B](;W)D92]!=71H
M+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!.;R!S
M)VAA('1R;V)A="!L)V5X=&5N<VGS(&MR8C4@;F5C97-SX')I82XB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HU.`IM<V=I9"`B075T:%]L9&%P.B!2
M97%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;&1A<#H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!,1$%0(&YE8V5S
M<^!R:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B
M(@HB075T:%]L9&%P.B!.;R!S)VAA('!O9W5T(&%F96=I<B!L)W5S=6%R:2`E
M<RX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L("(*(G-E<G9I9&]R.B(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z($YO(',G:&$@<&]G=70@<W5P<FEM:7(@;"=U<W5A
M<FD@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C@P"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S(@IM<V=S='(@(D%U=&]?;&1A<#H@3F\@<R=H82!P;V=U="!A8W1U
M86QI='IA<B!L)W5S=6%R:2`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L
M+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&]?;6-A;#H@3F\@<R=H82!T
M<F]B870@;"=E>'1E;G-I\R!-0T%,(&YE8V5S<^!R:6$N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?<VUB875T:#H@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I\R!334)!551(
M(&YE8V5S<^!R:6$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.#D*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R
M(")3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B4R=H82!P
M<F]D=>]T('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS+B`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")%;"!S
M97)V:61O<B!2041)55,@:&$@<F5B=71J870@;"=A=71E;G1I8V%C:?,N(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<V.`IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(E,G:&$@<')O9'7O="!U
M;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\R!A;6(@96P@<V5R=FED;W(@1E10
M+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")3)VAA('!R
M;V1U[W0@=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,@86UB(&5L('-E<G9I
M9&]R(%--0BXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C@S"FUS
M9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#86UP<R!D:7-P;VYI
M8FQE<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C,Q"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B86ED:F%N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X
M8W5S97,B"FUS9W-T<B`B0D]&2"!%>&-U<V5S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C
M:V=R;W5N9"(*;7-G<W1R(")&;VYS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R(")#;VQO<B!D96P@9F]N<R(*"B,Z(&QI8B](;W)D92]!=71H
M+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM
M<V=S='(@(D-O;G1R87-E;GEA($ME<F)E<F]S(&EN8V]R<F5C=&$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O
M<R!U<V5R;F%M92XB"FUS9W-T<B`B3F]M(&0G=7-U87)I($ME<F)E<F]S(&EN
M8V]R<F5C=&4N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT-0IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;65S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS.`IM
M<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM
M<V=S='(@(D+@;'1I8R`H25-/+3@X-3DM,3,I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-`IM<V=I9"`B0F%N9VQA9&5S
M:"(*;7-G<W1R(")"86YG;&$@1&5S:"(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,*;7-G:60@(D)A<F)A9&]S(@IM<V=S
M='(@(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C
M=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@
M96P@9&ER96-T;W)I(&1E(&=RX&9I8W,@8N!S:6-S("<E<R<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G
M:60@(D)A<V5L:6YE(@IM<V=S='(@(DSM;FEA(&)A<V4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(D)I96QO<G+Z<VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-0IM<V=I9"`B0F5L9VEU;2(*;7-G
M<W1R(")"Z&QG:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`*
M;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E;NUN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,0IM<V=I9"`B0F5R;75D82(*
M;7-G<W1R(")"97)M=61E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T
M86XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM
M<V=I9"`B0FER=&AD87DB"FUS9W-T<B`B06YI=F5R<V%R:2(*"B,Z(&QI8B](
M;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@
M9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&5L(&)L;V,@7"(E<UPB
M(&1E(&PG87!L:6-A8VGS(%PB)7-<(B`N(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R
M(")087+@;65T<F5S(&1E;"!B;&]C(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<'5S
M(&1E(&)L;V,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B3F5G<F5T82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,*;7-G:60@
M(D)O;&EV:6$B"FUS9W-T<B`B0F]L[79I82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.#D*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")-87)C
M861O<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B0V]N=&]R;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*
M;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(D=R=6EX(&1E;"!C
M;VYT;W)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")#;VYT;W)N
M<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S(*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0O)S
M;FEA(&D@2&5R8V5G;W9I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B06UB9/-S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT.`IM<V=I9"`B0F]T<W=A
M;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G
M<W1R("));F9E<FEO<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B
M26QL82!D92!";W5V970B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0T"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A<VEL
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3<*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R(")497)R:71O<FD@;V-EX&YI8R!D92!L)\UN9&EA(&)R:73@;FEC82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$87)U
M<W-A;&%M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8V,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")"=6EL9&EN9R!-3R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN
M(@IM<V=S='(@(D-O;G1R=6EN="!F:71X97)S($U/('!E<B!A;"!M\F1U;"`E
M<RXN+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0G5I;&1I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R(")#;VYS
M=')U:6YT("5S+BXN(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS-PIM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5L9^!R
M:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(DQL:7-T82!D92!P
M:6-S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-@IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,SD*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-S0*;7-G:60@(D--4R(*;7-G<W1R(")#
M35,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@IM<V=I
M9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G
M<W1R(")0=6YT<R!D92!D:7-T<FEB=6-I\R!D92!#4DPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G
M:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<&EE=&%T<R!D
M92!C96RW;&$N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34U"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G
M<W1R(").;R!S)VAA(&9I;F%L:71Z870@96P@<')O8^ES(&0G:6YI8VEA;&ET
M>F%C:?,@9&4@;&$@;65M\G)I82!C874B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4V(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-#8*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R:2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S@*;7-G:60@(D-A;&TB
M"FUS9W-T<B`B0V%L;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R.`IM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B0V%M
M8F]D:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8P"FUS9VED(")#86UE<F]O;B(*;7-G<W1R(")#86UE<G5N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(LES(&EM<&]S<VEB;&4@<F5I;FEC
M:6%R(&QA(&-O;G1R87-E;GEA(&%U=&]MX'1I8V%M96YT+"!P;W-A)W0@96X@
M8V]N=&%C=&4@(@HB86UB(&PG861M:6YI<W1R861O<B!D96P@<VES=&5M82XB
M"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C,U(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(LES(&EM<&]S
M<VEB;&4@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!)34%0.B`E<RXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q"FUS
M9VED(")#86YA9&$B"FUS9W-T<B`B0V%N863@(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,"!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$W"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ-R!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,30*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B0V%N8V5LMVQA<B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`B0V%N8V5LMVQA<B!L)VEN9F]R;64@9&4@<')O
M8FQE;65S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F\@97,@<&]T(&5S8F]R<F%R(&PG87)X:74@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R(").;R!E<R!P;W0@=')O8F%R('5N(&1I<F5C=&]R:2!T96UP
M;W)A;"XB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A
M;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB
M"FUS9W-T<B`B3F\@97,@<&]T(&-O;G1I;G5A<B!S96YS92!E;"!P87+@;65T
M<F4@)W1A<F=E=$9I;&4G+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R(").;R!E<R!P;W0@97-B;W)R87(@96P@9&ER96-T;W)I
M(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$Q,B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HU.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@
M(DYO(&5S('!O="!E<V)O<G)A<BP@8V]N=.D@9&5S8V5N9&5N=',@)60N("(*
M"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4Q,@IM<V=I9"`B(@HB
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM
M<V=S='(@(B(*(DYO(&5S('!O="!R96]R9&5N87(L(&5L(&YO;6)R92!D)V5N
M=')A9&5S('%U92!S)VAA;B!D92!R96]R9&5N87(@;F\@(@HB8V]I;F-I9&5I
M>"!A;6(@;&5S('%U92!H:2!H82!E;6UA9V%T>F5M861E<RXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B
M3F\@97,@<&]T(&%D<F7G87(@96P@;6ES<V%T9V4@86P@;F]M8G)E(&5S<&5C
M:69I8V%T+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C4*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B0V%P(%9E<F0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(DQL96=E;F1A(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N
M9"!,86)E;',B"FUS9W-T<B`B0V%T96=O<FEE<R!I(&5T:7%U971E<R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U"FUS
M9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("));&QE<R!#86EM86XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B
M0V5L;"!0:&]N92(*;7-G<W1R(")496SH9F]N(&WR8FEL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I
M9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!I971A=',@9&4@8V5L
MMVQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B1F%R8VEM96YT
M(&1E(&-E;+=L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P:65T871S(&1E(&QA(&-E;+=L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(D5S<&%I870@96YT<F4@8V5LMVQE<R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T
M<B`B5&5LZ&9O;B!M\F)I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#Z&QT:6,@
M*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")#
M96YT<F%R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HU-`IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(E)E</IB;&EC82!#96YT<F5A9G)I8V%N82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R(")%=7)O<&$@8V5N=')A;"`H25-/+3@X-3DM,BDB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF
M:6-A=&4@1&5T86EL<R(*;7-G<W1R(")$971A;&QS(&1E;"!C97)T:69I8V%T
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E1I='5L87(@9&5L(&-E<G1I9FEC
M870B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B
M0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L[71I<75E<R!D92!C
M97)T:69I8V%C:?,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C$*;7-G:60@(D-H860B"FUS9W-T<B`B5'AA9"(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@(D-H86YG92(*;7-G<W1R(")$97-F
MZ7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G
M<W1R("(B"B)#86YV:65U(&5L(&YO;2!I(&PG861R9>=A('%U92!S\VX@=FES
M:6)L97,@<75A;B!E<R!L;&5G96EX96X@;R!E<R!R97-P;VYE;B`B"B)E;',@
M=F]S=')E<R!M:7-S871G97,@9&4@8V]R<F5U(&5L96-T<O)N:6,N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")#:&%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#
M:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")697)I9FEC82!L)V5N;&QAYRXN+B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3,*
M(RP@9G5Z>GD*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I
M;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S
M='(@(B(*(DUA<F-A(&$@;&$@8V%S96QL82!L)V]P97)A8VGS(&\@;W!E<F%C
M:6]N<R!Q=64@9&5S:71G:7,@97AE8W5T87(@96X@87%U97-T82`B"B)O8V%S
M:?,N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU.0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B6&EL92(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$*;7-G:60@(D-H:6YA
M(@IM<V=S='(@(EAI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM
M<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(EAI
M;NAS('-I;7!L:69I8V%T("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM
M<V=S='(@(EAI;NAS('1R861I8VEO;F%L("A":6<U*2(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R
M9"(*;7-G<W1R(")4<FEA('5N82!C;VYT<F%S96YY82(*"B,Z(&QI8B](;W)D
M92]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M
M92(*;7-G<W1R(")4<FEA('5N(&YO;2!D)W5S=6%R:2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR.#@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA
M>2!D871E<SHB"FUS9W-T<B`B5')I82!C;VT@=F]L<R!V:7-U86QI='IA<B!L
M97,@9&%T97,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E1R:6$@=6X@=&EP
M=7,@9"=E<W1I;"!D92!L;&ES=&$@*'!E<B!A(&QL:7-T97,@;W)D96YA9&5S
M*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C8*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B26QL82!D92!#
M:')I<W1M87,B"@HC.B!L:6(O5D93+G!H<#HY,3,@;&EB+TYE="]335,N<&AP
M.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F
M("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@;&$@9&5F
M:6YI8VGS(&1E(&-L87-S92!D92`@)7,N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C@U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A;FEN9R!U<"!03R!F
M:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HX-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI;F<@
M=7`@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B0VQE87(B"FUS9W-T
M<B`B16QI;6EN87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S
M='(@(D5L:6UI;F$@;&5S(&5T:7%U971E<R!D92!-4T]F9FEC92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")%<V)O<G)A(&PG
M=7-U87)I.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R(")%<V)O<G)A(&PG=7-U
M87)I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G
M:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")%<V)O<G)A(&QE<R!D861E
M<R!D92!L)W5S=6%R:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$S"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(E,G
M86-L87)I<N`@8V%P(&%L('1A<F0N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K('1O($-O;G1I
M;G5E(@IM<V=S='(@(E!R96UI('!E<B!C;VYT:6YU87(B"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X,PIM<V=I9"`B0VQI8VMA=&5L
M;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('!E<B!(5%10(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B5&%N8V$@
M;&$@9FEN97-T<F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T,@IM<V=I
M9"`B0VQO=61S(@IM<V=S='(@(D[Z=F]L<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&]U9',@16%R;'DB
M"FUS9W-T<B`B3OIV;VQS(&$@<')I;65R82!H;W)A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L;W5D>2(*
M;7-G<W1R(")%;FYU=F]L870B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4R"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<R(*;7-G<W1R("));&QE<R!D92!#;V-O<R`H2V5E;&EN9RDB"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*;7-G:60@(D-O;&QA<'-E
M(%-I9&5B87(B"FUS9W-T<B`B4F5D=>]U(&QA(&)A<G)A(&QA=&5R86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R(")-87)G97,@
M<F5D=>]T<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-C(*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(D-O;/)M8FEA(@H*
M(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D-O;&]R(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0W,B!L:6(O2&]R9&4O
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDX"B,Z(&QI8B](;W)D92]";&]C:R]#
M;VQL96-T:6]N+G!H<#HR.3D@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E-E;&5C=&]R
M(&1E(&-O;&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X-#0*;7-G:60@
M(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?,@9&4@8V]L;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B0V]L=6UN97,Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T
M<B`B5.UT;VQS(&1E(&QE<R!C;VQU;6YE<R(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR.#0*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")#\FUI8W,B
M"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B3W)D<F4B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@
M(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B0V]N<V]L82(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"!O<'1I;VYS
M.B(*;7-G<W1R(")/<&-I;VYS(&1E(&QA(&-O;'5M;F$B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F1S.B(*;7-G
M<W1R(")/<F1R92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@IM
M<V=I9"`B0V]M;65N="(*;7-G<W1R(")#;VUE;G1A<FDB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B0V]M;6ET=&EN9SHB
M"FUS9W-T<B`B0V]N9&EC:6]N<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R(").;VT@8V]M
M^B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,P"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R97,B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N
M>2(*;7-G<W1R(")#;VUP86YY:6$B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY
M-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS9W-T<B`B
M17-C<FEU(&5L(&UI<W-A=&=E("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")/<F1I;F%D;W)S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#<*;7-G:60@(D-O;F1I=&EO
M;G,B"FUS9W-T<B`B0V]N9&EC:6]N<R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S
M='(@(D1I9F5RZ&YC:65S(&1E(&-O;F9I9W5R86-I\R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N(@IM<V=S='(@(DQA(&-O;F9I9W5R86-I\R!N;R!E<W3@(&%C
M='5A;&ET>F%D82XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(D-O;F9I
M9W5R82`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,S<*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B0V]N9FER;6%R
M(&QA(&-O;G1R87-E;GEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU-0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B0V]N9V\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S
M"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(@IM<V=S='(@(D-O;F=O+"!297#Z8FQI8V$@1&5M;V-RX'1I8V$@9&5L(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9"XB"FUS9W-T<B`B3F\@Z7,@<&]S<VEB;&4@<F5A;&ET>F%R(&QA
M(&-O;FYE>&GS+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I
M9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(").;R#I<R!P;W-S:6)L
M92!R96%L:71Z87(@;&$@8V]N;F5X:?,Z(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-S<Y"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(E,G:&$@<F5B=71J870@;&$@
M8V]N;F5X:?,@86P@<V5R=FED;W(@9&4@8VQA=7,@</IB;&EQ=65S+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<X,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")3)VAA(')E8G5T:F%T(&QA
M(&-O;FYE>&GS(&%L('-E<G9I9&]R(&1E(&-L875S('#Z8FQI<75E<RX@4F'S
M.B`E<R`H)7,I(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V,@IM<V=I9"`B0V]N
M;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3F\@Z7,@
M<&]S<VEB;&4@<F5A;&ET>F%R(&QA(&-O;FYE>&GS(&%L('-E<G9I9&]R($94
M4"XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS
M9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B16QS(&-O;G1A8W1E<R!S)VAA;B!A
M9F5G:70@8V]R<F5C=&%M96YT(&$@;&$@=&5V82!L;&EB<F5T82!D)V%D<F5C
M97,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C`@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O;G1E;G1S(&]F("<E<R<B"FUS9W-T<B`B0V]N=&EN9W5T(&1E("5S
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O
M;G1I;G5E(@IM<V=S='(@(D-O;G1I;G5A<B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R("));&QE<R!#;V]K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B1V%L971A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q
M"FUS9VED(")#;W!Y(@IM<V=S='(@(D-O<&EA<B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S
M(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@8V]P:6%R.B`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(D-O<&EA<B!S96QE8V-I\R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W!Y:6YG("5S('1O("5S(@IM<V=S='(@(EML[6YI82`E<R!D92`E
M<UTB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8S"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4W"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D-O<W1A(&0G279O<FDB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-38*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").;R!E
M<R!P;W0@>&EF<F%R(&5L(&UI<W-A=&=E(&%M8B!01U`N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`S,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYO(&5S('!O="!S:6=N
M87(@96P@;6ES<V%T9V4@86UB(%!'4"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(DYO(&5S('!O="!X:69R87(@96P@;6ES<V%T
M9V4@86UB(%,O34E-12XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(DYO(&5S('!O="!S:6=N87(@96P@;6ES<V%T9V4@86UB(%,O34E-
M12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B3F\@97,@<&]T(&%F96=I<B!E;"!C;VYT86-T92X@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,3`*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").;R!E<R!P;W0@8V]N
M;F5C=&%R(&%M8B!E;"!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<R(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYO(&5S('!O="!C;VUP<F]V
M87(@96P@<V%L9&\N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C
M="!T;R!S97)V97(@)R5S)R!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYO(',G
M:&$@<&]G=70@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B`G)7,G(&UI=&IA
M;N=A;G0@1E10.B`E<RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O<'D@)7,@
M=&\@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B`E<RXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8W)E87(@=6YA(&QL:7-T82!D
M92!D:7-T<FEB=6-I\RX@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O<GD@9F]R
M(&QO8V%L92`E<SHB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B!E;"!D
M:7)E8W1O<FD@)R5S)RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,3`U"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T
M82XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D97-X:69R87(@;&5S(&1A9&5S
M(%!'4"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4R,@IM<V=I
M9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DYO
M(',G:&$@<&]G=70@9&5S>&EF<F%R(&QE<R!D861E<R!3+TU)344N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@97-B;W)R87(@96P@8V]N=&%C=&4N("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&5S8F]R<F%R(&QA(&QL
M:7-T82!D92!D:7-T<FEB=6-I\RX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&5S8F]R<F%R(&QA('-E<?SH;F-I82!D)V%C='5A
M;&ET>F%C:?,@:6YS=&%LMVQA9&$@)R5S)RXB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HY,S@@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$*
M;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M
M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E=&5R;6EN
M87(@;"=A9')EYV$@96QE8W1R\FYI8V$@9&5L(&1E<W1I;F%T87)I+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#(*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@<F5C;VQL:7(@=&]T82!L82!L;&EB<F5T82!D)V%D
M<F5C97,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(')E8V]L;&ER('1O=&$@
M;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT-#4*;7-G:60@(D-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S
M='(@(DYO(',G:&$@<&]G=70@<F5C;VQL:7(@=&]T82!L82!L;&ES=&$@9&4@
M;&5S(&QL:7-T97,@9&4@9&ES=')I8G5C:?,N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%R<F5G87(@;"=E<W1R873H9VEA
M("<E<R<N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!C<F5A<B!E;"!D:7)E8W1O<FD@)R5S)RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HW,#@*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DYO(',G
M:&$@<&]G=70@;V)T96YI<B!U;F$@8VQA=2!P^F)L:6-A(&1E;"!S97)V:61O
M<B!D92!C;&%U<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T-"!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&]B<FER("5S+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!O8G)I<B`G)7,G('!E<B!E
M<V-R:75R92XB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B<FER
M(&5L(&WR9'5L(&1E('1A<W%U97,@9&4@;6%N=&5N:6UE;G0@)7,N(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&]B<FER
M(&5L(&1I<F5C=&]R:2`G)7,G+B(*"B,Z(&QI8B]61E,O3V)J96-T+G!H<#HR
M,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM
M<V=S='(@(DYO(',G:&$@<&]G=70@;&QE9VER("5S+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S
M970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@
M;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U
M="!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$@<&5R(&$@;"=U<W5A<FD@<V]L
MMVQI8VET870N($%L9W5N<R`B"B)D971A;&QS(&\@=&]T<R!N;R!S\VX@8V]R
M<F5C=&5S+B!4;W)N87(M:&\@82!I;G1E;G1A<B!O+"!P97(@82!MZ7,@(@HB
M:6YF;W)M86-I\RP@<&]S82=T(&5N(&-O;G1A8W1E(&%M8B!L)V%D;6EN:7-T
M<F%D;W(@9&5L('-I<W1E;6$N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<F5C=7!E<F%R(&QE
M<R!!0TPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<F5C=7!E<F%R
M(&QA(&QL:6)R971A(&0G861R96-E<RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B3F\@<R=H82!P;V=U="!R96-U<&5R87(@;&$@;&QI<W1A(&1E(&1I<W1R
M:6)U8VGS+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HT,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!R96-U<&5R87(@;&5S(&QL:7-T97,@9&4@9&ES=')I8G5C:?,N("5S(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!R96-U<&5R87(@;&5S('!O<W-I8FEL:71A=',@9&5L('-E<G9I9&]R(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T
M(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S)VAA('!O9W5T
M(')E<W1A=7)A<B!L82!C;VYF:6=U<F%C:?,N(@H*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&5L:6UI;F%R(&5L(&1I<F5C=&]R:2`G)7,G
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(DYO(',G:&$@<&]G=70@9&5S87(@;&$@8V]N9FEG=7)A8VGS("5S
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,PIM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@
M8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E<V%R('5N
M82!C;VYF:6=U<F%C:?,@9&4@<V5G=7)E=&%T+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DYO(',G
M:&$@<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I\R!D92!S96=U<F5T870Z
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`G)7,G+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E
M<V%R(&QA('-E<?SH;F-I82!D)V%C='5A;&ET>F%C:?,@:6YS=&%LMVQA9&$@
M96XZ("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O
M;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U
M="!D97-A<B!L82!C\G!I82!D92!S96=U<F5T870@9&4@;"=A<GAI=2!D92!C
M;VYF:6=U<F%C:?,@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B).;R!S)VAA('!O9W5T(&1E<V%R(&PG87)X:74@9&4@8V]N9FEG
M=7)A8VGS("5S+B!0;W1S('5T:6QI='IA<B!U;F$@9&4@;&5S("(*(F]P8VEO
M;G,@<&5R('1O<FYA<B!A(&1E<V%R(&5L(&-O9&D@96X@)7,@;R!BZ2!C;W!I
M87(@;6%N=6%L;65N="!E;"!C;V1I("(*(G-E9_QE;G0@96X@)7,N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(P"FUS9VED(")#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!C97)C87(@86P@<V5R=FED;W(@3$1!4"XB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R`G)7,G+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&1E<V5N;&QAYV%R("<E<R<N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@86-T=6%L:71Z87(@96P@8V]N=&%C=&4N("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").;R!S)VAA('!O9W5T(&%C='5A;&ET>F%R(&QA
M(&QL:7-T82!D92!D:7-T<FEB=6-I\RX@)7,B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<R(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&5S8W)I=7)E(&QA(&-O;F9I9W5R86-I\R!P97(@
M82`G)7,G.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-38*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(DYO(',G:&$@
M<&]G=70@;&]C86QI='IA<B!L82!B87)R82!L871E<F%L(&1E($UO>FEL;&$N
M($-O;7!R;W9A('%U92!L82!B87)R82`B"B)L871E<F%L(&5S=&EG=6D@;V)E
M<G1A+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD;B=T(&=I=F4@=7-E
M<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("<E
M<R<Z("5S(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@8V]N8V5D:7(@82!L
M)W5S=6%R:2`G)7,G(&5L<R!D<F5T<R!S96?\96YT<R!P97(@82!L82!C87)P
M971A("<E(@HB<R<Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C0*
M;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")497AT(&-O;7!T870B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R(")08>US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(V.`IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#=7)S;W,B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDW"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#$*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<F5A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<F5A<B!U;B!E;FQL8><B"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED
M(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-R96%R+6YE('5N(&1E(&YO
M=2(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I
M9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D-R96%R('-U8F-A<G!E
M=&5S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,V(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C$T"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E!E<FUI<V]S(&1E;"!C<F5A9&]R(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R,C@*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R
M(").^FUE<F\@9&4@;&$@=&%R9V5T82!D92!C<NAD:70B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P.0IM<V=I9"`B0W)O
M871I82(*;7-G<W1R(")#<F_@8VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV-`IM<V=I9"`B0W5B82(*;7-G<W1R(")#
M=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT
M(#0@4&AA<V5S(@IM<V=S='(@(C0@9F%S97,@86-T=6%L<R(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B
M0W5R<F5N="!4:6UE(@IM<V=S='(@(E1E;7!S(&%C='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM
M<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B16P@55),(&%C='5A;"#I
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R(")496UP<R!A8W1U86PB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8R"FUS9VED(")#=7)R96YT(&-O;F1I=&EO
M;CH@(@IM<V=S='(@(D-O;F1I8VGS(&%C='5A;#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT
M('-T>6QE(@IM<V=S='(@(D5S=&EL(&%C='5A;"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"B)0
M97)S;VYA;&ET>F5U(&QE<R!T87-Q=65S('%U92!S)VAA;B!E>&5C=71A<B!Q
M=6%N(',G:6YI8VEA(&QA('-E<W-I\R!A("5S+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B
M0W5T(@IM<V=S='(@(E)E=&%L;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*
M;7-G<W1R(")2971A;&QA<B!L82!S96QE8V-I\R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<*;7-G:60@(D-Y<')U<R(*
M;7-G<W1R(")8:7!R92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#:7+M;+=L:6,@*$M/
M23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER
M:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B0VER[6RW;&EC("A7:6YD
M;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@
M(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R(")#:7+M;+=L
M:6,O56-R8>]NZ',@*$M/23@M52DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C8X"FUS9VED(")#>F5C:"!297!U8FQI8R(*
M;7-G<W1R(")297#Z8FQI8V$@5'AE8V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#(S('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&QI8B](;W)D92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1IX')I86UE;G0B
M"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R
M;W=S97(B"FUS9W-T<B`B3F%V96=A9&]R(&1E($1A=&%4<F5E(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S.3<@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E
M(%)E8V5I=F5D(@IM<V=S='(@(E,G:&$@<F5B=70@;&$@9&%T82(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.#`U"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R(")396QE8V-I\R!D92!D871A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P-@IM<V=I9"`B1&%Y(@IM<V=S='(@(D1I82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B4W5P<FEM:7(@
M8V]L=6UN82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R(")$97-E;6)R92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G
M:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R(").;VUB<F5S(&1E8VEM86QS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(E)E9'7O=2!E;"!S
M86=N870B"@HC.B!L:6(O<')E9G,N<&AP.C$Q,2!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C$X-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")0<F5D971E<FUI
M;F%T(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B0V]L;W(@<')E
M9&5T97)M:6YA="(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z.3$*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E;G1I=&%T('!R961E
M=&5R;6EN861A(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$Y(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")$969A=6QT
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E-U<')I;6ER('!E<FWM<R(*"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,3DW"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT('!E<FUI<W-I;VYS(@IM<V=S='(@(E-U<')I;6ER('!E<FWM<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B
M"FUS9W-T<B`B1&5F:6YI8VEO;G,B"@HC.B!L86YG=&5S="YP:'`Z,C$@;&%N
M9W1E<W0N<&AP.C(S(&%D;6EN+V=R;W5P<RYP:'`Z-S(*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT-B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R(&QI
M8B](;W)D92]097)M<RYP:'`Z,CDU"B,Z(&QI8B](;W)D92]097)M<R]522YP
M:'`Z,S$U(&QI8B](;W)D92]097)M<R]522YP:'`Z,S,R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,PHC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDY"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"FUS
M9VED(")$96QE=&4B"FUS9W-T<B`B4W5P<FEM:7(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$X.2!A9&UI;B]G<F]U<',N<&AP.C(Q-PIM<V=I9"`B1&5L971E
M($=R;W5P(@IM<V=S='(@(E-U<')I;6ER(&=R=7`B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C8S(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<*;7-G
M:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E-U<')I;6ER('!E<FWM
M<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I
M9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")3=7!R:6UI
M<B!I(&)U:61A<B!M:7-S871G97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L
M;"(*;7-G<W1R(")3=7!R:6UI<B!C96RW;&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@8V]L=6UN(@IM<V=S='(@(E-U<')I;6ER(&-O;'5M;F$B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")3=7!R:6UI<B!L82!P;&%N=&EL
M;&$@86QT97)N871I=F$@97AI<W1E;G0B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4P(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E
M<R<B"FUS9W-T<B`B4W5P<FEM:7(@<&5R;6ES;W,@<&5R(&$@)R5S)R(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$W"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E-U<')I;6ER('!E<FUI<V]S
M('!E<B!A("<E<R<@:2!T;W1S(&5L<R!S=6)P97)M:7-O<S\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(E-U<')I;6ER(&9I;&$B"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4W5P<FEM:7(@;&$@
M:61E;G1I=&%T('-E;&5C8VEO;F%D82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")3=7!R:6UI<B!L82!C;VQU
M;6YA(&%C='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B1&5L971E('1H92!C=7)R96YT
M(')O=R(*;7-G<W1R(")3=7!R:6UI<B!L82!F:6QA(&%C='5A;"(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM
M<V=S='(@(E-U<')I;6ER('!E<FUI<V]S('!E<B!A("<E<R<@:2!T;W1S(&5L
M<R!S=6)P97)M:7-O<S\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R(")3)VAA('-U<')I;6ET(&QA
M('-E<?SH;F-I82!D)V%C='5A;&ET>F%C:?,@:6YS=&%LMVQA9&$@)R5S)RXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,"!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38R(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.30*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B
M2&]R82!D92!L;&EU<F%M96YT(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R(")$
M:6YA;6%R8V$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,3`@<V5R=FEC
M97,O<')O8FQE;2YP:'`Z,3$T('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-`IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B1&5S8W)I=FEU
M(&5L('!R;V)L96UA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDS."!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP8VGS(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QL<R`H=&%M8ND@86P@9FET>&5R
M(&1E(')E9VES=')E(&1E($AO<F1E*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C$Y
M.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B16QS(&1E=&%L;',@:&%N(&5S=&%T(')E
M9VES=')A=',@<&5R(&$@;"=A9&UI;FES=')A9&]R+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S
M='(@(D1E<V5N=F]L=7!A;65N="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$U"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4'5N="!D92!R;W-A9&$B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")0=6YT(&1E(')O<V%D82!D92!L
M82!D87)R97)A(&AO<F$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Q.0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B4'5N="!D92!R
M;W-A9&$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S
M='(@(D0G97-Q=65R<F$@82!D<F5T82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H
M="!T;R!L969T(@IM<V=S='(@(D1E(&1R971A(&$@97-Q=65R<F$B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S
M='(@(D1I<F5C=&]R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-38*
M;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B5F]L<R!V
M:7-U86QI='IA<BUH;R!E;B!F;W)M870@9&4@,C0@:&]R97,_(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B3W!C:6]N<R!D92!V:7-U86QI='IA8VGS(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HX,PIM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")-;W-T<F$@;&$@<')E=FES:?,@*%1!1BDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS
M9W-T<B`B1F]R;6%T(&1E('9I<W5A;&ET>F%C:?,B"@HC.B!L:6(O2&]R9&4O
M34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N(@IM<V=S='(@(DYO=&EF:6-A8VGS(&1E(')E8V5P8VGS(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,`IM<V=I9"`B
M1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C0V(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$U"FUS9VED
M(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYO(&AO('-U<')I;6EU(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED(")$;R!N;W0@9&ER
M96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").;R!A8V-E
M9&EU(&1I<F5C=&%M96YT(&$@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3D*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@HB3&$@<')I;65R82!F:6QA(&-O;G3I(&5L<R!N;VUS(&1E;',@8V%M
M<',_($5N(&-A<R!A9FER;6%T:74L(&%C=&EV82!A<75E<W1A("(*(F-A<V5L
M;&$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW,@IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<S"FUS9VED
M(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($1O;6EN
M:6-A;F$B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,W"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R(")$97-C87)R96=A<B(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B1&5S8V%R<F5G87(@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38U"FUS9VED(")$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R(")$
M97-C87)R96=A<B!L82!C;VYF:6=U<F%C:?,@9V5N97)A9&$@8V]M('5N82!S
M97'\Z&YC:6$@4$A0+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`W"FUS
M9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("),;&ES=&$@9&5S<&QE9V%B
M;&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S
M(@IM<V=S='(@(D1R;V=U97,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,#(*;7-G:60@(D4M36%I;"(*;7-G<W1R(")#;W)R974@96QE8W1R\FYI
M8R(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S4*;7-G:60@(D5C=6%D
M;W(B"FUS9W-T<B`B17%U861O<B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z
M,CDT('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,U('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-CD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,0HC.B!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM<V=S
M='(@(D5D:71A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(D5D:71A(&)L;V,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X."!A
M9&UI;B]G<F]U<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R
M(")%9&ET82!G<G5P(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@V"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B161I=&$@<&5R;>US(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R
M(")%9&ET82!P97)M:7-O<R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H
M<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F
M;W(@)7,B"FUS9W-T<B`B161I=&$@<&5R;6ES;W,@9&4@)7,B"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R
M.B(*;7-G<W1R(")%9&ET82!O<&-I;VYS(&1E.B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B161I=&$@<&5R;6ES;W,@9&4@
M)7,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`B161I=&$@<&5R;6ES
M;W,@9&4@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@
M(D5D=6-A=&EO;B(*;7-G<W1R(")%9'5C86-I\R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<*;7-G:60@(D5G>7!T(@IM
M<V=S='(@(D5G:7!T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B
M16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T
M<B`B16QE;65N="XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")1=6%D<F%T[2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#8Y(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C(T"FUS9VED(")%;6%I;"(*;7-G<W1R(")#;W)R
M974@96QE8W1R\FYI8R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-38U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#`*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R(")!9')EYV$@96QE8W1R\FYI8V$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(DQE<R!A9')E8V5S(&5L96-T<O)N:7%U97,@
M:&%N(&1E(&-O:6YC:61I<BXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DX
M.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B0V]R
M<F5U(&5L96-T<O)N:6,@86UB(&-O;F9I<FUA8VGS(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`IM<V=I9"`B16UO=&EC;VYS
M(@IM<V=S='(@(D5M;W1I8V]N97,B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T
M<B`B36ES<V%T9V4@96X@8FQA;F,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,3(X"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(E)E<W5L
M=&%T(&5N(&)L86YC+B(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP
M.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(D)U:61A
M<B!E;',@=&5R;65S(&1E(&-E<F-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S,@IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B2&%B:6QI=&%R
M(&QA(&EN<V5R8VGS(&1E(&EM871G97,@9&4@;&5S(&=A;&5R:65S(&1E(&9O
M=&]S(&5N(&5L('1E>'0_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M-PIM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS
M9W-T<B`B2&%B:6QI=&%R(&5L(&UE;OH@9&4@8V]N=&5X="!C;&EC86YT(&5N
M(&5L(&)O=/,@9')E=#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y-B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@P.0IM<V=I9"`B16YD('EE87(B"FUS9W-T
M<B`B06YY(&1E(&9I;F%L:71Z86-I\R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(D%M<&QI87(@;"=E9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T
M:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E
M<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@
M;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB26YT<F]D=>]U('5N82!P<F5G
M=6YT82!D92!S96=U<F5T870@<75E('-E('5S(&9O<FUU;&%RX"!S:2!U<R!C
M86P@<F5I;FEC:6%R("(*(FQA(&-O;G1R87-E;GEA+"!P97(@97AE;7!L92`G
M8V]M(&5S(&1I=2!E;"!V;W-T<F4@86YI;6%L(&1E(&-O;7!A;GEI83\G.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM
M<V=S='(@(DEN=')O9'7O=2!A<77M(&5L(%523"!D92!L82!I;6%T9V4B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E
M9"!C:&%N9V5D+"`E9"!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D*;7-G:60@(D5Q=6%T
M;W)I86P@1W5I;F5A(@IM<V=S='(@(D=U:6YE82!%<75A=&]R:6%L(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.0IM<V=I
M9"`B17)I=')E82(*;7-G<W1R(")%<FET<F5A(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B17)R;W(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-`IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+B(*;7-G<W1R(")(:2!H82!H86=U="!U;B!E<G)O<B!A;6(@96P@;6ES<V%T
M9V4@96QE8W1R\FYI8RXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('=R:71I;F<@)R5S)RXB"FUS9W-T<B`B2&D@:&$@:&%G
M=70@=6X@97)R;W(@96X@97-C<FEU<F4@)R5S)RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU,C(@<&\O=')A;G-L
M871I;VXN<&AP.C$S-S<*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T,S@@<&\O
M=')A;G-L871I;VXN<&AP.C$U,#$*(RP@9G5Z>GD*;7-G:60@(D5R<F]R.B`B
M"FUS9W-T<B`B17)R;W(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<V"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=/)N
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R(")%=&GR<&EA(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B
MR'1N:6,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,CD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B0V%D
M82`Q-2!M:6YU=',B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS
M9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B0V%D82`R(&UI;G5T<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C8@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")#
M861A(#,P('-E9V]N<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B179E<GD@-2!M:6YU
M=&5S(@IM<V=S='(@(D-A9&$@-2!M:6YU=',B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")#
M861A(&EN:6-I(&1E('-E<W-I\R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,S`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")#861A(&UI
M=&IA(&AO<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(W(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G
M<W1R(")#861A(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C@*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<G,@
M9"=E>&5M<&QE.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C
M;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B
M17AE8W5T92(*;7-G<W1R(")%>&5C=71A(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C(Y.2!P;R]T<F%N<VQA=&EO;BYP:'`Z,S(P('!O+W1R86YS;&%T:6]N
M+G!H<#HS-C(*(SH@<&\O=')A;G-L871I;VXN<&AP.C0T,2!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-30Q('!O+W1R86YS;&%T:6]N+G!H<#HV,#$*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C<P,B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S,W('!O+W1R
M86YS;&%T:6]N+G!H<#HW.3@*(SH@<&\O=')A;G-L871I;VXN<&AP.C@W-2!P
M;R]T<F%N<VQA=&EO;BYP:'`Z.3DT('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$V
M"B,L(&9U>GIY"FUS9VED(")%>&5C=71I;F<Z(@IM<V=S='(@(D5X96-U=&%R
M(@H*(SH@;&%N9W1E<W0R+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B17AI="(*
M;7-G<W1R(")%9&ET82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP
M.C,Y-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5X<&%N9&5I>"(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3
M:61E8F%R(@IM<V=S='(@(D5X<&%N9&ER(&QA(&)A<G)A(&QA=&5R86PB"@HC
M.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C
M=&5D("<I)R(*;7-G<W1R(")3)V5S<&5R879A("<I)R(*"B,Z(&QI8B](;W)D
M92]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")3)V5S<&5R879A
M('5N('-O;"!M;W0@;R!U;B!T97)M92!D92!C97)C82!C:71A="(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,0IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(D1A=&$@9&4@=F5N8VEM96YT(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(D5X<&]N96YT(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%>'1R86-T:6YG(&9R;VT@)7,N+BX@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O;&]R(&1E('!R
M:6UE<B!P;&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"FUS9VED
M(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D/@<G)E9V$@9&4@;&$@
M8V]N9FEG=7)A8VGS(&1E;"!&5%`B"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L
M+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("+)<R!I;7!O<W-I8FQE(')E8W5P97)A<B!L97,@<')E9F5R
MZ&YC:65S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$P,`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(LES(&EM<&]S<VEB;&4@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!,1$%0
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(LES(&EM<&]S
M<VEB;&4@8V]N;F5C=&%R(&%M8B!E;"!S97)V:61O<B!334(N(@H*(SH@;&EB
M+U9&4R]F='`N<&AP.C8P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`BR7,@:6UP;W-S:6)L92!C
M;W!I87(@9&4@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*
M;7-G<W1R("+)<R!I;7!O<W-I8FQE(&-O<&EA<B!A(%PB)7-<(BXB"@HC.B!L
M:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R
M96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("+)<R!I;7!O<W-I
M8FQE(&-R96%R('5N82!N;W9A(&-O;FYE>&GS(%-!4TPN(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C8T,2!L:6(O5D93+W-M8BYP:'`Z-#DY"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B
MR7,@:6UP;W-S:6)L92!T<F%N<V9E<FER(&$@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(')E=')I979E.B`E<R(*;7-G<W1R("+)<R!I;7!O<W-I8FQE(')E8W5P97)A
M<CH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-@IM<V=I9"`B1F%I<B(*;7-G<W1R(")#;&%R(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-`IM<V=I9"`B1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(DEL;&5S($9A;&ML86YD
M("A-86QV:6YE<RDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(DEL
M;&5S($;H<F]E(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&
M871A;"!%<G)O<CHB"FUS9W-T<B`B17)R;W(@:7)R96-U<&5R86)L92`B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-S4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R(")&96)R97(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q.`IM<V=I9"`B1F5E;',@3&EK92(*;7-G
M<W1R(")392!S96YT(&-O;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,C,*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")392!S96YT
M(&-O;3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-PIM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B4&]Q=65S('!L=6=E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X
M"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(E!O8W,@>.!F96-S
M(&1E(&YE=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30T"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`B36%T<FEU(&1E;"!C86UP(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,PIM<V=I9"`B
M1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C0@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")296-O
M;7!T92!D)V%R>&EU<SH@87)X:74@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O>FEP+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H
M<#HX,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R
M(")296-O;7!T92!D)V%R>&EU<SH@)7,@87)X:75S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T-`IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(D=E<W1O<B!D)V%R>&EU<R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`B3F]M(&1E(&PG87)X:74B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDY,PIM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`B4V5L96-C:?,@9"=A<GAI=7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30Y,0IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B0^!R<F5G82!D92!L
M)V%R>&EU(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@U,PIM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(DYO(.ES('!E
M<FWH<R!P96YJ87(@87)X:75S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C@W"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R97,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@R"FUS9VED
M(")&:6YL86YD(@IM<V=S='(@(D9I;FS@;F1I82(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S$*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B4')I;65R
M82!M96ET870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(E!R
M:6UE<B!Q=6%R="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")28?,@9FEX82,C
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`IM
M<V=I9"`B1FQI<"(*;7-G<W1R("));G9E<G1I=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(D-O;6$@9FQO=&%N="(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&;V<B"FUS9W-T<B`B
M0F]I<F$B"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,38P(&QI8B]61E,O;75S<6PN
M<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0B"FUS9W-T<B`B3&$@8V%R<&5T82`E<R!N;R!E>&ES=&5I>"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*
M;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B0V]L;W(@9&4@;&$@9F]N="(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G
M<W1R(")-96YJ87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T
M:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E!E<B!A;',@;F%V
M96=A9&]R<R!Q=64@;F\@861M971E;B!L97,@:6UA=&=E<R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S,R"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G
M<W1R(")0<F5V:7-I\R`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW.`IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)0<F5V:7-I\R!P97(@86QS(&1I
M97,@*'1I;F=U974@<')E<V5N="!Q=64@;&$@<')E=FES:?,@9F%C:6QI=&%D
M82!C;VUP<NAN(&5L("(*(F1I82!I(&QA(&YI=#H@=6X@;F]M8G)E(&5L979A
M="!P;V1R:6$@=&5N:7(@8V]M(&$@<F5S=6QT870@=6X@8FQO8R!A;7!L92XB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")&;W)G
M;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B2&5U(&]B;&ED870@;&$@8V]N
M=')A<V5N>6$_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM
M<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L87)I<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")$:71A
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE
M('1Y<&4B"FUS9W-T<B`B5&EP=7,@9&4@9&ET97,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D1I=&5S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&;W)T=6YE
M<R`R(@IM<V=S='(@(D1I=&5S(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,SDQ"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B1O)R=6US(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-PIM<V=I9"`B1F]R=V%R9',B
M"FUS9W-T<B`B4F5E;G9I86UE;G1S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9O=6YD(&%P<&QI
M8V%T:6]N<SH@)7,B"FUS9W-T<B`B07!L:6-A8VGS(&YO(';@;&ED82XB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U,@HC+"!F=7IZ>0IM<V=I9"`B1F]U
M;F0@9&ER96-T;W)I97,Z(@IM<V=S='(@(DYO(.ES('5N(&1I<F5C=&]R:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*
M;7-G:60@(D9R(@IM<V=S='(@(D1V+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*
M;7-G<W1R(")-87)C<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.#<*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%NYV$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;N=A(&UE=')O<&]L:71A;F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ
M"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D=U86EA;F$@1G)A;F-E
M<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X-`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")0;VQI;NAS
M:6$@1G)A;F-E<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C(*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R(")497)R:71O<FES($9R86YC97-O<R!D96P@4W5D(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@
M(D9R;VTB"FUS9W-T<B`B1&5S(&1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T,`IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D1E<R!D
M96PB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I
M9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEP8VGS(&-O;7!L
M971A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@R(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ.#$*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("),;'5N82!P;&5N
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,SD*;7-G
M:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VT@8V]M<&QE="(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(D9U>GIY(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#@*;7-G
M:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'
M86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("),82!G86QE<FEA
M(&1E(&QA('%U86P@<R=E>'1R974@;&$@:6UA=&=E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS
M9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-@IM<V=I9"`B1V%M8FEA
M(@IM<V=S='(@(D?@;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")%<R!G96YE<F$@;&$@8V]N9FEG=7)A8VGS("5S(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C$P"FUS9VED
M(")'96YE<F%T960@0V]D92(*;7-G<W1R(")#;V1I(&=E;F5R870B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-#<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=E
M;F5R871I;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,`IM
M<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'9?)R9VEA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R(")!;&5M86YY82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,S<Q"B,L(&9U>GIY"FUS9VED(")'971O<'0@17)R;W(Z("(*;7-G<W1R(")%
M<G)O<B!I<G)E8W5P97)A8FQE("(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3,*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H
M86YA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.
M86UE(@IM<V=S='(@(DYO;2!D92!P:6QA(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(D%N87(@82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@
M(D?V9&5L(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R(")#97)C82!A;"!';V]G;&4B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"FUS9VED(")'
M<F%Y<V-A;&4B"FUS9W-T<B`B17-C86QA(&1E(&=R:7-O<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`P"FUS9VED(")'
M<F5E8V4B"FUS9W-T<B`B1W+H8VEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<F5C
M("A)4T\M.#@U.2TW*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F5N
M;.!N9&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HX.0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F%N861A(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D=E<W1I\R!D92!G<G5P<R(*"B,Z(&QI8B](;W)D92]'
M<F]U<"YP:'`Z-3@*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(D5L<R!N;VUS(&1E(&=R=7`@;F\@97,@<&]D96X@9&5I
M>&%R(&5N(&)L86YC(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C`Q(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,C<W"B,L(&9U>GIY"FUS9VED(")'<F]U
M<"!P97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-O<R!D96QS('9I<VET86YT
M<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W-B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(U,"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S
M='(@(D=R=7!S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY.`IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D86QU
M<&4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P,PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDX"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(*;7-G:60@(D=U871E
M;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(W(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,C`U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G
M:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<V]S(&1E;',@
M=FES:71A;G1S(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3(X(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,C`V"B,L(&9U>GIY"FUS9VED(")'=65S="!P
M97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-O<R!D96QS('9I<VET86YT<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#@*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R("),;&EB<F4@9&4@=FES:71A;G1S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDY"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-PIM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$P-`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*
M;7-G<W1R(")'=6EN96$@0FES<V%U(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B1W5Y86YA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDV,`IM<V=I9"`B
M2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M(@IM<V=S='(@(DA434Q!<F5A(&YO('!E<FUE="!S=7!R:6UI<B!L82!D87)R
M97)A(&-E;+=L82!D92!L82!F:6QA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@;F\@<&5R;65T('-U<')I;6ER
M(&QA(&1A<G)E<F$@8V]L=6UN82!D92!L82!T875L82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A(&YO('!E<FUE="!S
M=7!R:6UI<B!L82!D87)R97)A(&9I;&$@9&4@;&$@=&%U;&$N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@<R=H82!T<F]B870@;"=A
M=71E;G1I8V%C:?,@2%144"XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA
M:73M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")(
M87-H+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FES;64@9&4@:&%S:"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED
M(")(87IE(@IM<V=S='(@(D-A;&ET:F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.3$Y(&QI8B](;W)D92]&;W)M+G!H<#HR.3,P"FUS9VED(")(96%D97(B
M"FUS9W-T<B`B0V%PYV%L97)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B26QL82!(96%R9"!I(&EL;&5S
M($UC1&]N86QD(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@
M(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R974@*$E33RTX
M.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B06SG861A
M(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$W."!L:6(O2&]R9&4O2&5L<"YP
M:'`Z,3@U('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(D%J=61A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B06IU9&$@<&5R
M('5T:6QI='IA<B!L)V5D:71O<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,S<V"FUS9VED(")(96QP97(B"FUS9W-T<B`B07!L:6-A8VGS(&0G86IU9&$B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.34*;7-G:60@(B(*(DAE;'!E<B!A
M<'!L:6-A=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N
M<R!F;W(@=&AE($AO<F1E7&XB"B)F<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A
M=&EO;G,N7&XB"B)&;W(@86X@:6YT<F]D=6-T:6]N(')E860@=&AE(&9I;&4@
M4D5!1$U%(&EN('1H:7,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B
M2&5M:7-F97)I(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B07%U97-T(.ES
M(&PG:6YI8VD@9&5L(&9I='AE<CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B2&EG:"(*;7-G<W1R(")!;'0B
M"@HC.B!L:6(O2&]R9&4O2&ES=&]R>2YP:'`Z,S(Q"B,L(&9U>GIY"FUS9VED
M(")(:7-T;W)Y(&5N=')Y(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S
M='(@(D5L<R!N;VUS(&1E(&=R=7`@;F\@97,@<&]D96X@9&5I>&%R(&5N(&)L
M86YC(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C0@
M=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV"FUS9VED(")(;U]M92(*;7-G
M<W1R("));FEC:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#,*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I(@IM<V=S='(@(FQA(%-A;G1A(%-E=2`H0VEU=&%T($5S=&%T(&1E
M;"!6871I8^`I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#(V"FUS9VED(")(;VUE
M(@IM<V=S='(@(DEN:6-I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')EYV$@<&%R=&EC
M=6QA<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP
M"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;.AF;VX@<&%R=&EC=6QA
M<B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P.`IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R97,B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8*;7-G
M:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-C,*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO
M<F1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S,CD*;7-G:60@(DAO<F1E
M('1R86YS;&%T:6]N(&=E;F5R871O<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S
M86=E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!3)VAA;B!T<F]B870@9&%D
M97,@6$U,("5S(&YO(';@;&ED97,@96X@96P@;6ES<V%T9V4@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C(W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L86(Z($YO(&AI(&AA(&-A<"!M:7-S
M871G92!Q=64@97,@8V]R<F5S<&]N9W5I(&%M8B!L)V]B:F5C=&4@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F\@<R=H82!T<F]B
M870@8V%P(&]B:F5C=&4@9&5L('1I<'5S("5S(&5N(&5L(&UI<W-A=&=E("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C`X"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S(%PB)7-<(B!H82!E<W1A
M="!E>'1R970@8V]R<F5C=&%M96YT(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY('-Y;F-H<F]N:7-E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z("5S(%PB)7-<(B!H82!E<W1A="!E>'1R970@8V]R
M<F5C=&%M96YT(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@
M(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S
M('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!%;"!M;W1O<B!D)VEN=&5G<F%C:?,@;F5C97-S:71A(&PG97AT96YS
M:?,@4$A0("=D;VUX;6PG(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($YO(',G:&$@<&]G=70@8W)E87(@=6X@;F]U(&%R8G)E(%A-
M3"!P97(@82!L)V]B:F5C=&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$R,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA
M8CH@3F\@<R=H82!P;V=U="!E>'1R975R92`E<R!<(B5S7"(Z("5S(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!.
M;R!S)VAA('!O9W5T(')E8W5P97)A<B!L)VED96YT:69I8V%D;W(@34E-12!P
M97(@82!L82!P87)T(&1E;"`B"B)T:7!U<R`E<R(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z,3$U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@<VEN8W)O;FET>F%R("5S
M7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(X,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YO(',G
M:&$@<&]G=70@<VEN8W)O;FET>F%R(&QE<R!Q=6]T97,Z("5S(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!%<W!A:2!D:7-P;VYI8FQE(&1E<V-O;F5G=70@7"(E<UPB(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(E)E9VQA(&AO<FET>F]N
M=&%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(D9A<F-I
M;65N="!H;W)I='IO;G1A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@
M(DAO<FET>F]N=&%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B0V]M(&AE=2!A<G)I
M8F%T(&9I;G,@87%U[3\@*$9E=2UN;W,M:&\@<V%B97(A*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G
M:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(E%U86YT97,@8V]L=6UN97,@=F]L974@<F5F;VYD<F4_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C@*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")1=6%N
M=',@8V%M<',@*&-O;'5M;F5S*2!H:2!H83\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@
M;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")1
M=6%N=&5S(&9I;&5S('9O;&5U(')E9F]N9')E/R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C(X"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")(=6UI=&%T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B
M2'5M:61I='DZ("(*;7-G<W1R(")(=6UI=&%T.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R
M:7-T97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3$*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B2&]N9W)I82(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BR7,@:6UP;W-S:6)L
M92!C<F5A<B!L82!B^G-T:6$@24U!4#H@)7,B"@HC.B!L:6(O2&]R9&4O075T
M:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S(@IM<V=S='(@(LES(&EM<&]S<VEB;&4@<W5P<FEM:7(@;&$@
M8OIS=&EA($E-05`Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP
M.C$W.2!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("+)<R!I;7!O<W-I8FQE(&-R96%R('5N(&5S<&%I(&1I
M<W!O;FEB;&4@<&5R(&$@;&$@8OIS=&EA($E-05`Z("5S(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B
M061R9>=A($E0(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z-S<*
M;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=A
M9')EYV$@25`@;F\@97-TX"!D:7-P;VYI8FQE+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H
M:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("),)V%D<F7G82!)4"!N
M;R!E<R!T<F]B82!E;B!E;"!B;&]C($-)1%(@<&5R;>AS+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED("))4"!L;V-K
M9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(E9I;VQA8VGS(&1E;"!B;&]Q=65I
M9R!)4"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G
M<W1R("));G-E<FEU('5N82!F:6QA(&1A;75N="(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,`IM<V=I9"`B26-E;&%N
M9"(*;7-G<W1R("))<VS@;F1I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B3F]MZ7,@:6-O;F5S
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("))8V]N97,@9&4@)7,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"FUS9VED("))8V]N<R!W:71H
M('1E>'0B"FUS9W-T<B`B26-O;F5S(&%M8B!T97AT(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$X,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G
M<W1R(").;VT@9"=I9&5N=&ET870Z(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP.C4X.`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N(@IM<V=S='(@(E-I(&YO(&5S('9I<W5A;&ET>F$@8V]R<F5C
M=&%M96YT+"!O8G)I=2`E<R!E;B!U;F$@;F]V82!F:6YE<W1R82XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0U"FUS9VED("(B"B))9B!Y;W4@9&]N
M)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U
M(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(E-I(&YO('9I<W5A;&ET>F5U
M(&-A<"!I8V]N82!M:71J86[G86YT(&PG26YT97)N970@17AP;&]R97(L(.ES
M('!O<W-I8FQE('%U92`B"B)HX&=I=2!D)V%C=&EV87(@87%U97-T('%U861R
M92!P97(@9&5S86-T:79A<B!L82!T<F%N<W!A<NAN8VEA(&1E(%!.1RXB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB4VD@=F5I974@87%U
M97-T(&UI<W-A=&=E(&5N(&QL;V,@9&4@;&$@:6UA=&=E+"!E;"!V;W-T<F4@
M;F%V96=A9&]R(&YO('!O="`B"B)M;W-T<F%R(&QA(&EM871G92!Q=64@=F]L
M974@<&5N:F%R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB
M"FUS9W-T<B`B5FES=6%L:71Z86-I\R!P<NAV:6$@9&4@;&$@:6UA=&=E.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")54DP@9&4@;&$@:6UA
M=&=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(E52
M3"!D92!L82!I;6%T9V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDB"FUS9W-T<B`B26UA=&=E(&1E(&QA(&=A;&5R:6$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B26UA
M=&=E(&1E(&QA(&=A;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")#X')R96=A(&1E(&QA
M(&EM871G92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("))
M;6%G97,B"FUS9W-T<B`B26UA=&=E<R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3
M=&5P("5D(@IM<V=S='(@(DEM<&]R=&%C:?,L('!A<R`E9"(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#86UP(&EM<&]R=&%T.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S,*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M<',@:6UP;W)T871S.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B26YS97)I
M=2!U;F$@9FEL82!A('-O=&$B"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP
M+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB
M"FUS9W-T<B`B16P@8V]D:2!D92!L)V%C8VGS('%U92!S)VAA(&9A8VEL:71A
M="#I<R!I;F-O<G)E8W1E+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S$*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(DYO;2!D)W5S=6%R:2!I+V\@8V]N=')A<V5N
M>65S(&EN8V]R<F5C=&5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(E,G:&$@9F%C:6QI=&%T('5N(&YO;2!D)W5S=6%R:2!O('5N82!A9')E
MYV$@86QT97)N871I=F$@:6YC;W)R96-T97,N(%1O<FYE=2TB"B)H;R!A(&EN
M=&5N=&%R(&\@<&]S974M=F]S(&5N(&-O;G1A8W1E(&%M8B!L)V%D;6EN:7-T
M<F%D;W(@<&5R(&$@;>ES(&%J=61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N
M="(*;7-G<W1R(")!=6=M96YT87(@96P@<V%G;F%T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I
M82(*;7-G<W1R("+-;F1I82(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$T
M,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I
M9'5A;"!5<V5R<R(*;7-G<W1R(")5<W5A<FES(&EN9&EV:61U86QS(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R"FUS
M9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;V[H<VEA(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS
M9W-T<B`B26YF;W)M86-I\R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-#0*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:?,B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@R"B,L('!H<"UF;W)M870*;7-G
M:60@(DEN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@(@IM<V=S='(@(DEN:6-I
M86QI='IA;G0@;?)D=6P@)7,N+BX@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@
M0U]O;'5M;B!!9G1E<B(*;7-G<W1R("));G-E<F5I>"!U;F$@8V]L=6UN82!A
M('-O=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R
M("));G-E<F5I>"!U;F$@:6UA=&=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM
M<V=S='(@(DEN<V5R96EX('5N82!T875L82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@
M3&EN:R(*;7-G<W1R("));G-E<F5I>"!E;FQL8><@=V5B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS
M9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B26YS97)E:7@@
M;&$@8V]L=6UN82!D86UU;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE
M=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R
M96EX('5N82!N;W9A(&-O;'5M;F$@82!S;W1A(&1E(&PG86-T=6%L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8T"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B26YS97)E:7@@=6YA(&YO=F$@8V]L=6UN82!A
M('-O8G)E(&1E(&PG86-T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<F5I
M>"!U;F$@;F]V82!F:6QA(&$@<V]T82!D92!L)V%C='5A;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM
M<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(DEN<V5R96EX('5N82!N;W9A(&9I;&$@82!S;V)R92!D92!L
M)V%C='5A;"`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A
M9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R96EX('5N('!A
M<N!G<F%F(&$@<V]T82!D96P@;F]D92!A8W1U86PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@
M(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*
M;7-G<W1R("));G-E<F5I>"!U;B!P87+@9W)A9B!A('-O8G)E(&1E;"!N;V1E
M(&%C='5A;"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("))
M;G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(DEN<V5R96EX(&PG
M86QT<F$@<&QA;G1I;&QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*(DEN
M<V5R96EX('5N82!A9')EYV$@9&4@8V]R<F5U('!E<B!R96)R92!L82!N;W9A
M(&-O;G1R87-E;GEA26YS97)I=2!U;F$@(@HB861R9>=A(&5L96-T<O)N:6-A
M(&$@;&$@<75A;"!P;V1E=2!R96)R92!L82!N;W9A(&-O;G1R87-E;GEA.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(DEN<V5R
M96EX('5N82!C96RW;&$@82!S;W1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E
M;&P@8F5F;W)E(@IM<V=S='(@(DEN<V5R96EX('5N82!C96RW;&$@82!S;V)R
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M26YS97)I=2!U;F$@8V]L=6UN82!A('-O=&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("));G-E<FEU('5N82!C;VQU;6YA
M(&$@<V]B<F4B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("));G-E<FEU(&UI
M<W-A=&=E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E
M<B(*;7-G<W1R("));G-E<FEU('5N('!A<N!G<F%F(&$@<V]T82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,PIM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B26YS
M97)I=2!U;B!P87+@9W)A9B!A('-O8G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(')O=R!A9G1E<B(*;7-G<W1R("));G-E<FEU('5N82!F:6QA(&$@<V]T82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(DEN<V5R
M:74@=6YA(&9I;&$@82!S;V)R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H
M92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B26YS97)I=2!L82!R97-P
M;W-T82!A(&QA('!R96=U;G1A(&1E('-E9W5R971A=#HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN<V5R:7(O36]D:69I8V%R(&EM
M871G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("));G-E
M<FER+TUO9&EF:6-A<B!E;FQL8><B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0R"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O
M('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(").;R!D
M:7-P;W-E=2!D92!P<F]U(&-RZ&1I="!P97(@96YV:6%R+6QO(&$@;&$@;&QI
M<W1A(&1E(&1I<W1R:6)U8VGS+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S0*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM
M<V=S='(@(D-RZ&1I="!I;G-U9FEC:65N="XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(").;VUB<F4@96YT
M97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E
M<B!L:7-T(@IM<V=S='(@(DQL:7-T82!D92!N;VUB<F5S(&5N=&5R<R(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("))
M;G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")51$@@
M;F\@=N!L:61A+B`H0V%PYV%L97)A(&1E(&1A9&5S(&0G=7-U87)I*2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P
M<&QI8V%T:6]N+B(*;7-G<W1R(")!<&QI8V%C:?,@;F\@=N!L:61A+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("))
M;G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("),)VED96YT:69I8V%D;W(@9&5L
M(&QO="!N;R#I<R!VX&QI9"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#@W
M(&QI8B](;W)D92]&;W)M+G!H<#HR,34X(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C,R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,CDW"FUS9VED("));G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("),97,@9&%D97,@<75E(',G:&%N
M('1R86WH<R!N;R!S\VX@=N!L:61E<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO
M;B!A9&1R97-S+B(*;7-G<W1R("),)V%D<F7G82!D92!D97-T:6YA8VGS(&YO
M(.ES(';@;&ED82XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HX
M,2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@9F]R
M;6%T(@IM<V=S='(@(D5L(&9O<FUA="!D92!L)V%R>&EU(&YO(.ES(';@;&ED
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DQA(&-L874@9&4@;&$@
M;&QI8^AN8VEA(&YO(.ES(';@;&ED82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("),82!U8FEC86-I\R!Q=64@:&5U('!R;W!O<F-I;VYA
M="!N;R#I<R!VX&QI9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(D5L('1I<'5S+6US9R!N;R#I<R!VX&QI9"XB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`B36%N8V$@96P@87!I7VED(&\@96P@<75E
M(',G:&$@9F%C:6QI=&%T(&YO(.ES(';@;&ED+B(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B36%N<75E;B!P87+@;65T<F5S
M(&\@96QS('%U92!S)VAA;B!F86-I;&ET870@;F\@<_-N(';@;&ED<RXB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-#,*;7-G:60@(DEN=F%L:60@
M<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DPG875T;W)I='IA8VGS('!A
M=&5R;F$@;F\@Z7,@=N!L:61A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T
M<B`B16P@8V]D:2!D)VED96YT:69I8V%C:?,@9&4@<V]C:2!N;R#I<R!VX&QI
M9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED
M("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B16P@8V]D:2!D96P@
M<')O9'5C=&4@;F\@Z7,@=N!L:60N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM
M<V=S='(@(D5L('!R;W1O8V]L(&YO(.ES(';@;&ED+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z("<E<R<B"FUS9W-T<B`B16P@
M9&5S=&EN871A<FD@;F\@Z7,@=N!L:60Z("<E<R<B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$P-#,@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C(P"FUS9VED
M("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("),)V]B:F5C=&4@8V]M
M<&%R=&ET(&YO(.ES(';@;&ED(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N
M(@IM<V=S='(@(DPG861R9>=A(&0G;W)I9V5N(&YO(.ES(';@;&ED82XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B
M26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(DQE<R!D861E<R!5;FEC
M;V1E(&YO('/S;B!VX&QI9&5S+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C,*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E;G1A<FDB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3D*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M27)A;BP@4F5P^F)L:6-A($ES;.!M:6-A(&0G(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))<F%Q(@IM
M<V=S='(@(DER87$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,3,*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B27)L86YD
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(DEL;&$@9&4@36%N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(E1E;7!E<W1E<R!A[VQL861E<R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-`IM<V=I9"`B
M27-R865L(@IM<V=S='(@(DES<F%E;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B16UI<W-O<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM
M<V=I9"`B271A;&EC(@IM<V=S='(@(D-U<G-I=F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$*;7-G:60@(DET86QY
M(@IM<V=S='(@(DETX&QI82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$R,PIM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*
M86UA:6-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B1V5N97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C4*;7-G:60@(DIA<&%N(@IM
M<V=S='(@(DIA</,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*87!O;NAS("A)
M4T\M,C`P,BU*4"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS
M9VED(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T"FUS9VED(")*;W)D86XB
M"FUS9W-T<B`B2F]R9.!N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S@P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")*=6QI;VPB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<Y(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R
M(")*=6YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")*=7-T:69I
M8V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(DIU
M<W1I9FEC87(@86P@8V5N=')E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L
M;"(*;7-G<W1R(")*=7-T:69I8V%R(&$@=&]T<R!D;W,@;6%R9V5S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")*=7-T:69I8V%R(&$@
M;"=E<W%U97)R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S
M='(@(DIU<W1I9FEC87(@82!L82!D<F5T82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-@IM<V=I9"`B2V%Z86MH<W1A
M;B(*;7-G<W1R(")+87IA:VAS=&%N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS
M9W-T<B`B5F]L974@8V]N<V5R=F%R(&PG;W)I9VEN86P_(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(V"FUS9VED(")+
M96YY82(*;7-G<W1R(")+96YY82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(D5L('-E<G9I9&]R($ME<F)E<F]S(&AA(')E
M8G5T:F%T(&PG875T96YT:6-A8VGS+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L
M($YE=V)I97,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G
M:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")#<F5A8VGS(&1E(&-L875S(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`S"FUS9VED(")+97D@1FEN
M9V5R<')I;G0B"FUS9W-T<B`B16UP<F5M=&$@9&EG:71A;"!D92!L82!C;&%U
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")+97D@
M3&5N9W1H(@IM<V=S='(@(DQO;F=I='5D(&1E(&QA(&-L874B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!4>7!E(@IM<V=S
M='(@(E1I<'5S(&1E(&-L874B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(MIS(&1E(&QA(&-L
M874B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,CD*;7-G:60@(DME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B2F$@97AI<W1E:7@@=6YA(&-L874@96X@96P@<V5R=FED;W(@9&4@
M8VQA=7,@</IB;&EQ=65S+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,PIM<V=I9"`B2VED<R(*;7-G<W1R(").;VES(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S,@IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]R96$L(%)E</IB
M;&EC82!$96UO8W+@=&EC82!0;W!U;&%R(&1E(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]R96$L(%)E</IB;&EC82!D92(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+
M4BDB"FUS9W-T<B`B0V]R9>`@*$550RU+4BDB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0*;7-G:60@(DMU=V%I="(*
M;7-G<W1R(")+=7=A:70B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,C<*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B
M2VER9W5I>FES=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX
M"FUS9VED("),85]Y;W5T(@IM<V=S='(@(D9O<FUA="(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S<@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B261I;VUA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED("),86\@
M4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI
M8V$@1&5M;V-RX'1I8V$@4&]P=6QA<B!D92!,86]S(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(D1A<G)E
M<F$@;65I=&%T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI8B]";&]C
M:R]M;V]N+G!H<#HY,`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(D1A
M<G)E<B!Q=6%R="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,30Y"FUS9VED
M("),87-T(%5P9&%T960Z(@IM<V=S='(@(D1A<G)E<F$@86-T=6%L:71Z86-I
M\SHB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C8V"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(D1A<G)E<F$@8V]N;F5X
M:?,Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(D1A
M<G)E<F$@8V]N;F5X:?,Z("5S(&1E("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N
M<&AP.C8V,PIM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B1&%R
M<F5R82!C;VYN97AI\SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*;7-G<W1R("),973R
M;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B
M"FUS9W-T<B`B3&QE:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D1I
M<W-E;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S
M='(@(D1E:7AA<BUH;R!E;B!B;&%N8R!P97(@96QI;6EN87(@96P@8V]N=&]R
M;B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S.`IM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),[6)A;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I
M9"`B3&5F="(*;7-G<W1R(")%<W%U97)R82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3$W"FUS9VED("),969T(&AE861E<B(*;7-G<W1R(")#87#G86QE
M<F$@97-Q=65R<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q,PIM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F%L;W)S(&1E(&PG97-Q=65R<F$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#,*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,@IM<V=I9"`B
M3&EB97)I82(*;7-G<W1R("),:6+H<FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),:6)Y86X@07)A
M8B!*86UA:&ER:7EA(@IM<V=S='(@(DSM8FEA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30P"FUS9VED("),:65C:'1E
M;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B3&EG:'0@1')I
M>GIL92(*;7-G<W1R(")0;'5G:6T@9F5B;&4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B3&EG:'0@4F%I;B(*
M;7-G<W1R(")0;'5J82!F96)L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("),:6=H="!286EN($5A<FQY(@IM
M<V=S='(@(E!L=6IA(&9E8FQE(&$@<')I;65R82!H;W)A(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT
M(%)A:6X@3&%T92(*;7-G<W1R(")0;'5J82!F96)L92!C87`@86P@=&%R9"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS
M9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")2=6EX870@9F5B;&4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM
M<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B4G5I>&%T
M(&9E8FQE(&%M8B!T<F]N<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(DYE
M=F%D82!F96)L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(Y"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(")8
MX&9E8R!D92!N974@9F5B;&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6-K(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$X,3@*;7-G:60@(DQI;FLB"FUS9W-T<B`B16YL
M;&'G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4V"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B
M16YL;&%CYV%R(&5L<R!P=6YT<R!A;6(Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE
M(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B16YL;&'G
M87(@;"=A9')EYV$@96QE8W1R\FYI8V$@82!L82!PX&=I;F$@9&4@<F5D86-T
M870@<75A;B!E<R!M;W-T<FDB"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(D5N;&QA
MYV]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU
M>"!#;V]K:64B"FUS9W-T<B`B1V%L971A($QI;G5X(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&QI<W1A<B`M($PG=7-U87)I
M('!O="!V975R92!L82!C87)P971A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,`IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B3&QI<W1A<B!L
M97,@8F%S97,@9&4@9&%D97,B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H
M<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("),;&ES=&$@
M9&5L<R!T96UE<R!D)V%J=61A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.0IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B3&QI<W1A<B!L97,@=&%U
M;&5S(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED
M("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES="U!<F-H:79E(@H*(SH@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B
M"FUS9W-T<B`B3&ES="U(96QP(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R
M<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W0M260B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M
M3W=N97(B"FUS9W-T<B`B3&ES="U/=VYE<B(*"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI
M<W0M4&]S="(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0IM
M<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U3=6)S8W)I8F4B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI
M<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B3&ES="U5;G-U8G-C<FEB92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-`IM<V=I9"`B3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3&$@;&QI<W1A(&0G
M=7-U87)I<R!E<W3@(&EN:&%B:6QI=&%D82XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B0FEB;&EO
M9W)A9FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET=>!N:6$B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,S.`HC+"!F=7IZ>0IM<V=I9"`B
M3&]A9&EN9R!L:6)R87)I97,N+BXB"FUS9W-T<B`B4R=E<W3@(&-A<G)E9V%N
M="XN+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S
M"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(E,G97-TX"!C87)R96=A;G0N
M+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`S"FUS9VED
M("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B2&]R82!L;V-A;#H@(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B
M"FUS9W-T<B`B261I;VUA(&D@:&]R82(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC
M.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HV,PIM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B56)I8V%C:?,B"@HC.B!L
M;V=I;BYP:'`Z,34U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-C0@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX-`HC.B!T96UP;&%T97,O;&]G
M:6XO;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U
M"FUS9VED("),;V<@:6XB"FUS9W-T<B`B26YI8VEA(&QA('-E<W-I\R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3@*;7-G:60@(DQO9R!O
M=70B"FUS9W-T<B`B4W5R="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E1A<W%U97,@9"=I;FEC
M:2!D92!S97-S:?,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$Q"FUS9VED
M("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W
M;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)(:2!H
M82!H86=U="!U;B!E<G)O<B!D92!C;VYN97AI\R!P97)Q=>@@:&5U(&EN=')O
M9'7O="!I;F-O<G)E8W1A;65N="!E;"!N;VT@(@HB9"=U<W5A<FD@;R!L82!C
M;VYT<F%S96YY82XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3`W"FUS9VED
M("),;V=I;B!F86EL960N(@IM<V=S='(@(DAA(&9A;&QA="!L82!C;VYN97AI
M\RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,`IM<V=I9"`B3&]N9R!T
M97AT(@IM<V=S='(@(E1E>'0@;&QA<F<B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B06UO<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED("),;W<B
M"FUS9W-T<B`B0F%I>"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE
M='1E<G,B"FUS9W-T<B`B06QF86)E="!G<F5C(&5N(&UI;OIS8W5L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B06QF
M86)E="!L;&%T[2!E;B!M:6[Z<V-U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E
M<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(EAI9G)E<R!R;VUA;F5S(&5N(&UI
M;OIS8W5L82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T-0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)U
M<F<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<S
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U,0IM<V=I9"`B34]41"(*;7-G
M<W1R(")-3U1$(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(DPG87)X:74@861J=6YT($U3+51.148@;F\@8V]N=&5N
M:6$@9&%D97,N(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W"FUS
M9VED(")-86-A;R(*;7-G<W1R(")-86-A=2(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,PIM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA
M8V5D\FYI82P@06YT:6=A(%)E</IB;&EC82!)=6=O<VQA=F$@9&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3$*;7-G
M:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B3>!G
M:6,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-SD*;7-G:60@(DUA
M:6PB"FUS9W-T<B`B0V]R<F5U(&5L96-T<O)N:6,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#8X"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@
M(D%D;6EN:7-T<F%D;W(@9&4@8V]R<F5U(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"FUS9VED(")-86ME
M(&QI;E]K+BXN(@IM<V=S='(@(E,G97-TX"!C<F5A;G0@=6X@96YL;&'G+BXN
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-3<*;7-G:60@(DUA:V4@<W5R
M92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R(&EN
M8VQU9&4@<&%T:"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C8W."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B36%K:6YG(&1I<F5C=&]R>2`E<R(*;7-G<W1R(").;R#I
M<R!U;B!D:7)E8W1O<FDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")-86QA
M=VDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-C<*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA;.!I<VEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T"FUS
M9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79E<R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-`IM<V=I9"`B36%L
M:2(*;7-G<W1R(")-86QI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38R"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N
M86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@
M:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB1V5S=&EO;F5U(&QA(&QL:7-T
M82!D92!C871E9V]R:65S(&%M8B!L97,@<75A;',@:&5U(&0G971I<75E=&%R
M(&5L<R`B"B)E;&5M96YT<RP@:2!E;',@8V]L;W)S(&%S<V]C:6%T<R!A;6(@
M87%U97-T97,@8V%T96=O<FEE<RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@
M(DUA<&$@36%P,C0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<W"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#4T"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P82!-87!1
M=65S="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED
M(")-87)C:"(*;7-G<W1R(")-87+G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM
M<V=S='(@(DUA<F=E(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS
M9W-T<B`B36%R8V%R(&%M8B!I;F1I8V%D;W)S('9I<VEB;&5S+VEN=FES:6)L
M97,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G
M:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS
M=V5R960I(@IM<V=S='(@(DUA<F-A<B!A;6(@86QT<F5S(&EN9&EC861O<G,@
M*'`N(&4N+"!I;7!O<G1A;G0O<F5S<&]S="DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3(*;7-G:60@(DUA<G-H86QL
M($ES;&%N9',B"FUS9W-T<B`B26QL97,@36%R<VAA;&PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3D*;7-G:60@(DUA
M<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6-A(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,3$*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G
M<W1R(")#86UP<R!Q=64@8V]I;F-I9&5I>&EN(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P"FUS9VED(")-875R:71A
M;FEA(@IM<V=S='(@(DUA=7)I=.!N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,*;7-G:60@(DUA=7)I=&EU<R(*
M;7-G<W1R(")-875R:6-I(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,30*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T
M<B`B0W+H9&ET(&W@>&EM('!E<FWH<RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@
M97AC965D960N(@IM<V=S='(@(E,G:&$@<W5P97)A="!E;"!N;VUB<F4@;>!X
M:6T@9&4@<&%R=',@9&4@;6ES<V%T9V4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#0*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R(")496UP97)A='5R82!MX'AI;6$@9&4@;&5S(&1A<G)E<F5S(#(T(&AO
M<F5S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-@IM<V=I9"`B36%X
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>!X
M:6UA(&1E(&QE<R!D87)R97)E<R`V(&AO<F5S.B`B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R
M("),;VYG:71U9"!MX'AI;6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S<X(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA:6<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S"FUS9VED(")-
M87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DUE9&EC:6YA(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ.0IM<V=I9"`B
M365M8F5R<R(*;7-G<W1R(")-96UB<F5S(@H*(SH@;&%N9W1E<W0N<&AP.C<*
M;7-G:60@(DUE;6]R>2!E>&AA=7-T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M(")4:7!U<R!D92!M96[Z.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM
M<V=S='(@(E)E9F]N87(@;&5S(&-E;+=L97,B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@86QL("5S
M+G!O(&9I;&5S('1O('1H92!C;VUP96YD:75M+BXN("(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#,X"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE<F=I;F<@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-S@X"B,L('!H<"UF;W)M870*;7-G:60@(DUE<F=I;F<@
M=&AE(%!/(&9I;&4@9F]R("5S('1O('1H92!C;VUP96YD:75M+BXN("(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#(U"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE<F=I;F<@=')A;G-L871I;VX@9F]R(&UO9'5L92`E<RXN
M+B(*;7-G<W1R("(B"@HC.B!L86YG=&5S="YP:'`Z,3<@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(DUI<W-A=&=E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S
M<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T
M(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B)%;"!M:7-S871G92!H82!E
M<W1A="!V97)I9FEC870@8V]R<F5C=&%M96YT+"!P97+R(&YO(',G:&$@<&]G
M=70@=F5R:69I8V%R(&5L("(*(F-E<G1I9FEC870@96P@<VEG;F%N="XB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-:7-S871G92!C861U8V%T+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(V(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4Y"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C@@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8P,0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I
M<'5S(&1E(&UI<W-A=&=E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS
M9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(E1E;7!S(&1E($U%5$%2(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B16P@8FQO8R!-151!4B!N;R!E<W3@
M(&1I<W!O;FEB;&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3`*;7-G
M:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*(D5L(&)L;V,@345405(@;F\@97-TX"!D:7-P;VYI8FQE+B!%;',@9&5T
M86QL<R!H86X@97-T870@<F5G:7-T<F%T<R!P97(@82`B"B)L)V%D;6EN:7-T
M<F%D;W(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM
M<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("),82!B
M87-E(&1E(&1A9&5S($U%5$%2(&YO(&5S=.`@8V]N;F5C=&%D82XB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,2!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HV-PIM<V=I9"`B365T:&]D(@IM<V=S='(@(DWH
M=&]D92(*"B,Z(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W(&QI8B](;W)D
M92]24$,O>&UL<G!C+G!H<#HX,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D("<E<R<@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B16P@;>AT
M;V1E("<E<R<@;F\@97-TX"!D969I;FET+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<S"FUS9VED
M(")-971R:6,B"FUS9W-T<B`B3>AT<FEC(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V"FUS9VED(")-97AI8V\B"FUS
M9W-T<B`B3>AX:6,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX-0IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9B(*;7-G<W1R(")-:6-R;V[H<VEA+"!%<W1A=',@1F5D97)A=',@
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")#96YT<F4B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@
M5'EP92(*;7-G<W1R(")4:7!U<R!-24U%(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#@*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R(")496UP97)A='5R82!M[6YI;6$@9&4@;&5S(&1A<G)E<F5S(#(T(&AO
M<F5S.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,`IM<V=I9"`B36EN
M('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>UN
M:6UA(&1E(&QE<R!D87)R97)E<R`V(&AO<F5S.B`B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$W"FUS9VED(")-:7)R;W(B"FUS
M9W-T<B`B4NAP;&EC82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")-:7-C96RW;&%N:2(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S,Y(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S$*;7-G:60@(DUI<W-I;F<@4$5!
M4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B1F%L=&$@;&$@<V]L
MMVQI8VET=60@2%144"!P97(@86P@<&%Q=65T(%!%05(N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$Q-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D9A
M;'1A(&QA(&-O;F9I9W5R86-I\RX@3"=H974@9&4@9V5N97)A<B!A<F$@<VD@
M=F]L974@=71I;&ET>F%R(&%Q=65S=&$@(@HB87!L:6-A8VGS+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED(")-:7-S
M:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(D9A;'1A(&PG:61E;G1I9FEC861O
M<B!D96P@;6ES<V%T9V4N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HU-PIM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"XB"FUS9W-T<B`B1F%L=&$@96P@8V]R<F5U(&5L96-T<O)N
M:6,@9&5L('!A<75E="!014%2(&YE8V5S<V%R:2XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R(")&86QT82!L)VED96YT:69I8V%D;W(@9&4@<V5S
M<VGS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(D1L+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HW,@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B
M0V]R<F5U(&WR8FEL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C0*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DUO9&5R870B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,"!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HX.`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV-@IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M(")$871A(&UO9&EF:6-A9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(DUO9&EF>2!54DPB
M"FUS9W-T<B`B36]D:69I8V%R(&QA(%523"(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HV-3<*(RP@9G5Z>GD*;7-G:60@(DUO9'5L92(*;7-G<W1R(")-\F1U
M;"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-
M;V1U;'5S(@IM<V=S='(@(DWR9'5L(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P"FUS9VED(")-;VQD;W9A+"!297!U
M8FQI8R!O9B(*;7-G<W1R(")-;VQDX'9I82P@4F5P^F)L:6-A(&1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y"FUS
M9VED(")-;VYA8V\B"FUS9W-T<B`B3?)N86-O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-;VYG;VQI
M82(*;7-G<W1R(")-;VYG\FQI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-3DR"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-97,@:2!A;GDB
M"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT
M:&QY(@IM<V=S='(@(DUE;G-U86QM96YT(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T
M(@IM<V=S='(@(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM
M<V=S='(@(D9A<V5S(&QU;F%R<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T.`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R
M(")-87)R;V,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,`IM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(DUA:F]R:73@
M<FEA;65N="!D97-C;V)E<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R
M(")-86IO<FETX')I86UE;G0@96YN=79O;&%T(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DUO<W1L>2!3=6YN
M>2(*;7-G<W1R(")-86IO<FETX')I86UE;G0@87-S;VQE;&QA="(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R.`IM<V=I9"`B36]V92!$;W=N
M(@IM<V=S='(@(DUO=7)E(&-A<"!A=F%L;"(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C0S,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(DUO
M=7)E(&$@;"=E<W%U97)R82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C0S-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")-;W5R92!A(&QA
M(&1R971A(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-#(T"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(DUO=7)E(&-A<"!A;75N="(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.38*;7-G:60@(DUO
M=F4@9&]W;B(*;7-G<W1R(")-;W5R92!C87`@879A;&PB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DU(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.38*;7-G:60@(DUO=F4@=7`B"FUS9W-T
M<B`B36]U<F4@8V%P(&%M=6YT(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,38X"FUS9VED(")-;WIA;6)I<75E(@IM<V=S
M='(@(DUOYV%M8FEC(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#0*;7-G
M:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("),:7-T
M97,@9&5S<&QE9V%B;&5S(&5N;&QAYV%D97,@96X@9&EV97)S;W,@;FEV96QL
M<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L
M92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?,@;?IL=&EP;&4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(Y(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S8*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B16P@;65U
M(&-O;7!T92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3`*;7-G
M:60@(DUY(%!O<G1A;"(*;7-G<W1R(")%;"!M974@<&]R=&%L(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+V5D:70N<&AP.C$R-`IM<V=I9"`B37D@4&]R=&%L($QA
M>6]U="(*;7-G<W1R(")$:7-S96YY(&1E;"!M974@<&]R=&%L(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U"FUS9VED
M(")->6%N;6%R(@IM<V=S='(@(DUY86YM87(B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(DY/+"!.3R!H:2!E<W1I8R!D)V%C;W)D
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B3F%M92(*;7-G<W1R(").;VTB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-CD*
M;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M[6)I82(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W.`IM<V=I9"`B3F%U
M<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE
M<&%L(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3<U"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(")08>]S;W,@0F%I
M>&]S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(D%N
M=&EL;&5S($YE97)L86YD97-E<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R(")5
M4DP@8F%S92!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M;7-G<W1R(")54DP@9&4@<F5V;V-A8VGS(&1E($-!(&1E($YE='-C87!E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C
M87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B55),(&1E('!O;.UT:7%U97,@
M9&4@0T$@9&4@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B
M55),(&1E(')E;F]V86-I\R!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T:6]N
M(%523"(*;7-G<W1R(")54DP@9&4@<F5V;V-A8VGS(&1E($YE='-C87!E(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C
M87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").;VT@9&5L('-E<G9I9&]R
M(%-33"!D92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(@IM
M<V=S='(@(D-O;65N=&%R:2!D96P@8V5R=&EF:6-A="!D92!.971S8V%P92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S
M8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E1I<'5S(&1E(&-E<G1I
M9FEC870@9&4@3F5T<V-A<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C,W"FUS9VED(").971W;W)K(@IM<V=S='(@(EAA<GAA(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$T(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B3F5V
M97(B"FUS9W-T<B`B36%I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<P"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S
M='(@(DYO=F$@0V%L963R;FEA(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,C<*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R
M(").;W9A(&-A=&5G;W)I82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W.0IM
M<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3&QU;F$@;F]V82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=2!N;VT@9"=U<W5A<FD@*&]P
M8VEO;F%L*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]V82!:
M96QA;F1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").
M;W9A(&9I;F5S=')A("A?96X@8FQA;F,I(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DYE=W,B"FUS9W-T<B`B36ES
M<V%T9V5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,PIM<V=I
M9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P<R!D92!D:7-C=7-S:?,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHS,B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$S-PHC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHR,2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT-@IM<V=I9"`B3F5X
M="(*;7-G<W1R(")396?\96YT(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(C0@9F%S97,@<V5G_&5N
M=',B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V."!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C,W,@IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@
M(D]P8VEO;G,@<V5G_&5N=',B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP
M.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B4V5G_&5N=#XB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(D[M9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3<S"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI
M9^AR:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$X"FUS
M9VED(").:6=H="(*;7-G<W1R(").:70B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD*;7-G:60@(DYI=64B"FUS9W-T
M<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HX.#4*;7-G:60@(DYO(@IM<V=S='(@(DYO(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V1I9F8N:'1M;#HQ-@IM<V=I9"`B3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS
M9W-T<B`B3F\@97,@9&ES<&]S96X@9&4@9&%D97,@9&4@8V]N9FEG=7)A8VGS
M('!E<B!M;W-T<F%R(&QE<R!D:69E<NAN8VEE<RXB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").;R!E<R!D:7-P;W-A
M(&0G=6YA(&5S=')A=.AG:6$@<&5R(&-R96%R(&EM871G97,@25-/+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED(").
M;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B3F\@:&D@:&$@<&QA;G1I;&QA
M(&1E(&QO=',N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-SD@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C,P"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(U,@IM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B3F\@97AI<W1E:7@@
M8V%P(&)L;V,@96X@;&$@<&]S:6-I\R!S;VRW;&EC:71A9&$B"@HC.B!L:6(O
M2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M3F\@<R=H82!P<F]P;W)C:6]N870@=6X@;F]M(&0G86=E;F1A('!E<B!A(&PG
M875T96YT:6-A8VGS($U#04PN(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B4V5N<V4@8V%N=FES+B(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30P"B,L(&9U>GIY"FUS9VED
M(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@
M=&AI<R!L979E;"XB"FUS9W-T<B`B3F\@97,@<&]D96X@869E9VER(&1E<V-E
M;F1E;G1S(&$@87%U97-T('!E<FWM<R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F\@97,@<&]D96X@869E9VER
M(&1E<V-E;F1E;G1S(&$@87%U97-T('!E<FWM<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,S<W"B,L(&9U>GIY"FUS9VED(").;R!C;VUM86YD('-P96-I
M9FEE9"XB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!U;B!N;VTN(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ-C<@;&EB+TAO<F1E+G!H<#HT-S<@;&EB+TAO
M<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(DYO(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E(&-O;F9I9W5R
M86-I\R!P97(@82`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S0Q"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RXB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!L97,@9&%D
M97,@9&4@8V]N9FEG=7)A8VGS('!E<B!A($944"!P97(@5D93+B(*"B,Z(&QI
M8B]61E,O<W%L+G!H<#HU.3$*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").;R!S
M)VAA(&5S<&5C:69I8V%T(&QE<R!D861E<R!D92!C;VYF:6=U<F%C:?,@<&5R
M(&$@4U%,('!E<B!61E,N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S`T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"B).;R!S)VAA(&5S<&5C
M:69I8V%T(&QE<R!D861E<R!D92!C;VYF:6=U<F%C:?,@9&4@4U%,('!E<B!A
M;"!F:71X97(@4U%,+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$S"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B3F\@
M<75E9&$@8W+H9&ET+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S,*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R(").;R!S)VAA(&9A8VEL:71A="!U;F$@9&5S=&EN86-I\RXB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X:7-T<R!I;B!T:&4@;W)I9VEN
M86P@:&5L<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E
M<BYP:'`Z.#<Q"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DYO
M(',G:&$@8V%R<F5G870@8V%P(&%R>&EU+B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DYO
M(',G:&$@=')O8F%T(&-A<"!I8V]N82XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU,C(*(RP@9G5Z>GD*;7-G:60@
M(DYO(&QO8V%L92!S<&5C:69I960N(@IM<V=S='(@(DYO(',G:&$@97-P96-I
M9FEC870@=6X@;F]M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,C`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3(Q"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S
M='(@(DYO(',G:&$@9&5F:6YI="!U;F$@=6)I8V%C:?,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(DYO(',G:&$@9F%C:6QI=&%T('5N82!U8FEC
M86-I\RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(").;R!S)VAA
M(&EN=')O9'7O="!U;B!M:7-S871G92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB
M"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!U;B!N;VTN(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;G5M
M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF:6-A="!U
M;F$@>&EF<F$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B3F\@97,@<&5R;65T
M96X@;&5S(&1I=&5S(&]F96YS:79E<RXB"@HC.B!L:6(O2&]R9&4O075T:"]H
M='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A4
M5%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO(',G:&$@:6YT<F]D=>]T
M('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!(5%10+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L
M)V%U=&5N=&EC86-I\R!)34%0+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N
M<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R
M;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO(',G:&$@:6YT<F]D=>]T
M('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!+97)B97)O
M<RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(DYO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S
M96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!)34%0+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-S4*
M(SH@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L
M)V%U=&5N=&EC86-I\R!D)VEN:6-I+B(*"B,Z(&QI8B](;W)D92]!=71H+W!A
M<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").;R!S)VAA(&EN=')O
M9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@4$%3
M4U=$+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@
M82!L)V%U=&5N=&EC86-I\R!334(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,
M(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S
M<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B
M"B).;R!S)VAA(&EN9&EC870@;&$@=FEA(&0G86-CZ7,@86P@8FEN87)I($]P
M96Y34TPN($-A;"!E;"!B:6YA<FD@3W!E;E-33"!P97(@(@HB=')E8F%L;&%R
M(&%M8B!L97,@9&%D97,@4$M#4R`Q,BXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N
M(@IM<V=S='(@(DYO(&AI(&AA(&%L=&5S('!E;F1E;G1S+B(*"B,Z(&QI8B]6
M1E,N<&AP.C<V-0IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(").;R!S
M)VAA(&1E9FEN:70@;"=E<W!A:2!D:7-P;VYI8FQE+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@
M(DYO(')U;&5S(@IM<V=S='(@(E-E;G-E(')E9VQE<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@
M(DYO('-I9&5S(@IM<V=S='(@(E-E;G-E(&-A<F5S(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C4X-0IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DYO(&5X
M:7-T96EX(&%Q=65S="!A<GAI=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,S`*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B3F\@97,@9&ES<&]S82!D92!C
M87`@9&ER96-T;W)I('1E;7!O<F%L('!E<B!A(&QA(&UE;?)R:6$@8V%U+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S`*;7-G:60@
M(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").
M;R!H974@96YV:6%T(&5L(&YO;2!D)W5S=6%R:2!N:2]O(&QA(&-O;G1R87-E
M;GEA(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B
M3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B3F\@<R=H86X@
M<F5T;W)N870@9&%D97,@6$U,(';@;&ED97,B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DS(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HY,#,*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDQ-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3,Q"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B4V5N<V4@=F%L;W)S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DYO(',G:&$@=')O8F%T
M(&QA('9E<G-I\R!E;B!L82!C;VYF:6=U<F%C:?,@;W)I9VEN86PN(%)E9V5N
M97)E=2!L82`B"B)C;VYF:6=U<F%C:?,N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB3F\@<R=H82!T<F]B870@;&$@=F5R<VGS(&5N(&QA(&-O;F9I9W5R
M86-I\RX@4F5G96YE<F5U(&QA(&-O;F9I9W5R86-I\RXB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,38@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDR"FUS9VED(").;VYE(@IM<V=S='(@(D-A<"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*
M;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B0V%P("CZ<R!I
M;7!L[6-I="DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B
M3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B3O)R9&EC("A)4T\M.#@U
M.2TQ,"DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S(*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DEL;&$@
M9&4@3F]R9F]L:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS
M9W-T<B`B2&5M:7-F97)I(&YO<F0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3@*;7-G:60@(DYO<G1H97)N($UA<FEA
M;F$@27-L86YD<R(*;7-G<W1R("));&QE<R!-87)I86YN97,@9&5L($YO<F0B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S8*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)U96=A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G
M<W1R(").;R!D97-P<NES(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F\@86)A;G,B"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C,S,0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y
M(@IM<V=S='(@(DYO(.ES('5N(&1I<F5C=&]R:2(*"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C4Y"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z.#,*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HY-`IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G
M<W1R(").;R!I;7!L96UE;G1A="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@
M(DYO(&1E9FEN:70B"@HC.B!L:6(O5D93+G!H<#HQ.3,@;&EB+U9&4RYP:'`Z
M,C`X(&QI8B]61E,N<&AP.C(S,R!L:6(O5D93+G!H<#HR-3$*(SH@;&EB+U9&
M4RYP:'`Z,C8X(&QI8B]61E,N<&AP.C(X-"!L:6(O5D93+G!H<#HS,#`@;&EB
M+U9&4RYP:'`Z,S$U"B,Z(&QI8B]61E,N<&AP.C,S,B!L:6(O5D93+G!H<#HS
M-C4@;&EB+U9&4RYP:'`Z-#(U(&QI8B]61E,N<&AP.C4P-`HC.B!L:6(O5D93
M+G!H<#HU-S,@;&EB+U9&4RYP:'`Z-3DP(&QI8B]61E,N<&AP.C8V.`HC.B!L
M:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$T,R!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L
M97(N<&AP.C$W,R!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC
M.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C(S-`IM<V=I9"`B3F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B3F\@<&5R;>AS+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-C(*;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&5S(@H*(SH@
M<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B3F\@:&D@:&$@<F5S(&$@
M=FES=6%L:71Z87(L(')E=')O8V5D:74N(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`HC+"!F=7IZ>0IM<V=I9"`B3F]T
M:6-E(@IM<V=S='(@(DYO=&5S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8G)E(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E<B(*;7-G
M<W1R(").;VUB<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30S,`IM<V=I
M9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B3F]M8G)E(&1E(&-A
M<N!C=&5R<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S<T(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#(X(&QI8B](;W)D92]&;W)M+G!H<#HQ-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED
M(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(").;VUB<F4@9&4@8V]L=6UN
M97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30R-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T.`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M
M8F5R(&]F(')O=W,B"FUS9W-T<B`B3F]M8G)E(&1E(&9I;&5S(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B(@HB3F\@<R=H86X@97-P96-I9FEC870@;F]M8G)E
M<R!Q=64@:&%G:6X@9&4@<V5R(&%C='5A;&ET>F%T<R!E;B!L82!L;&ES=&$@
M9&4@(@HB9&ES=')I8G5C:?,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8T('!O+W1R86YS;&%T:6]N+G!H<#HQ-#@*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$S-#@*;7-G:60@(D]+(@IM<V=S='(@(D0G
M86-O<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#$Q"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96-T92(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O
M<B(*;7-G<W1R(")#<F5A9&]R(&1E(&PG;V)J96-T92(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$S-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q-0HC
M+"!F=7IZ>0IM<V=I9"`B3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,B"FUS
M9W-T<B`B4&5R;6ES;W,@9&5L(&-R96%D;W(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3V-T86PB"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@S(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*
M;7-G<W1R(")/8W1U8G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR
M"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT<F4@9"=I;F9R
M86-C:6]N<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3D*;7-G
M:60@(D]F9FEC92(*;7-G<W1R(")/9FEC:6YA(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM
M<V=S='(@(D]M86XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D
M(&9O;&1E<G,N(@IM<V=S='(@(DYO;>ES(&5L<R!S97)V:61O<G,@24U!4"!P
M97)M971E;B!L)_IS(&1E(&-A<G!E=&5S(&-O;7!A<G1I9&5S+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B3F]MZ7,@;6ES<V%T9V5S(&]F96YS:75S(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B3F]MZ7,@Z7,@<&5R;65S82!U;F$@^FYI8V$@861R9>=A(&5L
M96-T<O)N:6-A+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB3F]MZ7,@96P@<')O<&EE=&%R
M:2!O(&PG861M:6YI<W1R861O<B!D92!S:7-T96UE<R!P;W0@8V%N=FEA<B!L
M82!P<F]P:65T870@;R`B"B)E;',@<&5R;6ES;W,@9&5L('!R;W!I971A<FD@
M<&5R(&$@<F5C=7)S;W,@8V]M<&%R=&ET<R(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")/8G)I=2!E;B!U;F$@;F]V82!F:6YE<W1R82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R("(B"B)%<G)O<B!/<&5N4U-,.B!N;R!S)VAA;B!P;V=U="!E>'1R
M975R92!L97,@9&%D97,@9&4@;&$@<&%R="!3+TU)344@<VEG;F%D82XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-30*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B3V)R92!A<75E<W0@96YL;&'G(&5N('5N82!N;W9A(&9I;F5S
M=')A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R
M871I;F<@4WES=&5M(@IM<V=S='(@(E-I<W1E;6$@;W!E<F%T:74B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS
M(@IM<V=S='(@(D]P8VEO;G,B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,CD@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3W!C:6]N<R!D)R5S(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B3W!T:6]N
M<SHB"FUS9W-T<B`B3W!C:6]N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R("),;&ES=&$@;W)D96YA9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N
M:71Z86-I\R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38X"FUS
M9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(E5N:71A="!O<F=A
M;FET>F%T:79A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,`IM
M<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")3)V5S=.`@;W)G86YI='IA;G0B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@
M87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B4&QA;G1I;&QA(&0G87!L
M:6-A8VGS(&]R:6=I;F%L(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R(")0;&%N=&EL;&5S(&]R:6=I;F%L<R!E;B`E<SHB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")!;'1R92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"FUS9VED
M(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")!;'1R82!I;F9O<FUA8VGS
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N
M97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES;W,@9&5L('!R;W!I971A
M<FDB"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=A
M=71E;G1I8V%C:?,@4$%-(&YO(&5S=.`@9&ES<&]N:6)L92XB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C4S"FUS9VED(")01U`@1&EG:71A;"!3
M:6=N871U<F4B"FUS9W-T<B`B4VEG;F%T=7)A(&1I9VET86P@4$=0(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(Y.0IM<V=I9"`B4$=0($5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(D1A9&5S('AI9G)A9&5S(&%M8B!01U`B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4Q"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R(")#;&%U(%!'4"!P^F)L:6-A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3,S,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R
M>7!T960@1&%T82(*;7-G<W1R(")$861E<R!S:6=N861E<R]X:69R861E<R!A
M;6(@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")02%`@
M0V]D92(*;7-G<W1R(")#;V1I(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(DEN=.AR<')E="!D)V]R
M9')E<R!02%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")0;'5G:6US
M(&1E('1A<F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S4*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4&QU9V5S(&1E
M('1A<F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B3F5V861E<R!D92!T87)D
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B6.!F96-S(&1E(&YE
M=2!A(&QA('1A<F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")3;VP@9&4@=&%R
M9&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.0IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&5S=&5S(&1E('1A
M<F1A(@H*(SH@;&EB+V%P:2YP:'`Z,3(X"FUS9VED(")07TA0(%-H96QL(@IM
M<V=S='(@(DEN=.AR<')E="!D)V]R9')E<R!07TA0(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R(")397!A<F%C:?,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<*;7-G:60@(E!A:VES=&%N
M(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B
M4&%L874B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DR"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D(@IM<V=S='(@(E1E<G)I=&]R:2!P86QE<W3M+"!O8W5P870B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#(*;7-G
M:60@(E!A;F%M82(*;7-G<W1R(")086YA;>`B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@3F]V82!'=6EN96$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU"FUS9VED
M(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(E!A<F-I86QM96YT(&5N;G5V;VQA="(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#,@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P,3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3@@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,V('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-S$*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B0V]N=')A<V5N
M>6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@
M(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")#;VYT<F%S96YY82!I;F-O
M<G)E8W1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(D-A;"!I;G1R;V1U:7(@=6YA(&-O;G1R87-E;GEA('!E
M<B!A(&PG875T96YT:6-A8VGS(%)!1$E54RXB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B0V]N=')A<V5N>6$@86UB(&-O;F9I<FUA8VGS(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`B0V]N=')A<V5N>6$Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B0V]N=')A
M<V5N>6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B3&5S
M(&-O;G1R87-E;GEE<R!H86X@9&4@8V]I;F-I9&ER+B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")%;F=A
M;GAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(D5N
M9V%N>&%R(&1E;"!P;W)T82UR971A;&QS(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R
M(")#86WM(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C0*;7-G
M:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B06QT97,@<&5N9&5N=',Z
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B
M"FUS9W-T<B`B1V5N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!E<F-E
M;G1A=&=E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?8F]T
M=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO
M;G,B"FUS9W-T<B`B4F5A;&ET>F%R(&]P97)A8VEO;G,@9&4@;6%N=&5N:6UE
M;G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(E9O;&5U(')E86QI='IA<B!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT(&5N
M(&EN:6-I87(@;&$@<V5S<VGS/R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV,2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8W"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(E!E<FWM<R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@)R5S)R!N;W0@
M9&5L971E9"XB"FUS9W-T<B`B3F\@<R=H82!E;&EM:6YA="!E;"!P97)M[7,@
M)R5S)RXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-3@X"FUS9VED(")097)M:7-S
M:6]N($1E;FEE9"(*;7-G<W1R(")097)M:7,@9&5N96=A="(*"B,Z(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M.3,*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-S0*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%D;6EN:7-T<F%D;W(@9&4@<&5R;6ES;W,B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C$T-2!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$T.`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U,@HC+"!F=7IZ>0IM
M<V=I9"`B4&5R;6ES<VEO;G,@9F]R(@IM<V=S='(@(E]097)M:7-O<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM<V=I9"`B4&5R<V]N86P@26YF
M;W)M871I;VXB"FUS9W-T<B`B1&%D97,@<&5R<V]N86QS(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@S"FUS9VED(")0
M97)U(@IM<V=S='(@(E!E<OHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`B06YI;6%L<R!D92!C;VUP86YY:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#8*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YE<R(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0
M:&]N92(*;7-G<W1R(")496SH9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0Q-@IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&]S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,`IM
M<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(E#M>&5L<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")4\G!I8W,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W
M"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B
M0VQI8V%R(&5N('5N82!C96RW;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#@*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M"FUS9W-T<B`B0V]N9FER;6%R('%U92!V;VQE=2!S=7!R:6UI<B!A<75E<W0@
M96QE;65N=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B0V]N
M9FER;6%R('%U92!V;VQE=2!D97-E;FQL8>=A<B!A<75E<W0@96QE;65N="XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V.0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B26YT<F]D=>]U('5N
M(&UE<R!I('5N(&%N>2XB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B26YT<F]D=>]U('5N(&YO
M;2!P97(@82!L82!N;W9A(&-A=&5G;W)I83HB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3,P-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RXB"FUS9W-T<B`B26YT<F]D=>]U('5N82!A9')EYV$@25`@=N!L:61A
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4X"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+B(*;7-G<W1R("));G1R;V1U[W4@=6YA(&1A=&$@=N!L
M:61A+"!C;VUP<F]V974@96QS(&1I97,@<75E('3I(&5L(&UE<RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0T.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92XB"FUS9W-T<B`B26YT<F]D=>]U('5N82!H;W)A(';@;&ED
M82XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(E!R;W!O<F-I;VYE=2!U;B!R97-U;2!D96P@<')O8FQE;6$N(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ."!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C(R"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S
M97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")0<F]P;W)C:6]N974@96P@
M;F]M(&0G=7-U87)I(&D@;&$@8V]N=')A<V5N>6$B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z,3(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T
M:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B),;&5G:74@96P@=&5X="!S96?\
M96YT+B!(974@9"=A8V-E<'1A<B!L97,@8V]N9&EC:6]N<R!P97(@<&]D97(@
M=71I;&ET>F%R(&5L("(*(G-I<W1E;6$N(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$W"FUS9VED(")0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`
M;&ES=',N:&]R9&4N;W)G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")496-L96=E=2!E;"!N
M;VT@9&4@;&$@;F]V82!C871E9V]R:6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X"FUS9VED(")0;VQA;F0B"FUS
M9W-T<B`B4&]L\FYI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM
M<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L[71I8V$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")0;VQL<R(*;7-G<W1R(")%
M;G%U97-T97,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3DS"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R(")0;W)T=6=A
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G
M92(*;7-G<W1R(")#;VRW;&]C86-I\R!D)V%Q=65S=&$@:6UA=&=E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B0V]LMVQO
M8V%C:?,@9"=A<75E<W1A('1A=6QA(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B16YV:6%R(&$@87%U97-T
M82!C87)P971A("AN;R!H:2!O8FQI9V$@24U!4"DB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(V-"!L:6(O0FQO8VLO;65T87(N<&AP.C(V.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ("(*;7-G<W1R(")0<F5C:7!I=&%C:?,@9'5R86YT(&QA(&1A<G)E<F$@
M)7,@:&]R82!O(&AO<F5S.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP
M:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@3F\@<R=H82!T
M<F]B870@;"=E>'1E;G-I\R!,1$%0('-O;+=L:6-I=&%D82XB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I
M;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4')E9G-?<V5S<VEO;CH@3F\@<R=H82!T<F]B870@;"=E>'1E;G-I
M\R!D92!S97-S:?,@<V]LMVQI8VET861A+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C(S"FUS9VED(")0<F5S<W5R92(*;7-G<W1R(")0<F5S<VGS(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3<*;7-G:60@(E!R97-S=7)E(&%T
M('-E82!L979E;#H@(@IM<V=S='(@(E!R97-S:?,@86P@;FEV96QL(&1E;"!M
M87(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R(")0<F5S<VGS.B`B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4')E=FEE=R(*;7-G<W1R(")6:7-U86QI='IA8VGS('!RZ'9I82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W(@IM<V=S='(@(E9I<W5A;&ET>F%R('!RZ'9I86UE;G0@;&$@:6UA=&=E
M(&5N('5N82!N;W9A(&9I;F5S=')A(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)
M+G!H<#HS-3@@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C(*;7-G:60@(E!R
M979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B3W!C:6]N<R!P<NAV:65S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I
M9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B26UP<FEM:7(@96P@9&]C=6UE
M;G0B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(E!R
M:79A=&4@2V5Y(@IM<V=S='(@(D-L874@<')I=F%D82(*"B,Z(&QI8B](;W)D
M92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FQE
M;6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L
M96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I<&-I\R!D96P@<')O8FQE
M;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Q"FUS9VED(")0
M<F]J96-T<R(*;7-G<W1R(")0<F]J96-T97,B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$Q,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B5&5X="!I;F1I8V%D;W(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B0VQA=2!P^F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(D%L
M9V]R:7-M92!D92!C;&%U('#Z8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@
M(DEN9F]R;6%C:?,@9&4@8VQA=2!P^F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,C,P"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER
M(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(").;R!S)VAA
M(&=E;F5R870@8V]R<F5C=&%M96YT(&QA('!A<F5L;&$@9&4@8VQA=7,@</IB
M;&EC82]P<FEV861A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B
M4'5E<G1O(%)I8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1871A<B(*;7-G<W1R(")1871A<B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,@IM<V=I9"`B475E<GDB"FUS9W-T
M<B`B0V]N<W5L=&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET
M*2(*;7-G<W1R(")#;&%U('#Z8FQI8V$@4E-!("@E9"!B:70I(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*
M;7-G<W1R(")";W3S(&1E('-E;&5C8VGS(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M4&QU:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")0;'5J82!A('!R:6UE
M<F$@:&]R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0R"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B4&QU:F$@8V%P(&%L
M('1A<F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,PIM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4G5I>&%T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@
M(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4&QU:F$@:2!N97<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I
M;B!T;R!3;F]W(@IM<V=S='(@(D%I9W5A;F5U(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(D1I
M=&$@86QE873R<FEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@*;7-G:60@
M(E)A=&EO(@IM<V=S='(@(E)E;&%C:?,B"@HC.B!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C(Y,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("),;&5G:74B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E
M860@;65S<V%G97,B"FUS9W-T<B`B3&QE9VEU(&5L<R!M:7-S871G97,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(D-O;F9I<FUE=2!Q=64@=F]L
M974@<W5P<FEM:7(@)7,_($%Q=65S=&$@;W!E<F%C:?,@;F\@97,@<&]T(&1E
M<V9E<BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*(D-O;F9I<FUE=2!Q=64@=F]L974@<W5P<FEM:7(@;&5S
M(&1A9&5S(&1E(&PG=7-U87)I('!E<B!A(&PG=7-U87)I("5S/R`B"B)!<75E
M<W1A(&]P97)A8VGS(&YO(&5S('!O="!D97-F97(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B5&]R;F$@82!F97(@;&$@9&%R
M<F5R82!A8V-I\R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G
M:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")2
M969R97-C87(@96QS(&5L96UE;G1S(&1E;"!M96[Z(&1I;N!M:6-S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,0IM<V=I9"`B4F5F<F5S:"!0;W)T
M86P@5FEE=SHB"FUS9W-T<B`B4F5F<F5S8V%R(&QA('9I<W5A;&ET>F%C:?,@
M9&5L('!O<G1A;"(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.30@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S4*;7-G
M:60@(E)E9V5X(@IM<V=S='(@(D5X<')E<W-I\R!R96=U;&%R(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,R-#<*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(DYA=F5G861O<B!D92!R96QA8VEO;G,B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R-`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")#
M;VUE;G1A<FES(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I
M9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B4V5R=FED;W)S(')E;6]T<R(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M
M;W1E(%523"`H:'1T<#HO+W=W=RYE>&5M<&QE+F5S+VAO<F1E*3HB"FUS9W-T
M<B`B55),(')E;6]T("AH='1P<SHO+W=W=RYE>&5M<&QE+F5S+VAO<F1E*3HB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$U('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E)E;6]V92(*
M;7-G<W1R(")3=7!R:6UI<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E-U<')I;6ER
M(&)L;V,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E-U<')I;6ER(&-O
M;'5M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")3=7!R
M:6UI<B!L82!F;W)M871A8VGS(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,S8*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E-U<')I;6ER
M(&QA('!A<F5L;&$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`U"FUS
M9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R
M87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B4W5P<FEM:7(@;&$@<V5Q_.AN8VEA
M(&1E<V%D82!D96P@9&ER96-T;W)I('1E;7!O<F%L(&1E;"!S97)V:61O<BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#$*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4W5P<FEM:7(@
M96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@
M9&]C=6UE;G0B"FUS9W-T<B`B4W5P<FEM:7(@87%U97-T(&YO9&4@9&5L(&1O
M8W5M96YT(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M-@IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4W5P<FEM:7(@;"=U<W5A
M<FDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(E-U
M<')I;6ER(&PG=7-U87)I.B`E<R(*"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C
M+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(DYO(',G:&$@<&]G=70@
M<F5S<&]N9')E(&$@;&$@<V]LMVQI8VET=60N($-O9&D@9"=E<G)O<B!R971O
M<FYA=#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T.0IM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R(").;R!S)VAA('1R;V)A="!E;"!S97)V96D@<V]LMVQI8VET870N
M(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S0@;&EB+TAO<F1E+G!H<#HT.#<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D("<E<R<@;F]T('-P
M96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").;R!S)VAA
M(&5S<&5C:69I8V%T(&5L("<E<R<@;F5C97-S87)I(&5N(&QA(&-O;F9I9W5R
M86-I\R!D92`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S0W(&QI8B]61E,O
M<W%L+G!H<#HU.3<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S$P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I
M960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYO(',G:&$@97-P
M96-I9FEC870@96P@)R5S)R!N96-E<W-A<FD@<&5R(&$@;&$@8V]N9FEG=7)A
M8VGS(%9&4RXB"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I
M960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3F\@<R=H82!E<W!E8VEF
M:6-A="!E;"`G)7,G(&YE8V5S<V%R:2!P97(@82!L82!C;VYF:6=U<F%C:?,N
M(@H*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R.`IM<V=I9"`B
M4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B0V%M<"!S;VRW;&EC:71A="(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS,SD@;&EB
M+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-0HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C0T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHQ,#$*;7-G:60@(E)E<V5T(@IM<V=S='(@(E)E:6YI8VEA(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A
M<W-W;W)D(@IM<V=S='(@(E)E:6YI8VEA<B!L82!C;VYT<F%S96YY82(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(E)E:6YI8VEA<B!L82!C;VYT<F%S96YY
M82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8U"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(E)E<W5L=&%T<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,C$*
M;7-G:60@(E)E<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,3D*(RP@9G5Z>GD*;7-G:60@(E)E
M<W5L=',Z(@IM<V=S='(@(E)E<W5L=&%T<R(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM
M<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5&]R;F$@82!O<&-I
M;VYS(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y-PIM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:?,B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E)E
M<W1A=7)A<B!L82!C;VYF:6=U<F%C:?,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,P"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS
M9W-T<B`B3W!C:6]N<R!D92!L)V5D:71O<B!D92!T97AT(&5N<FEQ=6ET(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM
M<V=S='(@(D5N:6=M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1R
M971A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3D*;7-G:60@(E)I9VAT
M(&AE861E<B(*;7-G<W1R(")#87#G86QE<F$@9')E=&$B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@
M(E9A;&]R<R!D92!L82!D<F5T82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(E!R;W!I971A=',@9&4@;&$@9FEL82XN+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED
M(")2;VQE(@IM<V=S='(@(D9U;F-I\R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B"FUS
M9W-T<B`B4F]M86YI82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#@*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B1VER87(@
M,3@P(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P
M-0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B1VER87(@82!L)V5S<75E
M<G)A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q
M,0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(D=I<F%R(&$@;&$@9')E
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P
M:65T871S(&1E(&QA(&9I;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE
M<R(*;7-G<W1R(")0<F]P:65T871S(&1E(&QA(&9I;&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W
M<SHB"FUS9W-T<B`B1FEL97,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T
M<B`B4F5G;&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")!<&%R96EX97)A
M;B!R96=L97,@96YT<F4@=&]T97,@;&5S(&9I;&5S(&D@8V]L=6UN97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@
M;VYL>2(*;7-G<W1R(")!<&%R96EX97)A;B!R96=L97,@;F]MZ7,@96YT<F4@
M8V]L=6UN97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>2(*;7-G<W1R(")!<&%R96EX97)A;B!R96=L97,@;F]M
MZ7,@96YT<F4@9FEL97,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS
M9VED(")2=6XB"FUS9W-T<B`B17AE8W5T87(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B1F5D97)A8VGS(%)U<W-A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,`IM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(E)W86YD82(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B4VEG;F%T=7)A(&-R:7!T;V=RX&9I8V$@86UB
M(%,O34E-12(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS
M9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B36ES<V%T
M9V4@>&EF<F%T(&%M8B!3+TU)344B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L
M+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R("),)V%U=&5N=&EC86-I\R!305-,(&YO(&5S=.`@
M9&ES<&]N:6)L92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4P
M"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(DUI<W-A=&=E<FEA(%--
M4R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(DEN=.AR<')E="!D)V]R9')E<R!344PB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S8Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-(
M(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(LA8250B"@HC.B!L:6(O
M87!I+G!H<#HQ,S(*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B26YTZ')P
M<F5T(&0G;W)D<F5S(%-13"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(D1S+B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#<*
M;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$*
M;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!#
M:')I<W1O<&AE<B!I($YE=FES(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y"FUS9VED(")386EN="!,=6-I82(*;7-G
M<W1R(")386EN="!,=6-I82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0M4&EE<G)E+65T+4UI<75E;&]N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M-`IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`B4V%I;G0@5FEN8V5N="!I(&QE<R!'<F5N861I;F5S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B
M4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(DUA=&5I>"!M87)C("A?<V5L
M9BDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4Q"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,38*;7-G:60@(E-A
M;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]MZ2!I(%!R[6YC
M:7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3
M871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4')O=F7O9&]R(&1E('-A=.AL
MMVQI="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#$*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")!<N!B:6$@
M4V%U9&ET82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM
M<V=I9"`B4V%V92(*;7-G<W1R(")$97-A(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*
M;7-G<W1R(")$97-A("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`G
M)7,G(@IM<V=S='(@(D1E<V$@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B1&5S82!L97,@
M;W!C:6]N<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S`*;7-G:60@
M(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R
M:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@HB1&5S974@;&$@8V]N9FEG=7)A8VGS(&=E;F5R861A(&-O
M;2!U;F$@<V5Q_.AN8VEA(%!(4"!E;B!E;"!D:7)E8W1O<FD@(@HB=&5M<&]R
M86P@9&5L('-E<G9I9&]R+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C8Y"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(E,G:&$@9&5S870@;&$@8V]N9FEG=7)A8VGS(&1E("5S
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDP"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@)R5S)RXB"FUS9W-T<B`B4R=H82!D97-A="!L82!S97'\Z&YC:6$@86-T
M=6%L:71Z861A(&1E(&-O;F9I9W5R86-I\R!A.B`G)7,G+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")38V%T
M=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B5&5M<&5S=&5S(&1I<W!E<G-E<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*
M;7-G<W1R(")#:>AN8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")#97)C82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-S8*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@
M(DUO=&]R<R!D92!C97)C82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#0X
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")396%R8VAI;F<@2&]R9&4@
M87!P;&EC871I;VYS(&EN("5S(@IM<V=S='(@(D]P8VEO;G,@9&4@8V5R8V$B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S"B,L(&9U>GIY"FUS9VED(")3
M96%R8VAI;F<@9V5T=&5X="!B:6YA<FEE<RXN+B(*;7-G<W1R(")/<&-I;VYS
M(&1E(&-E<F-A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S$*;7-G:60@
M(E-E;&5C="!&:6QE<R(*;7-G<W1R(")396QE8V-I;VYA<B!E;',@87)X:75S
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")396QE8V-I;VYA<B!U;F$@
M9&%T82(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED
M(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4V5L96-C:6]N87(@
M=6X@9W)U<"!Q=64@=G5L9W5E=2!A9F5G:7(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS
M9W-T<B`B4V5L96-C:6]N974@=6X@;F]U('!R;W!I971A<FDB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E
M<G9E<B(*;7-G<W1R(")396QE8V-I;VYE=2!U;B!S97)V:61O<B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U
M<V5R('1O(&%D9"(*;7-G<W1R(")396QE8V-I;VYE=2!U;B!U<W5A<FD@<75E
M('9U;&=U974@869E9VER(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-C$*
M;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")3
M96QE8V-I;VYE=2!T;W1S(&5L<R!E;&5M96YT<R!D92!L82!D871A+B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX,3$*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B4V5L96-C:6]N974@=6X@;V)J
M96-T92(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C8VEO;F5U(&5L
M<R!C87+@8W1E<G,@<75E(&YE8V5S<VET974@9&4@;&5S(&-A<V5L;&5S(&1E
M('-O=&$N(%!O9&5U("(*(F-O<&EA<BUL;W,@:2!E;F=A;GAA<BUL;W,@9&4@
M;"?@<F5A(&1E('1E>'0N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@
M(E-E;&5C8VEO;F%R(&5L(&1E;&EM:71A9&]R(&1E(&QA(&1A=&$Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F%R(&5L(&9O<FUA="!D
M92!L82!D871A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.#D*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.B(*;7-G<W1R(")396QE8V-I;VYA<B!L82!I9&5N=&ET870@
M<75E('9O;&5U('%U92!C86YV:6%R.B(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*
M;7-G<W1R(")396QE8V-I;VYA<B!E;"!D96QI;6ET861O<B!D92!L)VAO<F$Z
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C
M="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F%R(&5L(&9O
M<FUA="!D92!L)VAO<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHV-`IM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S
M='(@(E-E;&5C8VEO;F%R(&1O<R!C86UP<R!Q=64@8V]I;F-I9&5I>&EN+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.38*;7-G:60@(E-E;&5C="!Y
M;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4V5L96-C:6]N87(@;&$@8V]M
M8FEN86-I\R!D92!C;VQO<G,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(S.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*
M;7-G<W1R(")396QE8V-I;VYA<B!L)VED:6]M82!P<F5F97)I=#HB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0
M<F]B;&5M(%)E<&]R="(*;7-G<W1R(")%;G9I87(@;"=I;F9O<FUE(&1E;',@
M<')O8FQE;65S(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B16YV:6%R(%--4R(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3,*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S$T"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")3
M96YS;W(Z("(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS
M9VED(")397!T96UB97(B"FUS9W-T<B`B4V5T96UB<F4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO
M;G1E;F5G<F\B"FUS9W-T<B`B4^AR8FEA(&D@36]N=&5N96=R;R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M
M8F5R(@IM<V=S='(@(D[Z;65R;R!D92!SZ')I92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQE<R!D861E<R!D96P@<V5R
M=FED;W(@<_-N(&EN8V]R<F5C=&5S(&\@;F\@97-T86X@9&ES<&]N:6)L97,N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G
M:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B2&$@8V%D=6-A="!L
M)VED96YT:69I8V%D;W(@9&4@<V5S<VGS+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,S$R"FUS9VED(")3970B"FUS9W-T<B`B1&5F:6YE:7@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB1&5F:6YE:7@@;&5S(&]P8VEO;G,@
M<75E('5S('!E<FUE=&5N(')E:6YI8VEA<B!L82!C;VYT<F%S96YY82!S:2!M
M86D@(@HB;"=O8FQI9&5U+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")$969I;FEU
M(&5L<R!S97)V:61O<G,@<F5M;W1S(&$@<77H('9O;&5U(&%C8V5D:7(@9&5S
M(&1E;"!P;W)T86PN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS
M9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(B(*(D1E9FEN:74@96P@=F]S=')E
M(&ED:6]M82!P<F5F97)I="P@;&$@>F]N82!H;W+@<FEA(&D@;&5S(&]P8VEO
M;G,@9&4@9&%T82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O
M<'1I;VYS+B(*;7-G<W1R("(B"B)$969I;FEU(&PG87!L:6-A8VGS(&0G:6YI
M8VDL(&QA(&-O;6)I;F%C:?,@9&4@8V]L;W)S+"!E;"!R969R97-C86UE;G0@
M9&4@;&5S("(*(G#@9VEN97,@:2!A;'1R97,@;W!C:6]N<R!D92!V:7-U86QI
M='IA8VGS+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*;7-G:60@
M(E-E='5P(@IM<V=S='(@(D-O;F9I9W5R86-I\R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C,Y"FUS9VED(")3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(DAI(&AA('-E<?SH;F-I97,@
M9"=A8W1U86QI='IA8VGS(&1E(&QA(&-O;F9I9W5R86-I\R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S@*;7-G:60@(E-E=F5R86P@;&]C
M871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@
M(DAI(&AA(&1I=F5R<V5S('5B:6-A8VEO;G,@<&]S<VEB;&5S(&%M8B!E;"!P
M87+@;65T<F4Z("(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,#,*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y
M8VAE;&QE<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#(*;7-G
M:60@(E-H;W!P:6YG(@IM<V=S='(@(D-O;7!R97,B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*
M;7-G<W1R(")297-U;2!B<F5U(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0S-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R
M(&UO<W0@;&EN:W,_(@IM<V=S='(@(E9O;&5U(&1E9FEN:7(@;&5S(&-L875S
M(&0G86-CZ7,@<&5R(&$@;&$@;6%J;W(@<&%R="!D)V5N;&QAYV]S/R(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,CDR('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM
M<V=S='(@(DUO<W1R82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-3@*
M;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B36]S=')A(&QE<R!D:69E<NAN8VEE<R!E;G1R92!L82!C
M;VYF:6=U<F%C:?,@9&5S861A(&D@;&$@;F]V82XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#@P"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(E9O;&5U('9I<W5A;&ET>F%R(&PG
M:&]R82!D92!L82!D87)R97)A('-E<W-I\R!E;B!I;FEC:6%R/R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K
M965P(&]R:6=I;F%L(@IM<V=S='(@(DUO<W1R82!L)V]P8VGS(&1E(&-O;G-E
M<G9A<B!L)V]R:6=I;F%L(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,3$*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DUO<W1R82!E;"!C87!T=7)A
M9&]R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q-0IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")6;VQE=2!V
M:7-U86QI='IA<B!L82!B87)R82!D92!M96[Z(&0G;W!E<F%C:6]N<R!D92!T
M875L83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM
M<V=S='(@(E9O;&5U('9I<W5A;&ET>F%R(&5L(&UE;OH@)7,@9&4@;"=E<W%U
M97)R83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3@*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S=')A(&5L(&1IX&QE9R!D92!P
M<F]P:65T871S(&1E(&-E;+=L82!D92!T875L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B36]S
M=')A(&5L(&1IX&QE9R!D92!P<F]P:65T871S(&1E('1A=6QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y
M"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B36]S=')A(&5L(&1IX&QE9R!D92!P<F]P:65T871S(&1E(&9I
M;&$@9&4@=&%U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(DUO<W1R82!E;"!D:>!L96<@9&4@
M<')O<&EE=&%T<R!D92!I;6%T9V4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B36]S=')A(&QA(&/@
M<G)E9V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")2=6EX871S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B4G5I>&%T<R!A('!R:6UE<F$@:&]R82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS
M9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4G5I>&%T<R!C87`@86P@=&%R
M9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P
M"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R(")2=6EX
M871S(&$@;&$@<F]D86QI82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.C,Y.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(E)E9'7O=2(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C8Y,B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HW-30*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M.#$R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C@W-`HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,#D@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z.30V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDW-"!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#`T"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B4')I;65R(')E9'7O=2!O(&%P87)T974@96PH<RD@
M8FQO8RAS*2!D96P@8V]S=&%T(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU
M<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(D1O;F5U+79O<R!D
M)V%L=&$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED
M(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B
M"FUS9W-T<B`B4VEG;F%T=7)A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B
M06QG;W)I<VUE(&1E('-I9VYA='5R82(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#8*;7-G:60@(E-I;F=A<&]R92(*
M;7-G<W1R(")3:6YG87!U<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.38@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$R
M,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#8@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y,C@@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C$*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-CD@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C4*;7-G:60@(E-I>F4B"FUS9W-T<B`B36ED82(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z.0IM<V=I9"`B4VMI<"!-
M86EN=&5N86YC92(*;7-G<W1R(")/;65T(&UA;G1E;FEM96YT(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C0S,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@T('!O
M+W1R86YS;&%T:6]N+G!H<#HV-C8*(SH@<&\O=')A;G-L871I;VXN<&AP.C@V
M,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(R,PIM<V=I9"`B4VMI<'!E9"XN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")%<VQO=N!Q
M=6EA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P.`IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B17-L;W;H;FEA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G
M:60@(E-N;W<B"FUS9W-T<B`B3F5V861A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-N;W<@4VAO=V5R(@IM
M<V=S='(@(EC@9F5C(&1E(&YE=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B6.!F96-S(&1E(&YE=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS
M9W-T<B`B6.!F96-S(&1E(&YE=2!A('!R:6UE<F$@:&]R82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W
M(%-H;W=E<G,@3&%T92(*;7-G<W1R(")8X&9E8W,@9&4@;F5U(&-A<"!A;"!T
M87)D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S8*;7-G:60@(E-N;W<@
M9&5P=&@Z("(*;7-G<W1R(")'<G5I>"!D92!N974Z("(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@P"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z("(*;7-G<W1R(")%<75I=F%L96YT(&1E(&QA(&YE=2!E;B!A:6=U83H@
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(P,@IM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(DEL;&5S(%-A
M;&]M\R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,30*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]MX&QI82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M
M<R(*;7-G<W1R(")#86[G;VYS(&D@<&]E;65S(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y,C0*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S
M='(@(E-E;&5C8VGS(&5N(&5L('-E;G1I="!D92!L82!C;&%S<VEF:6-A8VGS
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,38@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#8*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4U."!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3@X"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R
M(")!9')EYV$@9"=O<FEG96XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS
M9W-T<B`B4W5D+>!F<FEC82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP
M"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B
M4W5D+65U<F]P974@*$E33RTX.#4Y+3,I(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q"FUS9VED(")3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")'
M9?)R9VEA(&1E;"!3=60@:2!L97,@:6QL97,@4V%N9'=I8V@@9&5L(%-U9"(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-F
M97)I('-U9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M(@IM<V=S='(@(D5S<&%I(&5N=')E(&-E;+=L97,@861J86-E;G1S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G
M:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB
M"FUS9W-T<B`B17-P86D@96YT<F4@96P@8V]N=&EN9W5T(&D@96P@8V]N=&]R
M;B!D92!L82!C96RW;&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"FUS
M9VED(")3<&%C97(B"FUS9W-T<B`B17-P86EA9&]R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(D5S<&%I870B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG
M(&%N9"!P861D:6YG(@IM<V=S='(@(D5S<&%I870@:2!F87)C:6UE;G0B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,`IM
M<V=I9"`B4W!A:6XB"FUS9W-T<B`B17-P86YY82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HY-@IM<V=I9"`B4W!A;2(*;7-G<W1R(")#;W)R974@
M8G)O<W-A(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3
M<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")%<V-R:7!T=7)A(&1E
M(&-A<N!C=&5R<R!E<W!E8VEA;',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL
M(@IM<V=S='(@(D1I=FED:7(@8V5LMVQA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(D1I=FED:7(@8V]L=6UN82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R(")$:79I9&ER(&9I;&$B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")%<W!O
M<G1S(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30Q"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S(*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(D5S=.!N9&%R
M9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4
M<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3DT(&QI8B](;W)D92]&;W)M+G!H<#HR.#`W"FUS9VED(")3=&%R="!Y
M96%R(@IM<V=S='(@(D%N>2!D)VEN:6-I(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S
M='(@(D5S=&%T(&\@<')O=NUN8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")%<W1A
M="(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W1A='5S(&9O<B!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#$S"FUS9VED(")3=&]R86=E(&9O<FUA
M="(*;7-G<W1R(")&;W)M870@9"=E;6UA9V%T>F5M871G92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3<R"FUS9VED(")3=')E970@061D<F5S
M<R(*;7-G<W1R(")!9')EYV$@<&%R=&EC=6QA<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B0F%R<F%T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(DQL:7-T82!D92!C
M861E;F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(D5L:6UI;F5U
M(&5L(&1O;6EN:2!D92!L)V%D<F7G82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#
M4U-=(@IM<V=S='(@(D5S=&EL(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B
M1&<N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N
M(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&5L('-U8F1I<F5C=&]R:2`@)R5S
M)RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM
M<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!<W-U;7!T92(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q
M,@IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D5N=FEA(@H*(SH@<VEG;G5P+G!H
M<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D
M(')E<75E<W0@=&\@861D("<E<R<@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N
M;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R
M;W9E9"XB"FUS9W-T<B`B(@HB4R=H82!T<F%MZ',@=6YA('-O;+=L:6-I='5D
M('!E<B!A9F5G:7(@)R5S)R!A;"!S:7-T96UA+B!.;R!P;V1E=2!I;FEC:6%R
M(&QA("(*(G-E<W-I\R!F:6YS('%U92!S)VAA9VD@87!R;W9A="!L82!S;VRW
M;&EC:71U9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B4W5B[6YD97@B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U(&QI8B](;W)D92].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*
M;7-G<W1R("+(>&ET(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O
M('1H92!S>7-T96TN(@IM<V=S='(@(E,G:&$@869E9VET(&-O<G)E8W1A;65N
M="`G)7,G(&%L('-I<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("<E<R<@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")3)VAA;B!E;&EM:6YA="!C;W)R96-T86UE;G0@9&5L('-I<W1E;6$@;&5S
M(&1A9&5S(&1E(&PG=7-U87)I("<E<R<N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HX,2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"`G)7,G+B(*;7-G
M<W1R(")3)VAA('-U<')I;6ET(&-O<G)E8W1A;65N="`G)7,G+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E;6]V960@)R5S)R!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(E,G:&$@<W5P<FEM:70@8V]R<F5C=&%M96YT("<E<R<@9&5L('-I
M<W1E;6$N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T
M;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@HB4R=H82!R97-T875R870@8V]R
M<F5C=&%M96YT(&QA(&-O;F9I9W5R86-I\RX@06-T=6%L:71Z974@<&5R('9E
M=7)E(&5L<R`B"B)C86YV:7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z-34@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E,G
M:&$@9&5S870@8V]R<F5C=&%M96YT(&QA(&-O;F9I9W5R86-I\R!D92!C\G!I
M82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B4R=H82!D97-A="!C;W)R96-T
M86UE;G0@;"=A<GAI=2!D92!L82!C;VYF:6=U<F%C:?,@9&4@8_)P:6$@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"`G)7,G(@IM<V=S='(@(E,G
M:&$@86-T=6%L:71Z870@8V]R<F5C=&%M96YT("<E<R<B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S(@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B4R=H82!E<V-R:70@8V]R<F5C=&%M96YT("<E<R<B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`T"FUS9VED
M(")3=61A;B(*;7-G<W1R(")3=61A;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB
M"FUS9W-T<B`B4F5S=6TB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C8*
M;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-O<G1I9&$@9&5L('-O;"(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW,0IM<V=I9"`B4W5N(%-E="(*;7-G
M<W1R(")0;W-T82!D96P@<V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-U;FYY(@IM<V=S='(@(D%S<V]L
M96QL870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS
M9VED(")3=6YR:7-E(@IM<V=S='(@(E-O<G1I9&$@9&5L('-O;"(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B4V]R=&ED82!D96P@
M<V]L+U!O<W1A(&1E;"!S;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`W"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B4V]R=&ED82!D
M96P@<V]L.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q
M"FUS9VED(")3=6YS970B"FUS9W-T<B`B4&]S=&$@9&5L('-O;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3`*;7-G:60@(E-U;G-E=#H@
M(@IM<V=S='(@(E!O<W1A(&1E;"!S;VPZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B
M"FUS9W-T<B`B4W5P97+M;F1E>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT,S0*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B07-S:7-TZ&YC:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$U"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS
M9W-T<B`B0V]G;F]M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P.0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE
M;B(*;7-G<W1R(")3=F%L8F%R9"!I($IA;B!-87EE;B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D*;7-G:60@(E-W
M87II;&%N9"(*;7-G<W1R(")3=V%Z:6S@;F1I82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4*;7-G:60@(E-W961E
M;B(*;7-G<W1R(")3=>AC:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T
M<B`B4W7O<W-A(@H*(SH@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z.3<*
M;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M17)R;W(@9&4@<VEN=&%X:2!E;B!E;',@=&5R;65S(&1E(&-E<F-A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.`IM
M<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A
M(,!R86(@4VER:6%N82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4W"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(E1E;7!E<W1A
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*
M;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(E1E;7!E<W1A(&D@
M=F5N=/-S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3D*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(E1E;7!E<W1E<R(*"B,Z
M(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*
M;7-G<W1R(")!<GAI=2!44U8B"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP
M.C$S-@HC+"!F=7IZ>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`B5&%U;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E!R;W!I971A
M=',@9&4@=&%U;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!I971A=',@9&4@=&%U;&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-`IM<V=I
M9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@
M0VAI;F$B"FUS9W-T<B`B5&%I=V%N+"!P<F]V[6YC:6$@9&4@;&$@6&EN82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C4*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%D:FEK:7-T86XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,U
M"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(E1A;GK@;FEA+"!297#Z8FQI8V$@56YI9&$@9&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z
M(@IM<V=S='(@(D]B:F5C=&EU.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-S$*;7-G:60@(E1A<VMS(@IM<V=S='(@(E1A<W%U97,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE
M($YU;6)E<B(*;7-G<W1R(").^FUE<F\@9&4@=&5LZ&9O;B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@X"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z
M("(*;7-G<W1R(")496UP97)A='5R82!D=7)A;G0@;&$@9&%R<F5R82!H;W)A
M.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q,@IM<V=I9"`B5&5M<&5R
M871U<F4B"FUS9W-T<B`B5&5M<&5R871U<F$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")496UP97)A='5R93H@(@IM<V=S
M='(@(E1E;7!E<F%T=7)A.B`B"@HC.B!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP
M.C(Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@)R5S
M)R!N;W0@9F]U;F0N(@IM<V=S='(@(DYO(',G:&$@=')O8F%T(&QA('!L86YT
M:6QL82`G)7,G+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A
M8VGS(&1E('!L86YT:6QL97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M,0IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(DYO;>ES
M('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(D%L:6YE
M86-I\R!D92!T97AT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")!;&EN96%T
M(&$@9&%L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(D1J+B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R
M(")486EL86YDZ',@*%1)4RTV,C`I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-`IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`B5&%I;.!N9&EA(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDP,PIM
M<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@)7,@:&5L<"!F:6QE(&9O<B`E<R!D;V5S;B=T('EE="!E
M>&ES="X@0W)E871I;F<@82!N97<@;VYE+B(*;7-G<W1R("(B"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z-S,W"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("),)V5X=&5N<VGS($944"!N;R!E<W3@
M(&1I<W!O;FEB;&4N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N
M(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")%;"!M
M;W1O<B!D)VEN=&5G<F%C:?,@2&]R9&4O2V]L86(@;F\@<&5R;65T(&PG^G,@
M9&4@7"(E<UPB(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(Y"FUS
M9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY(@IM<V=S='(@(DQA(&-L87-S92!-86EN=&5N86YC93HZ(&YO
M(',G:&$@8V%R<F5G870@8V]R<F5C=&%M96YT(R,B"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B4R=H82!T86YC
M870@;&$@9FEN97-T<F$@9"=O<&-I;VYS+B!3;W)T:6YT(&1E;"!S:7-T96UA
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ-3@@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HQ-CD@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ.#`*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HQ.3(@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,#,@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HR,C$*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S,@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR-S(*;7-G:60@(B(*(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N
M<RXB"FUS9W-T<B`B(@HB4VD@=F]L974@=71I;&ET>F%R(&5L<R!P97)M:7-O
M<RP@;"=A9&UI;FES=')A9&]R(&AA(&1E(&-O;F9I9W5R87(@=6X@;6]T;W(@
M(@HB9&4@<&5R;6ES;W,@<&5R;6%N96YT+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DYO;>ES(&5L(&-O;G1O<FX@:6YF
M97)I;W(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X
M"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB
M9&%T86)A<V4N(@IM<V=S='(@(B(*(D5L(&[Z;65R;R!I9&5N=&EF:6-A9&]R
M(&1E;"!C;VYT86-T92!N;R!S)VAA(&5S<&5C:69I8V%T+"!S)VAA(&1E:7AA
M="!E;B`B"B)B;&%N8R!O(&YO(',G:&$@=')O8F%T(&$@;&$@8F%S92!D92!D
M861E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")3)VAA(&%F96=I="!C;W)R
M96-T86UE;G0@96P@8V]N=&%C=&4@82!L82!L;&EB<F5T82!D)V%D<F5C97,N
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T.0IM<V=I9"`B(@HB
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB17,@
M;F5C97-S:71A(&5L(&)L;V,@9&4@<VEG;F%T=7)E<R!01U`@<V5P87)A="!P
M97(@=F5R:69I8V%R(&5L(&UI<W-A=&=E("(*(G-I9VYA="XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N
M(@IM<V=S='(@(B(*(DPG:61E;G1I9FEC861O<B!D92!L82!L;&ES=&$@9&4@
M9&ES=')I8G5C:?,@;F\@<R=H82!E<W!E8VEF:6-A="P@<R=H82!D96EX870@
M(@HB96X@8FQA;F,@;R!N;R!S)VAA('1R;V)A="!A(&QA(&)A<V4@9&4@9&%D
M97,N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R(").;R!S)VAA(&5S<&5C:69I8V%T(&QA(&QL:7-T82!D92!D
M:7-T<FEB=6-I\RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0N<&AP.C$Q,PIM<V=I
M9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3&5S(&-A<F%C=&5R[7-T:7%U97,@
M9&5L('AI9G)A=&=E(&5X:6=E:7AE;B!U;F$@8V]N;F5X:?,@=V5B(&9I86)L
M92XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-2!L:6(O2&]R9&4N<&AP.C0X.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!A("5S('-E='1I;F<N(@IM<V=S='(@(DPG87)X:74@)7,@:&%U<FEA(&1E
M(&-O;G1E;FER('5N('!A<N!M971R92`E<RXB"@HC.B!L:6(O2&]R9&4N<&AP
M.C$V."!L:6(O2&]R9&4N<&AP.C0W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*
M;7-G<W1R("),)V%R>&EU("5S(&AA=7)I82!D92!C;VYT96YI<B!A;&=U;G,@
M<&%RX&UE=')E<R`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$U,@HC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N(@IM<V=S='(@(DPG87)X:74@;F\@8V]N=&5N:6$@9&%D97,N(@H*
M(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(V,`IM<V=I9"`B5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(DPG87)X:74@;F\@8V]N=&5N:6$@
M9&%D97,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T
M:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*(D$@8V]N
M=&EN=6%C:?,@97,@<')E<V5N=&5N(&QE<R!C87#G86QE<F5S(&0G87%U97-T
M(&UI<W-A=&=E+VUI<W-A=&=E(')F8S@R,BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L
M;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H
M($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H
M870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@
M97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R
M(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF
M("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L
M>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A
M=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W
M87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@
M=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(E,G
M:&$@8V]N<W1A=&%T('%U92!E;"!M;V1E(&1E('!A;G1A;&QA(&-O;7!L971A
M(&3S;F$@<')O8FQE;65S(&%M8B!);G1E<FYE="`B"B)%>'!L;W)E<B!A(&-A
M=7-A(&0G97)R;W)S(&5N(&5L(&YA=F5G861O<B!Q=64@;F\@:&5M('!O9W5T
M(')E<V]L9')E+B!0;W0@<V5R("(*(G%U92!V:7-U86QI='IE=2!B<F]S<V$L
M('5S(&UA;G%U:6X@9G5N8VEO;G,@96X@;"=E9&ET;W(@:2]O('%U92!E;"!N
M879E9V%D;W(@(@HB=7,@9F%L;&D@9&4@;6%N97)A(&%L96%T\G)I82X@4VD@
M=&5N:74@96P@<VES=&5M82!7:6YD;W=S(#EX(.ES(&UO;'0@(@HB<')O8F%B
M;&4@<75E(&5S('!R;V1U96EX:2!U;B`G97)R;W(@9&4@<')O=&5C8VGS(&=E
M;F5R86PG(&D@:&%G=65U(&1E("(*(G)E:6YI8VEA<B!D92!N;W4N(%-I+"!T
M;W0@:2!A<75E<W0@861V97)T:6UE;G0L(&5N8V%R82!V;VQE=2!P<F]V87(@
M;"=E9&ET;W(@(@HB9&4@<&%N=&%L;&$@8V]M<&QE=&$L('!R96UE=2!$)V%C
M;W)D+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DW('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C,U"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!H96QP(&9I
M;&4@)7,@9&ED;B=T('-T87)T('=I=&@@/#]X;6PB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.C@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M4R=H82!S=7!R:6UI="!L82!I9&5N=&ET870@7"(E<UPB+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G
M:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DYO;>ES(&5L
M(&-O<W1A="!E<W%U97)R92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$T-@IM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(DQA('5B:6-A8VGS(&1E;"!B:6YA<FD@1VYU4$<@<R=H82!D)VEN
M9&EC87(@82!L82!C;&%S<V4@0W)Y<'1?<&=P+B(*"B,Z(&QI8B](;W)D92]-
M24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H
M87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T
M:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB
M"FUS9W-T<B`B(@HB4R=H82!M;W-T<F%T(&5L(&UI<W-A=&=E(&5N=FEA="!E
M;"`E<R!A("5S(&%M8B!L)V%S<W5M<'1E(%PB)7-<(BX@06EX\B!N;R`B"B)G
M87)A;G1E:7@@<75E(',G:&%G:2!L;&5G:70@;R!E;G3H<R!E;"!M:7-S871G
M92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM
M<V=S='(@(D5L(&YO;2!Q=64@<R=H82!D)W5T:6QI='IA<B!E;B!E;FQL8>=A
M<B!A;6(@0W)E87(@<.!G:6YA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER
M960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R
M(")%<R!N96-E<W-I=&$@96P@;?)D=6P@;W!E;G-S;"!P97(@82!L82!C;&%S
M<V4@2&]R9&5?0W)Y<'1?<VUI;64N(@H*(SH@;&EB+TAO<F1E+U!R969S+G!H
M<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@
M7"(E<UPB(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X
M8V5E9&5D('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@
M(B(*(DYO(',G:&$@<&]G=70@9&5S87(@;&$@<')E9F5RZ&YC:6$@7"(E<UPB
M('!E<G%UZ"!L82!I;F9O<FUA8VGS('%U92!C;VYT96YI82`B"B)S=7!E<F%V
M82!L82!M:61A(&W@>&EM82!P97)M97-A+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=V5B8W!P
M+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B).
M;R!S)VAA('1R;V)A="!E;B!E;"!S:7-T96UA(&5L('!R;V=R86UA('5S870@
M<&5R('9I<W5A;&ET>F%R(&%Q=65S="!T:7!U<R`B"B)D92!D861E<R`H)7,I
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY
M(@IM<V=S='(@(DYO;>ES(&5L<R!C;W-T871S(&1R970@:2!E<W%U97)R92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R
M(").;VWI<R!E;"!C;W-T870@9')E="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E,G:&$@<W5P<FEM
M:70@96P@<V5R=FED;W(@7"(E<UPB+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R
M<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@
M7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R(")3)VAA(&1E<V%T(&5L
M('-E<G9I9&]R(%PB)7-<(BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H
M87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")3)VAA(&5L:6UI;F%T(&QA('-O
M;+=L:6-I='5D(&0G86QT82!D92`E<RXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HR.3`*(RP@9G5Z>GD*;7-G:60@(E1H92!S<&5C:69I960@
M<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(").;R!E>&ES=&5I>"!L82!F
M:6QA(&5S<&5C:69I8V%D82XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3`X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DYO(&5X:7-T96EX(&PG87)X:74@
M=&5M<&]R86P@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O
M='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(DYO;>ES(&5L<R!C;W-T871S('-U
M<&5R:6]R(&D@:6YF97)I;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R(").;VWI<R!E;"!C;W-T870@<W5P97)I;W(B"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,S`W"FUS9VED(")4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B
M4R=H86X@<&5R9'5T(&QE<R!D861E<R!C87)R96=A9&5S(&1E<R!D96P@<&%S
M(&%N=&5R:6]R+B(*"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R(&QI
M8B](;W)D92]$871A+V-S=BYP:'`Z,C0P"FUS9VED(")4:&4@=7!L;V%D960@
M9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@9&5S87(@;"=A<GAI=2!C87)R96=A="XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,#<@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,0IM<V=I9"`B5&AE('=E871H97(N
M8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D5L(&)L;V,@
M=V5A=&AE<BYC;VT@;F\@97-TX"!D:7-P;VYI8FQE+B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE;65S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B3F\@
M<R=H82!T<F]B870@96P@9&ER96-T;W)I(%1H96UE<R`G)7,G+B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYO(&AI(&AA(&-A<"!O<&-I
M\R!D:7-P;VYI8FQE+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HS-#`*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(").;R!H:2!H82!C87`@<&%R="!Q
M=64@97,@<'5G=6D@;6]S=')A<B!E;B!L[6YI82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#`V"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S
M<R!T:&%N("5S+B(*;7-G<W1R("(B"B)!<75E<W0@8V%M<"!C;VYTZ2!M87-S
M82!C87+@8W1E<G,N($AE=2!I;G1R;V1U[W0@)7,@8V%RX&-T97)S(&D@;B=H
M974@(@HB9"=I;G1R;V1U:7(@;65N>7,@9&4@)7,N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$P-C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@9&]E
M<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R("5S+B(*;7-G<W1R("(B
M"@HC.B!S:6=N=7`N<&AP.C4S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T
M96TN("5S+B(*;7-G<W1R(")(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!A
M9F5G:7(@)R5S)R!A;"!S:7-T96UA.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(DAI(&AA(&AA9W5T('5N('!R;V)L96UA(&5N(&%F96=I<B`G)7,G(&%L('-I
M<W1E;6$Z("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG
M(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"B)(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!E<V)O<G)A<B!D96P@
M<VES=&5M82!L97,@9&%D97,@9&4@;"=U<W5A<FD@)R5S)RX@(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B2&D@:&$@:&%G=70@=6X@<')O8FQE;6$@96X@<W5P
M<FEM:7(@)R5S)R!D96P@<VES=&5M83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S(@IM<V=S='(@(DAI(&AA(&AA9W5T
M('5N('!R;V)L96UA(&5N(&%C='5A;&ET>F%R("<E<R<Z("5S(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.C@W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E
M<R!W87,@=7!L;V%D960N(@IM<V=S='(@(DAI(&AA(&AA9W5T('5N('!R;V)L
M96UA(&5N(&-A<G)E9V%R(&PG87)X:74Z(&YO(',G:&$@8V%R<F5G870@)7,N
M(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)(:2!H82!H
M86=U="!U;B!P<F]B;&5M82!E;B!C87)R96=A<B!L)V%R>&EU.B!E;"`E<R!E
M<F$@<W5P97)I;W(@82!L82!M:61A("(*(FW@>&EM82!P97)M97-A("@E(&)Y
M=&5S*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@U"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N(@IM<V=S='(@(B(*(DAI(&AA(&AA9W5T('5N('!R;V)L96UA(&5N(&-A
M<G)E9V%R(&PG87)X:74Z(&YO;>ES(',G:&$@8V%R<F5G870@<&%R8VEA;&UE
M;G0@(@HB96P@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E
M<G)O<B!E;B!M;W-T<F%R(&%Q=65S=&$@<&%R="!D96P@;6ES<V%T9V4B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B
M4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&EM<&]R=&%R(&QE<R!D861E<R!D
M92!C;VYT86-T92XB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD
M87(@9&%T82XB"FUS9W-T<B`B4R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&EM
M<&]R=&%R(&QE<R!D861E<R!I0V%L96YD87(N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW.0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN
M('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T
M(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(E,G:&$@<')O9'7O
M="!U;B!E<G)O<B!E;B!E;"!F;W)M=6QA<FD@9&4@8V]N9FEG=7)A8VGS+B!0
M;W1S97(@=7,@:&5U("(*(F1E<V-U:61A="!D)V5M<&QE;F%R('5N(&-A;7`@
M;F5C97-S87)I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`W('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,3$S('!O+W1R86YS;&%T:6]N+G!H<#HQ,C0U"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4
M<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@(@HB9FQA9R`M
M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S
M97(N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S<*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M
M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A
M<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)3)VAA('!R;V1U
M[W0@=6X@97)R;W(@96X@97AE8W5T87(@;&$@9G5N8VGS(&5S<&5C:69I8V%D
M82!D92!L82!L;&EB<F5T82`B"B)D)V%D<F5C97,N(%1O<FYE=2UH;R!A(&EN
M=&5N=&%R(&WI<R!T87)D+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B)3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@86-T
M=6%L:71Z87(@96QS(&1E=&%L;',@9&4@8V]N=&%C=&4N(%1O<FYE=2UH;R!A
M("(*(FEN=&5N=&%R(&WI<R!T87)D+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E,G:&$@<')O9'7O="!U;B!E<G)O
M<B!E;B!A8W1U86QI='IA<B!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(%1O
M<FYE=2UH;R!A("(*(FEN=&5N=&%R(&WI<R!T87)D+B(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S
M97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S
M='(@(D%Q=65S="!S97)V:61O<B!)34%0(&YO('!E<FUE="!L)_IS(&1E(&-A
M<G!E=&5S(&-O;7!A<G1I9&5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(").;R!S96UB;&$@<75E
M('-I9W5I('5N(&%R>&EU(')A<B!VX&QI9"XB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B3F\@<V5M8FQA
M('%U92!S:6=U:2!U;B!A<GAI=2!Z:7`@=N!L:60N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q-#,*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R(").;R!S96UB;&$@<75E
M(&%Q=65S="!N^FUE<F\@9&4@=&%R9V5T82!S:6=U:2!VX&QI9"XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB07%U97-T
M(&-O;G1R;VQA9&]R('!E<FUE="!E;G9I87(@;6ES<V%T9V5S('!E<B!M:71J
MX"!D92!L82!P87-S87)E;+=L82`B"B)#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI+"!U=&EL:71Z86YT(&QA($%022!(5%10(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D%Q=65S="!C;VYT
M<F]L861O<B!P97)M970@96YV:6%R(&UI<W-A=&=E<R!P97(@;6ET:N`@9&4@
M;&$@<&%S<V%R96RW;&$@(@HB<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@=71I;&ET>F%N="!L82!!4$D@2%144"(*"B,Z(&QI8B].970O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#`*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U
M9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D
M869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W
M:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM
M<V=S='(@(B(*(D%Q=65S="!C;VYT<F]L861O<B!P97)M970@96YV:6%R(&UI
M<W-A=&=E<R!P97(@=FEA(&1E(%--5%`@82!T<F%VZ7,@9&4@;&$@(@HB<&%S
M<V%R96RW;&$@5F]D869O;F4@9"=)=.!L:6$L(&YO;>ES(&$@;OIM97)O<R!6
M;V1A9F]N92X@0V%L('1E;FER('5N(&-O;7!T92`B"B)D92!C;W)R974@96QE
M8W1R\FYI8R!A;6(@5F]D869O;F4@9"=)=.!L:6$@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3<X(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#4W(&QI8B](;W)D92]&;W)M+G!H<#HQ,#@V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3$U(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@R(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,C4V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,CDP(&QI8B](;W)D92]&;W)M+G!H<#HQ-#`S(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-38R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.34X(&QI8B](;W)D92]&;W)M+G!H<#HR,#`U"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#(Y(&QI8B](;W)D92]&;W)M+G!H<#HR,#<X(&QI
M8B](;W)D92]&;W)M+G!H<#HR,30Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C(Q(&QI8B](;W)D92]&;W)M+G!H<#HR-#`X(&QI8B](;W)D92]&;W)M+G!H
M<#HR-#4R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4U(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#(V(&QI8B](;W)D92]&;W)M+G!H<#HS,3,U"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS-S(R(&QI8B](;W)D92]&;W)M+G!H<#HS-S,P"FUS
M9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("+)<R!N96-E
M<W-A<FD@87%U97-T(&-A;7`N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B07%U97-T(&-A;7`@;F]MZ7,@<&]T(&-O;G1E;FER(&YO
M;6)R97,@96YT97)S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#$V"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+B(*;7-G<W1R(")!<75E<W0@8V%M<"!N;VWI<R!P;W0@8V]N
M=&5N:7(@;F]M8G)E<R!I(&5L<R!D;W,@<'5N=',N(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D%Q=65S="!C86UP(&YO;>ES
M('!O="!C;VYT96YI<B!V86QO<G,@;V-T86QS+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M("(B"B)!<75E<W0@8V%M<"!H82!D92!S97(@=6YA(&QL:7-T82!D92!N;VUB
M<F5S(&5N=&5R<R!S97!A<F%T<R!P97(@8V]M97,@;R`B"B)E<W!A:7,N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M
M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")!<75E<W0@8V%M<"!H
M82!D92!S97(@=6X@;OIM97)O(';@;&ED+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#,T"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D%Q=65S="!C86UP(&AA(&1E
M(&-O;G1E;FER('5N(&-O9&D@9&4@8V]L;W(@9&4@9F]R;6%T(%)'0B!H97AA
M9&5C:6UA;"P@<&5R("(*(F5X96UP;&4@)R,Q,C,T868G+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B2F$@<R=H82!P<F]C97-S870@
M87%U97-T(&9O<FUU;&%R:2XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI
M;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R
M(")!:7CR(.ES("5S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#,W"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A
M<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@
M86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B
M($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B
M"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)!:7CR(.ES
M('5N(&]B:F5C=&4@9&4@2V]L86(@1W)O=7!W87)E+B!097(@=FES=6%L:71Z
M87(@87%U97-T(&]B:F5C=&4L('5S("(*(F-A;"!U;B!C;&EE;G0@9&4@8V]R
M<F5U(&5L96-T<O)N:6,@<75E(&%D;65T:2!E;"!F;W)M870@9&4@2V]L86(@
M1W)O=7!W87)E+B`B"B)097(@=&5N:7(@86-CZ7,@82!U;F$@;&QI<W1A(&0G
M87%U97-T<R!C;&EE;G1S(&1E(&-O<G)E=2!E;&5C='+R;FEC+"!V:7-I=&5U
M("(*(B5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB
M"FUS9W-T<B`B(@HB07%U97-T(&UI<W-A=&=E('9A('-E<B!E<V-R:70@86UB
M('5N(&IO8R!D92!C87+@8W1E<G,@*"5S*2!D:69E<F5N="!D96P@(@HB=F]S
M=')E+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4
M:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B07%U
M97-T(&[Z;65R;R!H82!D92!S97(@8V]M(&$@;>UN:6T@=6X@,2XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3,P-`IM<V=I9"`B5&AI<R!S8W)I<'0@;75S
M="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*
M;7-G<W1R(")!<75E<W0@<V5R=FED;W(@;F\@<&]T(&1E<V-O;7!R:6UI<B!A
M<GAI=7,@>FEP(&D@9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$T-PIM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R(")!<75E<W0@<VES=&5M82!E<W3@(&1E<V%C=&EV870@
M86-T=6%L;65N="XB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM
M<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")!
M<75E<W0@=F%L;W(@:&$@9&4@<V5R('5N(&[Z;65R;RXB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(D%Q=65S=&$@9FEN97-T<F$@<R=H82!D92!C<FED87(@9&5S(&0G=6YA
M(&9I;F5S=')A(&0G;W!C:6]N<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E1R
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C`*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B5&EQ=65T<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-#(V"FUS9VED(")4:6UE(@IM<V=S='(@(DAO<F$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM
M<V=S='(@(D-O;G1R;VP@9&4@=&5M<',B"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!H;W)A
M<FDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4S-PIM<V=I9"`B5&EM92!S
M96QE8W1I;VXB"FUS9W-T<B`B4V5L96-C:?,@9&4@=&5M<',B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P"FUS9VED
M(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<B!/<FEE;G1A;"(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4[71O;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B5.UT;VP@*'+H=&]L(&EN
M9&EC861O<B!D92!F=6YC:?,I.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")!(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R-@IM<V=I9"`B(@HB
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN
M9RXB"FUS9W-T<B`B(@HB4&5R('-E;&5C8VEO;F%R(&1I=F5R<V]S(&5L96UE
M;G1S+"!M86YT:6YG=65U('!I=&IA9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I
M("(*(F\@0V]M;6%N9"`H36%C*2!M96YT<F4@8VQI<75E=2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@P"FUS9VED(")4;V1A>2(*;7-G
M<W1R(")!=G5I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(D-O;6UU=&5U(&QA(&9O;G0@2%1-3"(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O9V\B"FUS9W-T
M<B`B5&]G;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,C8*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*;7-G:60@(E1O
M;6]R<F]W(@IM<V=S='(@(D1E;>`B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y"FUS9VED(")4;VYG82(*;7-G<W1R
M(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(E-U<&5R:6]R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM
M<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")-87)C('-U<&5R:6]R
M("A?<W5P97)I;W(I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F
M=7IZ>0IM<V=I9"`B5')A;G-L871E9"(*;7-G<W1R(")4<F%D=6-C:6]N<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I
M;VYS(@IM<V=S='(@(E1R861U8V-I;VYS(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,@IM<V=I9"`B5')I;FED860@
M86YD(%1O8F%G;R(*;7-G<W1R(")4<FEN:71A="!I(%1O8F%G;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(E9E<FET870@;R!F86QS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B1'0N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R.`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6[M<VEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,0IM<V=I
M9"`B5'5R:V5Y(@IM<V=S='(@(E1U<G%U:6$B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T
M<B`B5'5R8R`H25-/+3@X-3DM.2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N:7-T86XB
M"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,`IM<V=I9"`B5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S(@IM<V=S='(@(DEL;&5S(%1U<FMS(&D@0V%I8V]S(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,PIM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&QI8B](;W)D
M92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(E1E8VQE9V5U(&QA('9O<W1R82!O<&-I\SH@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U-@IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM
M<V=S='(@(LUN9&5X(%56.B`B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B
M55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#`*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@9&5L('9O<W1R92!I;F9O
M<FUE(&1E(&PG97-T870@9&4@=')A;65S82!D92!L82!S97'\Z&YC:6$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS
M9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,W"FUS9VED(")59V%N9&$B"FUS
M9W-T<B`B56=A;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S-@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")58W)A
M[VYA(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S4*;7-G:60@(E5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!A8V-E9&ER(&%L(&1I<F5C=&]R:2!61E,N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U
M<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B3F\@
M<R=H82!P;V=U="!A9F5G:7(@;>ES(&1A9&5S(&1E(&PG=7-U87)I(&5N(&5F
M96-T=6%R(&PG86QT82XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(V"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-A
M;G9I87(@96P@<&5R;>US(&1E(&PG87)X:74@5D93(%PB)7-<(BXB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C,P."!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N
M(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C
M86YV:6%R(&5L('!E<FWM<R!D92!L)V%R>&EU(%9&4R`E<R\E<RXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-C<R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%N
M=FEA<B!A("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,S<Q"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R
M(").;R!S)VAA('!O9W5T(&-O;FYE8W1A<B!A;"!S97)V:61O<B!344PN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C<U-@IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V]N;F5C=&%R
M(&%M8B!34TPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-3@@;&EB+U9&4R]F
M:6QE+G!H<#HQ-C,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3@X"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$Y,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#$*
M;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").;R!S
M)VAA('!O9W5T(&-O<&EA<B!L)V%R>&EU(%9&4RXB"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYO(',G:&$@<&]G
M=70@8W)E87(@96P@9&ER96-T;W)I(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR-S<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C4X(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C(T.`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&-R96%R(&5L(&1I
M<F5C=&]R:2!61E,N(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED
M(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T(&-R96%R(&PG87)X:74@5D93+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!C<F5A
M<B!L82!C87)P971A(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HQ.3@*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8W)E87(@=6X@87)X:74@5D93(&)U
M:70N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A<BYP:'`Z-S8@;&EB+TAO
M<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&1E<V-O;7!R
M:6UI<B!L97,@9&%D97,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-B!L:6(O
M5D93+W-M8BYP:'`Z,C(T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R:6UI<B!<(B5S7"(L(&5L(&1I
M<F5C=&]R:2!N;R!E<W3@(&)U:70N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M-30@;&EB+U9&4R]S<6PN<&AP.C,Q-"!L:6(O5D93+VUU<W%L+G!H<#HS,3$*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S(V"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@)7,L(&5L
M(&1I<F5C=&]R:2!N;R!E<W3@(&)U:70N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER("<E<R<Z("5S+B(*"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,T,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-#0*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R:6UI<B!E;"!D
M:7)E8W1O<FD@5D93(&1E(&UA;F5R82!R96-U<G-I=F$N(@H*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HR-C`@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O
M;75S<6PN<&AP.C,S-0HC.B!L:6(O5D93+VUU<W%L+G!H<#HS-#,@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S,V"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@
M96P@9&ER96-T;W)I(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S,Y(&QI
M8B]61E,O<W%L+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!S=7!R:6UI<B!E;"!D:7)E8W1O<FD@5D93.B`E<RXB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").;R!S)VAA
M('!O9W5T('-U<')I;6ER(&PG87)X:74@5D93(%PB)7-<(BXB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C(R-B!L:6(O5D93+W-Q;"YP:'`Z,C$P(&QI8B]61E,O
M;75S<6PN<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W,`HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS-S@*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@<W5P<FEM:7(@
M;"=A<GAI=2!61E,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(T-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(").;R!S)VAA('!O9W5T('-U<')I;6ER(&QA(&-A<G!E
M=&$@5D93(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S(X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!S=7!R:6UI<B!61E,@
M9&4@;6%N97)A(')E8W5R<VEV83H@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C<R,`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!D971E<FUI;F%R(&5L(&1I
M<F5C=&]R:2!A8W1U86PN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',B"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E>'1R975R92!E;',@9&5T
M86QL<R!D96P@8V5R=&EF:6-A="XB"@HC.B!L:6(O3F5T+TE-4U`N<&AP.C0U
M,2!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R(").;R!S)VAA('!O9W5T(&-A<G)E9V%R(&QA(&1E9FEN:6-I\R!D92`E
M<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$R.2!L:6(O5D93+V9I;&4N<&AP
M.C$S-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3@*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,38S"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`B3F\@<R=H82!P;V=U="!M;W5R92!L)V%R>&EU(%9&4RXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z-S8@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]6
M1E,O<VUB+G!H<#HQ,#(*(SH@;&EB+U9&4R]S;6(N<&AP.C8U,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C`U(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$R,B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,C4*;7-G:60@(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&]B<FER(&PG87)X:74@5D93('!E<B!E<V-R:75R92UH
M:2XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8W(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C<R"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T
M<B`B3F\@<R=H82!P;V=U="!O8G)I<B!L)V%R>&EU(%9&4RXB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R(").;R!S)VAA('!O
M9W5T(&]B<FER(&PG87)X:74@8V]M<')I;6ET+B(*"B,Z(&QI8B]61E,N<&AP
M.C@U-0IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@HB3F\@<R=H82!P;V=U="!L;&5G:7(@
M;"=A<GAI=2!61E,@*&QA(&UI9&$@9&4@;"=A<GAI=2@I(&AA(&1O;F%T(&5R
M<F]R*2XB"@HC.B!L:6(O5D93+G!H<#HX.#8*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(DYO(',G:&$@<&]G=70@;&QE9VER(&PG87)X:74@5D93("AG971&:6QE4VEZ
M92@I(&AA(&1O;F%T(&5R<F]R*2XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z
M("(*;7-G<W1R(").;R!S)VAA('!O9W5T(&QL96=I<B!L)V%R>&EU.B`N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HU.3(*;7-G:60@(E5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F\@<R=H82!P;V=U
M="!L;&5G:7(@96P@9&ER96-T;W)I(&%R<F5L(&1E(%9&4RXB"@HC.B!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$P-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*(DYO(',G:&$@<&]G=70@8V%N=FEA
M<B!E;"!N;VT@9&4@)7,@<&5R("5S.B!L82!C87)P971A(&1E(&1E<W1I;F%C
M:?,@:F$@(@HB97AI<W1E:7@B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M.#4*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F\@<R=H82!P;V=U="!C86YV:6%R(&5L(&YO;2!D96P@9&ER96-T
M;W)I(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C4Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I
M<F5C=&]R:2!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR.#$@;&EB
M+U9&4R]S;6(N<&AP.C(V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F\@<R=H82!P
M;V=U="!C86YV:6%R(&5L(&YO;2!D92!L)V%R>&EU(%9&4R!<(B5S7"(N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HU,S,@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N
M;VT@9&4@;"=A<GAI=2!61E,@)7,O)7,N(@H*(SH@;&EB+U9&4R]S<6PN<&AP
M.C(T-2!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M=7-Q;"YP:'`Z
M-#4R"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(W-R!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M(@IM<V=S='(@(DYO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&4@;"=A
M<GAI=2!61E,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(").
M;R!S)VAA('!O9W5T(&5X96-U=&%R("=M:VES;V9S)RXB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F\@<R=H
M82!P;V=U="!T<F%D=6ER(&%Q=65S="!D;V-U;65N="!D92!7;W)D(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C$R,B!L:6(O5D93+V9T<"YP:'`Z,3(U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DYO(',G:&$@<&]G=70@97-C<FEU<F4@;"=A<GAI=2!6
M1E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3$R"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("(B"B).;R!S)VAA('!O9W5T(&5S8W)I=7)E(&PG87)X:74@5D93("@C
M<R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&-O<&EA<BUL;R@I(",I+B(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S
M,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S4*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(").;R!S)VAA('!O9W5T(&5S
M8W)I=7)E(&QE<R!D861E<R!D92!L)V%R>&EU(%9&4RXB"@HC.B!L:6(O5D93
M+G!H<#HX-C$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B3F\@<R=H82!P;V=U="!E
M<V-R:75R92!L)V%R>&EU(%9&4RP@<V4@<W5P97)A<N`@;"=E<W!A:2!D:7-P
M;VYI8FQE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")3=6)R871L;&%T
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#
M:&%N9V5S(@IM<V=S='(@(D1E<V;I<R!E;',@8V%N=FES(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1&5S9N`@;&$@9&%R<F5R
M82!A8V-I\R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,C,@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B`B"FUS9W-T<B`B16P@<V5R=FED;W(@:&$@9&]N870@=6YA(')E<W!O<W1A
M(&EN97-P97)A9&$@96X@8V]N;F5C=&%R+7-E.B`B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#$*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,W."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS
M9W-T<B`B16P@<V5R=FED;W(@:&$@9&]N870@=6YA(')E<W!O<W1A(&EN97-P
M97)A9&$@83H@(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N
M="YI;F,Z-C0*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B4V5N<V4@8V%T96=O
M<FEA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O
M9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-PIM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B56YI\R!D96QS($5M:7)A
M=',@P')A8G,B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E)E
M9VYE(%5N:70B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(D5S
M=&%T<R!5;FET<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T
M;'EI;F<@27-L86YD<R(*;7-G<W1R("));&QE<R!097)I9NAR:7%U97,@365N
M;W)S(&1E;',@17-T871S(%5N:71S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-CD*;7-G:60@(E5N
M:71S(@IM<V=S='(@(E5N:71A=',B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,3@@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Y"FUS9VED(")5
M;FMN;W=N(@IM<V=S='(@(D1E<V-O;F5G=70B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B56YK;F]W;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R(")A<&EM<V=I9"`H:61E;G1I
M9FEC861O<B!D96P@;6ES<V%T9V4@9&4@;&$@05!)*2!D97-C;VYE9W5T+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED
M(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S
M='(@(D-L:6US9VED(&1E<V-O;F5G=70@*&ED96YT:69I8V%D;W(@9&5L(&UI
M<W-A=&=E(&1E;"!C;&EE;G0I+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN;W=N(&-O;6UA
M;F0Z("5S(@IM<V=S='(@(D1E<V-A<G)E9V%R("5S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"XB"FUS9W-T<B`B4R=H82!P<F]P;W)C:6]N870@=6YA('5B
M:6-A8VGS(&1E<V-O;F5G=61A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+B(*;7-G<W1R(").;VT@9"=U<W5A<FD@;R!C;VYT<F%S96YY82!D
M97-C;VYE9W5T<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N
M="!E;&5M96YT(@IM<V=S='(@(D1E<V5N;&QAYV%R(&PG96QE;65N="!A8W1U
M86PB"@HC.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN
M86UE9"(*;7-G<W1R(")396YS92!N;VTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DQE<R!S97'\Z&YC:65S('-E
M;G-E('!E<FUI<V]S(&YO('!O9&5N(&%C8V5D:7(@82!2971A;&QA<B]#;W!I
M87(O16YG86YX87(@9&4@(@HB;6%N97)A('!R;V=R86W@=&EC82!P97(@<F%O
M;G,@9&4@<V5G=7)E=&%T+B!#;&EQ=65U(&5N($0G86-O<F0@<&5R("(*(G9I
M<W5A;&ET>F%R('5N82!N;W1A('3H8VYI8V$@82!M;WII;&QA+F]R9R!Q=64@
M=7,@;6]S=')A(&-O;2!P;V1E=2!F97(@<75E("(*(G5N82!S97'\Z&YC:6$@
M86-C961E:7AI(&%L('!O<G1A+7)E=&%L;',N("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N
M<V5T(&-O;&]R(@IM<V=S='(@(D5L:6UI;F%R(&5L(&-O;&]R(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#8@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HY,C8*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,S(*
M;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")%>'1E;G-I
M\R!N;R!I;7!L96UE;G1A9&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W
M"B,L(&9U>GIY"FUS9VED(")5;G1R86YS;&%T960B"FUS9W-T<B`B4V5N<V4@
M;F]M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`V(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,3@S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B06-T=6%L:71Z87(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!8W1U86QI='IA<B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*;7-G
M:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D%C='5A;&ET>F%R(&PG=7-U87)I
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ,S<@861M:6XO<&5R;7,O961I="YP
M:'`Z,C$W('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@)R5S)RXB"FUS9W-T<B`B4R=H
M82!A8W1U86QI='IA="`G)7,G+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#DR('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T:6YG("5S(&AE;'`@9FEL92!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Q"FUS9VED(")5<&=R861E
M('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")3)VAA('-U<')I;6ET(&QA('-E
M<?SH;F-I82!D)V%C='5A;&ET>F%C:?,N(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3@R"FUS9VED(")5<&QO860B"FUS9W-T<B`B0V%R<F5G87(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@Y"FUS9VED(")5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B
M(@HB4R=H82!C87)R96=A="!A;"!S97)V:61O<B!T;W1S(&5L<R!A<GAI=7,@
M9&4@8V]N9FEG=7)A8VGS(&0G87!L:6-A8VEO;G,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I
M9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T(&QL873M
M(&5N(&UA:OIS8W5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU
M;6)E<G,B"FUS9W-T<B`B6&EF<F5S(')O;6%N97,@96X@;6%J^G-C=6QA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T
M,0IM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%I(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C,U('!O+W1R86YS;&%T:6]N+G!H<#HY,B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(E5S86=E.B(*;7-G<W1R
M(").;VT@9"=U<W5A<FDZ(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E
M;G0Z("5S(@IM<V=S='(@(E5T:6QI='IA<B!L)V%C='5A;#H@)7,B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"FUS9VED(")5<V4@
M4U-,(@IM<V=S='(@(E5T:6QI='IA<B!34TPB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(S"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R(")5=&EL:71Z974@
M<VD@96P@;F]M(&\@;&$@8V]N=')A<V5N>6$@<_-N(&1I9F5R96YT<R!A;"!S
M97)V:61O<B!)35-0+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-C$X
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES
M960@9F]R("5S+B(*;7-G<W1R("),)W5S=6%R:2`E<R!N;R!E<W3@(&%U=&]R
M:71Z870@<&5R(&$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED
M(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%C:?,@
M9"=U<W5A<FES(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-3`*;7-G
M:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<&-I;VYS(&0G=7-U87)I(@H*
M(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS
M9W-T<B`B4F5G:7-T<F4@9"=U<W5A<FES(@H*(SH@<VEG;G5P+G!H<#HR,@IM
M<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R
M('1H:7,@<VET92XB"FUS9W-T<B`B16P@<F5G:7-T<F4@9"=U<W5A<FES(&0G
M87%U97-T(&QL;V,@97-TX"!I;FAA8FEL:71A="XB"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ-S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#8*(RP@
M9G5Z>GD*;7-G:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES
M;W,@9&5L('!R;W!I971A<FDB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3@R"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3DW(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.3,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M-2!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C8V"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(").;VT@9"=U<W5A
M<FDB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@)R5S)R!A;')E861Y(&5X
M:7-T<RXB"FUS9W-T<B`B16P@;F]M(&0G=7-U87)I("<E<R<@:F$@97AI<W1E
M:7@N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED
M(")5<V5R;F%M93HB"FUS9W-T<B`B3F]M(&0G=7-U87)I.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS
M9W-T<B`B3F]M(&0G=7-U87)I.B`B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B57-E<G,B"FUS9W-T<B`B7U5S=6%R
M:7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED
M(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")5<W5A<FES(&1E;"!S
M:7-T96UA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#(*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI
M<W1A;B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3`Q(&QI8B]61E,O9FEL92YP
M:'`Z,3@X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")%;"!D:7)E8W1O<FD@5D93(&YO(&5X:7-T96EX+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,38*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(D%B<^AN8VEA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V-@IM
M<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R
M("),97,@=6)I8V%C:6]N<R!VX&QI9&5S('%U92!S)VAA;B!T<F]B870@<_-N
M.B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")6
M86QI9&ET>2(*;7-G<W1R(")686QI9&5S82(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C4T(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.38*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N
M(@IM<V=S='(@(E9A;&]R(&5N(&UI;G5T<R!A('!A<G1I<B!D)V%R82XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#4V(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")%;"!V86QO<B!S=7!E<F$@
M;&$@;&]N9VET=60@;>!X:6UA(&1E("5S+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0T(&QI8B](;W)D92]&;W)M+G!H<#HR,C8V(&QI8B](;W)D92]&
M;W)M+G!H<#HR,S$T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3(V"FUS9VED
M(")686QU97,B"FUS9W-T<B`B5F%L;W)S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,#D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E
M<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")686QO<G,@<75E(',G:&%N('-E
M;&5C8VEO;F%R(&1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T.0IM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU
M871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-@IM<V=I
M9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B;&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")696YE
M>G5E;&$B"FUS9W-T<B`B5F5N9>=U96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T
M:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G
M<W1R(")(82!F86QL870@;&$@=F5R:69I8V%C:?,Z(.ES('!O<W-I8FQE('%U
M92!S)VAA9VD@86QT97)A="!E;"!M:7-S871G92XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")6
M97)S:?,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`S"FUS9VED
M(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B0V]N=')O;"!D92!V97)S:6]N
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D%L:6YE
M86-I\R!V97)T:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`B1F%R8VEM96YT('9E<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S
M='(@(E9E<G1I8V%L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B36]L="!A
M;'0B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C0X"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)
M4T-)22DB"FUS9W-T<B`B5FEE=&YA;6ET82`H5DE30TE)*2(*"B,Z(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(")6:7-U86QI='IA<B`E<R(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B
M('!A9V4B"FUS9W-T<B`B5FES=6%L:71Z87(@=6YA('#@9VEN82!W96(@97AT
M97)N82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6:7-U86QI
M='IA<B!C;VT@82`E<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#8*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET
M:7-H(@IM<V=S='(@(DEL;&5S(%9E<F=E<R!B<FETX&YI<75E<R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<*;7-G
M:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DEL;&5S(%9E<F=E
M<R!N;W)D+6%M97)I8V%N97,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M-PIM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:7-I8FEL:71A="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(E9I<VEB
M:6QI='DZ("(*;7-G<W1R(")6:7-I8FEL:71A=#H@(@H*(SH@;&EB+TYE="]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW.0IM<V=I9"`B5F]D869O;F4@
M271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@9"=)=.!L:6$@<&5R
M('9I82!D92!33510(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(D%$5D52
M5,A.0TE!(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N(@IM<V=S='(@(D%6S5,A($5,24U)3D%2($Q!(%-%4=S(
M3D-)02!-04Y504Q-14Y4($1%("5S+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!I($9U='5N82(*"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0IM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R(")!=NUS(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@Q('!O+W1R86YS;&%T:6]N+G!H
M<#HW,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`V,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V.0HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`W-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X-R!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`Y-PHC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P
M-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3(S-0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-2!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3(U,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(W,0HC+"!F=7IZ>0IM
M<V=I9"`B5V%R;FEN9SH@(@IM<V=S='(@(D%V[7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G
M<W1R(")$8RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*
M;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B4')E=FES:?,@9&5L
M('1E;7!S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S-`IM
M<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(DEN9F]R
M;6%C:?,@;65T96]R;VSR9VEC82!P<F]P;W)C:6]N861A('!E<B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S
M='(@(E=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*
M;7-G:60@(E=E8B(*;7-G<W1R(")796(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S8W"FUS9VED(")796(@4VET92(*;7-G<W1R("),;&]C('=E
M8B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E
M96ML>2(*;7-G<W1R(")3971M86YA;&UE;G0B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")"96YV
M:6YG=71S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU,"!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B0F5N=FEN9W5T<R!A("5S(@H*(SH@
M;&%N9W1E<W0R+G!H<#HQ-`IM<V=I9"`B5V5L8V]M92!T;R!->2!02%`@07!P
M;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(D)E;G9I;F=U=',L
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(D]C8VED96YT86P@*$E33RTX.#4Y
M+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")/8V-I9&5N=&%L("A)4T\M.#@U
M.2TQ-2DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW.`IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4^!H87)A
M($]C8VED96YT86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S
M(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(E%U:6YA(&%P;&EC86-I
M\R!H875R:6$@9&4@;6]S=')A<B`E<R!E;B!I;FEC:6%R(&QA('-E<W-I\S\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B475I;B#I
M<R!E;"!C87+@8W1E<B!D96QI;6ET861O<C\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHR-`IM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/R(*;7-G<W1R(")1=6EN(.ES(&5L(&-A<N!C=&5R(&1E(&-I=&%C
M:?,_(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P
M:&%S97,B"FUS9W-T<B`B475I;F5S(&9A<V5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,0IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")0;'5G:6YS(&AA
M8FEL:71A=',@9&4@;"=E9&ET;W(@9&4@=&5X="!E;G)I<75I="XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T
M"FUS9VED(")7:61T:"(*;7-G<W1R(")!;7!L861A(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G
M<W1R(")!;7!L861A(&1E(&QE<R!U;FET871S($-34R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(D%M<&QA9&$@9&5L(&UE;OH@)7,@9&4@
M;"=E<W%U97)R82`H9&ES<&]N:6)L92!E;B!L82!P<F]P97)A('-E<W-I\RDZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R(")!;7!L861A
M(&1E(&QA('1A=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B56YI
M=&%T(&0G86UP;&%D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B06UP;&%D
M83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4Y"FUS9VED(")7
M:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5VEN9"(*;7-G<W1R(")696YT(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G
M:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B5F5N="!A('!R:6UE<F$@:&]R82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I=&%T(&1E;"!V96YT(&5N(&YU<V]S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-30*;7-G:60@(E=I;F0Z(@IM
M<V=S='(@(E9E;G0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S-`IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(E9E;G0Z("(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A
M=FEE<V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"B,L(&9U
M>GIY"FUS9VED(")7:7-H;&ES=',B"FUS9W-T<B`B3&QI<W1E<R!D92!D97-I
M=&IO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R
M:R(*;7-G<W1R(")&96EN82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(T(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R9>=A(&1E(&QA
M(&9E:6YA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5LZ&9O;B!D92!L82!F
M96EN82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R:71I;F<@=7!D871E9"!H96QP(&9I;&4@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,CD*;7-G
M:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT
M<R(*;7-G<W1R("),:6UI=&%C:6]N<R!BX'-I<75E<R!8-3`Y=C,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X
M=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("+:<R!D92!L82!C;&%U(&5S=&5S
M82!X-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R
M(").;VT@86QT97)N871I=2!D)V%S<W5M<'1E(%@U,#EV,R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C
M="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))9&5N=&EF:6-A9&]R(&1E(&-L
M874@9"=A<W-U;7!T92!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M17AT96YS:6]N<R!8-3`X=C,B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`B04$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@V(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C<*;7-G:60@(EE965DB"FUS9W-T<B`B04%!02(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Q"FUS9VED(")9
M86AO;R$@;6%P(@IM<V=S='(@(DUA<&$@9&4@66%H;V\A(@H*(SH@;&EB+TAO
M<F1E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(D%N=6%L;65N="(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N(@IM<V=S='(@(DEE;65N(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X-0IM<V=I
M9"`B665S(@IM<V=S='(@(E/M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE<RP@22!!9W)E92(*
M;7-G<W1R(")3[2P@:&\@86-C97!T;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+B(*;7-G<W1R(")3;W4@96X@96P@34]$12!415A4+B!5<V5U
M(&5L(&)O=/,@6SP^72!P97(@=&]R;F%R(&$@5UE325=91RXB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$R.#@*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N(@IM<V=S='(@(DYO(&5S=&5U(&%U=&5N=&EC871S+B(*"B,Z(&QI8B](
M;W)D92])9&5N=&ET>2YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")9;W4@8V%N
M(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92XB"FUS9W-T<B`B3F\@<&]D974@:6YC;&]U<F4@96P@8V%RX&-T97(@)UQ<
M)R!E;B!E;"!N;VT@8V]M<&QE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N
M;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").;R!H
M974@:6YT<F]D=>]T('5N82!A9')EYV$@96QE8W1R\FYI8V$@=N!L:61A+B(*
M"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O
M<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E
M<RXB"FUS9W-T<B`B(@HB3F\@:&5U(&%S<V]C:6%T(&-A<"!C86UP(&1E(&PG
M87)X:74@:6UP;W)T870@86UB(&5L<R!C86UP<R!C;W)R97-P;VYE;G1S(&1E
M("4B"B)S+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,#,*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B2&5U('-O<G1I="!D
M92!L82!S97-S:?,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G
M:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B
M"B)(974@9"=I;G1R;V1U:7(@=6X@;OIM97)O(&1E('1E;.AF;VX@;?)B:6P@
M=N!L:60L(&YO;>ES(&3M9VET<R!A;6(@=6X@)RLG("(*(F]P8VEO;F%L('!E
M<B!A;"!P<F5F:7@@9&4@=')U8V%D82!I;G1E<FYA8VEO;F%L+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E
M<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")(974@9"=I;G1R;V1U:7(@=6X@
M=F%L;W(@=N!L:60N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HS
M-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B2&5U(&1E(&-O;F9I9W5R87(@
M=6X@;6]T;W(@9&4@1&%T851R964@<&5R('5T:6QI='IA<B!!;'1E<RXB"@HC
M.B!L:6(O2&]R9&4N<&AP.C0S,0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(DAE=2!D92!C;VYF:6=U<F%R('5N
M(&UO=&]R(&1E(%9&4RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S
M='(@(DAE=2!D92!D97-C<FEU<F4@96P@<')O8FQE;6$@86)A;G,@9"=E;G9I
M87(M;F4@;"=I;F9O<FUE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!5
M4DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")(974@9"=I
M;G1R;V1U:7(@96P@55),('%U92!A<75E<W0@96YL;&'G(&EN9&EC82XB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU
M<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")(
M974@9&4@<V5L96-C:6]N87(@=6X@<V5R=FED;W(@<75E('9U;&=U974@96QI
M;6EN87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")(
M974@9"=E<W!E8VEF:6-A<B!U;B!N;VT@9"=U<W5A<FD@<75E('9U;&=U974@
M97-B;W)R87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")(
M974@9"=E<W!E8VEF:6-A<B!U;B!N;VT@9"=U<W5A<FD@<75E('9U;&=U974@
M<W5P<FEM:7(N(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(DAE=2!D)V5S<&5C:69I
M8V%R('%U:6X@;F]M(&0G=7-U87)I('9O;&5U(&%F96=I<BXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B2&5U(&0G97-P96-I9FEC87(@
M96P@;F]M(&0G=7-U87)I('%U92!V;VQE=2!A8W1U86QI='IA<BXB"@HC.B!L
M:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B2&5U
M(&0G97-P96-I9FEC87(@<75I;F$@86-C:?,@=F]L974@97AE8W5T87(N(@H*
M(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S(*;7-G
M:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T
M<B`B2&5U(&1E('1E8VQE:F%R('5N(&YO=2!N;VT@9&4@8V%T96=O<FEA+B(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*(DQA('9O<W1R82!S97-S:?,@96X@)7,@:&$@
M97AP:7)A="X@4VD@=7,@<&QA=2P@:6YI8VEE=2!U;F$@;F]V82!S97-S:?,N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@
M(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R("),82!V;W-T<F$@861R9>=A
M(&5L96-T<O)N:6-A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,@IM
M<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("),82!T979A(&%D
M<F7G82!D92!R97-P;W-T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U
M<B!);F9O<FUA=&EO;B(*;7-G<W1R("),82!V;W-T<F$@:6YF;W)M86-I\R(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HX.34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"B),82!V;W-T<F$@861R9>=A(&0G26YT97)N970@:&$@8V%N=FEA
M="!D97,@<75E(&AE=2!C;VUE;N=A="!L82!S97-S:?,@)7,N("(*(E!E<B!R
M86]N<R!D92!S96=U<F5T870L(&AE=2!D92!R96EN:6-I87(@;&$@<V5S<VGS
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED
M(")9;W5R($YA;64B"FUS9W-T<B`B16P@=F]S=')E(&YO;2(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"B,L(&9U>GIY"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB16P@
M=F]S=')E(&UO=&]R(&0G875T96YT:6-A8VGS(&YO('!E<FUE="!Q=64@97,@
M;&QI<W1I;B!E;',@=7-U87)I<RP@;R!BZ2`B"B)P97(@86QG=6YA(')A\R!A
M<75E<W1A(&-A<F%C=&5R[7-T:6-A(&5S=.`@:6YH86)I;&ET861A+B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z.0IM<V=I9"`B(@HB
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)%;"!V
M;W-T<F4@;6]T;W(@9"=A=71E;G1I8V%C:?,@;F\@<&5R;65T('%U92!E<R!L
M;&ES=&EN(&5L<R!U<W5A<FES+"!O(&+I("(*(G!E<B!A;&=U;F$@<F'S(&%Q
M=65S=&$@8V%R86-T97+M<W1I8V$@97-TX"!I;FAA8FEL:71A9&$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(E-E;6)L82!Q=64@96P@;F%V96=A9&]R(&AA(&-A;G9I870@9&5S
M('%U92!V874@8V]M96[G87(@;&$@<V5S<VGS("5S+B!097(@(@HB<F%O;G,@
M9&4@<V5G=7)E=&%T+"!H974@9&4@=&]R;F%R(&$@96YT<F%R(&%L('-I<W1E
M;6$N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`B16P@=F]S=')E(&YA=F5G861O<B!N;R!A8V-E<'1A(&%Q=65S=&$@8V%R
M86-T97+M<W1I8V$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N
M:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)%;"!V;W-T<F4@;F%V96=A9&]R
M(&YO('!E<FUE="!A<75E<W1A(&]P8VGS(&0G:6UP<F5S<VGS+B!0<F5M:2!#
M;VYT<F]L("L@4"`B"B)P97(@:6UP<FEM:7(N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(T-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB
M"FUS9W-T<B`B6F]N82!H;W+@<FEA(&%C='5A;#HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M(@IM<V=S='(@(DED96YT:71A="!P<F5D971E<FUI;F%D83HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DQ"FUS9VED(")9;W5R(&9U;&P@;F%M93HB
M"FUS9W-T<B`B3F]M(&-O;7!L970Z(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-0IM<V=I9"`B(@HB66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O(&]L
M9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN7&XB"B).;W0@
M86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T
M<B`B3&$@;F]V82!C;VYT<F%S96YY82!P97(@82`E<R#I<SH@)7,B"@HC.B!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+B(*;7-G<W1R("),97,@;W!C:6]N<R!H86X@97-T870@86-T=6%L
M:71Z861E<R!P97(@82!L82!D=7)A9&$@9"=A<75E<W1A('-E<W-I\RXB"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("),97,@;W!C:6]N<R!H
M86X@97-T870@86-T=6%L:71Z861E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="(*;7-G<W1R(")3)VAA(')E:6YI8VEA="!L82!V;W-T<F$@8V]N=')A
M<V5N>6$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I
M9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N
M(@IM<V=S='(@(B(*(E,G:&$@<F5I;FEC:6%T(&QA('9O<W1R82!C;VYT<F%S
M96YY82P@<F5V:7-A(&5L(&-O<G)E=2!E;&5C='+R;FEC(&D@:6YI8VEA("(*
M(FQA('-E<W-I\R!A;6(@;&$@;F]V82!C;VYT<F%S96YY82XB"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E
M('-E<G9E<G,Z(@IM<V=S='(@(E-E<G9I9&]R<R!R96UO=',Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-30*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B275G;W-LX'9I82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B
M"FUS9W-T<B`B6F%I<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4V"FUS9VED("):86UB:6$B"FUS9W-T<B`B6N!M
M8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-PIM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S
M='(@(EII<'!Y(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T
M<B`B6T]C=6QT82!T97AT(&-I=&%T72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C4V"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM);F9O
M<FUE(&1E;"!P<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*
M;7-G<W1R(");36]S=')A('1E>'0@8VET870@+2(*"B,Z(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G
M<W1R(");36]S=')A('1E>'0@8VET870@+2`E<R!L[6YI97-=(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@
M;V8@)7-=(@IM<V=S='(@(EML[6YI82`E<R!D92`E<UTB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$T,S(@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I
M9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UN:7-T<F%C:?,B"@HC
M.B!L:6(O87!I+G!H<#HQ,S8*;7-G:60@(E]#3$DB"FUS9W-T<B`B7T-,22(*
M"B,Z(&QI8B]A<&DN<&AP.C$R-`IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@
M(E]!<F)R92!D92!D861E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B
M"FUS9W-T<B`B7U-U<')I;6ER(&9I;&$B"@HC.B!L:6(O87!I+G!H<#HQ,38*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!S(@H*(SH@;&EB+TAO<F1E
M+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7T%J=61A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?
M4')O<&EE=&%T<R!D92!L82!I;6%T9V4N+BXB"@HC.B!L:6(O2&]R9&4O365N
M=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]);FEC:6$@;&$@
M<V5S<VGS(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO
M9R!O=70B"FUS9W-T<B`B7U-U<G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@
M3&EN:RXN+B(*;7-G<W1R(")?36]D:69I8V$@;"=E;FQL8><N+BXB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M(")?3W!C:6]N<R(*"B,Z(&QI8B]A<&DN<&AP.C$R,`IM<V=I9"`B7U!E<FUI
M<W-I;VYS(@IM<V=S='(@(E]097)M:7-O<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(E]%;&EM:6YA(&PG96YL;&'G+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3`X"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7T-O
M;F9I9W5R86-I\R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B7U!R;W!I971A=',@9&4@;&$@=&%U;&$N+BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,3(*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?57-U87)I
M<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DP"FUS9VED(")A9&1R97-S
M(&)O;VLB"FUS9W-T<B`B;&QI8G)E=&$@9"=A9')E8V5S(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C<Q,0HC+"!F=7IZ>0IM<V=I9"`B86X@97)R;W(@:&%S
M(&]C8W5R960Z(@IM<V=S='(@(E,G:&$@<')O9'7O="!U;B!E<G)O<B!I<G)E
M<&%R86)L92XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@X,@IM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B86=E;F1A(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-S`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")C86QM82(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HU.#@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T
M<B`B4')E;6D@87%U[2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-#4@<&\O
M=')A;G-L871I;VXN<&AP.C4U,"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$Q"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW-#D@<&\O=')A;G-L871I;VXN<&AP.C@Q
M,"!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@W"B,L(&9U>GIY"FUS9VED(")D;VYE
M(@IM<V=S='(@(F9E="(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-3(@<&\O
M=')A;G-L871I;VXN<&AP.C4X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$S"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW-S@@<&\O=')A;G-L871I;VXN<&AP.C@Q
M,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#DP"B,L(&9U>GIY"FUS9VED(")F86EL
M960B"FUS9W-T<B`B9F%L;&ED82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")F86QL:6YG(@IM<V=S='(@(F5S
M=.`@8V%I96YT(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@T.0IM<V=I
M9"`B9FEL92(*;7-G<W1R(")A<GAI=2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(F9O=6YD.B`B"FUS9W-T<B`B5F5N=#H@
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")D
M97,@9&5L("5S("@E<RD@82!L97,@)7,@)7,B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*;7-G<W1R(")H
M.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS,S$*
M;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C(@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V-`IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(FEM;65D:6%T(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")I;G-E<F5I>"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L
M:6YE<UTB"FUS9W-T<B`B;.UN:65S72(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@
M97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")3)VAA
M('!R;V1U[W0@=6X@8V]D:2!D)V5R<F]R("5D(&1E;"!M:VES;V9S(&5N(&-R
M96%R($E33RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S0R"FUS9VED(")M;2(*;7-G<W1R("(C;6TC(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HR.#<@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C(P-0IM<V=I9"`B;F%M92(*;7-G<W1R(")N;VTB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,S<X"B,L(&9U>GIY"FUS9VED(")N;W0@8VAA;F=E9"(*;7-G
M<W1R(")396YS92!C86YV:7,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S
M,0HC+"!F=7IZ>0IM<V=I9"`B;F]T(&9O=6YD(@IM<V=S='(@(DYO(',G:&$@
M=')O8F%T("5S+B(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R,0IM<V=I9"`B
M;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYO(',G:&$@:6UP;&5M96YT870B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO
M="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B96YC87)A(&YO(',G:&$@:6UP
M;&5M96YT870B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@W-`IM<V=I9"`B
M;F]T97!A9"(*;7-G<W1R(")B;&]C(&1E(&YO=&5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B
M<&5R8V5N="(*;7-G<W1R(")P97)C96YT871G92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I
M>&5L<R(*;7-G<W1R(")P[7AE;',B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(F5S
M=.`@<'5J86YT(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.`IM<V=I
M9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")M;W-T<F%R(&1I9F5RZ&YC
M:65S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q,PIM
M<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I;"!P
M97(@=FEA(&1E($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S4X"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")S=&5A
M9'DB"FUS9W-T<B`B8V]N<W1A;G0B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C@Y.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(FQL:7-T82!D92!T87-Q
M=65S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L;V-A
M;&4@)7,@9&]E<R!N;W0@97AI<W0Z(@IM<V=S='(@(DYO(&5X:7-T96EX(&PG
M87)X:74@=&5M<&]R86P@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(G1E8VQE9V5U
M(&QA(&-O;G1R87-E;GEA(&1U97,@=F5G861E<R!P97(@8V]N9FER;6%R+6QA
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEC870B"@HC
M.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*
M;7-G<W1R(")S96YS92!N;VTB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S<U
M"B,L(&9U>GIY"FUS9VED(")U<&1A=&5D(@IM<V=S='(@(D%C='5A;&ET>F%R
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C(@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-`IM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`B<V5L96-C:?,@9&4@;"=U<W5A<FDB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*
M;7-G<W1R(")V0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C0*;7-G:60@(G<Z(@IM<V=S='(@(G<Z(R,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB
M"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&\O8G-?0D$N<&\`````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C4P-C,Q(#$P-3$U-#,T
M,30R(#`Q-S0W,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C('1R86YS;&%T:6]N(&]F(&AO<F1E+6)S+G!O('1O($)O<VYI
M86X*(R!";W-N:6%N('1R86YS;&%T:6]N<R!F;W(@:6UP('!A8VMA9V4N"B,@
M0V]P>7)I9VAT("A#*2`R,#`S($AO<F1E(%!R;VIE8W0*(R!4:&ES(&9I;&4@
M:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS92!A<R!T:&4@
M:6UP('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P,#,N
M"B,@06QE;B!387)K:6YO=FEC(#QA;&5N0&QI;G5X+F]R9RYB83XL(#(P,#0N
M"B,@5F5D<F%N($QJ=6)O=FEC(#QV;&IU8F]V:6-`<VUA<G1N970N8F$^+"`R
M,#`U+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N
M.B!H;W)D92UB<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,#<M,#$@
M,3,Z,S$K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!6961R86X@3&IU8F]V
M:6,@/'9L:G5B;W9I8T!S;6%R=&YE="YB83Y<;B(*(DQA;F=U86=E+51E86TZ
M($)O<VYI86X@/&QO:V%L0&QI;G5X+F]R9RYB83Y<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,EQN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@HB6"U'96YE<F%T;W(Z($M"86)E;"`Q+C$P7&XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H<')I:F4@)7,@9&%N82DB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI
M;B`E<R!D87ES*2(*;7-G<W1R("(@*'IA("5S(&1A;F$I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B("AD86YA<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<U
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*'-U=')A*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y
M*2(*;7-G<W1R("(@*&IUZ&4I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B
M"FUS9W-T<B`B('4@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!D:7)E8W1O<GDN(@IM<V=S='(@(E!R879A8R!S;W)T:7)A;FIA(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T
M<B`B)R5S)R!N:6IE(&1O>G9O;&IE;B!I>F)O<BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;FEJ92!P;V1EN65N('4@<F5G
M:7-T<GDM:G4@87!L:6MA8VEJ92XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E
M+G!H<#HQ-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ92!P<F]N
M8?!E;BXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D
M<F5S87(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES
M<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@
M(B5D("5S(&D@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*
M;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!.87!O;65N
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S,R!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E
M<R!397)V:7-N92!O<&5R86-I:F4@+2!P;W1V<F1A(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S('!O9&6Y
M879A;FIE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S
M('!R:6IA=F$B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B5S('5S;&]V:2!U9V]V;W)A(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D
M>2!E>&ES=',N(@IM<V=S='(@(B5S('9EYB!P;W-T;VII+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S('4@)7,@)7,B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O
M>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T
M('1H:7,@=&EM92XB"FUS9W-T<B`B("8C,34Q.R`E<R#F92!S861A(&EZ=G*Y
M:71I('-E<G9I<VYE(&]P97)A8VEJ92!N879E9&5N92!I<W!O9"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B
M"FUS9W-T<B`B)7,@;6EN=71A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N
M;W0@9F]U;F0N(@IM<V=S='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!Z82`E<R!O9"`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S(&%D<F5S
M87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S(&MA;&5N
M9&%R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S(&)I;&IE
MOFYI8V$B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S('IA
M9&%C:2(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L
M86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(B5S('4@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M+2!I>F%B
M97)I=&4@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R
M($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+7-A=&YI(&9O<FUA="(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,C0M<V%T;FD@9F]R;6%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('-A=&$B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED
M("(\4')E=FEO=7,B"FUS9W-T<B`B4')E=&AO9&YA('-T<F%N82(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME
M;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L
M(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R(")$;[EL;R!J92!D;R!F871A
M;&YE(&=R9;EK92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y
M-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*
M(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F
M=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(DMO<&ER86HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0HC+"!F=7IZ>0IM<V=I9"`B04T@4F%I
M;B(*;7-G<W1R(")5<&]Z;W)E;FIE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B
M04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!
M8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")/(&]V;VT@961I=&]R=2(*"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*
M;7-G<W1R(")/('!R;V=R86UU+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B06)S8F]T
M=&]M(@IM<V=S='(@(D1N;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!
M8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-I:F4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`BJ6EF<F$@:V]R:7-N:>AK;V<@;F%L;V=A(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B3F%L;V<@:F4@
M>F%M<GIN=70N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PIM
M<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")28>AU;F]V;V1S='9O(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D
M8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B1&]D86HB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I
M9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L=2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`B1&]D86H@
M;W9D:F4Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S
M+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T
M<B`B3F5W<RUG<G5P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`HC+"!F=7IZ
M>0IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(DEZ;6EJ96YI
M(&1O>G9O;'4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P
M('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D
M(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B27IM:6IE
M;FD@9&]Z=F]L92!Z82`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED
M(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B1&]D86H@;F]V;V<@:V]R:7-N
M:6MA.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B1&]D86H@:V]L;VYU
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`HC+"!F
M=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(D1O9&%J(&YO
M=F]G(&MO<FES;FEK83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@
M)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")$;V1A:B`E
M<R!M96YI('4@36]Z:6QL82!3:61E8F%R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R(")$;V1A:B!U(&%D<F5S87(Z(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D1O9&%J('4@
M:6UE;FEK("@E<RDB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0HC+"!F=7IZ>0IM
M<V=I9"`B061D('5S97(B"FUS9W-T<B`B1&]D86H@;W9D:F4Z(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@
M7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET
M:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@H*
M(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM
M<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(V"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S,@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0HC+"!F=7IZ>0IM<V=I9"`B061D
M<F5S<R(*;7-G<W1R(")/9"!A9')E<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B26UE
M;FEK(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<FER86YJ92`M('!O9&6Y879A
M;FIE(&1O>G9O;&$@9')U9VEH(&MO<FES;FEK82(*"B,Z(&%D;6EN+VEN9&5X
M+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"B,L(&9U
M>GIY"FUS9VED(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R
M86-I:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L(&9U
M>GIY"FUS9VED(")!9',B"FUS9W-T<B`B1&]D86HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS
M9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!;&)A;FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06R^:7(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"B,L(&9U>GIY
M"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;+YI<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T
M<B`B4W9E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0HC+"!F=7IZ>0IM<V=I9"`B
M06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B57-M:F5R96YJ92!N
M:6IE('5S<&5L;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(R"B,L(&9U>GIY"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(E]'<G5P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0HC+"!F
M=7IZ>0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E]$;WIV;VQE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(D1O>G9O;&D@<')A=FQJ96YJ92!N=6UE<FES
M86YI:"!L:7-T:3\B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HU,#0*(RP@9G5Z>GD*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(B5S('9EYB!P;W-T;VII+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@
M(D%L=&5R;F%T:79N:2!)35-0(&QO9VEN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS
M9W-T<B`B06QT97)N871I=FYA($E-4U`@N6EF<F$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M
M92(*;7-G<W1R(")!;'1E<FYA=&EV;F\@24U34"!K;W)I<VYIZ&MO(&EM92(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS
M9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(").961O>G9O
M;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T
M97,B"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B56YEN65N82!J92!I;&5G
M86QN82!V<FEJ961N;W-T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S
M(&]C8W5R960N(@IM<V=S='(@(D1ON6QO(&IE(&1O(&9A=&%L;F4@9W)EN6ME
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"B,L(&9U
M>GIY"FUS9VED(")!;G-W97(B"FUS9W-T<B`B3V1G;W9O<F5N92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*(RP@9G5Z>GD*;7-G:60@(D%P<&QI
M8V%T:6]N(@IM<V=S='(@(D%K8VEJ82(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G
M<W1R(")!:V-I:F$B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"B,L
M(&9U>GIY"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B
M06MC:6IA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G
M:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C
M:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G
M<W1R("));64@9&%T;W1E:V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@
M<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")$82!L:2!S=&4@<VEG=7)N:2!D
M82"^96QI=&4@:7-P<F%Z;FET:2!F;VQD97(@:V]R<&$_(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B1&$@;&D@<W1E
M('-I9W5R;FD@9&$@OF5L:71E(&]B<FES871I(&]V92!P;W)U:V4_(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%L
MOFER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S
M='(@(E!I=&%J('!R:6IE(&]B879L:F%N:F$@<V5R=FES;FEH(&]P97)A8VEJ
M83\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!
M<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U
M<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I
M9"`B075S=')A;&EA(@IM<V=S='(@(D%U9W5S="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@
M9G5Z>GD*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075G=7-T(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C
M>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U
M"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM
M<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U
M-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R(").:6IE('5S<&5L;R!S<&&Y879A;FIE(&YE>F%V<KEE;F4@<&]R
M=6ME+B!/=F\@:F4@<&]R=6MA('-E<G9E<F$Z("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S(@IM<V=S='(@(DYI:F4@=7-P96QO('-P8;EA=F%N:F4@
M;F5Z879RN65N92!P;W)U:V4N($]V;R!J92!P;W)U:V$@<V5R=F5R83H@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B
M075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I
M<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960B"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#4Q
M"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E;&\N(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHW-0HC+"!F=7IZ>0IM<V=I9"`B079A:6QA8FQE
M(&9I96QD<SHB"FUS9W-T<B`B3F$@<F%S<&]L86=A;FIU('-U('-L:F5D9>9I
M(&EM96YI8VDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/
M1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B
M0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@
M=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M
M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R(")"<F%Z:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L
M=&GH:VD@*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L
M861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B
M0F%S96QI;F4B"FUS9W-T<B`B5F5L:>AI;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*(RP@9G5Z>GD*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B5F5L:>AI;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L
M(&9U>GIY"FUS9VED(")"96QI>F4B"FUS9W-T<B`B5F5L:>AI;F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"96YI;B(*;7-G<W1R(")2975N:6]N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5G)S
M=&$@8FQO:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B36%S;F\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(D)O;&EV:6IA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM<V=I9"`B0F]O:VUA<FMS(@IM
M<V=S='(@(EIA8FEL:F6Y:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T
M<B`B4G5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B1&5B
M;&II;F$@<G5B;W9A.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M4G5B;W9I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O
M=FEN82(*;7-G<W1R(")";W-N82!I($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM<V=S='(@(D)O8W9A;F$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")$;F\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E="!O<W1R=F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)A>FEL(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I
M=&]R>2(*;7-G<W1R(")"<FET86YS:V$@26YD:6IS:V\M3VME86YS:V$@5&5R
M:71O<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M
M(@IM<V=S='(@(D)R=6YE:2!$87)U<W-A;&%M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`B0G5G87)S:V$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E
M9"!,:7-T(@IM<V=S='(@(DQI<W1A('-A('1AZ&MA;6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B0G5R:VEN82!&87-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7)U;F1I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM
M<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(D]S;V)I;F4@YE]E;&EJ92XN+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1A<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*(RP@9G5Z>GD*;7-G
M:60@(D-A;&TB"FUS9W-T<B`B3V1U<W1A;FDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F_P82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL
M92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R
M"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S
M97)V97(Z("5S(@IM<V=S='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0
M('-E<G9E<CH@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S
M='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R
M+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ
M,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM
M<V=S='(@(D]D=7-T86YI(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M(")/9'5S=&%N:2!O9"!P<FEJ879E('!R;V)L96UA(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@(D-A
M;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM
M<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@
M<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B
M"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@
M9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T
M;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G
M:60@(D-A<'1I;VXB"FUS9W-T<B`B3W!C:6IE(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I:F4@
M:2!O>FYA:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B36%RN6%L;W9A(&]S=')V82(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*(RP@9G5Z>GD*
M;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L969O;B`H:W7F:2DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B
M3W-O8FEN92#F7V5L:6IE+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B0V5L;"!P<F]P97)T:65S
M(@IM<V=S='(@(D]S;V)I;F4@YE]E;&EJ92XN+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B2V5L='-K:2`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@HC+"!F=7IZ
M>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(DMR96ER86HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U
M"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B0V5N
M=')A;&YO+4%F<FGH:V$@4F5P=6)L:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(D-E;G1R86QN;RUE=G)O<'-K:2`H25-/+3@X-3DM,BDB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B
M0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@
M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*;7-G
M<W1R(")4;VL@=&5M92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H
M86YG92(*;7-G<W1R(")0<F]M:F5N:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)0<F]M:6IE;FET92!I;64@
M:2!A9')E<W4@:V]J92!V:61E(&1R=6=I(&MA9&$@Z&ET86IU(&D@;V1G;W9A
M<F%J=2!N82!V8;EE("(*(G!O<G5K92XB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O
M<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R
M871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")4;VL@
M=&5M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-0HC+"!F=7IZ>0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB
M"FUS9W-T<B`B7TEZ;6EJ96YI(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EL92(*;7-G<W1R("+(:6QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B2VEN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P
M"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B
M2VEN97-K:2!P;VIE9&YO<W1A=FQJ96YI("A'0C(S,3(I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@
M*$)I9S4I(@IM<V=S='(@(DMI;F5S:VD@=')A9&EC:6]N86QN:2`H0FEG-2DB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED
M(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("))>F%B97)I=&4@N6EF<G4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED
M(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("))>F%B97)I=&4@:V]R:7-N
M:>AK;R!I;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED
M(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(DEZ86)E
M<FET92!K86MO('-E('!R:6MA>G5J92!D871U;3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED
M(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB
M"FUS9W-T<B`B27IA8F5R:71E('9R<W1U('-T:6QA("AZ82!N=6UE<FES86YE
M(&QI<W1E*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B
M"FUS9W-T<B`B57-K<KEN:F4@;W-T<G9O(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(D_H:7-T:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*
M;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B3^AI<W1I($U3
M3V9F:6-E('1A9V]V92(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@
M9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(D_H:7-T:2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M
M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(D-L96%R('5S97(B"FUS9W-T<B`B3^AI<W1I(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")/9&%B97)I(&MO9&YI(')A<W!O<F5D('-L
M;W9A.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K
M871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED
M(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-#0*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")+;W!I
M<F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")+;W!I
M<F%J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*(RP@9G5Z>GD*;7-G:60@(D-L;W5D>2(*;7-G<W1R(")+;W!I<F%J(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")3:W5P
M:2!F;VQD97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED(")#;VQL87!S960@8F]R
M9&5R<R(*;7-G<W1R(")3:W5P:2!F;VQD97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U
M>GIY"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+86UB;_!A(@H*(SH@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,CD*(RP@9G5Z>GD*;7-G:60@(D-O;&]R(@IM<V=S='(@(DMO;6]R:2(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C0*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`P('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I
M8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(DEZ8F]R(&)O
M:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"B,L(&9U>GIY
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B3F]V82!P;W)U:V$B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS
M9W-T<B`B2V]M<&%N:6IA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS
M9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N
M="(*;7-G<W1R("):879RN65N;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38V"B,L(&9U>GIY"FUS9VED(")#;VUM;VX@3F%M92(*
M;7-G<W1R(")68;EE(&EM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(DMO;6]R:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B2V]M
M<&%N:6IA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"B,L(&9U>GIY
M"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B3F]V82!P;W)U:V$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED
M(")#;VYD:71I;VXB"FUS9W-T<B`B3W!C:6IE(&YA<F5D8F4Z(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO
M;G,B"FUS9W-T<B`B3W!C:6IE(&YA<F5D8F4Z(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"B,L
M(&9U>GIY"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-W
M;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B0V]N9V\B"FUS9W-T
M<B`B6F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")#;VYG;RP@5&AE
M($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(DQA;R!.87)O
M9&YA($1E;6]K<F%T<VMA(%)E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B
M57-M:F5R96YJ92!N:6IE('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#0U"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N
M('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI
M:F4@=7-P96QO+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS
M9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")<(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S
M87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T
M<B`B0F]U=F5T(&]S=')V;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,@HC+"!F=7IZ>0IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(DYO=F$@<&]R=6MA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<&ER86HB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(E5S;6IE<F5N
M:F4@;FEJ92!U<W!E;&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T
M<B`B2V]P:7)A:B!I>F%B<F%N;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD(&YO
M="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O
M34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM
M<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S
M.B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M(&QD87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S
M.B`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*
M;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S
M='(@(DYE(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@
M=7-I;F<@1E10.B`E<R(*;7-G<W1R(").92!M;V=U('-E('-P;VII=&D@;F$@
M24U!4"!S97)V97(Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM
M<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S
M.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*
M;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E
M<SH@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R
M,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I
M('!O<G5K92!O9"`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DYI
M:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O
M8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!F971C:"!T
M:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S
M='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M(%PB)7-<(BXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T
M86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M;W!E;B`E<RXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P
M;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G
M=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!!0TPB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I
M<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D
M("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").:6IE(&)I
M;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*
M;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E
M<SH@)7,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R
M(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B3FEJ92!B:6QO(&UO9W5C92!O
M8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(DYI:F4@8FEL;R!M;V=U8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S
M.B`E<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R(").:6IE(&)I;&\@
M;6]G=6-E(&]B<FES871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K
M92!O9"`E<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B3FEJ92!B:6QO(&UO9W5C92!O8G)I<V%T:2!P;W)U:V4@;V0@)7,Z("5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F
M;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES
M871I('!O<G5K92!O9"`E<SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B
M87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB
M)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,3D*(RP@9G5Z>GD*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("))
M<W!R879L:F5N('1E:W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-CD*(RP@9G5Z>GD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B
M3F]V82!P;W)U:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S
M"B,L(&9U>GIY"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DYO=F$@<&]R=6MA
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B2W)E:7)A:B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(").87!R879I
M(&QI;FLB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(DYA<')A=FD@
M;F]V:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B4')A=FQJ
M96YJ92!P;V0M9F]L9&5R82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C0P"B,L(&9U>GIY"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(D1E9F%U;'0@9&]Z=F]L92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R,S`*(RP@9G5Z>GD*;7-G:60@(D-R961I="!C87)D(&YU
M;6)E<B(*;7-G<W1R(")$96-E;6)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"B,L(&9U>GIY
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(DMR96ER86HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R
M("))<W!R879L:F5N('1E:W-T(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X
M"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(DES
M<')A=FQJ96X@=&5K<W0B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O
M0FQO8VLO=&EM92YP:'`Z,S`*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@5&EM
M92(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("))<W!R879L:F5N('1E
M:W-T(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS9VED
M(")#=7)R96YT(%5S97)S(@IM<V=S='(@(DES<')A=FQJ96X@=&5K<W0B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#=7)R
M96YT(%=E871H97(B"FUS9W-T<B`B27-P<F%V;&IE;B!T96MS="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@
M8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R("))<W!R879L:F5N('1E:W-T(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(E!O9&5S:71E('IA9&%T:V4@:V]J:2#F92!S92!I>G9RN6%V871I(&YA:V]N
M('!R:6IA=F4@;F$@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-0HC+"!F=7IZ>0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("))>F)O
M<B!B;VIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H
M2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-Y<FEL;&EC+U5K
M<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"B,L(&9U
M>GIY"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R(")#96YT<F%L;F\M
M069R:>AK82!297!U8FQI:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")$1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1N979N;R(*"B,Z
M(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B1&%T851R
M964@0G)O=W-E<B(*;7-G<W1R(")?1&%T851R964B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$
M871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(D1A=&4@4F5C96EV960B
M"FUS9W-T<B`B4')I;6QJ96YA(&YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@P-PHC+"!F=7IZ>0IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS
M9W-T<B`B5G)E;65N<VMA('IO;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*
M(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")-86HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(RP@
M9G5Z>GD*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D]B<FFY:2!F
M;VQD97(H92DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5C96UB87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`B1&5C96UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R
M969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B4W1A;F1A<F1N
M;R(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E-T86YD87)D;F$@
M8F]J82(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*
M;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B1&5F875L="!I9&5N
M=&ET970B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4W1A;F1A<F1N;R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B
M"FUS9W-T<B`B1&5F:6YI8VEJ92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")/8G)I
MN6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S
M='(@(D]B<FFY:2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B"FUS
M9W-T<B`B3V)R:;EI(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(D]B<FFY
M:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!097)M:7-S:6]N(@IM<V=S='(@(D]B<FFY:2!P;W)U:V4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")"<FES86YJ92!I
M(&EZ8F%C:79A;FIE('!O<G5K82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E
M;&5T92!C96QL(@IM<V=S='(@(D]B<FFY:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B3V)R:;EI(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(DEZ;6EJ
M96YI(&1O>G9O;&4@>F$@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(')O=R(*;7-G
M<W1R(")/8G)IN6DB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I
M='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS
M9W-T<B`B3V)R:;EI(&EZ86)R86YI(&ED96YT:71E="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R
M(")0;V1E<VD@=G)E;65N<VMU('IO;G4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E!O9&5S:2!V
M<F5M96YS:W4@>F]N=2XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DYI:F4@8FEL;R!M;V=U
M8V4@;V)R:7-A=&D@<&]R=6ME(&]D("5S.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B3V)R:;EI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I
M8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B3W!IN6ET92!P<F]B;&5M92!U(')A
M9'4@<V$@=V5B;6%I;&]M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D]P:7,B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H
M86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0HC+"!F=7IZ>0IM<V=I9"`B1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B3W9A('!O<G5K82!J92!P<FEJ879L:F5N82!K86\@<W!A;2!P
M;W)U:V$@861M:6YI<W1R871O<G4@<VES=&5M82XB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O
M:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS
M9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P
M;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I
M9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED
M(")$:7)E8W1O<GDB"FUS9W-T<B`B1&ER96MT;W)I:B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE
M<S\B"FUS9W-T<B`B4')I:V&^:2!V<FEJ96UE('4@,C0M<V%T;F]M(&9O<FUA
M='4_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!C:6IE('!R:6MA>F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B4')I:V&^:2!P<F]G
M;F]Z=2`H5$%&*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@
M(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')I:V&^:2!P<F]G
M;F]Z=2`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*
M(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(E!R:6MA
MOFDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED
M(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO
M="!D96QE=&4B"FUS9W-T<B`B56YD96QE=&4B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R
M"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*(RP@9G5Z>GD*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R
M(")#96YT<F%L;F\M069R:>AK82!297!U8FQI:V$B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B
M1&]W;FQO860B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T
M<B`B1&]W;FQO860@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R
M"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!0
M2%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC
M+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(E-A;F1U8V4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I
M9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@
M=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET(@IM<V=S='(@(DEZ;6EJ96YI(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U
M"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"B,L(&9U>GIY"FUS9VED
M(")%9&ET($=R;W5P(@IM<V=S='(@(D]B<FFY:2(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("))>FUI
M:F5N:2!D;WIV;VQU(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("))>FUI:F5N:2!D
M;WIV;VQE(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("))>FUI:F5N:2!D;WIV;VQE('IA("5S(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T
M<B`B27IM:6IE;FET92!O<&-I:F4@>F$Z(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("))>FUI:F5N
M:2!D;WIV;VQE('IA("5S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@)7,B"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L92!Z82`E<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(D%K8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@
M=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@V.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B4V%N9'5C
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R(")%;6%I;"!A9')E<V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.38S"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@
M;75S="!M871C:"XB"FUS9W-T<B`B16UA:6P@861R97-A(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@
M=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B3W-T86QE(&EN9F]R;6%C:6IE
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R(")3;6%J;&EJ:2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC+"!F=7IZ
M>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B5F&^;F4@<&]R=6ME
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$U,`HC+"!F=7IZ>0IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R("))
M<W!R87IN:2!K;W)P=2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*
M;7-G<W1R("))<W!R87IN:2!F;VQD97(@:V]R<&$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@
M<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")!:W1I=FER86H@
M:V]N=&5K<W0@;65N:2!N82!D97-N;VT@:VQI:W4_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$Q"B,L(&9U>GIY"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")0<F^Y:7)I
M(&9O;&1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B16MV871O<FEJ86QN82!'=FEN96IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M17)I=')E82(*;7-G<W1R(")%<FET<F5J82(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(D=R9;EK82(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN
M9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1O;FEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T:6]P:6IA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`B171N:>AK:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5V<F]P82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`B4W9A:VEH(#$U(&UI;G5T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")3=F%K
M:6@@,B!M:6YU=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N
M9',B"FUS9W-T<B`B4W9A:VEH(#,P('-E:W5N9&DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")3=F%K:6@@-2!M:6YU=&$B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P
M"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+;V0@<W9A:V4@<')I:F%V
M92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y
M(&AA;&8@:&]U<B(*;7-G<W1R(")3=F%K:6@@<&]L82!S871A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B4W9A:VD@;6EN=70B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA
M;7!L92!V86QU97,Z(@IM<V=S='(@(E9R:6IE9&YO<W1I('!R:6UJ97)I.B(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z
M-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT
M-S4*(RP@9G5Z>GD*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")0<F^Y:7)I('-V
M92(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*(RP@9G5Z
M>GD*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(E!R;[EI<FD@9F]L
M9&5R(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@
M=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T
M:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V
M"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").
M92!M;V=U('-E('-P;VII=&D@;F$@24U!4"!S97)V97(Z("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(").92!M
M;V=U('-E('-P;VII=&D@;F$@24U!4"!S97)V97(Z("5S(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*(RP@9G5Z>GD*;7-G:60@(D9A
M:7(B"FUS9W-T<B`B6F%I<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L
M(&9U>GIY"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(D)O=79E="!O
M<W1R=F\B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY
M"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B1W)EN6MA.B`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED
M(")&87@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B26UE(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L<R!L
M:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS
M9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED
M(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL
M92(*;7-G<W1R(")&:6QT97)I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"B,L(&9U
M>GIY"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B26UE(&1A=&]T96ME
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G
M:60@(D9I;&4@3F%M92(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"B,L(&9U>GIY"FUS9VED(")&:6QE
M('-E;&5C=&EO;B(*;7-G<W1R(")N:6IE9&YO('!R879I;&\@;FEJ92!O9&%B
M<F%N;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*(RP@9G5Z
M>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E!O;&IE(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I
M;'1E<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")&:6YL86YD(@IM
M<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@HC+"!F
M=7IZ>0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")0<G9A(%-T<F%N82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S8*(RP@9G5Z>GD*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4')V
M82!3=')A;F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4V"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B
M1FQI<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM
M<V=I9"`B1F]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B
M4W1A;F1A<F1N82!B;VIA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W
M"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM
M<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M"FUS9W-T<B`B5F&Y(&)R;W=S97(@;F4@<&]D<KYA=F$@;W9U(&UO9W7F;F]S
M="XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`HC+"!F=7IZ>0IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')I:V&^:2!P<F]G;F]Z=2`H
M5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I
M9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F
M;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G
M92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$P,@HC
M+"!F=7IZ>0IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@
M(DEZ86)E<FET92"Y:69R=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C(*(RP@9G5Z>GD*;7-G:60@(D9O<FUS(@IM<V=S='(@(D]D(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"B,L(&9U>GIY"FUS9VED(")&;W)T
M=6YE(@IM<V=S='(@(D9O;&1E<FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S
M(@IM<V=S='(@(D9O;&1E<FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,SD*(RP@9G5Z>GD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1F]L9&5R
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*(RP@9G5Z>GD*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;VQD97)I(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$P.0HC+"!F=7IZ>0IM<V=I9"`B1F]R=V%R9',B
M"FUS9W-T<B`B4')O<VQI:F5D:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C`*(RP@9G5Z>GD*;7-G:60@(D9R(@IM<V=S
M='(@(D]D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,PHC+"!F=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G
M<W1R("));64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#`V"B,L(&9U>GIY"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B3V0B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L
M;"!$97-C<FEP=&EO;B(*;7-G<W1R(")$971A;&IA;B!O<&ES(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G
M:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`HC
M+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DEM92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"B,L(&9U>GIY"FUS9VED(")'86UB:6$B"FUS9W-T<B`B6F%M8FEJ82(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M5G)A=&D@<W1A<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B2VEN82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("));64@9&%T;W1E:V4B"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B
M2W)E;FDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA<',B
M"FUS9W-T<B`B1V]O9VQE('!R971R86=A(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")';V]G
M;&4@<')E=')A9V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM
M<V=S='(@(D=RZ&MI("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")4;VL@=&5M92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B5&]K('1E
M;64B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B)7,@861M:6YI<W1R86-I
M:F$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(").:6IE('5S
M<&5L;R!S<&&Y879A;FIE(&YE>F%V<KEE;F4@<&]R=6ME+B!/=F\@:F4@<&]R
M=6MA('-E<G9E<F$Z("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PHC+"!F=7IZ>0IM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(E]'<G5P92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*(RP@9G5Z>GD*
M;7-G:60@(D=U86TB"FUS9W-T<B`B2G5N:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHX.`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B27IM:6IE;FD@9&]Z=F]L92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M2G5N:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B1W5I;F5A+4)I
M<W-A=2(*;7-G<W1R(")*=6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"B,L(&9U>GIY"FUS
M9VED(")'=7EA;F$B"FUS9W-T<B`B2G5N:2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T
M<"YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B57-M:F5R96YJ92!N:6IE('5S<&5L;RXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!
M;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S(*(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*;7-G<W1R(")0
M;VUOYB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B4&]M;^8B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B
M<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S='(@(DAE8G)E:G-K:2`H25-/+3@X
M-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(DAE:6=H="(*;7-G<W1R
M(").;^8B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y
M(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC
M.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B4&]M;^8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S
M:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B4&]M
M;^8B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B4&]M;^8B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B2&EG:"(*;7-G<W1R(").;^8B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(E!O
MZ%]E=&%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-3,U"FUS9VED(")(;VUE(@IM<V=S='(@(E!OZ&5T86LB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!9')E<V$@*&MUYFDI(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")(
M;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E:W1O<FEJ(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R(")496QE9F]N("AK=>9I*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM
M<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@
M)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DEM92!F
M;VQD97)A(%PB)7-<(B!J92!U<W!J9;EN;R!P<F]M:F5N:F5N;R!U(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C0W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(DEM92!F;VQD97)A(%PB)7-<(B!J92!U<W!J9;EN;R!P<F]M:F5N
M:F5N;R!U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B57-P
M:F6Y;F\@<W1E('!R:6IA=FQJ96YI(&YA(%PB)7-<(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S(@IM<V=S='(@(E5S<&IEN6YO('-T92!P<FEJ879L:F5N:2!N82!<
M(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO
M=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@
M<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G
M:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@
M(DAU;F=A<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)U<RYP:'`Z,3<R(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR
M,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U
M<W!E;&\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E5S;6IE<F5N:F4@;FEJ92!U<W!E
M;&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B
M25`@061D<F5S<R(*;7-G<W1R("))4"!A9')E<V$B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0(&%D<F5S82!N:6IE(&1O<W1U<&YA
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G
M:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M(@IM<V=S='(@(DE0(&%D<F5S82!N:6IE(&1O>G9O;&IE;F$@=6YU=&%R($-)
M1%(@8FQO:V$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I;VXN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.0HC+"!F=7IZ>0IM<V=I9"`B25]N<V5R="!2
M;W<@0F5F;W)E(@IM<V=S='(@(E!R:6UL:F5N82!P<FEJ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;F0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S
M='(@(E-A;6\@:6MO;F4B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEK
M;VYE('IA("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM<V=I
M9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEK;VYE('-A('1E:W-T;VTB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(DEM92!I9&5N=&ET971A.B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@
M=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'
M('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U('-E
M92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A
M;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I9"`B
M26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4')E=&AO9&YA('-T<F%N82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C$*(RP@9G5Z>GD*;7-G:60@(DEM86=E('5P
M;&]A9"(*;7-G<W1R(")0;VQJ92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L
M(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z
M("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P
M"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@
M9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(DYI:F4@<&]S;&%N;R!K;W)I<VYIZ&MO(&EM92!I+VEL
M:2"Y:69R82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"B,L
M(&9U>GIY"FUS9VED("));F1I82(*;7-G<W1R(")N;VYE(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("));F1O;F5S:6$B"FUS
M9W-T<B`B;F]N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(DEN9F\B"FUS9W-T<B`B26=N
M;W)IN6DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"B,L(&9U
M>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R(")097)S;VYA;&YE(&EN
M9F]R;6%C:6IE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S
M,`HC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL
M86)L92XB"FUS9W-T<B`B3F5M82!D;W-T=7!N:6@@;W!C:6IA+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(P"B,L(&9U>GIY"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B
M3V1G;W9O<F5N92!P;W)U:V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`P"B,L(&9U>GIY"FUS9VED("));G-E<G0@5&%B
M;&4B"FUS9W-T<B`B3V1G;W9O<F5N92!P;W)U:V4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@
M5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E!O9&5S:2!V<F5M96YS
M:W4@>F]N=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F
M;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@
M(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L
M871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*
M;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X
M"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")0
M<FEM;&IE;F$@<')I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M8V5L;"!B969O<F4B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")0
M<FEM;&IE;F$@<')I:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8U"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M8V]L=6UN(&)E9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B
M26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(D1O9&%V86YJ92!P;W)U:V$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E
M9F]R92(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"B,L(&9U>GIY
M"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(D]D9V]V;W)E;F4@
M<&]R=6ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(')O=R!B969O
M<F4B"FUS9W-T<B`B4')I;6QJ96YA('!R:6IE(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W
M97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"B,L(&9U
M>GIY"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(D]D9V]V
M;W)E;F4@<&]R=6ME(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX.0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T+TUO9&EF>2!,
M:6YK(@IM<V=S='(@(E])>FUI:F5N:2!L:6YK+BXN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S
M;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T
M8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D
M9')E<W,N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D
M<F5S:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H
M<#HX,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ
M,#`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(E9R96UE;G-K82!Z;VYA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB
M"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE
M9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@
M(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B3F5D
M;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@HC+"!F=7IZ
M>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(DYE9&]Z=F]L:F5N
M82!S;&]V82!U(&5M86EL(&%D<F5S:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N
M97(@:60N(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D
M<F5S:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L
M(&9U>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B
M3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@HC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B3F5D;WIV
M;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(V,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE
M8W0B"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S
M<RXB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R97-I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N
M(@IM<V=S='(@(DYE9&]Z=F]L:F5N82!S;&]V82!U(&5M86EL(&%D<F5S:2XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E
M;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W.0HC+"!F=7IZ>0IM<V=I9"`B26YV97)T('-E;&5C
M=&EO;B(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"B,L(&9U>GIY"FUS9VED("))<F5L86YD(@IM<V=S='(@(E1O:R!T96UE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES
M;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DES<F%E
M;"(*;7-G<W1R(")4;VL@=&5M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED
M("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS
M9VED("))=&%L>2(*;7-G<W1R(")$;F5V;F\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@
M9G5Z>GD*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B6F%M8FEJ82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*
M86YU87)Y(@IM<V=S='(@(DIA;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*
M;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P86YS
M:VD@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D
M(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB
M9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@
M(DIU;'DB"FUS9W-T<B`B2G5L:2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED
M(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S
M=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE
M9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0HC+"!F=7IZ>0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D]P8VEJ
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I
M9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*
M(RP@9G5Z>GD*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(DUI;64@=&EP(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z
M>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")0;W)U:V$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@U"B,L(&9U>GIY"FUS9VED(")+;W)E82P@1&5M
M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("),86\@3F%R
M;V1N82!$96UO:W)A='-K82!297!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B
M"FUS9W-T<B`B4F%?<W!O<F5D(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2F5Z:6LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC(@IM<V=S='(@(DQA;R!.87)O9&YA($1E;6]K<F%T<VMA(%)E<'5B;&EK
M82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@
M(DQA<W0@2&%L9B(*;7-G<W1R(")0<G9A(%-T<F%N82(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R
M9"!#:&%N9V4B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"B,L(&9U>GIY"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`B4')V82!3=')A;F$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G
M<W1R("):861N:F$@:7IM:F5N83HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`B6F%D;FIA('!R:6IA=F$Z("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S(Q"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B6F%D;FIA('!R:6IA=F$Z("5S('-A
M(&%D<F5S93H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*
M;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(EIA9&YJ82!P<FEJ
M879A.B!.:6MA9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S
M='(@(DQA='9I:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G
M:60@(DQA=R(*;7-G<W1R("):86MO;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM
M<V=S='(@(E)A<W!O<F5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O
M<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB
M"FUS9W-T<B`B3&EB86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G:60@(DQE9G0B"FUS
M9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L
M=65S(@IM<V=S='(@(EIA9&YJ82!S=')A;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1O(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G
M<W1R(").:6MA9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS
M9W-T<B`B3&EB97)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB:6IS:V$@07)A<'-K82!$OF%M
M86AI<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*
M;7-G<W1R("),:6AT96ZY=&%J;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(E!R:6IA
M=FD@<V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B
M3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI
M9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B
M3&EB97)I:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L
M(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FMO=FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*
M;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI;FMO=FDB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@
M(DQI;G5X($-O;VMI92(*;7-G<W1R(").;W9A('!O<G5K82(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&%N:F4@
M+2!K;W)I<VYI:R!M;[YE('9I9&IE=&D@9F]L9&5R(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B3&ES="!$871A8F%S97,B
M"FUS9W-T<B`B6F%D;FIA('-T<F%N82(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4P"B,L(&9U>GIY"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM
M<V=S='(@(E!O;6_F(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@HC+"!F
M=7IZ>0IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B6F%D;FIA('-T<F%N
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"B,L
M(&9U>GIY"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B4V%K<FEJ(&YE
M=7!I<V%N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B4&]M;^8B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@HC+"!F
M=7IZ>0IM<V=I9"`B3&ES="U)9"(*;7-G<W1R(")0;VUOYB(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"B,L(&9U>GIY"FUS9VED
M("),:7-T+4]W;F5R(@IM<V=S='(@(E!O;6_F(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y
M,0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B4V%K
M<FEJ(&YE=7!I<V%N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DP"B,L(&9U>GIY"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM
M<V=S='(@(E-A:W)I:B!N975P:7-A;F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P
M96QO+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`B5F&Y('!O='!I<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI=&AU86YI82(*;7-G<W1R("),:71V82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B5>AI=&%V86TN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K
M86QN;R!V<FEJ96UE.B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("),;VMA;&YE('!O<W1A
M=FME(&D@=G)I:F5M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV
M-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&]K86-I:F$B"@HC.B!L;V=I
M;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS
M9VED("),;V<@:6XB"FUS9W-T<B`B4')I:F%V:2!S92(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S
M('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DEZ;&%Z
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED
M("),;V=I;B(*;7-G<W1R(")0<FEJ879I('-E(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B6F%D
M86-I('!R:6IA=F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*
M;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@
M<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*
M(E!R:6IA=F$@;FEJ92!U<W!J96QA+B!.86IV97)O=F%T;FEJ92!J92!P;V=R
M9;EN;R!U;F5S96YO(&MO<FES;FGH:V\@:6UE(&EL:2`B"B*Y:69R82XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A
M:6QE9"XB"FUS9W-T<B`B4')I:F%V82!N:6IE('5S<&IE;&$N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM
M<V=S='(@(D1U9VD@=&5K<W0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#@*(RP@9G5Z>GD*;7-G:60@(DQO=F4B"FUS9W-T<B`B3F%S=&%V:2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"B,L(&9U
M>GIY"FUS9VED("),;W<B"FUS9W-T<B`B6F%K;VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED
M("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G
M:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PHC
M+"!F=7IZ>0IM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")$
M96-E;6)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("),=6MS96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED
M(")-32(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C
M:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DU31R(*;7-G<W1R(")#35,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA
M<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE
M<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R
M(")-87)T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"B,L(&9U
M>GIY"FUS9VED(")-86EL(@IM<V=S='(@(E-A;F1U8V4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R
M(")386YD=6-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&1I=F5S
M(@IM<V=S='(@(D9I;'1E<FD@<&^Y=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z
M>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B4V%N9'5C92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`B4V%N9'5C92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@HB3F%P<F%V:71E(&MA=&5G;W)I:F4@<W1A
M=FMI(&D@>F$@<W9A:W4@;V0@;FII:"!O9')E9&ET92!O9&=O=F%R86IUYG4@
M8F]J=2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-
M87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R(")-87)T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM
M<V=I9"`B36%R9VEN(@IM<V=S='(@(E5P;WIO<F5N:F4B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(D]Z;F'H879A;FIE(&MA
M;R!P<F_H:71A;F\O;F5P<F_H:71A;F\B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B3WIN
M8>AA=F%N:F4@9')U9VEM(&]Z;F%K86UA("AN<'(N('9AOFYO(&EL:2!O9&=O
M=F]R96YO*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD
M<R(*;7-G<W1R(")-87*Y86QO=F$@;W-T<G9A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS
M9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<G1I;FEK(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD
M<R(*;7-G<W1R(")/9&=O=F%R86IUYF$@<&]L:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:6-I:G5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.`HC+"!F=7IZ>0IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D
M960N(@IM<V=S='(@(E!O;&IA('!O<G5K92(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B36%J(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F
M=7IZ>0IM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-86HB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM
M<V=S='(@(D]B<FES86YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+(;&%N;W9I(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E
M.B(*;7-G<W1R(")6<G-T82!M96YI:F$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@
M8V5L;',B"FUS9W-T<B`B4W!O:FD@<&]L:F$B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S
M<V%G92(*;7-G<W1R(")0;W)U:V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ
M>0IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")0;VQJ82!P;W)U
M:V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y
M<&4B"FUS9W-T<B`B1&%T=6T@<&]R=6ME(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYE;6$@9&]S='5P;FEH(&]P
M8VEJ82XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@HC+"!F=7IZ>0IM
M<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T
M<B`B3W9A('!O<G5K82!J92!P<FEJ879L:F5N82!K86\@<W!A;2!P;W)U:V$@
M861M:6YI<W1R871O<G4@<VES=&5M82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-`HC+"!F=7IZ>0IM<V=I9"`B365T:&]D(@IM<V=S='(@(DQE<V]T;R(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K
M+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S
M='(@(E!R96)A8VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;64@=&EP
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*
M;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@
M(D=R9;EK82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B
M36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`HC+"!F=7IZ>0IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G
M<W1R(")/=F$@<&]R=6MA('4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U
M:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"B,L(&9U
M>GIY"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D]V82!P
M;W)U:V$@=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(DUO(@IM<V=S='(@(E!R96)A8VDB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*(RP@9G5Z>GD*;7-G
M:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DYO=F$@<&^Y=&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D
M97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"B,L
M(&9U>GIY"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E])>FUI:F5N:2!L
M:6YK+BXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S,*(RP@9G5Z>GD*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B4')E8F%C:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"B,L(&9U>GIY"FUS9VED(")-;VYA8V\B
M"FUS9W-T<B`B36%R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-`IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL
M>2(*;7-G<W1R(")-:F5S9>AN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E
M8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O
M8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*(RP@
M9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B2V]P:7)A:B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS
M9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"B,L(&9U>GIY"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B<&]M:F5R:2!N:;YE(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,L(&9U>GIY"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B4')E8F%C:2(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C4Q-PHC+"!F=7IZ>0IM<V=I9"`B36]V92!2:6=H
M="(*;7-G<W1R(")0<F5B86-I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3`U"B,L(&9U>GIY"FUS9VED(")-;W9E(%5P(@IM<V=S
M='(@(E!R96)A8VDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T
M<B`B<&]M:F5R:2!N:;YE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(T"B,L(&9U>GIY"FUS9VED(")-;W9E('5P(@IM<V=S
M='(@(G!O;6IE<FD@=FFY92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R(")-87)T:6YI:R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*
M(RP@9G5Z>GD*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")N
M:6IE9&YO('!R879I;&\@;FEJ92!O9&%B<F%N;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#`*(RP@9G5Z>GD*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B4F'H=6YO=F]D<W1V;R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO
M;B(*;7-G<W1R(")68;EE(&EN9F]R;6%C:6IE(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B37D@4&]R=&%L(@IM
M<V=S='(@(E)A<W!O<F5D(&UO9R!P;W)T86QA(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R(")287-P;W)E9"!M;V<@<&]R=&%L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G
M<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X
M"FUS9VED(").86UE(@IM<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F
M=7IZ>0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("):86UB:6IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M(RP@9G5Z>GD*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYO=F$@<&^Y=&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S
M='(@(DYO=FD@6F5L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA
M;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*
M;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE
M='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O
M8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G:60@
M(DYE='=O<FLB"FUS9W-T<B`B37)EOF$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*;7-G
M<W1R(").:6MA9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`B3F]V82!+86QE9&]N:6IA(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#
M871E9V]R>2(*;7-G<W1R(").;W9A(&MA=&5G;W)I:F$B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G
M<W1R(").;W9A('!O<G5K82`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(").;W9I(&UJ97-E8R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE
M=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYO=F\@:V]R:7-N:>AK
M;R!I;64@*&YI:F4@;V)A=F5Z;F\I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").
M97<@6F5A;&%N9"(*;7-G<W1R(").;W9I(%IE;&%N9"(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A
M<W-W;W)D(@IM<V=S='(@(JEI9G)A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O
M<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D
M;VXG="!M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L
M86YK*2(*;7-G<W1R(").;W9I('!R;WIO<B`H7W!R87IA;BDB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(").;W9O<W1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").97=S+6=R=7!E(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A
M=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE
M>'0B"FUS9W-T<B`B1&%L:F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*
M(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4VQJ961E
MYF$@9F%Z82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"FUS9VED(").97AT
M(&]P=&EO;G,B"FUS9W-T<B`B4VQJ961EYF4@;W!C:6IE(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^
M(@IM<V=S='(@(D1A;&IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B3FEK87)A9W9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG
M97)I82(*;7-G<W1R(").:6=E<FEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYOYB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B
M3F\B"FUS9W-T<B`B3F4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF
M9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED
M(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS
M9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")0<F]M
M:F5N:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O
M<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S0*(RP@9G5Z>GD*;7-G:60@(DYO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+B(*;7-G<W1R(").;W9E('!O<G5K92(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R(")0;VQJ92(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N
M(@IM<V=S='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N
M(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED
M960N(@IM<V=S='(@(DYI:F5D86X@9F]L9&5R(&YI:F4@<W!E8VEF:6-I<F%N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM
M<V=S='(@(DYO=F4@<&]R=6ME(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YA
M;64@<W!E8VEF:65D+B(*;7-G<W1R(")N:6MA:V%V('1E:W-T(&YI:F4@<W!E
M8VEF:6-I<F%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C
M:69I960N(@IM<V=S='(@(FYI:V%K878@=&5K<W0@;FEJ92!S<&5C:69I8VER
M86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--
M0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O
M('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN
M87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B3F4@:7IB<FES
M86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B
M3FEJ961N82(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T
M<B`B;FEK86MA=B!T96MS="!N:6IE('-P96-I9FEC:7)A;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@
M9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DYE(&EZ8G)I<V%N82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S
M=6-H(&9I;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I
M;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DYI:F4@<&]S;&%N
M;R!K;W)I<VYIZ&MO(&EM92!I+VEL:2"Y:69R82XB"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V
M97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,PIM<V=I9"`B3F]N92(*;7-G<W1R(").:6IE9&%N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N
M92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B3F]R9&EJ<VMI("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*(RP@
M9G5Z>GD*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DUA<KEA;&]V
M82!O<W1R=F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DUA<KEA;&]V82!O<W1R=F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYO<G=A>2(*;7-G<W1R(")0
M<F]S;&EJ961I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").;W0@
M1')A9G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S
M.0HC+"!F=7IZ>0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").;W0@1')A
M9G0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@*(RP@9G5Z
M>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")0<F%V86,@<V]R
M=&ER86YJ82(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,L(&9U>GIY"FUS
M9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYE(&EZ8G)I<V%N82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*
M(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F4@:7IB<FES86YA
M(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU
M,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*(RP@9G5Z
M>GD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYE(&EZ8G)I<V%N
M82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$W.`HC+"!F=7IZ>0IM<V=I9"`B3F]T97,B"FUS9W-T
M<B`B3FEJ961N82(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS
M-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U
M"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)A<B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E
M<B(*;7-G<W1R(").;W9E;6)A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`T"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R
M(")P;VUJ97)I(&YIOF4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B3F]V96UB87(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED
M(")/8FIE8W0B"FUS9W-T<B`B5&5M82(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R(")496UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P
M-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T
M<B`B3VMT;V)A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I
M9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N
M9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@9G5Z>GD*
M;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("*I:69R82(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")087-S=V]R9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL
M>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY
M(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-S$*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"XB"FUS9W-T<B`B3F5D;WIV;VQJ96YA('-L;W9A('4@96UA:6P@861R
M97-I+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P
M96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(D]P97)A=&EV;FD@<VES=&5M(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M(")/<&-I:F4B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B3W!C:6IE('IA("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I
M9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(DQI<W1A('-A('1AZ&MA;6$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PHC+"!F=7IZ
M>0IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(E)E9VES=')A8VEJ82!K
M;W)I<VYI:V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED
M(")/<F=A;FEZ:6YG(@IM<V=S='(@(E5P;WIO<F5N:F4B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@
M=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B
M"FUS9W-T<B`B3W-T86QO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T
M,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B3W-T86QE(&EN
M9F]R;6%C:6IE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0HC
M+"!F=7IZ>0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B2V]R
M:7-N:>AK92!O<&-I:F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*(RP@9G5Z>GD*
M;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R("):871A;6YI
M('!O='!I<V4_(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L
M(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")0
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")0
M7TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")086MI<W1A
M;B(*;7-G<W1R(")!9F=A;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R(")+86YA9&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B4&%R86=U87DB
M"FUS9W-T<B`B3FEK87)A9W9A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S8*(RP@9G5Z>GD*;7-G:60@(E!A<G1L>2!#;&]U
M9'DB"FUS9W-T<B`B2V]P:7)A:B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@
M(JEI9G)A(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS
M9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L
M(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S
M<W=O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R
M"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#4S"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")087-S=V]R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(E!A<W-W;W)D(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%S<W=O
M<F0B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"B,L(&9U>GIY"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS
M9W-T<B`B16UA:6P@861R97-A(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q
M.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W1E(@IM<V=S='(@(D1A='5M(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM
M<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0HC+"!F=7IZ
M>0IM<V=I9"`B4&%T:"(*;7-G<W1R(")$871U;2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(DQJ=61I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T
M<B`B4')O8V5N870B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E
M;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R
M871I;VYS(@IM<V=S='(@(DEZ=G*Y:2!S97)V:7-N92!O<&5R86-I:F4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(DEZ=G*Y
M:2!S97)V:7-N92!O<&5R86-I:F4@<')I;&EK;VT@;&]G:7)A;FIA/R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M
M:7-S:6]N(@IM<V=S='(@(D1O>G9O;&4B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S
M:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B1&]Z=F]L92!Z82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")$;WIV;VQE(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(E]$;WIV;VQE(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P
M97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM
M<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<W1R86-I:F$@9&]Z=F]L82`H<')I=FEL96=I:F$I(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R("),:>AN92!I;F9O<FUA8VEJ92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS
M9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")0
M:&]N92(*;7-G<W1R(")N;VYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED
M(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C
M;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@
M96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N
M9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*(RP@
M9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(@IM<V=S='(@(DUO;&EM('1E('!O<')A=FD@9'9O<VUI<VQE;F4@;V1N;W-N
M;R!I;G9A;&ED;F4@861R97-E+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U>GIY"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R(")-;VQI;2!T
M92!P;W!R879I(&1V;W-M:7-L96YE(&]D;F]S;F\@:6YV86QI9&YE(&%D<F5S
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")-;VQI;2!T92!P;W!R879I(&1V
M;W-M:7-L96YE(&]D;F]S;F\@:6YV86QI9&YE(&%D<F5S92XB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(DUO;&EM
M;R!D86IT92!K<F%T86L@;W!I<R!V8;EE9R!P<F]B;&5M82!S82!W96)M86EL
M;VTN(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(V"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(").
M:6IE('!O<VQA;F\@:V]R:7-N:>AK;R!I;64@:2]I;&D@N6EF<F$N(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!O;&%N
M9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ
M"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@
M24U!4"DB"FUS9W-T<B`B4VQA;FIE('4@;W9A:B!F;VQD97(@*&YI:F4@<')I
M;G7P96YO(&]D('-T<F%N92!)34%082DB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX
M"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B
M4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO
M;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A
M="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,U"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(E!A<W-W;W)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*(RP@9G5Z>GD*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B4')E=&AO9&YA('-T<F%N82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM
M<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U
M<R!O<'1I;VYS(@IM<V=S='(@(E!R971H;V1N92!O<&-I:F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0
M<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G
M:60@(E!R;V)L96TB"FUS9W-T<B`B4')O8FQE;3\B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B3W!I<R!P<F]B;&5M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"B,L(&9U
M>GIY"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R("))<W!R879L:F5N('1E
M:W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O
M(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I
M9"`B46%T87(B"FUS9W-T<B`B1&%T=6TB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`HC+"!F=7IZ>0IM<V=I
M9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*(RP@
M9G5Z>GD*;7-G:60@(E)A:6XB"FUS9W-T<B`B57!O>F]R96YJ92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*
M;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-@HC+"!F=7IZ>0IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B3W!C:6IE(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*(RP@9G5Z
M>GD*;7-G:60@(E)E860B"FUS9W-T<B`B3F4@<')OZ&ET86YE(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E
M860@;65S<V%G97,B"FUS9W-T<B`BR&ET86YJ92!P;W)U:V$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E
M;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A
M;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(E)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IE('-E
M<G9I<V$B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R97-H($1Y
M;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B0;YU<FER86H@9&EN86UI
MZ&ME(&5L96UE;G1E(&UE;FEJ83HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!
MOG5R:7)A:B!P;^AE=&YU('-T<F%N:6-U.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G:60@
M(E)E9V5X(@IM<V=S='(@(E!O;FFY=&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS9VED(")2
M96QO860B"FUS9W-T<B`B3F4@<')OZ&ET86YE(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,C8*(RP@9G5Z>GD*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B
M6F%B:6QJ9;EK92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E5D86QJ96YI('-E<G9E<FDB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G
M<W1R(")59&%L:F5N:2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PHC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(@IM<V=S='(@(DYA<W1A=FDB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!"
M;&]C:R(*;7-G<W1R(")5:VQO;FD@;V1A8G)A;FDB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(G!O;6IE<FD@;FF^92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(DEN9F]R;6%C
M:6IE('-E<G9I<V$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R
M.`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B<&]M:F5R
M:2!V:;EE(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R(")5:VQO;FD@;V1A8G)A;FDB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*
M;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ
M,0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B:7IB86-I
M(&EZ=F]R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B
M"FUS9W-T<B`B:7IB86-I(&EZ=F]R(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS
M=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E
M9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER
M960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*
M;7-G:60@(E)E<V5T(@IM<V=S='(@(E!O;FFY=&DB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S
M<W=O<F0B"FUS9W-T<B`B4&%S<W=O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S
M=V]R9"(*;7-G<W1R(")087-S=V]R9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE;&PN<&AP.C(X
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")297IU;'1A=&D@<')E=')A9V4B"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(DYA>F%D(&YA
M(&]P8VEJ92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`HC
M+"!F=7IZ>0IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R(")0
M87-S=V]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T
M<B`B4F5U;FEO;B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R
M871I;VXB"FUS9W-T<B`B5G)A=&D@<W1A<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")/<&-I:F4@961I=&]R82!T96MS=&$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2:6=H="(*;7-G<W1R
M(").;^8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED
M(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM
M<V=S='(@(EIA9&YJ82!S=')A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@
M(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")/<V]B:6YE(.9?96QI:F4N
M+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C,T"B,L(&9U>GIY"FUS9VED(")2;VQE(@IM<V=S='(@(DYA<W1A=FDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*(RP@9G5Z
M>GD*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B3&ES=&$@:V]N=&%K=&$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R
M"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("),:7-T82!K
M;VYT86MT82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C@*(RP@9G5Z>GD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R
M("),:7-T82!K;VYT86MT82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*(RP@9G5Z>GD*;7-G:60@(E)O=R!0
M<F]P97)T:65S(@IM<V=S='(@(D]S;V)I;F4@YE]E;&EJ92XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*
M(RP@9G5Z>GD*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(D]S;V)I
M;F4@YE]E;&EJ92XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S
M"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R(")297IU;'1A=&D@<')E
M=')A9V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C`*(RP@9G5Z>GD*;7-G:60@(E)U;B(*;7-G<W1R(")2975N:6]N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G
M<W1R(")+86YA9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0HC+"!F
M=7IZ>0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")5<VUJ97)E;FIE(&YI:F4@=7-P96QO+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--
M4R!-97-S86=I;F<B"FUS9W-T<B`B4')E9VQE9&%V86YJ92!P;W)U:V4B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED
M(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C8Q"B,L(&9U>GIY"FUS9VED(")382(*;7-G<W1R(")38>AU
M=F%J(&MA;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N
M9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(E-A;6]A(@IM<V=S='(@
M(DMA;6)O\&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")386X@
M36%R:6YO(@IM<V=S='(@(E5P;WIO<F5N:F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E
M(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A
M=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z.3@*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B4V'H
M=79A:B!K86\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*
M;7-G<W1R(")38>AU=F%J(&MA;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S
M(@IM<V=S='(@(E-AZ'5V86H@:V%O(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E-AZ'5V86H@
M;W!C:6IE(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B5G)A=&D@<W1A<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB
M+B(*;7-G<W1R(").:6IE(&)I;&\@;6]G=6-E(&]B<FES871I('!O<G5K92!O
M9"`E<SH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A
M<F-H(@IM<V=S='(@(E1R8;YI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R,`HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B4F5Z=6QT871I('!R971R86=E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDW,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S
M='(@(D]D86)E<FD@<W9E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T
M92(*;7-G<W1R(")/9&%B97)I(&ED96YT:71E="(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3DX"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S
M;&]V83HB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U
M>GIY"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B3V1A8F5R
M:2!N;VYE(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B27IA8F5R:71E('-E<G9E
M<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")/9&%B97)I
M(&MO9&YI(')A<W!O<F5D('-L;W9A.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A;&PB"FUS9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B4')I;&]G(&IE(&]B<FES86XN(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")/9&%B
M97)I(&YO;F4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R
M(")/9&%B97)I(&YO;F4B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*
M;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M
M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A
M<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B3V1A8F5R:2!K;V1N
M:2!R87-P;W)E9"!S;&]V83HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB
M"FUS9W-T<B`B3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")3
M96QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T
M<B`B27IA8F5R:71E(&ED96YT:71E="!K;VII(+YE;&ET92!P<F]M:6IE;FET
M:3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B3V1A
M8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V83HB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR-0HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE
M(&9O<FUA=#HB"FUS9W-T<B`B3V1A8F5R:2!K;V1N:2!R87-P;W)E9"!S;&]V
M83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B
M3V1G;W9A<F%J=>9A('!O;&IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R
M("))>F%B97)I=&4@N65M=2!B;VIA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93HB"FUS9W-T<B`B27IA8F5R:71E(+YE;&IE;FD@:F5Z:6LZ(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B4&^Y86QJ:2!P<FEJ879U('!R;V)L96UA
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E!ON6%L:FD@4TU3(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E;G-O<CH@(@IM
M<V=S='(@(E-E;GIO<CH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T
M96UB87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-R8FEJ
M82!I($-R;F$@1V]R82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E-E<FEJ
M<VMI(&)R;VHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q
M"B,L(&9U>GIY"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(").96UA(&1O<W1U<&YI:"!O<&-I:F$N(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N
M($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<F%C:6IA(&1O>G9O;&$@*'!R:79I
M;&5G:6IA*2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G
M<W1R("))1"!S97-I:F4@:F4@:7-T96MA;RXB"@HC.B!L:6(O87!I+G!H<#HQ
M-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E]$;WIV;VQE
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B4V5T
M(@IM<V=S='(@(D]D86)E<FDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y
M;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B
M(@HB4&]D97-I=&4@;W!C:6IE(&MO:F4@=F%M(&]M;V=UYG5J=2!D82!P;VYI
MN71I=&4@N6EF<G4@86MO(&IE('IA8F]R879I=&4N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(B(*(E!O9&5S:71E('5D86QJ96YE('-E<G9E<F4@:V]J:6UA(+YE
M;&ET92!P<FES='5P:71I('!U=&5M('9AN65G('!O<G1A;&$N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S
M='(@(D]D86)E<FET92"^96QJ96YI(&IE>FEK+"!V<F5M96YS:W4@>F]N=2!I
M('!O<W1A=FME('IA(&1A='5M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(E!O9&5S:71E('-T87)T;G4@
M:V]M<&]N96YT=2P@N65M=2!B;VIA+"!O<W9J9;YA=F%N:F4@<W1R86YI8V4@
M:2!D<G5G92!O<&-I:F4@(@HB:V]J92!S92!T:>AU('!R:6MA>F$N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T
M<B`B4&]S=&%V:V4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")397EC:&5L;&5S(@IM<V=S='(@(E-E:KEE;&DB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B
M4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+<F%T86L@;W!I<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")$82!L:2!D
M969I;FES871I('!R:7-T=7!N92!T:7!K92!Z82!L:6YK;W9E/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W
M(@IM<V=S='(@(E!R:6MAOFDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B4')I:V&^:2!V<FEJ96UE('IA9&YJ92!P<FEJ879E(&YA
M:V]N(&QO9VER86YJ83\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@
M(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\B"FUS9W-T<B`B4')I:V&^:2!M96YI('IA(&UA;FEP=6QA8VEJ92!T86)E
M;&%M83\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM
M<V=S='(@(E!R:6MAOFD@)7,@;65N:2!L:6IE=F\_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED
M(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV-`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B4')I:V&^:2!M96YI('IA(&UA
M;FEP=6QA8VEJ92!T86)E;&%M83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*(RP@
M9G5Z>GD*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(D1O=VYL;V%D(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@
M9G5Z>GD*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B4')I:V&^:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"B,L(&9U>GIY
M"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(DMR871A:R!O<&ES(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G
M:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G
M:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@
M;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B4VEG;B!U
M<"(*;7-G<W1R("(E<R!P<FEJ879A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,3(*(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R92(*
M;7-G<W1R(")68;D@<&]T<&ES.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S$Q"B,L(&9U>GIY"FUS9VED(")3:6=N871U<F4@06QG
M;W)I=&AM(@IM<V=S='(@(E9AN2!P;W1P:7,Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC
M+"!F=7IZ>0IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(E9AN2!P;W1P:7,Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ
M92(*;7-G<W1R(")696QIZ&EN82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E
M(@IM<V=S='(@(E!R97-K;^AI('-E<G9I<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G
M:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S
M='(@(E!R:6MAOFDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@
M(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I
M9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B!496UA.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A
M=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO
M;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O
M;6%L:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P
M"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,C8*(RP@9G5Z>GD*;7-G:60@(E-O<G0@;W)D
M97(@<V5L96-T:6]N(@IM<V=S='(@(E!R879A8R!S;W)T:7)A;FIA(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$X.0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M5F&Y82!E+6UA:6P@861R97-A.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O
M=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(DIUOFYO+65V<F]P<VMI("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S
M(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P
M:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N
M="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT
M96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX,34*(RP@9G5Z>GD*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")38>AU=F%J(&MA;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"B,L(&9U>GIY
M"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")3<&5C
M:6IA;&YI(&MA<F%K=&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*;7-G:60@(E-P;&ET
M(&-E;&PB"FUS9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"B,L(&9U>GIY"FUS
M9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B3V1A8F5R:2!S=F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q
M"B,L(&9U>GIY"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B3V1A8F5R:2!S
M=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A
M<F0B"FUS9W-T<B`B2V%L96YD87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B
M4W1O<F%G92!F;W)M870B"FUS9W-T<B`B26YF;W)M86-I:F4@<V5R=FES82(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U
M>GIY"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")/9"!A9')E<V4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S,*(RP@9G5Z>GD*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(FQI<W1A('IA9&%T86MA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE
M(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEJ
M92!P<F]N8?!E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(E1E;6$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$W"B,L(&9U>GIY"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B5&5M82(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B
M"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"B,L(&9U
M>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B5&5M82(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R(")5<W!J9;EN;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!J92!U
M<W!E<VYO(&1O9&%N('4@861R97-A<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R
M-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R(")<(B5S7"(@:F4@=7-P97-N;R!D;V1A;B!U(&%D<F5S87(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D
M96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B26UE(&9O;&1E<F$@7"(E<UPB(&IE
M('5S<&IEN6YO('!R;VUJ96YJ96YO('4@7"(E<UPB+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T
M<B`B7"(E<UPB(&IE('5S<&5S;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB
M)7-<(B(*;7-G<W1R("));64@9F]L9&5R82!<(B5S7"(@:F4@=7-P:F6Y;F\@
M<')O;6IE;FIE;F\@=2!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M("));64@9F]L9&5R82!<(B5S7"(@:F4@=7-P:F6Y;F\@<')O;6IE;FIE;F\@
M=2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")+
M<F%T86L@;W!I<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0HC+"!F
M=7IZ>0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B5&5M82(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R(")496UA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@(E-U
M;G)I<V4B"FUS9W-T<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B5&5M82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4Z
M("(*;7-G<W1R("(@5&5M83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E1E
M;6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"B,L(&9U
M>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(@5&5M83H@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PHC+"!F=7IZ
M>0IM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B5&5M82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B
M"FUS9W-T<B`B26UE(&1A=&]T96ME(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B"FUS
M9W-T<B`B57-E<FYA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R
M9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@
M9G5Z>GD*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")4<F&^:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-W961E;B(*;7-G<W1R(")6:61J
M96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"B,L(&9U>GIY
M"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(E5N9&5L971E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I9"`B4WEN8TU,(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY
M-PHC+"!F=7IZ>0IM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<R(*;7-G<W1R("))<W!R87IN:2!F;VQD97(@:V]R<&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"B,L(&9U>GIY"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G
M<W1R(")#96YT<F%L;F\M069R:>AK82!297!U8FQI:V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*
M(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(D]D(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M
M4W1O<FUS($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED
M(")486)L92(*;7-G<W1R("):861N:F$@<W1R86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ
M>0IM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")/<V]B:6YE(%]T
M86)E;&4N+BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@HC
M+"!F=7IZ>0IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")/<V]B
M:6YE(%]T86)E;&4N+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M86EW86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A
M<F=E=#HB"FUS9W-T<B`B4&]R=6MA(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"B,L(&9U>GIY
M"FUS9VED(")487-K<R(*;7-G<W1R("),;V=I;B!Z861A8VDB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PHC+"!F=7IZ>0IM<V=I
M9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")397)I:G-K:2!B<F]J(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA
M<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$T"FUS9VED(")496UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(
M:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M)7,@;FEJ92!P<F]N8?!E;BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V
M.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B)7,@861M:6YI<W1R86-I:F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G
M:60@(E1E>'0B"FUS9W-T<B`B5&5K<W0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<U"B,L(&9U>GIY"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M5&5K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<T"B,L(&9U>GIY"FUS9VED(")497AT(&%L:6=N(@IM<V=S
M='(@(E-L:F5D96-A('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B
M"FUS9W-T<B`B5&5K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&AA:6QA
M;F0B"FUS9W-T<B`B5')AOFDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B2'9A;&$@N71O(&MO<FES=&ET92!%;F5R9V]D871A('=E8FUA
M:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*(RP@9G5Z
M>GD*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(DE0(&%D<F5S82!N:6IE(&1O<W1U<&YA+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O
M=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R(")0<F]Z;W(@>F$@;W!C:6IE('-E('IA='9O<FEO+B!)>FQA>FEM+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M
M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R
M;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES
M<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)
M1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S
M(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B7"(E<UPB(&IE('5S
M<&5S;F\@9&]D86X@=2!A9')E<V%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S
M(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS
M9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS
M9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM
M<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("))9&5N=&ET970@7"(E<UPB(&IE(&]B<FES86XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM
M<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B3W9A
M('9R:6IE9&YO<W0@;6]R82!B:71I(&)R;VHN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N
M<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC
M92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@
M97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z
M,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP
M:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP
M:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM
M<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I
M9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<
M(B!J92!O8G)I<V%N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B261E;G1I=&5T(%PB)7-<
M(B!J92!S8>AU=F%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R("))9&5N=&ET970@7"(E<UPB
M(&IE('-AZ'5V86XN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE
M(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@
M;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H
M<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(E1H92!W96%T:&5R+F-O
M;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(").96UA(&1O<W1U
M<&YI:"!O<&-I:F$N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92XB"FUS9W-T<B`B3F5M82!D;W-T=7!N:6@@;W!C:6IA+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@HC+"!F=7IZ>0IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(DYE;6$@9&]S='5P;FEH(&]P8VEJ82XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB
M>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK
M82!T;VMO;2!S;&%N:F$@<&]R=6ME.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO
M=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B1&5S:6QA
M('-E(&=R9;EK82!T;VMO;2!S;&%N:F$@<&]R=6ME.B`E<R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@
M(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<VQA;FIA('!O<G5K93H@)7,B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B
M(@HB2F%V:6\@<V4@<')O8FQE;2!S82!D;V1A=F%N:F$@9&%T;W1E:V4N($UO
M9W7F:2!P<F]B;&5M+"!D871O=&5K82!J92!V9>9A(&]D("(*(FUA>"!D;WIV
M;VQJ96YI:"!-0BXB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN(@IM<V=S='(@(B(*(DIA=FEO('-E('!R;V)L96T@<V$@9&]D879A
M;FIE;2!D871O=&5K92X@36]G=>9I('!R;V)L96TL('9E;&GH:6YA(&1A=&]T
M96ME("(*(FIE('9EYF$@;V0@;6%X+B!D;WIV;VQJ96YI:"`H)60@34(I+B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL
M>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB2F%V:6\@<V4@<')O8FQE;2!S82!D
M;V1A=F%N:F$@9&%T;W1E:V4N($UO9W7F:2!P<F]B;&5M+"!D871O=&5K82!J
M92!V9>9A(&]D("(*(FUA>"!D;WIV;VQJ96YI:"!-0BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R(")$97-I;&$@<V4@9W)EN6MA('1O:V]M('!R:6MA>F$@;W9O9R!D
M:6IE;&$@<&]R=6ME(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")$97-I;&$@
M<V4@9W)EN6MA('1O:V]M('-P8;EA=F%N:F$@;F5Z879RN65N92!P;W)U:V4N
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"B,L(&9U>GIY
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L
M96YD87(@9&%T82XB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK82!T;VMO;2!S
M<&&Y879A;FIA(&YE>F%V<KEE;F4@<&]R=6ME+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R(")$97-I
M;&$@<V4@9W)EN6MA('1O:V]M(.AI=&%N:F$@;V1A8G)A;F4@<&]R=6ME+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,X"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R
M9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@
M4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5S:6QA('-E
M(&=R9;EK82!T;VMO;2#H:71A;FIA(&]D86)R86YE('!O<G5K92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC
M+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(D1E<VEL82!S92!G<F6Y:V$@=&]K;VT@<')I:V%Z82!O=F]G
M(&1I:F5L82!P;W)U:V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B1&5S:6QA('-E(&=R9;EK
M82!T;VMO;2#H:71A;FIA(&]D86)R86YE('!O<G5K92XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G
M:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(E9AN2!B<F]W<V5R(&YE('!O9'*^879A(&]V
M=2!M;V=UYFYO<W0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E
M87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B)7,@;F4@
M:7IG;&5D82!K86\@9&]Z=F]L:F5N('1I<"!S86YD=6-E=&$N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92XB"FUS9W-T<B`B)7,@;F4@:7IG;&5D82!K86\@9&]Z=F]L:F5N('1I
M<"!S86YD=6-E=&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T
M-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@
M=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(B5S(&YE(&EZ9VQE9&$@:V%O
M(&1O>G9O;&IE;B!T:7`@<V%N9'5C971A+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q
M-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I
M96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O
M;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R(")/=F$@=G)I:F5D;F]S="!M;W)A(&)I
M=&D@8G)O:BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS
M9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A
M9B<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V
M,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@
M5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*
M(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@
M9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P
M;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S
M*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E9R:6IE9&YO<W0@;W9O
M9R!B<F]J82!M;W)A(&YA:FUA;FIE(&EZ;F]S:71I(#$N(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C
M=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E
M<BXB"FUS9W-T<B`B3W9A('9R:6IE9&YO<W0@;6]R82!B:71I(&)R;VHN(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B
M5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I
M;F1O=R(*;7-G<W1R(")/=F%J('!R;WIO<B!S92!S;6EJ92!P;WII=F%T:2!S
M86UO(&EZ('!R;WIO<F$@3W!C:6IE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC
M:V5T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM
M<V=I9"`B5&EM92(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"B,L(&9U>GIY
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")6<F5M96YS:V$@>F]N82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*(RP@9G5Z>GD*;7-G
M:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E9R96UE;G-K82!Z;VYA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`B5G)E;65N<VMA('IO;F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I
M<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(EIA(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B
M(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC
M:VEN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,0HC+"!F=7IZ>0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B5&EJ96QO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`B6F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*(RP@9G5Z>GD*;7-G:60@
M(E1O;6]R<F]W(@IM<V=S='(@(B`H<W5T<F$I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`HC
M+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B6F$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(RP@9G5Z
M>GD*;7-G:60@(E1O<"(*;7-G<W1R("):82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H
M7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"B,L(&9U>GIY"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B06MC:6IA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS
M9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M
M.#@U.2TY*2(*;7-G<W1R(")4=7)S:VD@*$E33RTX.#4Y+3DI(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*(RP@9G5Z>GD*;7-G:60@(E5G86YD82(*;7-G<W1R
M(")+86YA9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5:W)A
M:6YE(@IM<V=S='(@(E5N9&5L971E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HY-@IM<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN
M9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HX,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,S4*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DYE
M(&UO9W4@<V4@<W!O:FET:2!N82!)34%0('-E<G9E<CH@)7,B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A
M<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#`S"FUS9VED(")5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?
M24U34"])35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM
M<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR
M,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HS,C,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P"B,L(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`B56YD96QE=&4B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B4&]N:;ET:2!I>FUJ
M96YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`B3F5K871E9V]R:7-A;F\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6MO9"`H
M551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A
M=&5S(@IM<V=S='(@(E5J961I;FIE;FD@07)A<'-K:2!%;6ER871I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"B,L(&9U>GIY"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(E5J961I;FIE;FD@07)A<'-K:2!%;6ER871I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HV.2!L:6(O0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED
M(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(").97!O
M>FYA=&\@:V]R:7-N:>AK;R!I;64@:6QI(+EI9G)A+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`HC+"!F
M=7IZ>0IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T
M<B`B4&]D97-I('9R96UE;G-K=2!Z;VYU+B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D(@IM<V=S='(@
M(D)E>FEM96YI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N
M;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R
M("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H
M;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@
M:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R(")0<FEM;&IE;F$@<')I:F4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"B,L(&9U>GIY"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`B1&%T=6TB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E
M<B(*;7-G<W1R(")$871U;2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B1&%T=6TB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I
M9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA
M=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I
M9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")$96-E;6)A<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(DMO<FES=&ET
M92!O=F\@86MO('-E(&EM92^Y:69R82!R87IL:6MU:G4@>F$@24U34"!S97)V
M97(N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC
M+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R(")5<V5R;F%M92(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S
M+B(*;7-G<W1R(")+;W)I<VYI:R`E<R!N96UA(&1O>G9O;'4@>F$@)7,N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"B,L(&9U>GIY"FUS9VED(")5<V5R($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(B5S(&%D;6EN:7-T<F%C:6IA(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@
M3W!T:6]N<R(*;7-G<W1R(")+;W)I<VYIZ&ME(&]P8VEJ92(*"B,Z('-I9VYU
M<"YP:'`Z-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E
M9VES=')A8VEJ82!K;W)I<VYI:V$B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI
M<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#8Y"B,L(&9U>GIY"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM
M<V=S='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B2V]R:7-N:>AK;R!I;64B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(D9O;&1E<B!<(B5S7"(@=F7F('!O<W1O:FDB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E5S97)N86UE.B(*;7-G<W1R(")5<V5R;F%M92(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B57-E<FYA;64B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,3@*(RP@9G5Z>GD*;7-G:60@(E9A8V%T:6]N(@IM
M<V=S='(@(D%K8VEJ82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@V
M-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S
M.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H
M92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R
M;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T
M"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS
M9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P,`HC+"!F=7IZ>0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("),:>AN
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*(RP@9G5Z>GD*
M;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R("),:>AN;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*
M(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(E-L:F5D
M96-A('-T<F%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I9"`B5FEE
M="!.86TB"FUS9W-T<B`B26UE(&1A=&]T96ME(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R
M"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B4')I:V%Z
M("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A
M;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B4')I:V%Z("5S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L
M(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*
M;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF
M;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")5<&]Z;W)E;FIE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM
M<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(*(RP@9G5Z>GD*;7-G:60@(E=E871H97(N
M8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X
M"FUS9VED(")7965K;'DB"FUS9W-T<B`B4V5D;6GH;F\B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M(")$;V)R;R!D;[EL:2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(D1O8G)O(&1ON6QI(&YA
M("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(D1O8G)O(&1ON6QI+"`E<R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M*2(*;7-G<W1R("):87!A9&YI("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB
M"FUS9W-T<B`B6F%P861N:2`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(EIA<&%D;F$@4V%H87)A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/R(*;7-G<W1R(")+;VIU(&MO;7!O;F5N='4@YF4@)7,@<')I
M:V%Z871I(&YA:V]N('5L87IA/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C
M=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA
M<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*
M;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!4
M97AT(&5D:71O<BXB"FUS9W-T<B`B2V]J92!D;V1A=&ME(+YE;&ET92!A:W1I
M=FER871I('IA(&5D:71O<B!F;W)M871I<F%N;V<@*')I8V@I('1E:W-T82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@T"B,L(&9U>GIY"FUS9VED(")7:61T:"(*;7-G<W1R(")4<F&^:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H
M(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R("(B"B*I:7)I;F$@)7,@;65N:6IA('-A(&QI:F5V92!S
M=')A;FEC92`H<W1U<&$@;F$@<VYA9W4@:V]D('-L:F5D9>9E('!R:6IA=F4I
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@
M9G5Z>GD*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B3&ET=F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0HC+"!F
M=7IZ>0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(E1R8;YI(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED
M(")7:6YD(@IM<V=S='(@(E1R8;YI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E=I;F0@16%R
M;'DB"FUS9W-T<B`B5')AOFDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P
M"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*
M;7-G<W1R(")4<F&^:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#(*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")4<F&^:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B
M5VES9&]M(@IM<V=S='(@(E1R8;YI(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7;W)K(@IM
M<V=S='(@(FEL:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S
M='(@(D]D(&%D<F5S92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.3(*(RP@9G5Z>GD*;7-G:60@(E=O<FL@4&AO;F4B"FUS
M9W-T<B`B5&5L969O;B`H:W7F:2DB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@
M;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T
M("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I
M9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P
M.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(*;7-G:60@(E@U,#EV
M,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C4P"FUS9VED(")962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-34*;7-G:60@(EE965DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY
M(@IM<V=S='(@(D=O9&FY;FIE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM
M<V=I9"`B665M96XB"FUS9W-T<B`B5FED:F5N82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G
M<W1R(")$82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC
M92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@
M8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B3F4@;6^^92!S861ROF%V
M871I("=<7"<@:V%R86MT97(@=2!T=F]M('!U;F]M(&EM96YU+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DW-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(").961O>G9O;&IE;F$@
M<VQO=F$@=2!E;6%I;"!A9')E<VDN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@
M;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@
M8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA=F4@
M8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")/9&IA=FQJ:79A;FIE(&IE('5S
M<&IEN6YO(&EZ=G*Y96YO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"B,L
M(&9U>GIY"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E
M+B(*;7-G<W1R(").961O>G9O;&IE;F$@<VQO=F$@=2!E;6%I;"!A9')E<VDN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S
M92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE
M;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T
M:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DUO<F%T
M92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(DUO
M<F%T92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(DUO
M<F%T92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI=&4@8G)I<V%T:2XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B36]R871E(&]D86)R871I
M(&ED96YT:71E="!K;VII(+YE;&ET92!B<FES871I+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$T-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A
M=&D@:61E;G1I=&5T(&MO:FD@OF5L:71E(&)R:7-A=&DN(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"B,L(&9U>GIY"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M(@IM<V=S='(@(DUO<F%T92!O9&%B<F%T:2!I9&5N=&ET970@:V]J:2"^96QI
M=&4@8G)I<V%T:2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP
M92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")-;W)A=&4@;V1A8G)A
M=&D@:61E;G1I=&5T(&MO:FD@OF5L:71E(&)R:7-A=&DN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G
M:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP
M:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(@)7,@<V5S:6IA
M(&IE(&ES=&5K;&$N($UO;&EM;R!D82!S92!P;VYO=F\@<')I:F%V:71E+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9
M;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B5F&Y82!E+6UA:6P@861R97-A
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B66]U<B!&
M<F]M.B!A9&1R97-S.B(*;7-G<W1R(")68;EA($9R;VTZ(&%D<F5S83HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T
M<B`B5F&Y92!I;F9O<FUA8VEJ92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T
M($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E9AN6$@26YT97)N
M970@861R97-A(&IE('!R;VUI:F5N:F5N82!N86MO;B!P<FEJ879L:FEV86YJ
M82!N82`E<RX@1&$@8FD@=F&Y82`B"B)S:6=U<FYO<W0@8FEL82!S8>AU=F%N
M82P@;6]R871E('-E('!O;F]V;R!P<FEJ879I=&DN(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R(")68;EE(&EM92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T
M=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E9AN6$@26YT
M97)N970@861R97-A(&IE('!R;VUI:F5N:F5N82!N86MO;B!P<FEJ879L:FEV
M86YJ82!N82`E<RX@1&$@8FD@=F&Y82`B"B)S:6=U<FYO<W0@8FEL82!S8>AU
M=F%N82P@;6]R871E('-E('!O;F]V;R!P<FEJ879I=&DN(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B5F&Y(&)R;W=S97(@
M;F4@<&]D<KYA=F$@;W9U(&UO9W7F;F]S="XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]P<FEN="YJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R
M97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@
M(B(*(E9AN2!B<F]W<V5R(&YE('!O9'*^879A(&]P8VEJ=2"Y=&%M<&%N:F$N
M(%!R:71I<VYI=&4@=&EP:V4@0V]N=')O;"M0(&EL:2`B"B)/<'1I;VXK4"!Z
M82"Y=&%M<&%N:F4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM
M<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B5')E;G5T
M;F$@=G)E;65N<VMA('IO;F$Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"XB"FUS9W-T<B`B5F&Y(&1E9F%U;'0@:61E;G1I=&5T.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F
M875L="!I9&5N=&ET>3HB"FUS9W-T<B`B5F&Y(&1E9F%U;'0@:61E;G1I=&5T
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@
M9G5L;"!N86UE.B(*;7-G<W1R(")68;EE(&EM92!I('!R97II;64Z(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B3W!C:6IE('-U('-A
MZ'5V86YE+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,B"FUS9W-T<B`B5F&Y82!N;W9A(+EI9G)A('IA("5S(&IE.B`E<R(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E9AN64@;W!C:6IE('-U('-A
MZ'5V86YE('1O:V]M('1R86IA;FIA(&]V92!S97-I:F4N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B3W!C:6IE('-U('-AZ'5V
M86YE+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED
M(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(E9AN6$@
MN6EF<F$@:F4@<&]N:;ET96YA(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W
M("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)68;EA(+EI9G)A(&IE('!O;FFY
M=&5N82P@<')O=FIE<FET92!V8;D@92UM86EL(&D@<')I:F%V:71E('-E('-A
M(&YO=F]M("(*(KEI9G)O;2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N(@IM<V=S='(@(E9AN6$@N6EF<F$@:F4@<&]N:;ET96YA(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T
M92!S97)V97)S.B(*;7-G<W1R(")68;EI('5D86QJ96YI('-E<G9E<FDZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R
M(")*=6=O<VQA=FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEJ82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G9E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R
M(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*
M;7-G<W1R(");4V%K<FEJ(&-I=&ER86YI('1E:W-T72(*"B,Z('-E<G9I8V5S
M+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S
M='(@(EM0<FEJ879A('!R;V)L96UA72(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X
M="`M(@IM<V=S='(@(EM0<FEK8;YI(&-I=&ER86YI('1E:W-T("TB"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(EM0<FEK8;YI(&-I=&ER86YI('1E:W-T
M("T@)7,@<F5D;W9A72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G
M<W1R(");<F5D("5S(&]D("5S72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED
M(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T<F%C:6IA(@H*
M(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#3$DB
M"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G<W1R
M(")?1&%T851R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S
M='(@(E]/8G)IN6D@<F5D(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?
M1W)O=7!S(@IM<V=S='(@(E]'<G5P92(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E]0;VUO
MYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T
M<B`B7T]S;V)I;F4@<VQI:V4N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]0<FEJ
M879I('-E(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B7TEZ;&%Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS
M9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B7TEZ;6EJ96YI(&QI;FLN
M+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS
M9VED(")?3W!T:6]N<R(*;7-G<W1R(")?3W!C:6IE(@H*(SH@;&EB+V%P:2YP
M:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7T1O>G9O;&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?56ML
M;VYI(&QI;FLN+BXB"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U
M<"(*;7-G<W1R(")?4&]D97-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")/<V]B:6YE(%]T86)E;&4N+BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?2V]R:7-N
M:6-I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@
M(F%D9')E<W,@8F]O:R(*;7-G<W1R(")I;65N:6LB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM<V=I9"`B861D
M<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B:6UE;FEK(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,3,*(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R
M(@IM<V=S='(@(DMA;&5N9&%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED
M(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R
M;W(B"FUS9W-T<B`B5G)A=&D@<W1A<G4@:V]N9FEG=7)A8VEJ=2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O
M<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O
M=6YD(@IM<V=S='(@(B5S(&YI:F4@<')O;F'P96XN(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(DYE:V%T96=O<FES
M86YO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B
M"FUS9W-T<B`B)7,@=2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B
M075G=7-T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*
M;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`B;F]N92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS
M.C$S"B,L(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;F]N92(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@
M)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C,R"B,L(&9U>GIY"FUS9VED(")N86UE(@IM
M<V=S='(@(DEM92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*(RP@
M9G5Z>GD*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(").92!I>F)R
M:7-A;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M,3D*(RP@9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T
M<B`B3F4@:7IB<FES86YA(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,#4*(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B3F4@<')O
MZ&ET86YE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.`HC+"!F=7IZ>0IM<V=I9"`B<&5R8V5N="(*;7-G<W1R
M(")0<F]C96YA="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R(")$;WIV;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED
M(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*
M;7-G:60@(G)I<VEN9R(*;7-G<W1R(")5<&]Z;W)E;FIE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@
M=6YA=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@
M(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M3F4@<')OZ&ET86YE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS
M,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B;&ES=&$@
M>F%D871A:V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@
M(G1R>2!A9V%I;B(*;7-G<W1R(")+;V0@<W9A:V4@<')I:F%V92(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(G5N:69I960B
M"FUS9W-T<B`B3F5K871E9V]R:7-A;F\B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(F)E>B!I
M;65N82(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B27IB;W(@8F]J92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q
M"B,L(&9U>GIY"FUS9VED(")W.B(*;7-G<W1R(")&=V0Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM
M<V=S='(@(G=E871H97(N8V]M(@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O:61?240N<&\`````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C<P,3,S(#$P-3$U-#,T,30R
M(#`Q-S0W,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C($AO<F1E("T@26YD;VYE<VEA;B!,86YG=6%G92!4<F%N<VQA=&EO
M;@HC($-O<'ER:6=H="`H0RD@,C`P-2!(;W)D92!0<F]J96-T"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($AO<F1E('!A8VMA9V4N"B,@2F%M97,@/&IA;65S0&%C=&EO;FUE<W-A
M9V4N8V]M/BP@,C`P-2X*(PHC+"!F=7IZ>0IM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@,C`P-2TP."TP,UQN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#@M,#0@,#DZ,3`K,#(P,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!*86UE<R`\:F%M97-`86-T:6]N;65S<V%G92YC;VT^7&XB"B),
M86YG=6%G92U496%M.B!I9"`\:61`;&DN;W)G/EQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U5
M4RU!4T-)25QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@-V)I=%QN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E
M<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S<S"B,L(&9U>GIY"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R(")(87)I
M($EN:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*(RP@9G5Z
M>GD*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(D)E<V]K(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@
M(B!P861A("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER
M96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@8F5L=6T@9&EB=6%T.B`E<RXB"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@
M=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<
M(B!S=61A:"!D:71A;6)A:&MA;B!K92!D86QA;2!S:7-T96T@9W)U<"XB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R(")<(B5S7"(@<W5D86@@9&ET86UB86AK86X@:V4@9&%L
M86T@:7II;B!S:7-T96TN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI
M;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!B
M96QU;2!D:6)U870Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@<W5D86@@9&EG=6YA
M:V%N(&1A<FD@)2XR9DU"('EA;F<@<W5D86@@9&EI:FEN:V%N("@E+C)F)24I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@9&%N
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B
M)60@:&%R:2!S86UP86D@<V%N9&D@86YD82!H86)I<R!M87-A(&)E<FQA:W5N
M>6$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M
M:&%R:2!R86UA;&%N(&-U86-A(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S
M='(@(B5S("T@4&5M8F5R:71A:'5A;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I
M;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M
M871I;VXB"FUS9W-T<B`B2V]N9FER;6%S:2`M($]P97)A<VD@4&5M96QI:&%R
M86%N("5S(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E
M='5P(@IM<V=S='(@(B5S(%-E='5P(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N
M(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B
M"FUS9W-T<B`B)7,@4WEA<F%T+7-Y87)A="!097)J86YJ:6%N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-3$@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S('!A9&$@)7,@)7,B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!S:6%P('5N='5K(&UE;&%K<V%N86MA
M;B!O<&5R87-I('!E;65L:6AA<F%A;B!Y86YG('-U9&%H(&1I=&%N9&%I(&1I
M(&)A=V%H("(*(FEN:2X@0F5R:6QA:"!T86YD82!P861A(&MO=&%K('1E<G-E
M8G5T('5N='5K(&]P97)A<VD@;6%N87!U;B!Y86YG(&%N9&$@(@HB:6YG:6YK
M86X@=6YT=6L@9&EL86MS86YA:V%N('!A9&$@=V%K='4@:6YI+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*
M;7-G<W1R("(E<R!M96YI="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HQ,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B5&ED86L@861A(&EK;VX@>6%N9R!D
M:71E;75K86XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M("(E<R!U;G1U:R`E<R`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E
M<W,@0F]O:R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@+2!096UB97)I=&%H
M=6%N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H
M<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I
M9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*(RP@9G5Z>GD*
M;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!A;F=I;B!K96YC86YG(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(BP@86YG:6X@:V5N8V%N9R`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@
M9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA8FQE(&1A<FD@)7,@:V4@
M)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.0IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R
M;6%T(#$R($IA;2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R;6%T(#(T($IA;2(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G
M<W1R("(R-"!J86TB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y
M"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B3&EH870B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B
M86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")$
M871A8F%S92!B86-K96YD(&1I<&5R;'5K86X@=6YT=6L@87)E82!I;FDN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,34*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P
M-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(D%-
M($UE;F1U;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")!32!'97)I
M;6ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B04T@2'5J86XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R(")!32!'97)I;6ES(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")!32!'97)I;6ES(%-A;&IU(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@
M=&AI<R!E9&ET;W(B"FUS9W-T<B`B5&5N=&%N9R!E9&ET;W(@:6YI(@H*(SH@
M<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM
M<V=S='(@(E1E;G1A;F<N+BX@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@
M(DIA<F%K(&%N=&%R82!B86=I86X@8F%W86@@8F%R:7,@9&5N9V%N(&)A9VEA
M;B!B87=A:"!G86UB87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B2F%R
M86L@86YT87)A(&)A9VEA;B!T96YG86@@8F%R:7,@9&5N9V%N(&)A9VEA;B!T
M96YG86@@9V%M8F%R(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@06-C
M;W5N="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R(")386YD:2!!8V-O=6YT(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"B,L
M(&9U>GIY"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B26YF;W)M
M87-I($%C8V]U;G0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S
M"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(D%K=6YT86YS:2(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E;7!L871E<R]P;W)T
M86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(E1A;6)A:"(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED
M(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B5&%M8F%H($=R=7`@06YA:R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B061D($-H
M:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B56)A:"!)>FEN(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R
M(")486UB86@@1&ES:6YI.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(E1A;6)A:"!'<G5P($)A<G4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")5
M8F%H($EZ:6XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD
M+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL
M9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B5&%M8F%H(&=R=7`@86YA:R!K
M92`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI
M<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(E1A;6)A:"!G<G5P(&%N86L@:V4@
M)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@
M=7-E<CHB"FUS9W-T<B`B5&%M8F%H('!E;F=G=6YA(&)A<G4Z(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`HC+"!F=7IZ
M>0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")0:7-A:&MA;B!K;VQO;2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@
M(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")486UB86@@86YG9V]T82!B87)U
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D
M('!A:7(B"FUS9W-T<B`B5&%M8F%H('!A<V%N9V%N(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B5&%M8F%H
M($UE;G4@)7,@<V5B86=A:2!086YE;"!N879I9V%S:2!-;WII;&QA(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U
M>GIY"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R(")"=6MU
M($%L86UA="`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B0G5K=2!!;&%M870@(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(E1A;6)A:"!P96YG9W5N82(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD
M(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S
M+B(*;7-G<W1R("(B"B(@)R5S)R!S=61A:"!D:71A;6)A:&MA;B!K92!D86QA
M;2!S:7-T96TL('1E=&%P:2!T:61A:R!D87!A="!M96YA;6)A:&MA;B`B"B)I
M;F9O<FUA<VD@<&5N9&%F=&%R86X@=&%M8F%H86XZ("5S+B(*"B,Z('-I9VYU
M<"YP:'`Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S
M='(@(B`G)7,G("!S=61A:"!D:71A;6)A:&MA;B!K92!D86QA;2!S:7-T96TN
M($%N9&$@9&%P870@;&]G(&EN('-E:V%R86YG+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(E!E;F%M8F%H86X@<&5N9V=U;F$@=&ED86L@
M9&EA:W1I9FMA;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,0HC+"!F
M=7IZ>0IM<V=I9"`B061D<F5S<R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S
M($)O;VLB"FUS9W-T<B`B0G5K=2!!;&%M870@(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(D%D
M;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM
M<V=S='(@(E5B86@@:7II;B!U;G1U:R`E<R(*"B,Z(&%D;6EN+VEN9&5X+G!H
M<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED(")!
M9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A<VDB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED(")!9',B"FUS9W-T<B`B
M26ML86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PHC+"!F=7IZ>0IM
M<V=I9"`B06QI87,B"FUS9W-T<B`B4F%T82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N
M(@IM<V=S='(@(E)A=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(E!E
M<F%T86%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!
M;&PB"FUS9W-T<B`B4V5M=6$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED
M(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")396UU82!096YG
M9W5N82!!<VQI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")396UU82!'
M<G5P(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"B,L(&9U>GIY"FUS
M9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G
M:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E-E;75A(&5M<&%T('-I<VDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B27II;FMA;B!P96YG871U<F%N(&1A
M<FD@=&EP92!D869T87(@;F]M;W(@8F5R=7)U=#\B"@HC.B!F<F%M97=O<FLO
M1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@
M97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(E!E;F=G
M86YT:2!,;V=I;B!)35-0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P
M-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B4&5N
M9V=A;G1I(%-A;F1I($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")0
M96YG9V%N=&D@3F%M82!096YG9W5N82!)35-0(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S(@IM<V=S='(@(E!E;F=G86YT:2!A;&%M870@96UA:6PB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E
M<R(*;7-G<W1R(")096YG9V%N=&D@=&5M<&QA=&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")096YG9V%N=&D@=&5K<SHB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C<*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@
M(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(DIA=V%B
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L
M:6-A=&EO;B(*;7-G<W1R(")!<&QI:V%S:2(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")$
M869T87(@07!L:6MA<VDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P
M"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B07!L:6MA
M<VD@<W5D86@@<VEA<"XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D1I
M9W5N86MA;B!U;G1U:R!"86=I86X@06YA:R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(D1I<V5T=6IU:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@
M(D%R86(@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,0IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI=F4@
M3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_(@IM<V=S='(@(B(*(D%P86MA:"!A;F1A('EA:VEN(&%N9&$@:6YG
M:6X@;65M:6YD86AK86X@<&5R;6]H;VYA;B!P96YD869T87)A;B!U;G1U:R`E
M<S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G
M<W1R(")!<&%K86@@86YD82!Y86MI;B!A;F1A(&EN9VEN(&UE;F=H87!U<R`G
M)7,G(&1A;B!S=6(M9W)U<"!M86YA<'5N/R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FUE;FEA("A!
M4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED
M(")!<G0B"FUS9W-T<B`B4V5N:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R=6)A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*
M;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B
M2V]D92!!<V-I:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B
M"FUS9W-T<B`B365M:6YT82!K;VYF:7)M87-I('-E8F5L=6T@;65L86MS86YA
M:V%N(&]P97)A<VD@<&5M96QI:&%R86%N/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3,*(RP@9G5Z>GD*;7-G:60@(D%S<VEG;FUE;G0@8V]L
M=6UN<R(*;7-G<W1R(")0:7-A:&MA;B!K;VQO;2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+B(*;7-G<W1R(")-96YC;V)A('5N='5K(&UE;F=H87!U<R!G
M<G5P('EA;F<@=&ED86L@861A+B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(DUE;F-O8F$@=6YT=6L@;65N9VAA<'5S
M(&EZ:6X@>6%N9R!T:61A:R!A9&$N(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")-96YC;V)A('5N='5K(&UE;F=U8F%H(&EZ
M:6X@>6%N9R!T:61A:R!A9&$N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N(@IM<V=S='(@(DUE;F-O8F$@=6YT=6L@;65N9W5B86@@8F%G:6%N
M('EA;F<@=&ED86L@861A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B06=U<W1U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")!=7-T
M<FEA(@IM<V=S='(@(D%G=7-T=7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD
M87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H
M870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S
M97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV
M,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM
M<V=S='(@(E-E;75A(%!E;F=G=6YA($%S;&DB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R
M96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I
M96QD<SHB"FUS9W-T<B`B2V]L;VT@>6%N9R!T97)S961I83HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@
M(D%L87-A;B!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R
M("),871A<B!"96QA:V%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS
M9W-T<B`B5V%R;F$@3&%T87(@0F5L86MA;F<B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN(@IM<V=S='(@(DUA<F=I
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")$87-A<B!D:7)E:W1O<FD@9W)A9FEK("<E<R<@=&ED86L@9&ET
M96UU:V%N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B2F%R86L@
M86YT87)A(&)A9VEA;B!B87=A:"!G86UB87(@9&5N9V%N(&=A<FES(&1A<V%R
M(&)A<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")*87)A:R!A
M;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@9V%R:7,@9&%S87(@
M8F%R:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"96YI;B(*;7-G
M<W1R(")*87)A:R!A;G1A<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@
M9V%R:7,@9&%S87(@8F%R:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H<"UF;W)M870*
M;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(E!E;F=A
M='5R86X@07)E82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW
M-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!E($%R96$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@
M(D)O;&0B"FUS9W-T<B`B2'5R=68@5&5B86PB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")0971U;FIU:R!H
M86QA;6%N('=E8B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")";W)D
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R(")+971E8F%L
M86X@0F]R9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")";W)D
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I
M9"`B0F]T:"(*;7-G<W1R(")+961U86YY82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S
M='(@(D)A=V%H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB
M"FUS9W-T<B`B4W5R870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*
M;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B1&%F=&%R($)U;&QE="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0
M<F]P97)T:2!37V5L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@
M(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T
M-@IM<V=I9"`B0V%L;2(*;7-G<W1R(")496YA;F<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B
M0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*(E1I9&%K(&1A<&%T(&UE;F=A='5R('5L86YG('-A;F1I('-E8V%R82!O
M=&]M871I<RP@<VEL86MA;B!H=6)U;F=I("(*(F%D;6EN:7-T<F%T;W(@86YD
M82XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A
M;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V
M97(Z("5S(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K92!S97)V
M97(@;&1A<"(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")#86YA9&$B
M"FUS9W-T<B`B2V%L96YD97(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M
M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A
M;F-E;"(*;7-G<W1R(")"871A;"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B0F%T86QK86X@3&%P;W)A;B!-87-A;&%H(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*
M;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B
M(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T
M:6]N(@IM<V=S='(@(DIU9'5L(%1A8F5L(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B
M0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I(&1A;B!,
M86)E;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(E!R
M;W!E<G1I(%-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G
M<W1R(")0<F]P97)T:2!396PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G
M<W1R(")*87)A:R!S<&%S:2!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D
M86QA;2!S96PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(G!R;W!E<G1I('-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S
M='(@(DIA<F%K('-P87-I(&%N=&%R('-E;"XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/
M+3@X-3DM,30I(@IM<V=S='(@(D-E;'1I8R`H25-/+3@X-3DM,30I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(E1E;F=A:"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B17)O<&$@5&5N9V%H("A)4T\M
M.#@U.2TR*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#
M97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L
M:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED
M(")#:&%D(@IM<V=S='(@(DMA<F%K=&5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E5B86@B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W
M;W)D(@IM<V=S='(@(E5B86@@4V%N9&D@06YD82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A
M9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P
M;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(E5B86@@;F%M82!D
M86X@86QA;6%T('-E:&EN9V=A(&]R86YG(&1A<&%T(&UE;&EH871N>6$@:V5T
M:6MA(&UE<F5K82!M96UB86-A("(*(F1A;B!M96UB86QA<R!K92!E;6%I;"!A
M;F1A+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I
M9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D
M('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-96YG=6)A:"!S86YD
M:2!A;F1A('1I9&%K(&1I9'5K=6YG(&1E;F=A;B!K;VYF:6=U<F%S:2!Y86YG
M('-E:V%R86YG+B!3:6QA:V%N("(*(FAU8G5N9VD@861M:6YI<W1R871O<B!A
M;F1A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B2V%R86MT97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E!E<FEK<V$@
M3&EN:RXN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM
M<V=S='(@(DIU9'5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B2V%R86MT97(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(D-I;F$@4V5D97)H86YA("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M(@IM<V=S='(@(D-I;F$@5')A9&ES:6]N:6P@*$)I9S4I(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B4V%N9&D@0F%R=2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S
M92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB
M"FUS9W-T<B`B4&EL:6@@8V%R82!U;G1U:R!M96YA;7!I;&MA;B!T86YG9V%L
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")0:6QI:"!D869T87(@=&EP92!G
M87EA("AU;G1U:R!D869T87(@;F]M;W(@8F5R=7)U="DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")$:7)E:W1O<FD@36]T
M:68@)R5S)R!T:61A:R!D:71E;75K86XN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@
M(D)E<G-I:&MA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B0F5R<VEH:V%N('1A9R!-4T]F9FEC92(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(D)E<G-I:&MA;B!P96YG9W5N82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U
M<V5R.B`E<R(*;7-G<W1R(")"97)S:6AK86X@<&5N9V=U;F$Z("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(D)E<G-I:&MA;B!P96YG9W5N82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R
M(&1A=&$B"FUS9W-T<B`B0F5R<VEH:V%N(&1A=&$@<&5N9V=U;F$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B
M0VQE87)I;F<@3&%T92(*;7-G<W1R(")#97)A:"!B96)E<F%P82!S86%T(&QA
M9VDB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:R!U
M;G1U:R!,86YJ=70B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B
M"FUS9W-T<B`B5'5T=7`@2F5N9&5L82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B365N9'5N9R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#
M;&]U9',@16%R;'DB"FUS9W-T<B`B365N9'5N9R!D:2!P86=I(&AA<FDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PIM<V=I
M9"`B0VQO=61Y(@IM<V=S='(@(D)E<F%W86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3
M:61E8F%R(@IM<V=S='(@(E!E<F)E<V%R(%!A;F5L($YA=FEG87-I("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(E!E<F)E<V%R
M(&)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-O;&]M8FEA
M(@IM<V=S='(@(E=A<FYA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(E=A<FYA(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC
M.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM
M<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(E!E;6EL:6@@5V%R;F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"B,L(&9U>GIY"FUS9VED
M(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM
M<V=I9"`B0V]L<SHB"FUS9W-T<B`B2V]L;VTB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R(")#;VUI8W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B0V]M;6%N9"(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R
M(")#;VUM86YD(%-H96QL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")#;VUM96YT(@IM<V=S='(@(D-O
M;6UA;F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-@HC+"!F=7IZ>0IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3F%M82!!
M;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(D-O;6]R;W,B"FUS
M9W-T<B`B0F5S;VLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,Y"B,L(&9U>GIY"FUS9VED(")#;VUP86YY(@IM<V=S='(@
M(E-A;&EN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B2V]M<'5T97(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,CDW"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B
M2V]N9&ES:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(DMO;F1I<VDB"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*
M;7-G<W1R(")097)B961A86X@2V]N9FEG=7)A<VDB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC
M:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(DMO;F9I9W5R
M87-I('-U9&%H(&AA8FES(&UA<V$@8F5R;&%K=6YY82XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I
M9W5R92`E<R(*;7-G<W1R(")-96YG871U<B`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O
M<F0B"FUS9W-T<B`B2V]N9FER;6%S:2!386YD:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*(RP@
M9G5Z>GD*;7-G:60@(D-O;F=O(@IM<V=S='(@(E=A<FYA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T
M<B`B2V]N=&%K(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B3&%N:G5T(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(D-O
M;VMI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")386QI;B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]L;VT@
M>6%N9R!D:6EM<&]R.B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S
M='(@(E-A;&EN(%!I;&EH86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'
M4"!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)
M344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G
M<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5&ED86L@9&%P
M870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87`B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P
M('-E<G9E<B(*;7-G<W1R(")4:61A:R!D87!A="!T97)I:V%T(&1E;F=A;B!S
M97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@;&1A<"(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O
M(&QD87`@<V5R=F5R(@IM<V=S='(@(E1I9&%K(&1A<&%T('1E<FAU8G5N9R!K
M92!S97)V97(@;&1A<"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(E1I9&%K
M(&1A<&%T('1E<FAU8G5N9R!K92!S97)V97(@)R5S)R!D96YG86X@;65N9V=U
M;F%K86X@1E10.B5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(E1I9&%K(&1A<&%T(&UE;G5L:7,@:V]N9FEG=7)A<VD@=6YT=6L@)R5S
M)SH@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G
M:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!K96UB86QI
M(&ME(&MO;F9I9W5R87-I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(")4:61A:R!D87!A="!M96YG:&%P=7,@<V-R:7!T('-E='5P('5P
M9W)A9&4@)R5S)RX@(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D
M87!A="!M96YG:&%P=7,@<V-R:7!T('-E='5P('5P9W)A9&4@)R5S)RX@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S$Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R(")4:61A:R!D87!A
M="!T97)I:V%T(&1E;F=A;B!S97)V97(@;&1A<"(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B5&ED86L@9&%P
M870@;65N>6EM<&%N(&MO;F9I9W5R87-I("5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+B(*;7-G<W1R(")4:61A:R!D87!A="!T97)H=6)U;F<@:V4@<V5R=F5R
M(&QD87`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N
M(@IM<V=S='(@(EPB)7-<(B!B96QU;2!D:6)U870Z("5S+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@
M<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O
M;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@
M5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB5&ED86L@9&%P
M870@;65N9V%T=7(@=6QA;F<@=6YT=6L@<&5N9V=U;F$@>6%N9R!D:6UI;G1A
M+B!"96)E<F%P82!A=&%U('-E;75A("(*(F1E=&EL('1I9&%K(&)E;F%R+B!#
M;V)A(&QA9VD@871A=2!S:6QA:V%N(&AU8G5N9VD@861M:6YI<W1R871O<B!A
M;F1A(&II:V$@(@HB86YD82!M96UE<FQU:V%N(&)A;G1U86X@;&5B:6@@;&%N
M:G5T+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B5&ED86L@9&%P870@:V5M8F%L:2!K92!K;VYF:6=U<F%S
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0S-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B5&ED
M86L@9&%P870@:V5M8F%L:2!K92!K;VYF:6=U<F%S:2XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E1I9&%K(&1A<&%T(&ME
M;6)A;&D@:V4@:V]N9FEG=7)A<VDN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U
M<F%S:2`E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I(&)A8VMU<"XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B
M"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&MO;F9I9W5R87-I(&)A
M8VMU<#H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P
M870@;65N>6EM<&%N('-C<FEP="!S971U<"!U<&=R861E(&ME.B<E<R<N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B5&ED86L@9&%P870@;65N>6EM<&%N(&9I;&4@
M:V]N9FEG=7)A<VD@8F%C:W5P("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A
M=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@
M=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A
M8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E
M<RXB"FUS9W-T<B`B(@HB5&ED86L@9&%P870@;65N>6EM<&%N(&9I;&4@:V]N
M9FEG=7)A<VD@)7,N($%N9&$@9&%P870@;65N9V=U;F%K86X@<V%L86@@<V%T
M=2`B"B)D87)I('!I;&EH86X@=6YT=6L@;65N>6EM<&%N(&MO9&4@=&5R<V5B
M=70@:V5M8F%L:2!K92`E<R!A=&%U<'5N(&UE;GEA;&EN("(*(FMO9&4@9&D@
M8F%W86@@:6YI('-E8V%R82!M86YU86P@:V4@)7,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")4:61A:R!D
M87!A="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN
M:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(E1I9&%K(&1A<&%T(&UE;GEI;7!A;B!K;VYF:6=U<F%S:2`E<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B5&ED86L@9&%P870@;65N
M=6QI<R!K;VYF:6=U<F%S:2!U;G1U:R`G)7,G.B`E<R(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B5&ED86L@9&%P870@;65N=6QI<R!K;VYF:6=U<F%S:2!U;G1U
M:R`G)7,G.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G
M:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(E1I9&%K(&1A
M<&%T(&UE;F5M=6MA;B!086YE;"!.879I9V%S:2!-;WII;&QA+B!087-T:6MA
M;B!P86YE;"!N879I9V%S:2!S=61A:"`B"B)T97)B=6MA+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F
M;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM<V=I
M9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38Y"B,L(&9U>GIY"FUS9VED(")#;W5N=')Y
M(@IM<V=S='(@(DMO;7!U=&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S=7,B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R(")"=6%T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS
M9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D)U870@;&EN:R(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R
M96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B0G5A="!B87)U(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T
M92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(T,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871O<B!097)M
M:7-S:6]N<R(*;7-G<W1R("))>FEN('1A;74B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C,P"B,L(&9U>GIY"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`B06YG:V$@1&5S:6UA;"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"B,L
M(&9U>GIY"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(D)U870B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G
M<W1R(")&87-E(%-E:V%R86YG(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X
M"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(DEZ
M:6X@=&%M=2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(E=A:W1U
M(%-E:V%R86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R(")54DP@4V5K87)A;F<@861A;&%H(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@
M(D9A<V4@4V5K87)A;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS
M9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B0W5A8V$@4V5K87)A;F<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#
M=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(DMO;F1I<VD@4V5K87)A;F<Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")'87EA(%-E:V%R86YG
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N(@IM<V=S='(@(DMO<W1U;6ES87-I('1U9V%S('5N='5K(&1I:F%L86YK
M86X@<V5B96QU;2!L;V=O;B!K92`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*
M;7-G<W1R(")(87!U<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B
M2&%P=7,@<&EL:6AA;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER
M:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B0WER:6QL:6,@*$M/23@M4BDB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2DB"FUS9W-T<B`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D-Y<FEL;&EC+U5K<F%I;FEA
M;B`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$
M(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X
M,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")$86EL>2(*;7-G<W1R(")(87)I(@H*
M(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W
M<V5R(@IM<V=S='(@(D1A=&%4<F5E($)R;W=S97(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"B,L(&9U>GIY
M"FUS9VED(")$871E(@IM<V=S='(@(E-A;&EN(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B
M"FUS9W-T<B`B5&%N9V=A;"!$:71E<FEM82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,#<*(RP@9G5Z>GD*;7-G:60@(D1A=&4@<V5L96-T:6]N
M(@IM<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,C(*;7-G:60@(D1A>2(*;7-G<W1R(")(87)I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"FUS9VED(")$
M95]L971E($-O;'5M;B(*;7-G<W1R(")(87!U<R!+;VQO;2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E
M;6)E<B(*;7-G<W1R(")$97-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM
M86P@;G5M8F5R<R(*;7-G<W1R(")!;F=K82!$97-I;6%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(DUE;F=U<F%N9VD@26YD96XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP
M.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")$969A=6QT(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@
M(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B1&5F875L="!787)N82(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B1&5F875L="!I9&5N=&ET
M87,@86YD83HB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*;7-G:60@
M(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B1&5F875L="!3:&5L;"(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS
M9W-T<B`B1&5F:6YI<VDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B2&%P=7,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(DAA<'5S(%-E;"(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W
M"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B2&%P=7,@1W)U<"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0HC+"!F=7IZ>0IM<V=I
M9"`B1&5L971E($QO9R(*;7-G<W1R(")(87!U<R!B87)I<R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!097)M:7-S
M:6]N(@IM<V=S='(@(DEZ:6X@=&%M=2(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL
M(@IM<V=S='(@(DAA<'5S('-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU
M;6XB"FUS9W-T<B`B2&%P=7,@:V]L;VTB"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP
M;&%T92(*;7-G<W1R(")(87!U<R!P96YG9V%N=&D@=&5M<&QA=&4@>6%N9R!S
M=61A:"!A9&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B56)A:"!I>FEN('5N='5K("5S(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD
M(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@
M(D1E;&5T92!R;W<B"FUS9W-T<B`B2&%P=7,@8F%R:7,B"@HC.B!T96UP;&%T
M97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@
M<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B2&%P=7,@:61E;G1I=&%S('EA
M;F<@=&5R<&EL:6@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6XB"FUS9W-T<B`B2&%P=7,@:V]L;VT@>6%N9R!S96MA<F%N9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R
M(")(87!U<R!B87)I<R!Y86YG('-E:V%R86YG(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")(
M87!U<R!S8W)I<'0@<V5T=7`@=7!G<F%D92`G)7,G+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B2&%P
M=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")$96YM87)K(@IM<V=S
M='(@(D1I=&%N9&%I(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(DIE
M;&%S:V%N($UA<V%L86@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY
M,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S:W)I<'-I(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I
M;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3D*(RP@9G5Z>GD*;7-G:60@
M(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(D%R96$@365T87(@=&ED86L@9&ES961I86MA;BX@1&5T
M:6P@=&5L86@@9&EC871A="!U;G1U:R!A9&UI;FES=')A=&]R+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(E!E<FME;6)A;F=A;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B5&ET:6L@16UB=6XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")4:71I:R!%;6)U;B!U;G1U:R!J
M86T@=&5R86MH:7(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B5&ET:6L@16UB=6XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X
M"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")!<F%H
M(&MI<FD@:V4@:V%N86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R(")!<F%H(&MA;F%N(&ME(&MI<FDB"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(D1I<F5K
M=&]R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B5&%M<&EL:V%N('=A:W1U
M(#(T(&IA;3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")486UP:6QK86X@4&EL:6AA;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@IM<V=I9"`B1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")486UP:6QK86X@9&5T
M:6P@<F%M86QA;B!C=6%C82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*
M;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5&%M<&EL
M:V%N(')A;6%L86X@8W5A8V$@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*
M;7-G<W1R(")486UP:6QK86X@<F%M86QA;B!C=6%C82`H5$%&*2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED
M(")$:FEB;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R(")(87!U<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR
M-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP
M:'`B"FUS9W-T<B`B2F%N9V%N(&QA;F=S=6YG(&UE;F=A:W-E<R!M86EN=&5N
M86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B)!<&%K86@@8F%R:7,@>6%N9R!P
M97)T86UA('1E<F1I<FD@9&%R:2!K;VQO;2!N86UA/R!J:6MA('EA+"!B97)I
M('1A;F1A('!A9&$@(@HB:V]T86L@:6YI.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN
M:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I
M9VX@=7`N(@IM<V=S='(@(E1I9&%K(&UE;6EL:6MI(&%C8V]U;G0_(%-I;&%K
M86X@;65N9&%F=&%R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(D1O=VYL;V%D
M(&MO;F9I9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!0
M2%`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B
M1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")/8F%T+6]B871A;B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ
M>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(E-U<F%T(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL
M+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R
M;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*
M;7-G<W1R(")58F%H(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET
M($)L;V-K(@IM<V=S='(@(E5B86@@0FQO:VER(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O
M=7`B"FUS9W-T<B`B56)A:"!'<G5P(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,`HC+"!F=7IZ>0IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E5B
M86@@27II;B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G
M:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B56)A:"!)>FEN(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")58F%H($EZ
M:6X@=6YT=6L@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS
M9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")58F%H('!I;&EH86X@
M=6YT=6LZ(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R(")58F%H(&EZ:6X@=6YT=6L@)7,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G
M:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5B86@@:7II
M;B!U;G1U:R`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(E!E;F1I9&EK86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA
M8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO
M;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L
M=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(D5L96UE;BXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0HC+"!F=7IZ>0IM<V=I9"`B16UA
M:6PB"FUS9W-T<B`B4W5R870B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G
M:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B06QA;6%T($5M86EL(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(E-A;F1I(&AA
M<G5S(&-O8V]K+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#D*
M(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(DMO;F9I9W5R87-I("5S('-U9&%H(&1I<VEM<&%N+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED(")%
M;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L(&9U>GIY"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`B2V]N9&ES:2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP
M='D@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA8FQE(&EN
M<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X
M=#\B"FUS9W-T<B`B06MT:69K86X@<&5N>6ES:7!A;B!G86UB87(M9V%M8F%R
M(&1A<FD@1V%L97)I($9O=&\@9&D@9&%L86T@=&5K<S\B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(*;7-G<W1R(")!:W1I9FMA;B!K;&EK(&MA;F%N(&UE
M;G4@:V]N=&5K<S\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*(RP@9G5Z>GD*;7-G:60@
M(D5N9"!Y96%R(@IM<V=S='(@(E!E<F)E<V%R(%!A;F5L($YA=FEG87-I(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B4&5R8F5S87(@161I=&]R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N
M("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*
M(DUA<W5K:V%N('!E<G1A;GEA86X@:V5A;6%N86X@9&EM86YA(&%N9&$@86MA
M;B!D:71A;GEA:V%N(&%P86)I;&$@86YD82!P97)L=2`B"B)U;G1U:R!M96YG
M871U<B!U;&%N9R!S86YD:2!A;F1A+"`@8V]N=&]H("=A<&%K86@@;F%M82!B
M:6YA=&%N9R!K97-A>6%N9V%N("(*(F%N9&$_)SHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G
M:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")-87-U:VMA
M;B!54DP@9V%M8F%R(&1I<VEN:2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T97)S
M(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A=&]R
M:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET
M<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V('-E<G9I8V5S+W!O
M<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM<V=S='(@(DME<V%L
M86AA;B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,B"FUS9W-T<B`B2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U
M:2!S86YD:3H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@
M<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(DME<V%L86AA;B!S86%T(&UE;7!E
M<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")+97-A;&%H86X@<V%A="!M
M96UP97)B86AA<G5I('-A;F1I.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DME<V%L86AA
M;B!S86%T(&UE;7!E<F)A:&%R=6D@<V%N9&DZ("5S(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")+97-A;&%H86X@
M<V%A="!M96UP97)B86AA<G5I('-A;F1I.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I
M;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS
M9VED(")%<W1O;FEA(@IM<V=S='(@(E-U:W4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")3=6MU(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R(")3971I87`@,34@;65N:70B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T
M97,B"FUS9W-T<B`B4V5T:6%P(#(@;65N:70B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@
M(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B4V5T:6%P(#,P(&1E=&EK(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B4V5T
M:6%P(#4@;65N:70B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C8P"B,L(&9U>GIY"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R(")3971I87`@;65N:70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B4V5T:6%P('-E
M=&5N9V%H(&IA;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B179E<GD@;6EN=71E(@IM
M<V=S='(@(E-E=&EA<"!M96YI="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B0V]N
M=&]H(&YI;&%I+6YI;&%I.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM
M<V=I9"`B17AE8W5T92(*;7-G<W1R(")*86QA;FMA;B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0HC+"!F=7IZ>0IM<V=I9"`B
M17AP86YD(@IM<V=S='(@(E!E<F)E<V%R(%!A;F5L($YA=FEG87-I(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD
M(%-I9&5B87(B"FUS9W-T<B`B4&5R8F5S87(@4&%N96P@3F%V:6=A<VDB"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"B,L(&9U>GIY
M"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B2F%L86YK86XB"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E
M8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I
M9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")787)N82!&
M1R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U
M<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B1E10('5P;&]A9"!U;G1U:R!S971U
M<"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I
M9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B5&ED86L@
M9&%P870@=&5R:'5B=6YG(&ME('-E<G9E<B!L9&%P(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")4:61A:R!D87!A
M="!T97)H=6)U;F<@:V4@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E
M871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R
M971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B0V5R
M86@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X
M"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PHC+"!F=7IZ>0IM<V=I
M9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-#D*;7-G:60@(D9A>&5S(@IM<V=S='(@(D9A>"(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R
M=6%R>2(*;7-G<W1R(")&96)R=6%R:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E-E<&5R=&DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")&965L
M<R!L:6ME.B`B"FUS9W-T<B`B4V5P97)T:3HB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B
M"FUS9W-T<B`B1V5R:6UI<R!396)A9VEA;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(D=E<FEM:7,@4V%L:G4@4V5B86=I86XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM
M<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@
M(D9I;&4B"FUS9W-T<B`B1FEL=&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@
M9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS
M9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1FEL92!-86YA9V5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I
M;&4@3F%M92(*;7-G<W1R(").86UA($QE;F=K87`B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3DU"B,L(&9U>GIY"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"B,L(&9U
M>GIY"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B1E10('5P;&]A9"!U;G1U:R!S971U<"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")&:6YL86YD(@IM<V=S='(@
M(FUA<VEH(&1I(&1A;&%M(&%N=')I86XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D9A<V4@<&5R=&%M
M82!D87)I(%-E<&%R=6@@0G5L86XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R
M(@IM<V=S='(@(D9A<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")&;&]A="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&
M;V<B"FUS9W-T<B`B0F5R:V%B=70B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L
M('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(E=A<FYA(%1U
M;&ES86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O
M;V0B"FUS9W-T<B`B36%K86YA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B56YT
M=6L@8G)O=W-E<B!Y86YG('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!G86UB87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B4F%M86QA;B!C=6%C82`H5$%&*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@
M1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS
M(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C
M;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)(87)I
M(%)A;6%L86X@0W5A8V$@*&-A=&%T86X@8F%H=V$@<F%M86QA;B!C=6%C82!Y
M86YG(&1I:V5M8F%L:6MA;B!A:V%N("(*(FUE;F=E;6)A;&EK86X@8F%I:R!S
M:6%N9R!A=&%U(&UA;&%M(&AA<FDL('-E:G5M;&%H(&%N9VMA(&1A<&%T(&1I
M:&%S:6QK86X@(@HB<&%D82!A<F5A(&EN:2DB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_
M(@IM<V=S='(@(DQU<&$@9&5N9V%N('-A;F1I(&%N9&$_(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M1F]R;75L:7(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@
M(D9O<G1U;F4B"FUS9W-T<B`B4F%M86QA;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1I<&4@
M4F%M86QA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B
M1F]R='5N97,B"FUS9W-T<B`B4F%M86QA;B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")286UA;&%N
M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&
M;W)U;7,B"FUS9W-T<B`B1F]R=6TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")$:71E<G5S:V%N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,`IM<V=I9"`B1G(B"FUS9W-T<B`B2FUT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S
M(@IM<V=S='(@(D9R86UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B
M1G)A;F-E(@IM<V=S='(@(D9R86UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N
M(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(D9R;VTB
M"FUS9W-T<B`B2FUT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*
M;7-G<W1R(")$87)I(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S:W)I
M<'-I($QE;F=K87`B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(D)U
M;&%N(%!U<FYA;6$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,`IM<V=I9"`B1G5L;"!.
M86UE(@IM<V=S='(@(DYA;6$@3&5N9VMA<"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B1V%L97)I('5N='5K(&UE;F=A
M;6)I;"!G86UB87(@9&%R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB
M"FUS9W-T<B`B1V%L97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G
M<W1R(")-96YG:&%S:6QK86X@)7,@2V]N9FEG=7)A<VD@(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(DMO9&4@>6%N9R!D:6AA<VEL:V%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H
M86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B2F%L86YK
M86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E
M;"(*;7-G<W1R(")';V5D96PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3$R.`HC+"!F=7IZ>0IM<V=I9"`B1V]O9VQE($UA
M<',B"FUS9W-T<B`B4&5N8V%R:6%N($=O;V=L92(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B
M4&5N8V%R:6%N($=O;V=L92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S<*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")'<F5E:R`H25-/+3@X-3DM
M-RDB"FUS9W-T<B`B675N86YI("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y
M"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES
M=')A<VD@1W)U<"(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T
M<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I
M9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@
M(E%U97)Y(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B27II;B!T86UU(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D)U
M:W4@=&%M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(D=U:6YE82(*
M;7-G<W1R(")*=6YI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES
M<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I
M9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB
M"FUS9W-T<B`B(@HB2%1-3$%R96$@9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U
M:R!M96YG:&%P=7,@<V5L('EA;F<@=&5R86MH:7(@9&D@9&%L86T@(@HB8F%R
M:7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B
M"B)(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U
M<R!K;VQO;2!Y86YG('1E<F%K:&ER(&1I(&1A;&%M("(*(G1A8F5L+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@HB2%1-3$%R96$@
M9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@8F%R:7,@>6%N
M9R!T97)A:VAI<B!D:2!D86QA;2`B"B)T86)E;"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM
M<V=I9"`B2&%Z92(*;7-G<W1R(")"97)K86)U="(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R
M"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS9W-T<B`B0F%C82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@
M(DAE861E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z
M>GD*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B2'5J86X@<&5T:7(@
M9&ES97)T86D@9&5N9V%N(&%N9VEN(')I8G5T(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G
M<W1R(")986AU9&D@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG
M:'0B"FUS9W-T<B`B5&EN9V=I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(D)A;G1U86XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q
M"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")"86YT=6%N(&UE
M;F=G=6YA:V%N(&5D:71O<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")"86YT=6%N
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E
M(@IM<V=S='(@(D)E;&%H86X@0G5M:2(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(DEN:2!A9&%L86@@<&5R;75L86%N(&1A<FD@9FEL93HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG
M:"(*;7-G<W1R(")4:6YG9VDB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G
M:60@(DAO7VUE(@IM<V=S='(@(DAO7VUE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I
M9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS
M9VED(")(;VUE(@IM<V=S='(@(DAO7VUE(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"B,L(&9U>GIY"FUS9VED(")(;VUE
M($%D9')E<W,B"FUS9W-T<B`B06QA;6%T($5M86EL(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R
M(")$:7)E:W1O<FD@2&]M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S
M='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@
M6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(EPB)7-<(G-U
M9&%H(&)E<FAA<VEL(&1I:&%P=7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M
M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y
M<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N
M=&%L(%)U;&4B"FUS9W-T<B`B1V%R:7,@2&]R:7-O;G1A;"!D:2!D86QA;2!(
M5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DIA<F%K
M(&=A<FES(&AO<FEZ;VYT86P@9&%R:2!B;W)D97(@9&5N9V%N('1E:W,@9&D@
M9&%L86T@<V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B2&]R:7IO
M;G1A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D)A9V%I;6%N82!C87)A(&%N9&$@
M8FES82!S86UP86D@9&ES:6YI/R`H4VEL86MA;B!M96QA<&]R(2DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U
M"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R(")"97)A<&$@8F%N>6%K(&MO;&]M('EA;F<@:6YG:6X@
M86YD82!G86)U;F=K86X_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R(")"97)A<&$@8F%N>6%K(&MO;&]M('EA;F<@861A(&1I
M<V%N83\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/R(*;7-G<W1R(")"97)A<&$@8F%N>6%K(&)A<FES('EA
M;F<@:6YG:6X@86YD82!G86)U;F=K86X_(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I
M9"`B2'5M:61I='DB"FUS9W-T<B`B2V5L96UB86)A;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS
M9W-T<B`B2V5L96UB86)A;CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")096QA=V%K(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*
M;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B06QA;6%T($5M86EL(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PHC+"!F=7IZ>0IM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A
M($UE=&%R('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED
M("))4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM
M<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N($)A
M<FES(%-E8F5L=6UN>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I
M9"`B26-O;G,@3VYL>2(*;7-G<W1R(")(86YY82!I:V]N(@H*(SH@=71I;"]I
M8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS
M(&9O<B`E<R(*;7-G<W1R(")):V]N('5N='5K("5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S
M='(@(DEK;VX@9&5N9V%N('1E:W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DYA;6$@
M261E;G1I=&%S.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES
M<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD
M;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*
M;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI
M<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B
M(@HB2FEK82!A;F1A('1I9&%K(&UE;&EH870@:6MO;B!M86YA<'5N(&1E;F=A
M;B!M96YG9W5N86MA;B!);G1E<FYE="!%>'!L;W)E<BP@(@HB86YD82!M=6YG
M:VEN('!E<FQU('5N='5K(&UE;F%N9&%I(&MO=&%K(&EN:2!U;G1U:R!M96YO
M;BUA:W1I9FMA;B!K96QE;6%H86X@(@HB4$Y'+B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E
M(%!R979I97<Z(@IM<V=S='(@(DQI:&%T($=A;6)A<CHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED
M("));6%G92!54DPB"FUS9W-T<B`B55),($=A;6)A<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM
M<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")54DP@1V%M8F%R.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D=A;6)A
M<B!D87)I(&=A;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y.B(*;7-G<W1R(")'86UB87(@9&%R:2!G86QE<FDZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED
M("));6%G97,B"FUS9W-T<B`B1V%M8F%R+6=A;6)A<B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z-PHC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP
M;W)T+"!3=&5P("5D(@IM<V=S='(@(DEM<&]R+"!,86YG:V%H("5D(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DMO;&]M('EA;F<@
M9&EI;7!O<CH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U
M"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DMO;&]M('EA;F<@
M9&EI;7!O<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(DUA<W5K:V%N($)A<FES($)E<FEK=71N>6$B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G:60@(DEN8V]R
M<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z
M>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@;F%M82!P96YG9W5N82!D86X@
M<V%N9&D@86YD82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q
M"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D
M9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYA
M;6$@<&5N9V=U;F$@871A=2!A;&%M870@96UA:6P@<&5N9V=A;G1I('1I9&%K
M(&)E;F%R+B!#;V)A(&QA9VD@871A=2`B"B)S:6QA:V%N(&AU8G5N9VD@861M
M:6YI<W1R871O<B!A;F1A(&II:V$@86YD82!M96UE<FQU:V%N(&)A;G1U86X@
M;&5B:6@@;&%N:G5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R
M(")-96YA;6)A:"!);F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B4&5N9V=U;F$@4')I8F%D:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN
M9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M87-I
M('-U9&%H('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E
M<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")-87-U:VMA;B!+;VQO;2!"97)I
M:W5T;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T
M<B`B36%S=6MK86X@1V%M8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S
M='(@(DUA<W5K:V%N(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM
M<V=S='(@(DUA<W5K:V%N(%=E8B!,:6YK(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E
M<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B36%S=6MK86X@2V]L;VT@4V5B
M96QU;6YY82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B36%S=6MK86X@:V]L;VT@
M>6%N9R!B87)U('-E=&5L86@@:V]L;VT@>6%N9R!S96MA<F%N9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DUA<W5K:V%N(&MO;&]M('EA;F<@8F%R=2!S96)E
M;'5M(&MO;&]M('EA;F<@<V5K87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R
M="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DUA
M<W5K:V%N(&)A<FES('EA;F<@8F%R=2!S971E;&%H(&)A<FES('EA;F<@<V5K
M87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")-87-U:VMA;B!B87)I<R!Y86YG
M(&)A<G4@<V5B96QU;2!K;VQO;2!Y86YG('-E:V%R86YG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS
M9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R(")-87-U:VMA;B!P87)A9W)A9B!S971E;&%H('!A<F%G<F%F
M('EA;F<@<V5K87)A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")-87-U:VMA
M;B!P87)A9W)A9B!S96)E;'5M('!A<F%G<F%F('EA;F<@<V5K87)A;F<B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R(")-87-U:VMA;B!T96UP;&%T92!P96YG
M9V%N=&DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("))
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B36%S=6MK86X@86QA;6%T
M(&5M86EL(&1I;6%N82!A;F1A(&1A<&%T(&UE;F5R:6UA('-A;F1I('EA;F<@
M8F%R=3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R
M(")-87-U:VMA;B!S96P@8F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R
M="!C96QL(&)E9F]R92(*;7-G<W1R(")-87-U:VMA;B!S96P@<V5B96QU;6YY
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M36%S=6MK86X@:V]L;VT@8F5R:6MU=&YY82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R
M="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DUA<W5K:V%N(&MO;&]M('-E8F5L
M=6UN>6$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@
M(DUA<W5K:V%N($=A;6)A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G
M<F%P:"!A9G1E<B(*;7-G<W1R(")-87-U:VMA;B!P87)A9W)A9B!B97)I:W5T
M;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R(")-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M;GEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")-87-U:VMA;B!B87)I
M<R!B97)I:W5T;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B
M"FUS9W-T<B`B36%S=6MK86X@8F%R:7,@<V5B96QU;6YY82(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
M36%S=6MK86X@:F%W86)A;B!Y86YG(&1I<&5R;'5K86X@=6YT=6L@<&5R=&%N
M>6%A86X@:V5A;6%N86XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*
M;7-G<W1R(")-87-U:VMA;B]58F%H($=A;6)A<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-
M;V1I9GD@3&EN:R(*;7-G<W1R(")-87-U:VMA;B]58F%H($QI;FLB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-S4*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
M5&5N9V%H(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I
M9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L
M:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M07!L:6MA<VD@=&ED86L@=F%L:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,CDY"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A
M9&1R97-S+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!786MT
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D%P;&EK
M87-I('1I9&%K('9A;&ED+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(D%P;&EK87-I('1I9&%K('9A;&ED+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM
M<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R
M("))>FEN(&EN9'5K('1I9&%K('9A;&ED+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(DEZ
M:6X@:6YD=6L@=&ED86L@=F%L:60N(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R("))>FEN(&EN9'5K('1I9&%K('9A;&ED+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B27II;B!I;F1U:R!T:61A:R!V86QI
M9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T<B`B07!L
M:6MA<VD@=&ED86L@=F%L:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"B,L(&9U>GIY"FUS9VED("));G9A
M;&ED('!R;W1O8V]L+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B27II;B!I;F1U:R!T:61A
M:R!V86QI9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R(")!<&QI:V%S:2!T:61A:R!V86QI9"XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB
M"FUS9W-T<B`B26YV96YT;W)I<R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S
M96QE8W1I;VXB"FUS9W-T<B`B2&%P=7,@<&EL:6AA;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B2'5J86X@
M<&5T:7(@9&ES97)T86D@86YG:6X@<FEB=70@9&D@9&%E<F%H('EA;F<@=&5R
M<&5N8VEL(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G
M:60@(DES<W5E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R(")(
M=7)U9B!-:7)I;F<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET
M86QY(@IM<V=S='(@(DAU<G5F($UI<FEN9R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*
M86YU87)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@
M*$E33RTR,#(R+4I0*2(*;7-G<W1R(")*97!A;F<@*$E33RTR,#(R+4I0*2(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*
M879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A
M;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L
M:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P
M"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T
M:69Y(@IM<V=S='(@(E)A=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT
M97(B"FUS9W-T<B`B4F%T82!496YG86@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF
M>2!&=6QL(@IM<V=S='(@(E)A=&$@2VER:2!D86X@2V%N86XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM
M<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(E)A=&$@2VER:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V
M"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(E)A=&$@2V%N86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I
M9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B2V5R
M;F5L($YE=V)I97,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")*
M=61U;"!486)E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE
M;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@57-A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI
M8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")!;F%K+6%N86LB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E82`H
M155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`B5&%M<&EL86XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")"86AA<V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E
M<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*
M;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")&87-E('1E<F%K:&ER(&1A<FD@
M4V5P87)U:"!"=6QA;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B4&5R=6)A:&%N
M(%-A;F1I(%1E<F%K:&ER(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI
M8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S
M='(@(D9A<V4@=&5R86MH:7(@9&%R:2!397!A<G5H($)U;&%N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@57!D871E9#HB"FUS
M9W-T<B`B4&5R=6)A:&%N(%1E<F%K:7(Z(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<R(*;7-G<W1R("(E<R!U;G1U:R`E<R`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B
M"FUS9W-T<B`B2'5K=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R(")4
M86UP:6QA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B5&EN9V=A;&MA;B!K;W-O;F<@=&%N<&$@8F]R9&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B
M3&5F="(*;7-G<W1R(")+:7)I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F
M="!V86QU97,B"FUS9W-T<B`B1&%F=&%R(%1A8F5L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T
M<B`B0VEN=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*(RP@9G5Z>GD*;7-G:60@(DQI8F5R
M:6$B"FUS9W-T<B`B4&%N='5N($IE;F%K82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI
M9VAT($1R:7IZ;&4B"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN
M(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G
M<W1R(")'97)I;6ES(&1I('!A9VD@:&%R:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA
M=&4B"FUS9W-T<B`B1V5R:6UI<R!B96)E<F%P82!S86%T(&QA9VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B1V5R:6UI<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H
M="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")'97)I;6ES(&1I<V5R=&%I
M('!E=&ER(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B0F5R<V%L:G4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I
M9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B1V5R:6UI<R!386QJ=2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB
M"FUS9W-T<B`B4&%N='5N($IE;F%K82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B3&]G
M:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("),
M:6YK(&UE;G5N:G5K(&ME.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O
M;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PHC
M+"!F=7IZ>0IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B5'5G87,@3&]G:6XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI
M92(*;7-G<W1R("),:6YU>"!#;V]K:64B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(D1A9G1A
M<B!$871A8F%S92(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS
M9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(D1A9G1A<B!4;W!I:R!"
M86YT=6%N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES
M="!486)L97,B"FUS9W-T<B`B1&%F=&%R(%1A8F5L(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(D1A
M9G1A<B!4;W!I:R!"86YT=6%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI
M<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0HC+"!F=7IZ
M>0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B06YG:V$O:'5R=68O
M<VEM8F]L('EA;F<@9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I
M9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$869T87(@<&5N9V=U
M;F$@9&EN;VXM86MT:69K86XN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B1&%F=&%R('!E;F=G=6YA(&1I;F]N+6%K=&EF
M:V%N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM
M<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B1&%F
M=&%R('!E;F=G=6YA(&1I;F]N+6%K=&EF:V%N+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R(")$869T
M87(@0F%C86%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),:71H
M=6%N:6$B"FUS9W-T<B`B3&5B87(@=6YI="(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(E=A:W1U(&QO8V%L.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N
M9"!4:6UE(@IM<V=S='(@(E1E;7!A="!097)I<W1I=V$@9&%N(%=A:W1U(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C8U"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("),;VMA<VDB"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T
M<B`B3&]G:6XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*
M;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B
M3&]G(&]U="(*;7-G<W1R("),;V<@;W5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("),;V=I;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM
M<V=S='(@(E1U9V%S($QO9VEN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*(RP@9G5Z
M>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B5&ED86L@9&EA<G-I
M<&MA;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z
M>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),;V<@;W5T(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(D-I
M;G1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C<*;7-G:60@(DQO=R(*;7-G<W1R(")296YD86@B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED
M("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(E-I;6)O;"!(=7)U9B!K
M96-I;"!Y=6YA;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T
M97)S(@IM<V=S='(@(E-I;6)O;"!(=7)U9B!K96-I;"!L871I;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4VEM8F]L
M($AU<G5F(&ME8VEL(')O;6%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X
M96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.
M148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B35-'(@IM<V=S='(@
M(D--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%C86\B"FUS
M9W-T<B`B3&EB=7)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S
M='(@(E-U;&%P(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS
M9VED(")-86EL(@IM<V=S='(@(E-U<F%T(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")3=7)A
M="!!9&UI;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R
M(")"=6%T(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R(")3=7)A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD
M:79E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@
M(DUA;&DB"FUS9W-T<B`B4W5R870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*
M;7-G:60@(DUA;'1A(@IM<V=S='(@(E-U<F%T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("(B"B)-96YG871U<B!D869T87(@:V%T96=O<FD@>6%N9R!H87)U<R!D
M:6)E<FD@;&%B96P@:71E;2P@9&%N('=A<FYA('EA;F<@(@HB8F5R:'5B=6YG
M86X@(&1E;F=A;B!K871E9V]R:2!T97)S96)U="XB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-
M87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R
M(")-87)E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G:6XB
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM
M<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS
M9VED(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N
M<W=E<F5D*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H
M86QL($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY
M"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(DUA<F=I;B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L
M9',B"FUS9W-T<B`B365N8V]C;VMK86X@:V]L;VTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M(RP@9G5Z>GD*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%R9VEN(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U
M"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(%-U:'4@;6%K<VEM=6T@>6%N9R!B
M97)L86YG<W5N9R!S96QA;6$@,C0@:F%M.B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(")3=6AU(&UA:W-I;75M('EA;F<@8F5R;&%N9W-U;F<@<V5L86UA(#8@
M:F%M.B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E
M<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DIU;6QA:"!M86MS:6UU;2!D
M87)I('!O<G1A;"!Y86YG(&1I8FQO:VER(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L
M96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-96DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")-87EO='1E(@IM<V=S='(@(E1A
M;7!I;&%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-
M961I8VEN92(*;7-G<W1R(")/8F%T+6]B871A;B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T
M<B`B06YG9V]T82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G
M:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N=2!M;V1E.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G
M:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(D=A8G5N9VMA;B!S96PB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")097-A;B!335,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I
M9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A
M<B!796%T:&5R(@IM<V=S='(@(B!#=6%C82!-971A<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(D%R96$@365T87(@=&ED86L@9&ES961I86MA;BXB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B07)E82!-971A<B!T:61A
M:R!D:7-E9&EA:V%N+B!$971I;"!T96QA:"!D:6-A=&%T('5N='5K(&%D;6EN
M:7-T<F%T;W(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M-0HC+"!F=7IZ>0IM<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*
M;7-G<W1R(")386YD:2!L86UA('1I9&%K(&)E;F%R+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W
M;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@
M(DUE=')I:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B365X:6-O
M(@IM<V=S='(@(DUE=')I:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(E1E;F=A:"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")3=6AU(&UI;FEM=6T@
M>6%N9R!B97)L86YG<W5N9R!S96QA;6$@,C0@:F%M.B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M("(*;7-G<W1R(")3=6AU(&UI;FEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA
M;6$@-B!J86TZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X
M<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S
M='(@(DME<V%L86AA;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("),86EN+6QA:6XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*
M;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*(DMO;F9I9W5R87-I('1I9&%K(&1I=&5M=6MA;BX@
M06YD82!H87)U<R!M96YG:&%S:6MA;B!K;VYF:6=U<F%S:2!S96MA<F%N9R`B
M"B)J:6MA(&%N9&$@:6YG:6X@;65N9V=U;F%K86X@87!L:6MA<VD@:6YI+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I
M;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(E-E;B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS
M9W-T<B`B36]B:6QE($UA:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B4V5D
M86YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*(RP@9G5Z>GD*
M;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B4V5D86YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S
M"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(E5B86@@55),(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L
M=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*
M;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-
M;VYT<V5R<F%T(@IM<V=S='(@(E-E9&%N9R(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B1F%S92!"=6QA;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@
M0VQE87(B"FUS9W-T<B`B4V5B86=I86X@8F5S87(@0V5R86@B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S
M=&QY($-L;W5D>2(*;7-G<W1R(")396)A9VEA;B!B97-A<B!"97)A=V%N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")396)A9VEA;B!B97-A<B!#97)A
M:"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM
M<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4Q,PHC+"!F=7IZ>0IM<V=I9"`B36]V92!,
M969T(@IM<V=S='(@(DMI<FDB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HU,3<*(RP@9G5Z>GD*;7-G:60@(DUO=F4@4FEG:'0B"FUS
M9W-T<B`B2V%N86XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA
M<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(T,@HC+"!F=7IZ>0IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM
M<V=S='(@(DAA<'5S('!I;&EH86XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(D%C8V]U;G0M
M:W4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-I($%C8V]U;G0M
M:W4B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B4&]R=&%L:W4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S
M='(@(E1A;7!I;&%N(%!O<G1A;&MU(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M>6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B
M"FUS9W-T<B`B5$E$04LL(%-A>6$@5$E$04L@4V5T=6IU(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(DYA;64B"FUS
M9W-T<B`B;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*
M;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").
M971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E
M(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(U,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").971W;W)K
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`B5&ED86L@<&5R;F%H(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"B,L(&9U>GIY"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S
M='(@(DMA=&5G;W)I($)A<G4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM
M<V=S='(@(DMA=&5G;W)I($)A<G4B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B0G5L86X@
M0F%R=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*
M;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYA;6$@
M4&5N9V=U;F$@0F%R=2`H<&EL:6AA;BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(DYE=R!:96%L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E-A
M;F1I($)A<G4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER
M92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R(")386YD:2!B87)U('1I9&%K(&-O8V]K+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W
M:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B5VEN9&]W($)A<G4@*%]B;&%N:RDB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X.0IM<V=I
M9"`B3F5W<R(*;7-G<W1R(")"97)I=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(D=R=7`@
M0F5R:71A(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B0F5R:6MU=&YY82(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B3F5X="`T(%!H87-E<R(*
M;7-G<W1R(")&87-E($)E<FEK=71N>6$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W-@HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(DME
M;6)A;&D@:V4@4&EL:6AA;B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z,3`S"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R(")"97)I:W5T
M;GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R
M(")-86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED
M(").:6=H="(*;7-G<W1R(")-86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"B,L(&9U>GIY"FUS9VED(").;R(*;7-G<W1R(")4
M:61A:R!A9&$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL
M.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@
M<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*(E1I9&%K(&%D82!D
M871A(&MO;F9I9W5R87-I('EA;F<@=&5R<V5D:6$@=6YT=6L@;65N=6YJ=6MK
M86X@<&5R8F5D86%N('5N='5K+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R
M871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*
M;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@
M=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA
M;F=E+B(*;7-G<W1R(")4:61A:R!A9&$@<&5R=6)A:&%N+B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R(")<(B5S7"(@<W5D86@@9&ET86UB86AK86X@:V4@9&%L86T@:7II
M;B!S:7-T96TN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T
M:6PO571I;"YP:'`Z-S<S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W
M"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM
M<V=S='(@(E1I9&%K(&%D82!I:V]N('EA;F<@9&ET96UU:V%N+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(E1I9&%K(&%D82!L;VMA<VD@
M>6%N9R!D:6%T=7(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(E1I9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T=7(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G
M:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED
M(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO
M(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(E1I9&%K(&%D82!R86UA;&%N('EA;F<@=&ED86L@<V]P86XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*
M;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R
M8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L
M;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED
M("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@
M5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I
M=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(E1I9&%K(&%D82!P96YD869T87)A;B!Y86YG(&1I='5N
M9&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")"96QU
M;2!D:6%T=7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")4:61A
M:R!A9&$@871U<F%N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#0Y"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")4:61A:R!A9&$@<VES
M:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"B,L(&9U>GIY
M"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B5&ED86L@861A('-I<VDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").
M;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM
M<V=S='(@(E1I9&%K(&%D82!D:7)E:W1O<FD@<V5M96YT87)A('EA;F<@=&5R
M<V5D:6$@=6YT=6L@8V%C:&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(E-I;&%K86X@;6%S
M=6MK86X@;F%M82!P96YG9W5N82!D86X@<V%N9&D@86YD82(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!8
M34P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0HC+"!F=7IZ>0IM<V=I9"`B3F\@
M=F%L=65S(@IM<V=S='(@(E1I9&%K(&%D82!A='5R86XB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HB5&ED86L@861A('9E<G-I('EA;F<@9&ET96UU
M:V%N(&1I(&1A;&%M(&MO;F9I9W5R87-I('EA;F<@87-L:2X@365N9VAA<VEL
M:V%N("(*(FMO;F9I9W5R87-I(&ME;6)A;&DN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HB5&ED86L@861A('9E<G-I('EA;F<@9&ET96UU:V%N(&1I(&1A
M;&%M(&MO;F9I9W5R87-I(&%N9&$N($UE;F=H87-I;&MA;B`B"B)K;VYF:6=U
M<F%S:2!K96UB86QI+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`B5&ED86L@861A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I
M9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R(")4:61A:R!A9&$@*&1I
M9W5N86MA;B!S96QE;F=K87!N>6$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(E-C
M86YD:6YA=FEA("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N
M($AE;6ES<&AE<F4B"FUS9W-T<B`B0F5L86AA;B!"=6UI(%5T87)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@
M9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")"96QU;2!D:6%T=7(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I
M9"`B3F]T($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HT,#@*(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R
M>2(*;7-G<W1R(")$:7)E:W1O<FD@2&]M92(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G
M:60@(DYO="!S970B"FUS9W-T<B`B0F5L=6T@9&EA='5R(@H*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-3@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y
M,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR.#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-#(R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS
M9W-T<B`B0V%T871A;B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(E1I9&%K(&%D82!Y86YG(&1A<&%T(&1I8G)O=W-E+"!S:6QA:V%N(&ME
M;6)A;&DN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30R-0HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A
M8W1E<G,B"FUS9W-T<B`B2G5M;&%H(&)A<FES(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O
M9B!C;VQU;6YS(@IM<V=S='(@(DIU;6QA:"!K;VQO;2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB
M97(@;V8@<F]W<R(*;7-G<W1R(")*=6UL86@@8F%R:7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M(RP@9G5Z>GD*;7-G:60@(D]B:F5C="(*;7-G<W1R(")096YC:7!T82!/8FIE
M:R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/
M8FIE8W0@0W)E871O<B(*;7-G<W1R(")096YC:7!T82!/8FIE:R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#0*(RP@9G5Z>GD*;7-G:60@(D]C
M=&%L(@IM<V=S='(@(E1E;F%N9R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]K
M=&]B97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F
M9F5N<V4@9FEL=&5R(@IM<V=S='(@(D9I;'1E<B!096QA;F=G87)A;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*
M;7-G<W1R(")+86YT;W(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B4V%N9&D@;&%M82!D86X@8F%R=2!H87)U<R!B
M97)B961A+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E-A;F1I(&QA;6$B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B4V%N9&D@;&%M82!T:61A
M:R!B96YA<BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*
M;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM
M<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B2&%N>6$@
M<F%M86QA;B!Y86YG('1I9&%K('-O<&%N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q"B,L
M(&9U>GIY"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M(@IM<V=S='(@(E!E;F=G86YT:2!A;&%M870@96UA:6PB"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@
M(B(*(DAA;GEA('!E;6EL:6L@871A=2!S:7-T96T@861M:6YI<W1R871O<B!S
M86IA('EA;F<@9&%P870@;65N9W5B86@@:V5P96UI;&EK86X@(@HB871A=2!P
M96UI;&EK(&EZ:6X@=6YT=6L@8F%G:6%N(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(D)U:V$@9&D@:F5N9&5L82!Y86YG(&)A<G4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@
M:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D)U:V$@;&EN:R!I;FD@9&D@:F5N
M9&5L82!Y86YG(&)A<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B4VES=&5M($]P97)A
M<VDB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(E!I;&EH86XB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B4&EL:6AA;B!U
M;G1U:R`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R(")$869T87(@
M3F]M;W(@0F5R=7)U="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T
M<B`B5')A;G-L87-I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G
M86YI>FEN9R(*;7-G<W1R(")-96YG871U<B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M92(*;7-G<W1R(")!<&QI:V%S:2!T96UP;&%T92!A<VQI(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")496UP;&%T92!A<VQI(&1I
M(&1A;&%M("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G
M<W1R("),86EN+6QA:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q
M"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA<VD@
M3&%I;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@
M(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEZ:6X@4&5M:6QI:R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0HC+"!F=7IZ>0IM<V=I
M9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(D%R96$@:V4@=V5A=&AE<BYC;VT@=&ED86L@9&ES961I86MA;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*
M;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG
M:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")+;V1E(%!(
M4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL
M(@IM<V=S='(@(E!(4"!3:&5L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(E!-($=E<FEM:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")032!'
M97)I;6ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B4$T@0F5R<V%L:G4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I
M9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E!-($=E<FEM:7,@4V%L:G4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM
M<V=I9"`B4$T@4W5N(@IM<V=S='(@(E!-($-E<F%H(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(E!-($AU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A
M;F=I;B!R:6)U="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G
M:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(D5K<W1E
M;G-I(%!/4TE8('1I9&%K(&1I=&5M=6MA;B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")02%`@4VAE;&PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(DIA<F%K('-P87-I(&1A<FD@8F]R
M9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")086MI<W1A;B(*
M;7-G<W1R(")386QI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L
M(&9U>GIY"FUS9VED(")086YA;6$B"FUS9W-T<B`B;F%M82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R(")396)A9VEA;B!"97)A=V%N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B
M4&%S<W=O<F0B"FUS9W-T<B`B4V%N9&DB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")386YD:2!B97)H87-I;"!D:75B86@N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY
M"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4V%N9&D@;&%M
M82!T:61A:R!B96YA<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU
M<RYP:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#4S"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")+971I:R!S86YD:2!D=6$@:V%L:2!U
M;G1U:R!M96YG:V]N9FER;6%S:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E-A;F1I.B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S
M=V]R9#H@(@IM<V=S='(@(E-A;F1I.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R(")386YD:2!H87)U<R!C;V-O:RXB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B
M4V%L:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("),
M96MA=&MA;B!D87)I(&-L:7!B;V%R9"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B
M4&%T:"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED
M(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(E!E;F1A9G1A<F%N('EA;F<@
M9&ET=6YD83HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@
M(E!E;W!L92(*;7-G<W1R(")/<F%N9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S
M='(@(E!E<G-E;B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,B"FUS9W-T<B`B365L86MS86YA:V%N($]P97)A<VD@4&5M96QI:&%R
M86%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R
M(")-96QA:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@<&%D82!W86MT
M=2!L;V=I;C\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R("))>FEN(@H*
M(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B
M27II;B!U;G1U:R!<(B5S7"(@=&ED86L@9&%P870@9&EH87!U<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B
M4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B27II;B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R(*;7-G
M<W1R("))>FEN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP
M:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B27II;B!!9&UI;FES=')A
M<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S:2!0<FEB861I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")":6YA
M=&%N9R!+97-A>6%N9V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P
M:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")0:&]N92(*;7-G<W1R
M(")4:61A:R!A9&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<X
M"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*
M;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS
M9W-T<B`B4&EX96PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G
M:60@(E!L871I='5D97,B"FUS9W-T<B`B2V%T82UK871A(&ML:7-E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@
M(E-I;&%K86X@:VQI:R!K92!D86QA;2!B96)E<F%P82!S96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*
M;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#HB"FUS9W-T<B`B4VEL86MA;B!K;VYF:7)M87-I(&)A
M:'=A(&%N9&$@:6YG:6X@;65M:6YD86AK86X@96QE;65N(&EN:3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL
M:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B4VEL86MA;B!K;VYF:7)M87-I
M(&)A:'=A(&%N9&$@:6YG:6X@;65N9VAA<'5S(&QI;FL@=6YT=6L@96QE;65N
M(&EN:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R(")3:6QA:V%N(&UA<W5K:V%N(&YA;6$@=6YT=6L@:V%T96=O<FD@
M>6%N9R!B87)U.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")3:6QA:V%N(&UA<W5K:V%N(&YA
M;6$@=6YT=6L@:V%T96=O<FD@>6%N9R!B87)U.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L
M(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P
M<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B4VEL
M86MA;B!M87-U:VMA;B!R:6YG:V%S86X@=6YT=6L@;6%S86QA:"XB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E-I;&%K86X@;6%S=6MK86X@;F%M
M82!P96YG9W5N82!D86X@<V%N9&D@86YD82(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO
M=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@HB4VEL86MA;B!M96UB86-A
M('1E:W,@8F5R:6MU="!I;FDN($%N9&$@2$%255,@<V5T=6IU(&1E;F=A;B!S
M>6%R870M<WEA<F%T("(*(G5N='5K(&UE;F=G=6YA:V%N('-I<W1E;2XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.B(*;7-G<W1R(")3:6QA:V%N(&UA<W5K:V%N(&YA;6$@=6YT=6L@
M:V%T96=O<FD@>6%N9R!B87)U.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0HC+"!F=7IZ>0IM
M<V=I9"`B4&]L86YD(@IM<V=S='(@(D-O;6UA;F0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&ET
M:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0
M;VQL<R(*;7-G<W1R(")0;VQL:6YG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0HC+"!F=7IZ
M>0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R=&%L:W4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B
M4&]S:7-I('5N='5K(&=A;6)A<B!I;FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I<VD@=6YT=6L@=&%B96P@:6YI
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*
M;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")(
M=6IA;B!S86QJ=2!U;G1U:R`E<R!J86T@=&5R86MH:7(Z(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC92(*;7-G<W1R(")+96UU;F=K:6YA;B`\8G(O/DAU:F%N
M('-A;&IU(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER
M960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B5&5K86YA;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS
M9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R(")496MA;F%N
M('!A9&$@<&5R;75K86%N(&QA=70Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")496MA
M;F%N.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(DQI:&%T
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B3&EH870@9V%M8F%R(&1I(&1A;&%M(&IE;F1E
M;&$@>6%N9R!B87)U(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z
M>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B2V5M8F%L:2!K
M92!0:6QI:&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B0V5T
M86L@9&]K=6UE;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B
M4')O8FQE;2(*;7-G<W1R(")/<F%N9R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$
M97-K<FEP<VD@36%S86QA:"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-CD*;7-G:60@(E!R;VIE8W1S(@IM<V=S='(@(E!R;VIE:R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"B,L
M(&9U>GIY"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")$87)I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L
M:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T
M-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B46%T87(B
M"FUS9W-T<B`B2W5O=&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G
M:60@(E%U97)Y(@IM<V=S='(@(E%U97)Y(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")+=6]T82(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M
M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*(RP@9G5Z>GD*;7-G
M:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R(")386QI;B!0:6QI:&%N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G
M:60@(E)A:6XB"FUS9W-T<B`B2'5J86XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R(")(=6IA;B!D:2!P86=I(&AA<FDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S
M='(@(DAU:F%N(&)E8F5R87!A('-A870@;&%G:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E
M<B(*;7-G<W1R(")'97)I;6ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B2'5J86X@9&%N($)E<G-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G
M<W1R(")(=6IA;B!B97)C86UP=7(@9&5N9V%N('-A;&IU(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S
M='(@(E)A;6%L86X@06-A:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B2'5J86XB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I
M9"`B4F5A9"(*;7-G<W1R(")"86-A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(EEA:VEN('5N
M='5K(&UE;F=H87!U<R`E<S\@3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB
M871A;&MA;BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T
M82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N
M92XB"FUS9W-T<B`B(@HB66%K:6X@=6YT=6L@;65M:6YD86AK86X@9&%T82!P
M96YG9W5N82!U;G1U:R!P96YG9W5N82`E<S\@3W!E<F%S:2!I;FD@=&ED86L@
M(@HB9&%P870@9&EB871A;&MA;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(")5;&%N9VD@86MS:2!T97)A:VAI<B!A;F1A(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z(@IM<V=S='(@(E)E9G)E<V@@16QE;65N($UE;G4@1&EN
M86UI<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2
M969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")2969R97-H($QI:&%T(%!O
M<G1A;#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,U"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(")!='5R
M(&ME;6)A;&D@(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(T.0IM
M<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(D)A8V$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M
M87)K<R(*;7-G<W1R(")$:71A;F1A:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,30*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E)E;6]T
M92!397)V97(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I
M9"`B4F5M;W9E(@IM<V=S='(@(E!I;F1A:&MA;B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S
M='(@(E!I;F1A:&MA;B!";&]K:7(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34W"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M8V]L=6UN(@IM<V=S='(@(DAA<'5S(&MO;&]M(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O
M<FUA='1I;F<B"FUS9W-T<B`B4&EN9&%H:V%N($-A<F$@1F]R;6%T(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P
M86ER(@IM<V=S='(@(E!I;F1A:&MA;B!P87-A;F=A;B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")0
M:6YD86AK86X@<V-R:7!T('EA;F<@<W5D86@@9&ES:6UP86X@9&%R:2!D:7)E
M:W1O<FD@<V5R=F5R('-E;65N=&%R82XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V
M92!T:&4B"FUS9W-T<B`B4&EN9&%H:V%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO
M=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E!I;F1A
M:&MA;B!N;V1E(&EN:2!D87)I(&1O:W5M96XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G
M<W1R(")0:6YD86AK86X@<&5N9V=U;F$B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E
M('5S97(Z("5S(@IM<V=S='(@(E!I;F1A:&MA;B!P96YG9W5N83H@)7,B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PIM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5&ED86L@9&%P870@
M;65N>6EM<&%N(&MO;F9I9W5R87-I("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")4:61A:R!D
M87!A="!M96YY:6UP86X@:V]N9FEG=7)A<VD@)7,N(@H*(SH@9G)A;65W;W)K
M+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")4:61A:R!D87!A="!M96YY:6UP86X@:V]N9FEG=7)A
M<VD@)7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z
M,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B071U<B!K
M96UB86QI("(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS
M9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")!='5R(&ME;6)A;&D@4V%N
M9&DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B
M4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")!='5R(&ME;6)A;&D@4V%N
M9&D@06YD82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*
M;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R(")&87-E('1E<F%K
M:&ER(&1A<FD@4V5P87)U:"!"=6QA;B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP
M.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(DAA<VEL(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")+96UB
M86QI(&ME(%!I;&EH86XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B2V5T
M:6L@=6QA;F<@<V%N9&D@8F%R=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*
M;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B2F%L86YK86XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*
M;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(DME;6)A;&D@
M:V4@2V]N9FEG=7)A<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R
M"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B4&EL
M:6AA;B!%9&ET;W(@4FEC:"!497AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E1E:V$M=&5K:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B2V%N86XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ
M>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(D1A9G1A<B!486)E;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R
M;W!E<G1I($)A<FES+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S-`HC+"!F=7IZ>0IM<V=I9"`B4F]L92(*;7-G<W1R
M(")!='5R86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T
M871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E!R
M;W!E<G1I($)A<FES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<&5R=&D@8F%R:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B
M0F%R:7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B071U<F%N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R(")!='5R86X@86MA;B!D:71A;7!I;&MA
M;B!D:6%N=&%R82!S96UU82!B87)I<R!D86X@:V]L;VTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED
M(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G
M<W1R(")!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D:6%N=&%R82!K
M;VQO;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M<F]W<R!O;FQY(@IM<V=S='(@(D%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&AA
M;GEA(&1I86YT87)A(&)A<FES(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M,`IM<V=I9"`B4G5N(@IM<V=S='(@(DIA;&%N:V%N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R(")"86-A
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G
M:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I
M9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@
M(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T
M<B`B07)E82!K92!W96%T:&5R+F-O;2!T:61A:R!D:7-E9&EA:V%N+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#0*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`B4&5S86X@4TU3(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B4U%,(%-H96QL(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T
M871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B
M4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS
M9W-T<B`B4U]13"!3:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(E-B="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(DAU:F%N(&)E8F5R87!A('-A870@;&%G:2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M
M92`H7W-E;&8I(@IM<V=S='(@(D9R86UE('EA;F<@<V%M82`H7W-E;&8I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M4W!A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B36%R9VEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O
M(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B
M:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDX"FUS9VED(")3879E(@IM<V=S='(@(E-I;7!A;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-I;7!A;B`E<R(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4VEM<&%N("5S(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S
M='(@(E-I;7!A;B!0:6QI:&%N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)3:6UP86X@:V]N9FEG=7)A<VD@>6%N
M9R!D:6AA<VEL:V%N('-E8F%G86D@<V-R:7!T(%!(4"!K92!D86QA;2!D:7)E
M:W1O<FD@(@HB<V5R=F5R('-E;65N=&%R82!A;F1A+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMO;F9I9W5R87-I("5S('-U
M9&%H(&1I<VEM<&%N+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")38W)I<'0@<V5T=7`@
M=7!G<F%D92!S=61A:"!D:7-I;7!A;B!K93H@)R5S)RXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(E-E8F%G:6%N($AU:F%N('!E=&ER(&1I
M<V5R=&%I(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(DEL;74@4&5N9V5T86AU86XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(E!E;F-A<FEA;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(DUE<VEN(%!E;F-A
M<FEA;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@
M(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!D871E(@IM<V=S='(@(E!I;&EH('-E<G9E<B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T
M;R!A9&0B"FUS9W-T<B`B4&EL:6@@9W)U<"!U;G1U:R!D:71A;6)A:"(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A
M(&YE=R!O=VYE<B(*;7-G<W1R(")0:6QI:"!P96UI;&EK(&)A<G4B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A
M('-E<G9E<B(*;7-G<W1R(")0:6QI:"!S97)V97(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A
M9&0B"FUS9W-T<B`B4&EL:6@@<&5N9V=U;F$@=6YT=6L@9&ET86UB86@B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(DAA<'5S('-E;"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")0:6QI
M:"!F;W)M870@=&%N9V=A;#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.#<S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86X@
M;V)J96-T(@IM<V=S='(@(E!I;&EH('!E;6EL:6L@8F%R=2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*
M;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E!I;&EH('!E;6EL:6L@8F%R
M=2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M
M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(E!I;&EH(&MA<F%K=&5R('EA
M;F<@86YD82!P97)L=6MA;B!D87)I(&MO=&%K+6MO=&%K(&1I8F%W86@@:6YI
M+B!!;F1A(&1A<&%T("(*(FUE;GEA;&EN(&1A;B!M96QE:V%T:V%N;GEA(&ME
M(&1A;&%M(&%R96$@=&5K<RXB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T
M<B`B4&EL:6@@8F%T87,@=&%N9V=A;#HB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS
M9W-T<B`B4&EL:6@@9F]R;6%T('1A;F=G86PZ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E!I;&EH(&ED
M96YT:71A<R!Y86YG(&EN9VEN(&1I=6)A:"!O;&5H(&%N9&$Z(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!D96QI;6ET97(Z(@IM<V=S='(@(E!I;&EH(&)A=&%S('=A:W1U.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R(")0:6QI:"!F;W)M870@=V%K='4Z(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T
M('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E!I;&EH(&1U82!K;VQO
M;2!Y86YG(&-O8V]K+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#8*
M;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B4&EL
M:6@@=V%R;F$@<V-H96UE(&%N9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R(")0:6QI:"!B86AA<V$@>6%N9R!A;F1A(&EN9VEN:V%N.B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(DMI<FEM($QA<&]R86X@36%S
M86QA:"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W(Z
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P
M.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*
M;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T96UB97(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA
M(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`Q"B,L(&9U>GIY"FUS9VED(")397)I86P@
M3G5M8F5R(@IM<V=S='(@(D%N9VMA($1E<VEM86PB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!<F5A($UE
M=&%R('1I9&%K(&1I<V5D:6%K86XN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(DEZ
M:6X@061M:6YI<W1R87-I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER
M960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM
M<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B27II;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*(RP@9G5Z>GD*;7-G:60@(E-E="(*;7-G<W1R
M(")3971U<"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)!='5R('!I
M;&EH86X@=6YT=6L@;65N9VEZ:6YK86X@86YD82!D87!A="!M96YG871U<B!U
M;&%N9R!K96UB86QI('-A;F1I(&%N9&$@(@HB87!A8FEL82!A;F1A(&QU<&$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P
M(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@
M>6]U<B!P;W)T86PN(@IM<V=S='(@(D%T=7(@<F5M;W1E('-E<G9E<B!Y86YG
M(&EN9VEN(&%N9&$@86MS97,@9&%R:2!P;W)T86P@86YD82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#0*;7-G:60@(E-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T
M<B`B071U<B!B86AA<V$L('IO;F$@=V%K='4@9&%N('!I;&EH86X@=&%N9V=A
M;"P@>6%N9R!A;F1A(&EN9VEN:V%N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B
M"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D%T=7(@87!L:6MA<VD@
M87=A;"!A;F1A+"!W87)N82!S8VAE;64L(&AA;&%M86X@<F5F<F5S:"!D86X@
M<&EL:6AA;B!T86UP:6QA;B`B"B)L86EN;GEA+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(E-E='5P(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@
M(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4V-R
M:7!T('-E='5P('5P9W)A9&4@=&5R<V5D:6$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")"96)E<F%P
M82!L;VMA<VD@>6%N9R!M=6YG:VEN(&1E;F=A;B!P87)A;65T97(Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R(")"96QA;FIA(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4FEN9VMA
M<V%N(%!E;F1E:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R(")097)L=6MA:"!K=6YC:2!A:W-E<R!D:61E9FEN:7-I
M:V%N('5N='5K(&ME8F%N>6%K86X@;&EN:S\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")4
M86UP:6QK86XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED
M("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*(E1A;7!I;&MA;B!P97)B961A86X@9&EA;G1A<F$@:V]N9FEG
M=7)A<VD@>6%N9R!B87)U(&1I<VEM<&%N(&1A;B!Y86YG(&)A<G4@(@HB9&EH
M87-I;&MA;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(E1A;7!I;&MA;B!W86MT=2!L;V=I;B!T97)A:VAI<B!K971I:V$@86YD
M82!L;V=I;C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS
M9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*(RP@9G5Z>GD*;7-G
M:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(D=E<FEM:7,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(V"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_(@IM<V=S='(@(E1A;7!I;&MA;B!P86YE;"!M96YU('1A
M8F5L(&]P97)A<VD_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/R(*;7-G<W1R(")486UP:6QK86X@365N=2`E<R!D:2!S96)E;&%H(&MI
M<FD_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A;7!I;&MA;B!D:6%L;V<@4')O<&5R
M=&D@4V5L(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486UP:6QK86X@9&EA;&]G(%!R
M;W!E<G1I(%1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%M<&EL:V%N(&1I86QO
M9R!0<F]P97)T:2!"87)I<R!486)E;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%M<&EL:V%N
M(&1I86QO9R!P<F]P97)T:2!G86UB87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R(")'97)I;6ES(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B1V5R:6UI<R!D:2!P86=I(&AA<FDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R
M<R!,871E(@IM<V=S='(@(D=E<FEM:7,@8F5B97)A<&$@<V%A="!L86=I(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(D=E<FEM:7,@
M9&D@<V5K:71A<B!D865R86@B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"B,L(&9U
M>GIY"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B1&%F=&%R($)A8V%A;B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED
M(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS
M9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(DQE=V%T:2!096UE;&EH
M87)A86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM
M<V=I9"`B4VYO=R(*;7-G<W1R(")386QJ=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*
M;7-G<W1R(")'97)I;6ES(%-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G
M<W1R(")'97)I;6ES(%-A;&IU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*
M;7-G<W1R(")'97)I;6ES(%-A;&IU(&1I('!A9VD@:&%R:2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W
M(%-H;W=E<G,@3&%T92(*;7-G<W1R(")'97)I;6ES(%-A;&IU(&)E8F5R87!A
M('-A870@;&%G:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED
M(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B2V5D86QA;6%N(%-A;&IU.B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z("(*;7-G<W1R(")097)B86YD:6YG86X@<V%L:G4@9&D@
M*&1A;&%M*2!A:7(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS
M9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(DQA9W4@)B!386IA:R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*(RP@9G5Z>GD*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(DAA<'5S('!I;&EH86XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G
M<W1R(")!;&%M870@16UA:6P@06YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@
M(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM
M<V=S='(@(D5R;W!A(%-E;&%T86X@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(D)E;&%H86X@0G5M:2!396QA=&%N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@
M(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B2F%R86L@
M86YT87)A('-E;"!Y86YG(&)E<F1E:V%T86XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")*87)A
M:R!A;G1A<F$@:7-I(&1A;B!B;W)D97(@9&D@9&%L86T@<V5L(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"B,L(&9U>GIY"FUS9VED(")3<&%C
M97(B"FUS9W-T<B`B2F%R86L@<W!A<VDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B
M"FUS9W-T<B`B2F%R86L@<W!A<VDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(DIA<F%K('-P87-I(&1A;B!J87)A:R!S<&%S
M:2!D87)I(&)O<F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")3
M<&%I;B(*;7-G<W1R(")*87)A:R!S<&%S:2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A
M8W1E<B!);G!U="(*;7-G<W1R(")-87-U:VMA;B!+87)A:W1E<B!3<&5S:6%L
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")0:7-A:&MA;B!3
M96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4&ES86AK
M86X@:V]L;VTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4&ES
M86AK86X@8F%R:7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G
M:60@(E-P;W)T<R(*;7-G<W1R(")/;&%H<F%G82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B4&5R:F%L
M86YA;B!":6YT86YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"B,L(&9U>GIY"FUS9VED
M(")3=&%R="!Y96%R(@IM<V=S='(@(E!E<FIA;&%N86X@0FEN=&%N9R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3
M=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(E-T871U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@
M9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FUA="!7
M86MT=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R
M"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I
M:V5T:')O=6=H(@IM<V=S='(@(D%N9VMA+VAU<G5F+W-I;6)O;"!Y86YG(&1I
M8F5R:2!T86YD82!G87)I<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE
M(%M#4U-=(@IM<V=S='(@(D=A>6$@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R
M(")-:6XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")3=6)D:7)E:W1O<FD@)R5S)R!T:61A:R!D:71E;75K
M86XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,PHC+"!F=7IZ>0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!;F=K82]H
M=7)U9B]S:6UB;VP@>6%N9R!D:71U;&ES(&1I8F%W86@@9V%R:7,@8F%R:7,@
M=&5K<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*(RP@9G5Z>GD*;7-G:60@
M(E-U8FUI="(*;7-G<W1R(")!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U
M;&ES(&1I8F%W86@@9V%R:7,@8F%R:7,@=&5K<R(*"B,Z('-I9VYU<"YP:'`Z
M-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R
M97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N
M;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R
M;W9E9"XB"FUS9W-T<B`B(@HB(%!E<FUI;G1A86X@>6%N9R!D:7-A;7!A:6MA
M;B!U;G1U:R!M96YA;6)A:&MA;B`G)2!S)R!K92!D86QA;2!S:7-T96TN($%N
M9&$@(@HB=&ED86L@9&%P870@;&]G(&EN('-A;7!A:2!P97)M:6YT86%N(&%N
M9&$@=&5L86@@9&ES971U:G5I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M(")!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U;&ES(&1I8F%W86@@9V%R
M:7,@8F%R:7,@=&5K<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")"97)H87-I
M;"(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(B<E<R<@<W5D86@@8F5R:&%S:6P@9&ET86UB86AK86X@
M:V4@9&%L86T@<VES=&5M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")$871A('5N='5K('!E;F=G=6YA("<E<R<@<W5D86@@8F5R:&%S:6P@9&EB
M97)S:6AK86X@9&%R:2!S:7-T96TN(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX
M,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E
M<UPB<W5D86@@8F5R:&%S:6P@9&EH87!U<RXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B<E
M<R!S=61A:"!B97)H87-I;"!D:7!I;F1A:&MA;B!D87)I('-I<W1E;2XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%S:2!S=61A:"!B97)H87-I;"!D
M:6ME;6)A;&EK86XN(%5L86YG:2!U;G1U:R!M96QI:&%T('!E<G5B86AA;BX@
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D)A8VMU<"!K;VYF:6=U<F%S:2!S
M=61A:"!B97)H87-I;"!D:7-I;7!A;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B1FEL92!"86-K=7`@2V]N9FEG=7)A<VD@)7,@<W5D86@@8F5R:&%S:6P@
M9&ES:6UP86XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B
M"FUS9W-T<B`B)R5S)R!S=61A:"!B97)H87-I;"!D:7!E<F)A:&%R=6DB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B"FUS9W-T<B`B)R5S)R!S=61A:"!B97)H87-I;"!D:71U;&ES(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M0V5R86@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E)I;F=K87-A
M;B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I
M<V4B"FUS9W-T<B`B36%T86AA<FD@5&5R8FET(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(DUA=&%H87)I
M(%1E<F)E;F%M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(D-E<F%H(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R(")-871A:&%R:2!497)B:70B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I
M<V4O4W5N<V5T(@IM<V=S='(@(DUA=&%H87)I(%1E<F)I="]-871A:&%R:2!4
M97)B96YA;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*
M;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")-871A:&%R:2!497)B:70Z(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B4W5N
M<V5T(@IM<V=S='(@(DUA=&%H87)I(%1E<F)E;F%M(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T
M<B`B36%T86AA<FD@5&5R8F5N86TZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS
M9W-T<B`B06YG:V$O:'5R=68O<VEM8F]L('EA;F<@9&ET=6QI<R!D:6%T87,@
M8F%R:7,@=&5K<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*
M;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B1'5K=6YG86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")N86UA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z
M>GD*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B;F%M82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T
M960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM
M<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I
M86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G
M<W1R(")(=6IA;B!P971I<B!D:7-E<G1A:2!D96YG86X@86YG:6X@<FEB=70B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM
M<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B2'5J86X@<&5T:7(@
M9&ES97)T86D@9&5N9V%N(&)A9&%I(&%N9VEN(')I8G5T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O
M<FUS(@IM<V=S='(@(DAU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A;B!A;F=I
M;B!R:6)U="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")'97)I;6ES(&1I('!A9VD@:&%R:2(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$O='-V+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S
M='(@(DIU9'5L(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(D1A9G1A<B!486)E;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<&5R
M=&D@5&%B96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")486)L92!3970B"FUS9W-T<B`B
M4')O<&5R=&D@5&%B96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S
M(@IM<V=S='(@(E!R;W!E<G1I('1A8F5L(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0HC+"!F=7IZ>0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(DAU:F%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A
M:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B5&%R9V5T.B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5'5G87,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H
M;VYE($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y,`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4W5H
M=2!U;G1U:R!J86T@=&5R86MH:7(Z(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E-U:'4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A
M='5R93H@(@IM<V=S='(@(E-U:'4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(E-U:'4\
M8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")$
M:7)E:W1O<FD@36]T:68@)R5S)R!T:61A:R!D:71E;75K86XN(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(E1E;7!L871E($%D;6EN:7-T<F%S:2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S-@HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G<W1R(")"97)I
M:W5T;GEA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B
M5&5X="!/;FQY(@IM<V=S='(@(DAA;GEA(%1E:W,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")4
M97AT(&%L:6=N(@IM<V=S='(@(E!E<F%T86%N(%1E:W,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT
M=&]P(@IM<V=S='(@(E1E:W,@0F%G:6%N($%T87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G
M<W1R(")+;7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B5&AA:2`H5$E3+38R,"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@
M=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,C`*(RP@9G5Z>GD*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%R96$@:V4@=V5A
M=&AE<BYC;VT@=&ED86L@9&ES961I86MA;BXB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R
M9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0
M+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")096UE;&EH87)A
M86XZ.B!C;&%S<R!T:61A:R!B97)H87-I;"!D:7!A;F=G:6PB"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B5VEN
M9&]W(%!I;&EH86X@<W5D86@@9&ET=71U<"X@4VEL86MA;B!+96QU87(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN
M:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI
M<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@
M;VYL>2(*;7-G<W1R(")(86YY82!S:7-I(&)A9VEA;B!B87=A:"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS
M9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T
M86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T
M(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@
M:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L
M;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@
M86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E
M;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@
M9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@
M=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E
M("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L
M;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)-;V1E($QA>6%R(%!E;G5H
M(&1I:V5N86P@9&%P870@;65N>65B86)K86X@;6%S86QA:"!D96YG86X@26YT
M97)N970@17AP;&]R97(L("(*(FIU9V$@=6YT=6L@;65N8V%R:2!K97-A;&%H
M86X@>6%N9R!M96YY96)A8FMA;B!A;F1A('1I9&%K(&UA;7!U(&)E:V5R:F$@
M(@HB9&5N9V%N(&)A:6LN($%N9&$@;75N9VMI;B!P97)N86@@;65N9V%L86UI
M('1A;7!I;&%N('EA;F<@8G5R=6LL(&ME:W5R86YG86X@(@HB9&%R:2!F=6YG
M<VD@961I=&]R(&1A;B]A=&%U(&)R;W=S97(@>6%N9R!S97)I;F<@:V%L:2!R
M=7-A:R!D86X@:&%R=7,@9&EU;&%N9R`B"B)K96UB86QI+B!*:6MA('-I<W1E
M;2!A;F1A(&%D86QA:"!7:6YD;W=S(#EX(&%D82!K96UU;F=K:6YA;B!A;F1A
M(&%K86X@(@HB;65N9&%P871K86X@)TME<V%L86AA;B!097)L:6YD=6YG86X@
M56UU;2<@9&%N('!E<FQU('5N='5K(&UE+7)E<W1A<G0@(@HB:V]M<'5T97(@
M86YD82Y<7&Y<7&X@06YD82!S=61A:"!D:7!E<FEN9V%T:2X@4VEL86MA;B!K
M;&EK($]+(&II:V$@86YD82!I;F=I;B`B"B)M96YC;V)A(&5D:71O<B!L87EA
M<B!P96YU:"XB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("))9&5N=&ET87,@7"(E<UPB('-U9&%H(&1I:&%P=7,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B2&%N>6$@<VES:2!B86=I86X@:VER:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F
M('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?
M<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA
M<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS
M9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP
M;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#0Q"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E
M(&YU;65R:6,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES
M(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(DAA;GEA('-I
M<VD@8F%G:6%N(&MA;F%N(&1A;B!K:7)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DAA;GEA('-I<VD@8F%G:6%N
M(&MA;F%N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"FUS
M9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@<W5D86@@
M8F5R:&%S:6P@9&EH87!U<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R(%PB)7-<(B!S=61A
M:"!B97)H87-I;"!D:7-I;7!A;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")097)M:6YT86%N('!E;F1A
M9G1A<F%N('5N='5K("5S('-U9&%H(&)E<FAA<VEL(&1I<&EN9&%H:V%N+B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I
M9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T
M<B`B2&%N>6$@<VES:2!B86=I86X@871A<R!D86X@8F%W86@B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS
M9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R(")(86YY82!S:7-I(&)A
M9VEA;B!A=&%S(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS
M9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R
M"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B07)E82!K92!W96%T:&5R+F-O;2!T:61A
M:R!D:7-E9&EA:V%N+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")$:7)E:W1O<FD@36]T:68@)R5S
M)R!T:61A:R!D:71E;75K86XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`B07)E82!-971A<B!T:61A:R!D:7-E
M9&EA:V%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M
M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M
M.B`E<R(*;7-G<W1R(")!9&$@;6%S86QA:"!K971I:V$@;65N86UB86AK86X@
M)R5S)R!K92!D86QA;2!S:7-T96TZ("5S("(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R(")!9&$@;6%S86QA:"!K971I:V$@;65M8F5R
M<VEH:V%N(&1A=&$@=6YT=6L@<&5N9V=U;F$@)R5S)R!D87)I('-I<W1E;3HB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D%D82!M87-A;&%H(&ME=&EK82!M
M96UI;F1A:&MA;B`G)7,G(&1A<FD@<VES=&5M.B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(D%D82!M
M87-A;&%H(&ME=&EK82!M96UP97)B86AA<G5I("<E<R<Z)7,B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@
M;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O
M<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N
M(@IM<V=S='(@(B(*(D%D82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@
M:V]N9FEG=7)A<VDN($UU;F=K:6X@86YD82!T:61A:R!M96YG:7-I("(*(FMO
M;&]M('EA;F<@9&EP97)L=6MA;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0P"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB061A(&ME<V%L86AA;B!D:2!D86QA
M;2!F;W)M=6QI<B!K;VYF:6=U<F%S:2X@375N9VMI;B!A;F1A('1I9&%K(&UE
M;F=I<VD@(@HB:V]L;VT@>6%N9R!D:7!E<FQU:V%N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L(&9U>GIY"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"B)!9&$@:V5S86QA:&%N(&1I(&1A;&%M(&9O<FUU;&ER(&MO;F9I9W5R
M87-I+B!-=6YG:VEN(&%N9&$@=&ED86L@;65N9VES:2`B"B)K;VQO;2!Y86YG
M(&1I<&5R;'5K86XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X"B,L(&9U>GIY"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")"
M<F]W<V5R(&%N9&$@=&ED86L@;65N9'5K=6YG('5N='5K(&9I='5R(&EN:2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS
M9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,30U"FUS9VED(")4:&ES(&1O97,@;F]T('-E
M96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S
M-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY
M("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q
M=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY
M("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*
M;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C
M;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O
M<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L
M<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@
M:7,@)7,N(@IM<V=S='(@(DEN:2!A9&%L86@@)7,N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T
M('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I
M9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM
M<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED
M(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W(@IM<V=S='(@(E=I;F1O=R!I;FD@:&%R=7,@9&EP86YG9VEL(&1A
M<FD@4&EL:6AA;B!7:6YD;W<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")0971I
M<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B5&EK970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R(")*=61U;"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS
M9W-T<B`B365N9VEK=71I(%=A:W1U(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP
M.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M870@5V%K='4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"B,L(&9U>GIY"FUS
M9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")(87!U<R!P:6QI:&%N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B
M2G5D=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(DIU9'5L
M("A#871A=&%N('!E='5N:G5K*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(E1O(@IM<V=S
M='(@(D%T87,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Q"FUS9VED(")4;V1A>2(*;7-G<W1R
M(")(87)I($EN:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R
M(")'86YT:2!3;W5R8V4@2%1-3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O
M9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S
M"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")"97-O:R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*(RP@9G5Z>GD*;7-G:60@(E1O;F=A(@IM<V=S='(@(DAA<FD@26YI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B071A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M
M92`H7W1O<"DB"FUS9W-T<B`B1G)A;64@071A<R`H7W1O<"DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G
M<W1R(")4<F%N<VQA<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A
M9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B4V5L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K
M97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G
M:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<FMI("A)4T\M
M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN
M9&5X.B`B"FUS9W-T<B`B26YD96MS(%4N5CHB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC
M+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R(")'87)I<R!B87=A:"(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA
M8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<
M(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M
M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@
M;V8@7"(E<R\E<UPB+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG
M:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q
M;"YP:'`Z-#,U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+B(*;7-G<W1R(")4:61A:R!D87!A="!T97)H=6)U;F<@
M:V4@<V5R=F5R(&QD87`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA
M<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")4:61A:R!D87!A
M="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`B5&ED86L@9&%P870@=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(E1I
M9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S
M7"(Z("5S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S0T"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U
M<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@
M7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S@S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@
M(E1I9&%K(&1A<&%T('5N='5K(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E
M<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U
M:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@P,PIM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R
M96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T
M(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]!=71H+G!H<#HQ,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")4
M:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM
M<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV
M-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M96YG:&%P=7,@7"(E<UPB
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z.#`@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M,@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G
M:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B5&ED86L@9&%P870@=6YT=6L@
M;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O
M="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(V-R!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E1I9&%K(&1A<&%T('5N='5K
M(&UE;F=H87!U<R!<(B5S7"(Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")4:61A:R!D87!A="!U;G1U:R!M
M96YG:&%P=7,@7"(E<UPB.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5&ED86L@9&%P870@
M=6YT=6L@;65N9VAA<'5S(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B
M1V%R:7,@8F%W86@B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS
M9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B0F%T86QK86X@4&5R=6)A:&%N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B0F%T
M86QK86X@86MS:2!T97)A:VAI<B!A;F1A(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B5&ED86L@9&EA<G-I<&MA
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@
M(E5N:71S(@IM<V=S='(@(E5N:70B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK
M;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U.0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B5&ED86L@861A(&QO:V%S:2!Y86YG(&1I871U<BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0B"FUS9W-T<B`B0F%T86QK86X@;&EN:R!P861A(&5L96UE;B!Y86YG('-E
M:V%R86YG(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR
M.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B;F%M82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G
M:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T
M+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R
M96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@
M;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB
M4V-R:7!T('EA;F<@=&ED86L@;65M<'5N>6%I(&AA:R!I<W1I;65W82!T:61A
M:R!D87!A="!M96YG86MS97,@2&%P=7,O4V%L:6XO(@HB3&5K871K86X@<V5S
M=6%I(')E;F-A;F$@=6YT=6L@86QA<V%N(&ME86UA;F%N+DML:6L@3TL@=6YT
M=6L@;65L:6AA="!C871A=&%N("(*(G1E:VYI<R!P861A(&UO>FEL;&$N;W)G
M(&1I;6%N82!A;F1A(&%K86X@9&EP97)L:6AA=&MA;B!C87)A(&)A9V%I;6%N
M82!U;G1U:R`B"B)M96YG:7II;FMA;B!S8W)I<'0@=6YT=6L@9&%P870@;65N
M9V%K<V5S(&ME(&-L:7!B;V%R9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R(")787)N82!B96QU;2!D:6%T=7(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E
M;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B
M"FUS9W-T<B`B4&5R8F%H87)U:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S
M(@IM<V=S='(@(E!E<F)A:&%R=6D@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R
M(")097)B86AA<G5I('!E;F=G=6YA(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ
M-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S
M7"(N(@IM<V=S='(@(EPB)7-<(B!S=61A:"!D:7!E<F)A:&%R=6DN(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R
M:7!T(&1E;&5T960N(@IM<V=S='(@(E-C<FEP="!U<&=R861E('-U9&%H(&1I
M:&%P=7,N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO
M860B"FUS9W-T<B`B57!L;V%D(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I
M;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(E-E;75A(&9I;&4@<V5T=7`@
M87!L:6MA<VD@<W5D86@@9&EU<&QO860@:V4@<V5R=F5R+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B4VEM8F]L(&AU
M<G5F(&)E<V%R(&QA=&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@
M;G5M8F5R<R(*;7-G<W1R(")3:6UB;VP@:'5R=68@8F5S87(@<F]M87=I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM
M<V=S='(@(D9A<V4@4V5K87)A;F<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5
M<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R
M=F5R+B(*;7-G<W1R(")'=6YA:V%N;&%H(&II:V$@;F%M82]S86YD:2!A;F1A
M(&)E<F)E9&$@=6YT=6L@<V5R=F5R($E-4U`N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*
M;7-G<W1R(")096YG9W5N82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B061M:6YI<W1R87-I(%!E;F=G=6YA(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3$*(RP@9G5Z>GD*;7-G:60@(E5S97(@3W!T
M:6]N<R(*;7-G<W1R(")3:6UP86X@4&EL:6AA;B(*"B,Z('-I9VYU<"YP:'`Z
M-C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E!E;F1A9G1A
M<F%N(%!E;F=G=6YA(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB
M"FUS9W-T<B`B4&5N9&%F=&%R86X@4&5N9V=U;F$@<W5D86@@9&EN;VXM86MT
M:69K86X@=6YT=6L@<VET92!I;FDN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R
M(")!8V-O=6YT(%!E;F=G=6YA('1I9&%K(&1I=&5M=6MA;B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DYA;6$@4&5N
M9V=U;F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3F%M82!096YG
M9W5N83HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED
M(")5<V5R;F%M93H@(@IM<V=S='(@(DYA;6$@4&5N9V=U;F$Z(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@
M=&AE('-Y<W1E;3HB"FUS9W-T<B`B4&5N9V=U;F$@9&D@9&%L86T@<VES=&5M
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B4W5B9&ER96MT;W)I
M("<E<R<@=&ED86L@9&ET96UU:V%N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(DQI8G5R86XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,S@*(RP@9G5Z>GD*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(DME;&5M8F%B86XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G
M:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V
M97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE
M8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU
M871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8FQE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#`*(RP@9G5Z>GD*;7-G:60@(E9E<G-I;VXB
M"FUS9W-T<B`B5F5R<VD@2V]N=')O;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")6
M97)S:2!+;VYT<F]L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS
M9W-T<B`B2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N=&%R82!G87)I<R!D87-A
M<B!D96YG86X@9V%M8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G
M<W1R(")*87)A:R!P;W-I<VD@=F5R=&EK86P@86YT87)A(&)O<F1E<B!D96YG
M86X@9V%M8F%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I:V%L
M.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P
M"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B4V%N9V%T(%1I;F=G:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(E9I971N86T@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(DQI:&%T('=E8B!P86=E(&5K<W1E<FYA;"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(DIA<F%K(%!A;F1A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B2F%R
M86L@4&%N9&%N9SHB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA
M(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%2
M3B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B4$5224Y'051!3B$A(2!024Y$
M04A+04X@4T-225!4($E.22!314-!4D$@34%.54%,($1!4DD@)7,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@
M(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W
M,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS
M9W-T<B`B4&5R:6YG871A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(E)A8G4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B4F%M86QA;B!#=6%C82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T
M82!P<F]V:61E9"!B>2(*;7-G<W1R(")$871A($-U86-A(&1I<V5D:6%K86X@
M;VQE:"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@HC+"!F=7IZ
M>0IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@
M(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@
M(E=E8B!3:71E(@IM<V=S='(@(E=E8B!3:71E(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS
M9VED(")796QC;VUE(@IM<V=S='(@(E-E;&%M870@1&%T86YG(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B
M"FUS9W-T<B`B4V5L86UA="!D871A;F<@:V4@)7,B"@HC.B!S97)V:6-E<R]P
M;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B
M4V5L86UA="!D871A;F<L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R(")797-T97)N
M("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!3
M86AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")!<&%K86@@87!L
M:6MA<VD@)7,@<&5R;'4@9&ET86UP:6QK86X@<V5T96QA:"!L;V=I;C\B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I
M<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B07!A:V%H('EA
M;F<@;65R=7!A:V%N(&)A=&%S(&MA<F%K=&5R/R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_(@IM<V=S='(@(D%P86MA:"!Y86YG(&UE<G5P86MA;B!K87)A
M:W1E<B!I;F1E;G1A<VD_(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R(")&87-E('EA;F<@;6%N82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M4&QU9VEN(&UA;F%K86@@>6%N9R!D87!A="!D:6%K=&EF:V%N('5N='5K(&5D
M:71O<B!2:6-H(%1E>'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B
M3&5B87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"B,L(&9U
M>GIY"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B3&5B87(@
M=6YI="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@
M*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(DQE
M8F%R(&UE;G4@)7,@<&%D82!B86=I86X@:VER:2`H86MA;B!B97)P96YG87)U
M:"!P861A(&QO9VEN(&)E<FEK=71N>6$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H
M92!T86)L92(*;7-G<W1R("),96)A<B!T86)E;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(DQE8F%R('5N:70B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S
M='(@(DQE8F%R.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B06YG:6XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R(")!;F=I;B!D:2!P86=I(&AA<FDB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN
M;W1S(@IM<V=S='(@(DME8V5P871A;B!A;F=I;B!D:2!D86QA;2!K;F]T(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S
M='(@(D%N9VEN.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")!;F=I;CHB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")+871A
M($)I:F%K<V%N82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*
M;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(D1A9G1A<B!+96EN9VEN86XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T
M<B`B4&5K97)J86%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B06QA;6%T($5M86EL($%N9&$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E
M8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED
M(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS
M:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I
M9"`B65DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T
M<B`B65DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")9
M96%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B66$L(%-!64$@4T5454I5(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U
M(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W
M:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(D%N9&$@8F5R861A
M(&1I(&1A;&%M($U/1$4@5$5+4RX@1W5N86MA;B!T;VUB;VP@6SP^72!U;G1U
M:R!M96YG9V%N=&D@:V5M8F%L:2`B"B)K92!D86QA;2!M;V1E(%=94TE764<N
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@
M=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(D%N9&$@=&ED86L@9&EI>FEN:V%N
M('5N='5K(&UE;6)U870@;&5B:6@@9&%R:2`E9"!A<F5A+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@
M=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S4*(RP@9G5Z>GD*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B4&5N
M9V=A;G1I(&%L86UA="!E;6%I;"(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA
M<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O
M<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(EEO=2!H879E(&)E
M96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P
M=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P
M<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C
M:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@
M=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R
M97!O<G0N(@IM<V=S='(@(B(*(D%N9&$@:&%R=7,@;65N:F5L87-K86X@;6%S
M86QA:"!S96)E;'5M(&%N9&$@9&%P870@;65N9VER:6UK86X@;&%P;W)A;B`B
M"B)M87-A;&%H+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")!;F1A(&AA<G5S(&UE
M;6%S=6MK86X@55),(&1I;6%N82!L:6YK(&EN:2!M96YU;FIU:R!K92(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(D%N
M9&$@:&%R=7,@;65M:6QI:"!S97)V97(@=6YT=6L@9&%P870@9&EH87!U<RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(D%N9&$@:&%R
M=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA;F<@:6YG:6X@9&EB97)S
M:6AK86XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")!;F1A
M(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I
M<&EN9&%H:V%N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF
M>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE
M;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D:71A;6)A:"XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B06YD82!H87)U<R!M96YE
M=&%P:V%N(&YA;6$@<&5N9V=U;F$@=6YT=6L@9&EP97)B86AA<G5I+B(*"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+B(*;7-G<W1R(")!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P
M96YG9W5N82!Y86YG(&EN9VEN(&1I<&EN9&%H:V%N+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM
M<V=S='(@(D%N9&$@:&%R=7,@;65N971A<&MA;B!N86UA('!E;F=G=6YA('EA
M;F<@:6YG:6X@9&EP:6YD86AK86XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D
M('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM
M<V=S='(@(D%L86UA="!%;6%I;"!!;F1A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(Q,@IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R
M(")!;F1A($1A<FDZ(&%L86UA=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87-I($%N9&$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(DYA;6$@06YD82(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"B)"86-K96YD(&%S;&D@86YD82!T:61A:R!D87!A="!M96YD=6MU;F<@
M<&5N86UB86AA;B!P96YG9W5N82P@871A=2!F:71U<B!I;FD@(@HB<W5D86@@
M9&EN;VXM86MT:69K86X@=6YT=6L@8F5B97)A<&$@86QA<V%N(&QA:6XN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B
M"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D
M:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(D)A
M8VME;F0@87-L:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!P96YD869T
M87)A;B!P96YG9W5N82P@871A=2!F:71U<B!I;FD@(@HB<W5D86@@9&EN;VXM
M86MT:69K86X@=6YT=6L@8F5B97)A<&$@86QA<V%N(&QA:6XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E
M('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R(")"<F]W<V5R(&%N9&$@=&ED86L@;65N9'5K=6YG('5N='5K(&9I='5R
M(&EN:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@HC
M+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(D)R;W=S97(@86YD82!T:61A
M:R!M96YD=6MU;F<@<&EL:6AA;B!U;G1U:R!M96YC971A:RX@5&5K86X@0V]N
M=')O;"]0:6QI:&%N("L@(@HB4"!U;G1U:R!M96YC971A:RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.B(*;7-G<W1R("):;VYA(%=A:W1U($%N9&$@4V5K87)A;F<Z(@H*
M(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B1&5F875L="!I
M9&5N=&ET87,@86YD82!S=61A:"!D:75B86@N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*
M;7-G<W1R(")$969A=6QT(&ED96YT:71A<R!A;F1A.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,#$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G
M<W1R(").86UA(&QE;F=K87`@86YD83HB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HQ,#`P"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@
M:7,Z("5S(@IM<V=S='(@(E-A;F1I(&)A<G4@86YD82!U;G1U:R`E<R!A9&%L
M86@Z("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE
M(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B1&5F
M875L="!I9&5N=&ET87,@86YD82!S=61A:"!D:75B86@N(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970B"FUS9W-T<B`B4V%N9&D@86YD82!S=61A:"!D:6%T
M=7(@=6QA;F<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM
M<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O
M<F0N(@IM<V=S='(@(B(*(E-A;F1I(&%N9&$@<W5D86@@9&EA='5R('5L86YG
M+"!P97)I:W-A;&%H(&5M86EL(&%N9&$@9&%N(&QO9VEN(&1E;F=A;B`B"B)M
M96YG9W5N86MA;B!S86YD:2!B87)U(&%N9&$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,S(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<&%S<W=O<F0@
M:&%S(&5X<&ER960N(@IM<V=S='(@(E-A;F1I(&%N9&$@<W5D86@@9&EA='5R
M('5L86YG(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")296UO=&4@<V5R
M=F5R(&%N9&$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L
M879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"B,L(&9U>GIY"FUS9VED("):86ER92(*;7-G<W1R(")#97)A:"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(D-E
M<FEA(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S
M='(@(EM396UB=6YY:6MA;B!);F1E;G1A<VD@5&5K<UTB"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G
M<W1R(");3&%P;W)A;B!-87-A;&%H72(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X
M="`M(@IM<V=S='(@(EM486UP:6QA;B!);F1E;G1A<VD@5&5K<R`M(@H*(SH@
M9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N
M<&AP.C$W,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O
M=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6U1A;7!I;&%N($EN9&5N
M=&%S:2!496MS("TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=
M(@IM<V=S='(@(B5S('5N='5K("5S("5S(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*
M;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R87-I
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(E]#
M3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R(")?1&%T851R964B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(DAA<'5S($)A<FES(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED
M(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS
M9W-T<B`B0F%N='5A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B4')O<&5R=&D@1V%M8F%R+BXN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B
M7TQO9R!I;B(*;7-G<W1R("),;V=I;B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(DQO9R!O=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN
M+B(*;7-G<W1R(")58F%H($QI;FLN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R(")0:6QI:&%N(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B27II;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(E!I;F1A:&MA;B!,:6YK+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7U-E='5P
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M(")0<F]P97)T:2!486)E;"XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I
M9"`B7U5S97)S(@IM<V=S='(@(E!E;F=G=6YA(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O
M:R(*;7-G<W1R(")"=6MU($%L86UA="`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*
M(RP@9G5Z>GD*;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R(")496YA
M;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM
M<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B
M8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*(RP@
M9G5Z>GD*;7-G:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B4&5R
M8F5D86%N($MO;F9I9W5R87-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI
M<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3@R"B,L
M(&9U>GIY"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B06-C;W5N
M="!096YG9W5N82!T:61A:R!D:71E;75K86XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G
M<W1R(")J871U:"(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@U-0HC+"!F=7IZ>0IM<V=I9"`B9FEL92(*;7-G<W1R(")4:61A:R!D:6%R
M<VEP:V%N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G
M<W1R(")$87)I("5S("@E<RD@<&%D82`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B
M86YG:6X@:V5N8V%N9R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B:6YL:6YE(@IM<V=S='(@(FUA<VEH(&1I(&1A;&%M(&%N=')I86XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B
M:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T
M=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(F)A
M<FES72(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R
M<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I
M9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM
M<V=S='(@(FYA;6$B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS
M9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N;W0@>65T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`U"B,L(&9U>GIY"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(G1E
M=&%P(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P97)S96XB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ
M>0IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`B27II;B!U;G1U
M:R!<(B5S7"(@=&ED86L@9&%P870@9&EH87!U<RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P
M:7AE;',B"FUS9W-T<B`B<&EX96PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O
M8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B;F%I:R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"B,L(&9U>GIY
M"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(D%R96$@365T
M87(@=&ED86L@9&ES961I86MA;BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(G1A;7!I
M;&MA;B!P97)B961A86XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`B=&5T87`B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B
M=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,#4*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z,C8Y"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M(@IM<V=S='(@(DME=&EK('-A;F1I(&1U82!K86QI('5N='5K
M(&UE;F=K;VYF:7)M87-I(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B;65N>6%T=6MA;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B;F%M82(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(R,PHC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B
M2&%P=7,@<&EL:6AA;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B
M2V%R86MT97(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T
M<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P;R]R;U]23RYP;P``````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V,3$U,C$@,3`U,34T,S0Q-#(@
M,#$W-3,V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",@2&]R9&4@4F]M86YI86X@=')A;G-L871I;VXN"B,@0V]P>7)I9VAT
M("A#*2`R,#`R($AO<F1E(%!R;VIE8W0N"B,@0V]R;F5L:74@3553050@/&-M
M=7-A=$!K97ES>7,N<F\^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB
M4')O:F5C="U)9"U697)S:6]N.B!(3U)$12`R+C%<;B(*(E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I
M;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO
M;BU$871E.B`R,#`R+3`X+3`Q(#`Y.C,T*S`R.C`P7&XB"B),87-T+51R86YS
M;&%T;W(Z($-O<FYE;&EU($U54T%4(#QC;75S871`:V5Y<WES+G)O/EQN(@HB
M3&%N9W5A9V4M5&5A;3H@4D]-04Y)04X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G
M/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!N=2!E<W1E
M(&-O;F9I9W5R870@:6X@2&]R9&4@4F5G:7-T<GDB"@HC.B!F<F%M97=O<FLO
M5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL
M('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T
M:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B)7,@3W!E<F%T:75N:2!D92!M96YT96YA;G1A("T@0V]N9FER;6%R
M92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N(@IM<V=S='(@(D)I9F%T:2!O<&5R871I=6XH96$O:6QE*2!P92!C
M87)E(&1O<FET:2!S82!L92!F86-E=&D@86-U;2XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&ES
M(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM
M<V=S='(@(DQA(&9I96-A<F4@-2!M:6YU=&4B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B6VQI;FEA("5S(&1I;B`E<UTB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS9W-T<B`B
M06=E;F1A(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B0V%L96YD87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M
M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O
M9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S
M=&EN9R`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B
M,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN
M92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B26YF;W)M871I:2!D97-P<F4@=&EN
M92(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H
M;W5R<R(*;7-G<W1R("(R-"!D92!O<F4B"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C
M:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*;7-G
M:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB/D$@
M87!A<G5T(&\@97)O87)E(&9A=&%L83H\+V(^(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS
M9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P
M=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@
M(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@
M(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I
M9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D
M(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI
M960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%T:6D@9&5S<')E('1I;F4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U
M;G0@4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O
M=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R(")!9')E
M<V$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP
M.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")!9')E<V$B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM
M<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P
M86ER(@IM<V=S='(@(D%D875G82!P97)E8VAE82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B06=E;F1A
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X
M"B,L(&9U>GIY"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S
M='(@(D%G96YD82(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"B,L(&9U>GIY"FUS
M9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9&%U9V$@<&5R96-H96$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM
M<V=S='(@(D%D<F5S82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,SD*(RP@9G5Z>GD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9V5N
M9&$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R(")!9')E<V$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L:6%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R
M(")!;&EA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`B06QI87,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!
M;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*
M;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T
M871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L
M=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O
M<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM
M<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@
M(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%D<F5S82!T82!D
M92!%;6%I;#HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(E,M82!S<&5C:69I8V%T(&\@=F%L;V%R92!I;F-O<F5C
M=&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F
M=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS
M9W-T<B`B/&(^02!A<&%R=70@;R!E<F]A<F4@9F%T86QA.CPO8CXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!
M;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U
M9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS
M9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC
M871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T
M92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S
M+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S
M(#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@
M(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U
M9W5S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS
M9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM
M<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@
M<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM
M87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U
M=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E
M9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@
M<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F
M:65L9',Z(@IM<V=S='(@(D-I;7!U<FD@9&ES<&]N:6)I;&4Z(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@
M(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E
M;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*
M;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(EII=6$@9&4@;F%S=&5R92(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L
M:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").;W1I9FEC871I
M;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B`M(&1E('1R861U<R(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T
M=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@
M(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")"
M;W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM
M<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(
M97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS
M9W-T<B`B0V]R97-P;VYD96YT82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET
M:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L
M;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K
M:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD
M:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T
M"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B
M0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9&%R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A
M;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@
M;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E
M<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(D-A;&5N9&%R
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")296YU;G1A(&QA(%)A<&]R
M="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E
M;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU
M;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(T"B,L(&9U>GIY"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D]P=&EU;FDB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ
M,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B5&5L969O;B!-
M;V)I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*
M;7-G<W1R(")496QE9F]N($UO8FEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*(RP@9G5Z>GD*;7-G:60@(D-E
M;&QP:&]N92(*;7-G<W1R(")496QE9F]N($UO8FEL(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I
M8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@(G9#
M87)D("T@9&4@=')A9'5S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D%N=6QE87IA(%-C:&EM8F%R:6QE
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#
M:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@
M861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E
M<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO
M=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT
M(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G
M<W1R(")V0V%R9"`M(&1E('1R861U<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B0VAI;&4B"FUS9W-T<B`B5&ET;'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM
M<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R
M861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP
M:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@
M(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R(").;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B`M
M(&1E('1R861U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R(")#86QE
M;F1A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ
M,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS
M9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@
M(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R
M"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B26YC:&ED92!F97)E87-T
M<F$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@
M(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I
M9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM
M<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM
M86YD(@IM<V=S='(@(D-O;7!A;FEA(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")#;VUP86YI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET
M:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*(RP@9G5Z>GD*;7-G:60@
M(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED
M(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S
M(&]F(%PB)7-<(B(*;7-G<W1R(")#;VYT:6YU='5L(&QU:2`G)7,G("T@9&4@
M=')A9'5S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#
M;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")#;W!Y
M(@IM<V=S='(@(D-O;7!A;FEA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I
M;&5D.B`E<R(*;7-G<W1R(")#:6UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T
M(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@9&4@3$1!4"XB"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T
M;R!L9&%P('-E<G9E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-#$*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@<V5R=F5R(@IM<V=S='(@
M(DYU(&UA('!O="!C;VYE8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYU
M('!O="!D97-C:&ED92!M;V1U;'5L(&1E($UE;G1E;F%N=&$@)7,B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYU
M('!O="!D97-C:&ED92!M;V1U;'5L(&1E($UE;G1E;F%N=&$@)7,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE
M8W1A(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@;G4@97-T92!C;VYF:6=U<F%T(&-O
M<F5S<'5N>F%T;W(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@
M66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S
M879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@
M8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").=2!M82!P;W0@
M8V]N96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*
M;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@
M;F5W(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P
M"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D
M(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T
M(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*
M;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#
M=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT
M(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*
M;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@
M(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N
M="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R
M=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED
M(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX
M+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS
M9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN
M:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z
M96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(D1$(@IM<V=S='(@(EI:(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")::6QN
M:6,B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E
M($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM
M<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@
M(D1A>2(*;7-G<W1R(")::6QN:6,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@
M0V]L=6UN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I
M9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U
M>GIY"FUS9VED(")$969A=6QT(@IM<V=S='(@(DED96YT:71A=&4@26UP;&EC
M:71A(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-S<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B
M571I;&EZ96%Z82!686QO<FD@26UP;&EC:71E(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET
M>2(*;7-G<W1R("))9&5N=&ET871E($EM<&QI8VET82(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!3:&5L
M;"(*;7-G<W1R("))9&5N=&ET871E($EM<&QI8VET82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM
M<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M
M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@
M(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M261E;G1I=&%T92!);7!L:6-I=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E
M('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R:64@<')O8FQE;6$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I97)E(&-O;7!L971A.B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M(")$971A;&EI(&EN<F5G:7-T<F%T92!I;B!,3T<@<&5N=')U(&%D;6EN:7-T
M<F%T;W(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I
M9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!T
M:75N:2!D92!!9FES87)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T(@IM<V=S='(@(D]P=&EU;FD@9&4@069I<V%R92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B3W!T:75N
M:2!D92!!9FES87)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP
M.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`B5&4@<F]G(&YU(&%C8V5S82!D:7)E8W0@;6%I
M;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@
M=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S
M+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M
M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@
M4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*
M;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G
M871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI
M<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED
M(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E
M<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D
M=6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S
M+"!O<B!U<V4@=&AE(&)A<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*
M;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8X"B,L(&9U>GIY"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(D%D<F5S82!T82!D92!%;6%I;#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC
M+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T
M<B`B06QT92!I;F9O<FUA=&EI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E
M=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I8V]N<R(*;7-G
M<W1R(")/<'1I=6YI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S
M86=E+B(*;7-G<W1R(")%;7!T>2!R97-U;'0N("T@9&4@=')A9'5S(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM
M<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")%;7!T>2!R97-U;'0N("T@
M9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET
M>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E
M9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM
M<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G
M:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,C<*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@
M(D5R<F]R(@IM<V=S='(@(D5R;V%R92(*"B,Z(&9R86UE=V]R:R]496UP;&%T
M92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P
M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(D\@9&%T82!L82`Q-2!M
M:6YU=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY
M"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B3&$@9FEE8V%R92`U
M(&UI;G5T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*
M;7-G<W1R(")/(&1A=&$@;&$@,S`@<V5C=6YD92(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I
M9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DQA(&9I96-A<F4@-2!M:6YU
M=&4B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("),82!F:65C87)E($-O
M;F5C=&%R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")/(&1A=&$@;&$@,S`@;6EN=71E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B26X@
M9FEE8V%R92!M:6YU="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B17AE;7!L92!D
M92!V86QO<FDZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M
M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%
M>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3
M:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%
M>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM
M<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D
M(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R
M96YC97,N(@IM<V=S='(@(DYU('!O="!C:71I('!R969E<FEN=&5L92XB"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE
M8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYU(&UA('!O="!C;VYE8W1A
M(&QA('-E<G9E<G5L(&1E($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.CDX"B,L(&9U>GIY"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L
M82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C8Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(").=2!M82!P;W0@8V]N
M96-T82!L82!S97)V97)U;"!D92!,1$%0+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R
M=F5R=6P@9&4@3$1!4"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E
M=')I979E.B`E<R(*;7-G<W1R(").=2!P;W0@8VET:2!P<F5F97)I;G1E;&4N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*
M;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R
M;W(Z(@IM<V=S='(@(D5R;V%R92!D92!I;G1R87)E.B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y
M"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&87@B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B
M<G5A<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*
M;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!
M4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S.`IM<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(D9I;&4B"FUS9W-T<B`B
M5&ET;'4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0HC
M+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYU;64B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX
M(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S$*;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT
M($-O;&]R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-PIM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S
M="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@
M=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED
M(")&;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,C$*;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&
M;W)T=6YE<R(*;7-G<W1R(").;W1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3G5M92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI
M=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY
M;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L
M(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R
M:65R92!C;VUP;&5T83HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA
M;64B"FUS9W-T<B`B3G5M96QE('1A=3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'
M86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B
M1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT
M;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H
M86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S$T(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*(RP@9G5Z>GD*;7-G
M:60@(D=U97-T8F]O:R(*;7-G<W1R(")!9V5N9&$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'
M=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B
M1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W
M"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA
M<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I
M9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE
M87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I
M9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@(DAE;'`B
M"FUS9W-T<B`B2&5L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z
M>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")(96QP(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M
M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$U,S4*(RP@9G5Z>GD*;7-G:60@(DAO;64B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")!
M9')E<V$@9&4@86-A<V$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*
M;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@
M4&AO;F4B"FUS9W-T<B`B5&5L969O;G5L(&1E(&%C87-A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC
M;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E
M<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@
M96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO
M=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@
M4G5L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Q
M"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@
M(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@
M(DAU;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*(RP@9G5Z>GD*;7-G
M:60@(DE0($%D9')E<W,B"FUS9W-T<B`B061R97-A(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H
M:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@
M(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS
M9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM<V=I9"`B261E;G1I
M='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@
M:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@
M82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4U"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ-S,*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E
M(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C
M86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I
M9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN
M9F\N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@
M4W1E<"`E9"(*;7-G<W1R(")#:6UP(&EM<&]R=&%T.B`E<R(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#:6UP(&EM<&]R=&%T.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0VEM<'5R:2!I;7!O<G1A=&4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*;7-G
M:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(E1E(')O9R!I;G1R;V1U('5N(&YU;64@9&4@
M=71I;&EZ871O<B!S:2!O('!A<F]L82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*
M;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U-PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T
M<B`B26YF;W)M871I:2!D97-P<F4@=&EN92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E
M<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T
M($-?;VQU;6X@069T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T
M;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T
M"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*
M;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED
M("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E
M9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE861E
M<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,C$P"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@
M87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B
M871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A
M;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y
M<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG
M(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<S"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN
M=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN
M=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L
M:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C(U"FUS9VED("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L
M>2(*;7-G<W1R(")::6QN:6,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I
M8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`IM
M<V=I9"`B(@HB2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R
M(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E("(*(F1I<W!L87EI
M;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU
M<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+
M96YY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*
M;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")-97-A:B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I
M9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("),:6UB82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(
M86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I
M9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D1E
M8V]N96-T87)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z
M>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(D5X96UP;&4@9&4@=F%L
M;W)I.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*
M;7-G:60@(DQE=F5L(@IM<V=S='(@(DYI8VEO9&%T82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),
M:6=H="!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!2
M86EN(@IM<V=S='(@(D-O;F5C=&%R92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G
M:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!2
M86EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L
M(&9U>GIY"FUS9VED("),:6YK(@IM<V=S='(@(D-O;F5C=&%R92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E
M<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED
M("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R
M("),:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<"(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@(DQI<W0M2&5L<"(*
M;7-G<W1R("),:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@
M(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")#;VYE
M8W1A<F4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G
M:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G
M(&]U="(*;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B0V]N
M96-T87)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PHC+"!F=7IZ
M>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B4V%R8VEN:2(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@HC+"!F=7IZ>0IM<V=I9"`B3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4')O8FQE;6$@
M8W4@0V]N96-T87)E82X@4')O8F%B:6P@;G5M96QE(&1E(%5T:6QI>F%T;W(@
M<V%U+W-I(%!A<F]L82!S:6YT("(*(F=R97-I=&4N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3DR"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z
M>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")$96-O;F5C=&%R92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R
M(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W
M97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),
M;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DQ,(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R(")#;W)E<W!O;F1E
M;G1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-
M86EL(@IM<V=S='(@(D-O<F5S<&]N9&5N=&$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DUA;&%W:2(*;7-G<W1R(")#;W)E
M<W!O;F1E;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R
M(")#;W)E<W!O;F1E;G1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED
M(")-86QT82(*;7-G<W1R(")#;W)E<W!O;F1E;G1A(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS
M9VED(")-87)G:6XB"FUS9W-T<B`B071E;G1I92(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@
M4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O
M=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@
M(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")#:6UP=7)I('!O=')I=FET92`M
M(&1E('1R861U<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM
M<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I
M;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R(").;W1E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-97-A:B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED
M("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I
M9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER
M960N(@IM<V=S='(@(DUE<V%J(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM
M<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DUE<V%J(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A;&EI(&EN<F5G:7-T<F%T
M92!I;B!,3T<@<&5N=')U(&%D;6EN:7-T<F%T;W(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#
M+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO
M9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G<W1R(")#;W)E
M<W!O;F1E;G1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H
M;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R
M"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,T"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B17)O87)E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE
M;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA
M9V4@2%144%]297%U97-T+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN
M(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U
M<V4@=&AI<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED
M(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C<T"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B
M36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S
M"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-
M;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S
M='(@(DQU;F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY
M($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM
M<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V92!,969T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q
M-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@(DUO=F4@57`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C,*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ
M=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%T:6D@9&5S<')E('1I;F4B
M"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C4T"FUS9VED(")->2!0
M;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP
M.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/
M+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").=6UE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE
M=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V
M97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS
M9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(DYI8VEO9&%T82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D
M;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I
M;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HQ,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@
M=&\@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI
M8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO
M;F%L*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L
M86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS-PHC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z
M>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]T92(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@
M(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS
M9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`B26YA<&]I(&QA(&]P=&EU;FDB"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R(").:6-I;V1A=&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-C,*
M;7-G:60@(DYO(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I
M;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#4*
M;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I
M;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA
M=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(T
M-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-C<*;7-G
M:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYU(&5S=&4@8V]N
M9FEG=7)A=&$@875T96YT:69I8V%R96$@4U%,(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T
M<B`B06YU;&5A>F$@4V-H:6UB87)I;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(DYU(&5S=&4@8V]N
M9FEG=7)A=&$@0V%T96=O<FEA(%-13"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#(T"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B
M3G4@<VEN="!C;VYF:6=U<F%T92!0<F5F97)I;G1E;&4@3$1!4"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"B,L(&9U>GIY"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U<F%T82!#871E9V]R:6$@
M4U%,(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PHC
M+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B3G4@97-T92!C
M;VYF:6=U<F%T82!#871E9V]R:6$@4U%,(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D
M:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N
M('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T
M<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q"FUS9VED(").;R!I
M8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E
M="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V.0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS
M9VED(").;R!N=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T
M=6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N
M<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I;6%P+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A
M;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DYU(&5S=&4@8V]N9FEG=7)A=&$@875T96YT:69I8V%R96$@4U%,(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3G4@97-T92!C;VYF:6=U<F%T82!A=71E;G1I
M9FEC87)E82!344PB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.#0*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYU(&5S=&4@8V]N9FEG=7)A
M=&$@875T96YT:69I8V%R96$@4U%,(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/
M<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES
M(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV
M"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F\@<75O=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED
M(").;R!R=6QE<R(*;7-G<W1R(").;W1E(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#0Y"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*
M;7-G<W1R(").;W1E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@
M9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L
M(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="XB"FUS9W-T<B`B5&4@<F]G(&EN=')O9'4@=6X@;G5M92!D92!U=&EL:7IA
M=&]R('-I(&\@<&%R;VQA(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A(')E='5R;F5D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-S$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDX,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3DR"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,#`Y"FUS9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*
M;7-G:60@(DYO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S
M92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H
M<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM
M<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I
M9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*
M(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F]T92(*"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S
M(@IM<V=S='(@(DYO=&4B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP
M:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-0HC+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3FEC:6]D
M871A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ
M>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYU;64B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T"FUS
M9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(V
M"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W
M;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S
M(&%L;&]W960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED
M(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B
M3W!T:75N:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3W!T:75N:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R
M960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-PIM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED
M(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I
M;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D%L=&4@:6YF;W)M871I:2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM
M<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I
M9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@
M(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*
M;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B
M4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I
M9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E!A<F]L82(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G
M:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<F]L82(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#H@
M(@IM<V=S='(@(E!A<F]L82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM
M<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP
M8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3
M:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*(RP@9G5Z>GD*;7-G:60@(E!E;W!L92(*;7-G<W1R(")2;VQE("T@9&4@
M=')A9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")%>&5C=71A
M($]P97)A=&EU;FEL92!D92!-96YT96YA;G1A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0P-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")%>&5C=71A($]P
M97)A=&EU;FEL92!D92!-96YT96YA;G1A(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*;7-G:60@
M(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*
M(RP@9G5Z>GD*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D%L=&4@:6YF;W)M871I:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@
M(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P
M:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I9"`B4&AO
M=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@
M=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW
M"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN(@IM<V=S='(@(E1E(')O9R!S<&5C:69I8V$@=6X@<W5M87(@86P@<')O
M8FQE;65I+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B5&4@<F]G
M(&EN=')O9'4@=6X@;G5M92!D92!U=&EL:7IA=&]R('-I(&\@<&%R;VQA(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O
M;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B
M4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S
M="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E
M9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM
M<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G
M:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R
M979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO
M;G,B"FUS9W-T<B`B26YA<&]I(&QA(&]P=&EU;FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D
M;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B6U)A<&]R="!0<F]B;&5M85TB"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)I97)E82!P<F]B;&5M96DB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8T-`IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@
M(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM
M<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")2
M96%D(&UE<W-A9V5S(@IM<V=S='(@(DUE<V%J(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5F
M<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B4F5I;7!R;W-P871E87IA(%-U
M;6%R=6P@+2!D92!T<F%D=7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA
M=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T
M"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M"B,L(&9U>GIY"FUS9VED(")296UO=F4B"FUS9W-T<B`B4W1E<F=E('!E<F5C
M:&5A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U
M>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4W1E<F=E('!E<F5C
M:&5A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R(")3=&5R9V4@<&5R
M96-H96$B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I
M9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D
M('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H92(*
M;7-G<W1R(")3=&5R9V4@<&5R96-H96$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B
M4W1E<F=E('!E<F5C:&5A(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B=U:60G(&YE<W!E8VEF:6-A="!I;B!C;VYF:6=U<F%T:6$@9&4@
M<')E9F5R:6YT92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W
M-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)W5I9"<@;F5S<&5C:69I8V%T(&EN
M(&-O;F9I9W5R871I82!D92!P<F5F97)I;G1E+B(*"B,Z(&9R86UE=V]R:R]5
M=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B)W5I9"<@;F5S<&5C:69I8V%T(&EN(&-O;F9I9W5R871I
M82!D92!P<F5F97)I;G1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"B,L(&9U
M>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@
M66]U<B!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N
M<R(*;7-G<W1R("));F%P;VD@;&$@;W!T:75N:2(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I
M;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@HC
M+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S
M='(@(DEN87!O:2!L82!O<'1I=6YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)O;&4@+2!D92!T<F%D
M=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*
M;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,@IM<V=I9"`B4F]T871E($QE
M9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*
M;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G
M<W1R(")2;VQE("T@9&4@=')A9'5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3
M+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@
M365S<V%G:6YG(@IM<V=S='(@(DUE<V%J(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C(Q"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I
M9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@
M2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@
M2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")386QV87IA($]P
M=&EU;FDB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3
M879E($]P=&EO;G,B"FUS9W-T<B`B4V%L=F%Z82!/<'1I=6YI(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G
M:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@T"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(D9O
M<FUA='5L(&1E(&%F:7-A<F4@82!D871E:3HB"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@861D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*
M;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E
M<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM
M<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B1F]R;6%T=6P@9&4@869I<V%R92!A
M(&1A=&5I.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82XB"FUS9W-T<B`B(@HB06QE9V4@8V%R86-T97)E;&4@9&4@8V%R92!A
M:2!N979O:64@9&EN(&-A<W5T96QE(&1E(&UA:2!J;W,N(%9E:2!P=71E82!A
M<&]I("(*(G-A(&QE(&-O<&EE>FD@:6X@>F]N82!D92!T97AT+B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.B(*;7-G<W1R(")$96QI;6ET871O<B!D92!D871A.B(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")&;W)M871U;"!D92!A9FES87)E
M(&$@9&%T96DZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R(")$96QI;6ET871O<B!D92!D871A.B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@
M9F]R;6%T.B(*;7-G<W1R(")&;W)M871U;"!D92!A9FES87)E(&$@;W)E:3HB
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L96-T96%Z82!D
M;W5A(&-I;7!U<FD@<&]T<FEV:71E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B
M4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE
M8W1E87IA(&QI;6)A('!R969E<F%T83HB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*
M;7-G<W1R(")4<FEM:71E(%)A<&]R="!D92!%<F]A<F4B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N
M9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I
M9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM
M<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@
M(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")386QV
M87IA($]P=&EU;FDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T
M"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,34*;7-G:60@(E-E
M="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F
M<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.#0*(RP@9G5Z>GD*;7-G:60@(E-E="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T
M<B`B06QE9V4@=&EM<'5L(&1E(')E:6UP<F]S<&%T87)E(&$@<&%G:6YI:2!S
M:2!A;'1E(&]P=&EU;FD@9&4@869I<V%R92XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R(")!;&5G
M92!T:6UP=6P@9&4@<F5I;7!R;W-P871A<F4@82!P86=I;FEI('-I(&%L=&4@
M;W!T:75N:2!D92!A9FES87)E+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E
M('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B4W5M
M87(@<V-U<G0Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G
M:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H
M;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")3
M87)I('!E<W1E($UE;G1E;F%N=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V
M96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3
M;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE
M;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E
M<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ>0IM<V=I
M9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B061R97-A(&QA(%-E<G9I8VEU
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%
M=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3
M<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U
M="(*;7-G<W1R(")#87)A8W1E<F4@4W!E8VEA;&4@+BXN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"B,L(&9U
M>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")#86QE;F1A<B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U
M"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("));F9O
M<FUA=&EI(&1E<W!R92!T:6YE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S82!L82!397)V:6-I=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R
M;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@
M6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S(&YO="!F;W5N9"X@+2!D92!T<F%D
M=7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I
M9"`B4W5C8V5S<R(*;7-G<W1R(")3=6-C97,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L
M;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N
M9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G
M:60@(E-U;6UA<GDB"FUS9W-T<B`B4W5M87)U;"!-974B"@HC.B!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U
M;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P
M<&]R="(*;7-G<W1R("));7!O<G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY
M"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")5=&EL:7IA=&]R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G
M:60@(E-U<FYA;64B"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T
M960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM
M<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C
M:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I
M86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@
M(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L
M(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")4:71L=2(*"B,Z(&9R
M86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")4
M86)L92(*;7-G<W1R(")4:71L=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")4
M86EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X
M-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B4V%R8VEN:2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP
M"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G
M:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")4
M97AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z
M>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B06D@9F]S="!D96-O;F5C=&%T+CQB<B`O/DUU;'1U;65S8R!C82!F
M;VQO<V5S=&D@<VES=&5M=6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX,C`*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z
M,3(Y,@IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L
M:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O
M=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A
M<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@
M:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C
M:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38X(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Q.0IM<V=I9"`B5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H
M92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O
M<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A
M<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T
M;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.CDP"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!I9&5N=&ET>2!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS
M9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T
M(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB
M5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E
M;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G
M:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS
M9W-T<B`B06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU;65R:6-A
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM
M<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD(&YO="!B92!S879E
M9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92`B"B)M87AI;75M(&%L
M;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H
M)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@
M<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E
M;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@
M9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO
M=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E
M;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S
M:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC
M92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S
M=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@
M8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-38*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO
M8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@
M(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3G4@
M97AI<W1A('!R969E<FEN=&4@9&ES<&]N:6)I;&4N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S
M7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I
M;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@
M(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#`*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A
M=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D
M(&9I96QD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@
M9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I9"`B
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@
M82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(D%C
M96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I92!N=6UE<FEC82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@
M(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U
M:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM
M<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS
M9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A
M<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY.#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B06-E87-T82!V
M86QO87)E('1R96)U:64@<V$@9FEE(&YU;65R:6-A+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+
M;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO
M=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N
M9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@
M<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N
M(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB
M"FUS9W-T<B`B5F%L;V%R96$@;6EN:6UA(&5S=&4@,2(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D%C96%S=&$@=F%L;V%R92!T<F5B=6EE('-A(&9I92!N=6UE
M<FEC82XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U
M"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P
M=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*
M;7-G:60@(E1I;64B"FUS9W-T<B`B5&ET;'4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M
M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S
M.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO
M:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET;'4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS
M9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W
M"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G
M:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@
M(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I
M9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5
M9V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT
M,3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@
M4U%,+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-@IM
M<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R(").=2!M82!P;W0@8V]N96-T82!L82!S
M97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P
M,38*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7,O)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BXB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R
M=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS
M9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(").
M=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").=2!M82!P;W0@8V]N
M96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$R-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R
M=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T
M92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O;F5C=&$@
M;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").
M=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U;"!344PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@
M(DYU('!O="!I;G)E9VES=')A('!R969E<FEN=&5L92!I;B!S97-I=6YE("T@
M9&4@=')A9'5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E
M=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N
M<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN
M:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O
M;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HX,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3G4@;6$@<&]T(&-O
M;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3G4@;6$@<&]T
M(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF
M:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS
M.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3G4@
M;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R=6P@4U%,+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT
M-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@
M(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5
M;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R
M(").=2!P;W0@=')A9'5C92!A8V5S="!D;V-U;65N="!7;W)D("T@9&4@=')A
M9'5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q
M=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5;F1E
M<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D%N=6QE87IA(%-C:&EM
M8F%R:6QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y
M,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C
M;VYN96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I
M9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(Y(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B
M56YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G
M:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@
M(E5N:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM
M<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")5=&EL:7IA
M=&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E
M8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@
M;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT
M96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS
M9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@
M)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHW-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C@S"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@
M(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED
M(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED
M(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B
M"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR
M-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")/<'1I=6YI(%5T:6QI
M>F%T;W(B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5<V5R
M(%)E9VES=')A=&EO;B(*;7-G<W1R(")/<'1I=6YI(%5T:6QI>F%T;W(B"@HC
M.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@
M8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@
M;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G
M:60@(E5S97)N86UE(@IM<V=S='(@(E5T:6QI>F%T;W(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"B,L(&9U>GIY
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S
M97)N86UE.B`B"FUS9W-T<B`B571I;&EZ871O<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T
M96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E
M;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS
M9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@
M86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R(")!=&5N=&EE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")7
M96%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E
M9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX
M.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E-A<'1A;6EN86PB"@HC
M.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I
M9"`B5V5L8V]M92(*;7-G<W1R(")":6YE(&%I('9E;FET+"`E<R(*"B,Z('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S
M(@IM<V=S='(@(D)I;F4@86D@=F5N:70@:6X@<VES=&5M=6P@)7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B
M"FUS9W-T<B`B0FEN92!A:2!V96YI="P@)7,B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B
M5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@
M:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H
M97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U
M;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W
M"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P
M"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM
M<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@
M(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED
M(")7;W)K($%D9')E<W,B"FUS9W-T<B`B061R97-A(&QA(%-E<G9I8VEU(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N(&QA(%-E<G9I8VEU
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S
M:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T
M<B`B04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`B04$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I
M9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T
M<B`B06YU86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E
M871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@
M=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R
M(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R
M(")/<'1I=6YI;&4@874@9F]S="!S86QV871E+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A
M;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E
M(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF
M:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+B(*;7-G<W1R(")4<F5B=6EE('-A(&1E<V-R:6D@<')O8FQE
M;6$@:6YA:6YT92!D92!A('1R:6UI=&4@<F%P;W)T=6PN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P
M"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO
M;B!T;R!P97)F;W)M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@
M='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM
M<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(E-E<VEU;F5A
M('1A(&1E("5S(&$@97AP:7)A="X@5&4@<F]G('-A(&9A8VD@3&]G($EN(&1I
M;B!N;W4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")!
M9')E<V$@=&$@9&4@16UA:6PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q,@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S.B(*;7-G
M<W1R(")!9')E<V$@=&$@9&4@16UA:6PZ(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS
M9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%T:6D@9&5S
M<')E('1I;F4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S
M='(@(DYU;65L92!T874Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@
M>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A
M<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA
M<R!B965N(&-H86YG960N(@IM<V=S='(@(D]P=&EU;FEL92!A=2!F;W-T('-A
M;'9A=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ
M>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R("))9&5N
M=&ET871E($EM<&QI8VET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,#$*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(").
M=6UE;&4@=&%U.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S
M='(@(D]P=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R
M871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")/<'1I=6YI;&4@874@
M9F]S="!S86QV871E+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N
M(@IM<V=S='(@(D]P=&EU;FEL92!A=2!F;W-T('-A;'9A=&4N(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V
M"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U)A
M<&]R="!0<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@
M(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");;&EN:6$@)7,@9&EN("5S72(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@
M9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(DAE;'`B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G
M:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@
M(E],;V<@:6XB"FUS9W-T<B`B0V]N96-T87)E(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B1&5C;VYE8W1A<F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I
M9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G
M<W1R(")/<'1I=6YI(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B4W1E<F=E('!E<F5C:&5A(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I
M9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(D%G96YD82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B0V%L
M96YD87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34X
M"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED
M(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM
M<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M
M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B"FUS
M9W-T<B`B5&ET;'4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R
M(").=6UE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B
M;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE
M;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P
M97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B<FES
M:6YG(@IM<V=S='(@(D%T96YT:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY"FUS9VED
M(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R
M96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*
M;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V
M-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@9G5Z>GD*;7-G:60@(G1R
M>2!A9V%I;B(*;7-G<W1R("),82!F:65C87)E($-O;F5C=&%R92(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I
M<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B
M=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0@+2!D92!T
M<F%D=7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<VM?4TLN<&\`````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-S`P,#<P(#$P
M-3$U-#,T,30R(#`Q-S4R-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C($AO<F1E(%-L;W9A:R!T<F%N<VQA=&EO;BX*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#(@3&5O($UR869K;R`\;&5O0&]E;"YS:SX@*&]R
M:6=I;F%L('1R86YS;&%T;W(I"B,@*$,I(#(P,#(L(#(P,#,@279A;B!.;W)I
M<R`\=FEX0'9A>FMA+G-K/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!(;W)D92`S+C%<;B(*(E)E<&]R="U-<V=I9"U"=6=S
M+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T
M93H@,C`P-BTP,2TP-B`Q-#HQ,"LP,3`P7&XB"B)03RU2979I<VEO;BU$871E
M.B`R,#`V+3`Q+3,P(#(Q.C(V*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@
M279A;B!.;W)I<R`\=FEX0'9A>FMA+G-K/EQN(@HB3&%N9W5A9V4M5&5A;3H@
M4VQO=F%K(#QV:7A`=F%Z:V$N<VL^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN
M(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y
M+3)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*'!R960@)7,@9/)A;6DI(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$MLX79E<V]VX2!S:W)A=&MA("5S
M*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AO("5S(&1N[2DB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-PIM<V=I9"`B("AT;V1A>2DB"FUS
M9W-T<B`B*&1N97,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-SD*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H>F%J=')A*2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B("AVZ&5R82DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R
M("(@<OUC:&QO<[L@(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G
M<W1R(")<(B5S7"(@;FEE(&IE(&%D<F5SX7(N(@H*(SH@;&EB+TAO<F1E+T-,
M22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B!N:64@:F4@<&QA=&[A
M('9OM6)A+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z-C4R(&QI8B](
M;W)D92]296=I<W1R>2YP:'`Z,3`T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+B(*;7-G<W1R(")<(B5S7"(@;FEE(&IE(&YA:V]N9FEG=7)O=F%NZ2!V(')E
M9VES=')I($AO<F1E+B(*"B,Z(&QI8B](;W)D92]4<F5E+G!H<#HQ-S$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")Z;V)R87IO=F'H('-T<F]M=2!<(B5S7"(@;F5B;VP@
M;N%J9&5N_2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN(@IM<V=S='(@(E-K=7!I;F$@7"(E<UPB(&)O;&$@<')I9&%NX2!D;R!S
M>7-TZ6UU+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(E!RX79O(%PB)7-<(B!B;VQO('!R
M:61A;ND@9&\@<WES=.EM=2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB
M(&YE8F]L;R!M;[YNZ2!V>71V;W)INSH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(E!O=;YI=/UC
M:"`E+C)F34(@>B!D;W9O;&5N_6-H("4N,F9-0B`H)2XR9B4E*2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&$@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO
M=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@9&[M(&1O('9Y<'*Y
M86YI82!P;&%T;F]S=&D@5N&Y:&\@:&5S;&$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD
M87D@9F]R96-A<W0B"FUS9W-T<B`B<')E9'!O=F7O(&YA("5D(&1N[2(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(%!O>F[A;6MA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B3V1T;&'H;VL@)7,B"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0P(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E
M<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R(")/<&5RX6-I92#Z9'*^
M8GD@<')E(&%P;&EKX6-I=2`E<R`M(%!O='9R9&5N:64B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B3F%S=&%V
M96YI92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B4F5G:7-T
M<F]V86YI92!D;R!A<&QI:^%C:64@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@
M06=R965M96YT(@IM<V=S='(@(E!O9&UI96YK>2!P;W6^:71I82`E<R(*"B,Z
M(&QI8B]61E,O<VUB+G!H<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O
M5D93+V9T<"YP:'`Z-C<Q"B,Z(&QI8B]61E,O9G1P+G!H<#HW,SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S
M('6^(&5X:7-T=6IE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S
M='(@(B5S('9O(';]N6ME("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y
M('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME
M9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS
M*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B
M(@HB07!L:6OA8VEA("5S(&IE('!R:7!R879E;N$@;F$@=GEK;VYA;FEE(&]P
M97+A8VGM(/ID<KYB>2Y/>FYAZ'1E(+ET=F]RZ&5K('!R:2`B"B)O<&5RX6-I
MX6-H+"!K=&]RZ2!C:&-E=&4@=GEK;VYANR!T97)A>BXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C,T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R
M97%U:7)E9"(*;7-G<W1R(")0;[YA9'5J92!S82`E<R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T
M97,B"FUS9W-T<B`B)7,@;6EN^G0B"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F
M;W5N9"XB"FUS9W-T<B`B)7,@;F5B;VP@;N%J9&5N_2XB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5S(&&^("5S('H@)7,B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<^%R('!O=;[M=F%T9;5A
M("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F3A<B!P;W6^
M[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")0;WINX6UK
M>2!P;W6^[79A=&6U82`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B
M6F]Z;F%M(/IL;V@@<&]UONUV871EM6$@)7,B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I
M="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@5.%T;R!S
M<'+A=F$@;F5M=7/M(&)YNR!O9"!O9&]S:65L871EM6$L(&MT;W+]('-A('IO
M8G)A>G5J92!A:V\@(@HB;V1O<VEE;&%T9;4@<W!RX79Y+B!:86-H;W9A:G1E
M(&]P871R;F]SNR!P<FD@:VQI:V%N[2!N82!L:6YK>2!V('-P<N%V92!A;&5B
M;R`B"B)P;W-K>71O=F%N[2!O<V]B;OUC:"!I;F9O<FWA8VGM(&]D;W-I96QA
M=&6U;W9I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T
M:6YG("(*;7-G<W1R("(L(&[A<F%Z;W;]("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@X(&QI8B]";&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(L('8@;N%R87IO
M8V@@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T
M<B`B+"!P<F5M96YNX2!V(')O>G-A:'4@)7,@8;X@)7,B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$S,B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0U
M"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=GEB97)T92!S:2`M
M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`B,3(M:&]D:6YO=OT@9F]R;>%T(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M("(R-"UH;V1I;F]V_2!F;W)MX70B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@:&]D[6XB"@HC
M.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B
M"FUS9W-T<B`B/%!R961C:.%D>F%J^F-A(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B4')E('1E;G1O(&)L;VL@:F4@
M<&^^861O=F%N_2!D871A8N%Z;W;](&)A8VME;F0N(@H*(SH@;&EB+TAO<F1E
M+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM
M<V=S='(@(E9Y<VMY=&QA('-A('KA=F&^;N$@8VAY8F$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(DYA
M('IAN6EF<F]V86YI92!S<'+A=GD@:F4@<&^^861O=F%N_2!V97)E:F[](%!(
M4"!KM?KH+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(DYA(&]V97)E;FEE('!O9'#M<V%N
M96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!01U`@:[7ZZ"XB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@HB3F$@9&6Y:69R;W9A;FEE('-P<N%V>2!S^B!P;W1R96)NZ3H@=F5R
M96IN_2!01U`@:[7ZZ"P@<')I=N%T;GD@4$=0(&NU^N@@82`B"B)H97-L;RXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T
M<B`B(@HB3F$@<&]D<.US86YI92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=G)E
M:F[](%!'4"!KM?KH+"!P<FEVX71N>2!01U`@:[7ZZ"!A("(*(FAE<VQO+B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB3F$@9&6Y:69R;W9A;FEE('-P<N%V>2!S^B!P;[YA
M9&]V86[I.B!V97)E:F[](%,O34E-12!KM?KH+"!P<FEVX71N>2!3+TU)344@
M(@HB:[7ZZ"!A(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB3F$@<&]D<.US86YI92!S
M<'+A=GD@<_H@<&^^861O=F%NZ3H@=F5R96IN_2!3+TU)344@:[7ZZ"P@<')I
M=N%T;GD@4R]-24U%("(*(FNU^N@@82!H97-L;RXB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(").
M82!Z8;EI9G)O=F%N:64@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!3
M34E-12!KM?KH+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")0<F5D<&]L=61N
M[6T@;V)L8>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(E!R961P
M;VQU9&[M;2"U86AK_2!DX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B4')E
M9'!O;'5D;NUM(&3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")0<F5D
M<&]L=61N[6T@<')E:.%N:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(E!R961P;VQU9&[M;2!S;F5H;W;I('!R96CA;FMY(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@(C$R
M(&AO9.UN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U
M="!T:&ES(&5D:71O<B(*;7-G<W1R(")/('1O;71O(&5D:71O<F4B"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS
M9W-T<B`B3RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")!8G-O;/IT
M;GD@<W!O9&]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(D%B<V]L^G1N
M>2!S=')E9"(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")0
M<FD@=GET=N%R86[M(%9&4R!A9')E<^%R82!B;VP@>F%M:65T;G5T_2!P<NUS
M='5P+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S
M(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B4')I('9Y=';A
M<F%N[2!61E,@<_IB;W)U(&)O;"!Z86UI971N=73]('!R[7-T=7`N(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`B26YF;W)MX6-I92!O(/KH=&4B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`B2&5S;&\@<')E(/KH970B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S
M='(@(MKH970@>F%B;&]K;W9A;OTN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("+:Z'1O=F%N
M:64B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")0<FED8;LB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM
M<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(E!R:61ANR!P;V1R:6%D
M96[Z('-K=7!I;G4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.CDX(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M
M:7-S:6]N(@IM<V=S='(@(E!R:61ANR!P;V1R:6%D96[I('!RX79O(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*
M;7-G<W1R(")0<FED8;LZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M
M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T
M<B`B4')I9&&[('-K=7!I;G4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C@W(&QI8B](;W)D92]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@
M4&5R;6ES<VEO;B(*;7-G<W1R(")0<FED8;L@;F]VZ2!P<N%V;R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S
M='(@(E!R:61ANR!D8^ER<VMU('-K=7!I;G4@9&\@7"(E<UPB(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B4')I
M9&&[(&1CZ7)S:V4@<'+A=F\@9&\@7"(E<UPB(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")0<FED8;L@
M<&]UONUV871EM6$Z(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4U,PIM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")0<FED8;L@
M<W3E<&5C(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS
M-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(E!R:61ANR#H;&5N
M;W8B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!
M9&0@<&%I<B(*;7-G<W1R(")0<FED8;L@<.%R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B4')I9&&[(&UE
M;G4@)7,@86MO($)OZ&[]('!A;F5L($UO>FEL;'DB"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R(")0<FED8;L@9&\@861R97/A<F$Z(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O
M(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R(")0<FED8;L@9&\@;?1J:&\@861R
M97/A<F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B
M"FUS9W-T<B`B4')I9&&[('!O=;[M=F%T9;5A(@H*(SH@861M:6XO=7-E<BYP
M:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB7"(E<UPB(&)O
M;"!P<FED86[](&1O('-Y<W3I;74L(&%L92!N96UOOFYO('!R:61ANR#O86RY
M:64@<')I:&QA<V]V86-I92`B"B)I;F9O<FWA8VEE.B`E<RXB"@HC.B!S:6=N
M=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(EPB
M)7-<(B!B;VP@<')I9&%N_2!D;R!S>7-TZ6UU+B!497)A>B!S82!M]+YE=&4@
M<')I:&SA<VF[+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(E!R:63A=F%N:64@<&]UONUV871EM6]V(&IE('IA:^%Z86[I+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O
M:R(*;7-G<W1R(")!9')E<^%R(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I
M;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES='+A8VEA("T@
M;F%S=&%V96YI92!P<N%V('!R92!I;OUC:"!P;W6^[79A=&6U;W8B"@HC.B!A
M9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R
MX6-I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@
M(D%D<R(*;7-G<W1R(")296ML86UY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B069G86YI<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB
MX6YS:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%LONUR<VMO(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L
M:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS9W-T
M<B`B6F%R;W9N8;LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(EIA<F]V
M;F%N:64Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED(")!
M;&PB"FUS9W-T<B`B5KEE=&MY(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B5KEE=&-I(&%U=&5N=&EF
M:6MO=F%N[2!P;W6^[79A=&5L:6$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(E:Y971K>2!S:W5P:6YY(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!
M;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5KEE=&MY('!RX79A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM
M<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5KEE=&MY(+ET>7)I('-T
M<F%N>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<U"FUS9VED(")!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&]V;VQINR!V:6%C97+I
M(&%D<F5S>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@
M(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@
M(E!O=F]L:;L@;F%S=&%V96YI92!T>7!U('IO<F%D96[I:&\@>F]Z;F%M=3\B
M"@HC.B!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(E6^(&5X:7-T=6IE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G
M:6XB"FUS9W-T<B`B06QT97)N873M=FYE('!R:6AL87-O=F%C:64@;65N;R!)
M35-0(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT
M97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N873M=FYE(&AE
M<VQO($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED
M(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=.UV
M;F4@<&]UONUV871EM7-KZ2!M96YO($E-4U`B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E
M<W,B"FUS9W-T<B`B06QT97)N873M=FYA(&4M;6%I;&]VX2!A9')E<V$B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E
M;7!L871E<R(*;7-G<W1R(")!;'1E<FYA=.UV;F4@N6%B;/-N>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T
M[79N>2!T97AT.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M
M97)I8VOA(%-A;6]A(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HY-2!L
M:6(O2&]R9&4O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")";VQA('IA9&%NX2!N97!L
M871NX2!H;V1N;W1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS
M9W-T<B`B3F%S=&%L82!N97INX6UA(&-H>6)A+B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B
M"FUS9W-T<B`B06YD;W)R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O
M;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R
M;WAY(@IM<V=S='(@(D%N;VYY;6[I('!R;WAY(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")/9'!O
M=F7O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")!;G1A<FMT:6MA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM
M<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&$@
M0F%R8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP
M<VAE;&PN<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC
M871I;VXB"FUS9W-T<B`B07!L:6OA8VEA(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(EIO
M>FYA;2!A<&QI:^%C:>TB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P
M"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B07!L:6OA
M8VEA(&IE('!R:7!R879E;N$N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R
M(")!<&QI:V]V8;L@;F$@<&]D<FEA9&5NZ2!Z9&EEM6%NZ2!P<FEEZ&EN:WDB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I
M9"`B07!P<F]V92(*;7-G<W1R(")38VAVX6QINR(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O>&EM871E(%-I>F4B
M"FUS9W-T<B`B4')I8FQIOF[A('9EM6MO<[LB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B07!R[6PB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W,0IM<V=I9"`B07)A8FEC("A7
M:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C4Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED
M(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")69;5K;W.[(&%R8VCM=G4B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R
M9&4O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@
M(DUE;F\@87)C:.UV=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S
M=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(#\B"FUS9W-T<B`B3F%O>F%J(&-H8V5T92!V>6UA>F&[(+YI861O<[L@
M;R!P<FEH;.%S96YI92`G)7,G/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R
M;W5P<S\B"FUS9W-T<B`B3F%O>F%J(&-H8V5T92!V>6UA>F&[(%PB)7-<(B!A
M(':Y971K>2!P;V1S:W5P:6YY/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M(")!<F=E;G3M;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;>EN<VMO
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S(*;7-G:60@(D%R;65N:6%N
M("A!4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(E5M96YI92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R
M=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(D]S=')O=B!!
M<V-E;G-I;VXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R(")!<V-I:2!U;65N:64B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO
M;B(*;7-G<W1R("+!>FEA+U!A8VEF:6-K_2!R96=I\VXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO
M;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T
M<B`B5GF^861O=F&[('!O='9R9&5N:64@<')E9"!V>6MO;F%N[6T@;W!E<N%C
M:>T@^F1ROF)Y/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`R"FUS9VED
M(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@9W)O=7`N(@IM<V=S='(@(E!O:W5S(&\@=GEM87IA;FEE(&YE97AI
M<W1U:OIC96H@<VMU<&EN>2XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T
M=6KZ8V5H;R!P<N%V82XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM
M<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(E!O:W5S(&\@^G!R879U(&YE97AI<W1U:OIC96AO('!R
MX79A+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R
M(")0;VMU<R!O(/IP<F%V=2!N965X:7-T=6KZ8V5H;R!Z9&EEM6%NZ6AO(&]B
M:F5K='4N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`B071R:6+Z='DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%U9W5S="(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U
M<W1R86QI82(*;7-G<W1R(")!=7-T<N%L:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM
M<V=S='(@(E)A:_IS:V\B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP
M.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(%!OOF%D;W9A
M;ND@<F]ZN>UR96YI92!I;6%P(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](
M;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A
M8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS
M9W-T<B`B075T:%]C>7)U<SH@8F%C:V5N9"!N96WA('!OOF%D;W9A;ND@<V-H
M;W!N;W-T:2XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3(R"FUS
M9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z('!OOF%D;W9A;ND@<F]ZN>UR
M96YI92!I;6%P(&YE8F]L;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]!=71H
M+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z('!O
MOF%D;W9A;ND@<F]ZN>UR96YI92!&5%`@;F5B;VQO(&[A:F1E;NDN(%-K;VUP
M:6QU:G1E(%!(4"!S("(*(G!R97#M;F'H;VT@+2UE;F%B;&4M9G1P+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z
M(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]I;6%P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@24U!4"!N96)O;&\@
M;N%J9&5NZ2XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I
M9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@<&^^861O=F%NZ2!R;WJY[7)E;FEE
M(&MR8C4@;F5B;VQO(&[A:F1E;NDN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*
M(D%U=&A?;&1A<#H@<')I9.%V86YI92!P;W6^[79A=&6U;W8@;FEE(&IE('!O
M9'!O<F]V86[I('!R92!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB
M"FUS9W-T<B`B(@HB075T:%]L9&%P.B!V>6UA>N%V86YI92!P;W6^[79A=&6U
M;W8@;FEE(&IE('!O9'!O<F]V86[I('!R92!!8W1I=F4@1&ER96-T;W)Y(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VQD87`Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!,1$%0(&YE8F]L
M;R!NX6ID96[I+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(D%U=&A?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED8;L@<&]UONUV871E
MM6$@)7,N(%-E<G9E<B!O9'!O=F5D86PZ("(*"B,Z(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z
M(&YE<&]D87)I;&\@<V$@;V1S='+A;FF[('!O=;[M=F%T9;5A("5S(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#H@;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<&]U
MONUV871EM6$@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT,#4*
M;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T:%]L
M9&%P.B!A:W1U86QI>N%C:6$@<&]UONUV871EM6]V(&YI92!J92!P;V1P;W)O
M=F%NX2!P<F4@06-T:79E($1I<F5C=&]R>2(*"B,Z(&QI8B](;W)D92]!=71H
M+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!P;[YA
M9&]V86[I(')O>KGM<F5N:64@34-!3"!N96)O;&\@;N%J9&5NZ2XB"@HC.B!L
M:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]S;6)A=71H.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<VUB875T
M:"!N96)O;&\@;N%J9&5NZ2XB"@HC.B!L:6(O2&]R9&4O24U!4"]!9&UI;BYP
M:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(D%U=&5N=&EF:6OA8VEA('!O;6]C;W4@24U!4"!S
M97)V97)A('IL>6AA;&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G
M<W1R(")!=71E;G1I9FEKX6-I82!Z;'EH86QA(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B075T96YT:69I:^%C:6$@>FQY:&%L
M82X@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B4V5R=F5R(%)!1$E54R!Z86UI971O;"!A=71E;G1I9FEKX6-I
M=2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z.#<Q"FUS9VED(")!=71H96YT:6-A
M=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B075T96YT:69I
M:^%C:6$@<&]M;V-O=2!&5%`@<V5R=F5R82!Z;'EH86QA+B(*"B,Z(&QI8B]6
M1E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--
M0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I9FEKX6-I82!P;VUO
M8V]U(%--0B!S97)V97)A('IL>6AA;&$N(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T
M<B`B1&]S='5P;ND@<&]L;[YK>3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S
M='(@(D%Z97)B86IDOF%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P
M"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!%>&-U<V5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")0;WIA9&EE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I
M9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")&87)B82!P;WIA9&EA(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B
M97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B6FSI(&AE<VQO('!R92!K97)B97)O
M<RXB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D
M(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("):;.D@<&]UONUV871EM7-K
MZ2!M96YO('!R92!K97)B97)O<RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@
M(D)A:&%M>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%J;B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<S"FUS9VED(")"86QT:6,@*$E33RTX
M.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@
M(D)A;F=L863IN2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A<F)A9&]S
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(E!R:67H:6YO:R!S(&=R869I:V]U(%PB)7-<(B!N96)O
M;"!NX6ID96[]+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B6N%K
M;&%D;OT@<FEA9&]K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")":65L;W)U
M<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6-K;R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R
M(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D>2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)H=71A;B(*;7-G<W1R(")"=73A;B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R
M(").87)O9&5N:6YY(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN
M<&AP.C,U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@
M87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO:R!<
M(B5S7"(@87!L:6OA8VEE(%PB)7-<(B!N96)O;"!NX6ID96[]+B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@4V5T
M=&EN9W,B"FUS9W-T<B`B3F%S=&%V96YI82!B;&]K=2(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G
M<W1R(")4>7`@8FQO:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B5'7H;NDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")";VQI=FEA(@IM<V=S='(@(D)O;.UV:6$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B
M6N%L;[YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")/:W)A:B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*
M;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(JGM<FMA(&]K<F%J
M83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(D]K<F%J92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G
M:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;F$@82!(
M97)C96=O=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I
M9"`B0F]T:"(*;7-G<W1R(")/8F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R
M(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)O='1O
M;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T($ES;&%N
M9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z[6QI82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B0G)I='-K
MZ2#Z>F5M:64@=B!);F1I8VMO;2!O8V7A;F4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R
M=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M;&=A<FEA(@IM<V=S='(@(D)U;&AA<G-K;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI
M<W0B"FUS9W-T<B`B6F]Z;F%M(',@;V1RX;YK86UI(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HS.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB
M"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-2
M0R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")$:7-T<FEB=>ANZ2!B
M;V1Y($-23"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")6;&%S=&YO<W1I(%]B=6YK>2XN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N(@IM<V=S='(@(DEN8VEA;&EZX6-I82!V>7)O=F[A=F%C
M96H@<&%MY'1I(&YE8F]L82!D;VMO;NAE;N$N(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X,B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@
M(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9.%R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")"97IV
M971R:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]DOF$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#86UE<F]O;B(*;7-G<W1R(")+86UE<G5N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(DYE<&]D87)I;&\@<V$@875T;VUA=&EC:WD@;V)N
M;W9INR!H97-L;RP@:V]N=&%K='5J=&4@<W9O:FAO(&%D;6EN:7-T<N%T;W)A
M+B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!Z87#M<V&[(&1O('/Z8F]R=2!<(B5S7"(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B3F5M;[YN;R!A9&UI
M:7-T<F]V8;L@97AT97)NZ2!O=FSA9&'H92!S961E;NTN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C(S-2!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('-P;VII
MNR!S($E-05`@<V5R=F5R;VTZ("5S(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[('/Z8F]R(%PB)7-<
M(BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B6G)UN6F[(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0
M<F]B;&5M(%)E<&]R="(*;7-G<W1R("):<G6Y:;L@<W!RX79U(&\@<')O8FSI
M;64B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@=GEM87IANR!S^F)O<B!<(B5S7"(N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R
M"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@;N%J<[L@9&_H87-N_2!A9')E<^%R+B(*
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R
M(").96UOOFYO('!O:W)AZ&]V8;L@8F5Z('!A<F%M971R82`G=&%R9V5T1FEL
M92<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(DYE<&]D87)I;&\@<V$@;V1S='+A;FF[(&%D<F5SX7(@7"(E<UPB+B(*"B,Z
M(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X(&QI8B](;W)D92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B3F5M;[YN;R!O9'-T
M<N%N:;LL(&5X:7-T=6IE("5D(&YA<VQE9&]V;NUK;W8N(@H*(SH@;&EB+TAO
M<F1E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O
M<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@
M9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB
M3F5M;[YN;R!P<F5U<W!O<FEA9&&[+"!P;^AE="!P;VQOOFEE:R!P<F4@<')E
M=7-P;W)I861A;FEE(&YE<_IH;&%S[2!S('!OZ'1O;2`B"B)U;&^^96[]8V@@
M<&]L;[YI96LN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE
M9"!N=6UB97(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<VUE<F]V8;L@<W!R
MX79U(&YA('5RZ&5NZ2#H[7-L;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S
M='(@(DMA<'9E<F1S:^D@;W-T<F]V>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB
M"FUS9W-T<B`B5&ET=6QO:R(*"B,Z(&QI8B].970O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B
M96QS(@IM<V=S='(@(DMA=&5G\W)I92!A('!O<&ES:WDB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y
M;6%N($ES;&%N9',B"FUS9W-T<B`B2V%J;6%N<VOI(&]S=')O=GDB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R(")-;V)I;&[]('1E;&5F\VXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED
M(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!B=6YK>2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T
M"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(E9Y<&QN96YI92!B=6YK
M>3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B5FQA
M<W1N;W-T:2!B=6YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@
M(E)O>F]S='5P(&)U;FEE:SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(W
M.`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL;OT@=&5L96;S;B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")#96QT:6,@*$E3
M3RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS
M9W-T<B`B1&\@<W1R961U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(E-T<F5D;V%F<FEC:^$@<F5P=6)L:6MA(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D-E;G1R86P@175R;W!E86X@
M*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S
M='(@(E!O9')O8F[I(&EN9F]R;>%C:64@;R!C97)T:69I:^%T92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T
M92!/=VYE<B(*;7-G<W1R(")6;&%S=&[M:R!C97)T:69I:^%T=2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T
M92!0;VQI8VEE<R(*;7-G<W1R(")0;VQI=&EK>2!P<F4@8V5R=&EF:6OA='DB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(D-H860B"FUS9W-T<B`BR&%D(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(EIM96YINR(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@
M4&%S<W=O<F0B"FUS9W-T<B`B6FUE;FF[(%9AN64@:&5S;&\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M
M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@
M86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B).87-T
M879E;FEE(&UE;F$@82!A9')I97,L(&MT;W+I('9I9&EA(+5U9&EA+"!K9>\@
MZ.UT86KZ(&$@;V1P;W9E9&%J^B!N82!68;EE("(*(F4M;6%I;'DN(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N
M9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@
M8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(EIM96YA(&AE<VQA(&YI92!J92!V(&%K
M='7A;&YE:B!K;VYF:6=U<N%C:6D@<&]D<&]R;W9A;N$N("!+;VYT86MT=6IT
M92!S=F]J:&\@(@HB861M:6YI<W1RX71O<F$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA
M<B(*;7-G<W1R("):;F%K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN
M+B(*;7-G<W1R(")37VMO;G1R;VQO=F&[(&QI;FMU+BXN(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("+([6YA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D-H:6YE<V4@
M4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W-PIM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG
M-2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM
M<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R(")6>6)E<G1E(&%P
M;&EKX6-I=3HB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(W,`IM
M<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B6G9OM71E('-I(&AE
M<VQO(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@
M(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(EIV;[5T92!S:2!P;W6^[79A
M=&6U<VOI(&UE;F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`R"FUS
M9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(E9Y
M8F5R=&4@<W#T<V]B('IO8G)A>F]V86YI82!DX71U;6]V.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*
M;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*;7-G<W1R(")6>6)E<G1E('1Y<""Y=/UL=2!Z;WIN86UU("AP<F4@
M>F]R861E;ND@>F]Z;F%M>2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM
M<V=S='(@(E9I86YOZ&[](&]S=')O=B(*"B,Z(&QI8B]61E,N<&AP.CDQ,R!L
M:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")$969I;NUC
M:6$@=')I961Y("5S(&YE8F]L82!NX6ID96[A+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G
M<W1R(")*87-N;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B3V1S='+A;FF[('!R[6MA>GD@35-/9F9I8V4B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")6>6UA
M>F&[(&1O=&%Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM
M<V=S='(@(D]D<W1RX6YINR!P;W6^[79A=&6U83H@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B
M"FUS9W-T<B`B3V1S='+A;FF[('!O=;[M=F%T9;5A(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R(")6>6UA>F&[('!O=;[M=F%T9;5S:^D@^F1A:F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B
M0VQE87)I;F<@3&%T92(*;7-G<W1R(").97-K]'(@=GEJ87-N96YI92(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS
M9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+;&EK;FET92!P<F4@
M<&]K<F'H;W9A;FEE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B
M0VQI8VMA=&5L;"!C97H@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H
M<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO
M<V4@5VEN9&]W(@IM<V=S='(@(EIA='9O<FF[(&]K;F\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM<V=S='(@(D]B;&%K
M>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B4N%N;R!O8FQAZ&YO(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G
M:60@(D-L;W5D>2(*;7-G<W1R(")/8FQAZ&YO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',B"FUS9W-T<B`B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED
M(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(EIB86QINR!";^AN_2!P86YE
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(EIB
M86QE;ND@;VMR86IE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L=6UB
M:6$B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO
M<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B1F%R8F$B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U(&QI8B](;W)D
M92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B5OUB
M97(@9F%R8GDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-0IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")6_6)E<B!F87)B>2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED
M(")#;VQS.B(*;7-G<W1R(")3=.5P8V4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-3`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B3F%D<&ES
M>2!S=.5P8V]V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM
M<V=I9"`B0V]M:6-S(@IM<V=S='(@(DMO;6EK<R(*"B,Z(&%D;6EN+V-M9'-H
M96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")0<NUK87HB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB
M"FUS9W-T<B`B4'+M:V%Z;W;](&EN=&5R<')E=&5R(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO
M;65N=.%R(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G
M:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(D)EOF[I(&UE;F\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M0V]M;W)O<R(*;7-G<W1R(")+;VUO<GDB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")3
M<&]L;^AN;W.[(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED
M(")#;VUP=71E<G,B"FUS9W-T<B`B4&_H[71AZ&4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B4W1A=B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(E-T878B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R(")2;WID:65L>2!V(&MO;F9I9W5RX6-I:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I
M;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T
M<B`B(@HB2V]N9FEG=7+A8VEA('!R92!S>6YC:')O;FEZX6-I=2!S(%!$02P@
M:6YT96QI9V5N=&[];6D@=&5L96;S;FUI(&$@3W5T;&]O:V]M+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(DMO;F9I9W5RX6-I82!P;W1R96)U
M:F4@86MT=6%L:7KA8VEU+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@
M(DMO;F9I9W5R;W9ANR`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B
M4&]T=G+O=&4@:&5S;&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*
M;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B
M"FUS9W-T<B`B1&5M;VMR871I8VOA(')E<'5B;&EK82!+;VYG;R(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960N(@IM<V=S='(@(E-P;VIE;FEE('IL>6AA;&\N(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM
M<V=S='(@(E-P;VIE;FEE('IL>6AA;&\Z("(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+M?KH(&)O;"!Z86UI971N
M=73]('-E<G9E<F]M('9E<F5J;OUC:"!KM?KH;W8N(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I(@IM<V=S='(@(DNU^N@@8F]L('IA;6EE=&YU=/T@<V5R=F5R
M;VT@=F5R96IN_6-H(&NU^NAO=BX@1/1V;V0Z("5S("@E<RDB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z.#8U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R(")3<&]J96YI92!S($944"!S97)V97)O;2!Z
M;'EH86QO+B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED
M(")#;VYT86-T<R(*;7-G<W1R(")+;VYT86MT>2(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(")+;VYT86MT>2!B;VQI(/IS<&6Y;F4@=FQOOF5NX2!D;R!6X;EH;R!A
M9')E<^%R82XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HV
M,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM
M<V=S='(@(E1Y<"!K;VUP<FEM;W9A;NEH;R!S^F)O<G4Z(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB
M(@IM<V=S='(@(D]B<V%H(%PB)7-<(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM
M<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B4&]K<F'H;W9ANR(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R(")#;V]K;W9E(&]S=')O=GDB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#
M;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P[7)O=F&[
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P[7)O=F%N:64@>FQY:&%L
M;SH@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W#M<F]V
M8;L@=OUB97(B"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3<P(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")+;W-T87)I:V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(E!O8G)EOFEE('-L;VYO
M=FEN>2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(").97!O
M9&%R:6QO('-A('IAN6EF<F]V8;L@<W!RX79U('!O;6]C;W4@4$=0.B`B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M<&]D<.US8;L@<W!RX79U('!O;6]C;W4@4$=0.B`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F&Y:69R
M;W9ANR!S<'+A=G4@<&]M;V-O=2!3+TU)344N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG
M;B!M97-S86=E+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!O9'#M<V&[('-P
M<N%V=2!P;VUO8V]U(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<FED
M8;L@:V]N=&%K="X@)7,N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.CDV(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$R,0IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@<')I<&]J:;L@:R!,1$%0('-E<G9E<G4N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@
M<V5R=F5R=2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ
M-38@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@;W9E<FF[('IO<W1A=&]K(&YA(/KH=&4N
M("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F%S=&%L
M82!C:'EB82!P<FD@<'+M<W1U<&4@:R!,1$%0('-E<G9E<G4B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')I<&]J:;L@:R!S97)V97)U(%PB
M)7-<(B!P;VUO8V]U($944#H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@=GET=F]R:;L@>F]Z;F%M('!R[6IE;6-O=BX@)7,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@9&6Y
M:69R;W9ANR!01U`@^F1A:F4Z("(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T
M82XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!D9;EI9G)O=F&[(%,O34E-12#Z
M9&%J92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(&MO;G1A:W0N
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@
M>F]Z;F%M('!R[6IE;6-O=BX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A
M<FEL;R!S82!V>6UA>F&[('-K<FEP="!N82!U<&=R861E(&MO;F9I9W5RX6-I
M92!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#$@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!U<NAINR!E+6UA:6QO=OH@861R97-U('!R
M[6IE;6-U+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<W1I86AN=;L@8V5L_2!A9')E
M<^%R+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z[7-K8;L@:V]M<&QE=&[]
M('IO>FYA;2!P<NUJ96UC;W8N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP
M;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!Z[7-K8;L@:V]M<&QE=&[]('IO>FYA;2!Z;WIN86UO=B!P
M<NUJ96UC;W8N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y+G!H<#HV.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A
M(&YAZ.UT8;L@<W1R873I9VEU(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!S<'5S=&F[(&UK9&ER(%PB)7-<(BXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD
M(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[('9E<F5J;OT@:[7ZZ"!Z;R!S
M97)V97)A(&NU^NAO=BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A(&]T=F]R:;L@7"(E<UPB('!R92!ZX7!I<RXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@;W1V;W)INR`E<RXB"@HC
M.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<R(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@;6]D=6P@36%I
M;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE
M<&]D87)I;&\@<V$@;W1V;W)INR!A9')E<^%R(%PB)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,3$Q(&QI8B](;W)D92]'<F]U<"]L9&%P
M+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(S-R!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HU,38@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-C4V(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S
M97)V97(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')I<&]J:;L@;F$@3$1!
M4"!S97)V97(N(@H*(SH@;&EB+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!P<F7H[71ANR`E<RXB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(DYE<&]D87)I;&\@<V$@;V)N;W9I
MNR!H97-L;R!Z861A;NEH;R!P;W6^[79A=&6U82X@3FEE:W1O<ND@86QE8F\@
M=KEE=&MY("(*(G!O9')O8FYO<W1I(&YI92!S^B!S<'+A=FYE+B!3:_IS=&4@
M=&\@>FYO=G4@86QE8F\@:V]N=&%K='5J=&4@5N&Y:&\@(@HB861M:6YI<W1R
MX71O<F$L(&%K('!O=')E8G5J971E('!O;6]C+B(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U
M;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").96UOOFYO('KM<VMANR!!
M0TPB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS:V&[(&%D<F5S
MX7(N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS
M:V&[('IO>FYA;2!P<NUJ96UC;W8N("5S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R
M(").97!O9&%R:6QO('-A('KM<VMANR!Z;WIN86UY('!R[6IE;6-O=B`E<R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DYE;6^^;F\@>NUS
M:V&[(&EN9F]R;>%C:64@;R!V;&%S=&YO<W1I86-H('-E<G9E<F$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=G+A
M=&F[(&MO;F9I9W5RX6-I=2XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('-P=7-T:;L@<FUD:7(@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M=6QOOFF[(&MO;F9I9W5RX6-I=2`E<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O
M=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!U;&^^:;L@>N%L;VAU(&MO;F9I9W5RX6-I92XB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(").97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A
M8VEE.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=6QO
MOFF[('-K<FEP="!N82!U<&=R861E(&YA<W1A=F5N[2!D;SH@7"(E<UPB+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H
M=2!K;VYF:6=U<N%C:64@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*
M;7-G<W1R("(B"B).97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG=7)AZ&[]
M('/Z8F]R("5S+B!-]+YE=&4@<&]UOFF[(&YI96MT;W+Z('H@(@HB;6^^;F]S
M=.T@;F$@>N%P:7,@:_-D=2!N82`E<R!A;&5B;R!S:V]P[7)O=F&[(')UZ&YE
M(&OS9"!U=F5D96[](&YIOKEI92!D;R`E<RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&BU861ANR!N82!,
M1$%0('-E<G9E<FDN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M=GEM87IANR!<(B5S7"(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@86MT=6%L
M:7IO=F&[(&MO;G1A:W0N("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").97!O9&%R
M:6QO('-A(&%K='5A;&EZ;W9ANR!Z;WIN86T@<'+M:F5M8V]V+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*;7-G<W1R(").97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG=7+A8VEU
M('!R92!<(B5S7"(Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B3F5M;[YN
M;R!NX6ISNR!";^AN_2!P86YE;"!-;WII;&QY+B!3:V]N=')O;'5J=&4L(+YE
M(&IE('!A;F5L(&]T=F]R96[]+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N
M)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(E!O=;[M=F%T9;5O
M=FD@7"(E<UPB('-A(&YE<&]D87)I;&\@<')I9&&[('!RX79A('!R92!P<FEE
MZ&EN;VL@7"(E<UPB.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S
M"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B4&_H[71A;OT@=&5X="(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N
M=')Y(@IM<V=S='(@(DMR86II;F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<GIY(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B5GET=F]R:;LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B5GET=F]R:;L@;&EN
M:W4B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT
M"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(E9Y='9O<FF[(&YO
M=OTB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G
M:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")6>71V;W)INR!P;V1P
M<FEEZ&EN;VLB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(T,`IM<V=I
M9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")0<N%V82!T=F]R8W4B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Q.0IM<V=I9"`B0W)E9&ET(&-A
M<F0@;G5M8F5R(@IM<V=S='(@(LCM<VQO(&MR961I=&YE:B!K87)T>2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")#<F]A=&EA(@IM<V=S='(@(D-H;W)VX71S:V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C8U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A
M(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B06MT=>%L;F4@-"!FX7IY
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E
M<W-I;VYS(@IM<V=S='(@(D%K='7A;&YE('-E9&5N:6$B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U
M<G)E;G0@5&EM92(*;7-G<W1R(")!:W1UX6QN>2#H87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G
M:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D%K='7A;&YA(%523"!J92(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R
M<R(*;7-G<W1R(")!:W1UX6QN:2!P;W6^[79A=&5L:6$B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T
M<B`B06MT=>%L;F4@<&_H87-I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-C0*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T
M<B`B06MT=>%L;F4@<&]D;6EE;FMY.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE
M(@IM<V=S='(@(D%K='7A;&YY(+ET_6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B3F%S=&%V96YI
M92#Z;&]H+"!K=&]RZ2!S82!S</JYNV%J^B!P<FD@<')I:&SA<V5N[2!D;R!A
M<&QI:^%C:64@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B5GES
M=')I:&[ZNR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B5GES=')I
M:&[ZNR!V_6)E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#>7!R=7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*
M;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L
M:6,B"FUS9W-T<B`BR&5S:^$@<F5P=6)L:6MA(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.2!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S(W,`IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*;7-G<W1R("(B"B)$4TX@*'!O>G)I(&AT='`Z+R]P96%R+G!H<"YN
M970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H
M<"DB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")$96YN92(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV
M-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")0<F5Z97)AZ"!D
MX71O=NEH;R!S=')O;74@*$1A=&%4<F5E*2(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C8X"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B5GEH
MM6%DX79A;FEE('8@9&%T86+A>F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0P,B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I
M9"`B1&%T92(*;7-G<W1R(")$X71U;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S
M='(@(D3A='5M('!R:6IA=&EA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W
M.38*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(E;]8F5R(&3A='5M
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@
M(D1E\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B
M3U]D<W1RX6YINR!S=.5P96,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$P(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B1&5C96UB97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5S:6%T
M:V]VZ2#H[7-L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("):
M;65NN6F[(&]D<V%D96YI92(*"B,Z(&QI8B]P<F5F<RYP:'`Z,3$W(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,3@W"FUS9VED(")$969A=6QT(@IM<V=S='(@
M(E!R961N87-T879E;NDB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R
M(")0<F5D;F%S=&%V96[A(&9A<F)A(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y
M+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")68;EA
M('!R961N87-T879E;N$@:61E;G1I=&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4')E9&YA
M<W1A=F5N_2!P<NUK87IO=OT@:6YT97)P<F5T97(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(D1E
M9FEN[6-I92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY."!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T
M92(*;7-G<W1R(")6>6UA>F&[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L
M;"(*;7-G<W1R(")6>6UA>F&[(&)U;FMU(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U
M<"(*;7-G<W1R(")6>6UA>F&[('-K=7!I;G4B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B
M5GEM87IANR!ZX7IN86TB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<W
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R
M;6ES<VEO;B(*;7-G<W1R(")6>6UA>F&[('!RX79O(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U
M<F=E(&UE<W-A9V5S(@IM<V=S='(@(E9Y;6%Z8;L@82!O9'-T<N%N:;L@<W!R
MX79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B5GEM87IA
MNR!B=6YK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B
M5GEM87IANR!S=.5P96,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM
M<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R(")6>6UA>F&[(&5X:7-T=6KZ8W4@86QT97)N873M=FYU(+EA8FSS;G4B
M"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")6>6UA>F&[('!RX79A('!R92!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B
M"FUS9W-T<B`B0VAC971E('9Y;6%Z8;L@7"(E<UPB(&$@=KEE=&MY(&IE:&\@
M<&]D<'+A=F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")6
M>6UA>F&[(')I861O:R(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N
M=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*
M;7-G<W1R(")6>6UA>F&[('9Y8G)A;OH@:61E;G1I='4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G
M:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B5GEM87IA
MNR!A:W1UX6QN>2!S=.5P96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!R;W<B"FUS9W-T<B`B5GEM87IANR!A:W1UX6QN>2!R:6%D;VLB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M"FUS9W-T<B`B4VMR:7!T(&YA('5P9W)A9&4@:V]N9FEG=7+A8VEE(%PB)7-<
M(B!B;VP@=GEM87IA;OTN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R
M>2!T:6UE(@IM<V=S='(@(LAA<R!D;W)UZ&5N:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K
M(@IM<V=S='(@(D3A;G-K;R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R
M(")0;W#MN71E('!R;V)LZ6TB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.30R
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(E!O<&ES(@H*(SH@;&EB
M+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3HB"FUS9W-T<B`B4&]D<F]B;F]S=&D@*'1I9;X@=B!L;V=O
M=F%C;VT@<_IB;W)E($AO<F1E*2(*"B,Z(&QI8B](;W)D92YP:'`Z,C`Q"FUS
M9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R(")$971A:6QY(&)O;&D@>F%Z;F%M96YA;ND@<')E
M(&%D;6EN:7-T<N%T;W)A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(E;]=F]J(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R(")2;W-N_2!B;V0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM
M<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")2;W-N
M_2!B;V0@>F$@<&]S;&5D;OH@:&]D:6YU.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R
M(")2;W-N_2!B;V0Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT
M(@IM<V=S='(@(E-M97(@>K5A=F$@9&]P<F%V82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO
M;B!R:6=H="!T;R!L969T(@IM<V=S='(@(E-M97(@<W!R879A(&1OM6%V82(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B061R97/A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B6F]B
M<F%Z;W9ANR#H87,@=B`R-"UH;V1I;F]V;VT@9F]R;>%T93\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B
M"FUS9W-T<B`B3F%S=&%V96YI92!Z;V)R87IE;FEA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T(@IM<V=S='(@(EIO8G)A>FF[('!O9')O8F[Z('!R961P;W9E
M[R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@
M9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B6F]B<F%Z:;L@<')E9'!O=F7O("A4
M048I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#8*;7-G:60@(D1I<W!L
M87D@9F]R;6%T(@IM<V=S='(@(D9O<FWA="!Z;V)R87IE;FEA(@H*(SH@;&EB
M+TAO<F1E+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B(*;7-G<W1R(")0;W1V<F1E;FEE(&\@9&]R=>AE;NTB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$:FEB;W5T:2(*;7-G<W1R(")$OFEB=71S:V\B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R(").979Y;6%Z8;LB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP(@IM<V=S='(@(DYE<&]UONUV86IT92!P<FEA;6\@;6%I;G1E;F%N8V4N
M<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#HB"FUS9W-T<B`B3V)S86AU:F4@<')V_2!R:6%D;VL@;N%Z=GD@
M<&]L[3\@06L@X6YO+"!Z8;EK<G1N:71E('!O;.WH:V\Z("(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O
M;6EN:6-A(@IM<V=S='(@(D1O;6EN:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E
M<'5B;&EC(@IM<V=S='(@(D1O;6EN:6OA;G-K82!R97!U8FQI:V$B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(DYE;>%T92#ZZ&5T/R!:
M87)E9VES=')U:G1E('-A+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(E-T:6%H;G6[(@H*
M(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")3=&EA:&YUNR`E<R(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S
M='(@(E-T:6%H;G6[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@86MO(%!(
M4"!S:W)I<'0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G:60@
M(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(EIO>FYA;2!S(';]8F5R;VTB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S
M='(@(D1R;V=Y(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@;&EB+TYE="]335,O
M9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W
M87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E
M<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D52
M4B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16MVX61O<B(*"B,Z(&QI8B](
M;W)D92]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS
M9VED(")%9&ET(@IM<V=S='(@(E5P<F%V:;LB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G
M:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B57!R879INR!B;&]K(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@
M(D5D:70@1W)O=7`B"FUS9W-T<B`B57!R879INR!S:W5P:6YU(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HW-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C$P,`IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(E5P<F%V:;L@
M<'+A=F\B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E5P<F%V:;L@<'+A=F$B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5P<F%V
M:;L@<'+A=F$@<')E("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B57!R879INR!N
M87-T879E;FEA('!R93HB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(B"FUS9W-T<B`B57!R879INR!P<N%V82!P<F4@7"(E<UPB(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")5<')A=FF[
M('!RX79A('!R92`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM
M<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(E9Z9&5LX79A;FEE(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16=Y<'0B"FUS9W-T<B`B16=Y<'0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM
M<V=S='(@(E-A;';A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM
M<V=S='(@(D5L96UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B16UA:6PB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T
M<B`B16UA:6QO=N$@861R97-A.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.38W"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T
M<B`B12UM86EL;W;I(&%D<F5S>2!M=7-I82!B>;L@<F]V;F%KZ2XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF
M:7)M871I;VXB"FUS9W-T<B`B12UM86EL(',@<&]T=G)D96[M;2(*"B,Z(&QI
M8B].970O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(D)RX6YA($5M86EL+6YA+5--4R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR.3<*;7-G:60@
M(D5M;W1I8V]N<R(*;7-G<W1R(")%;6]T:6MO;GDB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I9"`B16UP='D@;65S<V%G
M92XB"FUS9W-T<B`B4'+A>F1N82!S<'+A=F$N(@H*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C(T,R!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#@T
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV-C(@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C<P-0HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ
M-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4'+A>F1N>2!V_7-L
M961O:RXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G
M:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")0<N%Z9&YE('!O9&UI
M96YK>2!HM6%D86YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#<*
M;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@
M1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(E!O=F]L:;L@=FQOOF5N:64@
M;V)RX7IK;W8@>B!'86SI<FGM(&1O('1E>'1U/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT
M97AT(&UE;G4_(@IM<V=S='(@(E!O=F]L:;L@:V]N=&5X=&]VZ2!M96YU('!R
M92!P<F%VZ2!T;&'H:61L;S\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4Y
M,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P,`IM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B2V]N:65C(')O:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G
M<W1R("):=N3HN6F[(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"B):861A:G1E(&)E>G!EZ&YO<W1N^B!O=.%Z
M:W4L(&YA(&MT;W+Z(&)U9&5T92!M=7-I9;L@;V1P;W9E9&&[(&%K('IA8G5D
M;F5T92`B"B)H97-L;RP@;F%P<BX@)V%K;R!S82!V;VSA(&UO:F4@>G9I97)A
M=&MO/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),
M(&AE<F4B"FUS9W-T<B`B6F%D86IT92!54DP@;V)RX7IK82(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.#D*;7-G:60@(D5N=&5R
M('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("):861A:G1E('#M<VUE;N$@
M=79E9&5NZ2!N:;ZY:64Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDY
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS
M9W-T<B`B4F]V;NUK;W;A($=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B17)I=')E82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#@@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@HC.B!S97)V:6-E<R]P;W)T
M86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")#:'EB82(*
M"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")#:'EB
M82!P<FD@=GET=N%R86[M(&)L;VMU.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")#:'EB82!P<FD@=GEM
M87KA=F%N[2!U:V]T=F5N:6$@<WEN8VAR;VYI>N%C:64Z("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(D-H>6)A
M('!R:2!V>6UA>N%V86[M('KA>FYA;74@<WEN8VAR;VYI>N%C:64Z("5S(@H*
M(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")#:'EB
M82!P<FD@>NUS:V%V86[M(&]B<V%H=3H@)7,B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D-H>6)A('!R:2!A:W1U
M86QI>N%C:6D@:&5S;&$Z("5S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92XB"FUS9W-T<B`B0VAY8F$@=B!E+6UA:6QO=F5J('-P<N%V92XB"@HC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ
M-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N
M(@IM<V=S='(@(D-H>6)A('!R:2!Z87!I<V]V86[M(%PB)7-<(BXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%<W1O;FEA(@IM<V=S='(@(D5S=/-N<VMO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B
M"FUS9W-T<B`B171I\W!I82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(D5T;FEC:^DB"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U
M<O-P82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V
M97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B2V&^9/UC:"`Q-2!M:6[Z="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN
M=71E<R(*;7-G<W1R(")+8;YDZ2`R(&UI;OIT>2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I
M9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")+8;YD_6-H(#,P('-E:_IN
M9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@
M(DMAOF3]8V@@-2!M:6[Z="(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP
M:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(E!R:2!K8;YD;VT@
M<')I:&SA<V5N[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G
M:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+8;YD^B!P;VQH;V1I;G4B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+8;YD
M^B!M:6[Z='4B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM
M<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(DYA<'+M:VQA9#HB"@HC
M.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`B4W!U<W1INR(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0W
M-0IM<V=I9"`B17AP86YD(@IM<V=S='(@(E)O>F)A;&F[(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B
M87(B"FUS9W-T<B`B4F]Z8F%L:;L@0F_H;OT@<&%N96PB"@HC.B!L:6(O2&]R
M9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*
M;7-G<W1R(")/Z&%KX79A('-A("<I)R(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")/Z&%KX79A('-A('-L;W9O(&%L
M96)O('!O9&UI96YK82!HM6%D86YI82!V(/IV;V1Z;W9KX6-H(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A
M=&4B"FUS9W-T<B`B1.%T=6T@97AP:7+A8VEE(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5X
M<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1F%R8F$@
M=&5X='4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(DYA:')ANR!K;VYF:6=U<N%C
M:74@;F$@1E10(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS
M9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!Z[7-K8;L@;F%S=&%V96YI82XB"@HC.B!L:6(O2&]R
M9&4O1W)O=7`O;&1A<"YP:'`Z-S4@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(").87-T86QA(&-H>6)A('!R:2!S<&]J96[M(',@3$1!4"!S97)V
M97)O;2XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.CDX"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(").87-T
M86QA(&-H>6)A('!R:2!P<NUS='5P92!K(%--0B!S97)V97)U+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@
M:V]P[7)O=F&[('H@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&MO<.UR;W9ANR!D;R!<(B5S7"(N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*;7-G:60@(D9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!V>71V;W)INR!N;W;I(%-!4TP@<W!O:F5N:64N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C4P,2!L:6(O5D93+V9T<"YP:'`Z-S0T"B,L('!H
M<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!D;R!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>NUS
M:V&[.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(D1O8G+I(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L
M:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD<VOI
M(&]S=')O=GD@*$UA;';M;GDI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G
M<W1R(")&865R<VOI(&]S=')O=GDB"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR
M,S@*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("):X79AOF[A(&-H>6)A
M.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS
M9VED(")&87@B"FUS9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U,0IM<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X>2(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*
M;7-G<W1R(")&96)R=>%R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*
M;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B4&]C:70@=&5P;&]T>2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS
M(&QI:V4Z("(*;7-G<W1R(")0;V-I="!T97!L;W1Y.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H
M;W=E<G,B"FUS9W-T<B`B36%LZ2!Z<N&^:WDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")-86SI('-N96AO=ND@<')E:.%N:WDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3DT.`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S
M='(@(DUA=&EC82!P;VSM(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,C,*
M;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HS,S(W"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")&:6II(@IM<V=S='(@(D9I9+YI(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM<V=S='(@(E/Z8F]R
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R(")0;^AE="!S^F)O<F]V.B`E<R!S^F)O
M<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@
M0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(E!OZ&5T('/Z8F]R;W8Z("5S('/Z
M8F]R;W8B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED
M(")&:6QE($UA;F%G97(B"FUS9W-T<B`B4W!RX79C82!S^F)O<F]V(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")-96YO('/Z
M8F]R=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3@T"FUS9VED(")&:6QE
M('-E;&5C=&EO;B(*;7-G<W1R(")6_6)E<B!S^F)O<G4B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30Y,`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B
M3F%H<F%T:64@<_IB;W)U(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X
M-0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(DYA:'+A=F%N:64@<_IB;W)O=B!N:64@:F4@<&]D<&]R;W9A;NDN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM
M<V=S='(@(D9I;'1R92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1NUN<VMO
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L
M9B(*;7-G<W1R(")0<G;A('!O;&]V:6-A(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R(")0<G;A(+ET=G*[(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S
M='(@(E!E=F[]('!O;65R(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,`IM<V=I9"`B1FQI<"(*;7-G<W1R(")/=&_H:;LB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")0;.%V86KZ8VD@=&5X="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED
M(")&;V<B"FUS9W-T<B`B2&UL82(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR,S<@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O
M;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R(")0<FEEZ&EN;VL@)7,@
M;F5E>&ES='5J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B1F%R8F$@
M<.US;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O
M;V0B"FUS9W-T<B`B4&]T<F%V82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R
M;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B4')E
M('!R96AL:6%D8>AE+"!K=&]RZ2!N97!O9'!O<G5J^B!O8G+A>FMY(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@(D9O<F5C87-T("A4048I
M(@IM<V=S='(@(E!R961P;W9E[R`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)0<F5D<&]V9>\@;F$@
M=79E9&5N_2!P;^AE="!D;NT@*'!A;>1T86IT92!N82!T;RP@OF4@<')E9'!O
M=F7O(&IE('!R92!D;FD@86H@(@HB;F]C:2!A('1A:R!M]+YE('9EM6OI(.CM
M<VQO('9Y='9O<FF[('9EM6UI(+EI<F]K_2!B;&]K*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`B6F%B=61L:2!S=&4@:&5S;&\_(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
M1F]R;75LX7)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(D9O<G1U;F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")4>7`@
M9F]R='5N>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B
M1F]R='5N97,B"FUS9W-T<B`B1F]R='5N>2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")&;W)T=6YY
M(#(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&
M;W)U;7,B"FUS9W-T<B`B1O-R82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E!R97-M97)O=F%N
M:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R(")0:6$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M
M97,B"FUS9W-T<B`B4N%M8V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A
M;F/Z>G-K;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R(")&<F%N8_IZ<VMO("A%
M=7+S<&$I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDQ(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N8_IZ
M<VMA($=U87EA;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R
M(")&<F%N8_IZ<VMA(%!O;'ENZ7II82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YC^GIS:V4@:G6^;ND@=&5R
M:73S<FGA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B3V0B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I
M9"`B1G)O;2!T:&4@(@IM<V=S='(@(EIO('-M97)U("(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T
M:6]N(@IM<V=S='(@(MIP;&[]('!O<&ES(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O
M;B(*;7-G<W1R(")3<&QN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U
M;&P@3F%M92(*;7-G<W1R(")#96SI(&UE;F\Z(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS
M9W-T<B`B1V%B=6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;.ER:6$L('H@:W1O<F5J(&-H8V5T
M92!V>FEANR!O8G+A>F]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*
M;7-G<W1R(")'86SI<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB
M:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M1V5N97)O=F&[(&MO;F9I9W5RX6-I=2!P<F4@87!L:6OA8VEU("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E
M;F5R871E9"!#;V1E(@IM<V=S='(@(D=E;F5R;W9A;OT@:_-D(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M1V5O<F=I82(*;7-G<W1R(")'96]R9VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G
M<W1R(").96UE8VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=.%R(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS
M9W-T<B`B2W)S=&[I(&UE;F\B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B3V1O<VQANR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E
M;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X
M"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@36%P<R(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B2+5A9&&[(&YA($=O;V=L92(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S8*;7-G:60@(D=R87ES8V%L92(*
M;7-G<W1R(")/9'1I96YE(+EE9&5J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R
M(")'<NEC:V\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R(")'<O-N<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'
M<F5N861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<N%C:6$@<VMU<.UN
M(@H*(SH@;&EB+TAO<F1E+T=R;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE
M;7!T>2(*;7-G<W1R(")-96[A('-K=7#M;B!N97-M^B!B>;L@<'+A>F1N92(*
M"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D=R;W5P
M7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('-K=7!I;G4@)7,N(%-E<G9E
M<B!O9'!O=F5D86PZ("(*"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ
M,3@@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O
M=7!?;&1A<#H@;F5P;V1A<FEL;R!S82!V>6UA>F&[('-K=7!I;G4@)7,B"@HC
M.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S,X(&QI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L
M9&%P.B!N97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!S:W5P:6YU("5S(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G
M:60@(D=R;W5P<R(*;7-G<W1R(")3:W5P:6YY(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P
M92(*;7-G<W1R(")'=6%D96QO=7!E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B
M1W5A;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!RX79A(&%N;VYY;6[]8V@@<&]UONUV
M871EM6]V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,@IM<V=I
M9"`B1W5E<W1B;V]K(@IM<V=S='(@(D=U97-T8F]O:R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE
M82(*;7-G<W1R(")'=6EN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B1W5I;F5A+4)I<W-A=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@
M(D=U>6%N82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C0*;7-G:60@(DA4
M34PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*
M;7-G<W1R(")(5$U,07)E82!N961O=F]L[2!V>6UA>F&[('!O<VQE9&[Z(&)U
M;FMU('8@<FEA9&MU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P;W-L961N_2!S
M=.5P96,@=B!T86)UM6ME+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P;W-L961N_2!R
M:6%D;VL@=B!T86)UM6ME+B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP
M.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DA45%`@875T96YT:69I:^%C:6$@;F5B;VQA(&[A:F1E;N$N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B06QG;W)I=&UU<R!H87-H;W9A8V5J(&9U;FMC:64B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*
M;7-G<W1R(")/<&%R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDR,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,CDR,0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(DAL
M879IZ&MA(@H*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B2&QA=FGH:WDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@
M(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(
M96%R9&]V(&]S=')O=B!A($UC1&]N86QD;W9E(&]S=')O=GDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R(")3:6QNX2!B^G)K82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@R"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(E;]N6MA
M(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP
M:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(E!O;6]C
M;NUK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B4&]M;V-N
M[6L@<')E('!O=;[M=F%N:64@961I=&]R82(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S<U"FUS9VED(")(96QP97(B"FUS9W-T<B`B4&]M;V-N[6LB"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS
M9W-T<B`B4&]L;V=UM6$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R
M92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")4=2!J
M92!Z8>AI871O:R!S^F)O<G4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B5GES;VOA
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A
M9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R
M(")$;U]M;W8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T
M871E*2(*;7-G<W1R(")6871I:^%N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-3,Y
M"FUS9VED(")(;VUE(@IM<V=S='(@(D1O;6]V(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")$
M;VWA8V$@861R97-A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS
M9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$;VWA8VD@<')I9>AI;F]K
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L96;S;B!D;VUO=B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I
M9"`B2&]N9'5R87,B"FUS9W-T<B`B2&]N9'5R87,B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@=B!S<'+A=F4@
M)7,@8F]L:2!NX6ID96[I(&YE<&QA=&[I("5S(%A-3"#Z9&%J92(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@<R!O8FIE:W1O;2`E<R!N96MO<F6Y
M<&]N9'5J92"^:6%D;F$@<W!RX79A+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!V('-P<N%V92`E<R!N96)O;"!NX6ID96[](+YI861E
M;B!O8FIE:W0@='EP=2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B#Z
M<W!EN6YE(&]D<W1RX6YE;ND@)7,@7"(E<UPB(@H*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I
M;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!I;G1E9W+A8VEA('9YOF%D=6IE(%!(
M4"!R;WJY[7)E;FEE("=D;VUX;6PG(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@=GET=F]R:;L@;F]V_2!8
M34P@<W1R;VT@<')E(&]B:F5K="`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3(T,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!N97!O9&%R:6QO('-A(&]D<W1RX6YINR`E<R!<(B5S7"(Z("5S(@H*
M(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N
M97!O9&%R:6QO('-A('KM<VMANR!-24U%($E$('!R92#H87.[('1Y<'4@)7,B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A
M('-Y;F-H<F]N:7IO=F&[("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$S,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!N97!O9&%R:6QO('-A('-Y;F-H<F]N:7IO=F&[('ID
M:66U86[I(&]B:F5K='DZ("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HS
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N97INX6UY('ID
M:66U86[](&]B:F5K="!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B
M"FUS9W-T<B`B2&]R:7IO;G3A;&YA(.AI87)A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A
M;"!P861D:6YG(@IM<V=S='(@(DAO<FEZ;VYTX6QN92!V>7!L;F5N:64B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N=.%L;F4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*2(*;7-G<W1R(")!:V\@<W1E('-A('-E;2!D;W-T86QI/R`H4')O<^UM
M(&YA:&SA<W1E(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+;[5K;R!S=.5P8V]V
M(&-H8V5T92!Z;/KH:;L_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R("):861A:G1E('!OZ&5T('!O;.T@*'-TY7!C;W8I/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(DMOM6MO(')I861K;W8@8VAC971E('IL^NAINS\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")6;&AK
M;W.[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM<V=I
M9"`B2'5M:61I='DZ("(*;7-G<W1R(")6;&AK;W.[.B`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(
M=6UO<FES=&DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B36'O87)S:V\B
M"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@=GET=F]R:;L@24U!4"!S8VARX6YK=3H@)7,B"@HC.B!L:6(O2&]R
M9&4O075T:"]C>7)U<RYP:'`Z,C$T(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP
M:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IA
MNR!)34%0('-C:'+A;FMU.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!)34%0
M(&MV\W1U.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S(P"FUS9VED
M("))4"!!9&1R97-S(@IM<V=S='(@(DE0(&%D<F5S82(*"B,Z(&QI8B](;W)D
M92]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(DE0(&%D<F5S82!N:64@:F4@9&]S='5P;N$N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(DE0(&%D<F5S82!N:64@:F4@=B!RX6UC:2!D;W9O;&5NZ6AO($-)1%(@
M8FQO:W4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B4&]R
M=;EE;FEE('!R879I9&QA(&\@<&5V;F5J($E0(&%D<F5S92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")6;&^^:;L@:[7Z
MZ"!?<')E9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY
M(@IM<V=S='(@(DEB82!I:V]N>2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T
M<B`B26MO;GD@<')E("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X
M,0IM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEK;VYY(&$@=&5X
M="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT
M:71Y)W,@;F%M93HB"FUS9W-T<B`B3N%Z;W8@:61E;G1I='DZ(@H*(SH@;&EB
M+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(D%K('-A(&YE>F]B
M<F%Z[2!K;W)E:W1N92P@)7,@82!O='9O<NT@<V$@=B!N;W9O;2!O:VYE+B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO
M=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R
M+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O
M9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB06L@;F5V:63M=&4@
M<')I('!O=;YI=.T@26YT97)N970@17AP;&]R97)A(+YI861N92!I:V]N>2P@
M<&]T<F5B=6IE=&4@(@HB>F&Y:W)T;OJ[('3Z=&\@=F^U8G4@<')E('9Y<&YU
M=&EE('!R:65S=FET;F]S=&D@4$Y'(&]B<N%Z:V]V+B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)!:R!V:63M=&4@=/IT;R!S<'+A=G4@
M82!N979I9.UT92!O8G+A>F]K+"!O8G+A>F]K+"!K=&]R_2!S=&4@8VAC96QI
M(&YA:')ANRP@(@HB;F5M]+YE(&)YNR!Z;V)R87IE;OT@=F\@5F&Y;VT@<')E
M:&QI861AZ&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*
M;7-G<W1R(")5:^&^:V$@;V)RX7IK83HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!5
M4DPB"FUS9W-T<B`B55),(&]B<N%Z:V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B55),(&]B<N%Z:V$Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS
M9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B3V)RX7IO:R!Z(&=A
M;.ER:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB
M"FUS9W-T<B`B3V)RX7IO:R!Z(&=A;.ER:64Z(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(").86AR
M871I92!O8G+A>FMU(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G
M:60@(DEM86=E<R(*;7-G<W1R(")/8G+A>FMY(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L
M(%-T97`@)60B"FUS9W-T<B`B26UP;W)T+"!K<F]K("5D(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DEM<&]R=&]V86[I('!O;&4Z
M("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B
M26UP;W)T960@9FEE;&1S.B(*;7-G<W1R("));7!O<G1O=F%NZ2!P;VQI83HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E9L
M;[YINR!KM?KH(%]Z82(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G
M<W1R(")";VP@>F%D86[](&YE<W!RX79N>2!K\V0@86MC:64N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B3F5S<'+A
M=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE<VQO(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C
M="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3F5S<'+A=FYE('!O=;[M=F%T9;5S
M:^D@;65N;R!A;&5B;R!A;'1E<FYA=.UV;F$@861R97-A+B!3:_IS=&4@=&\@
M>FYO=G4@(@HB86QE8F\@:V]N=&%K='5J=&4@<W!RX79C=2!6X;EH;R!S>7-T
MZ6UU+"!A:R!P;W1R96)U:F5T92!P;VUO8RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S92!)
M;F1E;G0B"FUS9W-T<B`B6G;DZ+EINR!O9'-A9&5N:64B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN
M9&EA(@IM<V=S='(@(DEN9&EA(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN
M9&EV:61U86P@57-E<G,B"FUS9W-T<B`B2F5D;F]T;&EV[2!P;W6^[79A=&5L
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;NEZ:6$B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M26YF;R(*;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)MX6-I
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN
M9F]R;>%C:64@=;X@;FEE('/Z(&1O<W1U<&[I+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B
M26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B5FQOOFF[(%]S=.5P96,@
M>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R(")6
M;&^^:;L@;V)RX7IO:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R(")6
M;&^^:;L@=&%B=;5K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R
M(")6;&^^:;L@;&EN:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN
M($)E9F]R92(*;7-G<W1R(")6;&^^:;L@7W-TY7!E8R!P<F5D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")6;&^^:;L@;F]V_2!S=.5P96,@>F$@86MT=>%L;GDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R(")6;&^^:;L@;F]V_2!S=.5P96,@<')E
M9"!A:W1UX6QN>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFF[(&YO=OT@<FEA
M9&]K('IA(&%K='7A;&YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B5FQOOFF[(&YO
M=OT@<FEA9&]K('!R960@86MT=>%L;GDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(E9L;[YINR!O9'-T879E8R!Z82!A:W1UX6QN>2!B;V0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R(")6;&^^:;L@;V1S=&%V96,@<')E9"!A:W1UX6QN>2!B;V0B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R(")6;&^^:;L@86QT97)N873M=FYU
M(+EA8FSS;G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R"FUS9VED
M("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B6F%D86IT92!E+6UA
M:6QO=OH@861R97-U+"!N82!K=&]R^B!D;W-T86YE=&4@;F]VZ2!H97-L;SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R(")6;&^^
M:;L@8G5N:W4@>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`B5FQOOFF[(&)U;FMU('!R960B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E
M<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(E9L;[YINR!S=.5P96,@>F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")6;&^^
M:;L@<W3E<&5C('!R960B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")6;&^^
M=&4@<W!RX79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F
M=&5R(@IM<V=S='(@(E9L;[YINR!O9'-T879E8R!Z82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B5FQOOFF[(&]D
M<W1A=F5C('!R960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM
M<V=S='(@(E9L;[YINR!R:6%D;VL@>F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@
M<F]W(&)E9F]R92(*;7-G<W1R(")6;&^^:;L@<FEA9&]K('!R960B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE(')E
M<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S
M='(@(EIA9&%J=&4@<&^^861O=F%N^B!O9'!O=F7O(&YA(&)E>G!EZ&YO<W1N
M^B!O=.%Z:W4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R
M(")6;&^^:;LO=7!R879INR!O8G+A>F]K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF
M>2!,:6YK(@IM<V=S='(@(E9L;[YINR]U<')A=FF[(&QI;FMU(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B3F$@;V1O<VEE;&%N:64@<')E('IO>FYA;2!P<NUJ96UC
M;W8@;F5MX71E(&1O<W1A=&_H;OT@:W)E9&ET+B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(DYE9&]S=&%T;^AN_2!K<F5D:70N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
M0V5LZ2#H[7-L;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,W"FUS9VED
M("));G1E9V5R(&QI<W0B"FUS9W-T<B`B6F]Z;F%M(&-E;/UC:"#H:7-E;"(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED
M("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(").
M97!L861NZ2!51$@@*%5S97(@1&%T82!(96%D97(L($AL879IZ&MA('!O=;[M
M=F%T9;5S:_UC:"#Z9&%J;W8I+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z
M:7`N<&AP.C$V-R!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED
M(%I)4"!D871A(@IM<V=S='(@(DYE<&QA=&[I(/ID86IE(&9O<FWA='4@6DE0
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L
M:60@87!P;&EC871I;VXN(@IM<V=S='(@(DYE<&QA=&[A(&%P;&EKX6-I82XB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I
M9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B3F5P;&%T;ND@240@9.%V
M:WDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.3$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q-C(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S8*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S,#,@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S
M='(@(D)O;&D@;V1O<VQA;ND@;F5P;&%T;ND@^F1A:F4N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B3F5P;&%T;N$@8VEEM6]V
MX2!A9')E<V$N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y
M(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$S.0HC.B!L:6(O2&]R9&4O
M0V]M<')E<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M
M870B"FUS9W-T<B`B3F5P;&%T;OT@9F]R;>%T('/Z8F]R=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@;&EC
M96YS92!K97DN(@IM<V=S='(@(DYE<&QA=&[](&QI8V5NZ&[](&NU^N@N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B0F]L82!Z861A;N$@
M;F5P;&%T;N$@;&]K86QI=&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S
M='(@(DYE<&QA=&[A(&AO9&YO=&$@;7-G7W1Y<&4N(@H*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@
M;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(DYE<&QA=&[A(&%L96)O(&-H_6)A
M:OIC82!H;V1N;W1A(&%P:5]I9"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A
M<F%M971E<G,N(@IM<V=S='(@(DYE<&QA=&[I(&%L96)O(&-H_6)A:OIC92!P
M87)A;65T<F4N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS
M9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(").97!L
M871NZ2!R;V1IZ&]V<VOI('!RX79O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C$*;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS
M9W-T<B`B3F5P;&%T;ND@:60@<&%R=&YE<F$N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(DYE<&QA=&[](&OS9"!P<F]D=6MT=2XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI
M9"!P<F]T;V-O;"XB"FUS9W-T<B`B3F5P;&%T;OT@<')O=&]K;VPB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HX
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E
M<UPB(@IM<V=S='(@(DYE<&QA=&[]('!R[6IE;6-A.B!<(B5S7"(B"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$P-S4@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,C4X"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(").97!L
M871N_2!O8FIE:W0@>F1I9;5A;FEA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E
M<W,N(@IM<V=S='(@(DYE<&QA=&[A('ID<F]J;W;A(&%D<F5S82XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV
M86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(DYE<&QA=&[I(/ID86IE('5N
M:6-O9&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I
M9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=.%R(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM<V=I9"`B26YV97)T('-E
M;&5C=&EO;B(*;7-G<W1R("));G9E<G1O=F&[(';]8F5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DERX6XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G
M:60@(DER87$B"FUS9W-T<B`B27)A:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("+-<G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DES;&4@;V8@36%N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES
M;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(D]J961I;F5LZ2!B^G)K>2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B27-R865L(@IM<V=S='(@(DEZ<F%E;"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T<B`B5GED
M879A=&6U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B2W5R>NUV82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B271A;'DB"FUS9W-T<B`B5&%L:6%N<VMO(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A
M(@IM<V=S='(@(DIA;6%J:V$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,SDY(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YUX7(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N<VMO(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#,*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B
M2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S
M='(@(DIO<F3A;B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q
M"FUS9VED(")*=6QY(@IM<V=S='(@(DKZ;"(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DKZ;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B6F%R;W9N8;LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM
M<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B6F%R;W9N8;L@9&\@<W1R
M961U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("):87)O
M=FYANR!D;R!B;&]K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS
M9W-T<B`B6F%R;W9N8;L@=K5A=F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2
M:6=H="(*;7-G<W1R("):87)O=FYANR!V<')A=F\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K
M:'-T86XB"FUS9W-T<B`B2V%Z86-H<W1A;B(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-C,*;7-G:60@(DME97`@;W)I9VEN86P_
M(@IM<V=S='(@(E!O;F5C:&&[(&]R:6=I;N%L/R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B
M"FUS9W-T<B`B2V7R82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(DME<F)E<F]S('-E<G9E<B!Z86UI971O;"!A=71E;G1I
M9FEKX6-I=2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@
M(DME<FYE;"!.97=B:65S(@IM<V=S='(@(DME<FYE;"UN;W;AZ&EK;W9I82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(E9Y='9O<F5N:64@:[7ZZ&$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&:6YG97)P<FEN="(*
M;7-G<W1R(")$:6=I=.%L;GD@;V1T;&'H;VL@:[7ZZ&$B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T
M<B`B1.6^:V$@:[7ZZ&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(E1Y<"!KM?KH82(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B4&]UOFET:64@:[7ZZ&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B2[7ZZ"!UOB!E>&ES='5J92!N
M82!S97)V97)I('9E<F5J;OUC:"!KM?KH;W8N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(D1E=&DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(DMI<FEB871I(@IM<V=S='(@(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("*E
M=61O=F]D96UO:W)A=&EC:^$@<F5P=6)L:6MA($OS<F5A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+
M;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2_-R96IS:^$@<F5P=6)L:6MA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(DMO<F5A;B`H
M155#+4M2*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+
M=79A:G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VFY<VMO
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y
M;W5T(@IM<V=S='(@(E9Z7VBU860B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")*87IY:R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B3&%O<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA
M<W0@2&%L9B(*;7-G<W1R(")0;W-L961NX2!P;VQO=FEC82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N
M9V4B"FUS9W-T<B`B4&]S;&5D;N$@>FUE;F$@:&5S;&$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),
M87-T(%%U87)T97(B"FUS9W-T<B`B4&]S;&5D;N$@N71V<KLB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G
M<W1R(")0;W-L961NX2!A:W1U86QI>N%C:6$Z(@H*(SH@;&EB+TAO<F1E+T%U
M=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E
M<R(*;7-G<W1R(")0;W-L961NZ2!P<FEH;.%S96YI93H@)7,B"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@
M;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B4&]S;&5D;ND@<')I:&SA<V5N
M:64Z("5S('H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED
M("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")0;W-L961NZ2!P<FEH;.%S
M96YI93H@;FEK9'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),;W1YN7-K
M;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM
M<V=S='(@(E!RX79O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B5GIH
MM6%D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R
M(").96-H86IT92!P<N%Z9&YE('!R92"^:6%D96X@;VMR86HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*
M;7-G<W1R(")6M6%V;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`X"FUS
M9VED("),969T(&AE861E<B(*;7-G<W1R(")(;&%V:>AK82!VM6%V;R(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3`T"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R(")(;V1N;W1Y(':U879O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S
M='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(MIR;W9E\B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),:6+I<FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*
M86UA:&ER:7EA(@IM<V=S='(@(DSM8GEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T
M96EN(@IM<V=S='(@(DQI8VAT96ZY=&%J;G-K;R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(J5A:&OI(&UR:&]L96YI92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN
M(@IM<V=S='(@(J5A:&O](&3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*
M;7-G<W1R(")2X6YO(+5A:&O](&3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(DYE<VOT<B"U86AK_2!DX;[O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@
M4VAO=V5R(@IM<V=S='(@(J5A:&OI(&1AON]O=ND@<')E:.%N:WDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B
M3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`BI6%H:_T@9.&^[R!S
M(&AR;65N[6TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("*E86AKZ2!S;F6^
M96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("*E86AKZ2!S
M;F5H;W;I('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U
M"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE<FEC:R(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ.#$X"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FMA
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3&EN
M:V$@=6MA>G5J92!N83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W.0IM
M<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R(")0<F5P;VIINR!E+6UA:6QO
M=OH@861R97-U('-O('-T<N%N:V]U(&YA('#M<V%N:64@<&^Y='DB"@HC.B!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@
M(DQI;FMS(@IM<V=S='(@(DQI;FMY(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@@0V]O
M:VEE(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS
M9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B
M6F]Z;F%M("T@<&]UONUV871EM2!U=FED[2!P<FEEZ&EN;VLB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G
M<W1R(")6>7#M<V&[('IO>FYA;2!D871A8N%Z(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T
M<B`B6F]Z;F%M('3I;2!0;VUO8V[M:V$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")6>7#M<V&[('IO
M>FYA;2!T86)U;&EE:R(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP
M.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(DQI<W0M07)C:&EV
M92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B
M3&ES="U(96QP(@IM<V=S='(@(DQI<W0M2&5L<"(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),
M:7-T+4ED(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI<W0M3W=N97(B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*
M;7-G<W1R("),:7-T+5!O<W0B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M
M4W5B<V-R:6)E(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DP
M"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M56YS=6)S
M8W)I8F4B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@
M(EIO8G)A>F5N:64@<V5D96[M('IL>6AA;&\Z("5S(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@9F%I;&5D.B`E<R(*;7-G<W1R("):;V)R87IE;FEE('!O=;[M=F%T9;5O
M=B!Z;'EH86QO.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B6F]B<F%Z;W9A;FEE('IO>FYA;74@<&]UONUV871EM6]V(&IE('IA
M:^%Z86[I+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T^G)A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H
M=6%N:6$B"FUS9W-T<B`B3&ET=F$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(").
M8>CM=&%V82!S82XN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#`*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")-:65S=&YY(.AA
M<SH@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A
M;&4@86YD(%1I;64B"FUS9W-T<B`B3&]K86QI>N%C:6$@82#H87,B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI
M8B]";&]C:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@
M(DQO:V%L:71A(@H*(SH@;&]G:6XN<&AP.C$X-B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E!R:6AL
MX7-E;FEE(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS
M9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(EKA
M>FYA;7D@<')E9&-HX61Z86KZ8V5J('-Y;F-H<F]N:7KA8VEE(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*
M;7-G<W1R(")/9&ALX7-INR(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B4')I:&SA<V5N:64B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G
M<W1R("+:;&]H>2!P<FD@<')I:&SA<V5N[2(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(B(*(E!R:6ALX7-E;FEE('IL>6AA;&\L('!R971OOF4@<W1E('IA
M9&%L:2!N97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&%L96)O("(*(FAE
M<VQO+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY.#@*;7-G:60@(DQO9VEN
M(&9A:6QE9"XB"FUS9W-T<B`B4')I:&SA<V5N:64@>FQY:&%L;RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S
M='(@(D1L:/T@=&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM
M<V=I9"`B3&]V92(*;7-G<W1R("),X7-K82(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B
M3NUZ:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM
M<V=S='(@(DUA;.D@9W+I8VME('#M<VUE;N$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),
M;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(DUA;.D@;&%T:6YS:^D@<.US
M;65NX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B36%LZ2!R[6US:V4@Z.US;&EC92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R
M9R(*;7-G<W1R("),=7AE;6)U<G-K;R(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.3@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S-@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(E-P<N%V82!D\F$B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B4'+M;&]H
M82!-4RU43D5&(&YE;V)S86AO=F%L82"^:6%D;F4@^F1A:F4N(@H*(SH@;&EB
M+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS
M9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R
M(")-86-A;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D\VYS:V\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B3>%G:6$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB
M"FUS9W-T<B`B4&^Y=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3(T"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(E!O<VQANR!E+6UA:6P@
M861M:6YI<W1RX71O<F]V:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?:RXN
M+B(*;7-G<W1R(")6>71V;W)INR!L:6Y?:W4N+BXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W
M:2(*;7-G<W1R(")-86QA=VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@
M(DUA;&%J>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QE9&EV
M>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT
M82(*;7-G<W1R(")-86QT82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY
M-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U
M(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O
M8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB4W!R
M879O=F&[('IO>FYA;2!K871E9_-R:>TL(',@:W1O<OUM:2!O>FYAZ'5J971E
M('!O;&^^:WD@82!F87)B>2!A<V]C:6]V86[I("(*(G,@=/UM:71O(&MA=&5G
M\W)I86UI+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B36%P82!-87`R-"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P82!-87!1=65S="(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@
M<W1O<F5D+B(*;7-G<W1R(")-87!O=F%N:6$@=6QOOF5NZ2XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T
M<B`B36%R96,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B3VMR86HB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R(")/>FYAZ&F[
M('!R[7IN86MM:2!0<F7H[71A;NDO3F5P<F7H[71A;NDB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O
M=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@
M(D]Z;F'H:;L@:6[];6D@<'+M>FYA:VUI("AN87!R+B!$]&QEOFETZ2]:;V1P
M;W9E9&%NZ2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M36%R<VAA;&QO=F4@;W-T<F]V>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G
M<W1R(")-87)T:6YI:R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B6FAO9&[I('!O
M;&EA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(DUA=7)E=.%N:6$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R[71I=7,B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X
M(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-87AI;>%L;GD@<&]V;VQE;OT@
M:W)E9&ET+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T
M<B`B0F]L('!R96MR;^AE;OT@;6%X:6WA;&YY('!OZ&5T(.AA<W3M('-P<N%V
M>2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DYA:G9YN;EI82!T97!L;W1A
M('IA('!O<VQE9&[]8V@@,C0@:&]D[6XZ("(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R(").86IV>;FY:6$@=&5P;&]T82!Z82!P;W-L961N_6-H(#8@:&]D[6XZ
M("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O
M9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DUA>&EMX6QN>2!P;^AE="!B;&]K
M;W8@<&]R=.%L=2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY,#(@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,C$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-#,*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA>&EMX6QN82!DY;YK82(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB
M"FUS9W-T<B`B3>%J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO
M='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I
M8VEN92(*;7-G<W1R(")-961I8^UN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BR&QE
M;F]V:6$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED(")-
M96YU(&UO9&4Z(@IM<V=S='(@(EIO8G)A>F5N:64@;65N=3HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS
M9VED(")-97)G92!C96QL<R(*;7-G<W1R("):;/KH:;L@8G5N:WDB"@HC.B!L
M:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(E-P<N%V82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB4W!RX79A(&)O;&$@^G-P9;EN
M92!O=F5R96[A+"!A;&4@8V5R=&EF:6OA="!P;V1P:7-U('-A(&YE<&]D87)I
M;&\@;W9E<FF[+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E!L871N
M;W.[('-P<N%V>2!V>7!RN6%L82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,#(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE
M<W-A9V4@='EP92(*;7-G<W1R(")4>7`@<W!RX79Y(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(E!O
MZ&%S:64@365T87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED
M(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+:9&%J92!-
M971A<B!N:64@<_H@9&]S='5P;NDN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*(MID86IE($UE=&%R(&YI92!S^B!K(&1I<W!O>NUC:6DN
M($1E=&%I;'D@8F]L:2!Z87IN86UE;F%NZ2!P<F4@861M:6YI<W1RX71O<F$N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B
M365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R(")3>7-TZ6T@365T
M87)$0B!N:64@:F4@<')I<&]J96[]+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B365T\V1A(@H*(SH@;&EB+TAO
M<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z
M,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@;F]T
M(&1E9FEN960B"FUS9W-T<B`B365T\V1A(%PB)7-<(B!N:64@:F4@9&5F:6YO
M=F%NX2(*"B,Z(&QI8B](;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D
M.B`E<R(*;7-G<W1R(").961E9FEN;W9A;N$@;65T\V1A+B!6;VQA;ND@>B!M
M973S9'DZ("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*;7-G<W1R
M(")-971R:6-KZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE>&EC;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R
M"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S
M='(@(DUI:W)O;NEZ<VME(&9E9&5R873M=FYE(+ETX71Y(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED
M(")-:61D;&4B"FUS9W-T<B`B4W1R960B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4
M>7`@36EM92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-
M:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F%J;FF^N6EA('1E
M<&QO=&$@>F$@<&]S;&5D;OUC:"`R-"!H;V3M;CH@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(DYA:FYIOKEI82!T97!L;W1A('IA('!O<VQE9&[]8V@@-B!H
M;V3M;CH@(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED
M(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM
M<V=S='(@(DUI;FEMX6QN82!D;V)A('!L871N;W-T:2!H97-L82!EN71E(&YE
M=GEP<KEA;&$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B6G)K861L;W9O(&]B<N%T
M:;LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E
M;&QA;F5O=7,B"FUS9W-T<B`B4O1Z;F4B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C<R(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B0VC]8F$@8F%L[6L@4$5!4B!(5%107U)E<75E<W0N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(D-H
M_6)A(&MO;F9I9W5RX6-I82X@06L@8VAC971E('!O=;[M=F&[('3Z=&\@87!L
M:6OA8VEU+"!M=7/M=&4@=&5R87H@(@HB=GEG96YE<F]V8;L@:V]N9FEG=7+A
M8VEU+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T
M"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(D-H_6)A($E$
M('-P<N%V>2XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-
M86EL+B(*;7-G<W1R(")#:/UB82!P;[YA9&]V86[](%!%05(@8F%L[6L@36%I
M;"XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM
M<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")#:/UB82!)1"!R
M96SA8VEE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(E!O;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T
M<B`B36]B:6QN_2!M86EL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DUI97)N
M>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S
M='(@(D3A='5M('!O<VQE9&YE:B!Z;65N>2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D
M:69Y(%523"(*;7-G<W1R(")5<')A=FF[(%523"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO
M9'5L=7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(DUO;&1A=G-K;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#D@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%K;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$U,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L<VMO(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(U.#@*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM
M<V=S='(@(DUE<VEA8R!A(')O:R(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC
M92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B365S8>AN92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C$@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R(")-97-AZ&[I(&;A>GDB"@HC.B!L:6(O
M1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(").82!R:6%D:W4@)60@8F]L
M;R!NX6ID96[]8V@@=FEA8R!P;VSM(&%K;R!OZ&%KX79A;OUC:"`E9"XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*
M;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;VMO(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#
M;&5A<B(*;7-G<W1R(")0<F5V8;YN92!J87-N;R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO
M=61Y(@IM<V=S='(@(E!R979AOFYE(&]B;&'H;F\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U
M;FYY(@IM<V=S='(@(E!R979AOFYE('-L;F7H;F\B"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R
M(")0<F5S=6[ZNR!D;VQU(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4')E<W5N^KL@=K5A
M=F\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@
M(DUO=F4@4FEG:'0B"FUS9W-T<B`B4')E<W5N^KL@=G!R879O(@H*(SH@;&EB
M+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM
M<V=S='(@(E!R97-U;OJ[(&AO<F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-3(S"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B
M4')E<W5N^KL@9&]L=2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C(@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R,PIM<V=I9"`B36]V92!U<"(*;7-G<W1R(")0<F5S=6[ZNR!H;W)E(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%B;6EK(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q.#@*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@
M9&]W;B!L:7-T<R(*;7-G<W1R(")6:6%C^G)O=O)O=ND@=GEB97)A8VEE('IO
M>FYA;7DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C0V"FUS9VED(")-=6QT:7!L92!S96QE8W1I
M;VXB"FUS9W-T<B`B5FEA8V[A<V]B;OT@=OUB97(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@
M(DUO:F4@:V]N=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G
M:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)MX6-I
M92!O(&UO:F]M(/KH=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B3?1J('!O<G3A;"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A
M;"!,87EO=70B"FUS9W-T<B`B5GIHM6%D(&WT:FAO('!O<G3A;'4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$
M;R!.3U0@06=R964B"FUS9W-T<B`B3FEE+"!.15/:2$Q!4\U-+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,2!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$P,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B365N;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F%M:6)I82(*;7-G<W1R(").86WM8FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G
M<W1R(").875R=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5PX6PB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DAO;&%N9'-K;R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")(;VQA;F1S:^D@06YT
M:6QY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@
M(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(EKA:VQA9&[A(%523"!.971S
M8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@<')E
M('IN97!L871N96YI92!C97)T:69I:^%T;W8@0T$@3F5T<V-A<&4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523"(*;7-G<W1R(")54DP@<')E('!O;&ET:6MU($-!($YE
M='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G
M:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(E523"!P<F4@;V)N
M;W9E;FEE('!L871N;W-T:2!C97)T:69I:^%T;W8@3F5T<V-A<&4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B55),('!R92!Z;F5P;&%T;F5N:64@
M8V5R=&EF:6OA=&]V($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*
M;7-G<W1R(")-96YO(%-33"!S97)V97)A($YE='-C87!E(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I
M9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B2V]M96YTX7(@8V5R=&EF:6OA='4@
M3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X,0IM
M<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(")4>7`@
M8V5R=&EF:6OA='4@3F5T<V-A<&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(E-I9;LB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").
M979E<B(*;7-G<W1R(").:6MD>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*
M;7-G<W1R(").;W;A($MA;&5D\VYI82(*"B,Z(&QI8B](;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS
M9W-T<B`B3F]VX2!K871E9_-R:6$B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT
M97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY
M-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T<B`B3F]V
MX2!S<'+A=F$@<')E("5S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI
M8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS
M9VED(").97<@36]O;B(*;7-G<W1R(").;W8B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P
M=&EO;F%L*2(*;7-G<W1R(").;W;I('!O=;[M=F%T9;5S:^D@;65N;R`H;F5P
M;W9I;F[I*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]V_2!:
MZ6QA;F0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G
M:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").;W;I(&AE<VQO(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(")0;&%T
M;F]SNR!N;W;I:&\@:&5S;&$@=GEP<KGM("5X+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG
M="!M871C:"XB"FUS9W-T<B`B3F]VZ2!H97-LX2!N:64@<_H@<F]V;F%KZ2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ
M"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO=ND@;VMN
M;R`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYE=W,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S
M='(@(D1I<VMU<V[I('-K=7!I;GDB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("+/86QE:B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E<R(*
M;7-G<W1R(").87-L961U:OIC92`T(&;A>GDB"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C,W,B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W-@IM<V=I
M9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(L]A;+EI92!N87-T879E;FEA(@H*
M(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(DYA<VQE9'5J^F-A/B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S
M='(@(DYI:V%R86=U82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEG97(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEGZ7)I82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(DYO8R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-SD@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B
M"FUS9W-T<B`B3FEE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N
M:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A
M('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G<W1R("(B"B).:64@<_H@
M9&]S='5P;ND@OFEA9&YE(&MO;F9I9W5R8>ANZ2#Z9&%J92P@<')E(&MT;W+I
M(&)Y('-A(&1A;&D@>F]B<F%Z:;L@(@HB<F]Z9&EE;'DN(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B4')E('9Y=';A
M<F%N:64@25-/(&]B<F%Z;W8@;FEE(&IE(&L@9&ES<&]Z[6-I:2"^:6%D;F$@
M<W1R873I9VEA+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B3F5E
M>&ES='5J92"Y86)L\VYA('!R92!DX79K=2XB"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HW.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR
M-#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C8W"FUS9VED(").
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G
M<W1R(").82!P;[YA9&]V86YE:B!P;WKM8VEI(&YE97AI<W1U:F4@OFEA9&5N
M(&)L;VLN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G:60@
M(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(E!R92!-0T%,(&%U=&5N=&EF:6OA8VEU(&YE8F]L
M;R!Z861A;ND@;65N;R!K86QE;F3A<F$N(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`BKFEA9&YA('IM
M96YA+B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*
M;7-G<W1R(")+('1O;75T;R!P<N%V=2!N96UOOFYO('!R:61ANR"^:6%D;F4@
M<&]D<FEA9&5NZ2!P<N%V82XB"@HC.B!L:6(O2&]R9&4N<&AP.C$V.2!L:6(O
M2&]R9&4N<&AP.C4P."!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B4')E("5S(&YE8F]L82!U<NAE;N$@
M:V]N9FEG=7+A8VEA+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-#0*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+B(*;7-G<W1R(")0<F4@1E10(%9&4R!N96)O;&$@=7+H96[A(&MO
M;F9I9W5RX6-I82XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B4')E(%-13"!61E,@;F5B;VQA('5RZ&5NX2!K;VYF
M:6=U<N%C:6$N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,+49I;&4@5D93+B(*;7-G<W1R(")0<F4@4U%,+49I;&4@5D93(&YE8F]L
M82!U<NAE;N$@:V]N9FEG=7+A8VEA+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS
M9W-T<B`BKFEA9&5N(&MR961I="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"XB"FUS9W-T<B`B3F5B;VQO(+EP96-I9FEK;W9A;ND@;6EE<W1O('5RZ&5N
M:6$N(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,PIM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R(")3^F)O<B!N96)O;"!N86AR86[]+B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@
M9F]U;F0N(@IM<V=S='(@(DYE8F]L:2!NX6ID96[I(+YI861N92!I:V]N>2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM
M<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(").:64@:F4@;F%S
M=&%V96[A(&QO:V%L:71A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R
M(").96)O;&$@>F%D86[A(&QO:V%L:71A+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI
M960N(@IM<V=S='(@(DYE8F]L82!Z861A;N$@OFEA9&YA('-P<N%V82XB"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B3F5B;VQO(+EP96-I9FEK;W9A
M;ND@OFEA9&YE(&UE;F\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3F5B;VQO(+EP96-I9FEK;W9A;ND@Z.US;&\N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`BKFEA9&YE('5RX;YL:7;I(&9O<G1U;GDB"@HC.B!L:6(O2&]R
M9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!(5%10
M(&%U=&5N=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E
M($E-05`@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")0<F4@2V5R8F5R;W,@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%N
MZ2!H97-L;RXB"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-R!L:6(O
M2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0*(SH@;&EB+TAO<F1E+T%U=&@O<&%M
M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")0<F4@3&]G:6X@875T96YT:69I
M:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RXB"@HC.B!L:6(O2&]R9&4O075T
M:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@
M9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E(%!!4U-7
M1"!A=71E;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R92!3
M34(@875T96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RXB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A
M=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-3
M3"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N(@IM<V=S='(@(B(*(DYE8F]L82!Z861A;N$@8V5S=&$@:R!P<F]G
M<F%M=2!/<&5N4U-,+B!0<F]G<F%M($]P96Y34TP@:F4@<&]T<F5B;OT@;F$@
M<'+A8W4@(@HB<R#Z9&%J;6D@4$M#4R`Q,BXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(JYI861N92!P<F5B:65H86KZ8V4@<')I:&SA<V5N:6$N
M(@H*(SH@;&EB+U9&4RYP:'`Z-S8U"FUS9VED(").;R!Q=6]T82!S970N(@IM
M<V=S='(@(DMV\W1A(&YI92!J92!N87-T879E;N$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B
M3F\@<G5L97,B"FUS9W-T<B`B0F5Z(.AI87(B"@HC.B!L:6(O1FEL92]#4U8N
M<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3F5B;VP@N7!E8VEF:6MO=F%N_2!O9&1EM6]V8>@N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I
M9"`B3F\@<VED97,B"FUS9W-T<B`B0F5Z('-T<N%N(@H*(SH@;&EB+U9&4R]S
M;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(E/Z8F]R
M(&YE;N%J9&5N_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B4')E('9Y<F]V;N%V86-I=2!P86WDNR!N:64@
M:F4@9&]S='5P;OT@OFEA9&5N(&1OZ&%S;OT@<')I9>AI;F]K+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D('-E;G0N(@IM<V=S='(@(DYE8F]L;R!O9&]S;&%NZ2!P;W6^[79A
M=&6U<VOI(&UE;F\@82]A;&5B;R!H97-L;RXB"@HC.B!L:6(O2&]R9&4O4E!#
M+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(*;7-G<W1R(").96)O;&D@=G+A=&5NZ2!P;&%T;ND@6$U,(/ID86IE
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E
M<R(*;7-G<W1R("*N:6%D;F4@:&]D;F]T>2(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"B)6('#T=F]D;F5J(&MO;F9I9W5RX6-I:2!N96)O;&$@;N%J
M9&5NX2"^:6%D;F$@=F5R>FEA+B!6>6=E;F5R=6IT92!Z;F]V=2`B"B)K;VYF
M:6=U<N%C:74N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB5B!K;VYF:6=U
M<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA('9E<GII82X@5GEG96YE<G5J
M=&4@>FYO=G4@:V]N9FEG=7+A8VEU+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0R-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C
M="YI;F,Z.3,*;7-G:60@(DYO;F4B"FUS9W-T<B`BKFEA9&5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B
M3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("*N:6%D;F4@*'!O=;YINR!I
M;7!L:6-I=&[Z(&AO9&YO='4I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#4*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3W-T<F]V($YO<F9O;&LB
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(E-E=F5R
M;N$@<&]L;V=UM6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R(")3979E<F[I($UA<FGA;G-K92!O<W1R;W9Y(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").;W)W87DB"FUS9W-T<B`B3O-R<VMO(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").97!L
M873M('!O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F5P;&%T[2!P<F5D(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G
M<W1R(").:64@:F4@861R97/A<B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H
M<#HV,R!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP
M:'`Z.34*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").:64@
M:F4@:6UP;&5M96YT;W9A;NDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").
M96YA<W1A=F5NZ2(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR
M,#@@;&EB+U9&4RYP:'`Z,C,S(&QI8B]61E,N<&AP.C(U,0HC.B!L:6(O5D93
M+G!H<#HR-C@@;&EB+U9&4RYP:'`Z,C@T(&QI8B]61E,N<&AP.C,P,"!L:6(O
M5D93+G!H<#HS,34*(SH@;&EB+U9&4RYP:'`Z,S,R(&QI8B]61E,N<&AP.C,V
M-2!L:6(O5D93+G!H<#HT,C4@;&EB+U9&4RYP:'`Z-3`T"B,Z(&QI8B]61E,N
M<&AP.C4W,R!L:6(O5D93+G!H<#HU.3`@;&EB+U9&4RYP:'`Z-C8X"B,Z(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D92]397-S
M:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE
M<BYP:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z
M(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R(").:64@:F4@<&]D<&]R;W9A;NDN(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B4&]Z;N%M:WDB"@HC.B!S97)V
M:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@
M8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").:>@@;F$@<')E>F5R86YI92P@
M=G+ANW1E('-A('-PY+LN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P-3`*;7-G:60@(DYU;6)E<B(*;7-G<W1R
M("+([7-L;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(Y"FUS9VED(").
M=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")0;^AE="!Z;F%K;W8B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,30R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F
M(&-O;'5M;G,B"FUS9W-T<B`B4&_H970@<W3E<&-O=B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(U(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G
M<W1R(")0;^AE="!R:6%D:V]V(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B4')E
M(&%K='5A;&EZX6-I=2!Z;WIN86UU('!R[6IE;6-O=B!N96)O;&D@N7!E8VEF
M:6MO=F%NZ2#H[7-L82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,`IM<V=I9"`B3V)J
M96-T(@IM<V=S='(@(D]B:F5K="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")!=71O
M<B!O8FIE:W1U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,#@*;7-G:60@
M(D]C=&%L(@IM<V=S='(@(D]S;6GH:V]V_2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]K=/-B
M97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N
M<V4@9FEL=&5R(@IM<V=S='(@(D9I;'1E<B!N82!N863A=FMY(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B3V9F:6-E(@IM<V=S
M='(@(E!R86-O=FES:V\B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B4W1A<ND@82!N;W;I(&AE<VQO(&UU<VEA(&)Y
MNR!O9&QIN6[I+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E-T87+I(&AE<VQO(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@
M<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(E-T87+I(&AE<VQO
M(&YE8F]L;R!Z861A;ND@<W!RX79N92XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T
M<B`B3VWA;B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HW
M,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`B26)A($E-05`@<V5R=F5R>2!P;V1P;W)U:OH@>F1I
M9;5A;ND@<')I9>AI;FMY+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B26)A
M('5RX;YL:7;I(&9O<G1U;GDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")*92!P<NUP=7-T;N$@:6)A
M(&IE9&YA(&4M;6%I;&]VX2!A9')E<V$N(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)6;&%S
M=&[M:V$@86QE8F\@<'+A=F$@=FQA<W1N[6MA('!R92!Z9&EEM6%N_2!O8FIE
M:W0@;?2^92!Z;65N:;L@:6)A('9L87-T;NUK("(*(F%L96)O('-Y<W3I;6]V
M_2!A9&UI;FES='+A=&]R(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,SD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(D]T=F]R:;L@=B!N;W9O;2!O:VYE(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R
M;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%
M('!A<G0N(@IM<V=S='(@(D-H>6)A($]P96Y34TPZ(&YE<&]D87)I;&\@<V$@
M>NUS:V&[(/ID86IE('H@<&]D<.US86YE:B#H87-T:2!3+TU)344N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(D]T=F]R:;L@=/IT;R!L:6YK=2!V(&YO=F]M(&]K;F4B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T
M96TB"FUS9W-T<B`B3W!E<F'H;OT@<WES=.EM(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(").
M87-T879E;FEA(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO
M;G,@9F]R("5S(@IM<V=S='(@(DYA<W1A=F5N:6$@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E
M<F5D($QI<W0B"FUS9W-T<B`B6F]R861E;OT@>F]Z;F%M(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*
M;7-G<W1R(")/<F=A;FEZX6-I82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@
M(D]R9V%N:7IAZ&[A(&IE9&YO=&MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FEZ
M;W9A;FEE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(E#T=F]D;N$@
MN6%B;/-N82!A<&QI:^%C:64B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(E#T=F]D;ND@N6%B;/-N>2!V("5S.B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(DENZ2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S
M='(@(L]A;+EI92!I;F9O<FWA8VEE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M4'+A=F$@=FQA<W1N[6MA(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%M+G!H<#HW
M.0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(E!!32!A=71E;G1I9FEKX6-I82!N:64@:F4@9&]S='5P;N$N
M(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@
M(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")014%2.DUA:6P@8F%C:V5N
M9"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'
M4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")$:6=I=.%L;GD@<&]D<&ES
M(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@
M(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("+:9&%J92!Z8;EI9G)O=F%N
MZ2!P;VUO8V]U(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S
M-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"!V97)E:F[]
M(&NU^N@B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED
M(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(MID86IE('!O
M9'#M<V%NZ2]Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4"(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(&OS
M9"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL
M(@IM<V=S='(@(E!(4"!3:&5L;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S
M='(@(E!O<&]L=61N[2"U86AK_2!DX;[O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS
M9W-T<B`B4&]P;VQU9&[M('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS9W-T
M<B`B4&]P;VQU9&[M('-N9;YE;FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*
M;7-G<W1R(")0;W!O;'5D;NT@<VYE:&]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3
M=6XB"FUS9W-T<B`B4&]P;VQU9&[M('-N9;YE;FEE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(E!O<&]L=61N[2!B^G)K>2(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S
M:6YG(@IM<V=S='(@(D-H_6)A(')O>KGM<F5N:64@4$]325@B"@HC.B!L:6(O
M87!I+G!H<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4%](4"!3
M:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B5GEP;&YE;FEE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI<W1A;B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U<VOI(&]S=')O=GDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DR(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED
M(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A
M;&5S=.UN<VME(/IZ96UI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A
M;F%M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U
M82!.;W;A($=U:6YE82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.34@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A
M<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`BR&EA<W1OZ&YE
M(&]B;&'H;F\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3@P(&QI8B](;W)D92]&;W)M+G!H<#HR,#(R"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S<@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@;&EB+TYE="]335,O=VEN7VAT='`N
M<&AP.C$U,2!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B2&5S;&\B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")(97-L;R!B
M;VQO(/IS<&6Y;F4@>FUE;F5NZ2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R
M(").97-P<N%V;F4@:&5S;&\B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4')E(&%U=&5N=&EF:6OA8VEU(%)!
M1$E54R!J92!V>;YA9&]V86[I(&AE<VQO+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*
M;7-G<W1R(")(97-L;R!S('!O='9R9&5N[6TB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")(
M97-L;SHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I
M9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")(97-L;SH@(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H<#HR,#,X"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M
M=7-T(&UA=&-H+B(*;7-G<W1R(")(97-LX2!M=7-I82!B>;L@<F]V;F%KZ2XB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B5FQOOFF[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B
M"FUS9W-T<B`B5FQOOFF[('IO('-C:'+A;FMY(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T:"(*;7-G
M<W1R(")#97-T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(E!R96)I96AA:OIC
M92!R96=I<W1RX6-I93HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*
M;7-G:60@(E!E;W!L92(*;7-G<W1R("*E=61I82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT
M(@IM<V=S='(@(E!E<F-E;G0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(E9Y:V]N8;L@;W!E<N%C:64@^F1ROF)Y
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")6
M>6MO;F&[(&]P97+A8VEE(/ID<KYB>2!P<FD@<')I:&SA<V5N[3\B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*
M;7-G<W1R(")0<N%V;R(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E
M;&5T960N(@IM<V=S='(@(E!RX79O(%PB)7-<(B!N96)O;&\@=GEM87IA;NDN
M(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$
M96YI960B"FUS9W-T<B`B4'+M<W1U<"!Z86UI971N=73](@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!RX79A(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1RX6-I82!P<N%V(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*
M;7-G<W1R(")/<V]B;ND@:6YF;W)MX6-I92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G
M<W1R(")097)U(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED
M(")0971S(@IM<V=S='(@(D1O;>%C92!Z=FEE<F%TX2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI
M;&EP<&EN97,B"FUS9W-T<B`B1FEL:7#M;GDB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B
M5&5L96;S;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G
M:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O9W)A9FEE(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S
M='(@(D)O9&]V(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED
M(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C
M;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")+;&EK;FET92!P<F]S[6T@
M9&\@;F5J86ME:B!B=6YK>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R(")0;W1V<N]T92!P<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N:;L@=&5N
M=&\@96QE;65N=#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(E!L96%S92!C;VYF:7)M('1H
M870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B
M4&]T=G+O=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[(&QI;FMU('H@
M=&]H=&\@96QE;65N='4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C8*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S
M='(@(EIA9&%J=&4@<')O<^UM(&UE<VEA8R!A(')O:RXB"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T
M<B`B6F%D86IT92!P<F]S[6T@;65N;R!P<F4@;F]V^B!K871E9_-R:74Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(EIA9&%J=&4@<')O<^UM
M('!L871N^B!)4"!A9')E<W4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V
M-#<*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(EIA9&%J
M=&4@<')O<^UM('!L871N_2!DX71U;2P@<VMO;G1R;VQU:G1E('!OZ&5T(&1N
M[2!V(&UE<VEA8VDN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3$*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(EIA9&%J
M=&4@<')O<^UM('!L871N_2#H87,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0<F]S[6T@=79E[W1E('IH<FYU
M=&EE('!R;V)LZ6UU+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B
M4')O<^UM('IA9&%J=&4@<W9O:F4@<&]UONUV871EM7-KZ2!M96YO(&$@:&5S
M;&\B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*
M(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R
M964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S
M='(@(B(*(E!R9>CM=&%J=&4@<VD@<')O<^UM(&YA<VQE9'5J^F-I('1E>'0N
M($U54\U412!S^FAL87-INR!S('!O9&UI96YK86UI("(*(G!O=;[M=F%N:6$@
M<WES=.EM=2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.B(*;7-G<W1R("):861A:G1E('!R;W/M;2!M96YO('!R92!N;W;Z(&MA
M=&5G\W)I=3HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;[5S:V\B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM
M<V=S='(@(E!O;&ET:6MA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B06YK971Y(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Y,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B
M4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86QS:V\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G
M:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B56UI97-T
M;F5N:64@=&]H=&\@;V)RX7IK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE(@IM<V=S='(@(E5M:65S=&YE;FEE('1E:G1O('1A8G6U:WDB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@
M(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*
M;7-G<W1R(")/9&]S;&&[(&1O('1O:'1O('!R:67H:6YK82`H;F5V>6YU8W5J
M92!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET
M871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(EIRX;YK>2!Z
M82!P;W-L961N_6-H("5S(&AO9.UN.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E(@IM<V=S='(@(E!R879D97!O9&]B;F]SNSQB<B`O/GIRX;YO:R(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]L9&%P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@3$1!4"!N96)O
M;&\@;N%J9&5NZ2XB"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z
M,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@<&^^
M861O=F%NZ2!R;WJY[7)E;FEE('-E<W-I;VX@;F5B;VQO(&[A:F1E;NDN(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM
M<V=S='(@(E1L86LB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B5&QA:R!N82#Z
M<F]V;FD@;6]R83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R(")4;&%K.B`B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")5:^&^:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*
M;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R("):;V)R87IINR!U:^&^:W4@;V)RX7IK=2!V(&YO=F]M(&]K;F4B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,B!L:6(O2&]R9&4O4')E9G,O
M54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0
M<F5D8VCA9'IA:OIC92!N87-T879E;FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE
M;G0B"FUS9W-T<B`B5GET;&'H:;L@9&]K=6UE;G0B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(E!R:7;A=&YY(&NU^N@B"@HC.B!L:6(O2&]R9&4O365N=2YP:'`Z,38Y"FUS
M9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)LZ6TB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4&]P:7,@<')O8FSI;74B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S<Q"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT>2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3$U(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3DR(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")0<F]M<'0@
M=&5X="(*;7-G<W1R(")6_7IV82!N82!Z861A;FEE('1E>'1U(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM
M<V=S='(@(E9E<F5J;OT@:[7ZZ"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R
M(")!;&=O<FET;75S('9E<F5J;NEH;R!KM?KH82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS
M9W-T<B`B26YF;W)MX6-I92!O('9E<F5J;F]M(&NU^NAI(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")6
M97)E:F[]+W!R:7;A=&YY(&NU^NAO=OT@<.%R(&YE8F]L(/IS<&6Y;F4@=GEG
M96YE<F]V86[]+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!O
M<G1O<FEK;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R(")$
M;W1A>B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O
M=&$B"FUS9W-T<B`B2W;S=&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H
M)60@8FET*2(*;7-G<W1R(")24T$@=F5R96IN_2!KM?KH("@E9"!B:71O=BDB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V.`IM<V=I9"`B4F%D:6\@<V5L
M96-T:6]N(@IM<V=S='(@(E!R97#M;F'H(',@=OUB97)O;2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN
M(@IM<V=S='(@(D3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")2X6YO
M(&3AON\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(DYE<VOT<B!DX;[O(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G
M:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(D1AON]O=ND@<')E:.%N:WDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I
M9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")$X;[O('-O('-N96AO;2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED
M(")286EN('1O(%-N;W<B"FUS9W-T<B`B1.&^[R!P<F5C:.%D>F%J^F-I('8@
M<VYEOF5N:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B
M4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B3N%H;V1NX2!F;W)T=6YA(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E!O
M;65R(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@
M(E)E860B"FUS9W-T<B`BR.UT8;LB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B
MR.UT8;L@<W!RX79Y(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_
M(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(DYA
M;WIA:B!V>6UA>F&[("5S/R!4^G1O(&]P97+A8VEU(&YE;6^^;F\@=G+A=&F[
M('-PY+LN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M(@IM<V=S='(@(B(*(DYA;WIA:B!V>6UA>F&[('!O=;[M=F%T9;5S:^D@^F1A
M:F4@<')E('!O=;[M=F%T9;5A("5S/R!4^G1O(&]P97+A8VEU(&YE;6^^;F\@
M(@HB=G+A=&F[('-PY+LN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`B5G+A=&D@<W#DNR!68;EU('!O<VQE9&[Z(&%K8VEU(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B3V)N;W9INR(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.34*;7-G:60@(E)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")/8FYO=FF[(&5L96UE;G1Y
M(&1Y;F%M:6-KZ6AO(&UE;G4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B3V)N
M;W9INR!Z;V)R87IE;FEE('!O<G3A;'4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G=6SA<FYY(';]
M<F%Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S@*;7-G:60@(E)E;&%T
M:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(E!R96AL:6%D8>@@=GJ[86AO=B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("):
M;F]V=2!N8>CM=&&[(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G
M:60@(E)E;6%R:W,B"FUS9W-T<B`B4&]S=')E:'DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R
M(")6>F1I86QE;ND@<V5R=F5R>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E9Z9&EA;&5NX2!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D]D<W1RX6YINR(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E($)L;V-K(@IM<V=S='(@(D]D<W1RX6YINR!B;&]K(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B4F5M;W9E
M(&-O;'5M;B(*;7-G<W1R(")/9'-T<N%N:;L@<W3E<&5C(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M
M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B3V1S='+A;FF[(&9O<FWA=&]V86YI
M92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")2
M96UO=F4@<&%I<B(*;7-G<W1R(")/9'-T<N%N:;L@<.%R(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(D]D<W1RX6YINR!U;&^^96[]('-K<FEP="!Z(&1OZ&%S;NEH;R!P<FEEZ&EN
M:V$@;F$@<V5R=F5R:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS
M9W-T<B`B3V1S='+A;FF[(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N
M;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(D]D<W1RX6YINR!T96YT
M;R!B;V0@>B!D;VMU;65N='4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")/9'-T
M<N%N:;L@<&]UONUV871EM6$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(D]D<W1RX6YINR!P;W6^[79A=&6U83H@)7,B"@HC.B!L
M:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G
M<W1R(").82!P;[YI861A=FMU(&YE8F]L;R!M;[YNZ2!O9'!O=F5D8;LN($[A
M=G)A=&]V_2!K\V0@8VAY8GDZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO
M="!B92!F;W5N9"XB"FUS9W-T<B`B4&^^861O=F%N^B!S;'6^8G4@<V$@;F5P
M;V1A<FEL;R!NX6ISNRXB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O2&]R
M9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(")6(&MO;F9I9W5RX6-I:2`E<R!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA
M9&]V86[A('!O;&^^:V$@7"(E<UPB(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C8W
M."!L:6(O5D93+V9T<"YP:'`Z.#4P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<S
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5B!K;VYF
M:6=U<N%C:6D@5D93(&YI92!J92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@
M<&]L;[YK82!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E8@:V]N9FEG=7+A8VEI
M(&YI92!J92"Y<&5C:69I:V]V86[A('!OOF%D;W9A;N$@<&]L;[YK82!<(B5S
M7"(B"@HC.B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED
M(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")0;W9I;F[I('!O;&4B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,"!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")6>6UA>F&[(&9O<FUU;.%R
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E
M<V5T(%!A<W-W;W)D(@IM<V=S='(@(D]B;F]V:;L@:&5S;&\B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!0
M87-S=V]R9"(*;7-G<W1R(")/8FYO=FF[(%9AN64@:&5S;&\B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB
M"FUS9W-T<B`B3V)N;W9INR!P;W-L961N_2!D;W1A>B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L
M<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(E;]<VQE9&MY
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*
M;7-G<W1R(").X79R870@;F$@;F%S=&%V96YI82(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R
M9"(*;7-G<W1R("):861A:G1E(&YO=ND@:&5S;&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N
M:6]N(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(E9RX71INR!K;VYF:6=U<N%C:74B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E
M>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3F%S=&%V96YI82!R;WJY[7)E
M;NEH;R!T97AT;W;I:&\@961I=&]R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")(X61A;FMY(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P
M"FUS9VED(")2:6=H="(*;7-G<W1R(")6<')A=F\B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(DAL
M879IZ&MA('9P<F%V;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`V"FUS
M9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B2&]D;F]T>2!V<')A=F\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")6;&%S
M=&YO<W1I(%]R:6%D:V$N+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VQA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UU;G-K;R(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*;7-G:60@(E)O=&%T92`Q
M.#`B"FUS9W-T<B`B3W1OZ&F[(&\@,3@P(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R,0IM<V=I9"`B4F]T871E($QE9G0B"FUS
M9W-T<B`B3W1OZ&F[(':U879O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-PIM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(D]T;^AINR!V<')A=F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*
M;7-G<W1R(")6;&%S=&YO<W1I(')I861K82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P
M<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@<FEA9&MA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@
M(E)O=W,Z(@IM<V=S='(@(E)I861K>3HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R("+(:6%R>2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BR&EA<GD@
M<V$@>F]B<F%Z:6$@;65D>FD@=KEE=&O];6D@<FEA9&MA;6D@82!S=.5P8V%M
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L
M=6UN<R!O;FQY(@IM<V=S='(@(LAI87)Y('-A('IO8G)A>FEA(&EB82!M961Z
M:2!S=.5P8V%M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(LAI87)Y('-A('IO8G)A>FEA(&EB
M82!M961Z:2!R:6%D:V%M:2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*
M;7-G:60@(E)U;B(*;7-G<W1R(")3<'5S=&F[(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<VOA(&9E9&5RX6-I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@
M4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!K<GEP=&]G<F%F:6-K_2!P;V1P
M:7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E-P<N%V82!Z8;EI
M9G)O=F%NX2!P;VUO8V]U(%,O34E-12(*"B,Z(&QI8B](;W)D92]!=71H+W-A
M<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@875T96YT:69I:^%C:6$@;FEE(&IE
M(&1O<W1U<&[A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*
M;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4&]S:65L86YI92!335,B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*
M;7-G<W1R(")344P@4VAE;&PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W
M,@IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G
M<W1R(")344P@<'+M:V%Z('!R92!HM6%D86YI92!H;V1N]'0B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B
M4U-((@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(MI34$5#2"(*"B,Z
M(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")3
M7U%,(%-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B4V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M86EN="!(96QE;F$B"FUS9W-T<B`B4W;D=.$@2&5L96YA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")3
M86EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4W;D=/T@2VET=',@82!.
M979I<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4W;D=.$@3'5C
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(E-V+B!0:65R<F4@82!-:7%U96QO;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I
M;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-VY'3](%9I;F-E
M;G0@82!'<F5N861I;GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS
M9W-T<B`B5&5N(&ES=/T@<N%M96,@*%]S96QF*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A
M(@IM<V=S='(@(E-A;6]A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R
M(")386X@36%R:6YO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E
M(@IM<V=S='(@(E-A;R!4;VUE(&$@4')I;F-I<&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*
M;7-G<W1R(")3871E;&ET;OT@<&]S:WET;W9A=&6U(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U
M9&D@07)A8FEA(@IM<V=S='(@(E-A=61S:^$@07+A8FEA(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY"FUS9VED(")3879E(@IM<V=S='(@
M(E5L;[YINR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B
M56QOOFF[(%PB)7-<(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B56QO
MOFF[("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B
M4V%V92!/<'1I;VYS(@IM<V=S='(@(E5L;[YINR!N87-T879E;FEA(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"B)5
M;&^^:;L@=GEG96YE<F]V86[Z(&MO;F9I9W5RX6-I=2!A:V\@4$A0('-K<FEP
M="!D;R!D;^AA<V[I:&\@<')I9>AI;FMA(%;AN6AO("(*(G-E<G9E<F$N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG
M=7+A8VEA("5S(&)O;&$@=6QOOF5NX2XB"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3:W)I<'0@;F$@
M=7!G<F%D92!N87-T879E;NT@8F]L('5L;[YE;OT@9&\Z(%PB)7-<(BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I
M9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(D]J961I;F5LZ2!B^G)K
M>2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC
M92(*;7-G<W1R(")6961A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G
M:60@(E-E87)C:"(*;7-G<W1R(")(M6%D8;LB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R
M(")6>6BU863A=F'H92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.38R"FUS
M9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5GEB97)T92!S^F)O<GDB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@R"FUS9VED
M(")396QE8W0@82!D871E(@IM<V=S='(@(E9Y8F5R=&4@9.%T=6TB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@
M9W)O=7`@=&\@861D(@IM<V=S='(@(E9Y8F5R=&4@<VMU<&EN=2!N82!P<FED
M86YI92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@
M(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")6>6)E<G1E(&YO=NEH;R!V
M;&%S=&[M:V$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")6>6)E<G1E('-E<G9E
M<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")3
M96QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")6>6)E<G1E('!O=;[M=F%T
M9;5A(&YA('!R:61A;FEE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W,PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")6>6)E
M<G1E(':Y971K>2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C4P"FUS9VED
M(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B5GEB97)T
M92!VN65T:WD@:V]M<&]N96YT>2!DX71U;74B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<P"FUS9VED(")396QE8W0@86X@;V)J
M96-T(@IM<V=S='(@(E9Y8F5R=&4@;V)J96MT(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-`IM<V=I9"`B4V5L96-T(&YO;F4B
M"FUS9W-T<B`B6G)UN6F[(';]8F5R(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B
M(@HB5GEB97)T92!Z;F%K>2P@:W1O<ND@<&]T<F5B=6IE=&4L('H@;VMI96YO
M:R!N:;ZY:64N(%!O=&]M(&EC:"!M]+YE=&4@(@HB<VMO<.UR;W9ANR!A('9L
M;[YINR!Z('1E>'1O=NEH;R!P;[5A+B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R(")6>6)E<G1E(&]D9&6U;W9AZ"!V;R!F;W)MX71E(&3A='5M=3HB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T92!F;W)MX70@9.%T
M=6UU.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.B(*;7-G<W1R(")6>6)E<G1E(&ED96YT:71U+"!K=&]R^B!C:&-E=&4@
M>FUE;FF[.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED
M(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")6>6)E<G1E
M(&]D9&6U;W9AZ"!V;R!F;W)MX71E(.AA<W4Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(E9Y8F5R=&4@9F]R;>%T(.AA<W4Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN
M9R!F:65L9',N(@IM<V=S='(@(E9Y8F5R=&4@9'9E('IH;V1NZ2!P;VQI82XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E9Y8F5R=&4@<VD@9F%R96)N
M^B!S8VCI;74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9Y
M8F5R=&4@:F%Z>6LZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4&]S
M;&&[('-P<N%V=2!O('!R;V)LZ6UE(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(E!O<VQANR!335,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G
M86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R
M.B`B"FUS9W-T<B`B4V5N>F]R.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`W(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E;6)E
M<B(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@
M(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3<F)S:V\@82#(:65R
M;F$@:&]R82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S`R"FUS
M9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(E/I<FEO=ND@Z.US;&\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+:9&%J
M92!Z;R!S97)V97)A('/Z(&YE<W!RX79N92!A;&5B;R!N:64@<_H@9&]S='5P
M;NDN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED(")397-S:6]N
M($%D;6EN(@IM<V=S='(@(D%D;6EN:7-T<N%C:6$@<V5D96[M(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I
M;VX@240@97AP:7)E9"XB"FUS9W-T<B`B4&QA=&YO<[L@240@<V5D96YI82!V
M>7!RN6%L82XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I;VYS
M(@IM<V=S='(@(E-E9&5N:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q
M.`IM<V=I9"`B4V5T(@IM<V=S='(@(DUN;[YI;F$@:&]D;O1T(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A
M;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F
M;W)G970@:70N(@IM<V=S='(@(DYA<W1A=G1E(&UOOFYO<W1I(&YA(&]B;F]V
M96YI92!6X;EH;R!H97-L82!A:R!H;R!Z86)U9&YE=&4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M(@IM<V=S='(@(B(*(DYA<W1A=F5N:64@=GID:6%L96[]8V@@<V5R=F5R;W8L
M(&MU(&MT;W+];2!C:&-E=&4@<')I<W1U<&]V8;L@>B!6X;EH;R`B"B)P;W)T
MX6QU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B4V5T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O
M<'1I;VYS+B(*;7-G<W1R(")6>6)E<G1E(&IA>GEK+"#H87-O=OH@>O-N=2!A
M(&YA<W1A=F5N:6$@9.%T=6UU+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL
M(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB
M9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"B).87-T879E;FEE(&%P;&EK
MX6-I92!S</JYNV%N96H@<')I(+ET87)T92P@9F%R96)N96H@<V-HZ6UY+"!I
M;G1E<G9A;'4@(@HB;V)N;W9O=F%N:6$@<W1RX6YK>2!A(&EN_6-H('9L87-T
M;F]S=.T@>F]B<F%Z96YI82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<U"FUS9VED(")3971U<"(*;7-G<W1R(").87-T879E;FEE(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4_H@9&]S='5P
M;ND@<VMR:7!T>2!N82!U<&=R861E(&YA<W1A=F5N[2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D1O
M(/IV86AY('!R:6-HX61Z82!N:65K;[5K;R!L;VMA;.UT('!O;6]C;W4@<&%R
M86UE=')A.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H
M96QY(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B
M4VAO<'!I;F<B"FUS9W-T<B`B4VAO<'!I;F<B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R(")+<N%T:WD@<_IH<FXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`B36%J^B!S82!P<F4@=N3HN6EN=2!L:6YI
M96L@=GET=F]R:;L@<VMR871K;W;I(&MLX79E<WD_(@H*(SH@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B6F]B
M<F%Z:;LB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B
M"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N
M9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(EIO8G)A>FF[(')O>F1I96QY(&UE9'II('!RX79E('5L;[YE;F]U
M(&$@;F]V;W9Y9V5N97)O=F%N;W4@:V]N9FEG=7+A8VEO=2XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(DWA('-A('!R:2!P<FEH
M;.%S96[M('IO8G)A>FF[(.AA<R!P;W-L961NZ6AO('!R:6ALX7-E;FEA/R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(EIO8G)A>FF[(&UOOFYO<[L@
M;F$@<&]N96-H86YI92!O<FEG:6[A;'4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@P,@IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B6F]B<F%Z:;L@
M;N%S=')O:B!N82!V_6)E<B!F87)I96(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_(@IM<V=S='(@(EIO8G)A>FF[(&UE;G4@<')E(&]P97+A8VEE(',@=&%B
M=;5K86UI/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B
M"FUS9W-T<B`B6F]B<F%Z:;L@;65N=2`E<R!N82"U879E:B!S=')A;F4_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(EIO8G)A>FF[(&1I86SS9R!S('9L87-T;F]SNV%M
M:2!B=6YK>2!T86)UM6MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):;V)R87IINR!D:6%L\V<@
M<R!V;&%S=&YO<[MA;6D@=&%B=;5K>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO8G)A
M>FF[(&1I86SS9R!S('9L87-T;F]SNV%M:2!R:6%D:W4@=&%B=;5K>2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI(&]B<N%Z
M:W4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-PIM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`B6F]B<F%Z:;L@;F%H<F%NZ2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(E!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B4N%N;R!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B
M3F5S:_1R('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y
M(@IM<V=S='(@(EIRX;YK>2!V(&]K;VSM(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B6FUE;KEI
MNR(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<W-"!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDX-`HC
M.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C$P.#<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U
M="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B3F%J<')V(&UU<^UT92!Z;65N
MN6F[(&%L96)O('!R97-U;OJ[('-U<V5D;OT@8FQO:RAY*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R("):87)E9VES=')O=F&[('-A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")0;V1P:7,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG
M;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET;75S('!O9'!I<W4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P=7(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3`P(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Y
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0Q"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$Y(&QI8B](;W)D92]&;W)M
M+G!H<#HS,3$R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U
M(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM<V=S='(@
M(E9EM6MO<[LB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")0
M<F5S:V_H:;L@^F1ROF)U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M4VQO=F5N<VMO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=FEN
M<VMO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-30*;7-G:60@(E-N;W<B"FUS9W-T<B`B4VYEOF5N:64B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B4VYE:&]VX2!P<F5HX6YK82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4VYE:&]VZ2!P<F5HX6YK>2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H
M;W=E<G,@16%R;'DB"FUS9W-T<B`B4N%N;R!S;F5H;W;I('!R96CA;FMY(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G
M:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DYE<VOT<B!S;F5H;W;I
M('!R96CA;FMY(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@
M(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")(Y6)K82!S;F5H=3H@(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@(@IM<V=S='(@(DUN;[YS='9O('9O9'D@96MV:79A;&5N=&[I
M('-N96AU.B`B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
MJ6%L86WZ;F]V92!O<W1R;W9Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R
M(")3;VWA;'-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I
M9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")0:65S;F4@82!BX7-N92(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR.3$U"FUS9VED(")3;W)T(&]R9&5R('-E
M;&5C=&EO;B(*;7-G<W1R(")6_6)E<B!S;65R=2!T<FEE9&5N:6$B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-B!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S
M<R(*;7-G<W1R("):9')O:F]VX2!A9')E<V$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B2G6^;N$@069R:6MA(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#8*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3
M;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(DIUOF[A($=E;W)G:6$@
M82!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@
M2&5M:7-P:&5R92(*;7-G<W1R(")*=;YNX2!P;VQO9W6U82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(DUE9'IE<F$@
M;65D>FD@<W5S961N_6UI(&)U;FMA;6DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")-961Z97)A
M(&UE9'II(&]B<V%H;VT@82!O:W)A:F]M(&)U;FMY(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D]D9&6U;W9A
MZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R(")/9'-T=7`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T
M"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(D]D<W1U<"!A
M('9Y<&QN96YI92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G<W1R("*I<&%N:65L<VMO
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A
M;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*;7-G<W1R(")6;&^^
M96YI92"Y<&5C:>%L;GEC:"!Z;F%K;W8B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C
M96QL(@IM<V=S='(@(E)O>F1E;&F[(&)U;FMU(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L
M:70@8V]L=6UN(@IM<V=S='(@(E)O>F1E;&F[('-TY7!E8R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G
M:60@(E-P;&ET(')O=R(*;7-G<W1R(")2;WID96QINR!R:6%D;VLB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R
M("*I<&]R='DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<NT@3&%N
M:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`BJ71A
M;F1A<F1NZ2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B
M4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR-3DP(&QI8B](;W)D92]&;W)M+G!H<#HR-SDX"FUS9VED(")3
M=&%R="!Y96%R(@IM<V=S='(@(E!OZ&EA=&_H;OT@<F]K(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I
M;F-E(@IM<V=S='(@(JETX70@86QE8F\@<')O=FEN8VEA(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*
M;7-G<W1R(")3=&%V(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#0*;7-G
M:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D9O<FWA="!U;&^^96YI82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E
M970@061D<F5S<R(*;7-G<W1R(")">61L:7-K;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B4')EN6MR=&YU=.DB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B6F]Z;F%M
M(')ENV%Z8V]V(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G:60@
M(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(D]D<W1R
MX6YINR!D;VWI;G4@>B!A9')E<WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-3
M72(*;7-G<W1R("*I=/UL(%M#4U-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B3F4B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!O9'!R:67H:6YO:R!<(B5S7"(@;F5B;VP@;N%J9&5N_2XB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R(")0<F5D;65T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S
M-B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`B3V1O<VQANR(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y
M;W5R("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*
M(E!OOFEA9&%V:V$@;F$@<')I9&%N:64@7"(E<UPB(&1O('-Y<W3I;74@8F]L
M82!O9&]S;&%NX2X@3F5M]+YE=&4@<V$@(@HB<')I:&SA<VF[+"!K_6T@;F5B
M=61E(%9AN6$@<&^^:6%D879K82!S8VAVX6QE;N$N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R
M:7!T(@IM<V=S='(@(D1O;&[](&EN9&5X(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$P-"!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BVG-P96-H(@H*(SH@
M861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")0
M<FED86YI92!<(B5S7"(@9&\@<WES=.EM=2!B;VQO(/IS<&6Y;NDN(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B5GEM87IA;FEE(/ID86IO=B!Z;R!S>7-TZ6UU
M('!R92!P;W6^[79A=&6U82!<(B5S7"(@8F]L;R#Z<W!EN6[I+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S
M7"(N(@IM<V=S='(@(E9Y;6%Z86YI92!<(B5S7"(@8F]L;R#Z<W!EN6[I+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R(")6>6UA>F%N:64@7"(E<UPB('IO('-Y<W3I;74@8F]L;R#Z<W!E
MN6[I+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(D[A=G)A="!K=2!K;VYF:6=U<N%C
M:6D@8F]L(/IS<&6Y;OTN(%!R92!Z;V)R87IE;FEE('IM:65N('IN;W9U(&YA
MZ.UT86IT92`B"B)S='+A;FMU+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S
M<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("):
MX6QO:&$@:V]N9FEG=7+A8VEE(&)O;&$@=6QOOF5NX2XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E
M<RXB"FUS9W-T<B`B6N%L;[YN_2!K;VYF:6=U<F'H;OT@<_IB;W(@)7,@8F]L
M(/IS<&6Y;F4@=6QOOF5N_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB
M(@IM<V=S='(@(D%K='5A;&EZX6-I82!<(B5S7"(@8F]L82#Z<W!EN6[A+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W
M<F]T92`E<R(*;7-G<W1R("):X7!I<R`E<R!B;VP@^G-P9;EN_2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-U9&%N(@IM<V=S='(@(E-U9.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R
M>2(*;7-G<W1R(")3^FAR;B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV
M-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B5OUC:&]D('-L;FMA(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S
M='(@(EKA<&%D('-L;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-L;F7H;F\B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3
M=6YR:7-E(@IM<V=S='(@(E;]8VAO9"!S;&YK82(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B
M4W5N<FES92]3=6YS970B"FUS9W-T<B`B5OUC:&]D+WKA<&%D('-L;FMA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N
M<FES93H@(@IM<V=S='(@(E;]8VAO9"!S;&YK83H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@
M(EKA<&%D('-L;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B6N%P860@<VQN:V$Z("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*
M;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(DAO<F[](&EN9&5X(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*
M;7-G<W1R(")0;V1P;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B
M4W5R:6YA;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS
M9VED(")3=7)N86UE(@IM<V=S='(@(E!R:65Z=FES:V\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&$@2F%N
M($UA>65N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-V87II:G-K
M;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#4@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("*I=NED<VMO(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(E-W:71Z97)L86YD(@IM<V=S='(@(JEV86KH:6%R<VMO(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T
M960B"FUS9W-T<B`B6N%Z;F%M>2!O('-Y;F-H<F]N:7KA8VEI('9Y;6%Z86[I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,
M(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&QI8B](;W)D92]344PO2V5Y=V]R9',N
M<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E-Y;G1A:W1I8VOA(&-H>6)A('8@<&]D;6EE;FMA8V@@:+5A9&%N
M:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3
M_7)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D+Z<FMA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M4W1O
M<FT@86YD(%=I;F1Y(@IM<V=S='(@(D+Z<FMA(&$@=F5T97)N;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4
M+5-T;W)M<R(*;7-G<W1R(")"^G)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*
M;7-G<W1R(")2X6YO(&+Z<FMY(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H
M<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B!S^F)O<B(*"B,Z
M(&QI8B](;W)D92]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G
M<W1R(")486)UM6MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*
M;7-G<W1R(")6;&%S=&YO<W1I('1A8G6U:WDB"@HC.B!L:6(O2&]R9&4O1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B
M5FQA<W1N;W-T:2!T86)UM6MY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A
M;B(*;7-G<W1R(")486EW86XB"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM
M<V=S='(@(E1A:7=A;BP@<')O=FEN8VEA(,CM;GDB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II
M:VES=&%N(@IM<V=S='(@(E1A9+YI:VES=&%N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZX6YI82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G
M:60@(E1A<F=E=#HB"FUS9W-T<B`B0VEEM3HB"@HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G
M:60@(E1A<VMS(@IM<V=S='(@(MIL;VAY(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T
M<B`B5&5L96;S;FYE(.CM<VQO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1E<&QO
M=&$@>F$@<&]S;&5D;OH@:&]D:6YU.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B5&5P;&]T82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E
M;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5P;&]T83H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M96UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S
M='(@(E1E<&QO=&$\8G(@+SXH)7--87@E<R\E<TUI;B5S*2`F9&5G.R5S(@H*
M(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HV.#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BJ6%B
M;/-N82!<(B5S7"(@;F5B;VQA(&[A:F1E;N$N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E-P<N%V82"Y86)L\VXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-0IM<V=I9"`B5&5X="(*;7-G
M<W1R(")497AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I
M9"`B5&5X="!/;FQY(@IM<V=S='(@(DEB82!T97AT(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B
M5&5X="!A;&EG;B(*;7-G<W1R("):87)O=FYA;FEE('1E>'1U(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B
M5&5X='1O<"(*;7-G<W1R(")497AT(&AO<F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M("*I="(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")4:&%I
M("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4:&%I;&%N9"(*;7-G
M<W1R(")4:&%J<VMO(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@T,`IM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M4F]ZN>UR96YI92!&5%`@;FEE(&IE(&1O<W1U<&[I+B(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3,S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<
M(B5S7"(B"FUS9W-T<B`B26YT96=RX6-I82!(;W)D92]+;VQA8B!N97!O9'!O
M<G5J92!<(B5S7"(B"@HC.B!L:6(O3F5T+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM
M<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB
M"FUS9W-T<B`B24U34"!ZX7IN86T@<V$@;F5P;V1A<FEL;R!U;&^^:;LN(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I
M;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM
M<V=S='(@(E1R:65D82!-86EN=&5N86YC93HZ('-A(&YE;F'H[71A;&$@^G-P
M9;EN92(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*
M;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG
M+B(*;7-G<W1R(")/:VYO(',@;F%S=&%V96YI86UI('-A('IA='9O<FEL;RX@
M2V]N:65C+B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3@Y(&QI8B](;W)D
M92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M<RYP:'`Z,C$Q"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D92]097)M<RYP:'`Z,C,T
M(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T<N%T;W(@;75S[2!N86MO
M;F9I9W5R;W9ANR!P97)M86YE;G1N_2!B86-K96YD('!R92!0<N%V82P@86L@
M8VAC971E("(*(G!O=;[M=F&[(%!RX79A+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DEB82!S<&]D;N$@<W1R86YA(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B
M(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E
M+B(*;7-G<W1R("(B"B))1"#H[7-L;R!K;VYT86MT=2!N96)O;&\@N7!E8VEF
M:6MO=F%NZ2P@8F]L;R!P;VYE8VAA;ND@<'+A>F1N92!A;&5B;R!N96)O;&\@
M(@HB;N%J9&5NZ2!V(&1A=&%BX7IE+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(DMO;G1A:W0@8F]L(/IS<&6Y;F4@=FQOOF5N_2!D;R!6X;EH;R!A9')E<^%R
M82XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B
M"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B).
M82!O=F5R96YI92!P;V1P[7-A;F5J('-P<N%V>2!J92!P;[YA9&]V86[](&]D
M9&5L96[](&)L;VL@<R!01U`@<&]D<&ES;VTN(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R
M("(B"B))1"!Z;WIN86UU('!R[6IE;6-O=B!B=>\@;F5B;VQO(+EP96-I9FEK
M;W9A;NDL(&%L96)O(&)O;&\@<&]N96-H86[I('!RX7ID;F4@(@HB86QE8F\@
M;F5B;VQO(&[A:F1E;ND@=B!D871A8N%Z92XB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DYE8F]L('5RZ&5N
M_2!Z;WIN86T@<'+M:F5M8V]V+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP:'`Z
M,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@
M<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("*I:69R;W9A;FEE('9Y
MOF%D=6IE(&)E>G!EZ&[I('!R:7!O:F5N:64@*&AT='!S*2XB"@HC.B!L:6(O
M2&]R9&4N<&AP.C$W-R!L:6(O2&]R9&4N<&AP.C4Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N(@IM<V=S='(@(E/Z8F]R("5S(&)Y(&UA;"!O8G-A:&]V8;L@;F%S=&%V
M96YI92`E<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$W,"!L:6(O2&]R9&4N<&AP
M.C4P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")3^F)O<B`E<R!B
M>2!M86P@;V)S86AO=F&[(&YI96MT;W+I(&YA<W1A=F5N:6$@)7,N(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HR,C,*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B
M92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(EID<F]J;W;](&$@8VEE
MM6]V_2!S^F)O<B!M=7-I82!B>;L@;V1L:;ENZ2XB"@HC.B!L:6(O2&]R9&4O
M1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82XB"FUS9W-T<B`B4_IB;W(@;F5O8G-A:&]V86P@OFEA9&YE(/ID86IE+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED
M(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R(").87-L961U:OH@:&QA=FGH
M:WD@=&5J=&\@<W!RX79Y('9O(&9O<FWA=&4@;65S<V%G92]R9F,X,C(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM
M<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+B(*;7-G<W1R("(B"B)#96QO;V)R87IO=FMO=OT@<F6^:6T@<W#T<V]B=6IE
M('!R;V)LZ6UY('8@26YT97)N970@17AP;&]R97)I(&MV]&QI(&-H>6+A;2`B
M"B)P<F5H;&EA9&'H82P@:W1O<ND@<V$@;N%M(&YE<&]D87)I;&\@;V+M<[LN
M($WTOG4@<V$@<')E:F%V:;L@;F5S<'+A=FYY;2`B"B)Z;V)R87IE;NUM+"!C
M:/UB86KZ8VEM:2!F=6YK8VEA;6D@961I=&]R82!A+V%L96)O(&[A:&]D;OUM
M:2!PX61M:2`B"B)P<F5H;&EA9&'H82X@06L@:F4@5N&Y('-Y<W3I;2!7:6YD
M;W=S(#EX+"!J92!V9;5M:2!P<F%V9&5P;V1O8F[I+""^92!S82`B"B)Z;V)R
M87KM(&-H>6)A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&$@8G5D971E
M(&UU<VEENR!R9;ET87)T;W9ANR!P;^CM=&'H+B(*(EQ<;EQ<;E9A<F]V86QI
M('-M92!6X7,N(%-T;&'H=&4@<')O<^UM($]+(&%K(&YA;WIA:B!C:&-E=&4@
M<&]UOFF[(&5D:71O<B!V("(*(F-E;&]O8G)A>F]V:V]V;VT@<F6^:6UE+B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(DED96YT:71A(%PB)7-<(B!B;VQA('9Y;6%Z86[A+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G
M:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(DEB82"U87;A
M('-T<F%N82(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$U-PIM<V=I
M9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B
M92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(E1R
M:65D82!#<GEP=%]P9W`Z.B!P;W1R96)U:F4@<&]Z;F&[('5M:65S=&YE;FEE
M('!R;V=R86UU($=N=5!'+B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@
M;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P
M;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S
M86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB
M4W!RX79A(&]D;W-L86[A("5S('!R92`E<R!S('!R961M971O;2!<(B5S7"(@
M8F]L82!Z;V)R87IE;N$N7&XB"B).965X:7-T=6IE(':Y86L@>N%R=6MA+""^
M92!S<'+A=F$@8F]L82!P<F7H[71A;N$@86QE8F\@<&]C:&]P96[A+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B
M365N;RP@:W1O<ND@<V$@;>$@<&]UOFF[('!R:2!L:6YK;W9A;NT@;F$@<W1R
MX6YK=2!N82!P[7-A;FEE('-P<N%V("(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z
M-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R
M:6,N(@IM<V=S='(@(E!OZ&5T('!O;.T@;75S[2!B>;L@Z.US;&\N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+B(*;7-G<W1R(")4<FEE9&$@2&]R9&5?0W)Y<'1?<VUI
M;64Z.B!V>;YA9'5J92!M;V1U;"!O<&5N<W-L+B(*"B,Z(&QI8B](;W)D92]0
M<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F
M97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*
M;7-G<W1R("(B"B).87-T879E;FEE(%PB)7-<(B!S82!N97!O9&%R:6QO('5L
M;[YINRP@<')E=&^^92!J96AO(/ID86IE('!R96MR8>AU:OH@(@HB;6%X:6WA
M;&YU('!O=F]L96[Z('9EM6MO<[LB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N
M<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB4')O
M9W)A;2!P;W6^[79A;OT@;F$@>F]B<F%Z96YI92!T;VAT;R#Z9&%J;W;I:&\@
M='EP=2`H)7,I(&YE8F]L(&[A:F1E;OTN(@H*(SH@;&EB+T9I;&4O0U-6+G!H
M<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@
M<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B6FYA:R!C:73A8VEE(&UU<^T@
M8GF[(&IE9&5N('IN86LN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B26)A('!R87;A(&$@M6%VX2!S=')A
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS
M9W-T<B`B26)A('!R87;A('-T<F%N82(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z
M-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(D]D9&6U;W9AZ"!M=7/M(&)YNR!J961E;B!Z
M;F%K+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E
M;&5T960N(@IM<V=S='(@(E-E<G9E<B!<(B5S7"(@8F]L('9Y;6%Z86[]+B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*
M;7-G<W1R(")397)V97(@7"(E<UPB(&)O;"!U;&^^96[]+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(JYI
M861O<[L@;R!P<FEH;.%S96YI92`E<R!B;VQA('9Y;6%Z86[A+B(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I
M9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(JEP96-I9FEK;W9A
M;OT@<FEA9&]K(&YE97AI<W1U:F4N(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C$W
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E
M<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$;^AA<V[]('/Z8F]R(%PB
M)7-<(B!N965X:7-T=6IE+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S`P
M"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H
M92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(EIA9&%N_2!T97AT(&YI
M92!J92!R;W9N86O](&%K;R!T97AT(&YA(&]B<F%Z;W9K92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS
M9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("))
M8F$@:&]R;N$@82!S<&]D;N$@<W1R86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O
M<"!S:61E(&]N;'DB"FUS9W-T<B`B26)A(&AO<F[A('-T<F%N82(*"B,Z(&QI
M8B](;W)D92]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(").
M86AR86[I(/ID86IE('-A(&]D('!R961C:.%D>F%J^F-E:&\@:W)O:W4@<W1R
M871I;&DN(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-C(@;&EB+TAO
M<F1E+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B3F%H<F%N_2!S^F)O<B!S
M82!N97!O9&%R:6QO('5L;[YINRXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q,`IM
M<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D)L;VL@=V5A=&AE<BYC;VT@;FEE(&IE(&1O<W1U<&[]+B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(E!R:67H:6YO:R!TZ6T@7"(E<UPB(&YE8F]L(&[A:F1E;OTN(@H*(SH@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N
M;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`BKFEA9&YE(&YA<W1A=F5N
M:6$@;FEE('/Z(&1O<W1U<&[I+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("*N:6%D;F4@86QT97)N
M873M=FYE(.AA<W1I(&YE;6^^;F\@>F]B<F%Z:;L@=B!T96QE('-P<N%V>2XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES
M(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO
M=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB5B!T;VUT
M;R!P;VQI(&IE('!R[6QIN2!V9;5A('IN86MO=BX@6F%D86QI('-T92`E<R!Z
M;F%K;W8[(&UU<^UT92!Z861ANR!M96YE:B`B"B)A:V\@)7,N(@H*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@<')I9.%V
M86[M(%PB)7-<(B!D;R!S>7-TZ6UU.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@<')I(&]D<W1R8?)O=F%N
M[2!P;W6^[79A=&6U<VO]8V@@^F1A:F]V(%PB)7-<(B!Z;R!S>7-TZ6UU.B`B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P<FD@;V1S=')A\F]V
M86[M(%PB)7-<(B!Z;R!S>7-TZ6UU.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@<')I
M(&%K='5A;&EZX6-I:2!<(B5S7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N(@IM<V=S='(@(E9Y<VMY=&]L('-A('!R;V)LZ6T@<R!N86ARX79A;NUM
M('/Z8F]R=3H@KFEA9&5N("5S(&YE8F]L(&YA:')A;OTN(@H*(SH@;&EB+TAO
M<F1E+T)R;W=S97(N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ
M92`H)60@8GET97,I+B(*;7-G<W1R("(B"B)6>7-K>71O;"!S82!P<F]B;.EM
M(',@;F%H<N%V86[M;2!S^F)O<G4Z("5S(&)O;"!VY.BY[2!A:V\@;F%J=N3H
MN>T@<&]V;VQE;OT@(@HB;&EM:70@*"5D(&)A:G1O=BDN(@H*(SH@;&EB+TAO
M<F1E+T)R;W=S97(N<&AP.CDQ-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R(")6>7-K
M>71O;"!S82!P<F]B;.EM(',@=6ML861A;NUM('/Z8F]R=3H@)7,@8F]L(&YA
M:')A;OT@;&5N(.AI87-T;^AN92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B3F%S=&%L82!C
M:'EB82!P<FD@>F]B<F%Z;W9A;NT@=&5J=&\@Z&%S=&D@<W!RX79Y(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(DYA
M<W1A;&$@8VAY8F$@<')I(&EM<&]R=&4@^F1A:F]V(&\@:V]N=&%K=&4N(@H*
M(SH@;&EB+TAO<F1E+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S
M='(@(DYA<W1A;&$@8VAY8F$@<')I(&EM<&]R=&4@^F1A:F]V(&E#86QE;F1A
M<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@HB3F%S=&%L82!C:'EB82!V(&MO;F9I9W5R8>AN;VT@9F]R;75L
MX7)I+B!0<F%V9&5P;V1O8FYE('-T92!N979Y<&QN:6QI("(*(G!OOF%D;W9A
M;ND@<&]L92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*
M(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3F%S=&%L82!C:'EB82!P
M<FD@=GEK;V[A=F%N[2!U<NAE;F5J(&9U;FMC:64@861R97/A<F$N(%!R;W/M
M;2!S:_IS=&4@=&\@(@HB;F5S:_1R+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B).87-T86QA(&-H>6)A('!R:2!A:W1U
M86QI>N%C:6D@9&5T86EL;W8@:V]N=&%K='4N(%!R;W/M;2!S:_IS=&4@=&\@
M;F5S:_1R+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3F%S=&%L
M82!C:'EB82!P<FD@86MT=6%L:7KA8VEI('IO>FYA;74@<'+M:F5M8V]V+B!0
M<F]S[6T@<VOZ<W1E('1O('IN;W9U+B(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(E1E;G1O
M($E-05`@<V5R=F5R(&YE<&]D<&]R=6IE('ID:66U86YI92!P<FEEZ&EN:V]V
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R(")4;W1O('!R879D97!O9&]B;F4@;FEE(&IE('!L871N
M_2!A<F-H[78@<F%R+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED('II<"!F:6QE+B(*;7-G<W1R(")4;W1O('!R879D97!O9&]B;F4@;FEE
M(&IE('!L871N_2!A<F-H[78@>FEP+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3,T"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B5&]T;R!P<F%V9&5P;V1O8FYE(&YI
M92!J92!P;&%T;ND@Z.US;&\@:V%R='DN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E
M;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(E1E;G1O(&]V;.%D8>@@=6UOOO)U
M:F4@<&]S:65L86YI92!S<'+A=B!C97H@8G+A;G4@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!P;VUO8V]U($A45%`@05!)(@H*(SH@
M;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*(E1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@
M<&]S:65L86YI92!S<'+A=B!C97H@8G+A;G4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@(@HB<&]M;V-O=2!(5%10($%022(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)496YT;R!O=FSA9&'H('5M;[[R=6IE
M('!O<VEE;&%N:64@<W!RX78@8V5Z(&)RX6YU('-M<S)E;6%I;"`H:'1T<#HO
M+R(*(G-M<S)E;6%I;"YC;VTI('!O;6]C;W4@2%144"!!4$DB"@HC.B!L:6(O
M3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU4
M4"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+B(*;7-G<W1R("(B"B)496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE
M;&&[('-P<N%V>2!C97H@4TU44"!C97H@8G+A;G4@5F]D869O;F4@271A;'D@
M(@HB*&EB82!N82#H[7-L82!6;V1A9F]N92DN(%9YOF%D=6IE(&4M;6%I;&]V
M_2#ZZ&5T(%9O9&%F;VYE($ET86QY("AH='1P.B\O(@HB=W=W+C$Y,"YI="DN
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`V,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y,`HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X-B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(V,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P.2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30P,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,34V
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DV,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P.0HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C`S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C$U,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U
M-`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T-"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$R-@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S(Y-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@P,R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S@Q,0IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB"FUS9W-T<B`B5&]T;R!P;VQE(&IE('!O=FEN;NDN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B5&]T;R!P;VQE(&WTOF4@;V)S
M86AO=F&[(&EB82#H[7-L82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0R
M,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B5&]T;R!P;VQE(&WTOF4@;V)S86AO
M=F&[(&EB82#H[7-L82!A(&1V;VIB;V1K=2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B5&]T;R!P;VQE(&WTOF4@;V)S86AO
M=F&[(&EB82!O<VUIZ&MO=ND@:&]D;F]T>2XB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@
M;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B
M5&]T;R!P;VQE(&UU<^T@8GF[('IO>FYA;2#H[7-E;"!O9&1E;&5N_6-H(.AI
M87)K;W4@86QE8F\@;65D>F5R;W4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(E1O=&\@<&]L92!M=7/M(&)YNR!P;&%T;ND@Z.US;&\N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,C4*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB
M5&]T;R!P;VQE(&UU<^T@;V)S86AO=F&[(&OS9"!F87)B>2!V(+EE<W1NX7-T
M:V]V;VT@9F]R;>%T92!21T(L(&YA<'+M:VQA9"`B"B(G(S$R,S1A9B<N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V-0IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")496YT;R!F;W)M
M=6SA<B!UOB!B;VP@<W!R86-O=F%N_2XB"@HC.B!T96UP;&%T97,O:&5L<"]A
M8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*
M;7-G<W1R(")4;W1O(&IE("5S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)4
M;W1O(&IE(&]B:F5K="!+;VQA8B!'<F]U<'=A<F4N(%!R92!Z;V)R87IE;FEE
M('1O:'1O(&]B:F5K='4@<&]T<F5B=6IE=&4@92TB"B)M86EL;W;I:&\@:VQI
M96YT82P@:W1O<OT@<F]Z=6UI92!F;W)MX71U($MO;&%B($=R;W5P=V%R92X@
M4')E('IO>FYA;2`B"B)T86O]8VAT;R!K;&EE;G1O=B!N87:Y=.UV=&4@<')O
M<^UM("5S(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB
M"FUS9W-T<B`B(@HB5.%T;R!S<'+A=F$@8F]L82!N87#M<V%NX2!V(&EN96H@
M86MO(%9A;6D@<&]UONUV86YE:B!Z;F%K;W9E:B!S861E("@E<RDN(@H*(SH@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")4;W1O(.CM<VQO(&UU
M<^T@8GF[(&YA:FUE;F5J(#$N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V=Z
M:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B5&5N=&\@<V5R=F5R(&YE
M9&]KX;YE(&1E:V]M<')I;6]V8;L@<_IB;W)Y('II<"!A(&=Z:7`N(@H*(SH@
M;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#(*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B4WES=.EM(&IE
M(&UO;65N=.%L;F4@9&5A:W1I=F]V86[]+B(*"B,Z(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N(@IM<V=S='(@(E3A=&\@:&]D;F]T82!M=7/M(&)YNR#H[7-E;&[A+B(*
M"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@
M(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<B"FUS9W-T<B`B5&]T;R!O:VYO(&UU<^T@8GF[('IA=F]L86[I('H@
M;VMN82!.87-T879E;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")(<FUE;FEE
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC
M:V5T<R(*;7-G<W1R(")4:6-K971S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(T,CD@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(LAA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B5&EM92!4<F%C
M:VEN9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`B1F]R;>%T(.AA<W4B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4S-0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B5OUB
M97(@Z&%S=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(E1I;6]R
M+4QE<W1E(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S
M='(@(E1I='5L;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@
M(DYA9'!I<R`H8G5B;&EN;W;](';]<&ES*3HB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B4')E
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,0IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB4')E(';]8F5R('9I86-E<OUC:"!P
M;VQOOFEE:R!D<KYT92!P;^AA<R!K;&EK86YI82!K;.%V97-U($-O;G1R;VP@
M*%!#*2!A;&5B;R`B"B)#;VUM86YD("A-86,I+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D1N
M97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B4')E<&[Z
MNR!Z;V)R87IE;FEE('ID<F]J;W;I:&\@:_-D=2!(5$U,(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R
M(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P
M,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B6F%J=')A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R
M(")6<F-H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")6<F-H
M;OT@<N%M96,@*%]T;W`I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B4')E:VQA9'DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D(&$@
M5&]B86=O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W.30*;7-G:60@(E1R
M=64@;W(@9F%L<V4B"FUS9W-T<B`B4')A=F1A(&%L96)O(&YE<')A=F1A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B570B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S
M='(@(E1U;FES:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R96-K
M;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")4=7)K:7-H
M("A)4T\M.#@U.2TY*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T
M86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS(&$@0V%I8V]S(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM
M<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&QI8B](;W)D92]#
M3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@
M(EIA9&%J=&4@5F&Y=2!V;[5B=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N
M5BX@:6YD97@Z("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS
M9W-T<B`B55),(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(E523"!6X;EH;R!S:W)I<'1U('!R92!S<'+A
M=G4@;R!D;W)UZ&5N[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*
M;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A
M:6YE(@IM<V=S='(@(E5K<F%J:6YA(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HT
M,38*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!U<VMU=&_H;FF[('!R[7-T=7`@:R!61E,@
M861R97/A<G4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM
M<V=I9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"XB"FUS9W-T<B`B(@HB3F5P;V1A<FEL;R!S82!P<FED
M8;L@[V%LN6EE(&EN9F]R;>%C:64@;R!P;W6^[79A=&6U;W9I('!R:2!R96=I
M<W1RX6-I:2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A('IM96YINR!P
M<N%V;R!P<F4@5D93('/Z8F]R(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,X.2!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z;65N:;L@<'+A=F\@
M<')E(%9&4R!S^F)O<B`E<R\E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S<U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N
M(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>FUE;FF[(&YA("5S+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@<VMO;G1R;VQO=F&[('9EM6MO<[L@<_IB;W)U(%PB)7-<(BXB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8Y,B!L:6(O5D93+W-Q;"YP:'`Z,3`Q
M.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@<VMO;G1R;VQO=F&[('9EM6MO<[L@<_IB
M;W)U(%PB)7,O)7-<(BXB"@HC.B!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C0S
M.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B3F5P;V1A<FEL;R!S82!S<&]J:;L@<R!344P@<V5R=F5R;VTN(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C@U.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=VET:"!34TPN(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<W!O:FF[('!O
M;6]C;W4@4U-,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C(Y(&QI8B]61E,O
M9FEL92YP:'`Z,C,T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P-`HC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W
M"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B3F5P
M;V1A<FEL;R!S82!S:V]P[7)O=F&[(%9&4R!S^F)O<BXB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@=GET=F]R:;L@5D93(&%D<F5SX7(@7"(E<UPB+B(*"B,Z(&QI8B]6
M1E,O9FEL92YP:'`Z,S4X(&QI8B]61E,O;75S<6PN<&AP.C(U."!L:6(O5D93
M+W-Q;%]F:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!6
M1E,@861R97/A<BXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&]D87)I
M;&\@<V$@=GET=F]R:;L@5D93('/Z8F]R+B(*"B,Z(&QI8B]61E,O<VUB+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V
M;W)INR!61E,@<')I9>AI;F]K(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C(V.0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>71V;W)INR!P<N%Z9&YY(%9&
M4R!S^F)O<BXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-B!L
M:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@9&5K
M;VUP<FEM;W9ANR#Z9&%J92XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z,C(X(&QI
M8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@7"(E<UPB+"!A9')E
M<^%R(&YI92!J92!P<N%Z9&YY+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DYE<&]D
M87)I;&\@<V$@=GEM87IANR!<(B5S7"(Z("5S+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z,S,U(&QI8B]61E,O<W%L+G!H<#HS.34@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S$Q"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z8;L@
M)7,L(&%D<F5SX7(@;FEE(&IE('!RX7ID;GDB"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@<F5K=7)Z[79N92!V>6UA>F&[(%9&4R!A
M9')E<^%R+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S0Q(&QI8B]61E,O;75S
M<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!O
M9&%R:6QO('-A('9Y;6%Z8;L@5D93(&%D<F5SX7(N(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM
M<V=S='(@(DYE<&]D87)I;&\@<V$@=GEM87IANR!61E,@861R97/A<CH@)7,N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!S^F)O<B!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]F:6QE+G!H<#HS,#<@;&EB+U9&4R]S<6PN<&AP.C(Y,2!L:6(O
M5D93+VUU<W%L+G!H<#HQ-C<*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3@P(&QI
M8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3$*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R(").97!O9&%R:6QO('-A('9Y;6%Z
M8;L@5D93('/Z8F]R+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!V>6UA>F&[(%9&4R!P<FEE
MZ&EN;VL@7"(E<UPB+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HT,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+B(*;7-G<W1R(").97!O9&%R:6QO('-A(')E:W5R>NUV;F4@=GEM
M87IANR!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX,C,*;7-G:60@
M(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@=7+H:;L@86MT=>%L;GD@861R97/A<BXB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").97!O
M9&%R:6QO('-A('II<W1INR!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71E+B(*
M"B,Z(&QI8B].970O24U34"YP:'`Z-#,W(&QI8B].970O24U34"]!=71H+G!H
M<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DYE;6^^;ND@;F%H<F&[(&1E
M9FEN[6-I=2`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P,"!L:6(O5D93
M+V9I;&4N<&AP.C(P-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-S0*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F5S=6[ZNR!61E,@
M<_IB;W(N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.CDS(&QI8B]61E,O<VUB+G!H
M<#HQ,#8@;&EB+U9&4R]S;6(N<&AP.C8U,@HC.B!L:6(O5D93+V9T<"YP:'`Z
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@5D93
M('/Z8F]R(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(X,2!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30Q
M"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB
M"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B!N82!Z
MX7!I<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O9FEL92YP
M:'`Z,3,T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!O='9O
M<FF[(%9&4R!S^F)O<BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z
M+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+B(*;7-G<W1R(").97!O9&%R:6QO('-A(&]T=F]R:;L@:V]M<')I;6]V
M86[](&%R8VCM=BXB"@HC.B!L:6(O5D93+G!H<#HX-34*;7-G:60@(E5N86)L
M92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S
M='(@(DYE<&]D87)I;&\@<V$@<')EZ.UT8;L@5D93('/Z8F]R("AF=6YK8VEA
M(&9I;&5S:7IE*"D@>FQY:&%L82DN(@H*(SH@;&EB+U9&4RYP:'`Z.#@V"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F
M86EL960I+B(*;7-G<W1R(").97!O9&%R:6QO('-A('!R9>CM=&&[(%9&4R!S
M^F)O<B`H9G5N:V-I82!G971&:6QE4VEZ92@I('IL>6AA;&$I+B(*"B,Z(&QI
M8B](;W)D92]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA
M8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E
MZ.UT8;L@<_IB;W(Z(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-S,*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F5P;V1A<FEL;R!S82#H[71ANR!A9')E<^%R('9F<W)O;W0N(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3`T"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(").97!O9&%R:6QO('-A('!R96UE
M;F]V8;L@)7,@;F$@)7,Z(&-I9;5O=OT@<')I9>AI;F]K('6^(&5X:7-T=6IE
M(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&]D87)I;&\@
M<V$@<')E;65N;W9ANR!61E,@861R97/A<BXB"@HC.B!L:6(O5D93+W-Q;"YP
M:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E
M;65N;W9ANR!61E,@861R97/A<CH@)7,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP
M.C(W,2!L:6(O5D93+V9T<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").
M97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C8Q-"!L:6(O5D93+VUU<W%L+G!H<#HR,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RXB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&
M4R!S^F)O<B`E<R\E<RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S(V(&QI8B]6
M1E,O;75S<6PN<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HT-3(*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,P
M.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B
M3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!S^F)O<BXB"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O
M(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<W!U<W1I
MNR`G;6MI<V]F<R<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R
M9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@<')E;&^^:;L@=&5N
M=&\@9&]K=6UE;G0@5V]R9"(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ-30@;&EB
M+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!O9&%R:6QO
M('-A('IA<.US8;L@5D93('/Z8F]R(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C$X,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5P;V1A<FEL;R!S82!Z87#M<V&[
M(%9&4R!S^F)O<B`H9G5N:V-I82!C;W!Y*"D@>FQY:&%L82DN(@H*(SH@;&EB
M+U9&4R]F:6QE+G!H<#HR.#4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DYE<&]D87)I;&\@<V$@>F%P[7-A
MNR#Z9&%J92!61E,@<_IB;W)U+B(*"B,Z(&QI8B]61E,N<&AP.C@V,0IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X
M8V5E9&5D+B(*;7-G<W1R(").97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z
M8F]R+"!K=O-T82!J92!P<F5K<F_H96[A+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*
M;7-G<W1R(")0;V3H:6%R:VYU=.DB"@HC.B!T96UP;&%T97,O<')E9G,O96YD
M+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B6G)UN6F[('IM
M96YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M6G)UN>T@<&]S;&5D;OH@86MC:74B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(DYE;^AA:^%V86[A(&]D<&]V9>\@
M;V0@<V5R=F5R82!P;^AA<R!S<&]J96YI83H@(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S0Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-S@@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S
M='(@(DYE;^AA:^%V86[A(&]D<&]V9>\@;V0@<V5R=F5R82!N83H@(@H*(SH@
M;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@
M(E5N9FEL960B"FUS9W-T<B`B3F5N87-T879E;N$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")3<&]J
M96[I(&%R86)S:^D@96UI<N%T>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`B5F6U:^$@0G)I=.%N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A
M=&5S(@IM<V=S='(@(E-P;VIE;ND@N73A='D@06UE<FEC:^DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(DIE9&YO
M=&MY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(").97INX6UE(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M3F5Z;N%M92!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(DYE>F[A
M;64@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5;FMN;W=N(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R(")";VQA('IA9&%NX2!N97!L871NX2!L
M;VMA;&ET82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`B3F5Z;N%M92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*
M;7-G<W1R(")/9'-T<N%N:;L@;&EN:W4@>B!A:W1UX6QN96AO(&5L96UE;G1U
M(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#$*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B3F5P;VUE;F]V86[A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S
M<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B).97!R:79I;&5G;W9A;ND@
M<VMR:7!T>2!N96UA:OH@>B!B97IP9>AN;W-T;OUC:"!D]'9O9&]V('!R[7-T
M=7`@:R!V;[5BX6T@(@HB5GES=')I:&[ZNR]+;W#M<F]V8;LO5FQOOFF[+B!+
M;&EK;FET92!N82!/2R!A('IO8G)A>NT@<V$@=&5C:&YI8VOA("(*(FEN9F]R
M;>%C:6$@;F$@<W1RX6YK92!M;WII;&QA+F]R9RP@:W1O<N$@5N%S(&EN9F]R
M;75J92P@86MO('5M;[YN:;L@<VMR:7!T=2`B"B)P<NUS='5P(&L@<V-H<N%N
M:V4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B3V1S='+A
M;FF[(&9A<F)U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HY,C<*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO
M;B(*;7-G<W1R(").97!O9'!O<F]V86[I(')O>KGM<F5N:64B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(D%K='5A;&EZX6-I
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%K='5A;&EZ
M;W9ANR`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D%K='5A;&EZ;W9ANR!P
M;W6^[79A=&6U82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P
M"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R
M(")!:W1U86QI>N%C:6$@7"(E<UPB(&)O;&$@^G-P9;ENX2XB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@
M9&5L971E9"XB"FUS9W-T<B`B4VMR:7!T(&YA('5P9W)A9&4@8F]L('9Y;6%Z
M86[]+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM
M<V=S='(@(DYA:')ANR(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*
M;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T
M;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")6N65T:WD@<_IB;W)Y(',@:V]N9FEG
M=7+A8VEO=2!B;VQI(&YA:')A;ND@;F$@<V5R=F5R+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G
M:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B5F6U:^D@;&%T:6YS
M:^D@<.US;65NX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B5F6U:^D@<NUM<VME(.CM<VQI8V4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!L:6(O2&]R9&4O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B4&]UOFF[(&%K='7A;&YE.B`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@
M(E5S92!34TPB"FUS9W-T<B`B4&]UOFF[(%-33"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES
M(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(E!O=;YI=&4@
M=B!P<NUP861E+""^92!J92!M96YO+VAE<VQO(&]D;&FY;ND@<')E($E-4U`@
M<V5R=F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B4&]UONUV871EM2(*"B,Z(&QI8B](
M;W)D92]296=I<W1R>2YP:'`Z-S$V"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")0;W6^
M[79A=&6U("5S(&YI92!J92!A=71O<FEZ;W9A;OT@;F$@)7,N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(E-P<N%V82!P;W6^[79A=&6U;W8B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(E!O
M=;[M=F%T9;5S:^D@;F%S=&%V96YI82(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES='+A8VEA('!O
M=;[M=F%T9;5A(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B4F5G:7-T<N%C:6$@<&]UONUV871EM6]V(&)O;&$@<')E('1E;G1O
M('-Y<W3I;2!Z86OA>F%NX2XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(E!O
M=;[M=F%T9;5S:_T@^NAE="!N96)O;"!NX6ID96[](@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V(&QI8B].970O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.3@@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U,`HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,R!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")0;W6^[79A=&6U
M<VOI(&UE;F\B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(E!O=;[M=F%T9;5S:^D@;65N;R!<(B5S7"(@=;X@
M97AI<W1U:F4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B4&]UONUV871EM7-KZ2!M96YO
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S
M97)N86UE.B`B"FUS9W-T<B`B4&]UONUV871EM7-KZ2!M96YO.B`B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I
M;B!T:&4@<WES=&5M.B(*;7-G<W1R(")0;W6^[79A=&5L:6$@<WES=.EM=3HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z8F5K:7-T86XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C$V-R!L:6(O5D93+V9I;&4N<&AP.C(U.0IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M5D93(&%D<F5SX7(@;F5E>&ES='5J92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3(P"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")$;W9O;&5N
M:V$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L
M;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(E!L871NZ2!U;6EE
M<W1N96YI82!Z86C@\F%J^CH@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E!L871N;W.[(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B4&QA=&YO<[L@=B!M:6[Z=&%C
M:"!O9'1E<F%Z+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C`@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Q.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(DAO
M9&YO=&$@<')E:W)OZ&EL82!M87AI;>%L;G4@9.6^:W4@)7,N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-S`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S,C`*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Y,3<@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G
M:60@(E9A;'5E<R(*;7-G<W1R(")(;V1N;W1Y(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.3`*;7-G:60@(E9A
M;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")(;V1N;W1Y+"!Z(&MT;W+]
M8V@@<VD@;?2^971E('9Y8G)ANR(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T
M<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E!R96UE;F[A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L82(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"XB"FUS9W-T<B`B3W9E<F5N:64@>FQY:&%L;R`M('3A=&\@<W!RX79A(&UO
M:&QA(&)YNR!S9F%LN6]V86[A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<GII82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G:60@(E9E<G-I;VX@
M0V]N=')O;"(*;7-G<W1R(")-86YAOFUE;G0@=F5R>FGM(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B5F5R=&EKX6QN92!Z87)O=FYA
M;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")697)T:6OA
M;&YE('9Y<&QN96YI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T
M:6OA;&YE.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<P"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B5F6U;6D@=GES;VOA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HY-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("):
M;V)R87IINR`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@
M(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B6F]B<F%Z:;L@
M97AT97)N^B!W=W<@<W1RX6YK=2(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*
M;7-G<W1R("):;V)R87IINR!A:V\@)7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:"(*;7-G<W1R(")"<FET<VOI(%!A;F5N<VOI(&]S=')O
M=GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")!
M;65R:6-KZ2!086YE;G-KZ2!O<W1R;W9Y(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FED:71EM6YO
M<[LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED
M(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FED:71EM6YO<[LZ("(*"B,Z(&QI
M8B].970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O
M9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE($ET86QY
M(&-E>B!33510(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(E9!4D]604Y)
M12(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M
M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&
M4D]-("5S+B(*;7-G<W1R(")54$]:3U).14Y)12$A(2!/1%-44L'25$4@4TM2
M25!4(%H@)7,@4E7(3D4N(@H*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(E=)3B!C97H@2%14
M4"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(T-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI
M<R!A($9U='5N82(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(T(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R(")687)O=F%N:64B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")3
M="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0<F5D<&]V9>\@<&_H87-I82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("+:9&%J92!O('!OZ&%S
M[2!P;W-K>71U:F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DV"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I
M=&4B"FUS9W-T<B`B5U=7('-T<N%N:V$B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5/V^9&5N;F4B
M"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R(")6:71A:G1E(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5NUT82!6
MX7,@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP
M;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92P@)7,B"FUS9W-T<B`B5FET86IT92P@)7,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B6N%P861NX2!386AA<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M(@IM<V=S='(@(DMT;W+Z(&%P;&EKX6-I=2!MX2`E<R!Z;V)R87IINR!P;R!P
M<FEH;.%S96[M/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T
M"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G
M<W1R(")!:_T@:F4@>FYA:R!P<F4@;V1D9;5O=F'H/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_(@IM<V=S='(@(D%K_2!J92!Z;F%K('!R92#Z=F]D>F]V
M:W4_(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")-87!A
M($%U<W1RX6QI92!P<F4@<VQUOF)U(%=H97)E:7,B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")+=&]R
MZ2!FX7IY(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+B(*;7-G<W1R(")+=&]RZ2!ZX7-U=F[I(&UO9'5L>2!P;W9O;&F[('!R
M92!R;WJY[7)E;OT@=&5X=&]V_2!E9&ET;W(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED
M=&@B"FUS9W-T<B`BJ>UR:V$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q
M-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(JGM<FMA('8@
M:F5D;F]T:^%C:"!#4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G
M<W1R("*I[7)K82!M96YU("5S(':U879O("AP<F5J87;M('-A('!R:2#O86RY
M;VT@<')I:&SA<V5N[2DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R("*I[7)K82!T86)UM6MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS
M9W-T<B`B2F5D;F]T:V$@N>UR:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@
M(JGM<FMA.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*;7-G
M:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B5FEE=&]R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`B4N%N;R!V:65T;W(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S
M='(@(E+]8VAL;W.[('9E=')A('8@=7IL;V-H(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9I971O<CHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7:6YD
M.B`B"FUS9W-T<B`B5FEE=&]R.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R(")-^F1R;W.[(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B5VES:&QI<W0B"FUS
M9W-T<B`B5VES:&QI<W0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*
M;7-G:60@(E=O<FLB"FUS9W-T<B`B4'+A8V$B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D
M<F5S82!D;R!P<N%C92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F\VX@
M9&\@<'+A8V4B"@HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#
M4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB
M"FUS9W-T<B`B3F5S<'+A=FYY('!OZ&5T('!O;.T@;F$@<FEA9&MU("5D+B!/
MZ&%KX79A('-A("5D+"!N8;EL;R!S82`E9"XB"@HC.B!L:6(O1FEL92]#4U8N
M<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(DYE<W!R
MX79N>2!P;^AE="!P;VSM+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"XB
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*
M;7-G<W1R("):;/T@;V9F<V5T("5D('!R:2#H[71A;NT@5D93('/Z8F]R=2XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E
M9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T
M<B`B6N%K;&%D;ND@;V)M961Z96YI82!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME
M>2!5<V%G92(*;7-G<W1R(")0;W6^:71I92!R;WJY[7)E;NEH;R!KM?KH82!8
M-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")!
M;'1E<FYA=.UV;F4@;65N;R!S=6)J96MT=2!8-3`Y=C,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B261E;G1I9FEKX71O<B!KM?KH82!S
M=6)J96MT=2!8-3`Y=C,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S
M(')O>KGM<F5N:6$B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M65DB"FUS9W-T<B`B65DB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3,*;7-G:60@(EE965DB"FUS9W-T<B`B65E962(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO;R$@
M;6%P(@IM<V=S='(@(EEA:&]O(2!M87`B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B4F_H;F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")996UE;B(*;7-G<W1R(")*96UE;B(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R
M(")!;F\B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N
M:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(E/Z:&QA<^UM
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=
M(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B
M"B)3=&4@=B!415A43U9/32!21:Y)344N(%!O=;YI=&4@=&QAZ&ED;&\@6SP^
M72!N82!P<F5P;G5T:64@;F%S<.2[(&1O(%=94TE764<N(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+V5D:70N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C
M:W,N(@IM<V=S='(@(DYE;?2^971E('9Y='9O<FF[('9I86,@86MO("5D(&)L
M;VMO=BXB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYI92!S=&4@875T96YT:69I
M:V]V86[]+B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,S`W"FUS9VED
M(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+B(*;7-G<W1R(")6;R!68;EO;2!P;&YO;2!M96YE(&YE;?2^
M971E('!O=;YINR!Z;F%K("=<7"<N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$X-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-SD*;7-G:60@(EEO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B3F5Z
M861A;&D@<W1E('!L871N^B!E+6UA:6QO=OH@861R97-U+B(*"B,Z(&QI8B](
M;W)D92]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U
M(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE
M('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T
M<B`B(@HB3F5U<NAI;&D@<W1E('9ZNV%H(&UE9'II(+YI861N>6UI('!O;&EA
M;6D@>B!I;7!O<G1O=F%NZ6AO('/Z8F]R=2!A("(*(GIO9'!O=F5D86KZ8VEM
M:2!P;[5A;6D@=B`E<RXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@T"FUS
M9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D)O;&D@
M<W1E(&]D:&SA<V5N_2XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(V-0IM
M<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@
M(B(*(DUU<^UT92!Z861ANR!P;&%T;ND@Z.US;&\@;6]B:6QNZ6AO('1E;&5F
M\VYU+"!K=&]RZ2!O8G-A:'5J92!I8F$@Z.US;&$@<R`B"B)V;VQI=&6U;OUM
M('!R969I>&]M("<K)R!P<F4@;65D>FENX7)O9&[](&9O<FWA="XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B375S[71E('IA9&&[('!L871N
M^B!H;V1N;W1U+B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(D%B>2!S=&4@;6]H;&D@<&]U
MONUV8;L@4F5G:7-T<N%C:64L(&UU<^UT92!N86IS:_1R(&YA:V]N9FEG=7)O
M=F&[($1A=&%4<F5E("(*(F)A8VME;F0N(@H*(SH@;&EB+TAO<F1E+G!H<#HT
M-C(*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*
M;7-G<W1R(")-=7/M=&4@;F%K;VYF:6=U<F]V8;L@5D93(&)A8VME;F0N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")-=7/M=&4@<&]P[7-A
MNR!P<F]B;.EM('!R961T_6TL(&%K;R!O9&^Y;&5T92!S<'+A=G4@;R!P<F]B
M;.EM92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B375S[71E('IA9&&[(%523"!A
M9')E<W4L(&YA(&MT;W+Z('3A=&\@;&EN:V$@=6MA>G5J92(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE
M8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(DUU<^UT92!V
M>6)R8;L@<V5R=F5R+"!K=&]R_2!MX2!B>;L@=GEM87IA;OTN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")-=7/M=&4@=7+H:;L@;65N
M;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@=GEM87IANRXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U
M<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(DUU<^UT92!U<NAINR!M96YO
M('!O=;[M=F%T9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA>F&[+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+B(*;7-G<W1R(")-=7/M=&4@=7+H:;L@;65N;R!P;W6^[79A=&6U82P@
M:W1O<NEH;R!C:&-E=&4@<')I9&&[+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T
M-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+B(*;7-G<W1R(")-=7/M=&4@=7+H:;L@<&]UONUV871EM6$L(&MT;W+]
M('-A(&WA(&%K='5A;&EZ;W9ANRXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B375S[71E('5RZ&F[(&%K8VEU+"!K
M=&]RX2!S82!MX2!V>6MO;F&[+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W
M(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DUU<^UT92!Z861ANR!M96YO(&YO
M=F5J(&MA=&5G\W)I92XB"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET
M86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(DUU<^UT92!Z861ANR!T86QI
M86YS:V4@=&5L96;S;FYE(.CM<VQO(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.CDW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB4&QA
M=&YO<[L@5F&Y96H@<F5LX6-I92!P<F4@87!L:6OA8VEU("5S('9Y<'*Y86QA
M+B!0<F]S[6T@<')I:&SA<W1E('-A('IN;W9U+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E
M<W,B"FUS9W-T<B`B5F&Y82!%;6%I;&]VX2!A9')E<V$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z
M(@IM<V=S='(@(E9AN6$@16UA:6QO=N$@861R97-A('!O=;YI=.$@<')E(&]D
M8VCA9'IA:OIC=2!P;[ET=3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`B5F&Y92!I;F9O<FWA8VEE(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(B(*(E9AN6$@:6YT97)N971O=N$@861R97-A('-A('IM96YI;&$@;V0@>F'H
M:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@(@HB8F5Z<&7H;F]S
MNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B5F&Y92!M96YO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N(@IM<V=S='(@(B(*(E;AN2!A=71E;G1I9FEK8>AN_2!M;V1U;"!N97!O
M9'!O<G5J92!P<FEDX79A;FEE('!O=;[M=F%T9;5O=BX@06L@<VD@OF5LX71E
M("(*(G!O=;YINR!(;W)D92!N82!S<'+A=G4@<&]UONUV871EM7-K_6-H(/KH
M=&]V+"!M=7/M=&4@<&]UOFF[(&EN_2`B"B)A=71E;G1I9FEK8>AN_2!B86-K
M96YD+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R
M("(B"B)6X;D@875T96YT:69I:V'H;OT@;6]D=6P@;F5P;V1P;W)U:F4@>F]B
M<F%Z;W9A;FEE('IO>FYA;74@<&]UONUV871EM6]V+"`B"B)A;&5B;R!B;VQA
M('3A=&\@;6^^;F]SNR!Z(&YE:F%KZ6AO(&3T=F]D=2!Z86OA>F%NX2XB"@HC
M.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS
M9W-T<B`B(@HB6F3A('-A+""^92!6X;D@<')E:&QI861AZ"!S82!Z;65N:6P@
M;V0@>F'H:6%T:W4@5F&Y96H@<F5LX6-I92`E<RX@4')E(%9AN74@(@HB8F5Z
M<&7H;F]SNR!S82!M=7/M=&4@>FYO=G4@<')I:&SA<VF[+B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C4U"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E;AN2!P<F5H;&EA
M9&'H(&YE<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E;A
MN2!P<F5H;&EA9&'H(&YE<&]D<&]R=6IE('3Z=&\@9G5N:V-I=2!T;&'H92X@
M4W1L8>AT92!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G!R92!T;&'H+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(E9AN6$@86MT=>%L;F$@Z&%S;W;A('KS
M;F$Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDX"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B5F&Y
M82!P<F5D;F%S=&%V96[A(&ED96YT:71A(&)O;&$@>FUE;F5NX2XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ(@IM<V=S='(@(E!R961N87-T879E;N$@:61E;G1I=&$Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!F=6QL
M(&YA;64Z(@IM<V=S='(@(E9AN64@;65N;SHB"@HC.B!L:6(O2&]R9&4O075T
M:"YP:'`Z.3DV"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G
M<W1R(")0;&%T;F]SNR!6X;EH;R#ZZ'1U('9Y<'*Y86QA+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B5F&Y
M92!N;W;I(&AE<VQO('!R92`E<R!J93H@)7,B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G
M<W1R(")68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI>F]V86[I('!R92!T
M;W1O('-E9&5N:64N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-38*
M;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T
M<B`B5F&Y92!N87-T879E;FEA(&)O;&D@86MT=6%L:7IO=F%NZ2XB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")68;EE(&AE<VQO(&)O;&\@
M;V)N;W9E;NDB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM
M<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@
M>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O
M<F0N(@IM<V=S='(@(B(*(E9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ2P@<VMO
M;G1R;VQU:G1E('-I('!ON71U(&$@<')I:&SA<W1E('-A(',@5F&Y[6T@;F]V
M_6T@(@HB:&5S;&]M+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HW,S`*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E!L871N
M;W.[(%;AN6AO(&AE<VQA('9Y<'*Y86QA+B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB
M"FUS9W-T<B`B5F&Y92!V>F1I86QE;ND@<V5R=F5R>3HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R(")*=6AO<VSA=FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("):86ER(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("):
M:7!P>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM3
M:W)YNR!C:71O=F%N_2!T97AT72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C@Y"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM3<'+A=F$@
M;R!P<F]B;.EM95TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R
M(");6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M(@H*(SH@;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M
M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S
M='(@(EM:;V)R87IINR!C:71O=F%N_2!T97AT("T@)7,@<FEA9&MO=ETB"@HC
M.B!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)I861O:R`E<R!Z("5S72(*"B,Z(&QI
M8B](;W)D92YP:'`Z,34T-2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T<N%C
M:6$B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM
M<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B
M"FUS9W-T<B`B7U9Y;6%Z8;L@<FEA9&]K(@H*(SH@;&EB+V%P:2YP:'`Z,3,S
M"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]3:W5P:6YY(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7U!O;6]C
M;NUK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")6;&%S=&YO<W1I(%]O8G+A>FMU+BXN(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?4')I:&SA<VF[
M('-A(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O
M=70B"FUS9W-T<B`B7T]D:&SA<VF[('-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D
M:69Y($QI;FLN+BXB"FUS9W-T<B`B7U5P<F%V:;L@;&EN:W4N+BXB"@HC.B!L
M:6(O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M(")?3F%S=&%V96YI82(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E
M<FUI<W-I;VYS(@IM<V=S='(@(E]0<N%V82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(D]D<W1?<N%N:;L@;&EN:W4N+BXB"@HC
M.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(").85]S
M=&%V96YI92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B5FQA<W1N;W-T:2!?=&%B=;5K>2XN+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E!O7W6^[79A=&5L:6$B
M"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR,`IM<V=I9"`B861D<F5S<R!B
M;V]K(@IM<V=S='(@(F%D<F5SX7(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@
M(F%D<F5SX70@;F5Z;N%M>2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$R
M"FUS9VED(")C86QE;F1A<B(*;7-G<W1R(")K86QE;F3A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L
M('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8F5Z=F5T<FEE(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@(FYE<&]D87)I;&\@<V$@
M=GET=F]R:;L@=OUS='5P;OT@<_IB;W(B"@HC.B!L:6(O2&]R9&4O34E-12]-
M97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S
M='(@(FYE<&]D87)I;&\@<V$@;W1V;W)INR!V<W1U<"(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B:VQI:VYI=&4@<V5M(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS
M9W-T<B`B8VAY8F$@<')I('!O=;YI=.T@<'+M:V%Z;W;I:&\@<FEA9&MU(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF
M:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(F-H>6)A(&MO;F9I9W5RX6-I92(*
M"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R(")C:/UB82!D]&QE
MOFET_2!S>7-TZ6UO=OT@<_IB;W(B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@
M(F-H>6)A(&9O<FWA='4@^F1A:F]V(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B
M<&]L;[YK82!N96[A:F1E;N$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")K;&5S
MX2(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#$*;7-G:60@(F9I;&4B
M"FUS9W-T<B`B<_IB;W(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S(@IM<V=S='(@(GIO('-M97)U("5S("@E<RD@<OUC:&QO<[MO=2`E<R`E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@
M(F=U<W1I;F<B"FUS9W-T<B`B;N%R87IO=OTB"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS9VED(")H.B(*;7-G<W1R(")V
M.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-3<*
M;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R
M(")N97INX6UE(&UE;F\@:&]S=&ET9;5A(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(F]K86V^:71E
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")V('-P<N%V92(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O
M;W5T<'5T(&5R<F]R(@IM<V=S='(@(F-H>6)A('9S='5P=2]V_7-T=7!U(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E
M<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R(")I;G1E<F[A(&-H>6)A('-O
M9G1VZ7)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R(")R:6%D:V]V72(*"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R(")P;^AA<R!V>71VX7)A;FEA($E33R!N87-T86QA(&-H>6)A
M(&UK:7-O9G,@)60B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I
M9"`B;F%M92(*;7-G<W1R(")M96YO(@H*(SH@;&EB+TAO<F1E+U)00RYP:'`Z
M,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B;F5I;7!L96UE
M;G1O=F%NZ2(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(R,`IM
M<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")Z871I8;4@;F5I
M;7!L96UE;G1O=F%NZ2(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`T"FUS
M9VED(")N;W1E<&%D(@IM<V=S='(@(G!O>F[A;6MO=OT@8FQO:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*
M;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B<&5R8V5N="(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI
M960B"FUS9W-T<B`B<'+M<W1U<"!Z86UI971N=73](@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B
M<&EX96QS(@IM<V=S='(@(F)O9&]V(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B=GID:6%L96[A(&-H>6)A('8@<')O=&]K;VQE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R(")S=/IP82(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A
M9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R
M(")S;'6^8F$@;FEE(&IE(&1O<W1U<&[A(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")Z
M;V)R87IINR!R;WID:65L>2(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R
M(")S;7,R96UA:6P@8V5Z($A45%`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@T"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R"FUS9VED
M(")S=&5A9'DB"FUS9W-T<B`B=7-TX6QE;OTB"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R
M(")S>7-TZ6UO=N$@8VAY8F$B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDR
M.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(GIO>FYA;2#Z;&]H(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A
M<GD@9F%I;'5R92(*;7-G<W1R(")D;^AA<V[A(&-H>6)A(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G
M:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T
M<B`B<')E('!O='9R9&5N:64@>F%D86IT92!H97-L;R!D=F%K<N%T(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEK;W9A;NDB"@HC.B!L
M:6(O2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R(")N97!O;65N;W9A;N$B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")D969I;G5J92!P;W6^
M[79A=&6U(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0P"FUS9VED(")W.B(*;7-G<W1R
M("*Y.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED
M(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O;2(*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O+FAT86-C97-S````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#$V(#$P
M-3$U-#,T,30R(#`Q-S<T,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!$96YY(&9R;VT@86QL"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!O+VQT7TQ4+G!O````````````````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#<R,3<W-B`Q,#4Q-30S-#$T,B`P
M,3<U-3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````(R!,:71H=6%N:6%N('1R86YS;&%T:6]N<R!F;W(@2&]R9&4@<&%C:V%G
M92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!(;W)D92!P86-K86=E+@HC($1A<FEU<R!-871U;&EA=7-K87,@/&1A
M<FEU<T!L;FLN;'0^+"`R,#`R+@HC(%9I;&EU<R!3=6US:V%S(#QV:6QI=7-`
M;&YK+FQT/BP@,C`P,RP@,C`P-"X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R
M;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A
M=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#0M,3$M,CD@,3(Z-3(K,#(P,%QN(@HB3&%S="U4<F%N
M<VQA=&]R.B!6:6QI=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#Y<;B(*(DQA
M;F=U86=E+51E86TZ($QI=&AU86YI86X@/'9I;&EU<T!L;FLN;'0^7&XB"B)-
M24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4E33RTX.#4Y+3$S7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S
M='(@(B`H<')I9?`@)7,@9&EE;F%S*2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME
M>2`E<RDB"FUS9W-T<B`B("AM>6=T=6MA<R`E<RDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H<')I9?`@)7,@9&EE;F%S*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D
M87DI(@IM<V=S='(@(B`H\&EA;F1I96XI(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W-0HC+"!F=7IZ>0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS
M9W-T<B`B4GET;VHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q
M"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AV86MA<BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(@(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(DYE(&MA
M=&%L;V=A<R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C
M:&]I8V4N(@IM<V=S='(@(B<E<R<@>7)A(&YE;&5I<W1I;F$@<F5I:_!MZRXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@;F5S
M=6MO;F9I9_MR=6]T87,@2&]R9&4@<F5G:7-T<F4N(@H*(SH@9G)A;65W;W)K
M+U1R964O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(D[K
M<F$@)R5S)R!M963^:6\@9V5N97)A=&]R:6%U<RXB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")'<G5P
MZR`G)7,G('-U:W5R=&$N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(E1E:7/K
M("<E<R<@<W5K=7)T82XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E
M<R<@;F5B=79O('-U:W5R=&$Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E
M+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!I<B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D+61I96[X('!R;V=N;WKK(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@<&%S=&%B82(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&%N='-P
M875D87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS
M9W-T<B`B)7,@<')O9FEL86MT:6MO<R!V96EK<VUA:2`M('!A='9I<G1I;FEM
M87,B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(E]+;VYF:6?[<F%C:6IA(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S(')E9VES=')A8VEJ82(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@;G5O<W1A=&]S
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,C@@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S
M(&IA=2!E9WII<W1U;VIA+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,Y"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S4Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM
M<V=S='(@(B5S("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D
M>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K
M960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH
M<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@
M(E!A_GEMZVMI=&4L(&MU<FEA<R!O<&5R86-I:F%S(&YO<FET92!A=&QI:W1I
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@>7)A('!R
M:79A;&]M87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5TZW,B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B
M)7,@;F5R87-T87,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G
M<W1R(")N=6\@)7,@:6MI("5S(&GP("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R
M97-S($)O;VLB"FUS9W-T<B`B)7,@861R97/X(&MN>6=E;.LB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S(&MA;&5N9&]R:75S(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B5S('7^<F'P^"!K;GEG96SK
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(E<R!D87)B^"!S
MX')A\&%S(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@
M8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK
M<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P
M97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#$P"B,L(&9U>GIY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@
M(BP@9_MS:6%I("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(BP@9_MS:6%I("5S("5S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@:VEN=&$@;G5O
M("5S(&EK:2`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,CDT(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-S0Y"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@<&%S:7)I
M;FMI=&4@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R
M($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R('9A;&%N9/@@9F]R;6%T87,B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T
M(@IM<V=S='(@(C(T('9A;&%N9/@@9F]R;6%T87,B"@HC.B!T96UP;&%T97,O
M9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@
M=F%L86YD;W,B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"B,L
M(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B06YK<W1E<VYI<R!P
M=7-L87!I<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(M!I86T@8FQO:W5I(')E:6MA;&EN9V$@=FEE=&$@9'5O;65N
M^"!B87KK:F4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*
M;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(L%V
M>6MO(')I;71A(&ML86ED82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B3F]RZV1A;6D@=?YK
M;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A
M:W3@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(DYO<NMD86UI('!A=&EK
M<FEN=&D@<&%S:7)A\'ETX"!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67P
MX&KA(%!'4"!R86MTX"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB3F]RZV1A;6D@871K;V1U
M;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@
M:N$@4$=0(')A:W1U<RP@(@HB8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED
M("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HB3F]RZV1A;6D@<&%S:7)A\'ET:2!L86GP:^`@<')I=F%L
M;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%!'4"!R86MT=7,L("(*
M(F)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"B).;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K
M=&D@=FEE\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@(@HB<F%K='5S+"!B96D@
M_FEN;W1I('-L87!TX&K@(&9R87KF+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB3F]R
MZV1A;6D@<&%S:7)A\'ET:2!L86GP:^`@<')I=F%L;W1E('1U<NMT:2!V:67P
MX&KA(&ER('-L87!TX&KA(%,O34E-12`B"B)R86MT=7,L(&)E:2#^:6YO=&D@
M<VQA<'3@:N`@9G)A>N8N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U
M:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B3F]RZV1A;6D@
M=?YK;V1U;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4R]-
M24U%(')A:W3@+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.CD*(RP@9G5Z>GD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(")$
M96)E<W5O=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")032!L96YG=F%S(&QI971U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$Q"B,L(&9U>GIY"FUS9VED(")!32!286EN(@IM
M<V=S='(@(DQI971U<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D%-(')O
M9'EM87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PHC+"!F=7IZ>0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(E#[9V$B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B
M04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M(")!<&EE(/#A(')E9&%K=&]R:?@B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B07!I92XN+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G
M:60@(D%B<V)O='1O;2(*;7-G<W1R(")6:7-I\&MA:2!A<&'H:6]J92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G
M:60@(D%B<VUI9&1L92(*;7-G<W1R(")6:7-I\&MA:2!P97(@=FED=7+A(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")3
M:7-T96UA(&YE='5R:2!T96ES:?@@<W5K=7)T:2!61E,@:V%T86QO9^`N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B4VES=&5M
M82!N971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&9A:6S@+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IA(&%P:64@2G5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W
M;W)D(@IM<V=S='(@(E-L87!T8?YO9&ES(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT
M(&9R;WIE;BXB"FUS9W-T<B`B4^!S:V%I=&$@=?[P86QD>71A+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B
M"FUS9W-T<B`B07!S:V%I=&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D
M9"(*;7-G<W1R(")3=6MU<G1I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@
M861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R(")3=6MU<G1I('!O9W)U<.$B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(E-U:W5R
M=&D@<&]T96ES97,B"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM
M<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D)L;VMO(.%T97)P:6UA<SHB"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM
M<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")3=6MU<G1I(&YA=6K@(&=R
M=7#F(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B4W5K=7)T:2!N875J87,@=&5I<V5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E
M<UPB(@IM<V=S='(@(E!O9W)U<&EO(&=R=7!E:2`G)7,G('-U:_MR:6UA<R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O
M(%PB)7-<(B(*;7-G<W1R(")0;W1E:7/K<R!T96ES96D@)R5S)R!S=6O[<FEM
M87,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(DYA=6IO('9A<G1O=&]J;R!S=6O[<FEM87,Z(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I
M9"`B061D(&-O;'5M;B(*;7-G<W1R(")0<FEDZW1I('-T=6QP96SA(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D
M(&YE=R!M96UB97)S(@IM<V=S='(@(DYA=6KX(&YA<FGX('!R:63K:FEM87,B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@
M<&%I<B(*;7-G<W1R(")3=6MU<G1I('!O<N`B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R(")0<FEDZW1I("5S
M(&UE;FEU('!R:64@36]Z:6QO<R#A<F%N:VGX(&IU;W-T;W,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D
M9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(L%T<F%U:W1I(.$@861R97/X
M(&MN>6=E;.8Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S
M='(@(L%T<F%U:W1I(.$@;6%N;R!A9')E<_@@:VYY9V5LYCHB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B4W5K=7)T
M:2!V87)T;W1O:N`B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB5F%R=&]T;VIA<R`G)7,G('-U
M:W5R=&%S+"!T8>AI874@<&%P:6QD;VUA(')E9VES=')A8VEJ;W,@:6YF;W)M
M86-I:F$@;F5B=79O("(*(FGP<V%U9V]T83H@)7,N(@H*(SH@<VEG;G5P+G!H
M<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B
M5F%R=&]T;VIA<R`G)7,G('-U:W5R=&%S+B!'86QI=&4@<')I<VEJ=6YG=&DN
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@
M(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B5F%R=&]T;VKX
M(&O[<FEM87,@:?!J=6YG=&%S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S87,B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB
M"FUS9W-T<B`B061R97-A:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')U;W1I
M("T@9V%L:2!N=7-T871Y=&D@=&5I<V5S(&MI=&EE;7,@=F%R=&]T;VIA;7,B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B5F%L
M9'EM87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"FUS9VED
M(")!9',B"FUS9W-T<B`B0F%N97)I86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!
M9F=H86YI<W1A;B(*;7-G<W1R(")!9F=A;FES=&%N87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;/YY<F%S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI
M87,B"FUS9W-T<B`B4')A=F%R9.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G
M<W1R("),>6=I=6]T:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B3'EG
M:6%V:6UA<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@
M(D%L;"(*;7-G<W1R(")6:7-O<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G
M:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E9I<VD@<')I
M<VEJ=6YGYB!V87)T;W1O:F%I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A
M9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R
M(")6:7-O<R!G<G5PZW,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*
M;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")6:7-O<R!T96ESZW,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")6:7-O<R!K
M971U<FEO<R!P=7/K<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S$*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("),
M96ES=&D@:V5L973@(&%D<F5S^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y
M<&4_(@IM<V=S='(@(DQE:7-T:2!N875D;W1I('-U<OOP:75O=.`@<^!R8?#@
M/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P
M-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B2F%U(&5G>FES='5O
M:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!;'1E<FYA='EV=7,@24U34"!P
M<FES:6IU;F=I;6%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM
M<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N
M871Y=G5S($E-4U`@<VQA<'1A_F]D:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G
M<W1R(")!;'1E<FYA='EV=7,@24U34"!V87)T;W1O:F\@=F%R9&%S(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T
M92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T>79U<R!E;"X@<&'P
M=&\@861R97-A<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED
M(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T>7;[<R#P
M86)L;VYA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM
M<V=S='(@(D%L=&5R;F%T>79U<R!T96MS=&%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B06UE<FEK;W,@4V%M;V$B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N(@IM<V=S='(@(L%V963K=&4@;F5L96ES=&ENX"!R
M96EK\&WF+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*
M(RP@9G5Z>GD*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N
M(@IM<V=S='(@(L%V>6MO(')I;71A(&ML86ED82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G
M:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I
M9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(D%N9VEL86DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS
M9W-T<B`B06YO;FEM:6YI<R!P<F]X>2!S97)V97)I<R(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`B
M071S86MY;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G
M<W1R(")!;G1A<FMT:61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A
M;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A(&ER($)A<F)U9&$B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM
M<V=S='(@(DUO9'5L:7,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*
M(RP@9G5Z>GD*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B36]D
M=6QI<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P
M<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")-;V1U;&ES('9E:6MI82!G
M97)A:2XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I
M9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(E!R:71A:6MY=&D@
M:7(@<&_P86MI86US(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B4&%T=FER=&EN=&DB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G
M:60@(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM
M<V=S='(@(D)A;&%N9&ES(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*
M;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B:?!K
M82`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")!<F-H>79O
M(&9A:6QO(&1Y9&ES(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*
M;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")!<F-H>79O(&9A:6QO('!A
M=F%D:6YI;6%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/R(*;7-G<W1R(")!<B!T:6MR86D@;F]R:71E(&GP=')I;G1I("5S(')E9VES
M=')A8VEJ;W,@<')A\'EMX#\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S
M=6(M9W)O=7!S/R(*;7-G<W1R(")!<B!T:6MR86D@;F]R:71E(&GP=')I;G1I
M("<E<R<@:7(@=FES=7,@<&]G<G5P:75S/R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%R9V5N=&EN82(*;7-G<W1R(")!<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;>MN:6IA(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM
M<V=S='(@(D%R;>MN:?!K82`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DUE;F%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L
M86YD(@IM<V=S='(@(DMR:7-T875S(/YE;F=I;6\@X2!D86YG^"!S86QA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B
M"FUS9W-T<B`B06-S:6D@;65N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T
M<B`B07II:F$O4F%M:6]J;R!V86YD96YY;F\@<F5G:6]N87,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`B07(@<')A\'ET:2!P871V:7)T:6YT:2!P<F]F:6QA:W1I:V]S('9E
M:6MS;75S/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G
M:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")0<FES:WER:6UO('-T
M=6QP96QI86DB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B
M0F%N9&]T92!I\'1R:6YT:2!N965G>FES='5O:F%NZ&G@(&=R=7#F+B(*"B,Z
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D)A
M;F1O=&4@:?!T<FEN=&D@;F5E9WII<W1U;VIA;NAI87,@=&5I<V5S+B(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B0F%N9&]T
M92!R961A9W5O=&D@;F5E9WII<W1U;VIA;NAI87,@=&5I<V5S+B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")"86YD;W1E(')E
M9&%G=6]T:2!N965G>FES='5O:F%N=.$@96QE;65N=.`N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T
M<B`B071R:6)U=&%I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")2=6=P:OMT:7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A
M;&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B075S
M=')I:F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X
M"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@;F5R87-T87,@<F5I
M:V%L:6YG87,@24U!4"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D
M;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!
M=71H7V-Y<G5S.B!C>7)U<R!N971U<FD@<F5I:VEA;?@@9V%L:6UY8FGX+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!N97)A<W1A<R!R96EK86QI;F=A<R!)
M34%0(&UO9'5L:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP
M.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*
M(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!N97)A<W1A<R!R
M96EK86QI;F=A<R!&5%`@;6]D=6QI<RX@4W5K;VUP:6QI=6]K:71E(%!(4"!S
M=2`M+65N86)L92TB"B)F='`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<#H@;F5R87-T
M87,@<F5I:V%L:6YG87,@24U!4"!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR
M8C4Z(&YE<F%S=&%S(')E:6MA;&EN9V%S(&MR8C4@;6]D=6QI<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L
M9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E
M($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G
M:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S
M($Q$05`@;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I
M9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@<W5K=7)T:2!V87)T;W1O:N`@)7,@
M;F5P879Y:V\N(%-E<G9E<FEO('!R86YE\&EM87,Z("(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@:?!T<FEN=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B075T:%]L9&%P.B!A=&YA=6II;G1I('9A<G1O=&]JX"`E
M<R!N97!A=GEK;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#`U"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VUC86PZ(&YE<F%S=&%S(')E:6MA;&EN9V%S($U#04P@;6]D
M=6QI<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G
M:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z(&YE<F%S=&%S(')E
M:6MA;&EN9V%S('-M8F%U=&@@;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")0<FES:6IU;F=T:2!N97!A=GEK
M;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,B"FUS9W-T<B`B4')I<VEJ=6YG=&D@;F5P879Y:V\N("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B4D%$2553('-E<G9E<FES(&YE;&5I9/YI82!A=71E;G1I9FEK
M=6]T:7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")0<FES:6IU;F=T:2!P<FEE($944"!S97)V97)I;R!N97!A=GEK;RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(E!R:7-I:G5N9W1I('!R:64@1E10('-E<G9E<FEO(&YE<&%V
M>6MO+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@
M(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D=A;&EM:2!L875K86DZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R(")!>F5R8F%I
M9/YA;F%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"
M3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!A='-I<')A\'EM86DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X
M"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D9O;F%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C
M:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")&;VYO('-P86QV82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`B3F5T96ES:6YG87,@:V5R8F5R;W,@<VQA
M<'1A_F]D:7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(").971E
M:7-I;F=A<R!K97)B97)O<R!V87)T;W1O:F\@=F%R9&%S+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F5I;F%S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(D)A;'1I\&MA("A)4T\M.#@U.2TQ,RDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A9VQA9&7P87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<V%S
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%SZW,@)7,@;NMR82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G
M:60@(D)A<V5L:6YE(@IM<V=S='(@(E!A9W(N(&QI;FEJ;VIE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"86QT87)U<VEJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L9VEJ82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6YA<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R;75D86DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B0G5T86YA<R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(D=I;71A9&EE;FES(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DML87/K<R`E<R!NZW)A+B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@
M4V5T=&EN9W,B"FUS9W-T<B`B0FQO:V\@<&%R86UE=')A:2(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R(")";&]K;R!T:7!A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(")087-T
M;W)I;G1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")"
M;VQI=FEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R(")!=/YY;6]S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M0F]R9&5R(@IM<V=S='(@(DMR8?!T87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN
M97-S.B(*;7-G<W1R(")+<F'P=&\@<W1O<G5M87,Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M0F]R9&5R<R(*;7-G<W1R(")+<F'P=&%I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:6IA(&ER($AE
M<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(E9I<V]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T
M<W=A;F$B"FUS9W-T<B`B0F]T<W9A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*
M;7-G<W1R(")!<&'H:6]J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)
M<VQA;F0B"FUS9W-T<B`B0G5V970@<V%L82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)R87II;"(*;7-G<W1R(")"<F%Z:6QI:F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I
M9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(D)R
M:73X($EN9&EJ;W,@=F%N9&5N>6YO('1E<FET;VIA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B0G)U;NMJ875S(&1A
M<G5S86QE;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T
M<B`B0G5L9V%R:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R(")3
M=?YY;>MT87,@<^!R8?!A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@
M1F%S;R(*;7-G<W1R(")"=7)K:6YA<R!&87-A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:6IA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(E164R(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G
M:60@(D-20R(*;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN
M=',B"FUS9W-T<B`B0U),('!A<VMI<G-T>6UO('!U;FMT86DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*
M;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T-E;.MS(&YU
M<W1A='EM86DN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38S"B,L(&9U>GIY"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R(").9>%R8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X
M-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N
M9&]R:75S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM
M<V=I9"`B0V%L;2(*;7-G<W1R(")286UU(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9/YA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97+[;F%S(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S
M<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(N(@IM<V=S='(@(B(*(DYE=F5I:VEA(&%U=&]M871I;FES('-L87!T8?YO
M9/YI;R!P86ME:71I;6%S+"!S=7-I<VEE:VET92!S=2`B"B)A9&UI;FES=')A
M=&]R:75M:2XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@
M9FEL92!<(B5S7"(B"FUS9W-T<B`B3F5G86QI=2!I\'1R:6YT:2!F86EL;R!<
M(B5S7"(N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(DYE9V%L:74@<')I<VEJ=6YG=&D@<')I92!)34%0('-E<G9E<FEO
M.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0Q,PHC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3F5G86QI=2!I\'1R:6YT:2!F86EL;R!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ,@IM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%T\&%U:W1I
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!=/!A=6MT:2!P<F]B
M;&5M;W,@<')A;F7P:6W@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B3F5G86QI=2!I\'1R:6YT:2!F86EL;R!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-3(*;7-G:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3F5G86QI=2!R87-T:2!L86EK:6YO:F\@:V%T86QO9V\N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY
M,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+B(*;7-G<W1R(").96=A;&EU(&%P9&]R;W1I("=T87)G971&
M:6QE)R!P87)A;65T<F\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").96=A;&EU(&GP=')I;G1I(&MA=&%L
M;V=O(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N
M<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(DYE9V%L:74@:?!T<FEN=&DN($5G>FES
M='5O:F$@)60@<&_P86MI86DN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB3F5G86QI
M=2!P97)R^_!I=6]T:2X@P79E<W1A<R#A<F'P^"!S:V%IZ&EU<R!N97-U=&%M
M<&$@<W4@X7)A\/@@<VMA:>AI=6UI("(*(F1U;VUE;O@@8F%ZZVIE+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BXB"FUS9W-T<B`B3F5G86QI=2!N=6MR96EP=&D@_FEN=73K<R#A(&YU
M<F]D>73@(&YU;65RX2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E
M(@IM<V=S='(@(DME:7!V97)D:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM
M<V=S='(@(E!A=F%D:6YI;6%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O
M<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I:F]S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DMA:6UA;O@@
M<V%L;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL=7,@=&5L
M969O;F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(D-E;.MS(&YU<W1A='EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G
M<W1R(")487)P86D@8V5LZW-E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R
M=&EE<R(*;7-G<W1R(")#96SK<R!N=7-T871Y;6%I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@
M<W!A8VEN9SHB"FUS9W-T<B`B5&%R<&%I('1A<G`@8V5L:?@Z(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W-`IM<V=I9"`B0V5L;'!H;VYE(@IM
M<V=S='(@(DUO8FEL=7-I<R!T96QE9F]N87,B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B2V5L=/@@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*
M;7-G<W1R(")#96YT<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B0V5N=')I;NMS($%F<FEK;W,@4F5S
M<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")#96YT<FEN
MZW,@175R;W!O<R`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL
M<R(*;7-G<W1R(")397)T:69I:V%T;R!D971A;.MS(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*(RP@9G5Z>GD*;7-G:60@(D-E
M<G1I9FEC871E($]W;F5R(@IM<V=S='(@(E-E<G1I9FEK871O(&1E=&%LZW,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I
M9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4V5R=&EF:6MA=&\@
M=&5I<^MS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(LAA
M9&%S(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S
M='(@(E!A:V5I<W1I(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G
M<W1R(")3;&%P=&'^;V3^:6\@:V5I=&EM87,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)*^W/X('9A<F1O(&ER
M(&%D<F5S;RP@:W5R:75O<R!M871Y<R#^;6]NZW,L('-K86ET86YT>7,@:7(@
M871S86MI;NMJ86YT>7,@X2`B"B)*^W/X(&QA:?!K=7,L(&ME:71I;6%S+B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB
M0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@
M=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM
M<V=S='(@(E-I;6)O;&ES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN
M+B(*;7-G<W1R(")085]T:6MR:6YT:2!N=6]R;V3@+BXN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`BR&ELZR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-H:6YA(@IM<V=S='(@(DMI;FEJ82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB
M"FUS9W-T<B`B2VEN:65T:?!K82!P87!R87-T82`H1T(R,S$R*2(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*2(*;7-G<W1R(")+:6YI971I\&MA('1R861I8VENZR`H0FEG
M-2DB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS
M9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R(")087-I<FEN:VET92!S
M;&%P=&'^;V3A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B4&%S:7)I
M;FMI=&4@=F%R=&]T;VIO('9A<F3@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(Y.`IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*
M;7-G<W1R(")087-I<FEN:VET92!K86EP('9A:7ID=6]T:2!D871A<SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D
M97)E9"!L:7-T<RDB"FUS9W-T<B`B4&%S:7)I;FMI=&4@<W5R^_!I=6]T;R!S
MX')A\&\@<W1I;&GX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES
M;&%N9"(*;7-G<W1R(")+86SK9/@@<V%L82(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(DML87/K<R`E<R!NZW)A+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*
M;7-G<W1R(")':65D<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM
M<V=S='(@(DGP=')I;G1I($U3($]F9FEC92#^>6UE<R(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R(%%U97)Y(@IM
M<V=S='(@(DGP=F%L>71I('9A<G1O=&]J;R!D=6]M96YI<R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")687)T;W1O:F\@9'5O
M;65N^"!V86QY;6%S.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("))\'9A;'ET
M:2!V87)T;W1O:F\@9'5O;65N:7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@
M(DGP=F%L>71I('9A<G1O=&]J;R!D=6]M96YI<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U>GIY"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(DQI971U<R!V86MA<F4B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B
M0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B5.9S=&DB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@
M(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P97(@
M2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S
M='(@(E7^9&%R>71I(&QA;F?@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")$96)E<W5O=&$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@HC+"!F=7IZ>0IM
M<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(D1E8F5S=6]T82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#
M;&]U9'DB"FUS9W-T<B`B1&5B97-U;W1A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B2V]K;W-O("A+>6QI
M;F=O*2!S86QO<R(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,C,*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B
M5'7PZ&GX(&-E;&GX(&MR8?!T^"!R;V1Y;6%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B5'7PZ&GX(&-E;&GX(&MR8?!T^"!R
M;V1Y;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B
M2V]L=6UB:6IA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(E-P
M86QV82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R(")087-I<FEN:VET92!S<&%L=N`B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@
M<V5L96-T:6]N(@IM<V=S='(@(E-P86QV;W,@<&%S:7)I;FMI;6%S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G
M:60@(D-O;',Z(@IM<V=S='(@(E-T=6QP96QI86DZ(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G
M<W1R(")3='5L<&5L:?@@<&%V861I;FEM86DB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B2V]M:6MS
M86DB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B
M"FUS9W-T<B`B2V]M86YD82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM
M<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUA;F1I;NL@96EL=73K
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")#;VUM96YT(@IM<V=S='(@(DMO;65N=&%R87,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B5F%R9&%S+W!A=F%R9.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M0V]M;W)O<R(*;7-G<W1R(")+;VUO<F%I(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R(")+;VUP86YI:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*
M;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")+;VUP:75T97)I86DB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED
M(")#;VYD:71I;VXB"FUS9W-T<B`B4^!L>6=O<R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(E/@;'EG
M;W,B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R(").=7-T871Y;?@@<&%K96ET
M:6UA:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@(D-O
M;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE
M<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92XB"FUS9W-T<B`B4F5I:VEA(&%T;F%U:FEN=&D@:V]N9FEG
M^W)A8VENX2!F86ELX"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")+
M;VYF:6?[<G5O=&D@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E-L
M87!T8?YO9&ES(&1A<B!K87)TX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O
M(@IM<V=S='(@(DMO;F=A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4
M:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B1&5M;VMR
M871I;NL@2V]N9V\@4F5S<'5B;&EK82(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M+B(*;7-G<W1R(")0<FES:6IU;F=T:2!N97!A=GEK;RXB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@(@IM<V=S='(@(E!R:7-I:G5N9W1I(&YE<&%V>6MO.B`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B4')I<VEJ=6YG=&D@<')I92!V:67P^&KX(')A:W3X('-E<G9E
M<FEO(&YE<&%V>6MO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*
M;7-G<W1R(")0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R
M:6\@;F5P879Y:V\L(&YE<SH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R(")0<FES:6IU;F=T:2!P<FEE($944"!S97)V
M97)I;R!N97!A=GEK;RXB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q
M-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B2V]N:V%K=&%I('/K:VUI;F=A:2#A=')A=6MT:2#A($K[<_@@
M861R97/X(&MN>6=E;.8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E
M<UPB(@IM<V=S='(@(B<E<R<@='5R:6YY<R(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B5.9S=&DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B2W5K;R!S86QO<R(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(DQA:6WK<R#^:6YU=.MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S
M='(@(DMO<&EJ=6]T:2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B4')I<VEJ=6YG=&D@;F5P879Y:V\Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O
M<'D@<V5L96-T:6]N(@IM<V=S='(@(DMO<&EJ=6]T:2!P87-I<FEN:VEMX"(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED
M(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A
M(%)I8V$B"FUS9W-T<B`B2V]S=&$@4FEK82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B1')A;6)L:6\@2V%U;&\@2W)A;G1A
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DYE
M<&%V>6MO('7^:V]D=6]T:2!01U`@;&%I\&MO+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E+B(*;7-G<W1R(").97!A=GEK;R!P87-I<F'P>71I(%!'
M4"!L86GP:V\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E
M+B(*;7-G<W1R(").97!A=GEK;R!U_FMO9'5O=&D@4R]-24U%(&QA:?!K;RXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(DYE
M<&%V>6MO('!A<VER8?!Y=&D@4R]-24U%(&QA:?!K;RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S
M='(@(DYE<&%V>6MO('!R:63K=&D@:V]N=&%K=&\N("5S(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3F5P879Y:V\@875T96YT:69I:W5O=&ES(.$@
M3$1!4"!S97)V97+A+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R
M(@IM<V=S='(@(DYE<&%V>6MO(&%U=&5N=&EF:6MU;W1I<R#A($Q$05`@<V5R
M=F5RX2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYE<&%V>6MO('!A=&EK<FEN
M=&D@8F%L86YS;RX@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E
M<G9E<B(*;7-G<W1R(").97!A=GEK;R!P<FES:6IU;F=T:2!P<FEE(%--0B!S
M97)V97)I;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E
M<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").97!A=GEK;R!P
M<FES:6IU;F=T:2!P<FEE("<E<R<@<V5R=F5R:6\@<&5R($944#H@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!S=6MU<G1I(&1I
M<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$Q,C4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'
M4"!D871A+B(*;7-G<W1R(").97!A=GEK;R!A=&MO9'5O=&D@4$=0(&1U;VUE
M;O@N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*
M;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R
M(").97!A=GEK;R!A=&MO9'5O=&D@4R]-24U%(&1U;VUE;O@N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!K;VYT86MT;RX@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!D
M:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S
M='(@(DYE<&%V>6MO(&GP=')I;G1I(&%T;F%U:FEN:6UO('-K<FEP=&\@)R5S
M)RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+B(*;7-G<W1R(").97!A=GEK;R!N=7-T871Y=&D@9V%VZVIO(&5L+B!P8?!T
M;R!A9')E<V\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(E!A=GEK;R!G875T:2!V:7-O<R!A
M9')E<_@@:VYY9V5LZW,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3F5P879Y:V\@
M9V%U=&D@=FES;R!D:7-T<FEB=6-I:F]S('/@<F'P;RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U
M=&EO;B!L:7-T<RXB"FUS9W-T<B`B3F5P879Y:V\@9V%U=&D@=FES;R!D:7-T
M<FEB=6-I:F]S('/@<F'P^"!SX')A\&\N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(").97!A
M=GEK;R!U_FMR875T:2!S=')A=&5G:6IO<R`G)7,G+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*
M;7-G<W1R(").97!A=GEK;R!S=6MU<G1I(&MA=&%L;V=O("<E<R<N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L
M9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*
M;7-G<W1R(").97!A=GEK;R!G875T:2!V:67P;VIO(')A:W1O(&GP(')A:W3X
M('-E<G9E<FEO+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B3F5P879Y:V\@871I9&%R>71I("<E<R<@<F'P
M>6UU:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A<GET:2`E<RXB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&EO("5S(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!A=&ED87)Y
M=&D@:V%T86QO9V\@)R5S)RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N
M(@IM<V=S='(@(DYE<&%V>6MO('!A:67P:V$@3$1!4"!S97)V97)Y:F4N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYE<&%V
M>6MO('-K86ET>71I("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D
M(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B
M"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HB3F5P879Y:V\@<&%K96ES=&D@<VQA<'1A_F]D
M_FEO(/!I86T@=F%R=&]T;VIU:2X@2V%I(&MU<FD@87)B82!V:7-A("(*(FEN
M9F]R;6%C:6IA('ER82!N971I:W-L:2X@4&%B86YD>6MI=&4@9&%R(&MA<G3@
M(&%R8F$@<W5S:7-I96MI=&4@<W4@<V%V;R`B"B)A9&UI;FES=')A=&]R:75M
M:2!J96EG=2!R96EK86QI;F=A('!A9V%L8F$N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M($%#3"(*;7-G<W1R(").97!A=GEK;R!G875T:2!!0TPB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R(").97!A=GEK;R!G875T:2!A9')E<_@@:VYY9V5LZW,N
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!G
M875T:2!D:7-T<FEB=6-I:F]S('/@<F'P;RX@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W1S+B`E<R(*;7-G<W1R(").97!A=GEK;R!G875T:2!D:7-T<FEB=6-I:F]S
M('/@<F'P^"X@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<R(*;7-G<W1R(").97!A=GEK;R!N=7-T871Y=&D@<V5R=F5R
M:6\@9V%L:6UY8FGX(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM
M<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M(").97!A=GEK;R!A=&ME:7-T:2!N=7-T871Y;?@N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!K
M871A;&]G;R`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(DYE<&%V>6MO(&GP<V%U9V]T:2`E<R!N=7-T
M871Y;?@N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DYE<&%V>6MO('!A9&%R>71I
M(&%T<V%R9VENZW,@;G5S=&%T>6WX(&MO<&EJ;W,N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S
M='(@(DYE<&%V>6MO('!A9&%R>71I(&%T<V%R9VENZW,@)7,@;G5S=&%T>6WX
M(&MO<&EJ;W,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO
M(&GP<V%U9V]T:2!A=&YA=6II;FEM;R!S:W)I<'0@X3H@)R5S)RXB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RXB"FUS9W-T<B`B3F5P879Y:V\@<&%D87)Y=&D@871S87)G
M:6[K<R`E<R!N=7-T871Y;?@@:V]P:6IO<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B).97!A=GEK;R!U_G)A\'ET:2X@
M2OMS(&=A;&ET92!A<F)A(&YA=61O=&ES(&%T;F%U:FEN:6UO('-K<FEP='4@
M87)B82!P871Y<R`B"B)N=6MO<&EJ=6]T:2!K;V3@(&%P8>AI;VIE(.$@)7,N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").
M97!A=GEK;R!P86EE\&MA($Q$05`@<V5R=F5R>6IE+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&YU=')A=6MT
M:2!R>?#A("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").97!A=GEK;R!A=&YA
M=6II;G1I(&MO;G1A:W1O+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(DYE<&%V>6MO(&%T;F%U:FEN=&D@9&ES=')I8G5C:6IO<R!SX')A\&\N
M("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO
M;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R(").97!A=GEK;R!U_G)A\'ET:2`G
M)7,G(&YU<W1A='EM^#H@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).
M97!A=GEK;R!R87-T:2!-;WII;&]S(.%R86YK:?@@:G5O<W1O<RX@P7-I=&EK
M:6YK:71E+"!K860@:FD@871I9&%R>71A+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S
M='(@(DYE<&%V>6MO('-U=&5I:W1I(/!I^"!T96ES:?@@=F%R=&]T;VIU:2`G
M)7,G(&MA=&5L;V=E("<E<R<Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E)I8F]T
M87,@=&5K<W1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(E9A;'-T>6+K(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*
M;7-G<W1R(")+=7)S86DB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*;7-G
M<W1R(")3=6MU<G1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM
M<V=S='(@(E-U:W5R=&D@;G5O<F]DX"(*"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B
M"FUS9W-T<B`B4W5K=7)T:2!N875JX"!A<')A\.`B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U
M8B!F;VQD97)S(@IM<V=S='(@(E-U:W5R=&D@<&%K871A;&]G:75S(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T
M;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4V%V:6YI;FMO('1E:7/K<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C
M87)D(&YU;6)E<B(*;7-G<W1R(")+<F5D:71I;NMS(&MO<G1E;.MS(&YU;65R
M:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A
M=&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B2W5B82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B0W5R
M<F5N="`T(%!H87-E<R(*;7-G<W1R(")$86)A<G1I;NL@9F%ZZR(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!3
M97-S:6]N<R(*;7-G<W1R(")3879I;FEN:V\@=&5I<^MS(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#
M=7)R96YT(%1I;64B"FUS9W-T<B`B1&%B87)T:6YI<R!L86EK87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(M!I=6\@;65T=2!5
M4DP@>7)A(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(D1A8F%R=&ENZR!F87KK(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T
M:&5R(@IM<V=S='(@(D1A8F%R=&ENZW,@;W)O('/@;'EG;W,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O
M;F1I=&EO;CH@(@IM<V=S='(@(D1A8F%R=&ENZW,@<^!L>6=O<SH@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I
M9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")$86)A<G1I;FES('-T:6QI=7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B5F5I:W-M^"P@871L:65K86WX('!R:7-I:G5N9W5S('!R
M:64@)7,L(&YU<W1A='EM87,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T
M<B`B4&5R:V5L=&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(E!E
M<FME;'1I('!A<VER:6YK:6W@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(DMI<')A<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+:7)I;&EC82`H
M2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")+:7)I;&EC82`H5VEN
M9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B2VER:6QI
M8V$O56MR86EN:65T:?!K82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(LAE:VEJ;W,@4F5S<'5B;&EK82(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB
M1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED
M(")$86EL>2(*;7-G<W1R(")+87-D:65N(@H*(SH@861M:6XO9&%T871R964N
M<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(D1U;VUE
M;O@@;65D_FEO(&YA<O!Y:VSK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0IM<V=I9"`B1&%T92(*;7-G<W1R
M(")$871A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z
M,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1V%U=&$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C
M=&EO;B(*;7-G<W1R(")$871O<R!P87-I<FEN:VEM87,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*;7-G<W1R(")$:65N82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B2?!T<FEN=&D@7W-T
M=6QP96SA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D=R=6]D:7,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&7P:6UT86EN
M:6%I('-K86GH:6%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@
M(E-U;6'^:6YT:2!A=&ET<F%U:VEMX"(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS
M9VED(")$969A=6QT(@IM<V=S='(@(E-T86YD87)T:6[K('-P86QV82(*"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS
M9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(E-T86YD87)T:6[K('-P86QV
M82(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G
M:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B4W1A;F1A<G1I;FES(&%P
M<F'P87,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*
M;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4W1A;F1A<G1I;NL@<W!A
M;'9A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")!<&EB<NO^:6UA:2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G
M<W1R("))\'1R:6YT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`B2?!T<FEN=&D@8V5LYB(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@
M1W)O=7`B"FUS9W-T<B`B2?!T<FEN=&D@9W)U<.8B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#D*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B2?!T<FEN=&D@96EL=73F(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B2?!T
M<FEN=&D@=&5I<^8B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R(")6:7-I\&MA:2!I\'1R:6YT:2!L86GP:W5S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B2?!T<FEN=&D@8V5LYB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*
M;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B2?!T<FEN=&D@<W1U;'!E
M;.$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E
M(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("))\'1R:6YT
M:2!E9WII<W1U;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO;N`B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B)R5S)R!T96ES:?@@=')Y;FEM87,B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(D%R('1I:W)A:2!N;W)I=&4@:?!T<FEN
M=&D@)R5S)R!T96ES97,@:7(@=FES87,@<&]T96ES97,_(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E(')O=R(*;7-G<W1R("))\'1R:6YT:2!E:6QU=.8B"@HC.B!T
M96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$
M96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B2?!T<FEN=&D@<&%S
M:7)I;FMTX"!A<')A\.`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6XB"FUS9W-T<B`B2?!T<FEN=&D@\.$@<W1U;'!E;.$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B
M2?!T<FEN=&D@\&G@(&5I;'5TYB(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E
M='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B071N875J:6YI
M;6\@<VMR:7!T87,@)R5S)R!I\'1R:6YT87,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM
M<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R(")0<FES=&%T>6UO(&QA:6MA
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N:6IA
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(E!R;V)L96UO<R!A<')A
M\'EM87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B07!R8?!Y;6%S(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B1&5T86QI874@*'1A:7`@
M<&%T(/YI^W+K:VET92!(;W)D92!L;V<@9F%I;&4I.B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")!9&UI
M;FES=')A=&]R:75I(&GP<VGX<W1A<R!D971A;'5S(&%P<F'P>6UA<RXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R(")6>7-T>6UA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B1'+K9VYU;6%S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1'+K9VYU;6%S('!A<VMU=&ENYB!V
M86QA;F3@.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W
M"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")$<NMG;G5M87,Z("(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G
M:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(DMR>7!T:7,@
M:?`@:V%I<NMS(.$@9&7P:6[F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O
M(&QE9G0B"FUS9W-T<B`B2W)Y<'1I<R!I\"!D9?!I;NMS(.$@:V%I<N8B"@HC
M.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM
M<V=S='(@(DMA=&%L;V=A<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B4F]D
M>71I(#(T+6GX('9A;"X@9F]R;6%TX#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R(")686EZ
M9&%V:6UO(&YU<W1A='EM86DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R
M96-A<W0B"FUS9W-T<B`B4F]D>71I('!R;V=R;V[F("A4048I(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*2(*;7-G<W1R(")2;V1Y=&D@<')O9W)O;N8@*%1!1BDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$:7-P;&%Y(&9O<FUA
M="(*;7-G<W1R(")686EZ9&%V:6UO(&9O<FUA=&%S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(DQA:?!K;R!P<FES=&%T>6UO('!R86YE\&EM
M86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$_FEB
M=71I<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS
M9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYE=')I;G1I(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T
M;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R(").97-I:W)E:7!K
M:71E('1I97-I;V=I86D@X2!M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE
M(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R
M(")!<B!P:7)M87,@X7)A\&%S('ER82!L875K;R!V87)D86D_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI:V$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M
M:6YI:V]S(%)E<W!U8FQI:V$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B071S:7-I^'-T:2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R(")!='-I<VGX
M<W1I("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,@IM<V=I9"`B
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="XB"FUS9W-T<B`B071S:7-I^'-T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU
M<R!K86EP(%!(4"!S:W)I<'3@+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(DGP<VES
M:VQE:63^:6%N=&ES('/@<F'P87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(E9A:7-T86DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*
M;7-G<W1R(")%;"X@<&'P=&\@861R97-A<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU3
M35,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E
M('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM
M<V=I9"`B15)2(@IM<V=S='(@(D524B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C
M=6%D;W(B"FUS9W-T<B`B16MV861O<F%S(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@
M(D5D:70B"FUS9W-T<B`B2V5I<W1I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS
M9VED(")%9&ET($)L;V-K(@IM<V=S='(@(DME:7-T:2!B;&]K;R!P87)A;65T
M<G5S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B4F5D86=U;W1I(&=R
M=7#F(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM<V=I9"`B161I="!097)M
M:7-S:6]N(@IM<V=S='(@(E)E9&%G=6]T:2!T96ES97,B"@HC.B!S97)V:6-E
M<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(E)E9&%G=6]T:2!T96ES97,B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S('1E:7-I^"!R961A9V%V:6UA
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@
M;W!T:6]N<R!F;W(Z(@IM<V=S='(@(DME:7-T:2!N=7-T871Y;75S.B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B
M"FUS9W-T<B`B)7,@=&5I<VGX(')E9&%G879I;6%S(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R!T96ES:?@@<F5D86=A
M=FEM87,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D
M=6-A=&EO;B(*;7-G<W1R(")59V1Y;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16=Y<'0B"FUS9W-T<B`B16=I<'1A<R(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B
M;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N
M.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV
M861O<B(*;7-G<W1R(")386QV861O<F%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(D5L96UE;G1A<RXN+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G
M<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B
M16UA:6PB"FUS9W-T<B`B16PN('!A\'1A<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%;"X@<&'P=&\@
M861R97-A<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;"X@
M<&'P=&\@861R97-A:2!T=7)I('-U=&%P=&DN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I
M;VXB"FUS9W-T<B`B16PN('!A\'1O(&%D<F5S87,@<W4@<&%T=FER=&EN:6UU
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR.3@*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R("+0>7!S96[K;.MS(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED
M(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+>:6YU=.L@='7PZ&EA+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*
M;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4F5Z=6QT871A<R!T=?#H
M:6%S+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*
M;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(").96YU<F]DZW1E
M('!A:67P:V]S('1E<FUI;O@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("),96ES=&D@=&5K<W1E
M(.%T97)P=&D@<&%V96EK<VSK;&EU<R!I\"!.=6]T<F%U:_@@9V%L97)I:F]S
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(L%J=6YG=&D@
M9&7P:6YI;VIO('!E;.MS(&UY9W1U:V\@;65N:74_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$Q"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")'86QI;FEA:2!M971A:2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*
M;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(DGP<&SK<W1I(')E9&%K
M=&]R:?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B
M"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T
M<B`B(@HBP7)A\'EK:71E(&ML875S:6W@+"!K=7)I<R!J=6US(&)U<R!U_F1U
M;W1A<R!J96EG=2!P86UI<O!I=&4@<V%V;R!S;&%P=&'^;V3A+"`B"B)P=GHN
M.B`G:V]K<R!Y<F$@2OMS^"!G>7;[;F\@=F%R9&%S/R<Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R
M"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BP79E
M<VMI=&4@<&%V96EK<VSK;&EO(%523"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R(")%:W9A=&]R:6[K($=V:6[K:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71RZVIA(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX
M,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B2VQA:61A(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")+
M;&%I9&$@<VEU;NAI86YT(&%T<V%K>6W@.B`E<RXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R
M(")+;&%I9&$@<VEU;NAI86YT(&%T<V%K>6W@.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R
M(")+;&%I9&$@<VEU;NAI86YT(&%T<V%K>6W@.B`E<RXB"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")+
M;&%I9&$@<VEU;NAI86YT(&%T<V%K>6W@.B`E<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R
M<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B2VQA:61A(&QA:?!K
M92XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B2VQA
M:61A(')A\&%N="`G)7,G+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B
M"FUS9W-T<B`B17-T:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B
M"FUS9W-T<B`B171I;W!I:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&YI;NMS(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T
M<B`B175R;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0IM<V=I
M9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R(")+87,@,34@;6EN=>AI^"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*;7-G:60@(D5V97)Y(#(@
M;6EN=71E<R(*;7-G<W1R(")+87,@,B!M:6YU=&5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS
M9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(DMA<R`S,"!S96MU;F3^
M:?@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R
M(")+87,@-2!M:6YU=&5S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B
M2VEE:W9I96YO('!R:7-I:G5N9VEM;R!M971U(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(DMA<R!P=7-V86QA;F3A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED(")%=F5R>2!M:6YU
M=&4B"FUS9W-T<B`B2V%S(&UI;G5TYB(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B
M4&%V>7ID_FEU:3HB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO
M8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@
M(D5X96-U=&4B"FUS9W-T<B`B5GEK9'ET:2(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C0W-0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(DGP<VML96ES=&DB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC
M.C,R"B,L(&9U>GIY"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")'
M86QI;FEA:2!M971A:2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")296EK86QI
M;F=A<R`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(E)E:6MA;&EN9V%S(/YO9&ES(&%R8F$@:V%B=73K
M<V4@X7)A\'ET87,@<&%I9?!K;W,@:W)I=&5R:6IU<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(D=A;&EO:FEM;R!D871A(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT(@IM<V=S
M='(@(D5K<W!O;F5N=.LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R
M(")496MS=&\@<W!A;'9A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W
M-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(").=7-T871Y
M;?@@<VEU;G1I;6%S('!E<B!&5%`N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RXB"FUS9W-T<B`B2VQA:61A(&YU<VMA:71A;G0@;G5S=&%T>6UU
M<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO('!R
M:7-I:G5N9W1I('!R:64@3$1!4"!S97)V97)I;RXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I
M('!R:64@4TU"('-E<G9E<FEO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!N=6MO<&EJ=6]T:2!I
M\"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R(").97!A=GEK;R!N=6MO<&EJ=6]T:2#A(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DYE
M<&%V>6MO('-U:W5R=&D@;F%U:F\@4T%33"!R>?!I;RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('!E<FME;'1I(.$@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM
M<V=S='(@(DYE<&%V>6MO('!E<FME;'1I(.$@7"(E<UPB+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER
M(@IM<V=S='(@(M!V96QN=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N
M9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B1F]L:VQA;F3X('-A;&]S
M("A-86QV:6YA:2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S
M(@IM<V=S='(@(D9A<F5R^"!S86QO<R(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)
M+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R
M(")+<FET:6[K(&ML86ED82$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<V%S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%K<V%S(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(E9A<V%R:7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM
M<V=I9"`B1F5E;',@3&EK92(*;7-G<W1R(")!=')O9&\@;'EG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B1F5E;',@;&EK
M93H@(@IM<V=S='(@(D%T<F]D;R!L>6<Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*
M;7-G<W1R(")4<G5M<&%L86EK:7,@;&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(D9E
M=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4/MG82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED(")&
M:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9/YI<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B
M1FEL92(*;7-G<W1R(")F86EL87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F
M:6QE(@IM<V=S='(@(D9A:6SX('-K86GH:75S.B`E<R!F86EL87,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")&86EL^"!S:V%IZ&EU
M<SH@)7,@9F%I;&%I*/@I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(D9A:6SX('1V87)K
M>6UA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`B1F%I;&\@<&%V861I;FEM87,B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO
M;B(*;7-G<W1R(")&86EL;R!P87-I<FEN:VEM87,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M(")&86EL;R!S:75N=&EM87,B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R(").87+P>6MLZR!N97!A;&%I:V\@9F%I;/@@<VEU;G1I;6\N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT
M97)S(@IM<V=S='(@(D9I;'1R86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL
M86YD(@IM<V=S='(@(E-U;VUI:F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(E!I<FUO:FD@<'5SZR(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B4&ER;6%S:7,@:V5T
M=FER=&ES(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(DYU<W1A='ET87,@
M:V]E9FEC:65N=&%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R(")!='9I<FOPZ&EA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(DGP9.MS='EM87,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I
M9"`B1F]G(@IM<V=S='(@(E+[:V%S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B
M"FUS9W-T<B`B2V%T86QO9V%S("5S(&YE96=Z:7-T=6]J82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`B5&5K<W1O('-P86QV82(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")-86ES=&%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<R(*;7-G<W1R(").87+P>6MLZVUS+"!K=7)I;W,@;F5P
M86QA:6MO('!A=F5I:W-LZVQI^"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")/<O@@<')O9VYO
M>NL@*%1!1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*
M;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N
M960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB
M;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C
M:RDB"FUS9W-T<B`B(@HB3W+X('!R;V=N;WKK<R!A<&EM=&ES("CA<VEDZVWK
M:VET92P@:V%D(/!I(&9U;FMC:6IA(&=R8?YI;F$@:7(@9&EE;F]S(&ER("(*
M(FYA:W1I97,@<')O9VYO>N8[('!E<B!D:61E;&ES('-K86GH:75S(&=A;&D@
M<W5D87)K>71I(&1I>F%I;N`I(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R
M(")086UI<O!O=&4@<V%V;R!S;&%P=&'^;V3A/R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(D9O<FUO
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N
M92(*;7-G<W1R(")&<F%ZZR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(D9R87II^"!T:7!A<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B1G)A>NMS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y
M"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(D9R87KK<R`R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S
M='(@(D1I<VMU<VEJ;W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")097)S:75N=&EM86DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS
M9VED(")&<B(*;7-G<W1R(")096YK+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*
M;7-G<W1R(")+<F'P=&ENZW,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B
M"FUS9W-T<B`B4')A;F/[>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T
M<B`B4')A;F/[>FEJ82P@365T<F]P;VQI<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B4')A;F/[>FEJ;W,@1W9I86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M4')A;F/[>FEJ;W,@4&]L:6YE>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(E!R86YC^WII
M:F]S('!I971I;NMS('1E<FET;W)I:F]S(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R
M(").=6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(DYU;R`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM
M<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")0:6QN87,@87!R8?!Y
M;6%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")0:6QN871I<R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
M4&EL;F%S('9A<F1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S
M='(@(D=A8F]N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R:6IA(&GP(&MU<FEO<R!I\"!K
M=7)I;W,@8G5S(')O9&]M87,@<&%V96EK<VSK;&ES(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS
M9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEJ83HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'86UB:6$B"FUS9W-T<B`B1V%M8FEJ82(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A
M=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<G5O=&D@)7,@;G5S
M=&%T>6UU<R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M
M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")3=6=E;F5R=6]T
M87,@:V]D87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(D=R=7II:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@
M(E9O:VEE=&EJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@
M(D=A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B
M1VEB<F%L=&%R87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")687)D87,B"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T
M<B`B4F]D>71I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED
M(")';V5D96PB"FUS9W-T<B`B1V%D96QI<R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")'
M;V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@<&%I9?!K82(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS
M9W-T<B`B1V]O9VQE('!A:67P:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`B3F5S<&%L=F]T87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(D=R86EK:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*
M;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<F%I:VGP:V$@
M*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM
M<V=S='(@(D=R96YL86YD:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D
M82(*;7-G<W1R(")'<F5N861A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*
M;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D=R=7!I^"!A
M9&UI;FES=')A=FEM87,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP
M.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@
M(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7#K
M<R!V87)D87,@='5R:2!B^W1I(&YE='7PZ&EA<R(*"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD
M87`Z('-U:W5R=&D@=F%R=&]T;VK@("5S(&YE<&%V>6MO+B!397)V97)I;R!P
M<F%N9?!I;6%S.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T
M92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z(&%T;F%U:FEN=&D@=F%R
M=&]T;VK@("5S(&YE<&%V>6MO(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,S<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@
M871N875J:6YT:2!V87)T;W1O:N`@)7,@;F5P879Y:V\B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B
M1W)O=7!S(@IM<V=S='(@(D=R=7#K<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U
M861E;&]U<&4B"FUS9W-T<B`B1W9A9&5L=7#K(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U86TB"FUS9W-T<B`B1W5A;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M1W5A=&5M86QA(@IM<V=S='(@(D=V871E;6%L82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=E
M<FYS:7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M
M:7-S:6]N<R(*;7-G<W1R(")3=F7H:?@@=&5I<^MS(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@
M(E-V9>AI^"!K;GEG82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G
M<W1R(")'=FENZVIA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES
M<V%U(@IM<V=S='(@(D)I<W-A=2U'=FENZVIA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=7EA;F$B"FUS9W-T<B`B1V%J86YA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;F5G
M86QI(&GP=')I;G1I('!A<VMU=&ENZW,@8V5LZW,@96EL=73K:F4N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N
M96=A;&D@:?!R:6YT:2!P87-K=71I;FEO('-T=6QP96QI;R!L96YT96SK:F4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E
M82!N96=A;&D@:?!T<FEN=&D@<&%S:W5T:6[K<R!E:6QU=.MS(&QE;G1E;.MJ
M92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I
M9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E)E
M:6MA;&EN9V$@2%144"!A=71E;G1I9FEK86-I:F$N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:7,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(DAA<V@M06QG;W)I=&UA<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@
M(DUI9VQA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R
M(")!;G1R8?!TZR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M06YT<F'P=.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(97)D;R!S86QA(&ER($UA
M:V1O;F%L9&\@<V%L;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PHC+"!F=7IZ>0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*
M;7-G<W1R(")4+6%U9')A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*
M;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R86KX
M("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@
M(D%U:_!T:7,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`B4&%G86QB82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE
M;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(E)E9&%K=&]R:6%U<R!N875D;VII
M;6]S:2!P86=A;&)A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W
M,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(E!A9V%L8FEN:6YK87,B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T
M<B`B2&5M:7-F97)A(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@
M:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`BT'1A:2#H
M:6$@>7)A(&9A:6QO('!R863^:6$Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B4W9A
M<F)U(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E
M<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G
M<W1R(")?4&]R=&%L87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("+0=F5N=&%S:7,@4V]S
M=&%S("A6871I:V%N;R!V86QS=&EJ82DB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`B4&]R=&%L87,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*
M;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(").86WX(&%D<F5S87,B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(DAO
M;64@1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V=A<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(DAO;64@
M4&AO;F4B"FUS9W-T<B`B3F%M^"!T96QE9F]N87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F3[<F%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N:V]N9V%S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G
M<W1R(")0;W)T86QA<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z(&YE=&5I<VEN9VD@)7,@6$U,(&1U;VUE;GES(/YI
M;G5TZVIE("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@
M8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!O8FIE:W1O("5S(&YE871I=&EN:V$@:F]K:6$@_FEN=73K(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&]B:F5K=&\@=&EP
M87,@)7,@;F5R87-T87,@_FEN=73K:F4@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@)7,@7"(E<UPB('/K:VUI;F%I(&GP=')I;G1A(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E
M+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G
M9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!I
M;G1E9W)A8VEJ;W,@=F%R:6ML:75K=6D@<F5I:V%L:6YG87,@)V1O;7AM;"<@
M4$A0(&UO9'5L:7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@;F5P879Y:V\@<W5K=7)T:2!N875J;R!834P@;65D_FEO
M(&]B:F5K='5I("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M(&YE<&%V>6MO(&GP=')I;G1I("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(&YE<&%V
M>6MO(&=A=71I($U)344@240@9&%L:6%I("5S('1I<&\B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!N97!A=GEK;R!S=7-I;F-H<F]N
M:7IU;W1I("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!N97!A=GEK;R!S=7-I;F-H<F]N:7IU;W1I(&5L96UE;G3X
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@;F7^:6YO;6%S(&5L96UE;G1A
M<R!<(B5S7"(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B2&]R
M:7IO;G1A;&D@;&EN:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM
M<V=S='(@(DAO<FEZ;VYT86QU<R!T87)P87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L
M.B(*;7-G<W1R(")(;W)I>F]N=&%L:6%I.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W
M(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B
M2V%I<"#H:6$@<&%T96MO=&4_("A0<F%N9?!K:71E(2DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED
M(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R(")+:65K('-T=6QP96QI^"!N;W)I=&4@<W5J=6YG=&D_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")+:65K(&QA
M=6OX("AS='5L<&5L:?@I('1E;B!Y<F$_(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2VEE
M:R!E:6QUZ&GX(&YO<FET92!S=6IU;F=T:3\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS
M9VED(")(=6UI9&ET>2(*;7-G<W1R(")$<NMG;G5M87,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM
M<V=S='(@(D1RZV=N=6UA<SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B2G5M;W)E<VMO<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R(")696YG<FEJ82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G
M:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@
M(DYE<&%V>6MO('-U:W5R=&D@24U!4"!P8?!T;R!DZ_YU=.MS.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DYE
M<&%V>6MO(&GP=')I;G1I($E-05`@<&'P=&\@9.O^=73K<SH@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M(").97!A=GEK;R!N=7-T871Y=&D@24U!4"!P8?!T;R!DZ_YU=.MS(&1Y9/YI
M;SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED
M("))4"!!9&1R97-S(@IM<V=S='(@(DE0(&%D<F5S87,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DYE<&%V>6MO(&=A=71I($E0(&%D
M<F5S;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("))4"!A9')E<V%S(&YE=&5I<VEN9V%M92!#2412(&)L
M;VME+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("))4"!U_G)A:VEN=&%S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2
M;W<@0F5F;W)E(@IM<V=S='(@(E_!=&5R<'1I(&5I;'5TYB!V:7+P=6IE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9&EJ
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS
M($]N;'DB"FUS9W-T<B`B5&EK('!I:W1O9W)A;6]S(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))
M8V]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@;G5S=&%T>6UA:2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*
M;7-G<W1R(")0:6MT;V=R86UO<R!S=2!T96MS='4B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S
M='(@(D%P<F'P;R!P879A9&EN:6UA<SHB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")*96D@;F5G86QI=&4@<&5R<VMA
M:71Y=&D@\&EO(&QA:?!K;RP@)7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B
M(@HB2F5I9W4@;6%T;W1E(/!IX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI
M;RP@:W5RX2!N;W)I=&4@X6ME;'1I+"!T86D@2OMS^"`B"B)N87+P>6MLZR!N
M96=A;&D@:F\@871V86EZ9'5O=&DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G
M92!0<F5V:65W.B(*;7-G<W1R(")0879E:6MS;.ML:6\@<&5R_FG[<F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B4&%V96EK<VSK;&EO(%52
M3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")0879E
M:6MS;.ML:6\@55),.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y(@IM<V=S='(@(E!A=F5I:W-LZVQI<R!I\"!G86QE<FEJ;W,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B
M4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<SHB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B
M4&%V96EK<VSK;&EO(.%KZVQI;6%S(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")686EZ9&%I(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`BP6OK;&EM87,L("5D(/YI;F=S
M;FES(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(DQA
M=6MA<R#A:V5L=&%S.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`BP6ME;'1I
M(&QA=6MA:3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM
M<V=S='(@(L%?=&5R<'1I(&5I;'5TYB!A<&'H:6]J92(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(").971E:7-I;F=A<R!V
M96EK<VUO(&MO9&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(").971E:7-I;F=A<R!V87)T;W1O
M:F\@=F%R9&%S(&ER+V%R8F$@<VQA<'1A_F]D:7,N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@HB3F5I=&5I<VEN9V%S('9A<G1O=&]J;R!V87)D
M87,@87)B82!A;'1E<FYA='EV=7,@96PN('!A\'1O(&%D<F5S87,N($)A;F1Y
M:VET92`B"B)D87(@:V%R=.`@87)B82!S=7-I<VEE:VET92!S=2!S879O(&%D
M;6EN:7-T<F%T;W)I=6UI(&IE:6=U(')E:6MA;&EN9V$@(@HB=&]L97-NZR!P
M86=A;&)A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")0861I
M9&EN=&D@871I=')A=6MI;>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA
M(@IM<V=S='(@(DEN9&EJ82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED
M("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(DEN9&EV:61U86S[<R!V87)T
M;W1O:F%I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B26YD;VYE>FEJ82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M86-I
M:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("))
M;F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VEJ82(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DYU<W1A='EM
M^"!NZW)A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B
M"FUS9W-T<B`BP71R875K=&D@<W1U;'!E;.$@7V1E\&ENZVIE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`BP71E<G!T:2!P879E
M:6MS;.MLX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("+!=&5R<'1I
M(&QE;G1E;.8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BP71E
M<G!T:2!N=6]R;V3@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M;B!"
M969O<F4B"FUS9W-T<B`BP71E<G!T:2!S='5L<&5LX2!?:V%I<NMJ92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`BP71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M
M;R!S='5L<&5L:6\@9&7P:6[K:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+!
M=&5R<'1I(&YA=6K@('-T=6QP96SA(&5S86UO('-T=6QP96QI;R!K86ERZVIE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("+!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M
M;W,@96EL=73K<R!A<&'H:6]J92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(L%T97)P
M=&D@;F%U:N`@96EL=73F(&5S86UO<R!E:6QU=.MS('9I<O!U:F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(L%T97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P
M8>AI;VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A
M9^`@96QE;65N=&\@=FER\'5J92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(L%T97)P=&D@86QT97)N871Y=O@@\&%B;&]NX"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*
M;7-G<W1R("+!<F'P>6MI=&4@96PN('!A\'1O(&%D<F5SX"P@X2!K=7+A(&YO
M<FET92!G875T:2!N875JX"!S;&%P=&'^;V3A.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN
M<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(L%T97)P=&D@8V5LYB!P;R!T;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("+!=&5R
M<'1I(&-E;.8@<')I9?`@=&%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M
M;B!A9G1E<B(*;7-G<W1R("+!=&5R<'1I('-T=6QP96SA(&1E\&ENZVIE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`BP71E
M<G!T:2!S='5L<&5LX2!K86ERZVIE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*
M;7-G<W1R("+!=&5R<'1I(&QA:?!K=7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`BP71E<G!T:2!P87)A9W)A9N`@
M<&\@=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E
M(@IM<V=S='(@(L%T97)P=&D@<&%R86=R86;@('!R:67P('1A:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*
M;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`BP71E<G!T:2!E:6QU
M=.8@<&\@=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G
M<W1R("+!=&5R<'1I(&5I;'5TYB!P<FEE\"!T86DB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N
M<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(L%R8?!Y
M:VET92!R96EK:6%MX"!A='-A:WEMX"#A(&ML875S:6W@('9I<O!U:F4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM
M<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("+!=&5R<'1I+W)E
M9&%G=6]T:2!P879E:6MS;.MLX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("+!=&5R<'1I+U)E9&%G=6]T:2!N=6]R;V3@(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(D1I<W1R:6)U8VEJ;W,@<^!R8?!U:2!N
M=7-I^'-T:2!N977^=&5N:V$@:W)E9&ET;RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="XB"FUS9W-T<B`B3F5U_G1E;FMA(&MR961I=&\N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R(")3:V%IZ&EU<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")3:V%IZ&GX
M('/@<F'P87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN(@IM<V=S='(@(DYE=&5I<VEN9V%S(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$W,`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HR,#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,C$P"B,L(&9U>GIY"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S
M='(@(DYE=&5I<VEN9VD@=6YI:V]D;R!D=6]M96YY<RXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R(").971E:7-I;F=A<R!M;V1U;&ES+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B
M26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B3F5T96ES:6YG87,@240N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("+!=F5S=&D@;F5T96ES:6YG:2!D
M=6]M96YY<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B3F5T96ES:6YG87,@861R97-A<RXB"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED
M(&9I;&4@9F]R;6%T(@IM<V=S='(@(DYE=&5I<VEN9V%S(&9A:6QO(&9O<FUA
M=&%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-PHC+"!F
M=7IZ>0IM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B3F5T
M96ES:6YG87,@;6]D=6QI<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R(").971E:7-I;F=A<R!M;V1U;&ES+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM
M<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B3F5T96ES:6YG87,@
M;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R(").971E:7-I;F=A<R!A<F)A(&[K<F$@87!I7VED+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM
M<V=S='(@(E!A<F%M971R86D@;F5T96ES:6YG:2!A<F)A(&KX(&[K<F$N(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(").971E:7-I;F=O<R!P879E
M;&1I;6]S('1E:7/K<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM
M<V=S='(@(DYE=&5I<VEN9V]S('!A=F5L9&EM;W,@=&5I<^MS+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(").971E:7-I;F=A<R!P
M<F]T;VMO;&%S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`B3F5T96ES:6YG87,@<')O=&]K;VQA<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R(").971E
M:7-I;F=A<R!G87;K:F%S.B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM
M<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B3F5T96ES:6YG
M87,@;V)J96MT87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E
M<W,N(@IM<V=S='(@(DYE=&5I<VEN9V%S('-I=6YTZVIO(&%D<F5S87,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B3F5T
M96ES:6YG:2!U;FEK;V1O(&1U;VUE;GES+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E
M;G1O<FEU<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS
M9W-T<B`B4&5R:V5L=&D@<&%S:7)I;FMI;>`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27-L86UI
M\&MA($ER86YO(%)E<W!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER
M87$B"FUS9W-T<B`B27)A:V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L
M86YD(@IM<V=S='(@(D%I<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-96YO('-A
M;&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B27IO;&EU;W1O
M<R!4+6%U9')O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S
M='(@(DEZ<F%E;&ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("))\&1A=NMJ87,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R(")+=7)S>79A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B4V%U<VES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*
M;7-G<W1R(")*87!O;FEJ82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W
M"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N
M:?!K82`H25-/+3(P,C(M2E`I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L
M960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B
M"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R
M(")$_F5R<VES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T
M<B`B2F]R9&%N:6IA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B3&EE<&$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B
M2G5N92(*;7-G<W1R(")":7+^96QI<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB
M"FUS9W-T<B`B4&EL;F%I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R
M(@IM<V=S='(@(DQY9VEU;W1I(&-E;G1R92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T
M:69Y($9U;&PB"FUS9W-T<B`B3'EG=6]T:2!P:6QN86DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I
M9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(DQY9VEU;W1I(&MA:7+K:F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("),>6=I=6]T:2!D
M9?!I;NMJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G
M<W1R(")+87IA:W-T86YA<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S
M='(@(DGP<V%U9V]T:2!O<FEG:6YA;.`_(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")+96YY82(*;7-G<W1R(")+96YI:F$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N
M9W1I('!R:64@2V5R8F5R;W,@<V5R=F5R:6\N(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")"
M<F%N9'5O;&EO(&YA=6IO:V%I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B4F%K
M=&\@:_MR:6UA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(E)A:W1O(&%T
M<W!A=61A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")286MT;R!I;&=I<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B4F%K=&\@=&EP87,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S
M='(@(E)A:W1O('!A;F%U9&]J:6UA<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")286MT87,@:F%U('ER
M82!V:67P^&KX(')A:W3X('-E<G9E<GEJ92XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B5F%I:V%I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(D1E;6]K<F%T:6[K($MO<NMJ;W,@
M3&EA=61I97,@4F5S<'5B;&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO<NMJ;W,@4F5S<'5B;&EK82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(")+;W)E86X@*$55
M0RU+4BDB"FUS9W-T<B`B2V]RZVII971I\&MA("A%54,M2U(I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5V96ET87,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VEZ:6IA
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y
M;W5T(@IM<V=S='(@(E])\&3K<W1Y;6%S(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2V%L8F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(DQA;W-O($1E;6]K<F%T:6[K($QI875D:65S
M(%)E<W!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED
M("),87-T($AA;&8B"FUS9W-T<B`B06YT<F$@<'5SZR(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!087-S=V]R
M9"!#:&%N9V4B"FUS9W-T<B`B4&%K96ES=&D@<VQA<'1A_F]DX2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G
M:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")087-K=71I;FES(&ME='9I<G1I
M<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P
M9&%T960Z(@IM<V=S='(@(D%T;F%U:FEN=&$Z(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G
M:6XZ("5S(@IM<V=S='(@(E!A<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")087-K
M=71I;FES('!R:7-I:G5N9VEM87,Z("5S(&GP(&%D<F5S;R`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`B4')I<VEJ=6YGZW1E('!I<FW@(&MA<G3@(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B3&%T=FEJ82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@
M(E1E:7/K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B2?!DZW-T>6UA
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B
M2F5I9W4@;F5N;W)I=&4@;F5N875D;W1I(&MR8?!T^"P@<&%L:6MI=&4@='7P
MZ&G@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI
M8F%N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B2V%I<NMJ92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A
M9&5R(@IM<V=S='(@(DMA:7)I;VII(&%N=')A\'3K(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T
M<B`B2V%I<FEO<VEO<R!R96EK\&WK<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("),97-O=&%S(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED("),979E;"(*;7-G<W1R
M(")-96ELZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R
M("),:6)E<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@
M2F%M86AI<FEY82(*;7-G<W1R("),:6)I:F]S($%R86+X($5M>7)A=&%I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI
M8VAT96[P=&5I;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B4VUU
M;&MU<R!L:65T=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(").961I9&5L
M:7,@;&EE='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B3F5D
M:61E;&ES(&QI971U<R!R>71E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G
M<W1R(").961I9&5L:7,@;&EE='5S('9A:V%R92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN
M(%-H;W=E<B(*;7-G<W1R(").961I9&5LZR!L:?MT:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3F5D:61E;&ES(&QI971U<R!S
M=2!P97)K^VYI:F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R(").961I9&5L
M:7,@<VYI96=A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R(").
M961I9&5LZR#P;&%P9')I8F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI;65R:6MA<R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T
M<B`B3G5O<F]D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM
M<V=S='(@(DYU;W)O9&$@X3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C
M;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(E!A9&%R>71I
M(&5L+B!P8?!T;R!A9')E<^`@;G5O<F]D82#A(&QA:?!K;R!R8?!Y;6\@<'5S
M;&%PX2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T
M97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(DYU;W)O9&]S(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K
M:64B"FUS9W-T<B`B3&EN=7@@;&%I;>MS(/YI;G5TZW,B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(E)O9'ET:2`M('9A
M<G1O=&]J87,@9V%L:2!M871Y=&D@:V%T86QO9V\@='5R:6[A(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS
M9W-T<B`B4F]D>71I(&1U;VUE;O@@8F%Z:?@@<^!R8?#@(@H*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B
M"FUS9W-T<B`B4F]D>71I('!A9V%L8F]S('1E;6%S(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B4F]D
M>71I(&QE;G1E;&GX('/@<F'PX"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B
M2V]N9F5R96YC:6IO<R!A<F-H>79A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B
M2V]N9F5R96YC:6IO<R!P86=A;&)A(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B2V]N
M9F5R96YC:6IO<R!)1"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DMO;F9E<F5N
M8VEJ;W,@<V%V:6YI;FMA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B4F'P>71I
M(.$@:V]N9F5R96YC:6K@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(E!R
M:7-I:G5N9W1I('!R:64@:V]N9F5R96YC:6IO<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R
M:6)E(@IM<V=S='(@(D%T<VEJ=6YG=&D@;G5O(&MO;F9E<F5N8VEJ;W,B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")6
M87)T;W1O:O@@<^!R8?!A<R!U_F1R875S=&%S+B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HS-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN
M9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(E9A<G1O=&]J^"!SX')A\&%S
M('7^9')A=7-T87,N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R(")687)T;W1O:O@@<^!R8?!A<R!U_F1R875S=&%S+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R
M("),:71E<F%T^W)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B
M"FUS9W-T<B`B3&EE='5V82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B
M2W)A=6YA+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(E9I971I;FES(&QA:6MA
M<SH@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A
M;&4@86YD(%1I;64B"FUS9W-T<B`B3&]K86SK(&ER(&QA:6MA<R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS
M9W-T<B`B5FEE=&$B"@HC.B!L;V=I;BYP:'`Z,3<R('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ.3$@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,PHC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B4')I
M<VEJ=6YG=&DB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*
M;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B
M3&]G(&]U="(*;7-G<W1R(")!='-I:G5N9W1I(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R(")0
M<FES:6IU;F=T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(E!R:7-I:G5N9VEM;R!D87)B86DB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G:60@(DQO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(E!R:7-I:G5N9W1I
M(&YE<&%V>6MO+B!.971E:7-I;F=A<R!*^W/X(&YU<F]D>71A<R!V87)T;W1O
M:F\@=F%R9&%S(&ER+V%R("(*(G-L87!T8?YO9&ES+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G
M<W1R(")0<FES:6IU;F=T:2!N97!A=GEK;RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B26QG
M87,@=&5K<W1A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I
M9"`B3&]V92(*;7-G<W1R(")-96ELZR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B3F5S
M=F%R8G4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM
M<V=S='(@(DUA_F]S:6]S(&=R86EK:?!K;W,@<F%I9.MS(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM
M<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")-8?YO<VEO<R!L
M;W1Y;FGP:V]S(')A:63K<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N
M(&YU;6)E<G,B"FUS9W-T<B`B36'^:65J:2!R;VWK;FGP:VD@<VMA:>AI86DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B3&EU
M:W-E;6)U<F=A<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB
M"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q
M"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A
M8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")0<FEK86)I;G1A
M;64@35,M5$Y%1B!F86EL92!NZW)A(&1U;VWK;O@N(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36%C86\B"FUS9W-T<B`B36%K86\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9B(*;7-G<W1R(")-86ME9&]N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-K87)A<R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:6IA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL
M(@IM<V=S='(@(E!A\'1A<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,C(*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B4&'P=&\@=F%L9'EM
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B4W5K
M=7)T:2!?;G5O<F]DX"XN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(DUA;&%V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y
M<VEA(@IM<V=S='(@(DUA;&%I>FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B
M36%L9&EV97,B"FUS9W-T<B`B36%L9'EV86DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA;&DB"FUS9W-T<B`B36%L:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;'1A(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*
M(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B
M"B)+871E9V]R:6KX('/@<F'P;RP@:W5R:6]M<R!P<FES:VER:6%M:2!O8FIE
M:W1A:2P@:7(@<W4@:F]M:7,@<W5S:6IU<VGX("(*(G-P86QV^"!K96ET:6UA
M<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(/YE;>ML87!I
M<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,38X"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W0@_F5M
MZVQA<&ES(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS
M9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R(")+;W9A<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")0
M87)A\'3K(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R(")08?YY;>MT:2!K86EP('-K86ET>71U<R]N97-K86ET>71U<R(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R(")08?YY;>MT:2!K:71A:7,@871R:6)U=&%I<R`H<'9Z
M+B!S=F%R8G4O871S86MY=&$I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S
M:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<O!A;&\@<V%L;W,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:6MA(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H
M:6YG(&9I96QD<R(*;7-G<W1R(")3=6IU;F=T:2!L875K86DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FET86YI:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R
M:6-I:G5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S
M='(@(DUA:W-I;6%L=7,@:W)E9&ET87,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S
M<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B36%K<VEM86QU<R#^:6YU
MZ&GX(&1A;&GX(&MI96MI<R!I\&5I:W9O=&%S+B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`B36%K<RX@=&5M<"X@<&%S:RX@,C0@=F%L.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B36%K<RX@=&5M<"X@<&%S:RX@-B!V86PZ("(*"B,Z
M(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T
M86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H
M(@IM<V=S='(@(DUA:W-I;6%L=7,@:6QG:7,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@
M(D=E9W7^ZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T
M<B`B36]J;W3K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED
M(")-961I8VEN92(*;7-G<W1R(")-961I8VEN82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T
M<B`B3F%R:6%I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I
M9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96YI=2!R9?YI;6%S.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*
M;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(E-U:G5N9W1I(&-E;&5S(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BWFEN=73K(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R
M("(B"B),86GP:V%S('!A=FER=&EN=&%S+"!T8>AI874@;F5P871V:7)T:6YT
M87,@<&%S:7)A\&EU<VEO(&%S;65N<R!S97)T:69I:V%T87,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS
M9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(MYI;G5TZR!N96GP<VGX
M<W1A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G
M<W1R("+>:6YU=.MS('1I<&%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(D]R;R!S86QY9V]S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W)O('/@;'EG^"!B;&]K;R!NZW)A
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A
M<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")/<F\@<^!L>6?X
M(&)L;VMO(&[K<F$N($%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L
M=7,@87!R8?!Y;6%S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED
M(")-971H;V0B"FUS9W-T<B`B365T;V1A<R(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z
M,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB
M(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D87,@)R5S)R!N96%P<F'P
M>71A<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I
M8R(*;7-G<W1R(")-871A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O
M(@IM<V=S='(@(DUE:W-I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE>FEJ
M;W,@1F5D97)A8VENZW,@5F%L<W1I:F]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B
M"FUS9W-T<B`B5FED=7)Y:F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DU)
M344@=&EP87,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUI;BX@=&5M<"X@
M<&%S:RX@,C0@=F%L.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM
M<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B36EN+B!T
M96UP+B!P87-K+B`V(&AO=7)S.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"FUS9VED(")-:7)R;W(B"FUS
M9W-T<B`B071S<&EN9'ES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q
M"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DMI=&]S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS
M9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S
M='(@(DYE<F%S=&%S(%!%05(@2%144%]297%U97-T('!A:V5T87,N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@
M(B(*(DYU<W1A='EM^"!NZW)A+B!*96EG=2!N;W)I=&4@;F%U9&]T:2#PX2!M
M;V1U;.$L('1U<FET92!JX2!S=6MO;F9I9_MR=6]T:2XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@
M(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B3NMR82#^:6YU=.MS($E$
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M
M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G
M92!-86EL+B(*;7-G<W1R(").97)A<W1A<R!R96EK86QI;F=A<R!014%2($UA
M:6P@<&%K971A<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB
M"FUS9W-T<B`B3NMR82!S97-I:F]S($E$+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@
M(E!I<FTN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED
M(")-;V)I;&4@36%I;"(*;7-G<W1R(")-;V)I;'5S('!A\'1A<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-
M;V1E<F%T92(*;7-G<W1R(")6:61U=&EN:7,B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")2
M961A9V%V:6UO(&1A=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS
M9W-T<B`B2V5I<W1I(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L:7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DUO;&1O=F]S(%)E<W!U8FQI:V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA:V%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS
M9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI:F$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*
M;7-G<W1R(")-ZVYE<VEA:2!I<B!M971A:2(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS
M9W-T<B`B2V%S(&WK;F5SX2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E
M<G)A="(*;7-G<W1R(")-;VYS97)A=&%S(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E
M<R(*;7-G<W1R(")-ZVYU;&EO(&9A>NMS(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L
M:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;VMA<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED
M(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B1&%U9VEA=7-I82!G:65D<F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I
M9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")$875G:6%U<VEA(&%P<VEN875K
MYB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U
M"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B1&%U9VEA=7-I82!S875L
MZW1A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y
M"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B4&5R:V5L=&D@_F5M:6%U(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED
M(")-;W9E($QE9G0B"FUS9W-T<B`B4&5R:V5L=&D@:V%I<FEA=2(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V
M92!2:6=H="(*;7-G<W1R(")097)K96QT:2!D9?!I;FEA=2(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5
M<"(*;7-G<W1R(")097)K96QT:2!A=6OPZ&EA=2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R(")097)KZVQI;6%S(/YE;7EN(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM
M<V=S='(@(E!E<FOK;&EM87,@875K\'1Y;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I:V%S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S(@IM<V=S='(@(DME;&5T;R!L>6=I^"!I\'-I<VML96ED
M_FEA;G1I<R!SX')A\&%S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED
M(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B2V5L971A<R!P87-I<FEN
M:VEM^"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@
M(DUY($%C8V]U;G0B"FUS9W-T<B`B36%N;R!SX'-K86ET82(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VEJ82!A<&EE($IU<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O
M<G1A;"(*;7-G<W1R(")-86YO('!O<G1A;&%S(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R(")-86YO('!O<G1A;&\@:?!DZW-T>6UA<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-86EN;6%R87,B"@HC.B!T96UP;&%T
M97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L
M($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY%+"!.15-55$E.2U4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R
M(")687)D87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T
M<B`B3F%M:6)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S
M='(@(DYA=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T
M<B`B3F5P86QA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B
M"FUS9W-T<B`B3GED97)L86YD86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T
M:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B3GED97)L86YD^"!!;G1I;&%I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G
M:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(DYE='-C<&%P92!B87II
M;FES(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R
M(").971S8W!A92!S97)I9FEK871O(&%T\&%U:VEM;R!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8W!A92!S97)T:69I:V%T
M;R!T96ES:?@@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@
M(DYE='-C87!E(&%T;F%U:FEN;VUO(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2979O8V%T
M:6]N(%523"(*;7-G<W1R(").971S8V%P92!A=/!A=6MI;6\@55),(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE
M='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!34TP@
M<V5R=F5R:6\@=F%R9&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE
M;G0B"FUS9W-T<B`B3F5T<V-A<&4@<V5R=&EF:6MA=&\@87!R8?!Y;6%S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T<V-A<&4@
M<V5R=&EF:6MA=&\@=&EP87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(E1I;FML87,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS
M9VED(").979E<B(*;7-G<W1R(").:65K861A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYA=6IO:FD@2V%L961O;FEJ
M82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N
M:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F%U:F$@:V%T
M96=O<FEJ82(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA
M:6QS+G!H<#HX,0HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.#<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.CDW"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HQ,#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYE
M=R!-97-S86=E('1O("5S(@IM<V=S='(@(E)A\'ET:2!L86GP:^`@*"5S*2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS
M9W-T<B`B3F%U:F%S(&WK;G5L:7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L
M*2(*;7-G<W1R(").875J87,@=F%R=&]T;VIO('9A<F1A<R`H;F5B^W1I;F%S
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B
M3F%U:F]J:2!:96QA;F1I:F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R
M(")3;&%P=&'^;V1I<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@
M9&]N)W0@;6%T8V@N(@IM<V=S='(@(E-L87!T8?YO9/YI86D@='5R:2!S=71A
M<'1I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F%U
M:F%M92!L86YG92`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").97=S(@IM<V=S='(@(DYA=6II96YO
M<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE
M=W-G<F]U<',B"FUS9W-T<B`B3F%U:FEE;O@@9W)U<.MS(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B4V5K86YT:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z
M>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B4V5K86YT:2!F87KK
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S(@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@(DYE>'0@;W!T:6]N
M<R(*;7-G<W1R(")396MA;G1Y<R!N=7-T871Y;6%I(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM
M<V=S='(@(E-E:V%N=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G
M=6$B"FUS9W-T<B`B3FEK87)A9W9A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<B(*;7-G<W1R(").:6=E<FES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").
M:6=E<FEA(@IM<V=S='(@(DYI9V5R:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F%K=&ES
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=6KK(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV,PIM
M<V=I9"`B3F\B"FUS9W-T<B`B3F4B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T
M:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(DYE
M=?YT96YK82!D=6]M96[X('-K:7)T=6WX('!A<F]D>6UU:2XB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB
M"FUS9W-T<B`B3F5N=7)O9'ET82!S=')A=&5G:6IA($E33R!R8?!Y;75I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(D[K<F$@
M<W5DZW1I;FEO(/!A8FQO;F\N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V
M-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VXB"FUS9W-T<B`B3G5R;V1Y=&]J92!P;WII8VEJ;VIE(&)L;VMO(&[K
M<F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED
M(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").9>%V963K=&4@:V%L96YD;W)I875S('9A<F1O
M($U#04P@875T96YT:69I:V%C:6IO:F4N(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B4VMI<G1U;?@@
M;NMR82XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM
M<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`BT&EO<R!T96ESZW,@;F5G86QI('1U<NMT:2!P;W1E
M:7-I^"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5
M=&EL+G!H<#HW-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R(").
MZW)A(&EN9F]R;6%C:6IO<R!A<&EE("5S(&MO;F9I9_MR86-I:N`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*
M;7-G<W1R(").ZW)A(&EN9F]R;6%C:6IO<R!A<&EE($944"!61E,@:V]N9FEG
M^W)A8VEJX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N(@IM<V=S='(@(D[K<F$@:6YF;W)M86-I:F]S(&%P:64@
M4U%,(%9&4R!K;VYF:6?[<F%C:6K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@
M(D[K<F$@:6YF;W)M86-I:F]S(&%P:64@4U%,+49I;&4@5D93(&MO;F9I9_MR
M86-I:N`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
M2W)E9&ET87,@:?!E:6MV;W1A<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I
M;VX@<W5P<&QI960N(@IM<V=S='(@(DYEX79E<W1A<R!G87;K:F%S+B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R(")&86EL87,@;F5N=7-I^'-T87,B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(DYO
M(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(E<R!N97)A<W1A<RXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(").96YU<W1A='ET82!V:65T;W;K
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z
M>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").96YU
M<W1A='ET82!V:65T;W;K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L
M:65D+B(*;7-G<W1R(").9>%R8?#K=&4@_FEN=73K<RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B
M3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYEX7)A\.MT92!V87)D;RXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F7A
M<F'PZW1E(&YU;65R:6\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT
M"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B3F5R;V1Y
M=&D@X?YE:63^:6%NZ&GX(&9R87II^"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA
M<'1A_F]D_FEO($A45%`@875T96YT:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE
MX79E9.MT92!S;&%P=&'^;V3^:6\@24U!4"!A=71E;G1I9FEK86-I:F%I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F7A=F5DZW1E('-L87!T8?YO9/YI;R!+97)B97)O<R!A
M=71E;G1I9FEK86-I:F%I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYEX79E9.MT92!S;&%P=&'^;V3^:6\@3&]G:6X@875T96YT:69I:V%C
M:6IA:2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(").9>%V963K=&4@<VQA<'1A_F]D_FEO(%!!
M4U-71"!A=71E;G1I9FEK86-I:F%I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F7A=F5DZW1E('-L87!T
M8?YO9/YI;R!334(@875T96YT:69I:V%C:6IA:2XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N(@IM<V=S='(@(B(*(DYEX79E<W1A<R!K96QI87,@:6MI($]P96Y34TP@
M<&%G<FEN9&EN:?@@9F%I;/@N($]P96Y34TP@<F5I:V%L:6YG82!D87)B=6D@
M<W4@(@HB4$M#4R`Q,B!D=6]M96YI;6ES+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P
M<RXB"FUS9W-T<B`B3F5P871V:7)T:6YT^"!R96=I<W1R86-I:O@@;NMR82XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(DYE;G5R;V1Y
M=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(").96YA=61O=&D@
M<VMI<G1U:_@B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*
M(RP@9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S
M='(@(DYEX7)A\.MT92!N=6UE<FEO+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S
M(@IM<V=S='(@(D[K('9I96YO:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@9FEL
M92(*;7-G<W1R(").ZR!V:65N;VIE('!U<^MJ92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B4W!A<G1I;FEM
M=6D@;NMR82!L86EK:6YO:F\@:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(")687)T;W1O:F\@
M=F%R9&%S(&ER+V%R8F$@<VQA<'1A_F]D:7,@;F5N=7-I^'-T87,N(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(E1E:7-I;F?X(%A-3"!D
M=6]M96[X(&[K<F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(D[K<F$@<F5I
M:_!M:?@B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG^W)A8VEN
M:6%M92!F86EL92!NZW)A('9E<G-I:F]S+B!097)G96YE<G5O:VET92!N=7-T
M871Y;75S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMO;F9I9_MR86-I;FEA
M;64@9F%I;&4@;NMR82!V97)S:6IO<RX@4&5R9V5N97)U;VMI=&4@;G5S=&%T
M>6UU<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"FUS9VED(").;VYE(@IM<V=S='(@(DYE;G5R;V1Y=&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE
M("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(D[K<F$B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS
M9W-T<B`BT&EA=7+K<R`H25-/+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R(").;W)F;VQK;R!S86QO<R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BT&EA=7)I
M;NL@:&5M:7-F97)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-
M87)I86YA($ES;&%N9',B"FUS9W-T<B`BT&EA=7)I;NMS($UA<FEJ86[X('-A
M;&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R
M=F5G:6IA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").92!P;R!T;R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@
M0F5F;W)E(@IM<V=S='(@(DYE('!R:67P('1A:2(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM
M<V=S='(@(DYE(&MA=&%L;V=A<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYE<F5A;&EZ=6]T
M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DYE;G5R;V1Y=&$B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C0X
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R
M.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B3F5P86QA:6MO;6%S+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W
M.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B5?YR8?!A:2(*"B,Z('-E<G9I8V5S
M+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W
M<V4L(&=O(&)A8VLN(@IM<V=S='(@(D[K<F$@:^`@<&5R_FG[<NMT:2P@96EK
M:71E(&%T9V%L+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("),87!K<FET:7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB
M97(B"FUS9W-T<B`B3G5M97)I<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(E-I;6)O;&GX('-K86GH:75S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(E-T=6QP96QI^"!S:V%IZ&EU<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R(")%:6QUZ&GX('-K86GH:75S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@
M(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYEX79E<W1I(&1I<W1R:6)U8VEJ;W,@
M<^!R8?!O(&%T;F%U:FEN:6UO('-K86GH:6%I+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T
M<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96MT87,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R
M96%T;W(B"FUS9W-T<B`B3V)J96MT;R!S879I;FEN:V%S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
M0?!T=6YT86EN:7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")3<&%L:7,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL
M=&5R(@IM<V=S='(@(MYI875R=6UO(&9I;'1R87,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B3V9I
M<V%S(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED
M(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC
M+"!F=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E-L87!T8?YO
M9&ES(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U
M>GIY"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S
M='(@(E-L87!T8?YO9&ES(&YE=&5I<VEN9V%S(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(D]M86YA<R(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")+871A;&]G
M^"!D86QI:FEMX'-I('!A;&%I:V\@=&EK($E-05`@<V5R=F5R:6%I+B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B5&EK(.'^96ED_FEA;NAI;W,@9G)A>NMS
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R
M97-S(&%L;&]W960N(@IM<V=S='(@(DQE:63^:6%M87,@=&EK('9I96YA<R!E
M;"X@<&'P=&\@861R97-A<RXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D5L96UE;G1O('-A
M=FEN:6YK;R!T96ES97,@9V%L:2!K96ES=&D@=&EK(&IO('-A=FEN:6YK87,@
M87)B82!S:7-T96UO<R`B"B)A9&UI;FES=')A=&]R:75S(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(D%T:61A<GET:2!N875J86UE(&QA;F=E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!=&ED87)Y=&D@\&G@
M(&YU;W)O9.`@;F%U:F%M92!L86YG92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<')A
M8VENZW,@<VES=&5M;W,B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(DYU<W1A='EM86DB"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B)7,@;G5S=&%T>6UA:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G
M<W1R(")3=7+[\&EU;W1A<R!SX')A\&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G
M<W1R(")/<F=A;FEZ86-I:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G
M<W1R(")0861A;&EN>7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(E-I<W1E;6EN:6UA<R(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")/<FEG:6YA;'5S(&%P;&EK
M86-I:F]S(/!A8FQO;F%S(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S
M.B(*;7-G<W1R(")/<FEG:6YA;/AS(/!A8FQO;F%I("5S.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")+:71A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB
M"FUS9W-T<B`B2VET82!I;F9O<FUA8VEJ82(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(E-A=FEN:6YI:V\@=&5I<^MS(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B3NMR82!004T@875T96YT:69I:V%C:6IO
M<R!M96-H86YI>FUO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R
M-S,*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")01U`@
M<VMA:71M96YI;FES('!A<F'P87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS
M9W-T<B`B4$=0('7^:V]D=6]T82!I;F9O<FUA8VEJ82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@
M2V5Y(@IM<V=S='(@(E!'4"!V:67P87-I<R!R86MT87,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!P87-I<F'P>71I+W7^:V]D
M=6]T:2!D=6]M96YY<R(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I
M9"`B4$A0($-O9&4B"FUS9W-T<B`B4$A0(&MO9&%S(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0($-,
M22(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(E!-(&QE;F=V87,@;&EE
M='5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B4$T@;&G[=&ES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*(RP@9G5Z
M>GD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B4$T@;&G[=&ES(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*(RP@9G5Z>GD*
M;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-
M(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B4$T@
M5"UA=61R82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@
M(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI
M8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R(")07TA0
M($-,22(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B5&%R<&%I(&-E
M;.MS92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B
M4&%K:7-T86YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S
M='(@(E!A;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@
M5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")5_FEM=&]J:2!086QE<W1I
M;F]S('1E<FET;W)I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*
M;7-G<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE
M=R!'=6EN96$B"FUS9W-T<B`B4&%P=6$@3F%U:F]J:2!'=FENZVIA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=V86IU
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(D1A;&EN86D@9&5B97-U
M;W1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0R,PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4VQA<'1A_F]D:7,B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R(")3;&%P=&'^;V1I<R!N971E:7-I;F=A
M<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(E)!1$E54R!A=71E;G1I9FEK86-I:F%I(')E:6MI82!S
M;&%P=&'^;V3^:6\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U
M,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
M4VQA<'1A_F]D:7,@<W4@<&%T=FER=&EN:6UU(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B
M4VQA<'1A_F]D:7,Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4VQA<'1A_F]D:7,Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")3;&%P=&'^
M;V3^:6%I('1U<FD@<W5T87!T:2XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BP6ME;'1I(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B
M4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`BP6ME;'1I(&GP(&QA:6MI
M;F]S:6]S('-A=6=Y:VQO<R`H8VQI<&)O87)D*2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`B2V5L:6%S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC
M.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B3F5P871V:7)T
M:6YT;W,@<F5G:7-T<F%C:6IO<SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R("+>;6]NZW,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B
M4&5R8V5N="(*;7-G<W1R(")0<F]C96YT86DB"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(D%T;&EK=&D@<')O9FEL
M86MT:6YI=7,@=F5I:W-M=7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@
M;&]G:6X_(@IM<V=S='(@(D%R(&%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I
M:W-M=7,@<')I<VEJ=6YG:6UO(&UE='4_(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
M5&5I<^MS(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E
M;&5T960N(@IM<V=S='(@(E1E:7/K<R`G)7,G(&YE:?!T<FEN=&]S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS9VED
M(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")496ESZW,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B7U1E:7/K<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P
M.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O
M:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@
M(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E1E:7-I^"!A
M9&UI;FES=')A=FEM87,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*
M;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(D%S;65N:6[K
M(&EN9F]R;6%C:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S
M='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@
M(E!E=',B"FUS9W-T<B`B1WEV^VYA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;F%I(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&5L969O;F%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(DYU;W1R875K;W,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71K<F%N
M87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I:W-E;&EA:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G
M<W1R(")"86YA;'EBZW,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B2?!S:7)I;FMI=&4@:W5R:>`@;F]R<R!C
M96SF(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(E!A='9I<G1I
M;FMI=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\.$@96QE;65N=.`Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(E!A='9I<G1I;FMI
M=&4L(&%R('1I:W)A:2!N;W)I=&4@:?!T<FEN=&D@\&EO(&5L96UE;G1O(&YU
M;W)O9.`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B
MP79E<VMI=&4@;>MN97/A(&ER(&UE='5S+B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("+!=F5S
M:VET92!N875J;W,@:V%T96=O<FEJ;W,@<&%V861I;FEMX#HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("+!=F5S:VET92!T96ES:6YG
MX"!)4"!A9')E<^`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V
M,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE
M(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`BP79E<VMI
M=&4@=&5I<VEN9^`@9&%TX"P@<&%T:6MR:6YK:71E(&1I96[X('-K86GH:?@@
M;>MN97-Y:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`BP79E
M<VMI=&4@=&5I<VEN9^`@;&%I:^`N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")!<')A\'EK:71E('!R;V)L96W@
M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B3G5R;V1Y:VET92!S
M879O('9A<G1O=&]J;R!V87)DX"!B96D@<VQA<'1A_F]DX2(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HB4')A\&]M92!P97)S:V%I='ET:2#PX2!T96MS=.`N($K[<R!04DE604Q/
M5$4@<W5T:6MT:2!S=2!SX&QY9V]M:7,L(&IE:2`B"B)N;W)I=&4@;F%U9&]T
M:7,@<VES=&5M82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.B(*;7-G<W1R("+!=F5S:VET92!N875JX"!K871E9V]R
M:6IO<R!P879A9&EN:6W@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(DQE;FMI:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&ET:6MA:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S
M='(@(D)A;'-A=FEM86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A
M;"(*;7-G<W1R(")0;W)T=6=A;&EJ82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0879E:6MS;.ML:6\@
M<&]Z:6-I:F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*
M;7-G<W1R("),96YT96SK<R!P;WII8VEJ82(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B2?!S875G
M;W1I(/!I86UE(&MA=&%L;V=E("AN96=A;&EO:F$@24U!4"DB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S
M(&AO=7(H<RDZ("(*;7-G<W1R(")+<FET=6QI86D@<&%S:RX@)7,@=F%L86YD
MX"AA<RDZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*
M;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$
M05`@;6]D=6QI<RXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO
M;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I
M;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO
M;CH@;F5R87-T87,@<F5I:V%L:6YG87,@<V5S:6KX(&UO9'5L:7,N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S
M='(@(E-LZV=I<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED
M(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R(")3;.MG:7,@:OMR
M;W,@;'EG>6IE.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E-LZV=I<SH@(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B4&5R_FG[<F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=R(*;7-G<W1R(")097+^:?MRZW1I('!A=F5I:W-LZVSA(&YA=6IA;64@;&%N
M9V4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@IM<V=I9"`B4')E=FEO=7,@
M;W!T:6]N<R(*;7-G<W1R(")!;FMS=&5S;FD@;G5S=&%T>6UA:2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@
M(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(D%T<W!A=7-D:6YT:2!D;VMU;65N
M=.`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E-L87!T87-I<R!R86MT87,B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0
M<F]B;&5M(@IM<V=S='(@(E!R;V)L96UA(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@
M(E!R;V)L96UO<R!A<')A\'EM87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT86DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X-0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B4')A\'EM87,@=&5K
M<W1U:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM
M<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")6:67P87-I<R!R86MT87,B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B
M4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B5FEE\&]J;R!R86MT;R!A
M;&=O<FET;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#0*(RP@9G5Z>GD*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R
M(")6:67P87-I<R!R86MT87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E9I9?!O:F\O<VQA
M<'1O:F\@<F%K=/@@<&]R82!N97-U9V5N97)U;W1A+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(E!U97)T;R!2:6MA<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(DMA=&%R87,B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S
M='(@(E-A:VEN>7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@
M9G5Z>GD*;7-G:60@(E%U;W1A(@IM<V=S='(@(DMA=&%R87,B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@
M=FEE\&%S:7,@<F%K=&%S("@E9"!B:71A:2DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T
M<B`B)U)A9&EO)R!P87-I<FEN:VEM87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("),
M:65T=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("),:65T=7,@<GET92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS
M9VED(")286EN($QA=&4B"FUS9W-T<B`B3&EE='5S('9A:V%R92(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")2
M86EN(%-H;W=E<B(*;7-G<W1R("),:?MT:7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PHC+"!F=7IZ>0IM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R("),:65T=7,O4VYI96=A<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"B,L(&9U>GIY"FUS
M9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B3&EE='5S+U-N:65G87,B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U
M;F4B"FUS9W-T<B`B071S:71I:W1I;NL@9G)A>NLB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E-A
M;G1Y:VES(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#`*;7-G:60@(E)E860B"FUS9W-T<B`B4VMA:71Y=&DB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R(")097)S:V%I='ET:2!L86GP:V%I(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(E1I:W)A:2!I\'1R:6YT:2`E<S\@1W)A
M_FEN=&D@871G86P@;F5B96=A;.MS:71E+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL
M>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R(")4:6MR86D@:?!T<FEN=&D@
M=F%R=&]T;VIO("5S(&1U;VUE;FES/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%L
MZW-I=&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T
M<B`B4&%K87)T;W1I(&%N:W-T97-NX2!V96EK<VW@(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G
M:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(D%T;F%U:FEN=&D@:V%I<FEO:F\@;65N:74@96QE;65N='5S
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D%T;F%U:FEN=&D@<&]R=&%L;R!V
M86EZ9.`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R(")3X')Y\&GX(&YA<O!Y:VSK(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(P.`HC+"!F=7IZ>0IM<V=I9"`B4F5L;V%D(@IM<V=S='(@
M(E-K86ET>71I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@
M(E)E;6%R:W,B"FUS9W-T<B`B4&%S=&%B;W,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(").
M=71O;.8@<V5R=F5R:6%I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N
M8V]M+VAO<F1E*3HB"FUS9W-T<B`B3G5T;VSF<R!54DP@*&AT='`Z+R]W=W<N
M<&%V>7ID>7,N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("))\'1R:6YT:2(*"B,Z('1E
M;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L
M;V-K(@IM<V=S='(@(E!A\&%L:6YT:2!B;&]KX"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU-3<*;7-G:60@(E)E;6]V92!C
M;VQU;6XB"FUS9W-T<B`B4&%N86EK:6YT:2!S='5L<&5LX2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E!A;F%I:VEN=&D@9F]R;6%T879I
M;>`B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B
M4F5M;W9E('!A:7(B"FUS9W-T<B`B2?!T<FEN=&D@<&]RX"(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I
M<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("))\'1R:6YT:2!A=&YA=6II;FEM;R!S:W)I<'3@(&GP('-E<G9E<FEO(&QA
M:6MI;F]J;R!K871A;&]G;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`B4&'P86QI;G1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E!A\&%L:6YT:2#P
MX2!E;&5M96YTX"!I\"!D;VMU;65N=&\B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M("))\'1R:6YT:2!V87)T;W1O:N`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S
M97(Z("5S(@IM<V=S='(@(E9A<G1O=&]J;R!T<GEN:6UA<SH@)7,B"@HC.B!F
M<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B
M"FUS9W-T<B`B3F5G86QI=2!A='-A:WET:2#A('7^:VQA=7/@+B!+;&%I9&]S
M(&MO9&%S.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W
M"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N(@IM<V=S='(@(DYE9V%L:74@:?!S875G;W1I(&YU<VGX<W1O
M(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<T(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")087)A;65T<F%S("<E<R<@;F5N
M=7)O9'ET87,@)7,@:V]N9FEG^W)A8VEJ;VIE+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@
M<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")087)A
M;65T<F%S("<E<R<@;F5N=7)O9'ET87,@5D93(&MO;F9I9_MR86-I:F]J92XB
M"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E!A<F%M971R87,@)R5S)R!N
M96YU<F]D>71A<R!K;VYF:6?[<F%C:6IO:F4N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B
M4F5S970B"FUS9W-T<B`B2?`@;F%U:F\B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B
M4&%K96ES=&D@<VQA<'1A_F]DX2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(E-L87!T8?YO9/YI;R!K96ET:6UA<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S`*(RP@9G5Z>GD*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G
M<W1R(")087-K=71I;FES(&ME='9I<G1I<R(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN
M<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)E>G5L=&%T86DB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S
M='(@(D=RX?YT:2#A(&YU<W1A='EM=7,B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E)E='EP92!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`B4&%K96ES=&D@<VQA<'1A_F]DX2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5J^VYI:F$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(D%T
M<W1A='ET:2!K;VYF:6?[<F%C:6K@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S
M='(@(DA434P@<F5D86MT;W)I875S(&YU<W1A='EM86DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B3>%S
M;.MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")$9?!I;NMJ92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE
M861E<B(*;7-G<W1R(")$9?!I;FEO:FD@86YT<F'P=.LB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B1&7P:6YI;W-I;W,@<F5I:_!MZW,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O
M7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?16EL=73K<R!N=7-T871Y;6%I
M+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2;VSK(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UU;FEJ82(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O
M=&%T92`Q.#`B"FUS9W-T<B`B4&%S=6MT:2`Q.#`B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@
M3&5F="(*;7-G<W1R(")087-U:W1I(&MA:7+K;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T92!2
M:6=H="(*;7-G<W1R(")087-U:W1I(&1E\&ENZVXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2
M;W<@4')O<&5R=&EE<R(*;7-G<W1R(")%:6QU=.MS(&YU<W1A='EM86DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R(")%:6QU=.MS(&YU
M<W1A='EM86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B16EL=73K<SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")3:VER='5K86DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS(@IM<V=S='(@(E-K:7)T=6MA:2!T87)P('9I<_@@96EL=>AI^"!I
M<B!S='5L<&5L:?@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")3:VER='5K86D@=&EK('1A
M<G`@<W1U;'!E;&GX(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B4VMI<G1U:V%I('1I:R!T87)P
M(&5I;'7H:?@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2
M=6XB"FUS9W-T<B`B5GEK9'ET:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U
M<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-I:F]S($9E9&5R86-I:F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G5A;F1A
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G
M:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")3
M+TU)344@<&%R8?!A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS
M9W-T<B`B4R]-24U%('7^:V]D=6]T87,@;&%I\&MA<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3NMR82!305-,(&%U
M=&5N=&EF:6MA8VEJ;W,@;65C:&%N:7IM;RXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-3`T"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@
M(E--4R#^:6YU=.MS(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED
M(")344P@4VAE;&PB"FUS9W-T<B`B4U%,($-,22(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A
M;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B4$%664M/(@H*(SH@
M;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?
M44P@0TQ)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`BT&7P="XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`BT'9E;G1O:FD@2&5L
M96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`B4V%I;G0@2VET<V%S(&ER($YE=FES87,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A:6YT($QI=6-I
M:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI
M<75E;&]N(@IM<V=S='(@(M!V96YT87-I<R!0971R87,@:7(@36EG96QO;F%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE
M($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@5FEN8V5N=&%S(&ER($=R96YA
M9&EN86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B5&%M
M92!P8>AI86UE(&QA;F=E("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")386UO82(*;7-G<W1R(")386UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN87,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B4V%O
M(%1O;64@:7(@4')I;F-I<.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B
M4&%L>61O=F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA
M(@IM<V=S='(@(E-A=61O($%R86)I:F$B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B2?!S875G;W1I
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B
M2?!S875G;W1I("5S(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R("))\'-A
M=6=O=&D@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED
M(")3879E($]P=&EO;G,B"FUS9W-T<B`B2?!S875G;W1I(&YU<W1A='EM=7,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*(DGP<V%U9V]T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU<R!K86EP(%!(
M4"!S:W)I<'3@(&K[<_@@<V5R=F5R:6\@;&%I:VEN86IA;64@(@HB:V%T86QO
M9V4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M)7,@;G5S=&%T>6UA:2!I\'-A=6=O=&DN(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D%T
M;F%U:FEN:6UO('-K<FEP=&%S(&GP<V%U9V]T87,@X3H@)R5S)RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0HC+"!F=7IZ
M>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(DEZ;VQI=6]T
M;W,@5"UA=61R;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G
M:60@(E-C:65N8V4B"FUS9W-T<B`B36]K<VQA<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B267P:V]T:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%
M;F=I;F5S(@IM<V=S='(@(E!A:67P:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B4&%S
M:7)I;FMI=&4@9F%I;'5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-`IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R
M(")087-I<FEN:VET92!D873@(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R
M(")087-I<FEN:VET92!G<G5PYB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")0
M87-I<FEN:VET92!N875JX"!S879I;FEN:^`B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G
M<W1R(")087-I<FEN:VET92!S97)V97+A(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM
M<V=S='(@(E!A<VER:6YK:71E('9A<G1O=&]JX"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;&PB"FUS9W-T<B`B4&%S:7)I;FMI=&4@9F%I;'5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PIM<V=I9"`B4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E!A<VER:6YK:71E('9I<W5S
M(&1A=&]S(&MO;7!O;F5N='5S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B
M"FUS9W-T<B`B4&%S:7)I;FMI=&4@;V)J96MTX"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!N;VYE(@IM<V=S='(@(E!A<VER:6YK:71E(&YA=6K@('-A=FEN
M:6YKX"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB
M4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S
M(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F
M<F]M('1H92!T97AT(&%R96$N(@IM<V=S='(@(B(*(DGP(/YE;6EA=2!E<V%N
MZ&GX('/@<F'P^"!P87-I<FEN:VET92!R96EK:6%M=7,@<VEM8F]L:75S+B!6
MZVQI874@9V%L:71E(&IU;W,@(@HB;G5K;W!I:G5O=&D@X2!L86GP:^`N(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(E!A<VER:6YK:71E(&1A=&]S
M('-K:7)T=6O@.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS
M9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")087-I<FEN
M:VET92!D871O<R!F;W)M873@.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N
M=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@
M>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")087-I<FEN:VET92!A<')A
M\.`@:W5RX2!N;W)I=&4@<F5D86=U;W1I.B(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R
M.B(*;7-G<W1R(")087-I<FEN:VET92!L86EK;R!S:VER='5KX#HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B4&%S:7)I;FMI=&4@;&%I:V\@9F]R;6%T
MX#HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4&%S:7)I;FMI
M=&4@9'4@871I=&EN:V%NZ&EU<R!L875K=7,N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R(")087-I<FEN:VET92!S<&%L=O@@9&5R:6[A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B4&%S:7)I;FMI=&4@;F]R:6W@
M(&MA;&+@.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X
M"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-I^'-T:2!P
M<F]B;&5M;W,@<')A;F7P:6W@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(E-I^'-T:2!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM
M<V=S='(@(E-E;F5G86QA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V
M"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")396YS;W)I=7,Z("(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B4G5G<^MJ:7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT
M96YE9W)O(@IM<V=S='(@(E-E<F)I:F$@:7(@36]N=&5N96=R87,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R
M:6%L($YU;6)E<B(*;7-G<W1R(")397)I:F]S(&YU;65R:7,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")3
M97)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")/
M<F\@<^!L>6?X(&)L;VMO(&[K<F$N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(E1E
M:7-I^"!A9&UI;FES=')A=FEM87,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@
M97AP:7)E9"XB"FUS9W-T<B`B4V5S:6IO<R!)1"!P87-I8F%I9^LN(@H*(SH@
M;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G
M<W1R(")?5&5I<^MS(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-`IM<V=I9"`B4V5T(@IM<V=S='(@(E)I;FMI;GES(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C<V"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y
M;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@
M:70N(@IM<V=S='(@(B(*(DYU<W1A='EM86D@;&5I9/YI86YT>7,@2G5M<R!P
M87-I:V5I<W1I('-L87!T8?YO9.$L(&IE:6=U(&KA(&MA9&$@;F]R<R`B"B)P
M86UI<O!I=&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(DYU=&]L=7-I^"!S97)V
M97)I^"P@:W5R:75O<R!N;W)I=&4@;6%T>71I(&GP('!O<G1A;&\L(&YU<W1A
M='EM86DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@T"FUS9VED(")3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N(@IM<V=S='(@(DMA;&)O<RP@;&%I:V\@>F]N;W,@:7(@9&%T
M;W,@;G5S=&%T>6UA:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*
M;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA
M>2!O<'1I;VYS+B(*;7-G<W1R("(B"B)0=7-L87!I;R!S<&%L=O@L(&%T<VEN
M875J:6YI;6\@9&'^;G5M;R!I<B!K:73X('9A:7ID879I;6\@<&%R86UE='+X
M("(*(FYU<W1A='EM86DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-0HC+"!F=7IZ>0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B7TMO;F9I9_MR86-I
M:F$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M(")287-T87,@871N875J:6YI;6\@<VMR:7!T87,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N
M<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")3=2#P
M:75O('!A<F%M971R=2!G86QI;6]S(&ME;&EO<R!V:65T;W;K<SH@(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R(")396GP96QA
M:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H
M;W!P:6YG(@IM<V=S='(@(E!A<F1U;W1U=NLB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G
M<W1R(")4<G5M<&%S(&%P<F'P>6UA<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D
M(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")!<B!N875D;W1I(&ML879I873[
M<F]S(&UY9W1U:W5S('9A;&1Y;75I/R(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E)O9'ET
M:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@HB4&%R;V1Y=&D@<VMI<G1U;75S('1A<G`@:?!S875G;W1O(&ER(&O@('1I
M:R!S=6=E;F5R=6]T;R!K;VYF:6?[<F%C:6YI;R!F86EL;RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@
M=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(E)O9'ET:2!P87-K=71I
M;FEO('!R:7-I:G5N9VEM;R!L86EKX#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L(@IM<V=S='(@(E)O9'ET:2!G86QI;7EBYB!P86QI:W1I(&]R:6=I;F%L
MX"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(E)O9'ET:2!P87)I<VEN:VEMX"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E
M<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B4F]D>71I(&QE;G1E;.MS(&]P
M97)A8VEJ^"!M96YI=3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(E)O9'ET:2`E<R!M96YI=2!K86ERZVIE/R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R(")2;V1Y=&D@8V5LZW,@;G5S=&%T>6WX(&QA;F?@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(")2;V1Y=&D@;&5N=&5LZW,@;G5S=&%T>6WX(&QA;F?@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B4F]D>71I(&5I;'5TZW,@;G5S=&%T>6WX(&QA;F?@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R(")2;V1Y=&D@<&%V96EK<VSK;&EO(&YU<W1A='EM^"!L
M86YGX"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(E)O9'ET:2!F86EL^"#A:^ML:6W@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G
M:60@(E-H;W=E<G,B"FUS9W-T<B`B3&G[=&ES(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R
M;'DB"FUS9W-T<B`B3&G[=&ES(')Y=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(DQI^W1I<R!V86MA<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B4W5M8?YI;G1I
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*
M;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R(")3=6UA_FEN=&D@87)B82!P
M87-T=6UT:2!K86EM>6YI;FEU<R!B;&]K=7,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<F$@3&5O;NLB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N
M('5P(@IM<V=S='(@(E)E9VES=')A8VEJ82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T
M<B`B4&%R8?!A<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(E!A
M<F'P;R!A;&=O<FET;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(E-I;F=A</MR87,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S='(@(D1Y9&ES(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G
M:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B4')A;&5I<W1I('!R;V9I
M;&%K=&EKX"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(E-L;W9A:VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(E-L;W;K;FEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S
M='(@(E)O9'ET:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R(")0^V=A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*(RP@
M9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")0^V=A(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*(RP@9G5Z
M>GD*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R("),:?MT:7,@
M<GET92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4X"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R
M("),:?MT:7,@=F%K87)E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*
M;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")3;FEE9V\@9WEL:7,Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")3;FEE9V\@:VEE:VES('9A;F1E
M;FEU.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B
M"FUS9W-T<B`B4V]L;VUO;F\@<V%L;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED
M(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B1&%I
M;F]S(&ER($5I;.MR8?#H:6%I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B
M4OOP:6%V:6UO('1V87)K;W,@<&%S:7)I;FMI;6%S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I
M9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B4VEU;G3K:F\@861R97-A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")0
M:65T^"!!9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E!I973X
M($5U<F]P;W,@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R(")0:65T^"!$_F]R9/YI:F]S(&ER(%!I973X(%-A;F1V:>AO('-A
M;&]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")0
M:65T:6[K(&AE;6ES9F5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS(@IM<V=S='(@(E1A<G!A<R!T87)P(&-E;&GX(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@
M(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS
M9W-T<B`B5&%R<&%S('1A<G`@8V5LZW,@='5R:6YI;R!I<B!K<F'P=&ENZW,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E
M<B(*;7-G<W1R(")487)P87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T
M<B`B5&%R<&%I('1A<G`@8V5L:?@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(E1A<G!A:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")3<&%I;B(*;7-G<W1R("))<W!A;FEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M87,B"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R($EN<'5T(@IM<V=S='(@(E-P96-I9FEN:?@@<VEM8F]L:?@@X71E
M<G!I;6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")097)S
M:V5L=&D@8V5LYB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R
M(")097)S:V5L=&D@<W1U;'!E;.$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B
M"FUS9W-T<B`B4&5R<VME;'1I(&5I;'5TYB(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)T87,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("+0<FD@3&%N
M:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A
M;F1A<G1A<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B
M4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R=A<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")0<F%D:6YI86D@;65T
M86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B4F%J;VYA<R!A<F)A
M('!R;W9I;F-I:F$B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(D+[<V5N82(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@9F]R
M;6%T(@IM<V=S='(@(E-A=6=O:FEM;R!F;W)M871A<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"FUS9VED(")3=')E970@061D
M<F5S<R(*;7-G<W1R(")'871VZW,@861R97-A<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B5?YB<F%U:W1I(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`BWF]D
M_FGX('/@<F'P87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S
M"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R
M(").=6EM=&D@9&]M96[@(&YU;R!A9')E<V\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R(")3=&EL:75S(%M#4U-=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS
M9W-T<B`B4V5K;2XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N97)A<W1A<RXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J
M96-T(@IM<V=S='(@(E1E;6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS
M9VED(")3=6)M:70B"FUS9W-T<B`BP79E<W1I(@H*(SH@<VEG;G5P+G!H<#HT
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E
M<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO
M="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O
M=F5D+B(*;7-G<W1R("(B"B)687)T;W1O:F%S("<E<R<@<W5K=7)T87,@<VES
M=&5M;VIE+B!+;VP@:FES(&YE<&%T=FER=&EN=&%S+"!P<FES:6IU;F=T:2`B
M"B)N96=A;.MS:71E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("));F1E
M:W-A<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3ZVMM:6YG82(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S
M='(@(B<E<R<@<^MK;6EN9V%I('-U:W5R=&%S('-I<W1E;6]J92XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B5F%R=&]T;VIO("<E<R<@9'5O;65N
M>7,@<^MK;6EN9V%I(&GP=')I;G1I(&GP('-I<W1E;6]S+B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@
M7"(E<UPB+B(*;7-G<W1R("(G)7,G('/K:VUI;F=A:2!I\'1R:6YT82XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(B<E<R<@<^MK;6EN9V%I(&GP=')I;G1A<R!I\"!S:7-T
M96UO<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3
M=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O
M('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)+;VYF:6?[<F%C:6IA(&%T<W1A
M='ET82!SZVMM:6YG86DN(%!E<FMR875K:71E('!U<VQA<.$L(&MA9"!P86UA
M='ET=6WK=&4@(@HB<&%K96ET=6UU<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U
M8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B071S87)G:6[K(&MO;F9I9_MR86-I:F]S(&MO<&EJ82!SZVMM:6YG86D@
M:?!S875G;W1A+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B071S
M87)G:6[K(&MO;F9I9_MR86-I:F]S(&MO<&EJ82!SZVMM:6YG86D@:?!S875G
M;W1A(.$@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B
M"FUS9W-T<B`B)R5S)R!SZVMM:6YG86D@871N875J:6YT87,N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S
M(@IM<V=S='(@(B<E<R<@<^MK;6EN9V%I('7^<F'P>71A<RXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A;F%S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM
M<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")4=7)I;GES(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R(")3875L
MZW1E:VES(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3
M=6X@4V5T(@IM<V=S='(@(E-A=6SK;'EG:7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T
M<B`B4V%U;.MT82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B4V%U;.MT96MI<R(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ
M-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B4V%U;.MT96MI<R]3
M875LZVQY9&ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(E-A=6SK=&5K:7,Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E
M="(*;7-G<W1R(")3875LZVQY9VES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B4V%U;.ML
M>6=I<SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B3&%I<'-N:7,B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"FUS9VED(")3=7!P
M;W)T(@IM<V=S='(@(D%P=&%R;F%V:6UA<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UA<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")3=7)N86UE(@IM
M<V=S='(@(E!A=F%R9.LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R
M9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D87,@:7(@1/YA;FUA
M:6YA<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R
M(")3=F%Z:6QA;F1A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*
M;7-G<W1R("+0=F5D:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L
M86YD(@IM<V=S='(@(M!V96EC87)I:F$B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E
M9"(*;7-G<W1R(").971R:6YT:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#(*;7-G:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4VEN=&%K<^MS(&ML86ED82!P86EE
M\&MO<R!K<FET97)I:G5J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA
M;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-I<FEJ;W,@07)A8O@@4F5S<'5B
M;&EK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(E0M875D<F$B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3
M=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(E0M875D<F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM
M<V=S='(@(DQI^W1I<R!R>71E(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&9A:6QA
M<R(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"FUS9VED(")4
M86)L92(*;7-G<W1R("),96YT96SK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O
M<&5R=&EE<R(*;7-G<W1R("),96YT96SK<R!N=7-T871Y;6%I(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ
M>0IM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(DQE;G1E;.LB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS
M9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(DQE;G1E;.MS(&YU<W1A
M='EM86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS
M9W-T<B`B5&%I=F%N87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*
M;7-G<W1R(")486EV86YA<RP@2VEN:6IO<R!P<F]V:6YC:6IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4863^:6MI<W1A
M;F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!2
M97!U8FQI8R!O9B(*;7-G<W1R(")*=6YG=&ENZR!486YZ86YI:F]S(%)E<W!U
M8FQI:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(E1A:6MI;GES.B(*"B,Z
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B1&%R8F%I(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L969O;F\@;G5M97)I<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS9VED(")496UP(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R(")496UP+B!P87-K+B!V86QA;F3@.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B5&5M<&5R873[<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E
M<F%T^W)A.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE
M<F%S=&%S("<E<R<@\&%B;&]N87,N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(M!A8FQO;O@@861M:6YI<W1R879I;6%S(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS
M9VED(")497AT(@IM<V=S='(@(E1E:W-T87,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B5&EK('1E
M:W-T87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(DQY9VEU
M;W1I('1E:W-TX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K<W1O('9I
M<O!U:F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")+971V+B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R
M(")486EL86YD:65T:?!K82`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R(")486EL86YD87,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B0>AI^R!K860@;F%U9&]J873K<R!S
M:7-T96UA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS
M9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(").ZW)A($944"!M;V1U;&EO+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3,T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+
M;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S
M7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(@:6YT96=R86-I:F]S('9A<FEK;&EU
M:V%S(&YE<&%L86EK;R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]";V]K+G!H<#HQ,CDR"B,L(&9U>GIY"FUS9VED(")4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R(").96=A;&EU
M(&GP<V%U9V]T:2!N=7-I^'-T;R!F86EL;RXB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B3F5P879Y:V\@
M=?YK<F%U=&D@36%I;G1E;F%N8V4Z.B!K;&%SZW,B"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B3G5S=&%T>6WX
M(&QA;F=A<R!U_F1A<GET87,N($GP96EN=2XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P
M,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@
M=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@
M:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B
M"B)*96EG=2!N;W)I=&4@;F%U9&]T:2!N=7-T871Y;75S+"!P87!R8?!Y:VET
M92!K860@861M:6YI<W1R871O<FEU<R`B"B)S=6MO;F9I9_MR=6]T^"!P87-T
M;W9IX"!D=6]M96[X(&)A>N8@;G5S=&%T>6UA;7,@<V%U9V]T:2XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U
M"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")4:6L@87!A
M=&ENZVIE('!U<^MJ92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(DYEX7)A\.MT
M92!C;VYT86MT;R!)1"!N=6UE<FEO(&%R8F$@:FES(&YE<F%S=&%S(&1U;VUE
M;O@@8F%ZZVIE+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL
M>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K
M=&%S('/K:VUI;F=A:2#A=')A=6MT87,@X2!*^W/X(&%D<F5S^"!K;GEG96SF
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G
M:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E
M<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@
M(DYO<NMD86UI('!A=&EK<FEN=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@
M871S:VERX"!01U`@<&%R8?!O(&)L;VO@+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N
M(@IM<V=S='(@(DYEX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;R!)1"!A
M<F)A(&II<R!N97)A<W1A<R!D=6]M96[X(&)A>NMJ92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R(").9>%R8?#K=&4@9&ES=')I8G5C:6IO<R!SX')A\&\N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M(@IM<V=S='(@(B(*(E!'4"!U_FMO9&%V:6UO(&=A;&EM>6+K(')E:6MA;&%U
M:F$@<V%U9V%U<R!P<FES:6IU;F=I;6\N($)A;F1Y:VET92!R8?!Y=&D@(@HB
M:'1T<',Z+R\@861R97-O('!R863^:6]J92XB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(D9A:6QA<R`E<R!P<FEV86QO
M('1U<NMT:2`E<R!P87)A;65T<N`N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@
M<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B1F%I;&%S("5S('!R:79A;&\@
M='5RZW1I(&MA:2!K=7)I=6]S("5S('!A<F%M971R=7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@
M;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1F%I;&%S(&YE
M9V%L:2!B^W1I(&YU:V]P:6IU;W1A<R!A;G0@<V%VYG,N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B1F%I;&4@;NMR82!D=6]M96[X+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G
M:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE
M<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(E)&0S@X,B!L86GP:V\@
M86YT<F'P=.MS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O
M(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B
M"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@
M<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@HB2F5I9W4@9&ER8F%T92!);G1E
M<FYE="!%>'!L;W)E<B!N87+P>6ML92P@<&EL;F%E:W)A;FES(')E9&%K=&]R
M:6%U<R!R9?YI;6%S("(*(F=A;&D@<W5K96QT:2!P<F]B;&5M^"P@9.ML(/!I
M;W,@;F%R\'EK;.MS(&ML86ED^"X@1V%L:71E(&YE;6%T>71I(&MA:2!K=7)I
M^"`B"B)R961A:W1O<FEA=7,@96QE;65N=/@N($IE:6=U(&YA=61O:F%T92!7
M:6YD;W=S(#EX($]3(&=R96GH:6%U<VEA:2!J^W/X("(*(FMO;7!I=71E<FES
M('!A<')A\.AI875S:6%I(&YU;'7P('!A<VME;&)D86UA<R!A<&EE('!A9W)I
M;F1I;N8@:VQA:63@+EQ<;B(*(EQ<;DK[<R!B=79O=&4@<&5R<W#K=&%S+B!*
M96EG=2!V:7-T:65K(&YO<FET92!I\&)A;F1Y=&D@<&EL;F%E:W)A;N$@<F7^
M:6W@("(*(G-P875S:VET92!/2RXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z
M.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!<')A\&%S(%PB)7-<(B!I\'1R
M:6YT87,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B5&EK(&MA:7+K:F4@<'5SZVIE(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B0W)Y<'1?<'%P.CH@:VQA<V5I(')E
M:6MI82!N=7)O9'ET:2!K=7(@>7)A($=N=5!'(&9A:6QA:2XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J
M96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO
M(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@
M=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB3&%I\&MA<R!I\'-I^'-T87,@)7,@
M861R97-A='5I("5S('1E;6$@7"(E<UPB(&)U=F\@<&%R;V1Y=&%S+EQN(@HB
M5&'H:6%U('1A:2!N96=A<F%N='5O:F$@:V%D(&QA:?!K87,@8G5V;R!P97)S
M:V%I='ET87,@87)B82!S=7!R87-T87,N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(E!A=F%D:6YI;6%S
M(&MU<N$@;F%U9&]S:71E(&YU;W)O9&]J92#A(&QA:?!K;R!R8?!Y;6\@<'5S
M;&%PX2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE
M<FEC+B(*;7-G<W1R("+0:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RXB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R>7!T
M7W-M:6UE.CH@:VQA<V5I(')E:6MA;&EN9V%S($]P96Y34TP@;6]D=6QI<RXB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F5G86QI=2!I\'-A
M=6=O=&D@;G5S=&%T>6UO(%PB)7-<(BP@;F5S(&1U;VUE;O@@9'ED:7,@=FER
M\'EJ82!L96ES=&ENX"!R:6+@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@
M=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R(")0<F]G<F%M
M82P@<VMI<G1A('!E<OYI^W+K=&D@\.$@9'5O;65N^"!T:7#@("@E<RDL(&YE
M<F%S=&$@<VES=&5M;VIE+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C0U-`IM<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R(")4:6L@:V%I
M<NMJ92!I<B!D9?!I;NMJ92!P=7/K<V4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B5&EK(&1E\&ENZVIE('!U<^MJ
M92(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B
M5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!D96QE=&5D+B(*;7-G<W1R(")397)V97)I<R!<(B5S7"(@:?!T<FEN=&%S
M+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R(")397)V97)I<R!<(B5S7"(@:?!S875G;W1A<RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R
M("(E<R!R96=I<W1R86-I:F]S('!R8?!Y;6%S(&GP=')I;G1A<RXB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H
M92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(").=7)O
M9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R(").=7)O9'ET82!E:6QU=.L@;F5E9WII<W1U;VIA+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T97AT('EO=2!E
M;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'DB"FUS9W-T<B`B5&EK('9I<O!U=&ENZVIE(&ER(&%P871I;NMJ
M92!P=7/K<V4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G
M<W1R(")4:6L@87!A=&ENZVIE('!U<^MJ92(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO
M<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(DYU<VGX<W1I
M(&1U;VUE;GES('!R87)A<W1I+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM
M<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*
M;7-G<W1R(").96=A;&EU(&GP<V%U9V]T:2!N=7-I^'-T;R!F86EL;RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I
M9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(E=E871H97(N8V]M(&)L;VMO(&[K<F$N(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE
M<F%S=&%S("<E<R<@\&%B;&]N87,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92XB"FUS9W-T<B`B3G5S=&%T>6WX(&[K<F$N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0R"FUS9VED(")4:&5R92!A
M<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS
M9W-T<B`B1&%L:?@L(&MU<FEA<R!G86QI;6$@<F]D>71I(&QA:?!K;R!T96MS
M=&4L(&[K<F$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30P,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA
M<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H
M87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS
M9W-T<B`B(@HBT&EA;64@;&%U:V4@X79E<W1A('!E<B!D875G('-I;6)O;&GX
M+B!*^W,@X79E9.MT92`E<RP@;R!M86MS:6UA;'5S('-K86GH:75S("(*(BT@
M)7,@<VEM8F]L:6%I+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP
M:'`Z-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G
M<W1R(")3=6MU<G1I("<E<R<@;F5P879Y:V\Z("5S(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I('9A
M<G1O=&]J;R`G)7,G(&1U;VUE;O@@:?`@<VES=&5M;W,Z("(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B2?!T<FEN=&D@)R5S)R!N97!A=GEK;SH@(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B071N875J:6YT:2`G)7,G(&YE<&%V>6MO.B`E<R(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(E!R;V)L96UO<R!S=2!F
M86EL^"!S:75N=&EM=3H@)7,@;F5N=7-I^'-T87,N(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(DYU<VGX<W1I(&9A:6QO
M(&YE<&%V>6MO+B!&86EL87,@)7,@>7)A(&1I9&5S;FES(&YE9W4@;&5I9/YI
M86UA<R!D>61I<R`H)60@(@HB8F%I=&%I*2XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B3G5S
M:?AS=&D@9F%I;&\@;F5P879Y:V\N($9A:6QA<R`E<R!T:6L@9&%L:6YA:2!N
M=7-I^'-T87,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B3F5G86QI=2!P87)O9'ET
M:2#P:6]S(&QA:?!K;R!D86QI97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(DML86ED82#A
M:V5L:6%N="!K;VYT86MT:6YI=7,@9'5O;65N:7,N(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B2VQA
M:61A(.%K96QI86YT(&E#86QE;F1A<B!D=6]M96YI<RXB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB2VQA:61A
M(&MO;F9I9_MR86-I:F]S(&9O<FUO:F4N($=R96GH:6%U<VEA:2!N977^<&EL
M9.MT92!R96EK:6%M^"!L875K^"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O
M;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*(DML86ED82!A=&QI96MA;G0@;G5R;V1Y=.`@861R97/X(&MN>6=E
M;.MS(&9U;FMC:6K@+B!086)A;F1Y:VET92!VZVQI874N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@
M(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D
M971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")+;&%I
M9&$@871N875J:6YA;G0@:V]N=&%K=&EN:75S(&1U;VUE;FES+B!086)A;F1Y
M:VET92!VZVQI874N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(DML86ED82!A=&YA=6II;F%N="!D:7-T<FEB
M=6-I:F]S('/@<F'PX"X@4&%B86YD>6MI=&4@=NML:6%U+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RXB"FUS9W-T<B`BT&ES($E-05`@<V5R=F5R:7,@;F5P86QA:6MO(&MA=&%L
M;V?X(&1A;&EJ:6UO<VDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B071R;V1O+"!K860@
M=&%I(&YE='9A<FMI;F=A<R!205(@87)C:'EV87,N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
M071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!:25`@87)C:'EV87,N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D
M;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S
M='(@(D%T<F]D;RP@:V%D('1A:2!N971E:7-I;F=A<R!K;W)T96SK<R!N=6UE
M<FES+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO
M+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@HBT&D@='9A<FMY:VSK(&QE:63^:6$@<VGX<W1I(/YI
M;G5T97,@<&5R($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M(@HB<&%S:6YA=61O:F%N="!(5%10('!R;W1O:V]L=2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HBT&D@='9A<FMY:VSK
M(&QE:63^:6$@<VGX<W1I(/YI;G5T97,@<&5R('-M<S)E;6%I;"`H:'1T<#HO
M+W-M<S)E;6%I;"YC;VTI("(*(G!A<VEN875D;VIA;G0@2%144"!P<F]T;VMO
M;'4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*(M!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S
M('!E<B!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2`B"B)P87-I
M;F%U9&]J86YT($A45%`@<')O=&]K;VQU(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510
M('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="DN(@IM<V=S='(@(B(*(M!I('1V87)K>6MLZR!L96ED_FEA('-I^'-T:2#^
M:6YU=&5S(%--5%`@<')O=&]K;VQU('!E<B!6;V1A9F]N92!)=&%L:6IO<R`B
M"B)V87)T=7,L('1I:R!6;V1A9F]N92!N=6UE<FEA;7,N($II(')E:6MA;&%U
M:F$@96PN('!A\'1O(&%D<F5S;R!6;V1A9F]N92`B"B))=&%L>2`H:'1T<#HO
M+W=W=RXQ.3`N:70I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW
M."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q
M-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N(@IM<V=S='(@(M!I<R!L875K87,@<')I=F%L;VUA<RXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(M!I
M86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@<W9E:6MI96II('-K86GH:6%I+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M(@IM<V=S='(@(M!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@<VMA:>AI86D@
M:7(@9'9I=&'P:VEA:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@
M=F%L=65S+B(*;7-G<W1R("+0:6%M92!L875K92!G86QI(&+[=&D@=&EK(&'P
M='5N=&%I;FEA:2!S:V%IZ&EA:2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O
M<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B
M"B+0:6%M92!L875K92!T=7)I(&+[=&D@:V%B;&5L:6%I<R!A<F)A('1A<G!A
M:7,@871S:VER=&D@<W9E:6MI96II('-K86GH:6%I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@
M82!V86QI9"!N=6UB97(N(@IM<V=S='(@(M!I(')E:6OP;>L@='5R:2!B^W1I
M('-K86GH:75S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*
M;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S
M-&%F)RXB"FUS9W-T<B`B(@HBT&EA;64@;&%U:V4@9V%L:2!B^W1I('1I:R!S
M<&%L=F]S(&MO9&%S(%)'0B!(97@@9F]R;6%T92P@<&%V>7ID_FEU:2`B"B(G
M(S$R,S1!1B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS
M9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM
M<V=S='(@(M!I(&9O<FUA(&IA=2!A<&1O<F]T82XB"@HC.B!T96UP;&%T97,O
M:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES
M("5S+B(*;7-G<W1R(")486D@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A
M($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@
M>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S
M='(@(B(*(E1A:2!+;VQA8B!'<F]U<'=A<F4@;V)J96MT87,N($YO<NMD86UI
M('!E<OYI^W+K=&D@;V)J96MTX"!P<FEV86QO=&4@='5RZW1I("(*(F5L+B!P
M8?!T;R!K;&EE;G3@+"!K=7)I<R!S=7!R86YTX"#PX2!F;W)M873@+B!4;VMI
M^"!E;"X@<&'P=&\@:VQI96YT^"!SX')A\.`@(@HB9V%L:71E(')A<W1I(&%P
M<VEL86YKYB`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BXB"FUS9W-T<B`BT&ES(&QA:?!K87,@8G5V;R!P87)A\'ET87,@
M)7,@:V]D=6]T92X@2OMS(&YA=61O:F%T92!K:71O:VG@(&MO9'5O=.8N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("+0:7,@
M<VMA:>AI=7,@='5R:2!B^W1I(&1I9&5S;FES('7^(&YU;.$N(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4
M:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE
M<RXB"FUS9W-T<B`BT&ES('-E<G9E<FES(&YE9V%L:2!I\&%R8VAY=G5O=&D@
M>FEP(&ER(&=Z:7`@9F%I;/@N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`BT&D@<VES=&5M82!D86)A<B!I
M\&IU;F=T82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R
M("+0:2!R96EK\&WK('1U<FD@8OMT:2!S:V%IZ&EU<RXB"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(M#A(&QA;F?@(')E:6MI82!A=&ED87)I;NMT:2!I\"!N=7-T871Y;?@@
M;&%N9V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")097)K^VYI:F$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED(")4:6-K971S(@IM
M<V=S='(@(D)I;&EE=&%I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I
M;64B"FUS9W-T<B`B3&%I:V%S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("),86EK;R!A
M<'-K86ET82(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B3&%I:V\@9F]R;6%T87,B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*
M;7-G<W1R("),86EK;R!P87-I<FEN:VEM87,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<FQE<W3K(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B4&%R96EG
M;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(E!A=F%D:6YI
M;6%S.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(DMA;2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E
M;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A0
M0RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM
M<V=S='(@(B(*(DYO<NMD86UI('!A<VER:6YK=&D@:V5L973@(&5L96UE;G3X
M+"!L86EK>6MI=&4@0V]N=')O;"`H4$,I(&%R8F$@0V]M;6YA9"`B"B(H36%C
M*2!K;&%V:?#@+"!I<B!P87-I<FEN:VET92!P96QE+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@
M(M!I86YD:65N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(E)O9'ET:2!(5$U,(&MO9.`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O
M(@IM<V=S='(@(E1O9V%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B4GET;VHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&]P(@IM<V=S='(@(E9I<O!U:F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A
M;64@*%]T;W`I(@IM<V=S='(@(E9I<O!U=&EN:6%M92!L86YG92`H7W1O<"DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R(")697)T:6UA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED861A<R!I<B!4
M;V)A9V%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I
M9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")486EP(&%R8F$@;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R(")!;G1R+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U
M;FES:6$B"FUS9W-T<B`B5'5N:7-A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U<FME>2(*;7-G<W1R(")4=7)K:6IA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@
M(E1U<FMI\&MA("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;>MN:6IA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@
M(E1U<FMS;R!I<B!+86EK;W-O('-A;&]S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("+!=F5S:VET92!S879O('!A<VER:6YK:6W@.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B52Y6+B!I;F1E:W-A<SH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ
M-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R
M('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B
M4VMR:7!T;R!P<FES=&%T>6UO('-T871U<V\@<F%P;W)T;R!54DPB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED
M(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5
M9V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M56MR86EN92(*;7-G<W1R(")5:W)A:6YA(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#$R"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO('!E<G-K86ET>71I(%9&4R!K
M871A;&]G;RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO
M;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DYE<&%V>6MO('!R:63K=&D@
M<&%P:6QD;VUO<R!V87)T;W1O:F\@<F5G:7-T<F%C:6IO<R!I;F9O<FUA8VEJ
M;W,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS.#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('!A:V5I<W1I
M(%9&4R!F86EL;R!<(B5S7"(@=&5I<VGX+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(DYE<&%V>6MO
M('!A:V5I<W1I('1E:7-I^"!61E,@9F%I;'5I("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DYE<&%V>6MO('!E
M<F5I=&D@X2`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K
M(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO(&%T:61A
M<GET:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ
M92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('!E<G9A9&EN=&D@
M5D93(&9A:6QO("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L
M+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N(@IM<V=S='(@(DYE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@4U%,('-E
M<G9E<FEO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,Y"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B3F5P
M879Y:V\@<')I<VEJ=6YG=&D@4U-,(')E_FEM=2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ.38@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B3F5P879Y:V\@;G5K;W!I:G5O=&D@
M5D93(&9A:6QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@5D93
M(&MA=&%L;V=O(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"FUS9VED(")5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE<&%V>6MO
M('-U:W5R=&D@5D93(&MA=&%L;V=O+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I
M;&4N(@IM<V=S='(@(DYE<&%V>6MO('-U:W5R=&D@5D93(&9A:6QO+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL;R!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R
M(").97!A=GEK;R!S=6MU<G1I('1U\.AI;R!61E,@9F%I;&\N(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(").97!A=GEK;R!I\&%R
M8VAY=G5O=&D@9'5O;65N^"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I
M;G1I(%PB)7-<(BP@:V%T86QO9V%S(&YE='7PZ&EA<R(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z
M("5S+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I
M;G1I("5S+"!K871A;&]G87,@;F5T=?#H:6%S(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DYE<&%V>6MO(')E:W5R<VGP
M:V%I(&GP=')I;G1I(%9&4R!K871A;&]G;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!61E,@
M:V%T86QO9V\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,3<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS
M9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@5D93(&MA=&%L;V=O.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B3F5P879Y:V\@:?!T<FEN=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C$V-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE
M+B(*;7-G<W1R(").97!A=GEK;R!I\'1R:6YT:2!61E,@9F%I;&\N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(DYE<&%V>6MO(&GP=')I;G1I(%9&4R!F86EL;R!<(B5S
M7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+B(*;7-G<W1R(").97!A=GEK;R!R96MU<G-I\&MA:2!I\'1R:6YT
M:2!61E,Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S
M"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+B(*;7-G<W1R(").97!A=GEK;R!N=7-T871Y=&D@9&%B87)T:6YI;R!K871A
M;&]G;RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P
M,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<R(*;7-G<W1R(").97!A=GEK;R!G875T:2!S97)T:69I:V%T;R!A<')A\'EM
M;R(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT-3$@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(").97!A=GEK;R!U_FMR875T:2`E<R!A<')A\'EM;RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0IM
M<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DYE<&%V
M>6MO('!E<FME;'1I(%9&4R!F86EL;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`R"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-C0X(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").97!A=GEK;R!A=&ED
M87)Y=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"FUS
M9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL;R!R8?!Y;75I+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*
M;7-G<W1R(").97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3F5P
M879Y:V\@871I9&%R>71I('-U<W!A=7-T;R!A<F-H>79O+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(DYE<&%V>6MO(.%R8?!Y=&D@5D93(&9A:6QO("AC;W!Y*"D@:VQA:61A*2XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL
M960I+B(*;7-G<W1R(").97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R`H8V]P
M>2@I(&ML86ED82DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B3F5P879Y:V\@<&5R=F%D:6YT
M:2!61E,@9F%I;&\N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYE<&%V>6MO('!E<G-K86ET>71I('9F<W)O;W0@:V%T
M86QO9V\N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R(").
M97!A=GEK;R!P97)V861I;G1I("5S(.$@)7,Z('1O:W,@:V%T86QO9V%S(&IA
M=2!E9WII<W1U;VIA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!K871A;&]G;RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S
M+B(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!K871A;&]G;SH@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE
M<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").97!A=GEK;R!P97)V
M861I;G1I(%9&4R!F86EL;R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+B(*;7-G<W1R(").97!A=GEK;R!P97)V861I;G1I(%9&4R!F86EL
M;RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*
M;7-G<W1R(").97!A=GEK;R!P86QE:7-T:2`G;6MI<V]F<R<N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B3F5P879Y:V\@:?!V97)S=&D@\&EO(%=O<F0@9&]K=6UE;G1O(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HQ-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5P879Y:V\@X7)A
M\'ET:2!61E,@9F%I;&\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET:2!6
M1E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R
M(").97!A=GEK;R#A<F'P>71I(%9&4R!F86EL;R!D=6]M96[X+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB
M"FUS9W-T<B`B3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH*2!K
M;&%I9&$I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")086)R875K=&DB
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H
M86YG97,B"FUS9W-T<B`B073P875K=&D@<&%K96ET:6UU<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D%T\&%U:W1I(&%N:W-T
M97-NX2!V96EK<VW@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B3F5T:6OK=&$@<V5R=F5R
M:6\@:VQA:61A.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z("(*;7-G<W1R(").971I:^MT82!S97)V97)I;R!K;&%I9&$Z("(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q
M"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(DYE;G5R;V1Y=&$B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM
M<V=S='(@(E5N:6MO9&%S("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B
M56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B2G5N9W1I;FEA:2!!<F%B
M^"!%;7ER871A:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D
M;VTB"FUS9W-T<B`B2G5N9W1I;NL@2V%R86QY<W3K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")*=6YG=&ENZW,@5F%L
M<W1I:F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-
M:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(DIU;F=T:6YI^"!686QS
M='EJ^"!!=&]K97-NZW,@<V%L;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI
M=',B"FUS9W-T<B`B5FEE;F5T86DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DYE_FEN;VUA<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM
M<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G
M<W1R(").9?YI;F]M87,@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2XB"FUS9W-T<B`B3F7^:6YO;6%S(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0HC
M+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3F5N=7-T871Y=&$@=FEE=&]VZRXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYE_FEN;VUA<R!V
M87)T;W1O:F\@=F%R9&%S(&ER+V%R8F$@<VQA<'1A_F]D:7,N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X
M"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")0
M86YA:6MI;G1I(&YU;W)O9.`@\&EA;2!E;&5M96YT=6DB"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*
M;7-G<W1R(").9>%V87)D:6YT87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@
M<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA
M=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O
M('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*
M(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H
M92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(E-A=6=U;6\@<W5M971I;6%I<R!N
M97!R:79I;&5G:6IU;W1I('-K<FEP=&%I(&YE9V%L:2!A=&QI:W1I(%!E<FOK
M;&EM;R\B"B)+;W!I:F%V:6UO+\%KZVQI;6\@<')O9W)A;6GP:V%I+B!.;W+K
M9&%M:2!P97+^:?MRZW1I('1E8VAN:6YE<R!D971A;&5S("(*(FUO>FEL;&$N
M;W)G('1I;FML87!Y:F4L(&ER('-U_FEN;W1I(&MA:7`@<VMR:7!T86US(&QE
M:7-T:2!P<FEE:71I('!R:64@(@HB;&%I:VEN;W-I;W,@<V%U9WEK;&]S+"!P
M87-P875S:VET92!/2RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G
M<W1R(").96YA=61O=&D@<W!A;'9O<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B4&SK
M=&EN>7,@;F5P86QA:6MO;6%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*
M;7-G:60@(E5P9&%T92(*;7-G<W1R(")!=&YA=6II;G1I(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B071N875J:6YT:2`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T
M92!U<V5R(@IM<V=S='(@(D%T;F%U:FEN=&D@=F%R=&]T;VK@(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R("(G)7,G(&%T;F%U
M:FEN=&$N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@
M(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(D%T;F%U:FEN:6UO
M('-K<FEP=&%S(&GP=')I;G1A<RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R(").=7-I^'-T:2(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")6
M:7-I(&UO9'5L:?@@871N875J:6YI;6\@9F%I;&%I(.%K96QT:2#A('-E<G9E
M<N$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R(")$:63^:6]S:6]S(&QO=&EN:?!K;W,@<F%I9.MS(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")$:61I96II(')O
M;>MN:?!K:2!S:V%IZ&EA:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U
M87DB"FUS9W-T<B`B57)U9W9A:G5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DYA=61O=&D@9&%B87)T:6[F
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(DYA=61O=&D@4U-,
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB
M"FUS9W-T<B`B3F%U9&]T:2!J96EG=2!V87)T;W1O:F\@=F%R9&%S+W-L87!T
M8?YO9&ES($E-4U`@<V5R=F5R:75I('ER82!K:71O:W,N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B
M57-E<B(*;7-G<W1R(")687)T;W1O:F%I(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(E9A
M<G1O=&]J87,@)7,@;F5A=71O<FEZ=6]T87,@<')IZVII;75I('!R:64@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(E9A<G1O=&]J^"!A9&UI;FES=')A=FEM87,B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E
M<B!/<'1I;VYS(@IM<V=S='(@(E9A<G1O=&]J;R!N=7-T871Y;6%I(@H*(SH@
M<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T
M<B`B5F%R=&]T;VKX(')E9VES=')A8VEJ82(*"B,Z('-I9VYU<"YP:'`Z,C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N(@IM<V=S='(@(E9A<G1O=&]J^"!R96=I<W1R86-I:F$@
M:?!J=6YG=&$N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0HC+"!F
M=7IZ>0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(E
M<R!N97)A<W1A<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E
M;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R
M;F%M92(*;7-G<W1R(")687)T;W1O:F\@=F%R9&%S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R(")687)T;W1O:F\@=F%R9&%S("<E<R<@:F%U(&5G>FES='5O:F$N(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R
M;F%M93HB"FUS9W-T<B`B5F%R=&]T;VIO('9A<F1A<SHB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S
M='(@(E9A<G1O=&]J;R!V87)D87,Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(E9A<G1O=&]J86D@\&EO:F4@<VES=&5M;VIE.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W1A;F%S
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B5D93(&MA=&%L;V=A<R!N965G>FES
M='5O:F$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I
M9"`B5F%C871I;VXB"FUS9W-T<B`B071O<W1O9V]S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@(@IM<V=S='(@(E)A<W1O<R!T96ES:6YG;W,@=FEE=&]V
MZW,Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X
M"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")'86QI;VII;6%S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U
M"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")2
M96EK\&WK(&UI;G5TZVUI<R!N=6\@9&%B87(N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E)E:6OP;>MS
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R
M;VTB"FUS9W-T<B`B4F5I:_!MZW,@:?`@:W5R:?@@9V%L:6UA('!A<VER:6YK
M=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A
M;G5A='4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS
M9VED(")687)I86)L92(*;7-G<W1R(")+:6YT86YT:7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97-U96QA(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E
M<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E
M;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")0871V:7)T:6YI;6%S(&YE8F%I
M9W1A<R`M(/!I<R!L86GP:V%S('-U9V%D:6YT87,N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS
M9W-T<B`B5F5R<VEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")697)S:6KX(&MO
M;G1R;VSK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B
M3'EG:75O=&D@=F5R=&EK86QI86DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG
M(@IM<V=S='(@(E9E<G1I:V%L=7,@=&%R<&%S(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ
M(@IM<V=S='(@(E9E<G1I:V%L=7,Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R
M("),86)A:2!D:61E;&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.
M86TB"FUS9W-T<B`B5FEE=&YA;6%S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE
M=&YA;6EE=&GP:V$@*%9)4T-)22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E
M<R(*;7-G<W1R(")097+^:?MRZW1I("5S(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G
M<W1R(")2;V1Y=&D@:?!O<FENX2!P=7-L87#A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E9I97<@87,@)7,B"FUS9W-T<B`B4&5R_FG[<NMT:2!K86EP("5S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS
M9W-T<B`B0G)I=/@@5FER9/YI;FEJ;W,@<V%L;W,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")*058@5FER
M9/YI;FEJ;W,@<V%L;W,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM
M<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")-871O;75M87,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y
M.B`B"FUS9W-T<B`B36%T;VUU;6%S.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O
M;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D869O;F4@271A;&EJ82!P
M97(@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T
M<B`B5T%23B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(*;7-G<W1R(")$RTU%4TE/(2$A(%!!5%E3($G05%))
M3DM)5$4@4TM225!4P"!)T"`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B5TE.('9I82!(
M5%10(@IM<V=S='(@(G-M<S)E;6%I;"!P97(@2%144"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E9A;&ES(&ER
M($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")$ZVUE<VEO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B
M5V4B"FUS9W-T<B`B5')EZ"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B3W+X
M('!R;V=N;WKK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R
M-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D]R
M^"!P<F]G;F]ZZR!P86=A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S
M='(@(E=75R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G
M:60@(E=E8B!3:71E(@IM<V=S='(@(E=75R!P=7-L87!I<R(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E
M96ML>2(*;7-G<W1R(")+87,@<V%V86ETYB(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(E-V96EK
M:2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(E-V96EK:2!A='9Y:^8@X2`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("),86)A<RP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B5F%K87+X
M("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS
M9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B5F%K87+X("A)
M4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA
M<F$B"FUS9W-T<B`B5F%K87+X(%-A8VAA<F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@
M(DMO:^$@;6]D=6SA("5S('1U<FD@<F]D>71I('!O('!R:7-I:G5N9VEM;S\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B2V]K<R!S
M:VER='5K;R!S:6UB;VQI<S\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*
M;7-G<W1R(")+;VMS(&MA8G7H:?@@<VEM8F]L:7,_(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*(RP@9G5Z>GD*;7-G
M:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")!=7-T<F%L:6IA
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S
M97,B"FUS9W-T<B`B2W5R:6]S(&9A>NMS(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")(5$U,(')E9&%K=&]R
M:6%U<R!M;V1U;&GX(.%J=6YG:6UA<RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*
M;7-G<W1R(")0;&]T:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B4&QO=&ES
M($-34R!M871A:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R
M("(E<R!K86ER:6]J;R!M96YI=2!P;&]T:7,@*'!A:V5I=&EM86D@8G5S(&UA
M='ET:2!P;R!K:71O('!R:7-I:G5N9VEM;RDZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F
M('1H92!T86)L92(*;7-G<W1R("),96YT96SK<R!P;&]T:7,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B
M5VED=&@@=6YI="(*;7-G<W1R(")0;&_H:6\@;6%T87,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED
M=&@Z(@IM<V=S='(@(E!L;W1I<SHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7:6YD(@IM
M<V=S='(@(E;K:F%S.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM<V=S
M='(@(DQI971U<R!R>71E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM
M<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R(")6ZVIO(&=R96ET
M:7,@;6%Z9V%I<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34V"FUS9VED
M(")7:6YD.B(*;7-G<W1R(")6ZVIA<SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5NMJ87,Z
M("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M
M(@IM<V=S='(@(DGP;6EN=&ES(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Y-@HC+"!F=7IZ>0IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B4&%G
M96ED879I;6%I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED
M(")7;W)K(@IM<V=S='(@(D1A<F)A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM
M<V=S='(@(D1A<F)O(&%D<F5S87,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S
M='(@(D1A<F)O('1E;&5F;VYA<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$Q-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B
M4VES=&5M82!N971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&9A:6S@+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM
M<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G
M<W1R(")8-3`Y=C,@<&%G<FEN9&EN:6%I(&YU<W1A='EM86DB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S
M($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y=C,@:?!P;.MS=&\@
M<F%K=&\@<&%N875D;VII;6%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T
M:79E($YA;64B"FUS9W-T<B`B6#4P.78S(&%L=&5R;F%T>79U<R!V87)D87,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I
M9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P
M.78S(')A:W1O(&ED96YT:69I:V%T;W)I=7,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO
M;G,B"FUS9W-T<B`B6#4P.78S(&UO9'5L:6%I(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"FUS9VED(")965E9(@IM
M<V=S='(@(EE965DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO
M;R$@_F5MZVQA<&ES(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(DMA<VUE="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N87,B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S
M"FUS9VED(")997,B"FUS9W-T<B`B5&%I<"(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R
M964B"FUS9W-T<B`B5&%I<"P@8?`@<W5T:6YK=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)*^W,@97-A=&4@5$5+4U1)
M3DE!344@4D7>24U%+B!.;W+K9&%M:2!G<N'^=&D@X2!765-)5UE'('-P875S
M:VET92!;/#Y=+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DK[<R!N97!R:7-I:G5N9^8N(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@
M(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@
M9G5L;"!N86UE+B(*;7-G<W1R(")3879O('9A<F1E(&YE9V%L:71E(&YA=61O
M=&D@<VEM8F]L:6\@)UQ<)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO
M=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T
M<B`BP79E9.MT92!N971E:7-I;F?@(&5L+B!P8?!T;R!A9')E<^`N(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP
M;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@
M)7,N(@IM<V=S='(@(DYE<')I:G5N9^MT92!J;VMI^"!L875K^"!I\"#A:V5L
M:6%M;R!F86EL;R!P<FEE("5S(&%T:71I;FMA;?@@;&%U:_@N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N
M(&QO9V=E9"!O=70N(@IM<V=S='(@(DK[<R!A='-I:G5N9^MT92XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V
M92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O
M;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB5'5R:71E(.%V97-T
M:2!T96ES:6YGX"!T96QE9F]N;R!N=6UE<N$@*'1I:R!S:V%IZ&EU<R!I<B`G
M*R<L(&IE:6=U(&YO<FET92`B"B)N=7)O9'ET:2!T87)P=&%U=&ENX2!K;V3@
M*2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("+!=F5D
MZW1E(&YE=&5I<VEN9^`@<F5I:_!MYBXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*
M(DYO<NMD86UI(&YA=6=O=&ES(')E9VES=')A8VEJ;W,@<VES=&5M82P@='5R
M:71E('-U:V]N9FEG^W)U;W1I(&1U;VUE;O@@(@HB;65D_FEO('!O<VES=&5M
MYBXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM
M<V=S='(@(B(*(DYO<NMD86UI(&YA=6=O=&ES(')E9VES=')A8VEJ;W,@<VES
M=&5M82P@='5R:71E('-U:V]N9FEG^W)U;W1I(&1U;VUE;O@@(@HB;65D_FEO
M('!O<VES=&5MYBXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F
M;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@
M(E!R:67P('-I^'-D86UI('!R86YE\&EMX"P@87!R8?!Y:VET92!P<F]B;&5M
MX"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`BP7)A\'EK:71E(&YU;W)O9&]S(%52
M3"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9
M;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S
M='(@(E1U<FET92!P87-I<FEN:W1I('-E<G9E<N$L(&MU<N$@;F]R:71E(&GP
M=')I;G1I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M3G5R;V1Y:VET92!V87)T;W1O:F\@=F%R9.`L(&MU<FEO(&1U;VUE;FES('1R
M:6YA=&4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(").=7)O
M9'EK:71E('9A<G1O=&]J;R!V87)DX"!T<GEN:6UU:2XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB
M"FUS9W-T<B`B3G5R;V1Y:VET92!K=7)I86UO('9A<G1O=&]J;R!V87)DX"XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B3G5R;V1Y:VET
M92!A=&YA=6II;F%M;R!V87)T;W1O:F\@=F%R9.`N(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(DYU
M<F]D>6MI=&4@=F5I:W-MX"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A
M(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")*^W,@='5R:71E(.%V97-T
M:2!N875J;W,@:V%T96=O<FEJ;W,@<&%V861I;FEMX"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I
M9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(B5S('-E<VEJ82!B
M86EGZW-I+B!0<F'P;VUE('!R:7-I:G5N9W1I(&GP(&YA=6IO+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M
M86EL($%D9')E<W,B"FUS9W-T<B`B2OMS^"!E;"X@<&'P=&\@861R97-A<SHB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"FUS9VED(")9;W5R($9R
M;VTZ(&%D9')E<W,Z(@IM<V=S='(@(D5L+B!P8?!T;R!A9')E<V%S.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R
M("));F9O<FUA8VEJ82!A<&EE($IU<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R
M;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(DYU;R`E<R!S
M97-I:F]S('!R863^:6]S(&K[<_@@25`@861R97-A<R!P87-I:V5I=.LN(%1U
M<FET92!P<FES:6IU;F=T:2!I\"`B"B)N875J;RXB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S
M='(@(DK[<_@@=F%R9&%S+W!A=F%R9.LB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E
M<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB
M875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HB2OMS^"!S:7-T
M96UO<R!A=71E;G1I9FEK879I;6\@<&]S:7-T96WK(&YE<&%L86EK;R!V87)T
M;W1O:O@@:_MR:6UO+"!A<F)A(/!I("(*(F=A;&EM>6+K(&GP:G5N9W1A(&3K
M;"!T86T@=&EK<O@@<')I9?YA<^AI^"XB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB2OMS^"!A=71E;G1I9FEK879I;6\@
M<VES=&5M82!N97!A;&%I:V\@=F%R=&]T;VKX('/@<F'P;RP@87)B82#P:2!F
M=6YK8VEJ82`B"B)U_F1R875S=&$@9.ML('1A;2!T:6MR^"!P<FEE_F%SZ&GX
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@
M86=A:6XN(@IM<V=S='(@(B(*(DYU;R`E<R!S97-I:F]S('!R863^:6]S(&K[
M<_@@;F%R\'EK;.MS('1I<&%S('!A<VEK96ETZRX@5'5R:71E('!R:7-I:G5N
M9W1I("(*(FGP(&YA=6IO+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P
M"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E
M871U<F4N(@IM<V=S='(@(DK[<_@@;F%R\'EK;.L@;F5P86QA:6MO(/!I;W,@
M9V%L:6UY8NMS+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB2OMS^"!N87+P>6ML
MZR!N97!A;&%I:V\@\&EO('-P875S9&EN:6UO(&YU<W1A='EM;RX@3F]RZV1A
M;6D@871S<&%U<V1I;G1I("(*(G-P875S:VET92!#;VYT<F]L+T]P=&EO;B`K
M(%`N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U
M<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B2OMS^"!L86EK;R!J=6]S
M=&$Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED
M(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS
M9W-T<B`B2OMS^"!S=&%N9&%R=&EN:7,@87!R8?!A<SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,34X"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ(@IM<V=S='(@(DK[<_@@<W1A;F1A<G1I;FES(&%P<F'P87,Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA
M;64Z(@IM<V=S='(@(DK[<_@@=F%R9&%S+W!A=F%R9.LZ(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L
M;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B2OMS^"!N=7-T871Y;6%I(&%T
M;F%U:FEN=&DN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R(")*^W/X(&YA=6IA<R`E<R!S;&%P=&'^;V1I<R!Y
M<F$Z("5S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B
M2OMS^"!N=7-T871Y;6%I(&%T;F%U:FEN=&DN(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"XB"FUS9W-T<B`B2OMS^"!N=7-T871Y;6%I(&%T;F%U
M:FEN=&DN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B2OMS
M^"!S;&%P=&'^;V1I<R!P86ME:7-T87,B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(DK[<_@@<VQA<'1A_F]D
M:7,@<&%K96ES=&%S+B!087-I=&EK<FEN:VET92!S879O('!A\'3@(&ER('!R
M:7-I:G5N:VET92!S=2`B"B)N875J=2!S;&%P=&'^;V3^:74N(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R
M('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")*^W/X('-L87!T8?YO
M9&ES('!A:V5I<W1A<R(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B2OMS
M^"!N=71O;.8@<V5R=F5R:6%I.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G
M<W1R("):86ER87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS
M9W-T<B`B6F%M8FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(EII;6)A8G;K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8V"FUS9VED(")::7!P>2(*;7-G<W1R(")%;F5R9VEN9V]S(@H*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP
M.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM087-LZW!T
M:2!C:71U;VIA;>`@=&5K<W3@72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5M
M;W,@<')A;F7P:6UA<UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T
M94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G
M<W1R(");4F]D>71I(&-I='5O:F%MX"!T96MS=.`@+2(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L
M:6YE<UTB"FUS9W-T<B`B6U)O9'ET:2!C:71U;VIA;>`@=&5K<W3@("T@)7,@
M96EL=71E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M6V5I;'5TZR`E<R!I\"`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B
M7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]686QD>6UA<R(*"B,Z(&QI8B]A
M<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB
M+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B7T1U;VUE
M;O@@;65D:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@
M(E])\'1R:6YT:2!E:6QU=.8B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@
M(E]'<F]U<',B"FUS9W-T<B`B1U]R=7#K<R(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E!A
M7V=A;&)A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R(")?4&%V96EK<VSK;&EO(&YU<W1A='EM86DN+BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN
M(@IM<V=S='(@(E!R:7-I7VIU;F=T:2(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(D%T
M<VE?:G5N9W1I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS
M9W-T<B`B7TME:7-T:2!N=6]R;V3@+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?
M3G5S=&%T>6UA:2(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI
M<W-I;VYS(@IM<V=S='(@(E]496ESZW,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R(")?2?!T<FEN=&D@;G5O<F]DX"XN+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]+;VYF
M:6?[<F%C:6IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")?3&5N=&5LZW,@;G5S=&%T>6UA:2XN+B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E9?87)T;W1O:F%I
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@(F%D
M9')E<W,@8F]O:R(*;7-G<W1R(")A9')E<_@@:VYY9V5LZR(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED
M(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")A9')E<_@@:VYY9V5LZR(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE
M;F1A<B(*;7-G<W1R(")+86QE;F1O<FEU<R(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M
M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B<F%M=7,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(G-P875S:VET92#H
M:6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY
M"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B5S(&YU<W1A
M='EM86DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U
M-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM
M<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@
M(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("(E<R!N97)A<W1A<RXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B
M9F%L;&EN9R(*;7-G<W1R(")K<F5N=&$B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX-34*;7-G:60@(F9I;&4B"FUS9W-T<B`B9F%I;&%S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")N
M=6\@)7,@*"5S*2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B+"!G
M^W-I86D@)7,@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0Y"FUS9VED(")H.B(*;7-G<W1R(")A.B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")T=6]J874@<&%T(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")P87!R87-T:2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U
M="]O=71P=70@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B96EL=71E
M<UTB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI
M<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O
M<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,@
M:VQA:61O<R!K;V1A<R`E9"!B961A<F%N="!)4T\N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(G9A
M<F1A<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@(FYO
M="!I;7!L96UE;G1E9"(*;7-G<W1R(")N97)E86QI>G5O=&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y
M970@:6UP;&5M96YT960B"FUS9W-T<B`B9&%R(&YE<F5A;&EZ=6]T82(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D
M(@IM<V=S='(@(G7^<F'P^"!K;GEG96SK(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R(")P<F]C96YT86DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D
M96YI960B"FUS9W-T<B`B5&5I<^MS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM
M<V=S='(@(G!I:W-E;&EA:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")K>6QA(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*(RP@9G5Z>GD*;7-G
M:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B3W)O('/@;'EG^"!B
M;&]K;R!NZW)A+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G
M:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B<F]D>71I('-K:7)T=6UU
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS
M,F5M86EL('!E<B!(5%10(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T
M96%D>2(*;7-G<W1R(")S=&%B:6QI(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U
M,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B9&%R8O@@<^!R8?!A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ
M>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(DMI96MV:65N;R!P<FES:6IU
M;F=I;6\@;65T=2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B<VQA<'1A_F]DX2!T=7)I
M=&4@X7)A\'ET:2!D=2!K87)T=7,B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*
M;7-G<W1R(")U;FEF:6MU;W1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]0
M87)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")D86QI<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B=F%R=&]T;VIO('!A
M<VER:6YK:6UA<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED
M(")W.B(*;7-G<W1R(")P.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W96%T:&5R+F-O
M;2(*``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]D95]$12YP;P``````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W
M-3`P-#`@,3`U,34T,S0Q-#(@,#$W-#4V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````",@1V5R;6%N('1R86YS;&%T:6]N<R!F
M;W(@2&]R9&4@<&%C:V%G90HC($=E<FUA;B!M97-S86=E<R!F;W(@2&]R9&4N
M"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#8@2&]R9&4@4')O:F5C=`HC(%1H
M:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E
M(&%S('1H92!(;W)D92!P86-K86=E+@HC($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^+"`R,#`Q+3(P,#8N"B,*(R!M87)G:6XZ($%UWV5N86)S=&%N
M9`HC('!A9&1I;F<Z($EN;F5N86)S=&%N9`HC($AI<W1O<GDZ($-H<F]N:6L*
M;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E
M(#,N,2UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P-BTP-RTS,2`Q
M.#HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V+3`X+3`Y(#$V
M.C0U*S`R,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SY<;B(*(DQA;F=U86=E+51E86TZ($=E<FUA;B`\9&5V
M0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,5QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("AV;W(@)7,@5&%G96XI(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<T"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%IU9W)I9F9S
M=&%S=&4@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H
M:6X@)7,@5&%G96XI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y
M,0IM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("AH975T92DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDS"FUS9VED("(@*'1O;6]R<F]W*2(*
M;7-G<W1R("(@*&UO<F=E;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S@Y"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AG97-T97)N
M*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S='(@(B!M:70@(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M7"(E<UPB(&ES="!K96EN(%9E<GIE:6-H;FES+B(*"B,Z(&9R86UE=V]R:R]#
M3$DO0TQ)+G!H<#HR.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&ES="!K96EN
M92!G_&QT:6=E($%U<W=A:&PN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+U)E9VES=')Y+G!H<#HW,#<*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HQ,#DU"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S
M='(@(EPB)7-<(B!I<W0@:6X@9&5R($AO<F1E(%)E9VES=')Y(&YI8VAT(&MO
M;F9I9W5R:65R="XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")$97(@0F%U;2U296YD97)E<B!F_'(@7"(E<UPB
M('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB('=U<F1E('IU;2!'
M<G5P<&5N<WES=&5M(&AI;GIU9V5F_&=T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B!W=7)D92!Z=6T@4F5C:'1E<WES=&5M(&AI;GIU9V5F_&=T+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T
M960Z("5S+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@;FEC:'0@97)S=&5L;'0Z
M("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR
M9B4E*2(*;7-G<W1R("(E+C)F34(@*"4S)"XR9B4E*2!V;VX@)3(D+C)F34(@
M97)L875B=&5N('9E<F)R875C:'0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E
M<R(*;7-G<W1R("(E9"`E<R!U;F0@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3DT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R
M9"!E>'!I<F5S+B(*;7-G<W1R("));B`E9"!486=E;B!W:7)D($EH<B!087-S
M=V]R="!U;F?\;'1I9RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"U486=E+59O<FAE<G-A9V4B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I
M8V4B"FUS9W-T<B`B)7,@+2!(:6YW96ES(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@1FEN9V5R86)D<G5C:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!787)T
M=6YG<V%R8F5I=&5N("T@0F5S=.1T:6=U;F<B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,M2V]N9FEG=7)A
M=&EO;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!2
M96=I<W1R:65R=6YG(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R("(E<R!.=71Z=6YG<V)E9&EN9W5N9V5N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT-3`@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU,38*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#D@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&5X:7-T:65R="!B97)E
M:71S+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38Q(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38W(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Q"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S0W(&QI8B]";&]C:R]M971A<BYP:'`Z,S4S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&UI
M="`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H
M92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K
M('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@
M<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S('=I<F0@9&EE
M(%=A<G1U;F=S87)B96ET96X@9'5R8VAF_&AR96XL(&1I92!U;G1E;B!M87)K
M:65R="!S:6YD+B!-87)K:65R96X@(@HB4VEE(&%L;&4@075F9V%B96XL(&1I
M92!J971Z="!D=7)C:&=E9OQH<G0@=V5R9&5N('-O;&QE;BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S4X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(&ES="!N;W1W96YD:6<B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S($UI;G5T96XB"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEC:'0@9V5F
M=6YD96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E
M<R!B:7,@)7,@=F]N("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B)7-S($%D<F5S<V)U8V@B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDT-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(B5S<R!+86QE;F1E<B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3,V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T
M97!A9"(*;7-G<W1R("(E<W,@3F]T:7IB;&]C:R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.38P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M5&%S:VQI<W0B"FUS9W-T<B`B)7-S($%U9F=A8F5N;&ES=&4B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R
M("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL
M+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S
M<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E
M=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R
M;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T
M:6]N+B(*;7-G<W1R("(B"B(E<SH@1&EE<V4@3F%C:')I8VAT('-T86UM="!U
M;G1E<B!5;7-TY&YD96X@;FEC:'0@=F]N(&1E;2!A;F=E9V5B96YE;B`B"B)!
M8G-E;F1E<BX@1F]L9V5N(%-I92!K96EN96X@3&EN:W,@:6X@9&EE<V5R($YA
M8VAR:6-H="!U;F0@:/QT96X@4VEE('-I8V@@(@HB9&%V;W(L(&1E;2!!8G-E
M;F1E<B!P97)S]FYL:6-H92!$871E;B!P<F5I<WIU9V5B96XN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@
M8O9I9R`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C$Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@
M)7,@)7,B"FUS9W-T<B`B+"!B:6<@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!S8VAW86YK96YD('9O;B`E<R!B:7,@
M)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#8*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.`IM
M<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM($%U<W?D:&QE;B`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,3(M4W1U;F1E;BU&;W)M870B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T
M+5-T=6YD96XM1F]R;6%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(%-T=6YD96XB"@HC.B!F
M<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B
M"FUS9W-T<B`B/%IU<OQC:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(D9R(&1I97-E;B!";&]C:R!W:7)D(&5I;F4@
M1&%T96YB86YK(&)E;G1I9W0N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S$*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM
M<V=S='(@(D5I;B!S8VAW97)E<B!&96AL97(@:7-T(&%U9F=E=')E=&5N.B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDT-`IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92XB"FUS9W-T<B`B(@HB16EN(/9F9F5N=&QI8VAE<B!01U`M4V-H;/QS
M<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN97(@3F%C:')I
M8VAT("(*(F)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q-S<*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER
M960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I
M;B#V9F9E;G1L:6-H97(@4$=0+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@W&)E
M<G!R_&9U;F<@96EN97(@(@HB=6YT97)Z96EC:&YE=&5N($YA8VAR:6-H="!B
M96[V=&EG="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,3`X"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16EN(/9F9F5N=&QI8VAE<B!U;F0@
M96EN('!R:79A=&5R(%!'4"U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T
M('=I<F0@9OQR("(*(F1I92!%;G1S8VAL_'-S96QU;F<@96EN97(@3F%C:')I
M8VAT(&)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$P,C4*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B)%:6X@]F9F96YT;&EC:&5R('5N
M9"!E:6X@<')I=F%T97(@4$=0+5-C:&S\<W-E;"!S;W=I92!E:6X@4&%S<W=O
M<G0@=VER9"!F_'(@(@HB9&EE(%5N=&5R>F5I8VAN=6YG(&5I;F5R($YA8VAR
M:6-H="!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4P-@IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E
M;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M4V-H;/QS<V5L('-O
M=VEE(&5I;B!087-S=V]R="!W:7)D("(*(F;\<B!D:64@16YT<V-H;/QS<V5L
M=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(D5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M
M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D("(*(F;\<B!D:64@
M56YT97)Z96EC:&YU;F<@96EN97(@3F%C:')I8VAT(&)E;O9T:6=T+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!
M('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(D5I;B#V9F9E;G1L:6-H97(@4R]-24U%+5-C
M:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG(&5I;F5R("(*
M(DYA8VAR:6-H="!B96[V=&EG="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B
M5F]R;6ET=&%G<R!7;VQK96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R
M(")6;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-($QI9VAT(%-N
M;W<B"FUS9W-T<B`B5F]R;6ET=&%G<R!L96EC:'1E<B!38VAN965F86QL(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G
M:60@(D%-(%)A:6XB"FUS9W-T<B`B5F]R;6ET=&%G<R!296=E;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!
M32!3:&]W97)S(@IM<V=S='(@(E9O<FUI='1A9W,@4V-H875E<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")!
M32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B5F]R;6ET=&%G<R!38VAN965S8VAA
M=65R(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B
MW&)E<B!D:65S96X@161I=&]R(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP
M:'`Z-30*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(DEN9F\N+BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED
M(")!8G-B;W1T;VTB"FUS9W-T<B`B06)S;VQU="!5;G1E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B
M<VUI9&1L92(*;7-G<W1R(")!8G-O;'5T($UI='1E(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(X,0IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("):=6=R:69F('9E<G=E
M:6=E<G0@8F5I;2!!;FQE9V5N(&1E<R!61E,M5F5R>F5I8VAN:7-S97,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-0IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B6G5G<FEF
M9B!V97)W96EG97)T(&)E:6T@06YL96=E;B!D97(@5D93+41A=&5I+B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R
M;6%T:6]N(@IM<V=S='(@(DMO;G1O:6YF;W)M871I;VYE;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*
M;7-G<W1R(")+;VYT;W!A<W-W;W)T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R
M;WIE;BXB"FUS9W-T<B`B2V]N=&\@96EN9V5F<F]R96XN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R(")"=6-H:&%L='5N9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30X('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D
M(@IM<V=S='(@(DAI;GIU9OQG96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(S
M,2!A9&UI;B]G<F]U<',N<&AP.C(S,@IM<V=I9"`B061D($-H:6QD($=R;W5P
M(@IM<V=S='(@(DYE=64@56YT97)G<G5P<&4@:&EN>G5F_&=E;B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB
M"FUS9W-T<B`B3F5U92!5;G1E<G)E8VAT92!H:6YZ=6;\9V5N(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G
M<W1R(")(:65R(&AI;GIU9OQG96XZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHT-@IM<V=I9"`B061D($UE;6)E<G,B"FUS9W-T<B`B
M36ET9VQI961E<B!H:6YZ=6;\9V5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`B3F5U92!'<G5P<&4@:&EN>G5F_&=E;B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(DYE=64@4F5C:'1E(&AI;GIU9OQG96XB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")5;G1E<F=R=7!P
M92!Z=2!<(B5S7"(@:&EN>G5F_&=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H
M:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(E5N=&5R<F5C:'1E
M('IU(%PB)7-<(B!H:6YZ=6;\9V5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*
M;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R(")&_&=E;B!3:64@96EN
M96X@;F5U96X@0F5N=71Z97(@:&EN>G4Z(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D(&-O;'5M;B(*
M;7-G<W1R(")3<&%L=&4@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(E!A87(@
M:&EN>G5F_&=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(D1A<R`E<RU-96[\('IU<B!-;WII;&QA(%-I
M9&5B87(@:&EN>G5F_&=E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB
M"FUS9W-T<B`B6G5M($%D<F5S<V)U8V@@:&EN>G5F_&=E;CHB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D
M9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B6G4@;65I;F5M($%D<F5S
M<V)U8V@@:&EN>G5F_&=E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED
M(")!9&0@=7-E<B(*;7-G<W1R(")"96YU='IE<B!H:6YZ=6;\9V5N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D
M960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B
M(@HB7"(E<UPB('=U<F1E('IU;2!3>7-T96T@:&EN>G5G96;\9W0L(&%B97(@
M9&EE('IU<^1T>FQI8VAE;B`B"B)296=I<W1R:65R=6YG<VEN9F]R;6%T:6]N
M96X@:V]N;G1E;B!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S+B(*"B,Z
M('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T
M<B`B7"(E<UPB('=U<F1E('IU;2!3>7-T96T@:&EN>G5G96;\9W0N(%-I92!K
M]FYN96X@<VEC:"!J971Z="!A;FUE;&1E;BXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")$87,@2&EN>G5F_&=E;B!V;VX@0F5N=71Z97)N
M(&ES="!N:6-H="!M]F=L:6-H+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")!9&1R97-S($)O;VLB
M"FUS9W-T<B`B061R97-S8G5C:"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")697)W86QT96X@+2!2
M96-H=&4@9OQR(&%N9&5R92!"96YU='IE<B!F97-T;&5G96XB"@HC.B!A9&UI
M;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q
M-PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I
M;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!
M9',B"FUS9W-T<B`B5V5R8G5N9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA
M;FES=&%N(@IM<V=S='(@(D%F9VAA;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B06QB86YI82(*;7-G<W1R(")!;&)A;FEE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D%L9V5R:6$B"FUS9W-T<B`B06QG97)I96XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*
M;7-G<W1R(")3<&ET>FYA;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R
M(")!=7-R:6-H='5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B075S
M<FEC:'1U;F<Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS9VED
M(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C8*;7-G
M:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(D%N9V5M96QD
M971E($)E;G5T>F5R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G
M<F]U<',N<&AP.C(R.`IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")!;&QE
M($=R=7!P96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ
M(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@
M(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")!;&QE(%)E8VAT92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*
M;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(D%L;&4@=FEE<B!396ET
M96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@Y"FUS9VED(")!
M;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B365H<F5R92!!9')E
M<W-E;B!E<FQA=6)E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S$*
M;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM
M<V=S='(@(D9O<FUA="!V;VX@;G5M;65R:65R=&5N($QI<W1E;B#D;F1E<FX_
M(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`W
M"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R(")%>&ES=&EE<G0@8F5R
M96ET<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L
M=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(D%L=&5R;F%T:79E($E-4U`M
M06YM96QD=6YG(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-`IM<V=I
M9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I
M=F5S($E-4U`M4&%S<W=O<G0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#DV"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R(")!
M;'1E<FYA=&EV97(@24U34"U"96YU='IE<FYA;64B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`B06QT97)N871I=F4@12U-86EL+4%D<F5S<V4B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E
M;7!L871E<R(*;7-G<W1R(")!;'1E<FYA=&EV92!6;W)L86=E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T
M:79E<B!497AT.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A
M(@IM<V=S='(@(D%M97)I:V%N:7-C:"U386UO82(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"XB"FUS9W-T<B`B17,@=W5R9&4@96EN('5N9_QL=&EG97(@5V5R="!A;F=E
M9V5B96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM
M<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B
M16EN('5N8F5K86YN=&5R($9E:&QE<B!I<W0@875F9V5T<F5T96XN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM
M;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYY;65R(%!R;WAY(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(D%N<W=E<B(*;7-G<W1R
M(")!;G1W;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G
M<W1R(")!;G1A<FMT:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N
M9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@=6YD($)A<F)U9&$B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM
M<V=S='(@(D%N=V5N9'5N9R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT
M,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R(")!;G=E;F1U;F=S
M;&ES=&4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,Y"FUS9VED(")!
M<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B06YW96YD=6YG(&ES="!B
M97)E:70N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3D*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!=68@56YT97)R
M96-H=&4@86YW96YD96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")"97-TY'1I9V5N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS
M9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E5N9V5FY&AR92!'<O;?
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X
M"FUS9VED(")!<')I;"(*;7-G<W1R(")!<')I;"(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<X"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS
M9W-T<B`B07)A8FES8V@@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS
M9W-T<B`B07)C:&EV9W+VWV4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D%R8VAI=FYA;64B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@
M(B(*(E-I;F0@4VEE('-I8VAE<BP@9&%S<R!3:64@9&EE(%)E9VES=')I97)U
M;F=S86YF<F%G92!V;VX@)7,@;/9S8VAE;B!M]F-H=&5N/R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*
M;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB
M(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@HB4VEN9"!3:64@<VEC
M:&5R+"!D87-S(%-I92!<(B5S7"(@=6YD(&%L;&4@56YT97)G<G5P<&5N(&SV
M<V-H96X@;?9C:'1E;C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B
M"FUS9W-T<B`B07)G96YT:6YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE
M;FEA(@IM<V=S='(@(D%R;65N:65N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(D%R
M;65N:7-C:"`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(DMU;G-T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S
M='(@(D%S8V5N<VEO;BU);G-E;&XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!4T-)22U+=6YS="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I
M82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!<VEE;B]087II9FES8VAE(%)E
M9VEO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C(*;7-G:60@(D%S
M:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O
M<&5R871I;VYS/R(*;7-G<W1R(")!;G-T96AE;F1E(%=A<G1U;F=S87)B96ET
M96X@8F5S=.1T:6=E;B!L87-S96X_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@
M(EIU;W)D;G5N9W-F96QD97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS
M9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB
M"FUS9W-T<B`B17,@=W5R9&4@=F5R<W5C:'0L(&5I;F4@;FEC:'0@97AI<W1I
M97)E;F1E($=R=7!P92!Z=2!L]G-C:&5N+B(*"B,Z(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D5S('=U<F1E('9E<G-U8VAT
M+"!E:6X@;FEC:'0@97AI<W1I97)E;F1E<R!296-H="!Z=2!L]G-C:&5N+B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O
M(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B17,@
M=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT
M('IU(&)E87)B96ET96XN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA
M<F4N(@IM<V=S='(@(D5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI
M<W1I97)E;F1E<R!296-H="!Z=2!B96%R8F5I=&5N+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@
M(D%T=')I8G5T92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B075G=7-T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(D%U<W1R86QI96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(M9S=&5R<F5I
M8V@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS
M9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@1&EE(&)E;O9T:6=T92!)
M34%0+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!$87,@0F%C:V5N9"!H870@;FEC
M:'0@9&EE(&)E;O9T:6=T96X@1N1H:6=K96ET96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?8WER=7,Z($1I92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W=7)D
M92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T
M<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($1I92!B
M96[V=&EG=&4@1E10+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N
M+B!+;VUP:6QI97)E;B`B"B)3:64@4$A0(&UI="!D96T@+2UE;F%B;&4M9G1P
M(%!A<F%M971E<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP
M.C8P"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!$:64@8F5N]G1I9W1E
M($E-05`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K
M<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?:W)B-3H@1&EE(&)E;O9T:6=T92!+97)B97)O<RU%<G=E:71E
M<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*
M;7-G<W1R("(B"B)!=71H7VQD87`Z($1A<R!(:6YZ=6;\9V5N('9O;B!"96YU
M='IE<FX@=VER9"!F_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="`B"B)U;G1E
M<G-T_'1Z="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W
M"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L
M9&%P.B!$87,@3/9S8VAE;B!V;VX@0F5N=71Z97)N('=I<F0@9OQR($%C=&EV
M92!$:7)E8W1O<GD@;FEC:'0@(@HB=6YT97)S=/QT>G0B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U;F<@=W5R9&4@
M;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`Z($1E<B!"96YU='IE<B`E<R!K
M;VYN=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R`B
M"B)397)V97)S.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($)E;G5T>F5R
M("5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R
M(")!=71H7VQD87`Z($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!A:W1U86QI
M<VEE<G0@=V5R9&5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB
M075T:%]L9&%P.B!$87,@06MT=6%L:7-I97)E;B!V;VX@0F5N=71Z97)N('=I
M<F0@9OQR($%C=&EV92!$:7)E8W1O<GD@;FEC:'0@(@HB=6YT97)S=/QT>G0N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B
M075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(D%U=&A?;6-A;#H@1&EE(&)E;O9T:6=T92!-0T%,+45R=V5I
M=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?<VUB875T:#H@1&EE(&)E;O9T:6=T92!386UB82U%<G=E:71E<G5N9R!W
M=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%D;6EN+G!H<#HQ,#,*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@
M<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B06YM96QD=6YG(&)E:6T@24U!4"U3
M97)V97(@9F5H;&=E<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960B"FUS9W-T<B`B075T:&5N=&EF:7II97)U;F<@9F5H;&=E
M<V-H;&%G96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT
M:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(D%N;65L9'5N9R!F96AL9V5S
M8VAL86=E;BX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+B(*;7-G<W1R(")$:64@075T:&5N=&EF:7II97)U;F<@=W5R
M9&4@=F]M(%)!1$E54RU397)V97(@>G5R_&-K9V5W:65S96XN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.30*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!;FUE;&1U;F<@
M8F5I;2!&5%`M4V5R=F5R(&9E:&QG97-C:&QA9V5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B06YM96QD=6YG(&)E
M:6T@4TU"+5-E<G9E<B!F96AL9V5S8VAL86=E;BXB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*
M;7-G<W1R(")697)F_&=B87)E($9E;&1E<CHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!>F5R8F%I:F%N(@IM<V=S='(@(D%S97)B86ED<V-H86XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G
M<W1R(")"3T9(+4%U<W)E9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*
M;7-G<W1R(")(:6YT97)G<G5N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B
M"FUS9W-T<B`B2&EN=&5R9W)U;F1F87)B92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R
M9"XB"FUS9W-T<B`B1F%L<V-H97,@2V5R8F5R;W,M4&%S<W=O<G0N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME
M<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")&86QS8VAE<B!+97)B97)O<RU"
M96YU='IE<FYA;64N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G
M<W1R(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G
M<W1R(")"86AR96EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1I<V-H("A)
M4T\M.#@U.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM
M<V=S='(@(D)A;F=L861E<V-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D
M;W,B"FUS9W-T<B`B0F%R8F%D;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:7,M0FEL9&5R
M+59E<GIE:6-H;FES(%PB)7-<(B!N:6-H="!G969U;F1E;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G
M:60@(D)A<V5L:6YE(@IM<V=S='(@(D=R=6YD;&EN:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"96QA<G5S(@IM<V=S='(@(E=E:=]R=6QA;F0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D)E;&=I96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS
M9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y
M(@IM<V=S='(@(D=E8G5R='-T86<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")";&]C:R!<(B5S7"(@9&5R($%N=V5N9'5N9R!<(B5S7"(@;FEC
M:'0@9V5F=6YD96XN(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]C:V5I;G-T
M96QL=6YG96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*
M;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO8VMT>7`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`B1F5T="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B0F]L:79I96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B3&5S97IE:6-H96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4F%N9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O
M<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(E)A:&UE;F1I8VME.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B4N1N9&5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:65N
M+4AE<GIE9V]W:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS
M9VED(")";W1H(@IM<V=S='(@(D)E:61E<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T
M;VTB"FUS9W-T<B`B56YT96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(D)O=79E=&EN<V5L(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;&EE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M0G)I=&ES8VAE<R!497)R:71O<FEU;2!I;2!);F1I<V-H96X@3WIE86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"
M<G5N96D@1&%R=7-S86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA
M(@IM<V=S='(@(D)U;&=A<FEE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B56YN=6UM97)I97)T92!,:7-T92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B
M0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<R(*;7-G<W1R(")#4DP@1&ES=')I8G5T:6]N<W-T96QL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?6F5L
M;&5N96EG96YS8VAA9G1E;BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T
M960N(@IM<V=S='(@(D1E<B!:=VES8VAE;G-P96EC:&5R(&MO;FYT92!N:6-H
M="!I;FET:6%L:7-I97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDT,B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4P(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S
M='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")7:6YD<W1I;&PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]D<V-H82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T
M97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B17AT97)N
M92!397-S:6]N+4AA;F1L97(@:_9N;F5N(&YI8VAT(&%D;6EN:7-T<FEE<G0@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S
M-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M(@IM<V=S='(@(E9E<F)I;F1U;F<@>G5M($E-05`M4V5R=F5R(&MA;FX@;FEC
M:'0@:&5R9V5S=&5L;'0@=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O
M<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")$:64@1&%T96D@7"(E<UPB(&MA
M;FX@;FEC:'0@9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G
M:60@(D-A;F-E;"(*;7-G<W1R(")!8F)R96-H96XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@
M4F5P;W)T(@IM<V=S='(@(E!R;V)L96UB97)I8VAT(&%B8G)E8VAE;B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#0T(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(S-0HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8W-2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C(R"FUS9VED
M(")#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO
M;B!A<F4@=&AE('-A;64N(@IM<V=S='(@(B(*(D1A=&5I*&5N*2!K]FYN96X@
M;FEC:'0@:V]P:65R="!W97)D96X@+2!1=65L;"T@=6YD(%II96QD871E:65N
M('-I;F0@(@HB:61E;G1I<V-H+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(D1I92!$871E:2!<(B5S7"(@:V]N;G1E
M(&YI8VAT(&=E;/9S8VAT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")+96EN('1E;7!O<N1R
M97,@5F5R>F5I8VAN:7,@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU,3`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HQ.#<*;7-G:60@(D-A;FYO="!M;W9E(&9I
M;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(*;7-G<W1R
M("(B"B)$871E:2AE;BD@:_9N;F5N(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N
M("T@6FEE;&1A=&5I(&)E9FEN9&5T('-I8V@@:6T@(@HB475E;&QO<F1N97(N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY
M,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+B(*;7-G<W1R(")&;W)T<V5T>G5N9R!O:&YE(%PB=&%R9V5T
M1FEL95PB+5!A<F%M971E<B!N:6-H="!M]F=L:6-H+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$X"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B1&%S(%9E
M<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES
M="XB"FUS9W-T<B`B2V]N;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;BP@)60@
M2VEN9&5R(&5X:7-T:65R96XN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C$Q"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB56US;W)T
M:65R96X@;FEC:'0@;?9G;&EC:"X@1&EE($%N>F%H;"!D97(@16EN='+D9V4L
M(&1I92!U;7-O<G1I97)T('=E<F1E;B`B"B)S;VQL96XL('-T:6UM="!N:6-H
M="!M:70@9&5R($%N>F%H;"!D97(@9V5S<&5I8VAE<G1E;B!%:6YT<N1G92#\
M8F5R96EN+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Q"FUS
M9VED(")#86YN;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(E!A<W-W;W)T
M(&MA;FX@;FEC:'0@875T;VUA=&ES8V@@>G5R_&-K9V5S971Z="!W97)D96XL
M(&)I='1E('=E;F1E;B!3:64@<VEC:"`B"B)A;B!):')E;B!!9&UI;FES=')A
M=&]R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E
M8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@HB1&EE($YA8VAR:6-H="!K;VYN
M=&4@;FEC:'0@86X@9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE:71E
M="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!W<FET92!T;R!F:6QE(%PB
M)7-<(B(*;7-G<W1R(")$:64@1&%T96D@7"(E<UPB(&MA;FX@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D
M92(*;7-G<W1R(")+87`@5F5R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N(@IM
M<V=S='(@(MQB97)S8VAR:69T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@
M(E!R;W9I9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEE;B!U
M;F0@0F5S8VAR:69T=6YG96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N+4EN<V5L;B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@
M4&AO;F4B"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L
M;"!0<F]P97)T:65S(@IM<V=S='(@(EIE;&QE;F5I9V5N<V-H869T96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM
M<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("));FYE;F%B<W1A;F0Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(EIE;&QE;F5I
M9V5N<V-H869T96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("):
M96QL96YA8G-T86YD.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E;&5F;VXB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L=&EC("A)4T\M
M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L=&ES8V@@*$E33RTX.#4Y+3$T*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("):96YT<FEE<G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B
M6F5N=')A;&%F<FEK86YI<V-H92!297!U8FQI:R(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R(")-:71T96QE=7)O<.1I<V-H("A)4T\M.#@U.2TR*2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(EIE<G1I9FEK871D971A
M:6QS(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*
M;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(EIE<G1I9FEK871B
M97-I='IE<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("):97)T
M:69I:V%T<FEC:'1L:6YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B
M"FUS9W-T<B`B5'-C:&%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(L1N9&5R;B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS
M9W-T<B`BQ&YD97)N(%-I92!):'(@4&%S<W=O<G0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@
M861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E
M<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B+$;F1E<FX@4VEE
M(&1E;B!.86UE;B!O9&5R(&1I92!!9')E<W-E+"!D:64@9&EE($5M<&;D;F=E
M<B!):')E<B!%+4UA:6PM(@HB3F%C:')I8VAT96X@<V5H96XL('=E;FX@<VEE
M(&1I97-E(&QE<V5N(&]D97(@9&%R875F(&%N=V]R=&5N+B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R+B(*;7-G<W1R("(B"B)$87,@Q&YD97)N($EH<F5S(%!A<W-W;W)T<R!W
M:7)D('9O;B!D:65S96T@4WES=&5M('IU<B!:96ET(&YI8VAT("(*(G5N=&5R
M<W3\='IT+B!":71T92!W96YD96X@4VEE('-I8V@@86X@26AR96X@061M:6YI
M<W1R871O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(EIE:6-H96XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(DQI;FL@
M_&)E<E]P<OQF96XN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G
M<W1R(")#:&EL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(D-H:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&EN97-I<V-H
M('9E<F5I;F9A8VAT("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S
M='(@(D-H:6YE<VES8V@@=')A9&ET:6]N96QL("A":6<U*2(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO
M;CHB"FUS9W-T<B`B06YW96YD=6YG(&%U<W?D:&QE;CHB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")#:&]O<V4@82!P
M87-S=V]R9"(*;7-G<W1R(")7Y&AL96X@4VEE(&5I;B!087-S=V]R="(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H
M;V]S92!A('5S97)N86UE(@IM<V=S='(@(E?D:&QE;B!3:64@96EN96X@0F5N
M=71Z97)N86UE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.34*;7-G
M:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B3&5G
M96X@4VEE(&9E<W0L('=I92!D87,@1&%T=6T@86YG97IE:6=T('=E<F1E;B!S
M;VQL.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@
M*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("),:7-T96YF;W)M870@875S
M=^1H;&5N("AF_'(@;G5M;65R:65R=&4@3&ES=&5N*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B5V5I:&YA8VAT<VEN
M<V5L(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.CDP-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S
M<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B2VQA<W-E
M;F1E9FEN:71I;VX@9OQR("5S(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A
M<B(*;7-G<W1R(")(96ET97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S
M(@IM<V=S='(@(DU3+4]F9FEC92U486=S(&5N=&9E<FYE;B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@
M(D%B9G)A9V4@>G5R_&-K<V5T>F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(D)E;G5T>F5R9&%T96X@;/9S8VAE;CH@)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@
M(D-L96%R('5S97(B"FUS9W-T<B`B0F5N=71Z97)D871E;B!L]G-C:&5N(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L
M96%R('5S97(@9&%T82(*;7-G<W1R(")"96YU='IE<F1A=&5N(&SV<V-H96XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")3<.1T97(@075F:VQA<F5N
M9"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")&;W)T9F%H
M<F5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@
M(D-L:6-K871E;&P@<&5R($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L
M;W-E(%=I;F1O=R(*;7-G<W1R(")&96YS=&5R('-C:&QI9=]E;B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C0V"FUS9VED(")#;&]U9',B"FUS9W-T<B`B
M5V]L:V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R(")&<OQH(%=O;&ME
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B0F5W]FQK="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(DMO:V]S
M:6YS96QN(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM
M<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G<W1R(")-96[\(&5I;F9A:')E
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(EIU
M<V%M;65N:.1N9V5N9&4@4F%H;65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`B2V]L=6UB:65N(@H*(SH@;&EB+T)L;V-K+V-O;&]R
M+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O
M;&]R(@IM<V=S='(@(D9A<F)E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+T-O;&QE8W1I;VXN<&AP.C,S.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M0V]L;&5C=&EO;BYP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU,#,@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(D9A<F)A=7-W
M86AL(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")&87)B=V%H;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#
M;VQS.B(*;7-G<W1R(")3<&%L=&5N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C0*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B4W!A
M;'1E;OQB97)S8VAR:69T96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-S(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(D)E
M9F5H;"(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M;6%N
M9"!3:&5L;"(*;7-G<W1R(")"969E:&QS>F5I;&4B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T
M<B`B2V]M;65N=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(D5I;F1E=71I
M9V5R($YA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R
M(")+;VUO<F5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R(")&:7)M82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM
M<V=S='(@(D-O;7!U=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D)E9&EN9W5N9V5N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-O;F1I=&EO
M;G,B"FUS9W-T<B`B0F5D:6YG=6YG96XB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R(")+;VYF:6=U<F%T:6]N<W5N=&5R<V-H:65D92(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T
M(&]F(&1A=&4N(@IM<V=S='(@(D1I92!+;VYF:6=U<F%T:6]N(&UU<W,@86MT
M=6%L:7-I97)T('=E<F1E;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R
M("(E<R!K;VYF:6=U<FEE<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M(")087-S=V]R="!B97-TY'1I9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N
M9V\B"FUS9W-T<B`B2V]N9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@
M5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(D1E;6]K
M<F%T:7-C:&4@4F5P=6)L:6,@2V]N9V\B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S0W"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`B5F5R8FEN9'5N9R!F96AL9V5S8VAL86=E;BXB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0W"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(E9E<F)I;F1U;F<@9F5H;&=E
M<V-H;&%G96XZ("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y.0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2#V9F9E;G1L:6-H
M96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E(&%B9V5W:65S96XN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.#`Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*(E9E<F)I;F1U;F<@
M>G5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(@=W5R9&4@86)G97=I
M97-E;BX@1W)U;F0Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@X.`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@1E10+5-E<G9E<B!F96AL
M9V5S8VAL86=E;B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34P
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#<W"FUS9VED(")#;VYT86-T<R(*
M;7-G<W1R(")+;VYT86MT92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(D1I
M92!+;VYT86MT92!W=7)D96X@97)F;VQG<F5I8V@@26AR96T@061R97-S8G5C
M:"!H:6YZ=6=E9OQG="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E
M9"!F:6QE.B`B"FUS9W-T<B`B26YH86QT<W1Y<"!D97(@:V]M<')I;6EE<G1E
M;B!$871E:3H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@
M(DEN:&%L="!V;VX@7"(E<UPB(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z,S`@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED
M(")#;VYT:6YU92(*;7-G<W1R(")796ET97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:RU);G-E;&XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#
M;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R96XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0X.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B2V]P:65R96X@
M9F5H;&=E<V-H;&%G96XZ("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS
M9W-T<B`B075S=V%H;"!K;W!I97)E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(DMO
M<W1E;BU)1"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T
M<B`B0V]S=&$@4FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I
M<F4B"FUS9W-T<B`B16QF96YB96EN:_QS=&4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY.#8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC
M<GEP="!M97-S86=E.B`B"FUS9W-T<B`B1&EE($YA8VAR:6-H="!K;VYN=&4@
M;FEC:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E<F1E;CH@(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`V-`IM<V=I9"`B0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")$:64@3F%C:')I8VAT
M(&MO;FYT92!N:6-H="!M:70@4$=0('5N=&5R>F5I8VAN970@=V5R9&5N.B`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(D1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!3+TU)344@=F5R<V-H
M;/QS<V5L="!W97)D96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+B(*;7-G<W1R(")$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H="!M:70@
M4R]-24U%('5N=&5R>F5I8VAN970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M2V]N=&%K="!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+B`E<R(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$R,`HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#@R"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@9F5H;&=E
M<V-H;&%G96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+;VYT;W-T86YD(&MO
M;FYT92!N:6-H="#\8F5R<'+\9G0@=V5R9&5N+B`E<R(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")697)B:6YD=6YG('IU;2!,1$%0+5-E
M<G9E<B!F96AL9V5S8VAL86=E;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(D944"U6
M97)B:6YD=6YG('IU;2!397)V97(@7"(E<UPB(&MO;FYT92!N:6-H="!H97)G
M97-T96QL="!W97)D96XZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E(&YI8VAT(&5R<W1E;&QT('=E<F1E
M;BX@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3,W
M"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@
M(E!'4"U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@
M(E,O34E-12U$871E;B!K;VYN=&5N(&YI8VAT(&5N='-C:&S\<W-E;'0@=V5R
M9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V]N=&%K="!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(E9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D
M96XN("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E
M('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N9W-S
M:W)I<'0@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.38R"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B1&EE($4M36%I;"U!9')E<W-E(&1E<R!%;7!FY&YG97)S(&MO;FYT
M92!N:6-H="!E<FUI='1E;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")$87,@
M061R97-S8G5C:"!K;VYN=&4@;FEC:'0@:V]M<&QE='0@9V5L97-E;B!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B5F5R=&5I;&5R;&ES=&4@:V]N;G1E
M(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+B(*;7-G<W1R("),:7-T92!D97(@5F5R=&5I;&5R;&ES=&5N(&MO
M;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B1&EE(%-T
M<F%T96=I92!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S
M7"(N(@IM<V=S='(@(D1A<R!697)Z96EC:&YI<R!<(B5S7"(@:V]N;G1E(&YI
M8VAT(&%N9V5L96=T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(M9F9F5N=&QI8VAE
M<B!38VAL_'-S96P@:V]N;G1E(&YI8VAT('9O;2!38VAL_'-S96QS97)V97(@
M9V5H;VQT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B7"(E<UPB(&MO;FYT92!N:6-H="!Z=6T@4V-H<F5I
M8F5N(&=E]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(B5S(&MO;FYT92!N:6-H
M="!G96QE<V5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M(")$87,@36%I;G1E;F%N8V5?5&%S:R!-;V1U;"`E<R!K;VYN=&4@;FEC:'0@
M9V7V9F9N970@=V5R9&5N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S
M7"(N(@IM<V=S='(@(E9E<GIE:6-H;FES(%PB)7-<(B!K;VYN=&4@;FEC:'0@
M9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I
M9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B
M5F5R8FEN9'5N9R!Z=6T@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&AE<F=E
M<W1E;&QT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N
M<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E
M<RXB"FUS9W-T<B`B)7,@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@V"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M1&%S(%!A<W-W;W)T(&;\<B!D96X@86YG96=E8F5N96X@0F5N=71Z97(@:V]N
M;G1E(&YI8VAT('IU<OQC:V=E<V5T>G0@=V5R9&5N+"`B"B)W96EL(&5I;FEG
M92!!;F=A8F5N(&YI8VAT(')I8VAT:6<@=V%R96XN(%9E<G-U8VAE;B!3:64@
M97,@97)N975T(&]D97(@=V5N9&5N("(*(E-I92!S:6-H(&%N($EH<F5N($%D
M;6EN:7-T<F%T;W(L('=E;FX@4VEE('=E:71E<F4@2&EL9F4@8F5N]G1I9V5N
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P
M-0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#8*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0Q-`HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C`*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M04-,(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S(@IM<V=S='(@(D1A<R!!9')E<W-B=6-H(&MO;FYT92!N:6-H="!G96QE
M<V5N('=E<F1E;BX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(E9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E
M;BX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")697)T96EL
M97)L:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N+B`E<R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(X"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM
M<V=S='(@(D1I92!397)V97)FY&AI9VME:71E;B!K;VYN=&5N(&YI8VAT(&%U
M<V=E;&5S96X@=V5R9&5N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")+;VYF:6=U<F%T:6]N(&MO;FYT92!N:6-H="!Z=7+\8VMG97-E='IT
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B5F5R
M>F5I8VAN:7,@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B)7,M2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE
M<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")"86-K=7`@9&5R($MO
M;F9I9W5R871I;VX@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E
M<R(*;7-G<W1R(")"86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N;G1E(&YI
M8VAT(&=E<W!E:6-H97)T('=E<F1E;CH@)7,B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M(")$87,@06MT=6%L:7-I97)U;F=S<VMR:7!T(&MO;FYT92!N:6-H="!N86-H
M(%PB)7-<(B!G97-P96EC:&5R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T
M<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N("5S(&MO;FYT92!N:6-H="!G
M97-P96EC:&5R="!W97)D96XN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*
M;7-G<W1R("(B"B)$:64@2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@
M9V5S<&5I8VAE<G0@=V5R9&5N+B!3:64@:_9N;F5N(&5N='=E9&5R("(*(F5I
M;F4@9&5R($WV9VQI8VAK96ET96X@=6YT97(@)7,@=F5R=V5N9&5N+"!U;2!D
M96X@0V]D92!Z=2!S<&5I8VAE<FXL(&]D97(@(@HB9&5N('5N=&5N<W1E:&5N
M9&5N($-O9&4@;6%N=65L;"!N86-H("5S(&MO<&EE<F5N+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1&5R($Q$05`M4V5R
M=F5R(&MO;FYT92!N:6-H="!D=7)C:'-U8VAT('=E<F1E;BXB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B1&5R($MO;G1A
M:W0@:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX@)7,B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")697)T96EL97)L:7-T92!K;VYN=&4@
M;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;BX@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M1&EE($MO;F9I9W5R871I;VX@9OQR(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-C,*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A
M<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*
M(D1I92!-;WII;&QA(%-I9&5B87(@:V]N;G1E(&YI8VAT(&=E9G5N9&5N('=E
M<F1E;BX@4W1E;&QE;B!3:64@<VEC:&5R+"!D87-S("(*(F1I92!3:61E8F%R
M(&=E]F9F;F5T(&ES="XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N
M)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@
M=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*(D1E;2!"96YU='IE
M<B!<(B5S7"(@:V]N;G1E;B!D:64@9F]L9V5N9&4@4F5C:'1E(&;\<B!D96X@
M3W)D;F5R(%PB)7-<(B!N:6-H="`B"B)Z=6=E=VEE<V5N('=E<F1E;CH@)7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N
M=&5D('1E>'0B"FUS9W-T<B`B1V5ZY&AL=&5R(%1E>'0B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R("),86YD(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W
M-0IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")+=7)S92(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM
M<V=I9"`B0W)E871E(@IM<V=S='(@(D5R<W1E;&QE;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("),:6YK(&5R<W1E;&QE;B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.38*;7-G:60@
M(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B3F5U92!)9&5N=&ETY'0@86YL
M96=E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B56YT97)O<F1N
M97(@97)S=&5L;&5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B17)S
M=&5L;&5R<F5C:'1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S
M,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I=&MA
M<G1E;FYU;6UE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S
M='(@(DMR;V%T:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R
M(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(D%K='5E;&QE(#0@4&AA<V5N(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS
M(@IM<V=S='(@(D%K='5E;&QE(%-E<W-I;VYS(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT
M(%1I;64B"FUS9W-T<B`B06MT=65L;&4@6F5I="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B
M0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B06MT=65L;&4@55),(&ES="(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*
M;7-G<W1R(")!:W1U96QL92!"96YU='IE<B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R(")!:W1U
M96QL97,@5V5T=&5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V-`IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")$97)Z
M96ET:6=E($)E9&EN9W5N9V5N.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM
M<V=S='(@(D%K='5E;&QE<B!3=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@
M=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*(DQE9V5N(%-I
M92!F97-T+"!W96QC:&4@075F9V%B96X@;F%C:"!D97(@06YM96QD=6YG(&)E
M:2`E<R!E<FQE9&EG="!W97)D96X@(@HB<V]L;&5N+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I
M9"`B0W5T(@IM<V=S='(@(D%U<W-C:&YE:61E;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE
M8W1I;VXB"FUS9W-T<B`B075S=V%H;"!A=7-S8VAN96ED96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T<B`B6GEP97)N(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM
M<V=S='(@(DMY<FEL;&ES8V@@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS
M9W-T<B`B2WER:6QL:7-C:"`H5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52DB"FUS9W-T<B`B2WER:6QL:7-C:"]5:W)A:6YI<V-H("A+3TDX+54I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B
M5'-C:&5C:&ES8VAE(%)E<'5B;&EK(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B1$0B"FUS9W-T<B`B5%0B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,CDP"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S
M;BYP:'`I(@IM<V=S='(@(B(*(D133B`H<VEE:&4@:'1T<#HO+W!E87(N<&AP
M+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN
M<&AP*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(E3D9VQI8V@B"@HC.B!A9&UI
M;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS
M9W-T<B`B1&%T851R964@0G)O=W-E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#@*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R(")$
M871E;F)A;FMA8F9R86=E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V
M"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B
M"FUS9W-T<B`B16UP9F%N9W-D871U;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(D1A
M='5M<V%U<W=A:&PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A
M>2(*;7-G<W1R(")486<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN
M(@IM<V=S='(@(E-P86QT92!?;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G
M<W1R(")$97IE;6)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R
M<R(*;7-G<W1R("):86AL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B16EN>G5G('9E<G)I;F=E<FXB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F
M875L="(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(E-T86YD87)D9F%R8F4B"@HC.B!F<F%M97=O<FLO4')E9G,O
M261E;G1I='DN<&AP.CDX"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S
M='(@(E-T86YD87)D:61E;G1I=.1T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<U"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-T86YD87)D
M<VAE;&PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E
M9FEN:71I;VYS(@IM<V=S='(@(D1E9FEN:71I;VYE;B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C<*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<Q"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.30@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-#`@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#,*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*
M;7-G<W1R("),]G-C:&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*
M;7-G<W1R("):96QL92!L]G-C:&5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,#4@861M:6XO9W)O=7!S+G!H<#HR,S,*;7-G:60@(D1E;&5T92!'<F]U<"(*
M;7-G<W1R(")'<G5P<&4@;/9S8VAE;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U,0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("),;V<@
M;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T
M92!097)M:7-S:6]N(@IM<V=S='(@(E)E8VAT92!L]G-C:&5N(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B3F%C:')I8VAT96X@
M;/9S8VAE;B!U;F0@96YT9F5R;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E
M;&PB"FUS9W-T<B`B6F5L;&4@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T
M92!C;VQU;6XB"FUS9W-T<B`B4W!A;'1E(&SV<V-H96XB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T92(*;7-G<W1R(")"97-T96AE;F1E(&%L=&5R;F%T:79E
M(%9O<FQA9V4@;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T
M<B`B3F%C:')I8VAT96X@;/9S8VAE;B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)E8VAT92!F_'(@7"(E
M<UPB(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B
M4F5C:'1E(&;\<B!<(B5S7"(@=6YD(&%L;&4@56YT97)R96-H=&4@;/9S8VAE
M;C\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(EIE:6QE(&SV
M<V-H96XB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC
M.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M075S9V5WY&AL=&4@261E;G1I=.1T(&SV<V-H96XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U
M8B!F;VQD97)S(@IM<V=S='(@(E5N=&5R;W)D;F5R(&SV<V-H96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B
M1&EE(&%K='5E;&QE(%-P86QT92!L]G-C:&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(D1I92!A:W1U96QL92!:
M96EL92!L]G-C:&5N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N9W-S:W)I
M<'0@7"(E<UPB('=U<F1E(&=E;/9S8VAT+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G
M:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B075S;&EE9F5R=6YG<WIE:70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(D3D;F5M87)K
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D)E<V-H<F5I8F5N(%-I
M92!D87,@4')O8FQE;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS
M."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-C:')E:6)U;F<B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A
M:6QS("AA=6-H(&EN($AO<F1E<R!,;V=D871E:2DZ(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%I
M;',@=W5R9&5N(&;\<B!D96X@061M:6YI<W1R871O<B!M:71G96QO9V=T+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L
M;W!M96YT(@IM<V=S='(@(D5N='=I8VML=6YG(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,3D*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")4875P=6YK
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(E1A=7!U;FMT(&1E<B!L971Z
M=&5N(%-T=6YD93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B5&%U<'5N:W0Z("(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*
M;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(E9O;B!L
M:6YK<R!N86-H(')E8VAT<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L
M969T(@IM<V=S='(@(E9O;B!R96-H=',@;F%C:"!L:6YK<R(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B
M5F5R>F5I8VAN:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C8R"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(EIE:70@:6T@
M,C0M4W1U;F1E;BU&;W)M870@86YZ96EG96X_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D%N>F5I9V4M16EN<W1E;&QU;F=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M="(*;7-G<W1R(")$971A:6QI97)T92!6;W)H97)S86=E(&%N>F5I9V5N(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*2(*;7-G<W1R(")6;W)H97)S86=E("A4048I(&%N>F5I9V5N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES
M<&QA>2!F;W)M870B"FUS9W-T<B`B06YZ96EG969O<FUA="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N
M($YO=&EF:6-A=&EO;B(*;7-G<W1R(")%;7!F86YG<V)E<W3D=&EG=6YG(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1'-C:&EB=71I
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@
M(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3FEC:'0@;/9S8VAE;B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B1W)E:69E;B!3
M:64@;FEC:'0@9&ER96MT(&%U9B!M86EN=&5N86YC92YP:'`@>G4B"@HC.B!T
M96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*
M;7-G<W1R("(B"B)%;G1HY&QT(&1I92!E<G-T92!:96EL92!D:64@1F5L9&YA
M;65N/R!796YN(&IA+"!D:65S97,@075S=V%H;&OD<W1C:&5N("(*(FUA<FMI
M97)E;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R(")$
M;VUI;FEC82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI
M8R(*;7-G<W1R(")$;VUI;FEK86YI<V-H92!297!U8FQI:R(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B3F]C:"!K96EN96X@6G5G86YG
M/R!(:65R(&%N;65L9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@U,PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B2&5R=6YT
M97)L861E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@U,PHC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R
M("(E<R!(97)U;G1E<FQA9&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$V,0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="XB"FUS9W-T<B`B17)Z975G=&4@2V]N9FEG=7)A=&EO
M;B!A;',@4$A0+5-K<FEP="!H97)U;G1E<FQA9&5N+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,C4*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM
M<V=S='(@(D%U<W=A:&QL:7-T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B1')O9V5N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS
M9W-T<B`B12U-86EL(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"B)%+4UA:6PM;F%C:"U335,M9V%T97=A>2!F_'(@4')O
M=FED97(L(&1I92!E:6YE;B!S;VQC:&5N($1I96YS="!U;G1E<G-T_'1Z96XN
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(D9%2$Q%
M4B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16-U861O
M<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G
M<W1R(")"96%R8F5I=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")";&]C:R!B96%R
M8F5I=&5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#0*;7-G:60@(D5D:70@
M1W)O=7`B"FUS9W-T<B`B1W)U<'!E(&)E87)B96ET96XB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B
M4F5C:'1E(&)E87)B96ET96XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(E)E8VAT
M92!B96%R8F5I=&5N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")296-H=&4@9OQR("<E<R<@8F5A<F)E:71E;B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F
M;W(Z(@IM<V=S='(@(D5I;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(E)E8VAT92!F_'(@7"(E<UPB(&)E87)B96ET96XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E8VAT92!F_'(@)7,@
M8F5A<F)E:71E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(D)I;&1U;F<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%9WEP="(*;7-G<W1R("+$9WEP=&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT
M,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G
M:60@(D5M(@IM<V=S='(@(D5M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#@W"FUS9VED(")%;6%I;"(*;7-G<W1R(")%+4UA:6PB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B12U-
M86EL+4%D<F5S<V4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Q
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M1&EE($4M36%I;"U!9')E<W-E;B!M_'-S96X@9VQE:6-H('-E:6XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-PIM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B12U-86EL+4%D<F5S<V4@;6ET($)E
M<W3D=&EG=6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S
M='(@(D4M36%I;"UN86-H+5--4RU'871E=V%Y(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS
M(@IM<V=S='(@(E-M:6QE>7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(DQE97)E($YA8VAR:6-H="XB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R
M97-U;'0N(@IM<V=S='(@(DQE97)E<R!%<F=E8FYI<RXB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B4W5C:&)E9W)I9F9E(&SV<V-H96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30P"FUS9VED(")%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*
M;7-G<W1R(")%:6YF_&=E;B!V;VX@0FEL9&5R;B!A=7,@1F]T;V=A;&5R:65N
M(&EN(&1E;B!497AT(&5R;&%U8F5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,34*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_(@IM<V=S='(@(DMO;G1E>'1M96[\(&)E:2!296-H='-K;&EC:R!A:W1I
M=FEE<F5N/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS
M9W-T<B`B16YD:F%H<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@
M(D5D:71O<B!V97)G<O;?97)N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Q-@IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC
M:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R
M("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@
M<&5T/R<Z(@IM<V=S='(@(B(*(D=E8F5N(%-I92!E:6YE(%-I8VAE<FAE:71S
M9G)A9V4@96EN+"!D:64@26AN96X@9V5S=&5L;'0@=VER9"P@=V5N;B!3:64@
M26AR("(*(E!A<W-W;W)T('IU<OQC:W-E='IE;B!M]F-H=&5N+"!Z+B!"+B!<
M(E=I92!L875T970@9&5R($YA;64@26AR97,@2&%U<W1I97)S/R(*(EPB.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM
M<V=S='(@(DAI97(@9&EE($)I;&0M55),(&%N9V5B96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"FUS9VED(")%;G1E
M<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B1V5B96X@<VEE(&1I92!"
M=6-H<W1A8F5N('5N=&5N(&5I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")%<75A
M=&]R:6%L($=U:6YE82(*;7-G<W1R("+$<75A=&]R:6%L+4=U:6YE82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B17)I=')E82(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]6:65W+G!H<#HY,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R;W(B"FUS9W-T
M<B`B1F5H;&5R(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H
M<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO
M8VLZ("5S(@IM<V=S='(@(D9E:&QE<B!B96EM($5R<W1E;&QE;B!E:6YE<R!"
M;&]C:W,Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H
M;W(Z("5S(@IM<V=S='(@(D9E:&QE<B!B96EM($SV<V-H96X@9&5S(%-Y;F-H
M<F]N:7-A=&EO;G-A;FME<G,Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I
M;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(D9E:&QE<B!B96EM($SV<V-H96X@
M9&5S(%-Y;F-H<F]N:7-A=&EO;G-L;V=S.B`E<R(*"B,Z(&9R86UE=V]R:R]4
M96UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B1F5H;&5R(&)E
M:6T@17)Z975G96X@9&5S($EN:&%L=',Z("5S(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")&96AL97(@8F5I;2#$
M;F1E<FX@9&5S(%!A<W-W;W)T<SH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B1F5H;&5R(&EN(&1E<B!%+4UA
M:6PM3F%C:')I8VAT+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@
M(D9E:&QE<B!B96EM(%-C:')E:6)E;B!V;VX@7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T;&%N9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(L1T:&EO<&EE;B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@
M(D5T;FES8VAE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S8*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS
M9W-T<B`B06QL92`Q-2!-:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X-@IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(D%L;&4@
M,B!-:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,R!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@T"FUS9VED(")%=F5R>2`S,"!S96-O;F1S
M(@IM<V=S='(@(D%L;&4@,S`@4V5K=6YD96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@
M(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")!;&QE(#4@36EN=71E;B(*"B,Z
M(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G
M:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D)E:2!J961E<B!!;FUE;&1U;F<B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B06QL92!H86QB92!3='5N9&4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#4*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")!;&QE(#8P(%-E:W5N
M9&5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@
M(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")"96ES<&EE;'=E<G1E.B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@
M861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B17AE8W5T92(*;7-G<W1R
M(")!=7-F_&AR96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(E9E<F=R
M]M]E<FXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X
M"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B)RDG(&5R=V%R=&5T(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G
M<W1R(")%:6YZ96QN97,@5V]R="!O9&5R(%-U8VAB96=R:69F(&EN($%N9OQH
M<G5N9W-Z96EC:&5N(&5R=V%R=&5T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T
M<B`B5F5R9F%L;'-D871U;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R(")%>'!O;F5N
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(E9O<F1E<F=R=6YD
M9F%R8F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<V"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(DAO8VAL861E;B!D97(@2V]N
M9FEG=7)A=&EO;B!P97(@1E10(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-Q;"YP:'`Z,C(U"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E
M;F-E<RXB"FUS9W-T<B`B0F5N=71Z97)E:6YS=&5L;'5N9V5N(&MO;FYT96X@
M;FEC:'0@9V5L861E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R(")697)B:6YD=6YG('IU;2!,1$%0(%-E<G9E<B!G97-C:&5I=&5R
M="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(E9E
M<F)I;F1U;F<@>G5M(%--0BU397)V97(@9V5S8VAE:71E<G0N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D5S(&MO
M;FYT92!K96EN92!+;W!I92!V;VX@7"(E<UPB(&5R<W1E;&QT('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@
M(D5S(&MO;FYT92!N:6-H="!N86-H(%PB)7-<(B!K;W!I97)T('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(D%U9F)A=2!E:6YE;B!N975E;B!305-,+59E<F)I;F1U;F<@:7-T(&9E:&QG
M97-C:&QA9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3(S
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B17,@
M:V]N;G1E(&YI8VAT(&YA8V@@7"(E<UPB('9E<G-C:&]B96X@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#@S"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B1F5H
M;&5R(&)E:6T@3&5S96XZ("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9A:7(B"FUS9W-T<B`B2&5I=&5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(D9A;&ML86YD:6YS96QN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")&87+V97(B"@HC.B!F<F%M97=O
M<FLO0TQ)+T-,22YP:'`Z,C0P"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T
M<B`B4V-H=V5R97(@1F5H;&5R.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE
M<R(*;7-G<W1R(")&87AE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U
M87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,@IM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R(")'96;\:&QT92!496UP97)A='5R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@
M(@IM<V=S='(@(D=E9OQH;'1E(%1E;7!E<F%T=7(Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VAO
M=V5R<R(*;7-G<W1R(")697)E:6YZ96QT92!38VAA=65R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9E=R!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B5F5R96EN>F5L=&4@4V-H;F5E<V-H875E
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C(*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R(")&96QD;6%T<FEX(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,T,PIM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS
M9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S0W"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L970M
M1F]N="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED<V-H
M:2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I9"`B
M1FEL92(*;7-G<W1R(")$871E:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I
M;&4B"FUS9W-T<B`B06YZ86AL.B`E<R!$871E:2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%N>F%H;#H@)7,@1&%T96EE;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N
M86=E<B(*;7-G<W1R(")$871E:6UA;F%G97(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D1A=&5I
M;F%M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@
M(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(D1A=&5I875S=V%H;"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D
M(@IM<V=S='(@(D1A=&5I+4AO8VAL861E;B(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.CDP,`IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N(@IM<V=S='(@(D1A<R!(;V-H;&%D96X@=F]N($1A=&5I96X@
M=VER9"!N:6-H="!U;G1E<G-T_'1Z="XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YN;&%N9"(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B
M"FUS9W-T<B`B17)S=&4@2.1L9G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E
M<B(*;7-G<W1R(")%<G-T97,@5FEE<G1E;"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*
M;7-G<W1R(")697)HY&QT;FES('IU<OQC:W-E='IE;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B
M"FUS9W-T<B`B56UD<F5H96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M(")497AT9FQUWR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(R"FUS9VED(")&;V<B"FUS9W-T<B`B3F5B96PB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(X,"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,3`V"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES="(*;7-G<W1R(")$87,@5F5R>F5I8VAN:7,@)7,@97AI
M<W1I97)T(&YI8VAT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")38VAR
M:69T9F%R8F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@
M(D9O;V0B"FUS9W-T<B`B17-S96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B
M<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(D;\
M<B!"<F]W<V5R+"!D:64@:V5I;F4@0FEL9&5R('5N=&5R<W3\='IE;B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S,V"FUS9VED(")&;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")6;W)H97)S86=E("A4048I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E
M<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(E9O<FAE<F=E<V%G
M=&4@5&%G92`H5F]R:&5R<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD($[D8VAT
M92P@96EN(&AO:&5R(%=E<G0@(@HB:V%N;B!Z=2!E:6YE;2!S96AR(&=R;]]E
M;B!";&]C:R!F_&AR96XI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R(")0
M87-S=V]R="!V97)G97-S96X_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0V-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L87)E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S
M='(@(D=L_&-K<VME:W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*
M;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")';/QC:W-K96MS='EP(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*
M;7-G<W1R(")';/QC:W-K96MS92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")';/QC:W-K96MS92`R
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(D9O<F5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5V5I=&5R;&5I='5N
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C`*;7-G:60@(D9R(@IM<V=S='(@(D9R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S
M(@IM<V=S='(@(E)A:&UE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*
M;7-G<W1R(")&<F%N:W)E:6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R
M(")%=7)O<.1I<V-H97,@1G)A;FMR96EC:"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")&<F5E>FEN9R!$<FEZ
M>FQE(@IM<V=S='(@(D=E9G)I97)E;F1E<B!296=E;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;GKV<VES8V@M1W5A
M>6%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM
M<V=S='(@(D9R86YZ]G-I<V-H+5!O;'EN97-I96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R(")&
M<F%N>O9S:7-C:&4@1V5B:65T92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z
M96%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")6;VXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM
M<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(D%U<R`B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO
M;B(*;7-G<W1R(")6;VQL<W3D;F1I9V4@0F5S8VAR96EB=6YG(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G
M:60@(D9U;&P@36]O;B(*;7-G<W1R(")6;VQL;6]N9"(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV-2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B5F]L;'-TY&YD:6=E
M<B!.86UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B
M=6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F
M<F]M(@IM<V=S='(@(D)I;&1E<B!A=7,@9&EE<V5R($=A;&5R:64B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&5R:64Z(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(E<RU+;VYF:6=U
M<F%T:6]N(&5R>F5U9V5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D5R
M>F5U9W1E<B!#;V1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G
M<W1R(")'96]R9VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`B1&5U='-C:&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*
M;7-G<W1R(")':&%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*
M;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")6;W)N
M86UE(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W.2!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,`HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ.0IM<V=I9"`B1VQO8F%L($]P=&EO;G,B"FUS9W-T<B`B06QL9V5M
M96EN92!%:6YS=&5L;'5N9V5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3<*;7-G:60@(D=O(@IM<V=S='(@(DQO<R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E;"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3,Q
M"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@36%P<R(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B1V]O9VQE(%-U8VAE(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(D=R875S='5F96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E
M(@IM<V=S='(@(D=R:65C:&5N;&%N9"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@X"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B1W)I
M96-H:7-C:"`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`B1W+V;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$X-0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U
M<'!E;G9E<G=A;'1U;F<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP
M.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@
M(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7!P
M96YN86UE;B!D_')F96X@;FEC:'0@;&5E<B!S96EN(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB1W)O=7!?;&1A
M<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R
M9&5N+B!-96QD=6YG(&1E<R`B"B)397)V97)S.B`B"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($1I
M92!'<G5P<&4@)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S
M='(@(D=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N;G1E(&YI8VAT(&%K
M='5A;&ES:65R="!W97)D96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(T,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-`HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.`IM
M<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G
M<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#D*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D=A<W1R96-H=&4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B1^1S=&5B=6-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM
M<V=S='(@(D=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I
M<W-A=2(*;7-G<W1R(")'=6EN96$M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T
M92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B1&5R($5D:71O<B!K
M86YN(&1I92!L971Z=&4@6F5L;&4@96EN97(@6F5I;&4@;FEC:'0@;/9S8VAE
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(D1E
M<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%-P86QT92!E:6YE<B!486)E;&QE
M(&YI8VAT(&SV<V-H96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*
M;7-G<W1R(")$97(@161I=&]R(&MA;FX@9&EE(&QE='IT92!:96EL92!E:6YE
M<B!486)E;&QE(&YI8VAT(&SV<V-H96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10+4%U=&AE;G1I9FEZ:65R=6YG(&YI
M8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS
M9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M06QG
M;W)I=&AM=7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-`IM<V=I9"`B2&%Z92(*;7-G<W1R(")$:65S:6<B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(MQB97)S8VAR:69T(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM
M<V=I9"`B2&5A9&5R<R(*;7-G<W1R(")+;W!F96EN='+D9V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD
M<R(*;7-G<W1R(")(96%R9"T@=6YD($UC1&]N86QD:6YS96QN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DAE
M879Y(%0M4W1O<FTB"FUS9W-T<B`B4V-H=V5R92!'97=I='1E<B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y
M+3@M22DB"FUS9W-T<B`B2&5B<N1I<V-H("A)4T\M.#@U.2TX+4DI(@H*(SH@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S
M='(@(DCV:&4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-2!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM
M<V=I9"`B2&5L<"(*;7-G<W1R(")(:6QF92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@
M961I=&]R(@IM<V=S='(@(D5D:71O<FAI;&9E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(DAI;&9E
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E
M(@IM<V=S='(@(DAE;6ES<&AE<F4B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I
M;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I
M9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R
M(")$:65S(&ES="!D97(@0F5G:6YN(&1E<B!$871E:3HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B2&EG:"(*
M;7-G<W1R(")(;V-H(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV
M('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(
M;U]M92(*;7-G<W1R(")?4W1A<G1S96ET92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G
M:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(E9A
M=&EK86YS=&%D="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S
M<V4@<')I=F%T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED
M(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")(96EM=F5R>F5I8VAN:7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS
M9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@<')I=F%T(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@
M2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,+41A=&5N
M(&EN($YA8VAR:6-H="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,CDV"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@17,@<&%S<W0@:V5I;F4@3F%C:')I8VAT('IU;2!/8FIE:W0@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M2V5I;B!/8FIE:W0@=F]M(%1Y<"`E<R!I;B!.86-H<FEC:'0@)7,@9V5F=6YD
M96XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@7"(E<UPB
M('=U<F1E(&5R9F]L9W)E:6-H(&5N=&9E<FYT(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!$:64@26YT96=R871I
M;VYS9G5N:W1I;VYE;B!B96[V=&EG96X@9&EE(%PB9&]M>&UL7"(@4$A0+2(*
M(D5R=V5I=&5R=6YG(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU
M,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B
M(@HB2&]R9&4O2V]L86(Z($;\<B!D87,@3V)J96MT("5S(&MO;FYT92!K96EN
M(&YE=65R(%A-3"U"875M(&5R>F5U9W0@=V5R9&5N(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86(Z("5S(%PB)7-<(B!K;VYN=&4@;FEC:'0@96YT
M9F5R;G0@=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z-3`Y"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<R(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@1&EE($U)344M240@9&5S($%B
M<V-H;FET=',@=F]M(%1Y<"`E<R!K;VYN=&4@;FEC:'0@(@HB:&5R875S9V5F
M=6YD96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z("5S(%PB)7-<(B!K;VYN=&4@;FEC:'0@<WEN8VAR;VYI<VEE<G0@
M=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@HB2&]R9&4O2V]L
M86(Z($1I92!G96UE:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC:'0@<WEN
M8VAR;VYI<VEE<G0@=V5R9&5N.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,S8V"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M56YB96MA;FYT97,@9V5M96EN<V%M97,@3V)J96MT(%PB)7-<(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@
M(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")(;W)I>F]N=&%L92!,:6YI92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I>F]N=&%L
M97(@26YN96YA8G-T86YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO;G1A;#HB"FUS9W-T<B`B
M2&]R:7IO;G1A;#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(E=I92!S:6YD(%-I92!H
M:65R:&5R9V5L86YG=#\@0FET=&4@86X@9&EE($5N='=I8VML97(@>G5R_&-K
M;65L9&5N(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")7:64@=FEE;&4@4W!A;'1E
M;B!S;VQL96X@>G5S86UM96YG96;\9W0@=V5R9&5N/R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B5VEE=FEE;&4@1F5L9&5R
M("A3<&%L=&5N*2!G:6)T(&5S/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O
M=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E=I92!V:65L
M92!:96EL96X@<V]L;&5N('IU<V%M;65N9V5F_&=T('=E<F1E;C\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C,R"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("),=69T9F5U8VAT
M:6=K96ET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T.`IM
M<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("),=69T9F5U8VAT:6=K96ET.B`B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T
M<R(*;7-G<W1R(")+;VUI:V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG
M87)Y(@IM<V=S='(@(E5N9V%R;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO
M;B!F86EL960Z("5S(@IM<V=S='(@(D%N;&5G96X@9&5S($E-05`M4&]S=&9A
M8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("),]G-C:&5N(&1E<R!)34%0
M+5!O<W1F86-H<R!I<W0@9F5H;&=E<V-H;&%G96XZ("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B1F5S
M=&QE9V5N(&1E<B!)34%0+5!O<W1F86-H+5%U;W1A(&ES="!F96AL9V5S8VAL
M86=E;CH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS
M9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0+4%D<F5S<V4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R
M97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0+4%D<F5S<V4@;FEC:'0@
M=F5R9OQG8F%R+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP
M:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(DE0+4%D<F5S<V4@;FEC:'0@:6T@97)L875B
M=&5N($-)1%(M0FQO8VLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(E9E<FQE='IU;F<@9&5R(&9E<W1G96QE9W1E;B!)
M4"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R
M("):96EL92!E:6YF_&=E;B!?=F]R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))
M8V5L86YD(@IM<V=S='(@(DES;&%N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S,*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B3G5R($)I;&1E
M<B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26-O;G,@9OQR("5S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-`IM<V=I9"`B26-O;G,@=VET
M:"!T97AT(@IM<V=S='(@(D)I;&1E<B!U;F0@5&5X="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.#4*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS
M9W-T<B`B0F5Z96EC:&YU;F<@9&5R($ED96YT:73D="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*(E=E;FX@<VEE
M(&YI8VAT(&MO<G)E:W0@86YG97IE:6=T('=I<F0L("5S+"!U;2!S:64@:6X@
M96EN96T@;F5U96X@1F5N<W1E<B`B"B)A;F=E>F5I9W0@>G4@8F5K;VUM96XN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U,@IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)796YN(%-I92!M
M:70@9&5M($EN=&5R;F5T($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL
M(&W\<W-E;B!3:64@9&EE<V5S("(*(DOD<W1C:&5N(&UA<FMI97)E;BP@=6T@
M4$Y'+51R86YP87)E;GH@875S>G5S=&5L;&5N+B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"B)796YN(%-I92!D:65S92!.86-H<FEC
M:'0@86X@4W1E;&QE(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W
M<V5R(&1A<R`B"B)":6QD+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI
M8VAT(&%N>F5I9V5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE
M=SHB"FUS9W-T<B`B0FEL9'9O<G-C:&%U.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E
M(%523"(*;7-G<W1R(")":6QD+5523"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R(")":6QD+5523#HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")":6QD('9O;B!'86QE<FEE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S
M='(@(D)I;&0@=F]N($=A;&5R:64Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D)I;&0M
M2&]C:&QA9&5N(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@
M(DEM86=E<R(*;7-G<W1R(")":6QD97(B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E
M<"`E9"(*;7-G<W1R("));7!O<G1I97)E;BP@4V-H<FET="`E9"(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1I97)T97,@
M1F5L9#H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS
M9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(DEM<&]R=&EE<G1E($9E
M;&1E<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S
M='(@(EIE:6QE(&5I;F;\9V5N(%]N86-H(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E5N9_QL=&EG92!!:W1I;VX@86YG
M96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(")5;F?\;'1I9V5R($)E;G5T>F5R;F%M92!U
M;F0O;V1E<B!087-S=V]R="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HU,PIM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"B)&86QS8VAE<B!"96YU='IE<FYA;64@;V1E<B!%+4UA:6PM061R97-S
M92X@5F5R<W5C:&5N(%-I92!E<R!E<FYE=70@;V1E<B`B"B)W96YD96X@4VEE
M('-I8V@@86X@26AR96X@4WES=&5M861M:6YI<W1R871O<BP@=V5N;B!3:64@
M=V5I=&5R92!(:6QF92`B"B)B96[V=&EG96XN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@
M26YD96YT(@IM<V=S='(@(D5I;GIU9R!V97)G<O;?97)N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1I96XB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-0IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")%
M:6YZ96QN92!"96YU='IE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE
M<VEA(@IM<V=S='(@(DEN9&]N97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@
M(DEN9F]R;6%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M871I;VYE;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN
M9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R
M;6%T:6]N96X@;FEC:'0@;65H<B!V97)F_&=B87(N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B26YH97)I=&5D($UE
M;6)E<G,B"FUS9W-T<B`B5F5R97)B=&4@36ET9VQI961E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM
M<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B7U-P86QT92!D
M879O<B!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(D)I;&0@:&EN>G5F_&=E;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L
M92(*;7-G<W1R(")486)E;&QE(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E
M8B!,:6YK(@IM<V=S='(@(DQI;FL@96EN9OQG96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")37W!A;'1E(&1A;F%C
M:"!E:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B16EN92!N975E(%-P
M86QT92!N86-H(&1E<B!A:W1U96QL96X@96EN9OQG96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")%:6YE(&YE=64@4W!A;'1E('9O<B!D97(@86MT=65L;&5N
M(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%:6YE(&YE=64@6F5I;&4@
M;F%C:"!D97(@86MT=65L;&5N(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B16EN92!N975E(%IE:6QE('9O<B!D97(@86MT=65L;&5N(&5I;F;\9V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R(")%:6YE;B!N975E;B!!8G-A='H@;F%C
M:"!D96T@86MT=65L;&5N($5L96UE;G0@96EN9OQG96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R(")%:6YE;B!N975E;B!!8G-A='H@=F]R(&1E;2!A:W1U96QL
M96X@16QE;65N="!E:6YF_&=E;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(D%L=&5R;F%T:79E(%9O<FQA9V4@96EN9OQG96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C,T"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S
M<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB
M"FUS9W-T<B`B(@HB1V5B96X@4VEE(&5I;F4@12U-86EL+4%D<F5S<V4@86XL
M(&%N(&1I92!D87,@;F5U92!087-S=V]R="!G97-C:&EC:W0@=V5R9&5N("(*
M(G-O;&PZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T
M<B`B6F5L;&4@9&%N86-H(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T
M(&-E;&P@8F5F;W)E(@IM<V=S='(@(EIE;&QE(&1A=F]R(&5I;F;\9V5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R(")3<&%L
M=&4@9&%N86-H(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M
M;B!B969O<F4B"FUS9W-T<B`B4W!A;'1E(&1A=F]R(&5I;F;\9V5N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN
M<V5R="!M97-S86=E<R(*;7-G<W1R(").86-H<FEC:'1E;B!H:6YZ=6;\9V5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S
M='(@(D%B<V%T>B!D86YA8V@@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN
M<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(D%B<V%T>B!D879O<B!E
M:6YF_&=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T
M<B`B6F5I;&4@9&%N86-H(&5I;F;\9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T
M(')O=R!B969O<F4B"FUS9W-T<B`B6F5I;&4@9&%V;W(@96EN9OQG96XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(U"FUS9VED("));G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM
M<V=S='(@(D=E8F5N(%-I92!D:64@06YT=V]R="!A=68@9&EE(%-I8VAE<FAE
M:71S9G)A9V4@96EN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS
M9W-T<B`B0FEL9"!E:6YF_&=E;B]B96%R8F5I=&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T
M+TUO9&EF>2!,:6YK(@IM<V=S='(@(DQI;FL@96EN9OQG96XO8F5A<F)E:71E
M;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("):=2!W96YI9R!'=71H
M86)E;BP@=6T@86X@9&EE(%9E<G1E:6QE<FQI<W1E('IU('9E<G-C:&EC:V5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("):
M=2!W96YI9R!'=71H86)E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(D=A;GIZ86AL(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L
M:7-T(@IM<V=S='(@(DQI<W1E('9O;B!'86YZ>F%H;&5N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED
M("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")5
M;F?\;'1I9V5R(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED
M(%I)4"!D871A(@IM<V=S='(@(E5N9_QL=&EG92!:25`M1&%T96XN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B56YG_&QT:6=E($%N=V5N9'5N9RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(E5N9_QL=&EG92!"
M871C:"U)1"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-S8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(U,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(E5N9_QL=&EG
M92!$871E;B!E:6YG96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN
M871I;VX@861D<F5S<RXB"FUS9W-T<B`B56YG_&QT:6=E(%II96QA9')E<W-E
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P
M.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(E5N9_QL=&EG97,@
M1&%T96EF;W)M870B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")5;F?\
M;'1I9V5R($QI>F5N>G-C:&S\<W-E;"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34Y"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(")5;F?\;'1I9V5R($]R="!A;F=E9V5B96XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W
M"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(")5;F?\;'1I9V5R
M(&US9U]T>7!E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P
M:5]I9"XB"FUS9W-T<B`B56YG_&QT:6=E(&]D97(@9F5H;&5N9&4@87!I7VED
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N
M(@IM<V=S='(@(E5N9_QL=&EG92!O9&5R(&9E:&QE;F1E(%!A<F%M971E<BXB
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G:60@(DEN=F%L
M:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E5N9_QL=&EG97,@W&)E
M<G)E8VAT+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*
M;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B56YG_&QT:6=E
M(%!A<G1N97(M240N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(E5N
M9_QL=&EG97(@4')O9'5K=&-O9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R
M;W1O8V]L+B(*;7-G<W1R(")5;F?\;'1I9V5S(%!R;W1O:V]L;"XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(E5N
M9_QL=&EG97(@16UP9N1N9V5R.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$Q,3<@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,CDW"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")5;F?\
M;'1I9V5S(&=E;65I;G-A;65S($]B:F5K="(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI
M9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B56YG_&QT:6=E(%5R<W!R=6YG
M<V%D<F5S<V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB
M"FUS9W-T<B`B56YG_&QT:6=E(%5N:6-O9&4M1&%T96XN(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S
M='(@(DEN=F5N=&%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R
M(")!=7-W86AL('5M:V5H<F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DES;&%M:7-C:&4@4F5P
M=6)L:6L@27)A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R
M("))<F%K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@
M(DER;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS
M9VED("))<VQE(&]F($UA;B(*;7-G<W1R("))<VQE(&]F($UA;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("))
M<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")697)E:6YZ96QT92!'97=I='1E
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E
M;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS
M9VED("))<W-U97(B"FUS9W-T<B`B075S<W1E;&QE<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC
M(@IM<V=S='(@(DMU<G-I=B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB
M"FUS9W-T<B`B271A;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC
M82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N
M=6%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S
M92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&%N:7-C:"`H25-/+3(P,C(M
M2E`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@
M(DIE<G-E>2(*;7-G<W1R(")*97)S97DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R(")*;W)D86YI96XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R
M(")*=6QI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@
M(DIU<W1I9GDB"FUS9W-T<B`B0FQO8VMS871Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU
M<W1I9GD@0V5N=&5R(@IM<V=S='(@(EIE;G1R:65R96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I
M9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(D)L;V-K<V%T>B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS
M9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B3&EN:W,@875S<FEC:'1E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(E)E8VAT<R!A
M=7-R:6-H=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM
M<V=S='(@(DMA<V%C:'-T86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G
M<W1R(")/<FEG:6YA;"!B96EB96AA;'1E;C\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DME;GEA(@IM<V=S='(@(DME;FEA(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<RU397)V97(@
M:&%T($%U=&AE;G1I9FEZ:65R=6YG('IU<OQC:V=E=VEE<V5N+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B
M"FUS9W-T<B`B2V5R;F5L+4YE=6QI;F=E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T
M<B`B4V-H;/QS<V5L97)Z975G=6YG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B1FEN9V5R86)D<G5C:R!D97,@4V-H;/QS<V5L<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*
M;7-G<W1R(")38VAL_'-S96QLY&YG92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B4V-H
M;/QS<V5L='EP(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")38VAL_'-S96QZ=V5C
M:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("(B"B)$97(@4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R
M96ET<R!A=68@9&5M(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS97)V97(N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(DMI;F1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS
M9W-T<B`B2VER:6)A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$
M96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(D1E;6]K
M<F%T:7-C:&4@5F]L:W-R97!U8FQI8R!+;W)E82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM
M<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E<'5B;&EK($MO
M<F5A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R(")+;W)E86YI<V-H("A%54,M2U(I(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I<VES
M=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),
M85]Y;W5T(@IM<V=S='(@(D%N7W!A<W-E;B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(E-P<F%C
M:&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A
M=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B3&5T>G1E($CD
M;&9T92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX.`IM<V=I9"`B3&%S
M="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B3&5T>G1E(%!A<W-W;W)TY&YD
M97)U;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B3&5T>G1E
M<R!6:65R=&5L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3,*;7-G:60@
M(DQA<W0@57!D871E9#HB"FUS9W-T<B`B3&5T>G1E($%K='5A;&ES:65R=6YG
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("),971Z=&4@06YM
M96QD=6YG.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM
M<V=S='(@(DQE='IT92!!;FUE;&1U;F<Z("5S('9O;B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V
M97(B"FUS9W-T<B`B3&5T>G1E($%N;65L9'5N9SH@3F]C:"!N:64B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971T;&%N9"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@
M(D=E<V5T>B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D9O<FUA="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*
M;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B3&5E
M<B!L87-S96X@9OQR(&ME:6YE;B!286AM96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G
M:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F
M="(*;7-G<W1R("),:6YK<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DQI;FME(-QB97)S
M8VAR:69T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`B3&EN:V4@5V5R=&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I9"`B3&5V96PB"FUS
M9W-T<B`B16)E;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS
M9W-T<B`B3&EB97)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R
M86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)Y96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS
M9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@(E-P<OQH<F5G96XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B
M3&EG:'0@4F%I;B(*;7-G<W1R("),96EC:'1E<B!296=E;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H
M="!286EN($5A<FQY(@IM<V=S='(@(D9R_&@@;&5I8VAT97(@4F5G96XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I
M9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E-PY'1E<B!,96EC:'1E<B!2
M96=E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Q"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R("),96EC:'1E
M(%)E9V5N<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("),96EC:'1E<B!296=E;B!M:70@1V5W:71T97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B3&EG
M:'0@4VYO=R(*;7-G<W1R("),96EC:'1E<B!38VAN965F86QL(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DQI
M9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(DQE:6-H=&4@4V-H;F5E<V-H875E
M<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I
M8VLB"FUS9W-T<B`B3&EM97)I8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$W"FUS9VED("),:6YK(%523"(*;7-G
M<W1R("),:6YK+5523"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,S(*;7-G:60@(DQI;FL@86-C97-S(&ME>2(*;7-G<W1R("),:6YK+5IU9W)I
M9F9S=&%S=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G
M<W1R("),:6YK('9E<G=E:7-T(&%U9CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#(S"FUS9VED("),:6YK('1A<F=E="(*;7-G<W1R("),:6YK
M+5II96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(P"FUS9VED
M("),:6YK('1E>'0B"FUS9W-T<B`B3&EN:RU497AT(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@Y,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D
M<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G
M<W1R(")%+4UA:6PM061R97-S92!V97)L:6YK96X_(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3@R.0IM<V=I9"`B3&EN:R!T:71L92!A='1R:6)U
M=&4B"FUS9W-T<B`B3&EN:RU4:71L92U!='1R:6)U="(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G:60@
M(DQI;FMS(@IM<V=S='(@(DQI;FMS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B3&EN=7@M1VS\
M8VMS:V5K<V4B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM
M<V=S='(@(DQI<W0@+2!"96YU='IE<B!K86YN(&1E;B!/<F1N97(@<V5H96XB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS9VED("),:7-T($1A=&%B
M87-E<R(*;7-G<W1R(")$871E;F)A;FME;B!A;GIE:6=E;B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED("),:7-T($AE;'`@5&]P:6-S
M(@IM<V=S='(@(DAI;&9E96EN='+D9V4@86YZ96EG96XB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R(")4
M86)E;&QE;B!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-C`Q"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES
M=&5N+4%R8VAI=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DV"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B3&ES=&5N+4AI;&9E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HV,#,*;7-G
M:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&5N+4ED(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3D*;7-G:60@(DQI<W0M3W=N97(B
M"FUS9W-T<B`B3&ES=&5N+4)E<VET>F5R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HV,#`*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R
M("),:7-T96XM061R97-S92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DX"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),
M:7-T96XM06YM96QD=6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU.3<*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B
M3&ES=&5N+4%B;65L9'5N9R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H
M;&=E<V-H;&%G96XZ("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*
M;7-G<W1R(")$87,@06YZ96EG96X@9&5R($)E;G5T>F5R(&ES="!F96AL9V5S
M8VAL86=E;CH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S
M='(@(D1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T(&YI8VAT(&WV9VQI
M8V@N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E
M<F%T=7)E(@IM<V=S='(@(DQI=&5R871U<B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI=&%U96XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D:6YG
M+BXN(@IM<V=S='(@(DQA9&4N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3&]K
M86QE(%5H<GIE:70Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-@IM
M<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(E-P<F%C:&4@=6YD(%IE
M:70B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3<*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(DQO
M8V%T:6]N(@IM<V=S='(@(D]R="(*"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-"!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R(")!;FUE;&1E;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T-PIM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G
M<W1R("),;V<@9&5R(&QE='IT96X@4WEN8VAR;VYI<V%T:6]N+B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.3@*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`B06)M96QD96XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C$*;7-G:60@(DQO9VEN(@IM<V=S='(@(D%N;65L9&5N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T
M<B`B06YM96QD96%U9F=A8F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G
M<W1R("(B"B)$:64@06YM96QD=6YG(&ES="!F96AL9V5S8VAL86=E;BP@=V5I
M;"!3:64@26AR96X@0F5N=71Z97)N86UE;B!O9&5R($EH<B`B"B)087-S=V]R
M="!F86QS8V@@96EN9V5G96)E;B!H86)E;BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B
M06YM96QD=6YG(&9E:&QG97-C:&QA9V5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C4*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R("),86YG
M97(@5&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B
M3&]V92(*;7-G<W1R("),:65B92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<Q"FUS9VED("),;W<B"FUS9W-T<B`B3FEE9')I
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T
M<B`B2VPN(&=R:65C:&ES8VAE($)U8VAS=&%B96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED
M("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(DML+B!L871E:6YI<V-H
M92!"=6-H<W1A8F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M
M8F5R<R(*;7-G<W1R(")+;"X@<O9M:7-C:&4@6F%H;&5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM
M<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&+4%N:&%N9R!E;G1H:65L="!K
M96EN92!$871E;BXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS
M9W-T<B`B2$E.5T5)4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS
M9W-T<B`B36%C86\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R(")$:64@
M96AE;6%L:6=E($IU9V]S;&%W:7-C:&4@4F5P=6)L:6L@36%Z961O;FEE;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R(")-861A
M9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED(")-
M86=I8R(*;7-G<W1R(")-86=I92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")796)M86EL(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*
M;7-G<W1R(")%+4UA:6P@061M:6YI<W1R871I;VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B3&EN:R!?86YL96=E;BXN+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L87ES:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&ED
M:79E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E
M('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E
M;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@
M8V%T96=O<FEE<RXB"FUS9W-T<B`B(@HB5F5R=V%L=&5N(%-I92!D:64@2V%T
M96=O<FEE;BP@;6ET(&1E;F5N(%-I92!%;&5M96YT92!U;F0@16EN='+D9V4@
M(@HB:V5N;GIE:6-H;F5N(&OV;FYE;BP@<V]W:64@9&EE('IU9V5H]G)I9V5N
M($9A<F)E;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T+4MA
M<G1E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="U+
M87)T92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I
M9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("):=6]R9&YU;F=E;B!G97-P
M96EC:&5R="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B3>1R>B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G
M:60@(DUA<F=I;B(*;7-G<W1R(")!==]E;F%B<W1A;F0B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H
M(%-E96XO56YS965N(&9L86=S(@IM<V=S='(@(DUI="!'96QE<V5N+2]5;F=E
M;&5S96XM4W1A='5S('9E<G-E:&5N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUI="!A;F1E
M<F5M(%-T871U<R!V97)S96AE;B`H>BY"+B!7:6-H=&EG+T)E86YW;W)T970I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S
M='(@(DUA<G-H86QL:6YS96QN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T
M:6YI<75E(@IM<V=S='(@(DUA<G1I;FEQ=64B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(EIU9V5O<F1N971E($9E;&1E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B
M36%U<FET86YI82(*;7-G<W1R(")-875R971A;FEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM
M<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-87AI;6%L(&5R
M;&%U8G1E<B!+<F5D:70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T
M<R!E>&-E961E9"XB"FUS9W-T<B`B36%X:6UA;&4@3F%C:'1I8VAT96YT96EL
M92#\8F5R<V-H<FET=&5N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X
M"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B2/9C
M:'-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`R-"!3='5N9&5N.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P,`IM<V=I9"`B36%X('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B2/9C:'-T=&5M<&5R871U<B!D97(@;&5T>G1E
M;B`V(%-T=6YD96XZ("(*"B,Z(&QI8B]A<&DN<&AP.C$X,0IM<V=I9"`B36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-87AI;6%L
M92!!;GIA:&P@86X@4&]R=&%L8FSV8VME;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@
M;&5N9W1H(@IM<V=S='(@(DUA>&EM86QE($SD;F=E(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R(")-86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S
M='(@(DUA>6]T=&4@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I>FEN(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R
M<R(*;7-G<W1R(")-:71G;&EE9&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-0IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R(")-96[\;6]D=7,Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B6F5L;&5N('IU
M<V%M;65N9OQG96XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-PIM<V=I9"`B365S<V%G92(*;7-G<W1R(").
M86-H<FEC:'0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@
M8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB
M=F5R:69I960N(@IM<V=S='(@(B(*(D1I92!.86-H<FEC:'0@:V]N;G1E(&5R
M9F]L9W)E:6-H(/QB97)P<OQF="!W97)D96X@86)E<B!N:6-H="!D87,@6F5R
M=&EF:6MA="`B"B)D97,@06)S96YD97)S+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G
M92!E>'!I<F5D+B(*;7-G<W1R(").86-H<FEC:'0@;FEC:'0@;65H<B!G_&QT
M:6<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S
M='(@(DYA8VAR:6-H=&5N='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(DUE=&%R(%=E='1E<B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R8FQO8VL@;FEC:'0@=F5R
M9OQG8F%R+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B
M"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-
M971A<F)L;V-K(&YI8VAT('9E<F;\9V)A<BX@1&5T86EL<R!W=7)D96X@9OQR
M(&1E;B!!9&UI;FES=')A=&]R(&UI=&=E;&]G9W0N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+B(*;7-G<W1R(")+96EN92!697)B:6YD=6YG('IU<B!-971A
M<D1"+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I
M9"`B365T:&]D(@IM<V=S='(@(DUE=&AO9&4B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO
M="!D969I;F5D(@IM<V=S='(@(D1I92!-971H;V1E(%PB)7-<(B!I<W0@;FEC
M:'0@9&5F:6YI97)T(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z
M.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#
M86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-971H;V1E(&YI8VAT(&1E9FEN
M:65R="X@075F9V5R=69E;F4@365T:&]D93H@)7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,@IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I<V-H(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-97AI8V\B"FUS9W-T<B`B365X:6MO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T
M<B`B1O9D97)I97)T92!3=&%A=&5N('9O;B!-:6MR;VYE<VEE;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM
M<V=I9"`B36ED9&QE(@IM<V=S='(@(DUI='1E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*
M;7-G<W1R(")-:6UE='EP(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3(*
M;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")4:65F
M<W1T96UP97)A='5R(&1E<B!L971Z=&5N(#(T(%-T=6YD96XZ("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R(")4:65F<W1T96UP97)A='5R(&1E<B!L971Z=&5N
M(#8@4W1U;F1E;CH@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T
M(&5X<&ER960B"FUS9W-T<B`B1&%S(&UI;FEM86QE(%!A<W-W;W)T86QT97(@
M:7-T(&YO8V@@;FEC:'0@86)G96QA=69E;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G
M<W1R(")3<&EE9V5L;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")697)S8VAI961E;F5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N
M(@IM<V=S='(@(E!%05(M4&%K970@2%144%]297%U97-T(&9E:&QT+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R
M("(B"B)&96AL96YD92!+;VYF:6=U<F%T:6]N+B!3:64@;?QS<V5N(&1I97-E
M(&IE='IT(&5R>F5U9V5N+"!W96YN(%-I92!D:64@(@HB06YW96YD=6YG('9E
M<G=E;F1E;B!M]F-H=&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R(")&96AL96YD92!.86-H<FEC:'1E;BU)1"XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU
M.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB
M"FUS9W-T<B`B4$5!4BU086ME="!-86EL(&9E:&QT+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B
M36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")&96AL96YD92!3:71Z=6YG
M<RU)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")-;R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B
M12U-86EL($UO8FEL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S(*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DWDWVEG(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D
M($1A=&4B"FUS9W-T<B`BQ&YD97)U;F=S9&%T=6TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@
M(DUO9&EF>2!54DPB"FUS9W-T<B`B55),(&)E87)B96ET96XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU
M<R(*;7-G<W1R(")-;V1U;'5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD
M;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")297!U8FQI:R!-;VQD874B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&5I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P,@IM<V=I9"`B36]N
M=&@@86YD('EE87(B"FUS9W-T<B`B36]N870@=6YD($IA:'(B"@HC.B!F<F%M
M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-
M;VYT:&QY(@IM<V=S='(@(DUO;F%T;&EC:"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R(")-;VYD<&AA<V5N(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N
M9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")-
M96AR($9E;&1E<B!I;B!:96EL92`E9"!A;',@9&EE(&5R=V%R=&5T96X@)60@
M9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S
M='(@(DUA<F]K:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(MQB97)W
M:65G96YD(&AE:71E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,V"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(MQB
M97)W:65G96YD($)E=_9L:W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN
M9'DB"FUS9W-T<B`BW&)E<G=I96=E;F0@0F5W]FQK="!U;F0@5VEN9&EG(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("+<8F5R=VEE9V5N9"!3;VYN:6<B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(DYA8V@@=6YT96XB"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(DYA8V@@;&EN:W,B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(").86-H(')E8VAT<R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T"FUS
M9VED(")-;W9E(%5P(@IM<V=S='(@(DYA8V@@;V)E;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R(").86-H('5N=&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S
M='(@(DYA8V@@;V)E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U
M92(*;7-G<W1R(")-;W-A;6)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R,#(*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*
M;7-G<W1R(")!=7-W86AL;&ES=&4@:6X@;65H<F5R96X@16)E;F5N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3D*;7-G
M:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"U52RU+87)T
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C`*;7-G:60@(DUU
M;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")-96AR9F%C:&%U<W=A:&PB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O
M=6YT(@IM<V=S='(@(DUE:6X@2V]N=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B365I;B!+;VYT;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-#0*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")-96EN(%!O<G1A;"(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,@IM<V=I9"`B37D@4&]R=&%L
M($QA>6]U="(*;7-G<W1R(")-96EN(%!O<G1A;&QA>6]U="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")"=7)M82(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B3D5)3BP@:6-H('-T:6UM92!.
M24-(5"!Z=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(").86UE(@IM<V=S='(@(DYA;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA
M;6EB:6$B"FUS9W-T<B`B3F%M:6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE
M<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H
M97)L86YD<R(*;7-G<W1R(").:65D97)L86YD92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").:65D97)LY&YD
M:7-C:&4@06YT:6QL96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4M0F%S:7,M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(DYE='-C87!E+4-!+5-P97)R=6YG<RU54DPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T
M<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S8V%P92U#02U2:6-H
M=&QI;FEE;BU54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4M6F5T:69I:V%T<V5R;F5U97)U;F=S+5523"(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P
M92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92U3<&5R<G5N9W,M
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*
M;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S
M8V%P92U34TPM4V5R=F5R;F%M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT(@IM<V=S='(@(DYE='-C87!E+4MO;6UE;G1A<B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(DYE='-C87!E+5IE<G1I9FEK
M871T>7`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED
M(").971W;W)K(@IM<V=S='(@(DYE='IW97)K(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,S(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,PIM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B3FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O
M;FEA(@IM<V=S='(@(DYE=6MA;&5D;VYI96XB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A
M=&5G;W)Y(@IM<V=S='(@(DYE=64@2V%T96=O<FEE(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(").975M;VYD
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I
M9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B3F5U97(@0F5N
M=71Z97)N86UE("AO<'1I;VYA;"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE
M=R!:96%L86YD(@IM<V=S='(@(DYE=7-E96QA;F0B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G
M<W1R(").975E<R!087-S=V]R="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R(")$87,@;F5U92!087-S=V]R
M9"!W:7)D(&%M("5X(&%B;&%U9F5N+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"XB"FUS9W-T<B`B1&EE(&YE=65N(%!A<W-W]G)T97(@<W1I;6UE;B!N:6-H
M="#\8F5R96EN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T
M<B`B3F5U97,@1F5N<W1E<B`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYA
M8VAR:6-H=&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(").97=S9W)U<'!E;B(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM
M<V=S='(@(E=E:71E<B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I
M9"`B3F5X="`T(%!H87-E<R(*;7-G<W1R(").Y&-H<W1E(#0@4&AA<V5N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T:6]N<R(*
M;7-G<W1R(").Y&-H<W1E($5I;G-T96QL=6YG96XB"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C$P-@IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B5V5I
M=&5R/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@
M(DYI8V%R86=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T
M<B`B3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T
M<B`B3FEG97)I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-CD*;7-G:60@(DYI9VAT(@IM<V=S='(@(DYA8VAT<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T
M<B`B3F5I;B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B2V5I;F4@2V]N9FEG=7)A
M=&EO;G-D871E;B!V97)F_&=B87(L('5M(%5N=&5R<V-H:65D92!A;GIU>F5I
M9V5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R(")+96EN92!3=')A=&5G:64@>G5M($5R
M<W1E;&QE;B!V;VX@25-/+4%B8FEL9&5R;B!V97)F_&=B87(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B2V5I;F4@0F%T8V@M
M5F]R;&%G92XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T
M('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B17,@97AI<W1I97)T
M(&ME:6X@0FQO8VL@86X@9&5R(&%N9V5G96)E;F5N(%!O<VET:6]N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B2V5I;B!+86QE;F1E<FYA;64@9OQR(&1I92!-0T%,+4%U=&AE
M;G1I9FEZ:65R=6YG(&%N9V5G96)E;BXB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU,0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")+96EN92#$;F1E
M<G5N9V5N+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V
M"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+B(*;7-G<W1R("(B"B)5;G1E<FAA;&(@9&EE<V5R($5B96YE(&OV
M;FYE;B!K96EN92!W96ET97)E;B!5;G1E<G)E8VAT92!H:6YZ=6=E9OQG="!W
M97)D96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3$*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
M1OQR("5S('=U<F1E;B!K96EN92!+;VYF:6=U<F%T:6]N<VEN9F]R;6%T:6]N
M96X@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#8W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B(@HB1OQR(&1E;B!&5%`M5D93
M+51R96EB97(@=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I
M;VYE;B!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HW,C<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"B)&_'(@9&5N(%-13"U6
M1E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA
M=&EO;F5N(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"B)&
M_'(@9&5N(%-13"U$871E:2U61E,M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N
M9FEG=7)A=&EO;G-I;F9O<FUA=&EO;F5N("(*(F%N9V5G96)E;BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*
M;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")+96EN($MR961I="!M
M96AR(/QB<FEG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"XB"FUS9W-T<B`B2V5I;B!%;7!FY&YG97(@86YG96=E8F5N+B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDQ.`IM<V=I9"`B3F\@9FEL
M92!U<&QO861E9"(*;7-G<W1R(")+96EN92!$871E:2!H;V-H9V5L861E;B(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@
M9F]U;F0N(@IM<V=S='(@(DME:6YE($EC;VYS(&=E9G5N9&5N+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(D5S('=U<F1E(&ME:6X@3W)T
M(&9E<W1G96QE9W0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DME
M:6X@3W)T(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P
M;&EE9"XB"FUS9W-T<B`B2V5I;F4@3F%C:')I8VAT(&%N9V5G96)E;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DME:6X@3F%M
M92!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N
M(@IM<V=S='(@(DME:6YE($YU;6UE<B!A;F=E9V5B96XN(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B2V5I;F4@86YS=/;?:6=E;B!';/QC:W-K96MS92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@2%144"U!=71H96YT:69I>FEE
M<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HQ,#`*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D
M:64@24U!4"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@2V5R8F5R;W,M075T:&5N=&EF
M:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!,;V=I;BU!=71H96YT:69I
M>FEE<G5N9R!A;F=E9V5B96XN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P
M87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5I;B!087-S=V]R
M="!F_'(@9&EE(%!!4U-71"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")+96EN(%!A<W-W;W)T(&;\<B!D:64@4TU"+4%U=&AE;G1I9FEZ
M:65R=6YG(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y3
M4TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C
M97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@
M(B(*(DME:6X@4&9A9"!Z=6T@3W!E;E-33"U0<F]G<F%M;2!A;F=E9V5B96XN
M($1A<R!/<&5N4U-,+5!R;V=R86UM('=I<F0@(@HB8F5N]G1I9W0L('5M(%!+
M0U,M,3(M1&%T96X@=F5R87)B96ET96X@>G4@:_9N;F5N+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I
M;F<@<VEG;G5P<RXB"FUS9W-T<B`B2V5I;F4@875S<W1E:&5N9&5N(%)E9VES
M=')I97)U;F=E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4S"FUS
M9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(DME:6X@4W!E:6-H97)P;&%T
M>BU+;VYT:6YG96YT(&9E<W1G96QE9W0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L
M97,B"FUS9W-T<B`B2V5I;F4@4F%H;65N(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#@R"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D
M+B(*;7-G<W1R(")+96EN(%1R96YN>F5I8VAE;B!A;F=E9V5B96XN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B2V5I;F4@4V5I=&5N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV,#D*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R(")$871E:2!N:6-H="!G969U;F1E;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B2V5I
M;F4@=&5M<&]RY')E<R!697)Z96EC:&YI<R!F_'(@9&5N($-A8VAE(&=E9G5N
M9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="XB"FUS9W-T<B`B2V5I;B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O
M<G0@86YG96)E;BXB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T-@IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B17,@=W5R9&5N(&ME:6YE(&?\;'1I9V5N(%A-3"U$871E;B!Z=7+\8VMG
M96=E8F5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")+96EN92!797)T92(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I
M;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)+96EN92!697)S:6]N<VYU
M;6UE<B!I;B!D97(@3W)I9VEN86QK;VYF:6=U<F%T:6]N(&=E9G5N9&5N+B!%
M<FYE=65R;B!3:64@(@HB26AR92!+;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(DME:6YE(%9E<G-I;VYS;G5M;65R(&EN($EH<F5R
M($MO;F9I9W5R871I;VX@9V5F=6YD96XN($5R;F5U97)N(%-I92!):')E("(*
M(DMO;F9I9W5R871I;VXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY-0IM<V=I9"`B3F]N92(*;7-G<W1R(")+96EN92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@
M(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B2V5I;G,@*%-T86YD87)D
M(&)E;G5T>F5N*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED
M(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R(").;W)D:7-C:"`H25-/
M+3@X-3DM,3`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N
M9"(*;7-G<W1R(").;W)F;VQK:6YS96PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(
M96UI<W!H97)E(@IM<V=S='(@(D[V<F1L:6-H92!(96UI<W!H97)E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS
M9W-T<B`B3O9R9&QI8VAE($UA<FEA;F5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").;W)W87DB"FUS9W-T<B`B3F]R=V5G96XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S
M='(@(D?\;'1I9R!B:7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(")'_&QT:6<@
M86(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C0*;7-G:60@
M(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")+96EN(%9E<GIE:6-H;FES(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z,S0X"FUS
M9VED(").;W0@9F]U;F0N(@IM<V=S='(@(DYI8VAT(&=E9G5N9&5N+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H
M<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N
M(@IM<V=S='(@(DYI8VAT(&EM<&QE;65N=&EE<G0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E
M="(*;7-G<W1R(").:6-H="!F97-T9V5L96=T(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#@*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S@*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.3(*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,PHC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,Y(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR-C4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X,R!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,S`P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S,@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S0W(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C0*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,Y-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#4W
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,S8@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C8P-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C(R"FUS9VED
M(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").:6-H="!U;G1E<G-T_'1Z="XB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#8X(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*
M;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&EZ96XB"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R(").:6-H=',@86YZ=7IE:6=E;BP@8FET=&4@
M>G5R_&-K9V5H96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M
M8F5R(@IM<V=S='(@(EIA:&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")!
M;GIA:&P@9&5R(%IE:6-H96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B
M"FUS9W-T<B`B06YZ86AL(&1E<B!3<&%L=&5N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O
M9B!R;W=S(@IM<V=S='(@(D%N>F%H;"!D97(@6F5I;&5N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@
M(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DME:6YE($YU;6UE<FX@9OQR(&1I92!6
M97)T96EL97)L:7-T92!A;F=E9V5B96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")/
M2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/8FIE:W0B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,@IM<V=I9"`B3V)J96-T($-R96%T;W(B
M"FUS9W-T<B`B3V)J96MT97)S=&5L;&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMT86QZ86AL
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*
M;7-G:60@(D]C=&]B97(B"FUS9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T
M<B`B1FEL=&5R(&;\<B!A;G-T]M]I9V4@26YH86QT92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R(")"
M_')O(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED
M(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM
M<V=S='(@(DEH<B!N975E<R!087-S=V]R="!M=7-S('-I8V@@=F]N($EH<F5M
M(&%L=&5N('5N=&5R<V-H96ED96XN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B06QT
M97,@4&%S<W=O<G0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T
M<B`B1F%L<V-H97,@86QT97,@4&%S<W=O<G0N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(D]M86XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#(V"FUS9VED(")/;F-L:6-K(&5V96YT(@IM<V=S='(@(D]N
M8VQI8VLM179E;G0B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S
M:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B3G5R($E-05`M4V5R=F5R('5N=&5R
M<W3\='IE;B!G96UE:6YS86UE($]R9&YE<BXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(DYU<B!A;G-T]M]I9V4@1VS\8VMS:V5K<V4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.#D*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B3G5R(&5I;F4@12U-86EL+4%D<F5S<V4@97)L875B="XB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@
M=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@
M;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E
M(@IM<V=S='(@(B(*(DYU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M
M861M:6YI<W1R871O<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92`B"B)"
M97-I='IE<G)E8VAT92#D;F1E<FXB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HT,2!L:6(O0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B26X@;F5U96T@1F5N<W1E<B#V9F9N96XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I
M9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"U&96AL
M97(Z(%-I9VYI97)T92!3+TU)344M1&%T96X@:V]N;G1E;B!N:6-H="!E>'1R
M86AI97)T('=E<F1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B1&EE<V5N($QI;FL@:6X@96EN
M96T@;F5U96T@1F5N<W1E<B#V9F9N96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B0F5T
M<FEE8G-Y<W1E;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-34*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B16EN<W1E;&QU;F=E;B(*"B,Z
M('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G
M<W1R(")%:6YS=&5L;'5N9V5N(&;\<B`E<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES
M="(*;7-G<W1R(").=6UM97)I97)T92!,:7-T92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB
M"FUS9W-T<B`B3W)G86YI<V%T:6]N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B
M"FUS9W-T<B`B3W)G86YI<V%T:6]N<V%B=&5I;'5N9R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T
M<B`B3W)G86YI<VEE<F5N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*
M;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@
M(D]R:6=I;F%L=F]R;&%G92!D97(@06YW96YD=6YG(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")/<FEG:6YA;'9O<FQA9V4@:6X@
M)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(E-O
M;G-T:6=E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@
M(D%N9&5R92!);F9O<FUA=&EO;F5N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS,@IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M0F5S:71Z97)R96-H=&4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R(")004TM075T:&5N=&EF:7II97)U;F<@:7-T(&YI8VAT
M('9E<F;\9V)A<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R(")014%2.CI-86EL+4)A8VME;F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,C@U"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U
M<F4B"FUS9W-T<B`B1&EG:71A;&4@4$=0+55N=&5R<V-H<FEF="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,S$*;7-G:60@(E!'4"!%
M;F-R>7!T960@1&%T82(*;7-G<W1R(")01U`M=F5R<V-H;/QS<V5L=&4@1&%T
M96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S@S"FUS
M9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("+69F9E;G1L:6-H97(@4$=0
M+5-C:&S\<W-E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$S-C4*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T
M<B`B36ET(%!'4"!U;G1E<GIE:6-H;F5T92]V97)S8VAL_'-S96QT92!$871E
M;B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B4$A0($-O9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@4VAE;&PB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@
M3&EG:'0@4F%I;B(*;7-G<W1R(")6;W)M:71T86=S(&QE:6-H=&5R(%)E9V5N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*
M;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B3F%C:&UI='1A9W,@4F5G96XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I
M9"`B4$T@4VAO=V5R<R(*;7-G<W1R(").86-H;6ET=&%G<R!38VAA=65R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G
M:60@(E!-(%-N;W<B"FUS9W-T<B`B3F%C:&UI='1A9W,@4V-H;F5E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@
M(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(").86-H;6ET=&%G<R!38VAN965S
M8VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#4*;7-G:60@(E!-(%-U;B(*;7-G<W1R(").86-H;6ET=&%G<R!3;VYN
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(").86-H;6ET=&%G<R!'97=I
M='1E<B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.#8*;7-G:60@(E!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(D1I92!03U-)6"U%
M<G=E:71E<G5N9R!F96AL="(*"B,Z(&QI8B]A<&DN<&AP.C(Q-0IM<V=I9"`B
M4%](4"!3:&5L;"(*;7-G<W1R(")?4$A0(%-H96QL(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B
M4&%D9&EN9R(*;7-G<W1R("));FYE;F%B<W1A;F0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*
M;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM
M<V=S='(@(D)E<V5T>G1E(%!A;.1S=&EN96YS:7-C:&4@1V5B:65T92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")0
M87!U82U.975G=6EN96$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A
M>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(E1E:6QW96ES92!"97?V;&MT(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`S-@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<W
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#,*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T
M<B`B4&%S<W=O<G0B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")087-S=V]R="!E<F9O;&=R96EC:"!G9>1N9&5R="XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R(")&86QS8VAE<R!087-S=V]R="(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DME:6X@4&%S<W=O<G0@9OQR(&1I92!2041)55,M075T:&5N=&EF
M:7II97)U;F<@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-S$*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(E!A<W-W;W)T(&UI="!"97-TY'1I9W5N9R(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S
M='(@(E!A<W-W;W)T.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(E!A<W-W;W)T.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`U,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS
M9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B1&EE(%!A<W-W
M]G)T97(@;?QS<V5N(&=L96EC:"!S96EN+B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C`@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")%:6YF_&=E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*
M;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@(E9O;B!D97(@
M6G=I<V-H96YA8FQA9V4@96EN9OQG96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@
M(E!F860B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z-PIM<V=I
M9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")!=7-S=&5H96YD92!296=I
M<W1R:65R=6YG96XZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS
M9VED(")096]P;&4B"FUS9W-T<B`B4&5R<V]N96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N
M="(*;7-G<W1R(")0<F]Z96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")787)T=6YG<V%R8F5I=&5N(&1U<F-H
M9OQH<F5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P,PIM<V=I9"`B
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G
M<W1R(")787)T=6YG<V%R8F5I=&5N(&YA8V@@9&5R($%N;65L9'5N9R!D=7)C
M:&;\:')E;C\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")296-H=&4B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E
M<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")296-H="!<
M(B5S7"(@=W5R9&4@;FEC:'0@9V5L]G-C:'0N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV,3(*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM
M<V=S='(@(EIU9W)I9F8@=F5R=V5I9V5R="(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")296-H=&4B"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")296-H=&5V97)W86QT=6YG(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R(")097)S]FYL:6-H92!!;F=A8F5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B2&%U<W1I97)E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")0:&EL
M:7!P:6YE;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`B1F]T;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*
M;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4&EX
M96PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I
M='5D97,B"FUS9W-T<B`B4&QA='1H96ET96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B0FET=&4@:VQI8VME
M;B!3:64@:6X@96EN92!:96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*
M;7-G<W1R(")":71T92!B97-TY'1I9V5N(%-I92P@9&%S<R!3:64@9&EE<V5S
M($5L96UE;G0@;/9S8VAE;B!M]F-H=&5N.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+B(*;7-G<W1R("(B"B)":71T92!B973D=&EG96X@4VEE+"!D87-S(%-I
M92!D96X@3&EN:R!V;VX@9&EE<V5M($5L96UE;G0@96YT9F5R;F5N(&WV8VAT
M96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,`IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B0FET
M=&4@96EN96X@36]N870@=6YD(&5I;B!*86AR(&%N9V5B96XN(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM
M<V=S='(@(D)I='1E(&=E8F5N(%-I92!E:6YE;B!.86UE;B!F_'(@9&EE(&YE
M=64@2V%T96=O<FEE(&%N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M(@IM<V=S='(@(D)I='1E(&5I;F4@9_QL=&EG92!)4"U!9')E<W-E(&5I;F=E
M8F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-3@*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*(D)I='1E(&=E8F5N
M(%-I92!E:6X@9_QL=&EG97,@1&%T=6T@86X[(/QB97)P<OQF96X@4VEE(&1I
M92!:86AL(&1E<B!486=E(&EN("(*(F1E;2!-;VYA="XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#8U"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+B(*;7-G<W1R(")":71T92!E:6YE;B!G_&QT:6=E;B!:96ET
M=V5R="!E:6YG96)E;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE
M('!R;V)L96TN(@IM<V=S='(@(D)I='1E(&=E8F5N(%-I92!E:6YE(%IU<V%M
M;65N9F%S<W5N9R!):')E<R!0<F]B;&5M<R!A;BXB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(D)I='1E(&=E8F5N(%-I92!):')E;B!"96YU='IE
M<FYA;65N('5N9"!):'(@4&%S<W=O<G0@86XB"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL
M;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@
M=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(D)I='1E(&QE<V5N(%-I
M92!S:6-H(&1E;B!F;VQG96YD96X@5&5X="!S;W)G9N1L=&EG(&1U<F-H+B!3
M:64@3=Q34T5.(&1I97-E;B`B"B)"961I;F=U;F=E;B!Z=7-T:6UM96XL('=E
M;FX@4VEE(&1I97-E<R!3>7-T96T@8F5N=71Z96X@;?9C:'1E;BXB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM
M<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G
M<W1R(")":71T92!D96X@;F5U96X@2V%T96=O<FEE;F%M96X@96EN9V5B96XZ
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L96XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S
M(@IM<V=S='(@(E!O;&ET:6LB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")5;69R86=E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM
M<V=S='(@(E!O<VET:6]N:65R=6YG(&1I97-E($)I;&1E<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(E!O<VET:6]N:65R
M=6YG(&1I97-E<B!486)E;&QE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO
M="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R(")396YD96X@86X@9&EE<V5N
M($]R9&YE<B`H;FEC:'0@9'5R8V@@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(V."!L:6(O0FQO8VLO;65T87(N<&AP.C(W,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R(").:65D97)S8VAL86<@:6X@9&5N(&QE='IT96X@)7,@4W1U
M;F1E*&XI.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W
M"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DYI
M961E<G-C:&QA9W,M/&)R("\^=V%H<G-C:&5I;FQI8VAK96ET(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.C$P-`IM<V=I9"`B4')E9G-?
M;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")0<F5F<U]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W96ET97)U
M;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!R969S7W-E<W-I;VXZ($1I92!B96[V=&EG=&4@4V5S<VEO;BU%<G=E:71E
M<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BXB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(R-PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B3'5F=&1R=6-K
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C$*;7-G:60@(E!R97-S=7)E
M(&%T('-E82!L979E;#H@(@IM<V=S='(@(DQU9G1D<G5C:R!A=68@4V5E:/9H
M93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I
M9"`B4')E<W-U<F4Z("(*;7-G<W1R("),=69T9')U8VLZ("(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S
M"FUS9VED(")0<F5V:65W(@IM<V=S='(@(E9O<G-C:&%U(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T
M"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS
M9W-T<B`B16EN92!6;W)S8VAA=2!D97,@0FEL9&5S(&EN(&5I;F5M(&YE=65M
M($9E;G-T97(@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,`IM
M<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")6;VAE<FEG92!%:6YS
M=&5L;'5N9V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B1&]K
M=6UE;G0@9')U8VME;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B4')I=F%T97(@
M4V-H;/QS<V5L(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP
M.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0<F]B;&5M92(*"B,Z('-E
M<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP
M=&EO;B(*;7-G<W1R(")0<F]B;&5M8F5S8VAR96EB=6YG(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T
M<B`B4')O:F5K=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,#8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(Y-`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B
M3F%C:&9R86=E=&5X="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("+69F9E;G1L:6-H
M97(@4V-H;/QS<V5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@
M(D%L9V]R:71H;75S(&1E<R#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0
M=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M871I;VYE;B!Z=6T@]F9F
M96YT;&EC:&5N(%-C:&S\<W-E;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B1&%S(/9F9F5N
M=&QI8VAE+W!R:79A=&4@4V-H;/QS<V5L<&%A<B!K;VYN=&4@;FEC:'0@97)S
M=&5L;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2
M:6-O(@IM<V=S='(@(E!U97)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S
M(@IM<V=S='(@(DYA8VAR:6-H=&5N(&5N9&?\;'1I9R!L]G-C:&5N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C0*;7-G:60@(E%U97)Y(@IM<V=S='(@(D%B
M9G)A9V4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U
M;W1A(@IM<V=S='(@(E-P96EC:&5R<&QA='HM2V]N=&EN9V5N="(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M
M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(M9F
M9F5N=&QI8VAE<B!24T$@4V-H;/QS<V5L("@E9"!":70I(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(X,@IM<V=I9"`B4F%D:6\@<V5L96-T:6]N
M(@IM<V=S='(@(D%U<W=A:&QK;F]P9B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(@IM<V=S='(@(E)E
M9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#@*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B1G+\:"!296=E;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED
M(")286EN($QA=&4B"FUS9W-T<B`B4W#D=&5R(%)E9V5N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(E)E9V5N<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")286EN(&%N9"!3
M;F]W(@IM<V=S='(@(E-C:&YE97)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E)A:6X@=&\@4VYO=R(*
M;7-G<W1R(")296=E;B!I;B!38VAN964@_&)E<F=E:&5N9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G
M<W1R(")';/QC:W-K96MS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")697)HY&QT;FES(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$*;7-G:60@(E)E
M860B"FUS9W-T<B`B3&5S96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(").
M86-H<FEC:'1E;B!L97-E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M("(B"B(E<R!W:7)K;&EC:"!L]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K86YN
M(&YI8VAT('+\8VMGY&YG:6<@9V5M86-H="!W97)D96XN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(D1A=&5N
M(&1E<R!"96YU='IE<G,@)7,@=VER:VQI8V@@;/9S8VAE;C\@1&EE<V5R(%9O
M<F=A;F<@:V%N;B!N:6-H="`B"B)R_&-K9^1N9VEG(&=E;6%C:'0@=V5R9&5N
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D;\
M:')T(&QE='IT92!!:W1I;VX@97)N975T(&%U<R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-"!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,3`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0X"FUS9VED
M(")2969R97-H(@IM<V=S='(@(D%K='5A;&ES:65R92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.B(*;7-G<W1R(")$>6YA;6ES8VAE($UE;OQE;&5M96YT92!A
M:W1U86QI<VEE<F5N.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@*
M;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E!O<G1A;&%N
M<VEC:'0@86MT=6%L:7-I97)E;CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R
M(")296=U;.1R97(@075S9')U8VLB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M(")697)B:6YD=6YG<RU"<F]W<V5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,30T('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(Q,`IM
M<V=I9"`B4F5L;V%D(@IM<V=S='(@(D%K='5A;&ES:65R96XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,R.`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")"
M96UE<FMU;F=E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G
M:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D5N=&9E<FYT92!397)V97(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G
M<W1R(")397)V97)A9')E<W-E("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E
M;6]V92(*;7-G<W1R(")%;G1F97)N96XB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")"
M;&]C:R!L]G-C:&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")3
M<&%L=&4@;/9S8VAE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S
M='(@(D9O<FUA=&EE<G5N9R!E;G1F97)N96XB"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B
M4&%A<B!L]G-C:&5N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,0IM
M<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(D=E<W!E:6-H97)T97,@4VMR:7!T
M(&%U<R!D96T@=&5M<&]RY')E;B!697)Z96EC:&YI<R!E;G1F97)N96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D5N=&9E<FYE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M
M96YT(@IM<V=S='(@(D1I97-E<R!%;&5M96YT(&%U<R!D96T@1&]K=6UE;G0@
M96YT9F5R;F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B0F5N=71Z97(@;/9S
M8VAE;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B
M0F5N=71Z97(@;/9S8VAE;CH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C$T-`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B06YF<F%G92!K
M;VYN=&4@;FEC:'0@8F5A;G1W;W)T970@=V5R9&5N+B!:=7+\8VMG96=E8F5N
M97(@1F5H;&5R8V]D93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E
M(&9O=6YD+B(*;7-G<W1R(")$97(@9V5W_&YS8VAT92!$:65N<W0@:V]N;G1E
M(&YI8VAT(&=E9G5N9&5N('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$X-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I
M9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@=W5R
M9&4@:6X@9&5R($MO;F9I9W5R871I;VX@9OQR("5S(&YI8VAT(&%N9V5G96)E
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C<S,R!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@W,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S<X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")<(B5S7"(@=W5R9&4@:6X@9&5R(%9&4RU+;VYF:6=U<F%T:6]N
M(&YI8VAT(&%N9V5G96)E;BXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HX,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB
M('=U<F1E(&EN(&1E<B!+;VYF:6=U<F%T:6]N(&YI8VAT(&%N9V5G96)E;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G
M:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(DYO='=E;F1I9V5S($9E;&0B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(Q
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R
M("):=7+\8VMS971Z96XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HT.`IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B4&%S<W=O<G0@
M>G5R_&-K<V5T>F5N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,C@*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B4V5T>F5N
M(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$S,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(DQE
M='IT92!!8F9R86=E(&5I;F;\9V5N(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C<R(&%D;6EN+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B17)G96)N:7-S92(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B
M6G5R_&-K('IU($5I;G-T96QL=6YG96XB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`B3F5U97,@4&%S<W=O<G0@97)N975T(&5I;F=E8F5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2Z75N:6]N(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")+
M;VYF:6=U<F%T:6]N('IU<OQC:W-E='IE;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R(")765-)5UE'+45D:71O<B!%:6YS=&5L;'5N9V5N(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@
M(E+D='-E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B4F5C:'1S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(E)E8VAT92#<8F5R<V-H<FEF="(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*
M;7-G<W1R(")296-H=&4@5V5R=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?6F5I;&5N96EG96YS8VAA9G1E;BXN+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*
M;7-G:60@(E)O;&4B"FUS9W-T<B`B4F]L;&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;>1N:65N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E
M(#$X,"(*;7-G<W1R(")5;2`Q.#"P(&1R96AE;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,
M969T(@IM<V=S='(@(DYA8V@@;&EN:W,@9')E:&5N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E
M(%)I9VAT(@IM<V=S='(@(DYA8V@@<F5C:'1S(&1R96AE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G
M:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(EIE:6QE;F5I9V5N<V-H869T
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("):96EL
M96YE:6=E;G-C:&%F=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(EIE:6QE
M;CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")296=E;&XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P
M"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N
M9"!C;VQU;6YS(@IM<V=S='(@(E)A:&UE;B!Z=VES8VAE;B!A;&QE;B!:96EL
M96X@=6YD(%-P86QT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R(")286AM96X@;G5R('IW
M:7-C:&5N(%-P86QT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R(")286AM96X@;G5R('IW:7-C
M:&5N(%IE:6QE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@
M(E)U;B(*;7-G<W1R(")3=&%R=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<W-I<V-H92!&]G)D97)A
M=&EO;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2
M=6%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X
M-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S
M='(@(E,O34E-12!K<GET;V=R87!H:7-C:&4@56YT97)S8VAR:69T(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O
M34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")-:70@4R]-24U%('9E
M<G-C:&S\<W-E;'1E($YA8VAR:6-H="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"U!=71H96YT:69I>FEE<G5N
M9R!I<W0@;FEC:'0@=F5R9OQG8F%R+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3
M+59E<G-A;F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-1
M3"!3:&5L;"(*;7-G<W1R(")344P@4VAE;&PB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,CDR"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU
M92!L;V]K=7!S(@IM<V=S='(@(E-13"U!;G=E:7-U;F<@>G5R($%B9G)A9V4@
M9&5R(%=E<G1E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,PIM
M<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G
M:60@(E-50T-%4U,B"FUS9W-T<B`B15)&3TQ'(@H*(SH@;&EB+V%P:2YP:'`Z
M,C$Y"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@4VAE;&PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS
M9VED(")382(*;7-G<W1R(")382(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A
M:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN
M="!+:71T<R!U;F0@3F5V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT
M($QU8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM
M<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN
M="!0:65R<F4@=6YD($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I
M;G0@5FEN8V5N="!U;F0@9&EE($=R96YA9&EN96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R
M86UE("A?<V5L9BDB"FUS9W-T<B`B1VQE:6-H97(@4F%H;65N("A?<V5L9BDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R(")386UO82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B4V%N
M($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0
M<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!U;F0@4')I;F-I<&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI
M=&4@4')O=FED97(B"FUS9W-T<B`B4V%T96QL:71E;G!R;W9I9&5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61I
M+4%R86)I96XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B4W!E:6-H97)N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")3879E(%PB)7-<(B(*;7-G<W1R(")<(B5S7"(@<W!E:6-H97)N(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92`E<R(*;7-G<W1R("(E<R!S<&5I8VAE<FXB"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`B16EN<W1E;&QU;F=E;B!S<&5I8VAE<FXB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,38V"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E
M;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D5R>F5U9W1E($MO
M;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:6T@=&5M<&]RY')E;B!697)Z
M96EC:&YI<R!):')E<R`B"B)397)V97)S('-P96EC:&5R;BXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(E<RU+;VYF:6=U<F%T
M:6]N(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(D1A<R!!:W1U86QI<VEE<G5N
M9W-S:W)I<'0@=W5R9&4@:6X@7"(E<UPB(&=E<W!E:6-H97)T+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3
M8V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B5F5R96EN>F5L=&4@1V5W:71T
M97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N
M8V4B"FUS9W-T<B`B5VES<V5N<V-H869T(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R(")3=6-H92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S
M(@IM<V=S='(@(E-U8VAM87-C:&EN96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B1&%T
M96EE;B!A=7-WY&AL96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(D1A='5M(&%U<W?D:&QE;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3DY"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B
M2&EN>G5Z=6;\9V5N9&4@1W)U<'!E;B!A=7-WY&AL96XB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C0T"FUS9VED(")396QE8W0@82!N97<@;W=N
M97(B"FUS9W-T<B`B3F5U96X@0F5S:71Z97(@875S=^1H;&5N(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S
M97)V97(B"FUS9W-T<B`B4V5R=F5R(&%U<W?D:&QE;B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,34W"FUS9VED(")396QE8W0@82!U<V5R('1O
M(&%D9"(*;7-G<W1R(")(:6YZ=7IU9OQG96YD96X@0F5N=71Z97(@875S=^1H
M;&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")!;&QE(&%U<W?D:&QE
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C$*;7-G:60@(E-E
M;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("),96=E;B!3:64@
M86QL92!$871U;7-K;VUP;VYE;G1E;B!F97-T+B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A
M;B!O8FIE8W0B"FUS9W-T<B`B3V)J96MT(&%U<W?D:&QE;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E
M;&5C="!N;VYE(@IM<V=S='(@(DME:6YE;B!A=7-WY&AL96XB"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA
M<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A
M;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+B(*;7-G<W1R("(B"B)7Y&AL96X@4VEE(&1I92!B96[V=&EG=&5N(%IE
M:6-H96X@875S(&1E;B!J97=E:6QI9V5N($9E;&1E<FX@875S+B!$86YN("(*
M(FOV;FYE;B!3:64@9&EE<V4@875S(&1E;2!497AT9F5L9"!K;W!I97)E;B!U
M;F0@:6X@26AR92!.86-H<FEC:'0@96EN9OQG96XN(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S($1A='5M<W1R96YN>F5I
M8VAE;CHB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B5^1H;&5N(%-I92!D
M87,@1&%T=6US9F]R;6%T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3(*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")7Y&AL96X@4VEE(&1I92!)9&5N
M=&ETY'0L(&1I92!3:64@Y&YD97)N(&WV8VAT96XZ(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S(%IE:71T<F5N;GIE:6-H
M96XZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E
M;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E?D:&QE;B!3:64@9&%S
M(%IE:71F;W)M870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU
M-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@
M(E?D:&QE;B!3:64@>G=E:2!Z=7-A;6UE;F=E:/9R:6=E($9E;&1E<B!A=7,N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,PIM<V=I9"`B4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")7Y&AL96X@4VEE(&5I;B!&
M87)B<V-H96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#0*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M5^1H;&5N(%-I92!):')E(&)E=F]R>G5G=&4@4W!R86-H93HB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R(")0<F]B;&5M8F5R:6-H="!A8G-C:&EC:V5N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(E--4R!V97)S8VAI8VME;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A
M;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$X"FUS9VED(")396YS;W(Z
M("(*;7-G<W1R(")396YS;W(Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B
M4V5P=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R(")3
M97)B:65N('5N9"!-;VYT96YE9W)O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS9W-T
M<B`B4V5R:65N;G5M;65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B4V5R=F5R9&%T96X@=6YG_&QT:6<@;V1E<B!N:6-H
M="!V97)F_&=B87(N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS9VED
M(")397-S:6]N($%D;6EN(@IM<V=S='(@(E-E<W-S:6]N=F5R=V%L='5N9R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")397-S
M:6]N+4E$(&%B9V5L875F96XN(@H*(SH@;&EB+V%P:2YP:'`Z,C$Q"FUS9VED
M(")397-S:6]N<R(*;7-G<W1R(")3:71Z=6YG96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S,R"FUS9VED(")3970B"FUS9W-T<B`B075S=V%H
M;"U3871Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<Y"FUS9VED(")3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S='(@(B(*(DQE9V5N(%-I
M92!D:64@16EN<W1E;&QU;F=E;B!F97-T+"!D:64@97,@26AN96X@97)L875B
M96X@26AR(%!A<W-W;W)T("(*(GIU<OQC:WIU<V5T>F5N+"!F86QL<R!S:64@
M97,@96EN;6%L('9E<F=E<W-E;B!S;VQL=&5N+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T
M:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G
M<W1R("(B"B),96=E;B!3:64@96YT9F5R;G1E(%-E<G9E<B!F97-T+"!A=68@
M9&EE(%-I92!V;VX@26AR96T@4&]R=&%L(&%U<R!Z=6=R96EF96X@(@HB;?9C
M:'1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RXB"FUS9W-T<B`B5^1H;&5N(%-I92!):')E(&)E=F]R>G5G=&4@
M4W!R86-H92P@6F5I='IO;F4@=6YD($1A='5M<V5I;G-T96QL=6YG96XN(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO
M=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E
M9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S
M='(@(B(*(DQE9V5N(%-I92!D87,@9&EE(%-T87)T86YW96YD=6YG+"!D87,@
M1F%R8G-C:&5M82P@9&EE(%-E:71E;F%K='5A;&ES:65R=6YG("(*(G5N9"!A
M;F1E<F4@06YZ96EG965I;G-T96QL=6YG96X@9F5S="XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R(")+;VYF
M:6=U<F%T:6]N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT
M;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B
M"FUS9W-T<B`B06MT=6%L:7-I97)U;F=S<VMR:7!T92!S:6YD('9E<F;\9V)A
M<B(*"B,@365H<F5R92!P87-S96YD92!/<G1E(&UI="!D:65S96T@4&%R86UE
M=&5R.B`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B365H<F5R92!P87-S96YD92!/<G1E(&UI="!D:65S
M96T@4&%R86UE=&5R.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L
M;&5S(@IM<V=S='(@(E-E>6-H96QL96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#DX"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R(")%:6YK875F
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2W5R>F4@6G5S86UM96YF87-S=6YG
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,PIM<V=I9"`B4VAO=6QD
M(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S
M='(@(E-O;&QE;B!487-T96YK;VUB:6YA=&EO;F5N(&;\<B!D:64@;65I<W1E
M;B!,:6YK<R!A:W1I=FEE<G0@=V5R9&5N/R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")3:&]W(@IM<V=S='(@(EIE
M:6=E;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-30*;7-G:60@(B(*
M(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD
M('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@HB56YT97)S8VAI961E('IW:7-C:&5N(&1E<B!A:W1U96QL96X@=6YD
M(&1E<B!G97)A9&4@97)Z975G=&5N($MO;F9I9W5R871I;VX@(@HB86YZ96EG
M96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X-PIM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")!
M;GIE:6=E;BP@=V%N;B!D:64@;&5T>G1E($%N;65L9'5N9R!E<F9O;&=T(&ES
M=#\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(D5R:&%L=&5N
M(&1E<R!/<FEG:6YA;',@97)M]F=L:6-H96XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")!
M=7-WY&AL97(@86YZ96EG96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3(S"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM
M<V=S='(@(E=E<FMZ975G;&5I<W1E(&;\<B!486)E;&QE;B!A;GIE:6=E;C\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@
M(D1A<R`E<RU-96[\(&%U9B!D97(@;&EN:V5N(%-E:71E(&%N>F5I9V5N/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R(")$:6%L;V<@9OQR(%1A8F5L;&5N>F5L;&5N96EG
M96YS8VAA9G1E;B!A;GIE:6=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@
M5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B1&EA;&]G(&;\<B!4
M86)E;&QE;F5I9V5N<V-H869T96X@86YZ96EG96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M(")$:6%L;V<@9OQR(%1A8F5L;&5N>F5I;&5N96EG96YS8VAA9G1E;B!A;GIE
M:6=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B1&EA;&]G(&;\<B!":6QD96EG96YS8VAA9G1E
M;B!A;GIE:6=E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*
M;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DAO8VAL861E;B!E<FWV9VQI
M8VAE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E-C:&%U97(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO
M=V5R<R!%87)L>2(*;7-G<W1R(")&<OQH(%-C:&%U97(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VAO=V5R
M<R!,871E(@IM<V=S='(@(E-PY'1E<B!38VAA=65R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-H;W=E<G,@
M:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(E-C:&%U97(@:6X@9&5R(%5M9V5B
M=6YG(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")697)K;&5I;F5R;B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M.3$P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z.3<R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`U.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@
M;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@
M9FER<W0B"FUS9W-T<B`B5F5R:VQE:6YE<FX@;V1E<B!V97)S8VAI96)E;B!3
M:64@97)S="!D:64@8F5N86-H8F%R=&5N($)L]F-K92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED
M(")3:6=N('5P(@IM<V=S='(@(E)E9VES=')I97)E;B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B
M"FUS9W-T<B`B4VEG;F%T=7(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G
M<W1R(")3:6=N871U<F%L9V]R:71H;75S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4VEN9V%P;W)E(@IM<V=S='(@(E-I;F=A<'5R(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C8T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R(")'<O;?
M92(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(E=A<G1U;F=S
M87)B96ET96X@_&)E<G-P<FEN9V5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VQO=F%K:6$B"FUS9W-T<B`B4VQO=V%K96DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]W96YI96XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R(*
M;7-G<W1R(")38VAN964B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B4V-H
M;F5E<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8P"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B4V-H;F5E
M<V-H875E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B1G+\
M:"!38VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S
M='(@(E-PY'1E<B!38VAN965S8VAA=65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.#`*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R(")38VAN965H
M]FAE.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-`IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4V-H;F5E;65N9V4@
M86QS(%=A<W-E<CH@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)
M<VQA;F1S(@IM<V=S='(@(E-O;&]M;VYI;G-E;&XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(E-O;6%L:65N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S
M='(@(DQI961E<B`F($=E9&EC:'1E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDR-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T
M<B`B075S=V%H;"!D97(@4V]R=&EE<G)E:6AE;F9O;&=E(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM
M<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B57)S<')U;F=S861R97-S
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R
M(")3_&1A9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I
M9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(E/\9&5U
M<F]PY&ES8V@@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R(")3_&1G96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC
M:&EN<V5L;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B4_QD;&EC:&4@2&5M:7-P:&5R92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(D%B<W1A;F0@>G=I<V-H96X@875F
M96EN86YD97(@9F]L9V5N9&5N(%IE;&QE;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W
M965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(D%B<W1A
M;F0@>G=I<V-H96X@26YH86QT('5N9"!286AM96X@=F]N(%IE;&QE;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(D%B<W1A;F1H86QT97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS
M9W-T<B`B06)S=&%N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I
M;F<B"FUS9W-T<B`B06)S=.1N9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A
M:6XB"FUS9W-T<B`B4W!A;FEE;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A;2(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@
M26YP=70B"FUS9W-T<B`B4V]N9&5R>F5I8VAE;BU%:6YG86)E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM
M<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("):96QL92!T96EL96XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B4W!A;'1E('1E:6QE;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("):96EL92!T96EL96XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*
M;7-G<W1R(")3<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA
M(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED(")3=&%N
M9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R(")3
M=&%R=&IA:'(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B0G5N9&5S
M<W1A870@;V1E<B!0<F]V:6YZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U"FUS9VED(")3=&]R
M86=E(&9O<FUA="(*;7-G<W1R(")3<&5I8VAE<F9O<FUA="(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@
M061D<F5S<R(*;7-G<W1R(")3=')AWV4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H
M(@IM<V=S='(@(D1U<F-H9V5S=')I8VAE;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(EIE
M:6-H96YL:7-T92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X.3$*
M;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@
M(D1O;6%I;B!A=7,@9&5R($%D<F5S<V4@96YT9F5R;F5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I;"!;0U-372(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U
M(@IM<V=S='(@(E-O(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")5;G1E<G9E<GIE:6-H;FES(%PB)7-<(B!N:6-H="!G
M969U;F1E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D)E=')E9F8B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B"FUS9W-T<B`B
M06)S8VAI8VME;B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D1I92!296=I
M<W1R:65R=6YG<V%N9G)A9V4@9OQR(%PB)7-<(B!W=7)D92!A8F=E<V-H:6-K
M="X@4VEE(&OV;FYE;B!S:6-H(&YO8V@@(@HB;FEC:'0@86YM96QD96XL('-O
M;&%N9V4@9&EE($%N9G)A9V4@;F]C:"!N:6-H="!B97-TY'1I9W0@=W5R9&4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(E1I969G97-T96QL="(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I
M9"`B4W5C8V5S<R(*;7-G<W1R(")%<F9O;&<B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!W=7)D92!E
M<F9O;&=R96EC:"!H:6YZ=6=E9OQG="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R
M(")$871E;B!D97,@0F5N=71Z97)S(%PB)7-<(B!W=7)D92!E<F9O;&=R96EC
M:"!G96SV<V-H="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@=W5R9&4@
M97)F;VQG<F5I8V@@9V5L]G-C:'0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!W=7)D92!E
M<F9O;&=R96EC:"!G96SV<V-H="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)+;VYF
M:6=U<F%T:6]N(&5R9F]L9W)E:6-H('IU<OQC:V=E<V5T>G0N(%-E:71E(&YE
M=2!L861E;BP@=6T@9&EE(,1N9&5R=6YG96X@(@HB86YZ=7IE:6=E;BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B0F%C:W5P(&1E<B!+;VYF:6=U<F%T:6]N
M(&5R9F]L9W)E:6-H(&=E<W!E:6-H97)T+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R(")"86-K=7`@9&5R($MO;F9I9W5R871I;VX@)7,@97)F;VQG<F5I8V@@
M9V5S<&5I8VAE<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G
M<W1R(")<(B5S7"(@=W5R9&4@97)F;VQG<F5I8V@@86MT=6%L:7-I97)T(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R
M;W1E("5S(@IM<V=S='(@(B5S('=U<F1E(&5R9F]L9W)E:6-H(&=E<W!E:6-H
M97)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5D
M86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(EIU<V%M;65N9F%S
M<W5N9R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N
M(%)I<V4B"FUS9W-T<B`B4V]N;F5N875F9V%N9R(*"B,Z(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(")3;VYN96YU
M;G1E<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,PIM<V=I9"`B4W5N;GDB"FUS9W-T<B`B4V]N;FEG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B4W5N<FES92(*
M;7-G<W1R(")3;VYN96YA=69G86YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E
M+U-U;G-E="(*;7-G<W1R(")3;VYN96YA=68O=6YT97)G86YG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B4W5N<FES93H@
M(@IM<V=S='(@(E-O;FYE;F%U9F=A;F<Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3;VYN
M96YU;G1E<F=A;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`W"FUS9VED(")3=6YS970Z("(*;7-G<W1R(")3;VYN96YU;G1E<F=A;F<Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(DAO8VAG97-T96QL="(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.#`*;7-G:60@(E-U<'!O
M<G0B"FUS9W-T<B`B4W5P<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U
M<FEN86UE(@IM<V=S='(@(E-U<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(").
M86-H;F%M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*
M86X@36%Y96XB"FUS9W-T<B`B4W9A;&)A<F0@=6YD($IA;B!-87EE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%S:6QA
M;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B4V-H
M=V5D96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T
M<B`B4V-H=V5I>B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V
M"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(E-Y;F-H<F]N:7IA
M=&EO;G-L;V<@9V5L]G-C:'0B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B1F]R;6%T9F5H;&5R(&EN(%-U8VAB96=R:69F96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G
M<W1R(")!<F%B:7-C:&4@4F5P=6)L:6L@4WER:65N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M4W1O<FTB
M"FUS9W-T<B`B1V5W:71T97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B1V5W:71T97(@=6YD(%=I;F1I9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4+5-T;W)M<R(*;7-G
M<W1R(")'97=I='1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8W"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R(")&
M<OQH($=E=VET=&5R(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP
M.C$W,`IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6+41A=&5I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,PIM<V=I9"`B5&%B;&4@4')O<&5R=&EE<R(*;7-G<W1R(")486)E;&QE;F5I
M9V5N<V-H869T96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QL
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B5&%B
M96QL96YE:6=E;G-C:&%F=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E
M(&]F($-H:6YA(@IM<V=S='(@(E1A:7=A;BP@8VAI;F5S:7-C:&4@4')O=FEN
M>B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B
M5&%D<V-H:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5F5R96EN:6=T92!297!U
M8FQI:R!486YS86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B6FEE;#HB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDU."!C;VYF:6<O:&]O
M:W,N<&AP+F1I<W0Z,3`U.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3@Y"FUS9VED(")487-K<R(*;7-G<W1R(")!=69G86)E;B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO
M;F4@3G5M8F5R(@IM<V=S='(@(E1E;&5F;VYN=6UM97(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B
M"FUS9W-T<B`B5&5M<&5R871U<B!D97(@;&5T>G1E;B!3='5N9&4Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")496UP97)A='5R92(*
M;7-G<W1R(")496UP97)A='5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP
M97)A='5R.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B5&5M<&5R871U<CQB<B`O/B@E
M<TUA>"5S+R5S36EN)7,I("9D96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")6;W)L86=E(%PB)7-<
M(B!N:6-H="!G969U;F1E;BXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V
M.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5F]R
M;&%G96YV97)W86QT=6YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0U"FUS9VED(")497AT
M(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<R
M"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B3G5R(%1E>'0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS
M9VED(")497AT(&%L:6=N(@IM<V=S='(@(D%U<W)I8VAT=6YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B
M5&5X='1O<"(*;7-G<W1R(")497AT($]B96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R
M(")$;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I
M("A425,M-C(P*2(*;7-G<W1R(")4:&%I;.1N9&ES8V@@*%1)4RTV,C`I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA
M;F0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,PIM<V=I9"`B
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M1&EE($944"U%>'1E;G-I;VX@:7-T(&YI8VAT('9E<F;\9V)A<BXB"@HC.B!F
M<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HU-0IM<V=I9"`B5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")$:64@0VAR;VYI
M:R!S=&5H="!N:6-H="!Z=7(@5F5R9OQG=6YG+B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.38T"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B1&EE($AO<F1E+TMO;&%B($EN=&5G<F%T:6]N
M<V9U;FMT:6]N96X@=6YT97)S=/QT>F5N(%PB)7-<(B!N:6-H="(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H
M92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@
M(D1I92!)35-0+4QO9V1A=&5I(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D
M96XN(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY(@IM<V=S='(@(D1I92!-86EN=&5N86YC93HZ($ML87-S92!K;VYN=&4@
M;FEC:'0@9V5L861E;B!W97)D96XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L
M;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W:6YD;W<@:&%S
M(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B1&%S($5I;G-T96QL=6YG96XM
M1F5N<W1E<B!I<W0@9V5S8VAL;W-S96X@=V]R9&5N+B!!8F)R=6-H+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3DP(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C$R(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(T"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C,U(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C4S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8U(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S`T"FUS9VED("(B"B)4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N(@IM<V=S='(@(B(*(D1E<B!!9&UI;FES=')A=&]R(&UU<W,@96EN('!E
M<FUA;F5N=&5S(%)E8VAT92U"86-K96YD(&5I;G)I8VAT96XL('=E;FX@4VEE
M("(*(F1I92!296-H=&5V97)W86QT=6YG(&YU='IE;B!M]F-H=&5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(DYU<B!U
M;G1E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S
M(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I
M;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(D1I92!)1"U.=6UM97(@
M9&5S($MO;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B96XL('=A<B!L965R(&]D
M97(@:V]N;G1E(&EN(&1E<B`B"B)$871E;F)A;FL@;FEC:'0@9V5F=6YD96X@
M=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A
M9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B1&5R($MO;G1A
M:W0@=W5R9&4@97)F;VQG<F5I8V@@26AR96T@061R97-S8G5C:"!H:6YZ=6=E
M9OQG="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3@Q
M"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G
M<W1R("(B"B)$97(@4$=0+5-I9VYA='5R8FQO8VL@=VER9"!B96[V=&EG="P@
M=6T@9&EE('5N=&5R>F5I8VAN971E($YA8VAR:6-H="!Z=2`B"B+\8F5R<'+\
M9F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(B(*(D1I92!)1"U.
M=6UM97(@9&5R(%9E<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5B96XL
M('=A<B!L965R(&]D97(@:V]N;G1E("(*(FEN(&1E<B!$871E;F)A;FL@;FEC
M:'0@9V5F=6YD96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1I92!697)T
M96EL97)L:7-T92!W=7)D92!N:6-H="!A;F=E9V5B96XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*(D1I92!697)S8VAL_'-S96QU;F=S9G5N:W1I;VYE;B!B96[V
M=&EG96X@96EN92!S:6-H97)E(%-E<G9E<G9E<F)I;F1U;F<N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")$:64@1&%T
M96D@)7,@<V]L;'1E(&5I;F5N("5S($5I;G1R86<@96YT:&%L=&5N+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@
M(D1I92!$871E:2`E<R!S;VQL=&4@96EN:6=E("5S($5I;G1RY&=E(&5N=&AA
M;'1E;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")$:64@1&%T
M96D@96YT:&EE;'0@:V5I;F4@1&%T96XN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92XB"FUS9W-T<B`B2&EE<B!S:6YD(&1I92!+;W!F96EN='+D9V4@9OQR
M(&1I97-E(&UE<W-A9V4O<F9C.#(R($YA8VAR:6-H="XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4
M:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M
M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B
M=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@
M;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@
M961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE
M<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y
M(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T
M:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL
M('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@
M(B(*(D1E<B!6;VQL8FEL9&UO9'5S('9E<G5R<V%C:'0@875F($=R=6YD('9O
M;B!&96AL97)N(&EM($EN=&5R;F5T($5X<&QO<F5R("(*(F)E:V%N;G1E<FUA
MWV5N(%!R;V)L96UE(&UI="!D:65S96T@0G)O=W-E<BP@9&EE('=I<B!N:6-H
M="!U;6=E:&5N(&OV;FYE;BX@(@HB56YT97(@56US=.1N9&5N(&5R:&%L=&5N
M(%-I92!E:6YE(&9E:&QE<FAA9G1E($%N>F5I9V4L(&9E:&QE;B`B"B)%9&ET
M;W)F=6YK=&EO;F5N+"!O9&5R(&1E<B!"<F]W<V5R('-T_')Z="!A8BX@075F
M(&5I;F5M(%=I;F1O=R`Y>"!3>7-T96T@(@HB=V5R9&5N(%-I92!V97)M=71L
M:6-H(&5I;F4@)T%L;&=E;65I;F4@4V-H=71Z=F5R;&5T>G5N9R<@97)H86QT
M96X@=6YD(&W\<W-E;B`B"B)D96X@4F5C:&YE<B!N974@<W1A<G1E;BY<7&Y<
M7&Y3:64@=W5R9&5N(&=E=V%R;G0N($)I='1E(&1R_&-K96X@4VEE(&%U9B!/
M2RP@(@HB=V5N;B!3:64@;F]C:"!I;6UE<B!D96X@5F]L;&)I;&1M;V1U<R!V
M97)W96YD96X@;?9C:'1E;BXB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B1&EE($ED96YT:73D="!<(B5S7"(@
M=W5R9&4@9V5L]G-C:'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B3G5R(&QI;FMS(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB1&5R($]R="!D97,@1VYU4$<M
M4')O9W)A;6US(&UU<W,@9&5R($-R>7!T7W!G<#HZ($ML87-S92#\8F5R9V5B
M96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR
M,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O
M;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L
M87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A
M9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"B)$
M:64@3F%C:')I8VAT(&UI="!D96T@0F5T<F5F9B!<(B4S)'-<(BP@9&EE(&%M
M("4Q)',@86X@)3(D<R!G97-C:&EC:W0@=W5R9&4L("(*(FES="!A;F=E>F5I
M9W0@=V]R9&5N+EQN(@HB1&%S(&AE:=]T(&YI8VAT+"!D87-S(&1I92!.86-H
M<FEC:'0@875C:"!G96QE<V5N(&]D97(@=F5R<W1A;F1E;B!W=7)D92XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#DU"FUS9VED(")4:&4@;F%M
M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS
M9W-T<B`B3F%M92!F_'(@9&5N($QI;FL@>G5R($YA8VAR:6-H=&5N97)S=&5L
M;'5N9R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I
M9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G
M<W1R(")$:64@06YZ86AL(&1E<B!&96QD97(@;75S<R!A;',@6F%H;"!A;F=E
M9V5B96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T
M<B`B1&%S($]P96Y34TPM36]D=6P@=VER9"!F_'(@9&EE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@2VQA<W-E(&)E;O9T:6=T+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<RYP:'`Z,C@X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M92(*;7-G<W1R("(B"B)$:64@0F5N=71Z97)E:6YS=&5L;'5N9R!<(B5S7"(@
M:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BP@=V5I;"!I:')E("(*
M(D1A=&5N(&1I92!M87AI;6%L(&5R;&%U8G1E($=R]M]E(/QB97)S8VAR96ET
M96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H
M<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*(D1A<R!0<F]G<F%M;2!F_'(@9&EE
M($%N>F5I9V4@9&EE<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT(&=E
M9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM
M<V=I9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+B(*;7-G<W1R(")$87,@06YF_&AR=6YG<WIE:6-H96X@;75S
M<R!A;',@96EN>F5L;F5S(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G
M<W1R(").=7(@;&EN:W,@=6YD(')E8VAT<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R
M:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(").=7(@<F5C:'1S(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P
M87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@
M(D1A<R!4<F5N;GIE:6-H96X@;75S<R!A;',@96EN>F5L;F5S(%IE:6-H96X@
M86YG96=E8F5N('=E<F1E;BXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$97(@4V5R=F5R(%PB)7-<
M(B!W=7)D92!E;G1F97)N="XB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<
M(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B1&5R(%-E<G9E<B!<(B5S7"(@
M=W5R9&4@9V5S<&5I8VAE<G0N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B1&EE(%)E9VES=')I97)U;F=S
M86YF<F%G92!V;VX@)7,@=W5R9&4@96YT9F5R;G0N(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B1&EE(&%N9V5G96)E;F4@6F5I;&4@*"5D*2!E>&ES
M=&EE<G0@;FEC:'0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&EE('1E;7!O<N1R92!$
M871E:2!<(B5S7"(@97AI<W1I97)T(&YI8VAT+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,C`*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T
M<B`B(@HB1&5R(%1E>'0L(&1E;B!3:64@86YG96=E8F5N(&AA8F5N+"!E;G1S
M<')I8VAT(&YI8VAT(&1E;2!497AT(&%U9B!D96T@(@HB0FEL9'-C:&ER;2XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*
M;7-G<W1R(").=7(@;V)E;B!U;F0@=6YT96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R(").=7(@;V)E;B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@
M=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*
M(D1I92!H;V-H9V5L861E;F5N($1A=&5N('-I;F0@;F%C:"!D96T@;&5T>G1E
M;B!38VAR:71T('9E<FQO<F5N(&=E9V%N9V5N+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W-@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R(")$:64@:&]C:&=E;&%D96YE($1A=&5I(&MO;FYT
M92!N:6-H="!G97-P96EC:&5R="!W97)D96XN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")$97(@=V5A=&AE<BYC;VT@0FQO8VL@:7-T(&YI
M8VAT('9E<F;\9V)A<BXB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(")4:&5M96XM5F5R>F5I8VAN:7,@7"(E<UPB
M(&YI8VAT(&=E9G5N9&5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(D5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V97)F
M_&=B87(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M,S0Y"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B17,@9VEB="!K96EN92!A;GIE:6=B
M87)E;B!.86-H<FEC:'1E;G1E:6QE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N(@IM<V=S='(@(B(*(D1I97-E<R!&96QD(&5N=&CD;'0@>G4@
M=FEE;&4@6F5I8VAE;BX@4VEE(&AA8F5N("5S(%IE:6-H96X@86YG96=E8F5N
M.R!3:64@(@HB;?QS<V5N('=E;FEG97(@86QS("5S(&%N9V5B96XN(@H*(SH@
M<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@
M=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B0F5I;2!(:6YZ=6;\9V5N('9O;B!<
M(B5S7"(@>G5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ
M("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@HB0F5I;2!,
M]G-C:&5N(&1E<B!$871E;B!V;VX@0F5N=71Z97(@7"(E<UPB(&ES="!E:6X@
M4')O8FQE;2!A=69G971R971E;CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M
M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(D)E:6T@
M3/9S8VAE;B!V;VX@7"(E<UPB(&%U<R!D96T@4WES=&5M(&ES="!E:6X@4')O
M8FQE;2!A=69G971R971E;CH@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I
M;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")"96EM($%K='5A;&ES:65R96X@=F]N
M(%PB)7-<(B!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T96XZ("5S(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(U"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@HB0F5I;2!(
M;V-H;&%D96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N
M+B`E<R!W=7)D92!N:6-H="`B"B)H;V-H9V5L861E;BXB"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO
M=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB0F5I;2!(;V-H;&%D
M96X@9&5R($1A=&5I(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B`E<R!W
M87(@9W+VWV5R(&%L<R!D:64@(@HB;6%X:6UA;"!E<FQA=6)T92!'<O;?92`H
M)60@0GET97,I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R
M=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)"96EM($AO8VAL861E;B!D
M97(@1&%T96D@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN("5S('=U<F1E
M(&YU<B!T96EL=V5I<V4@(@HB:&]C:&=E;&%D96XN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS
M9W-T<B`B0F5I;2!!;GIE:6=E;B!D:65S97,@3F%C:')I8VAT96YT96EL<R!I
M<W0@96EN($9E:&QE<B!A=69G971R971E;BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D)E
M:6T@26UP;W)T:65R96X@9&5R($MO;G1A:W1D871E;B!I<W0@96EN($9E:&QE
M<B!A=69G971R971E;BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP
M:'`Z,S`*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")"96EM($EM<&]R=&EE<F5N(&1E
M<B!I0V%L96YD87(@1&%T96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E
M<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S
M='(@(B(*(D1A<R!+;VYF:6=U<F%T:6]N<RU&;W)M=6QA<B!E;G1H:65L="!E
M:6YE;B!&96AL97(N(%9I96QL96EC:'0@:&%B96X@4VEE(&5I;B`B"B)09FQI
M8VAT9F5L9"!L965R(&=E;&%S<V5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B(@HB0F5I;2!!=7-F_&AR96X@9&5R(&%N9V5G96)E;F5N($%D<F5S
M<V)U8VAF=6YK=&EO;B!I<W0@96EN($9E:&QE<B`B"B)A=69G971R971E;BX@
M0FET=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"B)"96D@9&5R($%K='5A;&ES:65R=6YG(&1E<B!+;VYT86MT9&5T
M86EL<R!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@0FET=&4@(@HB=F5R
M<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D)E
M:2!D97(@06MT=6%L:7-I97)U;F<@9&5R(%9E<G1E:6QE<FQI<W1E(&ES="!E
M:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92`B"B)V97)S=6-H96X@4VEE
M(&5S('-PY'1E<B!N;V-H(&5I;FUA;"XB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,CDY"FUS9VED(")4:&ES($E-05`@<V5R=F5R
M(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$
M:65S97(@24U!4"U397)V97(@=6YT97)S=/QT>G0@:V5I;F4@9V5M96EN<V%M
M96X@3W)D;F5R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D1I97,@<V-H96EN="!K96EN
M(&?\;'1I9V5S(%)!4BU!<F-H:78@>G4@<V5I;BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")$
M:65S('-C:&5I;G0@:V5I;B!G_&QT:6=E<R!:25`M07)C:&EV('IU('-E:6XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI
M<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM
M<V=S='(@(D1I97,@<V-H96EN="!K96EN92!G_&QT:6=E($MA<G1E;FYU;6UE
M<B!Z=2!S96EN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H
M:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B="!D
M87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC
M:V%T96QL+2(*(D=A=&5W87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET
M($AI;&9E(&1E<B!(5%10+4%022XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M(@IM<V=S='(@(B(*(D1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C
M:&EC:V5N('9O;B!.86-H<FEC:'1E;B!D=7)C:"!D96X@5TE.+4=A=&5W87D@
M(@HB*&AT='`Z+R]W:6YP;&,N8V]M*2!M:70@2&EL9F4@9&5R($A45%`M05!)
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S
M;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS
M9W-T<B`B(@HB1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K
M96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!S;7,R;6%I;"TB"B)'871E
M=V%Y("AH='1P.B\O<VUS,FUA:6PN8V]M*2!M:70@2&EL9F4@9&5R($A45%`M
M05!)+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N
M($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)$:65S
M97(@5')E:6)E<B!E<FQA=6)T(&1A<R!697)S8VAI8VME;B!V;VX@3F%C:')I
M8VAT96X@<&5R(%--5%`@9'5R8V@@9&5N("(*(E9O9&%F;VYE+4ET86QI96XM
M1V%T97=A>2!A=7-S8VAL:67?;&EC:"!A;B!6;V1A9F]N92U.=6UM97)N+B!$
M86;\<B!W:7)D(&5I;B`B"B)%+4UA:6PM2V]N=&\@8F5I(%9O9&%F;VYE($ET
M86QI96X@*&AT='`Z+R]W=W<N,3DP+FET*2!B96[V=&EG="XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3<*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(S"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,38W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,SD*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#8X
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-34@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,34*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S@R,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#,Q"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")$
M:65S97,@1F5L9"!I<W0@;F]T=V5N9&EG+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B1&EE<V5S($9E;&0@9&%R9B!N=7(@
M9V%N>F4@6F%H;&5N(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#,T"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")$:65S97,@1F5L
M9"!D87)F(&YU<B!:86AL96X@=6YD(&5I;F5N(%!U;FMT(&5N=&AA;'1E;BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R
M(")$:65S97,@1F5L9"!D87)F(&YU<B!/:W1A;'IA:&QE;B!E;G1H86QT96XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI
M<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI
M<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB1&EE<V5S($9E;&0@;75S<R!E
M:6YE(&MO;6UA+2!O9&5R(&QE97)Z96EC:&5N9V5T<F5N;G1E($QI<W1E('9O
M;B!G86YZ96X@(@HB6F%H;&5N(&5N=&AA;'1E;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R(")$:65S97,@1F5L9"!M=7-S(&5I;F4@
M9_QL=&EG92!:86AL(&5N=&AA;'1E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D1I97-E<R!&96QD(&UU
M<W,@96EN96X@1F%R8G=E<G0@:6T@:&5X861E>FEM86QE;B!21T(M1F]R;6%T
M(&5N=&AA;'1E;BP@>BX@0BX@(@HB)R,Q,C,T868G+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E
M861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")$:65S97,@1F]R;75L87(@
M=W5R9&4@8F5R96ET<R!V97)A<F)E:71E="XB"@HC.B!T96UP;&%T97,O:&5L
M<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S
M+B(*;7-G<W1R(")$:65S(&ES="`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES
M(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C
M="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R
M<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T
M(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS
M9W-T<B`B(@HB1&EE(&ES="!E:6X@2V]L86(M1W)O=7!W87)E+4]B:F5K="X@
M56T@9&EE<V5S($]B:F5K="!A;GIU>F5I9V5N+"!B96[V=&EG96X@(@HB4VEE
M(&5I;B!%+4UA:6PM4')O9W)A;6TL(&1A<R!D87,@2V]L86(M1W)O=7!W87)E
M+49O<FUA="!U;G1E<G-T_'1Z="X@16EN92`B"B),:7-T92!S;VQC:&5R(%!R
M;V=R86UM92!F:6YD96X@4VEE('5N=&5R("5S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)$:65S92!.
M86-H<FEC:'0@=W5R9&4@:6X@96EN96T@6F5I8VAE;G-A='H@*"5S*2!E<G-T
M96QL="P@9&5R(&YI8VAT($EH<F5M("(*(F5I9V5N96X@96YT<W!R:6-H="XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D1I
M97-E(%IA:&P@;75S<R`Q(&]D97(@9W+VWV5R('-E:6XN(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB
M"FUS9W-T<B`B1&EE<V5R(%-E<G9E<B!K86YN(%I)4"T@=6YD($=:25`M1&%T
M96EN(&YI8VAT(&5N='!A8VME;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X-@IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")$:65S97,@4WES=&5M(&ES
M="!Z=7(@6F5I="!D96%K=&EV:65R="XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+B(*;7-G<W1R(")$:65S97(@5V5R="!M=7-S(&5I;F4@6F%H;"!S
M96EN+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*
M;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T
M:6]N<R!W:6YD;W<B"FUS9W-T<B`B1&EE<V5S($9E;G-T97(@;75S<R!V;VX@
M96EN96T@16EN<W1E;&QU;F=E;BU&96YS=&5R(&=E]F9F;F5T('=E<F1E;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS
M9VED(")4:'5N9&5R(@IM<V=S='(@(D1O;FYE<B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B5&EC
M:V5T<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#,@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4W"FUS9VED(")4:6UE(@IM<V=S='(@
M(EIE:70B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED
M(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(EIE:71E<F9A<W-U;F<B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S
M='(@(EIE:71F;W)M870B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-30Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("):96ET875S=V%H
M;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@
M(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B5&ET96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ
M(@IM<V=S='(@(E1I=&5L("A4;V]L=&EP*3HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R
M(")!;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(DAA;'1E;B!3:64@8F5I
M;2!+;&EC:V5N(%-T<F<@8GIW+B`H4$,I($-O;6UA;F0@*$UA8RD@9V5D<OQC
M:W0L('5M(&UE:')E<F4@(@HB16EN='+D9V4@875S>G5WY&AL96XN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B2&5U=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS
M9W-T<B`B6G4@2%1-3"U1=65L;&-O9&4@=6US8VAA;'1E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B5&]G;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]K96QA=2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*;7-G:60@(E1O;6]R<F]W(@IM
M<V=S='(@(DUO<F=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM
M<V=S='(@(E1O;F=A(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K;VQA8BYP
M:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@
M=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B6G4@=FEE;&4@=6YG_&QT:6=E
M($%N;65L9&5V97)S=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU=&5N+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-PIM<V=I9"`B5&]P(@IM<V=S='(@(D]B96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@
M*%]T;W`I(@IM<V=S='(@(L1UWV5R<W1E<B!286AM96X@*%]T;W`I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")4<F%N<VQA=&EO;G,B
M"FUS9W-T<B`BW&)E<G-E='IU;F=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@=6YD(%1O
M8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@
M(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5V%H<B!O9&5R(&9A;'-C:"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G
M:60@(E1U(@IM<V=S='(@(D1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N
M:7-I82(*;7-G<W1R(")4=6YE<VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U<FME>2(*;7-G<W1R(")4_')K96DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B
M5/QR:VES8V@@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5R:VUE;FES=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R
M(")4=7)K<RT@=6YD($-A:6-O<VEN<V5L;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C<S"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T
M<B`B26AR92!!=7-W86AL.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B558M26YD
M97@Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G
M<W1R(")(;VUE<&%G92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T
M(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),($EH<F5S(%-K
M<FEP=',@9OQR(&1E;B!697)S86YD<W1A='5S8F5R:6-H="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E52
M3#HB"FUS9W-T<B`B061R97-S93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5
M9V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M56MR86EN92(*;7-G<W1R(")5:W)A:6YE(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#(X"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(D%U9B!D87,@5D93+59E<GIE:6-H;FES(&MO
M;FYT92!N:6-H="!Z=6=E9W)I9F9E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G
M<W1R("(B"B)$:64@>G5SY'1Z;&EC:&5N($)E;G5T>F5R:6YF;W)M871I;VYE
M;B!K;VYN=&5N(&)E:2!D97(@4F5G:7-T<FEE<G5N9R!N:6-H="`B"B)H:6YZ
M=6;\9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,SDU"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"B)$:64@
M6G5G<FEF9G-R96-H=&4@9OQR(&1I92!61E,M1&%T96D@7"(E<UPB(&MO;FYT
M96X@;FEC:'0@9V7D;F1E<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C0P,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M-#<Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*(D1I92!:
M=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`E<R\E<R!K;VYN=&5N
M(&YI8VAT(&=EY&YD97)T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('1O("5S+B(*;7-G<W1R(")%<R!K86YN(&YI8VAT(&EN(%9E<GIE
M:6-H;FES("5S(&=E=V5C:'-E;'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(D1I92!'
M<O;?92!V;VX@7"(E<UPB(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C4@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HY-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(D1I92!'<O;?
M92!V;VX@7"(E<R\E<UPB(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B5F5R
M8FEN9'5N9R!Z=6T@4U%,(%-E<G9E<B!K86YN(&YI8VAT(&AE<F=E<W1E;&QT
M('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,@IM
M<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(E-3
M3"U697)B:6YD=6YG(&MO;FYT92!N:6-H="!H97)G97-T96QL="!W97)D96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C0Q(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,C,S(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(T-@IM
M<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(D1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT(&MO<&EE<G0@=V5R9&5N+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@7"(E<UPB(&MO;FYT92!N:6-H
M="!A;F=E;&5G="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S<P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-CD*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")$87,@5D93
M+59E<GIE:6-H;FES(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R,PIM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D1A
M<R!61E,M5F5R>F5I8VAN:7,@7"(E<UPB(&MO;FYT92!N:6-H="!A;F=E;&5G
M="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G
M<W1R("),965R92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E
M<F1E;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H
M<#HW-0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-3(*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C@R
M"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")$
M:64@1&%T96X@:V]N;G1E;B!N:6-H="!D96MO;7!R:6UI97)T('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(S,2!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(EPB)7-<(B!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R
M9&5N+"!D87,@5F5R>F5I8VAN:7,@:7-T(&YI8VAT(&QE97(N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E
M<RXB"FUS9W-T<B`B7"(E<UPB(&MA;FX@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-#<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-3`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S@Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B5S(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC:&YI<R!I
M<W0@;FEC:'0@;&5E<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HT,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C0P-PIM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+B(*;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N:6-H
M="!R96MU<G-I=B!G96SV<V-H="!W97)D96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S4S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T-B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S4T"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B1&%S(%9&4RU697)Z96EC:&YI<R!K
M;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#<U(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#@W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN:7,@
M:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D1I
M92!61E,M1&%T96D@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D
M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$Y(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,T"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$W
M.0HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@V(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,S@*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C0T-@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(D1A<R!61E,M5F5R>F5I8VAN
M:7,@7"(E<UPB(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*
M;7-G<W1R(")$87,@5D93(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H
M="!W97)D96XZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#0V"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+B(*;7-G<W1R(")$87,@86MT=65L;&4@5F5R>F5I8VAN:7,@:V]N;G1E
M(&YI8VAT(&)E<W1I;6UT('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(")$:64@6F5R=&EF:6MA=&1E
M=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N('=E<F1E;B(*"B,Z(&9R
M86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")$
M97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96XN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Q(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(Q-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3DX(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,#,*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")$
M:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!V97)S8VAO8F5N('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-C<T(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,3(R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B1&EE(%9&4RU$871E:2!<(B5S7"(@:V]N;G1E(&YI8VAT(&=E
M]F9F;F5T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR.3,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38P"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B1&EE
M(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@>G5M($)E<V-H<F5I8F5N(&=E]F9F
M;F5T('=E<F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX
M-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-#`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.CDU"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R
M97-S960@87)C:&EV92XB"FUS9W-T<B`B1&%S($%R8VAI=B!K;VYN=&4@;FEC
M:'0@9V7V9F9N970@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX-#,*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(D1I92!61E,M1&%T96D@:V]N;G1E(&YI
M8VAT(&=E;&5S96X@=V5R9&5N("AF:6QE<VEZ92@I(&9E:&QG97-C:&QA9V5N
M*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#<X"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@
M(D1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT(&=E;&5S96X@=V5R9&5N("AS
M:7IE*"D@9F5H;&=E<V-H;&%G96XI+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA
M8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(D1I92!$871E:2!K;VYN=&4@
M;FEC:'0@9V5L97-E;B!W97)D96XZ("(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C8Y,0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O
M;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")$87,@=F9S<F]O="U697)Z96EC:&YI
M<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,30V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A
M;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"B(E<R!K;VYN=&4@;FEC:'0@;F%C
M:"`E<R!U;6)E;F%N;G0@=V5R9&5N.B!$87,@6FEE;'9E<GIE:6-H;FES(&5X
M:7-T:65R="`B"B)B97)E:71S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,T,@IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(")$87,@5D93+59E<GIE:6-H;FES(&MO;FYT92!N
M:6-H="!U;6)E;F%N;G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(D1A<R!61E,M5F5R
M>F5I8VAN:7,@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XZ("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@P(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")$:64@5D93
M+41A=&5I(%PB)7-<(B!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,S(@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")$:64@
M5D93+41A=&5I("5S+R5S(&MO;FYT92!N:6-H="!U;6)E;F%N;G0@=V5R9&5N
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S@Q(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR,3(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0V,R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S,T"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-38*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(D1I92!6
M1E,M1&%T96D@:V]N;G1E(&YI8VAT('5M8F5N86YN="!W97)D96XN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B
M7")M:VES;V9S7"(@:V]N;G1E(&YI8VAT(&%U<V=E9OQH<G0@=V5R9&5N+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*
M;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M(@IM<V=S='(@(D1I97-E<R!7;W)D+41O:W5M96YT(&SD<W-T('-I8V@@;FEC
M:'0@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$X
M,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('1R:6=G97(@9G)E
M92]B=7-Y('5P9&%T92!F;W(@)7,B"FUS9W-T<B`B(@HB1&EE($9R96DO1V5B
M=6-H="U);F9O<FUA=&EO;F5N(&;\<B`E<R!K;VYN=&5N(&YI8VAT(&%K='5A
M;&ES:65R="!W97)D96XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C$W."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$X,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")$:64@5D93+41A=&5I(%PB)7-<(B!K;VYN=&4@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$X.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y
M*"D@9F%I;&5D*2XB"FUS9W-T<B`B1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC
M:'0@9V5S8VAR:65B96X@=V5R9&5N("AC;W!Y*"D@9F5H;&=E<V-H;&%G96XI
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(Y-R!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38U"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-S`*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R(")$:64@5D93+41A=&5N(&MO;FYT96X@
M;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-3,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@
M<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@HB1&EE(%9&4RU$
M871E:2!K;VYN=&4@;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N+"!D87,@4W!E
M:6-H97)P;&%T>BU+;VYT:6YG96YT("(*(G?\<F1E(/QB97)S8VAR:71T96XN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E5N=&5R<W1R:6-H96XB"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`BQ&YD97)U;F=E;B!R_&-K9^1N9VEG(&UA8VAE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G
M:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(DUA8VAT(&1I
M92!L971Z=&4@06MT:6]N('+\8VMGY&YG:6<B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C@*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#(W"FUS9VED(")5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R(")5
M;F?\;'1I9V4@4OQC:VUE;&1U;F<@=F]M(%-E<G9E<B!B96EM($AE<G-T96QL
M96X@9&5R(%9E<F)I;F1U;F<Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-#$U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C0R,0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@(@IM<V=S='(@(E5N97)W87)T971E($%N='=O<G0@9&5S
M(%-E<G9E<G,@875F.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(").
M:6-H="!Z=6=E;W)D;F5T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*
M;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5;FEC;V1E("A55$8M
M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B
M"FUS9W-T<B`B5F5R96EN:6=T92!!<F%B:7-C:&4@16UI<F%T92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B5F5R96EN
M:6=T97,@2_9N:6=R96EC:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B5F5R96EN:6=T92!3=&%A=&5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)
M<VQA;F1S(@IM<V=S='(@(DML96EN97)E($%M97)I:V%N:7-C:&4@W&)E<G-E
M96EN<V5L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET<R(*;7-G<W1R(")%
M:6YH96ET96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N:VYO
M=VXB"FUS9W-T<B`B56YB96MA;FYT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P
M:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(E5N8F5K86YN=&4@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO
M=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B56YB
M96MA;FYT92!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D5S('=U<F1E(&5I;B!U;F)E
M:V%N;G1E<B!/<G0@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B56YB96MA;FYT97(@0F5N
M=71Z97)N86UE(&]D97(@4&%S<W=O<G0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("),:6YK('9O;2!A:W1U
M96QL96X@16QE;65N="!E;G1F97)N96XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M261E;G1I='DN<&AP.C,P-`IM<V=I9"`B56YN86UE9"(*;7-G<W1R(")5;F)E
M;F%N;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM
M<V=S='(@(B(*(D%U<R!3:6-H97)H96ET<V=R_&YD96X@9/QR9F5N('5N875T
M;W)I<VEE<G1E(%-K<FEP=&4@;FEC:'0@875S8VAN96ED96XL("(*(FMO<&EE
M<F5N('5N9"!E:6YF_&=E;BX@2VQI8VME;B!3:64@875F($]++"!U;2!E:6YE
M;B!(:6YW96ES(&%U9B!M;WII;&QA+F]R9R`B"B)A;F=E>F5I9W0@>G4@8F5K
M;VUM96XL(&1E<B!B97-C:')E:6)T+"!W:64@4VEE(&5I;F5M(%-K<FEP="!D
M96X@6G5G<FEF9B!A=68@(@HB9&EE(%IW:7-C:&5N86)L86=E(&5R;&%U8F5N
M(&OV;FYE;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")&
M87)B92!Z=7+\8VMS971Z96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM
M<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(D5R=V5I=&5R
M=6YG(&YI8VAT('5N=&5R<W3\='IT(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")!:W1U86QI<VEE<G5N9R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B5S(&%K='5A;&ES:65R
M96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS
M9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")"96YU='IE<B!A:W1U86QI<VEE
M<F5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<
M(B!W=7)D92!A:W1U86QI<VEE<G0N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S
M='(@(D%K='5A;&ES:65R=6YG<W-K<FEP="!G96SV<V-H="XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3<W(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")(;V-H
M;&%D96XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@U"FUS9VED(")5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BXB"FUS9W-T<B`B(@HB1&EE($MO;F9I9W5R871I;VYS9&%T96EE;B!A
M;&QE<B!!;G=E;F1U;F=E;B!W=7)D96X@875F(&1E;B!397)V97(@(@HB:&]C
M:&=E;&%D96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R(")'<BX@;&%T96EN:7-C:&4@0G5C:'-T86)E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B1W(N('+V
M;6ES8VAE(%IA:&QE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB
M"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S
M92!#=7)R96YT.B`E<R(*;7-G<W1R(")!:W1U96QL92!B96YU='IE;CH@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")34TP@8F5N=71Z96XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@;F%M
M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G
M<W1R("(B"B)":71T92!A=7-F_&QL96XL('=E;FX@4VEE(&5I;F5N(&%N9&5R
M96X@0F5N=71Z97)N86UE;B]087-S=V]R="!F_'(@9&5N($E-4U`M(@HB4V5R
M=F5R(&AA8F5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B0F5N=71Z97(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB
M"FUS9W-T<B`B0F5N=71Z97(@)7,@:7-T(&;\<B`E<R!N:6-H="!A=71O<FES
M:65R="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B0F5N=71Z97)V97)W86QT=6YG(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@
M3W!T:6]N<R(*;7-G<W1R(")"96YU='IE<F5I;G-T96QL=6YG96XB"@HC.B!S
M:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R
M(")"96YU='IE<G)E9VES=')I97)U;F<B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R(")$:64@0F5N=71Z97)R96=I<W1R:65R=6YG
M('=U<F1E(&%U9B!D:65S96T@4WES=&5M(&1E86MT:79I97)T+B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N
M;W0@9F]U;F0B"FUS9W-T<B`B0F5N=71Z97)K;VYT;R!N:6-H="!G969U;F1E
M;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,T
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S
M='(@(D)E;G5T>F5R;F%M92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E
M<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")$97(@0F5N=71Z97)N86UE
M(%PB)7-<(B!E>&ES=&EE<G0@8F5R96ET<RXB"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R(")"
M96YU='IE<FYA;64Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z
M.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")"96YU='IE<FYA;64Z("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(D)E;G5T>F5R(&1E<R!3>7-T
M96US.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T
M<B`B57-B96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$W,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S$*;7-G:60@(E9&
M4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1A<R!61E,M
M5F5R>F5I8VAN:7,@97AI<W1I97)T(&YI8VAT+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%B
M=V5S96YH96ET(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS
M9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@
M(E!A<W-E;F1E(&=E9G5N9&5N92!/<G1E.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`B1_QL=&EG:V5I="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E
M<R!F<F]M(&YO=RXB"FUS9W-T<B`B5V5R="!I;B!-:6YU=&5N('9O;B!J971Z
M="!A;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")6
M86QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T
M<B`B1&5R(%=E<G0@:7-T(/QB97(@9&5R(&UA>&EM86QE;B!,Y&YG92!V;VX@
M)7,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C@T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S,S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")6
M86QU97,B"FUS9W-T<B`B5V5R=&4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3(W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,#0*;7-G:60@
M(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")797)T92P@875S(&1E
M;F5N(&%U<V=E=^1H;'0@=V5R9&5N(&MA;FXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R
M(")$<F5H96YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI
M<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T
M<B`B(@HBW&)E<G!R_&9U;F<@9F5H;&=E<V-H;&%G96X@+2!D:65S92!.86-H
M<FEC:'0@:_9N;G1E(&UA;FEP=6QI97)T('=O<F1E;B!S96EN+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S
M:6]N(@IM<V=S='(@(E9E<G-I;VXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R
M<VEO;G-K;VYT<F]L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*
M;7-G<W1R(")!=7-R:6-H='5N9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B
M"FUS9W-T<B`B5F5R=&EK86QE<B!);FYE;F%B<W1A;F0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B5F5R=&EK86PZ(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(E9E<GD@2&EG:"(*;7-G
M<W1R(")396AR($AO8V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA
M;2(*;7-G<W1R(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA
M;65S:7-C:"`H5DE30TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.CDW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM
M<V=S='(@(B5S(&%N>F5I9V5N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")%
M:6YE(&5X=&5R;F4@5V5B<V5I=&4@86YZ96EG96XB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")!;GIE:6=E;B!A;',@)7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G
M<W1R(")"<FET:7-C:&4@2G5N9V9E<FYI;G-E;&XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R(")!;65R:6MA
M;FES8VAE($IU;F=F97)N:6YS96QN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,3$*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B4VEC:'0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL
M:71Y.B`B"FUS9W-T<B`B4VEC:'0Z("(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92!)=&%L:65N('!E
M<B!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R
M(")705).54Y'(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!
M3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E=!4DY53D<A(2$@3-930TA%3B!3
M244@1$%3(%-+4DE05"!-04Y514Q,($%54R`E<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(
M5%10(@IM<V=S='(@(E=)3B#\8F5R($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@=6YD($9U
M='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HY
M-0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")787)N=6YG(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B
M"FUS9W-T<B`B36DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B5V5T=&5R=F]R
M:&5R<V%G92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*
M;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")7971T
M97)D871E;B!V;VXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")7
M96(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")7
M96(@4VET92(*;7-G<W1R(")796)S:71E(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S
M='(@(E?V8VAE;G1L:6-H(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5VEL;&MO;6UE;B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O
M("5S(@IM<V=S='(@(E=I;&QK;VUM96X@8F5I("5S(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@
M(E=I;&QK;VUM96XL("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(E=E<W1E=7)O
M<.1I<V-H("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B5V5S
M=&5U<F]PY&ES8V@@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")797-T97)N(%-A:&%R82(*;7-G<W1R(")797-T<V%H87)A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/R(*;7-G<W1R(")796QC:&4@06YW96YD=6YG('-O;&P@)7,@;F%C:"!D96T@
M06YM96QD96X@86YG97IE:6=E;C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\B"FUS9W-T<B`B5V5L8VAE<R!4<F5N;GIE:6-H96X@=VER9"!V97)W
M96YD970_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B5V5L
M8VAE($%N9OQH<G5N9W-Z96EC:&5N('=E<F1E;B!V97)W96YD970_(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C4*;7-G
M:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES+4%U
M<W1R86QI82U+87)T92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I
M9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(E=E;&-H92!0:&%S96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@
M(E=E;&-H92!0;'5G:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@<V]L;&5N
M(&%K=&EV:65R="!W97)D96X_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`B0G)E:71E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM
M<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(D)R96ET92!I;B!#
M4U,M16EN:&5I=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS9W-T
M<B`B0G)E:71E(&1E<R`E<RU-96[\<R!L:6YK<R`H=VER:W-A;2!N86-H(&1E
M<B!NY&-H<W1E;B!!;FUE;&1U;F<I.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@
M=&%B;&4B"FUS9W-T<B`B5&%B96QL96YB<F5I=&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@
M=6YI="(*;7-G<W1R(")%:6YH96ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R
M(")"<F5I=&4Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM
M<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV.0IM<V=I9"`B5VEN9"(*;7-G<W1R(")7:6YD(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E=I
M;F0@16%R;'DB"FUS9W-T<B`B1G+\:"!7:6YD(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M(")7:6YD9V5S8VAW:6YD:6=T:V5I="!I;B!+;F]T96XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5VEN9#HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"FUS9VED(")7
M:6YD.B`B"FUS9W-T<B`B5VEN9#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B5V5I<VAE:70B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*
M;7-G<W1R(")7=6YS8VAZ971T96PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B07)B96ET(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K
M($%D9')E<W,B"FUS9W-T<B`B061R97-S92!G97-C:.1F=&QI8V@B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E;&5F;VX@9V5S8VCD9G1L:6-H(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B1F%L<V-H92!!;GIA:&P@86X@1F5L9&5R;B!I
M;B!:96EL92`E9"X@)60@97)W87)T970L("5D(&=E9G5N9&5N+B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(D9A;'-C:&4@06YZ86AL(&%N($9E;&1E<FXN("5D
M(&5R=V%R=&5T+"`E9"!G969U;F1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F
M<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B56YG
M_&QT:6=E<B!/9F9S970@)60@8F5I;2!,97-E;B!D97(@5D93+41A=&5I+B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*;7-G:60@(E@M4F5F
M(@IM<V=S='(@(E%U97)V97)W96ES92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R
M86EN=',B"FUS9W-T<B`B6#4P.78S($=E;F5R96QL92!%:6YS8VARY&YK=6YG
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G
M:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S
M($5R=V5I=&5R=&5R(%-C:&S\<W-E;'IW96-K(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S($%L=&5R;F%T:79E
M<B!.86UE(&1E<R!:97)T:69I:V%T:6YH86)E<G,B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S($ED96YT:73D="!D
M97,@6F5R=&EF:6MA='-C:&S\<W-E;',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B6#4P.78S($5R=V5I=&5R=6YG96XB"@HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B2DHB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(EE965DB
M"FUS9W-T<B`B2DI*2B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(EEA
M:&]O(2!+87)T92(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")*Y&AR;&EC:"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM
M<V=I9"`B665S(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*
M;7-G<W1R(")*82P@:6-H('-T:6UM92!Z=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@
M5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C
M:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"B)3:64@8F5F:6YD96X@<VEC:"!I
M;2!497AT;6]D=7,N($)E;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@
M:6X@9&5N("(*(E=94TE724<M36]D=7,@>G4@=V5C:'-E;&XN(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B4VEE(&3\<F9E;B!N
M:6-H="!M96AR(&%L<R`E9"!";/9C:V4@97)S=&5L;&5N+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,30Q-0IM<V=I9"`B66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"XB"FUS9W-T<B`B4VEE('-I;F0@;FEC:'0@86YG96UE
M;&1E="XB"@HC.B!F<F%M97=O<FLO4')E9G,O261E;G1I='DN<&AP.C,Q,`IM
M<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y
M;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B4VEE(&3\<F9E;B!D87,@6F5I8VAE
M;B`G7%PG(&YI8VAT(&EN($EH<F5M($YA;65N('9E<G=E;F1E;BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y.3,*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RXB"FUS9W-T<B`B4VEE(&AA8F5N(&ME:6YE(&?\;'1I
M9V4@12U-86EL+4%D<F5S<V4@86YG96=E8F5N+B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R
M("(B"B)3:64@:&%B96X@:V5I;F4@1F5L9&5R(&%U<R!D96X@:6UP;W)T:65R
M=&5N($1A=&5N(&1E;B!E;G1S<')E8VAE;F1E;B!&96QD97)N("(*(FEN("5S
M('IU9V5O<F1N970N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W
M"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(E-I
M92!W=7)D96X@86)G96UE;&1E="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@HB4VEE(&W\<W-E;B!E:6YE(&?\;'1I9V4@36]B:6QT
M96QE9F]N;G5M;65R(&%N9V5B96XL(&YU<B!A=7,@6F%H;&5N('5N9"!G9V8N
M("(*(F5I;F5M(%PB*UPB(&;\<B!I;G1E<FYA=&EO;F%L92!6;W)W86AL96X@
M8F5S=&5H96YD+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*
M;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S
M='(@(E-I92!M_'-S96X@96EN96X@9_QL=&EG96X@5V5R="!A;F=E9V5B96XN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED
M(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S
M92!3:6=N=7!S+B(*;7-G<W1R("(B"B)3:64@;?QS<V5N(&5I;B!$871A5')E
M92U"86-K96YD(&MO;F9I9W5R:65R96XL('5M(%)E9VES=')I97)U;F=E;B!V
M97)W96YD96X@(@HB>G4@:_9N;F5N+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-#8U"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6X@5D93+4)A8VME;F0@
M:V]N9FEG=7)I97)E;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHQ,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S
M='(@(E-I92!M_'-S96X@9&%S(%!R;V)L96T@8F5S8VAR96EB96XL('5M(&1E
M;B!"97)I8VAT(&%B>G5S8VAI8VME;BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B
M4VEE(&W\<W-E;B!D:64@55),(&%N9V5B96XL(&%U9B!D:64@9&EE<V5R($QI
M;FL@=F5R=V5I<V5N('-O;&PB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+B(*;7-G<W1R(")3:64@;?QS<V5N(&5R<W0@9&5N('IU(&5N
M=&9E<FYE;F1E;B!397)V97(@875S=^1H;&5N+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B(@HB4VEE(&W\<W-E;B!E:6YE;B!"96YU
M='IE<FYA;65N(&%N9V5B96XL(&1E<W-E;B!$871E;B!G96SV<V-H="!W97)D
M96X@<V]L;&5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B
M4VEE(&W\<W-E;B!E:6YE;B!Z=2!L]G-C:&5N9&5N($)E;G5T>F5R;F%M96X@
M86YG96)E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE
M;B!H:6YZ=7IU9OQG96YD96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@=7!D871E+B(*;7-G<W1R(")3:64@;?QS<V5N(&1E
M;B!Z=2!A:W1U86QI<VEE<F5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BXB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2XB"FUS9W-T<B`B4VEE(&W\<W-E;B!E:6YE($%K=&EO;B!A;F=E8F5N+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(E-I92!M_'-S96X@96EN96X@;F5U96X@2V%T96=O<FEE;F%M
M96X@86YG96)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")3:64@;?QS<V5N
M(&5I;F4@271A;&EE;FES8VAE(%1E;&5F;VYN=6UM97(@86YG96)E;B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B26AR92`E<RU397-S:6]N(&ES="!A8F=E;&%U
M9F5N+B!":71T92!M96QD96X@4VEE('-I8V@@97)N975T(&%N+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M
M86EL($%D9')E<W,B"FUS9W-T<B`B26AR92!%+4UA:6PM061R97-S92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#<*;7-G:60@(EEO=7(@1G)O;3H@
M861D<F5S<SHB"FUS9W-T<B`B26AR92!6;VXZ($%D<F5S<V4Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEH
M<F4@06YG86)E;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(DEH<F4@26YT97)N971A9')E<W-E
M(&AA="!S:6-H(&=EY&YD97)T+"!S96ET(%-I92!D:64@)7,M4VET>G5N9R!B
M96=O;FYE;B`B"B)H86)E;BX@6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET
M(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G
M<W1R(")):'(@3F%M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D
M+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@
M9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O
M("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO
M=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K
M96YD+B(*;7-G<W1R("(B"B)):'(@075T:&5N=&EF:7II97)U;F=S<WES=&5M
M(&5R;&%U8G0@:V5I;B!(:6YZ=6;\9V5N('9O;B!N975E;B!"96YU='IE<FXN
M("(*(E=E;FX@4VEE($AO<F1E(&)E;G5T>F5N(&WV8VAT96XL('5M($EH<F4@
M0F5N=71Z97(@>G4@=F5R=V%L=&5N+"!M_'-S96X@4VEE("(*(F5I;F5N(&%N
M9&5R96X@075T:&5N=&EF:7II97)U;F=S=')E:6)E<B!B96YU='IE;BXB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I
M<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB26AR
M($%U=&AE;G1I9FEZ:65R=6YG<W-Y<W1E;2!E<FQA=6)T(&1A<R!!;GIE:6=E
M;B!D97(@0F5N=71Z97(@;FEC:'0L(&]D97(@(@HB9&EE<V4@3?9G;&EC:&ME
M:70@=W5R9&4@875S9V5S8VAA;'1E="XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)):'(@
M0G)O=W-E<B!H870@<VEC:"!A;G-C:&5I;F5N9"!G9>1N9&5R="!S96ET(%-I
M92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B`B"B)H86)E;BX@6G5M(%-C:'5T
M>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD
M96XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3<*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`B26AR($)R;W=S97(@=6YT97)S=/QT>G0@9&EE<V4@1G5N:W1I;VX@;FEC
M:'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I
M;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R
M:6YT+B(*;7-G<W1R("(B"B)):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S
M92!$<G5C:V9U;FMT:6]N(&YI8VAT+B!":71T92!D<OQC:V5N(%-I92!3=')G
M+R(*(DMO;6UA;F1O("L@4"!U;2!Z=2!D<G5C:V5N+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-3,*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO
M;F4Z(@IM<V=S='(@(DEH<F4@86MT=65L;&4@6F5I='IO;F4Z(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(DEH<F4@4W1A;F1A<F1I
M9&5N=&ETY'0@=W5R9&4@9V7D;F1E<G0N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$U,PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G
M<W1R(")):')E(%-T86YD87)D:61E;G1I=.1T.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ.38*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R
M(")):'(@=F]L;'-TY&YD:6=E<B!.86UE.B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B26AR(%IU9V%N9R!I<W0@86)G96QA=69E;BXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(DEH
M<B!N975E<R!087-S=V]R="!F_'(@)7,@;&%U=&5T.B`E<R(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES
M('-E<W-I;VXN(@IM<V=S='(@(DEH<F4@16EN<W1E;&QU;F=E;B!W=7)D96X@
M9OQR(&1I92!$875E<B!D:65S97(@4VET>G5N9R!G97-P96EC:&5R="XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")):')E($5I
M;G-T96QL=6YG96X@=W5R9&5N(&=E<W!E:6-H97)T+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"FUS9VED(")9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T(@IM<V=S='(@(DEH<B!087-S=V]R="!W=7)D92!Z=7+\
M8VMG97-E='IT(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#`*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"B)):'(@4&%S<W=O<G0@=W5R9&4@>G5R_&-K9V5S
M971Z="X@4G5F96X@4VEE($EH<F4@12U-86EL+4YA8VAR:6-H=&5N(&%B('5N
M9"`B"B)M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A<W-W;W)T
M(&%N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,PIM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B26AR(%!A<W-W
M;W)T(&ES="!A8F=E;&%U9F5N+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T
M<B`B26AR92!397)V97(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M675G;W-L879I82(*;7-G<W1R(")*=6=O<VQA=VEE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@
M(EIA:7)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@
M(E-A;6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S
M='(@(E-I;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS
M9VED(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT
M7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HR,#,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(
M:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");6FET871T97AT('9E<G-T96-K
M96Y=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B
M;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U!R;V)L96UB97)I8VAT72(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM::71A='1E>'0@86YZ96EG
M96X@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HR,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6UII=&%T=&5X="!A
M;GIE:6=E;B`M("5S(%IE:6QE;ETB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E
M<UTB"FUS9W-T<B`B6UIE:6QE("5S('9O;B`E<UTB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B7T%D;6EN:7-T<F%T:6]N(@H*(SH@;&EB+V%P:2YP:'`Z,C(S"FUS
M9VED(")?0TQ)(@IM<V=S='(@(D)E7V9E:&QS>F5I;&4B"@HC.B!L:6(O87!I
M+G!H<#HR,#<*;7-G:60@(E]$871A5')E92(*;7-G<W1R(")?1&%T851R964B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(EIE:6QE(%]L
M]G-C:&5N(@H*(SH@;&EB+V%P:2YP:'`Z,3DY"FUS9VED(")?1W)O=7!S(@IM
M<V=S='(@(E]'<G5P<&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")?0FEL9&5I9V5N<V-H869T96XN+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G
M(&EN(@IM<V=S='(@(D%N7VUE;&1E;B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(D%B
M7VUE;&1E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S
M='(@(DQI;FL@7V)E87)B96ET96XN+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R(")?
M16EN<W1E;&QU;F=E;B(*"B,Z(&QI8B]A<&DN<&AP.C(P,PIM<V=I9"`B7U!E
M<FUI<W-I;VYS(@IM<V=S='(@(E]296-H=&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R("),:6YK(%]E;G1F97)N96XN+BXB"@HC
M.B!L:6(O87!I+G!H<#HQ.3$*;7-G:60@(E]3971U<"(*;7-G<W1R(")?2V]N
M9FEG=7)A=&EO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B7U1A8F5L;&5N96EG96YS8VAA9G1E;BXN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$Y-0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(E]"96YU='IE
M<B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34Q"FUS9VED(")A
M9&1R97-S(&)O;VLB"FUS9W-T<B`B061R97-S8G5C:"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@
M=6YK;F]W;B(*;7-G<W1R(")!9')E<W-A="!U;F)E:V%N;G0B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDT,PIM<V=I9"`B8V%L96YD87(B"FUS
M9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V,`HC+"!P:'`M9F]R;6%T"FUS9VED(")C
M86QM(@IM<V=S='(@(G=I;F1S=&EL;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U
M="!F:6QE(@IM<V=S='(@(D%U<V=A8F5D871E:2!K;VYN=&4@;FEC:'0@97)S
M=&5L;'0@=V5R9&5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(D5I
M;F=A8F4@:V%N;B!N:6-H="!G9?9F9FYE="!W97)D96XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#`*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B:VQI8VME;B!3:64@:&EE<B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B56YG_&QT:6=E($)E;G5T>G5N9R!D97(@
M2V]M;6%N9&]Z96EL92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@
M(DMO;F9I9W5R871I;VYS9F5H;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE
M(&UI<W-I;F<B"FUS9W-T<B`B2W)I=&ES8VAE(%-Y<W1E;61A=&5I(&9E:&QT
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G
M:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(D1A=&5N9F]R;6%T9F5H
M;&5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B
M961I="(*;7-G<W1R(")B96%R8F5I=&5N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R(")%:6YT<F%G(&YI8VAT(&=E9G5N9&5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S4*;7-G:60@(F9A;&QI;F<B
M"FUS9W-T<B`B9F%L;&5N9"(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@Y-@IM<V=I9"`B9FEL92(*;7-G<W1R(")$871E:2(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<V(&QI8B]";&]C:R]M971A<BYP:'`Z,S8R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S@X"B,L('!H<"UF;W)M870*;7-G:60@
M(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B875S("5S("@E
M<RD@;6ET("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")B]FEG(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I9"`B:#HB
M"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA
M;64@=6YK;F]W;B(*;7-G<W1R(")(;W-T;F%M92!U;F)E:V%N;G0B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")S;V9O<G0B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-"!A9&UI;B]S971U<"]D:69F+G!H<#HW-@IM
M<V=I9"`B:6YL:6YE(@IM<V=S='(@(DEN;&EN92(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@
M97)R;W(B"FUS9W-T<B`B16EN+2]!=7-G86)E9F5H;&5R(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L
M('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(DEN=&5R;F5R(%-O9G1W87)E9F5H
M;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z
M,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("):96EL96Y=(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L
M('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL
M92!M86MI;F<@25-/+B(*;7-G<W1R(")M:VES;V9S+49E:&QE<F-O9&4@)60@
M8F5I(&1E<B!%<G-T96QL=6YG(&1E<R!)4T\M06)B:6QD97,N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I9"`B
M;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(X-2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<T"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#,*;7-G:60@(FYA;64B"FUS
M9W-T<B`B3F%M92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*;7-G
M:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N:6-H="!I;7!L96UE;G1I
M97)T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P
M"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(DYO8V@@;FEC
M:'0@:6UP;&5M96YT:65R="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3,U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(DYO=&EZ8FQO8VLB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(E!R;WIE;G0B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES
M<VEO;B!D96YI960B"FUS9W-T<B`B6G5G<FEF9B!V97)W96EG97)T(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(E!I>&5L(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")296UO=&5F96AL97(@:6T@4')O=&]K
M;VQL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S<*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S=&5I9V5N9"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E
M('5N879A:6QA8FQE(@IM<V=S='(@(E-E<G9I8V4@;FEC:'0@=F5R9OQG8F%R
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@
M9&EF9F5R96YC97,B"FUS9W-T<B`B56YT97)S8VAI961E(&%N>F5I9V5N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,R96UA
M:6P@_&)E<B!(5%10(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-@IM<V=I9"`B<W1E
M861Y(@IM<V=S='(@(F=L96EC:&)L96EB96YD(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R(")3>7-T96UF96AL97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDU.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(D%U9F=A8F5N
M;&ES=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V
M-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B5F]R_&)E<F=E
M:&5N9&5R($9E:&QE<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B9V5B96X@4VEE(&1A
M<R!087-S=V]R="!E:6X@>G=E:71E<R!-86P@>G5R($)E<W3D=&EG=6YG(&5I
M;B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8T(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<V"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I960B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA
M;65D(@IM<V=S='(@(G5N8F5N86YN="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S
M96QE8W0B"FUS9W-T<B`B8F5N=71Z97)D969I;FEE<G0B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D
M(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B8CHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VYL7TY,+G!O
M````````````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#<S-#8Q-B`Q,#4Q-30S-#$T,B`P,3<U,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R!(;W)D92!$=71C:"!T<F%N
M<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$M,C`P-B!*86X@2W5I<&5R
M<RX*(R!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL
M/BP@,C`P,2TR,#`V+@HC(`IM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXQ+C$M8W9S7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#8M,#,M,3(@,#`Z,S$K,#$P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-BTP,RTQ,R`R,CHT,"LP,3`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($IA;B!+=6EP97)S(#QJ<FMU:7!E<G-`;&%U=V5R<V-O;&QE9V4N;FP^
M7&XB"B),86YG=6%G92U496%M.B!$=71C:"`\:3$X;D!L:7-T<RYH;W)D92YO
M<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G
M;RDB"FUS9W-T<B`B("@E<R!D86=E;B!G96QE9&5N*2(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3,X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A3;F5L=&]E=',@)7,I(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H8FEN;F5N("5S(&1A9V5N
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H
M=&]D87DI(@IM<V=S='(@(B`H=F%N9&%A9RDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@
M*&UO<F=E;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AG:7-T97)E;BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@;W`@(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&ES
M(&=E96X@9&ER96-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR
M-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED
M(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&ES(&=E96X@9V5L9&EG92!K975Z
M92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q
M,`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&ES(&YI
M970@9V5C;VYF:6=U<F5E<F0@:6X@:&5T($AO<F1E(')E9VES=&5R+B(*"B,Z
M(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@
M(EPB)7-<(B!T<F5E('=E97)G979E<B!N:65T(&=E=F]N9&5N+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB(&%A;B!H970@9W)O97!E;G-Y<W1E96T@=&]E9V5V;V5G9"XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M
M+B(*;7-G<W1R(")<(B5S7"(@86%N(&AE="!R96-H=&5N<WES=&5E;2!T;V5G
M979O96=D+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B5S7"(@:7,@;FEE="!A
M86YG96UA86MT.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L
M;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"(&=E8G)U:6MT('9A;B`E
M+C)F34(@=&]E9V5S=&%A;B`H)2XR9B4E*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@
M86YD("5S(@IM<V=S='(@(B5D("5S(&5N("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S
M<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B)60@9&%G96X@=&]T('5W('=A8VAT
M=V]O<F0@=F5R=F%L="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"UD86<@=F]O<G5I='II8VAT(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T
M:6-E(@IM<V=S='(@(B5S("T@3W!M97)K:6YG(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@=FEN9V5R869D<G5K(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($]N
M9&5R:&]U9'-W97)K>F%A;6AE9&5N("T@0F5V97-T:6=I;F<B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@
M26YS=&5L;&5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P(@IM<V=S='(@
M(B5S(&EN<V-H<FEJ=F5N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N
M="(*;7-G<W1R("(E<R!G96)R=6EK97)S;W9E<F5E;FMO;7-T(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW-3`*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&)E<W1A870@
M86PN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#8*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B)7,@;W`@
M)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E
M<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!I<R!G97)E960@
M;VT@;VYD97)S=&%A;F1E(&=E<V5L96-T965R9&4@;VYD97)H;W5D<W=E<FMZ
M86%M:&5D96X@=6ET('1E("(*(G9O97)E;BX@5FEN:R!D92!B97=E<FMI;F<H
M96XI(&%A;B!D:64@=2!O<"!D:70@;6]M96YT('=I;'0@=6ET=F]E<F5N+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:7,@=F5R96ES
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71E;B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N:65T
M(&=E=F]N9&5N+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T
M<B`B)7,@=&]T("5S('9A;B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!"
M;V]K(@IM<V=S='(@(B5S)W,@861R97-B;V5K(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#
M86QE;F1A<B(*;7-G<W1R("(E<R=S(&%G96YD82(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@
M3F]T97!A9"(*;7-G<W1R("(E<R=S(&YO=&ET:65B;V5K(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!487-K;&ES="(*;7-G<W1R("(E<R=S('1A:V5N;&EJ<W0B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G
M<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H
M=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@
M;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N
M($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F
M('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@1&ET(&)E<FEC:'0@:V]M="!M:7-S
M8VAI96X@;FEE="!V86X@9&5G96YE(&1I92!H970@8F5W965R="!T92!Z:6IN
M+B!7965S("(*(G9O;W)Z:6-H=&EG(&)I:B!H970@:VQI:VME;B!O<"!L:6YK
M<R!I;B!H970@8F5R:6-H="!O9B!D92!A9GIE;F1E<B`B"B)P97)S;V]N;&EJ
M:V4@:6YF;W)M871I92!T92!S='5R96XN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@=VEN9'9L86=E;B`B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B
M"FUS9W-T<B`B+"!W:6YD=FQA9V5N("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:6%B96P@=F%N("5S('1O="`E
M<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW
M-#@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`V.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3(X"FUS
M9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@<V5L96-T97)E;B`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B,3(@=75R<W=E97)G879E(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R("(R-"!U
M=7)S=V5E<F=A=F4B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM
M<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@=75R<R(*"B,Z(&9R86UE=V]R
M:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R
M("(\5F]R:6=E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G:60@
M(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C
M:RXB"FUS9W-T<B`B165N(&1A=&%B87-E(&)A8VME;F0@:7,@=F5R96ES="!V
M;V]R(&1I="!B;&]K+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<Q"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M(")%<B!H965F="!Z:6-H(&5E;B!F871A;&4@9F]U="!V;V]R9V5D86%N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R(")%96X@;W!E;F)A<F4@4$=0('-L975T96P@:7,@=F5R
M96ES="!O;2!E96X@8F5R:6-H="!T92!C;V1E<F5N+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*(D5E;B!O<&5N8F%R92!01U`@<VQE=71E;"!I<R!V97)E
M:7-T(&]M(&5E;B!O;F1E<G1E:V5N9"!B97)I8VAT('1E('9E<FEF:>MR96XN
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(D5E;B!O<&5N8F%R92!01U`@<VQE=71E;"P@<')I
M=ND@4$=0('-L975T96P@96X@=V%C:'1W;V]R9')E9V5L('II:FX@=F5R96ES
M="`B"B)O;2!E96X@8F5R:6-H="!T92!D96-O9&5R96XN(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M(D5E;B!O<&5N8F%R92!01U`@<VQE=71E;"P@<')I=ND@4$=0('-L975T96P@
M96X@=V%C:'1W;V]R9')E9V5L('II:FX@=F5R96ES="`B"B)O;2!E96X@8F5R
M:6-H="!T92!O;F1E<G1E:V5N96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%
M96X@;W!E;F)A<F4@4R]-24U%('-L975T96PL('!R:7;I(%,O34E-12!S;&5U
M=&5L(&5N('=A8VAT=V]O<F1R96=E;"!Z:6IN("(*(G9E<F5I<W0@;VT@965N
M(&)E<FEC:'0@=&4@9&5C;V1E<F5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB165N
M(&]P96YB87)E(%,O34E-12!S;&5U=&5L+"!P<FEVZ2!3+TU)344@<VQE=71E
M;"!E;B!W86-H='=O;W)D<F5G96P@>FEJ;B`B"B)V97)E:7-T(&]M(&5E;B!B
M97)I8VAT('1E(&]N9&5R=&5K96YE;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%
M96X@;W!E;F)A<F4@4TU)344@<VQE=71E;"!I<R!V97)E:7-T(&]M(&5E;B!B
M97)I8VAT('1E(&-O9&5R96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(D)E
M=V]L:VEN9R!V;V]R(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM
M<V=S='(@(DQI8VAT92!R96=E;B!V;V]R(#$R+C`P('5U<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!2
M86EN(@IM<V=S='(@(E)E9V5N('9O;W(@,3(N,#`@=75R(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H
M;W=E<G,B"FUS9W-T<B`B0G5I96X@=F]O<B`Q,BXP,"!U=7(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N965U=V)U:65N('9O;W(@,3(N,#`@
M=75R(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-
M+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T
M<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B
M3W9E<B!D97IE(&5D:71O<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP
M.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")/=F5R+BXN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(D%B<V)O='1O;2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L
M92(*;7-G<W1R(")!8G-M:61D;&4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(E1O96=A;F<@9V5W96EG97)D(&)I:B!H
M970@;6%K96X@=F%N(%9&4R!D:7)E8W1O<GDN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5&]E9V%N9R!G97=E:6=E<F0@8FEJ
M(&AE="!M86ME;B!V86X@5D93(&)E<W1A;F0N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B06-C;W5N=&EN9F]R;6%T:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B06-C;W5N
M='=A8VAT=V]O<F0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G
M<W1R(")!8V-O=6YT(&)E=G)O<F5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B5F5R86YT
M=V]O<F1I;F<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R
M(")4;V5V;V5G96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G
M<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@
M(D-H:6QD(&=R;V5P('1O979O96=E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B0VAI;&0@
M<F5C:'0@=&]E=F]E9V5N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")(:65R('1O979O96=E;CHB
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q
M.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(").:65U=V4@9W)O97`@
M=&]E=F]E9V5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX
M-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@
M3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B3FEE=7<@<F5C:'0@=&]E=F]E9V5N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S
M7"(B"FUS9W-T<B`B165N(%PB8VAI;&1G<F]E<%PB(&%A;B!<(B5S7"(@=&]E
M=F]E9V5N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R!<(B5S7"(B"FUS9W-T<B`B165N(%PB8VAI;&1R96-H=%PB(&%A;B!<(B5S
M7"(@=&]E=F]E9V5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D
M9"!A(&YE=R!U<V5R.B(*;7-G<W1R(").:65U=V4@9V5B<G5I:V5R('1O979O
M96=E;CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(DMO;&]M('1O979O
M96=E;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*
M;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(").:65U=V4@;&5D96X@
M=&]E=F]E9V5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM
M<V=I9"`B061D('!A:7(B"FUS9W-T<B`B4&%A<B!T;V5V;V5G96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R
M(")(970@)7,@;65N=2!T;V5V;V5G96X@86QS(&5E;B!-;WII;&QA(%-I9&5B
M87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E9O96<@
M=&]E(&%A;B!A9')E<V)O96LZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B
M;V]K(@IM<V=S='(@(E9O96<@=&]E(&%A;B!M:6IN(&%D<F5S8F]E:R(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")'
M96)R=6EK97(@=&]E=F]E9V5N(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T
M96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R
M;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB7"(E<UPB(&%A;B!H970@<WES
M=&5E;2!T;V5G979O96=D+"!M86%R(&MO;B!G965N(&5X=')A("(*(FEN<V-H
M<FEJ=FEN9W-I;F9O<FUA=&EE('1O979O96=E;CH@)7,N(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")<(B5S
M7"(@86%N(&AE="!S>7-T965M('1O96=E=F]E9V0N(%4@:W5N="!N=2!A86YM
M96QD96XN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*
M;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B5&]E
M=F]E9V5N('9A;B!G96)R=6EK97)S(&ES('5I=&=E<V-H86ME;&0N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS
M9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97-B;V5K(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*;7-G:60@(D%D;6EN
M:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S
M='(@(D)E:&5E<B`M(')E8VAT96X@=F]O<B!A;F1E<F4@9V5B<G5I:V5R<R!I
M;G-T96QL96XB"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B0F5H965R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,PIM<V=I9"`B061S(@IM<V=S='(@(D%D=F5R=&5N=&EE<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F9V%N:7-T86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L8F%N:>LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<T"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L9V5R:6IE(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM
M<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG
M;B(*;7-G<W1R(")5:71L:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S
M='(@(E5I=&QI:FYI;F<Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`B06QL92(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(D%L
M;&4@9V5A=71H96YT:6-E97)D92!G96)R=6EK97)S(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R
M;W5P<R(*;7-G<W1R(")!;&QE(&=R;V5P96XB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")!
M;&QE(')E8VAT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G
M<W1R(")!;&QE('9I97(@>FEJ9&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM
M<V=S='(@(DUE97)D97)E(&%D<F5S<V5N('1O97-T86%N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O
M<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B26YS=&5L;&5N('9A;B!G96]R
M9&5N9&4@;&EJ<W0@='EP92!T;V5S=&%A;C\B"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI
M<W1S(@IM<V=S='(@(D)E<W1A870@86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R
M(")!;'1E<FYA=&EE=F4@24U34"!A86YM96QD:6YG(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O
M<F0B"FUS9W-T<B`B06QT97)N871I968@24U34"!W86-H='=O;W)D(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-
M4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N871I979E($E-4U`@9V5B<G5I
M:V5R<VYA86TB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM
M<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B06QT97)N
M871I968@92UM86EL861R97,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R(")!;'1E<FYA
M=&EE=F4@<VIA8FQO;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"FUS9VED(")!;'1E<FYA=&4@
M=&5X=#HB"FUS9W-T<B`B06QT97)N871I979E('1E:W-T.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I:V%A;G,@
M4V%M;V$B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE
M9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D5E;B!O;F=E;&1I
M9V4@=V%A<F1E(&]P9V5G979E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+B(*;7-G<W1R(")%<B!H965F="!Z:6-H(&5E;B!O;F)E:V5N9&5F;W5T
M('9O;W)G961A86XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-@IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R(")!;F1O<G)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(D%N;VYI96UE
M('!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G
M:60@(D%N<W=E<B(*;7-G<W1R(")!;G1W;V]R9"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4*;7-G
M:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT87)C=&EC82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3D*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U
M82!E;B!"87)B=61A(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C,V(&%D;6EN
M+W1E;7!L871E<RYP:'`Z-S0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS
M9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R(")4;V5P87-S:6YG(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(E1O97!A<W-I;F=E;FQI:G-T(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM
M<V=S='(@(E1O97!A<W-I;F<@:7,@9V5R965D+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B3W`@8VAI;&1S:&%R97,@=&]E<&%S<V5N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B1V]E9&ME=7)E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T,@IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*
M;7-G<W1R(")'97-C:&%T=&4@9W)O;W1T92(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R
M(")!<')I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")!
M<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8FES8V@@*%=I;F1O
M=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@IM<V=I
M9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B07)C:&EE9F)E<W1A;F1S
M9W)O;W1T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"FUS9VED
M(")!<F-H:79E($YA;64B"FUS9W-T<B`B07)C:&EE9FYA86TB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(E=E970@=2!Z
M96ME<B!D870@=2!H970@86%N;65L9&EN9W-V97)Z;V5K('9A;B`E<R!W:6QT
M('9E<G=I:F1E<F5N/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B
M"FUS9W-T<B`B5V5E="!U('IE:V5R(&1A="!U(%PB)7-<(B!E;B!A;&QE('-U
M8F=R;V5P96X@=VEL="!V97)W:6ID97)E;C\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V"FUS9VED
M(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YIZR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(*
M;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)M96YIZR(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*
M;7-G<W1R(")!<FUE96YS("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B2W5N<W0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,P"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B07-C96YS:6]N(&5I;&%N9"(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%S8VEI
M(&MU;G-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(D%Z:>LO4&%C:69I
M<V-H92!296=I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G
M:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N
M86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")/;2!B979E<W1I9VEN9R!V<F%G
M96X@=F]O<B!H970@=6ET=F]E<F5N('9A;B!O;F1E<FAO=61S=V5R:WIA86UH
M961E;C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DU"FUS9VED
M(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B3W!D<F%C:'0@:V]L;VUM
M96XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B4&]G:6YG
M(&]M(&5E;B!N:65T(&)E<W1A86YD92!G<F]E<"!T92!V97)W:6ID97)E;BXB
M"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@=F5R=VEJ
M9&5R96XN(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R(")0;V=I;F<@;VT@965N(&YI970@8F5S=&%A;F0@<F5C:'0@=&4@8F5W
M97)K96XN(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S
M='(@(E!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9&4@<VAA<F4@=&4@8F5W
M97)K96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*;7-G:60@
M(D%T=')I8G5T97,B"FUS9W-T<B`B071T<FEB=71E;B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B075G=7-T=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y"FUS9VED(")!=7-T<F%L
M:6$B"FUS9W-T<B`B075S=')A;&GK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.`IM<V=I9"`B075S
M=')I82(*;7-G<W1R(")/;W-T96YR:6IK(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)S<6PZ('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O;F1E;BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@
M(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@8F%C:V5N9"!H965F
M="!N:65T(&1E('9E<F5I<W1E(&)E:W=A86UH961E;BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z
M(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B
M075T:%]C>7)U<SH@=F5R96ES=&4@:6UA<"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I
M9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I
M=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@=F5R96ES=&4@1E10(&5X=&5N
M=&EE(&YI970@9V5V;VYD96XN($-O;7!I;&5E<B!02%`@;65T(&1E("TM96YA
M8FQE+2(*(F9T<"!O<'1I92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM
M87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P.B!V97)E:7-T
M92!)34%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U
M:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M:W)B-3H@=F5R96ES=&4@:W)B-2!E>'1E;G1I92!N:65T(&=E=F]N9&5N+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!
M=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@=&]E=F]E
M9V5N('9A;B!G96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O
M<B!!8W1I=F4@(@HB1&ER96-T;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R("(B"B)!=71H7VQD87`Z(%9E<G=I:F1E<F5N('9A;B!G96)R=6EK97)S
M('=O<F1T(&YI970@;VYD97)S=&5U;F0@=F]O<B!!8W1I=F4@(@HB1&ER96-T
M;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@=F5R96ES=&4@3$1!4"!E>'1E;G1I
M92!N:65T(&=E=F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA
M8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U
M:6ME<B`E<R!T;V4@=&4@=F]E9V5N+B!$92!S97)V97(@;65L9'0Z("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE="!I;B!S=&%A="!G96)R=6EK97(@
M)7,@=&4@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($YI
M970@:6X@<W1A870@9V5B<G5I:V5R("5S(&)I:B!T92!W97)K96XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"B)!=71H7VQD87`Z($)I:G=E<FME
M;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R<W1E=6YD('9O;W(@
M06-T:79E("(*(D1I<F5C=&]R>2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!V97)E
M:7-T92!-0T%,(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]S;6)A=71H.B!V97)E:7-T92!S;6)A=71H(&5X=&5N=&EE(&YI
M970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!9&UI;BYP
M:'`Z,3`V"FUS9VED(")!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F
M86EL960N(@IM<V=S='(@(D%U=&AE;G1I8V%T:64@;W`@24U!4"!S97)V97(@
M;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*
M;7-G<W1R(")!=71H96YT:6-A=&EE(&UI<VQU:W0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S
M='(@(D%U=&AE;G1I8V%T:64@;6ES;'5K="X@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71H96YT
M:6-A=&EE(&=E=V5I9V5R9"!D;V]R(&1E(%)!1$E54R!S97)V97(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71H96YT
M:6-A=&EE(&]P($944"!S97)V97(@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&AE;G1I8V%T:64@
M;W`@9&4@4TU"('-E<G9E<B!M:7-L=6MT+B(*"B,Z('1E;7!L871E<R]D871A
M+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S
M='(@(D)E<V-H:6MB87)E('9E;&1E;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!
M>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B86ED>FIA;B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@
M(D)/1D@@17AC=7-E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`B06-H=&5R9W)O;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S
M='(@(D%C:'1E<F=R;VYD:VQE=7(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM
M<V=S='(@(D9O=70@:V5R8F5R;W-W86-H='=O;W)D+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U
M<V5R;F%M92XB"FUS9W-T<B`B1F]U=&4@:V5R8F5R;W-G96)R=6EK97)S;F%A
M;2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0U"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,X"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')E
M:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC
M("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&ES8V@@*$E33RTX.#4Y+3$S
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N
M9VQA9&5S:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S,*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@
M(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(D)A<VES(&%F8F5E;&1I;F=E;F1I<F5C
M=&]R>2!<(B5S7"(@;FEE="!G979O;F1E;BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*;7-G:60@(D)A<V5L
M:6YE(@IM<V=S='(@(D)A<VES;&EJ;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B5VET(')U<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U"FUS9VED
M(")"96QG:75M(@IM<V=S='(@(D)E;&=IZR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"
M96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B0F5R;75D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@(D)H=71A
M;B(*;7-G<W1R(")":'5T86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")6
M97)J86%R9&%G(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I
M;VXN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@
M;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0FQO
M:R!<(B5S7"(@=F%N('1O97!A<W-I;F<@7"(E<UPB(&YI970@9V5V;VYD96XN
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R(")";&]K:6YS=&5L;&EN9V5N(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4
M>7!E(@IM<V=S='(@(D)L;VMT>7!E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(E9E
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79I
M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G:60@(D)O
M;VMM87)K<R(*;7-G<W1R(")";V]K;6%R:W,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B4F%N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(E)A;F1D:6MT93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S
M='(@(E)A;F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(*;7-G:60@(D)O<VYI82!A;F0@2&5R
M>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FGK(&5N($AE<GIE9V]V:6YA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM<V=S='(@
M(D)E:61E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-#@*;7-G:60@(D)O='-W86YA(@IM<V=S='(@
M(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(R"FUS9VED(")";W1T;VTB"FUS9W-T<B`B3VYD97)K
M86YT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R
M(")";W5V970@96EL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-`IM<V=I9"`B0G)A>FEL(@IM
M<V=S='(@(D)R87II;&GK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<*;7-G:60@(D)R:71I<V@@
M26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET<R!);F1I<V-H
M92!/8V5A86X@5&5R<FET;W)I=6TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S<*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEJ92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*
M;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B3VYG96]R9&5N9&4@;&EJ
M<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B
M0G5R:VEN82!&87-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G
M<W1R(")"=7)U;F1I(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R(")#
M4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM
M<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B0U),($1I
M<W1R:6)U=&EE<'5N=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T
M:65S+BXN(@IM<V=S='(@(D-?96QE:6=E;G-C:&%P<&5N+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,0IM<V=I9"`B0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B0V%C:&4@:6YI=&EA;&ES
M871I92!I<R!N:65T(&%F9V5R;VYD+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#4@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,38*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T
M<B`B06=E;F1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")+86QM(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(D-A;6)O9&IA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,`IM
M<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)O96XB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P
M87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<BXB"FUS9W-T<B`B(@HB2V%N('=A8VAT=V]O<F0@;FEE="!A=71O;6%T
M:7-C:"!R97-E='1E;BP@;F5E;2!C;VYT86-T(&]P(&UE="!D92`B"B)S>7-T
M965M8F5H965R9&5R+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I
M;&4@7"(E<UPB(@IM<V=S='(@(DMA;B!N:65T(&YA87(@8F5S=&%N9"!<(B5S
M7"(@<V-H<FEJ=F5N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED
M(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M(@IM<V=S='(@(DMA;B!G965N(&5X=&5R;F4@<V5S<VEE:&%N9&QE<B!B96AE
M<F5N+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM
M<V=S='(@(DMA;B!N:65T('9E<F)I;F1E;B!M970@24U!4"!S97)V97(Z("5S
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DMA;B!B97-T86YD(%PB)7-<(B!N:65T(&]P96YE;BXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q
M"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%N861A(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M"FUS9VED(")#86YC96PB"FUS9W-T<B`B069B<F5K96XB"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(E!R;V)L965M<F%P<&]R="!A9F)R96ME;B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DMA;B!B97-T86YD(%PB)7-<(B!N:65T('9E<G=I:F1E<F5N+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-3(*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"FUS9VED
M(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(DMA;B!G965N('1I:F1E;&EJ:V4@9&ER96-T;W)Y('9I;F1E;BXB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(DMA;B!N:65T(&1O;W)G86%N('IO;F1E<B`G=&%R9V5T
M1FEL92<@<&%R86UE=&5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&1I<F5C=&]R>2!<(B5S7"(@
M;FEE="!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DMA;B!N:65T('9E<G=I:F1E
M<F5N.R`E9"!C:&EL9')E;B!B97-T86%N+B(*"B,Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*
M(DMA;B!N:65T(&]P;FEE=7<@<F%N9W-C:&EK:V5N+"!H970@86%N=&%L(&EN
M=F]E<F5N(&]M(&]P;FEE=7<@=&4@(@HB<F%N9W-C:&EK:V5N(&MO;70@;FEE
M="!O=F5R965N(&UE="!H970@;W!G97-L86=E;B!A86YT86PN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R(")+86X@8F5R:6-H="!N:65T(&YA87(@:&5T(&]P9V5G979E
M;B!N=6UM97(@=F5R<W1U<F5N+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4*;7-G:60@(D-A<&4@
M5F5R9&4B"FUS9W-T<B`B2V%A<"!697)D92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I
M;VXB"FUS9W-T<B`B3W!S8VAR:69T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S
M='(@(D1R86=E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(D-A=&5G;W)I9>MN
M(&5N(&QA8F5L<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R(")#87EM86X@96EL86YD96XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE
M(@IM<V=S='(@(E1E;"YN<BYM;V)I96PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R
M;W!E<G1I97,B"FUS9W-T<B`B0V5L96EG96YS8VAA<'!E;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#
M96QL('!A9&1I;F<Z(@IM<V=S='(@(D-E;"!V<FEJ92!R=6EM=&4Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(D-E;&5I9V5N<V-H
M87!P96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")#96QS<&%T
M:>MR:6YG.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*;7-G
M:60@(D-E;&QP:&]N92(*;7-G<W1R(")496PN;G(N;6]B:65L(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM
M,30I(@IM<V=S='(@(DME;'1I<V-H("A)4T\M.#@U.2TQ-"DB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS
M9VED(")#96YT97(B"FUS9W-T<B`B36ED9&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-`IM<V=I
M9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(D-E;G1R86%L
M($%F<FEK86%N<V4@4F5P=6)L:65K(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#(*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM
M<V=S='(@(D-E;G1R86%L($5U<F]P965S("A)4T\M.#@U.2TR*2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")#97)T
M:69I8V%T92!$971A:6QS(@IM<V=S='(@(D-E<G1I9FEC86%T9&5T86EL<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")#97)T:69I8V%A=&5I9V5N
M86%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*
M;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(D-E<G1I9FEC
M86%T8F5L96ED(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q"FUS9VED(")#:&%D(@IM<V=S='(@
M(E1S:F%A9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*
M;7-G<W1R(")7:6IZ:6=E;B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M5VEJ>FEG('5W('=A8VAT=V]O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T
M:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO
M=7(@(@HB96UA:6QS+B(*;7-G<W1R("(B"B)7:6IZ:6<@9&4@;F%A;2P@861R
M97,@96X@;VYD97)T96ME;FEN9R!D:64@;65N('II970@8FEJ(&AE="!L97IE
M;B!E;B`B"B)B96%N='=O;W)D96X@=F%N('5W(&4M;6%I;',N(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN
M9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R
M<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*(E=I:GII9V5N('9A;B!U=R!W86-H='=O;W)D
M('=O<F1T(&YI970@;VYD97)S=&5U;F0@9&]O<B!D92!H=6ED:6=E("(*(F-O
M;F9I9W5R871I92X@3F5E;2!C;VYT86-T(&]P(&UE="!U=R!S>7-T965M8F5H
M965R9&5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B2V%R86MT97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(D-O;G1?
M<F]L965R(&QI;FLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y"FUS9VED(")#:&EL92(*;7-G
M<W1R(")#:&EL:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(D-H:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&EN965S('9E
M<F5E;G9O=61I9V0@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T
M<B`B0VAI;F5E<R!T<F%D:71I;VYE96P@*$)I9S4I(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R(")+:65S('1O97!A<W-I;F<Z(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B
M"FUS9W-T<B`B2VEE<R!E96X@=V%C:'1W;V]R9"(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N
M86UE(@IM<V=S='(@(DMI97,@965N(&=E8G)U:6ME<G-N86%M(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")+:65S(&1A='5M=V5E<F=A=F4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I(@IM<V=S='(@(DMI97,@;&EJ<W1S=&EJ;'1Y<&4@*'9O
M;W(@9V5O<F1E;F1E(&QI:G-T96XI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-34*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR
M:7-T;6%S($ES;&%N9"(*;7-G<W1R(")#:')I<W1M87,@96EL86YD(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-"!F<F%M97=O<FLO3F5T7U--4R]3
M35,N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET
M:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B0VQA<W-D969I;FET:64@
M=F%N("5S(&YI970@9V5V;VYD96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(DAE
M;&1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B35-/
M9F9I8V4@=&%G<R!W:7-S96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y
M"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")7:7,@<75E<GDB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B5VES(&=E8G)U
M:6ME<CH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B5VES(&=E8G)U:6ME<B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#
M;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B5VES(&=E8G)U:6ME<G-D871A(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G
M:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B3&%T92!O<&ML87)I;F=E;B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P
M"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")+;&EK(&]M('9E
M<F1E<B!T92!G86%N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10
M(@IM<V=S='(@(D-L:6-K871E;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*
M;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")3;'5I="!S8VAE<FTB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S
M='(@(E=O;&ME;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B5G)O96=E
M(&)E=V]L:VEN9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B0F5W;VQK="(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-3(*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S
M='(@(D-O8V]S("A+965L:6YG*2!E:6QA;F1E;B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B
M"FUS9W-T<B`B6FEJ8F%L:R!I;FML87!P96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL
M87!S960@8F]R9&5R<R(*;7-G<W1R("));F=E:VQA<'1E(')A;F1E;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C(*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(D-O;&]M8FEA(@H*
M(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(DML975R(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,PHC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,X"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,SD@<V5R=FEC97,O
M:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R
M(@IM<V=S='(@(DML975R96YK:65Z97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#(X"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(DML975R<V5L96-T:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B2V]L;VUM
M96XZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B
M0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+;VQO;71I=&5L<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R
M(")3=')I<',B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O
M;6UA;F0B"FUS9W-T<B`B3W!D<F%C:'0B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B3W!D<F%C:'1S
M:&5L;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM
M<V=I9"`B0V]M;65N="(*;7-G<W1R(")/<&UE<FMI;F<B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B06QG96UE;F4@;F%A;2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P"FUS9VED
M(")#;VUO<F]S(@IM<V=S='(@(D-O;6]R96XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM
M<V=S='(@(D)E9')I:F8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*
M;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")#;VUP=71E<G,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB
M"FUS9W-T<B`B0V]N9&ET:64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:71I97,B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R(")697)S8VAI;&QE;B!I;B!C;VYF:6=U<F%T
M:64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF
M:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@
M86YD($]U=&QO;VLN(@IM<V=S='(@(B(*(D-O;F9I9W5R871I92!V;V]R(&AE
M="!S>6YC:')O;FES97)E;B!M970@4$1!)W,L(%-M87)T<&AO;F5S(&5N($]U
M=&QO;VLN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B0V]N9FEG
M=7)A=&EE(&ES('9E<F]U9&5R9"XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G
M<W1R("(E<R!C;VYF:6=U<F5R96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S
M='(@(D)E=F5S=&EG('=A8VAT=V]O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U"FUS9VED(")#
M;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O
M+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B2V]N
M9V\L($1E($1E;6]C<F%T:7-C:&4@4F5P=6)L:65K('9A;B!D92(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O
M;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")697)B:6YD:6YG(&UI<VQU:W0N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")697)B:6YD:6YG
M(&UI<VQU:W0Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B(*;7-G<W1R(")697)B:6YD:6YG+"!M970@9&4@;W!E;F)A
M<F4@<VQE=71E;'-E<G9E<BP@:7,@9V5W96EG97)D+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("(B"B)697)B:6YD:6YG+"!M970@
M9&4@;W!E;F)A<F4@<VQE=71E;'-E<G9E<BP@:7,@9V5W96EG97)D+B!2961E
M;CH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<V
M"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")697)B:6YD:6YG(&UE="!&5%`@<V5R=F5R(&UI<VQU:W0N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C0@8V]N9FEG+VAO;VMS+G!H
M<"YD:7-T.C$P-C<*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@(D%D<F5S<V5N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S
M"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B061R97-S96X@>FEJ;B!M970@
M<W5C8V5S(&%A;B!U=R!A9')E<V)O96L@=&]E9V5V;V5G9"XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT
M96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B0V]N=&5N
M="!T>7!E('9A;B!G96-O;7!R:6UE97)D(&)E<W1A;F0Z("(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("));FAO=60@=F%N(%PB)7-<(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B
M1&]O<F=A86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4X"FUS9VED(")#;V]K($ES;&%N9',B"FUS
M9W-T<B`B0V]O:R!E:6QA;F1E;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(D-O;VMI92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM
M<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!IZW)E;B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@
M9F%I;&5D.B`E<R(*;7-G<W1R(")+;W!IZW)E;B!M:7-L=6MT.B`E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G
M:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(DMO<&EE97(@<V5L96-T:64B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I
M9"`B0V]S="!)1"(*;7-G<W1R(")+;W-T96X@240B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(D-O<W1A(%)I8V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4W"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(DEV;V]R:W5S="(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B
M0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R(")+;VX@
M4$=0(&)E<FEC:'0@;FEE="!C;V1E<F5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G93H@(@IM<V=S='(@(DMO;B!01U`@8F5R:6-H="!N:65T(&]N
M9&5R=&5K96YE;CH@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S
M86=E+B(*;7-G<W1R(")+;VX@8F5R:6-H="!N:65T(%,O34E-12!C;V1E<F5N
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B
M2V]N(&)E<FEC:'0@;FEE="!3+TU)344@;VYD97)T96ME;F5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B
M"FUS9W-T<B`B2V]N(&%D<F5S("5S(&YI970@=&]E=F]E9V5N+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#@R"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B2V]N(&=E96X@=F5R8FEN9&EN9R!M970@9&4@3$1!4"US97)V97(@
M;6%K96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3<S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+;VX@=&5G;V5D("5S(&YI
M970@8V]N=')O;&5R96XN(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V
M-@IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DMO;B!N:65T('9E<F)I;F1E;B!M970@3$1!4"!S97)V97(N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@
M1E10.B`E<R(*;7-G<W1R(")+;VX@;FEE="!V97)B:6YD96X@;65T('-E<G9E
M<B!<(B5S7"(@;65T($944#H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G
M<W1R(")+;VX@9V5E;B!D:7-T<FEB=71I96QI:G-T("5S(&UA:V5N+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B2V]N(%!'4"!D
M871A(&YI970@9&5C;V1E<F5N.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N(@IM<V=S='(@(DMO;B!3+TU)344@9&%T82!N:65T(&1E8V]D
M97)E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMO;B!A9')E<R`E<R!N:65T('9E
M<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMO;B!D
M:7-T<FEB=71I96QI:G-T("5S(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(DMO;B!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(@;FEE
M="!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*
M;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M
M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")+;VX@:&5T(&4M;6%I;&%D<F5S('9A
M;B!D92!O;G1V86YG97(@;FEE="!B97!A;&5N+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+
M;VX@8V]M<&QE=&4@861R97-B;V5K(&YI970@;W!H86QE;BXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B(*;7-G<W1R(")+;VX@8V]M<&QE=&4@9&ES=')I8G5T:65L:6IS="!N:65T
M(&]P:&%L96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M
M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(DMO
M;B!C;VUP;&5T92!L:6IS="!V86X@9&ES=')I8G5T:65L:6IS=&5N(&YI970@
M;W!H86QE;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M(%PB)7-<(BXB"FUS9W-T<B`B2V]N('-T<F%T96=I92!<(B5S7"(@;FEE="!L
M861E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(*;7-G<W1R(")+;VX@9&ER96-T;W)Y(%PB)7-<(B!N:65T
M(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q
M.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE
M(&ME>7-E<G9E<BXB"FUS9W-T<B`B2V]N(&1E(&]P96YB87)E('-L975T96P@
M;FEE="!V97)K<FEJ9V5N('9A;B!D92!S;&5U=&5L<V5R=F5R+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R(")+;VX@7"(E
M<UPB(&YI970@;W!E;F5N('9O;W(@<V-H<FEJ=F5N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B2V]N
M("5S(&YI970@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@
M(DMO;B!O;F1E<FAO=61S=&%K96YM;V1U;&4@)7,@;FEE="!O<&5N96XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V]N(&1I
M<F5C=&]R>2!<(B5S7"(@;FEE="!O<&5N96XN(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R(")+;VX@9&4@3$1!4"US97)V97(@;FEE="!B97)E:6ME;BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B2V]N
M("5S(&YI970@;&5Z96XN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*
M(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B)+;VX@:&5T('=A8VAT=V]O<F0@=F%N(&1E(&=E
M=V5N<W1E(&=E8G)U:6ME<B!N:65T(')E<V5T=&5N+B!3;VUM:6=E(&]F(&%L
M;&4@(@HB9&5T86EL<R!Z:6IN(&YI970@:G5I<W0N(%!R;V)E97(@;W!N:65U
M=R!O9B!N965M(&-O;G1A8W0@;W`@;65T(&1E("(*(G-Y<W1E96UB96AE97)D
M97(L('=A;FYE97(@=2!V97)D97)E(&AU;'`@;F]D:6<@:&5E9G0N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S4*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E($%#3"(*;7-G<W1R(")+;VX@04-,(&YI970@;W!H86QE
M;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DMO;B!A9')E<V)O96L@)7,@
M;FEE="!O<&AA;&5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M2V]N(&1I<W1R:6)U=&EE;&EJ<W0@)7,@;FEE="!O<&AA;&5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES=',N("5S(@IM<V=S='(@(DMO;B!D:7-T<FEB=71I96QI:G-T
M96X@)7,@;FEE="!O<&AA;&5N+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HR,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R
M=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DMO;B!S97)V97)B96MW86%M
M:&5D96X@;FEE="!O<&AA;&5N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")+;VX@8V]N9FEG=7)A=&EE(&YI970@=&5R=6=Z971T96XN(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DMO;B!D:7)E8W1O<GD@
M7"(E<UPB(&YI970@=F5R=VEJ9&5R96XN(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N(&-O;F9I9W5R871I
M92`E<R!N:65T(&]P<VQA86XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DMO;B!G
M965N(&)A8VMU<&-O;F9I9W5R871I92!O<'-L86%N+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DMO
M;B!G965N(&)A8VMU<&-O;F9I9W5R871I92!O<'-L86%N.B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(DMO;B!S971U<"!U<&=R861E('-C<FEP="!N:65T(&]P
M<VQA86X@86QS.B!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B2V]N(&AE
M="!B86-K=7!C;VYF:6=U<F%T:65B97-T86YD(&YI970@;W!S;&%A;B`E<RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I
M;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DMO;B!H970@
M8V]N9FEG=7)A=&EE8F5S=&%N9"`E<R!N:65T(&]P<VQA86XN(%4@:W5N="!O
M9B#KZVX@=F%N(&1E(&]P=&EE<R`B"B)G96)R=6EK96X@;VT@9&4@8V]D92!T
M97)U9R!O<"!T92!S;&%A;B!O<"`E<R!O9B!O;F1E<G-T86%N9&4@8V]D92!H
M86YD;6%T:6<@(@HB;F%A<B`E<R!K;W!IZW)E;BXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C
M:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DMO;B!D92!,1$%0+7-E<G9E
M<B!N:65T(&1O;W)Z;V5K96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*
M;7-G<W1R(")+;VX@7"(E<UPB(&YI970@;&]S:V]P<&5L96XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(")+;VX@861R97,@)7,@;FEE="!B:6IW97)K96XN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V]N(&1I<W1R:6)U=&EE;&EJ<W0@
M)7,@;FEE="!B:6IW97)K96XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DMO;B!C;VYF:6=U
M<F%T:64@=F]O<B!<(B5S7"(@;FEE="!W96=S8VAR:6IV96XZ("5S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BXB"FUS9W-T<B`B(@HB2V]N(&1E($UO>FEL;&$@4VED96)A<B!N
M:65T('9I;F1E;BX@6F]R9R!E<G9O;W(@9&%T(&1E('-I9&5B87(@;W!E;B!I
M<RXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R
M(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<
M(B5S7"(Z("5S(@IM<V=S='(@(B(*(DMO;B!G96)R=6EK97(@7"(E<UPB(&1E
M('9O;&=E;F1E(')E8VAT96X@;W`@9&4@;6%P(%PB)7-<(B!N:65T(&=E=F5N
M.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@
M(D-O=6YT960@=&5X="(*;7-G<W1R(")'971E;&1E('1E:W-T(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT
M<GDB"FUS9W-T<B`B3&%N9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-S4*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B0W5R<W5S<V5N(@H*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B36%K96XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*
M;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B36%A:R!E96X@;&EN:R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G
M:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B36%A:R!E96X@;FEE=7=E
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(*;7-G
M:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")-86%K('-U8FUA<'!E
M;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED
M(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D5I9V5N86%R<F5C:'1E
M;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,3(*;7-G:60@(D-R
M961I="!C87)D(&YU;6)E<B(*;7-G<W1R(")#<F5D:71C87)D;G5M;65R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#D*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B2W)O871IZR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C0*;7-G:60@(D-U8F$B"FUS9W-T<B`B0W5B82(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*
M;7-G<W1R(")(=6ED:6=E(#0@9F%S96XB"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B2'5I9&EG
M92!S97-S:65S(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K
M+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B2'5I
M9&EG92!T:6ID(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G
M<W1R(")(=6ED:6=E(%523"!I<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R(")(=6ED:6=E(&=E8G)U
M:6ME<G,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R
M96YT(%=E871H97(B"FUS9W-T<B`B2'5I9&EG('=E97(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I
M=&EO;CH@(@IM<V=S='(@(DAU:61I9V4@8V]N9&ET:64Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U
M<G)E;G0@<W1Y;&4B"FUS9W-T<B`B2'5I9&EG92!S=&EJ;"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M(")!86YP87-S96X@=F%N('1A:V5N('1I:F1E;G,@86%N;65L9&EN9R!B:6H@
M)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B2VYI<'!E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G
M:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96-T:64@:VYI<'!E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C<*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#>7!R=7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@*$M/
M23@M4BDB"FUS9W-T<B`B0WER:6QL:7-C:"`H2T])."U2*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*;7-G<W1R(")#>7)I;&QI<V-H("A7:6YD;W=S+3$R-3$I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I
M;FEA;B`H2T])."U5*2(*;7-G<W1R(")#>7)I;&QI<V-H+U5K<F%I;G,@*$M/
M23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8X"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G
M<W1R(")4<VIE8VAI<V-H92!297!U8FQI96LB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R-S(*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P
M96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT
M<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@HB1%-.("AZ:64@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1A9V5L:6IK<R(*"B,Z
M(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E
M<B(*;7-G<W1R(")$871A5')E92!B<F]W<V5R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(W,`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S
M='(@(D1A=&%B87-E(&1O;W)Z;V5K96XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S.3@*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!2
M96-E:79E9"(*;7-G<W1R(")$871U;2!/;G1V86YG96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-S@Y"FUS9VED(")$871E('-E;&5C=&EO;B(*
M;7-G<W1R(")$871U;2!S96QE8W1I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M,0IM<V=I9"`B1&%Y(@IM<V=S='(@(D1A9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?
M;&5T92!#;VQU;6XB"FUS9W-T<B`B5F5R7W=I:F1E<B!K;VQO;2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$
M96-E;6)E<B(*;7-G<W1R(")$96-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E
M8VEM86P@;G5M8F5R<R(*;7-G<W1R(")$96-I;6%L92!G971A;&QE;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G
M:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("));G-P<FEN9V5N('9E<FML
M96EN96XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L
M:6(O<')E9G,N<&AP.C$Q-PIM<V=I9"`B1&5F875L="(*;7-G<W1R(")3=&%N
M9&%A<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")3=&%N9&%A
M<F0@:VQE=7(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(E-T86YD86%R
M9"!I9&5N=&ET96ET(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<U"FUS
M9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-T86YD86%R9"!S:&5L;"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO
M;G,B"FUS9W-T<B`B1&5F:6YI=&EE<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,2!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")6
M97)W:6ID97)E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T
M<B`B5F5R=VEJ9&5R(&-E;"(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B"FUS9W-T
M<B`B1W)O97`@=F5R=VEJ9&5R96XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B5F5R=VEJ
M9&5R(&QO9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T
M92!097)M:7-S:6]N(@IM<V=S='(@(E)E8VAT('9E<G=I:F1E<F5N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@
M(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B5F5R=VEJ9&5R
M(&5N('=I<R!B97)I8VAT96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*
M;7-G<W1R(")697)W:6ID97(@8V5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O
M;'5M;B(*;7-G<W1R(")697)W:6ID97(@:V]L;VTB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R(")"97-T86%N9"!A;'1E<FYA=&EE9B!S:F%B
M;&]O;B!V97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T
M<B`B5F5R=VEJ9&5R(&)E<FEC:'1E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)E8VAT96X@=F%N(%PB
M)7-<(B!V97)W:6ID97)E;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G
M<W1R(")296-H=&5N(&5N(&5V96YT=65L92!S=6)R96-H=&5N('9O;W(@7"(E
M<UPB('9E<G=I:F1E<F5N/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS
M9W-T<B`B5F5R=VEJ9&5R(')I:B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R(")'97-E;&5C=&5E<F1E(&ED96YT:71E:70@=F5R=VEJ
M9&5R96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(E9E<G=I
M:F1E<B!S=6)M87!P96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R
M<F5N="!C;VQU;6XB"FUS9W-T<B`B5F5R=VEJ9&5R(&1E(&AU:61I9V4@:V]L
M;VTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS
M9W-T<B`B5F5R=VEJ9&5R(&1E(&AU:61I9V4@<FEJ(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E-E='5P
M('5P9W)A9&4@<V-R:7!T(%PB)7-<(B!V97)W:6ID97)D+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B069L979E<G1I
M:F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<Q"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1E;F5M
M87)K96XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM
M<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B0F5S8VAR:6IF
M(&AE="!P<F]B;&5E;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS
M."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-C:')I:G9I;F<B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T
M86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A
M:6QS("AO;VL@:6X@2&]R9&4G<R!L;V=B97-T86YD*3HB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C(Q,`IM<V=I9"`B1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B1&5T
M86EL<R!Z:6IN(&=E;&]G9"!V;V]R(&1E('-Y<W1E96UB96AE97)D97(N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO
M<&UE;G0B"FUS9W-T<B`B3VYT=VEK:V5L:6YG(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")$875W<'5N
M="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Q"FUS9VED(")$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(D1A=7=P=6YT('9O;W(@:&5T
M(&%F9V5L;W!E;B!U=7(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(D1A=7=P=6YT
M.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")2
M:6-H=&EN9R!L:6YK<R!N86%R(')E8VAT(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B4FEC:'1I;F<@<F5C:'1S(&YA87(@;&EN
M:W,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(D1I<F5C=&]R>2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T
M<B`B,C0M=75R<R!T:6ID=V5E<F=A=F4_(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(E=E
M97)G879E;W!T:65S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@
M(D=E9&5T86EL;&5E<F1E('=E97)S=F]O<G-P96QL:6YG('1O;F5N(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*2(*;7-G<W1R(")7965R<W9O;W)S<&5L;&EN9R!T;VYE;B`H5$%&
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3D*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(E=E97)G879E9F]R;6%A="(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(")6;V]R8F5R96ED:6YG<VYO=&EF
M:6-A=&EE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B
M1&II8F]U=&DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(").:65T('9E<G=I:F1E
M<F5N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED(")$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R
M(")M86EN=&5N86YC92YP:'`@;FEE="!D:7)E8W0@86%N<W!R96ME;B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M(@IM<V=S='(@(D)E=F%T(&1E(&5E<G-T92!R:6H@9&4@=F5L9&YA;65N/R!:
M;R!J82P@9&ET(&AO:VIE(&%A;G9I;FME;CHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R"FUS9VED
M(")$;VUI;FEC82(*;7-G<W1R(")$;VUI;FEC82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,*;7-G
M:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEC86%N<V4@
M4F5P=6)L:65K(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM
M<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R
M(")'965N(&%C8V]U;G0_(%-C:')I:F8@=2!I;BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3,*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(D1O=VYL;V%D96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@
M)7,B"FUS9W-T<B`B)7,@9&]W;FQO861E;B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(D1O=VYL;V%D(&=E9V5N
M97)E97)D92!C;VYF:6=U<F%T:64@86QS(%!(4"!S8W)I<'0N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B1')O<"!D;W=N(&QI:G-T(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R(")$<G5G<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-
M86EL(@IM<V=S='(@(D4M36%I;"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T
M97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@
M<V5R=FEC92XB"FUS9W-T<B`B(@HB12UM86EL(&YA87(@4TU3(&=A=&5W87D@
M<W1U=7)P<F]G<F%M;6$L('9O;W(@9')A9V5R<R!D:64@9&5Z92!S97)V:6-E
M("(*(F]N9&5R<W1E=6YE;BXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%
M4E(B"FUS9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-0IM<V=I9"`B16-U861O<B(*
M;7-G<W1R(")%8W5A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS
M9VED(")%9&ET(@IM<V=S='(@(D)E=V5R:V5N(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R
M(")";&]K(&)E=V5R:V5N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M
M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B
M1W)O97`@8F5W97)K96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B4F5C:'0@8F5W97)K96XB"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E)E8VAT96X@8F5W97)K96XB"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E8VAT96X@=F%N
M("<E<R<@8F5W97)K96XB"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")/<'1I97,@8F5W
M97)K96X@=F]O<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B4F5C:'1E;B!V86X@7"(E<UPB(&)E=V5R:V5N
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")2
M96-H=&5N('9A;B`E<R!B97=E<FME;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D]N9&5R=VEJ<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S<*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G>7!T92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L
M=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE
M;65N="XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UM86EL
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"FUS9VED(")%;6%I;"!!9&1R97-S
M(@IM<V=S='(@(D4M;6%I;&%D<F5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M(@IM<V=S='(@(D4M;6%I;&%D<F5S<V5N(&UO971E;B!O=F5R965N:V]M96XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B12UM86EL(&UE="!B979E
M<W1I9VEN9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M
M='`N<&AP.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R
M(")%+6UA:6P@;F%A<B!335,@9V%T97=A>2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR.3D*;7-G:60@(D5M;W1I8V]N<R(*
M;7-G<W1R(")%;6]T:6-O;G,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE<W-A9V4N
M(@IM<V=S='(@(DQE96<@8F5R:6-H="XB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V
M,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U
M;'0N(@IM<V=S='(@(D=E96X@<F5S=6QT86%T+B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T
M97)M<R(*;7-G<W1R("),96=E('IO96MT97)M96XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("))
M;G9O96=E;B!V86X@869B965L9&EN9V5N('5I="!F;W1O86QB=6US(&EN('1E
M:W-T(&EN<V-H86ME;&5N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM
M<V=S='(@(E)E8VAT:VQI:VME;B!C;VYT97AT(&UE;G4@:6YS8VAA:V5L96X_
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-SDS"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")%
M:6YD:F%A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(E9E<F=R
M;V]T(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C0*;7-G
M:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I
M;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S
M=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*
M;7-G<W1R("(B"B)'965F(&5E;B!B979E:6QI9VEN9W-V<F%A9R!D:64@=2!G
M979R86%G9"!W;W)D="P@=V%N;F5E<B!H970@;F]D:6<@:7,@;VT@=7<@(@HB
M=V%C:'1W;V]R9"!T92!R97-E='1E;BP@8BYV+B`G=V%T(&ES(&1E(&YA86T@
M=F%N('5W(&AU:7-D:65R/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"FUS9VED(")%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B5F]E<B!D92!A9F)E96QD:6YG
M(%523"!H:65R(&EN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z
M(@IM<V=S='(@(E9O97(@;VYD97)S=&%A;F1E(&QE='1E<G,@:6XZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY.0IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B17%U
M871O<FEA86P@1W5I;F5E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.0IM<V=I9"`B17)I=')E82(*
M;7-G<W1R(")%<FET<F5A(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S8*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0X
M"FUS9VED(")%<G)O<B(*;7-G<W1R(")&;W5T(@H*(SH@9G)A;65W;W)K+U1E
M;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(D9O=70@8FEJ(&UA
M:V5N('9A;B!B;&]K.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y
M;F,@86YC:&]R.B`E<R(*;7-G<W1R(")&;W5T(&)I:B!V97)W:6ID97)E;B!V
M86X@<WEN8R!A;FME<CH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S
M>6YC(&QO9SH@)7,B"FUS9W-T<B`B1F]U="!B:6H@=F5R=VEJ9&5R96X@=F%N
M('-Y;F,@;&]G.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T
M92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@
M8V]N=&5N=#H@)7,B"FUS9W-T<B`B1F]U="!B:6H@;W!H86QE;B!V86X@:6YH
M;W5D.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,B"FUS9W-T<B`B1F]U="!B:6H@8FEJ=V5R:V5N('9A;B!W86-H='=O;W)D
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*
M;7-G<W1R(")&;W5T(&UE="!E+6UA:6QB97)I8VAT+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN
M9R!<(B5S7"(N(@IM<V=S='(@(D9O=70@8FEJ('-C:')I:G9E;B!V86X@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S8*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B17-T
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(D5T
M:&EO<&GK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%
M=&AN:6,B"FUS9W-T<B`B171N:7-C:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B16QK92`Q-2!M:6YU=&5N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,PIM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM
M<V=S='(@(D5L:V4@,B!M:6YU=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,T,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(D5L:V4@,S`@<V5C;VYD96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.30*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")%;&ME(#4@
M;6EN=71E;B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(D5L:V4@86%N
M;65L9&EN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#0*;7-G:60@
M(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")%;&L@:&%L9B!U=7(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")%;&ME(&UI;G5U
M="(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%
M>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`B5F]O<F)E96QD=V%A<F1E;CHB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<&AP<VAE;&PN<&AP.C@R
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`B56ET=F]E<F5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")5:71K
M;&%P<&5N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM
M<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B6FEJ8F%L:R!U:71K;&%P
M<&5N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM
M<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(E9E<G=A8VAT=&4@)RDG(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B
M17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G
M<W1R(")697)W86-H='1E(&5N:V5L('=O;W)D(&]F(&%A;F=E:&%A;&1E('IO
M96MT97)M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R
M"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B5F5R=F%L9&%T=6TB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-PIM<V=I
M9"`B17AP;VYE;G0B"FUS9W-T<B`B17AP;VYE;G0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&
M1R!#;VQO<B(*;7-G<W1R(")6;V]R9W)O;F1K;&5U<B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B
M"FUS9W-T<B`B1E10('5P;&]A9"!V86X@<V5T=7`B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O<W%L+G!H<#HR,C`*;7-G:60@(D9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(")/<&AA;&5N('9O;W)K975R<VEN
M<W1E;&QI;F=E;B!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B5F5R8FEN9&EN9R!M970@9&4@3$1!4"US97)V97(@:7,@;6ES;'5K
M="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(E9E
M<F)I;F1I;F<@;65T(&1E(%--0BUS97)V97(@:7,@;6ES;'5K="XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B2V]P
M:>MR96X@=6ET(%PB)7-<(B!I<R!M:7-L=6MT+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B2V]P:>MR96X@;F%A<B!<
M(B5S7"(@:7,@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O
M;FYE8W1I;VXN(@IM<V=S='(@(DUA:V5N('9A;B!N:65U=V4@4T%33"!V97)B
M:6YD:6YG(&ES(&UI<VQU:W0N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HW-34@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G
M<W1R(")697)P;&%A='-E;B!N86%R(%PB)7-<(B!I<R!M:7-L=6MT+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B3W!H86QE
M;B!V86X@)7,@:7,@;6ES;'5K="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(DUO;VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@T"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B1F%L:VQA;F0@96EL86YD96X@*$UA;'9I;F%S*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#8*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R;^MR
M(&5I;&%N9&5N(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D9A=&%L92!F;W5T.B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@
M(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&87AE;B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R
M=6%R>2(*;7-G<W1R(")&96)R=6%R:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(W"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(E9O96QT(&%L<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R(")6;V5L="!A;',Z("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO
M=V5R<R(*;7-G<W1R(")%;FME;&4@8G5I96XB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R(")%;FEG92!S;F5E=7=B=6EE;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G
M<W1R(")696QD;6%T<FEX(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,R-0IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!
M4%1#2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(Y"FUS9VED
M(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L970@9F]N="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")"97-T
M86YD(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")!86YT
M86P@8F5S=&%N9&5N.B`E<R!B97-T86YD(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@
M)7,@9FEL97,B"FUS9W-T<B`B06%N=&%L(&)E<W1A;F1E;CH@)7,@8F5S=&%N
M9&5N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P.0IM<V=I9"`B
M1FEL92!-86YA9V5R(@IM<V=S='(@(D)E<W1A;F1B96AE97(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,`IM<V=I9"`B1FEL92!.86UE(@IM<V=S
M='(@(D)E<W1A;F1S;F%A;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-S<*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(D)E<W1A;F0@
M:VEE>F5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I
M9"`B1FEL92!U<&QO860B"FUS9W-T<B`B0F5S=&%N9'5P;&]A9"(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B1FEL92!U
M<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D)E<W1A;F1U<&QO861S
M('=O<F1E;B!N:65T(&]N9&5R<W1E=6YD+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT97)S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L
M9B(*;7-G<W1R(")%97)S=&4@:&5L9G0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R
M=&5R(@IM<V=S='(@(D5E<G-T92!K=V%R=&%A;"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I
M;R(*;7-G<W1R(")697)H;W5D:6YG(&AE<G-T96QL96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP
M(@IM<V=S='(@(D]M:V5R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R
M(")$<FEJ=F5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")-:7-T(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`B36%P("5S(&)E<W1A870@;FEE="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B1F]N=&ML975R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(E9O961S
M96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C,*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(E9O;W(@8G)O=W-E<G,@9&EE(&=E
M96X@869B965L9&EN9V5N(&]N9&5R<W1E=6YE;B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R(")7
M965R<W9O;W)S<&5L;&EN9R`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T
M:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N
M9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)6;V]R=6ET>FEC:'1D86=E
M;B`H;65R:R!O<"!D870@:&5T(&=E9V5V96X@=F]O<G5I='II8VAT(&1A9V5N
M(&5N(&YA8VAT96X@(@HB9V5E9G0[(&5E;B!G<F]O="!A86YT86P@:V%N(')E
M<W5L=&5R96X@:6X@965N(&)R965D(&)L;VLI(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D
M/R(*;7-G<W1R(")5=R!W86-H='=O;W)D('9E<F=E=&5N/R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*;7-G:60@(D9O<FUS(@IM<V=S='(@
M(D9O<FUU;&EE<F5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS
M9VED(")&;W)T=6YE(@IM<V=S='(@(D9O<G1U;F4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R(")&
M;W)T=6YE='EP92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I
M9"`B1F]R='5N97,B"FUS9W-T<B`B1F]R='5N97,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1F]R
M='5N97,@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G
M:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;7,B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")$;V]R
M<W1U<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B5G(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&
M<F%M97,B"FUS9W-T<B`B1G)A;65S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-PIM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(D9R86YK<FEJ:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS
M9W-T<B`B1G)A;FMR:6IK+"!(;V]F9'-T961E;&EJ:R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;G,@1W5Y86YA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#0*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M1G)A;G,@4&]L>6YE<VGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R"FUS9VED(")&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B1G)A;G-E(%IU:61E;&EJ
M:V4@5&5R<FET;W)I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B5F%N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")686X@9&4@(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B5F]L;&5D:6=E(&)E<V-H<FEJ=FEN
M9R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B5F]L;&4@;6%A;B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
M5F]L;&5D:6=E(&YA86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X"FUS9VED(")'86)O;B(*;7-G
M<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME
M(&EM86=E(&9R;VTB"FUS9W-T<B`B06QB=6T@=V%A<G5I="!D92!A9F)E96QD
M:6YG(&=E:&%A;&0@9&EE;G0@=&4@=V]R9&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R(")!;&)U;3HB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV"FUS9VED
M(")'86UB:6$B"FUS9W-T<B`B1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(D=E;F5R965R("5S(&-O;F9I9W5R871I
M92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS
M9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R(")'96=E;F5R965R9&4@8V]D
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3`*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I
MZR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B1'5I='-L
M86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,PIM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1VAA;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDT"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L
M=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*
M;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B5F]O<FYA86TB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED
M(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")';&]B86QE(&]P=&EE<R(*"B,Z
M('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R
M(")'82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E
M9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R(")';V]G;&4@:V%A<G1E;B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B1V]O9VQE('IO
M96ME;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S@*;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")'<FEJ<W-C:&%A;"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`P"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W)I96ME;FQA
M;F0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@
M*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R:65K<R`H25-/+3@X-3DM-RDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)O96YL86YD
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX.0IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D=R;V5P<V)E:&5E<B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B1W)O97!N86UE;B!M;V=E;B!N:65T(&QE96<@>FEJ;B(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U
M<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@
M(D=R;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@=&]E('1E('9O
M96=E;BX@1&4@<V5R=F5R(&UE;&1T.B`B"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z($YI970@:6X@
M<W1A870@9W)O97`@)7,@=&4@=F5R=VEJ9&5R96XB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A
M<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L
M9&%P.B!.:65T(&EN('-T86%T(&=R;V5P("5S(&)I:B!T92!W97)K96XB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R;V5P96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U<&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'=65R;G-E>2(*
M;7-G<W1R(")'=65R;G-E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@
M(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(D=A<W0@<F5C:'1E;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")'87-T96YB;V5K(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-PIM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(D=U:6YE92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-`IM<V=I9"`B1W5I
M;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN964M0FES<V%U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`U"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA4
M34PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R
M96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!C96P@:6X@9&4@<FEJ('1E
M('9E<G=I:F1E<F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB
M"FUS9W-T<B`B2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!K
M;VQO;2!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A('=E:6=E<G0@;&%F
M(&]M(&1E(&QA871S=&4@<FEJ(&EN(&1E('1A8F5L('1E('9E<G=I:F1E<F5N
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%14
M4"!A=71H96YT:6-A=&EE(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB
M"FUS9W-T<B`B2&%S:"UA;&=O<FET:&UE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M3F5V96PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ-`IM<V=I9"`B2&5A9&5R(@IM<V=S='(@
M(DMO<"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B2V]P<&5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`W"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',B"FUS9W-T<B`B2&5A<F0@96EL86YD(&5N($UC1&]N86QD(&5I;&%N9&5N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*
M;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B6G=A<F4@;VYW965R<V)U
M:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5E=7=S("A)4T\M.#@U.2TX
M+4DI(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(DAO;V=T92(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92](96QP+G!H<#HQ.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O
M:&5L<"]I;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R(")(96QP(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B2&5L<"!B:6H@9V5B
M<G5I:R!V86X@961I=&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,W,0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(DAE;'!E<B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(
M86QF<F]N9"(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H
M92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(DAI97(@:7,@:&5T
M(&)E9VEN('9A;B!H970@8F5S=&%N9#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R(")(
M;V]G(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E
M<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G
M<W1R(")(;U]M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,*;7-G:60@(DAO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(DAO;'D@4V5E("A6871I8V%A
M;G-T860I(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30X"FUS
M9VED(")(;VUE(@IM<V=S='(@(DAO;64B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*
M;7-G<W1R(")!9')E<R`H<')I=NDI(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")(;VUE9&ER
M96-T;W)Y(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")496PN;G(N("AP
M<FEVZ2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@
M(DAO;F1U<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B2&]N9R!+;VYG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C8W"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($]N9V5L9&EG92`E
M<R!834P@9&%T82!T96=E;F=E:V]M96X@:6X@8F5R:6-H="`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@1V5E;B!B97)I8VAT(&-O
M<G)E<W!O;F1E97)T(&UE="!O8FIE8W0@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0T-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@1V5E;B!O8FIE8W0@=F%N('1Y<&4@
M)7,@9V5V;VYD96X@:6X@8F5R:6-H="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B`E<R!M970@<W5C8V5S('9E<G=I:F1E<F0@7"(E<UPB
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO
M<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H
M92`G9&]M>&UL)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!$92!I;G1E<F=R871I92!V97)E:7-T(&1E("=D;VUX;6PG(&5X=&5N<VEE
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W
M(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($MA;B!G965N(&YI975W92!834P@8F]O;2!M86ME;B!V;V]R(&]B:F5C="`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@)7,@7"(E
M<UPB(&YI970@=F5R=VEJ9&5R96XZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O
M9B!T>7!E("5S(@IM<V=S='(@(B(*(DAO<F1E+TMO;&%B.B!.:65T(&EN('-T
M86%T(&AE="!-24U%($E$+"!V;V]R(&AE="!G961E96QT92!M970@='EP92`E
M<RP@;W`@=&4@(@HB:&%L96XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!+86X@)7,@7"(E<UPB(&YI970@<WEN8VAR;VYI<V5R96XZ
M("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,W"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&=E
M9&5E;&1E(&)R;VYN96X@;FEE="!S>6YC:')O;FES97)E;CH@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($]N8F5K96YD92!G961E96QD92!B<F]N(%PB)7-<
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")(;W)I>F]N=&%L
M92!L:6IN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DAO
M<FEZ;VYT86QE('9R:6IE(')U:6UT92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(DAO<FEZ;VYT86%L.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y
M;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B2&]E(&MW
M86T@=2!H:65R/R`H1W)A86<@<F%P<&]R=&%G92$I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B
M2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS
M9W-T<B`B2&]E=F5E;"!K;VQO;6UE;B!W:6QT('4@<V%M96YV;V5G96X_(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")(;V5V
M965L('9E;&1E;B`H:V]L;VUM96XI('II:FX@97(_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B2&]E=F5E;"!R:6IE;B!W:6QT('4@<V%M96YV;V5G96X_(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X.0IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B5F]C:'1I9VAE:60B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(
M=6UI9&ET>3H@(@IM<V=S='(@(E9O8VAT:6=H96ED.B`B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R(")(
M=6UO<FES=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q"FUS9VED(")(=6YG87)Y(@IM<V=S
M='(@(DAO;F=A<FEJ92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L
M+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R"B,L
M('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL
M960Z("5S(@IM<V=S='(@(DUA:V5N('9A;B!)34%0(&UA:6QB;W@@;6ES;'5K
M=#H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*
M;7-G<W1R(")697)W:6ID97)E;B!V86X@24U!4"!M86EL8F]X(&UI<VQU:W0Z
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B36%K96X@=F%N($E-05`@;6%I;&)O>"!Q=6]T82!M:7-L
M=6MT.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38*;7-G
M:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@061R97,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0(&%D<F5S(&YI970@8F5S8VAI
M:V)A87(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B25`@861R97,@=F%L="!N:65T(&)I;FYE;B!H970@
M=&]E9V5S=&%N92!#2412(&)L;VLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W
M;B!V:6]L871I;VXN(@IM<V=S='(@(DE0(&QO8VMD;W=N(&]V97)T<F5D:6YG
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@
M(E)I:B!I7VYV;V5G96X@=F]O<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,`IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("))2G-L86YD(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")!;&QE96X@<&EC
M=&]G<F%M;65N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")0:6-T;V=R
M86UM96X@=F]O<B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*
M;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")0:6-T;V=R86UM96X@
M;65T('1E:W-T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I
M9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET96ET<VYA86TZ
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`P"B,L
M('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T
M<B`B(@HB5V%N;F5E<B!H970@;FEE="!G;V5D('=O<F1T('=E97)G96=E=F5N
M+"`E<R!O;2!H970@:6X@965N(&YI975W('-C:&5R;2!T92`B"B)O<&5N96XN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)!;',@=2!G965N
M('!I8W1O9W)A;6UE;B!Z:65T+"!B:6H@9V5B<G5I:R!V86X@26YT97)N970@
M17AP;&]R97(L(&MA;B!H970@(@HB;F]D:6<@>FEJ;B!D:70@=F%K:F4@86%N
M('1E('9I;FME;B!O;2!03D<@=')A;G-P87)A=&EE('5I="!T92!S8VAA:V5L
M96XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E=A
M;FYE97(@=2!D:70@8F5R:6-H="!Z:65T+"!M86%R(&=E96X@869B965L9&EN
M9RP@9&%N(&MA;B!D92!A9F)E96QD:6YG(&1I92`B"B)U('=I;'0@=7!L;V%D
M96X@;FEE="!D;V]R('5W(&)R;W=S97(@=V]R9&5N('=E97)G96=E=F5N+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R-0IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B069B
M965L9&EN9W-B96]O<F1E;&EN9SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`B069B965L9&EN9R!54DPB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*;7-G:60@(DEM
M86=E(%523#HB"FUS9W-T<B`B069B965L9&EN9R!54DPZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B069B965L9&EN
M9R!U:70@86QB=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L
M;&5R>3HB"FUS9W-T<B`B069B965L9&EN9R!U:70@86QB=6TZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D
M(@IM<V=S='(@(D%F8F5E;&1I;F=S=7!L;V%D(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R(")!9F)E96QD:6YG
M96XB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-30*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z-R!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1E
M<F5N+"!S=&%P("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM
M<V=S='(@(D=E:6UP;W)T965R9"!V96QD.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B1V5I;7!O<G1E97)D92!V96QD96XZ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("))
M;E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R(")2:6H@:6YV;V5G96X@;F$B"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G
M:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B3VYJ
M=6ES=&4@8F5W97)K:6YG<V-O9&4@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("))
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R(")/
M;FIU:7-T92!G96)R=6EK97)S;F%A;2!E;B]O9B!W86-H='=O;W)D+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O
M<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I
M;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(D]N:G5I<W1E(&=E8G)U:6ME
M<G-N86%M(&]F(&%L=&5R;F%T:65F(&%D<F5S+B!0<F]B965R(&]P;FEE=7<@
M;V8@;F5E;2`B"B)C;VYT86-T(&]P(&UE="!D92!S>7-T965M8F5H965R9&5R
M+"!W86YN965R('4@=F5R9&5R92!H=6QP(&YO9&EG(&AE969T+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@
M(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")697)G<F]O="!I;G-P<FEN9VEN
M9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-@IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:6$B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("));F1I=FED=65L92!G96)R=6EK97)S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$R"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE<VGK(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M871I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G
M:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@
M(DEN9F]R;6%T:64@;FEE="!L86YG97(@8F5S8VAI:V)A87(N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U
M"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")+;VQO;2!I
M;G9O96=E;B!N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-PIM<V=I9"`B26YS97)T($EM86=E(@IM
M<V=S='(@(D%F8F5E;&1I;F<@:6YV;V5G96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B
M;&4B"FUS9W-T<B`B5&%B96P@:6YV;V5G96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B
M($QI;FLB"FUS9W-T<B`B5V5B;&EN:R!I;G9O96=E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I
M9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E]+;VQO;2!I;G9O
M96=E;B!V;V]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")%96X@;FEE=7=E(&MO
M;&]M(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")%96X@;FEE=7=E(&MO;&]M(&EN=F]E9V5N('9O;W(@9&4@:'5I9&EG
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B165N(&YI975W92!R:6H@:6YV;V5G96X@
M;F$@9&4@:'5I9&EG92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O
M=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(D5E;B!N:65U=V4@
M<FEJ(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN
M<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S
M='(@(D5E;B!N:65U=V4@<&%R86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I
M9V4@;F]D92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E
M9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(D5E;B!N:65U=V4@<&%R
M86=R86%F(&EN=F]E9V5N(&YA(&1E(&AU:61I9V4@;F]D92(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(D%L=&5R;F%T:65F('-J86)L;V]N(&EN=F]E9V5N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T
M(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H
M92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(D5E;B!E+6UA:6QA9')E<R!I;G9O
M96=E;BP@=V%A<B!U(&AE="!N:65U=V4@=V%C:'1W;V]R9"!K86X@;VYT=F%N
M9V5N.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@
M(D-E;"!I;G9O96=E;B!N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E
M9F]R92(*;7-G<W1R(")#96P@:6YV;V5G96X@=F]O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@
M(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B2V]L;VT@:6YV;V5G96X@
M;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R
M(")+;VQO;2!I;G9O96=E;B!V;V]R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G
M<W1R(")"97)I8VAT96X@:6YV;V5G96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B4&%R86=R86%F(&EN=F]E9V5N
M(&YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R(")087)A9W)A868@:6YV;V5G96X@=F]O<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B4FEJ(&EN=F]E9V5N(&YA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B4FEJ(&EN
M=F]E9V5N('9O;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS
M9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I
M='D@<75E<W1I;VXZ(@IM<V=S='(@(DAE="!G97=E;G-T92!A;G1W;V]R9"!V
M;V]R(&1E(&)E=F5I;&EG:6YG<W9R86%G(&EN=F]E9V5N.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B069B965L9&EN9R!I;G9O96=E
M;B]A86YP87-S96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T
M<B`B3&EN:R!I;G9O96=E;B]A86YP87-S96XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F
M:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B3VYV;VQD;V5N9&4@:W)E9&EE="!O;2!N86%R(&1E(&1I
M<W1R:6)U=&EE;&EJ<W0@=&4@>F5N9&5N+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")/;G9O;&1O96YD92!K<F5D:65T(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E
M<B(*;7-G<W1R("));G1E9V5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(DEN=&5G97(@
M;&EJ<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN(@IM<V=S='(@(D]N9V5L9&EG92!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q
M,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")/;F=E;&1I9V4@
M6DE0(&1A=&$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T"FUS9VED
M("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")/;F=E;&1I9V4@=&]E
M<&%S<VEN9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S
M='(@(D]N9V5L9&EG(&)A=&-H($E$+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`B3VYG96QD:6=E(&1A=&$@;W!G96=E=F5N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(")/;F=E;&1I
M9R!B97-T96UM:6YG861R97,N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C$S.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HR-#$*;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS
M9W-T<B`B3VYG96QD:6<@=&EJ9&9O<FUA870B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y
M+B(*;7-G<W1R(")/;F=E;&1I9V4@;&EC96YT:65S;&5U=&5L+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@
M;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D]N9V5L9&EG92!L;V-A=&EE
M(&]P9V5G979E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM
M<V=S='(@(D]N9V5L9&EG(&US9U]T>7!E+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B3VYG96QD:6<@;V8@;VYT
M8G)E:V5N9"!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B3VYG96QD:6=E(&]F(&]N=&)R96ME
M;F1E('!A<F%M971E<G,N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M(")/;F=E;&1I9R!P87)E;G0@<F5C:'0N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*
M;7-G<W1R(")/;F=E;&1I9R!P87)T;F5R(&ED+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(")/;F=E;&1I9V4@<')O9'5C=&EE8V]D92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*
M;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(D]N9V5L9&EG('!R
M;W1O8V]L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`B3VYG96QD:6=E(&]N='9A;F=E<CH@7"(E<UPB(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#@P(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B
M"FUS9W-T<B`B3VYG96QD:6=E(&=E9&5E;&1E(&)R;VXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D]N9V5L9&EG(&)R
M;VYA9')E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*
M;7-G<W1R(")/;F=E;&1I9V4@=6YI8V]D92!D871A+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R
M("));G9E;G1A<FES(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R
M(")396QE8W1I92!O;6ME<F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y"FUS9VED("))<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(DER86XL($ES;&%M:71I
M<V-H92!297!U8FQI96L@=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X"FUS9VED("))<F%Q
M(@IM<V=S='(@(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,*;7-G:60@(DER96QA;F0B
M"FUS9W-T<B`B265R;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")%:6QA;F0@36%N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*
M;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(D=E:7-O;&5E<F1E
M(&]N=V5E<G-B=6EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-`IM<V=I9"`B27-R865L(@IM
M<V=S='(@(DES<F'K;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T<B`B56ET9V5V97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*;7-G
M:60@(DET86QI8R(*;7-G<W1R(")#=7)S:65F(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q"FUS
M9VED("))=&%L>2(*;7-G<W1R("))=&%L:>LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,*;7-G
M:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(DIA;G5A<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4*;7-G:60@(DIA<&%N(@IM
M<V=S='(@(DIA<&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G
M:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P86YS("A)
M4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-`IM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F1A;FGK(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB
M"FUS9W-T<B`B2G5L:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X
M"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(G5I=&QI:FYE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")'96-E;G1R965R9"!U:71L
M:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(E9O
M;&QE9&EG('5I=&QI:FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B
M"FUS9W-T<B`B3&EN:W,@=6ET;&EJ;F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`B4F5C:'1S('5I=&QI:FYE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA8VAS=&%N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM
M<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B3W)I9VEN965L(&)E:&]U
M9&5N/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B2V5N
M:6$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED
M(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DME<F)E<F]S('-E<G9E<B!W96EG97)D92!A=71H96YT:6-A=&EE
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L
M($YE=V)I97,B"FUS9W-T<B`B2V5R;F5L($YE=V)I97,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R(")3;&5U=&5L(&UA:V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B4VQE=71E;'9I;F=E<F%F9')U:R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M(")3;&5U=&5L;&5N9W1E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")3;&5U=&5L='EP
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DY"FUS
M9VED(")+97D@57-A9V4B"FUS9W-T<B`B4VQE=71E;&=E8G)U:6LB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A
M;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`B1&4@<VQE=71E;"!B97-T86%T(&%L(&]P(&1E(&]P96YB87)E('-L975T
M96QS97)V97(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED
M(")+:61S(@IM<V=S='(@(DMI;F1E<F5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y"FUS9VED
M(")+:7)I8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,@IM
M<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B2V]R96$L($1E;6]C<F%T:7-C:&4@5F]L:W-R97!U8FQI96L@
M=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,S"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B2V]R96$L(%)E<'5B;&EE:R!V86XB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(DMO<F5A86YS("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A
M:70B"FUS9W-T<B`B2V]E=V5I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-PIM<V=I9"`B2WER
M9WEZ<W1A;B(*;7-G<W1R(")+>7)G:65S:>LB"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B3U]P;6%A
M:R(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA
M;F=U86=E(@IM<V=S='(@(E1A86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<*;7-G:60@(DQA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(D1E;6]C
M<F%T:7-C:&4@5F]L:W-R97!U8FQI96L@3&%O(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(DQA871S=&4@
M:&5L9G0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA
M<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(DQA871S=&4@=V%C:'1W;V]R
M9'=I:GII9VEN9R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("),
M86%T<W1E(&MW87)T:65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B3&%A='-T(&)I:F=E=V5R
M:W0Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF
M;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(DQA871S=&4@
M86%N;65L9&EN9SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<R(*;7-G<W1R("),86%T<W1E(&%A;FUE;&1I;F<Z("5S('9A;B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I
M;CH@3F5V97(B"FUS9W-T<B`B3&%A='-T92!A86YM96QD:6YG.B!.;V]I="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-@IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(DQE=&QA;F0B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G
M<W1R(")296-H=&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"FUS9VED("),87EO=70B"FUS9W-T<B`B3W!M
M86%K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R
M("),86%T(&QE96<@=F]O<B!G965N(')A;F0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@*;7-G
M:60@(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`IM<V=I9"`B3&5F
M="(*;7-G<W1R("),:6YK<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,#$*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DQI;FMS92!K;W`B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DW"FUS9VED("),969T
M('9A;'5E<R(*;7-G<W1R("),:6YK<V4@=V%A<F1E;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R
M(").:79E874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(*;7-G:60@(DQI8F5R:6$B"FUS9W-T
M<B`B3&EB97)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-PIM<V=I9"`B3&EB>6%N($%R86(@
M2F%M86AI<FEY82(*;7-G<W1R("),:6)I<V-H92!!<F%B:7-C:&4@2F%M86AI
M<FEY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G
M<W1R("),:65C:'1E;G-T96EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T
M<B`B6F%C:'0@8G5I=&IE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B3&EC
M:'1E(')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B5G)O
M96<@;&EC:'1E(')E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R
M("),:6-H=&4@<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T
M<B`B3&EC:'1E(')E9V5N8G5I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R(@IM<V=S='(@(DQI8VAT92!R96=E;B!M970@;VYW965R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI
M9VAT(%-N;W<B"FUS9W-T<B`B3&EC:'1E('-N965U=R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3
M;F]W(%-H;W=E<B(*;7-G<W1R("),:6-H=&4@<VYE975W8G5I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R
M("),:6UE<FEC:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*
M;7-G:60@(DQI;FLB"FUS9W-T<B`B3&EN:R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN
M:R!P;VEN=',@=&\Z(@IM<V=S='(@(DQI;FL@=VEJ<W0@;F%A<CHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E
M;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y
M:6YG(@IM<V=S='(@(DQI;FL@:&5T(&4M;6%I;&%D<F5S(&%A;B!D92!N:65U
M=R!B97)I8VAT('!A9VEN82!T:6ID96YS('=E97)G879E(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I
M9"`B3&EN:W,B"FUS9W-T<B`B3&EN:W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"!#
M;V]K:64B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT
M-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S
M='(@(DQI:G-T("T@9V5B<G5I:V5R(&MA;B!D92!M87`@>FEE;B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM
M<V=S='(@(D1A=&%B87-E;&EJ<W0B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("),:6IS
M="!V86X@:&5L<"!O;F1E<F1E;&5N(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B5&%B96QL:6IS="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED
M("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&EJ<W0M07)C:&EE9B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"FUS9VED("),:7-T
M+4AE;'`B"FUS9W-T<B`B3&EJ<W0M2&5L<"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@
M(DQI:G-T+4ED(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B3&EJ<W0M16EG96YA
M87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI:G-T+5!O<W0B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3
M=6)S8W)I8F4B"FUS9W-T<B`B3&EJ<W0M26YS8VAR:6IV96XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5
M;G-U8G-C<FEB92(*;7-G<W1R("),:6IS="U5:71S8VAR:6IV96XB"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES
M=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(E=E97)G979E;B!V
M86X@<V5S<VEE;&EJ<W0@:7,@;6ES;'5K=#H@)7,B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R
M<R!F86EL960Z("5S(@IM<V=S='(@(E=E97)G979E;B!V86X@9V5B<G5I:V5R
M<VQI:G-T(&ES(&UI<VQU:W0Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R(")7965R9V5V96X@=F%N(&=E8G)U:6ME<G-L:6IS="!I
M<R!U:71G97-C:&%K96QD+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T=75R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET;W5W96XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W
M"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DQA9&5N+BXN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM
M93H@(@IM<V=S='(@(DQO:V%L92!T:6ID.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DQA
M;F1I;G-T96QL:6YG(&5N('1I:F0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-3<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DQO8V%T:64B"@HC
M.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M,#`@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B06%N;65L9&5N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E
M=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(DQO9R!V86X@=F]O<F=A86YD
M92!S>6YC('-E<W-I92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B069M96QD96XB"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO9VEN(@IM<V=S='(@
M(D%A;FUE;&1E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G
M:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(D%A;FUE;&1T86ME;B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G:6X@9F%I;&5D
M(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E
M9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB06%N;65L9&EN9R!M:7-L=6MT
M(&]M9&%T('5W(&=E8G)U:6ME<G-N86%M(&]F('=A8VAT=V]O<F0@;VYJ=6ES
M="!I<R`B"B)I;F=E=F]E<F0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(D%A;FUE;&1I
M;F<@;6ES;'5K="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U
M"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B3&%N9V4@=&5K<W0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B
M3&EE9F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R("),86%G(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I
M9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")'<FEE:W-E(&ML96EN
M92!L971T97)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R("),871I:FYS92!K;&5I;F4@;&5T=&5R<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*
M;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B2VQE:6YE(%)O
M;65I;G-E(&=E=&%L;&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O
M=7)G(@IM<V=S='(@(DQU>&5M8G5R9R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M(")-4RU43D5&(&)I:FQA9V4@8F5V871T92!G965N(&1A=&$N(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-PIM<V=I9"`B36%C86\B"FUS9W-T<B`B36%C86\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3,*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9B(*;7-G<W1R(")-86-E9&]N:>LL($1E('9R;V5G97)E($IO96=O
M<VQA=FES8VAE(%)E<'5B;&EE:R!V86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$*;7-G:60@
M(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<V-A<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:64B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB
M"FUS9W-T<B`B12UM86EL(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")-86EL8F5H965R9&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(DUA86L@
M;&EN7VLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4*;7-G:60@(DUA;&%W:2(*;7-G<W1R
M(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<*;7-G:60@(DUA;&%Y<VEA(@IM<V=S
M='(@(DUA;&5I<VGK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T"FUS9VED(")-86QD:79E<R(*
M;7-G<W1R(")-86QA9&EV96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30*;7-G:60@(DUA;&DB
M"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,@IM<V=I9"`B36%L=&$B"FUS
M9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*(D)E:&5E<B!U
M=R!L:6IS="!M970@8V%T96=O<FEEZVX@96X@9&4@8V]R<F5S<&]N9&5R96YD
M92!K;&5U<F5N+"!W86%R;65E("(*(F]N9&5R9&5L96X@=V]R9&5N(&=E;&%B
M96QD(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R-"!K86%R="(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@W
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q
M"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B36%P475E<W1K86%R="(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P
M<&EN9W,@<W1O<F5D+B(*;7-G<W1R(")+;W!P96QI;F=E;B!O<&=E<VQA9V5N
M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W
M"FUS9VED(")-87)C:"(*;7-G<W1R(")-86%R="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA
M<F=I;B(*;7-G<W1R(")-87)G92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C0X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,B"FUS9W-T<B`B36%R:V5E<B!M970@1V5Z:65N+TYI970@1V5Z:65N
M('9L86=G96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HT.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B36%R:V5E<B!M970@86YD97)E('9L
M86=G96X@*&(N=BX@0F5L86YG<FEJ:R]"96%N='=O;W)D*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,@IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87)C:&%L
M;"!E:6QA;F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.0IM<V=I9"`B36%R=&EN:7%U92(*
M;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")/=F5R
M965N:V]M96YD92!V96QD96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`*;7-G:60@(DUA=7)I
M=&%N:6$B"FUS9W-T<B`B36%U<F5T86YIZR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,PIM<V=I
M9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B
M36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-87AI;6%A;"!T;V5G97-T
M86%N(&MR961I970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"XB"FUS9W-T<B`B36%X:6UU;2!B97)I8VAT;VYD97)D96QE;B!O
M=F5R<V-H<F5D96XN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G
M:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")-87AI;75M
M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R.B`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S="`V
M(&AO=7)S.B`B"FUS9W-T<B`B36%X:6UU;2!T96UP97)A='5U<B!V86X@9&4@
M869G96QO<&5N(#8@=75R.B`B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R(")-87AI
M;75M(&%A;G1A;"!P;W)T86%L8FQO:VME;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@
M;&5N9W1H(@IM<V=S='(@(DUA>&EM=6T@;&5N9W1E(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R(")-96DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S"FUS9VED(")-87EO='1E(@IM<V=S
M='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G
M:60@(DUE9&EC:6YE(@IM<V=S='(@(D=E;F5E<VMU;F1E(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R("),961E;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#(*
M;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N=2!M;V1E.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*
M;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(D-E;&QE;B!S86UE;G9O96=E
M;B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(D)E<FEC:'0B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B
M(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM
M<V=S='(@(B(*(D)E<FEC:'0@;65T('-U8V-E<R!G979E<FEF:65E<F0L(&UA
M87(@:&5T(&-E<G1I9FEC86%T('9A;B!D92!O;F1E<F=E=&5K96YD92`B"B)K
M;VX@;FEE="!W;W)D96X@9V5V97)I9FEE97)D+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S
M<V%G92!E>'!I<F5D+B(*;7-G<W1R(")"97)I8VAT('9E<FQO<&5N+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,#(*;7-G:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")"97)I
M8VAT='EP92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T
M87(@5V5A=&AE<B(*;7-G<W1R(")-971A<B!7965R(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B345405(@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED("(B"B)-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-151!4B!B;&]K
M(&ES(&YI970@8F5S8VAI:V)A87(N($1E=&%I;',@>FEJ;B!G96QO9V0@=F]O
M<B!D92!S>7-T965M8F5H965R9&5R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E
M9"XB"FUS9W-T<B`B365T87)$0B!I<R!N:65T('9E<F)O;F1E;BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*
M;7-G<W1R(")-971H;V1E(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*
M;7-G<W1R(")-971H;V1E(%PB)7-<(B!I<R!N:65T(&=E9&5F:6YI965R9"(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,B"FUS9W-T<B`B365T:&]D92!I<R!N:65T(&=E9&5F:6YI965R9"X@06%N
M9V5R;V5P96X@;65T:&]D93H@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-PIM<V=I9"`B365T
M<FEC(@IM<V=S='(@(DUE=')I<V-H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V"FUS9VED(")-
M97AI8V\B"FUS9W-T<B`B365X:6-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4*;7-G:60@(DUI
M8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B36EC<F]N
M97-IZRP@1F5D97)A;&4@4W1A=&5N('9A;B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I9"`B36ED9&QE
M(@IM<V=S='(@(DUI9&1E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B36EM
M92!T>7!E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")-:6YI;75M('1E;7!E
M<F%T=75R('9A;B!D92!A9F=E;&]P96X@,C0@=75R.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P.0IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S
M.B`B"FUS9W-T<B`B36EN:6UU;2!T96UP97)A='5U<B!V86X@9&4@869G96QO
M<&5N(#8@=75R.B`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@
M97AP:7)E9"(*;7-G<W1R(")-:6YI;75M('=A8VAT=V]O<F1L965F=&EJ9"!I
M<R!N;V<@;FEE="!V97)L;W!E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")-
M:7)R;W(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI
M<V-E;&QA;F5O=7,B"FUS9W-T<B`B06QL97)H86YD92(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")/
M;G1B<F5K96YD92!014%2(&UO9'5L92!(5%107U)E<75E<W0N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M(D]N=&)R96ME;F1E(&-O;F9I9W5R871I92X@52!D:65N="!D97IE(&YU('1E
M(&=E;F5R97)E;BP@=V%N;F5E<B!U(&1E>F4@(@HB=&]E<&%S<VEN9R!W:6QT
M(&=E8G)U:6ME;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B3VYT8G)E:V5N9"!B97)I8VAT($E$+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M(")/;G1B<F5K96YD92P@=F5R96ES=&4L(%!%05(@;6]D=6QE($UA:6PN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(D]N=&)R
M96ME;F0@<V5S<VEE($E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DUA(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R(")-;V)I96QE(&4M;6%I;"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G
M<W1R(")'96UI9&1E;&0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,PIM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")7:6IZ:6=I;F=S9&%T
M=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B5VEJ>FEG
M(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L=7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1A
M=FGK+"!297!U8FQI96L@=F%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-;VYG
M;VQI82(*;7-G<W1R(")-;VYG;VQIZR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.#0*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DUA
M86YD(&5N(&IA87(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUA86YD96QI
M:FMS(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@
M(DUO;G1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(DUA
M86YF87-E;B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E
M>'!E8W1E9"`E9"XB"FUS9W-T<B`B365E<B!V96QD96X@:6X@<F5G96P@)60@
M9V5V;VYD96XL(&1A;B!D92!V97)W86-H='1E("5D+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M.`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:VMO(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L
M>2!#;&5A<B(*;7-G<W1R(")6;V]R;F%M96QI:FL@;VYB97=O;&MT(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@
M(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B5F]O<FYA;65L:6IK(&)E=V]L:W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM
M<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B5F]O<FYA
M;65L:6IK(&)E=V]L:W0@96X@=VEN9&5R:6<B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U;FYY
M(@IM<V=S='(@(E9O;W)N86UE;&EJ:R!Z;VYN:6<B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V
M92!$;W=N(@IM<V=S='(@(DYA87(@8F5N961E;B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E
M($QE9G0B"FUS9W-T<B`B3F%A<B!L:6YK<R(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS9VED(")-;W9E(%)I
M9VAT(@IM<V=S='(@(DYA87(@<F5C:'1S(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B
M"FUS9W-T<B`B3F%A<B!B;W9E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R
M(").86%R(&)E;F5D96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B3F%A<B!B
M;W9E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R
M(")-;WIA;6)I<75E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:6IS=&5N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3D*;7-G:60@(DUU;'1I
M;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"!62R!K86%R="(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E
M;&5C=&EO;B(*;7-G<W1R(")-965R=F]U9&EG92!S96QE8W1I92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B
M"FUS9W-T<B`B36EJ;B!A8V-O=6YT(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@
M(E5W(&%C8V]U;G1I;F9O<FUA=&EE(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN
M9&5X+G!H<#HT-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUI:FX@<&]R
M=&%A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HT,@IM<V=I9"`B
M37D@4&]R=&%L($QA>6]U="(*;7-G<W1R(")-:6IN('!O<G1A86QL87EO=70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-34*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B0FER;6$B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU
M-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DYE92P@:6L@
M86-C97!T965R(&1E('9O;W)W86%R9&5N($Y)150B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B3F%M92(*;7-G<W1R(").86%M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38Y"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB:>LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S@*;7-G:60@(DYA=7)U(@IM<V=S='(@(DYA=7)U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<W"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3F5D97)L
M86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S
M(@IM<V=S='(@(DYE9&5R;&%N9',@06YT:6QL96XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S
M92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@0F%S:7,@55),(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E($-!(&EN=')E
M:VMI;F<@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B
M3F5T<V-A<&4@0T$@8F5L96ED(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R(").971S8V%P92!V97)N:65U=VEN9R!54DPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A<&4@:6YT<F5K:VEN
M9R!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE
M='-C87!E(%-33"!S97)V97)N86%M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A<&4@8V5R=&EF:6-A871C;VUM96YT
M86%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B3F5T
M<V-A<&4@8V5R=&EF:6-A871T>7!E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").971W97)K(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`B3F]O:70B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`*
M;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B3FEE=7<@0V%L961O;FGK
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").:65U=V4@8V%T
M96=O<FEE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M
M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@
M36]O;B(*;7-G<W1R(").:65U=V4@;6%A;B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T
M:6]N86PI(@IM<V=S='(@(DYI975W92!G96)R=6EK97)S;F%A;2`H;W!T:6]N
M965L*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T
M<B`B3FEE=7<@6F5E;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYI975W('=A
M8VAT=V]O<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W
M"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER
M92!O;B`E>"XB"FUS9W-T<B`B3FEE=7<@=V%C:'1W;V]R9"!Z86P@=F5R;&]P
M96X@;W`@)7@N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R
M"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R(").
M:65U=V4@5V%C:'1W;V]R9&5N(&MO;65N(&YI970@;W9E<F5E;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYI975W('-C:&5R;2`H
M7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HT,`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYI975W<R(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T
M<B`B3FEE=7=S9W)O97!E;B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(U('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C0Q('1E;7!L871E<R]D871A+W1S=FEN
M9F\N:6YC.C$U"FUS9VED(").97AT(@IM<V=S='(@(E9O;&=E;F1E(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM
M<V=S='(@(E9O;&=E;F1E(#0@9F%S96XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E9O;&=E;F1E(&]P
M=&EE<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S"FUS9VED
M(").97AT/B(*;7-G<W1R(")6;VQG96YD93XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0*;7-G
M:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S$*;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S
M"FUS9VED(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R
M(").86-H="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.0IM<V=I9"`B3FEU92(*;7-G<W1R(").
M:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F5E(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@8V]N
M9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*;7-G
M<W1R(")'965N(&)E<V-H:6MB87)E(&-O;F9I9W5R871I961A=&$@;VT@=F5R
M<V-H:6QL96X@=&4@;&%T96X@>FEE;BXB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE
M('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B1V5E
M;B!B97-C:&EK8F%R92!S=')A=&5G:64@=F]O<B!H970@;6%K96X@=F%N($E3
M3R!I;6%G97,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS
M9W-T<B`B1V5E;B!B871C:'-J86)L;V]N+B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").
M;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G
M<W1R(")%<B!B97-T86%T(&=E96X@8FQO:R!O<"!D92!G979R86%G9&4@<&]S
M:71I92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*;7-G
M:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(D=E96X@86=E;F1A;F%A;2!O<&=E9V5V96X@
M=F]O<B!-0T%,(&%U=&AE;G1I8V%T:64N(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B1V5E;B!W:6IZ
M:6=I;F=E;BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U
M-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B06%N(&1I="!R96-H="!K=6YN96X@9V5E;B!C
M:&EL9"!R96-H=&5N('=O<F1E;B!T;V5G979O96=D+B(*"B,Z(&9R86UE=V]R
M:R]5=&EL+U5T:6PN<&AP.C<V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W.`HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(D=E96X@8V]N9FEG=7)A=&EE:6YF
M;W)M871I92!O<&=E9V5V96X@=F]O<B`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N(@IM<V=S='(@(D=E96X@
M8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@=F]O<B!&5%`@5D93
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RXB"FUS9W-T<B`B1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P
M9V5G979E;B!V;V]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B
M1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E;B!V;V]R(%-1
M3"UB97-T86YD(%9&4RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R(")'965N(&MR961I970@;65E<BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(D=E96X@8F5S=&5M;6EN9R!O
M<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.3(P"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(D=E96X@8F5S
M=&%N9"!U<&QO861E9"(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM
M<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(D=E96X@<&EC=&]G<F%M
M;65N(&=E=F]N9&5N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,P(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3$V"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S
M='(@(D5R(&ES(&=E96X@;&]C871I92!I;F=E<W1E;&0N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(D=E96X@;&]C871I92!O<&=E9V5V96XN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(D=E96X@
M8F5R:6-H="!G96QE=F5R9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I
M960N(@IM<V=S='(@(D=E96X@;F%A;2!O<&=E9V5V96XN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@
M(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(D=E96X@9V5T86P@;W!G
M96=E=F5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(D=E96X@8F5L961I9V5N
M9&4@9F]R='5N97,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP
M.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B1V5E;B!W86-H='=O;W)D(&]P9V5G979E
M;B!V;V]R($A45%`@875T:&5N=&EC871I92XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D=E96X@=V%C
M:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!)34%0(&%U=&AE;G1I8V%T:64N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")'965N('=A8VAT=V]O<F0@;W!G96=E=F5N('9A;B!+97)B
M97)O<R!A=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&]G:6XN<&AP.C@T(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(D=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!,;V=I;B!A
M=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D
M+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D=E96X@=V%C:'1W;V]R9"!O
M<&=E9V5V96X@=F]O<B!005-35T0@875T:&5N=&EC871I92XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D=E
M96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!334(@875T:&5N=&EC871I
M92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*
M;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I
M9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O
M<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(D=E96X@<&%D(&YA
M87(@9&4@3W!E;E-33"!B:6YA<GD@;W!G96=E=F5N+B!$92!/<&5N4U-,(&)I
M;F%R>2!I<R!N;V1I9R!O;2!T92`B"B)K=6YN96X@=V5R:V5N(&UE="!02T-3
M(#$R(&1A=&$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(")'965N
M(&AA;F=E;F1E(&EN<V-H<FEJ=FEN9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B1V5E
M;B!Q=6]T82!I;F=E<W1E;&0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`B1V5E;B!L:6YIZW)I;F<B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM
M<V=S='(@(D=E96X@<V-H96ED:6YG<W1E:V5N(&]P9V5G979E;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")'965N('II:F1E;B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I
M;&4B"FUS9W-T<B`B1V5E;B!D97)G96QI:FL@8F5S=&%N9"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B1V5E
M;B!T:6ID96QI:FL@9&ER96-T;W)Y(&)E<V-H:6MB86%R('9O;W(@8V%C:&4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*
M;7-G<W1R(")'965N(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT=V]O<F0@
M=F5R>F]N9&5N+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z
M,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R
M(")'965N(&=E;&1I9V4@6$U,(&1A=&$@=&5R=6=G97-T=75R9"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S0*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX-`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DU"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#$R"FUS9VED(").
M;R!V86QU97,B"FUS9W-T<B`B1V5E;B!W86%R9&5N(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O
M<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*(D=E96X@=F5R<VEE(&=E=F]N9&5N(&EN(&]R:6=I
M;F5L92!C;VYF:6=U<F%T:64N($AE<F=E;F5R965R(&-O;F9I9W5R871I92XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'965N('9E<G-I92!G979O;F1E;B!I
M;B!U=R!C;VYF:6=U<F%T:64N($AE<F=E;F5R965R(&-O;F9I9W5R871I92XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"FUS9VED(").
M;VYE(@IM<V=S='(@(D=E96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I
M(@IM<V=S='(@(D=E96X@*'9E<G!L:6-H="DB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,@IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T
M<B`B3F]O<F0@175R;W!E97,@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:R!E:6QA
M;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DYO
M;W)D96QI:FL@:&%L9G)O;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(")-87)I86YE;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$W-@IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO;W)W96=E;B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q"FUS9VED(").
M;W0@069T97(B"FUS9W-T<B`B3FEE="!N82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S
M='(@(DYI970@=F]O<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(D=E96X@9&ER
M96-T;W)Y(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*;7-G:60@(DYO="!I
M;7!L96UE;G1E9"XB"FUS9W-T<B`B3FEE="!G96EM<&QE;65N=&5E<F0N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM
M<V=I9"`B3F]T('-E="(*;7-G<W1R(").:65T(&EN9V5S=&5L9"(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(P.`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR-3(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V.2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q-@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,S,S(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C8*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R-B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3`U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S0@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4Y,0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-C8Y(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P
M<&]R=&5D+B(*;7-G<W1R(").:65T(&]N9&5R<W1E=6YD+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,#@*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P-3@@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B3F]T
M97,B"FUS9W-T<B`B3F]T:71I97,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I
M;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+B(*;7-G<W1R(").:65T<R!T92!B;&%D97)E;BP@9V$@=&5R=6<N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@
M(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M8F5R(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(D=E=&%L
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M
M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B06%N=&%L(&MA<F%K=&5R<R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T
M"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")!86YT86P@:V]L
M;VUM96XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B06%N=&%L
M(')I:F5N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D=E=&%L
M;&5N(&YI970@;W!G96=E=F5N('9O;W(@8FEJ=V5R:V5N(&EN(&5E;B!D:7-T
M<FEB=71I96QI:G-T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/
M8FIE8W0B"FUS9W-T<B`B3V)J96-T(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D]B
M:F5C=&5I9V5N86%R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P
M-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3V-T86%L(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY
M,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B0F5L961I9VEN9V9I
M;'1E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@
M(D]F9FEC92(*;7-G<W1R(")+86YT;V]R(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(D]U9&4@96X@;FEE=7=E('=A
M8VAT=V]O<F1E;B!D:65N96X@=F5R<V-H:6QL96YD('1E('II:FXN(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S
M<W=O<F0B"FUS9W-T<B`B3W5D92!W86-H='=O;W)D(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@
M;F]T(&-O<G)E8W0N(@IM<V=S='(@(D]U9&4@=V%C:'1W;V]R9"!I<R!N:65T
M(&IU:7-T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q"FUS9VED(")/;6%N(@IM<V=S='(@(D]M
M86XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW
M,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RXB"FUS9W-T<B`B06QL965N($E-05`@<V5R=F5R<R!O;F1E<G-T975N
M96X@9V5D965L9&4@;6%P<&5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
M06QL965N(&)E;&5D:6=E;F1E(&9O<G1U;F5S(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Q
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(E-L96-H="#IZ6X@92UM86EL861R97,@=&]E9V5S=&%A;BXB"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*(D%L;&5E;B!D92!E:6=E;F%A<B!O9B!E96X@<WES=&5E;6)E
M:&5E<F1E<B!M86<@9&4@96EG96YA87)R96-H=&5N('9A;B!E96X@(@HB<VAA
M<F4@=VEJ>FEG96XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O
M0FQO8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B3W!E;B!I;B!E96X@;FEE=7<@<V-H97)M(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N(@IM<V=S='(@(B(*(D]P96Y34TP@9F]U=#H@:V]N(&=E
M96X@9&%T82!U:70@:&5T(&]N9&5R=&5K96YD92!3+TU)344@;VYD97)D965L
M(&AA;&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")/<&5N="!D97IE(&QI;FL@:6X@965N(&YI
M975W('-C:&5R;2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I
M9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")"97-T=7)I;F=S<WET965M
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B
M3W!T:6]N<R(*;7-G<W1R(")/<'1I97,B"@HC.B!S97)V:6-E<R]P<F5F<RYP
M:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B3W!T:65S('9O;W(@
M)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B1V5O<F1E;F1E(&QI
M:G-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*
M;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A;FES=&%T:64B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B
M3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")/<F=A;FES871I92!E96YH
M96ED(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I9"`B
M3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A;FES97)E;B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R(")/<FEG:6YE96P@=&]E<&%S<VEN9W-S:F%B;&]O
M;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*
M;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B3W)I
M9VEN96QE('-J86)L;VYE;B!I;B`E<SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I
M9"`B3W1H97(B"FUS9W-T<B`B06YD97)E(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#D*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(U
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S0@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B
M06YD97)E(&EN9F]R;6%T:64B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")%:6=E
M;F%A<G)E8VAT96XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")004T@875T:&5N=&EC871I92!I<R!N:65T(&)E<V-H:6MB
M86%R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G
M<W1R(")$:6=I=&%L92!01U`@:&%N9'1E:V5N:6YG(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(D=E8V]D965R9&4@4$=0(&1A=&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R(")/<&5N8F%R92!01U`@<VQE=71E;"(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3
M:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B3VYD97)T96ME;F1E+V=E
M8V]D965R9&4@4$=0(&1A=&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*
M;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"!C;V1E(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0
M('-H96QL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B3&EC:'1E(')E
M9V5N(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!286EN(@IM<V=S='(@(E)E9V5N
M(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(D)U:65N
M(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Q"FUS9VED(")032!3;F]W(@IM<V=S='(@(E-N965U=R!N
M82`Q,BXP,"!U=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N
M965U=V)U:65N(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M6F]N(&YA(#$R+C`P('5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")/
M;G=E97)S8G5I96X@;F$@,3(N,#`@=75R(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(X-@IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B
M"FUS9W-T<B`B4$]325@@97AT96YS:64@;VYT8G)E96MT(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!(4"!?4VAE
M;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(E9R:6IE(')U:6UT
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-PIM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K
M:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DT"FUS9VED(")086QA=2(*;7-G<W1R(")0
M86QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3(*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B4&%L97-T:6IN<R!497)R:71O<FEU
M;2P@0F5Z970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(*;7-G:60@(E!A;F%M82(*;7-G<W1R
M(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4*;7-G:60@(E!A<'5A($YE=R!'=6EN
M96$B"FUS9W-T<B`B4&%P=6$@3FEE=7<@1W5I;F5A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-0IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U87DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4&%R
M=&QY($-L;W5D>2(*;7-G<W1R(")'961E96QT96QI:FL@8F5W;VQK="(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G
M:60@(E!A<W-W;W)D(@IM<V=S='(@(E=A8VAT=V]O<F0B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")786-H='=O;W)D(&UE="!S=6-C
M97,@9V5W:6IZ:6=D+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@
M(E=A8VAT=V]O<F0@;VYJ=6ES="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2
M041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E=A8VAT=V]O<F0@:7,@
M=F5R96ES="!V;V]R(%)!1$E54R!A=71H96YT:6-A=&EE+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(E=A8VAT=V]O<F0@;65T(&)E=F5S=&EG
M:6YG(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED
M(")087-S=V]R9#HB"FUS9W-T<B`B5V%C:'1W;V]R9#HB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G
M<W1R(")786-H='=O;W)D.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C
M:"XB"FUS9W-T<B`B5V%C:'1W;V]R9&5N(&UO971E;B!O=F5R965N:V]M96XN
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E
M(@IM<V=S='(@(E!L86MK96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R
M9"(*;7-G<W1R(")0;&%K:V5N('9A;F%F('!R:6MB;W)D(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B4&%T
M:"(*;7-G<W1R(")0860B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(")(86YG96YD
M92!I;G-C:')I:G9I;F=E;CHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-30*;7-G:60@(E!E;W!L92(*;7-G<W1R(")-96YS96XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R(")0<F]C96YT(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")/;F1E<FAO=61S=V5R:WIA86UH
M961E;B!U:71V;V5R96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P
M"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6X_(@IM<V=S='(@(D]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O97)E
M;B!B:6H@86%N;65L9&EN9S\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")296-H="(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@
M(E)E8VAT(%PB)7-<(B!N:65T('9E<G=I:F1E<F0N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D
M(@IM<V=S='(@(E)E8VAT(&=E=V5I9V5R9"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")296-H=&5N(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3@*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN
M+W!E<FUS+VEN9&5X+G!H<#HR,@IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B4F5C:'1E;F)E:&5E<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV.`IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB
M"FUS9W-T<B`B4&5R<V]O;FQI:FME(&EN9F]R;6%T:64B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#,*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R(")(=6ES9&EE<F5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@V"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")0
M:&EL:7!P:6IN96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]O;B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H;W1O
M<R(*;7-G<W1R(")&;W1O)W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP"FUS9VED(")0:71C
M86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T
M<B`B4&EX96QS(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED
M(")0;&%T:71U9&5S(@IM<V=S='(@(E!L871I='5D97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED
M(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B2VQI:R!I
M;B!E96X@8V5L+"!A+G4N8BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS
M9W-T<B`B0F5V97-T:6<L(&1A="!U(&1I="!E;&5M96YT('=I;'0@=F5R=VEJ
M9&5R96XL(&$N=2YB.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@
M=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R
M(")"979E<W1I9RP@9&%T('4@9&ET(&5L96UE;G0@=VEL="!L;W-K;W!P96QE
M;BP@82YU+F(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4V,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B1V5E9B!E96X@;6%A;F0@96X@965N(&IA87(L(&$N=2YB+B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R(")%96X@;F%A;2!V;V]R(&1E(&YI975W92!C871E9V]R:64@:6YV
M;V5R96XL(&$N=2YB+CHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*
M;7-G<W1R(")'965F(&5E;B!G96QD:6<@25`@861R97,L(&$N=2YB+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#`*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I
M;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*(D=E968@965N(&=E;&1I9V4@9&%T
M=6T@82YU+F(N+"!C;VYT<F]L965R(&AE="!A86YT86P@9&%G96X@:6X@9&4@
M;6%A;F0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-PIM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B1V5E9B!E
M96X@9V5L9&EG92!T:6ID+"!A+G4N8BXB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(D=E968@965N('-A;65N=F%T
M=&EN9R!V86X@:&5T('!R;V)L965M+"!A+G4N8BXB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(D=E968@=7<@9V5B<G5I:V5R<VYA86T@96X@=V%C
M:'1W;V]R9"P@82YU+F(N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB
M<WES=&5M+B(*;7-G<W1R("(B"B),965S(&1E('9O;&=E;F1E('1E:W-T+"!A
M+G4N8BX@52!-3T54(&1E('9O;W)W86%R9&5N('1E(&%C8V5P=&5R96X@;VT@
M:&5T("(*(G-Y<W1E96T@=&4@:W5N;F5N(&=E8G)U:6ME;BXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I
M9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R
M(")'965F(&1E(&YI975W92!C871E9V]R:65N86%M+"!A+G4N8BXZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@X"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B4&]L96XB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(E!O;&ET:65K(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X
M.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4&5I;&EN9V5N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,PIM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C0*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B4&]S:71I;VYE<FEN9R!V86X@9&5Z92!A9F)E96QD:6YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@
M(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:71I;VYE
M<FEN9R!V86X@9&5Z92!T86)E;"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDQ"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S0S,30N<&AP.C4Q"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B4W1U=7(@;F%A<B!D97IE
M(&UA<"`H;FEE="!A9F=E9'=O;F=E;B!D;V]R($E-05`I(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H
M;W5R*',I.B`B"FUS9W-T<B`B3F5E<G-L86<@=F%N(&1E(&%F9V5L;W!E;B`E
M<R!U<F5N.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@W
M"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(DYE
M97)S;&%G/&)R("\^:V%N<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L
M9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!V97)E
M:7-T92!,1$%0(&5X=&5N=&EE(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S
M97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ('9E<F5I<W1E('-E<W-I92!E>'1E
M;G1I92!N:65T(&=E=F]N9&5N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C,R"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("),=6-H=&1R=6LB"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I9"`B4')E<W-U<F4@870@<V5A
M(&QE=F5L.B`B"FUS9W-T<B`B3'5C:'1D<G5K(&]P('IE96YI=F5A=3H@(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-`IM<V=I9"`B4')E
M<W-U<F4Z("(*;7-G<W1R("),=6-H=&1R=6LZ("(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"FUS9VED
M(")0<F5V:65W(@IM<V=S='(@(D)E;V]R9&5L96XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*;7-G
M:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")"96]O<F1E96P@9&4@869B965L9&EN9R!I;B!E96X@;FEE=7<@<V-H97)M
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P
M=&EO;G,B"FUS9W-T<B`B5F]R:6=E(&]P=&EE<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O
M8W5M96YT(@IM<V=S='(@(D1O8W5M96YT(&%F9')U:VME;B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+
M97DB"FUS9W-T<B`B4')I=F4@<VQE=71E;"(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B
M4')O8FQE96TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE96UB97-C:')I
M:G9I;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED
M(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96-T96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W-@IM<V=I9"`B4')O
M;7!T('1E>'0B"FUS9W-T<B`B4')O;7!T('1E:W-T(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM
M<V=S='(@(D]P96YB87)E('-L975T96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B3W!E;F)A<F4@<VQE=71E;"!A;&=O<FET:&UE(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U
M8FQI8R!+97D@26YF;R(*;7-G<W1R(")/<&5N8F%R92!S;&5U=&5L:6YF;W)M
M871I92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM
M<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U
M8V-E<W-F=6QL>2XB"FUS9W-T<B`B3W!E;F)A87(O4')I=F4@<VQE=71E;'!A
M87(@;FEE="!G96=E;F5R965R9"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ"FUS9VED(")0
M=65R=&\@4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M
M97-S86=E<R(*;7-G<W1R(")7:7,@8F5R:6-H=&5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-@IM<V=I9"`B46%T87(B"FUS9W-T<B`B475A=&%R(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C8T"FUS9VED(")1=65R>2(*;7-G<W1R(")1=65R>2(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`IM<V=I9"`B475O=&$B"FUS9W-T
M<B`B475O=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(*;7-G<W1R(")24T$@;W!E;F)A<F4@<VQE=71E;"`H)60@8FET*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO
M('-E;&5C=&EO;B(*;7-G<W1R(")+975Z97)O;F1J92!S96QE8W1I92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED
M(")286EN(@IM<V=S='(@(E)E9V5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B5G)O96<@<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(DQA870@
M<F5G96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT.`IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4F5G96YB=6DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I
M9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")296=E;B!E;B!S;F5E=7<B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I
M9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(E)E9V5N(&YA87(@<VYE975W(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(E)A;F1O;2!&;W)T=6YE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")697)H
M;W5D:6YG(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3&5Z96XB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PIM<V=I9"`B4F5A9"!M97-S86=E
M<R(*;7-G<W1R("),965S(&)E<FEC:'1E;B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R("(E<R!E8VAT('9E<G=I:F1E<F5N/R!$97IE(&)E=V5R:VEN
M9R!K86X@;FEE="!O;F=E9&%A;B!G96UA86MT('=O<F1E;BXB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB1V5B
M<G5I:V5R<V1A=&$@=F%N(&=E8G)U:6ME<B`E<R!E8VAT('9E<G=I:F1E<F5N
M/R!$97IE(&)E=V5R:VEN9R!K86X@;FEE="`B"B)O;F=E9&%A;B!G96UA86MT
M('=O<F1E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R(")(97)H86%L="!U=R!V;W)I9V4@8F5W97)K:6YG(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*
M;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B5F5R=F5R<V5N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z(@IM<V=S='(@(E9E<G9E<G,@9'EN86UI<V-H92!M96YU
M(&]N9&5R9&5L96XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B4&]R=&%L=V5E
M<F=A=F4@=F5R=F5R<V5N.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E
M9V5X(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,0IM<V=I9"`B
M4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B0F5T<F5K:VEN9V5N(&)R
M;W=S97(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS
M9W-T<B`B2&5R;&%D96XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,PIM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R(")/<&UE<FMI;F=E;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@(E)E;6]T92!397)V97)S(@IM
M<V=S='(@(E-E<G9E<G,@;W`@869S=&%N9"(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E523"!O<"!A9G-T86YD
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E;6]V92(*;7-G<W1R(")697)W
M:6ID97)E;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM
M<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D)L;VL@=F5R=VEJ9&5R96XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34Y
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(DMO;&]M('9E<G=I:F1E
M<F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B3W!M86%K
M('9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,C@*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E!A87(@=F5R=VEJ9&5R
M96XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@HB5F5R=VEJ9&5R(&AE="!O<&=E<VQA9V5N('-C
M<FEP="!U:70@9&4@=&EJ9&5L:6IK92!D:7)E8W1O<GD@;W`@9&4@<V5R=F5R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*;7-G<W1R(")697)W:6ID
M97(@9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T
M:&4@9&]C=6UE;G0B"FUS9W-T<B`B5F5R=VEJ9&5R(&1E>F4@;F]D92!U:70@
M:&5T(&1O8W5M96YT(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B1V5B<G5I:V5R
M('9E<G=I:F1E<F5N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*
M;7-G<W1R(")697)W:6ID97(@9V5B<G5I:V5R.B`E<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M(")697)Z;V5K(&MO;B!N:65T('=O<F1E;B!B96%N='=O;W)D+B!'97)E=&]U
M<FYE97)D92!F;W5T8V]D93H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T
M(&)E(&9O=6YD+B(*;7-G<W1R(")$92!G979R86%G9&4@<V5R=FEC92!K;VX@
M;FEE="!W;W)D96X@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5F5R96ES=&4@7"(E
M<UPB(&YI970@;W!G96=E=F5N(&EN("5S(&-O;F9I9W5R871I92XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,2!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C8W.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S,Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")6
M97)E:7-T92!<(B5S7"(@;FEE="!O<&=E9V5V96X@:6X@5D93(&-O;F9I9W5R
M871I92XB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B5F5R96ES=&4@7"(E<UPB(&YI
M970@;W!G96=E=F5N(&EN(&-O;F9I9W5R871I92XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(E9E<F5I<W0@=F5L9"(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,Q(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,R,0HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(DAE<G-T96QL96XB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O
M<F0B"FUS9W-T<B`B4F5S970@=V%C:'1W;V]R9"(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(E)E<V5T('5W('=A8VAT=V]O<F0B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`B5F]O<F=A86YD92!Q=65R>2!H97)S=&5L;&5N(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(Y(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT871E
M;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B
M"FUS9W-T<B`B5&5R=6<@;F%A<B!O<'1I97,B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`B5'EP(&YI975W('=A8VAT=V]O<F0@;W!N:65U=R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3<*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4F5U;FEO;B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
M0V]N9FEG=7)A=&EE('1E<G5G>F5T=&5N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S-0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I;VYS(@IM
M<V=S='(@(E)I8V@@5&5X="!%9&ET;W(@;W!T:65S(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(E)A861S
M96QS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0X"FUS9VED(")2:6=H="(*;7-G<W1R(")296-H=',B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!H96%D
M97(B"FUS9W-T<B`B4F5C:'1S92!K;W`B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,#DY"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B4F5C
M:'1S92!W86%R9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N
M+BXB"FUS9W-T<B`B4FE?:F5I9V5N<V-H87!P96XN+BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(E)O;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`B4F]E;65N:>LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(C$X,"!D<F%A:65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B3F%A
M<B!L:6YK<R!D<F%A:65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(DYA87(@<F5C:'1S(&1R86%I96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R
M=&EE<R(*;7-G<W1R(")2:6H@96EG96YS8VAA<'!E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@
M(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E)I:B!E:6=E;G-C:&%P<&5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*
M;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)I:F5N.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U
M;&5S(@IM<V=S='(@(DQI;FGK<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T
M<B`B3&EN:>MR:6YG('IA;"!V97)S8VAI:FYE;B!T=7-S96X@86QL92!R:6IE
M;B!E;B!K;VQO;6UE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(DQI;FGK<FEN9R!Z86P@
M86QL965N('1U<W-E;B!K;VQO;6UE;B!V97)S8VAI:FYE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(DQI;FGK<FEN9R!Z86P@86QL965N('1U<W-E;B!R:6IE;B!V97)S8VAI
M:FYE;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*
M;7-G<W1R(")3=&%R=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.0IM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<W-I<V-H92!&961E<F%T:64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`P"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@
M(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")#<GEP
M=&]G<F%F:7-C:&4@4R]-24U%(&AA;F1T96ME;FEN9R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC
M<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%(&=E8V]D965R9"!B97)I
M8VAT(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I
M9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")305-,(&%U=&AE;G1I8V%T:64@:7,@;FEE="!B97-C:&EK8F%A<BXB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@
M365S<V%G:6YG(@IM<V=S='(@(E--4R!V97)S='5R96XB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@
M<VAE;&PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<T"FUS9VED
M(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-1
M3"!S=&%T96UE;G0@=F]O<B!W86%R9&5Z;V5K;W!D<F%C:'1E;B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R
M(")34T@B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S
M='(@(E-50T-%4R(*"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3
M:&5L;"(*;7-G<W1R(")37U%,('-H96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B
M6F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`W"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T
M<B`B4W0@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q"FUS9VED(")386EN="!+:71T
M<R!A;F0@3F5V:7,B"FUS9W-T<B`B4W0@2VET=',@96X@3F5V:7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,SD*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-T($QU8VEA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X.0IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;B(*;7-G<W1R(")3="!0:65R<F4@96X@36EQ=65L;VXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0T"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<R(*;7-G<W1R(")3="!6:6YC96YT(&5N(&1E($=R96YA9&EN97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED
M(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B6F5L9F1E(&9R86UE("A?
M<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q"FUS9VED(")386UO82(*;7-G<W1R(")3
M86UO82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3(*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T
M<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38*;7-G:60@(E-A;R!4;VUE
M(&%N9"!0<FEN8VEP92(*;7-G<W1R(")386\@5&]M92!E;B!0<FEN8VEP92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A
M=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R(")3871E;&QI971P<F]V:61E<B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")3
M875D:2!!<F%B:>LB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B3W!S;&%A;B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB(&]P<VQA86XB"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(B5S(&]P<VQA86XB"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`B3W!T:65S(&]P<VQA86XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D
M:7)E8W1O<GDN(@IM<V=S='(@(B(*(D=E9V5N97)E97)D92!C;VYF:6=U<F%T
M:64@86QS(%!(4"!S8W)I<'0@;W!G97-L86=E;B!I;B!D92!T:6ID96QI:FME
M("(*(F1I<F5C=&]R>2!V86X@=7<@<V5R=F5R+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S(&-O;F9I9W5R871I92!O<&=E
M<VQA9V5N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B4V5T=7`@=7!G<F%D92!S8W)I<'0@;W!G97-L
M86=E;B!N86%R.B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*
M;7-G<W1R(")'97-P<F5I9&4@;VYW965R<V)U:65N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(E=E=&5N
M<V-H87`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H
M(@IM<V=S='(@(EIO96ME;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(EIO96MM86-H
M:6YE<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-34*;7-G:60@
M(E-E;&5C="!&:6QE<R(*;7-G<W1R(")+:65S(&)E<W1A;F1E;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#4*;7-G:60@
M(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L96-T965R(&5E;B!D871U;2(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE
M8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B4V5L96-T965R(&5E;B!G<F]E
M<"!O;2!T;V4@=&4@=F]E9V5N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E
M;&5C=&5E<B!E96X@;FEE=7=E(&5I9V5N86%R(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS
M9W-T<B`B4V5L96-T965R(&5E;B!S97)V97(B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B
M"FUS9W-T<B`B4V5L96-T965R(&5E;B!G96)R=6EK97(@;VT@=&]E('1E('9O
M96=E;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B06QL97,@<V5L96-T
M97)E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#,*;7-G:60@
M(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")396QE8W1E
M97(@86QL92!D871U;6-O;7!O;F5N=&5N+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O
M8FIE8W0B"FUS9W-T<B`B4V5L96-T965R(&5E;B!O8FIE8W0B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")3
M96QE8W0@;F]N92(*;7-G<W1R(").:65T<R!S96QE8W1E<F5N(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82XB"FUS9W-T<B`B(@HB4V5L96-T965R(&1E(&)E;F]D:6=D92!K87)A
M:W1E<G,@=6ET(&1E(&]N9&5R<W1A86YD92!V86MJ97,N(%4@:W5N="!D97IE
M(&1A;B`B"B)K;W!IZW)E;B!E;B!P;&%K:V5N(&EN(&AE="!T96MS=&=E8FEE
M9"XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L
M96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-T965R(&AE
M="!D871U;7-C:&5I9&EN9W-T96ME;CHB"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS
M9W-T<B`B4V5L96-T965R(&AE="!D871U;69O<FUA870Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E-E
M;&5C=&5E<B!D92!I9&5N=&ET96ET(&1I92!U('=I;'0@=VEJ>FEG96XZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C=&5E<B!H970@=&EJ
M9'-C:&5I9&EN9W-T96ME;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B
M4V5L96-T965R(&AE="!T:6ID<V9O<FUA870Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(E-E;&5C=&5E<B!T=V5E(&]V97)E96YK;VUE;F1E
M('9E;&1E;BXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED
M(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(E-E;&5C=&5E
M<B!U=R!K;&5U<G-C:&5M82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C4R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM
M<V=S='(@(E-E;&5C=&5E<B!U=R!G97=E;G-T92!T86%L.B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L
M96T@4F5P;W)T(@IM<V=S='(@(E!R;V)L965M<F%P<&]R="!V97)Z96YD96XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T
M,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B5F5R>F5N9"!335,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S"FUS9VED(")396YE9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B4V5N<V]R.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<'1E
M;6)E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY
M"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4V5R=FGK
M(&5N($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")397)I
M96YU;6UE<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*
M;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(E-E<G9E<F1A=&$@9F]U="!O9B!N:65T(&)E<V-H:6MB86%R+B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI
M;B(*;7-G<W1R(")397-S:65B96AE97)D97(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I
M;VX@240@97AP:7)E9"XB"FUS9W-T<B`B4V5S<VEE($E$('9E<FQO<&5N+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
M4V5S<VEE<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G
M:60@(E-E="(*;7-G<W1R("));G-T96QL96XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B(@HB26YS=&5L;&5N('9A;B!O<'1I97,@;VT@=2!T;V4@=&4@
M<W1A86X@=7<@=V%C:'1W;V]R9"!T92!R97-E='1E;BP@=V%N;F5E<B!U("(*
M(F1I="!B96YT('9E<F=E=&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,3@*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W
M86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"B))
M;G-T96QL96X@=F%N('-E<G9E<G,@;W`@869S=&%N9"!D:64@=2!W:6QT(&)E
M;F%D97)E;B!V86YU:70@=7<@<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-PIM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("));G-T96QL
M96X@=F%N('5W(&=E=V5N<W1E('1A86PL('1I:F1Z;VYE(&5N(&1A='5M;W!T
M:65S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*
M(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@
M<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS
M+B(*;7-G<W1R("(B"B));G-T96QL96X@=F%N('5W(&]P<W1A<G1T;V5P87-S
M:6YG+"!K;&5U<G-C:&5M82P@<&%G:6YA=F5R=F5R<VEN9R!E;B!A;F1E<F4@
M(@HB=V5E<F=A=F5O<'1I97,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-PIM<V=I9"`B4V5T=7`B"FUS9W-T<B`B26YS=&5L;&5N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&)E<V-H:6MB86%R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S
M<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B5F5R<V-H:6QL
M96YD92!L;V-A=&EE<R!M;V=E;&EJ:R!M970@9&4@<&%R86UA=&5R.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`S"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H
M96QL96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DX"FUS9VED
M(")3:&]P<&EN9R(*;7-G<W1R(")7:6YK96QE;B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(DMO<G1E('-A;65N=F%T=&EN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R(")$:65N96X@<VYE;'1O971S
M96X@=F]O<B!D92!M965S=&4@;&EN:W,@9V5D969I;FEE97)D('1E('=O<F1E
M;C\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM
M<V=I9"`B4VAO=R(*;7-G<W1R(")7965R9V5V96XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E9E<G-C:&EL;&5N(&QA
M=&5N('II96X@='5S<V5N(&1E(&AU:61I9V4@;W!G97-L86=E;B!C;VYF:6=U
M<F%T:64@96X@9&4@(@HB;FEE=7=E(&=E9V5N97)E97)D92!C;VYF:6=U<F%T
M:64N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("),
M86%T<W1E(&%A;FUE;&1I;F=S=&EJ9"!W965R9V5V96X@8FEJ(&%A;FUE;&1E
M;C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(D]P=&EE('=E
M97)G979E;B!O;2!O<FEG:6YE96P@=&4@8F5W87)E;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(W.34*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S
M='(@(DMI97IE<B!W965R9V5V96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M(@IM<V=S='(@(E1A8F5L8F5W97)K:6YG<W1A86MB86QK('=E97)G979E;C\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*
M;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@
M(B5S(&UE;G4@86%N(&1E(&QI;FME<FMA;G0@=V5E<F=E=F5N/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R(")486)E;&-E;&5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T
M97(@=V5E<F=E=F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486)E;&5I9V5N<V-H87!P96X@
M9&EA;&]O9W9E;G-T97(@=V5E<F=E=F5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&%B
M96QR:6IE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS=&5R('=E97)G979E;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B069B965L9&EN9W-E:6=E;G-C:&%P<&5N(&1I86QO;V=V
M96YS=&5R('=E97)G979E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(E5P;&]A9"!W965R
M9V5V96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,@IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")"=6EE;B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W
M97)S($5A<FQY(@IM<V=S='(@(D)U:65N('9R;V5G(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@
M3&%T92(*;7-G<W1R(")"=6EE;B!L86%T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(D)U:65N(&EN(&1E(&YA8FEJ:&5I9"(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B5F5R:VQE:6YE;B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U
M.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS
M9W-T<B`B5F5R:VQE:6X@;V8@=F5R<&QA871S(&YA8G5R:6=E(&)L;VMK96X@
M965R<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q"FUS9VED(")3:65R<F$@3&5O;F4B"FUS
M9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("));G1E:V5N
M96XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM
M<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(DAA;F1T96ME;FEN9R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N
M871U<F4@06QG;W)I=&AM(@IM<V=S='(@(DAA;F1T96ME;FEN9R!A;&=O<FET
M:&UE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-@IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@
M(E-I;F=A<&]R92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3$R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#4*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B1W)O;W1T92(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA
M:6YT96YA;F-E(@IM<V=S='(@(D]N9&5R:&]U9"!O=F5R<VQA86XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]W86MI:F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`X"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V
M96YIZR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(E-N965U=R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H
M;W=E<B(*;7-G<W1R(")3;F5E=7=V;&%A9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B4VYE975W8G5I96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY
M(@IM<V=S='(@(G-N965U=V)U:65N('9R;V5G(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R
M<R!,871E(@IM<V=S='(@(E-N965U=V)U:65N(&QA870B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@
M(E-N965U=V1I97!T93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#D*
M;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(E-N
M965U=V5Q=6EV86QE;G0@:6X@=V%T97(Z("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(*;7-G
M:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R(")3;VQO;6]N(&5I;&%N9&5N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-`IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA
M;&GK(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG
M<R`F(%!O96US(@IM<V=S='(@(DQI961E<F5N(&5N(&=E9&EC:'1E;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,#@*;7-G:60@(E-O<G0@;W)D
M97(@<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E97)V;VQG;W)D92!S96QE8W1I
M92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D)R
M;VYA9')E<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-34*;7-G:60@(E-O=71H($%F<FEC82(*
M;7-G<W1R("):=6ED($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T
M<B`B6G5I9"!%=7)O<&5E<R`H25-/+3@X-3DM,RDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$*
M;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S(@IM<V=S='(@(EIU:60@1V5O<F=IZR!E;B!D92!:=6ED(%-A;F1W
M:6-H(&5I;&%N9&5N(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*
M;7-G<W1R("):=6ED96QI:FL@:&%L9G)O;F0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T
M=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")3<&%T:>MR:6YG('1U<W-E
M;B!A86YG<F5N>F5N9&4@8V5L;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B4W!A=&GK<FEN
M9R!T=7-S96X@:6YH;W5D(&5N(')A;F0@:6X@8V5L(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B4V-H
M96ED:6YG<W1E:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4U"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(E-P
M871IZW)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM
M<V=S='(@(E-P871IZW)I;F<@96X@=G)I:F4@<G5I;71E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#`*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86YJ92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B4W!A
M;2(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA
M;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B4W!E8VEA86P@:V%R86MT97(@
M:6YV;V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")#96P@
M;W!S<&QI='-E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R
M(")+;VQO;2!O<'-P;&ET<V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM
M<V=S='(@(E)I:B!O<'-P;&ET<V5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B4W!O<G0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#$*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HV-@IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A87)D
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R
M96LB"FUS9W-T<B`B4W1A<B!4<F5K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDQ"FUS9VED
M(")3=&%R="!Y96%R(@IM<V=S='(@(E-T87)T:F%A<B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0
M<F]V:6YC92(*;7-G<W1R(")3=&%A="!O9B!P<F]V:6YC:64B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(E-T871U<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(W.3<*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D]P<VQA9V9O
M<FUA870B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B061R97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED
M(")3=')I:V5T:')O=6=H(@IM<V=S='(@(D1O;W)H86QE;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM
M<V=S='(@(E-T<FEN9VQI:G-T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@W,PIM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B
M"FUS9W-T<B`B4W1R:7`@9&]M96EN('9A;B!H970@861R97,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS
M9VED(")3='EL92!;0U-372(*;7-G<W1R(")3=&EJ;"!;0U-372(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(EIO(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YI970@9V5V
M;VYD96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")/;F1E<G=E<G`B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B"FUS9W-T<B`B
M0F5V97-T:6=E;B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(E9E<GIO96L@
M=F5R<W1U=7)D(&]M(%PB)7-<(B!A86X@:&5T('-Y<W1E96T@=&]E('1E('9O
M96=E;BX@52!K=6YT(&YI970@(@HB86%N;65L9&5N('1O="!U=R!V97)Z;V5K
M(&ES(&=O961G96ME=7)D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")3
M=6)S8W)I<'0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U
M<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5C8V5S(@H*(SH@
M861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(")<
M(B5S7"(@;65T('-U8V-E<R!A86X@:&5T('-Y<W1E96T@=&]E9V5V;V5G9"XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M+B(*;7-G<W1R(")$871A('9A;B!G96)R=6EK97(@7"(E
M<UPB(&UE="!S=6-C97,@=6ET(&AE="!S>7-T965M('9E<G=I:F1E<F0N(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&UE="!S=6-C97,@=F5R=VEJ9&5R
M9"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B7"(E<UPB(&UE="!S=6-C97,@=6ET(&AE="!S>7-T965M
M('9E<G=I:F1E<F0N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B0V]N9FEG=7)A=&EE(&UE
M="!S=6-C97,@=&5R=6=G97IE="X@5F5R;FEE=7<@;VT@=VEJ>FEG:6YG96X@
M=&4@>FEE;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0F%C:W5P8V]N9FEG
M=7)A=&EE(&UE="!S=6-C97-S(&]P9V5S;&%G96XN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(D)A8VMU<&-O;F9I9W5R871I96)E<W1A;F0@)7,@;65T('-U
M8V-E<W,@;W!G97-L86=E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB
M(@IM<V=S='(@(EPB)7-<(B!M970@<W5C8V5S(&)I:F=E=V5R:W0B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@
M)7,B"FUS9W-T<B`B)7,@;65T('-U8V-E<R!G97-C:')E=F5N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4V]E9&%N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM
M<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")386UE;G9A='1I;F<B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@
M(EIO;G-O<&=A;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B6F]N<V]N9&5R9V%N9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")3=6YN
M>2(*;7-G<W1R("):;VYN:6<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(EIO;G-O<&=A;F<B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(EIO;G-O
M<&=A;F<O6F]N<V]N9&5R9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("):;VYS;W!G
M86YG.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS
M9VED(")3=6YS970B"FUS9W-T<B`B6F]N<V]N9&5R9V%N9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM
M<V=S='(@(EIO;G-O;F1E<F=A;F<Z("(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM
M<V=S='(@(E-U<&5R<V-R:7!T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")/;F1E<G-T975N:6YG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R
M:6YA;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")!8VAT97)N86%M(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P.0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M(")3<&ET<V)E<F=E;B!E;B!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y"FUS
M9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL86YD(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P-0IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(EIW961E;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("):=VET<V5R;&%N9"(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC
M(&QO9R!D96QE=&5D(@IM<V=S='(@(E-Y;F,@;&]G('9E<G=I:F1E<F0B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS
M9W-T<B`B4WEN8TU,(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E-Y;G1A>&9O=70@:6X@>F]E:W1E<FUE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FES
M8VAE($%R86)I<V-H92!297!U8FQI96LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M(")/;G=E97)S8G5I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@
M(D]N=V5E<G-B=6EE;B!E;B!W:6YD97)I9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R(*;7-G
M<W1R(")/;G=E97)S8G5I96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T
M<B`B3VYW965R<V)U:65N('9R;V5G(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T
M82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6(&)E
M<W1A;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@
M(E1A8F5L96EG96YS8VAA<'!E;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R
M(")486)E;'-E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS
M9W-T<B`B5&%B96QE:6=E;G-C:&%P<&5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-`IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A:7=A;BP@4')O=FEN8VEE('9A
M;B!#:&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4*;7-G:60@(E1A:FEK:7-T86XB"FUS
M9W-T<B`B5&%D>FII:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-0IM<V=I9"`B5&%N
M>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ86YI82P@
M5F5R96YI9V1E(%)E<'5B;&EE:R!V86XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S
M='(@(D1O96PZ(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S(@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5&%K96XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B
M5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(")496QE9F]O;FYU;6UE<B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R(")496UP97)A='5U<B!V86X@:&5T(&%F9V5L;W!E
M;B!U=7(Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")4
M96UP97)A='5R92(*;7-G<W1R(")496UP97)A='5U<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B
M"FUS9W-T<B`B5&5M<&5R871U=7(Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U
M<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP
M97)A='5U<CQB<B`O/B@E<TAO;V<E<R\E<TQA86<E<RD@)F=R9#LE<R(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(E-J86)L;V]N(%PB)7-<(B!N:65T(&=E=F]N9&5N+B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")3:F%B;&]O;F)E:&5E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R
M-PIM<V=I9"`B5&5X="(*;7-G<W1R(")496MS="(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")!;&QE
M96X@=&5K<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(E1E
M:W-T('5I=&QI:FYE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B5&5K<W1B
M;W9E;FMA;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")$;R(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R
M(")4:&%I<R`H5$E3+38R,"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T"FUS9VED(")4:&%I
M;&%N9"(*;7-G<W1R(")4:&%I;&%N9"(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")$92!&5%`@97AT96YT:64@:7,@;FEE="!B
M97-C:&EK8F%A<BXB"@HC.B!F<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H
M<#HU-0IM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R(")(970@9V5S8VAI961E;FES<WES=&5E;2!I<R!U:71G97-C:&%K
M96QD+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B1&4@2&]R
M9&4O2V]L86(@:6YT96=R871I92!O;F1E<G-T975N="!<(B5S7"(@;FEE="(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G
M:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM
M<V=S='(@(DAE="!)35-0(&QO9R!K;VX@;FEE="!W;W)D96X@9V5I;FET:6%L
M:7-E97)D+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I
M9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>2(*;7-G<W1R(")$92!-86EN=&5N86YC93HZ(&-L87-S('=E<F0@
M;FEE="!G96QA9&5N(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R
M+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N
M($5X:71I;F<N(@IM<V=S='(@(DAE="!/<'1I97-S8VAE<FT@:7,@9V5S;&]T
M96XN($%F<VQU:71E;BXB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM
M<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A
M;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"B)$92!B96AE97)D
M97(@9&EE;G0@965N('!E<FUA;F5N="!R96-H=&5N8F%C:V5N9"!T92!C;VYF
M:6=U<F5R96X@86QS('4@(@HB<F5C:'1E;B!W:6QT(&=E8G)U:6ME;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")!;&QE
M96X@9&4@;VYD97)K86YT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB2&5T
M(&-O;G1A8W0@240@;G5M;65R(&ES(&YI970@;W!G96=E=F5N+"!L965G(&=E
M;&%T96X@;V8@:7,@;FEE="!G979O;F1E;B!I;B`B"B)D92!D871A8F%S92XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*
M;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DAE="!A9')E<R!I<R!M970@
M<W5C8V5S(&%A;B!U=R!A9')E<V)O96L@=&]E9V5V;V5G9"XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@
M9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)(970@;&]S
M9V5K;W!P96QD92!01U`@;VYD97)T96ME;FEN9W-B;&]K(&ES('9E<F5I<W0@
M;VT@:&5T(&]N9&5R=&5K96YD92`B"B)B97)I8VAT('1E('9E<FEF:>MR96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@
M96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD
M("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B(@HB2&5T(&1I<W1R=6)U
M=&EE;&EJ<W0@240@:7,@;FEE="!O<&=E9V5V96XL(&QE96<@9V5L871E;B!O
M9B!I<R!N:65T(&=E=F]N9&5N("(*(FEN(&1E(&1A=&%B87-E+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS
M9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M(@IM<V=S='(@(D1E(&1I<W1R:6)U=&EE;&EJ<W0@:7,@;FEE="!O<&=E9V5V
M96XN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(D1E(&-O9&5E<FUO9V5L:6IK:&5D96X@
M=F5R96ES96X@965N(&)E=F5I;&EG9&4@=V5B=F5R8FEN9&EN9RXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(DAE="!B
M97-T86YD("5S(&1I96YT(&5E;B`E<R!I;G-T96QL:6YG('1E(&)E=F%T=&5N
M+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM
M<V=S='(@(DAE="!B97-T86YD("5S(&1I96YT(&5N:6=E("5S(&EN<W1E;&QI
M;F=E;B!T92!B979A='1E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,C8*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT
M;R!I='-E;&8N(@IM<V=S='(@(DAE="!B97-T86YD(&MA;B!N:65T(&YA87(@
M>FEC:'IE;&8@9V5K;W!I965R9"!W;W)D96XN(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82XB"FUS9W-T<B`B2&5T(&)E<W1A;F0@8F5V871T92!G965N(&1A=&$N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B2&5T('9O;&=E
M;F1E('II:FX@9&4@:V]P<&5N('9A;B!D:70@;65S<V%G92]R9F,X,C(@8F5R
M:6-H="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N(@IM<V=S='(@(B(*(E9A;B!D92!V;VQL961I9R!S8VAE<FT@
M;6]D92!I<R!B96ME;F0L(&1A="!D:70@<')O8FQE;65N(&MA;B!V97)O;W)Z
M86ME;B!M970@(@HB26YT97)N970@17AP;&]R97(L('9A;G=E9V4@8G)O=W-E
M<F)U9W,@=V%A<B!W:6H@;FEE="!O;6AE96X@:W5N;F5N+B!(970@:7,@(@HB
M;6]G96QI:FL@9&%T('4@<F]M;65L(&EN(&AE="!B965L9'-C:&5R;2P@9V5B
M<F5K(&%A;B!E9&ET;W)F=6YC=&EE<R!E;B]O9B`B"B)R86YD;VT@8G)O=W-E
M<BT@8W)A<VAE<R!E<G9A87)T+B!786YN965R('5W('-Y<W1E96T@5VEN9&]W
M<R`Y>"!I<RP@:7,@:&5T("(*(G=A87)S8VAI:FYL:6IK(&1A="!U(&5E;B`G
M06QG96UE;F4@0F5V96EL:6=I;F=S($9O=70G(&MR:6IG="P@96X@;W!N:65U
M=R`B"B)D:65N="!T92!H97)S=&%R=&5N+EQ<;EQ<;E4@8F5N="!G97=A87)S
M8VAU=V0N($1R=6L@;W`@3TL@=V%N;F5E<B!U('1O8V@@9&4@(@HB=F]L;&5D
M:6<@<V-H97)M(&5D:71O<B!W:6QT('!R;V)E<F5N+B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT
M:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$92!I9&5N
M=&ET96ET(%PB)7-<(B!I<R!V97)W:6ID97)D+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H
M92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(D%L;&5E;B!D92!L:6YK
M97)K86YT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W
M"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M
M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T
M<B`B(@HB1&4@<&QA871S('9A;B!H970@1VYU4$<@<')O9W)A;6UA(&1I96YT
M(&]P9V5G979E;B!T92!W;W)D96X@:6X@9&4@(@HB0W)Y<'1?<&=P.CH@8VQA
M<W,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN
M(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@
M8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*(DAE="!B97)I
M8VAT('9E<G-T=75R9"!O<"`E<R!A86X@)7,@;65T(&]N9&5R=V5R<"!<(B5S
M7"(@:7,@=V5E<F=E9V5V96XN7&XB"B)$:70@:7,@9V5E;B!G87)A;G1I92!D
M870@:&5T(&)E<FEC:'0@:7,@9V5L97IE;B!O9B!B96=R97!E;BXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED(")4:&4@;F%M92!T
M;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T
M<B`B1&4@;F%A;2!D:64@9V5B<G5I:W0@=V]R9'0@8FEJ(&QI;FME;B!N86%R
M(&1E(&YI975W(&)E<FEC:'0@<&%G:6YA(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M
M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(DAE="!A86YT86P@=F5L9&5N(&1I
M96YT(&YU;65R:65K('1E('II:FXN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@
M:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S
M+B(*;7-G<W1R(")$92!O<&5N<W-L(&UO9'5L92!I<R!V97)E:7-T('9O;W(@
M9&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE
M('-I>F4B"FUS9W-T<B`B(@HB1&4@=F]O<FME=7)S:6YS=&5L;&EN9R!<(B5S
M7"(@:V]N(&YI970@=V]R9&5N(&]P9V5S;&%G96XL(&]M9&%T(&1E(&1A=&$@
M9&4@(@HB;6%X:6UU;2!T;V5L86%T8F%R92!G<F]O='1E(&]V97)S8VAR:6ID
M="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP
M:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*(DAE="!P<F]G<F%M;6$@;VT@9&ET
M(&1A=&%T>7!E("@E<RD@=&4@8F5K:6IK96XL('=E<F0@;FEE="!O<"!H970@
M<WES=&5E;2`B"B)G979O;F1E;BXB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B2&5T(&%A;FAA;&EN
M9W-T96ME;B!D:65N="#KZVX@96YK96P@=&5K96X@=&4@>FEJ;BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W
M"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R
M(")!;&QE96X@9&4@<F5C:'1E<BT@96X@;&EN:V5R:V%N="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G
M:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")!;&QE96X@
M9&4@<F5C:'1E<FMA;G0B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BXB"FUS9W-T<B`B2&5T('-C:&5I9&EN9W-T96ME;B!D:65N
M="#KZVX@96YK96P@=&5K96X@=&4@>FEJ;BXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")$92!S97)V
M97(@7"(E<UPB(&ES('9E<G=I:F1E<F0N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(D1E('-E<G9E<B!<
M(B5S7"(@:7,@;W!G97-L86=E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G<W1R(")(970@86%N;65L9&EN9W-V
M97)Z;V5K('9O;W(@)7,@:7,@=F5R=VEJ9&5R9"XB"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X
M:7-T+B(*;7-G<W1R(")$92!O<&=E9V5V96X@<FEJ("@E9"D@8F5S=&%A="!N
M:65T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E
M<R!N;W0@97AI<W0N(@IM<V=S='(@(DAE="!T:6ID96QI:FL@8F5S=&%N9"!<
M(B5S7"(@8F5S=&%A="!N:65T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,#(*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@
M;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B1&4@:6YG
M979O97)D92!T96MS="!K;VUT(&YI970@;W9E<F5E;B!M970@9&4@=&5K<W0@
M;W`@:&5T('-C:&5R;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T
M;VT@<VED97,@;VYL>2(*;7-G<W1R(")!;&QE96X@9&4@8F]V96XM(&5N(&]N
M9&5R:V%N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S
M='(@(D%L;&5E;B!D92!B;W9E;FMA;G0B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")$92!U<&QO861E
M9"!D871A(&ES(&YA(&1E('9O;W)G86%N9&4@<W1A<"!V97)L;W)E;B!G96=A
M86XN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M
M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(DAE="!U<&QO
M861E9"!B97-T86YD(&ES(&YI970@;W!G97-L86=E;BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#D@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$Q,`IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(DAE="!W96%T:&5R+F-O;2!B;&]K(&ES
M(&YI970@8F5S8VAI:V)A87(N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E
M<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B5&AE;6%D:7)E8W1O<GD@7"(E<UPB
M(&YI970@9V5V;VYD96XN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L
M92XB"FUS9W-T<B`B1V5E;B!O<'1I97,@8F5S8VAI:V)A87(N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S4P"FUS9VED(")4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`B17(@>FEJ;B!G965N(&]N9&5R9&5L96XL('=E;&ME(&EN;&EN
M92!W965R9V5G979E;B!K=6YN96X@=V]R9&5N+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D5R('II:FX@=&4@=F5E;"!K
M87)A:W1E<G,@:6X@9&ET('9E;&0N(%4@:&5E9G0@)7,@:V%R86MT97)S(&]P
M9V5G979E;CL@=2`B"B)D:65N="!M:6YD97(@9&%N("5S(&]P('1E(&=E=F5N
M+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E
M<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(D5E;B!P<F]B;&5E;2!M
M970@:&5T('1O979O96=E;B!V86X@7"(E<UPB(&%A;B!H970@<WES=&5E;3H@
M)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)%96X@<')O
M8FQE96T@;65T(&AE="!V97)W:6ID97)E;B!V86X@9&%T82!V86X@9V5B<G5I
M:V5R(%PB)7-<(B!U:70@:&5T("(*(G-Y<W1E96TZ("(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")%96X@<')O8FQE96T@;65T(&AE="!V97)W:6ID97)E;B!V86X@7"(E
M<UPB('5I="!H970@<WES=&5E;3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")%96X@<')O8FQE96T@;65T(&AE
M="!B:6IW97)K96X@=F%N(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+B(*;7-G<W1R(")%96X@<')O8FQE96T@;65T(&1E(&)E
M<W1A;F1S=7!L;V%D.B!'965N("5S('=E<F0@9V5U<&QO860N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB
M86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D5E;B!P<F]B
M;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($AE="`E<R!I<R!G<F]T97(@
M9&%N(&1E(&UA>&EM=6T@(@HB=&]E;&%A=&)A<F4@9W)O;W1T92`H)60@8GET
M97,I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+B(*;7-G<W1R("(B"B)%96X@<')O8FQE96T@;65T(&1E(&)E
M<W1A;F1S=7!L;V%D.B!(970@)7,@:7,@<VQE8VAT<R!G961E96QT96QI:FL@
M9V5U<&QO860N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B165N(&9O=70@8FEJ(&AE
M="!B96MI:FME;B!V86X@9&ET(&)E<FEC:'1O;F1E<F1E96PB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM
M<V=S='(@(D5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E;B!V86X@9&4@861R
M97-D871A+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N
M9&%R(&1A=&$N(@IM<V=S='(@(D5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E
M;B!V86X@9&4@:4-A;&5N9&%R9&%T82XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B
M"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@HB165N(&9O=70@:6X@:&5T
M(&-O;F9I9W5R871I969O<FUU;&EE<BX@36ES<V-H:65N(&)E;G0@=2!E96X@
M=F5R<&QI8VAT('9E;&0@(@HB=F5R9V5T96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D
M<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("(B"B)%96X@9F]U="!B:6H@:&5T('5I='9O97)E;B!V86X@
M9&4@;W!G96=E=F5N(&%D<F5S8F]E:V9U;F-T:64N(%!R;V)E97(@;&%T97(@
M(@HB;W!N:65U=RP@82YU+F(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)%96X@9F]U="!M970@:&5T
M(&)I:G=E<FME;B!V86X@9&4@861R97-D971A:6QS+B!0<F]B965R(&QA=&5R
M(&]P;FEE=7<L(&$N=2YB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)%96X@9F]U="!M970@:&5T(&)I
M:G=E<FME;B!V86X@9&4@9&ES=')I8G5T:65L:6IS="X@4')O8F5E<B!L871E
M<B!O<&YI975W+"!A+B(*(G4N8BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D1E
M>F4@24U!4"!S97)V97(@;VYD97)S=&5U;G0@9V5E;B!D96QI;F<@=F%N(&UA
M<'!E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED
M(')A<B!A<F-H:79E+B(*;7-G<W1R(")$:70@;&EJ:W0@;FEE="!E96X@9V5L
M9&EG(')A<B!B97-T86YD('1E('II:FXN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B1&ET(&QI
M:FMT(&YI970@965N(&=E;&1I9R!Z:7`@8F5S=&%N9"!T92!Z:6IN+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M(")$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG(&MA87)T;G5M;65R('1E('II
M:FXN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G
M96QI:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@0VQI8VMA=&5L;"`B"B(H
M:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y('1E('9E<GIE;F1E;BP@
M9"YM+G8N(&1E($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO
M+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"B)$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI
M:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@5TE.("AH='1P.B\O(@HB=VEN
M<&QC+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(5%10
M($%022(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B
M"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@HB1&ET('-T=75R<')O9W)A;6UA(&=E969T(&1E(&UO9V5L
M:6IK:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E('-M<S)E;6%I;"`B"B(H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87D@=&4@=F5R>F5N9&5N+"!D+FTN
M=BX@9&4@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T
M:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T
M<B`B(@HB1&ET('-T=75R<')O9W)A;6UA(&=E969T(&1E(&UO9V5L:6IK:&5I
M9"!O;2!B97)I8VAT96X@=FEA(%--5%`@9"YM+G8N(&1E("(*(E9O9&%F;VYE
M($ET86QY(&=A=&5W87D@=&4@=F5R>F5N9&5N(&YA87(@5F]D869O;F4@;G5M
M;65R<RX@2&EE<G9O;W(@:7,@965N("(*(E9O9&%F;VYE($ET86QY(&4M;6%I
M;&%D<F5S("AH='1P.B\O=W=W+C$Y,"YI="D@;F]O9'IA:V5L:6IK+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U
M-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#`X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T-3`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8S-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#$P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Y-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#`U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S
M='(@(D1I="!V96QD(&ES('9E<F5I<W0B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(D1I="!V96QD(&UA9R!A;&QE96X@:6YT
M96=E<G,@8F5V871T96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0Q-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E
M<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B1&ET('9E;&0@;6%G(&%L;&5E
M;B!G971A;&QE;B!E;B!D92!D=6)B96QE('!U;G0@8F5V871T96XN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B1&ET
M('9E;&0@;6%G(&%L;&5E;B!O8W1A86P@=V%A<F1E;B!B979A='1E;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)$:70@=F5L9"!D:65N="!E96X@:V]M
M;6$@;V8@<W!A=&EE(&=E<V-H96ED96X@;&EJ<W0@;65T(&EN=&5G97)S('1E
M('II:FXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B
M1&5Z92!W86%R9&4@9&EE;G0@965N(&=E;&1I9R!G971A;"!T92!Z:6IN+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3@*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`B(@HB1&ET('9E;&0@9&EE;G0@965N(&ML975R8V]D92!I;B!21T(@2$58
M+69O<FUA870@=&4@8F5V871T96XL(&(N=BX@)R,Q,C,T868G+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA
M<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")$:70@9F]R;75L
M:65R(&ES(')E961S('9E<G=E<FMT+B(*"B,Z('1E;7!L871E<R]H96QP+V%B
M;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM
M<V=S='(@(D1I="!I<R`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L
M86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@
M=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B
M(@HB1&ET(&ES(&5E;B!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!/;2!D:70@
M;V)J96-T('=E97(@=&4@9V5V96X@:&5E9G0@=2!E96X@92TB"B)M86EL(&-L
M:65N="!N;V1I9R!D:64@:&5T($MO;&%B($=R;W5P=V%R92!F;W)M86%T(&)E
M9W)I:G!T+B!6;V]R(&5E;B!L:6IS="`B"B)M970@9&5Z92!E+6UA:6QC;&EE
M;G1S+"!B97IO96L@)7,L(&$N=2YB+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES
M(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@
M;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@HB1&ET(&)E<FEC:'0@
M:7,@:6X@965N(&%N9&5R92!K87)A:W1E<G-E="`H)7,I(&=E<V-H<F5V96XL
M(&1A;B!U=R!E:6=E;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O
M;F4N(@IM<V=S='(@(D1I="!G971A;"!D:65N="!T96YM:6YS=&4@Z>EN('1E
M('II:FXN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N
M<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B1&5Z92!S97)V97(@:V%N(&=E
M96X@>FEP(&5N(&=Z:7`@8F5S=&%N9&5N('5I='!A:VME;BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI
M<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R(")(
M970@<WES=&5E;2!I<R!M;VUE;G1E96P@=6ET9V5S8VAA:V5L9"XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")$97IE('=A87)D92!D
M:65N="!E96X@9V5T86P@=&4@>FEJ;BXB"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(D1I="!S
M8VAE<FT@9&EE;G0@86%N9V5R;V5P96X@=&4@=V]R9&5N('9A;G5I="!E96X@
M3W!T:65S<V-H97)M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C8*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B3VYW965R(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B5&EC:V5T
M<R(*;7-G<W1R(")4:6-K971S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0R-2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(E1I;64B"FUS9W-T<B`B5&EJ9"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B5&EJ9'!L
M86YN:6YG(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE
M(&9O<FUA="(*;7-G<W1R(")4:6ID9F]R;6%A="(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,S$*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(E1I:F1S96QE8W1I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B5&ET96PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4
M:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(E1I=&5L("AT;V]L=&EP*3HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U"FUS
M9VED(")4;R(*;7-G<W1R(")!86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L
M=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O
M;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B
M"B)/;2!M965R9&5R92!O;F1E<F1E;&5N('1E('-E;&5C=&5R96XL(&AO=60@
M9&4@0V]N=')O;"`H4$,I(&]F($-O;6UA;F0@*$UA8RD@(@HB=&]E=',@=F%S
M="!T:6ID96YS(&ML:6MK96XN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B5F%N9&%A9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G
M:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(&)R;VX@;VUS
M8VAA:V5L96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S"FUS9VED(")4;V=O(@IM<V=S='(@
M(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(V"FUS9VED(")4;VME;&%U(@IM<V=S='(@
M(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R
M"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")-;W)G96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(Y"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV
M86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@
M(E1E('9E96P@;VYG96QD:6=E(&%A;FUE;&1I;F=E;B!G961U<F5N9&4@9&4@
M869G96QO<&5N(&UI;G5T96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Q"FUS9VED(")4;W`B"FUS9W-T<B`B
M0F]V96YK86YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R(")"
M;W9E;G-T92!F<F%M92`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")697)T86QI;F=E
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S(*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B
M"FUS9W-T<B`B5')I;FED860@96X@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M(")4<G5E(&]F(&9A;'-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B1&DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(X"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(E1U;F5S:>LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B5'5R:VEJ92(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")4=7)K:7-H("A)
M4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)K<R`H25-/+3@X-3DM.2DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(W"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE
M;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,`IM<V=I9"`B5'5R:W,@86YD($-A:6-O
M<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS(&5N($-A:6-O<R!E:6QA;F1E;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S,*;7-G:60@(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO
M=7(@8VAO:6-E.B`B"FUS9W-T<B`B5'EP('5W(&ME=7IE.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X
M.B`B"FUS9W-T<B`B52Y6+B!I;F1E>#H@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T
M<B`B55),('9O;W(@=7<@869L979E<FEN9W-S=&%T=7-R87!P;W)T('-C<FEP
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<*
M;7-G:60@(E5G86YD82(*;7-G<W1R(")/96=A;F1A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")/96MR8>]N92(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&
M4R!D:7)E8W1O<GD@86%N('1E('-P<F5K96XN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X
M=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R
M("(B"B).:65T(&EN('-T86%T(&5X=')A(&=E8G)U:6ME<G-I;F9O<FUA=&EE
M('1O92!T92!V;V5G96X@8FEJ(&EN<V-H<FEJ=F5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").:65T(&EN('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B
M97-T86YD(%PB)7-<(B!T92!W:6IZ:6=E;BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(&1E(')E8VAT96X@=F%N(%9&4R!B97-T86YD("5S+R5S('1E('=I
M:GII9V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S@V"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM
M<V=S='(@(DYI970@:6X@<W1A870@=&4@=VEJ>FEG96X@;F%A<B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!B97-T86YD<V=R;V]T=&4@=F%N(%PB
M)7-<(B!T92!C;VYT<F]L97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV.34@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#(X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(DYI970@:6X@<W1A870@8F5S=&%N9'-G<F]O='1E
M('9A;B!<(B5S+R5S7"(@=&4@8V]N=')O;&5R96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!M970@
M9&4@4U%,('-E<G9E<B!T92!V97)B:6YD96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-S`*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I
M=&@@4U-,+B(*;7-G<W1R(").:65T(&EN('-T86%T(&UE="!34TP@=&4@=F5R
M8FEN9&5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R
M(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&MO<&GK<F5N+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2!<(B5S7"(@
M=&4@;6%K96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S8Q
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V-`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&
M4R!D:7)E8W1O<GD@=&4@;6%K96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL
M92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!M86ME
M;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Y,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!M87`@7"(E<UPB('1E
M(&UA:V5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,@IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!E96X@;&5E9R!61E,@8F5S=&%N9"!T92!M86ME
M;BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(DYI
M970@:6X@<W1A870@9&%T82!U:70@=&4@<&%K:V5N+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z,C(X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B
M3FEE="!I;B!S=&%A="!<(B5S7"(@=&4@=F5R=VEJ9&5R96XL(&1E(&1I<F5C
M=&]R>2!I<R!N:65T(&QE96<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(").:65T(&EN
M('-T86%T(%PB)7-<(CH@)7,@=&4@=F5R=VEJ9&5R96XN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,3$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.34@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2(*;7-G<W1R(").:65T(&EN('-T86%T("5S('1E('9E
M<G=I:F1E<F5N+"!D92!D:7)E8W1O<GD@:7,@;FEE="!L965G(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&1I<F5C=&]R>2!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3FEE
M="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E('9E<G=I:F1E<F5N+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(DYI970@:6X@
M<W1A870@5D93(&1I<F5C=&]R>2`E<R!T92!V97)W:6ID97)E;BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!<(B5S7"(@=&4@=F5R=VEJ
M9&5R96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S$P(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3@W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,CDQ(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N
M9"!T92!V97)W:6ID97)E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&
M4R!M87`@7"(E<UPB('1E('9E<G=I:F1E<F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B3FEE
M="!I;B!S=&%A="!61E,@)7,@<F5C=7)S:65F('1E('9E<G=I:F1E<F5N+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,T"FUS9VED(")5;F%B
M;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(").
M:65T(&EN('-T86%T(&AU:61I9V4@9&ER96-T;W)Y('1E(&)E<&%L96XN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!C97)T:69I8V%A=&1E=&%I;',@=6ET('1E(&9I
M;'1E<F5N(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F
M<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N(@IM<V=S='(@(DYI970@:6X@<W1A870@;VT@9&4@9&5F:6YI=&EE('9A
M;B`E<R!T92!L861E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S0@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N(@IM<V=S='(@(DYI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@
M=F5R<&QA871S96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY
M."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,3`V(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-C4R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N
M9"!<(B5S7"(@=&4@;W!E;F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(X-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@
M(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R
M(").:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E(&]P96YE;B!V;V]R('-C
M:')I:G9E;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,R!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,S<*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!O<&5N96XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H
M:79E+B(*;7-G<W1R(").:65T(&EN('-T86%T(&AE="!I;F=E<&%K=&4@8F5S
M=&%N9"!T92!O<&5N96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U
M-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T
M92!L97IE;B`H9FEL97-I>F4H*2!M:7-L=6MT*2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL
M92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R(").:65T(&EN('-T
M86%T(%9&4R!B97-T86YD('1E(&QE>F5N("AG971&:6QE4VEZ92@I(&UI<VQU
M:W0I+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@
M(@IM<V=S='(@(DYI970@:6X@<W1A870@8F5S=&%N9"!T92!L97IE;CH@(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DYI
M970@:6X@<W1A870@=F9S<F]O="!D:7)E8W1O<GD@=&4@;W!E;F5N+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO
M;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B3FEE="!I;B!S=&%A
M="!O;2`E<R!T92!H97)N;V5M96X@;F%A<B`E<SH@8F5S=&5M;6EN9W-M87`@
M8F5S=&%A="!A;"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@9&ER96-T;W)Y('1E(&AE<FYO
M96UE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,S,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!D:7)E8W1O<GD@
M)7,@=&4@:&5R;F]E;65N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&4R!B97-T86YD(%PB)7-<(B!T
M92!H97)N;V5M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"`E<R\E<R!T92!H
M97)N;V5M96XN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q
M,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S(V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,P.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`B3FEE="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!H97)N;V5M96XN(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N
M<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T
M<B`B2V%N("=M:VES;V9S)R!N:65T('5I='9O97)E;BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B
M;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(").
M:65T(&EN('-T86%T(&1I="!7;W)D(&1O8W5M96YT('1E('9E<G1A;&5N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3FEE="!I;B!S
M=&%A="!61E,@8F5S=&%N9"!<(B5S7"(@=&4@<V-H<FEJ=F5N+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3FEE
M="!I;B!S=&%A="!61E,@8F5S=&%N9"!T92!S8VAR:6IV96X@*&-O<'DH*2!F
M86EL960I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X."!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30V"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(").:65T(&EN('-T86%T(%9&
M4R!B97-T86YD<V1A=&$@=&4@<V-H<FEJ=F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B3FEE="!I;B!S
M=&%A="!61E,@8F5S=&%N9"!T92!S8VAR:6IV96XL('%U;W1A('=O<F1T(&]V
M97)S8VAR961E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B3VYD97)S
M=')E<&5N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B
M56YD;R!#:&%N9V5S(@IM<V=S='(@(DAE<G-T96P@=VEJ>FEG:6YG96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS
M9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$;V5T('5W
M(&QA871S=&4@8F5W97)K:6YG('1E;FEE="(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(D]N
M=F5R=V%C:'0@86YT=V]O<F0@=F%N(&1E('-E<G9E<B!O<"!V97)B:6YD:6YG
M.B`B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR
M,3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G
M<W1R(")/;G9E<G=A8VAT(&%N='=O;W)D('9A;B!S97)V97(@86%N.B`B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")/;F)E;F]E;60B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D92`H551&+3@I(@IM
M<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W"FUS9VED(")5
M;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")697)E;FEG9&4@07)A8FES
M8VAE($5M:7)A=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X"FUS9VED(")5;FET960@2VEN
M9V1O;2(*;7-G<W1R(")697)E;FEG9"!+;VYI;F=K<FEJ:R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#`*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B5F5R96YI9V1E
M(%-T871E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD*;7-G:60@(E5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")697)E;FEG9&4@4W1A
M=&5N+"!K;&5I;F4@8G5I=&5N(&QI9V=E;F1E(&5I;&%N9&5N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C(*;7-G:60@(E5N:71S(@IM<V=S='(@(D5E;FAE9&5N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU."!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(D]N8F5K
M96YD(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(D]N8F5K96YD(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN(@IM<V=S='(@(D]N8F5K96YD(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B3VYB96ME;F1E(&QO8V%T:64@;W!G96=E=F5N+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I
M9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B3VYB
M96ME;F1E(&=E8G)U:6ME<G-N86%M(&]F('=A8VAT=V]O<F0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X
M"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")(
M970@:'5I9&EG92!E;&5M96YT(&QO<VMO<'!E;&5N(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M960B"FUS
M9W-T<B`B3VYB96YO96UD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP
M=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L
M;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@
M82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+B(*;7-G<W1R("(B"B).:65T(&=E<F5C:'1I9V1E('-C<FEP=',@
M:W5N;F5N('!R;V=R86UM86UA=&EG(&YI970@2VYI<'!E;B]+;W!IZW)E;B\B
M"B)0;&%K:V5N+"!V86YW96=E(&)E=F5I;&EG:6YG<W)E9&5N96XN($ML:6L@
M;W`@3TL@;VT@965N('1E8VAN:7-C:&4@;W!M97)K:6YG("(*(F]P(&UO>FEL
M;&$N;W)G('1E(&)E:VEJ:V5N(&AO92!U(&5E;B!S8W)I<'0@=&]E<W1A870@
M:&5T('!R:6MB;W)D('1E("(*(F)E;F%D97)E;BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5
M;G-E="!C;VQO<B(*;7-G<W1R(")+;&5U<B!T97)U9W-T96QL96XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS
M:6]N(@IM<V=S='(@(DYI970@;VYD97)S=&5U;F1E(&5X=&5N=&EE(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")"
M:6IW97)K96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(E
M<R!B:6IW97)K96XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")'96)R=6EK97(@
M8FEJ=V5R:V5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P
M"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R
M(")<(B5S7"(@8FEJ9V5W97)K="XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T
M<B`B57!G<F%D92!S8W)I<'0@=F5R=VEJ9&5R9"XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")5<&QO860B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A
M;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS
M9W-T<B`B06QL92!T;V5P87-S:6YG('-E='5P8F5S=&%N9&5N(&YA87(@9&4@
M<V5R=F5R(&=E=7!L;V%D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN
M(&QE='1E<G,B"FUS9W-T<B`B3&%T:6IN<V4@:&]O9F1L971T97)S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R(")'<F]T
M92!2;VUE:6YS92!G971A;&QE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$*;7-G:60@(E5R
M=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")'96)R=6EK(&AU:61I9V4Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B1V5B<G5I:R!34TPB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(W"FUS9VED(")5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*
M;7-G<W1R(")'96)R=6EK96X@=V%N;F5E<B!N86%M+W=A8VAT=V]O<F0@=F5R
M<V-H:6QT(&UE="!)35-0('-E<G9E<BXB"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(D=E8G)U
M:6ME<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO
M<FES960@9F]R("5S+B(*;7-G<W1R(")'96)R=6EK97(@)7,@:7,@;FEE="!G
M96%U=&]R:7-E97)D('9O;W(@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D=E8G)U:6ME
M<G-B96AE97(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T
M-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@(D=E8G)U:6ME<G-O<'1I
M97,B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES=')A=&EO
M;B(*;7-G<W1R(")'96)R=6EK97)S<F5G:7-T<F%T:64B"@HC.B!S:6=N=7`N
M<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")'96)R=6EK97)S<F5G:7-T
M<F%T:64@:7,@=6ET9V5S8VAA:V5L9"!O<"!D97IE('-I=&4N(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0Y-`IM<V=I9"`B57-E<B!A8V-O=6YT(&YO
M="!F;W5N9"(*;7-G<W1R(")'96)R=6EK97)S86-C;W5N="!N:65T(&=E=F]N
M9&5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM
M<V=S='(@(D=E8G)U:6ME<G-N86%M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M
M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D=E8G)U:6ME<G-N
M86%M(%PB)7-<(B!B97-T86%T(&%L+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(D=E8G)U
M:6ME<G-N86%M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B1V5B<G5I:V5R<VYA86TZ("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(D=E8G)U:6ME<G,@:6X@:&5T
M('-Y<W1E96TZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB96MI<W1A;B(*
M;7-G<W1R(")/97IB96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C(*;7-G
M:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&
M4R!D:7)E8W1O<GD@8F5S=&%A="!N:65T+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%F=V5Z
M:6=H96ED(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(D=E
M=F]N9&5N(&=E;&1I9V4@;&]C871I97,@8F5V871T96XZ("(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET
M>2(*;7-G<W1R(")'96QD:6=H96ED(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"FUS9VED(")686QU92!I
M;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")786%R9&4@:6X@;6EN=71E
M;B!V86YA9B!N=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B5V%A<F1E(&QI9W0@8F]V96X@9&4@;6%X:6UU;2!L96YG=&4@
M=F%N("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3`*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I
M9"`B5F%L=65S(@IM<V=S='(@(E=A87)D96XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*
M;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")786%R9&5N
M('=A87)U:70@9V5S96QE8W1E97)D(&MA;B!W;W)D96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Y"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*
M;7-G<W1R(")687)I86)E;&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U"FUS9VED(")696YE
M>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+B(*;7-G<W1R(")697)I9FEC871I92!M:7-L=6MT("T@97(@:V%N(&UE="!D
M:70@8F5R:6-H="!G96MN;V5I9"!Z:6IN+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")697)S:6]N(@IM<V=S='(@
M(E9E<G-I92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C@*;7-G
M:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")697)S:65C;VYT<F]L92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(E9E<G1I:V%A
M;"!U:71L:6IN96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@
M(E9E<G1I:V%L92!V<FEJ92!R=6EM=&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS
M9W-T<B`B5F5R=&EK86%L.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B17)G
M(&AO;V<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6:65T($YA;2(*;7-G<W1R
M(")6:65T;F%M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@
M(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;65E<R`H5DE3
M0TE)*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(B5S(&)E
M:VEJ:V5N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")"96MI:FL@965N(&5X
M=&5R;F4@=V5B<&%G:6YA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,P"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B
M"FUS9W-T<B`B0F5K:6IK96X@86QS("5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B36%A9V1E;B!E
M:6QA;F1E;BP@0G)I='-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-PIM<V=I9"`B5FER9VEN
M($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B36%A9V1E;B!E:6QA;F1E;BP@5BY3
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL
M:71Y(@IM<V=S='(@(EII8VAT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(EII8VAT
M.B`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS
M9W-T<B`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,V"FUS9VED(")705).(@IM<V=S='(@(E=!4DXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B
M5T%!4E-#2%5724Y'(2$A("!615)724I$15(@4T-225!4($A!3D1-051)1R!5
M250@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R(")724X@=FEA($A4
M5%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4P"FUS9VED(")786QL:7,@86YD($9U='5N82(*
M;7-G<W1R(")786QL:7,@96X@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.CDU"FUS9VED(")787)N:6YG(@IM<V=S='(@
M(E=A87)S8VAU=VEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(E=O(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O
M<F5C87-T(@IM<V=S='(@(E=E97)S=F]O<G5I='II8VAT(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A
M('!R;W9I9&5D(&)Y(@IM<V=S='(@(E=E97)B97)I8VAT(&=E9V5V96YS(&=E
M;&5V97)D(&1O;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*
M;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(E=E871H97(N8V]M(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R(")7
M96(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")7
M96(@4VET92(*;7-G<W1R(")796)S:71E(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S
M='(@(E=E:V5L:6IK<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@(E=E;&MO;2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM
M<V=S='(@(E=E;&MO;2!B:6H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5V5L:V]M+"`E
M<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N
M("A)4T\M.#@U.2TQ*2(*;7-G<W1R(")797-T97)S("A)4T\M.#@U.2TQ*2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)
M4T\M.#@U.2TQ-2DB"FUS9W-T<B`B5V5S=&5R<R`H25-/+3@X-3DM,34I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E=E
M<W1E;&EJ:V4@4V%H87)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L
M9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R(")796QK92!T;V5P
M87-S:6YG(&1I96YT("5S('=E97(@=&4@9V5V96X@;F$@86%N;65L9&EN9S\B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA
M="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B5V%T(&ES
M(&AE="!S8VAE:61I;F=S:V%R86MT97(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B5V%T(&ES(&AE="!C:71A871K87)A:W1E<C\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-0IM
M<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H97)E:7,@
M075S=')A;&GK(&MA87)T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS
M9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B5V5L:V4@9F%S96XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS
M('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@
M(E=E;&ME('!L=6=I;G,@=F]O<B!D92!2:6-H(%1E>'0@961I=&]R(&EN<V-H
M86ME;&5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(D)R965D=&4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`W"FUS9VED(")7:61T
M:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B0G)E961T92!I;B!#4U,@965N:&5D
M96XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"B)"<F5E
M9'1E('9A;B!H970@)7,@;65N=2!A86X@9&4@;&EN:V5R:V%N="`H86MT:65F
M(&)I:B!V;VQG96YD92!A86YM96QD:6YG*3HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@
M=&AE('1A8FQE(@IM<V=S='(@(D)R965D=&4@=F%N(&1E('1A8F5L(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G
M:60@(E=I9'1H('5N:70B"FUS9W-T<B`B0G)E961T92!E96YH96ED(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R(")"<F5E9'1E.B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HU,34*;7-G:60@(E=I:VDB"FUS9W-T<B`B5VEK:2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(E=I;F0B"FUS
M9W-T<B`B5VEN9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E=I;F0@=G)O
M96<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@W"FUS9VED(")7:6YD('-P
M965D(&EN(&MN;W1S(@IM<V=S='(@(E=I;F1S;F5L:&5I9"!I;B!K;F]P96XB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B5VEN9#HB"FUS
M9W-T<B`B5VEN9#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5VEN9#H@(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B5VEJ
M<VAE:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED
M(")7:7-H;&ES="(*;7-G<W1R(")796YS;&EJ<W0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B5V5R:R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(E=E<FMA9')E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O
M<FL@4&AO;F4B"FUS9W-T<B`B5&5L+FYR+B`H=V5R:RDB"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*
M;7-G<W1R(")697)K965R9"!A86YT86P@=F5L9&5N(&EN(')E9V5L("5D+B!6
M97)W86-H="`E9"P@9V5V;VYD96X@)60N(@H*(SH@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU
M;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T
M<B`B5F5R:V5E<F0@86%N=&%L('9E;&1E;BX@5F5R=V%C:'0@)60L(&=E=F]N
M9&5N("5D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(")697)K965R9&4@;V9F<V5T("5D
M(&)I:B!L97IE;B!V86X@5D93(&)E<W1A;F0N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I
M9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!B
M87-I<V)E<&5R:VEN9V5N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B
M"FUS9W-T<B`B6#4P.78S('5I=&=E8G)E:60@<VQE=71E;&=E8G)U:6LB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B
M6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y
M=C,@86QT97)N871I979E(&]N9&5R=V5R<&YA86TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B6#4P.78S(&]N9&5R=V5R<"!S
M;&5U=&5L:61E;G1I9FEC871O<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G
M<W1R(")8-3`Y=C,@97AT96YT:65S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-3`*;7-G:60@(EE9(@IM<V=S='(@(DI*(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")965E9(@IM<V=S='(@
M(DI*2DHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$@;6%P
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(DIA87)L:6IK<R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3(*;7-G:60@(EEE;65N(@IM<V=S='(@(DIE;65N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S
M(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")*
M82P@:6L@86-C97!T965R(&1E('9O;W)W86%R9&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R
M92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C
M:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(E4@8F5N="!I;B!414M3
M5"!-3T1%+B!'96)R=6EK(&1E(%L\/ET@:VYO<"!O;2!N86%R(%=94TE764<@
M=&5R=6<@=&4@(@HB<V-H86ME;&5N+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E
M9"!B;&]C:W,N(@IM<V=S='(@(DAE="!I<R!U(&YI970@=&]E9V5S=&%A;B!O
M;2!M965R(&1A;B`E9"!B;&]K:V5N('1E(&UA:V5N+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,30R-`IM<V=I9"`B66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"XB"FUS9W-T<B`B52!B96YT(&YI970@9V5A=71H96YT:69I
M8V5E<F0N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@
M:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E4@:W5N="!G965N("=<7"<@
M:V%R86MT97(@:6X@=7<@=F]L;&5G92!N86%M(&AE8F)E;BXB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B52!H965F="!G965N(&=E;&1I9R!E+6UA
M:6QA9')E<R!O<&=E9V5V96XN(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(E4@:&5E
M9G0@9V5E;B!V96QD96X@=6ET(&AE="!G96EM<&]R=&5E<F1E(&)E<W1A;F0@
M9V5K;W!P96QD(&UE="!D92`B"B)O=F5R965N:V]M<W1I9V4@=F5L9&5N(&EN
M("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")5(&)E;G0@869G
M96UE;&0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I
M9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M
M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@
M=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*
M(E4@9&EE;G0@965N(&=E;&1I9R!M;V)I96P@;G5M;65R(&EN('1E('9O97)E
M;BP@86QL965N(&-I:F9E<G,@;65T(&5E;B`B"B)O<'1I;VYE;&4@)RLG('9O
M;W(@:&5T(&EN=&5R;F%T:6]N86QE(&MI97-V;V]R=F]E9W-E;"XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")5(&1I96YT(&5E;B!G
M96QD:6=E('=A87)D92!O<"!T92!G979E;BXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@
M(B(*(E4@9&EE;G0@965N($1A=&%4<F5E(&)A8VME;F0@=&4@8V]N9FEG=7)E
M<F5N(&]M(&EN<V-H<FEJ=FEN9V5N('1E(&MU;FYE;B`B"B)G96)R=6EK96XN
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S$*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")5(&1I
M96YT(&5E;B!61E,@8F%C:V5N9"!T92!C;VYF:6=U<F5R96XN(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"B)5(&1I96YT(&AE="!P<F]B
M;&5E;2!T92!B97-C:')I:G9E;BP@=F]O<F1A="!U(&AE="!P<F]B;&5E;7)A
M<'!O<G0@:W5N="`B"B)V97)Z96YD96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT
M97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@
M(E4@9&EE;G0@965N(%523"!I;B!T92!V;V5R96X@=V%A<FYA87(@9&5Z92!L
M:6YK('9E<G=I:G-T(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B52!D:65N="!E96X@<V5R=F5R('1E('-E;&5C=&5R
M96X@;VT@=&4@=F5R=VEJ9&5R96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@
M;W5T+B(*;7-G<W1R(")5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T
M92!G979E;B!O;2!T92!W:7-S96XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+B(*;7-G<W1R(")5(&1I96YT(&5E;B!G96)R=6EK97)S;F%A;2!O<"!T92!G
M979E;B!O;2!T92!V97)W:6ID97)E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B
M52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&]E
M('1E('9O96=E;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B52!D:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@
M8FEJ('1E(&MU;FYE;B!W97)K96XN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@(E4@9&EE;G0@965N
M(&)E=V5R:VEN9R!O<"!T92!G979E;B!W96QK92!U:71G979O97)D(&UO970@
M=V]R9&5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N(@IM<V=S='(@(E4@9&EE;G0@965N(&YI975W92!C871E9V]R
M:65N86%M(&]P('1E(&=E=F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T
M;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(E4@
M9&EE;G0@965N($ET86QI86%N<R!T96QE9F]O;FYU;6UE<B!O<"!T92!G979E
M;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S
M92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B57<@)7,@<V5S<VEE(&ES('9E<FQO
M<&5N+B!/<&YI975W(&%A;FUE;&1E;BP@82YU+F(N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@061D
M<F5S<R(*;7-G<W1R(")5=R!E+6UA:6QA9')E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS
M9W-T<B`B57<@5F%N.B!A9')E<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B57<@:6YF;W)M871I92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*(E5W(&EN=&5R;F5T861R97,@:7,@9V5W:6IZ:6=D('-I;F1S
M(&AE="!B96=I;B!V86X@=7<@)7,@<V5S<VEE+B!/;2!U=R`B"B)V96EL:6=H
M96ED('1E(&)E<V-H97)M96XL(&1I96YT('4@>FEC:"!O<&YI975W(&%A;B!T
M92!M96QD96XN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")5=R!N86%M.B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI
M;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N
M="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)(970@
M=&]E=F]E9V5N('9A;B!G96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U
M;F0@9&]O<B!U=R!A=71H96YT:6-A=&EE("(*(F)A8VME;F0N(%=A;FYE97(@
M=2!(;W)D92!G96)R=6EK97)S('=I;'0@8F5H97)E;BP@9&EE;G0@=2!E96X@
M86YD97(@(@HB875T:&5N=&EC871I92!B86-K96YD('1E(&=E8G)U:6ME;BXB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB
M2&5T('=E97)G979E;B!V86X@965N(&=E8G)U:6ME<G-L:6IS="!W;W)D="!N
M:65T(&]N9&5R<W1E=6YD(&1O;W(@=7<@(@HB875T:&5N=&EC871I92!B86-K
M96YD+"!O9B!D97IE(&]P=&EE(&ES(&]M(&%N9&5R92!R961E;F5N('5I=&=E
M<V-H86ME;&0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB57<@8G)O=W-E<B!L:6IK="!T
M92!Z:6IN(&=E=VEJ>FEG9"!S:6YD<R!H970@8F5G:6X@=F%N('5W("5S('-E
M<W-I92X@3VT@=7<@(@HB=F5I;&EG:&5I9"!T92!B97-C:&5R;65N+"!D:65N
M="!U('II8V@@;W!N:65U=R!A86X@=&4@;65L9&5N+B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(E5W(&)R;W=S97(@;VYD
M97)S=&5U;G0@9&5Z92!M;V=E;&EJ:VAE:60@;FEE="XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S
M($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*
M(E5W(&)R;W=S97(@;VYD97)S=&5U;G0@9&5Z92!P<FEN=&]P=&EE(&YI970N
M($1R=6L@;W`@0V]N=')O;"]#;VUM86YD("L@4"!O;2`B"B)A9B!T92!D<G5K
M:V5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(E5W(&AU:61I9V4@=&EJ
M9'IO;F4Z(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@
M(E5W('-T86YD86%R9"!I9&5N=&ET96ET(&ES(&=E=VEJ>FEG9"XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ(@IM<V=S='(@(E5W('-T86YD86%R9"!I9&5N=&ET96ET.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L
M;"!N86UE.B(*;7-G<W1R(")5=R!V;VQL961I9V4@;F%A;3HB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S
M(&5X<&ER960N(@IM<V=S='(@(E5W(&%A;FUE;&1I;F<@:7,@=F5R;&]P96XN
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*
M;7-G<W1R(")5=R!N:65U=V4@=V%C:'1W;V]R9"!V;V]R("5S(&ES.B`E<R(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(E5W(&]P=&EE<R!Z:6IN(&)I
M:F=E=V5R:W0@=F]O<B!D92!D=75R('9A;B!D97IE('-E<W-I92XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")5=R!O<'1I97,@
M>FEJ;B!B:6IG97=E<FMT+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM
M<V=S='(@(E5W('=A8VAT=V]O<F0@:7,@9V5R97-E="(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB57<@=V%C
M:'1W;V]R9"!I<R!V97)N:65U=V0L(&-O;G1R;VQE97(@=7<@92UM86EL(&5N
M(&UE;&0@86%N(&UE="!U=R!N:65U=V4@(@HB=V%C:'1W;V]R9"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E5W('=A8VAT=V]O<F0@:7,@=F5R
M;&]P96XN(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS
M9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")5=R!S97)V97)S
M(&]P(&%F<W1A;F0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-`IM<V=I9"`B675G
M;W-L879I82(*;7-G<W1R(")*;V5G;W-L879IZR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA
M[W)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-@IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA
M;6)I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@
M(EII;6)A8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED
M(")::7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R(");5F5R8F5R9R!A86YG96AA86QD92!T
M96MS=%TB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R
M;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O8FQE96UR87!P;W)T72(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM!86YG96AA86QD92!T
M96MS="!W965R9V5V96X@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M6T%A;F=E:&%A;&1E('1E:W-T("T@)7,@<F5G96QS72(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(EML
M:6YE("5S(&]F("5S72(*;7-G<W1R(");<F5G96P@)7,@=F%N("5S72(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34U-"!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T
M<B`B0E]E:&5E<B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*
M;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`B7T1A=&%4<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L
M971E(%)O=R(*;7-G<W1R(")697)?=VEJ9&5R(')I:B(*"B,Z(&QI8B]A<&DN
M<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)O97!E;B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](
M96QP(@IM<V=S='(@(E](96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O
M<&5R=&EE<RXN+B(*;7-G<W1R(")?069B965L9&EN9W-E:6=E;G-C:&%P<&5N
M+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM
M<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?06%N;65L9&5N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B
M"FUS9W-T<B`B7T%F;65L9&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI
M;FLN+BXB"FUS9W-T<B`B7U=I:GII9R!L:6YK+BXN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS
M9W-T<B`B7T]P=&EE<R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E
M<FUI<W-I;VYS(@IM<V=S='(@(E]296-H=&5N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7U9E<G=I:F1E<B!L:6YK+BXN(@H*
M(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7TEN
M<W1E;&QE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B7U1A8F5L96EG96YS8VAA<'!E;BXN+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(D=E7V)R=6EK97)S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E
M<W,@8F]O:R(*;7-G<W1R(")!9')E<V)O96LB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO
M=VXB"FUS9W-T<B`B1V5A9')E<W-E97)D92!O;F)E:V5N9"(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*;7-G
M<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S8U"FUS9VED(")C86QM(@IM<V=S='(@(DMA
M;&TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM
M<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R(")+86X@
M;W5T<'5T8F5S=&%N9"!N:65T(&UA:V5N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T
M(@IM<V=S='(@(DMA;B!I;G!U="!N:65T(&]P96YE;B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C8P,`IM<V=I9"`B8VQI8VL@:&5R
M92(*;7-G<W1R(")+;&EK(&AI97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(D-O;6UA;F1O<F5G96P@9V5B<G5I:W-F;W5T(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O
M;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B0V]N9FEG=7)A=&EE9F]U="(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED
M(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(DMR:71I
M<V-H('-Y<W1E96UB97-T86YD(&]N=&)R965K="(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E
M<G)O<B(*;7-G<W1R(")$871A9F]R;6%A=&9O=70B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S='(@(F)E=V5R
M:V5N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*
M;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")I;G9O97(@;FEE="!G
M979O;F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"FUS9VED(")F86QL:6YG(@IM<V=S='(@(F1A;&5N9"(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y.`IM<V=I9"`B9FEL92(*
M;7-G<W1R(")B97-T86YD(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E
M<R`E<R(*;7-G<W1R(")V86X@9&4@)7,@*"5S*2!O<"`E<R`E<R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B
M"FUS9W-T<B`B=FQA9V5R:6<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-3D*;7-G
M:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S
M='(@(FAO<W1N86%M(&]N8F5K96YD(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"FUS9VED(")I;6UE9&EA
M=&4B"FUS9W-T<B`B;VYM:61D96QI:FLB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE
M(@IM<V=S='(@(FEN;&EN92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T
M<B`B:6YP=70O;W5T<'5T(&9O=70B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B:6YT97)N92!S;V9T=V%R969O=70B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=
M(@IM<V=S='(@(G)E9V5L<UTB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM
M<V=S='(@(FUK:7-O9G,@9F]U=&-O9&4@)60@8FEJ(&AE="!A86YM86ME;B!V
M86X@25-/+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S`*;7-G:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q
M"FUS9VED(")N86UE(@IM<V=S='(@(FYA86TB"@HC.B!F<F%M97=O<FLO4E!#
M+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B
M;FEE="!V86X@=&]E<&%S<VEN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*
M;7-G<W1R(").;V<@;FEE="!V86X@=&]E<&%S<VEN9R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@
M(FYO=&ET:65B;V5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")P
M<F]C96YT(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(E)E8VAT(&=E
M=V5I9V5R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AE;',B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I
M9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(E)E;6]T92!F
M;W5T(&EN('!R;W1O8V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S4*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")S=&EJ9V5N
M9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS
M9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(E-E<G9I8V4@;FEE
M="!B97-C:&EK8F%A<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`Q
M"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(G1O;VX@=F5R<V-H
M:6QL96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@
M(G-M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#<*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G
M:60@(G-T96%D>2(*;7-G<W1R(")S=&%B:65L(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R(")S>7-T965M9F]U="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B=&%K96YL:6IS
M="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R(")T:6ID96QI:FME(&UI
M<VQU:VMI;F<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S=V]R
M9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(E9O97(L('1E<B!B979E<W1I
M9VEN9RP@:&5T('=A8VAT=V]O<F0@='=E92!M86%L(&EN(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G
M:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEE9"(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`B
M;VYB96YO96UD(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R
M(")'96)R=6EK97)S96QE8W1I92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0R"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*;7-G<W1R(")W
M96%T:&5R+F-O;2(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&\O:F%?2E`N<&\`````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C<W-S,R(#$P-3$U-#,T
M,30R(#`Q-S4R,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````C($IA<&%N97-E('1R86YS;&%T:6]N(&9O<B!(;W)D92X*(R!#
M;W!Y<FEG:'0@*$,I(#(P,#0@2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I
M<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(
M;W)D92!P86-K86=E+@HC($AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U
M:W5B82YA8RYJ<#X*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M260M
M5F5R<VEO;CH@2&]R9&4@,RXQ+C!<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`V+3`S+3`V(#$R.C0W*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#8M,#,M,C(@,3(Z,#`K,#DP,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!(:7)O
M;6D@2VEM=7)A(#QH:7)O;6E`=&%C+G1S=6MU8F$N86,N:G`^7&XB"B),86YG
M=6%G92U496%M.B!*87!A;F5S92`\=6YK;F]W;D!U;FMN;W=N+F1O;6%I;CY<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]4TA)1E1?2DE37&XB"B)#;VYT96YT+51R86YS9F5R
M+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S8V"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM
M<V=S='(@(B`H)7,@D_J13RDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$S.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I
M(@IM<V=S='(@(H-!@TZ#6H-8@TR#0R`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D
M87ES*2(*;7-G<W1R("*!:25S()/Z@LR3X(+)@6HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<P"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@
M*(VAD_HI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,@IM<V=I
M9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B@6F6OI/Z@6HB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S8X"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS
M9W-T<B`B("B-\)/Z*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,`HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDV"FUS9VED("(@870@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM
M<V=S='(@(B<E<R<@@LV#9H-"@XR#3H-G@XJ!6X+%@LV"H(+H@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@
M(EPB)7-<(B""S9"S@K6"HI%)D?""Q8+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,3`*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#DX"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B""S2!(;W)D92"#C(-7@UB#
M9X.*@LF0W9+H@K."ZH+$@J*"W(*Y@O$N(@H*(SH@9G)A;65W;W)K+U1R964O
M5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB((-C@XJ!6Y5<
MCJ:+0)1<@JJ,J95T@JF"Z(+<@KF"\8%"(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@@JJ#3X.+@5N#
M=H-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O8%"(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB((*J@T&#3H-:@UB,H(-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O2XB
M"@HC(&US9W-T<B`B)R5S)X*JBY:)PI#=DNB#5H-8@V6#@(+)DL>)P8*S@NJ"
MW(*U@KTN(@HC.B!A9&UI;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB((+-C>R0K(*S@NJ"
MW(*Y@O&"Q8*U@KTZ("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("*799?*("4R)"XR9DU"()*&@LP@
M)3$D+C)F34(@CF>7<"@E,R0N,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(E9"`E<R""QB`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W
M;W)D(&5X<&ER97,N(@IM<V=S='(@(H-P@UB#CX%;@VB"S8*@@L8@)60@D_J7
M3(SX@L6"MX%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(I+*DFT@+2`E<R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S()-D
MCG&.=Y;D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0P(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(B5S()7;CN>1@(WL@LR*;91&(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S((+,D-V2Z"(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R"#5(-#@Y.#08-B
M@W8B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S
M().OB-./\(V`(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT,S(@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.30*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV.#(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B5S((+-BOF"R9&VC=V"M8+<@K>!0B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@
M>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*
M(B5S((+-CI^"R8YWDNB"LX+J@L2"HH+IE=N.YY&`C>R"\([`C7."MX+ICX"4
M]8*JD*Z"HH+<@K6"O8%"CL"-<X*U@KV"HI&`C>R"S"(*(H-[@V*#3H-8@O"#
M8(-&@V*#3H*U@L2"K8*^@K."HH%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C,S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E
M9"(*;7-G<W1R("(E<R""JI5+EW:"Q8*W(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G
M<W1R("(E<R"5JB(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T
M:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD
M+B(*;7-G<W1R("(E<R""JH*@@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@@JF"YR`E<X%!C8>,=B`E<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S((+,@T&#:(.,
M@UB2H"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B)7,@@LR7
M7)+HE5PB"@HC(&US9W-T<B`B)7."S(-*@XR#DX-?(@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M($YO=&5P860B"FUS9W-T<B`B)7,@@LR#@8."DJ`B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B5S((+,@UZ#6(-.@XJ#6(-G(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T
M<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE
M<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"
M97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P
M<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA
M=&EO;BXB"FUS9W-T<B`B(@HB)7,Z((*Q@LR#@8-B@UJ!6X-7@LV.IH*S@NJ"
MQ(*B@NF1EY!-CM*"J8+G@LR"X(+,@L6"S8+(@J*"QHYV@NV"ZH+<@K>!0H*[
M@LR2AB(*(H+,@XJ#DX-.@O"#3H.*@V*#3H*U@KV"Z(%!C,*0;(_NE?&"\)&7
MD$V"MX+I@LR"S8]<E:J"R9*-B-."M8+$B;J"LX*B@4(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L('!H<"UF;W)M
M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#8V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.`IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM()%)D?`@+2TB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C$RCIZ*U(Q@CJXB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G
M:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(TCIZ*U(Q@CJXB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@CIZ*U"(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z
M-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\D4^"S(-Y@5N#5R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(H*Q
M@LR#=8.-@V*#3H+)@LV#9H%;@UZ#>(%;@UB"JI5+EW:"Q8*W@4(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E
M<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`BDG:6O9-)@LB#1X.)@5N"JI2M
MD+:"M8+<@K6"O2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B4$=0C/:*2HRN@JJ#@8-B@UJ!
M6X-7@LR(PXV&B;N"R95+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M(")01U",]HI*C*Z"JH^0EKR"LX+J@KV#@8-B@UJ!6X-7@LR,GX_8@LF52Y=V
M@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y
M.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"
MYH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V
M@L6"MX%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q
M-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE
M<W-A9V4N(@IM<V=S='(@(E!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#
M6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*
M(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S
M86=E+B(*;7-G<W1R("(B"B)3+TU)346,]HI*C*Z!05,O34E-193IEJ>,KH*H
M@N:"T8-P@UB#=(.,@5N#68*JB,.-AHF[@X&#8H-:@5N#5X+,E9R-AH+)E4N7
M=H+%(@HB@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB4R]-24U%C/:*2HRN@4%3
M+TU)3464Z9:GC*Z"J(+F@M&#<(-8@W2#C(%;@UF"JH.!@V*#6H%;@U>"S(^0
MEKR"R95+EW:"Q8*W@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")3+TU)346,]HI*
MC*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%@K>!0B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@
M(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(H*Q@LR#1X-F@T*#7H%;@LF"
MPH*B@L0B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B
M06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4X-F@T*#C(-.@V>#
MBH+,C>R0K(+-@T&#3H-:@UB+D93;@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5D93@W2#0(-#@XN"S(WL
MD*R"S8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(H-!@TJ#18.3@V>/[I7Q(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(H-!@TJ#18.3
M@V>"S(-P@UB#CX%;@V@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*
M;7-G<W1R("*#08-*@T6#DX-G@LV3@(R+@K."ZH+$@J*"W(*W@4(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED(")!8V-O=6YT:6YG
M(@IM<V=S='(@(H-!@TJ#18.3@V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@
M(D%D9"(*;7-G<W1R("*2QXG!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@
M861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*
M;7-G<W1R("*#5(-U@T^#BX%;@W:"\)+'B<$B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(H-4
M@W6#08-.@UJ#6(R@@O"2QXG!(@H*(R!M<V=S='(@(H-4@W6+EHG"@W2#B8-/
M@O"2QXG!(@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B
M061D($AE<F4Z(@IM<V=S='(@(H*Q@K&"R9+'B<$Z(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.
M97<@1W)O=7`B"FUS9W-T<B`BD%:"M8*B@T^#BX%;@W:"\)+'B<$B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*
M;7-G<W1R("*05H*U@J*"\(-!@TZ#6H-8C*""\)+'B<$B"@HC(&US9W-T<B`B
MD%:"M8*BBY:)PH-T@XF#3X+PDL>)P2(*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B@U2#=8-/@XN!6X-V
M@O`@7"(E<UPB((+)DL>)P2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(H-4@W6#08-.@UJ#6(R@@O`@
M7"(E<UPB((+)DL>)P2(*"B,@;7-G<W1R("*#5(-UBY:)PI#=DNB"\"<E<R>"
MR9+'B<$B"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@
M=7-E<CHB"FUS9W-T<B`BD%:+2X.&@5N#58+PDL>)P8%&(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("*7\8+PDL>)P2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*
M;7-G<W1R("*05HM+@X&#DX-O@O"2QXG!@48B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("*#>8-!
M@O"2QXG!(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I
M9&5B87(B"FUS9W-T<B`B)7,@@X&#:H.%@5N"\"!-;WII;&QA((+,@U2#0X-H
M@V^!6X+)DL>)P8*W@NDB"@HC(&US9W-T<B`B@TJ#C(.3@U^!6X+)DL>)P2(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("*#08-H@XR#6)*@
M@LF2QXG!.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R
M("*.A(+,@LR#08-H@XR#6)*@@LF2QXG!(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(H.&@5N#58+PDL>)P2(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@
M(B(*(H-6@UB#98.`@LD@7"(E<UPB((+PDL>)P8*U@MR"M8*]@JJ!08-4@T.#
MDX-!@V*#=H+,C^Z5\8*JDL>)P8+%@JN"W(*Y@O&"Q8*U(@HB@KV!1B5S(@H*
M(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G
M<W1R("*#5H-8@V6#@(+)(%PB)7-<(B""\)+'B<&"M8+<@K6"O8+,@L6!08.-
M@T^#0X.3@L6"JX+<@K>!0B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(H.&@5N#58+,DL>)P8^(EYV"S9:SC/B"R8+(@L&"Q(*B@MR"MX%"
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S@*;7-G:60@(D%D9')E<W,B
M"FUS9W-T<B`BCUJ/BB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("*#08-H@XR#6)*@(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-38*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@
M(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M(@IM<V=S='(@(HK'EYT@+2"1O(+,@X:!6X-5@LR#08-.@UJ#6(R@(@H*(SH@
M861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(HK'EYTB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS
M9W-T<B`B061S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS
M9W-T<B`B@T&#=(-+@VJ#6(->@Y,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A
M;FEA(@IM<V=S='(@(H-!@XN#;X-J@T$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!
M;&=E<FEA(@IM<V=S='(@(H-!@XN#5X-&@XJ#02(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM
M<V=S='(@(I7*EKPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS
M9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(HC*DG61M8*F@48B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R("*14Y64
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T
M960@57-E<G,B"FUS9W-T<B`BD5.41H_8@X:!6X-5(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R
M;W5P<R(*;7-G<W1R("*14X+$@LR#3X.+@5N#=B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A
M=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(I%3@L2"S(-!@TZ#6H-8C*`B"@HC(&US9W-T<B`BD5."Q(+,BY:)PI#=DN@B
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C@*;7-G:60@(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(*;7-G<W1R("*5H9"4@LR#08-H@XR#6(+PBY:)PB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(I34C8:5=(*K
M@XJ#6(-G@O"0W9+H@L6"JX+I@N:"I(+)@K6"W(*W@JF!2"(*"B,Z(&9R86UE
M=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR
M96%D>2!E>&ES=',B"FUS9W-T<B`BBOF"R9&VC=V"M8+<@K<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,
M;V=I;B(*;7-G<W1R("*1XY'6@LP@24U34""#C8-/@T.#DR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D(@IM<V=S='(@(I'CD=:"S"!)35-0((-P@UB#CX%;@V@B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`S"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M92(*;7-G<W1R("*1XY'6@LP@24U34""#AH%;@U66O"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA
M=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("*1XY'6@LR#@8%;@XN#08-H@XR#
M6"(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(I'CD=:"S(-E@Y.#=H.,@5N#9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(I'CD=:#
M98-,@UB#9X%&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B
M"FUS9W-T<B`B@T&#@8.*@TJ7S(-4@X*#02(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB
M"FUS9W-T<B`BE7.0LX+(DFR"JHYWDNB"LX+J@L2"HH+<@K<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R("*77(KZ@K6"R(*B@T>#B8%;
M@JJ4K9"V@K6"W(*U@KTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM
M<V=S='(@(H-!@Y.#:(.)(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM
M<V=S='(@(H-!@Y.#4X.)BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B@T&#DX-/@T*#B2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G
M<W1R("*3O9:\@W:#C8-,@U:!6R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T<B`BDYJ"IB(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`BD^R+R8%ID>67I(%J
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G
M<W1R("*#08.3@V6#0H-/@T&!18-O@5N#=8%;@U\B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(H-!
M@W:#BH-0@5N#5H.'@Y,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*
M;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B@T&#=H.*@U"!6X-6
M@X>#DXCJEY<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED
M(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B@T&#=H.*@U"!6X-6
M@X>#DXYGEW")PB(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X
M"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`BB;J(RH+,
MBZ273(+)DTN7<"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(H^SE$8B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`*;7-G:60@(D%P<')O
M>&EM871E(%-I>F4B"FUS9W-T<B`B@JB"J(+F@KN"S(-4@T.#62(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!
M<')I;"(*;7-G<W1R("*"4XR.(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&
M:6QE(%-I>F4B"FUS9W-T<B`B@T&!6X-*@T.#=8-T@T"#0X.+@U2#0X-9(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@
M3F%M92(*;7-G<W1R("*#08%;@TJ#0X-UEKPB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B5S((+,@U2#0X.3@T&#8H-V
MEW:+@8+PEGN3EH+)C>V/G(*U@L2"HH*B@L6"MX*I@4@B"@HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A
M;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(I9[DY:"R2!<(B5S7"(@@L:#
M5(-U@T^#BX%;@W:14X+$@O"-[8^<@K6"Q(*B@J*"Q8*W@JD_(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(H-!@XN#6X.3@V"#DXND
MF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B@T&#
MBX.!@VJ#08NDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("*#08.+@V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@
M27-L86YD(@IM<V=S='(@(H-!@UJ#DX-6@X>#DY.'(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!<VEA
M+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(H-!@U>#08%>D;Z5O9=MDFZ(YB(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/R(*;7-G<W1R("*5VX[GC>R+QH+,CL"-<Y%/@LF*;91&@O"+@8+?@NF"
MYH*D@LF"M8+<@K>"J8%((@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S`Y,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("*1MHW=@K6"R(*B@T^#
MBX%;@W:"\(WMCYR"M8+F@J2"QH*U@MR"M8*]@4(B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("*1MHW=@K6"R(*B@T&#
M3H-:@UB,H(+PC>V/G(*U@N:"I(+&@K6"W(*U@KV!0B(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`BD;:-W8*U@LB"HH-!@TZ#
M6H-8C*""\)72CU>"M8+F@J2"QH*U@MR"M8*]@4(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO
M;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`BD;:-W8*U@LB"HHNDETR"\)72
MCU>"M8+F@J2"QH*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,PIM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("*1KI"K(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@
M(D%U9W5S="(*;7-G<W1R("*"5XR.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(H-)@5N#6(-G@XF#BH-!(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM
M<V=I9"`B075S=')I82(*;7-G<W1R("*#28%;@UB#9X.*@T&+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!
M=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@E4N7=H+(24U!4(IGDJ.+0)1<@JJ,
MJ8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z((-O@V*#3H-'@Y.#:(+-E4N7=H+(E%R7S8+PETR"M8+$@J*"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I
M9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B"7=HN!@K>"Z6EM87"*9Y*C@JJ,
MJ8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N
M<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!&5%"*9Y*C
MBT"47(*J@MV"PH*I@NB"W(*Y@O$N(%!(4(+P("TM96YA8FQE+69T<""#28-V
M@U:#AX.3@O""PH*O@L0B"B*#4H.3@W"#0X.+@K6"R(*H@K6"Q(*M@KZ"LX*B
M@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED
M(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]I;6%P.B!)34%0BF>2HXM`E%R"JHRI@L*"J8+H
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q
M"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!K<F(UBF>2HXM`E%R"JHRI
M@L*"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H
M7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#59+'B<&"S8-4@WR!
M6X-G@K."ZH+$@J*"W(*Y@O$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(D%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""Q8+,@X:!6X-5C>V/G(+-
M@U2#?(%;@V>"LX+J@L2"HH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($Q$
M05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B075T:%]L9&%P.B"#AH%;@U4@
M)7,@@O"2QXG!@L6"JX+<@KF"\8%"@U2!6X-O@LR)GI.:.B`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z((.&@5N#52`E<R""\(WMCYR"Q8*K@MR"N8+Q(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B075T:%]L9&%P.B"#AH%;@U4@)7,@@O"-6)!6@L6"JX+<
M@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS
M9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T
M960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(D%U=&A?;&1A<#H@
M06-T:79E($1I<F5C=&]R>2""Q8+,@X:!6X-5C5B05H+-@U2#?(%;@V>"LX+J
M@L2"HH+<@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z
M-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($U#05"*9Y*CBT"47(*J
MC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@
M<VUB875T:(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!9&UI;BYP:'`Z,3`V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N(@IM<V=S='(@(DE-05"#5(%;
M@V^"Q8+,E$:/V(+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("*41H_8@LF.N)1S@K6"W(*U@KTB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960N("5S(@IM<V=S='(@(I1&C]B"R8ZXE'."M8+<@K6"O8%")7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G
M<W1R(")2041)55.#5(%;@V^"R8+F@NB41H_8@JJ+D93;@K."ZH+<@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&
M5%"#5(%;@V^"S)1&C]B"R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")334*#5(%;@V^"S)1&
MC]B"R8ZXE'."M8+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BCF>7
M<(G"E%R"R(-T@T*!6X.+@VB!1B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B
M86EJ86XB"FUS9W-T<B`B@T&#6X.+@V^#0X-7@X.#DXNDF&&-D2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`BE'>,
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`BE'>,:9!&(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D
M(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")+97)O8F5R;W,@@W"#6(./
M@5N#:(*JEK.,^(+%@K>!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B
M-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B2V5R;V)E<F]S((.&@5N#59:\@JJ6LXSX@L6"MX%"(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("*#;X-N@WTB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"86AR86EN(@IM<V=S='(@(H-O@5N#C(%;@Y,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ
M,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*
M;7-G<W1R("*#;X.3@T^#B8-F@U:#A9!LEJ^+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R("*#;X.+@V^#:(-8(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A
M<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(HKNEGN#3X.)@W2#0H-.@UB"S(-F@T*#C(-.@V>#BH%;(%PB)7-<(B""
MJH*@@NB"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B
MBNZ/@)#\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("*#
M>(.)@XN!6X-6BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*
M;7-G<W1R("*#>(.+@TV!6R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*
M;7-G<W1R("*#>(.*@5N#62(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM
M<V=S='(@(H-X@VF#DXNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B@V^#?H.%@5N#7X%ICY23AX%J(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM
M<V=I9"`B0FAU=&%N(@IM<V=S='(@(H-U@5N#7H.3B:2-D2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(I)AD+:3^B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(H-U@XV#8H-.(%PB)7-<(B""S(-!@W:#BH-0@5N#5H.'@Y,@
M7"(E<UPB((*J@J""Z(+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.CDP"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("*#
M=8.-@V*#3I#=DN@B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B@W6#C8-B@TZ#7H-#@W8B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*
M;7-G:60@(D)O;&0B"FUS9W-T<B`BD;Z.FB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)O;&EV:6$B"FUS9W-T<B`B@WN#BH-R@T&+I)AAC9$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED(")";V]K;6%R:W,B"FUS9W-T
M<B`B@W6#8H-.@WV!6X-.(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(HF/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`BB8^"S)&^
M@K.!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`BB8\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@
M(H-[@UB#:H-!@46#=X.+@V.#1H-3@W*#:2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R("*#>X-C@X^#:8NDF&&-D2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B@W6!6X-XDX<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R
M"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B@W6#B8-7@XLB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S
M='(@(HEPE\R#0X.3@VB/E).'(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I
M($1A<G5S<V%L86TB"FUS9W-T<B`B@W6#BX-L@T.!18-?@XN#5(.)@5N#@"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(H-U@XN#2X.*
M@T$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(HG3C_"/D8*K(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(H-U@XN#
M3(-I@W2#0(-<(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R
M("*#=8.+@Y.#5XNDF&&-D2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T
M<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(D-2
M3""4>I5Z@WR#0X.3@V<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I
M97,N+BXB"FUS9W-T<B`B7T6#6H.+D:Z0JRXN+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N(@IM<V=S='(@(H-,@X.#8H-6@X6"S(^)BOJ)NX*JBJZ7
MN8*U@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ-B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@U"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(I=<
MDNB57"(*"B,@;7-G<W1R("*#2H.,@Y.#7X%;(@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("*#2H.3@WN#5X-!
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B@TJ#@8.+
M@5N#DXNDF&&-D2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*#<(-8@X^!
M6X-H@LV.J9.N@L6"S8.*@UJ#8H-G@L6"JX+<@KF"\8%"BL>7G8[2@LF809>-
M@K6"Q(FZ@K."HH%"(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL
M92!<(B5S7"(B"FUS9W-T<B`B@W2#0(-#@XL@7"(E<UPB((+)CY&"KX+<@KF"
M\8%"(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A
M9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@
M(HI/E92"S(-:@V*#5H.'@Y.#;H.3@VB#B8%;@LV*QY>=@L6"JX+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T
M<B`B24U!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*].B`E<R(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R("*#=(-`
M@T.#BR!<(B5S7"(@@JJ*2H*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#86YA9&$B"FUS9W-T<B`B@TJ#:8-?(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B@TR#@X.3@UJ#BR(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE
M;2!297!O<G0B"FUS9W-T<B`BC^&*497QC9""\(-,@X.#DX-:@XN"MX+I(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M@W2#0(-#@XL@7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(HWL
MB\:#9H-"@XR#3H-G@XJ"JHRIE72"J8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM
M<V=S='(@(B=T87)G971&:6QE)R"#<(.)@X&!6X->@LB"M8+%@LV1L8US@L6"
MJX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("*#9H-"@XR#3H-G@XJ!6R!<(B5S7"(@@O"-[8^<
M@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+B(*;7-G<W1R("*-[8^<@L6"JX+<@KF"\8%"CG&1MX*J
M("5D()&VC=V"M8+<@K>!0B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU
M;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T
M(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*(I7`@M>1UH*F
M@LR1SH_;@LR0E(*JE=N1MH*S@NJ"Q(*B@NF0E(+&C8>"[8+(@J*"S(+%E<""
MUY'6@J:"JH+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`BCG>2Z(*S
M@NJ"O934C8:"R8.!@V*#6H%;@U>"\)1ZD9>"Q8*K@MR"N8+Q@L6"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(H-*@5N#
M?(-X@XN#9HNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B
ME5R1Z"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("*#3(.#@XJ#02(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A
M;F0@3&%B96QS(@IM<V=S='(@(I6JE]Z"QH.)@WB#BR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("*#4(-#@WV#DX^4DX<B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT
M"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(HQGD=&39)AB(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM
M<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(H-:@XN1KI"K(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G
M:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B@UJ#BY:$D9"!1B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*
M;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("*#6H.+D:Z0JR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(H-:@XN77922@48B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<Q"FUS9VED(")#96QL<&AO;F4B
M"FUS9W-T<B`BC&>1T9-DF&(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(I*&B9LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS
M9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`BDH:)FX-!
M@W2#BH-*BZ2888V1(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED
M(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(H_8EKZ/D8+,C]J-UR(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("*/V):^CY&"S(^*ETR.TB(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED
M(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("*/V):^CY&#?(.*@U:!
M6R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("*#8(.#@VB+
MI)AAC9$B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS
M9W-T<B`BE<^-6"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B@W"#6(./
M@5N#:(+PE<^-6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I
M9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE
M('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I
M;',N(@IM<V=S='(@(I-DCG&#@8-#@XN"R8YGEW""MX+IEKR13X+&@T&#:(.,
M@UB"\)7/C5B"M8+<@K>!0B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N
M;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@
M("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B*,
MNXW=@LR0W9+H@L6"S8-P@UB#CX%;@VB"S)7/C5B"\(-4@WR!6X-G@K6"Q(*B
M@MR"N8+Q@4**QY>=CM*"R9A!EXV"M8+$B;J"LR(*(H*B@4(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS
M9VED(")#:&%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI
M;FLN+BXB"FUS9W-T<B`B7TN#BH.3@TZ"\(-@@T:#8H-.+BXN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B@V"#BHNDF&&-D2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(I*&B=B0;):OBZ2888V1(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I
M9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R("*#08-V@XJ#4(%;@U:#
MAX.3D4F1\(%&(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B@W"#6(./
M@5N#:(+PD4F1\"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(H.&@5N#
M59:\@O"129'P(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I
M9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("*3^I5T
ME5R.IHQ@CJZ!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(H-.@XJ#6(-]
M@UB3AR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(H-.@XF#
M6)+HBV`@)7,@@JJ,J95T@JF"Z(+<@KF"\8%"(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B35,M
M3V9F:6-E@LR#7H-/@O".YH+HCYR"K2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,CD*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(HR?C?6/P8N.(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(H.&@5N#
M58+,D=Z+CH%&)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B@X:!6X-5C\&+CB(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#
M;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B@X:!6X-5@V:!6X->C\&+CB(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED
M(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#
M;VYT:6YU92(*;7-G<W1R("*#3H.*@V*#3H*W@NF"QHZ?@M8B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G
M:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B@T6#0H.3@VB#18+P
ME<*"MH+I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*;7-G:60@(D-L
M;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS
M9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C
M;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B@U*#4H-8CY23AR(*"B,Z
M('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA
M<'-E(%-I9&5B87(B"FUS9W-T<B`B@U2#0X-H@V^!6X+PC_2"WB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*
M;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(H-2@XV#DX-R@T&+I)AAC9$B
M"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`BD$8B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,U"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S8*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,R!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B
M"FUS9W-T<B`BD$:129'P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@R-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("*01I%)D?`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`BE_&!1B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-#,*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T
M<B`BE_&#7H-#@V>#BR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-C8*;7-G:60@(D-O;6EC<R(*;7-G<W1R("*#4H-^@V*#3H-8(@H*(SH@861M
M:6XO8VUD<VAE;&PN<&AP.C(V"FUS9VED(")#;VUM86YD(@IM<V=S='(@(H-2
M@WV#DX-H(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM
M86YD(%-H96QL(@IM<V=S='(@(H-2@WV#DX-H@U:#1H.+(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM
M<V=S='(@(H-2@X&#DX-G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(HNDDLJ6
MO"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(H-2@X*#
MC9A!C8<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(HGOCM`B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED
M(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R
M96YC97,B"FUS9W-T<B`BD-V2Z(+,C;>5JB(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@
M=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B
M4$1!@4&#6(-]@5N#9X-T@TB#DX%!3W5T;&]O:X+&@LR3KXKZ@O"0W9+H@K6"
MW(*W@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#
M;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("*0W9+H@LV/
MW):ABOJ,P)#8@NJ"Q8*W@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R
M("(E<R""\)#=DNB"MX+I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("*#
M<(-8@X^!6X-H@O"*;91&(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS
M9W-T<B`B@U*#DX-3BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L
M(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R("*#4H.3
M@U.6KX[EBZ2888V1(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@
M(I#:D;&.N)1S@4(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@
M(I#:D;&.N)1S@48B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BXB"FUS9W-T<B`BC/:/3XRN@U2!6X-O@M:"S)#:D;&"JHN1
ME-N"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB
M"FUS9W-T<B`BC/:*2HRN@U2!6X-O@M:"S)#:D;&"JHN1E-N"LX+J@MR"M8*]
M@4*7G9=2@48E<R`H)7,I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX-S8*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(D944(-4@5N#;X+6@LR0VI&Q@LF.N)1S@K6"W(*U@KV!0B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("*809>-
MD.8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("*809>-D.:"S8-!@VB#C(-8
MDJ""R9+'B<&"LX+J@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT96YT('1Y<&4@;V8@8V]M
M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`BB+./:X-T@T"#0X.+@LR#4H.3@V6#
MDX-C@UZ#0X-V@48B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T
M<B`B7"(E<UPB((+,D^"792(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B
M0V]N=&EN=64B"FUS9W-T<B`BD;&"K2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R("*#3H-B@TZ/E).'(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(H-2@W.!6R(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M<'D@9F%I;&5D.B`E<R(*;7-G<W1R("*#4H-S@5N.N)1S@48E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(I%)D?"4S8C-@O"#4H-S@5LB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B
M0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T82!2
M:6-A(@IM<V=S='(@(H-2@UB#7H.*@TJ+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(H-2@5N#9X-7@WN#CX%;@XN+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<*
M;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T
M<B`B@X&#8H-:@5N#5X+,(%!'4""(PXV&B;N"JH+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B@X&#
M8H-:@5N#5X+,(%!'4""/D):\@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(H.!@V*#
M6H%;@U>"S"!3+TU)344@B,.-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(H.!@V*#
M6H%;@U>"S"!3+TU)344@CY"6O(*J@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<R(*;7-G<W1R("*809>-D.:"\)+'B<&"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`B3$1!4""#5(%;@V^"R8-O@T.#DX-H@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("*.8XV"@JJ*;91&@L6"JX+<
M@KF"\8+%@K6"O8%")7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q
M"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3$1!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U<VEN9R!&
M5%`Z("5S(@IM<V=S='(@(D944"""Q8-4@5N#;R!<(B5S7"(@@LF0VI&Q@L6"
MJX+<@KF"\8+%@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("*1EY!-D.:#BH-8@V>"JHWLD*R"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B"FUS9W-T<B`B4$=0((-F@5N#
M7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*].B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C
M<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B4R]-24U%((-F@5N#7H+,E9R-
MAHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(IA!
MEXV0YH*JC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`BD9>039#F@XJ#6(-G@JJ-[8^<@L6"JX+<@KF"\8+%
M@K6"O8%")7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A
M9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`BD-V2Z(U8D%:7<(-8@TZ#BH-V
M@V<@7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN
M92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(H[S
MD$V.TH+,DV2.<8.!@5N#BX-!@VB#C(-8@JJ*;9+H@L6"JX+<@KF"\8+%@K6"
MO8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(H-!@VB#C(-8DJ""JHJND5."R8+-CN:3OH+%
M@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(I&7D$V0YH.*
M@UB#9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T
M<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(I&7D$V0YH.*@UB#9X*JBJZ14X+)
M@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(H-8@V>#B8-E@U>!
M6R!<(B5S7"(@@O"#C8%;@VB"Q8*K@MR"N8+Q@L6"M8*]@4(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G
M<W1R(")-:V1I<B!<(B5S7"(@@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T
M(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T
M<B`BC/:*2HRN@O",KH-4@5N#;X*I@N>.YI.^@L6"JX+<@KF"\8+%@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(EPB)7-<(B""\(^1@JN-GH+=EW""R8-)@5N#=H.3@L6"JX+<@KF"\8+%@K6"
MO8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M("5S+B(*;7-G<W1R("(E<R""\(-)@5N#=H.3@L6"JX+<@KF"\8+%@K6"O8%"
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT
M,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E
M;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BE=N.YXWLB\:#@H-7@X6!
M6X.+("5S((+PBDJ"KX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(H-F@T*#C(-.@V>#BH%;(%PB)7-<
M(B""JHI*@J^"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y
M.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B3$1!4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7,@@JJ3QX+=CV^"
MN8+<@KF"\8%"(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B*7=HN!@K."ZH*]@X:!6X-5@LR#<(-8@X^!6X-H@O"#BH-:
M@V*#9X+%@JN"W(*Y@O&"Q8*U@KV!0H*B@JV"PH*I@J""Z8*B@LV14X+$(@HB
M@LR/[I7Q@LV*U(CA@L&"Q(*B@MR"MX%"C<23>(Z.@K6"Q(+=@NF"J8K'EYV.
MTH+)F$&7C8*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS
M9W-T<B`B04-,((+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KTB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K
M+B`E<R(*;7-G<W1R("*#08-H@XR#6)*@@O".YI.^@L6"JX+<@KF"\8+%@K6"
MO8%")7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(I&7D$V0YH.*
M@UB#9X+PCN:3OH+%@JN"W(*Y@O&"Q8*U@KV!0B5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L
M:7-T<RX@)7,B"FUS9W-T<B`BD9>039#F@XJ#6(-G@O".YI.^@L6"JX+<@KF"
M\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<R(*;7-G<W1R("*#5(%;@V^"S(M`E%R(ZI>7@O".YI.^@L6"
MJX+<@KF"\8+%@K6"O2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*
M;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`BD-V2Z(+PC+."R9;?@KF"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HY-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD
M:7(@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@@V:#0H.,@TZ#9X.*@5N"JHWM
MCYR"Q8*K@MR"N8+Q@4(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(E<R"0W9+H@O"5VY&V@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A
M8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(I#=DNB"S(-O@V*#3H-!@V*#
M=H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(I#=DNB"S(-O
M@V*#3H-!@V*#=H+PE=N1MH+%@JN"W(*Y@O&"Q8*U@KV!1B5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<
M(BXB"FUS9W-T<B`BD-V2Z(U8D%:7<(-8@TZ#BH-V@V>"\"!<(B5S7"(@@LF5
MVY&V@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`BD-V2
MZ(+,@V^#8H-.@T&#8H-V@W2#0(-#@XL@)7,@@O"5VY&V@L6"JX+<@KF"\8+%
M@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B
M"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y
M(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"B*0
MW9+H@W2#0(-#@XL@)7,@@LF5VY&V@L6"JX+<@KF"\8+%@K6"O8%")7,@@LF6
MWX+!@L25VY&V@TF#=H-6@X>#DX+PCL"-<X*W@NDB"B*"J8%!CNB"Q8*Q@LR)
MYI;*@LR#4H%;@VB"\"`E<R""R8-2@W.!6X*U@L2)NH*S@J*!0B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3$1!4""#5(%;
M@V^"JHR?C?6"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N
M(@IM<V=S='(@(EPB)7-<(B""\(WMCYPH=6YL:6YK*8+%@JN"W(*Y@O&"Q8*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BF$&7C9#F@O"-6)!6@L6"JX+<@KF"
M\8+%@K6"O8%")7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("*1EY!-
MD.:#BH-8@V>"\(U8D%:"Q8*K@MR"N8+Q@L6"M8*]@4(E<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G
M<W1R(")<(B5S7"(@@LR0W9+H@JJ/D8*KC9Z"WX+<@KF"\8%&)7,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+B(*;7-G<W1R(")-;WII;&QA((+,@U2#0X-H@V^!6X*JC*F5=(*I
M@NB"W(*Y@O&!0H-4@T.#:(-O@5N"\(I*@J*"Q(FZ@K."HH%"(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$V"FUS
M9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T
M<B`BC9$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E
M(@IM<V=S='(@(HWLD*PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("*05HM+
MC>R0K"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP
M.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR
M"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B@U2#=8-T@TB#
MBX-?@O"-[)"L(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BC>R0K([2
M@LR#08-.@UJ#6(R@(@H*(R!M<V=S='(@(HWLD*R.TH+,E=N,[)#=DN@B"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,#D*;7-G:60@(D-R961I="!C
M87)D(&YU;6)E<B(*;7-G<W1R("*#3H.,@U>#8H-G@TJ!6X-HE-2-AB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(H-.@XV#08-@@T&+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(H-,@X6!
M6X-OBZ2888V1(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#
M=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("*,NXW=
M@LR#6H-B@U:#AX.3(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L
M;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B
MC+N-W8+,CIZ*U"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`BC+N-W8+,(%523"""S2(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("*,NXW=@LR#AH%;@U6!
M6R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@
M5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@
M(B5S((+6@LR#C8-/@TF#DXZ>@LF.P(US@K>"Z8->@UB#3H+PD-V2Z(*U@MR"
MMX%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`BD-B"Z([F@N@B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(I%)D?"4S8C-@O"0V(+HCN:"
MZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("*#3(-V@XV#
M6(NDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#
M>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y
M<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("*#8(-&@U*+I)AA
MC9$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4R('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R
M("*3^B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-CD*;7-G:60@
M(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM
M<V=I9"`B1&%I;'DB"FUS9W-T<B`BEHB3^B(*"B,Z(&%D;6EN+V1A=&%T<F5E
M+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")$871A
M5')E92")>Y>7(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(V-PIM
M<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(H-F@5N#7H-X@5N#6(Y1
MC\8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.34*;7-G:60@(D1A=&4B
M"FUS9W-T<B`BD_J5="(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM<V=S='(@(H-F@5N#
M7H[SD$TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-S@V"FUS9VED
M(")$871E('-E;&5C=&EO;B(*;7-G<W1R("*3^I5TD4F1\"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM
M<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B7TR7\8+,C>V/G"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED
M(")$96-E;6)E<B(*;7-G<W1R("(Q,HR.(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C
M:6UA;"!N=6UB97)S(@IM<V=S='(@(H]<D&F0E"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E
M($EN9&5N="(*;7-G<W1R("*2:8FZ@K""\)#S@JTB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PIM<V=I
M9"`B1&5F875L="(*;7-G<W1R("*#9H-T@TB#BX-G(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U
M;'0@0V]L;W(B"FUS9W-T<B`B@V:#=(-(@XN#9Y!&(@H*(SH@9G)A;65W;W)K
M+TED96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)9&5N
M=&ET>2(*;7-G<W1R("*#9H-T@TB#BX-G($E$(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(H-F
M@W2#2(.+@V<@<VAE;&PB"@HC(&US9W-T<B`B@V:#=(-(@XN#9XN6B<*0W9+H
M(@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I
M;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("*-[8^<(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("*#6H.+C>V/G"(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B@T^#BX%;@W:"\(WMCYPB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T
M92!,;V<B"FUS9W-T<B`B@XV#3X+,C>V/G"(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(H-!@TZ#
M6H-8C*""\(WMCYPB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("*#
M6H.+C>V/G"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B
ME_&"S(WMCYPB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("*1
MXY'6@V6#DX-V@XR!6X-G@LR-[8^<(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*
M;7-G<W1R("*#@8-B@UJ!6X-7@O"-[8^<(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB((+,@T&#
M3H-:@UB,H(+PC>V/G"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R
M(")<(B5S7"(@@LR#08-.@UJ#6(R@@L:"NX+,@U2#=8-!@TZ#6H-8C*""\)%3
M@L2-[8^<@K6"W(*W@JF!2"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS
M9W-T<B`BC7."S(WMCYPB"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E
M;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB
M"FUS9W-T<B`BD4F1\(*U@KU)1(+PC>V/G"(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O
M;&1E<G,B"FUS9W-T<B`B@U2#=8-T@TB#BX-?@O"-[8^<(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(HR[C=V(
MRI)U@LR7\8+PC>V/G"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(')O=R(*;7-G<W1R("*,NXW=B,J2=8+,C7."\(WMCYPB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B
MD-V2Z(U8D%:7<(-8@TZ#BH-V@V<@7"(E<UPB((+PC>V/G(*U@MR"M8*]@4(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@
M(I1ZD9>.GHK4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R
M("*#9H.3@WV!6X-.(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(H_A
MBE&3X)=E@LR0X):^(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,U
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(I#@EKXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-@IM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("*/VHW7@6E(;W)D98+,
M@XV#3X-T@T"#0X.+@N".48_&@6J!1B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*/VHW7@LV*QY>=CM*"
MS(*]@M^"R8M,F%Z"LX+J@MR"M8*]@4(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("**2I2M
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C0*;7-G:60@(D1E=R!0;VEN
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I
M9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")$97<@<&]I
M;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R("*-MH*I@N>)18+6(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0B"FUS9W-T<B`BB46"J8+GC;:"UB(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH
M;W5R('1I;65S/R(*;7-G<W1R("(R-(Z>BM257(ZF(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S
M='(@(I5<CJ:#28-V@U:#AX.3(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.3(*;7-G:60@(D1I
M<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<Y-@IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,0IM
M<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(H-7@W6#8(NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED
M(")$;R!N;W0@9&5L971E(@IM<V=S='(@(HWMCYR"M8+(@J(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(FUA:6YT96YA;F-E
M+G!H<"""R9*\D-J#08-.@UJ#6(*U@LB"HH+%@JV"OH*S@J(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@
M=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G
M<W1R("*-Q8^)@LR7\8*J@W2#0H%;@XN#:):\@O"*W(+Q@L6"HH+<@K>"J3\@
M@KN"I(+(@N>#8(-&@V*#3H*U@L2"K8*^@K."HH%&(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B@VB#?H-J@THB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B@VB#?H-J@TJ+
MI)AAC9$B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED
M(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(H-!
M@TJ#18.3@V>"JI5+EW:"R(+G@U2#0X.3@T&#8H-V@4(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3$*;7-G:60@(D1O=VYL;V%D
M(@IM<V=S='(@(H-?@T6#DX.-@5N#:"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N
M;&]A9"`E<R(*;7-G<W1R("(E<R""S(-?@T6#DX.-@5N#:"(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(I"VD*R"
MLX+J@KV0W9+H@O`@4$A0((-8@TZ#BH-V@V>"\(+&@K6"Q(-?@T6#DX.-@5N#
M:(*W@NF!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#0*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB
M"FUS9W-T<B`BDV2.<8.!@5N#BR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T
M97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@
M<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B
M15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS
M9W-T<B`B@T>#3H-!@VB#BXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,@IM<V=I9"`B161I="(*;7-G<W1R("*5TH]7(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G
M<W1R("*#=8.-@V*#3H+,E=*/5R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(H-/@XN!6X-V@LR5TH]7(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM
M<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(H-!@TZ#6H-8C*""S)72
MCU<B"@HC(&US9W-T<B`BBY:)PI#=DNB"S)72CU<B"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B@T&#3H-:@UB,H(+,E=*/5R(*"B,@;7-G<W1R("*+EHG"D-V2Z(+,
ME=*/5R(*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("(E<R""S(-!@TZ#6H-8C*""S)72CU<B"@HC(&US9W-T<B`B)7,@@LR+EHG"
MD-V2Z(+,E=*/5R(*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I
M9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B@TF#=H-6@X>#DX+,E=*/
M5X%&(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(@IM<V=S='(@(EPB)7-<(B""S(-!@TZ#6H-8C*""S)72CU<B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S((+,@T&#3H-:
M@UB,H(+,E=*/5R(*"B,@;7-G<W1R("(E<R""S(N6B<*0W9+H@LR5TH]7(@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("*#
M1X-7@W:#9X%%@T&#B8-UBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R("*#1X.+@U2#BX-O@VB#BXNDF&&-D2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8V"FUS9VED
M(")%;6%I;"(*;7-G<W1R("*39(YQ@X&!6X.+(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D6#@8%;@XN#
M08-H@XR#6"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C`*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%@X&!
M6X.+@T&#:(.,@UB"JHCJDG:"M8+(@J^"ZH+.@J*"KX+<@KF"\8%"(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX-@IM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B18.!@5N#BX-!@VB#C(-8BFV41B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS9VED
M(")%;6]T:6-O;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S
M86=E+B(*;7-G<W1R("*+\X.!@V*#6H%;@U>"Q8*W@4(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(HF]@N",J8+"@JF"Z(+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B
M16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(HOS@LR,GXWUC.HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*
M;7-G<W1R("*#38.#@XF#BH%;@JF"YXGFD9R"\)%]D_R"Q8*K@NF"YH*D@LF"
MM8+<@K>"J8%((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I
M9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B
MB46#3H.*@V*#3H+%@X&#:H.%@5N"\)5<CJ:"M8+<@K>"J8%((@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-SDP"FUS9VED(")%;F0@>65A<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%
M;FQA<F=E($5D:71O<B(*;7-G<W1R("*#1X-F@T*#7H%;B>:6RH+PD>6"JX*M
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT
M97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME
M9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N
M("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*
M(H*@@LB"O8+,@W"#6(./@5N#:(+P@XJ#6H-B@V>"MX+ICIZ"S)=PD%."S(*]
M@M^"S(Z_EN*"\)/\E\V!0I?A@J:"SH%!@76#>8-B@V<B"B*"S):\D4^"S8%(
M@7:!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@=&AE(&EM86=E(%523"!H
M97)E(@IM<V=S='(@(HGFD9R"S%523(+PD_R7S2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H
M92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED
M(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("*0U).Y@TV#:H-!BZ2888V1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("*#1X.*@V>#
MBH-!(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%<G)O
M<B(*;7-G<W1R("*#1X.)@5LB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M
M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A
M=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B@W6#C8-B@TZ-[)"L@T>#B8%;.B`E
M<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z
M("5S(@IM<V=S='(@(I.OBOJ#C8-/@LR-[8^<@T>#B8%;.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@
M(I/@EV6.YI.^@T>#B8%;.B`E<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I
M;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(H-P@UB#CX%;@VB-6)!6@T>#B8%;
M.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B@X&!6X.+@T&#:(.,@UB"S(-'@XF!6X+%@K>!0B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B""S(^1@JN-GH+=@T>#
MB8%;@L6"MX%"(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R
M("*#1X-8@V>#:H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P
M:6$B"FUS9W-T<B`B@T>#8(-)@W.#02(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@
M(H.(@5N#C8-B@W`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0S"FUS
M9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@(C$UE:J6B"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E
M<R(*;7-G<W1R("(RE:J6B"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@
M<V5C;VYD<R(*;7-G<W1R("(S,)6JEH@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G:60@(D5V
M97)Y(#4@;6EN=71E<R(*;7-G<W1R("(UE:J6B"(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO
M9VEN(@IM<V=S='(@(H.-@T^#0X.3EH@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B,S"5
MJI:((@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B
M,96JEH@B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I
M9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(HYWDNB2;(+,E^$B"@HC.B!A
M9&UI;B]P:'!S:&5L;"YP:'`Z.#(@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B
MCL"-<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BDU>*2B(*"B,Z('1E
M;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X<&%N9"!3
M:61E8F%R(@IM<V=S='(@(H-4@T.#:(-O@5N"\)-7BDHB"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B)RDG((+PDU>*2B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O
M<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A
M=&4B"FUS9W-T<B`BETR,^(KZC,`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`BCG>0
ME"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(I%/C&F01B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@
M;V8@<V5T=7`B"FUS9W-T<B`BD-V2Z(+P($944"""Q8-!@V*#=H.-@5N#:(*W
M@NDB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,C`*;7-G
M:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("*#
M=H.,@W2#0(.,@Y.#6)#=DNB"\([FD[Z"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@@U2!6X-O@LF0VI&Q@L6"JX+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*
M;7-G<W1R(")334(@@U2!6X-O@LF0VI&Q@L6"JX+<@KF"\8+%@K6"O8%"(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(EPB)7-<(B""J8+G@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@
M@M:"S(-2@W.!6X+)CKB4<X*U@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(I!6BTN"S"!305-,()#:D;&"
MR8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HU,#$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R
M(")<(B5S7"(@@M:"S(C:DZZ"R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("*.YI.^@LF.N)1S@K6"
MW(*U@KV!1B5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM
M<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@(H-T
M@TB!6X-.@XF#DX-HCY23AX%I@WV#BX-R@VF#6(^4DX>!:B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B@W2#1H.-@5N/E).'
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@
M17)R;W(Z(@IM<V=S='(@(I)VEKV328-'@XF!6X%&(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM
M<V=S='(@(D9!6"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*
M;7-G:60@(D9A>&5S(@IM<V=S='(@(D9!6"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G
M<W1R("*"48R.(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@
M(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS
M9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.30Q"FUS9VED(")&:65L9"!M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R,@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R-@IM
M<V=I9"`B1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I
M9"`B1FEJ:2(*;7-G<W1R("*#=(-"@U>!6X^4DX>+I)AAC9$B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T
M<B`B@W2#0(-#@XLB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S
M='(@(H-T@T"#0X.+D)0Z("5S((-T@T"#0X.+(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N
M=#H@)7,@9FEL97,B"FUS9W-T<B`B@W2#0(-#@XN0E#H@)7,@@W2#0(-#@XLB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B@W2#0(-#@XN#?8-L@5N#5X.#(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G
M<W1R("*#=(-`@T.#BY:\(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,CDW-`IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B@W2#0(-#@XN1
M29'P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X,PIM<V=I9"`B
M1FEL92!U<&QO860B"FUS9W-T<B`B@W2#0(-#@XN#08-B@W:#C8%;@V@B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#(*;7-G:60@(D9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("*#=(-`@T.#BX-!
M@V*#=H.-@5N#:(+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\8%"(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S
M='(@(H-T@T*#BX->(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G
M<W1R("*#=(-"@Y.#B8.3@VB+I)AAC9$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`BC^.,MX+,C(XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@
M<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R
M"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,W(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(H-T@TB#BX-?@5L@)7,@
M@JJ"H(+H@MR"N8+Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("*5MHZ:
MD$8B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("*)YI&<@O"#5(-\@5N#
M9X*U@LB"HH-U@XF#18-5EW`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T
M,0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`B@W"#6(./@5N#:(+PEEF"ZH+$@K6"W(*B
M@MR"M8*]@JF!2"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*
M;7-G:60@(D9O<FUS(@IM<V=S='(@(H-T@TB!6X.`(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I
M9"`B1F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M("*#=(-(@5N#B8.`(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q
M,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T
M<B`BB^`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`BF&<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B@W2#B8.3@UB+I)AAC9$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(H-T@XF#DX-8@6F6>XV1@6HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(H-T
M@XF#DX-8E\R#38-!@VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O
M;'EN97-I82(*;7-G<W1R("*#=(.)@Y.#6)?,@WR#BH-L@U:#02(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM
M<V=S='(@(H-T@XF#DX-8E\R+R9/LCY23AR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B
M1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("*/VH*U@J*0X):^(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G
M:60@(D9U;&P@36]O;B(*;7-G<W1R("*6GHR.(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("*.@9:\(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B@TN#>X.3BZ2888V1(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R
M("*)YI&<@O".YH+HCV^"MX--@X.#B8.*@5LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@
M(D=A;&QE<GDZ(@IM<V=S='(@(H--@X.#B8.*@5N!1B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=A;6)I82(*;7-G<W1R("*#2X.3@W*#08NDF&&-D2(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(E<R"-7)"LC^Z5
M\8+PD+:0K(*W@NDB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG
M+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`BD+:0K(*S
M@NJ"O8-2@5N#:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T
M<B`B@T^#BX-7@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY
M(@IM<V=S='(@(H-H@T.#8YA!EDV+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':&%N82(*;7-G<W1R("*#2X%;@VF+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")':6)R86QT87(B"FUS9W-T<B`B@U>#=8.)@XN#7H.+(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N
M($YA;64B"FUS9W-T<B`BD*DB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*
M;7-G<W1R("*+I)+*@TF#=H-6@X>#DR(*"B,Z('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$S,0IM<V=I
M9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B1V]O9VQE((-]@V*#=B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B
M"FUS9W-T<B`B1V]O9VQE((R?C?4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("*#38.*
M@U:#@XNDF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED
M(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1W)E96YL86YD(@IM<V=S='(@(H-/@XJ!6X.3@XF#DX-H(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("*#3X.,@VF#7R(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R("*#3X.+@5N#=HK'EYTB"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM
M<V=S='(@(H-/@XN!6X-VEKR"S8OSE)*"Q8+-@LB"HH*Q@L8B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")'<F]U<%]L
M9&%P.B"#3X.+@5N#=B`E<R""\)+'B<&"Q8*K@MR"N8+Q@4*#5(%;@V^"S(F>
MDYHZ("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"-[8^<@L6"JX+<@KF"
M\2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S
M(@IM<V=S='(@(D=R;W5P7VQD87`Z((-/@XN!6X-V("5S((+PC5B05H+%@JN"
MW(*Y@O$B"@HC(&US9W-T<B`B@T^#BX%;@W:+EHG"D-V2Z"(*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@
M(D=R;W5P<R(*;7-G<W1R("*#3X.+@5N#=B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B@T^#08-H@XN!6X-VDX<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("*#3X-!@X"3AR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B@T^#08-E@WV#B8NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U
M97)N<V5Y(@IM<V=S='(@(H-+@5N#DX-7@5N3AR(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(H-1@UB#
M9X-!@TZ#6H-8C*`B"@HC(&US9W-T<B`B@U&#6(-GBY:)PI#=DN@B"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*
M;7-G<W1R("*#48-8@V>#=8-B@TXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN
M96$B"FUS9W-T<B`B@TV#:H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=6EN96$M0FES<V%U(@IM<V=S='(@(H--@VJ#08-R@U2#18NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(H-+@T.#08-I
MBZ23KXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDU-PIM
M<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O
M=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%14
M4""41H_8@JJ"W8+"@JF"Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(86ET:2(*;7-G<W1R("*#;H-#@V"+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM
M(@IM<V=S='(@(H-N@V*#5H.%@T&#BX-3@XJ#68.`(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3$*;7-G:60@(DAE861E<B(*;7-G<W1R
M("*#=X-B@U\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S
M970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(H-W@V*#7R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S(@IM<V=S='(@(H-N@5N#:(%%@WV#3H-H@VF#BX-HCY23AR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED
M(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I
M9VAT(@IM<V=S='(@(HV"@K,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#8*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B@W>#BX-V(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.`IM<V=I9"`B2&5L<&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R
M92(*;7-G<W1R("*4O(N%(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE
M<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS
M9VED(")(;U]M92(*;7-G<W1R("*#>H%;@X`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS
M9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("*#
MC8%;@WV60(FDDJ&!:8-O@V"#2H.3CG.-D8%J(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-30X"FUS9VED(")(;VUE(@IM<V=S='(@(H-Z@5N#
M@"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U
M-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(HZID>Z"S(]:CXHB"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T
M;W)Y(@IM<V=S='(@(H-Z@5N#@(-F@T*#C(-.@V>#BH%;(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R("*.J9'N@LR39)ABE-2-AB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B@WJ#DX-7@X6#B8-8BZ2888V1
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`BC8&-
M8"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R
M9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B"5<Y"S@L@@6$U,((-F@5N#7B`E<R""JH.!
M@V*#6H%;@U<@)7,@@L6,GX]O@K."ZH+<@K6"O2(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@@TF#=8-7@T:#3H-G("5S((+)D<Z)GH*W
M@NF#@8-B@UJ!6X-7@LV"H(+H@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z((-)@W6#5X-&@TZ#9XQ>("5S((+-@X&#
M8H-:@5N#5R`E<R""R8+-@J""Z(+<@KF"\2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B`E<R""S8WMCYR"LX+J@MR"M8*](%PB)7-<(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4$A0
M((IGDJ,@)V1O;7AM;"<@@JJ52Y=V@L6"MR(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-3$R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B"#28-U@U>#1H-.@V<@)7,@@LP@
M6$U,((-C@XJ!6X*JC>R0K(+%@JN"W(*Y@O$B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@)7,@@JJ-[8^<@L6"JX+<@KF"\2!<(B5S7"(Z("5S
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B`E<R""S"!-24U%($E$((*JCN:3OH+%@JN"W(*Y@O$B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R""QI.OBOJ"Q8*K
M@MR"N8+Q(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B"3KXKZ@L6"JX+<@KF"\8%&)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z(%PB)7-<(B""S95SEKZ"R(NDETR"Q8*W(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A
M;"!2=6QE(@IM<V=S='(@(I"%E;V0_"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D
M9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(H*B@JV"
MPH+,E_&"\(R+C8>"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/R(*;7-G<W1R("*#=(-"@5N#BX-H*(US*8+,D)2"S8*B@JV"
MPH+%@K>"J8%((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B@J*"K8+"@LR-<X+PC(N-AX*U
M@MR"MX*I@4@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")(=6UI9&ET>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS
M9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("*#;H.3@TN#BH%;BZ28
M88V1(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B24U!4""#@8%;@XN#>X-B@TZ#6(+,C>R0K(+)CKB4<X*U@MR"M8*]
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(DE-05`@@X&!6X.+@WN#8H-.@UB"S(WMCYR"R8ZXE'."M8+<@K6"
MO3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("))34%0((.!@5N#BX-[@V*#3H-8@TZ#2(%;@UZ"S(WL
MD*R"R8ZXE'."M8+<@K6"O3H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S$S"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0((-!@VB#
MC(-8(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM
M<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4""#
M08-H@XR#6(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25"#08-H@XR#6(*JBY:)
MPH*S@NJ"O4-)1%*#=8.-@V*#3I/@@LF"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G
M:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B25"5E8V]B.&4
MO8+%@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R
M("*#08-#@UB#B8.3@VB+I)AAC9$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(H-!@T.#4H.3@LR"
MW2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@@LR#08-#@U*#DR(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("*#08-#@U*#DX+&@V6#3(-8@V<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))9&5N=&ET>2=S(&YA;64Z
M(@IM<V=S='(@(DE$@LR6O)%/(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RXB"FUS9W-T<B`B@N""M8+@D+."M8*ME5R.IH*S@NJ"R(*B
M@LB"YX%!)7,@@K6"Q)!6@K6"HH-%@T.#DX-H@5N"\(I*@J*"Q(FZ@K."HH%"
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B*"X(*U@N`@26YT
M97)N970@17AP;&]R97(@@O".9X+!@L2"HH+$@4&#08-#@U*#DX*JE5R.IH*S
M@NJ"R(*B@LB"YX%!@K&"L8+PD4F1\"(*(H*U@L2)NH*S@J*!0B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@
M(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE
M(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y
M960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(HGFD9R#=H.,@W*#A8%;(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(HGFD9P@55),(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(HGFD9P@55),.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S4X"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("*)YI&<(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B@T.#DX-\@5N#9X%!@UB#98-B
M@W8@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B
M@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+@VB!1B`E<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB
M"FUS9W-T<B`B@T.#DX-\@5N#9X*S@NJ"O8-T@T*!6X.+@VB!1B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("))
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(HK4B.&"P8*]
M@T&#3H-6@X>#DX-2@5N#:(*JEUZ"IH+G@NJ"Q(*B@MR"MX%"(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G
M:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S
M='(@(H.&@5N#59:\@JF#<(-8@X^!6X-H@JJ0LX*U@JV"H(+H@MR"N8+Q@4(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B*#AH%;@U66O(*ID>.1
MUH-!@VB#C(-8@JJ0LX*U@JV"H(+H@MR"N8+Q@4*-Q)-XCHZ"M8+$@MV"Z8*I
M@4&*QY>=CM*"R9A!EXV"M8+$(@HBB;J"LX*B@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`BDFF)NH*P@O"06X*M(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED("));F1I82(*;7-G<W1R("*#0X.3@V@B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("*,PI7*
M@X:!6X-5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B@T.#DX-H@VR#5H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("*/
M[I7Q(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B
M26YF;W)M871I;VXB"FUS9W-T<B`B@T.#DX-T@TB#@8%;@U:#AX.3(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q.0IM<V=I9"`B26YF;W)M
M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U
M"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")?3XSC@NN"
MR9?Q@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS
M9W-T<B`BB>:1G(+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R
M("*57(+PD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("*#
MBH.3@TZ"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E
M9F]R92(*;7-G<W1R(")?0Y%/@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`BC+N-W8C*DG6"S(SC@NN"R9?Q@O"1?9/\(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED
M("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B
M"FUS9W-T<B`BC+N-W8C*DG6"S)%/@LF7\8+PD7V3_"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I
M9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`BC+N-W8C*DG6"S(SC@NN"R8US@O"1?9/\(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED
M("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`BC+N-W8C*DG6"S)%/@LF-<X+PD7V3_"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B
M26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS
M9W-T<B`BC+N-W8C*DG6"S(SC@NN"R9)IEXZ"\)%]D_PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M92(*;7-G<W1R("*,NXW=B,J2=8+,D4^"R9)IEXZ"\)%]D_PB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T
M96UP;&%T92(*;7-G<W1R("*1XY'6@V6#DX-V@XR!6X-G@LR1?9/\(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N(&5M
M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N97<@
M<&%S<W=O<F0Z(@IM<V=S='(@(I!6@K6"HH-P@UB#CX%;@VB"\([S@J^.YH+I
M@X&!6X.+@T&#:(.,@UB"\)/\E\V!1B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C
M96QL(&%F=&5R(@IM<V=S='(@(HSC@NN"R8-:@XN"\)%]D_PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS
M9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`BD4^"R8-:@XN"\)%]
MD_PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@
M(HSC@NN"R9?Q@O"1?9/\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B
M969O<F4B"FUS9W-T<B`BD4^"R8-:@XN"\)%]D_PB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A
M9V5S(@IM<V=S='(@(H.!@V*#6H%;@U>"\)%]D_PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@
M(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`BC.."ZX+)DFF7CH+P
MD7V3_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B
M"FUS9W-T<B`BD4^"R9)IEXZ"\)%]D_PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(HSC@NN"R8US@O"1?9/\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I
M9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`BD4^"R8US@O"1?9/\(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*
M;7-G<W1R("*7<)!3@LR"O8+?@LR.OY;B@LR3FH*F@O"3_)?-@48B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED
M("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(HGFD9R"S)%]D_R!7I7/
MC5@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B@XJ#DX-.
M@LR1?9/\@5Z5SXU8(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(I&7
MD$V0YH+)D9>"Z8*]@M^"S(YCC8*"JI5SD:N"M8+$@J*"W(*W@4(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM
M<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`BCF.-@H*JE7.1
MJX+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S(*;7-G
M:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$S,`IM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP
M:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP
M.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR
M,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`BE7.0LX+((%II
M<""#9H%;@UZ"Q8*W@4(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("*5<Y"S@LB#
M08-V@XJ#4(%;@U:#AX.3@L6"MX%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-34*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,CDV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@
M(I:SC/B"R(-F@5N#7H*JDO&/;X*S@NJ"W(*U@KTN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("))
M;G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(I&7@NB0YH+,
M@T&#:(.,@UB"JI5SD+."Q8*W@4(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U
M"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("*5<Y"S@LB#
MB8-#@UJ#DX-8@TR#0X+%@K>!0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N
M(@IM<V=S='(@(I5SD+."R(_JCXJ"JHYWDNB"LX+J@MR"M8*]@4(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("))
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("*/XXC*@LR#08-.
M@UJ#6(R@@JJ5<Y"S@L6"MX%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M("*5<Y"S@LB#<(%;@V>#:8%;242"Q8*W@4(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D
M92XB"FUS9W-T<B`BE7.0LX+(D+N5:8-2@5N#:(+%@K>!0B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`BE7.0LX+(@W:#C8-G@U*#
MBX+%@K>!0B(*"B,@('!H<"UF;W)M870*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z.#`*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S
M7"(B"FUS9W-T<B`BE7.0LX+(CO.038[2@L6"MX%&7"(E<UPB(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#@P(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(V,PIM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS
M9W-T<B`BE7.0LX+(BZ273(-)@W6#5X-&@TZ#9R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV
M86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`BE7.0LX+(E*V038RS@T&#
M:(.,@UB"Q8*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A
M+B(*;7-G<W1R("*5<Y"S@LAU;FEC;V1E@V:!6X->@L6"MX%"(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`BD4F1
M\(+PE+V372(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!2
M97!U8FQI8R!O9B(*;7-G<W1R("*#0X.)@Y.!18-#@UB#B8.`BZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(H-#@XF#3HNDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("*#08-#
M@XN#B8.3@V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B@WV#DY.'(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA
M=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M27-R865L(@IM<V=S='(@(H-#@UB#B8-'@XLB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@
M(I2MC7..TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(H[.D<PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(H-#@UZ#BH-!BZ2888V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(H-7@X.#?8-#
M@THB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("*"4(R.(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")*87!A;B(*;7-G<W1R("*3^I9[(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G
M:60@(DIE<G-E>2(*;7-G<W1R("*#5X.#@5N#5X%;DX<B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("*#B(.+@U^#DR(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY
M(@IM<V=S='(@(H)6C(XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("*"58R.(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("*1M8*F@NDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I
M9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`BDH:)FY&U@J8B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(I>\DEN1M8*F(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("*-MI&U@J8B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM
M<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("*)19&U@J8B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B@TJ#58-T@UB#7H.3
MBZ2888V1(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B@TF#BH-7
M@VF#BX+PE=N1MH%((@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G
M<W1R("*#4(-J@T&+I)AAC9$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S((-4@5N#;X*JE$:/V(N1
ME-N"M8+<@K6"O8%"(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS
M9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R("*,KHWLD*R3^B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(HRN
MCG>6Y"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM
M<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("*,KI*W(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G
M<W1R("*,KH[ME]XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("*3
M9(YQC*Z"JH*W@L6"R8SVCT^,KH-4@5N#;X+)D;:-W8*U@MR"MX%"(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B@TR#
MBH-O@UB+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(I*ID4Z6KX[E
MCN6+8)!LEJ^+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R("*1Y8K8EJ^-D2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B@TZ#18-&
M@5N#9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R
M("*#3(.+@TV#6(NDF&&-D2(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")?68.,@T.#08-%@V<B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G
M92(*;7-G<W1R("*,OHSJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("*#B8-)@UB0;):O
MEJ^.Y8NDF&&-D2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-CD*;7-G:60@
M(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("*)NHRW@LR,CB(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("*1
M3XGQ@LR#C8-/@T.#DSH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O
M;2`E<R(*;7-G<W1R("*13XGQ@LR#C8-/@T.#DSH@)3(D<R""J8+G("4Q)',B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@
M;&]G:6XZ($YE=F5R(@IM<V=S='(@(I%/B?&"S(.-@T^#0X.3.B""R(*U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B@XF#9X-R@T&+
MI)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA
M=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("*4>I)U
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B@XR#;X-M
M@Y.+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`BC;8B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DX"FUS9VED("),969T(&AE861E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DT
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B@XR#7(-GB:2-D2(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(H.*
M@WB#BH-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A
M8B!*86UA:&ER:7EA(@IM<V=S='(@(I'E@XJ#<H-!@46#08.)@W6.T(GOCN6+
M8)!LEJ^#5X.#@WV!6X-Q@XJ!6X.$(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:65C:'1E;G-T96EN(@IM<V=S='(@(H.*@W&#98.3@U:#A8->@T.#DXSVC9$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM
M<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM
M<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!2
M86EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G
M:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q,0IM<V=I9"`B3&EN:R(*
M;7-G<W1R("*#BH.3@TXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<R
M"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(H.!@5N#BXWLD*R7<(+)
M@X&!6X.+@T&#:(.,@UB"R8.*@Y.#3H*W@NDB"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G
M:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(H-F@5N#
M7H-X@5N#6(CJEY<B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,0IM
M<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("*#=X.+@W:-@);:@O"5
M7(ZF@K>"Z2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI
M<W0@5&%B;&5S(@IM<V=S='(@(I5<@LR(ZI>7(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T
M+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B@UJ#8H-6@X>#DX+,B.J7EXWLD*R"R8ZXE'.!
M1B5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("*#AH%;
M@U6"S(CJEY>-[)"L@LF.N)1S@48E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B@X:!6X-5@LR#BH-8@V>"S9:SC/B"R8+(@L&"Q(*B
M@MR"MX%"(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),
M:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(H.*@V>#08-J@T&+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C<W"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(H.-@5N#:)*&+BXN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S
M='(@(HR[DFZ.GHK4@48B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#8*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("*2;HCF@L:.GHK4(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO
M;B(*;7-G<W1R("*/ZH^*(@H*(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P
M;W)T86PO<VED96)A<BYP:'`Z,C`P('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@
M(H.-@T^#0X.3(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U
M"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@
M(DQO9R!O=70B"FUS9W-T<B`B@XV#3X-!@T6#9R(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B@XV#3X-#@Y,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("*#C8-/@T.#DR"#7H-8@TXB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E
M('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R
M96-T;'DN(@IM<V=S='(@(H.&@5N#59:\@JF#<(-8@X^!6X-H@JJ0LX*U@JV"
MR(*B@KV"WX+)@XV#3X-#@Y."R8ZXE'."M8+<@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM
M<V=S='(@(H.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-C(*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED
M("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(H--@XJ#5H.#E;:.FH%I
MCZR5MHZ:@6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(H.)@V6#DY6VCIJ!:8^LE;:.FH%J(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("*#C8%;@WV0E(Z:@6F/
MK)6VCIJ!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("*#BX-.@UJ#DX-U@XN#3I'EC/:-D2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`BC(XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-
M4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@
M(I-9E72"LX+J@KT@35,M5$Y%1B""S8-F@5N#7H+PBMR"\8+%@J*"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(H-]@TJ#22(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(H-]@U"#:(-J@T&+C(.&@5N#4X-8
M@XF#<H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R
M(@IM<V=S='(@(H-]@U^#2X-8@TJ#BXNDF&&-D2(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@S"FUS9VED(")-86EL(@IM<V=S='(@
M(I-DCG&#@8%;@XLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T
M"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B
M36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R("*#?8.)@T6#0XNDF&&-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B@WV#C(%;@U:#02(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B@X*#BX-F@T*#=8ND
MF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R("*39(YQ
M@X&!6X.+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R("*#
M?8.+@UZ+I)AAC9$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.30*;7-G
M:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(I!&E72"KX*S@NJ"
MO8.)@WB#BX+PD<Z)GH*S@KF"Q)6JE]Z"\(K'EYV"M8+<@K>!0B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34V"FUS9VED
M(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*
M;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H
M(@IM<V=S='(@(H)2C(XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G
M:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(H-]@5N#5H.#@XN/E).'BZ2888V1(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(H-]@XN#98-"@VJ#
M3I.'(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@
M(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("*#=(-"@5N#BX-H@O"(ZI)V@K."
MN8+$@J*"W(*W(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(H."@5N#BH->@VJ#08%%@T.#6(.)@X"+I)AAC9$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("*#@H%;@XJ#5H.#@UB+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3,*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA
M>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DU(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-@IM
M<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G
M<W1R("*"5(R.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G
M<W1R("*#?8-#@XB#8H-GDX<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T
M<B`B@X&#DX-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I
M9"`B365N=2!M;V1E.B(*;7-G<W1R("*#@8-J@X6!6X."@5N#:"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*
M;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(H-:@XN,BXV'(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BEGN5MB(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E
M<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC
M871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B@X&#8H-:
M@5N#5X+-C)^/V(+%@JN"W(*U@KV"JH%!CY"6O([2@LR09XRS@LV,GX_8@L6"
MJX+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*;7-G:60@(DUE<W-A9V4@='EP
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@
M(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G:60@(DUE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B
M@X&#7(-B@V@B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q
M(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@
M(H.!@UR#8H-H(%PB)7-<(B""S9+HBV""LX+J@L2"W(*Y@O$B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-R!L:6(O
M0FQO8VLO;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B@X&#3(-6@U*-
MAX]/C9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R("*#?H-.@XV#;(-6@T&8099-(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V
M"FUS9VED(")-:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G
M<W1R(")-:6UE(%1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM
M<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED(")-:7)R;W(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-
M:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!0
M14%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")014%2((-P@V*#
M4(%;@U>"S"!(5%107U)E<75E<W0@@JJ,J9.6@KV"Z(+<@KF"\8%"(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@
M(B(*(I:BD-V2Z(+%@K>!0H*Q@LR#08-V@XJ#4(%;@U:#AX.3@O".9Y=P@K>"
MZ8*]@M^"R8+-D-V2Z(-T@T"#0X.+@O"-[)"L@K>"Z95+EW8B"B*"JH*@@NB"
MW(*W@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B@X&#8H-:@5N#5R!)1"""JHRIDY:"O8+H@MR"N8+Q@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`IM
M<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS
M9W-T<B`B4$5!4B"#<(-B@U"!6X-7@LP@36%I;"""JHRIDY:"O8+H@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B
M@UJ#8H-6@X>#DR!)1"""JHRIDY:"O8+H@MR"N8+Q@4(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R("*,CB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-@IM
M<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`BC&>1T8.!@5N#BR(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")-
M;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("*/0Y"SD_HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U
M8FQI8R!O9B(*;7-G<W1R("*#@H.+@VB#;XNDF&&-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(H."@VF#4HSVC9$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(H."@Y.#4X.+(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,0IM<V=I9"`B36]N=&@@86YD
M('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("*6B(R.
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(H."
M@Y.#9X-:@XF#9Y.'(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("*,
MCI?N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DV(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C
M=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO<F]C
M8V\B"FUS9W-T<B`B@X*#C8-B@U*)I(V1(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B
M36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L
M>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S
M='(@(HFZ@M8B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(HVV@M8B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("*)18+6(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G
M:60@(DUO=F4@57`B"FUS9W-T<B`BC^."UB(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@9&]W;B(*
M;7-G<W1R("*)NH+6(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P(@IM<V=S='(@(H_C@M8B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B@X*#58.3
M@W*!6X-.BZ2888V1(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M,0IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(S.0IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B@T&#2H-%@Y.#9R(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R("*#08-*@T6#DX-GC^Z5\2(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-#4*;7-G:60@(DUY(%!O<G1A;"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#,*;7-G
M:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")->6%N;6%R(@IM<V=S='(@(H-^@X.#DX-]@5N8099-(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G
M:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("*3KXC3@K6"W(*Y@O$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B3F%M92(*
M;7-G<W1R("*6O)%/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM
M<V=S='(@(H-I@WZ#<H-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M875R=2(*;7-G<W1R("*#:8-%@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE<&%L(@IM<V=S='(@(H-L@W"!6X.+B:2-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B@TF#B8.3@U^)I(V1(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S
M='(@(H-)@XF#DX-?E\R#08.3@V6#0H.+CY23AR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E
M(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G
M:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P
M92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C
M;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*
M;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B@VR#8H-G@X^!6X-.(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I
M9"`B3F5V97(B"FUS9W-T<B`B@LB"M2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M3F5W($-A;&5D;VYI82(*;7-G<W1R("*#=(.)@Y.#6)?,@VJ#A8%;@TJ#C(-H
M@VJ#02(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE
M;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`BD%:+2Y6J
ME]XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N
M(@IM<V=S='(@(I!6C(XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G
M<W1R("*05H*U@J*#AH%;@U66O"B40XC3*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B@VJ#A8%;@U>!6X.)@Y.#:"(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A
M<W-W;W)D(@IM<V=S='(@(I!6@K6"HH-P@UB#CX%;@V@B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`BD%:"
MM8*B@W"#6(./@5N#:(+-("5X((+)BOJ,P)#8@NJ"R8+(@NB"W(*W@4(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*;7-G:60@(DYE=R!P
M87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(I!6@K6"HH-P@UB#CX%;
M@VB"JHCJDG:"M8+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK
M*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R("*#:H.%@5N#6"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B
M"FUS9W-T<B`B@VJ#A8%;@UB#3X.+@5N#=B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(HZ?(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").
M97AT(&]P=&EO;G,B"FUS9W-T<B`BCI^"S(-)@W:#5H.'@Y,B"@HC.B!F<F%M
M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T
M<B`BCI^"S(-Y@5N#5SXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U
M82(*;7-G<W1R("*#:H-*@XF#3X-!BZ2888V1(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<B(*;7-G<W1R("*#:H-7@T:!6X.+BZ2888V1(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(H-I@T.#5X-&@XJ#09A!
MEDV+I)AAC9$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y
M"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYI=64B"FUS9W-T<B`B@VJ#18-'DX<B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(HVWE:J"\)5<CJ:"MX+I@KV"WX+,D-V2
MZ(*J@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<#HQ,#8*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G
M>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I
M9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS
M9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP
M.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("*5SXU8@LB"
MM8%"(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(H*Q@LR#08-.@UJ#6(R@@LF"S8-4@W6#08-.@UJ#6(R@
M@LV2QXG!@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3<*(SH@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X"B,L('!H<"UF;W)M870*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RXB"FUS9W-T<B`B)7,@@LR0W9+HC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q
M@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(D944"!61E,@@LR-7)"LC^Z5\8*JCG>2Z(*S@NJ"
MQ(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W
M,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!61E,@@LR-7)"LC^Z5\8*J
MCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")3
M44P@@TJ#98-3@XJ"S(U<D*R/[I7Q@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(HYCC8*"JH*@
M@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"XB"FUS9W-T<B`BD9>039#F@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR,`IM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R("*#=(-`@T.#BX*J@T&#8H-V@XV!6X-H
M@K."ZH+$@J*"W(*Y@O$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*
M;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("*#08-#@U*#DX*J@J""
MZ(+<@KF"\8%"(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q
M-B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,S`*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B
M3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(H_JCXJ"JHYWDNB"LX+J
M@L2"HH+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N
M(@IM<V=S='(@(H.!@V*#6H%;@U>"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("*6O)%/@JJ.
M=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E
M8VEF:65D+B(*;7-G<W1R("*4U(V&@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS
M:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")(5%10()1&C]B"S(-P
M@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B24U!4""41H_8@LR#
M<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DME<F)E<F]S
M()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L
M;V=I;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(H.-@T^#0X.3()1&C]B"S(-P@UB#CX%;@VB"
MJH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D
M+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!!4U-71""41H_8@LR#<(-8
M@X^!6X-H@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E--0B"41H_8@LR-7)"LC^Z5
M\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE
M($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@
M:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM
M<V=S='(@(B(*(D]P96Y34TP@@W:#C8-/@XF#@(+,@W"#6(*JCG>2Z(*S@NJ"
MQ(*B@MR"N8+Q@4)/<&5N4U-,((+-(%!+0U,@,3(@@LR#9H%;@UZ"\(BU(@HB
M@J2"S(+)E4N7=H+%@K>!0B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T
M<B`BE=N7KX+,@U2#0X.3@T&#8H-V@LB"M8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R("*#
M3H-(@5N#7H*JD-V2Z(*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").
M;R!R=6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S
M='(@(H-:@W"#C(%;@UZ"JHYWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU.#<*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("**
M69.6@W2#0(-#@XN"R(*U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(H.&@5N#59:\@JF#<(-8
M@X^!6X-H@JJ1EX+G@NJ"W(*Y@O&"Q8*U@KV!0B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T
M82!R971U<FYE9"(*;7-G<W1R("*6LXSX@LQ834R#9H%;@UZ"JI74@NB"W(*U
M@KTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q
M,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(I)L@LB"M2(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("*#28.*@U>#:8.+@LR0W9+H@W2#0(-#@XN"R8-O
M@5N#5X.'@Y."JH*@@NB"W(*Y@O&!0I#=DNB"\(W$D+:0K(*U@MR"MX%"(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BD-V2Z(-T@T"#0X.+@LF#;X%;@U>#AX.3
M@JJ"H(+H@MR"N8+Q@4*0W9+H@W2#0(-#@XN"\(WL@NB2O(*U@L2)NH*S@J*!
M0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G
M:60@(DYO;F4B"FUS9W-T<B`B@LB"M2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L
M:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*
M;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B@VV!6X-T
M@TB!6X-.DX<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(I9KE+R+A2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S(@IM<V=S='(@(I9K@WV#BH-!@VF/E).'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B@VV#BX-%@T:!6XFDC9$B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(H*Q@NJ"YH+HD4\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R("*"L8+J@N:"Z(SC(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
M@V:#0H.,@TZ#9X.*@L6"S8*@@NB"W(*Y@O$B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R("*.P)&5
M@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD*;7-G:60@(DYO
M="!S=7!P;W)T960N(@IM<V=S='(@(H-4@WR!6X-G@K."ZH+$@J*"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`X(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-3@@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X
M,`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B@X&#@B(*"B,Z('-E<G9I8V5S+V]B
M<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("(Q
M,8R.(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T,PIM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(I"4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30R,@IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B
ME;:.FI"4(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(P"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(I?Q
MD)0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`BC7.0E"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0T
M"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN
M(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("*1EY!-D.:#BH-8@V>"\(U8
MD%:"O8+?@LR4U(V&@JJ.=Y+H@K."ZH+<@KF"\8+%@K6"O8%"(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/
M2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("*#28-U@U>#
M1H-.@V<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I
M9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B@TF#=8-7@T:#3H-GC>R0K([2
M(@H*(R!M<V=S='(@(H-)@W6#5X-&@TZ#9XWLD*R.TH+,BY:)PI#=DN@B"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#$*;7-G:60@(D]C=&%L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(C$PC(XB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G
M:60@(D]F9FEC92(*;7-G<W1R("*#28-T@T*#6"(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O
M<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*
M;7-G<W1R("*,PX*B@W"#6(./@5N#:"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+B(*;7-G<W1R("*,PX*B@W"#6(./@5N#:(*JD+."M8*M@J""Z(+<@KF"
M\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R("*#28-]@5N#
MDR(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R("*+I)=,@W2#2(.+@U^"S2!)34%0((-4@5N#;X*^@J^"
MJH-4@WR!6X-G@L6"JX+<@K>!0B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.38X"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R
M97-S(&%L;&]W960N(@IM<V=S='(@(I-DCG&#@8%;@XN#08-H@XR#6(+-,8+"
M@KZ"KXYWDNB"Q8*K@MR"MX%"(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P
M97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("*/BI=,CM*"J8-6@UB#
M98.`BL>7G8[2@KZ"KX*JBZ273(+,CXJ73(R@@L:#08-.@UJ#6(R@@O"5SXU8
M@L6"JX+<@K<B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HT,2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HT,@IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`BD%:+2X-%@T.#DX-H@5N"R95<CJ8B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33""#1X.)@5N!1E,O34E-12"/D):\
M@K."ZH*]@W"!6X-G@JF"YX-F@5N#7H+PCN:"Z(]O@KF"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G
M<W1R("*#28-V@U:#AX.3(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C,Q('1E
M;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(B5S((-)@W:#5H.'@Y,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED
M(")/<F1E<F5D($QI<W0B"FUS9W-T<B`BE-2-AI5TB=./\(^1@JLB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G
M86YI<V%T:6]N(@IM<V=S='(@(I%GD$0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R("*5E(^0(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("*0KI>=(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(HRS@LR#08-V@XJ#4(%;@U:#AX.3@V6#
MDX-V@XR!6X-G(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDY(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#D*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-`IM<V=I9"`B3W1H97(@
M26YF;W)M871I;VXB"FUS9W-T<B`BD;R"S(-#@Y.#=(-(@X&!6X-6@X>#DR(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(H^*ETR.TH+,@T&#3H-:@UB,H"(*"B,@
M;7-G<W1R("*/BHZ=CM*"S(N6B<*0W9+H(@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R(")004T@E$:/V(+-CF>7<(+%@JN"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@
M(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")01U`@DV2.<8^0EKPB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED
M(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0((C#C8:5MB(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!'4"",]HI*C*XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4""/D):\C<\OB,.-AHF[@V:!
M6X->(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@0V]D
M92(*;7-G<W1R(")02%"#4H%;@V@B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%"#5H-&@XLB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B
M4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,@IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8
M(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8((IGDJ."JHRI
MDY:"O8+H@MR"N8+Q(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0
M(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T
M<B`BEH21D"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T
M<B`B@W"#3(-8@UZ#DX%%@T.#6(.)@X"+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q
M"FUS9VED(")086QA=2(*;7-G<W1R("*#<(.)@TF+I)AAC9$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D
M(@IM<V=S='(@(H-P@XR#6(-@@VF.J8ZAB^8B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!A;F%M82(*;7-G<W1R("*#<(-I@WV+I)AAC9$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B@W"#=H-!@VJ#
MA8%;@TV#:H-!D\:7IXV1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U
M87DB"FUS9W-T<B`B@W"#B8-/@T&#0XNDF&&-D2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,34*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(H-P@UB#
MCX%;@V@B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G
M:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("*#
M<(-8@X^!6X-H@LV0LX_M@LF5SXU8@K."ZH+<@K6"O8%"(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R
M9"!I;F-O<G)E8W0B"FUS9W-T<B`B@W"#6(./@5N#:(*JD+."M8*M@J""Z(+<
M@KF"\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*
M;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(E)!1$E54R"41H_8@LR#<(-8@X^!6X-H@JJ52Y=V
M@L6"MX%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,`IM<V=I
M9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B@W"#6(./
M@5N#:(+,BFV41B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(H-P@UB#CX%;@V@Z(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D
M.B`B"FUS9W-T<B`B@W"#6(./@5N#:#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S$*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(H-P@UB#CX%;@VB"JHCJDG:"M8+<@KF"\8%"
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E
M(@IM<V=S='(@(I-<@NB5=(*O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A
M<F0B"FUS9W-T<B`B@TZ#BH-B@W:#>X%;@VB"J8+GDUR"Z)5T@J\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED
M(")0871H(@IM<V=S='(@(H-P@U@B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("*5
MVY>ODH:"S(-4@T.#DX-!@V*#=H%&(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E
M;G0B"FUS9W-T<B`B@W"!6X-:@Y.#9R(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BE=N.YY&`C>R"\([`C7."MX+I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q,`IM<V=I9"`B4&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R("*#
MC8-/@T.#DXZ>@LF5VX[GD8"-[(+PCL"-<X*U@MR"MX*I@4@B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R("*#08-.@UJ#6(R@(@H*(R!M<V=S='(@(HN6B<*0W9+H(@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("*#
M08-.@UJ#6(R@(%PB)7-<(B""S8WMCYR"LX+J@MR"N8+Q@L6"M8*]@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B@T&#3H-:@UB"S8N1E-N"LX+J@MR"M8*]
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS
M(@IM<V=S='(@(H-!@TZ#6H-8C*`B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E
M<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS
M9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*#08-.
M@UJ#6(R@@LR*QY>=(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS
M9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("*,PI!LC^Z5\2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R("*#>8.+@5N+I)AA
MC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R("*#=(-"@XJ#<X.3BZ2888V1(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T
M<B`BDV288B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G
M:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0
M:71C86ER;B(*;7-G<W1R("*#<X-G@U"#08.3DX<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS
M(@IM<V=S='(@(H-S@TZ#6H.+(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@
M(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-3D*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M(@IM<V=S='(@(HR.@L:43H+PD_R7S8*U@L2"K8*^@K."HH%"(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G:60@
M(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ(@IM
M<V=S='(@(I!6@K6"HI6JE]Z"S):\D4^"\)/\E\V"M8+$B;J"LX*B.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R.3@*;7-G:60@(E!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S<*;7-G:60@(E!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N(@IM<V=S='(@(I"S@K6"HI/ZE72"\)/\E\V"M8+$@JV"OH*S@J(N
M((R.@LR3^I"4@O"#8(-&@V*#3H*U@L2"K8*^@K."HH%"(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("*/X8I1D^"798+PEW:6\8*U@L2"
MLHM,D_R"K8*^@K."HH%"(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A
M<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R
M("*#AH%;@U66O(+&@W"#6(./@5N#:(+PD_R7S8*U@L2"K8*^@K."HH%"(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B
M"B*.GX+,E;:/D8+PD\>"\8+%@JV"OH*S@J(N((*Q@LR#5H-8@V6#@(+PCF>7
M<(*W@NF"O8+?@LR+2Y+HCI:-@(+)DZ^(TX*W@NF52Y=V(@HB@JJ"H(+H@MR"
MMX%"(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@
M;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`B@WR!6X.)@Y.#:(NDF&&-D2(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T
M<B`BDXJ56Y"4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS
M9W-T<B`B@WR#BX-G@TN#BXNDF&&-D2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z()5+
MEW:"R$Q$05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?
M<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")0<F5F<U]L9&%P.B"52Y=V@LAS97-S:6]NBF>2HXM`E%R"
MJHRI@L*"J8+H@MR"N8+Q@4(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S
M,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*
M;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`B@W:#C(-R@X6!6R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I
M9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(I!6@K6"HH-%@T.#DX-H@5N"R8GFD9R"\)5<CJ8B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,U-B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,V,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R("*1
M3X+,@TF#=H-6@X>#DR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@
M(HCSC?PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*
M;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(I3IEJ>,KB(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB
M"FUS9W-T<B`BC^&*42(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM
M<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("*/X8I1D^"798+,
MD."6OB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@
M(E!R;VIE8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<S"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T<B`BC/:*2HRN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI
M8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(HSVCT^,KH-!@XN#4X.*@UF#@"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`BC/:*2HRNC^Z5\2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC
M+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB
M"FUS9W-T<B`BC/:/3XRN+Y3IEJ>,KH*JD+:0K(+%@JN"W(*Y@O&"Q8*U@KV!
M0B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(H-V@T>#BX-G@XJ#4B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R("*#
M@8-B@UJ!6X-7@O"#<(%;@U<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A
M<B(*;7-G<W1R("*#2H->@5N#BR(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV
M-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B@TZ#1X.*@5LB"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(H-*@UZ!
M6X.+(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB
M"FUS9W-T<B`B4E-!C/:/3XRN*"5D@W*#8H-G*2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-C$*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I;B!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-PIM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@
M(E)A=&EO(@IM<V=S='(@(I3D(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`BD\>"WB(*"B,@
MD\>-GB"3QX]O"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@
M8F4@=6YD;VYE+B(*;7-G<W1R("*6>Y.6@LD@)7,@@O"-[8^<@K6"W(*W@JD_
M((*Q@LR1@(WL@LV,LX+)EM^"N8+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(I9[DY:"R8.&@5N#52`E
M<R""S(-F@5N#7H+PC>V/G(*U@MR"MX*I@4@@@K&"S)&`C>R"S8[F@NB/P8*Y
M@MR"N8+Q@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R("*-Q8SC@LR1@(WL@O""XH+HDKR"MR(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2
M969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.34*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G
M<W1R("*3KI-)@X&#:H.%@5N"S(W$E5R.IHK4BG4Z(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB
M"FUS9W-T<B`B@WR!6X->@XN"S(W$E5R.IB(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$P"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S(*;7-G:60@(E)E9V5X(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,C@*;7-G
M:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("*#BH.-@5N#:"(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(H.*@X*!6X-G@U2!6X-R@U@B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T
M92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R
M("*#BH."@5N#9U523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M("(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,PIM<V=I9"`B4F5M;W9E
M(@IM<V=S='(@(HWMCYPB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("*#=8.-@V*#3H+P
MC>V/G"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B
M4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BCY&.KH+PC>V/G"(*"B,@;7-G
M<W1R("*.J96J@LR#2H.,@Y.#7X*I@N>-[8^<(@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B
M@WF#08+PC>V/G"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G
M:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("*5VY&V@K6"O8-8@TZ#BH-V@V>"\(WL
MB\:#9H-"@XR#3H-G@XJ"J8+GC>V/G(*W@NF!0B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B
M4F5M;W9E('1H92(*;7-G<W1R("*-[8^<@48B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B@K&"
MS(-M@5N#:(+P@VB#3(.%@X&#DX-G@JF"YXWMCYPB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*
M;7-G<W1R("*#AH%;@U6"\(WMCYPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S
M97(Z("5S(@IM<V=S='(@(H.&@5N#58+PC>V/G#H@)7,B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T
M<B`BEW:+@8+)E=23FH+%@JN"W(*Y@O$Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O
M=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.#4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU
M,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BEW:+@8*S
M@NJ"O2!<(B5S7"(@@LT@)7,@@LR0W9+H@LF.=Y+H@K."ZH+$@J*"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<X(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#8Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(I=VBX&"LX+J@KT@7"(E<UPB((+-(%9&4R"0W9+H@LF.=Y+H@K."
MZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("*7=HN!@K."ZH*]
M(%PB)7-<(B""S9#=DNB"R8YWDNB"LX+J@L2"HH+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U
M:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S8*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W
M"FUS9VED(")297-E="(*;7-G<W1R("*#BH-:@V*#9R(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*
M;7-G<W1R("*#<(-8@X^!6X-H@O"#BH-:@V*#9R(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D
M(@IM<V=S='(@(H*@@LB"O8+,@W"#6(./@5N#:(+P@XJ#6H-B@V<B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN
M+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`BC(N)RB(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I
M9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B@TF#=H-6@X>#DX+)EM^"
MZ2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B
M4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("*#<(-8@X^!6X-H@O"-Q)/\
ME\TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T
M<B`BC+."S(U<D*R"R9;?@K<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B
M@V6#3(-8@V>#1X-F@T*#7H%;@LR#28-V@U:#AX.3(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BB44B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3`P"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`Y-@IM<V=I9"`B4FEG
M:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`BEO"*
MA"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B@XN!
M6X-]@VJ#02(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,C8*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B,3@PDWB)\9-=
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,PIM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BC;:"R8GQDUTB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED
M(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`BB46"R8GQDUTB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED
M(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R("*-<Y&ND*LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED
M(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("*-<Y&ND*LB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W
M<SHB"FUS9W-T<B`BC7.!1B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@
M(HQRD/PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(I%3@L2"S(US@L:7\8+,
MBM2"R8QRD/R"\(CX@JTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("*-<X+,BM2"R8QRD/R"
M\(CX@JTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(')O=W,@;VYL>2(*;7-G<W1R("*7\8+,BM2"R8QRD/R"\(CX@JTB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED(")2=6XB"FUS9W-T<B`BCL"-
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R("*#C8-6@T&8099-(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A
M;F1A(@IM<V=S='(@(H.+@X^#DX-?(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@B,.-AH^0EKPB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%
M($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(E,O34E-12"(PXV&E;8B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!
M4TP@E$:/V(+-CF>7<(+%@JN"W(*Y@O&!0B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB
M"FUS9W-T<B`B4U%,((-6@T:#BR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R-S$*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*
M;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BD*R,]R(*"B,Z(&QI8B]A<&DN<&AP
M.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*
M;7-G<W1R("*3>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N
M82(*;7-G<W1R("*#6H.3@V>#=X.,@VF3AR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I
M9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(H-:@Y.#9X-,@V*#
M8X&5@VR!6X.4@T*#6"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C
M:6$B"FUS9W-T<B`B@UJ#DX-G@XN#5H-!(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("*#5(.3@W.#
M1X%;@XN!18-^@TZ#C8.3DX<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN
M="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("*#6H.3@V>#
M<X.3@UJ#DX-G@JB"YH+1@T^#C(-I@V:#0H%;@Y./E).'(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M
M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(E-A;6]A(@IM<V=S='(@(H-4@X*#09/&EZ>-D2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B@U2#DX-]@XJ#;8NDF&&-
MD2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP
M92(*;7-G<W1R("*#5(.3@V>#@8%%@W:#BH.3@U:#>9:OCN6+I)AAC9$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(H-4@T6#5X-!@XF#<H-!B:2-D2(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V
M92(*;7-G<W1R("*5VY&V(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*
M;7-G<W1R(")<(B5S7"(@@O"5VY&V(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G
M<W1R("(E<R""\)7;D;8B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU
M"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B@TF#=H-6@X>#DX+PE=N1
MMB(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@HBD+:0K(*S@NJ"O9#=DNB"\"!02%`@@UB#3H.*@W:#9X+&@K6"Q(-4
M@5N#;X+,C>R+QH-F@T*#C(-.@V>#BH+)E=N1MH*W@NF!0B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B5S()#=DNB"\)7;D;:"
MM8+<@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z(%PB)7-<(BXB"FUS9W-T<B`BD-V2Z(U8D%:7<(-8@TZ#BH-V@V<@7"(E
M<UPB((+PE=N1MH*U@MR"M8*]@4(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I
M9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ
M-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(HR?C?4B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G
M<W1R("*,GXWU@T>#DX-7@Y,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.34R"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B@W2#0(-#@XN"
M\)%)D?`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#@U"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(I/ZE72"\(YW
MDNB"M8+$@JV"OH*S@J*!1B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B
MDL>)P8*W@NF#3X.+@5N#=H+PD4F1\(*U@L2"K8*^@K."HB(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O
M=VYE<B(*;7-G<W1R("*05H*U@J*/BHZ=CM*"\)%)D?""M8+$@JV"OH*S@J(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R("*#5(%;@V^"\)%)D?""M8+$@JV"OH*S
M@J(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B
M4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BDL>)P8*W@NF#AH%;@U6"
M\)%)D?""M8+$@JV"OH*S@J(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@
M(I%3@L2129'P(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T,`IM
M<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*
M;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PIM<V=I9"`B4V5L
M96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@
M9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B
M"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB
ME4N7=H+(E;:.FH+PB;J"S(-[@V*#3H-8@JF"YY%)@O&"Q8-2@W.!6X*W@NF"
MQH%!@V6#3(-8@V>#1X.*@T&"UH-Y@5N#6(-G@L6"JR(*(H+<@K>!0B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("*3^I5T@LR+YI#8@NB5MHZ:@O".
M=Y+H@K6"Q(*M@KZ"LX*B@48B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-`IM<V=I9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B
MD_J5=(+,C&".KH+PCG>2Z(*U@L2"K8*^@K."HH%&(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(I7/C5B"
MM8*]@J))1(+PD4F1\#HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ
M-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B
MCIZ-CX+,B^:0V(+HE;:.FH+PCG>2Z(*U@L2"K8*^@K."HH%&(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(HZ>C8^"S(Q@CJZ"\(YWDNB"M8+$@JV"OH*S
M@J*!1B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@
M(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("*(ZI)V@K>"
MZ8)1@L*"S(-T@T*!6X.+@VB"\)%)@O&"Q8*M@KZ"LX*B@4(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(I!&DK*"\)%)D?""M8+$@JV"OH*S@J(N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("*,OHSJ@O"129'P@K6"
MQ(*M@KZ"LX*B.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(H_ABE&#
MC(-\@5N#9X+PD9>038*W@NDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B
M4TU3()&7D$TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(H-:@VR#2X.+BZ2888V1(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,C,*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B
M"FUS9W-T<B`B@EB,CB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B@UJ#BX-R@T&!18."@Y.#98-L@T^#C2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM
M<V=S='(@(I+*E-0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@
M(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B@UJ#8H-6@X>#DXK'EYTB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*
M;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,30U"FUS9VED(")397-S:6]N<R(*;7-G<W1R("*#6H-B@U:#
MAX.3(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q,0IM<V=I9"`B
M4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM
M<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("*668+J
M@L2"M8+<@L&"O8-P@UB#CX%;@VB"\(.*@UJ#8H-G@L6"JX+I@N:"I(+)@K6"
MW(*W@4(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B@WR!6X->@XN"Q8-!@TZ#6H-8
M@K>"Z8.*@X*!6X-G@U2!6X-O@O"0W9+H@K6"W(*W@4(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B
MC+Z,ZH%!CIZ*U)'1@4&3^I5T@O"0W9+H@K6"W(*W@4(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HBBDJ.
M;HZ>@LR#08-V@XJ#4(%;@U:#AX.3@4&01I*R@4&#>8%;@U>-Q)5<CJ:!08*[
M@LR1O(+,E5R.IH-)@W:#5H.'@Y."\)%)D?""M2(*(H+$@JV"OH*S@J(N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T=7`B"FUS
M9W-T<B`BD-V2Z"(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M(@IM<V=S='(@(I#=DNB-6)!6@UB#3H.*@W:#9R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B@UJ!6X-6
M@T:#BXNDF&&-D2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S
M='(@(HK(DE""R)=VEO&!1B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-3`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/R(*;7-G<W1R("*!:8.!@VJ#A8%;@LB"QX+%@6J#5H.'@5N#
M9X-*@V*#9X-,@5N"JHYG@J:"Z8+F@J2"R8*U@MR"MX*I@4@B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R("*57(ZF(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM
M<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("*,NXW=@LR0W9+H@L:05H*U@JV0MI"L@K."ZH*]D-V2Z(+&
M@LR-MY6J@O"57(ZF@K>"Z8%"(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y-`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG
M(&EN/R(*;7-G<W1R("*#C8-/@T.#DXZ>@LF13XGQ@LR#C8-/@T.#DXZ>BM2"
M\)5<CJ:"M8+<@K>"J8%((@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V,@IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDR"FUS9VED
M(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B
M87(_(@IM<V=S='(@(I5<D8"-[(.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B
MB>:6RHVV@LD@)7,@@X&#:H.%@5N"\)5<CJ:"M8+<@K>"J8%((@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y
M"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(I5<@LR#6H.+D:Z0JX-?@T.#08.-@T^"\)5<CJ8B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(I5<D:Z0JX-?@T.#08.-@T^"\)5<CJ8B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R
M("*57(+,E_&1KI"K@U^#0X-!@XV#3X+PE5R.IB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BE5R"
MS(USD:Z0JX-?@T.#08.-@T^"\)5<CJ8B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8P"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3:&]W
M97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(H]KCZPB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3(P"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X,PHC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(H+<@KB7UX+H@LR#
M=8.-@V*#3H+PCVN/K(+<@KV"S8C:DZZ"LX*Y@L2"K8*^@K."HH%"(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(H-6@T>#
MB8.,@TF#;(NDF&&-D2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B@U2#0X.3@T&#8H-V
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R("*39(YQCY"6O"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R"FUS9VED(")3:6=N871U<F4@
M06QG;W)I=&AM(@IM<V=S='(@(I-DCG&/D):\@T&#BX-3@XJ#68.`(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(H-6@Y.#2X-\
M@5N#BXNDF&&-D2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@T(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S0*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3`Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#(*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B@U2#0X-9(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I
M;G1E;F%N8V4B"FUS9W-T<B`BE=N.YX+P@UB#3(-B@W:"MX+I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B@UB#C8-O@TR#08ND
MF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@
M(H-8@XV#>(-J@T&+I)AAC9$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B
M4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED
M(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@Y"FUS9VED(")3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B@UR#C8."@Y./E).'(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("*#7(-]@XJ#
M09:OCN6+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G
M:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDP-0IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB
M"FUS9W-T<B`BE<""T8^'@LR129'P(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E
M(&%D9')E<W,B"FUS9W-T<B`BD9>038RS@T&#:(.,@U@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`BD^R#08-T@XJ#2HND
MF&&-D2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<R(*;7-G<W1R("*3[(-7@X>!6X-7@T&3AX%%D^R#5(.3@VB#
M0X-B@V"/E).'(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C
M:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G
M<W1R("*3[)2\BX4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C
M96QL<R(*;7-G<W1R("*7UX+,@UJ#BX+&@LR77922(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B
M@UJ#BX+&BZN*18+&@LR77922(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#$R"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3
M<&%C:6YG(@IM<V=S='(@(I==E)(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(I==E)*"QI:$D9`B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B4W!A:6XB"FUS9W-T<B`B@UB#>8-#@Y,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R
M86-T97(@26YP=70B"FUS9W-T<B`BD\&.ZI6VCIJ"S)/\E\TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS
M9VED(")3<&QI="!C96QL(@IM<V=S='(@(H-:@XN5JHJ$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I
M9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(I?QE:J*A"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@
M(E-P;&ET(')O=R(*;7-G<W1R("*-<Y6JBH0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("*#6(.*@XF#DX-*EJ^.
MY8[0B>^.Y8M@BZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8V(&QI8B]";&]C:R]M971A<BYP:'`Z.#$*;7-G:60@(E-T86YD87)D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I
M9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.#,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<X.`IM<V=I
M9"`B4W1A<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`BCT*"W(*]@LV,IR(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`BC_.1U"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.30*;7-G:60@(E-T;W)A
M9V4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<S"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R
M("*/6H^*E-22;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`BCN:/
MP8*UD/PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,P"FUS9VED
M(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<P"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G
M<W1R("*#6(->@T.#BR!;0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(I/Z(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*#
M5(-U@V:#0H.,@TZ#9X.*(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S,*;7-G:60@
M(E-U8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(Y(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM
M<V=I9"`B4W5B;6ET(@IM<V=S='(@(H[`C7,B"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@
M=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BB;J5=(*K(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$P-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(I"LC/<B"@HC.B!A9&UI;B]U<V5R+G!H<#HX
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E
M<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B""S8-6@UB#98.`
M@LF2QXG!@K."ZH+<@K6"O8%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@
M9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E
M<UPB((*J@U:#6(-E@X""J8+GC>V/G(*S@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N
M(@IM<V=S='(@(EPB)7-<(B""JHWMCYR"LX+J@MR"M8*]@4(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB((*J@U:#6(-E@X""J8+GC>V/G(*S@NJ"W(*U@KV!0B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M(@IM<V=S='(@(I#=DNB"S9"SC^V"R9;?@K."ZH+<@K6"O8%"@XJ#C8%;@VB"
MM8+$BFV41H+%@JN"W(*W@4(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BD-V2
MZ(+,@V^#8H-.@T&#8H-V@LV0LX_M@LF5VY&V@K."ZH+<@K6"O8%"(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(I#=DNB#=(-`@T.#BX+,@V^#8H-.@T&#8H-V
M("5S((+-D+./[8+)E=N1MH*S@NJ"W(*U@KV!0B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D
M871E9"!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB((+-D+./[8+)C5B05H*S@NJ"
MW(*U@KTB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B)7,@@LV0LX_M@LF/D8*KC9Z"W(+J
M@MR"M8*](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
M@UB!6X-?@Y.+I)AAC9$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@
M(HI4EW8B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U
M;B!2:7-E(@IM<V=S='(@(I/Z@LR/;R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("*3^H+,D_R"Z"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED
M(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM
M<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`BD_J"S(]O+Y/Z@LR3_(+H
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-`IM<V=I9"`B
M4W5N<FES93H@(@IM<V=S='(@(I/Z@LR/;X%&(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(P.`IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(I/Z
MEG8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R("*3^I9V@48B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP
M="(*;7-G<W1R("*/XY5T@JLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(H-4@WR!6X-G(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B@UB#BH-I@X"+
MI)AAC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("*0J2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B@UB#E(-`
M@5N#BX-O@XN!08.$@Y.#?8-#@T>#DX^4DX<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B@UB#CX-7@XF#DX-HB:2-D2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("*#6(-%@T:!6X-F
M@Y.)I(V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(H-8@T.#6)A!EDTB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS
M9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(H-6@XJ#08%%@T&#B8-UBZ2888V1(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED
M(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM
M<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6@W2#0(-#@XLB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS
M9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(I5<D:Z0JR(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@
M(E1A8FQE(%-E="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P
M97)T:65S(@IM<V=S='(@(I5<D:Z0JR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1A:7=A;B(*;7-G<W1R("*1Y)AP(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$B"FUS9W-T<B`BD>28<(%IDH:-D8+,B.J5E(%J(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("*#7H-7@TR#
M6(->@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@
M56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S='(@(H->@Y.#58-J@T&8099-BZ28
M88V1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T
M.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K
M<R(*;7-G<W1R("*#7H-8@TXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R
M("*39)ABE-2-AB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDW"FUS9VED
M(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B@V6#DX-V@XR!6X-G(%PB)7-<(B""JH*@@NB"W(*Y@O&!0B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("*#98.3@W:#C(%;@V>"S(K'EYTB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C`X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,C0*;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@
M(H-E@TR#6(-G@LR"W2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`BE;:.FI1ZDG4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(I6VCIJ"S(_C
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.0IM<V=I9"`B5&@B"FUS9W-T<B`BEM@B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B@UZ#0XFDC9$B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE
M($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1E10
M((IGDJ."JH*@@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R](:7-T;W)Y+TAI
M<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES
M86)L960N(@IM<V=S='(@(I>:E_"#5H-8@V6#@(+-EK.,^(+)@LB"P8+$@J*"
MW(*W@4(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@
M96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@
M(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>2(*;7-G<W1R(")-86EN=&5N86YC92"#3H.)@UB"S)/'C9Z"W8*JD+./
M[8+)C7."IH+<@KF"\8+%@K6"O2(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("*#28-V@U:#AX.3@T6#0H.3@VB#
M18+PE<*"MH+<@K6"O8%"CTF7N8*U@MR"MX%"(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R(&YE961S
M('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD
M(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS9W-T<B`B
M(@HB@T&#3H-:@UB,H(+PETR,^(+)@K>"Z8+)@LV*QY>=CM*"JH*[@LR#;X-B
M@TZ#1X.3@VB"\)#=DNB"MX+I@K&"QH*JE4N7=H+%@K>!0B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G
M:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED
M("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A
M<V4N(@IM<V=S='(@(B(*(IA!EXV0YDE$E-2-AH*JCG>2Z(*S@NJ"R(*I@L&"
MO8*I@4&+\X*^@L&"O8*I@4&"H(+I@J*"S8-F@5N#7H-X@5N#6)*&@LF,J95T
M@JDB"B*"Z(+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("*809>-D.:"S8*@@LB"O8+,@T&#:(.,@UB2H(+)DL>)P8*S@NJ"W(*U
M@KV!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*
M;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES
M(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S
M='(@(I-DCG&/D):\@K."ZH*]@X&#8H-:@5N#5X+PC)^/V(*W@NF"R8+-@4%0
M1U`@CY"6O(*JE4N7=H+%@K>!0B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S
M='(@(B(*(I&7D$V0YDE$E-2-AH*JCG>2Z(*S@NJ"R(*I@L&"O8*I@4&+\X*^
M@L&"O8*I@4&"H(+I@J*"S8-F@5N#7H-X@5N#6)*&@LF,J95T@JDB"B*"Z(+<
M@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`BD9>039#F2424U(V&@JJ.
M=Y+H@K."ZH+<@KF"\8+%@K6"O8%"(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E
M<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(HC#C8:)
MNX+)@LV(P)%3@LB#18-&@W60VI&Q@JJ52Y=V@L6"MX%"(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("*#=(-`@T.#BR`E
M<R""R8+-("5S((+,D-V2Z(*JE4N0>X+%@K>!0B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3$X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(H-T@T"#0X.+("5S
M((+)@LT@)7,@@LR0W9+H@JJ52Y![@L6"MX%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C(V"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("*#=(-`@T.#BX+-CJF5JHZI
MD&>"R8-2@W.!6X+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(H-T@T"#0X.+@JJ#9H%;@UZ"\(K<@O&"Q8*B@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W
M"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("*(R(FZ@LV"L8+,
M@X&#8H-:@5N#5X%I4D9#.#(R@6J"S(-W@V*#7X+%@K>!0B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*
M(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O
M9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S
M:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E
M<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*(E!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V
M92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I
M;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB"FUS9W-T
M<B`B(@HBDHV(TX%)((-T@XN#6(-.@XJ!6X.3@X*!6X-H@LT@26YT97)N970@
M17AP;&]R97(@@L6"S9;BD>B"JI2MD+:"MX+I@K&"QH*J@J""Z"(*(H+<@K>!
M:8-U@XF#18-5@LR#;X-/@L6"MX%J@4*)YI;*@LF#4X-^@JJ57(ZF@K."ZH*]
M@NB!05=I;F1O=W,@@JJ#3H.)@V*#5H.%@K4B"B*"O8+H@K>"Z8*I@N""M8+J
M@MR"N8+Q@4)<;B(*(H-T@XN#6(-.@XJ!6X.3@X*!6X-H@LF"MX+I@LB"YR!/
M2R""\(F?@K6"Q(FZ@K."HH%"(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DE$(%PB)7-<(B""S8WMCYR"LX+J
M@MR"M8*]@4(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*
M;7-G<W1R("(B"B)';G501R"#;X-#@VF#BH+,@W"#6(*J($-R>7!T7W!G<""#
M3H.)@UB"R9#=DNB"LX+J@L2"HH+IE4N7=H*J@J""Z(+<@K>!0B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U
M8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<T"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F
M(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(H*Q@LR#=(-"@5N#
MBX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS
M<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI
M;64Z.B!C;&%S<RXB"FUS9W-T<B`B2&]R9&5?0W)Y<'1?<VUI;66#3H.)@UB"
MR8+-;W!E;G-S;(."@U>#A8%;@XN"JI5+EW:"Q8*W@4(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E
M8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A
M8FQE('-I>F4B"FUS9W-T<B`B(@HB@W:#C(-T@T"#C(.3@UA<(B5S7"*"S8-F
M@5N#7H*J@U2#0X-9D*>,P(+PB7J"IH*]@KV"WY7;D;:"Q8*K@MR"N8+Q@L6"
MM8*]+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP
M.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN
M="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D
M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP
M.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z
M,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN
M<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB@K&"S(-F@5N#7HQ>*"5S*8+P
ME5R.IH*W@NF"O8+?@LR#=H.-@T^#B8.`@JJ"L8+,@U:#6(-E@X""R8+=@L*"
MJ8+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`BB/B7<)6$@LV"4)6VCIJ"Q8+(@J^"
MZH+.@LB"Z(+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I
M9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T
M(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("*+YI#8@NB5A(+-
M@E"5MHZ:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!0B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(H-4@5N#
M;R!<(B5S7"(@@LV-[8^<@K."ZH+<@K6"O8%"(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E
M<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(H-4@5N#;R!<
M(B5S7"(@@LV5VY&V@K."ZH+<@K6"O8%"(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F
M;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT-S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`BCG>2Z(*U@KV7\8%I)62!:H*J@J""Z(+<@KF"
M\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-SD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S
M(&YO="!E>&ES="XB"FUS9W-T<B`BB.J.GH-T@T"#0X.+(%PB)7-<(B""JH*@
M@NB"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.3D*
M;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE
M('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@
M9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T
M<B`B@T&#8H-V@XV!6X-H@V:!6X->@JJ2O)%/@LR#6(-E@V*#=H+%C\&.N(*U
M@MR"M8*]@4(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R
M(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B@T&#
M8H-V@XV!6X-H@V:!6X->@O"5VY&V@L6"JX+<@KF"\8+%@K6"O8%"(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Y(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C
M:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE;65S(&1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("*#98%;@WV#9H-"
M@XR#3H-G@XJ!6R!<(B5S7"(@@JJ"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E(&YO
M(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("*.=Y+H@L6"JX+I@TF#=H-6
M@X>#DX+-@J""Z(+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z,S0X"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B@T.#DX.)@T.#
MDY5<CJ:"Q8*K@NF5E)6J@LV"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,SDX"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B*5MHZ:D)2"JH*Q@LR#=(-"
M@5N#BX-H@LF1O8G?@JR"W(*W+B`E<R""S)6VCIJ"JI/\E\V"LX+J@L2"HH+<
M@K<N("5S((C(B;J"Q8+((@HB@JV"Q(+-@J*"KX+<@KF"\8%"(@H*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B7"(E<UPB((+P@U:#6(-E@X""UI+'B<&2
MAH+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(H.&@5N#52!<(B5S7"(@@LR#9H%;@UZ"\(-6@UB#98.`
M@JF"YX_!BXZ2AH+)EN*1Z(*JE*V0MH*U@MR"M8*].B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R(")<(B5S7"(@@O"#5H-8@V6#@(*I@N>-[8^<DH:"R9;BD>B"JI2MD+:"
MM8+<@K6"O3HB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(EPB)7-<(B""\(U8D%:2AH+)EN*1Z(*JE*V0MH*U@MR"
MM8*].B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S
M='(@(B(*(H-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U
M@KTZ("5S((+-@T&#8H-V@XV!6X-H@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B*#=(-`@T.#
MBX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""S8-T@T"#
M0X.+@LR#5(-#@UF0IXS`DFPH)62#;X-#(@HB@V<I@O")>H*F@L2"HH+<@K>!
M0B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+B(*;7-G<W1R("(B"B*#=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1
MZ(*JE*V0MH*U@MR"M8*].B`E<R""S8CJE92"S(+=@T&#8H-V@XV!6X-H@K."
MZH+<@K4B"B*"O8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B@K&"S(-P@5N#9X+P
ME5R.II*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B
MF$&7C9#F@V:!6X->@LR#0X.3@WR!6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"
MM8*]@4(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G
M:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A
M<B!D871A+B(*;7-G<W1R(")I0V%L96YD87(@@LR#0X.3@WR!6X-GDH:"R8-'
M@XF!6X*JE*V0MH*U@MR"M8*]+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E
M<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B*0W9+H@W2#2(%;@X"2AH+)@T>#
MB8%;@JJ"H(+H@MR"M8*]@4*"O8+4@O&!095+D'N-@);:@JJ+\Y22@KZ"P8*]
M@LR"Q8*U@N6"I(%"(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B*.
M=Y+H@K."ZH*]@T&#:(.,@UB2H(+,D8"-[)*&@LF#1X.)@5N"JI2MD+:"M8+<
M@K6"O8%"C.."Q8W$DWB.P(US@K6"Q(*M@KZ"LR(*(H*B@4(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(IA!
MEXV0YH+,C]J-UX+PC5B05I*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."
MQ8W$DWB.P(US@K6"Q(*M@KZ"LX*B@4(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE
M87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BD9>039#F@XJ#6(-G@LR-
M6)!6DH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4*,XX+%C<23>([`C7."M8+$
M@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S
M=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B@K&"S"!)34%0((-4
M@5N#;X+-BZ273(-T@TB#BX-?@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HT.`IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92XB"FUS9W-T<B`B@K&"ZH+-ETR,^(+((')A<B"#08%;@TJ#0X-U@L6"
MS8+(@J*"YH*D@L6"MX%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B@K&"ZH+-ETR,^(+(('II
M<""#=(-`@T.#BX+%@LV"R(*B@N:"I(+%@K>!0B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C0*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("*"L8+J@LV73(SX
M@LB#2H%;@VB4U(V&@L6"S8+(@J*"YH*D@L6"MX%"(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B
M"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O
M=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI
M(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@
M=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W
M87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@
M96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDW-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4T"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$Q,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<Y(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-3,*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDU"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@S-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#(*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`R-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#8@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(Q.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-#<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C8S-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(Y-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS.#`R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,3`*;7-G:60@(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(H*Q@LR#=(-"@5N#BX-H
M@LV52Y![@L6"MX%"(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V
M,@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+B(*;7-G<W1R("*"L8+,@W2#0H%;@XN#:(+-D*Z0E(+%@LB"K8+$@LV"HH*O
M@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$S"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@
M=&AE(&-O;&]N+B(*;7-G<W1R("*"L8+,@W2#0H%;@XN#:(+-D)2.FH+&@U*#
MC8.3@L6"R(*M@L2"S8*B@J^"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.3$*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(H*Q@LR#=(-"@5N#BX-H@LTX
MD&F0E(+%@LB"K8+$@LV"HH*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3(P"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G
M<W1R("(B"B*"L8+,@W2#0H%;@XN#:(+-@U*#DX-]@MR"O8+-B_.4DH+%B^:0
MV(+G@NJ"O9"ND)2"S(.*@UB#9X+%@LB"K8+$@LV"HH*O@MR"N2(*(H+Q@4(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#8*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B@K&"S(-T
M@T*!6X.+@VB"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B(@HB5&AI<R!F:65L
M9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O
M<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("*"L8+,
M@W2#0H%;@XN#:(+-,3:0:5)'0I5<BTR"S)!&@U*!6X-H@LB"K8+$@LV"HH*O
M@MR"N8+Q@4*7X3HG(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z-34X"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P
M<F]C97-S960N(@IM<V=S='(@(H*Q@LR#=(-(@5N#@(+-BOF"R8^(EYV"LX+J
M@L2"HH+<@K>!0B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4
M;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB
M8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F
M;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L
M96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(H*Q@LR#@8-B@UJ!
M6X-7@LV"H(+(@KV"JHYGEW""MX+I@LR"QHC9@LB"Z96VCIJ#6H-B@V>!:25S
M@6J"Q8^1@JF"ZH+$@J*"W(*W@4(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI<R!N=6UB97(@;75S="!B92!A="!L
M96%S="!O;F4N(@IM<V=S='(@(H*Q@LR4U(V&@LV-Q8^L@L6"X#&"Q8+(@JV"
MQ(+-@J*"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B@K&"S(-4@5N#
M;X+%@LUZ:7""QF=Z:7"#=(-`@T.#BX+PDU>*2H+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED
M(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S
M='(@(H*Q@LR#5H-8@V6#@(+-B.J.GI-)@LF6LXSX@LF"R(+!@L2"HH+<@K>!
M0B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(H*Q@LR2
M;(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(B"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M
M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@
M(H*Q@LR#18-"@Y.#:(-%@LV#28-V@U:#AX.3@T6#0H.3@VB#18*I@N>,Q(]O
M@K."ZH+IE4N7=H*J@J""Z(+<@K>!0B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C0R,B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I
M;64B"FUS9W-T<B`BCIZ*U"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS.#@*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B@UZ#0X.`@U:!
M6X-G(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE(&9O
M<FUA="(*;7-G<W1R("*.GHK4CY&.KB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U,C@*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(I.,
M@V6#0H."@5N#BY:OCN6+I)AAC9$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P
M"FUS9VED(")4:71L92(*;7-G<W1R("*#7H-#@V>#BR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE
M("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HBE:&0E(+,C8"6VH+PD4F1\(*W@NF"
MR8+-@4%00X+%@LU#;VYT<F]L@TR#0X%!36%C@LB"YT-O;6UA;F2#3(-#@O")
MGX*U@LB"JH+G@TXB"B*#BH-B@TZ"M8+<@K>!0B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*
M;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,@UR!6X-8
ME5R.II#8D=8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@
M(H-G@5N#4XNDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B
M"FUS9W-T<B`B@V>#4(.)@T6/E).'(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B@V>#DX-+B:2-D2(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N(@IM<V=S='(@(H*Q@LR0E)6JBM2"R8F]DWB"X(.-@T^#0X.3@JJ.CHUS
M@K."ZH+<@K6"O8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(H-G@XJ#:H-?@5N#:(%%@V>#;X-3BZ2888V1(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<X-PIM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("*)SB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B@V"#A8-J@U>#08NDF&&-D2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("*#9X.+@U*+
MI)AAC9$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(H-G@XN#3H.!@VJ#6(->@Y,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',B"FUS9W-T<B`B@UZ!6X-.@UB!18-*@T.#4H-8CY23AR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$*;7-G:60@(E1U=F%L=2(*;7-G<W1R("*#8X-O@XLB"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`BD4F1\(%&(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(H-%@TN#DX-?
MBZ2888V1(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R
M("*#18-.@XF#0X-I(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-#$Y"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(E9&4R"#9H-"@XR#3H-G@XJ"R8-!@TZ#6H-8@L6"JX+<@KF"\8%"
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M5D93((-T@T"#0X.+(%PB)7-<(B""S(-!@TZ#6H-8C*""S97/C5B"Q8*K@MR"
MN8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.3(@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@)7,O)7,@@LR#08-.@UJ#
M6(R@@LV5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HW.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H
M86YG92!T;R`E<RXB"FUS9W-T<B`B)7,@@LF5SXU8@L6"JX+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(H-T@T"#0X.+(%PB)7-<(B""S(-4@T.#68*J@V"#1H-B@TZ"
MJX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-CDU
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G
M<W1R("*#=(-`@T.#BR!<(B5S+R5S7"(@@LR#5(-#@UF"JH-@@T:#8H-.@L6"
MJX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S
M.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B4U%,((-4@5N#;X+)D-J1L8+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!W:71H(%-33"XB"FUS9W-T<B`B4U-,((+%D-J1L8+%@JN"W(*Y@O&!
M0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(P-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,C`Y"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<*
M;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@
M@W2#0(-#@XN"\(-2@W.!6X+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(E9&
M4R"#9H-"@XR#3H-G@XH@7"(E<UPB((+PC>R0K(+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V,2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+PC>R0K(+%@JN"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(E9&4R"#
M=(-`@T.#BX+PC>R0K(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(E9&4R"#9H-"
M@XR#3H-G@XH@7"(E<UPB((+PC>R0K(+%@JN"W(*Y@O&!0B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BB_."S"!61E,@@W2#0(-#
M@XN"\(WLD*R"Q8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(@IM<V=S='(@(H-F@5N#7H+PB+./:X+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(X(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M"FUS9W-T<B`B7"(E<UPB@O"-[8^<@L6"JX+<@KF"\2X@@V:#0H.,@TZ#9X.*
M@JJ+\X+%@LV"H(+H@MR"N8+Q@4(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")<(B5S
M7"*"\(WMCYR"Q8*K@MR"N8+Q.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.34*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y(@IM<V=S='(@(B5S@O"-[8^<@L6"JX+<@KF"\2X@@V:#0H.,@TZ#9X.*
M@JJ+\X+%@LV"H(+H@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+PC<2+09-)
M@LF-[8^<@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH+PC>V/G(+%@JN"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(P(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(E9&4R"#9H-"@XR#3H-G@XJ"\(WMCYR"Q8*K@MR"N8+Q@48E<R(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(")61E,@@W2#0(-#@XL@7"(E<UPB((+PC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(@IM<V=S='(@(E9&4R"#=(-`@T.#BX+PC>V/G(+%@JN"W(*Y@O&!0B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(E9&4R"#9H-"@XR#3H-G@XH@7"(E<UPB((+PC>V/G(+%@JN"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B5D93((+PC<2+09-)@LF-[8^<@L6"JX+<@KF"
M\8%&)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S-`IM<V=I
M9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BC+N-W8+,@V:#0H.,@TZ#9X.*@5N"JI/!DNB"Q8*K@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I
M9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G
M<W1R("*/V):^CY&"S(_:C=>"JH[F@NB/;X*Y@MR"N8+Q(@H*(SH@9G)A;65W
M;W)K+TYE=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B5S((+,
MDNB+8(*J@XV!6X-H@L6"JX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<T(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T
M;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"JHC:DZZ"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-C4R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@@W2#0(-#@XL@7"(E<UPB((*JBDJ"
MKX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@T
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(E9&4R"#=(-`
M@T.#BX+PCY&"JXV>@MV7<(+)BDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z.#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3,W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM
M<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(E9&4R"#
M=(-`@T.#BX*JBDJ"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M
M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("*(LX]KCY&,R8-T@T"#0X.+@O"*
M2H*O@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#4V"FUS
M9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL
M960I+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"JI/'@M^"W(*Y@O&!:69I;&5S
M:7IE*"D@@T>#B8%;@6J!0B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R"#=(-`@T.#BX*JD\>"WX+<@KF"
M\8%I9V5T1FEL95-I>F4H*2"#1X.)@5N!:H%"(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B5D93((-T@T"#0X.+
M@JJ3QX+?@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HV-S8*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B=F9S<F]O=""#9H-"@XR#3H-G@XJ"\)/'@M^"W(*Y
M@O&!0B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`BEKR1
M3R`E<R""\"`E<R""R97/C5B"Q8*K@MR"N8+Q@4:#=(-(@XN#7X%;@LV*^8+)
MD;:-W8*U@MR"MR(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH%;@LR6O)%/@O"5SXU8@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B5D93((-F@T*#C(-.@V>#BH%;@LR6O)%/@O"5
MSXU8@L6"JX+<@KF"\8%&)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B5D93((-T@T"#0X.+(%PB)7-<(B""S):\D4^"\)7/C5B"
MQ8*K@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*
M;7-G<W1R(")61E,@@W2#0(-#@XL@)7,O)7,@@LR6O)%/@O"5SXU8@L6"JX+<
M@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,C8@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z-#4R(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P
M.0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B
M5D93((-T@T"#0X.+@LR6O)%/@O"5SXU8@L6"JX+<@KF"\8%"(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P
M"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM
M<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B
M"FUS9W-T<B`B@K&"S"!7;W)D()6VCY&"\)9\EO."Q8*K@MR"N8+Q@4(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-"!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@@W2#0(-#
M@XL@7"(E<UPB((+)CY&"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(")61E,@@W2#0(-#@XN"R8^1
M@J^"W(*Y@O&!:6-O<'DH*8ZXE'.!:H%"(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C@X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U,0IM
M<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@
M(E9&4R"#=(-`@T.#BX+)CY&"KX+<@KF"\8%"(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R(")61E,@@W2#0(-#
M@XN"R8^1@J^"W(*Y@O&!0G%U;W1A((+PDK2)WX*U@KV"YH*D@L6"MX%"(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(HFZD/PB"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
ME<^-6(+PCN:"Z(_!@K<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO
M;B(*;7-G<W1R("*-Q8SC@LR1@(WL@O",LX+)EM^"MR(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,0HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(I#:D;&.GH+,@U2!6X-O@5N"J8+G@LR77(KZ@K6"R(*BB9Z3FH%&(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S8*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B
M@U2!6X-O@5N"J8+G@LR77(KZ@K6"R(*BB9Z3FH%&(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N
M9FEL960B"FUS9W-T<B`BEJ*0KI>=(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B
M@T&#B8-UCO&2MXV1F$&632(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D
M($MI;F=D;VTB"FUS9W-T<B`BB7"-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`BE<2-D2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*
M;7-G<W1R("*5Q)?,D;Z5O9=MCY23AR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV,B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5
M;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@
M(E5N:VYO=VXB"FUS9W-T<B`BE7.6OB(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A
M<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM
M<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDQ"FUS9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G
M<W1R("*#AH%;@U66O(*I@W"#6(./@5N#:(*JE7.6OH+%@K>!0B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`BEK.6O"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL
M96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O
M9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@
M3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI
M8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB@UJ#3(.%@XJ#98-"@5N/
MXX+,EYV74H*I@N>3P8R@@LR6LX*B@UB#3H.*@W:#9X+-($-U="]#;W!Y+U!A
M<W1E((+%@JN"W(*Y@O&!0B(*(D]+((+P@TZ#BH-B@TZ"MX+I@L:!08+'@J2"
MXH+!@L2#3H.*@V*#=H-[@5N#:(+)@T&#3H-:@UB"MX+I@JF"QH*B@J0@;6]Z
M:6QL82XB"B)O<F<@@LR+6H]PE;:/D8+PC*F"Z8*Q@L:"JH+%@JN"W(*W@4(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N
M(@IM<V=S='(@(H-4@WR!6X-G@K6"Q(*B@LB"HHIGDJ..<8+%@K<B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(HU8
MD%8B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("(E<R""\(U8
MD%:"MX+I@4(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("*#AH%;@U6"\(U8D%:"
MMX+I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(EPB)7-<
M(B""\(U8D%:"M8+<@K6"O8%"(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@
M(HU8D%:#6(-.@XJ#=H-G@O"-[8^<@K6"W(*U@KV!0B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(H-!@V*#=H.-
M@5N#:"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+B(*;7-G<W1R("*14X+$@LR#08-V@XJ#4(%;@U:#AX.3@LR0W9+H@W2#
M0(-#@XN"\(-4@5N#;X+)@T&#8H-V@XV!6X-H@K6"W(*U@KV!0B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B@XF#98.3
ME;:.FH%ID>65MHZ:@6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N
M=6UB97)S(@IM<V=S='(@(H.-@5N#?9"4CIJ!:9'EE;:.FH%J(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("*#18.+@T^#08-#DXR5
M^XNDF&&-D2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT
M.B`E<R(*;7-G<W1R("*,NXW=@LR2;(+PCF>7<(%&)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B
M57-E(%-33"(*;7-G<W1R(")34TP@@O".9Y=P(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@
M9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B24U34""#5(%;
M@V^"S(.&@5N#59:\@5Z#<(-8@X^!6X-H@JJ(V8+(@NF/ZHV'@LF.9Y=P@K6"
MW(*W@4(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q
M"FUS9VED(")5<V5R(@IM<V=S='(@(H.&@5N#52(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R
M("*#AH%;@U4@)7,@@LT@)7,@@L641H_8@K."ZH+$@J*"W(*Y@O&!0B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("*#AH%;@U6*QY>=(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("*#
MAH%;@U6#28-V@U:#AX.3(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VXB"FUS9W-T<B`B@X:!6X-5DV^87B(*"B,Z('-I9VYU
M<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(H.&@5N#58+,DV^87H+-
M@K&"S(-4@T.#9X+%@LV+UHY^@K."ZH+$@J*"W(*W@4(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O
M=6YD(@IM<V=S='(@(H.&@5N#58%;@T&#2H-%@Y.#9X*J@J""Z(+<@KF"\8%"
M@4(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R("*#AH%;@U66O"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("*#AH%;@U66O"!<(B5S7"(@@LV*
M^8+)@J""Z(+<@K>!0B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(H.&@5N#59:\.B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B@X:!6X-5EKPZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(H-6@UB#98.`DH:"S(.&@5N#58%&(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM
M<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("*#18-9@WB#3(-8@UZ#DXNDF&&-
MD2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,"!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-C(*;7-G:60@(E9&4R!D:7)E8W1O<GD@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(HMXB<DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C,*;7-G:60@(E9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED
M:71Y(@IM<V=S='(@(I=,C/B0JR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#4S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU
M;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$X,PIM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B
M@V^#:X-!@V.+I)AAC9$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B@WB#;(-9@T>#B8%%@WN#
MBH-O@XN+I)AAC9$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(HR?
MC]B.N)1S("T@@K&"S(.!@V*#6H%;@U>"S8G\XH*"LX+J@L2"HH+I@N:"I(+%
M@K>!0B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q
M"FUS9VED(")697)S:6]N(@IM<V=S='(@(I3%(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S
M='(@(H-O@5N#5X.'@Y.*QY>=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI
M9VXB"FUS9W-T<B`BCV.(RI)U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(E9E
M<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T
M($YA;2(*;7-G<W1R("*#>(-G@VF#@([0B>^.Y8M@BZ2888V1(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE<V4@*%9)4T-)
M22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B)7,@@O",J8+I(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I
M9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("**3Y64@LP@
M=V5B((-Y@5N#5X+PE5R.IB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H(@IM<V=S='(@(HEPE\R#;X%;@U>#DX^4DX<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R
M("*5Q)?,@V^!6X-7@Y./E).'(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU4
M4"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y5
M04Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T
M=6YA(@IM<V=S='(@(H-%@TB#BH-8@46#=(-G@T2!6X-ICY23AR(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R
M;FEN9R(*;7-G<W1R("*,>(V0(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`BD(4B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@X.0IM
M<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,Y"FUS9VED(")796(@4VET92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BEHB/5"(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM<V=S='(@
M(H+F@J2"L8*[(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B)7,@@LF"YH*D@K&"NR(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E
M<R(*;7-G<W1R("(E<R""LX+Q@4&"YH*D@K&"NR(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("*0O(-4@VZ#B2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\B"FUS9W-T<B`B)7.#C8-/@T.#DXSC@L>"S(-!@W:#BH-0@5N#5H.'@Y."
M\)5<CJ:"M8+<@K>"J8%((@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M(@IM<V=S='(@(HOFD-B"Z)6VCIJ"S8F]@L6"MX*I@4@B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O
M=&4@8VAA<F%C=&5R/R(*;7-G<W1R("*(^)=PE;:.FH+-B;V"Q8*W@JF!2"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8U
M"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+B(*;7-G<W1R("*#98-,@UB#9X-'@V:#0H->@5N"S(-V@XF#3X-#@Y."
M\)%)D?""M8+<@K>!0B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(I6=
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P-`IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(HVV@LF2=8*M)7.#@8-J@X6!6X+,E9V!:8Z?B?&"
MS(.-@T^#0X.3@JF"YY=,C/B!:CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A
M8FQE(@IM<V=S='(@(I5<@LR5G2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S
M='(@(I6=@LR24(C*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("*5G8%&(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED
M(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@
M:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-C,*;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED
M(")7:7-H;&ES="(*;7-G<W1R("*7?H*U@J*"X(+,B.J7ER(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G
M:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("*+SI:QD.:"S(]:CXHB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED
M(")7;W)K(%!H;VYE(@IM<V=S='(@(HO.EK&0YH+,DV288I34C88B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU
M;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(E9""-<Y;:@L6*U(CA@L&"O8V`EMJ0E(%"D+."M8*M
M@LT@)62!08YWDNB"LX+J@KV"S(+-("5D@4(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HS,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R("**U(CA@L&"O8V`EMJ0E(%"D+."M8*M@LT@)62!08YWDNB"LX+J@KV"
MS(+-("5D@4(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E
M861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B5D93@W2#0(-#@XN"S)/'@MV/
M;X*UDH:"R95SD+."R(-)@W2#6H-B@V<@)60@@JJ.=Y+H@K."ZH+<@K6"O8%"
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM<V=I9"`B6"U2
M968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*;7-G
M<W1R(")8-3`Y=C,@BNZ6>Y"GC,`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5
M<V%G92(*;7-G<W1R(")8-3`Y=C,@C*Z.9Y=PED`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE
M8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(")8-3`Y=C,@CN61S([2@LR5
MRI:\(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*
M;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@
M(E@U,#EV,R".Y9',CM*"S(RNCJ^5RHYQ(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS
M(@IM<V=S='(@(E@U,#EV,R"*9Y*CBT"47"(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C4P"FUS9VED(")962(*;7-G<W1R("*43B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-@IM<V=I9"`B65E962(*;7-G
M<W1R("*43B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R("*6B)1.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M665M96XB"FUS9W-T<B`B@T.#1X.!@Y.+I)AAC9$B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B"FUS
M9W-T<B`B@LV"HB(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`BDZ^(
MTX*U@MR"MR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H
M92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*;7-G
M<W1R("*-H8+-@V6#3(-8@V>#@H%;@VB"Q8*W@4);/#Y=@WN#7H.3@L5765-)
M5UE'@X*!6X-H@LF6WX+H@MR"MX%"(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&)L;V-K<RXB"FUS9W-T<B`B)60@B,B/XX+,@W6#C8-B@TZ"\(WLD*R"MX+I
M@K&"QH+-BY:)PH*S@NJ"Q(*B@MR"N8+Q@4(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$T,C0*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I
M8V%T960N(@IM<V=S='(@(H*@@LB"O8+-E$:/V(*S@NJ"Q(*B@MR"N8+Q@4(B
M"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P.`IM<V=I
M9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92XB"FUS9W-T<B`BEKR13X+,DH:"R2`G7%PG((+&@J*"I)6V
MCIJ"S8YG@J:"W(*Y@O&!0B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,@IM<V=I9"`B66]U
M(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R
M("*73(SX@LB39(YQ@X&!6X.+@T&#:(.,@UB"Q8+-@J""Z(+<@KF"\8%"(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB
M:6X@)7,N(@IM<V=S='(@(B(*(H-#@Y.#?(%;@V>"LX+J@KV#=(-`@T.#BX+,
M@W2#0H%;@XN#:(+P)7.3X(+,D<Z)GH*W@NF#=(-"@5N#BX-H@LF#?8-B@W:"
MM8+$@MPB"B*"N8+Q+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX
M-PIM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("*#
MC8-/@T&#18-G@K6"W(*U@KTN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(U.`IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C
M96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L
M("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N
M(@IM<V=S='(@(B(*(I"S@K6"HI-DF&*4U(V&@O"3_)?-@K>"Z8+F@J2"R9*-
MB-."M8+$B;J"LX*B@4*0E(Z:@KZ"KX*JCF>7<(+%@JN"W(*W@JJ!08V1C=LB
M"B*39)AB@LB"YY#FDZJ"R8%[@O"5=(*O@MR"MX%"(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$X-0IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!V86QU92XB"FUS9W-T<B`BD+."M8*BDFR"\)/\E\V"M8+$B;J"
MLX*B@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@
M=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*(H-4@T.#DX-!@V*#=H+PEYB7
M<(*W@NF"O8+?@LF"S2!$871A5')E92"#;X-B@TZ#1X.3@VB"\)#=DNB"MX+I
ME4N7=H*J@J""Z(+<(@HB@K>!0B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z-#<Q"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"XB"FUS9W-T<B`B5D93((-O@V*#3H-'@Y.#:(+PD-V2Z(*W@NF52Y=V
M@JJ"H(+H@MR"MX%"(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("*/X8I1@LR3X)=E@O"+3(]Q@K6"Q(*I@N>!08_ABE&#C(-\@5N#9X+PD9>0
M38*U@L2"K8*^@K."HH%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(H*Q@K&"R8.*
M@Y.#3H*W@NE54DR"\)/\E\V"M8+$B;J"LX*B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BC>V/G(*W@NF#5(%;@V^"
M\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="XB"FUS9W-T<B`BC\&+CH*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."
MHH%"(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("*-[8^<@K>"
MZ8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS
M9W-T<B`BDL>)P8*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(HU8D%:"MX+I@X:!
M6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("*.P(US@K>"
MZ8-!@TZ#5H.'@Y."\(YWDNB"M8+$@JV"OH*S@J*!0B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(I!6
M@K6"HI6JE]Z6O(+PD_R7S8*U@L2)NH*S@J*!0B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B)7,@@UJ#8H-6@X>#DX+,
METR,^(KZC,""JI#8@NJ"Q(*B@MR"MX%"@XV#3X-#@Y."M9*\@K6"Q(*M@KZ"
MLX*B@4(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM
M<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(I-DCG&#@8%;@XN#
M08-H@XR#6"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B@J""R(*]@LP@1G)O;3H@
M@T&#:(.,@U@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B@J""R(*]@LR#0X.3@W2#2(.!@5N#5H.'@Y,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"B*#6H-B@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@T&#:(.,
M@UB"JI7/C5B"LX+J@MR"M8*]@4*#6H-,@X6#BH-E@T*!6Y7;C.R"S(*](@HB
M@M^"R8.-@T^#0X.3@K62O(*W@M>"JX+%@K>!0B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B@J""R(*]@LR6O)%/(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@
M>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N(@IM<V=S='(@(B(*(H*Q@LR41H_8@V^#8H-.@T>#DX-H@L6"S8%!
M@X:!6X-5@LR2QXG!@JJ#5(-\@5N#9X*S@NJ"Q(*B@MR"N8+Q@4*"X(*U($AO
M<F1E((+%(@HB@X:!6X-5@T&#2H-%@Y.#9X+PBL>7G8*U@KV"HH+,@LB"YX%!
MD;R"S)1&C]B#;X-B@TZ#1X.3@VB"\(YG@J2"UX*K@L6"MX%"(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(H*Q@LR41H_8
M@V^#8H-.@T>#DX-H@L6"S8%!@X:!6X-5@LR#BH-8@V>"JH-4@WR!6X-G@K."
MZH+$@J*"R(*B@JF!08*@@NF"HH+-B;TB"B*"YX*I@LR7G9=2@L6"L8+,BT"4
M7(*JEK.,^(+)@LB"P8+$@J*"W(*W@4(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B*#6H-B
M@U:#AX.3("5S((+,BM2"R8*@@LB"O8+,@W6#B8-%@U6"JI7/C5B"LX+J@KV"
MYH*D@LB"S(+%@4&#6H-,@X6#BH-E@T*!6Y7;(@HBC.R"S(*]@M^"R8.-@T^#
M0X.3@K62O(*W@M>"JX+%@K>!0B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(H*HCF>"HH+,@W6#B8-%@U6"S8*Q@LR+0)1<
M@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L
M+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B*"J(YG@J*"
MS(-U@XF#18-5@LV"L8+,B/.-_(-)@W:#5H.'@Y."\(-4@WR!6X-G@K6"Q(*B
M@MR"N8+Q@4)#;VYT<F]L+T-O;6UA;F0@(@HB*R!0((+%B/.-_(*U@L2)NH*S
M@J*!0B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(H->@T.#@(-=@5N#DX%&
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A
M=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(H*@@LB"
MO8+,@V:#=(-(@XN#9TE$@LV5SXU8@K."ZH+<@K6"O8%"(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT
M:71Y.B(*;7-G<W1R("*"H(+(@KV"S(-F@W2#2(.+@V=)1#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB
M"FUS9W-T<B`B@J""R(*]@LR.@9:\(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G
M<W1R("*#C8-/@T.#DX+-BOJ,P)#8@NJ"Q8*W@4(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(I!6@K6"HB`E
M<R"7<(+,@W"#6(./@5N#:(%&)7,B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G
M<W1R("*"H(+(@KV"S(-)@W:#5H.'@Y."S8R[C=V"S(-:@V*#5H.'@Y.2AH+)
ME<^-6(*S@NJ"W(*U@KV!0B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N(@IM<V=S='(@(H-)@W:#5H.'@Y."\(U8D%:"M8+<@K6"O2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T(@IM<V=S='(@(H-P@UB#CX%;@VB"S8.*@UJ#
M8H-G@K."ZH+<@K6"O8%"(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L
M(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*
M(G!A<W-W;W)D+B(*;7-G<W1R("(B"B*#<(-8@X^!6X-H@LV#BH-:@V*#9X*S
M@NJ"W(*U@KV"S(+%@4&05H*U@J*#<(-8@X^!6X-H@L6#C8-/@T.#DX*U@L2"
MW8+$B;J"LR(*(H*B@4(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(H-P@UB#CX%;@VB"JHKZC,"0V(+J@L6"MX%"(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S
M.B(*;7-G<W1R("*#BH."@5N#9X-4@5N#;SHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(H.&@5N#4X-8@XF#<H-!
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6F%I<F4B"FUS9W-T<B`B@U6#0X%;@XN+I)AAC9&!:8-2@Y.#4Y:OCN6+I)AA
MC9&!:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("*#
M58.3@W*#08NDF&&-D2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E
M(@IM<V=S='(@(H-7@Y.#;X-U@T>+I)AAC9$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*
M;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*
M;7-G<W1R("*!;8_ABE&5\8V0@6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@
M(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*
M;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R(");C7,Z)7,O)7-=(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34T('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")?08K'EYTB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G
M<W1R(")?1(US@O"-[8^<(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?
M1W)O=7!S(@IM<V=S='(@(E]'@T^#BX%;@W8B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?
M2(-W@XN#=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B7TF)YI&<@W:#C8-P@V6#0BXN+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T
M<B`B7TR#C8-/@T.#DR(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(E],@XV#3X-!@T6#
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-
M@XJ#DX-.E<^-6"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H
M<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/@TF#=H-6@X>#DR(*
M"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(E]0@T&#3H-:@UB,H"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK
M+BXN(@IM<V=S='(@(E]2@XJ#DX-.C>V/G"(*"B,Z(&QI8B]A<&DN<&AP.C$R
M-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]3@UJ#8H-G@T&#8H-V(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?5)5<
MD:Z0JR(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S
M='(@(E]5@X:!6X-5(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("*#08-H@XR#6)*@(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(I5SEKZ"R(-!@VB#C(-8(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(I=<DNB57"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`BCV^7S8-T@T"#0X.+@JJ-[)"L@L6"JX+<@KF"\2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C
M86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("*3_)?-@W2#0(-#@XN"JHI*@J^"
MW(*Y@O$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU
M.3@*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B@K&"L8+P@TZ#BH-B@TXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I
M9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(H-2@WV#DX-H
MC7..9Y=P@LR#1X.)@5LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R
M("*0W9+H@T>#B8%;(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B
M"FUS9W-T<B`BCV27=H+(@U:#6(-E@X"#=(-`@T.#BX+,C(>7CB(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A
M(&9O<FUA="!E<G)O<B(*;7-G<W1R("*#9H%;@UZ,8(ZN@T>#B8%;(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*;7-G
M<W1R("*5TH]7(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R("*-@);:@JJ"
MH(+H@MR"N8+Q(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S
M='(@(H-T@T"#0X.+(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*;7-G:60@(F@Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("*#>H-8@V>6O(*JE7.6OB(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("*3_(]OE\V#1X.)
M@5LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM
M<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B@UR#=(-G
M@T6#1H-!D^"5E(+,@T>#B8%;(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S`*;7-G:60@(FUM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R("*6
MO)%/(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(H[`D96"LX+J@L2"HH+<@KF"\2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B
M;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R("*"W(*^CL"1E8*S@NJ"Q(*B
M@MR"N8+Q(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#D*;7-G
M:60@(FYO=&5P860B"FUS9W-T<B`B@X&#@I*@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R
M8V5N="(*;7-G<W1R("*#<(%;@UJ#DX-G(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D
M(@IM<V=S='(@(H-!@TZ#6H-8@LV+D93;@K."ZH+<@K6"O2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G
M:60@(G!I>&5L<R(*;7-G<W1R("*#<X-.@UJ#BR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VPB"FUS9W-T<B`B@XJ#@H%;@V>"Q8+,@W:#C8-G@U*#BX-'
M@XF!6R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I
M;&%B;&4B"FUS9W-T<B`B@U2!6X-R@UB5<Y1<(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T
M<B`BC;>5JH+PE5R.IB(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@(G-T96%D>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(H-6@UB#98.`@T>#
MB8%;(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S,*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R("*#7H-8@TZ#BH-8@V<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y
M(&9A:6QU<F4B"FUS9W-T<B`BB.J.GI-)@LB#1X.)@5LB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P
M"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM
M<V=S='(@(HIME$:"S(*]@M^#<(-8@X^!6X-H,I-XD_R7S8*U@L2)NH*S@J(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S
M='(@(I:SEKPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I
M9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O
M+W1R86YS;&%T:6]N+G!H<```````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#$U-C(W,"`Q,#4Q-30S-#$T,B`P,C$R,S4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(R$O=7-R+VQO
M8V%L+W!S82]A9&UI;B]B:6XO<&AP("UQ"CP_<&AP"B\J*@H@*B!4<F%N<VQA
M=&EO;B!H96QP97(@87!P;&EC871I;VX@9F]R('1H92!(;W)D92!F<F%M97=O
M<FLN"B`J"B`J($9O<B!U<V%G92!I;F9O<FUA=&EO;B!C86QL.@H@*B`N+W1R
M86YS;&%T:6]N+G!H<"!H96QP"B`J"B`J("1(;W)D93H@:&]R9&4O<&\O=')A
M;G-L871I;VXN<&AP+'8@,2XY,2XR+C$V(#(P,#8O,#4O,C,@,#(Z,3,Z-#,@
M<V5L<VMY($5X<"`D"B`J+PH*9G5N8W1I;VX@9F]O=&5R*"D*>PH@("`@9VQO
M8F%L("1C+"`D8W5R9&ER.PH*("`@("1C+3YW<FET96QN*"D["B`@("`D8RT^
M=W)I=&5L;B@G4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S
M+FAO<F1E+F]R9RXG*3L*"B`@("!C:&1I<B@D8W5R9&ER*3L*("`@(&5X:70[
M"GT*"F9U;F-T:6]N('5S86=E*"D*>PH@("`@9VQO8F%L("1O<'1I;VYS+"`D
M8SL*"B`@("!I9B`H8V]U;G0H)&]P=&EO;G-;,5TI("8F"B`@("`@("`@*"1O
M<'1I;VYS6S%=6S!=(#T]("=H96QP)R`F)B`A96UP='DH)&]P=&EO;G-;,5U;
M,5TI('Q\"B`@("`@("`@(65M<'1Y*"1O<'1I;VYS6S%=6S!=*2`F)B!I;E]A
M<G)A>2@D;W!T:6]N<ULQ75LP72P@87)R87DH)V-O;6UI="<L("=C;VUP96YD
M:75M)RP@)V5X=')A8W0G+"`G:6YI="<L("=M86ME)RP@)VUE<F=E)RDI*2D@
M>PH@("`@("`@(&EF("@D;W!T:6]N<ULQ75LP72`]/2`G:&5L<"<I('L*("`@
M("`@("`@("`@)&-M9"`]("1O<'1I;VYS6S%=6S%=.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C;60@/2`D;W!T:6]N<ULQ75LP73L*("`@("`@
M("!]"B`@("`@("`@)&,M/G=R:71E;&XH)U5S86=E.B<@+B`G('1R86YS;&%T
M:6]N+G!H<"!;;W!T:6]N<UT@)R`N("1C;60@+B`G(%MC;VUM86YD+6]P=&EO
M;G-=)RD["B`@("`@("`@:68@*"%E;7!T>2@D8VUD*2D@>PH@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@G0V]M
M;6%N9"!O<'1I;VYS.B<I.PH@("`@("`@('T*("`@("`@("!S=VET8V@@*"1C
M;60I('L*("`@("`@("`@("`@8V%S92`G8VQE86YU<"<Z"B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S
M92!O;FQY('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P(%!/(&9I
M;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G8V]M;6ET)SH*("`@
M("`@("`@("`@8V%S92`G8V]M;6ET+6AE;'`G.@H@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI
M<R!L;V-A;&4N)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL
M>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("U-+"`M+6UE<W-A9V4]34534T%'12`@57-E('1H
M:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O9B!T:&4@9&5F875L="!O;F5S
M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@+6XL("TM;F5W
M("`@("`@("`@("`@("!4:&ES(&ES(&$@;F5W('1R86YS;&%T:6]N+"!C;VUM
M:70@86QS;R!#4D5$2513+"<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)R`@("`@("`@("`@("`@("`@("`@("`@("!#2$%.1T53(&%N9"!N;',N
M<&AP+F1I<W0N)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@8V%S92`G8V]M<&5N9&EU;2<Z"B`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@G("`M82P@+2UA9&0]1DE,12`@("`@("`@061D('1H:7,@4$\@9FEL
M92!T;R!T:&4@8V]M<&5N9&EU;2X@57-E9G5L('1O)RD["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@G("`@("`@("`@("`@("`@("`@("`@("`@:6YC
M;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E<F5N="!B<F%N8V@@=&\G
M*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@9V5N97)A=&5D(&-O;7!E;F1I=6TN)RD["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M9"P@+2UD:7)E8W1O<GD]1$E2
M("`@0W)E871E(&-O;7!E;F1I=6T@:6X@=&AI<R!D:7)E8W1O<GDN)RD["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?
M0T,@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)V5X=')A8W0G.@H@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@1V5N97)A
M=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XG*3L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=I;FET
M)SH*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#<F5A
M=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD[
M"B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M8RP@+2UC;VUP96YD
M:75M/49)3$4@(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F
M('1H92!D969A=6QT)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M("`@("`@("`@("`@("`@("`@("`@("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I
M;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y*2XG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"<@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N7"=T
M('5S92!A(&-O;7!E;F1I=6TN)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`G;6%K92<Z"B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@G("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S92!O;FQY('1H
M:7,@;&]C86QE+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M+6TL("TM;6]D=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O
M<B!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)R`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!-97)G92!N97<@
M=')A;G-L871I;VYS('1O('1H:7,@8V]M<&5N9&EU;2!F:6QE)RD["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`@("`@("`@("`@("`@("`@("`@
M("`@(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE("AC;VUP96YD:75M+G!O
M(&EN('1H92<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@
M("`@("`@("`@("`@("`@("`@("!H;W)D92]P;R!D:7)E8W1O<GDN)RD["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;BP@+2UN;RUC;VUP96YD
M:75M("`@($1O;EPG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C
M;VUP96YD:75M+B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@
M+7,L("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I
M<W1I8W,@:6X@82!L;V-A;"!F:6QE+B<I.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)VUA:V4M:&5L<"<Z"B`@("`@("`@("`@
M(&-A<V4@)W5P9&%T92UH96QP)SH*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"<@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L
M;V-A;&4N)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G;65R9V4G.@H@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH)R`@+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI
M<R!L;V-A;&4N)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R
M('1H:7,@*$AO<F1E*2!M;V1U;&4N)RD["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@G("`M8RP@+2UC;VUP96YD:75M/49)3$4@(%5S92!T:&ES(&-O
M;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F('1H92!D969A=6QT)RD["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@G("`@("`@("`@("`@("`@("`@("`@
M("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T
M;W)Y*2XG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UN+"`M
M+6YO+6-O;7!E;F1I=6T@("`@1&]N7"=T('5S92!A(&-O;7!E;F1I=6TN)RD[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G=7!D
M871E)SH*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"<@("UL+"`M+6QO
M8V%L93UL;%]#0R`@("`@57-E('1H:7,@;&]C86QE+B<I.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)R`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5
M<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+B<I.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)R`@+6,L("TM8V]M<&5N9&EU;3U&24Q%("!5
M<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS=&5A9"!O9B!T:&4@9&5F875L
M="<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@
M("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@:6X@=&AE(&AO<F1E
M+W!O(&1I<F5C=&]R>2DN)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@G("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;EPG="!U<V4@82!C;VUP
M96YD:75M+B<I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?2!E;'-E('L*("`@("`@("`D8RT^=W)I=&5L;B@G57-A9V4Z)R`N("<@
M=')A;G-L871I;VXN<&AP(%MO<'1I;VYS72!C;VUM86YD(%MC;VUM86YD+6]P
M=&EO;G-=)RD["B`@("`@("`@)&,M/G=R:71E;&XH<W1R7W)E<&5A="@G("<L
M(%-T<FEN9SHZ;&5N9W1H*"=5<V%G93HG*2D@+B`G('1R86YS;&%T:6]N+G!H
M<"!;:&5L<'PM:'PM+6AE;'!=(%MC;VUM86YD72<I.PH@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@)&,M/G=R:71E;&XH)TAE;'!E<B!A<'!L:6-A
M=&EO;B!T;R!C<F5A=&4@86YD(&UA:6YT86EN('1R86YS;&%T:6]N<R!F;W(@
M=&AE($AO<F1E)RD["B`@("`@("`@)&,M/G=R:71E;&XH)V9R86UE=V]R:R!A
M;F0@:71S(&%P<&QI8V%T:6]N<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G
M1F]R(&%N(&EN=')O9'5C=&EO;B!R96%D('1H92!F:6QE(%)%041-12!I;B!T
M:&ES(&1I<F5C=&]R>2XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@
M("`@("1C+3YW<FET96QN*"=#;VUM86YD<SHG*3L*("`@("`@("`D8RT^=W)I
M=&5L;B@G("!H96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B<I
M.PH@("`@("`@("1C+3YW<FET96QN*"<@(&-O;7!E;F1I=6T@(%)E8G5I;&0@
M=&AE(&-O;7!E;F1I=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S
M('1H92<I.PH@("`@("`@("1C+3YW<FET96QN*"<@("`@("`@("`@("`@(&-U
M<G)E;G0@8V]M<&5N9&EU;2XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!E
M>'1R86-T("`@("!'96YE<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N
M)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@:6YI="`@("`@("`@0W)E871E
M(&]N92!O<B!M;W)E(%!/(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI
M;F<Z(%1H:7,G*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("`@("`@("`@("`@
M("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F:6QE<R!O9B!T:&ES(&QO
M8V%L92XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!M97)G92`@("`@("!-
M97)G92!T:&4@8W5R<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@
M=&5M<&QA=&4@9FEL92XG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!U<&1A
M=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N="XG*3L*("`@
M("`@("`D8RT^=W)I=&5L;B@G("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L;"!N
M97<@86YD(&-H86YG960@96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-3"!H
M96QP)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@("`@("`@9FEL
M92!A;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+B<I.PH@
M("`@("`@("1C+3YW<FET96QN*"<@(&-L96%N=7`@("`@($-L96%N<R!T:&4@
M4$\@9FEL97,@=7`@9G)O;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N
M=')I97,N)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@;6%K92`@("`@("`@
M0G5I;&0@8FEN87)Y($U/(&9I;&5S(&9R;VT@=&AE('-P96-I9FEE9"!03R!F
M:6QE<RXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G("!M86ME+6AE;'`@("!-
M87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG('5P
M+71O+61A=&4@86YD)RD["B`@("`@("`@)&,M/G=R:71E;&XH)R`@("`@("`@
M("`@("`@<')E<&%R92!T:&4@9FEL92!F;W(@=&AE(&YE>'0@97AE8W5T:6]N
M(&]F('5P9&%T92UH96QP+B!9;W4G*3L*("`@("`@("`D8RT^=W)I=&5L;B@G
M("`@("`@("`@("`@("!S:&]U;&0@;VYL>2!R=6X@;6%K92UH96QP($%&5$52
M('5P9&%T92UH96QP(&%N9"!R979I<VEN9R!T:&4G*3L*("`@("`@("`D8RT^
M=W)I=&5L;B@G("`@("`@("`@("`@("!H96QP(&9I;&4N)RD["B`@("`@("`@
M)&,M/G=R:71E;&XH)R`@8V]M;6ET("`@("`@0V]M;6ET('1R86YS;&%T:6]N
M<R!T;R!T:&4@0U93('-E<G9E<BXG*3L*("`@("`@("`D8RT^=W)I=&5L;B@G
M("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E
M<G9E<BXG*3L*("`@('T*("`@("1C+3YW<FET96QN*"D["B`@("`D8RT^=W)I
M=&5L;B@G3W!T:6]N<SHG*3L*("`@("1C+3YW<FET96QN*"<@("UB+"`M+6)A
M<V4]+U!!5$@@($9U;&P@<&%T:"!T;R!T:&4@*$AO<F1E*2!B87-E(&1I<F5C
M=&]R>2!T:&%T('-H;W5L9"!B92<I.PH@("`@)&,M/G=R:71E;&XH)R`@("`@
M("`@("`@("`@("`@("`@=7-E9"XG*3L*("`@("1C+3YW<FET96QN*"<@("UD
M+"`M+61E8G5G("`@("`@(%-H;W<@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@
M97AE8W5T960@8FEN87)I97,N)RD["B`@("`D8RT^=W)I=&5L;B@G("`M:"P@
M+2UH96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+B<I.PH@("`@
M)&,M/G=R:71E;&XH)R`@+70L("TM=&5S="`@("`@("`@4VAO=R!T:&4@97AE
M8W5T960@8V]M;6%N9',@8G5T(&1O;EPG="!R=6X@86YY=&AI;F<N)RD["GT*
M"F9U;F-T:6]N(&-H96-K7V)I;F%R:65S*"D*>PH@("`@9VQO8F%L("1G971T
M97AT7W9E<G-I;VXL("1C.PH*("`@("1C+3YW<FET96QN*"=396%R8VAI;F<@
M9V5T=&5X="!B:6YA<FEE<RXN+B<I.PH@("`@<F5Q=6ER95]O;F-E("=3>7-T
M96TN<&AP)SL*("`@(&9O<F5A8V@@*&%R<F%Y*"=G971T97AT)RP@)VUS9V%T
M=')I8B<L("=M<V=C870G+"`G;7-G8V]M;2<L("=M<V=F;70G+"`G;7-G:6YI
M="<L("=M<V=M97)G92<L("=X9V5T=&5X="<I(&%S("1B:6YA<GDI('L*("`@
M("`@("!E8VAO("1B:6YA<GD@+B`G+BXN("<["B`@("`@("`@)$=,3T)!3%-;
M)&)I;F%R>5T@/2!3>7-T96TZ.G=H:6-H*"1B:6YA<GDI.PH@("`@("`@(&EF
M("@D1TQ/0D%,4ULD8FEN87)Y72D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@D8RT^9W)E96XH)V9O=6YD.B`G*2`N("1'3$]"04Q36R1B:6YA<GE=*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^
M<F5D*"=N;W0@9F]U;F0G*2D["B`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@
M("`@('T*("`@('T*("`@("1C+3YW<FET96QN*"D["@H@("`@)&]U="`]("<G
M.PH@("`@97AE8R@D1TQ/0D%,4ULG9V5T=&5X="==("X@)R`M+79E<G-I;VXG
M+"`D;W5T+"`D<F5T*3L*("`@("1S<&QI="`](&5X<&QO9&4H)R`G+"`D;W5T
M6S!=*3L*("`@(&5C:&\@)V=E='1E>'0@=F5R<VEO;CH@)R`N("1S<&QI=%MC
M;W5N="@D<W!L:70I("T@,5T["B`@("`D9V5T=&5X=%]V97)S:6]N(#T@97AP
M;&]D92@G+B<L("1S<&QI=%MC;W5N="@D<W!L:70I("T@,5TI.PH@("`@:68@
M*"1G971T97AT7W9E<G-I;VY;,%T@/3T@,"`F)B`D9V5T=&5X=%]V97)S:6]N
M6S%=(#P@,3(I('L*("`@("`@("`D1TQ/0D%,4ULG<&AP7W-U<'!O<G0G72`]
M(&9A;'-E.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@)&,M/G=R
M:71E;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B`G66]U<B!G971T97AT('9E
M<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T
M:79E;'DN)RD["B`@("`@("`@)&,M/G=R:71E;&XH)TYO="!A;&P@<W1R:6YG
M<R!W:6QL(&)E(&5X=')A8W1E9"XG*3L*("`@('T@96QS92!["B`@("`@("`@
M)$=,3T)!3%-;)W!H<%]S=7!P;W)T)UT@/2!T<G5E.PH@("`@("`@("1C+3YW
M<FET96QN*"1C+3YG<F5E;B@G("<@+B`G3TLG*2D["B`@("!]"B`@("`D8RT^
M=W)I=&5L;B@I.PI]"@IF=6YC=&EO;B!S96%R8VA?9FEL92@D9FEL92P@)&1I
M<B`]("<N)RP@)&QO8V%L(#T@9F%L<V4I"GL*("`@('-T871I8R`D9F8["B`@
M("!I9B`H(6ES<V5T*"1F9BDI('L*("`@("`@("`D9F8@/2`F;F5W($9I;&5?
M1FEN9"@I.PH@("`@?0H*("`@(&EF("AS=6)S='(H)&9I;&4L(#`L(#$I("$]
M($13*2!["B`@("`@("`@)&9I;&4@/2`B+R1F:6QE+R(["B`@("!]"@H@("`@
M:68@*"1L;V-A;"D@>PH@("`@("`@("1F:6QE<R`]("1F9BT^9VQO8B@D9FEL
M92P@)&1I<BP@)W!E<FPG*3L*("`@("`@("`D9FEL97,@/2!A<G)A>5]M87`H
M8W)E871E7V9U;F-T:6]N*"<D9FEL92<L("=R971U<FX@(B<@+B`D9&ER("X@
M1%,@+B`G(B`N("1F:6QE.R<I+"`D9FEL97,I.PH@("`@("`@(')E='5R;B`D
M9FEL97,["B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B`D9F8M/G-E87)C
M:"@D9FEL92P@)&1I<BP@)W!E<FPG*3L*("`@('T*?0H*9G5N8W1I;VX@<V5A
M<F-H7V5X="@D97AT+"`D9&ER(#T@)RXG+"`D;&]C86P@/2!F86QS92D*>PH@
M("`@<F5T=7)N('-E87)C:%]F:6QE*"(N*UQ<+B1E>'1<)"(L("1D:7(L("1L
M;V-A;"D["GT*"F9U;F-T:6]N(&=E=%]P;U]F:6QE<R@D9&ER*0I["B`@("`D
M;&%N9W,@/2!S96%R8VA?97AT*"=P;R<L("1D:7(I.PH@("`@:68@*"@D:V5Y
M(#T@87)R87E?<V5A<F-H*"1D:7(@+B!$4R`N("=M97-S86=E<RYP;R<L("1L
M86YG<RDI("$]/2!F86QS92D@>PH@("`@("`@('5N<V5T*"1L86YG<ULD:V5Y
M72D["B`@("!]"B`@("!I9B`H*"1K97D@/2!A<G)A>5]S96%R8V@H)&1I<B`N
M($13("X@)V-O;7!E;F1I=6TN<&\G+"`D;&%N9W,I*2`A/3T@9F%L<V4I('L*
M("`@("`@("!U;G-E="@D;&%N9W-;)&ME>5TI.PH@("`@?0H@("`@<F5T=7)N
M("1L86YG<SL*?0H*9G5N8W1I;VX@9V5T7VQA;F=U86=E<R@D9&ER*0I["B`@
M("!G;&]B86P@)&-U<F1I<CL*"B`@("!C:&1I<B@D9&ER*3L*("`@("1L86YG
M<R`](&=E=%]P;U]F:6QE<R@G<&\G*3L*("`@("1L86YG<R`](&%R<F%Y7VUA
M<"AC<F5A=&5?9G5N8W1I;VXH)R1L86YG)RP@)W)E='5R;B!S=')?<F5P;&%C
M92@B<&\B("X@1%,L("(B+"!S=')?<F5P;&%C92@B+G!O(BP@(B(L("1L86YG
M*2D[)RDL("1L86YG<RD["B`@("!C:&1I<B@D8W5R9&ER*3L*("`@(')E='5R
M;B`D;&%N9W,["GT*"F9U;F-T:6]N('-E87)C:%]A<'!L:6-A=&EO;G,H*0I[
M"B`@("`D9&ER<R`](&%R<F%Y*"D["B`@("`D:&]R9&4@/2!F86QS93L*("`@
M(&EF("A`:7-?9&ER*$)!4T4@+B!$4R`N("=P;R<I*2!["B`@("`@("`@)&1I
M<G-;72`]($)!4T4["B`@("`@("`@)&AO<F1E(#T@=')U93L*("`@('T*("`@
M("1D:"`]($!O<&5N9&ER*$)!4T4I.PH@("`@:68@*"1D:"D@>PH@("`@("`@
M('=H:6QE("@D96YT<GD@/2!`<F5A9&1I<B@D9&@I*2!["B`@("`@("`@("`@
M("1D:7(@/2!"05-%("X@1%,@+B`D96YT<GD["B`@("`@("`@("`@(&EF("AI
M<U]D:7(H)&1I<BD@)B8*("`@("`@("`@("`@("`@('-U8G-T<B@D96YT<GDL
M(#`L(#$I("$]("<N)R`F)@H@("`@("`@("`@("`@("`@9FEL96EN;V1E*$A/
M4D1%7T)!4T4I("$](&9I;&5I;F]D92@D9&ER*2D@>PH@("`@("`@("`@("`@
M("`@)'-U8B`](&]P96YD:7(H)&1I<BD["B`@("`@("`@("`@("`@("!I9B`H
M)'-U8BD@>PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@D<W5B96YT<GD@
M/2!R96%D9&ER*"1S=6(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D<W5B96YT<GD@/3T@)W!O)R`F)B!I<U]D:7(H)&1I<B`N($13("X@)'-U
M8F5N=')Y*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1I<G-;
M72`]("1D:7(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5N
M=')Y(#T]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:&]R9&4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"$D:&]R9&4I('L*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D
M9&ER<RP@2$]21$5?0D%312D["B`@("`@("`@?0H@("`@?0H*("`@(')E='5R
M;B`D9&ER<SL*?0H*9G5N8W1I;VX@<W1R:7!?:&]R9&4H)&9I;&4I"GL*("`@
M(&EF("AI<U]A<G)A>2@D9FEL92DI('L*("`@("`@("!R971U<FX@87)R87E?
M;6%P*&-R96%T95]F=6YC=&EO;B@G)&9I;&4G+"`G<F5T=7)N('-T<FEP7VAO
M<F1E*"1F:6QE*3LG*2P@)&9I;&4I.PH@("`@?2!E;'-E('L*("`@("`@("!R
M971U<FX@<W1R7W)E<&QA8V4H0D%312`N($13+"`G)RP@)&9I;&4I.PH@("`@
M?0I]"@IF=6YC=&EO;B!X=')A8W0H*0I["B`@("!G;&]B86P@)&-M9%]O<'1I
M;VYS+"`D87!P<RP@)&1I<G,L("1D96)U9RP@)'1E<W0L("1C+"`D9V5T=&5X
M=%]V97)S:6]N+"`D<VEL96YC92P@)&-U<F1I<CL*"B`@("!F;W)E86-H("@D
M8VUD7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H
M)&]P=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@
M("`@("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@
M("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM;6]D=6QE
M)SH*("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@:68@*"1'3$]"04Q36R=P
M:'!?<W5P<&]R="==*2!["B`@("`@("`@)&QA;F=U86=E(#T@)U!(4"<["B`@
M("!](&5L<V4@>PH@("`@("`@("1L86YG=6%G92`]("=#*RLG.PH@("`@?0H@
M("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@
M("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S
M6R1I72D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"B`@("`@
M("`@<')I;G1F*"=%>'1R86-T:6YG(&9R;VT@)7,N+BX@)RP@)&%P<'-;)&E=
M*3L*("`@("`@("!C:&1I<B@D9&ER<ULD:5TI.PH@("`@("`@(&EF("@D87!P
M<ULD:5T@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`D9FEL97,@/2!S96%R
M8VA?97AT*"=P:'`G+"`G+B<L('1R=64I.PH@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>2@G861M:6XG+"`G9G)A;65W;W)K)RP@)VQI8B<L("=S97)V:6-E
M<R<L("=T96UP;&%T97,G+"`G=71I;"<L("=C;VYF:6<G("X@1%,@+B`G=&AE
M;65S)RD@87,@)'-E87)C:%]D:7(I('L*("`@("`@("`@("`@("`@("1F:6QE
M<R`](&%R<F%Y7VUE<F=E*"1F:6QE<RP@<V5A<F-H7V5X="@G*'!H<'QI;F-\
M:G,I)RP@)'-E87)C:%]D:7(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL97,L('-E87)C:%]E>'0H)V1I
M<W0G+"`G8V]N9FEG)RDI.PH@("`@("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG
M>&=E='1E>'0G72`N("<@+2UL86YG=6%G93TG("X@)&QA;F=U86=E("X*("`@
M("`@("`@("`@("`@("`@)R`M+69R;VTM8V]D93UI<V\M.#@U.2TQ("TM:V5Y
M=V]R9#U?("TM<V]R="UO=71P=70@+2UC;W!Y<FEG:'0M:&]L9&5R/2)(;W)D
M92!0<F]J96-T(B<["B`@("`@("`@("`@(&EF("@D9V5T=&5X=%]V97)S:6]N
M6S!=(#X@,"!\?"`D9V5T=&5X=%]V97)S:6]N6S%=(#X@,3$I('L*("`@("`@
M("`@("`@("`@("1S:"`N/2`G("TM;7-G:60M8G5G<RUA9&1R97-S/2)D979`
M;&ES=',N:&]R9&4N;W)G(B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&9I;&4@/2`D9&ER<ULD:5T@+B!$4R`N("=P;R<@+B!$4R`N("1A<'!S6R1I
M72`N("<N<&]T)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE
M*2`F)B`A:7-?=W)I=&%B;&4H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D
M8RT^=W)I=&5L;B@D8RT^<F5D*'-P<FEN=&8H)R5S(&ES(&YO="!W<FET86)L
M92XG+"`D9FEL92DI*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T;7!?9FEL92`]("1F:6QE("X@)RYT
M;7`N<&]T)SL*("`@("`@("`@("`@)'-H("X]("<@+6\@)R`N("1T;7!?9FEL
M92`N("<@)R`N(&EM<&QO9&4H)R`G+"`D9FEL97,I.PH@("`@("`@("`@("!I
M9B`H0&9I;&5?97AI<W1S*"1D:7)S6R1I72`N("<O<&\O=')A;G-L871I;VXN
M<&AP)RDI('L*("`@("`@("`@("`@("`@("1S:"`N/2`G('!O+W1R86YS;&%T
M:6]N+G!H<"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D9&5B
M=6<I('L*("`@("`@("`@("`@("`@("1S:"`N/2`D<VEL96YC93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H(21T97-T*2!E>&5C*"1S:"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&9I;&5S(#T@<V5A<F-H7V5X="@G*'!H<'QI
M;F-\:G,I)RD["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y7V9I;'1E<B@D
M9FEL97,L(&-R96%T95]F=6YC=&EO;B@G)&9I;&4G+"`G<F5T=7)N('-U8G-T
M<B@D9FEL92P@,"P@.2D@(3T@(BXB("X@1%,@+B`B8V]N9FEG(B`N($13.R<I
M*3L*("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"!S
M96%R8VA?97AT*"=D:7-T)RP@)V-O;F9I9R<I*3L*("`@("`@("`@("`@)'-H
M(#T@)$=,3T)!3%-;)WAG971T97AT)UT@+B`G("TM;&%N9W5A9V4])R`N("1L
M86YG=6%G92`N"B`@("`@("`@("`@("`@("`@("<@+2UK97EW;W)D/5\@+2US
M;W)T+6]U='!U="`M+69O<F-E+7!O("TM8V]P>7)I9VAT+6AO;&1E<CTB2&]R
M9&4@4')O:F5C="(G.PH@("`@("`@("`@("!I9B`H)&=E='1E>'1?=F5R<VEO
M;ELP72`^(#`@?'P@)&=E='1E>'1?=F5R<VEO;ELQ72`^(#$Q*2!["B`@("`@
M("`@("`@("`@("`D<V@@+CT@)R`M+6US9VED+6)U9W,M861D<F5S<STB9&5V
M0&QI<W1S+FAO<F1E+F]R9R(G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1F:6QE(#T@)W!O)R`N($13("X@)&%P<'-;)&E=("X@)RYP;W0G.PH@("`@
M("`@("`@("!I9B`H9FEL95]E>&ES=',H)&9I;&4I("8F("%I<U]W<FET86)L
M92@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR
M960H<W!R:6YT9B@G)7,@:7,@;F]T('=R:71A8FQE+B<L("1F:6QE*2DI.PH@
M("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1M<%]F:6QE(#T@)&9I;&4@+B`G+G1M<"YP;W0G.PH@("`@("`@
M("`@("`D<V@@+CT@)R`M;R`G("X@)'1M<%]F:6QE("X@)R`G("X@:6UP;&]D
M92@G("<L("1F:6QE<RD@+B`H)&1E8G5G(#\@)R<@.B`D<VEL96YC92D["B`@
M("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A)'1E<W0I(&5X96,H)'-H*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"1T;7!?9FEL92DI('L*("`@("`@("`@("`@)&9I;&5S
M(#T@<V5A<F-H7V5X="@G:'1M;"<L("=T96UP;&%T97,G*3L*("`@("`@("`@
M("`@:68@*"$D=&5S="D@)'1M<"`](&9O<&5N*"1F:6QE("X@)RYT96UP;&%T
M97,G+"`G=R<I.PH@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)'1E
M;7!L871E*2!["B`@("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D=&5M<&QA
M=&4L("=R)RD["B`@("`@("`@("`@("`@("`D;&EN96YO(#T@,#L*("`@("`@
M("`@("`@("`@('=H:6QE("@H)&QI;F4@/2!F9V5T<R@D9G`L(#0P.38I*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D;&EN96YO*RL["B`@
M("`@("`@("`@("`@("`@("`@)&]F9G-E="`](#`["B`@("`@("`@("`@("`@
M("`@("`@=VAI;&4@*"@D;&5F="`]('-T<G!O<R@D;&EN92P@)SQG971T97AT
M/B<L("1O9F9S970I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&QE9G0@*ST@.3L*("`@("`@("`@("`@("`@("`@("`@("`@)&)U
M9F9E<B`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D;&EN97-P86X@
M/2`P.PH@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92`H*"1E;F0@/2!S
M=')P;W,H)&QI;F4L("<\+V=E='1E>'0^)RP@)&QE9G0I*2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B=69F97(@+CT@<W5B
M<W1R*"1L:6YE+"`D;&5F="D["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;&5F="`](#`["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;&EN
M92`](&9G971S*"1F<"P@-#`Y-BD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&EN97-P86XK*SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D;&EN92`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*'-P<FEN=&8H(CQG971T
M97AT/B!T86<@;F]T(&-L;W-E9"!I;B!F:6QE("5S+EQN3W!E;FEN9R!T86<@
M9F]U;F0@:6X@;&EN92`E9"XB+"`D=&5M<&QA=&4L("1L:6YE;F\I*2D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L@,CL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D8G5F9F5R("X]('-U8G-T
M<B@D;&EN92P@)&QE9G0L("1E;F0@+2`D;&5F="D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A)'1E<W0I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9W<FET92@D=&UP+"`B(SH@)'1E;7!L871E.B1L:6YE;F]<;B(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9G=R:71E*"1T;7`L("=M
M<V=I9"`B)R`N('-T<E]R97!L86-E*&%R<F%Y*"<B)RP@(EQN(BDL(&%R<F%Y
M*"=<(B<L(")<7&Y<(EQN7"(B*2P@)&)U9F9E<BD@+B`B7")<;B(I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@9G=R:71E*"1T;7`L("=M<V=S='(@
M(B(G("X@(EQN7&XB*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D;V9F<V5T(#T@)&5N9"`K(#$P.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&9C;&]S92@D=&UP*3L*("`@("`@("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS
M9V-O;6TG72`N("(@+2UM;W)E+71H86X],"`M+7-O<G0M;W5T<'5T(%PB)'1M
M<%]F:6QE7"(@7"(D9FEL92YT96UP;&%T97-<(B`M+6]U='!U="UF:6QE(%PB
M)'1M<%]F:6QE7"(B("X@)'-I;&5N8V4["B`@("`@("`@("`@(&EF("@D9&5B
M=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=%
M>&5C=71I;F<Z)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D<V@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)'1E<W0I('L*("`@
M("`@("`@("`@("`@(&5X96,H)'-H*3L*("`@("`@("`@("`@("`@('5N;&EN
M:R@D9FEL92`N("<N=&5M<&QA=&5S)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2D@>PH@("`@("`@("`@("`@
M("`@)&1I9F8@/2!A<G)A>5]D:69F*&9I;&4H)'1M<%]F:6QE*2P@9FEL92@D
M9FEL92DI.PH@("`@("`@("`@("`@("`@)&1I9F8@/2!P<F5G7V=R97`H)R]>
M(E!/5"U#<F5A=&EO;BU$871E.B\G+"`D9&EF9BP@4%)%1U]'4D507TE.5D52
M5"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"%F:6QE
M7V5X:7-T<R@D9FEL92D@?'P@8V]U;G0H)&1I9F8I*2!["B`@("`@("`@("`@
M($!U;FQI;FLH)&9I;&4I.PH@("`@("`@("`@("!R96YA;64H)'1M<%]F:6QE
M+"`D9FEL92D["B`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YG<F5E;B@G
M=7!D871E9"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`=6YL
M:6YK*"1T;7!?9FEL92D["B`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YB
M;VQD*"=N;W0@8VAA;F=E9"<I*3L*("`@("`@("!]"B`@("`@("`@8VAD:7(H
M)&-U<F1I<BD["B`@("!]"GT*"F9U;F-T:6]N(&UE<F=E*"D*>PH@("`@9VQO
M8F%L("1C;61?;W!T:6]N<RP@)&%P<',L("1D:7)S+"`D9&5B=6<L("1T97-T
M+"`D8SL*"B`@("`D8V]M<&5N9&EU;2`]("<@+2UC;VUP96YD:75M/2(G("X@
M0D%312`N($13("X@)W!O)R`N($13("X@)V-O;7!E;F1I=6TN<&\B)SL*("`@
M(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@
M("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G
M.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O
M;W1E<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S
M92`G+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N
M6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M)VTG.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@
M("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!C87-E("=C)SH*("`@("`@("`@("`@8V%S92`G
M+2UC;VUP96YD:75M)SH*("`@("`@("`@("`@("`@("1C;VUP96YD:75M(#T@
M)R`M+6-O;7!E;F1I=6T])R`N("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;B<Z"B`@("`@("`@("`@(&-A
M<V4@)RTM;F\M8V]M<&5N9&EU;2<Z"B`@("`@("`@("`@("`@("`D8V]M<&5N
M9&EU;2`]("<G.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@?0H@("`@:68@*"%I<W-E="@D;&%N9RD@)B8@(65M<'1Y*"1C;VUP96YD
M:75M*2D@>PH@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)T5R<F]R.B`G
M("X@)TYO(&QO8V%L92!S<&5C:69I960N)RDI.PH@("`@("`@("1C+3YW<FET
M96QN*"D["B`@("`@("`@=7-A9V4H*3L*("`@("`@("!F;V]T97(H*3L*("`@
M('T*"B`@("!C;&5A;G5P*"D["@H@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE
M*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I72D@>PH@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("!]"B`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G
M365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O
M;&0H)&%P<'-;)&E=*2DI.PH@("`@("`@("1D:7(@/2`D9&ER<ULD:5T@+B!$
M4R`N("=P;R<@+B!$4SL*("`@("`@("!I9B`H96UP='DH)&QA;F<I*2!["B`@
M("`@("`@("`@("1L86YG<R`](&=E=%]L86YG=6%G97,H)&1I<G-;)&E=*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T
M<R@D9&ER("X@)&QA;F<@+B`G+G!O)RDI('L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@("`@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&QA;F=S(#T@87)R87DH)&QA;F<I.PH@("`@
M("`@('T*("`@("`@("!F;W)E86-H("@D;&%N9W,@87,@)&QO8V%L92D@>PH@
M("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"=-97)G:6YG(&QO8V%L
M92`E<RXN+B`G+"`D8RT^8F]L9"@D;&]C86QE*2DI.PH@("`@("`@("`@("`D
M<V@@/2`D1TQ/0D%,4ULG;7-G;65R9V4G72`N("<@+2UU<&1A=&4@+78G("X@
M)&-O;7!E;F1I=6T@+B`G("(G("X@)&1I<B`N("1L;V-A;&4@+B`G+G!O(B`B
M)R`N("1D:7(@+B`D87!P<ULD:5T@+B`G+G!O="(G.PH@("`@("`@("`@("!I
M9B`H)&1E8G5G('Q\("1T97-T*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)'-H*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T97-T
M*2!E>&5C*"1S:"D["B`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YG<F5E
M;B@G9&]N92<I*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N('-T871U
M<R@I"GL*("`@(')E='5R;CL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1A
M<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@)&,["@H@("`@)&]U='!U="`]
M(")S=&%T=7,N:'1M;"(["B`@("!F;W)E86-H("@D8VUD7V]P=&EO;G-;,%T@
M87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P=&EO;ELP72D@>PH@
M("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@("`@('5S86=E*"D[
M"B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@("`@("`@8V%S92`G
M;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*("`@("`@("`@("`@
M("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@8V%S92`G+2UM
M;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]("1O<'1I;VY;,5T[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;R<Z
M"B`@("`@("`@("`@(&-A<V4@)RTM;W5T<'5T)SH*("`@("`@("`@("`@("`@
M("1O=71P=70@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("!]"B`@("!]"B`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M9&ER<RD[("1I*RLI('L*("`@("`@("!I9B`H(65M<'1Y*"1M;V1U;&4I("8F
M("1M;V1U;&4@(3T@)&%P<'-;)&E=*2!["B`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@('T*("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"='96YE
M<F%T:6YG('-T871U<R!F;W(@;6]D=6QE("5S+BXN)RP@)&,M/F)O;&0H)&%P
M<'-;)&E=*2DI.PH@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@
M("`@("`@)&QA;F=S(#T@9V5T7VQA;F=U86=E<R@D9&ER<ULD:5TI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1D
M:7)S6R1I72`N($13("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O)RDI('L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QA;F=S(#T@
M87)R87DH)&QA;F<I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D;&%N
M9W,@87,@)&QO8V%L92D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I
M;G1F*"=3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B`G+"`D8RT^8F]L9"@D;&]C
M86QE*2DI.PH@("`@("`@('T*("`@('T*?0H*9G5N8W1I;VX@8V]M<&5N9&EU
M;2@I"GL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1D:7)S+"`D9&5B=6<L
M("1T97-T+"`D8RP@)'-I;&5N8V4["@H@("`@)&1I<B`]($)!4T4@+B!$4R`N
M("=P;R<@+B!$4SL*("`@("1A9&0@/2`G)SL*("`@(&9O<F5A8V@@*"1C;61?
M;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@("`@<W=I=&-H("@D;W!T
M:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@
M("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@
M("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S92`G+2UL;V-A;&4G.@H@
M("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)V0G.@H@("`@("`@("`@
M("!C87-E("<M+61I<F5C=&]R>2<Z"B`@("`@("`@("`@("`@("`D9&ER(#T@
M)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!C87-E("=A)SH*("`@("`@("`@("`@8V%S92`G+2UA9&0G.@H@("`@("`@
M("`@("`@("`@)&%D9"`]("<@)R`N("1O<'1I;VY;,5T["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"B`@("!I9B`H(6ES<V5T*"1L
M86YG*2D@>PH@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)T5R<F]R.B`G
M("X@)TYO(&QO8V%L92!S<&5C:69I960N)RDI.PH@("`@("`@("1C+3YW<FET
M96QN*"D["B`@("`@("`@=7-A9V4H*3L*("`@("`@("!F;V]T97(H*3L*("`@
M('T*("`@('!R:6YT9B@G365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE
M(&-O;7!E;F1I=6TN+BX@)RP@)&QA;F<I.PH@("`@)'!O9FEL97,@/2!A<G)A
M>2@I.PH@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK
M*2!["B`@("`@("`@)'!O9FEL92`]("1D:7)S6R1I72`N($13("X@)W!O)R`N
M($13("X@)&QA;F<@+B`G+G!O)SL*("`@("`@("!I9B`H9FEL95]E>&ES=',H
M)'!O9FEL92DI('L*("`@("`@("`@("`@)'!O9FEL97-;72`]("1P;V9I;&4[
M"B`@("`@("`@?0H@("`@?0H@("`@:68@*"%E;7!T>2@D9&ER*2`F)B!S=6)S
M='(H)&1I<BP@+3$I("$]($13*2!["B`@("`@("`@)&1I<B`N/2!$4SL*("`@
M('T*("`@("1S:"`]("1'3$]"04Q36R=M<V=C870G72`N("<@+2US;W)T+6]U
M='!U="`G("X@:6UP;&]D92@G("<L("1P;V9I;&5S*2`N("1A9&0@+B`G(#X@
M)R`N("1D:7(@+B`G8V]M<&5N9&EU;2YP;R`G("X@*"1D96)U9R`_("<G(#H@
M)'-I;&5N8V4I.PH@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@
M("1C+3YW<FET96QN*"D["B`@("`@("`@)&,M/G=R:71E;&XH)T5X96-U=&EN
M9SHG*3L*("`@("`@("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@?0H@("`@:68@
M*"1T97-T*2!["B`@("`@("`@)')E="`](#`["B`@("!](&5L<V4@>PH@("`@
M("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*("`@('T*("`@(&EF("@D<F5T
M(#T](#`I('L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G
M*2D["B`@("!](&5L<V4@>PH@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H
M)V9A:6QE9"<I*3L*("`@('T*?0H*9G5N8W1I;VX@:6YI="@I"GL*("`@(&=L
M;V)A;"`D8VUD7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S
M="P@)&,L("1S:6QE;F-E.PH*("`@(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP
M72!A<R`D;W!T:6]N*2!["B`@("`@("`@<W=I=&-H("@D;W!T:6]N6S!=*2![
M"B`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@("`@=7-A9V4H
M*3L*("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@("`@("!C87-E
M("=L)SH*("`@("`@("`@("`@8V%S92`G+2UL;V-A;&4G.@H@("`@("`@("`@
M("`@("`@)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("!C87-E("<M
M+6UO9'5L92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ
M73L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@
M(&EF("AE;7!T>2@D;&%N9RDI('L@)&QA;F<@/2!G971E;G8H)TQ!3D<G*3L@
M?0H@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2![
M"B`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A
M<'!S6R1I72D@>R!C;VYT:6YU93L@?0H@("`@("`@("1P86-K86=E(#T@=6-F
M:7)S="@D87!P<ULD:5TI.PH@("`@("`@("1P86-K86=E7W4@/2!3=')I;F<Z
M.G5P<&5R*"1A<'!S6R1I72D["B`@("`@("`@0&EN8VQU9&4@)&1I<G-;)&E=
M("X@)R]L:6(O=F5R<VEO;BYP:'`G.PH@("`@("`@("1V97)S:6]N(#T@9&5F
M:6YE9"@D<&%C:V%G95]U("X@)U]615)324].)RD@/R!C;VYS=&%N="@D<&%C
M:V%G95]U("X@)U]615)324].)RD@.B`G/S\_)SL*("`@("`@("!P<FEN=&8H
M)TEN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@)RP@)&%P<'-;)&E=*3L*("`@
M("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@+B`G+W!O+R<@+B`D
M87!P<ULD:5T@+B`G+G!O="<I*2!["B`@("`@("`@("`@("1C+3YW<FET96QN
M*"1C+3YR960H)V9A:6QE9"<I*3L*("`@("`@("`@("`@)&,M/G=R:71E;&XH
M<W!R:6YT9B@G)7,@;F]T(&9O=6YD+B!2=6X@7"=T<F%N<VQA=&EO;B!E>'1R
M86-T7"<@9FER<W0N)RP@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D
M87!P<ULD:5T@+B`G+G!O="<I*3L*("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@?0H@("`@("`@("1D:7(@/2`D9&ER<ULD:5T@+B!$4R`N("=P;R<@
M+B!$4SL*("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG;7-G:6YI="==("X@)R`M
M+6YO+71R86YS;&%T;W(@+6D@)R`N("1D:7(@+B`D87!P<ULD:5T@+B`G+G!O
M="`G("X*("`@("`@("`@("`@("`H(65M<'1Y*"1L86YG*2`_("<@+6\@)R`N
M("1D:7(@+B`D;&%N9R`N("<N<&\@+2UL;V-A;&4])R`N("1L86YG(#H@)R<I
M("X*("`@("`@("`@("`@("`H)&1E8G5G(#\@)R<@.B`D<VEL96YC92D["B`@
M("`@("`@:68@*"%E;7!T>2@D;&%N9RD@)B8@(4]37U=)3D1/5U,I('L*("`@
M("`@("`@("`@)'!O9FEL92`]("1D:7)S6R1I72`N("<O<&\O)R`N("1L86YG
M("X@)RYP;R<["B`@("`@("`@("`@("1S:"`N/2`B.R!S960@)W,O4$%#2T%'
M12!P86-K86=E+R1P86-K86=E('!A8VMA9V4O)R`D<&]F:6QE("(@+@H@("`@
M("`@("`@("`@("`@("`@(GP@<V5D("=S+U!!0TM!1T4@5D524TE/3B\D<&%C
M:V%G92`D=F5R<VEO;B\G("(@+@H@("`@("`@("`@("`@("`@("`@(GP@<V5D
M("=S+VUE<W-A9V5S(&9O<B!004-+04=%+VUE<W-A9V5S(&9O<B`D<&%C:V%G
M92\G("(@+@H@("`@("`@("`@("`@("`@("`@(GP@<V5D("=S+TQA;F=U86=E
M+51E86TZ(&YO;F4O3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO
M<F<O)R`B("X*("`@("`@("`@("`@("`@("`@("(^("1P;V9I;&4N=&UP(CL*
M("`@("`@("!]"B`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@
M("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1E
M<W0I('L*("`@("`@("`@("`@)')E="`](#`["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@("`@('T*
M("`@("`@("!R96YA;64H)'!O9FEL92`N("<N=&UP)RP@)'!O9FEL92D["B`@
M("`@("`@:68@*"1R970@/3T@,"D@>PH@("`@("`@("`@("`D8RT^=W)I=&5L
M;B@D8RT^9W)E96XH)V1O;F4G*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G9F%I;&5D)RDI.PH@("`@("`@
M('T*("`@('T*?0H*9G5N8W1I;VX@;6%K92@I"GL*("`@(&=L;V)A;"`D8VUD
M7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@)&1E8G5G+"`D=&5S="P@)&,L("1S
M:6QE;F-E+"`D<F5D:7)?97)R.PH*("`@("1C;VUP96YD:75M(#T@0D%312`N
M($13("X@)W!O)R`N($13("X@)V-O;7!E;F1I=6TN<&\G.PH@("`@)'-A=F5?
M<W1A=',@/2!F86QS93L*("`@(&9O<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A
M<R`D;W!T:6]N*2!["B`@("`@("`@<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@
M("`@("`@("`@(&-A<V4@)V@G.@H@("`@("`@("`@("`@("`@=7-A9V4H*3L*
M("`@("`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@("`@("`@("!C87-E("=L
M)SH*("`@("`@("`@("`@8V%S92`G+2UL;V-A;&4G.@H@("`@("`@("`@("`@
M("`@)&QA;F<@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("!C87-E("<M+6UO
M9'5L92<Z"B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=C)SH*
M("`@("`@("`@("`@8V%S92`G+2UC;VUP96YD:75M)SH*("`@("`@("`@("`@
M("`@("1C;VUP96YD:75M(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!C87-E("=N)SH*("`@("`@("`@("`@8V%S
M92`G+2UN;RUC;VUP96YD:75M)SH*("`@("`@("`@("`@("`@("1C;VUP96YD
M:75M(#T@)R<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`G<R<Z"B`@("`@("`@("`@(&-A<V4@)RTM<W1A=&ES=&EC<R<Z"B`@
M("`@("`@("`@("`@("`D<V%V95]S=&%T<R`]('1R=64["B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"B`@("`D:&]R9&4@/2!A<G)A
M>5]S96%R8V@H)VAO<F1E)RP@)&1I<G,I.PH@("`@)&AO<F1E7VUS9R`](&%R
M<F%Y*"D["B`@("`D<W1A='-?87)R87D@/2!A<G)A>2@I.PH*("`@(')E<75I
M<F5?;VYC92`G0V]N<V]L92]486)L92YP:'`G.PH@("`@)'-T871S(#T@;F5W
M($-O;G-O;&5?5&%B;&4H*3L*("`@("1S=&%T<RT^<V5T2&5A9&5R<RAA<G)A
M>2@G36]D=6QE)RP@)TQA;F=U86=E)RP@)U1R86YS;&%T960G+"`G1G5Z>GDG
M+"`G56YT<F%N<VQA=&5D)RDI.PH*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O
M=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L
M92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI(&-O;G1I;G5E.PH@("`@("`@
M("1C+3YW<FET96QN*'-P<FEN=&8H)T)U:6QD:6YG($U/(&9I;&5S(&9O<B!M
M;V1U;&4@)7,N+BXG+"`D8RT^8F]L9"@D87!P<ULD:5TI*2D["B`@("`@("`@
M:68@*&5M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N9W,@/2!G971?
M;&%N9W5A9V5S*"1D:7)S6R1I72D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@:68@*"%`9FEL95]E>&ES=',H)&1I<G-;)&E=("X@1%,@+B`G<&\G
M("X@1%,@+B`D;&%N9R`N("<N<&\G*2D@>PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH)U-K:7!P960N+BXG*3L*("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D;&%N9W,@/2!A<G)A>2@D;&%N9RD["B`@("`@
M("`@?0H@("`@("`@(&9O<F5A8V@@*"1L86YG<R!A<R`D;&]C86QE*2!["B`@
M("`@("`@("`@("1C+3YW<FET96QN*'-P<FEN=&8H)T)U:6QD:6YG(&QO8V%L
M92`E<RXN+B`G+"`D8RT^8F]L9"@D;&]C86QE*2DI.PH@("`@("`@("`@("`D
M9&ER(#T@)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE)R`N($13("X@)&QO8V%L
M92`N($13("X@)TQ#7TU%4U-!1T53)SL*("`@("`@("`@("`@:68@*"%I<U]D
M:7(H)&1I<BDI('L*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES
M=&5M+G!H<"<["B`@("`@("`@("`@("`@("!I9B`H)&1E8G5G*2!["B`@("`@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G36%K:6YG(&1I
M<F5C=&]R>2`E<R<L("1D:7(I*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@A)'1E<W0@)B8@(4!3>7-T96TZ.FUK9&ER*"(M<"`D
M9&ER(BDI('L*("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^
M<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)T-O=6QD(&YO="!C<F5A=&4@
M;&]C86QE(&1I<F5C=&]R>2!F;W(@;&]C86QE("5S.B<L("1L;V-A;&4I*3L*
M("`@("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D9&ER*3L*("`@("`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`O*B!#;VYV97)T('1O('5N:7@@;&EN96)R96%K<RX@
M*B\*("`@("`@("`@("`@)'!O9FEL92`]("1D:7)S6R1I72`N($13("X@)W!O
M)R`N($13("X@)&QO8V%L92`N("<N<&\G.PH@("`@("`@("`@("`D8V]N=&5N
M="`](&9I;&5?9V5T7V-O;G1E;G1S*"1P;V9I;&4I.PH*("`@("`@("`@("`@
M)&-O;G1E;G0@/2!S=')?<F5P;&%C92@B7'(B+"`G)RP@)&-O;G1E;G0I.PH@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D<&]F:6QE+"`G=V(G*3L*("`@("`@
M("`@("`@9G=R:71E*"1F<"P@)&-O;G1E;G0I.PH@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L*"B`@("`@("`@("`@("\J($-H96-K(%!/(&9I;&4@<V%N:71Y
M+B`J+PH@("`@("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG;7-G9FUT)UT@+B`B
M("TM8VAE8VL@7"(D<&]F:6QE7"(D<F5D:7)?97)R(CL*("`@("`@("`@("`@
M:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@("`@("`@)&,M/G=R
M:71E;&XH)T5X96-U=&EN9SHG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET
M96QN*"1S:"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T97-T
M*2!["B`@("`@("`@("`@("`@("`D<F5T(#T@,#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)')E="`A/2`P*2!["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=787)N:6YG.B`G
M*2`N("=A;B!E<G)O<B!H87,@;V-C=7)E9#HG*3L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*&EM<&QO9&4H(EQN(BP@)&]U="DI.PH@("`@("`@("`@
M("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&EF("@D87!P
M<ULD:5T@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E(#(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]M<&EL92!-
M3R!F:6QE+B`J+PH@("`@("`@("`@("`D<V@@/2`D1TQ/0D%,4ULG;7-G9FUT
M)UT@+B`G("TM<W1A=&ES=&EC<R`M;R`B)R`N("1D:7(@+B!$4R`N("1A<'!S
M6R1I72`N("<N;6\B("<["B`@("`@("`@("`@(&EF("@D87!P<ULD:5T@(3T@
M)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@)&AO<F1E7W!O(#T@)&1I<G-;
M)&AO<F1E72`N($13("X@)W!O)R`N($13("X@)&QO8V%L92`N("<N<&\G.PH@
M("`@("`@("`@("`@("`@:68@*"%`:7-?<F5A9&%B;&4H)&AO<F1E7W!O*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)U=A
M<FYI;F<Z("<I("X@<W!R:6YT9B@G=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H
M92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z)RP@)&QO8V%L92DI.PH@("`@
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1H;W)D95]P;RD["B`@("`@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@
M("`@("`D<V@@+CT@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D;&]C
M86QE("X@)RYP;R<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=C;VUM)UT@+B`B("TM
M;6]R92UT:&%N/3`@+2US;W)T+6]U='!U="!<(B1P;V9I;&5<(B!<(B1H;W)D
M95]P;UPB('P@)'-H("TB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-H("X]("1P;V9I;&4["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'-H("X]("1R961I<E]E<G(["B`@
M("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"=%>&5C=71I;F<Z)RD["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D<V@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1O=70@/2`G)SL*("`@("`@("`@("`@:68@*"1T97-T*2!["B`@("`@("`@
M("`@("`@("`D<F5T(#T@,#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@('!U=&5N=B@G3$%.1SUE;B<I.PH@("`@("`@("`@("`@("`@
M97AE8R@D<V@L("1O=70L("1R970I.PH@("`@("`@("`@("`@("`@<'5T96YV
M*"=,04Y'/2<@+B`D1TQ/0D%,4ULG;&%N9W5A9V4G72D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1R970@/3T@,"D@>PH@("`@("`@("`@("`@
M("`@)&,M/G=R:71E;&XH)&,M/F=R965N*"=D;VYE)RDI.PH@("`@("`@("`@
M("`@("`@)&UE<W-A9V5S(#T@87)R87DH,"P@,"P@,"D["B`@("`@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+RA<9"LI('1R86YS;&%T960O)RP@)&]U
M=%LP72P@)&UA=&-H*2D@>PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E
M<ULP72`]("1M871C:%LQ73L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&AO<F1E7VUS9ULD;&]C86QE72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&UE<W-A9V5S6S!=("T]("1H;W)D95]M<V=;)&QO8V%L95U;,%T[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D;65S<V%G97-;,%T@/"`P
M*2`D;65S<V%G97-;,%T@/2`P.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O*%QD*RD@9G5Z>GDO)RP@)&]U=%LP72P@)&UA=&-H*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1M97-S86=E<ULQ72`]("1M871C:%LQ73L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&AO<F1E7VUS9ULD;&]C86QE72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&UE<W-A9V5S6S%=("T]("1H
M;W)D95]M<V=;)&QO8V%L95U;,5T["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D;65S<V%G97-;,5T@/"`P*2`D;65S<V%G97-;,5T@/2`P.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%QD*RD@=6YT<F%N<VQA=&5D+R<L
M("1O=71;,%TL("1M871C:"DI('L*("`@("`@("`@("`@("`@("`@("`D;65S
M<V%G97-;,ET@/2`D;6%T8VA;,5T["B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1H;W)D95]M<V=;)&QO8V%L95TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1M97-S86=E<ULR72`M/2`D:&]R9&5?;7-G6R1L;V-A;&5=
M6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&UE<W-A9V5S6S)=
M(#P@,"D@)&UE<W-A9V5S6S)=(#T@,#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&%P<'-;
M)&E=(#T]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("`@("`D:&]R9&5?
M;7-G6R1L;V-A;&5=(#T@)&UE<W-A9V5S.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'-T871S7V%R<F%Y6R1A<'!S6R1I75U;)&QO8V%L
M95T@/2`D;65S<V%G97,["B`@("`@("`@("`@("`@("`D<W1A=',M/F%D9%)O
M=RAA<G)A>2@D87!P<ULD:5TL("1L;V-A;&4L("1M97-S86=E<ULP72P@)&UE
M<W-A9V5S6S%=+"`D;65S<V%G97-;,ETI*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)V9A:6QE
M9"<I*3L*("`@("`@("`@("`@("`@(&5X96,H)'-H+"`D;W5T+"`D<F5T*3L*
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*&EM<&QO9&4H(EQN(BP@)&]U
M="DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AC;W5N="@D;&%N
M9W,I(#X@,2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($UE<F=E('1R86YS;&%T:6]N(&EN=&\@
M8V]M<&5N9&EU;2X@*B\*("`@("`@("`@("`@:68@*"%E;7!T>2@D8V]M<&5N
M9&EU;2DI('L*("`@("`@("`@("`@("`@('!R:6YT9B@G365R9VEN9R!T:&4@
M4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@)RP@)&,M/F)O
M;&0H)&%P<'-;)&E=*2D["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1D
M:7(I("8F('-U8G-T<B@D9&ER+"`M,2D@(3T@1%,I('L*("`@("`@("`@("`@
M("`@("`@("`D9&ER("X]($13.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'-H(#T@)$=,3T)!3%-;)VUS9V-A="==("X@(B`M+7-O<G0M
M;W5T<'5T(%PB)&-O;7!E;F1I=6U<(B!<(B1P;V9I;&5<(B`^(%PB)&-O;7!E
M;F1I=6TN=&UP7"(B.PH@("`@("`@("`@("`@("`@:68@*"$D9&5B=6<I('L*
M("`@("`@("`@("`@("`@("`@("`D<V@@+CT@)'-I;&5N8V4["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T
M*2!["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@
M("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1S:"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;W5T(#T@)R<["B`@("`@("`@("`@
M("`@("!I9B`H)'1E<W0I('L*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@
M,#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@97AE8R@D<V@L("1O=70L("1R970I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@0'5N;&EN:R@D8V]M<&5N9&EU;2D["B`@("`@("`@
M("`@("`@("!R96YA;64H)&-O;7!E;F1I=6T@+B`G+G1M<"<L("1C;VUP96YD
M:75M*3L*("`@("`@("`@("`@("`@(&EF("@D<F5T(#T](#`I('L*("`@("`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)V1O;F4G*2D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"1C+3YR960H)V9A:6QE9"<I*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L;B@I
M.PH@("`@("`@('T*("`@('T*("`@(&EF("AE;7!T>2@D;6]D=6QE*2D@>PH@
M("`@("`@("1C+3YW<FET96QN*"=297-U;'1S.B<I.PH@("`@?2!E;'-E('L*
M("`@("`@("`D8RT^=W)I=&5L;B@G4F5S=6QT<R`H:6YC;'5D:6YG($AO<F1E
M*3HG*3L*("`@('T*("`@("1C+3YW<FET96QN*"1S=&%T<RT^9V5T5&%B;&4H
M*2D["B`@("!I9B`H)'-A=F5?<W1A=',I('L*("`@("`@("`D9G`@/2!`9F]P
M96XH)W1R86YS;&%T:6]N7W-T871S+G1X="<L("=W)RD["B`@("`@("`@:68@
M*"1F<"D@>PH@("`@("`@("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)'-T
M871S7V%R<F%Y*2D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M('T*("`@('T*?0H*9G5N8W1I;VX@8VQE86YU<"@D:V5E<%]U;G1R86YS;&%T
M960@/2!F86QS92D*>PH@("`@9VQO8F%L("1C;61?;W!T:6]N<RP@)&%P<',L
M("1D:7)S+"`D9&5B=6<L("1T97-T+"`D8SL*"B`@("!F;W)E86-H("@D8VUD
M7V]P=&EO;G-;,%T@87,@)&]P=&EO;BD@>PH@("`@("`@('-W:71C:"`H)&]P
M=&EO;ELP72D@>PH@("`@("`@("`@("!C87-E("=H)SH*("`@("`@("`@("`@
M("`@('5S86=E*"D["B`@("`@("`@("`@("`@("!F;V]T97(H*3L*("`@("`@
M("`@("`@8V%S92`G;"<Z"B`@("`@("`@("`@(&-A<V4@)RTM;&]C86QE)SH*
M("`@("`@("`@("`@("`@("1L86YG(#T@)&]P=&EO;ELQ73L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@
M("`@8V%S92`G+2UM;V1U;&4G.@H@("`@("`@("`@("`@("`@)&UO9'5L92`]
M("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("!]"@H@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&1I<G,I.R`D
M:2LK*2!["B`@("`@("`@:68@*"%E;7!T>2@D;6]D=6QE*2`F)B`D;6]D=6QE
M("$]("1A<'!S6R1I72D@>R!C;VYT:6YU93L@?0H@("`@("`@("1C+3YW<FET
M96QN*'-P<FEN=&8H)T-L96%N:6YG('5P(%!/(&9I;&5S(&9O<B!M;V1U;&4@
M)7,N+BXG+"`D8RT^8F]L9"@D87!P<ULD:5TI*2D["B`@("`@("`@:68@*&5M
M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D;&%N9W,@/2!G971?;&%N9W5A
M9V5S*"1D:7)S6R1I72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M:68@*"%`9FEL95]E>&ES=',H)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@
M+B`D;&%N9R`N("<N<&\G*2D@>PH@("`@("`@("`@("`@("`@)&,M/G=R:71E
M;&XH)U-K:7!P960N+BXG*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN
M*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D;&%N9W,@/2!A<G)A>2@D;&%N9RD["B`@("`@("`@?0H@
M("`@("`@(&9O<F5A8V@@*"1L86YG<R!A<R`D;&]C86QE*2!["B`@("`@("`@
M("`@("1C+3YW<FET96QN*'-P<FEN=&8H)T-L96%N:6YG('5P(&QO8V%L92`E
M<RXN+B`G+"`D8RT^8F]L9"@D;&]C86QE*2DI.PH@("`@("`@("`@("`D<&]F
M:6QE(#T@)&1I<G-;)&E=("X@1%,@+B`G<&\G("X@1%,@+B`D;&]C86QE("X@
M)RYP;R<["B`@("`@("`@("`@("1S:"`]("1'3$]"04Q36R=M<V=A='1R:6(G
M72`N("@D:V5E<%]U;G1R86YS;&%T960@/R`G)R`Z("<@+2UT<F%N<VQA=&5D
M)RD@+B`B("TM;F\M;V)S;VQE=&4@+2UF;W)C92UP;R`D<&]F:6QE(#X@)'!O
M9FEL92YT;7`B.PH@("`@("`@("`@("!I9B`H(21D96)U9RD@>PH@("`@("`@
M("`@("`@("`@)'-H("X]("1S:6QE;F-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@G
M17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)'-H
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T(#T@)R<["B`@("`@
M("`@("`@(&EF("@D=&5S="D@>PH@("`@("`@("`@("`@("`@)')E="`](#`[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!E>&5C*"1S
M:"P@)&]U="P@)')E="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1R970@/3T@,"D@>PH@("`@("`@("`@("`@("`@0'5N;&EN:R@D<&]F:6QE
M*3L*("`@("`@("`@("`@("`@(')E;F%M92@D<&]F:6QE("X@)RYT;7`G+"`D
M<&]F:6QE*3L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"1C+3YG<F5E
M;B@G9&]N92<I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@($!U;FQI;FLH)'!O9FEL92`N("<N=&UP)RP@)'!O9FEL92D["B`@("`@
M("`@("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=F86EL960G*2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@
M("!]"B`@("!]"GT*"F9U;F-T:6]N(&-O;6UI="@D:&5L<%]O;FQY(#T@9F%L
M<V4I"GL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1A<'!S+"`D9&ER<RP@
M)&1E8G5G+"`D=&5S="P@)&,["@H@("`@)&1O8W,@/2!F86QS93L*("`@(&9O
M<F5A8V@@*"1C;61?;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("`@("`@
M<W=I=&-H("@D;W!T:6]N6S!=*2!["B`@("`@("`@("`@(&-A<V4@)V@G.@H@
M("`@("`@("`@("`@("`@=7-A9V4H*3L*("`@("`@("`@("`@("`@(&9O;W1E
M<B@I.PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@8V%S92`G
M+2UL;V-A;&4G.@H@("`@("`@("`@("`@("`@)&QA;F<@/2`D;W!T:6]N6S%=
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)VTG
M.@H@("`@("`@("`@("!C87-E("<M+6UO9'5L92<Z"B`@("`@("`@("`@("`@
M("`D;6]D=6QE(#T@)&]P=&EO;ELQ73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!C87-E("=N)SH*("`@("`@("`@("`@8V%S92`G+2UN
M97<G.@H@("`@("`@("`@("`@("`@)&1O8W,@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)TTG.@H@("`@("`@("`@
M("!C87-E("<M+6UE<W-A9V4G.@H@("`@("`@("`@("`@("`@)&US9R`]("1O
M<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"B`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)&1I<G,I.R`D:2LK*2!["B`@("`@("`@:68@*"%E;7!T>2@D
M;6]D=6QE*2`F)B`D;6]D=6QE("$]("1A<'!S6R1I72D@8V]N=&EN=64["B`@
M("`@("`@:68@*"1A<'!S6R1I72`]/2`G:&]R9&4G*2!["B`@("`@("`@("`@
M("1D:7)S6UT@/2`D9&ER<ULD:5T@+B!$4R`N("=A9&UI;B<["B`@("`@("`@
M("`@("1A<'!S6UT@/2`G:&]R9&4O861M:6XG.PH@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1M;V1U;&4I*2!["B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@
M)VAO<F1E+V%D;6EN)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&QA;F<I*2!["B`@("`@("`@("`@(&EF("@D:&5L<%]O
M;FQY*2!["B`@("`@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D
M9FEL97,L('-T<FEP7VAO<F1E*'-E87)C:%]E>'0H)WAM;"<L("1D:7)S6R1I
M72`N($13("X@)VQO8V%L92<I*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL97,L('-T
M<FEP7VAO<F1E*&=E=%]P;U]F:6QE<R@D9&ER<ULD:5T@+B!$4R`N("=P;R<I
M*2D["B`@("`@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D9FEL
M97,L('-T<FEP7VAO<F1E*'-E87)C:%]F:6QE*"=>6V$M>EU[,GU?6T$M6EU[
M,GTG+"`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G+"!T<G5E*2DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1H
M96QP7V]N;'DI('L*("`@("`@("`@("`@("`@(&EF("@A0&9I;&5?97AI<W1S
M*"1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N("1L86YG("X@1%,@
M+B`G:&5L<"YX;6PG*2D@8V]N=&EN=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9&ER<ULD:5T@
M+B`G+W!O+R<@+B`D;&%N9R`N("<N<&\G*2D@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("`D9FEL97-;72`]('-T<FEP7VAO<F1E*"1D:7)S6R1I72`N($13
M("X@)W!O)R`N($13("X@)&QA;F<@+B`G+G!O)RD["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&9I;&5S6UT@/2!S=')I<%]H;W)D92@D9&ER<ULD:5T@
M+B!$4R`N("=L;V-A;&4G("X@1%,@+B`D;&%N9RD["B`@("`@("`@?0H@("`@
M("`@(&EF("@D9&]C<R`F)B`A)&AE;'!?;VYL>2`F)B`D87!P<ULD:5TI('L*
M("`@("`@("`@("`@)&9I;&5S6UT@/2!S=')I<%]H;W)D92@D9&ER<ULD:5T@
M+B!$4R`N("=D;V-S)RD["B`@("`@("`@("`@(&EF("@D87!P<ULD:5T@/3T@
M)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@)&AO<F1E7V-O;F8@/2`D9&ER
M<UMA<G)A>5]S96%R8V@H)VAO<F1E)RP@)&1I<G,I72`N($13("X@)V-O;F9I
M9R<@+B!$4SL*("`@("`@("`@("`@("`@("1F:6QE<UM=(#T@<W1R:7!?:&]R
M9&4H)&AO<F1E7V-O;F8@+B`G;FQS+G!H<"YD:7-T)RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"B`@("!C:&1I<BA"05-%*3L*("`@(&EF("AC
M;W5N="@D9FEL97,I*2!["B`@("`@("`@:68@*"1D;V-S*2!["B`@("`@("`@
M("`@("1C+3YW<FET96QN*"=!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O
M<GDZ)RD["B`@("`@("`@("`@("1S:"`]("=C=G,@861D)SL*("`@("`@("`@
M("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2!["B`@("`@("`@("`@("`@
M("!I9B`H<W1R<W1R*"1F:6QE+"`G;&]C86QE)RD@?'P@<W1R<W1R*"1F:6QE
M+"`G+G!O)RDI('L*("`@("`@("`@("`@("`@("`@("`D<V@@+CT@(B`D9FEL
M92(["B`@("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH)&9I;&4I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1S
M:"`N/2`G.R!C=G,@861D)SL*("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5S
M(&%S("1F:6QE*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1F:6QE
M+"`G;&]C86QE)RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&AE;'!?
M;VYL>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<V@@+CT@)R`G("X@
M)&9I;&4@+B!$4R`N("<J+GAM;"<["B`@("`@("`@("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"1F:6QE("X@1%,@+B`G*BYX;6PG*3L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<V@@+CT@)R`G("X@)&9I;&4@+B!$4R`N("<J+GAM;"`G("X@)&9I;&4@+B!$
M4R`N("=,0U]-15-304=%4R<["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"1F:6QE("X@1%,@+B`B*BYX;6Q<;B1F:6QE(B`N($13("X@
M)TQ#7TU%4U-!1T53)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)&AE
M;'!?;VYL>2D@>PH@("`@("`@("`@("`@("`@)'-H("X]("<[(&-V<R!A9&0G
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D9FEL92P@)VQO8V%L
M92<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A9&0@/2`D9FEL92`N
M($13("X@)TQ#7TU%4U-!1T53)R`N($13("X@)RHN;6\G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D<V@@+CT@)R`G("X@)&%D9#L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&,M/G=R:71E;&XH)&%D9"D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@(&EF("@D9&5B=6<@
M?'P@)'1E<W0I('L*("`@("`@("`@("`@("`@("1C+3YW<FET96QN*"=%>&5C
M=71I;F<Z)RD["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;B@D<V@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)'1E<W0I('-Y<W1E;2@D
M<V@I.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('T*("`@
M("`@("`D8RT^=W)I=&5L;B@G0V]M;6ET=&EN9SHG*3L*("`@("`@("`D8RT^
M=W)I=&5L;BAI;7!L;V1E*"<@)RP@)&9I;&5S*2D["B`@("`@("`@:68@*"%E
M;7!T>2@D;&%N9RDI('L*("`@("`@("`@("`@)&QA;F<@/2`G("<@+B`D;&%N
M9SL*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M<V<I*2!["B`@("`@
M("`@("`@(&EF("@D9&]C<RD@>PH@("`@("`@("`@("`@("`@)&US9R`](")!
M9&0D;&%N9R!T<F%N<VQA=&EO;BXB.PH@("`@("`@("`@("!](&5L<V5I9B`H
M)&AE;'!?;VYL>2D@>PH@("`@("`@("`@("`@("`@)&US9R`](")5<&1A=&4D
M;&%N9R!H96QP(&9I;&4N(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1M<V<@/2`B57!D871E)&QA;F<@=')A;G-L871I;VXN(CL*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<V@@/2`G8W9S(&-O
M;6UI="`M;2`B)R`N("1M<V<@+B`G(B`G("X@:6UP;&]D92@G("<L("1F:6QE
M<RD["B`@("`@("`@:68@*"1D96)U9R!\?"`D=&5S="D@>PH@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@G17AE8W5T:6YG.B<I.PH@("`@("`@("`@("`D8RT^
M=W)I=&5L;B@D<V@I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T97-T*2!S
M>7-T96TH)'-H*3L*("`@('T*?0H*9G5N8W1I;VX@=7!D871E7VAE;'`H*0I[
M"B`@("!G;&]B86P@)&-M9%]O<'1I;VYS+"`D9&ER<RP@)&%P<',L("1D96)U
M9RP@)'1E<W0L("1L87-T7V5R<F]R7VUS9RP@)&,["@H@("`@9F]R96%C:"`H
M)&-M9%]O<'1I;VYS6S!=(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@
M*"1O<'1I;VY;,%TI('L*("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@
M("`@("`@("!U<V%G92@I.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@
M("`@("`@("`@(&-A<V4@)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L
M92<Z"B`@("`@("`@("`@("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@
M("`@("`@(&-A<V4@)RTM;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U
M;&4@/2`D;W!T:6]N6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H@("`@?0H@("`@)&9I;&5S(#T@87)R87DH*3L*("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A
M96UP='DH)&UO9'5L92D@)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI('L@8V]N
M=&EN=64[('T*("`@("`@("!I9B`H(6ES7V1I<B@B)&1I<G-;)&E=+VQO8V%L
M92(I*2!C;VYT:6YU93L*("`@("`@("!I9B`H)&%P<'-;)&E=(#T]("=H;W)D
M92<I('L*("`@("`@("`@("`@)&1I<G-;72`]("1D:7)S6R1I72`N($13("X@
M)V%D;6EN)SL*("`@("`@("`@("`@)&%P<'-;72`]("=H;W)D92]A9&UI;B<[
M"B`@("`@("`@("`@(&EF("@A96UP='DH)&UO9'5L92DI('L*("`@("`@("`@
M("`@("`@("1M;V1U;&4@/2`G:&]R9&4O861M:6XG.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D;&%N9RDI('L*("`@("`@
M("`@("`@)&9I;&5S(#T@<V5A<F-H7V9I;&4H)VAE;'`N>&UL)RP@)&1I<G-;
M)&E=("X@1%,@+B`G;&]C86QE)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&9I;&5S(#T@87)R87DH)&1I<G-;)&E=("X@1%,@+B`G;&]C86QE
M)R`N($13("X@)&QA;F<@+B!$4R`N("=H96QP+GAM;"<I.PH@("`@("`@('T*
M("`@("`@("`D9FEL95]E;B`@/2`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G
M("X@1%,@+B`G96Y?55,G("X@1%,@+B`G:&5L<"YX;6PG.PH@("`@("`@(&EF
M("@A0&9I;&5?97AI<W1S*"1F:6QE7V5N*2D@>PH@("`@("`@("`@("`D8RT^
M=W)I=&5L;BAW;W)D=W)A<"@D8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN
M=&8H)U1H97)E(&1O97-N7"=T('EE="!E>&ES="!A(&AE;'`@9FEL92!F;W(@
M)7,N)RP@)&,M/F)O;&0H)&%P<'-;)&E=*2DI*3L*("`@("`@("`@("`@)&,M
M/G=R:71E;&XH*3L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@
M("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL95]L;V,I('L*("`@("`@
M("`@("`@)&QO8V%L92`]('-U8G-T<B@D9FEL95]L;V,L(#`L('-T<G)P;W,H
M)&9I;&5?;&]C+"!$4RDI.PH@("`@("`@("`@("`D;&]C86QE(#T@<W5B<W1R
M*"1L;V-A;&4L('-T<G)P;W,H)&QO8V%L92P@1%,I("L@,2D["B`@("`@("`@
M("`@(&EF("@D;&]C86QE(#T]("=E;E]54R<I(&-O;G1I;G5E.PH@("`@("`@
M("`@("!I9B`H(4!F:6QE7V5X:7-T<R@D9FEL95]L;V,I*2!["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D8RT^<F5D*"=787)N:6YG
M.B`G*2`N('-P<FEN=&8H)U1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N
M7"=T('EE="!E>&ES="X@0W)E871I;F<@82!N97<@;VYE+B<L("1C+3YB;VQD
M*"1L;V-A;&4I+"`D8RT^8F]L9"@D87!P<ULD:5TI*2DI.PH@("`@("`@("`@
M("`@("`@)&1I<E]L;V,@/2!S=6)S='(H)&9I;&5?;&]C+"`P+"`M.2D["B`@
M("`@("`@("`@("`@("!I9B`H(6ES7V1I<B@D9&ER7VQO8RDI('L*("`@("`@
M("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G36%K:6YG
M(&1I<F5C=&]R>2`E<R<L("1D:7)?;&]C*2D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@A)'1E<W0@)B8@(4!3>7-T
M96TZ.FUK9&ER*"(M<"`D9&ER7VQO8R(I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R
M:6YT9B@G0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L
M;V-A;&4@)7,Z)RP@)&QO8V%L92DI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;B@D9&ER7VQO8RD["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("@D9&5B=6<@?'P@)'1E<W0I('L*("`@
M("`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"AS<')I;G1F
M*"=#;W!Y:6YG("5S('1O("5S)RP@)&9I;&5?96XL("1F:6QE7VQO8RDI*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A)'1E<W0@
M)B8@(4!C;W!Y*"1F:6QE7V5N+"`D9FEL95]L;V,I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G5V%R;FEN9SH@)RD@+B!S
M<')I;G1F*"=#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<R<L("1F:6QE7V5N+"`D
M9FEL95]L;V,I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1C+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F*"=5
M<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+B<L("1C+3YB;VQD*"1L;V-A
M;&4I+"`D8RT^8F]L9"@D87!P<ULD:5TI*2D["B`@("`@("`@("`@("1F<"`]
M(&9O<&5N*"1F:6QE7VQO8RP@)W(G*3L*("`@("`@("`@("`@)&QI;F4@/2!F
M9V5T<R@D9G`I.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@
M("`@:68@*"%S=')S='(H)&QI;F4L("<\/WAM;"<I*2!["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D8RT^<F5D*"=787)N:6YG.B`G
M*2`N('-P<FEN=&8H)U1H92!H96QP(&9I;&4@)7,@9&ED;EPG="!S=&%R="!W
M:71H(#P_>&UL)RP@)&9I;&5?;&]C*2DI.PH@("`@("`@("`@("`@("`@)&,M
M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1E;F-O9&EN9R`]("<G.PH@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+V5N8V]D:6YG/2A;(EPG72DH6UY<7#%=*RE<
M7#$O)RP@)&QI;F4L("1M871C:"DI('L*("`@("`@("`@("`@("`@("1E;F-O
M9&EN9R`]("1M871C:%LR73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M9&]C7V5N(#T@9&]M>&UL7V]P96Y?9FEL92@D9FEL95]E;BD["B`@("`@("`@
M("`@(&EF("@A:7-?;V)J96-T*"1D;V-?96XI*2!["B`@("`@("`@("`@("`@
M("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D8RT^<F5D*"=787)N:6YG.B`G*2`N
M('-P<FEN=&8H)U1H97)E('=A<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE
M("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@9FQA
M9R`M9"!T;R!S964@86YY(&5R<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P
M87)S97(N)RP@)&9I;&5?96XI*2D["B`@("`@("`@("`@("`@("`D8RT^=W)I
M=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D9&]C7VQO8R`](&1O;7AM;%]O<&5N7V9I;&4H
M)&9I;&5?;&]C*3L*("`@("`@("`@("`@:68@*"%I<U]O8FIE8W0H)&1O8U]L
M;V,I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D
M8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)U1H97)E('=A<R!A;B!E
M<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T<F%N<VQA
M=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R<F]R(&UE
M<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N)RP@)&9I;&5?;&]C*2DI.PH@
M("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D;V-?;F5W
M("`](&1O;7AM;%]N97=?9&]C*"<Q+C`G*3L*("`@("`@("`@("`@)&AE;'!?
M96X@(#T@)&1O8U]E;BT^9&]C=6UE;G1?96QE;65N="@I.PH@("`@("`@("`@
M("`D:&5L<%]L;V,@/2`D9&]C7VQO8RT^9&]C=6UE;G1?96QE;65N="@I.PH@
M("`@("`@("`@("`D:&5L<%]N97<@/2`D:&5L<%]L;V,M/F-L;VYE7VYO9&4H
M*3L*("`@("`@("`@("`@)&5N=')I97-?;&]C(#T@87)R87DH*3L*("`@("`@
M("`@("`@)&5N=')I97-?;F5W(#T@87)R87DH*3L*("`@("`@("`@("`@)&-O
M=6YT7W5P=&]D871E(#T@,#L*("`@("`@("`@("`@)&-O=6YT7VYE=R`@("`@
M(#T@,#L*("`@("`@("`@("`@)&-O=6YT7V-H86YG960@(#T@,#L*("`@("`@
M("`@("`@)&-O=6YT7W5N:VYO=VX@(#T@,#L*("`@("`@("`@("`@9F]R96%C
M:"`H)&1O8U]L;V,M/F=E=%]E;&5M96YT<U]B>5]T86=N86UE*"=E;G1R>2<I
M(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@)&5N=')I97-?;&]C6R1E
M;G1R>2T^9V5T7V%T=')I8G5T92@G:60G*5T@/2`D96YT<GD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&1O8U]E;BT^9V5T7V5L96UE
M;G1S7V)Y7W1A9VYA;64H)V5N=')Y)RD@87,@)&5N=')Y*2!["B`@("`@("`@
M("`@("`@("`D:60@/2`D96YT<GDM/F=E=%]A='1R:6)U=&4H)VED)RD["B`@
M("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D:60L("1E;G1R
M:65S7VQO8RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&5N=')I97-?
M;&]C6R1I9%TM/FAA<U]A='1R:6)U=&4H)VUD-2<I("8F"B`@("`@("`@("`@
M("`@("`@("`@("`@(&UD-2@D96YT<GDM/F=E=%]C;VYT96YT*"DI("$]("1E
M;G1R:65S7VQO8ULD:61=+3YG971?871T<FEB=71E*"=M9#4G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]M;65N="`]("1D;V-?;&]C+3YC<F5A
M=&5?8V]M;65N="@B($5N9VQI<V@@96YT<GDZ7&XB("X@<W1R7W)E<&QA8V4H
M)RTM)RP@)R8C-#4[)B,T-3LG+"`D9&]C7VQO8RT^9'5M<%]N;V1E*"1E;G1R
M>2DI*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')I97-?;&]C6R1I
M9%TM/F%P<&5N9%]C:&EL9"@D8V]M;65N="D["B`@("`@("`@("`@("`@("`@
M("`@("`@("1E;G1R>5]N97<@/2`D96YT<FEE<U]L;V-;)&ED72T^8VQO;F5?
M;F]D92AT<G5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y7VYE
M=RT^<V5T7V%T=')I8G5T92@G<W1A=&4G+"`G8VAA;F=E9"<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]U;G1?8VAA;F=E9"LK.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A)&5N=')I97-?;&]C6R1I9%TM/FAA<U]A='1R:6)U=&4H)W-T871E)RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VUM96YT(#T@)&1O
M8U]L;V,M/F-R96%T95]C;VUM96YT*"(@16YG;&ES:"!E;G1R>3I<;B(@+B!S
M=')?<F5P;&%C92@G+2TG+"`G)B,T-3LF(S0U.R<L("1D;V-?;&]C+3YD=6UP
M7VYO9&4H)&5N=')Y*2DI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5N=')I97-?;&]C6R1I9%TM/F%P<&5N9%]C:&EL9"@D8V]M;65N="D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE?;F5W(#T@)&5N=')I
M97-?;&]C6R1I9%TM/F-L;VYE7VYO9&4H=')U92D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D96YT<GE?;F5W+3YS971?871T<FEB=71E*"=S=&%T
M92<L("=U;FMN;W=N)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]U;G1?=6YK;F]W;BLK.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y7VYE=R`]
M("1E;G1R:65S7VQO8ULD:61=+3YC;&]N95]N;V1E*'1R=64I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-O=6YT7W5P=&]D871E*RL["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E
M;G1R>5]N97<@/2`D96YT<GDM/F-L;VYE7VYO9&4H=')U92D["B`@("`@("`@
M("`@("`@("`@("`@)&5N=')Y7VYE=RT^<V5T7V%T=')I8G5T92@G<W1A=&4G
M+"`G;F5W)RD["B`@("`@("`@("`@("`@("`@("`@)&-O=6YT7VYE=RLK.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&5N=')I97-?;F5W
M6UT@/2`D96YT<GE?;F5W.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1D
M;V-?;F5W+3YA<'!E;F1?8VAI;&0H)&1O8U]N97<M/F-R96%T95]C;VUM96YT
M*"<@)"<@+B`G2&]R9&4D("<I*3L*("`@("`@("`@("`@9F]R96%C:"`H)&5N
M=')I97-?;F5W(&%S("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@)&AE;'!?
M;F5W+3YA<'!E;F1?8VAI;&0H)&5N=')Y*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"AS<')I;G1F*"=%;G1R:65S
M.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D
M+"`E9"!U;FMN;W=N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1C;W5N=%]U<'1O9&%T92`K("1C;W5N=%]N97<@*R`D8V]U;G1?
M8VAA;F=E9"`K("1C;W5N=%]U;FMN;W=N+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O=6YT7W5P=&]D871E+"`D8V]U;G1?;F5W
M+"`D8V]U;G1?8VAA;F=E9"P@)&-O=6YT7W5N:VYO=VXI*2D["B`@("`@("`@
M("`@("1D;V-?;F5W+3YA<'!E;F1?8VAI;&0H)&AE;'!?;F5W*3L*("`@("`@
M("`@("`@)&]U='!U="`]("1D;V-?;F5W+3YD=6UP7VUE;2AT<G5E+"`D96YC
M;V1I;F<I.PH@("`@("`@("`@("!I9B`H)&1E8G5G('Q\("1T97-T*2!["B`@
M("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"AS<')I;G1F*"=7
M<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S+B<L("1F:6QE7VQO8RDI
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21T97-T*2!["B`@
M("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL95]L;V,L("=W)RD["B`@
M("`@("`@("`@("`@("`D;&EN92`](&9W<FET92@D9G`L("1O=71P=70I.PH@
M("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G)60@8GET97,@=W)I='1E
M;BXG+"!S=')L96XH)&]U='!U="DI*3L*("`@("`@("`@("`@)&,M/G=R:71E
M;&XH*3L*("`@("`@("!]"B`@("!]"GT*"F9U;F-T:6]N(&UA:V5?:&5L<"@I
M"GL*("`@(&=L;V)A;"`D8VUD7V]P=&EO;G,L("1D:7)S+"`D87!P<RP@)&1E
M8G5G+"`D=&5S="P@)&,["@H@("`@9F]R96%C:"`H)&-M9%]O<'1I;VYS6S!=
M(&%S("1O<'1I;VXI('L*("`@("`@("!S=VET8V@@*"1O<'1I;VY;,%TI('L*
M("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@("`@("`@("!U<V%G92@I
M.PH@("`@("`@("`@("`@("`@9F]O=&5R*"D["B`@("`@("`@("`@(&-A<V4@
M)VPG.@H@("`@("`@("`@("!C87-E("<M+6QO8V%L92<Z"B`@("`@("`@("`@
M("`@("`D;&%N9R`]("1O<'1I;VY;,5T["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G;2<Z"B`@("`@("`@("`@(&-A<V4@)RTM
M;6]D=6QE)SH*("`@("`@("`@("`@("`@("1M;V1U;&4@/2`D;W!T:6]N6S%=
M.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H@("`@
M)&9I;&5S(#T@87)R87DH*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT
M*"1D:7)S*3L@)&DK*RD@>PH@("`@("`@(&EF("@A96UP='DH)&UO9'5L92D@
M)B8@)&UO9'5L92`A/2`D87!P<ULD:5TI(&-O;G1I;G5E.PH@("`@("`@(&EF
M("@A:7-?9&ER*"(D9&ER<ULD:5TO;&]C86QE(BDI(&-O;G1I;G5E.PH@("`@
M("`@(&EF("@D87!P<ULD:5T@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`D
M9&ER<UM=(#T@)&1I<G-;)&E=("X@1%,@+B`G861M:6XG.PH@("`@("`@("`@
M("`D87!P<UM=(#T@)VAO<F1E+V%D;6EN)SL*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;6]D=6QE*2D@>PH@("`@("`@("`@("`@("`@)&UO9'5L92`]("=H
M;W)D92]A9&UI;B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M:68@*&5M<'1Y*"1L86YG*2D@>PH@("`@("`@("`@("`D9FEL97,@/2!S96%R
M8VA?9FEL92@G:&5L<"YX;6PG+"`D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL97,@/2!A<G)A
M>2@D9&ER<ULD:5T@+B!$4R`N("=L;V-A;&4G("X@1%,@+B`D;&%N9R`N($13
M("X@)VAE;'`N>&UL)RD["B`@("`@("`@?0H@("`@("`@("1F:6QE7V5N("`]
M("1D:7)S6R1I72`N($13("X@)VQO8V%L92<@+B!$4R`N("=E;E]54R<@+B!$
M4R`N("=H96QP+GAM;"<["B`@("`@("`@:68@*"%`9FEL95]E>&ES=',H)&9I
M;&5?96XI*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@
M("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&5?;&]C*2!["B`@("`@("`@
M("`@(&EF("@A0&9I;&5?97AI<W1S*"1F:6QE7VQO8RDI('L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*"=3:VEP<&5D+BXN)RD["B`@("`@("`@("`@
M("`@("`D8RT^=W)I=&5L;B@I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QO8V%L92`]('-U8G-T<B@D
M9FEL95]L;V,L(#`L('-T<G)P;W,H)&9I;&5?;&]C+"!$4RDI.PH@("`@("`@
M("`@("`D;&]C86QE(#T@<W5B<W1R*"1L;V-A;&4L('-T<G)P;W,H)&QO8V%L
M92P@1%,I("L@,2D["B`@("`@("`@("`@(&EF("@D;&]C86QE(#T]("=E;E]5
M4R<I(&-O;G1I;G5E.PH@("`@("`@("`@("`D8RT^=W)I=&5L;BAS<')I;G1F
M*"=5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+B<L("1C+3YB;VQD*"1L
M;V-A;&4I+"`D8RT^8F]L9"@D87!P<ULD:5TI*2D["B`@("`@("`@("`@("1F
M<"`](&9O<&5N*"1F:6QE7VQO8RP@)W(G*3L*("`@("`@("`@("`@)&QI;F4@
M/2!F9V5T<R@D9G`I.PH@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@
M("`@("`@:68@*"%S=')S='(H)&QI;F4L("<\/WAM;"<I*2!["B`@("`@("`@
M("`@("`@("`D8RT^=W)I=&5L;BAW;W)D=W)A<"@D8RT^<F5D*"=787)N:6YG
M.B`G*2`N('-P<FEN=&8H)U1H92!H96QP(&9I;&4@)7,@9&ED;EPG="!S=&%R
M="!W:71H(#P_>&UL)RP@)&9I;&5?;&]C*2DI.PH@("`@("`@("`@("`@("`@
M)&,M/G=R:71E;&XH*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1E;F-O9&EN9R`]("<G.PH@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+V5N8V]D:6YG/2A;(EPG72DH6UY<7#%=
M*RE<7#$O)RP@)&QI;F4L("1M871C:"DI('L*("`@("`@("`@("`@("`@("1E
M;F-O9&EN9R`]("1M871C:%LR73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9&]C7V5N("`@/2!D;VUX;6Q?;W!E;E]F:6QE*"1F:6QE7V5N*3L*("`@
M("`@("`@("`@:68@*"%I<U]O8FIE8W0H)&1O8U]E;BDI('L*("`@("`@("`@
M("`@("`@("1C+3YW<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z
M("<I("X@<W!R:6YT9B@G5&AE<F4@=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE
M(&9I;&4@)7,N(%1R>2!R=6YN:6YG('1R86YS;&%T:6]N+G!H<"!W:71H('1H
M92!F;&%G("UD('1O('-E92!A;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@
M>&UL('!A<G-E<BXG+"`D9FEL95]E;BDI*3L*("`@("`@("`@("`@("`@("1C
M+3YW<FET96QN*"D["B`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1D;V-?;&]C("`](&1O;7AM;%]O<&5N
M7V9I;&4H)&9I;&5?;&]C*3L*("`@("`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)&1O8U]L;V,I*2!["B`@("`@("`@("`@("`@("`D8RT^=W)I=&5L;BAW;W)D
M=W)A<"@D8RT^<F5D*"=787)N:6YG.B`G*2`N('-P<FEN=&8H)U1H97)E('=A
M<R!A;B!E<G)O<B!O<&5N:6YG('1H92!F:6QE("5S+B!4<GD@<G5N;FEN9R!T
M<F%N<VQA=&EO;BYP:'`@=VET:"!T:&4@9FQA9R`M9"!T;R!S964@86YY(&5R
M<F]R(&UE<W-A9V5S(&9R;VT@=&AE('AM;"!P87)S97(N)RP@)&9I;&5?;&]C
M*2DI.PH@("`@("`@("`@("`@("`@)&,M/G=R:71E;&XH*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H
M96QP7VQO8R`]("1D;V-?;&]C+3YD;V-U;65N=%]E;&5M96YT*"D["B`@("`@
M("`@("`@("1M9#5?96X@("`](&%R<F%Y*"D["B`@("`@("`@("`@("1C;W5N
M=%]A;&P@/2`P.PH@("`@("`@("`@("`D8V]U;G0@("`@(#T@,#L*("`@("`@
M("`@("`@9F]R96%C:"`H)&1O8U]E;BT^9V5T7V5L96UE;G1S7V)Y7W1A9VYA
M;64H)V5N=')Y)RD@87,@)&5N=')Y*2!["B`@("`@("`@("`@("`@("`D;60U
M7V5N6R1E;G1R>2T^9V5T7V%T=')I8G5T92@G:60G*5T@/2!M9#4H)&5N=')Y
M+3YG971?8V]N=&5N="@I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F
M;W)E86-H("@D9&]C7VQO8RT^9V5T7V5L96UE;G1S7V)Y7W1A9VYA;64H)V5N
M=')Y)RD@87,@)&5N=')Y*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M96YT<GDM/F-H:6QD7VYO9&5S*"D@87,@)&-H:6QD*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1C:&EL9"T^;F]D95]T>7!E*"D@/3T@6$U,7T-/34U%
M3E1?3D]$12`F)B!S=')S='(H)&-H:6QD+3YN;V1E7W9A;'5E*"DL("=%;F=L
M:7-H(&5N=')Y)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y
M+3YR96UO=F5?8VAI;&0H)&-H:6QD*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]U;G1?86QL
M*RL["B`@("`@("`@("`@("`@("`D:60@/2`D96YT<GDM/F=E=%]A='1R:6)U
M=&4H)VED)RD["B`@("`@("`@("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES
M=',H)&ED+"`D;60U7V5N*2D@>PH@("`@("`@("`@("`@("`@("`@("1C+3YW
M<FET96QN*'=O<F1W<F%P*"1C+3YR960H)U=A<FYI;F<Z("<I("X@<W!R:6YT
M9B@G3F\@96YT<GD@=VET:"!T:&4@:60@(B5S(B!E>&ES=',@:6X@=&AE(&]R
M:6=I;F%L(&AE;'`@9FEL92XG+"`D:60I*2D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R>2T^<V5T7V%T=')I
M8G5T92@G;60U)RP@)&UD-5]E;ELD:61=*3L*("`@("`@("`@("`@("`@("`@
M("`D96YT<GDM/G-E=%]A='1R:6)U=&4H)W-T871E)RP@)W5P=&]D871E)RD[
M"B`@("`@("`@("`@("`@("`@("`@)&-O=6YT*RL["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U="`]("1D;V-?
M;&]C+3YD=6UP7VUE;2AT<G5E+"`D96YC;V1I;F<I.PH@("`@("`@("`@("!I
M9B`H(21T97-T*2!["B`@("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL
M95]L;V,L("=W)RD["B`@("`@("`@("`@("`@("`D;&EN92`](&9W<FET92@D
M9G`L("1O=71P=70I.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&,M/G=R:71E;&XH<W!R:6YT9B@G
M)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T92<L("1C;W5N
M="P@)&-O=6YT7V%L;"DI.PH@("`@("`@("`@("`D8RT^=W)I=&5L;B@I.PH@
M("`@("`@('T*("`@('T*?0H*)&-U<F1I<B`](&=E=&-W9"@I.PID969I;F4H
M)T13)RP@1$E214-43U)97U-%4$%2051/4BD["@HD;&%N9W5A9V4@/2!G971E
M;G8H)TQ!3D<G*3L*:68@*&5M<'1Y*"1L86YG=6%G92DI('L*("`@("1L86YG
M=6%G92`](&=E=&5N=B@G3$%.1U5!1T4G*3L*?0H*0&1E9FEN92@G2$]21$5?
M0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V-O<F4N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]#3$DN<&AP)SL*"B1C(#T@)FYE=R!(;W)D95]#3$DH*3L*:68@
M*"$D8RT^<G5N;FEN9T9R;VU#3$DH*2D@>PH@("`@)&,M/F9A=&%L*"=4:&ES
M('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI;F4N)RD[
M"GT*)&,M/FEN:70H*3L*"B1C+3YW<FET96QN*"1C+3YB;VQD*"<M+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TG*2D["B1C+3YW<FET96QN*"1C+3YB;VQD
M*"=(;W)D92!T<F%N<VQA=&EO;B!G96YE<F%T;W(G*2D["B1C+3YW<FET96QN
M*"1C+3YB;VQD*"<M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TG*2D["@HO
M*B!386YI='D@8VAE8VMS("HO"FEF("@A97AT96YS:6]N7VQO861E9"@G9V5T
M=&5X="<I*2!["B`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"='971T97AT(&5X
M=&5N<VEO;B!N;W0@9F]U;F0A)RDI.PH@("`@9F]O=&5R*"D["GT*"B1C+3YW
M<FET96QN*"=,;V%D:6YG(&QI8G)A<FEE<RXN+B<I.PHD;&EB<U]F;W5N9"`]
M('1R=64["@IF;W)E86-H("AA<G)A>2@G0V]N<V]L95]'971O<'0G(#T^("=#
M;VYS;VQE+T=E=&]P="YP:'`G+`H@("`@("`@("`@("`@("`G0V]N<V]L95]4
M86)L92<@(#T^("=#;VYS;VQE+U1A8FQE+G!H<"<L"B`@("`@("`@("`@("`@
M("=&:6QE7T9I;F0G("`@("`@/3X@)T9I;&4O1FEN9"YP:'`G*0H@("`@("`@
M("!A<R`D8VQA<W,@/3X@)&9I;&4I('L*("`@(&5C:&\@)&-L87-S("X@)RXN
M+B`G.PH@("`@0&EN8VQU9&4@)&9I;&4["B`@("!I9B`H8VQA<W-?97AI<W1S
M*"1C;&%S<RDI('L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^9W)E96XH)T]+
M)RDI.PH@("`@?2!E;'-E('L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D
M*'-P<FEN=&8H)R5S(&YO="!F;W5N9"XG+"`D8VQA<W,I*2D["B`@("`@("`@
M)&QI8G-?9F]U;F0@/2!F86QS93L*("`@('T*?0H*:68@*"$D;&EB<U]F;W5N
M9"D@>PH@("`@)&,M/G=R:71E;&XH*3L*("`@("1C+3YW<FET96QN*"=-86ME
M('-U<F4@=&AA="!Y;W4@:&%V92!014%2(&EN<W1A;&QE9"!A;F0@:6X@>6]U
M<B!I;F-L=61E('!A=&@N)RD["B`@("`D8RT^=W)I=&5L;B@G:6YC;'5D95]P
M871H.B`G("X@:6YI7V=E="@G:6YC;'5D95]P871H)RDI.PH@("`@9F]O=&5R
M*"D["GT*)&,M/G=R:71E;&XH*3L*"B\J($-O;6UA;F1L:6YE('!A<F%M971E
M<G,@*B\*)&%R9W,@("`@/2!#;VYS;VQE7T=E=&]P=#HZ<F5A9%!(4$%R9W8H
M*3L*)&]P=&EO;G,@/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T*"1A<F=S+"`G
M8CID:'0G+"!A<G)A>2@G8F%S93TG+"`G9&5B=6<G+"`G:&5L<"<L("=T97-T
M)RDI.PII9B`H4$5!4CHZ:7-%<G)O<B@D;W!T:6]N<RD@)B8@)&%R9W-;,%T@
M/3T@)%]315)615);)U!(4%]314Q&)UTI('L*("`@(&%R<F%Y7W-H:69T*"1A
M<F=S*3L*("`@("1O<'1I;VYS(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P="@D
M87)G<RP@)V(Z9&AT)RP@87)R87DH)V)A<V4])RP@)V1E8G5G)RP@)VAE;'`G
M+"`G=&5S="<I*3L*?0II9B`H4$5!4CHZ:7-%<G)O<B@D;W!T:6]N<RDI('L*
M("`@("1C+3YW<FET96QN*"1C+3YR960H)T=E=&]P="!%<G)O<CH@)R`N('-T
M<E]R97!L86-E*"=#;VYS;VQE7T=E=&]P=#HG+"`G)RP@)&]P=&EO;G,M/F=E
M=$UE<W-A9V4H*2DI*3L*("`@("1C+3YW<FET96QN*"D["B`@("!U<V%G92@I
M.PH@("`@9F]O=&5R*"D["GT*:68@*&5M<'1Y*"1O<'1I;VYS6S!=6S!=*2`F
M)B!E;7!T>2@D;W!T:6]N<ULQ75LP72DI('L*("`@("1C+3YW<FET96QN*"1C
M+3YR960H)T5R<F]R.B`G("X@)TYO(&-O;6UA;F0@<W!E8VEF:65D+B<I*3L*
M("`@("1C+3YW<FET96QN*"D["B`@("!U<V%G92@I.PH@("`@9F]O=&5R*"D[
M"GT*)&1E8G5G(#T@9F%L<V4["B1T97-T("`](&9A;'-E.PIF;W)E86-H("@D
M;W!T:6]N<ULP72!A<R`D;W!T:6]N*2!["B`@("!S=VET8V@@*"1O<'1I;VY;
M,%TI('L*("`@("`@("!C87-E("=B)SH*("`@("`@("!C87-E("<M+6)A<V4G
M.@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1O<'1I;VY;,5TL("TQ*2`]/2!$
M4RD@>PH@("`@("`@("`@("`@("`@)&]P=&EO;ELQ72`]('-U8G-T<B@D;W!T
M:6]N6S%=+"`P+"`M,2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5F
M:6YE*"="05-%)RP@)&]P=&EO;ELQ72D["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@)V0G.@H@("`@("`@(&-A<V4@)RTM9&5B=6<G.@H@("`@
M("`@("`@("`D9&5B=6<@/2!T<G5E.PH@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("!C87-E("=T)SH*("`@("`@("!C87-E("<M+71E<W0G.@H@("`@("`@
M("`@("`D=&5S="`]('1R=64["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M(&-A<V4@)V@G.@H@("`@("`@(&-A<V4@)RTM:&5L<"<Z"B`@("`@("`@("`@
M('5S86=E*"D["B`@("`@("`@("`@(&9O;W1E<B@I.PH@("`@?0I]"FEF("@A
M)&1E8G5G*2!["B`@("!I;FE?<V5T*"=E<G)O<E]R97!O<G1I;F<G+"!F86QS
M92D["GT*:68@*"%D969I;F5D*"="05-%)RDI('L*("`@(&1E9FEN92@G0D%3
M12<L($A/4D1%7T)!4T4I.PI]"FEF("@D;W!T:6]N<ULQ75LP72`]/2`G:&5L
M<"<I('L*("`@('5S86=E*"D["B`@("!F;V]T97(H*3L*?0HD<VEL96YC92`]
M("1D96)U9R!\?"!/4U]724Y$3U=3(#\@)R<@.B`G(#(^("]D978O;G5L;"<[
M"B1R961I<E]E<G(@/2!/4U]724Y$3U=3(#\@)R<@.B`G(#(^)C$G.PHD;W!T
M:6]N<U]L:7-T(#T@87)R87DH"B`@("`G8VQE86YU<"<@("`@/3X@87)R87DH
M)VAL.FTZ)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<I*2P*("`@("=C
M;VUM:70G("`@("`]/B!A<G)A>2@G:&PZ;3IN33HG+"!A<G)A>2@G;6]D=6QE
M/2<L("=L;V-A;&4])RP@)VYE=R<L("=M97-S86=E/2<I*2P*("`@("=C;VUM
M:70M:&5L<"<]/B!A<G)A>2@G:&PZ;3IN33HG+"!A<G)A>2@G;6]D=6QE/2<L
M("=L;V-A;&4])RP@)VYE=R<L("=M97-S86=E/2<I*2P*("`@("=C;VUP96YD
M:75M)R`]/B!A<G)A>2@G:&PZ9#IA.B<L(&%R<F%Y*"=L;V-A;&4])RP@)V1I
M<F5C=&]R>3TG+"`G861D/2<I*2P*("`@("=E>'1R86-T)R`@("`]/B!A<G)A
M>2@G:&TZ)RP@87)R87DH)VUO9'5L93TG*2DL"B`@("`G:6YI="<@("`@("`@
M/3X@87)R87DH)VAL.FTZ;F,Z)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE
M/2<L("=N;RUC;VUP96YD:75M)RP@)V-O;7!E;F1I=6T])RDI+`H@("`@)VUE
M<F=E)R`@("`@(#T^(&%R<F%Y*"=H;#IM.F,Z;B<L(&%R<F%Y*"=M;V1U;&4]
M)RP@)VQO8V%L93TG+"`G8V]M<&5N9&EU;3TG+"`G;F\M8V]M<&5N9&EU;2<I
M*2P*("`@("=M86ME)R`@("`@("`]/B!A<G)A>2@G:&PZ;3IC.FYS)RP@87)R
M87DH)VUO9'5L93TG+"`G;&]C86QE/2<L("=C;VUP96YD:75M/2<L("=N;RUC
M;VUP96YD:75M)RP@)W-T871I<W1I8W,G*2DL"B`@("`G;6%K92UH96QP)R`@
M/3X@87)R87DH)VAL.FTZ)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<I
M*2P*("`@("=U<&1A=&4G("`@("`]/B!A<G)A>2@G:&PZ;3IC.FXG+"!A<G)A
M>2@G;6]D=6QE/2<L("=L;V-A;&4])RP@)V-O;7!E;F1I=6T])RP@)VYO+6-O
M;7!E;F1I=6TG*2DL"B`@("`G=7!D871E+6AE;'`G/3X@87)R87DH)VAL.FTZ
M)RP@87)R87DH)VUO9'5L93TG+"`G;&]C86QE/2<I*2P*("`@("=S=&%T=7,G
M("`@("`]/B!A<G)A>2@G:&PZ;3IO.B<L(&%R<F%Y*"=M;V1U;&4])RP@)VQO
M8V%L93TG+"`G;W5T<'5T/2<I*0HI.PHD;W!T:6]N<U]A<G(@/2`D;W!T:6]N
M<ULQ73L*)&-M9"`@("`@("`@(#T@87)R87E?<VAI9G0H)&]P=&EO;G-?87)R
M*3L*:68@*&%R<F%Y7VME>5]E>&ES=',H)&-M9"P@)&]P=&EO;G-?;&ES="DI
M('L*("`@("1C;61?;W!T:6]N<R`]($-O;G-O;&5?1V5T;W!T.CIG971O<'0H
M)&]P=&EO;G-?87)R+"`D;W!T:6]N<U]L:7-T6R1C;61=6S!=+"`D;W!T:6]N
M<U]L:7-T6R1C;61=6S%=*3L*("`@(&EF("A014%2.CII<T5R<F]R*"1C;61?
M;W!T:6]N<RDI('L*("`@("`@("`D8RT^=W)I=&5L;B@D8RT^<F5D*"=%<G)O
M<CH@)R`N('-T<E]R97!L86-E*"=#;VYS;VQE7T=E=&]P=#HG+"`G)RP@)&-M
M9%]O<'1I;VYS+3YG971-97-S86=E*"DI*2D["B`@("`@("`@)&,M/G=R:71E
M;&XH*3L*("`@("`@("!U<V%G92@I.PH@("`@("`@(&9O;W1E<B@I.PH@("`@
M?0I]"@HO*B!396%R8VAI;F<@87!P;&EC871I;VYS("HO"F-H96-K7V)I;F%R
M:65S*"D["@HD8RT^=W)I=&5L;BAS<')I;G1F*"=396%R8VAI;F<@2&]R9&4@
M87!P;&EC871I;VYS(&EN("5S)RP@0D%312DI.PHD9&ER<R`]('-E87)C:%]A
M<'!L:6-A=&EO;G,H*3L*"FEF("@D9&5B=6<I('L*("`@("1C+3YW<FET96QN
M*"=&;W5N9"!D:7)E8W1O<FEE<SHG*3L*("`@("1C+3YW<FET96QN*&EM<&QO
M9&4H(EQN(BP@)&1I<G,I*3L*?0H*)&%P<',@/2!S=')I<%]H;W)D92@D9&ER
M<RD["B1A<'!S6S!=(#T@)VAO<F1E)SL*)&,M/G=R:71E;&XH=V]R9'=R87`H
M<W!R:6YT9B@G1F]U;F0@87!P;&EC871I;VYS.B`E<R<L(&EM<&QO9&4H)RP@
M)RP@)&%P<',I*2DI.PHD8RT^=W)I=&5L;B@I.PH*<W=I=&-H("@D8VUD*2![
M"B`@("!C87-E("=C;&5A;G5P)SH*("`@(&-A<V4@)V-O;6UI="<Z"B`@("!C
M87-E("=C;VUP96YD:75M)SH*("`@(&-A<V4@)VUE<F=E)SH*("`@("`@("`D
M8VUD*"D["B`@("`@("`@8G)E86L["B`@("!C87-E("=C;VUM:70M:&5L<"<Z
M"B`@("`@("`@8V]M;6ET*'1R=64I.PH@("`@("`@(&)R96%K.PH@("`@8V%S
M92`G97AT<F%C="<Z"B`@("`@("`@>'1R86-T*"D["B`@("`@("`@8G)E86L[
M"B`@("!C87-E("=I;FET)SH*("`@("`@("!I;FET*"D["B`@("`@("`@)&,M
M/G=R:71E;&XH*3L*("`@("`@("!M97)G92@I.PH@("`@("`@(&)R96%K.PH@
M("`@8V%S92`G;6%K92<Z"B`@("`@("`@8VQE86YU<"AT<G5E*3L*("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@(&UA:V4H*3L*("`@("`@("!B<F5A
M:SL*("`@(&-A<V4@)VUA:V4M:&5L<"<Z"B`@("`@("`@;6%K95]H96QP*"D[
M"B`@("`@("`@8G)E86L["B`@("!C87-E("=U<&1A=&4G.@H@("`@("`@('AT
M<F%C="@I.PH@("`@("`@("1C+3YW<FET96QN*"D["B`@("`@("`@;65R9V4H
M*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@)W5P9&%T92UH96QP)SH*("`@
M("`@("!U<&1A=&5?:&5L<"@I.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G
M<W1A='5S)SH*+R\@("`@("`@('AT<F%C="@I.PH@("`@("`@(&UE<F=E*"D[
M"B\O("`@("`@("!S=&%T=7,H*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U
M;'0Z"B`@("`@("`@)&,M/G=R:71E;&XH)&,M/G)E9"@G17)R;W(Z("<I("X@
M<W!R:6YT9B@G56YK;F]W;B!C;VUM86YD.B`E<R<L("1C;60I*3L*("`@("`@
M("`D8RT^=W)I=&5L;B@I.PH@("`@("`@('5S86=E*"D["B`@("`@("`@9F]O
M=&5R*"D["GT*"F9O;W1E<B@I.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&\O:7-?25,N<&\`````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C,R,S0T(#$P-3$U-#,T,30R
M(#`Q-S4S,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````C($EC96QA;F1I8R!T<F%N<VQA=&EO;G,@9F]R(&1I<VL@<&%C:V%G
M92X*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!D:7-K('!A8VMA9V4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J
M96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"XU7&XB"B)297!O<G0M37-G:60M
M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#(M,#$M,3`@,3DZ,#`K,#$P,%QN(@HB4$\M4F5V:7-I;VXM
M1&%T93H@,C`P-2TQ,2TQ.2`R,#HS,RLP,#`P7&XB"B),87-T+51R86YS;&%T
M;W(Z($)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N97)P82YI<SY<;B(*(DQA
M;F=U86=E+51E86TZ($EC96QA;F1I8R`\<W5P<&]R=$!S;F5R<&$N:7,^7&XB
M"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.0IM
M<V=I9"`B(@HB("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES(&-O
M;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RXB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4S"FUS9VED("(B"B(@
M("UA+"`M+6%D9#U&24Q%("`@("`@("!!9&0@=&AI<R!03R!F:6QE('1O('1H
M92!C;VUP96YD:75M+B!5<V5F=6P@=&]<;B(*(B`@("`@("`@("`@("`@("`@
M("`@("`@(&EN8VQU9&4@82!C;VUP96YD:75M(&9R;VT@82!D:69F97)E;G0@
M8G)A;F-H('1O7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N
M97)A=&5D(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,3,*;7-G:60@(B(*(B`@+6(L("TM8F%S93TO4$%42"`@1G5L
M;"!P871H('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO
M=6QD(&)E7&XB"B(@("`@("`@("`@("`@("`@("`@('5S960N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV.0IM<V=I9"`B(@HB("`M8RP@
M+2UC;VUP96YD:75M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@
M=&AI<R!C;VUP96YD:75M(&9I;&5<;B(*(B`@("`@("`@("`@("`@("`@("`@
M("`@("!I;G-T96%D(&]F('1H92!D969A=6QT(&]N92`H8V]M<&5N9&EU;2YP
M;R!I;B!T:&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!H;W)D92]P
M;R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV,R!P;R]T<F%N<VQA=&EO;BYP:'`Z.#$@<&\O=')A;G-L871I;VXN<&AP
M.C@W"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H
M:7,@8V]M<&5N9&EU;2!F:6QE(&EN<W1E860@;V8@=&AE(&1E9F%U;'1<;B(*
M(B`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@*&-O;7!E;F1I=6TN<&\@
M:6X@=&AE(&AO<F1E+W!O(&1I<F5C=&]R>2DN(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,30*;7-G:60@(B`@+60L("TM9&5B=6<@("`@
M("`@4VAO=R!E<G)O<B!M97-S86=E<R!F<F]M('1H92!E>&5C=71E9"!B:6YA
M<FEE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4T"FUS
M9VED("(@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N9&EU
M;2!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$Q-0IM<V=I9"`B("`M:"P@+2UH96QP("`@("`@("!3:&]W
M('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#(@<&\O=')A;G-L871I;VXN<&AP.C8W('!O+W1R86YS;&%T
M:6]N+G!H<#HW-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S
M92!O;FQY('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#<@<&\O=')A;G-L871I;VXN<&AP.C8Q('!O+W1R86YS;&%T
M:6]N+G!H<#HW.0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#4*;7-G:60@(B`@
M+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-0IM<V=I9"`B("`M;"P@
M+2UL;V-A;&4];&Q?0T,@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C@*;7-G:60@(B`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!"=6EL9"!-3R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(
M;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#,*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A;G5P
M(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT.`IM<V=I9"`B(@HB("`M
M;2P@+2UM;V1U;&4]34]$54Q%("`@($-O;6UI="!T<F%N<VQA=&EO;G,@;VYL
M>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8R"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@
M;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#`*
M;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F:6QE
M<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S8*;7-G:60@(B(*(B`@+6TL("TM;6]D
M=6QE/4U/1%5,12`@("!5<&1A=&4@:&5L<"!F:6QE<R!O;FQY(&9O<B!T:&ES
M("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.#8*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!5<&1A
M=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-3@*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I
M(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<P
M"FUS9VED("(B"B(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@1&]N)W0@;65R
M9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&4@8V]M<&5N9&EU;2XB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8T('!O+W1R86YS;&%T:6]N
M+G!H<#HX,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#@*;7-G:60@(B`@+6XL("TM
M;F\M8V]M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S$*;7-G:60@(B`@+7,L
M("TM<W1A=&ES=&EC<R`@("`@("!3879E('1R86YS;&%T:6]N('-T871I<W1I
M8W,@:6X@82!L;V-A;"!F:6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3$V"FUS9VED("(@("UT+"`M+71E<W0@("`@("`@(%-H;W<@
M=&AE(&5X96-U=&5D(&-O;6UA;F1S(&)U="!D;VXG="!R=6X@86YY=&AI;F<N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4*;7-G:60@
M(B(*(B`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F<F]M
M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RXB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.`IM<V=I9"`B("!C;VUM:70@
M("`@("!#;VUM:70@=')A;G-L871I;VYS('1O('1H92!#5E,@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y"FUS9VED("(@
M(&-O;6UI="UH96QP($-O;6UI="!H96QP(&9I;&5S('1O('1H92!#5E,@<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3D*;7-G
M:60@(B(*(B`@8V]M<&5N9&EU;2`@4F5B=6EL9"!T:&4@8V]M<&5N9&EU;2!F
M:6QE+B!787)N:6YG.B!4:&ES(&]V97)W<FET97,@=&AE7&XB"B(@("`@("`@
M("`@("`@(&-U<G)E;G0@8V]M<&5N9&EU;2XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$P,`IM<V=I9"`B("!E>'1R86-T("`@("!'96YE
M<F%T92!03R!T96UP;&%T92`H+G!O="D@9FEL97,N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HY.`IM<V=I9"`B("!H96QP("`@("`@("!3
M:&]W('1H:7,@:&5L<"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3`Q"FUS9VED("(B"B(@(&EN:70@("`@("`@($-R96%T
M92!O;F4@;W(@;6]R92!03R!F:6QE<R!F;W(@82!N97<@;&]C86QE+B!787)N
M:6YG.B!4:&ES7&XB"B(@("`@("`@("`@("`@(&]V97)W<FET97,@=&AE(&5X
M:7-T:6YG(%!/(&9I;&5S(&]F('1H:7,@;&]C86QE+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`V"FUS9VED("(@(&UA:V4@("`@("`@
M($)U:6QD(&)I;F%R>2!-3R!F:6QE<R!F<F]M('1H92!S<&5C:69I960@4$\@
M9FEL97,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<*
M;7-G:60@(B(*(B`@;6%K92UH96QP("`@36%R:R!A;&P@96YT<FEE<R!I;B!T
M:&4@6$U,(&AE;'`@9FEL92!B96EN9R!U<"UT;RUD871E(&%N9%QN(@HB("`@
M("`@("`@("`@("!P<F5P87)E('1H92!F:6QE(&9O<B!T:&4@;F5X="!E>&5C
M=71I;VX@;V8@=7!D871E+6AE;'`N(%EO=5QN(@HB("`@("`@("`@("`@("!S
M:&]U;&0@;VYL>2!R=6X@;6%K92UH96QP($%&5$52('5P9&%T92UH96QP(&%N
M9"!R979I<VEN9R!T:&5<;B(*(B`@("`@("`@("`@("`@:&5L<"!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`R"FUS9VED("(B
M"B(@(&UE<F=E("`@("`@($UE<F=E('1H92!C=7)R96YT(%!/(&9I;&4@=VET
M:"!T:&4@8W5R<F5N="!03R!T96UP;&%T92!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`S"FUS9VED("(@('5P9&%T92`@("`@
M(%)U;B!E>'1R86-T(&%N9"!M97)G92!S97%U96YT+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`T"FUS9VED("(B"B(@('5P9&%T92UH
M96QP($5X=')A8W0@86QL(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R;VT@
M=&AE($5N9VQI<V@@6$U,(&AE;'!<;B(*(B`@("`@("`@("`@("`@9FEL92!A
M;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC
M.C$Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S8W"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3(T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H=&]D87DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-CD*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED("(@
M870@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3<V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&)Y=&5S('=R:71T96XN(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,C@T"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M(&]F("5D(&5N=')I97,@;6%R:V5D(&%S('5P+71O+61A=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T;W`N:6YC.C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C,R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R-"!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?=&]P+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S
M='(@(E9I\&AA;&1S8?!G97+P:7(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]A9W)E96UE;G1?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C4V."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8S-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(DUA<'!A;B!<(B5S7"(@97(@;OH@_F5G87(@=&EL
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3<@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#,@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,S`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@
M=&\@82!F<F5E+V)U<WD@<F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET871I
M;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.#<@<&\O=')A;G-L871I
M;VXN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!N;W0@=W)I
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`BP2!F:6UM
M(&WM;OIT;F$@9G)E<W1I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C$R,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,U,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!R97%U
M97-T<R!Y;W5R(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!P<F5S
M96YC92!A="`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B)60@=&EL("5D(&%F("5D('-K97ET=6TB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W:7-H97,@=&\@861D('1O
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!W
M:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!R96-E:79E('1H
M92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#DQ"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(").971F
M86YG86+S:R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#@S"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HX-S4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.#DY"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G
M(&ES(&YO="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HU-30*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)R5S)R!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G
M:7-T<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP
M.C$V-`HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G('1R964@<F5N9&5R97(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W
M"B,L('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!G
M<F]U<',@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@861D
M960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HU-2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!W87,@;F]T(&-R96%T960Z
M("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X-B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L
M(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M
M("5S('1O("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-CDQ"FUS9VED("(M
M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$S,C@@<&\O=')A;G-L871I;VXN<&AP.C$S,S`*;7-G:60@(BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM
M<V=S='(@(E5P<&S]<VEN9V%R(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y
M"B,L(&9U>GIY"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R(")5<'!L
M_7-I;F=A<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED
M("(R-"!H;W5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G
M97(N<&AP.C8Y"B,L(&9U>GIY"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B
M1GER<FD@8FQA\'/M\&$B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S0T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(CQG971T97AT/B!T86<@;F]T(&-L;W-E
M9"!I;B!F:6QE("5S+EQN(@HB3W!E;FEN9R!T86<@9F]U;F0@:6X@;&EN92`E
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3<*;7-G
M:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDQ-PIM
M<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$T,@IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`W-`IM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDY,@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW"FUS9VED(")!32!#
M;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z.`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS
M9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Q"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.0IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T
M('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!
M8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C0P"FUS9VED(")!8V-E<'0@<F5Q=65S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X,0IM
M<V=I9"`B06-C97!T960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN
M9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S4*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS
M9W-T<B`B3'EK:6QO<O`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S$T"B,L
M(&9U>GIY"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DCF:VMA;F1I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-3$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV,C4*(RP@9G5Z>GD*;7-G:60@(D%C=&EO;G,B"FUS9W-T<B`B0?!G97+P
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4T(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3,R"B,Z('1E;7!L871E<R]P;W)T86PO861D
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ
M-@IM<V=I9"`B061D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,C$T(&%D;6EN+V=R;W5P<RYP:'`Z,C$U"FUS9VED(")!9&0@0VAI;&0@1W)O
M=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HX-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@U"FUS9VED(")!
M9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C`X(&%D;6EN+V=R;W5P<RYP:'`Z,C`Y
M"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-S,@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S
M)R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3,@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`G)7,G(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@
M=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C4R.0IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,U"FUS9VED
M(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C,Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C,W"FUS9VED(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O
M;VLZ(@IM<V=S='(@(D+F=&$@[2!N971F86YG86+S:R`H)7,I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"B,L(&9U>GIY
M"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D+F=&$@
M[2!N971F86YG86+S:R`H)7,I(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G
M:60@(D%D9"!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D("<E<R<@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("4B"B)S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.38R"FUS9VED(")!9&1I;F<@;F5W(&9I;&5S('1O(')E
M<&]S:71O<GDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0V"B,L(&9U
M>GIY"FUS9VED(")!9&1R97-S(@IM<V=S='(@(E-E;F1A;F1A;F5T9F%N9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S8*;7-G:60@(D%D9')E
M<W,@0F]O:R(*;7-G<W1R(").971F86YG86+S:R(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,@IM<V=I9"`B061S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!
M;&EA<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W
M"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(M9L;"!S:V5Y=&DB
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,S@@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-PIM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3(S"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HT,#@*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*;7-G:60@
M(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.38*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#@*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS9VED
M(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(").971F86YG(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T
M96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA
M=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC
M86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM
M<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R
M("+3=.9K="!G:6QD:2!T:6QG<F5I;G0N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B
M06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C0Y"B,L(&9U>GIY"FUS9VED(")!;G-W97(B"FUS
M9W-T<B`B4W9A<F'P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B
M=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M
M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]5
M22YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@HC
M+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B0?!G97+P(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO
M;B!,:7-T(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M,SD*;7-G:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@
M=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R-`IM
M<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<W"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB
M"FUS9W-T<B`B87!R[6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM
M<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B17)T(/[Z
M('9I<W,@=6T@8?`@_OH@=FEL:FER(&=E<F$@_F5T=&$_(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.CD*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M)R5S)R!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R="#^^B!V:7-S
M('5M(&'P(/[Z('9I;&II<B!TYFUA(/YE<W-A(&WV<'!U/R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I
M;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$U
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,38V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,S$X"FUS9VED(")!='1A8VAE9"!I<R!A;B!I
M0V%L96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-0IM<V=I9"`B071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z,S@*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-3<W"B,L(&9U>GIY"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B5FGP:&5N
M9VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C@*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(N%G^G-T
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`BX6?Z
M<W0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS
M9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N
M;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM
M<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@
M<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM
M87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*
M(E9I<W1U;B!U<'!K87-T<VEN<R!M:7-T\VMS="X@3F5T_FKS;FYI;FX@:V]M
M(&UE\"!E9G1I<F9A<F%N9&D@=FEL;'4Z("5S(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H
M<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(X.0HC
M+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@
M(D5N9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM
M<V=S='(@(D5N9'5R=NUS=6X@;6ES:&5P<&'P:7-T+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S8X"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHX,PHC+"!F=7IZ>0IM<V=I9"`B
M079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5&EL=.9K87(@;F5T9F%N9V%B
MYFMU<CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8Q-`IM<V=I9"`B07=A:71I;F<@4F5S<&]N<V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E
M<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M
M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA
M9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`X"FUS
M9VED(")"87)E(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C
M=&]R>2`G)7,G(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"
M87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F5L:7IE(@IM<V=S
M='(@(E-TYG+P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD
M87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")"
M;&]C:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"B,L
M(&9U>GIY"FUS9VED(")";VQD(@IM<V=S='(@(DUE9VEN;>%L(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3@X"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DWV<'!U
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B3?9P<'5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B
M"FUS9W-T<B`B0N;P:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW-0HC+"!F=7IZ>0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@
M(D+F\&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U
M<W-A;&%M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO
M9'5L92`E<RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C<S"B,L('!H<"UF;W)M870*;7-G:60@(D)U:6QD:6YG(&QO8V%L92`E<RXN
M+B`B"FUS9W-T<B`B0GEG9VD@;OH@;&]C86QE("5S("XN+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&
M87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,PIM<V=I
M9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S(*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I
M<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#
M7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-38@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$T-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,PHC+"!F=7IZ>0IM<V=I
M9"`B0V%L;2(*;7-G<W1R(")(YG1T82!V:?`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M
M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC
M86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$W"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3<*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")(YG1T82!V:?`B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B
M0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,C4V"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!D96QE=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#
M86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*
M;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A
M<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D
M:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964N<&AP.C$Q,B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HU.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4Q,PIM<V=I9"`B
M(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D
M(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@
M=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"B,L(&9U>GIY"FUS
M9VED(")#87!T:6]N(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA
M8F5L<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G
M:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L
M;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0*
M;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D+Z
M82!T:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*
M;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS
M9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I
M8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z
M>GD*;7-G:60@(D-H860B"FUS9W-T<B`B169N:7/^<N'P=7(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4Y-@HC+"!F
M=7IZ>0IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@(E!E<G/S;G5L96=T
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM<V=S='(@
M(D)R97ET82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-@HC+"!F=7IZ
M>0IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B
M"B)E;6%I;',N(@IM<V=S='(@(B(*(DCI<B!G971U<B#^^B!B<F5Y='0@_G;M
M(&AV8?!A(&YA9FXL(&YE=&9A;F<@;V<@<VME>71I<V)O=&X@:V5M=7(@9G)A
M;2#M("(*(G-K97ET=6T@_NUN=6TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B
M0VAA<B(*;7-G<W1R(")"<F5Y=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7W1O<"YI;F,Z,3,*;7-G:60@(D-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6QE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*(RP@9G5Z>GD*;7-G
M:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(E-E;6IA(&[]='0@<VME
M>71I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT-3(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HV,C8*(RP@9G5Z>GD*;7-G:60@(D-H;V]S92!A;B!A8W1I;VXZ
M(@IM<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C@X"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HV,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HX-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI;F<@=7`@
M4$\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#8W"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%N
M:6YG('5P(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B2')E:6YS82!T:6P@[2!L
M;V-A;&4@)7,@+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3(*;7-G:60@(D-L96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L
M96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE
M87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I
M9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")#;&5A<FEN9R!,
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I
M8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#,*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#(*;7-G:60@(D-L;W5D
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-`IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"B,L(&9U
M>GIY"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B069R:70B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T
M"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*(RP@9G5Z>GD*;7-G
M:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B3&]K82!M]G!P=2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C@*(RP@9G5Z>GD*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(DQO:V$@;?9P<'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C
M;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y-PHC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDX"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC
M:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M-3`*(RP@9G5Z>GD*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B
M5F5L9'4@8?!G97+P.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.#,*(RP@9G5Z>GD*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")396UJ82(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,X"FUS
M9VED(")#;VUM86YD(&]P=&EO;G,Z(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HY-PIM<V=I9"`B0V]M;6%N9',Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.0IM<V=I9"`B0V]M
M;65N="(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`P,`IM
M<V=I9"`B0V]M;6ET=&EN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"B,L(&9U>GIY"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(E-E;6IA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(S.0HC+"!F=7IZ>0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R(")!9G)I="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-CDW"B,L(&9U>GIY"FUS9VED(")#;VUP;&5T960B"FUS
M9W-T<B`B4V5M:F$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O;7!O
M<V4@365S<V%G92`H)7,I(@IM<V=S='(@(E-E;6IA('-K97ET:2`H)7,I(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#
M;VUP=71E<G,B"FUS9W-T<B`B4V5M:F$B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(T-PIM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HX.0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S<*(RP@9G5Z>GD*;7-G:60@
M(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B3'EK:6QO<O`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED
M(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R
M(")%;F1U<G;M<W5N(&UI<VAE<'!A\&ES="XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN
M96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(D5N9'5R=NUS=6X@;6ES:&5P<&'P
M:7-T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<W-@IM
M<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R
M=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HW-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-C(*
M;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYE=&9A
M;F=I\"!<(B5S7"(@=F%R(&+F='0@[2!N971F86YG86+S:VEN82(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-38@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F("<E<R<B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(D-O
M;VMI92(*;7-G<W1R(")396UJ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0IM<V=I9"`B0V]P>2(*;7-G
M<W1R(")!9G)I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S8*(RP@9G5Z>GD*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM
M<V=S='(@(E9E;&1U(&'P9V5R\#HB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>6EN9R`E<R!T
M;R`E<R(*;7-G<W1R(")496YG:F%S="`E<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,#,P"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4$=0('-I
M9VX@;65S<V%G92XB"FUS9W-T<B`BWOH@X71T(#$@;OUT="!S:V5Y=&DN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I
M9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HW,`IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B`G)7,G('5S:6YG($944#H@)7,B"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.#<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C8X,2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D:7)E8W1O
M<GD@9F]R(&QO8V%L92`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$P,@IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y
M<'0@4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#4*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B1V%T(&5K:VD@97ET="!S:V5Y='5M(&9RX2`E<SH@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B1V%T(&5K:VD@97ET="!S:V5Y
M='5M(&9RX2`E<SH@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R(")'870@96MK
M:2!E>71T('-K97ET=6T@9G+A("5S.B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.CDS-0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@R"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C0Y,@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-0IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L
M:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S
M=')A=&5G>2`G)7,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S`U"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8W-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)R5S)R!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R(")'870@96MK:2!E>71T('-K97ET=6T@9G+A("5S
M.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#@S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD(&YO="!R971R:65V
M92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER("<E<R<N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I
M;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A
M;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C@P"FUS9VED(")#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U
M;FQI;FL@)R5S)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<R(*;7-G<W1R
M(")'870@96MK:2!E>71T('-K97ET=6T@9G+A("5S.B`E<R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-38*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9&XG="!G
M:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B`G)7,G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#(T"B,L(&9U>GIY"FUS9VED(")#;W5N=&5D('1E>'0B"FUS
M9W-T<B`B3&5I\'+I='1U<B!T97AT:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C<*;7-G:60@(D-O=7)S
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PHC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS9VED(")#<F5A=&4B"FUS9W-T
M<B`B0OIA('1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@
M;&EN:R(*;7-G<W1R(")"^F$@=&EL(@H*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B0W)E871E(&$@
M;F5W(&]N92(*;7-G<W1R(")"^F$@=&EL(&[]:F$@;?9P<'4@*')U<VQA:_9R
M9G4I('5N9&ER(&5Y9&0@<VME>71I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(D-R96%T92!S
M=6(@9F]L9&5R<R(*;7-G<W1R(")"^F$@=&EL(&WV<'!U(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3,V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C$T"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S0*;7-G:60@(D-R961I
M="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0HC+"!F=7IZ
M>0IM<V=I9"`B0W)O871I82(*;7-G<W1R(")"^F$@=&EL(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C8*;7-G:60@(D-U<G)E;G0@4&AA<V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"B,L(&9U
M>GIY"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B3&5I\'+I='1U<B!T
M97AT:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,PIM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!7
M96%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S<*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B
M4W1I;&QA(&'P9V5R\&ER('-E;2!E<G4@9G)A;6MVYFUD87(@_F5G87(@_OH@
M=&5N9VES="`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0R,R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU.0HC+"!F=7IZ>0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`BVG1L:70B"@HC
M.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDW"FUS
M9VED(")$871E(@IM<V=S='(@(D1A9W,B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B1&%T92!296-E
M:79E9"(*;7-G<W1R(")-\W1T96MI\"#^86YN.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$*(RP@
M9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")M8>TB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*(RP@9G5Z
M>GD*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(D5Y\&$@;?9P<'4H
M;2DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S@U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B9&5S96UB97(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V
M"B,L(&9U>GIY"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B9&5S
M96UB97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8X-0HC+"!F=7IZ>0IM<V=I9"`B1&5C;&EN960B"FUS9W-T<B`B
M17ET="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP
M.C$Q,0HC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")%>?!A(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*
M(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B3F]T82!S
M:N%L9F=E9FGP(&=I;&1I(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")3
M:N%L9F=E9FGP(&ME;FYI;6%R:R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$Q.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-@IM<V=I9"`B
M1&5F875L="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$Y-PIM<V=I9"`B1&5F875L="!P97)M:7-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*
M(RP@9G5Z>GD*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(E-K:6QG<F5I
M;FEN9R#A('/M=7)E9VQU(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HV-#,*(RP@9G5Z>GD*;7-G:60@(D1E;&5G871E
M('!O<VET:6]N(@IM<V=S='(@(E-E;6IA(&[]='0@<VME>71I(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3,*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R(")%>71T(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR.34@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,34*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,S(@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY.2!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*
M;7-G:60@(D1E;&5T92(*;7-G<W1R(")%>?!A(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%>?!A(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HV,R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G
M<W1R(")%>?!A('-K97ET=6TB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<R(*;7-G<W1R(")%>61D('-K97ET:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(D5Y\&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S
M"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(D5Y\&$B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4P(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@)R5S)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C,Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("<E<R<@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B
M"FUS9W-T<B`B17GP82(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N
M=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>2(*;7-G<W1R(")696QD=2!K96YN:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@HC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")3
M=&EL;&$@;OIV97)A;F1I('3M;6%B96QT:2XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*
M;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4W1I;&QA
M(&[Z=F5R86YD:2!T[6UA8F5L=&DN(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HT.`IM<V=I9"`B1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S
M971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C4R"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@
M(D5Y\&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C0R"FUS9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S$*;7-G:60@
M(D1E;GD@<F5Q=65S="!F;W(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q,"!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,30@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(T"FUS9VED
M(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B5F%L:V]S=&ER(&YO=&%N9&$B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0HC+"!F=7IZ>0IM<V=I9"`B1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B(@HBWF5T=&$@<VME>71I(&AE9G5R('9E<FGP('-E;G0@=&EL(&ME
M<F9I<W5M<VKS;F%R('-E;2!T:6QK>6YN:6YG('5M(')U<VQP\W-T("(*(BA3
M4$%-*2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DU"FUS9VED
M(")$979E;&]P;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q-0IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,CDR"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@
M:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.30*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@
M(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I
M<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,Y"B,L(&9U>GIY"FUS9VED(")$:7)E8W1O<GDB"FUS
M9W-T<B`B4O;P=6YA<N%T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-38*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P
M=&EO;G,B"FUS9W-T<B`BVG1L:71S<W1I;&QI;F=A<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z.#,*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R,0HC
M+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`BVG1L:70B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$
M:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q
M-0HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R(")%;F1U
M<G9E:VIA(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ.2!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E<R!T:&4@9FER
M<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K
M('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI
M;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#,U"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R(")3YFMJ
M82!Y9FER(.$@=FEN;G5S=/;P(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D
M("5S(@IM<V=S='(@(E/F:VIA("5S('EF:7(@X2!V:6YN=7-T]O`B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38U"FUS9VED(")$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P
M(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C,Y.0HC+"!F=7IZ>0IM<V=I9"`B12U-86EL
M(@IM<V=S='(@(E#S<W1M87!P82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@
M(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,CDT('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T
M97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET(@IM<V=S='(@(D)R
M97ET82(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$X."!A9&UI;B]G<F]U
M<',N<&AP.C(Q-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C8R(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.#8*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!0
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#0@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!P97)M:7-S:6]N<R!F;W(@)R5S)R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*
M;7-G<W1R(")!\&=E<O`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM
M<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-#`*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B3F5T9F%N9R(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*(RP@9G5Z>GD*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(").971F
M86YG(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B
M16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`HC+"!F=7IZ>0IM
M<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*
M(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(L%R[?!A
M;F1I('-K97ET:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M.#@*(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5.9M
M82!R=7-L86OV<F9U(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N
M<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E3F;6$@<G5S;&%K]G)F=6WV<'!U(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S,@IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G
M97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-#@*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-3,*;7-G
M:60@(D5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C`V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(D5N
M9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3$*;7-G:60@(B(*
M(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@
M87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R
M92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M
M9&%T92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HW
M.0IM<V=I9"`B17)R;W(B"FUS9W-T<B`B5FEL;&$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W.`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!S96YD:6YG(')E<&QY.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`T"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R`G)7,G+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU
M,C(@<&\O=')A;G-L871I;VXN<&AP.C$S-S<*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$T,S@@<&\O=')A;G-L871I;VXN<&AP.C$U,#$*(RP@9G5Z>GD*;7-G
M:60@(D5R<F]R.B`B"FUS9W-T<B`B5FEL;&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO
M<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM
M<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD*;7-G:60@(D5V97)Y(#$U(&UI;G5T
M97,B"FUS9W-T<B`BP2!K;W)T97)S(&9R97-T:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-SD*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(#(@;6EN=71E
M<R(*;7-G<W1R("+!(&9I;6T@;>UN^G1N82!F<F5S=&DB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*
M;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`BP2`S,"!S96LN(&9R
M97-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C@@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(L$@9FEM;2!M[6[Z=&YA(&9R97-T:2(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(D5V
M97)Y($QO9VEN(@IM<V=S='(@(L$@;>UN^G1U(&9R97-T:2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS,S`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*
M;7-G<W1R("+!(&CA;&9T[6UA(&9R97-T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(L$@;>UN^G1U(&9R97-T:2(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(X"FUS9VED(")%>&%M<&QE('9A
M;'5E<SHB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D
M;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS
M9VED(")%>&5C=71E(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HR.3D@<&\O=')A;G-L871I;VXN<&AP.C,R,"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,S8R"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-#$@<&\O=')A;G-L871I
M;VXN<&AP.C4T,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-C`Q"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HW,#(@<&\O=')A;G-L871I;VXN<&AP.C<S-R!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-SDX"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-S4@<&\O
M=')A;G-L871I;VXN<&AP.CDY-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Q-@IM
M<V=I9"`B17AE8W5T:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HS.30*(RP@9G5Z>GD*;7-G:60@(D5X<&%N
M9"(*;7-G<W1R(")/<&YA(&%L;&%R(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S
M:61E8F%R+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B3W!N82!M]G!P=2(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED
M(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y
M.`IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N
M="(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(D5X=')A8W1I;F<@9G)O;2`E<RXN+B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C8P"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV,#@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-C0Q"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,38*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T
M86P@17)R;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I
M9"`B1F5B<G5A<GDB"FUS9W-T<B`B9F5B<OIA<B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C$X"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3@*;7-G:60@(D9E96QS
M(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-PIM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*
M;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8T"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C0*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S0S"B,L(&9U>GIY"FUS9VED(")&:6QE($UA;F%G
M97(B"FUS9W-T<B`B4VMRX7)N869N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")3
M:W+A<FYA9FXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DY"B,L
M(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")E;F=I;B!R
M96=L82!V86QI;B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.3$*
M(RP@9G5Z>GD*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E)E:71U<B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U,PIM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX-@IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")3[75R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B1FEN;&%N
M9"(*;7-G<W1R(")&:6YN82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S$*
M(RP@9G5Z>GD*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T<B`B1GER<W1A('/M
M\&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<V"B,L(&9U>GIY"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@
M(D9Y<G-T82!S[?!A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S.0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,30*;7-G
M:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3D*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C$U."!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T
M('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S,R"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S@*;7-G:60@(B(*(D9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-0IM<V=I9"`B1F]R
M9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.3D*(RP@9G5Z>GD*;7-G:60@(D9O<FUS(@IM<V=S
M='(@(D9RX2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B
M1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@
M,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDP
M"B,L(&9U>GIY"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B3?9P<'5R(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P-@HC+"!F=7IZ>0IM<V=I9"`B
M1F]R=V%R9',B"FUS9W-T<B`BP69R86US96YD82(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ-#4X"B,L('!H<"UF;W)M870*;7-G:60@(D9O=6YD(&%P<&QI
M8V%T:6]N<SH@)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-3(*;7-G:60@(D9O=6YD(&1I<F5C=&]R:65S.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"B,L
M(&9U>GIY"FUS9VED(")&<B(*;7-G<W1R(")&<N$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY
M"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3F%F;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@
M9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R(")(YG1T82!V:?`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@
M365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#$W"B,L(&9U>GIY"FUS9VED(")&
M<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T<B`B57!P;/US:6YG87(@;F5T
M_FKS;G,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C0R-PIM<V=I9"`B1G)E92]"=7-Y(%)E<&QY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#(R"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(W,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C,T
M,0IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D9RX2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*(RP@9G5Z>GD*
M;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")&<N$B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$
M97-C<FEP=&EO;B(*;7-G<W1R(")3:VEL9W)E:6YI;F<@X2!S[75R96=L=2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3@Q"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHS.0HC+"!F=7IZ>0IM<V=I9"`B1G5L
M;"!.86UE(@IM<V=S='(@(DYA9FXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-C4W"FUS9VED(")&=7IZ>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@
M=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I
M9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M
M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG
M+FAT;6PZ,3`*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1V5N97)A=&EN9R!S=&%T=7,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$S-S$*;7-G:60@(D=E=&]P="!%<G)O<CH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I9"`B
M1VEV96X@3F%M92(*;7-G<W1R(")3:W+A<FYA9FXB"@HC.B!T96UP;&%T97,O
M<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0HC+"!F=7IZ>0IM<V=I
M9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("),96ET82#M('-K97ET=6TB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"FUS
M9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T
M"B,L(&9U>GIY"FUS9VED(")'<F5N861A(@IM<V=S='(@(D5F;FES_G+A\'5R
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"YP:'`Z-3@*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(W-PIM<V=I9"`B1W)O=7`@<&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C4P"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I
M9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*
M;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D
M:70N<&AP.C$R-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-0HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ,C@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,#8*;7-G:60@
M(D=U97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'=6EN96$B"FUS9W-T<B`B
M:OIN[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S,Q
M"FUS9VED(")(2"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP
M.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDY"FUS9VED
M(")(87-H+4%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B2&%Z92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDS-@IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92](96QP+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$X-0HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R
M(")(:N%L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S8*(RP@9G5Z>GD*;7-G
M:60@(DAE;'!E<B(*;7-G<W1R(")(:N%L<"(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HY-0IM<V=I9"`B(@HB2&5L<&5R(&%P<&QI8V%T:6]N('1O(&-R96%T
M92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@2&]R9&5<;B(*
M(F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RY<;B(*(D9O<B!A;B!I
M;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM
M<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M-PIM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&ES=&]R>2](:7-T;W)Y+G!H<#HS,C$*;7-G:60@(DAI<W1O<GD@96YT<GD@
M;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8SHT"FUS9VED(")(;U]M92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C8*
M;7-G:60@(DAO;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,34U"B,L(&9U>GIY"FUS9VED(")(;VUE($%D
M9')E<W,B"FUS9W-T<B`B4V5N9&%N9&%N971F86YG(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R(")4[6UA8F5L=&DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HV,@IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C$S,CD*;7-G:60@(DAO<F1E('1R86YS;&%T:6]N
M(&=E;F5R871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C<W
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R,#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B36%P<&%N(%PB)7-<(B!V87(@96YD=7)N969N9"!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,34T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY('-Y;F-H
M<F]N:7-E9"`E<R!<(B5S7"(B"FUS9W-T<B`B7"(E<UPB('9A<B!G97+P('9I
M<FLB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT.#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C`U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$U,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,C@R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C,Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(
M;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N
M:6YC.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T
M:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W
M;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C@*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C$*;7-G:60@(DAU
M;6ED:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Q"FUS9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,C,R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,CDR"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,C`*(RP@9G5Z>GD*;7-G:60@
M(DE0($%D9')E<W,B"FUS9W-T<B`B4V5N9&%N9&%N971F86YG(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D
M<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO
M="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*
M;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(Y"FUS9VED("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C8*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T
M<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S8W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,`IM<V=I9"`B
M261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")+96YN:6YA9FXZ(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3@V"B,L('!H<"UF;W)M
M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-0IM<V=I9"`B(@HB268@>6]U(&1O
M;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO
M=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X"FUS9VED("(B"B))9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0
M<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS
M9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHR,`HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHW,PIM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C<P,0IM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*
M;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-`IM<V=I9"`B26YC
M;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC+"!F
M=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B4VSA\'4@:6YN(&YO=&%N9&%N869N(&]G(&QY:VQI;W+P
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*
M(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO
M=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A
M<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD
M:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,30Q('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("));F1I=FED=6%L
M(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I
M9"`B26YD;VYE<VEA(@IM<V=S='(@(F5N9VEN;B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@
M(DEN9F\B"FUS9W-T<B`B2'5N9'-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(T,PHC+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T
M<B`B57!P;/US:6YG87(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@R"B,L
M('!H<"UF;W)M870*;7-G:60@(DEN:71I86QI>FEN9R!M;V1U;&4@)7,N+BX@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T($-?;VQU;6X@069T
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B4VME>71I('-E;2!B^FGP(&5R(&'P('-V87)A
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,`IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R
M="!796(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(DEN<V5R="!?
M0V]L=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE
M(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N
M<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Y"FUS9VED("))
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B
M26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F=7IZ>0IM
M<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DWS='1E:VGP(&9Y
M<FER.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R(")3
M:V5Y=&D@<V5M(&+Z:?`@97(@8?`@<W9A<F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN
M<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED
M("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS
M9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@
M(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,C`*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I
M9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,T"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS
M9VED("));G1E9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(X
M,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C,U,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@
M8V]M<&]N96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@541(
M+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("))
M;G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(DEN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HT,PIM<V=I9"`B26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED("));G9A
M;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDR"B,L('!H<"UF;W)M870*;7-G
M:60@(DEN=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`T,R!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R,C`*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$P"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R,@IM
M<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I
M9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"B,L(&9U>GIY"FUS9VED("))<F5L86YD(@IM<V=S='(@(D5F;FES_G+A\'5R
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES
M;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM
M<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S0*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU
M87)Y(@IM<V=S='(@(FIA;OIA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P
M86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G
M:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM
M<V=I9"`B2G5L>2(*;7-G<W1R(")J^FSM(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B
M:OIN[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*
M;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED
M(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I
M9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(T-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B97)O<R!S
M97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,SDW"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@1FEN
M9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,SDX"FUS9VED(")+97D@3&5N9W1H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R
M(")3:V5Y=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW
M,C8*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I
M9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+
M;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B
M2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER
M9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N
M:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B069T96YG
M:F%S="(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S8@<&\O=')A
M;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B5'5N
M9W5MX6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*(RP@9G5Z>GD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R(")S
M[?!A<W1A(&)L<RXB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@@;&EB+T)L
M;V-K+VUO;VXN<&AP.CDP"B,L(&9U>GIY"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B<^WP87-T82!B;',N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-#D*;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B<^WP87-T('5P
M<&;F<G0Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-C8V"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E/M\&%S
M="!T96YG<W0Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B
M"FUS9W-T<B`B4^WP87-T('1E;F=S=#H@)7,@9G+A("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z-C8S"FUS9VED("),87-T(&QO9VEN.B!.979E
M<B(*;7-G<W1R(")3[?!A<W0@=&5N9W-T.B!!;&1R96DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971T;&%N9"(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D9R86US971N:6YG(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B
M3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3.UB86YO;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM
M<V=I9"`B3&5F="(*;7-G<W1R(")6:6YS=')I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F
M="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O
M=&AO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB97)I82(*
M;7-G<W1R("),[6)E<NUA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@
M07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B3&EG:'0@1')I>GIL
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,PIM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PIM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C@*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*
M;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I;"!A
M9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B
M3&ES="!$871A8F%S97,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B3&ES="!486)L
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DAJX6QP(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU
M.3(*;7-G:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M
M56YS=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHT"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*
M;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS
M9VED("),:71H=6%N:6$B"FUS9W-T<B`B3&ET:.%E;B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,S,X"FUS9VED("),;V%D:6YG(&QI8G)A<FEE<RXN+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C@S"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S@*;7-G:60@(DQO8V%L('1I
M;64Z("(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*
M;7-G:60@(DQO8V%L92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W,"!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R
M(&QI8B]";&]C:R]M971A<BYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(D'P9V5R\"(*"B,Z(&QO9VEN+G!H<#HQ-34@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$V-"!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R(")496YG:F%S="(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`BVG1S:W+A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`B5F5R:V5F;FD@=FGP('1E;F=I;F=U(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3$Q"B,L(&9U>GIY"FUS9VED("),;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B)496YG:6YG(&UI<W3S:W-T+B!,
M[6ML96=A(&5R(&YO=&%N9&%N869N(/YI='0@9?!A(&QY:VEL;W+P(')A;F=T
M(&EN;G-L96=I\"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY,#<*
M(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B16YD=7)V
M[7-U;B!M:7-H97!P8?!I<W0N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,W,`IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I
M9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K
M(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S0R"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS-S,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(U,`IM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!
M='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS9VED
M(")-86=I8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-S@*;7-G:60@(DUA:6PB"FUS9W-T<B`B5F5F</-S='5R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-PIM<V=I9"`B36%I;"!!9&UI;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-3<*;7-G:60@(DUA:V4@
M<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R
M(&EN8VQU9&4@<&%T:"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C8W."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-86MI;F<@9&ER96-T;W)Y("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%V[2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L8>US[6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(D=RYFYH]F;P
M865Y:F%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA
M;.TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3<X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4U"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H
M(@IM<V=S='(@(FUA<G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-87)G:6XB"FUS9W-T<B`B
M4W#A<W/M82(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O
M<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R(")-87)S:&%L;&5Y:F%R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3$Q"B,L(&9U>GIY"FUS9VED
M(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B4W;F\&DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B3>%R[71A;NUA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS
M9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I
M9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.38*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S@*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-
M87DB"FUS9W-T<B`B;6'M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I
M9"`B36%Y;W1T92(*;7-G<W1R(")M8>TB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3,Q"FUS9VED
M(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,PIM<V=I9"`B
M365E=&EN9R!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.0IM<V=I9"`B365E
M=&EN9R!0<F]P;W-A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-0IM<V=I9"`B365E=&EN9R!2
M97!L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4Q-`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU,3D*;7-G:60@(DUE971I;F<@57!D871E(%)E<75E<W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ
M.0IM<V=I9"`B365M8F5R<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S8X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HU,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!A
M;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365R9VEN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HW.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R
M9VEN9R!T:&4@4$\@9FEL92!F;W(@)7,@=&\@=&AE(&-O;7!E;F1I=6TN+BX@
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B365R9VEN9R!T<F%N<VQA=&EO;B!F;W(@;6]D=6QE
M("5S+BXN(@IM<V=S='(@(E-A;65I;F$@_OWP:6YG87(@9GER:7(@)7,@96EN
M:6YG=6YA+BXN(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`IM<V=I9"`B365S<V%G92(*
M;7-G<W1R(")3:V5Y=&DB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B365S<V%G
M92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V.`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C8*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4Y"FUS9VED(")-
M97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$P
M"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*;7-G
M:60@(DUE=&AO9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@)R5S)R!I<R!N;W0@9&5F:6YE
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,PIM<V=I9"`B365T<FEC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE
M>.UK\R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T
M960@4W1A=&5S(&]F(@IM<V=S='(@(DWM:W+S;F5S[6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@
M(DUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#`*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,3<*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")3<&5G;&$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`BW6UI<VQE9W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8W,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,SD*;7-G:60@(DUI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$Q-`IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM
M<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU-PIM
M<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDS"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DWA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<Q"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4R"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(D)R97ET82!S;//P
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PIM<V=I9"`B36]D=6QE(@IM
M<V=S='(@(D5I;FEN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B3?-N86OS(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`R"FUS9VED(")-;VYT:"!A;F0@
M>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G
M:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Q"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED(")-;W-T
M;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#(X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B1FQY
M=&IA(&YI\'5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-#,R"B,L(&9U>GIY"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B1FQY
M=&IA('5P<"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0S-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,C0*;7-G:60@(DUO=F4@57`B
M"FUS9W-T<B`B1FQY=&IA('5P<"(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.3<*(RP@9G5Z>GD*;7-G:60@(DUO=F4@9&]W
M;B(*;7-G<W1R(")FYG)A(&YI\'5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#DW"B,L(&9U>GIY"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(F;F<F$@=7!P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA
M;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R"FUS9VED
M(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S,U"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3(T"FUS9VED(")-
M>2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O86=R965M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L($D@1&\@3D]4
M($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C,Y-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3`R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3@S"FUS9VED(").86UE(@IM<V=S='(@(DYA9FXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C<P-@HC+"!F=7IZ>0IM<V=I9"`B3F5E
M9',@06-T:6]N(@IM<V=S='(@(D'P9V5R\"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F
M=7IZ>0IM<V=I9"`B3F5P86PB"FUS9W-T<B`B3OUR('#S<W1U<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED
M(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R
M"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!C;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,S8*(RP@9G5Z>GD*;7-G:60@(DYE='=O<FLB"FUS9W-T
M<B`B3OUT="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S8*;7-G:60@(DYE=F5R(@IM<V=S='(@(D%L9')E:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR
M-PIM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B3F5W($UO;VXB"FUS9W-T
M<B`B3OUR('#S<W1U<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3F5W(%IE86QA
M;F0B"FUS9W-T<B`B3OUR('#S<W1U<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B
M;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-3@*(RP@9G5Z>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`B3OUT
M="(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3(*;7-G:60@(DYE
M=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,C$@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#8*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S<@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,S(*;7-G:60@(DYE>'0B"FUS9W-T<B`B3N9S=&$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@4&AA
M<V4B"FUS9W-T<B`B3N9S=&$@<^WP82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S8X(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S<R"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B5F%L
M:V]S=&ER(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C$P,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3N9S=&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(D%L9')E
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"FUS9VED(").:6=H
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@X.`IM<V=I9"`B3F\B"FUS9W-T<B`B3F5I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+V1I9F8N:'1M;#HQ-@IM<V=I9"`B3F\@879A:6QA8FQE(&-O
M;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B3F\@8F%T
M8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C(S,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HR-3(*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D
M('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;6-A;"YP:'`Z-3`*;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@
M9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C4U"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N
M(@IM<V=S='(@(D)R97ET82(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30P"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@
M8F4@861D960@8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q"FUS9VED(").;R!C:&EL9')E;B!C
M86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V]M;6%N9"!S<&5C:69I960N(@IM<V=S='(@(D5N9VEN(&UA<'!A('9A<B!T
M:6QG<F5I;F0B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W-PHC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<T,0IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($94
M4"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-3<U"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<P-`IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S,*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G
M<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(").;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X:7-T<R!I
M;B!T:&4@;W)I9VEN86P@:&5L<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S$*;7-G:60@(DYO(&9I;&4@
M=7!L;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C<Q"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C0Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z-3(R"B,L
M(&9U>GIY"FUS9VED(").;R!L;V-A;&4@<W!E8VEF:65D+B(*;7-G<W1R(")%
M;F=I;B!M87!P82!V87(@=&EL9W)E:6YD(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$R,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C$*;7-G:60@(DYO(&QO8V%T:6]N(&ES
M('-E="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(D[]('-K97ET:2(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"B,L(&9U>GIY
M"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B96YG:6YN('1E
M>'1I('1I;&=R96EN9'5R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E
M<B!S<&5C:69I960N(@IM<V=S='(@(F5N9VEN;B!T97AT:2!T:6QG<F5I;F1U
M<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F
M96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L
M+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B
M3F\@<VED97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$S,`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I
M;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@
M(E-LX?!U(&EN;B!N;W1A;F1A;F%F;B!O9R!L>6ML:6]R\"(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!8
M34P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY,#8*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3,T"FUS9VED(").;R!V86QU97,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B
M3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!2
M96=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C`T"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-38P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R(")%;F=I;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@
M*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N
M+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYO
M<G=A>2(*;7-G<W1R("+!9G)A;7-E;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E
M<B(*;7-G<W1R(")%:VMI('5P<&MA<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$*(RP@9G5Z
M>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(")2]O!U;F%RX71T
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV
M,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DYO
M="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16MK:2!E>71T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B3F]T('-E="(*;7-G<W1R(")%:VMI(&5Y='0B"@HC.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T,PHC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$U
M.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C(V(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR-#(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(U-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C<T"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HS,#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-#0T(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU,3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4S,`IM<V=I9"`B3F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,38Q"B,L(&9U>GIY"FUS9VED(").;W1E<R(*;7-G<W1R(")%;F=I;B(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*(RP@9G5Z>GD*
M;7-G:60@(DYO=&EC92(*;7-G<W1R(")%;F=I;B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#0*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*
M;7-G<W1R(")N\W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-#8*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<B(*;7-G<W1R(")N\W9E;6)E
M<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S`*;7-G:60@(DYU
M;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4P('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@
M;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T."!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#,*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-#@S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C8S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-"!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,S0X"FUS9VED(")/2R(*;7-G<W1R("+-(&QA9VDB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$T"B,L(&9U>GIY
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B169N:2(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HR,34*;7-G:60@(D]B:F5C="!C<F5A=&]R
M('!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O
M8F5R(@IM<V=S='(@(F]K=/-B97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.3@*;7-G:60@(D]F9FEC92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G
M:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I
M9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV
M-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U
M"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*
M;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R
M871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`P"FUS9VED(")/<'1I;VYA;"!0
M87)T:6-I<&%N="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(E9A;'-T:6QL
M:6YG87(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P
M=&EO;G,@9F]R("5S(@IM<V=S='(@(E9A;'-T:6QL:6YG87(B"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")/<'1I;VYS.B(*
M;7-G<W1R(")686QS=&EL;&EN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38W"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A
M=&EO;F%L(%5N:70B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$R.0IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA
M=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`HC+"!F=7IZ
M>0IM<V=I9"`B3W1H97(B"FUS9W-T<B`B;VMT\V)E<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"B,L(&9U>GIY
M"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")5<'!L_7-I;F=A
M<B!N973^:O-N<R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*
M;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-3`*(RP@9G5Z>GD*;7-G:60@
M(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")(869A('5N9&ER<VMR
M:69T:7(@;67P(&1A=69U;2!L:70_(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3(Y-@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-#@*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,S`*;7-G:60@(E!'4"!3:6=N
M960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE
M;&PN<&AP.C8X"FUS9VED(")02%`@0V]D92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B4$T@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-@IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@
M4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*
M;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP
M.C$R-@IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED
M(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K
M:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@
M5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*
M;7-G:60@(E!A;F%M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM
M<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@(E!A<G1L>2!#;&]U9'DB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$X,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`Q.`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<P('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,U,@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B3'EK:6QO
M<O`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("),
M>6MI;&]R\"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ
M-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC
M+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(DQY:VEL;W+P(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B3'EK:6QO<O`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S
M=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W1E(@IM<V=S='(@
M(D1A9W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHT"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`W"B,L(&9U>GIY"FUS9VED(")097)C96YT(@IM<V=S='(@
M(E!R96YT82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7V)O
M='1O;2YI;F,Z-@HC+"!F=7IZ>0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(E9I\&AA;&1S8?!G97+P:7(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDV"B,L(&9U>GIY"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(D9R86UK=N9M82!V:?!H86QD<V'P9V5R\&ER('9I\"!T96YG:6YG=2(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,2!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8W"B,L
M(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!E<G/S;G5L96=T
M(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HV.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")097)M:7-S:6]N("<E<R<@;F]T(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E!E<FUI
M<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R('5M
M(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T.`HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U,@IM<V=I9"`B4&5R;6ES<VEO;G,@
M9F]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0IM
M<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B57!P;/US:6YG
M87(@=6T@;F]T86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"B,L(&9U>GIY"FUS9VED(")0:&]N92(*;7-G<W1R(")E
M;F=I;FXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#$U"FUS9VED
M(")0:&]T;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET
M8V%I<FXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4W,0HC+"!F=7IZ>0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T<B`B4VSA
M\'4@:6YN(&[]:F$@;F%F;FGP.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")3
M;.'P=2!I;FX@;OUT="!M]G!P=6YA9FXZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3,P-PHC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B4VSA\'4@:6YN(&=I;&1A<B!L
M96ET87)F;W)S96YD=7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T.0HC+"!F=7IZ>0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B4VSA\'4@
M:6YN(&=I;&1A<B!L96ET87)F;W)S96YD=7(N(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S
M=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D(@IM<V=S='(@(E-LX?!U(&EN;B!N;W1A;F1A;F%F;B!O9R!L
M>6ML:6]R\"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?
M=&]P+FEN8SHQ,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$W"FUS9VED(")0;&5A<V4@<F5P;W)T(&%N
M>2!B=6=S('1O(&DQ.&Y`;&ES=',N:&]R9&4N;W)G+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T
M,`IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG(&EN9F]R
M;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@=&AE("(*
M(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#,U"B,L(&9U>GIY"FUS9VED(")0
M;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*
M;7-G<W1R(")696QD=2!A+FTN:R!E:6YA(&WV<'!U('1I;"!A\"!L96ET82#M
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A
M=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E-LX?!U(&EN;B!N_6IA(&YA9FYI\#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C0*;7-G:60@
M(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U
M9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O
M;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C8T(&QI8B]";&]C:R]M971A<BYP:'`Z,C8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@
M)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C,*;7-G
M:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C4W"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`R"FUS9VED
M(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"B,L(&9U>GIY"FUS
M9VED(")0<F5V:65W(@IM<V=S='(@(D9Y<G)I(&)L8?!S[?!A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-3@@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(*(RP@9G5Z>GD*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B1GER<F$@<VME>71I
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT
M,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Y"FUS9VED(")0<FEV871E($ME
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E9A;F1A
M;>%L/R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O
M8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C$P"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q.#@*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P.0IM<V=I9"`B
M4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,C(W"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS
M9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS
M9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C(*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT,`IM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4F%I;B!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")2
M86EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*;7-G
M:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@P"B,L(&9U>GIY"FUS9VED(")296%D(@IM<V=S='(@
M(M-L97-I\"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(D[]('-K97ET:2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI
M;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED(")2969R97-H
M($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,S,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S:"!0
M;W)T86P@5FEE=SHB"FUS9W-T<B`B16YD=7)H;&'P82!M]G!P=6AA;3HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U
M"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(")%;F1U<G-E=&IA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(U,PIM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C0*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-S8*;7-G
M:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*(RP@9G5Z>GD*
M;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(D9J87)LYF=J82!V86QI
M;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C@*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ-0HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(DAA;&1A(.%F<F%M(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")2
M96UO=F4@0FQO8VLB"FUS9W-T<B`B1FIA<FSF9VIA('9A;&EN(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S,@HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")FYG)A(&YI\'5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC
M+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B57!P
M;/US:6YG87(@;F5T_FKS;G,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8U.`IM<V=I9"`B4F5M;W9E(&9R;VT@;7D@
M8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,S8*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!P86ER(@IM<V=S='(@
M(F;F<F$@=7!P(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P-0IM<V=I
M9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I
M9"`B4F5M;W9E('1H92(*;7-G<W1R(")&:F%R;.9G:F$@=F%L:6XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B9FIA
M<FSF9VIA(&AA;F1R:70B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO
M=F4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,C@P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,S0Y"B,L(&9U>GIY"FUS9VED(")297!L>2!3
M96YT+B(*;7-G<W1R(")3=F%R82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#8X"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<X"FUS9VED(")297!L>2!W
M:71H($YO="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0V-@IM<V=I
M9"`B4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT:',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#8U"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E
M+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3@Y"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")297!L>3H@)7,B"FUS9W-T<B`B4W9A<CHB"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT.#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-3@Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S0W"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M)R5S)R!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R.`IM
M<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.3(*;7-G:60@(E)E
M<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,34@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C0T"FUS9VED(")297-E="(*;7-G<W1R(")%;F1U<G-E=&IA(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(DQY:VEL;W+P(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@
M4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q
M(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C4*
M(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B3FGP=7)S=&'P82!L
M96ET87(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#(Q"FUS9VED(")297-U
M;'1S("AI;F-L=61I;F<@2&]R9&4I.B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#$Y"B,L(&9U>GIY"FUS9VED(")297-U;'1S.B(*;7-G
M<W1R(").:?!U<G-T8?!A(&QE:71A<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B5F%L:V]S
M=&ER(&YO=&%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B4F5V97)T($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B57!P;/US:6YG87(@;F5T_FKS;G,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,P"FUS9VED(")2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I
M9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$R-0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT('9A;'5E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-3@S"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P.`IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C`U"B,L(&9U>GIY"FUS9VED(")2;W1A=&4@3&5F
M="(*;7-G<W1R(")496YG:6QI\&%L:7-T:2(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,3$*;7-G:60@(E)O=&%T92!2:6=H
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ>0IM<V=I
M9"`B4G5L97,B"FUS9W-T<B`B16YD=7)S971J82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*
M;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PHC
M+"!F=7IZ>0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S
M='(@(E-E;F1A('-K97ET:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0T.0HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M(")3:V_P82!S:V5Y=&DB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G
M:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")34R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8P"FUS9VED(")34T@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,S`*;7-G:60@(E-?44P@4VAE
M;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE
M(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N
M($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@
M5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I
M82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3@*(RP@9G5Z>GD*;7-G:60@(E-A=F4B"FUS9W-T<B`B5FES=&$@<V5M(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B5FES=&$@<V5M(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@(E9I<W1A
M('-E;2(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*(RP@9G5Z>GD*
M;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")686QK;W-T:7(@;F]T86YD
M82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S`*;7-G:60@(B(*(E-A
M=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O
M('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E<R<N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0V"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`B3&5I=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<U"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G
M<W1R(").:?!U<G-T8?!A(&QE:71A<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ-#0X"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:&EN9R!(;W)D92!A
M<'!L:6-A=&EO;G,@:6X@)7,B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C$R,PIM<V=I9"`B4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N
M+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW
M-PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E9E;&IA
M(&%L;'0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4V"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@
M(E9E;&1U(&ME;FYI(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY"FUS9VED
M(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B5F5L:F$@96MK97)T(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"B,L(&9U>GIY"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5F5L9'4@<W1A9F%S971T
M.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"B,L(&9U>GIY
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")696QD=2!S
M=&%F87-E='0Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8W,`HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(D5Y\&$@=FGP:&5N9VDN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%N(&]B:F5C="(*;7-G<W1R(")696QJ82!E:VME<G0B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C
M=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T
M:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM
M<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E9E;&1U('-T869A
M<V5T=#HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.C@Y"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z
M,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE
M8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C8T"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG
M(&9I96QD<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(Y-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,X"FUS9VED(")396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E9E;&1U('-J
MX6QF9V5F:?`@='5N9W5MX6PZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV-3,*(RP@9G5Z>GD*;7-G:60@(E-E;F0@
M3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(E5P<&S]<VEN9V%R(&YE=/YJ
M\VYS(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G
M:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`HC+"!F=7IZ>0IM
M<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4V5N9&$@<VME>71I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G
M:60@(E-E<'1E;6)E<B(*;7-G<W1R(")S97!T96UB97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N
M9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,0IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$R"B,L(&9U>GIY
M"FUS9VED(")3970B"FUS9W-T<B`B5F5L:F$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*
M;7-G<W1R(")696QD=2!S:N%L9F=E9FGP('1U;F=U;>%L.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*;7-G:60@(E-E='5P(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,Y
M"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*;7-G
M:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M
M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H
M96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0T,0IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-@IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,CDR('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-3@*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0X,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!L87-T(&QO
M9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")3_6YA(&AV96[F
M<B#^^B!T96YG9&ES="!S[?!A<W0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S8Y"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,34*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E-H;W<@=&AE
M(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8S"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(E-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C<*(RP@9G5Z>GD*;7-G:60@
M(E-H;W<@=7!L;V%D(@IM<V=S='(@(E/F:VIA('EF:7(@X2!V:6YN=7-T]O`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4VAO=V5R<R!%87)L>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT.0IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3
M:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS.3D*;7-G:60@(E-H<FEN:R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HV.3(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S4T"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@Q,B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX-S0*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3`Y(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.CDT-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HY-S0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M,3`P-`IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K
M*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#D*
M;7-G:60@(E-I9VX@=7`@:68@;F]T(')E9VES=&5R960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*(RP@9G5Z
M>GD*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")5;F1I<G-K<FEF="#^[6XZ
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G
M:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,T"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C<*;7-G:60@(E-I>F4B"FUS9W-T<B`B4W3F
M<O`B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN
M:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C0S,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-#@T
M('!O+W1R86YS;&%T:6]N+G!H<#HV-C8*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C@V,"!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(R,PIM<V=I9"`B4VMI<'!E9"XN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VYO=R!3:&]W97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3,*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E
M<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W
M-@IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C@P"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T
M97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M
M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*
M;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDS,`HC+"!F=7IZ>0IM<V=I9"`B4V]R="!O<F1E
M<B!S96QE8W1I;VXB"FUS9W-T<B`B4O;P=6YA<N%T="(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34X"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@X"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M-#8*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D9U
M;&QT(&YE=&9A;F<@_FET="`H1G+A.BD@.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*
M;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDU"FUS9VED(")3<&%M
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`HC+"!F
M=7IZ>0IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B
M4^ER=.%K;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C(*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-E;&PB"FUS
M9W-T<B`B5F5L:F$@86QL="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S(*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-#0S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-30X"FUS9VED(")3=&%R="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@
M(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q.0HC+"!F=7IZ>0IM
M<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B57!P;/US:6YG87(@;F5T
M_FKS;G,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B4V5N
M9&%N9&%N971F86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED(")3=')I
M;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R
M"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y("<E<R<@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Q,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D5F;FDB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I
M9"`B4W5B:F5C="!0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO
M4F5N9&5R97(N<&AP.C,Q,@HC+"!F=7IZ>0IM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(D5F;FDB"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"`G)7,G('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*(RP@9G5Z>GD*;7-G
M:60@(E-U8G-C<FEP="(*;7-G<W1R(")%9FYI(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$P-0HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3=6-C97-S(@IM
M<V=S='(@(D9R86UK=N9M="(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@)R5S
M)R!T;R!T:&4@<WES=&5M+B(*;7-G<W1R(").971F86YG:?`@7"(E<UPB('9A
M<B!BYG1T(.T@;F5T9F%N9V%B\VMI;F$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,2!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE
M=&5D("<E<R<N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"`G)7,G
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C4U"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-3@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C8*;7-G:60@(E-U;B!2
M:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW,0IM
M<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X,PIM<V=I9"`B
M4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N
M<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ.#(*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"B,L(&9U>GIY"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B169N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#4*(RP@9G5Z>GD*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B!%
M9FYI<VSM;F$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-U<'!O<G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R
M:6YA;64B"FUS9W-T<B`B4VMRX7)N869N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S0*(RP@9G5Z>GD*;7-G:60@(E-U<FYA;64B
M"FUS9W-T<B`B3F]T86YD86YA9FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"B,L(&9U>GIY"FUS9VED(")3=V5D96XB"FUS9W-T<B`B3&5S:?`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED
M(")4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.0IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S8*;7-G
M:60@(E1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W,`HC+"!F=7IZ
M>0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5F5R:V5F;FD@=FGP('1E;F=I;F=U
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G
M:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#@*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$R"FUS9VED(")4
M96UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3DP"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z,C$W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1E;7!L871E("<E<R<@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M
M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#$*;7-G:60@(E1E
M;G1A=&EV96QY($%C8V5P="!R97%U97-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Y"FUS9VED
M(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q"FUS9VED(")497AT(@IM<V=S='(@(E1E
M>'1I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-0HC+"!F=7IZ>0IM
M<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E1E>'1I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ
M>0IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(").YG-T82!S[?!A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC+"!F
M=7IZ>0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")497AT:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED
M(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HBWOH@:&5F=7(@;OH@869T96YG
M<W0@)7,N(%1A:VL@9GER:7(@;F]T:W5N:6YA+B#>96=A<B#^^B!V:6QT('1E
M;F=J87-T(&%F='5R+"`B"B)N;W1A\'4@_N$@<F5I=&EN82!HZ7(@8?`@;F7P
M86XN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE("5S(&AE;'`@9FEL92!F;W(@)7,@9&]E<VXG="!Y970@
M97AI<W0N($-R96%T:6YG(&$@;F5W(&]N92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,S<*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D
M:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@
M(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G
M<W1R(")3:V5Y=&EN=2!S96T@=F5R:?`@=F%R(&'P('-E;6IA(&AE9G5R('9E
M<FGP(&QO:V'P+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,34X
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,3@P(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,3DR"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`S(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C,S(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C<R"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#D*;7-G:60@(E1H92!C
M86QE;F1A<B!D871A(&ES(&EN=F%L:60B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C4Q"B,L(&9U>GIY"FUS9VED(")4:&4@8V]N=&%C="!W87,@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G
M<W1R(").971F86YG:?`@7"(E<UPB('9A<B!BYG1T(.T@;F5T9F%N9V%B\VMI
M;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,30V"FUS
M9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,`IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I
M9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.`IM<V=I9"`B5&AE(&5V96YT
M(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z-#@X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,34R"FUS
M9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C8P"FUS
M9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM
M<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB
M5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE
M;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F
M(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H
M97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R
M>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL
M;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y-R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3(S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:&5L<"!F:6QE
M("5S(&1I9&XG="!S=&%R="!W:71H(#P_>&UL(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DME
M;FYI;G4@7"(E<UPB(&AE9G5R('9E<FGP(&5Y='0N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B
M5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,30S"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E
M(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS
M-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H
M<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H
M<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@
M(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B2V5N;FEN=2!<(B5S7"(@:&5F=7(@=F5R:?`@97ET="XB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(DME;FYI\"`@7"(E<UPB(&AE9G5R('9E<FGP('9I<W1A
M\"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"XB"FUS9W-T<B`B2V5N;FGP("!<(B5S7"(@:&5F=7(@=F5R:?`@
M=FES=&'P+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C(Y,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,3`X"FUS9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R('1A<VML:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,#<*;7-G
M:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+V-S=BYP:'`Z,C0P(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*
M(RP@9G5Z>GD*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"XB"FUS9W-T<B`B16MK:2!V87(@:.9G="!A\"!S:VEP=&$@=6T@
M=6YD:7)S:W)I9G0N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B5&AE('5S97(G<R!F
M<F5E+V)U<WD@:6YF;W)M871I;VX@=V%S('-U8V5S<V9U;&QY('-T;W)E9"XB
M"FUS9W-T<B`B56YD:7)S:W)I9G0@:&5F=7(@=F5R:?`@8G)E>71T+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$P-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Q"FUS9VED
M(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N(@IM<V=S='(@(MYA\"!E<G4@96YG:6X@<VME>71I(.T@_F5S<W4@
M</-S=&CS;&9I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,S.`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE
M<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U
M(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E
M<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#8P"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E(&1O97-N)W0@
M>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@
M<VEG;G5P+G!H<#HU,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E
M<RXB"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V:?`@=.9M:6YG=2#A
M("5S+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS;G-I;G,@9GEL9VER(&CI<B#A
M("(*(F5F=&ER(@H*(SH@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG("<E
M<R<@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M
M('5P<"!V:?`@=.9M:6YG=2#A("5S+B!6:6QL=71I;&MY;FYI;F<@;F5T_FKS
M;G-I;G,@9GEL9VER(&CI<B#A("(*(F5F=&ER(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R("(B"B)686YD86WA;"!K;VT@=7!P('9I\"!T
MYFUI;F=U('#S<W1H\VQF<RX@5FEL;'5T:6QK>6YN:6YG(&YE=/YJ\VYS:6YS
M(&9Y;&=I<B`B"B)HZ7(@X2!E9G1I<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@
M(B(*(E9A;F1A;>%L(&MO;2!U<'`@=FGP('3F;6EN9W4@X2`E<RX@5FEL;'5T
M:6QK>6YN:6YG(&YE=/YJ\VYS:6YS(&9Y;&=I<B!HZ7(@X2`B"B)E9G1I<B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G.B`E<R(*
M;7-G<W1R(")%:VMI('3S:W-T(&'P('-E;F1A('-K97ET:?`Z("5S(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*
M(E9A;F1A;>%L(&MO;2!U<'`@=FGP('5P<&AL9?!S;'4@<VMRX7(N(%-K<N%I
M;B!E<B!E+G0N=BX@<W3F<G)I(&5N(&QE>69I;&5G="`B"B)E<BXB"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA
M>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*
M(E9A;F1A;>%L(&MO;2!U<'`@=FGP('5P<&AL9?!S;'4@<VMRX7(N(%-K<N%I
M;B!E<B!E+G0N=BX@<W3F<G)I(&5N(&QE>69I;&5G="`B"B)E<B`H)60@34(I
M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB5F%N9&%MX6P@:V]M('5P<"!V
M:?`@=7!P:&QE\'-L=2!S:W+A<BX@4VMRX6EN(&5R(&4N="YV+B!S=.9R<FD@
M96X@;&5Y9FEL96=T("(*(F5R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(E9I;&QA
M(&MO;2!U<'`@=FGP(&)I<G1I;F=U(/YE<W-A(&AL=71A('-K97ET:7-I;G,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(E9I;&QA(&MO;2!U<'`@_F5G87(@
MX71T:2!A\"!V:7-T82!U<'!K87-T:?`N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HW-0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M979E;G0Z("5S+B(*;7-G<W1R(")6:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@
M8?`@<_UN82!U;6)E\&GP('-K97ET:2XB"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+VEM8RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")6
M:6QL82!K;VT@=7!P(/YE9V%R(.%T=&D@8?`@=FES=&$@=7!P:V%S=&GP+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!T87-K.B`E<RXB"FUS9W-T<B`B5FEL;&$@
M:V]M('5P<"#^96=A<B#A='1I(&'P('/];F$@=6UB9?!I\"!S:V5Y=&DN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HY
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E
M<RXB"FUS9W-T<B`B16MK:2!T\VMS="!A\"!S96YD82!S:V5Y=&GP.B`E<R(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P-R!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3$Q,R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(T-0HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3(U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI
M;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE("(*(F9L86<@+60@=&\@<V5E
M(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-PIM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O
M<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L
M96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"B,L(&9U
M>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS
M9W-T<B`B5FEL;&$@:V]M('5P<"!V:?`@8FER=&EN9W4@_F5S<V$@:&QU=&$@
M<VME>71I<VEN<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A
M<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")6:6QL82!K;VT@=7!P(/YE
M9V%R(.%T=&D@8?`@<_UN82!U;6)E\&GP('-K97ET:2XB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z.#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HY-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$Q,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C(P,`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H:7,@
M86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q-#D*(RP@9G5Z>GD*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+>
M971T82!G:6QD:2!V97+P=7(@8?`@=F5R82!T86QA+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M
M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX,`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,CDP(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34V,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,S(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-S(X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,W,S8*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P
M-C4*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M-@IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@
M86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(MYE='1A(&=I;&1I('9E<O!U<B!A\"!V97)A('1A;&$N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T,`IM<V=I9"`B(@HB5&AI
M<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@
M2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI
M<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA
M="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R
M(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@
M=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA
M;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@
M;&5A<W0@;VYE+B(*;7-G<W1R(")486QA;B!V97+P=7(@8?`@=F5R82!A\"!L
MX6=M87)K:2`Q+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S`T"FUS9VED
M(")4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI
M;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,30W"FUS9VED(")4:&ES
M('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED(")4
M:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(MYE='1A(&=I
M;&1I('9E<O!U<B!A\"!V97)A('1A;&$N(@H*(SH@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!W:6YD
M;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G
M<W1R("(B"B+>97-S:2!G;'5G9VD@_F%R9B!A\"!V97)A(';M<W5N(&9RX2!G
M;'5G9V%N=6T@_F%R('-E;2!N_2!S:V5Y=&D@97)U('-A;6EN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4
M:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,3D*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0R-@HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G
M<W1R(")4[6UA8F5L=&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S`U"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!F;W)M870B
M"FUS9W-T<B`B5.UM86)E;'1I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4S-PHC+"!F=7IZ>0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T
M<B`B5.UM86)E;'1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S
M=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B
M5&ET;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<U"FUS9VED(")4;R(*;7-G<W1R(")4:6PB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(Y"FUS9VED("(B"B)4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED(")4;V1A>2(*;7-G<W1R(")-96=I;FWA;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G
M:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y"B,L(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S='(@(E1I;"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-PIM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<W"B,L(&9U>GIY"FUS9VED(")4;W`B"FUS9W-T<B`B5&EL(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C4W"FUS9VED(")4<F%N<VQA=&5D(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<Y-`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R
M:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC
M93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S$*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#`*;7-G
M:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R
M"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C,S-0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S(V"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,#@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I
M;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z,S<Q"FUS9VED(")5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<U-@IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@
M=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$U."!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$X."!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#$*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C0X
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y.`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(U-"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,P-0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)R5S)SH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-#`@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-C`@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,S-@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C,S,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C(V(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,C`V"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,W
M.`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ
M("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C<R,`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H
M<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$R.2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,S0*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U."!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38S"FUS9VED(")5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,C4*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O
M<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C4Y,@IM
M<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.#4*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR-#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C4S,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C,X(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C<W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G
M;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,3(R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,3(U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C$Q,@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C`Y(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S-0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`*(RP@9G5Z>GD*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")%
M;F1U<G9E:VIA(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@HC+"!F
M=7IZ>0IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D)R97ET82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G
M:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N
M97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E
M9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8T"B,L(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM
M<V=S='(@(M-L97-I\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI
M<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET
M960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N
M:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HV.0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$U(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q-@IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3<*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#
M;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ-3`Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;FMN
M;W=N(&-O;6UA;F0Z("5S(@IM<V=S='(@(E/F:VIA("5S('EF:7(@X2!V:6YN
M=7-T]O`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3`*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B56YL:6YK
M('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B4W1I;&QA(&[Z=F5R86YD
M:2!T[6UA8F5L=&DN(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y
M+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BTVYE9FYT(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I
M9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O
M0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E
M87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M
M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*(RP@9G5Z>GD*
M;7-G:60@(E5N=')A;G-L871E9"(*;7-G<W1R("+3<W9A<F'P(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`V(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3@S"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S
M"B,L(&9U>GIY"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B1&%G<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0X"FUS9VED(")5<&1A
M=&4@<F5S<&]N9&5N="!S=&%T=7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PIM<V=I9"`B57!D871E('5S97(B
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ,S<@861M:6XO<&5R
M;7,O961I="YP:'`Z,C$W('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"`G)7,G+B(*;7-G<W1R("(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y,B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&EN9R`E<R!H96QP
M(&9I;&4@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,2!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@R"FUS9VED(")5<&QO
M860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X.0IM
M<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R
M(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P
M97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS
M9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HS-2!P;R]T<F%N<VQA=&EO;BYP:'`Z.3(@<&\O=')A;G-L871I;VXN<&AP
M.CDS"B,L(&9U>GIY"FUS9VED(")5<V%G93HB"FUS9W-T<B`B4VME>71I(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C$X"B,L
M('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@
M9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G
M:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+U5)+G!H<#HR-3`*;7-G:60@(E5S97(@3W!T:6]N
M<R(*;7-G<W1R(")686QK;W-T:7(@;F]T86YD82(*"B,Z('-I9VYU<"YP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(E9A;&MO<W1I<B!N;W1A;F1A(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3<R
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C0V"B,L(&9U>GIY"FUS
M9VED(")5<V5R('!E<FUI<W-I;VYS(@IM<V=S='(@(E9A;&MO<W1I<B!N;W1A
M;F1A(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$X,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HQ.3<@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-2!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B
M"FUS9W-T<B`B3F]T86YD86YA9FXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92`G)7,G(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")-87!P86X@
M7"(E<UPB(&5R(&[Z(/YE9V%R('1I;"(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S
M='(@(DYO=&%N9&%N869N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(").;W1A
M;F1A;F%F;B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C$Y
M"B,L(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G<W1R(").;W1A;F1A;F%F;B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,3`Q(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$X.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q-0HC+"!F
M=7IZ>0IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B0?!G97+P(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-30*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*
M;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R
M"FUS9VED(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED(")687)I86)L92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*
M;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`HC+"!F=7IZ>0IM<V=I
M9"`B5F5R<VEO;B(*;7-G<W1R(")097)S\VYU;&5G="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,#(*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@
M(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E
M("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.CDU,PHC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(@IM<V=S='(@(E/];F$@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@Q,@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")3
M_6YA("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HW.0IM<V=I9"`B5FEE=R!E=F5N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.0HC
M+"!F=7IZ>0IM<V=I9"`B5FEE=R!T87-K(@IM<V=S='(@(E/];F$@)7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD
M<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M-PIM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C(U"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-SD*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z
M,CD*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B0?!V]G)U;B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ-#4@<&\O=')A;G-L871I;VXN<&AP.C8X,2!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4@
M<&\O=')A;G-L871I;VXN<&AP.C$P-C`@<&\O=')A;G-L871I;VXN<&AP.C$P
M-CD*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-S<@<&\O=')A;G-L871I;VXN
M<&AP.C$P.#<@<&\O=')A;G-L871I;VXN<&AP.C$P.3<*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$Q,#<@<&\O=')A;G-L871I;VXN<&AP.C$Q,3,@<&\O=')A
M;G-L871I;VXN<&AP.C$R,S4*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R-#4@
M<&\O=')A;G-L871I;VXN<&AP.C$R-3$@<&\O=')A;G-L871I;VXN<&AP.C$R
M-S$*(RP@9G5Z>GD*;7-G:60@(E=A<FYI;F<Z("(*;7-G<W1R(")!\';V<G5N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#D*;7-G:60@
M(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")7
M96(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V
M-@IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"B,L
M(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(E9E;&MO;6EN*&XI(.T@
M)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R(")696QK;VUI;BAN*2#M("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE
M+"`E<R(*;7-G<W1R(")696QK;VUI;BAN*2#M("5S(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(DUA<'!A(&7P82!H86UU<B!S96T@X2!A\"!S_6YA(.T@
M=7!P:&%F:3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM
M<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C0*;7-G:60@
M(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,0IM<V=I9"`B
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Y"FUS9VED(")7:61T
M:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@
M)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G
M+6EN*3HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I
M9"`B5VED=&@Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3@*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@
M(E=I;F0B"FUS9W-T<B`B1FEN;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")7:6YD('-P
M965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,34T"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R(")&:6YN82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#D*(RP@9G5Z>GD*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R(")&:6YN82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-SD*;7-G:60@(E=I<VAL:7-T<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*(RP@9G5Z
M>GD*;7-G:60@(E=O<FLB"FUS9W-T<B`B9?!A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")7
M;W)K($%D9')E<W,B"FUS9W-T<B`B4V5N9&%N9&%N971F86YG(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B
M5V]R:R!0:&]N92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<FET:6YG('5P9&%T960@:&5L
M<"!F:6QE('1O("5S+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C(X"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD
M960@2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@
M261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS.#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0R-PIM<V=I9"`B65E962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P,@IM<V=I9"`B66%H;V\A
M(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I
M;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`B3&5S
M:?`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#@X"FUS9VED(")997,B"FUS9W-T<B`B2N$B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-@IM<V=I9"`B665S+"!)
M($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%
M+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)
M5UE'+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$R.#@*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R
M"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I
M;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U
M"FUS9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E
M<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@
M9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O
M;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY,#,*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B4W1I;&QI;F=A<B#^[6YA<B!H
M869A('9E<FGP('5P<&;F<O!A<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C0S,0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(E9E;&1U(&AV8?!A(&ME;FYI(/[Z('9I;'0@97GP82XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E1I;&=R96EN9'4@
M=FGP=&%K86YD82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M(@IM<V=S='(@(E1I;&=R96EN9'4@=FGP=&%K86YD82XB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`BWOH@_F%R9G0@9GER<W0@8?`@=F5L:F$@_F%U
M('9I\&AE;F=I('-E;2#^^B!V:6QT('-E;F1A(&UE\"!S:V5Y=&EN=2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`BWOH@
M_F%R9G0@9GER<W0@8?`@=F5L:F$@_F%U('9I\&AE;F=I('-E;2#^^B!V:6QT
M('-E;F1A(&UE\"!S:V5Y=&EN=2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B5&EL
M9W)E:6YD=2!V:?!T86MA;F1A+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(E1I;&=R
M96EN9'4@=FGP=&%K86YD82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(DQO=&%N
M("5S(&5R(')U;FYI;B#Z="#A('3M;6$N(%1E;F=D=2#^:6<@869T=7(N(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(").971F86YG(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,@IM<V=I9"`B66]U<B!&<F]M
M.B!A9&1R97-S.B(*;7-G<W1R(")&=6QL="!N971F86YG(/YI='0@*$9RX3HI
M(#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO=7(@26YF;W)M871I;VXB
M"FUS9W-T<B`B57!P;/US:6YG87(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HX.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PHC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(D9U;&QT(&YA9FX@_FET=#HB"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VYO;&ES="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O
M;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HX.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B
M<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I
M;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@
M<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G
M<W1R("(B"B)6969S:V_P87)I(/YI;FX@<W1Y\'5R(&5K:VD@_F5S<V$@<')E
M;G1A\&=E<O`N($YO=&'P=2!#5%),+T]P=&EO;B!O9R!0('1I;"`B"B)A\"!P
M<F5N=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z,C<*
M;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K(%`@=&\@(@HB
M<')I;G0N(@IM<V=S='(@(B(*(E9E9G-K;_!A<FD@_FEN;B!S='GP=7(@96MK
M:2#^97-S82!P<F5N=&'P9V5R\"X@3F]T8?!U($-44DPO3W!T:6]N(&]G(%`@
M=&EL("(*(F'P('!R96YT82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C0W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(").
M^G9E<F%N9&D@=.UM86)E;'1I.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B
M4VKA;&9G969I\"!K96YN:2#^:71T.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ.3$*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R(")&=6QL
M="!N869N(/YI='0Z(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-0IM<V=I
M9"`B(@HB66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O(&]L9"!A;F0@9&]E
M<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN7&XB"B).;W0@86QL('-T<FEN
M9W,@=VEL;"!B92!E>'1R86-T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U
M<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B4W1I;&QI;F=A<B#^
M[6YA<B!H869A('9E<FGP('5P<&;F<O!A<BXB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")3=&EL;&EN9V%R(/[M;F%R(&AA9F$@
M=F5R:?`@=7!P9N9R\&%R+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS
M9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C4X"B,L(&9U>GIY"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*;7-G
M<W1R(")&=6QL="!N971F86YG(/YI='0@*$9RX3HI(#HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG
M:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HU-@IM<V=I9"`B
M6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*
M;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS"B,L('!H<"UF
M;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,S(@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$S-`IM<V=I9"`B7T-,22(*;7-G<W1R("(B
M"@HC.B!L:6(O87!I+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(E]$871A5')E
M92(*;7-G<W1R(")$86=S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS9VED(")?1&5L
M971E(%)O=R(*;7-G<W1R(")%>?!A(@H*(SH@;&EB+V%P:2YP:'`Z,3$T"FUS
M9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(DAJX6QP
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L
M(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E1E;F=J87-T(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B7TQO
M9R!O=70B"FUS9W-T<B`BVG1S:W+A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B5F%L:V]S
M=&ER(@H*(SH@;&EB+V%P:2YP:'`Z,3$X"FUS9VED(")?4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3`V"FUS9VED(")?4V5T=7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,R"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,3`*;7-G:60@(E]5<V5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C@Y,`HC
M+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(DYE=&9A;F=A
M8O-K(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q,0IM<V=I9"`B86X@97)R
M;W(@:&%S(&]C8W5R960Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.#@R"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,"!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4X-@IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-#0U('!O+W1R86YS;&%T:6]N+G!H<#HU-3`@<&\O=')A;G-L871I;VXN<&AP
M.C8Q,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S0Y('!O+W1R86YS;&%T:6]N
M+G!H<#HX,3`@<&\O=')A;G-L871I;VXN<&AP.C@X-PIM<V=I9"`B9&]N92(*
M;7-G<W1R(")L;VMI\"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-3(@<&\O
M=')A;G-L871I;VXN<&AP.C4X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$S"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW-S@@<&\O=')A;G-L871I;VXN<&AP.C@Q
M,B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#DP"FUS9VED(")F86EL960B"FUS9W-T
M<B`B:VQI:VMA\&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-#D*;7-G:60@(F9I;&4B"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.0IM<V=I9"`B9F]U
M;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,U."!L:6(O0FQO8VLO;65T87(N<&AP.C,X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,S(*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38T"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,@IM
M<V=I9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"B,L(&9U>GIY"FUS
M9VED(")I;FQI;F4B"FUS9W-T<B`B96YG:6YN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@W('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR,#4*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS
M9W-T<B`B3F%F;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-S@*;7-G:60@
M(FYO="!C:&%N9V5D(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,S$*;7-G:60@(FYO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00RYP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")N;W0@:6UP;&5M
M96YT960B"FUS9W-T<B`B16MK:2!E>71T(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"B,L(&9U>GIY"FUS9VED(")N;W0@>65T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(D5K:VD@97ET="(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.#<T"B,L(&9U>GIY"FUS9VED(")N;W1E<&%D
M(@IM<V=S='(@(M-L97-I\"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS
M9VED(")R:7-I;F<B"FUS9W-T<B`B0?!V]G)U;B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z.3@*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,3,*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM
M<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.#DX"B,L(&9U>GIY"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B4W9A<G1L:7-T:2(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW,C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R('1H92!L
M;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-S8*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PHC+"!F=7IZ>0IM
M<V=I9"`B=6YN86UE9"(*;7-G<W1R("+3;F5F;G0B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,S<U"FUS9VED(")U<&1A=&5D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38T"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,@HC+"!F=7IZ>0IM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B96YG:6X@
M<F5G;&$@=F%L:6XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C0*(RP@9G5Z>GD*
M;7-G:60@(G<Z(@IM<V=S='(@(L%F<F%M<RXZ(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@
M(B(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]S
M;%]322YP;P``````````````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`V-30T-38@,3`U,34T,S0Q-#(@,#$W-30U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````",@4VQO=F5N:6%N
M('1R86YS;&%T:6]N<R!F;W(@2&]R9&4@<&%C:V%G80HC(%-L;W9E;G-K:2!P
M<F5V;V0@2&]R9&4@<&%K971A"B,@0V]P>7)I9VAT("A#*2`R,#`V($AO<F1E
M(%!R;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@:&]R9&4@<&%C:V%G92X*(R!!=71O;6%T
M:6-A;&QY(&=E;F5R871E9"P@,C`P-BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*
M(E!R;VIE8W0M260M5F5R<VEO;CH@+EQN(@HB4F5P;W)T+4US9VED+4)U9W,M
M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`V+3`W+3(U(#$Q.C,P*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z
M(#(P,#8M,#0M,S`@,3`Z,S(K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!D
M=6-K0&]B86QA+FYE=%QN(@HB3&%N9W5A9V4M5&5A;3H@<VQ?4TD@/&1U8VM`
M;V)A;&$N;F5T/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UU=&8M.%QN(@HB0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C8U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@
M86=O*2(*;7-G<W1R("(@*'!R960@)7,@9&YE=FDI(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S4V"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$1O<W1O<&YA('1I<&MA("5S*2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*'8@)7,@9&YE:"DB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8Q"FUS9VED("(@*'1O
M9&%Y*2(*;7-G<W1R("(H9&%N97,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C8V,PIM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B2G5T<FD@
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U.0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(BAVQ(UE<F%J*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3`@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,U,PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDY"FUS
M9VED("(@870@(@IM<V=S='(@(B!O8B`B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@;FD@:6UE;FEK(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<
M(B5S7"(@:F4@;F5V96QJ879N82!I>F)I<F$B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M3FES=&4@=G-T879I;&D@=F5L:F%V;F5G82!E;&5K=')O;G-K96=A(&YA<VQO
M=F$N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW
M,#`*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#8Y
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!N92!Z
M87IN86T@=B!(;W)D;W9E;2!R96=I<W1R=2`B"@HC.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(G)7,G(&YE(&YA:F1E
M;2!D<F5V97-A('IA(&EZ<FES+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@
M9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!J92!B:6P@9&]D86X@<VMU
M<&EN<VME;74@<VES=&5M=2(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@:F4@8FEL
M(&1O9&%N(&L@9&]P=7-T;F5M=2!S:7-T96UU+B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-3,@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G
M<W1R("(G)7,G(&YI('5S='9A<FIE;CH@)7,@(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(E5P;W)A8FQJ
M96YI:"`E+C)F34(@;V0@)2XR9DU"(&1O=F]L:F5N:6@@*"4N,F8E)2DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R!I;B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8W(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HU.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y
M<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(L6@92`E
M9"!D;FD@9&\@<&]T96MA(&=E<VQA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R
M96-A<W0B"FUS9W-T<B`B)60M9&YE=FYA(&YA<&]V960B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M+2!.;W1I8V4B"FUS9W-T<B`B)7,@XH"3($)O9&ET92!P;WIO<FYI(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@3V1T:7,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S<@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0S"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,U(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@T,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@34(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!6>F1R
MQ;YE=F%L;F$@9&5L82`M(%!O=')D:71E=B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q,PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(E<R`@("`@("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!P<FEJ879A(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!0;V=O
M:FDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0T,R!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y.0HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8Y."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HW,#`@9G)A;65W;W)K+U9&4R]6
M1E,O<W-H,BYP:'`Z-S8U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("(E<R#%OF4@;V)S=&%J82XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W,2!L:6(O0FQO8VLO;65T87(N<&AP.C$W-R!L
M:6(O0FQO8VLO;65T87(N<&AP.C(U,0HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U-R!L:6(O0FQO8VLO;65T87(N<&AP.C,V,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!O8B`E<R`E<R(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R
M(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES
M('1I;64N(@IM<V=S='(@(B(*(B5S(&IE('!R:7!R879L:F5N(&YA(&EZ=F%J
M86YJ92!V>F1RQ;YE=F%L;FEH(&]P97)A8VEJ+"!P<F5V97)I('-P;V1A:BY0
M<F5V97)I("(*(FYA8FER86QN:6L@>F$@=G-E(&]P97)A8VEJ92P@:VD@8FD@
M:FEH(')A9"!O<')A=FEL('-E9&%J+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B4&]T<F5B=6IE;2`E<R`B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM
M<V=S='(@(B5S(&UI;G5T(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@
M9F]U;F0N(@IM<V=S='(@(B5S(&YE(&YA:F1E;2(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M=&\@)7,@;V8@)7,B"FUS9W-T<B`B)7,@;V(@)7,@;V0@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("));65N:6L@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(DMO;&5D87(@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B0F5L9<6^:V$@)7,B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(B5S($]P<F%V:6QA(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS
M9W-T<B`B)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z('1O('-P;W)OQ(UI;&\@;6]G;\2-
M92!N:2!O9"!P;\6A:6QJ871E;&IA+"!K871E<FD@<')A=FD@9&$@:F4N(%!A
M>FET92!S92`B"B)K871E<FEH:V]L:2!P;W9E>F%V('8@<W!O<F_$C6EL=2!A
M;&D@<&]D86IA;FIU(&MA=&5R:6@@:V]L:2!O<V5B;FEH("(*(FEN9F]R;6%C
M:6H@;F$@=&$@;F%S;&]V+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-3<@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P,@IM<V=I
M9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&=O<W1I;2`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(P-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!G
M;W-T:6T@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS
M9W-T<B`B+"!S<')E;65N;&II=FMA(&]D("5S(&1O("5S(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HW-3`*;7-G:60@(BTM('-E;&5C
M="`M+2(*;7-G<W1R("(M+2!I>F)E<FD@+2TB"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,C4*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R('5R
M(&9O<FUA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR-`IM<V=I9"`B,C0@
M2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@=7(@9F]R;6%T(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@
M(C(T('5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I
M9"`B/%!R979I;W5S(@IM<V=S='(@(E!R96K%H6YJ82!M;\6^;F]S="(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3,Q"FUS9VED(")!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(EIA
M('1A(&)L;VL@:F4@<&]T<F5B;F$@<&]V97IA=F$@;F$@<&]D871K;W9N:2!S
M=')EQ;YN:6LB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,0IM
M<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`B4&]J
M879I;&$@<V4@:F4@:'5D82!N87!A:V$N(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HT,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M02!M97-S86=E(&AA<R!B965N('-E;G0@=&\@7"(E<UPB('1O('9E<FEF>2!T
M:&%T('1H:7,@:7,@<F5A;&QY('EO=7(@(@HB861D<F5S<RX@5&AE(&YE=R!E
M;6%I;"!A9&1R97-S(&ES(&%C=&EV871E9"!A<R!S;V]N(&%S('EO=2!C;VYF
M:7)M('1H:7,@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("):82!K;V1I<F%T:2!S<&]R;\2-:6QO('!O=')E8G5J96T@:F%V;FD@4$=0
M(&ML:G7$C2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,38X"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E
M<FEF>2!A('-I9VYE9"!M97-S86=E+B(*;7-G<W1R(")*879N:2!01U`@:VQJ
M=<2-(&IE('!O=')E8F5N('IA(&]D:VQE<&%N:F4@<W!O<F_$C6EL82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB
M"FUS9W-T<B`B(@HB2F%V;FD@4$=0(&ML:G7$C2P@>F%S96)N:2!01U`@:VQJ
M=<2-(&EN(&=E<VQO('-O('!O=')E8FYI('IA(&]D:VQE<&%N:F4@(@HB<W!O
M<F_$C6EL82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB
M;65S<V%G92XB"FUS9W-T<B`B(@HB2F%V;FD@4$=0(&ML:G7$C2P@>F%S96)N
M:2!01U`@:VQJ=<2-(&EN(&=E<VQO('-O('!O=')E8FYI('IA('!O9'!I<R!S
M<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B
M"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB2F%V;FD@4R]-24U%
M(&ML:G7$C2P@>F%S96)N:2!3+TU)344@:VQJ=<2-(&EN(&=E<VQO('-O('!O
M=')E8FYI('IA('!O9'!I<R`B"B)S<&]R;\2-:6QA+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB2F%V;FD@4R]-24U%(&ML:G7$C2P@>F%S96)N:2!3+TU)344@:VQJ
M=<2-(&EN(&=E<VQO('-O('!O=')E8FYI('IA('!O9'!I<R`B"B)S<&]R;\2-
M:6QA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T
M"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC
M<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B!*879N:2!334E-12!K;&IU92!J
M92!P;W1R96)E;B!Z82!O9&ML97!A;FIE('-P;W)OQ(UI;&$@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I9"`B04T@
M0VQO=61S(@IM<V=S='(@(D]B;&'$C6YO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB
M"FUS9W-T<B`B2G5T<F%N:FD@4F%H96P@9&7%OB(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM
M<V=S='(@(DIU=')A;FII(&1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R
M(")*=71R86YJ:2!N86QI=B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T
M<B`B2G5T<F%N:FD@<VYEQ;YN:2!M971EQ;XB"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,#`*;7-G:60@(D%022!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
M3W!I<RXN+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR.#(*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B4')E<&]V961A;B!D;W-T;W`@>F$@=7-T=F%R:F%N:F4@;6%P
M92!61E,N("(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S
M='(@(E!R97!O=F5D86X@9&]S=&]P('IA('5S='9A<FIA;FIE(&1A=&]T96ME
M(%9&4RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")68<6A:2!P;V1A=&MI(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O=6YT(%!A<W-W
M;W)D(@IM<V=S='(@(E!O=')D:2!G97-L;R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(DEZ=F%J86TB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DEZ
M=F%J86TB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R(")$
M;V1A:B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(R(&%D;6EN+V=R;W5P<RYP
M:'`Z,C(S"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B1&]D86H@
M<VMU<&EN;R!O=')O:R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.3@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B
M061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B1&]D86H@9&]V;VQJ96YJ
M82!O=')O:V$B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C<P"FUS
M9VED(")!9&0@0V]N=&5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(D1E9&%J
M('-E;3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q-B!A9&UI;B]G<F]U<',N
M<&AP.C(Q-PIM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")$;V1A:B!N
M;W9O('-K=7!I;F\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D
M9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")$;V1A:B!N;W9A(&1O=F]L:F5N
M:F$B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB
M)7-<(B(*;7-G<W1R(")$;V1A:B!S:W5P:6YO(&]T<F]K(%PB)7-<(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM
M<V=S='(@(D1O9&%J(&1O=F]L:F5N:F4@;W1R;VMA(%PB)7-<(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C(Y"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T
M<B`B1&]D86H@;F]V96=A('5P;W)A8FYI:V$Z(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.`IM<V=I9"`B061D(&-O;'5M
M;B(*;7-G<W1R(")$;V1A:B!S=&]L<&5C(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM
M<V=S='(@(D1O9&%J(&YO=F4@Q(UL86YE(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B1&]D86H@
M<&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(B"FUS9W-T<B`B1&]D86H@)7,@365N=2!V($UO>FEL;&$@4VED96)A<B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0IM
M<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B1&]D86H@=B!I
M;65N:6LZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@
M(D1O9&%J('8@;6]J(&EM96YI:SHB"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM
M<V=I9"`B061D('5S97(B"FUS9W-T<B`B1&]D86H@=7!O<F%B;FEK82(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@
M(B(*(B!$;V1A;"`G)7,G('-I<W1E;74L('9E;F1A<B!B;R!N96UO9V_$C64@
M9&]D86IA;FIE(&1O9&%T;FEH('9P:7-N:6@@(@HB:6YF;W)M86-I:CH@)7,N
M(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*
M;7-G<W1R(")$;V1A;B`G)7,G('-I<W1E;74N(%-E9&%J('-E(&QA:&MO('!R
M:6IA=FET92XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")$
M;V1A:F%N:F4@=7!O<F%B;FEK;W8@:F4@;VYE;6]G;\2-96YO+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#4T"FUS9VED(")!9&1R97-S(@IM<V=S='(@
M(DYA<VQO=B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#@*;7-G
M:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("));65N:6LB"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B
M57)E9&D@9&]V;VQJ96YJ82!Z82!O<W1A;&4@=7!O<F%B;FEK92(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3<*;7-G:60@(D%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(E5P<F%V;&IA;FIE(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA;64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9FAA
M;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R(")!
M;&)A;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B
M06S%OFER:6IA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B3WII<F]M82(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B06QL(@IM<V=S='(@
M(E9S92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT
M:6-A=&5D(%5S97)S(@IM<V=S='(@(E9S:2!O=F5R:F5N:2!U<&]R86)N:6MI
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,B!A9&UI;B]G<F]U<',N<&AP.C(R
M,`IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")6<V4@<VMU<&EN92(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(E9S82!$;W9O;&IE;FIA(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C`P.0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S
M<V5S(@IM<V=S='(@(D1O=F]L:2!M;F]G;VMR871N92!N87-L;W9E(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R.`IM<V=I9"`B06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B1&]V;VQI(&YA<W1A
M=FET=F4@("(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN
M<&AP.C4Q.`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`BPX+%O64@
M;V)S=&%J82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@
M(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(DYA9&]M97-T;F\@24U3
M4"!U<&]R86)N:<6A:V\@:6UE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P,@IM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B
M3F%D;VUE<W1N;R!)35-0(&=E<VQO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Y-`IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T
M<B`B3F%D;VUE<W1N;R!)35-0('5P;W)A8FYIQ:%K;R!I;64B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M
M86EL(&%D9')E<W,B"FUS9W-T<B`B3F%D;VUE<W1N:2!E;&5K=')O;G-K:2!N
M87-L;W8B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,0IM<V=I9"`B06QT
M97)N871E('1E;7!L871E<R(*;7-G<W1R(").861O;65S=&YI('9Z;W)C:2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(B!!
M;65R:<6A:V$@4V%M;V$@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I
M9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(").
M879E9&5N82!J92!B:6QA(&YE>F%K;VYI=&$@=G)E9&YO<W0N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,`IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B<&]J879I;&$@<V4@:F4@
M;F%P86MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!
M;F1O<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG
M;VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B06YG
M=6EL;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS
M9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;FEM96X@4')O>'DB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS
M=V5R(@IM<V=S='(@(D]D9V]V;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1I8V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED
M(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@:6X@0F%R
M8G5D82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S,@861M:6XO<&AP<VAE
M;&PN<&AP.C,T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-`IM<V=I9"`B07!P
M;&EC871I;VXB"FUS9W-T<B`B07!L:6MA8VEJ82(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R
M(")397IN86T@87!L:6MA8VEJ(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$S.0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%P
M;&EK86-I:F$@:F4@<')I<')A=FQJ96YA(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*
M;7-G<W1R(")0<FEJ879I(&]T<F]K;W9E(&1E;&YI8V4@(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B
M"FUS9W-T<B`B4&]T<F1I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S`*;7-G:60@(D%P<FEL(@IM<V=S='(@(D%P<FEL(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN
M9&]W<RTQ,C4V*2(*;7-G<W1R(")!<F%B<VMI("A7:6YD;W=S+3$R-38I(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI=F4@
M1FEL92!3:7IE(@IM<V=S='(@(E9E;&EK;W-T(&1A=&]T96ME($%R:&EV("(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!<F-H:79E
M($YA;64B"FUS9W-T<B`B26UE($%R:&EV82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B4W1E('!R97!R:<2-86YI+"!D
M82#%OF5L:71E('!R96ML:6-A=&D@>F%H=&5V;R!Z82!P<FEJ879O('IA("5S
M(#\@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R(")3
M=&4@<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@:7IB<FES871I("<E<R<@:6X@
M;W-T86QE('!O9'-K=7!I;F4_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT
M:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R
M;65N:6$B"FUS9W-T<B`B07)M96YI:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W.0IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M07)M96YS:VD@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S,*;7-G:60@(D%R="(*;7-G<W1R(")5;65T;F]S="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%R=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R(")5;65T;F]S=&D@Q(UR:R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC
M(%)E9VEO;B(*;7-G<W1R(")!>FEA+U!A8VEF:<6A:V4@<F5G:6IE(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF
M:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_
M(@IM<V=S='(@(E9P<F'%H6%J('IA('!O=')D:71E=B!P<F5D(&EZ=F%J86YJ
M96T@=GID<L6^979A;FIA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,X,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D1O9&5L
M:F5N92!K;VQO;F4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<S"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`B4&]S:W5S(&EZ8G)I<V$@;F5O8G-T;VIEQ(UE('-K=7!I;F4N(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HR.`IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]S
M:W5S(&EZ8G)I<V$@;F5O8G-T;VIEQ(UE9V$@9&]V;VQJ96YJ82XB"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HX-@IM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!O<VMU<R!U
M<F5D:71V92!N96]B<W1O:F7$C65G82!D;W9O;&IE;FIA+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HU.`IM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R(")0;W-K=7,@=7)E9&ET
M=F4@;F5O8G-T;VIEQ(UE(&1E;&YI8V4N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B3&%S=&YO
M<W1I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S0*;7-G:60@(D%U9W5S="(*;7-G<W1R(")!=F=U<W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B079S=')A;&EJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B079S=')I:F$B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$V"FUS9VED(")!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R("(@075T:%]C>7)U<SH@6F%H=&5V86YO(&EM87`@Q:%I<FET978@
M;FES96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$S,0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R(")!=71H7V-Y<G5S
M.B!"86-K96YD(&YI;6$@>F%H=&5V86YI:"!Z;6_%OFYO<W1I+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-`IM<V=I9"`B075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G5S.B!:86AT979A;F\@:6UA<"#%H6ER:71E=B!N:7-E
M;2!N8<6A96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C4V
M"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T
M<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!:86AT979A;F\@1E10
M(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X@27IP;VQN:2!02%`@>B`M;VYE;6]G
M;\2-96YO+2!F='`@(@HB>F%M96YJ879O+B`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VEM87`N<&AP.C$P-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA
M<&AT979A;F\@24U!4&ET978@;FES96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S,*;7-G:60@(D%U=&A?:W)B-3H@4F5Q
M=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VMR8C4Z(%IA:'1E=F%N;R!K<F(U(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,0IM<V=I9"`B
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($YI(&UOQ;YN
M;R!D;V1A:F%N:F4@=7!O<F%B;FEK;W8@=B!!8W1I=F4@1&ER96-T;W)Y(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-38*;7-G:60@(D%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($YI(&UOQ;YN
M;R!O9'-T<F%N:F5V86YJ92!U<&]R86)N:6MO=B!V($%C=&EV92!$:7)E8W1O
M<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDR"FUS9VED
M(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]L9&%P.B!:86AT979A;F\@3$1!4"#%H6ER:71E
M=B!N:7-E;2!N8<6A96PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($YE(&UO<F5M(&1O9&%T:2!U<&]R
M86)N:6MA("5S+B!3<&]R;\2-:6QO('-T<F7%OFYI:V$Z("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S
M='(@(D%U=&A?;&1A<#H@3F4@;6]R96T@;V1S=')A;FET:2!U<&]R86)N:6MA
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P.B!.92!M;W)E;2!N861G<F%D
M:71I('5P;W)A8FYI:V$@)7,@(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HT,#0*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T
M<B`B075T:%]L9&%P.B!N92!M;W)E;2!N861G<F%J979A=&D@=7!O<F%B;FEK
M;W8@=B!!8W1I=F4@1&ER97-T;W)Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;6-A;"YP:'`Z-C(*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!
M3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ(%IA
M:'1E=F%N;R!-0T%,(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#8*;7-G:60@(D%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7W-M8F%U=&@Z(%IA:'1E=F%N96=A('-M8F%U=&@@>F$@Q:%I
M<FET978@;FES96T@;F'%H65L+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")/=F5R:F%N:F4@>F$@1E10('-T<F7%
MOFYI:R!N:2!U<W!E;&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F
M86EL960B"FUS9W-T<B`B3W9E<FIA;FIE(&YI('5S<&5L;RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S
M(@IM<V=S='(@(D]V97)J86YJ92!N:2!U<W!E;&\N("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$X,@IM<V=I9"`B075T:&5N=&EC
M871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B3W9E
M<FIA;FIE(&IE('IA=G)N:6P@4D%$2553('-T<F7%OFYI:RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W,PIM<V=I9"`B075T:&5N=&EC871I
M;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D]V97)J86YJ92!Z
M82!&5%`@<W1R9<6^;FEK(&YI('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<V@R+G!H<#HX.#D*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O(%-32#(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3W9E<FIA;FIE
M('IA($944"!S=')EQ;YN:6L@;FD@=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H
M92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B3W9E<FIA;FIE('IA(%--
M0B!S=')EQ;YN:6L@;FD@=7-P96QO+B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@
M(E!O;&IA(&YA(')A>G!O;&%G;SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(D%Z97)B86IDQ;YA;B`B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(").
M975M;FD@:7IG;W9O<FDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@R"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@
M(DYA<&'$C6YO(&ME<F)E<F]S(&=E<VQO+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#0*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B3F%P8<2-;F\@:V5R8F5R;W,@=7!O<F%B;FG%H6MO(&EM
M92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(D)A:&%M
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%H<F%I
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")"86QT:6,@
M*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"86QT:6L@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA
M9&7%H2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A
M<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(DYI<V5M(&YAQ:%E;"!O<VYO=FYE9V$@9W)A
M9FG$C6YE9V$@:6UE;FEK82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F5L87)U<R(*;7-G<W1R(")"96QO<G5S:6IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I
M9"`B0F5L9VEU;2(*;7-G<W1R(")"96QG:6IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R
M;75D82(*;7-G<W1R(")"97)M=61S:VD@;W1O:VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS
M9VED(")":'5T86XB"FUS9W-T<B`B0G5T86XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*
M;7-G<W1R(")2;VIS=&YI(&1A;B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO
M8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(DYI<V5M(&YAQ:%E;"!B;&]K82!<(B5S7"(L(&%P;&EK86-I:F4@
M7"(E<UPB("XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(EIA=7-T879I($YA<W1A
M=FET=F4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S(*;7-G
M:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B6F%U<W1A=FD@5&EP(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VQI=FEJ82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D)O;VMM87)K<R(*
M;7-G<W1R(")0<FEL:G5B;&IE;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N
M:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D)O<VYA(&EN($AE<F-E9V]V
M:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P,0IM<V=I9"`B0F]T
M:"(*;7-G<W1R(")/8F]J:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O='-W86YA
M(@IM<V=S='(@(D)O8W9A;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(D)O=79E=&]V;R!O=&_$C6IE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87II;&EJ82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS
M9W-T<B`B($)R:71A;G-K;R!O>F5M;&IE($EN9&EJ<VME9V$@;V-E86YA("(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@
M(D)R=6YE:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@
M(D)O;&=A<FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*
M;7-G<W1R(")"=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U
M;F1I(@IM<V=S='(@(D)U<G5N9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#8W"FUS9VED(")#35,B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM
M<V=S='(@(D-20R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DX"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R
M("(@0U),(')A>F1E;&ET=F5N92!T;\2-:V4@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U-@IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"XB"FUS9W-T<B`B3F%S=&%V;&IA;FIE('!R961P;VUN:6QN
M:6MA(&YI(&1O:V]NQ(UA;F\N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,38@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X.0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Y,B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,38T"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+
M;VQE9&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,`IM
M<V=I9"`B0V%L;2(*;7-G<W1R("):8G)IQ:%I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9,6^82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*
M;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC.B!A9&UI;B]S
M97-S:6]N<RYP:'`Z,C$*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N
M86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B3F4@;6]R96IO('5P<F%V
M;&IA=&D@>G5N86YJ:2!U<')A=FQJ86QC:2(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C(T,2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q
M;"YP:'`Z,S,P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@
M=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DYE(&UO<F5M('9Z<&]S=&%V
M:71I('!O=F5Z879E('H@24U!4"!S=')EQ;YN:6MO;3H@)7,@(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYI(&UO9V_$
MC64@;V1P<F5T:2!<(B5S7"(@9&%T;W1E:V4N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,"!A9&UI;B]U<V5R+G!H<#HQ,3D@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$Q"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHQ,B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS
M9VED(")#86YC96PB"FUS9W-T<B`B6F)R:<6A:2(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C4R"FUS9VED(")#86YC96P@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`B<&]R;\2-:6QO(&\@=&7%OF%V86@@>B!B<FES86YJ
M96TB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`T(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#(W"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8W-PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HV-SD@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(Q-0IM<V=I9"`B0V%N;F]T(&-O<'D@9FEL92AS*2`M
M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE+B(*;7-G<W1R
M(").92!M;W)E;2!K;W!I<F%T:2!D871O=&5K("AE*2`M('9I<B!I;B!C:6QJ
M82!S=&$@:7-T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,R
M,R!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HS,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M3F4@;6]R96T@:7IB<FES871I(&1A=&]T96ME(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B
M0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").
M92!N86ID96T@>F'$C6%S;F4@9&%T;W1E:RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0X,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,#<*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,SD@9G)A;65W;W)K
M+U9&4R]61E,O<W-H,BYP:'`Z-S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HQ-CD*;7-G:60@(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D
M97-T:6YA=&EO;B!I<R!W:71H:6X@<V]U<F-E+B(*;7-G<W1R(").92!M;W)E
M;2!P<F5M86MN:71I(&1A=&]T96L@*&4I("T@8VEL:B!J92!Z;F]T<F%J('9I
M<F$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+B(*;7-G<W1R(").92!M;W)E;2!N861A;&IE=F%T:2!B
M<F5Z('!A<F%M971R;W8@)V-I;&IN92!D871O=&5K92<N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D@9G)A;65W;W)K+U9&4R]61E,O<W-H
M,BYP:'`Z,S$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@
M9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB($EM96YI:V$@;F4@
M;6]R96T@>F)R:7-A=&DN(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(").92!M;W)E;2!O9'-T<F%N:71I
M.R!O8G-T86IA("5D('!O9'9E;&HB"@HC.B!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HV,C(*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R
M+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S
M(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B).92!M
M;W)E;2!P;VYO=FYO('5R961I=&DL(,6A=&5V:6QO(&1A;FEH('9N;W-O=B!S
M92!N92!S:VQA9&$@<R#%H71E=FEL;VT@("(*(G-H<F%N:F5N:6@N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;FYO="!R
M97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B3F4@;6]R96T@879T;VUA='-K;R!P;VYA
M<W1A=FET:2!G97-L82P@;V)R;FET92!S92!N82!S:W)B;FEK82(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM
M<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E
M<BXB"FUS9W-T<B`B3F4@;6]R96T@<')E=7-M97)I=&D@<W!O<F_$C6EL82!N
M879E9&5N96UU(,6A=&5V:6QU+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@=W)I=&4@
M=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B0V%N;F]T('=R:71E('1O(&9I;&4@
M7"(E<UPB(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R
M(")+87!V97)D<VMI(&]T;VMI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@
M(E!R:6YAQ:%A;&5C(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS
M9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEJ
M92!I;B!Z;F%M:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N
M9',B"FUS9W-T<B`B2V%Y;6%N<VMI(&]T;VMI(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N
M92(*;7-G<W1R(")-;V)I;&YI('1E;&5F;VXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C@S"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B
M:6QN:2!T96QE9F]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G
M:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1S:VD@*$E3
M3RTX.#4Y+3$T*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A
M;B!297!U8FQI8R(*;7-G<W1R(")#96YT<F%L;F\@069R:<6A:V$@4F5P=6)L
M:6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-E;G1R
M86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(E-R961N:F5E=G)O
M<'-K:2`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G
M<W1R(")0;V1R;V)N;W-T:2!P;W1R9&EL82(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE
M<B(*;7-G<W1R("),87-T;FEK('!O=')D:6QA(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O
M;&EC:65S(@IM<V=S='(@(E!R879I;&$@<&]T<F1I;&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(D-H860B"FUS9W-T<B`B16%D(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(E-P<F5M96YI(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U
M<B!087-S=V]R9"(*;7-G<W1R(")S<')E;65N:71E('9AQ:%E(&=E<VQO(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
M(@HB4W!R96UE;FET92!I;64@:6X@;F%S;&]V('9AQ:%E9V$@96QE:W1R;VYS
M:V5G82!N87-L;W9A+"!K:2!G82`B"B)V:61I:F]P<F5J96UN:6MI(&]B(&)R
M86YJ=2!I;B!O9&=O=F%R:F%N:G4@;F$@=F'%H6\@<&_%H71O+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I
M;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U
M<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)6('1R96YU=&YI(&MO;F9I9W5R86-I:F4@
M;F4@;6]R971E('-P<F5M96YI=&D@9V5S;&$N($MO;G1A:W1I<F%J=&4@=F'%
MH65G82`B"B)S:W)B;FEK82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#$W"B,L(&9U>GIY"FUS9VED(")#:&%R86-T97(@=&\@<W!L:70@;75L
M=&EP;&4@861D<F5S<V5S('=I=&@B"FUS9W-T<B`B1&]V;VQI(&UN;V=O:W)A
M=&YE(&YA<VQO=F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R
M("+$C6EL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(DMI
M=&%J<VMA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")0;V5N;W-T879L
M:F5N82!K:71A:L6AQ(UI;F$H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@T"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*
M;7-G<W1R(")4<F%D:6-I;VYA;&YA(&MI=&%JQ:'$C6EN82`H0FEG-2DB"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P
M;&EC871I;VXZ(@IM<V=S='(@(DEZ8F5R:2!A<&QI:V%C:6IO.B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@(D-H;V]S
M92!A('!A<W-W;W)D(@IM<V=S='(@(DEZ8F5R:2!G97-L;R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(DEZ8F5R:2!U<&]R86)N:<6A:V\@:6UE(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO
M=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")+86MO('!R:6MA>F%T:2!D
M871U;64Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*
M;7-G<W1R(")";\6^:<2-;FD@;W1O:VDB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3@T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+B(*;7-G<W1R(").:7-E;2!N8<6A96P@9&5F:6YI8VEJ92!V<G-T92!Z
M82`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B2F%S;F\B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")0
M<F7$C6ES=&D@<&]I>G9E9&)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S
M97(Z("5S(@IM<V=S='(@(D]D<W1R86YI('IU;F%N:F5G82!U<&]R86)N:6MA
M.B`E<R`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B3V1S=')A;FD@=7!O<F%B;FEK
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED
M(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B27IB<FG%H6D@<&]D871E:R!U
M<&]R86)N:6MA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B:7IB<FG%
MH6D@<&]T96TB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B
M2VQI:VYI('IA(&YA9&%L:F5V86YJ92`B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E
M;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L;"!P<F]T;VT@2%144"(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(EIA
M<')I(&]K;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U-@IM<V=I9"`B
M0VQO=61S(@IM<V=S='(@(D]B;&%K:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS
M9W-T<B`B6FIU=')A:B!/8FQAQ(UN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B
M3V)L8<2-;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@
M27-L86YD<R(*;7-G<W1R(")+;VMO<V]V:2!O=&]K:2(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,C0*;7-G:60@(D-O;&QA<'-E(%-I9&5B
M87(B"FUS9W-T<B`B6F1R=<6^:2!S=')A;G-K;R!O:VYO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L=6UB:6IA(@H*(SH@;&EB
M+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R(")"87)V82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-#`*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,T,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3`W('-E<G9I8V5S+VEM86=E<R]C;VQO
M<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R("))
M>F)I<F%L96,@8F%R=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,38*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B($EZ8FER82!"
M87)V92`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,T"FUS9VED
M(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(DYA<VQO=B!S=&]L<&EC82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#`*;7-G:60@(D-O;6EC<R(*
M;7-G<W1R(")3=')I<&DB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C0*;7-G
M:60@(D-O;6UA;F0B"FUS9W-T<B`B56MA>B(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HQ.`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")5:V%Z;F$@
M;'5P:6YA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S
M"FUS9VED(")#;VUM96YT(@IM<V=S='(@(DMO;65N=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D-O;6UO;B!.
M86UE(@IM<V=S='(@(E-K=7!N;R!I;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M0V]M;W)O<R(*;7-G<W1R(")+;VUO<FD@(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R(")$<G7%OF)A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")#;VUP=71E<G,B"FUS9W-T<B`B4F'$C75N86QN:6MI(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,`IM<V=I9"`B0V]N9&ET:6]N
M(@IM<V=S='(@(DYA<W1A=FET978B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(V,0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(").87-T879I='9E(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B4F%Z;&EK92!N87-T879I='9E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/
M=71L;V]K+B(*;7-G<W1R(").87-T879I='9E('IA('-I;FMR;VYI>F%C:6IA
M;R!D;&%NQ(UN:6MO=B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S0*
M;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@
M(DYA<W1A=FET=F4@<&]T<F5B=6IE:F\@8<6^=7)I<F%N:F4B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M;F9I9W5R92`E<R(*;7-G<W1R(").87-T879I("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,@IM<V=I9"`B0V]N9FER;2!087-S
M=V]R9"(*;7-G<W1R(")0;W1R9&D@9V5S;&\B"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C0P-PHC+"!F=7IZ>0IM<V=I9"`B0V]N9FER
M;2!N97<@96UA:6P@861D<F5S<R(*;7-G<W1R(").861O;65S=&YI(&5L96MT
M<F]N<VMI(&YA<VQO=B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(DMO;F=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+;VYG;RP@1&5M;VMR
M871IQ(UN82!R97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B4&]V97IA=F$@;FD@=7-P96QA+B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I
M;&5D.B`B"FUS9W-T<B`B4&]V97IA=F$@;FD@=7-P96QA.B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("):
M879R;FIE;F$@<&]V97IA=F$@>B!J879N:6T@:VQJ=<2-;FEM('-T<F7%OFYI
M:V]M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R("):
M879R;FIE;F$@<&]V97IA=F$@>B!J879N:6T@:VQJ=<2-;FEM('-T<F7%OFYI
M:V]M+B!287IL;V<Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@V-PIM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A
M:6QE9"XB"FUS9W-T<B`B4&]V97IA=F$@<R!&5%`@<W1R9<6^;FEK;VT@;FD@
M=7-P96QA+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C@X,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!34T@R('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(E!O=F5Z879A(',@1E10('-T<F7%OFYI:V]M(&YI('5S
M<&5L82XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-"!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3$S-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T
M<B`B4W1I:VDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")3=&EK(&IE(&)I
M;"!U<W!EQ:%N;R!D;V1A;B!K('9AQ:%I;2!N87-L;W9O;2XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT
M96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5&EP('-T
M:6MA('-T:7-N:F5N92!D871O=&5K93HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<
M(B5S7"(B"FUS9W-T<B`B5G-E8FEN92!O9%PB)7-<(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B3F%D86QJ=6HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B0V]O:V]V
M:2!O=&]K:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B
M0V]O:VEE(@IM<V=S='(@(E!IQ:%K;W1E:R(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I
M;&5D.B`E<R(*;7-G<W1R(")+;W!I<F%N:F4@;FD@=7-P96QO.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#
M;W-T($E$(@IM<V=S='(@(DE$('-T<F_%H65K(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]S=&$@4FEC82(*;7-G<W1R(")+;W-T87)I:V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B!3;&]N;VMOQ:'$C65N
M82!O8F%L82`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS
M9W-T<B`B4$=0(&YE(&UO<F4@Q:%I9G)I<F%T:2!S<&]R;\2-:6QA.B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B3FD@;6]G;V4@
M4$=0('!O9'!I<R!S<&]R;V5I;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+B(*;7-G<W1R(").:2!M;V=OQ(UE(%,O34E-12#%H6EF
M<FER871I('-P;W)OQ(UI;&$N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M
M97-S86=E+B(*;7-G<W1R(").:2!M;V=OQ(UE(%,O34E-12!P;V1P:7,@<W!O
M<F_$C6EL82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S(@IM<V=S='(@(DYI(&UO9V_$C64@9&]D871I('-T
M:6MO=BX@)7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HT.#(*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O
M($Q$05`@<V5R=F5R+B(*;7-G<W1R(")0;W9E>F%V82!Z($Q$05`@<W1R9<6^
M;FEK;VT@;FD@;6]G;\2-82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(DYI(&UO
M9V_$C64@:V]N=')O;&ER871I(#\_/S\_/R`E<RXB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-#8V"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B4&]V97IA=F$@>B!,1$%0('-T<F7%OFYI
M:V]M(&YI(&UO9V_$C6$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E
M<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").92!M;W)E;2!V
M>G!O<W1A=FET:2!P;W9E>F%V92!S('-T<F7%OFYI:V]M(%PB)7-<(B!Z('5P
M;W)A8F\@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE
M(&UO<F5M('5S='9A<FET:2!S97IN86UA('IA(&1I<W1R:6)U8VEJ;RX@)7,B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DYI(&UO
M9V_$C64@9&7%H6EF<FER871I(%!'4"!P;V1A=&MO=CHB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(DYI(&UO9V_$C64@9&7%
MH6EF<FER871I(%,O34E-12!P;V1A=&ME+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B
M3F4@;6]R96T@:7IB<FES871I('-T:6MO=BX@)7,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R(").92!M;W)E;2!I>F)R:7-A=&D@9&ES=')I8G5C:6IS
M:V5G82!S97IN86UA+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(").92!M;W)E;2!I
M>F)R:7-A=&D@;F%S=&%V:71V96YE(&'%OG5R86-I:G-K92!S:W)I<'1E(%PB
M)7-<(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U
M;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E
M<W,N(@IM<V=S='(@(DYI(&UO9V_$C64@9&]L;\2-:71I(&5L96MT<F]N<VME
M9V$@;F%S;&]V82!P<F5J96UN:6MA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").:2!M;V=O
MQ(UE(&1O;&_$C6ET:2!C96QO=&YE9V$@:6UE;FEK82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*
M;7-G<W1R(").:2!M;V=OQ(UE(&1O;&_$C6ET:2!C96QO=&YE9V$@9&ES=')I
M8G5C:6IS:V5G82!S97IN86UA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*
M;7-G<W1R(").:2!M;V=OQ(UE(&1O;&_$C6ET:2!C96QO=&YE9V$@<V5Z;F%M
M82!D:7-T<FEB=6-I:G-K:6@@<V5Z;F%M;W8B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV
M.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B3FD@;6]G;\2-
M92!N86QOQ;YI=&D@<W1R871E9VEJ92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B
M3F4@;6]R96T@='9O<FET:2!M87!E(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DYI
M(&UO9V_$C64@9&]B:71I(&IA=FYE9V$@:VQJ=<2-82!O9"!K;&IUQ(UN96=A
M('-T<F7%OFYI:V$N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DYI(&UO9V_$C64@;V1P<F5T:2!<(B5S7"(@>F$@<&ES
M86YJ92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(DYI(&UO9V_$C64@;V1P<F5T:2`E<RXB"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R(").:2!M;V=OQ(UE(&]D<')E=&D@;6]D
M=6QA(&\@;W!R879I;'5?=GID<L6^979A;FIA("5S("(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").:2!M;V=OQ(UE('!R96)R
M871I(&EM96YI:R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS
M9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(").:2!M;V=OQ(UE(&1O<V7$C6D@3$1!4"!S=')EQ;YN:6MA+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(").:2!M;V=OQ(UE
M('!R96)R871I("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D
M971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@HB3FD@;6_%OFYO('!O;F%S=&%V:71I(&=E<VQA('IA
M('IA:'1E=F%N96=A('5P;W)A8FYI:V$N($YE:V%T97)E(&%L:2`B"B)V<V5P
M;V1R;V)N;W-T:2!N:7-O('!R879I;&YE+B!0;W-K=7-I=&4@>FYO=F$@86QI
M(&MO;G1A:W1I<F%J=&4@(@HB=F'%H65G875P<F%V:71E;&IA+"#$C64@<&]T
M<F5B=6IE=&4@;F%D86QJ;FIO('!O;6_$C2XB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M04-,(@IM<V=S='(@(DYI('5S<&5L;R!V>G!O<W1A=FET:3H@)7,@(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B3FD@=7-P96QO('9Z<&]S=&%V:71I(&EM
M96YI:V$Z("5S("(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3FD@
M=7-P96QO('9Z<&]S=&%V:71I(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M83H@
M)7,@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3FD@=7-P96QO
M('9Z<&]S=&%V:71I(&1I<W1R:6)U8VEJ<VME9V$@<V5Z;F%M83H@)7,@(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS
M9W-T<B`B3FD@=7-P96QO('9Z<&]S=&%V:71I.B`E<R`B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(EIA:'1E=F%N:2`G)7,G(&YI('!O9')O
M8FYO(&]B;&EK;W9A;B!V("5S('!O9&]B:2XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB
M)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I(&UA<&4@7"(E<UPB
M+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B5S(&MO;F9I9W5R86-I:F4@;FD@;6]G;\2-92!S:')A;FET:2XB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BXB"FUS9W-T<B`B2V]N9FEG=7)A8VEJ92!V87)N;W-T;F4@
M:V]P:6IE(&YI(&UO9V_$C64@<VAR86YI=&DN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2V]N9FEG
M=7)A8VEJ92!V87)N;W-T;F4@:V]P:6IE(&YI(&UO9V_$C64@<VAR86YI=&DZ
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,3`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M('-H<F%N:71I(&YA
M<W1A=FET=F5N92!AQ;YU<F%C:6IS:V4@<VMR:7!T92!N83H@7"(E<UPB+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(DYE(&UO<F5M('-H<F%N:71I(&MO;F9I9W5R
M86-I:G-K;R!D871O=&5K;R`E<RP@=F%R;F]S=&YE(&MO<&EJ92XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DYE(&UO<F5M('-H<F%N
M:71I("!K;VYF:6=U<F%C:6IS:V4@9&%T;W1E:V4@)7,N($QA:&MO('5P;W)A
M8FET92!A;&D@96YO(&]D("(*(F]P8VEJ('IA('-H<F%N:71I(&MO9&\@>F%D
M86H@;F$@)7,@86QI(')OQ(UN;R!K;W!I<F%T92!S<&]D;FIO(&MO9&\@;F$@
M)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(").:2!M;V=OQ(UE(&ES:V%N:F4@3$1!4"!S=')EQ;YN:6MA+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3FD@;6]G;\2-92!O9'-T<F%N
M:71I('!O=F5Z879E('H@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B3FD@
M;6]G;\2-92!AQ;YU<FER871I('-T:6LN("5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(DYI(&UO9V_$C64@8<6^=7)I<F%T:2!D:7-T<FEB=6-I
M:G-K:2!S97IN86TN("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U
M<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DYI(&UO9V_$C64@;F%P
M:7-A=&D@:V]N9FEG=7)A8VEJ92!Z82!<(B5S7"(Z("5S(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,W,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@
M36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E
M;BXB"FUS9W-T<B`B3F4@;F%J9&5M($UO>FEL;&$@4VED96)A<BX@4')E=F5R
M:2!A;&D@:F4@;V1P<G0N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R(")<(B5S7"(@=7!O<F%B
M;FEK=2!N92!M;W)E;2!D;V1E;&ET:2!S;&5D9<2-:6@@<')A=FEC('IA(&UA
M<&\@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,S(*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")0<F7%H71E=&\@8F5S
M961I;&\@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S`*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B1'+%OF%V82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(D-O=7)S97,B"FUS9W-T
M<B`B5&7$C6%J:2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@
M(E5S='9A<FDB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDV"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(E5S='9A
M<FD@;F]V;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B57-T=F%R
M:2!P;V1M87!E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B079T;W(@
M9&]V;VQJ96YJ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S0Y.0IM
M<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(L6@=&5V:6QK82!K
M<F5D:71N92!K87)T:6-E("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA
M(@IM<V=S='(@(DAR=F'%H6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*
M;7-G<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED
M(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(E-E9&%N:F4@-"!R87IV;VIN
M92!S=&]P;FIE(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#
M=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(E-E9&%N:F4@<V5J92(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS-0IM<V=I
M9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(E-E9&%N:FD@Q(UA<R(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G
M<W1R(")3961A;FII('5P;W)A8FYI:VDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,P"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B4V5D86YJ
M92!V<F5M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*
M;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B4V5D86YJ92!S
M=&%N:F4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(DYA<W1A=FET92!A:W1I=FYO<W1I+"!K:2!S
M92!B;V1O(&EZ=G+%H6EL92!O8B!P<FEJ879I(&YA("5S+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#:7!E<B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G
M<W1R(")#:7)I;&EC82A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@
M(D-I<FEL:6-A("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*
M;7-G<W1R(")#:7)I;&EC82]5:W)A:FEN<VMI("A+3TDX+54I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`BQ(UEQ:%K82!R
M97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4V('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*
M;7-G<W1R(")$1"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,U-3D*
M;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T
M<B`B(@HB1$Y3("AP;V=L96H@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO
M96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@
M(D1A:6QY(@IM<V=S='(@(D1N979N;R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H
M<#HV,PIM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(")0<F5G;&5D
M;W9A;&YI:R!D<F5V97-N92!S=')U:W1U<F4B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS-34W"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T
M<B`B4&]I>G9E9&)A(&)A>F4@<&]D871K;W8B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V.#8*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T=6TB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R(")$871U;2!P<F5J96UA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S`W-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB
M"FUS9W-T<B`B27IB:7)A(&1A='5M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q
M-`IM<V=I9"`B1&%Y(@IM<V=S='(@(D1A;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,3<*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<X"FUS9VED(")$96-E;6)E<B(*;7-G
M<W1R(")$96-E;6)E<B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S
M='(@(E!R:79Z971O(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B
M4')I=GIE=&$@0F%R=F$B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(E!R
M:79Z971A(&ED96YT:71E=&$B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-S4*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4')I=GIE=&$@;'5P
M:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")/<')E9&5L:71V92(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S`@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G
M<W1R("):8G)IQ:%I(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3<@861M:6XO
M9W)O=7!S+G!H<#HR,C4*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("):
M8G)IQ:%I('-K=7!I;F\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B6F)R:<6A:2!D;F5V
M;FEK(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B6F)R:<6A:2!D;W9O;&IE;FIE(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B27IB<FG%H6D@:6X@
M<')EQ(UI<W1I('-P;W)OQ(UI;&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T-PIM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R("))>F)R:<6A:2!O8G-T;VIEQ(UI(&%L=&5R;F%T:79N:2!V
M>F]R96,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(DEZ8G)IQ:%I
M('-P;W)OQ(UI;&$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R(%PB)7-<(B(*;7-G<W1R("))>F)R:<6A:2!D;W9O;&IE;FIA('IA(%PB
M)7-<(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("))>F)R:<6A
M96T@9&]V;VQJ96YJ92!Z82!<(B5S7"(@:6X@=G-A('!O9&1O=F]L:F5N:F$_
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM
M<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S='(@(DEZ8G)I
MQ:%I(&EZ8G)A;F\@:61E;G1I=&5T;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B27IB<FG%H6D@<&]D(&UA<&4B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D
M('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R
M96T@:7IB<FES871I(&YA<W1A=FET=F5N92!AQ;YU<F%C:6IS:V4@<VMR:7!T
M92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM
M92(*;7-G<W1R("+$C&%S(&1O<W1A=F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M96YM87)K(@IM<V=S='(@(D1A;G-K82(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C(W"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*
M;7-G<W1R(")/<&G%H6ET92!T9<6^879O(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.30W"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")/<&ES
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#8*;7-G:60@(D1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B4&]D
M<F]B;F]S=&D@*'1U9&D@=B!(;W)D;W9I(&QO9R!D871O=&5K:2DZ(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,3`*;7-G:60@(D1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S
M='(@(E!O9')O8FYO<W1I('-O(&)I;&4@<')I:F%V;&IE;F4@>F$@=7!R879L
M:F%L8V$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-0IM<V=I
M9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B4F%Z=F]J(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,CD*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")2;W-I
MQ:'$C64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")2;W-IQ:'$C64@>F$@
M<')E:L6A;FIO('5R;SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(Q"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")2;W-IQ:'$C64Z
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R
M>2(*;7-G<W1R("));65N:6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E!R
M:6MAQ;YE;2#$C6%S('!O(#(T('5R;F5M('-I<W1E;74_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM
M<V=S='(@(DYA<W1A=FET=F4@<')I:V%Z;W9A;FIA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.CDT"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D
M(&9O<F5C87-T(@IM<V=S='(@(E!R:6MAQ;YI('!O9')O8FYO(&YA<&]V960B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.CDW"FUS9VED(")$:7-P;&%Y(&9O
M<F5C87-T("A4048I(@IM<V=S='(@(E!R:6MAQ;YI(&YA<&]V960@*%1!1BDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#@W"FUS9VED(")$:7-P
M;&%Y(&9O<FUA="(*;7-G<W1R(")0<FEK8<6^:2!V96QI:V]S="(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET
M:6]N($YO=&EF:6-A=&EO;B(*;7-G<W1R(")/8G9E<W1I;&\@;R!D;W-T879L
M:F5N:2!P;\6A=&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G
M<W1R(")$Q;YI8G5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYE('IB<FG%
MH6DB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@
M(DYE(&1O<W1O<&%J(&YE<&]S<F5D;F\@9&\@;VAR86YJ86YJ82YP:'`@(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C
M;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O
M>#HB"FUS9W-T<B`B06QI('!R=F$@=G)S=&$@=G-E8G5J92!I;65N82!P;VQJ
M/R#$C64@:FEH+"!P<F5V97)I(&YA8FER86QN:6LZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M"FUS9VED(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&]M:6YI:V%N
M<VMA(%)E<'5B;&EK82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.#@*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B3FES=&4@<F5G:7-T<FER86YI/R!296=I<W1R:7)A:G1E('-E+B`B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B4')E;F5S
M:2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*;7-G:60@(D1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M(@IM<V=S='(@(E!R96YE<VET92!G96YE<FER86YO(&MO;F9I9W5R86-I:F\@
M:V]T(%!(4"!S:W)I<'1O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S.34*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(E!A9&%J;\2-
M:2!M96YI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")$
M<G5G<R(*;7-G<W1R("):9')A=FEL82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX,PIM<V=I9"`B1'EN86UI8R!-86EL(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-
M86EL(@IM<V=S='(@(D5L96MT<F]N<VMI(&YA<VQO=B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I
M;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P
M<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B4')E;F]S(&5L96MT<F]N
M<VMI:"!S<&]R;\2-:6P@=B!335,M:F4@>F$@;W!E<F%T97)J92P@:VD@=&\@
M;VUO9V_$C6%J;RXB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R
M(")%:W9A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%
M9&ET(@IM<V=S='(@(E5R961I(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")5<F5D:2!S
M=&]L<&5C(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.38@861M:6XO9W)O=7!S
M+G!H<#HR,C0*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B57)E9&D@<VMU
M<&EN;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIE(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(T,@IM<V=I9"`B161I="!097)M:7-S:6]N
M<R(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIA(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(T-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")5<F5D:2!D;W9O;&IE;FIA('IA
M("5S("(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(E5R961I(&UOQ;YN;W-T:2!Z83HB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B57)E9&D@9&]V;VQJ96YJ82!Z82!<(B5S7"(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E5R961I(&1O=F]L:F5N
M:F$@>F$@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@
M(D5D=6-A=&EO;B(*;7-G<W1R("))>F]B<F'%OF5V86YJ92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:7!T(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W
M"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")386QV861O<B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-PIM<V=I9"`B16UA:6PB"FUS9W-T<B`B
M16QE:W1R;VYS:V$@<&_%H71A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8Y"FUS
M9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5L96MT<F]N<VMI(&YA<VQO
M=B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-3$*;7-G:60@(D5M
M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;&5K=')O;G-K
M:2!N87-L;W8@<V4@;6]R82!U:F5M871I+B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z-#4P"B,L(&9U>GIY"FUS9VED(")%;6%I;"!A
M9&1R97-S97,@=&\@8V]N9FER;2!N;W0@9F]U;F0N(@IM<V=S='(@(D5L96MT
M<F]N<VMI(&YA<VQO=B!S92!M;W)A('5J96UA=&DN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(W-PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B16QE:W1R;VYS:V$@<&_%H71A(',@<&]T<F1I='9I
M:F\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B16UA
M:6PM4TU3(%!R96AO9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HS,#,*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")3;67%
MH6MI(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")0<F%Z
M96YO('-P;W)OQ(UI;&\N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G
M<W1R(")0<F%Z96X@<F5Z=6QT870N(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(E!R87IE;B!I<VMA;&YI:R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU-#4*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R
M;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(DEZ:VQO<&EM
M('9S=&%V;&IA;FIE('-L:6L@:7H@1F]T;R!'86QE<FEJ92!V('1E:W-T/R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3(*;7-G:60@(D5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(DEZ:VQO<&EM(&UE
M;FD@>B!D97-N:6T@:VQI:V]M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(X-S8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S`X,0IM<V=I9"`B
M16YD('EE87(B"FUS9W-T<B`B2V]N96,@;&5T82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E
M<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@
M<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B)6;F5S:71E('9A<FYO<W1N
M;R!V<')AQ:%A;FIE+"!K:2!B;R!P;W-T879L:F5N;RP@Q(UE(&)O<W1E("(*
M(G!O=')E8F]V86QI<&]N87-T879I=&D@=F'%H64@9V5S;&\L(&YP<BX@PX+B
M@)YI;64@=F'%H65G82!L:G5B;&IE;L2-:V$@:F4_.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R
M('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R(")6;F5S:71E('-P;V1N:F4@
MQ(UR:V4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B
M"FUS9W-T<B`B16MV871O<FEA;&YA($=V:6YE:F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS
M9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96IA(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+U9I97<N<&AP
M.CDT(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU,PHC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C0Q"FUS9VED(")%<G)O<B(*;7-G<W1R(").87!A:V$B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS
M9W-T<B`B3F%P86MA('!R:2!U<W1V87)J86YJ=2!S=&]L<&$Z("5S+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R
M(").87!A:V$@<')I(&)R:7-A;FIU('!O=F5Z879E('-I;FAR;VX@:7IA8VEJ
M93H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B
M"FUS9W-T<B`B3F%P86MA('!R:2!B<FES86YJ=2!D;F5V;FEK82!S:6YH<F]N
M:7IA8VEJ93H@)7,N(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<R(*;7-G<W1R(").87!A:V$@<')I('!O=F5Z;W9A;FIU.B`E
M<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM
M<V=S='(@(DYA<&%K82!P<FD@8<6^=7)I<F%N:G4@9V5S;&$Z("5S+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(").
M87!A:V$@>B!E;&5K=')O;G-K:6T@<W!O<F_$C6EL;VTN(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET
M:6YG(%PB)7-<(BXB"FUS9W-T<B`B3F%P86MA('!R:2!P:7-A;FIU(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I
M;W!I:F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(D5T
M:&YI8R(*;7-G<W1R(")%<W1O;FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5V<F]P82(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,#$@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G
M<W1R(")6<V%K:6@@,34@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B5G-A:VD@
M,B!M:6YU=&DB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(E9S
M86MI:"`S,"!S96MU;F0B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3`P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S
M='(@(E9S86MI:"`U(&UI;G5T(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E
M+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T
M<B`B5G-A:V$@<')I:F%V82(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E
M<GD@:&%L9B!H;W5R(@IM<V=S='(@(E9S86ME('!O;"!U<F4B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`S"B,L(&9U>GIY"FUS9VED(")%
M=F5R>2!H;W5R(@IM<V=S='(@(E9S86ME('!O;"!U<F4B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R
M>2!M:6YU=&4B"FUS9W-T<B`B5G-A:V\@;6EN=71O(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*
M;7-G<W1R(")0<FEM97(@=G)E9&YO<W1I.B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,"!A9&UI;B]C;61S:&5L;"YP:'`Z-#D@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-@IM<V=I9"`B17AE8W5T92(*;7-G<W1R("))>G9E9&DB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM
M<V=I9"`B17AP86YD(@IM<V=S='(@(E!O=F7$C6%J(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD
M(%-I9&5B87(B"FUS9W-T<B`B2V]N96,@;&5T82(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*
M;7-G<W1R(")0<FG$C6%K;W9A;B`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E!R:<2-86MO=F%N82!J
M92!B:6QA(&)E<V5D82!A;&D@8F5S961N82!Z=F5Z82!V(&YA=F5D;FEC86@B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")$871U;2!Z87!A9&QO<W1I(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(EIA<W1O<&YI:R(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ-S8*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS
M9W-T<B`B1E10(&YA;&_%OFET978@;F%M97-T:71V92XB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR-3$*;7-G:60@(D9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R(").:2!U<W!E;&\@=GIP;W-T
M879I=&D@<')E9F5R96YC92XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM
M<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(E!O=F5Z879A('H@3$1!4"!S=')EQ;YN:6MO;2!N:2!U<W!E;&$N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C$P,0IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B4&]V97IA
M=F$@<R!334(@<W1R9<6^;FEK;VT@;FD@=7-P96QA("(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-S$Q(&9R86UE=V]R:R]61E,O5D93+W-S:#(N
M<&AP.C<Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F
M<F]M(%PB)7-<(BXB"FUS9W-T<B`B2V]P:7)A;FIE(&EZ(%PB)7-<(BP@;FD@
M=7-P96QO+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$V(&9R
M86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DMO<&ER
M86YJ92!N82!<(B5S7"(L(&YI('5S<&5L;RXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-A<VPN<&AP.C@Y"FUS9VED(")&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DYI('5S<&5L;R!V>G!O<W1A
M=FET:2!N;W9O(%-!4TP@<&]V97IA=F\N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HU,#8@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-C4*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z-S<P"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B
M3FD@=7-P96QO('!R96UA:VYI=&D@:SH@)7,@(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HT-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(')E=')I979E.B`E<R(*;7-G<W1R(").96UO9V_$C64@<')E8G)A=&DZ
M("5S("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$X"FUS9VED(")&86ER(@IM<V=S='(@(D]D9&%L:FYO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@
M(D9A;&ML86YD<VMI(&]T;VMI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@
M27-L86YD<R(*;7-G<W1R(")&97)S:VD@;W1O:VD@(@H*(SH@9G)A;65W;W)K
M+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@
M(DAU9&$@;F%P86MA(2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8U"FUS9VED(")&87AE<R(*;7-G
M<W1R(")&87AI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C@*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E8G)U87(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B1F5E;',@3&EK92(*
M;7-G<W1R(")0;\2-=71I=&D@<V4@:V]T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R-0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(E!OQ(UU=&ET:2!S92!K;W0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@
M(DYE:V%J(&YA;&EV;W8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M(").96MA:B!S;F7%OFYI:"!M971EQ;YE=B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R,S(*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-
M871R:6-A('!O;&IA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S8Q
M,@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#
M2$$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-C$V"FUS9VED(")&
M:6=L970@9F]N="(*;7-G<W1R(")&:6=L970@<&ES879A(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:63%OFDB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`B1&%T
M;W1E:V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L6@
M=&5T:F4@1&%T;W1E:SH@)7,@9&%T;W1E:R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z
M("5S(&9I;&5S(@IM<V=S='(@(L6@=&5T:F4@1&%T;W1E:SH@)7,@9&%T;W1E
M:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S`*;7-G:60@(D9I
M;&4@36%N86=E<B(*;7-G<W1R(")5<')A=FET96QJ(&1A=&]T96LB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM
M<V=S='(@(DEM92!D871O=&5K92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R-C4*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(DEZ8FER
M82!D871O=&5K92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#DY
M"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(").86QOQ;YI(&1A=&]T96MO
M(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`W"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&]D86YA
M(&1A=&]T96MA(&YI('!O9'!R=&$N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.CDX"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B1FEN<VMA(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R(")0<G9A('!O;&]V:6-A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T
M(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*
M;7-G<W1R(")0<G9A(,2-971R=&EN82(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R(")3=&%L;F4@=F5L:6MO<W1I(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R(")/
M8G)N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B365G;&$B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(V,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES="(*;7-G<W1R("(E<R!M87!A(&YE(&]B<W1A:F$@(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")&;V]D(@IM<V=S='(@(DAR
M86YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#8*;7-G:60@(D9O<F5C
M87-T("A4048I(@IM<V=S='(@(DYA<&]V960@*%1!1BDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S<*;7-G:60@(B(*(D9O<F5C87-T($1A
M>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B
M;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U
M;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B1&YE=FD@;F%P
M;W9E9&DN("A.87!O=F5D82!L92!L86AK;R!Z96QO(&1O;&=A*2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.30*;7-G:60@(D9O<F=O="!Y;W5R
M('!A<W-W;W)D/R(*;7-G<W1R(")3=&4@<&]Z86)I;&D@=F'%H64@9V5S;&\_
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-0IM<V=I9"`B1F]R
M;7,B"FUS9W-T<B`B;V)L:6ME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(V"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E-R9<2-82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HQ,#0*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G
M<W1R(")3<F7$C64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G
M:60@(D9O<G1U;F5S(@IM<V=S='(@(E-R9<2-92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-`IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")3<F7$
MC64@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S8*;7-G:60@
M(D9O<G5M<R(*;7-G<W1R(")486)L82!P;V=O=F]R;W8B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M(")0<F5U<VUE<FET979E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B1G(B"FUS9W-T<B`B1G(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@
M365T<F]P;VQI=&%N(@IM<V=S='(@(D9R86YC:6IA+"!+;VQO;FEA;&YA(&UE
M=')O<&]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS
M9W-T<B`B1G)A;F-O<VMA($=V86IA;F$@(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B1G)A;F-O<VMA(%!O;&EN97II
M:F$@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,B"FUS9W-T<B`B1G)A;F-O<VMI(&IUQ;YN:2!T97)I=&]R:6H@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,`IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,U,@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDX"FUS9VED
M(")&<F]M('1H92`B"FUS9W-T<B`B3V0@(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-#(*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4&]L;B!/<&ES.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T
M<B`B4&]L;F$@;'5N82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-2!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8Q"FUS9VED(")&=6QL
M($YA;64B"FUS9W-T<B`B4&]L;F\@:6UE(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B1V%M8FEJ82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R(")5<W1V87)I("5S($YA<W1A=FET=F4B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ-@IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)I<F%J(&MO9&\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=R=7II:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(DYE;<2-:6IA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B1V%N82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@
M3F%M92(*;7-G<W1R(")$86YO(&EM92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-SD@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I
M;VYS(@IM<V=S='(@(E-P;&_%H6YE($UOQ;YN;W-T:2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R(")0;VID:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B1V]E9&5L(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&]V
M92!M87!E(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B
M1V]O9VQE(%-E87)C:"(*;7-G<W1R("))Q:'$C6D@>B!';V]G;&]M(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I
M9"`B1W)A>7-C86QE(@IM<V=S='(@(DQE<W1V:6-A('-I=FEN92`B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM<V=S='(@(D=RQ(UI:F$B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B1W)E96L@*$E33RTX.#4Y
M+3<I(@IM<V=S='(@(D=RQ:%K:2`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E;FQA;F1I:F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(D=R96YA9&$B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$W.`IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B4VMU<&EN<VMA(&%D;6EN:7-T<F%C:6IA(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R("));65N82!3:W5P:6X@;F4@<VUE:F\@8FET:2!P
M<F%Z;F$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A
M9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R(")!=71H7VQD87`Z($YE(&UO<F5M(&1O9&%T:2!S:W5P:6YE("5S
M+B!3<&]R;\2-:6QO('-T<F7%OFYI:V$Z("(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B4VMU<%]L9&%P.B!.92!M;W)E
M;2!I>F)R:7-A=&D@<VMU<&EN92`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(E-K=7!?;&1A<#H@3F4@
M;6]R96T@;F%D9W)A9&ET:2!S:W5P:6YE("5S(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P
M<R(*;7-G<W1R(")3:W5P:6YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L
M;W5P92(*;7-G<W1R(")'=6%D96QO=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T
M96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B1W5E<FYS
M97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S
M:6]N<R(*;7-G<W1R(")$;W9O;&IE;FIA('IA(&=O<W1E(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C0Y,PIM<V=I9"`B1W5E<W1B;V]K(@IM<V=S
M='(@(DMN:FEG82!G;W-T;W8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B
M"FUS9W-T<B`B1W9I;F5J82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R(")'=FEN96IA+4)I<W-A;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=V86IA;F$B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY-CD*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-
M3"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z,34T"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B3W9E
M<FIE;F5G82!(5%10($YI<V5M(&YAQ:%E;"XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G
M<W1R(")(87-H($%L9V]R:71E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S8*;7-G:60@(B(*(DAA=F4@82!B=71T;VX@:6X@=&AE('1O;VQB87(@
M=&AA="!P;W!S('5P(&$@=VEN9&]W('=I=&@@<W!E8VEA;"!C:&%R86-T97)S
M/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")-96=L:6-A(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3(X(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R,#(*;7-G:60@(DAE861E<B(*;7-G<W1R(")';&%V82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G
M:60@(DAE861E<G,B"FUS9W-T<B`B1VQA=F4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R
M(")(96%R9"!O=&]K(&EN($UC1&]N86QD;W9O(&]T;\2-:F4B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A
M=GD@5"U3=&]R;2(*;7-G<W1R(")-;\2-;F$@;F5V:6AT82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M
M22DB"FUS9W-T<B`B2&5B<F5J<VMI("A)4T\M.#@U.2TX+4DI(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,C(*;7-G:60@(DAE:6=H="(*;7-G<W1R(")6
M:<6A:6YA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X
M,2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@R"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X+FEN
M8SHT"FUS9VED(")(96QP(@IM<V=S='(@(E!O;6_$C2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S.#0*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")0
M;VUOQ(UL;FEK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(E!O;&]B;&$B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*
M;7-G<W1R(")4=6MA:B!J92!Z8<2-971E:R!D871O=&5K93HB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B2&EG
M:"(*;7-G<W1R(")6:7-O:V\B"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN
M8SHW"FUS9VED(")(;U]M92(*;7-G<W1R(")$;VUO=B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S
M='(@(E9A=&EK86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")$;VUA
MQ(UI(&YA<VQO=B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I
M9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B26UE;FEK(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R(")$;VUAQ(UI('1E;&5F;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#4R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED
M("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($YE=F5L:F%V96X@)7,@6$U,('!O9&%T96L@;F%J
M9&5N('8@<W!O<F_$C6EL=2`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3F]B96YO('-P;W)OQ(UI;&\@<V4@;F4@=6IE;6$@<R!P
M<F5D;65T;VT@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@5B!S<&]R;\2-:6QU("5S(&YI(&YA:F1E;B!N;V)E;B!P<F5D
M;65T('1I<&$@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F
M=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M57-P9<6A;F\@;V1S=')A;FIE;B`E<R!<(B5S7"(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5G<F%C:6IS:V$@
M;F%P<F%V82!Z86AT979A("=D;VUX;6PG(%!(4"!E:W-T96YZ:6IO(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE(&UO
M<F4@=7-T=F%R:71I(&YO=F\@6$U,(&1R979O('IA("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0X"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE(&UO<F5M(&]D<W1R86YI=&D@)7,@
M7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#@S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@3F4@;6]R96T@<&]I>G9E9&5T:2!Z82!-24U%
M($E$('IA(&1E;"!O9"!V<G-T92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z($YE(&UO<F5M('-I;FAR;VYI>FER871I("5S(%PB
M)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.
M92!M;W)E;2!S:6YH<F]N:7II<F%T:2!D96QE.B`E<R(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@3F5Z;F%N82!D96QI=&5V(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B2V]L:6MO('!O;&H@*'-T
M;VQP8V5V*6IE('1A;3\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDS(&QI8B]";&]C:R]M971A<BYP:'`Z,C0R"FUS9VED(")(=6UI9&ET
M>2(*;7-G<W1R(")6;&'%OFYO<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4S"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(E9L8<6^
M;F]S=#H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED(")(
M=6UO<FES=',B"FUS9W-T<B`B2'5M;W)I<W1I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED(")(=6YG87)Y(@IM<V=S='(@(DUA9,6^87)S:V$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S`@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(S-`HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")5<W1V87)J86YJ
M92!)34%0(&YA8FER86QN:6MA(&YI('5S<&5L;SH@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(Y-@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")"<FES86YJ92!)
M34%0(&YA8FER86QN:6MA(&YI('5S<&5L;SH@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-S<@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(T,0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")5<W1V87)J
M86YJ92!K=F]T92!)34%0(&YA8FER86QN:6MA+"!N:2!U<W!E;&\Z("5S(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,R-0IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("))4"!.87-L;W8B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(DE0($YA<VQO=B!N:2!N82!R87IP;VQA9V\N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS
M9W-T<B`B25`@3F%S;&]V(&YI('8@9&]V;VQJ96YI($-)1%(@<VMU<&EN:2XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B
M6F%K;&5N:F5N($E0+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*
M;7-G<W1R("))<VQA;F1I:F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@P"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(E-A;6\@:6MO;F4B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(DEK;VYE('IA("5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B26-O;G,@=VET:"!T97AT
M(@IM<V=S='(@(DEK;VYE('H@8F5S961I;&]M(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R
M("))9&5N=&EF:6MA8VEJ<VMO(&EM93HB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HV,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(E<R!Z82!O9'!R971I('8@;F]V
M96T@;VMN=2P@Q(UE(&YI('!R879I;&YO('!R:6MA>F%N;RXB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B
M"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I
M;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HBQ(UE('9I9&ET92!T;R!S
M<&]R;\2-:6QO(&EN('-L:<2-:6-E(&YE+"!P;VUE;FDL(&1A('9AQ:$@8G)S
M:V%L;FEK(&YE(&UO<F4@(@HB;V1P<F5T:2!S;&G$C6EC92P@:VD@:F\@Q;YE
M;&ET92!N86QOQ;YI=&DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<W-`IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D1O9&%J('-L:6MO
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*
M;7-G<W1R(")3;&EK92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S
M='(@(E9N;W,L($MO<F%K("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z
M("5S(@IM<V=S='(@(E9N9<6A96YO('!O;&IE.B`E<R(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB
M"FUS9W-T<B`B5FYEQ:%E;F$@<&]L:F$Z(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(E!O<W)E9&]V86X@;F5P<F%V:6QE
M;B!U:V%Z+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(").97!R879I;&YO('5P;W)A8FYIQ:%K;R!I
M;64@:6XO86QI(&=E<VQO+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(DYE<')A=FEL;F\@=7!O<F%B;FG%H6MO(&EM92!A;&D@86QT97)N871I
M=F5N(&YA<VQO=BX@4&]S:W5S:71E('IN;W9A(&%L:2`B"B)K;VYT86MT:7)A
M:G1E('9AQ:%E9V$@<VMR8FYI:V$L(,2-92!P;W1R96)U:F5T92!N861A;&IN
M:F\@<&]M;\2-+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T
M<B`B26YD:6IA(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B4&]S86UE>FYI(%5P;W)A8FYI:VD@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B26YD;VYE
M>FEJ82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@
M(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%C:6IE(&\@<V5S=&%N:W4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"FUS9VED("))
M;F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O
M<FUA8VEJ92!N:7-O('9EQ(T@9&]S96=L:FEV92XB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.0IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M92(*;7-G<W1R(")6<W1A=FD@86QT97)N871I=F5N('9Z;W)E8R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.B(*;7-G<W1R(")6<W1A=FET92!E;&5K=')O;G-K:2!N87-L;W8@
M;F$@:V%T97)E9V$@;&%H:V\@<')E:FUE=&4@;F]V;R!G97-L;SHB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS
M97)T(&UE<W-A9V5S(@IM<V=S='(@(E9S=&%V:71E('-P;W)OQ(UI;&\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,S"FUS9VED("));G-E<G0@=&AE
M(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM
M<V=S='(@(E9P:<6A:71E('IA:'1E=F%N(&]D9V]V;W(@;F$@=F%R;F]S=&YO
M('9P<F'%H6%N:F4Z(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@
M=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(E-T
M86YJ92!N82!R8<2-=6YU(&YE('IA9&]S='5J92!Z82!P;\6A:6QJ86YJ92!N
M82#%OF5L:F5N('-P:7-E:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B4W1A;FIE(&YA(')AQ(UU;G4@;F4@>F%D;W-T=6IE
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#0*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`B0V5L;R#%H71E=FEL;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-#(*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R
M(")397IN86T@8V5L:6@@Q:%T979I;"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B3F5V96QJ879E;B!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*
M;7-G<W1R(").979E;&IA=F5N(%I)4"!P;V1A=&5K+B`B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R(").979E;&IA=FYA(&%P;&EK86-I:F$N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED
M("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(").979E;&IA=FYI($E$('!A
M:V5T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0T-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3(P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B
M26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B3F5V96QJ879N:2!P
M;V1A=&MI('-O(&)I;&D@;V1P;W-L86YI+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI
M9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(").979E;&IA=F5N(&YA
M<VQO=B!N87-L;W9N:6MA+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S
M='(@(B!.979E;&IA=FYA(&]B;&EK82!D871O=&5K92`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<P"FUS9VED("));G9A;&ED(&QI8V5N
M<V4@:V5Y+B(*;7-G<W1R(").979E;&IA=F5N(&QI8V5NQ(UN:2!K;&IUQ(TN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-`IM<V=I9"`B
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3V1R96IE;B!N
M979E;&IA=F5N(&MR86HN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E
M+B(*;7-G<W1R(").979E;&IA=F5N('1I<%]M<V<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("))
M;G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R(").979E;&IA=F5N
M(&%L:2!M86YJ:V%J;\2-(&%P:5]I9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.38*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+B(*;7-G<W1R(").979E;&IA=FYI(&%L
M:2!M86YJ:V%J;\2-:2!P87)A;65T<FDN(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(V"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(").979E;&IA=FYO(&1O=F]L:F5N:F4@<W1A<L6A978N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-@IM<V=I9"`B26YV
M86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(").979E;&IA=F5N('!A<G1N97)J
M978@:60N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.`IM
M<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(DYE=F5L:F%V
M;F$@:V]D82!A<G1I:VQA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O
M;"XB"FUS9W-T<B`B3F5V96QJ879E;B!P<F]T;VMO;"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(DYE=F5L:F%V
M96X@;F%S;&]V;FEK.B!<(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$P.#`@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8S"FUS
M9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(@3F5V96QJ879E
M;B!O8FIE:W0@9&5L:F5N:F$@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R(").979E;&IA=F5N(&EZ=F]R;FD@;F%S;&]V
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@
M(B!.979E;&IA=F5N('5N:6MO9"!P;V1A=&5K(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,W,PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN
M=F5N='5R82]P;W!I<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV.#`*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T
M<B`B3V)R;FD@:7IB;W(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A;BP@27-L86US:V$@4F5P
M=6)L:6MA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(DER
M86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B27)S
M:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B
M27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS
M(@IM<V=S='(@(E!O<V%M97IN92!N979I:'1E(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("))<W)A96PB"FUS9W-T<B`B27IR865L(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G<W1R
M("))>F1A:F%T96QJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G
M<W1R("))=&%L:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM
M<V=S='(@(DIA;6%J:V$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-PIM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU87(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N<VMA
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DIA<&%N97-E
M("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B2F%P;VYS:VD@*$E33RTR,#(R+4I0
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*
M97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*
M;W)D86XB"FUS9W-T<B`B2F]R9&%N:6IA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(DIU;'DB"FUS9W-T<B`B
M2G5L:6HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B2G5N92(*;7-G<W1R(")*=6YI:B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA:'-T86XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED
M(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")/8F1RQ;YI;2!I>G9I<FYI:S\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;FEJ82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#8*;7-G:60@(DME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B2V5R8F5R;W,@<W1R9<6^;FEK('IA=G)N:6P@;W9E<FET978N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED(")+97)N96P@3F5W8FEE
M<R(*;7-G<W1R(")+97)N96P@;F]V:6YC:2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S
M='(@(E5S='9A<FD@2VQJ=<2-("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@
M(D]D=&ES($ML:G7$C6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B1&]LQ;YI;F$@
M2VQJ=<2-82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5&EP($ML:G7$C6$@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME
M>2!5<V%G92(*;7-G<W1R(")5<&]R86)A($ML:G7$C6$@(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D
M>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(DML
M:G7$C2#%OF4@;V)S=&%J82!N82!J879N96T@:VQJ=<2-;F5M('-T<F7%OFYI
M:W4N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED(")+:61S
M(@IM<V=S='(@(D]T<F]C:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A
M=&DB"FUS9W-T<B`B2VER:6)A=&D@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+
M;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R
M(")+;W)E:F$L($1E;6]K<F%T:<2-;F$@;&IU9'-K82!R97!U8FQI:V$@(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B2V]R96IA+"!297!U8FQI:V$@(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")+;W)E:G-K
M:2`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S
M='(@(DMU=F%J="`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB
M"FUS9W-T<B`B2VER9VEZ:6IA("(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S4*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DIE>FEK(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U
M8FQI8R(*;7-G<W1R("),86]S(&QJ=61S:V$@9&5M;VMR871IQ(UN82!R97!U
M8FQI:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T
M($AA;&8B"FUS9W-T<B`B6F%D;FIA('!O;&]V:6-A(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C@X"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*
M;7-G<W1R("):861N:F$@<W!R96UE;6)A(&=E<VQA.B`B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),
M87-T(%%U87)T97(B"FUS9W-T<B`B6F%D;FIA(,2-971R=&EN82(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED("),87-T(%5P9&%T960Z(@IM
M<V=S='(@(EIA9&YJ92!AQ;YU<FER86YJ93HB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`B6F%D;FIA('!R:6IA=F$Z("5S("(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(EIA9&YJ82!P<FEJ879A
M.B`E<R!I>B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B6F%D;FIA('!R:6IA
M=F$Z($YI:V]L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S
M='(@(DQA='9I:F$@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Y"FUS
M9VED("),87<B"FUS9W-T<B`B4')A=F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQE8F%N;VXB"FUS9W-T<B`B3&EB86YO;B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S.#@*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(DQE
M=F\@;V=L879L:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S@T
M"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")6<F5D;F]S=&D@;F$@;&5V
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O
M=&\B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@
M(DQE=F5L(@IM<V=S='(@(E)A=F5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:6)E<FEA(@IM<V=S='(@(DQI8F5R:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED
M("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(DQI8FEJ82`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EE
M8VAT96YS=&5I;B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R(")286AE
M;"!P<L6A96,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")286AE;"!D9<6^
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*
M;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B6F=O9&%J(')A:&5L
M(&1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(E!O>FYO(')A
M:&5L(&1EQ;XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B4&QO
M:&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B4&QO
M:&$@>B!G<FUE;FIE;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S='(@(E)A:&5L
M('-N96<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B4VYEQ;YN
M:2!M971EQ;XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*(RP@9G5Z
M>GD*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI8F5R:6IA(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@R-PIM<V=I9"`B3&EN:R(*;7-G<W1R
M(")0;W9E>F%V82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,3,*
M;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B4&]V9<6^:2!E+6YA<VQO
M=B!S(&]B<F%Z8V5M('IA('-E<W1A=F\@;F]V92!P;\6A=&\@;64@<')I:V%Z
M;W9A;FIE;2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M
M;#)T97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(E!O=F5Z879E
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED("),:6YU>"!#
M;V]K:64B"FUS9W-T<B`B3&EN=7@@<&G%H6MO=&5K(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R(")397IN86T@+2!U<&]R86)N
M:6L@;&%H:V\@=FED:2!M87!O(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,@IM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T<B`B4V5Z;F%M('!O9&%T
M:V]V;FEH(&)A>B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS
M9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(E-E>FYA;2!496T@4&]M
M;\2-:2`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,Q"FUS9VED("),:7-T
M(%1A8FQE<R(*;7-G<W1R(")397IN86T@=&%B96PB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Q-@IM<V=I9"`B3&ES="U!<F-H:79E
M(@IM<V=S='(@(B!397IN86T@07)H:79A("(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3$Q"FUS9VED("),:7-T+4AE;'`B"FUS9W-T
M<B`B4V5Z;F%M(%!O;6_$C6D@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU,3@*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B4V5Z;F%M
M($ED96YT:71E="`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Q-`IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R(")397IN86T@3&%S
M=&YI:V]V("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3$U"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B4V5Z;F%M(%!OQ:%T92`B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Q,PIM<V=I
M9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B4V5Z;F%M(%!R:6IA=B`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Q,@IM<V=I9"`B
M3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R(")397IN86T@3V1J878@(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")3<&ES96L@<V5Z
M;F%M82!S96H@;FD@=7-P96PZ("5S+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B4V5Z;F%M('5P;W)A8FYI:V]V(&YI(&UO9V_$C64Z
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS
M9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")397IN
M86T@=7!O<F%B;FEK;W8@;FD@;6]G;\2-+B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU,@IM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T
M=7)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS9W-T<B`B
M3&ET=F$@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S
M+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(").86QA9V%M+BXN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(DQO:V%L;FD@Q(UA<SHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#8*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*
M;7-G<W1R("),;VMA;&EZ86-I:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C(*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A
M<BYP:'`Z-S<*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(DUE<W1O(@H*(SH@
M;&]G:6XN<&AP.C$X."!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`T
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX
M,@IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(E!R:6IA=F$B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U
M<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B3V1J879A(',@<')E9&AO9&YE('-Y
M;F,@<V5J92`B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3DX
M"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D]D:F%V82(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV,0IM<V=I9"`B3&]G:6XB"FUS9W-T<B`B4')I:F%V
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO9VEN
M(%1A<VMS(@IM<V=S='(@(E!R:6IA=F$@;F$@;W!R879I;&$B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN(@IM<V=S='(@(E!R:6IA=F$@;FD@=7-P96QA+B!5<&]R
M86)N:<6A:V\@:6UE(&%L:2!G97-L;R!N97!R879I;&YO('9N9<6A96YO(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F
M86EL960N(@IM<V=S='(@(E!R:6IA=F$@;FD@=7-P96QA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,W.`IM<V=I9"`B3&]N9R!T97AT(@IM<V=S
M='(@(D1O;&=O($)E<V5D:6QO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4S"FUS9VED("),;W9E(@IM<V=S='(@(DQJ=6)E>F5N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DQO=R(*
M;7-G<W1R(").:7IE:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R
M9R(*;7-G<W1R("),=6MS96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0S('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.3<*;7-G:60@(DU/5$0B"FUS9W-T<B`B4W!O<F_$C6EL;R!D
M;F5V82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A
M=&$N(@IM<V=S='(@(DU3+51.148@4')I<&]N:V$@;FD@=G-E8F]V86QA('!O
M9&%T:V]V+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M(")-4T<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA
M8V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36%K961O;FEJ82P@
M9F]R;6%L;F$@2G5G;W-L;W9A;G-K82!R97!U8FQI:V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B36%G:6,B"FUS9W-T
M<B`BQ(UA<F]B96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3`*
M;7-G:60@(DUA:6PB"FUS9W-T<B`B16QE:W1R;VYS:VD@;F%S;&]V(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4T-@IM<V=I9"`B36%I;"!!9&UI
M;B(*;7-G<W1R(")!9&UI;FES=')A=&]R('!OQ:%T92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%V:2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L97II:F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I=FDB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N
M(@IM<V=S='(@(B(*(E5R961I=&4@<V5Z;F%M(&MA=&5G;W)I:B!S(&MA=&5R
M:6UI(&)O<W1E(&]Z;F'$C6EL:2!P;W-T879K92!I;B!P<FEP861A:F_$C64@
M(@HB8F%R=F4@>F$@=&4@:V%T96=O<FEJ92XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I9"`B36%P,C0@;6%P
M(@IM<V=S='(@(EIE;6QJ979I9"!-87`R-"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#@W"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,3<Q"FUS9VED(")-87!1=65S="!M
M87`B"FUS9W-T<B`B6F5M;&IE=FED($UA<%%R97-T(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N
M(@IM<V=S='(@(E-H<F%N:F5N92!P;W9E>F%V92(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87)C:"(*;7-G
M<W1R(")-87)E8R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS
M9W-T<B`B3WIN8<2-:2!Z('IA<W1A=FEC86UI(%9I9&5N;R].979I9&5N;R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R(")/>FYAQ(UI('H@;W-T86QI;6D@>F%S=&%V:6-A;6DH
M;G!R+B!0;VUE;6)N;R]/9&=O=F]R:F5N;RDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G
M:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B36%R<VAA;&QO=F\@;W1O
MQ(UJ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R
M(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")5:F5M86YJ92!P
M;VQJ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@
M(DUA=G)E=&%N:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B
M"FUS9W-T<B`B36%V<FEC:75S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C
M<F5D:70N(@IM<V=S='(@(DYE:G9EQ(T@9&]V;VQJ96YI('IN97-E:R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@
M(DUA:W-I;6%L;FD@9&5L:2!S<&]R;\2-:6QA('!R96MO<F'$C65N:2XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q.`IM<V=I9"`B36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@(@IM<V=S='(@(DUA:W-I;6%L;F$@=&5M<&5R871U<F$@
M>F%D;FII:"`R-"!U<CHB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM
M<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B36%K<VEM
M86QN82!T96UP97)A='5R82!Z861N:FEH(#8@=7(Z(@H*(SH@;&EB+V%P:2YP
M:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B
M"FUS9W-T<B`B36%K<VEM86QN;R#%H71E=FEL;R!B;&]K;W8@<&]R=&%L82(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C(V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M-#@*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(DUA:W-I;6%L;F$@
M9&]LQ;YI;F$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW,0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA:B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B36%Y;W1T92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B
M6F1R879I;&\@*$UE9&EC:6YA*2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BQ(UL86YI
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M
M;V1E.B(*;7-G<W1R(")4:7`@;65N:6IA.B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S
M86=E(@IM<V=S='(@(E-P;W)OQ(UI;&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E-P;W)OQ(UI
M;&\@:F4@8FEL;R!U<W!EQ:%N;R!P<F5V97)J96YO+"!T;V1A('!O9'!I<VYI
M:V]V96=A('!O=')D:6QA(&YI(&)I;&\@(@HB;6]G;\2-92!P<F5V97)I=&DN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E-P;W)O
MQ(UI;&\@:F4@<&]T96ML;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S
M86=E('1Y<&4B"FUS9W-T<B`B5&EP(%-P;W)OQ(UI;&$B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B
M365T87(@=G)E;64B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C0R"FUS9VED
M(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")-971A<B!B
M;&]K(&YI(&YA(')A>G!O;&%G;RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$R-`IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T
M86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B4&]D<F]B;F]S=&D@<V\@8FEL92!P<FEJ879L:F5N92!Z82!U
M<')A=FQJ86QC82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34X"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(DUE=&%R1$(@;FD@<&]V97IA;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G<W1R(")0;W-T;W!E:R(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K
M+U)00R]24$,O<&AP9W<N<&AP.C@X"B,Z(&9R86UE=V]R:R]24$,O4E!#+W!H
M<&=W+G!H<#HX.2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE
M9"(*;7-G<W1R("(G)7,G('!O<W1O<&5K(&YI(&1O;&_$C65N+B(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS
M9W-T<B`B4&]S=&]P96L@;FD@9&]L;\2-96XN(%!O<W1O<&5K(&-E;&EC93H@
M)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B365T<FEC(@IM<V=S='(@(DUE=')I
MQ(UN:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE
M:&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T
M960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O;F5Z:6IA+"!&961E<F%T:79N
M82!D<L6^879A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4:7`@9&%T;W1E
M:V4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,@IM<V=I9"`B36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DUI;FEM86QN82!T96UP97)A
M='5R82!Z861N:FEH(#(T('5R.B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$T"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")-
M:6YI;6%L;F$@=&5M<&5R871U<F$@>F%D;FII:"`V('5R.B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,X"FUS9VED(")-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(DUI;FEM
M86QN82!S=&%R;W-T(&=E<VQA(,6A92!N:2!P;W1E:VQA(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0IM<V=I9"`B36ER
M<F]R(@IM<V=S='(@(D]G;&5D86QO(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4V"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(DUN;V=O<W1R
M86YS:V$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="XB"FUS9W-T<B`B4&]G<F7%H6%N(%!%05(@<&%K970L($A45%`@
M>F%H=&5V86XN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-`HC+"!F
M=7IZ>0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@;75S
M="!G96YE<F%T92!I="!B969O<F4@=7-I;F<@=&AI<R!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`B(@HB4&]G<F7%H6%N82!K;VYF:6=U<F%C:6IA+B#$C64@Q;YE
M;&ET92!U<&]R86)L:F%T:2!T;R!A<&QI:V%C:6IO+"!M;W)A=&4@(@HB9V5N
M97)I<F%T:2!K;VYF:6=U<F%C:6IO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M
M97-S86=E($E$+B(*;7-G<W1R(")0;V=R9<6A86YO($E$('-P;W)OQ(UI;&\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E
M($UA:6PN(@IM<V=S='(@(E!O9W)EQ:%A;F\@<W!O<F_$C6EL;R!O('IA:'1E
M=F%N96T@4$5!4B!P86ME='4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I
M;VX@240N(@IM<V=S='(@(E!O9W)EQ:%A;F$@240@<V5J82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")-
M;R(*;7-G<W1R(")0;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW
M-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B36]B:6QN82!P;\6A=&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B6FUE<FYO(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T
M<B`B1&%T=6T@<W!R96UE;6)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B36]D=6QI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*
M;7-G<W1R(")-;VQD879I:F$L(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%K;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:6IA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@W,@IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B365S96,@:6X@;&5T;R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T
M<B`B365S9<2-;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B
M"FUS9W-T<B`B36]N='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS
M9W-T<B`B3'5N:6YE(&UE;F4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L('!H
M<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@
M=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(E8@=G)S=&D@)60@:F4@
M;F%J9&5N:6@@=F7$C2!P;VQJ(&]D('!R961V:61E;FEH("5D+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:V\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B
M36]S=&QY($-L96%R(@IM<V=S='(@(E!R971EQ;YN;R!J87-N;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-
M;W-T;'D@0VQO=61Y(@IM<V=S='(@(E!R971EQ;YN;R!O8FQAQ(UN;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED
M(")-;W-T;'D@0VQO=61Y(&%N9"!7:6YD>2(*;7-G<W1R(")0<F5T9<6^;F\@
M;V)L8<2-;F\@:6X@=F5T<F]V;F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S
M='(@(E!R971EQ;YN;R!S;V[$C6YO(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#@*;7-G:60@(DUO=F4@1&]W;B(*
M;7-G<W1R(")0;VUA:VYI('-E(&1O;"(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B4&]M86MN:2!S92!V(&QE=F\B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2
M:6=H="(*;7-G<W1R(")0;VUA:VYI('-E('8@9&5S;F\B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B
M36]V92!5<"(*;7-G<W1R(")0;VUA:VYI('-E(&=O<B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S`*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R(")0;VUA:VYI('-E(&1O;"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S,`IM<V=I9"`B36]V92!U<"(*
M;7-G<W1R(")0;VUA:VYI('-E(&=O<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R(")-;WIA;6)I:R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-S(*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W
M;B!L:7-T<R(*;7-G<W1R(")69<2-(&YI=F]J;FD@<&%D86IOQ(UI('-P:7-K
M:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B375L=&EM87`@
M54L@>F5M;&IE=FED+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M,S`*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")-;F]G;VMR
M871E;B!I>F)O<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C,*
M;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B36]J(')AQ(UU;B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O
M<FUA=&EO;B(*;7-G<W1R(")0;V1A=&MI(&UO:F5G82!R8<2-=6YA(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HV-`IM<V=I9"`B37D@4&]R=&%L
M(@IM<V=S='(@(DUO:B!P;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z,S0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B3V)L
M:6MA(&UO:F4@<')V92!S=')A;FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY
M86YM87(B"FUS9W-T<B`B36IA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@
M06=R964B"FUS9W-T<B`B3F4L('-E(&YE('-T<FEN:F%M(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B26UE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB
M:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYI
M>F]Z96US:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT
M:6QL97,B"FUS9W-T<B`B3FEZ;WIE;7-K:2!!;G1I;&DB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@;W-N;W9N:2!54DPB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B($YE='-C87!E($-!
M(%523"!Z82!P<F5K;&EC(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS
M9W-T<B`B3F%S;&]V($YE='-C87!E(&-E<G1I9FEK871A(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E
M(%)E;F5W86P@55),(@IM<V=S='(@(B!.971S8V%P92!O8FYO=FET=F5N:2!5
M4DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM
M<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B($YE='-C
M87!E(%523"!Z82!P<F5K;&EC(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M
M92(*;7-G<W1R(").971S8V%P92!34TP@:6UE('-T<F7%OFYI:V$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S8V%P92!U
M<F%D;FD@:V]M96YT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R(")4:7`@3F5T<V-A<&4@8V5R=&EF:6MA=&$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C8W"FUS9VED(").971W;W)K(@IM<V=S='(@
M(D]M<F7%OFIE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(U('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY-PHC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*
M;7-G:60@(DYE=F5R(@IM<V=S='(@(DYI:V]L:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W9A($MA;&5D;VYI:F$B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(DYO=F$@:V%T96=O
M<FEJ82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO
M;VXB"FUS9W-T<B`B3F]V82!,=6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHS-@IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA
M;"DB"FUS9W-T<B`B3F]V;R!U<&]R86)N:<6A:V\@:6UE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").;W9A(%IE;&%N9&EJ
M82(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B
M3F5W('!A<W-W;W)D(@IM<V=S='(@(DYO=F\@9V5S;&\B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-Q;"YP:'`Z,C0Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B3F]V
M;R!G97-L;R!B;R!P;W1E:VQO("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"XB"FUS9W-T<B`B3F]V;R!G97-L;R!S92!N92!U:F5M82XB"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(").;W9I8V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(Q"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(DYO=FG$C6%R<VMA('-K
M=7!I;F$B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM
M<V=I9"`B3F5X="(*;7-G<W1R(").87-L961N:FDB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B3F%S
M;&5D;FIE(#0@<W1O<&YJ92(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS
M9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B3F%S;&5D;FIA(&UOQ;YN;W-T
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE
M>'0^(@IM<V=S='(@(DYA<VQE9&YJ:3XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G=F$B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS
M9VED(").:6=E<FEA(@IM<V=S='(@(DYI9V5R:6IA(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,W,@IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B
M3FEG97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C8*;7-G:60@(DYO(@IM<V=S='(@(DYO8F5D96XB"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM
M<V=S='(@(DYI(&1O<W1O<&YI:"!P;V1A=&MO=B!O(&MO;F9I9W5R86-I:FD@
M9&$@8FD@<&]K87IA;"!R87IL:6ME+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(")3=')A
M=&5G:6IA('IA(&EZ9&5L879O($E33R!S;&EK+"!N:2!D;W-T;W!N82XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R(").:2!P86ME
M=&YE('!R961L;V=E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,#$*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYA(,6^96QE
M;F5M(&UE<W0@8F5L9<6^:V$@;F4@;V)S=&%J82XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C8W"FUS9VED(").;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("):
M82!-0T%,(&]V97)I=&5V(&YI(&MO;&5D87)S:V5G82!I;65N82(*"B,Z(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S
M='(@(FYI('-P<F5M96YJ96YO(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(DYA('1E:B!S=&]P;FII(&YE
M(&1O9&%J86UO(&]T<F_%H6MI:"!D;W9O;&IE;FHN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,3,*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B6F$@)7,@;FD@<W!E8VEF:6-I<F%N
M:6@@:V]N9FEG=7)A8VEJ<VMI:"!I;F9O<FUA8VEJ+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#0V"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B
M6F$@1E10(%9&4R!N:2!P;W-E8FYI:"!I;F9O<FUA8VEJ+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-S$P"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T
M<B`B(%IA(%-13"!61E,@;FD@<&]S96)N:6@@:6YF;W)M86-I:BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S<U"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R("(@6F$@9&%T;W1E:V\M4U%,(%9&4R!N:2!P;W-E
M8FYI:"!I;F9O<FUA8VEJ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N
M<&AP.C@W,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-32#(@5D93+B(*;7-G<W1R("(@6F$@
M4U%,(%9&4R!N:2!P;W-E8FYI:"!I;F9O<FUA8VEJ+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DYI('-T86YJ82!N82!R8<2-=6YU
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T
M<B`B3FD@9&5S=&EN86-I:F4B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HY,C4*;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B
M3FD@;F%L;\6^96YI:"!D871O=&5K+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(DYE(&YA
M:F1E;2!I:V]N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,C$@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3,U"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(DUE<W1O(&YI(&YA<W1A=FQJ96YO+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-C(*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*
M;7-G<W1R(")-97-T;R!N:2!N87-T879L:F5N;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@
M;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B3F]B96YO('-P;W)OQ(UI;&\@
M9&]S=&%V;&IE;F\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R(").:2!S<&5C:69I8VER86YO(&YO8F5N;R!I;64N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G
M:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYI('-P96-I9FEC
M:7)A;F\@;F]B96YO(,6A=&5V:6QO+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY.0IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(DYO8F5N:6@@;V9E;GII=FYI:"!S<F7$C2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@=&\@
M=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA
M<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M(@IM<V=S='(@(B(*(E!O="!D;R!B:6YA<FYE(&1A=&]T96ME($]P96Y34TP@
M;FD@8FEL82!N87-T879L:F5N82X@3W!E;E-33"!B:6YA<FYA("(*(F1A=&]T
M96MA(&IE('!O=')E8FYA('IA(&1E;&\@<R!02T-3(#$R('!O9&%T:VDN(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B
M3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R(").92!S<')E:F5M86UO('IA
MQ(UA<VYI:"!P<FEJ878B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#$X
M"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(DMV;W1A(&YI(&YA<W1A
M=FQJ96YA+V1O;&_$C65N82XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT.#(*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S
M='(@(DYI('-P96-I9FEC:7)A;F\@;&_$C6EL;RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4W-@IM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S
M='(@(DYI('1A:V4@9&%T;W1E:V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3,Q"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(DYE(&YA:F1E;2!Z8<2-87-N
M92!M87!E('IA('!R961P;VUN:6QN:6LN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").;V)E;F\@=7!O<F%B
M;FG%H6MO(&EM92!I;B]A;&D@9V5S;&\@;FD@8FEL;R!P;W-L86YO+B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P(&9R86UE=V]R:R]2
M4$,O4E!#+W!H<&=W+G!H<#HQ-S4*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(E!O=G)A=&YI:"!V96QJ879N:6@@6$U,('!O
M9&%T:V]V(&YI(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDW-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.34*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P,3(*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")"<F5Z('9R961N
M;W-T:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)6(&]R:6=I;F%L
M;FD@:V]N9FEG=7)A8VEJ:2!N92!N86ID96T@;F]B96YE(')A>FQIQ(UI8V4N
M($]B;F]V:71I("(*(FMO;F9I9W5R86-I:F\N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$R-PIM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R
M(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HB5B!V8<6A:2!K;VYF:6=U<F%C:6II(&YE(&YA:F1E;2!N;V)E
M;F4@<F%Z;&G$C6EC92X@3V)N;W9I=&4@:V]N9FEG=7)A8VEJ;RXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+W!R
M969S+VED96YT:71Y<V5L96-T+FEN8SHY-0IM<V=I9"`B3F]N92(*;7-G<W1R
M(").;V)E9&5N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(DYO<F1I:G-K:2`H25-/
M+3@X-3DM,3`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD
M(@IM<V=S='(@(DYO<F9O;,6A:VD@;W1O:VDB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(E-E=F5R;F$@<&]L;V)L82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S
M='(@(E-E=F5R;FD@36%R:6%N<VMI(&]T;VMI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").;W)W87DB"FUS9W-T<B`B3F]R=F7%H6MA(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R(").92!K87-N96IE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B3F4@
M<')E:B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0T-PIM<V=I
M9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(DYI(&EM96YI:R(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT
M.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM
M<V=S='(@(DYI(&EZ=F5D96YO+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@Y
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,C,V(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3,*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(P."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,T"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-3(@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C(V.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8X(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HS.#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0Q
M."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#<X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HU-3<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8R-@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-C0S(&9R86UE=V]R:R]61E,O5D93+G!H<#HW
M,C$*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C@R(&9R86UE=V]R
M:R]61E,O5D93+VAO<F1E+G!H<#HQ,S$*(SH@9G)A;65W;W)K+U9&4R]61E,O
M:&]R9&4N<&AP.C$U,2!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3<P
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HQ.#D@9G)A;65W;W)K
M+U9&4R]61E,O:&]R9&4N<&AP.C(P-PHC.B!F<F%M97=O<FLO5D93+U9&4R]H
M;W)D92YP:'`Z,C(W(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HS,S`*
M;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(DYE('!O9'!I<F%M(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#@@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC.B!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3$R,B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS
M9VED(").;W1E<R(*;7-G<W1R("):87!I<VMI(@H*(SH@<V5R=FEC97,O;V)R
M;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RXB"FUS9W-T<B`B3FD@=G!I<V%N:6@@8F5S960@>F$@:7-K86YJ
M92P@=G)N:71E('-E(&YA>F%J+B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,38*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<W"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").
M;W9E;6)E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-34*;7-G
M:60@(DYU;6)E<B(*;7-G<W1R("+%H'1E=FEL;R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T,S@*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S
M(@IM<V=S='(@(L6@=&5V:6QO('IN86MO=B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30S-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4X"FUS9VED(").=6UB97(@
M;V8@8V]L=6UN<R(*;7-G<W1R("+%H'1E=FEL;R!S=&]L<&-E=B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.#`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30S-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4V"FUS
M9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("+%H'1E=FEL;R!V<G-T:6,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN
M9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3FD@<W!E8VEF:6-I
M<F%N:6@@Q:%T979I;&L@>F$@8<6^=7)I<F%N:F4@:6X@9&ES=')I8G5C:6IS
M:VD@<V5Z;F%M+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("):861E=F$B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T
M($-R96%T;W(B"FUS9W-T<B`B57-T=F%R:F%L96,@<')E9&UE=&]V(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q,PIM<V=I9"`B3V-T86PB"FUS
M9W-T<B`B3W-M:<6A:VDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-@IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/:W1O8F5R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDW"FUS9VED(")/9F9E;G-E
M(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S0R"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B4&ES87)N82(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N
M97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R(")3=&%R
M;R!I;B!N;W9O(&=E<VQO(&UO<F%T82!B:71I(')A>FQIQ(UN82XB"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S
M=V]R9"(*;7-G<W1R(")3=&%R;R!'97-L;R(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C
M;W)R96-T+B(*;7-G<W1R(")3=&%R;R!G97-L;R!N:2!P<F%V:6QN;RXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/
M;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G
M<W1R(")-87!E('8@<VMU<&YI('5P;W)A8FD@<&]D<&ER82!S86UO($E-05`@
M<W1R9<6^;FEK+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ,#`*;7-G
M:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(E-A;6\@;F5S
M<F%M;F4@:7IJ879E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U
M.0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G
M<W1R(")$;W9O;&IE;B!J92!L92!E;B!E;&5K=')O;G-K:2!N87-L;W8N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V-PHC+"!F=7IZ>0IM<V=I
M9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!I<R!A;&QO=V5D+B(*;7-G<W1R
M(")$;W9O;&IE;B!J92!L92!E;B!E;&5K=')O;G-K:2!N87-L;W8N(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C<P"FUS9VED("(B"B)/;FQY('1H
M92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W
M;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*
M;7-G<W1R("(B"B),92!L87-T;FEK(&%L:2!U<')A=FYI:R!S:7-T96UA(&QA
M:&MO('IA;65N:F$@;&%S=&YIQ:%T=F\@86QI(&QA<W1N:6MO=F\@(@HB9&]V
M;VQJ96YJ92!Z82!D96QEQ;XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,S8*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D]D<')I
M('8@;F]V96T@;VMN=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT
M<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R(")/
M9'!R=&%34TP@;F%P86MA.B!.92!M;W)E;2!P;W9Z971I(&1A='5M82!I>B!O
M>FYAQ(UE;F5G82!3+TU)32!D96QA+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.`IM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R
M871I=FYI('-I<W1E;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H
M<#HQ-34*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B36_%OFYO<W1I(@H*(SH@
M<V5R=FEC97,O<')E9G,N<&AP.C,R('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S
M='(@(DUOQ;YN;W-T:2!Z82`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B
M3W)G86YI>F%C:6IA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-CD*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T<B`B
M3W)G86YI>F%C:6IS:V$@96YO=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,30Q"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7IA
M8VEJ82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,T"FUS9VED(")/<FEG
M:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("))>G9I<FYE(,6A
M86)L;VYE(&%P;&EK86-I:B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$V
M"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E
M<SHB"FUS9W-T<B`B27IV:7)N:2#%H6%B;&]N92!V("5S.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PIM<V=I9"`B3W1H97(B"FUS9W-T<B`B1')U9V\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO
M;B(*;7-G<W1R(")/<W1A;&4@:6YF;W)M86-I:F4B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*
M;7-G<W1R(")$;W9O;&IE;FIA(&QA<W1N:6MA(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P86TN<&AP.C@P"FUS9VED(")004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W9E<FIE;FIE(&YI('5S<&5L
M;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z
M.B!G;VYI;&YI:R!0;\6A=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS
M9W-T<B`B1&EG:71A;&5N('!O9'!I<R!01U`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A
M=&$B"FUS9W-T<B`B2V]D:7)A;FD@4$=0('!O9&%T:VDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC
M($ME>2(*;7-G<W1R(")*879N:2!K;&IU92!01U`B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N
M8W)Y<'1E9"!$871A(@IM<V=S='(@(E!O9'!I<V%N:2]K;V1I<F%N:2!01U`@
M<&]D871K:2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV-PIM<V=I9"`B4$A0
M($-O9&4B"FUS9W-T<B`B4$A0(&MO9&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,3@*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@;'5P:6YA(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G
M:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&]P;VQD;F4@<F%H96P@9&7%
MOB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y
M"FUS9VED(")032!286EN(@IM<V=S='(@(E!O<&]L9&YE(&1EQ;XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B
M4$T@4VAO=V5R<R(*;7-G<W1R(")0;W!O;&1N92!N86QI=FDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R(")0;W!O;&1N92!S;F5G+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4&]P;VQD;F4@<VYEQ;YN:2!M971EQ;YI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@
M(E!-(%-U;B(*;7-G<W1R(")0;W!O;&1N92!S;VYC92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4+5-T
M;W)M<R(*;7-G<W1R(")0;W!O;&1N92!N979I:'1E(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(X-@IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<B"FUS9W-T<B`B4&]G<F7%H6%N82!03U-)6"!E:W-T96YZ:6IA(@H*
M(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@
M(E!(4"!L=7!I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM
M<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B
M"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN:VD@
M;VMU<&ER86YI('1E<FET;W)I:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N
M86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P
M=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.;W9A($=V:6YE:F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")087)A9W9A
M:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(D1E;&YO(&]B;&'$C6YO
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,P-@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8Y('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-#0*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T
M-@IM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B1V5S;&\B"@HC.B!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG
M960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")'97-L;R!U<W!EQ:%N;R!S<')E
M;65N:F5N;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DYE<')A
M=FEL;F\@9V5S;&\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34W"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("):82!2041)55,@;W9E<FET978@:F4@
M>F%H=&5V86YO(&=E<VQO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-#$*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(D=E<VQO(&EN('!O=')D:71E=B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(D=E<VQO
M.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")0
M87-S=V]R9#H@(@IM<V=S='(@(D=E<VQO.B`B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@
M;75S="!M871C:"XB"FUS9W-T<B`B1V5S;&\@<V4@;6]R82!U:F5M871I+B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3@*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(E!R:6QE<&DB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R(").97!O=')J96YE
M('!R:6IA=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@
M(E!E;W!L92(*;7-G<W1R("),:G5D:F4B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(DEZ=G+%H6D@=GID<L6^979A
M;&YA(&1E;&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(DEZ=G+%H6EM('9Z9'+%OF5V86QN82!D96QA(&]B('!R:6IA=FD_
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(E!E<FUI<W-I;VXB"FUS9W-T<B`B1&]V;VQJ96YJ92(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES
M<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(EPB)7-<(B!D;W9O
M;&IE;FIE(&YI(&EZ8G)I<V%N;RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4W.0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B
M1&]V;VQJ96YJ92!J92!Z879R;FIE;F\N(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(D1O=F]L:F5N:F$B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#@@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C4Y"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,2!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4W"FUS9VED(")097)M:7-S:6]N<R!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")5<')A=FYIQ:%K82!D;W9O;&IE;FIA(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")/<V5B;F4@:6YF;W)M86-I:F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4&5T<R(*;7-G<W1R("),:G5B
M;&IE;L2-:VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM
M<V=S='(@(D9I;&EP:6YI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O
M;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#$*;7-G:60@(E!H
M;W1O<R(*;7-G<W1R(")&;W1O9W)A9FEJ92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-3`*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!R;W-I;6\L
M(&1A('9N97-E=&4@;65S96,@:6X@;&5T;RXB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B4')O
M<VEM;RP@9&$@=FYE<V5T92!I;64@;F]V92!K871E9V]R:6IE.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,3`*;7-G:60@(E!L96%S92!E;G1E
M<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(E!R;W-I;6\L(&1A('9N
M97-E=&4@=F5L:F%V96X@25`@;F%S;&]V+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C@*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM
M<V=S='(@(E!R;W-I;6\L(&1A('9N97-E=&4@=F5L:F%V96X@9&%T=6TZ('!R
M979E<FET92#%H71E=FEL;R!D;FD@=B!M97-E8W4N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C<S-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92XB"FUS9W-T<B`B4')O<VEM;RP@9&$@=FYE<V5T92!P<F%V:6QE
M;B#$C6%S+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*
M;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE
M;2XB"FUS9W-T<B`B4')O<VEM;RP@9&$@<')I<')A=FET92!P;W9Z971E:R!T
M9<6^878N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")0<F]S:6UO
M+"!D82!S:2!I>F)E<F5T92!U<&]R86)N:<6A:V\@:6UE(&EN(&=E<VQO+B(*
M"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B(@HB4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS9W-T<B`B
M(@HB4')O<VEM;RP@<')E8F5R:71E('-L961EQ(UE(&)E<V5D:6QO+B#$C64@
MQ;YE;&ET92!U<&]R86)L:F%T:2!T82!S:7-T96TL('-E("(*(FUO<F%T92!S
M=')I;FIA=&D@<R!P;V=O:FDN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4')O<VEM+"!V;F5S:71E
M(&EM92!N;W9E(&MA=&5G;W)I:F4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`B4&]L:G-K82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$P"FUS9VED(")0;VQL<R(*
M;7-G<W1R(")!;FME=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A
M;"(*;7-G<W1R(")0;W)T=6=A;'-K82(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R
M("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B3V1D86H@=B!T;R!M
M87!O("AN:2!Z86AT979A;F\@;V0@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(W."!L:6(O0FQO8VLO;65T87(N<&AP.C(X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R(")0861A=FEN92!V('IA9&YJ:6@@)7,@=7)A:#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDQ"FUS9VED(")0<F5C:7!I
M=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(E!A9&%V:6YE/&)R("\^8VAA
M;F-E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.C$S.0IM
M<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(@4')E9G-?;&1A<#H@>F%H=&5V86YE9V$@3$1!
M4"!R87IT96=A(&YE(&YA:F1E;2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(S-PIM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B5&QA:R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<Q"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V
M96PZ("(*;7-G<W1R(")4;&%K(&YA(&UO<G-K:2!V:<6A:6YI.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,CD*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`B5&QA:SH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(P,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")0
M<F5D;V=L960B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U
M,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,U-@IM<V=I9"`B4')E
M=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0<F5JQ:%N:F4@;6_%OFYO<W1I(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R("):87-E8F5N(&ML:G7$C2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB
M"FUS9W-T<B`B4')O8FQE;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R
M-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("):(&]P:7-O
M;2!S;R!T9<6^879E+BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S@U"FUS9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]J96MT:2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C0W-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-38S"FUS
M9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")486MO:L6A;FIE(&)E<V5D:6QO
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED
M(")0=6)L:6,@2V5Y(@IM<V=S='(@(DIA=FYI(&ML:G7$C2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@
M2V5Y($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET96T@:F%V;F5G82!K;&IU
MQ(UA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*
M;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("));F9O<FUA8VEJ92!J
M879N96=A(&ML:G7$C6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E
M;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DIA=FYI+WIA<V5B;FD@
M<&%R(&ML:G7$C65V(&YI(&)I;"!U<W!EQ:%N;R!G96YE<FER86XN(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B4&]R=&]R
M:6MO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E!R9<2-:7-T:2!S
M<&]R;\2-:6QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C(*;7-G:60@(E%U
M97)Y(@IM<V=S='(@(E!O:7IV961B82(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HX,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B2W9O=&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")24T$@
M:F%V;FD@:VQJ=<2-("@E9"!B:71O=BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-34R"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B
M27IB97)I=&4@<F%D:6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R(")$9<6^(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@
M(E)A:6X@16%R;'DB"FUS9W-T<B`B1&7%OB!Z:G5T<F%J(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@
M3&%T92(*;7-G<W1R(")$9<6^('!O<&]L9&YE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R
M(@IM<V=S='(@(DYA;&EV(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B
M1&7%OB!I;B!S;F5G(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3`*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")$9<6^
M('8@<VYE9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")2
M86YD;VT@1F]R='5N92(*;7-G<W1R(")3<F7$C6$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(E)A
M>FUE<FIE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#`*;7-G:60@(E)E860B"FUS9W-T<B`B0F5R:2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S
M(@IM<V=S='(@(D)E<FD@<W!O<F_$C6EL;R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R(")3=&4@<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@>F)R:7-A
M=&D@)7,_($EZ8G)I<V$@;FD@;6]G;\2-92!P<F5K;&EC871I+B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)3
M=&4@<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@>F)R:7-A=&D@=7!O<F%B;FEK
M;W9E('!O9&%T:V4@>F$@=7!O<F%B;FEK825S/R`B"B))>F)R:7-A(&YI(&UO
M9V_$C64@<')E:VQI8V%T:2XB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*
M;7-G<W1R(")/<W9EQ;YI(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y
M-0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S
M='(@(D]S=F7%OFD@9&EN86UIQ(UN:2!M96YI(&5L96UE;G1O=CHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A
M;"!6:65W.B(*;7-G<W1R(")/<W9EQ;YI('!O<G1A;#HB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.30*(RP@9G5Z>GD*;7-G:60@(E)E9G)E
M<V@@<F%T93HB"FUS9W-T<B`B3W-V9<6^:2!P;W)T86PZ(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3`S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,C(*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T-`IM<V=I9"`B
M4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS-3$X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M("))<VMA;&YI:R!R87IM97)I:B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G
M:60@(E)E;&]A9"(*;7-G<W1R(")0;VYO=FYO(&YA;&_%OFDB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,S.`IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")0
M<FEP;VUB92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*;7-G:60@
M(E)E;6]T92!397)V97)S(@IM<V=S='(@(D]D9&%L:F5N:2!S=')EQ;YN:6MI
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")2
M96UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS
M9W-T<B`B3V1D86QJ96X@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z."!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")/9'-T<F%N:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU-C$*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B3V1S
M=')A;FD@<W1O;'!E8R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R(")/9'-T<F%N:2!P87(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`Q"FUS9VED(")296UO=F4@
M<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3V1S=')A;FD@<VAR86YJ96YO('-K<FEP=&\@:7H@<W1R
M9<6^;FEK;W9E('IAQ(UA<VYE(&UA<&4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R
M(")/9'-T<F%N:2!U<&]R86)N:6MA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U
M<V5R.B`E<R(*;7-G<W1R(")/9'-T<F%N:2!U<&]R86)N:6MA.B`E<R`B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S."!F<F%M97=O<FLO
M4E!#+U)00R]P:'!G=RYP:'`Z,3<S"FUS9VED(")297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("):
M86AT979I(&YE(&UO<F5M('5G;V1I=&DN(%9R;FIE;F$@:F4@;F%P8<2-;F$@
M:V]D83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,`IM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R(").92!N86ID96T@>F%H=&5V86YE9V$@<V5R=FES82XB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X-2!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C4R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("):86AT979A;FD@7"(E<UPB(&YI('!O9')O8FYO(&]B;&EK;W9A;B!V
M("5S(&MO;F9I9W5R86-I:FDN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HW,38@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3(*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z.#<V(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HT,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S@Q"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("):
M86AT979A;FD@7"(E<UPB(&YI('!O9')O8FYO(&]B;&EK;W9A;B!V(%9(4R!K
M;VYF:6=U<F%C:6II+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("):86AT979A;FD@
M)R5S)R!N:2!P;V1R;V)N;R!O8FQI:V]V86XN(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L
M9"(*;7-G<W1R("):86AT979A;F$@9&%T;W1E:V$B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-#@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C<X"FUS9VED(")297-E="(*;7-G<W1R(")0;VYA<W1A=FDB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@
M4&%S<W=O<F0B"FUS9W-T<B`B4&]N87-T879I(&=E<VQO(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`B4&]N87-T879I=&4@=F'%H64@9V5S;&\B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B3V)N;W9I=&4@>F%D;FIO('!O:7IV961B;R(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,"!A9&UI;B]C;61S:&5L;"YP:'`Z,C<@861M
M:6XO<W%L<VAE;&PN<&AP.C8U"FUS9VED(")297-U;'1S(@IM<V=S='(@(EIA
M9&5T:VDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I
M;VYS(@IM<V=S='(@(E9R;FD@<V4@;F$@36_%OFYO<W1I(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A
M<W-W;W)D(@IM<V=S='(@(E!O;F]V;F\@=G!IQ:%I=&4@;F]V;R!G97-L;R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4&]N;W9N
M;R!Z9')UQ;YI(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A
M=&EO;B(*;7-G<W1R(")0;W9R;FD@:V]N9FEG=7)A8VEJ;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R(")6<FYI('-E(&YA(&UOQ;YN;W-T:2!U<F5J979A
M;&YI:V$@8F5S961I;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*
M;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B16YI9VUE(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,Y,`IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S
M='(@(D1E<VYO(&]G;&%V:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S@V"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&5S;F4@=G)E
M9&YO<W1I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")&=6YK8VEJ82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B4F]M=6YI:F$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS
M9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D]B<FYI('IA(#$X,"(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(D]B<FYI(&YA(&QE=F\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2
M;W1A=&4@4FEG:'0B"FUS9W-T<B`B3V)R;FD@;F$@9&5S;F\B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3$Y"FUS9VED(")2=6XB"FUS9W-T<B`B6F'%OF5N
M:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R(")2=7-I:F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B
M"FUS9W-T<B`B4G5A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA
M='5R92(*;7-G<W1R("(@4R]-24U%(&MR:7!T;V=R869S:VD@<&]D<&ES(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@
M(E,O34E-12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R(")3+TU)344@:V]D
M:7)A;F\@<W!O<F_$C6EL;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S
M;"YP:'`Z.#(*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B4T%33"!/=F5R:F%N:F4@;FD@=7-P96QO(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R.`IM<V=I9"`B4TU3($UE
M<W-A9VEN9R(*;7-G<W1R(")335,@<W!O<F_$C6EL;R(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ.0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"!L
M=7!I;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-38Q"FUS9VED
M(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(E-1
M3"!S=&%V96L@>F$@<&]I>G9E9&)O('9R961N;W-T:2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-30*;7-G:60@(E-32"(*;7-G<W1R(")34T@B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(E53
M4$5((@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM
M<V=S='(@(E-13"!L=7!I;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8S"FUS9VED(")382(*;7-G<W1R(")382(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")3=F5T
M82!(96QE;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N
M9"!.979I<R(*;7-G<W1R(")386EN="!+:71T<R!A;F0@3F5V:7,@(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN="!,
M=6-I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<R(*;7-G<W1R(")386EN="!6:6YC96YT(&EN($=R96YA9&EN
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")3
M86X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD
M(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&EN(%!R:6YC:7!E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL
M:71E(%!R;W9I9&5R(@IM<V=S='(@(E-A=&5L:71S:VD@;W-K<F)O=F%L96,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B
M4V%U9'-K82!!<F%B:6IA(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C$Q-0IM<V=I9"`B4V%V92(*;7-G<W1R(")3:')A;FDB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(E-H<F%N:2!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E("5S(@IM<V=S='(@(E-H<F%N:2`E<R`B"@HC.B!T96UP
M;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS
M9W-T<B`B4VAR86YI($UOQ;YN;W-T:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C8*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y
M("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB4VAR86YI=&4@9V5N97)I<F%N
M;R!K;VYF:6=U<F%C:6IO(&MO="!02%`@<VMR:7!T;R!N82!Z8<2-87-N:2!M
M87!I("(*(G9AQ:%E9V%S=')EQ;YN:6MA9&ER96-T;W)Y+B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(E-H<F%N:F5N82`E<R!K
M;VYF:6=U<F%C:6IA(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B4VAR86YJ96YA(&YA<W1A=FET=F5N
M92!S:W)I<'1A(&YA9&=R861N:F4@;F$Z(%PB)7-<(BXB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E
M<F5D(%0M4W1O<FUS(@IM<V=S='(@(E)A>F1I=FIA;F$@;F5V:6AT82!Z(&=R
M;65N:F5M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")3
M8VEE;F-E(@IM<V=S='(@(EIN86YO<W0B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(DG%H<2-:2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,S8*;7-G:60@(E-E87)C:"!%;F=I;F5S
M(@IM<V=S='(@(DES:V%L;FEK:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R-#,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("))>F)E<FD@
M9&%T;W1E:V\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@Y"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(DEZ8F5R
M:2!D871U;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS
M9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B27IB97)I('-K
M=7!I;F\L(&MI(&IO(,6^96QIQ:$@9&]D871I+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*
M;7-G<W1R("))>F)E<FD@;F]V96=A(&QA<W1N:6MA(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B
M"FUS9W-T<B`B27IB97)I('-T<F7%OFYI:R(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("))>F)E<FD@=7!O<F%B;FEK82P@:VD@9V$@Q;YE;&G%H2!D;V1A
M=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-C<X"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(DEZ8F5R:2!V<V4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,Q"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B27IB97)I('!O<&]L;B!D
M871U;2(*"B,Z('-E<G9I8V5S+V5D:71O<B]X:6YH82]P;'5G:6YS+T%N<V5L
M26UA9V4O:6YS97)T7VEM86=E+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E-E
M;&5C="!A;B!I;6%G92(*;7-G<W1R("))>F)E<FD@9&%T=6TB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")3
M96QE8W0@86X@;V)J96-T(@IM<V=S='(@(DEZ8F5R:2!P<F5D;65T(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I
M9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B3V1K;&IU:V%J('9S92(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(EIN86ME+"!K:2!J:6@@<&]T<F5B=6IE=&4@
M:7IB97)I=&4@:7H@;VMV:7)J978@<W!O9&%J+B!.871O(&II:"!L86AK;R`B
M"B)K;W!I<F%T92!I;B!P<FEL97!I=&4@=B]I>B!B97-E9&EL82XB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CHB"FUS9W-T<B`B1&]L;\2-:2!K;V[$C6YI(&1A='5M
M.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R("))>F)E<FD@;V)L:6MO(&1A
M='5M83HB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDR"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93HB"FUS9W-T<B`B27IB97)I=&4@:61E;G1I=&5T;RP@:V%T97)O(,6^
M96QI=&4@<W!R96UE;FET:3HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T
M<B`B1&]L;\2-:2!K;V[$C6YO('5R;SHB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS
M9W-T<B`B27IB97)I(&]B;&EK;R!U<F4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(DEZ8F5R:2!D=F4@=6IE;6%J;\2-:2!S92!P;VQJ:3HB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(DEZ8F5R:71E('9AQ:%E(&)A
M<G9N;R!K;VUB:6YA8VEJ;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS
M9W-T<B`B27IB97)I=&4@:F5Z:6LZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z-3$*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B4&_%H6QJ:2!P;W)OQ(UI;&\@;R!N87!A:V%H(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#(*;7-G:60@(E-E
M;F0@4TU3(@IM<V=S='(@(E!OQ:%L:FD@4TU3(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM
M<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,C@*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(E-E;GIO
M<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-0IM<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(E-E<')E;6)E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B
M:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B4W)B:6IA(&EN(,2-<FYA(&=O
M<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,@IM
M<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R(")397)I:G-K82#%H71E=FEL
M:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34T"FUS9VED
M(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")3=')EQ;YN:6MO=B!D871U;2!J92!N87!AQ(UE;B!A;&D@;FD@;F$@<F%Z
M<&]L86=O+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-@IM<V=I9"`B4V5S
M<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')A8VEJ82!S96IE(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR
M"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DE$('-E:F4@
M:F4@<&]T96ML82XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G:60@(E-E<W-I
M;VYS(@IM<V=S='(@(E-E:F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C`R"FUS9VED(")3970B"FUS9W-T<B`B3F%M97-T:2(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL
M;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R
M9V5T(&ET+B(*;7-G<W1R("(B"B).87-T879I(&]P8VEJ;RP@9&$@=B!P<FEM
M97)U+"!D82!P;WIA8FET92!V8<6A92!G97-L;RP@;&%H:V\@<&]N87-T879I
M=&4@;&4M(@HB=&\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM
M<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*(E5R961I=&4@
M;V1D86QJ96YE('-T<F7%OFYI:V4@;F$@:V%T97)E(,6^96QI=&4@9&]S=&]P
M871I('H@=F'%H65G82!P;W)T86QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I
M;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(DYA<W1A=FET92!P
M<FEV>F5T(&IE>FEK(&EN(&YA<W1A=FET=F4@9&%T=6UA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U
M<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L
M(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(E5R961I
M('IAQ(UE=&YE(&)A<G9N92!S:&5M92P@87!L:6MA8VEJ92P@;W-V9<6^:71V
M92!S=')A;FDN+BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS
M9VED(")3971U<"(*;7-G<W1R(").86UE<W1I(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S4*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B3F%S=&%V:2!S:W)I<'1O('IA
M(&]S=F7%OFET978@:V]T(')A>G!O;&_%OFQJ:79O+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ.#`*;7-G:60@(E-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(DUO
MQ;YN:6@@:F4@=F7$C2!L;VMA8VEJ(',@<&%R86UE=')O;3HB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E:L6A96QI(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q.0IM<V=I9"`B4VAO<'!I
M;F<B"FUS9W-T<B`B3F%K=7!O=F%N:F4B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R
M(")+<F%T96L@<&]V>F5T96LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`B3F%T879I;2!T:7!K87)S:V4@8FQIQ;YN
M:6-E(&YA('!O=F5Z879E/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(E!O:V'%OFDB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34T"FUS9VED("(B"B)3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E!O
M:V'%OFD@<F%Z;&EK92!M960@<V5D86H@<VAR86YJ96YO(&EN(&YA:FYO=F5J
MQ:%O(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#@U"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(E!R:6MAQ;YI(&1A='5M('IA9&YJ
M92!P<FEJ879E('!O('9S=&]P=3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-S<X"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M(@IM<V=S='(@(E!R:6MAQ;YI(&]P8VEJ92!Z82!O8F1RQ;YA=&D@;W)I9VEN
M86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#@S"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R(")0;VMAQ;YI('1I<W1E9V$L(&MI('-P<F5J
M96UA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,`IM<V=I9"`B4VAO
M=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*;7-G<W1R(")0<FEK8<6^
M:2!M96YI:G-K;R!V<G-T:6-O(&1E;&]V86YJ82!T86)E;&4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S4S"B,L('!H<"UF;W)M870*;7-G:60@(E-H
M;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S='(@(E!R:6MAQ;YE
M;2`E<R!M96YI(&YA(&QE=FD@<W1R86YI/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W-S8*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(D1O
M9&%J(&YA;&%G86YJ92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S(@IM<V=S='(@(E!L;VAE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B6FIU=')A:B!P;&]H92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED
M(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4&]P;VQD;F4@<&QO:&4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B
M4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B5B!B;&G%OFEN:2!P
M;&]H92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z-C$Y"FUS9VED(")3:')I;FLB"FUS9W-T<B`B4VMRQ(UI(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY,3`*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HY
M-S(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,#4X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3$R,`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA
M;F%G97(N<&AP.C$Q.#,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HQ,C(S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,3(U,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R.#4*;7-G:60@(E-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M="(*;7-G<W1R(").86IP<F5J('-K<L2-:2!A;&D@<')E;6%K;FD@<V]S961N
M:F4@8F5L9<6^:V4N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C<*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M4')I:F%V:2!S92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I
M9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UIQ(UE;B!P;V1P
M:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
M4VEN9V%P=7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(R-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,S0@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S(P,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SDR"FUS
M9VED(")3:7IE(@IM<V=S='(@(E9E;&EK;W-T(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I
M;G1E;F%N8V4B"FUS9W-T<B`B4')E<VMOQ(UI('9Z9'+%OF5V86YJ92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9AQ:%K
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(E-L
M;W9E;FEJ82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(E-N96<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97(B"FUS9W-T<B`B4VYEQ;YN82!P;&]H82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B4VYEQ;YN92!P;&]H92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3;F]W(%-H;W=E<G,@
M16%R;'DB"FUS9W-T<B`B6FIU=')A:B!S;F7%OFYE('!L;VAE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N
M;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(E!O<&]L9&YE('-N9<6^;F4@<&QO
M:&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B4VYO=R!D
M97!T:#H@(@IM<V=S='(@(E9IQ:%I;F$@<VYE9V$Z(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.30*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@(@IM<V=S='(@(E-N96=U(&5K=FEV86QE;G1N82!K;VQIQ(UI;F$@=F]D
M93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS
M9W-T<B`B4V%L;VUO;F]V:2!O=&]K:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI:F$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-C4*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B4&5S
M;6D@:6X@<&]E>FEJ92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M.38*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E9R<W1A
M('5R96IE;F5G82!I>F)O<F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R(").87-L;W8@=FER82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")*=<6^;F$@069R:6MA(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E-O=71H($5U<F]P96%N
M("A)4T\M.#@U.2TS*2(*;7-G<W1R(")*=<6^;F\M979R;W!S:VD@*$E33RTX
M.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N
M9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R(")*=<6^;F$@
M1V5O<F=I82!I;B!O=&]K:2!*=<6^;FD@4V%N9'=I8V@B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3
M;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DIUQ;YN82!P;VQO8FQA(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#(T"FUS9VED(")3<&%C97(B
M"FUS9W-T<B`B4')E<VQE9&YI8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A
M:6XB"FUS9W-T<B`BQ:!P86YI:F$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3`W"FUS9VED(")3<&%M(@IM<V=S='(@(DYE>F'%OF5L96YA('!O
MQ:%T82(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E
M8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`B5FAO9"!Z82!P;W-E8FYE
M('IN86ME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")3
M<&]R=',B"FUS9W-T<B`BQ:!P;W)T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M4W)I($QA;FMA(@IM<V=S='(@(L6@<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-S$@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-@IM
M<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<F1E;B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-PIM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@
M(EIV97ID;F4@<W1E>F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#<T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P-SD*;7-G:60@(E-T87)T
M('EE87(B"FUS9W-T<B`B6F'$C65T;F\@;&5T;R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V
M:6YC92(*;7-G<W1R(")$<L6^879A(&%L:2!P<F]V:6YC82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$P"FUS9VED(")3=&%T=7,B
M"FUS9W-T<B`B4W1A='5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S`X-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B3V)L:6MA('!O
M;6YI;&YI:V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B3F%S;&]V('5L
M:6-E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T,@IM<V=I9"`B
M4W1R:6YG(&QI<W0B"FUS9W-T<B`B4W!I<V5K(&)E<V5D;FEH('IV97HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$Q"FUS9VED(")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(_/S\_/S\_/S\_9&]M
M96YA(&EZ(&YA<VQO=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8T"FUS9VED(")3=2(*;7-G<W1R(").92(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F4@;F%J
M9&5M('!O9&UA<&4@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV.0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("):
M861E=F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS-#$@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`B4')E9&QOQ;YI(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E
M<UPB('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO
M=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB
M4W!R96IE;&D@<VUO('IA:'1E=F5K('IA('9P:7,@7"(E<UPB+B!.92!M;W)E
M=&4@<V4@<')I:F%V:71I(&1O:VQE<B!V8<6A82`B"B)Z86AT979E:R!N92!P
M;R!P;W1R:F5N+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#,*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")5<W!E:"(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB('-E;2!U<W!EQ:%N;R!D;V1A;"!K('-I<W1E;74N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B)R5S)R!S96T@=7-P9<6A;F\@;V1S=')A;FEL(&EZ
M('-I<W1E;6$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB('-E;2!U<W!E
MQ:%N;R!I>F)R:7-A;"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB('-E;2!U<W!EQ:%N;R!O
M9'-T<F%N:6P@:7H@<VES=&5M82XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)5<W!E
MQ:%N;R!O8G)N:F5N82!K;VYF:6=U<F%C:6IA+B#$C64@Q;YE;&G%H2!V:61E
M=&D@<W!R96UE;6)E+"!P;VYO=FYO(&YA;&_%OFDN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E5S<&7%H6YO('-H<F%N:F5N82!V87)N;W-T;F$@:V]P:6IA
M(&MO;F9I9W5R86-I:F4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(E5S<&7%
MH6YO('-H<F%N:F5N82!V87)N;W-T;F$@:V]P:6IA(&MO9FEG=7)A8VEJ92!D
M871O=&5K92`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S
M='(@(EPB)7-<(B!J92!B:6P@=7-P9<6A;F\@<&]S;V1O8FQJ96XN(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B5S('-E;2!U<W!EQ:%N;R!Z87!I<V%L+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(E-U9&%N(@H*(SH@;&EB
M+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R
M(")3;V[$C6YI('9Z:&]D(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X
M"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E-O;L2-;FD@>F%H;V0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B
M4W5N;GDB"FUS9W-T<B`B4V]NQ(UN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,3`*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B4V]NQ(UN
M:2!V>FAO9"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C
M:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T
M<B`B4V]NQ(UN:2!V>FAO9"]Z86AO9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#D*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")3;V[$
MC6YI('9Z:&]D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,PIM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E-O;L2-;FD@>F%H;V0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$R"FUS9VED(")3=6YS970Z
M("(*;7-G<W1R(")3;V[$C6YI('IA:&]D.B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS.30*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4&]D<&]R
M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U
M<FEN86TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W
M-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")0<FEI;65K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R(")3
M=F%L8F%R9"!I;B!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3
M=V%Z:6QA;F0B"FUS9W-T<B`B4W9A>FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")3=V5D96XB"FUS9W-T<B`BQ:!V961S:V$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I
M9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`BQ:!V:6-A(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`B27IB<FES86X@<VEN:W)O;FEZ86-I:G-K:2!D;F5V;FEK(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM
M<V=S='(@(E-I;FMR;VYI>F%C:6IA(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H
M('1E<FUS(@IM<V=S='(@(DYA<&%K82!V('-I;G1A:W-I(&ES:V%L;FEH('!O
M9V]J978B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U
M8FQI8R(*;7-G<W1R(")3:7)I:G-K82!A<F%B<VMA(')E<'5B;&EK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED
M(")4+5-T;W)M(@IM<V=S='(@(D=R;65N:F4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;2!A;F0@
M5VEN9'DB"FUS9W-T<B`B3F5V:6AT82!Z(&=R;65N:F5M(&EN('9E=')O;2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS
M9VED(")4+5-T;W)M<R(*;7-G<W1R(").979I:'1A('H@9W)M96YJ96TB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0HC+"!F
M=7IZ>0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B6FIU=')A:B!P
M;&]H92(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-C8*;7-G
M:60@(E135B!F:6QE(@IM<V=S='(@(E135B!D871O=&5K82(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A
M8FQE(%-E="(*;7-G<W1R(").87-T879I=&5V('1A8F5L92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R(")486IV86XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B
M5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XL(&1E
MQ;YE;&$@2VET86IS:V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES
M=&%N(@IM<V=S='(@(E1A9,6^:6MI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G
M:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B5&%N
M>F%N:6IA+"!:9')UQ;YE;F$@<F5P=6)L:6MA(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$Q,#<*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5&%S:W,B
M"FUS9W-T<B`B3W!R879I;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R
M(")496QE9F]N<VMA(,6A=&5V:6QK82(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`R"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")4
M96UP97)A='5R82!V('IA9&YJ:2!U<FDZ(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C8*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T
M=7)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-PIM<V=I
M9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R83H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(@IM<V=S='(@(E1E;7!E<F%T=7)A/&)R("\^*"5S2&DE<R\E<TQO)7,I
M("9D96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@=GIO<F-A(&YE(&YA:F1E;2XB"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.`IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B57)E:F5V86QN:6L@Q:%A8FQO;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C`@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S8Q-`IM<V=I9"`B5&5X="(*;7-G<W1R(")"97-E9&EL;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL
M>2(*;7-G<W1R(")386UO($)E<V5D:6QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B5&@B"FUS9W-T<B`B
M5&\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H
M5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA
M:6QA;F0B"FUS9W-T<B`B5&%J<VMA(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX-#(*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D]V97)J96YJ92!N:2!U<W!E;&\B"@HC.B!F
M<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HV,PIM<V=I9"`B5&AE($AI
M<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("):9V]D;W9I;F$@
M:F4@:7IK;&]P;&IE;F$N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G
M<W1R(")(;W)D92]+;VQA8B!I;G1E9W)A8VEJ82!N92!P;V1P:7)A(%PB)7-<
M(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*
M;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N
M(@IM<V=S='(@(E!O<V]D;V)L:F5N(&1A=&]T96ME(&YE(&UO<F5M('-H<F%N
M:71I+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B
M5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F
M=6QL>2(*;7-G<W1R(")6>F1RQ;YE=F%N:F4Z(')A>G)E9"!N:2!B:6P@=7-P
M9<6A;F\@;F%L;\6^96XN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N(@IM<V=S='(@(D]K;F\@36_%OFYO<W1I(&IE(&)I;&\@
M>F%P<G1O+B!:86ML:G5E=6IE;2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<V@R+G!H<#HX-C8*(RP@9G5Z>GD*;7-G:60@(E1H92!34T@R(%!%0TP@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D]V97)J96YJ92!N
M:2!U<W!E;&\B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B
M(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R(")!9&UI;FES=')A=&]R(&UO<F$@
M;F%J<')E:B!N87-T879I=&D@<VES=&5M('IA('!R879I8V4N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G
M:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE
M9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A
M8F%S92XB"FUS9W-T<B`B2V]N=&%K=&YI($E$(&YI(&)I;"!P;W-R961O=F%N
M(&%L:2!N:2!B:6P@;F%J9&5V('8@8F%Z:2!P;V1A=&MO=BXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*;7-G:60@(E1H
M92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN(@IM<V=S='(@(E-T:6L@:F4@8FEL('5S<&7%H6YO(&1O9&%N
M(&L@=F'%H6EM(&YA<VQO=F]M+B!+;&EK;FET92!S<&]D86H@>F$@;V=L960Z
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$W,@IM<V=I
M9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B
M(@HB4&]T<F5B=6IE;2!L;\2-96YO(%!'4"!P;V1P:7-A;F\@8F5L9<6^;FEC
M;RP@9&$@<')E=FER:6T@<&]D<&ES86YO('-P;W)OQ(UI;&\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G
M:60@(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO
M="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H
M92!D871A8F%S92XB"FUS9W-T<B`B240@<V5Z;F%M82!N:2!B:6P@<&]S<F5D
M;W9A(&%L:2!N:2!B:6P@;F%J9&5N('8@8F%Z:2!P;V1A=&MO=BXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R(")4;R!D96IA;FIE(&YI;6$@<&]D<&]R92XB"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@96UA:6P@861D<F5S<R`E<R!H87,@8F5E;B!A9&1E
M9"!T;R!Y;W5R(&ED96YT:71I97,N(%EO=2!C86X@8VQO<V4@=&AI<R`B"B)W
M:6YD;W<@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B2V]D:7)A
M;F$@=G-E8FEN82!Z86AT979A('9A<FYO(&EN=&5R;F5T;F\@<&]V97IA=F\N
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HU,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R
M("(E<R!D871O=&5K82!B:2!M;W)A;&$@=G-E8F]V871I("5S(&YA<W1A=FET
M=G(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-SD@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HU,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB
M"FUS9W-T<B`B)7,@9&%T;W1E:V$@8FD@;6]R86QA('9S96)O=F%T:2`E<R!N
M87-T879I='9E+B`B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*
M;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")$
M871O=&5K82!N92!V<V5B=6IE(&YO8F5N:6@@<&]D871K;W8N(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-T
M<F7%OFYI:R!<(B5S7"(@:F4@8FEL(&EZ8G)I<V%N+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T
M:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@
M0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(DUE<W1O($=N=5!'('!R;V=R
M86UA(&UO<F$@8FET:2!P;W-R961O=F%N;R!R87IR961U($-R>7!T7W!G<"XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB4W!O<F_$C6EL;R!P
M;W-L86YO(&1N92`E<R!Z82`E<R!Z(&YA<VQO=F]M(%PB)7-<(B!J92!B:6P@
M<')E8G)A;BY<;B(*(DYI('IA9V]T;W9I;&$@9&$@:F4@8FEL;R!D96IA;G-K
M;R!P<F5B<F%N;R!A;&D@<F%Z=6UL:F5N;RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,#$U"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B26UE('IA('!O
M=F5Z879O(&YA('-T<F%N('IA('-E<W1A=FQJ86YJ92!S<&]R;\2-:6QA+B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,#8*;7-G:60@(E1H92!N97<@9G)O
M;2!A9&1R97-S(&-A;B=T(&)E('9E<FEF:65D+"!T<GD@86=A:6X@;&%T97(Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I
M8RXB"FUS9W-T<B`B5&$@=G)E9&YO<W0@;6]R82!B:71I(,6A=&5V:6QK82XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(E!O=')E8G5J96T@
M;W!E;G-S;"!M;V1U;"!Z82!(;W)D95]#<GEP=%]S;6EM93HZ(')A>G)E9"XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3F%S=&%V:65N92!D
M871O=&5K92!<(B5S7"(@;F4@;6]R92!S:')A;FET:2P@:V5R(&YJ96YI('!O
M9&%T:VD@(@HB<')E<V5G86IO;F%J=F7$C6II(&1O=F]L:F5N(&]B<V5G+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HS,#4@9G)A;65W
M;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,30U"FUS9VED("(B"B)4:&4@<')E
M9F5R96YC97,@8F%C:V5N9"!I<R!C=7)R96YT;'D@=6YA=F%I;&%B;&4@86YD
M('EO=7(@<')E9F5R96YC97,@:&%V92`B"B)N;W0@8F5E;B!L;V%D960N(%EO
M=2!M87D@8V]N=&EN=64@=&\@=7-E('1H92!S>7-T96T@=VET:"!D969A=6QT
M('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(E!R;V=R
M86UA+"!K:2!O9'!I<F$@<&]D871K92!T92!V<G-T92`H)7,I(&YE(&YA:F1E
M;2!V('-I<W1E;74N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N(@IM<V=S='(@(E)A>FUE:FET978@;6]R82!B:71I
M('-E<W1A=FQJ96YA(&QE(&EZ(&5N96=A('IN86MA+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0W.0IM<V=I9"`B5&AE('-E<&%R871O<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("),;\2-:71E
M=B!M;W)A(&)I=&D@<V5S=&%V;&IE;F$@;&4@:7H@96YE9V$@>FYA:V$N(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB
M"FUS9W-T<B`B4W1R9<6^;FEK(%PB)7-<(B!J92!B:6P@:7IB<FES86XN(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM
M<V=S='(@(E-T<F7%OFYI:R!<(B5S7"(@:F4@<VAR86YJ96XN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3DW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM
M<V=S='(@(EIA:'1E=F5K('IA('!R:6IA=F\@:F4@8FEL(&]D<W1R86YJ96XN
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HT-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M*"5D*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B27IB<F%N82!V<G-T:6-A
M("@E9"D@;F4@;V)S=&%J82XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(P,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O
M<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B6F'$
MC6%S;F$@9&%T;W1E:V$@;F4@;V)S=&%J82XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS-3@Y"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@
M(E9N9<6A96YO(&)E<V5D:6QO(&YE('5S=')E>F$@8F5S961I;&\@;F$@96MR
M86YU+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N(@IM<V=S='(@(E!O<V]D;V)L:F5N:2!P;V1A=&MI('-O(&)I;&D@
M:7IG=6)L:F5N:2!P<FD@<')E:L6A;FIE;2!K;W)A:W4N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A
M+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(E!O<V]D;V)L:F5N(&1A=&]T96ME(&YE
M(&UO<F5M('-H<F%N:71I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HU-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U"FUS9VED
M(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B=V5A=&AE<BYC;VT@;FD@;F$@=F]L:F\N(@H*(SH@=71I;"]I8V]N
M7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F4@;F%J9&5M
M(&UA<&4@;V)L:6L@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z-#0T(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP
M:'`Z-#0X"FUS9VED(")4:&5R92!A<F4@;F\@96UA:6P@861D<F5S<V5S('1O
M(&-O;F9I<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I
M;&%B;&4N(@IM<V=S='(@(DYI(&UOQ;YN;W-T:2!N82!R87IP;VQA9V\N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z,S0T"FUS9VED
M(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN
M;&EN92XB"FUS9W-T<B`B1&5L:2!N92!M;W)E:F\@8FET:2!P<FEK87IA;FDN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@HB
M5B!P;VQJ=2!J92!P<F5V9<2-('IN86MO=BX@5G1I<&MA;&D@<W1E("5S('IN
M86MO=BX@5G1I<&MA=&D@;6]R871E(&UA;FH@:V]T("4B"B)S('IN86MO=BXB
M"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<
M(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")0<FG%H6QO(&IE(&1O(&YA
M<&%K92!P<FD@9&]D86IA;FIU("<E<R<@:R!S:7-T96UU.B`E<R(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E!R:<6A;&\@:F4@9&\@;F%P86ME
M('!R:2!O9'-T<F%N:F%N:G4@)R5S)R!I>B!S:7-T96UA+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C$P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*
M;7-G<W1R(")0<FG%H6QO(&IE(&1O(&YA<&%K92!P<FD@;V1S=')A;FIA;FIU
M("<E<R<@:7H@<VES=&5M82XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R!<(B5S7"(Z("5S(@IM<V=S='(@(E!R:<6A;&\@:F4@9&\@;F%P86ME('!R
M:2!P;W-O9&%B;&IA;FIU("<E<R<Z("5S("(*"B,Z(&9R86UE=V]R:R]"<F]W
M<V5R+T)R;W=S97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R
M92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W
M87,@=7!L;V%D960N(@IM<V=S='(@(E!R:2!N86QA9V%N:G4@9&%T;W1E:V4@
M:F4@<')IQ:%L;R!D;R!N87!A:V4N($YO8F5D96X@)7,@;FD@8FEL(&YA;&_%
MOF5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS-PHC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"B)0<FD@;F%L86=A;FIU(&1A=&]T96ME(&IE('!R:<6A;&\@9&\@;F%P
M86ME+B`E<R!Z87-E9&$@=F7$C2!P<F]S=&]R82P@:V]T(&IE("(*(F1O=F]L
M:F5N;RX@1&]V;VQJ96YO(&IE("@E9"!B>71O=BDN(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@
M(E!R:2!N86QA9V%N:G4@9&%T;W1E:V4@:F4@<')IQ:%L;R!D;R!N87!A:V4N
M("5S(&IE(&QE(&1E;&YO(&YA;&_%OF5N82XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R
M(")6('-P;W)O96EL=2!S92!J92!P;VIA=FEL82!N97IN86YA(&YA<&%K82XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS
M9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T
M(&1A=&$N(@IM<V=S='(@(E!R:2!S<')E:F5M86YJ=2!K;VYT86MT82!J92!P
M<FG%H6QO(&1O(&YA<&%K92XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM
M8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")0<FD@<W!R96IE;6%N:G4@
M:V]N=&%K=&$@:F4@<')IQ:%L;R!D;R!N87!A:V4N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(DMO;F9I9W5R
M86-I:G-K:2!O8G)A>F5C('9S96)U:F4@;F%P86MO+B!697)J971N;R!S=&4@
M<&]Z86)I;&D@;F%S=&%V:71I("(*(GIA:'1E=F%N;R!P;VQJ92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(E!R:<6A;&\@:F4@9&\@;F%P86ME
M('!R:2!P<F]C97-I<F%N:G4@:7IB<F%N96=A(&EM96YI:V$N(%!R;W-I;6\@
M<&]S:W5S:71E("(*(GIN;W9A;F5K;VQI:V\@:V%S;F5J92(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M4')I('-P<F5J96UA;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME
M+B!0<F]S:6UO('!O<VMU<VET92!Z;F]V82`B"B)K87-N96IE+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"B)0<FD@<W!R96IE;6%N:G4@:V]N=&%K=&$@:F4@<')IQ:%L;R!D;R!N87!A
M:V4N(%!R;W-I;6\@<&]S:W5S:71E(&MA<VYE:F4N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*
M;7-G<W1R(")68<6A(&)R<VMA;&YI:R!N92!P;V1P:7)A('1E('!O=&5Z92XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS
M9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+B(*;7-G<W1R(")4;R!N:2!V96QJ879E;B!205(@87)H:78N(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HU,@IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92XB"FUS9W-T<B`B5&\@;FD@=F5L:F%V;F$@>FEP(&1A=&]T96MA+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T,30*;7-G:60@(E1H:7,@9&]E
M<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R
M("+$@N*`FL6@=&5V:6QK82!K87)T:6-E(&YI('9E;&IA=FYA+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E
M;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M1V]N:6QN:6L@;VUO9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R96MO
M(&]P97)A=&5R:F$@0VQI8VMA=&5L;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH
M='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(D=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA;FIE('-P
M;W)OQ(UI;"!P<F5K;R!O<&5R871E<FIA(%=)3BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(D=O;FEL;FEK(&]M
M;V=OQ(UE('!OQ:%I;&IA;FIE('-P;W)OQ(UI;"!P<F5K;R!O<&5R871E<FIA
M('-M<S)E;6%I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N
M=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B
M(@HB1V]N:6QN:6L@;VUO9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R
M96MO(&ET86QJ86YS:V5G82!O<&5R871E<FIA(%9O9&]A9F]N92XB"B):82!P
M;\6A:6QJ86YJ92!M;W)E=&4@:6UE=&D@<F5G:7-T<FER86YI(&YA(&AT='`Z
M+R]W=W<N,3DP+FET(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@W
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C8*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`Y-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(T
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(V-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3$*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,34W,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C0V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3,@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S8V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,S<*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-CDV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W,S@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T,#8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S4X-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HT,#DR"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C0Q,#`*;7-G
M:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(E!O=')E8G5J
M96T@=&\@<&]L:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W
M-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+B(*;7-G<W1R(")4;R!P;VQJ92!L86AK;R!V<V5B=6IE(&QE(&-E;&$@Q:%T
M979I;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<P-`IM<V=I
M9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BXB"FUS9W-T<B`B5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!L92#%
MH71E=FEL82!I;B!S=&]L<&5C+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#,*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O
M8W1A;"!V86QU97,N(@IM<V=S='(@(E1O('!O;&IE(&QA:&MO('9S96)U:F4@
M;&4@Q:%T979I;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S
M,@IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B4&]L:F4@;6]R
M82!V<V5B;W9A=&D@<V5Z;F%M(,6A=&5V:6PL(&QOQ(UE;FEH('H@=F5J:6-O
M(&%L:2!P<F5S;&5D:V]M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDY.`IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(*;7-G<W1R(")482!V<F5D;F]S="!M;W)A(&)I=&D@Q:%T979I;&MA+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#8*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`B(@HB5&\@<&]L:F4@;6]R82!V<V5B;W9A=&D@8F%R=FYO(&MO9&\@=B!2
M1T(@2&5X(&9O<FUA='4L(&YA('!R:6UE<B`G(S$R,S1A9B<N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z-3<Q"FUS9VED(")4:&ES(&9O<FT@:&%S
M(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(E1A(&]B;&EK82!J
M92!B:6QA(,6^92!O8F1E;&%N82XB"@HC.B!T96UP;&%T97,O:&5L<"]A8F]U
M="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*;7-G
M<W1R(")4;R!J92`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H
M92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@
M96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB
M5&\@:F4@<&]D871E:R!S:W5P:6YS:V$@=7!R879L:F%N:F4@2V]L86(N(%IA
M('!R96=L960@=&5G82!P;V1A=&MA("(*(G!O=')E8G5J971E<')E9VQE9&QO
M=F%L;FEK+"!K:2!P;V1P:7)A(&YAQ(UI;B!Z87!I<V$@2V]L86(@1W)O=7!W
M87)E+B!:82`B"B)S97IN86T@;V1J96UA;&-E=FMI('1O('!O9'!I<F%J;R!O
M8FG%H<2-:71E("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z-3DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W
M87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N
M('EO=7(@;W=N+B(*;7-G<W1R(")3<&]R;\2-:6QO(&IE(&)I;&\@;F%P:7-A
M;F\@=B!K;V1N:2!T86)E;&D@9')U9V'$C6YE(&]D('9AQ:%E("@E<RDN(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")4;R#%
MH71E=FEL;R!M;W)A(&)I=&D@=G-A:B!E;F$N(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B5&$@<W1R9<6^;FEK(&YE(&UO<F4@;V1P<F5T:2!Z:7`@:6X@9WII<"!D
M871O=&5K+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3<Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N(@IM<V=S='(@(E-I<W1E;2!J92!T<F5N=71N;R!N96%K:71I=F5N
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(E1A('9R
M961N;W-T(&UO<F$@8FET:2#%H71E=FEL:V$N(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R(")4
M;R!O:VYO(&UO<F%T92!P;V=N871I('H@;VMN82!-;\6^;F]S=&DN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@
M(E1H=6YD97(B"FUS9W-T<B`B0FQI<VLB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4P"FUS9VED(")4:6-K971S(@IM<V=S='(@(E!R:6IA=F4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-S$S('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R("+$C6%S
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B5&EM
M92!4<F%C:VEN9R(*;7-G<W1R(")3;&5D;FIE(,2-87-A(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C(R"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")/
M8FQI:V$@Q(UA<V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Y
M"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("))>F)I<F$@96%S82XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R
M(").87-L;W8B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<Q"FUS9VED(")4;R(*;7-G<W1R("):82(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-38*;7-G:60@(B(*(E1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N
M(@IM<V=S='(@(B(*(F7$C2#%OF5L:71E(&EZ8G)A=&D@=F7$C2!P<F5D;65T
M;W8L('!R:71I<VYI=&4@0V]N=')O;"`H4$,I(&%L:2!#;VUM86YD("A-86,I
M("(*(G1I<&MO+"!M961T96T@:V\@;F%N:F4@:VQI:V%T92XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`S"FUS9VED(")4;V1A>2(*;7-G
M<W1R(")D86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@
M(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@
M(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`U
M"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R(")+;VUO<FD@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#4*;7-G:60@(E1O;R!M86YY(&EN
M=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R
M(")0<F5V9<2-(&YE=7-P96QI:"!P;W9E>F%V('8@>F%D;FII:"!M:6YU=&%H
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV.`IM<V=I9"`B5')A;G-L
M871I;VYS(@IM<V=S='(@(D]R9V%N:7IA8VEJ82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*
M;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')I;FED860@
M:6X@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@P,PIM
M<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")$82!A;&D@;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4=2(*;7-G<W1R("+$C&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI
M<VEA(@IM<V=S='(@(E1U;FEZ:6IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5'5R:V5Y(@IM<V=S='(@(E1U<F5I:F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B
M5'5RQ:%K:2`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@
M(E1U<L6A:VD@:6X@0V%I8V]S(&]T;VMI(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M(")6=&EP:V%J=&4@=F'%H6\@:7IB:7)O.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T
M<B`B52Y6+B!I;F1E:W,Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I
M9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),('9A
MQ:%E('-K<FEP=&4@>F$@<&]R;\2-86YJ92!S=&%T=7-A(&1O<W1A=F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:FEN
M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0U,0IM<V=I9"`B
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").:6UA
M;2!D;W-T;W!A(&1O(%9&4R!I;65N:6MA+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,SDV(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C,X
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@
M<W!R96UE;FET:2!P<F%V:6-E('IA(%9&4R!D871O=&5K;R!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#(T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HT.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B1&]V;VQJ96YJ82!Z82!61E,@)7,O)7,@;F4@;6]R96T@<W!R
M96UE;FET:2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Y-B!F
M<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HX,3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F4@;6]R
M96T@<W!R96UE;FET:2!N82`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(S-R!F<F%M97=O<FLO5D93+U9&4R]S<V@R+G!H<#HR,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M('-P<F5M96YI=&D@;F$@7"(E
M<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C<S,R!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P-S4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.CDP,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D871O=&5K92`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@V,0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DYE(&UO<F5M('-E('!O
M=F5Z871I(',@4U-,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(V-"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(S-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C0Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR-#D*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R(")61E,@9&%T;W1E:V4@;F4@;6]R96T@:V]P:7)A=&DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S,@9G)A;65W;W)K+U9&4R]6
M1E,O<W-H,BYP:'`Z,S8V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE(&UO
M<F5M('5S=&%V<FET:2!I;65N:6MA(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS.3,@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDV
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(E9&4R!I;65N:6MA(&YE(&UO<F5M('5S=&%V<FET:2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&%T;W1E:V4@;F4@;6]R
M96T@=7-T=F%R:71I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C@U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE(&UR;V5M('5S='9A<FET:2!I
M;65N:6MA(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,#0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M(@IM<V=S='(@(E9&4R!D871O=&5K92!N92!M;W)E;2!U<W1V87)I=&DN(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")0;V1A=&MO
M=B!N92!M;W)E;2!S<')O<W1I=&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,3D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z,CDV"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I("5S
M+"!I;65N:6L@;FD@<')A>F5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S<@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DYE(&UO
M<F5M(&EZ8G)I<V%T:2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS-S`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R,R!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDR"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y(@IM<V=S='(@(DYE(&UO<F5M(&EZ8G)I<V%T:2`E<RP@:6UE;FEK(&YI
M('!R87IE;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M-#`V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,3`*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB
M"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I(&EM96YI:V$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S<V(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,S0*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,T-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S4U"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HT,#(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F4@;6]R96T@:7IB
M<FES871I(&EM96YI:V$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT-34@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`B3F4@;6]R96T@:7IB<FES871I(%9&4R!I;65N:6MA.B`E
M<R`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Q,B!F<F%M97=O
M<FLO5D93+U9&4R]S<V@R+G!H<#HR,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE
M(&UO<F5M(&EZ8G)I<V%T:2!D871O=&5K92Y<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0R(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,S$T"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HT-#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C0T.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T
M<B`B3F4@;6]R96T@:7IB<FES871I(%9&4R!D871O=&5K92XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R
M(").92!M;W)E;2!I>F)R:7-A=&D@9&%T;W1E:V4@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#0T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS
M9W-T<B`B3F4@;6]R96T@:7IB<FES871I(%9&4SH@)7,@(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX,C4*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE(&UO<F5M(&1O
M;&_$C6ET:2!S961A;FIE9V$@:6UE;FEK82XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R(").92!M;W)E;2!I>G!I
M<V%T:2!P;W1R:F5N:6@@<&]D<F]B;F]S=&DN(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`N<&AP.C0S-R!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!
M=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DYE(&UO<F5M('-P
M<F5M96YI=&D@;F$@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C(S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DP(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ.34*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R(").92!M;W)E;2!P<F5M86MN:71I(%9&4R!D871O
M=&5K92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-C0Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP:'`Z.3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M(").92!M;W)E;2!O9'!R971I(&1A=&]T96ME7"(E<UPB+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Q-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W
M<FET:6YG+B(*;7-G<W1R(").92!M;W)E;2!O9'!R971I(%9&4R!D871O=&5K
M92!N86UE;FIE;F4@<&ES86YJ=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HX,2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX-@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-#`@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92XB"FUS9W-T<B`B3F4@;6]R96T@;V1P<F5T:2!61E,@9&%T;W1E:V4N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM
M<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G
M<W1R(").92!M;W)E;2!O9'!R971I('IG;\6AQ(UE;F5G82!A<FAI=F$N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDP.`IM<V=I9"`B56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D871O=&5K92`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3,Y"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I
M+B(*;7-G<W1R(").92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL
M93H@(@IM<V=S='(@(DYE(&UO<F5M('!R96EM96YO=F%T:2!61E,@9&%T;W1E
M:V4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-S$T"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S
M='(@(DYE(&UO<F5M('!R96)R871I(%9&4R!O<VYO=FYE9V$@:6UE;FEK82XB
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DYE(&UO<F5M
M('!R96EM96YO=F%T:2`E<R!V("5S.B!M87!A(,6^92!O<W1A:F$B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0U"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DYE(&UO<F5M
M('!R96EM96YO=F%T:2!61E,@:6UE;FEK82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").92!M;W)E
M;2!P<F5I;65N;W9A=&D@5D93(&EM96YI:V$Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C8U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S4Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-S:#(N<&AP.C,T-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D871O
M=&5K92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C4U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D871O=&5K92`E
M<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,V,2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HT-C0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4Y
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(").
M92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM
M<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DYE(&UO
M<F5M('-P<F5M96YI=&D@;F$@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B3F4@;6]R96T@<')E
M=F5S=&D@=&5G82!7;W)D;W9E9V$@9&]K=6UE;G1A+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3@S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=')I9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(*;7-G
M<W1R(").92!M;W)E;2!S<')OQ;YI=&D@<')O<W1O+WIA<V5D96YO('!O<V]D
M;V)I=&4@>F$@)7,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U
M-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<V@R+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O<W-H,BYP
M:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DYE(&UO<F5M(&YA<&ES871I(%9&
M4R!D871O=&5K92!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+B(*;7-G<W1R(").92!M;W)E;2!N87!I<V%T:2!61E,@
M<&]D871K;W9N:6@@9&%T;W1E:RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T
M-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B3F4@
M;6]R96T@;F%P:7-A=&D@5D93('!O9&%T:V]V;FEH(&1A=&]T96LN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-`IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M(").92!M;W)E;2!N87!I<V%T:2!61E,@9&%T;W1E:V4L(&MV;W1A(&)O('!R
M97-EQ;YE;F$N(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I
M9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(E)A>G9E;&IA=FD@<W!R96UE;6)E
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B3F5P<FG$C6%K;W9A;B!O9&=O=F]R(',@<W1R
M9<6^;FEK82!V('!O=F5Z;W9A;FIU.B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(DYE<')IQ(UA:V]V86X@;F5P<FG$
MC6%K;W9A;B!O9&=O=F]R('-T<F7%OFYI:V$@>F$Z(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N
M9FEL960B"FUS9W-T<B`B3F5I>G!O;&YJ96YO(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.38*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R(")5
M;FEK;V0@*%541BTX*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A
M8B!%;6ER871E<R(*;7-G<W1R("):9')UQ;YE;FD@87)A8G-K:2!E;6ER871I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R
M("):9')UQ;YE;F\@:W)A;&IE<W1V;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B6F1R=<6^96YE(&1RQ;YA=F4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',B"FUS9W-T<B`B6F1R=<6^96YE(&1RQ;YA=F4@3W1O:VD@
M36EN;W(@3W5T;'EI;F<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,PIM<V=I9"`B56YI=',B"FUS
M9W-T<B`B16YO=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-3@*;7-G:60@(E5N
M:VYO=VXB"FUS9W-T<B`B3F5P;WIN86YO(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(DYE<&]Z;F%N
M82!A<&EM<V=I9"`H240@05!)('-P;W)OQ(UI;&$I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R
M(").97!O>FYA;F$@8VQI;7-G:60@*$E$('5P;W)A8FYIQ:%K96=A('-P;W)O
MQ(UI;&$I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,@IM
M<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B365S
M=&\@;FD@;F%S=&%V;&IE;F\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(").97IN86YO('5P;W)A8FYIQ:%K
M;R!I;64@86QI(&=E<VQO+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,S$Y"FUS9VED(")5;FYA;65D(@IM<V=S='(@(D)R97H@:6UE
M;F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T
M960@17AT96YS:6]N(@IM<V=S='(@(DYE<&]D<')T82!R87K%H6ER:71E=B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T
M<B`B4&]S;V1O8FDB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M(")0;W-O9&]B:2`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(E!O<V]D;V)L
M:F5N('5P;W)A8FYI:R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30S(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$P,2!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,U"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G
M<W1R(")0;W-O9&]B;&IE;B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C@Y"FUS9VED(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G
M<W1R("))>F)R:7-A;F$@<VMR:7!T82!Z82!N861G<F%D;FIO+B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(DYA
M;&%G86TB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@U"FUS9VED(")5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BXB"FUS9W-T<B`B3F%L;\6^:2!N82!S=')EQ;YN:6L@=G-E(&YA;65S
M=&ET=F5N92!D871O=&5K92!A<&QI:V%C:6HN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=F%J(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(E5P;W)A8FD@
M<V5D86YJ:3H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")5<&]R
M86)I(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(@IM<V=S='(@(E5P;W)A8FDL(,2-92!J92!U<&]R86)N:<6A:V\@
M:6UE+V=E<VQO(&1R=6=AQ(UN;R!O9"!)35-0('-T<F7%OFYI:V$B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"FUS9VED(")5<V5R
M(@IM<V=S='(@(E5P;W)A8FYI:R(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]296=I<W1R>2YP:'`Z-S8T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@
M)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")5<&]R86)N
M:6L@)7,@;FEM82!D;W-T;W!A(&1O("5S(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,C`R"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E5P<F%V
M82!Z82!U<&]R86)N:6ME(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")5<&]R86)N
M:<6A:V4@;F%S=&%V:71V92(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S
M97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES=')A8VEJ82!U<&]R86)N
M:6MA(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B
M4F5G:7-T<FER86YJ92!U<&]R86)N:6MO=B!J92!N82!T96H@<W1R86YI(&]N
M96UO9V_$C65N;RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#DT"FUS
M9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(DYE(&YA:F1E
M;2!U<&]R86)N:6MO=B!R8<2-=6XN(@H*(SH@861M:6XO=7-E<BYP:'`Z,S0@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHV-"!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B57!O<F%B;FG%H6MO(&EM92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*
M;7-G<W1R(")5<&]R86)N:<6A:V\@:6UE(%PB)7-<(B!J92#%OF4@=B!U<&]R
M86)I+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I
M9"`B57-E<FYA;64Z(@IM<V=S='(@(E5P;W)A8FYIQ:%K;R!I;64Z("(*"B,Z
M('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE
M.B`B"FUS9W-T<B`B57!O<F%B;FG%H6MO(&EM93H@(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y
M<W1E;3HB"FUS9W-T<B`B57!O<F%B;FEK:2P@:VD@<V\@=B!S:7-T96UU.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB
M96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,R!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.30*;7-G:60@(E9&4R!D:7)E
M8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!I;65N:6L@;F4@
M;V)S=&%J82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(W"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R(")/9'-O=&YO<W0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX-S4*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B3F%J9&5N82!V96QJ879N82!L;VMA
M8VEJ82!Z86IE;6$Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(E9E;&IA=FYO<W0B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM
M<V=S='(@(E9R961N;W-T('8@;6EN=71A:"!O9"!S961A:B!D86QJ92XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C4@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O
M=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B5G)E9&YO
M<W0@<')E<V5G82!M86MS:6UA;&YO(&1O;,6^:6YO("5S+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C`T(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@
M(E9R961N;W-T:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3<@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0W-`IM<V=I9"`B5F%L=65S('1O
M('-E;&5C="!F<F]M(@IM<V=S='(@(E9R961N;W-T:2!O9"!K;V1E<B!I>F)I
M<F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B
M5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S@*
M;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FEA8FEL;F\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU96QA(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@
M(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")0<F5V97)J86YJ92!N975S
M<&7%H6YO("T@;6]G;\2-92!J92!B:6QO('-P;W)OQ(UI;&\@<W!R96UE;FIE
M;F\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*
M;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B4F%Z;&G$C6EC82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#(*;7-G:60@(E9E<G-I;VX@0V]N=')O
M;"(*;7-G<W1R(")287IL:<2-:6-A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R
M("):96QO('9I<V]K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M
M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M
M<VMI("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.34R"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T
M<B`B4&]G;&5J("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S
M(%LE<UTB"FUS9W-T<B`B4&]G;&5J(&MO="`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B4&]G;&5D(&YA('IU;F%N:F\@<W!L971N;R!S=')A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(D1E=FG%H6MI(&]T;VMI("AB<FET86YS:VDI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B1&5V
M:<6A:VD@;W1O:VD@*%I$02DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M,0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")6:61L:FEV;W-T(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-PIM<V=I9"`B5FES:6)I
M;&ET>3H@(@IM<V=S='(@(E9I9&QJ:79O<W0Z(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O
M9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F;VX@271A;&EJ
M82!P<F5K;R!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*
M;7-G<W1R(")/4$]:3U))3$\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!3
M0U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B3U!/6D]224Q/(2$A
M(%)/Q(U.3R!/1%-44D%.24T@4TM225!43R!)6B`E<RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I
M82!(5%10(@IM<V=S='(@(E=)3B!P<F5K;R!(5%10(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B5V%L;&ES(&EN
M($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HY-0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")/<&]Z;W)I;&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED
M(")792(*;7-G<W1R(")-:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-`IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R(")6<F5M
M96YS:V$@;F%P;W9E9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT,3D*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R
M(")6<F5M96YS:VD@<&]D871K:2!S('-P;&5T82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDP,0IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B
M=V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I
M9"`B5V5B(@IM<V=S='(@(E-P;&5T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V,`IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B4W!L971N82!S
M=')A;B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")4961E;G-K;R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE(@IM
M<V=S='(@(D1O8G)O9&_%H6QI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL
M92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B1&]B<F]D;\6A
M;&D@;F$@<W!L971N:6@@<W1R86YE:"!P<F]G<F%M82`E<R(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E=E;&-O;64L("5S(@IM<V=S='(@(D1O8G)O9&_%H6QI+"`E<R(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DX"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R("):86AO9&YI("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M-2DB"FUS9W-T<B`B6F%H;V1N:2`H25-/+3@X-3DM,34B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B6F%H;V1N82!386AA
M<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_(@IM<V=S='(@(DMA=&5R;R!A<&QI:V%C:6IO(&YA:B!P
M<FEK8<6^92`E<RP@<&\@<')I:F%V:3\B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\B"FUS9W-T<B`B2V%KQ:%E;B!J92!L;\2-:6QN:2!Z;F%K/R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(DMA:\6A96X@:F4@
M;F%V961E;FD@>FYA:S\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`V-0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P
M(@IM<V=S='(@(EIE;6QJ979I9"`@5VAE<F5I<R!!=7-T<F%L:6$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G
M<W1R(")287IV;VIN82!S=&]P;FIA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H
M92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")+871E<F4@9&]D871K92!N
M86H@;VUO9V_$C6EM('!R:2!U<F5J86YJ=2!B97-E9&EL+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S.30*;7-G:60@(E=I9'1H(&EN($-34R!U
M;FET<R(*;7-G<W1R("+%H&ER:6YA('8@96YO=&%H($-34R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(L6@:7)I;F$@)7,@;65N:6IA(&YA
M(&QE=FD@*&]D<F%Z:6QA('-E(&)O(&]B(&YA<VQE9&YJ:2!P<FEJ879I*3HB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3,W"FUS9VED(")7:6MI
M(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,CDS(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W
M"FUS9VED(")7:6YD(@IM<V=S='(@(E9E=&5R.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B5VEN9"!%87)L
M>2(*;7-G<W1R(")*=71R86YJ:2!V971E<CH@(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HY,@IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M(")(:71R;W-T('9E=')A('8@=F]Z;&EH(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C@*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9E=&5R.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S8*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R(")6971E<CH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Y
M"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B36]D<F]S="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,3(*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@
M(DQI<W1A(,6^96QJ82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW,`IM
M<V=I9"`B5V]R:R(*;7-G<W1R(")3;'7%OF)A(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E
M<W,B"FUS9W-T<B`B4VQUQ;YB96YI(&YA<VQO=B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO
M;F4B"FUS9W-T<B`B4VQUQ;YB96YI('1E;&5F;VXB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F
M:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G
M<W1R(").87!AQ(UN;R#%H71E=FEL;R!P;VQJ('8@)60@=G)S=&DN(%!R:<2-
M86MO=F%N:6@@)60L(&YA:F1E;FEH("5D+B(*"B,Z(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S
M='(@(DYA<&'$C6YO(,6A=&5V:6QO('!O;&HN(%!R:<2-86MO=F%N:6@@)60L
M(&YA:F1E;FEH("5D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI
M;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G<W1R(").87!AQ(UE;B!O9&UI
M:R`E9"!M960@8G)A;FIE;2!D871O=&5K92!61E,N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2
M968B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM
M<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV
M,R!O<VYO=FYA(&]M96II=&5V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A
M9V4B"FUS9W-T<B`B6#4P.78S(%)A>L6A:7)J96YA('5P;W)A8F$@:VQJ=<2-
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@
M(E@U,#EV,R!:861E=F$@86QT97)N871I=FYO(&EM92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R(")8-3`Y=C,@2VIU92!Z82!D
M;VQO96ET:2!Z861E=F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M6#4P.78S(')A>L6A:7)I=&5V(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(EE9(@IM<V=S='(@(DQ,(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#8P"FUS9VED(")965E9(@IM<V=S='(@(DQ,
M3$PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R(")986AO;R$@>F5M;&IE
M=FED(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(DQE=&YO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(")997,B
M"FUS9W-T<B`B1&$N(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT
M96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")$
M82P@<V4@<W1R:6YJ86TN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U
M(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K
M<RXB"FUS9W-T<B`B3FEM871E(&1O=F]L:F5N:F$@=7-T=F%R:71I('9EQ(T@
M:V]T("5D(&)L;VMO=BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$S.34*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S
M='(@(DYI<W1E('!R:6IA=FQJ96YI(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HS,C4*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@
M)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(E8@
M:6UE;G4@;F4@;6]R971E(&EM971I('IN86MO=B`G7%PG(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O<&AP9W<N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B66]U
M(&1I9"!N;W0@875T:&5N=&EC871E+B(*;7-G<W1R(").:7-T92!P<FEJ879L
M:F5N:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C,*;7-G:60@
M(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B3FES=&4@=G-T879I;&D@=F5L:F%V;F5G82!E;&5K=')O;G-K96=A
M(&YA<VQO=F$N(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L
M9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN
M9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*(DUE9"!S<')E:F5T:6UI
M(&1A=&]T96MA;6D@;FES=&4@;WIN8<2-:6QI(&YO8F5N96=A('!O;&IA+"!K
M:2!S92!U:F5M82!S('!O;&II("(*(G8E<RXB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HY.#<*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U
M="XB"FUS9W-T<B`B0FEL:2!S=&4@;V1J879L:F5N:2XB"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W4@:&%V92!R97%U97-T960@=&\@861D('1H92!E;6%I;"!A
M9&1R97-S(%PB)7-<(B!T;R!T:&4@;&ES="!O9B!Y;W5R("(*(G!E<G-O;F%L
M(&5M86EL(&%D9')E<W-E<RY<;B(*(EQN(@HB1V\@=&\@=&AE(&9O;&QO=VEN
M9R!L:6YK('1O(&-O;F9I<FT@=&AA="!T:&ES(&ES(')E86QL>2!Y;W5R(&%D
M9')E<W,Z7&XB"B(E<UQN(@HB7&XB"B))9B!Y;W4@9&]N)W0@:VYO=R!W:&%T
M('1H:7,@;65S<V%G92!M96%N<RP@>6]U(&-A;B!D96QE=&4@:70N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S`*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)6
M;F5S=&D@;6]R871E('9E;&IA=FYO(&=S;2#%H71E=FEL:V\N1'9O;&IE;FD@
M>FYA:VD@<V\@;&4@Q:%T979I;&ME(&EN("<K)R!K;W0@(@HB<')E9'!O;F$@
M;65D;F%R;V1N:6T@Q:%T96EV;&MA;2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3DW"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+B(*;7-G<W1R(")6<W1A=FET:2!M;W)A=&4@=F5L:F%V;F\@=G)E
M9&YO<W0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+B(*;7-G<W1R(")/8FQI:V]V871I(&UO<F%T92!3
M:6=N=7`@8F%C:V5N9"P@Q:%E;&4@;F%T;R!S92!L86AK;R!P<FEJ879L:F%T
M92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0V-PIM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(D]B
M;&EK;W9A=&D@;6]R871E(%9&4R!B86-K96YD+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB
M92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M
M(')E<&]R="XB"FUS9W-T<B`B3F%J<')E:B!O<&G%H6ET92!T9<6^879E+"#%
MH65L92!N871O(&QA:&MO('!OQ:%L:F5T92!P;W)OQ(UI;&\@;R!T9<6^879A
M:"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@X"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!E;G1E<B!A;B!E;6%I;"!A9&1R97-S+B(*;7-G
M<W1R(").:7-T92!V<W1A=FEL:2!V96QJ879N96=A(&5L96MT<F]N<VME9V$@
M;F%S;&]V82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#@V"B,L
M(&9U>GIY"FUS9VED(")9;W4@;75S="!E;G1E<B!A="!L96%S="!O;F4@96UA
M:6P@861D<F5S<RXB"FUS9W-T<B`B3FES=&4@=G-T879I;&D@=F5L:F%V;F5G
M82!E;&5K=')O;G-K96=A(&YA<VQO=F$N(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V
M97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B27IB<F%T:2!M;W)A=&4@<W1R
M9<6^;FEK+"!K:2!B;R!I>F)R:7-A;BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,3@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N(@IM<V=S='(@(DYA=&%NQ(UN96IE(&YA=F5D:71E('5P;W)A8FYI
MQ:%K;R!I;64L(&MI(&=A(,6^96QI=&4@:7IB<FEA=&DN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z.3D*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N(@IM<V=S='(@(DYA=&%NQ(UN96IE(&YA=F5D:71E('5P
M;W)A8FYIQ:%K;R!I;64L(&MI(&=A(,6^96QI=&4@;V1S=')A;FET:2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O(&%D9"XB"FUS9W-T<B`B3F%T86[$C6YE:F4@;F%V961I=&4@=7!O<F%B
M;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!D;V1A=&DN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,30U"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(DYA=&%NQ(UN96IE(&YA=F5D:71E
M('5P;W)A8FYIQ:%K;R!I;64L(&MI(&=A(,6^96QI=&4@<&]S;V1O8FET:2XB
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R
M;2XB"FUS9W-T<B`B3F%T86[$C6YE:F4@;F%V961I=&4@:V%J(,6^96QI=&4@
M;F%R961I=&DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92XB"FUS9W-T<B`B5G1I<&MA:G1E(&EM92!N;W9E(&MA=&5G
M;W)I:F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@
M271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B5FYE<W1I(&UO<F%T92!I
M=&%L:6IA;G-K;R!T96QE9F]N<VMO(,6A=&5V:6QK;R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB5F'%H6$@<')I:F%V:71V96YA('-E:F$@)7,@:F4@<&]T
M96ML82X@4')O<VEM;RP@9&$@<V4@<&]N;W9N;R!P<FEJ879I=&4N(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S0*;7-G:60@(EEO=7(@
M16UA:6P@061D<F5S<R(*;7-G<W1R(")68<6A(&5L96MT<F]N<VMI(&YA<VQO
M=CHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$U"FUS9VED(")9;W5R
M($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(E9AQ:$@;F%S;&]V.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")6
M8<6A:2!P;V1A=&MI(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB3V0@>F'$C65T:V$@)7,@<V5J
M92P@<V4@:F4@=F'%H2!S<&QE=&YI(&YA<VQO=B!S<')E;65N:6PN($EZ("(*
M(G9A<FYO<W1N:6AR87IL;V=O=BP@<V4@;6]R871E('!O;F]V;F\@<')I:F%V
M:71I+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,P"FUS
M9VED(")9;W5R($YA;64B"FUS9W-T<B`B5F'%H64@:6UE.B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@
M=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES
M=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B
M"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)68<6A92!O
M>F%D:F4@>F$@;W9E<FIE;F4@;F4@<&]D<&ER82!D;V1A:F%N:F$@=7!O<F%B
M;FEK;W8N(,2-92#%OF5L:71E("(*(G5P;W)A8FET:4AO<F1E('IA(&%D;6EN
M:7-T<FER86YJ92!U<&]R86)N:<6A:VEH(')AQ(UU;F]V+"!M;W)A=&4@=7!O
M<F%B:71I("(*(F1R=6=O(&]Z861J92!Z86]V97)J86YJ92XB"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D
M(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB5F'%H64@;WIA
M9&IE('IA(&]V97)J86YJ92!N92!P;V1P:7)A(&YA=F%J86YJ82!U<&]R86)N
M:6MO=B!A;&D@<&$@:F4@8FEL82`B"B)M;\6^;F]S="!O;F5M;V=OQ(UE;F$@
M:7H@9')U9VEH(')A>FQO9V]V+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(DMAQ;YE+"!D
M82!S92!J92!O9"!Z8<2-971K82`E('-E:F4L('9AQ:$@8G)S:V%L;FEK('-P
M<F5M96YI;"X@27IV87)N;W-T;FEH("(*(G)A>FQO9V]V+"!S92!M;W)A=&4@
M<&]N;W9N;R!P<FEJ879I=&DN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92XB"FUS9W-T<B`B5F'%H2!B<G-K86QN:6L@;F4@<&]D<&ER82!T
M92!F=6YK8VEJ92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*(E9AQ:$@8G)S:V%L;FEK(&YE('!O
M9'!I<F$@9&]L;\2-96YI:"!M;\6^;F]S=&D@<')I('!R:6YT86YJ=2X@6F$@
M<')I;G1A;FIE("(*(G!R:71I<VYI=&4@0V]N=')O;"]-;\6^;F]S=&D@*R!0
M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@
M8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(E9AQ:$@=')E;G5T;FD@Q(UA
M<V]V;FD@<&%S.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,S`*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G
M<W1R(")68<6A82!P<FEV>F5T82!I9&5N=&ET971A(&IE(&)I;&$@<W!R96UE
M;FIE;F$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")0<FEV>F5T82!I9&5N
M=&ET971A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B
M66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E9AQ:%E(&EM93HB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S
M(&5X<&ER960N(@IM<V=S='(@(E9AQ:%A('!R:6IA=F$@:F4@<&]T96ML82XB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM
M<V=S='(@(E9AQ:%E(&YO=F4@9V5S;&\@>F$@)7,@:F4Z("5S(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B5F'%H64@;F%S=&%V:71V92!S;R!B:6QE
M('!O<V]D;V)L:F5N92!Z82#$C6%S('1E('-E:F4N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B5F'%H64@;F%S=&%V:71V92!S
M;R!B:6QE('!O<V]D;V)L:F5N92XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="(*;7-G<W1R(")68<6A92!G97-L;R!J92!B:6QO('!O;F%S=&%V;&IE;F\N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"B)68<6A92!G97-L;R!J92!B:6QO('!O;F%S=&%V;&IE;F\N($YA
M('9AQ:$@92UN87-L;W8@<VUO('9A;2!P;W-L86QI(&YO=F]G97-L;R`B"B)S
M(&MA=&5R:6T@<V4@<')I:F%V:71E+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B5F'%H64@9V5S;&\@:F4@<&]T96ML;RXB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E
M<G9E<G,Z(@IM<V=S='(@(E9AQ:%I('!O<W)E9&YI('-T<F7%OFYI:VDZ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R
M(")*=6=O<VQA=FEJ82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(EIA:7(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEJ82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G9E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C<Q"FUS9VED(")::7!P>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T
M<B`B6U-K<FEJ(&-I=&ER86YO(&)E<V5D:6QO72(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@
M(EMP;W)OQ(UI;&\@;R!N87!A:VE=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("TB"FUS9W-T<B`B6U!O:V'%OFD@8VET:7)A;F\@8F5S961I;&\@+2(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B6U!O:V'%OFD@8VET:7)A;F\@8F5S
M961I;&\@+2`E<R!V<G-T:6-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=
M(@IM<V=S='(@(ELE<R!V<G-T:6-A(&]D("5S72(*"B,Z(&QI8B]A<&DN<&AP
M.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP
M:'`Z,30Q"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B1')E=F5S;F$@(@H*
M(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]3
M:W5P:6YE(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W
M-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B4&]M;\2-(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G
M<W1R(")0<FEJ879A(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y,`IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B3V1J879A(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P
M=&EO;G,B"FUS9W-T<B`B36_%OFYO<W1I(@H*(SH@;&EB+V%P:2YP:'`Z,3,W
M"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]V;VQJ96YJ82(*"B,Z
M(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E].86UE
M<W1I(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T
M<B`B7U5P;W)A8FYI:VDB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(DEM96YI:R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A
M9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(").87-L;W9N:6L@;F5Z;F%N(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3<*;7-G:60@(F-A;&5N
M9&%R(@IM<V=S='(@(DMO;&5D87(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$X-"!L:6(O0FQO8VLO;65T87(N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")C86QM(@IM<V=S='(@(DUI<FYO(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T
M<'5T(&9I;&4B"FUS9W-T<B`B3F4@;6]R96T@=7-T=F%R:71I(&EZ:&]D;F4@
M9&%T;W1E:V4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$S,`IM<V=I9"`B8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B3F4@;6]R
M96T@;V1P<F5T:2!V:&]D82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C8P,`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")K;&EK
M;FD@='4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R
M,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(FYA
M<&%K82!V('5P;W)A8FYI('5K87IN92!V<G-T:6-E(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I9W5R871I
M;VX@97)R;W(B"FUS9W-T<B`B3F%P86MA('8@:V]N9FEG=7)A8VEJ:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C
M<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(DYE(&YA:F1E
M;2!Z86AT979A;F4@<VES=&5M<VME(&1A=&]T96ME(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T
M(&5R<F]R(@IM<V=S='(@(DYA<&'$C6YA(&]B;&EK82!D871U;6$B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED(")E9&ET(@IM<V=S
M='(@(E5R961I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(").92!N86ID
M96T@=FYE<V5N:6@@<&]D871K;W8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")0
M861A=FEN92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP
M,PIM<V=I9"`B9FEL92(*;7-G<W1R(")D871O=&5K82(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3@V(&QI8B]";&]C:R]M971A<BYP:'`Z,S<R(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,SDX"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B:7H@)7,@*"5S*2!K("5S
M("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I
M9"`B9W5S=&EN9R(*;7-G<W1R(")G;W-T:6TB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R
M(")H.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-C,*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN
M;W=N(@IM<V=S='(@(DYE>FYA;F\@:6UE(&=O<W1I=&5L:F$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*
M;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")T86MO:B(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")I;FQI;F4B"FUS9W-T<B`B365D('9R<W1I8V%M:2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P
M=70@97)R;W(B"FUS9W-T<B`B5FAO9&YA+VEZ:&]D;F$@;F%P86MA(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN
M=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(DEN=&5R;F$@;F%P86MA
M('8@<')O9W)A;74B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(G9R<W1I8V4B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(FUK:7-O9G,@;F%P86MA
M(&MO9&4@)60L(&UE9"!P<FEP<F%V;&IA;FIE;2!)4T\N(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-`IM<V=I9"`B;6TB
M"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C(X,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<T"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR-#,*;7-G:60@(FYA;64B"FUS9W-T
M<B`B:6UE(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B
M;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FYI(&1O:V]NQ(UA;F\B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO
M="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`BQ:%E(&YI('!O9'!R=&$B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A
M9"(*;7-G<W1R(")"96QEQ;YK82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R(")$;W9O;&IE;FIE(&IE('IA=G)N:F5N;RXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L(@IM<V=S='(@(FYA<&%K82!V(&]D9&QJ96YE;2!P<F]T
M;VMO;'4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(G9Z:&%J86IOQ(UE(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E
M<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B4V5R=FES(&YI(&YA('9O;&IO
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`R"FUS9VED(")S:&]W
M(&1I9F9E<F5N8V5S(@IM<V=S='(@(E!O:V'%OFD@<F%Z;&EK92(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS
M9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('!R
M96MO($A45%`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,SDQ"FUS9VED(")S<R(*;7-G<W1R(")S<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB
M"FUS9W-T<B`B4W1A8FEL;F\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(E-I
M<W1E;7-K82!N87!A:V$N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")397IN86T@;W!R879I
M;"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM
M<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B>F'$C6%S;F$@;V1P
M;W9E9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B>F$@<&]T<F1I=&5V('9T:7!K86IT
M92!G97-L;R!D=F%K<F%T(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T
M<B`B96YO=&5N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C(W
M.0HC+"!F=7IZ>0IM<V=I9"`B=6YK;F]W;B!E<G)O<B(*;7-G<W1R(")P;VIA
M=FEL82!S92!J92!N87!A:V$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A
M<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S='(@(F)R97H@:6UE;F$B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(DEZ8FER82!U
M<&]R86)N:6MA("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=B!+87)T:6-A(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM
M<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE
M<BYC;VTB"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!O+V)G7T)'+G!O````````````````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8T,S<Q,2`Q,#4Q-30S
M-#$T,B`P,3<T-C0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(R!"=6QG87)I86X@=')A;G-L871I;VYS(&9O<B!(;W)D92!P
M86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P,B!(;W)D92!0<F]J96-T"B,@
M5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N
M<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@36ER;W-L878@4&5N9&5V(#QM
M:7)O0&-Y8F5R<VAA9&4N=7,^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B
M(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S7&XB"B)297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M
M4F5V:7-I;VXM1&%T93H@,C`P,BTQ,2TQ.2`R,#HT-"TP-3`P7&XB"B),87-T
M+51R86YS;&%T;W(Z($UI<F]S;&%V(%!E;F1E=B`\;6ER;T!C>6)E<G-H861E
M+G5S/EQN(@HB3&%N9W5A9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<
M;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]0U`Q,C4Q7&XB"B)#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S
M='(@(B`H)7,@Y.WH(.W@Y^#D*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(@*"5S(.3MZ"#MX.?@Y"DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<S"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*.3MY?$I
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT
M;VUO<G)O=RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,W,0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`HXO?E\.`I
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U-B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C8U.0HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P-#(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E
M9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@(B<E<R<@[>4@Y2#J
M[NWTZ./S\.CPX.T@XB!(;W)D92!296=I<W1R>2XB"@HC.B!F<F%M97=O<FLO
M5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R
M("(G)7,GX>7XY2#D[N'@XN7MX"#J^NP@X_#S[^CRY2XB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2XB"FUS9W-T<B`B)R5S)R#AY?CE(.3NX>#BY>T@ZOKL(/'H\?+E[.#RX"#G
MX"#O\.#BX"#MX"#O[O+PY>'H\N7KZ/+E+B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB
M"FUS9W-T<B`B)R5S)^WE(.'E^.4@\?KGY.#DY>TZ("5S+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F
M34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I
M8V4B"FUS9W-T<B`B)7,@+2#'X.'EZ^7FZN`B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N(@IM<V=S='(@(B5S(,[A\>OSYN+@^>@@[N_E\.#VZ.@@+2#/
M[O+B^O#FY.7MZ.4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3:6=N(%5P
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E96UE;G0B"FUS
M9W-T<B`B)7,@T_'K[N+H_R#O[B#1[^[PX.?S[.7MZ.7R[B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O
M0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T
M-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S
M(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P
M97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB
M"FUS9W-T<B`BR.?AY?#E\N4@[N_E\.#VZ.CRY2P@ZN[I\NX@Z/'JX/+E(.3@
M(.CGXOKP^.CRY2#QY>/@+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS
M9W-T<B`B)7,@[>7NX?7NY.CL(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`BPO'EZN@@-2#LZ.WS\N@B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,3(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(NWE(.'E^.4@[>#LY?#E[2(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(EOK
MZ.WH_R`E<R#N\B`E<UTB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDR,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`BP.3PY?'E[2#AY>OEYNWHZB(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(LK@Z^7MY.#P(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(E<R`M(,?@X>7KY>;J
MX"(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B
M:6QE+G!H<#HY-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S
M(@IM<V=S='(@(B5S[>#LY?#E[3HE<R`E<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET
M(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN
M:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@
M<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED
M("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C(P"B,L(&9U>GIY"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R
M("+([?3N\.S@]NC_(.?@(,+@\2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`BR.WT
M[O#LX/;H_R#GX"#"X/$B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@]^#QX"(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B02!D
M871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`HC
M+"!F=7IZ>0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS
M9W-T<B`B/&(^S>7O\.7NY.[KZ.S@(./PY?CJX#H\+V(^(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G
M<W1R("+'X"#DX"#J\.CO\NCPX/+E(._H\>SN(.4@[>7NX?7NY.CL(._SX>OH
M]^7M(%!'4"#JZ_[W+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(L?@(.3@(._P
M[N+E\.CRY2#O[N3OZ/'@[>X@[^CQ[.X@Y2#MY>[A]>[DZ.P@4$=0(.KK_O<N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y-PIM<V=I
M9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*(FUE<W-A
M9V4N(@IM<V=S='(@(B(*(L?@(.3@(.3EZO#H[_+H\.#RY2#OZ/'L[B#QX"#M
MY>[A]>[DZ.SH.B#O\^'KZ/?E[2#JZ_[W+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[B
MX"`B"B+T\.#GX"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@HBQ^`@Y.`@[^[D[^CXY?+E(._H\>SN
M(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH]^7M(.KK_O<@Z"#J
MZ_[W[N+@("(*(O3PX.?@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3`U"B,L(&9U>GIY"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@HBQ^`@Y.`@Y.7J\.CO\NCPX/+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._S
MX>OH]^7M(%--24U%(.KK_O<L(.OH]^7M(%--24U%("(*(NKK_O<@Z"#JZ_[W
M[N+@(/3PX.?@+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-#,Q"B,L(&9U>GIY"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y
M+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U
M:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HBQ^`@Y.`@
M[^[D[^CXY?+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(%--24U%
M(.KK_O<L(.OH]^7M(%--24U%(.KK_O<@Z"`B"B+JZ_[W[N+@(/3PX.?@+B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED
M(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(L?@(.3@(.KPZ._RZ/#@\N4@[^CQ[.X@Y2#M
MY>[A]>[DZ.P@[_/AZ^CWY>T@4TU)344@ZNO^]RXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@
M(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*
M;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B04TO
M4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U
M="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED
M(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@
MPN#Q(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U"B,L(&9U>GIY"FUS
M9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(L_N\N+Z\.3E\N4@[^#P
M[NO@\N`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,S"B,L(&9U>GIY"FUS
M9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(LSN__+@(,_N^>`B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L
M+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R("+$[N'@XNKH
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR
M,C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("+$
M[N'@XO_MY2#MX"#M[N+@(./P\^_@(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY
M"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R
M("+$[N'@XO_MY2#MX"#M[N+H(._PX.+@(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R
M("+`Y/#E\2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(L3NX>#B
M_^WE(.W@(.WNXN`@X_#S[^`B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*;7-G
M:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("+$[N'@XO_MY2#MX"#M
M[N+H(._PX.+@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL
M9"YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@9W)O=7`@=&\@7"(E<UPB(@IM<V=S='(@(L3NX>#BZ"#MX/'KY>3E[>`@
MX_#S[^`@ZOKL("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI
M;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`BQ.[AX.+H(.W@\>OE
MY.7MZ"#O\.#BX"#J^NP@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS
M9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`BQ.[AX.+H(.WNXB#O[O+P
MY>'H\N7K.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`HC+"!F=7IZ>0IM<V=I
M9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(L3NX>#BZ"#M[N(@]^OE[2(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!P86ER(@IM<V=S='(@(L3NX>#BZ"#PY>?^[.4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*
M(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@
M(L3NX>#BZ"#J^NP@[.[_\N`@X.3PY?'MX"#J[>CCX#HB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G
M:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`BQ.[AX.+H(.KZ
M["#L[O_RX"#@Y/#E\>W@(.KMZ./@.B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q
M"B,L(&9U>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("+$[N'@XN@@[>[B
M(._N\O#EX>CRY>LZ(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O('1H92!S>7-T96TL(&)U
M="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N
M.B`B"B(E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("+$[N'@XO_MY?+N(.W@(._N\O#EX>CRY>OH(.4@
MY^#A\.#MY>WN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED
M(")!9&1R97-S(@IM<V=S='(@(L#D\.7Q(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S.0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(L#D
M\.7QY>T@X>7KY>;MZ.HB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B061M:6YI<W1E<B`M('-E
M="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`BT.7DX.KV
MZ/\@[>`@[_#@XN#RX"#GX"`G)7,G(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(L#D[.CMZ/'R\.CPX.WE(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(L3N
MX>#BZN@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S
M='(@(L_QY>+D[NWH["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*(RP@9G5Z>GD*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`BS_'EXN3N[>CL(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T
M<B`BS_'EXN3N[>CL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ>0IM<V=I9"`B06QI9VXB"FUS
M9W-T<B`BS_'EXN3N[>CL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N
M=&EC871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM
M<V=S='(@(L+QZ/?JZ"#C\//OZ"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H
M<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(L+QZ/?JZ"#O
M\.#BX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-3,T"FUS9VED(")!;&QO=R!S971T:6YG(&]F(&]R9&5R
M960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G
M:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,#<*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY"FUS
M9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+"X/CH_R!%
M;6%I;"#@Y/#E\3HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I
M9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*
M;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X
M"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N(@IM<V=S='(@(L+ZXN7DY>W@\N`@\?+NZ>WN\?(@[>4@Y2#D[N_S
M\?+H[.`N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC
M+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB
M"FUS9W-T<B`B[>7O\.7NY.[KZ.S@(./PY?CJX#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!;F1O<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M9V]L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y
M"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"B,L(&9U>GIY"FUS
M9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("+"X.K@[?;H_R(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I
M;VX@3&ES="(*;7-G<W1R("+-X.SE\.7MZ"#O\.CK[N;E[>C_.B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P<&QI8V%T:6]N
M(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q
M"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM
M<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`BT.#G[.7P(.W@(.#P
M]>CB[>C_(/3@Z>LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM
M<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(LCLY2#MX"#@\/7HXN`B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A
M;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G
M<W1R("+1Z./S\.WH(.OH(/'RY2P@]^4@Z/'JX/+E(.3@(.CG\O#HY?+E("<E
M<R<@Z"#B\>CWZN@@[^[D[_#@XN`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A
M;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`BT>CC\_#MZ"#KZ"#Q\N4L(/?E(.CQ
MZN#RY2#DX"#HY_+PZ.7RY2`G)7,G(.@@XO'H]^KH(._NY./P\^_H/R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!
M<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I
M9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I
M;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BQ.`@\>4@Z/'J
MX"#KZ"#O[O+B^O#FY.7MZ.4@[_#EY.@@[N'QZ_/FXN#YZ/+E(.[OY?#@]NCH
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S
M<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"XB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@[>7Q
M^OGE\?+B\^+@^>`@X_#S[^`N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>4@
M[>7Q^OGE\?+B\^+@^>@@[_#@XN`N(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("+#\.7XZN`@[_#H(/#EY.#J\NCPX.WE(.W@
M(.WE\?KYY?'RXO/BX/GH(._PX.+@+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("+#\.7XZN`@[_#H(/#EY.#J
M\NCPX.WE(.W@(.WE\?KYY?'RXO/BX/GH(._PX.+@+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@
M(L#R\.CA\_+H(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S(*(RP@9G5Z>GD*;7-G:60@(D%U9W5S="(*;7-G<W1R("+!^N/N
MXN4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*
M;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U
M:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS
M9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W
M"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R
M("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S
M97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D
M871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E
M9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@Z.3E[?+H].CJX/;H_R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.3E[?+H].CJX/;H_R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(LCDY>WRZ/3HZN#V
MZ/_RX"#AY?CE(.[R]>+Z\.OE[>`@[O(@4D%$2553(/'Z\.+Z\.`N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*(RP@9G5Z>GD*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM<V=S='(@(L+P^N?JX/+@
M(/'Z\2!&5%`@\?KPXOKPX"#QY2#O\.[BX.OH+B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM
M<V=S='(@(LW@Z^CW[>@@[^[KY?+@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z
M97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I
M9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O
M;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B
MS>7BX.OHY.W@(&ME<F)E<F]S("#OX/#NZ^`N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N
M86UE+B(*;7-G<W1R("+-Y>+@Z^CD[>X@:V5R8F5R;W,@[^[R\.7AZ/+EZ_'J
M[B#H[.4N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN(@IM<V=S='(@
M(D)A<F)I92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS
M9VED(")"86YG;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HS,0HC+"!P:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C
M=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@
M(D)A<V5L:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R
M=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")"96QI>F4B"FUS
M9W-T<B`BT.#G[.7P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I9"`B0FER
M=&AD87DB"FUS9W-T<B`BT.[FY.7M(.3E[2(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("+1Z_/XX/+EZ__R("5S(.WE(.4@[>#LY?#E
M[2XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@
M(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*
M;7-G:60@(D)O;&0B"FUS9W-T<B`BT^3EX>7KY>WH(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM
M<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`BSO+LY?+J
MZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")(;W)D
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B2&]R9&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")";W1S=V%N
M82(*;7-G<W1R(")"<F]W;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(L_N^>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R
M=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*(RP@9G5Z>GD*;7-G:60@(D)U;&QE=&5D
M($QI<W0B"FUS9W-T<B`BS^[D\.7DY>T@\>_H\?KJ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM
M<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0T-`IM<V=I9"`B0TU3(@IM<V=S='(@(D--4R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*
M;7-G<W1R(")#4D,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G
M:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@
M8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+*X.OE[>3@
M\"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*(RP@9G5Z
M>GD*;7-G:60@(D-A;&TB"FUS9W-T<B`BSO+JX.;H(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M
M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A
M;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B
M"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\2#LY>GK(/'Z\.+Z\#H@
M)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S
M='(@(LK@Z^7MY.#P(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S
M97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB
M"FUS9W-T<B`BSO+JX.;H(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@[_#E[.#UXN#MY3L@*"5S*2#BY??E(/'Z^>7Q\N+S
MXN`B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD
M<F5N(&5X:7-T+B(*;7-G<W1R("+#\.7XZN`@[_#H(._PY>S@]>+@[>4[("@E
M<RD@XN7WY2#Q^OGE\?+B\^+@(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T
M<B`BSN_VZ.@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B
M0F%R8FEE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#
M871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@
M4&AO;F4B"FUS9W-T<B`BS.[AZ.OE[2#RY>OE].[M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0HC+"!F=7IZ
M>0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@(LSNX>CKY>T@\N7K
MY?3N[2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*
M;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L
M;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B
MS.[AZ.OE[2#RY>OE].[M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*
M;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*
M(RP@9G5Z>GD*;7-G:60@(D-E;G1E<B(*;7-G<W1R("+6Y>WR\.CPX.TB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-E
M;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T
M:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/=VYE
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")#:&%D(@IM<V=S='(@
M(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ>0IM<V=I9"`B
M0VAA;F=E(@IM<V=S='(@(D]R86YG92(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`BS^[RXOKPY.7RY2#OX/#NZ^#RX"(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE
M(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A
M;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I
M;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U
M<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R
M(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL
M92(*;7-G<W1R("+TX.GK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O
M<F0B"FUS9W-T<B`BS^[RXOKPY.7RY2#OX/#NZ^#RX"(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S
M97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(M'K\_C@\N7K__(@)7,@[>4@
MY2#MX.SE\.7M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$T"B,L(&9U>GIY"FUS9VED(")#;&5A<B(*;7-G<W1R("+*X.OE
M[>3@\"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R
M.B`E<R(*;7-G<W1R("+/\.7LX/7MZ"#O[O+PY>'H\N7K.B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@
M=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHS-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S
M='(@(LCGX>7PZ"#O[O+PY>'H\N7K(.?@(.3NX>#B_^WE(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R
M:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3(*(RP@9G5Z>GD*;7-G:60@(D-L;W-E
M(%=I;F1O=R(*;7-G<W1R("+'X/+B[O#H(._P[N?N\.7V(%PBS^[L[OE<(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PHC+"!F=7IZ>0IM
M<V=I9"`B0VQO=61Y(@IM<V=S='(@(LKN[^CPX.DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS
M9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S
M92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B
M;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L
M;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S
M97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO
M<B!0:6-K97(B"FUS9W-T<B`BR.?AZ/#@[>4@[>`@]N+_\B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@(D-O;&]U<B!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L
M97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V
M-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(LKN[.CJ\>@B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T
M<B`BRN[LX.WDZ#HB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*(RP@9G5Z
M>GD*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`BRN[LX.WDZ#HB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`BRN[LX.WDZ#HB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(D-O
M;6]R;W,B"FUS9W-T<B`BRN[LZ.KQZ"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T
M<B`BRN[L[^#MZ/\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G
M:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VXB"FUS
M9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#D*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`BRN[M].CC
M\_#@]NC_(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`BRN[M
M].CC\_#@]NC_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B
M0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("+/[O+B^O#DY?+E(._@\.[KX/+@
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE
M9"XB"FUS9W-T<B`BPO#ZY^K@\N`@\?KQ($944"#Q^O#B^O#@(/'E(._P[N+@
MZ^@N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q
M,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R
M("+"\/KGZN#RX"#Q^O$@1E10(/'Z\.+Z\.`@\>4@[_#NXN#KZ"XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T
M<B`BQ.[Q\OKOX"#D[B#O\^'KZ/?MZ/\@\?KPXOKP(.'E^.4@[O+JX.?@[2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@
M(L3N\?+Z[^`@Y.X@[_/AZ^CW[>C_(/'Z\.+Z\"#AY?CE(.[RZN#GX.TN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*(RP@9G5Z>GD*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(L+P^N?JX/+@(/'Z\2!&5%`@\?KPXOKPX"#QY2#O\.[BX.OH+B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3,*(RP@9G5Z>GD*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"B+2
MY>?H(.3@[>WH(.?@(.KN[?+@ZO(@X?_UX"#S\>_E^.WN(.3NX>#BY>WH(.KZ
M["#"X/C@\N`@[_#NX_#@[.`N(,KKZ.KMY?+E(._N+2(*(N3NZ_,@Y^`@Y.`@
MXNCDZ/+E.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS
M9W-T<B`BT?KD^O#FX.WHY2#MX"`G)7,G(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S
M"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED
M(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS
M9VED(")#;W!Y(@IM<V=S='(@(LKN[^CPX.DB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]P>2!F86EL960Z("5S(@IM<V=S='(@(LCL[^[P\NCPX.WN(._NZ^4Z("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM
M<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@
M(L/PY?CJX"#O\.@@4$=0(.KPZ._RZ/#@[>7R[B#MX"#OZ/'L[BXB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`BP_#E^.K@(._PZ"!0
M1U`@[^[D[^CQXN#MY?+N(.W@(._H\>SN+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`BP_#E^.K@(._P
MZ"!334E-12#J\.CO\NCPX.WE\NX@[>`@[^CQ[.XN(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("+#\.7XZN`@
M[_#H(%--24U%(._NY._H\>+@[>7R[B#MX"#OZ/'L[BXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<R(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S
M+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B
M0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(LWEXOKG
M[.[F[>[Q\B#DX"#QY2#N\?KYY?'RXN@@XO#ZY^K@(/$@3$1!4"#Q^O#B^O`N
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BP_#E
M^.K@(._PZ"#O[NOS]^#BX.WE\NX@[>`@[_/AZ^CW[>C_(.KK_O<@[O(@ZNO^
M]RWQ^O#B^O#@+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(LWEXOKG
M[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`BP_#E^.K@(._PZ"#QXOKP
MY^+@[>4@\?KQ(%--0B#Q^O#B^O`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T
M<B`BP_#E^.K@(._PZ"#QXOKPY^+@[>4@\2!24$,@\?KPXOKP.B`E<R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'Z
MY^3@XN#MY2#MX"#K[NK@Z^W@(.3H\.7J\N[PZ/\@Y^`@Z^[JX.OHY^#VZ/\@
M)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`BP_#E
M^.K@(._PZ"#DY>KPZ._RZ/#@[>7R[B#MX"!01U`@Y.#M[>@N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*(RP@9G5Z>GD*;7-G
M:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.3EZO#H[_+H\.#MY?+N(.W@(%--24U%(.3@[>WH+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H
M\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU
M,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(LWEZN[PY>KRY>T@96UA:6P@X.3P
MY?$@[>`@[^[K\_?@\N7K_RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BS>7J
M[O#EZO+E[2!E;6%I;"#@Y/#E\2#MX"#O[NOS]^#RY>O_+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED
M(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@
M\NX@)7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I
M<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("+#\.7XZN`@[_#H
M(._NZ_/WX.+@[>7R[B#MX"#O\^'KZ/?MZ/\@ZNO^]R#N\B#JZ_[W+?'Z\.+Z
M\.`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG
M+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@ZN[OZ/#@("5S(/+N("5S
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(V,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@
M)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`BS>7B^N?L
M[N;M[O'R(.3@(/'E(.[RXN[PZ"#.X?'K\^;BX/GH7^?@Y.#WZ"#L[N3SZR`E
M<R`B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM
M<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N
M;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("+-Y>+ZY^SNYNWN
M\?(@Y.`@\>4@[O'Z^>7Q\N+H(.+P^N?JX"#Q($Q$05`@\?KPXOKP+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B
MS>7B^N?L[N;M[O'R(.3@(/'E(.KN[^CPX"`E<R#R[B`E<RXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T
M(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3
M;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N
M(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y
M;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M(@IM<V=S='(@(LWEZN[PY>KRY>T@96UA:6P@X.3PY?$@[>`@[^[K\_?@\N7K
M_RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R
M979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2&]R9&4@[>4@Y2#J[NWT
MZ./S\.CPX.T@ZN[PY>KR[>XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(LWE[N'U[N3H[.C_("=P;W)T)R#MY2#E(.?@
MY.#DY>T@XOKB(%9&4R#J[NWTZ./S\.#VZ/_RX"XB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G
M:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL
M92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V
M97(N(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#DX"#QY2#N\?KYY?'RXN@@XO#Z
MY^K@(/$@3$1!4"#Q^O#B^O`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB
M)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"!01U`@[^[D[^CQXN#MY?+N(.W@
M(._H\>SN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(LWEXOKG[.[F[>[Q
M\B#DX"#QY2#J[N_H\.`@)7,@\NX@)7,N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG
M=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("+#\.7XZN`@[_#H(/'Z
MY^3@XN#MY2#MX"#K[NK@Z^W@(.3H\.7J\N[PZ/\@Y^`@Z^[JX.OHY^#VZ/\@
M)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT
M960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R
M("+HY_#EYN@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS
M9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDT"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S
M='(@(LCGX>7PY?+E(.WNXB#O\.CRY>;@\N7K(.W@(./P\^_@(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(T,`HC+"!F=7IZ>0IM<V=I9"`B0W)E871O<B!0
M97)M:7-S:6]N<R(*;7-G<W1R("+/\.#BX"#O[B#O[N3PX.?AZ/#@[>4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P"FUS9VED(")#<F5D:70@
M8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R
M;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E
M;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C0X"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@
M(L_PX.+@(.?@(./N\?+H(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB
M+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@(D-U
M<G)E;G0@57-E<G,B"FUS9W-T<B`BPN#XZ/+E(/'Z\.+Z\.@Z(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S4*
M;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B
M0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P
M"FUS9VED(")#=70B"FUS9W-T<B`BZ.?PY>;H(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(D-Y
M<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(L3$(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*
M;7-G<W1R("+%YN7D[>7B[>XB"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*
M;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A<V4@3&]O:W5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Y.0HC+"!F
M=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R("+$X.WMZ"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#<*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3(@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,R,@HC+"!F=7IZ>0IM<V=I9"`B1&%Y(@IM<V=S='(@(L7F
MY>3MY>+M[B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS-@HC+"!F=7IZ>0IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`BR.?AY?#E\N4@ZN[K[NWH.B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"B,L(&9U>GIY"FUS9VED(")$
M96-E;6)E<B(*;7-G<W1R("+7Z^7M[N+E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C
M:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G:60@(D1E8W)E
M87-E($EN9&5N="(*;7-G<W1R("+-X.S@Z^@@\^7D[>#JXO_BX.WE\NXB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N
M<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R("+(Y_+P
MZ.DB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHT-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHW-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("+(
MY^_NZ^?BX.D@[^[D\.#GX>CPX/G@\N`@\>4@\?+NZ>WN\?(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ"FUS9VED(")$969A=6QT
M($ED96YT:71Y(@IM<V=S='(@(LCDY>WRZ/?M[O'R(._N(._NY/#@Y^'H\.#M
MY2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-PHC+"!F=7IZ>0IM<V=I
M9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("+(Y.7M\NCW[>[Q\B#O[B#O[N3P
MX.?AZ/#@[>4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("+(
MY_+PZ.DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM
M<V=S='(@(LCG\O#HZ2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`BR.?R\.CI(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(LCG
M\O#HZ2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(L_PX.+@(._N(._NY/#@Y^'H
M\.#MY2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@
M(LCG\O#HZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`BR.?AY?#E\N4@ZN[K[NWH.B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E
M;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+0Y>3@ZO;H_R#MX"#O
M\.#BX/+@(.?@("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E
M<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M(@IM<V=S='(@(M'HX_/P[>@@Z^@@\?+E+"#WY2#H\>K@\N4@Y.`@Z.?R\.CE
M\N4@)R5S)R#H(.+QZ/?JZ"#O[N3O\.#BX#\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@<F]W(@IM<V=S='(@(LCG\O#HZ2(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@
M(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R("+(Y.7M\NCW[>[Q
M\B#O[B#O[N3PX.?AZ/#@[>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE
M=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S
M='(@(LCG\O#HZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G
M:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C
M<FEP=&EO;B(*;7-G<W1R("+/^NOM[B#N[^CQX.WHY3HB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`BQ.7RX.GK
MZ/+E(.'_]>`@\.7CZ/'R\.CPX.WH(.?@(.#D[.CMZ/'R\.#R[O#@+B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3D*;7-G:60@(D1E=F5L;W!M
M96YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$W"FUS
M9VED(")$97<@4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-PIM
M<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N
M(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8V"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM
M97,_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM
M<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(L3H\>_KY>D@SN_VZ.@B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`BQ.CQ
M[^OEZ2#.[_;HZ"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@
M(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA
M>2!F;W)M870B"FUS9W-T<B`BQ.CQ[^OEZ2#.[_;HZ"(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB
M;W5T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0R,@HC+"!F=7IZ>0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R
M("+(Y_+PZ.DB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G
M:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E
M;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O
M;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A
M;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@
M=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("+-Y>CGXN7Q
M\NW@(.KN[.#MY.`Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V
M,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")$
M<G5G<R(*;7-G<W1R("+!^N/NXN4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R
M("+/[OG@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("+0Y>3@ZO;H_R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A
M;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@HC
M+"!F=7IZ>0IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("+#\//OZ"(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;B(*;7-G<W1R("+/\.#BX"(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HR,S<*(RP@9G5Z>GD*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`BS_#@XN`B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z
M,C,Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VYS(&9O<B`E<R(*;7-G<W1R("+0Y>3@ZO;H_R#MX"#O\.#BX/+@(.?@("<E
M<R<B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"B,L(&9U>GIY"FUS
M9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+0Y>3@ZO;H_R#MX"#O
M\.#BX/+@(.?@("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(M#EY.#J]NC_(.W@(._PX.+@
M\N`@Y^`@)R5S)R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@
M9F]R("5S(@IM<V=S='(@(M#EY.#J]NC_(.W@(._PX.+@\N`@Y^`@)R5S)R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B
M161U8V%T:6]N(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I
M="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("+/Z/'L[B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M("+%;6%I;"#@Y/#E\2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R
M(")%;6%I;"#@Y/#E\>CRY2#R\/_AXN`@Y.`@\?KB[^#DX/(N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA
M:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`BQ/#SX^`@Z.WT[O#LX/;H
M_R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDQ"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDX"B,L
M(&9U>GIY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BSN_VZ.@B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*
M(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(L_PX.?E
M[2#PY>?SZ_+@\BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@
M(L_PX.?E[2#PY>?SZ_+@\BXB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I9"`B16YA
M8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@
M:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H
M870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HX
M,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`BP_#E^.K@(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O
M<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B175R;W!E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,SD*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`BPO'EZN@@
M,34@[.CM\_+H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F
M=7IZ>0IM<V=I9"`B179E<GD@,B!M:6YU=&5S(@IM<V=S='(@(L+QY>KH(#4@
M[.CM\_+H(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM
M<V=S='(@(L+QY>KH(#,P(/'EZO/MY.@B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V
M97)Y(#4@;6EN=71E<R(*;7-G<W1R("+"\>7JZ"`U(.SH[?/RZ"(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@
M(D5V97)Y($QO9VEN(@IM<V=S='(@(L+Q_^KN(.ONX^+@[>4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H86QF(&AO=7(B
M"FUS9W-T<B`BS>`@XO'EZN@@[^[K[N+H[2#WX/$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G
M:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+"\?_JX"#LZ.WS\N`B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V
M86QU97,Z(@IM<V=S='(@(L_PZ.SE\.WH(/'R[NGM[O'RZ#HB"@HC.B!A9&UI
M;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,C<*(RP@9G5Z>GD*;7-G:60@(D5X96-U=&4B"FUS
M9W-T<B`BR.?O^NOM_^+@[>4@[>`Z(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP
M86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G
M:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N
M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`BR.?O\.#YX.WE\NX@
M[>`@].#IZ^[BY2#MY2#QY2#O[N3D^O#FX"XB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y.`@\>4@Y^#P
MY>3_\B#O\.7TY?#E[?;HZ/+E+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX
M"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`BS>7B^N?L[N;M[O'R(.3@(/'E(.[Q^OGE\?+BZ"#B\/KGZN`@\2!,
M1$%0(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(L/PY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z\2!334(@\?KPXOKP+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(/'B^O#GXN#MY2#Q^O$@4TU"(/'Z\.+Z
M\"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED
M(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(L/P
MY?CJX"#O\.@@\>+Z\.?BX.WE(/'Z\2!334(@\?KPXOKP+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(LWEXOKG
M[.[F[>[Q\B#DX"#QY2#GX/#EY/_R(._PY?3E\.7M]NCH\N4N(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A
M:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(L/PY?CJX"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R("+4X.KQ(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T.0HC+"!F=7IZ>0IM<V=I9"`B1F%X
M97,B"FUS9W-T<B`BU.#J\2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,`IM<V=I9"`B1F5E;',@3&EK92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,Q
M"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#0*;7-G:60@(D9I
M96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S,T"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")&:6=L970@
M9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F
M=7IZ>0IM<V=I9"`B1FEL92(*;7-G<W1R("+TX.GK(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL92(*;7-G<W1R("+!\.[I(/3@Z>ONXN4Z("5S(/3@Z>LB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("+!\.[I(/3@
MZ>ONXN4Z("5S(/3@Z>O@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(M3@Z>L@[.7MX.;E
M\"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED(")&:6QE
M($YA;64B"FUS9W-T<B`BR.SE(.W@(/3@Z>LB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"B,L(&9U>GIY
M"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("+([.4@[>`@].#IZR(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(LCG[_#@^>#MY?+N
M(.W@(/3@Z>ONXN4@[>4@\>4@[^[DY/KPYN`N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(M3HZ_+Z
M\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G
M:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I
M9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B
M1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R
M9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V
M,@HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`BU.[P\^SH(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"B,L(&9U>GIY"FUS9VED(")&;W)T
M=6YE(@IM<V=S='(@(M3N\//LZ"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`BU.[P\^SH(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y
M"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(M3N\//LZ"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M
M<R(*;7-G<W1R("+4[O#S[.@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3`Y"B,L(&9U>GIY"FUS9VED(")&;W)W87)D<R(*;7-G<W1R("+/\.7O
M\.#YX.WH_R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*
M;7-G:60@(D9R86UE<R(*;7-G<W1R("+4[O#S[.@B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L
M(&9U>GIY"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B3W)A;F=E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE
M=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N
M8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N
M8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B
M1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*(RP@9G5Z
M>GD*;7-G:60@(D9R;VTB"FUS9W-T<B`BU.[P\^SH(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*
M;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C
M<FEP=&EO;B(*;7-G<W1R("+/^NOM[B#N[^CQX.WHY3HB"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B
M1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED
M(")&=6QL($YA;64B"FUS9W-T<B`BR.SE(.W@(/3@Z>LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=E;F5R871E("5S
M($-O;F9I9W5R871I;VXB"FUS9W-T<B`BRN[M].CC\_#@]NC_(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R
M871E9"!#;V1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S4*(RP@9G5Z>GD*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`BR.SE(.W@(/3@Z>LB"@HC.B!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I9"`B1V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,C@*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V"B,L(&9U>GIY"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W)E96XB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E3
M3RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*(RP@9G5Z>GD*;7-G
M:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F5E;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*(RP@
M9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E96XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@[>`@X_#S[^@B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M9&5L971E(&=R;W5P("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T
M<B`BP_#S[^@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@HC+"!F=7IZ>0IM<V=I9"`B1W5E
M<FYS97DB"FUS9W-T<B`B1W)E>2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C(V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G
M:60@(D=U97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(L_PX.+@(.?@(./N\?+H
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E
M<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(
M5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10(.CDY>WR
MZ/3HZN#VZ/\@[>4@Y2#MX.SE\.7MX"XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z
M>GD*;7-G:60@(DAA:71I(@IM<V=S='(@(LKNY?3H]NCE[?(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG
M;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(96%D97(B"FUS9W-T<B`BQ^#C
MZ^#BZ/\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(96%D97)S(@IM<V=S='(@(L?@X^O@
MXNC_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@
M(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED
M(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(L_N[.[Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM
M<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,0HC+"!F=7IZ>0IM<V=I9"`B2&5L<&5R
M(@IM<V=S='(@(L_N[.[Y(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS
M9VED(")(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P
M"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E
M<BYI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B2&]?;64B"FUS9W-T<B`BS>#WX.ON
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-3,U"FUS9VED(")(;VUE(@IM<V=S='(@(LW@]^#K[B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B
M2&]M92!!9&1R97-S(@IM<V=S='(@(L3N[.#XY>T@X.3PY?$B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER96-T;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BQ.[LX/CE[2#R
MY>OE].[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@(DAO<F1E
M(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN=F%L
M:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R
M97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(M/Q
M[^7X[>X@[_#E[.#U[>#R("<E<R<@[O(@\>CQ\N7LX/+@+B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@
M5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@
M4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H
M92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO
M;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W
M(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@
M(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("+#\.7XZN`@[_#H(/'ZY^3@XN#MY2#MX"!)34%0(._N^>7M\>K@(.KS\NC_
M.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(DE-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM
M<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE(.W@($E-05`@[^[YY>WQZN`@
MZO/RZ/\Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<Y(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BP_#E^.K@(._N\.#DZ"#JXN[RX"#O\.@@\?KG
MY.#BX.WE(.W@($E-05`@[^[YY>WQZN`@ZO/RZ/\Z("5S(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("+`Y/#E\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:7!B87-I8RYP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(DE0($%D9')E<W,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B25`@X.3PY?'@(.WE(.4@XB#O[N?B[NOE
M[>C_($-)1%(@X>ONZBXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S
M:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"#@Y/#E\>`@[>4@Y2#B(._NY^+N
MZ^7MZ/\@0TE$4B#AZ^[J+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@(DE?
M;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*
M;7-G<W1R("+1X.SN(.CJ[NWH(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<W"FUS9VED("))8V]N
M<R!W:71H('1E>'0B"FUS9W-T<B`BR.KN[>@@\2#RY>KQ\B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM
M<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S
M"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS
M9VED("));6%G92!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("))
M;6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA
M9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E
M;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS
M9W-T<B`BR.SO[O#RZ/#@[>X@[^[KY3H@)7,B"@HC.B!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E
M9"!F:65L9#H@)7,B"FUS9W-T<B`BR.SO[O#RZ/#@[>X@[^[KY3H@)7,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E
M9"!F:65L9',Z(@IM<V=S='(@(LCL[^[P\NCPX.WH(._NZ^7RX#HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S`*(RP@9G5Z>GD*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@
M(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC
M;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BS>7J
M[O#EZO+MX"#OX/#NZ^`@Z.OH(._N\O#EX>CRY>OQZNX@Z.SE(2(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F
M=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(DEN8W)E
M87-E($EN9&5N="(*;7-G<W1R("+3XN7KZ/?@XN#MY2#MX"#SY>3MX.KB_^+@
M[>7R[B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("));F1O
M;F5S:6$B"FUS9W-T<B`BS>#O\.#BY>WN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"B,L(&9U>GIY
M"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("+([?3N\.S@]NC_(.?@(,+@
M\2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B
M"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,L(&9U
M>GIY"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`BPNSZZNWH(._NY/#@
MXNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@
M(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!?0V]L
M=6UN($)E9F]R92(*;7-G<W1R("+"[/KJ[>@@[^[D\.#B[>CRY>LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C8*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P
M"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C,Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC
M:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS
M9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0HC+"!F=7IZ>0IM<V=I
M9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+M
MZ/+EZR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C;VQU;6X@869T
M97(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH\N7K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0HC+"!F=7IZ
M>0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`BPNSZZNWH
M(._NY/#@XNWH\N7K(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8Y"B,L(&9U>GIY"FUS9VED("));G-E<G0@<F]W(&%F
M=&5R(@IM<V=S='(@(L+L^NKMZ"#O[N3PX.+MZ/+EZR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*(RP@9G5Z
M>GD*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(L+L^NKMZ"#O
M[N3PX.+MZ/+EZR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G
M:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!)
M;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS
M9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@
M(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(LCG[_#@\N7MZ/+E(.3@[>WH
M(/'@(.WEXN#KZ.3MZ"XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C,T
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R
M("+-X.SE\.7MZ"#O\.CK[N;E[>C_.B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`BR.?O\.#RY>WH\N4@Y.#M
M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B
MR.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B
M26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N
M(@IM<V=S='(@(LCG[_#@\N7MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(LCG[_#@\N7MZ/+E(.3@[>WH(/'@(.WEXN#KZ.3MZ"XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("+(Y^_PX/+E[>CRY2#DX.WMZ"#Q
MX"#MY>+@Z^CD[>@N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<(B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S8@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A;&ED('-H87)E(&]B
M:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D
M9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"FUS9VED("));G9E
M<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B
M27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS
M9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I
M9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R("+-X.KK[NWE[>@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(LW@ZNON[>7MZ"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B
M2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED
M(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*879A<V-R:7!T
M(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P
M86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R"B,L(&9U
M>GIY"FUS9VED(")*97)S97DB"FUS9W-T<B`B1W)E>2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P
M"FUS9VED(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*(RP@9G5Z>GD*;7-G:60@
M(DIU<W1I9GDB"FUS9W-T<B`BZ__B[B#O[N3PX.+M_^+@[>4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0HC
M+"!F=7IZ>0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`BZ__B[B#O
M[N3PX.+M_^+@[>4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(N_ZZ^WN(._NY/#@XNW_XN#MY2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`BZ__B[B#O[N3PX.+M_^+@[>4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I
M9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("+D__'M[B#O[N3PX.+M_^+@[>4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM
M<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S
M"B,L(&9U>GIY"FUS9VED(")+96YY82(*;7-G<W1R("+'X.'PX.WH(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R
M;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+
M97)B97)O<R#Q^O#B^O#@(.[R]>+Z\.OH(.CDY>WRZ/3HZN#VZ/_RX"XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I
M;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*
M;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(DUI;64@\NCO(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*(RP@9G5Z>GD*;7-G:60@
M(DME>2!5<V%G92(*;7-G<W1R("+(Y^_NZ^?BX.WE.CHB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`BRNO^
M]^`@XN7WY2#Q^OGE\?+B\^+@(.(@[_/AZ^CW[>C_(.KK_O?Q^O#B^O`N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@
M(DQA7WEO=70B"FUS9W-T<B`BR.?U[N0B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R("+%Y^CJ(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y
M"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<V"B,L(&9U>GIY"FUS9VED("),87-T(%!A<W-W;W)D($-H
M86YG92(*;7-G<W1R("+/X/#NZ^`Z("(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0HC+"!F
M=7IZ>0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("+.[_#E\>WH(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("),871V:6$B
M"FUS9W-T<B`BQ.#M[>@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*
M;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z>GD*;7-G:60@(DQA
M>6]U="(*;7-G<W1R("+(Y_7NY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N
M;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A
M;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R("+-_^S@
M(/'R[NGM[O'RZ"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`HC+"!F=7IZ>0IM<V=I9"`B3&5S
M;W1H;R(*;7-G<W1R("+,Y?+NY"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BS>CJ
M[N/@(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T
M<B`B3&EG:'0@0FQU92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(@IM<V=S
M='(@(L+U[N0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I
M9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN
M(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD
M97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T
M<B`B3&EG:'0@0FQU92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R
M:6-K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,30*(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`BPO7NY"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN:W,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E
M<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED
M("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R
M("+/[NSN^2#RY>SH(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I
M9"`B3&ES="!486)L97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X
M.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(L_N[.[Y(/+E
M[.@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM
M<V=I9"`B3&ES="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM
M<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("+1[^CQ
M^NK@(/$@[^[R\.7AZ/+EZ^@@Y2#GX.'PX.WE[2XB"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("+1[^CQ^NK@(/$@[^[R\.7A
MZ/+EZ^@@Y2#GX.'PX.WE[2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(M'OZ/'ZZN`@\2#O[O+PY>'H\N7KZ"#E(.?@X?#@[>7M+B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C@S"B,L(&9U>GIY"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@
M(N?@\.7FY.#MY2#MX"#AZ.'KZ.[RY>KH\N4N+BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A;"!T:6UE.B`B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),
M;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C8U"B,L(&9U>GIY"FUS9VED("),;V-A=&EO;B(*;7-G<W1R
M("+"X.K@[?;H_R(*"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R("+"]>[D
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`BR.?U[N0B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*
M(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(L+U[N0B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`W"B,L(&9U>GIY"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("+'X.3@]^@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.38*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@HC+"!F
M=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("+O\.[BX.OE[>XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY"FUS
M9VED("),;VYG('1E>'0B"FUS9W-T<B`BR.?U[N0B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(DQO=F4B"FUS9W-T<B`B
MS_#E[.#U[>@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@
M(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I
M9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(LS,(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM
M<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R(")-4RU43D5&(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#X
MY2#DX.WMZ"XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,L(&9U>GIY"FUS9VED(")-
M4T<B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED
M(")-86-A;R(*;7-G<W1R("+"X.K@[?;H_R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z
M>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(L_N^>`B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`BS^[YX"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C(*;7-G:60@(DUA:6P@
M061M:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L
M87=I(@IM<V=S='(@(L_N^>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y
M<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI
M(@IM<V=S='(@(L_N^>`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DUA;'1A(@IM<V=S='(@(L_N^>`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S
M('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@(@HB
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,34S
M"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*;7-G:60@(DUA<F=I
M;B(*;7-G<W1R("+"[>CLX.WHY2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG
M(&9I96QD<R(*;7-G<W1R("+1^N+OX.3@^>@@[^[KY?+@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X
M(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M
M97-S86=E('!A<G1S(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,P-@IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS
M9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L
M($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(L+HY"#MX"#LY>W^\NXZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HS,`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(DUE<W-A9V4B"FUS9W-T<B`BS^CQ[.XB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@HC+"!F=7IZ>0IM<V=I9"`B(@HB
M365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G
M<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S
M='(@(B(*(L_H\>SN\NX@X>7XY2#O\.[BY?#E[>X@\_'OY?CM[BP@[>X@\>7P
M\NCTZ.K@\N`@[>`@[^[D[^CQX"#MY2#AY?CE(._N\N+Z\.3E[2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*
M(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BS^CQ
M[.XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y
M<&4B"FUS9W-T<B`BS^CQ[.XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*
M;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*(RP@
M9G5Z>GD*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(L3E\N#IZ^CRY2#A__7@(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH
M[>CQ\O#@\N[PX"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(LSE\N[D(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`BS.7R[N0@)R5S)R#MY2#E(.3E].CMZ/#@
M[2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I8R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D
M(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI
M9&1L92(*;7-G<W1R("+TX.GK(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")-
M:6UE(/+H[R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-
M:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*
M;7-G<W1R("+#\.7XZN`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*
M;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K
M86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S
M:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8X"B,L(&9U>GIY"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("+$
MX/+@(.W@(._P[NSE[?_MY2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(L3@\N`@[>`@[_#N
M[.7M_^WE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S"FUS9VED
M(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]L
M9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED
M(")-;VYT:&QY(@IM<V=S='(@(LSE\>7W[>XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ
M-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M
M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T
M;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-3`Y"B,L(&9U>GIY"FUS9VED(")-;W9E($1O=VXB"FUS
M9W-T<B`B[_#E[.7Q\N@@[>`@Y.[K\R_D__'M[B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PHC+"!F=7IZ>0IM<V=I9"`B36]V
M92!,969T(@IM<V=S='(@(N_PY>SE\?+H(.W@(./N\.4OZ__B[B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q-PHC+"!F=7IZ>0IM
M<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("+O\.7LY?'RZ"#MX"#D[NOS+^3_
M\>WN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U
M"B,L(&9U>GIY"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(N_PY>SE\?+H(.W@
M(./N\.4OZ__B[B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R
M("+O\.7LY?'RZ"#MX"#D[NOS+^3_\>WN(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"B,L(&9U>GIY"FUS9VED(")-;W9E
M('5P(@IM<V=S='(@(N_PY>SE\?+H(.W@(./N\.4OZ__B[B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*
M;7-G<W1R("+,[O_RX"#/[OG@(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM
M<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A
M;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N
M;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN
M=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DYA;64B"FUS9W-T<B`BR.SE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI
M8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C
M87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#
M02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@
M(LSPY>;@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`BS>CJ[N/@(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V
M"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*
M;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(LWNXNX@
M[^[R\.7AZ/+EZ_'J[B#H[.4@*.[O]NCN[>#K[>XI(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S
M=V]R9"(*;7-G<W1R("+/X/#NZ^`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R
M9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L(&9U>GIY"FUS9VED(").97<@<&%S
M<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G<W1R("+-Y>KN\.7J\NW@(._@\.[K
MX"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY
M"FUS9VED(").97=S(@IM<V=S='(@(L'EZ^7FZN@B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S`U"B,L(&9U>GIY"FUS9VED(").97=S9W)O=7!S
M(@IM<V=S='(@(L/P\^_H(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT
M(&]P=&EO;G,B"FUS9W-T<B`BSN_VZ.@B"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R("+-Z.KNX^`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").:75E(@IM
M<V=S='(@(M'Z[N'YY>WHY2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(DYO(@IM<V=S='(@(LWE(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A
M=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC
M97,@9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H
M92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#OX/#NZ^`@Y^`@24U!4"#HY.7M\NCT
MZ.K@]NC_+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(G)7,G(.'E
M^.4@Y.[AX.+E[2#J^NP@\>CQ\N7LX/+@(.?@(._PX.+@(.W@(._N\O#EX>CR
MY>OH\N4N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO
M571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM
M<V=S='(@(LW_[.`@Y^#DX.3E[>`@ZN[M].CC\_#@]NC_(.?@(%-13"!61E,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!&
M5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C8Y"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,(%9&4RXB"FUS9W-T<B`BS?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#V
MZ/\@Y^`@4U%,(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S$W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+-_^S@(.?@
MY.#DY>W@(.KN[?3HX_/PX/;H_R#GX"!344PM1FEL92!61E,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS
M9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*;7-G:60@(DYO(&9I;&4@=7!L
M;V%D960B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO
M8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I;VX@
M<')O=FED960N(@IM<V=S='(@(LW_[.`@Y^#DX.3E[>`@Z^[JX.OHY^#VZ/\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S,*(RP@9G5Z>GD*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM
M<V=S='(@(LW_[.`@Y^#DX.3E[>`@Z^[JX.OHY^#VZ/\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z
M>GD*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("+-_^S@(.?@
MY.#DY>W@(.ONZN#KZ.?@]NC_+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"B,L(&9U>GIY"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(.ONZN#K
MZ.?@]NC_+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B
M3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*(RP@9G5Z>GD*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("+-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)34%0(.CDY>WRZ/3HZN#V
MZ/\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)34%0(.CD
MY>WRZ/3HZN#VZ/\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@(.?@Y.#DY>W@(._@\.[K
MX"#GX"!+97)B97)O<R#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I
M;BYP:'`Z.#0*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@ZN[M].CC\_#@]NCN[>W@
M(.CM].[P[.#VZ/\@Y^`@3$1!4"#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(LW_[.`@ZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@
MY^`@4TU"(.CDY>WRZ/3HZN#VZ/\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+-_^S@(.KN[?3HX_/PX/;H
M[NWMX"#H[?3N\.S@]NC_(.?@(%--0B#HY.7M\NCTZ.K@]NC_+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BS?_LX"#Q\N[I
M[>[Q\N@B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#D*(RP@
M9G5Z>GD*;7-G:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@
M(LW_[.`@Y^#DX.3E[>`@Z^[JX.OHY^#VZ/\N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(LWEZN[PY>KR[>`@[^#P
M[NO@(.CKZ"#O[O+PY>'H\N7K\>KN(.CLY2$B"@HC.B!F<F%M97=O<FLO4E!#
M+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@
M<F5T=7)N960B"FUS9W-T<B`BPOKP[>#RZ/+E(.3@[>WH(.WE(/'@(%A-3"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`BS?_LX"#Q\N[I[>[Q\N@B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*
M(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F
M=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R("+-X._PX.+E[>XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").
M;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Y"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT
M,#@*(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("+1
M^N?DX.+@[>4@[>`@Y.CPY>KR[O#H_R`E<R(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@
M9G5Z>GD*;7-G:60@(DYO="!S970B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"B,L(&9U>GIY"FUS9VED
M(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+(Y^_PX/G@[>7R[B#MX"#TX.GK
M[N+E(.WE(/'E(._NY.3Z\.;@+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B3F]T
M97,B"FUS9W-T<B`BP>7KY>;JZ"(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN
M9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<U"B,L(&9U>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("+7
MZ^7M[N+E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F
M=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(M?KY>WNXN4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA
M<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM
M<V=S='(@(L[*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T
M"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N
M<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C8*(RP@9G5Z>GD*;7-G:60@(D]F9FEC92(*;7-G<W1R("+(Y^KK
M+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B
M3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*(RP@
M9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("+/X/#NZ^`B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`BS>7J
M[O#EZO+MX"#OX/#NZ^`@Z.OH(._N\O#EX>CRY>OQZNX@Z.SE(2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.`HC+"!F=7IZ>0IM<V=I9"`B3VUA;B(*;7-G<W1R("+"ZNLN(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G
M:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I
M9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV
M-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T
M<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U
M"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*
M;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R
M871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`BSN_VZ.@B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@
M9F]R("5S(@IM<V=S='(@(L[O]NCH(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(L_NY/#EY.7M(/'OZ/'ZZB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38W"B,L(&9U>GIY"FUS9VED(")/<F=A;FES871I
M;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,R"B,L(&9U>GIY"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R86YG
M92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA
M;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT
M"FUS9VED(")/=&AE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("+$
M\//CX"#H[?3N\.S@]NC_(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`@
M[>`@[_#H\N7FX/+EZ_\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP
M:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CDY>WRZ/3HZN#V
MZ/\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")0
M1U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*
M;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I
M9"`B4$A0(%-H96QL(@IM<V=S='(@(E!'4"!3:&5L;"(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@(E!-(%-U;B(*;7-G<W1R(")3=6XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM
M<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I
M;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"B,L(&9U>GIY"FUS
M9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!'4"!3:&5L;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G
M:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY
M"FUS9VED(")086MI<W1A;B(*;7-G<W1R("+"[/KJ[>@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R("+/X/#NZ^`B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R("+/X/#NZ^`Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-3(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(LW_[.`@ZN[M].CC
M\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4D%$2553(.CDY>WRZ/3HZN#VZ/\N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS
M9W-T<B`BS^#P[NO@.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@(L_@\.[KX#H@(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I
M9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(LWEZN[PY>KR[>`@
M[^#P[NO@+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED
M(")087-T92(*;7-G<W1R("+"[/KJ[>@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L
M:7!B;V%R9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U>GIY"FUS9VED(")0871H(@IM<V=S
M='(@(L+L^NKMZ"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW
M"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B4&5O<&QE(@IM
M<V=S='(@(M#NZ_\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0HC+"!F
M=7IZ>0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(L3@(/'E(.CGXOKP^.+@\B#KZ"#NX?'K\^;BX/GH\N4@[N_E\.#V
MZ.@@[_#H(,+U[N0_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM
M<V=I9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN
M/R(*;7-G<W1R("+$X"#QY2#HY^+Z\/CBX/(@Z^@@[N'QZ_/FXN#YZ/+E(.[O
MY?#@]NCH(._PZ"#"]>[D/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@
M(L_PX.+@(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*
M(RP@9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(L_P
MX.+@(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I
M;VYS(@IM<V=S='(@(L_PX.+@(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M
M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I
M9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH
M\?+PZ/#@[>4@[>`@[_#@XN#RX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS
M9W-T<B`BQ/#SX^`@Z.WT[O#LX/;H_R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*
M;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("+2
MY>OE].[M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM<V=I
M9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I
M=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O
M;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(LSNZ_\L(.+ZXN7D
MY?+E(.SE\>7V(.@@X^[DZ.W@+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("+,
M[NO_+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("+,[NO_+"#B^N+EY.7R
MY2#LY?'E]B#H(./NY.CMX"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"B,L(&9U>GIY"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R("+,[NO_
M+"#B^N+EY.7RY2#LY?'E]B#H(./NY.CMX"XB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C4X"B,L(&9U>GIY"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L
M;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O
M('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B+,[NO_+"#O\.[WY?+E
M\N4@\>OEY.WH__(@\N7J\?(N("#"Z.4@TM#?P<+`(.3@(/'E(/'ZX^O@\>CR
MY2#Q(//QZ^[BZ/_RX"#GX"`B"B+HY^_NZ^?BX.WE(.W@(/'H\?+E[.#RX"XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!O
M;&%N9"(*;7-G<W1R("+3Y.7AY>OE[>@B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*
M;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N
M+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T
M('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S4*(RP@9G5Z>GD*;7-G:60@(E!R97-S=7)E.B`B"FUS
M9W-T<B`BS^#P[NO@.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R
M("+/\.7GY>WRX/;HZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*
M;7-G<W1R("+/\.[AZ^7L/R(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R
M-@HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R
M("+/^NOM[B#N[^CQX.WHY3HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B
M4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`BRNO^]^[BX"#DXN[I
MZN`@[_/AZ^CWY>TO]^#Q\N7M(.KK_O<@[>4@X>7XY2#CY>WE\.CPX.W@+B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@(E%A=&%R(@IM<V=S='(@
M(L3@[>WH(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S"FUS9VED(")1=65R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G
M:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,PHC+"!F=7IZ>0IM<V=I9"`B4F%I;B(*;7-G<W1R("+*[N7TZ/;HY>WR(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G
M:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-@IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@
M86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M
M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R("+*[N7TZ/;HY>WR(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@
M(E)E860B"FUS9W-T<B`BU^7RY>WE(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S
M<V%G97,B"FUS9W-T<B`BS^CQ[.XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS
M9W-T<B`BR/'JX/+E(.3@(.CG\O#HY?+E("5S(.OH/R#2X.?H(.[OY?#@]NC_
M(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#GX.0N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("+(\>K@\N4@
MY.`@Z.?R\.CE\N4@)7,@Z^@_(-+@Y^@@[N_E\.#VZ/\@[>4@[.[FY2#DX"#Q
MY2#B^O#MY2#MX.?@Y"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO
M;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B4F5F<F5S
M:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`BSN_PY?'MZ"#0Y>?^[.4@Z.?CZ^7D
MX#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,U"FUS9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E
M<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L(&9U>GIY"FUS
M9VED(")296QO860B"FUS9W-T<B`BU^7RY>WE(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,C8*(RP@9G5Z>GD*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B
MSO+LY?+JZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(L+@^.CRY2#Q^O#B
M^O#H.B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I
M9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M(@IM<V=S='(@(L#D\.7Q(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR
M,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")2
M96UO=F4B"FUS9W-T<B`BS_#E[.#U[>@B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*
M;7-G<W1R("+/\.7LX/7MZ"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-3<*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!C;VQU
M;6XB"FUS9W-T<B`BS_#E[.#U[>@@\.7G_NSE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`BR.WT[O#LX/;H_R#GX"#"X/$B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`HC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BS_#E[.#U[>@@\.7G_NSE(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('1H
M92(*;7-G<W1R("+/\.7LX/7MZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED
M(")296UO=F4@=7-E<B(*;7-G<W1R("+/\.7LX/7MZ"#O[O+PY>'H\N7K.B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`BS_#E
M[.#U[>@@[^[R\.7AZ/+EZSH@)7,B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X
M;6QR<&,N<&AP.C$S.`HC+"!F=7IZ>0IM<V=I9"`B4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B
MS>`@Y^#OZ/+BX.WE\NX@[>4@X>7XY2#N\N/NXN[PY>WN.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U>GIY"FUS9VED(")2
M97%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@
M(LW@(.?@[^CRXN#MY?+N(.WE(.'E^.4@[O+C[N+N\.7M[CH@(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(LWE[N'U[N3H[.C_("=P;W)T)R#MY2#E(.?@Y.#DY>T@XOKB
M(%9&4R#J[NWTZ./S\.#VZ/_RX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CLZ/\@
M)W!O<G0G(.WE(.4@Y^#DX.3E[2#B^N(@5D93(.KN[?3HX_/PX/;H__+@+B(*
M"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BS>7NX?7NY.CLZ/\@)W!O<G0G
M(.WE(.4@Y^#DX.3E[2#B^N(@5D93(.KN[?3HX_/PX/;H__+@+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q
M=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R
M9"(*;7-G<W1R("+/X/#NZ^`B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*
M;7-G<W1R("+/[O+B^O#DY?+E(._@\.[KX/+@(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP
M:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0X"B,L(&9U>GIY"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R("+*[NWTZ./S\.#VZ/\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO
M;G,B"FUS9W-T<B`B1$A434P@4FEC:"!497AT(/#EY.#J\N[P(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3<*(RP@9G5Z
M>GD*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("),:6=H="!";'5E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S-`IM
M<V=I9"`B4F]L92(*;7-G<W1R("+0[NO_(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O
M=&%T92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F
M=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`BT.[K_R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B
M4G5N(@IM<V=S='(@(E-U;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I
M86X@1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"B,L(&9U
M>GIY"FUS9VED(")2=V%N9&$B"FUS9W-T<B`BU^7RY>WE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PHC+"!F=7IZ>0IM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(L/PY?CJX"#O\.@@
M4TU)344@ZO#H[_+H\.#MY?+N(.W@(._H\>SN+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z.#$*(RP@9G5Z>GD*;7-G:60@(E-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`BP_#E^.K@
M(._PZ"#HY.7M\NCTZ.K@]NC_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4P-`HC+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M("+/Z/'L[B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,
M(%-H96QL(@IM<V=S='(@(E-13"!3:&5L;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E
M(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,34S"B,L(&9U>GIY"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-1
M3"!3:&5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*
M;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M
M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A
M;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I
M;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@
M86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS
M9VED(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR
M,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T
M<B`BSN_PY?'MZ"`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*
M(RP@9G5Z>GD*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("+.[_;HZ"(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDS"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@
M<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@
M5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PHC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(LCGX>7PZ"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*
M(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`BR.?AY?#E
M\N4@\?KPXOKP(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*
M;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R("+(Y^'E\.7R
MY2#C\//OX"#GX"#D[N'@XO_MY2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("+(
MY^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#MX"#C\//OX"(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R
M(@IM<V=S='(@(LCGX>7PY?+E(/'Z\.+Z\"(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*
M;7-G<W1R("+(Y^'E\.@@[^[R\.7AZ/+EZR#GX"#D[N'@XO_MY2(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z
M>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BR.?AY?#H(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L
M96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(LCGX>7PY?+E(/3N
M\.S@\B#GX"#$X/+@\N`Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R("+(Y^'E\.7RY2#M[N(@[_#H\N7FX/+EZR#MX"#C\//O
MX"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-S@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(LCGX>7P
MY?+E(.WNXB#O\.CRY>;@\N7K(.W@(./P\^_@(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H
M87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C
M86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@
M87)E82XB"FUS9W-T<B`B(@HBR.?AY?#E\N4@[>7NX?7NY.CLZ/+E(,+H(/'H
M[.+NZ^@N(-'KY>0@\N[BX"#CZ"#J[N_H\.#I\N4@[O(@\N7J\?+NXN[R[B#O
M[NOE+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+(Y^'E\.7RY2#$
MX/+@(/#@Y^3EZ^CRY>LZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(LCG
MX>7PY?+E(/3N\.S@\B#GX"#$X/+@\N`Z(@H*(SH@=&5M<&QA=&5S+W!R969S
M+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N
M=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+W1I;64N:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R("+(Y^'E\.7RY2#$X/+@(/#@
MY^3EZ^CRY>LZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(LCGX>7PY?+E
M(/3N\.S@\B#GX"#7X/'@.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R("+(Y^'E\.7RY2#DXN4@\?KB[^#DX/GH(._NZ^7RX#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO
M<B!S8VAE;64N(@IM<V=S='(@(LCGX>7PY?+E(.+@^.#RX"#Q]>7LX"#GX"#V
MXN7R[N+E\N4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I
M9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R("+(
MY^'E\.7RY2#O\.7D[^[WZ/+@[>C_\B#N\B#"X/$@Y>?HZCHB"@HC.B!T96UP
M;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B
M;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+7
MZ^7M[N+E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B
MP.3LZ.WH\?+PZ/#@[>4@[>`@[_#@XN#RX"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO
M;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#4*
M(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(L_PX.+@(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-`HC+"!F=7IZ>0IM<V=I9"`B
M4V5T(@IM<V=S='(@(LCGX>7PZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@
M(LCGX>7PY?+E(._PY>3O[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A
M<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI
M;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*
M(L?@Y.#I\N4@PN#XY?+N(.W@]^#K[>X@[_#HZ^[FY>WHY2P@\?7E[.`@Y^`@
M]N+E\N[BY2P@[N_PY?'M_^+@[>4@[>`@(@HB\?+PX.WH]N#RX"#H(.3P\^/H
M(.[O]NCH(.?@(.3H\>_KY?\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R("+*\.#R
MZNX@\.7G_NSE.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G
M:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI
M;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("+/[NK@Y^+@[>4B"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I
M9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W
M;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#$S"B,L(&9U>GIY"FUS9VED(")3:&]W('!I8VME<B(*
M;7-G<W1R("+(Y^'H\.#MY2#MX"#VXO_R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`BS^[J
MX.?BX.WE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3$*;7-G:60@(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H
M;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC
M:6YI='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-#@P"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X
M-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M:65R<F$@3&5O;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B
M4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDS,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED
M(")3:7IE(@IM<V=S='(@(M#@Y^SE\"(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA
M;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(L_NZN#GXN#M
MY2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U
M"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N
M;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED
M(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L
M(&9U>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+!Z.?MY?$@
MX.3PY?$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G
M:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(L+ZXN7FY.#MY2#MX"#Q[^7VZ.#K[>@@\>CLXN[K
MZ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@HC
M+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(LCGX>7PY?+E
M(.KNZ^[MZ#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<S(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM
M<V=S='(@(B5S(-'RX.WDX/#R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8R"FUS9VED(")3=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0
M<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*(RP@9G5Z>GD*;7-G:60@(E-T
M;W)A9V4@9F]R;6%T(@IM<V=S='(@(LCM].[P[.#VZ/\@Y^`@PN#Q(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*
M;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(L'HY^WE\2#@Y/#E\2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B
M4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@HC+"!F=7IZ>0IM<V=I
M9"`B4W4B"FUS9W-T<B`B4W5N(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP
M.C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BT>OS^.#RY>O_\B`E<R#MY2#E
M(.W@[.7PY>TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+(
MY^'E\.@B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B
M"FUS9W-T<B`BR.?O\.#RZ"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U
M<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R"B,L
M(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`BR.?O\.#RZ"(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I
M9"`B4W5C8V5S<R(*;7-G<W1R("+3\>_E]2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S='(@(M/Q[^7X[>X@
MY.[AX.+E[2`G)7,G(.KZ["#QZ/'RY>S@\N`N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TN(@IM<V=S='(@(M/Q[^7X[>X@[_#E[.#U[>#R("<E<R<@[O(@\>CQ\N7L
MX/+@+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S
M<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("+3\>_E^.WN(.CG\O#H
M\B`G)7,G+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BT_'OY?CM[B#O\.7LX/7MX/(@)R5S
M)R#N\B#QZ/'RY>S@\N`N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU
M,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN
M(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("+3\>_E^.WN
M(.'E^.4@[N'M[N+E[2`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B
MT_'OY?CM[B#AY?CE(.[A[>[BY>T@)R5S)RXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"B,L
M(&9U>GIY"FUS9VED(")3=61A;B(*;7-G<W1R(")3=6XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U
M>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(LKPX/+J[B#PY>?^[.4Z(@H*
M(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*(RP@9G5Z
M>GD*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4W5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@
M(E-U;FYY(@IM<V=S='(@(E-U;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M4W5N(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3
M=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(E-U
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@
M(E-U<'!O<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM
M<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`BX>7G(.CLY2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(N'EYR#H[.4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED
M(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G
M:60@(E-W:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y
M;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G
M:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM
M<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B].#IZR(*"B,Z(&9R86UE=V]R:R]5
M22]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS9VED(")486)L92(*;7-G
M<W1R("+$Z_KF[>[Q\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*
M;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL
M(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*
M;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM
M<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU
M"B,L(&9U>GIY"FUS9VED(")487)G970Z(@IM<V=S='(@(LCG[^[KY^+@[>4Z
M.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`BQ^#DX/?H
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G
M:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")4
M96UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M
M<&QA=&4N<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@[>`@[^[R\.7AZ/+EZ^CR
MY2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S,S-@HC+"!F=7IZ>0IM<V=I9"`B5&5X="(*;7-G
M<W1R("+1X.SN(/+EZO'R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(M'@[.X@\N7J\?(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T
M"B,L(&9U>GIY"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(M'@[.X@\N7J
M\?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I
M("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4
M:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C`*
M;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@IM<V=I
M9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED
M(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S
M<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I
M8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO
M<V5D+B!%>&ET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP
M.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@
M8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@
M>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*
M(F1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(B(*(M+EY^@@Y.#M[>@@Y^`@ZN[M\N#J\B#A__7@(//Q
M[^7X[>X@Y.[AX.+E[>@@ZOKL(,+@^.#RX"#O\.[C\.#LX"X@RNOHZNWE\N4@
M[^XM(@HBY.[K\R#GX"#DX"#BZ.3H\N4Z(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'
M4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S
M:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HBS_#HZO#E[^7MZ/_R(%!'4"#O
M[N3OZ/$@Y2#MY>[A]>[DZ.P@Y^`@Y.`@\>4@[_#NXN7PZ"#O[N3OZ/'@[>[R
M[B#OZ/'L[BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N
M;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM
M<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q
M,PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BRO#H[_+H\.#MY?+N(.CG
MZ/'JXN`@ZO#H[_+H\.#MX"!W96(@XO#ZY^K@+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C
M86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"B,L(&9U>GIY"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B#O
M\.CJ\.7OY>WH__(@].#IZR#MY2#Q^N3Z\.;@^.4@Y.#M[>@N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"B+,Y?'R[N_NZ^[FY>WHY?+N(.W@($=N=5!'(/3@Z>O@(/+P_^'BX"#D
MX"#A^N3E(.3@Y.7M;R#MX"!#<GEP=%]P9W`Z.B!C;&%S(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB
M97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BTN#GZ"#Q
M\N[I[>[Q\B#R\/_AXN`@Y.`@Y2#WZ/'K[BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*(RP@9G5Z>GD*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(LSNY//K^O(@3W!E;E-33"#E(.WE
M[N'U[N3H["#GX"!#<GEP=%]S;6EM93HZ(&-L87-S+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B
M;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*(L_P[N/P
MX.S@\N`L(.KN__+N(/'K\^;H(.?@(._NZN#GXN#MY2#MX"#R[N?H(/+H[R#D
MX.WMZ"`H)7,I(.WE(.'E^.4@[O+J\.CRX"`B"B+B(/'H\?+E[.#RX"(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O
M<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B2&]R
M9&4@4$\@].#IZR#GX"#K[NK@Z^CGX/;H_R`E<R#MY2#Q^OGE\?+B\^+@.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE
M('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`BS?_LX"#DXN[IZN@L(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CM
MZ/_RX"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS
M-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+B(*;7-G<W1R("+-_^S@(.3B[NGJZ"P@ZN[H\NX@Y.`@
MX?KDX/(@[^[JX.?@[>@@XB#KZ.WH__+@+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N(@IM<V=S='(@(B(*(LCLX"#RXOKPY.4@[.WNX^X@\>CL
MXN[KZ"#B(/+NXN`@[^[KY2X@POKBY>OH(/'RY2`E<R#QZ.SB[NO@.R#R\/_A
MXN`@Y.`@(@HBXOKBY>3E\N4@[^XM[.#KZNX@[O(@)7,N(@H*(SH@<VEG;G5P
M+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O
M('1H92!S>7-T96TZ("5S(@IM<V=S='(@(L/PY?CJX"#O\.@@Y.[AX.+_[>4@
M[>`@)R5S)R#J^NP@\>CQ\N7LX/+@+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R("+#\.7XZN`@[_#H(._PY>S@]>+@[>7R[B#MX"`G
M)7,G(.[R(/'H\?+E[.#RX"XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(L/P
MY?CJX"#O\.@@[_#E[.#UXN#MY?+N(.W@("<E<R<@[O(@\>CQ\N7LX/+@+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S
M(@IM<V=S='(@(L/PY?CJX"#O\.@@[N_PY?'M_^+@[>4@[>`@)R5S)SH@)7,B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@Z>O@.B`E<R#MY2#AY?CE(.CG[_#@
M\N7M+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"B+([.#XY2#O\.[AZ^7L(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX"X@
M)7,@Y2#O[BWC[NO_["#N\B#LX.KQZ.S@Z^WN("(*(N3N[_/Q\NCLZ/\@\.#G
M[.7P("@E9"#AX.GRX"DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?O
M\.#YX.WE\NX@[>`@].#IZ^`N("5S(.'E^.4@\>#L[B#N\O?@\?+H(.CG[_#@
M\N7M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(L/PY?CJX"#O\.@@
M[_#NXN7PZN#RX"#MX"#R[N+@(._H\>SN+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`BP_#E
M^.K@(._PZ"#H[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`BP_#E^.K@(._PZ"#H[._N\/+H\.#MY2#MX"#HY^'PX.WH
M\N4@Y.#M[>@@Y^`@ZN#KY>WDX/`N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C
M;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB
M<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E
M<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CL[^[P\B#M
MX"#DX.WMZ"#GX"#J[NWRX.KRZ"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,@HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#H[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("+2[N+@(.WE(.4@XN#KZ.3E[2!R
M87(@X/#UZ.(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HU,@IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V
M86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`BTN[BX"#MY2#E(.+@Z^CDY>T@>FEP
M(/3@Z>LN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0HC+"!F
M=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(M+NXN`@[>4@Y2#BX.OHY.7M(')A<B#@
M\/7HXBXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD
M:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z
M+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP
M;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*
M(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U
M-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS
M9W-T<B`BTN[BX"#O[NOE(.4@[>7NX?7NY.CL[BXB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(M+NXN`@[^[KY2#L[N;E(.3@
M(/'ZY/KPYN`@\>#L[B#VY>OH(/?H\>O@+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(M+NXN`@[^[K
MY2#L[N;E(.3@(/'ZY/KPYN`@\>#L[B#WZ/'KX"#H(.3B[N7R[O?HY2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"B,L(&9U>GIY"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R("+2[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@(/'@[.X@[>[LY?#@
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(M+NXN`@[^[KY2#R\/_AXN`@Y.`@
MY2#GX._E\N#_(.CKZ"#H[?+E\.+@ZR#PX.?DY>OE[2#Q[^CQ^NH@[_#N[.7M
MZ^CBZ"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.0HC+"!F=7IZ
M>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*
M;7-G<W1R("+2X.?H(/'R[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@
M9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE
M>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES
M(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(M+@
MY^@@].[P[.`@XN7WY2#AY?CE(.[A\.#A[O+E[>`N(@H*(SH@=&5M<&QA=&5S
M+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I
M<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T
M:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H
M(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*
M;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G
M<W1R("+2[N+@(/?H\>ON(/+P_^'BX"#DX"#E(._N[>4@Y>3H[>CVX"XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G
M:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+B(*;7-G<W1R("+2[N?H(/'Z\.+Z\"#MY2#L[N;E(.3@(.3EZN[L
M[_#E\>CPX"!Z:7`@Z"!G>FEP(/3@Z>ONXN4N(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M
M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`BTN#GZ"#Q\N[I[>[Q\B#R
M\/_AXN`@Y.`@Y2#WZ/'K[BXB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N
M9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`BQ.OZYNWN\?(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE(%1R
M86-K:6YG(@IM<V=S='(@(L_P[O'KY>3_XN#MY2#MY2#B\.7LY2(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B
M5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BQ.OZYNWN\?(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4
M:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB
M=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,3$*(RP@9G5Z>GD*;7-G:60@(E1O9&%Y(@IM<V=S
M='(@(B`HY.WE\2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0HC+"!F=7IZ>0IM<V=I9"`B5&]G;R(*;7-G
M<W1R("+(Y_7NY"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM
M<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R("+/\.7GY>WRX/;HZ"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@
M9G5Z>GD*;7-G:60@(E1U<FME>2(*;7-G<W1R(")'<F5Y(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@
M0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I
M9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N
M(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC
M+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC
M+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R("+/[N3WY?#RX.WH(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S@X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E
M<RXB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B
M^O`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@7"(E<UPB+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G
M)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS9VED(")5;F%B
M;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R("+-Y>+ZY^SN
MYNWN\?(@Y^`@XO#ZY^K@(/$@4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(LWEXOKG[.[F[>[Q\B#GX"#B
M\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("+-Y>+ZY^SNYNWN\?(@Y^`@XO#ZY^K@
M(/$@4U%,(/'Z\.+Z\"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R
M96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@
M[^K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T
M(._@[^K@+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V-0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92XB"FUS9W-T<B`BS>7B^N?L[N;M[O'R(.?@(.+P^N?JX"#Q(%-13"#Q^O#B
M^O`N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z
M-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CPX.T@
MX/#UZ.(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R
M[B#MX"!V9G-R;V]T(._@[^K@+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7M
MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S4R"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7R
MY>WE\NX@[>`@=F9S<F]O="#OX._JX"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7M
MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(L/PY?CJX"#O\.@@Z.?R\.CBX.WE
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@
M[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`BP_#E^.K@(._P
MZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(L/PY?CJ
MX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-#`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@
M(L/PY?CJX"#O\.@@Z.?R\.CBX.WE("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("+#\.7X
MZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W,0HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S
M='(@(LWEXOKG[.[F[>[Q\B#GX"#B\/KGZN`@\2!344P@\?KPXOKP+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV
M-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BP_#E^.K@(._PZ"#N
M\N+@\/_MY?+N(.W@(.KN[._PY?'H\.#M(.#P]>CB+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G
M<W1R("+#\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CPX.T@X/#U
MZ.(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT
M-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("+#\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CPX.T@
MX/#UZ.(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@S-0IM<V=I9"`B
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`BP_#E^.K@(._PZ"#HY_+P
MZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C8Y"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN(@IM<V=S='(@(L/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O
M="#OX._JX"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E
M<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(RP@
M9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`BP_#E^.K@(._PZ"#WY?+E[>7R[B#MX"!V9G-R;V]T(._@[^K@
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+B(*;7-G<W1R("+#\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F
M<W)O;W0@[^#OZN`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S
M+B(*;7-G<W1R("+#\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(/?E\N7MY?+N(.W@('9F<W)O;W0@[^#OZN`N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS
M9W-T<B`BP_#E^.K@(._PZ"#HY_+PZ.+@[>4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`BP_#E^.K@(._PZ"#O\.7B[N3@(.W@(/+NY^@@5V]R9"#D[NKS[.7M\B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,34R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+#
M\.7XZN`@[_#H(.CG\O#HXN#MY2`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@
M97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R
M("+/[N3WY?#RX.WH(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM
M<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*(RP@9G5Z>GD*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM
M<V=S='(@(LWEXN#KZ.3E[2#N\N/NXN[P(.[R(/'Z\.+Z\.`B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0Q"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W.`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*(RP@9G5Z>GD*;7-G:60@
M(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R
M("+-Y>+@Z^CDY>T@[O+C[N+N\"#N\B#Q^O#B^O#@(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*(RP@9G5Z>GD*
M;7-G:60@(E5N9FEL960B"FUS9W-T<B`B[_#NXN#KY>WN(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@2VEN
M9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@
M4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`BS>7J[O#EZO+MX"#O
MX/#NZ^`@Z.OH(._N\O#EX>CRY>OQZNX@Z.SE(2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.38*(RP@9G5Z>GD*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`BX>7G(.CLY2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@HC+"!F=7IZ
M>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`BPNSZZNWH(._NY/#@XNWH
M\N7K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#8@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,C8*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G:60@(E5N<W5P<&]R
M=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(L[O\.7Q[>@B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R("+.[_#E\>WH("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B57!D871E('5S97(B"FUS9W-T<B`BSN_PY?'MZ"`E<R(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`BSN_PY?'MY>UA("<E
M<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A
M<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC
M+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("+/[O+PY>'H\N7KZ"(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3LZ.WH\?+PZ/#@[>4@
M[>`@[^[R\.7AZ/+EZ^CRY2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,C4Q"B,L(&9U>GIY"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T
M<B`BSN_VZ.@B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("+`Y.SH[>CQ\O#H\.#MY2#MX"#O
M[O+PY>'H\N7KZ/+E(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V.0IM<V=I
M9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP
M.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+([.4B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`BR.SE.B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T
M<B`BR.SE.B`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("+/[O+PY>'H
M\N7KZ"#B(/'H\?+E[.#RX#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@
M(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(E9A8V%T:6]N
M(@IM<V=S='(@(L+@ZN#M]NC_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G
M:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V
M97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(E9A
M;'5E<R(*;7-G<W1R("+-_^S@(/'R[NGM[O'RZ"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E
M(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`BP_#E^.K@
M(._PZ"#O\.[BY?#JX/+@("T@\N[BX"#OZ/'L[B#L[N;E(.3@(.4@X>CK[B#O
M[N3O\.#BY>WN+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`P"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(L_PX.+@
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L
M(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y
M($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@HC+"!F=7IZ>0IM<V=I
M9"`B5FEE="!.86TB"FUS9W-T<B`BR.SE(.W@(/3@Z>LB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X
M=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")6
M:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I
M<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED(")6:7-I8FEL:71Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*
M;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*
M;7-G:60@(E=)3B!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN
M<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#,*;7-G:60@(E=A<FYI
M;F<B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y,@IM
M<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")796(@4VET92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BT>7D[.CW[>XB"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`HC+"!F=7IZ>0IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R("+$[N'PY2#D[OCKZ"P@)7,B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M("+$[N'PY2#$[OCKZ"#B("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL
M92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF
M;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(L3NX?#E(.3N^.OH
M+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L
M87D@869T97(@;&]G:6X_(@IM<V=S='(@(LCGX>7PY?+E(._PZ.ONYN7MZ.7R
M[BP@ZN[E\NX@)7,@Y.`@[^[JX.;E(/'KY>0@XO7NY"XB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA
M(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G
M:60@(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F
M;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G
M:60@(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*
M;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B
M5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U
M;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7
M:6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@
M:VYO=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*
M;7-G:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#(*(RP@9G5Z>GD*;7-G:60@(E=I;F0Z("(*;7-G<W1R
M("+"[>CLX.WHY3H@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS
M9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM
M<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(L'HY^WE\2#@Y/#E\2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BP>CG[>7Q(/+EZ^7T[NTB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?
M0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU
M;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD
M("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I
M96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T
M,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS
M=')A:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,@IM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-`IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV.#(*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("+#PR(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U-0HC
M+"!F=7IZ>0IM<V=I9"`B65E962(*;7-G<W1R("+#PR(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3`X"FUS9VED(")986AO
M;R$@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+#[N3H
M^.WN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS
M9W-T<B`B1W)E96XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`BQ.`B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B
M665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$58
M5"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T
M;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL
M;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA
M;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("+-
MY2#B^N+EY.[U\N4@XN#KZ.3E[2!E;6%I;"#@Y/#E\2XB"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"B,L(&9U
M>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@
M(L+@^.CRY2#J[NWTZ./S\.#VZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`BS>4@XOKB
MY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3PY?$N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U
M(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P
M"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+P
MY>'H\N7K(.?@(.CG\O#HXN#MY2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N(@IM<V=S='(@(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+P
MY>'H\N7K(.?@(.CG\O#HXN#MY2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M(@IM<V=S='(@(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG
M\O#HXN#MY2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#D
MY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!U<&1A=&4N(@IM<V=S='(@(M+P_^'BX"#DX"#GX.3@Y.7RY2#O[O+PY>'H
M\N7K(.?@(.[O\.7Q[?_BX.WE+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C$S.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("+2\/_A
MXN`@Y.`@Y^#DX.3E\N4@[^[R\.7AZ/+EZR#GX"#HY_+PZ.+@[>4N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92XB"FUS9W-T<B`BTO#_X>+@(.3@(.?@Y.#DY?+E(._N\O#EX>CRY>L@
MY^`@Z.?R\.CBX.WE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*
M;7-G<W1R("+"X/CH_R!%;6%I;"#@Y/#E\3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E
M<W,Z(@IM<V=S='(@(L+@^.C_($5M86EL(.#D\.7Q.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("+([?3N\.S@
M]NC_(.?@(,+@\2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`BPN#XY?+N(.CLY3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)
M9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R
M(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N
M=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@HBPN#XZ/_R(.CDY>WRZ/3H
MZN#VZ.[MY>T@Y/#@Z>+E\"#MY2#O[N3D^O#FX"#D[N'@XO_MY2#MX"#O[O+P
MY>'H\N7KZ"P@Z.OH("(*(O+@Y^@@XOKG[.[F[>[Q\B#E(.?@X?#@[>7MX"XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@
M(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P
M;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB
MPN#XZ/_R(.CDY>WRZ/3HZN#VZ.[MY>T@Y/#@Z>+E\"#MY2#O[N3D^O#FX"#Q
M[^CQ^NH@[>`@[^[R\.7AZ/+EZ^CRY2P@Z.OH("(*(O+@Y^@@XOKG[.[F[>[Q
M\B#E(.?@X?#@[>7MX"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O
M;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HY-@HC+"!F=7IZ>0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA
M<R!B965N(&-H86YG960N(@IM<V=S='(@(L+@^.CRY2#J[NWTZ./S\.#VZ.[M
M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I
M='DZ(@IM<V=S='(@(LCDY>WRZ/?M[O'R(._N(._NY/#@Y^'H\.#MY2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@9G5L;"!N86UE.B(*;7-G<W1R("+"X/CE\NX@Z.SE.B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@
M;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(L+@^.CRY2#J[NWTZ./S\.#V
MZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE
M=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(L+@^.CRY2#J[NWTZ./S\.#V
MZ.[M[>@@[N_VZ.@@X?_UX"#NX>WNXN7MZ"XB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D+B(*;7-G<W1R("+"X/CH\N4@ZN[M].CC\_#@]NCN[>WH
M(.[O]NCH(.'_]>`@[N'M[N+E[>@N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I
M9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BPN#XZ/+E(/'Z\.+Z
M\.@Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM
M8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V
M"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED
M92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE
M;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S
M(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB
M"FUS9W-T<B`B6^OH[>C_("5S(.[R("5S72(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`BP.3L
MZ.WH\?+PZ/#@[>4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"B,L(&9U>GIY"FUS9VED
M(")?1&%T851R964B"FUS9W-T<B`BQ.#M[>@B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*
M;7-G:60@(E]$96QE=&4@4F]W(@IM<V=S='(@(LCG\O#HZ2(*"B,Z(&QI8B]A
M<&DN<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("+#
M\//OZ"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*
M(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(L_N[.[Y(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S
M"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS
M9VED(")?3&]G(&EN(@IM<V=S='(@(L+U[N0B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U
M="(*;7-G<W1R("+(Y_7NY"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK
M+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ-C0*(RP@9G5Z>GD*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(L[O
M]NCH(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"B,L(&9U>GIY"FUS9VED(")?4&5R
M;6ES<VEO;G,B"FUS9W-T<B`BS_#@XN`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO
M=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ,C4*;7-G
M:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0HC
M+"!F=7IZ>0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(L_N\O#EX>CRY>OH(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G
M:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+`Y/#E\>7M(.'EZ^7F[>CJ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R("+*X.OE[>3@\"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@
M(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B
M8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R
M(@IM<V=S='(@(LKN[?3HX_/PX/;H_R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL
M92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X
M,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(NWE
M(.'E^.4@[>#LY?#E[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*
M;7-G<W1R("+TX.GK(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4P"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D
M:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(L_N
MY/?E\/+@[>@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I
M;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PHC+"!F=7IZ>0IM<V=I
M9"`B;&EN97-=(@IM<V=S='(@(L?@X^O@XNC_(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF
M;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI
M;F<@25-/+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,S(*(RP@9G5Z>GD*;7-G:60@(FYA;64B"FUS9W-T<B`BR.SE(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I
M9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M("+/\.#BX"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED
M(")R:7-I;F<B"FUS9W-T<B`BPNWH[.#MZ.4B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL
M86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDY
M"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED
M(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(G-T96%D>2(*;7-G<W1R("+7Y?+E[>4B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I
M=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS
M,#4*(RP@9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("+"\?_J[B#K
M[N/BX.WE(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@
M='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D
M:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM
M<V=I9"`B=6YI9FEE9"(*;7-G<W1R("+O\.[BX.OE[>XB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM<V=S
M='(@(N'EYR#H[.4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0Q"FUS9VED(")W.B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM
M<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&\O9G)?1E(N<&\`````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-S0U-S8S(#$P-3$U
M-#,T,30R(#`Q-S4S-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````C($AO<F1E(#,N,2XQ($9R96YC:"!T<F%N<VQA=&EO;BX*
M(R!#;W!Y<FEG:'0@*$,I(#(P,#$M,C`P,B!4:&4@2&]R9&4@4')O:F5C="X*
M(R!0:65R<F4@3&%C:&%N8V4@/'!L0'!I97)R96QA8VAA;F-E+FYE=#X@970@
M0F5N;VET(%-T+4%N9'+I("AB96Y`8F5N;VET<W0M86YD<F4N;F5T*2P@,C`P
M,RP@,C`P-"X*(R!&<F5D97)I8R!4<G5D96%U(#QF=')U9&5A=4!C86TN;W)G
M/BP@,C`P,2X*(R!4:&EE<G)Y(%1H;VUA<R`\=&AI97)R>4!P;VUP;RYN970^
M+"`R,#`R+"`R,#`U+"`R,#`V+@HC($-O=6YT<GD@=')A;FQA=&EO;G,@9G)O
M;2!-:6=U96P@5')E;6)L87D@/&MB86)E;"YM:6=U96Q`<'1A9F8N8V$^+"`R
M,#`T+@HC($)E;F]I="!3="U!;F1RZ2`\8F5N0&)E;F]I='-T+6%N9')E+FYE
M=#XL(#(P,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ(&9R7T927&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#,M
M,#8@,3(Z-#<K,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,RTS
M,2`R,CHS,"LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z(%1H:65R<GD@5&AO
M;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#Y<;B(*(DQA;F=U86=E+51E86TZ($9R
M96YC:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ
M(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<
M;B(*(E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[
M7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8V"B,L('!H<"UF
M;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H:6P@>2!A
M("5S(&IO=7)S*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,X
M,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B("A4;W5C:&4@9"=A8V/H<R!R87!I9&4@)7,I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN
M("5S(&1A>7,I(@IM<V=S='(@(B`H9&%N<R`E<R!J;W5R<RDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<P"FUS9VED("(@*'1O9&%Y*2(*;7-G
M<W1R("(@*&%U:F]U<F0G:'5I*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-S(*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H9&5M86EN
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-C@*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@*&AI97(I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G
M:60@(B!A="`B"FUS9W-T<B`B(.`@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`BJZ`E<Z"[(&XG97-T('!A<R!U;B!D
M;W-S:65R(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*
M;7-G<W1R("*KH"5SH+L@;B=E<W0@<&%S('5N(&-H;VEX('9A;&ED92XB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`BJZ`E<Z"[(&XG97-T('!A<R!C
M;VYF:6=U<ND@9&%N<R!L92!R96=I<W1R92!D92!(;W)D92XB"@HC.B!F<F%M
M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("),)VEN
M=&5R<'+I=&5U<B!D)V%R8G)E(*N@)7.@NR!N)V$@<&%S(.ETZ2!T<F]U=NDN
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G
M<W1R("*KH"5SH+L@82#I=.D@86IO=73I(&%U('-Y<W3H;64@9&5S(&=R;W5P
M97,N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I
M;VYS('-Y<W1E;2XB"FUS9W-T<B`BJZ`E<Z"[(&$@Z73I(&%J;W5TZ2!A=2!S
M>7-TZ&UE(&1E<R!P97)M:7-S:6]N<RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
MJZ`E<Z"[(&XG82!P87,@Z73I(&-RZ>F@.B`E<RXB"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9J!-
M;R!U=&EL:7/I<R!S=7(@)2XR9J!-;R!P97)M:7,@*"4N,F:@)24I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@970@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@
M=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(E9"!J;W5R
M<R!A=F%N="!L)V5X<&ER871I;VX@9&4@=F]T<F4@;6]T(&1E('!A<W-E+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B5D+7!RZ79I
M<VEO;B!D=2!J;W5R(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S
M("T@3F]T:6-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS
M9W-T<B`B16UP<F5I;G1E(%!'4"!D92`E<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T,"!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS
M9W-T<B`B)7.@2V\B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R!O<.ER871I;VYS(&1E(&UA
M:6YT96YA;F-E("9N9&%S:#L@0V]N9FER;6%T:6]N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(D-O;F9I9W5R
M871I;VX@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z
M,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B
M26YS8W)I<'1I;VX@9&4@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M
M96YT(@IM<V=S='(@(D-O;F1I=&EO;G,@9"=U=&EL:7-A=&EO;B!D92`E<R(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#,R(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#DT"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-C@R(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!E
M>&ES=&4@9.EJX"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V-B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,U,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R
M("(@)7.@X"`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A
M;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&5S
M="!P<NIT(.`@969F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA
M;F-E(&-O8VCI97,@8VDM9&5S<V]U<RX@(@HB4^EL96-T:6]N;F5Z(&QA(&]U
M(&QE<R!O<.ER871I;VXH<RD@<75E('9O=7,@=F]U;&5Z(&5F9F5C='5E<B!C
M971T92!F;VES+6-I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T
M<B`B)7,@97-T(&]B;&EG871O:7)E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R
M("(E<R!M:6YU=&5S(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C$R.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(B5S(&YO;B!T<F]U=NDB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O
M("5S(&]F("5S(@IM<V=S='(@(B5SH.`@)7,@9&4@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R(")#87)N970@9"=A9')E<W-E<R!D
M92`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B06=E;F1A
M(&1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(D)L;V,M
M;F]T97,@9&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@
M(DQI<W1E(&1E('3B8VAE<R!D92`E<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5SH#H@)7,B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"B(E<Z`Z(&PGZ6UE='1E=7(@9&4@8V4@;65S<V%G92!A('!U(.IT<F4@
M9F%L<VEF:>DN($%T=&5N=&EO;B!E;B!S=6EV86YT(&QE<R`B"B)L:65N<R!Q
M=2=I;"!C;VYT:65N="!O=2!E;B!F;W5R;FES<V%N="!D97,@:6YF;W)M871I
M;VYS('!E<G-O;FYE;&QE<R#@("(*(FPGZ6UE='1E=7(N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@96X@
M<F%F86QE("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN
M9R`E<R`E<R(*;7-G<W1R(")R869A;&4@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B=F%R:6%B;&4@9'4@)7,@874@)7,B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#8V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.`IM<V=I
M9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(%/I;&5C=&EO;FYE<B`M+2(*
M"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M
M870B"FUS9W-T<B`B1F]R;6%T(#$R(&AE=7)E<R(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R
M;6%T(#(T(&AE=7)E<R(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!H975R97,B"@HC.B!F<F%M
M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS
M9W-T<B`B/%!RZ6/I9&5N="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V
M"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H
M:7,@8FQO8VLN(@IM<V=S='(@(E5N92!B87-E(&1E(&1O;F[I97,@<')I;F-I
M<&%L92`H8F%C:V5N9"D@97-T(&[I8V5S<V%I<F4@<&]U<B!C92!B;&]C(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S$*;7-G:60@(D$@9F%T
M86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(E5N92!E<G)E=7(@9F%T
M86QE(',G97-T('!R;V1U:71E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")5;F4@8VQE9B!P
M=6)L:7%U92!01U`@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF9G)E<B!U;B!M
M97-S86=E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R
M:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5N92!C;&5F('!U
M8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(';I<FEF:65R(&QA('-I
M9VYA='5R92!D)W5N(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3`Y.0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E5N92!C;&5F
M('!U8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H
M<F%S92!S96-RZ'1E('-O;G0@(@HB;NEC97-S86ER97,@<&]U<B!DZ6-H:69F
M<F5R('5N(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T
M92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E5N92!C;&5F('!U8FQI<75E
M(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-R
MZ'1E('-O;G0@(@HB;NEC97-S86ER97,@<&]U<B!S:6=N97(@=6X@;65S<V%G
M92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-@IM
M<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E5N92!C;&5F('!U8FQI<75E(%,O
M34E-12P@=6YE(&-L968@<')I=NEE(%,O34E-12P@970@=6YE('!H<F%S92!S
M96-RZ'1E('-O;G0@(@HB;NEC97-S86ER97,@<&]U<B!DZ6-H:69F<F5R('5N
M(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)5;F4@8VQE9B!P=6)L:7%U
M92!3+TU)344L('5N92!C;&5F('!R:7;I92!3+TU)344L(&5T('5N92!P:')A
M<V4@<V5C<NAT92!S;VYT("(*(F[I8V5S<V%I<F5S('!O=7(@<VEG;F5R('5N
M(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B56YE(&-L968@<'5B;&EQ
M=64@4R]-24U%(&5S="!NZ6-E<W-A:7)E('!O=7(@8VAI9F9R97(@=6X@;65S
M<V%G92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B3G5A9V5S(&QE(&UA=&EN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*
M;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B4&QU:64@;.EGZ')E(&QE
M(&UA=&EN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B4&QU:64@;&4@;6%T:6XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM
M<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!=F5R<V5S(&QE(&UA=&EN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G
M:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")#:'5T97,@9&4@;F5I9V4@
M;&4@;6%T:6XB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I
M9"`B04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*
M;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G
M<W1R("+`('!R;W!O<R!D92!C970@Z61I=&5U<B(*"B,Z('-E<G9I8V5S+VAE
M;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("+`('!R
M;W!O<RXN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R(")"87,@86)S;VQU
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(DUI;&EE=2!A8G-O;'4B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D%C
M8^AS(')E9G5SZ2!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1E('+I<&5R=&]I<F4@
M5D93("XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS
M9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R
M(")!8V/H<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D92!F:6-H:65R
M(%9&4RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C
M;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")$;VYNZ65S('!E<G-O;FYE;&QE
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N
M="!087-S=V]R9"(*;7-G<W1R(")-;W0@9&4@<&%S<V4@9'4@8V]M<'1E(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B0V]M<'1E(&EN
M86-T:68B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,U"FUS9VED
M(")!8V-O=6YT:6YG(@IM<V=S='(@(D-O;7!T97,B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z
M,3$*;7-G:60@(D%D9"(*;7-G<W1R(")!:F]U=&5R(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R(")!:F]U=&5R('5N('-O=7,M9W)O=7!E(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES
M<VEO;B(*;7-G<W1R(")!:F]U=&5R('5N92!N;W5V96QL92!S;W5S+7!E<FUI
M<W-I;VXB"@HC.B!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B
M061D($AE<F4Z(@IM<V=S='(@(D%J;W5T97(@:6-IH#HB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D
M($YE=R!'<F]U<"(*;7-G<W1R(")!:F]U=&5R('5N(&YO=79E874@9W)O=7!E
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B06IO=71E<B!U;F4@;F]U=F5L;&4@<&5R;6ES<VEO
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E
M<UPB(@IM<V=S='(@(D%J;W5T97(@=6X@9W)O=7!E(&9I;',@X""KH"5SH+LB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<
M(B(*;7-G<W1R(")!:F]U=&5R('5N92!P97)M:7-S:6]N(&9I;&QE(.`@JZ`E
M<Z"[(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U
M<V5R.B(*;7-G<W1R(")!:F]U=&5R('5N(&YO=79E;"!U=&EL:7-A=&5U<J`Z
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U
M-@IM<V=I9"`B061D(&-O;'5M;B(*;7-G<W1R(")!:F]U=&5R('5N92!C;VQO
M;FYE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM
M<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(D%J;W5T97(@9&4@;F]U
M=F5A=7@@;65M8G)E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D%J;W5T97(@=6YE('!A:7)E
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B
M"FUS9W-T<B`B06IO=71E<B!L92!M96YU("5S(.`@;&$@8F%R<F4@9&4@36]Z
M:6QL82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`B06IO
M=71E<B!A=2!C87)N970@9"=A9')E<W-E<Z`Z(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@
M861D<F5S<R!B;V]K(@IM<V=S='(@(D%J;W5T97(@X"!M;VX@8V%R;F5T(&0G
M861R97-S97,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B061D('5S
M97(B"FUS9W-T<B`B06IO=71E<B!U;B!U=&EL:7-A=&5U<B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB
M)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO
M;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*(JN@
M)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92P@;6%I<R!L)V%J;W5T(&0G
M:6YF;W)M871I;VX@<W5P<&SI;65N=&%I<F5S("4B"B)S(&XG97-T('!A<R!P
M;W-S:6)L92XB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I
M;B!N;W<N(@IM<V=S='(@(JN@)7.@NR!A(.ETZ2!A:F]U=.DN(%9O=7,@<&]U
M=F5Z('9O=7,@8V]N;F5C=&5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(DQA(&9O;F-T:6]N(&0G86IO=70@9"=U=&EL:7-A=&5U<G,@
M97-T(&3I<V%C=&EVZ64N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S@*
M;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-S92(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G
M<W1R(")#87)N970@9"=A9')E<W-E<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A
M=&5U<B`M(&%J=7-T97(@;&5S('!E<FUI<W-I;VYS('!O=7(@9"=A=71R97,@
M=71I;&ES871E=7)S(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S(@IM<V=S='(@(E!U8G,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R(")!9F=H86YI<W1A
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B06QGZ7)I
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B
M06QI9VXB"FUS9W-T<B`B06QI9VYE<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS
M9W-T<B`B06QI9VYE;65N=*`Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B5&]U="(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@
M(E1O=7,@;&5S('!A<G1I8VEP86YT<R!A=71H96YT:69IZ7,B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!
M;&P@1W)O=7!S(@IM<V=S='(@(E1O=7,@;&5S(&=R;W5P97,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]0
M97)M<R]D871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*
M;7-G<W1R(")4;W5T97,@;&5S('!E<FUI<W-I;VYS(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M06QL(&9O=7(@<VED97,B"FUS9W-T<B`B3&5S('%U871R92!C]'3I<R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C@*;7-G:60@(D%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")097)M971T<F4@9&5S(&%D<F5S
M<V5S(&1E(&-O=7)R:65L(&UU;'1I<&QE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(D%U=&]R:7-E<B!L82!M:7-E(&5N('!L86-E
M(&1E(&QI<W1E<R!N=6WI<F]TZ65SH#\B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S
M(@IM<V=S='(@(D5X:7-T92!DZ6K@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B
M3F]M(&0G=71I;&ES871E=7(@24U34"!A;'1E<FYA=&EF(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4Q,0IM<V=I9"`B06QT97)N871E($E-4U`@4&%S
M<W=O<F0B"FUS9W-T<B`B36]T(&1E('!A<W-E($E-4U`@86QT97)N871I9B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T
M92!)35-0(%5S97)N86UE(@IM<V=S='(@(DYO;2!D)W5T:6QI<V%T975R($E-
M4U`@86QT97)N871I9B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!
M9')E<W-E(&1E(&-O=7)R:65L(&%L=&5R;F%T:79E(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS
M9W-T<B`B075T<F5S(&UO9.AL97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R
M;F%T92!T97AT.B(*;7-G<W1R(")497AT92!A;'1E<FYA=&EFH#HB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R(")386UO82!!
M;>ER:6-A:6XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(E5N92!V86QE
M=7(@:6QLZ6=A;&4@82#I=.D@<W#I8VEF:>EE+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@
M:&%S(&]C8W5R960N(@IM<V=S='(@(E5N92!E<G)E=7(@:6YC;VYN=64@<R=E
M<W0@<')O9'5I=&4N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G
M<W1R(")!;F1O<G)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S
M='(@(D%N9V]L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(E!R;WAY(&%N
M;VYY;64B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I
M9"`B06YS=V5R(@IM<V=S='(@(E+I<&]N<V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;G1A<F-T:6-A(@IM<V=S='(@(D%N=&%R8W1I<75E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I9W5A
M+65T+4)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN
M+W!H<'-H96QL+G!H<#HS-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN
M<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G
M:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P<&QI8V%T:6]N(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T
M(@IM<V=S='(@(DQI<W1E(&0G87!P;&EC871I;VYS(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN
M(@IM<V=S='(@(DPG87!P;&EC871I;VX@97-T('!RZG1E(@H*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD
M(%-H87)E<R(*;7-G<W1R(")!<'!L:7%U97(@875X('!A<G1A9V5S(&9I;',B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR,0IM<V=I
M9"`B07!P<F]V92(*;7-G<W1R(")!<'!R;W5VZ2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T,`IM<V=I9"`B07!P<F]X:6UA=&4@
M4VEZ92(*;7-G<W1R(")486EL;&4@87!P<F]X:6UA=&EV92(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I
M;"(*;7-G<W1R(")!=G)I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X
M"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07)A8F4@
M*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5&%I;&QE(&1U
M(&9I8VAI97(@87)C:&EV92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<W"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T<B`B3F]M(&1E(&PG87)C
M:&EV92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS
M9W-T<B`B(@HBRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P<FEM
M97(@8V5T=&4@<F5Q=>IT92!D)VEN<V-R:7!T:6]N("!P;W5R("5SH#\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(LIT97,M=F]U
M<R!C97)T86EN(&1E('9O=6QO:7(@969F86-E<B"KH"5SH+L@970@<V5S('-O
M=7,M9W)O=7!E<Z`_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM
M<V=S='(@(D%R9V5N=&EN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B
M"FUS9W-T<B`B07)MZ6YI92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y
M"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R(")!<FWI;FEE
M;B`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM
M<V=I9"`B07)T(@IM<V=S='(@(D%R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R
M=6)A(@IM<V=S='(@(D%R=6)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!<V-E
M;G-I;VX@*,YL92DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R(")!<G0@05-#24DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B4NEG:6]N($%S:64O4&%C:69I<75E(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM
M<V=S='(@(B(*(D1E;6%N9&5R('5N92!C;VYF:7)M871I;VX@879A;G0@9&4@
M;&%N8V5R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-EH#\B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DR"FUS9VED(")!<W-I9VYM96YT
M(&-O;'5M;G,B"FUS9W-T<B`B0V]L;VYN97,@9&5S('3B8VAE<R(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")496YT871I=F4@9"=E9F9A
M8V5M96YT(&0G=6X@9W)O=7!E(&EN97AI<W1A;G0N(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B5&5N=&%T:79E("!D
M)V5F9F%C96UE;G0@9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T86YT92XB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E1E;G1A
M=&EV92!D92!M;V1I9FEC871I;VX@9"=U;F4@<&5R;6ES<VEO;B!I;F5X:7-T
M86YT92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B5&5N=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N('!A<G1A9V4@:6YE
M>&ES=&%N="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I
M9"`B071T<FEB=71E<R(*;7-G<W1R(")0<F]P<FGI=.ES(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S
M="(*;7-G<W1R(")!;_MT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA
M(@IM<V=S='(@(D%U<W1R86QI92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R
M:6$B"FUS9W-T<B`B075T<FEC:&4B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S
MH#H@17AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I92XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<Z`Z(&QE(&)A8VME;F0@;B=A('!A
M<R!L97,@8V%P86-I=.ES(')E<75I<V5S+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER
M960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y
M<G5SH#H@97AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@=')O=7;I92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T
M:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP
M:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G
M<W1R("(B"B)!=71H7V9T<*`Z(&5X=&5N<VEO;B!R97%U:7-E($944"!N;VX@
M=')O=7;I92X@26P@9F%U="!C;VUP:6QE<B!02%`@879E8R`B"B)L)V]P=&EO
M;B`M+65N86)L92UF='`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HV-`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA<*`Z(&5X=&5N<VEO
M;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B
M-:`Z(&5X=&5N<VEO;B!R97%U:7-E(&MR8C4@;F]N('1R;W5VZ64N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB075T:%]L9&%PH#H@;"=A:F]U="!D
M)W5T:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.D@879E8R!!8W1I=F4@
M1&ER96-T;W)Y(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"B)!=71H
M7VQD87"@.B!L92!R971R86ET(&0G=71I;&ES871E=7)S(&XG97-T('!A<R!S
M=7!P;W)TZ2!A=F5C($%C=&EV92`B"B)$:7)E8W1O<GDB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T
M:%]L9&%PH#H@97AT96YS:6]N(')E<75I<V4@3$1!4"!N;VX@=')O=7;I92XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*
M(D%U=&A?;&1A<*`Z(&EM<&]S<VEB;&4@9"=A:F]U=&5R(&PG=71I;&ES871E
M=7(@)7,N($-E8VD@97-T(&QA('+I<&]N<V4@9'4@(@HB<V5R=F5U<J`Z("(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<*`Z(&EM<&]S<VEB;&4@9&4@<W5P<')I
M;65R(&PG=71I;&ES871E=7(@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87"@
M.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D92!L)W5T:6QI<V%T975R("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@
M(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB075T:%]L9&%PH#H@
M;&$@;6]D:69I8V%T:6]N(&1E<R!U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U
M<'!O<G3I92!A=F5C($%C=&EV92`B"B)$:7)E8W1O<GDN(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U
M=&A?;6-A;*`Z(&5X=&5N<VEO;B!R97%U:7-E($U#04P@;F]N('1R;W5VZ64N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71HH#H@97AT96YS:6]N(')E<75I
M<V4@<VUB875T:"!N;VX@=')O=7;I92XB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-
M05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`BR6-H96,@9&4@;"=A=71H96YT
M:69I8V%T:6]N(&%U('-E<G9E=7(@24U!4"XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R("+)8VAE8R!D92!L)V%U=&AE;G1I
M9FEC871I;VXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT
M:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(LEC:&5C(&1E(&PG875T:&5N
M=&EF:6-A=&EO;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S
M+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!
M1$E54R!S97)V97(N(@IM<V=S='(@(DQE('-E<G9E=7(@4D%$2553(&$@<F5J
M973I(&PG875T:&5N=&EF:6-A=&EO;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C@X,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(LEC:&5C(&1E(&PG875T:&5N=&EF:6-A
M=&EO;B!A=2!S97)V975R($944"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N(@IM<V=S='(@(LEC:&5C(&1E(&PG875T:&5N=&EF:6-A
M=&EO;B!A=2!S97)V975R(%--0BXB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B;&4@9FEE;&1S.B(*;7-G<W1R(")#
M:&%M<',@9&ES<&]N:6)L97.@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B
M86EJ86XB"FUS9W-T<B`B07IE<F)A[V1J86XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R(")%>&-U
M<V5S($)/1D@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(D-O
M=6QE=7(@9&4@9F]N9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`B0V]U;&5U<B!D92!F;VYD(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K
M<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G
M<W1R(")-;W0@9&4@<&%S<V4@2V5R8F5R;W,@97)R;V[I+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O
M<R!U<V5R;F%M92XB"FUS9W-T<B`B3F]M(&1E(&-O;FYE>&EO;B!+97)B97)O
M<R!E<G)O;NDN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R
M(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M(")"86AR9>]N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@
M(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)A;'1E("A)4T\M.#@U
M.2TQ,RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@
M(D)A;F=L861E<V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G
M<W1R(")"87)B861E(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L
M('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(E+I<&5R=&]I<F4@9&5S(&=R87!H
M:7%U97,@JZ`E<Z"[(&YO;B!T<F]U=NDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN
M92(*;7-G<W1R("),:6=N92!D92!B87-E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B
M0F5L87)U<R(*;7-G<W1R(")"Z6QA<G5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F5L9VEU;2(*;7-G<W1R(")"96QG:7%U92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"
M96YI;B(*;7-G<W1R(")"Z6YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B0F5R;75D97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T
M86XB"FUS9W-T<B`B0FAO=71A;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(D%N;FEV97)S86ER92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL
M96-T:6]N+G!H<#HS-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E
M<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D)L;V,@JR5S(+L@9&4@;"=A<'!L:6-A=&EO;B"KH"5SH+L@:6YC;VYN=2(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO
M8VL@4V5T=&EN9W,B"FUS9W-T<B`B4'+I9NER96YC97,@9&4@8FQO8R(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@
M5'EP92(*;7-G<W1R(")4>7!E(&1E(&)L;V,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T
M<B`B1W)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M0F]L:79I92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R(")3:6=N971S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M0F]R9&5R(@IM<V=S='(@(D)O<F1U<F4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN
M97-S.B(*;7-G<W1R("+)<&%I<W-E=7(@9&4@;&$@8F]R9'5R9:`Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")";W)D<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FEE
M+4AE<GKI9V]V:6YE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS
M9VED(")";W1H(@IM<V=S='(@(DQE<R!D975X(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0F]T<W=A;F$B"FUS9W-T<B`B0F]T<W=A;F$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O
M='1O;2(*;7-G<W1R(")"87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@
M27-L86YD(@IM<V=S='(@(D)O=79E="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R
M87II;"(*;7-G<W1R(")"<NES:6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(E1E<G)I=&]I
M<F5S(&)R:71A;FYI<75E<R!D92!L)T]CZ6%N($EN9&EE;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(E-U;'1A;F%T
M(&1U($)R=6[I:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S
M='(@(D)U;&=A<FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("),
M:7-T92#@('!U8V5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O
M(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")'97-T:6]N(&1E(&-O
M;G1E;G4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(D1I<W1R:6)U=&EO;B!D97,@<&]I;G1S($Q2
M0R`H3&ES=&4@9&4@<NEV;V-A=&EO;B!D97,@8V5R=&EF:6-A=',I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R
M:>ETZ7,@9&4@;&$@0U]E;&QU;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R("),)VEN:71I86QI<V%T:6]N(&1U(&-A8VAE(&YE(',G
M97-T('!A<R!T97)M:6[I92XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDQ-B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#@U"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0P(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-3<*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D%G
M96YD82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G
M:60@(D-A;&TB"FUS9W-T<B`B0V%L;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M0V%M8F]D:6$B"FUS9W-T<B`B0V%M8F]D9V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#86UE<F]O;B(*;7-G<W1R(")#86UE<F]U;B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B));7!O<W-I8FQE(&1E('+I:6YI=&EA;&ES97(@;&4@
M;6]T(&1E('!A<W-E(&%U=&]M871I<75E;65N="P@8V]N=&%C=&5Z('9O=')E
M("(*(F%D;6EN:7-T<F%T975R('-Y<W3H;64N(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N
M;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!S=7!P<FEM97(@;&4@9FEC:&EE<B"KH"5SH+LN(@H*(SH@861M:6XO<V5S
M<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L
M('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=A9&UI
M;FES=')E<B!D97,@9V5S=&EO;FYA:7)E<R!D92!S97-S:6]N(&5X=&5R;F5S
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S
M='(@(LEC:&5C(&1E(&QA(&-O;FYE>&EO;B!A=2!S97)V975R($E-05"@.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("));7!O<W-I8FQE(&0G;W5V<FER(&QE(&9I8VAI97(@JZ`E<Z"[+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")#86YA9&$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!;FYU;&5R(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A
M;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!;FYU;&5R(&QE(')A<'!O
M<G0@9'4@<')O8FSH;64B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!F
M:6-H:65R(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FQE(&1E('1R;W5V97(@
M=6X@<NEP97)T;VER92!T96UP;W)A:7)E(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E
M960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G<W1R("))
M;7!O<W-I8FQE(&1E('!R;V/I9&5R('-A;G,@;&4@<&%R86WH=')E(*L@=&%R
M9V5T1FEL92"[(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!R
MZ7!E<G1O:7)E(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L
M+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(E-U<'!R97-S:6]N(&EM<&]S
M<VEB;&4L(&EL('D@82`E9"!E;G)E9VES=')E;65N=',@9FEL<RXB"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@
M(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE
M9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D
M+B(*;7-G<W1R("(B"B));7!O<W-I8FQE(&1E('+I;W)D;VYN97(L(&QE(&YO
M;6)R92!D)^ELZ6UE;G1S(.`@<NEO<F1O;FYE<B!N92!C;W)R97-P;VYD("(*
M(G!A<R!A=2!N;VUB<F4@9"?I;.EM96YT<R!E;G)E9VES='+I<RXB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*
M;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N(@IM<V=S='(@(DYE('!E=70@9&ER:6=E<B!L92!M97-S86=E('9E<G,@
M;&4@;F]M8G)E('-PZ6-I9FGI+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@
M5F5R9&4B"FUS9W-T<B`B0V%P+59E<G0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#87!T:6]N
M(@IM<V=S='(@(DSI9V5N9&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B
M5')A;G-P;W)T975R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS
M9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B0V%TZ6=O<FEE
M<R!E="#)=&EQ=65T=&5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)
M<VQA;F1S(@IM<V=S='(@(LYL97,@0V'O;6%N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N
M92(*;7-G<W1R(")4Z6SI<&AO;F4@8V5L;'5L86ER92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@
M(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA(&-E
M;&QU;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")296UP;&ES
M<V%G92!A=71O=7(@9&4@;&$@8V5L;'5L9:`Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,0IM<V=I9"`B0V5L
M;"!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:>ETZ7,@9&4@;&$@8V5L;'5L
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(D5S<&%C96UE;G0@
M9&4@;&$@8V5L;'5L9:`Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(W,0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(E3I;.EP:&]N92!C96QL
M=6QA:7)E("(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS9VED(")#
M96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#96QT92`H25-/+3@X-3DM
M,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1R97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`B4NEP=6)L:7%U92!C96YT<F%F<FEC86EN92(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M
M.#@U.2TR*2(*;7-G<W1R(")%=7)O<.EE;B!C96YT<F%L("A)4T\M.#@U.2TR
M*2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS
M9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(D3I=&%I;',@9'4@
M8V5R=&EF:6-A="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")0<F]P
M<FGI=&%I<F4@9'4@8V5R=&EF:6-A="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE
M<R(*;7-G<W1R(")0;VQI=&EQ=64@9&4@8V5R=&EF:6-A=&EO;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")48VAA9"(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")-;V1I9FEE<B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA
M;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B36]D:69I97(@=F]T<F4@;6]T
M(&1E('!A<W-E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED
M("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL
M<RXB"FUS9W-T<B`B(@HB0VAA;F=E<B!L92!N;VTL(&PG861R97-S92!E="!L
M82!S:6=N871U<F4@<75E(&QE<R!P97)S;VYN97,@=F]I96YT('%U86YD("(*
M(F5L;&5S(&QI<V5N="!E="!RZ7!O;F1E;G0@X"!V;W,@;65S<V%G97,N(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#
M:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T
M:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(DQA(&UO9&EF:6-A=&EO;B!D92!V
M;W1R92!M;W0@9&4@<&%S<V4@;B=E<W0@<&%S('-U<'!O<G3I92!A=F5C(&QA
M("(*(F-O;F9I9W5R871I;VX@86-T=65L;&4N($-O;G1A8W1E>B!V;W1R92!A
M9&UI;FES=')A=&5U<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(D-H
M87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(E;I
M7W)I9FEE<B!L92!L:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B"FUS
M9W-T<B`B0VAI;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R
M(")#:&EN92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;F]I<R!S
M:6UP;&EF:>D@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B
M0VAI;F]I<R!T<F%D:71I;VYN96P@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G
M<W1R(")#:&]I<VER(&PG87!P;&EC871I;VZ@.B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W
M;W)D(@IM<V=S='(@(D-H;VES:7(@=6X@;6]T(&1E('!A<W-E(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E
M(&$@=7-E<FYA;64B"FUS9W-T<B`B0VAO:7-I<B!U;B!N;VT@9&4@8V]N;F5X
M:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")#:&]I<VER(&QE
M(&UO9&4@9"=A9F9I8VAA9V4@9&5S(&1A=&5SH#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED
M(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB
M"FUS9W-T<B`B0VAO:7-I<B!L92!S='EL92!D92!L:7-T92`H<&]U<B!L97,@
M;&ES=&5S(&YU;>ER:7%U97,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0VAR:7-T
M;6%S($ES;&%N9"(*;7-G<W1R("+.;&5S($-H<FES=&UA<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O
M9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(D3I9FEN:71I;VX@9&4@;&$@8VQA
M<W-E(&1E("5S(&YO;B!T<F]U=NEE+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")%
M9F9A8V5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R(").
M971T;WEE<B!L97,@8F%L:7-E<R!-4RU/9F9I8V4B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")%9F9A
M8V5R(&QA(')E<77J=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@
M)7,B"FUS9W-T<B`B4F5T:7)E<B!L)W5T:6QI<V%T975R.B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@
M=7-E<B(*;7-G<W1R(")%9F9A8V5R(&PG=71I;&ES871E=7(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E
M<B!D871A(@IM<V=S='(@(D5F9F%C97(@;&5S(&1O;F[I97,@9&4@;"=U=&EL
M:7-A=&5U<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(LEC;&%I<F-I
M97,@=&%R9"!D86YS(&QA(&IO=7)NZ64B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N
M=&EN=64B"FUS9W-T<B`B0VQI<75E<B!P;W5R('!O=7)S=6EV<F4B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*
M;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T<B`B0VQI8VMA=&5L
M;"!V:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W
M(@IM<V=S='(@(D9E<FUE<B!L82!F96[J=')E(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R(").=6%G97,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I
M9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(DYU86=E<R!M871I;F%U>"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED
M(")#;&]U9'DB"FUS9W-T<B`B3G5A9V5U>"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@
M(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(LYL97,@0V]C;W,B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#
M;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E)E<&QI97(@;&$@8F%R<F4@9&4@
M8_1TZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(E+I9'5I<F4@;&5S(&)O<F1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB
M:6$B"FUS9W-T<B`B0V]L;VUB:64B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP
M.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B
M"FUS9W-T<B`B0V]U;&5U<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS,S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,S-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3`S('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z-C8*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z.#(*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R(")086QE='1E(&1E
M(&-O=6QE=7)S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R-0IM
M<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I;VX@9"=U
M;F4@8V]U;&5U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R(")#;VQSH#HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30S"FUS9VED(")#;VQU;6X@
M=&ET;&5S(@IM<V=S='(@(E1I=')E<R!D92!C;VQO;FYE(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(V-@IM<V=I9"`B0V]M:6-S(@IM<V=S='(@
M(D(N1"XB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA
M;F0B"FUS9W-T<B`B0V]M;6%N9&4B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B0V]M;6%N9&4@<VAE
M;&PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M;65N=&%I<F4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B3F]M('5S=65L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O
M;6]R;W,B"FUS9W-T<B`B0V]M;W)E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T
M<B`B4V]C:>ETZ2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM<V=I
M9"`B0V]M<'5T97)S(@IM<V=S='(@(D]R9&EN871E=7)S(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM
M<V=S='(@(D-O;F1I=&EO;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4V
M"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(D-O;F1I=&EO;G,B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R(")$:69FZ7)E;F-E<R!D92!C;VYF:6=U<F%T
M:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-@IM<V=I9"`B0V]N
M9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S
M(&%N9"!/=71L;V]K+B(*;7-G<W1R("(B"B)3>6YC:')O;FES871I;VX@9&5S
M(&%S<VES=&%N=',@<&5R<V]N;F5L<RP@/$D^<VUA<G1P:&]N97,\+TD^(&5T
M($]U=&QO;VLN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B3&$@
M8V]N9FEG=7)A=&EO;B!N)V5S="!P87,@X"!J;W5R+B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG
M=7)E("5S(@IM<V=S='(@(D-O;F9I9W5R97(@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W
M;W)D(@IM<V=S='(@(D-O;F9I<FUE<B!L92!M;W0@9&4@<&%S<V4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")#;VYG;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4B"FUS9W-T<B`B4NEP=6)L:7%U92!DZ6UO8W)A=&EQ=64@9'4@0V]N9V\B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS
M9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`BR6-H96,@9&4@;&$@
M8V]N;F5X:6]N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("+)
M8VAE8R!D92!L82!C;VYN97AI;VZ@.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T
M;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0V]N;F5X:6]N(&%U
M('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D-O;FYE>&EO;B!A=2!S97)V
M975R(&1E(&-L969S('!U8FQI8R!R969U<^EE+B!286ES;VZ@.B`@)7,@*"5S
M*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<V"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+)8VAE
M8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!&5%`B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B0V]N=&%C=',B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R(")#97,@8V]N=&%C=',@;VYT(&)I96X@Z73I
M(&%J;W5TZ7,@X"!V;W1R92!C87)N970@9"=A9')E<W-E<RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#;VYT
M96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B5'EP92!D
M92!C;VYT96YU(&1U(&9I8VAI97(@8V]M<')E<W/IH#H@(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1E;G4@9&4@JZ`E<Z"[(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")0
M;W5R<W5I=G)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM
M<V=S='(@(LYL97,@0V]O:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(E3I;6]I;B`H8V]O:VEE*2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")#;W!I97(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]P:66@.B`E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(E/I;&5C=&EO;B!D
M)W5N92!C;W!I92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(DED+B!C;_MT(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R(")#
M]'1E(&0G279O:7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z.3<W"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@
M(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@8VAI9F9R97(@;&4@;65S<V%G9:`Z
M("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-34*;7-G
M:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B4VEG
M;F%T=7)E(%!'4"!D=2!M97-S86=E(&EM<&]S<VEB;&6@.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9&4@8VAI9F9R97(@;&4@;65S<V%G92!A=F5C(%,O34E-12XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U
M;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(E-I9VYA='5R
M92!3+TU)344@9'4@;65S<V%G92!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B06IO=70@9'4@8V]N=&%C="`E<R!I;7!O<W-I8FQE+B`B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ,C$*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U
M-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DYE('!E=70@<V4@8V]N;F5C=&5R(&%U('-E<G9E=7(@3$1!4"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U
M-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S(@IM<V=S='(@(E;I<FEF:6-A=&EO;B!D92!L82!B86QA;F-E
M("5S(&EM<&]S<VEB;&4N("(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*
M;7-G<W1R("+)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S
M:6YG($944#H@)7,B"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U
M('-E<G9E=7(@JZ`E<Z"[('9I82!&5%"@.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(D-RZ6%T:6]N(&1E(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;B!I;7!O<W-I8FQE+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M.B`B"FUS9W-T<B`B26UP;W-S:6)L92!D92!DZ6-H:69F<F5R(&QE<R!D;VYN
MZ65S(%!'4*`Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3(S"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`B26UP;W-S:6)L92!D92!DZ6-H:69F<F5R(&QE<R!D;VYNZ65S
M(%,O34E-12XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE('!E=70@<&%S('-U<'!R
M:6UE<B!L92!C;VYT86-T("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B3F4@<&5U="!P87,@<W5P<')I;65R(&QA(&QI<W1E(&1E(&1I<W1R:6)U
M=&EO;B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(").92!P975T('!A<R!S=7!P<FEM
M97(@;&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(*N@)7.@NRXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(")$
MZ71E<FUI;F%T:6]N(&1E(&PG861R97-S92!D=2!D97-T:6YA=&%I<F4@:6UP
M;W-S:6)L92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B3F4@<&5U="!RZ6-U<.ER97(@=&]U
M="!L92!C87)N970@9"=A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYE
M('!E=70@<NEC=7#I<F5R('1O=71E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO
M;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B3B=A('!A<R!P
M=2!RZ6-U<.ER97(@;&$@;&ES=&4@8V]M<&SH=&4@9&4@;&ES=&5S(&1E(&1I
M<W1R:6)U=&EO;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!C:&%R9V5R(&QA
M('-T<F%TZ6=I92"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!C<NEE<B!L92!RZ7!E<G1O:7)E(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DEM
M<&]S<VEB;&4@9"=O8G1E;FER(&QA(&-L968@<'5B;&EQ=64@X"!P87)T:7(@
M9'4@<V5R=F5U<B!D92!C;&5F<RXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F
M;W(@=W)I=&EN9RXB"FUS9W-T<B`B3W5V97)T=7)E(&1E(*N@)7.@NR!I;7!O
M<W-I8FQE(&5N(.EC<FET=7)E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3W5V97)T=7)E(&1E("5S
M(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B26UP
M;W-S:6)L92!D)V]U=G)I<B!L92!M;V1U;&4@36%I;G1E;F%N8V5?5&%S:R`E
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")/
M=79E<G1U<F4@9'4@9&]S<VEE<B"KH"5SH+L@:6UP;W-S:6)L92XB"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=A='1E:6YD<F4@
M;&4@<V5R=F5U<B!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D
M("5S+B(*;7-G<W1R("),96-T=7)E(&1E("5S(&EM<&]S<VEB;&4N("(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB3B=A
M('!U(')E;65T=')E(.`@>NER;R!L92!M;W0@9&4@<&%S<V4@<&]U<B!L)W5T
M:6QI<V%T975R(&1E;6%N9.DN($-E<G1A:6YS("(*(BAO=2!T;W5S*2!L97,@
M9.ET86EL<R!N92!S;VYT('!A<R!C;W)R96-T<RX@4NEE<W-A>65Z(&]U(&-O
M;G1A8W1E>B!V;W1R92`B"B)A9&UI;FES=')A=&5U<B!P;W5R(&1E(&PG86ED
M92XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(E+I8W5PZ7)A=&EO
M;B!D97,@04-,(&EM<&]S<VEB;&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R
M(").92!P975T('+I8W5PZ7)E<B!L92!C87)N970@9"=A9')E<W-E<RX@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE('!E=70@<NEC=7#I
M<F5R(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N
M(&QI<W1S+B`E<R(*;7-G<W1R(").92!P975T('+I8W5PZ7)E<B!L97,@;&ES
M=&5S(&1E(&1I<W1R:6)U=&EO;BX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").92!P975T('+I8W5P
MZ7)E<B!L97,@<&]S<VEB:6QI=.ES(&1U('-E<G9E=7(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DYE('!E=70@<&%S(')E=F5N:7(@X"!L
M82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N=&4N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<
M(B5S7"(N(@IM<V=S='(@(D5F9F%C96UE;G0@9'4@9&]S<VEE<B"KH"5SH+L@
M:6UP;W-S:6)L92X@(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B3F4@<&5U="!P87,@96YR96=I<W1R97(@;&$@
M8V]N9FEG=7)A=&EO;B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").92!P975T
M('!A<R!E;G)E9VES=')E<B!U;F4@<V%U=F5G87)D92!D92!L82!C;VYF:6=U
M<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U
M871I;VXZ("5S(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!U
M;F4@8V]P:64@9&4@;&$@8V]N9FEG=7)A=&EO;J`Z("5S(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB
M"FUS9W-T<B`B26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE('-C<FEP="!D
M92!M:7-E(.`@:F]U<B!D86YSH#H@JZ`E<Z"[+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!U;F4@8V]P:64@9'4@9FEC
M:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T
M('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H
M97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E
M(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T
M;R`E<RXB"FUS9W-T<B`B(@HB26UP;W-S:6)L92!D)V5N<F5G:7-T<F5R(&QE
M(&9I8VAI97(@9&4@8V]N9FEG=7)A=&EO;B`E<RX@5F]U<R!P;W5V97H@<V]I
M="`B"B)U=&EL:7-E<B!U;F4@9&5S(&]P=&EO;G,@<&]U<B!S875V97(@;&4@
M8V]D92!S=7(@)7,@<V]I="!C;W!I97(@;6%N=65L;&5M96YT("(*(FQE(&-O
M9&4@8VDM9&5S<V]U<R!D86YS("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BXB"FUS9W-T<B`B3F4@<&5U="!P87,@<F5C:&5R8VAE<B!L
M92!S97)V975R($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G
M<W1R(")3=7!P<F5S<VEO;B!D92"KH"5SH+L@:6UP;W-S:6)L92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N
M("5S(@IM<V=S='(@(DUI<V4@X"!J;W5R(&1U(&-O;G1A8W0@:6UP;W-S:6)L
M92X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").92!P975T(&UE
M='1R92#@(&IO=7(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`E<R(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*;7-G<W1R(").92!P975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U
M<F%T:6]N('!O=7(@JZ`E<Z"[H#H@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R
M(").92!P975T('1R;W5V97(@;&$@8F%R<F4@9&4@36]Z:6QL82X@($%S<W5R
M97HM=F]U<R!Q=2=E;&QE(&5S="!A8W1I=F4N(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B
M"B).92!P975T(&%T=')I8G5E<B!C97,@9')O:71S(.`@;"=U=&EL:7-A=&5U
M<B"KH"5SH+L@('-U<B!L92!D;W-S:65R(*N@)7.@NZ`Z("(*(B5S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q-@IM<V=I9"`B0V]U;G1E9"!T
M97AT(@IM<V=S='(@(E1E>'1E(&-O;7!TZ2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(E!A>7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(D-O=7)S(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#
M<F5A=&4B"FUS9W-T<B`B0W+I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A
M(&QI;FLB"FUS9W-T<B`B0W+I97(@=6X@;&EE;B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE
M=R!O;F4B"FUS9W-T<B`B0W+I97(@=6X@;F]U=F5A=2(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B
M(&9O;&1E<G,B"FUS9W-T<B`B0W+I97(@=6X@<V]U<RUD;W-S:65R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T
M;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<VEO;G,@1&4@0W+I871E
M=7(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C`Y"FUS9VED(")#
M<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B3G5MZ7)O(&1E(&-A<G1E(&1E
M(&-RZ61I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@
M(D-R;V%T:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(D-U
M8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@
M-"!0:&%S97,B"FUS9W-T<B`B-"!P:&%S97,@8V]U<F%N=&5S(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C4P"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(E-E<W-I;VYS(&5N(&-O=7)S(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I
M;64B"FUS9W-T<B`B2&5U<F4@86-T=65L;&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U
M<G)E;G0@55),(&ES(@IM<V=S='(@(DPG861R97-S92!54DP@86-T=65L;&4@
M97-T(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT
M(%5S97)S(@IM<V=S='(@(E5T:6QI<V%T975R<R!A8W1U96QS(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM
M<V=S='(@(D]B<V5R=F%T:6]N<R!A8W1U96QL97,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO
M;CH@(@IM<V=S='(@(D-O;F1I=&EO;B!A8W1U96QL9:`Z("(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U
M<G)E;G0@<W1Y;&4B"FUS9W-T<B`B4W1Y;&4@8V]U<F%N="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R
M(")$Z69I;FER(&QE<R!TXF-H97,@X"!E9F9E8W1U97(@;&]R<R!D92!L82!C
M;VYN97AI;VX@X"`E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R(")#
M;W5P97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(D-O=7!E<B!L
M82!SZ6QE8W1I;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R=7,B"FUS9W-T
M<B`B0VAY<')E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D-Y<FEL;&EQ=64@*$M/23@M
M4BDB"@HC(&-O;F9I9R]N;',N<&AP+F1I<W0Z"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@V"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G
M<W1R(")#>7)I;&QI<75E("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])
M."U5*2(*;7-G<W1R(")#>7)I;&QI<75E+U5K<F%I;FEE;B`H2T])."U5*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E+I
M<'5B;&EQ=64@5&-HZ'%U92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3(@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(D1$(@IM<V=S='(@(DI*(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(V.0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*2(*;7-G<W1R("(B"B)$4TX@*$-F+B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA
M;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM
M<V=I9"`B1&%I;'DB"FUS9W-T<B`B0VAA<75E(&IO=7(B"@HC.B!A9&UI;B]D
M871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T
M<B`B3F%V:6=A=&5U<B!D92!$871A5')E92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R-C<*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R
M(")!;&EA<R!D92!L82!B87-E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,SDU"FUS9VED(")$871E(@IM<V=S='(@(D1A=&4B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E
M9"(*;7-G<W1R(")$871E(&1E('+I8V5P=&EO;B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(W.#8*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S
M='(@(E/I;&5C=&EO;B!D)W5N92!D871E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(X,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S$Q"FUS9VED(")$87DB"FUS9W-T<B`B2F]U<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B
M1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B4W5P<')I;65R(%]L82!C;VQO;FYE
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*
M;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D3I8V5M8G)E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM
M<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(DYO;6)R97,@9.EC:6UA
M=7@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B1&EM:6YU97(@
M;"=I;F1E;G1A=&EO;B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S
M='(@(D3I9F%U="(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(D-O
M=6QE=7(@<&%R(&3I9F%U="(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B
M261E;G1I=.D@<&%R(&3I9F%U="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HV-PIM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R("));G1E<G!RZ71E
M=7(@9&4@8V]M;6%N9&4@<&%R(&3I9F%U="(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B1.EF:6YI
M=&EO;G,B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B169F86-E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM
M<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B169F86-E<B!L82!C96QL=6QE
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR
M,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3=7!P<FEM97(@=6X@
M9W)O=7!E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"FUS
M9VED(")$96QE=&4@3&]G(@IM<V=S='(@(D5F9F%C97(@;&$@=')A8V4B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO
M;B(*;7-G<W1R(")3=7!P<FEM97(@=6YE('!E<FUI<W-I;VXB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")3=7!P<FEM97(@970@
M<'5R9V5R(&QE<R!M97-S86=E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL
M(@IM<V=S='(@(D5F9F%C97(@;&$@8V5L;'5L92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E
M;&5T92!C;VQU;6XB"FUS9W-T<B`B169F86-E<B!L82!C;VQO;FYE(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4W5P<')I;65R('5N(&%U
M=')E(&UO9.AL92!E>&ES=&%N="(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS
M9W-T<B`B4W5P<')I;65R(&QE<R!M97-S86=E<R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E-U<'!R:6UE
M<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"KH"5SH+LB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")$
M96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\B"FUS9W-T<B`BRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I
M<B!E9F9A8V5R(*N@)7.@NR!E="!S97,@<V]U<RUP97)M:7-S:6]N<Z`_(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")%9F9A8V5R(&QA(')A
M;F?I92(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z
M,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")3
M=7!P<FEM97(@;"=I9&5N=&ETZ2!SZ6QE8W1I;VYNZ64B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E
M('-U8B!F;VQD97)S(@IM<V=S='(@(E-U<'!R:6UE<B!U;B!S;W5S+61O<W-I
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB
M"FUS9W-T<B`B169F86-E<B!L82!C;VQO;FYE(&%C='5E;&QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(D5F9F%C
M97(@;&$@<F%N9^EE(&%C='5E;&QE(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U
M<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(E-C<FEP="!D92!C;VYF
M:6=U<F%T:6]N(&1E(&UI<V4@X"!J;W5R('-U<'!R:6WI(*N@)7.@NRXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DAE
M=7)E(&1E(&QI=G)A:7-O;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1&%N96UA<FLB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B1.EC<FER92!L92!P<F]B;.AM92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDS-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,P"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C
M<FEP=&EO;B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`V"FUS
M9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S
M='(@(D3I=&%I;',@*&%U<W-I(&1A;G,@;&4@9FEC:&EE<B!D92!T<F%C97,@
M9&4@2&]R9&4IH#HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(Q
M,`IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS
M:6=NZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@
M(D3I=F5L;W!P96UE;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM
M<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(E!O:6YT(&1E(')O<^EE(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B4&]I;G0@9&4@<F]SZ64@<&]U<B!L82!D
M97)N:>AR92!H975R9:`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!O:6YT(&1E
M(')O<^EEH#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS
M9W-T<B`B1&4@9V%U8VAE(.`@9')O:71E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I
M9VAT('1O(&QE9G0B"FUS9W-T<B`B1&4@9')O:71E(.`@9V%U8VAE(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G
M<W1R(")2Z7!E<G1O:7)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(W
M,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")!9F9I
M8VAE<B!S=7(@,C0@:&5U<F5SH#\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N
M<R!D)V%F9FEC:&%G92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R
M(")!9F9I8VAE<B!L82!P<NEV:7-I;VX@9.ET86EL;.EE(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")!9F9I8VAE<B!L82!P<NEV:7-I;VX@*%1!1BDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDV"FUS9VED(")$:7-P;&%Y(&9O
M<FUA="(*;7-G<W1R(")&;W)M870@9"=A9F9I8VAA9V4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B079I<R!D92!L:79R86ES;VXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(DYE('!A<R!S=7!P<FEM97(B"@HC.B!S97)V
M:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(DYE('!A<R!A8V/I
M9&5R(&1I<F5C=&5M96YT(.`@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H
M92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T
M<B`B(@HB3&4@<')E;6EE<B!E;G)E9VES=')E;65N="!C;VYT:65N="UI;"!L
M92!N;VT@9&5S(&-H86UP<Z`_($1A;G,@(@HB;"=A9F9I<FUA=&EV92P@8V]C
M:&5Z(&-E='1E(&)O[G1EH#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC
M82(*;7-G<W1R(")$;VUI;FEQ=64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4NEP=6)L:7%U92!D;VUI;FEC86EN
M92(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B5F]U<R!N
M)V%V97H@<&%S(&1E(&-O;7!T9:`_($5N<F5G:7-T<F5Z+79O=7,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4Q"FUS9VED(")$
M;W=N;&]A9"(*;7-G<W1R(")4Z6SI8VAA<F=E<B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@U,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$;W=N;&]A9"`E<R(*;7-G<W1R(")4Z6SI8VAA<F=E<B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E3I
M;.EC:&%R9V5R(&QA(&-O;F9I9W5R871I;VX@9^ENZ7+I92!C;VUM92!U;B!S
M8W)I<'0@4$A0(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P-`IM
M<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B3&ES=&4@9.ER;W5L86YT
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B
M"FUS9W-T<B`B1')O9W5E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@(D-O=7)R:65R(.EL
M96-T<F]N:7%U92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC
M7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV
M97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB
M"FUS9W-T<B`B(@HB4&EL;W1E(&1E('!A<W-E<F5L;&4@8V]U<G)I97(@+R!3
M35,L('!O=7(@;&5S(&9O=7)N:7-S975R<R!D92!C92!S97)V:6-E+B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R(")%4E(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(LEQ=6%T975R(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(DUO
M9&EF:65R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM
M<V=I9"`B161I="!";&]C:R(*;7-G<W1R("+)9&ET97(@;&4@8FQO8R(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS
M9VED(")%9&ET($=R;W5P(@IM<V=S='(@(LED:71E<B!U;B!G<F]U<&4B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB
M"FUS9W-T<B`BR61I=&5R('5N92!P97)M:7-S:6]N(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*
M;7-G<W1R("+)9&ET97(@;&5S('!E<FUI<W-I;VYS(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+)9&ET97(@;&5S('!E<FUI
M<W-I;VYS('!O=7(@JZ`E<Z"[(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`BR61I=&5R
M(&QE<R!O<'1I;VYS('!O=7*@.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES
M<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+)9&ET97(@;&5S('!E<FUI<W-I
M;VYS('!O=7(@JZ`E<Z"[(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R("+)9&ET97(@;&5S('!E<FUI<W-I;VYS('!O=7(@)7,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO
M;B(*;7-G<W1R("+)9'5C871I;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP
M="(*;7-G<W1R("+)9WEP=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A
M;'9A9&]R(@IM<V=S='(@(E-A;'9A9&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M
M96YT+BXN(@IM<V=S='(@(LELZ6UE;G0N+BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T
M<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C8*;7-G:60@(D5M
M86EL(@IM<V=S='(@(D%D<F5S<V4@Z6QE8W1R;VYI<75E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D%D
M<F5S<V4@Z6QE8W1R;VYI<75E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DV,`IM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(DQE<R!A9')E<W-E<R#I;&5C=')O;FEQ=65S(&1O:79E;G0@8V]R
M<F5S<&]N9')E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#8*
M;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(D-O=7)R
M:65R(&%V96,@8V]N9FER;6%T:6]N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'
M871E=V%Y(@IM<V=S='(@(E!A<W-E<F5L;&4@8V]U<G)I97(@+R!335,B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDY"FUS
M9VED(")%;6]T:6-O;G,B"FUS9W-T<B`BR6UO=&EC]&YE<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM<V=I
M9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B365S<V%G92!V:61E+B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*
M;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4NES=6QT870@=FED92XB
M"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED
M(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5&5R;65S(&1E(')E8VAE
M<F-H92!V:61E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B06-T:79E<B!L)VEN<V5R=&EO;B!D
M)VEM86=E<R!V96YA;G0@9&5S(&%L8G5M<R!P:&]T;W,@9&%N<R!L92!T97AT
M9:`_(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA
M8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06-T:79E
M<B!L92!M96YU(&-O;G1E>'1U96P@879E8R!U;B!C;&EC(&1R;VETH#\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@U(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(W.3`*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D9I;B!D
M92!L)V%N;NEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B06=R
M86YD:7(@;"?I9&ET975R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R
M-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y
M;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*
M(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T
M/R<Z(@IM<V=S='(@(B(*(LEC<FEV97H@=6YE('%U97-T:6]N(&1E('/I8W5R
M:73I('%U)V]N('9O=7,@<&]S97)A('-I('9O=7,@9&5V97H@<F5M971T<F4@
MX"`B"B)ZZ7)O('9O=')E(&UO="!D92!P87-S92P@<&%R(&5X96UP;&4@JR!1
M=65L(&5S="!L92!N;VT@9&4@=F]T<F4@86YI;6%L("(*(G!RZ6;I<NF@/Z"[
MH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R
M92(*;7-G<W1R("));G-C<FEV97H@;"=A9')E<W-E(%523"!D92!L)VEM86=E
M(&EC:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R
M(")%;G1R97H@;&5S(&QE='1R97,@8VDM9&5S<V]U<Z`Z(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B1W5I;NEE(.EQ
M=6%T;W)I86QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R
M("+)<GET:'+I92(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I
M9"`B17)R;W(B"FUS9W-T<B`B17)R975R(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R
M;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E
M(&QA(&-RZ6%T:6]N(&1U(&)L;V.@.B`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E
M;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R(")%<G)E=7(@;&]R<R!D
M92!L82!S=7!P<F5S<VEO;B!D92!L)V%N8W)E(&1E('-Y;F-H<F]N:7-A=&EO
M;J`Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(D5R<F5U<B!L;W)S(&1E(&QA('-U<'!R97-S:6]N(&1U(&IO
M=7)N86P@9&4@<WEN8VAR;VYI<V%T:6]NH#H@)7,B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(D5R<F5U<B!L
M;W)S(&1E(&QA('+I8W5PZ7)A=&EO;B!D=2!C;VYT96YUH#H@)7,B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(D5R
M<F5U<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1U(&UO="!D92!P87-S9:`Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM
M<V=S='(@(D5R<F5U<B!A=F5C(&QE(&UE<W-A9V4N(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG
M(%PB)7-<(BXB"FUS9W-T<B`B17)R975R(&QO<G,@9&4@;"=E;G)E9VES=')E
M;65N="!D92"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R(")%<W1O;FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B
M"FUS9W-T<B`BR71H:6]P:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R(")%=&AN:7%U92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S
M='(@(D5U<F]P92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#,*;7-G
M:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B5&]U<R!L97,@)F9R86,Q
M-#L@9"=H975R92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")4;W5T97,@;&5S(#(@;6EN
M=71E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G
M<W1R(")4;W5T97,@;&5S(#,P('-E8V]N9&5S(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED
M(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B5&]U=&5S(&QE<R`U(&UI;G5T
M97,B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("+`(&-H87%U92!C;VYN
M97AI;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0T"FUS9VED(")%
M=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B5&]U=&5S(&QE<R`F9G)A8S$R.R!H
M975R97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R
M(")4;W5T97,@;&5S(&UI;G5T97,B"@HC.B!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(D5X
M96UP;&4@9&4@=F%L975R<Z`Z(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@R
M(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X
M"FUS9VED(")%>&5C=71E(@IM<V=S='(@(D5XZ6-U=&5R(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@
M(D5X<&%N9"(*;7-G<W1R(")$Z79E;&]P<&5R(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS
M9W-T<B`B1.EP;&EE<B!L82!B87)R92!D92!C]'3I(@H*(SH@9G)A;65W;W)K
M+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG
M(@IM<V=S='(@(JL@*2"[(&%T=&5N9'5E(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")5;B!S975L(&UO="!O
M=2!E>'!R97-S:6]N(&5N=')E(&=U:6QL96UE=',@871T96YD=7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER
M871I;VX@1&%T92(*;7-G<W1R(")$871E(&0G97AP:7)A=&EO;B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O
M;F5N="(*;7-G<W1R(")297!RZ7-E;G1A;G0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#
M;VQO<B(*;7-G<W1R(")#;W5L975R(&0G879A;G0M<&QA;B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T
M=7`B"FUS9W-T<B`B5.ELZ6-H87)G96UE;G0@=F5R<R!L92!S97)V975R(&1E
M(&QA(&-O;F9I9W5R871I;VX@<&%R($944"(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S<6PN<&AP.C(R,`IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N(@IM<V=S='(@(DQE8W1U<F4@9&5S('!RZ6;I<F5N8V5S
M(&EM<&]S<VEB;&4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+)
M8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!,1$%0+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O
M(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`BR6-H96,@9&4@;&$@
M8V]N;F5X:6]N(&%U('-E<G9E=7(@4TU"+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("+)8VAE8R!D92!L82!C;W!I
M92!D97!U:7,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O
M(%PB)7-<(BXB"FUS9W-T<B`BR6-H96,@9&4@;&$@8V]P:64@=F5R<R`@JZ`E
M<Z"[+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*;7-G
M:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B26UP;W-S:6)L92!D92!C<NEE<B!U;F4@;F]U=F5L;&4@8V]N;F5X
M:6]N(%-!4TPB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4P,2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(LEC:&5C
M(&1U(&3I<&QA8V5M96YT('9E<G,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`BR6-H96,@;&]R<R!D92!L82!R
MZ6-U<.ER871I;VZ@.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(D)E874B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M"FUS9W-T<B`BSFQE<R!&86QK;&%N9"`H36%L;W5I;F5S*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BSFQE<R!&Z7)OZ2(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A=&%L($5R
M<F]R.B(*;7-G<W1R(")%<G)E=7(@9F%T86QEH#HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B5.ELZ6-O<&EE<R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R(")&Z79R:65R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B5&5M<.ER871U<F4@<F5S
M<V5N=&EE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,`IM
M<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(E1E;7#I<F%T=7)E(')E<W-E
M;G1I9:`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")1=65L<75E<R!A
M=F5R<V5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B475E;'%U
M97,@8VAU=&5S(&1E(&YE:6=E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DT,0IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(DUA=')I8V4@
M9&5S(&-H86UP<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C(*
M;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(D9I9VQE="!#05!40TA!
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,R-@IM<V=I9"`B1FEG
M;&5T(&9O;G0B"FUS9W-T<B`B4&]L:6-E(&1E(&QA(#Q)/F9I9VQE=#PO23XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S='(@(D9I9&II(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(D9I8VAI97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(DYO;6)R92!D92!F:6-H:65R<Z`Z("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#
M;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B3F]M8G)E(&1E(&9I8VAI97)SH#H@
M)7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&
M:6QE($UA;F%G97(B"FUS9W-T<B`B1V5S=&EO;FYA:7)E(&1E(&9I8VAI97)S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@
M3F%M92(*;7-G<W1R(").;VT@9'4@9FEC:&EE<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y-S0*;7-G:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S
M='(@(D-H;VEX(&1E(&9I8VAI97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#@S"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")4Z6SI8VAA
M<F=E;65N="!D92!F:6-H:65R(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"XB"FUS9W-T<B`B3"=E;G9O:2!D92!F:6-H:65R<R!N)V5S="!P87,@<')I
M<R!E;B!C;VUP=&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDQ
M"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R97,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FQA;F1E(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")0
M<F5M:>AR92!D96UI92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T
M<B`B4')E;6EE<B!Q=6%R=&EE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R
M(")&:7AE<B!L92!R871I;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T<B`B4F5T;W5R
M;F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B1FQO='1A;G0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I
M9"`B1F]G(@IM<V=S='(@(D)R;W5I;&QA<F0B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(S-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R(")$;W-S:65R("5S(&EN97AI<W1A;G0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B
M1F]N="!#;VQO<B(*;7-G<W1R(")#;W5L975R(&1E('!O;&EC92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(").
M;W5R<FET=7)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")0;W5R(&QE<R!N879I
M9V%T975R<R!N92!S=7!P;W)T86YT('!A<R!L97,@:6UA9V5S(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#$*;7-G:60@(D9O<F5C87-T("A4048I(@IM
M<V=S='(@(E!RZ79I<VEO;B`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T
M:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N
M9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)*;W5R<R!D92!P<NEV:7-I
M;VX@*&YO=&5Z('%U92!L97,@<'+I=FES:6]N<R!F;W5R;FEE<R!D;VYN96YT
M(&QE(&IO=7(@970@;&$@(@HB;G5I=*`[('5N(&=R86YD(&YO;6)R92!I8VD@
M<&5U="!F86ER92!U;B!B;&]C('1RZ',@;&%R9V4B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(E9O=7,@879E>B!O=6)L:>D@=F]T<F4@;6]T(&1E('!A
M<W-EH#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED
M(")&;W)M<R(*;7-G<W1R(")&;W)M=6QA:7)E<R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")#:71A=&EO
M;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N
M92!T>7!E(@IM<V=S='(@(E1Y<&4@9&4@8VET871I;VXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(D-I
M=&%T:6]N<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM<V=I9"`B
M1F]R='5N97,@,B(*;7-G<W1R(")#:71A=&EO;G,@,B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&
M;W)U;7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$Q"FUS9VED
M(")&;W)W87)D<R(*;7-G<W1R(")2961I<F5C=&EO;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM
M<V=S='(@(E9E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(D-A9')E
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N8V4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(D9R86YC92!MZ71R;W!O;&ET
M86EN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T
M<B`B1W5Y86YE(&9R86[G86ES92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N
M8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O;'ENZ7-I92!F<F%NYV%I<V4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE
M<R(*;7-G<W1R(")497)R97,@875S=')A;&5S(&5T(&%N=&%R8W1I<75E<R!F
M<F%NYV%I<V5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")$92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,T.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDU"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B1'4@(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B1&5S8W)I<'1I;VX@8V]M<&SH=&4B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I
M9"`B1G5L;"!-;V]N(@IM<V=S='(@(E!L96EN92!L=6YE(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VT@8V]M<&QE
M="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*
M;7-G<W1R(")!;&)U;2!D)V]R:6=I;F4@9&4@;"=I;6%G92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B06QB=6V@.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'86UB:64B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R
M871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1^ENZ7)E<B!L82!C;VYF
M:6=U<F%T:6]N(&1E("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V-O
M;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D-O
M9&4@9^ENZ7+I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R
M(")'Z6]R9VEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R
M(")!;&QE;6%G;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDS
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N82(*;7-G<W1R
M(")':&%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R
M(")':6)R86QT87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(")0<NEN;VTB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<U('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y
M"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")/<'1I;VYS(&=L;V)A
M;&5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3<*;7-G:60@(D=O
M(@IM<V=S='(@(D%L;&5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P
M"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L
M92!-87!S(@IM<V=S='(@(D-A<G1E<R!';V]G;&4B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@
M(E)E8VAE<F-H92!';V]G;&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,X"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B
M3FEV96%U(&1E(&=R:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W)E96-E(@IM
M<V=S='(@(D=RZ&-E(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G
M:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<F5C("A)4T\M.#@U
M.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'
M<F_K;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@
M(D=R96YA9&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B1W)O
M=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9&5S
M(&=R;W5P97,B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(DQE<R!N;VUS(&1E
M(&=R;W5P92!N92!P975V96YT('!A<R#J=')E('9I9&5S(@H*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB1W)O=7!?
M;&1A<*`Z(&EM<&]S<VEB;&4@9"=A:F]U=&5R(&QE(&=R;W5P92`E<RX@0V5C
M:2!E<W0@;&$@<NEP;VYS92!D=2`B"B)S97)V975RH#HB"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87"@
M.B!S=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&=R;W5P92`E<R(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@
M(D=R;W5P7VQD87"@.B!M;V1I9FEC871I;VX@:6UP;W-S:6)L92!D=2!G<F]U
M<&4@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R;W5P97,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861E;&]U
M<&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R(")'=6%M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R(")'=6%T96UA
M;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R(")'=65R;F5S97DB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S
M:6]N<R!D97,@:6YV:73I<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("),:79R92!D)V]R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6[I92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6EN
MZ64M0FES<V%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B1W5Y86YA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.34W"FUS
M9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@<F5F=7-E(&+J=&5M96YT(&1E('-U
M<'!R:6UE<B!L82!D97)N:>AR92!C96QL=6QE(&1E(&QA(')A;F?I92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@
M<F5F=7-E(&+J=&5M96YT(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C;VQO
M;FYE(&1U('1A8FQE874B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L
M>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM
M<V=S='(@(DA434Q!<F5A(')E9G5S92!BZG1E;65N="!D92!S=7!P<FEM97(@
M;&$@9&5R;FGH<F4@<F%N9^EE(&1U('1A8FQE874B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A
M=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&AE;G1I9FEC871I;VX@2%14
M4"!N;VX@=')O=7;I92XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM
M<V=S='(@(DAA[W1I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET
M:&UE(&1E(&AA8VAA9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")"<G5M92!SZ&-H
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ-B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.3$Q"FUS9VED(")(96%D97(B"FUS9W-T<B`B16XM
M=.IT92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP
M:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B16XM=.IT97,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("+.;&5S($AE87)D(&5T($UC1&]N86QD(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE
M879Y(%0M4W1O<FTB"FUS9W-T<B`B3W)A9V5S('9I;VQE;G1S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM
M."U)*2(*;7-G<W1R(")(Z6)R974@*$E33RTX.#4Y+3@M22DB"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HR,B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`B
M2&%U=&5U<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ
M.#0@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V
M:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI
M;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R(")!:61E(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B2&5L<"!U
M<VEN9R!E9&ET;W(B"FUS9W-T<B`B06ED92!P;W5R(&PGZ61I=&5U<B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C@*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R(")!:61E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED
M(")(96UI<W!H97)E(@IM<V=S='(@(DCI;6ES<&CH<F4B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.B(*;7-G<W1R(")6;VEC:2!L92!DZ6)U="!D=2!F:6-H:65RH#HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I
M9"`B2&EG:"(*;7-G<W1R(")(875T92(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z
M-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B05]C8W5E:6PB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G
M<W1R(")#:73I(&1U(%9A=&EC86XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$U-#@*;7-G:60@(DAO;64B"FUS9W-T<B`B06-C=65I;"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@<&5R<V]N;F5L;&4B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C0*;7-G:60@(DAO;64@1&ER
M96-T;W)Y(@IM<V=S='(@(E+I<&5R=&]I<F4@<&5R<V]N;F5L(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B
M2&]M92!0:&]N92(*;7-G<W1R(")4Z6SI<&AO;F4@<&5R<V]N;F5L(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@
M2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@9&]N;NEE<R!834P@)7,@:6YV86QI
M9&5S(')E=')O=7;I97,@9&%N<R!L92!M97-S86=E("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@875C=6X@;65S<V%G92!N92!C
M;W)R97-P;VYD(&%U('-U:F5T("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS
M9W-T<B`B2&]R9&4O2V]L86*@.B!P87,@9"=O8FIE="!D92!T>7!E("5S('1R
M;W5VZ2!D86YS(&QE(&UE<W-A9V4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(
M;W)D92]+;VQA8J`Z("5S('-U<'!R:6WI(*N@)7.@NR!A=F5C('-U8V/H<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"B)(;W)D92]+;VQA
M8J`Z(&QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N(&[I8V5S<VET92!L)V5X=&5N
M<VEO;B`G9&]M>&UL)R!D92!02%`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@8W+I97(@=6X@
M;F]U=F5L(&%R8G)E(%A-3"!P;W5R(&PG;V)J970@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9"=E;FQE=F5R("5S
M(*N@)7.@NZ`Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT
M.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM
M<V=S='(@(B(*(DAO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D92!RZ6-U<.ER
M97(@;"=I9&5N=&EF:6%N="!-24U%('!O=7(@;&$@<&%R=&EE(&1E("(*(G1Y
M<&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@
M:6UP;W-S:6)L92!D92!S>6YC:')O;FES97(@)7,@JZ`E<Z"[H#H@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S
M:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D
M92!S>6YC:')O;FES97(@;&5S('!A<G1A9V5SH#H@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R
M9&4O2V]L86*@.B!P87)T86=E(&EN8V]N;G4@JZ`E<Z"[(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R
M:7IO;G1A;"!2=6QE(@IM<V=S='(@(DQI9VYE(&AO<FEZ;VYT86QE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(E)E;7!L:7-S86=E(&AO
M<FEZ;VYT86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N
M=&%LH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D-O;6UE;G0@ZG1E<RUV;W5S(&%R
M<FEVZ2!I8VF@/R`H4U90(')A<'!O<G1E>BUL9:`A*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(D-O;6)I96X@9&4@8V]L;VYN97,@=F]U;&5Z+79O=7,@9G5S:6]N
M;F5RH#\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I
M9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S
M='(@(D-O;6)I96X@9&4@8VAA;7!S("AC;VQO;FYE<RD@>2!A+70M:6R@/R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(D-O;6)I96X@9&4@<F%N9^EE<R!V;W5L97HM=F]U
M<R!F=7-I;VYN97*@/R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<*;7-G:60@(DAU;6ED:71Y
M(@IM<V=S='(@(DAU;6ED:73I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")(=6UI9&ET
MZ:`Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M
M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T97,B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DAU;F=A<GDB"FUS9W-T<B`B2&]N9W)I92(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(LEC:&5C(&QO<G,@9&4@
M;&$@8W+I871I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H96,@;&]R
M<R!D92!L82!S=7!P<F5S<VEO;B!D92!L82!B;^YT92!)34%0H#H@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R("+)8VAE8R!L;W)S(&1E(&QA(&-RZ6%T:6]N(&1U('%U;W1A('-U<B!L
M82!B;^YT92!)34%0H#H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S$S"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@25`B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED
M("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%D<F5S<V4@
M25`@;F]N(&1I<W!O;FEB;&4N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L
M;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B061R97-S92!)4"!H;W)S(&1U
M(&)L;V,@0TE$4B!A;&QO=>DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V
M:6]L871I;VXN(@IM<V=S='(@(E9I;VQA=&EO;B!D92!B;&]C86=E($E0+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(DE?
M;G/I<F5R(')A;F?I92!A=F%N="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("))<VQA;F1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("))8_1N97,@<V5U
M;&5M96YT(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("))8_1N97,@<&]U
M<B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC
M;VYS('=I=&@@=&5X="(*;7-G<W1R("))8_1N97,@<&QU<R!T97AT92(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@
M;F%M93HB"FUS9W-T<B`B3F]M(&1U(&-O;7!T9:`Z(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G
M:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O
M<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@HB4VD@;"=A9F9I
M8VAA9V4@;B=E<W0@<&%S(&-O<G)E8W0L("5S('!O=7(@;"=O=79R:7(@9&%N
M<R!U;F4@;F]U=F5L;&4@9F5NZG1R92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N
M<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H
M96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN
M(@IM<V=S='(@(B(*(E-I('9O=7,@;F4@=F]Y97H@875C=6X@:6/T;F4@96X@
M=71I;&ES86YT($EN=&5R;F5T($5X<&QO<F5R+"!V;W5S('!O=79E>B`B"B)A
M=F]I<B#@(&-O8VAE<B!C971T92!C87-E('!O=7(@9.ES86-T:79E<B!L82!T
M<F%N<W!A<F5N8V4@9&5S(%!.1RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H
M:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T
M;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BXB"FUS9W-T<B`B(@HB4VD@=F]U<R!V;WEE>B!C92!M97-S86=E(&UA:7,@
M875C=6YE(&EM86=E+"!L)VEM86=E('%U92!V;W5S('9O=6QE>B!E;G9O>65R
M("(*(FYE('!E=70@ZG1R92!A9F9I8VCI92!P87(@=F]T<F4@;F%V:6=A=&5U
M<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@
M(D%P97+G=2!D92!L)VEM86=EH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`B061R97-S92!54DP@9&4@;"=I;6%G92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM
M<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")!9')E<W-E(%523"!D92!L)VEM
M86=EH#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*
M;7-G<W1R("));6%G92!D92!L)V%L8G5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("))
M;6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DEM86=E(&1E(&PG86QB=6V@
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-3@*;7-G:60@(DEM
M86=E('5P;&]A9"(*;7-G<W1R(")4Z6SI8VAA<F=E;65N="!D)VEM86=E<R(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS
M9W-T<B`B26UA9V5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T
M<B`B26UP;W)T871I;VXL(.ET87!E("5D(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@
M9FEE;&0Z("5S(@IM<V=S='(@(D-H86UP(&EM<&]R=.F@.B`E<R(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I
M96QD<SHB"FUS9W-T<B`B0VAA;7!S(&EM<&]R=.ESH#HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G
M:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(DEN7W/I<F5R(')A;F?I
M92!A<'+H<R(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R(")#;V1E(&0G86-T:6]N(&EN8V]R<F5C="XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B
M26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B
M3F]M(&0G=71I;&ES871E=7(@970O;W4@=F]T<F4@;6]T(&1E('!A<W-E(&EN
M8V]R<F5C="XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B).;VT@
M9"=U=&EL:7-A=&5U<B!O=2!A9')E<W-E(&%L=&5R;F%T:79E(&EN8V]R<F5C
M="X@(%+I97-S87EE>B!O=2!C;VYT86-T97H@(@HB=F]T<F4@861M:6YI<W1R
M871E=7(@<WES=.AM92!P;W5R(&1E(&PG86ED92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`B075G;65N=&5R(&PG:6YD96YT871I;VXB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM<V=S='(@(DEN9&4B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G
M<W1R(")5=&EL:7-A=&5U<G,@:6YD:79I9'5E;',B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;NES:64B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("))
M;F9O(@IM<V=S='(@(DEN9F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4Y"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA=&EO
M;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS9VED
M("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("),
M)VEN9F]R;6%T:6]N(&XG97-T('!L=7,@9&ES<&]N:6)L92XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*
M;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN<^ER97(@
M8U]O;&]N;F4@87!RZ',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G
M92(*;7-G<W1R("));G/I<F5R(&EM86=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B26YS97)T(%1A8FQE
M(@IM<V=S='(@(DEN<^ER97(@=6X@=&%B;&5A=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!7
M96(@3&EN:R(*;7-G<W1R("));G/I<F5R('5N(&QI96X@=V5B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T
M"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B26YSZ7)E
M<B!?8V]L;VYN92!A=F%N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YSZ7)E
M<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A<'+H<R!L82!C;VQO;FYE(&%C='5E
M;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YSZ7)E<B!U;F4@;F]U=F5L
M;&4@8V]L;VYN92!A=F%N="!L82!C;VQO;FYE(&%C='5E;&QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("));G/I<F5R('5N92!N;W5V96QL92!R86YGZ64@87!RZ',@
M;&$@<F%N9^EE(&%C='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YSZ7)E
M<B!U;F4@;F]U=F5L;&4@<F%N9^EE(&%V86YT(&QA(')A;F?I92!A8W1U96QL
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B26YSZ7)E<B!U;B!P87)A9W)A<&AE
M(&%P<NAS(&QE(&XF;V5L:6<[=60@86-T=65L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS
M9W-T<B`B26YSZ7)E<B!U;B!P87)A9W)A<&AE(&%V86YT(&QE(&XF;V5L:6<[
M=60@86-T=65L(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@
M(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YSZ7)E<B!U
M;B!A=71R92!M;V3H;&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0R
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@HB26YS
M8W)I=F5Z('5N92!A9')E<W-E(&1E(&-O=7)R:65R(.`@;&%Q=65L;&4@=F]U
M<R!R96-E=G)E>B!L92!N;W5V96%U(&UO="!D92`B"B)P87-S9:`Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M.`IM<V=I9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YSZ7)E<B!C
M96QL=6QE(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E
M(@IM<V=S='(@(DEN<^ER97(@8V5L;'5L92!A=F%N="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@
M(DEN<V5R="!C;VQU;6X@869T97(B"FUS9W-T<B`B26YSZ7)E<B!C;VQO;FYE
M(&%P<NAS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS
M9W-T<B`B26YSZ7)E<B!C;VQO;FYE(&%V86YT(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E
M<R(*;7-G<W1R("));G/I<F5R(&QE<R!M97-S86=E<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));G/I<F5R('!A
M<F%G<F%P:&4@87!RZ',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@8F5F;W)E(@IM<V=S='(@(DEN<^ER97(@<&%R86=R87!H92!A=F%N="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B26YSZ7)E
M<B!R86YGZ64@87!RZ',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R
M92(*;7-G<W1R("));G/I<F5R(')A;F?I92!A=F%N="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B26YS
M8W)I=F5Z(&QA('+I<&]N<V4@X"!L82!Q=65S=&EO;B!D92!SZ6-U<FETZ:`Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-@IM<V=I9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));G/I<F5R
M+TUO9&EF:65R('5N92!I;6%G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("));G/I<F5R+TUO9&EF:65R('5N(&QI96X@=V5B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D-RZ61I="!I;G-U9F9I<V%N="!P
M;W5R(&5N=F]Y97(@X"!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(D-RZ61I="!I
M;G-U9F9I<V%N="XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<R
M"FUS9VED("));G1E9V5R(@IM<V=S='(@(D5N=&EE<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,S`*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G
M<W1R("),:7-T92!C;VUP;.AT92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B541(("A5<V5R($1A=&$@
M2&5A9&5R*2!I;G9A;&ED92(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@
M(D1O;F[I92!:25`@:6YV86QI9&4N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B
M07!P;&EC871I;VX@:6YV86QI9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A
M=&-H($E$+B(*;7-G<W1R(")'<F]U<&4@240@:6YV86QI9&4N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,34U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,CD@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+B(*;7-G<W1R(")%;G9O:2!D92!D;VYNZ65S(&EN=F%L:61E
M<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M"FUS9W-T<B`B061R97-S92!D92!D97-T:6YA=&EO;B!I;G9A;&ED92XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")&;W)M870@9&4@9FEC:&EE
M<B!I;G9A;&ED92XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")#;&5F
M(&1E(&QI8V5N8V4@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B16UP;&%C96UE;G0@:6YD:7%UZ2!I;G9A;&ED92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(JMM<V=?='EP
M9;L@:6YV86QI9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@
M87!I7VED+B(*;7-G<W1R("*K87!I7VEDNR!I;G9A;&ED92!O=2!M86YQ=6%N
M="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+B(*;7-G<W1R(")087)A;>AT<F5S(&EN=F%L:61E<R!O=2!M86YQ=6%N=',N
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")097)M:7-S:6]N(&EN
M=F%L:61E+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*
M;7-G:60@(DEN=F%L:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B260N(&1E('!A
M<G1E;F%I<F4@:6YV86QI9&4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S
M='(@(D-O9&4@9&4@<')O9'5I="!I;G9A;&ED92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN
M=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(E!R;W1O8V]L92!I;G9A;&ED92XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(D1E<W1I;F%T86ER92!I;G9A;&ED9:`Z(*N@)7.@NR(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`X,"!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S
M='(@(D]B:F5T(&1E('!A<G1A9V4@:6YV86QI9&4B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN
M=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D%D<F5S<V4@<V]U<F-E
M(&EN=F%L:61E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N
M(@IM<V=S='(@(D1O;F[I92!5;FEC;V1E(&EN=F%L:61E+B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS-3D*;7-G:60@(DEN=F5N=&]R>2(*;7-G
M<W1R("));G9E;G1A:7)E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G
M<W1R("));G9E<G-E<B!L82!SZ6QE8W1I;VXB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B27)A;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O
M9B!-86XB"FUS9W-T<B`BSFQE(&1E($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T
M;W)M<R(*;7-G<W1R(")496UPZG1E<R!I<V]LZ65S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED("))<W)A96PB"FUS9W-T<B`B27-R8>ML(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G
M<W1R("+);65T=&5U<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DET86QI<75E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("))=&%L:64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M8>]Q
M=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YV:65R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!O;B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I
M(@IM<V=S='(@(DIA<&]N86ES("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@
M(DIE<G-E>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@
M(DIO<F1A;FEE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5I;&QE="(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*
M=6YE(@IM<V=S='(@(DIU:6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S
M='(@(DIU<W1I9FEE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*
M;7-G<W1R(")#96YT<F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*
M;7-G<W1R(")*=7-T:69I97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T
M(@IM<V=S='(@(D%L:6=N97(@X"!G875C:&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S
M=&EF>2!2:6=H="(*;7-G<W1R(")!;&EG;F5R(.`@9')O:71E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%K:'-T86XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8U
M"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")'87)D97(@;"=O<FEG
M:6YA;*`_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+
M96YY82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G
M:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3&4@<V5R=F5U<B!+97)B97)O<R!A(')E:F5TZ2!L)V%U=&AE
M;G1I9FEC871I;VXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS
M9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(")$Z6)U=&%N=',@9'4@;F]Y
M874B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G
M:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(")#<NEA=&EO;B!D92!C;&5F(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+
M97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B16UP<F5I;G1E(&1E(&QA(&-L968B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(DME>2!,96YG=&@B"FUS9W-T<B`B3&]N9W5E=7(@9&4@;&$@8VQE9B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y
M(%1Y<&4B"FUS9W-T<B`B5'EP92!D92!C;&5F(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R(")5=&EL:7-A=&EO;B!D92!L82!C;&5F(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES
M=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(DQA(&-L968@
M<V4@=')O=79E(&3I:N`@<W5R(&QE('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*
M;7-G<W1R(")%;F9A;G1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M0V]RZ64@9'4@3F]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(D-O<NEE(&1U(%-U9"(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T
M<B`B0V]RZ65N("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A
M:70B"FUS9W-T<B`B2V]W9>]T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G
M>7IS=&%N(@IM<V=S='(@(DMI<F=H:7II<W1A;B(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")0<NE?
M<V5N=&%T:6]N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM
M<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B3&%N9W5E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G
M<W1R("),86]S(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B
M3&%S="!(86QF(@IM<V=S='(@(D1E<FYIZ')E(&1E;6EE(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG
M92(*;7-G<W1R(")$97)N:>AR92!M;V1I9FEC871I;VX@9'4@;6]T(&1E('!A
M<W-E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N
M+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(D1E<FYI97(@
M<75A<G1I97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B
M3&%S="!5<&1A=&5D.B(*;7-G<W1R(")$97)N:>AR92!M:7-E(.`@:F]U<J`Z
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L('!H<"UF;W)M
M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(D1E<FYIZ')E(&-O
M;FYE>&EO;J`Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B
M"FUS9W-T<B`B1&5R;FGH<F4@8V]N;F5X:6]NH#H@)7,@X"!P87)T:7(@9&4@
M)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@(DQA
M<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(D1E<FYIZ')E(&-O;FYE>&EO;J`Z
M(&IA;6%I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@
M(DQE='1O;FEE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED
M("),87<B"FUS9W-T<B`B3&]I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T
M<B`B4'+I<V5N=&%T:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O
M<F1E<B(*;7-G<W1R("),86ES<V5R('9I9&4@<&]U<B!N92!P87,@879O:7(@
M9&4@8F]R9'5R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G
M<W1R("),:6)A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")'875C:&4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DX"FUS9VED("),969T
M(&AE861E<B(*;7-G<W1R(")%;G3J=&4@9V%U8VAE(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S`Y-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T
M<B`B5F%L975R<R!D92!G875C:&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE
M<V]T:&\B"FUS9W-T<B`B3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B3FEV96%U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B
M"FUS9W-T<B`B3&EB>64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N
M<W1E:6XB"FUS9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(D)R=6EN92!LZ6?H<F4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*
M;7-G<W1R(")0;'5I92!LZ6?H<F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*
M;7-G<W1R(")0;'5I92!LZ6?H<F4@=/1T(&1A;G,@;&$@:F]U<F[I92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED
M("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B4&QU:64@;.EGZ')E('1A<F0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B079E<G-E<R!LZ6?H
M<F5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(E!L
M=6EE(&SI9^AR92!A=F5C('1O;FYE<G)E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS
M9W-T<B`B3F5I9V4@:6YT97)M:71T96YT92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H
M;W=E<B(*;7-G<W1R(")!=F5R<V4@9&4@;F5I9V4@;.EGZ')E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R
M(")2:6UE<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3$*;7-G
M:60@(DQI;FLB"FUS9W-T<B`B3&EE;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P
M;VEN=',@=&\Z(@IM<V=S='(@(DQE(&QI96X@<&]I;G1E('9E<G.@.B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S(*;7-G:60@(DQI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<B"FUS9W-T<B`B(@HB3&EE(&PG861R97-S92!D92!C;W5R<FEE;"#@
M(&QA('!A9V4@9&4@8V]M<&]S:71I;VX@9'4@;65S<V%G92!E;B!L)V%F9FEC
M:&%N="(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T
M97AT+G!H<#HQ.#(*;7-G:60@(DQI;FMS(@IM<V=S='(@(DQI96YS(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B
M"FUS9W-T<B`B0FES8W5I="!,:6YU>"(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C0V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&4@+2!U=&EL:7-A=&5U<B!P975T
M('9O:7(@;&4@9&]S<VEE<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S0*
M;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(DQI<W1E(&1E<R!B87-E
M<R!D92!D;VYNZ65S(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B26YD97@@9&4@;"=A
M:61E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!4
M86)L97,B"FUS9W-T<B`B069F:6-H97(@;&5S('1A8FQE<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R
M8VAI=F4B"FUS9W-T<B`B07)C:&EV97,@9&4@;&$@;&ES=&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(
M96QP(@IM<V=S='(@(D%I9&4@9&4@;&$@;&ES=&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U)9"(*;7-G
M<W1R("))9"X@9&4@;&$@;&ES=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R(")0
M<F]P<FGI=&%I<F4@9&4@;&$@;&ES=&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@
M(D5N=F]I(.`@;&$@;&ES=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B
M06)O;FYE;65N="#@(&QA(&QI<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.3`*;7-G:60@(DQI<W0M56YS=6)S8W)I8F4B"FUS
M9W-T<B`B1.ES86)O;FYE;65N="!D92!L82!L:7-T92(*"B,Z(&%D;6EN+W-E
M<W-I;VYS+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E
M<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`BR6-H96,@9&4@;&$@;&ES=&4@
M9&5S('-E<W-I;VYSH#H@)7,B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S
M(@IM<V=S='(@(LEC:&5C(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A=&5U<G.@
M.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM
M<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B3"=A
M9F9I8VAA9V4@9&4@;&$@;&ES=&4@9&5S('5T:6QI<V%T975R<R!E<W0@9.ES
M86-T:7;I+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B
M3&ET97)A='5R92(*;7-G<W1R("),:71TZ7)A='5R92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='5A;FEE(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B
M3&]A9&EN9RXN+B(*;7-G<W1R(")#:&%R9V5M96YT+BXN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C86P@=&EM93H@
M(@IM<V=S='(@(DAE=7)E(&QO8V%L9:`Z("(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(DAE
M=7)E(&5T(&QO8V%L92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PHC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW
M,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&EE=2(*"B,Z(&QO9VEN+G!H
M<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T
M97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@
M(DQO9R!I;B(*;7-G<W1R(")#;VYN97AI;VXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U<R!S>6YC
M('-E<W-I;VXB"FUS9W-T<B`B5')A8V4@9&4@;&$@9&5R;FGH<F4@<V5S<VEO
M;B!D92!S>6YC:')O;FES871I;VXB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D3I8V]N;F5X
M:6]N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I
M;B(*;7-G<W1R(")#;VYN97AI;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R(")4XF-H97,@9&4@
M8V]N;F5X:6]N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS
M9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B),
M82!C;VYN97AI;VX@97-T(')E9G5SZ64N($EL(&5S="!P<F]B86)L92!Q=64@
M=F]T<F4@;F]M(&0G=71I;&ES871E=7(@;W4@(@HB=F]T<F4@;6]T(&1E('!A
M<W-E(&$@Z73I(&UA;"!S86ES:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("+)8VAE8R!D
M92!C;VYN97AI;VXN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M,@IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E1E>'1E(&QO;F<B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B
M06UO=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.0IM<V=I9"`B3&]W(@IM<V=S='(@(D9A:6)L92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G
M:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B3&5T=')E(&=R96-Q
M=65S(&UI;G5S8W5L97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L
M971T97)S(@IM<V=S='(@(DQE='1R92!L871I;F5S(&UI;G5S8W5L97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DYO
M;6)R92!R;VUA:6YS(&UI;G5S8W5L97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQU>&5M8F]U<F<B"FUS9W-T<B`B3'5X96UB;W5R9R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DUE
M<W-A9V4@9'4@:F]U<B`H34]41"DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT
M(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("),82!P:>AC92!J;VEN=&4@
M35,M5$Y%1B!N92!C;VYT96YA:70@875C=6YE(&1O;F[I92XB"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E+I<'5B;&EQ=64@9&4@36%CZ61O:6YE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S='(@(DUA9&%G87-C
M87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC
M(@IM<V=S='(@(DUA9VEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C@S"FUS9VED(")-86EL(@IM<V=S='(@(D-O=7)R:65R(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G
M<W1R(")!9&UI;FES=')A=&EO;B!D=2!C;W5R<FEE;"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I
M9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R(")&86ER92!U;B!L:65?;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%W:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L86ES:64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&1I
M=F5S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S='(@(DUA;'1E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED("(B"B)-86YA9V4@
M=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M
M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C
M871E9V]R:65S+B(*;7-G<W1R("(B"B)!9&UI;FES=')E>B!L82!L:7-T92!D
M92!C873I9V]R:65S(&5T(&QE<R!C;W5L975R<R!L:>EE<R#@(&-E<R!C873I
M9V]R:65S+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,34V"FUS9VED(")-87`R-"!M87`B"FUS9W-T<B`B0V%R=&4@JR!-
M87`R-""[(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")#87)T92"K
M($UA<'%U97-T(+LB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ
M,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B0V]R<F5S<&]N
M9&%N8V5S(&5N<F5G:7-T<NEE<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G92(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R<75E<B!A=F5C
M(&1E<R#I=&EQ=65T=&5S(%9U+TYO;B!V=2(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")-87)Q
M=65R(&%V96,@9"=A=71R97,@Z71I<75E='1E<R`H97@N.B!);7!O<G1A;G0O
M4NEP;VYD=2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N
M9',B"FUS9W-T<B`BSFQE<R!-87)S:&%L;"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I
M9"`B36%R=&EN:7%U92(*;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD
M<R(*;7-G<W1R(")#:&%M<',@87!P87)E;G3I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R(")-875R:71A;FEE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`BSFQE($UA=7)I8V4B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,34*;7-G:60@(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B0W+I
M9&ET(&UA>&EM=6T@86QL;W7I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(DQI;6ET92!D=2!M97-S86=E(&3I
M<&%S<^EE+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B5&5M<.ER871U<F4@
M;6%X:6UA;&4@9&5S(#(T(&1E<FYIZ')E<R!H975R97.@.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B5&5M<.ER871U<F4@;6%X:6UA;&4@9&5S(#8@9&5R
M;FGH<F5S(&AE=7)E<Z`Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(DYO;6)R
M92!M87AI;75M(&1E(&)L;V-S(&1U('!O<G1A:6PB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX.34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,V"FUS9VED(")-87AI
M;75M(&QE;F=T:"(*;7-G<W1R("),;VYG=65U<B!M87AI;75M(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA
M>2(*;7-G<W1R(")-86DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E
M(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(DWI9&EC86UE;G0B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB
M97)S(@IM<V=S='(@(DUE;6)R97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(E1Y<&4@9&4@;65N
M=:`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B1G5S:6]N
M;F5R(&QE<R!C96QL=6QE<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S
M='(@(DUE<W-A9V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L
M;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@
M(@HB=F5R:69I960N(@IM<V=S='(@(B(*(E;I<FEF:6-A=&EO;B!D=2!M97-S
M86=E('+I=7-S:64L(&UA:7,@;&4@8V5R=&EF:6-A="!D=2!S:6=N871A:7)E
M(&XG82!P87,@<'4@(@HBZG1R92!VZ7)I9FGI+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S
M<V%G92!E>'!I<F5D+B(*;7-G<W1R(")-97-S86=E(&5X<&ERZ2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P
M,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B5'EP92!D
M92!M97-S86=E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-
M971A<B!796%T:&5R(@IM<V=S='(@(DWI=.EO($UE=&%R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B3&4@8FQO8R"K($UE=&%R(+L@;B=E<W0@<&%S(&1I
M<W!O;FEB;&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@
M(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B
M965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*
M(DQE(&)L;V,@JR!-971A<B"[(&XG97-T('!A<R!D:7-P;VYI8FQE+B`@3&5S
M(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@<&]U<B`B"B)L)V%D;6EN:7-T
M<F%T975R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3,*
M;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B365T
M87)$0B!N)V5S="!P87,@8V]N;F5C=.DN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B3>ET:&]D
M92(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W
M;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B3&$@;>ET
M:&]D92"KH"5SH+L@;B=E<W0@<&%S(&3I9FEN:64B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H
M;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(DWI
M=&AO9&4@;F]N(&3I9FEN:64N($WI=&AO9&4@87!P96SI9:`Z("5S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M971A
M<BYP:'`Z.#(*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Z71R:7%U92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(DUE>&EQ=64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B(*;7-G<W1R("+)=&%T<R!FZ63I<NES(&1E($UI8W)O;NES:64B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")-:6QI974B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4
M>7!E(@IM<V=S='(@(E1Y<&4@34E-12(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S$W"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T
M<B`B5&5M<.ER871U<F4@;6EN:6UU;2!D97,@,C0@9&5R;FGH<F5S(&AE=7)E
M<Z`Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`Y"FUS9VED(")-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UPZ7)A='5R92!M:6YI
M;75M(&1E<R`V(&1E<FYIZ')E<R!H975R97.@.B`B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R
M9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("),82!D=7+I92!M
M:6YI;6%L92!D=2!M;W0@9&4@<&%S<V4@;B=A('!A<R!E;F-O<F4@97AP:7+I
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M-0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(DUI<F]I<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R
M(")687)IZ7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="XB"FUS9W-T<B`B3&4@<&%Q=65T86=E($A45%!?<F5Q=65S
M="!014%2(&5S="!M86YQ=6%N="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3$U"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H
M879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI
M<R`B"B)A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A=&EO;B!I
M;F5X:7-T86YT92X@5F]U<R!D979E>B!L82!GZ6[I<F5R(&UA:6YT96YA;G0@
M<VD@=F]U<R!V;W5L97H@(@HB=71I;&ES97(@8V5T=&4@87!P;&EC871I;VXN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@(DE$
M(&1U(&UE<W-A9V4@;6%N<75A;G0N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(DQE('!A<75E
M=&%G92!014%2($UA:6P@97-T(&UA;G%U86YT+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("))1"!D92!S97-S:6]N(&UA;G%U
M86YT+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DQU(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R(")#
M;W5R<FEE;"!S86YS(&9I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*;7-G<W1R(")-;V3I
M<NDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D
M:69I960@1&%T92(*;7-G<W1R(")$871E(&1E(&UO9&EF:6-A=&EO;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R(")-;V1I9FEE<B!L)U52
M3"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<T"FUS
M9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B36]L9&%V:64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R(")-;VYA8V\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O
M;&EE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X,0IM<V=I9"`B
M36]N=&@@86YD('EE87(B"FUS9W-T<B`B36]I<R!E="!A;F[I92(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@
M(DUO;G1H;'DB"FUS9W-T<B`B365N<W5E;&QE;65N="(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS
M9VED(")-;V]N(%!H87-E<R(*;7-G<W1R(")0:&%S97,@9&4@;&$@;'5N92(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R
M92!F:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E
M9"XB"FUS9W-T<B`B0VAA;7!S('-U<'!LZ6UE;G1A:7)E<R!T<F]U=NES(.`@
M;&$@;&EG;F4@)60@*&%T=&5N9'5S("5D*2XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;V,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R
M(@IM<V=S='(@(D?I;NER86QE;65N="!E;G-O;&5I;&SI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L
M>2!#;&]U9'DB"FUS9W-T<B`B1^ENZ7)A;&5M96YT(&YU86=E=7@B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B
M36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B4')I;F-I<&%L96UE
M;G0@;G5A9V5U>"!E="!V96YT975X(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G
M<W1R(")'Z6[I<F%L96UE;G0@96YS;VQE:6QLZ2(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B5F5R<R!L92!B87,B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,@IM<V=I9"`B36]V92!,
M969T(@IM<V=S='(@(D3I<&QA8V5R(.`@9V%U8VAE(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@(DUO
M=F4@4FEG:'0B"FUS9W-T<B`B1.EP;&%C97(@X"!D<F]I=&4B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I
M9"`B36]V92!5<"(*;7-G<W1R(")697)S(&QE(&AA=70B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E
M(&1O=VXB"FUS9W-T<B`B5F5R<R!L92!B87,B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G:60@(DUO=F4@=7`B"FUS
M9W-T<B`B5F5R<R!L92!H875T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA
M;6)I<75E(@IM<V=S='(@(DUO>F%M8FEQ=64B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3@Q"FUS9VED(")-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',B"FUS9W-T<B`B3&ES=&5S(&3I<F]U;&%N=&5S(&UU;'1I+6YI=F5A
M=7@B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`U.0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(D-A<G1E(*N@
M375L=&EM87`@54N@NR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M,SD*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")3Z6QE8W1I
M;VX@;75L=&EP;&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`R
M"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(E!A<F%MZ71R86=E(&1U(&-O
M;7!T92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@
M06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")-97,@9&]N;NEE<R!P97)S
M;VYN96QL97,B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS
M9VED(")->2!0;W)T86PB"FUS9W-T<B`B36]N('!O<G1A:6PB"@HC.B!S97)V
M:6-E<R]P;W)T86PO961I="YP:'`Z-#,*;7-G:60@(DUY(%!O<G1A;"!,87EO
M=70B"FUS9W-T<B`B4'+I<V5N=&%T:6]N(&1E(&UO;B!P;W)T86EL(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(D)I<FUA;FEE(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*
M;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").3TXL(&IE(&XG
M86-C97!T92!P87,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM
M<V=I9"`B3F%M92(*;7-G<W1R(").;VTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYE<&%L(@IM<V=S='(@(D[I<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M971H97)L86YD<R(*;7-G<W1R(")087ES+4)A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")!;G1I;&QE<R!N
MZ65R;&%N9&%I<V5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(E52
M3"!D92!B87-E(&1E($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I
M;VX@55),(@IM<V=S='(@(E523"!D92!RZ79O8V%T:6]N(&1E(&PG02Y#+B!.
M971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(E52
M3"!D92!L82!P;VQI=&EQ=64@9"=!+D,N($YE='-C87!E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E
M(%)E;F5W86P@55),(@IM<V=S='(@(E523"!D92!R96YO=79E;&QE;65N="!.
M971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@S"FUS9VED(").971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(")5
M4DP@9&4@<NEV;V-A=&EO;B!.971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!34TP@<V5R
M=F5R(&YA;64B"FUS9W-T<B`B3F]M(&1U('-E<G9E=7(@4U-,($YE='-C87!E
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B0V]M
M;65N=&%I<F4@9'4@8V5R=&EF:6-A="!.971S8V%P92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!C
M97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E1Y<&4@9'4@8V5R=&EF:6-A="!.
M971S8V%P92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G
M:60@(DYE='=O<FLB"FUS9W-T<B`B4NES96%U(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M,SD*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B2F%M86ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L
M961O;FEA(@IM<V=S='(@(DYO=79E;&QE+4-A;.ED;VYI92(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED
M(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]U=F5L;&4@8V%TZ6=O<FEE(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV
M."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G
M<W1R(").;W5V96QL92!L=6YE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB
M"FUS9W-T<B`B3F]U=F5A=2!N;VT@9&4@8V]N;F5X:6]N("AF86-U;'1A=&EF
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B
M3F]U=F5L;&4M6NEL86YD92(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYO=79E874@
M;6]T(&1E('!A<W-E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP
M.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E
M>'!I<F4@;VX@)7@N(@IM<V=S='(@(DQE(&YO=79E874@;6]T(&1E('!A<W-E
M(&5X<&ER97)A(&QE("5X+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS
M9W-T<B`B3&5S(&YO=79E875X(&UO=',@9&4@<&%S<V4@9&EF9NAR96YT+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*
M;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B3F]U=F5L;&4@
M9F5NZG1R92`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYO=79E;&QE<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B1F]R=6US(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B4W5I=F%N="(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H87-E
M<R(*;7-G<W1R("(T('!H87-E<R!S=6EV86YT97,B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(D]P=&EO
M;G,@<W5I=F%N=&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ
M,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(E-U:79A;G0^(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87)A9W5A(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6=E<FEA(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B
M"FUS9W-T<B`B3G5I="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G
M<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.CDV-@IM<V=I9"`B3F\B"FUS9W-T<B`B3F]N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+B(*;7-G<W1R("(B"B)087,@9&4@9&]N;NEE<R!D92!C;VYF:6=U<F%T:6]N
M('!O=7(@;&5S<75E;&QE<R!M;VYT<F5R(&QE<R!D:69FZ7)E;F-E<RXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM
M<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM
M86=E<RXB"FUS9W-T<B`B4&%S(&1E('-T<F%TZ6=I92!D:7-P;VYI8FQE('!O
M=7(@9F%I<F4@9&5S(&EM86=E<R!)4T\N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B871C
M:"!T96UP;&%T92XB"FUS9W-T<B`B4&%S(&1E(&=A8F%R:70@96X@=')A:71E
M;65N="!P87(@;&]T+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")!=6-U;B!B
M;&]C(&XG97AI<W1E(.`@;&$@<&]S:71I;VX@9&5M86YDZ64B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(")087,@9&4@;F]M(&1E(&-A;&5N9')I97(@9F]U<FYI('!O=7(@;"=A
M=71H96YT:69I8V%T:6]N('!A<B!-0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(DYO;B!M;V1I
M9FGI+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS
M9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S
M:6]N+B(*;7-G<W1R(")!=6-U;F4@<V]U<RUP97)M:7-S:6]N(&XG82!B97-O
M:6X@9"?J=')E(&%J;W5TZ64@<V]U<R!C92!N:79E874N(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S@@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3<*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B075C=6YE(&EN9F]R;6%T:6]N
M(&1E(&-O;F9I9W5R871I;VX@<W#I8VEF:>EE('!O=7(@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G
M<W1R(")!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R
M;FEE('!O=7(@1E10(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8W,@IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(D%U8W5N92!I;F9O<FUA
M=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!344P@5D93+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N(@IM<V=S='(@(D%U8W5N92!I;F9O<FUA=&EO;B!D92!C
M;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!344PM1FEL92!61E,N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$T
M"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B075C=6X@8W+I9&ET
M(&1I<W!O;FEB;&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@(DYO(&1E<W1I;F%T:6]N('-U<'!L
M:65D+B(*;7-G<W1R(")!=6-U;F4@9&5S=&EN871I;VX@=')O=7;I92XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,C`*;7-G:60@(DYO
M(&9I;&4@=7!L;V%D960B"FUS9W-T<B`B075C=6X@9FEC:&EE<B!E;G9O>>DB
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R(")!=6-U;B!I8_1N92!T<F]U=NDN(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,S`*;7-G:60@(DYO
M(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B075C=6X@;&EE=2!N)V5S="!S
MZ6QE8W1I;VYNZ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-3<*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")!=6-U
M;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M
M97-S86=E('-U<'!L:65D+B(*;7-G<W1R(")!=6-U;B!M97-S86=E(&9O=7)N
M:2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B075C
M=6X@;F]M('-PZ6-I9FGI+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF
M:65D+B(*;7-G<W1R(")!=6-U;B!N;VUB<F4@<W#I8VEF:>DN(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R
M='5N97,B"FUS9W-T<B`B4&%S(&0G87!H;W)I<VUE<R!C:&]Q=6%N=',B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N
M=&EF:6-A=&EO;B!P87(@2%144"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D92!P
M87-S92!F;W5R;FD@<&]U<B!L)V%U=&AE;G1I9FEC871I;VX@<&%R($E-05`N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@9&4@<&%S<V4@9F]U<FYI('!O=7(@
M;"=A=71H96YT:69I8V%T:6]N('!A<B!+97)B97)O<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R(")!=6-U;B!M;W0@9&4@<&%S<V4@<W#I8VEF
M:>D@<&]U<B!L)V%U=&AE;G1I9FEC871I;VXN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]P87-S=V0N<&AP.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B075C
M=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T
M:6]N(%!!4U-71"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(D%U8W5N(&UO="!D92!P87-S92!S<.EC:69I
MZ2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!334(N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+B(*;7-G<W1R("(B"B)!=6-U;B!C:&5M:6X@=F5R<R!L92!B:6YA:7)E
M($]P96Y34TP@9F]U<FYI+B!,92!B:6YA:7)E(&0G3W!E;E-33"!E<W0@(@HB
M;NEC97-S86ER92!P;W5R(&9O;F-T:6]N;F5R(&%V96,@9&5S(&1O;F[I97,@
M4$M#4R`Q,BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(D%U8W5N
M92!C;VYF:7)M871I;VX@96X@871T96YT92(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B4&%S
M(&1E('%U;W1A('!O<VET:6]N;NDN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B
M"FUS9W-T<B`B4&%S(&1E('+H9VQE<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB
M"FUS9W-T<B`B075C=6X@<^EP87)A=&5U<B!S<.EC:69IZ2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS
M9VED(").;R!S:61E<R(*;7-G<W1R(")087,@9&4@8_1TZ7,B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE
M(@IM<V=S='(@(D9I8VAI97(@:6YE>&ES=&%N="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B075C=6X@<NEP
M97)T;VER92!T96UP;W)A:7)E(&5S="!D:7-P;VYI8FQE('!O=7(@;&$@8V%C
M:&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M(@IM<V=S='(@(D%U8W5N(&YO;2!D)W5T:6QI<V%T975R(&5T("]O=2!M;W0@
M9&4@<&%S<V4@96YV;WGI+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*
M;7-G<W1R(")!=6-U;F4@9&]N;NEE(%A-3"!V86QI9&4@;B=A(.ETZ2!R971O
M=7)NZ64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(E!A<R!D92!V86QE=7(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB4&%S(&1E('9E<G-I;VX@
M=')O=7;I92!D86YS(&QA(&-O;F9I9W5R871I;VX@;W)I9VEN86QE+B!2Z6?I
M;NER97H@;&$@(@HB8V]N9FEG=7)A=&EO;BXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B)087,@9&4@=F5R<VEO;B!T<F]U=NEE(&1A;G,@=F]T<F4@8V]N
M9FEG=7)A=&EO;BX@4NEGZ6[I<F5Z(&QA(&-O;F9I9W5R871I;VXN(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N
M92(*;7-G<W1R(")!=6-U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB
M"FUS9W-T<B`B075C=6X@*'5T:6QI<V5R(&EM<&QI8VET96UE;G0I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X
M-3DM,3`I(@IM<V=S='(@(DYO<F1I<75E("A)4T\M.#@U.2TQ,"DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(LYL92!.
M;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M
M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R
M(")(Z6UI<W!HZ')E($YO<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("+.;&5S($UA<FEA;FYE<R!D
M=2!N;W)D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B
M3F]R=NAG92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0Q"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B4&%S(&%P<NAS(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO
M="!"969O<F4B"FUS9W-T<B`B4&%S(&%V86YT(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z-#$U"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS
M9W-T<B`B4&%S('5N(&1O<W-I97(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(N<&AP.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R
M871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU
M.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(").;VX@:6UP;.EM
M96YTZ2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(DEN86-T:68B"@HC.B!F
M<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$T
M-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N
M<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#@@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C(S-`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD*(SH@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(X-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S
M,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HT,C8*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P-2!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z-3<T"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HU.3$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V.0IM<V=I9"`B3F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B3F]N('!R:7,@96X@8V]M<'1E+B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`X(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#0*(SH@8V]N9FEG+VAO;VMS+G!H<"YD
M:7-T.C$P-3@@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X,`IM<V=I9"`B
M3F]T97,B"FUS9W-T<B`B3F]T97,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I
M;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+B(*;7-G<W1R(")2:65N(.`@;F%V:6=U97(L(')E=&]U<FYE>B!E;B!A<G)I
MZ')E+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)R92(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-#,*;7-G:60@(DYU;6)E<B(*;7-G
M<W1R(").;VUB<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(R
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(").;VUB<F4@
M9&4@8V%R86-TZ')E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0R('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G
M<W1R(").;VUB<F4@9&4@8V]L;VYN97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S8T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,"!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O
M=W,B"FUS9W-T<B`B3F]M8G)E(&1E(')A;F?I97,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B3F]M8G)E(&YO;B!S<.EC:69IZ2!P;W5R(&QA
M(&UI<V4@X"!J;W5R(&1E(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G
M:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B
M:F5T(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@
M(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D-RZ6%T975R(&0G;V)J970B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`Q"FUS9VED(")/8W1A;"(*
M;7-G<W1R(")/8W1A;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(D]C=&]B<F4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@
M9FEL=&5R(@IM<V=S='(@(D9I;'1R92!A;G1I+6]F9F5N<V%N="(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G
M<W1R(")"=7)E874B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="XB"FUS9W-T<B`B3"=A;F-I96X@970@;&4@;F]U=F5A=2!M;W1S(&1E
M('!A<W-E(&1O:79E;G0@ZG1R92!D:69FZ7)E;G1S+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM
M<V=S='(@(D%N8VEE;B!M;W0@9&4@<&%S<V4B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="XB"FUS9W-T<B`B3"=A;F-I96X@;6]T(&1E('!A<W-E(&5S="!I
M;F-O<G)E8W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B
M3VUA;B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+B(*;7-G<W1R(")3975L(&QE<R!S97)V975R<R!)34%0('-U<'!O
M<G1E;G0@;&5S(&1O<W-I97)S('!A<G1A9^ES+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B4V5U;&5M96YT(&QE<R"KH&9O<G1U;F5SH+L@;V9F96YS86YT
M97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-C@*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B56YE('-E=6QE(&%D<F5S<V4@9&4@
M8V]U<G)I96P@<&5R;6ES92XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(E-E=6QS(&QE('!R
M;W!R:>ET86ER92!O=2!L)V%D;6EN:7-T<F%T975R('-Y<W3H;64@<&5U="!M
M;V1I9FEE<B!L97,@(@HB<&5R;6ES<VEO;G,@9"=U;B!P87)T86=E+B(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")/=79R
M:7(@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R
M.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P
M87)T+B(*;7-G<W1R("(B"B)%<G)E=7(@3W!E;E-33*`Z(&EM<&]S<VEB;&4@
M9"=E>'1R86ER92!L97,@9&]N;NEE<R!D92!L82!P87)T:64@<VEG;NEE(%,O
M34E-12(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W
M('=I;F1O=R(*;7-G<W1R(")/=79R:7(@;&5S(&QI96YS(&1A;G,@=6YE(&YO
M=79E;&QE(&9E;NIT<F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B4WES=.AM92!D)V5X
M<&QO:71A=&EO;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-3$*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B3W!T:6]N<R(*"B,Z('-E<G9I
M8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R(")/
M<'1I;VYS('!O=7(@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M3&ES=&4@;G5MZ7)O=.EE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")/<F=A
M;FES871I;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")5;FET
MZ2!O<F=A;FES871I;VYN96QL92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI<V%T
M:6]N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I
M;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(DUO9.AL92!O<FEG
M:6YA;"!D)V%P<&QI8V%T:6]N(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.B(*;7-G<W1R(")-;V3H;&5S(&]R:6=I;F%U>"!D86YS("5SH#HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B075T<F4B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O
M<FUA=&EO;B(*;7-G<W1R(")!=71R97,@:6YF;W)M871I;VYS(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B4&5R;6ES<VEO;G,@9'4@<')O<')IZ71A:7)E(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3"=A
M=71H96YT:69I8V%T:6]N(%!!32!N)V5S="!P87,@9&ES<&]N:6)L92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*
M;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")-;V1U;&4@4$5!
M4CHZ36%I;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R
M-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")3:6=N
M871U<F4@;G5MZ7)I<75E(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G
M<W1R(")$;VYNZ65S(%!'4"!C:&EF9G+I97,B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")01U`@4'5B;&EC($ME>2(*
M;7-G<W1R(")#;&5F('!U8FQI<75E(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$B"FUS9W-T<B`B1&]N;NEE<R!01U`@<VEG;NEE<R]C:&EF9G+I
M97,B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD*;7-G:60@(E!(4"!#;V1E
M(@IM<V=S='(@(D-O9&4@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B26YT97)P<NET975R(%!(4"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS
M9VED(")032!,:6=H="!286EN(@IM<V=S='(@(E!L=6EE(&SI9^AR92!L)V%P
M<NAS+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.0IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")0;'5I92!L)V%P<NAS
M+6UI9&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")!=F5R<V5S(&PG87!R
MZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Q"FUS9VED(")032!3;F]W(@IM<V=S='(@(DYE:6=E(&PG87!RZ',M
M;6ED:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0R"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B0VAU=&5S(&1E
M(&YE:6=E(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B4V]L
M96EL(&PG87!RZ',M;6ED:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R(")/
M<F%G97,@;"=A<'+H<RUM:61I(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(W-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T
M<B`B17AT96YS:6]N(%!/4TE8(&%B<V5N=&4B"@HC.B!L:6(O87!I+G!H<#HQ
M-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B26YT97)P<NET975R(%!?
M2%`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(E)E;7!L:7-S86=E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R(")086MI
M<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(D)E
M;&%U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I;F4@*'1E<G)I=&]I<F4@
M;V-C=7#I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@
M(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R(")087!O=6%S:64M3F]U=F5L;&4M1W5I;NEE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U87DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")087)T:65L;&5M96YT(&YU86=E
M=7@B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$U"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(U"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")-;W0@9&4@<&%S<V4B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")#:&%N9V5M96YT
M(&1U(&UO="!D92!P87-S92!E9F9E8W1UZ2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W;W)D(&EN8V]R
M<F5C="(*;7-G<W1R(")-;W0@9&4@<&%S<V4@:6YC;W)R96-T(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B36]T(&1E('!A<W-E(')E<75I<R!P;W5R(&PG875T:&5N=&EF:6-A=&EO
M;B!2041)55,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,`IM
M<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B36]T
M(&1E('!A<W-E(&%V96,@8V]N9FER;6%T:6]N(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B
M36]T(&1E('!A<W-EH#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R(")-;W0@9&4@<&%S<V6@
M.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`S,0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B3&5S
M(&UO=',@9&4@<&%S<V4@9&]I=F5N="#J=')E(&ED96YT:7%U97,N(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(D-O;&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S
M='(@(D-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A<&EE<G,B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0
M871H(@IM<V=S='(@(D-H96UI;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D-O
M;F9I<FUA=&EO;G,@96X@871T96YT9:`Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B4&5R<V]N;F5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*
M;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4&]U<F-E;G1A9V4B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(D5F9F5C
M='5E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B169F96-T=65R(&QE
M<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B
M4&5R;6ES<VEO;B(*;7-G<W1R(")097)M:7-S:6]N(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S
M:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B3&$@<&5R;6ES<VEO
M;B"KH"5SH+L@;B=E<W0@<&%S('-U<'!R:6WI92XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4Y,`IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B
M"FUS9W-T<B`B4&5R;6ES<VEO;B!R969U<^EE(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W-I
M;VYS(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9&5S('!E
M<FUI<W-I;VYS(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED
M(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")$;VYNZ65S('!E<G-O
M;FYE;&QE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")0
MZ7)O=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T
M<R(*;7-G<W1R(")!;FEM875X(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL
M:7!P:6YE<R(*;7-G<W1R(")0:&EL:7!P:6YE<R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM
M<V=S='(@(E3I;.EP:&]N92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT.#`*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")0:&]T;W,B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C86ER;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS
M9VED(")0:7AE;',B"FUS9W-T<B`B4&EX96QS(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(E!L871I
M='5D97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E
M;&PB"FUS9W-T<B`B4U90(&-L:7%U97H@9&%N<R!U;F4@8V5L;'5L92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")35E`@8V]N9FER;65Z(&QA
M('-U<'!R97-S:6]N(&1E(&-E="#I;.EM96YTH#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@
M(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="XB"FUS9W-T<B`B4U90(&-O;F9I<FUE>B!Q=64@=F]U<R!V;W5L
M97H@9.EL:65R(&-E="#I;.EM96YT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U-3D*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A
M('EE87(N(@IM<V=S='(@(E9E=6EL;&5Z('-A:7-I<B!U;B!M;VES(&5T('5N
M92!A;F[I92XB"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE
M(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B5F5U:6QL97H@<V%I<VER('5N(&YO
M;2!P;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(Y.`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RXB"FUS9W-T<B`B5F5U:6QL97H@96YT<F5R('5N92!A
M9')E<W-E($E0('9A;&ED92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C,W"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B
M"B)6975I;&QE>B!E;G1R97(@=6YE(&1A=&4@=F%L:61EH#L@=NER:69I97H@
M;&4@;F]M8G)E(&1E(&IO=7)S(&1U(&UO:7,N("(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-#0*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED
M('1I;64N(@IM<V=S='(@(E9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@=F%L
M:61E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G
M:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB
M"FUS9W-T<B`B5F5U:6QL97H@9F]U<FYI<B!U;B!RZ7-U;>D@9'4@<')O8FSH
M;64N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y
M;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")6975I;&QE>B!F
M;W5R;FER('9O=')E(&YO;2!D)W5T:6QI<V%T975R(&5T('9O=')E(&UO="!D
M92!P87-S92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I
M9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@3553
M5"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB
M"FUS9W-T<B`B(@HB5F5U:6QL97H@;&ER92!L92!T97AT92!S=6EV86YT+B!6
M;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O=7(@(@HB=71I
M;&ES97(@;&4@<WES=.AM92XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R(")6975I;&QE>B!E;G1R97(@
M;&4@;F]U=F5A=2!N;VV@9&4@;&$@8V%TZ6=O<FEEH#HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQO9VYE(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VQI=&EQ=64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS
M9VED(")0;VQL<R(*;7-G<W1R(")38W)U=&EN<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1U9V%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(E!O
M<VET:6]N(&1E(&-E='1E(&EM86=E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B4&]S:71I;VX@9&4@8V4@=&%B;&5A=2(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED
M(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB
M"FUS9W-T<B`B16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO;B!A<'!L:7%UZ2!P
M87(@24U!4"DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I
M=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")0<NEC:7!I
M=&%T:6]N<R!P;W5R(&QE<R`E<R!D97)N:>AR97,@:&5U<F5SH#H@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R(")0<F]B86)I;&ETZ3QB<B`O
M/F1E('!L=6EE(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP
M.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87"@.B!E>'1E;G-I;VX@
M<F5Q=6ES92!,1$%0(&YO;B!T<F]U=NEE+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]S97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S:6]N
MH+L@;F]N('1R;W5VZ64N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S(*
M;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(E!R97-S:6]N(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E
M;#H@(@IM<V=S='(@(E!R97-S:6]N(&%U(&YI=F5A=2!D92!L82!M97*@.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0
M<F5S<W5R93H@(@IM<V=S='(@(E!R97-S:6]NH#H@(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G
M:60@(E!R979I97<B"FUS9W-T<B`B07!E<N=U(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED
M(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M07!E<N=U(&1E(&PG:6UA9V4@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R92(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I
M;VYS(@IM<V=S='(@(D]P=&EO;G,@<'+I8^ED96YT97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN
M="!D;V-U;65N="(*;7-G<W1R("));7!R:6UE<B!L92!D;V-U;65N="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B0VQE9B!P<FEVZ64B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(E!R;V)LZ&UE(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS
M9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:7!T:6]N
M(&1U('!R;V)LZ&UE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W
M,0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5T<R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#@@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$X-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<S"FUS9VED
M(")0<F]M<'0@=&5X="(*;7-G<W1R(")497AT92!C;W5R="(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME
M>2(*;7-G<W1R(")#;&5F('!U8FQI<75E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(D%L9V]R:71H;64@9&4@8VQE9B!P=6)L:7%U92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0
M=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B26YF;W)M871I;VYS('-U<B!L82!C
M;&5F('!U8FQI<75E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("+)8VAE8R!D92!L82!GZ6[I
M<F%T:6]N(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E+W!R:7;I92XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0
M;W)T;R!2:6-O(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(E!U<F=E
M<B!L97,@;65S<V%G97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*
M;7-G<W1R(")1871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I
M9"`B475E<GDB"FUS9W-T<B`B4F5Q=>IT92(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B475O=&$B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R(")#
M;&5F('!U8FQI<75E(%)302`H)60@8FET<RDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8Q"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T
M<B`B4^EL96-T:6]N(')A9&EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B4&QU:64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")0;'5I92!T]'0@;&4@;6%T:6XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM
M<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(E!L=6EE('1A<F0@9&%N<R!L82!J
M;W5R;NEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(D%V97)S97,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I
M9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")0;'5I92!E="!N96EG92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED
M(")286EN('1O(%-N;W<B"FUS9W-T<B`B4&QU:64@<'5I<R!N96EG92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N
M92(*;7-G<W1R(")!<&AO<FES;64@874@:&%S87)D(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")4
M875X(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*
M;7-G:60@(E)E860B"FUS9W-T<B`B3&ER92(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C0W"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM
M<V=S='(@(DUE<W-A9V5S(&QU<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G
M<W1R(")3=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E("5SH#\B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@HB4W5P
M<')E<W-I;VX@9.EF:6YI=&EV92!D97,@9&]N;NEE<R!P;W5R(&PG=71I;&ES
M871E=7(@)7.@/R!#971T92!O<.ER871I;VX@(@HB97-T(&3I9FEN:71I=F4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4F5P
M<F5N9')E('9O=')E(&1E<FYIZ')E(&%C=&EO;B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED
M(")2969R97-H(@IM<V=S='(@(E)A9G)A[F-H:7(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SHB"FUS9W-T<B`B4F%F<F'N8VAI<B!L97,@Z6SI;65N=',@9'4@
M;65N=2!D>6YA;6EQ=66@.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(E)A9G)A
M[F-H:7(@;"?I8W)A;B!D=2!S;VUM86ER9:`Z(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DQ(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,@IM<V=I9"`B4F5G97@B
M"FUS9W-T<B`B17AP<F5S<VEO;B!R871I;VYN96QL92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,R,C@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W
M<V5R(@IM<V=S='(@(DYA=FEG871E=7(@<F5L871I;VYN96PB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B4F5C:&%R9V5R
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B
M"FUS9W-T<B`B4F5M87)Q=65S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B4V5R=F5U<G,@
M9&ES=&%N=',B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*
M;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.B(*;7-G<W1R(")54DP@9&ES=&%N=&4@*&AT='`Z+R]W=W<N97AE;7!L
M92YC;VTO:&]R9&4O*:`Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR
M.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S
M"FUS9VED(")296UO=F4B"FUS9W-T<B`B4F5T:7)E<B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM
M<V=S='(@(E)E=&ER97(@;&4@8FQO8R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB
M"FUS9W-T<B`B4F5T:7)E<B!L82!C;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O
M<FUA='1I;F<B"FUS9W-T<B`B4F5T:7)E<B!L92!F;W)M871A9V4B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A
M:7(B"FUS9W-T<B`B4F5T:7)E<B!L82!P86ER92(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")%;FQE
M=F5R(&QE('-C<FEP="!E;G)E9VES='+I(&1U('+I<&5R=&]I<F4@=&5M<&]R
M86ER92!D=2!S97)V975R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B4F5M;W9E('1H92(*
M;7-G<W1R(")2971I<F5R(&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(E)E=&ER97(@8V4@
M;F]E=60@9'4@9&]C=6UE;G0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")2971I
M<F5R(&PG=71I;&ES871E=7(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z
M("5S(@IM<V=S='(@(E)E=&ER97(@;"=U=&EL:7-A=&5U<J`Z("5S(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E
M<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@
M(@IM<V=S='(@(D%U8W5N92!RZ7!O;G-E(.`@=F]T<F4@<F5Q=>IT92X@0V]D
M92!D)V5R<F5U<B!R971O=7)NZ:`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3&4@<V5R=FEC92!D96UA;F3I(&5S
M="!I;G1R;W5V86)L92XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$X-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B),92!P87)A;>AT<F4@;V)L
M:6=A=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O
M;F9I9W5R871I;VX@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-S@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<S,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3&4@<&%R86WH=')E(&]B;&EG871O
M:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@9&%N<R!L82!C;VYF:6=U
M<F%T:6]N(&1U("(*(E9&4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H
M<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB3&4@
M<&%R86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF
M:>D@9&%N<R!L82!C;VYF:6=U<F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I9"`B4F5Q=6ER960@1FEE;&0B
M"FUS9W-T<B`B0VAA;7`@;V)L:6=A=&]I<F4B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R(")2P%HB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B
M"FUS9W-T<B`B4F5M:7-E(.`@>NER;R!D=2!M;W0@9&4@<&%S<V4B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R(")296UE='1R92#@('KI<F\@=F]T<F4@;6]T
M(&1E('!A<W-E(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,0IM<V=I9"`B
M4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(E)E=F5N:7(@X"!L82!D97)N
M:>AR92!R97%UZG1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<R(&%D;6EN
M+V-M9'-H96QL+G!H<#HR.2!A9&UI;B]S<6QS:&5L;"YP:'`Z-C<*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`B4NES=6QT871S(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW
M"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")2979E;FER(&%U
M>"!O<'1I;VYS(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X
M"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E+I+65N=')E
M<B!L92!N;W5V96%U(&UO="!D92!P87-S92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E)E=6YI;VXB"FUS9W-T<B`B4NEU;FEO;B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I
M9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B4F5V96YI<B#@(&QA
M(&-O;F9I9W5R871I;VX@<'+I8^ED96YT92(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*
M;7-G<W1R(")/<'1I;VYS(&1E(&PGZ61I=&5U<B!2:6-H(%1E>'0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T
M<B`B1&5V:6YE='1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B1')O
M:71E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,`IM<V=I9"`B
M4FEG:'0@:&5A9&5R(@IM<V=S='(@(D5N=.IT92!D92!D<F]I=&4B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,#DV"FUS9VED(")2:6=H="!V86QU
M97,B"FUS9W-T<B`B5F%L975R<R!C;W)R96-T97,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@
M(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FGI=.ES(&1E(&QA
M(')A;E]GZ64@+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R(")2]&QE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2;W5M86YI92(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C8*
M;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B4&EV;W1E<B`Q.#`B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(S"FUS9VED
M(")2;W1A=&4@3&5F="(*;7-G<W1R(")0:79O=&5R(.`@9V%U8VAE(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I
M9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E!I=F]T97(@X"!D<F]I=&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FGI=.ES
M(&1E(&QA(')A;F?I92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM
M<V=S='(@(E!R;W!R:>ETZ7,@9&4@;&$@<F%N9^EE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z
M(@IM<V=S='(@(E)A;F?I97.@.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(E+H9VQE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B1&5S(&9I;&5T
M<R!A<'!A<F'N=')O;G0@96YT<F4@=&]U=&5S(&QE<R!R86YGZ65S(&5T(&QE
M<R!C;VQO;FYE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(D1E<R!F:6QE=',@87!P87)A
M[G1R;VYT(&5N=')E(&QE<R!C;VQO;FYE<R!S975L96UE;G0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G
M<W1R(")$97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N9^EE
M<R!S975L96UE;G0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q"FUS9VED
M(")2=6XB"FUS9W-T<B`B3&%N8V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B
M4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(E)U<W-I92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=V%N9&$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R92#I
M;&5C=')O;FEQ=64@4R]-24U%(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R(")-97-S86=E(&-H:69F<ND@4R]-24U%(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("),)V%U=&AE;G1I
M9FEC871I;VX@4T%33"!N)V5S="!P87,@9&ES<&]N:6)L92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@(E--4R!-97-S86=I;F<B
M"FUS9W-T<B`B365S<V%G97)I92!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("));G1E<G!RZ71E=7(@
M4U%,(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W,0IM<V=I9"`B
M4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")/<F1R
M92!344P@<&]U<B!R971O=7)N97(@;&5S('9A;&5U<G,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B"FUS9W-T<B`B4U-(
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")3
M54-#R%,B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB
M"FUS9W-T<B`B26YT97)P<NET975R(%-?44PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R
M(")382(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R(")386EN=&4M2.ELZ&YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN
M="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B4V%I;G0M0VAR:7-T;W!H92UE
M="U.:>EVZ',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM
M<V=S='(@(E-A:6YT92U,=6-I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B4V%I;G0M4&EE<G)E
M(&5T($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0M5FEN8V5N
M="UE="UL97,@1W)E;F%D:6YE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF
M*2(*;7-G<W1R(")-ZFUE(&-A9')E("A?<V5L9BDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")386UO82(*;7-G<W1R(")386UO82!O8V-I9&5N=&%L97,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A:6YT
M+4UA<FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R
M:6YC:7!E(@IM<V=S='(@(E-A;RU4;VWI+65T+5!R:6YC:7!E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E
M(%!R;W9I9&5R(@IM<V=S='(@(D9O=7)N:7-S975R('-A=&5L;&ET92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R(")!<F%B
M:64@4V%O=61I=&4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B16YR96=I<W1R97(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(D5N<F5G:7-T<F5R(*N@)7.@
MNR(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B16YR96=I<W1R97(@)7,B
M"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P
M=&EO;G,B"FUS9W-T<B`B16YR96=I<W1R97(@;&5S(&]P=&EO;G,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D5N
M<F5G:7-T<F5R(&QA(&-O;F9I9W5R871I;VX@9^ENZ7+I92!C;VUM92!U;B!S
M8W)I<'0@4$A0(&1A;G,@;&4@<NEP97)T;VER92`B"B)T96UP;W)A:7)E(&1E
M('9O=')E('-E<G9E=7(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B16YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E
M<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S
M7"(N(@IM<V=S='(@(E-C<FEP="!D92!M:7-E(.`@:F]U<B!D92!C;VYF:6=U
M<F%T:6]N(&5N<F5G:7-T<ND@<V]U<Z`Z(*L@)7.@NR(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")38V%T=&5R
M960@5"U3=&]R;7,B"FUS9W-T<B`B3W)A9V5S(&ES;VSI<R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")3
M8VEE;F-E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C
M:"(*;7-G<W1R(")296-H97)C:&4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(R"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")-;W1E
M=7)S(&1E(')E8VAE<F-H92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y-3(*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")#:&]I<VES<V5Z
M(&QE<R!F:6-H:65R<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B
M4^EL96-T:6]N;F5Z('5N92!D871E(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G
M<W1R(")3Z6QE8W1I;VYN97H@=6X@9W)O=7!E(.`@86IO=71E<B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE
M=R!O=VYE<B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=6X@;F]U=F5A=2!P<F]P
M<FGI=&%I<F4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*
M;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@
M=6X@<V5R=F5U<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R(")3Z6QE8W1I
M;VYN97H@=6X@=71I;&ES871E=7(@X"!A:F]U=&5R(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B4V5L96-T
M(&%L;"(*;7-G<W1R(")4;W5T('/I;&5C=&EO;FYE<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(V-#`*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=&]U=&5S(&QE<R!C
M;VUP;W-A;G1E<R!D92!L82!D871E+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B0VAO:7-I<W-E>B!U;B!O8FIE="(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(DYE('/I;&5C=&EO;FYE<B!A=6-U;B(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(E/I;&5C=&EO;FYE>B!L97,@8V%R86-TZ')E
M<R!D;VYT('9O=7,@879E>B!B97-O:6X@X"!L)V%I9&4@9&4@;"=O=71I;"!C
M:2TB"B)D97-S;W5S+B!6;W5S('!O=79E>B!E;G-U:71E(&QE<R!C;W!I97(@
M970@;&5S(&-O;&QE<B!D86YS('9O=')E('1E>'1E+B(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L
M:6UI=&5R.B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@;&4@9.EL:6UI=&5U<B!D
M92!D871EH#HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I
M9"`B4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B4^EL96-T:6]N
M;F5Z(&QE(&9O<FUA="!D92!D871EH#HB"@HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4^EL96-T:6]N;F5R
M(&QE('!R;V9I;"!Q=64@=F]U<R!DZ7-I<F5Z(&UO9&EF:65R.B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@;&4@9.EL:6UI
M=&5U<B!D)VAE=7)EH#HB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4^EL
M96-T:6]N;F5Z(&QE(&9O<FUA="!D92!L)VAE=7)EH#HB"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RXB"FUS9W-T<B`B4^EL96-T:6]N;F5Z(&1E=7@@8VAA;7!S
M(&%P<&%R96YTZ7,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM
M<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")3Z6QE
M8W1I;VYN97H@=F]T<F4@=&CH;64@9&4@8V]U;&5U<G,N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R(")3Z6QE8W1I;VYN97H@=F]T<F4@;&%N
M9W5E('!RZ6;I<NEEH#HB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")%
M;G9O>65R(&QE(')A<'!O<G0@9"=A;F]M86QI92(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#0R"FUS9VED(")396YD(%--
M4R(*;7-G<W1R(")%;G9O>65R(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-E;F5G86PB"FUS9W-T<B`B4^ENZ6=A;"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S(S"FUS9VED(")396YS;W(Z("(*;7-G<W1R(")3;VYD9:`Z("(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS
M9VED(")397!T96UB97(B"FUS9W-T<B`B4V5P=&5M8G)E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A
M;F0@36]N=&5N96=R;R(*;7-G<W1R(")397)B:64@970@36]N=&5N96=R;R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED
M(")397)I86P@3G5M8F5R(@IM<V=S='(@(DYU;>ER;R!D92!SZ7)I92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E
M<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DQE<R!D
M;VYNZ65S(&1U('-E<G9E=7(@<V]N="!F875S<V5S(&]U(&YO;B!D:7-P;VYI
M8FQE<RXB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I
M;VX@061M:6XB"FUS9W-T<B`B061M:6YI<W1R871I;VX@9&5S('-E<W-I;VYS
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(DED
M+B!D92!S97-S:6]N(&5X<&ERZ2XB"@HC.B!L:6(O87!I+G!H<#HQ-#4*;7-G
M:60@(E-E<W-I;VYS(@IM<V=S='(@(E-E<W-I;VYS(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,Q,0IM<V=I9"`B4V5T(@IM<V=S='(@(E/I;&5C
M=&EO;FYE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I9"`B
M4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)#;VYF:6=U
M<F5R(&QE<R!O<'1I;VYS('!O=7(@=F]U<R!P97)M971T<F4@9&4@<F5M971T
M<F4@X"!ZZ7)O('9O=')E(&UO="!D92`B"B)P87-S92!S:2!J86UA:7,@=F]U
M<R!L)V]U8FQI97HN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q.`IM
M<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(D-O;F9I9W5R97(@
M;&5S('-E<G9E=7)S(&1I<W1A;G1S(&%C8V5S<VEB;&5S(&1E<'5I<R!V;W1R
M92!P;W)T86EL+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I
M9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B"B)3Z6QE8W1I;VYN97H@=F]T<F4@
M;&%N9W5E('!RZ6;I<NEE+"!F=7-E874@:&]R86ER92!E="!L97,@;W!T:6]N
M<R!D92!D871E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G
M:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O
M<'1I;VYS+B(*;7-G<W1R("(B"B)$Z69I;FES<V5Z(&QA('!R96UIZ')E(&%P
M<&QI8V%T:6]N(&QA;F/I92P@;&4@=&CH;64@9&4@8V]U;&5U<G,L(&QE("(*
M(G)A9G)A[F-H:7-S96UE;G0@9&5S('!A9V5S+"!E="!D)V%U=')E<R!O<'1I
M;VYS(&0G869F:6-H86=E+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S<*;7-G:60@(E-E='5P(@IM<V=S='(@(D-O;F9I9W5R871I;VXB"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(")38W)I<'0@
M9&4@8V]N9FEG=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!D:7-P;VYI8FQE(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B
M"FUS9W-T<B`B4&QU<VEE=7)S(&5N9')O:71S('!O<W-I8FQE<R!A=F5C(&QE
M('!A<F%MZ'1R9:`Z("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL
M97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(D%C:&%T(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H
M;W)T(%-U;6UA<GDB"FUS9W-T<B`B4NES=6WI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C0U,`IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E
M9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(D1O:70M;VX@9.EF:6YI
M<B!D97,@=&]U8VAE<R!D92!R86-C;W5R8VES('!O=7(@;&$@<&QU<&%R="!D
M97,@;&EE;G.@/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(D%F9FEC:&5R(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E
M;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E
M;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)-;VYT<F5R
M(&QE<R!D:69FZ7)E;F-E<R!E;G1R92!L82!C;VYF:6=U<F%T:6]N(&5N<F5G
M:7-T<NEE(&%C='5E;&QE;65N="!E="`B"B)C96QL92!N;W5V96QL96UE;G0@
M9^ENZ7+I92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DT"FUS9VED
M(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_(@IM<V=S
M='(@(DUO;G1R97(@;"=H975R92!D92!L82!D97)N:>AR92!C;VYN97AI;VX@
MX"!L)V5N='+I9:`_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M,@IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R
M(")-;VYT<F5R(&PG;W!T:6]N(&1E(&-O;G-E<G9E<B!L)V]R:6=I;F%L(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y,@IM<V=I9"`B4VAO=R!P
M:6-K97(B"FUS9W-T<B`B36]N=')E<B!L92!SZ6QE8W1E=7(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3:&]W('1A8FQE(&]P97)A
M=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(D%F9FEC:&5R(&QA(&)A<G)E(&1E
M(&UE;G4@9&4@=&%B;&5A=7B@/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\B"FUS9W-T<B`B069F:6-H97(@;&4@;65N=2`E<R#@(&=A
M=6-H9:`_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D%F9FEC:&5R(&QA(&)O[G1E(&1E
M(&1I86QO9W5E('1A8FQE874@8V5L;'5L92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B069F:6-H
M97(@;&$@8F_N=&4@9&4@9&EA;&]G=64@9&5S('!R;W!R:>ETZ7,@9'4@=&%B
M;&5A=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(D%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I
M86QO9W5E(&1E<R!P<F]P<FGI=.ES(&1E(&QA(')A;F?I92!D=2!T86)L96%U
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R(")!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L;V=U92!D
M97,@<')O<')IZ73I<R!D92!L)VEM86=E(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V,`IM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T<B`B069F
M:6-H97(@;"=E;G9O:2!D92!F:6-H:65R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS9W-T
M<B`B079E<G-E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D%V97)S
M97,@=/1T(&1A;G,@;&$@:F]U<F[I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W97)S($QA=&4B"FUS
M9W-T<B`B079E<G-E<R!T87)D(&5N(&IO=7)NZ64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VAO=V5R<R!I
M;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B079E<G-E<R!A=7@@86QE;G1O=7)S
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")297-S97)R97(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW
M,@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$P-3@*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I9"`B4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M(@IM<V=S='(@(E)E<W-E<G)E<B!O=2!DZ6=A9V5R(&0G86)O<F0@;&4H<RD@
M8FQO8RAS*2!V;VES:6XH<RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V-@IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R(")3)VEN<V-R:7)E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R(")3:6=N871U
M<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM
M<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")!;&=O<FET:&UE
M(&1E('-I9VYA='5R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R
M92(*;7-G<W1R(")3:6YG87!O=7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3,*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#,@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,CDP.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3`R"FUS9VED(")3:7IE(@IM<V=S='(@(E1A:6QL92(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED
M(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(D%N;G5L97(@;&$@;6%I;G1E
M;F%N8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R
M(")3;&]V87%U:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*
M;7-G<W1R(")3;&]VZ6YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(@IM<V=S='(@(DYE:6=E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G
M:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(D%V97)S92!D92!N96EG92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED
M(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B079E<G-E<R!D92!N96EG92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED
M(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B079E<G-E<R!D92!N96EG
M92!T]'0@9&%N<R!L82!J;W5R;NEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E
M(@IM<V=S='(@(D%V97)S97,@9&4@;F5I9V4@=&%R9"!E;B!J;W5R;NEE(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z
M("(*;7-G<W1R(")(875T975R(&1E(&YE:6=EH#H@(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#D*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@(@IM<V=S='(@(E%U86YT:73I(&0G96%U(.EQ=6EV86QE;G1E(.`@;&$@
M<75A;G1I=.D@9&4@;F5I9V6@.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3
M;VQO;6]N($ES;&%N9',B"FUS9W-T<B`BSFQE<R!386QO;6]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3;VUA;&EE(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3;VYG<R`F(%!O96US
M(@IM<V=S='(@(D-H86YS;VYS(&5T('!OZ&UE<R(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,#4*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N
M(@IM<V=S='(@(E/I;&5C=&EO;B!D92!L)V]R9')E(&1E('1R:2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(D%D<F5S<V4@<V]U
M<F-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(D%F<FEQ=64@9'4@<W5D(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R
M(")3=60M975R;W#I96X@*$E33RTX.#4Y+3,I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R(")'Z6]R9VEE+61U+7-U9"!E="#N;&5S(%-A;F1W:6-H
M+61U+7-U9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T
M<B`B2.EM:7-P:.AR92!3=60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(*;7-G<W1R(")%<W!A8V4@96YT<F4@8V5L;'5L97,@861J
M86-E;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(D5S<&%C92!E;G1R92!L92!C;VYT96YU
M(&5T(&QA(&)O<F1U<F4@9&%N<R!U;F4@8V5L;'5L92(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Q,@IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D5S
M<&%C975R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(D5S<&%C96UE
M;G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@
M(D5S<&%C96UE;G0@970@<F5M<&QI<W-A9V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B4W!A:6XB"FUS9W-T<B`B17-P86=N92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ,#`*;7-G:60@(E-P86TB"FUS9W-T<B`B4&]U<G)I96PB
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(D-A<F%C=.AR97,@<W#I8VEA=7@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(E-C:6YD97(@;&$@
M8V5L;'5L92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R(")3
M8VEN9&5R(&QA(&-O;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`B4V-I;F1E<B!L82!R86YGZ64B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R=',B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX,0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A
M<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@
M5')E:R(*;7-G<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3@S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.#@*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B06YNZ64@9&4@9.EB=70B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A
M=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`BR71A="!O=2!P<F]V:6YC92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3
M=&%T=7,B"FUS9W-T<B`B4W1A='5T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y-`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T<B`B1F]R
M;6%T(&1E('-A=79E9V%R9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B
M4G5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R(")"87)RZ2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S`*;7-G:60@(E-T<FEN9R!L
M:7-T(@IM<V=S='(@(DQI<W1E(&1E(&-H8>YN97,B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#<P"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<R(*;7-G<W1R(")2971I<F5R(&QE(&1O;6%I;F4@9&4@;"=A
M9')E<W-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1Y
M;&4@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")$:2(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4V]U<RURZ7!E<G1O
M:7)E(*N@)7.@NR!N;VX@=')O=7;I(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R
M(")3=6IE="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3<*;7-G:60@(E-U8FUI
M="(*;7-G<W1R(")%;G9O:2(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(DQA
M(&1E;6%N9&4@9"=A:F]U="!D92"KH"5SH+L@874@<WES=.AM92!A(.ETZ2!S
M;W5M:7-E+B!6;W5S(&YE('!O=7)R97H@<&%S("(*(G9O=7,@8V]N;F5C=&5R
M(&IU<W%U)^`@<V]N(&%P<')O8F%T:6]N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*
M;7-G<W1R("));F1I8V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`U"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B4W5C8^AS
M(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G
M<W1R("*KH"5SH+L@82!B:65N(.ETZ2!A:F]U=.DH92DN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B3&5S(&1O;F[I97,@9&4@;"=U=&EL:7-A=&5U<B"KH"5S
MH+L@;VYT(&)I96X@Z73I(')E=&ERZ65S(&1U('-Y<W3H;64N+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S
M7"(N(@IM<V=S='(@(JN@)7.@NR!A(&)I96X@Z73I('-U<'!R:6WI*&4I+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*
M;7-G<W1R("*KH"5SH+L@82!B:65N(.ETZ2!R971I<NDH92DN(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RXB
M"FUS9W-T<B`B(@HB4F5T;W5R(.`@;&$@8V]N9FEG=7)A=&EO;B!I;FET:6%L
M92!RZ75S<VDN("!2869R8>YC:&ER(&QA('!A9V4@<&]U<B!V;VER(&QE<R`B
M"B)M;V1I9FEC871I;VYS+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU
M.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")%;G)E
M9VES=')E;65N="!D92!L82!C;VYF:6=U<F%T:6]N(&1E(&QA('-A=79E9V%R
M9&4@<NEU<W-I+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"B)%;G)E9VES
M=')E;65N="!RZ75S<VD@9&4@;&$@8V]P:64@9&4@<V%U=F5G87)D92!D=2!F
M:6-H:65R(&1E(&-O;F9I9W5R871I;VX@)2(*(G,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U
M<&1A=&5D(%PB)7-<(B(*;7-G<W1R("*KH"5SH+L@82!B:65N(.ETZ2!M:7,H
M92D@X"!J;W5R+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U
M8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("+)8W)I='5R92!D92`E<R!R
MZ75S<VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3
M;W5D86XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y(@IM<V=S='(@(E-O;6UA:7)E
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3=6X@4FES
M92(*;7-G<W1R("),979E<B!D=2!3;VQE:6PB"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B0V]U8VAE<B!D
M=2!3;VQE:6PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B16YS;VQE:6QLZ2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I
M<V4B"FUS9W-T<B`B3&5V97(@9'4@4V]L96EL(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3
M=6YR:7-E+U-U;G-E="(*;7-G<W1R("),979E<B]#;W5C:&5R(&1U(%-O;&5I
M;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@
M(E-U;G)I<V4Z("(*;7-G<W1R("),979E<B!D=2!3;VQE:6PZ("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*
M;7-G<W1R(")#;W5C:&5R(&1U(%-O;&5I;"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(D-O
M=6-H97(@9'4@4V]L96ELH#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T
M<B`B17AP;W-A;G0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@P
M"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(D%S<VES=&%N8V4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(&]U($=U
M>6%N92!H;VQL86YD86ES92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(DYO;2!D92!F
M86UI;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA
M;B!-87EE;B(*;7-G<W1R("+.;&5S(%-V86QB87)D(&5T($IA;B!-87EE;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z
M:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS9W-T<B`B
M4W7H9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T
M<B`B4W5I<W-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B2F]U<FYA;"!D92!S
M>6YC:')O;FES871I;VX@<W5P<')I;>DB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B4WEN8TU,(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT
M87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D5R<F5U<B!D92!S
M>6YT87AE(&1A;G,@;&5S('1E<FUE<R!D92!R96-H97)C:&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R(")3
M>7)I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8R"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D]R86=E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T
M;W)M(&%N9"!7:6YD>2(*;7-G<W1R(")/<F%G92!E="!V96YT(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C0*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(D]R86=E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4+5-T;W)M<R!%87)L>2(*
M;7-G<W1R(")/<F%G97,@;6%T:6YA=7@B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")&:6-H
M:65R(%135B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T
M<B`B4')O<')IZ73I<R!D=2!T86)L96%U(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM
M<V=S='(@(E1A8FQE874@9&4@=F%L975R<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE
M('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')IZ73I<R!D=2!T86)L96%U(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E1A
M[W=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X
M"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(E1A
M[W=A;BP@<')O=FEN8V4@9&4@0VAI;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")486II:VES=&%N(@IM<V=S='(@(E1A:FEK:7-T86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(E1A;GIA;FEE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R(")#:6)L9:`Z
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S(@8V]N9FEG+VAO
M;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B5.)C:&5S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E;&5P:&]N
M92!.=6UB97(B"FUS9W-T<B`B3G5MZ7)O(&1E('3I;.EP:&]N92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R(")496UPZ7)A='5R92!P;W5R(&QA(&1E<FYIZ')E(&AE
M=7)EH#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E
M;7!E<F%T=7)E(@IM<V=S='(@(E1E;7#I<F%T=7)E(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R(")496UPZ7)A='5R9:`Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U
M<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP
MZ7)A='5R93QB<B`O/B@E<TAA)7,O)7-"825S*2`F9&5G.R5S(@H*(SH@9G)A
M;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M4')O9FEL(*N@)7.@NR!N;VX@=')O=7;I(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%T:6]N(&1E<R!M;V3H;&5S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(P."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S(T"FUS9VED(")497AT(@IM<V=S='(@(E1E>'1E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E1E
M>'1E('-E=6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(D%L
M:6=N96UE;G0@9'4@=&5X=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E
M>'1E(&5N(&AA=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R(")*92(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R(")4:&'O("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H
M86EL86YD(@IM<V=S='(@(E1H8>]L86YD92(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#4Q"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("),)V5X=&5N<VEO;B!&5%`@;B=E<W0@
M<&%S(&1I<W!O;FEB;&4N(@H*(SH@9G)A;65W;W)K+TAI<W1O<GDO2&ES=&]R
M>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE
M9"XB"FUS9W-T<B`B3"=H:7-T;W)I<V%T:6]N(&5S="!DZ7-A8W1I=NEE+B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@
M9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B3&4@;6]T975R(&0G
M:6YTZ6=R871I;VX@2&]R9&4O2V]L86(@;F4@<W5P<&]R=&4@<&%S(*N@)7.@
MNR(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3@*
M;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N
M(@IM<V=S='(@(DQE(&IO=7)N86P@24U34"!N)V$@<&%S('!U(.IT<F4@:6YI
M=&EA;&ESZ2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G
M:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'DB"FUS9W-T<B`B3&$@8VQA<W-E($UA:6YT96YA;F-E.CH@;B=A
M('!A<R#I=.D@8VAA<F?I92!C;W)R96-T96UE;G0B"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B3&$@9F5NZG1R
M92!D97,@;W!T:6]N<R!S)V5S="!F97)MZ64N(%-O<G1I92XB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Q,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(U
M,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V-"!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T
M;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS
M(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*
M;7-G<W1R("(B"B),)V%D;6EN:7-T<F%T975R(&1O:70@8V]N9FEG=7)E<B!U
M;B!B86-K96YD('!E<FUA;F5N="!P;W5R(&QE<R!P97)M:7-S:6]N<R`B"B)S
M:2!V;W5S('9O=6QE>B!L97,@96UP;&]Y97(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE
M(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B3&$@8F]R9'5R92!D=2!B87,@
M<V5U;&5M96YT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB3"=)1"!D=2!C
M;VYT86-T(&XG82!P87,@Z73I('-PZ6-I9FGI+"!L86ES<^D@=FED92!O=2!N
M)V$@<&%S(.ETZ2!T<F]U=ND@9&%N<R`B"B)L82!B87-E(&1E(&1O;F[I97,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q
M"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")#92!C;VYT86-T(&$@8FEE
M;B#I=.D@86IO=73I(.`@=F]T<F4@8V%R;F5T(&0G861R97-S97,N("(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*
M(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D
M('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(DQE
M(&)L;V,@9&4@<VEG;F%T=7)E(%!'4"!SZ7!A<ND@97-T(&[I8V5S<V%I<F4@
M<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U<F4N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S
M92XB"FUS9W-T<B`B(@HB3"=)1"!D92!L82!L:7-T92!N)V$@<&%S(.ETZ2!S
M<.EC:69IZ2P@;&%I<W/I('9I9&4@;W4@;F]N('1R;W5VZ2!D86YS(&QA("(*
M(F)A<V4@9&4@9&]N;NEE<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("),82!L:7-T92!D
M92!D:7-T<FEB=71I;VX@;B=A('!A<R#I=.D@<W#I8VEF:>EE+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("),92!C:&EF9G)E;65N="!NZ6-E<W-I=&4@=6YE(&-O;FYE
M>&EO;B!SZ6-U<FESZ64N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.#8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(*;7-G<W1R("),92!F:6-H:65R("5S(&1O:70@8V]N=&5N:7(@
M;&5S(&]P=&EO;G,@)7,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RXB"FUS9W-T<B`B3&4@9FEC:&EE<B`E<R!D;VET(&-O;G1E
M;FER(&-E<G1A:6YE<R!O<'1I;VYS("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(R-@IM<V=I9"`B5&AE(&9I;&4@8V%N;F]T(&)E(&-O
M<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B3&4@9FEC:&EE<B!N92!P975T
M('!A<R#J=')E(&-O<&GI('-U<B!L=6DM;>IM92XB"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+B(*;7-G<W1R("),92!F:6-H:65R(&YE(&-O;G1E;F%I="!A=6-U
M;F4@9&]N;NEE+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@
M(D-E('%U:2!S=6ET('-O;G0@;&5S(&5N+73J=&5S('!O=7(@8V4@;65S<V%G
M92!M97-S86=E+U)&0S@R,BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N
M<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@
M<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO
M=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@
M;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(DQE(&UO9&4@<&QE
M:6X@Z6-R86X@8V%U<V4@9&5S('!R;V)LZ&UE<R!A=F5C($EN=&5R;F5T($5X
M<&QO<F5R(&3[(.`@9&5S("(*(F)O9W5E<R!D=2!N879I9V%T975R('%U:2!N
M)V]N="!P=2#J=')E(&-O;G1O=7)NZ7,N(%9O=7,@<&]U=F5Z(.IT<F4@(@HB
M8V]N9G)O;G3I<R#@(&1E(&PG869F:6-H86=E(&1E(&-A<F%C=.AR97,@Z71R
M86YG97,L(&%U(&YO;BUF;VYC=&EO;FYE;65N="`B"B)D97,@8V5R=&%I;F5S
M(&9O;F-T:6]N<R!E="]O=2!A=2!P;&%N=&%G92!A;.EA=&]I<F4@9'4@;F%V
M:6=A=&5U<BX@4VD@=F]T<F4@(@HB<WES=.AM92!E<W0@=6X@5VEN9&]W<R`Y
M>"P@:6P@97-T('1RZ',@<&]S<VEB;&4@<75E('9O=7,@875R97H@=6YE("=&
M875T92`B"B)GZ6[I<F%L92!D92!P<F]T96-T:6]N)R!E="!Q=64@=F]U<R!D
M979R97H@<F5DZ6UA<G)E<B!V;W1R92!O<F1I;F%T975R+EQ<;B(*(EQ<;E9O
M=7,@879E>B#I=.D@<'+I=F5N=7,N(%-64"!A<'!U>65Z('-U<B!/2R!S:2!V
M;W5S('9O=6QE>B!T;W5J;W5R<R`B"B)E<W-A>65R(&QE(&UO9&4@<&QE:6X@
MZ6-R86X@9&4@;"?I9&ET975R(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DPG:61E;G1I=.D@JZ`E<Z"[("!A
M(.ETZ2!S=7!P<FEMZ64N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S
M:61E(&]N;'DB"FUS9W-T<B`B3&4@8_1TZ2!G875C:&4@<V5U;&5M96YT(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B
M"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I
M=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB3"=E
M;7!L86-E;65N="!D=2!P<F]G<F%M;64@1VYU4$<@9&]I="#J=')E(&9O=7)N
M:2#@(&QA(&-L87-S92!#<GEP=%]P9W`Z.BXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<
M(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"XB"FUS9W-T<B`B(@HB3&4@;65S<V%G92!E;G9O>>D@;&4@)7,@X"`E<R!A
M=F5C(&-O;6UE('-U:F5T(*N@)7.@NR!A(.ETZ2!A9F9I8VCI+B!<;B(*(DEL
M(&XG>2!A(&%U8W5N92!G87)A;G1I92!Q=64@8V4@;65S<V%G92!A(.ETZ2!L
M=2!O=2!C;VUP<FES+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S0*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G92(*;7-G<W1R("),92!N;VT@X"!U=&EL:7-E<B!E;B!L
M:6%N="#@(&QA('!A9V4@9&4@8V]M<&]S:71I;VXB"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B3&4@;F]M8G)E(&1E(&-H
M86UP<R!D;VET(.IT<F4@=6X@;F]M8G)E('9A;&ED92XB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DQE(&UO9'5L92!/<&5N4U-,(&5S="!R
M97%U:7,@<&]U<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z.BXB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3&$@<'+I9NER96YC92"K
MH"5SH+L@;B=A('!A<R!P=2#J=')E(&5N<F5G:7-T<NEE(&-A<B!S82!T86EL
M;&4@9.EP87-S92!L92`B"B)M87AI;75M(&%U=&]R:7/I(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*
M;7-G<W1R("(B"B),92!P<F]G<F%M;64@=71I;&ESZ2!P;W5R('9I<W5A;&ES
M97(@8V4@='EP92!D92!D;VYNZ65S("@E<RD@;B=A('!A<R#I=.D@(@HB=')O
M=7;I+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I
M9"`B5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+B(*;7-G<W1R("),92!C87)A8W3H<F4@9&4@<')O=&5C=&EO;B!D
M;VET(.IT<F4@=6X@8V%R86-TZ')E('5N:7%U92XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<W"FUS9VED(")4
M:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*;7-G<W1R("),97,@8_1T
MZ7,@9V%U8VAE(&5T(&1R;VET('-E=6QE;65N="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H
M92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("),92!C]'3I(&1R;VET
M('-E=6QE;65N="(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W
M.0IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+B(*;7-G<W1R("),92!SZ7!A<F%T975R(&1O:70@ZG1R92!U;B!C
M87)A8W3H<F4@=6YI<75E+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DQE('-E<G9E=7(@JZ`E<Z"[
M(&$@Z73I('-U<'!R:6WI+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN
M<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB
M(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("),92!S97)V975R(*N@)7.@NR!A
M(.ETZ2!E;G)E9VES='+I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(DQA(')E<77J=&4@9"=E;G)E9VES
M=')E;65N="!P;W5R("5S(&$@Z73I(&3I<&QA8^EE+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(DQA(&QI9VYE(&1E;6%N9.EE("@E9"D@;B=E>&ES
M=&4@<&%S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(DQE(&9I8VAI97(@=&5M<&]R86ER
M92"K("5SH+L@;B=E>&ES=&4@<&%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.3D*;7-G:60@(E1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N
M;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB"FUS9W-T<B`B3&4@
M=&5X=&4@96YT<ND@;F4@8V]R<F5S<&]N9"!P87,@874@=&5X=&4@<W5R(&PG
MZ6-R86XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'DB"FUS9W-T<B`B3&4@:&%U="!E="!L92!B87,@<V5U;&5M96YT(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B3&4@:&%U
M="!S975L96UE;G0B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*
M;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P
M<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"B),97,@9&]N;NEE<R!TZ6SI8VAA
M<F?I97,@=F5R<R!L92!S97)V975R(&]N="#I=.D@<&5R9'5E<R!D97!U:7,@
M;"?I=&%P92`B"B)P<NECZ61E;G1E+B`B"@HC.B!F<F%M97=O<FLO1&%T82]$
M871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"XB"FUS9W-T<B`B3&4@9FEC:&EE<B#I;6ES(&XG82!P87,@<'4@ZG1R92!E
M;G)E9VES='+I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT
M.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED(")4:&4@
M=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M3&4@8FQO8R"KH'=E871H97(N8V]MH+L@;B=E<W0@<&%S(&1I<W!O;FEB;&4N
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4NEP97)T;VER92!D97,@=&CH;65S(*N@)7.@NR!N;VX@=')O=7;I
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@
M(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B26P@
M;B=Y(&$@<&%S(&0G;W!T:6]N<R!D:7-P;VYI8FQE<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T.`IM<V=I9"`B5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S
M='(@(D%U8W5N92!P87)T:64@;F4@<&5U="#J=')E(&%F9FEC:.EE(&5N(&QI
M9VYE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@
M(B(*(DEL('D@(&$@=')O<"!D92!C87)A8W3H<F5S(&1A;G,@8V4@8VAA;7`N
M(%9O=7,@96X@879E>B!E;G1RZ2`E<Z`[(&EL(&5N(&9A=70@(@HB;6]I;G,@
M9&4@)7,N(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN
M9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B56X@<')O8FSH
M;64@97-T(&%P<&%R=2!L;W)S(&1E(&PG86IO=70@9&4@JZ`E<Z"[H#H@)7,B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)5;B!P<F]B;.AM
M92!E<W0@87!P87)U(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&5S(&1O;F[I
M97,@9&4@;"=U=&EL:7-A=&5U<B`B"B*KH"5SH+N@.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS
M9W-T<B`B56X@<')O8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&QA('-U<'!R
M97-S:6]N(&1E(*N@)7.@NZ`Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B56X@<')O8FSH;64@97-T(&%P<&%R
M=2!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R(&1E(*N@)7.@NZ`Z("5S(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@HB56X@<')O
M8FSH;64@97-T(&%P<&%R=2!L;W)S(&1E(&PG96YV;VD@9'4@9FEC:&EE<J`Z
M(&%U8W5N("5S(&XG82#I=.D@(@HB=')A;G-M:7,N(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E
M9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(E5N92!E<G)E=7(@97-T
M('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@;&4@)7,@
MZ71A:70@<&QU<R!G<F]S("(*(G%U92!L92!M87AI;75M(&%U=&]R:7/I("@E
M9"!O8W1E=',I+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R
M=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)5;F4@97)R975R(&5S="!S
M=7)V96YU92!L;W)S(&1E(&PG96YV;VD@9'4@9FEC:&EE<J`Z(&QE("5S(&$@
MZ73I('1R86YS;6ES("(*(G!A<G1I96QL96UE;G0N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@
M=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS
M9W-T<B`B(@HB56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG
M869F:6-H86=E(&1E(&-E='1E('!A<G1E(&1U(&UE<W-A9V4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM
M<V=S='(@(B(*(E5N92!E<G)E=7(@<R=E<W0@<')O9'5I=&4@;&]R<R!D92!L
M)VEM<&]R=&%T:6]N(&1E<R!D;VYNZ65S(&1E(&-E(&-O;G1A8W0N(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS
M9W-T<B`B(@HB56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG
M:6UP;W)T871I;VX@9&4@8V5T=&4@8V%R=&4@:4-A;&5N9&%R+B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B))
M;"!Y(&%V86ET('5N92!E<G)E=7(@9&%N<R!L92!F;W)M=6QA:7)E(&1E(&-O
M;F9I9W5R871I;VXN(%!E=70MZG1R92!A=F5Z+2(*(G9O=7,@;&%I<W/I('5N
M(&-H86UP(')E<75I<R!V:61E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B(@HB56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG97CI
M8W5T:6]N(&1E(&-E='1E(&9O;F-T:6]N(&1U(&-A<FYE="`B"B)D)V%D<F5S
M<V4N(%-64"!E<W-A>65R(.`@;F]U=F5A=2!P;'5S('1A<F0N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G
M:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C
M="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"B));"!Y(&$@974@=6YE(&5R<F5U<B!L;W)S(&1E(&QA(&UI<V4@X"!J;W5R
M(&1E<R!I;F9O<FUA=&EO;G,@<W5R(&QE("(*(F-O;G1A8W0N("!6975I;&QE
M>B!E<W-A>65R(.`@;F]U=F5A=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB26P@>2!A(&5U('5N92!E
M<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D92!L82!L:7-T92!D92!D
M:7-T<FEB=71I;VXN("`B"B)6975I;&QE>B!E<W-A>65R(&1E(&YO=79E874N
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X
M"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+B(*;7-G<W1R("),92!P<NES96YT('-E<G9E=7(@24U!
M4"!N92!S=7!P;W)T92!P87,@;&4@<&%R=&%G92!D92!D;W-S:65R<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H
M:79E+B(*;7-G<W1R("+'82!N92!S96UB;&4@<&%S(.IT<F4@=6YE(&%R8VAI
M=F4@4D%2('9A;&ED92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("+'82!N92!S96UB;&4@<&%S
M(.IT<F4@=6X@9FEC:&EE<B!:25`@=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,C0*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("+'82!N92!S96UB
M;&4@<&%S(.IT<F4@=6X@;G5MZ7)O(&1E(&-A<G1E('9A;&ED92XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@
M(B(*(D-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R#@('1R
M879E<G,@;&$@<&%S<V5R96QL92!#;&EC:V%T96QL("(*(BAH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&5N('5T:6QI<V%N="!L)T%022!(5%10(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)#92!P:6QO=&4@<&5R;65T
M(&PG96YV;VD@9&4@;65S<V%G97,@=FEA(&QA('!A<W-E<F5L;&4@5TE.("AH
M='1P.B\O=VEN<&QC+B(*(F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%`B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS
M,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*(D-E('!I;&]T92!P97)M970@;"=E;G9O:2!D92!M97-S86=E<R#@
M('1R879E<G,@;&$@<&%S<V5R96QL92!S;7,R96UA:6P@(@HB*&AT='`Z+R]S
M;7,R96UA:6PN8V]M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)#92!P:6QO=&4@<&5R;65T
M(&PG96YV;VD@9&4@;65S<V%G97,@<&%R(%--5%`@X"!T<F%V97)S(&QA('!A
M<W-E<F5L;&4@(@HB5F]D869O;F4@271A;&EE+"!S975L96UE;G0@875X(&YU
M;>ER;W,@5F]D869O;F4N($-E;&$@;NEC97-S:71E('5N(&-O;7!T92!D92`B
M"B)C;W5R<FEE;"!6;V1A9F]N92!)=&%L:64@*&AT='`Z+R]W=W<N,3DP+FET
M*2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S4@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#@S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,3(*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$W.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C4S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-34T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,S8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#`R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C8@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W-0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,30V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,3@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V,S0@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.30*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@P,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS.#$P"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(*;7-G<W1R(")#92!C:&%M<"!E<W0@;V)L:6=A=&]I<F4N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V,@IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")#92!C:&%M<"!N
M92!D;VET(&-O;G1E;FER('%U92!D97,@96YT:65R<RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$S"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")#
M92!C:&%M<"!N92!D;VET(&-O;G1E;FER('%U92!D97,@;F]M8G)E<R!E="!L
M97,@9&5U>"UP;VEN=',N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`Y,0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RXB"FUS9W-T<B`B0V4@8VAA;7`@;F4@9&]I="!C;VYT96YI<B!Q
M=64@9&5S('9A;&5U<G,@;V-T86QE<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3(P"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R
M("(B"B)#92!C:&%M<"!D;VET(&-O;G1E;FER('5N92!L:7-T92!D)V5N=&EE
M<G,@<^EP87+I<R!P87(@9&5S('9I<F=U;&5S(&]U(&1E<R`B"B)E<W!A8V5S
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@V"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(D-E(&-H
M86UP(&1O:70@ZG1R92!U;B!N;VUB<F4@=F%L:61E+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@HB0V4@8VAA
M;7`@9&]I="!C;VYT96YI<B!U;B!C;V1E(&1E(&-O=6QE=7(@874@9F]R;6%T
M(%)'0B!H97AA9.EC:6UA;"P@<&%R("(*(F5X96UP;&4@)R,Q,C,T868G+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4U.`IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")#92!F
M;W)M=6QA:7)E(&$@9.EJX"#I=.D@=')A:73I+B(*"B,Z('1E;7!L871E<R]H
M96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@
M)7,N(@IM<V=S='(@(D,G97-T("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#8Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@
M82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T
M('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S
M=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@
M;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G
M<W1R("(B"B)#96-I(&5S="!U;B!O8FIE="!+;VQA8B!'<F]U<'=A<F4N(%!O
M=7(@=F]I<B!C970@;V)J970L('9O=7,@9&5V<F5Z(&%V;VER('5N("(*(F-L
M:65N="!D92!C;W5R<FEE;"!Q=6D@8V]M<')E;F0@;&4@9F]R;6%T($MO;&%B
M($=R;W5P=V%R92X@4&]U<B!U;F4@;&ES=&4@9&4@(@HB8V5S(&-L:65N=',@
M9&4@8V]U<G)I96PL('9I<VET97H@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*(D-E(&UE<W-A9V4@
M82#I=.D@Z6-R:70@9&%N<R!U;B!C;V1E(&1E(&-A<F%C=.AR97,@*"5S*2!A
M=71R92!Q=64@;&4@=O1T<F4N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+B(*;7-G<W1R(")#92!N;VUB<F4@9&]I="#J=')E('-U<.ER:65U
M<B#@('5N+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z
M:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D-E('-E<G9E=7(@;F4@<&5U
M="!P87,@9.EC;VUP<F5S<V5R(&QE<R!F:6-H:65R<R!:25`@970@9WII<"XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R(")#92!S>7-TZ&UE(&5S="!P<NES96YT96UE;G0@9.ES86-T:7;I
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T"FUS9VED
M(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(D-E='1E
M('9A;&5U<B!D;VET(.IT<F4@=6X@;F]M8G)E+B(*"B,Z('-E<G9I8V5S+VEM
M86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU
M<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B
M0V5T=&4@9F5NZG1R92!D;VET(.IT<F4@87!P96SI92!D97!U:7,@=6YE(&9E
M;NIT<F4@9&5S(&]P=&EO;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")4;VYN
M97)R92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@
M(E1I8VME=',B"FUS9W-T<B`B5&EC:V5T<R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,C(@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")4:6UE(@IM<V=S='(@(DAE=7)E(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R
M(")3=6EV:2!H;W)A:7)E(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS
M9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M870@9"=H975R92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,C@*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(E/I;&5C=&EO;B!D92!L)VAE=7)E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(@;W)I
M96YT86PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*
M;7-G<W1R(")4:71R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T
M<B`B5&ET<F4@*&EN9F]B=6QL92F@.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(L`B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T
M"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W
M;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H
M:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)0;W5R('/I;&5C=&EO;FYE<B!P
M;'5S:65U<G,@:71E;7,@X"!L82!F;VES+"!M86EN=&5N97H@96YF;VYCZ2!L
M92!B;W5T;VX@(@HBJZ!#=')LH+L@*%!#*2!O=2"KH$-O;6UA;F1EH+L@*$UA
M8RD@96X@8VQI<75A;G0N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B075J;W5R9"=H=6DB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS
M9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B5F]I<B!L82!S;W5R
M8V4@2%1-3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B
M5&]G;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B
M5&]K96QA=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#(*
M;7-G:60@(E1O;6]R<F]W(@IM<V=S='(@(D1E;6%I;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1O;F=A(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K;VQA8BYP:'`Z,3`T"FUS9VED(")4;V\@;6%N>2!I;G9A
M;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RXB"FUS9W-T<B`B
M5')O<"!D92!C;VYN97AI;VYS(&EN9G)U8W1U975S97,@9&%N<R!L97,@9&5R
M;FGH<F5S(&UI;G5T97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B2&%U
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B0V%D<F4@9'4@
M:&%U="`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G
M:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4<F%D=6-T:6]N<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
M5')I;FETZ2UE="U4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-S@W"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(E9R86D@;W4@
M9F%U>"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(DUA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM
M<V=I9"`B5'5N:7-I82(*;7-G<W1R(")4=6YI<VEE(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<G%U:64B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB
M"FUS9W-T<B`B5'5R8R`H25-/+3@X-3DM.2DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R:VWI;FES=&%N(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM
M<V=S='(@(LYL97,@5'5R<75E<R!E="!#8>]Q=65S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*
M;7-G<W1R(")%;G1R97H@=F]T<F4@8VAO:7B@.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4X"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B26YD:6-E(%56H#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM
M<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B55),
M('!O=7(@=F]T<F4@<F%P<&]R="!D92!L:79R86ES;VX@9'4@<V-R:7!T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM
M<V=I9"`B55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56=A;F1A(@IM<V=S='(@(D]U9V%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")5:W)A:6YE(@IM<V=S='(@(E5K<F%I;F4B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D)V%T=&5I;F1R
M92!L92!RZ7!E<G1O:7)E(%9&4RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E
M<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9"=A:F]U=&5R(&1E<R!I;F9O<FUA=&EO;G,@8V]M<&SI;65N=&%I
M<F5S(.`@;"=I;G-C<FEP=&EO;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M26UP;W-S:6)L92!D92!M;V1I9FEE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!L
M92!F:6-H:65R(%9&4R"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,SDR(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!M;V1I9FEE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B!L92!F:6-H:65R(%9&
M4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*
M;7-G<W1R("));7!O<W-I8FQE(&1E(&-H86YG97(@<&]U<B`E<RXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS
M9W-T<B`B26UP;W-S:6)L92!D92!VZ7)I9FEE<B!L82!T86EL;&4@9'4@9FEC
M:&EE<B!D92"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-CDU(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,3`R.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB
M+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(';I<FEF:65R(&QA('1A:6QL92!D
M=2!F:6-H:65R(&1E(*L@)7,O)7,@NRXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-Q;"YP:'`Z-#,Y"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!3
M44P@<V5R=F5R+B(*;7-G<W1R(")#;VYN97AI;VX@:6UP;W-S:6)L92!A=2!S
M97)V975R(%-13"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W
M,`IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@
M(D-O;FYE>&EO;B!I;7!O<W-I8FQE(&5N(%-33"(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(S,B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-O<&EE<B!U
M;B!F:6-H:65R(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&-R
MZ65R('5N('+I<&5R=&]I<F4@5D93(*N@)7.@NRXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HS-C$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C8T
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)L92!D
M92!C<NEE<B!L92!F:6-H:65R(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FQE
M(&1E(&-RZ65R(&QE('+I<&5R=&]I<F4@5D93(*N@)7.@NRXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C
M<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@
M8W+I97(@=6X@9FEC:&EE<B!61E,@=FED92X@(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R(")/=79E<G1U<F4@:6UP;W-S:6)L92!D
M92!L)V%R8VAI=F4@8V]M<')E<W/I92X@(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HR,C@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")3=7!P<F5S
M<VEO;B!I;7!O<W-I8FQE(&1E(*N@)7.@NRP@;&4@9&]S<VEE<B!N)V5S="!P
M87,@=FED92XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!I;7!O
M<W-I8FQE(&1E(*N@)7.@NZ`Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,S."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y-0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DB"FUS9W-T<B`B4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D92`E<RP@;&4@
M9&]S<VEE<B!N)V5S="!P87,@=FED92(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,V,`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!RZ6-U<G-I=F4@
M9'4@9&]S<VEE<B!61E,@:6UP;W-S:6)L92XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS-#0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!D=2!RZ7!E<G1O
M:7)E(%9&4R!I;7!O<W-I8FQE+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#(P(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>3H@)7,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<W5P<')I;65R(&QE('+I
M<&5R=&]I<F4@5D93H#H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E-U<'!R97-S:6]N(&EM<&]S
M<VEB;&4@9'4@9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C(Y,0HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(E-U
M<'!R97-S:6]N(&EM<&]S<VEB;&4@9'4@9FEC:&EE<B!61E,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`B4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!RZ7!E<G1O:7)E(%9&4R"K
MH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S
M:79E;'DZ("5S+B(*;7-G<W1R(")3=7!P<F5S<VEO;B!61E,@<NEC=7)S:79E
M(&EM<&]S<VEB;&6@.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S:6)L92!D92!DZ71E<FUI;F5R(&QE
M(&1O<W-I97(@8V]U<F%N="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R("));7!O<W-I8FQE(&0G97AT<F%I<F4@
M;&5S(&3I=&%I;',@9'4@8V5R=&EF:6-A="(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O075T
M:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D
M('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("));7!O<W-I8FQE(&1E
M(&-H87)G97(@;&$@9.EF:6YI=&EO;B!D92`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S0@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@
M9.EP;&%C97(@;&4@9FEC:&EE<B!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P-@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8U,B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D
M)V]U=G)I<B!L92!F:6-H:65R(%9&4R"KH"5SH+LN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,C@T(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I
M;F<N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!6
M1E,@96X@Z6-R:71U<F4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z.#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3,W"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<VEB;&4@9"=O=79R:7(@
M=6X@9FEC:&EE<B!61E,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+B(*;7-G<W1R(")/=79E<G1U<F4@:6UP;W-S:6)L92!D92!L
M)V%R8VAI=F4@8V]M<')E<W/I92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I
M>F4H*2!F86EL960I+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(&QI<F4@;&4@
M9FEC:&EE<B!61E,@*.EC:&5C(&1E(&9I;&5S:7IE*"DI+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX.#<*;7-G:60@(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9&4@;&ER92!L92!F:6-H:65R(%9&4R`HZ6-H96,@9&4@9V5T1FEL
M95-I>F4H*2DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F
M:6QE.B`B"FUS9W-T<B`B26UP;W-S:6)L92!D92!L:7)E(&QE(&9I8VAI97*@
M.B`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-S8*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3&5C='5R92!D=2!RZ7!E<G1O:7)E(')A8VEN92!61E,@:6UP;W-S:6)L
M92XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(DEM<&]S
M<VEB;&4@9&4@<F5N;VUM97(@)7,@96X@)7.@.B!L92!D;W-S:65R(&-I8FQE
M(&5X:7-T92!DZ6K@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("));7!O<W-I8FQE(&1E(')E;F]M;65R(&QE('+I<&5R=&]I
M<F4@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S,R"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(DEM<&]S<VEB;&4@9&4@<F5N;VUM97(@;&4@
M<NEP97)T;VER92!61E.@.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(W,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H
M:65R(%9&4R"KH"5SH+LN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B26UP;W-S:6)L92!D92!R96YO;6UE<B!L92!F:6-H:65R
M(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R
M-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S`Y"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G
M<W1R("));7!O<W-I8FQE(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S
M='(@(DEM<&]S<VEB;&4@9"=E>.EC=71E<B`G;6MI<V]F<R<N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B
M56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T
M<B`B26UP;W-S:6)L92!D92!T<F%D=6ER92!C92!D;V-U;65N="!7;W)D+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,34T(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,34W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB
M;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S
M:6)L92!D)^EC<FER92!L97,@9&]N;NEE<R!D=2!F:6-H:65R(%9&4R`H8V]P
M>2@I(&EM<&]S<VEB;&4I+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(X."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30V"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("));7!O<W-I
M8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U(&9I8VAI97(@5D93+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T
M<B`B26UP;W-S:6)L92!D)^EC<FER92!L92!F:6-H:65R(%9&4RP@;&4@<75O
M=&$@<V5R86ET(&3I<&%S<^DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@
M(E-O=6QI9VYE<B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G
M:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")!;FYU;&5R(&QE<R!C:&%N9V5M
M96YT<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(D%N;G5L92!V;W1R92!D97)N:>AR92!A8W1I;VXB"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@X"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*;7-G<W1R
M(")2Z7!O;G-E(&EN871T96YD=64@9'4@<V5R=F5U<B!L;W)S(&1E(&QA(&-O
M;FYE>&EO;J`Z("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T
M;SH@(@IM<V=S='(@(E+I<&]N<V4@:6YA='1E;F1U92!D=2!S97)V975R(."@
M.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")(;W)S(&-A=.EG;W)I
M92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E
M("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(LEM:7)A
M=',@07)A8F5S(%5N:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+
M:6YG9&]M(@IM<V=S='(@(E)O>6%U;64M56YI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM
M<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("+)=&%T<RU5;FES(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN
M9R!)<VQA;F1S(@IM<V=S='(@(LYL97,@97ATZ7)I975R97,@9&5S(,ET871S
M+55N:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B56YI=',B"FUS9W-T<B`B56YI
M=.ES(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM
M<V=S='(@(DEN8V]N;G4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B87!I;7-G:60@:6YC;VYN=2`H
M05!)($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")C;&EM<V=I9"!I;F-O
M;FYU("A#;&EE;G0@365S<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$T-PIM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V
M:61E9"XB"FUS9W-T<B`B16UP;&%C96UE;G0@<^EL96-T:6]N;ND@:6YC;VYN
M=2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(DYO;2!D)W5T:6QI<V%T975R(&]U(&UO="!D92!P87-S92!I
M;F-O;FYU+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`B1.EL:65R(&PGZ6SI;65N="!C;W5R86YT(@H*(SH@
M9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N
M;F%M960B"FUS9W-T<B`B4V%N<R!N;VTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G
M960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R
M86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S
M('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(DQE<R!S8W)I<'1S(&YO;BUP
M<FEV:6SI9VGI<R!N92!P975V96YT(&%C8^ED97(@875X(&9O;F-T:6]N<R!C
M;W5P97(O8V]P:65R+R(*(F-O;&QE<B!P;W5R(&1E<R!R86ES;VYS(&1E('/I
M8W5R:73I+B!!<'!U>65Z('-U<B!/2R!P;W5R('9O:7(@=6YE(&YO=&4@(@HB
M=&5C:&YI<75E('-U<B!M;WII;&QA+F]R9R!Q=6D@=F]U<R!E>'!L:7%U97)A
M(&-O;6UE;G0@875T;W)I<V5R('5N('-C<FEP="#@("(*(G5T:6QI<V5R(&QE
M('!R97-S92UP87!I97)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS
M9W-T<B`B4F5M971T<F4@;&$@8V]U;&5U<B#@('KI<F\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM
M<V=S='(@(D5X=&5N<VEO;B!N;VX@<')I<V4@96X@8V]M<'1E(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")-;V1I
M9FEE<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(DUO9&EF
M:65R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-@IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B36]D:69I97(@;"=U=&EL
M:7-A=&5U<B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS
M+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L
M('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R(")-
M:7-E(.`@:F]U<B!D92"KH"5SH+LN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S
M='(@(DQE('-C<FEP="!D92!M:7-E(.`@:F]U<B!E<W0@<W5P<')I;>DB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R
M(")#:&%R9V5R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I
M9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H
M92!S97)V97(N(@IM<V=S='(@(B(*(E1O=7,@;&5S(&9I8VAI97)S(&1E(&-O
M;F9I9W5R871I;VX@9&5S(&%P<&QI8V%T:6]N<R!O;G0@Z73I(&5N=F]YZ7,@
M<W5R(&QE("(*(G-E<G9E=7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T
M:6X@;&5T=&5R<R(*;7-G<W1R("),971T<F5S(&QA=&EN97,@;6%J=7-C=6QE
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B3F]M8G)E<R!R;VUA:6YS(&UA:G5S8W5L97,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B16UP;&]Y
MZ2!A8W1U96QL96UE;G2@.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(E5T:6QI<V5R(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C<*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*(E5T:6QI<V5R('-I(&QE(&YO
M;2!D)W5T:6QI<V%T975R+VUO="!D92!P87-S92!E<W0@9&EF9NER96YT(&1U
M('-E<G9E=7(@24U34"XB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(E5T:6QI<V%T975R(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F
M;W(@)7,N(@IM<V=S='(@(DPG=71I;&ES871E=7(@)7,@;B=A('!A<R!L)V%U
M=&]R:7-A=&EO;B!P;W5R("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM
M<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A
M=&EO;B!D97,@=71I;&ES871E=7)S(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")0
M<NEFZ7)E;F-E<R!P97)S;VYN96QL97,B"@HC.B!S:6=N=7`N<&AP.C8R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")%;G)E9VES=')E;65N
M="!D97,@=71I;&ES871E=7)S(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`B3"=E;G)E9VES=')E;65N="!D)W5T:6QI<V%T975R
M(&5S="!DZ7-A8W1I=ND@<W5R(&-E('-Y<W3H;64N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N
M9"(*;7-G<W1R(")#;VUP=&4@=71I;&ES871E=7(@;F]N('1R;W5VZ2(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(DYO
M;2!D)W5T:6QI<V%T975R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S
M7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(DQE(&YO;2!D92!C;VYN97AI
M;VX@JZ`E<Z"[(&5X:7-T92!DZ6K@+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DYO;2!D
M)W5T:6QI<V%T975RH#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHX"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DYO;2!D)W5T:6QI<V%T
M975RH#H@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B571I;&ES871E
M=7)S(&3I9FEN:7.@.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B3W5Z8NEK:7-T86XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-S`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8R
M"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R
M(")2Z7!E<G1O:7)E(%9&4R!I;F5X:7-T86YT+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D%B
M<V5N8V5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8S"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DQE
M<R!E;7!L86-E;65N=',@=F%L:61E<R!T<F]U=NES(&EN8VQU96YTH#H@(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(E9A;&ED:71Y(@IM<V=S='(@(E9A;&ED:73I(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")6
M86QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R(")686QE=7(@96X@
M;6EN=71E<R#@('!A<G1I<B!D92!M86EN=&5N86YT+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@U,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3<T"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")686QE=7(@<W5PZ7)I975R
M92#@(&QA(&QO;F=U975R(&UA>&EM86QE(&1E("5S+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(V,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$S(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,#<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E9A
M;&5U<G,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#,*;7-G:60@(E9A;'5E<R!T;R!S96QE
M8W0@9G)O;2(*;7-G<W1R(")686QE=7)S(.`@<^EL96-T:6]N;F5R(&1E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R(")686YU871U
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,PIM<V=I9"`B
M5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B;&4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS
M9VED(")696YE>G5E;&$B"FUS9W-T<B`B5NENZ7IU96QA(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+B(*;7-G<W1R("+)8VAE8R!D92!L82!VZ7)I9FEC871I;VX@
M)FUD87-H.R!C92!M97-S86=E(&$@<&5U="WJ=')E(.ETZ2!F86QS:69IZ2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I
M9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6]N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S
M='(@(D-O;G1R]&QE(&1E('9E<G-I;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R(")!;&EG;F5M96YT('9E<G1I8V%L(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B
M5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R(")296UP;&ES<V%G92!V97)T:6-A
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6-A;*`Z(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@
M(E9E<GD@2&EG:"(*;7-G<W1R(")4<NAS(&AA=71E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DW"FUS9VED(")6:65T;F%M97-E("A625-#24DI
M(@IM<V=S='(@(E9IZG0M;F%M:65N("A625-#24DI(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`B5F]I<B`E<R(*"B,Z(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B
M"FUS9W-T<B`B5F]I<B!U;F4@<&%G92!W96(@97AT97)N92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9O:7(@8V]M;64@)7,B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*
M;7-G<W1R("+.;&5S(%9I97)G97,@8G)I=&%N;FEQ=65S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`BSFQE
M<R!6:65R9V5S(&1E<R#)=&%T<RU5;FES(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES:6)I;&ET
MZ2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(")6:7-I8FEL:73IH#H@(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*
M;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F
M;VYE($ET86QY('9I82!33510(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B
M5T%23B(*;7-G<W1R(").3U1)0T4B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B051414Y424].
M(2$A("!355!04DE-15(@3$4@4T-225!4($U!3E5%3$Q%345.5"!$12`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS
M9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('9I82!(5%10(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B
M5V%L;&ES(&5T($9U='5N82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R(")!='1E;G1I
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4X"FUS9VED(")792(*;7-G<W1R(")-92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G
M<W1R(")0<NEV:7-I;VYS(&WI=.EO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(@IM<V=S='(@(D1O;F[I97,@;>ETZ6\@9F]U<FYI97,@<&%R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#@Y"FUS9VED(")796%T:&5R+F-O;2(*
M;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B4VET
M92!W96(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B0VAA<75E('-E;6%I;F4B
M"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L
M8V]M92(*;7-G<W1R(")":65N=F5N=64B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")":65N
M=F5N=64@X"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")":65N=F5N=64L("5S(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$I(@IM<V=S='(@(D]C8VED96YT86P@*$E33RTX.#4Y+3$I(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX
M.#4Y+3$U*2(*;7-G<W1R(")/8V-I9&5N=&%L("A)4T\M.#@U.2TQ-2DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4V%H
M87)A($]C8VED96YT86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(E%U96QL92!A<'!L
M:6-A=&EO;B`E<R!D;VET+6EL('!RZ7-E;G1E<B!A<'+H<R!L82!C;VYN97AI
M;VZ@/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED
M(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R(")1
M=65L(&5S="!L92!C87)A8W3H<F4@9&4@<^EP87)A=&EO;J`_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE
M('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B475E;"!E<W0@;&4@8V%R86-T
MZ')E(&1E(&-I=&%T:6]NH#\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`V-0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@
M;6%P(@IM<V=S='(@(D-A<G1E(%=H97)E:7,@075S=')A;&EE(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T
M<B`B475E;&QE<R!P:&%S97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I
M8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(E%U96QL97,@97AT96YS:6]N<R!A
M8W1I=F5R('!O=7(@;"?I9&ET975R(%)I8V@@5&5X="XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED
M(")7:61T:"(*;7-G<W1R("),87)G975R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$P-`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S
M='(@(DQA<F=E=7(@96X@=6YI=.ES($-34R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(B(*(DQA<F=E=7(@9'4@;65N=2!D92!G875C:&4@
M)7,@("AL82!C;VYF:6=U<F%T:6]N('!R96YD<F$@969F970@X"!L82!P<F]C
M:&%I;F4@(@HB8V]N;F5X:6]N*:`Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T
M86)L92(*;7-G<W1R("),87)G975R(&1U('1A8FQE874B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED
M=&@@=6YI="(*;7-G<W1R(")5;FETZ2!D92!L87)G975R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I
M9'1H.B(*;7-G<W1R("),87)G975RH#HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-3$U"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")7:6YD(@IM<V=S='(@
M(E9E;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV.`IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R(")696YT('3T="!L92!M
M871I;B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@
M<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5FET97-S92!D=2!V96YT(&5N(&XF
M;V5L:6<[=61S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(E9E;G2@.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R(")696YTH#H@
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB
M"FUS9W-T<B`B4V%G97-S92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(DQI<W1E(&1E('8F;V5L
M:6<[=7@B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O
M<FLB"FUS9W-T<B`B5')A=F%I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S
M='(@(D%D<F5S<V4@<')O9F5S<VEO;FYE;&QE(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N
M92(*;7-G<W1R(")4Z6SI<&AO;F4@<')O9F5S<VEO;FYE;"(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(DYO;6)R92!D92!C:&%M<',@:6YC;W)R96-T(.`@;&$@;&EG
M;F4@)60N("5D(&%T=&5N9'5S+"`E9"!T<F]U=NES+B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M(@IM<V=S='(@(DYO;6)R92!D92!C:&%M<',@:6YC;W)R96-T+B`E9"!A='1E
M;F1U<RP@)60@=')O=7;I<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T("5D
M('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B1.EC86QA9V4@
M)60@:6YC;W)R96-T(&QO<G,@9&4@;&$@;&5C='5R92!D92!F:6-H:65R(%9&
M4RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0U"FUS9VED(")8
M+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',B"FUS9W-T<B`B0V]N=')A:6YT97,@8F%S:7%U97,@6#4P.78S(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B571I;&ES871I;VX@
M9&4@8VSI(.ET96YD=64@6#4P.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64B"FUS9W-T<B`B075T<F4@;F]M(&1U('-U:F5T(%@U,#EV
M,R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS
M9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("))
M9&5N=&EF:6%N="!D92!C;.D@9'4@<W5J970@6#4P.78S(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E
M>'1E;G-I;VYS(@IM<V=S='(@(D5X=&5N<VEO;G,@6#4P.78S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(D%!(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED
M(")965E9(@IM<V=S='(@(D%!04$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,0IM<V=I9"`B66%H;V\A(&UA<"(*;7-G
M<W1R(")#87)T92"KH%EA:&]OH"&@NR(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R
M(")!;FYU96QL96UE;G0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*
M;7-G<W1R(")9Z6UE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")/=6DB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I
M9"`B665S+"!)($%G<F5E(@IM<V=S='(@(D]U:2P@:B=A8V-E<'1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I
M9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(E9O=7,@
MZG1E<R!E;B!M;V1E(*N@5&5X=&6@NRX@571I;&ES97H@;&4@8F]U=&]N(%L\
M/ET@<&]U<B!R979E;FER(&%U(&UO9&4@(@HBJZ!765-)5UE'H+LN(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B5F]U<R!N)^IT
M97,@<&%S(&%U=&]R:7/I(.`@8W+I97(@<&QU<R!D92`E9"!B;&]C<RXB"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C0*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(E9O=7,@;B?J=&5S('!A
M<R!A=71H96YT:69IZ2XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C,P.`IM<V=I9"`B66]U(&-A;FYO="!H879E('1H92`G7%PG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B5F]U<R!N92!P
M;W5V97H@<&%S(&%V;VER(&QE(&-A<F%C=.AR92"K7%R[(&1A;G,@=F]T<F4@
M;F]M(&-O;7!L970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@U
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<R"FUS9VED(")9;W4@9&ED
M(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(E9O
M=7,@;B=A=F5Z('!A<R!S86ES:2!U;F4@861R97-S92#I;&5C=')O;FEQ=64@
M=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B)6;W5S(&XG879E>B!P87,@
M87-S;V-IZ2!L97,@8VAA;7!S(&1U(&9I8VAI97(@:6UP;W)TZ2!A=7@@8VAA
M;7!S("(*(F-O<G)E<W!O;F1A;G1S(&1A;G,@)7,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N(@IM<V=S='(@(E9O=7,@879E>B#I=.D@9.EC;VYN96-TZ2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4X"FUS9VED("(B"B)9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N
M871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB5F]U<R!D979E
M>B!I;G-C<FER92!U;B!N=6WI<F\@9&4@8V5L;'5L86ER92!V86QI9&4L('-E
M=6QS(&1E<R!N;VUB<F5S(&5T('5N("(*(JN@*Z"[(&]P=&EO;FYE;"!P;W5R
M(&QE<R!A<'!E;',@:6YT97)N871I;VYA=7@N(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$X-0IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V
M86QI9"!V86QU92XB"FUS9W-T<B`B5F]U<R!N)V%V97H@<&%S('-A:7-I('5N
M92!E;G1RZ64@=F%L:61E+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB5F]U<R!D
M979E>B!C;VYF:6=U<F5R('5N(&)A8VME;F0@1&%T851R964@<&]U<B!U=&EL
M:7-E<B!L97,@:6YS8W)I<'1I;VYS(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HT-S$*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B
M86-K96YD+B(*;7-G<W1R(")6;W5S(&1E=F5Z(&-O;F9I9W5R97(@=6X@;6]D
M=6QE(%9&4RXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ
M,0IM<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*
M(E9O=7,@9&5V97H@9.EC<FER92!L92!P<F]B;.AM92!A=F%N="!D92!N;W5S
M(&9A:7)E('!A<G9E;FER(&QE(')A<'!O<G0N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S
M='(@(E9O=7,@9&5V97H@96YT<F5R('5N92!54DP@;_D@<&]I;G1E(&1E(&QI
M96XN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B26P@9F%U="!SZ6QE8W1I;VYN97(@=6X@<V5R=F5U<B#@('-U<'!R
M:6UE<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N(@IM<V=S='(@(E9O
M=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@<F5T:7)E<BX@
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")6;W5S(&1E=F5Z
M('-PZ6-I9FEE<B!U;B!U=&EL:7-A=&5U<B#@(')E=&ER97(N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N(@IM<V=S='(@(E9O=7,@9&5V97H@<W#I8VEF:65R('5N('5T:6QI<V%T
M975R(.`@86IO=71E<BXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@
M(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS
M9W-T<B`B5F]U<R!D979E>B!S<.EC:69I97(@;&4@;F]M(&1E(&PG=71I;&ES
M871E=7(@X"!M;V1I9FEE<BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA
M="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B5F]U<R!D979E>B!I;F1I
M<75E<B!Q=65L;&4@86-T:6]N(&%C8V]M<&QI<BXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")6;W5S
M(&1E=F5Z(.EC<FER92!U;B!N;VT@<&]U<B!L82!N;W5V96QL92!C873I9V]R
M:64N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A
M;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B5F]U<R!D979E>B!F;W5R;FER
M('5N(&ZP(&1E('3I;.EP:&]N92!I=&%L:65N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@
M<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G
M<W1R(")6;W1R92!S97-S:6]N("5S(&$@97AP:7+I+B!6975I;&QE>B!V;W5S
M(')E8V]N;F5C=&5R+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`B5F]T
M<F4@861R97-S92!D92!C;W5R<FEE;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B
M5F]T<F4@861R97-S92!D92!C;W5R<FEE;""K($1E.B"[H#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B5F]S
M(&1O;F[I97,@<&5R<V]N;F5L;&5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5F]T<F4@861R
M97-S92!);G1E<FYE="!A(&-H86YGZ2!D97!U:7,@;"=O=79E<G1U<F4@9&4@
M=F]T<F4@<V5S<VEO;B`E<RX@("(*(E!O=7(@=F]T<F4@<^EC=7)I=.DL('9O
M=7,@9&5V97H@=F]U<R!R96-O;FYE8W1E<BXB"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@
M(E9O=')E(&YO;2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"B)6;W1R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N
M(&YE('-U<'!O<G1E('!A<R!L)V%J;W5T(&0G=71I;&ES871E=7)S+"!3:2`B
M"B)V;W5S('-O=6AA:71E>B!U=&EL:7-E>B!(;W)D92!P;W5R(&%D;6EN:7-T
M<F5R(&QE<R!C;VUP=&5S('5T:6QI<V%T975R<RP@(@HB=F]U<R!D979E>B!U
M=&EL:7-E<B!U;B!A=71R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)6
M;W1R92!M;V1U;&4@9"=A=71H96YT:69I8V%T:6]N(&XG97-T('!A<R!E;B!M
M97-U<F4@9"?I=&%B;&ER('5N92!L:7-T92!D97,@(@HB=71I;&ES871E=7)S
M+"!O=2!C971T92!F;VYC=&EO;B!A(.ETZ2!R971I<NEE('!O=7(@=6YE(&%U
M=')E(')A:7-O;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@
M=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B)6;W1R92!N879I9V%T975R
M('-E;6)L92!A=F]I<B!C:&%N9^D@9&5P=6ES(&QE(&3I8G5T(&1E('9O=')E
M('-E<W-I;VX@)7,N("`B"B)0;W5R('9O=')E('/I8W5R:73I+"!V;W5S(&1E
M=F5Z('9O=7,@<F5C;VYN96-T97(N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z-3<*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@9F5A='5R92XB"FUS9W-T<B`B5F]T<F4@;F%V:6=A=&5U<B!N92!S=7!P
M;W)T92!P87,@8V5T=&4@;W!T:6]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O
M;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B)6;W1R92!N879I
M9V%T975R(&YE('!R96YD('!A<R!E;B!C;VUP=&4@8V5T=&4@;W!T:6]N(&0G
M:6UP<F5S<VEO;BX@4')E<W-E>B`B"B)#;VYT<O1L92]#;VUM86YD92`K(%`@
M<&]U<B!I;7!R:6UE<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C$*
M;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(E9O=')E
M(&9U<V5A=2!H;W)A:7)E(&%C='5E;*`Z(@H*(SH@<V5R=FEC97,O<')E9G,N
M<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(E9O=')E('!R;V9I;"!P87(@9.EF875T(&$@
MZ73I(&UO9&EF:>DN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM
M<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")0<F]F:6P@
M<&%R(&3I9F%U=*`Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM
M<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E9O=')E(&YO;2!C;VUP
M;&5TH#HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@
M(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(E9O=')E(&-O;7!T
M92!A(&5X<&ERZ2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@
M)7,@:7,Z("5S(@IM<V=S='(@(E9O=')E(&YO=79E874@;6]T(&1E('!A<W-E
M('!O=7(@)7,@97-TH#HE<R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@
M(E9O<R!O<'1I;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R('!O=7(@;&$@9'5R
MZ64@9&4@8V5T=&4@<V5S<VEO;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U
M<&1A=&5D+B(*;7-G<W1R(")6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@
M:F]U<BXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I
M9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R(")6;W1R
M92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"B)6;W1R
M92!M;W0@9&4@<&%S<V4@82#I=.D@<F5M:7,@X"!ZZ7)O+"!VZ7)I9FEE<B!V
M;W1R92!C;W5R<FEE<B!E="!C;VYN96-T97HM(@HB=F]U<R!A=F5Z('9O=')E
M(&YO=79E874@;6]T(&1E('!A<W-E+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B5F]T<F4@;6]T(&1E('!A<W-E(&$@97AP:7+I+B(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO
M=&4@<V5R=F5R<SHB"FUS9W-T<B`B5F]S('-E<G9E=7)S(&1I<W1A;G1SH#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S
M='(@(EEO=6=O<VQA=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F'O<F4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6F%M8FEE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B6FEM8F%B=V4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S
M='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=
M(@IM<V=S='(@(EM#86-H97(@;&5S(&-I=&%T:6]N<UTB"@HC.B!S97)V:6-E
M<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G
M<W1R(");4F%P<&]R="!D92!P<F]B;.AM95TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D
M(%1E>'0@+2(*;7-G<W1R(");069F:6-H97(@;&4@=&5X=&4@8VETZ2`M(@H*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");069F:6-H97(@;&4@=&5X=&4@
M8VETZ2`M("5S(&QI9VYE<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB
M"FUS9W-T<B`B6VQI9VYE("5S(&1E("5S72(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34U-"!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C$Q
M"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T<F%T
M:6]N(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@
M(DQI9VYE(&1E(%]C;VUM86YD92(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I
M9"`B7T1A=&%4<F5E(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I
M9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B4W5P<')I;65R(&QA(%]R86YGZ64B
M"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B
M7T=R;W5P97,B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R(")?06ED92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')?:>ETZ7,@
M9&4@;"=I;6%G92XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU
M+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7T-O;FYE>&EO;B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@
M(E],;V<@;W5T(@IM<V=S='(@(E]$Z6-O;FYE>&EO;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(E]-;V1I9FEE<B!U;B!L:65N
M('=E8BXN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<'1I;VYS(@H*(SH@;&EB
M+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!E
M<FUI<W-I;VYS(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN+BXB"FUS
M9W-T<B`B7U)E=&ER97(@=6X@;&EE;B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM
M<V=I9"`B7U-E='5P(@IM<V=S='(@(E]#;VYF:6=U<F%T:6]N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S
M"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FGI
M=.ES(&1U(%]T86)L96%U(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?
M57-E<G,B"FUS9W-T<B`B7U5T:6QI<V%T975R<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T
M<B`B8V%R;F5T(&0G861R97-S97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS
M9W-T<B`B9&5S=&EN871A:7)E(&EN8V]N;G4B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B86=E
M;F1A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-SD@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R
M(")C86QM92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(FEM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!D92!S;W)T:64B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B
M8V%N;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B:6UP;W-S:6)L92!D)V]U=G)I
M<B!L)V5N='+I92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C4Y.`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")C;&EQ=65Z(&EC
M:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS
M9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B97)R975R
M(&0G=71I;&ES871I;VX@9&4@;&$@;&EG;F4@9&4@8V]M;6%N9&4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N
M9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")E<G)E=7(@9&4@8V]N9FEG=7)A
M=&EO;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(F%B<V5N8V4@8W)I=&EQ=64@9"=U;B!F:6-H:65R('-Y<W3H;64B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B97)R975R(&1E(&9O<FUA="!D92!D
M;VYNZ64B"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C,P"FUS9VED
M(")E9&ET(@IM<V=S='(@(FUO9&EF:65R(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*
M;7-G<W1R(")E;G1RZ64@;F]N('1R;W5VZ2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")F86QL:6YG(@IM<V=S
M='(@(G1O;6)A;G0B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B9FEC:&EE<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A<BYP:'`Z,S8W(&QI
M8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G:60@(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B9&5P=6ES(&QE("5S
M("@E<RD@X"`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B96X@<F%F86QE(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I
M9"`B:#HB"FUS9W-T<B`B:*`Z(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B:&@B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B
M:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B;F]M(&0G:/1T92!I;F-O;FYU
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B:6UMZ61I871E
M;65N="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B:6YC;W)P;W+I
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS
M9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B97)R975R(&0G96YT
M<NEE+W-O<G1I92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R
M(")E<G)E=7(@;&]G:6-I96QL92!I;G1E<FYE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")L:6=N97-=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK
M:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R
M(")E<G)E=7(@;6MI<V]F<R!C;V1E("5D(&5N(&-RZ6%N="!L)TE33R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S`*;7-G
M:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE
M(@IM<V=S='(@(FYO;2(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0*
M;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")N;VX@<')I<R!E;B!C
M;VUP=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M,C`*;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B<&%S(&5N
M8V]R92!P<FES(&5N(&-O;7!T92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.3`Y"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(F)L;V,M;F]T97,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!O=7)C96YT86=E(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@
M(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(G!E<FUI<W-I;VX@<F5F=7/I
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AE;',B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M
M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(F5R<F5U<B!D:7-T86YT
M92!D86YS(&QE('!R;W1O8V]L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R:7-I;F<B"FUS9W-T<B`B<R?I
M;&5V86YT(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B<V5R=FEC
M92!N;VX@9&ES<&]N:6)L92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")M;VYT<F5R
M(&QE<R!D:69FZ7)E;F-E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A4
M5%`B"FUS9W-T<B`B<VUS,F5M86EL('9I82!(5%10(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS
M9W-T<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(F9I>&4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M
M(&5R<F]R(@IM<V=S='(@(F5R<F5U<B!S>7-TZ&UE(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S,*;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R
M(")L:7-T92!D92!TXF-H97,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T
M<B`BZ6-H96,@=&5M<&]R86ER92(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@
M=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B96YT<F5Z
M(&QE(&UO="!D92!P87-S92!D975X(&9O:7,@<&]U<B!C;VYF:7)M97(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H
M<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:>DB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U;FYA;65D(@IM
M<V=S='(@(G-A;G,@;F]M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*
M;7-G<W1R(")3Z6QE8W1I;VX@9"=U=&EL:7-A=&5U<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B
M"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C0R"FUS9VED(")W.B(*;7-G<W1R(")LH#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P;R]A<E]362YP;P``````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V,38Q-3<@,3`U,34T
M,S0Q-#(@,#$W-30U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````",@2$]21$4@07)A8FEC('1R86YS;&%T:6]N"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($AO<F1E('!A8VMA9V4N"B,@0V]P>7)I9VAT("A#*2`R,#`S(%!L871I
M;G5M($EN8RX@/'!L0'1I;G5M+FEN9F\^"B,@0W5S=&]M(%=E8B!!<'!L:6-A
M=&EO;G,@/&AT='`Z+R]P;&%T:6YU;2US>2YC;VT^"B,@4&QA=&EN=6T@1&5V
M96QO<&UE;G0@5&5A;2`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^"B,*;7-G
M:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($A/4D1%('8R
M+C`N,%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D
M92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R
M*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#,M,#0M,S`@,3(Z,#`K
M,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!0;&%T:6YU;2!$979E;&]P;65N
M="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#Y<;B(*(DQA;F=U86=E
M+51E86TZ($%R86)I8R`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[(&-H
M87)S970]0U`Q,C4V7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S8Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@(B`H=&]M;W)R;W<I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*
M;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-PIM
M<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T
M(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<
M(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D
M9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C4P"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T
M960Z("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"
M(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E
M<R!A;F0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HR-C@@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP
M:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R
M("+*Y,CMY2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM
M<V=S='(@(LKDW>W0(-KCX>W'RB#'X=7MQ^3)(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@
M;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A
M9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N
M<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO
M;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E
M<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`BUMH@
MVN''X\D@W>T@X]'(VB#'X=KCX>W)("C'X=KCX>W'RBD@Q^'*[2#*T>W/(,KD
MW>W0Y<<@S<?AQ_`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("+?X2`U(,_>[=[)
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R
M,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R("+;[=$@X^;,YL\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R(");Q^'3V-$@)7,@X^0@)7-=(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(L_=RM$@VN3'YNWD
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`BP\SD
MS\DB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E
M(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I
M;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N
M9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@2&]U<B!&
M;W)M870B"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!L:6(O0FQO8VLO=&EM92YP
M:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@
M(LCMQ^3'RM\Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G
M:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(-/'VLDB"@HC.B!F<F%M97=O<FLO
M54DO54DO4&%G97(N<&AP.C8Y"FUS9VED("(\4')E=FEO=7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A
M<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z
M>GD*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@
M(CQB/B#-U>$@SMC#.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HY,S4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C$P.3<*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*
M;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@
M4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!
M32]032(*;7-G<W1R("+DY<?1Q_`OX>WAQ_`B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)
M1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O
M=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*
M;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@
M(M_AX\D@Q^'CT>;1(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,PHC+"!F
M=7IZ>0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("+*Y-WMT#HB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(D%D9"(*;7-G<W1R("+'X=KD
MYL?D(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H
M<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L
M(&9U>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BQ^':Y.;'Y"(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS
M9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P
M"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D
M('!A:7(B"FUS9W-T<B`BP];=(,ODQ\;M(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"B,L(&9U>GIY"FUS
M9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("+/W<K1(-KDQ^;M
MY"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G
M<W1R("+/W<K1(-KDQ^;MY"(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"B,L(&9U
M>GIY"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R("+#UMT@R^3'QNTB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B
M"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D
M(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR
M"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM
M<V=S='(@(L?AVN3FQ^0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`BS]W*T2#:Y,?F[>0B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM
M<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M-#$*(RP@9G5Z>GD*;7-G:60@(D%D<R(*;7-G<W1R("+'X=KDYL?D(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-PIM<V=I9"`B06QB86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")!;&=E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N
M;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W
M"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM
M<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E
M92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@
M='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E
M<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED
M(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT
M97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@R-'MS]\@Q^'%
MX=_*T>;D[3HB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B
M06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G
M:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I
M960N(@IM<V=S='(@(LKC(,K-S^W/(-[MX\D@V^W1(./>R.;AR2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@
M(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(LW5X2#.
MV,,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS
M9VED(")!;G-W97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT
M87)C=&EC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A
M(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X
M+FAT;6PZ-@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B
MQ^'*V,CMWL?*(,?AX^;,YL_).B`E<R(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G
M<W1R("+'X<K8R.W>Q\H@Q^'CYLSFS\DZ("5S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS
M:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(LK#W^W/(,?AV.'((-[(
MX2#'X<C/P2#(VN/A[<?*(,?AU>W'Y,F_(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q,PIM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER
M960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@
M=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED
M(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?
M;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@
M=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C0P-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED
M(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP
M.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS
M9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+B(*;7-G<W1R("+*XR#1W=8@Q^'*S=[>(./D(,?AY>;MR2#CY"#>R.$@Q^'C
MSL_C(-''S^WFTRXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U
M,0HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*U<?A(,CCSL_C
M(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`HC
M+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'%RM7'X2#(X\[/
MXR#'X=P@1E10+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*
M;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(L?AS=[FX2#'X>/*
MYMW1R3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%
M>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@
M:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(M_AX\D@X]'FT2#;R-$@X][(
MYN')("C?[='([='FTRDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@
M(L?3XR#'X>/3RL[/XR#;R-$@X][(YN$@*-_MT<CMT>;3*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC
M;VY?8G)O=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G
M<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@
M(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H
M9&%Y(@IM<V=S='(@(NWFXR#'X>/MX<?/(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(N'C(.W:R]$@VN'L(,?AX]/*X]H@)7,N(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C@Y"FUS9VED(")";&]C
M:R!3971T:6YG<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED
M(")";VQD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0IM
M<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*(RP@9G5Z>GD*;7-G
M:60@(D)O<F1E<B(*;7-G<W1R("+EYM'/[2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC
M:VYE<W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D)O<F1E
M<G,B"FUS9W-T<B`BY>;1S^TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S
M"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(D)R87II
M;"(*;7-G<W1R("+'X<C1[<\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE
M=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`HC
M+"!F=7IZ>0IM<V=I9"`B0TU3(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y
M-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,34U"FUS9VED(")#86QE;F1A<B(*;7-G<W1R("+#S.3/R2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A;&TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@
M<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HS,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(N''Q>/?Q^3M
MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"XB"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E
M;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(L/,Y,_)(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A9&UI;B]U<V5R+V-L
M96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R("+%X=O'P2#'X<CAQ]L@VN0@X]3?X<DB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I
M9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(L7DU,?!(,?A
MX\SASR`E<R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z
M,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E
M;B!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A
M=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@
M;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N
M;W0@;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS
M9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T
M<B`BSNW'T<?*(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@
M3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@
M(L?AY<?*W2#'X<SFQ^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R
M;W!E<G1I97,B"FUS9W-T<B`BQ^'EQ\K=(,?AS.;'X2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL
M('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R
M=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY
M"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BQ^'EQ\K=(,?AS.;'X2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX
M.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS
M9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I
M9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A
M=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ>0IM<V=I9"`B0VAA9"(*
M;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(RP@9G5Z>GD*
M;7-G:60@(D-H86YG92(*;7-G<W1R("+*T<?,VB#:Y"#'X<K;[>W1Q\HB"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G:60@(D-H86YG
M92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-@IM<V=I9"`B(@HB0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"B,L(&9U>GIY"FUS9VED(")#:&%R(@IM<V=S='(@
M(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R
M("+'X>'>R"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H
M;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y
M;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(N'C(.W:R]$@
MVN'L(,?AX]/*X]H@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,30*(RP@9G5Z>GD*;7-G:60@(D-L96%R(@IM<V=S='(@
M(L/,Y,_)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R
M>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A
M=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*
M;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I
M9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+%V^''WB#'X>3'W=#)
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#
M;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z
M,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G:60@
M(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G
M:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(M'3YN/'
MRB(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R("+'X</FQ^/1.B(*"B,Z(&%D;6EN+V-M9'-H96QL
M+G!H<#HR,`HC+"!F=7IZ>0IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R
M("+'X</FQ^/1.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M;65N="(*;7-G<W1R("+'X</FQ^/1
M.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38V"FUS
M9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`HC+"!F
M=7IZ>0IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+1T^;CQ\HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#
M;VUP86YY(@IM<V=S='(@(L?AU-'?R2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O
M;F1I=&EO;B(*;7-G<W1R("+*Y-WMT"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E
M<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-#,*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHU,0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R
M("+?X>/)(,?AX]'FT2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I
M8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N
M;F5C=&EO;B!F86EL960N(@IM<V=S='(@(LW5X2#.V,,@SN''X2#'X<7*U<?A
M(,CCSL_C(,?AW"!&5%`N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL
M960Z("(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'%RM7'X2#(X\[/XR#'X=P@
M1E10+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`HC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("+-U>$@SMC#(,[AQ^$@Q^'%RM7'X2#(
MX\[/XR#'X=P@1E10+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S
M960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T-0HC
M+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`BS=7A(,[8PR#.X<?A(,?AQ<K5Q^$@R./.S^,@Q^'<($94
M4"XB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N
M=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F
M=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("+CS<KF
M[<?*("<E<R<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@
M(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O
M<'DB"FUS9W-T<B`BQ^'4T=_)(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I
M;&5D.B`E<R(*;7-G<W1R("+'X<W>YN$@Q^'CT\KFT<_).B`E<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G:60@(D-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S(@IM<V=S='(@(N''(,7CW\?D[<D@X>33SB`E<R#%X>P@)7,B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%
MRM7'X2#(Q^'CSL_C($Q$05`N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`BX<<@Q>/?Q^3M
MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT
M-#$*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD87`@
M<V5R=F5R(@IM<V=S='(@(N''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@4TU"
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S
M:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(N''Q>/?Q^3MR2#AQ>34Q\$@X\SASR#CS>'M("AL;V-A
M;"D@X^0@P\SA(./AW2#'X>';R2`E<SHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,3(U"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S
M(,7A["`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BX<<@Q>/?Q^3MR2#A
MY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S
M(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T
M<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A
M["`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E
M8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I
M<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@
M:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+V-O<'DN<&AP.C$S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("+AQR#%
MX]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`BX<<@Q>/?
MQ^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(N''Q>/?Q^3MR2#AW<K-($UA:6YT96YA;F-E7U1A<VL@X>'(T>WCS"`E
M<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?A
MX\[/XR!,1$%0+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A
M9"`E<RXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AY-/.("5S(,7A["`E<R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O
M:RX@)7,B"FUS9W-T<B`BX<?%X]_'Y.W)(.'%Y-3'P2#CS.'/(./-X>T@*&QO
M8V%L*2#CY"##S.$@X^'=(,?AX=O)("5S.B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("+AXR#MRN,@Q=K/Q\\@Y>;1S^T@R-3?X2#5S>W-(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+AXR#MVLO1
M(-KA["`G<&]R="<@W>T@Q=K/Q\_'RB!61E,N(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*(RP@
M9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R
M+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C($Q$05`N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<R(*;7-G<W1R("+AQR#%X]_'Y.W)(.'DT\X@)7,@Q>'L("5S(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M("+AQ\7CW\?D[<D@X<7DU,?!(./,X<\@X\WA[2`H;&]C86PI(./D(,/,X2#C
MX=T@Q^'AV\D@)7,Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM
M<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#$Y"FUS
M9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B
M0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R96%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E
M871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,S`*
M;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I
M;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G:60@(D-U
M<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#>7!R
M=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I
M9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(NWFXR`M
M(-'>X^WD(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R("+MYN/M(@H*(SH@861M:6XO9&%T871R
M964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B
M87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM
M<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B[>;C[2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@
M(D1E8V5M8F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@
M;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@
M;&EB+W!R969S+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS
M9W-T<B`BQ^'*S=[>(,?AQ]W*T<?6[2(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT($-O;&]R(@IM<V=S='(@(L?3RL[/XR#'X=[MXR#'X<7=RM''UNW)(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B
M1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("+'X<K-WMX@Q^''W<K1Q];M(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$
M969A=6QT(%-H96QL(@IM<V=S='(@(L?ARLW>WB#'X<?=RM''UNTB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O
M=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S(*;7-G:60@
M(D1E;&5T92!#96QL(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y
M"FUS9VED(")$96QE=&4@3&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS
M9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3<*;7-G:60@(D1E;&5T92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E
M('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y+FEN8SHQ
M-0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM
M<V=S='(@(L?ARLW>WB#'X<?=RM''UNTB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(M31S2#'X>/4W^')(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E
M<V-R:7!T:6]N(@IM<V=S='(@(L?AU-'-(,?ARMW5[>'M.B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+*XR#-
MW=D@Q^'*W<?5[>$@X>//[=$@Q^'DV<?C(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P
M=&EO;G,B"FUS9W-T<B`BSNW'T<?*(,?AVM'6(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P;&%Y(&1E
M=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(L[MQ]''RB#'X=K1UB(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@
M*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B
MSNW'T<?*(,?AVM'6(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP
M.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS9VED(")$;R!N
M;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'`B"FUS9W-T<B`BX<<@RL_.X2#CR,?4T<GP(,7A["#'X>/AW2!M
M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ,B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$
M;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B
MP^/1(-OMT2#CVM'FW2`E<SHB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM<V=S='(@(L?AR-'MSR(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS
M9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R
M<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G
M:60@(D5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED
M(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DX(&%D;6EN+V=R;W5P<RYP:'`Z,C(V"FUS9VED(")%9&ET($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z,C,W"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I
M;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R
M(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E
M<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L
M(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("+'X<C1
M[<\@Q^'%X=_*T>;D[2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ
M>0IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("+:Y.;'Y"#(T>W/WR#'
MX<7AW\K1YN3M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L(&9U>GIY"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+CVN'FX\?*
M(,+.T>PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P
M+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y
M.`HC+"!F=7IZ>0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(L[MQ]''RB(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,@HC+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B
MX<?*YLS/(.3*Q\;,+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T
M<B`BX<?*YLS/(.3*Q\;,+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R
M"FUS9VED(")%<G)O<B(*;7-G<W1R("+.V,,B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%
M=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+?X2`Q-2#/WNW>
MR2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+?X2`U(,_>[=[)(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(M_A(#,P
M(,_>[=[)(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS
M9W-T<B`BW^$@-2#/WNW>R2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@
M(M_A(,_.YN$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED
M(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`BW^$@Y-7=(-/'VLDB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("+?X2#/WNW>R2(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M
M<&QE('9A;'5E<SHB"FUS9W-T<B`BP^/+X<D@VN'L(,?AWNWC.B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M
M:6XO<W%L<VAE;&PN<&AP.C$R-PHC+"!F=7IZ>0IM<V=I9"`B17AE8W5T92(*
M;7-G<W1R("+*Y-WMT#HB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O
M9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>':R^;1(-KA["#'X<K=UNWAQ\HN
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%
MRM7'X2#(Q^'CSL_C($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+B(*;7-G<W1R("+AQ\7CW\?D[<D@X>'%RM7'X2#(Q^'CSL_C(%--0BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<
M(BXB"FUS9W-T<B`BX<?%X]_'Y.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I
M;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("+AQ\7CW\?D
M[<D@X>'%RM7'X2#(Q^'CSL_C(%--0BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("+AQ\7CW\?D[<D@X>':R^;1
M(-KA["#'X<K=UNWAQ\HN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM
M<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(LW5X2#.V,,Z(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B
M1F%X(@IM<V=S='(@(MW'W],B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R("+=Q]_3(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G
M:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@
M(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I
M9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM
M<V=S='(@(L?AX=[((@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE
M($UA;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+'X<?3
MXR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I
M;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M
M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4V"FUS
M9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM<V=I9"`B1F]G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C,T(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G
M:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM
M<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S0*;7-G:60@
M(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW.0IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-C(*;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*(RP@9G5Z>GD*
M;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(N/AQ\W9Q\HB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,PIM<V=I9"`B1F]R
M=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(D9R86UE<R(*;7-G<W1R("+'
MX<?3XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC
M92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM
M<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C`*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0P-@IM<V=I9"`B1G)O
M;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM
M<V=S='(@(L?AU-'-(,?ARMW5[>'M.B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*(RP@9G5Z>GD*;7-G:60@
M(D9U;&P@3F%M92(*;7-G<W1R("+'T^/?.B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB
M:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N
M:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*
M;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P
M7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'
M=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`IM<V=I9"`B1W5E
M<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(
M5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@(DA45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N
M9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T
M;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS
M9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM
M<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N
M<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T
M97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R("+'X>/3
MQ]K/R2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@
M(DAE;'!E<B(*;7-G<W1R("+'X>/3Q]K/R2(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S
M='(@(L?AR,_'[<DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U,S4*;7-G:60@(DAO;64B"FUS9W-T<B`BQ^'(
MS\?MR2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(MKDYL?D(,?AX^32
MX2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R
M("+EQ\K=(,?AX^32X2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED
M(")(;W)D92(*;7-G<W1R("+EYM'/[2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D
M92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@
M)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R
M(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I
M9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ
M;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I9"!Y;W4@
M9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM
M<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P
M"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I
M<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N9V%R>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S(@IM<V=S
M='(@(L?AVN3FQ^0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N
M<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*
M;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E
M9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I
M9"`B26-O;G,@3VYL>2(*;7-G<W1R("+#[=[FY,?*(-W>V"(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(L/MWN;DQ\H@
MX]H@Y-7FU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@
M(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@
M(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N
M(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P
M87)E;F-Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G
M92!U<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S<*;7-G:60@(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))
M;7!O<G0L(%-T97`@)60B"FUS9W-T<B`BQ^'-WN;A(,?AX]/*YM'/R3H@)7,B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BQ^'-WN;A
M(,?AX]/*YM'/R3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C8U"FUS9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(L?AS=[FX2#'
MX>/3RN;1S\DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ,S4*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(L[8PR#=[2#'T^,@Q^'C
MT\K.S^,@YB_#YB#?X>/)(,?AT]$N(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B
M"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("));F1O;F5S:6$B"FUS
M9W-T<B`BRN,@R.3,Q\TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@9G5Z>GD*;7-G:60@(DEN
M9F]R;6%T:6]N(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,S,`IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N
M9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E
M<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@
M(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R
M="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T
M(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@
M86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM
M<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(S,`IM<V=I9"`B26YS97)T('1H92!R97%U
M:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G
M:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`BQ^'*V,CMWL?*(,?A
MX^;,YL_).B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED
M("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G
M:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B
M26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<W"FUS9VED("));G9A;&ED(&QI8V5N<V4@
M:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3<Q"FUS9VED("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE
M=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"FUS9VED
M("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C
M="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C
M;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT
M.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I
M9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED
M("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G
M:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.0IM<V=I9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O
M9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED
M("))<W-U97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R("+M
MYN/M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS
M9VED(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F%P86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*
M;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S
M8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T
M:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*
M;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B
M2G5N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS
M9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU
M<W1I9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M87IA:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B
M2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("+'X>/.S^,@W^W1R.W1YM,@T=W6(,?ARLW>WB#CY"#'X>7F[<DN(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W
M8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME>2!&
M:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+
M97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S
M='(@(LW,XR#'X<?3RL[/Q^,Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-S0P"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHX"B,L(&9U>GIY"FUS9VED("),85]Y;W5T(@IM<V=S
M='(@(L[1YLPB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS
M9VED("),86YG=6%G92(*;7-G<W1R("+'X>';R2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(
M86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-@IM
M<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX.`IM<V=I
M9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(L[1
MYLPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I
M9"`B3&5F="!V86QU97,B"FUS9W-T<B`BP^/+X<D@VN'L(,?AWNWC.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE
M=F5L(@IM<V=S='(@(L/(S\?P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E
M<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R
M86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B
MS\[FX2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),
M:6=H="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG
M:'0@4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK
M(@IM<V=S='(@(L_.YN$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U
M"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@
M(DQI;FMS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@
M=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S97,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI
M<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`BWL?&X\D@VN3'YNWD(,?AX]/'VL_)
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.30*;7-G:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM
M<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(M['QN/)(-KDQ^;MY"#'X>/3Q]K/
MR2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS
M9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS
M9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T
M:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"B,L(&9U>GIY"FUS9VED
M("),;V%D:6YG+BXN(@IM<V=S='(@(LK-X^WA(,?AX]_*R,?*+BXN(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B3&]C86P@
M=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX
M,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T
M<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(L_.YN$B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P
M<F5V:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R
M("+.T>;,(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY
M"FUS9VED("),;V=I;B(*;7-G<W1R("+/SN;A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`BQ^'CY>/'RB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY
M-@HC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U
M<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB
M"FUS9W-T<B`B(@HBS=7A(,[8PR#AT\C((./'(,/+Y,?!(,?AS\[FX2X@VN'L
M(,?AP]',S2##Y"#'T^,@Q^'CT\K.S^,@P^8@W^'CR2#'X>/1YM'A[=/*("(*
M(M7-[<W)(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"B,L(&9U
M>GIY"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@(MW4X2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO
M;F<@=&5X="(*;7-G<W1R("+.T>;,(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS
M9W-T<B`BU.71("T@T=[C[>0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I
M9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z
M>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*;7-G<W1R("+'X<C1
M[<\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-
M86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B36%K92!L:6Y?
M:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@
M(DUA;&%W:2(*;7-G<W1R("+'X<C1[<\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@
M(DUA;&%Y<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L
M9&EV97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED
M(")-86QI(@IM<V=S='(@(L?AR-'MSR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B36%L=&$B"FUS9W-T<B`BQ^'(T>W/(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.CDQ"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@
M8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@
M8V]L;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#@T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,38X"FUS9VED
M(")-87!1=65S="!M87`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-87!P:6YG<R!S=&]R960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8W"FUS9VED(")-87)C:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"B,L(&9U>GIY"FUS
M9VED(")-87)G:6XB"FUS9W-T<B`BRN3([>4B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H
M97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-
M871C:&EN9R!F:65L9',B"FUS9W-T<B`BX]C'R-[)(,?AS=[FX2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-
M87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O
M<G1A;"!";&]C:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.#DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG
M=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@HC+"!F=7IZ>0IM
M<V=I9"`B365M8F5R<R(*;7-G<W1R("+CT-_1Q\HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(N;6
MVB#'X>/0W]''RCHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+1T\?AR2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B
M"B)-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE
M<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$P"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(M'3Q^')(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I
M9"`B365S<V%G92!T>7!E(@IM<V=S='(@(M'3Q^')(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("+*XR#-W=D@Q^'*W<?5[>$@X>//[=$@
MQ^'DV<?C(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-0IM
M<V=I9"`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C@Q(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H
M<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE=')I
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@
M(DUI9&1L92(*;7-G<W1R("+'X<C1[<\B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E
M>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G
M<W1R("+.V,,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG
M(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N
M9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO
M=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8X"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO
M9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A
M+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O
M;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U
M.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO
M;G1H;'DB"FUS9W-T<B`BU.71[<?P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-
M;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3<R(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X
M<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U
M-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO
M<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S,*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM
M<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U
M;FYY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C4P.0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4Q,PIM<V=I9"`B36]V
M92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4Q-PIM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*;7-G:60@
M(DUO=F4@57`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G
M:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI
M<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B
M375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED
M(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(LCMQ^3'RM\Z(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R
M=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ
M,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@
M22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BQ^''T^,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5T
M:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE
M<FQA;F1S($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,PIM<V=I9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#4*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!54DPB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@
M(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!2
M979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E
M<B!N86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@W"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@P"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G
M:60@(DYE='=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T
M<B`BP\C/Q_`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B
M3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+?X>/)(,?A
MX]'FT2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N
M("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z
M>GD*;7-G:60@(DYE=W,B"FUS9W-T<B`BX^''S=G'RB(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS
M9W-T<B`BVN;/R2#%X>P@Q^'.[<?1Q\HB"@HC.B!F<F%M97=O<FLO54DO54DO
M4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R("+#R,_'\"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P"FUS9VED(").:6=H="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*(RP@9G5Z>GD*;7-G:60@(DYI=64B"FUS
M9W-T<B`BRN3([>4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("+AQR(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA
M8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A=&5G>2!F
M;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B
M3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DYO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(N''RN;,SR#?X>/)(./1YM$@X>'*S=[>(%--0CXB"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*
M;7-G<W1R("+*T<?,VB#:Y"#'X<K;[>W1Q\HB"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E
M(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(N''RN;,SR#C
MVN'FX\?*(,WFX2#%VL_'S\?*(,?AW"!344P@5D93+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B
MX<?*YLS/(./:X>;CQ\H@S>;A(,7:S\?/Q\H@Q^'<($944"!61E,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*
M;7-G<W1R("+AQ\KFS,\@X]KAYN/'RB#-YN$@Q=K/Q\_'RB#'X=P@4U%,(%9&
M4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+AQ\KFS,\@X]KAYN/'RB#-YN$@
MQ=K/Q\_'RB#CX=W'RB!344P@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O
M;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-CD*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R("+AXR#MRN,@RLW/[<\@X=O)(./-X>W)+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS
M9VED(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("+AXR#MRN,@RLW/
M[<\@X=O)(./-X>W)+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,V"B,L(&9U>GIY"FUS9VED(").;R!N86UE('-P
M96-I9FEE9"XB"FUS9W-T<B`BX>,@[<KC(,K-S^W/(.';R2#CS>'MR2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-PHC+"!F=7IZ>0IM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`BX>,@[<KC(,K-S^W/(.';R2#CS>'MR2XB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-
MWMX@3$1!4"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P
M.`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@
MX>'*S=[>($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("+AQ\KFS,\@W^'CR2#CT>;1(.'A
MRLW>WB#?[='([='FTR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP
M:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(N''RN;,SR#?X>/)(./1YM$@X>'*S=[>($Q$05`N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@4TU"
M/B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@4TU"/B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB
M3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/
M<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+
M0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BX^''S=G'RB(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`BX>,@[<KC
M(,K-S^W/(.';R2#CS>'MR2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S
M:61E<R(*;7-G<W1R("+CX<?-V<?*(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU.#,*;7-G:60@(DYO('-U8V@@9FEL92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T
M96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C(Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S
M<W=O<F0@<V5N="XB"FUS9W-T<B`BSMC#(-WM(,?3XR#'X>/3RL[/XR#F+\/F
M(-_AX\D@Q^'3T2XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP
M.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R
M:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R.`IM
M<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM<V=I
M9"`B3F]N92(*;7-G<W1R("+*XR#(Y,S'S2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I
M;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#D*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`HC+"!F=7IZ
M>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@(L7DU,?!(,?AX\SA
MSR`E<R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP
M;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B
M"FUS9W-T<B`BX^''S=G'RB(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(N/AQ\W9Q\HB"@HC
M.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI
M;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0HC+"!F=7IZ>0IM<V=I
M9"`B3F]V96UB97(B"FUS9W-T<B`BP\C/Q_`B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T
M<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS
M9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T-2!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`HC+"!F=7IZ
M>0IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`BVL_/(,?AP]KC
MS\D@W>T@Q^'CX<[5.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A
M=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8T"FUS9VED(")/
M2R(*;7-G<W1R("+CYL?=WB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T
M($-R96%T;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED
M(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM
M<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C0V"B,L(&9U>GIY"FUS9VED
M(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N(@IM<V=S='(@(L[8PR#=
M[2#'T^,@Q^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/
M<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(L[MQ]''RB(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`BSNW'
MT<?*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/<F=A;FES
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B
M3W)G86YI>FEN9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,0IM<V=I9"`B3W1H97(@26YF
M;W)M871I;VXB"FUS9W-T<B`BX]KAYN/'RB#"SM'L(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y
M"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A8VME;F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W,PIM
M<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%
M;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S
M"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0
M($-O9&4B"FUS9W-T<B`BY>;1S^TB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG:'0@
M4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I
M9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*
M;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I
M9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R
M("+'X<?3XR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED
M(")087-S=V]R9"(*;7-G<W1R("+?X>/)(,?AX]'FT2(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O
M<F0@:6YC;W)R96-T(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`BX<?*YLS/(-_AX\D@X]'FT2#AX<K-WMX@T<?/[>;3+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z
M(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO
M8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T
M<B`BW^'CR2#'X>/1YM$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G
M:60@(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O
M87)D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG
M;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T
M"B,L(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`BQ^'/YM$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I
M9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS(@IM<V=S='(@(LKDW>W0(-KCX>W'RB#'X=7MQ^3)
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@HC+"!F=7IZ>0IM<V=I
M9"`B4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*
M;7-G<W1R("+*Y-WMT"#:X^'MQ\H@Q^'5[<?DR2(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H
M:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U"B,L(&9U>GIY"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R("+CVN'FX\?*(,+.T>PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED
M(")0971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP
M<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`BY<?*W2(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M
M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R
M(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H
M92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM
M<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M
M+B(*;7-G<W1R("+'X=',Q\$@RM+F[<_DQR#CX<[5(,?AX]3?X<DN(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("+'X=',Q\$@RM+F[<_DQR#(Q]/C
M(,?AX]/*SL_C(.;?X>/)(,?AT]$N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG
M('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T
M:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y
M<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T
M(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.3@*;7-G:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP.CDX"FUS
M9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S
M97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@
M<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S
M=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(P-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z
M>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`BVN;/R2#%X>P@
MQ^'.[<?1Q\HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R
M:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T
M<B`B6\K>T>W1(,?AX]3?X<E=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(M31S2#'
MX>/4W^')(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I
M9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*
M;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@
M(E%A=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM
M<V=I9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I
M9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V
M"FUS9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("+1T\?AR2(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@
M(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$*;7-G:60@
M(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E
M9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")2
M96UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N
M97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R
M("+%TN')(,?AR^3'QNTB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+%
MTN')(,?AR^3'QNTB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(L72
MX<D@Q^'+Y,?&[2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE
M(@IM<V=S='(@(L72X<D@Q^'+Y,?&[2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+%TN')(,?AR^3'QNTB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("+%TN')
M(,?AR^3'QNTB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S
M.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N
M960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$U-PIM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U
M;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
MX>,@[=K+T2#:X>P@)W!O<G0G(-WM(,7:S\?/Q\H@5D93+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW
M,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<
M(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("+AXR#MVLO1(-KA["`G<&]R="<@W>T@Q=K/Q\_'RB!61E,N(@H*(SH@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+AXR#MVLO1(-KA["`G<&]R="<@W>T@Q=K/
MQ\_'RB!61E,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP
M:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G
M:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(M_AX\D@Q^'CT>;1(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@
M861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B
M"FUS9W-T<B`BVN;/R2#%X>P@Q^'.[<?1Q\HB"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*(RP@
M9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R
M("+:YL_)(,7A["#'X<[MQ]''RB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I
M9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("+'X<_FT2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E
M(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X
M"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B
M4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R
M;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(L?AS^;1(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W
M<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED
M(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)W86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX
M,0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T
M"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(M'3Q^')
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM
M<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")3
M4T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T53
M4R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U
M96QO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6
M:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")3
M86UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B
M4V%N($UA<FEN;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3
M86\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I
M9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DW"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A=61I($%R
M86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C(Q-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R("+-W=D@Q^'.[<?1Q\HB"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BS=W9(,?A
MSNW'T<?*(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B
M4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM
M<V=I9"`B4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C
M="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D
M871E(@IM<V=S='(@(L?.RM$@RN33[=X@Q^'*Q]'MSCHB"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@
M=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C
M="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-PIM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C8S"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86QL(&1A=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`BQ\[*T2#*Y-/MWB#'X<K'
MT>W..B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I
M9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82XB"FUS9W-T<B`BS<_/(,?AS='FW2_'X='CYM(@Q^'*[2#*T>W/Y<<@P\_D
MQ^4N(.;CY"#+XR#MX]_D(.33SN7'YN'5WN7'(-;CY"#'X>35+B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+'SLK1(,?AW>;'U>$@X>'*Q]'MSCHB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`BQ\[*T2#*Y-/MWB#'X<K'T>W.
M.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*
M;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC
M+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS
M9W-T<B`BQ\[*T2#'X=WFQ]7A(.'ARL?1[<XZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(L?.RM$@RN33[=X@Q^'FWLHZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N(@IM<V=S='(@(L7.RM$@S=[A[>0@X\KCQ\OA[>0N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C0X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z
M(@IM<V=S='(@(L7.RM$@X=O*WR#'X>/=UN').B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(L/1T^$@RM[1[=''\"#(X]3?X<D@S=7ARB(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#,Y"FUS9VED
M(")396YD(%--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3
M96YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$V
M"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P=&5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@
M(E-E<FEA;"!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V,0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O;F<@;W(@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(W"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,@IM
M<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M87!I+G!H<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@
M(LW=V2#'X<[MQ]''RB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G
M<W1R("+'SLK1(,K-S^W+(,?AU=W-R2#FSNW'T<?*(,?AU,?4R2#'X</.T>PN
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED
M("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T
M:6]N<RXB"FUS9W-T<B`BQ\[*T2#*S<_MRR#'X=7=S<D@YL[MQ]''RB#'X=3'
MU,D@Q^'#SM'L+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G
M:60@(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ.#8*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE
M('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z
M>GD*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BQ^'DRNW,R2#'X>/.
MRM71R3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$U-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W
M965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B
M"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#DP"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN
M86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q
M,PIM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(L7EX^$@
MQ^'5[<?DR2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T
M"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W
M(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS
M9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I
M9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS9VED(")3;W5R8V4@861D
M<F5S<R(*;7-G<W1R("+:Y.;'Y"#'X=KCX2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G
M:60@(E-O=71H($%F<FEC82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y,`IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I
M82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV
M,@IM<V=I9"`B4V]U=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX,34*
M;7-G:60@(E-P86-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B4W!A:6XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDX"FUS9VED(")3<&%M
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I
M9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T<B`BQ<_.Q]$@S='F
MW2#.Q]7)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I
M9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(L?3RNW1
MQ\\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T
M<B`BP\SDS\DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@
M(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W1O<F%G92!F;W)M
M870B"FUS9W-T<B`BR.W'Y,?*WSHB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E
M<W,B"FUS9W-T<B`BVN3FQ^0@Q^':X^$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*
M;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H
M92!A9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5B9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(N'C(.W:
MR]$@VN'L(,?AX]/*X]H@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS9W-T
M<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP
M="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BRN,@R.3,Q\TB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S
M9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BQ^'.X<?5
MR2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I
M<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS
M9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS9VED(")3
M=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS
M970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G:60@(E-U;G-E="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$X"FUS9VED
M(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C<FEP="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<X"B,L(&9U
M>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(L?3RNW1Q\\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"B,L(&9U>GIY"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("+'X<?3
MXR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L
M(&9U>GIY"FUS9VED(")3=7)N86UE(@IM<V=S='(@(L?AQ]/C(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@
M9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM
M<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(L?AX=[((@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G
M:60@(E1A8FQE(@IM<V=S='(@(L?AX=[((@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@
M4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G
M:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
MS<SC(,?AQ]/*SL_'XSHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(L?AX^7CQ\HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M<"!F;W(@
M;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E<F%T=7)E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB<B`O/B@E
M<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*(RP@9G5Z
M>GD*;7-G:60@(E1E>'0B"FUS9W-T<B`BY-4@W=[8(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(N35
M(-W>V"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`BY-4@W=[8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I
M9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN(@IM<V=S='(@(LKC(,?ASM'FS"#(Y,S'S2X@/&)R
M("\^(-3?T<?P(.''T\K.S\?CW^,@Y=#'(,?AY-G'XRXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I
M;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O
M24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@
M;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@
M861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@
M4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM
M<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D
M(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H
M92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET
M<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I
M9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@
M<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R
M;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD
M+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET
M)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB
M4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO
M=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE
M=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU
M4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L
M87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP
M:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D
M:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B
M92!N=6UE<FEC+B(*;7-G<W1R("+MS,@@P^0@RM_FY"#ET.4@Q^'>[>/)(-'>
MXRXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*
M;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V
M960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"B+AXR#MRN,@Q^':R^;1(-KA["#'X<C1Y,?CS"#'X>/3RL[/XR#A
MQ=GEQ]$@Q^'1T\?&X2#CY"#DYMH@*"5S*2#6X^0@Y-G'X]\N(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED(")4:&4@<75O=&4@
M8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E
M<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,3<W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+%Y"#CX=W'
MRB!03R#AX=O)("5S(-OMT2#CYLSFS\DB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@
M;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B
M5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S
M('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V
M+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I
M9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@
M;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(N''RN;,SR##[<D@RMW6[>''
MRBXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S
M97(N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R
M(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T
M:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS
M.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I
M;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG
M('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I
M;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@
M=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES
M($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS
M9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU
M;6)E<BXB"FUS9W-T<B`B[<S((,/D(,K?YN0@Y=#E(,?AWNWCR2#1WN,N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG
M(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET
M86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@
M<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-30*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X
M,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*;7-G:60@(E1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y-`IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R
M,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY"FUS9VED(")4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(NW,R"##
MY"#*W^;D(.70Y2#'X=[MX\D@T=[C+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP
M+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U
M<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE
M960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA
M<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED
M(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B
M[<S((,/D(.W?YN0@Y=#'(,?AT=[C(,/?R-$@X^0@Q^'5W=$B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+B(*;7-G<W1R("+MS,@@P^0@RM_FY"#ET.4@Q^'>[>/)(-'>XRXB"@HC
M.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I
M;64B"FUS9W-T<B`BQ^'AWL@B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@V"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B
M5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I
M9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`BQ^'AWL@B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*
M;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI
M;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@
M(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"B,L(&9U>GIY"FUS9VED(")4;V=O(@IM<V=S='(@(L[1YLPB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4;VME;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3,*;7-G:60@(E1O;6]R<F]W(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H
M7W1O<"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S
M"FUS9VED(")4<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A
M;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U=F%L
M=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C8T"FUS
M9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM<V=I9"`B52Y6+B!I;F1E>#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E52
M3"(*;7-G<W1R("+:Y.;'Y"#'X<7DRM'D[<HB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O
M<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T<B`BVN3FQ^0@Q^'%Y,K1
MY.W*(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#$R"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(N''
M(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BX<<@Q>/?Q^3M
MR2#ARMOM[=$@Q^'3X\?-[<?*(.'CX=T@5D93("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(N''(,7CW\?D[<D@X<K;[>W1(,?AT^/'S>W'RB#AX^'=(%9&4R`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C(%-13"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(S,@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N
M(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<
M(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV
M.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E
M<UPB+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=
M(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C0S-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BXB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AX<7*U<?A(,CCSL_C(%-13"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(N''(,7C
MW\?D[<D@X>'%RM7'X2#(X\[/XR!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#A
MRMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C,V-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HR-38*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V
M9G-R;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM
M<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&
M4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*
MV^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(V-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'
MY.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HR.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<
M(B5S7"(Z("5S+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3
MXR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DB"FUS9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R
M;V]T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`BX<<@Q>/?Q^3MR2#AWM''P<D@X\SASR!V9G-R;V]T+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("+AQR#%
MX]_'Y.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+A
MQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92XB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WM
MT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("+A
MQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'
MT^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T97)M
M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>
MT<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I
M9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])
M35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H
M+G!H<#HQ,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("+AQR#%X]_'
MY.W)(.'>T<?!R2#CS.'/('9F<W)O;W0N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@
M(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7C
MW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&
M4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
MX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3
MXR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("+AQR#%X]_'Y.W)
M(.'AQ<K5Q^$@R./.S^,@4U%,+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3M
MR2#ARMOM[=$@Q]/C("#CX=T@Q^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#8V"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R
M("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O
M)7,N(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!F:6QE.B`B"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@
M(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@
M9&ER96-T;W)Y+B(*;7-G<W1R("+AQR#%X]_'Y.W)(.'>T<?!R2#CS.'/('9F
M<W)O;W0N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM
M<V=S='(@(N''(,7CW\?D[<D@X=[1Q\')(./,X<\@=F9S<F]O="XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'
MX=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./A
MW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(N''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C("#CX=T@
MQ^'<(%9&4R`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S`Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE+B(*;7-G<W1R("+AQR#*YLS/(,7CW\?D[<D@X<K;[>W1(,?3XR`@
MX^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`BX<<@RN;,SR#%X]_'
MY.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@
M(MOMT2#>Q\_1(-KA["#*T<SCR2#CT\KDSR#'X>;1SR#ET,<B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$U,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`BX<<@RN;,SR#%
MX]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93("5S+R5S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS
M9W-T<B`BX<<@RN;,SR#%X]_'Y.W)(.'*V^WMT2#'T^,@(./AW2#'X=P@5D93
M("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("+AQR#*YLS/
M(,7CW\?D[<D@X<K;[>W1(,?3XR`@X^'=(,?AW"!61E,@)7,O)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T,0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@
M(LK1Q\S:(-KD(,?ARMOM[=''RB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@
M86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O
M;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z
M('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"B,L
M(&9U>GIY"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(MW4X2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A
M=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI
M;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D
M(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET
M960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M
M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI
M96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*(RP@9G5Z>GD*;7-G:60@(E5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(L[8PR#=[2#'T^,@
MQ^'CT\K.S^,@YB_#YB#?X>/)(,?AT]$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC+"!F=7IZ>0IM<V=I9"`B
M56YN86UE9"(*;7-G<W1R("+'X<?3XR(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E
M9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A
M;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@
M=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@
M(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@
M=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@
M8V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY,S(*;7-G
M:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,PIM<V=I9"`B57!D871E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P
M"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G
M<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P
M<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L
M(&9U>GIY"FUS9VED(")5<V5R(@IM<V=S='(@(L?3XR#'X>/3RL[/XR(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S(S"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@
M(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*
M;7-G<W1R("+.[<?1Q\H@Q^'CT\K.S^,B"@HC.B!S:6=N=7`N<&AP.C8R"B,L
M(&9U>GIY"FUS9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("+.[<?1
MQ\H@Q^'CT\K.S^,B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#8Y"FUS9VED
M(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(L?3XR#'X>/3
MRL[/XR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HQ,C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@
M97AI<W1S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.#<*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("+'
MT^,@Q^'CT\K.S^,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(L?3XR#'X>/3
MRL[/XR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G
M:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C(U-0IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q
M.`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U;F0@
M:6YC;'5D93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C,X"FUS9VED(")686QI9&ET>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-34*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A
M;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C,Q-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A
M;'5E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E
M<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS
M9VED(")686YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R
M:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N
M('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E
M<G-I;VX@0V]N=')O;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A
M;"!A;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@
M3F%M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS
M9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#(Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES
M;&%N9',L(%4N4RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C@T"FUS9VED(")6;V1A9F]N92!)=&%L>2!V:6$@
M4TU44"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-
M04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PIM<V=I9"`B5TE.('9I82!(5%10
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HX,PIM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+*Y,CMY2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*
M;7-G:60@(E=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")7
M96%T:&5R(&1A=&$@<')O=FED960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED(")796%T:&5R+F-O;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*
M;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G
M<W1R("+#T\CFVNW'\"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP
M.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(L/EX<<@YM/E
MX<<@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5V5L8V]M92!T;R`E<R(*;7-G<W1R("+#Y>''(,C?XR#%X>P@)7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B
M"FUS9W-T<B`BP^7AQR#FT^7AQR`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")7
M97-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P
M<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G
M<W1R("+CQR#'X<C1Y,?CS"#'X>/*T=8@VM'6Y2#CY"#EYM'/[2#(VL\@Q^'/
MSN;AOR(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED
M(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA
M="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3
M('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@
M;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S
M"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I
M9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@HC+"!F=7IZ>0IM<V=I
M9"`B5VEN9#H@(@IM<V=S='(@(LKDR.WE.B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E=I<VAL:7-T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+:Y.;'
MY"#'X=KCX2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BY<?*W2#'X=KC
MX2(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E
M9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A
M(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@
M2V5Y(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E
M;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S
M='(@(M/DR2`M(-?7(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(M/D
MR2`M(-?7(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B
M665A<FQY(@IM<V=S='(@(M/DYNW'\"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("+DVN,B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@X"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N(@IM<V=S='(@(LKC(,K-S^W+(,?ASNW'T<?*(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL
M>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N
M86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(NW,R"#4T<T@Q^'CU-_AR2#>
MR.$@Q]'3Q^$@RM[1[=''\"#(Y<<N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@
M=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G
M:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE
M960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(L?DRN7*(-7AQ\WMR2#'X<?*U<?A
M("5S+B#'X=',Q\$@Q=K'S\D@Q^'/SN;A+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL
M($%D9')E<W,B"FUS9W-T<B`BVN3FQ^0@R-'MS]\@Q^'%X=_*T>;D[3HB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9
M;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(MKDYL?D(,C1[<_?(,?AQ>'?
MRM'FY.TZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(LCMQ^3'RM\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N
M970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(EEO
M=7(@3F%M92(*;7-G<W1R("+'T^/?.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO
M=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C
M;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A
M=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T
M:&5R(')E87-O;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E
M<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R
M:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N
M=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("+*XR#*S<_MRR#'X<[M
MQ]''RB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-3@*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`BQ^'*S=[>
M(,?AQ]W*T<?6[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#$*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("+'T^/?.B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(LKC(,K-S^W+
M(,?ASNW'T<?*(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$U-`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+B(*;7-G<W1R("+*XR#*S<_MRR#'X<[MQ]''RB(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(LKC(,K-S^W+(,?ASNW'T<?*(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I
M;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O
M<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L
M879I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I
M9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z.#@*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T
M<B`B6\K>T>W1(,?AX]3?X<E=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");
M4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6\?AT]C1("5S(./D("5S
M72(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T
M97,O<&]R=&%L+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*
M(RP@9G5Z>GD*;7-G:60@(E](96QP(@IM<V=S='(@(L?AX]/'VL_)(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY
M"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(L_.YN$B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G
M(&]U="(*;7-G<W1R("+.T>;,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI
M;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B
MSNW'T<?*(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E
M($QI;FLN+BXB"FUS9W-T<B`BQ=+AR2#'X<ODQ\;M(@H*(SH@;&EB+V%P:2YP
M:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED
M(")?5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I
M+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S
M<R!B;V]K(@IM<V=S='(@(L_=RM$@VN3'YNWD(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("+#S.3/R2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@
M(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`*;7-G:60@(F-A;FYO
M="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C
M;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S>7-T
M96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D871A(&9O<FUA="!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S
M='(@(MOMT2#CYLSFSR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I
M9"`B9FEL92(*;7-G<W1R("+=U.$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N
M<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I
M(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B
M:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M
M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@
M(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F
M='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F
M<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C
M;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@IM<V=I9"`B;F%M92(*;7-G<W1R
M("+'X<?3XR(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M
M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B
M<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R("+*Y,CMY2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*;7-G:60@
M(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E
M;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM
M<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I<'0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V
M"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y
M(&%G86EN(@IM<V=S='(@(M_A(,_.YN$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M-B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")T
M>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF:65D(@IM<V=S='(@(MW4X2(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*(RP@9G5Z>GD*
M;7-G:60@(G5N;F%M960B"FUS9W-T<B`BQ^''T^,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B
M=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+W5K7U5!+G!O````````````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8P-34V,R`Q
M,#4Q-30S-#$T,B`P,3<U,S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````(R!(;W)D92!5:W)A:6YI86X@2T])."U5('1R86YS
M;&%T:6]N"B,@0V]P>7)I9VAT("A#*2`R,#`R($%N9')I>2!+;W!Y<W1Y86YS
M:WDN"B,@06YD<FEY($MO<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N
M=6$^+"`R,#`R+@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U6
M97)S:6]N.B!(;W)D92!V,BXQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P
M,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,BTP,2TP-2`Q-CHQ-2LP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($%N9')I
M>2!+;W!Y<W1Y86YS:WD@/&%N<FE`<&]L>6YE="YL=FEV+G5A/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@56MR86EN:6%N(#QW96)M87-T97)`<&]L>6YE="YL=FEV
M+G5A/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U+3TDX+55<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#@M8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,W
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-C4Y"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5')E
M92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R
M964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S
M7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R("+U
MT]"FV\[/(,3/Q,'.SR`G)7,G(,3/(-/)T]3%S<DN(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O
M9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S
M=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F
M;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("+OT,72
MP<.FT2#0TL_&ILS!R]3)WL[/Q\\@S\+3S-7'S]?5U\'.SM$@)7,@+2#PIL34
MU\72Q-;%SL[1(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-C4Q(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*
M(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M
M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B]Z;$S:;4V-3%(,_0Q=+#IL`HIRDL
M(-'+IB#3S*;$(-K$ILK3SLG4R2#7(,/%RB#>P=,N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I
M<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*;7-G<W1R("+AQ-+%
MT\[!(,O.R<?!(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R
M;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@
M(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R
M('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C<T.0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R
M($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN
M8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@Q\_$R<[)(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED
M(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#$U"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U
M="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G
M<W1R("+PIL34U\72Q-;%SL[1(-#!TL_,P"(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N
M="!F<F]Z96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T<B`BX<32Q=/!
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR
M,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U
M>GIY"FUS9VED(")!9&0@2&5R93HB"FUS9W-T<B`BY,_$P=3)(,O/TLG3U-77
MP=[!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H
M<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI
M;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T
M;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@
M<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("+DS\3!
MU,D@SL_7S\?/(,O/TLG3U-77P=[!.B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS
M-`HC+"!F=7IZ>0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(N3/
MQ,'4R2#.S]?/Q\\@R\_2R=/4U=?!WL$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`BY,_$P=3)
M(-#!TM4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8W"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(D%D9"!T;R!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(N'$TL73SL$@R\[)Q\$B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@
M(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`BX<32Q=/.P2#+SLG'
MP2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G
M<W1R("+DS\3!U,D@R\_2R=/4U=?!WL$B"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(N3/Q,'7P<[.T2#+S]+)T]35
MU\'>IM<@VL'"S]+/SL7.Q2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3(V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T
M,0IM<V=I9"`B061D<F5S<R(*;7-G<W1R("+AQ-+%T\$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"B,L(&9U>GIY"FUS9VED(")!9&1R97-S
M($)O;VLB"FUS9W-T<B`BX<32Q=/.P2#+SLG'P2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`BX<3-
MILZFT]32U=?!SL[1(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(N'$TL73P2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B\-/%U\3/SJ;-
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R
M("+PT\77Q,_.ILTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+PT\77Q,_.ILTB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$V"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R("+PT\77Q,_.
MILTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@
M9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@
M(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H
M<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38W"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA
M<R!O8V-U<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!
M;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4X"FUS9VED(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@
M(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS
M9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O
M=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,S"FUS9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V
M92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B07)M96YI82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS
M:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R
M-0IM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@
M(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T
M=')I8G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@
M(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C
M87!A8FEL:71E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)U<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU
M,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED
M(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@
M9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT
M.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT
M-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<VUB+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A
M=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I
M9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP
M.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C<P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S4*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(N3/
MT]35T,ZF(-#/S-$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@
M(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,0IM<V=I
M9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R
M;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A
M:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B
M0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM
M<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E
M8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED
M(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA
M<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I
M9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@
M(N3%SM@@SL'2S\36Q<[.T2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@
M7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I
M9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"B,L(&9U
M>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D
M97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q"B,L(&9U>GIY"FUS9VED
M(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B
M0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED
M(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L(&9U>GIY"FUS9VED
M(")"<F%Z:6PB"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS
M9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I
M9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V
M,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L971E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#8*;7-G:60@(D-A
M;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#$S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(O>FQ,VFSLG4R2#0S]>FQ,_-S,7.SM$@T-+/PLS%S<DB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H
M<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K
M+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("+ZPL72Q<?4R2#/
MT,.FIR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N
M<&AP.C$P-`IM<V=I9"`B0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R("+SU*;,
MV,[)R\_7R<H@U,7,Q<;/SB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@
M4')O<&5R=&EE<R(*;7-G<W1R("+SU*;,V,[)R\_7R<H@U,7,Q<;/SB(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS
M9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E
M;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T
M"B,L(&9U>GIY"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B\]2FS-C.R<O/
MU\G*(-3%S,7&S\XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I
M9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-E;G1R
M86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X
M-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3$*
M;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I
M8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@
M(D-H860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC+"!F=7IZ
M>0IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(O/+P=/5U\'4R2#:S:;.R2(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0HC+"!F=7IZ>0IM<V=I
M9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.
MT2#0P=+/S,`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-PIM
M<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,
M:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(O3)U-7,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI
M;F$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D
M:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@
M<&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/S,`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O
M<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO
M;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@(D-L96%R(%%U97)Y
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U="!U<V5R.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z
M,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM
M<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(OK!R]+)U,D@UZ;+SL\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B0VQO=61S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L
M;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E
M;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B
M0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I
M9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD
M(@IM<V=S='(@(NO/S=#!SJ;1(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P
M"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V
M-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G
M<W1R("+KS\W0P<ZFT2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM
M<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I9"`B0V]N9&ET:6]N
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*
M;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S
M<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/S,`B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED
M(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y
M<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K
M<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G
M:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N
M=',@;V8@7"(E<UPB(@IM<V=S='(@(O?-IM/4("<E<R<B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS9W-T<B`BZ\_-T,'.IM$B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(K;-
MT,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ
M.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S
M86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD
M87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)
M344@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HS.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#$@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S"FUS9VED(")#;W5L9"!N;W0@
M9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A
M9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y
M+G!H<#HV.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-S$Y"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB
M)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY
M"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@
M(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U
M97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-PHC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#,*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")(
M;W)D92#.Q2#3R\_.QJ;'U=+/U\'.P2#0TL'7R<S8SL\B"@HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M
M9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C8S(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4Y"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I
M;VXZ("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P
M('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C8*
M;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H
M92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q.0IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N=')Y(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@
M(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z
M.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R
M96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C8U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM
M<V=I9"`B0W5B82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,C8*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T
M:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E
M;G0@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U
M="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP
M<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS
M9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G
M:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R("+DY"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#$*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`B_<_$Q<[.SR(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H
M<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY
M"B,L(&9U>GIY"FUS9VED(")$871E(@IM<V=S='(@(O?)U,72U,DB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T
M92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,C(*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G
M<W1R("+]S\3%SL[/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L971E
M($-O;'5M;B(*;7-G<W1R("+WR=3%TM3)(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ
M,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`B]\G4Q=+4R2(*
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W
M"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(O?)R\_2
MR=/4S]?5U\'4R2#:SL'>Q<[.T2#:P2#:P<W/U][5U\'.SM'-(@H*(SH@9G)A
M;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B1&5F875L
M="!)9&5N=&ET>2(*;7-G<W1R("+OT\[/U\[!(*;0S]/4P=/8(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")$969A=6QT
M(%-H96QL(@IM<V=S='(@(N_3SL_7SL$@IM#/T]3!T]@B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT
M,C(@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*
M;7-G:60@(D1E;&5T92(*;7-G<W1R("+WR=3%TM3)(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U
M>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("+WR=3%TM3)(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@
M9G5Z>GD*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("+WR=3%TM3)(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS
M9VED(")$96QE=&4@3&]G(@IM<V=S='(@(O?)U,72U,DB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("+W
MR=3%TM3)(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*
M;7-G<W1R("+WR=3%TM3)(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*
M;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T
M<B`B]\G4Q=+4R2(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>2(*;7-G<W1R("+OT\[/U\[!(*;0S]/4P=/8(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC+"!F=7IZ>0IM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R("+WR=3%TM3)(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B
M1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T
M<B`B[]#)VZ;4V"#0TL_"S,7-U2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDS."!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,P"B,L(&9U>GIY"FUS9VED(")$97-C<FEP=&EO;B(*;7-G<W1R
M("+PS]?.R<H@S]#)TSHB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$Y-0IM<V=I9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I
M.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y
M.0IM<V=I9"`B1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*
M;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"B,L(&9U>GIY"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*;7-G:60@(D1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II8F]U=&DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*
M(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B]\G4Q=+4
MR2(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@
M;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M.38*;7-G:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.#0T"FUS9VED(")$;W=N;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&]W;FQO860@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V,@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$
M<G5G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*(RP@9G5Z>GD*;7-G:60@(D4M36%I;"(*;7-G<W1R("))35`M
MT,_2U,',(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT
M<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@
M9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET
M+FEN8SHR-0IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P;W)T86PO961I="YI
M;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D
M:70@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,`IM
M<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED
M(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A
M<VEC($A434P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED
M(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM
M<V=S='(@(N4MT,_;U,$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z
M>GD*;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B]\';P2#!Q-+%T\$@
MQ2W0S]O4R3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L
M(&9U>GIY"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS
M9W-T<B`B\,'2S\S8(,W5T\G4V"#3T*;7T,'3U,DN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*
M(RP@9G5Z>GD*;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(O#/TL_6
MSJ;*(-+%VM7,V-3!U"XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,C0S(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S
M='(@(O#/TL_6SJ;*(-+%VM7,V-3!U"XB"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM<V=I
M9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL
M97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4Q.`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@
M>65A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(Q"FUS9VED("(B"B)%
M;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S
M:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR-PHC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z-#4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4U"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X
M+G!H<#HX,@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B\,_-R<S+P2(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N
M=&5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I
M=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G:60@(D5T:&YI
M8R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G
M:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R("+KS];.S\?/(-?(S\35(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@W"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM
M<V=S='(@(NO/UL[/Q\\@U\C/Q-4B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R("+KS];.S\?/(-?(S\35(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X.`HC+"!F=7IZ>0IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(NO/
MUL[/Q\\@U\C/Q-4B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR
M-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(N3!SJ8@Q,S1(-#2
MR<O,P<35.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S
M:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE
M8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED
M96)A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D
M<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP
M96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G
M:60@(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O
M9B!S971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E<F5N
M8V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I
M9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I
M9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A
M:7(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L
M86YD<R`H36%L=FEN87,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#
M3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S
M='(@(O#/S<G,R\$@MLW0S]+4U3H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(N;!
MR],B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY
M"FUS9VED(")&87AE<R(*;7-G<W1R("+FP<O3(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&
M965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I
M9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT
M-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G
M:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@
M(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(O3)U-7,(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*(RP@9G5Z>GD*
M;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("*VS6#1(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I
M9"`B1FEL92!U<&QO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S
M97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U
M<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C@Y"FUS9VED(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HX,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED
M(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@
M(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@
M(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y
M"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R
M;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*
M(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO
M8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED
M(")&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#4S"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P.0IM<V=I9"`B1F]R=V%R
M9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B1G)A;65S(@IM<V=S='(@(K;-8-$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H
M97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`HC+"!F=7IZ
M>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+PS]?.R<H@S]#)
MTSHB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
M]\';Q2"FS2?1.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'
M96YE<F%T960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M96]R9VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")'
M:79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B
M1V]O9VQE($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED
M(")'<F%Y<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R
M965C92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM
M<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3<Y"B,L(&9U>GIY"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G
M<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S
M."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O
M=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC
M+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(N'$TL73SL$@R\[)
MQ\$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM
M<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(
M86ET:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED
M(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.CDQ.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A
M8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)
M4T\M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N
M:6YC.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BY,_0S\W/Q\$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(
M96QP('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T
M<B`BY,_0S\W/Q\$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@
M(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G
M:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN
M8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I
M9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(N3/S<';SM$@P<32Q=/!(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(N3/S<';
MSJ;*(-3%S,7&S\XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B
M2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E
M(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C$R-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T
M<B`B]=/0IMO.SR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C0W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,V
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B
M2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("+AQ-+%
MT\$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS
M9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0
M($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@
M3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I
M=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3DP"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@HC+"!P:'`M9F]R
M;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@
M)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-34*;7-G:60@(B(*(DEF('EO=2!D
M;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y
M;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@
M4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I9"`B(@HB268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R
M(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D(@IM<V=S='(@(K;-T,_2U,_7P<[%
M(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM<V=S
M='(@(K;-T,_2U,_7P<[%(-#/S,4Z("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@9FEE;&1S.B(*;7-G<W1R
M("*VS=#/TM3/U\'.IB#0S\S1.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2
M;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O<G)E8W0@86-T:6]N(&-O
M9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L(&9U>GIY"FUS9VED("));F-O
M<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("+BU<38
M+<S!T\O!+"#7R\'6IM38(,[!VM?5(,O/TLG3U-77P=[!(*8@T,'2S\S8(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN
M8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G
M86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@
M26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR
M-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV
M:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("))
M;F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S,P"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F
M=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS
M9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED
M("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS
M9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU
M;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*
M;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@
M8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M.0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*
M;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS
M9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E
M<G0@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@
M<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS
M97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B
M26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E
M<G0@<F]W(&)E9F]R92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO
M9&EF>2!,:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B
M26YT96=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3,S"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM
M<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@
M(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W,0IM<V=I9"`B26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HR-PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I
M9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U
M8W0@8V]D92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N
M=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G
M:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I
M9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS
M9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-SD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@
M;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I
M9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`B
M_<_$Q<[.SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIA<&%N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@W"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"FUS9VED("(B"B)*
M879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N('EO=7(@8G)O=W-E<B!A
M;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES<&QA>6EN9R!C;W)R96-T
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS
M9VED(")*;W)D86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*;7-G
M:60@(DIU;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3<*;7-G:60@(DIU<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED
M(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I
M9"`B2V%Z86MH<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P(&]R:6=I;F%L
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4*;7-G
M:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED
M(")+97)N96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*
M;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$Q"FUS9VED(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`HC+"!F=7IZ>0IM<V=I9"`B2V5Y
M(%5S86=E(@IM<V=S='(@(NS)T]0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<V"FUS9VED("),87-T(%!A<W-W
M;W)D($-H86YG92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@
M(DQA<W0@57!D871E9#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-@IM
M<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@Y"FUS9VED("),871V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"B,L(&9U
M>GIY"FUS9VED("),87EO=70B"FUS9W-T<B`B]\G*U,DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V
M92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM<V=I9"`B3&5F="!V86QU97,B
M"FUS9W-T<B`BY,'.IB#$S-$@T-+)R\S!Q-4Z(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G
M:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT(%)A:6XB"FUS9W-T<B`B]]>FRM3)(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM
M<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT
M(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*
M(RP@9G5Z>GD*;7-G:60@(DQI;FLB"FUS9W-T<B`B]]>FRM3)(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W
M"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@
M861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT
M;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@
M(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O
M:6YD97@N<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@
M(O#%TL7,ILL@TL_:Q*;,IM<@Y,_0S\W/Q\DB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES
M="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY"FUS9VED("),:7-T+4AE;'`B"FUS
M9W-T<B`B\,72Q<RFRR#2S]K$ILRFUR#DS]#/S<_'R2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T
M+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S(@IM<V=S='(@(O#%TL7'S-'$(-/0R=/+U2#+S]+)
MT]35U\'>IM<@VL'"S]+/SL7.R<HN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S
M(&9A:6QE9#H@)7,B"FUS9W-T<B`B\,72Q<?,T<0@T]#)T\O5(,O/TLG3U-77
MP=ZFUR#:P<+/TL_.Q<[)RBXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N
M;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M(@IM<V=S='(@(O#%TL7'S-'$(-/0R=/+U2#+S]+)T]35U\'>IM<@VL'"S]+/
MSL7.R<HN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),
M:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET
M:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,0IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(O?7ILK4
MR2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B
M3&]G(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T
M(@IM<V=S='(@(O?)RM3)(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("+WUZ;*U,DB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*;7-G
M:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S
M<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I
M;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8U"B,L(&9U>GIY"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B]\G*U,DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),
M;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I
M9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQU>&5M8F]U<F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R("+M[2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR.#$*;7-G:60@(DU/5$0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G
M:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I9"`B35-'(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C86\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDQ"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L
M878@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED
M(")-861A9V%S8V%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B24U0+=#/
MTM3!S"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B
M36%I;"(*;7-G<W1R("))35`MT,_2U,',(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B24U0+=#/
MTM3!S"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`B24U0
M+=#/TM3!S"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L=&$B
M"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@
M;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B
M36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(O77P<?!(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F
M;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE
M+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE
M;&1S(@IM<V=S='(@(O>FQ-#/UZ;$SJ8@T,_,T2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%U<FET86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A;&QO
M=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B
M36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C
M:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-CD*;7-G:60@(DUA>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")-87EO='1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,`IM<V=I9"`B365D:6-I;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS9VED(")-
M96YU(&UO9&4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(NS)
MT]0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R("+LR=/4(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ
M>0IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(NS)T]0B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,3(*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@
M9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN
M960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U
M"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(")-97AI8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O
M;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L
M(&9U>GIY"FUS9VED(")-:61D;&4B"FUS9W-T<B`B24U0+=#/TM3!S"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED
M(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B36EN('1E
M;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@<&%S<W=O<F0@
M86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC+"!F=7IZ>0IM
M<V=I9"`B36ER<F]R(@IM<V=S='(@(O#/S<G,R\$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*
M;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@
M9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P
M<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S
M<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G
M:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF
M>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDP"FUS9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U.30*;7-G:60@(DUO;G1H(&%N9"!Y96%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B_<_-IM/1P]$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M"FUS9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD
M(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B
M36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS
M9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@
M(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I
M9"`B37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B
M37D@4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED
M(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BMLU@T2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").971H97)L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B
M3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E($)A
M<V4@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-`IM
M<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C
M87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@
M<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y
M<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U
M,0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S
M-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V"FUS9VED(").979E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z
M.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B
M3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+PP=+/S-@B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R
M"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R("+PP=+/S-@@S=73R=38(-/0IM?0P=/4R2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@
M=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G
M;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"B,L(&9U>GIY"FUS9VED(").97=S(@IM
M<V=S='(@(N[/U,'4R\DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S`U"FUS9VED(").97=S9W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X="`T(%!H
M87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,W,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@HC+"!F
M=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(O#/U\72SM74R=/1
M(,3/(._0PZ;*(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*
M;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B
M3FEC87)A9W5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*
M;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL
M86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F
M;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<BYP:'`Z,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@
M9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@
M(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C8W"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8VAA;F=E+B(*;7-G<W1R("+SR\'3U=?!U,D@VLVFSLDB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z
M-S<S"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,C0*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M(%-13"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,3<*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS
M9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F
M:6QE('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R
M+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED
M(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R
M;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P
M;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW
M,@IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP
M.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP
M:'`Z,3,U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@
M,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC
M+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(N+5Q-@MS,'3R\$L(-?+
MP=:FU-@@SL':U]4@R\_2R=/4U=?!WL$@IB#0P=+/S-@B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,PHC+"!F=7IZ>0IM<V=I9"`B3F]N92(*;7-G<W1R("+TQ<S%QL_.
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U
M.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK
M($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I
M9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@
M(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV
M,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE
M;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G
M<W1R("+NS]3!U,O)(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E
M<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E<W-I
M;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W;W)K
M+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B[L_4P=3+R2(*"B,Z('-E
M<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"B,L
M(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`BMLU@T2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R
M86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS
M9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@
M9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@
M<&%S<W=O<F0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*
M;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3W!T
M:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z('-E<G9I8V5S+W!R
M969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED
M(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A
M=&EO;B(*;7-G<W1R("+AQ,VFSJ;3U-+5U\'.SM$B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N
M86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS
M9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z
M-SD*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S
M"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0
M($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S
M-3,*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"B,L(&9U>GIY"FUS9VED(")0
M2%`@0V]D92(*;7-G<W1R(")(;W)D92(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H
M="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS
M9VED(")032!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#$*;7-G:60@(E!-(%-U;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3
M=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W
M-`IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDY"FUS9VED(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Q"FUS9VED(")086QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I
M9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*
M;7-G<W1R("+PP=+/S-@B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C$S,C(*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G
M<W1R("+PP=+/S-@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,34R"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#4S"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3`*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+PP=+/S-@B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+PP=+/S-@B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S
M=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B\,'2S\S8(,W5T\G4V"#3T*;7
MT,'3U,DN(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$Q.2!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@
M(E!A<W1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@4VEG;G5P
M<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`B\L_,V"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,B"FUS9W-T<B`B]\G+S\[!U,D@T-+/QJ;,P<O4R=[.IB#/
MT,72P<.FIR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z
M>GD*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\B"FUS9W-T<B`B]\G+S\[!U,D@T-+/QJ;,P<O4R=[.IB#/T,72P<.F
MIR(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S
M7"(@;F]T(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES
M<VEO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I
M;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MX<3-ILZFT]32U=?!SL[1(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U
M"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`B],7,Q<;/SB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX
M96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM
M<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS
M9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT
M+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D
M<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@
M=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("+BU<38+<S!T\O!
M+"#$P<K4Q2#+S]+/U,O)RB#/T,G3(-#2S\+,Q<W)+B(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0B"FUS9W-T<B`BXM7$V"W,P=/+P2P@U\O!UJ;4V"#.P=K7U2#+
MS]+)T]35U\'>P2"F(-#!TL_,V"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T
M97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE
M("(*(G-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDY"FUS9VED(")0;VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@=&%B
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E
M;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I
M9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S
M<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E
M<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C4*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R
M92!A="!S96$@;&5V96PZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"B,L(&9U>GIY
M"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS(@IM<V=S='(@(O#/U\72SM74R=/1
M(,3/(._0PZ;*(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0
M<FEV871E($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38Y"B,L(&9U>GIY"FUS9VED(")0<F]B;&5M(@IM<V=S
M='(@(EOPS]>FQ,_-S,7.SM$@\-+/PLS%S<E=(@H*(SH@<V5R=FEC97,O<')O
M8FQE;2YP:'`Z,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S
M='(@(N_0R=,@T-+/PLS%S<DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B
M4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE
M;&PN<&AP.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`IM
M<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PIM<V=I9"`B4F%I
M;B!A;F0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD
M;VT@1F]R='5N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@
M(NS)T]0B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O
M<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H
M:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G
M:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L
M96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0Q"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U
M"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R("+OWLG3U,G4R2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N
M<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*
M;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(O?)U,72U,D@T,'2U2(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I
M<B(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R
M"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(O?)U,72U,D@
MT,'2U2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@=7-E<B(*
M;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M;6]V92!U<V5R.B`E<R(*;7-G<W1R("+WR=3%TM3)(-#!TM4B"@HC.B!F<F%M
M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C
M;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PIM
M<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U
M"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B[][)T]3)U,DB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM
M<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B\,'2S\S8(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(E)E
M<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B\*;$U-?%TL36Q<[.T2#0P=+/
MS,`B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E
M($QA<W0@475E<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B[][)T]3)U,DB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM
M<V=S='(@(O#/U\72SM74R=/1(,3/(._0PZ;*(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L
M(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T
M<B`B\,_7Q=+.U=3)T]$@Q,\@[]##ILHB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED
M(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B\L_,V"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T
M871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I
M9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W
M('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U;&5S(@IM<V=S='(@(O+/S-@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R
M;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*;7-G
M:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S
M:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP
M.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU
M,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B[,G3
MU"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*
M;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I9"`B
M4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-50T-%
M4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS9VED(")37U%,
M(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B
M4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A=&5L;&ET92!0<F]V
M:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!
M<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M)7,B"FUS9W-T<B`B^L+%TL7'U,D@S]##IJ<B"@HC.B!T96UP;&%T97,O<')E
M9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B^L+%
MTL7'U,D@S]##IJ<B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS
M9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0
M('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS
M9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R,`IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW,PIM<V=I9"`B
M4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT.#0*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`B]\G"Q=*FU-@@QL_2S<'4(,3!U,DZ(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A
M(&=R;W5P('1O(&%D9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED
M(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(O?)PL72IM38
M(,;/TLW!U"#$P=3).B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W.`IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82XB"FUS9W-T<B`B(@HB]\G"Q=*FU-@@SL7/PLBFQ,ZF(/?!
MS2#3R<W7S\S)(-H@T,_,IM<@SLG6WL4N(/?)(-K-S];%U,4@T\O/T*;`U\'4
MR2"GR""F("(*(M?3U,'7R=3)(-H@T,_,T2#7U\_$U2#4Q<O3U-4N(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(O?)PL72IM38(-+/VL2FS,#7P=X@
MQ,'4R3HB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&9O<FUA=#HB"FUS9W-T<B`B]\G"Q=*FU-@@QL_2
MS<'4(,3!U,DZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T
M;R!C:&%N9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N
M:6YC.C$V"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R("+WR<+%TJ;4V"#2S]K$ILS`U\'>(,3!U,DZ(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!F;W)M870Z(@IM<V=S='(@(O?)PL72IM38(,;/TLW!U"#>P=/5.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("+WIL30
MS]>FQ,ZF(-#/S-$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS
M9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!2
M97!O<G0B"FUS9W-T<B`B]Z;$IM/,P=3)(-#/UZ;$S\W,Q<[.T2#0TL\@T-+/
MPLS%S=4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`S.0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@
M(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S
M:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G
M:60@(B(*(E-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C
M:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O
M<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P
M;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S
M"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(NO/TL_4
MR\G*(-K-IM/4(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I
M9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T
M:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G
M:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H
M;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS
M9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA
M=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@
M;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE
M;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("+P
MTL_0U=/4R=3)(-#2S\:FS,'+U,G+U2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L
M;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED(")3
M;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@
M(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A
M;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3;W)T(&]R
M9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U>GIY"FUS
M9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("+RS\+/WL$@P<32Q=/!(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C
M:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R("+WUZ;$(//0Q<.FP<S8SLG((-/)S=?/S*;7(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I
M9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM
M<V=I9"`B4W!O<G1S(@IM<V=S='(@(K;-T,_2U"(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S(*(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM
M<V=S='(@(O+/PL_>P2#!Q-+%T\$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G
M:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3
M=6)M:70B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R
M("(*(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G
M:60@(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T
M<B`B]=/0IMO.SR(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O
M('1H92!S>7-T96TN(@IM<V=S='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@Q,\@
MT\G3U,7-R2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R
M('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B]=/0IMO.
MSR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C@P(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#8*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB
M"FUS9W-T<B`B]=/0IMO.SR#$S\3!SL\@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B]=/0IMO.SR#7R<3!S,7.SR`G)7,G(-H@T\G3U,7-R2XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P
M9&%T960@7"(E<UPB(@IM<V=S='(@(O73T*;;SL\@Q,_$P<[/("<E<R<@Q,\@
MT\G3U,7-R2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(O73T*;;SL\@Q,_$
MP<[/("<E<R<@Q,\@T\G3U,7-R2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3
M=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(NO/TL_4R\G*(-K-IM/4(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8U"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*
M;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP
M.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M.0IM<V=I9"`B4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*
M;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS
M9W-T<B`BMLW0S]+4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B
M4W5R:6YA;64B"FUS9W-T<B`B[L':U\$@R\_2R=/4U=?!WL$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I
M9"`B4W5R;F%M92(*;7-G<W1R("+NP=K7P2#+S]+)T]35U\'>P2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G
M(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$T,@IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*
M;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,38V"B,L(&9U>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R("+TR=35S"(*
M"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")486)L92(*;7-G<W1R("+TR=35S"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE
M(%!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS
M9VED(")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$X-PIM<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.
M=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*
M;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS
M9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
MX<3-ILZFT]32U=?!SL[1(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H
M<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB
M"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM<V=I9"`B5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E
M(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@
M(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D
M:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("+TTL'0R<S!
MT]$@T-+/PLS%S<$@T-+)(,3/Q,'7P<[.IB`G)7,G(,3/(-/)T]3%S<DN(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(O32P=#)S,'3
MT2#0TL_"S,7-P2#0TLD@U\G$P<S%SLZF("<E<R<@VB#3R=/4Q<W)+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B]-+!T,G,P=/1(-#2S\+,Q<W!(-#2R2#7
MR<3!S,7.SJ8@)R5S)R#:(-/)T]3%S<DN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B]-+!T,G,P=/1
M(-#2S\+,Q<W!(-#2R2#$S\3!U\'.SJ8@)R5S)R#$SR#3R=/4Q<W)+B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@
M=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I
M;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F
M:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I
M;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B
M92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@
M(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM
M<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z
M+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,X,30@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B
M5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4
M:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@
M;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A
M;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@S-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@
M82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP
M;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O
M86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P
M=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E
M9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@
M(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*
M;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G
M>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E
M(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED
M(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR,S0*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`B],G4U<PB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@V"FUS9VED(")4:6UE
M(%1R86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4S.0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B
M"FUS9W-T<B`B],G4U<PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G
M:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B
M5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N
M9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I
M9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G
M:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX
M.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM
M96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED
M(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,3(*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A
M('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(U-@IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR-C4*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M,C0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O
M<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C<X(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,S,T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@P,PIM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I
M(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE
M4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B
M56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@
M=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R
M(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE
M('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,30Y(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z,34R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@Q(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ,S@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$T,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-#$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL
M;"!B92!E>&-E961E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@
M(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+SR\'3U=?!U,D@VLVFSLDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED
M(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#0*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O
M<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&
M+3@I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A
M8B!%;6ER871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N
M:71E9"!+:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O
M0FQO8VLO;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G
M:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A
M=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G
M:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(N[!VM?!(,O/TLG3U-77P=[!(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM
M<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#
M=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.CDS,@IM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`BY,_$P=3)
M(,O/TLG3U-77P=[!(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E
M<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*
M(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`B[L':U\$@R\_2R=/4U=?!
MWL$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(N'$S:;.IM/4TM77P<[.T2#+S]+)T]35U\'>IM<@2&]R9&4B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I9"`B
M57-E<B!/<'1I;VYS(@IM<V=S='(@(OK"Q=+%Q]3)(,_0PZ:G(@H*(SH@<VEG
M;G5P+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I;VXB
M"FUS9W-T<B`BX<3-ILZFT]32U=?!SL[1(,O/TLG3U-77P=ZFUR!(;W)D92(*
M"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N
M="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B[L':U\$@R\_2R=/4U=?!WL$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@W
M"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B[L':U\$@R\_2
MR=/4U=?!WL$B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"B,L
M(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(N[!VM?!(,O/TLG3
MU-77P=[!(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM
M<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`BZ\_2R=/4U=?!
MWJ8@UR#3R=/4Q<VF.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E
M;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"FUS9VED(")697)S:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS
M9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I
M8V%L.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E("A625-#
M24DI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.CDV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W("5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@
M86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@87,@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I
M9"`B5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI
M='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(V,PIM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@T"FUS
M9VED(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$S,PIM<V=I9"`B5TE.('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:'1M;"YP:'`Z,C<R(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R("+UU\''P2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A
M=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-#(W"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED960@
M8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR
M"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP
M:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("+]S]3)UL[1(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G:60@(E=E
M;&-O;64B"FUS9W-T<B`B]Z;4P<`@]\'3+"`E<R(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*
M;7-G<W1R("+WIM3!P"#WP=,L("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(O>FU,'`(/?!
MTRP@)7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.38*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P
M;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$P-C$*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H
M:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,S"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE
M(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I
M9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@
M(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E
M8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@
M;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@
M(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G
M:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T
M<B`B\L_"S][!(,'$TL73P2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B
M\L_"S][)RB#4Q<S%QL_.(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,38Y(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@
M)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G
M:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3$T"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W
M:&EL92!R96%D:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS
M9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U
M,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3
M=6)J96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT
M96YS:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM
M<V=I9"`B65DB"FUS9W-T<B`B\O(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS
M9W-T<B`B\O(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED
M(")996%R;'DB"FUS9W-T<B`B_<_2IM[.SR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N
M;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS
M9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B
M66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F
M=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*
M;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB
M9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z-#4V"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N
M9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E
M9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R
M("+WR2#0S]?)SLZF(,_0R=/!U,D@T-+/PLS%S=4L(-#%TML@SJ;6(->FQ-/)
MS,'4R2#0S]>FQ,_-S,7.SM$@T-+/(,[%IRXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z
M>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35
MU\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+
MS]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E
M;6]V92XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+S]+)T]35
MU\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+WP<T@
MT\RFQ"#7R\':P=3)(,[!VM?5(,O/TLG3U-77P=[!(,3,T2#$S\3!U\'.SM$N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@
M(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1(,3/Q,'7
MP<[.T2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B]\'-(-/,IL0@U\O!VL'4R2#.
MP=K7U2#+S]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM
M<V=S='(@(O?!S2#3S*;$(-?+P=K!U,D@SL':U]4@R\_2R=/4U=?!WL$@Q,S1
M(-?)Q,',Q<[.T2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED
M92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS
M9W-T<B`B]\';P2#!Q-+%T\$@Q2W0S]O4R3HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D9')E
M<W,Z(@IM<V=S='(@(O?!V\$@P<32Q=/!(,4MT,_;U,DZ(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S
M"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B]\';Q2"FS2?1
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*
M;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A
M='5R92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I
M;G0N:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@
M*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*;7-G:60@(EEO
M=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(N_3SL_7SL$@
MIM#/T]3!T]@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B]\';Q2"FS2?1
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*;7-G:60@(EEO
M=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO
M=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E
M96X@=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I
M9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@
M(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6_#/UZ;$S\W,Q<[.T2#PTL_"
MS,7-R5TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ
M<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S
M(&]F("5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(N'$S:;.IM/4TM77
MP<[.T2(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(O?)U,72U,DB"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'
M<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`BY,_0
MS\W/Q\$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ
M.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B]]>FRM3)(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,`HC+"!F=7IZ
M>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B]\G*U,DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G
M:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")?3W!T
M:6]N<R(*;7-G<W1R("+ZPL72Q<?4R2#/T,.FIR(*"B,Z(&QI8B]A<&DN<&AP
M.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC
M+"!F=7IZ>0IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(O?)U,72
MU,D@T,'2U2(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*
M(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("+AQ-+%T\[!
M(,O.R<?!(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S0*;7-G:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,34X"FUS9VED(")C86YN;W0@8W)E871E(&]U='!U="!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,P"FUS
M9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*;7-G:60@(F-L:6-K(&AE
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W
M.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,0IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HX-34*(RP@9G5Z>GD*;7-G:60@(F9I;&4B
M"FUS9W-T<B`B],G4U<PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L
M:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T
M+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z
M-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G
M<W1R("*VS6#1(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I
M9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L
M96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP-0IM<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED
M(")P97)C96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T
M92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B
M<FES:6YG(@IM<V=S='(@(O77P<?!(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I
M9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS
M,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@(G-S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<R
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HS,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")T
M<GD@86=A:6XB"FUS9W-T<B`BZ\_6SL_'SR#7R,_$U2(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T
M=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@
M(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&\O:71?250N<&\`````````````````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C<Q-30T(#$P-3$U-#,T,30R(#`Q
M-S4T,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C($ET86QI86X@=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E+@HC
M($-O<'ER:6=H="`H0RD@,C`P-B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE
M(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE
M(&AO<F1E('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L(#(P
M,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M(&AO<F1E(#,N,2XQ7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M,#0M
M,3,@,30Z,38K,#(P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP-"TQ
M,R`Q-#HQ-BLP,C`P7&XB"B),87-T+51R86YS;&%T;W(Z($UA<F-O(%!I<F]V
M86YO(#QM87)C;RYP:7)O=F%N;T!U;FEB;V-C;VYI+FET/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@
M,2D[7&XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&=I;W)N
M:2!S8V]R<VDI(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*$-H:6%V92!D
M:2!A8V-E<W-O("5S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AI
M;B`E<R!G:6]R;FDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*;7-G
M:60@(B`H=&]D87DI(@IM<V=S='(@(B`H;V=G:2DB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AD
M;VUA;FDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S$*;7-G:60@(B`H
M>65S=&5R9&%Y*2(*;7-G<W1R("(@*&EE<FDI(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G
M:60@(B!A="`B"FUS9W-T<B`B(&$@82(*"B,Z(&QI8B]61E,O<VUB+G!H<#HR
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B7"(E<UPB(&YO;B#H('5N82!D:7)E8W1O<GDN(@H*
M(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<
M(B!N;VX@Z"!U;F$@<V-E;'1A('9A;&ED82XB"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<Q,"!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&YO;B#H(&-O
M;F9I9W5R871O(&YE:2!296=I<W1R:2!D:2!(;W)D92XB"@HC.B!L:6(O2&]R
M9&4O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB(&%L8F5R
M;R!R96YD97)E<B!N;VX@=')O=F%T;RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B#H('-T871O(&%G
M9VEU;G1O(&%I(&=R=7!P:2!D:2!S:7-T96UA+B(*"B,Z(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@
M(EPB)7-<(B#H('-T871O(&%G9VEU;G1O(&%I('!E<FUE<W-I(&1I('-I<W1E
M;6$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!N;VX@Z"!S=&%T;R!C
M<F5A=&\Z("5S+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*2(*;7-G<W1R("(E+C)F34(@=7-A=&D@9&D@)2XR9DU"(&1I
M<W!O;FEB:6QI("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B
M"FUS9W-T<B`B)60@)7,@92`E<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HU.30@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C8X"B,L('!H<"UF;W)M
M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S
M+B(*;7-G<W1R("(E9"!G:6]R;FD@86QL;R!S8V%D97)E(&1E;&QA('1U82!P
M87-S=V]R9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R
M("(E9"UG:6]N;R!P<F5V:7-I;VYE(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM
M<V=S='(@(B5S("T@3F]T:7II82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-S`U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT
M(@IM<V=S='(@(B5S($9I<FUA($1I9VET86QE(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@T,B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S
M($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B)7,@3W!E<F%Z:6]N:2!D:2!-86YU=&5N>FEO
M;F4@+2!#;VYF97)M82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3971U<"(*;7-G<W1R("(E<R!);7!O<W1A>FEO;F4B"@HC.B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3:6=N(%5P(@IM<V=S='(@(B5S($9I<FUA(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E
M<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(E<R!497)M:6YI(&1I($%C8V]R
M9&\B"@HC.B!L:6(O5D93+V9T<"YP:'`Z-CDP(&QI8B]61E,O9G1P+G!H<#HW
M-C,@;&EB+U9&4R]S;6(N<&AP.C0T,0HC.B!L:6(O5D93+W-M8BYP:'`Z-3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G
M<W1R("(E<R!G:>`@97-I<W1E;G1E+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,38V(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S
M("5S(@IM<V=S='(@(B5S(&$@)7,@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A
M9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C
M:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N
M*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R
M("(B"B(E<R#H('!R;VYT;R!P97(@97-E9W5I<F4@;&4@;W!E<F%Z:6]N:2!D
M:2!M86YU=&5N>FEO;F4@<V]T=&\@<V5L97II;VYA=&4N("(*(E-E;&5Z:6]N
M82!L82!C87-E;&QA('!E<B!O9VYI(&]P97)A>FEO;F4H:2D@8VAE('9U;VD@
M97-E9W5I<F4@;W)A+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S
M(.@@<FEC:&EE<W1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU
M=&DB"@HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@
M;F]N('1R;W9A=&\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G
M<W1R("(E<R!A("5S(&1I("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB"FUS
M9W-T<B`B4G5B<FEC82!D:2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T
M<B`B0V%L96YD87)I;R!D:2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3$P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R
M(").;W1E(&1I("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("),:7-T
M82!!='1I=FETX"!D:2`E<R(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$R-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@
M5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T
M;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@
M;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@
M:6YF;W)M871I;VXN(@IM<V=S='(@(B(*(B5S.B!1=65S=&\@;65S<V%G9VEO
M('!O=')E8F)E(&YO;B!A<G)I=F4@9&$@8VAI(&1I8VAI87)A(&1I(&5S<V5R
M92X@(@HB071T96YZ:6]N92!A:2!L:6YK('!R97-E;G1I(&EN(&5S<V\@;R!F
M;W)N:7-C:2!O9VYI(&EN9F]R;6%Z:6]N92!A;"!M:71T96YT92XB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B
M+"!S;V9F:6%N9&\@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.34@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G
M=7-T:6YG("5S("5S(@IM<V=S='(@(BP@<V]F9FEA;F1O("5S("5S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S='(@(BP@=F%R:6%B:6QE
M(&1A("5S(&$@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`V.2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$R.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-S0X(&QI8B](;W)D92]097)M<R]522YP:'`Z,CDT"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,S0X"FUS9VED("(M+2!S96QE8W0@
M+2TB"FUS9W-T<B`B+2T@<V5L97II;VYA("TM(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R(")&;W)M
M871O(#$R(&]R92(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B
M,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R;6%T;R`R-"!O<F4B"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS
M9W-T<B`B,C0@;W)E(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM
M<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(CQ0<F5C961E;G1E(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B56X@9&%T
M86)A<V4@9&D@8F%C:V5N9"#H(')I8VAI97-T;R!P97(@<75E<W1O(&)L;V-C
M;RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960B"FUS9W-T<B`B12<@86-C861U=&\@=6X@97)R;W)E
M(&9A=&%L92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I
M9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B56YA(&-H:6%V92!P=6)B;&EC82!01U`@Z"!R
M:6-H:65S=&$@<&5R(&-I9G)A<F4@:6P@;65S<V%G9VEO+B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(E5N82!C:&EA=F$@<'5B8FQI8V$@4$=0(.@@<FEC:&EE<W1A
M('!E<B!V97)I9FEC87)E(&EL(&UE<W-A9V=I;R!F:7)M871O+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@<'5B;&EC
M(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B
M"B)5;F$@8VAI879E('!U8F)L:6-A(%!'4"P@=6YA(&-H:6%V92!P<FEV871A
M(%!'4"P@92!U;F$@<&%S<W=O<F0@<V]N;R`B"B)R:6-H:65S=&4@<&5R(&1E
M8VEF<F%R92!U;B!M97-S86=G:6\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB56YA(&-H:6%V92!P=6)B;&EC
M82!01U`L('5N82!C:&EA=F4@<')I=F%T82!01U`L(&4@=6YA('!A<W-W;W)D
M('-O;F\@(@HB<FEC:&EE<W1E('!E<B!F:7)M87)E('5N(&UE<W-A9V=I;R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED("(B"B)!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`B(@HB56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344L('5N
M82!C:&EA=F4@<')I=F%T82!3+TU)344@92!U;F$@<&%S<W=O<F0@<V]N;R`B
M"B)R:6-H:65S=&4@<&5R(&1E8VEF<F%R92!U;F$@;65S<V%G9VEO+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS
M9W-T<B`B(@HB56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344L('5N82!C:&EA
M=F4@<')I=F%T82!3+TU)344@92!U;F$@<&%S<W=O<F0@<V]N;R`B"B)R:6-H
M:65S=&4@<&5R(&9I<FUA<F4@=6X@;65S<V%G9VEO+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(E5N82!C:&EA=F4@<'5B8FQI8V$@4R]-24U%(.@@<FEC:&EE<W1A('!E<B!C
M:69R87)E('5N(&UE<W-A9V=I;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B
M04T@3G5B:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(D%-(%!I;V=G
M:6$@3&5G9V5R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(D%-(%!I;V=G:6$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM
M<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")!32!!8W%U87IZ;VYI(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@
M(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")!32!.979I8V%T92(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O
M=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B4FEG=6%R9&\@<75E<W1O(&5D:71O
M<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4S"FUS9VED(")!8F]U
M="XN+B(*;7-G<W1R(")2:6=U87)D;RXN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,C@R"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D%C8V5S<V\@;F5G871O(&-R
M96%N9&\@;&$@9&ER96-T;W)Y(%9&4RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H
M<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N
M(@IM<V=S='(@(D%C8V5S<V\@;F5G871O(&-R96%N9&\@5D93(&9I;&4N(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@26YF
M;W)M871I;VXB"FUS9W-T<B`B26YF;W)M87II;VYI($%C8V]U;G0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O
M<F0B"FUS9W-T<B`B4&%S<V]W<F0@06-C;W5N="(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE
M;BXB"FUS9W-T<B`B06-C;W5N="!C;VYG96QA=&\N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R
M(")!8V-O=6YT:6YG(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#@@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B
M06=G:75N9VDB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U
M<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%G
M9VEU;F=I($=R=7!P;R!&:6=L:6\B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.CDX(&QI8B](;W)D92]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(D%G9VEU;F=I(%!E<FUE<W-I($9I
M9VQI;R(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!
M9&0@2&5R93HB"FUS9W-T<B`B06=G:75N9VD@<75I.B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@
M3F5W($=R;W5P(@IM<V=S='(@(D%G9VEU;F=I($YU;W9O($=R=7!P;R(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z.#<@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(D%G
M9VEU;F=I($YU;W9O(%!E<FUE<W-O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B06=G:75N9VD@=6X@
M9W)U<'!O(&9I9VQI;R!A(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E
M<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@(D%G9VEU;F=I('5N('!E<FUE
M<W-O(&9I9VQI;R!A(%PB)7-<(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS
M9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B06=G:75N9VD@=6X@;G5O
M=F\@=71E;G1E.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B06=G:75N9VD@
M8V]L;VYN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R(")!9V=I=6YG:2!N
M=6]V:2!M96UB<FDB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU
M"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")!9V=I=6YG:2!L82!C;W!P:6$B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*
M;7-G<W1R(")!9V=I=6YG:2!I;"`E<R!-96YU(&-O;64@=6YA($UO>FEL;&$@
M4VED96)A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%G9VEU
M;F=I(&%L;&$@<G5B<FEC83HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM
M<V=S='(@(D%G:75N9VD@86QL82!R=6)R:6-A('!E<G-O;F%L92(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")!9V=I
M=6YG:2!U=&5N=&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("(*(B5S+B(*;7-G<W1R("(B"B)!9V=I=6YT:2!<(B5S7"(@86P@<VES=&5M
M82P@;6$@;F]N('-I('!O<W-O;F\@86=G:75N9V5R92!U;'1E<FEO<FD@(@HB
M:6YF;W)M87II;VYI.B`E<RXB"@HC.B!S:6=N=7`N<&AP.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(D%G9VEU;G1O(%PB)7-<(B!A;"!S
M:7-T96UA+B!/<F$@<'5O:2!A8V-E9&5R92XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("),)V%G9VEU;G1A(&1I('5T96YT:2#H(&1I<V%B
M:6QI=&%T82XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T,2!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,PIM<V=I9"`B061D<F5S<R(*;7-G<W1R
M("));F1I<FEZ>F\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q
M"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B4G5B<FEC82(*"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-"!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-38*;7-G:60@(D%D;6EN:7-T97(@+2!S970@
M<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%M;6EN:7-T
M<F%T;W)E("T@:6UP;W-T82!I('!E<FUE<W-I('!E<B!A;'1R:2!U=&5N=&DB
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q-PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B06UM
M:6YI<W1R87II;VYE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,PIM<V=I9"`B061S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-`IM<V=I9"`B06QG
M97)I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B06QL:6YE82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB
M"FUS9W-T<B`B06QL:6YE86UE;G1O.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E1U='1I(@H*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B
M5'5T=&D@9VQI('5T96YT:2!A=71E;G1I8V%T:2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U
M<',B"FUS9W-T<B`B5'5T=&D@:2!G<G5P<&DB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O9&%T871R964N<&AP.C<U(&QI8B](;W)D92]097)M<R]522YP:'`Z.3$*
M;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")4=71T:2!I('!E<FUE
M<W-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`B5'5T
M=&D@92!Q=6%T=')O(&D@;&%T:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B
M5'5T=&D@9VQI(&EN9&ER:7IZ:2!M=6QT:7!L:2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HU,S@*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E
M9"!L:7-T('1Y<&4_(@IM<V=S='(@(E!E<FUE='1E<F4@;&4@:6UP;W-T87II
M;VYI(&1I(&QI<W1E(&]R9&EN871E('!E<B!T:7!O/R(*"B,Z(&QI8B](;W)D
M92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B
M"FUS9W-T<B`B17-I<W1E(&=IX"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(DQO
M9VEN($E-4U`@86QT97)N871I=F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M(")087-S=V]R9"!)35-0(&%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B
M"FUS9W-T<B`B571E;G1E($E-4%,@86QT97)N871I=F\B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL
M(&%D9')E<W,B"FUS9W-T<B`B26YD:7)I>GIO(&5M86EL(&%L=&5R;F%T:79O
M(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T
M92!T96UP;&%T97,B"FUS9W-T<B`B36%S8VAE<F4@86QT97)N871I=F4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R(")497-T
M;R!A;'1E<FYA=&EV;SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N(@IM<V=S='(@(D4G('-T871O('-P96-I9FEC871O('5N('9A
M;&]R92!N;VX@=F%L:61O+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N
M(@IM<V=S='(@(D5R<F]R92!S8V]N;W-C:75T;RXB"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V"FUS9VED(")!;F1O<G)A
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P"FUS9VED(")!
M;F=U:6QL82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM
M<V=S='(@(E)I<W!O<W1A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-0IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&QI
M8B](;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E
M='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B
M07!P;&EC87II;VYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R"FUS
M9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(DQI<W1A($%P<&QI8V%Z
M:6]N:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@(D%P
M<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R("),)V%P<&QI8V%Z:6]N92#H
M('!R;VYT82XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM
M<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(D%P<&QI8V$@
M86D@9FEG;&D@8V]N9&EV:7-I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!P<F]V
M82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(*;7-G:60@
M(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B1&EM96YS:6]N92!!<'!R;W-S
M:6UA=&EV82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#4@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS
M9VED(")!<')I;"(*;7-G<W1R(")!<')I;&4B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W.`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8V"FUS9VED(")!<F-H:79E($9I;&4@4VEZ
M92(*;7-G<W1R(")$:6UE;G-I;VYE(&9I;&4@:6X@87)C:&EV:6\B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M>FEP+G!H<#HV-0IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(DYO;64@
M07)C:&EV:6\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(E-E:2!S:6-U<F\@9&D@=F]L97(@<FEM=6]V97)E(&QE(')I
M8VAI97-T92!F:7)M871E('!E<B`E<R`_(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S
M=6(M9W)O=7!S/R(*;7-G<W1R(")!<V5I('-I8W5R;R!D:2!V;VQE<B!E;&EM
M:6YA<F4@7"(E<UPB(&4@;V=N:2!S;W1T;RUG<G5P<&\_(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-@IM<V=I9"`B07)G
M96YT:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!
M4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S`*;7-G:60@(D%R=6)A(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C
M96YS:6]N($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y
M"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B(@HB4FEC:&EE9&5R92!L
M82!C;VYF97)M82!P<FEM82!D:2!E<V5G=6ER92!L92!O<&5R87II;VYI(&1I
M(&UA;G5T96YZ:6]N93\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S`Y-0IM
M<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D%S<V5G;F%M96YT
M;R!C;VQO;FYE(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T
M96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@
M(E-I(.@@8V5R8V%T;R!D:2!E;&EM:6YA<F4@=6X@9W)U<'!O(&YO;B!E<VES
M=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B4VD@Z"!C97)C871O(&1I(&5L:6UI;F%R92!U;B!P97)M97-S
M;R!N;VX@97-I<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B4VD@Z"!C97)C871O(&1I('!U8F)L:6-A<F4@=6X@
M<&5R;65S<V\@;F]N(&5S:7-T96YT92XB"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!S:&%R92XB"FUS9W-T<B`B4VD@Z"!C97)C871O(&1I('!U8F)L:6-A
M<F4@=6YA(&-O;F1I=FES:6]N92!N;VX@97-I<W1E;G1E+B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8T(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<Q"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(D%T=')I8G5T:2(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U
M<W0B"FUS9W-T<B`B06=O<W1O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR.0IM<V=I9"`B075S=')A;&EA(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C@*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER
M<W%L.B!E<W1E;G-I;VYE(&EM87`@<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*
M"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RXB"FUS9W-T<B`B075T:%]C>7)U<SH@:6P@8F%C:V5N9"!N;VX@:&$@
M;&4@8V%P86-I=.`@<FEC:&EE<W1E+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y
M<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@97-T
M96YS:6]N92!I;6%P(')I8VAI97-T82!N;VX@=')O=F%T82XB"@HC.B!L:6(O
M2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q
M=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I
M=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U
M=&A?9G1P.B!%<W1E;G-I;VYE($944"!R:6-H:65S=&$@;F]N('1R;W9A=&$N
M($-O;7!I;&$@4$A0(&-O;B!L)V]P>FEO;F4@+2TB"B)E;F%B;&4M9G1P+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM
M87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B075T:%]I;6%P.B`@17-T96YS:6]N92!)34%0(')I8VAI97-T82!N;VX@
M=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I
M9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@17-T96YS:6]N92!K<F(U(')I8VAI
M97-T82!N;VX@=')O=F%T82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H
M<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L
M9&%P.B!L)V%G9VEU;G1A(&1I('5T96YT:2!N;VX@Z"!S=7!P;W)T871A('!E
M<B!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@HB
M075T:%]L9&%P.B!L82!C86YC96QL87II;VYE(&1I('5T96YT:2!N;VX@Z"!S
M=7!P;W)T871A('!E<B!!8W1I=F4@1&ER96-T;W)Y(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z
M($5S=&5N<VEO;F4@3$1!4"!R:6-H:65S=&$@;F]N('1R;W9A=&$N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@HB075T:%]L9&%P
M.B!);7!O<W-I8FEL92!A9V=I=6YG97)E(&PG=71E;G1E("5S+B!1=65S=&$@
MZ"!L82!R:7-P;W-T82!D96P@(@HB<V5R=F5R.B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD
M87`Z($EM<&]S<VEB:6QE(&-A;F-E;&QA<F4@;"=U=&5N=&4@)7,B"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T
M<B`B075T:%]L9&%P.B!);7!O<W-I8FEL92!A9V=I;W)N87)E(&PG=71E;G1E
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@;"=A
M9V=I;W)N86UE;G1O(&1E9VQI('5T96YT:2!N;VX@Z"!S=7!P;W)T871O('!E
M<B!!8W1I=F4@(@HB1&ER96-T;W)Y+B(*"B,Z(&QI8B](;W)D92]!=71H+VUC
M86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]M8V%L.B!E<W1E;G-I
M;VYE($U#04P@<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7W-M8F%U=&@Z(&5S=&5N<VEO;F4@<VUB875T:"!R:6-H:65S=&$@;F]N('1R
M;W9A=&$N(@H*(SH@;&EB+TAO<F1E+TE-05`O061M:6XN<&AP.C$P-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("),)V%U=&5N=&EC87II;VYE(&%L('-E<G9E<B!)34%0(.@@9F%L;&ET
M82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM<V=S='(@(D%U=&5N=&EC
M87II;VYE(&9A;&QI=&$B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C8W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<R(*;7-G<W1R(")!=71E;G1I8V%Z:6]N92!F86QL:71A+B`E<R(*"B,Z(&QI
M8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!=71E
M;G1I8V%Z:6]N92!R:69I=71A=&$@9&%L('-E<G9E<B!2041)55,N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C@Y-0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D%U=&5N=&EC87II;VYE(&%L
M('-E<G9E<B!&5%`@9F%L;&ET82XB"@HC.B!L:6(O5D93+W-M8BYP:'`Z-S`*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"XB"FUS9W-T<B`B075T96YT:6-A>FEO;F4@86P@<V5R=F5R(%--0B!F86QL
M:71A+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@
M(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(D-A;7!I(&1I<W!O;FEB:6QI
M.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S$*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")39F]N9&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS
M9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O;&]R92!S9F]N9&\B
M"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM<V=I9"`B0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")087-S=V]R9"!K97)B97)O<R!N
M;VX@=F%L:61A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS
M9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(E5T96YT92!K
M97)B97)O<R!N;VX@=F%L:61O+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#4*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M.`IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS-`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,S"FUS9VED(")"87)B
M861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B1&ER96-T;W)Y(&=R869I8V$@
M9&D@8F%S92!<(B5S7"(@;F]N('1R;W9A=&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"FUS9VED(")"87-E
M;&EN92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0Y"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S4*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU,`IM<V=I9"`B0F5L:7IE(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#`*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$*;7-G:60@(D)E<FUU9&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT-@IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*
M;7-G<W1R(")#;VUP;&5A;FYO(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,V-PHC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S
M7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B
M0FQO8V-O(%PB)7-<(B!D96QL)V%P<&QI8V%Z:6]N92!<(B5S7"(@;F]N('1R
M;W9A=&\N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDP"FUS
M9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R("));7!O<W1A>FEO;FD@0FQO
M8V-O(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED
M(")";&]C:R!4>7!E(@IM<V=S='(@(E1I<&\@0FQO8V-O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"FUS9VED(")";VQD
M(@IM<V=S='(@(D=R87-S971T;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#,*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(E-E9VYA;&EB<FDB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D
M97(B"FUS9W-T<B`B0F]R9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*
M;7-G<W1R(")3<&5S<V]R92!D96P@8F]R9&\Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R
M9&5R<R(*;7-G<W1R(")";W)D:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S(*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`B0F]S;FEA(&4@2&5R>F5G;W9I;F$B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B"FUS9W-T<B`B16YT
M<F%M8F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0X"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*;7-G:60@
M(D)O='1O;2(*;7-G<W1R(")"87-S;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#<*;7-G:60@(D)O=79E="!)<VQA;F0B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT-`IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-PIM
M<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S<*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B16QE;F-O('!U;G1A=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C,V"FUS9VED(")"=7)K:6YA($9A<V\B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HS.0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#35,B"FUS9W-T<B`B0TU3
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@
M(D-20R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T
M<B`B4'5N=&D@1&ES=')I8G5Z:6]N92!#4DPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?
M96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I973@($-?96QL92XN
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@
M(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(DQA(&-A
M8VAE(&EN:7II86QE(&YO;B#H('-T871A(&-O;7!L971A=&$N(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HY,38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-0HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T,"!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W"FUS9VED(")#86QE;F1A<B(*
M;7-G<W1R(")#86QE;F1A<FEO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-0IM<V=I9"`B0V%L;2(*;7-G<W1R(")#86QM;R(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(X"FUS9VED
M(")#86UB;V1I82(*;7-G<W1R(")#86UB;V=I82(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`*;7-G:60@(D-A;65R;V]N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,R(&QI8B]61E,O
M9G1P+G!H<#HV-S8@;&EB+U9&4R]S;6(N<&AP.C0S-0HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HR,#,*;7-G:60@(D-A;B!N;W0@8V]P>2!F:6QE*',I("T@
M<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@=&AE('-A;64N(@IM<V=S='(@
M(B(*(DEM<&]S<VEB:6QE(&-O<&EA<F4@9FEL92AS*2`M(&QA('-O<F=E;G1E
M(&4@;&$@9&5S=&EN87II;VYE('-O;F\@=6=U86QI+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,C`R(&QI8B]61E,O9G1P+G!H<#HW-3(@;&EB+U9&4R]S;6(N
M<&AP.C4P,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-C@*;7-G:60@(D-A
M;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@:7,@=VET:&EN('-O
M=7)C92XB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@<W!O<W1A<F4@:6P@9FEL
M92AS*2`M(&QA(&1E<W1I;F%Z:6]N92#H(&%L;"=I;G1E<FYO(&1E;&QA("(*
M(G-O<F=E;G1E+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P
M"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B));7!O
M<W-I8FEL92!R96EM<&]S=&%R92!L82!P87-S=V]R9"!A=71O;6%T:6-A;65N
M=&4L(&-O;G1A='1A("(*(FPG86UM:6YI<W1R871O<F4N(@H*(SH@;&EB+T9I
M;&4O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N(&YO="!W
M<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("));7!O<W-I8FEL92!S8VEV
M97)E(&YE;"!F:6QE(%PB)7-<(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+B(*;7-G<W1R("));7!O<W-I8FEL92!G97-T:7)E('-E<W-I;VYI
M(&5S=&5R;F4N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M("));7!O<W-I8FEL92!C;VQL96=A<G-I(&%L('-E<G9E<B!)34%0.B`E<R(*
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&%P<FER92!I;"!F:6QE(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.C$Q"FUS9VED(")#86YC96PB"FUS9W-T<B`B0V%N
M8V5L;&$B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM
M<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D-A;F-E;&QA
M(&EL(%)E<&]R="!P<F]B;&5M82(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&EL(&9I;&4@7"(E
M<UPB+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]C;W!Y+G!H<#HU,@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W-I8FEL92!T<F]V87)E
M('5N82!D:7)E8W1O<GD@=&5M<&]R86YE82XB"@HC.B!L:6(O5D93+TE33U=R
M:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<')O
M8V5D97)E('-E;GIA(&EL('!A<F%M971R;R`G=&%R9V5T1FEL92<N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(')I;75O=F5R92!L82!D:7)E8W1O<GD@(%PB)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O1&%T851R964N<&AP.C$R."!L:6(O2&]R9&4O1&%T851R964O<W%L
M+G!H<#HV.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@
M)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DEM<&]S<VEB:6QE(')I;75O
M=F5R92P@97-I<W1O;F\@)60@9FEG;&DN(@H*(SH@;&EB+TAO<F1E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M
M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@
M;6%T8V@@;G5M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@HB26UP;W-S:6)I
M;&4@<FEO<F1I;F%R92P@;"=E;&5N8V\@9F]R;FET;R!N;VX@8V]R<FES<&]N
M9&4@8V]N(&PG96QE;F-O("(*(FUE;6]R:7IZ871O+B(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U
M=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("));7!O
M<W-I8FEL92!I;G-T<F%D87)E(&EL(&UE<W-A9V=I;R!A;"!N=6UE<F\@<W!E
M8VEF:6-A=&\N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV-0IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(D-A
M<G)I97)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#
M871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B0V%T96=O<FEE(&4@171I
M8VAE='1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S4*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(DES;VQE
M($-A>6UA;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@(D-E;&QU;&%R92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@
M0V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R(")2:65M<&EM
M96YT;R!C96QL93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS
M9W-T<B`B4')O<')I973@(&-E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB
M"FUS9W-T<B`B4W!A>FEO(&-E;&QE.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B0V5L;'5L87)E(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/
M+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G
M<W1R(")#96YT<F\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@
M(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@(D5U<F]P
M82!#971R86QE("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S
M='(@(D1E='1A9VQI(&1E;"!#97)T:69I8V%T;R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*
M;7-G<W1R(")0<F]P<FEE=&%R:6\@9&5L($-E<G1I9FEC871O(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E
M(%!O;&EC:65S(@IM<V=S='(@(E!O;&ET:6-H92!D96P@0V5R=&EF:6-A=&\B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C$*;7-G:60@(D-H860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D-A;6)I82(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S
M<W=O<F0B"FUS9W-T<B`B0V%M8FEA(&QA('1U82!087-S=V]R9"(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV.0IM<V=I9"`B(@HB0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(B(*(D-A
M;6)I82!I;"!N;VUE(&4@;"=I;F1I<FEZ>F\@8VAE(&QE('!E<G-O;F4@=F5D
M;VYO('%U86YD;R!L96=G;VYO(&4@(@HB<FES<&]N9&]N;R!A;&QE('1U92!E
M;6%I;"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,C0*;7-G
M:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E
M9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("`B"B)#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB26P@8V%M8FEO(&1E
M;&QA('1U82!P87-S=V]R9"!N;VX@Z"!S=7!P;W)T871O(&-O;B!L82!C;VYF
M:6=U<F%Z:6]N92`B"B)C;W)R96YT92X@($-O;G1A='1A(&PG86UM:6YI<W1R
M871O<F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")#87)B;VYE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")#:&5C7VL@
M3&EN:RXN+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3D*;7-G:60@(D-H:6QE(@IM<V=S='(@(D-I;&4B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8Q"FUS9VED(")#
M:&EN82(*;7-G<W1R(")#:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#,*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*
M;7-G<W1R(")38V5G;&D@;"=A<'!L:6-A>FEO;F4Z(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(E-C96=L:2!U;F$@<&%S<W=O<F0B"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B
M"FUS9W-T<B`B4V-E9VQI('5N(&YO;64@=71E;G1E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y
M(&1A=&5S.B(*;7-G<W1R(")38V5G;&D@8V]M92!V:7-U86QI>GIA<F4@;&$@
M9&%T83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E
M("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B4V-E9VQI(&EL('1I<&\@
M9&D@<W1I;&4@9&5L;&$@;&ES=&$@*'!E<B!L:7-T92!O<F1I;F%T92DB"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V"FUS
M9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,N
M<&AP.CDQ-"!L:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G
M:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("),82!D969I;FEZ:6]N92!D:2!C;&%S<V4@9&D@)7,@;F]N(.@@<W1A=&$@
M=')O=F%T82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B0VAI87)O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B
M0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R(")!;FYU
M;&QA($1O;6%N9&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B
M"FUS9W-T<B`B16QI;6EN82!L)W5T96YT93H@)7,B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS
M9W-T<B`B16QI;6EN82!U=&5N=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@
M(D5L:6UI;F$@:6YF;W)M87II;VYI('5T96YT92(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A<FEN9R!,
M871E(@IM<V=S='(@(D5L:6UI;F%R92!$;W!O("(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T
M;R!#;VYT:6YU92(*;7-G<W1R(")#;&EC:R!P97(@0V]N=&EN=6%R92(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#
M;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM
M<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(D-H:75D:2!&:6YE<W1R82(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U9',B"FUS
M9W-T<B`B3G5B:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3G5B:2!P
M<F5S=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DYU=F]L;W-O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,@IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED
M96)A<B(*;7-G<W1R(")#:&EU9&D@4VED96)A<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O
M;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(D-H:75D:2!I(&)O<F1I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,@IM<V=I
M9"`B0V]L;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H
M<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R
M(@IM<V=S='(@(D-O;&]R92(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,#,@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,S.`HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Y('-E
M<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M<&QA=&5S
M+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@(D-O;&]R
M(%!I8VME<B(*;7-G<W1R(")-87!P82!#;VQO<FDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C@R.`IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R
M(")396QE>FEO;F4@8V]L;W)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D-O
M;&]N;F4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O
M;'5M;B!T:71L97,B"FUS9W-T<B`B5&ET;VQO(&-O;&]N;F4B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T
M<B`B0V]M:6-H92(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-@IM<V=I9"`B
M0V]M;6%N9"(*;7-G<W1R(")#;VUA;F1O(@H*(SH@861M:6XO8VUD<VAE;&PN
M<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DQI;F5A(&1I
M(&-O;6%N9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M;65N=&\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T
M<B`B3F]M92!#;VUU;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$S,`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R(")!>FEE;F1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B0V]M<'5T97)S
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B
M0V]N9&ET:6]N(@IM<V=S='(@(D-O;F1I>FEO;F4B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U-@IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD
M:7II;VYI(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1&EF9F5R96YZ92!N
M96QL82!C;VYF:6=U<F%Z:6]N92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!0
M1$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@HB0V]N
M9FEG=7)A>FEO;F4@<&5R(&QA('-I;F-R;VYI>GIA>FEO;F4@8V]N(%!$07,L
M(%-M87)T<&AO;F5S(&4@3W5T;&]O:RXB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E
M+B(*;7-G<W1R("),82!C;VYF:6=U<F%Z:6]N92#H('9E8V-H:6$N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B0V]N9FEG=7)A("5S(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER
M;2!087-S=V]R9"(*;7-G<W1R(")#;VYF97)M82!L82!087-S=V]R9"(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34*;7-G
M:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B0V]L;&5G86UE;G1O(&9A;&QI=&\N(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y-R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(D-O;&QE9V%M96YT;R!F86QL:71O.B`B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@
M:V5Y<V5R=F5R(&]U8F)L:6-O(')I9FEU=&%T82XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RDB"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@:V5Y<V5R=F5R('!U
M8F)L:6-O(')I9FEU=&%T82X@36]T:79O.B`E<R`H)7,I(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C@X.0IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`B0V]N;F5S<VEO;F4@86P@<V5R=F5R($944"!F
M86QL:71A+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(T(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED(")#;VYT86-T<R(*;7-G<W1R(")#
M;VYT871T:2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("))(&-O;G1A='1I('-O;F\@
M<W1A=&D@86=G:75N=&D@8V]N('-U8V-E<W-O(&%L;&$@='5A(')U8G)I8V$N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@
M(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4
M:7!O(&1I(&-O;G1E;G5T;R!D96P@9FEL92!C;VUP<F5S<V\Z("(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T9WHN<&AP.C<U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8S"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB
M)7-<(B(*;7-G<W1R(")#;VYT96YU=&D@9&D@7"(E<UPB(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")#;VYT:6YU82(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3@*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6$B"@HC.B!L:6(O5D93+W-M
M8BYP:'`Z-#@P"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E
M<R(*;7-G<W1R(")#;W!I82!F86QL:71A.B`E<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L
M96-T:6]N(@IM<V=S='(@(D-O<&EA('-E;&5Z:6]N92(*"B,Z(&QI8B].970O
M4TU3+W=I;E]H='1P+G!H<#HQ-S`@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S"FUS9VED(")#;W-T82!2
M:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-3<*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3<W"FUS9VED(")#;W5L
M9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(@IM<V=S='(@(DYO;B!S:2!P
M=?(@8VEF<F%R92!I;B!01U`@:6P@;65S<V%G9VEO(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4Z("(*;7-G<W1R(").;VX@<VD@<'7R(&9I<FUA<F4@:6X@4$=0
M(&EL(&UE<W-A9V=I;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB
M"FUS9W-T<B`B3F]N('-I('!U\B!C<FEF<F%R92!I;B!3+TU)344@:6P@;65S
M<V%G9VEO(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G
M:60@(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(").
M;VX@<VD@<'7R(&9I<FUA<F4@:6X@4R]-24U%(&EL(&UE<W-A9V=I;R(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M(").;VX@<VD@<'7R(&%G9VEU;F=E<F4@:6P@8V]N=&%T=&\N("5S(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0X,B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z.38*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED
M(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F]N
M('-I('!U\B!I;G1E<G)O9V%R92!I;"!S97)V97(@3$1!4"XB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,R!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").;VX@<VD@<'7R
M('9E<FEF:6-A<F4@;"=E<75I;&EB<FEO+B`E<R(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-C8*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W-I8FEL92!C;VQL96=A<G-I(&%L
M('-E<G9E<B!,1$%0+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@
M8V]L;&5G87)S:2!A;"!S97)V97(@7"(E<UPB('5S86YD;R!&5%`Z("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@=6YA(&QI<W1A
M(&1I(&1I<W1R:6)U>FEO;F4N("5S(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z
M("(*;7-G<W1R("));7!O<W-I8FEL92!D96-I9G)A<F4@:6P@9&%T;R!I;B!F
M;W)M871O(%!'4#H@(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G
M<W1R("));7!O<W-I8FEL92!D96-I9G)A<F4@:6P@9&%T;R!I;B!F;W)M871O
M(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C0V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN87)E(&EL(&-O
M;G1A='1O+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI
M;6EN87)E(&QE(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(B(*(DEM<&]S:6)I;&4@96QI;6EN87)E(&QO('-C<FEP="!D
M:2!A9V=I;W)N86UE;G1O(&1E;&PG:6UP;W-T87II;VYE(%PB)7-<(BXB"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HS.#$*;7-G:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE
M(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R("));7!O<W-I
M8FEL92!D971E<FUI;F%R92!G;&D@:6YD:7)I>GII(&5M86EL(&1E:2!D97-T
M:6YA=&%R:2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(")I26UP;W-S:6)I;&4@<V-A<FEC87)E(&EN(&UO9&\@
M8V]M<&QE=&\@;&$@<G5B<FEC82XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DEM<&]S<VEB:6QE('-C
M87)I8V%R92!I;B!M;V1O(&-O;7!L971O(&QA(&QI<W1A(&1I(&1I<W1R:6)U
M>FEO;F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T
M-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F
M(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@HB26UP;W-S:6)I;&4@
M<V-A<FEC87)E(&EN(&UO9&\@8V]M<&QE=&\@;&$@;&ES=&$@9&5L;&4@;&ES
M=&4@9&D@9&ES=')I8G5Z:6]N92XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z.#0*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(DEM
M<&]S<VEB:6QE(&-A<FEC87)E(&QA('-T<F%T96=I82!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP
M:'`Z,S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,3$P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M
M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-R96%R92!L82!D
M:7)E8W1O<GD@7"(E<UPB+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@;W1T96YE<F4@
M;&$@8VAI879E('!U8F)L:6-A(&1A;"!S97)V97(N(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(%PB)7-<(B!P97(@
M;&$@<FES8W)I='1U<F$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#4@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R("));7!O<W-I
M8FEL92!A<')I<F4@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@
M87!R:7)E(&EL(&UO9'5L;R!-86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@87!R:7)E(&QA(&1I<F5C
M=&]R>2!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q
M,2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HR,S<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W
M.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C8U-B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W-I
M8FEL92!C;VYT871T87)E(&EL('-E<G9E<B!,1$%0+B(*"B,Z(&QI8B]61E,O
M3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E860@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&QE9V=E<F4@)7,N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O
M=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@
M=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B))
M;7!O<W-I8FEL92!A>GIE<F%R92!L82!P87-S=V]R9"!P97(@;"=U=&5N=&4@
M<FEC:&EE<W1O+B!!;&-U;FD@;R!T=71T:2!I("(*(F1E='1A9VQI(&YO;B!S
M;VYO(&-O<G)E='1I+B!2:7!R;W9A(&%N8V]R82!O(&-O;G1A='1A(&PG86UM
M:6YI<W1R871O<F4@<V4@(@HB;F5C97-S:71I(&1I('5L=&5R:6]R92!A:75T
M;RXB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`W(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,S@*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-2!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S@Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.#<*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T
M<B`B26UP;W-S:6)I;&4@<F5C=7!E<F%R92!!0TPB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(')E8W5P97)A<F4@;&$@<G5B<FEC82X@)7,B"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L82!L:7-T
M82!D:2!D:7-T<FEB=7II;VYE+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B
M26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L92!L:7-T92!D:2!D:7-T<FEB=7II
M;VYE+B`E<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"FUS9VED(")#;W5L9"!N
M;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(DEM
M<&]S<VEB:6QE(')E8W5P97)A<F4@;&4@<&]S<VEB:6QI=.`@9&5L('-E<G9E
M<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B26UP;W-S:6)I
M;&4@:6YV97)T:7)E(&QA(&-O;F9I9W5R87II;VYE+B(*"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S
M='(@(DEM<&]S<VEB:6QE(&-A;F-E;&QA<F4@;&$@9&ER96-T;W)Y(%PB)7-<
M(BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("));7!O<W-I8FEL92!S86QV87)E(&QA(&-O;F9I9W5R87II;VYE
M(&1I("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("));7!O<W-I8FEL92!S86QV
M87)E('5N82!C;W!I82!D96QL82!C;VYF:6=U<F%Z:6]N92XB"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R
M("));7!O<W-I8FEL92!S86QV87)E('5N82!C;W!I82!D96QL82!C;VYF:6=U
M<F%Z:6]N93H@)7,B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"B));7!O<W-I8FEL
M92!S86QV87)E(&QO('-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM
M<&]S=&%Z:6]N:2!S=3H@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DEM
M<&]S<VEB:6QE('-A;'9A<F4@:6P@9FEL92!D:2!S86QV871A9V=I;R!D96QL
M82!C;VYF:6=U<F%Z:6]N92!D:2`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N(@IM<V=S='(@(B(*(DEM<&]S<VEB:6QE('-A;'9A<F4@:6P@9FEL92!D
M:2!C;VYF:6=U<F%Z:6]N92!D:2`E<RX@4'5O:2!U<V%R92!N82!D96QL92`B
M"B)O<'II;VYI('!E<B!S86QV87)E(&EL(&-O9&EC92!S=2`E<R!O(&-O<&EA
M<F4@;6%N=6%L;65N=&4@:6P@8V]D:6-E('-O='1O('-U("(*(B5S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$T,PIM<V=I9"`B0V]U;&0@;F]T
M('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&9A<F4@=6YA(')U8V5R8V$@;F5L('-E<G9E<B!,1$%0+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B26UP;W-S:6)I;&4@86=G:6]R;F%R92!I;"!C
M;VYT871T;RX@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%G
M9VEO<FYA<F4@;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B26UP;W-S:6)I;&4@<V-R:79E<F4@;&$@8V]N9FEG=7)A>FEO
M;F4@<&5R(%PB)7-<(CH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("));7!O
M<W-I8FEL92!T<F]V87)E(&QA(%-I9&5B87(@9&D@36]Z:6QL82X@07-S:6-U
M<F%T:2!C:&4@<VEA(&%P97)T82XB"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD
M;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R
M('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"B));7!O<W-I8FEL
M92!D87)E(&%L;"=U=&5N=&4@7"(E<UPB(&D@<V5G=65N=&D@9&ER:71T:2!P
M97(@;&$@8V%R=&5L;&$@7"(E<R(*(EPB.B`E<R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5&5S
M=&\@8V]N=&%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P
M"FUS9VED(")#;W5N=')Y(@IM<V=S='(@(DYA>FEO;F4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@
M(D-O<G-I(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B0W)E
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<F5A
M('5N(&QI;FLB"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-R96$@
M=6YO(&YU;W9O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.CDR(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU,@IM<V=I9"`B
M0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D-R96%R92!S;W1T;R!C87)T
M96QL92(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS9VED(")#
M<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D-R96%T;W)E(&1I('!E<FUE
M<W-I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,3(*;7-G:60@(D-R961I
M="!C87)D(&YU;6)E<B(*;7-G<W1R(").=6UE<F\@8V%R=&$@9&D@8W)E9&ET
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV
M-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C0*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(D-O<G)E;G1E(#0@1F%S:2(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*
M;7-G<W1R(")397-S:6]N:2!C;W)R96YT:2(*"B,Z(&QI8B]";&]C:R]T:6UE
M+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4
M:6UE(@IM<V=S='(@(E1E;7!O($%T='5A;&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U
M<G)E;G0@55),(&ES(@IM<V=S='(@(DQA(%523"!A='1U86QE(.@B"@HC.B!A
M9&UI;B]S97-S:6]N<RYP:'`Z,S4*;7-G:60@(D-U<G)E;G0@57-E<G,B"FUS
M9W-T<B`B571E;G1I($%T='5A;&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B5&5M<&\@071T
M=6%L92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C0*;7-G
M:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B0V]N9&EZ:6]N92!C
M;W)R96YT93H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(")3=&EL
M92!C;W)R96YT92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N
M(&QO9V]N('1O("5S+B(*;7-G<W1R(")097)S;VYA;&EZ>F$@;&4@;W!E<F%Z
M:6]N:2!D82!E<V5G=6ER92!A;&PG879V:6\@9&D@)7,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G
M:60@(D-U="(*;7-G<W1R(")486=L:6$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N
M(@IM<V=S='(@(E1A9VQI82!L82!S96QE>FEO;F4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W"FUS9VED(")#>7!R=7,B
M"FUS9W-T<B`B0VEP<F\B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM
M<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R
M-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.`IM
M<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,R-S(*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H
M<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1VEO<FYA;&UE;G1E(@H*(SH@
M861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<P"FUS9VED
M(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S.3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S(*;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D
M(@IM<V=S='(@(D1A=&$@4FEC979U=&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C<X.0IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II
M;VYA(&QA(&1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A
M>2(*;7-G<W1R(")':6]R;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L
M=6UN(@IM<V=S='(@(D5?;&EM:6YA($-O;&]N;F$B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-3$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B
M1&EC96UB<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS
M9W-T<B`B3G5M97)I(&1E8VEM86QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(D1I;6EN=6ES8VD@;&$@<FEE;G1R86YZ82(*"B,Z(&QI8B]P
M<F5F<RYP:'`Z,3$W(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W"FUS9VED
M(")$969A=6QT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E
M9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM
M<V=S='(@(D-O;&]R92!S=&%N9&%R9"(*"B,Z(&QI8B](;W)D92])9&5N=&ET
M>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B261E
M;G1I=.`@9&D@9&5F875L="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-0IM<V=I9"`B1&5F875L="!3:&5L;"(*;7-G<W1R(")3:&5L;"!D:2!D969A
M=6QT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I
M;FET:6]N<R(*;7-G<W1R(")$969I;FEZ:6]N:2(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z-S$@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HT,C(*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,SD@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY."!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS,0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3`*;7-G:60@(D1E;&5T92(*;7-G<W1R(")%;&EM:6YA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R(")%;&EM:6YA($-E;&QA
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR
M,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")%;&EM:6YA($=R=7!P
M;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B
M1&5L971E($QO9R(*;7-G<W1R(")%;&EM:6YA($QO9R(*"B,Z(&QI8B](;W)D
M92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(D5L:6UI;F$@4&5R
M;65S<V\B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*
M;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B16QI
M;6EN87)E(&4@<W9U;W1A<F4@:2!M97-A9V=I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L
M971E(&-E;&PB"FUS9W-T<B`B16QI;6EN82!C96QL82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B16QI;6EN82!C;VQO;FYA(@H*(SH@
M861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B16QI;6EN82!L82!M87-C
M:&5R82!A;'1E<FYA=&EV82!E<VES=&5N=&4B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S86=E<R(*
M;7-G<W1R(")%;&EM:6YA(&D@;65S<V%G9VDB"@HC.B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")%;&EM:6YA(&D@<&5R;65S
M<VD@<&5R(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(T
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")%;&EM
M:6YA(&D@<&5R;65S<VD@<&5R(%PB)7-<(B!E(&]G;FD@<V]T=&\M<&5R;65S
M<V\_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")%;&EM:6YA
M(')I9V$B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC
M.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M16QI;6EN82!L)VED96YT:73@('-E;&5Z:6]N871A(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$96QE=&4@<W5B(&9O
M;&1E<G,B"FUS9W-T<B`B16QI;6EN82!L92!S;W1T;R!C87)T96QL92(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R
M(")%;&EM:6YA(&QA(&-O;&]N;F$@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B16QI;6EN82!L82!R
M:6=A(&-O<G)E;G1E(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="!<(B5S7"(N(@IM<V=S='(@(D5L:6UI;F$@;&\@<V-R:7!T(&1I(&%G
M9VEO<FYA;65N=&\@9&5L;&4@:6UP;W-T87II;VYI(&1I(%PB)7-<(BXB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,2!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.34*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B5&5M
M<&\@9"=I;G9I;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S$*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N:6UA<F-A
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@
M(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D1E<V-R:79I(&EL('!R
M;V)L96UA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDS."!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEZ:6]N92(*"B,Z(&QI8B](;W)D
M92YP:'`Z,C`V"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ(@IM<V=S='(@(D1E='1A9VQI("AA;F-H92!N96P@9FEL92!D:2!L
M;V<@9&D@2&]R9&4I.B(*"B,Z(&QI8B](;W)D92YP:'`Z,C$P"FUS9VED(")$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("))(&1E='1A9VQI('-O;F\@<W1A=&D@<V-R:71T:2!N96P@
M9FEL92!D:2!L;V<@<&5R(&PG86UM:6YI<W1R871O<F4N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(R,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS
M9W-T<B`B4W9I;'5P<&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-`IM
M<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(E!U;G1O(&1I(')U9VEA9&$B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,0IM<V=I9"`B1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R(")0=6YT;R!D:2!R=6=I861A('!E<B!L
M)W5L=&EM82!O<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,38*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(E!U;G1O(&1I(')U
M9VEA9&$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM<V=S
M='(@(D1I<F5Z:6]N92!D82!S:6YI<W1R82!A(&1E<W1R82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I
M<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S='(@(D1I<F5Z:6]N92!D82!D
M97-T<F$@82!S:6YI<W1R82(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y
M"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*
M;7-G<W1R(")6:7-U86QI>GIA(&EL('1E;7!O(&YE;"!F;W)M871O(#(T(&]R
M93\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!D:2!V:7-U86QI>GIA>FEO
M;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.#D*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B5FES=6%L:7IZ
M82!P<F5V:7-I;VYE(&1E='1A9VQI871A(@H*(SH@;&EB+V)L;V-K+VUE=&%R
M+G!H<#HY,@IM<V=I9"`B9&ES<&QA>2!F;W)E8V%S="`H=&%F*2(*;7-G<W1R
M(")V:7-U86QI>GIA('!R979I<VEO;F4@*'1A9BDB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C<Y.0IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B
M1F]R;6%T;R!D:2!V:7-U86QI>GIA>FEO;F4B"@HC.B!L:6(O2&]R9&4O34E-
M12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M(@IM<V=S='(@(DYO=&EF:6-A(&1I(&1I<W!O<VEZ:6]N92(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`*;7-G:60@(D1J
M:6)O=71I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(DYO;B!E;&EM:6YA
M<F4B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@
M(DYO;B!A8V-E9&5R92!D:7)E='1A;65N=&4@;6%I;G1E;F%N8V4N<&AP(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C
M;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O
M>#HB"FUS9W-T<B`B(@HB3&%P<FEM82!R:6=A(&-O;G1I96YE(&EL(&-A;7!O
M(&1E:2!N;VUI/R!392!S:2P@<V5L97II;VYA('%U97-T82!C87-E;&QA.B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S(*
M;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,*;7-G:60@(D1O;6EN:6-A;B!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(DYO;B!H86D@=6XG=71E;GIA/R!I<V-R:79I=&DN(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U,PIM<V=I9"`B1&]W;FQO
M860B"FUS9W-T<B`B4V-A<FEC82(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E
M;G1S+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B
M"FUS9W-T<B`B4V-A<FEC82`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-C$*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(DQA(&-O;F9I9W5R87II;VYE(&=E
M;F5R871A(.@@<W1A=&$@<V-A<FEC871A(&-O;64@<V-R:7!T(%!(4"XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$P-PIM<V=I9"`B1')O<"!D;W=N(&QI
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS
M9VED(")$<G5G<R(*;7-G<W1R(")$<F]G:&4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT
M;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V
M:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-0IM<V=I9"`B16-U861O<B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4&5R;7,N<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS9W-T<B`B4'5B8FQI8V$B"@HC
M.B!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K
M(@IM<V=S='(@(E9I<W5A;&EZ>F$@8FQO8V-O(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G:60@(D5D:70@1W)O
M=7`B"FUS9W-T<B`B5FES=6%L:7IZ82!'<G5P<&\B"@HC.B!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C<V(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B5FES=6%L:7IZ82!097)M
M97-S;R(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5FES=6%L:7IZ82!097)M97-S
M:2(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M5FES=6%L:7IZ82!097)M97-S:2!P97(@)7,B"@HC.B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R
M(")6:7-U86QI>GIA(&QE(&]P>FEO;FD@<&5R.B(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R(")6:7-U86QI>GIA(&D@<&5R
M;65S:2!P97(@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B`E<R(*;7-G<W1R(")6:7-U86QI>GIA(&D@<&5R;65S<VD@<&5R("5S(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HW-PIM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I='1O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W"FUS
M9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`B16QE;65N=&\N+BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-CD@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R("));F1I<FEZ>F\@16UA:6PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3DV,PIM<V=I9"`B16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(@IM
M<V=S='(@(DPG:6YD:7)I>GIO($5M86EL(&1E=F4@8V]R<FES<&]N9&5R92XB
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DX.0IM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B16UA:6P@8V]N(&-O;F9E<FUA(@H*
M(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")-97-S86=G:6\@
M=G5O=&\N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C(T,R!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HV-C(@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L
M="XB"FUS9W-T<B`B4FES=6QT871O('9U;W1O+B(*"B,Z(&QI8B](;W)D92]3
M44PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS
M(@IM<V=S='(@(E)I8V5R8V$@9&5I('1E<FUI;FD@=G5O=&$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N
M(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G
M<W1R("(B"B)!8FEL:71A(&PG:6YS97)I;65N=&\@9&D@:6UM86=I;FD@;F5L
M('1E<W1O(&1A;&QA($=A;&QE<FEA(&1E;&QE($9O=&]G<F%F:64_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT
M(&-L:6-K(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06)I;&ET87)E(&EL(&UE
M;G4@9&D@8V]N=&5S=&\@8VQI8V-A;F1O(&EL('1A<W1O(&1E<W1R;R!D96P@
M;6]U<V4_(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.#@@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(W.3,*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(D9I;F4@
M86YN;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(DEN9W)A9&ES
M8VD@;"=E9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS
M9VED("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB
M"FUS9W-T<B`B(@HB26YS97)I<V-I('5N82!D;VUA;F1A('-I8W5R82!C:&4@
M=&D@=F5R<N`@8VAI97-T82!S92!A=G)A:2!N96-E<W-I=.`@9&D@(@HB87IZ
M97)A<F4@;&$@='5A('!A<W-W;W)D+"!E<R`G<75A;"?H(&EL(&YO;64@9&5L
M('1U;R!C=6-C:6]L;S\G.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0IM<V=I9"`B16YT97(@=&AE
M(&EM86=E(%523"!H97)E(@IM<V=S='(@(DEN<V5R:7-C:2!L)U523"!D96QL
M)VEM;6%G:6YE('%U:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*
M;7-G<W1R("));G-E<FES8VD@;&4@;&5T=&5R92!S;W1T;R!R:7!O<G1A=&4Z
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY
M.0IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.0IM<V=I9"`B
M17)I=')E82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]6:65W+G!H<#HY-`IM<V=I9"`B17)R;W(B"FUS
M9W-T<B`B17)R;W)E(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E+G!H<#HT-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M(@IM<V=S='(@(D5R<F]R92!C<F5A;F1O(&EL(&)L;V-C;SH@)7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B
M17)R;W)E(&5L:6UI;F%N9&\@;"=A;F-O<F$@9&D@<VEN8W)O;FEA.B`E<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R
M(")%<G)O<F4@96QI;6EN86YD;R!I;"!L;V<@9&D@<VEN8W)O;FEA.B`E<R(*
M"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B17)R
M;W)E(&]T=&5N96YD;R!I;"!C;VYT96YU=&\Z("5S(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")%<G)O<F4@86=G
M:6]R;F%N9&\@;&$@<&%S<W=O<F0Z("5S(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@
M;65S<V%G92XB"FUS9W-T<B`B17)R;W)E(&-O;B!I;"!M97-S86=G:6\@96UA
M:6PN(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO
M8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I
M;F<@7"(E<UPB+B(*;7-G<W1R(")%<G)O<F4@<V-R:79E;F1O(%PB)7-<(BXB
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V
M"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$*;7-G:60@(D5T:&EO<&EA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B
M171H;FEC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R
M(")/9VYI(#$U(&UI;G5T:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")/9VYI(#(@;6EN
M=71I(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,"!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S
M='(@(D]G;FD@,S`@<V5C;VYD:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@
M-2!M:6YU=&5S(@IM<V=S='(@(D]G;FD@-2!M:6YU=&DB"@HC.B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R(")!9"!O9VYI(&%C8V5S<V\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B3V=N:2!M
M97IZ)V]R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#$@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN=71E(@IM<V=S
M='(@(D]G;FD@;6EN=71O(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI
M;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")686QO<FD@
M9"=E<V5M<&EO.B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HU,2!A9&UI;B]P
M:'!S:&5L;"YP:'`Z.#(@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B
M17AE8W5T92(*;7-G<W1R(")%<V5G=6DB"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(D5S<&%N9&DB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R
M"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R(")%<W!A;F1I(%-I9&5B
M87(B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R(")0<F5V:7-T;R`G*2<B"@HC.B!L:6(O
M2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A
M<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FTB"FUS9W-T<B`B:5!A<F]L
M82!P<F5V:7-T82!O('1E<FUI;F4@8VET871O(&1I(')I8V5R8V$B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@
M1&%T92(*;7-G<W1R(")$871A(&1I('-C861E;GIA(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(D5S<&]N96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D-O
M;&]R92!&1R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S8*;7-G:60@
M(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B06=G:6]R;F%M96YT;R!&
M5%`@9&5L;&4@:6UP;W-T87II;VYI(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q
M;"YP:'`Z,C(P"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RXB"FUS9W-T<B`B5&5N=&%T:79O(&9A;&QI=&\@;F5L(')E8W5P97)O(&1E
M;&QE('!R969E<F5N>F4N(@H*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP
M.C<U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B0V]L;&5G86UE
M;G1O(&%L('-E<G9E<B!,1$%0(&9A;&QI=&\N(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"
M('-E<G9E<BXB"FUS9W-T<B`B0V]L;&5G86UE;G1O(&%L('-E<G9E<B!334(@
M9F%L;&ET;RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S(U"B,L('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R
M(").;VX@Z"!R:75S8VET;R!A(&-O<&EA<F4@9&$@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HW,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(").;VX@Z"!R:75S8VET;R!A
M(&-O<&EA<F4@82!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP
M:'`Z.#<*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B3F]N(.@@<FEU<V-I=&\@82!C<F5A<F4@=6YA(&YU
M;W9A(&-O;FYE<W-I;VYE(%-!4TPN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V
M."!L:6(O5D93+W-M8BYP:'`Z-3$T"B,L('!H<"UF;W)M870*;7-G:60@(D9A
M:6QE9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B3F]N(.@@<FEU<V-I
M=&\@82!S<&]S=&%R92!A(%PB)7-<(BXB"@HC.B!L:6(O5D93+W-M8BYP:'`Z
M-#<T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@
M)7,B"FUS9W-T<B`B3F]N(.@@<FEU<V-I=&\@82!R96-U<&5R87)E.B`E<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS
M9VED(")&86ER(@IM<V=S='(@(D=I=7-T;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I
M9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(D5R<F]R92!&871A;&4Z(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A
M>"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Q
M"FUS9VED(")&87AE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`S(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5B8G)A
M:6\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R(")3:6UI;&4@82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C`*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")3
M:6UI;&4@83HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E
M=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-0IM<V=I9"`B1FEG;&5T($-!4%1#2$$B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,CD*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&
M:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B0V]N=&5G9VEO
M(&9I;&4Z("5S(&9I;&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R(")#;VYT96=G
M:6\@9FEL93H@)7,@9FEL97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#`Y"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1V5S=&EO;F4@
M1FEL92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8S(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<P"FUS9VED(")&:6QE($YA;64B"FUS9W-T
M<B`B3F]M92!&:6QE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y-S<*;7-G
M:60@(D9I;&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5Z:6]N92!F:6QE(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D
M(@IM<V=S='(@(D-A<FEC82!&:6QE(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N
M<&AP.CDP,`IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM
M<V=S='(@(D-A<FEC86UE;G1O(&9I;&4@;F]N('-U<'!O<G1A=&\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B1FEL=')I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD
M:6$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(
M86QF(@IM<V=S='(@(E!R:6UO($UE>GIO(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW-@IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R(")0<FEM;R!1=6%R=&\B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS
M9W-T<B`B4F%P<&]R=&\@9FES<V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B
M3F5B8FEA(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3`W(&QI8B]61E,O<W%L
M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T(@IM<V=S='(@(DQA($-A<G1E;&QA("5S(&YO;B!E<VES=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R
M"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(D-O;&]R92!D96QL82!F;VYT
M92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*
M;7-G<W1R(")#:6)O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"FUS9VED(")&;W(@8G)O=W-E<G,@
M=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")097(@8G)O=W-E
M<B!C:&4@;F]N('-U<'!O<G1A;F\@;&4@:6UM86=I;FDB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,T,0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T
M<B`B4')E=FES:6]N92`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@
M82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM
M<V=S='(@(DAA:2!D:6UE;G1I8V%T;R!L82!P87-S=V]R9#\B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*;7-G:60@(D9O<G1U
M;F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS
M9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I
M9"`B1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,3$*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(DEN;VQT<FDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS
M9VED(")&<B(*;7-G<W1R(")692(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C@W"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;F-I82(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O
M<&]L:71A;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDQ"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@T"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,@IM
M<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED
M(")&<F]M(@IM<V=S='(@(D1A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*;7-G:60@(D9R;VT@
M=&AE("(*;7-G<W1R(")$82!I;"`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R
M(")$97-C<FEZ:6]N92!#;VUP;&5T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB
M"FUS9W-T<B`B3&YA(%!I96YA(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@
M(D9U;&P@3F%M92(*;7-G<W1R(").;VUE($-O;7!L971O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.`IM<V=I9"`B1V%B
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A
M:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QL97)I82!D86QL82!Q=6%L92!P
M<F5N9&5R92!L92!I;6UA9VEN:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R
M>3HB"FUS9W-T<B`B1V%L;&5R:6$Z(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY-@IM<V=I9"`B1V%M8FEA(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'
M96YE<F$@)7,@0V]N9FEG=7)A>FEO;F4B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`B0V]D:6-E($=E;F5R871O(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(D=E<FUA;FEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,PIM<V=I9"`B
M1VAA;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(D=I
M8FEL=&5R<F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-@IM
M<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R(").;VUE($1A=&\B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<Y('1E;7!L871E<R]P<F5F<R]A
M<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED
M(")';&]B86P@3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI($=L;V)A;&DB"@HC
M.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T
M<B`B5F%I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")'
M;V5D96PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(DUA
M<'!E($=O;V=L92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G
M:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(E-C86QE(&1I(&=R:6=I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDS"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#`*;7-G:60@(D=R965C92(*;7-G<W1R
M(")'<F5C:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R(")!;6UI;FES=')A>FEO;F4@1W)U<'!I(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+G!H<#HU.2!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,38Y
M"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R
M("))(&YO;6D@9&5L(&=R=7!P;R!N;VX@9&5V;VYO(&5S<V5R<F4@=G5O=&DB
M"@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M
M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)'
M<F]U<%]L9&%P.B!);7!O<W-I8FEL92!A9V=I=6YG97)E(&EL(&=R=7!P;R`E
M<RX@475E<W1A(.@@;&$@<FES<&]S=&$@9&5L("(*(G-E<G9E<CH@(@H*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q."!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,3(T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E
M;&5T92!G<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!);7!O<W-I9&EL
M92!E;&EM:6YA<F4@:6P@9W)U<'!O("5S(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@26UP;W-S:6)I;&4@
M86=G:6]R;F%R92!I;"!G<G5P<&\@)7,B"@HC.B!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@
M(D=R=7!P:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3@*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,*;7-G:60@
M(D=U86TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#(*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,C(V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(E!E<FUE<W-I(&1E9VQI(&]S<&ET:2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*
M;7-G<W1R("),:6)R;R!D96=L:2!O<W!I=&DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDW"FUS9VED(")'=6EN96$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3`T"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-0IM
M<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L
M;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HQ-3<*;7-G
M:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,3`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*
M;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ-`IM<V=I9"`B2&5A9&5R(@IM
M<V=S='(@(DEN=&5S=&%Z:6]N92(*"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O
M=&%B;&5S970N<&AP.C8Q"FUS9VED(")(96%D97)S(@IM<V=S='(@(DEN=&5S
M=&%Z:6]N:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$P-PIM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")(96)R97<@
M*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(D%L=&5Z>F$B"@HC
M.B!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@T(&QI8B](;W)D92](96QP+G!H<#HQ
M.#8@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z,3<*(SH@=&5M<&QA=&5S+VAE
M;'`O:6YD97@N:6YC.C0*;7-G:60@(DAE;'`B"FUS9W-T<B`B06EU=&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS
M9VED(")(96QP('5S:6YG(&5D:71O<B(*;7-G<W1R(")!:75T;R!U<V%N9&\@
M;"=E9&ET;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,0IM<V=I9"`B
M2&5L<&5R(@IM<V=S='(@(D%I=71A;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@(D5M:7-F97)O(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B475E<W1O(.@@;"=I;FEZ:6\@9&5L
M(&9I;&4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S$*;7-G:60@(DAI9V@B"FUS9W-T<B`B06QT;R(*"B,Z('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T<B`B2&]?<F1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,PIM
M<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B
M4V%N=&$@4V5D92`H0VET=&$G(&1E;"!6871I8V%N;RDB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$U-#@*;7-G:60@(DAO;64B"FUS9W-T<B`B2&]R9&4B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(DEN9&ER:7IZ;R!D:2!C87-A(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$
M:7)E8W1O<GD@9&D@8V%S82(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(E1E;&5F
M;VYO(&1I(&-A<V$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-@IM
M<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HV-PIM<V=I9"`B2&]R9&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ
M,C4Q"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-3$R
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#@S"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q.3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3,S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*
M;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")296=O;&$@;W)I>GIO
M;G1A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T<B`B4FEE
M;7!I;65N=&\@;W)I>GIO;G1A;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G
M<W1R(")/<FEZ>F]N=&%L93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(D-O;64@<V5I
M(&%R<FEV871O('%U:3\@*%-E:2!P<F5G871O(&1I(&9A<F4@=6X@<F%P<&]R
M=&\A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT92!C;VQO;FYE('9U;VD@
M=6YI<F4_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G
M:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G
M<W1R(")1=6%N=&D@8V%M<&D@*&-O;&]N;F4I(&-I('-O;F\@/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*
M;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M(@IM<V=S='(@(E%U86YT92!R:6=H92!V=6]I('5N:7)E/R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#D*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(E5M:61I=.`B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X"FUS9VED(")(=6UI9&ET
M>3H@(@IM<V=S='(@(E5M:61I=.`Z("(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0IM<V=I9"`B
M2'5N9V%R>2(*;7-G<W1R(")5;F=H97)I82(*"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G-Q;"YP:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B0W)E87II;VYE(&1E;&QA(&-A<V5L;&$@24U!
M4"!F86QL:71A.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z
M,CDU(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B0V%N8V5L;&%Z:6]N92!D96QL82!C87-E;&QA($E-05`@9F%L;&ET
M83H@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(T,B!L:6(O
M2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(D-R96%Z:6]N92!D96QL82!Q=6]T82!D96QL82!C87-E;&QA($E-05`@
M9F%L;&ET83H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q-@IM<V=I
M9"`B25`@061D<F5S<R(*;7-G<W1R("));F1I<FEZ>F\@25`B"@HC.B!L:6(O
M2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("));F1I<FEZ>F\@25`@;F]N(&1I<W!O
M;FEB:6QE+B(*"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y"FUS
M9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+B(*;7-G<W1R("),)VEN9&ER:7IZ;R!)4"!N;VX@Z"!A;&PG:6YT97)N;R!D
M96P@8FQO8V-O($-)1%(@8V]N<V5N=&ET;RXB"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W
M($)E9F]R92(*;7-G<W1R("))7VYS97)I<V-I(&QA(%))9V$@<')I;6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*
M;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B27-L86YD82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B
M4V]L;R!)8V]N92(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B26-O;F4@
M<&5R("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,0IM<V=I9"`B
M26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEC;VYE(&-O;B!T97-T;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(DED96YT:71Y)W,@
M;F%M93HB"FUS9W-T<B`B3F]M92!D96QL)TED96YT:73@(@H*(SH@;&EB+TAO
M<F1E+TU)344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*(E-E(&YO;B#H('-T
M871O('9I<W5A;&EZ>F%T;R!C;W)R971T86UE;G1E+"`E<R!A<')I<F4@:6X@
M=6YA(&YU;W9A(&9I;F5S=')A+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS
M9W-T<B`B(@HB4V4@;F]N('9E9&D@;F5S<W5N82!I8V]N82!U<V%N9&\@26YT
M97)N970@17AP;&]R97(L('!O=')E<W1I(&1O=F5R("(*(G-E;&5Z:6]N87)E
M('%U97-T82!C87-E;&QA('!E<B!A;FYU;&QA<F4@;&$@=')A<W!A<F5N>F$@
M9&5L;&4@:6UM86=I;FD@4$Y'+B(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M
M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P
M;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*
M;7-G<W1R("(B"B)392!V961I('%U97-T;R!M97-S86=G:6\@;6$@;F]N(&PG
M:6UM86=I;F4L(&PG:6UA9VEN92!C:&4@=G5O:2!C87)I8V%R92!N;VX@(@HB
M<'7R(&5S<V5R92!V:7-U86QI>GIA=&$@9&%L('1U;R!B<F]W<V5R+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B4')E+59I
M<W5A;&EZ>F%Z:6]N92!D96QL)TEM;6%G:6YE.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM
M86=E(%523"(*;7-G<W1R(")54DP@26UM86=I;F4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*;7-G
M:60@(DEM86=E(%523#HB"FUS9W-T<B`B55),($EM;6%G:6YE.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM;6%G
M:6YE(&1A;&QA(&=A;&QE<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F
M<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DEM;6%G:6YE(&1A;&QA(&=A;&QE<FEA
M.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U
M<&QO860B"FUS9W-T<B`B0V%R:6-A;65N=&\@26UM86=I;F4B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEM
M;6%G:6YI(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-R!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4T"B,Z('1E;7!L871E<R]D871A+V1A
M=&5M87`N:6YC.C<@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B26UP
M;W)T82P@4&%S<V\@)60B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN
M8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B
M"FUS9W-T<B`B0V%M<&D@:6UP;W)T871I.B`E<R(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B0V%M<&D@:6UP;W)T871I.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R
M="!2;W<@069T97(B"FUS9W-T<B`B26Y?<V5R:7-C:2!R:6=A(&1O<&\B"@HC
M.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R
M<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B0V]D:6-E(&1I(&%Z
M:6]N92!E<G)A=&\@9&%T;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(").;VUE('5T96YT92!E+V\@<&%S<W=O<F0@
M;F]N(&-O<G)E='1O+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*
M(DYO;64@=71E;G1E(&\@:6YD:7)I>GIO(&%L=&5R;F%T:79O(&YO;B!V86QI
M9&\N(%)I<')O=F$@86YC;W)A(&\@8V]N=&%T=&$@(@HB;"=A;6UI;FES=')A
M=&]R92!S92!N96-E<W-I=&D@9&D@=6QT97)I;W)E(&%I=71O+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@
M(DEN8W)E87-E($EN9&5N="(*;7-G<W1R(")!=6UE;G1A(&QA(')I96YT<F%N
M>F$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,38*;7-G:60@(DEN9&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T
M"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(E5T96YT:2!);F1I
M=FED=6%L:2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*
M;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z:6]N92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%Z
M:6]N92!N;VX@<&GY(&1I<W!O;FEB:6QE+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS
M97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B26YS97)I<V-I($-?;VQO;FYA
M($1O<&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3<*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R
M("));G-E<FES8VD@26UM86=I;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS
M9W-T<B`B26YS97)I<V-I(%1A8F5L;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B($QI
M;FLB"FUS9W-T<B`B26YS97)I<V-I(&QI;FL@=V5B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED
M("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B26YS97)I<V-I(%]#
M;VQO;FYA(%!R:6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<FES8VD@
M=6YA(&YU;W9A(&-O;&]N;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("));G-E<FES8VD@=6YA(&YU;W9A(&-O;&]N;F$@
M<')I;6$@9&D@<75E;&QA(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E
M<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("))
M;G-E<FES8VD@=6YA(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("));G-E<FES8VD@=6YA(&YU;W9A(')I9V$@
M<')I;6$@9&D@<75E;&QA(&-O<G)E;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E
M<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M("));G-E<FES8VD@=6X@<&%R86=R869O(&1O<&\@:6P@;F]D;R!C;W)R96YT
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R:7-C:2!U;B!P87)A9W)A
M9F\@<')I;6$@9&5L(&YO9&\@8V]R<F5N=&4B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("));G-E<FES8VD@=6YA(&UA<V-H97)A(&%L=&5R;F%T:79A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,@IM<V=I9"`B26YS97)T(&%N
M(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H92!N
M97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*(DEN<V5R:7-C:2!U;B!I;F1I<FEZ
M>F\@96UA:6P@86P@<75A;&4@<&]T<F%I(')I8V5V97)E(&QA(&YU;W9A('!A
M<W-W;W)D.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S
M='(@(DEN<V5R:7-C:2!U;F$@8V5L;&$@9&]P;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN
M<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));G-E<FES8VD@=6YA(&-E;&QA
M('!R:6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G
M<W1R("));G-E<FES8VD@=6YA(&-O;&]N;F$@9&]P;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@
M(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@
M8V]L;VYN82!P<FEM82(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*;7-G
M:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("));G-E<FER92!M97-S86=G
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G
M<W1R("));G-E<FES8VD@=6X@<&%R86=R869O(&1O<&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G
M:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7-C
M:2!U;B!P87)A9W)A9F\@<')I;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W
M(&%F=&5R(@IM<V=S='(@(DEN<V5R:7-C:2!U;F$@<FEG82!D;W!O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B26YS97)I<V-I
M('5N82!R:6=A('!R:6UA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("));G-E<FES8VD@;&$@<FES<&]S
M=&$@<FEC:&EE<W1A(&%L;&$@9&]M86YD82!D:2!S:6-U<F5Z>F$Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I
M9"`B26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));G-E<FES8VDO34]D
M:69I8V$@;"=I;6UA9VEN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*
M;7-G<W1R("));G-E<FES8VDO34]D:69I8V$@:6P@;&EN:R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC
M:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N
M(@IM<V=S='(@(D-R961I=&D@:6YS=69F:6-I96YT:2!P97(@<W!E9&ER92!A
M;&QA(&QI<W1A(&1I(&1I<W1R:6)U>FEO;F4N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R
M961I="XB"FUS9W-T<B`B0W)E9&ET:2!I;G-U9F9I8VEE;G1I+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@
M(DEN=&5R;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3,S"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&$@:6YT97)A(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(E5$2"!N;VX@=F%L
M:61A("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E
M<W,O>FEP+G!H<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV
M86QI9"!:25`@9&%T82(*;7-G<W1R(")$871A(%I)4"!N;VX@=F%L:61A(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B07!P;&EC87II;VYE(&YO;B!V86QI9&$N
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G
M:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(D)A=&-H($E$(&YO;B!V
M86QI9&\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X-R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$U."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S,@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(Y.2!L:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE
M<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS
M9W-T<B`B:4PG:6YF;W)M87II;VYE('-O='1O;65S<V$@;F]N(.@@=F%L:61A
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS
M9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(DPG
M:6YD:7)I>GIO(&1I(&1D97-T:6YA>FEO;F4@;F]N(.@@=F%L:61O+B(*"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C$P.2!L:6(O2&]R9&4O0V]M
M<')E<W,O9&)X+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(DEL
M(&9O<FUA=&\@9&5L(&9I;&4@;F]N(.@@=F%L:61O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B3&$@8VAI879E(&1E;&QA(&QI8V5N>F$@;F]N(.@@
M=F%L:61A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DEL
M(&QO9V\@9F]R;FET;R!N;VX@Z"!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y
M<&4N(@IM<V=S='(@(FUS9U]T>7!E(&YO;B!V86QI9&\N(@H*(SH@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@(DEN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(F%P:5]I9"!N;VX@=F%L:61O
M(&\@;6%N8V%N=&4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S
M+B(*;7-G<W1R(")087)A;65T<F\@;F]N('9A;&ED;R!O(&UA;F-A;G1E+B(*
M"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI
M9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&5R;65S<V\@9&5L(&=E
M;FET;W)E(&YO;B!V86QI9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$V,0IM<V=I9"`B26YV86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R
M(")I9"!D96P@<&%R=&YE<B!N;VX@=F%L:61O+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C
M;V1E+B(*;7-G<W1R(")#;V1I8V4@<')O9&]T=&\@;F]N('9A;&ED;RXB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B
M26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B4')O=&]C;VQL;R!N;VX@=F%L
M:61O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,R!L
M:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*(SH@;&EB+TYE="]335,O=VEN
M7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C
M:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN871A<FEO(&YO;B!V86QI
M9&\Z(%PB)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`X,"!L:6(O
M2&]R9&4O2V]L86(N<&AP.C$R-C,*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J
M96-T(@IM<V=S='(@(D]G9V5T=&\@8V]N9&EV:7-O(&YO;B!V86QI9&\B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B
M26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B26YD:7)I>GIO('-O
M<F=E;G1E(&YO;B!V86QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS
M9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YT87)I;R(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R
M="!S96QE8W1I;VXB"FUS9W-T<B`B26YV97)T:2!L82!S96QE>FEO;F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X
M"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,PIM<V=I9"`B27)E;&%N9"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))
M<VQE(&]F($UA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$T"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C8*;7-G:60@(DES<W5E<B(*;7-G
M<W1R(")%;6ET=&5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C$*;7-G
M:60@(DET86QY(@IM<V=S='(@(DET86QI82(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,PIM<V=I9"`B2F%M86EC82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM
M<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")'96YN86EO(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U"FUS9VED(")*87!A
M;B(*;7-G<W1R(")':6%P<&]N92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DP"FUS9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,C0*;7-G:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R
M("),=6=L:6\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`W(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM
M<V=I9"`B2G5N92(*;7-G<W1R(")':75G;F\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T
M:69Y(@IM<V=S='(@(D=I=7-T:69I8V$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF
M>2!#96YT97(B"FUS9W-T<B`B1VEU<W1I9FEC82!A;"!C96YT<F\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(D=I=7-T:69I8V$@='5T
M=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(D=I=7-T
M:69I8V$@82!S:6YI<W1R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT
M(@IM<V=S='(@(D=I=7-T:69I8V$@82!D97-T<F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S8*;7-G:60@(DMA>F%K
M:'-T86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B
M36%N=&5N97)E(&PG;W)I9VEN86QE/R(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-@IM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B26P@<V5R=F5R($ME<F)E<F]S(&AA(')I9FEU=&%T;R!L)V%U=&5N=&EC
M87II;VYE+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B
M2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B0W)E
M87II;VYE(&-H:6%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(DEM<')O;G1A(&1I
M9VET86QE(&1E;&QA(&-H:6%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("),=6YG:&5Z>F$@
M9&5L;&$@8VAI879E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q
M"FUS9VED(")+97D@5'EP92(*;7-G<W1R(")4:7!O(&1E;&QA(&-H:6%V92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")+97D@
M57-A9V4B"FUS9W-T<B`B57-O(&1E;&QA(&-H:6%V92(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("),82!C:&EA=F4@
MZ"!G:>`@<')E<V5N=&4@<W5L(&ME>7-E<G9E<B!P=6)B;&EC;RXB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B
M0F%M:6)I;FDB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,CD*;7-G:60@(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,@IM<V=I
M9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,S"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H
M155#+4M2*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S0*;7-G:60@(DMU=V%I="(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,C<*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(D1I
M7W-P;W-I>FEO;F4B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S
M"FUS9VED("),86YG=6%G92(*;7-G<W1R("),:6YG=6%G9VEO(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,W"FUS9VED
M("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),87-T($AA;&8B
M"FUS9W-T<B`B56QT:6UO(&UE>GIO(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@X"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G<W1R(")5
M;'1I;6$@<&]S<VEB:6QI=.`@<&5R(&EL(&-A;6)I;R!D96QL82!P87-S=V]R
M9"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")5;'1I;6\@<75A
M<G1O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G:60@(DQA<W0@
M57!D871E9#HB"FUS9W-T<B`B56QT:6UO(&%G9VEO<FYA;65N=&\Z(@H*(SH@
M;&EB+TAO<F1E+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R;6%T"FUS9VED("),
M87-T(&QO9VEN.B`E<R(*;7-G<W1R(")5;'1I;6$@8V]N;F5S<VEO;F4Z("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(E5L=&EM82!C
M;VYN;F5S<VEO;F4Z("5S(&1A("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP
M.C<Q-`IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B56QT:6UA
M(&-O;FYE<W-I;VYE.B!-86DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#8*;7-G:60@(DQA='9I82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G
M<W1R("),96=G92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(D1I<W!O
M<VEZ:6]N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS
M9W-T<B`B3&%S8VEA;&\@=G5O=&\@<&5R(&%V97)L;R!S96YZ82!B;W)D:2(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M.`IM<V=I9"`B3&5B86YO;B(*;7-G<W1R("),:6)A;F\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*;7-G:60@
M(DQE9G0B"FUS9W-T<B`B4VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$P,0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B26YT97-T87II
M;VYE(&1I('-I;FES=')A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3<*
M;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R:2!D:2!S:6YI<W1R
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$T,PIM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DQE=F5L(@IM<V=S='(@(DQI
M=F5L;&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-#(*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,`IM<V=I9"`B3&EE
M8VAT96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")0:6]G9VEA(&QE9V=E
M<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG
M:'0@4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E
M<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT
M(%-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B0V]L;&5G
M86UE;G1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T
M<B`B26P@8V]L;&5G86UE;G1O('!U;G1A(&$Z(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@
M=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@HB
M0V]L;&5G82!L)VEN9&ER:7IZ;R!E;6%I;"!A;&QA('!A9VEN82!D:2!C;VUP
M;W-I>FEO;F4@<75A;F1O('9I96YE("(*(G9I<W5A;&EZ>F%T;R(*"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B
M3&EN:W,B"FUS9W-T<B`B0V]L;&5G86UE;G1I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0V"FUS9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@IM<V=I9"`B3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(D5L96YC;R`M(&PG=71E;G1E
M('!U\B!V961E<F4@;&4@8V%R=&5L;&4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3,T"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")%;&5N8V\@
M9&5I(&1A=&%B87-E(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*
M;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T<B`B16QE;F-O(&1E:2!S
M;V=G971T:2!D96QL)V%I=71O(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,PIM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B16QE;F-O(%1A8F5L;&4B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,#$*;7-G:60@(DQI
M<W0M07)C:&EV92(*;7-G<W1R(")!<F-H:79I;R!D96QL82!,:7-T82(*"B,Z
M(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES="U(
M96QP(@IM<V=S='(@(D%I=71O(&1E;&QA($QI<W1A(@H*(SH@;&EB+TAO<F1E
M+TU)344O2&5A9&5R<RYP:'`Z-C`S"FUS9VED("),:7-T+4ED(@IM<V=S='(@
M(DED96YT:69I8V%T:79O(&1E;&QA($QI<W1A(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DY"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@
M(E!R;W!R:65T87)I;R!D96QL82!L:7-T82(*"B,Z(&QI8B](;W)D92]-24U%
M+TAE861E<G,N<&AP.C8P,`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y.`IM<V=I9"`B3&ES
M="U3=6)S8W)I8F4B"FUS9W-T<B`B27-C<FEZ:6]N92!A;&QA($QI<W1A(@H*
M(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DW"FUS9VED("),:7-T
M+55N<W5B<V-R:6)E(@IM<V=S='(@(D%N;G5L;&$@;"=I<V-R:7II;VYE(&%L
M;&$@3&ES=&$B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S
M='(@(DPG96QE;F-O(&1E;&QE('-E<W-I;VYE(.@@9F%L;&ET;SH@)7,B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S='(@(DPG96QE;F-O(&1E
M9VQI('5T96YT:2#H(&9A;&QI=&\Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R("),)V5L96YC;R!D96=L:2!U=&5N=&D@Z"!D:7-A
M8FEL:71A=&\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED
M("),:71E<F%T=7)E(@IM<V=S='(@(DQE='1E<F%T=7)A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30T"FUS9VED("),
M:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B0V%R
M:6-A;65N=&\N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C`P"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B3W)A(&QO8V%L93H@
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@
M86YD(%1I;64B"FUS9W-T<B`B3&EN9W5A(&4@3W)A(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW,B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R("),=6]G;R(*
M"B,Z(&QO9VEN+G!H<#HQ.#D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C(P-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDP"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,34*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")%;G1R82(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I
M;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3DX"FUS9VED("),;V<@;W5T(@IM<V=S='(@(D5S
M8VDB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO9VEN
M(@IM<V=S='(@(D5N=')A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q
M,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B3W!E<F%Z:6]N:2!D:2!!
M8V-E<W-O(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDY-0IM<V=I9"`B3&]G
M:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W
M87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB3"=A8V-E<W-O
M(.@@9F%L;&ET;R!P97)C:.@@:6P@;F]M92!U=&5N=&4@;R!L82!P87-S=V]R
M9"!I;G-E<FET:2!N;VX@<V]N;R`B"B)C;W)R971T:2XB"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S='(@
M(D%C8V5S<V\@9F%L;&ET;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V
M-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E1E<W1O(&QU;F=O(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@
M(D%M;W)E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-CD*;7-G:60@(DQO=R(*;7-G<W1R(")"87-S;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G
M:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B3&5T=&5R92!G<F5C
M:&4@;6EN=7-C;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T
M=&5R<R(*;7-G<W1R("),971T97)E(&QA=&EN92!M:6YU<V-O;&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DYU;65R
M:2!R;VUA;FD@;6EN=7-C;VQI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(DQU<W-E;6)U<F=O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P,2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#,Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@S"FUS9VED
M(")-3U1$(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+B(*;7-G<W1R(")-4RU43D5&(&PG86QL96=A=&\@;F]N(&-O
M;G1I96YE(&EN9F]R;6%Z:6]N:2XB"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-3<*;7-G:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,PIM<V=I9"`B36%C961O
M;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U,0IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VEC
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I
M;"(*;7-G<W1R(")0;W-T82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,C0*;7-G:60@(DUA:6P@061M:6XB"FUS9W-T<B`B26YD:7)I>GIO(&%M
M;6EN:7-T<F%T;W)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM
M<V=S='(@(D-R96$@8V]L;&5G86UE;E]T;RXN+B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-0IM<V=I9"`B36%L87=I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T"FUS
M9VED(")-86QD:79E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30*;7-G:60@(DUA;&DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38R"FUS9VED(")-86QT82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM
M<V=S='(@(B(*(D=E<W1I<V-I(&PG96QE;F-O(&1E;&QE(&-A=&5G;W)I92!E
M=&EC:&5T=&%N9&\@9VQI(&%R=&EC;VQI+"!E(&-O;B!I(&-O;&]R:2`B"B)A
M<W-O8VEA=&D@86QL92!C871E9V]R:64N(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`X-PHC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W
M,0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B36%R>F\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Q"FUS9VED(")-
M87)G:6XB"FUS9W-T<B`B36%R9VEN92(*"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP
M:'`Z-#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R(")#;VYT<F%S<V5G;F%R92!C;VX@:2!F;&%G<R!6:7-T;R].;VY6:7-T
M;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*;7-G:60@(DUA<FL@=VET
M:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S
M='(@(D-O;G1R87-S96=N87)E(&-O;B!A;'1R:2!F;&%G<R`H97,Z($EM<&]R
M=&%N=&4O4FES<&]S=&\I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,34R"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U.0IM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@
M9FEE;&1S(@IM<V=S='(@(D-A;7!I(&-O<G)I<W!O;F1E;G1I(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38P"FUS9VED
M(")-875R:71A;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,PIM<V=I9"`B36%U<FET:75S(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(D-R961I
M=&\@;6%S<VEM;R!P97)M97-S;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N(@IM<V=S='(@(D5C8V5D=71E(&QA('!A<G1I(&UA<W-I;64@9&5L
M(&UE<W-A9V=I;RXB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,PIM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(E1E;7!O(&UA
M<W-I;6\@=6QT:6UE(#(T(&]R93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS,#4*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@
M(E1E;7!O(&UA<W-I;6\@=6QT:6UE(#8@;W)E.B`B"@HC.B!L:6(O87!I+G!H
M<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*
M;7-G<W1R(").=6UE<F\@;6%S<VEM;R!D96P@4&]R=&$@0FQO8VMS(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q
M-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG
M=&@B"FUS9W-T<B`B3'5N9VAE>GIA(&UA<W-I;6$B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(DUA9V=I
M;R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-3,*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I
M8VEN82(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365M8G)I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")5;FES8VD@;&4@
M8V5L;&4B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U
M"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE<W-A9V=I;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E
M<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC
M871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB26P@
M;65S<V%G:6\@Z"!S=&%T;R!V97)I9FEC871O(&-O<G)E='1A;65N=&4L(&UA
M(&EL(&9I<FUA=&%R:6\@9&5L("(*(F-E<G1I9FEC871O(&YO;B!P=?(@97-S
M97)E('9E<FEF:6-A=&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B
M365S<V%G9VEO('-C861U=&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-C`*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.2!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"FUS9VED(")-97-S
M86=E('1Y<&4B"FUS9W-T<B`B5&EP;R!M97-S86=G:6\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B
M;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T
M<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3,*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO
M9"(*;7-G<W1R(")-971O9&\B"@HC.B!L:6(O2&]R9&4O4E!#+W-O87`N<&AP
M.C$Q-R!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R
M("));"!M971O9&\@(%PB)7-<(B!N;VX@Z"!D969I;FET;R(*"B,Z(&QI8B](
M;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T
M:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R(")-
M971O9&\@;F]N(&1E9FEN:71O+B!-971O9&\@8VAI86UA=&$Z("5S(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HX,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C<*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:6-A(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V"FUS
M9VED(")-97AI8V\B"FUS9W-T<B`B365S<VEC;R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@U"FUS9VED(")-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(DUE>GIO(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")496UP;R!M:6YI;6\@=6QT:6UE
M(#(T(&]R93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@
M(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!O(&UI;FEM
M;R!U;'1I;64@-B!O<F4Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@
M97AP:7)E9"(*;7-G<W1R("));"!T96UP;R!D:2!D=7)A=&$@;6EN:6UO(&1E
M;&QA('!A<W=O<F0@;F]N(.@@<V-A9'5T;R(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")3<&5C8VAI;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I
M9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")687)I;R(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-S(*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+B(*;7-G<W1R("));"!P86-C:&5T=&\@4$5!4B!(5%107U)E<75E<W0@Z"!M
M86YC86YT92XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$T"FUS9VED
M("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R
M871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L:6-A
M=&EO;BXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A>FEO;F4@;6%N8V%N=&4N($1E
M=FD@9V5N97)A<FYE('5N82!N=6]V82!S92!V=6]I('5S87)E('%U97-T82`B
M"B)A<'!L:6-A>FEO;F4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T
M<B`B240@9&5L(&UE<W-A9V=I;R!M86YC86YT92XB"@HC.B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("));"!P86-C:&5T
M=&\@4$5!4B!-86EL(')I8VAI97-T;R#H(&UA;F-A;G1E+B(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG
M('-E<W-I;VX@240N(@IM<V=S='(@(DE$(&1E;&QA('-E<W-I;VYE(&UA;F-A
M;G1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DQU(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)A=&\B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HV-B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HX-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,PIM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R(")$871A(&1E;&QA
M(&UO9&EF:6-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@
M(DUO9&EF:6-A(%523"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C<T"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9'5L;R(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,`IM<V=I9"`B
M36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Y"FUS9VED(")-;VYA
M8V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X-`IM<V=I9"`B36]N=&@@86YD('EE
M87(B"FUS9W-T<B`B365S92!E(&%N;F\B"@HC.B!L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(DUE;G-I;&UE
M;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38Q"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B
M36]O;B!0:&%S97,B"FUS9W-T<B`B1F%S:2!L=6YA<FDB"@HC.B!L:6(O1FEL
M92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"B)3;VYO('-T871I('1R;W9A
M=&D@<&GY(&-A;7!I(&YE;&QA(&QI;F5A("5D(')I<W!E='1O(&$@<75E;&QI
M(&EP<F5V:7-T:2`E9"XB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#@*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G
M:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V
M92!$;W=N(@IM<V=S='(@(E-P;W-T82!3;W1T;R(*"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B
M"FUS9W-T<B`B4W!O<W1A(&$@4VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*
M;7-G<W1R(")3<&]S=&$@82!$97-T<F$B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M(")3<&]S=&$@4V]P<F$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4W!O<W1A
M('-O='1O(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4R-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(E-P;W-T82!S;W!R82(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V.`IM<V=I9"`B
M36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C$X-`IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO
M;B(*;7-G<W1R(")396QE>FEO;F4@;75L=&EP;&$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@
M(DUI;R!!8V-O=6YT(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(X"FUS
M9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%Z
M:6]N:2!D96P@36EO($%C8V]U;G0B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C0T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B36EO(%!O<G1A
M;&4B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*;7-G:60@(DUY
M(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B1&ES<&]S:7II;VYE(&1E;"!-:6\@
M4&]R=&%L92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B
M3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(DY/+"!N;VX@<V]N;R!D)V%C
M8V]R9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S='(@(DYO
M;64B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-CD*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X"FUS9VED(").875R
M=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-0IM<V=I
M9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,*;7-G:60@(DYE=&AE<FQA;F1S
M($%N=&EL;&5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HU.#4*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@S"FUS9VED(").
M971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@X"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Q
M"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`B4F5T92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE=F5R(@IM<V=S='(@(DUA:2(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,`IM
M<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G
M;W)Y(@IM<V=S='(@(DYU;W9A($-A=&5G;W)I82(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B3'5N82!.=6]V
M82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G
M:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYU;W9O($YO
M;64@571E;G1E("AO<'II;VYA;&4I(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P"FUS9VED(").97<@6F5A;&%N9"(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*
M;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(").=6]V82!P87-S=V]R9"(*
M"B,Z(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B3&$@;G5O=F$@<&%S<W=O<F0@<V-A9'+@(&EN("5X+B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D
M<R!D;VXG="!M871C:"XB"FUS9W-T<B`B3&$@;G5O=F$@<&%S<W=O<F0@;F]N
M(&-O<G)I<W!O;F1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS
M9W-T<B`B3G5O=F$@9FEN:7-T<F$@*%]V=6]T82DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3(@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y,0IM<V=I9"`B3F5W<R(*;7-G<W1R
M(").;W1I>FEE(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-PIM
M<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P<&D@9&D@3F]T:7II92(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3(Y"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0Q('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U"FUS9VED(").
M97AT(@IM<V=S='(@(E!R;W-S:6UO(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(E!R;W-S:6UE(#0@
M1F%S:2(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8V(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T
M<B`B4')O<W-I;64@;W!Z:6]N:2(*"B,Z(&QI8B](;W)D92]522]086=E<BYP
M:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R(")0<F]S<VEM;SXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S0*;7-G
M:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S$*;7-G:60@(DYI9V5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W,PIM<V=I9"`B3FEG97)I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Y"FUS9VED(").:6=H="(*;7-G<W1R
M(").;W1T92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W.0IM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*
M;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*(DYO;B!S;VYO(&1I<W!O
M;FEB:6QI(&EN9F]R;6%Z:6]N:2!R:6=U87)D;R!L82!C;VYF:6=U<F%Z:6]N
M92!P97(@;6]S=')A<F4@;&4@(@HB9&EF9F5R96YZ92XB"@HC.B!L:6(O5D93
M+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E
M9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R(").;VX@Z"!D:7-P
M;VYI8FEL92!U;F$@<W1R871E9VEA('!E<B!C<F5A<F4@:6UM86=I;FD@25-/
M+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS
M9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,#$*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HS.#4*(SH@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT,#<*;7-G:60@(DYO(&)L;V-K(&5X
M:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(DYO;B!E
M<VES=&4@=6X@8FQO8V-O(&%L;&$@<&]S:7II;VYE(')I8VAI97-T82(*"B,Z
M(&QI8B](;W)D92]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(").;VX@Z"!S=&%T;R!F;W)N:71O(&EL(&YO;64@9&5L(&-A;&5N9&%R
M:6\@<&5R(&PG875T96YT:6-A>FEO;F4@34-!3"XB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(").97-S
M=6YA(&UO9&EF:6-A+B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V
M"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M
M:7-S:6]N+B(*;7-G<W1R(").97-S=6X@9FEG;&EO('!U\B!E<W-E<F4@86=G
M:75N=&\@82!Q=65S=&\@<&5R;65S<V\N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-S@@;&EB+TAO<F1E+G!H<#HU,3<@;&EB+TAO<F1E+U5T:6PN<&AP.C<X,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(B(*(DYO;B#H('-T871A
M('-P96-I9FEC871A(&%L8W5N82!I;F9O<FUA>FEO;F4@<W5L;&$@8V]N9FEG
M=7)A>FEO;F4@<&5R("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C@*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!&5%`@5D93+B(*;7-G<W1R("(B"B).;VX@Z"!S=&%T82!S<&5C:69I8V%T
M82!A;&-U;F$@:6YF;W)M87II;VYE('-U;&QA(&-O;F9I9W5R87II;VYE('!E
M<B!&5%`@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HV.#0*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("(B"B).;VX@Z"!S=&%T82!S<&5C:69I8V%T82!A;&-U
M;F$@:6YF;W)M87II;VYE('-U;&QA(&-O;F9I9W5R87II;VYE('!E<B!344P@
M5D93+B(*"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<U,PIM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RXB"FUS9W-T<B`B(@HB3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@
M86QC=6YA(&EN9F]R;6%Z:6]N92!S=6QL82!C;VYF:6=U<F%Z:6]N92!P97(@
M4U%,+2(*(D9I;&4@5D93+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
M3F]N(.@@<FEM87-T;R!N97-S=6X@8W)E9&ET;RXB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!D
M97-T:6YA>FEO;F4N(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDQ.`IM
M<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("));"!F:6QE(&YO;B#H
M('-T871O(&-A<FEC871O(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C<Q
M"FUS9VED(").;R!I8V]N<R!F;W5N9"XB"FUS9W-T<B`B3F]N('-O;F\@<W1A
M=&4@=')O=F%T92!L92!I8V]N92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$S,"!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Q-@IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T
M+B(*;7-G<W1R(").;VX@Z"!S=&%T;R!I;7!O<W1A=&\@;&$@<&]S:7II;VYE
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@
M(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").;VX@Z"!S=&%T;R!I
M;F1I8V%T;R!L82!P;W-I>FEO;F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB
M"FUS9W-T<B`B3F]N(.@@<W1A=&\@9F]R;FET;R!I;"!M97-S86=G:6\N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B
M3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYO;B#H('-T871O('-P96-I
M9FEC871O(&EL(&YO;64N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3F]N(.@@<W1A=&\@<W!E8VEF:6-A=&\@:6P@;G5M97)O+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+VAT='`N<&AP
M.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F]N(.@@<W1A=&$@9F]R;FET82!L82!P
M87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!(5%10+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H
M('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO
M;F4@24U!4"XB"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R(").;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W
M;W)D('!E<B!L)V%U=&5N=&EC87II;VYE($ME<F)E<F]S+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQO9VEN+G!H<#HX-"!L:6(O2&]R9&4O075T:"]P86TN<&AP
M.C<U"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C<W"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYO;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG
M875T96YT:6-A>FEO;F4@3&]G:6XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S
M<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYO;B#H('-T871A(&9O
M<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@4$%34U=$
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DYO;B#H('-T871A(&9O<FYI=&$@;&$@<&%S<W=O<F0@<&5R(&PG875T
M96YT:6-A>FEO;F4@4TU"+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@HB3F]N
M(.@@9&ES<&]N:6)I;&4@86QC=6YA('!A=&-H('!E<B!L82!V97)S:6]N92!B
M:6YA<FEA(&1I($]P96Y34TPN($QA("(*(G9E<G-I;VYE(&)I;F%R:6$@9&D@
M3W!E;E-33"#H(&YE8V5S<V%R:6\@8VAE(&]P97)I(&-O;B!L92!I;F9O<FUA
M>FEO;FD@4$M#4R`B"B(Q,BXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A
M<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]61E,N<&AP.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T
M+B(*;7-G<W1R(").;VX@Z"!S=&%T82!I;7!O<W1A=&$@;&$@<75O=&$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B3F5S<W5N82!R96=O;&$B
M"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R
M('-P96-I9FEE9"XB"FUS9W-T<B`B3F]N(.@@<W1A=&\@<W!E8VEF:6-A=&\@
M:6P@<V5P87)A=&]R92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E<R(*;7-G<W1R
M(").97-S=6YA(&QA=&\B"@HC.B!L:6(O5D93+W-M8BYP:'`Z-C`P"FUS9VED
M(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B3F5S<W5N('1I<&\@9&D@9FEL92(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@(DYO
M('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS
M9W-T<B`B3F]N(.@@9&ES<&]N:6)I;&4@=6YA(&1I<F5C=&]R>2!T96UP;W)A
M;F5A('!E<B!L82!C86-H92XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Q(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G
M:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R
M(").;VX@Z"!S=&%T82!I;G9I871O(&EL(&YO;64@=71E;G1E(&4O;R!P87-S
M=V]R9"XB"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED
M(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").;VX@<V]N
M;R!R:71O<FYA=&4@:6YF;W)M87II;VYI(%A-3"!V86QI9&4B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<T(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.#0*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@
M(DYE<W-U;B!V86QO<F4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$Y
M"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
M3F]N(.@@<W1A=&$@=')O=F%T82!L82!V97)S:6]N92!N96QL82!C;VYF:6=U
M<F%Z:6]N92!O<FEG:6YA;&4N(%)I9V5N97)A(&QA("(*(F-O;F9I9W5R87II
M;VYE+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DYO;B#H('-T871A('1R
M;W9A=&$@;&$@=F5R<VEO;F4@;F5L;&$@='5A(&-O;F9I9W5R87II;VYE+B!2
M:6=E;F5R82!L82`B"B)C;VYF:6=U<F%Z:6]N92XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,C<@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L
M96-T+FEN8SHY,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0U"FUS9VED(").;VYE(@IM<V=S='(@(DYE<W-U;F\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP
M"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(DYE<W-U;F\@
M+W5S;R!I;7!L:6-I=&\I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*
M;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,@IM<V=I
M9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE
M<FX@2&5M:7-P:&5R92(*;7-G<W1R(")%;6ES9F5R;R!3971T96YT<FEO;F%L
M92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U.`IM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W-@IM<V=I9"`B3F]R=V%Y(@IM<V=S='(@(DYO<G9E9VEA(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#$*;7-G:60@(DYO="!!9G1E<B(*
M;7-G<W1R(").;VX@1&]P;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(DYO;B!0<FEM82(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-#(Q"FUS9VED(").;W0@82!D:7)E8W1O
M<GDB"FUS9W-T<B`B3F]N('5N82!D:7)E8W1O<GDB"@HC.B!L:6(O5D93+TE3
M3U=R:71E<BYP:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+G!H<#HU.0HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2YP:'`Z.34*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS
M9W-T<B`B3F]N(&EM<&QE;65N=&%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T
M<B`B3F]N(&EM<&]S=&%T;R(*"B,Z(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93
M+G!H<#HR,#@@;&EB+U9&4RYP:'`Z,C,T(&QI8B]61E,N<&AP.C(U,@HC.B!L
M:6(O5D93+G!H<#HR-CD@;&EB+U9&4RYP:'`Z,C@U(&QI8B]61E,N<&AP.C,P
M,2!L:6(O5D93+G!H<#HS,38*(SH@;&EB+U9&4RYP:'`Z,S,S(&QI8B]61E,N
M<&AP.C,V-B!L:6(O5D93+G!H<#HT,C8@;&EB+U9&4RYP:'`Z-3`U"B,Z(&QI
M8B]61E,N<&AP.C4W-"!L:6(O5D93+G!H<#HU.3$@;&EB+U9&4RYP:'`Z-C8Y
M"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,30U(&QI8B](;W)D
M92]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&QI8B](;W)D92]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<U(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z
M,3@Y"B,Z(&QI8B](;W)D92]397-S:6]N2&%N9&QE<BYP:'`Z,C,V"FUS9VED
M(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R(").;VX@<W5P<&]R=&%T;RXB"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP."!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T-`HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`U
M."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").;W1E<R(*
M;7-G<W1R(")!<'!U;G1I(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N
M<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS
M9W-T<B`B3G5L;&$@9&$@=FES=6%L:7IZ87)E+"!T;W)N82!I;F1I971R;RXB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V
M96UB97(B"FUS9W-T<B`B3F]V96UB<F4B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(DYU;65R;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C
M=&5R<R(*;7-G<W1R(").=6UE<F\@9&D@8V%R871T97)I(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S-CD@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C,@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(DYU;65R;R!D:2!C;VQO;FYE(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$S-C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C$@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@
M(DYU;65R;R!D:2!R:6=H92(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*(DD@
M;G5M97)I(&YO;B!S;VYO('-T871I('-P96-I9FEC871I('!E<B!L)V%G9VEO
M<FYA;65N=&\@;F5L;&$@;&ES=&$@9&D@(@HB9&ES=')I8G5Z:6]N92XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G
M:60@(D]+(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R(")/9V=E='1O
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B
M:F5C="!#<F5A=&]R(@IM<V=S='(@(D-R96%T;W)E(&1E;&PG3V=G971T;R(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G
M<W1R(")/='1A;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/='1O8G)E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED
M(")/9F9I8V4B"FUS9W-T<B`B569F:6-I;R(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S
M(&UU<W0@8F4@9&EF9F5R96YT+B(*;7-G<W1R("),92!P87-S=V]R9"!V96-C
M:&EE(&4@;G5O=F4@9&5V;VYO(&5S<V5R92!D:69F97)E;G1I(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@<&%S<W=O
M<F0B"FUS9W-T<B`B5F5C8VAI82!P87-S=V]R9"(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO
M="!C;W)R96-T+B(*;7-G<W1R("),82!V96-C:&EA('!A<W-W;W)D(&YO;B#H
M(&-O<G)E='1A+B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,0IM<V=I9"`B3VUA;B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E-O
M;&\@:2!S97)V97(@24U!4"!S=7!P;W)T86YO(&QE(&-A<G1E;&QE(&-O;F1I
M=FES92XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N
M;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#4Q(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<Q"FUS9VED
M(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S='(@(D4G
M('!E<FUE<W-O('-O;&\@=6X@:6YD:7)I>GIO(&5M86EL+B(*"B,Z('-E<G9I
M8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N
M97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H
M:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T
M<B`B(@HB4V]L;R!I;"!P<F]P<FEE=&%R:6\@;R!L)V%M;6EN:7-T<F%T;W)E
M(&1I('-I<W1E;6$@<'7R(&-A;6)I87)E(&QA('!R;W!R:65TX"`B"B)O(&D@
M<&5R;65S<VD@9&5L('!R;W!R:65T87)I;R!P97(@=6YA(&-O;F1I=FES:6]N
M92(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R
M(")!<')E(&EN('5N82!N=6]V82!F:6YI<W1R82(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L
M9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*
M;7-G<W1R("(B"B)%<G)O<F4@3W!E;E-33#H@;F]N('-I('!O<W-O;F\@97-T
M<F%R<F4@;&4@:6YF;W)M87II;VYI(&1A;&QA('!A<G1E(&9I<FUA=&$@(@HB
M4R]-24U%+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")!<')E('%U97-T;R!C;VQL96=A;65N=&\@
M:6X@=6YA(&YU;W9A(&9I;F5S=')A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(E-I<W1E
M;6$@3W!E<F%T:79O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$U-0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<'II;VYI(@H*(SH@<V5R
M=FEC97,O<')E9G,N<&AP.C,Q('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@
M(D]P>FEO;FD@<&5R("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@
M(D5L96YC;R!O<F1I;F%T;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-38X"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI>GIA
M>FEO;F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I
M9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R(")5;FETX"!/<F=A;FEZ
M>F%T:79A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S-`IM<V=I
M9"`B3W)G86YI>FEN9R(*;7-G<W1R(")!9V5N9&$B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$S-0IM<V=I9"`B3W)I9VEN86P@87!P;&EC871I;VX@=&5M
M<&QA=&4B"FUS9W-T<B`B36%S8VAE<F$@;W)I9VEN86QE(&1E;&PG87!L:6-A
M>FEO;F4B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@
M(DUA<V-H97)A(&]R:6=I;F%L92!I;B`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED
M(")/=&AE<B(*;7-G<W1R(")!;'1R;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D%L
M=')E($EN9F]R;6%Z:6]N92(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUE
M<W-I(&1E;"!P<F]P<FEE=&%R:6\B"@HC.B!L:6(O2&]R9&4O075T:"]P86TN
M<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B3"=A=71E;G1I8V%Z:6]N92!004T@;F]N(.@@9&ES
M<&]N:6)I;&4N(@H*(SH@;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<#HQ
M,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A
M;"!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(DEN9F]R;6%Z:6]N92!#:69R871A(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@
M(D-H:6%V92!0=6)B;&EC82!01U`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM
M<V=S='(@(DEN9F]R;6%Z:6]N92!&:7)M871A+T-I9G)A=&$@4$=0(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C8Y"FUS9VED(")02%`@0V]D92(*;7-G<W1R
M(")#;V1I8V4@4$A0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED
M(")02%`@4VAE;&PB"FUS9W-T<B`B4VAE;&P@4$A0(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-($QI9VAT
M(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@
M(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*
M;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4$T@4W5N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0T"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E;G-I
M;VX@:7,@;6ES<VEN9R(*;7-G<W1R(")%<W1E;G-I;VYE(%!/4TE8(&UA;F-A
M;G1E(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B4FEE;7!I
M;65N=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ.#<*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.30*;7-G:60@
M(E!A;&%U(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3(*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I
M=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R"FUS9VED(")086YA;6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3@U"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.34*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(E!A<GII86QM96YT92!.=79O;&]S;R(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!L:6(O3F5T+U--4R]W:6Y?:'1T
M<"YP:'`Z,34Q(&QI8B](;W)D92]&;W)M+G!H<#HR,#$X"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS
M9VED(")087-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S
M<V9U;&QY+B(*;7-G<W1R(")087-S=V]R9"!C86UB:6%T82!C;VX@<W5C8V5S
M<V\N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED
M(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S<V]W<F0@;F]N(&-O
M<G)E='1A(@H*(SH@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(D4G(')I8VAI97-T82!L82!P87-S=V]R9"!P97(@;"=A
M=71E;G1I8V%Z:6]N92!2041)55,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S
M='(@(E!A<W-W;W)D(&-O;B!C;VYF97)M82(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S
M=V]R9#H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS
M9W-T<B`B3&4@<&%S<W=O<F0@9&5V;VYO(&-O<G)I<W!O;F1E<F4N(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,"!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S
M='(@(DEN8V]L;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G
M<W1R("));F-O;&QA(&1A;&QA(&-L:7!B;V%R9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`B4&5R8V]R<V\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G<W1R
M(")097)S;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4&5R8V5N='5A
M;&4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(D5S96=U:2!L92!/<&5R87II;VYI(&1I($UA;G5T96YZ:6]N92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B17-E
M9W5I<F4@;&4@;W!E<F%Z:6]N:2!D:2!M86YT=71E;GII;VYE(&%L;"=A8V-E
M<W-O/R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(")0
M97)M:7-S:6]N(@IM<V=S='(@(E!E<FUE<W-O(@H*(SH@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B4&5R;65S<V\@7"(E<UPB
M(&YO;B!C86YC96QL871O+B(*"B,Z(&QI8B]61E,O<VUB+G!H<#HV,#,*;7-G
M:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(E!E<FUE<W-O($YE9V%T
M;R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,38Q(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")0
M97)M97-S:2(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,"!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C4X"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D=E<W1I;VYE(%!E<FUE<W-I
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA
M;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA>FEO;FD@4&5R<V]N86QI
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@S"FUS9VED(")097)U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#`*;7-G:60@(E!H
M;W1O<R(*;7-G<W1R(")&;W1O9W)A9FEE(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,`IM<V=I9"`B4&ET8V%I<FXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL
M(@IM<V=S='(@(E-I('!R96=A(&1I(&-L:6-C87)E(&EN(&%L8W5N92!C96QL
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")3:2!P<F5G82!D
M:2!C;VYF97)M87)E(&-H92!S:2!V=6]L92!R:6UU;W9E<F4@<75E<W1O(&5L
M96UE;G1O.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")3:2!P
M<F5G82!D:2!C;VYF97)M87)E(&-H92!S:2!V=6]L92!S8V]L;&5G87)E('%U
M97-T;R!E;&5M96YT;SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4V,@IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB"FUS9W-T
M<B`B4VD@<')E9V$@9&D@:6YS97)I<F4@=6X@;65S92!E('5N(&%N;F\N(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(E-I('!R96=A(&1I(&EN<V5R:7)E('5N(&YO;64@<&5R
M(&QA(&YU;W9A(&=A=&5G;W)I83HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB
M"FUS9W-T<B`B4VD@<')E9V$@9&D@:6YS97)I<F4@=6X@:6YD:7)I>GIO($E0
M('9A;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8T,`IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@HB4VD@<')E9V$@9&D@
M:6YS97)I<F4@=6YA(&1A=&$@=F%L:61A+"!C;VYT<F]L;&$@:6P@;G5M97)O
M(&1I(&=I;W)N:2!N96P@;65S92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C0T-PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T
M<B`B4VD@<')E9V$@9&D@:6YS97)I<F4@=6XG;W)A('9A;&ED82XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(E-I
M('!R96=A(&1I(&9O<FYI<F4@=6X@<FEA<W-U;G1O(&1E;"!P<F]B;&5M82XB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@
M=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E-I('!R96=A(&1I(&9O
M<FYI<F4@:6P@<')O<')I;R!N;VUE('5T96YT92!E('!A<W-W;W)D(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"B)3
M:2!P<F5G82!D:2!L96=G97)E(&EL('-E9W5E;G1E('1E<W1O+B!$159)(&5S
M<V5R92!D)V%C8V]R9&\@8V]N(&D@=&5R;6EN:2`B"B)D)W5S;R!D96P@<VES
M=&5M82XB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE
M.B(*;7-G<W1R(")3:2!P<F5G82!D:2!S8W)I=F5R92!I;&YO;64@9&5L;&$@
M;G5O=F$@8V%T96=O<FEA.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#$*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X.`IM<V=I9"`B4&]L86YD(@IM<V=S='(@(E!O
M;&]N:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@(E!O
M;&ET:6-S(@IM<V=S='(@(E!O;&ET:6-A(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0X.0IM<V=I9"`B4&]L;',B"FUS9W-T<B`B4V-R=71I;FEO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,PIM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R=&]G86QL;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-`IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G
M<W1R(")0;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@:6UM86=I;F4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R(")0;W-I>FEO
M;F%M96YT;R!D:2!Q=65S=&$@=&%B96QL82(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*2(*;7-G<W1R(")0;W-T87)E(&$@<75E<W1A(&-A<G1E
M;&QA("AN;VX@87!P;&EC871O(&1A($E-05`I(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B`B"FUS9W-T<B`B4')E8VEP:71A>FEO;F4@<&5R(&PG=6QT:6UA("5S(&]R
M82AE*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#<*;7-G
M:60@(E!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!R969S7VQD87`Z($5S=&5N<VEO;F4@3$1!4"!R:6-H:65S=&$@;F]N('1R
M;W9A=&$N(@H*(SH@;&EB+TAO<F1E+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS
M9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7W-E<W-I;VXZ(&5S=&5N<VEO
M;F4@9&5L;&$@<V5S<VEO;F4@<FEC:&EE<W1A(&YO;B!T<F]V871A+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")0<F5S<W5R92(*;7-G
M<W1R(")0<F5S<VEO;F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM
M<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B4')E<W-I
M;VYE(&%L(&QI=F5L;&\@9&5L(&UA<F4Z("(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B
M4')E<W-I;VYE.B`B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C`S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,`IM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")!
M;G1E<')I;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C$*;7-G:60@(E!R979I97<@=&AE(&EM86=E
M(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")!;G1E<')I;6$@9&5L;"=I;6UA
M9VEN92!I;B!U;F$@;G5O=F$@9FEN97-T<F$B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V,`IM<V=I
M9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")/<'II;VYI('!R96-D96YT
M:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(E-T86UP82!D;V-U
M;65N=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@
M(E!R:79A=&4@2V5Y(@IM<V=S='(@(D-H:6%V92!0<FEV871A(@H*(SH@;&EB
M+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(")0
M<F]B;&5M82(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")$97-C<FEZ:6]N92!D96P@
M<')O8FQE;6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS
M9VED(")0<F]J96-T<R(*;7-G<W1R(")0<F]G971T:2(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,3$Q(&QI8B](;W)D92]&;W)M+G!H<#HR,3@X(&QI8B](
M;W)D92]&;W)M+G!H<#HS,C<V"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U
M8FQI8R!+97DB"FUS9W-T<B`B0VAI879E(%!U8F)L:6-A(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@(E!U8FQI8R!+97D@06QG
M;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M;R!D96QL82!#:&EA=F4@4'5B8FQI
M8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B
M4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(DEN9F]R;6%Z:6]N:2!S=6QL82!#
M:&EA=F4@4'5B8FQI8V$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR
M-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(DQA(&-O<'!I82!C:&EA=F4@4'5B
M8FQI8V$O4')I=F%T82!N;VX@Z"!S=&%T82!G96YE<F%T82!C;VX@<W5C8V5S
M<V\N(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y,0IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G92!M
M97-S86=E<R(*;7-G<W1R(")%;&EM:6YA(&D@;65S<V%G9VDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED
M(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C0*
M;7-G:60@(E%U97)Y(@IM<V=S='(@(D1O;6%N9&$B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z.#`*;7-G:60@(E%U;W1A(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`B4V5L97II;VYE(')A9&EO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M4&EO9V=I82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN
M($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS
M9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")286EN('1O(%-N
M;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")287!P;W)T;R(*"B,Z
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV."!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(DQE9V=I(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C@W(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PIM<V=I
M9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),96=G97)E(&D@;65S<V%G9VDB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B16QI;6EN87)E(')E86QM
M96YT92`E<S\@3"=O<&5R87II;VYE(&YO;B!P=?(@97-S97)E(')E8W5P97)A
M=&$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM
M<V=S='(@(B(*(D5L:6UI;F%R92!R96%L;65N=&4@;&4@:6YF;W)M87II;VYI
M(')E;&%T:79E(&%L;"=U=&5N=&4@)7,_($PG;W!E<F%Z:6]N92!N;VX@(@HB
M<'7R(&5S<V5R92!R96-U<&5R871A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(E)I97-E9W5E(&QA('1U82!U;'1I;6$@87II
M;VYE(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B06=G:6]R
M;F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R
M97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B06=G:6]R;F$@
M9VQI(&5L96UE;G1I(&1I;F%M:6-I(&1E;"!M96YU.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z
M(@IM<V=S='(@(D%G9VEO<FYA<F4@;&$@=FES=&$@9&5L('!O<G1A;&4Z(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,R,S$*;7-G:60@(E)E
M;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R(")2:6-A<FEC82(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@
M(D]S<V5R=F%Z:6]N:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3<*
M;7-G:60@(E)E;6]T92!397)V97)S(@IM<V=S='(@(E-E<G9E<B!R96UO=&DB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E
M;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G
M<W1R(")54DP@<F5M;W1A("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E
M*3HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C(*;7-G:60@(E)E;6]V
M92(*;7-G<W1R(")2:6UU;W9I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B4FEM=6]V
M:2!I;"!B;&]C8V\B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34Y"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)I;75O
M=FD@;&$@8V]L;VYN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S
M='(@(E)I;75O=FD@;&$@9F]R;6%T=&%Z:6]N92(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R
M(")2:6UU;W9I(&QA(&-O<'!I82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,#$*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G
M<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")2:6UU;W9I(&QO('-C
M<FEP="!S86QV871O(&1A;&QA(&1I<F5C=&]R>2!T96UP;W)A;F5A(&1E;"!S
M97)V97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(E)I
M;75O=FD@:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B4FEM=6]V:2!Q=65S=&\@;F]D;R!D
M86P@9&]C=6UE;G1O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4FEM=6]V:2!L
M)W5T96YT92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T
M<B`B4FEM=6]V:2!L)W5T96YT93H@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM
M;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R("),82!R:6-H:65S
M=&$@;F]N('!U\B!E<W-E<F4@979A<V$N($-O9&EC92!D:2!E<G)O<F4@9&D@
M<FET;W)N;SH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T
M-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD
M+B(*;7-G<W1R("));"!S97)V:7II;R!R:6-H:65S=&\@;VX@<'7R(&5S<V5R
M92!T<F]V871O+B(*"B,Z(&QI8B](;W)D92YP:'`Z,3@U(&QI8B](;W)D92YP
M:'`Z-3(W"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N
M;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EPB
M)7-<(B!R:6-H:65S=&\@;F]N(.@@<W!E8VEF:6-A=&\@;F5L;&$@8V]N9FEG
M=7)A>FEO;F4@9&D@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C@W-"!L:6(O
M5D93+W-Q;"YP:'`Z-CDP(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE
M9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B7"(E<UPB(')I8VAI
M97-T;R!N;VX@Z"!S<&5C:69I8V%T;R!N96QL82!C;VYF:6=U<F%Z:6]N92!D
M:2!61E,N(@H*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@<FEC:&EE<W1O(&YO;B#H
M('-P96-I9FEC871O(&YE;&QA(&-O;F9I9W5R87II;VYE+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,S8*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(D-A;7!O(%)I8VAI97-T;R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q(&QI8B](;W)D92]&;W)M+G!H<#HS,SD*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,"!L:6(O2&]R9&4O1F]R;2]296YD
M97)E<BYP:'`Z,S(Q"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#`@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B
M4F5S970B"FUS9W-T<B`B07IZ97)A(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(D%Z
M>F5R82!L82!P87-S=V]R9"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D%Z
M>F5R82!L82!T=6$@<&%S<W=O<F0B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,Q"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B4FEP<FES
M=&EN82!L)W5L=&EM82!D;VUA;F1A(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(Y(&%D;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C<*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4FES=6QT871I(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHW"FUS9VED(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")2
M:71O<FYA(&%L;&4@3W!Z:6]N:2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W
M;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R
M(")2:7-C<FEV:2!L82!N=6]V82!P87-S=V]R9"(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<*;7-G:60@(E)E=6YI
M;VXB"FUS9W-T<B`B4FEU;FEO;F4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R
M="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(DEN=F5R=&D@;&$@0V]N9FEG=7)A
M>FEO;F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B3W!Z:6]N:2!P97(@
M:6P@4FEC:"!497AT($5D:71O<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R("));F1O=FEN96QL:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M.`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B1&5S=')A(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C,Q,#,*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R("))
M;G1E<W1A>FEO;FD@9&D@9&5S=')A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,P.3D*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R(")686QO<FD@9&D@
M9&5S=')A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B4')O<')I973@(&1E;&QA(%)I7V=A+BXN(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T
M<B`B4F5G;VQA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y.`IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED(")2
M;W1A=&4@,3@P(@IM<V=S='(@(E)O=71A(&1I(#$X,"(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*;7-G:60@(E)O=&%T92!,
M969T(@IM<V=S='(@(E)O=71A(&$@<VEN:7-T<F$B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED(")2;W1A=&4@4FEG
M:'0B"FUS9W-T<B`B4F]U=&$@82!$97-T<F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@
M4')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@9&5L;&$@4FEG82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65TX"!D
M96QL82!R:6=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)I9VAE.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(E)E9V]L92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@
M(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M
M;G,B"FUS9W-T<B`B3&4@<F5G;VQE(&%P<&%R:7)A;FYO('1R82!T=71T92!L
M92!R:6=H92!E(&QE(&-O;&]N;F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL
M(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("),92!R96=O
M;&4@87!P87)I<F%N;F\@<V]L;R!T<F$@;&4@8V]L;VYN92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(DQE(')E9V]L92!A<'!A<FER86YN;R!S;VQO('1R82!L92!R:6=H92(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C$*;7-G:60@(E)U;B(*;7-G<W1R
M(")%<V5G=6ER92(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.3D*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`P"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R(")&:7)M82!C:69R871A(%,O34E-
M12(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3
M+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B365S<V%G9VEO(&-I
M9G)A=&\@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*
M;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B3"=A=71E;G1I8V%Z:6]N92!305-,(&YO;B#H(&1I<W!O;FEB
M:6QE+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#8*;7-G:60@
M(E--4R!-97-S86=I;F<B"FUS9W-T<B`B365S<V%G9VEO(%--4R(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C<T"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(D1I8VAI87)A>FEO
M;F4@4U%,('!E<B!I;"!V86QO<F4@9&D@;&]O:W-U<"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z
M,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,#<*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S$*
M;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,SD*;7-G
M:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D*;7-G:60@(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-`IM<V=I9"`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B
M4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E-T97-S82!S=')U='1U<F$@
M*%]A=71O*2(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3$*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-@IM<V=I9"`B4V%O(%1O;64@86YD
M(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(G!R
M;W9I9&5R('-A=&5L;&ET87)E(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P,0IM<V=I9"`B4V%U9&D@07)A8FEA(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.0IM
M<V=I9"`B4V%V92(*;7-G<W1R(")386QV82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92!<(B5S7"(B"FUS9W-T<B`B4V%L=F$@7"(E<UPB(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92`E<R(*;7-G<W1R(")386QV82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")386QV82!L
M92!/<'II;VYI(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-@IM<V=I
M9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"B),82!C;VYF:6=U<F%Z:6]N92!G96YE<F%T82#H('-T
M871A('-A;'9A=&$@8V]M92!S8W)I<'0@4$A0(&YE;&QA(&1I<F5C=&]R>2`B
M"B)T96UP;W)A;F5A(&1E;"!T=6\@<V5R=F5R+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(G-A;'9A=&4@)7,@8V]N9FEG=7)A
M>FEO;FDN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B4V%L=F%T;R!L;R!S8W)I<'0@9&D@86=G:6]R
M;F%M96YT;R!D96QL92!I;7!O<W1A>FEO;FD@:6XZ(%PB)7-<(BXB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B
M4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(")38VEE;GIA
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G
M<W1R(")2:6-E<F-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R
M,@IM<V=I9"`B4V5A<F-H($5N9VEN97,B"FUS9W-T<B`B36]T;W)I(&1I(%)I
M8V5R8V$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDU-0IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(D9I;&4@<V5L97II;VYA=&DB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@U"FUS9VED(")396QE
M8W0@82!D871E(@IM<V=S='(@(E-E;&5Z:6]N82!U;F$@9&%T82(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G
M<F]U<"!T;R!A9&0B"FUS9W-T<B`B4V5L97II;VYA('5N(&=R=7!P;R!D82!A
M9V=I=6YG97)E(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM
M<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E-E;&5Z:6]N82!U
M;B!N=6]V;R!P<F]P<FEE=&%R:6\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")3
M96QE>FEO;F$@=6X@<V5R=F5R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(E-E;&5Z:6]N82!U;B!U=&5N=&4@9&$@86=G:75N9V5R92(*"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C
M="!A;&PB"FUS9W-T<B`B4V5L97II;VYA('1U='1O(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(V-#,*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+B(*;7-G<W1R(")396QE>FEO;F$@='5T=&D@:2!C;VUP;VYE;G1I(&1E
M;&QA(&1A=&$N(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R(")S96QE
M>FEO;F$@=6X@;V=G971T;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S<*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(DYE
M<W-U;F$@<V5L97II;VYE(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W
M"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB4V5L
M97II;VYA(&D@8V%R871T97)I(&1I(&-U:2!H86D@8FES;V=N;R!D86QL92!C
M87-E;&QE('-O='1O(')I<&]R=&%T92X@4'5O:2`B"B)C;W!I87)L:2!E(&EN
M8V]L;&%R;&D@9&%L;"=A<F5A(&1I('1E<W1O+B(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.B(*;7-G<W1R(")396QE>FEO;F$@:6P@=&5R;6EN92!D96QL82!D871A
M.B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0T"FUS9VED(")396QE
M8W0@=&AE(&1A=&4@9F]R;6%T.B(*;7-G<W1R(")396QE>FEO;F$@:6P@9F]R
M;6%T;R!D96QL82!D871A.B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET
M>7-E;&5C="YI;F,Z.3`*;7-G:60@(E-E;&5C="!T:&4@:61E;G1I='D@>6]U
M('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R(")396QE>FEO;F$@;"=I9&5N=&ET
MX"!C:&4@=G5O:2!M;V1I9FEC87)E.B(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*
M;7-G<W1R(")396QE>FEO;F$@:6P@;&EM:71E(&1E;&PG;W)A.B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I
M;64@9F]R;6%T.B(*;7-G<W1R(")396QE>FEO;F$@:6P@9F]R;6%T;R!D96QL
M)V]R83HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED
M(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B4V5L97II
M;VYA(&1U92!C86UP:2!C:&4@8V]R<FES<&]N9&]N;RXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N(@IM<V=S='(@(E-E;&5Z:6]N82!L;R!S8VAE;6$@9&5I(&-O;&]R
M:2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(E-E;&5Z:6]N
M82!L82!L:6YG=6$@<')E9F5R:71A.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM
M<V=S='(@(DEN=FEA(&EL(%)E<&]R="!D96P@<')O8FQE;6$B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N
M9"!335,B"FUS9W-T<B`B26YV:6$@4TU3(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3@*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,PIM<V=I9"`B4V5N96=A;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R,PIM<V=I9"`B
M4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R93H@(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")3
M971T96UB<F4B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY
M"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B3G5M97)O(&1I(%-E<FEE(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T.0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B26YF;W)M87II;VYE(&1E
M;"!S97)V97(@<V)A9VQI871A(&\@;F]N(&1I<W!O;FEB:6QE+B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G
M<W1R(")!;6UI;FES=')A=&]R92!D:2!S97-S:6]N92(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$
M(&5X<&ER960N(@IM<V=S='(@(DQA('-E<W-I;VYE($E$(.@@<V-A9'5T82(*
M"B,Z(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
M4V5S<VEO;FDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q-`IM<V=I9"`B
M4V5T(@IM<V=S='(@(DEM<&]S=&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-SD*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E
M="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T
M<B`B(@HB26UP;W-T82!L92!O<'II;VYI('!E<B!P97)M971T97)T:2!D:2!A
M>GIE<F%R92!L82!P87-S=V]R9"!N96P@8V%S;R!D;W9E<W-I("(*(F1I;65N
M=&EC87)T96QA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G
M:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("));7!O<W1A(&EL('-E
M<G9E<B!R96UO=&\@86P@<75A;&4@=G5O:2!A8V-E9&5R92!D86P@='5O('!O
M<G1A;&4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N(@IM<V=S='(@(DEM<&]S=&$@;&$@;&EN9W5A('!R969E<FET
M82!E(&QE(&]P>FEO;FD@<&5R(&PG;W)A(&4@;&$@9&%T82XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB
M26UP;W-T82!L92!A<'!L:6-A>FEO;FD@9&D@879V:6\L(&QO('-C:&5M82!D
M96D@8V]L;W)I+"!I;"!T96UP;R!D:2`B"B)A9V=I;W)N86UE;G1O(&1E;&QA
M('!A9VEN82!E(&%L=')E(&]P>FEO;FD@9&D@=FES=6%L:7IZ87II;VYE+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P(@IM
M<V=S='(@(DEM<&]S=&%Z:6]N92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C,W"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE(@IM<V=S='(@(E-C<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E
M;&QE(&EM<&]S=&%Z:6]N:2!D:7-P;VYI8FEL:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D1I=F5R
M<V4@<&]S:7II;VYI(&1I<W!O;FEB:6QI(&-O;B!I;"!P87)A;65T<F\Z("(*
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#,*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@
M(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B0G)E=F4@4V]M;6%R:6\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3:&]U;&0@86-C97-S
M(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B3&$@
M8VAI879E(&0G86-C97-S;R!D;W9RX"!E<W-E<F4@9&5F:6YI=&$@<&5R('!I
M^2!C;VQL96=A;65N=&D_(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B36]S=')A(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$U-`IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B)-;W-T<F$@;&4@
M9&EF9F5R96YZ92!T<F$@;&$@8V]N9FEG=7)A>FEO;F4@871T=6%L;65N=&4@
M<V%L=F%T82!E(&QA(&YU;W9A("(*(F=E;F5R871A+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B36]S=')A(&PG;W)A(&1E;&PG
M=6QT:6UO(&%C8V5S<V\@<75A;F1O(&5N=')I/R(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L(@IM<V=S='(@(DUO<W1R82!L)V]P>FEO;F4@<&5R(&UA;G1E;F5R92!Q
M=65L;&$@;W)I9VEN86QE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.34*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(DUO<W1R82!I;"!R86-C;V=L
M:71O<F4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS9VED(")3
M:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(DUO<W1R
M87)E(&QA('1A8F5L;&$@9&5L;&4@;W!E<F%Z:6]N:2!D96P@;65N=2!B87(_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R
M(")-;W-T<F$@:6P@;65N=2!D:2`E<R!S=6QL82!S:6YI<W1R83\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8S"FUS
M9VED(")3:&]W('5P;&]A9"(*;7-G<W1R(")-;W-T<F$@:6P@8V%R:6-A;65N
M=&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,@IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS9VED
M(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z.3<R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3`U.`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$Q,C`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3@S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R
M,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R-3(*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS
M9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A
M($QE;VYE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP
M:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(D-O;G1R87-S96=N82(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N
M871U<F4B"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R
M(")!;&=O<FET;6\@9&D@9FER;6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-PHC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(T-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-2!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M-`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@IM<V=I9"`B
M4VEZ92(*;7-G<W1R(")$:6UE;G-I;VYE(@H*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K:7`@36%I;G1E
M;F%N8V4B"FUS9W-T<B`B4V%L=&$@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N
M>FEO;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C$P"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X"FUS9VED
M(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R(*;7-G<W1R(").979E
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*
M;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS9VED(")3;F]W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO
M=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,@IM<V=I9"`B
M4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED
M(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR.3`X"FUS9VED(")3;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R
M(")/<F1I;F$@;"=O<F1I;F%M96YT;R!D:2!S96QE>FEO;F4B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-34Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.#D*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$V-B!L:6(O3F5T
M+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*
M;7-G<W1R("));F1I<FEZ>F\@<V]R9V5N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4U"FUS9VED(")3;W5T:"!!
M9G)I8V$B"FUS9W-T<B`B4W5D($%F<FEC82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`Q"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U
M=&@@4V%N9'=I8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T
M:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(F5M:7-F97)O($UE<FED:6]N86QE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T
M<B`B4W!A>FEO('1R82!C96QL92!A:61A8V5N=&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")3
M<&%Z:6\@=')A(&EL(&-O;G1E;G5T;R!E(&EL(&)O<F1O(&EN('5N82!C96QL
M82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX,34*;7-G:60@(E-P86-E<B(*
M;7-G<W1R(")$:7-T86YZ:6%T;W)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4U"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(E-P87II871U<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P
M861D:6YG(@IM<V=S='(@(E-P87II871U<F$@92!R:65M<&EM96YT;R(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P"FUS
M9VED(")3<&%I;B(*;7-G<W1R(")3<&%G;F$B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T
M97(@26YP=70B"FUS9W-T<B`B26YS97)I;65N=&\@0V%R871T97)I(%-P96-I
M86QI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")397!A<F$@
M;&$@8V5L;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B
M4V5P87)A(&QA(&-O;&]N;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS
M9W-T<B`B4V5P87)A(&QA(')I9VAA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Q"FUS9VED(")3<&]R=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q"FUS9VED(")3<FD@
M3&%N:V$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C8*;7-G:60@(E-T86YD87)D
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I
M9"`B4W1A<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-3@V(&QI8B](;W)D92]&;W)M+G!H<#HR-SDQ"FUS9VED(")3=&%R="!Y
M96%R(@IM<V=S='(@(D%N;F\@9&D@<&%R=&5N>F$B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B
M"FUS9W-T<B`B4W1A=&\@;R!0<F]V:6YC:6$B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&]R86=E
M(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1I(&UE;6]R:7IZ87II;VYE(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E
M="!!9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H
M<F]U9V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,S,*
M;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<R(*;7-G<W1R(")4;V=L:2!I;"!D;VUI;FEO(&1A;&PG:6YD:7)I>GIO
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B4W1I;&4@6T-3
M4UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8R"FUS9VED(")3=2(*;7-G<W1R(")$;R(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B4V]T=&]D:7)E8W1O<GD@7"(E
M<UPB(&YO;B!T<F]V871A+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M9F,X,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(D]G9V5T=&\B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R(")3;W1T;VUE
M='1I(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB12<@<W1A=&$@:6YV:6%T
M82!L82!R:6-H:65S=&$@<&5R(&%G9VEU;F=E<F4@7"(E<UPB(&%L('-I<W1E
M;6$N($YO;B!P=6]I("(*(F%C8V5D97)E(&9I;G1A;G1O("!C:&4@;&$@<FEC
M:&EE<W1A(&YO;B!V:65N92!A<'!R;W9A=&$N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#4@;&EB+TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(.@@<W1A=&\@86=G:75N
M=&\@8V]N('-U8V-E<W-O(&%L('-I<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@HB3&4@:6YF;W)M87II;VYI(')E;&%T:79E(&%L;"=U=&5N=&4@
M7"(E<UPB('-O;F\@<W1A=&4@8V%N8V5L;&%T92!C;VX@(@HB<W5S<V5S<V\@
M9&%L('-I<W1E;6$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&5L:6UI
M;F%T82!C;VX@<W5C8V5S<V\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!R:6UO<W-O(&-O
M;B!S=6-C97-S;R!D86P@<VES=&5M82XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG
M=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"B)#
M;VYF:6=U<F%Z:6]N92!I;G9E<G1I=&$@8V]N('-U8V-E<W-O+B!2:6-A<FEC
M82!P97(@=F5D97)E(&D@8V%M8FEA;65N=&DN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(D-O<&EA(&1E;&QA(&-O;F9I9W5R87II;VYE('-A;'9A=&$@8V]N
M('-U8V-E<W-O+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")#;W!I82!D96P@
M9FEL92!D:2!C;VYF:6=U<F%Z:6]N92!D:2`E<R!S86QV871A(&-O;B!S=6-C
M97-S;RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(D%G
M9VEO<FYA=&\@8V]N('-U8V-E<W-O(%PB)7-<(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R
M(")38W)I='1O(&-O;B!S=6-C97-S;R`E<R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B4V]M;6%R
M:6\B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2
M:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM
M<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-0IM<V=I9"`B
M4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N
M<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I
M9"`B4W5P<&]R="(*;7-G<W1R(")3=7!P;W)T;R(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@(E-O<')A;FYO;64B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y"FUS
M9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3D*;7-G
M:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B4W9E>FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-V
M:7IZ97)A(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G
M:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@
M97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D5R<F]R92!D:2!S:6YT
M87-S:2!N96D@=&5R;6EN:2!D:2!R:6-E<F-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.`IM<V=I9"`B4WER:6%N
M($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C,*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4
M+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E13
M5B!F:6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`B4')O<')I973@(&1E;&QA(%1A8F5L;&$B"@HC.B!L:6(O
M2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@
M4V5T(@IM<V=S='(@(DEM<&]S=&%Z:6]N92!D96QL82!486)E;&QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE=.`@
M9&5L;&$@=&%B96QL82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")486EW86XB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U
M"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S4*;7-G:60@(E1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R
M9V5T.B(*;7-G<W1R(")/8FEE='1I=F\Z(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,S(@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#D*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B
M071T:79I=.`B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W-`IM
M<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G<W1R(").=6UE<F\@9&D@=&5L
M969O;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I9"`B5&5M
M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@<&5R(&PG
M=6QT:6UA(&]R83H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C$*;7-G
M:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E;7!E<F%T=7)A(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B5&5M<&5R871U
M<F4Z("(*;7-G<W1R(")496UP97)A='5R83H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP
M97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DUA<V-H97)A(%PB)7-<(B!N;VX@=')O=F%T82XB"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B1V5S=&EO;F4@36%S8VAE<F$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(Q,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-PIM<V=I9"`B5&5X
M="(*;7-G<W1R(")497-T;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-SD*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")3;VQO(%1E<W1O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW
M-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R(")!;&QI;F5A;65N=&\@=&5S
M=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S
M='(@(D=I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E1H
M86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HX-C0*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DPG97-T
M96YS:6]N92!&5%`@;F]N(.@@9&ES<&]N:6)I;&4N(@H*(SH@;&EB+TAO<F1E
M+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N(@IM<V=S='(@(DQA(&-R;VYI<W1O<FEA(&1E;"!S:7-T96UA
M(.@@9&ES86)I;&ET871A+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,X
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A
M=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B
M26P@;6]T;W)E(&1I(&EN=&5G<F%Z:6]N92!(;W)D92]+;VQA8B!N;VX@<W5P
M<&]R=&$@7"(E<UPB(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*
M;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N
M(@IM<V=S='(@(DEL(&QO9R!D:2!)35-0(&YO;B!P=?(@97-S97)E(&EN:7II
M86QI>GIA=&\N(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS
M9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY(@IM<V=S='(@(DQA(&-L87-S92!-86EN=&5N86YC93HZ(&YO
M;B#H('-T871A(&-A<FEC871A(&-O;B!S=6-C97-S;R(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R("),82!F:6YI
M<W1R82!D96QL92!/<'II;VYI('-I(.@@8VAI=7-A+B!5<V-I<F4N(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M,#`@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E<FUS
M+G!H<#HR,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HR-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB+TAO
M<F1E+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A=&]R
M(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B
M86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS
M9W-T<B`B4V]L86UE;G1E(&EL(&QA=&\@:6YF97)I;W)E(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O
M;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS
M9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("));"!C;VYT871T;R#H('-T871O
M(&%G9VEU;G1O(&-O;B!S=6-C97-S;R!A;&QA('1U82!R=6)R:6-A+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D
M:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L
M(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E
M8VEF:65D+B(*;7-G<W1R(").;VX@Z"!S=&%T82!S<&5C:69I8V%T82!L82!L
M:7-T82!D:2!D:7-T<FEB=7II;VYE+B(*"B,Z(&QI8B](;W)D92]#<GEP="YP
M:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G<W1R("),82!F=6YZ:6]N
M92!D:2!C:69R871U<F$@<FEC:&EE9&4@=6YA(&-O;FYE<W-I;VYE('=E8B!S
M:6-U<F$N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#8@;&EB+TAO<F1E+G!H<#HU
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O
M;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("));"!F:6QE("5S(&1O=G)E
M8F)E(&-O;G1E;F5R92!U;F$@)7,@:6UP;W-T87II;VYE+B(*"B,Z(&QI8B](
M;W)D92YP:'`Z,3<Y(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N(@IM<V=S='(@(DEL(&9I;&4@)7,@9&]V<F5B8F4@8V]N=&5N97)E
M(&%L8W5N92`E<R!I;7!O<W1A>FEO;FDN(@H*(SH@;&EB+TAO<F1E+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(DEL(&9I;&4@;F]N(&-O;G1I96YE(&EN9F]R;6%Z:6]N:2XB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@HB3&4@<V5G=65N=&D@<V]N
M;R!L92!I;G1E<W1A>FEO;FD@<&5R('%U97-T;R!M97-S86=G:6\O<F9C.#(R
M(&UE<W-A9V=I;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T
M;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("),)VED96YT:73@(%PB
M)7-<(B#H('-T871A(&-A;6-E;&QA=&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE
M($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z
M.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O341.+G!H
M<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A9V4@<V5N
M="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I
M<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@=&AE(&UE
M<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]&:6QE+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(DEL(&YU
M;65R;R!D96D@8V%M<&D@9&5V92!E<W-E<F4@9&D@=&EP;R!N=6UE<FEC;RXB
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DEL(&UO9'5L;R!O<&5N<W-L
M(.@@<FEC:&EE<W1O('!E<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.BXB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(Y-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB3&$@<')E9F5R96YZ82!<
M(B5S7"(@;F]N('!U\B!E<W-E<F4@<V%L=F%T82!P97)C:.@@;"=I;F9O<FUA
M>FEO;F4@8V]N=&5N=71A("(*(F5C8V5D92!L82!M87-S:6UA(&1I;65N<VEO
M;F4@9&ES<&]N:6)I;&4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B
M+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]W96)C<'`N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@HB26P@<')O9W)A
M;6UA('5S871O('!E<B!V:7-U86QI>GIA<F4@<75E<W1O('1I<&\@9&D@:6YF
M;W)M87II;VYE("@E<RD@;F]N(.@@(@HB<W1A=&\@=')O=F%T;R!N96P@<VES
M=&5M82XB"@HC.B!L:6(O1FEL92]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HT
M-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S
M7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B26P@<V5R=F5R(%PB)7-<
M(B#H('-T871O(&5L:6UI;F%T;RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB
M)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B26P@<V5R=F5R(%PB)7-<
M(B#H('-T871O('-A;'9A=&\N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B3&$@<FEC:&EE<W1A(&1I(&ES
M8W)I>FEO;F4@<&5R("5S(.@@<W1A=&$@<FEM;W-S82XB"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("),82!R:6=A('-P96-I9FEC871A("@E9"D@;F]N(&5S:7-T
M92XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N
M(@IM<V=S='(@(DEL(&9I;&4@=&5M<&]R86YE;R!<(B5S7"(@;F]N(&5S:7-T
M92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,P,@IM<V=I9"`B5&AE('1E
M>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@
M<V-R965N+B(*;7-G<W1R("));"!T97-T;R!D:6=I=&%T;R!N;VX@8V]R<FES
M<&]N9&4@86P@=&5S=&\@<W5L;&\@<V-H97)M;RXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P
M"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W
M87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B3"=I
M;F9O<FUA>FEO;F4@8V%R:6-A=&$@Z"!S=&%T82!P97)S82!S:6X@9&%L;"=U
M;'1I;6\@<&%S<V\N(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-C(@
M;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E
M9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B26P@9FEL92!C
M87)I8V%T;R!N;VX@<'7R(&5S<V5R92!S86QV871O+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3&$@9&ER96-T;W)Y(&1E:2!T
M96UI(%PB)7-<(B!N;VX@Z"!S=&%T82!T<F]V871A+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N(@IM<V=S='(@(DYO;B!C:2!S;VYO(&]P>FEO;FD@9&ES
M<&]N:6)I;&DN(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,U
M,`IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(DYO;B!C:2!S;VYO('!A<G1I(&-H92!P
M;W-S;VYO(&5S<V5R92!V:7-U86QI>GIA=&4@:6YL:6YE+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)#:2!S;VYO('1R;W!P:2!C
M87)A='1E<FD@:6X@<75E<W1O(&-A;7!O+B!(86D@9&EG:71A=&\@)7,@8V%R
M871T97)I.R!D979I("(*(F1I9VET87)E('5N(&YU;65R;R!D:2!C87)A='1E
M<FD@;6EN;W)E(&1I("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E
M<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@
M(D-I('-O;F\@86QC=6YI('!R;V)L96UI(&YE;&PG86=G:75N9V5R92!<(B5S
M7"(@86P@<VES=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN
M9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G
M<W1R("(B"B)#)^@@<W1A=&\@=6X@<')O8FQE;6$@;F5L(&-A;F-E;&QA<F4@
M;&4@:6YF;W)M87II;VYI('!E<B!L)W5T96YT92!<(B5S7"(@9&%L("(*(G-I
M<W1E;6$Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")#)^@@<W1A=&\@=6X@<')O8FQE
M;6$@;F5L(')I;75O=F5R92!<(B5S7"(@9&%L('-I<W1E;6$Z("(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B0R?H
M('-T871O('5N('!R;V)L96UA(&YE;&PG86=G:6]R;F%M96YT;R!D:2!<(B5S
M7"(Z("5S(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*(D,G
MZ"!S=&%T;R!U;B!P<F]B;&5M82!C;VX@:6P@8V%R:6-A;65N=&\@9&5L(&9I
M;&4Z($YE<W-U;B`E<R#H('-T871O("(*(F-A<FEC871O+B(*"B,Z(&QI8B](
M;W)D92]"<F]W<V5R+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I
M>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB0R?H('-T871O('5N('!R;V)L
M96UA(&-O;B!I;"!C87)I8V%M96YT;R!D96P@9FEL93H@26P@)7,@97)A('!I
M^2!L=6YG;R!D96QL82`B"B)M87-S:6UA(&1I;65N<VEO;F4@<&5R;65S<V$@
M*"5D(&)Y=&5S*2XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N(@IM<V=S='(@(B(*(D,GZ"!S=&%T;R!U;B!P<F]B;&5M82!C
M;VX@:6P@8V%R:6-A;65N=&\@9&5L(&9I;&4Z($EL("5S(.@@<W1A=&\@8V%R
M:6-A=&\@(@HB<V]L;R!P87)Z:6%L;65N=&4N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*
M(D,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L;&$@=FES=6%L:7IZ87II;VYE(&1I
M('%U97-T82!P87)T92!D96P@;65S<V%G9VEO(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D,GZ"!S=&%T;R!U;B!E
M<G)O<F4@;F5L;"=I;7!O<G1A<F4@;&4@:6YF;W)M87II;VYI(&1E;"!C;VYT
M871T;RXB"@HC.B!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B0R?H('-T871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%R
M92!L92!I;F9O<FUA>FEO;FD@9&D@:4-A;&5N9&%R+B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T
M(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B)#)^@@<W1A
M=&\@=6X@97)O<F4@;F5L;&$@9F]R;2!D:2!C;VYF:6=U<F%Z:6]N92X@4')O
M8F%B:6QM96YT92!H86D@(@HB9&EM96YT:6-A=&\@=6X@8V%M<&\@<FEC:&EE
M<W1O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"B)#)^@@<W1A=&\@=6X@97)R;W)E
M(&YE;&PG97-E9W5I<F4@;&$@<W!E8VEF:6-A(&9U;GII;VYE(&1E;&QA(')U
M8G)I8V$N(%-I("(*(G!R96=A(&1I(')I<')O=F%R92!P:?D@=&%R9&DN(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*(D,G
MZ"!S=&%T;R!U;B!E<G)O<F4@;F5L;"=A9V=I;W)N86UE;G1O(&1E:2!D971T
M86=L:2!D96P@8V]N=&%T=&\N(%-I('!R96=A("(*(F1I('!R;W9A<F4@<&GY
M('1A<F1I+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE
M<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES
M="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB0R?H('-T
M871O('5N(&5R<F]R92!N96QL)V%G9VEO<FYA;65N=&\@9&5L;&$@;&ES=&$@
M9&D@9&ES=')I8G5Z:6]N92X@4VD@(@HB<')E9V$@9&D@<')O=F%R92!P:?D@
M=&%R9&DN(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T
M.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B475E<W1O('-E<G9E<B!)34%0(&YO
M;B!S=7!P;W)T82!L82!C;VYD:79I<VEO;F4@9&D@8V%R=&5L;&4N(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM
M<V=S='(@(E%U97-T;R!S96UB<F$@;F]N(&5S<V5R92!U;B!A<F-H:79I;R!D
M:2!T:7!O(')A<B!V86QI9&\N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E
M(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(E%U97-T;R!S96UB<F$@;F]N
M(&5S<V5R92!U;B!F:6QE(&1I('1I<&\@>FEP('9A;&ED;RXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$R-PIM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M
M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(E%U97-T;R!N
M;VX@<V5M8G)A(&5S<V5R92!U;B!N=6UE<F\@9&D@8V%R=&$@=F%L:61O+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*(E9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HY-S@@;&EB+TAO<F1E+T9O<FTN<&AP.C$P
M-3<@;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#8*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q.#(@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-38*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#4@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$S.3@@;&EB+TAO<F1E+T9O<FTN<&AP.C$U-3<*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y
M-3@@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,#4*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(P,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S@@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Q-#D*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,C$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(V,S<@;&EB+TAO<F1E+T9O<FTN<&AP.C(X
M,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,3D*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,X,#4@;&EB+TAO<F1E+T9O
M<FTN<&AP.C,X,3,*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@
M(B!1=65S=&\@8V%M<&\@<'7R(&-O;G1E;F5R92!S;VQO(&EN=&5R:2XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T
M<B`B(%%U97-T;R!C86UP;R!P=?(@8V]N=&5N97)E('-O;&\@;G5M97)I(&4@
M9'5E('!U;G1I+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DT"FUS9VED
M(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$R,PIM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HB475E<W1O(&-A;7!O('!U
M\B!E<W-E<F4@<V]L;R!U;F$@;&ES=&$@9&D@:6YT97)I('-A<&%R871I(&1A
M('9I<F=O;&$@;R!S<&%Z:6\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@Y
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM
M<V=S='(@(E%U97-T;R!C86UP;R!D979E(&5S<V5R92!U;B!N=6UE<F\@=F%L
M:61O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$X"FUS9VED("(B"B)4
M:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'
M0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S
M='(@(B(*(E%U97-T;R!C86UP;R!D979E(&-O;G1E;F5R92!U;B!C;VQO<F\@
M:6X@9F]R;6%T;R!21T(@97-A9&5C:6UA;&4L(&%D(&5S96UP:6\@(@HB)R,Q
M,C,T868G+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H
M:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B
M475E<W1A(&9O<FT@Z"!G:6$@<W1A=&$@<')O8V5S<V%T82XB"@HC.B!T96UP
M;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&ES(&ES("5S+B(*;7-G<W1R(")1=65S=&\@Z"`E<RXB"@HC.B!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T
M96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W
M;BXB"FUS9W-T<B`B(@HB475E<W1O(&UE<W-A9V=I;R#H('-T871O('-C<FET
M=&\@:6X@=6X@<V5T(&1I(&-A<F%T=&5R:2`H)7,I(&1I=F5R<V\@9&%L('1U
M;RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-@IM<V=I9"`B5&AI
M<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(E%U97-T
M;R!N=6UE<F\@9&5V92!E<W-E<F4@=6YI8V\N(@H*(SH@;&EB+TAO<F1E+T-O
M;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U
M;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B475E<W1O
M('-E<G9E<B!N;VX@<'7R(&1E8V]M<')I;65R92!F:6QE(&EN(&9O<FUA=&\@
M>FEP(&4@9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R(")!;"!M;VUE;G1O('%U97-T;R!S:7-T96UA(&YO;B#H(&%T=&EV
M;RXB"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R(")1=65S=&\@=F%L
M;W)E(&1E=F4@97-S97)E('5N(&YU;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(E%U
M97-T82!F:6YE<W1R82!D979E(&5S<V5R92!C:&EA;6%T82!D82!U;F$@9FEN
M97-T<F$@9&5L;&4@3W!Z:6]N:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E1U
M;VYO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-@IM<V=I9"`B
M5&EC:V5T<R(*;7-G<W1R(")":6=L:65T=&DB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C0R-2!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(E1I;64B"FUS9W-T<B`B3W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM
M<V=S='(@(D9O<FUA=&\@9&5L;"=O<F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4S,0IM<V=I9"`B5&EM92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L97II
M;VYE(&1E;&PG;W)A(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(S,`IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,CD*;7-G:60@(E1I=&QE(@IM<V=S='(@(E1I
M=&]L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O
M(@IM<V=S='(@(D$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C4T"FUS9VED("(B"B)4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*;7-G<W1R("(B"B)097(@<V5L97II
M;VYE<F4@<&GY('9O8VDL('1I96YI('!R96UU=&\@:6P@=&%S=&\@0V]N=')O
M;"`H4$,I(&\@0V]M;6%N9"`B"B(H36%C*2!M96YT<FD@<W1A:2!C;&EC8V%N
M9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I
M9"`B5&]D87DB"FUS9W-T<B`B3V=G:2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O
M=7)C92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C(S"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8*
M;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B1&]M
M86YI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R.0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV86QI9"!L
M;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@(E1R;W!P
M92!A8V-E<W-I(&YO;B!V86QI9&D@9'5R96YT92!G;&D@=6QT:6UI(&UI;G5T
M:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#$*;7-G:60@(E1O<"(*;7-G<W1R(")!;'1O(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P
M(&9R86UE("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4<F%D=7II
M;VYI(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(S,@IM<V=I9"`B5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F
M86QS92(*;7-G<W1R(")697)O(&\@9F%L<V\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R
M(")-82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,0IM<V=I9"`B
M5'5R:V5Y(@IM<V=S='(@(E1U<F-H:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y-0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C`*;7-G:60@
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S"FUS9VED
M(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8T
M"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B1&EG:71A(&QA
M('1U82!S8V5L=&$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO:69R86UE+G!H<#HQ-R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A
M<F0N<&AP.C(T.0IM<V=I9"`B55),(@IM<V=S='(@(B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS
M9VED(")54DPZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S<*;7-G:60@(E5G86YD82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C,V"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z-#(U"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%C8V5D97)E(&%L;&$@9&ER
M96-T;W)Y(%9&4RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.CDV
M"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@
M=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B));7!O<W-I8FEL92!A9V=I
M=6YG97)E(&%L=')E(&EN9F]R;6%Z:6]N:2!S=6=L:2!U=&5N=&D@;65N=')E
M(&1U<F%N=&4@;&$@(@HB<V]T=&]S8W)I>FEO;F4N(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M26UP;W-S:6)I;&4@8V%M8FEA<F4@:2!P97)M97-S:2!P97(@:6P@9FEL92!6
M1E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDX(&QI8B]61E,O
M;75S<6PN<&AP.C0X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("));7!O<W-I8FEL92!C86UB:6%R92!I('!E<FUE<W-I('!E<B!I;"!F:6QE
M(%9&4R`E<R\E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-SDY"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@
M(DEM<&]S<VEB:6QE(&-A;6)I87)E(&$@)7,N(@H*(SH@;&EB+U9&4R]F='`N
M<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@=F5R
M:69I8V%R92!L82!D:6UE;G-I;VYE(&1I(%PB)7-<(BXB"@HC.B!L:6(O5D93
M+V9I;&4N<&AP.C<P-R!L:6(O5D93+W-Q;"YP:'`Z,3`T,"!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HX-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(DEM<&]S
M<VEB:6QE('9E<FEF:6-A<F4@;&$@9&EM96YS:6]N92!D:2!<(B5S+R5S7"(N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O<W%L+G!H<#HT,SD*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S='(@(DEM<&]S<VEB
M:6QE(&-O;FYE='1E<G-I(&%L('-E<G9E<B!344PN(@H*(SH@;&EB+U9&4R]F
M='`N<&AP.C@X,PIM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&-O;FYE='1E<G-I(&-O;B!34TPN(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR,S@@;&EB+U9&4R]F:6QE+G!H<#HR-#,@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$T"B,Z(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C(Q.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,C<*;7-G:60@(E5N86)L
M92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FEL92!C;W!I
M87)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS-S,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@8W)E87)E(&QA(&1I
M<F5C=&]R>2!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S8W
M(&QI8B]61E,O;75S<6PN<&AP.C(W,"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR
M-S0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B26UP;W-S:6)I;&4@8W)E87)E(&QA(&1I<F5C=&]R>2!61E,N(@H*
M(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!F:6QE+B(*;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@:6P@
M9FEL92!61E,N(@H*(SH@;&EB+U9&4R]S;6(N<&AP.C(Y-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB
M+B(*;7-G<W1R("));7!O<W-I8FEL92!C<F5A<F4@;&$@8V%R=&5L;&$@5D93
M(%PB)7-<(BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(W.`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@8W)E87)E(&EL(&9I;&4@5D93('9U;W1O+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]G>FEP+G!H<#HW.2!L:6(O2&]R9&4O0V]M<')E<W,O=&%R
M+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS
M9W-T<B`B26UP;W-S:6)I;&4@9&5C;VUP<FEM97)E(&QE(&EN9F]R;6%Z:6]N
M:2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S`S(&QI8B]61E,O<VUB+G!H<#HR
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S
M7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("));7!O
M<W-I8FEL92!E;&EM:6YA<F4@7"(E<UPB+"!L82!D:7)E8W1O<GD@;F]N(.@@
M=G5O=&$N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI;6EN
M87)E(%PB)7-<(CH@)7,N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HS-#0@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S(S(&QI8B]61E,O<W%L+G!H<#HT,#<*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92`E<RP@;&$@9&ER96-T
M;W)Y(&YO;B#H('9U;W1A(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S@T
M(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,X.`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R("));7!O
M<W-I8FEL92!E;&EM:6YA<F4@;&$@9&ER96-T;W)Y(%9&4R!I;B!M;V1O(')I
M8V]R<VEV;RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,U,"!L:6(O5D93+VUU
M<W%L+G!H<#HS,S0@;&EB+U9&4R]M=7-Q;"YP:'`Z,S0W"B,Z(&QI8B]61E,O
M;75S<6PN<&AP.C,U-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#`*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP
M;W-S:6)I;&4@96QI;6EN87)E(&QA(&1I<F5C=&]R>2!61E,N(@H*(SH@;&EB
M+U9&4R]S<6PN<&AP.C0S,B!L:6(O5D93+W-Q;"YP:'`Z-#0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!D:7)E8W1O
M<GD@5D93.B`E<RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("))37!O<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL92!61E,@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S$V(&QI8B]61E,O;75S
M<6PN<&AP.C$V-R!L:6(O5D93+VUU<W%L+G!H<#HQ.#`*(SH@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L+G!H<#HR.3$@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z-#$Y"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0R-PIM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@96QI;6EN87)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI8B]61E,O<VUB
M+G!H<#HR-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@96QI
M;6EN87)E(&QA(&-A<G1E;&QA(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C0R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&5L:6UI;F%R92!61E,@:6X@;6]D;R!R:6-O<G-I=F\Z("5S+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HX-#<*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&1E=&5R
M;6EN87)E(&QA(&1I<F5C=&]R>2!A='1U86QE+B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DEM<&]S<VEB:6QE(&5S=&%R
M<F4@:2!D971T86=L:2!D96P@8V5R=&EF:6-A=&\B"@HC.B!L:6(O3F5T+TE-
M4U`N<&AP.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F
M("5S+B(*;7-G<W1R("));7!O<W-I8FEL92!C87)I8V%R92!L82!D969I;FEZ
M:6]N92!D:2`E<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(P."!L:6(O5D93
M+V9I;&4N<&AP.C(Q,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-SD*(SH@;&EB
M+U9&4R]S<6Q?9FEL92YP:'`Z,3@T"FUS9VED(")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@<W!O<W1A<F4@:6P@9FEL
M92!61E,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.CDX(&QI8B]61E,O<VUB+G!H
M<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V"B,Z(&QI8B]61E,O<VUB+G!H<#HV
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W-I8FEL92!A<')I<F4@:6P@9FEL
M92!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,CDP(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$S."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*
M;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*
M;7-G<W1R("));7!O<W-I8FEL92!A<')I<F4@:6P@9FEL92!61E,@<&5R(&QA
M('-C<FET='5R82XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C@S(&QI8B]61E,O
M9FEL92YP:'`Z,3,W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S:6)I;&4@
M87!R:7)E(&EL(&9I;&4@5D93+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N(@IM<V=S='(@(DEM<&]S<VEB:6QE(&%P<FEE(&PG87)C:&EV
M:6\@8V]M<')E<W-O+B(*"B,Z(&QI8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B26UP;W-I8FEL92!L96=G97)E(&EL(&9I;&4@5D93("AF:6QE<VEZ
M92!F:6QE*"D@9F%I;&5D*2XB"@HC.B!L:6(O5D93+G!H<#HX.#<*;7-G:60@
M(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE
M9"DN(@IM<V=S='(@(DEM<&]S<VEB:6QE(&QE9V=E<F4@:6P@9FEL92!61E,@
M*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I
M;&4Z("(*;7-G<W1R("));7!O<W-I8FEL92!L96=G97)E(&EL(&9I;&4Z("(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C@X"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<VEB:6QE
M(&QE9V=E<F4@;&$@9&ER96-T;W)Y('9F<W)O;W0N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,3`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"B));7!O<W-I8FEL92!R:6YO;6EN87)E("5S
M(&EN("5S.B!L82!C87)T96QL82!D:2!D97-T:6YA>FEO;F4@Z"!G:6$@<')E
M<V5N=&4B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,C,*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S
M:6)I;&4@<FEN;VUI;F%R92!L82!D:7)E8W1O<GD@5D93+B(*"B,Z(&QI8B]6
M1E,O<W%L+G!H<#HS-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B26UP;W-S:6)I
M;&4@<FEN;VUI;F%R92!L82!D:7)E8W1O<GD@5D93.B`E<RXB"@HC.B!L:6(O
M5D93+V9T<"YP:'`Z,S4Q(&QI8B]61E,O<VUB+G!H<#HR-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE(')I;F]M:6YA<F4@:6P@9FEL92!61E,@
M7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z-C(Y(&QI8B]61E,O;75S
M<6PN<&AP.C(T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("));7!O<W-I8FEL92!R:6YO
M;6EN87)E(&EL(&9I;&4@5D93("5S+R5S+B(*"B,Z(&QI8B]61E,O;75S<6PN
M<&AP.C(Q,R!L:6(O5D93+VUU<W%L+G!H<#HT-C0@;&EB+U9&4R]S<6PN<&AP
M.C,S.`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,34@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S,W"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+B(*;7-G<W1R("));7!O<W-I8FEL92!R:6YO;6EN87)E(&EL(&9I;&4@5D93
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS9VED
M(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B26UP;W-S:6)I
M;&4@97-E9W5I<F4@)VUK:7-O9G,G+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("));7!O<W-I8FEL92!T<F%D
M=7)R92!Q=65S=&\@9&]C=6UE;G1O(%=O<F0B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$X,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('1R
M:6=G97(@9G)E92]B=7-Y('5P9&%T92!F;W(@)7,B"FUS9W-T<B`B26UP;W-S
M:6)I;&4@9&%R92!L)V%V=FEO(&%L;"=A9V=I;W)N86UE;G1O(&9R964O8G5S
M>2!P97(@)7,B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P
M+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S:6)I;&4@<V-R:79E
M<F4@:6P@9FEL92!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z
M,3@V"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F
M86EL960I+B(*;7-G<W1R("));7!O<W-I8FEL92!S8W)I=F5R92!I;"!F:6QE
M(%9&4R`H8V]P>2@I(&9A:6QE9"DN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M.30@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$U,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N
M(@IM<V=S='(@(DEM<&]S<VEB:6QE('-C<FEV97)E(&QE(&EN9F]R;6%Z:6]N
M:2!N96P@9FEL92!61E,N(@H*(SH@;&EB+U9&4RYP:'`Z.#8R"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N(@IM<V=S='(@(DEM<&]S<VEB:6QE('-C<FEV97)E(&EL(&9I;&4@5D93
M+"!L82!Q=6]T82!C;VYS96YT:71A('9E<G+@(&5C8V5D=71A+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@
M(E5N9&5R;&EN92(*;7-G<W1R(")3;W1T;VQI;F5A=&\B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`B06YN=6QL82!-;V1I9FEC:&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(").;VX@9F%R92!L82!T=6$@=6QT:6UA(&%Z:6]N
M92(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$@;&EB
M+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.`IM<V=I9"`B56YE>'!E
M8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS
M9W-T<B`B4FES<&]S=&$@:6YA='1E<V$@9&%L('-E<G9E<B!D=7)A;G1E(&QA
M(&-O;FYE<W-I;VYE.B`B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C$W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS9W-T<B`B4FES<&]S=&$@
M:6YA='1E<V$@9&%L('-E<G9E<B!A.B`B"@HC.B!L:6(O2&]R9&4O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D
M92`H551&+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$W"FUS9VED(")5;FET960@07)A8B!%;6ER
M871E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S@*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#`*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S.0IM
M<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HU."!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,CD*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(E-C;VYO<V-I=71O(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@
M(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3D*;7-G
M:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$T-PIM
M<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@
M(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(DYO;64@
M=71E;G1E(&4@<&%S<W=O<F0@<V-O;F]S8VEU=&DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@
M(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(DYO;B!C;VQL
M96=A<F4@;"=E;&5M96YT;R!C;W)R96YT92(*"B,Z(&QI8B](;W)D92])9&5N
M=&ET>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E-E;GIA(&YO
M;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z.3(W"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B17-T
M96YS:6]N92!N;VX@<W5P<&]R=&%T82(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS
M9VED(")5<&1A=&4B"FUS9W-T<B`B06=G:6]R;F$B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5P9&%T92`E<R(*;7-G<W1R(")!9V=I;W)N82`E<R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R
M(@IM<V=S='(@(D%G9VEO<FYA('5T96YT92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T960@
M7"(E<UPB+B(*;7-G<W1R(")!9V=I;W)N82!<(B5S7"(N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E
M;&5T960N(@IM<V=S='(@(E-C<FEP="!D:2!C87)I8V%M96YT92!E;&EM:6YA
M=&$N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-R!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"FUS9VED(")5<&QO860B"FUS
M9W-T<B`B0V%R:6-A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-0IM
M<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N(@IM<V=S='(@(F-A<FEC871I('1U='1I(&D@9FEL92!D
M:2!I;7!O<W1A>FEO;F4@9&5L;&4@87!P;&EC87II;VYI('-U;"!S97)V97(N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R
M(")C87)A='1E<FD@;&%T:6YI(&UA:75S8V]L:2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@
M(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B3G5M97)I(')O;6%N:2!M
M86EU<V-O;&DB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0Q"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")U<V$@:6P@
M8V]R<F5N=&4Z("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")5<V$@4U-,(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O
M<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T
M<B`B57-A('-E(&EL(&YO;64@=71E;G1E+W!A<W-W;W)D(.@@9&EF9F5R96YT
M92!D82!Q=65L;&$@9&5L('-E<G9E<B!)35-0+B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B
M571E;G1E(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@
M)7,N(@IM<V=S='(@(DQU=&5N=&4@)7,@;F]N(.@@875T;W)I>GIA=&\@<&5R
M("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")'97-T:6]N92!5=&5N=&DB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM
M<V=S='(@(D]P>FEO;FD@571E;G1I(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G:7-T<F%Z:6]N92!5
M=&5N=&DB"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R
M("),87)E9VES=')A>FEO;F4@9&5G;&D@=71E;G1I(.@@<W1A=&$@9&ES86)I
M;&ET871A('!E<B!Q=65S=&\@<VET;RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#DT"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S
M='(@(DYO;64@=71E;G1E(&YO;B!T<F]V871O(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,V"B,Z(&QI8B].970O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.3@@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$U,`HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,R!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N
M:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(").;VUE(%5T96YT92(*
M"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B3F]M92!5=&5N=&4@7"(E<UPB(.@@9VEA('!R97-E;G1E+B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(DYO;64@571E;G1E.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F]M
M92!5=&5N=&4Z("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E5T96YT
M:2!N96P@<VES=&5M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0R"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3<P(&QI8B]61E,O9FEL92YP:'`Z
M,C8X"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G
M<W1R("),82!D:7)E8W1O<GD@5D93(&YO;B!E<VES=&4N(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T
M<B`B07-S96YZ82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C8*;7-G:60@
M(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B4&]S
M:7II;VYI('9A;&ED92!T<F]V871E(&EN8VQU9&]N;SH@(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED:71Y(@IM<V=S
M='(@(E9A;&ED:73@(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR-34@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM
M<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B5F%L
M;W)E(&EN(&UI;G5T:2!D82!O<F$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B26P@=F%L;W)E(.@@;6%G9VEO<F4@9&QL82!M87-S:6UA(&QU
M;F=H97IZ82!D:2`E<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,Q
M-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,"!L:6(O2&]R9&4O1F]R;2]4
M>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(E9A
M;&]R:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`Y(&QI8B](;W)D92]&
M;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS
M9W-T<B`B5F%L;W)I(&1A:2!Q=6%L:2!S96QE>FEO;F%R92(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#D*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5F%R:6%B:6QE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(T-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I;VX@9F%I
M;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET
M:"XB"FUS9W-T<B`B5F5R:69I8V$@9F%L;&ET82`M('%U97-T;R!M97-S86=G
M:6\@<'7R(&5S<V5R92!S=&%T;R!A;'1E<F%T;R!C;VXN(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E9E<G-I;VXB"FUS9W-T
M<B`B5F5R<VEO;F4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X
M"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B5F5R<VEO;F4@9&D@
M0V]N=')O;&QO(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T
M<B`B06QL:6YE86UE;G1O('9E<G1I8V%L92(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A
M9&1I;F<B"FUS9W-T<B`B4FEE;7!I;65N=&\@=F5R=&EC86QE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I8V%L93HB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B5F5R>2!(:6=H
M(@IM<V=S='(@(DUO;'1O($%L=&\B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X"FUS9VED(")6:65T($YA;2(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE
M=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.3<Q"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M)7,B"FUS9W-T<B`B5FES=6%L:7IZ82`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS
M9W-T<B`B5FES=6%L:7IZ82!U;F$@<&%G:6YA('=E8B!E<W1E<FYA(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9I<W5A;&EZ>F$@8V]M92`E
M<R(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#8*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#<*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$V"FUS9VED(")6:7-I8FEL:71Y
M(@IM<V=S='(@(E9I<VEB:6QI=.`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4R"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FES
M:6)I;&ETX#H@(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I
M;&4N<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(D%45$5.6DE/3D4B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RXB"FUS9W-T<B`B051414Y:24].12$A(2!224U53U9)($Q/(%-#4DE05"!-
M04Y504Q-14Y412!$02`E<RXB"@HC.B!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,`IM<V=I
M9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.CDU(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:'1M
M;"YP:'`Z,3(W"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%T=&5N>FEO;F4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X
M"FUS9VED(")792(*;7-G<W1R(")-92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R
M(")";VQL971T:6YO(&UE=&5O<F]L;V=I8V\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B0F]L;&5T=&EN;R!M971E;W)O;&]G:6-O(&9O<FYI
M=&\@9&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T
M:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G
M<W1R(")3971T:6UA;F%L;65N=&4B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B
M:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R(")"96YV96YU=&\B
M"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M
M92!T;R`E<R(*;7-G<W1R(")"96YV96YU=&\@82`E<R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI
M;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R
M(")"96YV96YU=&\L("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3@*
M;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ-2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S@*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B475A;&4@87!P;&EC87II;VYE(&1O
M=G+@('9I<W5A;&EZ>F%R92`E<R!D;W!O(&PG86-C97-S;S\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@
M9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B475A;"?H(&EL(&-A<F%T
M=&5R92!D:2!D96QI;6ET87II;VYE/R(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T
M97(_(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#8U"FUS9VED(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC
M:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")1=6%L92!P;'5G:6YS(&%B:6QI
M=&%R92!P97(@:6P@4FEC:"!497AT(&5D:71O<BXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"FUS9VED(")7
M:61T:"(*;7-G<W1R("),87)G:&5Z>F$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$P-PIM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(DQA
M<F=H97IZ82!I;B!U;FETX"!#4U,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.B(*;7-G<W1R("(B"B),87)G:&5Z>F$@9&5L(&UE;G4@9&D@)7,@<W5L;&$@
M<VEN:7-T<F$@*&%V<N`@969F971T;R!C;VP@<')O<W-I;6\@86-C97-S;RDZ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("),87)G:&5Z
M>F$@9&5L;&$@=&%B96QL82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@
M(E5N:73@(&1I(&QA<F=H97IZ82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B
M3&%R9VAE>GIA.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,34*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-PIM<V=I9"`B5VEN9"(*;7-G<W1R(")696YT;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")7:6YD
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*
M;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5F5L;V-I=.`@
M9&5L('9E;G1O(&EN(&YO9&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V
M,PIM<V=I9"`B5VEN9#HB"FUS9W-T<B`B5F5N=&\Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(E9E;G1O.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@
M(E=I<V1O;2(*;7-G<W1R(")386=G97IZ82(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HQ.3@*;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R
M("),879O<F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(DEN9&ER:7IZ;R!D96P@;&%V;W)O
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`B5&5L969O;F\@9&5L(&QA=F]R;R(*
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS(&QI8B]&:6QE+T-35BYP:'`Z,CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',@
M:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").
M=6UE<F\@9&D@8V%M<&D@97)R871O(&YE;&QA(&QI;F5A("5D+B!!='1E<VD@
M)60L('1R;W9A=&D@)60N(@H*(SH@;&EB+T9I;&4O0U-6+G!H<#HS,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP
M96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R(").=6UE<F\@9&D@8V%M<&D@
M97)R871O+B!!='1E<VD@)60L('1R;W9A=&D@)60N(@H*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HQ,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;V9F<V5T
M("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB"FUS9W-T<B`B0V]M<&5N
M<V%Z:6]N92!S8F%G;&EA=&$@)60@9'5R86YT92!L82!L971T=7)A(&1I('5N
M(&9I;&4@5D93+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#4*
M;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*
M;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V
M"FUS9VED(")965E9(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3$Q"FUS9VED(")986AO;R$@;6%P(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@
M(EEE87)L>2(*;7-G<W1R(")!;FYU86QM96YT92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3(*;7-G:60@(EEE;65N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R(")3:2(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B4VDL('-O;F\@9"=A8V-O<F1O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*(E-E:2!I;B!F
M;W)M871O('1E<W1O+B!5<V$@:6P@8F]T=&]N92!;/#Y=('!E<B!T;W)N87)E
M(&%L(&9O<FUA=&\@5UE325=91RXB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@
M87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS
M+B(*;7-G<W1R(").;VX@:&%I(&EL('!E<FUE<W-O(&1I(&-R96%R92!P:?D@
M9&D@)60@8FQO8V-H:2XB"@HC.B!L:6(O2&]R9&4N<&AP.C$T,C0*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYO;B!T:2!S
M96D@875T96YT:6-A=&\N(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS
M,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@
M:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(DYO;B!P=6]I(&%V97)E(&EL
M(&-A<F%T=&5R92`G7%PG(&YE;"!T=6\@;F]M92!C;VUP;&5T;RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW
M-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R
M97-S+B(*;7-G<W1R(").;VX@:&%I(&EN<V5R:71O('5N(&EN9&ER:7IZ;R!E
M;6%I;"!V86QI9&\N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B).;VX@:&%I(&%S<V]C:6%T
M;R!N97-S=6X@9&5I(&-A;7!I(&1A;"!F:6QE(&EM<&]R=&%T;R!C;VX@:2!C
M86UP:2`B"B)C;W)R:7-P;VYD96YT:2!I;B`E<RXB"@HC.B!L:6(O2&]R9&4O
M075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N
M(@IM<V=S='(@(E-E:2!S=&%T;R!D:7-C;VYN97-S;RXB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@
M82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N
M(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N(@IM<V=S='(@(B(*(D1E=FD@:6YS97)I<F4@=6X@;G5M97)O
M(&1I(&-E;&QU;&%R92!V86QI9&\L(&-O;G1E;F5N=&4@<V]L;R!N=6UE<FD@
M8V]N("(*(FPG;W!Z:6]N92!D96P@)RLG('!E<B!I('!R969I<W-I(&EN=&5R
M;F%Z:6]N86QI+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@X"FUS9VED
M(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R(")$
M979I(&EN<V5R:7)E('5N('9A;&]R92!V86QI9&\N(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B
M1&5V:2!C;VYF:6=U<F%R92!U;B!B86-K96YD('!E<B!I;"!$871A5')E92!P
M97(@=7-A<F4@4VEG;G5P<RXB"@HC.B!L:6(O2&]R9&4N<&AP.C0W,0IM<V=I
M9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@
M(D1E=FD@8V]N9FEG=7)A<F4@=6X@8F%C:V5N9"!61E,N(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E
M<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R
M;V)L96T@<F5P;W)T+B(*;7-G<W1R(")$979I('!R:6UA(&1E<V-R:79E<F4@
M:6P@<')O8FQE;6$@<')I;6$@9&D@;6%N9&%R;&\@8V]M92!R97!O<G0N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY.`IM
M<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O(@IM<V=S='(@(D1E=FD@:6YS97)I<F4@;"=54DP@86QL82!Q
M=6%L92!P=6YT82!Q=65S=&\@8V]L;&5G86UE;G1O(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`B1&5V:2!S96QE>FEO
M;F%R92!U;B!S97)V97(@9&$@96QI;6EN87)E+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B1&5V:2!S<&5C:69I8V%R92!U;B!U=&5N
M=&4@9&$@87IZ97)A<F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED
M(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G
M<W1R(")$979I('-P96-I9FEC87)E('5N('5T96YT92!D82!R:6UU;W9E<F4N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@=6X@=71E
M;G1E(&1A(&%G9VEU;F=E<F4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@=6X@=71E;G1E(&1A(&%G9VEO
M<FYA<F4N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN
M(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@=6XG87II;VYE(&1A(&5S96=U
M:7)E+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N
M(@IM<V=S='(@(D1E=FD@<W!E8VEF:6-A<F4@:6P@;F]M92!D96QL82!N=6]V
M82!C871E9V]R:6$N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S
M;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L
M:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R(")$979I(&EN<V5R:7)E('5N(&YU
M;65R;R!D:2!T96QE9F]N;R!I=&%L:6%N;R(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N
M(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(DQA
M('1U82!S97-S:6]N92`E<R#H('-C861U=&$N(%-I('!R96=A(&1I(&-O;&QE
M9V%R<VD@;G5O=F%M96YT92XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(DEL('1U;R!I;F1I<FEZ>F\@16UA:6PB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C$U"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@
M(DEL(&-A;7!O($1A.B!D96P@='5O(&EN9&ER:7IZ;SHB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B3&4@='5E
M(&EN9F]R;6%Z:6]N:2(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+B(*;7-G<W1R("(B"B));"!T=6\@:6YD:7)I>GIO($EN=&5R
M;F5T(.@@8V%M8FEA=&\@9&%L;"=I;FEZ:6\@9&5L;&$@='5A('-E<W-I;VYE
M("5S+B!097(@(@HB<')O=&5G9V5R92!L82!T=6$@<VEC=7)E>GIA+"!D979I
M(')I8V]L96=A<G1I(&YU;W9A;65N=&4N(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("))
M;"!T=6\@3F]M92(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"B));"!T=6\@8F%C:V5N9"!D:2!A=71E;G1I8V%Z:6]N
M92!N;VX@<W5P<&]R=&$@;"=A9V=I=6YT82!D:2!N=6]V:2!U=&5N=&DN(%-E
M("(*(G9U;VD@=7-A<F4@2&]R9&4@<&5R(&=E<W1I<F4@9VQI('5T96YT:2P@
M9&5V:2!U<V%R92!U;B!B86-K96YD(&1I("(*(F%U=&5N=&EC87II;VYE(&1I
M9F9E<F5N=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC
M.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*
M(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS
M9W-T<B`B(@HB26P@='5O(&)A8VME;F0@9&D@875T96YT:6-A>FEO;F4@;F]N
M('-U<'!O<G1A(&PG96QE;F-O(&1E9VQI('5T96YT:2P@;R!L82`B"B)F=6YZ
M:6]N92#H('-T871A(&1I<V%B:6QI=&%T82!P97(@86QT<F4@<F%G:6]N:2XB
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@
M<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB
M"FUS9W-T<B`B(@HB4V5M8F9R82!C:&4@:6P@='5O(&)R;W=S97(@<VEA(&-A
M;6)I871A(&1A;&PG:6YI>FEO(&1E;&QA('1U82!S97-S:6]N92`E<RX@(@HB
M4&5R('!R;W1E9V=E<F4@;&$@='5A('-I8W5R97IZ82P@9&5V:2!A8V-E9&5R
M92!N=6]V86UE;G1E+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS
M9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N(@IM<V=S='(@(DEL('1U;R!B<F]W<V5R(&YO;B!S=7!P;W)T82!Q=65S
M=&$@9G5N>FEO;F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N
M:G,Z-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M("(*(G1O('!R:6YT+B(*;7-G<W1R("(B"B));"!T=6\@8G)O=W-E<B!N;VX@
M<W5P<&]R=&$@<75E<W1A(&]P>FEO;F4@9&D@<W1A;7!A+B!0<F5M:2!#;VYT
M<F]L+T-O;6UA;F0@(@HB*R!0('!E<B!S=&%M<&%R92XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C8Q"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM92!Z
M;VYE.B(*;7-G<W1R("));"!T=6\@9G5S;R!O<F%R:6\Z(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M(&AA<R!B965N(&-H86YG960N(@IM<V=S='(@(DQA('1U82!I9&5N=&ETX"!D
M:2!D969A=6QT(.@@<W1A=&$@;6]D:69I8V%T82XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M(@IM<V=S='(@(DQA('1U82!I9&5N=&ETX"!D:2!D969A=6QT.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE
M.B(*;7-G<W1R("));"!T=6\@;F]M92!C;VUP;&5T;SHB"@HC.B!L:6(O2&]R
M9&4O075T:"YP:'`Z.3DY"FUS9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+B(*;7-G<W1R("),82!T=6$@;&]G:6X@Z"!S8V%D=71A+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B3&$@
M='5A(&YU;W9A('!A<W-W;W)D('!E<B`E<R#H.B`E<R(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(DQE('1U92!O<'II;VYI('-O;F\@<W1A=&4@86=G:6]R;F%T
M92!P97(@;&$@9'5R871A(&1I('%U97-T82!S97-S:6]N92XB"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA
M=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("),92!T=64@;W!Z:6]N:2!S;VYO
M('-T871E(&%G9VEO<FYA=&4N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B3&$@='5A('!A<W-W;W)D(.@@<W1A=&$@87IZ97)A=&$B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A
M;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@
M(B(*(DQA('1U82!P87-S=V]R9"#H('-T871A(&%Z>F5R871A+"!C;VYT<F]L
M;&$@;&$@='5A(&5M86EL(&4@86-C961I(&-O;B!L82!T=6$@(@HB;G5O=F$@
M<&%S<W=O<F0N(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM<V=I9"`B
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B3&$@='5A('!A
M<W-W;W)D(.@@<V-A9'5T82XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@
M(DD@='5O:2!S97)V97(@<F5M;W1I.B(*"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4T"FUS9VED(")9
M=6=O<VQA=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-@IM<V=I9"`B6F%M
M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-3<*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M6TYA<V-O;F1I(&EL('1E<W1O(&-I=&%T;UTB"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");
M4F5P;W)T(&1E;"!P<F]B;&5M85TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@
M+2(*;7-G<W1R(");36]S=')A(&EL('1E<W1O(&-I=&%T;R`M(@H*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L
M('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN
M97-=(@IM<V=S='(@(EM-;W-T<F$@:6P@=&5S=&\@8VET871O("T@)7,@;&EN
M965=(@H*(SH@;&EB+TAO<F1E+G!H<#HR,#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(EML:6YE82`E<R!D:2`E<UTB
M"@HC.B!L:6(O2&]R9&4N<&AP.C$U-30@=&5M<&QA=&5S+W!O<G1A;"]M96YU
M+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!;6UI
M;FES=')A>FEO;F4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G
M<W1R(")?0V%N8V5L;&$@4FEG82(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I
M9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<'!I(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B7T%I=71O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")P<F]P
M<FEE=.`@9&5L;"=?26UM86=I;F4N+BXB"@HC.B!L:6(O2&]R9&4O365N=2YP
M:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(E]%;G1R82(*"B,Z(&QI
M8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(E]%<V-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T
M<B`B7TUO9&EF:6-A($-O;&QE9V%M96YT;RXN+B(*"B,Z(&QI8B](;W)D92]-
M96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<'II;VYI
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B7U!E<FUE<W-I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B7T5L:6UI;F$@0V]L;&5G86UE;G1O+BXN(@H*(SH@;&EB
M+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B7TEM<&]S=&%Z
M:6]N92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS
M9W-T<B`B4')O<')I973@(&1E;&QA(%]486)E;&QA+BXN(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B571E;G1I(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C4*;7-G:60@(F%D9')E<W,@8F]O:R(*
M;7-G<W1R(")R=6)R:6-A(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W;B(*;7-G<W1R(")I;F1I
M<FEZ>FD@<V-O;F]S8VEU=&DB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDQ
M-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B8V%L96YD87)I;R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U
M"B,L('!H<"UF;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6\B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS9W-T<B`B;F]N('!O<W-O(&-R96%R
M92!I;"!F:6QE(&1I(&]U<'5T(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G
M92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R(")N
M;VX@<&]S<V\@87!R:7)E(&PG:6YP=70B"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z-C`P"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(G!R
M96UI('%U:2(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM
M<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@(F5R<F]R
M92!N96QL)W5S;R!D96QL82!L:6YE82!D:2!C;VUA;F1O(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N
M(&5R<F]R(@IM<V=S='(@(F5R<F]R92!D:2!C;VYF:6=U<F%Z:6]N92(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(F5R<F]R92!N96P@9F]R;6%T;R!D96QL82!D871A(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*
M;7-G<W1R(")P=6)B;&EC82(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(F5N=')Y
M(&YO;B!T<F]V871A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S,*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.C@Y-@IM<V=I9"`B9FEL92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X,2!L:6(O0FQO8VLO;65T87(N
M<&AP.C,V-R!L:6(O0FQO8VLO;65T87(N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(F1A
M;"`E<R`H)7,I(&%L("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4P"FUS9VED(")H.B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S4Y"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM
M<V=S='(@(FYO;64@:&]S="!S8V]N;W-C:75T;R(*"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R(")I;6UE
M9&EA=&\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U
M<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T
M<'5T(&5R<F]R(@IM<V=S='(@(F5R<F]R92!D:2!I;G!U="]O=71P=70B"@HC
M.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-#8*;7-G:60@(FEN=&5R
M;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(F5R<F]R92!I;G1E<FYO(&1E
M;"!S;V9T=V%R92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$S"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B;&EN965=(@H*(SH@
M;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)
M4T\N(@IM<V=S='(@(F5R<F]R92!D:2!C;V1I8V4@)60@9&D@;6MI<V]F<R!D
M=7)A;G1E(&QA('-C<FET=&]R82!)4T\N(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR.#4@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W-`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C0S"FUS9VED(")N86UE(@IM<V=S='(@(FYO;64B"@HC.B!L:6(O2&]R
M9&4O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R
M(")N;VX@:6UP;&5M96YT871O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@
M(FYO;B!A;F-O<F$@:6UP;&5M96YT861O(@H*(SH@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B8FQO8V-O(&YO=&4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!E<F-E;G1O(@H*(SH@
M;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S
M:6]N(&1E;FEE9"(*;7-G<W1R(")P97)M97-S;R!N96=A=&\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS
M9VED(")P:7AE;',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB
M"FUS9W-T<B`B97)R;W)E(')E;6]T;R!N96P@<')O=&]C;VQL;R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")R
M:7-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP
M:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@(G-E
M<G9I>FEO(&YO;B!D:7-P;VYI8FEL92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(FUO
M<W1R82!L92!D:69F97)E;GIE(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#<*;7-G:60@(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<T"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
M8V]S=&%N=&4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3`*
M;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R(")E<G)O<F4@9&D@<VES=&5M
M82(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3,S"FUS9VED(")T87-K(&QI
M<W0B"FUS9W-T<B`B96QE;F-O(&%T=&EV:73@(@H*(SH@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*
M;7-G<W1R(")G=6%S=&\@=&5M<&]R86YE;R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(G-C<FEV
M:2!L82!P87-S=V]R9"!D=64@=F]L=&4@<&5R(&-O;F9E<FUA<F4B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW
M.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")U;FEF:6-A=&\B"@HC.B!L:6(O
M2&]R9&4O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R
M(")S96YZ82!N;VUE(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C,@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0IM
M<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B=71E;G1E('-E;&5Z:6]N871O
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I
M9"`B=D-A<F0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VAO<F1E+G!O=```````````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#4W-3$V
M,2`Q,#4Q-30S-#$T,B`P,C`P,30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````(R!33TU%($1%4T-225!4259%(%1)5$Q%+@HC
M($-O<'ER:6=H="`H0RD@645!4B!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE
M(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE
M(%!!0TM!1T4@<&%C:V%G92X*(R!&25)35"!!551(3U(@/$5-04E,0$%$1%)%
M4U,^+"!914%2+@HC"B,L(&9U>GIY"FUS9VED("(B"FUS9W-T<B`B(@HB4')O
M:F5C="U)9"U697)S:6]N.B!004-+04=%(%9%4E-)3TY<;B(*(E)E<&]R="U-
M<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E
M871I;VXM1&%T93H@,C`P-BTP-RTS,2`Q.#HQ,BLP,C`P7&XB"B)03RU2979I
M<VEO;BU$871E.B!914%2+4U/+41!($A/.DU)*UI/3D5<;B(*(DQA<W0M5')A
M;G-L871O<CH@1E5,3"!.04U%(#Q%34%)3$!!1$1215-3/EQN(@HB3&%N9W5A
M9V4M5&5A;3H@3$%.1U5!1T4@/$Q,0&QI+F]R9SY<;B(*(DU)344M5F5R<VEO
M;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M0TA!4E-%5%QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,X-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(S.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E
M<R!D87ES*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,SDQ"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,SDS"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Y"FUS9VED
M("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S4P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.38*;7-G:60@
M(B!A="`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HR,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L
M:60@8VAO:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O4F5G:7-T<GDN<&AP.C<P-PHC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O
M4F5G:7-T<GDN<&AP.C$P.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E
M<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO
M=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($M"(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I
M;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS
M(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0U,"!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4Q-@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X.2!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<V,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E
M861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-C$@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C<@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-#$*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#<@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@
M)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O('!E<F9O
M<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX@
M0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N
M="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(X.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HQ,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34R"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.30T"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HY,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G
M<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z.38P"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA
M:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I
M;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S
M;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,U-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,SDY"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DP(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU"B,L
M('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HW-#@*;7-G:60@(BTM
M('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T
M(&AO=7)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP
M:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.30T"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3<W"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,3`X"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`R-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-($QI9VAT(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3(*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,30*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B04TO4$TB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I
M9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M:&5L<"]I;F1E>"YP:'`Z-30*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*
M;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(X
M,0IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3,U"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B
M06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(S,2!A9&UI;B]G<F]U
M<',N<&AP.C(S,@IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC
M.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C0V"FUS9VED(")!9&0@365M8F5R<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U
M<',N<&AP.C(R-0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H
M:6QD+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R
M;W5P('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T
M(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM
M<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D
M9')E<W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4V"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES
M=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$Q-PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,PIM<V=I9"`B061S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B06QG97)I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z-C8*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O
M=7!S+G!H<#HR,C@*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X.0IM<V=I
M9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S$*;7-G:60@(D%L;&]W('-E='1I;F<@
M;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C4P-PIM<V=I9"`B06QR96%D
M>2!E>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-@IM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-`IM<V=I9"`B06QT97)N871E
M($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C0Y-@IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S8*;7-G
M:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA
M=&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E
M>'0Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@
M(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I9"`B06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS
M9VED(")!;F=O;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B06YG
M=6EL;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B06YO;GEM;W5S(%!R;WAY(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED(")!;G-W97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO
M<&AP<VAE;&PN<&AP.C,V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP
M:'`Z-3@@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,SD*;7-G:60@(D%P<&QI8V%T
M:6]N(&ES(')E861Y+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C(Q.0IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T,@IM<V=I9"`B07!P<F]X:6UA=&4@
M4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ
M,C4V*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW
M.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U
M960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!4DU3
M0TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%R
M=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,C(*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!
M<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@S"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I
M9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U
M<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G
M:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W
M:71C:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HV,`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P
M.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@
M(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T
M;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,S@U"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O
M(')E;6]V92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?
M;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H
M7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C
M=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@
M34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#,*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@Y-`IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE
M(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A
M:6IA;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*
M;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"
M86-K9W)O=6YD(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG<F]U;F0@0V]L;W(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@
M:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G
M:60@(D)A:&%M87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM
M<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S
M"FUS9VED(")"87-E;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I
M=6TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F
M(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY,`IM<V=I9"`B0FQO8VL@
M4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B
M0F]L9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#<*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P
M"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)R87II;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE
M=&5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN
M82!&87-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-@IM
M<V=I9"`B0TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED
M(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN:70@=V%S
M(&YO="!C;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.30R(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3`@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM
M<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M
M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#
M86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S
M-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0T-"!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,S4*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV-S4@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(R,@IM<V=I9"`B0V%N;F]T
M(&-O<'D@9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H
M92!S86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C4Q,"!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,#4*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-3$@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$X-PIM<V=I9"`B0V%N;F]T(&UO
M=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E
M=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M97=O<FLO1&%T
M851R964O1&%T851R964O<W%L+G!H<#HV.#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8Q
M,0IM<V=I9"`B(@HB0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B
M"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C(Q"FUS9VED(")#86YN;W0@<F5S970@<&%S<W=O<F0@875T;VUA
M=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!W<FET
M92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*;7-G:60@(D-A<'1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?
M<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,PIM<V=I9"`B0V%T96=O<FEE<R!A;F0@
M3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM
M<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN
M9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(W
M-`IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!0
M87-S=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-CD*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@
M(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N
M86P@*$)I9S4I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B
M0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA
M;64B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y-0IM
M<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C(R"FUS9VED(")#:&]O<V4@;&ES="!S='EL92!T>7!E("AF;W(@
M;W)D97)E9"!L:7-T<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,N<&AP.C(Y-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3`U"B,L
M('!H<"UF;W)M870*;7-G:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I
M9"`B0VQE87(@35-/9F9I8V4@=&%G<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q"FUS9VED(")#
M;&5A<B!U<V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,T"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*
M;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K
M('1O($-O;G1I;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L
M;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L
M;W-E(%=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(T-@IM<V=I9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9',@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#
M;VQL87!S92!3:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA
M<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O
M;&]M8FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@
M;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP
M:'`Z,S,X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,SD*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4P,R!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED
M(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3DV-`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#
M;VUI8W,B"FUS9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(V"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C<*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED
M(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;VYD:71I;VYS(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.CDS"FUS9VED(")#
M;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,S0*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@
M;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I
M9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HR,#0*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S0W"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T-PIM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3D*;7-G:60@(D-O;FYE8W1I;VX@<F5F
M=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.#`Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#@X"FUS9VED(")#;VYN96-T:6]N('1O
M($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDU,"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`W
M-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL
M93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,"!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O
M;VMI92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.#D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@
M(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY.#8*;7-G:60@(D-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`V-`IM<V=I9"`B0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M.38@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C`*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C0X,@IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V-@IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$S-PIM<V=I9"`B
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U
M;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDV
M,@IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HT-S@*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q
M-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C8Y.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O3V)J96-T+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C@V"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,S`U"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z-#$T"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C0R,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HT,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE
M=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I
M;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(P-`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HR,C0*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(X"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P
M=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N
M=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8S"FUS9VED(")#;W5L
M9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@
M<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-34*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*;7-G:60@(D-O=6YT
M960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDV"FUS9VED(")#
M<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET
M(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#
M<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G
M:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U
M<G)E;G0@55),(&ES(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V-`IM
M<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#
M=7)R96YT('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*
M;7-G:60@(D-U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B0WER:6QL:6,@
M*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#8*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(Y,`IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R
M;W=S97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S(X.`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q-@IM<V=I9"`B1&%T92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I
M9"`B1&%T92!296-E:79E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Q(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(D1A>2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS
M9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I
M;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C<W"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R])9&5N=&ET>2YP:'`Z.3@*;7-G:60@(D1E9F%U;'0@261E
M;G1I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<U
M"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R
M,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-S$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY-"!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$T,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,PHC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L
M971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,0IM
M<V=I9"`B1&5L971E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E
M($-E;&PB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#4@861M
M:6XO9W)O=7!S+G!H<#HR,S,*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3$*;7-G:60@
M(D1E;&5T92!,;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HW-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P
M,0IM<V=I9"`B1&5L971E(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E
M;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I
M9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T
M.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T
M+G!H<#HU-`IM<V=I9"`B1&5L971E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L
M('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E
M<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W
M"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD
M97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R
M;V)L96TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,C`V"FUS9VED(")$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E
M;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q.0IM
M<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,CDV"FUS9VED(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*
M;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO
M;B!L969T('1O(')I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R
M:6=H="!T;R!L969T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(V,@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I
M;65S/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`P
M"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I
M;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I9"`B1&ES
M<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R"FUS
M9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L
M9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA
M=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS9VED(")$;W=N;&]A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S
M+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V,0IM<V=I9"`B
M1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R
M-0IM<V=I9"`B1')O<"!D;W=N(&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M
M36%I;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@
M9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I
M8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@IM<V=I9"`B161I="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P"FUS
M9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,C`T"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,W"FUS9VED(")%
M9&ET(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M
M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%
M9'5C871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@X-PIM<V=I9"`B16UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C8@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.#$*;7-G:60@(D5M86EL(&%D
M9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#`W"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(Y.0IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM
M<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP
M='D@<F5S=6QT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,`IM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4Q-0IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N
M=3\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8P
M-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$Q"FUS9VED(")%;F0@>65A
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C$V"FUS9VED("(B"B)%;G1E
M<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D
M(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@
M)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L
M86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C@Y,@IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@8F5L;W<Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5R:71R96$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+U9I97<N<&AP.CDR(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT.`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V"FUS9VED(")%<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP
M.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C
M:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN
M8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`U
M"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S-@IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@V"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S,R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@T"FUS9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-PIM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@
M(D5V97)Y($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS,S<*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#4*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V
M86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,B!A
M9&UI;B]C;61S:&5L;"YP:'`Z-3$@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM
M<V=I9"`B17AE8W5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ
M-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP
M:7)A=&EO;B!$871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<V"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP
M.C(R-0IM<V=I9"`B1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<R-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3(S(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S8W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HT.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F%I<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-
M86QV:6YA<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z
M,C0P"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*
M;7-G:60@(D9A>&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,@IM<V=I9"`B1F5E;',@
M3&EK92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C(*;7-G
M:60@(D9I96QD(&UA=')I>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,S0S"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S0W"FUS9VED(")&
M:6=L970@9F]N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-PIM<V=I9"`B1FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y.34*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDP,`IM<V=I9"`B1FEL92!U
M<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HY,0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C4W"FUS9VED
M(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S,@IM<V=I9"`B1FQI<"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,R"FUS9VED(")&;&]A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B1F]G(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@P(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@
M(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I
M9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,S8*;7-G:60@(D9O
M<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T
M:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N
M9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C0*
M;7-G:60@(D9O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U
M;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0IM
M<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#4U"FUS9VED(")&;W)U;7,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B
M1G)A;65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*
M;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS9VED(")&
M<F5E>FEN9R!$<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@
M(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM
M<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C,W(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O
M;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,3<V"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S
M"FUS9VED(")'86)O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A
M;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR
M.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG
M=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O
M8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=H86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I
M8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<Y('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$Y
M"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$Q,S$*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#@*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$X-0IM<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,S@@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C0Q(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S$T"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<X"FUS9VED(")'<F]U<',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,C(V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#D*;7-G:60@(D=U97-T(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R
M96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN
M(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B
M;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP
M:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G
M:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED(")(87IE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3,R"FUS9VED(")(96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV
M,0IM<V=I9"`B2&5A9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-0IM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C(R('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G
M:60@(DAE:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O2&5L<"YP:'`Z,3@T(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H
M<#HQ.#8*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-2!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I
M;F1E>"YI;F,Z-`IM<V=I9"`B2&5L<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP
M('5S:6YG(&5D:71O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(96UI<W!H97)E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")(:6=H(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T
M97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC
M86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"FUS9VED
M(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(
M;W)D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDV"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C0W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E
M<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z
M(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG
M(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HU,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,C@R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S8X
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C,V-@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM
M<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ
M;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E
M/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B
M2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<R(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,Q-@IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I
M=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I
M9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,W,PIM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S0*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@U"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C8P,`HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT-3(*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A
M9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D
M(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L
M;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@
M)60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T960@9FEE;&0Z("5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G
M:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,P"FUS9VED
M("));E]S97)T(%)O=R!!9G1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S0*;7-G:60@(DEN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN
M8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4S"FUS9VED("(B"B))
M;F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E
M($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,U"FUS9VED("));F1I
M=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B
M26YD;VYE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q.0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET
M+FEN8SHS-0IM<V=I9"`B26YH97)I=&5D($UE;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS
M9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E
M8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU
M;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S0*;7-G:60@(DEN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@
M8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O
M;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L
M=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R-0IM<V=I9"`B
M26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U
M97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O
M('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@
M(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT
M96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N
M("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0
M(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS
M-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R
M"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q-S8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S
M=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O
M<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38U"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y"FUS9VED("))
M;G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G
M:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS
M9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N
M97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-C,*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF
M;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3$W(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(Y-PIM<V=I9"`B26YV86QI9"!S:&%R
M92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C
M92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI
M8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.`IM<V=I9"`B
M26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*
M;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))=&%L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA
M;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B
M2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(V-0IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED
M(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B
M2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T"FUS
M9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")+97D@3&5N9W1H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW-#`*
M;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S
M"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E
M82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B2V]R
M96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B
M2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ
M<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y
M"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C@X"FUS9VED("),87-T(%!A<W-W;W)D($-H86YG92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3,*;7-G:60@(DQA<W0@57!D871E9#HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W"B,L
M('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-`IM<V=I9"`B3&%S="!L;V=I
M;CH@3F5V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V
M:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS
M9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE9G0@
M=F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H
M;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR
M-3<*;7-G:60@(DQE=F5L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&EB97)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI
M8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!$
M<FEZ>FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"FUS
M9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,R"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,PIM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#$T"FUS9VED("),:6YK(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,3<*;7-G:60@(DQI;FL@55),
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,S(*
M;7-G:60@(DQI;FL@86-C97-S(&ME>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G
M:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#(S"FUS9VED("),:6YK('1A<F=E="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(P"FUS9VED("),
M:6YK('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@Y,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@
M8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(Y"FUS9VED("),:6YK('1I=&QE
M(&%T=')I8G5T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT
M97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI
M;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T
M:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,S0*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED("),:7-T($AE;'`@5&]P:6-S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@
M(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O2&5A9&5R<RYP:'`Z-C`Q"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C8P,PIM<V=I9"`B3&ES="U)9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y.0IM
M<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C8P,`IM<V=I9"`B3&ES="U0;W-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DX
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-PIM<V=I9"`B3&ES="U5;G-U
M8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z
M("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR
M"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA
M9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("),;V-A;"!T
M:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@V
M"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C4W"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED("),;V-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!L;V=I;BYP:'`Z,3@Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR,#0@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.CDP"FUS9VED("),;V<@:6XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0W"FUS9VED("),;V<@;V8@<')E=FEO
M=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ.3@*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q"FUS9VED("),;V=I;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),
M;V=I;B!487-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,0IM<V=I
M9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C<Q"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W
M97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),
M;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@
M(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.2!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(X,PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B
M35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.#,*;7-G:60@(DUA:6PB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM<V=I9"`B36%I;"!!9&UI;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA;'1A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-38*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$W,0IM<V=I9"`B36%P475E<W0@
M;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B
M36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C0X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS
M9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@
M(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I
M;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED
M(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,#`*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$X,0IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@
M4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE
M;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<*;7-G:60@(DUA>6]T=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-
M96UB97)S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S4*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B
M365R9V4@8V5L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3<*;7-G:60@(DUE<W-A9V4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G
M92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,PIM
M<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q.0IM<V=I
M9"`B(@HB365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U,PIM<V=I9"`B
M365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q(&9R
M86UE=V]R:R]24$,O4E!#+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M
M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C8W(&QI8B]";&]C:R]M971A<BYP:'`Z.#(*;7-G:60@(DUE=')I8R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S$R"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#0*;7-G:60@
M(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A
M<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G
M:60@(DUI<G)O<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS
M9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*
M(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE
M:71A;'E?<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<R"FUS9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B36]D:69I960@
M1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M-S0*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;F%C;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V,#(*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HS(&QI8B]";&]C:R]M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,3DV(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(X,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-@IM<V=I9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B36]S
M=&QY($-L;W5D>2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(DUO<W1L>2!3
M=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8T.`IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z-C4R"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-38*;7-G:60@
M(DUO=F4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-#0*;7-G:60@(DUO=F4@57`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C4R-@IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C4*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B36]V
M92!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ
M=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(P
M,@IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ
M,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,`IM<V=I9"`B375L=&EP;&4@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#(*;7-G:60@(DUY($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-#0*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z-#(*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL
M.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS
M9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A
M<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I
M;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,PIM<V=I9"`B
M3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E
M(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S,R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#,*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D
M;VYI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T
M96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@
M(DYE=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S
M=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?
M8FQA;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M
M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*
M;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#8*;7-G:60@(DYE
M>'0^(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI
M9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38V"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN
M9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H
M('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-PIM<V=I9"`B3F\@8FQO
M8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-3$*
M;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<X(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$Q"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<Y,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#8W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HW,C<*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-S<R"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*
M;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDQ.`IM<V=I9"`B3F\@9FEL92!U
M<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z
M-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,`IM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34W"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A9V4@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@
M;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P,`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M87-L+G!H<#HW-R!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<#HX-`HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]S;6(N<&AP.C@T"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#<*;7-G:60@(B(*(DYO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3(#$R(&1A
M=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,PIM<V=I9"`B3F\@<75O
M=&$@<V5T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#(*;7-G
M:60@(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*
M;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-C`Y"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-@IM<V=I9"`B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M('-E;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P
M8RYP:'`Z,30V"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`Q,@IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,3D*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@
M:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3(W"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDU"FUS9VED(").
M;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DYO
M<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM
M<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R
M=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C0P"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R-`IM<V=I9"`B3F]T(&$@9&ER96-T
M;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C,T.`IM<V=I9"`B3F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30X
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3<X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,3DR"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,W(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HQ.3,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S.2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#,@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,S(*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,T-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8T
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS.3<@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C0U-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3,V(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV,#4*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C8R,@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-`HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I
M<W0Z,3`V."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED(").
M;W1E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP
M:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E
M<B!O9B!C:&%R86-T97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@
M8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@
M=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I
M9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$R"FUS9VED(")/8FIE8W0@
M0W)E871O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@
M(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C@*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@
M;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"FUS9VED(")/;&0@
M<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C0V"FUS9VED(")/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3VUA;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(V"FUS9VED(")/
M;F-L:6-K(&5V96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DX.0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C0R"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@
M9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,34U"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R
M9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,T"FUS
M9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T
M92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@
M<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S-`IM<V=I9"`B3W1H97(@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,@IM<V=I9"`B3W=N97(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(X-0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,S$*
M;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S@S"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S8U"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B
M4$A0($-O9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P
M"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*;7-G:60@(E!-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G
M:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4$T@4W5N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0V"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z,C@V"FUS9VED(")03U-)6"!E>'1E;G-I;VX@
M:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HR,34*;7-G
M:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R
M>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")0
M86YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.
M97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A
M<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S8*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S
M=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,3,R,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S$*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C$Q"FUS9VED(")087-S=V]R9#H@(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#4R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I
M9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#,*;7-G:60@(E!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HU,@HC+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N
M;W0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HV,3(*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X
M+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED(")097)M
M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#@*
M;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM
M<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G
M:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H
M:7,@96QE;65N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C4X,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@
M>65A<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A
M;&ED($E0(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(V-3@*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A
M=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-C4*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S
M92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R96%D('1H
M92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R
M;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED
M(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X.0IM<V=I
M9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R
M='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-C@@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E
M<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP
M:'`Z,3`T"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R-PIM<V=I9"`B4')E<W-U
M<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C$*;7-G
M:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C0*;7-G:60@(E!R97-S=7)E
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A
M(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B
M4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y"FUS
M9VED(")0<F]B;&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0<F]J
M96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,3(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,#8*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(Y-`IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS
M9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B
M4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F
M=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O
M(%)I8V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C-#,Q-"YP:'`Z-34*;7-G:60@(E!U<F=E(&UE<W-A9V5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1=6]T82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8V-`HC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@
M8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C@R"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#D*;7-G:60@
M(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3$*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E)A:6X@
M=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,0IM
M<V=I9"`B4F5A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HT-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@
M;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@
M(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-"!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR,3`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0X
M"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.#@*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE
M;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X
M"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"FUS
M9VED(")296=E>"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#0@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C$P"FUS9VED(")296QO860B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C@*;7-G:60@(E)E;6%R
M:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM
M<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")2
M96UO=F4@0FQO8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C0P"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M
M;W9E('!A:7(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C(P,0IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I
M9"`B4F5M;W9E('1H92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V
M92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M
M;W9E('5S97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C$T-`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$T-0IM<V=I9"`B4F5Q=65S=&5D('-E<G9I
M8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$X-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C<S,R!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@W,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S<X"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB
M)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HX,#`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@
M:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]296YD97)E<BYP:'`Z,S,V"FUS9VED(")297%U:7)E9"!&:65L
M9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S(Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")2
M97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HT.`IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C@*;7-G:60@(E)E<V5T(%EO=7(@
M4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S
M,0IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W!H<'-H96QL+G!H<#HW,B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M
M:6XO<W%L<VAE;&PN<&AP.C8W"FUS9VED(")297-U;'1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S
M+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS
M9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS
M9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG
M:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R
M,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3<*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Y"FUS9VED
M(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R
M;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*
M;7-G:60@(E)U;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I
M;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@
M(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN
M9R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,CDR"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K
M=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M,S,*;7-G:60@(E-32"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I
M8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,U"FUS
M9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C(Q.0IM
M<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@3F5V
M:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R
M<F4@86YD($UI<75E;&]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0<FEN8VEP92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I
M9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.0IM<V=I9"`B4V%V92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C4W"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,C$W"B,L('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-C8*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R"FUS9VED(")3
M96%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-0IM
M<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$Y.0IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@
M861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-#0*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A
M('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$U-PIM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W
M-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-C8Q"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M
M<&]N96YT<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<W"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E
M;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(E-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*
M;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`S"FUS9VED(")396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-#0*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P-#(*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,3@*;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C(Q,0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,S,@IM<V=I9"`B
M4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM
M<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@
M<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS9VED(")3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E="!Y;W5R('-T87)T=7`@
M87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A
M;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED(")3971U<"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED
M(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T
M97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L
M;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M.3@*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#,*;7-G:60@
M(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R
M-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY
M,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,`IM<V=I9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,34T"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.#<*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG
M:6YA;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#$S"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3(S"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO
M;G,@;65N=2!B87(_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W
M('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2
M;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED
M(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8S"FUS9VED(")3:&]W
M('5P;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I
M9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VAO=V5R<R!,871E
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4W"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C8Q.0IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U
M.`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$Q,C`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N
M96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C8*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA='5R92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q
M,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#0@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C8T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`U"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N
M;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8R"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X,`IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@T"FUS
M9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E
M;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR
M-@IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N
M9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P
M"FUS9VED(")3<&%M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V
M"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B
M4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM
M<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N<&AP.C@Q"FUS9VED
M(")3=&%N9&%R9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C`T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R
M(%!R;W9I;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F
M;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(S,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Y,0IM<V=I9"`B
M4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X
M,C(N<&AP.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3@*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S
M:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-0HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X
M"FUS9VED(")3=6-C97-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R
M96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL
M>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG
M97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*;7-G
M:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B4W5N;GDB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-0IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U
M;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS
M970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(P-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S
M8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V
M"FUS9VED(")3=7)I;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=V5D96XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED
M(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN
M('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED
M(")3>7)I86X@07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R
M;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV-0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*
M;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED(")4+5-T;W)M<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z
M,3<P"FUS9VED(")44U8@9FEL92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")4
M86)L92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDU."!C;VYF:6<O:&]O:W,N
M<&AP+F1I<W0Z,3`U.0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y
M"FUS9VED(")487-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W-`IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B
M5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,38*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3(*;7-G:60@(E1E
M;7!E<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(X,@HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R
M93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-CDU"B,L('!H<"UF
M;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP
M;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M-#4*;7-G:60@(E1E>'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W,@IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S0*
M;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C,*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@
M2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.38T"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G
M(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C,Q"FUS9VED(")4:&4@36%I;G1E;F%N
M8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G
M:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$Y,"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(P,0HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(Q,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R
M-`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,N<&AP.C(U,PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C(V-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P-`IM<V=I9"`B
M(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@
M8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE
M(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L
M86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3$*;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D
M960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q.#$*;7-G:60@(B(*(E1H92!D
M971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E
M<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED
M("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@
M9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X
M-B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I
M;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@
M<V5T=&EN9W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N
M<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H96%D97)S
M(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*
M;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A
M=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA
M>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O
M=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y
M>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L
M("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I
M9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O
M<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N
M(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA
M;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H
M92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE<W-A
M9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA<R!B
M965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#DU"FUS9VED
M(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z-#<T"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E
M<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+G!H<#HR.#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R969E<F5N8V4@7"(E<UPB(&-O
M=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H
M92`B"B)M87AI;75M(&%L;&]W86)L92!S:7IE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I
M;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R
M:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G
M:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-SD*;7-G:60@(E1H92!S97!A
M<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z
M-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S
M(&)E96X@<V%V960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL
M92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,C`*;7-G:60@(E1H92!T97AT('EO=2!E
M;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M('-I
M9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z
M,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T
M:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP
M:'`Z,3<V"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS9VED
M(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z,S0Y"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@
M9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R
M(&QE<W,@=&AA;B`E<RXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A
M9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F
M;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG
M(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.3(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U
M<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.CDS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N
M;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U"FUS9VED(")4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O:6UC+G!H<#HS,`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z.#(*;7-G:60@(B(*(E1H97)E('=A<R!A
M;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO
M=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M.`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T
M<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C(*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N
M(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.0HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR.3D*;7-G:60@
M(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@
M9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*;7-G:60@
M(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@
M*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z
M+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T
M:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N
M92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@
M(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4W"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S8@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#0W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.38*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,Y"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,C8@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0V.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C,@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S@S,0IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V
M-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#,T
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY.#D*;7-G:60@
M(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S-@IM<V=I9"`B(@HB
M5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!2
M1T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$*;7-G:60@
M(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@
M=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I
M<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C4Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A
M9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@
M=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A
M;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X-@IM
M<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R
M-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS
M9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME
M=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0T
M,R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-3<*;7-G:60@(E1I;64B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X.`IM
M<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-#D*;7-G:60@(E1I;64@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G
M:60@(E1I=&QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@
M<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@
M*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P
M,`IM<V=I9"`B5&]D87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@
M4V]U<F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS
M9VED(")4;VUO<G)O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4;VYG82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMO
M;&%B+G!H<#HQ,#0*;7-G:60@(E1O;R!M86YY(&EN=F%L:60@;&]G:6YS(&1U
M<FEN9R!T:&4@;&%S="!M:6YU=&5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G:60@
M(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A
M;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R
M:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U
M<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM
M<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,PIM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A
M='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C0R.`IM<V=I9"`B56YA8FQE('1O(&%C
M8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@
M97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDU"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HT,#$@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C0W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Y.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDW"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.CDT"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HV-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX.#(*;7-G:60@(E5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-#$@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C0V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M,S,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(S.`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C0V"FUS9VED(")5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HS-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S<P(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR-CD*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3(S"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C,P,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#$*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]T87(N<&AP.C<U"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]G>FEP+G!H<#HU,@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z.#(*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C,Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S`R"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0W(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#4P"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HS,C(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-#`S(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HT,#<*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4S(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,T-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S4T"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HT-S4@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Q.2!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,S-`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-SD*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z-#,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HT-#8*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#8T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#8*;7-G:60@(E5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B
M;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3$@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$V"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ.3@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(P,PIM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-S0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR.3,@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$U-PHC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38P"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#8@9G)A;65W;W)K
M+U9&4R]61E,O9FEL92YP:'`Z,30P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HY-0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@T
M,PIM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@
M9F%I;&5D*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@W.`IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*'-I>F4H*2!F
M86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T
M;R!R96%D(&9I;&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV.3$*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,30V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0R"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z,S@W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C@P(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S4P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,S(@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C,X,2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$R"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C,@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4V"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$X,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T92!F;W(@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-S@@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ.#$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3@Y"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.3<@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-0HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<P"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@U,PIM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P"FUS9VED(")5
M;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI
M;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R.`HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HT,C<*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-#$U
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C0R,0IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D
M($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI
M=&5D(%-T871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-S@*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N(&-L:6US9VED("A#;&EE
M;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N:VYO=VX@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O261E;G1I='DN<&AP.C,P-`IM<V=I9"`B56YN86UE9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%
M>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*
M;7-G:60@(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.`IM<V=I
M9"`B57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ.#4*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F
M:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED
M(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G
M:60@(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G
M:60@(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E
M<B!296=I<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HR,@IM
M<V=I9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R
M('1H:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C0Y-`IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<X"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS
M-`HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y
M(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,R!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR-S$*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU.3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C@T"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S,S0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED
M(")686QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$R-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C`T"FUS9VED(")6
M86QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@
M(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED
M(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R
M=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN
M9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S0*;7-G:60@
M(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6
M:65T($YA;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M-PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M:69R86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I
M;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$Q"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3(*;7-G:60@(E9I<VEB:6QI
M='DZ("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@
M=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO
M;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B
M5T%23B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))
M4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@
M2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@
M86YD($9U='5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C$R-R!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z.34*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM
M<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E
M871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM
M<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED
M(")796QC;VUE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.`IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C4*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,C4*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4T"B,L('!H<"UF;W)M870*;7-G
M:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E
M9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")7:6YD
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<P"FUS9VED(")7:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO
M=',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*;7-G
M:60@(E=I;F0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H
M;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*
M;7-G:60@(E=O<FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ.3,@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-0IM
M<V=I9"`B6"U2968B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A
M:6YT<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y-@IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@
M(EE965DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G
M:60@(EEE;65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM
M<V=I9"`B665S+"!)($%G<F5E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C(S-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H
M86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$T,34*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R])9&5N=&ET>2YP
M:'`Z,S$P"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.3,*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P
M(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R
M<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA=F4@8F5E
M;B!L;V=G960@;W5T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T
M:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R
M969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K
M96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0V-0IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HV
M,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@=&\@
M<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M86EL($%D9')E<W,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-PIM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*
M;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]N;V%D9"YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@
M=VES:"!T;R`B"B)U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U
M;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I
M;VX@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C4W"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,PIM<V=I9"`B66]U<B!C
M=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C$Q-PIM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B
M965N(&-H86YG960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ-3,*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y-@IM<V=I9"`B66]U
M<B!F=6QL(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY.0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HX,`IM<V=I9"`B(@HB66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HR,#,*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@
M(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ
M,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,C`S"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,C`T"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F
M("5S72(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@;&EB
M+V%P:2YP:'`Z,C(S"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C(P-PIM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,3DY"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@
M(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HR,#,*;7-G:60@(E]097)M:7-S:6]N<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ.3$*;7-G:60@(E]3971U<"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$Y-0IM<V=I9"`B7U5S97)S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.34Q"FUS
M9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G:60@(F%D9')E<W-E92!U;FMN
M;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.30S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HV,#`*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E
M<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B961I="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$X,@IM<V=I9"`B96YT<GD@;F]T(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<U"FUS9VED(")F
M86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@Y-@IM<V=I9"`B9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W-B!L:6(O0FQO8VLO;65T87(N<&AP.C,V,B!L:6(O
M0FQO8VLO;65T87(N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(U,`IM<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I
M9"`B:6UM961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C8T(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS9VED(")I;FQI;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B
M:6YT97)N86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S
M72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS
M-S`*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M-S0*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(T,PIM<V=I9"`B
M;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(T
M"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C(P"FUS9VED(")N;W0@>65T
M(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3,U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*
M;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@9&5N:65D
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B
M<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<W"FUS9VED(")R:7-I
M;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@
M9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V
M:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-@IM<V=I9"`B
M<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY-3D*;7-G:60@(G1A<VL@
M;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@
M=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-"!A9&UI;B]S971U<"]D:69F+G!H<#HW-@IM<V=I9"`B=6YI9FEE9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP.C(W
M"FUS9VED(")U;FYA;65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E
M<B!S96QE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0R"FUS
M9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P;R]M:U]-2RYP;P``````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`V,3$V-#8@,3`U,34T,S0Q-#(@
M,#$W-3(T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````",@=')A;G-L871I;VX@;V8@;6M?34LN<&\@=&\@36%C961O;FEA;@HC
M(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E
M;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC($-O<'ER:6=H="`H0RD@,C`P
M,R!%=7)E:V$@26YF;W)M871I:V$*(R!3=&]J86X@4&5S;W8@/'-S<$!E=7)E
M:V$N8V]M+FUK/BP@,C`P,PHC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!M:U]-2UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R
M,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P
M,#,M,#8M,C8@,34Z,3@K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!3=&]J
M86X@4&5S;W8@/'-S<$!E=7)E:V$N8V]M+FUK/EQN(@HB3&%N9W5A9V4M5&5A
M;3H@36%C961O;FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%
M+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C
M:&%R<V5T/4E33RTX.#4Y+35<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I
M;F<Z(#AB:71<;B(*(E@M1V5N97)A=&]R.B!+0F%B96P@,2XP+C%<;B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY
M97-T97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U
M"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H
M;VEC92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E
M9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HQ,#0R"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@X^'?U>C=WB#4WM30U-7=(-W0(.'8
MX>+5W-[B+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E
M)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O0V]N=&5N=',N<&AP.C@S,R!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@2T(B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VXB"FUS9W-T<B`B)7,@OM_5X-#FV-@@U]`@WM3@UN/2T/K5("T@
MO][BTN#4T"(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N(@IM<V=S='(@(K+:V^/GV"#0VMX@X=#:T.@@U-`@V-?2
MX.C8Z"#=U=K>V"#>W]7@T.;8V"#2WB#<WMS5W>+>TBXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M870*;7-G:60@(B5S
M(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C@V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(K#4
MX-7AT.`B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S
M(%1A<VML:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W
M:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R`B"B)A
M;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET
M:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C4@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C0Q,`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N
M<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F<F]M("5S('1O("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R
M.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y
M"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R
M;6%T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#GT.'0(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y"FUS9VED(")!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38P"FUS
M9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-C4*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U
M"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P
M=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S
M<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B
M04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PIM
M<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]0
M32(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T
M('1H:7,@961I=&]R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD
M97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!
M8G-B;W1T;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I
M9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C8V]U;G0@
M26YF;W)M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<U"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S
M='(@(K_>XM+@U-@@V][7V-W:T"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z
M96XN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,S,*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC
M.C$Q"B,L(&9U>GIY"FUS9VED(")!9&0B"FUS9W-T<B`BL-3@U>'0(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G
M:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`BM-[4T-38(-K>X-CAW=C:(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G
M:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ
M-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO
M;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*
M;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*;7-G<W1R("*TWM30U-@@W=[2(-K>
MX-CAW=C:.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HU-30*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`HC+"!F=7IZ>0IM<V=I
M9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(K3>U-#4V"#=WM(@VM[@V.'=
MV-HZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B
M061D('!A:7(B"FUS9W-T<B`BM-[4T-38(-_0X"(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E
M<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW,0HC+"!F=7IZ
M>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS9W-T<B`BL-3@U>'0
MX"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HW
M.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G
M<W1R("*PU.#5X=#@(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(K3>U-#4V"#:WN#8X=W8VB(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<
M(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L
M('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I
M9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB
M('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@
M(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`BM-[4T-+0^M7B
MWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BL-3@U>'0
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0HC+"!F=7IZ>0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(K#4X-7AT.`B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M
M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(K#4W-C=V.'BX-#FV/C0(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,T,0HC+"!F=7IZ>0IM<V=I9"`B061S(@IM<V=S='(@(K#4X-7AT"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QI
M87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(D%L:6%S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B06QI87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R(")!;&EA<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@
M(D%L:6=N;65N=#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C@W"FUS9VED(")!;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,#<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV-0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R
M,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D
M871A=')E92YP:'`Z-S4*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"FUS9VED(")!;')E861Y(&5X:7-T<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED
M(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY
M"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I
M9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`BLM#HT"!%;6%I
M;"#0U.#5X=`Z(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@
M(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(U"FUS
M9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF
M:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38W"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O
M>'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED
M(")!;G1A<F-T:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N
M=&EG=6$@86YD($)A<F)U9&$B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HW-"!A9&UI;B]P:'!S:&5L;"YP:'`Z,S4*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+U5)+G!H<#HU."!T96UP;&%T97,O861M:6XO<V5T=7`O
M:6YD97@N:'1M;#HV"FUS9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N
M($QI<W0B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T
M,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS
M9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B
M07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N
M<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I
M9"`B07)C:&EV92!.86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N
M>2!S=6(M9W)O=7!S/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M<F=E;G1I;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B07)M96YI
M82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I
M9"`B07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@
M(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R-0IM<V=I9"`B07-K
M(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3,*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M075S=')I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA
M<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($94
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M
M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E
M<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`R
M"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R
M=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S4W"FUS9VED(")!=71H7VQD87`Z
M(%)E;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L
M9&%P+G!H<#HV,PIM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,S,Y"B,L('!H<"UF;W)M870*;7-G:60@(D%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM
M<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B
M075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P"FUS9VED
M(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G
M:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(K3>X>+0W]W8(-_>V]CZ
MT#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U
M<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E3
M3RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG
M;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")"87-E(&=R87!H:6-S(&1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F5R;75D82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BP-[4U=W4U=TB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S
M"B,L('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A
M=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW
M-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K
M;6%R:W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R
M(@IM<V=S='(@(DAO<F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R
M(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G
M;W9I;F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV
M"FUS9VED(")";W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O
M='-W86YA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(K_>Z.+0(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED
M(")"=6QG87)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*(RP@9G5Z>GD*;7-G
M:60@(D--4R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-2
M3"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I
M9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38S"FUS9VED(")#86-H92!I;FET('=A
M<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N
M9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I
M9"`B0V%L96YD87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-@IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R:71E('1O(&9I;&4@7"(E
M<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I
M9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0
M('-E<G9E<CH@)7,B"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,
M1$%0(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!O<&5N(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP
M.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R("*^XMK0UM@@O^#>
MT=O5W"#`U=_>X.(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E
M9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M("*WT.?CTM#X(-[?YMC8(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E
M;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE
M<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#
M87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H;VYE(@IM
M<V=S='(@(KS>T=C;U=TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED(")#96QL(%!R
M;W!E<G1I97,B"FUS9W-T<B`BO-[1V-O5W2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED
M(")#96QL<&AO;F4B"FUS9W-T<B`BO-[1V-O5W2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<X"FUS9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L
M($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8Q,0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED(")#:&%N9V4B"FUS9W-T<B`BON+:
MT-;8(-/8(-_@WMS5W=CBU2(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B
M"FUS9W-T<B`BO][BTN#4V"#;WM?8W=K0(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E
M<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T
M;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA
M;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R('!A
M<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF
M:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U
M"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"B,L(&9U>GIY"FUS9VED(")#:&EL92(*;7-G<W1R("*]T.';WM(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X,`IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S
M,3(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q"FUS
M9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"B,L(&9U>GIY
M"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G<W1R("*_WN+2X-38(-O>
MU]C=VM`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8X
M"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HX.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED
M(")#;&5A<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*;7-G:60@
M(D-L96%R(%%U97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R(&]U
M="!U<V5R.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L
M96%R('5S97(@9&%T82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(K?0
MXM+>X-@@T]X@W^#>U][@U>;>XB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0T"FUS9VED(")#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*;7-G:60@(D-L;W5D<R!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C0*;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O
M;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P
M<V5D(&)O<F1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L
M;VUB:6$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H
M<#HS,C0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP
M.C,R-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3`P('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#D*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-3`*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C4*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C8*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*(SH@=&5M
M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#(*;7-G:60@
M(D-O;&]R(%!I8VME<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#0V"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`S"FUS9VED(")#;VQS.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-C0*;7-G:60@(D-O
M;6EC<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*(RP@
M9G5Z>GD*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`BQ-C@W-`B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS
M9VED(")#;VUM96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS
M9VED(")#;VUP86YY(@IM<V=S='(@(L38X-S0(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y-PIM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS
M9VED(")#;VYD:71I;VYS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.CDV"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF:6=U<F4@)7,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I
M9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R("*_WN+2X-38(-O>U]C=VM`B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@
M=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D
M('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(L'>U.#6V-W0(-W0("<E
M<R<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E
M<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(D-O<'DB"FUS
M9W-T<B`BQ-C@W-`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S
M(@IM<V=S='(@(KC<W][@XMC@T-W>(-_>V]4Z("5S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S
M96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.34*;7-G:60@(D-O<W0@240B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-@IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,C$*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("*]U>/AW]7H
MW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0U-PIM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A
M<"!S97)V97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*;7-G<W1R("*]U>/A
MW]7HW=`@VM[=U=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO
M="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D
M96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C,X,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G
M:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES
M="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@
M8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E
M9WDO9&ER96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@
M<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR
M-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(KS>U./;WN(@
MW=`@U]#4T.?0XM`@U]`@WM3@UN/2T/K5("5S(-W5(-S>UM4@U-`@T=C4U2#>
MXM+>X-7=(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("*\WM3CV][B(-W0(-?0U-#GT.+0(-?0(-[4X-;CTM#ZU2`E
M<R#=U2#<WM;5(-30(-'8U-4@WN+2WN#5W2(*"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,C,W(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C8Y.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0
M(.'5X-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z
M,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM
M<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE
M(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#D*
M;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&%D9')E
M<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DAO<F1E(-W5(-4@W^#0TMC;W=X@VM[=Y-C3X^#8X-#=(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`BO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5
MX-+5X-[B+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,V-@IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R
M+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S
M7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*;7-G:60@(D-O=6YT<GDB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM
M<V=I9"`B0V]U<G-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*;7-G:60@(D-R
M96%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHY-`IM<V=I9"`B0W)E871E(&$@;F5W(&]N92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I
M9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HR-@IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-#@*;7-G:60@(D-U<G)E;G0@4V5S<VEO
M;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L
M;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S,*;7-G:60@(D-U<G)E;G0@57-E<G,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0IM<V=I9"`B
M0W5R<F5N="!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-S4*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I
M9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#>7!R=7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@
M(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B
M(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C
M:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS
M9VED(")$86EL>2(*;7-G<W1R("*TW=72W=XB"@HC.B!A9&UI;B]D871A=')E
M92YP:'`Z-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B1&%T86)A
M<V4@3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,Y.0HC+"!F=7IZ>0IM<V=I9"`B1&%T92(*;7-G<W1R("*XU]'@V.C8(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@
M(D1A=&4@4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB
M"FUS9W-T<B`BM-W5TMW>(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V"B,L(&9U>GIY"FUS9VED(")$95]L
M971E($-O;'5M;B(*;7-G<W1R("*XU]'@V.C8(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H
M<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0B"FUS9W-T<B`BN-?1X-CH
MV"(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C<W"B,L(&9U>GIY"FUS9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(KK>
MX-CAXM@@X>+0W=30X-3=T"#2X-74W=[AXB(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=XMCBU>(B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB
M"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=XMCBU>(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C8*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C<P"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T
M92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G
M:60@(D1E;&5T92(*;7-G<W1R("*XU]'@V.C8(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY
M"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("*XU]'@V.C8(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S+G!H<#HR,C<*(RP@9G5Z
M>GD*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("*XU]'@V.C8(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@3&]G(@IM<V=S='(@(KC7T>#8Z-@B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM
M<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4W"B,L(&9U>GIY"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("*XU]'@
MV.C8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G
M<W1R("*XU]'@V.C8(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G
M:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS
M(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!R;W<B"FUS9W-T<B`B
MN-?1X-CHV"(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI
M;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>2(*;7-G<W1R("+!XM#=U-#@U-7=(-C4U=WBV.+5XB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*;7-G:60@(D1E;&EV
M97)Y('1I;64B"FUS9W-T<B`BN-?1X-CHV"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S
M='(@(K[?V.$@W=`@W^#>T=O5W-[B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(KK>W-_;U>+5W2#>W]CA.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G
M9FEL92DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$979E;&]P;65N="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-PIM<V=I9"`B1&5W(%!O:6YT
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDT"FUS9VED
M(")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G:60@(D1E=R!P;VEN
M=#H@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$
M:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(V-@IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*(RP@9G5Z>GD*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("*WT.?CTM#X(-[?YMC8(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"FUS9VED(")$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q-PIM<V=I
M9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O=71I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(KC7
MT>#8Z-@B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@
M(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S
M='(@(KW5(-_@V.'BT-_CTM#X(-38X-7:XMW>(-3>(&UA:6YT96YA;F-E+G!H
M<"(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H92!F:7)S="!R
M;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI
M<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U
M8FQI8R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP
M.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G
M:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B
M1')U9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$S"B,L(&9U>GIY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`BO][H
MXM`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H
M<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@
M8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,S4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC
M.C(U"FUS9VED(")%9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]522YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR
M-0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'
M<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED
M(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF;W)M870*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@
M2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS
M9VED(")%;"!386QV861O<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L
M96UE;G0N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T
M<B`BU2W?WNCBT"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38U('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM
M<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R("*RT.C0($5M86EL(-#4X-7A
MT#HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
MN][7V-W:V.+5(-S>X-`@U-`@T=C4T.(@V.'BV"XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@HC
M+"!F=7IZ>0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BO^#0U]7=
M(.#5U^/;XM#B+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B
MO^#0U]7=(.#5U^/;XM#B+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@
M<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@
M>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DQ"FUS9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R
M"FUS9VED(")%<G)O<B(*;7-G<W1R("*SX-7HVM`B"@HC.B!F<F%M97=O<FLO
M5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z-S(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M
M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R
M9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED
M(")%=7)O<&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,S.0IM<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R
M>2`R(&UI;G5T97,B"FUS9W-T<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S."!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDP"B,L(&9U>GIY"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`BP=7:WM4@W^#8^-#2X]+0^M4B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G
M<W1R("+!U=K>U2#?X-CXT-+CTM#ZU2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS.#@*(RP@9G5Z>GD*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R
M("+!U=K>U2#?X-CXT-+CTM#ZU2(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M
M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS9W-T<B`BO^#8
MW-7@.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L
M;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HT-S4*;7-G:60@(D5X<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T
M960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8W-@IM<V=I9"`B17AP;VYE;G0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L
M+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R
M969E<F5N8V5S+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#3V"#8U]S5W=#<(-_>
MU-7AX]+0^M#BT"XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(KW5
MX^'?U>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A
M:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(KW5X^'?
MU>C=T"#:WMW5VN;8^-`@X=X@3$1!4"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C8X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&
M86EL960@=&\@8V]P>2!F<F]M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.3$*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B
MO=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@
M(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B3$1!4"#:WMW5VN;8^-#BT"#4WB`E<R#5(-W5X^'?U>C=T"XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I
M;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R("*]U>/AW]7HW=`@VM[=
MU=KFV/C0(.'>($Q$05`@X=7@TM7@WN(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HT-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(')E=')I979E.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA
M<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L
M(&9U>GIY"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`BL^#5Z-K0(-_@
MV"#8W-_>X.(Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(L30VN$B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE
M<R(*;7-G<W1R("+$T-KA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*
M;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E
M<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE
M;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F
M;VYT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U
M>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(KW0X=O>TB(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@
M0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@
M)7,@9FEL97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0P-PIM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&:6QE
M($YA;64B"FUS9W-T<B`BN-S5(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO
M860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED
M(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I
M9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R
M=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS
M9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&
M;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BM]#1
MU=O5Z-K8(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED(")&
M;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&;W)W87)D<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"B,L(&9U>GIY"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`BN-S5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A
M;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O
M<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-#`V"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@9G5Z>GD*;7-G:60@(D9U
M;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`BNM[<W]O5XM7=(-[?V.$Z(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*
M;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV
M,`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(K+0Z-4@V-S5
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@
M0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS
M9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA
M<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM
M<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E
M96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N
M861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"B,L(&9U
M>GIY"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("*PU-S8
MW=CAXN#0YMCXT"(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O
M=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U
M871E;6%L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDR"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C@X"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P"B,L(&9U>GIY"FUS
M9VED(")'=65S=&)O;VLB"FUS9W-T<B`BL-3@U>'0X"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@
M(D=U:6YE82U":7-S874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED
M(")'=7EA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E
M;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ
M-3<*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS
M9VED(")(96%D97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(S"FUS
M9VED(")(96%V>2!4+5-T;W)M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L
M<"(*;7-G<W1R("*_WMS>Z"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@
M9G5Z>GD*;7-G:60@(DAE;'!E<B(*;7-G<W1R("*_WMS>Z"(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN
M:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I9"`B2&EG:"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*(RP@9G5Z>GD*;7-G:60@(DAO
M7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,U"B,L(&9U>GIY"FUS9VED(")(
M;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED(")(;VUE($%D9')E<W,B"FUS9W-T
M<B`BM-[<T.C=T"#0U.#5X=`Z(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(
M;VUE(%!H;VYE(@IM<V=S='(@(K3>W-#HU=T@XM7;U>3>W2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M-#,U"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE
M8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(G)7,G(./AW]7HW=X@WN+AXN#0
MW=7B(-[4(.'8X>+5W-[B+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z,C(S"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N
M9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0W-`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE
M('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,S0P"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U
M;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM
M<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H
M8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(
M;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(
M=6UI9&ET>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED
M("))4"!!9&1R97-S(@IM<V=S='(@(K#4X-7AT"(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN
M(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))
M4"!L;V-K9&]W;B!V:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I
M9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<V"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(B(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("))8V]N<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W-PIM<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y
M)W,@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3<S"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q
M"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I
M9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM
M<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@
M(DEM86=E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T
M97`@)60B"FUS9W-T<B`BN-S?WN#BV.#0W=X@W][;U3H@)7,B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BN-S?WN#BV.#0W=X@W][;
MU3H@)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED
M("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(KC<W][@XMC@T-W8(-_>V]CZ
MT#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S
M-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,@HC+"!F=7IZ>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N
M9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`BLM4@W-[;V-S5(-W0TM74U>+5(-+0
MZ-4@VM[@V.'=V.?:WB#8W-4@V"#;WM?8W=K0(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M
M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@
M>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S0*;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B26YF;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C4W"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED("))
M;F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR,`IM<V=I9"`B26YS97)T($EM86=E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G
M:60@(DEN<V5R="!486)L92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E<G0@5V5B
M($QI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M
M;B!"969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R
M96YT(&YO9&4B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S.0IM<V=I9"`B26YS97)T
M(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H
M92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R
M="!C96QL(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3D*;7-G:60@(DEN<V5R="!C
M96QL(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@8V]L
M=6UN(&%F=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU
M;6X@8F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B
M969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(')O=R!A9G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,P"FUS9VED
M("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@26UA
M9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@
M=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I
M9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-0IM<V=I9"`B26YT96=E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ-S`*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`IM<V=I9"`B26YV86QI9"!:
M25`@9&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI9"!D871A
M('-U8FUI='1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P"FUS9VED("));G9A;&ED(&1E
M<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`*;7-G:60@(DEN=F%L:60@9FEL92!F
M;W)M870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$W-PIM<V=I9"`B26YV86QI9"!L:6-E;G-E(&ME>2XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,0IM<V=I9"`B
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS
M9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G:60@
M(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM
M<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W,PIM<V=I9"`B26YV86QI9"!P87)T
M;F5R(&ED+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<U"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z-S$@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R
M8V4@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A;&ED('5N
M:6-O9&4@9&%T82XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*;7-G:60@
M(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS
M9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@36%N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T
M"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@HC
M+"!F=7IZ>0IM<V=I9"`B271A;'DB"FUS9W-T<B`BM-W5TMW>(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N
M97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I<'0@:&%S(&)E
M96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES('!A9V4@;6%Y
M(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E
M>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS
M9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B
M2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E
M<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4
M>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B
MO][@T-K0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P
M"FUS9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES
M97)V97(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,PIM<V=I9"`B2VED<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@
M(DMI<FEB871I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO
M<F5A;B`H155#+4M2*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMU=V%I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y
M>G-T86XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M
M;V]N+G!H<#HX.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34Q"FUS9VED("),87-T(%5P9&%T960Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G
M:6XZ($YE=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T
M=FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM
M<V=I9"`B3&%W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y
M;W5T(@IM<V=S='(@(KC7V]77(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO
M(&)O<F1E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N
M;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C8Y"FUS9VED("),969T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A
M9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,34*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(K_@V-S5
MX#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E
M;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA
M:&ER:7EA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT
M96YS=&5I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("*[WM/8X-#Z
MU2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W
M"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H
M="!286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@
M4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM
M<V=S='(@(KO>T]C@T/K5(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M-0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED
M("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),
M:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(KC7V]CAXM#X(.+5W-@@U]`@W][<
MWN@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A
M8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y"B,L(&9U>GIY
M"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`BN-?;V.'BT/@@XM7<V"#7T"#?
MWMS>Z"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DV
M"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS
M"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(KO8
MX>+0^M7BWB#=T"#:WN#8X=W8YM@@U2#>W=72WM?<WM;5W=XN(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`BN]CAXM#ZU>+>
M(-W0(-K>X-CAW=CFV"#5(-[=U=+>U]S>UM7=WBXB"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(KO8X>+0^M7BWB#=T"#:WN#8X=W8YM@@
MU2#>W=72WM?<WM;5W=XN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W
M"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q
M,0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-`HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`B(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I
M;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S
M='(@(KO>T]C@T/K5(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.#4*;7-G
M:60@(DQO9R!O=70B"FUS9W-T<B`BN-?;U=<B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(@IM<V=S='(@(KO>
MT]C@T/K5(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B
M3&]G:6X@5&%S:W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3DV"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S
M97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3(*;7-G
M:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B3&]N9R!T97AT(@IM
M<V=S='(@(KC7V]77(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS
M9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N
M968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D
M(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@
M(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@
M1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM
M<V=S='(@(K_>Z.+0(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q
M"FUS9VED(")-86EL(@IM<V=S='(@(K_>Z.+0(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`BO][H
MXM`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM<V=S='(@(K_>Z.+0
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R
M("*_WNCBT"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B
M(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@
M;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T
M(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B
M36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(K+=
MV-S0W=C5(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED
M(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM
M<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(KK>X-7AW][=U-C@T.?:V"#?WMO8^M`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G
M:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED
M(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E
M9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y
M"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N
M=2!M;V1E.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("*_WN#0
MVM`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM
M<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R("*_WN#0VM`B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BO][@T-K0(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP
M:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@:7,@
M;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(&YO="!D
M969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B36ED9&QE(@IM<V=S='(@(K_>Z.+0(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@
M(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q,`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A
M9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS
M9VED(")-:7)R;W(B"FUS9W-T<B`BL^#5Z-K0(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,T,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C(U,`IM<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS
M9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A<'!L
M:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A
M9V4@240N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@
M(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"FUS9VED
M(")-;V)I;&4@36%I;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B36]D97)A=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*;7-G:60@(DUO
M9&EF:65D($1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<S"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(KS5X=7GW=XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS
M9VED(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M,C4S"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S
M=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E
M(%)I9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED
M(")-;W9E(&1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT
M:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU
M;'1I;6%P(%5+(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C0R"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B
M37D@06-C;W5N="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@
M4&]R=&%L(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HQ,S8*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")->6%N;6%R(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BN-S5(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS
M9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE
M=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!5
M4DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V
M97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS
M9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,U"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G:60@(DYE=F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX,0HC
M.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#<*
M(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.CDW
M"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HQ
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M
M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@
M36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(DYE=R!:96%L86YD(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F
M=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(KO>U]C=VM`B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M
M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4R"B,L
M(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G
M<W1R("*[WM?8W=K8XM4@W-[@T"#4T"#1V-30XB#8X>+8+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE
M=R!W:6YD;W<@*%]B;&%N:RDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*(RP@9G5Z>GD*;7-G:60@(DYE=W,B
M"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E
M;6%P+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@
M-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*
M(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("*]T-?0U"#:
MWMT@WM_FV-CBU2(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z,3`S
M"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI
M9V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P
M"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED
M(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0^M4@W=`@4U%,(-C4
MU=WBV.+5XMCBU2XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("*^XMK0UM@@T]@@W^#>
MW-7=V.+5(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*
M;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#Z
MU2#=T"!344P@VM#BU=/>X-C8XM4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("*]
MU=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!,1$%0(-S>UMW>X>+8
MXM4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-CD*(RP@9G5Z
M>GD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@
MW][4U>'CTM#ZU2#=T"!344P@VM#BU=/>X-C8XM4N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&
M:6QE(%9&4RXB"FUS9W-T<B`BO=7<T"#8W>3>X-S0YMC8(-?0(-_>U-7AX]+0
M^M4@W=`@4U%,(-K0XM73WN#8V.+5+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED(").;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@
M(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O
M;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I
M9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N
M97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H
M<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("*]
MU=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!344P@V-35W>+8XM7B
MV.+5+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(KW5W-`@V-WDWN#<T.;8V"#7
MT"#?WM35X>/2T/K5(-W0(%-13"#8U-7=XMCBU>+8XM4N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C@T"B,L(&9U>GIY"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R("*]U=S0(-C=Y-[@W-#FV-@@U]`@W][4U>'CTM#ZU2#=T"!344P@V-35
MW>+8XM7BV.+5+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA
M<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@
M=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@
M<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E
M="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM<V=I9"`B3F\@<G5L97,B
M"FUS9W-T<B`BM]#1U=O5Z-K8(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z-#0Y"FUS9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0T"B,L(&9U>GIY"FUS9VED(").;R!S:61E<R(*;7-G<W1R
M("*WT-'5V]7HVM@B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X
M,PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D
M:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*(RP@
M9G5Z>GD*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT
M+B(*;7-G<W1R("*RU2#<WMO8W-4@W=#2U=35XM4@TM#HU2#:WN#8X=W8Y]K>
M(-C<U2#8(-O>U]C=VM`B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N
M<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R
M.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I
M;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PHC+"!F=7IZ>0IM
M<V=I9"`B3F]N92(*;7-G<W1R("+"U=O5Y-[=(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E
M(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDV"FUS9VED(").;W)F;VQK($ES;&%N9"(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP
M.C8P"FUS9VED(").;W)T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F]R=V%Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS
M9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX
M,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U
M='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`HC
M+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R("*WT-'5V]7HVM@B"@HC
M.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP
M.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#4@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,CDW"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4P,2!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-0IM<V=I9"`B3F]T
M('-U<'!O<G1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z
M,3`P-0HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3<X"FUS9VED(").
M;W1E<R(*;7-G<W1R("*WT-'5V]7HVM@B"@HC.B!S97)V:6-E<R]O8G)O=W-E
M<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B
M86-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(KC<U2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E
M<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N
M(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B
M3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C8*;7-G:60@(D]F
M9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP
M:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I
M9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T
M<B`BN][7V-W:T"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@
M(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3<Q"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-0IM
M<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T
M;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO
M;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M
M92YP:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS
M9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R
M;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G
M:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I
M;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E
M8F%R+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(D]P=&EO;G,B"FUS9W-T<B`B
MM]#GX]+0^"#>W^;8V"(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP
M;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-C<*(RP@9G5Z>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("*P
MU-S8W=CAXN#0YMCXT"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38X"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R
M9V%N:7II;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"B,L('!H<"UF;W)M
M870*;7-G:60@(D]R:6=I;F%L('1E;7!L871E<R!I;B`E<SHB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E
M<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,Q
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#$*;7-G:60@(D]T:&5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM
M<V=I9"`B4$5!4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S,*;7-G:60@(E!'4"!$:6=I
M=&%L(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,S$Y"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,W,0IM<V=I9"`B4$=0(%!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I
M9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@
M(DAO<F1E(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@
M4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*
M;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#`*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,0IM<V=I9"`B
M4$T@4W5N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!4+5-T;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C<T"FUS9VED(")03U-)6"!E
M>'1E;G-I;VX@:7,@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ-#D*;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-@IM<V=I
M9"`B4&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A
M:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*
M;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M,3@*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,C,*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(KO>U]C=VM`B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R("*[WM?8W=K0(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B
M4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM
M<V=I9"`B4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS
M9VED(")087-S=V]R9#HB"FUS9W-T<B`BN][7V-W:T"(*"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")087-S=V]R
M9#H@(@IM<V=S='(@(KO>U]C=VM`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`S-`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@;75S="!M
M871C:"XB"FUS9W-T<B`BN][7V-W:V.+5(-S>X-`@U-`@T=C4T.(@V.'BV"XB
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU,0IM<V=I9"`B4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V97%U975E9"YI;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*(RP@9G5Z>GD*
M;7-G:60@(E!E;W!L92(*;7-G<W1R("+#V][3T"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C0Y"FUS9VED(")097)F;W)M($UA:6YT96YA;F-E($]P97)A
M=&EO;G,B"FUS9W-T<B`BN-?2X.C8(-[?U>#0YMC8(-?0(-[4X-;CTM#ZU2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,#8*(RP@9G5Z>GD*;7-G:60@
M(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS
M9W-T<B`BN-?2X.C8(-[?U>#0YMC8(-?0(-[4X-;CTM#ZU2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E;&5T
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-3@V"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`BL-3<V-W8X>+@T.;8
M^-`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@(E!E<G-O
M;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M("+"U=O5Y-[=(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W.`IM
M<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@
M(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U
M9&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T
M('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED
M(")0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN(@IM<V=S='(@(K+5(-S>V]C<U2#=T-+5U-7BU2#3WB#?
MX-[1V]7<WN(N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R("*RU2#<
MWMO8W-4@W=#2U=35XM4@TM#HU2#:WN#8X=W8Y]K>(-C<U2#8(-O>U]C=VM`B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L
M96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@
M=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA
M;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B
M4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0X-PIM<V=I9"`B4&]L;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED
M(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0
M;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I
M<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0
M<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U
M"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-0IM
M<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`U"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4')E=FEE=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V-@HC+"!F=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T
M:6]N<R(*;7-G<W1R("*]T-?0U"#:WMT@WM_FV-CBU2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT
M(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0HC+"!F=7IZ
M>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R(");N-?2U>CBT/@@U]`@W^#>T=O5
MW-[B72(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O
M8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R("*^W]CA(-W0(-_@WM';U=S>XB(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-CD*;7-G:60@(E!R;VIE
M8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!U8FQI8R!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I
M=&AM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0
M=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0=65R=&\@
M4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A<B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U
M97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`IM
M<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0S"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN($5A<FQY(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@
M4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X
M"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B
M4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G
M:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`BO][@T-K0(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L
M87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS
M9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0IM<V=I9"`B4F5F<F5S
M:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-0HC+"!F=7IZ>0IM<V=I9"`B
M4F5G97@B"FUS9W-T<B`B4F5S970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R
M:W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM
M<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")296UO=F4B
M"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L
M87EO=70N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@0FQO8VLB"FUS
M9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C4U-PIM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@9F]R;6%T=&EN9R(*;7-G
M<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N
M:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`BOM3AXN#0W=@@
MW]#@(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M
M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@HC+"!F=7IZ>0IM<V=I9"`B4F5M
M;W9E('1H92(*;7-G<W1R("*^U.'BX-#=V"#?T.`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@
M(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`BOM3AXN#0W=@@W]#@
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T
M<B`BOM3AXN#0W=@@W]#@(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C
M+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N
M(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(E)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D
M(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(K'0X-#=V-[B("=U:60G(-W5(-4@W=#2U=35W2#2WB#?WM35X>/2
MT/K0XM`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<R,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(K'0X-#=V-[B("=U:60G(-W5(-4@W=#2U=35
MW2#2WB#?WM35X>/2T/K0XM`N(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP
M:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R
M("*QT.#0W=C>XB`G=6ED)R#=U2#5(-W0TM74U=T@TMX@W][4U>'CTM#ZT.+0
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM
M<V=I9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(E)E<V5T(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@
M(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(KO>U]C=VM`B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4F5S970@
M66]U<B!087-S=V]R9"(*;7-G<W1R("*_WN+2X-38(-O>U]C=VM`B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E
M<GDB"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*(RP@9G5Z
M>GD*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S970B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N
M:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(KW0U]#4
M(-K>W2#>W^;8V.+5(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP
M.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`BO=#7T-0@VM[=(-[?
MYMC8XM4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I
M9&1L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H
M="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$Q-PIM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@
M(E)O;&4B"FUS9W-T<B`BP]O>T]`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M;VUA;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,C4*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M,@IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E
M(%)I9VAT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O=R!P<F]P97)T:65S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"B,L(&9U>GIY
M"FUS9VED(")2=6QE<R(*;7-G<W1R("+#V][3T"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T
M=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*
M;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM
M<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4P-`HC+"!F=7IZ>0IM<V=I
M9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R("*_WN#0VM`B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@S"FUS9VED(")344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@(E-32"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8Q"FUS9VED(")382(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")386EN="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED
M(")386EN="!+:71T<R!A;F0@3F5V:7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S
M96QF*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")386UO82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N9"!0
M<FEN8VEP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM<V=I9"`B
M4V%V92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E("5S(@IM<V=S='(@(K?0
MY^/2T/@@WM_FV-@B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS
M9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*;7-G:60@(B(*(E-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#D*;7-G:60@(E-C871T97)E9"!4+5-T;W)M<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C
M:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P
M"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3<S"FUS9VED(")396QE8W0@1FEL97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0X-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R
M("*XU]'5X-@@Y-[@W-#B(-?0(-30XN/<WN(Z(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D
M9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S
M97)V97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*
M;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N(@IM<V=S='(@(KC7T=7@V"#DWN#<T.(@U]`@U-#B
MX]S>XCHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G
M:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N(@IM<V=S='(@(B(*(KC7T=7@V"#:WM@@VM#@T-KBU>#8(.+8(.+@U='0
MT.(N(+S>UM7H(-_>XM[0(-W8TB#4T"#3V"#8X=K>W]C@T.@@WM0@W][;U>+>
M("(*(M?0(.+5VN'B+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T
M"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("*X
MU]'5X-@@X=7?T.#0XM[@(-?0(-30XN/<WN(Z(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z
M(@IM<V=S='(@(KC7T=7@V"#DWN#<T.(@U]`@U-#BX]S>XCHB"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(KC7T=7@
MV"#AU=_0X-#BWN`@U]`@U-#BX]S>XCHB"@HC.B!T96UP;&%T97,O9&%T82]T
M:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS
M9W-T<B`BN-?1U>#8(.3>X-S0XB#7T"#2X-7<U>+>.B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI
M;F<@9FEE;&1S+B(*;7-G<W1R("*XU]'5X-@@U-+5(-[4T][2T.#0Y]K8(-_>
MV]CZT"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S`V"FUS9VED(")3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`BO^#0XM@@V-?2U>CBT/@@U]`@W^#>T=O5W-[B(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@
M(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-E
M;F5G86PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*
M;7-G:60@(E-E;G-O<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D*;7-G:60@(E-E<F)I82!A;F0@36]N=&5N96=R;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B
M4V5R:6%L($YU;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,38Q"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS
M9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B
MM]#GX]+0^"#>W^;8V"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,30*;7-G:60@(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B
M4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S
M(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3@*;7-G:60@(B(*(E-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U
M<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED
M(")397EC:&5L;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED
M(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(KK@T.+:WB#@U=?8W-4Z(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S
M<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED
M(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT
M;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y
M,`IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN
M/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U
M"FUS9VED(")3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E
M;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED
M(")3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM
M86=E('!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4P"FUS9VED(")3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A
M<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G
M:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX
M,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,30Y"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I
M;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@
M(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B
M4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(P-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I
M9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R("*_X-7AVM[:W=@@WM3@UN/2
MT/K5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G
M:60@(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V
M"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO
M=V5R<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S@*;7-G:60@
M(E-N;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(X,@IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3
M;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,C8*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ.#D*(RP@9G5Z>GD*;7-G:60@(E-O=7)C92!A9&1R97-S
M(@IM<V=S='(@(K#4X-7AT"#=T"#@T-'>XM`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G
M:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C(*;7-G:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G
M:60@(E-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*
M;7-G:60@(E-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U
M"FUS9VED(")3<&%C97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A
M;2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(K+=U>'CTM#Z
MU2#=T"#AW]7FV/C0V]W8(-?=T.;8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L
M;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B4W!O<G1S
M(@IM<V=S='(@(KC<W][@XB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA
M;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3=&%N9&%R9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@
M(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#D*;7-G:60@
M(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S`*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL
M.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*
M(RP@9G5Z>GD*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(K#4X-7A
MT"#=T"#@T-'>XM`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S,*;7-G:60@(E-T<FEN
M9R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*
M;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K
M+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M:70B"FUS
M9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O('1H92!S
M>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E
M<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C
M<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z
M(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R
M+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`BP^'?U>C=
MWB(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T
M96TN(@IM<V=S='(@(B<E<R<@X^'?U>C=WB#4WM30U-7=(-W0(.'8X>+5W-[B
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<
M(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(./AW]7HW=X@
MWN+AXN#0W=7B(-[4(.'8X>+5W-[B+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-@HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G
M<W1R("(G)7,G(./AW]7HW=X@U-[4T-35W2#=T"#AV.'BU=S>XBXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S>7-T96TN
M(@IM<V=S='(@(B<E<R<@X^'?U>C=WB#>XN'BX-#=U>(@WM0@X=CAXM7<WN(N
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0IM<V=I9"`B4W5C8V5S
M<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@
M8VAA;F=E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U
M<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G(./AW]7HW=X@U-[4T-35W2#=
MT"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(B<E<R<@X^'?
MU>C=WB#4WM30U-7=(-W0(.'8X>+5W-[B+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-U9&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U
M;6UA<GDB"FUS9W-T<B`BNN#0XMK>(.#5U]C<U3HB"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU.0IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I
M<V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,W.`HC+"!F=7IZ>0IM<V=I9"`B4W5P<&]R
M="(*;7-G<W1R("*XW-_>X.(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"B,L(&9U>GIY"FUS
M9VED(")3=7)I;F%M92(*;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS
M9VED(")3=7)N86UE(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I9"`B4WEN8R!L;V<@
M9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30R"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3>6YT87@@97)R;W(@:6X@
M<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@
M(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM
M<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ
M-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(KW0X=O>TB(*
M"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T"B,L(&9U>GIY"FUS
M9VED(")486)L92(*;7-G<W1R("*]T.';WM(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L
M92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP
M"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM<V=I9"`B5&5M<&5R871U<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM
M<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E
M;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*(RP@
M9G5Z>GD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(K#4W-C=V.'BX-#FV/C0(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I
M9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*
M;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T
M:&4@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B
M(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]";V]K+G!H
M<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP
M:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@
M=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N
M9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T<FEB=71I
M;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I
M<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP:'`Z,C@P"FUS9VED(")4
M:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B
M5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G
M92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U
M;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET
M:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T
M:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT
M(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O
M<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)
M9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&
M875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@
M=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT
M('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*
M;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU
M<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB
M"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0IM<V=I9"`B5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]W96)C<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0U-`IM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#0V"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I
M;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$Q"FUS9VED(")4:&4@=&5X="!Y;W4@
M96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP
M.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@
M=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E
M('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(KW5W-`@
MU-[AXM#?W=@@W][4U>'CTM#ZT"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T
M:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@
M9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"@HC.B!S:6=N
M=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@
M=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`BO=#AXM#=T"#?X-[1V]7<(-_@
MV"#4WM30TM#ZU2#=T"`E<R#2WB#AV.'BU=S>XBXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`BO=#AXM#=T"#?X-[1V]7<(-_@V"#>
MXN'BX-#=X]+0^M4@W=`@)7,@WM0@X=CAXM7<WN(N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ
M("(*;7-G<W1R("*]T.'BT-W0(-_@WM';U=P@W^#8(-[BX>+@T-WCTM#ZU2#=
MT"`E<R#>U"#AV.'BU=S>XBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("*]T.'BT-W0(-_@WM';U=P@
MW^#8(-3>U-#2T/K5(-W0("5S(-+>(.'8X>+5W-[B+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.
M;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@
M<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE
M("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T
M(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N
M;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-3(*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q-#4*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,T"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M
M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--
M5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP
M+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(S"FUS9VED(")4:&ES(&9I96QD
M(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I
M;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S
M-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q
M,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC
M.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W
M87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N
M=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*
M;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`BO=#AV][2(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN
M9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@
M(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,P(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,CD@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(KW0X=O>TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O
M=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-S<*;7-G:60@(E1O<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@
M9G)A;64@*%]T;W`I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,PIM<V=I9"`B5')A;G-L871I;VYS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U
M92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4=79A;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@
M:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS
M9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L
M(&9U>GIY"FUS9VED(")54DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E5G86YD82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS
M9VED(")5:W)A:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5
MVN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`BO=4@
MW-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8X."!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I
M9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B
MO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("*]U2#<
MWM;5TB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`BO=4@
MW-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S4T
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-@HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("*]U2#<WM;5
MTB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G<W1R("*]U2#<WM;5TB#4
MT"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S
M='(@(KW5(-S>UM72(-30(.'5(-K>W=7:XMC@T-P@X=X@4U%,(.'5X-+5X-[B
M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<V
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HW.0IM
M<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,C0@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HR.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S$@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HS.3(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,Q,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S,T"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@
M:7,@;F]T(&5M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,U,@IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,R
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:
MWMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,Y,0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-#0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HT,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!6
M1E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@P,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2XB"FUS9W-T<B`BO=7CX=_5
MZ-W>(.#5T]CAXN#8X-#ZU2#=T"#?WM35X>/2T/K0XM`@TMX@X=7AV/C0XM`N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G
M:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F
M<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@
M;6]V92!61E,@9FEL92XB"FUS9W-T<B`BO=4@W-[6U=(@U-`@T]@@V-?<U=W0
MW"#?WM35X>/2T/K0XM`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM
M<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("*]U2#<WM;5TB#4T"#AU2#:WMW5
MVN+8X-#<(.'>(%-13"#AU>#2U>#>XBXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(KW5(-S>UM72
M(-30(-/8(-C7W-7=T-P@W][4U>'CTM#ZT.+0+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE
M("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F
M:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H
M<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN
M871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
MO=4@W-[6U=(@U-`@X=4@VM[=U=KBV.#0W"#AWB!344P@X=7@TM7@WN(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G
M:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H
M<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z
M-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M
M96YT(@IM<V=S='(@(KW5(-S>UM72(-30(-/>(-_@U=+5U-#<(-[2WO@@5V]R
M9"#4WMKCW-7=XBXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T
M.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X
M,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T
M;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G
M:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O
M96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`BON+:T-;8
M(-/8(-_@WMS5W=CBU2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L
M871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5
M;F9I;&5D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS
M"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S($UI;F]R($]U
M=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C8Y(&QI8B]";&]C:R]M971A<BYP:'`Z-S$*;7-G:60@
M(E5N:71S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0R.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*
M;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM
M<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Y
M"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT
M:71Y+G!H<#HR.38*(RP@9G5Z>GD*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B
MNM[@V.'=V.?:WB#8W-4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A
M('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S
M('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP
M8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U
M<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E5P9&%T92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C<V"B,L(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E
M<B(*;7-G<W1R("*TWM30U-@@VM[@V.'=V-HB"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B57!L;V%D(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@
M(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5<'!E<B!L871I
M;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O
M;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B
M57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I
M9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0
M('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*;7-G<W1R("*Z
MWN#8X=W8Y]K>(-C<U2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HR,#,*(RP@9G5Z>GD*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B2&]R9&4@L-3<V-W8X>+@T.+>X"(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"B,L(&9U>GIY"FUS9VED(")5<V5R
M($]P=&EO;G,B"FUS9W-T<B`BM]#GX]+0^"#>W^;8V"(*"B,Z('-I9VYU<"YP
M:'`Z-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S
M='(@(DAO<F1E(+#4W-C=V.'BX-#BWN`B"@HC.B!S:6=N=7`N<&AP.C(R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M=&AI<R!S:71E+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-#8Y"FUS9VED(")5<V5R(&%C8V]U;G0@;F]T(&9O=6YD(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S
M='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<
M(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(KK>X-CAW=CGVMX@V-S5(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z("(*
M;7-G<W1R("*ZWN#8X=W8Y]K>(-C<U2(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM
M<V=S='(@(KK>X-CAW=CFV"#2WB#AV.'BU=S>XCHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G
M:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U
M"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$P.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"FUS9VED(")686QU97,@=&\@
M<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M5F%N=6%T=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C0T"FUS9VED(")687)I86)L92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A
M=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP
M97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N
M($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y
M"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BLMW8W-#=V-4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS
M9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS
M9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`BO=74U=O=WB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X
M"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(K3>T>#5U-[XU-4L
M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(K3>T>#5U-[XU-4L("5S(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O
M<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(K3>T>#5U-[XU-4L("5S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DV"FUS9VED(")797-T
M97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L
M:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@
M(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")7:&%T
M(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8Q"FUS9VED(")7
M:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@
M=6YI=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7:61T:"!O9B!T:&4@)7,@;65N=2!O
M;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3HB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#8*;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q
M,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*
M;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV-0IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"!%87)L
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED
M(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0R"FUS9VED(")7:6YD.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED
M(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Y-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I
M9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(K#4X-7AT"#=T"#@T-'>XM`B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS
M9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(L+5V]7DWMT@W=`@X-#1WN+0(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N
M9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@
M0V]N<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF
M:65R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B
ML[,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-34*(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`BL[,B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B
M66%H;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B
ML][4V.C=WB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A
M=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T
M:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW-0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1&%T82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F
M:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED
M(")9;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N
M;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A
M('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#4V"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M
M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@
M=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("*^W]CHU>+5(-/>(-_@WM';
MU=S>XB#?X-74(-30(-CAW^#0XM7BU2#8U]+5Z.+0^"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@
M8F4@9&5L971E9"XB"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@
MV-S5(-30(.'5(-[BX>+@T-W8+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@
MV-S5(-30(.'5(-[BX>+@T-W8+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB
M"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-[B
MX>+@T-W8+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@VM[@
MV.'=V.?:WB#8W-4@U-`@X=4@U-[4T-35+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$T-@HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E
M<FYA;64@=&\@=7!D871E+B(*;7-G<W1R("*]T-+5U-7BU2#:WM4@VM[@V.'=
MV.?:WB#8W-4@U-`@X=4@U-[4T-35+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R("*]
MT-+5U-7BU2#:WM4@VM[@V.'=V.?:WB#8W-4@U-`@X=4@WN+AXN#0W=@N(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O
M<GD@;F%M92XB"FUS9W-T<B`BO=#2U=35XM4@VM[5(-K>X-CAW=CGVMX@V-S5
M(-30(.'5(-[BX>+@T-W8+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,S@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S
M<R(*;7-G<W1R("*RT.C0($5M86EL(-#4X-7AT#HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D
M9')E<W,Z(@IM<V=S='(@(K+0Z-`@16UA:6P@T-3@U>'0.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS
M,PHC+"!F=7IZ>0IM<V=I9"`B66]U<B!.86UE(@IM<V=S='(@(K+0Z-4@V-S5
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U
M>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"B*RT.C8WN(@T-+BWN#8U]#FV-[=U=T@W^#>XM[:WML@
MW=4@W][4X-;CTM`@U-[4T-+0^M4@VM[@V.'=V.;8+"#8V]@@XM#0("(*(MS>
MUMW>X>(@U2#>W=72WM?<WM;5W=`@WM0@U.#CT]@@W^#8Y]C=V"XB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G:60@(B(*(EEO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI
M<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HBLM#HV-[B
M(-#2XM[@V-?0YMC>W=7=(-_@WN+>VM[;(-W5(-_>U.#6X]+0(-O8X>+0^M4@
MVM[@V.'=V.;8+"#8V]@@XM#0("(*(MS>UMW>X>(@U2#>W=72WM?<WM;5W=`@
MWM0@U.#CT]@@W^#8Y]C=V"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P
M<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO:69R86UE+G!H<#HU,`IM<V=I9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]P<FEN="YJ<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W
M<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S
M($-O;G1R;VPO0V]M;6%N9"`K(%`@(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HY-@IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N
M(&-H86YG960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-3@*(RP@9G5Z>GD*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB
M"FUS9W-T<B`BP>+0W=30X-35W2#8U-7=XMCBU>(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY"FUS9VED(")9;W5R(&9U;&P@;F%M
M93HB"FUS9W-T<B`BLM#HU2#8W-4Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z,3`P,`IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$U-`IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<S,@IM<V=I9"`B66]U<B!P87-S=V]R
M9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R(')E;6]T92!S97)V97)S.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA
M=FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*
M;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED
M(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@
M(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R
M(");N-?2U>CBT/@@U]`@W^#>T=O5W-[B72(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")?061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BL-3<V-W8X>+@T.;8^-`B"@HC.B!L:6(O87!I+G!H<#HQ-3<*
M;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS
M9VED(")?1&%T851R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R("*XU]'@V.C8(@H*(SH@;&EB+V%P
M:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G:60@
M(E](96QP(@IM<V=S='(@(K_>W-[H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM
M<V=S='(@(KO>T]C@T/K5(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$Y,`HC+"!F=7IZ>0IM<V=I9"`B7TQO9R!O=70B"FUS9W-T<B`B
MN-?;U=<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"B,L
M(&9U>GIY"FUS9VED(")?3W!T:6]N<R(*;7-G<W1R("*WT.?CTM#X(-[?YMC8
M(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`BOM3AXN#0W=@@W]#@(@H*(SH@;&EB+V%P:2YP:'`Z,3(U
M"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B
M;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDR,0HC+"!F=7IZ>0IM<V=I9"`B861D<F5S<R!B;V]K
M(@IM<V=S='(@(K#4X-7AT.`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3,*;7-G:60@
M(F-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM
M<V=I9"`B9FEL92(*;7-G<W1R("*]T.';WM(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM
M<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO
M<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E
M<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G
M:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I
M9"`B;F%M92(*;7-G<W1R("*XW-4B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP
M:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS9VED(")N
M;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G:60@(G!E<FUI<W-I;VX@
M9&5N:65D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM
M<V=I9"`B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U
M>GIY"FUS9VED(")R:7-I;F<B"FUS9W-T<B`BLMW8W-#=V-4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC
M92!U;F%V86EL86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.CDY"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I
M9"`B<W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P.0IM<V=I9"`B<W=I=&-H(&]F
M9B!J879A<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,#4*(RP@
M9G5Z>GD*;7-G:60@(G1R>2!A9V%I;B(*;7-G<W1R("+!U=K>U2#?X-CXT-+C
MTM#ZU2(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H
M<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T
M,0IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O;'9?3%8N<&\`````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-C$Q,S4R(#$P
M-3$U-#,T,30R(#`Q-S4T,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C($QA='9I86X@=')A;G-L871I;VX@9F]R($AO<F1E
M+@HC($MA<W!A<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CXL(#(P,#(N
M"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO
M<F1E(#(N,5QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U
M.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,3$M,C@@,30Z
M,#`K,#(P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!+87-P87)S($MA<&5N:65K
M<R`\:V%S<&%R<T!R8V,N;'8^7&XB"B),86YG=6%G92U496%M.B!,871V:6%N
M(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP
M7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]0U`Q,C4W
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!
M8V-E<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<S
M"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE
M<W1E<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(U-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#<*;7-G:60@(B!A="`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G
M:7-T<GDN<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM
M<V=S='(@(B<E<R<@;F%V(&YO<N)D[G1S($AO<F1E(')E[&ES='+B(@H*(SH@
M9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES
M<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M870*
M;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&
M:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N(@IM<V=S='(@(B5S(%5Z='5RY_!A;F%S(&]P97+B8VEJ87,@+2!A
M<'-T:7!R:6[B:G5M<R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!3971U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(D%T>NYMYVII970@9&%R8NYB
M87,L(&MO(';G;&%T:65S('9E:6MT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:7,@<F5Q=6ER
M960B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B
M2V%T<F%S(#4@;6EN^W1E<R(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#
M;VQL96-T:6]N+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E
M<R!O9B`E<R(*;7-G<W1R(");<FEN9&$@)7,@;F\@)7-=(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(DMO;G1A:W1I(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,30*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD
MXG)S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B
M92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W
M:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E
M;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN
M9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO=7(@
M1F]R;6%T(@IM<V=S='(@(DK[<W4@:6YF;W)MXF-I:F$B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3D*(RP@9G5Z>GD*;7-G:60@(C(T($AO=7(@1F]R;6%T
M(@IM<V=S='(@(DK[<W4@:6YF;W)MXF-I:F$B"@HC.B!T96UP;&%T97,O9&%T
M82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@<W1U
M;F1A<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z-CD*;7-G:60@
M(CQ0<F5V:6]U<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960B"FUS9W-T<B`B/&(^27(@;F]T:6MU<VD@:W)I=&ES:V$@
M:^_[;64Z/"]B/B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDS-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME
M>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Y
M-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A("(*
M(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$P,34*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*
M(F$@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I
M<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0IM<V=I
M9"`B04T@0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@(D%-+U!-
M(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3(*;7-G:60@(D%B;W5T+BXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M
M:61D;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PHC
M+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")*
M^W-U(&EN9F]R;>)C:6IA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<U
M"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,PIM<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@(D%C8V]U
M;G1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"B,L(&9U>GIY"FUS
M9VED(")!9&0B"FUS9W-T<B`B061R97-E(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HR,C0@861M:6XO9W)O=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'
M<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@
M(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R93HB
M"FUS9W-T<B`B061R97-E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M
M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*;7-G:60@(D%D9"!N
M97<@;65M8F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M
M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R(")0:65V:65N;W0@
M<.)R:2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`B2V]N=&%K=&DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(D%D9"!T
M;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B2V]N=&%K=&DB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HS,0HC+"!F=7IZ>0IM<V=I9"`B061D('5S97(B"FUS9W-T
M<B`B4&EE=FEE;F]T('#B<FDB"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@
M:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ-#0Q"FUS9VED(")!9&1R97-S(@IM<V=S='(@(D%D<F5S92(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*(RP@9G5Z>GD*;7-G:60@(D%D
M9')E<W,@0F]O:R(*;7-G<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM<V=I
M9"`B061S(@IM<V=S='(@(D%D<F5S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F
M9VAA;FES=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(D%L8F%N:6$B"FUS9W-T<B`B06EZ<W3B:G;B<F1S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!:7IS=.)J=N)R
M9',B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!:7IS=.)J=N)R9',B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$V
M"B,L(&9U>GIY"FUS9VED(")!;&EG;B(*;7-G<W1R(")!:7IS=.)J=N)R9',B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W
M"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S
M+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY,2!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,0IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$
M871A5')E92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-
M4U`@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Y.0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S4*(RP@9G5Z
M>GD*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(DK[
M<W4@92UP87-T82!A9')E<V4Z(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M;V$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+B(*;7-G<W1R(").;W+B9.YT82!N961E<NYG82!VYW)T
M[F)A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V-PHC+"!F
M=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS
M9W-T<B`B/&(^27(@;F]T:6MU<VD@:W)I=&ES:V$@:^_[;64Z/"]B/B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS
M=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R
M8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM
M871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA
M;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H
M05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q,PIM<V=I
M9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S0*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HX-PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-@IM<V=I9"`B071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B
M075G=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*
M;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S
M(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U
M=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V
M"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T
M<"!S=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I
M<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS
M9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B
M;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B
M075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I
M<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M
M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N
M=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE
M(&9I96QD<SHB"FUS9W-T<B`B4&EE96IA;6EE(&QA=6MI.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"
M86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HX,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G
M:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R(")$>FEM\&%N87,@9&EE;F$B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<(B5S7"(@;V8@87!P;&EC
M871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B3F%V('-T<F]D86US
M('!A>FGR;VIU;74@:VQA=7/N=.)J<R`E<R(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED
M(")";&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS9W-T
M<B`B2&]R9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Q"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DAO<F1E
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@
M(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"B,L(&9U>GIY"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B4&%S=',B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R
M<FET;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$
M87)U<W-A;&%M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A
M<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T-`HC+"!F=7IZ>0IM<V=I9"`B0TU3
M(@IM<V=S='(@(D-64R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0U),($1I<W1R
M:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L
M;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT.#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDX
M-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34U"FUS9VED(")#86QE
M;F1A<B(*;7-G<W1R(")+86QE;F3B<G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C0V"FUS9VED(")#86QM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E
M='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R
M9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<
M(B5S7"(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS
M9VED(")#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE
M<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C(S-2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-
M05`@<V5R=F5R.B`E<R(*;7-G<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@
M3$1!4"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B
M0V%N861A(@IM<V=S='(@(DMA;&5N9.)R<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O9&5L971E+FEN8SHQ,2!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,@IM
M<V=I9"`B0V%N8V5L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`B071C96QT('!R;V)LYVUA<R!P:65T96EK=6UU(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G
M:60@(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HY,0IM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X"FUS
M9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P
M<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R("(*(G-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S
M<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C0*(RP@9G5Z
M>GD*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`B3W!C:6IA<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B
M0V%R<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M.3`*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM
M<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R(")-;V)I;&%I<R!TXFQR=6YI<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C4*(RP@9G5Z>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R
M(")-;V)I;&%I<R!TXFQR=6YI<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C<T"B,L(&9U>GIY"FUS9VED(")#96QL
M<&AO;F4B"FUS9W-T<B`B36]B:6QA:7,@=.)L<G5N:7,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0V5N
M=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.3D*;7-G:60@(D-E<G1I
M9FEC871E($1E=&%I;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,3$*;7-G:60@(D-E<G1I9FEC871E($]W;F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#@*(RP@9G5Z>GD*;7-G:60@(D-H860B"FUS9W-T<B`B
M=D-A<F0B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"B,L(&9U>GIY"FUS9VED(")#
M:&%N9V4B"FUS9W-T<B`B071C96QT(&EZ;6%I\F%S(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS9VED(")#:&%N9V4@66]U<B!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*
M;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E
M;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB
M96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")V0V%R9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B5FER<W)A:W-T
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#$*;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*
M;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A
M('5S97)N86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR.3@*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C@Y,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(DYA=B!S=')O9&%M<R!P
M87II\F]J=6UU(&ML875S[G3B:G,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`HC+"!F=7IZ>0IM<V=I9"`B0VQE87(B
M"FUS9W-T<B`B2V%L96YDXG)S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@=&%G
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED
M(")#;&5A<B!1=65R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O
M=70@=7-E<CH@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T"FUS9VED(")#
M;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,34*;7-G:60@(D-L96%R:6YG($QA=&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R(")!
M:7IVYW)T(&QO9W4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I
M9"`B0VQO=61S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S"FUS9VED(")#;VQL87!S92!3
M:61E8F%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HR.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0
M:6-K97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I
M9"`B0V]L<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS
M9VED(")#;VUM86YD(@IM<V=S='(@(E5Z\N=M=6US(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B
M0V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B
M0V]M<&%N>2(*;7-G<W1R(")5>O+G;75M<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS,0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*;7-G:60@(D-O;F1I=&EO
M;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T.0IM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#
M;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N
M97,@86YD($]U=&QO;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A
M=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-3$*(RP@9G5Z
M>GD*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQE(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]N9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-0IM<V=I9"`B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM
M<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(G)7,G('-A='5R<R(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C8Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-@IM<V=I9"`B0V]O:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B0V]P>2(*;7-G<W1R(")5
M>O+G;75M<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B265LXF3G=&%I<R!L875K<SH@)7,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3<V"FUS9VED(")#;W5L9"!N;W0@4$=0
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE:7ID97;B<R!P
M:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O(&QD87`@<V5R
M=F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3F5I>F1E=N)S
M('!I97-LYV=T:65S($Q$05`@<V5R=F5R:6TN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X
M,2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O
M=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R
M97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O
M;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$P"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER
M96-T+G!H<#HS,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC
M(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@7"(E<UPB(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-C(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z
M-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DYE:7ID97;B<R!A=';G
M<G0@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&D@)7,B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DYE:7ID97;B<R!A
M=';G<G0@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&D@)7,B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV.3D*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R96%C:"!T
M:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DYE:7ID97;B<R!P:65S;.=G=&EE
M<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+T]B:F5C
M="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D
M("5S+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F
M;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB
M9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE
M;'`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R,PIM
M<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L
M(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(DAO<F1E(&YA=B!K;W)E:W1I(&MO;F9I9W5RYW1A(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N
M9FEG=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E
M('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S
M92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M,30S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B3F5I>F1E=N)S('!I97-LYV=T:65S($Q$05`@
M<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@
M7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8V"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B
M87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB
M)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T,3D*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S
M"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN
M:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS
M9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM<V=I9"`B0W5R<F5N="!397-S
M:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O
M0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM<V=I9"`B0W5R<F5N="!5<V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,U"FUS
M9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G
M:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T
M<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED
M("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z-3D*
M;7-G:60@(D1A:6QY(@IM<V=S='(@(DEK9&EE;F%S(@H*(SH@861M:6XO9&%T
M871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W<V5R(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A
M=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S.3D*;7-G:60@(D1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M-PIM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B26MD
M:65N87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V
M"FUS9VED(")$96-E;6)E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$
M96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C<F5A<V4@26YD
M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"B,L(&9U>GIY"FUS9VED(")$969A
M=6QT(@IM<V=S='(@(E!A<F%S=.(@:61E;G1I=.)T92(*"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"B,L(&9U>GIY"FUS
M9VED(")$969A=6QT($-O;&]R(@IM<V=S='(@(DEZ;6%N=&]T(&YO:VQU<^=T
M;R!VYW)T[F)U(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HY,0IM<V=I9"`B1&5F875L="!)9&5N=&ET>2(*;7-G<W1R(")087)A<W3B
M(&ED96YT:73B=&4B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@
M9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B4&%R87-TXB!I
M9&5N=&ETXG1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED
M(")$969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I
M9"`B1&5L971E($=R;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES
M<VEO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I
M;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A
M;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$
M96QE=&4@<F]W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE
M=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")087)A<W3B(&ED96YT:73B=&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI
M=F5R>2!T:6UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA
M<FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D%P
M<F%K<W1I970@<')O8FSG;74B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
M4&EL;G,@87!R86MS=',Z(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(E/N:^)K82!I;F9O<FWB8VEJ82!I<B!N
M;W/[=.YT82!A9&UI;FES=')A=&]R86TN(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER
M96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y($]P
M=&EO;G,B"FUS9W-T<B`B16MRXFYA(&EE<W1A=.YJ=6UI(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.CDV"B,L(&9U>GIY"FUS9VED(")$:7-P
M;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(D5K<N)N82!I97-T873N
M:G5M:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*;7-G:60@(D1I<W!L
M87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-PHC+"!F=7IZ>0IM<V=I9"`B1&ES<&QA>2!F;W)M
M870B"FUS9W-T<B`B16MRXFYA(&EE<W1A=.YJ=6UI(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@3F]T
M:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J:6)O
M=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C
M=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B3F%V('1I9?!A
M<R!P:65E:F%S(&UA:6YT96YA;F-E+G!H<"(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$R('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R
M"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@
M;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E
M(&%N(&%C8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#0T"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*
M;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY"FUS
M9VED(")%+4UA:6PB"FUS9W-T<B`B4&%S=',B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M
M4TU3(&=A=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED
M92!T:&ES('-E<G9I8V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*
M;7-G:60@(D524B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A
M9&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,@HC.B!T
M96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U
M<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I
M9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-0IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G
M>7!T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S$P"B,L('!H<"UF;W)M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE
M;CH@)7,L(&]R('5S92!T:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*
M;7-G:60@(D5M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@V.0IM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP87-T<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHV.`HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")*^W-U(&4M<&%S=&$@861R97-E.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-C,*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ.3@Y"B,L(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;B(*;7-G<W1R(")#:71A(&EN9F]R;>)C:6IA(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O
M+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR.3@*(RP@9G5Z>GD*;7-G:60@(D5M;W1I
M8V]N<R(*;7-G<W1R(")/<&-I:F%S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"B,L(&9U>GIY"FUS9VED(")%
M;7!T>2!M97-S86=E+B(*;7-G<W1R(")4=6OP<R!R97IU;'3B=',N(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM
M<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4=6OP<R!R97IU;'3B=',N
M(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I
M9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C@Q,0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B
M16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO
M;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E
M="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT
M97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.3$*;7-G:60@(D5N=&5R
M('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0U(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HU-0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,V
M('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z.#(*;7-G:60@(D5R<F]R(@IM
M<V=S='(@(DOO^V1A(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@
M8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG
M('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D
M96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V97)Y
M(#$U(&UI;G5T97,B"FUS9W-T<B`B2V%T<F%S(#$U(&UI;OMT97,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"B,L(&9U>GIY"FUS9VED(")%=F5R
M>2`R(&UI;G5T97,B"FUS9W-T<B`B2V%T<F%S(#4@;6EN^W1E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S8@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X-PIM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*;7-G<W1R(")+871R87,@
M,S`@<V5K=6YD97,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E
M<R(*;7-G<W1R(")+871R87,@-2!M:6[[=&5S(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G
M:6XB"FUS9W-T<B`B2V%T<N(@<&EE<VSG9_!A;N)S(')E:7KG(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,`IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(DMA=')U('!U<W-T=6YD=2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM<V=I9"`B
M179E<GD@;6EN=71E(@IM<V=S='(@(DMA=')U(&UI;OMT:2(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E
M<SHB"FUS9W-T<B`B4&%R875G=N=R=.YB87,B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS
M,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@
M)RDG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S
M+G!H<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@
M<V5A<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*
M;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O
M;&]R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*
M;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B3F5I>F1E=N)S('-A
M\F5M="!I97-T873N:G5M=7,N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*
M;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G
M<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G
M:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@
M(DYE:7ID97;B<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@V"B,L('!H<"UF;W)M870*;7-G
M:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G
M<W1R(").96EZ9&5VXG,@<&EE<VSG9W1I97,@3$1!4"!S97)V97)I;2XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL
M960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DYE:7ID97;B
M<R!P:65S;.=G=&EE<R!,1$%0('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(DYE:7ID97;B<R!S
M8?)E;70@:65S=&%T[FIU;75S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&87)O92!)<VQA;F1S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*(RP@9G5Z
M>GD*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("))96SB9&5S(&ML^V1A
M.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&86MS<R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S
M='(@(D9A:W-S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS
M9VED(")&:6QE(@IM<V=S='(@(E9I<G-R86MS=',B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O
M=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.
M86UE(@IM<V=S='(@(E;B<F1S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X-@IM<V=I9"`B1FEL92!U<&QO
M860B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP
M:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS9VED
M(")&:6QT97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA
M;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I
M9"`B1FER<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R
M=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS
M9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG
M="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&
M;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B4&EE
M>NYM97,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O
M<G1U;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0U,PIM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C`*;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")6XG)D<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R
M86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET
M;W)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0X(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0P-@IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L(&9U>GIY"FUS9VED(")&
M=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(E!I;&YS(&%P<F%K<W1S.B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V
M"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-C`*(RP@9G5Z>GD*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")*^W-U(';B
M<F1S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'
M96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T
M960@0V]D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.
M86UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R
M"FUS9VED(")';R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE
M($UA<',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT
M,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y
M<V-A;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B
M1W)E96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=R965N;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'
M<F5N861A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS
M9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L
M('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE
M=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS,30@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-S<*;7-G:60@(D=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS
M97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E
M<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0W,`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S
M='(@(DMO;G1A:W1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R:71H;2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,3D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM
M<V=I9"`B2&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@
M(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED
M(")(96EG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H
M96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(E!A;.YD>NYB
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S$*(RP@9G5Z>GD*;7-G:60@(DAE
M;'!E<B(*;7-G<W1R(")086SN9'KN8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@
M9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED(")(;U]M92(*;7-G<W1R
M(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I9"`B2&]M92(*;7-G<W1R
M(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(DWB:F%S(&%D
M<F5S92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M
M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G
M<W1R(")-XFIA<R!T96QE9F]N<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N
M9'5R87,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO
M;F<B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U
M"FUS9VED(")(;W)D92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#0R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HR.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO
M(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,U"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3(U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED
M(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E
M<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R
M964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@
M)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@
M(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E
M('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET>3H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B
M2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B2'5N
M9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S
M(@IM<V=S='(@(D%D<F5S92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B
M87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H
M<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$
M4B!B;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V
M:6]L871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2
M;W<@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E
M;&%N9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<V
M"FUS9VED("))8V]N<R!/;FQY(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@
M)7,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-PIM
M<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y
M960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I
M9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O
M>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<S"FUS
M9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L
M('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X
M"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED
M("));6%G92!54DPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G
M92!54DPZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8Q"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T
M<B`B265LXF3G=&%I<R!L875K<SH@)7,B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G1E9"!F
M:65L9#H@)7,B"FUS9W-T<B`B265LXF3G=&%I<R!L875K<SH@)7,B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("));7!O<G1E9"!F
M:65L9',Z(@IM<V=S='(@(DEE;.)DYW1I92!L875K:3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G
M:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@HC+"!F=7IZ
M>0IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B3/MD>G4@;F]RXF1I970@<V%V=2!L:65T;W3B:F$@=N)R9'4@
M=6X@<&%R;VQI(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*
M;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D
M<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I
M9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM
M<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR-30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S0*
M;7-G:60@(DEN9&EV:61U86P@57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@P"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4W"B,L
M(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B(*;7-G<W1R(")*^W-U(&EN9F]R
M;>)C:6IA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`IM
M<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS
M97)T(%=E8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T
M(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("))
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H
M92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@
M(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C
M96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED
M("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("))
M;G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS
M97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A
M9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A
M9W)A<&@@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R
M;W<@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B
M969O<F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D
M:69Y($EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN
M:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S,PIM
M<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3<P"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN
M=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L
M:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV
M86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED
M(&9I;&4@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S<*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*
M;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.38*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z,C<*;7-G
M:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S,*;7-G:60@(DEN=F%L
M:60@<&%R=&YE<B!I9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P
M-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV
M86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y
M"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES<W5E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CD*;7-G:60@(DET86QI8R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#(*(RP@9G5Z>GD*;7-G:60@(DET86QY(@IM<V=S='(@(DEK9&EE;F%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R"FUS9VED(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#$*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED
M(")*86YU87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P
M86XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*;7-G
M:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I
M<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES
M('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G
M:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIO
M<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N
M92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED
M(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+87IA
M:VAS=&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-C0*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE
M;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B
M2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G
M:60@(DME>2!4>7!E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B
M"FUS9W-T<B`B6FGR82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G
M:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@X"FUS
M9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V
M"FUS9VED(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED
M(")+>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G
M<W1R(")686QO9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O
M<F0@0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM<V=I9"`B
M3&%S="!5<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V"FUS
M9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*(RP@9G5Z
M>GD*;7-G:60@(DQA>6]U="(*;7-G<W1R("))>FEE="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E
M(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$Y"FUS
M9VED("),969T(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3$U"B,L(&9U>GIY"FUS9VED("),969T('9A;'5E<R(*
M;7-G<W1R(")087)A=6=VYW)T[F)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(DYE:V%D
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*(RP@9G5Z>GD*
M;7-G:60@(DQI9VAT(%)A:6XB"FUS9W-T<B`B4&EE<VSG9W1I97,B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B
M3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,
M871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G
M:60@(DQI9VAT(%-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO
M=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM
M<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R(")0
M:65S;.=G=&EE<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G
M:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E
M>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PIM<V=I9"`B3&EN
M:W,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS
M9VED("),:6YU>"!#;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-
M05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R
M(&-A;B!S964@=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(
M96QP(%1O<&EC<R(*;7-G<W1R(")087+B9.YT('!A;.YD>NYB87,@=&5M871U
M<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B
M;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*
M;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R(")087+B9.YT('!A;.YD>NYB87,@
M=&5M871U<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DS"FUS9VED("),:7-T+5!O<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R
M:6)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R
M<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED
M("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L('!H<"UF;W)M870*;7-G:60@(DQI
M<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C(*;7-G:60@(DQI<W1I;F<@=7-E
M<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),
M;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C0*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A<BYP:'`Z
M-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN+G!H<#HQ
M-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G:60@(DQO
M9R!I;B(*;7-G<W1R(")0:65S;.=G=&EE<R(*"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y;F,@
M<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DEZ:65T(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS9VED("),;V=I
M;B(*;7-G<W1R(")0:65S;.=G=&EE<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,#<*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@
M(E5Z9&5V=6UI(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DV"B,L
M(&9U>GIY"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G
M<W1R(")0:65S;.=G=&EE<R!N96EZ9&5VXG-I+DYE<&%R96EZ<R!L:65T;W3B
M:F$@=N)R9',@=F%I('!A<F]L92XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.3(*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0HC+"!F=7IZ>0IM<V=I9"`B
M3&]N9R!T97AT(@IM<V=S='(@(DEZ:65T(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB
M"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q
M"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUA8V%O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A<V-A<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*(RP@9G5Z>GD*;7-G
M:60@(DUA9VEC(@IM<V=S='(@(E!A<W1S(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@(E!A<W1S(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I9"`B36%I;"!!9&UI
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QA=VDB
M"FUS9W-T<B`B4&%S=',B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")-86QI(@IM
M<V=S='(@(E!A<W1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-
M86QT82(*;7-G<W1R(")087-T<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-3,*
M;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B36%P475E<W0@
M;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B
M36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC+"!F=7IZ>0IM<V=I9"`B36%R9VEN
M(@IM<V=S='(@(D)R[F1I;N)J=6US(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI
M;F<@9FEE;&1S(@IM<V=S='(@(E-A<VMA;F_P:64@;&%U:VDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS9VED(")-
M87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO
M=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3@*
M;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M($YU;6)E<B!O9B!0;W)T
M86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(DUA>&EM=6T@;&5N9W1H
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*(RP@9G5Z>GD*;7-G
M:60@(DUE;6)E<G,B"FUS9W-T<B`B5&5K<W1I(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B365S<V%G92(*;7-G<W1R(")::?)A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@
M9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`B6FGR82(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@='EP92(*
M;7-G<W1R(")::?)A(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED
M(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L(&9U>GIY
M"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R(")3[FOB:V$@:6YF;W)MXF-I:F$@:7(@;F]S^W3N=&$@861M:6YI<W1R
M871O<F%M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*
M;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H
M;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED
M(")-:61D;&4B"FUS9W-T<B`B4&%S=',B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E
M>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,S0*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G
M<W1R(")+[_MD82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I
M9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I
M;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@
M36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@
M240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE($UA:6PB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W,PIM<V=I9"`B
M36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O
M=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N
M9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM<V=I9"`B
M36]N=&AL>2(*;7-G<W1R(")+871R=2!MYVYE<VDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H
M87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H
M<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF
M;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA
M;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM
M<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,T"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-
M;W-T;'D@4W5N;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z-3`Y"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS
M9VED(")-;W9E($QE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P
M-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS9VED(")-;W9E(&1O=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-3(T"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3@T"FUS9VED(")-=6QT:2UL979E;"!D<F]P
M(&1O=VX@;&ES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C$P-34*;7-G:60@(DUU;'1I;6%P(%5+(&UA
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0R
M"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C;W5N="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*(RP@9G5Z
M>GD*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B2OMS
M=2!I;F9O<FWB8VEJ82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z
M-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z,3,V"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS9VED(").86UE(@IM<V=S
M='(@(E;B<F1S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B
M3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E($-!(%)E
M=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE
M='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R
M=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S,U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#8*;7-G
M:60@(DYE=F5R(@IM<V=S='(@(DYE:V%D(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED
M(").97<@0V%L961O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R
M+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(").
M97<@365S<V%G92!T;R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R
M;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`B4&%R;VQE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN
M<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL
M;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R(")0:65Z[FUE<R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#4*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI
M;F,Z,34@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT
M(&]P=&EO;G,B"FUS9W-T<B`B071G<FEE>G1I97,@<&EE(&]P8VEJXFTB"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*
M;7-G<W1R(").96MA9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S@P
M"FUS9VED(").:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@
M(DYI=64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED
M(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD
M87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B4U%,(&%U=&5N=&EF:6OB8VEJ86D@;F%V(&YO<N)D[G1A(&MO;F9I
M9W5RXF-I:F%S(&EN9F]R;>)C:6IA+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N
M<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@(D%T
M8V5L="!I>FUA:?)A<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI
M<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,@HC
M.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B4U%,(&MA=&5G;W)I:N)M(&YA=B!N
M;W+B9.YT82!K;VYF:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R-`HC+"!F=7IZ>0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N(@IM<V=S='(@(DQ$05`@:65S=&%T[FIU;6]S(&YA=B!N;W+B9.YT82!K
M;VYF:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C8V.0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S
M='(@(E-13"!K871E9V]R:6KB;2!N878@;F]RXF3N=&$@:V]N9FEG=7+B8VEJ
M87,@:6YF;W)MXF-I:F$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<Q-PHC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T
M<B`B4U%,(&MA=&5G;W)I:N)M(&YA=B!N;W+B9.YT82!K;VYF:6=U<N)C:6IA
M<R!I;F9O<FWB8VEJ82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP
M.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3(X(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$R,PIM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"FUS9VED
M(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@
M(DYO(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").
M;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU
M;6)E<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G
M:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N
M<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HW-R!F<F%M97=O<FLO075T
M:"]!=71H+VQO9VEN+G!H<#HX-`HC.B!F<F%M97=O<FLO075T:"]!=71H+W!A
M;2YP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(&%U=&5N
M=&EF:6OB8VEJ86D@;F%V(&YO<N)D[G1A(&MO;F9I9W5RXF-I:F%S(&EN9F]R
M;>)C:6IA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ
M,S4*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"!A=71E;G1I9FEK
MXF-I:F%I(&YA=B!N;W+B9.YT82!K;VYF:6=U<N)C:6IA<R!I;F9O<FWB8VEJ
M82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z
M>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N
M=&EC871I;VXN(@IM<V=S='(@(E-13"!A=71E;G1I9FEKXF-I:F%I(&YA=B!N
M;W+B9.YT82!K;VYF:6=U<N)C:6IA<R!I;F9O<FWB8VEJ82XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R.#8*;7-G:60@(B(*(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*(G=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*
M(RP@9G5Z>GD*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E!I97KN;65S(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Y"FUS9VED(").;R!S
M97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"B,L(&9U>GIY
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R(")0:65Z[FUE<R(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S
M.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R
M(&-A8VAE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=VEN7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DS[9'IU(&YO<N)D
M:65T('-A=G4@;&EE=&]TXFIA(';B<F1U('5N('!A<F]L:2(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!8
M34P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C`*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE
M8W0N:6YC.CDS"B,L(&9U>GIY"FUS9VED(").;VYE(@IM<V=S='(@(E3B;')U
M;FES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M
M.#@U.2TQ,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").;W)F
M;VQK($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F]R=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(DYO="!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z-#`X"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H
M<#HV,PHC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L
M96UE;G1E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*
M;7-G<W1R(")0:65Z[FUE<R(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HU-S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S='(@(E!I97KN;65S(@H*
M(SH@<V5R=FEC97,O;V)R;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H
M:6YG('1O(&)R;W=S92P@9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S4*(RP@9G5Z>GD*;7-G
M:60@(DYO=F5M8F5R(@IM<V=S='(@(DYE:V%D(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(E;B<F1S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-0IM
M<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@
M(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R<R!N;W0@<W!E
M8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")/8FIE8W0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*;7-G
M:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED
M(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HY,@IM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,R-@IM<V=I9"`B3V9F:6-E(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU.`IM<V=I
M9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S8*
M(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")087)O;&4B
M"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@
M<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS
M:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I
M9"`B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS
M9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q
M"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(D]P8VEJ87,B"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S
M='(@(D]P8VEJ87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@
M(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@56YI
M="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R
M"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP
M;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/
M=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")#:71A(&EN9F]R;>)C:6IA(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,0IM<V=I9"`B3W=N97(@
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S,3D*
M;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q"FUS9VED(")01U`@4'5B
M;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`HC+"!F=7IZ
M>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I
M9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS.0IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G
M:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3
M:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,0IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B
M4&%S<W=O<F0B"FUS9W-T<B`B4&%R;VQE(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C@R"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E
M<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,S(R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!I;F-O
M<G)E8W0B"FUS9W-T<B`B4&%R;VQE(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R
M(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDP"B,L(&9U>GIY"FUS9VED(")087-S=V]R9#HB"FUS9W-T
M<B`B4&%R;VQE(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*
M(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%R;VQE(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM
M<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"FUS
M9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B
M4&5O<&QE(@IM<V=S='(@(DQO;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M
M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM
M<V=S='(@(DEZ<&EL9.YT('5Z='5RY_!A;F%S(&]P97+B8VEJ87,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED(")097)F
M;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@
M(DEZ<&EL9.YT('5Z='5RY_!A;F%S(&]P97+B8VEJ87,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H
M<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X
M-@IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P97)M<R]A
M9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I;VYS($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B4&5R<V]N86P@26YF;W)M871I;VXB
M"FUS9W-T<B`B0VET82!I;F9O<FWB8VEJ82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B4&5R=2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0:&EL:7!P:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R
M(")4XFQR=6YI<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S@*
M;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED
M(")0:71C86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"FUS9VED(")0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM
M<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,`IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+B(*;7-G<W1R("),^V1Z=2!N;W+B9&EE="!P<F]B;.=M
M87,@86YO=.)C:6IU+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B
M3/MD>G4@;F]RXF1I970@<V%V=2!L:65T;W3B:F$@=N)R9'4@=6X@<&%R;VQI
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0
M;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E
M('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R
M+G!H<#HW,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N
M86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*;7-G:60@
M(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HT.#<*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I
M9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B
M4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET
M871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3@*;7-G:60@(E!R96-I<&ET
M871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+VQD87`N<&AP.CDX"FUS9VED(")0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R
M-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S4*
M;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W
M('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P
M=&EO;G,B"FUS9W-T<B`B071G<FEE>G1I97,@<&EE(&]P8VEJXFTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED
M(")0<FEN="!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*
M(RP@9G5Z>GD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B6U!R;V)LYVUA<R!Z
M:?)O:G5M<UTB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@
M(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FSG;6%S(&%P<F%K
M<W1S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B
M4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@X"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#4*;7-G:60@(E!R;VUP="!T97AT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!
M;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G
M:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C
M97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U
M97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A
M=&%R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM<V=I
M9"`B475E<GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"FUS9VED(")1=6]T82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")2
M4T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#,*;7-G:60@(E)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R
M;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B
M4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS
M9VED(")2871I;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C,R-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,T"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z-C@@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-"!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-PHC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$X,`IM<V=I9"`B4F5A9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R(")::?)A(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R
M96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F
M<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ
M"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC+"!F=7IZ>0IM
M<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE=SHB"FUS9W-T<B`B071J875N;W0@
M:V]P<V%V:6QK=6UA('-K871U.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E
M;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T"FUS9VED(")296UO=&4@4V5R=F5R
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3,*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92(*;7-G<W1R("))>F1ZYW-T('#B
M<FDB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R("))>F1ZYW-T('#B<FDB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W
M"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@9G5Z>GD*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO
M=F4@<&%I<B(*;7-G<W1R("))>F1ZYW-T('#B<FDB"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R
M;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(DEZ
M9'KG<W0@<.)R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F
M<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M=7-E<B(*;7-G<W1R("))>F1ZYW-T('#B<FDB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R("))>F1ZYW-T('#B<FDB"@HC
M.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$U-PIM<V=I9"`B4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B4&EE<')A<^YT86ES
M("=U:60G(&YA=B!N;W+B9.YT<R!I97-T873N:G5M=2!K;VYF:6=U<N)C:6KB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<U(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")0:65P<F%S[G1A:7,@)W5I9"<@;F%V(&YO<N)D[G1S
M(&EE<W1A=.YJ=6UU(&MO;F9I9W5RXF-I:N(N(@H*(SH@9G)A;65W;W)K+U5T
M:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")0:65P<F%S[G1A:7,@)W5I9"<@;F%V(&YO<N)D[G1S(&EE
M<W1A=.YJ=6UU(&MO;F9I9W5RXF-I:N(N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-#8*(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L92(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S`*;7-G:60@(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE
M;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T
M;R!/<'1I;VYS(@IM<V=S='(@(D%T9W)I97IT:65S('!I92!O<&-I:N)M(@H*
M(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y
M<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G
M:60@(E)E=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E
M<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,R"B,L(&9U>GIY"FUS9VED(")2:6-H(%1E>'0@161I=&]R
M($]P=&EO;G,B"FUS9W-T<B`B071G<FEE>G1I97,@<&EE(&]P8VEJXFTB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PIM
M<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`IM<V=I9"`B
M4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS
M9W-T<B`B3&]M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(R"FUS9VED(")2
M;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G
M:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(E)U
M;&5S(@IM<V=S='(@(DQO;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,C`*;7-G:60@(E)U;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)
M344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-
M12!%;F-R>7!T960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S
M86=I;F<B"FUS9W-T<B`B6FGR82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR
M,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A
M;'5E(&QO;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,34S"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S
M(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A
M:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3879E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B4V%G;&%BXG0@;W!C:6IA
M<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@
M3W!T:6]N<R(*;7-G<W1R(")386=L86+B="!O<&-I:F%S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G
M<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM
M<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@
M(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(DEZ=N=L
M:65T:65S(&1A='5M82!F;W)MXG1U.B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I
M9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V
M"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED
M(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C
M;VUP;VYE;G1S+B(*;7-G<W1R("))>G;G;&EE=&EE<R!D871U;6$@9F]R;>)T
M=3HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@
M(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M(@IM<V=S='(@(B(*(DEZ=N=L:65T:65S('-I;6)O;'5S(&YO('IE;>)K(')E
M9'IA;6%JXFT@:7IVYVQNYVTN(%#G8R!T86T@:OMS('9I\G5S('9A<F%T("(*
M(G#B<FYE<W0@87(@8V]P>2]P87-T92(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R("))>G;G;&EE=&EE<R!D871U;6$@871D86SN=.)J=3HB"@HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT-`IM<V=I9"`B4V5L96-T('1H92!D
M871E(&9O<FUA=#HB"FUS9W-T<B`B27IVYVQI971I97,@9&%T=6UA(&9O<FWB
M='4Z(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY
M,`IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*
M;7-G<W1R("))>G;G;&EE=&EE<R!D871U;6$@871D86SN=.)J=3HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`B27IVYVQI971I97,@;&%I:V$@9F]R;>)T
M=3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")3
M96QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B27IVYVQI971I
M97,@9&EV=7,@<V%D97+N9W5S(&QA=6MU<RXB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`V"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#@*;7-G
M:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B
M27IVYVQI971I97,@=F%L;V1U.B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(DYO<_MT[G0@<')O8FSG;6%S('!I971E:6MU;74B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N
M9"!335,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I
M9"`B4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM
M<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I
M86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@
M(E-E<W-I;VX@240@97AP:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP
M:'`Z,30U"B,L(&9U>GIY"FUS9VED(")397-S:6]N<R(*;7-G<W1R(")386=L
M86+B="!O<&-I:F%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q
M-`IM<V=I9"`B4V5T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3
M970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@
M9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@T"B,L(&9U>GIY"FUS9VED(")3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S
M='(@(DEE<W3B9.YT(&QA<'5A=&IA=6YO\&%NXG,@=6X@8VET87,@96MRXFYA
M(&]P8VEJ87,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"B,L(&9U
M>GIY"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I
M<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B265S=.)D[G0@;&%P=6%T:F%U;F_P
M86[B<R!U;B!C:71A<R!E:W+B;F$@;W!C:6IA<RXB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C<U"FUS9VED(")3971U<"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T
M=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@V"FUS9VED(")3979E<F%L
M(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@
M(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C0S"B,L(&9U>GIY"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(LYS82!A;F]TXF-I:F$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y,`IM<V=I9"`B4VAO=R!L87-T
M(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8U"FUS9VED(")3:&]W(&]P=&EO
M;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L
M;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8T"FUS9VED(")3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA
M;&]G(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4P"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED
M(")3:&]W97)S($QA=&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C0X,`IM<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.CDX-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HQ,#0W(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C$P.#<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q
M-B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"FUS9VED
M(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F
M('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G
M:60@(E-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<Q,0IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H
M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,PIM
M<V=I9"`B4VEZ92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC
M92(*;7-G<W1R("))>FQA:7-T('5Z='5RY_!A;G4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V86MI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3;&]V96YI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM
M<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X
M"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I9"`B
M4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T
M-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F
M=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B1&%R8F$@861R
M97-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<W"FUS9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I
M8V@@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED
M(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")3<&%I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.3@*;7-G:60@(E-P86TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!)
M;G!U="(*;7-G<W1R("+.<&'P;R!S:6UB;VQU(&EE=F%D92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G
M:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@
M8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*(RP@9G5Z>GD*
M;7-G:60@(E-P;W)T<R(*;7-G<W1R("))96SB9&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-S,@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`HC+"!F
M=7IZ>0IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B2V%L96YDXG)S(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3=&%R(%1R96LB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y-B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3=&%R="!Y96%R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A
M='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(DK[
M<W4@:6YF;W)MXF-I:F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D9')E<W,B"FUS
M9W-T<B`B1&%R8F$@861R97-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,S"FUS9VED
M(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D
M<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8F1I
M<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").878@<W1R;V1A
M;7,@<&%Z:?)O:G5M=2!K;&%U<^YTXFIS("5S(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$W"FUS9VED(")3=6)M
M:70B"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HT.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@7"(E<UPB('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*
M(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@
M(E-U8G-C<FEP="(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B
M5F5I:W-M92(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M
M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U
M<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E
M9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R
M(")-86YS(&MO<'-A=FEL:W5M<R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED
M(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM
M<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B4W5N<FES93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3D*;7-G
M:60@(E-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$X"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED
M(")3=7!E<G-C<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S<X"B,L(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@
M(DEE;.)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(DQI971O=.)J82!VXG)D<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N
M86UE(@IM<V=S='(@(DQI971O=.)J82!VXG)D<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T,@IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME
M>7=O<F1S+G!H<#HY-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T
M97)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@
M07)A8B!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"B,L(&9U
M>GIY"FUS9VED(")44U8@9FEL92(*;7-G<W1R(")6:7)S<F%K<W1S(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@
M(E1A8FQE(@IM<V=S='(@(E9I<G-R86MS=',B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED(")486)L
M92!0<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTO5'EP92]T86)L97-E="YP:'`Z-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM
M<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S='(@(E5Z9&5V=6UI(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C8X-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,V"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S4*;7-G:60@(E1E>'0@3VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)
M4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL
M86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX
M.`HC+"!F=7IZ>0IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+B(*;7-G<W1R(")*^W,@97-A="!I>F?B:FES(&YO('-I<W3G;6%S+CQB
M<B`O/E!A;&1I97,@<&%R('-I<W3G;6%S(&QI971O\&%N=2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM<V=I9"`B5&AE($944"!E>'1E
M;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S
M=7!P;W)T(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"]";V]K+G!H<#HQ,CDR"FUS9VED(")4:&4@24U34"!L;V<@8V]U
M;&0@;F]T(&)E(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ
M(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@
M4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T
M;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T
M;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3$V.0IM<V=I9"`B(@HB5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*
M(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A
M8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@
M;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N
M(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3<U(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C@@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T
M:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O
M(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82YP
M:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM
M<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U
M<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y
M+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W
M<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX
M(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@
M(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D
M96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@
M1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ
M(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$
M3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E
M('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E
M;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-PIM<V=I9"`B
M5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P
M86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0T,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S
M="!B92!N=6UE<FEC+B(*;7-G<W1R("+086D@=N=R=.YB86D@:7(@:N)B^W0@
M<VMA:71L:6TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@
M9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G
M:60@(E1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N
M9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M
M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S
M879E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O
M=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E
M;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE
M('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T
M:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS9VED(")4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4
M:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L
M;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R
M+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`HC+"!F=7IZ
M>0IM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G
M<W1R("))97-T873N:G5M:2!N878@<&EE96IA;6DB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#(*;7-G:60@(E1H97)E(&%R92!N
M;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@(@HB>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B
M"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<
M(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN
M9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A
M<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE
M('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B
M"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T
M:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@
M9FEE;&0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@
M;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,30U"B,L(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T
M('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`BT&%I
M(';G<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB
M5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G
M:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*
M(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A
M>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HY-S@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,34*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R
M.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S@Q-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES
M(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@
M9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T
M(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.CDX.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R("+086D@=N=R=.YB86D@:7(@:N)B
M^W0@<VMA:71L:6TN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@S
M-@IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C
M;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@(@HB)R,Q
M,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HU-C$*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC
M.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W
M87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N
M=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M
M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R("+0:6T@<VMA:71L
M:6T@:7(@:N)B^W0@=FES;6%Z(#$N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E<B!C86XG
M="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G
M:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*
M;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B
MT&%I(';G<G3N8F%I(&ER(&KB8OMT('-K86ET;&EM+B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W
M(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C0*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B5&EM92(*;7-G<W1R
M(")6:7)S<F%K<W1S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X
M-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I
M;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*
M;7-G:60@(E1I=&QE(@IM<V=S='(@(E9I<G-R86MS=',B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L
M92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-30*
M;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI
M;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@
M(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@
M(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4
M;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS
M;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN
M:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K
M97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G
M:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@(E1Y<&4@>6]U
M<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(T.2!L
M:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM<V=S='(@(E52
M3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I9"`B55),.B(*
M;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,3(*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@
M4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,C,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX,S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<W%L+G!H<#HT,S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@
M4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#,Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-3
M3"XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R
M=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C(U(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(P.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE<VSG9W1I97,@4U%,('-E<G9E
M<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B3F%V
M(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*
M;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S(%-13"!S97)V97)I
M;2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW
M-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*
M;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI;B]P
M97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z,SDR"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P
M:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYA=B!I97-P
MYVIA;7,@<V5S:6KB(')E[&ES='+G="!I97-T873N:G5M=7,N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Y-B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@
M9FEL92XB"FUS9W-T<B`B3F%V(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@
M<V5R=F5R:6TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B
M56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE+B(*;7-G<W1R(").878@:65S<.=J86US('!I97-LYV=T:65S
M(%-13"!S97)V97)I;2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C0U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C
M;VUP<F5S<V5D(&%R8VAI=F4N(@IM<V=S='(@(DYA=B!I97-PYVIA;7,@<&EE
M<VSG9W1I97,@4U%,('-E<G9E<FEM+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE
M<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`IM
M<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F%V(&EE
M<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR-C<@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM<V=I
M9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@
M(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S
M='(@(DYA=B!I97-PYVIA;7,@:6YT97)P<F5TYW0@\&\@5V]R9"!D;VMU;65N
M='4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N86)L92!T;R!W<FET92!6
M1E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R
M;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV
M"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B071C96QT(&EZ;6%I\F%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM<V=I
M9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T
M:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A
M=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O
M9&4@*%541BTX*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI
M=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")5;FET960@2VEN9V1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S
M"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N:VYO
M=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B
M56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C(Y-@HC
M+"!F=7IZ>0IM<V=I9"`B56YN86UE9"(*;7-G<W1R("),:65T;W3B:F$@=N)R
M9',B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C
M=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N
M;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@
M86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E
M;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G
M:60@(E5P9&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R
M=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S@@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Y.0IM<V=I9"`B
M57!L;V%D(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P"FUS9VED(")5
M<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@
M(E5P<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@
M(E5S92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R-`IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0HC+"!F=7IZ>0IM<V=I9"`B57-E<B(*
M;7-G<W1R("),:65T;W3B:F$@=N)R9',B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O4F5G:7-T<GDN<&AP.C<R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO;G,B"FUS9W-T<B`B3&EE=&]TXFIA
M(&]P8VEJ87,B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("),:65T;W3B:F$@;W!C:6IA<R(*
M"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C;W5N
M="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM
M<V=I9"`B57-E<FYA;64B"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PHC
M+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(DQI971O=.)J82!V
MXG)D<R(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z
M>GD*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3&EE=&]TXFIA(';B<F1S
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B
M57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-`IM<V=I9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C4U"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$X"FUS
M9VED(")686-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L
M=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@
M:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O
M('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R-@IM<V=I9"`B5F5R<VEO
M;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L
M:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I8V%L('!A9&1I;F<B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")697)Y($AI
M9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@
M(E9I971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD
M<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P
M.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A
M;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!
M3$Q9($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U
M;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(D)R[F1I;N)J=6US
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,C<*;7-G:60@
M(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")7
M96(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M-PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM
M<V=S='(@(DMA=')U(&YE9.?O=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")796QC;VUE(@IM<V=S='(@(DQA
M:7!N:2!L^V1Z;2P@)7,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("),86EP;FD@;/MD>F%M
M("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(DQA:7!N:2!L^V1Z;2P@)7,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM
M,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.38*;7-G
M:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G
M:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*
M;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,S"FUS9VED(")7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4*;7-G:60@(E=I9'1H
M(&EN($-34R!U;FET<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S4W"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED
M(")7:61T:#HB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C4Q,PIM<V=I9"`B5VEK:2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7
M:6YD($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@
M(E=I;F0Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C0*;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3DV"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,38T"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`B1&%R8F$@861R97-E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")$87)B82!TXFQR=6YI<R(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C,P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&
M4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C0S"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y
M(%5S86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV
M92!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@
M(D='(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4U"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(D='(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@
M(EEA:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@
M(DMA=')U(&=A9'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.38S"FUS9VED(")997,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!
M9W)E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C@R
M"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A<F4@;F]T(&%L;&]W960@=&\@
M8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,30Q,0IM<V=I9"`B66]U(&%R92!N
M;W0@875T:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED
M96YT:71Y+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA
M=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N
M=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T
M960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G
M<W1R(")*^W-U(&]P8VEJ87,@:7(@<V%G;&%BXG1A<RXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D
M:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!V86QU92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3
M:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A
M5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D
M97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P
M<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B07!R86MS=&EE="!P<F]B;.=M=2!P
M:7)M<R!P:65T96EK=6UA('/[=.[P86YA<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E
M;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G:60@
M(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO
M=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z
M,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9
M;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N
M(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B2OMS=2`E<R!S97-I:F$@
M:7(@8F5I9W5S:65S+B!,^V1Z=2!P:65S;.=D>FEE=&EE<R!A=&OB<G1O=&DN
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*(RP@9G5Z
M>GD*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")*^W-U(&4M
M<&%S=&$@861R97-E.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*
M(RP@9G5Z>GD*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B
M2OMS=2!E+7!A<W1A(&%D<F5S93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@
M(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`B2OMS=2!I;F9O<FWB8VEJ82(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*
M(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B2OMS=2!V
MXG)D<SHB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0IM
M<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@
M2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U
M<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E
M(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I
M;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP
M.C4P"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N
M93HB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U
M>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA
M;F=E9"XB"FUS9W-T<B`B2OMS=2!O<&-I:F%S(&ER('-A9VQA8N)T87,N(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$U.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")087)A<W3B(&ED96YT
M:73B=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`Q"B,L(&9U>GIY
M"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B2OMS=2!VXG)D<SHB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")*^W-U(&]P
M8VEJ87,@:7(@<V%G;&%BXG1A<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN(@IM<V=S='(@(DK[<W4@;W!C:6IA<R!I<B!S86=L86+B
M=&%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34V"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@
M(DK[<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z-S,R"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6F%I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B
M6FEP<'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D
M(%1E>'1=(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X
M"FUS9VED(");4')O8FQE;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;.=M87,@
M>FGR;VIU;7-=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C
M:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN
M92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)I;F1A("5S(&YO("5S72(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T,2!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*(RP@9G5Z>GD*
M;7-G:60@(E](96QP(@IM<V=S='(@(E!A;.YD>NYB82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I
M9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`HC+"!F=7IZ>0IM<V=I9"`B
M7TQO9R!I;B(*;7-G<W1R(")0:65S;.=G=&EE<R(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ.3`*(RP@9G5Z>GD*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(DEZ:65T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI
M;FLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE
M;G4N<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B
M3W!C:6IA<R(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I
M;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@HC+"!F=7IZ>0IM<V=I9"`B7U)E;6]V
M92!,:6YK+BXN(@IM<V=S='(@(DEZ9'KG<W0@<.)R:2(*"B,Z(&QI8B]A<&DN
M<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I
M9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@9G5Z>GD*;7-G:60@(F%D9')E
M<W,@8F]O:R(*;7-G<W1R(")+;VYT86MT:2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R97-S964@=6YK;F]W
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ
M,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B2V%L96YDXG)S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I
M9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N
M;F]T(&]P96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z-3DR"FUS9VED(")C;&EC:R!H97)E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R
M"FUS9VED(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@
M(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y
M<W1E;2!F:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R
M<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G
M:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O
M0G)O=W-E<BYP:'`Z.#4U"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@
M(E9I<G-R86MS=',B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W-"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO;65T87(N<&AP.C,X-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I
M9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U
M='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@97)R
M;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R
M(")6XG)D<R(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C$*;7-G:60@
M(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R,3D*;7-G:60@(FYO="!Y970@:6UP;&5M
M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,#4*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B
M<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE
M<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@
M97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(G)I
M<VEN9R(*;7-G<W1R(")"<NYD:6[B:G5M<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA
M8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*
M;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@
M(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,@IM<V=I9"`B<W1E861Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F(&IA=F%S8W)I
M<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B=&%S:R!L:7-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I
M9"`B=')Y(&%G86EN(@IM<V=S='(@(DMA='+B('!I97-LYV?P86[B<R!R96EZ
MYR(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O
M4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N:69I960B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR
M-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S
M97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A
M<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VYN7TY/+G!O````
M````````````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#8R-#,S-R`Q,#4Q-30S-#$T,B`P,3<U,S8`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````(R!(;W)D92!.;W)W96=I86X@3GEN
M;W)S:R!T<F%N<VQA=&EO;@HC($-O<'ER:6=H="`H0RD@,C`P,B!097(M4W1I
M86X@5F%T;F4*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE
M('-A;64@;&EC96YS92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!097(M4W1I
M86X@5F%T;F4@/'!S=D!O<G-T82YO<F<^+"`R,#`R+@HC(`IM<V=I9"`B(@IM
M<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN
M(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<
M;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<
M;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#8M,#@@,C(Z,S`K,#$P,%QN
M(@HB3&%S="U4<F%N<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S=D!O<G-T
M82YO<F<^7&XB"B),86YG=6%G92U496%M.B!.;W)W96=I86X@3GEN;W)S:R`\
M;GEN;W)S:T!O<G-T82YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C
M97-S:V5Y("5S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM
M<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,0IM<V=I9"`B("AY97-T
M97)D87DI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A('9A;&ED(&-H;VEC
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES
M=')Y+G!H<#HV-3D*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y
M+G!H<#HQ,#0R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G
M<W1R("(G)7,G(&5R(&EK:VIE(&MO;F9I9W5R97)T(&D@<F5G:7-T97)E="!T
M:6P@2&]R9&4N(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L
M('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T
M:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!V87)T(&QA9W0@=&EL
M(&=R=7!P97-Y<W1E;65T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G)7,G
M('9A<G0@;&%G="!T:6P@=&EL9V%N9W-S>7-T96UE="XB"@HC.B!A9&UI;B]G
M<F]U<',N<&AP.C4T(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E
M9#H@)7,N(@IM<V=S='(@(B<E<R<@=F%R="!I:VMJ92!O<'!R971T83H@)7,B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"!D
M87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@3F]T:7,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S('9E9&QI:V5H86QD<V]P97)A
M<VIO;F%R("T@4W1A9&9E<W1I;F<B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C(V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!3:6=N(%5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E
M96UE;G0B"FUS9W-T<B`B)7,@5FEL:^5R(&9O<B!A=G1A;&4B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C4@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92`B"B)B;W@@9F]R(&%N>2!O
M<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N
M(@IM<V=S='(@(DMR>7-S(&%V(&9O<B!O<&5R87-J;VXH87(I(&1U('9I;"!K
M^'ER92!N;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(DMV87)T(#4N(&UI;G5T
M="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ
M,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHT"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M(");;&EN:F4@)7,@878@)7-=(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D
M<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V5B;VLB"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.CDQ-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`V"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B)7,@+2!.;W1I<R(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,P"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO
M="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L
M;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"FUS9VED("(L(&=U<W1I;F<@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@X(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S
M=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V.2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3(X"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HW-#D*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*(RP@9G5Z>GD*;7-G:60@(C$R($AO
M=7(@1F]R;6%T(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B,C0@2&]U<B!&;W)M
M870B"FUS9W-T<B`B1&EN(&EN9F]R;6%S:F]N(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T('1I
M;6%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B
M/%!R979I;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R
M('1H:7,@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,38P"B,L(&9U>GIY"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9"(*;7-G<W1R("(\8CY$970@<VMJ961D92!E:6X@:V%T87-T
M<F]F86P@9F5I;#H\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI8R!0
M1U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED("(B"B)!('!U
M8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L:6,@4TU)344@
M:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY
M"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A
M:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-
M(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.0IM<V=I9"`B
M04TO4$TB"FUS9W-T<B`B04TO4$TB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW-`IM<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@
M(D%B<VUI9&1L92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@
M5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S
M='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R
M(")3=&%D9F5S="!P87-S;W)D(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE
M;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S
M,PIM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI
M;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z
M,3$*;7-G:60@(D%D9"(*;7-G<W1R("),96=G('1I;"(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"B,L(&9U>GIY"FUS
M9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B3&5G9R!T:6P@=6YD97)O
M<F1N82!O8FIE:W0B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(DQE9V<@=&EL
M('5N9&5R;W)D;F$@;V)J96MT=&EL9V%N9R!T:6P@)R5S)R(*"B,Z('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R
M93HB"FUS9W-T<B`B3&5G9R!T:6P@8G)U:V%R(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HR,3@@861M:6XO9W)O=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@
M1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"B,L(&9U
M>GIY"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B5&EL9V%N
M9R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P
M('1O(%PB)7-<(B(*;7-G<W1R("),96=G('1I;"!U;F1E<F]R9&YA(&]B:F5K
M=&=R=7!P92!T:6P@)R5S)R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C
M:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("),96=G('1I;"!U
M;F1E<F]R9&YA(&]B:F5K='1I;&=A;F<@=&EL("<E<R<B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(DQE
M9V<@=&EL(&YY(&)R=6MA<CHB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S0*(RP@
M9G5Z>GD*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),96=G('1I
M;"!N>71T(&UE9&QE;2(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(DQE9V<@=&EL('!A<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@8F]O:SHB"FUS
M9W-T<B`B061R97-S96)O:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HW.`HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<W-E8F]K(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(DQE9V<@=&EL(&)R
M=6MA<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@
M;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G
M(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB
M"FUS9W-T<B`B3&5G9R!T:6P@8G)U:V%R87(@97(@<VSE='0@878N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97-S92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,SD*
M;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E8F]K(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.30*(RP@9G5Z
M>GD*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R("<E<R<B"@HC
M.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI
M<W1R97)I;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Q"B,L
M(&9U>GIY"FUS9VED(")!9',B"FUS9W-T<B`B3&5G9R!T:6PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4V"FUS9VED(")!9F=H86YI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W
M"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(D%L:6%S(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B06QG97)I82(*;7-G<W1R(")!;&EA
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,#<*;7-G:60@(D%L:6%S(@IM<V=S='(@(D%L:6%S(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B06QI9VXB"FUS9W-T<B`B06QI87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE
M;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HX-PIM
M<V=I9"`B06QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G
M:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO9W)O=7!S+G!H<#HR,C(*(RP@9G5Z
M>GD*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B1W)U<'!E<B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B06QL(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$W"FUS9VED(")!;&P@
M9F]U<B!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B
M06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T
M"FUS9VED(")!;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3(S"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I
M;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS
M9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HS-0HC+"!F=7IZ>0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D
M9')E<W,B"FUS9W-T<B`B1&D@92UP;W-T861R97-S93HB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.CDU
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I
M;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM<V=S='(@(D5I;B!U;&]V
M;&5G('9E<F1I('9A<G0@<W!E<VEF:7-E<G0N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W
M;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B/&(^1&5T('-K:F5D9&4@
M96EN(&MA=&%S=')O9F%L(&9E:6PZ/"]B/B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*(RP@9G5Z
M>GD*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B1FYO<G)E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@
M(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS
M=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R
M8G5D82(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D
M;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*
M;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P<')O>&EM
M871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O
M=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8V"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA
M;64B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHQ,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\B"FUS9W-T<B`B17(@9'4@<VEK:V5R('#E(&%T(&1U('9I
M;"!S;&5T=&4@)R5S)S\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E
M;&5T92YI;F,Z-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO
M=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M
M9W)O=7!S/R(*;7-G<W1R(")%<B!D=2!S:6MK97(@<.4@870@9'4@=FEL('-L
M971T92`G)7,G/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H
M05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@07)T(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM
M<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS
M9W-T<B`B4W#X<B!O;2!S=&%D9F5S=&EN9R!F^'(@:_AY<FEN9R!A=B!V961L
M:6ME:&%L9'-O<&5R87-J;VYA<C\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E!R^'9D92#E
M('-L971T92!E:2!I:VMJ92UE:W-I<W1E<F%N9&4@9W)U<'!E+B(*"B,Z(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(E!R^'9D
M92#E('-L971T92!E:6X@:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0<OAV
M9&4@Y2!E;F1R92!E:6X@:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"B,L(&9U>GIY"FUS9VED
M(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S
M='(@(E!R^'9D92#E(&5N9')E(&5I;B!I:VMJ92UE:W-I<W1E<F%N9&4@=&EL
M9V%N9RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8T(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-@IM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`X"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B075G=7-T(@IM
M<V=S='(@(DQU<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@
M(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N
M<&AP.C$S-0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?8WER
M=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C,V"FUS9VED
M("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET
M8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP
M:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR
M8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@
M061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS
M,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R
M96UO=F4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-0IM<V=I9"`B075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VUC86PN<&AP.C0V"FUS9VED(")!=71H7VUC86PZ(%)E<75I<F5D($U#
M04P@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDP"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE
M8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O
M('1H92!334(@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD
M<SHB"FUS9W-T<B`B5&EL9VIE;F=E;&5G92!F96QT.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*
M;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,PIM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"86AA;6%S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$*(RP@9G5Z>GD*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`B0F%R8FEE(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/
M+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L
M861E<V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B
M"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H
M<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M"FUS9VED(")"96YI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M97)M=61A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")"=7)S9&%G(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P
M<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D9A;FX@:6MK
M:F4@=F%R<V5L;'ET=&%R("5S+B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C
M:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(P"B,L(&9U>GIY"FUS9VED(")";W)D97(B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Q
M"B,L(&9U>GIY"FUS9VED(")";W)D97)S(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O=&@B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B0F]T<W=A
M;F$B"FUS9W-T<B`B0G)U;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@
M(D4M<&]S="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0G)U;F5I($1A<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0T"B,L(&9U>GIY"FUS
M9VED(")#35,B"FUS9W-T<B`B0U93(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G
M:60@(D-?96QL(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z.3@W"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G
M:60@(D-A;&5N9&%R(@IM<V=S='(@(DMA;&5N9&5R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T-@HC+"!F=7IZ>0IM<V=I9"`B0V%L;2(*
M;7-G<W1R(")!=F)R>70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@
M(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86X@;F]T('=R:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HR,@IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E
M>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C,Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`HC+"!F=7IZ>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;&5N9&5R
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B079B
M<GET(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G
M:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")!=F)R>70@<')O
M8FQE;7)A<'!O<G0B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E
M9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+G!H<#HQ
M,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T
M851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G
M:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R
M(")!;'1E<FYA=&EV(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")#87)R:65R(@IM<V=S
M='(@(D)A<F)I92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#
M96QL(%!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*(RP@9G5Z
M>GD*;7-G:60@(D-E;&P@4')O<&5R=&EE<R(*;7-G<W1R(")-;V)I;'1E;&5F
M;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-`IM<V=I9"`B0V5L;"!P861D:6YG.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS
M9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@
M<W!A8VEN9SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3(W-`HC+"!F=7IZ>0IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO
M8FEL=&5L969O;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED
M(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED
M(")#96YT97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U
M.2TR*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0IM
M<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC
M871E(%!O;&EC:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`HC+"!F=7IZ
M>0IM<V=I9"`B0VAA9"(*;7-G<W1R(")V0V%R9"(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(RP@9G5Z>GD*;7-G:60@(D-H86YG92(*;7-G<W1R(")!;F=R92!E
M;F1R:6YG87(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*
M(RP@9G5Z>GD*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(E-T861F97-T('!A<W-O<F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C8*;7-G:60@(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M(@HB96UA:6QS+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR-PHC+"!F=7IZ>0IM<V=I9"`B0VAA<B(*;7-G<W1R(")V0V%R9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR-0IM<V=I9"`B0VAE8U]K($QI;FLN+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0VAI;&4B"FUS9W-T<B`B5&ET=&5L
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`B4W1A
M9&9E<W0@<&%S<V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3@*;7-G:60@(D-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I
M9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA
M;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR
M.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N
M(@IM<V=S='(@(D9A;FX@:6MK:F4@=F%R<V5L;'ET=&%R("5S+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY
M"FUS9VED(")#;&5A<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R
M($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN
M<&AP.C$R.`IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@=7-E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R(")+;&EK:R!F;W(@Y2!H86QD92!F<F%M(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS
M9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(DQU:VL@=FEN9&%U
M9V5T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D
M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED
M(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@4VED96)A<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP
M:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R-`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X-#8*;7-G
M:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-#8*
M;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(V-`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R(")&:7)M82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR
M,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-C8*;7-G:60@(D-O;6UO;B!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T
M"FUS9VED(")#;VUO<F]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS
M9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G
M:60@(D-O;7!U=&5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDW"FUS9VED(")#;VYD:71I;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@
M(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F
M;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"FUS
M9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W
M;W)D(@IM<V=S='(@(E-T861F97-T('!A<W-O<F0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG
M;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G
M:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")/<'!K;W!L:6YG(&UO
M="!O9F9E;G1L96<@;OAK:V5L=&5N87(@;F5K=&$N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")/<'!K;W!L:6YG(&UO
M="!O9F9E;G1L96<@;OAK:V5L=&5N87(@;F5K=&$N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX-#4*;7-G:60@(D-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HQ,#$T"FUS9VED(")#;VYT86-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@
M(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z
M+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@
M;V8@7"(E<UPB(@IM<V=S='(@(DEN;FAA;&0@:2`G)7,G(@H*(SH@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C,S"B,L(&9U>GIY"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")+
M;&EK:R!F;W(@Y2!H86QD92!F<F%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]O
M:R!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS,@IM<V=I9"`B0V]O:VEE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]P>2(*;7-G<W1R(")&:7)M82(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B26UP;W)T97)T92!F96QT.B`E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T92!D)TEV;VER92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*
M;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R
M(")+=6YN92!I:VMJ92!01U`M:V]D92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P-3,*;7-G:60@(D-O=6QD(&YO="!0
M1U`@<VEG;B!M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VMJ92!01U`M<VEG
M;F5R92!M96QD:6YG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,SDS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+6MO9&4@
M;65L9&EN9RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C0V-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE
M<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:VIE(%!'4"US:6=N97)E(&UE;&1I
M;F<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!A9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@9&5K;V1E
M(%!'4"UD871A+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S
M='(@(DMU;FYE(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B2W5N;F4@:6MK
M:F4@<VMA9F9E(&]F9F5N=&QE9R!N^&MK96P@9G+E(&[X:VME;'1E;F%R96XN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C
M:R!B86QA;F-E+B`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!L9&%P('-E<G9E<B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T:6P@
M3$1!4"UT96YA<F5N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A
M=&$N(@IM<V=S='(@(DMU;FYE(&EK:VIE(&1E:V]D92!01U`M9&%T82XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4R,@HC+"!F=7IZ
M>0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S
M='(@(DMU;FYE(&EK:VIE(&1E:V]D92!01U`M9&%T82XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T
M+B`E<R(*;7-G<W1R(")+=6YN92!I:VMJ92!D96MO9&4@4$=0+61A=&$N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@
M;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N
M(@IM<V=S='(@(DMU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E
M+7!O<W1A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+=6YN92!I
M:VMJ92!A=F=J97)E(&UO='1A:V%R96X@<VD@92UP;W-T861R97-S92XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y
M,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B
M=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@<VMA9F9E(&]F9F5N=&QE9R!N^&MK96P@9G+E(&[X:VME
M;'1E;F%R96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C(V,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE(%!'4"UK
M;V1E(&UE;&1I;F<N(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@;W!N92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@
M(DMU;FYE(&EK:VIE(&]P;F4@36%I;G1E;F%N8V5?5&%S:RUM;V1U;&5N("5S
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L
M9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I
M:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B)R5S)R!V87)T(&EK
M:VIE(&]P<')E='1A.B`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D
M(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B
M"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@
M:&5L<"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X.0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(W-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B2W5N;F4@:6MK
M:F4@879G:F5R92!M;W1T86MA<F5N('-I(&4M<&]S=&%D<F5S<V4N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.#0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S
M+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&5R(&EK:VIE(&]R9&5N=&QE
M9R!K;VYF:6=U<F5R="(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HY-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HV-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O
M('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H
M92!C;V1E(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@4$=0+7-I9VYE
M<F4@;65L9&EN9RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(")+=6YN92!I
M:VMJ92!D96MO9&4@4$=0+61A=&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-C8*;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED
M96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@
M7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30Q.0IM<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")#;W5N
M=')Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED
M(")#<F5A=&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@82!L
M:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E
M;&5C="YI;F,Z.30*;7-G:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*
M;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`HC+"!F=7IZ>0IM<V=I9"`B
M0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S,`IM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A=&EA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R96YT(#0@
M4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`IM
M<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U
M<G)E;G0@5&EM92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-30*;7-G:60@(D-U<G)E;G0@
M55),(&ES(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PIM
M<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT
M('-T>6QE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@
M(D-U="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0WER:6QL:6,@*$M/23@M
M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G
M:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI
M86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,2!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU
M,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C@Q"FUS9VED("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP
M:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S
M;BYP:'`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-
M86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1A9VQE
M9R(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@
M0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"B,L(&9U>GIY"FUS9VED(")$871E
M(@IM<V=S='(@(D]P<&1A=&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P-PIM<V=I9"`B1&%T
M92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Y,B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R
M"B,L(&9U>GIY"FUS9VED(")$87DB"FUS9W-T<B`B1&%G;&5G(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,V
M"B,L(&9U>GIY"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")3;&5T
M=&4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@HC+"!F=7IZ>0IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`B365D;&5M;6%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*
M;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$X-R!L:6(O<')E9G,N<&AP.C$Q-PHC
M+"!F=7IZ>0IM<V=I9"`B1&5F875L="(*;7-G<W1R(")3;&5T=&4B"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PHC+"!F
M=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R(")"<G5K('-T86YD
M87)D=F5R9&DB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(E-T86YD87)D
M:61E;G1I=&5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U
M>GIY"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-T86YD87)D:61E
M;G1I=&5T(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$
M969I;FET:6]N<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VQE
M='1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$96QE=&4@0V5L;"(*;7-G
M<W1R(")3;&5T=&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G
M<F]U<',N<&AP.C(R-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E($=R;W5P(@IM
M<V=S='(@(E-L971T92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(T.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")3;&5T
M=&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")4:6QG86YG(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T
M92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PHC+"!F=7IZ
M>0IM<V=I9"`B1&5L971E(&-E;&PB"FUS9W-T<B`B4VQE='1E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,PHC
M+"!F=7IZ>0IM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")3;&5T=&4B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS
M9W-T<B`B16YD<F4@=&EL9V%N9R!F;W(@)R5S)R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI
M<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8W"B,L(&9U>GIY"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(E-L971T92(*"B,Z('1E;7!L871E<R]P<F5F<R]D
M96QE=&5I9&5N=&ET>2YI;F,Z,34*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")3=&%N9&%R9&ED96YT:71E="(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(RP@9G5Z>GD*
M;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B4VQE='1E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.0IM<V=I9"`B1&5N;6%R:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R
M;V)L96TB"FUS9W-T<B`B4VMI;&1R92!P<F]B;&5M970B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`HC+"!F=7IZ>0IM<V=I9"`B1&5S8W)I
M<'1I;VXB"FUS9W-T<B`B1G5L;"!S:VEL9')I;F<Z(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@
M2&]R9&4G<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D1E=&%L:F%R
M(&5R(&QO9V=A(&9O<B!A9&UI;FES=')A=&]R96XN(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0
M;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM
M<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@
M<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I
M9"`B1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P
M;&%Y($]P=&EO;G,B"FUS9W-T<B`B5FES:6YG<V%L=&5R;F%T:78B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(D1I<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`B5FES:6YG<V%L
M=&5R;F%T:78B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@U"FUS9VED(")$
M:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,3<*(RP@9G5Z>GD*;7-G:60@(D1I<W!L87D@
M9F]R;6%T(@IM<V=S='(@(E9I<VEN9W-A;'1E<FYA=&EV(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-1$XN<&AP.C$Y,`IM<V=I9"`B1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1J
M:6)O=71I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(R"B,L(&9U>GIY"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S
M='(@(E-L971T92(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM
M<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B
M"FUS9W-T<B`B26MK:F4@8G)U:R!M86EN=&5N86YC92YP:'`@9&ER96MT92XB
M"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W
M(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@
M8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI;FEC86X@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY
M-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M-#0*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")$;W=N;&]A9"`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,38R"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*(RP@9G5Z>GD*
M;7-G:60@(D1R=6=S(@IM<V=S='(@(DQU<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B12U-86EL(@IM
M<V=S='(@(D4M<&]S="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE
M<FEC7W-M='`N<&AP.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#$@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L871E<R]P;W)T
M86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B16YD<F4B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4P('1E;7!L871E<R]P
M;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70@0FQO8VLB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR
M,C8*(RP@9G5Z>GD*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B1W)U<'!E
M<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R(")4:6QG86YG(@H*(SH@<V5R=FEC97,O
M<VAA<F5S+V5D:70N<&AP.C(S-PHC+"!F=7IZ>0IM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG(@H*(SH@<V5R=FEC97,O<VAA<F5S
M+V5D:70N<&AP.C(S.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I
M="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B16YD<F4@=&EL9V%N9R!F
M;W(@)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*(RP@9G5Z
M>GD*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(D5N9')E('1I
M;&=A;F<@9F]R("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M
M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(D5N9')E('1I;&=A;F<@9F]R
M("<E<R<B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R(")%;F1R92!T:6QG86YG(&9O<B`G)7,G(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%9'5C871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B16ET:&5R(&5N86)L92!I="!T:&5N.B`E<RP@;W(@=7-E('1H92!B87-I
M8R!(5$U,('9E<G-I;VXZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*
M;7-G:60@(D5L(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B
M16QE;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G
M<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4V-2!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*
M;7-G:60@(D5M86EL($%D9')E<W,B"FUS9W-T<B`B1&D@92UP;W-T861R97-S
M93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"B,L(&9U>GIY
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M4&%S<V]R9&$@;>4@<V%M<W9A<F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DX.0HC+"!F=7IZ>0IM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M
M871I;VXB"FUS9W-T<B`B06YN86X@:6YF;W)M87-J;VXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`HC+"!F=7IZ>0IM<V=I9"`B
M16UO=&EC;VYS(@IM<V=S='(@(D%L=&5R;F%T:78B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*(RP@9G5Z>GD*
M;7-G:60@(D5M<'1Y(&UE<W-A9V4N(@IM<V=S='(@(E1O;70@<F5S=6QT870N
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT+B(*;7-G<W1R(")4;VUT(')E<W5L
M=&%T+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*
M;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N
M(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3$*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G
M:60@(D5N;&%R9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,C$*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E
M<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@
M<F5S970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@
M(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS9VED(")%
M;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%<G)O
M<B(*;7-G<W1R(")&96EL(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L
M871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@8W)E871I
M;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G:60@(D5V
M97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B2W9A<G0@,34N(&UI;G5T="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#D*(RP@9G5Z>GD*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R(")+=F%R="`U+B!M:6YU='0B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2W9A<G0@
M,S`N('-E:W5N9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S
M(@IM<V=S='(@(DMV87)T(#4N(&UI;G5T="(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN
M(@IM<V=S='(@(DMV87(@:6YN;&]G9VEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")+
M=F%R(&AA;'9E('1I;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R(")+=F%R="!M:6YU='0B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@
M(D5K<V5M<&5L=F5R9&EA<CHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@
M861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*
M;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B
M17AP86YD(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]3
M44PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*
M;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X
M<&]N96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G:60@(D94
M4"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN
M9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@:&5N=&4@:6YN
M<W1I;&QI;F=A<B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HW-2!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2W5N
M;F4@:6MK:F4@:V]P;&4@=&EL($Q$05`M=&5N87)E;BXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D
M('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z-CDQ"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(DMU;FYE
M(&EK:VIE(&MO<&QE('1I;"!,1$%0+71E;F%R96XN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C0Y-R!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&UO=F4@=&\@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!K;W!L92!T
M:6P@3$1!4"UT96YA<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M<F5T<FEE=F4Z("5S(@IM<V=S='(@(DMU;FYE(&EK:VIE(&AE;G1E(&EN;G-T
M:6QL:6YG87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS
M9VED(")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C,X"B,L(&9U>GIY"FUS9VED(")&
M871A;"!%<G)O<CHB"FUS9W-T<B`B26UP;W)T9F5I;#H@(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E
M=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T<FEX(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE
M="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S
M='(@(E1I='1E;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P-PIM<V=I9"`B1FEL92!-
M86YA9V5R(@IM<V=S='(@(D9I;&AA;F1S86UI;F<B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92!.86UE(@IM
M<V=S='(@(D9I;&AA;F1S86UI;F<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R
M+G!H<#HX-3D*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN
M;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS
M9VED(")&:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U
M87)T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S$*
M;7-G:60@(D9L:7`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O
M;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S,T"FUS9VED(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*
M(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M
M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ,#(*;7-G:60@
M(D9O<F=O="!Y;W5R('!A<W-W;W)D/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*(RP@9G5Z>GD*;7-G:60@
M(D9O<G1U;F4B"FUS9W-T<B`B1FYO<G)E(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T
M=6YE<R(*;7-G<W1R(").;W1A=&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,Y"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS9VED(")&
M;W)W87)D<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"B,L(&9U>GIY"FUS9VED(")&<F%M97,B"FUS9W-T<B`B3F%M;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*;7-G<W1R(")/<F%N<VIE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS
M9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8P"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@
M(D9R;VT@=&AE("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P
M<F]B;&5M+FEN8SHT.`HC+"!F=7IZ>0IM<V=I9"`B1G5L;"!$97-C<FEP=&EO
M;B(*;7-G<W1R(")&=6QL('-K:6QD<FEN9SHB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#$@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-
M;V]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T
M96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS
M9VED(")&=6QL($YA;64B"FUS9W-T<B`B1&ET="!N86UN.B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B
M1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS
M9VED(")'86UB:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF
M:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U
M<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@0V]D92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1VEB<F%L=&%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O
M961E;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3$R.`IM<V=I9"`B1V]O9VQE($UA<',B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HR,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE
M(%-E87)C:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,W"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(D=R965C92(*;7-G<W1R
M(")'<OAN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R
M965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U
M>GIY"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W+X;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*(RP@9G5Z>GD*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W+X;B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")'<G5P<&5A9&UI;FES=')E<FEN9R(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E
M<B!S86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T
M;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T
M<B`B1W)U<'!E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")'
M=65R;G-E>2(*;7-G<W1R(")'<N4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"B,L
M(&9U>GIY"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG
M86YG(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,`HC+"!F=7IZ
M>0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D%D<F5S<V5B;VLB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@
M=&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T
M<"YP:'`Z,34W"FUS9VED(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(96%D
M97(B"FUS9W-T<B`B3W9E<G-K<FEF=&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B2&5A
M9&5R<R(*;7-G<W1R(")/=F5R<VMR:69T97(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G
M:60@(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,PIM<V=I9"`B2&5A=GD@5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-@IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y(&9R86UE=V]R
M:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC97,O:&5L<"]I
M;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC.C,*;7-G:60@
M(DAE;'`B"FUS9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q
M"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&IE;'`B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DAI9V@B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L
M871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"B,L(&9U>GIY"FUS9VED
M(")(;U]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@
M(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0HC+"!F=7IZ>0IM<V=I
M9"`B2&]M92(*;7-G<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM
M<V=S='(@(D%D<F5S<V4L('!R:79A="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I
M9"`B2&]M92!0:&]N92(*;7-G<W1R(")496QE9F]N+"!P<FEV870B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@
M;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-3`*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L
M;'D@<F5M;W9E9"`E<R!<(B5S7"(B"FUS9W-T<B`B1FIE<FYA("<E<R<@9G+E
M('-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S
M"FUS9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R
M97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR
M;VYI<V4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$S,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*
M;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C,P"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4Y"FUS9VED(")(=6UI9&ET
M>3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM
M<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I
M9"`B2'5N9V%R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP
M.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L
M971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"B,L(&9U>GIY"FUS9VED("))4"!!
M9&1R97-S(@IM<V=S='(@(D%D<F5S<V4B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B
M87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?
M;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O
M;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DP"FUS9VED("))9&5N=&ET>2=S(&YA
M;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N
M=',N<&AP.C4Y,@HC+"!P:'`M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M-34*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG
M($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@(@HB
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$W,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO
M(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E
M("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I
M9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM
M86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*;7-G:60@
M(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z
M-R!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P("5D
M(@IM<V=S='(@(DEM<&]R=&5R=&4@9F5L=#H@)7,B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B26UP;W)T97)T92!F96QT.B`E<R(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R
M=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T97)T92!F96QT.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("))
M;F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,L
M(&9U>GIY"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D+B(*;7-G<W1R(")3:W)I=B!I;FX@9&ET="!B<G5K87)N86UN(&]G('!A
M<W-O<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I
M9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("))
M;F-R96%S92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("));F1I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I
M9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3<*(RP@9G5Z
M>GD*;7-G:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO
M;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU;6X@069T97(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM
M<V=I9"`B26YS97)T(%1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!7
M96(@3&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L
M=6UN($)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Q"FUS9VED("));G-E<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$U,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y"FUS9VED("));G-E
M<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@
M=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS
M97)T(&-E;&P@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I9"`B26YS97)T
M(&-E;&P@8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C
M;VQU;6X@869T97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS97)T(&-O
M;'5M;B!B969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@<F]W(&%F
M=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G
M:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS97)T+TUO9&EF>2!)
M;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS
M9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G:60@
M(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"FUS9VED("));G9A;&ED
M(%I)4"!D871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,@IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@
M9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE
M(&9O<FUA="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<W"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<Q"FUS9VED
M("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*
M;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I
M9"`B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV
M"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("))
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"FUS9VED("));G9A;&ED('!A
M<G1N97(@:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S4*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z.3,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW
M,2!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H
M<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<V(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,@IM<V=I9"`B26YV86QI9"!S
M:&%R92!O8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O
M=7)C92!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@
M=6YI8V]D92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W.0IM<V=I
M9"`B26YV97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B27-R865L(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(U"FUS9VED("))<W-U97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"B,L(&9U>GIY"FUS9VED("))=&%L>2(*;7-G<W1R(")$86=L96<B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A
M<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P
M86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C,Q,`IM<V=I9"`B(@HB2F%V87-C<FEP="!H87,@
M8F5E;B!D:7-A8FQE9"!O;B!Y;W5R(&)R;W=S97(@86YD('1H:7,@<&%G92!M
M87D@;F]T(&)E("(*(F1I<W!L87EI;F<@8V]R<F5C=&QY+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,@HC+"!F=7IZ>0IM
M<V=I9"`B2F5R<V5Y(@IM<V=S='(@(D=RY2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F]R9&%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#8*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED
M(")*=6YE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*
M;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B
M2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@
M(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"B,L(&9U>GIY"FUS9VED(")+96YY
M82(*;7-G<W1R(").96MT(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U
M+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM<V=I9"`B2V5Y($-R
M96%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B
M2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*(RP@9G5Z>GD*;7-G:60@(DME>2!4>7!E(@IM<V=S
M='(@(DU)344M='EP92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B
M365L9&EN9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T
M,`HC+"!F=7IZ>0IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")/<'!K;W!L:6YG(&UO="!O9F9E
M;G1L96<@;OAK:V5L=&5N87(@;F5K=&$N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS
M9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI
M8R!O9B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM
M<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO=70B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A9V4B"FUS
M9W-T<B`B4W!RY6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O
M<F0@0VAA;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0HC+"!F=7IZ
M>0IM<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R(")/<'!D871E<B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<#HW,38*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(DQO
M9V<@=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q.0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-0HC+"!F=7IZ>0IM
M<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B16MS96UP96QV97)D:6%R.B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@
M(DQE=F5L(@IM<V=S='(@(D%L9')I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),
M:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N
M($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G
M:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*(RP@9G5Z>GD*;7-G:60@(DQI
M9VAT($1R:7IZ;&4B"FUS9W-T<B`B3'ES(&)LY2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"B,L(&9U>GIY"FUS9VED("),
M:6=H="!286EN(@IM<V=S='(@(DQO9V<@:6YN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M.0IM<V=I9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI
M9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"B,L(&9U>GIY"FUS9VED
M("),:6=H="!3;F]W(@IM<V=S='(@(DQY<R!B;.4B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO
M=R!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.#$T"B,L(&9U>GIY"FUS9VED("),:6YK(@IM<V=S
M='(@(DQO9V<@:6YN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W-0IM
M<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),
M:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*
M;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4P"FUS9VED("),:7-T
M($AE;'`@5&]P:6-S(@IM<V=S='(@(E9I<R!E;6YE(&9RY2!(:F5L<"(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z
M-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.#D*(RP@9G5Z>GD*;7-G:60@
M(DQI<W0M2&5L<"(*;7-G<W1R(")6:7,@96UN92!F<N4@2&IE;'`B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y-@IM<V=I9"`B3&ES
M="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES
M="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I
M9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DQI<W1I
M;F<@<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R("),:7-T:6YG(&%V(&)R
M=6MA<F%R(&5R('-LY71T(&%V+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F
M86EL960Z("5S(@IM<V=S='(@(DQI<W1I;F<@878@8G)U:V%R87(@97(@<VSE
M='0@878N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR
M"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),
M:7-T:6YG(&%V(&)R=6MA<F%R(&5R('-LY71T(&%V+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS
M9VED("),;V%D:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,3$*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L
M92!A;F0@5&EM92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C:R]M971A
M<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QO9VEN
M+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R("),;V=G(&EN;B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S('-Y
M;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO9V<@=70B
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@
M(DQO9VEN(@IM<V=S='(@(DQO9V<@:6YN(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-PHC+"!F=7IZ>0IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T
M<B`B3W!P9^5V97(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.38*
M(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM
M<V=S='(@(B(*(DMU;FYE(&%V(&5I;B!E;&QE<B!A;FYA;B!G<G5N;B!I:VMJ
M92!L;V=G92!I;FXN(%-A;FYS>6YL96=V:7,@97(@8G)U:V%R;F%M;B`B"B)E
M;&QE<B!P87-S;W)D('1A<W1A(&EN;B!F96EL+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U"B,L(&9U>GIY
M"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B3&]G9R!U="(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G
M<W1R(")&:F5R;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I
M9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS
M9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*
M;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,V
M"FUS9VED(")-4RU43D5&($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N
M(@IM<V=S='(@(DU3+51.148M=F5D;&5G9R!I;FYE:&5L9'0@:6YG96X@9&%T
M82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Y"B,L(&9U>GIY"FUS9VED(")-86=I8R(*;7-G<W1R(")%+7!O<W0B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS
M9W-T<B`B12UP;W-T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R
M,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U
M>GIY"FUS9VED(")-86QA=VDB"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*
M;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@HC+"!F
M=7IZ>0IM<V=I9"`B36%L:2(*;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*(RP@9G5Z>GD*;7-G:60@(DUA;'1A(@IM<V=S='(@(D4M<&]S="(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-3,*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`X-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$V.`IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0HC
M+"!F=7IZ>0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(L5T=F%R:6YG(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@
M(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B
M36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E
M9"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN
M:7%U92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(E-A;7-V87)A
M;F1E(&9E;'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS9VED(")-875R:71I=7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`V"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3@*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI
M;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B365D;&5M;6%R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(U-0IM<V=I9"`B365S<V%G92(*;7-G<W1R(")-96QD:6YG(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*
M(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R
M)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`B365L9&EN9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(RP@9G5Z>GD*;7-G
M:60@(DUE<W-A9V4@='EP92(*;7-G<W1R(")-96QD:6YG(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE=&%R(&)L
M;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A;&IA<B!E<B!L;V=G82!F
M;W(@861M:6YI<W1R871O<F5N+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T
M"FUS9VED(")-971H;V0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ
M,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S7"(@
M:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365T;V1E("<E<R<@:6MK:F4@9&5F
M:6YE<G0B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M
M971H;V0Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HW-"!L:6(O0FQO8VLO;65T87(N<&AP.C<U"FUS9VED(")-971R
M:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R
M871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,L(&9U>GIY"FUS9VED
M(")-:61D;&4B"FUS9W-T<B`B12UP;W-T(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G
M<W1R(")-24U%+71Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM
M<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S
M(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,T"B,L(&9U>GIY"FUS9VED(")-
M:7)R;W(B"FUS9W-T<B`B1F5I;"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HR-3`*;7-G
M:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB
M36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I
M="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HU.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2
M('!A8VMA9V4@36%I;"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG
M('-E<W-I;VX@240N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B36]B:6QE
M($UA:6PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE9"!$
M871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W
M,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM
M<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU
M-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-Y6YA9&QE9R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO
M;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HR-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@9F]U;F0@:6X@;&EN92`E
M9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE
M87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G
M:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,3,*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,3<*;7-G:60@(DUO=F4@4FEG:'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z-3`U"FUS9VED(")-;W9E(%5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@
M9&]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*;7-G:60@(DUU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U-0IM<V=I9"`B375L=&EM87`@
M54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-#(*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!8V-O
M=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`HC
M+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R
M(")$:6X@:6YF;W)M87-J;VXB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N
M<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L($QA>6]U
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").
M14DL(&5G(&5R($E+2TI%('-A;60B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS.`IM<V=I9"`B3F%M92(*;7-G<W1R(").86UN(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM
M<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M97!A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA
M;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD
M<R!!;G1I;&QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#,*;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS
M9VED(").971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S
M8V%P92!296YE=V%L(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A
M=&EO;B!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-PIM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").
M971W;W)K(@IM<V=S='(@(DYE='1V97)K(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS
M9W-T<B`B06QD<FDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL
M<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O
M("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I
M9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA
M;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S<*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R(")087-S
M;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@
M)7@N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HU,@HC+"!F=7IZ>0IM<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"XB"FUS9W-T<B`B4&%S<V]R9&$@;>4@<V%M<W9A<F4N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I9"`B3F5W
M('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HT,"!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*
M;7-G<W1R(").;W1A=&%R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,P-0HC+"!F=7IZ>0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")'<G5P
M<&5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4*;7-G
M:60@(DYE>'0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<R(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]522YP:'`Z,S<V"B,L(&9U>GIY"FUS9VED(").97AT(&]P=&EO;G,B"FUS
M9W-T<B`B5&EL8F%K92!T:6P@86QT97)N871I=B(*"B,Z(&9R86UE=V]R:R]5
M22]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(D%L9')I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*;7-G:60@(DYI9VAT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38S"FUS9VED(").;R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M,3`U"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E
M;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C8W
M"FUS9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN
M<&AP.C4P"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R;W9I
M9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E;B!K
M;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344PM
M875T96YT:7-E<FEN9RXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-`HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")!;F=R92!E;F1R
M:6YG87(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$U-@HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B)R5S)R!V87)T(&QA9W0@=&EL('1I
M;&=A;F=S<WES=&5M970N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-C<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@)7,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J
M;VX@<W!E<VEF:7-E<G0@9F]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,C0*(RP@9G5Z>GD*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G
M<W1R("));F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES
M97)T(&9O<B!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-C8Y"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A
M<VIO;G-I;F9O<FUA<VIO;B!S<&5S:69I<V5R="!F;W(@4U%,(%9&4RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"B,L(&9U>GIY
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S
M:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@5D93+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<W"FUS9VED(").;R!F:6QE
M('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C@@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(S"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-CD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").
M;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HW,@IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC+"!F=7IZ>0IM
M<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S
M:F]N('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"B,L(&9U>GIY"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%S:F]N<VEN9F]R;6%S
M:F]N('-P97-I9FES97)T(&9O<B!344PM875T96YT:7-E<FEN9RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@
M(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VYS:6YF;W)M87-J;VX@<W!E
M<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S4P"B,L('!H<"UF;W)M
M870*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F
M=7IZ>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0IM<V=I9"`B3F\@<V5P87)A
M=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`HC+"!F=7IZ>0IM<V=I
M9"`B3F\@<VED97,B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-3@S"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$S.`IM<V=I
M9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C(R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(E-K<FEV(&EN;B!D:71T(&)R
M=6MA<FYA;6X@;V<@<&%S<V]R9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE
M9"(*;7-G<W1R("));F=E;B!G>6QD:6=E(%A-3"UD871A(')E='5R;F5R="(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"FUS
M9VED(").;R!V86QU97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA
M;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@
M(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0U"B,Z('1E;7!L871E<R]P
M<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*(RP@9G5Z>GD*;7-G:60@(DYO
M;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I
M="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G
M:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I
M9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T
M($%F=&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C,Y"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0P.`IM<V=I9"`B3F]T(&$@
M9&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*
M;7-G:60@(DYO="!S970B"FUS9W-T<B`B3F]T871A<B(*"B,Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30S"B,Z(&9R
M86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,34X
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP
M:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93+G!H<#HQ.3`*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-#@@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S(Y"B,Z(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4X-R!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@<W5P<&]R=&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-S@*;7-G:60@(DYO=&5S(@IM<V=S
M='(@(DYO=&%T87(B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z
M,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-0HC+"!F=7IZ>0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B365D;&5M;6%R
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM
M<V=I9"`B3G5M8F5R(@IM<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C4*;7-G:60@(DYU;6)E<B!O9B!C:&%R86-T
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*
M;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#8*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-`IM<V=I9"`B3TLB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"FUS9VED
M(")/8W1A;"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL
M=&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D
M<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S
M<W=O<F0B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R
M96-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@
M(D]M86XB"FUS9W-T<B`B3W)A;G-J92(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE
M(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N
M97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/
M<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O
M<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@
M<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED
M(")/<'1I;VYS(@IM<V=S='(@(D%L=&5R;F%T:78B"@HC.B!S97)V:6-E<R]P
M<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@
M(D%L=&5R;F%T:78B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*(RP@9G5Z
M>GD*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R(")!9&UI;FES=')E<FEN
M9R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X"FUS
M9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(D]R9V%N
M:7II;F<B"FUS9W-T<B`B3W)A;G-J92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")!;FYA;B!I;F9O<FUA<VIO;B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W
M;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+W!A;2YP:'`Z-SD*;7-G:60@(E!!32!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%
M05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-3,*;7-G:60@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8X"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")0
M32!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS
M9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#$*(RP@9G5Z>GD*;7-G:60@
M(E!-(%-U;B(*;7-G<W1R(")3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C(W-`IM<V=I9"`B4$]3
M25@@97AT96YS:6]N(&ES(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@;&EB+V%P
M:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*
M;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")086MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QA=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.`IM<V=I9"`B4&%N86UA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@IM<V=I9"`B4&%R=&QY($-L
M;W5D>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#$X"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")087-S
M;W)D(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS9VED
M(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(R"B,L(&9U
M>GIY"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B4&%S<V]R
M9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G
M:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-3,*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<W-O<F0B"@HC.B!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S
M<W=O<F0Z("(*;7-G<W1R(")087-S;W)D(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(E!A<W-O<F1A(&WE('-A;7-V87)E+B(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,W"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E
M<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F=7IZ>0IM<V=I
M9"`B4&5O<&QE(@IM<V=S='(@(E)O;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R(*;7-G<W1R(")+^'ER('9E9&QI:V5H86QD<V]P97)A<VIO;F%R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C0P-@IM<V=I9"`B4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G<W1R(")+^'ER('9E
M9&QI:V5H86QD<V]P97)A<VIO;F%R('9E9"!I;FYL;V=G:6YG/R(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED
M(")097)M:7-S:6]N(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I
M;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES
M<VEO;B!$96YI960B"FUS9W-T<B`B5&EL9V%N9R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R(")4:6QG86YG
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HV,`HC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M
M:6XO<&5R;7,O9&5L971E+G!H<#HU.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B5&EL9V%N9W-A9&UI;FES=')E<FEN9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-0HC+"!F=7IZ>0IM<V=I9"`B
M4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B06YN86X@:6YF;W)M87-J
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM
M<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS
M9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I
M9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI
M<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-3<Q"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y
M96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM
M86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;F%M92!F
M;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C8V,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,0IM<V=I
M9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E
M('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")3
M:W)I=B!I;FX@96ET('-A;6%N9')A9R!A=B!P<F]B;&5M970N(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9"(*;7-G<W1R(")3:W)I=B!I;FX@9&ET="!B<G5K87)N
M86UN(&]G('!A<W-O<F0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-3@*(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I
M;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E
M('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9E<B!V96YL96<@;V<@;&5S
M(&;X;&=J86YD92!T96MS="X@1'4@3<4@=F5R92!S86UD(&UE9"!V:6QKY7)A
M(&9O<B#E(&)R=6ME("(*(G-Y<W1E;65T+B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@
M='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&]L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PIM<V=I9"`B4&]L;',B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@9F]L9&5R("AN
M;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R
M*',I.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(Y.`IM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*
M;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N.B!297%U:7)E
M9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E
M<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S-0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C`U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C,V,B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-@HC+"!F
M=7IZ>0IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")0<F5S96YT
M87-J;VYA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4')I
M=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+TUE;G4N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R
M(");4')O8FQE;7)A<'!O<G1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3(V"FUS9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E-K:6QD
M<FEN9R!A=B!P<F]B;&5M970B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B
M4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-`IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B3V9F96YT;&5G+W!R
M:79A="!N^&MK96QP87(@=F%R="!I:VMJ92!G96YE<F5R="XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`R"FUS9VED(")1871A<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED(")286EN(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0T
M"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#8*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")2
M86EN(&%N9"!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A
M;F1O;2!&;W)T=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B
M"FUS9W-T<B`B3&5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS
M9W-T<B`B365L9&EN9R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#$*(RP@9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I
M97<Z(@IM<V=S='(@(D9R:7-K(&]P<"!O=F5R<VEK='9I<VEN9SHB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.30@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,U"B,L
M(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(").=6QL<W1I;&PB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C0Y"FUS9VED(")296QA=&EO;G-H
M:7`@0G)O=W-E<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN
M8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,L
M(&9U>GIY"FUS9VED(")296QO860B"FUS9W-T<B`B3&5S(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,C8*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`HC+"!F=7IZ>0IM<V=I9"`B
M4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")&
M:F5R;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D9J97)N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")&:F5R;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(D9J97)N
M('!A<B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED
M(")296UO=F4@<&%I<B(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0R"B,L(&9U>GIY"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@
M(D9J97)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4P"FUS9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!U<V5R
M(@IM<V=S='(@(D9J97)N('!A<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V92YI;F,Z-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5M
M;W9E('5S97(Z("5S(@IM<V=S='(@(D9J97)N('!A<B(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"B,L(&9U>GIY"FUS9VED(")297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M("(*;7-G<W1R(")+=6YN92!I:VMJ92!S=F%R92!PY2!F^')E<W!U<FYA9"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*(RP@9G5Z>GD*
M;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB
M"FUS9W-T<B`B2W5N;F4@:6MK:F4@<W9A<F4@<.4@9OAR97-P=7)N860B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B3OAD=F5N9&EG("=T86)L92<@:6MK:F4@<W!E<VEF
M:7-E<G0@:2!K;VYF:6=U<F%S:F]N(&9O<B!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S4@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HX,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<R,PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[X
M9'9E;F1I9R`G=&%B;&4G(&EK:VIE('-P97-I9FES97)T(&D@:V]N9FEG=7)A
M<VIO;B!F;W(@5D93+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<X
M,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B3OAD
M=F5N9&EG("=T86)L92<@:6MK:F4@<W!E<VEF:7-E<G0@:2!K;VYF:6=U<F%S
M:F]N(&9O<B!61E,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E
M<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S(P('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#`*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B4F5S970B"FUS9W-T<B`B
M3G5L;'-T:6QL(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*
M(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E!A<W-O
M<F0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PHC+"!F=7IZ
M>0IM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")3=&%D9F5S
M="!P87-S;W)D(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,`IM<V=I9"`B
M4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H
M96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE
M;&PN<&AP.C8V"B,L(&9U>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(DYU
M;&QS=&EL;"(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$@
M=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O($]P
M=&EO;G,B"FUS9W-T<B`B5&EL8F%K92!T:6P@86QT97)N871I=B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2
M975N:6]N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#0@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O
M;F9I9W5R871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/<'1I
M;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL(&%L=&5R;F%T:78B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(Q"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-PHC+"!F=7IZ
M>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(DQY<R!B;.4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED
M(")2;VQE(@IM<V=S='(@(E)O;&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B
M4F]M86YI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(U"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC+"!F=7IZ
M>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B4F]L;&4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U
M;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`*(RP@9G5Z>GD*;7-G:60@(E)U
M;B(*;7-G<W1R(")3;VPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N
M($9E9&5R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PHC+"!F=7IZ
M>0IM<V=I9"`B4G=A;F1A(@IM<V=S='(@(DQE<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T
M960@365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,#0*(RP@9G5Z>GD*;7-G:60@(E--4R!-97-S86=I;F<B"FUS
M9W-T<B`B365L9&EN9R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I
M9"`B4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO
M;VMU<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,0IM<V=I9"`B4U-((@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*
M;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.
M979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I
M97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM
M<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(E-A
M=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS
M9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.CDX"B,L(&9U>GIY"FUS9VED(")3879E(@IM<V=S
M='(@(DQA9W)E("<E<R<B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D
M:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB
M)7-<(B(*;7-G<W1R("),86=R92`G)7,G(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@)7,B"FUS9W-T<B`B3&%G<F4@)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R("),86=R
M92!A;'1E<FYA=&EV(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP
M="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O
M<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM
M<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@
M(E-E;&5C="!&:6QE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE
M8W0@82!D871E(@IM<V=S='(@(E9E;"!D871O9F]R;6%T.B(*"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3DX"FUS9VED(")396QE8W0@82!G<F]U
M<"!T;R!A9&0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHT,PIM<V=I9"`B4V5L96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV,`IM<V=I9"`B4V5L
M96-T(&$@<V5R=F5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,34V"FUS9VED(")396QE8W0@82!U<V5R('1O(&%D9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-C<W"FUS9VED(")396QE8W0@86QL(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R(")696P@9&%T;V9O<FUA
M=#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#<S"FUS9VED(")396QE8W0@86X@;V)J96-T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@
M(E-E;&5C="!N;VYE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B(@HB4V5L96-T('1H92!C:&%R86-T
M97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H
M96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M(@IM<V=S='(@(B(*(E9E;"!T96EK;F$@9'4@=')E;F<@9G+E(&)O:W-A;F4@
M=6YD97(N($1U(&MA;B!SY2!K;W!I97)E(&]G(&QI;64@9&5I(&EN;B!F<N4@
M(@HB=&5K<W1B;VMS82XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B
M5F5L('-K:6QJ971E:6MN(&9O<B!D871O.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R(")696P@9&%T;V9O<FUA=#HB"@HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E9E;"!S:VEL:F5T96EK;B!F
M;W(@9&%T;SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5F5L('1I9'-F
M;W)M870Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I
M9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E9E;"!T
M;R!S86US=F%R86YD92!F96QT+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,#8*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T
M<B`B5F5L(&9A<F=E<VMJ96UA+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-#@*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93HB
M"FUS9W-T<B`B5F5L(/AN<VMA('-P<N5K.B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD(%!R;V)L96T@4F5P;W)T
M(@IM<V=S='(@(E-E;F0@<')O8FQE;7)A<'!O<G0B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B4V5N9"!3
M35,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-@IM<V=I9"`B
M4V5N<V]R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R(")-961L96UM87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S`Q"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C$*;7-G:60@(E-E<G9E<B!D871A
M('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PHC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!!9&UI
M;B(*;7-G<W1R(")4:6QG86YG<V%D;6EN:7-T<F5R:6YG(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED
M(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B5&EL
M9V%N9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@
M(E-E="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*
M;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R
M('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E
M;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U
M<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")696P@
M^&YS:V$@<W!RY6LZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"B,L
M(&9U>GIY"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N
M+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*
M(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B4V5T(&9A<F=E<VMJ96UA+"!S
M:61E;W!P9G)I<VMI;F<@;V<@86YD<F4@=FES:6YG<V%L=&5R;F%T:78N(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ
M,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM
M<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R
M86UE=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y
M8VAE;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#DV"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I9"`B4VAO
M<G0@4W5M;6%R>2(*;7-G<W1R(")+;W)T('-A;6%N9')A9SHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#0V"FUS9VED(")3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C,@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@(E-H
M;W<B"FUS9W-T<B`B5FES(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U
M-0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DP
M"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4*
M;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,PIM<V=I9"`B4VAO
M=R!P:6-K97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4R-@IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@
M9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,@IM<V=I9"`B4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B5FES(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@
M(E-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,@3&%T92(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#@P
M"FUS9VED(")3:')I;FLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C@S-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.3@T
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P-#<@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3`X-PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,3$V(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C$Q-#D*;7-G:60@(E-H<FEN:R!O<B!M;W9E
M(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R<F$@3&5O;F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V-0IM<V=I9"`B4VEG;B!U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$Q"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8U(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(R-#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(S"FUS9VED(")3:7IE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH
M=&UL.C4R"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(DAO<'`@
M;W9E<B!V961L:6ME:&%L9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A
M:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(E9I<R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4U"FUS
M9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*
M;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<X"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@
M97%U:79A;&5N="!I;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(V"FUS9VED(")3
M;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"B,L(&9U
M>GIY"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G<W1R(")!9')E<W-E+"!A
M<F)E:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")3;W5T:"!!9G)I8V$B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3`*;7-G:60@(E-O
M=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G
M:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(DEN;G1A<W1I;F<@878@<W!E<VEA;'1E:6MN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED
M(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@
M<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0HC
M+"!F=7IZ>0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(DEM<&]R="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP
M.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R("(E<R!3=&%N
M9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A
M<B!4<F5K(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U.38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A
M<G0@>65A<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,3(*
M;7-G:60@(E-T871U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#$U"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*
M;7-G<W1R(")$:6X@:6YF;W)M87-J;VXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C4W,@HC+"!F=7IZ>0IM<V=I9"`B4W1R965T($%D
M9')E<W,B"FUS9W-T<B`B061R97-S92P@87)B96ED(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME
M=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<S"FUS9VED(")3=')I<"!D;VUA:6X@
M9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(S"FUS9VED(")3='EL
M92!;0U-372(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8R"B,L(&9U>GIY"FUS9VED(")3=2(*;7-G<W1R
M(")3;VPB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O
M=6YD+B(*;7-G<W1R(")&86YN(&EK:VIE('9A<G-E;&QY='1A<B`E<RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S"FUS
M9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,3<*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP.C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN
M('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C
M8V5S<R(*;7-G<W1R(")3=6MS97-S(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B3&$@=&EL("<E<R<@
M=&EL('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R(")&
M:F5R;F$@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E9"!<(B5S7"(N(@IM
M<V=S='(@(E-L971T82`G)7,G+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V
M960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1FIE<FYA("<E
M<R<@9G+E('-Y<W1E;65T+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`B4VQE='1A
M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW,2!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R(")3;&5T=&$@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")3=61A;B(*;7-G<W1R
M(")3;VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4V"B,L(&9U>GIY"FUS9VED(")3=6UM87)Y(@IM<V=S='(@
M(DUI='0@<V%M86YD<F%G(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U
M"FUS9VED(")3=6X@4FES92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-3D*(RP@9G5Z>GD*;7-G:60@(E-U;FYY(@IM<V=S='(@(E-O;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*(RP@9G5Z>GD*;7-G:60@
M(E-U;G)I<V4B"FUS9W-T<B`B4V]L(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E
M+U-U;G-E="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$U"FUS9VED(")3=6YR:7-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.0HC+"!F=7IZ>0IM<V=I9"`B
M4W5N<V5T(@IM<V=S='(@(E-O;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@
M(E-U<&5R<V-R:7!T(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
M26UP;W)T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-@HC+"!F=7IZ>0IM<V=I9"`B4W5R:6YA
M;64B"FUS9W-T<B`B0G)U:V%R;F%M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<T"B,L(&9U>GIY"FUS9VED(")3=7)N86UE(@IM
M<V=S='(@(D)R=6MA<FYA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(E-W87II;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3=V5D96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W
M:71Z97)L86YD(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@(E-Y;F--3"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L
M:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M
M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-@HC+"!F=7IZ>0IM<V=I9"`B
M5%-6(&9I;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U1A8FQE+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@
M(E1I='1E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H
M<#HU-PIM<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@
M(E1A8FQE('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I
M;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED
M(")487)G970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES
M=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B5&%S
M:W,B"FUS9W-T<B`B3W!P9^5V97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4W,PIM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y,`IM<V=I9"`B5&5M
M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C,*;7-G:60@(E1E;7!E
M<F%T=7)E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-C@W"B,L('!H<"UF;W)M
M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY"FUS9VED
M(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")"<G5K87)A9&UI
M;FES=')E<FEN9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")4
M97AT($]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED
M(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I
M;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1'4@97(@;&]G9V$@=70N/&)R("\^
M5&%K:R!F;W(@870@9'4@8G)U:V%R(&1E='1E('-Y<W1E;65T+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P"FUS9VED(")4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T
M('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M24U34"])35-0+T)O;VLN<&AP.C$R.3(*;7-G:60@(E1H92!)35-0(&QO9R!C
M;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")+
M;&%S<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK:VIE(&QA<W1A(&EN;B(*"B,Z
M('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X.2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C(P,`HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,N<&AP.C(Q,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-"!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(U,@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(V
M-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,P,PIM<V=I9"`B(@HB5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E
M<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M
M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$*
M;7-G:60@(E1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-CD*;7-G:60@(B(*(E1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B"B)4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A
M<V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI
M<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO;B!F
M96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*;7-G
M<W1R(")+<GEP=&5R:6YG<V9U;FMS:F]N86YE(&MR978@96D@<VEK:V5R(&YE
M='1O<'!K;W!L:6YG+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E
M<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE
M9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,C@P"B,L(&9U>GIY"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1BUV961L96=G(&EN;F5H96QD
M="!I;F=E;B!D871A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDP
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE
M9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@
M;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP
M=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@
M:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*
M;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O
M;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!M
MY2!V97)E(&5I="!T86PN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U
M;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE
M("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@
M=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B(@HB1F%N;B!I:VMJ92!P<F]G<F%M;65T('-O
M;2!B<G5K87-T('1I;"#E('9I<V4@9&5N;F4@='EP96X@;65L9&EN9V%R("@E
M<RDN(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T"FUS9VED
M(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R
M86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H="!A;F0@
M;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R
M:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B
M965N(')E;6]V960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,3$*;7-G:60@(E1H92!T
M97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE
M('-C<F5E;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE
M('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT-B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-38*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$Y"FUS9VED(")4:&4@=V5A=&AE<BYC
M;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T
M<B`B26YG96X@:6YN<W1I;&QI;F=A<B!E<B!T:6QG:F5N9V5L96=E+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM<V=I9"`B
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z
M-S,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R
M(")0<F]B;&5M(&UE9"#E(&QE9V=E('1I;"`G)7,G('1I;"!S>7-T96UE="XB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@
M=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B4')O8FQE
M;2!V960@9FIE<FYI;F<@878@)R5S)R!F<N4@<WES=&5M970N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TZ("(*;7-G<W1R(")0<F]B;&5M('9E9"!F:F5R;FEN9R!A=B`G)7,G
M(&9RY2!S>7-T96UE="XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D
M871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R(")0<F]B;&5M(&UE9"#E(&QE9V=E
M('1I;"`G)7,G('1I;"!S>7-T96UE="XB"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S
M('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HX.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A
M<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;VYL>2!P87)T:6%L;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@
M=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@
M>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E("(*
M(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I
M;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS
M9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN
M9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U"B,L
M(&9U>GIY"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI
M9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!MY2!V97)E
M(&5I="!T86PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O
M=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z
M+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H("(*
M(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R,0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,P-@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-C4*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q.`IM
M<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`Y-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@Y"B,L(&9U>GIY
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM
M<V=S='(@(D1E;FYE('9E<F1I96X@;>4@=F5R92!E:70@=&%L+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*;7-G:60@(B(*(E1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`B1&5T=&4@=&%L970@;>4@=F5R92!M:6YS="!E:6XN
M(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U
M"FUS9VED(")4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@
M9WII<"!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S
M="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B1&5N;F4@=F5R9&EE;B!MY2!V97)E
M(&5I="!T86PN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5&AU;F1E<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T"FUS9VED
M(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U
M>GIY"FUS9VED(")4:6UE(@IM<V=S='(@(E1I='1E;"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"FUS9VED(")4:6UE
M(&9O<FUA="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]"
M;&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71T
M96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@
M(E1O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I
M=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H
M36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3$*;7-G:60@(E1O9&%Y(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE
M("A?=&]P*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-C,*(RP@9G5Z>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")0<F5S
M96YT87-J;VYA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N
M9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<Y,`IM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED
M(")4=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1U
M<FME>2(*;7-G<W1R(")'<N4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y
M,@IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP
M92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-CD*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E
M<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"B,L(&9U>GIY"FUS9VED(")5
M4DPZ(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")5
M:W)A:6YE(@IM<V=S='(@(D]R86YS:F4B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HT,3(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!A8V-E
M<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:VIE(&MO<&QE('1I
M;"!344PM=&5N87(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S@U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW-34*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!C:&%N9V4@=&\@)7,N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L
M92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,C,R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK
M:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O
M9B!<(B5S+R5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G
M.B`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z-#,U"FUS
M9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*;7-G<W1R
M(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L
M92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HR,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT
M96YA<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,V-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C4V"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VMJ92!K
M;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8W)E871E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I
M:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL
M(%-13"UT96YA<BXB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII
M<"YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(")+=6YN
M92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR
M"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,S0X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,S,W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS-#0*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#$W(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,C@X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ
M-C<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HS.#,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92XB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@)R5S)SH@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R
M<VEV96QY.B`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T
M;W)Y+B(*;7-G<W1R(")+86X@:6MK:F4@<F5G:7-T<F5R92!I;FYS=&EL;&EN
M9V%R(&D@^&MT82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@
M9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N<&AP.C$Q
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&QO860@
M=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L
M971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`Q"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-C8@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O
M(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@
M4U%,+71E;F%R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#(*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VMJ92!S;&5T=&4@
M)R5S)SH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<W
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,PIM<V=I9"`B56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M+B(*;7-G<W1R(")+86X@:6MK:F4@:V]P;&4@=&EL(%-13"UT96YA<BXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C0U"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N
M(@IM<V=S='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+G!H<#HX,S4*;7-G:60@(E5N86)L92!T;R!R
M96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-C8*;7-G:60@(E5N86)L92!T
M;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M860@9FEL93H@(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T92`G)7,G.B`E
M<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@
M(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E
M<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I:VMJ92!K;W!L92!T:6P@4U%,+71E;F%R+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,3`@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B
M2W5N;F4@:6MK:F4@<VQE='1E("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DMU;FYE(&EK
M:VIE('-L971T92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")+86X@:6MK:F4@;VUS
M971J92!D971T92!7;W)D+61O:W5M96YT970N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ
M-3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:VIE('-L971T
M92`G)7,G.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-SD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#,*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T<B`B
M06YG<F4@96YD<FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B56=Y;&1I
M9R!S=F%R(&9RY2!T96YA<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C,X-`HC+"!F=7IZ>0IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS
M92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E5G>6QD:6<@<W9A<B!F<N4@
M=&5N87(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER
M871E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(S."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+
M:6YG9&]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV.2!L:6(O0FQO8VLO
M;65T87(N<&AP.C<Q"FUS9VED(")5;FET<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3D*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L
M:65N="!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P
M<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3@*;7-G:60@(E5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(D)R=6MA<FYA;6XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R
M:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E
M('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L
M:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G
M('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@
M86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@
M(E5N<V5T(&-O;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z.3(V"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R
M(")/<'!D871E<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*
M;7-G<W1R(")/<'!D871E<G1E("<E<R<N(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHW-@HC+"!F=7IZ>0IM<V=I9"`B57!D871E('5S
M97(B"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$T
M-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#(@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E
M9"!<(B5S7"(N(@IM<V=S='(@(D]P<&1A=&5R=&4@)R5S)RXB"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W."!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DY
M"FUS9VED(")5<&QO860B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E
M='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ
M.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H
M<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S
M.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(T"FUS9VED(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D
M:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED
M(")5<V5R(@IM<V=S='(@(D)R=6MA<F%R(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A
M=&EO;B(*;7-G<W1R(")"<G5K87)A9&UI;FES=')E<FEN9R(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C4Q"FUS9VED(")5<V5R($]P=&EO
M;G,B"FUS9W-T<B`B0G)U:V%R86QT97)N871I=B(*"B,Z('-I9VYU<"YP:'`Z
M-C(*(RP@9G5Z>GD*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(D)R=6MA<F%D;6EN:7-T<F5R:6YG(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I
M9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY
M7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R
M(")"<G5K87)N86UN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHX-PHC+"!F=7IZ>0IM<V=I9"`B57-E<FYA;64Z(@IM
M<V=S='(@(D)R=6MA<FYA;6XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHX"B,L(&9U>GIY"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(D)R
M=6MA<FYA;6XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHR
M"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R(")"<G5K87)A
M<B!I('-Y<W1E;65T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T
M86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(U-0IM<V=I9"`B5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED
M(")686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C,X"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3<W
M"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA>&EM
M=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C8*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3`Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.#8*;7-G:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@
M(E9A<FEA8FQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E
M;F5Z=65L82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P
M"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(E1I;&=A;F<B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(V"FUS9VED(")697)S:6]N
M($-O;G1R;VPB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(E9E<GD@2&EG
M:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-`IM<V=I9"`B
M5FEE=&YA;65S92`H5DE30TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S
M+"!5+E,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y
M"FUS9VED(")6:7-I8FEL:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E9I<VEB:6QI='DZ("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-@IM<V=I9"`B5T%23B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%144"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BQ71V87)I;F<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS
M9VED(")792(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS
M9VED(")796(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T
M<B`B2W9A<B!V96ME(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z
M,C@*(RP@9G5Z>GD*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5F5L:V]M96XL
M("5S(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.C4W"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L:V]M96X@=&EL("5S(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM
M<V=S='(@(E9E;&MO;65N+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")797-T
M97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS9VED(")7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!
M=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$R-0IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*;7-G:60@
M(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7
M:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*
M;7-G:60@(E=I;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S
M<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(T,@IM<V=I9"`B5VEN9#H@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*
M;7-G:60@(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@
M061D<F5S<R(*;7-G<W1R(")!9')E<W-E+"!A<F)E:60B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K
M(%!H;VYE(@IM<V=S='(@(E1E;&5F;VXL(&%R8F5I9"(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C$V.2!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C,P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%
M>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C$Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0S"FUS9VED
M(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU
M"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,@IM
M<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(L7%(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U"B,L(&9U>GIY
M"FUS9VED(")965E9(@IM<V=S='(@(L7%(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M87`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(L5R;&5G(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`B1W+X
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY
M-C,*;7-G:60@(EEE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I9"`B665S+"!)($%G<F5E
M(@IM<V=S='(@(DIA+"!E9R!E<B!S86UD(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E
M9&ET+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A
M;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@
M(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@
M8V%N(&YO="!H879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@
M;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@U-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<U"B,L(&9U>GIY"FUS
M9VED(")9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N
M(@IM<V=S='(@(DMU;FYE(&EK:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E
M+7!O<W1A9')E<W-E+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A;GD@
M9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O
M;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B06QT97)N871I=F$@9&EN92!H
M87(@8FQI='0@;W!P9&%T97)T92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C8Q"FUS9VED("(B"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N
M86P@)RLG("(*(F9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I
M>"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X
M.`IM<V=I9"`B66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M5D93(&)A8VME;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B1'4@;>4@<VMI;&1R92!P<F]B;&5M970@9OAR(&1U(&MA
M;B!S96YD92!P<F]B;&5M<F%P<&]R=&5N+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE
M=&5D+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U:V%R;F%M
M;B#E(&9J97)N92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K87)N86UN
M(.4@9FIE<FYE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B
M1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!A9&0N(@IM<V=S='(@(D1U(&WE('-P97-I9FES97)E(&5I="!B<G5K
M87)N86UN(.4@;&5G9V4@=&EL+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E:70@8G)U
M:V%R;F%M;B#E(&QE9V=E('1I;"XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B1'4@
M;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA;6X@Y2!F:F5R;F4N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*
M(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@
M;F%M92XB"FUS9W-T<B`B1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R=6MA<FYA
M;6X@Y2!F:F5R;F4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F
M;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I
M9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H<"UF;W)M870*;7-G:60@
M(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("+8:W1A(&1I("@E<RD@:&%R(&?E='0@=70@<.4@=&ED
M+B!,;V=G(&EN;B!PY2!N>71T+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C,X"B,L(&9U>GIY"FUS9VED(")9;W5R($5M86EL($%D9')E
M<W,B"FUS9W-T<B`B1&D@92UP;W-T861R97-S93HB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,C$R"B,L(&9U>GIY"FUS9VED(")9;W5R($9R;VTZ(&%D
M9')E<W,Z(@IM<V=S='(@(D1I(&4M<&]S=&%D<F5S<V4Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(D1I;B!I
M;F9O<FUA<VIO;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,S"B,L(&9U>GIY"FUS9VED(")9;W5R($YA;64B"FUS
M9W-T<B`B1&ET="!N86UN.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO
M861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF
M('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@
M86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT
M:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG<V)A:V1E
M;&XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*;7-G
M:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B
M(@HB3&ES=&EN9R!A=B!B<G5K87)A<B!E<B!I:VMJ92!S=/AT=&$@878@8F%K
M<F4@875T96YT:7-E<FEN9RP@96QL97(@9G5N:W-J;VYE;B`B"B)H87(@878@
M96EN(&5L;&5R(&%N;F%N(&=R=6YN(&)L:71T('-LY71T(&%V+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN
M8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED(")9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T
M;R!P<FEN="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T
M<B`B06QT97)N871I=F$@9&EN92!H87(@8FQI='0@;W!P9&%T97)T92XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,34X"B,L(&9U>GIY"FUS9VED(")9
M;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(E-T86YD87)D:61E;G1I
M=&5T(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P,0HC+"!F=7IZ>0IM
M<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(D1I='0@;F%M;CHB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P"B,L(&9U>GIY"FUS9VED
M(")9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")!;'1E<FYA=&EV
M82!D:6YE(&AA<B!B;&ET="!O<'!D871E<G1E+B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T
M:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B06QT97)N871I=F$@9&EN
M92!H87(@8FQI='0@;W!P9&%T97)T92XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D+B(*;7-G<W1R(")!;'1E<FYA=&EV82!D:6YE(&AA<B!B;&ET
M="!O<'!D871E<G1E+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED
M("(B"B)9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,R"FUS
M9VED(")9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@
M<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L
M;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");4')O8FQE
M;2!297!O<G1=(@IM<V=S='(@(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H
M;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H
M<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3DS
M"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R
M(");;&EN:F4@)7,@878@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-30Q('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z
M>GD*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')E
M<FEN9R(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$871A5')E92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,S$*(RP@9G5Z>GD*;7-G:60@(E]$96QE=&4@4F]W(@IM
M<V=S='(@(E-L971T92(*"B,Z(&QI8B]A<&DN<&AP.C$S,PHC+"!F=7IZ>0IM
M<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B7TAE
M;'`B"FUS9W-T<B`B2&IE;'`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E]);6%G92!0<F]P
M97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ.30*(RP@9G5Z>GD*;7-G:60@(E],;V<@:6XB"FUS9W-T
M<B`B3&]G9R!I;FXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3DP"B,L(&9U>GIY"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("),;V=G
M('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`HC+"!F
M=7IZ>0IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B06QT97)N871I=B(*"B,Z
M(&QI8B]A<&DN<&AP.C$S-PHC+"!F=7IZ>0IM<V=I9"`B7U!E<FUI<W-I;VYS
M(@IM<V=S='(@(E1I;&=A;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@(E]2
M96UO=F4@3&EN:RXN+B(*;7-G<W1R(")&:F5R;B!P87(B"@HC.B!L:6(O87!I
M+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G
M:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$R.0HC+"!F=7IZ>0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(D)R
M=6MA<F%R(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*(RP@
M9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<W-E8F]K
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*;7-G
M:60@(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF;W)M870*;7-G
M:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I
M;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I
M9"`B8VQI8VL@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T
M"FUS9VED(")C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS
M9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM
M<V=I9"`B9FEL92(*;7-G<W1R(")4:71T96PB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O0FQO8VLO
M;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-3`*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM
M<V=I9"`B:#HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G:60@(FAO
M<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B:6UM
M961I871E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*(RP@9G5Z>GD*;7-G:60@(FQI
M;F5S72(*;7-G<W1R(")/=F5R<VMR:69T97(B"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN
M9R!)4T\N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-CD*;7-G:60@(FUM(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDQ('-E<G9I8V5S+W!O<G1A
M;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B;F%M92(*;7-G<W1R(").86UN(@H*
M(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R,0IM<V=I9"`B;F]T(&EM<&QE
M;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0IM<V=I
M9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,3<T"B,L(&9U>GIY"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R
M(")4:6QG86YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R
M96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S,*(RP@9G5Z>GD*;7-G
M:60@(G)I<VEN9R(*;7-G<W1R("+%='9A<FEN9R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A
M:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M.3D*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G
M:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U"FUS9VED(")S<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(DQE<R(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET
M8V@@;V9F(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM
M<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P
M-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(DMV87(@:6YN
M;&]G9VEN9R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(G5N
M:69I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T
M+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G
M:60@(G5S97(@<V5L96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T
M<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C0Q"FUS9VED(")W.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T
M<B`B(@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&\O<&Q?4$PN<&\`````````````````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P-C(P,#$U(#$P-3$U-#,T,30R(#`Q-S4R,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C($A/
M4D1%(%!O;&ES:"!T<F%N<VQA=&EO;BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#$@
M36%R:75S>B!:>6YE;"`\;6%R:75S>D!M:7IA<BYO<F<^"B,@36%R:75S>B!:
M>6YE;"`\;6%R:75S>D!M871H+G5W8BYE9'4N<&P^+"`R,#`Q+@HC(%!I;W1R
M(%)O<WIA='EC:VD@/&1E>'1E<D!D96)I86XN;W)G/BP@,C`P,2X*(R!+<GIY
M<WIT;V8@2V]Z;&]W<VMI(#QK;WII:S%`;S(N<&P^+"`R,#`U+@HC"FUS9VED
M("(B"FUS9W-T<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M
M8W9S7&XB"B)297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E
M+F]R9UQN(@HB4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3$M,C0@,C`Z-38K
M,#$P,%QN(@HB4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TQ,2TR-"`R,3HT-BLP
M,3`P7&XB"B),87-T+51R86YS;&%T;W(Z($MR>GES>G1O9B!+;WIL;W=S:VD@
M/&MO>FEK,4!O,BYP;#Y<;B(*(DQA;F=U86=E+51E86TZ(%!O;&ES:"`\<&Q`
M;&DN;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*(D-O;G1E;G0M5'EP
M93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR7&XB"B)#;VYT96YT
M+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=%QN(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B(@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T<B`B
M)7,@+2!G;W1O=WD@9&\@=WEK;VYA;FEA(&-Y:VQI8WIN>6-H(&]P97)A8VII
M('IA>FYA8WIO;GEC:"!P;VYIOV5J+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,S8X"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM
M<V=S='(@(B`H)7,@9&YI('1E;74I(@H*(SH@;&EB+TAO<F1E+G!H<#HQ,C4V
M"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R
M("(H:VQU8WH@9&]S=.IP=2`E<RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C,W-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S
M='(@(B`H=R!C:;%G=2`E<R!D;FDI(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(S-S(*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H9'IIMBDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-`IM<V=I9"`B("AT;VUO<G)O=RDB"FUS
M9W-T<B`B("AJ=71R;RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W,`IM
M<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H=V-Z;W)A:BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Y-0IM<V=I9"`B(&%T("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0TQ)+G!H<#HR-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO
M="!A('9A;&ED(&-H;VEC92XB"FUS9W-T<B`B7"(E<UPB(&YI92!J97-T('!R
M87=I9+-O=WEM('=Y8F]R96TN(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H
M<#HU-30@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HY,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D
M92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&YI92!J97-T('-K;VYF:6=U
M<F]W86YY('<@<F5J97-T<GIE($AO<F1E+B(*"B,Z(&QI8B](;W)D92]4<F5E
M+G!H<#HQ-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T
M<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEE>FYA;&5Z
M:6]N>2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M(@IM<V=S='(@(E5D8;-O('-IZB!D;V1AYB!<(B5S7"(@9&\@9W)U<"XB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('5P<F%W
M;FEE\2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN+W!E<FUS+V%D
M9&-H:6QD+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S
M(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B7"(E<UPB(&YI92!Z;W-T8;,@
M=71W;W)Z;VYY.B`E<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C(U"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G
M<W1R("(E9"`E<R!I("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]T
M;W`N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS
M9W-T<B`B)7,@+2!5=V%G82(*"B,Z('1E;7!L871E<R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8SHS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VIA("5S(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B)7,@;V1C:7-K('!A;&-A(@H*(SH@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@S,"!L:6(O2&]R9&4O34E-
M12]#;VYT96YT<RYP:'`Z.#,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"
M(@IM<V=S='(@(B5S(&M"(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@
M+2!O<&5R86-J92!C>6ML:6-Z;F4@+2!P;W1W:65R9'IE;FEE(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,C$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(DMO
M;F9I9W5R86-J82`E<R(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C8S"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B
M4F5J97-T<F%C:F$@)7,B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R
M965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M
M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C4V."!L:6(O5D93+V9T<"YP:'`Z-C,V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(E<R!J=;\@:7-T;FEE:F4N
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3D@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ-C4@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,SD*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#4@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3$*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S
M(&1O("5S('H@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,S.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!J
M97-T('=Y;6%G86YY(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU
M="(*"B,Z(&QI8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N
M:65Z;F%L97II;VYY+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS
M9W-T<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.#DQ"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(DMS:;&_:V$@861R97-O=V$@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C@X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(DMA;&5N9&%R>B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z.#<U"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G
M<W1R(").;W1A=&YI:R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#DY
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B
M3&ES=&$@>F%D8?$@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z
M("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HS-3,@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.`IM
M<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$X."!L:6(O0FQO8VLO;65T87(N<&AP.C$Y,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM<V=S='(@(B5S
M(&1O("5S('H@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S`@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(Q,CD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8X.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM('=Y
M8FEE<GH@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R
M($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R+6=O9'II;FYY(&9O<FUA="(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B
M"FUS9W-T<B`B,C0M9V]D>FEN;GD@9F]R;6%T(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O=&EM92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&=O
M9'HN(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(CQ0;W!R>F5D;FDB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")"<F%K(&MO
M;F9I9W5R86-J:2!W97=NZG1R>FYE:B!D;&$@=&5G;R!H;W-T82(*"B,Z(&QI
M8B](;W)D92YP:'`Z,38P"FUS9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U
M<G)E9"(*;7-G<W1R(").87-TL7!ILR!BL[%D(&MR>71Y8WIN>2(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.CDR,`IM<V=I9"`B02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!Z87-Z
M>69R;W=A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3$T-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HB4&]T
M<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%!'4"!D;R!S<')A=V1Z96YI
M82!P;V1P:7-A;F5J('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3`W-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N92!S
ML2!K;'5C>B!P=6)L:6-Z;GD@4$=0+"!K;'5C>B!P<GEW871N>2!01U`@;W)A
M>B!H87.S;R!D;R`B"B)O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3DU"FUS9VED("(B"B)!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M4&]T<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A
M=&YY(%!'4"!O<F%Z(&AA<[-O(&1O("(*(G!O9'!I<V%N:6$@=VEA9&]M;[9C
M:2XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(E!O=')Z96)N92!SL2!K;'5C>B!P=6)L:6-Z
M;GD@4R]-24U%+"!K;'5C>B!P<GEW871N>2!3+TU)344@;W)A>B!H87.S;R!D
M;R`B"B)O9'-Z>69R;W=A;FEA('=I861O;6^V8VDN(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)0
M;W1R>F5B;F4@<[$@:VQU8WH@<'5B;&EC>FYY(%,O34E-12P@:VQU8WH@<')Y
M=V%T;GD@4R]-24U%(&]R87H@:&%SLV\@9&\@(@HB<&]D<&ES86YI82!W:6%D
M;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S8T"FUS
M9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N(@IM<V=S='(@(E!O=')Z96)N>2!J97-T(&ML=6-Z('!U
M8FQI8WIN>2!334E-12!D;R!Z87-Z>69R;W=A;FEA('=I861O;6^V8VDN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F
M=7IZ>0IM<V=I9"`B04T@0VQO=61S(@IM<V=S='(@(EIA;6MN:6HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ
M>0IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("):86QO9W5J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*(RP@9G5Z
M>GD*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@HC+"!F=7IZ
M>0IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R("));7!O<G0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,PHC+"!F=7IZ>0IM
M<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(DEM<&]R="(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI
M<R!E9&ET;W(B"FUS9W-T<B`B3R!T>6T@961Y=&]R>F4B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B
M3R!P<F]G<F%M:64N+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@HC
M+"!F=7IZ>0IM<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(E-T86YO=VES:V\B
M"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-S`*(RP@9G5Z>GD*;7-G:60@(D%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(D%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(DAA<[-O(&1O(&MO;G1A(@H*(SH@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G
M<W1R(")+;VYT;R!Z86)L;VMO=V%N92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S$W"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DMO;G1A
M(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4T(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,3,R"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ
M-"!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ-@IM<V=I
M9"`B061D(@IM<V=S='(@(D1O9&%J(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,30@861M:6XO9W)O=7!S+G!H<#HR,34*(RP@9G5Z>GD*;7-G:60@(D%D9"!#
M:&EL9"!'<F]U<"(*;7-G<W1R(")$;V1A:B!N;W>Q(&=R=7#J(@H*(SH@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HX-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C@U"B,L(&9U>GIY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G
M<W1R(")$;V1A:B!N;W=E('5P<F%W;FEE;FEE(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R(")$;V1A
M:B!T=71A:CHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(P."!A9&UI;B]G<F]U
M<',N<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")$;V1A
M:B!N;W>Q(&=R=7#J(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,R!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<T"FUS9VED(")!9&0@3F5W(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B1&]D86H@;F]W92!U<')A=VYI96YI92(*"B,Z('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.CD*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<
M(B(*;7-G<W1R(")/<&-J92`E<R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<
M(B5S7"(B"FUS9W-T<B`B3W!C:F4@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(D1O9&%J(&YO=V5G
M;R!UOWET:V]W;FEK83HB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@(D1O9&%J
M(&MO;'5M;NHB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C,U"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B1&]D86H@;F]W
M>6-H(&-ZLV]N:_-W(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(D1O9&%J('!A<NHB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<B(*;7-G<W1R
M(")$;V1A:B!M96YU("5S(&1O('!A<VMA($UO>FEL;&DB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D
M<F5S<R!B;V]K.B(*;7-G<W1R(")$;V1A:B!D;R!K<VFQOVMI(&%D<F5S;W=E
M:CHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D1O9&%J(&1O
M(&UO:F5J(&MS:;%Z:VD@861R97-O=V5J(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(D1O9&%J('6_>71K;W=N:6MA
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+"!B=70@8V]U
M;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@(@HB
M)7,N(@IM<V=S='(@(D1O9&%N;R!<(B5S7"(@9&\@<WES=&5M=2X@36^_97-Z
M('-IZB!Z86QO9V]W8>8N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A
M;B!L;V<@:6X@;F]W+B(*;7-G<W1R(")$;V1A;F\@7"(E<UPB(&1O('-Y<W1E
M;74N($UOOV5S>B!S:>H@>F%L;V=O=V'F+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHT"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(D1O9&%W86YI92!UOWET:V]W;FEK\W<@:F5S="!W
M>;-A8WIO;F4N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#,@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS
M9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B2W-IL;]K82!A9')E<V]W82(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC+"!F=7IZ
M>0IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B3W!C:F4@)7,B"@HC.B!A9&UI;B]I;F1E>"YP
M:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-J82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS.3(*;7-G:60@(D%D<R(*;7-G<W1R
M(")296ML86UY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B069G86YI
M<W1A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T<B`B06QB86YI82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@
M(D%L9V5R:6$B"FUS9W-T<B`B06QG:65R:6$B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B
M06QI87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!
M;&EG;FUE;G0Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E=S>GES=&MO(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3$X('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-C4*;7-G:60@(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E=S
M>GES8WD@=7=I97)Z>71E;&YI96YI('6_>71K;W=N:6-Y(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(Q,@IM<V=I9"`B06QL
M($=R;W5P<R(*;7-G<W1R(")7<WIY<W1K:64@9W)U<'DB"@HC.B!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z,S@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW
M-PIM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(E=S>GES=&MI92!U
M<')A=VYI96YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*(RP@9G5Z>GD*;7-G:60@(D%L;"!F;W5R('-I
M9&5S(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-S(*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")0
M;WIW\VP@;F$@=VEE;&4@861R97/S=R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,C8*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]$871A5')E92]S<6PN
M<&AP.C0P.`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B2G6_(&ES
M=&YI96IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT97)N871Y=VYY(&QO
M9VEN($E-4U`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED
M(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")!;'1E<FYA='EW
M;GD@:&%SLV\@24U34"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3$*
M;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@(D%L=&5R
M;F%T>7=N82!N87IW82!UOWET:V]W;FEK82!)35-0(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S(@IM<V=S='(@(D%L=&5R;F%T>7=N>2!A9')E<R!E;6%I;"(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"B,L(&9U>GIY"FUS9VED(")!;'1E
M<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(E1W\VH@861R97,@92UM86EL.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(D%L
M=&5R;F%T>7=N>2!T96MS=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](;W)D
M92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N(@IM<V=S='(@(EIO<W1ALV$@<&]D86YA(&YI97!R87=I
M9+-O=V$@=V%R=&^VYBXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,34T"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+B(*;7-G<W1R(")0<F]S>NH@<&]D8>8@;F%Z=^H@=;]Y=&MO=VYI
M:V$@:2!H87.S;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B06YG;VQA(@IM<V=S='(@(D%N9V]L82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA
M(@IM<V=S='(@(D%N9W5I;&QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B06YO;FEM
M;W=E(%!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*
M;7-G:60@(D%N<W=E<B(*;7-G<W1R(")/9'!O=VEE9+PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;G1A
M<F-T:6-A(@IM<V=S='(@(D%N=&%R:W1Y9&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N
M9"!"87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U(&QI8B](;W)D92]";&]C:R]522YP
M:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM
M<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L:6MA8VIA(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$S.0IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(D%P;&EK86-J82!G;W1O=V$B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@
M4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(EIA='=I97)D
MO"(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX,S`*;7-G:60@
M(D%P<')O>&EM871E(%-I>F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-R!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(DMW:65C
M:67Q(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S4*;7-G:60@(D%R86)I
M8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F%R+G!H<#HU.2!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP
M+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM
M<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B5VEE;&MOMN8@87)C
M:&EW=6TB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(DYA>G=A(&%R8VAI=W5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N
M=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R(")#>GD@;F$@<&5W;F\@8VAC
M97-Z('5S=6ZQYB!TZB!R96=UL^H_(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R
M;W5P<R]D96QE=&4N:6YC.CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A
M;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B0WIY(&YA('!E=VYO(&-H8V5S>B!U
M<W5NL>8@=.H@<F5G=;/J/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!
M<F=E;G1Y;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N:6$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T
M<B`B07)U8F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34*;7-G:60@
M(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I
M8R!296=I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Q-PIM<V=I9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(E!O<')OMB!O('!O
M='=I97)D>F5N:64@<')Z960@=WEK;VYA;FEE;2!O<&5R86-J:2!C>6ML:6-Z
M;GEC:#\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q,@IM<V=I9"`B07-S
M:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-S4*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT
M(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C,X"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HY.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B071T
M<FEB=71E<R(*;7-G<W1R(")!=')Y8G5T>2(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS.#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B4VEE<G!I
M9?$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4Y"FUS9VED(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R(")!=7-T<FEA(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER
M=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&EM
M87`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$S-0IM<V=I9"`B
M075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A
M<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U
M<RYP:'`Z,3(R"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER=7,Z($YI92!Z
M;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&EM87`N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z
M(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(
M4"!W:71H('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B
M"B)!=71H7V9T<#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R
M>F5N:6$@1E10+B!3:V]M<&EL=6H@4$A0('H@(@HB<&%R86UE=')E;2`M+65N
M86)L92`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@
M(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R(")!=71H7VEM87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE
M9V\@<F]Z<WIE<GIE;FEA($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B
M-2YP:'`Z-3$*;7-G:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VMR8C4Z($YI92!Z;F%L
M97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&MR8C4N(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O;&1A<"YP:'`Z-3@*;7-G:60@(D%U=&A?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H
M7VQD87`Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA
M($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3@T"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A
M9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM
M<V=S='(@(EIA<&ES>F%N:64@<WIK:6-U(&YI975D86YE+B!397)W97(@>G=R
M\V-ILR!O9'!O=VEE9+PZ("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,C(R"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3FEE('5D
M8;-O('-IZB!U<W5NL>8@=;]Y=&MO=VYI:V$@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!.:64@=61ALV\@<VGJ('5A:W1U86QN:>8@=;]Y=&MO=VYI:V$@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(D%U=&A?;6-A;#H@3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS
M>F5R>F5N:6$@34-!3"XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P
M"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!.:64@>FYA
M;&5Z:6]N;R!W>6UA9V%N96=O(')O>G-Z97)Z96YI82!S;6)A=71H+B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B57=I97)Z>71E;&YI96YI
M92!N:64@<&]W:6]DLV\@<VGJ(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C<V"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"X@)7,B"FUS9W-T<B`B57=I97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@
M<VGJ+B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS
M9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R
M+B(*;7-G<W1R(")5=VEE<GIY=&5L;FEE;FEE(&]D<GIU8V]N92!P<GIE>B!S
M97)W97(@4D%$2553+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-C@*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")5=VEE<GIY=&5L;FEE;FEE(&1O('-E<G=E<F$@1E10(&YI92!P;W=I;V2S
M;R!S:>HN(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHX,PIM<V=I
M9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B1&]S=.IP;F4@<&]L83HB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y
M"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B96IDOV%N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B
M"FUS9W-T<B`B5WEM\W=K:2!"3T9((@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N
M9"(*;7-G<W1R(")4LV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S
M='(@(DMO;&]R('2S82(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q
M"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(EJS92!H
M87.S;R!+97)B97)O<V$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z
M.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B6K-A
M(&YA>G=A('6_>71K;W=N:6MA($ME<F)E<F]S82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C8*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B
M"FUS9W-T<B`B5WES<'D@0F%H86UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C,X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R
M(")"86AR86IN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@
M(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D)ALW1Y8VMI("A)4T\M
M.#@U.2TQ,RDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H(@IM<V=S='(@(D)A;F=L861E
M<WHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*
M;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(D]D<GIU8V]N92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E
M;&%R=7,B"FUS9W-T<B`B0FEALV]R=;8B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S
M='(@(D)E;&=I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R(")"96QI>F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"96YI;B(*;7-G<W1R(")"96YI;B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS
M9W-T<B`B0F5R;75D>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`B1&%T82!U<F]D>F5N:6$B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(X"B,L('!H<"UF;W)M870*
M;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U
M="YI;F,Z.#D*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(E5S=&%W
M:65N:6$@8FQO:W4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B5'EP(&)L;VMU(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX"B,L(&9U
M>GIY"FUS9VED(")";VQD(@IM<V=S='(@(E1R9;;F(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I
M82(*;7-G<W1R(")";VQI=VEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$Y,0IM<V=I9"`B0F]O:VUA<FMS(@IM<V=S='(@(EIA:[-A9&MI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,`HC+"!F=7IZ>0IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(DAO<F1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM
M<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0HC+"!F
M=7IZ>0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R(")(;W)D92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O
M<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F^V;FEA(&D@2&5R8V5G
M;W=I;F$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O
M=&@B"FUS9W-T<B`B3V)A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0X
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B
M0F]U=F5T($ES;&%N9"(*;7-G<W1R(")7>7-P>2!/=V-Z92(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R
M87II;"(*;7-G<W1R(")"<F%Z>6QI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA
M;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5L9V%R:6$B"FUS9W-T<B`B
M0G6S9V%R:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Y"B,L(&9U>GIY"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S
M='(@(E=Y8FEE<GH@;&ES=.HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)K:6YA($9A<V\B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S@S"FUS9VED(")#35,B"FUS9W-T<B`B0TU3(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S4*;7-G:60@(D-2
M0R(*;7-G<W1R(")#4D,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C4Y-PIM<V=I9"`B0U),($1I<W1R:6)U=&EO;B!0;VEN=',B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E>S8;9C:7=OMF-I(&MO;?-R:VDN+BX@*%]C*2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3`*(RP@9G5Z>GD*;7-G:60@(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(EIAL[%C>FYI:R!N:64@
M>F]S=&&S('IN86QE>FEO;GDN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0U-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30X
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,T"FUS9VED(")#86QM(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@S"FUS9VED(")#86UB;V1I82(*;7-G<W1R(")+86UB;V2_82(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-A;65R;V]N(@IM<V=S='(@(DMA;65R=6XB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@HB3FEE('5D8;-O('-IZB!Z<F5S971O=V'F(&AA<[-A
M(&%U=&]M871Y8WIN:64L('-K;VYT86MT=6H@<VGJ('H@(@HB861M:6YI<W1R
M871O<F5M+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB
M+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($E-05`Z("5S
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-`IM<V=I9"`B0V%N861A(@IM<V=S='(@(DMA;F%D82(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$P,2!A9&UI;B]U<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8U"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]C
M;&5A<BYI;F,Z,3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHQ-PIM<V=I9"`B0V%N8V5L(@IM<V=S='(@(D%N=6QU:B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O
M8FQE;2!297!O<G0B"FUS9W-T<B`B06YU;'5J(')A<&]R="!O('!R;V)L96UI
M92(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UO
MOVYA('-K87-O=V'F('!L:6MU(%PB)7-<(B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I
M9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R
M(").:64@=61ALV\@<VGJ('IN86QEO.8@:V%T86QO9W4@='EM8WIA<V]W96=O
M+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*;7-G
M<W1R("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4R"B,L('!H<"UF;W)M870*
M;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T
M<B`B3FEE(&UOOVYA('-K87-O=V'F(&MA=&%L;V=U(%PB)7-<(B(*"B,Z(&QI
M8B](;W)D92]$871A5')E92YP:'`Z,3$R(&QI8B](;W)D92]$871A5')E92]S
M<6PN<&AP.C4X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S='(@(DYI92!M;[]N
M82!S:V%S;W=AYB!K871A;&]G=2!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O1&%T
M851R964O<W%L+G!H<#HU,3(*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N
M=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO
M="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.`IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R(")7>7-P>2!::65L;VYE9V\@
M4')Z>6RQ9&MA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-`HC+"!F=7IZ>0IM<V=I9"`B0V%P=&EO;B(*;7-G
M<W1R(")/<&-J92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I
M9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S='(@(DMA=&5G;W)I92!I
M(&]Z;F%C>F5N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-@HC+"!F=7IZ>0IM<V=I9"`B0V%Y;6%N($ES;&%N9',B
M"FUS9W-T<B`B5WES<'D@4V%L;VUO;F$B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*;7-G<W1R
M(")496PN(&MO;2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS
M9W-T<B`B5[-AMF-I=V^V8VD@:V]M\W)K:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I
M;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*
M;7-G<W1R(")7LV&V8VEW;[9C:2!K;VWS<FMI(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A
M8VEN9SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S0*
M;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ
M-"DB"FUS9W-T<B`B0V5L='EC:VD@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*(RP@
M9G5Z>GD*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")3='?S<GHB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#
M96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P=6)L:6MA(*9R
M;V1K;W=E:B!!9G)Y:VDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM
M<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BDB"FUS9W-T<B`B
MIG)O9&MO=V]E=7)O<&5J<VMI("A)4T\M.#@U.2TR*2(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A
M:6QS(@IM<V=S='(@(E-Z8WIE9_.S>2!C97)T>69I:V%T=2(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED(")#97)T:69I8V%T92!/
M=VYE<B(*;7-G<W1R(")7LV&V8VEC:65L(&-E<G1Y9FEK871U(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(E-Z8WIE9_.S>2!C97)T>69I
M:V%T=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P.`IM<V=I9"`B0VAA9"(*;7-G<W1R(")#>F%D(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM<V=S='(@(EIM:67Q(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B6FUI
M9?$@:6UIZBP@;F%Z=VES:V\@:2!A9')E<RP@:W3S<GD@:6YN:2!W:61ZL2!W
M(%1W;VEC:"!L:7-T86-H(&5M86EL+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*(RP@9G5Z>GD*;7-G:60@
M(D-H87(B"FUS9W-T<B`B2V%L96YD87)Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C
M7VL@3&EN:RXN+B(*;7-G<W1R(")3<')A=V2\(&QI;FLN+BXB"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("):87IN86-Z('!O>GEC
M:NH@9&QA(&MT\W)E:B!C:&-E<WH@=WEK;VYAYB!O<&5R86-JZBXB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#:&EL92(*;7-G<W1R(")#:&EL92(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@
M(D-H:6YY(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA
M;"`H0FEG-2DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E!O
M9&%J(&AA<[-O(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C@*
M;7-G:60@(D-H;V]S92!A('5S97)N86UE(@IM<V=S='(@(E!O9&%J(&YA>G?J
M('6_>71K;W=N:6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,`IM
M<V=I9"`B0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.B(*;7-G<W1R(")7
M>6)I97)Z('-P;W/S8B!W>;9W:65T;&%N:6$@9&%T.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G
M:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S
M*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@
M(E=Y<W!A($)OOV5G;R!.87)O9'IE;FEA(@H*(SH@;&EB+U9&4RYP:'`Z-C$U
M(&QI8B].970O4TU3+G!H<#HR.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R
M("):8;.Q8WIN:6L@;FEE('IO<W1ALR!Z;F%L97II;VYY+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY"FUS
M9VED(")#;&5A<B(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-
M4T]F9FEC92!T86=S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+V-L96%R+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B6F1A;&YE('-E<G=E<GDB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,38*(RP@9G5Z>GD*
M;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B2V%L96YD87)Z(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*(RP@9G5Z>GD*;7-G:60@
M(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-0HC+"!F=7IZ>0IM
M<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")+86QE;F1A<GHB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;F]T:6-E7V)O='1O;2YI;F,Z-@IM<V=I
M9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:VYI:B!B>2!K;VYT
M>6YU;W=AYB(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,@IM<V=I9"`B0VQO<V4@5VEN9&]W(@IM<V=S='(@(EIA;6MN
M:6H@;VMN;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0T"B,L(&9U>GIY
M"FUS9VED(")#;&]U9',B"FUS9W-T<B`B6F%M:VYI:B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"B,L(&9U>GIY"FUS9VED
M(")#;&]U9',@16%R;'DB"FUS9W-T<B`B2W+S=&MI92!S=')E<WIC>F5N:64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-PHC
M+"!F=7IZ>0IM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DMR86HB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R(")7>7-P>2!+;VMO<V]W
M92`H2V5E;&EN9V$I(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHT"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(E-C:&]W86H@
M<&%S96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(X"B,L(&9U>GIY"FUS9VED(")#;VQL87!S960@8F]R9&5R
M<R(*;7-G<W1R("):=VGQ(&9O;&1E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S
M='(@(DMO;'5M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O
M0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@
M(DMO;&]R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y
M.2!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S`P"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM
M<V=S='(@(E=Y8FEE<GH@:V]L;W(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@T-0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R(")7>6+S<B!K
M;VQO<G4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,PHC+"!F=7IZ>0IM<V=I9"`B0V]L<SHB"FUS9W-T<B`B6G=I\2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.30W"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(E1Y='6S>2!K;VQU;6XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@V"B,L(&9U>GIY"FUS9VED(")#;VUI8W,B"FUS9W-T
M<B`B5'?S<GHB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O
M;6UA;F0B"FUS9W-T<B`B2V]M96YD82(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR,`IM<V=I9"`B0V]M;6%N9"!3:&5L;"(*;7-G<W1R(")0;W>S;VMA(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")#;VUM96YT
M(@IM<V=S='(@(DMO;65N=&%R>B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-38V"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R(")+;VUO<GDB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*;7-G<W1R
M(")&:7)M82(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]4
M97AT+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")3='?S<GH@=VEA9&]M
M;[;F("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@
M(D-O;7!U=&5R<R(*;7-G<W1R(")+;VUP=71E<GDB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L(&9U>GIY"FUS9VED(")#;VYD:71I
M;VXB"FUS9W-T<B`B5V%R=6YK:2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(E=A<G5N:VDB"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(E-K;VYF:6=U
M<G5J("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-PIM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")0;W1W:65R9+P@
M:&%SLV\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O
M;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B
M1&5M;VMR871Y8WIN82!297!U8FQI:V$@2V]N9V\B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DY(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G
M<W1R(")0;[.Q8WIE;FEE(&YI92!P;W=I;V2S;R!S:>HN(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@
M(@IM<V=S='(@(E!OL[%C>F5N:64@;FEE('!O=VEO9+-O('-IZCH@(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S<Y"FUS9VED(")#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D]D
M;?-W:6]N;R!P;[.Q8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S@Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D]D;?-W:6]N;R!P;[.Q
M8WIE;FEA(&1O('!U8FQI8WIN96=O('-E<G=E<F$N(%!O=_-D.B`E<R`H)7,I
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V,@IM<V=I9"`B0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q
M8WIE;FEA('-IZB!Z('-E<G=E<F5M($944"XB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B2V]N=&%K='D@>F]S=&&S>2!P;VUYMFQN:64@9&]D86YE(&1O(%1W;VIE
M:B!K<VFQOVMI(&%D<F5S;W=E:BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=&=Z+G!H<#HV,`IM<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S
M960@9FEL93H@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8S
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("):87=A
M<G1OMN8@7"(E<UPB(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(DMO;GEN=75J(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]O:R!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y($-O;VMA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,R"B,L(&9U>GIY"FUS9VED(")#;V]K:64B"FUS
M9W-T<B`B5'?S<GHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B4VMO
M<&EU:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(E-K;W!I=6H@
M=WEB\W(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M=&4@9"=)=F]I<F4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z.34V"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G
M92XB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4$=0*2!W
M:6%D;VUOMF-I+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P,S,*
M;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R(").
M:64@=61ALV\@<VGJ('!O9'!I<V'F("A01U`I('=I861O;6^V8VDN(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO
M="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R(").:64@=61ALV\@
M<VGJ('IA<WIY9G)O=V'F("A3+TU)344I('=I861O;6^V8VDN(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@(D-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R(").:64@=61ALV\@<VGJ('!O
M9'!I<V'F("A3+TU)344I('=I861O;6^V8VDN(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R(").:64@
M;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,3`*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@
ML[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@3$1!4"XB"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B3FEE(&UOOVYA
M(&]T=V]R>GGF("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V
M97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%PB)7-<(B!P;W!R>F5Z($944#H@
M)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W
M('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C$Q,#4*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A
M+B(*;7-G<W1R(").:64@=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!0
M1U`N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").:64@
M=61ALV\@<VGJ(&]D<WIY9G)O=V'F(&1A;GEC:"!3+TU)344N(@H*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*
M;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W86YE
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@
M<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R
M(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@
M)7,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,X,2!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HY,S@*;7-G:60@(D-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").
M:64@=61ALV\@<VGJ('5S=&%L:>8@861R97-U(&4M;6%I;"!O9&)I;W)C>2XB
M"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B
M;V]K+B(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT
M96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#DS"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYI92!M;[]N82!O
M='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*(RP@9G5Z>GD*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB
M=71I;VX@;&ES=',N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1U
MLW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM
M<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?
M5&%S:R`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.C$Q,`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B3FEE
M(&UOOVYA('5T=V]R>GGF(&MA=&%L;V=U(%PB)7-<(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.C<P.`IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P
M=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3FEE('5D
M8;-O('-IZB!U>GES:V'F('H@<V5R=V5R82!K;'5C>F$@<&)U;&EC>FYE9V\N
M(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!O
M='=O<GIYYB!<(B5S7"(@9&\@>F%P:7-U+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)7,N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB`E<RXB"@HC.B!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<R(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA
M;F-E7U1A<VL@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").:64@;6^_
M;F$@;W1W;W)Z>>8@:V%T86QO9W4@7"(E<UPB(@H*(SH@;&EB+U9&4R]/8FIE
M8W0N<&AP.C(S.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(')E860@)7,N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1U
MLW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A
M<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F
M('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U
M<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,P.2!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0P"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X,PHC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@04-,(@IM<V=S='(@(DYI92!M;[]N82!O='=O
M<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-S0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S
M(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A
M;F4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")(;W)D92!N:64@:F5S
M="!W('!ELVYI('-K;VYF:6=U<F]W86YE+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A
M;F4N(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.2!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T
M<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E
M(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S
M7"(N(@IM<V=S='(@(DYI92!U9&&S;R!S:>H@<VMA<V]W86YI92!K871A;&]G
M=2!<(B5S7"(N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@
M<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")#
M;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@
M(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ
M("5S(@IM<V=S='(@(DAO<F1E(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R
M;W=A;F4N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N(@IM<V=S='(@(DYI92!M;[]N82!O
M='=O<GIYYB!M;V1ULW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF
M:6=U<F]W86YE+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I
M9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T
M:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@
M8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(P"B,L(&9U>GIY"FUS
M9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S('!R>F5S>G5K:7=A;FEA('H@<V5R=V5R96T@3$1!
M4"XB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL
M:6YK(%PB)7-<(BXB"FUS9W-T<B`B3FEE('5D8;-O('-IZB!S:V%S;W=AYB!P
M;&EK=2!<(B5S7"(N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z
M>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<R(*;7-G<W1R(").:64@;6^_;F$@;W1W;W)Z>>8@;6]D=;-U($UA:6YT96YA
M;F-E7U1A<VL@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E(&YI92!J
M97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,U.`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS
M9W-T<B`B3FEE('5D8;-O('-IZB!Z;F%L9;SF('!A<VMA($UO>FEL;&DN(%5P
M97=N:6H@<VGJ+""_92!J97-T(&]N(&]T=V%R='DN(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L
M;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*(E6_>71K;W=N:6L@7"(E<UPB('!R87=I9+-O=V\@>F1E9FEN:6]W
M8;,@<')A=V$@9&]S=.IP=2!D;R!F;VQD97)A(%PB)7-<(BXB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,30R,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;G1E9"!T
M97AT(@IM<V=S='(@(E=Y;&]G=6HB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R(")+<F%J(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,`HC+"!F=7IZ>0IM<V=I9"`B
M0V]U<G-E<R(*;7-G<W1R("*L<O-DLV$B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDW
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ,#$*;7-G:60@(D-R
M96%T92(*;7-G<W1R(")3='?S<GHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D-R96%T92!A
M(&QI;FLB"FUS9W-T<B`B4W1W\W)Z(&QI;FLB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(")#<F5A=&4@82!N97<@
M;VYE(@IM<V=S='(@(E-T=_-R>B!N;W>Q(@H*(SH@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.CDR"B,L(&9U>GIY"FUS9VED(")#<F5A=&4@<W5B
M(&9O;&1E<G,B"FUS9W-T<B`B571W\W)Z(&YO=WD@9F]L9&5R(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3,V(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C$T"B,L(&9U>GIY"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R,CD*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R(").
M=6UE<B!K87)T>2!K<F5D>71O=V5J(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B"FUS9W-T
M<B`B0VAO<G=A8VIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.`IM<V=I9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY"FUS9VED(")#=7)R96YT
M(#0@4&AA<V5S(@IM<V=S='(@(D]B96-N>2!C>F%S(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED(")#=7)R
M96YT(%1I;64B"FUS9W-T<B`B3V)E8VYY(&-Z87,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D]B96-N>2!C>F%S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B
M0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D]B96-N>2!C>F%S(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V,PHC+"!F=7IZ>0IM<V=I9"`B
M0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")/8F5C;GD@:V%T86QO9SH@
M)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,R"B,L(&9U>GIY"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D]B
M96-N>2!C>F%S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N(@IM<V=S='(@(E-P97)S;VYA;&EZ=6H@>F%D86YI82!U
M<G5C:&%M:6%N92!P<GIY(&QO9V]W86YI=2!D;R`E<RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G
M:60@(D-U="(*;7-G<W1R(")7>71N:6HB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,U"B,L(&9U>GIY"FUS9VED(")#=70@
M<V5L96-T:6]N(@IM<V=S='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*
M;7-G:60@(D-Y<')U<R(*;7-G<W1R(")#>7!R(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#(*;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E)E
M<'5B;&EK82!#>F5C:"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C,@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$
M(@IM<V=S='(@(D1$(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU
M.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B0V]D>FEE;FYI92(*"B,Z(&%D;6EN
M+V1A=&%T<F5E+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R(")$871A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M.3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@
M(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C$S"B,L(&9U>GIY"FUS9VED(")$871E(%)E8V5I=F5D
M(@IM<V=S='(@(D]T<GIY;6%N92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M.#`V"B,L(&9U>GIY"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")3
M:V%S=6H@=WEB<F%NL2!T;[]S86UOMN8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M,3`*(RP@9G5Z>GD*;7-G:60@(D1A>2(*;7-G<W1R(")#;V1Z:65N;FEE(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,U"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R(")?57-U\2!K
M;VQU;6[J(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,X-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G
M:60@(D1E8V5M8F5R(@IM<V=S='(@(D=R=61Z:67Q(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-@HC+"!F
M=7IZ>0IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(D=R=61Z:67Q
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,`HC+"!F=7IZ>0IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(E)A
M<&]R='5J(&IA:V\@;FEE<WIK;V1L:7=Y(@H*(SH@;&EB+W!R969S+G!H<#HQ
M,3$@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*(RP@9G5Z>GD*;7-G:60@
M(D1E9F%U;'0B"FUS9W-T<B`B1&]M>;9L;GDB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#
M;VQO<B(*;7-G<W1R(")$;VUYMFQN>2!K;VQO<B(*"B,Z(&QI8B](;W)D92])
M9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T
M<B`B1&]M>;9L;F$@=&^_<V%M;[;F(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,3$Y(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DV"FUS9VED(")$969A
M=6QT(%!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*;7-G:60@(D1E9F%U
M;'0@<&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S,*(RP@9G5Z>GD*;7-G:60@
M(D1E9FEN:71I;VYS(@IM<V=S='(@(E!ELVYY(&]P:7,Z(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HW,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M.34@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,34*(SH@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HS,S(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,38@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C<S"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.2!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R
M(")5<W7Q(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S
M+G!H<#HR,3<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")5<W7Q($=R
M=7#J(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,R!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C@W"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G
M<W1R(")5<W7Q('5P<F%W;FEE;FEA(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E(&UE<W-A
M9V5S(@IM<V=S='(@(E5S=?$@:2!W>6-Z>;;F('=I861O;6^V8VDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W
M"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")5<W7Q(&MO;?-R:^HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(E5S=?$@:V]L=6UN
MZB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"B,L(&9U>GIY"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(E1W\VH@861R97,@92UM86EL.B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP
M:'`Z-3`@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`B4VMA<W5J('5P<F%W;FEE;FEA(&1L82!<(B5S7"(B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B!A;F0@86YY('-U8BUP97)M:7-S
M:6]N<S\B"FUS9W-T<B`B4VMA<V]W8>8@=7!R87=N:65N:6$@9&QA(%PB)7-<
M(B!I('=S>GES=&MI92!P;V0M=7!R87=N:65N:6$_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B
M1&5L971E(')O=R(*;7-G<W1R(")5<W7Q('=I97)S>B(*"B,Z('1E;7!L871E
M<R]P<F5F<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>2(*;7-G<W1R(")3:V%S=6H@=WEB<F%NL2!T;[]S
M86UOMN8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C8*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU
M;6XB"FUS9W-T<B`B57-U\2!A:W1U86QNL2!K;VQU;6[J(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS
M9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(E5S=?$@86MT
M=6%L;GD@=VEE<G-Z(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT.`IM
M<V=I9"`B1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M
M:7-S:6]N<S\B"FUS9W-T<B`B4VMA<V]W8>8@=&\@=7!R87=N:65N:64@:2!W
M<WIY<W1K:64@<&]D+75P<F%W;FEE;FEA/R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")$96QE
M=&5D('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B3FEE
M(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,R!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4S"B,L(&9U>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM
M<V=S='(@(E5S=?$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S$@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1A;FEA(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3$P('-E<G9I8V5S+W!R;V)L96TN
M<&AP.C$Q-"!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C0*;7-G:60@(D1E<V-R
M:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D]P:7-Z('!R;V)L96TB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(D1E<V-R
M:7!T:6]N(@IM<V=S='(@(E!ELVYY(&]P:7,Z(@H*(SH@;&EB+TAO<F1E+G!H
M<#HQ.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(E-Z8WIE9_.S>2!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA(&%D
M;6EN:7-T<F%T;W)A+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M.3@*(RP@9G5Z>GD*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(D1Z:6&S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I
M9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"FUS9VED(")$97<@<&]I
M;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B
M1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,C4X"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM
M<V=S='(@(E=YMG=I971L(&-Z87,@=R!F;W)M86-I92`R-"UG;V1Z:6YN>6T_
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDW"FUS9VED(")$:7-P;&%Y
M($]P=&EO;G,B"FUS9W-T<B`B57-T87=I96YI82!W>6=LL61U(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@X"B,L(&9U>GIY"FUS9VED(")$
M:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(E5S=&%W:65N:6$@
M=WEG;+%D=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#4*(RP@9G5Z>GD*
M;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B57-T87=I
M96YI82!W>6=LL61U(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,38*(RP@
M9G5Z>GD*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@(E5S=&%W:65N
M:6$@=WEG;+%D=2(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,3DP"B,L
M(&9U>GIY"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T
M<B`B4F]Z;6EE<WIC>F5N:64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$
MOVEB=71I(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HT-B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,Q-0IM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G
M<W1R(").:64@:V%S=6HB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,C0*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP(@IM<V=S='(@(D)R86L@8F5Z<&^V<F5D;FEE9V\@9&]S=.IP=2!D;R!M
M86EN=&5N86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ.0IM<V=I9"`B1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC
M82(*;7-G<W1R(")$;VUI;FEK82`H5W-P\VQN;W1A($1O;6EN:6MI*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$;VUI;FEK86YA("A2
M97!U8FQI:V$@1&]M:6YI:V'Q<VMA*2(*"B,Z(&QI8B](;W)D92]-24U%+T-O
M;G1E;G1S+G!H<#HX-#$*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(J9C:;%G
M;FEJ(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("*F8VFQ9VYI
M:B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C4*;7-G:60@(D1O
M=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3`X"FUS9VED
M(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(DYA<FMO='EK:2(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@IM<V=I9"`B12U-86EL
M(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO
M3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S`*
M;7-G:60@(D5C=6%D;W(B"FUS9W-T<B`B16MW861O<B(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,CDT('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHW,@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED
M(")%9&ET(@IM<V=S='(@(D5D>6-J82(*"B,Z(&QI8B](;W)D92]";&]C:R]5
M22YP:'`Z-3`@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@HC+"!F=7IZ
M>0IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")%9'ET=6H@8WIA<FZQ(&QI
M<W3J(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#@@861M:6XO9W)O=7!S+G!H
M<#HR,38*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B57-U\2!'<G5PZB(*
M"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-C(@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HX-@IM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(EIM
M:67Q('5P<F%W;FEE;FEE(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("):;6EE\2!U
M<')A=VYI96YI82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:6$@9&QA("5S(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB
M"FUS9W-T<B`B6FUI9?$@=7-T87=I96YI82!D;&$Z(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z,C`T(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@P"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O
M<B!<(B5S7"(B"FUS9W-T<B`B6FUI9?$@=7!R87=N:65N:6$@9&QA("5S(@H*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("):;6EE
M\2!U<')A=VYI96YI82!D;&$@)7,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")/<&-J
M92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(D5G:7!T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%;"!3
M86QV861O<B(*;7-G<W1R(")386QW861O<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE
M;65N="XN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S`@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,C0*;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C0P"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@
M(D%D<F5S(&5M86EL(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C0*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")!9')E
M<WD@96UA:6P@;75S>K$@9&\@<VEE8FEE('!A<V]W8>8N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y.3`*(RP@9G5Z>GD*;7-G:60@(D5M86EL('=I=&@@
M8V]N9FER;6%T:6]N(@IM<V=S='(@(DAA<[-O(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(X,`IM<V=I9"`B16UO=&EC;VYS(@IM
M<V=S='(@(D5M;W1I:V]N>2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")0
M=7-T82!W:6%D;VUOMN8N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z
M,3(X"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(D)R86L@<F5Z=6QT
M873S=RXB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,3,*(RP@
M9G5Z>GD*;7-G:60@(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")/<'+S
MOVYI:B!F;VQD97(@:V]S>F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3,U"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H
M;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$P"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/R(*;7-G<W1R(")7L[%C>GGF(&UE;G4@:V]N=&5K<W1O
M=V4@<&]D('!R87=Y;2!P<GIY8VES:VEE;2!M>7-Z>3\B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C4Y-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q,`HC+"!F
M=7IZ>0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B4F]Z=VGQ('!A<V5K(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(Q,PIM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I
M9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(D=W:6YE82!2\W=N:6MO=V$B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q
M"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R>71R96$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C<@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HW.0IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B0K.Q9"(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`U"B,L(&9U>GIY"FUS9VED(")%<G)O<B!W:71H(&5M86EL
M(&UE<W-A9V4N(@IM<V=S='(@(D)R86L@9F]L9&5R=2!Z(&YO=WEM:2!W:6%D
M;VUOMF-I86UI(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!R>GD@>F%P:7-I92!<
M(B5S7"(N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R(")%<W1O;FEA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I
M9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B171H;FEC(@IM<V=S='(@
M(D5S=&]N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I
M9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS,S$*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B
M0V\@:V&_9&4@,34@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@Q"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B0V\@:V&_9&4@
M,B!M:6YU='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(X(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B0V\@:V&_9&4@,S`@<V5K=6YD(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S,"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@R"FUS9VED
M(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T<B`B0V\@:V&_9&4@-2!M:6YU="(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y
M($QO9VEN(@IM<V=S='(@(D-O(&MAOV1E('IA;&]G;W=A;FEE(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S,@IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(D-O(&MAOV1E('#SLR!G;V1Z:6YY(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,R.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B0V\@:V&_9+$@;6EN=73J(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@(D5X86UP
M;&4@=F%L=65S.B(*;7-G<W1R(")0<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC
M.B!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R
M."!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$*;7-G:60@(D5X96-U=&4B"FUS9W-T
M<B`B5WEK;VYA:B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,Y
M-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(E)O>G=I\2(*"B,Z('1E;7!L871E
M<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3:61E8F%R
M(@IM<V=S='(@(E)O>G=I\2!P87-E:R(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$V.`HC+"!F=7IZ>0IM<V=I9"`B17AP96-T960@)RDG(@IM
M<V=S='(@(E=Y:V]N86HB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H
M<#HQ-S4*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A
M<F-H('1E<FTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#`Q"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-S8*(RP@9G5Z>GD*;7-G:60@
M(D5X<&]N96YT(@IM<V=S='(@(D5K<W!O<G0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"B,L(&9U>GIY"FUS
M9VED(")&1R!#;VQO<B(*;7-G<W1R(")$;VUYMFQN>2!K;VQO<B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*(RP@9G5Z>GD*;7-G:60@(D944"!U
M<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B5V=R>7=A;FEE('!L:6OS=R!N:64@
M:F5S="!O8G.S=6=I=V%N92XB"@HC.B!L:6(O2&]R9&4O4')E9G,O<W%L+G!H
M<#HR,38*(RP@9G5Z>GD*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@>FUI86YY('5S=&%W:67Q
M+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$P,`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D*SL60@
M<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.3@*(RP@9G5Z>GD*;7-G:60@(D9A:6QE
M9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM<V=S='(@(D*SL60@<&]D
M8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,1$%0+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HV,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!K;W!I
M;W=A;FEA('H@7"(E<UPB+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,#@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@:V]P:6]W86YI82!D;R!<(B5S7"(N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*(RP@9G5Z>GD*;7-G:60@
M(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M($Q$05`@
M)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8T,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D*SL60@
M<&]D8WIA<R!P<GIE;F]S>F5N:6$@9&\@7"(E<UPB+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"B,L(&9U>GIY"FUS9VED
M(")&86ER(@IM<V=S='(@(D]D(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H
M36%L=FEN87,I(@IM<V=S='(@(D9A;&ML86YD>2`H36%L=VEN>2DB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&87)O92!)<VQA;F1S(@IM<V=S='(@(E=Y<W!Y($]W8WIE(@H*(SH@;&EB
M+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T
M<B`B0K.Q9"!K<GET>6-Z;GDZ("(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B1F%K<R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S4@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED(")&96)R=6%R
M>2(*;7-G<W1R("),=71Y(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C`*
M;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Y"B,L(&9U>GIY"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R("));7!O
M<G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`HC+"!F=7IZ>0IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("))
M;7!O<G0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-0IM<V=I9"`B1FEE
M;&0@;6%T<FEX(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#$*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FED
MOVDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,"!L:6(O
M2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE
M($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R87(N<&AP.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#8*;7-G:60@
M(D9I;&4@36%N86=E<B(*;7-G<W1R(")-96YE9+]E<B!P;&EK\W<B"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-
M12]6:65W97(O>FEP+G!H<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(DYA>G=A('!L
M:6MU(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.30*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(E=Y8O-R('!L:6MU(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T.#@*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E=G
M<GEW86YI92!P;&EK=2(*"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX-C,*
M;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R(")7
M9W)Y=V%N:64@<&QI:_-W(&YI92!J97-T(&]B<[-U9VEW86YE+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G
M<W1R(")&:6QT<GDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;FQA;F1I
M82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@
M(D9I<G-T($AA;&8B"FUS9W-T<B`B26UIZB(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@
M(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B26UIZB(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,SD*;7-G:60@(D9I>"!R871I;R(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3`W(&QI8B]61E,O<W%L+G!H<#HQ-C`*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*
M;7-G<W1R(")5OWEC:64@9F]L9&5R=2!N:64@:F5S="!A:W1Y;G=E+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*(RP@
M9G5Z>GD*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B1&]M>;9L;GD@:V]L
M;W(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B
M"FUS9W-T<B`B2F5D>F5N:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*(RP@9G5Z>GD*;7-G:60@
M(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S
M='(@(E=Y;6%G86YA(&IE<W0@;V)SLW5G82!I1G)A;65S*'"S>7=A:K%C>6-H
M(')A;65K*2!P<GIE>B!P<GIE9VRQ9&%R:^HB"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,S-`HC+"!F=7IZ>0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS
M9W-T<B`B57-T87=I96YI82!W>6=LL61U(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C<Q"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E
M('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@
M86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.3@*;7-G:60@(D9O<F=O="!Y;W5R('!A<W-W;W)D
M/R(*;7-G<W1R("):87!O;6YI8;-EMB!H87.S83\B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#`Y"B,L(&9U>GIY"FUS9VED(")&;W)M<R(*;7-G
M<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HY.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N92!T
M>7!E(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,X"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")5=V%G:2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B
M1F]R='5N97,@,B(*;7-G<W1R(")5=V%G:2(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT,#`*(RP@9G5Z>GD*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M(")5=V%G:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*(RP@
M9G5Z>GD*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E!R>F5K8;\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"B,L(&9U
M>GIY"FUS9VED(")&<B(*;7-G<W1R(")/9"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G
M:60@(D9R86UE<R(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D9R86YC92(*;7-G<W1R(")&<F%N8VIA(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1W5J86YA($9R
M86YC=7-K82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O
M;&EN97IJ82!&<F%N8W5S:V$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<R(*;7-G<W1R(")&<F%N8W5S:VEE(%1E<GET;W)I82!0;[-U
M9&YI;W=E(&D@06YT87)K='EC>FYE(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B3V0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,V(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-#@*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y-`HC+"!F=7IZ>0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(D]D(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*(RP@
M9G5Z>GD*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4&6S;GD@
M;W!I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,3@Q"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS.0HC+"!F=7IZ>0IM<V=I
M9"`B1G5L;"!.86UE(@IM<V=S='(@(E1W;VIE(&EM:>HB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O
M;B(*;7-G<W1R(")'86)O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T
M;R!T86ME(&EM86=E(&9R;VTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS9VED
M(")'86QL97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B
M1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO
M;B(*;7-G<W1R(")(;W)D92!N:64@:F5S="!W('!ELVYI('-K;VYF:6=U<F]W
M86YE+B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HQ
M,`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O
M<F=I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(DYI96UC
M>2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L
M=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<U"B,L(&9U>GIY"FUS9VED(")':79E;B!.86UE(@IM<V=S
M='(@(DUE;F5DOV5R('!L:6OS=R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("))9+PB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#`*;7-G:60@(D=O961E;"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H
M(@IM<V=S='(@(E=Y<WIU:VEW87)K82!';V]G;&4B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(P"FUS9VED(")'<F%Y<V-A;&4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'<F5C:F$B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0HC+"!F=7IZ>0IM<V=I9"`B1W)E
M96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H
M25-/+3@X-3DM,BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T<B`B1W)E;FQA
M;F1I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D
M;6EN+V=R;W5P<RYP:'`Z,3<P"B,L(&9U>GIY"FUS9VED(")'<F]U<"!!9&UI
M;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A8VIA(@H*(SH@;&EB+TAO
M<F1E+T=R;W5P+G!H<#HU.`IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N
M;VXM96UP='DB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,C`Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,C<W"B,L(&9U>GIY"FUS9VED
M(")'<F]U<"!P97)M:7-S:6]N<R(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI
M96YI82(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W-B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U,`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM
M<V=S='(@(D=R=7!Y(&1Y<VMU<WEJ;F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D96QO=7!E(@IM
M<V=S='(@(D=W861E;'5P82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@(D=U86TB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(D=W871E;6%L82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T
M<B`B1W5E<FYS97DB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C<@;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#4*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHX.`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI;B]P97)M
M<R]E9&ET+G!H<#HQ,C@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#8*(RP@
M9G5Z>GD*;7-G:60@(D=U97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(D1O;7FV
M;&YE('5P<F%W;FEE;FEA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0Q-PIM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE
M82(*;7-G<W1R(")'=VEN96$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B1W=I;F5A($)I<W-A=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@
M(D=U:F%N82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C`*;7-G:60@(DA4
M34PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"B,L(&9U>GIY"FUS9VED
M(")(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B57=I
M97)Z>71E;&YI96YI92!N:64@<&]W:6]DLV\@<VGJ(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET
M:2(*;7-G<W1R(")(86ET:2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,@HC+"!F=7IZ>0IM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B
M06QG;W)Y=&T@<&]D<&ES=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HY,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,S$*
M(RP@9G5Z>GD*;7-G:60@(DAE861E<B(*;7-G<W1R(").86>S\W=K:2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@IM<V=S
M='(@(E=Y<W!Y($AE87)D(&D@36-$;VYA;&1A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE
M879Y(%0M4W1O<FTB"FUS9W-T<B`B57=A9VDB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@HC+"!F=7IZ>0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX
M+4DI(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,BDB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,T"B,L(&9U>GIY"FUS9VED(")(96EG:'0B"FUS9W-T<B`B5WES;VMI
M(@H*(SH@;&EB+TAO<F1E+TAE;'`N<&AP.C$W.2!L:6(O2&]R9&4O2&5L<"YP
M:'`Z,3@V('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E
M<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(E!O;6]C
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,0IM<V=I9"`B2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S-S,*(RP@9G5Z>GD*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R(")0;VUO8R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0HC+"!F
M=7IZ>0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")0;VUO8R(*"B,Z('1E
M;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$W('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C$W"FUS9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(E=Y<V]K
M:2(*"B,Z(&QI8B](;W)D92](:7-T;W)Y+G!H<#HS,C$*;7-G:60@(DAI<W1O
M<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI
M;B]C;VUM;VXM:&5A9&5R+FEN8SHT"FUS9VED(")(;U]M92(*;7-G<W1R(")?
M4W1A<G0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*2(*;7-G<W1R(")7871Y:V%N("A3=&]L:6-A($%P;W-T;VQS:V$I(@H*(SH@
M;&EB+TAO<F1E+G!H<#HQ-#,U"FUS9VED(")(;VUE(@IM<V=S='(@(E!O8WJQ
M=&5K(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-34*;7-G:60@(DAO
M;64@061D<F5S<R(*;7-G<W1R(")!9')E<R!D;VUO=WDB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N
M92(*;7-G<W1R(")496PN(&1O;2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S
M='(@(DAO;F1U<F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N
M9TMO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G:60@
M(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HT,C`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B
M.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@
M)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU
M+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,C<W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P
M;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQYB!<
M(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#$S
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!O8FIE8W0@
M;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!59&&S;R!S:>H@=7-U;K'F("5S(%PB
M)7-<(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$U-`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!S
M>6YC:')O;FES960@)7,@7"(E<UPB(@IM<V=S='(@(E5D8;-O('-IZB!U<W5N
ML>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT.#$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E
M(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S(@IM<V=S='(@(E5D8;-O('-I
MZB!U<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C$R,#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T
M<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@
M9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B561ALV\@<VGJ('5S
M=6ZQYB!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3$U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S
M='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E<UPB('H@<WES=&5M=2XB"@HC.B!L
M:6(O2&]R9&4O2V]L86(N<&AP.C$R.#(*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y
M<W1E;74N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HS,3@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E
M(%PB)7-<(B(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y
M<W1E;74N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G
M:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I
M>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(DAO=R!D:60@>6]U
M(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*
M;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C(X"FUS9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X."!L:6(O0FQO8VLO;65T87(N<&AP.C(S
M,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R
M:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B5^IG
M<GDB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<R(&QI8B](;W)D
M92]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M(")0;[.Q8WIE;FEE(&YI92!P;W=I;V2S;R!S:>HZ("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C(Q-"!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C(Y-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL
M8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4&^SL6-Z96YI92!N
M:64@<&]W:6]DLV\@<VGJ.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ-SD@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR-#(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E5W:65R>GET96QN:65N:64@;FEE
M('!O=VEO9+-O('-IZBX@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q
M-PHC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R(")!9')E<R(*
M"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C<W"B,L(&9U>GIY"FUS
M9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@
M7")-971A<EPB(&YI92!J97-T(&1O<W3J<&YY+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VEP8F%S:6,N<&AP.C@Y"B,L(&9U>GIY"FUS9VED("))4"!!9&1R97-S
M(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+B(*;7-G<W1R(")";&]K
M(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N>2XB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*(RP@9G5Z>GD*;7-G:60@
M(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C>B!T
M=71A:B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA;F1I82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C@*;7-G:60@(DEC;VYS($]N;'DB
M"FUS9W-T<B`B5'EL:V\@:6MO;GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S8Y"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B26MO;GD@
M>B!T96MS=&5M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(").87IW82!T;[]S86UOMF-I
M.B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0W"FUS9VED("(B"B))9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@
M;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HQ-3@*;7-G:60@(B(*(DEF('EO
M=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO
M=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U
M<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G
M:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!O9&=LL60@<&]C>G1Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHS-PHC+"!F=7IZ>0IM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D=R869I
M:V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C$*(RP@9G5Z>GD*;7-G:60@(DEM86=E(%523#HB"FUS
M9W-T<B`B1W)A9FEK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G
M86QL97)Y(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O
M;2!G86QL97)Y.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3<V,@HC+"!F=7IZ>0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(E=G
M<GEW86YI92!P;&EK=2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS
M9VED("));6%G97,B"FUS9W-T<B`B1W)A9FEK82(*"B,Z('1E;7!L871E<R]D
M871A+W1S=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C$P"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1O=V%N92!P;VQE
M.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(P"B,L('!H
M<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("))
M;7!O<G1O=V%N92!P;VQE.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-S,*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP
M;W)T;W=A;F4@<&]L83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*(RP@9G5Z>GD*;7-G:60@(DEN7W-E
M<G0@4F]W($%F=&5R(@IM<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*
M(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,U"FUS9VED("));F-O
M<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*(RP@9G5Z>GD*;7-G:60@
M(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@
M(E!R;W-ZZB!P;V1AYB!N87IWZB!UOWET:V]W;FEK82!I(&AA<[-O(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R
M<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN
M(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES=')A=&]R(&EF('EO=2!N965D
M(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0HC+"!F=7IZ>0IM<V=I9"`B26YC
M<F5A<V4@26YD96YT(@IM<V=S='(@(E)A<&]R='5J(&IA:V\@;FEE<WIK;V1L
M:7=Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1I92(*"B,Z(&%D;6EN
M+W!E<FUS+V5D:70N<&AP.C$T,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G
M:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5Z:F$B"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B26YF;R(*;7-G
M<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T-@HC
M+"!F=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B5'=O:F4@:6YF
M;W)M86-J92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,3@*
M(RP@9G5Z>GD*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N(@IM<V=S='(@(DEN9F]R;6%C:F4@;R!O<V]B:7-T>6T@:VQU8WIU('!U
M8FQI8WIN>6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!#7V]L
M=6UN($%F=&5R(@IM<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B5VML96H@;V)R
M87IE:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,#`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R(")0
M<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(U"B,L(&9U>GIY"FUS9VED("));G-E<G0@
M5V5B($QI;FLB"FUS9W-T<B`B6FUI9?$@;&EN:RXN+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PHC+"!F
M=7IZ>0IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(E=P
M<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"B,L(&9U>GIY"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G
M<W1R(")5<W7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8T"B,L(&9U>GIY"FUS9VED("));G-E<G0@82!N
M97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B57-U
M\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHV,0HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B57-U\2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE(@IM<V=S='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*(RP@9G5Z>GD*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(E5S=?$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R
M(")5<W7Q(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*(RP@9G5Z>GD*
M;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B5'?S
M:B!A9')E<R!E+6UA:6PZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,0IM<V=I9"`B26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!C96QL(&%F=&5R(@IM<V=S='(@
M(D)R86L@<F5Z=6QT873S=RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED("));G-E
M<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8T"B,L(&9U>GIY"FUS9VED("));G-E<G0@8V]L=6UN(&%F=&5R(@IM
M<V=S='(@(D)R86L@<F5Z=6QT873S=RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"B,L(&9U>GIY"FUS9VED
M("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")7<')O=V%DO"!K;'5C
M>B!T=71A:B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,`HC+"!F=7IZ>0IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(D)R
M86L@<F5Z=6QT873S=RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T
M86HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#,*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(@IM<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R(")7<')O
M=V%DO"!K;'5C>B!T=71A:B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DEN<V5R
M="!R;W<@8F5F;W)E(@IM<V=S='(@(E=P<F]W862\(&ML=6-Z('1U=&%J(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,@IM<V=I9"`B26YS97)T('1H
M92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(V"B,L(&9U>GIY"FUS9VED("));G-E<G0O36]D:69Y($EM86=E
M(@IM<V=S='(@(EIM:67Q(&QI;FLN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"B,L(&9U>GIY"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B6FUI9?$@;&EN:RXN+B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*(RP@9G5Z>GD*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYI92!M;[]N82!O='=O<GIYYB!M;V1U
MLW4@36%I;G1E;F%N8V5?5&%S:R`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#<U"B,L(&9U
M>GIY"FUS9VED("));G1E9V5R(@IM<V=S='(@(D]D=W+SYB(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3,S"B,L(&9U>GIY"FUS9VED("));G1E9V5R(&QI
M<W0B"FUS9W-T<B`B3V1W<O/F(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$871A
M($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z
M:7`N<&AP.C$W,"!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@
M;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(D%D<F5S(&1O;6]W>2(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE
M;FEA(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*
M(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@8F%T8V@@240N(@IM<V=S='(@(DYI
M97!O<')A=VYY($E$(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P.#@@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q-3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S,*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R.3@*;7-G:60@(DEN=F%L:60@9&%T
M82!S=6)M:71T960N(@IM<V=S='(@(E=Y<[-A;F4@;FEE<')A=VEDLV]W92!D
M86YE+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(DYI97!R87=I9+-O=WD@861R97,@9&]C96QO=WDN(@H*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+V1B>"YP:'`Z.#$@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I
M9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(").:65P<F%W:62S;W=Y
M(&9O<FUA="!P;&EK=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C0*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(DYI
M97!R87=I9+-O=WD@:VQU8WH@;&EC96YC:FDN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$U.`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!L
M;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3FEE>FYA;GD@861R97-A="(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R(").:65P;W!R
M87=N82!N87IW82(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+B(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U>GIY"FUS9VED
M("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B1&]M
M>;9L;F4@=7!R87=N:65N:6$B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z-#,*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<&%R96YT('!E<FUI<W-I
M;VXN(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,`HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!P87)T;F5R(&ED+B(*;7-G<W1R(")$;VUYMFQN92!U<')A=VYI96YI
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C(*(RP@9G5Z
M>GD*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")!9')E
M<R!D;VUO=WDB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P-@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T
M<B`B3FEE<&]P<F%W;GD@;V)J96-T260B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B3FEE<&]P<F%W
M;GD@=W!I<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3`T,R!L:6(O2&]R
M9&4O2V]L86(N<&AP.C$R,C`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<VAA
M<F4@;V)J96-T(@IM<V=S='(@(DYI97!O<')A=VYY(&]B:F5C=$ED(@H*(SH@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*(RP@9G5Z>GD*
M;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D%D<F5S
M(&1O;6]W>2(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS
M9W-T<B`B061R97,@9&]M;W=Y(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,R-0HC+"!F=7IZ>0IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(DYI
M97!O<')A=VYY('=P:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B27)A;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))
M<F%K(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9&EA(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C0*(RP@9G5Z>GD*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM
M<V=S='(@(E5W86=I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@P"FUS9VED("))<W)A96PB"FUS9W-T<B`B27IR865L
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,C4*;7-G:60@(DES
M<W5E<B(*;7-G<W1R(")7>61A=V-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY"B,L(&9U>GIY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`B5[-O8VAY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L>2(*;7-G<W1R(")7LV]C
M:'DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86IK82(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S0@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM
M<V=S='(@(E-T>6-Z9?$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N
M:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I9"`B2F%P86YE
M<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3(R"B,L(&9U>GIY"FUS9VED(")*97)S97DB"FUS9W-T<B`B
M1W5E<FYS97DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#,*;7-G:60@(DIO<F1A;B(*;7-G<W1R(")*;W)D86XB"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@P(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*
M;7-G<W1R("),:7!I96,B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<Y(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,38*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R(")#>F5R=VEE8R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G
M:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@
M0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2:6=H="(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B2V%Z86-H<W1A;B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#8*;7-G:60@(DME
M97`@;W)I9VEN86P_(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2V5N>6$B"FUS9W-T
M<B`B2V5N:6$B"@HC.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I
M9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@
M(DME<FYE;"!.97=B:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(E1W
M;W)Z96YI92!K;'5C>F$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,#,*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R(")/9&-I<VL@:VQU
M8WIA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Q"FUS9VED(")+
M97D@3&5N9W1H(@IM<V=S='(@(D2S=6=OMN8@:VQU8WIA(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#`P"FUS9VED(")+97D@5'EP92(*;7-G<W1R
M(")4>7`@:VQU8WIA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.3@*(RP@9G5Z>GD*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(")7:6%D;VUO
MMN8B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW,CD*;7-G:60@(DME
M>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS
M9W-T<B`B2VQU8WH@:G6_(&ES=&YI96IE(&YA('!U8FQI8WIN>6T@<V5R=V5R
M>F4@:VQU8WIY+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I
M9"`B2VED<R(*;7-G<W1R(")$>FEE8VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3(Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM
M<V=S='(@(DMI<FEB871I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")+;W)E8?%S:V$@4F5P=6)L
M:6MA($QU9&]W;RU$96UO:W)A='EC>FYA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P
M=6)L:6,@;V8B"FUS9W-T<B`B4F5P=6)L:6MA($MO<F5I(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=E:G0B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B2VER9VES=&%N(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y;W5T(@IM<V=S='(@
M(E=Y9VRQ9"`H7WDI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW
M.0IM<V=I9"`B3&%N9W5A9V4B"FUS9W-T<B`B2NIZ>6LB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"B,L(&9U>GIY"FUS9VED("),
M87-T($AA;&8B"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z.#@@;&EB+T)L;V-K+VUO;VXN<&AP.CDP"B,L(&9U>GIY"FUS9VED
M("),87-T(%%U87)T97(B"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$U,0HC+"!F=7IZ>0IM<V=I9"`B3&%S="!5<&1A=&5D
M.B(*;7-G<W1R(").87IW:7-K;R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV
M.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T
M<B`B3W-T871N:64@;&]G;W=A;FEE.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H
M+G!H<#HV.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@
M9G)O;2`E<R(*;7-G<W1R(")/<W1A=&YI92!L;V=O=V%N:64Z("5S('H@)7,B
M"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z-C@S"FUS9VED("),87-T(&QO9VEN
M.B!.979E<B(*;7-G<W1R(")/<W1A=&YI92!L;V=O=V%N:64Z(&YI9V1Y(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y
M"FUS9VED("),871V:6$B"FUS9W-T<B`BHV]T=V$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#0*(RP@9G5Z>GD*;7-G:60@(DQA=R(*;7-G<W1R(").
M:7-K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHW.0HC+"!F=7IZ>0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E=Y
M;&]G=6HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*(RP@9G5Z
M>GD*;7-G:60@(DQE9G0B"FUS9W-T<B`B4')Z97-U\2!W(&QE=V\B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$Q.`HC+"!F=7IZ>0IM<V=I9"`B3&5F="!H
M96%D97(B"FUS9W-T<B`B4')Z>6NS861O=V4@=V%R=&^V8VDZ(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C,Q,30*(RP@9G5Z>GD*;7-G:60@(DQE9G0@=F%L
M=65S(@IM<V=S='(@(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("),97-O=&AO(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM
M<V=S='(@(DQI8F5R:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I
M>6$B"FUS9W-T<B`B3&EB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(U"B,L(&9U>GIY"FUS9VED("),:6=H="!$<FEZ
M>FQE(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I
M;B(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%)A:6X@
M16%R;'DB"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C(X"B,L(&9U>GIY"FUS9VED("),:6=H="!2
M86EN($QA=&4B"FUS9W-T<B`B6F%L;V=U:B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Y"B,L(&9U>GIY"FUS9VED("),:6=H
M="!286EN(%-H;W=E<B(*;7-G<W1R("):86QO9W5J(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*(RP@9G5Z>GD*;7-G:60@
M(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S='(@(EIA;&]G=6HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0HC+"!F
M=7IZ>0IM<V=I9"`B3&EG:'0@4VYO=R(*;7-G<W1R("):86QO9W5J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S(*(RP@9G5Z
M>GD*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM<V=S='(@(EIA;&]G=6HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*(RP@9G5Z>GD*;7-G:60@
M(DQI;65R:6-K(@IM<V=S='(@(DQI8F5R:6$B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@Q-0HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("):861A
M;FEA('!R>GD@;&]G;W=A;FEU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED("),:6YK('!O:6YT
M<R!T;SHB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S8*
M;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@
M<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"B,L(&9U>GIY"FUS9VED
M("),:6YK<R(*;7-G<W1R("):861A;FEA('!R>GD@;&]G;W=A;FEU(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"B,L(&9U>GIY"FUS9VED("),:6YU
M>"!#;V]K:64B"FUS9W-T<B`B5'?S<GHB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"B,L(&9U>GIY"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R(")0
M<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R(")7>;9W
M:65T;"!T96UA='D@<&]M;V-Y(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B4')Z>6NS
M861O=V4@=V%R=&^V8VDZ(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP
M:'`Z-3DT"B,L(&9U>GIY"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B
M56MR>6H@;FEE<W5B<VMR>6)O=V%N92(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C4X.0HC+"!F=7IZ>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S
M='(@(E=YMG=I971L('1E;6%T>2!P;VUO8WDB"@HC.B!L:6(O2&]R9&4O34E-
M12](96%D97)S+G!H<#HU.38*(RP@9G5Z>GD*;7-G:60@(DQI<W0M260B"FUS
M9W-T<B`B5WFV=VEE=&P@=&5M871Y('!O;6]C>2(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C4Y,@HC+"!F=7IZ>0IM<V=I9"`B3&ES="U/=VYE
M<B(*;7-G<W1R(")7>;9W:65T;"!T96UA='D@<&]M;V-Y(@H*(SH@;&EB+TAO
M<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"B,L(&9U>GIY"FUS9VED("),:7-T
M+5!O<W0B"FUS9W-T<B`B5WFV=VEE=&P@=&5M871Y('!O;6]C>2(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,0HC+"!F=7IZ>0IM<V=I9"`B
M3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B56MR>6H@;FEE<W5B<VMR>6)O=V%N
M92(*"B,Z(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`HC+"!F=7IZ
M>0IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R(")5:W)Y:B!N:65S
M=6)S:W)Y8F]W86YE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T
M+FEN8SHT"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G
M<W1R("),:7-T;W=A;FEE('6_>71K;W=N:6OS=R!J97-T('=YL[%C>F]N92XB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@
M(DQI=&5R871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N
M:6$B"FUS9W-T<B`B3&ET=V$B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6UA9V5S+G!H<#HY,@IM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("*C861O
M=V%N:64N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DY
M"FUS9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B0WIA<R!L;VMA;&YY.B`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A
M;F0@5&EM92(*;7-G<W1R(")5<W1A=VEE;FEA(&QO:V%L;F4@:2!C>F%S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4V(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C8U(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q"B,L(&9U>GIY"FUS9VED("),;V-A
M=&EO;B(*;7-G<W1R(")/<&-J92(*"B,Z(&QO9VEN+G!H<#HQ-C(@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$V-"!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.#8*;7-G:60@(DQO9R!I;B(*;7-G
M<W1R("):86QO9W5J(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$U.`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS
M9W-T<B`B6F%D86YI82!P<GIY(&QO9V]W86YI=2(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY,S$*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M(@IM<V=S='(@(B(*(DQO9V]W86YI92!N:64@<&]W:6]DLV\@<VGJ+"!P;VYI
M97=AOR!P;V1ALV6V(&YI97!R87=I9+-O=V4@:&%SLV\@;'5B(&YA>G?J("(*
M(G6_>71K;W=N:6MA+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,C<*;7-G
M:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B3&]G;W=A;FEE(&YI92!P;W=I
M;V2S;R!S:>HN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-C<*(RP@9G5Z
M>GD*;7-G:60@(DQO;F<@=&5X="(*;7-G<W1R(")7>6QO9W5J(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0X"B,L(&9U>GIY"FUS9VED("),;W9E(@IM
M<V=S='(@(B(*(B,M(RTC+2,M(R`@<&Q?4$PN<&\@*$EN9V\@:#,M,2XP+C$I
M("`C+2,M(RTC+2-<;B(*(E!R>F5S=?%<;B(*(B,M(RTC+2,M(R`@<&Q?4$PN
M<&\@*$EM<"!H,RTT+C`N,RD@(",M(RTC+2,M(UQN(@HB4')Z96YI9;9<;B(*
M(B,M(RTC+2,M(R`@<&Q?4$PN<&\@*%1U<F)A(&@S+3(N,"XS*2`@(RTC+2,M
M(RTC7&XB"B)0<GIE;FEEMB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8W"FUS9VED("),;W<B"FUS9W-T<B`B3FES:VDB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R(")'<G5D>FEE\2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G
M<W1R("),=6MS96UB=7)G(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$P"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E
M<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G
M<W1R(")-32(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3,*;7-G
M:60@(DU/5$0B"FUS9W-T<B`B34]41"(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*
M;7-G<W1R(")-4T<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O(@IM<V=S='(@(DUA:V%U(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ
M"FUS9VED(")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L
M:6,@;V8B"FUS9W-T<B`B36%C961O;FEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R
M(@IM<V=S='(@(DUA9&%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(E!O8WIT82(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*
M;7-G<W1R(")0;V-Z=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#<W"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`IM<V=I
M9"`B36%K92!L:6Y?:RXN+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*
M;7-G<W1R(")-86QA=VDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38W
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM<V=S='(@(DUA
M;&5Z:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(DUA;&5D:7=Y(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR
M"FUS9VED(")-86QI(@IM<V=S='(@(DUA;&DB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,38R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM
M<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS
M9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V
M92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T
M960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B):87)ZL61Z
M86H@;&ES=+$@:V%T96=O<FEI+"!K=/-R>6UI(&+J9'II97-Z(&]Z;F%C>F&S
M('!O>GEC:F4L(&D@:V]L;W)A;6D@>B`B"B)N:6UI('IW:;%Z86YY;6DN(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G
M:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3<W"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#4T"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W
M-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@
M(DUA<F-H(@IM<V=S='(@(DUA<GIE8R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*
M;7-G<W1R(")-87)G:6YE<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX.`IM<V=I9"`B36%R:R!W:71H(%-E96XO56YS965N(&9L86=S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.0IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-87)S:&%L;"!)
M<VQA;F1S(@IM<V=S='(@(E=Y<W!Y($UA<G-H86QL82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R
M=&EN:7%U92(*;7-G<W1R(")-87)T>6YI:V$B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$Q,0IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(E!A<W5JL6-E('!O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T
M<B`B36%U<F5T86YI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA
M=7)I=&EU<R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"B,L(&9U>GIY
M"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B
M5VEA9&]M;[;F(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@
M(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO
M=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S
M.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W."!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-
M86HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA:F]T=&$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC
M:6YE(@IM<V=S='(@(D]D<GIU8V]N92(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,3D*(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS
M9W-T<B`B1W)U9'II9?$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P
M"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(E1R>6(@;65N=3HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8P
M"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R(")0;[.Q8WH@:V]M\W)K:2(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HS,`IM<V=I9"`B365S<V%G92(*;7-G<W1R(")7:6%D;VUOMN8B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G
M92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T
M:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,L(&9U
M>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@(E=I861O;6^V
MYB(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(V,`HC+"!F=7IZ>0IM<V=I9"`B365S<V%G92!T>7!E
M(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,PHC+"!F=7IZ>0IM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")/8F5C
M;GD@8WIA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@7")-971A
M<EPB(&YI92!J97-T(&1O<W3J<&YY+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$R"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B)";&]K(%PB365T87)<(B!N:64@:F5S="!D;W-TZG!N
M>2X@4WIC>F5G\[-Y('ID87)Z96YI82!Z;W-T8;-Y('IA;&]G;W=A;F4@9&QA
M("(*(F%D;6EN:7-T<F%T;W)A+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-3(*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*(RP@9G5Z>GD*
M;7-G:60@(DUE=&AO9"(*;7-G<W1R("),97-O=&AO(@H*(SH@;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]24$,O<V]A<"YP:'`Z,3$W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB(&ES
M(&YO="!D969I;F5D(@IM<V=S='(@(E6_>6-I92!F;VQD97)U(&YI92!J97-T
M(&%K='EN=V4N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8V
M(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(DUE=')I
M8R(*;7-G<W1R(")-96MS>6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-
M96MS>6LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O
M9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S8*(RP@9G5Z>GD*;7-G:60@(DUI9&1L92(*;7-G
M<W1R(")3=&%N;W=I<VMO(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N
M968N<&AP.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B5'EP($UI;64B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q,`IM<V=I9"`B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`R"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C$W"B,L(&9U>GIY"FUS9VED(")-:7)R;W(B"FUS9W-T<B`B0K.Q9"(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I9"`B36ES8V5L;&%N96]U
M<R(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C<R(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P"FUS
M9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,30*;7-G:60@(B(*
M(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@
M:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-`HC+"!F=7IZ>0IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*
M;7-G<W1R(")7:6%D;VUOMN8@9&\B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%
M05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-`HC+"!F=7IZ>0IM<V=I9"`B36ES<VEN
M9R!S97-S:6]N($E$+B(*;7-G<W1R(").:64@>F1E9FEN:6]W86YO('1E:W-T
M=2!W(&YO8VEE('=A:V%C>6IN96HN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C<T"B,L(&9U>GIY"FUS9VED
M(")-;V)I;&4@36%I;"(*;7-G<W1R(").;W=A('!O8WIT82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"B,L(&9U>GIY"FUS
M9VED(")-;V1E<F%T92(*;7-G<W1R(")/<W1A=&YI82!M;V1Y9FEK86-J82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8V(&QI8B](;W)D
M92]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@
M(D]S=&%T;FEA(&UO9'EF:6MA8VIA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")-;V1I9GD@
M55),(@IM<V=S='(@(EIM:67Q(&QI;FLB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-;[-D87=I
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]L9&]V82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4F5P
M=6)L:6MA($UOLV1A=VEI(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B36]N
M86MO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R(")-;VYG;VQI82(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-3DS"B,L(&9U>GIY"FUS9VED(")-;VYT
M:"!A;F0@>65A<B(*;7-G<W1R(")2;WIW:?$@<&%S96LB"@HC.B!L:6(O2&]R
M9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@
M(D-O(&UI97-IL6,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N
M='-E<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B1F%Z>2!K
M<VGJOWEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:V\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I
M9"`B36]S=&QY($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")-;W-T
M;'D@0VQO=61Y(@IM<V=S='(@(DMR86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R.`IM
M<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(E!R>F5S=?$@=R!D\[,B"@HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,S(*;7-G:60@(DUO=F4@3&5F
M="(*;7-G<W1R(")0<GIE<W7Q('<@;&5W;R(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C0S-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")0
M<GIE<W7Q('<@<')A=V\B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HT,C0*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4')Z97-U\2!W(&?S<NHB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DV"FUS
M9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B4')Z96YI9;8@=R!D\[,B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DU(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT.38*;7-G:60@(DUO=F4@=7`B
M"FUS9W-T<B`B4')Z97-U\2!W(&?S<NHB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B
M"FUS9W-T<B`B36]Z86UB:6LB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X
M-0IM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C0S"B,L(&9U>GIY"FUS9VED
M(")-=6QT:7!L92!S96QE8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@
M=&^_<V%M;[;F(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S,2!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,X"FUS9VED(")->2!!8V-O=6YT
M(@IM<V=S='(@(DMO;G1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H
M<#HU,0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DWS:B!P;W)T86PB"@HC
M.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3(T"B,L(&9U>GIY"FUS9VED
M(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(E!O<G1U9V%L:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G
M:60@(DUY86YM87(B"FUS9W-T<B`B0FER;6$B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O86=R965M96YT7V)O='1O;2YI;F,Z-PIM<V=I9"`B3D\L($D@
M1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`R(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F
M+G!H<#HS.`HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@
M(DYA;64B"FUS9W-T<B`B3F%Z=VES:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS
M9W-T<B`B3F%M:6)I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<W(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H
M97)L86YD<R(*;7-G<W1R(")(;VQA;F1I82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD
M<R!!;G1I;&QE<R(*;7-G<W1R(")!;G1Y;&4@2&]L96YD97)S:VEE(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@(DYE='-C87!E
M($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-0IM
M<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I9"`B3F5T<V-A<&4@
M4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#(*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS
M9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*(RP@9G5Z>GD*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B0G)A:R!O
M<V]B:7-T96=O(&-E<G1Y9FEK871U(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.#`*(RP@9G5Z>GD*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC
M871E('1Y<&4B"FUS9W-T<B`B5W!R;W=A9+P@:VQU8WH@='5T86HB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,Y"FUS9VED(").971W;W)K(@IM
M<V=S='(@(E-I9>8B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,30@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R-PHC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S<X"FUS9VED(").979E<B(*;7-G<W1R(").:6=D>2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$V,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I
M9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W=A($MA;&5D;VYI82(*"B,Z
M(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E
M;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(W"FUS9VED
M(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]W82!K871E9V]R:6$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(DYE=R!-;V]N
M(@IM<V=S='(@(DYO=WD@:V]N=&%K="(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE=R!5<V5R;F%M92`H;W!T:6]N
M86PI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B
M3F]W82!:96QA;F1I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B;&%N:RDB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-C$*;7-G:60@(DYE=W,B"FUS9W-T<B`B5VEA9&]M;[9C:2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.34*(RP@9G5Z>GD*;7-G:60@(DYE=W-G
M<F]U<',B"FUS9W-T<B`B1W)U<'D@9'ES:W5S>6IN92(*"B,Z('1E;7!L871E
M<R]D871A+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C0V"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@
M(DYA<W3J<&YE(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY
M"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(DYA<W3J<&YA('-T<F]N
M82(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S<P(&QI8B](;W)D92]0
M<F5F<R]522YP:'`Z,S<T"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B
M3F%S=.IP;F4@;W!C:F4B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P
M,PHC+"!F=7IZ>0IM<V=I9"`B3F5X=#XB"FUS9W-T<B`B3F%S=.IP;F4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*
M;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6MA<F%G=6$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@
M(DYI9V5R(@IM<V=S='(@(DYI9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S
M='(@(DYI9V5R:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,S8X"B,L(&9U>GIY"FUS9VED(").:6=H="(*;7-G<W1R(")7>7-O:VDB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.#4*(RP@9G5Z>GD*;7-G:60@(DYO(@IM
M<V=S='(@(DYI92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT
M;6PZ,38*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@
M=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-SD@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C,P
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C(U,@IM<V=I9"`B3F\@
M8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*(RP@9G5Z>GD*
M;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E
M<GIE(%-13"!Z('6_>71K;W=N:6MA;6DB"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")"97H@>FUI86XN
M(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G
M:60@(DYO(&-H:6QD('!E<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E9"!B96QO
M=R!T:&ES(&QE=F5L+B(*;7-G<W1R(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB
M(&1O('5P<F%W;FEE\2XB"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-C$*(RP@9G5Z>GD*;7-G:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(E5D8;-O('-IZB!D;V1AYB!<
M(B5S7"(@9&\@=7!R87=N:67Q+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38W(&QI
M8B](;W)D92YP:'`Z-#<W(&QI8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+B(*;7-G<W1R(")"<F%K(&MO;F9I9W5R86-J:2!D
M;&$@)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<T,0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N(@IM<V=S='(@(D)R86L@:6YF;W)M86-J:2!O('-E<G=E<GIE
M($Q$05`@>B!U<W1A=VEE;FEA;6DN(@H*(SH@;&EB+U9&4R]S<6PN<&AP.C4Y
M,0HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(D)R86L@:6YF;W)M
M86-J:2!O('-E<G=E<GIE(%-13"!Z(&MA=&5G;W)I86UI+B(*"B,Z(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C<P-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V]N9FEG
M=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&
M4RXB"FUS9W-T<B`B0G)A:R!I;F9O<FUA8VII(&\@<V5R=V5R>F4@4U%,('H@
M:V%T96=O<FEA;6DN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,30*(RP@9G5Z>GD*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G
M<W1R(").:64@=WEG96YE<F]W86YO(+]A9&YE9V\@<VMR>7!T=2XB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"B,L(&9U>GIY"FUS
M9VED(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B5VEA9&]M
M;[;F(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP.C@X,0IM<V=I9"`B3F\@
M9FEL92!U<&QO861E9"(*;7-G<W1R(").:64@=V=R86YO('!L:6MU(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*(RP@9G5Z
M>GD*;7-G:60@(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B07!L:6MA
M8VIA(&=O=&]W82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-38*(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G
M<W1R(").:65Z;F%N>2!A9')E<V%T(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8S,PHC+"!F=7IZ>0IM<V=I9"`B3F\@;65S<V%G92!S
M=7!P;&EE9"XB"FUS9W-T<B`B5VEA9&]M;[;F(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8S-@HC+"!F=7IZ>0IM<V=I9"`B3F\@;F%M
M92!S<&5C:69I960N(@IM<V=S='(@(DYI92!W>6)R86YO('6_>71K;W=N:6MA
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*(RP@
M9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N(@IM<V=S='(@(DYI
M92!W>6)R86YO('6_>71K;W=N:6MA+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(DYI92!Z;F%L97II;VYO(&MO;G1A:W3S=R(*"B,Z(&QI8B](
M;W)D92]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3FEE('!O
M9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!(5%10+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI
M92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@24U!4"XB"@HC
M.B!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HW,@IM<V=I9"`B3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G
M<W1R(").:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($ME
M<F)E<F]S+B(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDT"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI
M96YI82!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C<W(&QI
M8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L:6(O2&]R9&4O075T:"]P
M86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A;F\@:&%SLV$@
M9&QA('5W:65R>GET96QN:65N:6$@3$]'24XN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P;V1A
M;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@4$%34U=$+B(*"B,Z(&QI
M8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYI92!P
M;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@4TU"+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-@IM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S:6=N=7!S+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0S"B,L(&9U>GIY"FUS9VED(").;R!R=6QE<R(*;7-G<W1R(")5
M=V%G:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@
M(E5W86=I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$R-0IM
M<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,Q"B,L(&9U>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B4')O<WKJ('!O9&'F(&YA>G?J('6_
M>71K;W=N:6MA(&D@:&%SLV\B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP
M:'`Z,30P"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.#DS(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY,#,*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-"!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3,Q"B,L(&9U>GIY"FUS9VED
M(").;R!V86QU97,B"FUS9W-T<B`B57=A9VDB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3$Y"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R-PIM<V=I
M9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$V('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED
M96YT:71Y<V5L96-T+FEN8SHY,@IM<V=I9"`B3F]N92(*;7-G<W1R("*O861N
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*(RP@9G5Z>GD*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(J9R;V1K;W=O975R;W!E:G-K:2`H
M25-/+3@X-3DM,BDB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C@*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@
M(DYO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8P"B,L(&9U>GIY"FUS9VED(").;W)T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(E!O;6]C(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B
M3F]R=V5G:6$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`HC
M+"!F=7IZ>0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(E5W86=I(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,SD*(RP@9G5Z>GD*;7-G:60@
M(DYO="!"969O<F4B"FUS9W-T<B`B57=A9VDB"@HC.B!L:6(O5D93+V9I;&4N
M<&AP.C,S,0HC+"!F=7IZ>0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S
M='(@(DMA=&%L;V<B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C,@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX,PHC.B!L
M:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC
M.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-3D*
M;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B3FEE('IA:6UP;&5M
M96YT;W=A;F\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").:65U<W1A=VEO
M;F4B"@HC.B!L:6(O5D93+G!H<#HQ-S4@;&EB+U9&4RYP:'`Z,3DS(&QI8B]6
M1E,N<&AP.C(Q,"!L:6(O5D93+G!H<#HR,C8*(SH@;&EB+U9&4RYP:'`Z,C0R
M(&QI8B]61E,N<&AP.C(U-R!L:6(O5D93+G!H<#HR-S0@;&EB+U9&4RYP:'`Z
M,S`W"B,Z(&QI8B]61E,N<&AP.C,V-R!L:6(O5D93+G!H<#HT-#8@;&EB+U9&
M4RYP:'`Z-3$U(&QI8B]61E,N<&AP.C4S,@HC.B!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C$T,R!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$U.`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W,R!L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(N<&AP.C(S-`IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS
M9W-T<B`B3FEE;V)SLW5G:7=A;F4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C(T-"!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,38T
M"FUS9VED(").;W1E<R(*;7-G<W1R(")5=V%G:2(*"B,Z('-E<G9I8V5S+V]B
M<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC
M92]C;VYF:7)M7W1O<"YI;F,Z,3`*;7-G:60@(DYO=&EC92(*;7-G<W1R(")5
M=V%G82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED
M(").;W9E;6)E<B(*;7-G<W1R("),:7-T;W!A9"(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#0V"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS9W-T<B`B
M3&ES=&]P860B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-PHC+"!F=7IZ
M>0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B3&EC>F)A
M('=I97)S>GDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I
M9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3&EC>F)A(&MO;'5M;B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8Y(&QI8B](;W)D92]&;W)M+G!H
M<#HQ-#(S(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0U"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("),:6-Z8F$@=VEE<G-Z>2(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*(RP@9G5Z>GD*;7-G:60@(DYU
M;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T
M:6]N(&QI<W0N(@IM<V=S='(@(E-T=V]R>GFS9;8@;&ES=.H@9'ES=')Y8G5C
M>6INL2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Q,0HC+"!F=7IZ>0IM<V=I9"`B3V)J
M96-T(@IM<V=S='(@(E1E;6%T(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,3$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S
M='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3,W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C$U"B,L(&9U>GIY
M"FUS9VED(")/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<R(*;7-G<W1R(")$
M;VUYMFQN92!U<')A=VYI96YI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@S(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")08;QD
M>FEE<FYI:R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM<V=I9"`B
M3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,P,0IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(D)I=7)O(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86XB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E1E
M;B!S97)W97(@;FEE(&]B<[-U9W5J92!U9&]S=.IP;FEA;FEA(&9O;&1E<O-W
M+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$X-3(@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S(*;7-G:60@(D]N
M;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B5'?S:B!J
M961E;B!A9')E<R!E+6UA:6P@:F5S="!D;WIW;VQO;GDN(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C8U"FUS9VED("(B"B)/;FQY('1H92!O=VYE
M<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI
M<"!O<B!O=VYE<B`B"B)P97)M:7-S:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I
M;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B3W1W\W)Z('<@;F]W>6T@;VMN:64B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E
M;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE
M9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"B,L(&9U>GIY"FUS
M9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@
M(E!O8G)AYB!P;V-Z=.H@=R!O<V]B;GEM(&]K;FEE/R(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS
M9VED(")/<'1I;VYS(@IM<V=S='(@(D]P8VIE(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C(Y('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D]P=&EO;G,@9F]R("5S(@IM<V=S='(@(D]P8VIE("5S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`HC+"!F=7IZ>0IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E=Y8FEE
M<GH@;&ES=.HB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7IA8VIA(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A
M=&EO;F%L(%5N:70B"FUS9W-T<B`B2F5D;F]S=&MA(&]R9V%N:7IA8WEJ;F$B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A
M;FEZ:6YG(@IM<V=S='(@(D]R9V%N:7IA=&]R(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T
M:6]N('1E;7!L871E(@IM<V=S='(@(D1O;7FV;&YE('5P<F%W;FEE;FEA(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("));FYE(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#8*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3(R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S$*;7-G:60@
M(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(DEN;F4@:6YF;W)M86-J92(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(DEN;F4@=7!R87=N:65N:6$B"@HC.B!L
M:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B57=I97)Z>71E;&YI
M96YI92!004T@;FEE(&IE<W0@9&]S=.IP;F4N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3(U,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E
M(@IM<V=S='(@(D-Y9G)O=WD@<&]D<&ES(%!'4"(*"B,Z(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$R.3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*
M;7-G<W1R(")7:6%D;VUOMN8@>F%S>GEF<F]W86YA(%!'4"(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$S-3$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y
M(@IM<V=S='(@(DML=6-Z('!U8FQI8WIN>2!01U`B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HQ,S,S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(E=I861O;6^VYB!Z87-Z>69R;W=A;F$O<&]D<&ES
M86YA(&ML=6-Z96T@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS
M9VED(")02%`@0V]D92(*;7-G<W1R(")+;V0@4$A0(@H*(SH@861M:6XO<&AP
M<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4&]WLV]K
M82!02%`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS-PHC+"!F=7IZ>0IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("):
M86QO9W5J(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S@*(RP@9G5Z>GD*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T<B`B26UP
M;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,SD*(RP@9G5Z>GD*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B4&]K8;\B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`HC+"!F
M=7IZ>0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(DEM<&]R="(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS
M9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#(*(RP@9G5Z>GD*;7-G:60@(E!-(%0M4W1O
M<FUS(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+V%P:2YP:'`Z,3(X"FUS9VED
M(")07TA0(%-H96QL(@IM<V=S='(@(E!O=[-O:V$@4%](4"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*(RP@
M9G5Z>GD*;7-G:60@(E!A9&1I;F<B"FUS9W-T<B`B4F]Z=VEJ86YI92(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$W,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM
M<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N(%1E
M<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B
M"FUS9W-T<B`B4&%N86UA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM
M<V=S='(@(E!A<'5A+4YO=V$@1W=I;F5A(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB
M"FUS9W-T<B`B4&%R86=W86HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS-@HC+"!F=7IZ>0IM<V=I9"`B4&%R=&QY($-L;W5D
M>2(*;7-G<W1R(")+<F%J(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#$Y('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-S,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHS-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8R"FUS9VED(")0
M87-S=V]R9"(*;7-G<W1R(")(87.S;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S
M='(@(DAA<[-O(&YI97!R87=I9+-O=V4B"@HC.B!L:6(O2&]R9&4O075T:"]R
M861I=7,N<&AP.C$U,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B0G)A:R!I
M;F9O<FUA8VII(&\@<V5R=V5R>F4@4U%,('H@=;]Y=&MO=VYI:V%M:2(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,#4T"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")(87.S;R!Z('!O='=I97)D>F5N:65M
M(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")0
M87-S=V]R9#HB"FUS9W-T<B`B2&%SLV\Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B2&%S
MLV\Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`S-0HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U
M"FUS9VED(")087-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B2&%SLV\@
M;75S:2!P87-O=V'F+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R
M"FUS9VED(")087-T92(*;7-G<W1R(")7:VQE:B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R
M;VT@8VQI<&)O87)D(@IM<V=S='(@(E=K;&5J('IE('-C:&]W:V$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q"B,L(&9U
M>GIY"FUS9VED(")0871H(@IM<V=S='(@(E=K;&5J(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F5Q=65U960N:6YC.C0*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U
M>GIY"FUS9VED(")096]P;&4B"FUS9W-T<B`B6U)A<&]R="!O('!R;V)L96UI
M95TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4&5R8V5N="(*;7-G<W1R(")$<G5K=6HB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.C8*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R(")7>6MO;F%J(&-Y:VQI8WIN92!O<&5R86-J92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.3@*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B5WEK;VYA:B!C>6ML:6-Z
M;F4@;W!E<F%C:F4@<&]D8WIA<R!L;V=O=V%N:6$_(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV
M-`HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G:60@(E!E<FUI
M<W-I;VXB"FUS9W-T<B`B57!R87=N:65N:64B"@HC.B!A9&UI;B]P97)M<R]D
M96QE=&4N<&AP.C8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M
M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`B0G)A:R!D;W-T
MZG!U(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HY,PHC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HW-`HC+"!F=7IZ>0IM<V=I9"`B4&5R
M;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-J
M82(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30U(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,30X"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,34R
M"FUS9VED(")097)M:7-S:6]N<R!F;W(B"FUS9W-T<B`B57!R87=N:65N:6$@
M9&QA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")097)S
M;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUA8VIE(&]S;V)I<W1E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$X-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&:6QI<&EN>2(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G
M<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R
M-0IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N
M(@IM<V=S='(@(E!I=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM<V=I9"`B4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*
M;7-G<W1R(").82!P97=N;R!U<W5NL>8@=&5N('=Y8G)A;GD@96QE;65N=#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-34*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS9W-T<B`B3F$@<&5W;F\@=7-U
M;K'F('=Y8G)A;GD@96QE;65N=#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C4W,`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BXB"FUS9W-T<B`B4')O<WKJ('!O9&'F(&YO=[$@;F%Z=^HZ(@H*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*
M(RP@9G5Z>GD*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!D;&$@
M;F]W96=O(&9O;&1E<G4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S,#$*
M;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM<V=S
M='(@(E!R;W-ZZB!P;V1AYB!P;W!R87=N>2!A9')E<R!)4"XB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C8U.0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(T-3`*;7-G
M:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E!R;W-Z
MZB!P;V1AYB!P;W!R87=N>2!C>F%S+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R
M>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B4')O<WKJ(&]P:7-AYB!P<F]B
M;&5M+B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3@@=&5M<&QA
M=&5S+VQO9VEN+VQO9VEN+FEN8SHR,@IM<V=I9"`B4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B4')O<WKJ('!O
M9&'F(&YA>G?J('6_>71K;W=N:6MA(&D@:&%SLV\B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O86=R965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@
M66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R
M>4UA;F%G97(N<&AP.C<Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(DUU<VES>B!O:W)EMFQI
MYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F+B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$X,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I
M9"`B4&]L86YD(@IM<V=S='(@(E!O;'-K82(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PHC+"!F=7IZ>0IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B
M6G=I\2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S0*(RP@9G5Z
M>GD*;7-G:60@(E!O;&QS(@IM<V=S='(@(EIW:?$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T
M=6=A;"(*;7-G<W1R(")0;W)T=6=A;&EA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0
M;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I;VX@9F]R
M(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(E!R96-I<&ET871I;VX\8G(@
M+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+VQD87`N
M<&AP.CDX"B,L(&9U>GIY"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,
M1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@
M3FEE('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@3$1!4"XB
M"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S,*(RP@9G5Z>GD*
M;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z(%=Y;6%G86YE(')O
M>G-Z97)Z96YI92!)34%0(&YI92!Z;F%L97II;VYE+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@
M<V5A(&QE=F5L.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(R,PIM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")0;V1G;+%D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(T"B,L(&9U>GIY"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B5WFV=VEE=&P@>F&SL6-Z;FEK('<@;W-O8FYY
M;2!O:VYI92(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S8P(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S8T"B,L(&9U>GIY"FUS9VED(")0<F5V:6]U
M<R!O<'1I;VYS(@IM<V=S='(@(E!R97IE;G1A8VIE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@
M9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#$R"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")+;'5C>B!P<GEW
M871N>2(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L
M96TB"FUS9W-T<B`B4')O8FQE;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP
M.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")/<&ES
M('!R;V)L96UU(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q,PIM
M<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#D*(RP@9G5Z>GD*;7-G
M:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E=Y;&]G=6HB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B2VQU8WH@<'5B;&EC>FYY(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@
M(D%L9V]R>71M(&ML=6-Z82!P=6)L:6-Z;F5G;R(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C0T"FUS9VED(")0=6)L:6,@2V5Y($EN9F\B"FUS
M9W-T<B`B26YF;W)M86-J92!O(&ML=6-Z=2!P=6)L:6-Z;GEM(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,C,P"FUS9VED(")0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R
M(")087)A(&ML=6-Z>2!O<V]B:7-T>6-H(&YI92!Z;W-T8;-A('=Y9V5N97)O
M=V%N82!P;VUYMFQN:64N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T
M<B`B4&]R=&]R>6MO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T<B`B2V%T87(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C(*;7-G:60@(E%U97)Y(@IM<V=S
M='(@(EIA<'ET86YI92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C8S"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B
M:70I(@IM<V=S='(@(DML=6-Z('!U8FQI8WIN>2!24T$@*"5D(&)I=/-W*2(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8U"B,L(&9U>GIY"FUS9VED(")2
M861I;R!S96QE8W1I;VXB"FUS9W-T<B`B4VMA<W5J('=Y8G)A;K$@=&^_<V%M
M;[;F(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS9W-T<B`B3W-T<GIEOV5N:64B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-`HC
M+"!F=7IZ>0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R("):86QO9W5J(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*(RP@
M9G5Z>GD*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("):86QO9W5J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*(RP@9G5Z
M>GD*;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(EIA;&]G=6HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-PHC+"!F=7IZ
M>0IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("):86QO9W5J(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#@*(RP@9G5Z
M>GD*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("):86QO9W5J(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(E)A;F1O
M;2!&;W)T=6YE(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C@@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP
M:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A=&EO(@IM<V=S='(@(D]P8VIE(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3,@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*(RP@9G5Z>GD*;7-G
M:60@(E)E860B"FUS9W-T<B`B4')Z9;-A9'5J(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@W"B,L(&9U>GIY"FUS9VED(")296%D(&UE
M<W-A9V5S(@IM<V=S='(@(DYO=V4@=VEA9&]M;[9C:2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,T"B,L(&9U>GIY"FUS9VED(")2961O
M97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")7>F[S=R!S=V]JL2!S97-J
MZB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#,*;7-G:60@(E)E9G)E
M<V@@1'EN86UI8R!-96YU($5L96UE;G1S.B(*;7-G<W1R(")/9+9W:66_(&1Y
M;F%M:6-Z;F4@96QE;65N='D@;65N=3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,S"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R
M(")/9+9W:66_('=I9&]K('-E<G=I<W4Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,R-#@*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"B,L(&9U
M>GIY"FUS9VED(")296UA<FMS(@IM<V=S='(@(D1A;FEA(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS
M9W-T<B`B6F1A;&YE('-E<G=E<GDB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,34*;7-G:60@(E)E;6]V92(*;7-G<W1R(")5<W7Q(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@
M0FQO8VLB"FUS9W-T<B`B57-U\2!B;&]K(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4R.0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*
M;7-G<W1R(")5<W7Q(&MO;'5M;NHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0P"B,L(&9U>GIY"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R(")5<W7Q('!A<NHB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T
M<B`B57-U\2!P87+J(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C(P-0IM
M<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,0IM<V=I9"`B4F5M
M;W9E('1H92(*;7-G<W1R(")5<W7Q(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,38*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(E5S=?$@=;]Y=&MO=VYI:V$B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(EID86QN92!UOWET:V]W;FEK
M83H@)7,B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED
M(")297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O
M<F-O9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30T"B,L(&9U>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N(@IM<V=S='(@(J]A9&%N>2!O8FIE:W0@;FEE
M>FYA;&5Z:6]N>2XB"@HC.B!L:6(O2&]R9&4N<&AP.C$W-"!L:6(O2&]R9&4N
M<&AP.C0X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B0G)A:R!W>6UA9V%N96H@;W!C:FD@)W5I9"<@9&QA(&MO;F9I9W5R
M86-J:2!U<W1A=VEE\2XB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S0W(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C<Q,"!L:6(O5D93+W-Q;"YP:'`Z-3DW"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B0G)A:R!W
M>6UA9V%N96H@;W!C:FD@)W5I9"<@9&QA(&MO;F9I9W5R86-J:2!U<W1A=VEE
M\2XB"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S@T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I
M;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")"<F%K('=Y;6%G86YE:B!O<&-J
M:2`G=6ED)R!D;&$@:V]N9FEG=7)A8VII('5S=&%W:67Q+B(*"B,Z(&QI8B](
M;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C@*;7-G:60@(E)E<75I<F5D($9I
M96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](;W)D
M92]&;W)M+G!H<#HS,SD@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q
M-0HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(DMA<W5J(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#8*
M;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@(E=Y8WIYMN8@:&%SLV\B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S
M970@66]U<B!087-S=V]R9"(*;7-G<W1R(")7>6-Z>;;F(%1W;VIE(&AA<[-O
M(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H
M<#HV-2!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$*;7-G:60@(E)E<W5L=',B"FUS
M9W-T<B`B5WEN:6MI(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C$P,B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED(")2971U<FX@
M=&\@3W!T:6]N<R(*;7-G<W1R(")0;W=R\W0@9&\@;W!C:FDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DW(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.#4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")2975N:6]N(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*(RP@9G5Z
M>GD*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(DAO<F1E
M(&YI92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC:"!497AT($5D:71O<B!/
M<'1I;VYS(@IM<V=S='(@(E)O>F)U9&]W86YY(&5D>71O<B!T96MS='4B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E)I
M9&1L97,B"FUS9W-T<B`B4W1A;F]W:7-K;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I
M9"`B4FEG:'0B"FUS9W-T<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,C`*(RP@9G5Z>GD*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G<W1R
M(")0<GIY:[-A9&]W92!W87)T;[9C:3HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$Q-@HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@
M(E!R>GEKLV%D;W=E('=A<G1OMF-I.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.`HC+"!F=7IZ>0IM<V=I
M9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2
M;VQE(@IM<V=S='(@(E-T86YO=VES:V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM
M<V=S='(@(E)U;75N:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C`X"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(D]B<O/F
M(&\@,3@P('-T;W!N:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,#4*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(D]B<O/F
M('<@;&5W;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,3$*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")/8G+SYB!W('!R
M87=O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHT.0HC+"!F=7IZ>0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS
M9W-T<B`B5[-AMF-I=V^V8VD@<GKJ9'4@4')O<&5R=&EE<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G
M:60@(E)O=R!P<F]P97)T:65S(@IM<V=S='(@(E>S8;9C:7=OMF-I(')ZZF1U
M(%!R;W!E<G1I97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P,0IM<V=I9"`B4F]W<SHB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC
M+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B4W1A;F]W:7-K;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU
M,@IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R,0IM<V=I9"`B
M4G5N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*
M;7-G<W1R(")2;W-J82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2=6%N
M9&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B5VEA9&]M;[;F('IA<WIY9G)O
M=V%N82!3+TU)344B"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM
M<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")5=VEE<GIY=&5L;FEE;FEE(%-!4TP@;FEE(&IE<W0@9&]S=.IP
M;F4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U.0HC+"!F=7IZ
M>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")7>;9W:65T;&%N:64@
M=VEA9&]M;[9C:2(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B
M4U%,(%-H96QL(@IM<V=S='(@(E!O=VQO:V$@4U%,(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,W,`IM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H
M<#HQ,S(*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B4&]WLV]K82!37U%,
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,0HC+"!F=7IZ>0IM<V=I9"`B4V$B"FUS9W-T<B`B6F%P:7-Z(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I
M9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@(J9W:>IT82!(96QE;F$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R(")386EN="!+:71T
M<R!I($YE=FES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386EN
M="!,=6-I82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB
M"FUS9W-T<B`B4V%I;G0M4&EE<G)E(&D@36EQ=65L;VXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")3
M86EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")386EN
M="!6:6YC96YT(&D@1W)E;F%D>6YY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E
M;&8I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3$@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@36%R:6YO(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I9"`B
M4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E=O:F5W\V2\='=O(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DW"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PIM
M<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(D%R86)I82!3875D>6IS:V$B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A
M=F4B"FUS9W-T<B`B6F%P:7-Z(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R
M("):87!I<WH@)7,B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N
M:6YC.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S
M='(@(EIA<&ES>B!<(B5S7"(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN
M8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B6F%P:7-Z(&]P8VIE
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W,`IM<V=I9"`B(@HB4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HV.0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M(%PB)7-<(BXB"FUS9W-T<B`B3FEE(&UOOVYA(&]T=V]R>GGF(&UO9'6S=2!-
M86EN=&5N86YC95]487-K("5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(E-C871T97)E9"!4
M+5-T;W)M<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B4V-I96YC92(*;7-G<W1R(").861A
M=V-A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*
M;7-G<W1R(")3>G5K86HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C<X"B,L(&9U>GIY"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")/
M<&-J92!W>7-Z=6MI=V%N:6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDW
M,@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(E=Y8FEE<GH@<&QI:VDB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"B,L
M(&9U>GIY"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E=Y8FEE<GH@
M9F]R;6%T(&1A='DZ(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G
M<W1R(")3='?S<GH@;F]WL2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G
M<W1R(")3='?S<GH@;F]WL2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHV,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S
M='(@(E-T=_-R>B!N;W>Q(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM
M<V=S='(@(E-T=_-R>B!N;W>Q(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V
M-C(*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S
M+B(*;7-G<W1R(")7>6)I97)Z(&9O<FUA="!D871Y.B(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HX,3$*(RP@9G5Z>GD*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B4W1W\W)Z(&YO=[$B"@HC.B!S
M97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*(RP@9G5Z>GD*;7-G:60@(B(*(E-E
M;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B
M96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B)7>6)I97)Z('IN86MI('H@
M<&]N:;]S>GEC:"!P\VP@9F]R;75L87)Z82X@36^_97-Z(&IE('-K;W!I;W=A
MYB!I('=K;&5IYB!Z("(*(G!O;&$@=&5K<W1O=V5G;RXB"@HC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CHB"FUS9W-T<B`B5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C
M="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E=Y8FEE<GH@9F]R;6%T(&1A
M='DZ(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHX
M.0IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z(@IM<V=S='(@(E=Y8FEE<GH@=&^_<V%M;[;F(&1O('IM:6%N>3HB"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5WEB:65R>B!Z;F%K('!O9'II
M8;-U(&1A='DZ(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G
M:60@(E-E;&5C="!T:&4@=&EM92!F;W)M870Z(@IM<V=S='(@(E=Y8FEE<GH@
M9F]R;6%T(&-Z87-U.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-C0*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R
M(")7>6)I97)Z(&1W82!P87-U:K%C92!P;VQA+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR.3@*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M
M92XB"FUS9W-T<B`B5WEB:65R>B!S8VAE;6%T(&MO;&]R\W<N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(T,`IM<V=I9"`B4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")7>6)I97)Z('1W\VH@<')E9F5R
M;W=A;GD@:NIZ>6LZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B5WFV
M;&EJ(')A<&]R="!O('!R;V)L96UI92(*"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HY-C$*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`B4V5N96=A;"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S$V"B,L(&9U>GIY"FUS9VED(")396YS;W(Z
M("(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#(@;&EB+TAO<F1E+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B
M5W)Z97-I9?$B"@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY
M"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#$*;7-G:60@(E-E<FEA;"!.
M=6UB97(B"FUS9W-T<B`B3G5M97(@<V5R>6IN>2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#@*(RP@9G5Z>GD*;7-G:60@(E-E<G9E<B!D
M871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L;VL@7")-
M971A<EPB(&YI92!J97-T(&1O<W3J<&YY+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDR"B,L(&9U>GIY"FUS9VED(")397-S:6]N
M($E$(&5X<&ER960N(@IM<V=S='(@(E=I861O;6^VYB(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S$S"FUS9VED(")3970B"FUS9W-T<B`B57-T87<B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@
M(E5S=&%W('ID86QN92!S97)W97)Y+"!D;R!K=/-R>6-H(&-H8V5S>B!M:67F
M(&1O<W3J<"!Z('-E<G=I<W4N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(E5S=&%W('!R969E<F]W
M86YY(&KJ>GEK+"!S=')E9NH@8WIA<V]WL2!I(&]P8VIE(&1A='DN(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S
M=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S
M:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B
M(@HB57-T87<@=7.S=6?J('!O8WJQ=&MO=[$L('-C:&5M870@:V]L;W+S=RP@
M;V2V=VEEOV%N:64@<W1R;VYY(&D@:6YN92!O<&-J92`B"B)W>;9W:65T;&%N
M:6$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<T"FUS9VED(")3971U
M<"(*;7-G<W1R(")+;VYF:6=U<F%C:F$B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HS.0HC+"!F=7IZ>0IM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R(").:64@;6^_;F$@;W1W
M;W)Z>>8@;6]D=;-U($UA:6YT96YA;F-E7U1A<VL@)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<T"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-Z97-Z96QE(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,0HC+"!F=7IZ>0IM<V=I9"`B
M4VAO<'!I;F<B"FUS9W-T<B`B2&ES>G!A;FEA(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS
M9W-T<B`B2W+S=&MI(&]P:7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#,X"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8W('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3,@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S8*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-SD*;7-G:60@(E-H;W<B"FUS9W-T<B`B4&]K8;\B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,34X"FUS9VED("(B"B)3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.#(*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B4&]K87IY=V'F(&-Z
M87,@;W-T871N:65G;R!Z86QO9V]W86YI82!P;R!L;V=O=V%N:74_(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$W-C8*;7-G:60@(E-H;W<@;W!T:6]N('1O
M(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(X,3(*(RP@9G5Z>GD*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@
M(DEM<&]R="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*(RP@9G5Z
M>GD*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS
M9W-T<B`B5WFV=VEE=&QAYB!I:V]NZB!F:6QT97+S=R!N82!P87-K=2!Z861A
M\3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S
M='(@(E!O:V&_(&UE;G4@)7,@<&\@;&5W96H_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"B,L(&9U>GIY
M"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(E1E;"X@:V]M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PHC+"!F=7IZ>0IM<V=I9"`B
M4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&5L
M+B!K;VTN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4Y"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!486)L
M92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B5&5L+B!K;VTN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4Q"B,L(&9U>GIY"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3<V-`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!U<&QO860B"FUS
M9W-T<B`B5V=R>7=A;FEE('!L:6MU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,B
M"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B2W+S=&MI92!S=')E<WIC>F5N:64B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B
M4VAO=V5R<R!,871E(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S(&EN
M('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HS.3D*(RP@9G5Z>GD*;7-G:60@(E-H<FEN:R(*;7-G<W1R
M(")"86AR86IN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-CDR
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<U-`HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HX,3(@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z.#<T"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDP.2!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY-#8*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z.3<T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P
M,#0*;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS
M*2!O=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3
M:65R<F$@3&5O;F4B"FUS9W-T<B`B4VEE<G)A($QE;VYE(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C4*(RP@9G5Z>GD*;7-G:60@(E-I9VX@
M=7`B"FUS9W-T<B`B4F5J97-T<F%C:F$@)7,B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDR"FUS9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E
M<F5D(@IM<V=S='(@(EIA<F5J97-T<G5J('-IZBP@:F6V;&D@:F5S>F-Z92!T
M96=O(&YI92!Z<F]B:;-EMB(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S$R"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B4&]D<&ES(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G:60@(E-I9VYA='5R
M92!!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)Y=&T@<&]D<&ES=2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!U<B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HX.38@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$R,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,C(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I>F4B"FUS9W-T<B`B5VEE;&MO
MMN8B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN
M:6YC.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B4&]M:?$@
M;W!E<F%C:F4@8WEK;&EC>FYE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B4[-O=V%C:F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3LV]W
M96YI82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C4T"B,L(&9U>GIY"FUS9VED(")3;F]W(@IM<V=S='(@(E!O:V&_(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*(RP@9G5Z
M>GD*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"B,L(&9U>GIY
M"FUS9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B26UP;W)T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*(RP@9G5Z>GD*
M;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")+<O-T:VEE('-T
M<F5S>F-Z96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")3;F]W(%-H;W=E<G,@3&%T92(*
M;7-G<W1R("));7!O<G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM
M<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T
M<B`B5WES<'D@4V%L;VUO;F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3;VUA;&EA(@IM<V=S='(@
M(E-O;6%L:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@
M(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Y,C4*(RP@9G5Z>GD*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T:6]N
M(@IM<V=S='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4X.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Q-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(T-PHC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B
M061R97,@9&]M;W=Y(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@
M(E!OLW5D;FEO=V$@069R>6MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ
M.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*;7-G<W1R
M(")0;[-U9&YI;W=O975R;W!E:G-K:2`H25-/+3@X-3DM,RDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S
M(@IM<V=S='(@(D=E;W)G:6$@4&^S=61N:6]W82(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*(RP@9G5Z>GD*;7-G
M:60@(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B4&]M;V,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I
M9"`B4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-0IM
M<V=I9"`B4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L
M;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"B,L(&9U
M>GIY"FUS9VED(")3<&%C97(B"FUS9W-T<B`B2&ES>G!A;FEA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"B,L
M(&9U>GIY"FUS9VED(")3<&%C:6YG(@IM<V=S='(@(DAI<WIP86YI82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-30*;7-G:60@(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(E-P86EN(@IM<V=S='(@(DAI<WIP86YI82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HY.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H
M87)A8W1E<B!);G!U="(*;7-G<W1R(")%9'EC:F$@>FYA:_-W('-P96-J86QN
M>6-H(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*;7-G<W1R(")0;V1Z:65L
M(&MO;?-R:^HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B
M4&]D>FEE;"!K;VQU;6[J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S
M='(@(E!O9'II96P@=VEE<G-Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8Q"B,L(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`B26UP;W)T(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X
M"FUS9VED(")3<FD@3&%N:V$B"FUS9W-T<B`B4W)I($QA;FMA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8U(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-T86YD87)D(@IM<V=S='(@(DMA;&5N
M9&%R>B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@HC+"!F=7IZ>0IM
M<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87)T(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U.34@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#@*(RP@9G5Z
M>GD*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B4W1A<G0B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@;W(@4')O
M=FEN8V4B"FUS9W-T<B`B5V]J97?S9+QT=V\@;'5B('-T86XB"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S
M(@IM<V=S='(@(E-T871U<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T
M"B,L(&9U>GIY"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&;W)M
M870@8WIA<W4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,@IM
M<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B061R97,@9&]M;W=Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM
M<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(S,PHC+"!F=7IZ>0IM<V=I9"`B4W1R:6YG(&QI<W0B"FUS
M9W-T<B`B57-T87=I96YI82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<T
M"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")496UA="(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,S(@;&EB+TAO<F1E+T9O<FTO4F5N9&5R
M97(N<&AP.C,Q,@IM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E=YMFQI:B(*"B,Z
M('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB4W5B;6ET
M=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B!9;W4@
M8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I
M<'0B"FUS9W-T<B`B4&6S;GD@;W!I<SHB"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z,3`U(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")0;W=O9'IE;FEE(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R
M(")59&&S;R!S:>H@9&]D8>8@7"(E<UPB(&1O('-Y<W1E;74N(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B561ALV\@<VGJ('5S=6ZQYB!<(B5S7"(@>B!S>7-T
M96UU+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@
M9&5L971E9"!<(B5S7"(N(@IM<V=S='(@(E5D8;-O('-IZB!U<W5NL>8@7"(E
M<UPB+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")59&&S;R!S:>H@=7-U;K'F(%PB)7-<(B!Z('-Y<W1E
M;74N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU,0HC+"!F=7IZ>0IM
M<V=I9"`B4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E
M;&]A9"!T;R!S964@8VAA;F=E<RXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@
M=R!P9;-N:2!S:V]N9FEG=7)O=V%N92XB"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-34*(RP@9G5Z>GD*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B2&]R9&4@;FEE(&IE<W0@=R!P9;-N:2!S:V]N9FEG=7)O
M=V%N92XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(DAO<F1E(&YI
M92!J97-T('<@<&6S;FD@<VMO;F9I9W5R;W=A;F4N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U
M<&1A=&5D(%PB)7-<(B(*;7-G<W1R(")59&&S;R!S:>H@=6%K='5A;&YIYB!<
M(B5S7"(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(E5D8;-O('-IZB!D;V1A
MYB!<(B5S7"(@9&\@<WES=&5M=2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R
M(")3=61A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-38*(RP@9G5Z>GD*;7-G:60@(E-U;6UA<GDB"FUS9W-T
M<B`B2W+S=&MI92!S=')E<WIC>F5N:64Z(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")3=6X@4FES92(*;7-G<W1R(").
M87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HW
M,0HC+"!F=7IZ>0IM<V=I9"`B4W5N(%-E="(*;7-G<W1R(").87IW82!UOWET
M:V]W;FEK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C`T"B,L(&9U>GIY"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3
M=6YR:7-E+U-U;G-E="(*;7-G<W1R(")7<V-H\V0O>F%C:/-D('.S;_%C82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#,*(RP@9G5Z>GD*
M;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*(RP@9G5Z>GD*
M;7-G:60@(E-U;G-E="(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#8*(RP@9G5Z>GD*;7-G
M:60@(E-U;G-E=#H@(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PHC+"!F
M=7IZ>0IM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B4&6S;GD@;W!I<SHB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0S"B,L(&9U>GIY"FUS
M9VED(")3=7!P;W)T(@IM<V=S='(@(DEM<&]R="(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN
M86UE(@IM<V=S='(@(E-U<FEN86TB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4W-`HC+"!F=7IZ>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(").
M87IW82!UOWET:V]W;FEK82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@
M36%Y96XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@
M(E-U87II(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-Z=V5C:F$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-@IM
M<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B4WIW86IC87)I82(*"B,Z(&QI
M8B](;W)D92]344PO2V5Y=V]R9',N<&AP.CDW"B,L(&9U>GIY"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(D]P<O._;FEJ
M(&9O;&1E<B!K;W-Z82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(E-Y<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B57=A9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C(*(RP@
M9G5Z>GD*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(E5W86=I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*(RP@9G5Z>GD*
M;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S='(@(DMR\W1K:64@<W1R97-Z
M8WIE;FEE(@H*(SH@;&EB+TAO<F1E+T1A=&$O='-V+G!H<#HQ-C8*(RP@9G5Z
M>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E1Y='6S(@H*(SH@;&EB+TAO
M<F1E+U5)+U1A8FQE+G!H<#HQ,S8*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM
M<V=S='(@(E>SL6-Z;VYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PHC+"!F=7IZ>0IM<V=I9"`B5&%B;&4@
M4')O<&5R=&EE<R(*;7-G<W1R(")496PN(&MO;2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"B,L(&9U>GIY
M"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E1E;"X@:V]M+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%J=V%N(@H*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I
M=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486IW86XB"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")486II:VES=&%N(@IM<V=S='(@(E1A9+]Y:VES=&%N(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZ
M86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B5VEA9&]M
M;[;F(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W,PIM<V=I9"`B
M5&%S:W,B"FUS9W-T<B`B6F%D86YI82(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(DYU;65R('1E;&5F;VYU(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*
M;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"B,L(&9U>GIY"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R(")0;V1P:7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Q"B,L(&9U>GIY"FUS9VED(")496UP97)A='5R93H@(@IM
M<V=S='(@(E!O9'!I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH
M)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O5&5M<&QA=&4N<&AP.C(Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B)7,@;FEE
M>FYA;&5Z:6]N>2XB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V.0HC+"!F
M=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M061M:6YI<W1R86-J82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Q"B,L
M(&9U>GIY"FUS9VED(")497AT(@IM<V=S='(@(E1Y;&MO('1E:W-T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I9"`B5&5X="!/;FQY(@IM
M<V=S='(@(E1Y;&MO('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM<V=I9"`B5&5X
M="!A;&EG;B(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@
M(E1E>'1T;W`B"FUS9W-T<B`B5'EL:V\@=&5K<W0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED(")4:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA
M:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`B5&%J;&%N9&EA(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDR,PIM
M<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R
M(")$>FGJ:W5J96UY('IA(&MO<GIY<W1A;FEE('H@<V5R=VES=2XB"@HC.B!L
M:6(O5D93+V9T<"YP:'`Z-S,W"B,L(&9U>GIY"FUS9VED(")4:&4@1E10(&5X
M=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")5=VEE<GIY=&5L
M;FEE;FEE(&YI92!P;W=I;V2S;R!S:>HB"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDP,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O24U34"]";V]K+G!H<#HQ,CDT"B,L(&9U
M>GIY"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+B(*;7-G<W1R(")0;V1P:7,@;FEE(&UOOV4@8GGF('IA<W2Q<&EO;F$N
M(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(Y"FUS9VED(")4:&4@
M36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY
M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP
M:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(E1H92!/<'1I;VYS('=I;F1O=R!H87,@
M8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R(")4=V]R>F]N82!W:6%D;VUOMN8@
M>F]S=&&S82!Z86UK;FGJ=&$N(%=Y8VAO9'IE;FEE+B(*"B,Z(&QI8B](;W)D
M92]097)M<RYP:'`Z,34X(&QI8B](;W)D92]097)M<RYP:'`Z,38Y(&QI8B](
M;W)D92]097)M<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,3DR
M(&QI8B](;W)D92]097)M<RYP:'`Z,C`S(&QI8B](;W)D92]097)M<RYP:'`Z
M,C(Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C,S(&QI8B](;W)D92]097)M
M<RYP:'`Z,C<R"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T
M;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I
M9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,SD*;7-G:60@
M(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@
M;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S
M92XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M2V]N=&%K='D@>F]S=&&S>2!P;VUYMFQN:64@9&]D86YE(&1O(%1W;VIE:B!K
M<VFQOVMI(&%D<F5S;W=E:BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HQ,30Y"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"B)0;W1R>F5B;GD@:F5S="!K;'5C>B!P
M=6)L:6-Z;GD@4$=0(&1O('-P<F%W9'IE;FEA('!O9'!I<V%N96H@=VEA9&]M
M;[9C:2XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q
M"B,L(&9U>GIY"FUS9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM<V=S='(@(E1A(&]P97)A8VIA
M(&YI92!J97-T(&]B<[-U9VEW86YA+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#(*(RP@9G5Z>GD*;7-G:60@(E1H92!D:7-T<FEB
M=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B5&$@;W!E
M<F%C:F$@;FEE(&IE<W0@;V)SLW5G:7=A;F$N(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+G!H<#HQ,3,*(RP@9G5Z>GD*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S
M='(@(D]B<[-U9V$@;W-O8FES=&5G;R!K;'5C>F$@4$=0('=Y;6%G82!B97IP
M:65C>FYE9V\@<&^SL6-Z96YI82!W=W<N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ
M-S4@;&EB+TAO<F1E+G!H<#HT.#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB
M"FUS9W-T<B`B6FUI9?$@=7-T87=I96YI82!T<F%K=&]W86YI82!P;&EK\W<@
M:2!K871A;&]G\W<N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C@@;&EB+TAO<F1E
M+G!H<#HT-S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE
M("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@
M(EIM:67Q('5S=&%W:65N:6$@=')A:W1O=V%N:6$@<&QI:_-W(&D@:V%T86QO
M9_-W+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,34R"FUS9VED(")4:&4@9FEL
M92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T1A=&$N<&AP.C(V,`IM<V=I9"`B5&AE(&9I;&4@8V]N
M=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R
M92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T
M;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HX.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E1OOW-A;6^VYB!<(B5S
M7"(@>F]S=&&S82!U<W5N:>IT82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HQ-#8*;7-G:60@(B(*(E1H92!L;V-A=&EO;B!O9B!T:&4@1VYU
M4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L
M87-S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P
M,0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N
M("5S('1O("5S('=I=&@@<W5B:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA
M>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G
M92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<X"FUS9VED(")4:&4@;F%M92!T;R!U
M<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M4')E9G,N<&AP.C(X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E
M9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S
M(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+V1E8BYP:'`Z
M,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O<G!M+G!H<#HS,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=V5B8W!P+G!H<#HS-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<W)C
M:&EG:&QI=&4N<&AP.C,W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H
M92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*
M;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HW.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R(")397)W97(@7"(E<UPB('IO<W1ALR!U<W5N:>IT>2XB"@HC.B!S
M97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T
M<B`B4V5R=V5R(%PB)7-<(B!Z;W-T8;,@>F%P:7-A;GDN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S
M='(@(DMO;G1O(%PB)7-<(B!Z;W-T8;-O('IA<&ES86YE+B(*"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(Y,`HC+"!F=7IZ>0IM<V=I9"`B5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D]K<F6V
M;&]N>2!P;&EK(&YI92!I<W1N:65J92XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z
M,3`X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")/:W)EMFQO
M;GD@<&QI:R!N:64@:7-T;FEE:F4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A
M;F0@8F]T=&]M('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B
M5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T1A
M=&$N<&AP.C,P-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]$871A+V-S=BYP:'`Z,C0P(&QI8B](;W)D92]$871A+W1S=BYP:'`Z
M,3<R"B,L(&9U>GIY"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N(@IM<V=S='(@(E!O9'!I<R!N:64@;6^_92!B>>8@>F%S
M=+%P:6]N82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$P.0IM<V=I9"`B5&AE('=E
M871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D)L
M;VL@=V5A=&AE<BYC;VT@;FEE(&IE<W0@9&]S=.IP;GDN(@H*(SH@;&EB+TAO
M<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I
M;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3FEE(&UA(+]A9&YY8V@@9&]S=.IP
M;GEC:"!O<&-J:2XB"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z
M,S0Q"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C
M86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3FEE(&UA(+]A9&YY
M8V@@86QT97)N871Y=VYY8V@@8WKJMF-I+"!K=/-R92!M;V>S>6)Y('IO<W1A
MYB!P;VMA>F%N92XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[("(*(GEO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB"FUS9W-T
M<B`B(@H*(SH@<VEG;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<
M(B5S7"(@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B5WES=+%P:;,@<')O
M8FQE;2!P<GIY(&1O9&%W86YI=2!<(B5S7"(@9&\@<WES=&5M=3H@)7,B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<
M(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)7>7-TL7!ILR!P<F]B
M;&5M('!R>GD@=7-U=V%N:74@9&%N>6-H(&1L82!UOWET:V]W;FEK82!<(B5S
M7"(@=R!S>7-T96UI93H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@
M7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(E=Y<W2Q<&FS('!R
M;V)L96T@<')Z>2!U<W5W86YI=2!<(B5S7"(@>B!S>7-T96UU+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B5WES
M=+%P:;,@<')O8FQE;2!P<GIY('5A:W1U86QN:6%N:74@7"(E<UPB.B`E<R(*
M"B,Z(&QI8B](;W)D92]"<F]W<V5R+G!H<#HX.#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"<F]W<V5R
M+G!H<#HX.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@
M(E=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!W>;9W:65T;&%N:6$@=&5J(&-ZZK9C
M:2!W:6%D;VUOMF-I(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C0X"B,L
M(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H
M92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]C>F%S
M(&EM<&]R=&]W86YI82!D86YY8V@@:4-A;&5N9&%R+B(*"B,Z(&QI8B](;W)D
M92]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")7>7-TL7!I
MLR!BL[%D('!O8WIA<R!I;7!O<G1O=V%N:6$@9&%N>6-H(&E#86QE;F1A<BXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Y"B,L(&9U>GIY"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L
M9"XB"FUS9W-T<B`B5WES=+%P:;,@8K.Q9"!P;V1C>F%S(&%K='5A;&EZ86-J
M:2!T96=O('=P:7-U.B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S@*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E
M<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U
M;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R(")7
M>7-TL7!ILR!BL[%D('!O9&-Z87,@86MT=6%L:7IA8VII('1E9V\@=W!I<W4Z
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,`HC
M+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M(@IM<V=S='(@(E=Y<W2Q<&FS(&*SL60@<&]D8WIA<R!A:W1U86QI>F%C:FD@
M=&5G;R!W<&ES=3H@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0U"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R(")7>7-TL7!ILR!BL[%D('!O9&-Z87,@
M86MT=6%L:7IA8VII('1E9V\@=W!I<W4Z("5S(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$T.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB
M"FUS9W-T<B`B5&5N('-E<G=E<B!N:64@;V)SLW5G=6IE('5D;W-TZG!N:6%N
M:6$@9F]L9&5R\W<N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E!L:6L@;FEE('=Y9VRQ9&$@;F$@
M<&]P<F%W;F4@87)C:&EW=6T@4D%2+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T
M;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")0;&EK(&YI92!W>6=L
ML61A(&YA('!O<')A=VYE(&%R8VAI=W5M(%I)4"XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,S$T-`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(F9O;&1E
M<B`E<R!N:64@:F5S="!P<F%W:62S;W=Y+B(*"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T
M96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO
M=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@
M*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB
M97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D
M869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDW."!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`U-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X-@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$Q-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3(U-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,30P,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,34U.0HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T,"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3DU.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P-@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`S,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$U,`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R,B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U,PHC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S-@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,S<R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S<S,0IM<V=I9"`B5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B5&\@<&]L92!J97-T('=Y
M;6%G86YE+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,#8U"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#$W"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`Y-`IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HY.#D*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BXB"FUS9W-T<B`B5&\@<&]L92!M=7-I(&)YYB!P;W!R87=NL2!L:6-Z
M8K$N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,S4*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:&5L<"]A8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N9&5R<W1A
M;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F
M('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@
M82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB"FUS
M9W-T<B`B5VEA9&]M;[;F('IO<W1ALV$@;F%P:7-A;F$@=R!I;FYE:B!N:;\@
M='=O:F$@<W1R;VYI92!K;V1O=V5J("@E<RDN(@H*(SH@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ,C8*(RP@9G5Z>GD*;7-G:60@(E1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")-=7-I<WH@=W!R;W=A9'II
MYB!P<GIY;F%J;6YI96H@:F5D;F5G;R!A9')E<V%T82XB"@HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A
M;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R(")4
M96X@<V5R=V5R(&YI92!P;W1R869I(')O>G!A:V]W>7=AYB!A<F-H:7?S=R!Z
M:7`@:2!G>FEP+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,30W"B,L
M(&9U>GIY"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I
M=F%T960N(@IM<V=S='(@(E-K<GEP="!D96%K='EW;W=A;GD@<&]P<F%W;FEE
M+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3(T"B,L(&9U>GIY"FUS
M9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S='(@(DUU
M<VES>B!W<')O=V%D>FGF(&QI8WIBZBXB"@HC.B!S97)V:6-E<R]I;6%G97,O
M8V]L;W)P:6-K97(N<&AP.C,U"B,L(&9U>GIY"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(E1O(&]K;F\@;75S:2!Z;W-T8>8@=WEW;[-A;F4@<')Z97H@;VMN;R!K
M;VUP;WIY=&]R82!W:6%D;VUOMF-I+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(DYA9&%W8V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(R"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#(W"FUS9VED(")4:6UE(@IM<V=S='(@(D-Z87,B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`X"FUS9VED(")4:6UE(%1R
M86-K:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM
M<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R;6%T(&-Z87-U(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S@*(RP@9G5Z>GD*;7-G:60@(E1I;64@
M<V5L96-T:6]N(@IM<V=S='(@(E-K87-U:B!W>6)R86ZQ('1OOW-A;6^VYB(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C(Y"FUS9VED(")4:71L92(*;7-G<W1R(")4>71ULR(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I
M=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(D1O(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8R-@IM<V=I
M9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C
M;&EC:VEN9RXB"FUS9W-T<B`B(@HB06)Y('=Y8G)AYB!W:65L;VMR;W1N92!P
M;VQA('!R>GET<GIY;6%J('!R>GEC:7-K($-T<FP@*%!#*2!L=6(@0V]M;6%N
M9"`H36%C*2`B"B)P;V1C>F%S(&ML:6MA;FEA+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3D*;7-G:60@(E1O9&%Y(@IM<V=S='(@(D1Z
M:;8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C(S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,P,0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B2G5T<F\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC+"!F=7IZ>0IM<V=I
M9"`B5&]P(@IM<V=S='(@(D1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*(RP@9G5Z
M>GD*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")0<F5Z96YT86-J92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B5')Y;FED
M860@:2!4;V)A9V\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y,0IM<V=I
M9"`B5')U92!O<B!F86QS92(*;7-G<W1R(")0<F%W9&$@;'5B(&9ALW-Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R
M(")4=6YE>FIA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R:V5Y(@IM<V=S='(@(E1U<F-J82(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)
M4T\M.#@U.2TY*2(*;7-G<W1R(")4=7)E8VMI("A)4T\M.#@U.2TY*2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*
M;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R(")4=7)K;65N:7-T86XB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U=F%L=2(*"B,Z(&QI8B](;W)D
M92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3<*;7-G
M:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HQ-R!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(T
M.0IM<V=I9"`B55),(@IM<V=S='(@(E523"(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED(")5
M4DPZ(@IM<V=S='(@(E523#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B
M56=A;F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:6YA(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S4*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C
M>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X
M=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R
M("(B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,P
M."!L:6(O5D93+VUU<W%L+G!H<#HT-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@
M>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G
M<W1R(")"L[%D('!O9&-Z87,@>FUI86YY(&1O("5S+B(*"B,Z(&QI8B](;W)D
M92]!=71H+W-Q;"YP:'`Z,S<Q"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T
M;R!344P@<V5R=F5R+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@
M<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-38*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@
M4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,34X(&QI8B]61E,O9FEL92YP
M:'`Z,38S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$X.`HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HQ.3,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z,S`S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*
M;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@
M4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<W(&QI8B]61E,O;75S<6PN
M<&AP.C(U."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR-#@*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC
M.B!L:6(O5D93+VUU<W%L+G!H<#HQ,C0*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"S
ML6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HQ.3@*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S
M:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+W1A
M<BYP:'`Z-S8@;&EB+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C<Y"FUS9VED
M(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@<F]Z<&%K;W=Y=V%N:6$@9&%N>6-H+B(*"B,Z(&QI8B]61E,O9G1P
M+G!H<#HR,S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M
M(%-13"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Y(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S
M(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C(U-"!L:6(O5D93+VUU<W%L+G!H<#HS,3$@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S(V"B,Z(&QI8B]61E,O<W%L+G!H<#HS,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(D*SL60@<&]D8WIA<R"S
ML6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0P(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R
M<VEV96QY+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@
M<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C8P(&QI8B]6
M1E,O;75S<6PN<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4*(SH@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,S0S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,S-@HC
M+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R
M96T@4U%,+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS,SD@;&EB+U9&4R]S<6PN
M<&AP.C,U,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B0K.Q9"!P;V1C
M>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93
M+V9T<"YP:'`Z,3<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P
M;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O
M5D93+V9I;&4N<&AP.C(R-B!L:6(O5D93+VUU<W%L+G!H<#HQ-C<@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3@P"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$X-R!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS-S`@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S<X
M"B,Z(&QI8B]61E,O<W%L+G!H<#HR,3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"S
ML6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+U9&4R]S<6PN
M<&AP.C,R.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(")"L[%D('!O
M9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HW,C`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!D971E
M<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(D*SL60@<&]D8WIA
M<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV,#,*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B4WIC>F5G
M\[-Y(&-E<G1Y9FEK871U(@H*(SH@;&EB+TYE="])35-0+G!H<#HT-3$@;&EB
M+TYE="])35-0+T%U=&@N<&AP.C$Q-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,CD@;&EB+U9&4R]F:6QE+G!H
M<#HQ,S0@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34X"B,Z(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$V,PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&UO=F4@
M5D93(&9I;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R!Z;6EA;GD@=7-T87=I
M9?$N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#4@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3(R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R-0HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N(@IM
M<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!3
M44PN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HV-R!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4N(@IM<V=S='(@(D*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W
M97)E;2!344PN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@
M87)C:&EV92XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S('IM:6%N>2!U<W1A=VEE
M\2XB"@HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*
M(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R
M(")"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z-3DR"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR.#4*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C4Q
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@L[%C
M>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HR.#$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")"L[%D('!O9&-Z87,@
ML[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@4U%,+B(*"B,Z(&QI8B]61E,O9FEL
M92YP:'`Z-3,S(&QI8B]61E,O;75S<6PN<&AP.C(R.0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E
M<F5M(%-13"XB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&4R]M
M=7-Q;"YP:'`Z-#4R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(W-PHC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HR.3,@;&EB+U9&4R]S<6PN<&AP.C(T-0HC+"!F
M=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB
M"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(D*S
ML60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!344PN(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@
M(DYI92!M;[]N82!P<GIE=+-U;6%C>GGF('1E9V\@9&]K=6UE;G1U(%=O<F0M
M82(*"B,Z(&QI8B]61E,O9G1P+G!H<#HQ,C(@;&EB+U9&4R]F='`N<&AP.C$R
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE
M;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE
M;FEA('-IZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!L:6(O5D93+V9I;&4N<&AP
M.C(P.2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S`@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82XB"FUS9W-T<B`B0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-I
MZB!Z('-E<G=E<F5M(%-13"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P"B,L(&9U>GIY"FUS9VED(")5;F1E<FQI;F4B
M"FUS9W-T<B`B3V1T=_-R>B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC
M.C8*;7-G:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R(")#;V9N:6H@>FUI86YY
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,PHC+"!F=7IZ>0IM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS
M9W-T<B`B5WIN\W<@<W=O:K$@<V5S:NHB"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S<X(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN
M8SHV-`HC+"!F=7IZ>0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")P;&EK(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%54
M1BTX*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI=&5D($%R86(@16UI<F%T97,B
M"FUS9W-T<B`B6FIE9&YO8WIO;F4@16UI<F%T>2!!<F%B<VMI92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I
M9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B5VEE;&MA($)R>71A;FEA(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B56YI=&5D(%-T871E<R(*;7-G<W1R(")54T$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8Q(&QI8B]"
M;&]C:R]M971A<BYP:'`Z-S$*;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C4X(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0Q.`HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT
M,3D*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B3FEE>FYA;F4B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.`IM<V=I9"`B56YK;F]W
M;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30V"B,L(&9U>GIY
M"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").
M:65Z;F%N>2!A9')E<V%T(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.3$*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(E!R;W-ZZB!P;V1AYB!N87IWZB!UOWET
M:V]W;FEK82!I(&AA<[-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"B,L(&9U>GIY"FUS9VED(")5;FQI
M;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")5<W7Q(@H*(SH@;&EB
M+TAO<F1E+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T
M<B`B0F5Z(&YA>G=Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@
M8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@
M9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T
M96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y
M;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O
M87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@R"B,L(&9U>GIY"FUS9VED(")5;G-E="!C
M;VQO<B(*;7-G<W1R(")$;VUYMFQN>2!K;VQO<B(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-C@V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M.3(V"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5
M;G-U<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B3FEE;V)SLW5G:7=A;F4@
M<F]Z<WIE<GIE;FEE(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3`V(&QI
M8B](;W)D92]097)M<R]522YP:'`Z,3@S"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B56%K='5A
M;&YI:B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S$*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R
M(")$;V1A:B!UOWET:V]W;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92!U<V5R(@IM
M<V=S='(@(D1O9&%J('6_>71K;W=N:6MA(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ,S<@861M:6XO<&5R;7,O961I="YP:'`Z,C$W('-E<G9I8V5S+W-H87)E
M<R]E9&ET+G!H<#HR,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5P
M9&%T960@7"(E<UPB+B(*;7-G<W1R(")$;V1A:B!UOWET:V]W;FEK82(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Q"B,L(&9U>GIY"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(").:64@=WEG96YE<F]W
M86YO(+]A9&YE9V\@<VMR>7!T=2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#(*
M;7-G:60@(E5P;&]A9"(*;7-G<W1R("):8;-A9'5J(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C$X.0IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI8V%T
M:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.`HC+"!F=7IZ>0IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R(")'<G5D>FEE\2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B
M57)U9W=A:B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`B57-U\2!O8F5C;F4@:VQU8WIE(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(T"FUS9VED
M(")5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C8Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,C`S"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S
M='(@(D%D;6EN:7-T<F%C:F$@=;]Y=&MO=VYI:_-W($AO<F1E(@H*(SH@;&EB
M+TAO<F1E+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*
M;7-G<W1R(")/<&-J92!UOWET:V]W;FEK82(*"B,Z('-I9VYU<"YP:'`Z-C(*
M;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E:F5S=')A8VIA
M('6_>71K;W=N:6MA(@H*(SH@<VEG;G5P+G!H<#HR,@HC+"!F=7IZ>0IM<V=I
M9"`B57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92XB"FUS9W-T<B`B3V)SLW5G82!F:6QT<O-W(&IE<W0@=WFSL6-Z
M;VYA(&YA('1Y;2!S>7-T96UI92XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HQ-S(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-#8*(RP@9G5Z>GD*;7-G
M:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B1&]M>;9L;F4@=7!R87=N
M:65N:6$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3@R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S8@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y."!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C8X('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS
M9VED(")5<V5R;F%M92(*;7-G<W1R(").87IW82!UOWET:V]W;FEK82(*"B,Z
M(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB"FUS9W-T
M<B`B5;]Y=&MO=VYI:R!O(&YA>G=I92!<(B5S7"(@:G6_(&ES=&YI96IE+B(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E
M<FYA;64Z(@IM<V=S='(@(DYA>G=A('6_>71K;W=N:6MA.B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS
M9W-T<B`B3F%Z=V$@=;]Y=&MO=VYI:V$Z("(*"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C$Y"B,L(&9U>GIY"FUS9VED(")5<V5R<R(*;7-G<W1R(").
M87IW82!UOWET:V]W;FEK82(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@
M(E6_>71K;W=N:6-Y('<@<WES=&5M:64Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A
M;B(*;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ
M,#$@;&EB+U9&4R]F:6QE+G!H<#HQ.#@*(RP@9G5Z>GD*;7-G:60@(E9&4R!D
M:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D]K<F6V;&]N>2!P
M;&EK(&YI92!I<W1N:65J92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")786MA8VIE(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C@V-@IM<V=I9"`B5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O
M9B`E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#4@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C<@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M,34*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C<*(RP@9G5Z>GD*;7-G:60@
M(E9A;'5E<R(*;7-G<W1R(")5=V%G:2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR,3$P(&QI8B](;W)D92]&;W)M+G!H<#HR,3@W"FUS9VED(")686QU97,@
M=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*
M;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S,@HC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B5WFS
ML6-Z;VYE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E=E;F5Z=65L
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")6
M97)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E
M96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB"FUS9W-T<B`B5V5R
M<VIA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-0HC+"!F=7IZ
M>0IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E]5<')A=VYI96YI
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S
M='(@(E1Y;&MO('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX-`HC+"!F=7IZ>0IM<V=I9"`B5F5R=&EC86P@<&%D
M9&EN9R(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*;7-G:60@(E9E
M<G1I8V%L.B(*;7-G<W1R(")4>6QK;R!T96MS="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"B,L(&9U>GIY"FUS9VED(")6
M97)Y($AI9V@B"FUS9W-T<B`B5WES;VMI(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB
M"FUS9W-T<B`B5VEE=&YA;2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT
M"FUS9VED(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")7:61O:R`E<R(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B4&]K8;\@<W1R;V[J(%=75R(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE
M=R!A<R`E<R(*;7-G<W1R(")0;VMAOR!J86MO("5S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B0G)Y='EJ<VMI92!7>7-P
M>2!$>FEE=VEC>F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*
M;7-G<W1R(")7>7-P>2!$>FEE=VEC>F4@4W1A;O-W(%IJ961N;V-Z;VYY8V@B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET
M>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C4Q"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TYE
M="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B5F]D869O
M;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V"FUS9VED(")705).
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L
M('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-
M04Y504Q,62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@
M86YD($9U='5N82(*;7-G<W1R(")786QL:7,@:2!&=71U;F$B"@HC.B!L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,CD*;7-G
M:60@(E=A<FYI;F<B"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"B,L(&9U>GIY"FUS
M9VED(")792(*;7-G<W1R(")75U<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-0IM<V=I9"`B
M5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HX.3(*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS
M9W-T<B`B5U=7(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W-@HC
M+"!F=7IZ>0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B55),('-T<F]N>2(*
M"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML
M>2(*;7-G<W1R(")#;R!T>61Z:67Q(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO
M8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B5VET86UY(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C4S"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@
M=&\@)7,B"FUS9W-T<B`B5VET86UY('<@)7,B"@HC.B!S97)V:6-E<R]P;W)T
M86PO;6]B:6QE+G!H<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5VET
M86UY+"`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")7
M97-T97)N("A)4T\M.#@U.2TQ*2(*;7-G<W1R("):86-H;V1N:2`H25-/+3@X
M-3DM,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S
M=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(EIA8VAO9&YI("A)4T\M.#@U
M.2TQ-2DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B"FUS9W-T<B`B4V%H87)A
M(%IA8VAO9&YI82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2F%KL2!A<&QI:V%C:NH@
M;6$@)7,@=WFV=VEE=&QAYB!P;R!Z86QO9V]W86YI=2!S:>H_(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(E=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(T"FUS9VED(")7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B2F%K
M:64@=W1Y8WIK:2!A:W1Y=V]W8>8@=R!2;WIB=61O=V%N>6T@961Y=&]R>F4@
M=&5K<W1U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(@IM<V=S='(@
M(D]S=')Z9;]E;FEE(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C0*(RP@
M9G5Z>GD*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R("),:71W
M82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A
M:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*(E-Z97)O
M:V^VYB!L97=E9V\@;65N=2`E<R`H>FUI86YA('IA8WIN:64@;V)O=VFQ>GEW
M8>8@<')Z>2!N87-TZG!N>6T@(@HB;&]G;W=A;FEU*3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-@IM<V=I9"`B5VED
M=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"B,L(&9U>GIY"FUS9VED(")7
M:61T:"!U;FET(@IM<V=S='(@(DQI='=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*;7-G:60@(E=I
M9'1H.B(*;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HT-C@*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X."!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HV-0HC+"!F=7IZ>0IM<V=I9"`B5VEN9"(*
M;7-G<W1R(")/<W1R>F6_96YI92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY
M(@IM<V=S='(@(D]S=')Z9;]E;FEE(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B5VEN
M9#HB"FUS9W-T<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C,P"B,L(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T
M<B`B3W-T<GIEOV5N:64B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3@R"B,L(&9U>GIY"FUS9VED(")7:7-H;&ES=',B"FUS9W-T
M<B`B0FEALV$@;&ES=&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*
M(RP@9G5Z>GD*;7-G:60@(E=O<FLB"FUS9W-T<B`B;'5B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R(")!9')E<R!D;R!P<F%C>2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(E1E
M;"X@9&\@<')A8WDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,Q
M"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DR
M"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8X,@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(E)2(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#(W"FUS9VED(")965E9(@IM<V=S='(@(E)24E(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P,0IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4V
M"FUS9VED(")996%R;'DB"FUS9W-T<B`B0V\@<F]K(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M
M96XB"FUS9W-T<B`B2F5M96XB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#@U"FUS9VED(")997,B"FUS9W-T<B`B5&%K(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R(")486LL('IG861Z86T@<VGJ
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3(Y-PIM<V=I9"`B66]U(&%R92!N;W0@875T
M:&5N=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y
M+G!H<#HS,#(*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA
M<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@U-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-@HC
M+"!F=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+B(*;7-G<W1R(")4=_-J(&%D<F5S(&4M;6%I;#HB"@HC.B!L
M:6(O2&]R9&4O1&%T82YP:'`Z,C<P"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@
M9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,C,*;7-G:60@(EEO
M=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B5WEL;V=O=V&S9;8@
M<VGJ+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B"B)9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I
M9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@:6YT
M97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q.#@*(RP@9G5Z>GD*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(E1W\VH@861R97,@
M92UM86EL.B(*"B,Z(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,S<*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@(D)R86L@:V]N9FEG=7)A
M8VII('=E=V[J=')Z;F5J(&1L82!T96=O(&AO<W1A(@H*(SH@;&EB+TAO<F1E
M+G!H<#HT,S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A
M(%9&4R!B86-K96YD+B(*;7-G<W1R(")"<F%K(&MO;F9I9W5R86-J:2!W97=N
MZG1R>FYE:B!D;&$@=&5G;R!H;W-T82(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B375S:7-Z(&]P:7-AYB!P<F]B;&5M('IA;FEM(&=O('=Y
MMFQE<WHN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHY.`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O(@IM<V=S='(@(DUU<VES>B!W
M<')O=V%D>FGF('!R>GEN86IM;FEE:B!J961N96=O(&%D<F5S871A+B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"B,L(&9U>GIY"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(DUU<VES>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C
M:&-E<WH@=7-U;K'F+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0HC+"!F=7IZ
M>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R
M(&]U="XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K
M=/-R96=O(&-H8V5S>B!U<W5NL>8N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+B(*;7-G<W1R(")-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E
M9V\@8VAC97-Z('5S=6ZQYBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HV,B!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*;7-G:60@(EEO=2!M=7-T
M('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB"FUS9W-T<B`B375S:7-Z
M(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!D;V1AYBXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-#8*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B
M375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!D
M;V1AYBXB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HQ,S@*(RP@
M9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@
M<&5R9F]R;2XB"FUS9W-T<B`B375S:7-Z(&]K<F6V;&GF('6_>71K;W=N:6MA
M+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N(@H*(SH@;&EB+TAO<F1E+U!R969S
M+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S(*(RP@9G5Z>GD*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B375S:7-Z
M(&]K<F6V;&GF('6_>71K;W=N:6MA+"!K=/-R96=O(&-H8V5S>B!U<W5NL>8N
M(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM
M<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU
M;6)E<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$Q"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E
M9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!
M9&1R97-S(@IM<V=S='(@(E1W\VH@861R97,@92UM86EL(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I9"`B66]U<B!&<F]M.B!A9&1R97-S
M.B(*;7-G<W1R(")4=_-J(&%D<F5S($]D.B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S0@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX.0IM
M<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")4=V]J92!I;F9O<FUA
M8VIE(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDQ-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*
M(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M(@IM<V=S='(@(B(*(E1W\VH@861R97,@:6YT97)N971O=WD@<VGJ('IM:65N
M:;,@;V0@<&]C>K%T:W4@<V5S:FD@)7,N(%<@>G=IL7IK=2!Z("(*(F)E>G!I
M96-Z9?%S='=E;2!4=V]J96=O(&MO;G1A(&UU<VES>B!Z86QO9V]W8>8@<VGJ
M('!O;F]W;FEE+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B5'=O:F4@:6UIZB(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHY"FUS9VED("(B"B)9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A
M9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T<B`B(@HB5&5N('-Y
M<W1E;2!A=71E;G1Y:V%C:FD@;FEE(&]B<[-U9W5J92!D;V1A=V%N:6$@=;]Y
M=&MO=VYI:_-W+"!L=6(@=&$@;W!C:F$@(@HB>F]S=&&S82!W>;.Q8WIO;F$N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHY"FUS9VED
M("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P
M<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*
M(E1E;B!S>7-T96T@875T96YT>6MA8VII(&YI92!O8G.S=6=U:F4@;&ES=&]W
M86YI82!UOWET:V]W;FEK\W<L(&QU8B!T82!O<&-J82`B"B)Z;W-T8;-A('=Y
ML[%C>F]N82XB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3$Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T
M;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(E1W\VH@861R97,@:6YT97)N
M971O=WD@<VGJ('IM:65N:;,@;V0@<&]C>K%T:W4@<V5S:FD@)7,N(%<@>G=I
ML7IK=2!Z("(*(F)E>G!I96-Z9?%S='=E;2!4=V]J96=O(&MO;G1A(&UU<VES
M>B!Z86QO9V]W8>8@<VGJ('!O;F]W;FEE+B(*"B,Z(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM<V=S='(@(B(*(E1W;VIA('!R
M>F5G;+%D87)K82!N:64@;V)SLW5G=6IE('=YMG=I971L86YI82!P;&EK\W<@
M9W)A9FEC>FYY8V@@=&5G;R!T>7!U+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+W!R:6YT+FIS.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S
M97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@
M0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB
M5'=O:F$@<')Z96=LL61A<FMA(&YI92!O8G.S=6=U:F4@=&5J(&]P8VII(&1R
M=6MO=V%N:6$N($YA:F-IMFYI:B!#=')L+T]P8VIA("(*(BL@4"!A8GD@=WED
M<G5K;W=AYBXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0Y"FUS9VED
M(")9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.B(*;7-G<W1R(")4=V]J82!O8F5C
M;F$@<W1R969A(&-Z87-O=V$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$U,`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")$
M;VUYMFQN82!T;[]S86UOMN8Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Y,PIM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E1W;VIE('!E
MLVYE(&EM:>H@:2!N87IW:7-K;SHB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(E1W;VEM(&YO=WEM(&AA<[-E
M;2!W("5S(&IE<W0Z("5S(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ
M-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@
M=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B5'=O:F4@
M=7-T87=I96YI82!Z;W-T8;-Y('5A:W1U86QN:6]N92!N82!C>F%S('1R=V%N
M:6$@=&5J('-E<VII+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V
M"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S
M='(@(E1W;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U86MT=6%L;FEO;F4N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*(RP@9G5Z>GD*;7-G
M:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B5'=O
M:6T@;F]W>6T@:&%SLV5M('<@)7,@:F5S=#H@)7,B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@
M<V5R=F5R<SHB"FUS9W-T<B`B5'=O:F4@>F1A;&YE('-E<G=E<GDZ(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W.S87=I
M82(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I
M<F4B"FUS9W-T<B`B6F%I<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):
M86UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)W92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO
M8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z-38*;7-G:60@(EM0<F]B;&5M
M(%)E<&]R=%TB"FUS9W-T<B`B6U)A<&]R="!O('!R;V)L96UI95TB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B
M6U-H;W<@475O=&5D(%1E>'0@+2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G<W1R("(E<R!D;R`E
M<R!Z("5S(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#0Q('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")?061M:6YI<W1R86-J82(*"B,Z(&QI8B]A<&DN<&AP.C$S-@IM<V=I9"`B
M7T-,22(*;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,3(T"B,L(&9U
M>GIY"FUS9VED(")?1&%T851R964B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM
M<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B7U5S=?$@=VEE<G-Z(@H*(SH@
M;&EB+V%P:2YP:'`Z,3$V"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(E]'<G5P
M>2(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM
M<V=S='(@(E]0;VUO8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PHC+"!F=7IZ>0IM<V=I9"`B7TEM86=E
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5&5L+B!K;VTN(@H*(SH@;&EB+TAO
M<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")?6F%L
M;V=U:B(*"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@
M;W5T(@IM<V=S='(@(E]7>6QO9W5J(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y
M($QI;FLN+BXB"FUS9W-T<B`B6FUI9?$@;&EN:RXN+B(*"B,Z(&QI8B](;W)D
M92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/<&-J
M92(*"B,Z(&QI8B]A<&DN<&AP.C$R,`IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM
M<V=S='(@(E]5<')A=VYI96YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,
M:6YK+BXN(@IM<V=S='(@(E5S=?$@;&EN:RXN+B(*"B,Z(&QI8B]A<&DN<&AP
M.C$P.`IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]+;VYF:6=U<F%C:F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(E1E;"X@:V]M+B(*"B,Z(&QI8B]A<&DN<&AP.C$Q,@IM<V=I9"`B
M7U5S97)S(@IM<V=S='(@(E]5OWET:V]W;FEC>2(*"B,Z(&QI8B](;W)D92]+
M;VQA8BYP:'`Z.#DP"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B:W-I
ML;]K82!A9')E<V]W82(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#@R"FUS
M9VED(")C86QE;F1A<B(*;7-G<W1R(")K86QE;F1A<GHB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HU.#D*;7-G:60@(F-L:6-K(&AE<F4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T)R;W=S97(N<&AP.C@U.0IM<V=I9"`B9FEL92(*;7-G<W1R(")P;&EK(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S0@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T
M<B`B)7,@9&\@)7,@>B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S@*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B4VEE
M<G!I9?$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,R"FUS9VED(")H.B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S,Q"FUS9VED(")H:"(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(FEN;&EN92(*;7-G
M<W1R(").86>S\W=K:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$S"B,L(&9U>GIY"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B
M3F%GL_-W:VDB"@HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,T,@IM<V=I9"`B;6TB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR.#@@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C(P-0IM<V=I9"`B;F%M92(*;7-G<W1R(").87IW
M:7-K;R(*"B,Z(&QI8B](;W)D92]24$,N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I
M9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(E5K;_%C>F]N92(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(Q.0HC+"!F=7IZ>0IM<V=I9"`B
M;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")482!O<&-J82!N:64@:F5S
M="!J97-Z8WIE('IAL[%C>F]N82XB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C@W-`IM<V=I9"`B;F]T97!A9"(*;7-G<W1R(")N;W1A=&YI:R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#@*
M(RP@9G5Z>GD*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B1')U:W5J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I
M;F<B"FUS9W-T<B`B3W)G86YI>F%T;W(B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*;7-G:60@
M(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S4X"FUS9VED(")S<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@HC+"!F=7IZ>0IM<V=I9"`B<W1E861Y(@IM<V=S='(@(DYO=&%T;FEK("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3@*(RP@9G5Z>GD*;7-G:60@
M(G1A<VL@;&ES="(*;7-G<W1R(")#>F%R;F$@;&ES=&$B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(V.0HC+"!F
M=7IZ>0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;2(*;7-G<W1R(")(87.S;R(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")U;FEF
M:65D(@IM<V=S='(@(G!L:6LB"@HC.B!L:6(O2&]R9&4O34E-12]087)T+G!H
M<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R(")B97H@;F%Z=WDB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R
M('-E;&5C="(*;7-G<W1R(")7>6+S<B!K;VQO<G4B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R
M(")V0V%R9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,C0*(RP@9G5Z>GD*;7-G:60@(G<Z(@IM<V=S='(@(D9W9#HB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC
M;VTB"FUS9W-T<B`B(@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O
M:VU?2T@N<&\`````````````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P-C0P-S(T(#$P-3$U-#,T,30R(#`Q-S4Q-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````C(%-/344@1$53
M0U))4%1)5D4@5$E43$4N"B,@0V]P>7)I9VAT("A#*2!914%2($AO<F1E(%!R
M;VIE8W0*(R!4:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A
M;64@;&EC96YS92!A<R!T:&4@4$%#2T%'12!P86-K86=E+@HC($QE86YG($-H
M=6US;V)E;B`\<V]B96Y`:VAM97)O<RYI;F9O/BP@,C`P-BX*(PIM<V=I9"`B
M(@IM<V=S='(@(B(*(E!R;VIE8W0M260M5F5R<VEO;CH@24U07&XB"B)03U0M
M0W)E871I;VXM1&%T93H@,C`P-"TQ,BTP."`Q,#HR."LP,3`P7&XB"B)03RU2
M979I<VEO;BU$871E.B`R,#`U+3`V+3$U(#$Q.C4S*S`W,#!<;B(*(DQA<W0M
M5')A;G-L871O<CH@3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE<F]S+FEN
M9F\^7&XB"B),86YG=6%G92U496%M.B!+:&UE<B`\<W5P<&]R=$!K:&UE<F]S
M+FEN9F\^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E
M.B!T97AT+W!L86EN.R!C:&%R<V5T/75T9BTX7&XB"B)#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y<R!A9V\I
M(@IM<V=S='(@(B`H)7,@X9Z0X9^2X9Z$X9^#XH"+X9Z`X9Z3X9^2X9Z;X9Z$
MXH"+X9Z1X9^%*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,3,X
M-@HC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T
M<B`B("CAGH+AGY+AGIKAGK;AGI3AGXOB@(OAGH7AGKOAGH7B@(OAGI7AGY+A
MGIOAGKSAGISB@(OAGH#AGK;AGH_AGXL@)7,I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED("(@*&EN("5S
M(&1A>7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S.#$*;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`HX9Z0X9^2X9Z$X9^#
MXH"+X9Z3X9^!X9^'*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M.#,*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`HX9Z0X9^2X9Z$X9^#
MXH"+X9Z?X9^2X9ZBX9^"X9Z`*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S-SD*;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*.&>F.&?
MDN&>G^&>M^&>F^&>F.&?B>&>M^&>B2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C4P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-3,*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.0IM<V=I9"`B
M(&%T("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER
M96-T;W)Y+B(*;7-G<W1R(")<(B5S7"(@X9Z8X9ZWX9Z3XH"+X9Z8X9^"X9Z3
MXH"+X9Z'X9ZVXH"+X9Z0X9Z/XH"+X9ZAX9Z^X9Z9PJ#AGY0B"@HC.B!F<F%M
M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(EPB
M)7-<(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(EPB)7-<(B#A
MGICAGK?AGI/B@(OAGICAGX+AGI/B@(OAGH?AGK;B@(OAGH?AGICAGY+AGIKA
MGK[AGI_B@(OAGH_AGY+AGIKAGKGAGICAGH_AGY+AGIKAGKSAGISB@(OAGJ'A
MGK[AGIG"H.&?E"(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z-S`S"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`Z,3`W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O
M;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G
M:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E
M)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T
M<B`B)60@)7,@X9Z3X9ZWX9Z$("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HR-C<@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@
M97AP:7)E<RXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A
M<W0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C8X
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`U"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T,B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX-#`@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z.#0V"B,L('!H<"UF;W)M870*;7-G:60@(B5S($U"(@IM
M<V=S='(@(B5S(.&>F.&?@>&>@.&>MN&>E.&?@R(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C(Q-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C0Y-`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X
M,B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ-S$@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S<@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3$*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-3<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I
M;G1E;F%N8V4N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A
M=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T.`HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!M:6YU=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S
M(&]F("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP
M:'`Z.3(Q"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@5&%S:VQI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF
M:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,@X9^6("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@
M=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U-R!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`R"FUS9VED("(L(&=U<W1I
M;F<@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`P(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C`U"B,L('!H<"UF;W)M870*;7-G:60@(BP@
M9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(Q,PHC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR.30@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W-R!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3,V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HW-#8*;7-G:60@(BTM('-E;&5C="`M+2(*;7-G<W1R("(M
M+2#AGH?AGY+AGIKAGK[AGI\@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,C4*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(N&>D>&?DN&>FN&>
MA.&?B^&>D>&?DN&>FN&>MN&>F2#AGZ'AGZ(@X9Z8X9^)X9^$X9Z$(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C(T"FUS9VED("(R-"!(;W5R($9O<FUA="(*
M;7-G<W1R("+AGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGID@X9^BX9^D
M(.&>F.&?B>&?A.&>A"(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X
M"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("+AGZ+AGZ0@X9Z8X9^)X9^$X9Z$
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R
M979I;W5S(@IM<V=S='(@(CSAGICAGKOAGI,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$S,0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$V,@IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED
M96YT:71Y+G!H<#HT,#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB02!M97-S
M86=E(&AA<R!B965N('-E;G0@=&\@7"(E<UPB('1O('9E<FEF>2!T:&%T('1H
M:7,@:7,@<F5A;&QY('EO=7(@(@HB861D<F5S<RX@5&AE(&YE=R!E;6%I;"!A
M9&1R97-S(&ES(&%C=&EV871E9"!A<R!S;V]N(&%S('EO=2!C;VYF:7)M('1H
M:7,@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38X"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`V"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-
M($QI9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*
M;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3,*;7-G:60@(D%B;W5T
M+BXN(@IM<V=S='(@(N&>HN&?AN&>EN&>N.*`BRXN+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O
M='1O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<R"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I9"`B06-C;W5N="!);F9O
M<FUA=&EO;B(*;7-G<W1R("+AGI;AGY#AGH_AGXSAGICAGK;AGI/B@(OAGJ+A
MGX;AGI;AGKCAGH+AGH[AGI/AGK@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S@*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS
M"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T.0IM<V=I9"`B06-C;W5N=&EN9R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T."!T
M96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("+A
MGI3AGI/AGY+AGI#AGX+AGI@B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A
M9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H
M:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB)7-<(B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM
M<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU-30*;7-G:60@(D%D9"!C
M;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E
M9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P
M86ER(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HW,0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@
M=7-E<B(*;7-G<W1R("+AGI3AGI/AGY+AGI#AGX+AGICB@(OB@(OB@(OAGJ+A
MGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKXB"@HC.B!A9&UI;B]U<V5R+G!H<#HW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE
M('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@
M:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@
M<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@
M=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#0Y"FUS9VED(")!9&1R97-S(@IM<V=S='(@(N&>HN&>MN&>
MG^&>F>&>BN&?DN&>B^&>MN&>DR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ-#@*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+AGI_AGX#A
MGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI,B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B
M"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM
M<V=S='(@(N&>@.&>MN&>FN*`B^&>@N&?DN&>FN&>E.&?B^*`B^&>@N&?DN&>
MFN&>A"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3<*;7-G:60@
M(D%D<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A
M;B(*;7-G<W1R("+AGJ+AGK;AGJ#AGY+AGH+AGK;AGI/AGKCAGI_AGY+AGI#A
MGK;AGI,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(N&>
MHN&>MN&>F^&?B^&>E.&>MN&>D^&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L
M9V5R:6$B"FUS9W-T<B`BX9ZBX9ZVX9Z;X9^+X9Z@X9^2X9Z?X9^!X9Z:X9ZX
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M-PIM<V=I9"`B06QI87,B"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z`
MX9^2X9Z;X9^"X9Z$X9Z`X9^2X9Z;X9ZVX9Z9(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`BX9Z/X9Z8X9^2X9Z:X9ZYX9Z8(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM
M96YT.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*
M;7-G:60@(D%L;"(*;7-G<W1R("+AGI'AGK;AGX;AGH3B@(OAGJ+AGI_AGXLB
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E
M9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(R"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I
M9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-SD*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED(")!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,3@*;7-G:60@
M(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L
M=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N
M86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+A
MGI3AGY+AGHKAGKSAGIKB@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B
M@(OAGJ+AGXKAGKCAGICAGX+AGILB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$T,@IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C4*;7-G:60@(D%L=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("+AGI_A
MGK;AGICAGKSAGJ+AGK8@X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z`(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@
M<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38P"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM
M<V=S='(@(N&>HN&>A.&?B^&>BN&>O.&>FN&?B>&>MB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*
M;7-G:60@(D%N9V]L82(*;7-G<W1R("+AGJ+AGH3AGXOAGJ#AGY+AGH+AGX3A
MGJ'AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R("+A
MGJ+AGH3AGXOAGJ#AGY+AGI_AGXKAGKCAGJ'AGK8B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-#D*
M;7-G:60@(D%N<W=E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!
M;G1A<F-T:6-A(@IM<V=S='(@(N&>E^&>MN&>@N*`B^&>@>&>MN&>A.*`B^&>
MC^&?DN&>E.&>O.&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@86YD
M($)A<F)U9&$B"FUS9W-T<B`BX9ZBX9Z$X9^+X9Z1X9ZXX9Z@X9^2X9Z"X9ZV
M(.&>D^&>M^&>A"#AGI3AGK;AGI3AGXKAGKOAGIGAGHKAGK8B"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI
M;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S
M='(@(N&>@.&>F.&?DN&>F.&>G.&>M^&>DN&>N"(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L
M:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#0R"FUS9VED(")!<'!R;WAI;6%T92!3:7IE
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8X"FUS9VED(")!<')I;"(*;7-G<W1R("+AGICAGX'AGI_AGK8B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W,0IM<V=I9"`B07)A8FEC("A7
M:6YD;W=S+3$R-38I(@IM<V=S='(@(N&>HN&>MN&>FN&?B>&>MN&>E.&?BR`H
M5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<X
M"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E
M9"YI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N
M:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B
MX9ZBX9ZVX9Z@X9^2X9Z?X9Z$X9^+X9Z1X9ZXX9Z3(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B07)M96YI82(*;7-G<W1R("+AGJ+AGK;AGICAGX'AGI/AGK@B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W,@IM<V=I9"`B07)M96YI86X@*$%2
M35-#24DM."DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,S"FUS9VED(")!<G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B
M07)U8F$B"FUS9W-T<B`BX9ZBX9ZVX9Z:X9Z\X9Z4X9ZV(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0R.0IM<V=I9"`B
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,#8*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-3,*;7-G:60@(D%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<Q"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B
M"FUS9W-T<B`BX9Z"X9Z[X9Z.X9Z;X9Z`X9^2X9Z!X9Z.X9^((@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-PHC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U
M9W5S="(*;7-G<W1R("+AGI_AGKCAGJ#AGK8B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`BX9ZBX9Z\X9Z?X9^2X9Z/X9^2X9Z:X9ZV
MX9Z;X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')I82(*;7-G<W1R("+A
MGJ+AGKSAGI'AGY+AGIKAGKCAGI\B"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G-Q;"YP:'`Z,S$V"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@
M:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S$*;7-G:60@(D%U=&A?8WER
M=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E
M<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP
M:'`Z,C,T"FUS9VED(")!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O9G1P+G!H<#HU-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P-`IM<V=I9"`B075T:%]I;6%P
M.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S,*;7-G:60@
M(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP
M.C,P,0IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-@IM<V=I9"`B075T:%]L
M9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z.3(*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!
M4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,S.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@
M(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#DX"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U
M<V5R("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z-#`T"FUS9VED(")!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-C(*;7-G:60@
M(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z
M.#8*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%D;6EN+G!H<#HQ,#8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&%T
M($E-05`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z5
MX9^2X9Z1X9^`X9Z$XH"+X9Z5X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z7X9ZVX9Z6
MXH"+X9Z/X9^2X9Z:X9ZYX9Z8XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZV
MX9Z3XH"+X9Z4X9Z:X9ZVX9Z'X9^0X9Z9(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3@R"FUS9VED
M(")!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@X,@IM
M<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`*;7-G
M:60@(D%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM
M<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R("+AGJ+AGK;AGJ#AGY+AGI_A
MGXKAGX+AGIKAGI3AGX+AGJ#AGY+AGI_AGH3AGXLB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D)/1D@@17AC=7-E<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(N&>E>&?DN&>D>&?
M@^*`B^&>@>&>MN&>A.*`B^&>@.&?DN&>FN&?A.&>F2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C,*;7-G:60@(D)A8VMG
M<F]U;F0@0V]L;W(B"FUS9W-T<B`BX9Z6X9Z.X9^,XH"+X9Z5X9^2X9Z1X9^#
MXH"+X9Z!X9ZVX9Z$XH"+X9Z`X9^2X9Z:X9^$X9Z9(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX,@IM<V=I9"`B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@T"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`BX9Z4
MX9ZVX9Z@X9ZVX9Z8X9^)X9ZVX9Z?(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H
M<F%I;B(*;7-G<W1R("+AGI3AGK;AGIKAGXGAGX+AGI,B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W,PIM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G
M<W1R("+AGI3AGH3AGXOAGH#AGY+AGIOAGK;AGHKAGX'AGI_AGY+AGJ`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R("+AGI3AGK;AGIKA
MGI3AGK;AGHKAGKSAGI\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@
M7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<S"FUS9VED(")"87-E
M;&EN92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM
M<V=S='(@(N&>E.&?@>&>H>&>MN&>FN&>N^&>G^&?DN&>GR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T<B`BX9Z4X9^"X9Z;XH"+X9Z@X9^2
MX9Z?X9^*X9ZWX9Z`(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S
M='(@(N&>E.&?@>&>F^&>N.&>H.&?DN&>GR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(N&>E.&?@>&>CN&>MN&?AN&>A"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`BX9Z4X9^*X9^!X9Z:X9Z8X9Z\
MX9Z*X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(N&>
ME.&?BN&>O.&>C^&>MN&>DR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(N&>
MD.&?DN&>A.&?@^&>@.&?AN&>CN&>ON&>CR(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHY,`IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<R"FUS9VED(")";&]C:R!4>7!E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("+AGHKAGK?AGH\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")";VQI=FEA(@IM<V=S='(@(N&>E.&>O.&>F^&>
MN.&>G.&>N"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G
M:60@(D)O;VMM87)K<R(*;7-G<W1R("+AGH#AGI/AGY+AGIOAGX+AGH3B@(OA
MGH7AGX;AGH[AGK;AGX8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B
MX9Z?X9^*X9Z[X9Z8(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G<W1R("+AGI_AGXKAGKOA
MGICB@(LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V
M:6YA(@IM<V=S='(@(N&>E.&>O.&>G^&?DN&>D^&?BN&>N"#AGI/AGK?AGH0@
MX9Z@X9ZZX9Z@X9^2X9Z?X9^*X9^!X9Z@X9^2X9Z"X9^$X9Z<X9ZXX9Z.X9ZV
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P,0IM<V=I9"`B0F]T:"(*
M;7-G<W1R("+AGI'AGK;AGX;AGH3B@(OAGI;AGKCAGIKB@(LB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R("+AGI3AGKOAGH_AGI_AGY+A
MGISAGK;AGH[AGK8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R("+AGI3A
MGK;AGH\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(N&>@.&?A.&?A^*`B^&>E.&?BN&>O.&>G.&?B>&?@B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R87II;"(*;7-G<W1R("+AGI3AGY+AGIKAGX'AGI_AGXKA
MGKCAGILB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y(@IM<V=S='(@(N&>HN&>MN&>CN&>MN&>A>&>@.&?DN&>
MFN*`B^&>G^&>F.&>N^&>D>&?DN&>FN*`B^&>I>&>CN&?DN&>C.&>MB#AGJ+A
MGH3AGXOAGH+AGY+AGIOAGX'AGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N
M96D@1&%R=7-S86QA;2(*;7-G<W1R("+AGI3AGY+AGIKAGXKAGKOAGIGAGH[A
MGX'B@(OAGHKAGK;AGIKAGXKAGKOAGIGAGI_AGK;AGJ'AGK;AGI@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R("+AGI3AGXKAGKOAGIOA
MGJ#AGY+AGH+AGK;AGIKAGK@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R
M("+AGI3AGXKAGKSAGIKAGH+AGKCAGH[AGK;AGJ#AGY+AGISAGK;AGI_AGKPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(N&>E.&?BN&>
MO.&>FN&>N^&>D^&>C.&>N"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-C`*;7-G:60@(D--4R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B
M0U)#(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34V"FUS9VED(")#86-H
M92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@S(&-O;F9I9R]H
M;V]K<RYP:'`N9&ES=#HQ,#4U"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HQ-C0*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(N&>E.&?DN&>FN&>C^&>
MM^&>D>&>M^&>DR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#`*;7-G:60@(D-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(N&>@.&>F.&?DN&>EN&>N^&>A^&>MB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(N&>@.&>MN&>F.&?
MB>&>MN&>FN&>O.&>DR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS-3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D
M;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C0Q(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R("+AGH#A
MGK;AGH[AGK;AGHKAGK8B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO
M=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R("+AGI3AGX3AGX?AGI3AGH3AGXLB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@
M4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E
M;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO="!P
M<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N
M<&AP.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV
M.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI
M;&1R96X@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92]S<6PN<&AP.C8R,@IM<V=I9"`B(@HB0V%N;F]T(')E;W)D
M97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O
M97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P92!697)D
M92(*;7-G<W1R("+AGH#AGK;AGI3AGISAGX+AGIHB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED(")#
M87!T:6]N(@IM<V=S='(@(N&>A>&?AN&>CN&>A.&>A^&>ON&>A"(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I
M9"`B0V%R<FEE<B(*;7-G<W1R("+AGISAGH_AGY+AGI#AGKOB@(OAGHKAGKGA
MGH#B@(OAGH?AGHGAGY+AGH?AGKSAGI,B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z.3,*;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T
M<B`BX9Z`X9^$X9^'XH"+X9Z`X9^#X9Z8X9^)X9ZVX9Z3(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L
M;"!0:&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I
M97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,0IM<V=I9"`B0V5L;"!P<F]P97)T:65S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS
M9VED(")#96QL('-P86-I;F<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B0V5L=&EC("A)
M4T\M.#@U.2TQ-"DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM
M<V=S='(@(N&>@.&>CN&?DN&>C^&>MN&>FR(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R("+AGI_AGK;AGI+A
MGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGJ#AGY+AGISAGY+AGIKA
MGK?AGH#B@(OAGH#AGH[AGY+AGHKAGK;AGILB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-0IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM
M,BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#`*;7-G:60@(D-E<G1I9FEC871E($1E=&%I;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,3(*;7-G
M:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DW"FUS9VED(")#97)T:69I8V%T
M92!0;VQI8VEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H
M860B"FUS9W-T<B`BX9Z&X9ZVX9Z*(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@IM
M<V=I9"`B0VAA;F=E(@IM<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>
ME.&?DN&>C^&>O.&>FB(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HS,0IM<V=I9"`B0VAA;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B
M"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET
M:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R("+AGHCA
MGKCAGIOAGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("+A
MGH7AGK?AGI,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-@IM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")#:&EN97-E(%1R861I=&EO
M;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P
M+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S$*;7-G:60@
M(D-H;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('5S97)N
M86UE(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,#(*
M;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R
M(&]R9&5R960@;&ES=',I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HU-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@
M(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+X9Z"X9^2
MX9Z:X9ZXX9Z?X9^2X9Z/X9Z8X9^)X9ZVX9Z?(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDQ-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO
M="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,30*;7-G:60@(D-L96%R(@IM<V=S='(@(N&>A^&>
MF.&?DN&>FN&?AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B0VQE87(@
M475E<GDB"FUS9W-T<B`BX9Z'X9Z8X9^2X9Z:X9^'XH"+X9Z?X9^&X9Z.X9Z]
MX9Z:(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I
M9"`B0VQE87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$U"FUS9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#
M;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K
M871E;&P@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED
M(")#;&]S92!7:6YD;W<B"FUS9W-T<B`BX9Z4X9ZWX9Z1XH"+X9Z4X9Z$X9^2
MX9ZBX9Z]X9Z%(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*;7-G:60@
M(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B
M0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+
MX9Z`X9Z\X9Z`X9Z\("CAGH/AGKCAGIOAGKCAGH0I(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHR-`IM<V=I9"`B0V]L;&%P<V4@4VED96)A
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R9&5R<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R
M("+AGH#AGKSAGJ'AGKOAGX;AGI3AGXKAGK@B"@HC.B!L:6(O0FQO8VLO8V]L
M;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B
M0V]L;W(B"FUS9W-T<B`BX9Z6X9Z.X9^,(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,S,`HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,Q"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HU,#$@<V5R=FEC97,O:6UA9V5S+V-O;&]R
M<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA
M9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,SD*;7-G:60@(D-O;&]U
M<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-30*;7-G:60@(D-O
M;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(X,`IM<V=I9"`B0V]M:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R("+AGI;A
MGK;AGH#AGY+AGIGB@(OAGI3AGHGAGY+AGH?AGK8B"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#
M;VUM96YT(@IM<V=S='(@(N&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^*`B^&>
MHN&>DN&>M^&>E.&?DN&>E.&>MN&>F2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")#;VUM;VX@3F%M92(*;7-G<W1R
M("+AGHCAGY+AGICAGX3AGX?B@(OAGI+AGICAGY+AGICAGH_AGK8B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-`IM<V=I9"`B0V]M;W)O<R(*;7-G<W1R("+AGH#AGKOAGX;AGICA
MGXGAGKSAGIKAGXGAGKSAGI\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(N&>
M@.&?DN&>FN&>N^&>F.&>H.&?BN&>N^&>DR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS-@IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(N&>@.&>N^&?
MAN&>EN&?DN&>F>&>O.&>D>&?D.&>FB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR.3`*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("+AGIOA
MGH#AGY+AGH'AGH'AGH[AGY+AGHPB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(V,0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("+AGIOAGH#AGY+AGH'A
MGH'AGH[AGY+AGHPB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I
M9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N
M(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO
M;VLN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*
M;7-G:60@(D-O;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-O;F9I<FTN<&AP.C,X"FUS9VED(")#;VYF:7)M($5M86EL($%D9')E<W,B
M"FUS9W-T<B`BX9ZBX9^'X9ZBX9ZVX9Z$XH"+X9ZBX9ZVX9Z?X9Z9X9Z*X9^2
MX9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHU,0IM<V=I9"`B0V]N9FER;2!087-S
M=V]R9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I
M='DN<&AP.C,X-0IM<V=I9"`B0V]N9FER;2!N97<@96UA:6P@861D<F5S<R(*
M;7-G<W1R("+AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+AGK;AGI_AGIGAGHKAGY+A
MGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIOB@(OAGI#AGY+AGICAGK@B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R("+AGH#AGKOAGH3A
MGJ#AGY+AGH+AGX0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH_AGI?AGY+A
MGH?AGK;AGI3AGXOB@(OAGI3AGK;AGI/B@(OAGI3AGIKAGK;AGH?AGY#AGIGB
M@(O"H.&?E"(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@W-@IM<V=I9"`B
M0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$Q,#`*;7-G:60@(D-O;G1A8W1S
M(@IM<V=S='(@(D-O;G1A8W1S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HV,`IM
M<V=I9"`B0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL93H@(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-38@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C<U"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(N&>
ME.&>D^&?DN&>CR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*
M;7-G<W1R("+AGH#AGX3AGX?B@(OAGH#AGKSAGH`B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S<*;7-G:60@(D-O;VMI92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`BX9Z%X9Z8X9^2X9Z;X9Z$(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S8*;7-G:60@(D-O<'D@
M<V5L96-T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C<*;7-G:60@(D-O<W1A(%)I8V$B"FUS9W-T<B`BX9Z`X9Z\X9Z?
MX9^2X9Z/X9ZVX9Z:X9ZXX9Z`X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V]T
M92!D)TEV;VER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z.38@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ,C$*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@
M<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C$U-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O(&QD
M87`@<V5R=F5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HT.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4R,PIM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M861D<F5S<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PIM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0T-@IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T
M(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C$S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!<
M(B5S7"(@9F]R('=R:71I;F<N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,C`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?
M5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y
M.0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED
M("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q
M=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R
M92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI
M;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(W-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-30*;7-G:60@(D-O=6QD
M(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM
M<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG
M=6%T:6]N.B`E<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C<W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N
M("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S
M"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@V"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A
M8W0N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E
M<UPB.B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T
M,C<*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*
M;7-G<W1R("+AGI3AGY+AGIKAGI'AGX'AGI\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(N&>E.&>A.&?DN&>@.&>
MON&>CR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@
M<W5B(&9O;&1E<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HR-#`*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(R,PIM<V=I
M9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y
M"FUS9VED(")#<F]A=&EA(@IM<V=S='(@(N&>@.&?DN&>FN&>O.&>HN&>MN&>
MCR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS9W-T<B`BX9Z"X9Z[X9Z9
MX9Z4X9ZV(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"FUS9VED(")#=7)R
M96YT(#0@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H
M<#HU,`IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S4*;7-G
M:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("+AGI;AGX'AGIOB@(OAGISAGX'A
MGIOAGK;B@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+AGI,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P"FUS9VED(")#=7)R
M96YT(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(V.0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ("(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(N&>FN&>A>&>
MD^&>MN&>E.&?D.&>D>&?DN&>F.*`B^&>E.&>A>&?DN&>A>&>N^&>E.&?DN&>
ME.&>D^&?DN&>D^*`BR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("+AGI3AGY+AGH_AGKSAGIKB@(OA
MGI?AGK;AGIKAGH#AGK?AGH7AGY+AGH7B@(OAGHKAGX+AGIOB@(OAGH_AGY+A
MGIKAGKSAGISB@(OAGIKAGH_AGXOB@(OAGH_AGK;AGICB@(OAGI3AGX;AGH[A
MGH0@X9ZBX9ZVX9Z?X9^2X9Z:X9^0X9Z9XH"+X9Z;X9Z^XH"+X9Z`X9ZVX9Z:
MXH"+X9Z%X9Z\X9Z;XH"+X9Z1X9^%XH"+("5S(.&?E"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I
M9"`B0W5T(@IM<V=S='(@(N&>@.&>MN&>C^&?BR(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE
M8W1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S(@IM
M<V=S='(@(N&>G^&?BN&>N.&>EN&>FN&?C2(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3<X"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("+A
MGI_AGXKAGKCAGIKAGKCAGIOAGKCAGH`@*$M/23@M4BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2DB"FUS9W-T<B`BXH"+XH"+X9Z?X9^*X9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A7
M:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G
M:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G<W1R("+AGI_A
MGK;AGI+AGK;AGIKAGH[B@(OAGIKAGHKAGY+AGHOB@(OAGH;AGX'AGH`B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4P('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C0X('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(B(*(D13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B
M1&%I;'DB"FUS9W-T<B`BX9Z:X9ZVX9Z;X9^+XH"+X9Z0X9^2X9Z$X9^#(@H*
M(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"<F]W
M<V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#$*;7-G:60@(D1A=&%B87-E($QO;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,#8*;7-G:60@(D1A=&4B"FUS9W-T<B`BX9Z`
MX9ZVX9Z;XH"+XH"+X9Z4X9Z:X9ZWX9Z%X9^!X9^2X9Z&X9Z1(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@
M4F5C96EV960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@P,`IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-2!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S$T"FUS9VED(")$87DB"FUS9W-T<B`BX9Z0X9^2
MX9Z$X9^#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,V"FUS9VED(")$95]L971E($-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-@IM<V=I9"`B1&5C96UB97(B"FUS9W-T<B`BX9Z2X9^2X9Z3X9Z\(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@
M(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("+AGI3AGI/AGY+AGI#AGID@X9Z%
MX9Z\X9Z;XH"+X9Z4X9Z3X9^2X9Z1X9ZVX9Z/X9^+(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G
M:60@(D1E9F%U;'0B"FUS9W-T<B`BX9Z;X9^&X9Z3X9ZVX9^&X9Z*X9Z^X9Z8
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M-S<*;7-G:60@(D1E9F%U;'0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY-@IM<V=I9"`B1&5F875L="!)
M9&5N=&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-C<*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHW,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D
M96QE=&4N:6YC.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q
M"FUS9VED(")$96QE=&4B"FUS9W-T<B`BX9Z;X9Z[X9Z4XH"+(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R
M"FUS9VED(")$96QE=&4@0V5L;"(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E
M($=R;W5P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN
M<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8S
M"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S='(@(N&>F^&>N^&>E.*`B^&>
MA^&>O>&>FN*`B^&>B.&>FB(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X
M"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@(N&>F^&>
MN^&>E.*`B^&>A^&>O>&>FN&>BN&?@>&>@"(*"B,Z('1E;7!L871E<R]P<F5F
M<R]D96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E
M9"!I9&5N=&ET>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$
M96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4Y-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`BX9Z*X9ZVX9Z.
MX9ZZX9Z8X9^)X9ZVX9Z`(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDT,B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED(")$
M97-C<FEP=&EO;B(*;7-G<W1R("+AGH#AGK;AGIKAGI;AGK?AGI;AGH[AGXSA
MGI/AGK8B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-PIM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P,0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S
M-0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`BXH"+X9ZBX9Z7X9ZWX9Z<
MX9Z,X9^2X9Z-(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,CD*;7-G:60@
M(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P-@IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Q"FUS9VED
M(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F
M="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@
M=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(N&>D.&>CR(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-S`*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M,`IM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-`IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.CDW"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3`*;7-G:60@(D1I
M<W!L87D@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G
M<W1R("+AGJ#AGY+AGI_AGXKAGKCAGI3AGKSAGI'AGK@B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T
M92(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*
M;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$R
M('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$R"FUS9VED(")$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1O;6EN:6-A(@IM<V=S='(@(N&>BN&>O.&>F.&>N.&>D^&>N.&>@.&>MB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R
M("+AGI_AGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OAGHKAGKSAGICA
MGKCAGI/AGKCAGH#AGX+AGI,B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C@X"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>F.&>MN&>D^*`B^&>@N&>CN&>D^&>
MN,*@/R#AGI_AGKSAGICB@(OAGH7AGKOAGX?AGHCAGY+AGICAGX3AGX?"H.&?
ME"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@U.`IM
M<V=I9"`B1&]W;FQO860B"FUS9W-T<B`BX9Z1X9ZVX9Z)X9Z9X9Z`(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4X"B,L('!H<"UF
M;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,34*;7-G:60@(D1R;W`@9&]W
M;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M.0IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C@S"FUS9VED(")$>6YA;6EC($UA:6PB"FUS9W-T<B`BX9Z?
MX9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9ZVX9Z8X9Z<X9Z3X9^2X9Z/(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%
M+4UA:6PB"FUS9W-T<B`BX9ZBX9^*X9ZXX9Z8X9^"X9Z;(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-
M86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H
M('!R;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B16-U861O<B(*;7-G<W1R("+AGJ+AGX'AGH#AGY+AGISAGK;AGHSAGY#A
MGIHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X,2!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B"FUS
M9W-T<B`BX9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:X9Z]X9Z;(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U
M<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I
M9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L
M('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T
M"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I
M9"`B161U8V%T:6]N(@IM<V=S='(@(N&>@.&>MN&>FN*`B^&>HN&>E.&?B^&>
MFN&?AB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5G>7!T(@IM<V=S='(@(N&>HN&?
M@>&>H.&?DN&>G^&?BN&>N.&>E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@
M4V%L=F%D;W(B"FUS9W-T<B`BX9ZBX9^"X9Z;X9Z?X9ZVX9Z;X9^+X9Z<X9^)
MX9ZVX9Z,X9^0X9Z:(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS9VED(")%;&5M96YT+BXN(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S<*;7-G:60@(D5M86EL(@IM<V=S='(@(N&>HN&?BN&>N.&>
MF.&?@N&>FR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-38V('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV.`IM<V=I9"`B16UA:6P@
M061D<F5S<R(*;7-G<W1R("+AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B
M@(OAGJ+AGXKAGKCAGICAGX+AGILB"@HC.B!S97)V:6-E<R]C;VYF:7)M+G!H
M<#HS,`IM<V=I9"`B16UA:6P@861D<F5S<V5S(&AA=F4@8F5E;B!L;V-K960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S$*
M;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R("+A
MGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+A
MGIOB@(OAGH_AGY+AGIKAGKSAGISB@(OAGH_AGX+B@(OAGHKAGKSAGH7AGH+A
MGY+AGI/AGK;"H.&?E"(*"B,Z('-E<G9I8V5S+V-O;F9I<FTN<&AP.C(S"FUS
M9VED(")%;6%I;"!A9&1R97-S97,@=&\@8V]N9FER;2!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y.3<*;7-G
M:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ"FUS9VED
M(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDW"FUS9VED(")%;6]T
M:6-O;G,B"FUS9W-T<B`BX9Z?X9Z)X9^2X9Z)X9ZVXH"+X9ZBX9ZVX9Z:X9Z8
MX9^2X9Z8X9Z.X9^-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M
M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30W"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3(R"FUS9VED(")%;F%B;&4@<FEG
M:'0@8VQI8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#0*;7-G:60@(D5N9"!Y96%R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R
M9V4@161I=&]R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI
M8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U
M<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H
M92!I;6%G92!54DP@:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DP"FUS9VED(")%;G1E<B!T:&4@
M;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9ZXX9Z.X9^!
MXH"+X9ZBX9^!X9Z`X9^2X9Z<X9ZVX9Z1X9^0X9Z:(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM
M<V=I9"`B17)I=')E82(*;7-G<W1R("+AGJ+AGX'AGIKAGKCAGI'AGY+AGIKA
MGK8B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C4S"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-#$*;7-G:60@(D5R<F]R
M(@IM<V=S='(@(N&>@.&?AN&>H.&>N^&>GR(*"B,Z(&9R86UE=V]R:R]496UP
M;&%T92]496UP;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S
M<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T;VYI82(*;7-G<W1R("+AGJ+A
MGX'AGI_AGY+AGH_AGKSAGI/AGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI
M;W!I82(*;7-G<W1R("+AGJ+AGX'AGH_AGY+AGIGAGKSAGI;AGK@B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(D5T:&YI8R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@
M(D5U<F]P92(*;7-G<W1R("+AGJ+AGKKAGIKAGXGAGKOAGI0B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`Q(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#,*;7-G:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`BX9Z:
MX9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+XH"+(.&?H>&?I2#AGI/AGK;AGI'AGK@B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R
M(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDX(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C;VYD<R(*
M;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOB@(L@X9^CX9^@(.&>
MG.&>M^&>D^&>MN&>D>&>N"(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T
M+FEN8SHQ,#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS
M9W-T<B`BX9Z:X9^`X9Z$XH"+X9Z:X9ZVX9Z;X9^+(.&?I2#AGI/AGK;AGI'A
MGK@B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`R(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R("+AGIKAGX#A
MGH3B@(OAGIKAGK;AGIOAGXOB@(OAGH#AGI/AGY+AGIOAGX?B@(OAGICAGXGA
MGX3AGH0B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3`S"FUS
M9VED(")%=F5R>2!H;W5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R("+AGIKAGX#AGH3B@(OAGIKAGK;AGIOAGXOAGI/AGK;AGI'A
MGK@B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B
M17AA;7!L92!V86QU97,Z(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN
M<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("+AGI3AGY+AGIKAGH_A
MGK?AGI3AGH_AGY+AGH_AGK<B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C0V-@IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(N&>E.&>D^&?DN&>F^&>MN&>F2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED
M96)A<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@*;7-G:60@
M(D5X<&5C=&5D("<I)R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-1
M3"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B17AP:7)A=&EO;B!$
M871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C<W"FUS9VED(")%>'!O;F5N="(*;7-G<W1R("+AGJ+AGXKAGK?A
MGH7AGI_AGY+AGI3AGKSAGH[AGH3AGXOAGI_AGX+AGILB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Q"FUS9VED
M(")&1R!#;VQO<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]S<6PN<&AP.C(T-0IM<V=I9"`B
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.C$P,0IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O
M(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(R"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!C;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S87-L+G!H<#HX.0IM<V=I9"`B1F%I;&5D('1O(&-R96%T
M92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#8U"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R
M:65V93H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM
M<V=S='(@(N&>@.&?A.&?A^*`B^&>H.&?DN&>G.&?B>&>@.&>H>&>A.&?BR`H
MX9Z8X9^)X9ZVX9Z;X9^+X9Z<X9ZXX9Z.X9ZV*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G
M:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`BX9Z`X9^$X9^'X9Z@X9^2X9Z<
MX9ZVX9ZBX9^!X9Z:X9Z\(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*
M;7-G<W1R("+AGI'AGKSAGIKAGI_AGK;AGIHB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S8U"FUS9VED(")&87AE<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,SD*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B
M1F5B<G5A<GDB"FUS9W-T<B`BX9Z`X9Z[X9Z8X9^2X9Z7X9^((@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,S(*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-0IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HR,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34R"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,S-@IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,T,`IM<V=I9"`B1FEG;&5T(&9O;G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R("+A
MGJ#AGY+AGISAGKCAGJ#AGY+AGI_AGXKAGK@B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(D9I;&4B"FUS9W-T<B`BX9ZOX9Z`
MX9Z?X9ZVX9Z:(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R
M+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8P
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")&:6QE($UA
M;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#(*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX?B
M@(OAGJ_AGH#AGI_AGK;AGIHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3@X"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#DT"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HX.#4*;7-G:60@(D9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`BX9Z/X9Z8X9^2X9Z:X9Z$(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("+AGJ#AGY+AGISAGK;AGX;AGH3A
MGJ'AGH3AGXLB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&
M:7)S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(U-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,S`*;7-G:60@
M(D9L:7`B"FUS9W-T<B`BX9Z/X9^2X9Z:X9ZAX9Z4X9^+(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I
M9"`B1FQO870B"FUS9W-T<B`BX9Z1X9Z?X9Z7X9ZVX9Z"(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O9R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(V,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*
M;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(R"FUS
M9VED(")&;VYT($-O;&]R(@IM<V=S='(@(N&>EN&>CN&?C.*`B^&>EN&>N^&>
MF.&?DN&>EN*`B^&>HN&>@.&?DN&>G^&>FB(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,@IM<V=I9"`B1F]O9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*
M;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0V"FUS9VED
M(")&;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-S<*;7-G:60@(B(*(D9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S
M=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY-`IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O
M<F0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-S@*;7-G:60@(D9O<FUS(@IM<V=S='(@(N&>G^&?AN&>CN&>N^&?AN*`B^*`
MB^&>E.&?@N&>E.&>E.&>D2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR
M-@IM<V=I9"`B1F]R='5N92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,3`T"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")&;W)T=6YE<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@
M(D9O<G1U;F5S(#(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0V.0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*;7-G:60@(D9O<G=A<F1S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R86UE
M<R(*;7-G<W1R("+AGI_AGXKAGKOAGI@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&
M<F%N8V4B"FUS9W-T<B`BX9Z4X9ZVX9Z:X9ZVX9^&X9Z$(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4L($UE=')O
M<&]L:71A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@
M1W5I86YA(@IM<V=S='(@(N&>H.&?DN&>@N&>O.&>HN&?BN&>N.&>F>&?B>&>
MMN&>CN&>MB#AGI3AGK;AGIKAGK;AGX;AGH0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R("+AGI3AGXGAGKSAGIOAGKCA
MGI/AGX'AGI_AGXKAGKCB@(OAGI3AGK;AGIKAGK;AGX;AGH0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D*;7-G:60@(D9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G
M<W1R("+AGJ+AGK;AGH[AGH7AGH#AGY+AGIKB@(OAGH'AGK;AGH3B@(OAGH_A
MGY+AGI3AGKSAGH0@X9Z4X9ZVX9Z:X9ZVX9^&X9Z$(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-`IM<V=I9"`B1G)O;2(*
M;7-G<W1R("+AGI;AGK@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-3(*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y.`IM<V=I9"`B1G)O;2!T:&4@
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS
M9VED(")&=6QL($UO;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*
M;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R("+AGHCAGY+AGICAGX3AGX?B@(OA
MGI;AGX'AGHDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("+A
MGJ#AGY+AGH+AGK;AGI3AGKOAGH0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM
M<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1V%M8FEA(@IM<V=S='(@(N&>H.&?DN&>@.&>MN&?AN&>E.&?BN&>N"(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N
M97)A=&5D($-O9&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1V5O
M<F=I82(*;7-G<W1R("+AGJ#AGY+AGI_AGH#AGJ#AGY+AGI_AGXKAGK@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y"FUS9VED(")'97)M86YY(@IM<V=S='(@(N&>HN&>MN&>F^&?
MDN&>F^&>NN&>F.&?B>&>A.&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA
M(@IM<V=S='(@(N&>H.&?DN&>@.&>MN&>CN&>MB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=I8G)A;'1A<B(*;7-G<W1R("+AGJ#AGY+AGH+AGKCAGI3AGY+AGIKA
MGK;AGIOAGXOAGH_AGK8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W-@IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("+AGI/AGK;A
MGICAGH'AGY+AGIOAGKWAGI,B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A
M<BYP:'`Z,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L
M871E<R]P<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*
M;7-G<W1R("+AGH?AGICAGY+AGIKAGK[AGI_B@(OAGI_AGH#AGILB"@HC.B!T
M96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-PIM<V=I9"`B1V\B"FUS9W-T<B`B
MX9Z1X9^%(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED(")'
M;V5D96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q,CD*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L
M92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L
M92!396%R8V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(S-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@
M(N&>F.&>MN&>C^&?DN&>FN&>BN&?DN&>B^&>MN&>D^*`B^&>E.&?DN&>FN&>
ME>&?@>&?AR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B
MX9Z`X9^2X9Z:X9ZWX9Z`(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#$*
M;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R("+AGH#AGY+AGIKA
MGK?AGH`@*$E33RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL
M86YD(@IM<V=S='(@(N&>@N&?DN&>FN&>N.&>H>&>A.&?BR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`BX9Z@X9^2X9Z"X9^2X9Z:X9ZX
MX9Z.X9ZVX9Z*X9ZV(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@
M(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$V.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS
M-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O
M('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS.`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B1W)O=7!S
M(@IM<V=S='(@(N&>@.&?DN&>FN&>N^&>F"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`BX9Z@X9^2X9Z"X9Z\X9ZBX9ZVX9Z*X9ZZ
MX9Z;X9Z\X9Z4X9^)X9^!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS
M9W-T<B`BX9Z@X9^2X9Z"X9ZVX9^&X9Z8(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@
M(D=U871E;6%L82(*;7-G<W1R("+AGJ#AGY+AGH+AGK;AGH_AGX'AGICAGXGA
MGK;AGJ'AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR"FUS
M9VED(")'=65R;G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X
M"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@V"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(N&>
MH.&?DN&>@N&>N.&>CN&?@2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5I;F5A
M+4)I<W-A=2(*;7-G<W1R("+AGJ#AGY+AGH+AGKCAGH[AGX'AGI3AGXKAGKCA
MGI_AGX4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R("+A
MGJ#AGY+AGH+AGKCAGIGAGXGAGK;AGH[AGK8B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY-C0*;7-G:60@(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#4*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E
M('1H92!L87-T(&-E;&P@:6X@<F]W+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS9VED
M(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S
M="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA4
M34Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O
M=R!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]H='1P+G!H<#HQ-30*;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I
M(@IM<V=S='(@(N&>H.&?@^&>D>&>N"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3(S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C4*;7-G
M:60@(DAE861E<B(*;7-G<W1R("+AGI3AGHOAGICAGH#AGI#AGK;B@(LB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"FUS
M9VED(")(96%D97)S(@IM<V=S='(@(N&>E.&>B^&>F.&>@.&>D.&>MB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)
M<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>H.&?BN&>ON&>BB#AGI/A
MGK?AGH0@X9Z`X9^$X9^'XH"+X9Z8X9^)X9ZVX9Z`X9Z*X9Z\X9Z.X9ZVX9Z;
MX9^+(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#(*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)
M*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`BX9Z`
MX9Z8X9^2X9Z6X9Z?X9^+(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE
M;'`N<&AP.C$X,2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@R
M"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP
M+VEN9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(N&>A^&?AN&>D^&>
MO>&>F2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-SD*;7-G:60@(DAE;'!E<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,CD*;7-G:60@(DAE
M;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3`@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@
M(DAE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*
M;7-G:60@(DAI9V@B"FUS9W-T<B`BX9Z!X9^2X9Z6X9Z?X9^+(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E
M*2(*;7-G<W1R("+AGJ#AGKSAGIOAGKCAGI_AGXKAGK@@*.&>FN&>BN&?DN&>
MB^*`B^&>@.&?DN&>FN&>N^&>A.*`B^&>G.&?B>&>MN&>D>&>N.&>@.&>A.&?
MBRDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-34*;7-G:60@
M(DAO;64B"FUS9W-T<B`BX9Z"X9^!X9Z@X9Z1X9^&X9Z6X9^0X9Z:(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED
M(")(;VUE($%D9')E<W,B"FUS9W-T<B`BX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+
MX9ZVX9Z3XH"+X9Z5X9^2X9Z1X9^'(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R("+AGI#AGH_A
MGI7AGY+AGI'AGX<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S='(@(N&>D>&>
MO.&>FN&>G^&?D.&>EN&?DN&>D>*`B^&>E>&?DN&>D>&?AR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`BX9Z@X9Z[X9Z$X9Z,X9Z\
MX9Z:X9^)X9ZVX9Z?X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS9VED(")(;VYG($MO
M;F<B"FUS9W-T<B`BX9Z@X9Z[X9Z$X9Z`X9Z[X9Z$(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED(")(;W)D92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0T,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O
M=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0S
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S
M(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E
M;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A
M=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0S"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S(%PB)7-<
M(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HT-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,S,R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK;F]W
M;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2
M=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*
M;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L:6(O
M0FQO8VLO;65T87(N<&AP.C(T,@IM<V=I9"`B2'5M:61I='DB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,PIM<V=I9"`B
M2'5M:61I='DZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#8*;7-G:60@(DAU;6]R:7-T<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`BX9Z@X9Z[X9Z$X9Z"X9^2X9Z:
MX9ZX(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<P(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C$T
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.38*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<W(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,R,`IM<V=I9"`B25`@061D<F5S<R(*;7-G<W1R("+AGJ+AGK;AGI_A
MGIGAGHKAGY+AGHOAGK;AGI/B@(L@25`B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VEP8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B
M87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO
M=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?
M;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DEC96QA;F0B"FUS9W-T<B`BX9ZBX9^*X9ZXX9Z?X9^2X9Z;X9Z$X9^+
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@
M3VYL>2(*;7-G<W1R("+AGH_AGX+B@(OAGIKAGKSAGI3AGH_AGX;AGH[AGK;A
MGH0B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#$*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS"FUS9VED("))
M9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C4Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I
M="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R
M96YC>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S$*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V.0IM<V=I9"`B26UA9V4@
M=7!L;V%D(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W
M"FUS9VED("));6%G97,B"FUS9W-T<B`BX9Z:X9Z\X9Z4X9Z7X9ZVX9Z6(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T
M82]D871E;6%P+FEN8SHW"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M-30@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G0L(%-T97`@)60B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T96UA<"YI;F,Z,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M26UP;W)T960@9FEE;&0Z("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D
M871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S0*;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@
M<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT
M97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("+AGI3AGH3A
MGY+AGH#AGK[AGI/B@(OAGH#AGK;AGIKB@(OAGH7AGKSAGIOB@(OAGI3AGI/A
MGY+AGI'AGK;AGH_AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN9&EA(@IM
M<V=S='(@(N&>I>&>CN&?DN&>C.&>MB(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T
M"FUS9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(N&>I>&>CN&?DN&>C.&>
MO.&>D^&?@>&>G^&?BN&>N"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`BX9Z6X9^0
MX9Z/X9^,X9Z8X9ZVX9Z3(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(W,PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`BX9Z6X9^0X9Z/X9^,
MX9Z8X9ZVX9Z3(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R
M,@IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BX9Z4X9Z)X9^2
MX9Z%X9Z\X9Z;XH"+X9Z/X9ZVX9Z:X9ZVX9Z$(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E
M8B!,:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU
M;6X@0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@
M82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R
M<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@
M8V5L;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O
M;'5M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L
M=6UN(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E
M<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I
M9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y
M('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM
M86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD
M('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G
M:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS9W-T
M<B`BX9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z"X9Z/X9^+(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E<B!L:7-T(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI
M9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED
M(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,#DU(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-C8*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E
M="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N
M<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<P"FUS9VED("))
M;G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38T"FUS9VED("));G9A;&ED(&QO8V%T:6]N
M('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G
M7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R
M(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38V"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C@*;7-G:60@
M(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@
M(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<U(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A9&1R97-S+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<S"FUS9VED
M("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8W-@IM<V=I9"`B26YV97)T('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("))<F%Q(@IM<V=S='(@(N&>HN&?BN&>N.&>FN&?B>&>MN&>@.&?BR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("+AGJ+AGX#AGIKA
MGJ'AGH3AGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM
M<V=I9"`B27-L92!O9B!-86XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M
M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L
M(@IM<V=S='(@(N&>HN&?BN&>N.&>G^&?DN&>FN&>MN&>HN&?@N&>FR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))
M<W-U97(B"FUS9W-T<B`BX9ZBX9^2X9Z3X9Z`XH"+X9Z%X9^!X9Z)(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED
M("))=&%L:6,B"FUS9W-T<B`BX9Z1X9^2X9Z:X9^!X9Z/(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@R"FUS9VED("))=&%L>2(*;7-G<W1R("+AGJ+AGXKAGKCAGH_AGK;AGIOA
MGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`BX9Z%
MX9ZVX9Z8X9^)X9^#X9Z`X9ZV(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BX9Z8
MX9Z`X9Z:X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R
M("+AGH?AGI3AGXGAGKOAGI,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R("+B@(OA
MGH?AGI3AGXGAGKOAGI,@*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`BX9Z@X9^2X9Z?
MX9^*X9Z`X9Z*X9ZVX9Z3X9ZX(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`BX9Z`X9Z`
MX9^2X9Z`X9Z*X9ZV(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`BX9Z8X9ZWX9Z0X9Z[
MX9Z3X9ZV(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+AGH_AGICA
MGY+AGIKAGKGAGICB@(OAGI_AGH3B@(OAGH'AGK;AGH0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I
M9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*;7-G:60@(DIU
M<W1I9GD@1G5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,
M969T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G
M<W1R("+AGH#AGK;AGJ#AGY+AGI_AGK;AGH#AGXOAGI_AGY+AGH_AGH3AGXLB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8S
M"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(N&>@.&?@N&>D^&>F>&?B>&>MB(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#8*;7-G:60@(DME
M<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED(")+97)N
M96P@3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@
M(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T
M<B`BX9Z4X9^2X9Z:X9Z<X9^"X9Z$XH"+X9Z`X9Z\X9Z3X9Z?X9^$(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@
M5'EP92(*;7-G<W1R("+AGI3AGY+AGIKAGI?AGX'AGI'B@(OAGH+AGY+AGIKA
MGK;AGI3AGXOB@(OAGH7AGKOAGH4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@
M(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R("+AGH+AGK?AGIKAGK?AGI3AGK;AGI'AGK@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@T"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`BXH"+X9Z`
MX9Z\X9Z:X9^)X9^!("A%54,M2U(I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED(")+
M=7=A:70B"FUS9W-T<B`BX9Z"X9Z[X9Z9XH"+X9Z<X9^)X9^"X9Z/(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(N&>@N&?@.&>
MFN&>H.&?DN&>@N&>N.&>G^&?DN&>C^&>A.&?BR(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<U"FUS9VED("),86YG=6%G
M92(*;7-G<W1R("+AGI?AGK;AGI_AGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(DQA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC(@IM<V=S='(@(N&>
MG^&>MN&>DN&>MN&>FN&>CN&>FN&>BN&?DN&>B^*`B^&>E.&?DN&>FN&>A^&>
MMN&>DN&>M^&>E.&>C^&?@>&>F>&?DN&>F>*`B^&>E.&?DN&>FN&>A^&>MN&>
MF.&>MN&>D^&>M^&>C^*`B^&>H>&>MN&>G"(*"B,Z(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-CD*;7-G:60@(DQA<W0@2&%L9B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA
M;F=E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX-B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z.#@*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B3&%S="!5
M<&1A=&5D.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$T"FUS9VED("),
M87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G
M:60@(DQA='9I82(*;7-G<W1R("+AGJ'AGK;AGH_AGISAGKCAGIGAGXGAGK8B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*;7-G:60@(DQA=R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("+AGI3AGY+AGIOA
MGH3AGXOB@(LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&5B86YO;B(*;7-G<W1R
M("+AGIOAGKCAGI3AGH3AGXLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`B
MX9Z&X9^2X9Z<X9^!X9Z$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$Q,@IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F="!V86QU97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@
M(N&>H>&?@>&>G^&>O.&>C^&>O"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`BX9Z`X9Z8X9^2X9Z:
MX9ZWX9Z/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@
M(N&>F^&>N.&>E.&?@>&>FN&>N.&>F>&?B>&>MB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,30W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM
M<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("+AGH7AGK;A
MGICAGXGAGK;AGJ+AGXKAGK?AGIKAGKCAGIGAGXGAGK;B@(OAGJ+AGK;AGIKA
MGXGAGK;AGI3AGXL@X9Z;X9ZXX9Z4X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(N&>F^&>M^&>A>&>D>&?@>&>
MD^&>G^&?DN&>C^&?@N&>DR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V
M"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(W"FUS9VED("),:6=H="!286EN
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,CD*;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),
M:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@
M4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED("),:6UE
M<FEC:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#(R"FUS9VED("),:6YK(@IM<V=S='(@(N&>C^&?AN&>CB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PIM
M<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X.#,*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL
M,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`BX9Z/X9^&X9Z.
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED("),:6YU>"!#
M;V]K:64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#8*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE
M(&9O;&1E<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S
M"FUS9VED("),:7-T($1A=&%B87-E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]H96QP+VEN9&5X+G!H<#HU,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),
M:7-T(%1A8FQE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4P.0IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`T"FUS
M9VED("),:7-T+4AE;'`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU,3$*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU,#<*;7-G
M:60@(DQI<W0M3W=N97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12](96%D97)S+G!H<#HU,#@*;7-G:60@(DQI<W0M4&]S="(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-@IM
M<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12](96%D97)S+G!H<#HU,#4*;7-G:60@(DQI<W0M56YS=6)S
M8W)I8F4B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4R"B,L
M('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E
M<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM
M<V=I9"`B3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"FUS9VED("),:71E<F%T=7)E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM
M<V=S='(@(N&>F^&>N.&>D>&>N^&>F>&>HN&>MN&>D^&>N"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`Z-S<*;7-G:60@(DQO
M861I;F<N+BXB"FUS9W-T<B`BX9Z`X9^&X9Z6X9Z[X9Z$XH"+X9Z5X9^2X9Z1
MX9Z[X9Z`+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-0IM<V=I9"`B3&]C86P@=&EM93H@(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-PIM<V=I9"`B
M3&]C871I;VXB"FUS9W-T<B`BX9Z1X9ZXX9Z/X9ZVX9^&X9Z$(@H*(SH@;&]G
M:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,C`P('1E
M;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN
M+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,@IM
M<V=I9"`B3&]G(&EN(@IM<V=S='(@(N&>A>&>O.&>FR(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I;W5S
M('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(N&>A>&?
M@>&>B2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.0IM<V=I9"`B3&]G
M:6XB"FUS9W-T<B`BX9Z%X9Z\X9Z;(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BX9Z7X9ZVX9Z:
MX9Z`X9ZWX9Z%X9^2X9Z%XH"+X9Z%X9Z\X9Z;(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DU"FUS9VED("),;V=I;B!F86EL960@8F5C875S92!Y
M;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C
M=&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,W,PIM<V=I9"`B3&]N9R!T97AT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3&]V
M92(*;7-G<W1R("+AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI_AGY+AGIKA
MGJ'AGK;AGHGAGXLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM<V=S='(@(N&>D>&>MN&>E"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L
M86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("+A
MGIOAGKOAGH7AGJ#AGY+AGI_AGX;AGI3AGKWAGIHB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,SDY"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,S<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Y-PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R("+AGICAGXGA
MGK;AGH#AGK;AGIPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@
M5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`BX9Z8X9^)
MX9ZVX9Z*X9ZVX9Z@X9^2X9Z`X9ZVX9Z?X9^2X9Z`X9ZVX9Z:(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")-86=I8R(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3`*;7-G:60@(DUA:6PB
M"FUS9W-T<B`BX9Z?X9^&X9Z4X9Z[X9Z/X9^2X9Z:(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C4S.`IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`BX9Z8X9^)X9ZV
MX9ZAX9ZVX9Z<X9^#(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-86QA>7-I82(*
M;7-G<W1R("+AGICAGXGAGK;AGJ'AGX'AGI_AGXKAGK@B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.30*;7-G:60@(DUA;&1I=F5S(@IM<V=S='(@(N&>F.&?B>&>MN&>F^&?B^&>
MC.&>N.&>G"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R("+A
MGICAGXGAGK;AGIOAGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM
M<V=S='(@(N&>F.&?B>&>MN&>F^&?B^&>C^&>MB(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-30*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-0HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.0IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`BX9Z8X9ZXX9Z3X9ZV(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%R9VEN(@IM<V=S='(@(N&>FN&>N>&>F.*`B^&>D>&?AN&>EN&?
MD.&>FB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A
M;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX<@36%R<VAA;&PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`BX9Z8
MX9^)X9ZVX9Z:X9Z1X9ZXX9Z3X9ZXX9Z"(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B
MX9Z8X9^)X9Z\X9Z:X9ZXX9Z/X9ZVX9Z3X9ZX(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"FUS
M9VED(")-875R:71I=7,B"FUS9W-T<B`BX9Z8X9^)X9Z\X9Z:X9ZXX9Z1X9Z[
MX9Z?(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$X"FUS9VED(")-
M87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R
M<SH@(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI
M;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-#,*;7-G
M:60@(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T
M<B`BX9ZGX9Z?X9Z7X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T
M92(*;7-G<W1R("+AGICAGX/AGJ+AGKSAGH_AGX$B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-34*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`BX9Z?X9Z8X9ZVX9Z'X9ZWX9Z`(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U
M-0IM<V=I9"`B365S<V%G92(*;7-G<W1R("+AGI_AGK;AGIHB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-#(*;7-G:60@
M(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,3(T"FUS9VED("(B"B)-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34X"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN
M96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(N&>G.&>M^&>DN&>N.&>
MG^&>MN&>G^&?DN&>FN&?DN&>CR(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM
M;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C@X"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HX.2!F<F%M97=O<FLO4E!#
M+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D
M(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,B!L:6(O0FQO
M8VLO;65T87(N<&AP.C@W"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`BX9Z8X9^)X9ZWX9Z%
MX9Z?X9^*X9ZWX9Z`(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-
M:61D;&4B"FUS9W-T<B`BX9Z`X9Z.X9^2X9Z/X9ZVX9Z;(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI;64@
M5'EP92(*;7-G<W1R("+AGI3AGY+AGIKAGI?AGX'AGI$@36EM92(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S(R"FUS9VED(")-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M,30*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,X"FUS9VED(")-
M:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,S,*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+AGH;AGY+AGIOAGKOAGX<B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(DUI<V-E;&QA
M;F5O=7,B"FUS9W-T<B`BX9Z5X9^2X9Z?X9^!X9Z$X9^7XH"+(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0P
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C4P"FUS
M9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*
M(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&UU<W0@9V5N97)A=&4@:70@
M8F5F;W)E('5S:6YG('1H:7,@87!P;&EC871I;VXN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU
M.`IM<V=I9"`B36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HW-@IM<V=I9"`B36]B:6QE($UA:6PB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-CD*
M;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@U"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B36]D=6QU
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N
M86-O(@IM<V=S='(@(N&>F.&?B>&>O.&>CN&>MN&>@.&>O"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T<B`BX9Z8X9^)X9Z[X9Z$X9Z@
MX9^2X9Z"X9^$X9Z;X9ZX(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C4Y,@IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`BX9Z!X9^"(.&>
MD^&>M^&>A"#AGH;AGY+AGI/AGK;AGX8B"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S
M='(@(N&>FN&>MN&>F^&?B^*`B^&>@>&?@B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I
M9"`B36]N='-E<G)A="(*;7-G<W1R("+AGICAGXGAGKOAGH3AGI_AGX'AGIKA
MGXGAGK8B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L
M9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@
M(N&>F.&?B>&>MN&>FN&?B>&>N^&>@"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE87(B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO
M<W1L>2!3=6YN>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C4P,`IM<V=I9"`B36]V92!$;W=N(@IM
M<V=S='(@(N&>E>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>A>&>N^&?
MA^*`B^&>@.&?DN&>FN&?A.&>F"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z-3`T"FUS9VED(")-;W9E($QE9G0B"FUS
M9W-T<B`BX9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z1X9^%XH"+
MX9Z&X9^2X9Z<X9^!X9Z$(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="]-86YA9V5R+G!H<#HU,#@*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T
M<B`BX9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9Z1X9^%XH"+X9Z?
MX9^2X9Z/X9ZVX9^&(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="]-86YA9V5R+G!H<#HT.38*;7-G:60@(DUO=F4@57`B"FUS9W-T<B`BX9Z5
MX9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZXXH"+X9ZAX9Z^X9Z$XH"+X9Z;X9Z^
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R
M-`IM<V=I9"`B36]V92!D;W=N(@IM<V=S='(@(N&>A>&>N^&?A^*`B^&>@.&?
MDN&>FN&?A.&>F"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,C,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-`IM<V=I9"`B36]V92!U<"(*;7-G<W1R("+AGJ'AGK[AGH3B
M@(OAGIOAGKXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS
M9W-T<B`BX9Z8X9^)X9Z\X9Z@X9^2X9Z?X9ZVX9^&X9Z4X9^*X9ZWX9Z`(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Y,@IM<V=I9"`B375L=&DM
M;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#4V"FUS9VED(")-=6QT
M:6UA<"!52R!M87`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(U,`IM<V=I9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,38*;7-G:60@(DUY
M($%C8V]U;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C(X"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-C8*;7-G:60@(DUY(%!O
M<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z
M,3,U"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("+AGICAGKCAGIGAGXGA
MGK;AGI/AGXOAGICAGXGAGK8B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G<F5E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0Q,2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(N&>B.&?DN&>F.&?A.&?AR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("+AGH[AGK;AGICAGKCAGI3A
MGXKAGK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM<V=S='(@(N&>
MCN&>O.&>FN&>NR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T
M<B`BX9Z3X9^!X9Z4X9^)X9ZVX9Z;X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED
M(").971H97)L86YD<R(*;7-G<W1R("+B@(OAGJ#AGKOAGIOAGY+AGIOAGH3A
MGXLB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B
M"FUS9W-T<B`BX9ZBX9Z$X9^+X9Z1X9ZXX9Z9X9^-XH"+X9Z@X9Z\X9Z;X9^2
MX9Z;X9Z$X9^+(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#(*;7-G:60@(DYE='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").
M971S8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A
M<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X-0IM<V=I9"`B3F5T<V-A<&4@4F5N97=A
M;"!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@W"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G
M:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#$*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(V-PIM<V=I9"`B3F5T=V]R:R(*;7-G
M<W1R("+AGI3AGH[AGY+AGH_AGK;AGHDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C4@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC
M.CDW"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B"FUS9W-T<B`BX9Z`X9Z[X9^&
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@
M(N&>D^&>O.&>G.&?@N&>F^&>@.&>MN&>F^&?@>&>BN&>O.&>D^&>N"(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P
M"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V
M"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@T"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX.`HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(DYE=R!-97-S86=E('1O("5S(@IM<V=S='(@(N&>G^&>
MMN&>FN*`B^&>D.&?DN&>F.&>N.*`B^&>D>&?A2`E<R(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C@@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W
M(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R("+AGI/AGKSAGISAGX+AGIOA
MGJ#AGXKAGY+AGI_AGX'AGJ'AGH3AGXLB"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G<W1R("+A
MGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_AGXOB@(OAGI#A
MGY+AGICAGK@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C0Y
M"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER
M92!O;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS
M9VED(").97=S(@IM<V=S='(@(N&>EN&?D.&>C^&?C.&>F.&>MN&>DR(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C$*;7-G:60@(DYE=W-G<F]U
M<',B"FUS9W-T<B`BX9Z<X9^!X9Z1X9ZWX9Z`X9ZVXH"+X9Z6X9^0X9Z/X9^,
MX9Z8X9ZVX9Z3(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$*(SH@=&5M<&QA=&5S+V1A
M=&$O8W-V;6%P+FEN8SHQ,CD@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,C4*;7-G:60@(DYE>'0B"FUS9W-T<B`BX9Z4X9Z3X9^2X9Z1X9ZVX9Z4X9^+
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA
M<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,S8W(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S<Q"FUS9VED
M(").97AT(&]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(N&>D^&>N.&>@.&>
MMN&>FN&?B>&>MN&>H.&?DN&>@N&?D.&>FB(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEG97(B"FUS9W-T<B`BX9Z3X9ZXX9Z@X9^2X9Z?X9^!X9Z:(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6=E<FEA(@IM<V=S='(@(N&>D^&>N.&>H.&?
MDN&>G^&?@>&>FN&>N.&>F>&?B>&>MB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-S(*;7-G:60@(DYI9VAT(@IM<V=S='(@(N&>F>&>E.&?
MBR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R("+AGI/AGKCA
MGIPB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.38T"FUS9VED(").;R(*;7-G<W1R("+AGI'AGX$B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA
M:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A
M=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C<V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C,W"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,C4Y"FUS9VED(").;R!B
M;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C8W"FUS9VED
M(").;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU
M-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-CD@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,C`*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S8X
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8Y.`IM<V=I9"`B
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-1
M3"!61E,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HW,C4*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M-`IM<V=I9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,T"FUS9VED
M(").;R!D97-T:6YA=&EO;B!S=7!P;&EE9"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`S"FUS9VED(").;R!F:6QE
M('5P;&]A9&5D(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H
M<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C$@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,U"FUS9VED(").
M;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-C(*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(").
M;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D
M871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U
M;W1A('-E="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#@R"FUS
M9VED(").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,S$*;7-G:60@
M(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"!S96YT+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C$T,"!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3<U"FUS
M9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<R"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY.#(*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,`IM<V=I
M9"`B3F\@=F%L=65S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").
M;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@
M(N&>@N&?DN&>F.&>MN&>DR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@
M(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`BX9Z`X9^$X9^'XH"+
MX9Z.X9^)X9Z@X9^2X9Z<X9^)X9Z`(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H
M97)N($UA<FEA;F$@27-L86YD<R(*;7-G<W1R("+AGH#AGX3AGX?B@(OAGICA
MGXGAGK;AGIKAGX#AGH[AGK;B@(OAGI?AGK;AGH+B@(OAGH'AGK;AGH3B@(OA
MGH?AGK[AGH0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R
M("+AGI/AGY#AGIKAGISAGX+AGI\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED
M(").;W0@0F5F;W)E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q.`IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z
M-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T
M96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").;W0@:6UP;&5M
M96YT960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*;7-G:60@(DYO="!S970B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H
M<#HQ-#4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD
M;&5R+G!H<#HQ-C`*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I
M;VY(86YD;&5R+G!H<#HQ-S4*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#D*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR,S8@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`X(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HR,S0*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C(U,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C8Y"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HR.#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,P,0HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$V(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HS,S,*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,V-B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z-#(V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#4@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W-`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z-3DQ(&9R86UE=V]R:R]61E,O5D93+G!H<#HV-CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,O:&]R9&4N<&AP.C@R(&9R86UE=V]R:R]61E,O5D93+VAO
M<F1E+G!H<#HQ,S$*(SH@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$U
M,2!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,3<P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VAO<F1E+G!H<#HQ.#D@9G)A;65W;W)K+U9&4R]61E,O:&]R
M9&4N<&AP.C(P-PHC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z,C(W
M(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HS,S`*;7-G:60@(DYO="!S
M=7!P;W)T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P
M.#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X-PIM<V=I9"`B3F]T
M97,B"FUS9W-T<B`BX9Z%X9^&X9Z.X9ZVX9^&(@H*(SH@<V5R=FEC97,O;V)R
M;W=S97(O:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@
M9V\@8F%C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(N&>
MG.&>M^&>A>&?DN&>AN&>M^&>@.&>MB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-3`*;7-G:60@(DYU;6)E<B(*;7-G<W1R("+AGIOAGX'AGH$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,S"FUS9VED(").=6UB
M97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+AGH7AGX;AGI/AGKWAGI/B@(OA
MGH_AGKWAGJ+AGH#AGY+AGI_AGIHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S<W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,S$*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30U,R!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M
M;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W
M-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Y"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-3$@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T
M:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+
M(@IM<V=S='(@(N&>F>&>F^&?B^&>EN&?DN&>FN&>F"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S$*;7-G:60@(D]B:F5C
M="(*;7-G<W1R("+AGISAGH_AGY+AGI#AGKLB"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$Q,0IM<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P.`IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BX9Z/X9Z[
MX9Z;X9ZV(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDW"FUS9VED(")/
M9F9E;G-E(&9I;'1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S0R"FUS9VED(")/9F9I8V4B"FUS9W-T<B`BX9Z`X9ZVX9Z:
MX9ZWX9Z9X9ZVX9Z;X9^0X9Z9(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O
M<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B
M92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(N&>
MEN&>MN&>@.&?DN&>F>*`B^&>G^&>F.&?DN&>A.&>MN&>C^&?B^*`B^&>A>&>
MMN&>G^&?BR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@IM
M<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`BX9ZBX9Z\X9Z8
MX9^"X9Z3(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D
M(&9O;&1E<G,N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HQ,#`*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW.0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C,Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C0P
M"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+AGI3AGK[A
MGH#B@(OB@(OAGH#AGY+AGI/AGKOAGH3B@(OB@(OAGI3AGH3AGY+AGJ+AGKWA
MGH7B@(OAGI#AGY+AGICAGK@B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C(T-0IM<V=I9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T
M(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4U"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M.`IM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("+AGI3AGY+AGIKA
MGI;AGY#AGI/AGY+AGI+B@(OAGI3AGY+AGIKAGH_AGK?AGI3AGH_AGY+AGH_A
MGK?AGH#AGK;AGIHB"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,34Q"FUS9VED(")/<'1I;VYS(@IM<V=S='(@(N&>A^&>F.&?DN&>FN&>ON&>
MG^*`BR(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,B!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O
M<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C@*;7-G
M:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,30Q"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E
M;7!L871E<RYP:'`Z,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T
M96UP;&%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$Q
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@:6X@
M)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*
M;7-G<W1R("+AGI7AGY+AGI_AGX'AGH3AGY<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/
M=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W!A;2YP:'`Z.#`*;7-G:60@(E!!32!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA
M:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'
M4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS
M9VED(")02%`@0V]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP
M:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I9"`B4$T@3&EG
M:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I
M9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS9VED(")032!3
M=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N
M<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T
M.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0
M861D:6YG(@IM<V=S='(@(N&>A>&>D^&?DN&>F^&?A.&?AR(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`BX9Z4X9^)X9ZVX9Z"X9ZX
MX9Z?X9^2X9Z0X9ZVX9Z3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B
M"FUS9W-T<B`BX9Z4X9^)X9ZVX9ZAX9Z\(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I
M9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R("+AGI3AGXGA
MGK;AGH[AGK;AGICAGXGAGK8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A
M($YE=R!'=6EN96$B"FUS9W-T<B`BX9Z4X9^)X9ZVX9Z6X9Z\X9Z)X9Z\X9Z<
MX9Z@X9^2X9Z"X9ZXX9Z.X9^!(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R
M86=U87DB"FUS9W-T<B`BX9Z4X9^)X9ZVX9Z:X9^)X9ZVX9Z@X9^2X9Z"X9ZV
MX9Z9(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R-@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C8Y('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B4&%S
M<W=O<F0B"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$
MX9ZVX9Z/X9^+(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R
M"FUS9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S(S
M"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U-PIM<V=I9"`B4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`V,0IM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB
M"FUS9W-T<B`BX9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$X9ZVX9Z/
MX9^+PJ#AGY8B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`T,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")087-S=V]R9',@
M;75S="!M871C:"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$Q.2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C(*;7-G:60@(E!A<W1E(@IM<V=S='(@(N&>E.&>M^&>D>&>E^&?
MDN&>A^&>MN&>E.&?BR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BX9Z5X9^2X9Z;X9Z\X9Z<
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E
M;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Y"FUS9VED(")096]P;&4B"FUS9W-T<B`BX9Z8X9Z3X9Z[X9Z?
MX9^2X9Z?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`BX9Z7X9ZVX9Z"X9Z:
MX9Z9(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT
M;6PZ-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#$P"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(N&>DN&?DN&>G.&>ON*`B^&>E.&?DN&>FN&>C^&>M^&>E.&>C^&?
MDN&>C^&>M^&>@.&>MN&>FN*`B^&>C^&?AN&>H.&?@N&>D>&>MN&?AB#AGI;A
MGX'AGIOB@(OAGH7AGKSAGIL@/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(N&>G^&>
MM^&>D>&?DN&>DN&>MR(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4&5R;6ES<VEO;B!<(B5S7"(@;F]T(&1E
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3DP"FUS9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BX9Z?X9ZWX9Z1X9^2X9Z2X9ZW(@H*(SH@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`Y(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,`HC.B!A9&UI
M;B]P97)M<R]I;F1E>"YP:'`Z,C(@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M.`IM<V=I9"`B4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA
M;"!);F9O<FUA=&EO;B(*;7-G<W1R("+AGI;AGY#AGH_AGXSAGICAGK;AGI/B
M@(OAGI7AGY+AGI'AGK;AGIOAGXOB@(OAGH'AGY+AGIOAGKWAGI,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`BX9Z4X9^)X9^!X9Z:X9^)
MX9Z\(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")0971S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&AI;&EP<&EN97,B
M"FUS9W-T<B`BX9Z@X9^2X9Z<X9ZXX9Z;X9ZXX9Z6X9ZXX9Z3(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B
M4&AO;F4B"FUS9W-T<B`BX9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y-`IM<V=I9"`B4&AO=&]S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S
M='(@(N&>EN&>N.&>C^&>@>&>MN&>F>&>FN&>M^&>DR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE
M;',B"FUS9W-T<B`BX9Z7X9ZXX9Z`X9Z?X9^"X9Z;(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")0;&%T:71U9&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N
M;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U-S`*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO;G1H
M(&%N9"!A('EE87(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@
M82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U"FUS9VED(")0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-C4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-#4U"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED
M(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I
M9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS9VED("(B"B)0;&5A<V4@
M<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@
M=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R
M("+AGI3AGXGAGKSAGJ'AGKSAGHDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C(*;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HU,#,*;7-G:60@(E!O;&QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(N&>EN&?
MD.&>FN&>D>&>N^&>F>&>H.&?DN&>@N&>MN&>F^&?BR(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM
M<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I
M9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3$*;7-G:60@(E!R96-I
M<&ET871I;VX\8G(@+SYC:&%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+VQD87`N<&AP.C$S,PIM<V=I9"`B4')E9G-?;&1A<#H@
M4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S-PIM<V=I9"`B4')E<W-U<F4B
M"FUS9W-T<B`BX9Z?X9Z8X9^2X9Z6X9ZVX9Z2(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-S$*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,CD*
M;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`BX9Z8X9Z^X9Z;XH"+X9Z'X9ZVXH"+XH"+XH"+
MX9Z8X9Z[X9Z3(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G
M92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HS-3<@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HS-C$*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM
M<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z
M,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R
M;V)L96TN<&AP.C$R-PIM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@U"FUS9VED
M(")0<F]J96-T<R(*;7-G<W1R("+AGH+AGICAGY+AGIKAGX3AGH0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q.38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-PIM
M<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S
M='(@(N&>@.&>O.&>D^&>G^&?A.*`B^&>G^&>MN&>DN&>MN&>FN&>CN&?B"(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V"FUS9VED
M(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME
M>2!);F9O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@
M9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS9W-T<B`BX9Z6X9^0X9Z:X9Z/
MX9Z\X9Z:X9ZXX9Z`X9Z\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B
M"FUS9W-T<B`BX9Z`X9ZVX9Z/X9ZV(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C8S"FUS9VED(")1=65R>2(*;7-G<W1R("+AGI_AGX;AGH[AGKWAGIKB@(LB
M"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*;7-G:60@(E%U;W1A(@IM
M<V=S='(@(N&>@.&>O.&>C^&>MB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L
M:6,@2V5Y("@E9"!B:70I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-S(*;7-G:60@(E)A9&EO('-E;&5C=&EO;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M-`IM<V=I9"`B4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-@IM<V=I9"`B4F%I;B!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM
M<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A
M=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.CDQ"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(N&>HN&>MN&>DR(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED
M(")296%D(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI
M;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@
M9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N
M9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S('EO=7(@;&%S="!A8W1I
M;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T
M<B`BX9Z2X9^2X9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z:X9Z?X9^+
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-0IM<V=I9"`B4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-#4*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I
M97<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHY-`IM<V=I9"`B4F5F<F5S:"!R871E.B(*;7-G<W1R("+AGJ+AGH_AGY+A
MGIKAGK;B@(OAGI+AGY+AGISAGK[B@(OAGK+AGY+AGIGB@(OAGI_AGY+AGIKA
MGI_AGXO"H.&?EB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#(*;7-G:60@(E)E;&%T:6]N<VAI
M<"!"<F]W<V5R(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC
M;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G
M:60@(E)E;&]A9"(*;7-G<W1R("+AGI7AGY+AGI'AGKOAGH#B@(OAGJ'AGK[A
MGH3B@(OAGISAGK?AGHDB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S.`IM
M<V=I9"`B4F5M87)K<R(*;7-G<W1R("+AGH#AGX;AGH[AGH_AGXOB@(OAGI_A
MGICAGY+AGH+AGK;AGIOAGXLB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$W"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@
M*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z."!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R("+AGIGAGH#B
M@(OAGH7AGX'AGHDB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*
M;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED
M(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@
M=&AE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D
M92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC
M.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X(&9R
M86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HQ-S,*;7-G:60@(E)E<75E<W0@
M8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3`*
M;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S8@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HW,#0@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-C$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C0Q(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,S0*;7-G:60@(E)E<75I
M<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T,PHC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U)E;F1E<F5R+G!H<#HS,3D@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W
M"FUS9VED(")297-E="(*;7-G<W1R("+AGH#AGX;AGH[AGH_AGXOB@(OAGJ'A
MGK[AGH3B@(OAGISAGK?AGHDB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO
M=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP
M.C$S,`IM<V=I9"`B4F5S=&]R92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@
M861M:6XO<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@
M(N&>F^&>D>&?DN&>DN*`B^&>E>&>FR(*"B,Z('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I
M9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`BX9Z/X9^2X9Z:X9ZAX9Z4
MX9^+XH"+X9Z1X9^%XH"+X9Z'X9Z8X9^2X9Z:X9Z^X9Z?(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A
M<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E)E=6YI
M;VXB"FUS9W-T<B`BX9Z:X9ZXX9ZBX9Z[X9Z9X9Z3X9ZXX9Z9X9^)X9Z[X9Z$
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,U"FUS9VED(")2
M:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")2:61D;&5S(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`BXH"+X9Z?X9^2X9Z/X9ZVX9^&
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-`IM<V=I9"`B4FEG
M:'0@:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,3`*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED
M(")2;VQE(@IM<V=S='(@(N&>C^&>O>&>D^&>MN&>D>&>N"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(*;7-G:60@(E)O;6%N:6$B"FUS9W-T<B`BX9Z:X9Z\X9Z8X9^)X9ZV
MX9Z3X9ZX(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(R-`IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS9VED(")2
M;W1A=&4@3&5F="(*;7-G<W1R("+AGI3AGH3AGY+AGISAGK?AGIOB@(OAGI'A
MGX7B@(OAGH;AGY+AGISAGX'AGH0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C(W"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS
M9W-T<B`BX9Z4X9Z$X9^2X9Z<X9ZWX9Z;XH"+X9Z1X9^%XH"+X9Z?X9^2X9Z*
MX9ZVX9^&(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G
M:60@(E)O=W,Z(@IM<V=S='(@(N&>A^&>O>&>FN*`B^&>BN&?@>&>@,*@X9^6
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,PIM<V=I9"`B4G5L97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,`IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T
M<B`BX9Z:X9Z/X9^+XH"+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA
M;B!&961E<F%T:6]N(@IM<V=S='(@(N&>G^&>H.&>EN&?D.&>D^&?DN&>DN*`
MB^&>FN&>N^&>G^&?DN&>G^&?BN&>N"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@
M(E)W86YD82(*;7-G<W1R("+AGIKAGISAGXGAGK;AGI/AGXOAGHKAGK8B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B
M4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3
M+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,@IM<V=I9"`B4T%33"!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(P"FUS9VED(")335,@365S<V%G:6YG
M(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HR,0IM<V=I9"`B
M4U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,R.#4*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU
M<',B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0T
M-PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*
M;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,34S
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G
M<W1R("+AGI_AGH3AGXOB@(OAGJ#AGX'AGJ'AGX'AGH[AGK8B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("+A
MGI_AGH3AGXOAGH/AGKCAGH\@X9Z3X9ZWX9Z$(.&>D^&?@>&>G.&>N.&>GR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`BX9Z?
MX9Z$X9^+X9Z;X9Z\X9Z?X9^*X9ZXX9Z9X9^)X9ZV(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("+A
MGI_AGH3AGXOB@(OAGI;AGY+AGIGAGX+AGIH@X9Z3X9ZWX9Z$(.&>F.&>N.&>
M@N&>N^&>F>&>HN&?@>&>H>&>N^&>A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@
M(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(N&>
MG^&>A.&?B^&>G.&>MN&?AN&>A.&>G^&>A.&?BR#AGI/AGK?AGH0@XH"+X9Z@
MX9^2X9Z"X9^2X9Z:X9ZXX9Z.X9ZVX9Z,X9ZXX9Z3(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F
M<F%M92`H7W-E;&8I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E-A;6]A(@IM<V=S='(@(N&>G^&>MN&>F.&>O.&>HN&>MB(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BX9Z?X9ZVX9Z3X9^+
MX9Z8X9^)X9ZVX9Z:X9ZXX9Z.X9Z\(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE(&%N9"!0
M<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`BX9ZBX9ZVX9Z:
MX9^)X9ZVX9Z4X9^+XH"+X9Z4X9^*X9ZXX9Z?X9ZVX9ZBX9Z\X9Z,X9ZX(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q-0IM<V=I9"`B4V%V
M92(*;7-G<W1R("+AGIKAGH#AGY+AGI_AGK;B@(OB@(OAGI'AGKOAGH#B@(OB
M@(LB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(N&>FN&>
M@.&?DN&>G^&>MN*`B^&>D>&>N^&>@.*`BR#AGH?AGICAGY+AGIKAGK[AGI\B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y
M;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L('!H<"UF;W)M870*
M;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4P"FUS9VED(")38V%T=&5R960@5"U3=&]R;7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")38VEE;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$V"FUS9VED(")3
M96%R8V@B"FUS9W-T<B`BX9Z?X9^2X9Z<X9^"X9Z$X9Z:X9Z`(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-@IM<V=I9"`B4V5A<F-H($5N9VEN
M97,B"FUS9W-T<B`BX9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3XH"+X9Z?X9^2X9Z<
MX9^"X9Z$X9Z:X9Z`(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDV
M-@IM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#,*;7-G:60@(E-E;&5C
M="!A(&1A=&4B"FUS9W-T<B`BX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z`X9ZVX9Z;
MX9Z4X9Z:X9ZWX9Z%X9^2X9Z&X9^!X9Z1(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D9"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S"FUS
M9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V
M97(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S0*;7-G
M:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BX9Z'X9^2X9Z:X9Z^X9Z?XH"+X9Z1
MX9ZVX9^&X9Z$X9ZBX9Z?X9^+(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8U-`IM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX-S$*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-0IM
M<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`BX9Z'X9^2X9Z:X9Z^X9Z?XH"+
MX9Z"X9^2X9Z8X9ZVX9Z3(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W
M"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P
M87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI
M;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")3
M96QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H
M:6YG(&9I96QD<RXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Q,`IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4R"FUS9VED(")3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")396YD
M(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,#0P"FUS9VED(")396YD(%--4R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S
M='(@(N&>G^&?@>&>CN&?@>&>H.&?DN&>@N&>MN&>F^&?BR(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S(X"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`X
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#8*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM
M<V=I9"`B4V5P=&5M8F5R(@IM<V=S='(@(N&>@.&>B>&?DN&>B>&>MB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")3
M97)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T<B`BX9Z?X9^"X9Z4X9^*X9ZX
M(.&>D^&>M^&>A"#AGICAGXGAGKOAGH3AGH_AGX'AGH[AGX'AGJ#AGY+AGH#A
MGY+AGIKAGKPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,@IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G<W1R("+AGIOAGX'AGH'B
M@(OAGI_AGICAGY+AGH+AGK;AGIOAGXLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34T"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S:6]N<RYP
M:'`Z,C<*;7-G:60@(E-E<W-I;VX@061M:6XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS
M9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`BX9Z?X9Z8X9^0
MX9Z9(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,R,@IM<V=I9"`B
M4V5T(@IM<V=S='(@(N&>@.&?AN&>CN&>C^&?BR(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW.0IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X"FUS
M9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A
M8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@W"FUS9VED(")3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#$*;7-G:60@(B(*(E-E
M="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G
M92!R969R97-H:6YG+"!A;F0@;W1H97(@(@HB9&ES<&QA>2!O<'1I;VYS+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"FUS9VED
M(")3971U<"(*;7-G<W1R("+AGHKAGX;AGJ'AGK[AGH0B"@HC.B!T96UP;&%T
M97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3@P"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(N&>
MG^&>N.&>G^&?DN&>H.&?@N&>FR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HU,3(*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM
M87)Y(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R("+AGI3AGH3AGY+A
MGJ#AGK;AGHDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,34U"FUS9VED
M("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D
M(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@
M(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W,PIM<V=I9"`B
M4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`V"FUS9VED(")3:&]W('!I8VME
M<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,P"FUS
M9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T
M:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P
M"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S<Q"FUS9VED(")3:&]W('5P;&]A9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I
M9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3:&]W
M97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0W,0IM<V=I9"`B4VAR
M:6YK(@IM<V=S='(@(N&>E.&>A.&?DN&>FN&>O>&>B2(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-S8R"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.#(T"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3`S-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$P-S4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HQ,3`T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z,3$S-PIM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R
M("+AGI_AGX'AGIKAGXGAGK;AGJ'AGX'AGJ+AGKSAGI,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8W"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`BX9Z@X9Z/X9^2X9Z0X9Z;
MX9^!X9Z!X9ZV(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E(@IM<V=S='(@(N&>G^&>
MN>&>A.&?DN&>H.&>E.&>N^&>FN&>N"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3(S"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,38*;7-G:60@(E-I>F4B"FUS9W-T<B`BX9Z1X9^&X9Z@X9^&
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`BX9Z?X9^2X9Z;X9Z\
MX9Z<X9^)X9ZVX9Z"X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N
M:6$B"FUS9W-T<B`BX9Z?X9^2X9Z;X9Z\X9Z<X9^)X9ZVX9Z3X9ZX(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@
M(E-N;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS
M9VED(")3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R
M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W97)S($QA=&4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E-N
M;W<@9&5P=&@Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(Y-`IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM
M<V=S='(@(N&>@.&?A.&?A^*`B^&>G^&>O.&>H>&>O.&>F.&?B>&>O.&>DR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`BX9Z?X9Z\
MX9Z8X9^)X9ZVX9Z;X9ZX(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U
M"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,3D*;7-G:60@(E-O<G0@;W)D97(@<V5L96-T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-#<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC
M82(*;7-G<W1R("+AGJ+AGK;AGJ#AGY+AGIKAGK?AGH#B@(OB@(OAGH'AGK;A
MGH3B@(OAGH_AGY+AGI3AGKSAGH0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X-@IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@
M=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`BX9Z@X9^2X9Z?
MX9Z`X9Z@X9^2X9Z?X9^*X9ZXXH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\
MX9Z$(.&>D^&>M^&>A"#AGH#AGX3AGX?AGI_AGK;AGX;AGH3AGISAGK?AGH7B
M@(OAGH'AGK;AGH3B@(OAGH_AGY+AGI3AGKSAGH0B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T
M:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W
M965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B
M971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q.0IM<V=I9"`B4W!A8V5R
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("+AGH+A
MGICAGY+AGIOAGK;AGH\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")3<&%I;B(*;7-G
M<W1R("+AGJ+AGX'AGI_AGXGAGY+AGI3AGK;AGHDB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3`W"FUS9VED(")3<&%M(@IM<V=S='(@(N&>G^&>
MMN&>FN*`B^&>I>&>C^*`B^&>E.&>MN&>D^*`B^&>@.&>MN&>FB(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T
M97(@26YP=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L;"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(N&>G^&?
MDN&>FN&>N.&>F^&>A.&?DN&>@.&>MB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW,2!L:6(O0FQO8VLO;65T87(N<&AP.C@V"FUS9VED(")3
M=&%N9&%R9"(*;7-G<W1R("+AGH'AGY+AGI/AGK;AGH_B@(OAGH+AGX;AGIKA
MGKPB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C<*;7-G:60@(E-T87(@
M5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#(*;7-G:60@(E-T87)T
M('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS
M9VED(")3=&%T=7,B"FUS9W-T<B`BX9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.`IM<V=I9"`B4W1O
M<F%G92!F;W)M870B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`BX9Z4X9Z3X9^2
MX9Z1X9ZVX9Z/X9^+XH"+X9Z&X9Z\X9Z/(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,0IM<V=I9"`B4W1R:7`@
M9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I
M9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP
M.C<S"FUS9VED(")3=6)J96-T(@IM<V=S='(@(N&>E.&?DN&>FN&>DN&>MN&>
MD^*`B^&>E.&>D2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S-B!F
M<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,38*;7-G:60@(E-U
M8FUI="(*;7-G<W1R("+AGHKAGK;AGH#AGXOB@(OAGI_AGY+AGI/AGKXB"@HC
M.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI
M='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N
M(&%P<')O=F5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T
M<B`BX9ZBX9Z`X9^2X9Z?X9Z:XH"+X9Z/X9Z\X9Z%XH"+X9Z`X9^2X9Z:X9^$
MX9Z8(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP
M.C(X"FUS9VED(")3=6-C97-S(@IM<V=S='(@(N&>A^&?A.&>@N&>A^&?D.&>
MF2(*"B,Z(&%D;6EN+W5S97(N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E
M<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS
M9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F<F]M('1H92!S
M>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8R
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@
M8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,38X"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B
MX9Z?X9^*X9Z\X9Z*X9Z$X9^+(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G
M<W1R("+AGI_AGH3AGY+AGH'AGX'AGI0B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-C4*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]S=6YR:7-E+G!H<#HV.`IM<V=I9"`B4W5N(%-E="(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,`IM
M<V=I9"`B4W5N;GDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(Q,`IM<V=I9"`B4W5N<FES92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#D*;7-G:60@(E-U;G)I<V4Z("(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$S
M"FUS9VED(")3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM
M<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`BX9ZBX9Z`X9^2X9Z?X9Z:XH"+
MX9Z/X9Z\X9Z%XH"+X9Z;X9Z^(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,Y-`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("+AGH+AGK;AGX;AGI'A
MGY+AGIHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=7)I;F%M92(*;7-G<W1R
M("+AGI_AGXKAGKSAGIKAGKCAGH[AGK;AGICAGK@B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N
M($UA>65N(@IM<V=S='(@(N&>G^&?DN&>G.&>MN&>F^&?B^&>E.&>MN&>CR#A
MGI/AGK?AGH0@X9Z@X9^2X9Z?X9Z$X9^+X9Z8X9^)X9ZVX9Z9X9^!X9Z3(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(N&>G^&?
MDN&>G.&>MN&>H.&?DN&>G^&?BN&>N.&>H>&>A.&?BR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-W961E;B(*;7-G<W1R("+AGI_AGXKAGKOAGIGAGJ+AGX+A
MGHHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`B
MX9Z?X9^2X9Z<X9^*X9ZXX9Z?(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#8*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")3>7)I86X@07)A8B!297!U8FQI
M8R(*;7-G<W1R("+AGI_AGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OA
MGJ+AGK;AGIKAGXGAGK;AGI3AGXL@X9Z?X9^*X9ZXX9Z:X9ZX(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C$*;7-G:60@(E0M
M4W1O<FTB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8S"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-`IM<V=I9"`B5"U3=&]R;7,@
M16%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N
M<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*;7-G:60@(E1A8FQE(@IM<V=S='(@
M(N&>C^&>MN&>FN&>MN&>A"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E<G1I
M97,B"FUS9W-T<B`BX9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z?X9Z8X9^2X9Z4
MX9Z/X9^2X9Z/X9ZWXH"+X9Z/X9ZVX9Z:X9ZVX9Z$(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B;&4@
M4V5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S(*;7-G:60@(E1A8FQE('!R;W!E<G1I97,B
M"FUS9W-T<B`BX9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+X9Z?X9Z8X9^2X9Z4X9Z/
MX9^2X9Z/X9ZWXH"+X9Z:X9Z4X9Z?X9^+XH"+XH"+X9Z/X9ZVX9Z:X9ZVX9Z$
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@
M(N&>C^&?@^&>G.&?B>&>MN&>D^&?BR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1A:FEK
M:7-T86XB"FUS9W-T<B`BX9Z/X9ZVX9Z*X9Z@X9^2X9Z?X9^*X9ZXX9Z"X9ZX
MX9Z?X9^2X9Z/X9Z$X9^+(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"FUS9VED(")487)G
M970Z(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#<P
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.38*;7-G:60@(E1A<VMS(@IM
M<V=S='(@(N&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@
M3G5M8F5R(@IM<V=S='(@(N&>F^&?@>&>@>*`B^&>D>&>O.&>FN&>G^&?D.&>
MEN&?DN&>D2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`R"FUS9VED(")4
M96UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(R-@IM<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`BX9Z?
MX9ZXX9Z/X9Z[X9Z.X9^2X9Z@X9Z7X9ZVX9Z6(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-PIM<V=I9"`B5&5M<&5R871U<F4Z("(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"B,L
M('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E
M<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L
M871E+U1E;7!L871E+G!H<#HV.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B5&5X="(*
M;7-G<W1R("+AGJ+AGH_AGY+AGI#AGI3AGI$B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BX9Z/X9^"
MX9ZBX9Z/X9^2X9Z0X9Z4X9Z1(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED
M(")4:&%I("A425,M-C(P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y"FUS
M9VED(")4:&%I;&%N9"(*;7-G<W1R("+AGI#AGX,B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@U,0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAI
M<W1O<GDO2&ES=&]R>2YP:'`Z-C,*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E
M;2!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB
M)7-<(B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]"
M;V]K+G!H<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN=&5N
M86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI
M<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES
M<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO
M;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B;W1T;VT@<VED92!O
M;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3$W,@IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S
M:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-#(*;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8V]N9FER
M;2YP:'`Z,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&5M86EL(&%D
M9')E<W,@)7,@:&%S(&)E96X@861D960@=&\@>6]U<B!I9&5N=&ET:65S+B!9
M;W4@8V%N(&-L;W-E('1H:7,@(@HB=VEN9&]W(&YO=RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+G!H<#HQ,38*;7-G:60@(E1H92!E
M;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE
M8W1I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3<W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-S`@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,C(Y"FUS9VED(")4:&4@9FEL92!C86YN;W0@8F4@8V]P
M:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W
M;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D
M=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O
M('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E
M<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E
M;B!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ
M,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB)7-<(B!H
M87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@
M;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-3<*;7-G:60@(B(*(E1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TU$3BYP:'`Z,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<
M(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X
M-0IM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@
M8V]M<&]S92!P86=E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HY-`IM<V=I9"`B5&AE(&YE=R!F<F]M(&%D9')E<W,@8V%N)W0@8F4@=F5R
M:69I960L('1R>2!A9V%I;B!L871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE(&YU;6)E<B!O
M9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O
M<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T
M7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P
M<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D
M96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R
M:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O
M=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI
M9VAL:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M
M<V5X8V5L+G!H<#HS,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')O
M9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T
M(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U;W1E(&-H87)A
M8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N9"!S:61E(&]N
M;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z
M-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<W!E8VEF:65D
M(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S$S"FUS
M9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T
M97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*
M;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P;&]A9&5D(&1A
M=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W
M;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D
M(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-30@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Q-0IM<V=I9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES
M(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T
M;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+V-O;F9I<FTN<&AP.C$W('-E<G9I8V5S+V-O;F9I<FTN<&AP.C(Q"FUS9VED
M(")4:&5R92!A<F4@;F\@96UA:6P@861D<F5S<V5S('1O(&-O;F9I<FTN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X
M"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T
M-0IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L
M87EE9"!I;FQI;F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E
M('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@
M96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO
M=7-E<BYP:'`Z-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@
M<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ
M("(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S
M7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDQ-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E
M<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H
M<#HY,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S
M(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T
M<B`BX9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]X9Z9(.&>
M@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>E.&>A.&?DN&>H.&>MN&>
MB>*`B^&>E>&?DN&>D^&?@N&>@.*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>
MFN*`B^&>D^&?@>&?AR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN
M9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E
M("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A
M:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,@IM<V=I
M9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X
M"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T(&%P
M<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED
M(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,X
M"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC
M:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C$S-`IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.
M("AH='1P.B\O=VEN<&QC+F-O;2D@(@HB9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R\B"B)S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H
M<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@
M5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N
M="!W:71H("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX,B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#8Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$P.3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R-C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#`V"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$U-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@T
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38V(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,3,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Q-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(R.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$V(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C8T."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S`@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S,P.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$V(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,X,C0*;7-G:60@(E1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$P-CD*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I
M;G1E9V5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0R-`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU
M;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3$R-PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3DS
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,CD*;7-G
M:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I
M;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F
M)RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38U
M"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4
M;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB
M8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F
M;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L
M96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I
M(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E
M<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ.#(*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)
M+G!H<#HQ,C0*;7-G:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HS-0IM<V=I9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A
M;B!/<'1I;VYS('=I;F1O=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM<V=I9"`B5&AU;F1E<B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4P"FUS9VED
M(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T,S,@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")4:6UE(@IM<V=S='(@(N&>EN&?@>&>F^*`B^&>G.&?@>&>F^&>MN*`BR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#(*;7-G:60@(E1I;64@
M5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(R
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("+AGI'AGY+AGIKAGH3AGXOB
M@(OAGI'AGY+AGIKAGK;AGIGB@(OB@(OB@(OB@(OAGI;AGX'AGIOB@(OB@(OA
MGISAGX'AGIOAGK;B@(LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+AGH7AGX;A
MGH[AGH3B@(OAGH?AGK[AGH0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(N&>D>&?A2(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-3(*;7-G:60@(B(*
M(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT
M<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI
M;F<N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,#,*;7-G:60@(E1O9&%Y(@IM<V=S='(@(N&>D.&?DN&>A.&?@^*`B^&>
MD^&?@>&?AR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(N&>C^&>O.&>
MH.&?DN&>@N&?A"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O:V5L874B"FUS
M9W-T<B`BX9Z/X9Z\X9Z`X9^!X9ZAX9ZVX9ZBX9^*X9Z\(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,P-0IM<V=I9"`B5&]M;W)R;W<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B
MX9Z/X9Z[X9Z$X9Z@X9^2X9Z"X9^$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T
M<B`BX9Z`X9^&X9Z6X9Z\X9Z;(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE("A?=&]P*2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C@*;7-G:60@
M(E1R86YS;&%T:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(N&>D>&?DN&>FN&>N.&>
MD^&>N.&>BN&>MN&>BB#AGI/AGK?AGH3B@(OB@(L@X9Z/X9Z\X9Z4X9ZVX9Z@
MX9^2X9Z"X9^$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y.`IM
M<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM<V=S='(@
M(N&>D>&>N^&>F>&>CN&?@>&>G^&?BN&>N"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U<FME>2(*;7-G<W1R("+AGI'AGKWAGIKAGH+AGK@B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM
M.2DB"FUS9W-T<B`BX9Z1X9Z]X9Z:X9Z"X9ZX("A)4T\M.#@U.2TY*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("+AGI'A
MGKWAGH+AGICAGX'AGI/AGKCAGI_AGY+AGH_AGH3AGXLB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B
MX9Z`X9^$X9^'XH"+X9Z1X9Z]X9Z`(.&>D^&>M^&>A.*`BR#AGH#AGX/AGH#A
MGKSAGI\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A;'4B"FUS9W-T<B`B
MX9Z1X9Z[X9Z9X9Z<X9^)X9ZVX9Z;X9Z[X9Z9(@H*(SH@9G)A;65W;W)K+T-,
M22]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G
M:60@(E4N5BX@:6YD97@Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N
M<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E52
M3"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`BX9ZBX9^*X9Z\X9Z@X9^2X9Z"
MX9Z$X9^+X9Z*X9ZV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*
M;7-G<W1R("+AGJ+AGXKAGKOAGIGAGH#AGY+AGIKAGX+AGI,B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HT,C(*;7-G:60@(E5N86)L92!T;R!A
M8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,Y
M-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@)7,O)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S@V"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&%N9V4@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,C,W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.3@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HQ,#8S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HX-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I
M;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,C,U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(T,`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`T(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C(Q-PIM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93
M(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z,S<P"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,V-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR
M-C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R-`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR.3`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<U
M"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H
M<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z
M-SD*;7-G:60@(E5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(X(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E
M;7!T>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0Q(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z-#$X"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S4V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S0W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,S-2!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HT-#,@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT-34*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HR,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C,Q,R!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,Q-`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDQ"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M.3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0X"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B!<(B5S
M7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#,R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@=&\@97AT
M<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0
M+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#8@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ-S0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W
M.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HQ,#8*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HV-3(@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X-R!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$*;7-G:60@(E5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HX,2!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HX-@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-#`@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<V"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#4V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O
M;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-SD*;7-G
M:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`T"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z
M(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED
M(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S4U"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C<Q
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV,C`@9G)A
M;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,T.2!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(Y,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Y"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U
M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ.#D*
M;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(Y,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30V"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+AGH+AGKSAGI_B@(OAGI3AGI/A
MGY+AGI'AGK;AGH_AGXOB@(OAGH#AGY+AGIKAGX3AGI@B"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,PIM<V=I9"`B56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,`IM
M<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@T"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S
M+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS
M9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z4X9ZVX9Z3XH"+X9Z:X9^`X9Z4X9Z%X9^&
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(E5N:6-O9&4@
M*%541BTX*2(*;7-G<W1R("+AGIGAGKSAGI/AGKCAGH#AGKSAGHH@*%541BTX
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*
M;7-G<W1R("+AGJ+AGK;AGIKAGXGAGK;AGI3AGXOB@(OAGIKAGKWAGI@B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(N&>
MA>&>@.&?DN&>FN*`B^&>E^&>EN*`B^&>HN&>A.&?B^&>@N&?DN&>F^&?@>&>
MGR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T
M<B`BX9Z?X9Z@X9Z:X9Z*X9^2X9Z+X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z`(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>AN&?DN&>A.&>
MMN&>F>&?E^*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>H.&>FN&>BN&?DN&>B^*`
MB^&>HN&>MN&>F.&?@>&>FN&>M^&>@"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HV-R!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS9VED(")5
M;FET<R(*;7-G<W1R("+AGJ_AGH#AGH_AGK8B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#,P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-3@*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z?
MX9^2X9Z"X9ZVX9Z;X9^+(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED
M("A!4$D@365S<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK
M;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34R"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G
M:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+
MX9Z(X9^2X9Z8X9^$X9^'(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP
M=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L
M;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@
M82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B56YS
M=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI
M<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`BX9Z2X9^2X9Z<X9Z^
MXH"+X9ZRX9^2X9Z9XH"+X9Z1X9ZVX9Z3X9^+XH"+X9Z?X9Z8X9^0X9Z9(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-@IM<V=I9"`B57!D871E('5S
M97(B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO
M<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"FUS9VED(")5
M<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("+AGI7AGY+A
MGI'AGKOAGH#B@(OAGJ'AGK[AGH0B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@V"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@
M9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I
M9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS
M9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`BX9ZBX9^*X9Z[X9Z9X9Z:
MX9^)X9ZVX9Z@X9^2X9Z"X9ZVX9Z9(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@
M4U-,(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*
M;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@
M24U34"!S97)V97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G
M<F]U<',O961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`BX9ZBX9^2
MX9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+U)E9VES=')Y+G!H<#HW-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO
M;B(*;7-G<W1R("+AGH#AGK;AGIKB@(OAGH+AGY+AGIKAGI3AGXOAGH+AGY+A
MGIKAGH3B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKXB"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(T-0IM<V=I9"`B57-E<B!/<'1I
M;VYS(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G:60@(E5S97(@
M4F5G:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T
M:&ES('-I=&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV-"!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`BX9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:
MX9Z^(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E
M>&ES=',N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHX-PIM<V=I9"`B57-E<FYA;64Z(@IM<V=S='(@(N&>B.&?DN&>F.&?
MA.&?A^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>OL*@X9^6(@H*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z
M("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(N&>HN&?
MBN&>O.&>H.&?DN&>G^&>E.&?@>&>@N&>N.&>G^&?DN&>C^&>A.&?BR(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$W,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-C4*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HQ,C<*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS
M(&9O=6YD(&EN8VQU9&4Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B5F%L:61I='DB"FUS9W-T
M<B`BX9Z?X9Z[X9Z6X9Z;X9Z7X9ZVX9Z6(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.3<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU
M92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX-C`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I<R!O=F5R('1H92!M
M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(U,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M,C<T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,C0@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDR,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU97,B"FUS9W-T<B`BX9Z/
MX9Z8X9^2X9Z;X9^#(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DT"FUS9VED(")686QU97,@
M=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I
M9"`B5F%N=6%T=2(*;7-G<W1R("+AGISAGXGAGK;AGI/AGKOAGIGAGJ+AGK;A
MGI'AGKOAGIDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,X
M"FUS9VED(")687)I86)L92(*;7-G<W1R("+AGJ+AGI#AGX'AGIHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`BX9Z<X9^!X9Z.
MX9^!X9Z@X9^2X9Z?X9Z[X9Z9X9ZBX9^!X9ZAX9ZV(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G:60@(E9E<FEF:6-A=&EO
M;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E
M9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R("+AGH#AGX;A
MGH[AGX(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C0R"FUS9VED
M(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`BX9Z`X9ZVX9Z:XH"+X9Z/X9^2
MX9Z:X9Z]X9Z/XH"+X9Z6X9ZWX9Z3X9ZWX9Z/X9^2X9Z9XH"+X9Z`X9^&X9Z.
MX9^"(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM
M<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-S$*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM<V=I9"`B5FEE=&YA;65S92`H5DE3
M0TE)*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HY-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G
M<W1R("+AGICAGK[AGIL@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS
M"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5
M+E,N(@IM<V=S='(@(N&>@.&?A.&?A^*`B^&>G.&>N.&>A^&>N.&>DR#AGI_A
MGJ#AGIKAGHKAGY+AGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH`B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O
M9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS
M9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM
M<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T<B`BX9Z<X9^)X9ZVX9Z;
MX9ZXX9Z?(.&>D^&>M^&>A"#AGJ#AGY+AGISAGXKAGKSB@(OAGI'AGKOAGIGA
MGH[AGK8B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C$R-"!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M.#,*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`BX9Z6X9^2X9Z:X9Z8X9ZVX9Z3
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU
M.`IM<V=I9"`B5V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,T"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3D*;7-G:60@
M(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")7
M96(B"FUS9W-T<B`BX9Z<X9ZWX9Z4(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C0U,PIM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`BX9Z/X9^&X9Z4
MX9Z3X9^+X9Z4X9Z.X9^2X9Z/X9ZVX9Z)(@H*(SH@9G)A;65W;W)K+TUA:6YT
M96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S
M='(@(N&>FN&>MN&>F^&?B^*`B^&>G^&>E.&?DN&>BN&>MN&>H.&?C2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")796QC;VUE
M(@IM<V=S='(@(N&>G^&>O.&>F.*`B^&>G^&?DN&>G.&>MN&>@N&>F.&>D^&?
MC2(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC
M;VUE('1O("5S(@IM<V=S='(@(N&>G^&>O.&>F.*`B^&>G^&?DN&>G.&>MN&>
M@N&>F.&>D^&?C>*`B^&>F.&>@.*`B^&>@.&>MN&>D^&?BR`E<R(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B
M5V5S=&5R;B`H25-/+3@X-3DM,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3(*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S=&5R;B!386AA<F$B
M"FUS9W-T<B`BX9Z?X9ZVX9Z@X9ZVX9Z:X9^)X9ZVXH"+X9Z!X9ZVX9Z$XH"+
MX9Z;X9ZWX9Z%(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D
M:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$P-C(*;7-G:60@(E=H97)E:7,@075S=')A;&EA(&UA
M<"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@
M(E=H:6-H('!H87-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,V"FUS9VED(")7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#0*;7-G:60@
M(E=I9'1H(@IM<V=S='(@(N&>D>&>D>&>N>&>A.*`BR(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,3@*;7-G:60@(E=I9'1H(&EN($-34R!U;FET
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"B,L
M('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS
M9VED(")7:61T:"!U;FET(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U"FUS9VED(")7:61T:#HB"FUS
M9W-T<B`BX9Z1X9Z1X9ZYX9Z$(.&?EB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HU,CD*;7-G:60@(E=I:VDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,R!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I
M9"`B5VEN9"!%87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.CDR"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38X"FUS9VED(")7:6YD.B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,V"FUS
M9VED(")7:6YD.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8Y"FUS9VED(")7:7-D;VTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C(Q,@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B
MX9Z4X9Z)X9^2X9Z'X9ZXXH"+X9Z4X9^2X9Z:X9ZVX9Z0X9^2X9Z3X9ZV(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C<P"FUS9VED(")7;W)K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(N&>HN&>MN&>G^&>
MF>&>BN&?DN&>B^&>MN&>D^*`B^&>@.&>D^&?DN&>F^&?@N&>A.*`B^&>DN&?
MDN&>G.&>ON*`B^&>@.&>MN&>FB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G:60@(E=O<FL@4&AO;F4B"FUS9W-T
M<B`BX9Z1X9Z\X9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+XH"+XH"+X9Z`X9Z3X9^2
MX9Z;X9^"X9Z$XH"+XH"+XH"+X9Z2X9^2X9Z<X9Z^X9Z`X9ZVX9Z:(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F
M:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(T"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-3D*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C@S"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B65DB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-30*
M;7-G:60@(EE965DB"FUS9W-T<B`B65E962(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HQ,3`Y"FUS9VED(")986AO;R$@;6%P
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+AGI3AGY+AGIKA
MGH7AGK;AGX;AGH;AGY+AGI/AGK;AGX8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED
M(")996UE;B(*;7-G<W1R("+AGIGAGX'AGICAGX+AGI,B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS9VED(")997,B
M"FUS9W-T<B`BX9Z4X9ZVX9Z1+^&>A>&>MN&>GR(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@
M06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HX
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,C4*;7-G:60@(EEO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA
M=F4@=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]P:'!G=RYP:'`Z,3$W"FUS
M9VED(")9;W4@9&ED(&YO="!A=71H96YT:6-A=&4N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-C,@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DX,PIM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T
M82]$871A+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I
M9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O
M('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@
M:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S<Q"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(EEO=2!H879E(')E<75E<W1E9"!T;R!A9&0@=&AE(&5M86EL(&%D
M9')E<W,@7"(E<UPB('1O('1H92!L:7-T(&]F('EO=7(@(@HB<&5R<V]N86P@
M96UA:6P@861D<F5S<V5S+EQN(@HB7&XB"B)';R!T;R!T:&4@9F]L;&]W:6YG
M(&QI;FL@=&\@8V]N9FER;2!T:&%T('1H:7,@:7,@<F5A;&QY('EO=7(@861D
M<F5S<SI<;B(*(B5S7&XB"B)<;B(*(DEF('EO=2!D;VXG="!K;F]W('=H870@
M=&AI<R!M97-S86=E(&UE86YS+"!Y;W4@8V%N(&1E;&5T92!I="XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V-0IM<V=I9"`B
M(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R
M+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F;W(@=&AE
M(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.3(*;7-G:60@(EEO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@
M8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-S0*
M;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM
M<V=I9"`B66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3@*;7-G
M:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O
M:6YT<R!T;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M
M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,3D*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O
M=70N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$T-@IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M=7!D871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M
M<')E<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA
M="!A8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B
M66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T
M:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW
M.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E
M<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S
M('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9Z:X9Z4X9Z?X9^+X9ZBX9^2X9Z3X9Z`(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,C8*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@
M;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("+AGIGAGKSAGJ#A
MGY+AGH+AGX3AGI_AGY+AGIOAGK;AGISAGK@B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("+AGI_A
MGX,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`BX9Z@
MX9^2X9Z?X9ZVX9^&X9Z4X9^*X9ZX(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B
M6FEM8F%B=V4B"FUS9W-T<B`BX9Z@X9^2X9Z?X9^*X9ZXX9Z8X9Z4X9ZVX9Z<
MX9^)X9^!(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C<Q"FUS9VED("):
M:7!P>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@
M5&5X=%TB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*
M;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-38Q('1E;7!L871E
M<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS
M9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T851R964B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R
M("(B"@HC.B!L:6(O87!I+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM
M<V=I9"`B7TAE;'`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@
M4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@
M(E],;V<@;W5T(@IM<V=S='(@(E],X9Z%X9^!X9Z)("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I
M9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S-PIM<V=I9"`B7U!E<FUI<W-I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM
M<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B7U1A8FQE(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C`*
M;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N
M:VYO=VXB"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z1X9Z1X9Z]X9Z;XH"+X9Z?X9^&X9Z4X9Z[
MX9Z/X9^2X9Z:(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3(*
M;7-G:60@(F-A;&5N9&%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3@T(&QI8B]";&]C:R]M971A<BYP:'`Z,S<P"B,L('!H<"UF;W)M
M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T
M<'5T(&9I;&4B"FUS9W-T<B`BX9Z8X9ZWX9Z3XH"+X9ZBX9ZVX9Z%XH"+X9Z4
MX9Z$X9^2X9Z`X9Z^X9Z/XH"+X9ZOX9Z`X9Z?X9ZVX9Z:XH"+X9Z;X9Z1X9^2
MX9Z2X9Z5X9Z;(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(N&>F.&>
MM^&>D^*`B^&>HN&>MN&>A>*`B^&>E.&>ON&>@.*`B^&>EN&?D.&>C^&?C.&>
MF.&>MN&>D^*`B^&>E.&>B>&?DN&>A>&>O.&>FR(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-0IM<V=I9"`B8VQI8VL@:&5R92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP
M.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R(@IM<V=S='(@
M(N&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>MN&>FN*`B^&>E.&?DN&>FN&>ON*`
MB^&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>EN&>MN&>@.&?DN&>F>&>E.&>
MB>&?DN&>A^&>MB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(N&>
M@.&?AN&>H.&>N^&>G^*`B^&>@.&>MN&>FN*`B^&>@.&?AN&>CN&>C^&?B^*`
MB^&>FN&>A>&>D^&>MN&>G^&>F.&?DN&>EN&?D.&>D^&?DN&>DB(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(N&>E.&>MN&>C^&?
MB^*`B^&>K^&>@.&>G^&>MN&>FN*`B^&>E.&?DN&>FN&>EN&?D.&>D^&?DN&>
MDN*`B^&>G^&?AN&>@>&>MN&>D^&?B^*`B^&>E.&?AN&>E>&>N^&>CR(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V"FUS9VED(")D
M871A(&9O<FUA="!E<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OA
MGI'AGY+AGIKAGH3AGXOAGI'AGY+AGIKAGK;AGIGB@(OAGI'AGK?AGI/AGY+A
MGI/AGI/AGY#AGIDB"@HC.B!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(X
M"FUS9VED(")E9&ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS
M9W-T<B`BX9Z:X9Z`XH"+X9Z8X9ZWX9Z3XH"+X9Z#X9Z^X9Z)XH"+X9Z2X9ZV
MX9Z/X9Z[XH"+X9Z4X9Z)X9^2X9Z%X9Z\X9Z;(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(F9A;&QI;F<B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@Q
M"FUS9VED(")F:6QE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3@V(&QI8B]";&]C:R]M971A<BYP:'`Z,S<R(&QI8B]";&]C:R]M971A
M<BYP:'`Z,SDX"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(T-`IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C0X"FUS9VED
M(")H.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4W"FUS9VED(")H:"(*;7-G<W1R(")H:"(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T
M(&YA;64@=6YK;F]W;B(*;7-G<W1R("+AGICAGK?AGI/B@(OAGI_AGY+AGH+A
MGK;AGIOAGXOB@(OAGHCAGY+AGICAGX3AGX?B@(OAGICAGXGAGK;AGI_AGXKA
MGKCAGI,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR,C,*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H
M<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@
M97)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z4X9Z)X9^2X9Z%
MX9^!X9Z)+^&>E.&>B>&?DN&>A>&>O.&>FR(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R
M92!E<G)O<B(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGH#AGICAGY+A
MGICAGISAGK?AGI+AGKCB@(OAGH'AGK;AGH3B@(OAGH#AGY+AGIKAGX4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B;&EN97-=(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,V.`IM<V=I9"`B;6TB"FUS9W-T<B`BX9Z8+N&>F"XB"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(X-B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`BX9Z(X9^2X9Z8X9^$X9^'
M(@H*(SH@9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM
M<&QE;65N=&5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,3(R,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-`IM
M<V=I9"`B;F]T97!A9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("+AGI_A
MGK?AGI'AGY+AGI+AGK?B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI3AGHKAGK?AGI_AGX'AGI(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`BX9Z7X9ZXX9Z`X9Z?X9^"X9Z;(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P
M<F]T;V-O;"(*;7-G<W1R("+AGH#AGX;AGJ#AGKOAGI_B@(OAGI;AGKCB@(OA
MGH7AGICAGY+AGH3AGK;AGIGB@(OAGH#AGY+AGI/AGKOAGH3B@(OAGI;AGK?A
MGI+AGKCAGH#AGK;AGIHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HW-`IM<V=I9"`B<FES:6YG(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V
M:6-E('5N879A:6QA8FQE(@IM<V=S='(@(N&>F.&>M^&>D^*`B^&>HN&>MN&>
MA>*`B^&>FN&>@.*`B^&>G^&?@>&>G.&>MN*`B^&>E.&>MN&>DR(*"B,Z(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z,3`R"FUS9VED(")S:&]W(&1I9F9E<F5N
M8V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T<B`B<W,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,PIM<V=I9"`B<W1E861Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,34P"FUS9VED(")S>7-T96T@97)R;W(B"FUS9W-T<B`BX9Z`X9^&X9Z@
MX9Z[X9Z?XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C@*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$V
M-@IM<V=I9"`B=&5M<&]R87)Y(&9A:6QU<F4B"FUS9W-T<B`BX9Z4X9Z:X9ZV
MX9Z'X9^0X9Z9XH"+X9Z4X9Z.X9^2X9Z*X9^$X9^'X9ZBX9ZVX9Z?X9Z3X9^2
MX9Z3(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I
M8V4@=&\@8V]N9FER;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F
M+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B=6YI9FEE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z
M,C<Y"FUS9VED(")U;FMN;W=N(&5R<F]R(@IM<V=S='(@(N&>F.&>M^&>D^*`
MB^&>G^&?DN&>@N&>MN&>F^&?B^*`B^&>@.&?AN&>H.&>N^&>GR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B
M"FUS9W-T<B`BX9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z(X9^2X9Z8X9^$X9^'(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C(S"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#
M87)D(@IM<V=S='(@(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B=SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N
M8V]M(@IM<V=S='(@(B(*````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]H95])
M3"YP;P``````````````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`V,#(P-C0@,3`U,34T,S0Q-#(@,#$W-3`P`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````",@2&5B<F5W('1R86YS
M;&%T:6]N<R!F;W(@2&]R9&4@<&%C:V%G92X*(R!#;W!Y<FEG:'0@*$,I(#(P
M,#8@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B,@5&AI<R!F
M:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@
M=&AE($AO<F1E('!A8VMA9V4N"B,@075T;VUA=&EC86QL>2!G96YE<F%T960L
M(#(P,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,BUC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O.B!D
M979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP,BTP-R`P-#HP."TP-3`P7&XB"B)03RU2979I<VEO;BU$871E.B`R,#`V
M+3`R+3`W(#`T.C`X+3`U,#!<;B(*(DQA<W0M5')A;G-L871O<CH@36%T="!3
M96QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^7&XB"B),86YG=6%G92U496%M
M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N.B`Q+C!<
M;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U55$8M.%QN
M(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(@*"5S(&1A>7,@86=O*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$S.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E
M<W-K97D@)7,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(S.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S@Q"FUS
M9VED("(@*'1O9&%Y*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S@S"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<Y"FUS9VED("(@*'EE<W1E
M<F1A>2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U,"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4S"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*;7-G:60@(B!A="`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T
M<GDN<&AP.C<P,PHC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C$P-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C
M;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"XB"FUS9W-T
M<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N
M<&AP.C4S(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C<P"B,L('!H<"UF;W)M
M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F
M)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@)7,@86YD("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,C8W(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HU-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HX-#$@9G)A;65W;W)K+TU)344O34E-12]#;VYT
M96YT<RYP:'`Z.#0W"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M.2!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@34(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-CDP(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z-S0W"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-#,T(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#@V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$W,2!L:6(O0FQO8VLO;65T87(N<&AP.C$W
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C(U,0HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,U-R!L:6(O0FQO8VLO;65T87(N<&AP.C,V,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M
M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0X"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$S-0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=&\@
M)7,@;V8@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HY,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O
M;VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDP-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P860B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,G<R!487-K;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E
M(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I
M;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N
M9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4W(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HT,#(*;7-G:60@(BP@9W5S=&EN9R`B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,#`@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG
M("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$S
M"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S4P(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S0X(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$S-@IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR-0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C(T"FUS9VED("(R-"!(
M;W5R($9O<FUA="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3,Q"FUS9VED(")!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38R"FUS
M9VED(")!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP.C0R.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B)!(&UE<W-A9V4@:&%S(&)E96X@<V5N="!T;R!<
M(B5S7"(@=&\@=F5R:69Y('1H870@=&AI<R!I<R!R96%L;'D@>6]U<B`B"B)A
M9&1R97-S+B!4:&4@;F5W(&5M86EL(&%D9')E<W,@:7,@86-T:79A=&5D(&%S
M('-O;VX@87,@>6]U(&-O;F9I<FT@=&AI<R`B"B)M97-S86=E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@
M(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,#$V"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'
M4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@
M(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER
M960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L
M;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM
M<V=I9"`B04T@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,#`*;7-G:60@(D%022!)1"(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U
M="!T:&ES(&5D:71O<B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]H96QP+VEN
M9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I9"`B
M06)S8F]T=&]M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI9&1L92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<P"FUS9VED
M(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8*;7-G
M:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HS"FUS9VED(")!8V-O=6YT
M($EN9F]R;6%T:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HW.`IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3,*;7-G:60@(D%C8V]U;G0@9G)O>F5N+B(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y"FUS9VED(")!8V-O=6YT:6YG(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X
M('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C(R(&%D;6EN+V=R;W5P<RYP:'`Z
M,C(S"FUS9VED(")!9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C<R"FUS
M9VED(")!9&0@0V]N=&5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$V(&%D;6EN+V=R;W5P<RYP:'`Z,C$W"FUS
M9VED(")!9&0@3F5W($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX.`IM<V=I9"`B061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@=&\@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,30W"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(Y
M"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D
M('!A:7(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-
M;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S
M<R!B;V]K.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z-S@*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O
M;VLB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C<X"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@(@HB)7,N(@IM<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN
M(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-#D*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$T.`IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S
M='(@(M>AUZ37J"#7F]>JUY77D=>5UZHB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P
M97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U-PIM<V=I9"`B061S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@*;7-G:60@
M(D%F9VAA;FES=&%N(@IM<V=S='(@(M>0UZ37DM>@UYG7H=>JUY\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q"FUS9VED(")!;&)A;FEA(@IM<V=S='(@(M>0UYS7D=>@UYG7E"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S0*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`BUY#7G->2UZC7
MF=>4(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$P-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI
M9VXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3(*;7-G:60@(D%L;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC
M871E9"!5<V5R<R(*;7-G<W1R("(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,R
M(&%D;6EN+V=R;W5P<RYP:'`Z,C(P"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R
M('-I9&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$X-SD*;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,W"FUS9VED(")!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,3@*;7-G
M:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@
M(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,#,*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S
M97)N86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,0IM<V=I9"`B06QT97)N
M871E('1E;7!L871E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C4*;7-G:60@(D%L
M=&5R;F%T92!T97AT.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(W"FUS9VED(")!
M;65R:6-A;B!386UO82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*
M;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`*
M;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I
M9"`B06YS=V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4*;7-G:60@(D%N=&%R
M8W1I8V$B"FUS9W-T<B`BUYG7D=>IUZKB@)/7D->@UYC7D->HUZ?7F->9UZ?7
ME"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3D*;7-G:60@(D%N=&EG=6$@86YD($)A<F)U9&$B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C,S(&%D;6EN+W1E;7!L
M871E<RYP:'`Z-S,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU
M."!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HT"FUS9VED(")!
M<'!L:6-A=&EO;B(*;7-G<W1R("(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@
M:7,@<F5A9'DN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,C$*
M;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#,Y(&9R86UE=V]R:R]-24U%+TU)344O0V]N
M=&5N=',N<&AP.C@T,0IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#$*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-@IM<V=I9"`B07)C
M:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L
M('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H
M<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE
M=&4@7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-@IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(M>0UZC7DM>@UYC7
MF=>@UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(M>0
MUZC7GM>@UYG7E"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED
M(")!<FUE;FEA;B`H05)-4T-)22TX*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D%R="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,P"FUS9VED(")!<G5B82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B
M07-C:6D@07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$P-@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S,*;7-G:60@(D%T=&5M<'0@=&\@9&5L
M971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C(X"FUS9VED(")!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HX-@IM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HU,@IM<V=I9"`B071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('-H87)E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8T(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#,*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW,0IM<V=I9"`B071T<FEB=71E<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD*;7-G
M:60@(D%U<W1R86QI82(*;7-G<W1R("+7D->5UZ'7F->HUYS7F=>4(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR.`IM<V=I9"`B075S=')I82(*;7-G<W1R("+7D->5UZ'7F->HUYG7
ME"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,38*;7-G
M:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$S,0IM<V=I9"`B075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S0*;7-G:60@(D%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F='`N<&AP.C4V"FUS
M9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S
M=VET8V@N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA
M<"YP:'`Z,3`T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]K<F(U+G!H<#HW,PIM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S`Q"FUS9VED(")!=71H7VQD
M87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M;&1A<"YP:'`Z,S4V"FUS9VED(")!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY,@IM<V=I
M9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,S,X"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H
M<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HT.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#0*;7-G:60@(D%U
M=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]M8V%L+G!H<#HV,@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E
M9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-@IM<V=I9"`B075T:%]S;6)A
M=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P
M-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M96YT:6-A=&EO;B!F86EL960N("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ.#(*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#8P"FUS9VED(")!=71H96YT
M:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C<U"FUS9VED(")!=F%I;&%B
M;&4@9FEE;&1S.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M-0IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*;7-G:60@
M(D)A8VMG<F]U;F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M.C@R"FUS9VED(")"860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#0*;7-G:60@(D)A
M9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-0IM
M<V=I9"`B0F%H86UA<R(*;7-G<W1R("+7D->9UYGB@)/7D=>4UY[7E"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S@*;7-G:60@(D)A:')A:6XB"FUS9W-T<B`BUY'7E]>HUYG7F=>?
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#,*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0*;7-G:60@(D)A
M;F=L861E<V@B"FUS9W-T<B`BUY'7H->2UYS7D]>I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,PIM
M<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM
M<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.0IM<V=I9"`B
M0F5L87)U<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U"FUS9VED(")"96QG:75M
M(@IM<V=S='(@(M>1UYS7DM>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P"FUS9VED(")"96QI
M>F4B"FUS9W-T<B`BUY'7G->9UY8B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P"FUS9VED(")"96YI
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q"FUS9VED(")"97)M=61A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#8*;7-G:60@(D)H=71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS
M9VED(")":7)T:&1A>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z
M.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW,@IM<V=I9"`B0FQO8VL@5'EP92(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,PIM
M<V=I9"`B0F]L:79I82(*;7-G<W1R("+7D=>5UYS7F=>1UYG7E"(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C$*;7-G:60@(D)O;VMM87)K<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M0F]R9&5R<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HQ,#$*;7-G:60@(D)O=&@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M.`IM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`BUY'7E=>FUY77E=>@UY0B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W"FUS9VED
M(")";W5V970@27-L86YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0*;7-G:60@
M(D)R87II;"(*;7-G<W1R("+7D=>HUY;7F=><(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<*;7-G
M:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R
M("+7D=>HUY77H->9UYDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W"FUS9VED(")"=6QG87)I82(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S8*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Y"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(M>1UY77J->5UZ#7D]>9
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V-PIM<V=I9"`B0TU3
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S4*;7-G:60@(D-20R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y.`IM<V=I9"`B0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0
M<F]P97)T:65S+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-38*;7-G:60@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.#<@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-3$*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$V-`IM<V=I9"`B0V%L96YD
M87(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T,`IM<V=I9"`B0V%L;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.`IM<V=I
M9"`B0V%M8F]D:6$B"FUS9W-T<B`BUZ?7GM>1UY77D]>9UY0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C8P"FUS9VED(")#86UE<F]O;B(*;7-G<W1R("+7I]>>UZC7E=>?(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C,U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86X@;F]T('=R
M:71E('1O(&9I;&4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I
M;VYS+G!H<#HR,0IM<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S
M97-S:6]N(&AA;F1L97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,S,P(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C(T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1FEL95]#4U8O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,0IM
M<V=I9"`B0V%N861A(@IM<V=S='(@(M>GUZ#7D]>4(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3`P(&%D;6EN+W5S97(N<&AP.C$Q.0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V
M92YI;F,Z,3(@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M"FUS9VED(")#86YC96PB"FUS9W-T<B`BUZG7H->4(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3(*;7-G:60@(D-A;F-E;"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@9&5L971E(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HT-@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$Y"B,L('!H
M<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E
M+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z
M-CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HV,C(*;7-G:60@(B(*(D-A;FYO="!R96]R
M9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D
M;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4*;7-G:60@(D-A<&4@5F5R
M9&4B"FUS9W-T<B`BUZ?7I->4(->5UZC7D]>4(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS9VED(")#871E9V]R:65S
M(&%N9"!,86)E;',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4*;7-G:60@(D-A
M>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C$*;7-G
M:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S
M<&%C:6YG.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#0*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4T"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS
M9W-T<B`BUY37I]>4UYG7G->9UYG7E"#7E->>UZC7F]>6XH"3UY#7I->HUYG7
MI]>@UYG7JB(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED(")#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R
M=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R,0IM<V=I9"`B0VAA9"(*;7-G<W1R("+7IM>3(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,0IM<V=I9"`B0VAA
M;F=E(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8Y"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D
M9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L
M>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED("(B"B)#:&%N9VEN9R!Y;W5R
M('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C
M;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@(D-H87(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4Y"FUS9VED(")#:&EL92(*;7-G<W1R("+7IM>9UYS7F2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C$*;7-G:60@(D-H:6YA(@IM<V=S='(@(M>AUYG7GR(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@V"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@*$="
M,C,Q,BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#<*
M;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!
M<'!L:6-A=&EO;CHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W
M,`IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,P,@IM<V=I9"`B0VAO;W-E(&AO=R!T;R!D
M:7-P;&%Y(&1A=&5S.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(R"FUS9VED(")#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RDB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV-@IM<V=I9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.3<Y(&9R86UE=V]R
M:R].971?4TU3+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I
M9"`B0VQE87(B"FUS9W-T<B`BUZG7GM>9UYT@UY'7E->9UZC7G2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@
M(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$R-@IM<V=I9"`B0VQE87(@475E<GDB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE
M87(@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS
M9VED(")#;&5A<FEN9R!,871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M
M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T
M;R!#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@
M=FEA($A45%`B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP
M.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S
M92!7:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-38*;7-G:60@(D-L;W5D<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S($5A<FQY
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB"FUS9W-T<B`BUZG7GM>9UYT@UY[7
MHM>5UZ#7H->9UYTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R"FUS9VED(")#;V-O<R`H2V5E;&EN
M9RD@27-L86YD<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I
M9&5B87(N:6YC.C(T"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C(*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(M>GUY77G->5
MUY[7D=>9UY0B"@HC.B!L:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,V"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,S<@<V5R
M=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@
M4&EC:V5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,SD*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*;7-G
M:60@(D-O;',Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Y-30*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(X,`IM<V=I9"`B0V]M:6-S(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,PIM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,3@*;7-G
M:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")#;VUM96YT(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38W"FUS
M9VED(")#;VUM;VX@3F%M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,`IM<V=I
M9"`B0V]M;W)O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B0V]M<'5T
M97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.3`*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(V,0IM<V=I9"`B0V]N9&ET:6]N<R(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A
M=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG
M('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I
M9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N
M9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-3(*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HT,#<*
M;7-G:60@(D-O;F9I<FT@;F5W(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HU-0IM<V=I9"`B0V]N9V\B"FUS9W-T<B`BUZ?7E=>@UY+7E2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3,*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U
M8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C$Y-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#@*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED
M(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@
M=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@U-`IM<V=I
M9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"XB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P.38*;7-G:60@(D-O;G1A
M8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@
M(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYT96YT<R!O9B!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4X"FUS9VED(")#;V]K($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS9VED(")#;V]K:64B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z-#4S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M<'D@9F%I;&5D.B`E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO
M;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8S
M"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(M>GUY77H=>8UY0@UZC7F=>G
MUY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C4W"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-PIM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4Z("(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED
M(")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#
M;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT-C<*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N
M("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L
M:6(O0FQO8VLO86-C;W5N="YP:'`Z-#4W"FUS9VED(")#;W5L9"!N;W0@8FEN
M9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"FUS9VED(")#
M;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@
M1E10.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED
M(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT
M86-T+B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R
M:7!T(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z.34S(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,S@Q"FUS9VED(")#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE
M;G0G<R!E+6UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@
M9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP
M.C8X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L9"!N
M;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A
M:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S@W"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M04-,(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HR,C$*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G
M<R!C87!A8FEL:71I97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3D@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C8S"FUS9VED(")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@
M=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@
M=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A
M<F-H('1H92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C@V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI
M;FL@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=W)I
M=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F
M:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A
M<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C<*;7-G:60@(D-O=6YT960@=&5X
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4W,`IM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(")#;W5R<V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.`IM<V=I9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDV"FUS9VED(")#<F5A=&4@
M82!N97<@;VYE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4R"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDR"FUS9VED(")#<F5A=&4@<W5B(&9O;&1E<G,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*
M;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(R,PIM<V=I9"`B0W)E9&ET(&-A<F0@
M;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y"FUS9VED(")#<F]A=&EA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C0*;7-G:60@(D-U8F$B"FUS9W-T<B`B
MUZ?7E=>1UY0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U
M<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C0X"FUS9VED(")#=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS-0IM
M<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B
M0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,S"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y
M"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@
M(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S
M:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,`IM<V=I9"`B0W5T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV-PIM<V=I9"`B0WEP<G5S(@IM<V=S='(@
M(M>GUZ37J->9UZ'7F=>?(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*
M;7-G:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ
M,C4Q*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C@*;7-G:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(M>F
MUYO7F=>4(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-"!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,PIM<V=I
M9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y
M"FUS9VED(")$86EL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]D871A=')E92YP
M:'`Z-C,*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B1&%T86)A<V4@
M3&]O:W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P
M-@IM<V=I9"`B1&%T92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`P"FUS9VED
M(")$871E('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS,30*;7-G:60@(D1A>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E
M7VQE=&4@0V]L=6UN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,`IM<V=I9"`B1&5C<F5A<V4@26YD96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET
M>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H
M96QL(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C,V('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$Q-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,`IM<V=I9"`B1&5L971E(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ.3<@861M:6XO9W)O=7!S+G!H<#HR,C4*
M;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-R!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$P,0IM<V=I9"`B1&5L971E(%!E
M<FUI<W-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S
M<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B1&5L971E(&-E;&PB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T-PIM<V=I9"`B1&5L971E(&5X
M:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU-`IM<V=I9"`B1&5L
M971E(&UE<W-A9V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@
M(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E
M<FUI<W-I;VYS/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F<R]D96QE=&5I9&5N=&ET
M>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I9&5N=&ET>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H
M<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-PIM<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*;7-G:60@(D1E;&EV
M97)Y('1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,0IM<V=I9"`B1&5N;6%R
M:R(*;7-G<W1R("+7D]>@UYG7E"(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C(W"FUS9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-#(@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I
M9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3<*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G
M<R!L;V=F:6QE*3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR,S4*;7-G:60@(D1E=F5L;W!M96YT(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(Y"FUS9VED(")$97<@
M4&]I;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,0IM<V=I9"`B1&5W
M('!O:6YT.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G
M:60@(D1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.30*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY-PIM<V=I
M9"`B1&ES<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$P"FUS9VED(")$:7-P;&%Y(&9O<FUA
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z
M,3DQ"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW,`IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO
M="!D96QE=&4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C(U"FUS9VED(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA
M;F-E+G!H<"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,@IM<V=I9"`B
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R
M"FUS9VED(")$;VUI;FEC82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S"FUS9VED
M(")$;VUI;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`BUY37J->DUY77D=><UYG7
MI]>4(->4UY/7E=>>UYG7H->9UZ?7H->9UZHB"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@X"FUS9VED(")$;VXG="!H879E(&%N(&%C8V]U;G0_
M(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@U-PIM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#4W"B,L('!H
M<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,34*;7-G:60@(D1R;W`@
M9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.0IM<V=I9"`B1')U9W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@S"FUS9VED(")$>6YA;6EC($UA:6PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED
M(")%+4UA:6PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E
M=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S
M97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%
M4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-0IM<V=I9"`B16-U861O<B(*;7-G
M<W1R("+7D->GUY77E=>3UY77J"(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,S(U('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S4*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.2!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.CDR"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$U('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,X"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3@Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW
M,@IM<V=I9"`B161I="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DV(&%D;6EN+V=R;W5P<RYP:'`Z,C(T
M"FUS9VED(")%9&ET($=R;W5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-S8@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ,#`*;7-G:60@(D5D:70@4&5R;6ES<VEO;B(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,V"FUS9VED(")%9&ET(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!097)M:7-S:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-0IM<V=I9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B161I="!P97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")%9'5C871I
M;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-PIM<V=I9"`B16=Y<'0B"FUS9W-T
M<B`BUY[7IM>HUYG7G2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-PIM<V=I9"`B16P@4V%L=F%D
M;W(B"FUS9W-T<B`BUY#7G.*`D]>AUYS7E=>5UY/7E=>H(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0S"FUS
M9VED(")%;&5M96YT+BXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(D5M86EL
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38V('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-CD*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,`IM<V=I9"`B16UA
M:6P@061D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.3<Q"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HT-3`*;7-G:60@(D5M86EL(&%D9')E<W-E<R!T;R!C;VYF:7)M(&YO="!F
M;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DY-PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z
M.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS,#$*;7-G
M:60@(D5M;W1I8V]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y(&UE
M<W-A9V4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X
M-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$Q
M,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HU-30*;7-G:60@(D5N86)L92!I;G-E<G1I
M;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C$*;7-G:60@
M(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@P-`IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM
M<V=I9"`B16YL87)G92!%9&ET;W(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I
M9"`B16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX.30*;7-G:60@
M(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDY"FUS9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<Y"FUS9VED(")%<FET<F5A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]6:65W+G!H
M<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3,*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HT,0IM<V=I9"`B17)R;W(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E
M+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C
M;VYT96YT.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I
M;F<@<&%S<W=O<F0Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@
M=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V"FUS9VED(")%<W1O;FEA
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$*;7-G:60@(D5T:&EO<&EA(@IM<V=S
M='(@(M>0UZK7F=>5UZ37F=>4(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0Q"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,2!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0S"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3,*;7-G:60@(D5V
M97)Y(#(@;6EN=71E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VQA>6]U="YI;F,Z.3@@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,`HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDQ"FUS9VED(")%=F5R>2`S,"!S96-O
M;F1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN
M8SHQ,#`@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDT"FUS9VED(")%=F5R>2`U(&UI;G5T97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S0T"FUS9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$P,PIM<V=I9"`B179E<GD@
M:&]U<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI
M;F,Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,0HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X
M86UP;&4@=F%L=65S.B(*;7-G<W1R("(B"@HC.B!A9&UI;B]C;61S:&5L;"YP
M:'`Z-#@@861M:6XO<&AP<VAE;&PN<&AP.C<Y(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,C4*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30*;7-G:60@(D5X
M<&%N9"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED96)A<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E
M8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B
M1D<@0V]L;W(B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W-PIM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR-#4*;7-G:60@(D9A
M:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<VUB+G!H<#HQ,#$*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O
M(%--0B!S97)V97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z-S`S"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y(&9R;VT@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@
M=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`Z.#D*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HW-3(@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HT.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C0T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@<F5T<FEE
M=F4Z("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.#0*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@V"FUS9VED(")&87)O92!)<VQA;F1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A
M=&%L($5R<F]R.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V-0IM<V=I9"`B1F%X97,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C,R"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C4*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU,@IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S8*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S-#`*;7-G:60@(D9I9VQE="!F;VYT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.#,*;7-G:60@(D9I:FDB"FUS9W-T<B`BUZ37
MF=>2UYDB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G
M:60@(D9I;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL
M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z
M-SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE<R(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,P"FUS9VED
M(")&:6QE($UA;F%G97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C@R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3@X"FUS9VED(")&:6QE('-E;&5C
M=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#DT"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,#8*;7-G:60@(D9I;&4@=7!L;V%D
M<R!N;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z.3@*;7-G:60@(D9I;'1E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HX,@IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R("+7I->9UZ#7G->@UY,B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38V"FUS9VED(")&:7)S="!(86QF
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U
M-0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S`*;7-G:60@(D9L:7`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@(D9O
M9R(*;7-G<W1R("+7HM>HUZ37G"(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,#<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR-C`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L;W(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")&;V]D(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-#8*;7-G:60@(D9O<F5C87-T("A4048I(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW-PIM<V=I9"`B(@HB1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R
M92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDT"FUS9VED(")&;W)G;W0@
M>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0X-0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C(V"FUS9VED(")&;W)T=6YE(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HQ,#0*;7-G:60@(D9O<G1U
M;F4@='EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#,*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-`IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<V"FUS9VED(")&;W)U;7,B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM
M<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<*
M;7-G:60@(D9R86YC92(*;7-G<W1R("+7IM>HUZ37JB(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O
M;&ET86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,0IM<V=I9"`B1G)E;F-H($=U
M:6%N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-`IM<V=I9"`B1G)E;F-H(%!O
M;'EN97-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(*;7-G:60@(D9R96YC
M:"!3;W5T:&5R;B!497)R:71O<FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-#(@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,U,@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,SDX"FUS9VED(")&<F]M('1H92`B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#(*
M;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@
M(D9U;&P@36]O;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHV,0IM<V=I
M9"`B1G5L;"!.86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#@*;7-G:60@(D=A
M8F]N(@IM<V=S='(@(M>2UY'7E=>?(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*
M;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38*;7-G:60@
M(D=A;6)I82(*;7-G<W1R("+7DM>>UY'7F=>4(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HT,@HC+"!P:'`M9F]R;6%T"FUS9VED(")'96YE<F%T92`E
M<R!#;VYF:6=U<F%T:6]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]S971U<"]C;VYF:6<N:'1M;#HV"FUS9VED(")'96YE<F%T960@0V]D92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDP"FUS9VED(")'96]R9VEA(@IM<V=S='(@
M(M>2UY77J->2UYG7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS
M9W-T<B`BUY+7J->>UZ#7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,PIM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`BUY+7H->4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-`IM<V=I9"`B1VEB<F%L=&%R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@
M(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G<W1R("+7G->:(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED(")';V5D96PB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,S,*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(S-@IM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P
M"FUS9VED(")'<F5E8V4B"FUS9W-T<B`BUYG7E=>5UY\B"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B1W)E96L@*$E33RTX.#4Y+3<I(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z.34*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Y"FUS9VED(")'<F5N861A(@IM<V=S='(@(M>2UZC7
MH->3UY0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.`IM<V=I9"`B1W)O=7`@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+G!H<#HU.2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,38Y"FUS9VED(")'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A
M9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,C0*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,S@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HY.`IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P,PIM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,@IM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(M>2UY77D->8UY[7G->4
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E
M<FYS97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B
M1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0Y,PIM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.3<*;7-G:60@(D=U:6YE82(*;7-G<W1R("+7DM>9UZ#7D->4
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`T"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P-0IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(M>2UYG7
MD->@UY0B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C0*;7-G:60@
M(DA434PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#8*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-`IM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`BUY37D->9UYC7F2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S
M:"U!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4T-0IM<V=I9"`B(@HB2&%V92!A(&)U='1O;B!I;B!T:&4@=&]O;&)A
M<B!T:&%T('!O<',@=7`@82!W:6YD;W<@=VET:"!S<&5C:6%L(&-H87)A8W1E
M<G,_(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDR,R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR.3(U"FUS9VED(")(96%D97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<*;7-G:60@(DAE87)D($ES;&%N
M9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,PIM<V=I9"`B2&5A=GD@
M5"U3=&]R;2(*;7-G<W1R("+7H=>5UZ37JN*`D]>HUZ+7GM>9UYT@UZ+7EM>4
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@(DAE8G)E=R`H
M25-/+3@X-3DM."U)*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(96EG:'0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP
M.C$X,2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@R"B,Z('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L871E<R]H96QP+VEN9&5X
M+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(M>BUY;7J->4(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3,W.0IM<V=I9"`B2&5L<&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,"!T96UP
M;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B2&EG:"(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;65N=2]M96YU+FEN8SHW"FUS9VED
M(")(;U]M92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S"FUS9VED(")(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("+7E=>8UYG7I]>?
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-34U"FUS9VED(")(
M;VUE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`IM<V=I9"`B2&]M92!$:7)E
M8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,#@*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(M>4UY77
MH->3UY77J->A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V"FUS9VED(")(;VYG($MO;F<B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8W"FUS9VED
M(")(;W)D92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV
M86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L
M('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HQ,C0S"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5M;W9E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-S,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$Y,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@
M)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,S,R"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@
M=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L
M.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S4*;7-G:60@
M(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS
M9VED(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(Y,R!L:6(O0FQO8VLO;65T87(N<&AP.C(T,@IM<V=I
M9"`B2'5M:61I='DB"FUS9W-T<B`BUYS7E]>5UZHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C4S"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S
M='(@(CK7G->7UYG7JB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-@IM
M<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,0IM<V=I
M9"`B2'5N9V%R>2(*;7-G<W1R("+7E->5UZ#7DM>HUYG7E"(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR,S0@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)U<RYP:'`Z,3<P"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR.38@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,C$T"B,L('!H<"UF;W)M870*;7-G:60@(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HR-#$@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`Z,3<W"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@
M(DE0($%D9')E<W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S
M:6,N<&AP.C@Y"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD
M;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS
M97)T(%)O=R!"969O<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P"FUS9VED
M("))8V5L86YD(@IM<V=S='(@(M>0UYG7H=><UZ#7DR(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS.#`*;7-G:60@(DEC;VYS($]N;'DB"FUS9W-T<B`B
M(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,PIM<V=I9"`B261E
M;G1I='DG<R!N86UE.B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HU.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@
M:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@
M:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#4Y"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I
M8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O
M(&-H96-K("(*(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N
M8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ-S(*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S
M86=E(&)U="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A
M9"!C86XG="!B92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E
M;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,R
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-CD*;7-G:60@(DEM86=E('5P
M;&]A9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM
M<V=I9"`B26UA9V5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-`HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHW('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC
M.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D(&9I96QD.B`E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS
M9VED("));7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I
M9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E
M8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"FUS9VED("))
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+B(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("));F-R96%S
M92!);F1E;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V"FUS9VED("));F1I
M82(*;7-G<W1R("+7E->5UY/7E2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,C4T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS
M9VED("));F1I=FED=6%L(%5S97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M,@IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(M>0UYG7H->3UY77H->6UYG7
ME"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(W,PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R,@IM<V=I9"`B26YF
M;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED
M("));G-E<G0@5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@
M0F5F;W)E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C8U"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N
M="!N;V1E(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30Y
M"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A
M;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@
M;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E<G0@
M8V5L;"!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L
M;"!B969O<F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M
M;B!A9G1E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN
M(&)E9F]R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,T,S$T+G!H<#HU,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F;W)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,PIM<V=I9"`B26YS
M97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T
M:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D:69Y($EM86=E(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.#D*;7-G:60@(DEN<V5R="]-;V1I9GD@3&EN:R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN
M<W5F9FEC:65N="!C<F5D:70N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$S-PIM<V=I9"`B26YT96=E
M<B!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O
M;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,38W"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$Y-`HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HR,3(*;7-G:60@(DEN=F%L:60@6DE0(&1A
M=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM
M<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,#DU(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S`W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z,S<*;7-G:60@(DEN=F%L:60@9&%T82!S=6)M
M:71T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#D*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V1B>"YP:'`Z,3,Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]D8G@N<&AP.C(T,0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3<P"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38T"FUS9VED("));G9A
M;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*;7-G:60@
M(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PIM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG(&%P:5]I9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED
M("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(V"FUS9VED("));G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38V"FUS9VED("));G9A;&ED('!A<G1N97(@
M:60N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-C@*;7-G:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M
M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,#<U(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3(U.`IM<V=I9"`B26YV86QI9"!S:&%R92!O
M8FIE8W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A
M9&1R97-S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D
M92!D871A+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S<S"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8X,`IM<V=I9"`B26YV
M97)T('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D*;7-G:60@
M(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS9W-T<B`BUY#7F=>HUY\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3@*;7-G:60@(DER87$B"FUS9W-T<B`BUZ+7F=>HUZ<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3,*;7-G:60@(DER96QA;F0B"FUS9W-T<B`BUY#7F=>H
MUYS7H->3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T
M;W)M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30*;7-G:60@(DES<F%E;"(*
M;7-G<W1R("+7F=>IUX'7J->0UYPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I
M9"`B271A;&EC(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,0IM<V=I9"`B271A
M;'DB"FUS9W-T<B`BUY#7F=>8UYS7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S"FUS9VED
M(")*86UA:6-A(@IM<V=S='(@(M>2UY[7F=>9UZ?7E"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-0IM<V=I9"`B2F%P86XB"FUS9W-T
M<B`BUYG7I->?(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@
M(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C0*;7-G:60@(DIO<F1A;B(*;7-G<W1R("+7F=>H
MUY/7GR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<Q"FUS9VED(")*=6QY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*;7-G
M:60@(DIU<W1I9GD@0V5N=&5R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P"FUS9VED(")*
M=7-T:69Y($9U;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*;7-G:60@(DIU<W1I9GD@
M3&5F="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0IM<V=I9"`B2G5S=&EF>2!2:6=H="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S8*;7-G:60@(DMA>F%K:'-T86XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(V,PIM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3(V"FUS9VED(")+96YY82(*;7-G<W1R("+7I]>@UYG7E"(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#8*;7-G:60@(DME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED(")+97)N96P@
M3F5W8FEE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@(DME
M>2!&:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4Y.0IM<V=I9"`B2V5Y(%5S86=E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@
M(DMI9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Y"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(*;7-G:60@(DMO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S,PIM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")+;W)E86X@*$55
M0RU+4BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T"FUS9VED(")+=7=A:70B
M"FUS9W-T<B`BUYO7E=>5UYG7F=>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W"FUS9VED(")+
M>7)G>7IS=&%N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z-S4*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B
M3&%S="!(86QF(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HW-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX
M.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,38S"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C<Q-PHC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-@IM<V=I9"`B3&%T=FEA(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B3&%W
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G
M:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,X"FUS9VED("),96)A;F]N(@IM<V=S='(@(M><UY'7H->5UY\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*;7-G:60@(DQE9G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S$Q,@IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P.`IM<V=I9"`B3&5F
M="!V86QU97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30S"FUS9VED("),97-O
M=&AO(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C(U-0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30R"FUS
M9VED("),:6)E<FEA(@IM<V=S='(@(M><UYG7D=>HUYG7E"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-PIM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("+7
MG->5UY$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#`*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C8*;7-G:60@(DQI
M9VAT(%)A:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@
M=VET:"!4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DQI;65R:6-K(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,C(*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T
M;SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X
M,PIM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED
M("),:6YK<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3$*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT-@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HQ,S$*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T
M($AE;'`@5&]P:6-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S`*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3`Y"FUS9VED("),:7-T+4%R
M8VAI=F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D
M97)S+G!H<#HU,#0*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Q,0IM<V=I9"`B3&ES
M="U)9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4P-PIM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P.`IM<V=I9"`B3&ES
M="U0;W-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3`V"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4P-0IM<V=I
M9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S97-S
M:6]N<RYP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS
M+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3(*;7-G
M:60@(DQI=&5R871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T"FUS9VED
M("),:71H=6%N:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6UA9V5S+G!H<#HW-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS
M9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8R"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z-S<@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R"FUS9VED("),;V-A
M=&EO;B(*;7-G<W1R("(B"@HC.B!L;V=I;BYP:'`Z,3@X('-E<G9I8V5S+W!O
M<G1A;"]S:61E8F%R+G!H<#HR,#`@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHX,@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U"FUS9VED("),;V<@:6XB"FUS9W-T<B`B
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),
M;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED
M("),;V=I;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,3$P"FUS9VED("),;V=I;B!487-K<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+G!H<#HY.34*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,0IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<S"FUS9VED("),;VYG('1E>'0B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED
M("),;W9E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8X"FUS9VED("),;W<B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR
M,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS
M.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N
M:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30U"FUS9VED("),=7AE;6)O=7)G(@IM<V=S='(@(M><UY77
MF]>AUY[7D=>5UZC7DB(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T,2!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M34TB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Y
M-PIM<V=I9"`B34]41"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34W"FUS
M9VED(")-86-A;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3,*;7-G:60@(DUA
M8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3$*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T
M<B`BUY[7D]>2UZ'7I]>H(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T
M"FUS9VED(")-86=I8R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.3`*;7-G:60@(DUA:6PB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4T-0IM<V=I9"`B36%I;"!!9&UI;B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,38U"FUS9VED(")-86QA=VDB"FUS9W-T<B`BUY[7G->5
MUY77F2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-PIM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B
MUY[7G->9UYG7EM>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C0*;7-G:60@(DUA;&1I=F5S
M(@IM<V=S='(@(M>4UY#7F=>9UYT@UY37GM><UY/7F=>5UY77F=>9UYTB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-30*;7-G:60@(DUA;&DB"FUS9W-T<B`BUY[7G->9(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,38R"FUS9VED(")-86QT82(*;7-G<W1R("+7GM><UYC7E"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-`IM<V=I9"`B(@HB36%N86=E('1H
M92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@
M=VET:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T
M96=O<FEE<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$Q-3@*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3`X.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$W,PIM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O
M<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,0IM
M<V=I9"`B36%R9VEN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S0S,30N<&AP.C0X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@4V5E;B]5;G-E
M96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,@IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3D*;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I
M96QD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C`*;7-G:60@(DUA=7)I=&%N
M:6$B"FUS9W-T<B`BUY[7D->5UZC7F=>8UZ#7F=>4(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S
M"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`BUY[7D->5UZC7F=>FUYG7E=>A
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$X"FUS9VED(")-87@@
M=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUA>"!T96UP(&QA<W0@-B!H;W5R<SH@
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-87AI;75M
M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.CDP,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-#,*;7-G:60@
M(DUA>&EM=6T@;&5N9W1H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(U,PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(DUE9&EC:6YE(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z
M,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X,@IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8P"FUS9VED(")-97)G92!C96QL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C,P"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I
M9"`B365S<V%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B
M365S<V%G92!E>'!I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C`R"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z-#(*;7-G:60@(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3(T"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$
M971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,34X"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B
M365T:&]D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W-O87`N
M<&AP.C$Q-R!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@Q"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H<#HX."!F<F%M97=O<FLO4E!#+U)0
M0R]P:'!G=RYP:'`Z.#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B365T:&]D(%PB
M)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]R97-T+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")-971H
M;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@W"FUS9VED(")-971R:6,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,38V"FUS9VED(")-97AI8V\B"FUS9W-T<B`BUY[7F]>AUYG7I]>5(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0R"FUS9VED(")-:61D;&4B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*
M;7-G:60@(DUI;64@5'EP92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,R,@IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$T"FUS9VED(")-
M:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C0S.`IM<V=I9"`B36EN:6UU;2!P87-S
M=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,S"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4V"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I
M9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U"FUS9VED("(B"B)-
M:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!M=7-T(&=E;F5R871E(&ET(&)E
M9F]R92!U<VEN9R!T:&ES(&%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*
M;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*
M;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"FUS
M9VED(")-;V1E<F%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HW,PIM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S0*;7-G:60@(DUO9'5L=7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34P"FUS9VED(")-;VQD;W9A+"!297!U
M8FQI8R!O9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D*;7-G:60@(DUO;F%C
M;R(*;7-G<W1R("+7GM>5UZ#7I]>5(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V"FUS9VED(")-
M;VYG;VQI82(*;7-G<W1R("+7GM>5UZ#7DM>5UYS7F=>4(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,@IM<V=I9"`B36]N=&@@86YD('EE87(B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA
M;F-E+G!H<#HU-PIM<V=I9"`B36]N=&AL>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C$*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-
M;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P"B,L
M('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@
M)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T.`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("+7GM>HUY77I]>5(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*;7-G:60@
M(DUO<W1L>2!#;&5A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I9"`B36]S=&QY($-L;W5D>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS
M9VED(")-;W9E($1O=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F
M="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+TUA;F%G97(N<&AP.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(X"FUS9VED(")-;W9E(&1O
M=VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C4R-PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(X"FUS9VED(")-;W9E('5P(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V.`IM<V=I9"`B36]Z86UB:7%U92(*;7-G<W1R("+7GM>5UY;7GM>1
MUYG7IR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.3(*;7-G:60@
M(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V,`IM<V=I
M9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-3`*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS
M9VED(")->2!!8V-O=6YT(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N="!);F9O<FUA=&EO;B(*;7-G
M<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C8U"FUS9VED
M(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+V5D
M:70N<&AP.C,U"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U-0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I
M9"`B3D\L($D@1&\@3D]4($%G<F5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP.C,X"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S='(@(M>IUYTB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-CD*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<X"FUS9VED(").875R=2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S<*;7-G:60@(DYE<&%L(@IM<V=S='(@(M>@UZ37G"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M-0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`BUY37E=><UZ#7DR(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,@IM
M<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@(DYE='-C87!E
M($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P
M;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!296YE=V%L(%523"(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X,PIM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G
M:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I9"`B3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8W"FUS9VED(").971W;W)K(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R-2!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3<*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDP"FUS9VED(").979E
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S`*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.#0*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C@X"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS
M+G!H<#HQ,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]"
M;&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED
M(").97<@36]O;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]U<&1A=&4N:6YC.C,V"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`*;7-G:60@(DYE=R!:96%L86YD
M(@IM<V=S='(@(M>@UYG7E>*`D]>6UYG7G->@UY,B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S<*;7-G:60@(DYE=R!P87-S=V]R9"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z,C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O
M;B`E>"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C4R"FUS9VED(").97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-R!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HT,`HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`U"FUS9VED
M(").97=S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS,C$*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C4@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHQ,CD*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-#$@=&5M
M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,34*;7-G:60@(DYE>'0B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@
M4&AA<V5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8R(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS
M9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W-`IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@(M>@UYG7I]>H
MUY+7E=>0UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$*;7-G:60@(DYI9V5R(@IM<V=S='(@
M(M>@UYG7EM>H(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S"FUS9VED(").:6=E<FEA(@IM<V=S
M='(@(M>@UYG7DM>HUYG7E"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS-S(*;7-G:60@(DYI9VAT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M.0IM<V=I9"`B3FEU92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38X"FUS9VED(").;R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@
M(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P,0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C,X
M-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C0P-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@
M<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HV-PIM<V=I9"`B3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@
M(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V."!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V.0HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C4R,`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,S"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HV.3@*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S0W"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR
M-`IM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(Q
M(&QI8B]";&]C:R]M971A<BYP:'`Z,3,U"B,Z(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38R"FUS9VED(").
M;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO
M(&UE<W-A9V4@<W5P<&QI960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,V"FUS9VED(").;R!N
M86UE('-P96-I9FEE9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S<*;7-G:60@(DYO(&YU;6)E
M<B!S<&5C:69I960N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY.0IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(X-PIM
M<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED
M960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z-@IM<V=I9"`B3F\@<&5N9&EN9R!S
M:6=N=7!S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M.#$S"FUS9VED(").;R!Q=6]T82!S970N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G
M:60@(DYO(')U;&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU-C,*;7-G:60@(DYO('-U
M8V@@9FEL92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3,Q"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL
M86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`@9G)A;65W;W)K+U)00R]24$,O
M<&AP9W<N<&AP.C$W-0IM<V=I9"`B3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N
M960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDW-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3@V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HY.3<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P,30*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O
M=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$R.`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W('1E;7!L
M871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.34*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0IM<V=I9"`B
M3F]N92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(").
M;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S(*
M;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO
M<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X"FUS
M9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<V"FUS9VED(").;W)W87DB"FUS9W-T<B`BUZ#7E=>HUY77E=>2
MUYG7E"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0Q
M"FUS9VED(").;W0@069T97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!"969O<F4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#0Q"FUS
M9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV,PHC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP
M.C0X"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2YP:'`Z-3D*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.34*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,3DS(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#@*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C4R"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,V,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S@P(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HT,3,*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C0W,R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-34R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HV,C$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8S.`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S$V(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HX,@HC.B!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z
M,3,Q(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HQ-3$*(SH@9G)A;65W
M;W)K+U9&4R]61E,O:&]R9&4N<&AP.C$W,"!F<F%M97=O<FLO5D93+U9&4R]H
M;W)D92YP:'`Z,3@Y"B,Z(&9R86UE=V]R:R]61E,O5D93+VAO<F1E+G!H<#HR
M,#<@9G)A;65W;W)K+U9&4R]61E,O:&]R9&4N<&AP.C(R-PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]H;W)D92YP:'`Z,S,P"B,Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,30U"B,Z(&9R86UE=V]R:R]3
M97-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,38P"B,Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,3<U"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,3@Y"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,C,V"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#@Q"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#<*;7-G:60@(DYO=&5S(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B
M<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,30*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4P"FUS9VED
M(").=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30S,PIM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,W-R!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#,Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$T-3,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S-S4@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,30R.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#4Q('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED
M(").=6UB97(@;V8@<F]W<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<U"FUS9VED(")/
M8FIE8W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,#@*;7-G:60@(D]C=&%L(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0U,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<T"FUS9VED(")/8W1O8F5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-PIM<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,@IM<V=I9"`B3V9F
M:6-E(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF
M9F5R96YT+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@Q
M"FUS9VED(")/;6%N(@IM<V=S='(@(M>BUY77GM>0UY\B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)
M34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C$P,`IM<V=I9"`B3VYL>2!O
M9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3@U.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<Y
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HV-`IM<V=I9"`B
M(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z
M,SD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-#`*;7-G:60@(D]P96X@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4X"FUS9VED(")/<&5R871I;F<@4WES=&5M(@IM<V=S='(@(B(*"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO;G,B
M"FUS9W-T<B`BUY#7I->IUZC7E=>9UY77JB(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HS,B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/
M<F1E<F5D($QI<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM
M<V=I9"`B3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30Q"FUS9VED(")/<F=A;FEZ:6YG(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,T"FUS9VED(")/
M<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R=FEC97,O:V5Y8F]A<F0N
M<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("+7D->7UZ@B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P
M.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO
M;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q
M"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W!A;2YP:'`Z.#`*;7-G:60@(E!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@
M(E!%05(Z.DUA:6P@8F%C:V5N9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C<V"FUS9VED(")01U`@1&EG:71A;"!3
M:6=N871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z,3,R,@IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-S0*
M;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$S-38*;7-G:60@(E!'4"!3:6=N960O
M16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C8V"FUS9VED(")02%`@0V]D92(*;7-G<W1R("(B"@HC.B!A9&UI;B]P
M:'!S:&5L;"YP:'`Z,3@*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM<V=I
M9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.`IM<V=I9"`B4$T@4F%I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HS.0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO
M=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0R"FUS
M9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#,*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z(&QI8B]A
M<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-PIM<V=I
M9"`B4&%K:7-T86XB"FUS9W-T<B`BUZ37I]>9UZ'7JM>?(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-`IM<V=I9"`B4&%L874B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,@IM
M<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#(*;7-G:60@(E!A;F%M82(*;7-G<W1R("+7I->@
MUY[7E"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$X-0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU"FUS9VED(")087)A9W5A>2(*;7-G
M<W1R("+7I->HUY+7E=>0UYG7F2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3DY"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,34Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,C8*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHV.2!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C0T"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-#8*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(M>AUYG7H=>>UY`B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W)A9&EU<RYP:'`Z,34W"FUS9VED(")087-S=V]R9"!R97%U:7)E9"!F
M;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Q"FUS9VED(")087-S=V]R9"!W:71H
M(&-O;F9I<FUA=&EO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R("+7H=>9
MUZ'7GM>0.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C$Q"FUS
M9VED(")087-S=V]R9#H@(@IM<V=S='(@(M>AUYG7H=>>UY`Z("(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#0R
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*;7-G:60@
M(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3$W('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM
M<V=I9"`B4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0IM<V=I9"`B
M4&%T:"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHR('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z-PIM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E!E;W!L92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-PIM<V=I9"`B4&5R8V5N="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU
M-C8*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38T"FUS9VED(")097)M:7-S:6]N<R(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3D@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HU-PHC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#@@
M861M:6XO<&5R;7,O:6YD97@N<&AP.C(Q"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-C@*;7-G:60@(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X,PIM<V=I9"`B4&5R=2(*;7-G<W1R("+7I->HUY4B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G:60@(E!E=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G
M<W1R("+7I->9UYS7F=>DUYG7H->9UYG7G2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,#$*;7-G:60@
M(E!H;W1O<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DP"FUS9VED(")0:71C
M86ER;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4&QA=&ET=61E<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<P"FUS9VED(")0;&5A<V4@96YT
M97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-0IM<V=I9"`B
M4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U,0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0U-0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P
M<F]B;&5M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`IM<V=I9"`B
M(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A
M9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y<W1E;2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N
M86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@X"FUS9VED(")0;VQA
M;F0B"FUS9W-T<B`BUZ37E=><UYG7GR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,@IM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4Q,`IM<V=I9"`B4&]L;',B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,PIM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`BUZ37
ME=>HUYC7E=>2UYPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG(&]F
M('1H:7,@=&%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(W."!L:6(O0FQO8VLO;65T87(N<&AP.C(X,PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO
M=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CDQ"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HQ
M,S,*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,S<*;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C<Q"FUS9VED(")0<F5S<W5R92!A="!S96$@;&5V96PZ
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C(Y"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#0*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS
M9VED(")0<F5V:65W(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4R(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S4V"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B
M4')I=F%T92!+97DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G<W1R("(B"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L96T@1&5S
M8W)I<'1I;VXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X-0IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$Q.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,3DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#<*;7-G:60@
M(E!R;VUP="!T97AT(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T-@IM<V=I
M9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+
M97D@26YF;R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3$*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4U"FUS9VED(")0=7)G
M92!M97-S86=E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV"FUS9VED(")1
M871A<B(*;7-G<W1R("+7I]>8UZ@B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C$*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(W,@IM<V=I9"`B4F%D:6\@<V5L
M96-T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0T"FUS9VED(")286EN(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")2
M86EN($5A<FQY(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C0V"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*
M;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS9VED(")286EN(&%N9"!3
M;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Y"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T
M=6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G
M:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R
M+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T
M86P@5FEE=SHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.CDT"FUS9VED(")2969R97-H(')A=&4Z(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*
M;7-G:60@(E)E9V5X(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R-#(*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*;7-G:60@(E)E;&]A9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S.`IM<V=I9"`B4F5M
M87)K<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$W
M"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!54DP@*&AT
M='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z."!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$S('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C(*;7-G:60@(E)E;6]V92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-38Q"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(X
M"FUS9VED(")296UO=F4@<&%I<B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R
M;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z,3,X(&9R86UE=V]R:R]24$,O4E!#+W!H<&=W+G!H
M<#HQ-S,*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-3`*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E
M(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-S8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,SD@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HW,#0*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<U,R!F<F%M97=O<FLO5D93+U9&4R]H;W)D92YP:'`Z-#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I
M960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")2
M97%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S0*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,T
M,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,3D@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C<X"FUS9VED(")297-E="(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S
M970@4&%S<W=O<F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z,C<*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T
M<B`B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.`IM<V=I9"`B4F5S=&]R
M92!,87-T(%%U97)Y(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H
M<#HR-B!A9&UI;B]P:'!S:&5L;"YP:'`Z-CD@861M:6XO<W%L<VAE;&PN<&AP
M.C8T"FUS9VED(")297-U;'1S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z
M-PIM<V=I9"`B4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W
M('!A<W-W;W)D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<*;7-G:60@(E)E
M=6YI;VXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"FUS9VED(")2:61D
M;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q-`IM<V=I9"`B4FEG:'0@
M:&5A9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,3`*;7-G:60@(E)I9VAT('9A;'5E<R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*
M;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2
M;VQE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@*;7-G:60@(E)O;6%N:6$B
M"FUS9W-T<B`BUZC7E=>>UZ#7F=>4(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I9"`B4F]T871E(#$X,"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(Q"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(W"FUS9VED(")2
M;W1A=&4@4FEG:'0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E
M<G1I97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G
M:60@(E)U;&5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU
M;6YS(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$Q.`IM<V=I9"`B4G5N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3D*;7-G:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R("+7
MJ->5UZ'7F=>4(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,`IM<V=I9"`B4G=A;F1A(@IM<V=S
M='(@(M>HUY77D->@UY/7E"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HS,C,*;7-G:60@(E,O34E-12!%;F-R>7!T960@365S<V%G92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@R
M"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,C<*
M;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B(@H*(SH@861M:6XO<W%L
M<VAE;&PN<&AP.C$Y"FUS9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#4T"FUS9VED(")34T@B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N
M97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV
M,0IM<V=I9"`B4V$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-PIM<V=I9"`B
M4V%I;G0@2&5L96YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,0IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S
M.0IM<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M.0IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0T"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@
M1W)E;F%D:6YE<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L
M9BDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,0IM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$V"FUS9VED(")386\@5&]M92!A;F0@4')I
M;F-I<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#$*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("+7
MHM>HUY$@UY37H=>BUY77D]>9UZHB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$U"FUS9VED(")3879E(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V92!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E
M<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS
M9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$V-PIM<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@(@HB9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E
M<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HY.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U
M<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,`IM<V=I9"`B
M4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B4V-I96YC92(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M
M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(M>7
MUYG7I->5UZDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S,V"FUS
M9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR.38V"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-PIM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T(&$@9W)O
M=7`@=&\@861D(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-C`*;7-G:60@(E-E
M;&5C="!A('-E<G9E<B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4T"FUS9VED(")396QE8W0@86QL(&1A
M=&4@8V]M<&]N96YT<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W-0IM<V=I9"`B4V5L96-T(&%N(&]B
M:F5C="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-C<Y"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R("(B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G:60@(B(*(E-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E('1H96T@9G)O;2!T
M:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHS-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3(*;7-G:60@(E-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L
M96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM92!F
M;W)M870Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI
M;F,Z-3<*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G
M<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S$P"FUS9VED(")3
M96QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93HB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3$*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C$P-#0*;7-G:60@(E-E;F0@4TU3(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3,*;7-G:60@(E-E;F5G86PB"FUS9W-T<B`BUZ'7H->2UYPB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,R.`IM<V=I9"`B4V5N<V]R.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N
M9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-30*;7-G
M:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR-@IM<V=I9"`B4V5S<VEO
M;B!!9&UI;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP
M:7)E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")3
M97-S:6]N<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S(R"FUS9VED(")3970B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*;7-G
M:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C
M8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,0IM<V=I9"`B(@HB4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D:7-P;&%Y(&]P=&EO;G,N(@IM
M<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@
M(E-E='5P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C,U"FUS9VED(")3971U<"!U<&=R861E('-C<FEP=',@879A
M:6QA8FQE(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#`*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I
M=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#,*
M;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`BUY#7F=>9XH"3UZ'7F=>9UZG7
MG"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3D*;7-G:60@(E-H
M;W!P:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L
M96TN:6YC.C,X"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*;7-G:60@(E-H;W5L9"!A8V-E
M<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-C<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$S-@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I
M9"`B4VAO=R(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N
M=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*(F-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<W
M,PIM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`V"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3(Y"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F
M=#\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I
M9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-S<Q"FUS9VED(")3:&]W('5P;&]A9"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,0IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!%
M87)L>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS
M9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM
M<V=I9"`B4VAR:6YK(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,3@S"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(R
M,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@
M8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(M>GUYG7
MF=>HUY0@UYS7F=>0UY77GR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG
M;G5P+G!H<#HR-C<*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3,*;7-G:60@(E-I9VYA
M='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`V"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B
MUZ'7F=>@UY+7I->5UZ@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8U(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,#`*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C0Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-30@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDR,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,3$V"FUS9VED(")3:7IE(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS9VED(")3:VEP($UA:6YT
M96YA;F-E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3`*;7-G:60@(E-L;W9A
M:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@*;7-G:60@(E-L;W9E;FEA
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C4U"FUS9VED(")3;F]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4V"FUS9VED(")3;F]W(%-H
M;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4X"FUS
M9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@
M4VAO=V5R<R!,871E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,CDP"FUS9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(E-N;W<@97%U:79A;&5N="!I
M;B!W871E<CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(*;7-G:60@(E-O
M;&]M;VX@27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$T"FUS9VED
M(")3;VUA;&EA(@IM<V=S='(@(M>AUY77GM><UYG7E"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$Y"FUS9VED(")3
M;W)T(&]R9&5R('-E;&5C=&EO;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED
M(")3;W5R8V4@861D<F5S<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4U"FUS
M9VED(")3;W5T:"!!9G)I8V$B"FUS9W-T<B`BUY/7J->5UYWB@)/7D->DUZC7
MF=>GUY0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B4V]U
M=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$P,0IM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-34*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I
M9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,`IM<V=I9"`B4W!A:6XB"FUS9W-T<B`BUZ'7I->HUY,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,3`W"FUS9VED(")3<&%M(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#
M:&%R86-T97(@26YP=70B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@
M8V5L;"(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B4W!O<G1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,0IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@
M(M>AUZC7F2#7G->@UZ?7E"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HW,2!L:6(O0FQO8VLO;65T87(N<&AP.C@V"FUS9VED(")3=&%N9&%R
M9"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C<*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,#(*;7-G
M:60@(E-T87)T('EE87(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C$P"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P.`IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T
M<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(S-PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@X,0IM<V=I9"`B4W1R:7`@9&]M
M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4W1Y;&4@6T-34UTB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I9"`B4W4B"FUS9W-T<B`B(@H*
M(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<S
M"FUS9VED(")3=6)J96-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,S-B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H
M<#HS,38*;7-G:60@(E-U8FUI="(*;7-G<W1R("(B"@HC.B!S:6=N=7`N<&AP
M.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T
M('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;FYO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$P,@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED(")3
M=6-C97-S(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C@T"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(S
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A
M=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW.2!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE
M=&5D(%PB)7-<(BXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`T
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E
M9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HU.0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C8R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB
M"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,38W"B,L('!H<"UF;W)M
M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R
M("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@=W)O=&4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-`IM<V=I9"`B
M4W5D86XB"FUS9W-T<B`BUZ'7E=>3UY\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I
M9"`B4W5N(%)I<V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$P
M"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N
M<FES92]3=6YS970B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P.0IM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3,*;7-G:60@(E-U;G-E
M="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$R"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3=7!E<G-C
M<FEP="(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,SDT"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,34*
M;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(M>AUY77J->9UZ#7G2(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D*;7-G:60@(E-V86QB87)D
M(&%N9"!*86X@36%Y96XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.0IM<V=I
M9"`B4W=A>FEL86YD(@IM<V=S='(@(M>AUY77E=>6UYG7G->@UY,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`U"FUS9VED(")3=V5D96XB"FUS9W-T<B`BUZG7E=>5UY/7F=>4
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-38*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(M>I
MUY77E=>9UZ4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM
M<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30U"FUS9VED(")3>6YC34PB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW"FUS9VED(")3
M>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,3@*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@
M(M>AUY77J->9UY0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3
M=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8T"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM
M<V=I9"`B5&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O
M<&5R=&EE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,T"FUS9VED(")486EW86XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@
M(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(R-0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,U"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(M>8UZ#7EM>@UYG7E"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-C8@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5&%S:W,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#(*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(V"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C$W"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N
M<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$V.`IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-2!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,S,X"FUS9VED(")497AT(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(E1E>'0@3VYL>2(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*
M;7-G:60@(E1E>'1T;W`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E1H86D@*%1)
M4RTV,C`I(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0*;7-G:60@(E1H86EL
M86YD(@IM<V=S='(@(M>JUY#7F=><UZ#7DR(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#(Y"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N
M;W0@879A:6QA8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&ES=&]R
M>2](:7-T;W)Y+G!H<#HV,PIM<V=I9"`B5&AE($AI<W1O<GD@<WES=&5M(&ES
M(&1I<V%B;&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L
M86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?24U34"])35-0+T)O;VLN
M<&AP.C$R.3@*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI
M=&EA;&EZ960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E
M+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO
M="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]I
M;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T:6]N<R!W
M:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C4Q"FUS9VED(")4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA
M='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M
M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U
M=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@
M<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@
M96UA:6P@861D<F5S<R`E<R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&ED96YT
M:71I97,N(%EO=2!C86X@8VQO<V4@=&AI<R`B"B)W:6YD;W<@;F]W+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q-@IM<V=I
M9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-S<@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,S$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$W,"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR-#(*;7-G:60@(E1H92!F:6QE(&-A;FYO
M="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(E1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E
M(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP
M;&]R97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T
M(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*
M(F=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N
M9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T
M96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL
M(&=E="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S
M92`B"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U
M;&P@<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<')E
M9G,N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@
M7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G
M:60@(E1H92!L969T+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$U-PIM<V=I9"`B(@HB5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HR,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE
M8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@
M9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U
M;F1E<G-T;V]D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.#@U"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG
M('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O
M<')E9G,N<&AP.C$P,`IM<V=I9"`B5&AE(&YE=R!F<F]M(&%D9')E<W,@8V%N
M)W0@8F4@=F5R:69I960L('1R>2!A9V%I;B!L871E<CH@(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0W-`IM<V=I9"`B5&AE
M(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G
M:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO
M<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,C@S"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]D96(N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+V5N<V-R:7!T+G!H<#HS-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<V5X8V5L+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<G!M+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=V5B8W!P+G!H<#HS-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S
M*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0X-PIM<V=I9"`B5&AE('%U
M;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED
M97,@;VYL>2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4:&4@<FEG:'0M:&%N
M9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C0Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ.3<*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO
M=F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C0W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@
M<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(P,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T
M(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S$S"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*
M;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-PIM<V=I9"`B5&AE('5P
M;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O8W-V+G!H<#HR
M-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$W,@IM<V=I9"`B5&AE
M('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-30@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$Q-0IM<V=I9"`B5&AE('=E871H97(N8V]M
M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M
M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#0T(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z-#0X"FUS9VED(")4:&5R92!A<F4@
M;F\@96UA:6P@861D<F5S<V5S('1O(&-O;F9I<FTN(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X"FUS9VED(")4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T-0IM<V=I9"`B5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H
M87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C
M:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM
M<V=S='(@(B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I
M;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$R,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R
M;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z("5S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS-@HC+"!P
M:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE
M<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C@R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R
M97%U:7)E9"!F:65L9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P
M9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V
M97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-#@*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,S@*;7-G:60@(E1H:7,@9&]E<R!N;W0@
M<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC
M:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B
M"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*
M;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A
M;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3@R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34V-2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#0W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-C8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q,PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#,W(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P.#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U-R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S
M,"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R
M-`IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(T"FUS9VED(")4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DX"FUS
M9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3(W
M"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S
M97!A<F%T960@;&ES="!O9B!I;G1E9V5R<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A('9A;&ED(&YU;6)E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@R.0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T
M(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@
M9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@
M86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI
M<R!I<R`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B
M+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO
M;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U
M('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD
M<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S
M=6-H(&5M86EL("(*(F-L:65N=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@
M:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ
M,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII
M<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X,@IM<V=I9"`B5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O
M=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C8U"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-3`*;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0S,R!S97)V:6-E<R]P;W)T
M86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(E1I;64B"FUS9W-T<B`B(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B5&EM92!4<F%C
M:VEN9R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C(*;7-G
M:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,S`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I
M9"`B5&\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C8U-@IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE
M(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD
M("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,PIM<V=I9"`B5&]D87DB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C,*;7-G:60@(E1O9V\B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(R-@IM<V=I9"`B5&]K96QA=2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`U"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y"FUS9VED(")4;VYG82(*;7-G<W1R
M("+7I]>1UY77IM>JXH"3UY#7F=>9XH"3UYC7E=>@UY+7E"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I
M9"`B5&]P(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8X"FUS9VED(")4
M<F%N<VQA=&EO;G,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,@IM<V=I9"`B
M5')I;FED860@86YD(%1O8F%G;R(*;7-G<W1R("+7F->HUYG7H->9UY/7DR#7
ME=>8UY77D=>2UY4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDX
M"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,C@*;7-G:60@(E1U;FES:6$B"FUS9W-T
M<B`BUYC7E=>@UYG7H=>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q"FUS9VED(")4=7)K
M97DB"FUS9W-T<B`BUYC7E=>HUZ?7F=>9UY0B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$Y.`IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R-PIM<V=I9"`B5'5R:VUE;FES=&%N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C`*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@
M27-L86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V-`IM
M<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(E4N5BX@:6YD97@Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")5
M4DPB"FUS9W-T<B`BUY#7JM>H(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDW"FUS9VED
M(")54DPZ(@IM<V=S='(@(M>0UZK7J#HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,W"FUS9VED
M(")59V%N9&$B"FUS9W-T<B`BUY#7E=>2UZ#7D]>4(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M-@IM<V=I9"`B56MR86EN92(*;7-G<W1R("+7D->5UZ?7J->9UYG7H->4(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#0U"FUS9VED(")5;F%B
M;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,3@@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C0V.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-S(Q(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;"YP:'`Z,3`V,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z.#<R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@T.`IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(U."!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR-C,*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(R-B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,SD*;7-G:60@(E5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C,W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(%9&4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.#<@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C@V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<
M(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C(Y.`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL
M92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S
M+V=Z:7`N<&AP.C<Y"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T
M87(N<&AP.C<V"FUS9VED(")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,P,R!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='DN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-S<@861M:6XO<&5R;7,O9&5L971E+G!H<#HT,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,V-"!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,S$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#$X(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,W."!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,S@R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,W,"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S<T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#0S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#4U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S8@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C$V-PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3@P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,30@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C0Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z-#(Q"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD
M97(@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C0S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z.#$R"FUS9VED(")5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE
M('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C$X(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R,PHC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,3@U(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HQ.3`*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HQ,#8@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV,C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HS,3`@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z.#$@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z.#8*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,30P(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW-@IM<V=I
M9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDP,PIM<V=I9"`B56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDS-`IM<V=I9"`B56YA8FQE
M('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+VYO;F4N<&AP.C,X"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE
M.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-S`R"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S
M('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,R
M,PIM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,U-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDZ("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,T."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C0S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(Q
M,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#4R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z,S0Y(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HS,34*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,S,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK
M:7-O9G,N<&AP.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W
M;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3@Y"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH
M*2!F86EL960I+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HS,30@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$T
M-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q"FUS9VED
M(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.CDP.0IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S,*;7-G:60@(E5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X,@IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"FUS9VED(")5;F9I;&5D(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DY"FUS9VED(")5
M;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<*;7-G:60@
M(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(M>4UY#7GM>9UZC7E=>9
MUY77JB#7E->>UY#7E=>7UY/7E=>J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X"FUS9VED(")5
M;FET960@2VEN9V1O;2(*;7-G<W1R("+7E->>UY[7G->;UY0@UY37GM>0UY77
ME]>3UZHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0P"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(M>0UZC7IM>5UZKB@)/7E->1UZC7F=>J(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S
M.0IM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C@S"FUS9VED(")5;FET<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C4X
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R.0HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34R"FUS9VED(")5;FMN;W=N(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3$*;7-G:60@(E5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU.`IM
M<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,3D*;7-G:60@
M(E5N;F%M960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X-R!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR-PHC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,PIM<V=I9"`B
M56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHW-PIM<V=I9"`B57!D871E('5S97(B"FUS
M9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#,@861M:6XO<&5R;7,O
M961I="YP:'`Z,3`Q('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,CD*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Y"FUS9VED(")5<&=R861E
M('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R("+7E->BUYS7D->4(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q"FUS9VED(")5<G5G=6%Y(@IM
M<V=S='(@(M>0UY77J->5UY+7E=>5UYDB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S
M92!34TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+V=R;W5P<R]E9&ET+FEN8SHR,0IM<V=I9"`B57-E<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<V-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O
M<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`R"FUS9VED
M(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P=&EO;G,B
M"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VXB"FUS9W-T<B`B(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V
M.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*;7-G<W1R("(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS-"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4S-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8T('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R("+7
MI]>5UY,@UY;7F=>4UY77F2#7GM>IUZK7GM>I(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]3:6=N=7`N<&AP.C$R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-PIM<V=I9"`B57-E<FYA
M;64Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y
M<W1E;3HB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,@IM<V=I9"`B57IB96MI
M<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ-S,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C@X"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(W"FUS9VED(")686-A=&EO;B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-S`*;7-G
M:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G
M:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PIM<V=I9"`B5F%L=64@
M:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#8P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q
M.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X
M:6UU;2!L96YG=&@@;V8@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(R-3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(W
M-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S(T(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Y,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E
M+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$Y-`IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#D*;7-G:60@(E9A;G5A='4B"FUS9W-T
M<B`BUY77H->5UY#7F->5(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S.`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(M>5UZ#7EM>5UY#7G->4
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*;7-G
M:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R("+7DM>9UZC7H=>4(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T,@IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E
M<G1I8V%L('!A9&1I;F<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<Q"FUS9VED(")697)Y($AI9V@B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T.`IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`BUY77F=>9UYCB@)/7H->=
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HR,#`*;7-G:60@(E9I971N86UE
M<V4@*%9)4T-)22DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@
M)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I
M9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0W"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,0IM<V=I9"`B
M5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C4W"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T<B`B(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(U,`IM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]H=&UL+G!H<#HQ,C$@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S
M"FUS9VED(")787)N:6YG(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-`IM<V=I9"`B
M5V5A=&AE<B!&;W)E8V%S="(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#$Y"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#DV"FUS9VED(")796%T:&5R+F-O;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-C`*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N86YC
M92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R("(B"@HC.B!S97)V:6-E
M<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C4W('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L
M8V]M92!T;R`E<R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD
M97@N<&AP.C<T('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]N;',N<&AP+F1I<W0Z,C`Q"FUS9VED(")797-T97)N("A)4T\M.#@U
M.2TQ*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C(P,@IM
M<V=I9"`B5V5S=&5R;B`H25-/+3@X-3DM,34I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C<X"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H<"UF;W)M870*;7-G:60@
M(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G
M:6X_(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM
M<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V
M-@IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@<&AA<V5S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@
M(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.`IM<V=I9"`B5VED
M=&@@:6X@0U-3('5N:71S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G
M:60@(E=I9'1H.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3,V"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0B"FUS9W-T<B`BUZC7E=>7
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*
M;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HY,@IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V.`IM<V=I9"`B5VEN9#HB
M"FUS9W-T<B`BUZC7E=>7.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S8*;7-G:60@(E=I;F0Z("(*;7-G<W1R("+7J->5UY<Z("(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV.0IM<V=I9"`B5VES9&]M(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,3(*;7-G:60@
M(E=I<VAL:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HW,`IM<V=I9"`B5V]R:R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y,R!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HR.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@
M;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U
M;F0@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$R-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F
M:6QE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C4Y"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC($-O
M;G-T<F%I;G1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.
M86UE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3DV"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,38*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U.`IM
M<V=I9"`B65E962(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3$Q,PIM<V=I9"`B66%H;V\A(&UA<"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N
M<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M,@IM<V=I9"`B665M96XB"FUS9W-T<B`BUZK7F=>>UY\B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38X"FUS9VED(")997,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS
M9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#(U"FUS9VED(")9;W4@87)E(&YO
M="!A=71H96YT:6-A=&5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E
M;G1I='DO261E;G1I='DN<&AP.C,R-0IM<V=I9"`B66]U(&-A;FYO="!H879E
M('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+U)00R]24$,O<&AP9W<N<&AP.C$Q-PIM<V=I
M9"`B66]U(&1I9"!N;W0@875T:&5N=&EC871E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#8S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y.#,*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M261E;G1I='DO261E;G1I='DN<&AP.C,Y,PHC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W4@:&%V92!R97%U97-T960@=&\@861D('1H92!E;6%I;"!A9&1R
M97-S(%PB)7-<(B!T;R!T:&4@;&ES="!O9B!Y;W5R("(*(G!E<G-O;F%L(&5M
M86EL(&%D9')E<W-E<RY<;B(*(EQN(@HB1V\@=&\@=&AE(&9O;&QO=VEN9R!L
M:6YK('1O(&-O;F9I<FT@=&AA="!T:&ES(&ES(')E86QL>2!Y;W5R(&%D9')E
M<W,Z7&XB"B(E<UQN(@HB7&XB"B))9B!Y;W4@9&]N)W0@:VYO=R!W:&%T('1H
M:7,@;65S<V%G92!M96%N<RP@>6]U(&-A;B!D96QE=&4@:70N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C4*;7-G:60@(B(*
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I
M;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3DR"FUS9VED(")9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#<T"FUS
M9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*;7-G
M:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED
M(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z.#`*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$X"FUS
M9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T
M+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HY.0IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS9W-T<B`B
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T
M-0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D
M871E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z
M-S,*;7-G:60@(EEO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3<U"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H
M87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS-`IM<V=I9"`B66]U
M<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T
M<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW.0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@
M:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C,P"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*
M(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@(@HB=7-E($AO<F1E('1O
M(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF
M9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B
M(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHT,@IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M(@HB=&\@<')I;G0N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HQ,C0*;7-G:60@(EEO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G<W1R("(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,38Q"FUS9VED(")9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,#0*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@
M;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-30*;7-G:60@(EEO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B
M"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW
M,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@
M(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B
M66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(U-`IM<V=I9"`B675G;W-L879I82(*;7-G<W1R("+7F=>5UY+7E=>A
MUYS7D=>9UY0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED("):86ER92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V"FUS9VED
M("):86UB:6$B"FUS9W-T<B`BUY;7GM>1UYG7F=>4(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-PIM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`BUY;7F=>>UY'7D=>5UY77E"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HW,0IM<V=I9"`B6FEP<'DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H
M;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q
M=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C@X"FUS9VED(");
M4')O8FQE;2!297!O<G1=(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@
M5&5X="`M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UTB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.34*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34V,0IM<V=I9"`B7T%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B
M7T-,22(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G:60@(E]$
M871A5')E92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S$*;7-G:60@(E]$96QE=&4@4F]W
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`Z,3<U"FUS9VED(")?2&5L<"(*;7-G<W1R("+7HM>6UZC7E"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,PIM<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y-`IM<V=I9"`B7TQO
M9R!I;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("+7E->JUZ#7JM>G
MUY77JB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G
M:60@(E]/<'1I;VYS(@IM<V=S='(@(M>0UZ37J=>HUY77F=>5UZHB"@HC.B!L
M:6(O87!I+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C8*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R("(B"@HC
M.B!L:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(P"FUS9VED(")A9&1R
M97-S(&)O;VLB"FUS9W-T<B`BUZ'7I->H(->;UZK7E=>1UY77JB(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R
M97-S964@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.CDQ,@IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B8V%L;2(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N
M;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T(&]P
M96X@:6YP=70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DU"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED
M(")C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G:60@(F-O;F9I
M9W5R871I;VX@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F
M:6QE(&UI<W-I;F<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ,C8*;7-G:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G
M:60@(F5D:70B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW
M,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HY,#(*;7-G:60@(F9I;&4B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T"FUS9VED(")G=7-T
M:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR-#@*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-C$*;7-G:60@(FAH
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-C4*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I
M9"`B:6YL:6YE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38R"FUS9VED(")I;G!U="]O=71P=70@97)R;W(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS
M9VED(")L:6YE<UTB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*
M;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S<R"FUS9VED(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C(X,2!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR
M-#$*;7-G:60@(FYA;64B"FUS9W-T<B`BUZG7G2(*"B,Z(&9R86UE=V]R:R]2
M4$,O4E!#+G!H<#HQ,C0*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*
M;7-G:60@(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#0*;7-G:60@(FYO=&5P860B"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`IM<V=I9"`B<&5R
M;6ES<VEO;B!D96YI960B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP
M:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@:6X@<')O=&]C;VPB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S0*;7-G:60@(G)I<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$T,@IM<V=I9"`B<V5R=FEC92!U;F%V86EL
M86)L92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C$P
M,@IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I
M9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#D*;7-G:60@(G-S(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<S"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O
M<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M.`IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I
M;'5R92(*;7-G<W1R("(B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C<Q"FUS9VED(")T>7!E('1H92!P
M87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(@IM<V=S='(@(B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS
M9VED(")U;FEF:65D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VAO<F1E+G!H<#HR-SD*;7-G:60@(G5N:VYO=VX@97)R;W(B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B
M=6YN86UE9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,`IM<V=I9"`B=SHB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!O+V1A7T1++G!O````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,3$P,3(T,2`Q,#4Q
M-30S-#$T,B`P,3<T-3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````(R!$86YI<V@@=')A;G-L871I;VYS(&9O<B!(;W)D92!P
M86-K86=E"B,@1&%N<VME(&]V97)SYG1T96QS97(@9F]R('!A:VME($AO<F1E
M+@HC($-O<'ER:6=H="`H0RD@,C`P,2!-87)T:6X@3&ES="U0971E<G-E;BX*
M(R!#;W!Y<FEG:'0@*$,I(#(P,#4M,C`P-B!"<FEA;B!4<G5E;'-E;BX*(R!4
M:&ES(&9I;&4@:7,@9&ES=')I8G5T960@=6YD97(@=&AE('-A;64@;&EC96YS
M92!A<R!T:&4@2&]R9&4@<&%C:V%G92X*(R!-87)T:6X@3&ES="U0971E<G-E
M;B`\;6%R=&EN0&QI<W0M<&5T97)S96XN9&L^+"`R,#`Q+@HC($)R:6%N(%1R
M=65L<V5N(#QH;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^+"`R,#`U+3(P
M,#8N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,2XQ+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V
M+3`S+3$Q(#$R.C,Y*S`Q,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M
M,#,M,3$@,38Z-3(K,#$P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!"<FEA;B!4
M<G5E;'-E;B`\:&]R9&4K:3$X;D!B<FEA;G1R=65L<V5N+F1K/EQN(@HB3&%N
M9W5A9V4M5&5A;3H@1&%N:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*
M(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]25-/+3@X-3DM,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%
M;F-O9&EN9SH@.&)I=%QN(@HB4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P
M;'5R86P]*&X@(3T@,2D[7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,S8Y(&QI8B](;W)D92]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*
M;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H)7,@9&%G92!S:61E
M;BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S.#,@;&EB+TAO
M<F1E+G!H<#HQ,S@S"B,L('!H<"UF;W)M870*;7-G:60@(B`H06-C97-S:V5Y
M("5S*2(*;7-G<W1R("(@*$%C8V5S<VME>2`E<RDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<W(&QI8B](;W)D92]&;W)M+G!H<#HR,S<W"B,L
M('!H<"UF;W)M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AO
M;2`E<R!D86=E*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H=&]D87DI(@IM<V=S
M='(@(B`H:2!D86<I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,W-0IM<V=I9"`B("AT;VUO<G)O=RDB
M"FUS9W-T<B`B("AI(&UO<F=E;BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S<Q(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE
M<W1E<F1A>2DB"FUS9W-T<B`B("AI(&?E<BDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Y-@IM<V=I
M9"`B(&%T("(*;7-G<W1R("(@;65D("(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-M8BYP:'`Z,C$Y(&QI8B]61E,O<VUB+G!H<#HR,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M7"(E<UPB(&5R(&EK:V4@970@:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO0TQ)
M+T-,22YP:'`Z,C<R(&QI8B](;W)D92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G
M<W1R(")<(B5S7"(@97(@:6YT970@9WEL9&EG="!V86QG+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S$P"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`Y."!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C<Q,`HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D
M(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B7"(E<UPB(&5R(&EK
M:V4@:V]N9FEG=7)E<F5T(&D@2&]R9&5S(&9O<G1E9VYE;'-E+B(*"B,Z(&9R
M86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,2!L:6(O2&]R9&4O5')E92YP:'`Z
M,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"XB"FUS9W-T<B`B7"(E<UPB('1RYBUO<&)Y9V=E<B!I:VME
M(&9U;F1E="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T
M96TN(@IM<V=S='(@(EPB)7-<(B!B;&5V('1I;&;X:F5T(&D@9W)U<'!E+7-Y
M<W1E;65T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!B;&5V('1I;&;X:F5T
M('1I;&QA9&5L<V5S+7-Y<W1E;65T+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-30@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<
M(B5S7"(@8FQE=B!I:VME(&1A;FYE=#H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C@P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D
M(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!B
M<G5G="!U9"!A9B`E+C)F34(@=&EL;&%D="`H)2XR9B4E*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&]G("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HR-C@@;&EB+TAO<F1E+T%U=&@O
M;&1A<"YP:'`Z,C8X"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU.30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D
M(&5X<&ER97,N(@IM<V=S='(@(B5D(&1A9V4@=&EL(&1I="!K;V1E;W)D('5D
M;/AB97(N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B
M)60M9&%G<R!U9'-I9W0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B
M)7,@+2!.;W1I=',B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C<P-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P-0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!F:6YG
M97)A9G1R>6LB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#(@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#(@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+
M0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S(%9E9&QI9V5H;VQD
M96QS92`M($)E:W+F9G1E;'-E(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&]P<^9T;FEN9R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C0@;&EB+TAO<F1E+T%U
M=&@O4VEG;G5P+G!H<#HR-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG
M;B!5<"(*;7-G<W1R("(E<R!O<'-K<FEV;FEN9R(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HU.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M
M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@8G)U9W-B971I;F=E;'-E<B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C@R(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S4P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-#,R(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DT"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HV.#(@;&EB+U9&4R]F='`N<&AP.C<U,"!L:6(O5D93+W-M
M8BYP:'`Z-#,R"B,Z(&QI8B]61E,O<VUB+G!H<#HT.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&5K<VES
M=&5R97(@86QL97)E9&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#8*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3(@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@)7,B"FUS
M9W-T<B`B)7,@=F5D("5S("5S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N
M<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S(&ES(')E861Y('1O
M('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B
M96QO=RX@0VAE8VL@=&AE("(*(F)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y
M;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B(@HB
M)7,@97(@<&%R870@=&EL(&%T('5D9OAR92!D92!V961L:6=E:&]L9&5L<V5S
M:&%N9&QI;F=E<BP@<V]M(&5R(&UA<FME<F5T("(*(FYE9&5N9F]R+B`@4^9T
M(&AA:R!U9"!F;W(@9&4@:&%N9&QI;F=E<BP@<V]M(&1U(/AN<VME<B!U9&;X
M<G0@;G4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I
M<R!R97%U:7)E9"(*;7-G<W1R("(E<R!K<N9V970B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU=&5S
M(@IM<V=S='(@(B5S(&UI;G5T=&5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C$S,B!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'`Z,3,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N
M9"XB"FUS9W-T<B`B)7,@:6MK92!F=6YD970N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T
M;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!T:6P@)7,@868@)7,B"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-B!L:6(O2&]R9&4O2V]L86(N<&AP
M.CDR-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@0F]O:R(*
M;7-G<W1R("(E<W,@861R97-S96MA<G1O=&5K(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,3@@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!#86QE;F1A<B(*;7-G<W1R("(E<W,@
M:V%L96YD97(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,"!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B)7-S(&YO=&5S8FQO:R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3,T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@5&%S:VQI<W0B"FUS9W-T
M<B`B)7-S(&]P9V%V97(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,Z(&QI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HY-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B)7,Z("5S(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP:'`Z,3(W(&QI8B](;W)D
M92]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I
M="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@1&5N;F4@
M8F5S:V5D(&5R(&UU;&EG=FES(&EK:V4@9G)A(&1E;B!P97)S;VXL('-O;2!D
M96X@:.9V9&5R(&%T(';F<F4@(@HB9G)A+B`@5N9R('9A<G-O;2!M960@870@
M9OAL9V4@:&5N=FES;FEN9V5R(&5L;&5R(&9O<G-Y;F4@869S96YD97)E;B!M
M960@(@HB<&5R<V]N;&EG92!I;F9O<FUA=&EO;F5R+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-30@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,Y.0IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&1I<V5T
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DU(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C`P"B,L('!H<"UF;W)M870*;7-G:60@(BP@9W5S=&EN9R`E<R`E
M<R(*;7-G<W1R("(L(&)LYG-E;F1E("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(BP@<VMR:69T96YD92!F<F$@)7,@=&EL
M("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C<T."!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-`HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,#8Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,C@@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P-CD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(Q,C@@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T.`HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Y-"!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C,T.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(';F
M;&<@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO
M=7(@1F]R;6%T(@IM<V=S='(@(C$R+71I;65R<R!F;W)M870B"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@(C(T($AO=7(@1F]R;6%T(@IM<V=S
M='(@(C(T+71I;65R<R!F;W)M870B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@=&EM97(B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y(&QI8B](;W)D92]522]0
M86=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\1F]R96?E
M96YD92!D86<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R-@IM<V=I9"`B
M02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K
M+B(*;7-G<W1R(")%;B!D871A8F%S92UB86-K96YD(&5R(&MRYG9E="!F;W(@
M9&5N;F4@8FQO:RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W
M,2!L:6(O2&]R9&4N<&AP.C$W,0IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960B"FUS9W-T<B`B1&5R(&5R(&]P<W3E970@96X@9W)A=F5R96YD
M92!F96IL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.3,U
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B16X@;V9F96YT;&EG(%!'4"UN^&=L92!E<B!K<N9V970@9F]R(&%T
M(&MR>7!T97)E(&5N(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,38X(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-C@*
M;7-G:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(D5N(&]F9F5N=&QI9R!01U`M
M;OAG;&4@97(@:W+F=F5T(&9O<B!A="!V97)I9FEC97)E(&5N('-I9VYE<F5T
M(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,#DY(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3D*;7-G:60@(B(*(D$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G
M<W1R("(B"B)%;B!O9F9E;G1L:6<@4$=0+6[X9VQE+"!P<FEV870@4$=0+6[X
M9VQE(&]G(&5T(&SX<V5N(&5R(&MRYG9E="!F;W(@870@(@HB9&5K<GEP=&5R
M92!E;B!B97-K960N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`Q-B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#$V"FUS9VED("(B
M"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS
M9W-T<B`B(@HB16X@;V9F96YT;&EG(%!'4"UN^&=L92P@<')I=F%T(%!'4"UN
M^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970L(&9O<B!A="`B"B)S:6=N97)E
M(&5N(&)E<VME9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4P-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4P-@IM<V=I9"`B
M(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE
M<W-A9V4N(@IM<V=S='(@(B(*(D5N(&]F9F5N=&QI9R!3+TU)344M;OAG;&4L
M('!R:79A="!3+TU)344M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T+"!F
M;W(@870@(@HB9&5K<GEP=&5R92!E;B!B97-K960N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,S$@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L
M:6<@4R]-24U%+6[X9VQE+"!P97)S;VYL:6<@4R]-24U%+6[X9VQE(&]G(&SX
M<V5N(&5R(&MRYG9E="!F;W(@870@(@HB<VEG;F5R92!E;B!B97-K960N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B;&EC(%--24U%
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T
M<B`B16X@;V9F96YT;&EG(%,O34E-12UN^&=L92!E<B!K<N9V970@9F]R(&%T
M(&MR>7!T97)E(&5N(&)E<VME9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B
M1F]R;6ED9&%G(%-K>65T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B
M1F]R;6ED9&%G($QE="!296=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-(%)A:6XB"FUS9W-T<B`B1F]R
M;6ED9&%G(%)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO=V5R<R(*;7-G<W1R(")&;W)M:61D
M86<@0GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(D9O<FUI
M9&1A9R!3;F5B>6=E<B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y
M"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM
M<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S
M='(@(D]M(&1E;FYE('-K<FEB96YT(@H*(SH@<V5R=FEC97,O:&5L<"]I;F1E
M>"YP:'`Z-3,*;7-G:60@(D%B;W5T+BXN(@IM<V=S='(@(D]M+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I
M9"`B06)S8F]T=&]M(@IM<V=S='(@(D%B<V)O='1O;2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S(*;7-G:60@(D%B<VUI
M9&1L92(*;7-G<W1R(")!8G-M:61D;&4B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,C<P(&QI8B]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R
M(")!9&=A;F<@;N9G=&5T('9E9"!D86YN96QS92!A9B!61E,M:V%T86QO9RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V(&QI8B]61E,O
M;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92XB"FUS9W-T<B`B061G86YG(&[F9W1E="!V960@9&%N;F5L<V4@
M868@5D93+69I;"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")+;VYT;RUI;F9O<FUA
M=&EO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C
M;W5N="!087-S=V]R9"(*;7-G<W1R(")+;VYT;V5N<R!K;V1E;W)D(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED
M(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T<B`B2V]N=&\@:6YD969R;W-S970N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C
M;W5N=&EN9R(*;7-G<W1R(")+;VYT97)I;F<N(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-#@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M-#@*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C$T('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T
M<B`B5&EL9OAJ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O
M=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R(")4
M:6QF^&H@=6YD97)G<G5P<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.CDX(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY."!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.CDY"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R(")4
M:6QF^&H@=6YD97)O<F1N961E('1I;&QA9&5L<V4B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(E1I
M;&;X:B!H97(Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,3@@861M:6XO9W)O
M=7!S+G!H<#HR,3D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B5&EL
M9OAJ(&YY(&=R=7!P92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`HC.B!L:6(O
M2&]R9&4O4&5R;7,O54DN<&AP.C@W(&QI8B](;W)D92]097)M<R]522YP:'`Z
M.#@*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")4:6QF^&H@
M;GD@<F5T=&EG:&5D(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G
M<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B5&EL9OAJ('5N9&5R9W)U<'!E('1I
M;"!<(B5S7"(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T
M-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R
M(")4:6QF^&H@96X@=6YD97)R971T:6=H960@=&EL(%PB)7-<(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T
M<B`B3W!R971T92!E;B!N>2!B<G5G97(Z(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-34V"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S
M='(@(E1I;&;X:B!K;VQO;FYE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@
M(E1I;&;X:B!N>64@;65D;&5M;65R(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B3W!R970@<&%R
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B
M"FUS9W-T<B`B5&EL9OAJ("5S+6UE;G5E;B!S;VT@96X@36]Z:6QL82!3:61E
M8F%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<Q(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@
M(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(E1I;&;X:B!T:6P@861R
M97-S96MA<G1O=&5K.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C<X"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(E1I
M;&;X:B!T:6P@;6ET(&%D<F5S<V5K87)T;W1E:R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")/<')E="!B<G5G97(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G
M<W1R("(B"B)(87(@=&EL9OAJ970@7"(E<UPB('1I;"!S>7-T96UE="P@;65N
M(&MU;FYE(&EK:V4@=&EL9OAJ92!E:W-T<F$@(@HB;W!S:W)I=FYI;F=S:6YF
M;W)M871I;VXZ("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B5&EL9OAJ970@7"(E<UPB('1I;"!S>7-T
M96UE="X@1'4@:V%N(&QO9V=E(&EN9"!N=2XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z,@IM<V=I9"`B061D:6YG('5S97)S(&ES(&1I
M<V%B;&5D+B(*;7-G<W1R(")/<')E='1E;'-E(&%F(&)R=6=E<F4@97(@<VSE
M970@9G)A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T-#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B061R97-S92(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ-#$*;7-G:60@(D%D9')E<W,@0F]O:R(*
M;7-G<W1R(")!9')E<W-E:V%R=&]T96LB"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HY-`HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q
M-"YP:'`Z-38*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT
M"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES='+I<B`M(&EN9'-T:6P@=&EL;&%D
M96QS97(@9F]R(&%N9')E(&)R=6=E<F4B"@HC.B!A9&UI;B]I;F1E>"YP:'`Z
M,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q,PIM<V=I9"`B061M
M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R871I;VXB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!9',B"FUS9W-T<B`B
M4F5K;&%M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@
M(D%F9VAA;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@
M(D%L8F%N:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(D%L
M9V5R:65T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$P-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$P
M-PIM<V=I9"`B06QI87,B"FUS9W-T<B`B2V%L9&5N879N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I
M9"`B06QI9VXB"FUS9W-T<B`B3W!S=&EL;&EN9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N
M=#HB"FUS9W-T<B`B2G5S=&5R:6YG.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(D%L;&4B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C(P-PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED
M(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")!;&QE(.9G=&5D
M92!B<G5G97)E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U
M<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")!;&QE(&=R
M=7!P97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*(SH@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HY,2!L:6(O2&]R9&4O4&5R;7,O9&%T871R964N
M<&AP.C<U"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B06QL92!T
M:6QL861E;'-E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S
M='(@(D%L;&4@9FER92!S:61E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S$*;7-G:60@(D%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")4:6QL860@;75L=&EP;&4@
M861R97-S97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3,X"FUS9VED
M(")!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/R(*;7-G<W1R
M(")4:6QL860@86YG:79E;'-E(&%F(&]R9&YE="!L:7-T971Y<&4_(@H*(SH@
M9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T(&QI8B](
M;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES
M=',B"FUS9W-T<B`B16MS:7-T97)E<B!A;&QE<F5D92(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(D%L=&5R;F%T:78@24U34"UL;V=I;B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(D%L=&5R;F%T:78@24U34"UK;V1E;W)D(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@
M57-E<FYA;64B"FUS9W-T<B`B06QT97)N871I=B!)35-0+6)R=6=E<FYA=FXB
M"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT
M97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B1&EN(&4M;6%I;"UA9')E
M<W-E(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R
M;F%T92!T96UP;&%T97,B"FUS9W-T<B`B06QT97)N871I=F4@<VMA8F5L;VYE
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$R,@IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@
M(D%L=&5R;F%T:78@=&5K<W0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(W
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"FUS9VED(")!;65R:6-A;B!3
M86UO82(*;7-G<W1R(")!;65R:6MA;G-K(%-A;6]A(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$Q-0HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDU(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,3$U"FUS9VED(")!;B!I;&QE9V%L('9A;'5E
M('=A<R!S<&5C:69I960N(@IM<V=S='(@(D1E;B!VYG)D:2P@9&5R(&)L978@
M86YG:79E="P@=F%R(&EK:V4@9WEL9&EG+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-34*;7-G:60@(D%N('5N:VYO=VX@97)R;W(@:&%S
M(&]C8W5R960N(@IM<V=S='(@(D1E<B!E<B!O<'-TY65T(&5N('5K96YD="!F
M96IL+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-0IM<V=I9"`B06YD;W)R82(*;7-G<W1R(")!;F1O<G)A
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!;F=O;&$B"FUS9W-T<B`B06YG;VQA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B
M06YO;GEM:7-E<F5N9&4@<')O>'DB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W
M;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(D)E<W9A<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R(")3>61P;VQE;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R(")!;G1I
M9W5A(&%N9"!"87)B=61A(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C,V(&%D
M;6EN+W1E;7!L871E<RYP:'`Z-S0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+U5)+G!H<#HU."!L:6(O2&]R9&4O0FQO8VLO54DN<&AP.C4X"B,Z('1E;7!L
M871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T
M:6]N(@IM<V=S='(@(D%P<&QI:V%T:6]N(@H*(SH@=71I;"]I8V]N7V)R;W=S
M97(N<&AP.C0R"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(D%P
M<&QI:V%T:6]N<VQI<W1E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T
M,`IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%P<&QI
M:V%T:6]N(&5R('!A<F%T+B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B
M4.5F^'(@=6YD97)D96QI;F=E<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D=O9&ME
M;F0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#(@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@T,@IM<V=I9"`B07!P<F]X
M:6UA=&4@4VEZ92(*;7-G<W1R(")#:7)K87-T^')R96QS92(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B
M07!R:6PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B07)A
M8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R86)I<VL@*%=I;F1O=W,M
M,3(U-BDB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV-B!L:6(O2&]R
M9&4O34E-12]6:65W97(O<F%R+G!H<#HU.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HW."!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HV-@IM<V=I9"`B07)C:&EV92!&:6QE(%-I>F4B"FUS9W-T<B`B07)K:78M
M9FEL<W3X<G)E;'-E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C<W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-S<@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C4*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R(")!<FMI
M=FYA=FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_(@IM
M<V=S='(@(D5R(&1U('-I:VME<B!PY2P@870@9'4@=FEL('-L971T92!O<'-K
M<FEV;FEN9W-A;FUO9&YI;F=E;B!F;W(@)7,@/R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@7"(E<UPB(&%N9"!A
M;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B17(@9'4@<VEK:V5R+"!A="!D=2#X
M;G-K97(@870@<VQE='1E(%PB)7-<(B!O9R!E;FAV97(@=6YD97)G<G5P<&4_
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@(D%R;65N:65N(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D%R;65N:6%N("A!
M4DU30TE)+3@I(@IM<V=S='(@(D%R;65N<VL@*$%235-#24DM."DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")+
M=6YS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,"!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N9"(*;7-G<W1R(")!
M<V-E;G-I;V[X96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,CD*;7-G
M:60@(D%S8VEI($%R="(*;7-G<W1R(")!4T-)22!!<G0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07-I
M871I<VLO<W1I;&QE:&%V<W)E9VEO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D
M;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")3</AR9R!E
M9G1E<B!B96MRYF9T96QS92!F^'(@=61F^')E;'-E(&%F('9E9&QI9V5H;VQD
M96QS97-H86YD;&EN9V5R/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,P.34@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.34*;7-G:60@(D%S<VEG;FUE
M;G0@8V]L=6UN<R(*;7-G<W1R(")4:6QD96P@:V]L;VYN97(B"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"XB"FUS9W-T<B`B1F]R<_AG('#E(&%T('-L971T
M92!E;B!I:VME+65K<VES=&5R96YD92!G<G5P<&4N(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1F]R<_AG('#E(&%T
M('-L971T92!E;B!I:VME+65K<VES=&5R96YD92!T:6QL861E;'-E+B(*"B,Z
M(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B1F]R<_AG
M('#E(&%T(.9N9')E(&5N(&EK:V4M96MS:7-T97)E;F1E('1I;&QA9&5L<V4N
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(D9O
M<G/X9R!PY2!A="#F;F1R92!E;B!I:VME+65K<VES=&5R96YD92!D96QI;F<N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-"!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S$@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#,@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*
M;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B071T<FEB=71T97(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#<*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G
M<W1R(")!=6=U<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R
M(")!=7-T<F%L:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@
M(MAS=')I9R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HQ
M-C@@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?
M8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?8WER<W%L.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK
M:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C$S-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($)A8VME;F0@:&%R(&EK:V4@
M9&4@;OAD=F5N9&EG92!E=FYE<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HQ,C(@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM
M<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!+<N9V970@24U!4"UU9'9I
M9&1E;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M9G1P+G!H<#HS-B!L:6(O2&]R9&4O075T:"]F='`N<&AP.C,V"FUS9VED("(B
M"B)!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+2(*(F9T<"!S=VET8V@N
M(@IM<V=S='(@(B(*(D%U=&A?9G1P.B!+<N9V970@1E10+75D=FED9&5L<V4@
M:6MK92!F=6YD970N($]V97)SYG0@4$A0(&UE9"`M+65N86)L92UF='`M(@HB
M9FQA9V5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0@
M;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!
M=71H7VEM87`Z($MRYG9E="!)34%0+75D=FED9&5L<V4@:6MK92!F=6YD970N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,2!L:6(O2&]R
M9&4O075T:"]K<F(U+G!H<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B
M-3H@2W+F=F5T($M20C4M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,P,B!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T
M<B`B(@HB075T:%]L9&%P.B!4:6QF^&IE;'-E(&)R=6=E<F4@97(@:6MK92!U
M;F1E<G-T^'1T970@9F]R($%C=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,U-R!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HS-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@
M;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B
M"B)!=71H7VQD87`Z(%-L971N:6YG(&%F(&)R=6=E<F4@97(@:6MK92!U;F1E
M<G-T^'1T970@=F5D($%C=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VQD87`N<&AP.C8S(&QI8B](;W)D92]!=71H+VQD87`N<&AP
M.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!+<N9V970@3$1!4"UU
M9'9I9&1E;'-E(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z,S,Y(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,S.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S
M='(@(D%U=&A?;&1A<#H@2W5N;F4@:6MK92!T:6QF^&IE(&)R=6=E<B`E<RX@
M4V5R=F5R96X@<V%G9&4Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A
M<"YP:'`Z,S@U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E
M<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($MA;B!I:VME('-L971T92!B<G5G
M97(@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.2!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T
M<B`B075T:%]L9&%P.B!+86X@:6MK92!O<&1A=&5R92!B<G5G97(@)7,B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P-2!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HT,#4*;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@
M=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB
M"FUS9W-T<B`B(@HB075T:%]L9&%P.B!/<&1A=&5R:6YG(&%F(&)R=6=E<F4@
M97(@:6MK92!U;F1E<G-T^'1T970@=F5D($%C=&EV92!$:7)E8W1O<GDN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-B!L:6(O2&]R9&4O
M075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@
M2W+F=F5T($U#04PM=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`@;&EB+TAO<F1E+T%U=&@O<VUB
M+G!H<#HV,`IM<V=I9"`B075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@
M2W+F=F5T(%--0D%55$@M=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%D;6EN+G!H<#HQ,#8@;&EB+TAO<F1E+TE-
M05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@24U!
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+&9W1N:6YG('9E9"!)34%0+7-E
M<G9E<B!F96IL961E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D(@IM
M<V=S='(@(L9G=&YI;F<@9F5J;&5D92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C8W"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z-C<@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A
M=&EO;B!F86EL960N("5S(@IM<V=S='(@(L9G=&YI;F<@9F5J;&5D92X@)7,B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,3<V(&QI8B](
M;W)D92]!=71H+W)A9&EU<RYP:'`Z,3<V"FUS9VED(")!=71H96YT:6-A=&EO
M;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R("+&9W1N:6YG
M(&%F=FES="!A9B!2041)55,M<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#@R(&QI8B]61E,O9G1P+G!H<#HX.#(*;7-G:60@(D%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R("+&
M9W1N:6YG(&]V97)F;W(@1E10+7-E<G9E<B!F96IL961E+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-S`@;&EB+U9&4R]S;6(N<&AP.C<P"FUS
M9VED(")!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N
M(@IM<V=S='(@(L9G=&YI;F<@;W9E<F9O<B!334(M<V5R=F5R(&9E:FQE9&4N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A
M:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B1F5L=&5R('1I;"!RY61I9VAE9#HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S$@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T<B`B07-E<F)A:61J
M86XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@
M17AC=7-E<R(*;7-G<W1R(")"3T9(+75N9'-K>6QD;FEN9V5R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.`IM
M<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")"86-K9W)O=6YD(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B
M0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")"86=G<G5N9'-F87)V92(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB
M"FUS9W-T<B`B1.5R;&EG="!K97)B97)O<RUK;V1E;W)D+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,@;&EB+TAO<F1E+T%U=&@O:W)B
M-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T
M<B`B1.5R;&EG="!K97)B97)O<RUB<G5G97)N879N+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I
M9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A
M:')A:6XB"FUS9W-T<B`B0F%H<F%I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@P"FUS9VED(")"86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R(")"
M86QT:6MU;2`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D
M97-H(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A
M9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D)A<VES(&=R869I
M:VMA=&%L;V<@7"(E<UPB(&EK:V4@9G5N9&5T+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ.0IM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B0F%S:7-L:6YI92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L
M87)U<R(*;7-G<W1R(")(=FED97)U<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E
M;&=I=6TB"FUS9W-T<B`B0F5L9VEE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C,R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L:7IE
M(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C,S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T
M<B`B0F5N:6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#$@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R
M;75D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H=71A;B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@
M(D)I<G1H9&%Y(@IM<V=S='(@(D;X9'-E;'-D86<B"@HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S8W(&QI8B](;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<#HS-C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0FQO
M8VL@7"(E<UPB(&]F(&%P<&QI8V%T:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D)L;VL@7"(E<UPB(&%F(&%P<&QI:V%T:6]N(%PB)7-<(B!I:VME
M(&9U;F1E="XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;VLM96=E;G-K86)E
M<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B
M0FQO8VL@5'EP92(*;7-G<W1R(")";&]K='EP92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G
M<W1R(")&960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C0S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HS-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L
M:79I96XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`W"FUS9VED
M(")";V]K;6%R:W,B"FUS9W-T<B`B0F]G;>9R:V5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M0F]R9&5R(@IM<V=S='(@(E)A;F0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S
M.B(*;7-G<W1R(")286UM971Y:VME;'-E.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E
M<G,B"FUS9W-T<B`B4F%N9&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S(@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)O<VYI82!A;F0@
M2&5R>F5G;W9I;F$B"FUS9W-T<B`B0F]S;FEE;B!O9R!(97)Z96=O=FEN82(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G
M<W1R(")"96=G92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T<B`B
M0F]T<W9A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,C(*;7-G:60@(D)O='1O;2(*;7-G<W1R(")"=6YD(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HT-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S='(@(D)O=79E=/AE
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(D)R87-I;&EE;B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GDB"FUS9W-T<B`B0G)I=&ES:RU);F1I96X@3V-E86YO;7+E9&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2!$
M87)U<W-A;&%M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,W(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=6QG87)I82(*;7-G<W1R(")"
M=6QG87)I96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Y"FUS9VED(")"=6QL971E9"!,:7-T(@IM<V=S='(@(E!U;FMT
M;&ES=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S8@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"
M=7)K:6YA($9A<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B
M0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#8*;7-G
M:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP.C<U(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S(@IM
M<V=S='(@(D-23"!D:7-T<FEB=71I;VYS<W1E9&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W"FUS9VED
M(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(D-E;&QE+65G96YS:V%B
M97(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34Q"FUS
M9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("))
M;FET:6%L:7-E<FEN9R!A9B!M:61L97)T:61I9W0@;&%G97(@:6MK92!FYG)D
M:6=G:F]R="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#@U(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$V"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3$V(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT.#4*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B
M"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@(E9I;F1S=&EL;&4B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B2V%M8F]D:6$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-A;65R;V]N(@IM<V=S='(@(D-A;65R;W5N(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@
M<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(N(@IM<V=S='(@(DMA;B!I:VME(&YU;'-T:6QL92!K;V1E
M;W)D(&%U=&]M871I<VL[(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(N(@H*
M(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P(&QI8B]&:6QE+T-3
M5BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@
M=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B2V%N(&EK:V4@<VMR:79E('1I;"!F
M:6P@7"(E<UPB(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#
M86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM
M<V=S='(@(DMA;B!I:VME(&CE;F1T97)E(&5K<W1E<FYE('-E<W-I;VYS:.5N
M9'1A9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y
M(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-0HC.B!L:6(O2&]R
M9&4O075T:"]C>7)S<6PN<&AP.C,Q.2!L:6(O2&]R9&4O075T:"]C>7)U<RYP
M:'`Z,C,U"B,L('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@
M24U!4"!S97)V97(Z("5S(@IM<V=S='(@(DMA;B!I:VME(&9O<F)I;F1E('1I
M;"!)34%0('-E<G9E<BX@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6
M+G!H<#HT-#8@;&EB+T9I;&4O0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK
M:V4@Y6)N92!F:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU
M,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V%N861A(@IM
M<V=S='(@(D-A;F%D82(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,2!A9&UI;B]U
M<V5R+G!H<#HQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C8U('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,0IM<V=I9"`B0V%N8V5L(@IM
M<V=S='(@(D%N;G5L;&5R(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R
M(")!9F)R>60@<F5P;W)T97)I;F<@868@<')O8FQE;2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,S(S(&QI8B]61E,O9G1P+G!H<#HS,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(&9I;"!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C0V"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I:VME(&9I;F1E(&5T(&UI9&QE<G1I9&EG="!K
M871A;&]G+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<BYP:'`Z.3$@;&EB+U9&4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM
M<V=S='(@(DMA;B!I:VME(&9O<G1SYG1T92!U9&5N("=T87)G971&:6QE)RUP
M87)A;65T<F5N+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$Y
M(&QI8B]61E,O9G1P+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M;F]T(')E;6]V92!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK
M92!F:F5R;F4@:V%T86QO9R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T1A=&%4
M<F5E+T1A=&%4<F5E+G!H<#HQ,C@@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4
M<F5E+W-Q;"YP:'`Z-C@P"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3(X
M(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS
M9W-T<B`B2V%N(&EK:V4@9FIE<FYE+"`E9"!B^')N(&5K<VES=&5R97(N(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-C`X(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C8P.`IM<V=I9"`B(@HB0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@
M(B(*(DMA;B!I:VME(&]M9F]R9&5L93L@86YT86QL970@868@<'5N:W1E<B!A
M;F=I=F5T('1I;"!O;69O<F1E;&EN9R!S=F%R97(@:6MK92`B"B)T:6P@9&5T
M(&]P8F5V87)E9&4@86YT86PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G
M92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R(")+86X@:6MK92!D:7)I
M9V5R92!B97-K960@=&EL(&%N9VEV;F4@;G5M;65R+B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C4@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0Y"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0V%P92!697)D92(*;7-G<W1R(")+87`@5F5R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(D)I;&QE9'1E:W-T(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`T(&QI8B].970O4TU3
M+V=E;F5R:6-?<VUT<"YP:'`Z,3`T"FUS9VED(")#87)R:65R(@IM<V=S='(@
M(E5D8GED97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G:60@
M(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:65R(&]G
M($WF<FME<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,U(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD<R(*;7-G
M<W1R(")#87EM86[X97)N92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T<B`B36]B:6PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(U"FUS9VED(")#96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B0V5L;&4M
M96=E;G-K86)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(D-E
M;&QE9F]R<FEN9SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS
M9W-T<B`B0V5L;&4M96=E;G-K86)E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z
M(@IM<V=S='(@(D-E;&QE+6UE;&QE;7)U;3HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C<T(&QI8B](;W)D92]&;W)M+G!H<#HQ,C<T"FUS9VED
M(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6QT96QE9F]N(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#$*;7-G:60@(D-E;'1I8R`H25-/+3@X-3DM,30I
M(@IM<V=S='(@(DME;'1I<VL@*$E33RTX.#4Y+3$T*2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@
M(D-E;G1E<B(*;7-G<W1R(")#96YT<NER(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT
M<F%L($%F<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B1&5N(&-E;G1R86QA9G)I
M:V%N<VME(%)E<'5B;&EK(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*
M;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I(@IM<V=S='(@
M(D-E;G1R86PM975R;W#F:7-K("A)4T\M.#@U.2TR*2(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-S`P"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S
M='(@(D-E<G1I9FEK870M9&5T86QJ97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8Q,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B0V5R=&EF
M:6MA="UE:F5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.3<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-E
M<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(D-E<G1I9FEK870M<&]L:71I
M:VME<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS9W-T<B`B5&-H860B
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B
MQFYD<F4B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z,S$*;7-G
M:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L9N9')E(&1I="!K
M;V1E;W)D(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B
M"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB
M"FUS9W-T<B`B(@HB2&5R(&MA;B!D=2#F;F1R92!D970@;F%V;B!O9R!D96X@
M861R97-S92P@<V]M(&%N9')E('-E<BP@;N5R(&1E(&SF<V5R(&]G("(*(G-V
M87)E<B!PY2!D:6YE(&4M;6%I;"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@
M:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I
M;VXN("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B
M(@HB2V]D96]R9'/F;F1R:6YG(&5R(&EK:V4@=6YD97)S=/AT=&5T(&%F(&1E
M;B!N=7;F<F5N9&4@;W!SYG1N:6YG+B`@2V]N=&%K="`B"B)D:6X@861M:6YI
M<W1R871O<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(E1E9VXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(DAA:R!L:6YK
M(&%F+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HU.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")#:&EL92(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4T"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0VAI;F$B"FUS9W-T<B`B2VEN82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#:&EN97-E(%-I;7!L:69I960@
M*$=",C,Q,BDB"FUS9W-T<B`B4VEM<&QI9FEC97)E="!K:6YE<VES:R`H1T(R
M,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#:&EN
M97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R(")4<F%D:71I;VYE;'0@
M:VEN97-I<VL@*$)I9S4I(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z
M-PIM<V=I9"`B0VAO;W-E($%P<&QI8V%T:6]N.B(*;7-G<W1R(")6YFQG(&%P
M<&QI:V%T:6]N.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H
M<#HR-S`@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H
M;V]S92!A('!A<W-W;W)D(@IM<V=S='(@(E;F;&<@970@:V]D96]R9"(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('5S97)N86UE
M(@IM<V=S='(@(E;F;&<@970@8G)U9V5R;F%V;B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS,#(*;7-G:60@(D-H;V]S92!H;W<@=&\@9&ES<&QA>2!D
M871E<SHB"FUS9W-T<B`B5N9L9R!H=F]R9&%N(&1A=&]E<B!S:V%L('9I<V5S
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")6YFQG(&QI<W1E+7-T:6P@*&9O
M<B!O<F1N961E(&QI<W1E<BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)
M<VQA;F0B"FUS9W-T<B`B2G5L9?AE;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HY,30@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@;&EB+U9&
M4RYP:'`Z.3$T"B,Z(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM
M<V=S='(@(DML87-S961E9FEN:71I;VX@868@)7,@:6MK92!F=6YD970N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G
M:60@(D-L96%R(@IM<V=S='(@(DML87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I
M8V4@=&%G<R(*;7-G<W1R(")&:F5R;B!-4T]F9FEC92UO<&WF<FMN:6YG97(B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Y"FUS9VED(")#;&5A<B!1=65R
M>2(*;7-G<W1R(").=6QS=&EL(&9O<F5S</AR9W-E;"(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-L96%R(&]U="!U<V5R.B`E<R(*;7-G<W1R(")296YS(&)R=6=E<B!U9#H@
M)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z,3$*;7-G
M:60@(D-L96%R('5S97(B"FUS9W-T<B`B3G5L<W1I;"!B<G5G97(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@
M=7-E<B!D871A(@IM<V=S='(@(E9I<VL@8G)U9V5R9&%T82!U9"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#
M;&5A<FEN9R!,871E(@IM<V=S='(@(E-E;B!O<&ML87)I;F<B"@HC.B!T96UP
M;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HV,`IM<V=I9"`B
M0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B2VQI:R!F;W(@870@9F]R='/F
M='1E(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@T"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3@T"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K
M871E;&P@=FEA($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I
M;F1O=R(*;7-G<W1R("),=6L@=FEN9'5E(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-3$*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")3:WEE<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#
M;&]U9',@16%R;'DB"FUS9W-T<B`B4VMY97(@=&ED;&EG="(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U
M9'DB"FUS9W-T<B`B4VMY970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HU-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-O8V]S("A+965L
M:6YG*2!)<VQA;F1S(@IM<V=S='(@(D-O8V]S("A+965L:6YG*2#897)N92(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O
M;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`B1F]L9"!S:61E<&%N96P@<V%M;65N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4V%M
M;65N9F]L9&5D92!R86YD92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HV,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS
M9W-T<B`B2V]L=6UB:65N(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S
M='(@(D9A<G9E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4P,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO
M;BYP:'`Z,S,X"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N
M+G!H<#HS,SD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C4P,R!L:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S,X"B,Z(&QI
M8B](;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<#HS,SD@<V5R=FEC97,O:6UA
M9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM
M<V=S='(@(D9A<G9E=N9L9V5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C@R."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@R.`IM<V=I9"`B0V]L;W5R
M('-E;&5C=&EO;B(*;7-G<W1R(")&87)V979A;&<B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB
M"FUS9W-T<B`B2V]L<SHB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.30V(&QI8B](;W)D92]&;W)M+G!H<#HQ.30V"FUS9VED(")#;VQU;6X@=&ET
M;&5S(@IM<V=S='(@(DMO;&]N;F5T:71L97(B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B5&5G;F5S
M97)I97(B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C8*;7-G:60@(D-O;6UA
M;F0B"FUS9W-T<B`B2V]M;6%N9&\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z
M,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B2V]M;6%N9&]L:6YI
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,R!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T
M<B`B2V]M;65N=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-C<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@
M(D-O;6UO;B!.86UE(@IM<V=S='(@(D-O;6UO;B!.86UE(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-3@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*
M;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M;W)E<FYE(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(S.0IM<V=I9"`B0V]M<&%N>2(*
M;7-G<W1R(")&:7)M82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0IM
M<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(D-O;7!U=&5R92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#8*;7-G:60@(D-O;F1I=&EO;B(*
M;7-G<W1R(")&;W)H;VQD(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-38*
M;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B0F5T:6YG96QS97(B"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$
M:69F97)E;F-E<R(*;7-G<W1R(")+;VYF:6=U<F%T:6]N<V9O<G-K96QL92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R
M871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@
M3W5T;&]O:RXB"FUS9W-T<B`B2V]N9FEG=7)A=&EO;B!T:6P@<WEN:W)O;FES
M97)I;F<@;65D(%!$065R+"!3;6%R='!H;VYE<R!O9R!/=71L;V]K+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O;F9I9W5R871I
M;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(DMO;F9I9W5R871I;VYE;B!E
M<B!F;W+F;&1E="XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")+;VYF
M:6=U<NER("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHU,0IM<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")"96MRYF9T
M(&MO9&5O<F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HU.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O(@IM<V=S='(@(DMO;F=O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4S(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L
M:6,@;V8@=&AE(@IM<V=S='(@(DMO;F=O+"!$96X@9&5M;VMR871I<VME(')E
M<'5B;&EK(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,P."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#@*;7-G:60@(D-O;FYE
M8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")&;W)B:6YD96QS92!M:7-L>6MK961E
M<RXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3<*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,P.`IM<V=I9"`B0V]N;F5C=&EO
M;B!F86EL960Z("(*;7-G<W1R(")&;W)B:6YD96QS92!M:7-L>6MK961E<SH@
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")&;W)B:6YD
M96QS92!T:6P@;V9F96YT;&EG(&[X9VQE<V5R=F5R(&[F9W1E="XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3(@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z-SDR"B,L('!H<"UF;W)M870*;7-G:60@(D-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I(@IM<V=S='(@(D9O<F)I;F1E;'-E('1I;"!O9F9E;G1L:6<@;OAG
M;&5S97)V97(@;N9G=&5T+B#%<G-A9SH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#<V(&QI8B]61E,O9G1P+G!H<#HX-S8*;7-G
M:60@(D-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D9O<F)I;F1E;'-E('1I;"!&5%`M<V5R=F5R(&UI<VQY:VME9&5S+B(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(T(&QI8B](;W)D92]+;VQA
M8BYP:'`Z.3(T"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#8W"FUS9VED
M(")#;VYT86-T<R(*;7-G<W1R(")+;VYT86MT97(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@
M(DMO;G1A:W1E<B!B;&5V('1I;&;X:F5T('1I;"!D:70@861R97-S96MA<G1O
M=&5K970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C8P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C8P"FUS9VED(")#
M;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B`B"FUS9W-T<B`B26YD
M:&]L9'-T>7!E(&%F(&MO;7!R:6UE<F5T(&9I;#H@(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C<U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-38*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(DEN9&AO;&0@868@
M7"(E<UPB(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,S"FUS9VED(")#;VYT:6YU92(*
M;7-G<W1R(")&;W)T<^9T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B
M"FUS9W-T<B`B0V]O:R!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B4VWE:V%G92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR
M,0IM<V=I9"`B0V]P>2(*;7-G<W1R(")+;W!I97(B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C0W,B!L:6(O5D93+W-M8BYP:'`Z-#<R"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E<R(*;7-G<W1R(")+;W!I
M97)I;F<@;6ES;'EK:V5D97,Z("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB
M"FUS9W-T<B`B2V]P:>ER(&UA<FME<FEN9R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,3DU(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HQ-S`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I9"`B
M0V]S="!)1"(*;7-G<W1R(")'96)Y<B!)1"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S
M=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C4W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#
M;W1E(&0G279O:7)E(@IM<V=S='(@(D5L9F5N8F5N<VMY<W1E;B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDW-R!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M
M97-S86=E.B`B"FUS9W-T<B`B2W5N;F4@:6MK92!01U`M:W)Y<'3I<F4@8F5S
M:V5D.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P-34*;7-G:60@(D-O=6QD(&YO
M="!01U`@<VEG;B!M97-S86=E.B`B"FUS9W-T<B`B2W5N;F4@:6MK92!01U`M
M<VEG;NER92!B97-K960Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,SDS(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDS"FUS
M9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T
M<B`B2W5N;F4@:6MK92!3+TU)344M:W)Y<'1E<F4@8F5S:V5D+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I
M9VX@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK92!3+TU)344M<VEG;NER
M92!B97-K960N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HQ.#0*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O
M;G1A8W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@=&EL9OAJ92!K;VYT86MT
M+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O2&]R9&4O
M1W)O=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(Q
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT.#(*;7-G:60@(D-O=6QD(&YO
M="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&MO
M8FQE('1I;"!,1$%0+7-E<G9E<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C$U-B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M8VAE8VL@8F%L86YC92X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!K;VYT<F]L
M;&5R(&)A;&%N8V4N("5S(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0V
M-@IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DMU;FYE(&EK:V4@9F]R8FEN9&4@=&EL($Q$05`M<V5R=F5R+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@7"(E<UPB('5S:6YG
M($944#H@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!F;W)B:6YD92!T:6P@<V5R
M=F5R(%PB)7-<(B!V960@8G)U9R!A9B!&5%`Z("5S(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,R,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*
M;7-G<W1R(")+=6YN92!I:VME(&]P<F5T=&4@9&ES=')I8G5T:6]N<VQI<W1E
M+B`E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C@@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$R.`IM<V=I9"`B0V]U;&0@;F]T
M(&1E8W)Y<'0@4$=0(&1A=&$Z("(*;7-G<W1R(")+=6YN92!I:VME(&1E:W)Y
M<'1E<F4@4$=0+61A=&$Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3(S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3(S"FUS
M9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B
M2W5N;F4@:6MK92!D96MR>7!T97)E(%,O34E-12UD871A+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M(")+=6YN92!I:VME('-L971T92!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B2W5N;F4@:6MK92!S;&5T=&4@9&ES=')I8G5T:6]N<VQI<W1E
M+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,X"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME('-L971T92`\96T^
M<V-R:7!T/"]E;3X@7"(E<UPB('1I;"!O<&=R861E<FEN9R!A9B!O<'/F=&YI
M;F<N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34S(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z,S@Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT
M)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DMU;FYE(&EK:V4@8F5S=&5M
M;64@;6]D=&%G97)E;G,@92UM86EL+6%D<F5S<V4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T
M(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2W5N;F4@
M:6MK92!H96YT92!H96QE(&%D<F5S<V5K87)T;W1E:RXB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DMU;FYE(&EK:V4@:&5N=&4@:&5L92!D:7-T<FEB=71I;VYS;&ES=&4N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M-#8*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I
M9"`B0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R
M:6)U=&EO;B!L:7-T<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!F=6QD
M<W3F;F1I9R!F;W)T96=N96QS92!O=F5R(&1I<W1R:6)U=&EO;G-L:7-T97(N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&QI
M8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2!<(B5S
M7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@:&5N=&4@<W1R871E9VD@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G
M>2]D:7)E8W0N<&AP.C,P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(&UK
M9&ER(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HW,3D@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S$Y"FUS9VED(")#;W5L
M9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+B(*
M;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&]F9F5N=&QI9R!N^&=L92!F<F$@
M;OAG;&5S97)V97(N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$S.0HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@7"(E<UPB(&9O
M<B!W<FET:6YG+B(*;7-G<W1R(")+=6YN92!I:VME(.5B;F4@7"(E<UPB(&9O
M<B!S:W)I=FYI;F<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,C8R(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK
M92#E8FYE("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN=&5N
M86YC92YP:'`Z-#(P(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z-#(P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@Y6)N92!M;V1U
M;"!T:6P@=F5D;&EG96AO;&1E;'-E("5S(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C<P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O
M<'DN<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y6)N92!K
M871A;&]G(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A
M<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*
M(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U
M<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(SH@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@
M<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME(&[E($Q$05`M<V5R=F5R96XN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`@;&EB+U9&
M4R]/8FIE8W0N<&AP.C(T,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!LYG-E("5S+B(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L
M9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S
M97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@8V]R
M<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB2W5N
M;F4@:6MK92!N=6QS=&EL;&4@:V]D96]R9&5T(&9O<B!D96X@86YM;V1E9&4@
M8G)U9V5R+B`@3F]G;&4@96QL97(@86QL92`B"B)D971A;&IE<B!E<B!U:V]R
M<F5K=&4N(%!R^'8@:6=E;B!E;&QE<B!K;VYT86MT(&1I;B!A9&UI;FES=')A
M=&]R+"!H=FES(&1U("(*(FAA<B!B96AO=B!F;W(@>61E<FQI9V5R92!H:N9L
M<"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,#<*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S,X
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,W-0HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#$*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,S."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<U"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-PIM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(")+=6YN92!I:VME
M(&AE;G1E($%#3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C<T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT
M92!A9')E<W-E:V%R=&]T96ME="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B2W5N;F4@:6MK92!H96YT92!D:7-T<FEB=71I;VYS;&ES=&4N("5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT
M,S<*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E(&1I<W1R
M:6)U=&EO;G-L:7-T97(N("5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,C$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y-PHC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C$*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`B
M2W5N;F4@:6MK92!H96YT92!S97)V97)S(&5V;F5R(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")+=6YN92!I:VME(&=E;F1A;FYE(&MO;F9I
M9W5R871I;VXN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S
M='(@(DMU;FYE(&EK:V4@<FUD:7(@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@
M9V5M;64@)7,M:V]N9FEG=7)A=&EO;B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")+
M=6YN92!I:VME(&=E;6UE(&5N(&)A8VMU<"UK;VYF:6=U<F%T:6]N+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM
M<V=S='(@(DMU;FYE(&EK:V4@9V5M;64@96X@8F%C:W5P+6MO;F9I9W5R871I
M;VXZ("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B2W5N;F4@:6MK92!G96UM92!S
M8W)I<'0@=&EL(&]P9W)A9&5R:6YG(&%F(&]P<^9T;FEN9R!T:6PZ(%PB)7-<
M(BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B(*;7-G<W1R(")+=6YN92!I:VME(&=E;6UE(&)A8VMU
M<"UK;VYF:6=U<F%T:6]N<V9I;&5N("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T
M('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H
M97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E
M(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T
M;R`E<RXB"FUS9W-T<B`B(@HB2W5N;F4@:6MK92!G96UM92!K;VYF:6=U<F%T
M:6]N<V9I;&5N("5S+B!$=2!K86X@96YT96X@86YV96YD92!E;B!A9B`B"B)M
M=6QI9VAE9&5R;F4@9F]R(&%T(&=E;6UE(&MO9&5N('1I;&)A9V4@<.4@)7,@
M96QL97(@;6%N=65L="!K;W!I97)E(&MO9&5N("(*(FYE9&5N9F]R('1I;"`E
M<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T,R!L:6(O
M2&]R9&4O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@(D-O=6QD(&YO="!S96%R
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(")+=6YN92!I:VME('/X9V4@
M3$1!4"US97)V97)E;BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N
M(@IM<V=S='(@(DMU;FYE(&EK:V4@/&5M/G5N;&EN:SPO96T^(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C(Q.0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@
M)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<&1A=&5R92!K;VYT86MT+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,SDV"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I
M;VX@;&ES="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<&1A=&5R92!D:7-T
M<FEB=71I;VYS;&ES=&4N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@
M<VMR:79E(&MO;F9I9W5R871I;VX@9F]R(%PB)7-<(CH@)7,B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S<P"FUS9VED(")#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+B(*;7-G<W1R(")+=6YN92!I:VME(&9I;F1E($UO>FEL;&$@4VED96)A
M<BX@1F]R=FES(&1I9R!O;2!A="!S:61E8F%R96X@97(@Y6)E;BXB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$U-`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I
M;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M(@HB2W5N;F4@:6MK92!G:79E(&)R=6=E<B!<(B5S7"(@9OAL9V5N9&4@<F5T
M=&EG:&5D97(@=&EL(&UA<'!E;B!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Q.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30Q.0IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(D]P=&%L="!T96MS="(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<U"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(DMU<G-E<B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(D]P<F5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X"FUS9VED(")#<F5A=&4@
M82!L:6YK(@IM<V=S='(@(D]P<F5T(&5N(&AE;G9I<VYI;F<B"@HC.B!T96UP
M;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A
M=&4@82!N97<@;VYE(@IM<V=S='(@(D]P<F5T(&5N(&YY(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3(@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4R"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@
M(D]P<F5T('5N9&5R;6%P<&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(T,"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B
M0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")3:V%B97)S(')E='1I9VAE
M9&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q,B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(Q,@IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM
M<V=S='(@(DMR961I=&MO<G0M;G5M;65R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#D@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R
M;V%T:6$B"FUS9W-T<B`B2W)O871I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B
M"FUS9W-T<B`B0W5B82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I
M9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R(").=7;F<F5N9&4@-"!F87-E
M<B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HU,`IM<V=I9"`B0W5R<F5N="!3
M97-S:6]N<R(*;7-G<W1R("));F1E=N9R96YD92!S97-S:6]N(@H*(SH@;&EB
M+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS9VED
M(")#=7)R96YT(%1I;64B"FUS9W-T<B`B06MT=65L('1I9"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`IM
M<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B3G5VYG)E;F1E(%523"!E
M<B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-0IM<V=I9"`B0W5R<F5N="!5
M<V5R<R(*;7-G<W1R(").=7;F<F5N9&4@8G)U9V5R92(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A=&AE<B(*;7-G<W1R
M(")!:W1U96QT('9E:G(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(DYU
M=N9R96YD92!V96IR.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@
M(D%K='5E;"!S=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E1I;'!A<R!O<&=A=F5R+"!D97(@
M8FQI=F5R('5D9OAR="P@;N5R(&1U(&QO9V=E<B!I;F0@:2`E<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,C`*;7-G:60@(D-U="(*;7-G<W1R(")+;&EP(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C
M=&EO;B(*;7-G<W1R(")+;&EP('9A;&<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8W(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U
M<R(*;7-G<W1R(")#>7!E<FXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-0IM<V=I9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B2WER:6QL:7-K
M("A+3TDX+5(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*;7-G:60@
M(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I(@IM<V=S='(@(DMY<FEL;&ES:R`H
M5VEN9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B2WER
M:6QL:7-K+U5K<F%I;G-K("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C8X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C
M:"!297!U8FQI8R(*;7-G<W1R(")4:F5K:VEE="(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-3(*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,B!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,C<R(&QI8B](;W)D92]&;W)M+G!H<#HS,C<R"FUS9VED
M("(B"B)$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I(@IM<V=S='(@(B(*
M(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4Y(&QI8B](;W)D92]-86EN
M=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1A9VQI9R(*
M"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O
M=W-E<B(*;7-G<W1R(")$871A5')E92!S=&EF:6YD97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C<P(&QI8B](;W)D92]&;W)M+G!H<#HS,C<P
M"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B1&%T86)A<V4M;W!S
M;&%G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDX"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR,SDX(&QI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N
M<&AP.C<R"FUS9VED(")$871E(@IM<V=S='(@(D1A=&\B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E
M:79E9"(*;7-G<W1R(")-;V1T86=E;'-E<V1A=&\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR-S@Y(&QI8B](;W)D92]&;W)M+G!H<#HR-S@Y"FUS
M9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")$871O=F%L9R(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM<V=S='(@(D1A9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`B4VQE="!K;VQO
M;FYE(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#4Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$
M96-E;6)E<B(*;7-G<W1R(")$96-E;6)E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E
M8VEM86P@;G5M8F5R<R(*;7-G<W1R(")$96-I;6%L=&%L(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,`IM<V=I9"`B1&5C
M<F5A<V4@26YD96YT(@IM<V=S='(@(DUI;F1S:R!I;F1R>6MN:6YG(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H
M<#HQ,3<*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*;7-G:60@(D1E
M9F%U;'0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F875L="!#;VQO
M<B(*;7-G<W1R(")3=&%N9&%R9&9A<G9E(@H*(SH@9G)A;65W;W)K+TED96YT
M:71Y+TED96YT:71Y+G!H<#HY-B!L:6(O2&]R9&4O261E;G1I='DN<&AP.CDV
M"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(E-T86YD87)D+6ED
M96YT:71E="(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW-0IM<V=I9"`B
M1&5F875L="!3:&5L;"(*;7-G<W1R(")3=&%N9&%R9"US:V%L(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N<R(*;7-G
M<W1R(")$969I;FET:6]N97(B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<Q(&9R
M86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(V"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z-#(R(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z-#,Y"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,S(V(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z-#(R"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-#,Y
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S8*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHW,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,Y"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@R('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHW,PHC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3@@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;&ES="YI;F,Z,S$*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE
M=&4N:6YC.C$P"FUS9VED(")$96QE=&4B"FUS9W-T<B`B4VQE="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,@IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B4VQE="!C96QL92(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS
M9VED(")$96QE=&4@1W)O=7`B"FUS9W-T<B`B4VQE="!G<G5P<&4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G:60@(D1E;&5T92!,
M;V<B"FUS9W-T<B`B4VQE="!L;V=B;V<B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3`Q"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S
M='(@(E-L970@=&EL;&%D96QS97(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS
M9W-T<B`B1FIE<FX@;V<@=61S;&5T(&)E<VME9&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-PIM<V=I9"`B
M1&5L971E(&-E;&PB"FUS9W-T<B`B4VQE="!C96QL92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@
M(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B4VQE="!K;VQO;FYE(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B4VQE="!E:W-I<W1E<F5N9&4L
M(&%L=&5R;F%T:79E('-K86)E;&]N(@H*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-30@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C4T"FUS9VED(")$96QE=&4@;65S<V%G97,B"FUS9W-T<B`B4VQE
M="!B97-K961E<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(Q(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@
M(E-L970@=&EL;&%D96QS97(@9F]R(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-#(T(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3
M;&5T('1I;&QA9&5L<V5R(&9O<B!<(B5S7"(@;V<@86QL92!U;F1E<F]R9&YE
M9&4@=&EL;&%D96QS97(_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G
M<W1R(")3;&5T('+F:VME(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED
M96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M(@IM<V=S='(@(E-L970@=F%L9W1E(&ED96YT:71E="(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4S(&QI8B](;W)D92])34%0
M+T%#3"]R9F,T,S$T+G!H<#HU,PIM<V=I9"`B1&5L971E('-U8B!F;VQD97)S
M(@IM<V=S='(@(E-L970@=6YD97)M87!P97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E
M;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B4VQE="!D96X@86MT
M=65L;&4@:V]L;VYN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E('1H92!C=7)R
M96YT(')O=R(*;7-G<W1R(")3;&5T(&1E;B!A:W1U96QL92!RYFMK92(*"B,Z
M(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R(")/<&=R861E<FEN9W-S8W)I<'0@7"(E<UPB('-L971T970N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38S(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I;64B
M"FUS9W-T<B`B3&5V97)I;F=S=&ED<W!U;FMT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C<Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$
M96YM87)K(@IM<V=S='(@(D1A;FUA<FLB"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHR.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB
M"FUS9W-T<B`B0F5S:W)I=B!P<F]B;&5M970B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,S@@;&EB+TAO<F1E+T9O<FTN<&AP.CDS.`HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS
M9VED(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-K<FEV96QS92(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C`V(&QI8B](;W)D92YP:'`Z,C`V
M"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ(@IM
M<V=S='(@(D1E=&%L:F5R("AO9W/E(&D@2&]R9&4G<R!L;V=F:6PI.B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,C$P(&QI8B](;W)D92YP:'`Z
M,C$P"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R(")$971A;&IE<B!E<B!S:W)E=F5T('1I
M;"!L;V=B;V=E;B!A9B!H96YS>6X@=&EL(&%D;6EN:7-T<F%T;W)E;BXB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$979E;&]P
M;65N="(*;7-G<W1R(")59'9I:VQI;F<B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R-`IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@(D1U9W!U;FMT(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*;7-G:60@(D1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1'5G<'5N:W0@9F]R('-I9'-T92!T
M:6UE.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"FUS
M9VED(")$97<@<&]I;G0Z("(*;7-G<W1R(")$=6=P=6YK=#H@(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B4F5T;FEN9R!V96YS
M=')E('1I;"!H^&IR92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T
M(@IM<V=S='(@(E)E=&YI;F<@:/AJ<F4@=&EL('9E;G-T<F4B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@
M(DMA=&%L;V<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED
M(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(E9I<R!T:60@;65D
M(#(T('1I;65R/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,#`*;7-G
M:60@(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("));F1S=&EL;&EN9V5R(&9O
M<B!V:7-N:6YG(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C@Y
M"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM<V=S='(@(E9I
M<R!U9&1Y8F5N9&4@=F5J<G5D<VEG="(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z.3(*;7-G:60@(D1I<W!L87D@9F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B
M5FES('9E:G)U9'-I9W0@*%1!1BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-SDY(&QI8B](;W)D92]&;W)M+G!H<#HR-SDY"FUS9VED(")$:7-P
M;&%Y(&9O<FUA="(*;7-G<W1R(")6:7-N:6YG<V9O<FUA="(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O341.+G!H<#HQ.3$@;&EB+TAO<F1E+TU)344O341.
M+G!H<#HQ.3$*;7-G:60@(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(*;7-G
M<W1R(")/=F5R9')A9V5L<V5S;F]T:71S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C<P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$:FEB
M;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(R(&QI8B](;W)D92]097)M<R]522YP:'`Z-#(R"FUS
M9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(D9O<G1R>60@<VQE=&YI;F<B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(D1U
M(&WE(&EK:V4@:V%L9&4@;6%I;G1E;F%N8V4N<&AP(&1I<F5K=&4B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*
M;7-G<W1R("));F1E:&]L9&5R(&1E;B!F^')S=&4@<N9K:V4@9F5L=&YA=FYE
M/R!(=FES(&IA+"!M87)KZ7(@9&5N;F4@8F]K<SHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1O;6EN:6-A(@IM<V=S='(@(D1E;B!D;VUI;FEK86YS:V4@4F5P=6)L:6LB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")$
M96X@9&]M:6YI:V%N<VME(%)E<'5B;&EK(@H*(SH@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A;B!A8V-O=6YT/R!3
M:6=N('5P+B(*;7-G<W1R(")(87(@9'4@:6MK92!N;V=E;B!K;VYT;S\@365L
M9"!D:6<@=&EL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@U,R!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4S"FUS9VED
M(")$;W=N;&]A9"(*;7-G<W1R(")(96YT(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.#4S(&QI8B](;W)D92]-24U%+T-O;G1E;G1S
M+G!H<#HX-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS
M9W-T<B`B2&5N="`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*
M;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N(@IM<V=S='(@(DAE;G0@9V5N97)E<F5T(&MO;F9I9W5R871I
M;VX@;F5D('-O;2!02%`M<V-R:7!T+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R
M;W`@9&]W;B!L:7-T(@IM<V=S='(@(E)U;&QE9V%R9&EN+6QI<W1E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,T"FUS9VED(")$<G5G<R(*;7-G<W1R
M(")-961I:V%M96YT97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%
M+4UA:6PB"FUS9W-T<B`B12UM86EL(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(@;&EB+TYE="]335,O9V5N97)I8U]S
M;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R
M+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM
M<V=S='(@(B(*(D5-86EL+71I;"U335,@9V%T97=A>2UD<FEV97(L(&9O<B!O
M<&5R873X<F5R+"!S;VT@=61B>61E<B!D96YN92!S97)V:6-E+B(*"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO
M8FEL92YP:'`Z,S0*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5Q=6%D;W(B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C,R-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-CD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-0HC.B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S."!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X,0HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M;7-G:60@(D5D:70B"FUS9W-T<B`B4F5D:6=E<B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]522YP:'`Z-3`@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU
M,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R("+&;F1R92!B;&]K(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H<#HR,C8*;7-G
M:60@(D5D:70@1W)O=7`B"FUS9W-T<B`BQFYD<F4@9W)U<'!E(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HW-B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C$P,`HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<V
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI
M<W-I;VXB"FUS9W-T<B`BQFYD<F4@=&EL;&%D96QS92(*"B,Z('-E<G9I8V5S
M+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B
M"FUS9W-T<B`BQFYD<F4@=&EL;&%D96QS97(B"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(L9N9')E('1I;&QA9&5L<V5R(&9O
M<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G:60@(D5D
M:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(L9N9')E('9A;&<@9F]R.B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W(&QI8B](;W)D92]0
M97)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R
M;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R("+&;F1R92!T:6QL861E;'-E
M<B!F;W(@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R("+&;F1R92!T:6QL861E;'-E<B!F;W(@)7,B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R
M(")59&1A;FYE;'-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R("+&
M9WEP=&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B16P@4V%L=F%D;W(B"FUS9W-T
M<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G:60@(D5L96UE;G0N+BXB"FUS
M9W-T<B`B16QE;65N="XN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED(")%;2(*;7-G<W1R(")%;2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,C0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V.0HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@V.2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-`IM
M<V=I9"`B16UA:6PB"FUS9W-T<B`B94UA:6PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4V-@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8X
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3`*;7-G:60@(D5M
M86EL($%D9')E<W,B"FUS9W-T<B`B92UM86EL+6%D<F5S<V4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S(&QI8B](;W)D92]&;W)M+G!H<#HQ
M.38S"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T
M<B`B12UM86EL+6%D<F5S<V5R('-K86P@<&%S<V4N(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DX.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DX.0IM
M<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B12UM86EL
M(&UE9"!B96MRYF9T96QS92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G
M96YE<FEC7W-M='`N<&AP.CDQ(&QI8B].970O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D5M
M86EL+71O+5--4R!'871E=V%Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(Y.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B4VUI
M;&5Y<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B5&]M(&)E<VME
M9"XB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C0S(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT.#0*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8V,B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-S`U"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,34P(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR-#,*(SH@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C0X-"!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP
M:'`Z-C8R"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HW,#4@;&EB+TAO
M<F1E+T%U=&@O;&1A<"YP:'`Z,34P"FUS9VED(")%;7!T>2!R97-U;'0N(@IM
M<V=S='(@(DEN=&5T(')E<W5L=&%T+B(*"B,Z(&9R86UE=V]R:R]344PO4U%,
M+TME>7=O<F1S+G!H<#HQ,3,@;&EB+TAO<F1E+U-13"]+97EW;W)D<RYP:'`Z
M,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B5&]M="!U
M9'1R>6LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-30W"FUS9VED(")%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/R(*;7-G<W1R(")!:W1I=NER(&EN9'/F='1E;'-E(&%F(&)I
M;&QE9&5R(&9R82!&;W1O9V%L;&5R:65R(&D@=&5K<W0_(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C4R,@IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\B"FUS9W-T<B`B06MT:7;I<B!H^&IR92UK;&EK(&-O
M;G1E>'0M;65N=3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3,*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(U.#@@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3,*;7-G:60@(D5N
M9"!Y96%R(@IM<V=S='(@(E-L=70MY7(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O
M<B(*;7-G<W1R(")&;W)S=/AR(&5D:71E<FEN9W-VYG)K=/AJ(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C(R-`IM<V=I9"`B(@HB16YT97(@82!S96-U
M<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@
M;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES
M('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(DEN9'1A<W0@
M970@<VEK:V5R:&5D<W-P^')G<VWE;"P@<V]M(&1U('9I;"!B;&EV92!S<'5R
M9W0L(&[E<B!D=2!H87(@8G)U9R!F;W(@(@HB870@YFYD<F4@9&ET(&MO9&5O
M<F0L(&9X("=H=F%D(&5R(&1I="!KYFQE9'ER<R!N879N/R<Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$Y"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B
M26YD=&%S="!54DP@=&EL(&)I;&QE9"!H97(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DR"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T
M97)S(&)E;&]W.B(*;7-G<W1R("));F1T87-T(&)O9W-T879E<B!N961E;F9O
M<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@
M(L9K=F%T;W)I86P@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(L9R:71R96$B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O5FEE=RYP:'`Z.30*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O5FEE=RYP:'`Z.30@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#@*;7-G
M:60@(D5R<F]R(@IM<V=S='(@(D9E:FPB"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C0V,R!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C0V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@
M)7,B"FUS9W-T<B`B1F5J;"!V960@9&%N;F5L<V4@868@8FQO:SH@)7,B"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T
M<B`B1F5J;"!U;F1E<B!S;&5T;FEN9R!A9B!S>6YC+6CF9W1E.B`E<R(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@S"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")&
M96IL('5N9&5R('-L971N:6YG(&%F('-Y;F,@;&]G.B`E<R(*"B,Z(&9R86UE
M=V]R:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8X(&QI8B](;W)D92]496UP
M;&%T92YP:'`Z-#8X"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I
M;F<@8V]N=&5N=#H@)7,B"FUS9W-T<B`B1F5J;"!U;F1E<B!H96YT;FEN9R!A
M9B!I;F1H;VQD.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H
M<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S
M=V]R9#H@)7,B"FUS9W-T<B`B1F5J;"!U;F1E<B!O<&1A=&5R:6YG(&%F(&MO
M9&5O<F0Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S`U"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`U"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM
M<V=S='(@(D9E:FP@9F]R8G5N9&5T(&UE9"!E+7!O<W0@8F5S:V5D+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G
M:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")&96IL('5N9&5R
M('-K<FEV;FEN9R!A9B!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C<V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA
M(@IM<V=S='(@(D5S=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM
M<V=S='(@(L9T:6]P:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V
M"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171N:7-K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E<R(*
M;7-G<W1R(")(=F5R(&MV87)T97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2'9E<G0@
M,BX@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(D5V97)Y(#,P('-E8V]N9',B
M"FUS9W-T<B`B2'9E<B!H86QV92!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-`IM<V=I9"`B
M179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DAV97(@-2X@;6EN=70B"@HC.B!F
M<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P(&QI8B](
M;W)D92]-86EN=&5N86YC92YP:'`Z-C`*;7-G:60@(D5V97)Y($QO9VEN(@IM
M<V=S='(@(D%L=&ED('9E9"!L;V=I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-#0*;7-G:60@(D5V97)Y(&AA;&8@:&]U<B(*;7-G<W1R(")(=F5R
M(&AA;'9E('1I;64B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3(*;7-G:60@(D5V97)Y(&UI;G5T92(*
M;7-G<W1R(")(=F5R(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA
M<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")%:W-E
M;7!E;';F<F1I97(Z(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C4Q(&%D;6EN
M+W!H<'-H96QL+G!H<#HX,B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED
M(")%>&5C=71E(@IM<V=S='(@(E5D9OAR(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV,30@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z-#<U"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z-C$T"FUS9VED(")%>'!A;F0B"FUS9W-T<B`B561V:60B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C,R"FUS9VED(")%>'!A
M;F0@4VED96)A<B(*;7-G<W1R(")&;VQD('-I9&5P86YE;"!U9"(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T
M<B`B1F]R=F5N=&5D92`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z,3<U(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W-0IM
M<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;2(*;7-G<W1R(")&;W)V96YT961E(')E;G0@;W)D(&5L;&5R(&-I=&5R970@
M<_AG971E<FTB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT
M,3(@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T
M:6]N($1A=&4B"FUS9W-T<B`B1F]RYFQD96QS97-D871O(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S<@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@(D5K<W!O
M;F5N="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM<V=S='(@(D9'+69A<G9E
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W-PIM<V=I9"`B1E10('5P
M;&]A9"!O9B!S971U<"(*;7-G<W1R(")&5%`M;&%G<FEN9R!A9B!O<'/F=&YI
M;F<B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<W%L+G!H<#HR,C`@;&EB
M+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(P"FUS9VED(")&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92#F;F1R92!I
M;F1S=&EL;&EN9V5R;F4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C<U(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C<U(&QI8B](;W)D92]!=71H+VQD
M87`N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!FY2!F;W)B:6YD96QS92!T:6P@
M3$1!4"!S97)V97)E;BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP
M:'`Z.3@@;&EB+TAO<F1E+T%U=&@O<VUB+G!H<#HY.`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK
M92!F;W)B:6YD92!T:6P@4TU"+7-E<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C<Q-R!L:6(O5D93+V9T<"YP:'`Z-S$W"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R(")&96IL('5N9&5R(&MO<&EE<FEN9R!F<F$@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(R(&QI8B]61E,O9G1P+G!H<#HW
M,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(")+=6YN92!I:VME(&MO<&EE<F4@=&EL(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W(&QI8B](;W)D
M92]!=71H+W-A<VPN<&AP.C@W"FUS9VED(")&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@971A8FQE
M<F4@;GD@4T%33"UF;W)B:6YD96QS92XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<U-2!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4P,0HC
M.B!L:6(O5D93+V9T<"YP:'`Z-S4U(&QI8B]61E,O<VUB+G!H<#HU,#$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R(")+=6YN92!I:VME(&9L>71T92!T:6P@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8U(&QI8B]61E,O<VUB+G!H<#HT
M-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E
M<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E.B`E<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM
M<V=S='(@(E-M=6MT(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-SD*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&86QK;&%N9"!)<VQA;F1S
M("A-86QV:6YA<RDB"FUS9W-T<B`B1F%L:VQA;F1S^&5R;F4@*$UA;'9I;F%S
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@P
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")&YG+X
M97)N92(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@@;&EB+TAO<F1E
M+T-,22YP:'`Z,C,X"FUS9VED(")&871A;"!%<G)O<CHB"FUS9W-T<B`B1/AD
M96QI9R!F96IL.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.#<*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,S4Q"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS
M:6UI;&5R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0Q"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#,@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED
M(")&96)R=6%R>2(*;7-G<W1R(")&96)R=6%R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B1OAL97,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&
M965L<R!L:6ME.B`B"FUS9W-T<B`B1OAL97,Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED(")&97<@4VAO=V5R
M<R(*;7-G<W1R(")&Y2!B>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(D;E('-N96)Y9V5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3DT-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@
M;6%T<FEX(@IM<V=S='(@(D9E;'1M871R:6-E(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R-0IM<V=I
M9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S(Y(&QI8B](;W)D92]&;W)M
M+G!H<#HS,S(Y"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L970@
M<VMR:69T<W1Y<&]G<F%F:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C@Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,R!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R
M(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS
M9VED(")&:6QE(@IM<V=S='(@(D9I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HW.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,L('!H<"UF;W)M870*;7-G:60@(D9I
M;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B06YT86P@9FEL97(Z("5S(&9I
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T9WHN<&AP.C<Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM
M<V=S='(@(D%N=&%L(&9I;&5R.B`E<R!F:6QE<B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M(")&:6QHY6YD=&5R:6YG(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z
M-S`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S`*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&:6QN
M879N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW-R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDW-PIM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T
M<B`B1FEL=F%L9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T.#8*;7-G:60@(D9I;&4@=7!L;V%D(@IM
M<V=S='(@(D9I;&QA9W)I;F<B"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W
M<V5R+G!H<#HY,#(@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDP,@IM<V=I9"`B
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S='(@(D9I;&QA9W)I
M;F<@:6MK92!U;F1E<G-T^'1T970N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.CDQ"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1R92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,0IM<V=I9"`B1FEN;&%N9"(*;7-G<W1R(")&:6YL86YD(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R
M(")&^')S=&4@:&%L=F1E;"(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HW-"!L
M:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G:60@(D9I<G-T(%%U87)T97(B"FUS
M9W-T<B`B1OAR<W1E(&MV87)T86PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C4W"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HR-3<*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")&
M:6MSZ7(@<W3X<G)E;'-E<V9O<FAO;&0B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,S(*;7-G:60@(D9L:7`B"FUS9W-T<B`B1FQI
M<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(D9L>61E;F1E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C$*;7-G:60@
M(D9O9R(*;7-G<W1R(")4Y6=E(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$P-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-PHC.B!L
M:6(O5D93+VUU<W%L+G!H<#HQ,#<@;&EB+U9&4R]S<6PN<&AP.C(S-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS
M9W-T<B`B36%P<&4@)7,@96MS:7-T97)E<B!I:VME(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#
M;VQO<B(*;7-G<W1R(")4>7!O9W)A9FEF87)V92(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-PIM<V=I9"`B1F]O9"(*;7-G<W1R(")-860B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C,*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(@IM<V=S='(@(D9O<B!W96)P<F]G<F%M;65R+"!S;VT@:6MK92!U
M;F1E<G-T^'1T97(@8FEL;&5D97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,T,0IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5F5J<G5D<VEG
M="`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,@IM
M<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE
M9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82`B"B)L
M87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K
M*2(*;7-G<W1R("(B"B)59'-I9W1S9&%G92`H8F5MYG)K(&%T(&1E;B!R971U
M<FYE<F4@=F5J<G5D<VEG="!V961R^')E<B!BY61E(&1A9R!O9R!N870[(&5T
M("(*(G-T;W)T(&%N=&%L(&AE<B!K86X@<F5S=6QT97)E(&D@96X@;65G970@
M8G)E9"!B;&]K*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R
M"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B1VQE;70@
M9&ET(&MO9&5O<F0_(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V
M-`IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R;75L87)E<B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*;7-G<W1R(")/
M<F1S<')O9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY.0IM<V=I9"`B
M1F]R='5N92!T>7!E(@IM<V=S='(@(D5P:6=R86UT>7!E(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C,X"FUS9VED(")&;W)T=6YE<R(*;7-G<W1R(")%
M<&EG<F%M;65R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y"FUS9VED
M(")&;W)T=6YE<R`R(@IM<V=S='(@(D5P:6=R86UM97(@,B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M(")&;W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q,0IM<V=I
M9"`B1F]R=V%R9',B"FUS9W-T<B`B5FED97)E<V5N9&5L<V4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&
M<B(*;7-G<W1R(")&<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED(")&<F%M97,B"FUS9W-T<B`B
M4F%M;65R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@W(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A;FMR
M:6<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI
M=&%N(@IM<V=S='(@(D9R86YK<FEG+"!-971R;W!O;&ET86XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.CDQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-`HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*
M;7-G:60@(D9R96YC:"!'=6EA;F$B"FUS9W-T<B`B1G)A;G-K($=U>6%N82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(D9R
M86YS:R!0;VQY;F5S:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R86YS:V4@<WED;&EG92!4
M97)R:71O<FEE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S0*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B1G)A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.34*
M;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")&<F$B"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO
M;B(*;7-G<W1R(")&=6QD(&)E<VMR:79E;'-E(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@
M36]O;B(*;7-G<W1R(")&=6QD;>5N92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT
M+G!H<#HV-2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS
M9VED(")&=6QL($YA;64B"FUS9W-T<B`B1G5L9'0@;F%V;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM
M<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@
M(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&QE<FD@
M:'9O<F9R82!B:6QL961E('-K86P@=&%G97,@9G)A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Y"FUS
M9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QL97)I.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I82(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<NER("5S+6MO;F9I9W5R871I
M;VXB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ.`IM
M<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS9W-T<B`B1V5N97)E<F5T(&MO9&4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D=E<FUA;GDB"FUS9W-T<B`B5'ES:VQA;F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,0HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S4*;7-G:60@(D=H86YA(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3(*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED
M(")':6)R86QT87(B"FUS9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S8@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU-S8*;7-G:60@(D=I=F5N($YA;64B"FUS9W-T<B`B1F]R;F%V
M;B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA
M=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(D=R=6YD;.9G
M9V5N9&4@:6YD<W1I;&QI;F=E<B(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N
M:6YC.C$W"FUS9VED(")';R(*;7-G<W1R(")59&;X<B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D?V9&5L
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,S$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,S$*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!-87!S(@H*(SH@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR
M,2!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C
M:"(*;7-G<W1R(")';V]G;&4M<_AG;FEN9R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,S@*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(S.`IM<V=I9"`B1W)A>7-C86QE(@IM<V=S
M='(@(D=RY71O;F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDS"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R
M(")'<N9K96YL86YD(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G
M:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")'<N9S:R`H25-/+3@X
M-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDU(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.34@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<OAN
M;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDU"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDU"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW-`IM<V=I9"`B1W)E;F%D82(*;7-G<W1R(")'<F5N861A
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*;7-G:60@(D=R;W5P($%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(D=R=7!P92UA9&UI;FES=')A=&EO;B(*"B,Z
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$V.0HC.B!L:6(O2&]R9&4O1W)O=7`N<&AP.C4Y
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA
M;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@(D=R=7!P96YA=FYE(&WE
M(&EK:V4@=N9R92!T;VUM92(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HS,#<@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P
M:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R
M;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T
M<B`B1W)O=7!?;&1A<#H@2V%N(&EK:V4@=&EL9OAJ92!G<G5P<&4@)7,N(%-E
M<G9E<F5N(&UE;&1E<CH@(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C$Q."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT,3@@;&EB+TAO
M<F1E+T=R;W5P+VQD87`N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A
M<"YP:'`Z,3(T(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT,3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<R(*;7-G<W1R(")'<F]U<%]L9&%P.B!+86X@:6MK92!S;&5T=&4@
M9W)U<'!E("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,Z(&QI
M8B](;W)D92]'<F]U<"]L9&%P+G!H<#HS,S@@;&EB+TAO<F1E+T=R;W5P+VQD
M87`N<&AP.C,W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@(D=R;W5P7VQD87`Z
M($MA;B!I:VME(&]P9&%T97)E(&=R=7!P92`E<R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,S$T(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S$T"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B1W)U<'!E
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDV"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDV
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY."!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-@IM<V=I9"`B1W5A9&5L;W5P92(*;7-G<W1R(")'=6%D96QO
M=7!E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDW"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<W"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&%M86QA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.3(*;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,C8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1^9S
M=&5T:6QL861E;'-E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT
M-S(*;7-G:60@(D=U97-T8F]O:R(*;7-G<W1R(")'YG-T96)O9R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6YE82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F5A+4)I<W-A=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'=7EA;F$B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`@;&EB+TAO<F1E+T9O<FTN
M<&AP.CDV,`IM<V=I9"`B2%1-3"(*;7-G<W1R(")(5$U,(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-0IM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(DA434Q!<F5A(&[F9W1E<B!PY2!F
M96H@=FES(&%T('-L971T92!D96X@<VED<W1E(&-E;&QE(&D@<N9K:V4N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-@IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E
M82!NYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!K;VQO
M;FYE(&D@=&%B96PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+B(*;7-G
M<W1R(")(5$U,07)E82!NYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N
M('-I9'-T92!RYFMK92!I('1A8F5L+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:'1T<"YP:'`Z,34W(&QI8B](;W)D92]!=71H+VAT='`N<&AP.C$U-PIM
M<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(DA45%`MYF=T;FEN9R!I:VME(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(86ET:2(*;7-G<W1R(")(8>]T:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM<V=S='(@(DAA<V@M86QG;W)I=&UE
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*
M;7-G:60@(DAA>F4B"FUS9W-T<B`B1&ES(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.3$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,30*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.CDQ.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ
M-`IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(E1O<'1E:W-T(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0HC.B!L:6(O2&]R
M9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HV,0IM<V=I9"`B2&5A9&5R<R(*
M;7-G<W1R(")/=F5R<VMR:69T97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3`W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O
M<FTB"FUS9W-T<B`B2W)A9G1I9R!T;W)D96XB"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X.0IM<V=I9"`B2&5B<F5W("A)4T\M.#@U.2TX+4DI(@IM<V=S
M='(@(DAE8G)A:7-K("A)4T\M.#@U.2TX+4DI(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,C(@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(DCX:F1E(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-"!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3@V"B,Z(&QI8B](;W)D92](96QP
M+G!H<#HQ.#0@;&EB+TAO<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP
M+VEN9&5X+G!H<#HQ-PHC.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM
M<V=I9"`B2&5L<"(*;7-G<W1R(")(:N9L<"(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@
M961I=&]R(@IM<V=S='(@(DAJYFQP('1I;"!R961I9V5R:6YG<W;F<FMT^&HB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S<Q"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&KF;'!E<B(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*
M;7-G<W1R(")(96UI<V;F<F4B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHQ,"!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,`IM<V=I9"`B
M2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.B(*;7-G<W1R(")(
M97(@97(@<W1A<G1E;B!A9B!F:6QE;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I9"`B2&EG:"(*;7-G<W1R(")(
M^&HB"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S
M+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S
M='(@(DAJ96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I
M8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(DAE;&QI9W/X("A6871I:V%N<W1A
M=&5N*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34T."!L:6(O
M2&]R9&4N<&AP.C$U-#@*;7-G:60@(DAO;64B"FUS9W-T<B`B2&IE;2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S
M(@IM<V=S='(@(E!R:79A="UA9')E<W-E(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C<P"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")(:F5M
M;65K871A;&]G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G<W1R(")0<FEV870M=&5L969O
M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-SD*;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U
M<F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO
M;F<@2V]N9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-PIM<V=I
M9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C0U,B!L:6(O2&]R9&4O2V]L86(N<&AP.C0U,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!59WEL9&EG("5S(%A-3"!D871A('#E=')U9F9E="!I(&)E<VME9"`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YG96X@8F5S:V5D('-V87)E<B!T:6P@;V)J
M96MT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#4@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HT-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A
M9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5T(&]B:F5K="!A9B!T
M>7!E("5S(&9U;F1E="!I(&)E<VME9"`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z,3(U,2!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R
M96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4VQE='1E
M9&4@)7,@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HR
M,C,@;&EB+TAO<F1E+TMO;&%B+G!H<#HR,C,*;7-G:60@(DAO<F1E+TMO;&%B
M.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL
M)R!02%`@97AT96YS:6]N(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);G1E9W)A
M=&EO;G-M87-K:6YE;B!K<N9V97(@4$A0+75D=FED9&5L<V4@)V1O;7AM;"<B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4Q,B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C4Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA
M8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EK:V4@9&%N;F4@;GET(%A-
M3"UT<N8@9F]R(&]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3(T."!L:6(O2&]R9&4O2V]L86(N<&AP.C$R-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EK:V4@<VQE
M='1E("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C0X,R!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@
M240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L
M86(Z($MA;B!I:VME(&EN9&AE;G1E($U)344M240@9F]R(&1E;&5N(&%F('1Y
M<&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3<@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HQ,3DW"B,L('!H<"UF;W)M870*;7-G:60@(DAO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@7"(E<UPB.B`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EK:V4@<WEN:W)O;FES97)E
M("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S<@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,S,W"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA
M<F5S.B`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@2V%N(&EK:V4@<WEN:W)O
M;FES97)E(&1E;&EN9V5R.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,S0P(&QI8B](;W)D92]+;VQA8BYP:'`Z,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB)7-<(B(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@56ME;F1T(&1E;&EN9R!<(B5S7"(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS
M9VED(")(;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`B5F%N9')E="!S=')E9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*
M;7-G:60@(DAO<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")686YD<F5T(&9O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(E9A;F1R970Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4Q"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*2(*;7-G<W1R(")(=F]R9&%N(&)A<B!D=2!D:6<@860@;65D(&%T(&AA
M=FYE(&AE<C\@*$EN9')A<'!O<G3I<B$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA
M;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B
M2'9O<B!M86YG92!K;VQO;FYE<B#X;G-K97(@9'4@870@<V%M;65N;.9G9V4_
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO
M=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")(
M=F]R(&UA;F=E(&9E;'1E<B`H:V]L;VYN97(I(&5R(&1E<C\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS
M9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*
M;7-G<W1R(")(=F]R(&UA;F=E('+F:VME<B#X;G-K97(@9'4@870@<V%M;65N
M;.9G9V4_(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S<@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X.0IM<V=I9"`B2'5M:61I='DB"FUS9W-T
M<B`B1G5G=&EG:&5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")&=6=T:6=H960Z("(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(DAU;6]R:7-T97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG
M87)Y(@IM<V=S='(@(E5N9V%R;B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER<W%L+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,3<R"B,Z(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C,U(&QI8B](;W)D
M92]!=71H+V-Y<G5S+G!H<#HQ-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B3W!R971T
M96QS92!A9B!)34%0+6UA<'!E(&9E:FQE9&4Z("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-2!F<F%M97=O<FLO075T:"]!=71H
M+V-Y<G5S+G!H<#HR,30*(SH@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR
M.34@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C(Q-`HC+"!P:'`M9F]R;6%T
M"FUS9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G
M<W1R(")3;&5T;FEN9R!A9B!)34%0+6UA<'!E(&9E:FQE9&4Z("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR-#(@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@
M9F%I;&5D.B`E<R(*;7-G<W1R(")$969I;F5R:6YG(&%F(&MV;W1E(&9O<B!)
M34%0+6UA<'!E(&9E:FQE9&4Z("5S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,Q-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q-@IM<V=I9"`B25`@
M061D<F5S<R(*;7-G<W1R("))4"UA9')E<W-E(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]I<&)A<VEC+G!H<#HW-R!L:6(O2&]R9&4O075T:"]I<&)A<VEC
M+G!H<#HW-PIM<V=I9"`B25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R("))4"UA9')E<W-E(&EK:V4@=&EL9^9N9V5L:6=E+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D@;&EB+TAO<F1E+T%U=&@O
M:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A
M;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(DE0+6%D<F5S<V4@:6MK92!I
M;F1E;F9O<B!#2412+6)L;VLN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDU"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L871I
M;VXN(@IM<V=S='(@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*
M;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("));F1SYG0@<N9K
M:V4@9OAR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R,"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))
M<VQA;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))
M8V]N<R!/;FQY(@IM<V=S='(@(DMU;B!I:V]N97(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(DEK;VYE<B!F;W(@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
M26MO;F5R(&UE9"!T96MS="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M.3,*;7-G:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B261E;G1I=&5T
M<VYA=FXZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M-C`P(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL
M("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")(=FES
M(&1E;B!I:VME('9I<W0@:V]R<F5K="P@)7,@9F]R(&%T(.5B;F4@9&5N(&D@
M970@;GET('9I;F1U92XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4Y
M"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H
M:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@
M(B(*(DAV:7,@9'4@:6MK92!S97(@;F]G96X@:6MO;F5R('9E9"!B<G5G(&%F
M($EN=&5R;F5T($5X<&QO<F5R('-K86P@9'4@;>5S:V4@(@HB:&%K:V4@9&5N
M;F4@8F]K<R!A9B!F;W(@870@<VSE(%!.1RUT<F%N<W!A<F5N<R!F<F$N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3<R"FUS9VED
M("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB9&ES<&QA
M>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2'9I<R!D=2!S97(@
M9&5N;F4@8F5S:V5D(&D@<W1E9&5T(&9O<B!E="!B:6QL961E+"!SY2!V:6P@
M9'4@:6MK92!K=6YN92!S92`B"B)D970@:2!D:6X@;F5T+6SF<V5R(&5F=&5R
M(&]P;.9G;FEN9RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*;7-G:60@(DEM86=E(%!R979I97<Z
M(@IM<V=S='(@(D)I;&QE9"UF;W)HY6YD<W9I<VYI;F<Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I
M9"`B26UA9V4@55),(@IM<V=S='(@(D)I;&QE9"U54DPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*
M;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B0FEL;&5D+5523#HB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R(")":6QL
M961E(&9R82!G86QL97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M
M(&=A;&QE<GDZ(@IM<V=S='(@(D)I;&QE9&4@9G)A(&=A;&QE<FDZ(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3<V,0IM<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D)I;&QE9"UO
M<&SF9VYI;F<B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(D)I;&QE9&5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z-R!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<@=&5M<&QA=&5S+V1A=&$O
M='-V:6YF;RYI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T
M97`@)60B"FUS9W-T<B`B26UP;W)T97)I;F<L('1R:6X@)60B"@HC.B!T96UP
M;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED
M("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B26UP;W)T97)E9&4@9F5L
M=&5R.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G
M:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T97)E9&4@9F5L
M=&5R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T
M<B`B26YD<^9T('+F:VME(&5F=&5R(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3,T(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N
M<&AP.C$S-`IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*
M;7-G<W1R(")&96IL86=T:6<@:&%N9&QI;F=S:V]D92!A;F=I=F5T+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@
M(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@
M(E5K;W)R96MT(&)R=6=E<FYA=FX@;V<O96QL97(@:V]D96]R9"XB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM<V=I9"`B(@HB26YC;W)R
M96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@
M9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)5:V]R<F5K="!B<G5G97)N879N
M(&5L;&5R(&%L=&5R;F%T:78@861R97-S92X@4'+X=B!I9V5N(&5L;&5R(&MO
M;G1A:W0@9&EN("(*(F%D;6EN:7-T<F%T;W(L(&AV:7,@9'4@:&%R(&)R=6<@
M9F]R('ED97)L:6=E<F4@:&KF;'`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT
M(@IM<V=S='(@(D9O<OAG(&EN9')Y:VYI;F<B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#D*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,38@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED
M("));F1I82(*;7-G<W1R("));F1I96XB"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C(U-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(U-`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I
M9'5A;"!5<V5R<R(*;7-G<W1R("));F1I=FED=65L;&4@8G)U9V5R92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R("));F1O;F5S:65N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I
M9"`B26YF;R(*;7-G<W1R("));F9O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M871I;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$Y"FUS
M9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R
M("));F9O<FUA=&EO;B!I:VME(&SF;F=E<F4@=&EL9^9N9V5L:6<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(DEN9'/F
M="!K;VQO;FYE(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"FUS9VED("));G-E<G0@26UA
M9V4B"FUS9W-T<B`B26YD<^9T(&)I;&QE9&4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B
M;&4B"FUS9W-T<B`B26YD<^9T('1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(DEN9'/F="!W96(M:&5N=FES;FEN9R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-`IM
M<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM<V=S='(@(DEN9'/F="!K
M;VQO;FYE(&;X<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M
M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YD<^9T(&5N(&YY
M(&MO;&]N;F4@969T97(@9&5N(&%K='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS
M9W-T<B`B26YD<^9T(&5N(&YY(&MO;&]N;F4@9OAR(&1E;B!A:W1U96QL92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV,@IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R
M<F5N="!O;F4B"FUS9W-T<B`B26YD<^9T(&5N(&YY('+F:VME(&5F=&5R(&1E
M;B!A:W1U96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B
M969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9'/F="!E;B!N>2!R
MYFMK92!F^'(@9&5N(&%K='5E;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C<P"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("))
M;F1SYG0@96X@<&%R86=R868@969T97(@9&5T(&%K='5E;&QE('!U;FMT(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4B"FUS9W-T<B`B26YD<^9T(&5N('!A<F%G<F%F(&;X<B!D
M970@86MT=65L;&4@<'5N:W0B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U
M,`IM<V=I9"`B26YS97)T(&%L=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("))
M;F1SYG0@86QT97)N871I=B!S:V%B96QO;B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O
M('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G
M<W1R("));F1T87-T(&5N(&4M;6%I;"UA9')E<W-E+"!H=F]R=&EL(&1U(&MA
M;B!M;V1T86=E(&1E="!N>64@:V]D96]R9#HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));F1SYG0@8V5L;&4@969T97(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T<B`B26YD<^9T
M(&-E;&QE(&;X<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@869T97(B
M"FUS9W-T<B`B26YD<^9T(&MO;&]N;F4@969T97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED("))
M;G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("));F1SYG0@:V]L;VYN92!F
M^'(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HU,"!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3`*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDP"FUS9VED("));G-E<G0@;65S<V%G
M97,B"FUS9W-T<B`B26YD<^9T(&)E<VME9&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0U"FUS9VED("))
M;G-E<G0@<&%R86=R87!H(&%F=&5R(@IM<V=S='(@(DEN9'/F="!P87)A9W)A
M9B!E9G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O
M<F4B"FUS9W-T<B`B26YD<^9T('!A<F%G<F%F(&5F=&5R(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));F1SYG0@<N9K:V4@969T
M97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8X"FUS9VED("));G-E<G0@<F]W(&)E9F]R92(*;7-G<W1R("))
M;F1SYG0@<N9K:V4@9OAR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("));F1T87-T(&1E="!K<N9V961E
M('-V87(@=&EL('-I:VME<FAE9'-S</AR9W-MY6QE=#HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(DEN9'/F="_F;F1R92!B:6QL961E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DEN9'/F="_F
M;F1R92!H96YV:7-N:6YG(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8T,PIM<V=I9"`B26YS=69F:6-I96YT(&-R961I="!T;R!S
M96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B571I;'-T
M<N9K:V5L:6<@:W)E9&ET('1I;"!A="!S96YD92!T:6P@9&ES=')I8G5T:6]N
M<VQI<W1E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S-0HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET+B(*;7-G<W1R(")5
M=&EL<W1RYFMK96QI9V4@:W)E9&ET+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN
M=&5G97(B"FUS9W-T<B`B2&5L=&%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3$S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT
M96=E<B!L:7-T(@IM<V=S='(@(DAE;'1A;'-L:7-T92(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PHC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-PIM<V=I9"`B26YV86QI
M9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B56=Y;&1I9R!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ-C<*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]Z:7`N<&AP.C(Q,B!L:6(O2&]R9&4O0V]M<')E<W,O>FEP+G!H
M<#HQ-C<*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT(&QI8B](
M;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI9"!:25`@
M9&%T82(*;7-G<W1R(")59WEL9&EG92!:25`M9&%T82(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN
M(@IM<V=S='(@(E5G>6QD:6=T(&%P<&QI:V%T:6]N+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI
M9"!B871C:"!)1"XB"FUS9W-T<B`B56=Y;&1I9W0@<VMR:7!T+4E$+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.#<@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C,R
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R.3D*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`X-PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U."!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(S,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(Y.0HC.B!L:6(O
M2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I9"`B26YV86QI
M9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B56=Y;&1I9V4@9&%T82!A9G-E
M;F1T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,`IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G
M<W1R(")59WEL9&EG(&1E<W1I;F%T:6]N+B(*"B,Z(&9R86UE=V]R:R]#;VUP
M<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+V1B>"YP:'`Z,C0Q(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N
M<&AP.C$P.0HC.B!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HQ,SD@;&EB
M+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I
M;&4@9F]R;6%T(@IM<V=S='(@(E5G>6QD:6=T(&9I;&9O<FUA="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DEN=F%L:60@
M;&EC96YS92!K97DN(@IM<V=S='(@(E5G>6QD:6<@;&EC96YS;OAG;&4N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B56=Y;&1I9R!P;&%C
M97)I;F<@86YG:79E="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#<*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#<*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S
M='(@(E5G>6QD:6<@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I
M;F<@87!I7VED+B(*;7-G<W1R(")59WEL9&EG(&5L;&5R(&UA;F=L96X@87!I
M7VED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM
M<V=S='(@(E5G>6QD:6=E(&5L;&5R(&UA;F=L96YD92!P87)A;65T<F4N(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED
M('!A<F5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")59WEL9&EG92!F;W+F;&1R
M92UT:6QL861E;'-E<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(E5G
M>6QD:6<@<&%R=&YE<BUI9"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,38S"FUS9VED("));G9A;&ED('!R;V1U8W0@8V]D92XB"FUS9W-T
M<B`B56=Y;&1I9R!P<F]D=6MT+6MO9&4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O
M8V]L+B(*;7-G<W1R(")59WEL9&EG('!R;W1O:V]L+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M97=O<FLO3F5T
M7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HY,R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z-S$*
M(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C@P"B,L('!H<"UF;W)M870*
M;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B56=Y
M;&1I9R!M;V1T86=E<CH@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,#@P(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(V,PHC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P.#`@;&EB+TAO<F1E+TMO;&%B+G!H
M<#HQ,C8S"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(")5
M9WEL9&EG="!D96QI;F=S;V)J96MT(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`Q"FUS9VED("));G9A;&ED('-O=7)C92!A
M9&1R97-S+B(*;7-G<W1R(")59WEL9&EG(&]P<FEN9&5L<V5S861R97-S92XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,3$*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3$*
M;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")59WEL9&EG
M('5N:6-O9&4M9&%T82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S4Y"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YD8F\B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<X"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R
M="!S96QE8W1I;VXB"FUS9W-T<B`B26YV97)TZ7(@;6%R:V5R:6YG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,@IM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G
M<W1R("))<F%N+"!$96X@:7-L86UI<VL@<F5P=6)L:6LB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q
M"FUS9VED("))<F%Q(@IM<V=S='(@(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED
M("))<F5L86YD(@IM<V=S='(@(DER;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3$U(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G
M:60@(DES;&4@;V8@36%N(@IM<V=S='(@(DUA;B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4
M+5-T;W)M<R(*;7-G<W1R(")3=&5D=FES('1O<F1E;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8R-@IM<V=I9"`B27-S=65R(@IM<V=S='(@(E5D<W1E9&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS
M9VED("))=&%L:6,B"FUS9W-T<B`B271A;&EE;G-K(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B271A;'DB"FUS9W-T<B`B271A;&EE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G
M:60@(DIA;6%I8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`R(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV-0IM<V=I9"`B2F%N=6%R>2(*;7-G<W1R(")*86YU
M87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@S"FUS9VED(")*87!A;B(*;7-G<W1R(")*87!A;B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&%N<VL@*$E33RTR,#(R+4I0*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R(")*97)S97DB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(T(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`B2F]R9&5N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*=6QY(@IM
M<V=S='(@(DIU;&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT-#4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0U
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S`*
M;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I
M9GDB"FUS9W-T<B`B2G5S=.ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,34*;7-G:60@(DIU<W1I9GD@0V5N
M=&5R(@IM<V=S='(@(D-E;G1RZ7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(DQI9V4@;6%R9V5N97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S
M=&EF>2!,969T(@IM<V=S='(@(E9E;G-T<F5J=7-T97)E="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS
M9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(DCX:G)E:G5S=&5R970B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@V"FUS9VED(")+87IA:VAS=&%N(@IM<V=S='(@(DMA<V%K:'-T
M86XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C8U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-C4*
M;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(D)E=F%R(&]R:6=I;F%L
M/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;GEA(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-2!L:6(O2&]R9&4O
M075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<R!S97)V97(@
M869V:7-T92!G;V1K96YD96QS92!A9B!I9&5N=&ET970N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G
M<W1R(")+97)N92T\96T^3F5W8FEE<SPO96T^(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q,0IM<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D[X9VQE+7-K86)E
M;'-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$T(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R
M:6YT(@IM<V=S='(@(D[X9VQE+69I;F=E<F%F=')Y:R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B3OAG;&5LYFYG
M9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@5'EP92(*;7-G
M<W1R(").^&=L971Y<&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y.0IM<V=I
M9"`B2V5Y(%5S86=E(@IM<V=S='(@(D[X9VQE86YV96YD96QS92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,"!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O;B!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B3OAG;&4@96MS:7-T97)E
M<B!A;&QE<F5D92!PY2!D96X@;V9F96YT;&EG92!N^&=L97-E<G9E<BXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T
M<B`B0OAR;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(DMI<FEB871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B4WED:V]R96$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B
M3F]R9&MO<F5A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@
M(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")K;W)E86YS:R`H155#+4M2*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S0@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(DMI<F=I<VES
M=&%N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),
M85]Y;W5T(@IM<V=S='(@(E5D9F]R;6YI;F<B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")3<')O
M9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#<*;7-G:60@(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(@IM<V=S='(@(DQA;W,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38Y"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B4VED<W1E(&AA;'9D
M96PB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.#@*;7-G:60@(DQA<W0@
M4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E-I9'-T92!K;V1E;W)D<^9N9')I
M;F<B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B4VED<W1E(&MV
M87)T86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.`IM<V=I9"`B3&%S
M="!5<&1A=&5D.B(*;7-G<W1R(")3:61S="!O<&1A=&5R970Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$W(&QI8B](;W)D92]!=71H+G!H<#HW
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T
M<B`B4VED<W1E(&QO9VEN.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.C<Q.2!L:6(O2&]R9&4O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*
M;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T<B`B4VED<W1E
M(&EN9&QO9VYI;F<Z("5S(&9R82`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.C<Q-"!L:6(O2&]R9&4O075T:"YP:'`Z-S$T"FUS9VED("),87-T
M(&QO9VEN.B!.979E<B(*;7-G<W1R(")3:61S=&4@;&]G:6XZ($%L9')I9R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$T-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(W
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#8@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),971L86YD(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T
M<B`B3&]V(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C,Y"FUS9VED("),87EO=70B"FUS9W-T<B`B3&%Y;W5T(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM
M<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(")4;VT@
M=F5D(&EN9V5N(')A;6UE<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M,S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB
M"FUS9W-T<B`B3&EB86YO;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-CD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,`IM<V=I9"`B3&5F="(*;7-G<W1R(")6
M96YS=')E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S$P,0IM<V=I9"`B3&5F="!H96%D97(B"FUS9W-T
M<B`B5F5N<W1R92!T;W!T96MS="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,P.3<@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3<*;7-G:60@(DQE9G0@
M=F%L=65S(@IM<V=S='(@(E9E;G-T<F4@=N9R9&EE<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B3&5S;W1O(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED("),979E;"(*;7-G<W1R(").
M:79E874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30R(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI
M8F5R:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB>6%N($%R86(@2F%M86AI
M<FEY82(*;7-G<W1R("),:6)Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,30P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:65C
M:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E:6XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B3&EG:'0@
M1')I>GIL92(*;7-G<W1R(")3=/AV<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM
M<V=S='(@(DQE="!R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R;'DB"FUS9W-T
M<B`B3&5T(')E9VX@=&ED;&EG="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED("),:6=H="!286EN($QA=&4B"FUS
M9W-T<B`B3&5T(')E9VX@<V5N="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*
M;7-G<W1R("),970@8GEG92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E
M<B(*;7-G<W1R("),970@8GEG92!M960@=&]R9&5N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N
M;W<B"FUS9W-T<B`B3&5T('-N92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*
M;7-G<W1R("),970@<VYE(&)Y9V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(E9I='1I9VAE9"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X,30*;7-G:60@(DQI;FLB"FUS9W-T<B`B2&5N=FES;FEN9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-PIM<V=I9"`B3&EN:R!P;VEN=',@=&\Z(@IM<V=S='(@(D9O<F)I;F0@
M<'5N:W1E<B!T:6PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B3&EN:R!T:&4@96UA
M:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN
M9R(*;7-G<W1R(")&;W)B:6YD(&4M;6%I;"UA9')E<W-E;B!M960@:6YD<VMR
M:79N:6YG<W-I9&5N('9E9"!F<F5M=FES;FEN9R(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@R"FUS9VED("),:6YK
M<R(*;7-G<W1R(")(96YV:7-N:6YG97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"UK
M:6MS(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.#8*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0V"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@
M8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1E("T@8G)U9V5R(&MA
M;B!S92!M87!P96XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,T"FUS9VED
M("),:7-T($1A=&%B87-E<R(*;7-G<W1R("),:7-T(&1A=&%B87-E<B(*"B,Z
M('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4Q"FUS9VED("),:7-T($AE;'`@
M5&]P:6-S(@IM<V=S='(@(D]P;&ES=&YI;F<@868@:&KF;'!E96UN97(B"@HC
M.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),:7-T(%1A8FQE<R(*
M;7-G<W1R("),:7-T('1A8F5L;&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12](96%D97)S+G!H<#HU.30@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z
M-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&4M07)C:&EV
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3@Y(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP
M(@IM<V=S='(@(DQI<W0M2&5L<"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DV(&QI8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y
M-@IM<V=I9"`B3&ES="U)9"(*;7-G<W1R("),:7-T+4ED(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI
M<W0M3W=N97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP
M.C4Y,R!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI
M<W0M4&]S="(*;7-G<W1R("),:7-T+5!O<W0B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y,2!L:6(O2&]R9&4O34E-12](96%D97)S
M+G!H<#HU.3$*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M
M4W5B<V-R:6)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.3`@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W0M56YS=6)S8W)I8F4B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S(@IM<V=S='(@(DQI<W1N:6YG
M(&%F('-E<W-I;VYS(&9E:FQE9&4Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I
M;&5D.B`E<R(*;7-G<W1R("),:7-T;FEN9R!A9B!B<G5G97)E(&9E:FQE9&4Z
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS
M9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")6:7-N
M:6YG(&%F(&)R=6=E<F4@97(@<VSE970@9G)A+B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71T
M97)A='5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@
M(DQI=&%U96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I;6%G
M97,N<&AP.C<W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I;6%G97,N<&AP
M.C<W"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(DAE;G1E<BXN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*;7-G:60@(DQO8V%L
M('1I;64Z("(*;7-G<W1R("),;VMA;"!T:60Z(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B
M4F5G:6]N86QD871A(&]G('1I9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<R
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-S(@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C(R"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-PIM<V=I
M9"`B3&]C871I;VXB"FUS9W-T<B`B4W1E9"(*"B,Z(&QO9VEN+G!H<#HQ.#D@
M<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P,"!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.CDP"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34*;7-G:60@(DQO9R!I
M;B(*;7-G<W1R("),;V<@:6YD(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N
M(@IM<V=S='(@(DQO9R!A9B!T:61L:6=E<F4@<WEN:W)O;FES97)I;F=S<V5S
M<VEO;F5R(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y-`IM
M<V=I9"`B3&]G(&]U="(*;7-G<W1R("),;V<@=60B"@HC.B!L:6(O0FQO8VLO
M86-C;W5N="YP:'`Z-C$*;7-G:60@(DQO9VEN(@IM<V=S='(@(DQO9R!I;F0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$P"FUS9VED("),;V=I;B!4
M87-K<R(*;7-G<W1R("),;V=I;BUO<&=A=F5R(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z.3DU(&QI8B](;W)D92]!=71H+G!H<#HY.34*;7-G:60@
M(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O
M<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN(@IM<V=S='(@(B(*(DQO9R!I
M;F0@9F5J;&5D92!F;W)D:2!D:70@8G)U9V5R;F%V;B!E;&QE<B!K;V1E;W)D
M(&)L978@86YG:79E="!F;W)K97)T+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDY,2!L:6(O2&]R9&4O075T:"YP:'`Z.3DQ"FUS9VED("),;V=I
M;B!F86EL960N(@IM<V=S='(@(DQO9VEN9"!M:7-L>6MK961E<RXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B3&%N9R!T96MS="(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G
M<W1R(")+YG)L:6=H960B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0IM<V=I9"`B3&]W(@IM<V=S='(@(DQA=B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z
M,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B"FUS9W-T<B`B4VWE(&=R
MYG-K92!T96=N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R
M<R(*;7-G<W1R(")3;>4@;&%T:6YS:V4@=&5G;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3<*;7-G:60@
M(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`B4VWE(')O;65R=&%L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S0*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=7AE;6)O
M<F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,SD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,2!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L
M871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C4P"FUS9VED(")-32(*;7-G<W1R(")-32(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#,*;7-G:60@(DU/5$0B"FUS9W-T
M<B`B34]41"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N
M<&AP.C,V(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")-4RU43D5&+6)I;&%G(&EN9&AO;&1T(&EN9V5N(&1A=&$N(@H*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M;6]B:6QE+G!H<#HS-PHC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+VUO8FEL92YP:'`Z,S<*;7-G:60@(DU31R(*;7-G<W1R(")-4T<B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-0HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3$*;7-G:60@(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(*;7-G<W1R(")-86ME9&]N:65N+"!$96X@=&ED;&EG97)E
M(&IU9V]S;&%V:7-K92!R97!U8FQI:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA
M9&%G87-C87(B"FUS9W-T<B`B36%D86=A<VMA<B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G:6,B"FUS9W-T<B`B36%G:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G
M<W1R(")%+6UA:6PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T
M"FUS9VED(")-86EL($%D;6EN(@IM<V=S='(@(D4M;6%I;"UA9&UI;FES=')A
M=&]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D1A
M;B!H96YV:7-N:6YG+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,S@*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM
M<V=S='(@(DUA;&%W:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-R!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,Y"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA(@IM
M<V=S='(@(DUA;&%Y<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V
M-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B
M"FUS9W-T<B`B36%L9&EV97)N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB
M"FUS9W-T<B`B36%L:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,30R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B)(Y6YD=.ER(&QI
M<W1E;B!A9B!K871E9V]R:65R+"!S;VT@9'4@<VMA;"!M87)K97)E(&5M;F5R
M(&UE9"P@;V<@9F%R=F5R;F4L("(*(F1E<B!S:V%L(&MN>71T97,@=&EL(&1I
M<W-E(&MA=&5G;W)I97(N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$Q-38*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C$Q-38*;7-G:60@(DUA<#(T(&UA<"(*;7-G<W1R(")-87`R
M-"UK;W)T(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-S$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P.#<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-S$*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="UK;W)T
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,3`U"FUS9VED(")-
M87!P:6YG<R!S=&]R960N(@IM<V=S='(@(DMO<G1LYF=N:6YG(&=E;70N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#0@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T,@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8W"FUS9VED(")-87)C:"(*
M;7-G<W1R(")-87)T<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-
M87)G96XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HX.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<#HT
M."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#@*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K('=I=&@@
M4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R:^ER(&UE9"!3970O57-E
M="UF;&%G(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z.#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z
M-#D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C0Y"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B36%R:^ER(&UE9"!A;F1R92!F;&%G("AF>"!6:6=T:6<O0F5S=F%R970I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,34R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R
M(")-87)S:&%L;/AE<FYE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34Y(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-#0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN:7%U
M92(*;7-G<W1R(")-87)T:6YI<75E(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHQ,#,*;7-G:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")/
M=F5R96YS<&%S<V5N9&4@9F5L=&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-#4*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U
M<FET86YI82(*;7-G<W1R(")-875R:71A;FEE;B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G
M:60@(DUA=7)I=&EU<R(*;7-G<W1R(")-875R:71I=7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DUA>"!A
M;&QO=V5D(&-R961I="XB"FUS9W-T<B`B36%X('1I;&QA9'0@:W)E9&ET+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(DUA
M:W-I;75M(&)E<VME9"UD96QE(&]V97)S:W)E9&5T+B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B36%K<RX@=&5M<"X@<VED<W0@,C0@=&EM97(Z("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U"FUS9VED(")-87@@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R(")-86MS+B!T96UP+B!S:61S=&4@-B!T:6UE
M<CH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G:60@(DUA>&EM=6T@3G5M8F5R
M(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B36%K<VEM=6T@86YT86P@868@
M<&]R=&%L8FQO:VME(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S.2!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DX(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C$W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R(")-86MS:6UU;6SF;F=D
M92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T
M-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y
M(@IM<V=S='(@(DUA:B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$T-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*
M;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P
M"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8VEN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ-@IM<V=I9"`B365M8F5R<R(*
M;7-G<W1R(")-961L96UM97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S@R"FUS9VED(")-96YU(&UO9&4Z(@IM<V=S='(@(DUE;G4M=&EL<W1A;F0Z
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B1F]RZ6X@8V5L
M;&5R(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(D)E<VME
M9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$V(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E
M(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I
M9FEC871E(&-O=6QD(&YO="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB
M0F5S:V5D('-U8V-E<V9U;&1T('9E<FEF:6-E<F5T(&UE9"!U;F1E<G-K<FEV
M97)E;G,@8V5R=&EF:6MA="!K=6YN92!I:VME("(*(G9E<FEF:6-E<F5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM
M<V=I9"`B365S<V%G92!E>'!I<F5D+B(*;7-G<W1R(")"97-K960@=61L^&)E
M="XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P
M,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R-R!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM<V=I9"`B365S<V%G
M92!T>7!E(@IM<V=S='(@(D)E<VME9'1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H97(B"FUS9W-T<B`B365T87(@
M5V5A=&AE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*;7-G:60@(DUE
M=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DUE=&%R8FQO:R!I
M:VME('1I;&?F;F=E;&EG+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$Y
M"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G
M<W1R("(B"B)-971A<F)L;VL@:6MK92!T:6QGYFYG96QI9RX@1&5T86QJ97(@
M97(@8FQE=F5T(&YO=&5R970@=&EL(&)R=6<@9F]R("(*(F%D;6EN:7-T<F%T
M;W)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S"FUS
M9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE=&%R
M1$(@97(@:6MK92!F;W)B=6YD970N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-
M971H;V0B"FUS9W-T<B`B365T;V1E(@H*(SH@9G)A;65W;W)K+U)00R]24$,O
M<V]A<"YP:'`Z,3$W(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$*
M(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C@Q(&QI8B](;W)D92]24$,O
M<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!<(B5S
M7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B365T;V1E(%PB)7-<(B!E<B!I
M:VME(&1E9FEN97)E="(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP
M.C@R(&QI8B](;W)D92]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*
M;7-G<W1R(")-971O9&4@:6MK92!D969I;F5D+B!-971O9&4@:V%L9'0Z("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX,B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z-C<*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Y6QE96YH
M960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B365X:6-O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T
M.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.#4@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8B"FUS9W-T<B`B36EK<F]N97-I96XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*;7-G:60@(DUI9&1L
M92(*;7-G<W1R(")-:61T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&YE9BYP:'`Z,S@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B34E-12UT>7!E(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HS,3<*;7-G:60@(DUI;B!T96UP(&QA<W0@
M,C0@:&]U<G,Z("(*;7-G<W1R(")-:6XN('1E;7`N('-I9'-T92`R-"!T:6UE
M<CH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(DUI;BX@=&5M<"X@<VED<W1E
M(#8@=&EM97(Z("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#,Y(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU
M;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-
M:6YI;75M(&MO9&5O<F1S86QD97(@97(@96YD;G4@:6MK92!U9'-TY65T(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,U"FUS9VED
M(")-:7)R;W(B"FUS9W-T<B`B4W!E:FQE(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE;W5S(@IM<V=S='(@(D9O<G-K
M96QL:6=T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-S(*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#`@;&EB
M+TYE="]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I9"`B36ES<VEN9R!014%2
M('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")-86YG;&5R(%!%05(M
M<&%K:V4@2%144%]297%U97-T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%T:6]N(&UA
M;F=L97(N($1U(&)L:79E<B!N^&1T('1I;"!A="!G96YE<F5R92!D96X@;G4L
M(&AV:7,@9'4@^&YS:V5R("(*(F%T(&)R=6=E(&1E;FYE(&%P<&QI:V%T:6]N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R(")-86YG;&5R
M(&)E<VME9"UI9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HU.`HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET
M86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I<F5D(%!%05(@
M<&%C:V%G92!-86EL+B(*;7-G<W1R(")-86YG;&5R(&MRYG9E="!014%2+7!A
M:VME($UA:6PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDT"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@
M(DUA;F=L97(@<V5S<VEO;BU)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")-86XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S8*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(DUO8FEL($4M<&]S="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")*YG9N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-S,*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`BQFYD
M<FEN9W-D871O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@
M(L9N9')E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C<T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-
M;V1U;'5S(@IM<V=S='(@(DUO9'5L=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ-3`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M;VQD;W9A+"!297!U8FQI8R!O9B(*;7-G<W1R(")-;VQD;W9A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$T.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@(DUO;F%C;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F=O;&EE;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.#0@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(U.#0*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(DWE;F5D(&]G
M(.5R(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HU-R!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT
M:&QY(@IM<V=S='(@(DWE;F5D;&EG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDT(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N
M='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H
M87-E<R(*;7-G<W1R(")-Y6YE9F%S97(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HQ.38@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C@P
M"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DV(&QI8B]&:6QE+T-35BYP:'`Z,C@P
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(D9L97)E(&9E
M;'1E<B!F=6YD970@:2!L:6YI92`E9"!E;F0@9&5T(&9O<G9E;G1E9&4@)60N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T."!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R(")-87)O:VMO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S,*
M;7-G:60@(DUO<W1L>2!#;&5A<B(*;7-G<W1R(")-97-T('-K>69R:70B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-`IM<V=I
M9"`B36]S=&QY($-L;W5D>2(*;7-G<W1R(")-97-T('-K>65T(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S4*;7-G:60@(DUO
M<W1L>2!#;&]U9'D@86YD(%=I;F1Y(@IM<V=S='(@(DUE<W0@<VMY970@;V<@
M8FSF<V5N9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS-@IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(DUE<W0@<V]L
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HV-#@@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3`Y"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E
M($1O=VXB"FUS9W-T<B`B1FQY="!N960B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U,B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HU,3,*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R(")&;'ET('1I
M;"!V96YS=')E(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HV-38@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z-3$W
M"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C4V"FUS
M9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(DUO9"!H^&IR92(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C0T(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C4P-0HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M(")&;'ET(&]P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C4R-@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1FQY="!N960B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(U"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-2!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E('5P
M(@IM<V=S='(@(D9L>70@;W`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$U-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,38X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I
M<75E(@IM<V=S='(@(DUO8V%M8FEQ=64B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3@T(&QI8B](;W)D92]&;W)M+G!H<#HR,3@T"FUS9VED(")-
M=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',B"FUS9W-T<B`B375L=&DM;FEV
M96%U(')U;&QE9V%R9&EN<VQI<W1E<B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,#4Y"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,#4Y"FUS9VED(")-=6QT:6UA<"!52R!M87`B
M"FUS9W-T<B`B375L=&EM87`@54L@:V]R="(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(R-#(@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#(*;7-G:60@
M(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")-=6QT:7!L92!V86QG(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,@IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R(")-:6X@:V]N=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z,C@*;7-G:60@(DUY($%C8V]U;G0@26YF;W)M871I;VXB"FUS9W-T
M<B`B36EN92!K;VYT;RUI;F9O<FUA=&EO;F5R(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HT-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DUI
M;B!0;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z-#(*;7-G
M:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B36EN(%!O<G1A;"UU9&9O
M<FUN:6YG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,34U(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")-
M>6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E
M+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R(").
M14HL(&IE9R!E<B!)2TM%(&5N:6<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,3`R(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE9BYP:'`Z,S@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(").86UE(@IM<V=S='(@(DYA
M=FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDU"FUS9VED(").86UI8FEA(@IM<V=S='(@(DYA;6EB
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R=2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<&%L(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3F5D97)L86YD
M96YE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3<*;7-G:60@(DYE=&AE<FQA;F1S($%N=&EL;&5S(@IM
M<V=S='(@(DAO;&QA;F1S:V4@06YT:6QL97(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@0F%S92!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-`IM<V=I
M9"`B3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DPB"FUS9W-T<B`B3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4X-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X
M-@IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R(").971S
M8V%P92!#02!P;VQI8WD@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*
M;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(DYE='-C87!E
M(%)E;F5W86P@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@
M(DYE='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(%)E
M=F]C871I;VX@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@
M(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R(").971S8V%P92!3
M4TP@<V5R=F5R(&YA;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4X."!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X.`IM<V=I
M9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(").971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.#$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.#$*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E('1Y<&4B"FUS9W-T
M<B`B3F5T<V-A<&4@8V5R=&EF:6-T92!T>7!E(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(U,PIM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").971V
MYG)K(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(U(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0R-0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S,Y(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G:60@(DYE
M=F5R(@IM<V=S='(@(D%L9')I9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#
M86QE9&]N:6$B"FUS9W-T<B`B3GD@2V%L961O;FEE;B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z(&QI8B](
M;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E
M<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@
M0V%T96=O<GDB"FUS9W-T<B`B3GD@:V%T96=O<FDB"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYY;>5N92(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@
M(DYE=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYY="!B<G5G97)N
M879N("AV86QG9G)I="DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@P
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R(").97<@6F5A;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYY
M="!K;V1E;W)D(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R
M-R!L:6(O2&]R9&4O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@
M(DYY="!K;V1E;W)D('9I;"!U9&SX8F4@9&5N("5X+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W;W)D<R!D
M;VXG="!M871C:"XB"FUS9W-T<B`B3GEE(&MO9&5O<F0@97(@:6MK92!E;G,N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,0IM<V=I9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").>70@=FEN
M9'5E("A?8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R(&QI
M8B]";&]C:R]G;V]G;&4N<&AP.C0P"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B3GEH961E<B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#<*;7-G:60@(DYE=W-G<F]U<',B
M"FUS9W-T<B`B3GEH961S9W)U<'!E<B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C(U('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y"B,Z
M('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C$U"FUS9VED(").97AT(@IM<V=S='(@(D[F<W1E(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(D[F<W1E(#0@9F%S97(B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP
M.C,W,`HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V-B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@
M(D[F<W1E('1I;'9A;&<B"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C$P,R!L:6(O2&]R9&4O54DO4&%G97(N<&AP.C$P,PIM<V=I9"`B3F5X=#XB
M"FUS9W-T<B`B3N9S=&4^(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A
M(@IM<V=S='(@(DYI8V%R86=U82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R
M(@IM<V=S='(@(DYI9V5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C8*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W
M,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*
M;7-G<W1R(").:6=E<FEA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F%T(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3FEU92(*;7-G<W1R(").:75E(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"FUS9VED(").;R(*;7-G<W1R(").
M96HB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G
M:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(DEN9V5N('1I;&?F;F=E;&EG92!K
M;VYF:6=U<F%T:6]N9&%T82!A="!V:7-E(&9O<G-K96QL92!F;W(N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HQ,#8@;&EB
M+U9&4R])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B26YG96X@
M=&EL9^9N9V5L:6<@<W1R871E9VD@=&EL(&%T(&QA=F4@25-/+6)I;&QE9&5R
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q
M,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(DEN9V5N('-K
M<FEP="US:V%B96QO;BXB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C$P,0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C,X-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C0P-R!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HW.0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HR-#4@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C8W"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z-#`W"FUS9VED(").;R!B;&]C:R!E>&ES=',@
M870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*;7-G<W1R(")$97(@96MS:7-T
M97)E<B!I:VME(&YO9V5N(&)L;VL@<.4@9&5N(&9O<F5S<'5R9W1E('!O<VET
M:6]N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,"!L:6(O
M2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M26YG96X@:V%L96YD97(@86YG:79E="!T:6P@34-!3"WF9W1N:6YG+B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM
M<V=S='(@(DEN9V5N(.9N9')I;F<N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+U5)+G!H<#HQ-38@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-38*;7-G
M:60@(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I
M;VXN(@IM<V=S='(@(D1E<B!K86X@:6MK92!T:6QF^&IE<R!B^')N('1I;"!D
M96YN92!T:6QL861E;'-E+B(*"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP
M.C<V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W.`HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C4Q-R!L:6(O2&]R9&4N<&AP.C$W."!L:6(O
M2&]R9&4N<&AP.C4Q-PHC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S8X"B,L('!H
M<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A=&EO
M;BUI;F9O<FUA=&EO;B!A;F=I=F5T(&9O<B`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@U-2!L:6(O5D93+V9T<"YP:'`Z.#4U"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A=&EO;BUI;F9O<FUA
M=&EO;B!A;F=I=F5T(&9O<B!&5%`@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;"YP:'`Z-C<R(&QI8B]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@
M5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N
M(&%N9VEV970@9F]R(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C<R-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HW,C4*;7-G
M:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R871I;VXM
M:6YF;W)M871I;VX@86YG:79E="!F;W(@4U%,+49I;&4@5D93+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I="!U9'3X;70N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DEN=&5T(&)E<W1E
M;6UE;'-E<W-T960@86YG:79E="XB"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"
M<F]W<V5R+G!H<#HY,C`@;&EB+TAO<F1E+T)R;W=S97(N<&AP.CDR,`IM<V=I
M9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("));F=E;B!F:6P@<V5N9'0B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R(")&86YD="!I;F=E;B!I:V]N97(N(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HQ,S`@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,38*;7-G:60@(DYO
M(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B26YT970@<W1E9"!I;F1S=&EL
M;&5T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G
M:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("));G1E="!S=&5D
M(&%N9VEV970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B
M26YG96X@8F5S:V5D(&%N9VEV970N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C:69I960N
M(@IM<V=S='(@(DEN=&5T(&YA=FX@86YG:79E="XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@
M<W!E8VEF:65D+B(*;7-G<W1R("));G1E="!N=6UM97(@86YG:79E="XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R("));F=E;B!A;G-T^&1E;&EG92!E<&EG<F%M
M;65R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HY,2!L:6(O
M2&]R9&4O075T:"]H='1P+G!H<#HY,0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN=&5T
M(&MO9&5O<F0@86YG:79E="!T:6P@8G)U9R!F;W(@2%144"WF9W1N:6YG+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X(&QI8B](;W)D
M92]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN=&5T(&MO
M9&5O<F0@86YG:79E="!T:6P@8G)U9R!F;W(@24U!4"WF9W1N:6YG+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YT970@:V]D
M96]R9"!A;F=I=F5T('1I;"!B<G5G(&9O<B!+97)B97)O<RWF9W1N:6YG+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T(&9R86UE=V]R
M:R]!=71H+T%U=&@O<&%M+G!H<#HW-0HC.B!F<F%M97=O<FLO075T:"]!=71H
M+W-A<VPN<&AP.C<W(&QI8B](;W)D92]!=71H+VQO9VEN+G!H<#HX-`HC.B!L
M:6(O2&]R9&4O075T:"]P86TN<&AP.C<U(&QI8B](;W)D92]!=71H+W-A<VPN
M<&AP.C<W"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN=&5T(&MO9&5O<F0@86YG:79E
M="!F;W(@3&]G:6YD+>9G=&YI;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]P87-S=V0N<&AP.C$S-2!L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP.C$S
M-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B26YT970@:V]D96]R9"!A;F=I=F5T="!T
M:6P@4$%34U=$+>9G=&YI;F<N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S
M;6(N<&AP.C@T(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DEN=&5T(&MO9&5O<F0@86YG:79E="!F;W(@4TU"+>9G=&YI;F<N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@W(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(X-PIM<V=I9"`B(@HB3F\@<&%T
M:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,
M(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82XB"FUS9W-T<B`B(@HB4W1I('1I;"!/<&5N4U-,+6)I8FQI;W1E:V5T
M(&UA;F=L97(N("!/<&5N4U-,+6)I8FQI;W1E:V5T(&5R(&[X9'9E;F1I9W0@
M9F]R("(*(F%T(&CE;F1T97)E(%!+0U,Q,BUD871A+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@(DYO('!E;F1I;F<@
M<VEG;G5P<RXB"FUS9W-T<B`B26YG96X@=F5N=&5N9&4@;W!S:W)I=FYI;F=E
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-S8V(&QI8B]61E,N<&AP
M.C<V-@IM<V=I9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(")+=F]T92!I:VME
M(&EN9'-T:6QL970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B
M26YG96X@<W1R96=E<B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP
M.C0X,B!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P87)A=&]R
M('-P96-I9FEE9"XB"FUS9W-T<B`B26YG96X@<VMI;&QE=&5G;B!A;F=I=F5T
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DEN9V5N('-I9&5R
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#<@;&EB+U9&4R]S
M;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(DEN9V5N
M('/E9&%N(&9I;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,C8*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`B1&5R(&UA;F=L97(@970@;6ED;&5R=&ED:6=T
M(&MA=&%L;V<@=&EL(&UE;&QE;6QA9V5R+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV,S$*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(R,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M(@IM<V=S='(@(DEN=&5T(&)R=6=E<FYA=FX@;V<O96QL97(@:V]D96]R9"!S
M96YD="XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T,"!L
M:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI9"!8
M34P@9&%T82!R971U<FYE9"(*;7-G<W1R("));F=E;B!G>6QD:6=E(%A-3"UD
M871A(')E='5R;F5R970B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3<T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDY-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3`Q,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY
M.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM<V=I
M9"`B3F\@=F%L=65S(@IM<V=S='(@(DEN9V5N(';F<F1I97(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD
M(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB3W)I9VEN86P@:V]N9FEG=7)A=&EO;B!M
M86YG;&5R('9E<G-I;VYS;G5M;65R+B!296=E;F5RZ7(@:V]N9FEG=7)A=&EO
M;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")$:6X@:V]N9FEG=7)A=&EO;B!M
M86YG;&5R('9E<G-I;VYS;G5M;65R+B!296=E;F5RZ7(@:V]N9FEG=7)A=&EO
M;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E<R]P<F5F<R]I
M9&5N=&ET>7-E;&5C="YI;F,Z.3,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0IM<V=I9"`B3F]N92(*;7-G<W1R
M("));F=E;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3`*;7-G:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B
M26YG96X@*&)R=6<@:6UP;&EC:70I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3(*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(DYO
M<F1I<VL@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYO<F9O
M;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&LB"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,S(@;&EB+T)L;V-K+VUO;VXN<&AP.C8P"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(DYO<F1L:6=E(&AA;'9K=6=L92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N($UA<FEA;F$@27-L86YD<R(*;7-G
M<W1R(").;W)D;&EG92!-87)I86YA^&5R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B
M3F]R=V%Y(@IM<V=S='(@(DYO<F=E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#$@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M-#$*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")):VME('-E;F5R92!E;F0B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,"!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I9"`B3F]T($)E9F]R92(*
M;7-G<W1R(")):VME(&;X<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C0Q-2!L:6(O5D93+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER
M96-T;W)Y(@IM<V=S='(@(DEK:V4@;F]G970@:V%T86QO9R(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T
M4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L
M:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.34*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU
M.0IM<V=I9"`B3F]T(&EM<&QE;65N=&5D+B(*;7-G<W1R(")):VME(&EM<&QE
M;65N=&5R970N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")):VME(&EN9'-T
M:6QL970B"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,3DS(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S
M-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HR-CD@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(X-0HC.B!F<F%M
M97=O<FLO5D93+U9&4RYP:'`Z,S`Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HS
M,38*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C,S,R!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,S8V"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HT,C8@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C4P-0HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z-3<T(&9R86UE=V]R:R]61E,O5D93+G!H<#HU.3$*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C8V.2!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M
M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!L
M:6(O5D93+G!H<#HQ.3,*(SH@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP
M.C(S-"!L:6(O5D93+G!H<#HR-3(@;&EB+U9&4RYP:'`Z,C8Y"B,Z(&QI8B]6
M1E,N<&AP.C(X-2!L:6(O5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V(&QI
M8B]61E,N<&AP.C,S,PHC.B!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z
M-#(V(&QI8B]61E,N<&AP.C4P-2!L:6(O5D93+G!H<#HU-S0*(SH@;&EB+U9&
M4RYP:'`Z-3DQ(&QI8B]61E,N<&AP.C8V.2!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T-0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$V,"!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X.2!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B26MK92!U;F1E<G-T^'1T970N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(T-"!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP.`HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.CDP."!L:6(O2&]R9&4O
M34E-12]6:65W97(O=F-A<F0N<&AP.C(T-`HC.B!C;VYF:6<O:&]O:W,N<&AP
M+F1I<W0Z,3`U."!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@P"FUS9VED
M(").;W1E<R(*;7-G<W1R(").;W1E<B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R
M+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A
M8VLN(@IM<V=S='(@(DEN=&5T(&%T(&)R;W=S92P@=F5N9"!T:6QB86=E+B(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$R(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB
M97(B"FUS9W-T<B`B3F]V96UB97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#0V(&QI8B](;W)D92]&;W)M+G!H<#HQ,#0V"FUS9VED(").=6UB
M97(B"FUS9W-T<B`B5&%L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R-0IM<V=I9"`B3G5M8F5R(&]F
M(&-H87)A8W1E<G,B"FUS9W-T<B`B06YT86P@=&5G;B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S8Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(S(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#0U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN
M<R(*;7-G<W1R(")!;G1A;"!K;VQO;FYE<B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$S-C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0S(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S8W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(Q(&QI8B](;W)D
M92]&;W)M+G!H<#HQ-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@;V8@<F]W<R(*;7-G<W1R
M(")!;G1A;"!RYFMK97(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")486P@
M:6MK92!A;F=I=F5T(&9O<B!O<&1A=&5R:6YG(&D@9&ES=')I8G5T:6]N<VQI
M<W1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@(D]B:F5C="(*;7-G<W1R
M(")/8FIE:W0B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,0IM
M<V=I9"`B3V)J96-T($-R96%T;W(B"FUS9W-T<B`B3V)J96MT9&%N;F5R(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$P-`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMT86PB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#D*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B3VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B06YS=/AD96YD92!F:6QT
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/
M9F9I8V4B"FUS9W-T<B`B2V]N=&]R(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE=R!P87-S=V]R9',@;75S
M="!B92!D:69F97)E;G0N(@IM<V=S='(@(D=A;6UE;'0@;V<@;GET(&MO9&5O
M<F0@<VMA;"!VYG)E(&9O<G-K96QL:6=E+B(*"B,Z('-E<G9I8V5S+V-H86YG
M97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@
M(D=A;6UE;'0@:V]D96]R9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HT-@IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*
M;7-G<W1R(")'86UM96QT(&MO9&5O<F0@97(@:6MK92!K;W)R96MT+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#$@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3@*;7-G:60@(D]M86XB"FUS9W-T<B`B3VUA;B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S(&QI8B](;W)D92])
M34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I9"`B3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB"FUS9W-T<B`B1&5L=&4@;6%P
M<&5R('5N9&5R<W3X='1E<R!K=6X@868@24U!4"US97)V97)E+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B2W5N(&%N<W3X9&5L:6=E(&5P:6=R86UM97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Y-S$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3$@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL
M(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B2W5N(.EN(&4M<&]S="UA9')E
M<W-E('1I;&QA9'0N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C8U
M"FUS9VED("(B"B)/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R
M871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B`B"B)P97)M:7-S
M:6]N<R!F;W(@82!S:&%R92(*;7-G<W1R("(B"B)%;B!D96QI;F=S(&5J97)S
M:V%B(&]G(&5J97)T:6QL861E;'-E<B!MY2!K=6X@YFYD<F4@868@96X@(@HB
M<WES=&5M861M:6YI<W1R871O<B!E;&QE<B!E:F5R96X@<V5L=B(*"B,Z(&QI
M8B]";&]C:R]I9G)A;64N<&AP.C0Q(&QI8B]";&]C:R]I9G)A;64N<&AP.C0R
M"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("+%8F5N(&D@
M970@;GET('9I;F1U92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C0U(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED
M(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@
M<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R(")/<&5N4U-,+69E:FPZ($1A
M=&$@:W5N;F4@:6MK92!U9&1R86=E<R!F<F$@<VEG;F5R970@4R]-24U%+61E
M;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`BQ6)E;B!D96YN92!H96YV:7-N:6YG(&D@970@;GET
M('9I;F1U92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R871I=G-Y<W1E;2(*"B,Z
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-3$*;7-G:60@(D]P=&EO
M;G,B"FUS9W-T<B`B26YD<W1I;&QI;F=E<B(*"B,Z('-E<G9I8V5S+W!R969S
M+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("));F1S=&EL;&EN
M9V5R(&9O<B`E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R(")/<F1N
M970@;&ES=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4V."!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G
M86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A=&EO;B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38Y(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S
M='(@(D]R9V%N:7-A=&]R:7-K(&5N:&5D(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$S-`IM<V=I9"`B3W)G86YI>FEN9R(*;7-G<W1R(")/<F=A
M;FES97)I;F<B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$S-0IM<V=I9"`B
M3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4B"FUS9W-T<B`B3W!R:6YD
M96QI9R!A<'!L:6MA=&EO;G-S:V%B96QO;B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B3W!R:6YD96QI9V4@<VMA8F5L;VYE<B!I
M("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ,3<@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B06YD96XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*
M;7-G<W1R(")!;F1E;B!I;F9O<FUA=&EO;B(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(D5J97)R971T:6=H961E<B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%M+G!H<#HW.2!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y"FUS9VED(")0
M04T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M4$%-+>9G=&YI;F<@97(@:6MK92!T:6QGYFYG96QI9V4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U(&QI8B].970O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B4$5!4CHZ36%I;"UM;W1O<B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C$R-S8@;&EB+TAO<F1E+T-R>7!T+W!G
M<"YP:'`Z,3(W-@IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(E!'4"!D:6=I=&%L('-I9VYA='5R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,R,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ
M,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B4$=0+6MR
M>7!T97)E="!D871A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3,W-"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S<T"FUS9VED(")0
M1U`@4'5B;&EC($ME>2(*;7-G<W1R(")/9F9E;G1L:6<@4$=0+6[X9VQE(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,U-B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(E!'4"US:6=N97)E="]K<GEP=&5R970@9&%T
M82(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.0IM<V=I9"`B4$A0($-O9&4B
M"FUS9W-T<B`B4$A0+6MO9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*
M;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`M<VMA;"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!,
M:6=H="!286EN(@IM<V=S='(@(D5F=&TN(&QE="!R96=N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,SD*;7-G:60@(E!-(%)A
M:6XB"FUS9W-T<B`B169T;2X@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED(")032!3:&]W97)S(@IM<V=S
M='(@(D5F=&TN(&)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#$*;7-G:60@(E!-(%-N;W<B"FUS9W-T<B`B169T;2X@
M<VYE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")%9G1M+B!S;F5B
M>6=E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0S"FUS9VED(")032!3=6XB"FUS9W-T<B`B169T;2X@<V]L(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E!-
M(%0M4W1O<FUS(@IM<V=S='(@(D5F="X@=&]R9&5N(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(X-@IM<V=I9"`B4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<B"FUS9W-T<B`B4$]325@M=61V:61D96QS92!M86YG;&5R(@H*(SH@
M;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H96QL(@IM<V=S='(@(E!(
M4"US:V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT-@IM<V=I9"`B4&%D9&EN9R(*;7-G<W1R(")&;W)R:6YG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-S(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T
M86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S,*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&%U(@IM<V=S='(@(E!A;&%U
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D(@IM<V=S='(@(E!A;.9S=&EN82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ.#(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G
M:60@(E!A;F%M82(*;7-G<W1R(")086YA;6$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A($YY($=U:6YE82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4&%R86=U87DB"FUS9W-T<B`B4&%R86=U
M87DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M-PIM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R(")$96QV:7-T('-K>65T
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU,S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3DY"B,Z(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,3@*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,C4*;7-G
M:60@(E!A<W-W;W)D(@IM<V=S='(@(DMO9&5O<F0B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")+;V1E;W)D(.9N9')E="XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HQ,S(S"FUS9VED(")087-S=V]R9"!I;F-O<G)E
M8W0B"FUS9W-T<B`B2V]D96]R9"!F;W)K97)T(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]R861I=7,N<&AP.C$U,B!L:6(O2&]R9&4O075T:"]R861I=7,N
M<&AP.C$U,@IM<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V]D96]R9"!K<N9V970@=F5D(%)!
M1$E54RWF9W1N:6YG+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M-3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-3,*;7-G:60@(E!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DMO9&5O<F0@;65D(&)E:W+F9G1E
M;'-E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED
M(")087-S=V]R9#HB"FUS9W-T<B`B2V]D96]R9#HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")+;V1E;W)D.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`S-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S-`HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")0
M87-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`B2V]D96]R9&5N92!S:V%L
M(';F<F4@96YS+B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C`@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS
M9VED(")087-T92(*;7-G<W1R("));F1SYG0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W"FUS9VED(")087-T92!F<F]M
M(&-L:7!B;V%R9"(*;7-G<W1R("));F1SYG0@9G)A('5D:VQI<'-H;VQD97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Q
M"FUS9VED(")0871H(@IM<V=S='(@(E-T:2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S
M='(@(E9E;G1E;F1E(&]P<VMR:79N:6YG97(Z(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B1F]L:R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS
M9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B"@HC.B!T96UP;&%T97,O
M;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R
M;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@(E5D9OAR('9E9&QI
M9V5H;VQD96QS92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,3`*;7-G
M:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B
M"FUS9W-T<B`B561F^'(@=F5D;&EG96AO;&1E;'-E('9E9"!L;V<@:6YD/R(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V(&QI8B](;W)D
M92]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@
M(E1I;&QA9&5L<V5R(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L
M971E9"XB"FUS9W-T<B`B5&EL;&%D96QS92!<(B5S7"(@:6MK92!S;&5T=&5T
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3DP(&QI8B]61E,O
M<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@
M(E1I;&QA9&5L<V4@;N9G=&5T(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-C$@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HQ-C0*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(E1I;&QA
M9&5L<V5R(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-3@*(SH@861M:6XO<&5R;7,O961I="YP:'`Z
M,3`Y(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,@IM<V=I9"`B4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B5&EL;&%D96QS97,M861M:6YI
M<W1R871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C@*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(E!R;V9I;&5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097)U(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(DOF;&5D
M>7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R(")&
M:6QI<'!I;F5R;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DV"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3DV"FUS9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,`IM<V=I9"`B4&AO=&]S(@IM<V=S
M='(@(D9O=&]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@P"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G
M<W1R(")0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4')I:VME
M<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET
M=61E<R(*;7-G<W1R(")"86YA;&ET971E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;"(*;7-G<W1R(")+;&EK(&D@96X@8V5L
M;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B0F5K<N9F="!A
M="!D=2#X;G-K97(@870@<VQE='1E(&1E='1E(&5L96UE;G0Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V
M"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN
M:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(D)E:W+F9G0@870@9'4@^&YS:V5R
M(&%T(&%F;.9N:V4@9&5T=&4@96QE;65N="XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-38R(&QI8B](;W)D92]&;W)M+G!H<#HR-38R"FUS9VED
M(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G<W1R("))
M;F1T87-T(&5N(&WE;F5D(&]G(&5T(.5R<W1A;"XB"@HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B
M26YD=&%S="!E="!N879N('1I;"!D96X@;GEE(&MA=&5G;W)I.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#$@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,#$*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M(@IM<V=S='(@(DEN9'1A<W0@96X@9WEL9&EG($E0+6%D<F5S<V4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8T,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C8T,`IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE
M8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"XB"FUS9W-T<B`B
M26YD=&%S="!E;B!G>6QD:6<@9&%T;RP@=&IE:R!A;G1A;&QE="!A9B!D86=E
M(&D@;>5N961E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#0W
M(&QI8B](;W)D92]&;W)M+G!H<#HR-#0W"FUS9VED(")0;&5A<V4@96YT97(@
M82!V86QI9"!T:6UE+B(*;7-G<W1R("));F1T87-T(&5N(&=Y;&1I9R!T:61S
M86YG:79E;'-E+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O
M8FQE;2XB"FUS9W-T<B`B4VMR:78@=F5N;&EG<W0L(&AV860@<')O8FQE;65T
M(&?E<B!U9"!PY2!O9R!H=F%D(&1E<B!S:V5R+B(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHR
M-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0B"FUS9W-T<B`B26YD=&%S="!V96YL:6=S="!B<G5G97)N879N(&]G
M(&MO9&5O<F0B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G
M:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*(DSF<R!F^&QG96YD92!T96MS="X@1'4@4TM!3"!VYG)E
M(&5N:6<@:2!B971I;F=E;'-E<FYE(&9O<B!A="!B<G5G92!S>7-T96UE="XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H
M<#HW,`HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW
M,`IM<V=I9"`B4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*
M;7-G<W1R("));F1T87-T(&1E="!N>64@:V%T96=O<FEN879N.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQE;B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B
M4&]L:71I:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#D*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(DUE;FEN9W-MY6QI;F=E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3DS(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,0IM<V=I9"`B4&]R='5G86PB"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C0*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`B4&QA8V5R:6YG(&%F(&)I;&QE9&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3$*;7-G:60@(E!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4B"FUS9W-T<B`B4&QA8V5R:6YG(&%F(&1E;FYE('1A
M8F5L(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-3$@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-E;F0@
M=&EL(&1E;FYE(&UA<'!E("AI:VME(&=E;FYE;71V=6YG970@868@24U!4"DB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,R!L:6(O0FQO8VLO;65T87(N
M<&AP.C(W.`HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(").961B^'(@9V5N;F5M('-E
M;F5S="`E<R!T:6UE<CH@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(*;7-G
M<W1R(").961B^'(\8G(@+SYC:&%N8V4B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O;&1A<"YP:'`Z.3@@;&EB+TAO<F1E+U!R969S+VQD87`N<&AP.CDX
M"FUS9VED(")0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E!R969S7VQD87`Z($MRYG9E="!,1$%0+75D
M=FED9&5L(&EK:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,R!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z
M,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@2W+F
M=F5T('-E<W-I;VXM=61V:61D96QS92!I:VME(&9U;F1E="XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B
M5')Y:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V"FUS9VED(")0<F5S
M<W5R92!A="!S96$@;&5V96PZ("(*;7-G<W1R(")4<GEK('9E9"!O=F5R9FQA
M9&5N.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS
M9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E1R>6LZ("(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#,*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*;7-G:60@
M(E!R979I97<B"FUS9W-T<B`B1VQI;70B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*;7-G:60@(E!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")"971R
M86=T(&)I;&QE9&5T(&D@970@;GET('9I;F1U92(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S4V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S8P"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,S4V(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V:6]U<R!O<'1I;VYS
M(@IM<V=S='(@(D9O<G)I9V4@=&EL=F%L9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R:6YT(&1O8W5M
M96YT(@IM<V=S='(@(E5D<VMR:78@9&]K=6UE;G0B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-#(S"FUS9VED(")0<FEV871E($ME>2(*;7-G<W1R(")0<FEV870@;OAG
M;&4B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38Y(&QI
M8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B
M4')O8FQE;2(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.C$R-PIM<V=I9"`B
M4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R(")0<F]B;&5M8F5S:W)I=F5L
M<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<Q"FUS9VED(")0
M<F]J96-T<R(*;7-G<W1R(")0<F]J96MT97(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C$Q,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S(W-@IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`B
M4W1I:V]R9'-T96MS="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0R,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U
M8FQI8R!+97DB"FUS9W-T<B`B3V9F96YT;&EG92!N^&=L92(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0V(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C0V"FUS9VED(")0=6)L:6,@2V5Y($%L9V]R:71H;2(*
M;7-G<W1R(")/9F9E;G1L:6<M;OAG;&4M86QG;W)I=&UE(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#4@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R
M(")/9F9E;G1L:6<@;OAG;&4@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")/9F9E;G1L:6<O<')I=F%T
M+6[X9VQE<^9T+6=E;F5R97)I;F<@;6ES;'EK:V5D97,N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`P"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0=65R=&\@4FEC;R(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S0S,30N<&AP.C4U(&QI
M8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-0IM<V=I9"`B4'5R9V4@
M;65S<V%G97,B"FUS9W-T<B`B561R96YS(&)E<VME9&5R(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$X-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`R"FUS9VED(")1871A<B(*;7-G<W1R(")1871A<B(*"B,Z(&%D;6EN+W-Q
M;'-H96QL+G!H<#HV-`IM<V=I9"`B475E<GDB"FUS9W-T<B`B1F]R97-P^')G
M<V5L(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@P"FUS9VED(")1=6]T
M82(*;7-G<W1R(")+=F]T92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C8T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C8T"B,L
M('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM
M<V=S='(@(D]F9F5N=&QI9R!24T$M;OAG;&4@*"5D(&)I="DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T(&QI8B](;W)D92]&;W)M+G!H<#HR
M,C8T"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS9W-T<B`B16YK96QT=FES
M('9A;&<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B(*;7-G<W1R(")296=N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#8*;7-G:60@(E)A:6X@16%R
M;'DB"FUS9W-T<B`B4F5G;B!T:61L:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@3&%T92(*;7-G
M<W1R(")296=N('-E;G0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT.`IM<V=I9"`B4F%I;B!3:&]W97(B"FUS9W-T<B`B4F5G
M;F)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-#D*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B4F5G;B!O9R!S
M;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(E-L=60B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,PIM<V=I9"`B4F%N9&]M($9O<G1U;F4B"FUS
M9W-T<B`B5&EL9N9L9&EG="!E<&EG<F%M(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<V"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED
M(")2871I;R(*;7-G<W1R(")&;W)H;VQD(@H*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HS,C0@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C0*(SH@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-"!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C8X"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3$@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,S<@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*
M;7-G:60@(E)E860B"FUS9W-T<B`B3.9S(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C-#,Q-"YP:'`Z-#<@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S
M,30N<&AP.C0W"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M-PIM<V=I9"`B4F5A9"!M97-S86=E<R(*;7-G<W1R("),YG,@8F5S:V5D97(B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B5FER:V5L:6<@<VQE='1E
M("5S/R!$96YN92!O<&5R871I;VX@:V%N(&EK:V4@8FQI=F4@;VUG:F]R="XB
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@HB5FER:V5L:6<@<VQE='1E(&1A=&$@9F]R(&)R=6=E<B`E<S\@1&5N
M;F4@;W!E<F%T:6]N(&MA;B!I:VME(&)L:79E(&]M9VIO<G0N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B3VUG^'(@9&EN('-I
M9'-T92!H86YD;&EN9R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP
M.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC
M97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S
M='(@(D]P9&%T97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS
M9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B
M3W!F<FES:R!D>6YA;6ES:V4@;65N=2UE;&5M96YT97(Z(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T-0IM<V=I9"`B4F5F<F5S:"!0;W)T86P@5FEE
M=SHB"FUS9W-T<B`B1V5N;W!F<FES:R!P;W)T86QV:7-N:6YG.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q,PHC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T
M<B`B4F5G=6SF<G0@=61T<GEK(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(S,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(S,0IM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B4F5L871I;VYS;.9S97(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C`X"FUS9VED(")296QO860B"FUS9W-T<B`B1V5N;W!F
M<FES:R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,S"FUS9VED(")296UA
M<FMS(@IM<V=S='(@(DYO=&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B1FIE<FYE('-E
M<G9E<F4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G
M:60@(E)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.B(*;7-G<W1R(")&:F5R;B!54DP@*&AT='`Z+R]W=W<N96MS96UP96PN9&LO
M:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC
M.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3,@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,@IM<V=I9"`B
M4F5M;W9E(@IM<V=S='(@(E-L970B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA
M>6]U="YI;F,Z,3$*;7-G:60@(E)E;6]V92!";&]C:R(*;7-G<W1R(")3;&5T
M(&)L;VLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-34Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU
M-3D*;7-G:60@(E)E;6]V92!C;VQU;6XB"FUS9W-T<B`B1FIE<FX@:V]L;VYN
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E-L970@9F]R
M;6%T97)I;F<B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM
M<V=I9"`B4F5M;W9E('!A:7(B"FUS9W-T<B`B4VQE="!P87(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B1FIE<FX@;&%G<F5T('-K<FEP="!F<F$@<V5R=F5R<R!M:61L97)T:61I
M9V4@:V%T86QO9RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T
M<B`B1FIE<FXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3`*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O
M;2!T:&4@9&]C=6UE;G0B"FUS9W-T<B`B1FIE<FX@9&5T=&4@<'5N:W0@9G)A
M(&1O:W5M96YT970B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N
M:6YC.C$Q"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R(")3;&5T(&)R=6=E
M<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")296UO=F4@=7-E<CH@)7,B"FUS9W-T<B`B4VQE
M="!B<G5G97(Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HQ,S@@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q
M=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E
M.B`B"FUS9W-T<B`B06YM;V1N:6YG(&MU;FYE(&EK:V4@8F5S=F%R97,N(%)E
M='5R;F5R970@9F5J;&MO9&4Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO
M="!B92!F;W5N9"XB"FUS9W-T<B`B06YM;V1E="!T:F5N97-T92!K=6YN92!I
M:VME(&9I;F1E<RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$X
M-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4R-PHC.B!L:6(O2&]R9&4N
M<&AP.C$X-2!L:6(O2&]R9&4N<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U
M<F%T:6]N+B(*;7-G<W1R(")+<N9V961E("<E<R<@97(@:6MK92!A;F=I=F5T
M(&D@)7,M:V]N9FEG=7)A=&EO;BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@V,2!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W.`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,Q(&QI8B]61E,O9G1P
M+G!H<#HX-C$@;&EB+U9&4R]S<6PN<&AP.C8W.`HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DMRYG9E="!<(B5S7"(@97(@:6MK92!A;F=I=F5T(&D@5D93(&MO;F9I
M9W5R871I;VXN(@H*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<V(&QI
M8B](;W)D92]5=&EL+G!H<#HW-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q
M=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB
M"FUS9W-T<B`B2W+F=F5D92!<(B5S7"(@97(@:6MK92!A;F=I=F5T(&D@:V]N
M9FEG=7)A=&EO;F5N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,S-B!L:6(O2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S,V"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")+<N9V970@9F5L="(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HR,C`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,R,0HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,S,Y(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HR,C`*(SH@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S
M='(@(DYU;'-T:6PB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B3G5L<W1I;"!K;V1E
M;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*;7-G:60@
M(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B3G5L<W1I;"!D:70@:V]D
M96]R9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S$*;7-G:60@(E)E<W1O
M<F4@3&%S="!1=65R>2(*;7-G<W1R(")'96YS:V%B('-I9'-T92!F;W)E<W#X
M<F=S96PB"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,CD@861M:6XO<&AP<VAE
M;&PN<&AP.C<R(&%D;6EN+W-Q;'-H96QL+G!H<#HV-PIM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")297-U;'1A=&5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R(")4:6QB86=E('1I;"!I;F1S
M=&EL;&EN9V5R;F4B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M,S@*;7-G:60@(E)E='EP92!N97<@<&%S<W=O<F0B"FUS9W-T<B`B1V5N=&%S
M="!N>70@:V]D96]R9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DW
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*
M;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT
M-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R(")'96YD86X@:V]N9FEG=7)A=&EO;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S4*;7-G:60@(E)I8V@@5&5X="!%
M9&ET;W(@3W!T:6]N<R(*;7-G<W1R("));F1S=&EL;&EN9V5R(&9O<B!2:6-H
M(%1E>'0M<F5D:6=E<FEN9R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU
M.`IM<V=I9"`B4FED9&QE<R(*;7-G<W1R(")'Y61E<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`IM<V=I9"`B
M4FEG:'0B"FUS9W-T<B`B2/AJ<F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,3`S(&QI8B](;W)D92]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H
M="!H96%D97(B"FUS9W-T<B`B2/AJ<F4@=&]P=&5K<W0B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,#DY(&QI8B](;W)D92]&;W)M+G!H<#HS,#DY
M"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B2/AJ<F4@=N9R9&EE<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(E+F
M:VME+65G96YS:V%B97(N+BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(E)E9V5L(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`R"FUS9VED(")2;VUA;FEA(@IM<V=S='(@(E)U;>9N:65N(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-@HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(V"FUS9VED
M(")2;W1A=&4@,3@P(@IM<V=S='(@(E)O=.ER(#$X,"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C,*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,PIM<V=I9"`B4F]T871E($QE
M9G0B"FUS9W-T<B`B4F]TZ7(@=F5N<W1R92(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,CD*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(R.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM
M<V=S='(@(E)O=.ER(&CX:G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I
M97,B"FUS9W-T<B`B4N9K:V4M96=E;G-K86)E<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S`*;7-G:60@(E)O
M=R!P<F]P97)T:65S(@IM<V=S='(@(E+F:VME+65G96YS:V%B97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I
M9"`B4F]W<SHB"FUS9W-T<B`B4N9K:V5R.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S
M(@IM<V=S='(@(E-T<F5G97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(E-T
M<F5G97(@=FEL(&]P='+F9&4@;65L;&5M('+F:VME<B!O9R!K;VQO;FYE<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(E-T<F5G97(@=FEL(&MU;B!O<'1RYF1E(&UE;&QE
M;2!K;VQO;FYE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E-T<F5G97(@=FEL(&MU;B!O<'1R
MYF1E(&UE;&QE;2!RYFMK97(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(Q
M"FUS9VED(")2=6XB"FUS9W-T<B`B561F^'(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DY(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G
M:60@(E)U<W-I86X@1F5D97)A=&EO;B(*;7-G<W1R(")2=7-L86YD(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#`@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R(")+<GEP=&]G<F%F:7-K(%,O34E-12US
M:6=N871U<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M,S(S(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)
M344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%+7-I9VYE<F5T
M(&)E<VME9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z.#$@
M;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N
M=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4T%33"WF9W1N
M:6YG(&5R(&EK:V4@=&EL9^9N9V5L:6<N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C4P-@IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")3
M35,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L
M;"(*;7-G<W1R(")344PM9F]R=&]L:V5R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(W-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-`IM<V=I9"`B
M4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<R(*;7-G<W1R(")344PM
M=61T<GEK(&9O<B!O<'-L86<@868@=N9R9&EE<B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,S,*;7-G:60@(E-32"(*;7-G<W1R(")34T@B"@HC
M.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]M;V)I;&4N<&AP.C,U"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")3
M54-#15,B"@HC.B!L:6(O87!I+G!H<#HQ-3,*;7-G:60@(E-?44P@4VAE;&PB
M"FUS9W-T<B`B4U%,+69O<G1O;&ME<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(DSX
M<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I;G0@2&5L96YA(@IM<V=S='(@
M(E-K="X@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.3`*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B4V%I;G0@2VET=',@
M86YD($YE=FES(@IM<V=S='(@(E-K="X@2VET=',@;V<@3F5V:7,B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,Y(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")3:W0N($QU8VEA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DR"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E
M;&]N(@IM<V=S='(@(E-K="X@4&EE<G)E(&]G($UI<75E;&]N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(T-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DS"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$U"FUS9VED(")386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE
M<R(*;7-G<W1R(")3:W0N(%9I;F-E;G0@;V<@1W)E;F%D:6YE<FYE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I
M9"`B4V%M92!F<F%M92`H7W-E;&8I(@IM<V=S='(@(E-A;6UE(')A;6UE("A?
M<V5L9BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A
M;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@
M(E-A;B!-87)I;F\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-A;R!4;VUE(&%N
M9"!0<FEN8VEP92(*;7-G<W1R(")3;V$@5&]M92!O9R!0<FEN8VEP92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@4')O=FED97(B"FUS
M9W-T<B`B4V%T96QI='5D8GED97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-A
M=61I($%R86)I82(*;7-G<W1R(")3875D:6%R86)I96XB"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M1V5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")'96T@
M7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92`E<R(*;7-G<W1R(")'96T@7"(E<UPB
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-0IM<V=I9"`B4V%V92!/
M<'1I;VYS(@IM<V=S='(@(D=E;6UE($EN9'-T:6QL:6YG97(B"@HC.B!A9&UI
M;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E
M9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E
M<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D=E;2!G
M96YE<F5R970@:V]N9FEG=7)A=&EO;B!S;VT@4$A0+7-K<FEP="!I(&1I;B!S
M97)V97)S(&UI9&QE<G1I9&EG92`B"B)K871A;&]G+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D=E;70@)7,M:V]N9FEG=7)A
M=&EO;BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M7"(E<UPB+B(*;7-G<W1R(")'96UT92!S:W)I<'0@9F]R(&]P9W)A9&5R:6YG
M(&%F(&]P<^9T;FEN9R!T:6PZ(%PB)7-<(BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,0IM<V=I9"`B4V-A='1E<F5D(%0M
M4W1O<FUS(@IM<V=S='(@(E-P<F5D="!T;W)D96XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B5FED96YS
M:V%B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,30@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@(E-E87)C:"(*
M;7-G<W1R(")3^&<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(R
M"FUS9VED(")396%R8V@@16YG:6YE<R(*;7-G<W1R(")3^&=E;6%S:VEN97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.34U(&QI8B](;W)D92]&
M;W)M+G!H<#HR.34U"FUS9VED(")396QE8W0@1FEL97,B"FUS9W-T<B`B5N9L
M9R!F:6QE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.#4*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6YFQG(&5N(&1A
M=&\B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E;F;&<@96X@9W)U<'!E
M(&%T('1I;&;X:F4B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0S
M"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B5N9L9R!E;B!N
M>2!E:F5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS
M9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5N9L9R!E;B!S97)V97(B
M"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I9"`B4V5L
M96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5N9L9R!E;B!B<G5G97(@870@
M=&EL9OAJ92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HV-S8*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8W-@IM<V=I9"`B4V5L96-T(&%L;"(*;7-G<W1R(")6YFQG(&%L;&4B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0S(&QI8B](;W)D92]&;W)M
M+G!H<#HR-C0S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB
M"FUS9W-T<B`B5N9L9R!A;&QE(&1A=&\M:V]M<&]N96YT97(N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<S"FUS9VED(")396QE
M8W0@86X@;V)J96-T(@IM<V=S='(@(E;F;&<@970@;V)J96MT(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-PHC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED(")396QE
M8W0@;F]N92(*;7-G<W1R(")6YFQG(&EN9V5N(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@
M>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C
M;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS
M9W-T<B`B(@HB5N9L9R!D92!T96=N(&1U(&AA<B!B<G5G(&9O<B!F<F$@:V%S
M<V5R;F4@;F5D96YF;W(N($1E(&MA;B!SY2!K;&EP<&5S(&]G("(*(FMO<&EE
M<F5S(&9R82!T97AT9F5L=&5T+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N
M:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G
M<W1R(")6YFQG(&1A=&\M861S:VEL;&5R96XZ(@H*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z
M(@IM<V=S='(@(E;F;&<@9&%T;V9O<FUA=#HB"@HC.B!T96UP;&%T97,O<')E
M9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE(&ED
M96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B5N9L9R!D96X@
M:61E;G1I=&5T+"!S;VT@9'4@=FEL(.9N9')E.B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI
M=&5R.B(*;7-G<W1R(")6YFQG('1I9',M861S:VEL;&5R96XZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C4*;7-G:60@(E-E;&5C="!T:&4@=&EM
M92!F;W)M870Z(@IM<V=S='(@(E;F;&<@=&ED<V9O<FUA=#HB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C4W"FUS9VED(")396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RXB"FUS9W-T<B`B5N9L9R!T;R!F96QT97(L(&1E<B!S
M=F%R97(@=&EL(&AI;F%N9&5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,3`*;7-G:60@(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T
M<B`B5N9L9R!D:6X@9F%R=F5S86UM96YSYG1N:6YG+B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR-3(*;7-G:60@(E-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93HB"FUS9W-T<B`B5N9L9R!D:70@9F]R971R=6MN92!S<')O
M9SHB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I
M9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")396YD('!R;V)L96UB
M97-K<FEV96QS92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#0R"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,#0R"FUS9VED(")396YD(%--4R(*;7-G<W1R(")396YD(%--4R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y
M.`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")396YE9V%L
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E;G-O<CH@
M(@IM<V=S='(@(D;X;&5R.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#$P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0Q,"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")397!T96UB97(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO
M;G1E;F5G<F\B"FUS9W-T<B`B4V5R8FEE;B!O9R!-;VYT96YE9W)O(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#(@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HW,#(*;7-G:60@(E-E<FEA;"!.=6UB97(B"FUS
M9W-T<B`B4V5R:65N=6UM97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,30Y"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A
M:6QA8FQE+B(*;7-G<W1R(")397)V97(M9&%T82!F;W)K97)T(&5L;&5R(&EK
M:V4@=&EL9^9N9V5L:6<N(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W"FUS
M9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(E-E<W-I;VYS861M:6YI<W1R
M871O<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*;7-G<W1R(")397-S
M:6]N+4E$('5D;/AB970N(@H*(SH@;&EB+V%P:2YP:'`Z,30U"FUS9VED(")3
M97-S:6]N<R(*;7-G<W1R(")397-S:6]N97(B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S$T(&QI8B](;W)D92]&;W)M+G!H<#HR,S$T"FUS9VED
M(")3970B"FUS9W-T<B`B3>9N9V1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<Y"FUS9VED(")3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N(@IM<V=S
M='(@(B(*(DEN9'-T:6QL:6YG97(@9&5R('1I;&QA9&5R(&1I9R!A="!N=6QS
M=&EL;&4@9&ET(&MO9&5O<F0L(&AV:7,@9'4@;F]G96YS:6YD92`B"B)S:W5L
M;&4@9VQE;6UE(&1E="XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$X
M"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T
M;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B26YD<W1I;"!F
M:F5R;F4@<V5R=F5R92P@<V]M(&1U(/AN<VME<B!A="!T:6QGY2!F<F$@9&EN
M('!O<G1A;"XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@
M(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RXB"FUS9W-T<B`B26YD<W1I;"!D:6X@9F]R971R=6MN92!S
M<')O9RTL('1I9'-Z;VYE+2!O9R!D871O=F%L9RXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB26YD<W1I
M;"!D:6YE(&]P<W1A<G1S87!P;&EK871I;VYE<BP@9F%R=F5S86UM96YSYG1N
M:6YG+"!S:61E;W!F<FES:VYI;B!O9R`B"B)A;F1R92!V:7-N:6YG<W1I;'9A
M;&<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B4V5T
M=7`B"FUS9W-T<B`B26YD<W1I;&QI;F<B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O:6YD97@N:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I
M<'1S(&%V86EL86)L92(*;7-G<W1R(")3:W)I<'1S('1I;"!O<&=R861E<FEN
M9R!A9B!O<'/F=&YI;F<@=&EL9^9N9V5L:6=E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B1FQE<F4@
M<W1E9&5R(&UU;&EG(&UE9"!P87)A;65T97)E;CH@(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`P"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T
M"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@(E-E>6-H96QL97)N92(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*;7-G:60@(E-H;W!P:6YG
M(@IM<V=S='(@(E-H;W!P:6YG(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R
M="!O<'-U;6UE<FEN9R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-3`*
M;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T
M(&QI;FMS/R(*;7-G<W1R(")3:V%L(&AU<G1I9RUT87-T97(@9&5F:6YE<F5S
M(&9O<B!D92!F;&5S=&4@:&5N=FES;FEN9V5R/R`H]RDB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R,R!L:6(O2&]R9&4O4&5R;7,N<&AP.C,R
M,PHC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,S('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-C<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q,PHC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W.0IM<V=I9"`B4VAO=R(*;7-G<W1R(")6:7,B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,34U"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D("(*(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(E9I<R!F;W)S:V5L
M;&5N92!M96QL96T@9&5N(&=E;71E(&]G(&1E;B!N>6QI9W0@9V5N97)E<F5D
M92!K;VYF:6=U<F%T:6]N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.30*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B5FES('1I9'-P=6YK="!F;W(@<V5N97-T92!T:6QG86YG
M('9E9"!PY6QO9VYI;F<_(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3<V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-0IM<V=I9"`B4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")6:7,@;75L:6=H960@9F]R
M(&%T(&)E:&]L9&4@;W!R:6YD96QI9R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(W.34@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.34*;7-G:60@(E-H
M;W<@<&EC:V5R(@IM<V=S='(@(E9I<R!S;G5P<&5R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S,`IM<V=I9"`B4VAO=R!T86)L92!O<&5R871I;VYS
M(&UE;G4@8F%R/R(*;7-G<W1R(")6:7,@5&%B96QO<&5R871I;VYE<BUK;F%P
M<&5N(&D@;65N=65N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@
M;&5F=#\B"FUS9W-T<B`B5FES("5S+6UE;G5E;B!T:6P@=F5N<W1R93\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E
M<B!F;W(@=&%B96QC96QL96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E9I<R!D:6%L;V=V:6YD
M=64@;65D(&5G96YS:V%B97(@9F]R('1A8F5L;&5N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED
M(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B5FES(&1I86QO9W9I;F1U92!M960@96=E;G-K86)E<B!F;W(@=&%B96QR
MYFMK96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G(@IM<V=S='(@(E9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS
M:V%B97(@9F]R(&)I;&QE9&5T(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<V,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U
M<&QO860B"FUS9W-T<B`B5FES(&%F<V5N9'1E(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3(*;7-G:60@(E-H;W=E<G,B"FUS
M9W-T<B`B0GEG97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU,PIM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")">6=E
M<B!T:61L:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@3&%T92(*;7-G<W1R(")">6=E<B!S
M96YT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-34*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(D)Y
M9V5R(&D@;N9R:&5D96XB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP.C8Q.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HT.#`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M,3D*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")3:W)U;7`B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDQ,`HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.CDW,@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$P-3@*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3(P"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3$X,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R,C,*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C4R"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,3(X-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HW-S0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.CDR,B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z
M,3`T-R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HQ,#@W"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C$Q,38@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z,3$T.0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.CDQ,`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.CDW,@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C$P-3@*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3(P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3$X
M,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R,C,*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C4R"B,Z
M(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3(X-0IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(E-K<G5M<"!E;&QE<B!F;'ET(&YA
M8F]B;&]K:V4@868@=F5J96X@9OAR<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(Q,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E-K<FEV
M(&EN9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$S
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U
M<F4B"FUS9W-T<B`B56YD97)S:W)I9G0B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<Q,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C<Q,@IM<V=I9"`B4VEG;F%T=7)E($%L9V]R:71H;2(*;7-G<W1R(")3:6=N
M871U<F%L9V]R:71M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(P,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P;W)E
M(@IM<V=S='(@(E-I;F=A<&]R92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3$R"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,#4@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(Q-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S-R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C(T-B!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ,@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S$P-2!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F%R+G!H<#HV-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW,@IM<V=I9"`B4VEZ
M92(*;7-G<W1R(")3=/AR<F5L<V4B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC
M92(*;7-G<W1R(")3<')I;F<@=F5D;&EG96AO;&1E;'-E(&]V97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#,*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9A:VEE="(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P
M-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`X(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N
M:65N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-38*;7-G:60@(E-N;W<B"FUS9W-T<B`B4VYE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3<*;7-G:60@(E-N;W<@4VAO=V5R
M(@IM<V=S='(@(E-N96)Y9V4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@
M(E-N96)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO=V5R<R!%87)L>2(*;7-G<W1R(")3
M;F5B>6=E<B!T:61L:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S
M='(@(E-N96)Y9V5R('-E;G0B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X
M-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM<V=S='(@(E-N961Y8F1E.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B4VYEYFMV:79A;&5N="!I('9A;F0Z
M("(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`R(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S
M='(@(E-A;&]M;V[X97)N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,30@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C$T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI
M82(*;7-G<W1R(")3;VUA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8P"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(E-A;F=E(&]G('!O
M97-I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDP."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,CDP.`IM<V=I9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB
M"FUS9W-T<B`B4V]R=&5R:6YG<W9A;&<B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3@Y"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3@Y(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Q-PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T
M-R!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HQ.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(D%F<V5N9&5R861R97-S92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U
M=&@@069R:6-A(@IM<V=S='(@(E-Y9&%F<FEK82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DS"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RDB"FUS9W-T<B`B4WED975R;W#F:7-K("A)4T\M.#@U.2TS*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(P.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S(@IM<V=S='(@(E-Y9"!'96]R9VEA(&]G($1E('-Y9&QI
M9V4@4V%N9'=I8VCX97(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(E-Y9&QI9V4@:&%L=FMU9VQE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E
M='=E96X@861J86-E;G0@8V5L;',B"FUS9W-T<B`B3'5F="!M96QL96T@;F%B
M;V-E;&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL(@IM<V=S='(@(DQU9G0@;65L;&5M(&EN9&AO;&0@;V<@
M<F%M;64@:2!C96QL92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q
M-2!L:6(O2&]R9&4O1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T
M<B`B365L;&5M<G5M<W1A;F=E="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0IM<V=I9"`B4W!A8VEN9R(*;7-G
M<W1R(")-96QL96UR=6TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D
M:6YG(@IM<V=S='(@(DQU9G0@;V<@9F]R<FEN9R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C@P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED
M(")3<&%I;B(*;7-G<W1R(")3<&%N:65N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$P,`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3:VED='!O<W0B
M"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@
M0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DEN9'1A<W1N:6YG(&9O<B!S<&5C
M:6%L:V%R86MT97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@
M(D1E;"!C96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-C8*;7-G:60@(E-P;&ET(&-O;'5M;B(*;7-G<W1R
M(")$96P@:V]L;VYN92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R
M(")$96P@<N9K:V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G
M:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@
M(E-R:2!,86YK82(*;7-G<W1R(")3<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@Q(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-@IM
M<V=I9"`B4W1A;F1A<F0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G<W1R(")3
M=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3$*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(U.#8@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.3$*;7-G:60@(E-T87)T
M('EE87(B"FUS9W-T<B`B0F5G>6YD96QS97/E<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<Q"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")$
M96QS=&%T(&5L;&5R('!R;W9I;G,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(E-T871U
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3<@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(W.3<*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@
M(DQA9W)I;F=S9F]R;6%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G
M:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(E9E:B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK
M971H<F]U9V@B"FUS9W-T<B`B1V5N;F5M<W1R96=N:6YG(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3(S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(S
M,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B3&ES=&4@868@<W1R96YG
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A
M9&1R97-S(@IM<V=S='(@(D9J97)N(&1O;>9N92!F<F$@861R97-S96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R(")3=&EL(%M#4U-=(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM
M<V=I9"`B4W4B"FUS9W-T<B`B4_AN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S
M7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")5;F1E<FMA=&%L;V<@7"(E<UPB(&EK
M:V4@9G5N9&5T+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S,*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`B16UN92(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,3@*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L:6(O
M2&]R9&4O1F]R;2]296YD97)E<BYP:'`Z,S$X"FUS9VED(")3=6)M:70B"FUS
M9W-T<B`B1V]D:V5N9"(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*
M(G)E<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D%N;6]D
M;FEN9R!O;2!A="!T:6QF^&IE(%PB)7-<(B!T:6P@<WES=&5M(&%F<V5N9'0N
M("!$=2!K86X@:6MK92!L;V=G92!PY2!F^'(@(@HB9&EN(&%N;6]D;FEN9R!E
M<B!B;&5V970@86YE<FME;F1T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R
M("),878@<VMR:69T(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-0HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S
M=&%T=7,N<&AP.C(X"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N
M97(O<W1A='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")59&;X
M<G0B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@861D960@7"(E<UPB('1O('1H92!S>7-T96TN(@IM
M<V=S='(@(EPB)7-<(B!B;&5V('1I;&;X:F5T('1I;"!S>7-T96UE="XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R(")$871A(&9O<B!B<G5G97(@7"(E<UPB(&)L
M978@<VQE='1E="!F<F$@<WES=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L('!H<"UF;W)M870*
M;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB)7-<(BXB"FUS9W-T<B`B
M7"(E<UPB('-L971T970N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D(%PB)7-<(B!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(EPB)7-<(B!S;&5T=&5T(&9R82!S
M>7-T96UE="XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+B(*;7-G<W1R(")+;VYF:6=U<F%T:6]N('1I;&)A
M9V5F^')T+B!'96YI;F1LYG,@9F]R(&%T('-E(.9N9')I;F=E<FYE+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HU-PIM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")297-E<G9E:V]N9FEG=7)A=&EO;B!G96UT
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")297-E<G9E:V]N9FEG=7)A=&EO
M;F9I;"`E<R!G96UT+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$V.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS
M9W-T<B`B7"(E<UPB(&]P9&%T97)E="XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B7"(E
M<UPB('-K<F5V970N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G
M<W1R(")3=61A;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`B26YD
M:&]L9"(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N
M(%)I<V4B"FUS9W-T<B`B4V]L;W!G86YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(E-O;&YE9&=A;F<B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM
M<V=I9"`B4W5N;GDB"FUS9W-T<B`B4V]L<FEG="(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@(E-U;G)I<V4B"FUS9W-T<B`B
M4V]L;W!G86YG(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C,@;&EB+T)L
M;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3=6YR:7-E+U-U;G-E="(*;7-G
M<W1R(")3;VQO<&=A;F<O<V]L;F5D9V%N9R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")3
M;VQO<&=A;F<Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R(")3;VQN961G86YG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-PIM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B4V]L;F5D9V%N9SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS
M9W-T<B`B2.9V970@<VMR:69T(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G<W1R(")(:N9L<"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B4W5R:6YA;2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<U(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3<U"FUS9VED(")3=7)N86UE(@IM<V=S='(@
M(D5F=&5R;F%V;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Y(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@86YD
M($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!O9R!*86X@36%Y96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,30*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R(")3=V%Z:6QA
M;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G<W1R(")3=F5R
M:6=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-38@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S='(@(E-C
M:'=E:7HB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX-@IM<V=I
M9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3>6YC(&QO9R!S;&5T=&5T
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,
M(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O
M<F1S+G!H<#HY-R!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY-PIM<V=I
M9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R(")3>6YT
M86MS9F5J;"!I('/X9V5L960B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA
M;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@(E-Y<FEE;B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"FUS9VED(")4+5-T;W)M
M(@IM<V=S='(@(E1O<F1E;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R(")4;W)D96X@;V<@=FEN9"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")4
M;W)D96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-0IM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T<B`B5&]R9&5N('1I
M9&QI9W0B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP:'`Z,38V(&QI
M8B](;W)D92]$871A+W1S=BYP:'`Z,38V"FUS9VED(")44U8@9FEL92(*;7-G
M<W1R(")44U8M9FEL(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE+G!H<#HQ,S0*
M;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8F5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B
M;&4@4')O<&5R=&EE<R(*;7-G<W1R(")486)E;"UE9V5N<VMA8F5R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC.B!L
M:6(O2&]R9&4O1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PIM<V=I9"`B5&%B
M;&4@4V5T(@IM<V=S='(@(E1A8F5L;>9N9V1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B
M;&4@<')O<&5R=&EE<R(*;7-G<W1R(")486)E;"UE9V5N<VMA8F5R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-`HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM
M<V=S='(@(E1A:7=A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G
M:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B5&%I=V%N
M+"!$96X@:VEN97-I<VME('!R;W9I;G,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3D*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@
M(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%D:FEK:7-T86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B5&%N>F%N:6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDU"FUS9VED(")487)G970Z(@IM<V=S='(@(DWE;#HB"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDS,@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`T.2!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@Y"FUS9VED(")487-K<R(*;7-G<W1R
M(")/<&=A=F5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU-S0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E1E
M;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L969O;FYU;6UE<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO
M=7(Z("(*;7-G<W1R(")496UP+B!S:61S=&4@=&EM93H@(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C$*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@
M(E1E;7!E<F%T=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C$R"FUS9VED(")496UP97)A='5R93H@(@IM<V=S='(@(E1E;7!E<F%T=7(Z
M("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A='5R/&)R("\^*"5S2/AJ)7,O
M)7-,878E<RD@)F1E9SLE<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-CDU(&QI8B](;W)D92]496UP;&%T92YP:'`Z-CDU"B,L('!H
M<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(E-K86)E;&]N(%PB)7-<(B!I:VME(&9U;F1E="XB"@HC.B!A9&UI
M;B]T96UP;&%T97,N<&AP.C$V.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R
M871I;VXB"FUS9W-T<B`B4VMA8F5L;VXM861M:6YI<W1R871I;VXB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,C<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,3$@;&EB+TAO
M<F1E+T9O<FTN<&AP.C,S,C<*;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5K<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N
M;'DB"FUS9W-T<B`B4F5N('1E:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG
M;B(*;7-G<W1R(")496MS="UJ=7-T97)I;F<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM
M<V=S='(@(E1E:W-T+71O<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(E1O<B(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P
M*2(*;7-G<W1R(")4:&%I("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C0@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:6QA;F0B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C@U,2!L:6(O5D93+V9T<"YP:'`Z.#4Q"FUS9VED
M(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")&5%`M=61V:61D96QS96X@97(@:6MK92!T:6QGYFYG96QI9RXB"@HC.B!F
M<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HU-2!L:6(O2&]R9&4O2&ES
M=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A
M8FQE9"XB"FUS9W-T<B`B2&ES=&]R:6LM<WES=&5M970@97(@<VSE970@9G)A
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,X(&QI8B](;W)D
M92]+;VQA8BYP:'`Z.3,X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(M:6YT96=R871I;VYS;6]T;W)E
M;B!U;F1E<G-T^'1T97(@:6MK92!<(B5S7"(B"@HC.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]";V]K+G!H<#HQ,CDX(&QI8B].970O24U34"]";V]K+G!H
M<#HQ,CDX"FUS9VED(")4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I
M86QI>F5D+B(*;7-G<W1R("))35-0+6QO9V=E;B!K=6YN92!I:VME(&ML87)G
M^')E<RXB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@
M(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S
M9G5L;'DB"FUS9W-T<B`B36%I;G1E;F%N8V4Z.BUK;&%S<V5N(&)L978@:6MK
M92!I;F1LYG-T(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H
M<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X
M:71I;F<N(@IM<V=S='(@(E1I;'9A;&=S=FEN9'5E="!E<B!B;&5V970@;'5K
M:V5T+B!!9G-L=71T97(N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*
M(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HQ.#D@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR,#`@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,3$*(SH@;&EB+TAO<F1E+U!E
M<FUS+G!H<#HR,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HR,S0@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HR-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR-C0@;&EB
M+TAO<F1E+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB
M"FUS9W-T<B`B(@HB061M:6YI<W1R871O<F5N(&)L:79E<B!N^&1T('1I;"!A
M="!K;VYF:6=U<F5R92!E;B!P97)M86YE;G0@5&EL;&%D96QS97,M(@HB8F%C
M:V5N9"P@:'9I<R!D=2!V:6P@86YV96YD92!4:6QL861E;'-E<BXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U
M"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R(")+=6X@=6YD
M97)S:61E;B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C,Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T
M('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H
M92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HB2V]N=&%K="U)1"UN=6UM97)E
M="!B;&5V(&EK:V4@86YG:79E="P@969T97)L861T('1O;70@96QL97(@8FQE
M=B!I:VME(&9U;F1E="`B"B)I(&1A=&%B87-E;BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3$@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U
M8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T
M<B`B2V]N=&%K=&5N(&)L978@=&EL9OAJ970@=&EL(&1I="!A9')E<W-E:V%R
M=&]T96ME="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,3<R(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@(B(*(E1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*(D1E;B!L
M^'-G:F]R=&4@4$=0+7-I9VYA='5R+6)L;VL@97(@:W+F=F5T(&9O<B!A="!K
M=6YN92!V97)I9FEC97)E(&1E;B`B"B)S:6=N97)E9&4@8F5S:V5D+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@
M(B(*(E1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D
M871A8F%S92XB"FUS9W-T<B`B(@HB1&ES=')I8G5T:6]N<VQI<W1E+4E$(&5R
M(&5N=&5N(&EK:V4@86YG:79E="P@=&]M="!E;&QE<B!I:VME(&9U;F1E="!I
M("(*(F1A=&%B87-E;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8T,@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S
M(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1I<W1R:6)U=&EO;G-L:7-T96X@
M:6MK92!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z
M,3$V(&QI8B](;W)D92]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC<GEP
M=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N
M+B(*;7-G<W1R(")+<GEP=&5R:6YG<V9A8VEL:71E=&5R;F4@:W+F=F5R(&5N
M('-I:VME<B!W96(M9F]R8FEN9&5L<V4N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.#8@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,C@*
M(SH@;&EB+TAO<F1E+G!H<#HQ.#8@;&EB+TAO<F1E+G!H<#HU,C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+B(*;7-G<W1R(")&:6QE;B`E<R!B^'(@:6YD96AO;&1E(&5N
M("5S+6EN9'-T:6QL:6YG+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$X"B,Z(&QI8B](
M;W)D92YP:'`Z,3<Y(&QI8B](;W)D92YP:'`Z-3$X"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T
M=&EN9W,N(@IM<V=S='(@(D9I;&5N("5S(&+X<B!I;F1E:&]L9&4@;F]G;&4@
M)7,M:6YD<W1I;&QI;F=E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR,C8@;&EB+U9&4R]F:6QE+G!H<#HR,C8*;7-G:60@(E1H92!F:6QE
M(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N(@IM<V=S='(@(D9I;&5N
M(&MA;B!I:VME(&MO<&EE<F5S(&]V96YPY2!S:6=S96QV+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(X,"!L:6(O2&]R9&4O1&%T82YP:'`Z,C@P
M"FUS9VED(")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B
M1FEL96X@:6YD96AO;&1T(&EN9V5N(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92XB"FUS9W-T<B`B1OAL9V5N9&4@97(@:&]V961E<FYE(&9R82!D96YN92!M
M97-S86=E+W)F8S@R,BUB97-K960N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R
M965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E
M<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC
M=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y
M;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA
M="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@
M86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D
M+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R
M>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B)&=6QD<VOF
M<FUS=&EL<W1A;F0@=FED97,@870@=F]L9&4@<')O8FQE;65R(&D@26YT97)N
M970@17AP;&]R97(@9W)U;F1E="`B"B)B<F]W<V5R+69E:FPL('-O;2!V:2!I
M:VME(&AA<B!K=6YN970@;VUGY2X@1'4@=FEL(&UU;&EG=FES(&]P;&5V92`B
M"B)F;W)V86YS:V5D92!V:7-N:6YG97(L(&UA;F=E;"!PY2!E9&ET97)I;F=S
M9G5N:W1I;VYE<B!O9R]E;&QE<B!T:6QFYFQD:6=E("(*(F)R;W=S97(M;F5D
M8G)U9"X@2'9I<R!D:70@<WES=&5M(&5R(%=I;F1O=W,F;F)S<#LY>"!V:6P@
M9'4@;65D(&CX:B`B"B)S86YD<WEN;&EG:&5D(&]P;&5V92`G1V5N97)E;"!B
M97-K>71T96QS97-F96IL)R!O9R!V:6P@8FQI=F4@;OAD="!T:6P@870@(@HB
M9V5N<W1A<G1E(&UA<VMI;F5N+EQ<;EQ<;D1U(&5R(&YU(&%D=F%R970N("!4
M<GEK($]+(&AV:7,@9'4@<W1A9&EG(/AN<VME<B!A="`B"B)P<OAV970@9G5L
M9'-KYG)M<W)E9&EG97)I;F<N(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C$Q
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(DED96YT:71E=&5N(%PB)7-<(B!E
M<B!S;&5T=&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(DMU;B!V96YS=')E('-I9&4N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M(@IM<V=S='(@(E!L86-E<FEN9V5N(&%F($=N=5!'+7!R;V=R86UM970@<VMA
M;"!G:79E<R!T:6P@0W)Y<'1?<&=P.CHM:VQA<W-E;BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R(&QI8B](;W)D92]-24U%+TU$3BYP
M:'`Z,C`R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D
M:7-P;&%Y960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M
M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B
M(@HB0F5S:V5D96XL('-O;2!E<B!S96YD="!D96X@)7,@=&EL("5S(&UE9"!E
M;6YE="!<(B5S7"(@97(@8FQE=F5T('9I<W0N7&XB"B)$971T92!E<B!I;F=E
M;B!G87)A;G1I(&9O<BP@870@8F5S:V5D96X@<F5N="!F86MT:7-K(&5R(&)L
M979E="!LYG-T(&5L;&5R("(*(F9O<G-TY65T+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$X-S<@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-S<*;7-G
M:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O
M<V4@<&%G92(*;7-G<W1R(").879N970L(&1E<B!S:V%L(&)R=6=E+"!NY7(@
M9&5R(&AE;G9I<V5S('1I;"!S:W)I=F5S:61E;B(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0W-"!L:6(O1FEL92]#4U8N<&AP.C0W-`IM<V=I
M9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*;7-G
M<W1R(")!;G1A;&QE="!A9B!F96QT97(@<VMA;"!VYG)E(&5T('1A;"XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C,R"FUS9VED(")4:&4@;W!E;G-S;"!M
M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ
M(&-L87-S+B(*;7-G<W1R(")O<&5N<W-L+6UO9'5L970@97(@:W+F=F5T(&%F
M($AO<F1E7T-R>7!T7W-M:6UE.CHM:VQA<W-E;BXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,N<&AP.C(Y-2!L:6(O2&]R9&4O4')E9G,N<&AP.C(Y-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@
M8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@
M=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB4'+F
M9F5R96YC96X@7"(E<UPB(&MU;FYE(&EK:V4@9V5M;65S(&9O<F1I(&1E;G,@
M9&%T82!O=F5R<VMR:61E<B!D96X@(@HB;6%K<VEM86QT('1I;&QA9'1E('-T
M^')R96QS92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP
M:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N
M<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W
M;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN
M<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL
M:71E+G!H<#HS-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C,W(&QI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R<&TN<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H
M;&ET92YP:'`Z,S<*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP
M:'`Z,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+B(*;7-G<W1R("(B"B)0<F]G<F%M;65T+"!D97(@8G)U
M9V5S('1I;"!A="!B971R86=T92!D96YN92!D871A='EP92`H)7,I+"!B;&5V
M970@:6MK92`B"B)F=6YD970@<.4@<WES=&5M970N(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z-#@W(&QI8B]&:6QE+T-35BYP:'`Z-#@W"FUS
M9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C
M:&%R86-T97(N(@IM<V=S='(@(D-I=&%T:6]N<W1E9VYE="!S:V%L(';F<F4@
M970@96YK96QT('1E9VXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'DB"FUS9W-T<B`B2W5N(&CX:G)E(&]G('9E;G-T<F4@
M<VED92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*
M;7-G<W1R(")+=6X@<VED96X@=&EL(&CX:G)E(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z-#<Y(&QI8B]&:6QE+T-35BYP:'`Z-#<Y"FUS9VED
M(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N
M(@IM<V=S='(@(D%D<VMI;&QE;'-E<W1E9VYE="!S:V%L(';F<F4@970@96YK
M96QT('1E9VXN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E
M96X@9&5L971E9"XB"FUS9W-T<B`B4V5R=F5R96X@7"(E<UPB(&5R('-L971T
M970N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V
M960N(@IM<V=S='(@(E-E<G9E<F5N(%PB)7-<(B!E<B!G96UT+B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@
M(D]P<VMR:79N:6YG<V%N;6]D;FEN9V5N(&9O<B`E<R!E<B!S;&5T=&5T+B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M-#<P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#<P
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S<&5C:69I960@<F]W("@E9"D@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1E;B!A;F=I=FYE('+F:VME("@E
M9"D@96MS:7-T97)E<B!I:VME+B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C,S,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(D1E;B!A;F=I=FYE('+F:VME(&5K<VES=&5R97(@
M:6MK92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W.2!L:6(O
M5D93+W-Q;"YP:'`Z,3<Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP
M;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1E
M;B!M:61L97)T:61I9V4@9FEL(%PB)7-<(B!F:6YD97,@:6MK92XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`R(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S`R"FUS9VED(")4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA
M=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN(@IM<V=S='(@(D1E;B!T96MS
M="P@<V]M(&1U(&EN9'1A<W1E9&4L('!A<W-E<B!I:VME('1I;"!T96MS=&5N
M('#E('-KYG)M96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.0IM<V=I9"`B5&AE('1O<"!A;F0@8F]T=&]M
M('-I9&5S(&]N;'DB"FUS9W-T<B`B2W5N('1O<"!O9R!B=6YD(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM
M<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS9W-T<B`B2W5N('1O<"(*"B,Z
M(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C,R-R!L:6(O2&]R9&4O1&%T82YP
M:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC
M92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B1&5N(&%F<V5N9'1E(&EN
M9F]R;6%T:6]N(&5R('1A8G0@<VED96X@<VED<W1E('1R:6XN(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$
M871A+W1S=BYP:'`Z,3<R"B,Z(&QI8B](;W)D92]$871A+W1S=BYP:'`Z,3<R
M(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R"FUS9VED(")4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D1E;B!O=F5R
M9OAR=&4@9FEL(&MU;FYE(&EK:V4@9V5M;65S+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3$P"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B=V5A=&AE<BYC;VTM8FQO:VME;B!E<B!I:VME
M('1I;&?F;F=E;&EG+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N
M;W0@9F]U;F0N(@IM<V=S='(@(E1E;6$M:V%T86QO9V5T(%PB)7-<(B!I:VME
M(&9U;F1E="XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W
M."!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B5&AE<F4@87)E
M(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("));F=E;B!T:6QV86QG
M('1I;"!RY61I9VAE9"XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HS-3`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,U,`IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(D1E<B!F;W)E9FEN9&5S(&EN9V5N(&1E;&4L
M('-O;2!K86X@=FES97,@:6YD;&5J<F5T+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$T,#$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E
M<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T
M97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@
M(B(*(D1E<B!E<B!F;W(@;6%N9V4@=&5G;B!I(&1E='1E(&9E;'0N($1U(&AA
M<B!I;F1T87-T970@)7,@=&5G;CL@9'4@<VMA;"`B"B)I;F1T87-T92!M:6YD
M<F4@96YD("5S+B(*"B,Z('-I9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z
M-S,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A
M9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ("5S(@IM<V=S='(@(D1E<B!O
M<'-T;V0@970@<')O8FQE;2!U;F1E<B!T:6QF^&IE;'-E;B!A9B`G)7,G('1I
M;"!S>7-T96UE=#H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R
M("(B"B)$97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@9FIE<FYE;'-E(&%F
M(&1A=&$@9F]R(&)R=6=E<B!<(B5S7"(@9G)A("(*(G-Y<W1E;65T.B`B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M.B`B"FUS9W-T<B`B1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R('-L
M971N:6YG(&%F(%PB)7-<(B!F<F$@<WES=&5M970Z("(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C$U.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B1&5R(&]P<W1O
M9"!E="!P<F]B;&5M('5N9&5R(&]P9&%T97)I;F<@868@7"(E<UPB.B`E<R(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDR-R!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.3(W"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A
M<R!U<&QO861E9"XB"FUS9W-T<B`B1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N
M9&5R(&9I;&]V97)F^')S;&5N.B!);F=E;B`E<R!B;&5V(&]V97)F^')T+B(*
M"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.CDS,B!L:6(O2&]R
M9&4O0G)O=W-E<BYP:'`Z.3,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE
M("@E9"!B>71E<RDN(@IM<V=S='(@(B(*(D1E<B!O<'-T;V0@970@<')O8FQE
M;2!U;F1E<B!F:6QO=F5R9OAR<VQE;CH@)7,@=F%R('-T^')R92!E;F0@9&5N
M(&UA:W-I;6%L="`B"B)T:6QL861T92!S=/AR<F5L<V4@*"5D(&)Y=&5S*2XB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HY,S0@;&EB+TAO
M<F1E+T)R;W=S97(N<&AP.CDS-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@
M)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B"B)$
M97(@;W!S=&]D(&5T('!R;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ("5S
M(&)L978@:W5N(&1E;'9I<W0@;W9E<F;X<G0N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS-0HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HS-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0B"FUS9W-T<B`B1&5R
M(&]P<W1O9"!E;B!F96IL('5N9&5R('9I<VYI;F<@868@9&5N;F4@8F5S:V5D
M9&5L(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT
M."!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T
M<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R:6YG96X@868@
M:V]N=&%K=&EN9F]R;6%T:6]N+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O
M:6UC+G!H<#HS,2!L:6(O2&]R9&4O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82XB"FUS9W-T<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R
M:6YG96X@868@:4-A;&5N9&%R(&1A=&$N(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HX,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H
M92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@
M(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D1E<B!O<'-T;V0@96X@
M9F5J;"!I(&MO;F9I9W5R871I;VYS9F]R;75L87)E;BX@3G5L:6=V:7,@:&%R
M(&1U('5D96QA9'0@970@(@HB:W+F=F5T(&9E;'0N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(D1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!U9&;X<F5L
M<V4@868@9&5N(&%N9VEV;F4@(@HB861R97-S96MA<G1O=&5K<V9U;FMT:6]N
M+B!0<OAV(&EG96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T
M:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N(@IM<V=S='(@(D1E<B!O<'-T;V0@96X@9F5J;"!U;F1E<B!O<&1A=&5R
M:6YG(&%F(&MO;G1A:W0M9&5T86QJ97)N92X@4'+X=B!I9V5N+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#4*(SH@;&EB+TYE="]335,O
M=VEN7VAT='`N<&AP.C(R,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A
M9V%I;B!L871E<BXB"FUS9W-T<B`B1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R
M(&]P9&%T97)I;F<@868@9&ES=')I8G5T:6]N<VQI<W1E;BX@4'+X=B!I9V5N
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T
M."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,30X"FUS9VED(")4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+B(*;7-G<W1R(")$96YN92!)34%0+7-E<G9E<B!U;F1E<G-T^'1T97(@
M:6MK92!D96QI;F<@868@;6%P<&5R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-#@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(D1E='1E('1Y9&5R(&EK:V4@
M<.4@870@=N9R92!E="!G>6QD:6=T(')A<BUA<FMI=BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R(&QI8B](;W)D92]-24U%
M+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")$96YN92!T>61E
M<B!I:VME('#E(&%T(';F<F4@96X@9WEL9&EG('II<"UF:6PN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$R-PIM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(D1E='1E('1Y9&5R(&EK:V4@<.4@870@
M=N9R92!E="!G>6QD:6=T(&MO<G1N=6UM97(N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#
M;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL
M('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$96YN92!D<FEV97(@
M=&EL;&%D97(@869S96YD96QS92!A9B!B97-K961E<B!I9V5N;F5M($-L:6-K
M871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@861G86YG<W!U;FMT
M970@=F5D(&)R=6<@868@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$S-"!L:6(O3F5T+U--4R]W:6Y?:'1T<"YP
M:'`Z,3,T"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M
M*2`B"B)G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@HB
M1&5N;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@
M:6=E;FYE;2!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2`B"B)A9&=A;F=S<'5N
M:W1E="!V960@8G)U9R!A9B!(5%10($%022(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E
M;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG
M('1H92!(5%10($%022(*;7-G<W1R("(B"B)$96YN92!D<FEV97(@=&EL;&%D
M97(@869S96YD96QS92!A9B!B97-K961E<B!I9V5N;F5M('-M<S)E;6%I;"`H
M:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&%D9V%N9W-P=6YK=&5T('9E9"!B
M<G5G(&%F($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*(SH@;&EB+TYE="]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL
M;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@
M5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N
M=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB
M5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B
M(@HB1&5N;F4@9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D
M97(@=FEA(%--5%`@:6=E;FYE;2!6;V1A9F]N92`B"B))=&%L:65N(&%D9V%N
M9W-P=6YK=&5T+"!D;V<@:W5N('1I;"!6;V1A9F]N92UN=6UR92X@1&5N(&MR
MYG9E<B!E;B!E+2(*(FUA:6QK;VYT;R!H;W,@5F]D869O;F4@271A;&EE;B`H
M:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.CDW."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$Q-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3,P-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3@S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`R.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C(R,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#`X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3`*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C8S-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$P
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(Y-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M.#`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,3,*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.CDW."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`U-R!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3`X-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q-2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(U
M-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3,Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,34U-PHC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@S.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU."!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C`P-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R.2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C`W."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$T
M.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(R,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C0P."!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0U,`HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C8S-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$Q.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(Y-R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S@P-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S@Q
M,PIM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T<B`B1&5T
M=&4@9F5L="!E<B!K<N9V970N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3`V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")$971T
M92!F96QT(&WE(&MU;B!I;F1E:&]L9&4@:&5L=&%L+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(T,38@;&EB+TAO<F1E+T9O<FTN<&AP.C(T,38*
M;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N
M9"!T:&4@8V]L;VXN(@IM<V=S='(@(D1E='1E(&9E;'0@;>4@:W5N(&EN9&5H
M;VQD92!N=6UR92!O9R!K;VQO;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#DT(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R
M(")$971T92!F96QT(&WE(&MU;B!I;F1E:&]L9&4@;VMT86QE(';F<F1I97(N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$R,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T
M<B`B(@HB1&5T=&4@9F5L="!S:V%L(';F<F4@96X@:V]M;6$M(&5L;&5R(&UE
M;&QE;7)U;7-A9'-K:6QD="!L:7-T92!A9B!H96QT86PB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY.#D@;&EB+TAO<F1E+T9O<FTN<&AP.CDX.0IM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G
M<W1R(")$971T92!F96QT('-K86P@=N9R92!E="!G>6QD:6=T(&YU;6UE<BXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$X(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#$X"FUS9VED("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I
M;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA
M;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(D1E='1E(&9E;'0@<VMA;"!I
M;F1E:&]L9&4@96X@9F%R=F5K;V1E(&D@4D="(&AE>"UF;W)M870L(&9X("<C
M,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C$@;&EB
M+TAO<F1E+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E
M861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")$96YN92!F;W)M=6QA<B!E
M<B!A;&QE<F5D92!P<F]C97-S97)E="XB"@HC.B!T96UP;&%T97,O:&5L<"]A
M8F]U="YI;F,Z,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&ES(&ES("5S+B(*
M;7-G<W1R(")$971T92!E<B`E<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.C0V.2!L:6(O2&]R9&4O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C
M="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL
M("(*(F-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A
M<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,B"FUS9W-T<B`B(@HB1&5T=&4@97(@970@2V]L
M86(@1W)O=7!W87)E+6]B:F5K="X@1F]R(&%T('-E(&1E='1E(&]B:F5K="!H
M87(@9'4@8G)U9R!F;W(@(@HB96X@92UM86EL+6ML:65N="P@<V]M(&9O<G-T
MY7(@2V]L86(@1W)O=7!W87)E+69O<FUA=&5T+B!"97/X9R`E<R!F;W(@96X@
M(@HB;&ES=&4@868@:VQI96YT97(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]#;VYT96YT<RYP:'`Z-3DY(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H
M<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(D1E;FYE(&)E<VME9"!E<B!S:W)E=F5T(&UE9"!E
M="!A;F1E="!T96=N<^9T("@E<RD@96YD(&1I="!E9V5T+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`B5&%L;&5T('-K86P@=N9R92!M:6XN(#$N(@H*(SH@
M9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0U(&QI8B](
M;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@
M(D1E;FYE('-E<G9E<B!K86X@:6MK92!D96MO;7!R:6UE<F4@>FEP+2!O9R!G
M>FEP+69I;&5R+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3@Y(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@
M(D1E='1E('-Y<W1E;2!E<B!D96%K=&EV97)E="XB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C$R-"!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G
M<W1R(")$96YN92!VYG)D:2!S:V%L(';F<F4@970@=&%L+B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS
M9W-T<B`B1&5T=&4@=FEN9'5E('-K86P@:V%L9&5S(&9R82!E="!4:6QV86QG
M<W9I;F1U92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8V"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E1O<F1E;B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I8VME=',B"FUS
M9W-T<B`B4V%G97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(U
M(&QI8B](;W)D92]&;W)M+G!H<#HR-#(U"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(U-0IM<V=I9"`B5&EM92(*;7-G<W1R(")4:60B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K
M:6YG(@IM<V=S='(@(E1I9'-O<&?X<F5L<V4B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,3<*;7-G:60@(E1I;64@9F]R;6%T(@IM<V=S='(@(E1I9'-F;W)M
M870B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Q(&QI8B](;W)D
M92]&;W)M+G!H<#HR-3,Q"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R
M(")4:61S=F%L9R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&EM;W(M3&5S=&4B
M"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C(Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED
M(")4:71L92(*;7-G<W1R(")4:71E;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP
M*3HB"FUS9W-T<B`B5&ET;&4@*'1O;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)F8S@R,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E1I
M;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-30*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM
M<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@
M=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL
M92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HB1F]R(&%T(';F;&=E(&UU;'1I<&QE
M(&EN9&=A;F=E('-K86P@0W1R;"T@*%!#*2!E;&QE<B!#;VUM86YD("A-86,I
M+71A<W1E;B`B"B)H;VQD97,@;F5D92!M961E;G,@9&5R(&ML:6MK97,N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,P,`IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`B22!$86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B
M"FUS9W-T<B`B4VMI9G0@2%1-3"UK:6QD92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R,PHC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(T"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4
M;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("))(&UO
M<F=E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N
M9V$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B+G!H<#HQ,#0@;&EB
M+TAO<F1E+T%U=&@O:V]L86(N<&AP.C$P-`IM<V=I9"`B5&]O(&UA;GD@:6YV
M86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N(@IM<V=S='(@
M(D9O<B!M86YG92!U9WEL9&EG92!L;V=I;F0M9F]R<_AG(&D@;/AB970@868@
M9&4@<VED<W1E(&UI;G5T=&5R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,0IM<V=I9"`B5&]P(@IM<V=S='(@
M(E1O<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B5&]P(&9R
M86UE("A?=&]P*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I
M9"`B5')A;G-L871I;VYS(@IM<V=S='(@(D]V97)SYG1T96QS97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B
M5')I;FED860@;V<@5&]B86=O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3<Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<Y,`IM<V=I9"`B5')U92!O
M<B!F86QS92(*;7-G<W1R(")386YD(&5L;&5R(&9A;'-K(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B
M"FUS9W-T<B`B5&ER(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C@@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=6YI<VEA(@IM
M<V=S='(@(E1U;F5S:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=7)K97DB
M"FUS9W-T<B`B5'ER:VEE="(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DU
M"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4>7)K:7-K
M("A)4T\M.#@U.2TY*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES
M=&%N(@IM<V=S='(@(E1U<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I
M9"`B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(@IM<V=S='(@(E1U<FMS(&]G
M($-A:6-O<R#897)N92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM
M<V=S='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0@
M;&EB+TAO<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E
M.B`B"FUS9W-T<B`B4VMR:78@9&ET('9A;&<Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3@*;7-G:60@(E4N5BX@:6YD97@Z("(*;7-G
M<W1R(")5+E8N+6EN9&5K<SH@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(T.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B
M55),(@IM<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-30Q"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I<'0@9&5L
M:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@9F]R('-K<FEP="!T
M:6P@;6]D=&%G96QS92!A9B!S=&%T=7,@<F%P<&]R=&5N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),
M.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B
M"FUS9W-T<B`B56=A;F1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")5:W)A:6YE
M(@IM<V=S='(@(E5K<F%I;F4B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,3D@;&EB+U9&4R]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T
M;R!A8V-E<W,@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B2W5N;F4@:6MK92!T
M:6QGY2!61E,M:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I
M9VYU<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I
M9"`B56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@
M<VEG;FEN9R!U<"XB"FUS9W-T<B`B2V%N(&EK:V4@=&EL9OAJ92!E:W-T<F$@
M8G)U9V5R(&EN9F]R;6%T:6]N('5N9&5R(&]P<VMR:79N:6YG+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,SDS(&QI8B]61E,O9G1P+G!H<#HS
M.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME
M(.9N9')E('1I;&QA9&5L<V5R(&9O<B!61E,M9FEL(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS.3(@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C0V.`HC.B!L:6(O5D93+V9I;&4N<&AP.C,Y,B!L:6(O
M5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B2V%N(&EK:V4@YFYD<F4@=&EL;&%D96QS97(@9F]R(%9&4RUF:6P@
M)7,O)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.#8@;&EB
M+U9&4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(")+86X@:6MK92!S:VEF=&4@=&EL
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,W(&QI8B]6
M1E,O9G1P+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME
M('1J96MK92!F:6QS=/AR<F5L<V5N(&%F(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV.34@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HQ,#(X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HX
M-3`@;&EB+U9&4R]F:6QE+G!H<#HV.34*(SH@;&EB+U9&4R]S<6PN<&AP.C$P
M,C@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z.#4P"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*
M;7-G<W1R(")+86X@:6MK92!T:F5K:V4@9FEL<W3X<G)E;'-E;B!A9B!<(B5S
M+R5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S.2!L
M:6(O2&]R9&4O075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!FY2!F
M;W)B:6YD96QS92!T:6P@4U%,('-E<G9E<F5N+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z.#<P(&QI8B]61E,O9G1P+G!H<#HX-S`*;7-G:60@
M(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(")+86X@:6MK
M92!FY2!F;W)B:6YD96QS92!M960@4U-,+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C(S,B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR
M,S<*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P-"!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<#HR,3<@;&EB+U9&4R]F:6QE+G!H<#HR,S(*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HR,S<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z
M,C`T(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HR,3<*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*
M;7-G<W1R(")+86X@:6MK92!K;W!I97)E(%9&4RUF:6PN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS-S`@;&EB+U9&4R]F='`N<&AP.C,W,`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!D86YN92!61E,M:V%T
M86QO9R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,S8Q(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(V-"!L:6(O5D93+V9I;&4N<&AP
M.C,V,0HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I:VME(&1A;FYE(%9&4RUK871A;&]G+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*
M;7-G<W1R(")+86X@:6MK92!L879E(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HR.3`@;&EB+U9&4R]S;6(N<&AP.C(Y,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@
M7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!O<')E='1E(%9&4RUM87!P92!<
M(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C<R(&QI
M8B]61E,O9FEL92YP:'`Z,C<R"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!L879E('1O;2!61E,M
M9FEL+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW
M-B!L:6(O2&]R9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+W1A<BYP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!D96-O;7!R
M97-S(&1A=&$N(@IM<V=S='(@(DMA;B!I:VME(&1E:V]M<')I;65R92!D871A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S`S(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z,C(X"B,Z(&QI8B]61E,O9G1P+G!H<#HS,#,@
M;&EB+U9&4R]S;6(N<&AP.C(R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(DMA;B!I:VME('-L971T92!<(B5S7"([(&MA=&%L;V=E
M="!E<B!I:VME('1O;70N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW."!A9&UI
M;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B2V%N(&EK:V4@
M<VQE='1E(%PB)7-<(CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS.34@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C,T,@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S."!L
M:6(O5D93+VUU<W%L+G!H<#HS,3$@;&EB+U9&4R]S<6PN<&AP.C,Y-0HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E("5S.R!K871A;&]G970@97(@
M:6MK92!T;VUT(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C,U-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"B,Z(&QI
M8B]61E,O<W%L7V9I;&4N<&AP.C,U-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS
M-C`*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U
M<G-I=F5L>2XB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(%9&4RUK871A;&]G
M970@<F5K=7)S:79T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,T-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,T,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,S4R(&QI8B]61E,O9FEL92YP:'`Z,S0T"B,Z(&QI8B]61E,O;75S<6PN
M<&AP.C,R,B!L:6(O5D93+VUU<W%L+G!H<#HS,S4@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S0S"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,U,@IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK
M92!S;&5T=&4@5D93+6MA=&%L;V<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S(*(SH@
M;&EB+U9&4R]S<6PN<&AP.C0R,"!L:6(O5D93+W-Q;"YP:'`Z-#,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>3H@)7,N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!61E,M:V%T86QO9SH@
M)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,3(@;&EB+U9&
M4R]F='`N<&AP.C(Q,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE
M='1E(%9&4RUF:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C(Y,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D@;&EB+U9&4R]F
M:6QE+G!H<#HS,3`*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W(&QI8B]61E,O
M;75S<6PN<&AP.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<*(SH@;&EB+U9&
M4R]S<6PN<&AP.C(Y,2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.3$@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,SDY"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@5D93+69I;"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(T."!L:6(O5D93+W-M8BYP
M:'`Z,C0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME('-L971T92!6
M1E,M;6%P<&4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`Z-#`Y(&QI8B]61E,O<W%L+G!H<#HT,#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+B(*;7-G
M<W1R(")+86X@:6MK92!S;&5T=&4@5D93(')E:W5R<VEV=#H@)7,N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,S0@;&EB+U9&4R]F='`N<&AP
M.C@S-`IM<V=I9"`B56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C
M=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@8F5S=&5M;64@86MT=65L="!K871A
M;&]G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C`T
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"FUS9VED(")5;F%B;&4@
M=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS(@IM<V=S='(@(DMA;B!I
M:VME('5D9')A9V4@8V5R=&EF:6MA="UD971A;&IE<B(*"B,Z(&9R86UE=V]R
M:R].971?24U34"])35-0+G!H<#HT,S<@9G)A;65W;W)K+TYE=%])35-0+TE-
M4U`O075T:"YP:'`Z,3(S"B,Z(&QI8B].970O24U34"YP:'`Z-#,W(&QI8B].
M970O24U34"]!=71H+G!H<#HQ,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(DMA
M;B!I:VME(&EN9&SF<V4@9&5F:6YI=&EO;F5N(&%F("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,R!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,#@*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$W-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3<Y"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C`S(&QI8B]61E,O9FEL92YP:'`Z,C`X(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C$W-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ
M-SD*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")+
M86X@:6MK92!F;'ET=&4@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.CDX(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z.3,*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HQ,#8@9G)A;65W;W)K+U9&4R]6
M1E,O<VUB+G!H<#HV-3(*(SH@;&EB+U9&4R]F='`N<&AP.CDX(&QI8B]61E,O
M<VUB+G!H<#HY,R!L:6(O5D93+W-M8BYP:'`Z,3`V"B,Z(&QI8B]61E,O<VUB
M+G!H<#HV-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92#E8FYE(%9&4RUF
M:6P@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(X
M-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,X"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-#$@;&EB+U9&4R]F:6QE+G!H
M<#HR.#0*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3,X(&QI8B]61E,O<W%L
M7V9I;&4N<&AP.C$T,0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N(@IM<V=S='(@(DMA;B!I:VME(.5B;F4@5D93+69I;"!T
M:6P@<VMR:79N:6YG+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C@S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S8@;&EB+U9&4R]F:6QE+G!H<#HX
M,R!L:6(O5D93+V9I;&4N<&AP.C$S-PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM<V=S='(@
M(DMA;B!I:VME(.5B;F4@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C0U(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C0U"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(DMA;B!I:VME(.5B;F4@:V]M<')I;65R970@87)K
M:78N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@U-B!L:6(O5D93+G!H
M<#HX-38*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ
M92@I(&9A:6QE9"DN(@IM<V=S='(@(DMA;B!I:VME(&SF<V4@5D93+69I;"`H
M9FEL97-I>F4H*2!F96IL961E*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP
M:'`Z.#@W(&QI8B]61E,N<&AP.C@X-PIM<V=I9"`B56YA8FQE('1O(')E860@
M5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N
M(&EK:V4@;.9S92!61E,M9FEL("AG971&:6QE4VEZ92@I(&9E:FQE9&4I+B(*
M"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]N
M;VYE+G!H<#HS.`HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;F]N92YP
M:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D(&9I;&4Z("(*;7-G<W1R(")+
M86X@:6MK92!LYG-E(&9I;#H@(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z-C<V(&QI8B]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@
M=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I
M:VME(&SF<V4@=F9S<F]O="UK871A;&]G970N(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,3`Y(&QI8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M2V%N(&EK:V4@;VUD^&)E("5S('1I;"`E<SH@;>5L;6%P<&5N(&9I;F1E<R!A
M;&QE<F5D92(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,#$@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I:VME(&]M9/AB
M92!61E,M:V%T86QO9RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,S,B!L:6(O5D93+W-Q;"YP:'`Z,S,R"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N(@IM<V=S='(@
M(DMA;B!I:VME(&]M9/AB92!61E,M:V%T86QO9SH@)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR-S$*(SH@;&EB+U9&4R]F='`N<&AP.C,T."!L:6(O5D93+W-M8BYP
M:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!O;63X8F4@5D93
M+69I;"!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M-C$W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(SH@;&EB+U9&
M4R]F:6QE+G!H<#HV,3<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M(@IM<V=S='(@(DMA;B!I:VME(&]M9/AB92!61E,M9FEL("5S+R5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0U,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C,R-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#D@;&EB+U9&4R]M
M=7-Q;"YP:'`Z,C$S"B,Z(&QI8B]61E,O;75S<6PN<&AP.C0U,B!L:6(O5D93
M+W-Q;"YP:'`Z,S(V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@
M5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&]M9/AB92!61E,M9FEL+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S
M+G!H<#HU,`HC.B!L:6(O5D93+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,`IM
M<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(DMA;B!I
M:VME(&%F=FEK;&4@)VUK:7-O9G,G+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DMU;FYE(&EK:V4@;W9E<G/F
M='1E(&1E='1E(%=O<F0@9&]K=6UE;G0B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C$U-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U-PHC
M.B!L:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB
M)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@<VMR:79E(%9&4RUF:6P@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$X-B!L:6(O5D93
M+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N(&EK:V4@<VMR:79E(%9&
M4RUF:6P@*&-O<'DH*2!F96IL961E*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR.#@@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$T-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,34Q(&QI
M8B]61E,O9FEL92YP:'`Z,C@X"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$T
M-B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-3$*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(")+86X@:6MK92!S:W)I=F4@
M5D93+69I;&1A=&$N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V,B!L
M:6(O5D93+G!H<#HX-C(*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"XB"FUS9W-T<B`B2V%N(&EK:V4@
M<VMR:79E(%9&4RUF:6P[(&MV;W1E;B!V:6P@8FQI=F4@;W9E<G-K<F5D970N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E5N9&5R;&EN:65R970B"@HC
M.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED(")5;F1O($-H86YG
M97,B"FUS9W-T<B`B1F]R=')Y9"#F;F1R:6YG97(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@
M>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")/;6?X<B!D:6X@<VED<W1E(&AA
M;F1L:6YG(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(Q"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,X."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(Q"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM
M<V=S='(@(E5V96YT970@<F5A:W1I;VX@9G)A('-E<G9E<B!PY2!F;W)B:6YD
M96QS96XZ("(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C(Q-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS,SD*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S<V"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M,B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C$W"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,SD@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,W-@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S@R"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@
M<V5R=F5R('1O.B`B"FUS9W-T<B`B579E;G1E="!R96%K=&EO;B!F<F$@<V5R
M=F5R('#E.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HU-PHC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HU-PHC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M
M96YT+FEN8SHV,0IM<V=I9"`B56YF:6QE9"(*;7-G<W1R(")):VME(&%N8G)A
M9W0B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B56YI8V]D
M92`H551&+3@I(@IM<V=S='(@(E5N:6-O9&4@*%541BTX*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V
M"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G<W1R(")&;W)E;F5D
M92!!<F%B:7-K92!%;6ER871E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E
M9"!+:6YG9&]M(@IM<V=S='(@(E-T;W)B<FET=&%N:65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM<V=S='(@(E5302(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S-PHC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Y(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)
M<VQA;F1S(@IM<V=S='(@(E5307,@=6YD97)O<F1N961E(/AE<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z-S@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8R"FUS9VED(")5;FET<R(*;7-G<W1R(")%;FAE9&5R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU."!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#,P(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP
M.C4X"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0R.2!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,S`*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B56ME
M;F1T(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,CDX"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M(@IM<V=S='(@(E5K96YD="!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y.0IM
M<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*
M;7-G<W1R(")5:V5N9'0@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2XB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS9VED(")5
M;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")5:V5N9'0@<W1E
M9"!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"XB"FUS9W-T<B`B56ME;F1T(&)R=6=E<FYA=FX@96QL97(@:V]D96]R9"XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3@*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT(@IM
M<V=S='(@(DCF9W0@86MT=65L="!E;&5M96YT(&%F+B(*"B,Z(&9R86UE=V]R
M:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`R(&QI8B](;W)D92])9&5N=&ET
M>2YP:'`Z,S`R"FUS9VED(")5;FYA;65D(@IM<V=S='(@(DEK:V4@;F%V;F=I
M=F5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU.0IM<V=I9"`B(@HB56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R("(*(G-E
M8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@
M;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O
M(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G
M<W1R("(B"B)5<')I=FEL:6=E<F5D92!S:W)I<'1E<B!K86X@:6MK92!T:6QG
MY2!K;&EP<&4O:V]P:2]I;F1SYG0@<')O9W)A;6WF<W-I9W0@868@(@HB<VEK
M:V5R:&5D<^5R<V%G97(N("!+;&EK($]+(&9O<B!A="!S92!E;B!T96MN:7-K
M(&YO=&4@:&]S(&UO>FEL;&$N;W)G+"!S;VT@(@HB=FES97(@9&EG+"!H=F]R
M9&%N(&1U(&MA;B!T:6QL861E(&5T('-K<FEP="!A="!T:6QGY2!U9&ML:7!S
M:&]L9&5R96XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B
M1F%R=F4@:6MK92!I;F1S=&EL;&5T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#<@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,C<*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,S,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.#<*(SH@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HY,C<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HY,S,*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(")5
M9'9I9&1E;'-E(&EK:V4@=6YD97)S=/AT=&5T(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.3<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ
M.3<*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@
M(E5P9&%T92(*;7-G<W1R(")/<&1A=.ER(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O=7!D871E+FEN8SHR.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&4@)7,B"FUS9W-T<B`B3W!D873I<B`E<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S
M='(@(D]P9&%TZ7(@8G)U9V5R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@
M861M:6XO<&5R;7,O961I="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HR,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N
M(@IM<V=S='(@(EPB)7-<(B!O<&1A=&5R970N(@H*(SH@861M:6XO<V5T=7`O
M<V-R:7!T<RYP:'`Z.#,*;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M(@IM<V=S='(@(D]P9W)A9&5R:6YG<RUF;W)E<VMR:69T('-L971T970N(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ.3@*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")5
M<&QO860B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5
M<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E
M<G9E<BXB"FUS9W-T<B`B3W!SYG1N:6YG<V9I;&5R('1I;"!A;&QE(&%P<&QI
M:V%T:6]N97(@;&%G="!O<"!PY2!S97)V97(N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B
M57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")3=&]R92!L871I;G-K92!B
M;V=S=&%V97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S
M(@IM<V=S='(@(E-T;W)E(')O;65R=&%L(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED
M(")5<G5G=6%Y(@IM<V=S='(@(E5R=6=U87DB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC.B!L:6(O2&]R9&4O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5<V4@0W5R<F5N=#H@)7,B"FUS9W-T<B`B06YV96YD(&YU=N9R96YD
M93H@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4S.`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S='(@(D)R=6<@4U-,(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S
M<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B
M0G)U9R!H=FES(&YA=FXO:V]D96]R9"!E<B!F;W)S:V5L;&EG(&9O<B!)35-0
M+7-E<G9E<BXB"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C(Q"FUS9VED(")5<V5R(@IM<V=S='(@(D)R=6=E<B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T(&QI8B](;W)D92]296=I
M<W1R>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")"<G5G97(@)7,@:6MK
M92!B96UY;F1I9V5T('1I;"`E<RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HR,#,*
M;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS9W-T<B`B0G)U9V5R+6%D
M;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HR-#4@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR-#4*;7-G:60@(E5S97(@
M3W!T:6]N<R(*;7-G<W1R(")"<G5G97)I;F1S=&EL;&EN9V5R(@H*(SH@<VEG
M;G5P+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B
M0G)U9V5R+7)E9VES=')E<FEN9R(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@
M(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N(@IM<V=S='(@(D)R=6=E<BUR96=I<W1R97)I;F<@97(@8FQE=F5T
M('-LY65T(&9R82!PY2!D971T92!W96)S=&5D+B(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT.30*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B
M"FUS9W-T<B`B0G)U9V5R:V]N=&\@:6MK92!F=6YD970B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$U
M,"!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,V"B,Z(&QI8B].
M970O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@;&EB+TYE="]335,O=VEN7VAT
M='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(")"
M<G5G97)N879N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C$R-"!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N(@IM
M<V=S='(@(D)R=6=E<FYA=FX@7"(E<UPB(&9I;F1E<R!A;&QE<F5D92XB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R(")"<G5G97)N879N.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B0G)U
M9V5R;F%V;CH@(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B0G)U9V5R
M92!I('-Y<W1E;65T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,SD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB96MI<W1A
M;B(*;7-G<W1R(")5<V)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3<P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V,@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP.C(V,@IM
M<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B
M5D93+6MA=&%L;V<@96MS:7-T97)E<B!I:VME+B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HQ,C`*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(D9E
M<FEE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#8V(&QI8B](;W)D
M92]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B`B"FUS9W-T<B`B1WEL9&EG92!F=6YD970@<W1E9&5R(&EN:VQU
M9&5R97(Z(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV
M,SD@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,SD*;7-G:60@(E9A;&ED
M:71Y(@IM<V=S='(@(D=Y;&1I9VAE9"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C4U"FUS9VED(")686QU92!I;B!M:6YU=&5S(&9R;VT@
M;F]W+B(*;7-G<W1R(")6YG)D:2!E<B!M:6YU='1E<B!F<F$@;G4N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Q-S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@U-B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS9VED(")686QU92!I
M<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B5N9R
M9&D@97(@;65R92!E;F0@9&5N(&UA:W-I;6%L92!LYFYG9&4@868@)7,N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ,`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0T"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C8V(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S$V(&QI8B](;W)D92]&;W)M+G!H<#HR.3$P"B,Z(&QI
M8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B5N9R9&EE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C$P.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-@IM
M<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E;F<F1I97(L
M(&1E<B!K86X@=N9L9V5S(&EB;&%N9'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E-K
M:69T96YD92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0U(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S
M='(@(E9E;F5Z=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,C$X(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED
M(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B169T97)P<OAV;FEN9R!F
M96IL961E("T@9&5R(&5R(&)L979E="!P:6QL970@=F5D(&1E;FYE(&)E<VME
M9"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*
M;7-G<W1R(")697)S:6]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(R.`IM<V=I9"`B5F5R<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I;VYS
M:V]N=')O;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@
M(DQO9')E="!O<'-T:6QL:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHX-`IM<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*
M;7-G<W1R("),;V1R970@9F]R<FEN9R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G
M<W1R("),;V1R970Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-S(*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R(")-96=E="!H
M^&HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#(*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I970@3F%M(@IM<V=S='(@(E9I
M971N86TB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-PIM<V=I9"`B5FEE
M=&YA;65S92`H5DE30TE)*2(*;7-G<W1R(")6:65T;F%M97-I<VL@*%9)4T-)
M22DB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HY-S$@
M;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.CDW,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W("5S(@IM<V=S='(@(E9I<R`E<R(*"B,Z(&QI8B]";&]C
M:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N86P@=V5B('!A
M9V4B"FUS9W-T<B`B4V4@<.4@96MS=&5R;B!W96)S:61E(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,P(&QI8B](;W)D92]-24U%
M+T-O;G1E;G1S+G!H<#HX,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A
M<R`E<R(*;7-G<W1R(")6:7,@<V]M("5S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED
M(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R(")*;VUF<G7X97(L
M($)R:71I<VME(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0T"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD
M<RP@52Y3+B(*;7-G<W1R(")*;VUF<G7X97(L($%M97)I:V%N<VME(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS
M9W-T<B`B4WEN;&EG:&5D(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E-Y;FQI9VAE
M9#H@(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#0*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P
M+G!H<#HX-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T
M<B`B5F]D869O;F4@271A;&EE;B!V:6$@4TU44"(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S8*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,V"FUS9VED(")705).(@IM<V=S='(@(E=!4DXB"@HC.B!A9&UI;B]S
M971U<"]S8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).
M24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T
M<B`B041605)314PA(2$@1DI%4DX@4T-225!4($U!3E5%3%0@1E)!("5S+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S(&QI
M8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S,*;7-G:60@(E=)3B!V:6$@2%14
M4"(*;7-G<W1R(")724X@=FEA($A45%`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@
M(E=A;&QI<R!A;F0@1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!O9R!&=71U;F$B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VAT;6PN<&AP.C$R-PHC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VAT;6PN<&AP.C$R-R!L:6(O0FQO8VLO86-C;W5N="YP:'`Z.34*;7-G:60@
M(E=A<FYI;F<B"FUS9W-T<B`B061V87)S96PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R
M(")/;G,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G
M:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B5F5J<G5D<VEG="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,38*;7-G:60@(E=E871H
M97(@9&%T82!P<F]V:61E9"!B>2(*;7-G<W1R(")696IR:6YF;W)M871I;VX@
M<W1I;&QE="!T:6QRY61I9VAE9"!A9B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C@Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DR"FUS9VED(")796%T
M:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]";&]C:R]G
M;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S.0IM<V=I9"`B5V5B(%-I=&4B"FUS
M9W-T<B`B5V5B<VET92(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3@@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HU.`IM
M<V=I9"`B5V5E:VQY(@IM<V=S='(@(E5G96YT;&EG(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+VUO8FEL92YP:'`Z,C@*;7-G:60@(E=E;&-O;64B"FUS9W-T<B`B
M5F5L:V]M;65N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-R!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHT"B,L('!H<"UF;W)M870*;7-G
M:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T<B`B5F5L:V]M;65N('1I;"`E<R(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E;7!L871E<R]P
M;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE
M+"`E<R(*;7-G<W1R(")696QK;VUM96XL("5S(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$I(@IM<V=S
M='(@(E9E<W1L:6<@*$E33RTX.#4Y+3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3D*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y+3$U*2(*;7-G<W1R
M(")697-T;&EG("A)4T\M.#@U.2TQ-2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0V"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HW."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B5V5S
M=&5R;B!386AA<F$B"FUS9W-T<B`B5F5S='-A:&%R82(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT-#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VAA="!A
M<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\B"FUS
M9W-T<B`B2'9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L("5S('9I<V4@969T97(@
M;&]G:6YD/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$T"FUS
M9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R
M(")(=F%D(&5R('-E<&%R871O<G1E9VYE=#\B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@<75O=&4@8VAA
M<F%C=&5R/R(*;7-G<W1R(")(=F%D(&5R(&-I=&%T:6]N<W1E9VYE=#\B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`V-0IM<V=I
M9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S='(@(E=H97)E:7,@075S
M=')A;&EE;BUK;W)T(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS9VED
M(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2'9I;&ME(&9A<V5R(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")(
M=FEL:V4@<&QU9VEN<R!S:V%L(&%K=&EV97)E<R!F;W(@4FEC:"!497AT+7;F
M<FMT^&IE="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R(")"<F5D9&4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`W(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`W"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T
M<B`B0G)E9&1E(&D@0U-3+65N:&5D97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S8Q"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E
M<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M
M:6XI.B(*;7-G<W1R(")"<F5D9&4@868@)7,M;65N=65N('1I;"!V96YS=')E
M("AB;&EV97(@86MT:79E<F5T('9E9"!NYG-T92!L;V=I;F0I.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED
M(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B0G)E9&1E(&%F('1A8F5L
M;&5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3`*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B0G)E9&1E+65N:&5D
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R(")"<F5D9&4Z(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7
M:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B5VEN
M9"(*;7-G<W1R(")6:6YD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-C@*;7-G:60@(E=I;F0@16%R;'DB"FUS9W-T<B`B0FSF
M<W0@=&ED;&EG="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z.#<*;7-G:60@
M(E=I;F0@<W!E960@:6X@:VYO=',B"FUS9W-T<B`B5FEN9&AA<W1I9VAE9"!I
M(&MN;V(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$V,PIM<V=I9"`B5VEN
M9#HB"FUS9W-T<B`B5FEN9#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5FEN9#H@(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS9VED(")7:7-D;VTB"FUS9W-T
M<B`B5FES9&]M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`BV&YS:V5L:7-T92(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")!<F)E
M:F1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,38T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3(T(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38T"FUS9VED(")7;W)K
M($%D9')E<W,B"FUS9W-T<B`B061R97-S92`H87)B96ID92DB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H
M;VYE(@IM<V=S='(@(E1E;&5F;VX@*&%R8F5J9&4I(@H*(SH@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,3DS(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N
M<&AP.C(Y-`HC.B!L:6(O1FEL92]#4U8N<&AP.C$Y,R!L:6(O1FEL92]#4U8N
M<&AP.C(Y-`HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS
M9W-T<B`B1F]R:V5R="!A;G1A;"!F96QT97(@:2!L:6YI92`E9"X@1F]R=F5N
M=&5D92`E9"P@9F%N9'0@)60N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-3
M5BYP:'`Z,S,R(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F
M;W5N9"`E9"XB"FUS9W-T<B`B1F]R:V5R="!A;G1A;"!F96QT97(N($9O<G9E
M;G1E9&4@)60L(&9A;F1T("5D+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$R,2!L:6(O5D93+V9I;&4N<&AP.C$R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F
M:6QE+B(*;7-G<W1R(")&;W)K97)T(&9O<G-K>61N:6YG("5D('5N9&5R(&EN
M9&SF<VYI;F<@868@96X@5D93+69I;"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0U"FUS9VED(")8+5)E9B(*;7-G<W1R(")8+5)E9B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DT(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',B"FUS9W-T<B`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4B"FUS9W-T<B`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DU(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R!3=6)J96-T
M($%L=&5R;F%T:79E($YA;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B
M6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X,R!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M6#4P.78S('5D=FED9&5L<V5R(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(EE9(@IM<V=S='(@(L7%(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4V"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R("+%Q<7%(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA
M:&]O(2!M87`B"FUS9W-T<B`B66%H;V\A+6MO<G0B"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V(&QI8B](;W)D92]-86EN
M=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R("+%<FQI9R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T
M-PHC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B665M96XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*;7-G:60@
M(EEE<R(*;7-G<W1R(")*82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M
M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T
M<B`B2F$L(&IE9R!E<B!E;FEG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/
M1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=9
M4TE764<N(@IM<V=S='(@(B(*(D1U(&)E9FEN9&5R(&1I9R!I(%1%2U-4($U/
M1%53+B`@0G)U9R!;/#Y=+6MN87!P96X@=&EL(&%T('-K:69T92!T:6QB86=E
M('1I;"`B"B)765-)5UE'+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70O36%N86=E<BYP:'`Z,C,V"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z,C,V"B,L('!H<"UF;W)M870*;7-G:60@(EEO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N
M(@IM<V=S='(@(D1U(&AA<B!I:VME('1I;&QA9&5L<V4@=&EL(&%T(&]P<F5T
M=&4@;65R92!E;F0@)60@8FQO:VME+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,30R-"!L:6(O2&]R9&4N<&AP.C$T,C0*;7-G:60@(EEO=2!A
M<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D1U(&5R(&EK:V4@YF=T
M970N(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS,#@@
M;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@
M:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM
M<V=S='(@(D1U(&MA;B!I:VME(&AA=F4@)UQ<)RUT96=N970@:2!D:70@9G5L
M9&4@;F%V;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-34@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB"FUS9W-T<B`B
M1'4@:6YD=&%S=&5D92!I:VME(&5N(&=Y;&1I9R!E+7!O<W0M861R97-S92XB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`@;&EB+TAO<F1E+T1A
M=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"B)&
M;W(@870@:6UP;W)T97)E('-K86P@9'4@=&EL;W)D;F4@9F5L=&5R(&9R82!D
M96X@9FEL(&1U(&EM<&]R=&5R97(@=&EL(&1E("(*(G1I;'-V87)E;F1E(&9E
M;'1E<B!I("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-R!L
M:6(O2&]R9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N(@IM<V=S='(@(D1U(&5R(&)L979E="!L;V=G970@=60N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,2!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(V,0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO
M;F%L("<K)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F
M:7@N(@IM<V=S='(@(B(*(D1U('-K86P@:6YD=&%S=&4@970@9G5N9V5R96YD
M92!M;V)I;&YU;6UE<CL@:W5N(&-I9G)E(&UE9"!E="!V86QG9G)I("<K)R!F
M;W(@(@HB9&5N(&EN=&5R;F%T:6]N86P@<F5T;FEN9W-K;V1E+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M(@IM<V=S='(@(D1U('-K86P@:6YD=&%S=&4@96X@9WEL9&EG(';F<F1I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HS-R!L:6(O2&]R
M9&4O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*;7-G<W1R
M("(B"B)$=2!S:V%L(&MO;F9I9W5R97)E(&5N($1A=&%4<F5E+6)A8VME;F0@
M9F]R(&%T(&MU;FYE(&%N=F5N9&4@3W!S:W)I=FYI;F=E<BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0W,2!L:6(O2&]R9&4N<&AP.C0W,0IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(D1U('-K86P@:V]N9FEG=7)E<F4@96YD(%9&4RUB86-K96YD+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T<B`B(@HB1'4@8FQI=F5R(&[X
M9"!T:6P@870@;&%V92!E;B!P<F]B;&5M8F5S:W)I=F5L<V4L(&;X<B!D=2!K
M86X@<V5N9&4@9&5N(&EN9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@
M55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B1'4@<VMA
M;"!I;F1T87-T92!D96X@55),(&AV;W)T:6P@9&5N;F4@:.9G=&4@<VMA;"!H
M96YV:7-E(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*;7-G
M:60@(EEO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB
M"FUS9W-T<B`B1'4@<VMA;"!VYFQG92!D96X@<V5R=F5R+"!S;VT@<VMA;"!S
M;&5T=&5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B
M1'4@<VMA;"!A;F=I=F4@8G)U9V5R;F%V;F5T+"!S;VT@9'4@=FEL(&9J97)N
M92XB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(D1U('-K86P@
M86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F:F5R;F4N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N(@IM<V=S='(@(D1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@
M<V]M(&1U('9I;"!T:6QF^&IE+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM
M<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+B(*;7-G<W1R(")$=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D
M=2!V:6P@;W!D871E<F4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+WII<"YP:'`Z,3,X(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S
M.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F
M;W)M+B(*;7-G<W1R(")$=2!S:V%L(&%N9VEV92!D96X@:&%N9&QI;F<L('-O
M;2!S:V%L('5D9OAR97,N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-S$*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@
M8V%T96=O<GD@;F%M92XB"FUS9W-T<B`B1'4@<VMA;"!A;F=I=F4@970@;GET
M(&MA=&5G;W)I;F%V;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D
M869O;F5I=&%L>5]S;71P+G!H<#HW,PHC.B!L:6(O3F5T+U--4R]V;V1A9F]N
M96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V:61E
M(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(D1U(&)L:79E<B!N
M^&1T('1I;"!A="!A;F=I=F4@970@:71A;&EE;G-K92!T96QE9F]N;G5M;65R
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<U(&QI8B](;W)D92]!
M=71H+G!H<#HY-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@
M(D1I;B`E<R!S97-S:6]N(&5R('5D;/AB970N($QO9R!V96YL:6=S="!I;F0@
M:6=E;BXB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM
M<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D1I;B!E+7!O<W0M
M861R97-S92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@
M(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B1&EN($9R;VTZ(&%D<F5S
M<V4Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HW-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#4*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDR"FUS9VED(")9;W5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D1I;F4@:6YF;W)M871I;VYE<B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@N<&AP.CDW.2!L:6(O2&]R9&4O075T:"YP:'`Z.3<Y"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H87,@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BXB"FUS9W-T<B`B(@HB1&EN($EN=&5R;F5T+6%D<F5S<V4@97(@
M<VMI9G1E="!S:61E;B!B96=Y;F1E;'-E;B!A9B!D:6X@)7,M<V5S<VEO;BX@
M1F]R(&%T("(*(F)E<VMY='1E(&1I;B!S:6MK97)H960@8FQI=F5R(&1U(&[X
M9'0@=&EL(&%T(&QO9V=E(&EN9"!I9V5N+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T<B`B
M1&ET(&YA=FXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z
M-0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U
M<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S
M="!U<V4@82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB
M"FUS9W-T<B`B(@HB1&EN(.9G=&YI;F=S+6)A8VME;F0@=6YD97)S=/AT=&5R
M(&EK:V4@=&EL9OAJ96QS96X@868@8G)U9V5R92X@2'9I<R!D=2`B"B+X;G-K
M97(@870@8G)U9V4@2&]R9&4@=&EL(&%T(&%D;6EN:7-T<F5R92!B<G5G97)K
M;VYT:2P@8FQI=F5R(&1U(&[X9'0@=&EL(&%T("(*(F)R=6=E(&5N(&%N9&5N
M(.9G=&YI;F=S+6)A8VME;F0N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHU"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN(@IM<V=S='(@(B(*(D1I;B!A=71O<FES871I;VYS+6)A8VME;F0@
M=6YD97)S=/AT=&5R(&EK:V4@;W!L:7-T;FEN9V5N(&%F(&)R=6=E<F4@96QL
M97(@97(@(@HB9&5N(&9U;FMT:6]N(&%F(&5N(&5L;&5R(&%N9&5N(&=R=6YD
M(&)L979E="!S;.5E="!F<F$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3@S(&QI8B](;W)D92]!=71H+G!H<#HY.#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4
M;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN
M+B(*;7-G<W1R("(B"B)$:6X@8G)O=W-E<B!S>6YE<R!A="!VYG)E('-K:69T
M970@<VED96X@8F5G>6YD96QS96X@868@9&EN("5S+7-E<W-I;VXN($9O<B`B
M"B)A="!B97-K>71T92!D:6X@<VEK:V5R:&5D+"!S:V%L(&1U(&QO9V=E(&EN
M9"!I9V5N+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4W"FUS9VED(")9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(@IM
M<V=S='(@(D1I;B!B<F]W<V5R('5N9&5R<W3X='1E<B!I:VME(&1E;FYE(&9U
M;FMT:6]N86QI=&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT
M+FIS.C0R"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB1&EN(&)R;W=S97(@=6YD97)S
M=/AT=&5R(&EK:V4@9&5N;F4@<')I;G0M;75L:6=H960N(%1R>6L@0W1R;"]#
M;VUM86YD("L@4"`B"B)F;W(@870@<')I;G1E+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z
M(@IM<V=S='(@(D1I;B!A:W1U96QL92!T:61S>F]N93HB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z,3$W"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@
M:&%S(&)E96X@8VAA;F=E9"XB"FUS9W-T<B`B1&EN(&9O<G9A;&=T92!I9&5N
M=&ET970@97(@YFYD<F5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M-C$*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B1&EN
M('-T86YD87)D+6ED96YT:71E=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C`T"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B1&ET(&9U
M;&1E(&YA=FXZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DY(&QI
M8B](;W)D92]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X
M<&ER960N(@IM<V=S='(@(D1I="!L;V=I;F0@97(@=61L^&)E="XB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@
M(D1I="!N>64@:V]D96]R9"!F;W(@)7,@97(Z("5S(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-30@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ-30*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F
M;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BXB"FUS9W-T<B`B1&EN
M92!T:6QV86QG(&5R(&)L979E="!O<&1A=&5R970@9F]R('9A<FEG:&5D96X@
M868@9&5N;F4@<V5S<VEO;BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")$:6YE
M('1I;'9A;&<@97(@;W!D871E<F5T+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C<U"FUS9VED(")9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T(@IM<V=S='(@(D1I="!K;V1E;W)D(&5R(&)L979E="!N=6QS=&EL;&5T
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"B)$:70@:V]D96]R9"!E<B!B;&5V970@;G5L<W1I;&QE.R!K;VYT
M<F]L;.ER(&1I;B!I;F1B86MK92!O9R!L;V<@:6YD(&UE9"!D:70@(@HB;GEE
M(&MO9&5O<F0N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S,S(&QI
M8B](;W)D92]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&5X<&ER960N(@IM<V=S='(@(D1I="!K;V1E;W)D(&5R('5D;/AB970N(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C4X"FUS9VED(")9;W5R
M(')E;6]T92!S97)V97)S.B(*;7-G<W1R(")$:6YE(&9J97)N92!S97)V97)E
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-30*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU
M9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F'O<F4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G=E(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("):
M:7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI
M9VAT<75O=&5S+G!H<#HQ-S0*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB
M"FUS9W-T<B`B6U-K:G5L(&-I=&5R970@=&5K<W1=(@H*(SH@<V5R=FEC97,O
M<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T
M<B`B6U!R;V)L96UB97-K<FEV96QS95TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@475O=&5D(%1E
M>'0@+2(*;7-G<W1R(");5FES(&-I=&5R970@=&5K<W0@+2(*"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ
M-S0*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP
M:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=(@IM<V=S='(@(EM6:7,@8VET97)E="!T96MS="`M("5S
M(&QI;FEE<ETB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C(P-"!L
M:6(O2&]R9&4N<&AP.C(P-`HC+"!P:'`M9F]R;6%T"FUS9VED(");;&EN92`E
M<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FEE("5S('5D(&%F("5S72(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34U-"!L:6(O2&]R9&4N<&AP.C$U
M-30*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F%T:6]N(@H*(SH@;&EB
M+V%P:2YP:'`Z,34W"FUS9VED(")?0TQ)(@IM<V=S='(@(D-,22(*"B,Z(&QI
M8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E(@IM<V=S='(@(D1A=&%4
M<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")3;&5T
M('+F:VME(@H*(SH@;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM
M<V=S='(@(D=R=7!P97(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,3<U(&QI8B](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP
M(@IM<V=S='(@(DAJYFQP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")":6QL960M96=E;G-K86)E<BXN+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$Y-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R("),;V<@:6YD(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y,"!L:6(O2&]R
M9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R("),;V<@
M=60B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*;7-G<W1R("+&
M;F1R:6YG(&AE;G9I<VYI;F<N+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4O365N=2YP:'`Z,38T(&QI8B](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@
M(E]/<'1I;VYS(@IM<V=S='(@(DEN9'-T:6QL:6YG97(B"@HC.B!L:6(O87!I
M+G!H<#HQ,S<*;7-G:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")4:6QL861E
M;'-E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@
M(E-L970@:&5N=FES;FEN9RXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I
M9"`B7U-E='5P(@IM<V=S='(@(D]P<^9T;FEN9R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,PIM<V=I9"`B
M7U1A8FQE(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5&%B96PM96=E;G-K86)E
M<BXN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S
M='(@(D)R=6=E<F4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR
M-2!L:6(O2&]R9&4O2V]L86(N<&AP.CDR-0IM<V=I9"`B861D<F5S<R!B;V]K
M(@IM<V=S='(@(F%D<F5S<V5K87)T;W1E:R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,3,T(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$S-`IM<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B861R
M97-S96YT('5K96YD="(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$W(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$W"FUS9VED(")C86QE;F1A<B(*
M;7-G<W1R(")K86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<Y
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@
M(F-A;&TB"FUS9W-T<B`B=FEN9'-T:6QL92(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O365S<V%G92YP:'`Z,34X(&QI8B](;W)D92]-24U%+TUE<W-A9V4N
M<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(*;7-G
M<W1R(")K86X@:6MK92!D86YN92!U9&1A=&$M9FEL(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]-97-S86=E+G!H<#HQ,S`@;&EB+TAO<F1E+TU)344O365S
M<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R
M(")K86X@:6MK92#E8FYE(&EN9&1A=&$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HV,#`@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N
M<&AP.C8P,`IM<V=I9"`B8VQI8VL@:&5R92(*;7-G<W1R(")K;&EK(&AE<B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(R(&QI8B](
M;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(F9E:FP@=F5D(&%N=F5N9&5L<V4@868@
M:V]M;6%N9&\M;&EN:64B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W."!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S@*;7-G
M:60@(F-O;F9I9W5R871I;VX@97)R;W(B"FUS9W-T<B`B:V]N9FEG=7)A=&EO
M;G-F96IL(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M-30@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET
M:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(FUA;F=L97(@:W)I
M=&ES:R!S>7-T96UF:6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$R-B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,C8*;7-G
M:60@(F1A=&$@9F]R;6%T(&5R<F]R(@IM<V=S='(@(F9E:FP@:2!D871A9F]R
M;6%T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHS,`IM<V=I9"`B
M961I="(*;7-G<W1R(")R961I9V5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z
M,3@R"FUS9VED(")E;G1R>2!N;W0@9F]U;F0B"FUS9W-T<B`B:6YD9V%N9R!I
M:VME(&9U;F1E="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<S"FUS9VED(")F86QL:6YG(@IM<V=S='(@(F9A;&1E;F1E(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DX(&QI8B](;W)D
M92]"<F]W<V5R+G!H<#HX.3@*;7-G:60@(F9I;&4B"FUS9W-T<B`B9FEL(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#$@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS-C<@;&EB+T)L;V-K+VUE=&%R+G!H<#HS.3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<R(*;7-G<W1R(")F<F$@
M)7,@*"5S*2!M960@)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,Y"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(G-T;W)M9G5L9"(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-3`*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U,`IM<V=I
M9"`B:#HB"FUS9W-T<B`B:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S4Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-3D*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S@@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,3,X"FUS9VED(")H;W-T(&YA;64@=6YK;F]W;B(*
M;7-G<W1R(")U:V5N9'0@;6%S:VEN;F%V;B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M^&IE8FQI:VME;&EG="(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D
M;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B
M:6YD;&5J<F5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-C(@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38R"FUS9VED(")I
M;G!U="]O=71P=70@97)R;W(B"FUS9W-T<B`B:6YD9&%T82]U9&1A=&$M9F5J
M;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,30V(&QI
M8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@
M<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B:6YT97)N('-O9G1W87)E+69E:FPB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B;&EN97-=(@IM<V=S='(@(FQI;FEE<ETB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(SH@;&EB
M+U9&4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M(@IM<V=S='(@(FUK:7-O9G,@9F5J;&MO9&4@)60@=6YD97(@9&%N;F5L<V4@
M868@25-/+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S`*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W,`IM<V=I9"`B;6TB"FUS9W-T<B`B;6TB"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.C(X-2!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C(X
M-0HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HR-#$*;7-G:60@(FYA;64B"FUS9W-T<B`B
M;F%V;B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+G!H<#HQ,C0@;&EB+TAO<F1E
M+U)00RYP:'`Z,3(T"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B
M:6MK92!I;7!L96UE;G1E<F5T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,C(P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3(R
M,`IM<V=I9"`B;F]T('EE="!I;7!L96UE;G1E9"(*;7-G<W1R(")E;F1N=2!I
M:VME(&EM<&QE;65N=&5R970B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDP.2!L:6(O2&]R9&4O2V]L86(N<&AP.CDP.0IM<V=I9"`B;F]T97!A
M9"(*;7-G<W1R(")N;W1E<V)L;VLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM
M<V=S='(@(G!R;V-E;G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$W-"!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S0*;7-G
M:60@(G!E<FUI<W-I;VX@9&5N:65D(@IM<V=S='(@(G1I;&QA9&5L<V4@;N9G
M=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(G!R:6MK97(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,"!L:6(O2&]R
M9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I
M;B!P<F]T;V-O;"(*;7-G<W1R(")F96IL(&D@<')O=&]K;VP@9G)A(&9J97)N
M('-I9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW-0IM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T:6=E;F1E(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-#(@;&EB+TAO<F1E+TU)
M344O365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE
M(@IM<V=S='(@(G1J96YE<W1E('5T:6QGYFYG96QI9R(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z,3`Q"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(G9I<R!F;W)S:V5L;&4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B<VUS,F5M86EL('9I82!(5%10(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PHC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@W"FUS9VED(")S<R(*;7-G<W1R(")S
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<T
M"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B<W1A8FEL="(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P(&QI8B](;W)D92]-24U%+TUE
M<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M(&5R<F]R(@IM<V=S='(@(G-Y
M<W1E;69E:FPB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS,R!L
M:6(O2&]R9&4O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S:R!L:7-T(@IM<V=S
M='(@(F]P9V%V96QI<W1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-C8@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,38V"FUS
M9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R(")M:61L97)T:61I9R!F
M96IL=&EL<W1A;F0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C<P"B,Z(&QI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'`Z,C<P"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T
M;R!C;VYF:7)M(@IM<V=S='(@(FEN9'1A<W0@:V]D96]R9&5T('1O(&=A;F=E
M(&9O<B!A="!B96MRYF9T92(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S
M='(@(G-A;6UE;G-M96QT970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U!A
M<G0N<&AP.C(W(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS9VED(")U
M;FYA;65D(@IM<V=S='(@(G5N879N9VEV96XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T
M<B`B8G)U9V5R=F%L9R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HS-2!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C,U"FUS9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T,@IM<V=I9"`B=SHB"FUS9W-T
M<B`B=SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I
M9"`B=V5A=&AE<BYC;VTB"FUS9W-T<B`B=V5A=&AE<BYC;VTB"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!O+V-S7T-:+G!O````````````````````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#<R,3$W,2`Q,#4Q-30S-#$T,B`P,3<U
M,C(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M(R!#>F5C:"!T<F%N<VQA=&EO;G,@9F]R($AO<F1E+@HC($-O<'ER:6=H="`H
M0RD@,C`P-"!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U
M=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE($AO<F1E('!A8VMA
M9V4N"B,@4&%V96P@0VAY=&EL(#QP879E;$!C:'ET:6PN=&L^+"`R,#`Q+3(P
M,#0N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,%QN(@HB4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X
M(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A=&4Z(#(P,#0M,#<M,C(@
M,3$Z-#DM,#<P,%QN(@HB3&%S="U4<F%N<VQA=&]R.B!-:6QO<R!7:6UM97(@
M/'=I;6UE<D!Z8W4N8WH^7&XB"B),86YG=6%G92U496%M.B!#>F5C:"`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB
M0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3)<
M;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*(E!L=7)A
M;"U&;W)M<SH@;G!L=7)A;',],SL@<&QU<F%L/2AN)3$P/3TQ("8F(&XE,3`P
M(3TQ,2`_(#`@.B!N)3$P/CTR("8F(&XE(@HB,3`\/30@)B8@*&XE,3`P/#$P
M('Q\(&XE,3`P/CTR,"D@/R`Q(#H@,BD[7&XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S8Y"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y
M<R!A9V\I(@IM<V=S='(@(B`H</AE9"`E<R!D;GDI(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*%#X[7-T=7!O=OT@:VSMZ"`E<RDB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M
M870*;7-G:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AV("5S(&1N96-H
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S,*;7-G:60@(B`H
M=&]D87DI(@IM<V=S='(@(B`H9&YE<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*'KM
M=')A*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*;7-G:60@
M(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*';H97)A*2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR-38@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,V,0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W
M"FUS9VED("(@870@(@IM<V=S='(@(B!R>6-H;&]S="`B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(Q-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB(&ES(&YO="!A(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5N
M[2!A9')E<^'X96TB"@HC.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L
M:60@8VAO:6-E+B(*;7-G<W1R("(E<R!N96QZ92!Z=F]L:70N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV-3D*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HQ,#0R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@
M=&AE($AO<F1E(%)E9VES=')Y+B(*;7-G<W1R("(G)7,G(&YE;NT@;F%K;VYF
M:6=U<F]VX6X@=B!R96=I<W1R96-H($AO<F1E('-Y<W3I;74N(@H*(SH@9G)A
M;65W;W)K+U1R964O5')E92YP:'`Z,3<Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B<E<R<@</AE:VQA9&'H(&YE8GEL(&YA;&5Z96XN(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HU-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B
M)7,G(&)Y;"!P^&EDX6X@9&\@<WES=.EM=2!S:W5P:6XN(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T
M96TN(@IM<V=S='(@(B<E<R<@8GEL('#X:63A;B!D;R!S>7-TZ6UU('#X[7-T
M=7!O=OUC:"!P<N%V+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S
M)R!N96)Y;"!V>71V;_AE;CH@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N
M,F9-0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&$@)7,B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U
M<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D
M+61A>2!F;W)E8V%S="(*;7-G<W1R("(E9"UD96YN[2!P^&5D<&]V[.\B"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-C@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@+2!.;W1I8V4B"FUS9W-T<B`B)7,@+2!O>F[A;65N[2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`T"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(&]T:7-K
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-
M86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@
M(B5S(&]P97)A8V4@^F1ROF)Y("T@<&]T=G)Z96[M(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S(&YA<W1A
M=F5N[2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!R
M96=I<W1R86-E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(%1E<FUS(&]F($%G<F5E;65N="(*;7-G
M<W1R("(E<R!P;V1M[6YK>2!P;W6^[7;A;NTB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0R."!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0Y
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8U,2!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A
M;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@:FF^(&5X:7-T=6IE+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]";&]C:R]M971A<BYP:'`Z
M,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z,S4Q"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&YA("5S("5S(@H*
M(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C0X"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(D]Z;F'H:70@<N%M9>AE:R!P
M<F\@=KEE8VAN>2!O<&5R86-E+"!K=&5RZ2!C:&-E=&4@=&7O('!R;W;I<W0N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!J92!P;[YA
M9&]VX6YO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU="(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N
M96)Y;&\@;F%L97IE;F\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*
M;7-G<W1R("(E<R!AOB`E<R!Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S
M($)O;VLB"FUS9W-T<B`B)7,@861R97/A^"(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L
M96YD87(B"FUS9W-T<B`B)7,@:V%L96YDX?@B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDP-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO
M=&5P860B"FUS9W-T<B`B)7,@>N%P:7-N[6LB"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDS,`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A
M<VML:7-T(@IM<V=S='(@(B5S('-E>FYA;2#Z:V]L^2(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,Z("5S(@IM<V=S='(@(B5S
M.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VAT;6PN<&AP
M.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B(E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R`B"B)A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED
M:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C4@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q,`HC+"!F=7IZ>0IM
M<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&[A<F%Z;W;]("5S("5S(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S(@IM
M<V=S='(@(BP@;N%R87IO=OT@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,B"FUS9W-T<B`B+"!P<F]M[&YNX2!O9"`E<R!D;R`E<R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M
M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@=OUB['(@+2TB"@HC.B!L:6(O0FQO
M8VLO=&EM92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@
M(C$R(&AO9&EN;W;](&9O<FWA="(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ
M.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@:&]D:6YO=OT@
M9F]R;>%T(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,C@*;7-G:60@
M(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AO9&EN(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HV.0HC+"!F=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM
M<V=S='(@(E#X961C:&]Z[2!S='+A;FMA(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B4')O('1E;G1O(&)L;VL@:F4@
M=GF^861O=N%N(&1A=&%BX7IO=OT@>F1R;VHN(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ-C`*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D(@IM<V=S='(@(E9Y<VMY=&QA('-E('KA=F&^;N$@8VAY8F$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G:60@(D$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N(@IM<V=S='(@(E!R;R!Z8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@
M<&]UONUT('9E^&5J;OT@4$=0(&ML[>@N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3$V-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T
M<B`B4')O('9E<FEF:6MA8VD@<&]D97!S86[I('IP<N%V>2!J92!N=71N;R!P
M;W6^[70@=F7X96IN_2!01U`@:VSMZ"XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB4')O(&1E
MN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P;W6^[70@=F7X96IN_2!01U`@
M:VSMZ"P@<')I=N%T;NT@4$=0(&ML[>@@82`B"B)H97-L;RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#$U"FUS9VED("(B"B)!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B
M(@HB4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J
M;OT@4$=0(&ML[>@L('!R:7;A=&[M(%!'4"!K;.WH(&$@(@HB:&5S;&\N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4*;7-G:60@
M(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M
M97-S86=E+B(*;7-G<W1R("(B"B)0<F\@9&6Y:69R;W;A;NT@>G!RX79Y(&IE
M(&YU=&YO('!O=;[M="!V9?AE:F[](%,O34E-12!K;.WH+"!P<FEVX71N[2!3
M+TU)344@(@HB:VSMZ"!A(&AE<VQO+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@
M:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T<B`B(@HB4')O
M('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]UONUT('9E^&5J;OT@4R]-
M24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12`B"B)K;.WH(&$@:&5S;&\N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B4')O('IAN6EF<F]VX6[M('IP<N%V>2!J92!N
M=71N;R!P;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HY"B,L(&9U>GIY"FUS9VED
M(")!32!#;&]U9',B"FUS9W-T<B`B6F%T8;YE;F\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,`HC+"!F=7IZ>0IM<V=I9"`B
M04T@3&EG:'0@4F%I;B(*;7-G<W1R(")/9'!O;&5D;NT@;&5H:_T@9.FYNR(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Q"FUS
M9VED(")!32!286EN(@IM<V=S='(@(E)A;F[M(&3IN;LB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,@IM<V=I9"`B04T@4VAO
M=V5R<R(*;7-G<W1R(")286YN[2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S"FUS9VED(")!32!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4F%N;NT@<V[L:&]VZ2!P^&5HX?)K>2(*"B,Z('1E
M;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R
M(")!32]032(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(P,`IM<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*
M;7-G:60@(D%B;W5T('1H:7,@961I=&]R(@IM<V=S='(@(DEN9F]R;6%C92!O
M('1O;71O(&5D:71O<G4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B26YF;W)M86-E+BXN(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`IM<V=I
M9"`B06)S8F]T=&]M(@IM<V=S='(@(E1E>'0@9&]L^2!D;R!O8G+A>FMU(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM
M<V=I9"`B06)S;6ED9&QE(@IM<V=S='(@(E1E>'0@9&]P<F]S=/AE9"!O8G+A
M>FMU(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I
M9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G
M<W1R(")6>71V;_AE;NT@5D93(&%D<F%SX?AE(&YE8GEL;R!P;W9O;&5N;RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!
M8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")6>71V
M;_AE;NT@5D93('-O=6)O<G4@;F5B>6QO('!O=F]L96YO+B(*"B,Z(&QI8B]"
M;&]C:R]A8V-O=6YT+G!H<#HS"B,L(&9U>GIY"FUS9VED(")!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-E(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM
M<V=S='(@(E6^:79A=&5L<VOI(&AE<VQO(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT
M(&9R;WIE;BXB"FUS9W-T<B`B5;YI=F%T96QK_2#ZZ&5T(&)Y;"!Z86)L;VMO
M=N%N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S,*;7-G:60@
M(D%C8V]U;G1I;F<B"FUS9W-T<B`B5;YI=F%T96QKZ2#ZZ'1Y(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#@@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C$T"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI
M;&0N:6YC.C$Q"FUS9VED(")!9&0B"FUS9W-T<B`B5FQOOB(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z,C(T(&%D;6EN+V=R;W5P<RYP:'`Z,C(U"FUS9VED(")!
M9&0@0VAI;&0@1W)O=7`B"FUS9W-T<B`B4/AI9&%T('!O9'-K=7!I;G4B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S
M:6]N(@IM<V=S='(@(E#X:61A="!P;V0M<'+A=F$B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S='(@(E#X
M:61A=#HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N
M<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U<"(*;7-G<W1R(")0^&ED870@
M;F]V;W4@<VMU<&EN=2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z.#<@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX.`IM<V=I9"`B
M061D($YE=R!097)M:7-S:6]N(@IM<V=S='(@(E#X:61A="!N;W;A('!RX79A
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@9W)O=7`@
M=&\@7"(E<UPB(@IM<V=S='(@(E#X:61A="!P;V1S:W5P:6YU(&1O("<E<R<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T
M;R!<(B5S7"(B"FUS9W-T<B`B4/AI9&%T('!O9"UP<N%V82!D;R`G)7,G(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,S`*;7-G:60@(D%D9"!A(&YE=R!U<V5R.B(*
M;7-G<W1R(")0^&ED870@;F]VZ6AO('6^:79A=&5L93HB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!9&0@
M8V]L=6UN(@IM<V=S='(@(E#X:61A="!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB
M97)S(@IM<V=S='(@(E#X:61A="!N;W;I(.AL96YY(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHY-0IM<V=I9"`B061D('!A:7(B"FUS9W-T<B`B
M4/AI9&%T('#A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL
M82!3:61E8F%R(@IM<V=S='(@(E#X:61A="`E<R!M96YU(&IA:V\@8F_H;NT@
M<VQO=7!E8R!-;WII;&QY(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@861D<F5S<R!B;V]K.B(*
M;7-G<W1R(")0^&ED870@9&\@861R97/A^&4Z(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@
M861D<F5S<R!B;V]K(@IM<V=S='(@(E#X:61A="!D;R!MZ6AO(&%D<F5SX?AE
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S
M='(@(E#X:61A="!UOFEV871E;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E<UPB('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB)R5S)R!B>6QO
M('#X:63A;F\@9&\@<WES=.EM=2P@86QE(&YE;'IE('#X:61A="!NX7-L961U
M:NUC[2!I;F9O<FUA8V4Z("5S+B(*"B,Z('-I9VYU<"YP:'`Z-#4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B<E<R<@8GEL;R!P
M^&EDX6YO(&1O('-Y<W3I;74N($WYOF5T92!S92!N>6[M('#X:6ALX7-I="!D
M;R!S>7-TZ6UU+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN
M8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@
M(E#X:63A=N%N[2!UOFEV871E;/D@:F4@>F%B;&]K;W;A;F\N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B
M061R97-A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S.0IM<V=I
M9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5SX?@B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY-`IM<V=I9"`B061M:6YI
M<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B"FUS9W-T
M<B`B(@HB5GEK;V[A=F%T(&%D;6EN:7-T<F%C:2`M(&YA<W1A=F5N[2!P^.US
M='5P;W;]8V@@<'+A=B!P<F\@;W-T871N[2!UOFEV871E;&4B"@HC.B!A9&UI
M;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Q
M,PIM<V=I9"`B061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-E
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B061S
M(@IM<V=S='(@(DEN>F5RX71Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B069G:&%N
M:7-T86XB"FUS9W-T<B`B069G:.%N:7-TX6XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED
M(")!;&)A;FEA(@IM<V=S='(@(D%L8N%N:64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")!;&=E<FEA(@IM<V=S='(@(D%LONUR<VMO(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P-PIM<V=I9"`B06QI87,B"FUS
M9W-T<B`B4/AE>F3M=FMA+T%L:6%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS
M9W-T<B`B6F%R;W9N870B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(EIA
M<F]V;N%N[3HB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@
M(D%L;"(*;7-G<W1R(")6N64B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED
M(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")6N6EC:&YI(&]V
M[/AE;NT@=;YI=F%T96SI(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI
M;B]G<F]U<',N<&AP.C(R,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G<W1R(")6
MN65C:&YY('-K=7!I;GDB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.CDQ(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*
M;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R(")6N65C:&YA('6^:79A
M=&5L<VOA('!RX79A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS
M9W-T<B`B5KEE8VAN>2#H='GX:2!S=')A;GDB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,B"FUS9W-T<B`B4&]V;VQI="!V[6-E(&%D<F5S(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E
M<F5D(&QI<W0@='EP93\B"FUS9W-T<B`B4&]V;VQI="!N87-T879E;NT@='EP
M=2!S973X[63L;OT@<V5Z;F%M/R(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$
M871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS
M9W-T<B`B2FF^(&5X:7-T=6IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$R,PIM<V=I9"`B06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B06QT
M97)N871I=F[M($E-4U`@</AI:&SAN65N[2!D;R!S>7-TZ6UU(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@
M4&%S<W=O<F0B"FUS9W-T<B`B06QT97)N871I=F[M($E-4U`@:&5S;&\B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#DY"FUS9VED(")!;'1E<FYA=&4@
M24U34"!5<V5R;F%M92(*;7-G<W1R(")!;'1E<FYA=&EV;NT@24U34"!UOFEV
M871E;'-KZ2!J;>EN;R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C,U"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R(")!
M;'1E<FYA=&EV;NT@92UM86EL;W;A(&%D<F5S82(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S
M='(@(D%L=&5R;F%T:79N[2!V>F]R>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT
M97)N871E('1E>'0Z(@IM<V=S='(@(D%L=&5R;F%T:79N[2!T97AT.B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I
M8VOA(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HY
M-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q-0IM<V=I9"`B06X@
M:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G<W1R(")">6QA('IA
M9.%N82!N97!O=F]L96[A(&AO9&YO=&$N(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$V-PHC+"!F=7IZ>0IM<V=I9"`B06X@=6YK;F]W;B!E
M<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B;F%S=&%L82!C:'EB83HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N9&]R82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY
M;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6UN[2!P<F]X>2(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0Y"FUS9VED(")!;G-W97(B"FUS9W-T
M<B`B3V1P;W;L[R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS
M9W-T<B`B06YT87)K=&EK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%N=&EG=6$@
M86YD($)A<F)U9&$B"FUS9W-T<B`B06YT:6=U82!A($)A<F)U9&$B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A
M9&UI;B]S971U<"]I;F1E>"YH=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM
M<V=S='(@(D%P;&EK86-E(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0R
M"FUS9VED(")!<'!L:6-A=&EO;B!,:7-T(@IM<V=S='(@(E-E>FYA;2!A<&QI
M:V%C[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G:60@(D%P
M<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")!<&QI:V%C92!J92!P^&EP
M<F%V96YA(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G
M:60@(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")0;W6^[70@<')O
M(&3L9&GH;ND@<V3M;&5N[2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P
M<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(E-C:';A;&ET
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S"FUS
M9VED(")!<'!R;WAI;6%T92!3:7IE(@IM<V=S='(@(E#X:6)L:;YNX2!V96QI
M:V]S="(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8X"FUS9VED(")!<')I;"(*;7-G<W1R(")$=6)E;B(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3<U"FUS9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB
M"FUS9W-T<B`B07)A8G-K>2`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*
M;7-G<W1R(")696QI:V]S="!A<F-H:79O=F%NZ6AO('-O=6)O<G4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4X(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HX,`IM<V=I9"`B07)C:&EV92!.86UE
M(@IM<V=S='(@(DIMZ6YO(&%R8VAI=G4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@
M(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R`_(@IM<V=S='(@(E5RZ&ET["!C:&-E=&4@=GEM87IA
M=""^X61O<W0@;R!P^&EH;.&Y96[M(&1O("5S/R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<
M(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E5RZ&ET["!S:2!P^&5J
M971E('9Y;6%Z870@)R5S)R!A('!O9'-K=7!I;GD_(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM
M<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(D%R9V5N=&EN82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B07)MZ6YI92(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<V"FUS9VED(")!<FUE;FEA;B`H05)-4T-)22TX
M*2(*;7-G<W1R(")!<FWI;G-K_2`H05)-4T-)22TX*2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(E5M[&[M(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@
M27-L86YD(@IM<V=S='(@(D%S8V5N<VEO;B!)<VQA;F0B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!
M<V-I:2!U;>QN[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU
M-0IM<V=I9"`B07-I82]086-I9FEC(%)E9VEO;B(*;7-G<W1R(")!<VEE+W)E
M9VEO;B!4:6-HZ6AO(&]C9>%N=2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN
M9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G<W1R(")0;[[A9&%T(&\@
M<&]T=G)Z96[M('#X960@<')O=F5D96[M;2!O<&5R86/M(/ID<KYB>3\B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM
M96YT(&-O;'5M;G,B"FUS9W-T<B`B4VQO=7!C92!S(/IK;VQY(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@9W)O=7`N(@IM<V=S='(@(E!O:W5S(&\@=GEM87KA;NT@
M;F5E>&ES='5J[6/M('-K=7!I;GDN(@H*(SH@861M:6XO<&5R;7,O9&5L971E
M+G!H<#HR.0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&]K=7,@;R!V>6UA>N%N[2!N965X
M:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N(@H*(SH@861M:6XO<&5R
M;7,O961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")0;VMU<R!O(/IP<F%V=2!N
M965X:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E!O:W5S(&\@^G!R879U
M(&YE97AI<W1U:NUC[6AO('-D[6QE;NEH;R!O8FIE:W1U+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S
M='(@(D%T<FEB=71Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S(*;7-G:60@(D%U9W5S="(*;7-G<W1R(")3<G!E;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<N%L:64B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(E)A:V]U<VMO
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I
M9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ($YE8GEL82!N86QE>F5N82!P
M;[YA9&]V86[A('#X[7!O;F$@<')O(&EM87`N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H7V-Y<G5S.B!"86-K
M96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N(@IM<V=S
M='(@(D%U=&A?8WER=7,Z(%ID<F]J(&YE;>$@<&^^861O=F%NZ2!S8VAO<&YO
M<W1I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$R,@IM
M<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!.96)Y;&$@;F%L97IE;F$@
M<&^^861O=F%NX2!P^.UP;VYA('!R;R!I;6%P+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H
M7V9T<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@
M9G1P+B!+;VUP:6QU:G1E(%!(4"!S("TM(@HB96YA8FQE+69T<"(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VEM87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O
M;F$@<')O($E-05`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HU,0IM<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@3F5B>6QA(&YA;&5Z
M96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@:W)B-2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!
M9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C
M=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,U-PIM<V=I9"`B075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VQD87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A
M('#X[7!O;F$@<')O($Q$05`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@
M<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@</AI9&%T('6^:79A
M=&5L92`E<RX@2&SAN65N[2!S97)V97)U.B`B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H
M7VQD87`Z($YE;'IE('9Y;6%Z870@=;YI=F%T96QE("5S(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T
M<B`B075T:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@=;YI=F%T96QE("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*;7-G:60@
M(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U
M:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?
M;6-A;#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM<&]N82!P<F\@
M34-!3"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z-C`*;7-G
M:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7W-M8F%U=&@Z($YE8GEL82!N86QE
M>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O('-M8F%U=&@N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B3W;L^&5N[2!S
M96QH86QO(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")/=NSX96[M('-E;&AA;&\N("5S
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM<V=I
M9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BXB
M"FUS9W-T<B`B3W;L^&5N[2!B>6QO('IA;>UT;G5T;R!2041)55,@<V5R=F5R
M96TN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R
M(")396QH86QO(&]V[/AE;NT@1E10('-E=F5R96TN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")396QH
M86QO(&]V[/AE;NT@1E10('-E=F5R96TN(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T
M<B`B1&]S='5P;N$@<&]L93HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I
M:F%N(@IM<V=S='(@(D%Z97)B86IDON%N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,P"FUS9VED(")"3T9(($5X8W5S97,B"FUS9W-T<B`B0D]&2"!V
M_6UL=79Y(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")0;WIA
M9.TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D)A<G9A('!O
M>F%D[2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G
M:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`BJ7!A=&[I(&AE
M<VQO('!R;R!K97)B97)O<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S
M='(@(JEP871NZ2!UOFEV871E;'-KZ2!J;>EN;R!P<F\@:V5R8F5R;W,N(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*;7-G<W1R(")"86AA;7DB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A:')A:6XB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-PIM<V=I9"`B0F%L=&EC("A)4T\M
M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L=&EC:^D@*$E33RTX.#4Y+3$S*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9.FY
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F%R8F%D;W,B"FUS9W-T<B`B0F%R8F%D
M;W,B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y(%PB)7-<
M(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE8GEL(&YA;&5Z96X@861R97/A^"`G
M)7,G(',@9W)A9FEK86UI+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S96QI;F4B"FUS9W-T
M<B`B6N%K;&%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R
M(")"[&QO<G5S:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S
M='(@(D)E;&=I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R
M(")"96QI>B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S='(@(D)E
M;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R(")"97)M
M=61Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)H^G3A
M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,3$*;7-G:60@(D)I<G1H9&%Y(@IM<V=S='(@(DYA<F]Z96YI;GDB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H
M<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(").96QZ92!N86SI>G0@Z.%S="!<
M(B5S7"(@87!L:6MA8V4@7"(E<UPB+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M3F%S=&%V96[M(&)L;VMU(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N
M:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(E1Y<"!B;&]K=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM
M<V=I9"`B0F]L9"(*;7-G<W1R(")4=>AN["(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)O;&EV:6$B"FUS9W-T<B`B0F]L[79I92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R("):X6QO
MOFMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(D]K<F%J(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I
M9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`BJ>WX:V$@;VMR86IE.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B3VMR86IE(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,`IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")"
M;W-N82!A($AE<F-E9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDV"FUS9VED(")";W1H(@IM<V=S='(@(D]B82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HS.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G
M:60@(D)O='-W86YA(@IM<V=S='(@(D)O='-W86YA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<U"FUS9VED(")"
M;W1T;VTB"FUS9W-T<B`B1&]L;NT@Z.%S="(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@
M(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T($ES;&%N9"(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%Z[6QI92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GDB
M"FUS9W-T<B`B0G)I='-KX2!T97)I=&]R:6$@=B!);F1I8VOI;2!O8V7A;NPB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R
M(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A
M<FEA(@IM<V=S='(@(D)U;&AA<G-K;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B
M"FUS9W-T<B`B4V5Z;F%M(',@;V1RX;YK86UI(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD82(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R
M(")#35,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I
M;VX@4&]I;G1S(@IM<V=S='(@(D-23"!D:7-T<FEB=>AN[2!B;V1Y(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E9L87-T
M;F]S=&D@8E]U\FMY+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$V,PHC+"!F=7IZ>0IM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O
M;7!L971E9"XB"FUS9W-T<B`B3F5B>6P@=79E9&5N(&1I<W1R:6)UZ&[M('-E
M>FYA;2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#@T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
M2V%L96YDX?@B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0V
M"FUS9VED(")#86QM(@IM<V=S='(@(D)E>G;L=/CM(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9+YA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B2V%M97)U;B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T
M('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES
M=')A=&]R+B(*;7-G<W1R("(B"B)(97-L;R!N96QZ92!N87-T879I="!A=71O
M;6%T:6-K>2P@<')O<^UM(&MO;G1A:W1U:G1E(%9AN65H;R!S>7-TZ6UO=NEH
M;R`B"B)A9&UI;FES='+A=&]R82XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B!N
M;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B3F5L>F4@=GEM87IA
M="!S;W5B;W(@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR,@IM
M<V=I9"`B0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S
M+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C,Q.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<R(*;7-G<W1R(").96QZ92!S92!P^&EP;VII="!K($E-05`@<V5R
M=F5R=3H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A;B=T(&]P96X@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@<V]U8F]R(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B2V%N861A(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E<R]A
M9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B4W1O<FYO
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@
M(D-A;F-E;"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")3=&]R;F\@:&SAN65N
M[2!P<F]B;.EM=2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE=&4@9FEL92!<(B5S
M7"(N(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@<V]U8F]R(%PB)7-<(BXB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM
M<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G
M<W1R(").96QZ92!N86KM="!D;^AA<V[](&%D<F5SX?@N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R(").96QZ92!P;VMR8>AO=F%T(&)E>B!P87)A;65T<G4@)W1A<F=E
M=$9I;&4G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$T"B,L
M('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`B3F5L>F4@=GEM87IA="!A9')E<^'X(%PB)7-<(BXB
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N
M(@IM<V=S='(@(DYE;'IE('9Y;6%Z870L('!R;W1OOF4@97AI<W1U:NT@<&]D
M<VMU<&EN>2`E9"XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@
M;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C
M:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B).96QZ92!P<F]VZ7-T
M('IM[&YU('5S<&_XX63A;NTL('!OZ&5T('!O<VMY=&YU=/UC:"!P;VQOOF5K
M('!R;R!N;W;I("(*(G5S<&_XX63A;NT@;F5O9'!O=NUDX2!P;^AT=2!U;&^^
M96[]8V@@<&]L;[YE:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DYE;'IE('IA<VQA
M="!Z<'+A=G4@;F$@>F%D86[I(.CM<VQO+B`B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T"FUS9VED
M(")#87!T:6]N(@IM<V=S='(@(E1I='5L:WDB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED
M(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B2V%T96=O<FEE(&$@
M>FYAZ&MY(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S(@IM
M<V=S='(@(DMA:FUA;G-KZ2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I9"`B0V5L;"!0:&]N92(*
M;7-G<W1R(")-;V)I;&[M('1E;&5F;VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL(%!R
M;W!E<G1I97,B"FUS9W-T<B`B36^^;F]S=&D@8G7R:WDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-`IM<V=I9"`B0V5L
M;"!P861D:6YG.B(*;7-G<W1R(")/9'-T=7`@;65Z:2!B=?)K86UI.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I
M(&)U\FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`B365Z97)Y
M(&UE>FD@8G7R:V%M:3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B36]B:6QN[2!T96QE9F]N
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H
M25-/+3@X-3DM,30I(@IM<V=S='(@(DME;'1S:_T@*$E33RTX.#4Y+3$T*2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R(")3=/AE9"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")3
M=/AE9&]A9G)I8VOA(')E<'5B;&EK82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R(")3=/AE9&]E=G)O<'-K_2`H25-/+3@X-3DM,BDB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF
M:6-A=&4@1&5T86EL<R(*;7-G<W1R(")0;V1R;V)N;W-T:2!C97)T:69I:^%T
M=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"B,L
M(&9U>GIY"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R(")0;V1R
M;V)N;W-T:2!C97)T:69I:^%T=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3DV"FUS9VED(")#97)T:69I8V%T92!0;VQI8VEE<R(*
M;7-G<W1R(")0;V1M[6YK>2!C97)T:69I:^%T=2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.`IM
M<V=I9"`B0VAA9"(*;7-G<W1R("+(860B"@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV
M"FUS9VED(")#:&%N9V4B"FUS9W-T<B`B6FWL;FET(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N9V4@
M66]U<B!087-S=V]R9"(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!68;EE
M:&\@:&5S;&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@
M(B(*(D-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S
M964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS
M+B(*;7-G<W1R("(B"B).87-T879E;NT@:FWI;F$@82!E;6%I;&]VZ2!A9')E
M<WDN(%1Y=&\@<&]L;[YK>2!L:63I('5V:63M+"!K9'F^('-I(.AT;W4@(@HB
M;F5B;R!O9'!O=NUD86KM(&YA(%9AN64@>G!RX79Y+B(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(EIN86LB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(EIK;VYT
M7W)O;&]V870@;V1K87HN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C4Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*
M;7-G<W1R(")#:&EL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S
M='(@(LCM;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,`IM<V=I9"`B
M0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S='(@(LCM;KET:6YA
M('IJ961N;V1UN65NX2`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R(")4<F%D:>AN[2#H[6ZY=&EN82`H0FEG-2DB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S
M=V]R9"(*;7-G<W1R("):=F]L=&4@:&5S;&\B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M
M92(*;7-G<W1R("):=F]L=&4@=;YI=F%T96QS:^D@:FWI;F\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z(@IM<V=S='(@(E9Y8G)A="!Z;V)R87IE;NT@9&%T=6UU
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R(")6>6)R870@='EP('-T>6QU('-E
M>FYA;74@*'!R;R#X87IE;ND@<V5Z;F%M>2DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED
M(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(E;A;F_H;NT@;W-T<F]V(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H<#HR.30@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS9W-T<B`B3F5B>6QA(&YA;&5Z
M96YA(&1E9FEN:6-E('3X[61Y("5S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#;&5A<B(*;7-G<W1R(")6
M>>AI<W1I="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS9W-T<B`B
M5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I8V4B"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z,3(X"B,L(&9U>GIY"FUS9VED(")#;&5A<B!1=65R>2(*;7-G<W1R
M(")/9'-T<F%N:70@=;YI=F%T96QE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQE87(@;W5T
M('5S97(Z("5S(@IM<V=S='(@(D]D<W1R86[L;NT@=;YI=F%T96QE.B`E<R(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B
M0VQE87(@=7-E<B(*;7-G<W1R(")/9'-T<F%N:70@=;YI=F%T96QE(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R
M('5S97(@9&%T82(*;7-G<W1R(")/9'-T<F%N[&[M(/ID86KY(&\@=;YI=F%T
M96QI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS9W-T<B`B4&]Z
M9&[M(&3IN;LB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N
M8V4N:'1M;#HV,`IM<V=I9"`B0VQI8VL@=&\@0V]N=&EN=64B"FUS9W-T<B`B
M2VQI:V[L=&4@<')O('!O:W)AZ&]VX6[M(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED(")#;&EC:V%T
M96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@</AE<R!(5%10(@H*
M(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B6F%V
M^.UT(&]K;F\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-`IM<V=I9"`B
M0VQO=61S(@IM<V=S='(@(EIA=&&^96YO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z>GD*;7-G:60@(D-L;W5D
M<R!%87)L>2(*;7-G<W1R(")/8FQAZ&YO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R
M(")/8FQAZ&YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',B"FUS9W-T<B`B2V]K;W-O=ND@;W-T<F]V>2(*"B,Z('1E;7!L
M871E<R]P;W)T86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I
M9&5B87(B"FUS9W-T<B`B4VML87!N;W5T(&)OZ&[M(&QIN71U(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM
M<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4VML87!N;W5T(&]K
M<F%J92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-O;&]M8FEA(@IM<V=S='(@(DMO
M;'5M8FEE(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO
M8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D)A<G9A
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R
M-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,#`@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT.0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU,`HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX,@IM<V=I9"`B0V]L
M;W(@4&EC:V5R(@IM<V=S='(@(E;]8NQR(&)A<F5V(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@T-@IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*
M;7-G<W1R(")086QE=&$@8F%R978B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B
M4VQO=7!C93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30V"FUS
M9VED(")#;VQU;6X@=&ET;&5S(@IM<V=S='(@(D[A>G9Y('-L;W5P8V4B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T"FUS9VED(")#;VUI8W,B
M"FUS9W-T<B`B2V]M:6MS>2(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM
M<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")0^.UK87HB"@HC.B!A9&UI;B]C;61S
M:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`B4/CM
M:V%Z;W;A(&MO;GIO;&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B4&]Z;N%M:V$B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-@IM<V=I9"`B
M0V]M;6]N($YA;64B"FUS9W-T<B`B3V)E8V[I(&IMZ6YO(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B2V]M;W)O<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O
M;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")0;^CM=&'H92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G
M:60@(D-O;F1I=&EO;B(*;7-G<W1R(")0;V1M[6YK>2(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(E!O
M9&WM;FMY(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.38*;7-G:60@(D-O
M;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B4F]Z9.UL>2!V(&YA
M<W1A=F5N[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#,*;7-G:60@
M(D-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H
M;VYE<R!A;F0@3W5T;&]O:RXB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0HC+"!F=7IZ>0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B2F4@=/AE8F$@86MT=6%L:7IO=F%T
M(&YA<W1A=F5N[2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3`P"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(").87-T
M879I="`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS9W-T<B`B4&]T=G)D:70@
M:&5S;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG
M;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!2
M97!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B2V]N9V\L($1E;6]K<F%T:6-KX2!R
M97!U8FQI:V$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B4W!O
M:F5N[2!S96QH86QO+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D.B`B"FUS9W-T
M<B`B4W!O:F5N[2!S96QH86QO.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HW.3`*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0GEL;R!Z86WM=&YU=&\@
M<W!O:F5N[2!S('9E^&5J;OUM(&ML[>AO=OUM('-E<G9E<F5M+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")">6QO('IA;>UT;G5T
M;R!S<&]J96[M(',@=F7X96IN_6T@:VSMZ&]V_6T@<V5R=F5R96TN($3Y=F]D
M(#H@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U
M"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G
M<W1R(")396QH86QO('-P;VIE;NT@<R!&5%`@<V5R=F5R96TN(@H*(SH@8V]N
M9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@
M=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMO;G1A:W1Y(&)Y;'D@
M^G-P[+EN["!P^&EDX6YY(&1O(%9AN65H;R!A9')E<^'X92XB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D]B<V%H('8@)R5S
M)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T
M<B`B4&]K<F'H;W9A="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD
M<R(*;7-G<W1R(")#;V]K;W9Y(&]S=')O=GDB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")+;VSAZ&5K(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(DMO<.UR;W9A="(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B4W!O:F5N[2!S
M96QH86QO.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C,V"FUS9VED(")#;W!Y('-E;&5C=&EO;B(*;7-G<W1R(")+;W#M
M<F]V870@=OUB['(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A<FEK82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HV,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS9W-T<B`B4&]B^&6^[2!S
M;&]N;W9I;GDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY
M-S8*;7-G:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G
M<W1R("):<'+A=G4@;F5L>F4@N6EF<F]V870@<&]M;V/M(%!'4"XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4S"FUS9VED(")#;W5L
M9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B6G!RX79U(&YE;'IE
M('!O9&5P<V%T('!O;6]C[2!01U`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS.3,*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC
M<GEP="!M97-S86=E+B(*;7-G<W1R("):<'+A=G4@;F5L>F4@N6EF<F]V870@
M<&]M;V/M(%,O34E-12XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C0V-PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N(@IM<V=S='(@(EIP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4R]-
M24U%+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B3F5L>F4@</AI9&%T(&MO;G1A:W0N("5S
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J
M:70@:R!,1$%0('-E<G9E<G4N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&)I;F0@=&\@;&1A<"!S
M97)V97(B"FUS9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E<G9E
M<G4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C
M:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").96QZ92!Z:V]N=')O;&]V870@
M^NAE="X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-#0Q"B,L(&9U
M>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E<B(*
M;7-G<W1R(").96QZ92!S92!P^&EP;VII="!K(%--0B!S97)V97)U+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R(%PB)7-<(B!U
M<VEN9R!&5%`Z("5S(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@<V5R
M=F5R=2`G)7,G('!O;6]C[2!&5%`Z("5S(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@9&ES=')I8G7H;NT@<V5Z;F%M+B`E
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,C4*;7-G
M:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(").96QZ
M92!D9;EI9G)O=F%T(%!'4"!D871A+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82XB"FUS9W-T<B`B3F5L>F4@9&6Y:69R;W9A="!3+TU)344@
M9&%T82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C(T-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L
M971E(&-O;G1A8W0N("5S(@IM<V=S='(@(DYE;'IE('-M87IA="!K;VYT86MT
M+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DYE;'IE('-M87IA
M="!D:7-T<FEB=>AN[2!S97IN86TN("5S(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G
M<W1R(").96QZ92!S;6%Z870@;F%S=&%V;W9A8^T@<VMR:7!T('!R;R!A:W1U
M86QI>F%C:2`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU,PIM
M<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(@IM<V=S='(@(DYE;'IE('IJ:7-T:70@92UM86EL;W9O
M=2!A9')E<W4@</CM:F5M8V4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@(D-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DYE;'IE('KM<VMA
M="#Z<&QN_2!A9')E<^'X+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@
M8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(DYE;'IE('KM
M<VMA="#Z<&QN_2!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O
M=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I
M;VX@;&ES=',N(@IM<V=S='(@(DYE;'IE('KM<VMA="#Z<&QN_2!S97IN86T@
M9&ES=')I8G7H;NUC:"!S97IN86WY+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/
M5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2YP:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B4W1R871E
M9VEE("<E<R<@:F4@;F5D;W-T=7!NX2XB"@HC.B!F<F%M97=O<FLO5D937TE3
M3U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z
M,3$P"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B
M3F5L>F4@>F%L;[YI="`G)7,G+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Q.0IM<V=I9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@
M:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB"FUS9W-T<B`B3F5L>F4@>NUS:V%T
M('9E^&5J;OT@:VSMZ"!Z(&ML[>AO=NEH;R!S97)V97)U+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3F5L
M>F4@;W1E=OCM="`G)7,G(&L@>N%P:7-U+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<W"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(V,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB"FUS9W-T<B`B3F5L>F4@;W1E
M=OCM="`E<RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C0Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E
M;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<R(*;7-G<W1R(").96QZ92!P
M<F]VZ7-T(&]P97)A8V4@^F1ROF)Y('!R;R!M;V1U;"`E<R(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HW,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@
M;W1E=OCM="!A9')E<^'X("<E<R<N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR,S<@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-CDY
M"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R
M=F5R+B(*;7-G<W1R(").96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(DYE;'IE
M(.CM<W0@)7,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*
M;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*
M;7-G<W1R("(B"B).96QZ92!R97-E=&]V870@:&5S;&\@<')O(&1A;NEH;R!U
MOFEV871E;&4N(%:Y96-H;GD@;F5B;R!N[&MT97+I('H@(@HB<&]D<F]B;F]S
M=.T@;F5B>6QY('-P<N%V;NP@>F%DX6YY+B!::W5S=&4@=&\@>FYO=G4@;F5B
M;R!P;VMU9"!P;W3X96)U:F5T92`B"B)P;VUO8RP@:V]N=&%K='5J=&4@<W!R
MX79C92!S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,P.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-#`*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S<W"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,X,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.#D*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M3F5L>F4@>NUS:V%T($%#3"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DYE
M;'IE('KM<VMA="!A9')E<^'X+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B
M"FUS9W-T<B`B3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C0S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(").96QZ92!Z[7-K870@
M9&ES=')I8G7H;NT@<V5Z;F%M>2X@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(").96QZ92!Z[7-K870@
M<V-H;W!N;W-T:2!S97)V97)U(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(").96QZ92!P^&5P;F]U="!K;VYF:6=U<F%C:2XB"@HC.B!F<F%M
M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'`Z.30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE(&]D<W1R86YT
M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B3F5L>F4@=6QOOFET(&MO;F9I9W5R86-I('!R;R`E<RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z-3D*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BXB"FUS9W-T<B`B3F5L>F4@=6QOOFET('KA;&^^;NT@:V]N
M9FEG=7)A8VDN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(DYE;'IE('5L;[YI="!ZX6QO
MOF[M(&MO;F9I9W5R86-I("5S+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R
M(").96QZ92!U;&^^:70@;F%S=&%V;W9A8^T@<V-R:7!T('!R;R!A:W1U86QI
M>F%C:2!D;SH@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(").96QZ92!U;&^^
M:70@>N%L;VAU(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB;W!T:6]N
M<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL
M>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB3F5L>F4@>F%P
M<V%T+B!-^;YE=&4@<&]UONUT('-K<FEP="!P<F\@86MT=6%L:7IA8VD@;F5B
M;R!R=>AN["!Z:V]P[7)O=F%T("(*(F[MOF4@=79E9&5N_2!K\V0@9&\@)7,N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G:60@
M(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").
M96QZ92!H;&5D870@=B!,1$%0('-E<G9E<G4N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@;V1P;VII="`G)7,G+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N
M=&%C="X@)7,B"FUS9W-T<B`B3F5L>F4@86MT=6%L:7IO=F%T(&MO;G1A:W0N
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3F5L>F4@86MT=6%L
M:7IO=F%T(&1I<W1R:6)UZ&[M('-E>FYA;2X@)7,B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z-S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM
M<V=S='(@(DYE;'IE('5L;[YI="!K;VYF:6=U<F%C:2!P<F\@)R5S)SH@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V"FUS9VED(")#;W5L9&XG
M="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED
M96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"B).96QZ92!N86SI>G0@8F_H;NT@
M;&FY='4@<')O($UO>FEL;'4N(%!R;W/M;2!P^&5S=NQDZ'1E('-E+""^92!J
M92!O=&5V^&5NX2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ-30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(D-O
M=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@
M9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G<W1R(")5OFEV871E;&D@
M)R5S)R!N96QZ92!P;W-K>71N;W5T(&[A<VQE9'5J[6/M('!RX79A('!R;R!S
M;&^^:W4@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B3V1P;^CM=&%N_2!T
M97AT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-CD*
M;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`B6F5M["(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HR-S,*;7-G:60@(D-O=7)S97,B"FUS9W-T<B`B5GEU
MZ&]V86/M('#X961M['1Y(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`B5GET=F_X:70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB
M"FUS9W-T<B`B5GET=F_X:70@;V1K87HB"@HC.B!T96UP;&%T97,O<')E9G,O
M:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE
M(@IM<V=S='(@(E9Y='9O^&ET(&YO=F]U(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@(D-R96%T92!S=6(@9F]L
M9&5R<R(*;7-G<W1R(")6>71V;_AI="!P;V1S;&^^:WDB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(T,`IM<V=I9"`B0W)E871O<B!097)M
M:7-S:6]N<R(*;7-G<W1R(")4=OER8V4@<'+A=B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,R,S`*;7-G:60@(D-R961I="!C87)D(&YU;6)E<B(*
M;7-G<W1R("+([7-L;R!K<F5D:71N[2!K87)T>2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS
M9VED(")#<F]A=&EA(@IM<V=S='(@(D-H;W)V871S:V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#=6)A(@IM<V=S='(@(DMU8F$B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z,C8*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS
M9W-T<B`B06MT=>%L;NT@9N%Z92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")4
M=OER8V4@<'+A=B(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C
M:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D%K
M='7A;&[M(.AA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS
M9W-T<B`B06MT=>%L;NT@55),(&IE(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,S"B,L(&9U>GIY"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(D%K
M='7A;&[M(&;A>F4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U"FUS9VED
M(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B06MT=>%L;NT@<&_H87/M(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(W-0IM<V=I9"`B0W5R
M<F5N="!C;VYD:71I;VXZ("(*;7-G<W1R(")!:W1UX6QN[2!P;V1M[6YK>3H@
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M,@IM<V=I9"`B0W5R<F5N="!S='EL92(*;7-G<W1R(").>6[L:KGM('-T>6PB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L('!H<"UF;W)M870*
M;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E
M<RXB"FUS9W-T<B`B3F%S=&%V96[M(/IK;VSY('!R;W;A9.QN_6-H('#X:2!P
M^&EH;.&Y96[M(&1O("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@
M(E9Y<W3X:6AN;W5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T('-E;&5C=&EO;B(*;7-G<W1R(")6
M>7-T^&EH;F]U="!V_6+L<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*
M;7-G<W1R(")+>7!R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#(*;7-G
M:60@(D-Y<FEL;&EC("A+3TDX+5(I(@IM<V=S='(@(D%Z8G5K82`H2T])."U2
M*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")!>F)U:V$@*%=I;F1O=W,M,3(U
M,2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL
M:6,O56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(D%Z8G5K82]5:W)A:FEN
M82`H2T])."U5*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Z96-H(%)E<'5B;&EC
M(@IM<V=S='(@(LAE<VOA(')E<'5B;&EK82(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N
M8V4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R(")$
M96YN["(*"B,Z(&%D;6EN+V1A=&%T<F5E+G!H<#HV-0IM<V=I9"`B1&%T851R
M964@0G)O=W-E<B(*;7-G<W1R(")$871A5')E92!P<F]H;.V^9>@B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,
M;V]K=7`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY
M"FUS9VED(")$871E(@IM<V=S='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O87!P<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B
M"FUS9W-T<B`B4/AI:F%T;R!D;F4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")6_6+L
M<B!D871U;74B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*
M;7-G<W1R(")$96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(E-M85]Z870@<VQO=7!E8R(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0U,`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<V"FUS9VED(")$96-E;6)E<B(*;7-G<W1R
M(")0<F]S:6YE8R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*
M;7-G<W1R("+([7-L82!D97/M=&MO=ND@<V]U<W1A=GDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R
M96%S92!);F1E;G0B"FUS9W-T<B`B6FUE;KEI="!O9'-A>F5N[2(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z
M,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(DEM<&QI8VET;NTB"@HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I
M9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("));7!L:6-I=&[M(&)A<G9A(@H*
M(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HY,0IM<V=I9"`B
M1&5F875L="!)9&5N=&ET>2(*;7-G<W1R("));7!L:6-I=&[M(&ED96YT:71A
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8W"B,L(&9U>GIY"FUS9VED
M(")$969A=6QT(%-H96QL(@IM<V=S='(@(DEM<&QI8VET;NTB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S,*;7-G:60@(D1E9FEN:71I;VYS(@IM<V=S
M='(@(D1E9FEN:6-E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0S
M.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]L
M:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-M87IA="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS,@HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($-E;&PB"FUS9W-T<B`B4VUA
M>F%T(&)U\FMU(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O
M=7!S+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")3;6%Z
M870@<VMU<&EN=2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M.0HC+"!F=7IZ>0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")3;6%Z870@
M^.%D96LB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS9VED(")$96QE=&4@
M4&5R;6ES<VEO;B(*;7-G<W1R(")3;6%Z870@<'+A=F$B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E
M(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")3;6%Z870@82!V>>AI<W1I
M="!Z<'+A=GDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")3
M;6%Z870@8G7R:W4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@8V]L=6UN(@IM<V=S
M='(@(E-M87IA="!S;&]U<&5C(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B4VUA>F%T(&5X:7-T=6KM8^T@86QT97)N871I=F[M('9Z;W(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<
M(B5S7"(B"FUS9W-T<B`B4VUA>F%T('!RX79A('!R;R`G)7,G(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3;6%Z870@<'+A=F$@
M82!P;V1P<N%V82!P<F\@)R5S)S\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W
M(@IM<V=S='(@(E-M87IA="#XX61E:R(*"B,Z('1E;7!L871E<R]P<F5F<R]D
M96QE=&5I9&5N=&ET>2YI;F,Z,34*;7-G:60@(D1E;&5T92!S96QE8W1E9"!I
M9&5N=&ET>2(*;7-G<W1R(")3;6%Z870@=GEB<F%N;W4HZ2D@:61E;G1I='4H
M>2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB
M"FUS9W-T<B`B4VUA>F%T('-O=>AA<V[]('-L;W5P96,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G
M:60@(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`B4VUA>F%T('-O
M=>AA<V[](/CA9&5K(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")+;VYF:6=U<F'H;NT@<V-R
M:7!T('!R;R!A:W1U86QI>F%C:2`G)7,G(&)Y;"!S;6%ZX6XN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U,PIM<V=I9"`B1&5L:79E<GD@=&EM92(*;7-G<W1R("+(87,@9&]R
M=>AE;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(D3A
M;G-K;R(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS
M9VED(")$97-C<FEB92!T:&4@4')O8FQE;2(*;7-G<W1R(")0;W!S870@<')O
M8FSI;2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDS."!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R(")0;W!I<R(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO
M<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(E!O9')O8FYO<W1I("AT86OI('8@
M;&]G('-O=6)O<G4@2&]R9&4I.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3DY"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")0;V1R;V)N;W-T:2!B>6QY
M('IA>FYA;65NX6YY(&1O(&QO9R!S;W5B;W)U('!R;R!A9&UI;FES='+A=&]R
M82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C$Y"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R(")6_79O:B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B4F]S;OT@8F]D
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*;7-G:60@(D1E=R!0;VEN
M="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4F]S;OT@8F]D('IA('!O<VQE
M9&[M(&AO9&EN=3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-PIM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T<B`B4F]S;OT@8F]D.B`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X
M"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3;>QR
M('H@;&5V82!D;W!R879A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHS.0IM<V=I9"`B1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0B"FUS9W-T<B`B4VWL<B!Z('!R879A(&1O;&5V82(*"B,Z(&QI8B]";&]C
M:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B061R
M97/A^"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B6F]B<F%Z:70@,C0M:&]D
M:6YO=OT@Z&%S/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-PIM<V=I
M9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@(DUOOFYO<W1I('IO8G)A>F5N
M[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R("):
M;V)R87II="!P^&5D<&]V[.\@*%1!1BDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@
M(EIO8G)A>FET('#X961P;W;L[R`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM<V=S='(@
M(D9O<FWA="!Z;V)R87IE;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$
M3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I;VXB"FUS
M9W-T<B`B1&ES<&]Z:>AN[2!U<&]Z;W)N[&[M(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I
M9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8F]U=&DB"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E;&5T92(*
M;7-G<W1R(").97-M87IA="(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'`B"FUS9W-T<B`B3F5P^&ES='5P;W9A="!P^.UM;R!D;R!M86EN=&5N
M86YC92YP:'`B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ,B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ,@IM<V=I9"`B1&]E<R!T:&4@
M9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H
M96-K('1H:7,@8F]X.B(*;7-G<W1R("(B"B)/8G-A:'5J92!P<G9N[2#XX61E
M:R!NX7IE=B!S;&]U<&/Y/R!0;VMU9"!A;F\L('IAN6MR=&[L=&4@=&5N=&\@
M<N%M9>AE:SHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M(")$;VUI;FEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U
M8FQI8R(*;7-G<W1R(")$;VUI;FEKX6YS:^$@<F5P=6)L:6MA(@H*(SH@=&5M
M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHY-@IM<V=I9"`B1&]N)W0@:&%V92!A
M;B!A8V-O=6YT/R!3:6=N('5P+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#0*;7-G:60@(D1O=VYL;V%D(@IM
M<V=S='(@(E-T8;YE;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E
M;G1S+G!H<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B
M"FUS9W-T<B`B4W1AOF5N[2`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(E-T86AN;W5T(&=E;F5R;W9A;F]U
M(&MO;F9I9W5R86-I(&IA:V\@4$A0('-K<FEP="XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G
M<W1R(")2;VQE=&]V_2!S97IN86TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=Y(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")%+4UA:6PB"FUS
M9W-T<B`B12UM86EL(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R
M(")%:W;A9&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B
M57!R879I="(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C
M:R(*;7-G<W1R(")5<')A=FET(&)L;VLB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*
M;7-G<W1R(")5<')A=FET('-K=7!I;G4B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`B57!R879I="!P
M<N%V82(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,B"FUS9W-T<B`B57!R879I="!P<N%V82(*"B,Z
M('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B161I="!097)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B57!R879I
M="!P<N%V82!P<F\@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")5<')A=FET(&UO
MOFYO<W1I('!R;SHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,V-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B161I="!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E5P<F%V:70@<'+A=F$@<')O("5S
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")5
M<')A=FET('!RX79A('!R;R`E<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(E;]=6MA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=Y<'0B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C,Q,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%
M:71H97(@96YA8FQE(&ET('1H96XZ("5S+"!O<B!U<V4@=&AE(&)A<VEC($A4
M34P@=F5R<VEO;CH@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B4')V96LN+BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B
M16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-CD*
M;7-G:60@(D5M86EL(@IM<V=S='(@(D5M86EL(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@=&5M<&QA=&5S+V%D;6EN+V=R;W5P
M<R]E9&ET+FEN8SHQ,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5M86EL;W;A
M(&%D<F5S82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,*;7-G
M:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%;6%I
M;&]VZ2!A9')E<WD@<V4@;75S[2!S:&]D;W9A="XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ.3@Y"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R(")%;6%I;"!S('!O='9R>F5N[6TB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA
M:6PM=&\M4TU3($=A=&5W87DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS
M(@IM<V=S='(@(DEK;VYK>2!S(&5M;V-E;6DB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D5M<'1Y
M(&UE<W-A9V4N(@IM<V=S='(@(E!RX7ID;N$@>G!RX79A+B(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HR-#,@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW
M,#4*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-3`*;7-G:60@
M(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B4'+A>F1N_2!V_7-L961E:RXB"@HC
M.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3$S"FUS9VED(")%
M;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B4'+A>F1N_2!T97)M[6X@<')O
M('9Y:&QE9.%VX6[M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T,PIM
M<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B4&]V;VQI="!V:VSA9.%N[2!O
M8G)A>FOY('H@9F]T;R!G86QE<FGM(&1O('1E>'1U/R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3@*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_(@IM<V=S='(@(D%K=&EV;W9A="!P<F%VZ2!K;&EK;G5T
M[2!P<F\@:V]N=&5X=&]VZ2!M96YU/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0IM<V=I
M9"`B16YD('EE87(B"FUS9W-T<B`B2V]N96,@<F]K=2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R
M9V4@161I=&]R(@IM<V=S='(@(EIV['2Y:70@961I=&]R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET
M>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E
M9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H
M92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(EIA9&5J=&4@8F5Z
M<&7H;F]S=&[M(&]TX7IK=2P@;F$@:W1E<F]U(&)U9&5T92!M=7-E="!O9'!O
M=NQD['0@<&]K=60@<VD@(@HB8G5D971E(&-H=.UT(')E<V5T;W9A="!S=ND@
M:&5S;&\L(&YA</@N("=*86OI(&IE(&IMZ6YO(%9AN65H;R!P<V$_)SHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G
M<W1R("):9&4@=FQOOFET(%523"!O8G+A>FMU(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE
M(&QE='1E<G,@8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HW-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(E)O=F[M:V]VX2!'=6EN96$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<Q"FUS9VED(")%<FET<F5A(@IM<V=S='(@(D5R:71R96$B
M"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]S=&%T=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HT-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP
M.C@R"FUS9VED(")%<G)O<B(*;7-G<W1R(")#:'EB82(*"B,Z(&9R86UE=V]R
M:R]496UP;&%T92]496UP;&%T92YP:'`Z-#8S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B
M3F%S=&%L82!C:'EB82!P^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB"@HC
M.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,B"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G
M.B`E<R(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!O9&5S[6SA;NT@;V1P
M;W;L9&DZ("5S+B(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP
M:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T
M:6YG(&-O;G1E;G0Z("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D
M97/M;.%N[2!O9'!O=NQD:3H@)7,N(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S
M<W=O<F0N<&AP.C<V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O
M<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,B"FUS9W-T<B`B3F%S=&%L82!C:'EB
M82!P^&D@;V1E<^ULX6[M(&]D<&]V[&1I.B`E<RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#4*;7-G:60@(D5R
M<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B3F%S=&%L82!C:'EB
M82!S('!ON71O=F[M('IP<N%V;W4N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<
M(B5S7"(N(@IM<V=S='(@(D-H>6)A('#X:2!ZX7!I<W4@)R5S)RXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(D5S=&]N<VMO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW,0IM<V=I9"`B171H:6]P:6$B"FUS9W-T<B`B171I;W!I92(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S
M='(@(D5T;FEC:^DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")%=G)O<&$B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R>2`Q-2!M:6YU=&5S(@IM
M<V=S='(@(DMAOF3]8V@@,34@;6EN=70B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS9W-T<B`B2V&^
M9.D@,B!M:6YU='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,V(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS.#<*;7-G:60@(D5V97)Y(#,P('-E8V]N
M9',B"FUS9W-T<B`B2V&^9/UC:"`S,"!S96MU;F0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")+8;YD_6-H(#4@;6EN=70B
M"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C8P
M"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")+8;YDZ2!P^&EH;.&Y96[M
M(&1O('-Y<W3I;74B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS
M9VED(")%=F5R>2!H86QF(&AO=7(B"FUS9W-T<B`B2V&^9&]U('#Y;"!H;V1I
M;G4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,W(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS.#@*;7-G:60@(D5V97)Y(&UI;G5T92(*;7-G<W1R(")+
M8;YD;W4@;6EN=71U(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z
M,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R(")6>F]R;W;]('#X
M[6ML860@:&]D;F]T.B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HX,2!A9&UI
M;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L<VAE;&PN<&AP.C$R-PIM<V=I
M9"`B17AE8W5T92(*;7-G<W1R(")0<F]VZ7-T(@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U"FUS9VED(")%>'!A;F0B"FUS9W-T
M<B`B4F]Z=FEN;W5T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN
M8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B4F]Z8F%L:70@
M8F_H;NT@;&FY='4B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP
M:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B3^AE:^%VX6YA
M("<I)R(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-S4*
M;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FTB"FUS9W-T<B`B3^AE:^%VX6YO('-A;6]S=&%T;ND@<VQO=F\@;F5B;R!H
M;&5D86[]('1E<FWM;B!V('5V;WIO=FOA8V@B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I;VX@1&%T92(*
M;7-G<W1R(")$871U;2!P<F\@:V]N96,@<&QA=&YO<W1I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X<&]N96YT
M(@IM<V=S='(@(D5X<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS
M9W-T<B`B0F%R=F$@<&]P^&5D[2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-S<*;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B4/AE
M;F]S(&MO;F9I9W5R86-E('!O;6]C[2!&5%`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR,38*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R(")396QH86QO('KM<VOA;NT@;6^^;F]S
M=.TN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<U(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z.3@*;7-G:60@(D9A:6QE9"!T
M;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(").96QZ92!S92!P
M^&EP;VII="!K($Q$05`@<V5R=F5R=2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--
M0B!S97)V97(N(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET(&L@4TU"('-E
M<G9E<G4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N
M(@IM<V=S='(@(E-E;&AA;&\@:V]P[7)O=N%N[2!Z(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")&86EL960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(E-E;&AA
M;&\@:V]P[7)O=N%N[2!D;R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")396QH86QO('IA;&^^96[M(&YO
M=NEH;R!305-,('-P;VIE;NTN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT.3<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C0*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*;7-G
M<W1R(")396QH86QO('#X97-U;G5T[2!D;R!<(B5S7"(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B4V5L:&%L
M;R!P^&5S=6YU=.T@9&\@7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(D1O
M8G+I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L
M=FEN87,I(@IM<V=S='(@(D9A;&ML86YD<VOI(&]S=')O=GD@*$UA;'9I;GDI
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R(")&
M87)I:G-KZ2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S
M.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM<V=S='(@(EKA=F&^;N$@8VAY8F$Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS-#D*(RP@9G5Z>GD*;7-G:60@(D9A>&5S(@IM<V=S='(@
M(D9A>"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0T,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C8V"FUS9VED(")&96)R=6%R>2(*;7-G<W1R("+:;F]R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M0^UT:70@<V4@:F%K;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S$*;7-G:60@(D9E96QS(&QI:V4Z("(*;7-G<W1R(")#[71I="!S92!J
M86MO.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Y"FUS9VED(")&97<@4VAO=V5R<R(*;7-G<W1R(")$<F]B;ND@</AE:.'R
M:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M,`IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")$<F]B;ND@<V[L
M:&]VZ2!P^&5HX?)K>2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y
M-#0*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-871I8V4@<&]L92(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S0*;7-G:60@(D9I9VQE
M="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B1FEL92(*
M;7-G<W1R(")S;W5B;W(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM
M<V=S='(@(E!OZ&5T('-O=6)O<ODZ("5S('-O=6)O<B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@
M0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(E!OZ&5T('-O=6)O<ODZ("5S('-O
M=6)O<ODB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`W"FUS9VED
M(")&:6QE($UA;F%G97(B"FUS9W-T<B`B4W!RX79C92!S;W5B;W+Y(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*
M;7-G<W1R(").X7IE=B!S;W5B;W)U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,CDY-0IM<V=I9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`B5OUB
M['(@<V]U8F]R=2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T.#8*
M;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(E#X96[I<W0@<V]U8F]R(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B4/AE;F]S('-O
M=6)O<OD@;F5N[2!P;V1P;W)O=N%N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HX.0IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R(")&:6QT<GDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")&:6YL86YD(@IM<V=S='(@(D9I;G-K;R(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HQ-C8*;7-G:60@(D9I<G-T($AA;&8B"FUS
M9W-T<B`B4')V;NT@<&]L;W9I;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-S0@;&EB+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R
M(@IM<V=S='(@(E!R=F[M(.AT=G)T:6YA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(U-@IM<V=I9"`B1FEX(')A=&EO(@IM
M<V=S='(@(E!E=F[I(&WL^.UT:V\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(E#X
M96AO9&ET(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS,@IM<V=I9"`B1FQO870B"FUS9W-T<B`B4&QO=F]U8^TB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,0IM
M<V=I9"`B1F]G(@IM<V=S='(@(DUL:&$B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W
M"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES
M="(*;7-G<W1R(")3;&^^:V$@)7,@;F5E>&ES='5J92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@
M0V]L;W(B"FUS9W-T<B`B0F%R=F$@<.US;6$B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B"FUS9W-T<B`B2NUD;&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@
M:6UA9V5S(@IM<V=S='(@(E!R;R!P<F]H;.V^9>AE(&YE<&]D<&]R=6KM8^T@
M;V)RX7IK>2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S,T"FUS9VED(")&
M;W)E8V%S="`H5$%&*2(*;7-G<W1R(")0^&5D<&]V[.\@*%1!1BDB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-SD*;7-G:60@(B(*(D9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS9W-T<B`B(@HB
M4/AE9'!O=NSO('!OZ&%S[2!P<F\@9&YY("AP;WINX6UK83H@</AE9'!O=NSO
M(&IE('!R;R!D;GD@:2!N;V-I.R!T;W1O(&WYOF4@(@HB=GET=F_X:70@<&]M
M[')N["!O8G/A:&S]('-E>FYA;2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G
M:6XN:6YC.C$P,@IM<V=I9"`B1F]R9V]T('EO=7(@<&%S<W=O<F0_(@IM<V=S
M='(@(EIA<&]M;NQL:2!J<W1E(%9AN64@:&5S;&\_(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0V,@IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B1F]R
M;75LX?AE(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&
M;W)T=6YE(@IM<V=S='(@(JET['-T[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1Y<""Y=.QS
M=.TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U
M;F5S(@IM<V=S='(@(JET['-T[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R("*I=.QS=.T@,B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*;7-G:60@(D9O<G5M<R(*
M;7-G<W1R(")&\W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$P
M.0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B4/AE<&]S;.%N[2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C`*;7-G:60@
M(D9R(@IM<V=S='(@(E#A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(E+A;7DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#,*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B1G)A
M;F-I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I
M9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;F-I92P@;65T
M<F]P;VQI=&[M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*
M;7-G<W1R(")&<F%N8V]U<VOA($=U86GA;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B1G)E;F-H(%!O;'EN97-I82(*;7-G<W1R(")&<F%N8V]U<VOA(%!O;'EN
MZ7-I92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E
M<G)I=&]R:65S(@IM<V=S='(@(D9R86YC;W5S:^$@:FF^;NT@=&5R:71O<FEA
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M-`IM<V=I9"`B1G)O;2(*;7-G<W1R(")/9"(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`V"FUS9VED
M(")&<F]M('1H92`B"FUS9W-T<B`B3V0B"@HC.B!T96UP;&%T97,O<')O8FQE
M;2]P<F]B;&5M+FEN8SHT.`IM<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G
M<W1R(")0;V1R;V)N_2!P;W!I<R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX
M,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V"FUS9VED(")&=6QL($UO;VXB"FUS
M9W-T<B`BVG!L;NQK(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E
M;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@
M3F%M92(*;7-G<W1R(")#96SI(&IMZ6YO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1V%B;VXB"FUS9W-T<B`B1V%B;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE
M<GD@=&\@=&%K92!I;6%G92!F<F]M(@IM<V=S='(@(D=A;&5R:64@<')O(';]
M8NQR(&]B<N%Z:_DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S
M='(@(D=A;&5R:64Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S
M='(@(D=A;6)I92(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*
M;7-G<W1R(")6>71V;_AI="`E<R!K;VYF:6=U<F%C:2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]C;VYF:6<N:'1M;#HX"FUS9VED(")'96YE<F%T960@
M0V]D92(*;7-G<W1R(")6>6=E;F5R;W9A;OT@:_-D(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM
M<V=I9"`B1V5O<F=I82(*;7-G<W1R(")'<G5Z[6YS:V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")'97)M86YY(@IM<V=S='(@(D[L;65C:V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U
M"FUS9VED(")':&%N82(*;7-G<W1R(")':&%N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G
M:60@(D=I8G)A;'1A<B(*;7-G<W1R(")':6)R86QT87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0IM<V=I9"`B1VEV96X@3F%M
M92(*;7-G<W1R(")+^&5S=&[M(&IMZ6YO(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3(*;7-G:60@(D=O(@IM<V=S='(@(DID:2!N82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@
M(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ,3(X"B,L(&9U>GIY"FUS9VED(")';V]G;&4@36%P<R(*;7-G<W1R
M(")6>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU(@H*(SH@;&EB+T)L;V-K+V=O
M;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G<W1R(")6
M>6AL963A=N%N[2!P;VUO8^T@1V]O9VQU(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(E-T=7!N[""Y961I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R("+896-K;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U
M"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T<B`BV&5C:^D@*$E3
M3RTX.#4Y+3<I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W)E96YL86YD(@IM<V=S
M='(@(D=R\VYS:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")'<F5N861A(@IM<V=S
M='(@(D=R96YA9&$B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM<V=I9"`B
M1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R86-E('!R
M;R!S:W5P:6YY(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U
M<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")-=7/M(&+]="!Z
M863A;F\@:FWI;F\@<VMU<&EN>2(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R
M;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($YE;'IE
M('#X:61A="!UOFEV871E;&4@)7,N($ALX;EE;NT@<V5R=F5R=3H@(@H*(SH@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q."!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HT,3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T
M<B`B075T:%]L9&%P.B!.96QZ92!A:W1U86QI>F]V870@=;YI=F%T96QE("5S
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R
M;W5P("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@3F5L>F4@86MT=6%L:7IO=F%T
M('6^:79A=&5L92`E<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S$T(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,X"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3<W"FUS9VED(")'<F]U<',B"FUS9W-T<B`B4VMU
M<&EN>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B
M1W5A9&5L;W5P92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S='(@
M(D=U86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDX"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@
M(D=U871E;6%L82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3(*
M;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHX.`IM<V=I9"`B1W5E<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B
M4'+A=F$@:&]S=/DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<P
M"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B2VYI:&$@:&]S=/DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDW(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")'=6EN96$B"FUS9W-T<B`B1W5I;F5A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<X"FUS9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6YE82U"
M:7-S874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N82(*;7-G<W1R(")'
M=7EA;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@
M(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+B(*;7-G<W1R(")(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z870@<&]S
M;&5D;NT@8G7R:W4@;F$@^.%D:W4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!Z8F%B[&QE(&]D;>UTX2!S;6%Z
M870@<&]S;&5D;NT@8G7R:W4@=F4@<VQO=7!C:2!T86)U;&MY+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#<*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R96$@>F)A8NQL
M92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(/CA9&5K('8@=&%B=6QC92XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%14
M4"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D]V[/AO=N%N
M[2!P;VUO8^T@2%144"!N96)Y;&\@;F%L97IE;F\N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(86ET:2(*;7-G<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B2&%S:"U!;&=O<FET:&TB
M"FUS9W-T<B`B2&%S:"UA;&=O<FET;75S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B
M36QH879O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*;7-G:60@(DAE861E<B(*;7-G<W1R
M(")(;&%V:>AK82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M2&QA=FGH:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D($ES;&%N9"!A
M;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R(")(96%R9"!)<VQA;F0@82!-
M8T1O;F%L9"!)<VQA;F1S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C,*(RP@9G5Z>GD*;7-G:60@(DAE879Y(%0M4W1O<FTB
M"FUS9W-T<B`B0F]U^&MA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#8*
M;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R96JY
M=&EN82`H25-/+3@X-3DM."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G
M<W1R(")6_;EK82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H
M<#HQ-SD@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E
M>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R(").X7!O=NQD82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@
M(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D[A<&]V[&1A('!R;R!E9&ET
M;W(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q"FUS9VED(")(
M96QP97(B"FUS9W-T<B`B4&]M;V-N[6LB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,CD*;7-G:60@(DAE;6ES<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)A(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3`@=&5M<&QA=&5S+V1A
M=&$O8W-V:6YF;RYI;F,Z,3`*;7-G:60@(DAE<F4@:7,@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`B6F1E(&IE('IAZ.%T96L@<V]U8F]R
M=3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M.0IM<V=I9"`B2&EG:"(*;7-G<W1R(")6>7-O:^$B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D
M97(N:6YC.C4*;7-G:60@(DAO7VUE(@IM<V=S='(@(E](;W)D92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,30*;7-G:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I
M(@IM<V=S='(@(E-V873I($WL<W1O("A6871I:^%N*2(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G<W1R(")(
M;W)D92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!D;VWY
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"B,L(&9U>GIY"FUS9VED
M(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")!9')E<^'X(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M
M92!0:&]N92(*;7-G<W1R(")496QE9F]N(&1O;?DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD*
M;7-G:60@(DAO;F1U<F%S(@IM<V=S='(@(DAO;F1U<F%S(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")(;VYG($MO;F<B"FUS9W-T<B`B2&]N9R!+;VYG(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C8U"FUS9VED(")(;W)D92(*;7-G
M<W1R(")(;W)D92(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#0R
M"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S
M(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($YE<&QA=&[I("5S(%A-3"!D871A('9E('IP<N%V["`E
M<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O
M;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@KN%D;N$@
M>G!RX79A('-E(&YE<VAO9'5J92!S(&]B:F5K=&5M("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE
M<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE8GEL(&YA;&5Z96X@
MON%D;OT@;V)J96MT('1Y<'4@)7,@=F4@>G!RX7;L("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(-IS<.RY;ND@;V1S=')A;NQN[2`E<R!<
M(B5S7"(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I
M9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z($EN=&5G<F'H;NT@;N%S=')O:B!P;W3X96)U:F4@4$A0('#X[7!O
M;G4@)V1O;7AM;"<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C4P
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3F5L>F4@=GET=F_X:70@;F]V_2!S=')O;2!834P@<')O
M(&]B:F5K="`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3(T
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.
M96QZ92!O9'-T<F%N:70@)7,@7"(E<UPB.B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z-#<T"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A
M<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5L>F4@>NUS
M:V%T($U)344@240@<')O(.CA<W0@='EP=2`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z,3$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T("5S
M(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S
M,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B
M.B!.96QZ92!S>6YC:')O;FEZ;W9A="!S9.UL96[I(&]B:F5K='DZ("5S(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM
M<V=S='(@(DAO<F1E+TMO;&%B.B!.97INX6W]('-D[6QE;OT@;V)J96MT(%PB
M)7-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,C0*;7-G:60@(DAO<FEZ;VYT86P@4G5L92(*;7-G<W1R(")6;V1O<F]V
M;ND@<')A=NUT:V\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A9&1I;F<B"FUS9W-T
M<B`B2&]R:7IO;G3A;&[M(&]D<W1U<"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM
M<V=S='(@(DAO<FEZ;VYTX6QN[3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(DIA:R!J
M<W1E('-E('-E;2!D;W-T86QI/R`H6F&Y;&5T92!P<F]S[6T@>G!RX79U(2DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R(")+;VQI:R!S;&]U<&/Y(&-H8V5T92!S<&]J
M:70_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@
M(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R
M(")+;VQI:R!J92!T86T@<&]L[2`H<VQO=7!C^2D_(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-@IM<V=I9"`B
M2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T
M<B`B2V]L:6L@^.%D:_D@8VAC971E('-P;VII=#\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]M971A<BYP:'`Z,C,P
M"FUS9VED(")(=6UI9&ET>2(*;7-G<W1R(")6;&AK;W-T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C(U.0IM<V=I9"`B2'5M:61I='DZ("(*
M;7-G<W1R(")6;&AK;W-T.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R;NDB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAU;F=A<GDB"FUS9W-T<B`B36'O87)S:V\B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U
M=&@O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")396QH
M86QO('9Y='9O^&5N[2!)34%0;W;I('-C:'+A;FMY.B`E<R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(Q-"!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G-Q;"YP:'`Z,CDU"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@
M;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-E;&AA;&\@
M<VUA>N%N[2!)34%0;W;I('-C:'+A;FMY.B`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y
M<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O
M>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(E-E;&AA;&\@
M;F%S=&%V96[M(&MV\W1Y('!R;R!)34%0;W9O=2!S8VARX6YK=3H@)7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R
M97-S(@IM<V=S='(@(DE0(&%D<F5S82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:7!B87-I8RYP:'`Z-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`B25`@861R97-A(&YE;NT@9&]S='5P;N$N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T
M<B`B25`@861R97-A(&YE;NT@=B!P;W9O;&5NZ6T@0TE$4B!R;WIS86AU+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")0
M;W)UN65N[2!I;G1E9W)I='D@25`N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED("))7VYS97)T
M(%)O=R!"969O<F4B"FUS9W-T<B`B5E]L;[YT92#XX61E:R!P^&5D(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;&%N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@(DEC;VYS($]N;'DB
M"FUS9W-T<B`B4&]U>F4@:6MO;GDB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(DEK;VYY('!R;R`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R(")):V]N>2!S('1E
M>'1E;2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ.3`*;7-G:60@(DED
M96YT:71Y)W,@;F%M93HB"FUS9W-T<B`B3N%Z978@:61E;G1I='DZ(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DR"B,L('!H<"UF
M;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B4&]K
M=60@>F]B<F%Z96[M(&YE;NT@=B!P;_CA9&MU+"`E<R!O=&5V^.UT('8@;F]V
MZ6T@;VMN["XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED
M("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE
M="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X
M('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*(E!O
M:W5D('!O=;[M=N%T92!);G1E<FYE="!%>'!L;W)E<B!A(&YE=FED[71E(+[A
M9&[I(&EK;VYY+"!Z^&5J;>P@<&]T^&5B=6IE=&4@(@HB;WIN8>AI="!T96YT
M;R!RX6UEZ&5K('!R;R!V>7!N=73M(%!.1R!T<F%N<W!A<F5N8V4N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W,PIM<V=I
M9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T
M:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L
M87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E!O:W5D('9I9.UT
M92!T=71O('IP<N%V=2!M[7-T;R!O8G+A>FMU+"!O8G+A>F5K(&MT97+](&-H
M8V5T92!P^&5NZ7-T(&YE;'IE("(*(E9AN>UM('!R;VAL[;YEZ&5M('IO8G)A
M>FET+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T
M<B`B3N%H;&5D(&]B<N%Z:W4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM
M<V=S='(@(E523"!O8G+A>FMU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(Q"FUS9VED("));6%G92!5
M4DPZ(@IM<V=S='(@(E523"!O8G+A>FMU.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B
M26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(D]B<N%Z96L@>B!G86QE<FEE
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S
M='(@(D]B<N%Z96L@>B!G86QE<FEE.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$W-C$*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R(")0^&5N
M;W,@;V)RX7IK=2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED
M("));6%G97,B"FUS9W-T<B`B3V)RX7IK>2(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3
M=&5P("5D(@IM<V=S='(@(DEM<&]R="P@:W)O:R`E9"(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1O=F%NZ2!P;VQE.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T;W9A;N$@<&]L93HB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E9L;[YI
M="#XX61K=2!Z82(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z
M:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+B(*;7-G<W1R(")">6P@>F%DX6X@;F5S<'+A=F[](&%KZ&[M(&OS9"XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M,@IM<V=I9"`B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B3F5S<'+A=F[L('IA9&%NZ2!UOFEV871E;'-KZ2!J;>EN;R!A
M+VYE8F\@:&5S;&\N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M3F5S<'+A=F[I('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@86QT97)N871I=F[M
M(&%D<F5S82X@6FMU<W1E(&IEN73L(&IE9&YO=2`B"B)N96)O(&MO;G1A:W1U
M:G1E(%9AN65H;R!S>7-TZ6UO=NEH;R!A9&UI;FES='+A=&]R82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED
M("));F-R96%S92!);F1E;G0B"FUS9W-T<B`B6G;L=+EI="!O9'-A>F5N[2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS9W-T<B`B26YD:64B"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*
M;7-G<W1R(")*961N;W1L:7;M('6^:79A=&5LZ2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]NZ7-I92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN
M9F\B"FUS9W-T<B`B26YF;W)M86-E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M
M86-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,S,`HC+"!F
M=7IZ>0IM<V=I9"`B26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92XB
M"FUS9W-T<B`BKN%D;ND@>B!M;[YN;W-T[2!N96IS;W4@9&]S='5P;NDN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R(")6
M;&^^:70@<U]L;W5P96,@>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!)
M;6%G92(*;7-G<W1R(")6;&^^:70@;V)RX7IE:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@(DEN<V5R="!4
M86)L92(*;7-G<W1R(")6;&^^:70@=&%B=6QK=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C4*;7-G:60@(DEN<V5R="!7
M96(@3&EN:R(*;7-G<W1R(")6;&^^:70@=V5B;W;](&]D:V%Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T
M"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B5FQOOFET
M(%]S;&]U<&5C('#X960@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R(")6;&^^:70@
M;F]V_2!S;&]U<&5C('IA('-O=>AA<V[](@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T
M<B`B5FQOOFET(&YO=OT@<VQO=7!E8R!P^&5D('-O=>AA<V[](@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8R
M"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N
M92(*;7-G<W1R(")6;&^^:70@;F]V_2#XX61E:R!Z82!S;W7H87-N_2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(E9L;[YI="!N;W;](/CA9&5K('#X960@<V]UZ&%S
M;OTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(E9L;[YI="!O9'-T879E8R!Z82!S
M;W7H87-N_2!U>F5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A
M<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B5FQOOFET(&]D
M<W1A=F5C('#X960@<V]UZ&%S;OT@=7IE;"(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM
M<V=S='(@(E9L;[YI="!A;'1E<FYA=&EV;NT@=GIO<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R
M97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D
M.B(*;7-G<W1R(")6;&^^=&4@96UA:6QO=F]U(&%D<F5S=2P@;F$@:W1E<F]U
M(&]B9'*^[71E(&YO=ND@:&5S;&\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS97)T(&-E
M;&P@869T97(B"FUS9W-T<B`B5FQOOFET(&)U\FMU('IA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.0IM<V=I
M9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(E9L;[YI="!B=?)K=2!P
M^&5D(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*;7-G<W1R
M(")6;&^^:70@<VQO=7!E8R!Z82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!C;VQU
M;6X@8F5F;W)E(@IM<V=S='(@(E9L;[YI="!S;&]U<&5C('#X960B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B
M26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(E9L;[YI="!Z<'+A=GDB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#4*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@869T97(B"FUS9W-T<B`B5FQO
MOFET(&]D<W1A=F5C('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E<G0@<&%R86=R
M87!H(&)E9F]R92(*;7-G<W1R(")6;&^^:70@;V1S=&%V96,@</AE9"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B5FQOOFET(/CA
M9&5K('IA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T
M<B`B5FQOOFET(/CA9&5K('#X960B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,C,P"FUS9VED("));G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T
M:&4@<V5C=7)I='D@<75E<W1I;VXZ(@IM<V=S='(@(E9L;[YT92!P;[YA9&]V
M86YO=2!O9'!O=NSO(&YA(&)E>G!EZ&YO<W1N[2!O=.%Z:W4Z(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B
M26YS97)T+TUO9&EF>2!);6%G92(*;7-G<W1R(")6;&^^:70O=7!R879I="!O
M8G+A>F5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(E9L
M;[YI="]U<')A=FET(&]D:V%Z(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S
M='(@(DYE9&]S=&%T9>AN_2!K<F5D:70@:R!O9&5S;.%N[2!Z<'+A=GD@;F$@
M9&ES=')I8G7H;NT@<V5Z;F%M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I8VEE;G0@
M8W)E9&ET+B(*;7-G<W1R(").961O<W1A=&7H;OT@:W)E9&ET+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-S4*;7-G:60@(DEN=&5G97(B"FUS
M9W-T<B`B0V5LZ2#H[7-L;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Q,S,*;7-G:60@(DEN=&5G97(@;&ES="(*;7-G<W1R(")397IN86T@8V5L
M_6-H(.CM<V5L(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T
M82!(96%D97(I+B(*;7-G<W1R(").97-P<N%V;ND@541(+B`H57-E<B!$871A
M($AE861E<BDN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII
M<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N
M<&AP.C(P,0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HR,3`*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@6DE0(&1A=&$B"FUS9W-T
M<B`B3F5P;&%T;N$@9&%T82!U;FEC;V1E+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S
M='(@(DYE<&QA=&[A(&%P;&EK86-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B
M871C:"!)1"XB"FUS9W-T<B`B3F5P;&%T;ND@:61E;G1I9FEK8>AN[2#H[7-L
M;R`H240I(&3A=FMY+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P
M.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$U.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C,R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R
M.3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS
M-PIM<V=I9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B0GEL
M82!Z863A;F$@;F5P;&%T;N$@9&%T82(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+B(*;7-G<W1R(").97!L871NX2!A9')E<V$@
M</CM:F5M8V4N(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(").97!L
M871N_2!F;W)MX70@<V]U8F]R=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@;&EC96YS92!K
M97DN(@IM<V=S='(@(DYE<&QA=&[A(&%P;&EK86-E+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(DEN=F%L
M:60@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE<&QA=&[A(&%P;&EK
M86-E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B
M3F5P;&%T;OT@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+B(*;7-G<W1R(").97!L871NZ2!N96)O(&-H>6+L:NUC
M[2!A<&E?:60N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RXB"FUS9W-T<B`B3F5P;&%T;ND@;F5B;R!C:'EB[&KM8^T@<&%R
M86UE=')Y+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I
M9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B3F5P;&%T
M;N$@=FQA<W1N:6-KX2!P<N%V82XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<G1N97(@
M:60N(@IM<V=S='(@(DYE<&QA=&[A('9L87-T;FEC:^$@<'+A=F$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0HC+"!F=7IZ>0IM<V=I
M9"`B26YV86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(DYE<&QA=&[]('!R
M;W1O:V]L+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T
M<B`B3F5P;&%T;OT@<')O=&]K;VPN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z.#`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B!<(B5S7"(B"FUS9W-T<B`B3F5P;&%T;OT@</CM
M:F5M8V4Z("<E<R<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P
M-S8@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C8R"FUS9VED("));G9A
M;&ED('-H87)E(&]B:F5C="(*;7-G<W1R(").97!L871N_2!S9.UL96[](&]B
M:F5K="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS
M9W-T<B`B3F5P;&%T;N$@861R97-A(&]D97/M;&%T96QE+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I
M9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(DYE<&QA=&[A(&1A
M=&$@=6YI8V]D92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4W
M"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YV96YTX?@B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<Y"B,L(&9U>GIY
M"FUS9VED("));G9E<G0@<V5L96-T:6]N(@IM<V=S='(@(E9Y<W3X:6AN;W5T
M(';]8NQR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(LURX6XL($ES;.%M<VOA(')E<'5B;&EK82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<N%K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER<VMO(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,34*;7-G:60@(DES;&4@;V8@
M36%N(@IM<V=S='(@(D]S=')O=B!M=;YE(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C0*;7-G:60@(DES;VQA=&5D(%0M4W1O
M<FUS(@IM<V=S='(@(D]J961I;NQLZ2!B;W7X:WDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*
M;7-G:60@(DES<F%E;"(*;7-G<W1R("))<W)A96PB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S
M='(@(E!O<VMY=&]V871E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DMU<GKM
M=F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DETX6QI
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA
M:FMA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B3&5D96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#,*;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<&]N<VMO(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*
M4"DB"FUS9W-T<B`B2F%P;VZY=&EN82`H25-/+3(P,C(M2E`I(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA=F%S8W)I
M<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N9"!T:&ES
M('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L>2XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C(*;7-G
M:60@(DIE<G-E>2(*;7-G<W1R(")4<FEK;W0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIO<F1A;B(*;7-G<W1R(")*;W)DX6YS:V\B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G
M<W1R("+(97)V96YE8R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,#8*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(LAE<G9E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B6F%R;W9N870B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM
M<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B6F%R;W9N870@;F$@<W3X
M960B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(EIA<F]V
M;F%T('9Y<&QN[&[M;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS
M9W-T<B`B6F%R;W9N870@9&]L979A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@
M4FEG:'0B"FUS9W-T<B`B6F%R;W9N870@9&]P<F%V82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-@IM<V=I9"`B2V%Z86MH<W1A;B(*;7-G<W1R(")+87IA8VAS=.%N(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I
M9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B56-H;W9A="!O<FEG:6[A;#\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME\F$B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U"FUS9VED(")+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN(@IM<V=S='(@
M(DME<F)E<F]S('-E<G9E<B!Z86WM=&YU;"!O=NSX96[M+B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,@IM<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS
M9W-T<B`B3F]VX>AC:2!K97)N96QU(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$Q"FUS9VED(")+97D@0W)E871I;VXB"FUS9W-T<B`B
M5GET=F_X96[M(&ML[>AE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B5GET
M=F_X96[M(&]T:7-K=2!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")$Z6QK
M82!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5'EP(&ML[>AE(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(DME>2!5
M<V%G92(*;7-G<W1R(")5OFET[2!K;.WH92(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI<W1S
M(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")+;.WH(&IIOB!E
M>&ES='5J92!N82!V9?AE:F[I;2!K;.WH;W;I;2!S97)V97)U+B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HT,PIM<V=I9"`B2VED<R(*;7-G<W1R(")$
M['1I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R(")+
M:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T<B`B2TQ$4B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DMO
M<F5A(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(DMO<F5A
M;B`H155#+4M2*2(*;7-G<W1R(")+;W)E:G-K>2`H155#+4M2*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(DMU=F%J="(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX,PIM<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R(")+>7)G:7IS=.%N
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHX"FUS9VED("),85]Y
M;W5T(@IM<V=S='(@(E]2;WIL;[YE;NTB"@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C@S"FUS9VED("),86YG=6%G92(*;7-G<W1R(")*87IY:R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@
M4F5P=6)L:6,B"FUS9W-T<B`B3&%O<RP@3&ED;W;L($1E;6]K<F%T:6-K82!2
M97!U8FQI:V$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"FUS9VED("),
M87-T($AA;&8B"FUS9W-T<B`B1')U:.$@<&]L;W9I;F$B"@HC.B!L:6(O0FQO
M8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(DQA<W0@4&%S<W=O
M<F0@0VAA;F=E(@IM<V=S='(@(E;]8VAO>NT@;F%S=&%V96[M(&AE<VQA(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@V(&QI8B]";&]C:R]M;V]N+G!H<#HX
M.`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(E!O<VQE9&[M(.AT=G)T
M:6YA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA<W0@
M57!D871E9#HB"FUS9W-T<B`B4&]S;&5D;NT@86MT=6%L:7IA8V4Z(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E!O<VQE9&[M('#X:6ALX;EE
M;NTZ("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S(Q"B,L('!H
M<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@)7,B"FUS9W-T
M<B`B4&]S;&5D;NT@</AI:&SAN65N[3H@)7,@>B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B
M"FUS9W-T<B`B4&]S;&5D;NT@</AI:&SAN65N[3H@3FEK9'DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),:71V82(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM<V=S='(@(E!RX79O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B4F]Z;&^^96[M(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-@IM<V=I
M9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R(").96-H870@
M<'+A>F1NZ2!B97H@;VMR86IE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED("),96)A
M;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T
M<B`B1&]L979A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$Q.0IM
M<V=I9"`B3&5F="!H96%D97(B"FUS9W-T<B`B3&5VX2!H;&%V:>AK82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*;7-G:60@(DQE9G0@=F%L
M=65S(@IM<V=S='(@(DAO9&YO='D@;F%L979O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS
M9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T:&\B"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM
M<V=S='(@(DSA<VMA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X"FUS9VED("),:6)E<FEA(@IM
M<V=S='(@(DQI8NER:64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI8GEA;B!!
M<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3&EB:64B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*
M;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B3&EC:'1E;KET96IN<VMO
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*
M;7-G:60@(DQI9VAT($1R:7IZ;&4B"FUS9W-T<B`B3&5H:^D@;7)H;VQE;NTB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM
M<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),96AK_2!DZ;F[(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI
M9VAT(%)A:6X@16%R;'DB"FUS9W-T<B`B0G)Z:_T@;&5H:_T@9.FYNR(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(X"FUS9VED
M("),:6=H="!286EN($QA=&4B"FUS9W-T<B`B4&]Z9.QJ:2!L96AK_2!DZ;F[
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*
M;7-G:60@(DQI9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DQE:&OI(&1EN;MO
M=ND@<W+AOFMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S`*;7-G:60@(DQI9VAT(%)A:6X@=VET:"!4:'5N9&5R(@IM<V=S
M='(@(DQE:&O](&3IN;L@<R!H^&WL;NUM(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S$*;7-G:60@(DQI9VAT(%-N;W<B"FUS
M9W-T<B`B3&5H:^D@<V[LOF5N[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*
M;7-G<W1R("),96AKZ2!S;NQH;W;I('#X96CA\FMY(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),:6UE
M<FEC:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@
M(DQI;FLB"FUS9W-T<B`B3V1K87HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I
M;G1S('1O.B(*;7-G<W1R(")/9&MA>GD@=6MA>G5J[2!N83HB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M(@IM<V=S='(@(B(*(E!O=;[M="!O9&MA>GD@;F$@96UA:6QO=ND@861R97-Y
M('#X:2!Z;V)R87IO=N%N[2!S='+A;FMY('!R;R!P<V%N[2!Z<'+A=B(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:'1M;#)T97AT+G!H<#HQ
M.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@(D]D:V%Z>2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@
M(DQI;G5X;W;I(&-O;VMI92(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H
M92!F;VQD97(B"FUS9W-T<B`B4V5Z;F%M("T@=;YI=F%T96P@;?F^92!V:63L
M="!S;&^^:W4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,S"FUS9VED("),
M:7-T($1A=&%B87-E<R(*;7-G<W1R(")397IN86T@9&%T86+A>NTB"@HC.B!S
M97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B3&ES="!(96QP(%1O
M<&EC<R(*;7-G<W1R(")397IN86T@=.EM870@;N%P;W;L9'DB"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,R"FUS9VED("),:7-T(%1A8FQE<R(*;7-G<W1R
M(")397IN86T@=&%B=6QE:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A
M9&5R<RYP:'`Z-3DT"FUS9VED("),:7-T+4%R8VAI=F4B"FUS9W-T<B`B4V5Z
M;F%M+4%R8VAI=B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP
M:'`Z-3@Y"FUS9VED("),:7-T+4AE;'`B"FUS9W-T<B`B4V5Z;F%M+4[A<&]V
M[&1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*
M;7-G:60@(DQI<W0M260B"FUS9W-T<B`B4V5Z;F%M+4ED(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3(*;7-G:60@(DQI<W0M3W=N
M97(B"FUS9W-T<B`B4V5Z;F%M+59L87-T;NUK(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S="(*;7-G
M<W1R(")397IN86TM3V1E<VSA;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS9W-T
M<B`B4V5Z;F%M+5#X:6ALX;EE;NTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R(")397IN86TM3V1H;.&Y96[M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I
M;VYS(&9A:6QE9#H@)7,B"FUS9W-T<B`B5OUP:7,@=;YI=F%T96SY(&YE;NT@
M9&]S='5P;OTN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B
M"FUS9W-T<B`B5OUP:7,@=;YI=F%T96SY(&YE;NT@9&]S='5P;OTN(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")6_7!I<R!UOFEV871E
M;/D@;F5N[2!D;W-T=7!N_2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5R82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQO='FY<VMO
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HX
M,PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(").86ARX7;A;NTN+BXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Q"FUS9VED("),;V-A
M;"!T:6UE.B`B"FUS9W-T<B`B3>US=&[M(.AA<SH@(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS9W-T
M<B`B3&]C86QE(&$@Z&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8T"B,Z
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO;65T87(N<&AP
M.C8U"FUS9VED("),;V-A=&EO;B(*;7-G<W1R(")-[7-T;R(*"B,Z(&QO9VEN
M+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$Y,2!T96UP
M;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.3`*;7-G
M:60@(DQO9R!I;B(*;7-G<W1R(")0^&EH;.%S:70@<V4B"@HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V:6]U
M<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$X-0IM<V=I9"`B3&]G(&]U="(*;7-G<W1R(")/9&AL
MX;EE;NTB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*(RP@9G5Z>GD*
M;7-G:60@(DQO9VEN(@IM<V=S='(@(E#X:6ALX7-I="!S92(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S
M='(@(MIK;VQY('!R;W;A9.QNZ2!P^&D@</AI:&SAN65N[2(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB4V5L:&%L;R!P^&EH;.&Y96[M(&1O
M('-Y<W3I;74N(%!R879D['!O9&]B;NP@5F&Y92!UOFEV871E;'-KZ2!J;>EN
M;R!A+VYE8F\@(@HB:&5S;&\@;F5B>6QO('-P<N%V;NP@>F%DX6YO+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I
M;&5D+B(*;7-G<W1R(")0^&EH;.&Y96[M('-E;&AA;&\N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-0IM<V=I9"`B3&]N9R!T97AT(@IM<V=S
M='(@(D1L;W5H_2!T97AT(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X
M"FUS9VED("),;W9E(@IM<V=S='(@(DSA<VMA(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO=R(*;7-G<W1R
M(").[7IKX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E<G,B
M"FUS9W-T<B`B36%LX2#X96-KX2!P[7-M96YA(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B
M3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R(")-86SA('1I<VMA8^T@<.US
M;65N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS
M9W-T<B`B36%LZ2#X[6US:^D@Z.US;&EC92(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I
M9"`B3'5X96UB;W5R9R(*;7-G<W1R("),=6-E;6)U<G-K;R(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#`*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S."!T96UP;&%T97,O
M9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT
M."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q"FUS9VED(")-3U1$(@IM<V=S='(@
M(EIP<N%V82!D;F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<#HS-@IM<V=I9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+B(*;7-G<W1R(")0^&EP;VIE;OT@<V]U8F]R($U3+4Y4148@
M;F5O8G-A:'5J92"^X61NX2!D871A+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*;7-G
M:60@(DU31R(*;7-G<W1R(")-4T<B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA
M8V%O(@IM<V=S='(@(DUA:V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ"FUS9VED(")-86-E
M9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B36%K961O;FEE+"!B_79A;.$@4F5P=6)L:6MA($IU9V]S;.%V:64B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B36%D86=A
M<VMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I9"`B36%G
M:6,B"FUS9W-T<B`B36%G:64B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B4&^Y=&$B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3(R"FUS9VED(")-86EL($%D;6EN(@IM<V=S
M='(@(D%D;6EN:7-T<N%T;W(@<&^Y='DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@
M;&EN7VLN+BXB"FUS9W-T<B`B5GET=F_X:70@;V1?:V%Z+BXN(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDU"FUS9VED(")-86QA>7-I82(*;7-G<W1R(")-86QA:G-I92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS9W-T<B`B36%L9&EV>2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34T(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDT"FUS9VED(")-86QT82(*;7-G<W1R(")-86QT82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R`B"B)A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O
M<FEE<RXB"FUS9W-T<B`B(@HB4')O('5M;[YN[&[M(&]V;.%DX6[M(&MA=&5G
M;W)I[2!J92!Z87!O=/AE8NT@;WIN8>AI="!P;VQOOFMY(&)A<G9A;6DL(&MT
M97+I("(*(FIS;W4@</AI^&%Z96YY(&L@=.QM=&\@:V%T96=O<FGM;2XB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U,PIM
M<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<&$@36%P,C0B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`X-`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$V.`IM<V=I9"`B
M36%P475E<W0@;6%P(@IM<V=S='(@(DUA<&$@36%P475E<W0B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T
M;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(D+X97IE;B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")/:W)A:B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B3WIN8>AI="!Z;F'H
M:V]U(%!R;VALZ61N=71O+TYE<')O:&SI9&YU=&\B"@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I9"`B36%R:R!W:71H
M(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T
M<B`B3WIN8>AI="!J:6[];6D@>FYAZ&MA;6D@*&IA:V\@1/EL9;YI=.DO3V1P
M;W;L>F5NZ2DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N
M9',B"FUS9W-T<B`B36%RN6%L<VOI($]S=')O=GDB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*
M;7-G:60@(DUA<G1I;FEQ=64B"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E
M;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F
M:65L9',B"FUS9W-T<B`B4VAO9'5J[6/M('-E('!O;&4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3,*;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<F5TX6YI92(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7)I8VEU
M<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R(")-
M87AI;6%L;NT@<&]V;VQE;OT@:W)E9&ET(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"FUS9VED(")-87@@;65S
M<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B0GEL82!P^&5K<F_H96YA
M(&UA>&EM86QN[2!DZ6QK82!Z<'+A=GDN(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*;7-G
M<W1R(").96IV>;FY[2!T97!L;W1A('IA('!O<VQE9&[M8V@@,C0@:&]D:6XZ
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(").96IV>;FY[2!T97!L;W1A('IA
M('!O<VQE9&[M8V@@-B!H;V1I;CH@(@H*(SH@;&EB+V%P:2YP:'`Z.#8*;7-G
M:60@(DUA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DX(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$R,3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B36%X:6WA;&[M
M(&3I;&MA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")+=NQT96XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T=&4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@
M(DUE9&EC[6YA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHQ-@IM<V=I9"`B365M8F5R<R(*;7-G<W1R("+(;&5N;W;I(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G
M<W1R(")-\V1Y('!R;R!M96YU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS
M(@IM<V=S='(@(E-P;VII="!B=?)K>2(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E
M(@IM<V=S='(@(EIP<N%V82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B6G!RX79A(&)Y;&$@;W;L^&5N
M82!V('!O^.%D:W4L(&%L92!N96QZ92!O=NSX:70@<&]D<&ES;W;](&-E<G1I
M9FEKX70N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$P"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@
M(EIP<N%V82!P<F]P861L82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED(")-97-S
M86=E('1Y<&4B"FUS9W-T<B`B5'EP('IP<N%V>2(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G<W1R(")0;^AA
M<^TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,W"FUS9VED(")-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K(&\@<&_H87/M(&YE
M;NT@9&]S='5P;OTN(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3(*;7-G
M:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@
M(B(*(D)L;VL@;R!P;^AA<^T@;F5N[2!D;W-T=7!N_2X@4&]D<F]B;F]S=&D@
M8GEL>2!Z87IN86UE;N%N>2!P<F\@<WES=.EM;W;I:&\@(@HB861M:6YI<W1R
MX71O<F$@9&\@;&]G=2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38U"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C<@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I
M9"`B365T:&]D(@IM<V=S='(@(DUE=&]D82(*"B,Z(&9R86UE=V]R:R]24$,O
M4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z
M,3$W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E<UPB
M(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D82`G)7,G(&YE;NT@9&5F
M:6YO=N%N82(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L
M('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D
M(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*;7-G:60@(DUE
M=')I8R(*;7-G<W1R(")-971R:6-K_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B
M365X:6-O(@IM<V=S='(@(DUE>&EK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<R"FUS9VED(")-
M:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(DUI:W)O
M;NES:64L($9E9&5R86-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<V"FUS9VED(")-:61D;&4B"FUS9W-T<B`B
M57!R;W-T^&5D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE
M9BYP:'`Z,S@*;7-G:60@(DUI;64@5'EP92(*;7-G<W1R(")4>7`@36EM92(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B3F5J;FF^N>T@=&5P;&]T82!Z82!P
M;W-L961N[6-H(#(T(&AO9&EN.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P,@IM<V=I9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B
M3F5J;FF^N>T@=&5P;&]T82!Z82!P;W-L961N[6-H(#8@:&]D:6XZ("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI
M;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M,S0*;7-G:60@(DUI<G)O<B(*;7-G<W1R("):<F-A9&QO=NPB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B4OEZ;NDB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8W,@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#`*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W=I;E]H='1P+G!H<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E
M($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4')O9W)A;6]V_2!B86SM:R!(5%10
M7U)E<75E<W0@8VAY8NT@=B!014%2+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)#:'EB[&KM8^T@:V]N
M9FEG=7)A8V4N(%!O:W5D('-I('#X96IE=&4@<&]UONUV870@='5T;R!A<&QI
M:V%C:2P@;75S[71E("(*(G9Y9V5N97)O=F%T(&MO;F9I9W5R8>AN[2!S;W5B
M;W(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@
M(D-H>6+L:NUC[2!)1"!Z<'+A=GD@*&ED96YT:69I:V'H;NT@Z.US;&\I(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA
M:6PN(@IM<V=S='(@(E!OOF%D;W9A;OT@<')O9W)A;6]V_2!B86SM:R!-86EL
M(&-H>6+M('8@4$5!4BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G:60@(DUI<W-I;F<@<V5S<VEO;B!)
M1"XB"FUS9W-T<B`B0VAY8NQJ[6/M($E$('!R;R!R96QA8VDN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B
M36\B"FUS9W-T<B`B4&\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-S0*;7-G:60@(DUO8FEL92!-86EL(@IM<V=S='(@(DUO8FEL;NT@<&^Y=&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM
M<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B3>UR;OTB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=&=Z+G!H<#HX.`IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R
M(")$871U;2!P;W-L961N[2!Z;>QN>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y
M(%523"(*;7-G<W1R("):;>SR:70@55),(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV-S,*;7-G:60@(DUO9'5L=7,B"FUS9W-T<B`B
M36]D=6PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(DUO;&3A=FEE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-
M;VYA8V\B"FUS9W-T<B`B36]N86MO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M;VYG;VQI82(*;7-G<W1R(")-;VYG;VQS:V\B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R
M(")-['/M8R!A(')O:R(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC92]-86EN
M=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B3>QS[>AN
M["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-
M;VYS97)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M
M;V]N+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B1N%Z92!-
M['/M8V4B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-S(@9G)A
M;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S"B,L('!H<"UF;W)M870*;7-G
M:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP
M96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]R
M;V-C;R(*;7-G<W1R(")-87)O:V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S
M='(@(E#X97;AOF[L(&IA<VYO(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T
M<B`B4/AE=N&^;NP@;V)L8>AN;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T
M<B`B4/AE=N&^;NP@<VQU;F7H;F\B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO
M8VLO3&%Y;W5T+G!H<#HU,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")0
M;W-U;F]U="!D;VSY(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-3$S"FUS9VED(")-;W9E($QE9G0B"FUS9W-T<B`B4&]S=6YO=70@
M9&]L979A(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z
M-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM<V=S='(@(E!O<W5N;W5T(&1O<')A
M=F$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#4*
M;7-G:60@(DUO=F4@57`B"FUS9W-T<B`B4&]S=6YO=70@;F%H;W)U(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-`IM<V=I
M9"`B36]V92!D;W=N(@IM<V=S='(@(E!O<W5N;W5T(&1O;/DB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO
M=F4@=7`B"FUS9W-T<B`B4&]S=6YO=70@;F%H;W)U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO<V%M8FEK(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(E;M8V4M^G)O=O)O=ND@<F]L971O
M=ND@<V5Z;F%M>2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I9"`B375L
M=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(E;M8V5NX7-O8F[A('-E;&5K8V4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"FUS9VED(")->2!!
M8V-O=6YT(@IM<V=S='(@(DWY:B#ZZ&5T(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T
M:6]N(@IM<V=S='(@(E9AN64@:6YF;W)M86-E(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VEN9&5X+G!H<#HU-`IM<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(DWY
M:B!P;W)TX6PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP:'`Z,3,V"FUS
M9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(DUO:F4@<F]Z;&^^96[M
M('!O<G3A;'4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T
M<B`B37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T
M<B`B3D4L($Y%4T]52$Q!4\U-(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B2FWI;F\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.34*;7-G:60@(DYA;6EB:6$B"FUS9W-T<B`B3F%M:6)I92(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-PIM<V=I9"`B3F%U<G4B"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE<&%L(@IM<V=S='(@(DYE<.%L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW
M"FUS9VED(").971H97)L86YD<R(*;7-G<W1R(").:7IO>F5M[2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").
M:7IO>F5M<VOI($%N=&EL>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(").971S8V%P92!"87-E(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R(").971S8V%P92!#02!2979O8V%T:6]N(%523"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").
M971S8V%P92!#02!P;VQI8WD@55),(@IM<V=S='(@(DYE='-C87!E($-!('!O
M;&EC>2!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4X-`IM<V=I9"`B3F5T<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB
M"FUS9W-T<B`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-@IM<V=I9"`B3F5T<V-A<&4@
M4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DIMZ6YO($YE='-C87!E(%-33"!S
M97)V97)U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T
M<B`B4&]Z;N%M:V$@:R!C97)T:69I:^%T=2!.971S8V%P=2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@P"FUS9VED(").971S8V%P
M92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E1Y<"!C97)T:69I:^%T=2!.
M971S8V%P=2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3$*;7-G
M:60@(DYE='=O<FLB"FUS9W-T<B`B4^V[(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS
M9W-T<B`B3FEK9'DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N
M:6$B"FUS9W-T<B`B3F]VX2!+86QE9&]N:64B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,`HC.B!T96UP;&%T97,O
M<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-@IM<V=I9"`B3F5W($-A
M=&5G;W)Y(@IM<V=S='(@(DYO=N$@:V%T96=O<FEE(@H*(SH@9G)A;65W;W)K
M+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE=V]R
M:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M97=O
M<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T
M<B`B5GET=F_X:70@>G!RX79U("@E<RDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DWL<^UC('8@<')V;NT@
MZ'1V<G1I;NPB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G<W1R(").
M;W;I('6^:79A=&5L<VOI(&IMZ6YO("AN97!O=FEN;NDI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDX"FUS9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").;W;](%KI;&%N9"(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM
M<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DAE<VQO(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]S<6PN<&AP.C(R-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").97<@<&%S<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@HC+"!F=7IZ>0IM
M<V=I9"`B3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B2&5S
M;&$@<V4@;75S[2!S:&]D;W9A="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA
M;FLI(@IM<V=S='(@(DYO=ND@;VMN;R`H7W!RX7ID;NDI(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4R"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(DYE=W,B"FUS
M9W-T<B`B3F]V:6YK>2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS
M,#4*;7-G:60@(DYE=W-G<F]U<',B"FUS9W-T<B`B3F5W<V=R;W5P<R(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z
M,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT
M(@IM<V=S='(@(D1A;+GM(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L
M(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S(@IM<V=S='(@(D1A;+GM(&;A
M>F4B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W,B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,W-@IM<V=I9"`B3F5X="!O<'1I
M;VYS(@IM<V=S='(@(D1A;+GM(&UOOFYO<W1I(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U!A9V5R+G!H<#HQ,#,*(RP@9G5Z>GD*;7-G:60@(DYE>'0^(@IM<V=S
M='(@(D1A;+GM(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS
M9W-T<B`B3FEK87)A9W5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV"FUS9VED(").:6=E<B(*
M;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*
M;7-G<W1R(").:6?I<FEE(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T<B`B3F]C(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-SD@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI=64B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38S"FUS9VED(").;R(*;7-G
M<W1R(").92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ
M.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S
M:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`BKF%D;N$@:V]N9FEG=7)A
MZ&[M(&1A=&$@;F5J<V]U(&1O<W1U<&[A('!R;R!Z;V)R87IE;NT@<F]Z9.UL
M^2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@
M25-/(&EM86=E<RXB"FUS9W-T<B`B3F5N[2!D;W-T=7!NX2"^X61NX2!S=')A
M=&5G:64@<')O('1V;W)B=2!)4T\@;V)R87KY+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@
M8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(D)E>B!DX79K;W;I:&\@=GIO<G4N
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@
M97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB"FUS9W-T<B`B3F$@
M<&^^861O=F%NZ2!P;WII8VD@;F5E>&ES='5J92"^X61N_2!B;&]K(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@ON%D;ND@:FWI;F\@<')O(&MA
M;&5N9.'X('#X:2!O=NSX;W;A;NT@<&]M;V/M($U#04PN(@H*(SH@861M:6XO
M<V5T=7`O9&EF9BYP:'`Z-30*;7-G:60@(DYO(&-H86YG92XB"FUS9W-T<B`B
M0F5Z('IM[&YY+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P
M97)M:7-S:6]N+B(*;7-G<W1R(").96QZ92!P^&ED870@ON%D;N$@<&]D+7!R
MX79A(&L@=.QM=&\@<'+A=OEM+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,38W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`R"B,Z(&9R
M86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<W,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M)7,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN
M[2!I;F9O<FUA8V4@<')O("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B3F5B>6QY('5V961E
M;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@1E10(%9&4RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8V.0IM<V=I9"`B3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!6
M1E,N(@IM<V=S='(@(DYE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN
M[2!I;F9O<FUA8V4@<')O(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C<Q-PIM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T
M<B`B3F5B>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C
M92!P<F\@4U%,+49I;&4@5D93+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET(&QE
M9G0N(@IM<V=S='(@(DYE;>%T92"^X61N_2!K<F5D:70N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@
M(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").96)Y;"!P;W-K
M>71N=70@ON%D;OT@8^UL+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S
M97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO861E9"(*;7-G<W1R("*N
MX61N_2!S;W5B;W(@;F5B>6P@</AE;F5S96XB"@HC.B!U=&EL+VEC;VY?8G)O
M=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").
M96)Y;'D@;F%L97IE;GD@ON%D;ND@:6MO;GDN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$R."!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-#`*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO8V%T:6]N
M(&ES('-E="XB"FUS9W-T<B`B3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V.0HC+"!F=7IZ
M>0IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE8GEL
M;R!V>6)RX6YO(+[A9&[I(&WM<W1O+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E
M('-U<'!L:65D+B(*;7-G<W1R(").96)Y;'D@<&]S:WET;G5T>2"^X61NZ2!Z
M<'+A=GDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S8*;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R
M(").96)Y;&\@=79E9&5N;R"^X61NZ2!J;>EN;RXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@
M;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5B>6QO('5V961E;F\@ON%D
M;ND@Z.US;&\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED
M(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`B0F5Z(&YE<VQUN6[]
M8V@B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED
M(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V[/AE
M;NT@<&]M;V/M($A45%`N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P
M+G!H<#HQ,#@*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0
M(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@<&]S:WET;G5T;R!H
M97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@24U!4"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+VMR8C4N<&AP.C<R"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE
M8GEL;R!P;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!+97)B
M97)O<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96)Y;&\@
M<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P^&EH;.&Y96[M('-E(&1O
M('-Y<W3I;74N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP
M.C$S-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5B>6QO('!O<VMY=&YU=&\@:&5S
M;&\@<')O(&]V[/AE;NT@<&]M;V/M(%!!4U-71"XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DYE8GEL;R!P
M;W-K>71N=71O(&AE<VQO('!R;R!O=NSX96[M('!O;6]C[2!334(N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B
M"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE
M($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@
M4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"B).96)Y;&$@<&]S:WET;G5T82!C
M97-T82!K(&)I;N%R;NUM=2!S;W5B;W)U($]P96Y34TPN($)I;N%R;NT@<V]U
M8F]R($]P96Y34TP@(@HB:F4@>F%P;W3X96+M('!R;R!P<N%C:2!S(%!+0U,@
M,3(@9&%T>2XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN
M8SHV"FUS9VED(").;R!P96YD:6YG('-I9VYU<',N(@IM<V=S='(@(J[A9&[I
M(&YE=GGX[7IE;ND@ON%D;W-T:2!O('#X:6ALX;EE;NTN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C<U,`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B3F\@<75O=&$@<V5T+B(*;7-G<W1R(").96[M(&YA<W1A=F5N;R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(D)E>B!P<F%V:61E;"(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I
M9"`B3F\@<V5P87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B3F5B>6QO('5V
M961E;F\@ON%D;ND@Z.US;&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS
M9W-T<B`B0F5Z(&]K<F%J^2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP
M:'`Z-3@S"B,L(&9U>GIY"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
M0F5Z(&]K<F%J^2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,S@*;7-G:60@(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92XB"FUS9W-T<B`BKN%D;OT@>B!D;^AA<V[]8V@@861R97/A^/D@
M;F5N[2!D;W-T=7!N_2!P<F\@8V%C:&4N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S$*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HR,C$*;7-G:60@(DYO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").96)Y;&\@;V1E<VSA
M;F\@ON%D;ND@=;YI=F%T96QS:^D@:FWI;F\@82]N96)O(&AE<VQO+B(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V
M86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R(").96)Y;&$@;F%V<N%C
M96YA(+[A9&[A('!L871NX2!834P@9&%T82XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3<Q"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY.#$*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY,@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P.0IM<V=I9"`B3F\@=F%L=65S(@IM
M<V=S='(@(J[A9&[I(&AO9&YO='DB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(P"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B5B!O<FEG:6[A;&[M(&MO;F9I9W5R86-I(&YE8GEL82!N86QE>F5N82!V
M97)Z92X@3V)N;W9T92!K;VYF:6=U<F%C:2XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")692!68;GM(&MO;F9I9W5R86-I(&YE8GEL82!N86QE>F5N82!V97)Z
M92X@3V)N;W9T92!K;VYF:6=U<F%C:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E
M;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(J[A9&[]
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("*NX61N_2`H
M<&]UOFEJ=&4@:6UP;&EC:71N[2DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X.0IM<V=I9"`B3F]R9&EC("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B4V5V
M97)S:_T@*$E33RTX.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R
M9F]L:R!)<VQA;F0B"FUS9W-T<B`B3F]R9F]L:W-KZ2!O<W1R;W9Y(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M;V]N+G!H<#HV,`IM
M<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R(")3979E<F[M('!O
M;&]K;W5L92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S(@IM<V=S='(@(E-E=F5R;NT@36%R:>%N<VOI(&]S=')O=GDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)S:V\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($%F=&5R(@IM<V=S='(@(DYE;NT@<&\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*
M;7-G<W1R(").96[M('#X960B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HT,#@*;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R(").96[M
M(&%D<F5SX?AE;2(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z
M.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y"FUS9VED(").
M;W0@:6UP;&5M96YT960N(@IM<V=S='(@(DYE;NT@:6UP;&5M96YT;W;A;F\N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").96[M(&YA<W1A=F5N;R(*"B,Z
M(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z
M,30S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE
M<BYP:'`Z,34X"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N
M2&%N9&QE<BYP:'`Z,3<S"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]3
M97-S:6]N2&%N9&QE<BYP:'`Z,3@W"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N
M9&QE<B]397-S:6]N2&%N9&QE<BYP:'`Z,C,T(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HQ.3`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P-2!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M-#@@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(V-0HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C@Q(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.3<*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C,Q,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,S(Y"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS-C(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C0R,@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3`Q(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HU-S`*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4X-R!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-C8U"FUS9VED(").;W0@
M<W5P<&]R=&5D+B(*;7-G<W1R(").96[M('!O9'!O<F]VX6YO+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C$W.`IM<V=I9"`B3F]T97,B"FUS9W-T<B`B4&]Z;N%M:V$B"@HC.B!S
M97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R(").:6,@:R!P<F]H;.ED;G5T
M[2P@8NR^=&4@>G#L="XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B3&ES=&]P
M860B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V"FUS9VED(").
M=6UB97(B"FUS9W-T<B`BR.US;&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(U"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R
M(")0;^AE="!Z;F%K^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R,PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#0U('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G
M<W1R(")0;^AE="!S;&]U<&/Y(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM
M<V=S='(@(E!OZ&5T(/CA9&OY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@(DYU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM
M<V=S='(@(DYE8GEL82!Z863A;F$@Z.US;&$@<')O(&%K='5A;&EZ86-I(&1I
M<W1R:6)UZ&[M:&\@<V5Z;F%M=2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C0*;7-G:60@(D]+(@IM<V=S='(@(D]+(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM
M<V=I9"`B3V)J96-T(@IM<V=S='(@(D]B:F5K="(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G
M<W1R(")4=OER8V4@;V)J96MT^2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]S;6GH:V]V_2(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3`*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<T"FUS9VED
M(")/8W1O8F5R(@IM<V=S='(@(MCM:F5N(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT
M<F]V870@;F5S;'6Y;NDB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S(V"FUS9VED(")/9F9I8V4B"FUS9W-T<B`B2V%N8V5LX?@B"@HC.B!S97)V
M:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,V"B,L(&9U>GIY"FUS9VED
M(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B2&5S;&\B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-#8*(RP@9G5Z>GD*;7-G:60@(D]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B3F5S<'+A=F[I(&AE<VQO
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]MX6XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,PIM<V=I
M9"`B3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RXB
M"FUS9W-T<B`B4V3M;&5NZ2!S;&^^:WD@:G-O=2!P;W-K>71O=N%N>2!P;W5Z
M92!)34%0('-E<G9E<GDN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU
M"FUS9VED(")/;FQY(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")0;W5Z
M92!N97-L=;ENZ2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0IM<V=I9"`B3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")*92!P;W9O;&5N82!P
M;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+B(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@
M<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@
M;W=N97(@(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB
M4&]U>F4@=FQA<W1N[6L@;F5B;R!S>7-TZ6UO=OT@861M:6YI<W1RX71O<B!M
M^;YE(&WL;FET('!RX79A('!R;R!S9.UL96[]("(*(F]B:F5K="XB"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B3W1E=OCM="!V(&YO=NEM(&]K;NPN(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N(@IM<V=S='(@(D-H>6)A($]P96Y34TPZ($YE;'IE('KM
M<VMA="!D871A('H@<&]D97!S86[I(.CA<W1I(%,O34E-12XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-34*
M;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T
M<B`B3W1E=OCM="!T96YT;R!O9&MA>B!V(&YO=NEM(&]K;NPB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB
M"FUS9W-T<B`B3W!E<F'H;NT@<WES=.EM(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")-;[YN
M;W-T:2(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E
M9G,O87!P+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O
M<B`E<R(*;7-G<W1R(")-;[YN;W-T:2!P<F\@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D
M($QI<W0B"FUS9W-T<B`B4V7X87IE;OT@<V5Z;F%M(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C<*;7-G:60@(D]R9V%N:7-A=&EO
M;B(*;7-G<W1R(")/<F=A;FEZ86-E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;F%L(%5N:70B
M"FUS9W-T<B`B3W)G86YI>F'H;NT@:F5D;F]T:V$B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3,R"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@
M(D]R9V%N:7IO=N%N[2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U"FUS
M9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R(")/
M<FEG:6[A;&[M('9Z;W(@<')O(+[A9&]S="(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B3W)I9VENX6QN[2!V>F]R('8@)7,Z(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K
M97EB;V%R9"YP:'`Z,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(D]S=&%T;NTB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")/<W1A=&[M(&EN9F]R;6%C92(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E<FUI
M<W-I;VYS(@IM<V=S='(@(E6^:79A=&5L<VOA('!RX79A(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3W;L^&5N[2!P;VUO
M8^T@4$%-(&YE;NT@9&]S='5P;NDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V=E;F5R:6-?<VUT<"YP:'`Z,3`U"FUS9VED(")014%2.CI-86EL(&)A
M8VME;F0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z,3(W,PIM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S
M='(@(E!'4"!D:6=I=.%L;NT@<&]D<&ES(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z,3,Q.0IM<V=I9"`B4$=0($5N8W)Y<'1E9"!$871A
M(@IM<V=S='(@(E!'4""Y:69R;W9A;N$@9&%T82(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y
M(@IM<V=S='(@(E9E^&5J;OT@4$=0(&ML[>@B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A(@IM<V=S='(@(D1A=&$@<&]D97!S86[A+[EI9G)O=F%NX2!P
M;VUO8^T@4$=0(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C8X"FUS9VED(")0
M2%`@0V]D92(*;7-G<W1R(")02%`@:_-D(@H*(SH@861M:6XO<&AP<VAE;&PN
M<&AP.C(P"FUS9VED(")02%`@4VAE;&PB"FUS9W-T<B`B4$A0(&MO;GIO;&$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-PIM
M<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G<W1R(")/9'!O;&5D;NT@;&5H:_T@
M9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,X"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(D]D<&]L961N[2!P^&5H
MX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@(D]D<&]L961N[2!S;NR^96[M
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#`*
M;7-G:60@(E!-(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")/9'!O;&5D;NT@<V[L
M:&]VZ2!P^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3=6XB"FUS9W-T<B`B
M3V1P;VQE9&[M('-N[+YE;NTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,@IM<V=I9"`B4$T@5"U3=&]R;7,B"FUS9W-T<B`B
M3V1P;VQE9&[M(&)O=?AK>2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR
M-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@
M(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G
M<W1R(")07TA0(&MO;GIO;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S
M='(@(D]D<W1U<'DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES=&%N(@IM
M<V=S='(@(E#A:VES=.%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B
M"FUS9W-T<B`B4&%L874B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN<VOI
M('1E<FET;W)I=6TL(&]K=7!O=F%NZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I9"`B
M4&%N86UA(@IM<V=S='(@(E!A;F%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R(")087!U82!.;W;A($=U:6YE82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@(E!A<F%G
M=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B3>US='D@>F%T8;YE
M;F\B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")(97-L;R(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA
M;F=E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z,3,R,@IM<V=I9"`B4&%S<W=O<F0@:6YC
M;W)R96-T(@IM<V=S='(@(DYE<W!RX79NZ2!H97-L;R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A<W-W;W)D(')E
M<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E!R
M;R!O=NSX96[M('!O;6]C[2!2041525,@:F4@;G5T;F\@>F%D870@:&5S;&\N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B2&5S;&\@<R!P;W1V
M<GIE;NUM(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDP"FUS
M9VED(")087-S=V]R9#HB"FUS9W-T<B`B2&5S;&\Z(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T
M<B`B2&5S;&\Z("(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U,"!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#,T"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z,34*;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R(")(97-L82!S92!M=7/M('-H;V1O=F%T+B(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")6;&^^:70B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W
M"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")6;&^^:70@
M>F4@<V-H<N%N:WDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(D-E<W1A(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C<*;7-G:60@(E!E;F1I;F<@
M4VEG;G5P<SHB"FUS9W-T<B`BKN%D;W-T:2!O('#X:6ALX;EE;NTZ(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"FUS9VED(")096]P;&4B"FUS9W-T
M<B`B3&EDZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM
M<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS(@IM<V=S='(@
M(E!R;W;I<W0@;W!E<F%C92#Z9'*^8GDB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO
M;G,@;VX@;&]G:6X_(@IM<V=S='(@(E!R;W;I<W0@;W!E<F%C92#Z9'*^8GD@
M</AI('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$U-@IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R
M(")0<N%V82(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3(*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D
M96QE=&5D+B(*;7-G<W1R(")0<N%V;R`G)7,G(&YE8GEL;R!S;6%ZX6YO+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-3@V"B,L(&9U>GIY"FUS
M9VED(")097)M:7-S:6]N($1E;FEE9"(*;7-G<W1R(")0<N%V82(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,38T"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N
M<R(*;7-G<W1R(")?4'+A=F$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P"B,Z(&%D;6EN+W!E<FUS
M+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4X"FUS9VED
M(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES
M=')AZ&[M('!RX79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS
M9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R(")/<V]B;NT@:6YF
M;W)M86-E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S@*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")097)U(@IM<V=S='(@(E!E
M<G4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-34*;7-G:60@(E!E=',B
M"FUS9W-T<B`B1&]MX6/M('IV[?AA=&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@
M(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP[6YY(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I9"`B4&AO;F4B
M"FUS9W-T<B`B5&5L969O;B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT-S@*;7-G:60@(E!H;W1O<R(*;7-G<W1R(")&;W1O9W)A9FEE(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E!I>&5L^2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R(")&
M<N%Z92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L
M;"(*;7-G<W1R(")0<F]S[6T@:VQI:V[L=&4@;F$@;NQJ86MO=2!B=?)K=2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R(")0<F]S[6T@<&]T=G+O
M=&4L(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U
M;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")0<F]S[6T@<&]T=G+O=&4L
M(+YE('-I('#X96IE=&4@;V1S=')A;FET('1E;G1O('!R=F5K+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L96%S92!E;G1E
M<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!R;W/M;2!Z861E:G1E
M(&WL<^UC(&$@<F]K+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA
M;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE(&9O
M<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!N
MX7IE=B!N;W;I(&MA=&5G;W)I93HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,S`Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+B(*;7-G<W1R(")0<F]S[6T@>F%D96IT92!S<'+A=FYO=2!)4"!A9')E
M<W4N+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-C`*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(E!R;W/M;2!Z861E:G1E
M('-P<N%V;OT@9&%T=6T@82!Z:V]N=')O;'5J=&4@<&_H970@9&[M('8@;>QS
M[6-I+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T-3$*;7-G:60@
M(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM<V=S='(@(E!R;W/M;2!Z
M861E:G1E('-P<N%V;OT@Z&%S+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C<*;7-G:60@(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O
M9B!T:&4@<')O8FQE;2XB"FUS9W-T<B`B4')O<^UM('5V9>]T92!S:')N=73M
M(%9AN65H;R!P<F]B;.EM=2XB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C8*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(E!R;W/M;2!Z861E:G1E(%9AN64@=;YI=F%T96QS:^D@:FWI;F\@82!H
M97-L;R(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HU.`HC+"!F=7IZ
M>0IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9
M;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE("(*(G-Y
M<W1E;2XB"FUS9W-T<B`B(@HB4')O<^UM('#X9>AT['1E('-I(&[A<VQE9'5J
M[6/M('1E>'0N($U54\U412!S;W5H;&%S:70@<R!P;V1M[6YK86UI('!O=;[M
M=N%N[2`B"B)S>7-TZ6UU+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<P"FUS9VED(")0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E!R;W/M;2!Z861E:G1E(&YO
M=OT@;N%Z978@:V%T96=O<FEE.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&]L
M86YD(@IM<V=S='(@(E!O;'-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L:71I:V$B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@W"FUS9VED(")0;VQL<R(*;7-G
M<W1R(")(;&%S;W;A;NTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A
M;"(*;7-G<W1R(")0;W)T=6=A;'-K;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")5;>US=.QN[2!T;VAO
M=&\@;V)RX7IK=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M(@IM<V=S='(@(E5M[7-T[&[M('1A8G5L:WDB"@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(EIA<VQA
M="!D;R!TZ71O('-L;[YK>2`H;F5N[2!P;W-K>71N=71O($E-05!E;2DB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP
M.C(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ("(*;7-G<W1R(")3<N&^:WD@>F$@<&]S;&5D;NTH
M8V@I("5S(&AO9&EN*'4I.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,CDX"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY
M.`IM<V=I9"`B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(*;7-G<W1R(")0<F5F<U]L9&%P.B!.96)Y;&$@;F%L97IE
M;F$@<&^^861O=F%NX2!P^.UP;VYA($Q$05`N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED(")0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(E!R969S7W-E<W-I;VXZ($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A
M('#X[7!O;F$@<V5K8V4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C4*
M;7-G:60@(E!R97-S=7)E(@IM<V=S='(@(D)A<F]M971R:6-K_2!T;&%K(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R97-S=7)E(&%T
M('-E82!L979E;#H@(@IM<V=S='(@(D)A<F]M971R:6-K_2!T;&%K(&YA(/IR
M;W9N:2!M;_AE.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,U"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(D)A<F]M971R:6-K_2!T
M;&%K.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(D[A:&QE
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR-`IM<V=I9"`B4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N
M97<@=VEN9&]W(@IM<V=S='(@(D[A:&QE9"!O8G+A>FMU('8@;F]VZ6T@;VMN
M["(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O
M<'1I;VYS(@IM<V=S='(@(E#X961C:&]Z[2!M;[YN;W-T:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*;7-G:60@(E!R
M:6YT(&1O8W5M96YT(@IM<V=S='(@(E1I<VMN;W5T(&1O:W5M96YT(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(S"FUS9VED(")0<FEV
M871E($ME>2(*;7-G<W1R(")0<FEVX71N[2!K;.WH(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.0IM<V=I9"`B4')O8FQE;2(*;7-G
M<W1R(")0<F]B;.EM(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(V"FUS
M9VED(")0<F]B;&5M($1E<V-R:7!T:6]N(@IM<V=S='(@(E!O<&ES('!R;V)L
MZ6UU(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,V.0IM<V=I9"`B
M4')O:F5C=',B"FUS9W-T<B`B4')O:F5K='DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#@*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0IM<V=I9"`B4')O;7!T
M('1E>'0B"FUS9W-T<B`B4')O;7!T('1E>'0B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B5F7X96IN_2!K;.WH(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S
M='(@(D%L9V]R:71M=7,@<')O('9E^&5J;OT@:VSMZ"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0
M=6)L:6,@2V5Y($EN9F\B"FUS9W-T<B`B5F7X96IN_2!K;.WH(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*
M;7-G<W1R(")69?AE:F[]+W!R:7;A=&[M(&ML[>AO=OT@<.%R(&YE8GEL(/IS
M<.RY;NP@=GET=F_X96XN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O
M(%)I8V\B"FUS9W-T<B`B4&]R=&]R:6MO(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I
M9"`B46%T87(B"FUS9W-T<B`B2V%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP
M:'`Z-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(E9Y:&QE9.%N[2(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B475O=&$B
M"FUS9W-T<B`B2V%T87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME
M>2`H)60@8FET*2(*;7-G<W1R(")24T$@=F7X96IN_2!K;.WH("@E9"!B:73Y
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A
M9&EO('-E;&5C=&EO;B(*;7-G<W1R(")3</AAOF5NZ2!T;&'H[71K;R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")286EN(@IM<V=S='(@(D3IN;LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R
M(")"<GIK_2!DZ;F[(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")0;WID;NT@
M9.FYNR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")$9;F[;W;I('#X96CA
M\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B1.FYNR!S92!S;NQH
M96TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(D3IN;L@8;X@<V[M:"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R(").X6AO9&[L('9Y8G)A;ND@N73L<W3M(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G
M<W1R(")0;VWL<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3@P"FUS9VED(")296%D(@IM<V=S='(@(LAT96/M(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E860@
M;65S<V%G97,B"FUS9W-T<B`B4/AEZ'1E;ND@>G!RX79Y(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B
M92!U;F1O;F4N(@IM<V=S='(@(D]P<F%V9'4@<VUA>F%T("5S/R!4871O(&]P
M97)A8V4@:F4@;F5V<F%T;N$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M8VQE87(N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(D]P<F%V9'4@<VUA>F%T('6^:79A
M=&5L<VOA(&1A=&$@<')O('6^:79A=&5L92`E<S\@5&%T;R!O<&5R86-E(&IE
M(&YE=G)A=&[A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N(@IM
M<V=S='(@(D]P86MO=F%T('!O<VQE9&[M(&%K8VDB"@HC.B!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-@IM<V=I
M9"`B4F5F<F5S:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,SDQ"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB
M"FUS9W-T<B`B3V)N;W9I="!D>6YA;6EC:^D@<')V:WD@;65N=3HB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")2969R97-H(%!O<G1A
M;"!6:65W.B(*;7-G<W1R(")/8FYO=F$@>F]B<F%Z96[M('!O<G3A;'4Z("(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C$S"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,S4*;7-G:60@(E)E9V5X(@IM<V=S='(@(E)E9V5X(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,S(T.0IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S
M97(B"FUS9W-T<B`B4')O:&SMOF7H('9Z=&%H^2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E;&]A9"(*;7-G<W1R("+(=&5C[2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM
M<V=S='(@(DAO9&YO='DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$T
M"FUS9VED(")296UO=&4@4V5R=F5R<R(*;7-G<W1R(")6>F3A;&5NZ2!S97)V
M97)Y+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I
M9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M(@IM<V=S='(@(E9Z9.%L96[A(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHR,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.C$S"FUS9VED
M(")296UO=F4B"FUS9W-T<B`B3V1S=')A;FET(@H*(SH@=&5M<&QA=&5S+W!O
M<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T
M<B`B3V1S=')A;FET(&)L;VLB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO=F4@8V]L=6UN(@IM<V=S
M='(@(D]D<W1R86YI="!S;&]U<&5C(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I9"`B4F5M;W9E(&9O<FUA='1I
M;F<B"FUS9W-T<B`B3V1S=')A;FET(&9O<FWA=&]VX6[M(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@(E)E;6]V92!P86ER(@IM
M<V=S='(@(D]D<W1R86YI="!PX7(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B3V1S=')A=&ET('5L
M;[YE;OT@<VMR:7!T('H@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E<G4N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM<V=S='(@(D]D<W1R86YI
M="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D
M;V-U;65N="(*;7-G<W1R(")/9'-T<F%N:70@='5T;R#HX7-T(&1O:W5M96YT
M=2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G
M:60@(E)E;6]V92!U<V5R(@IM<V=S='(@(D]D<W1R86YI="!UOFEV871E;&4B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B4F5M;W9E('5S97(Z("5S(@IM<V=S='(@(D]D<W1R
M86YI="!UOFEV871E;&4Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL
M<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R
M960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(DYE;'IE(&]D<&]V
M[&3L="!N82!P;[YA9&%V96LN($-H>6)O=ND@:&SAN65N[3H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B
M4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R
M(")0^&5N97-E;OT@<V]U8F]R(&YE;'IE('5L;[YI="XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4Q,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@
M7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B4&^^861O=F%NZ2`G)7,G(&YE8GEL;R!U=F5D96YO('8@:V]N9FEG
M=7)A8VD@<')O("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&
M4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")0;[YA9&]V86[I("<E<R<@;F5B
M>6QO('5V961E;F\@=B!K;VYF:6=U<F%C:2!P<F\@5D93+B(*"B,Z(&9R86UE
M=V]R:R]5=&EL+U5T:6PN<&AP.C<X,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B4&^^861O=F%NZ2`G)7,G(&YE8GEL;R!U=F5D
M96YO('8@:V]N9FEG=7)A8VDN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]2
M96YD97)E<BYP:'`Z,S,U"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R
M(")0;[YA9&]V86[I('!O;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2]296YD97)E<BYP:'`Z,S(P('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHQ,#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHW-PIM
M<V=I9"`B4F5S970B"FUS9W-T<B`B5OUC:&]Z[2!N87-T879E;NTB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S
M<W=O<F0B"FUS9W-T<B`B5OUC:&]Z[2!N87-T879E;NT@:&5S;&$B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U
M<B!087-S=V]R9"(*;7-G<W1R(")6_6-H;WKM(&YA<W1A=F5N[2!68;EE:&\@
M:&5S;&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"B,L(&9U>GIY"FUS
M9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T<B`B4&]S;&5D;NT@Z'1V
M<G1I;F$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-S$@861M:6XO8VUD<VAE
M;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HV-@IM<V=I9"`B4F5S=6QT
M<R(*;7-G<W1R(")6_7-L961K>2(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C
M<W5M+FEN8SHQ,#$@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B
M4F5T=7)N('1O($]P=&EO;G,B"FUS9W-T<B`B3N%V<F%T(&1O(&UOOFYO<W3M
M(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L(&9U>GIY
M"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E;]8VAO>NT@
M;F%S=&%V96[M(&AE<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO
M;B(*;7-G<W1R(")2975N:6]N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HT-"!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@
M0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")0^&5P;F]U="!K;VYF:6=U<F%C:2(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@5&5X
M="!%9&ET;W(@3W!T:6]N<R(*;7-G<W1R(")-;[YN;W-T:2!2:6-H(%1E>'0@
M961I=&]R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B
M4FED9&QE<R(*;7-G<W1R(")(X61A;FMY(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*
M;7-G<W1R(")$;W!R879A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R,0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(DAL879IZ&MA(&YA
M<')A=F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W"FUS9VED
M(")2:6=H="!V86QU97,B"FUS9W-T<B`B2&]D;F]T>2!N87!R879O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B5FQA<W1N
M;W-T:2#XX5]D:W4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE(@IM<V=S='(@(MIL;VAA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2=6UU;G-K;R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C4*
M;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`B3W1OZ&ET(&\@,3@PL"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*;7-G
M:60@(E)O=&%T92!,969T(@IM<V=S='(@(D]T;^AI="!D;VQE=F$B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(X"FUS9VED
M(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B3W1OZ&ET(&1O<')A=F$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0Y
M"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")6;&%S=&YO<W1I(/CA
M9&MU(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B5FQA
M<W1N;W-T:2#XX61K=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+8X61K>3HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4S"FUS9VED(")2=6QE<R(*;7-G<W1R(")0<F%V:61L82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*
M;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD
M(&-O;'5M;G,B"FUS9W-T<B`B4')A=FED;&$@<V4@=7!L871N[2!M97II(':Y
M96UI(/CA9&MY(&$@<VQO=7!C:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(E!R879I9&QA
M('-E('5P;&%T;NT@<&]U>F4@;65Z:2!S;&]U<&-I(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B
M4')A=FED;&$@<V4@=7!L871N[2!P;W5Z92!M97II(/CA9&MY(@H*(SH@861M
M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(E!R;W;I
M<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB
M"FUS9W-T<B`B4G5S:^$@9F5D97)A8V4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$X.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED
M(")2=V%N9&$B"FUS9W-T<B`B4G=A;F1A(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P
M:&EC(%-I9VYA='5R92(*;7-G<W1R(")3+TU)344@N6EF<F]V86[]('!O9'!I
M<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S"FUS
M9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%
M(+EI9G)O=F%NX2!Z<'+A=F$B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A
M<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D]V[/AE;NT@<&]M;V/M(%-!4TP@;F5N[2!D
M;W-T=7!NZ2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3`T"FUS
M9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(E--4R!Z<'+A=GDB"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3:&5L;"(*;7-G<W1R
M(")344P@:V]N>F]L82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R
M.#,*;7-G:60@(E-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',B"FUS
M9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S,0IM<V=I
M9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@
M(E-50T-%4U,B"FUS9W-T<B`BVE-0S$-((@H*(SH@;&EB+V%P:2YP:'`Z,34S
M"FUS9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44P@:V]N>F]L82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G
M:60@(E-A(@IM<V=S='(@(E-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V%I
M;G0@2&5L96YA(@IM<V=S='(@(E-V873A($AE;&5N82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3,Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M-`IM<V=I9"`B4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-V873]
M($MI='1S(&$@3F5V:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU
M8VEA(@IM<V=S='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I
M9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(*;7-G<W1R(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I
M;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"FUS9W-T<B`B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE
M("A?<V5L9BDB"FUS9W-T<B`B4W1E:F[]('+A;2`H7W-E;&8I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$Y-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@(E-A;B!-87)I;F\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B
M"FUS9W-T<B`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I
M9&5R(@IM<V=S='(@(E9L87-T;NUK('-A=&5L:71U(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-A=61S:^$@07+A8FEE
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED(")3
M879E(@IM<V=S='(@(E5L;[YI="(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z-#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A
M=F4@7"(E<UPB(@IM<V=S='(@(E5L;[YI="`E<R(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$V"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M)7,B"FUS9W-T<B`B56QOOFET("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N
M9"YI;F,Z-0IM<V=I9"`B4V%V92!/<'1I;VYS(@IM<V=S='(@(E5L;[YE;NT@
M;6^^;F]S=.TB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38W"FUS9VED
M("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B"B)D:7)E8W1O<GDN
M(@IM<V=S='(@(B(*(E5L;[YI="!V>71V;_AE;OT@:V]N9FEG=7)AZ&[M(%!(
M4"!S:W)I<'0@9&\@9&_H87-NZ6AO(&%D<F5SX?AE(&YA('-E<G9E<G4N(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B2V]N9FEG
M=7)A8V4@)7,@=6QOOF5N82XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HY,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B2V]N9FEG=7)A
MZ&[M('-K<FEP="!P<F\@86MT=6%L:7IA8VD@8GEL('5L;[YE;B!D;SH@)R5S
M)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@
M(D]J961I;NQLZ2!B;W7X:WDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`B5NQD82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R
M+VQI<W0N:6YC.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`B5GEH;&5D870B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(P"FUS9VED(")396%R
M8V@@16YG:6YE<R(*;7-G<W1R(")6>6AL963A=F%C[2!NX7-T<F]J92(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y-S,*;7-G:60@(E-E;&5C="!&
M:6QE<R(*;7-G<W1R(")6>6)R870@<V]U8F]R>2(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT.#0*;7-G:60@(E-E;&5C="!A
M(&1A=&4B"FUS9W-T<B`B5GEB<F%T(&1A='5M(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E;&5C="!A(&=R;W5P('1O(&%D
M9"(*;7-G<W1R(")6>6)R870@<VMU<&EN=2P@:W1E<N$@8G5D92!P^&EDX6YA
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,PIM<V=I9"`B4V5L
M96-T(&$@;F5W(&]W;F5R(@IM<V=S='(@(E9Y8G)A="!N;W;I:&\@=FQA<W1N
M[6MA(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED
M(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5GEB<F%T('-E<G9E<B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,34V"FUS9VED(")396QE8W0@
M82!U<V5R('1O(&%D9"(*;7-G<W1R(")6>6)R870@=;YI=F%T96QE+"!K=&5R
M_2!B=61E('#X:63A;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A;&PB"FUS
M9W-T<B`B5GEB<F%T('-O=6)O<GDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RXB
M"FUS9W-T<B`B5GEB<F%T(':Y96-H;GD@Z.%S=&D@9&%T=6UU+B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5GEB<F%T(&]B:F5K="(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S@*(RP@
M9G5Z>GD*;7-G:60@(E-E;&5C="!N;VYE(@IM<V=S='(@(E9Y8G)A="!N;W;I
M:&\@=FQA<W1N[6MA(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C,W"FUS
M9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T
M:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T<B`B(@HB5GEB97)T
M92!P;W3X96)NZ2!Z;F%K>2!Z(&[MOF4@=79E9&5N_6-H(&)O>/DN(%!O=.D@
M:F4@;?F^971E(&MO<.UR;W9A="!A("(*(G9L;[YI="!Z('1E>'1O=ND@;V)L
M87-T:2XB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB97)T92!O
M9&3L;&]V86/M('IN86L@<')O(&1A='5M.B(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T.B(*
M;7-G<W1R(")6>6)E<G1E(&9O<FWA="!D871U;74Z(@H*(SH@=&5M<&QA=&5S
M+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L96-T('1H
M92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(E9Y8F5R
M=&4@:61E;G1I='4L(&MT97)O=2!S:2!P^&5J971E('IM[&YI=#HB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B5GEB97)T92!O9&3L;&]V86/M('IN
M86L@<')O(.AA<SHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B5GEB97)T
M92!F;W)MX70@Z&%S=3HB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B5GEB97)T92!D=NP@;V1P;W;M9&%J[6/M('!O;&4N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+B(*;7-G<W1R(")6>6)E<G1E(&)A<F5V;OT@;6]T:78N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")6>6)E<G1E(%;A;6D@<')E
M9F5R;W9A;OT@:F%Z>6LZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE
M;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B
M4&]S;&%T('IP<N%V=2!O('!R;V)LZ6UU(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,SD*;7-G:60@(E-E;F0@4TU3(@IM
M<V=S='(@(E!O<VQA="!335,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(Q,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")396YE
M9V%L(@IM<V=S='(@(E-E;F5G86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,Q-@IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`B4V5N<V]R.B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#D*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<S"FUS9VED(")3
M97!T96UB97(B"FUS9W-T<B`B6N'X[2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G
M<F\B"FUS9W-T<B`B4W)B<VMO(&$@R&5R;N$@2&]R82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"FUS9VED(")397)I86P@3G5M
M8F5R(@IM<V=S='(@(E/I<FEO=ND@Z.US;&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V97(@9&%T
M82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K(&\@<&_H
M87/M(&YE;NT@9&]S='5P;OTN(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C(W
M"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@(D%D;6EN
M:7-T<F'H;NT@<'+A=F$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B240@<V5K8V4@>F%N:6ML;RXB"@HC.B!L:6(O87!I+G!H
M<#HQ-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E]0<N%V
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,30*;7-G:60@(E-E
M="(*;7-G<W1R(").87-T879I="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R
M(").87-T879I="!M;[YN;W-T:2!P<F\@<&]V;VQE;NT@<F5S971U(&AE<VQA
M+"!P;VMU9"!H;R!Z87!O;65N971E+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,34*;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO
M=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(").
M87-T879I="!V>F3A;&5NZ2!S97)V97)Y('1A:RP@OF4@8G5D;W4@</CM<W1U
M<&[I('H@<&]R=.%L=2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#0*
M;7-G:60@(E-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RXB"FUS9W-T<B`B3F%S=&%V96[M(%;A;6D@<')E
M9F5R;W9A;NEH;R!J87IY:V$L(.AA<V]VZ6AO('#A<VUA(&$@='EP=2!D871U
M;74N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB
M"FUS9W-T<B`B(@HB3F%S=&%V96[M('!OZ.%T9>AN[2!A<&QI:V%C92P@8F%R
M979NZ6AO(&UO=&EV=2P@;V)N;W9O=N%N[2!S='+A;F5K(&$@9&%LN>UC:"`B
M"B)M;[YN;W-T[2!Z;V)R87IE;NTN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HW-0IM<V=I9"`B4V5T=7`B"FUS9W-T<B`B3F%S=&%V96[M(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E
M='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B3F%S=&%V
M;W9A8^T@:V]N9FEG=7)AZ&[M('-K<FEP='D@<')O(&%K='5A;&EZ86-I(&IS
M;W4@9&]S='5P;NDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3@V"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R(").[&MT97+A(&WM<W1A(&QZ92!N87-T
M879I="!S('3M;71O('!A<F%M971R96TZ("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<R(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT.38*;7-G:60@(E-H;W!P:6YG(@IM<V=S
M='(@(DYA:W5P;W;A;NTB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+<N%T:^D@
M<VAR;G5T[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@
M(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS
M/R(*;7-G<W1R(")-[&QY(&)Y(&+]="!P^.US='5P;W;I(&ML[>AE(&1E9FEN
M;W;A;GD@<')O(';L=+EI;G4@;V1K87KY/R(*"B,Z(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(EIO
M8G)A>FET(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U-0IM<V=I9"`B
M(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("):;V)R87II="!R;WID[6QY(&UE>FD@<V]UZ&%S;F]U(&$@</AE9&-H
M;WKM(&MO;F9I9W5R86/M+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT
M.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I
M;C\B"FUS9W-T<B`B6F]B<F%Z:70@Z&%S('!O<VQE9&[M:&\@</AI:&SAN65N
M[2!D;R!S>7-TZ6UU/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T
M<B`B6F]B<F%Z:70@;6^^;F]S="!U9'*^96[M(&]R:6=I;N%L=2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3,*;7-G:60@(E-H;W<@<&EC:V5R
M(@IM<V=S='(@(EIO8G)A>FET('-B[')AZ"(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU
M(&)A<C\B"FUS9W-T<B`B6F]B<F%Z:70@;65N=2!O<&5R8>AN[2!L:;ET=2!P
M<F\@=&%B=6QK>3\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_(@IM<V=S='(@(EIO8G)A>FET("5S(&UE;G4@;F%L979O/R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("):;V)R87II="!D:6%L;V<@<')O('9L87-T;F]S=&D@8G5N
M[&L@=B!T86)U;&OA8V@B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(EIO8G)A>FET(&1I86QO9R!V
M;&%S=&YO<W3M('1A8G5L96LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A
M8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):;V)R87II="!D
M:6%L;V<@=FQA<W1N;W-T[2#XX61E:R!T86)U;&5K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED
M(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*;7-G<W1R("):
M;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!O8G+A>FOY(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,PIM<V=I9"`B4VAO=R!U<&QO860B"FUS
M9W-T<B`B6F]B<F%Z:70@</AE;F]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B
M4/AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,0IM<V=I9"`B4VAO=V5R<R!%87)L>2(*;7-G<W1R(")"<GIKZ2!P
M^&5HX?)K>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B4&]Z9&[M('#X
M96CA\FMY(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3,*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@
M(E#X96CA\FMY('8@;VMO;.TB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R("):;65NN6ET
M(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-S<T(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C@S-@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,C(@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z.3@T"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C
M:R],87EO=70N<&AP.C$P-#<@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`X-PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HQ,3$V(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q-#D*
M;7-G:60@(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O
M=70@;V8@=&AE('=A>2!F:7)S="(*;7-G<W1R("):;65NN6ET(&YE8F\@<&]S
M=6YO=70@9&\@<V]U<V5D;NUH;R!B;&]K=2CY*2P@>B!C97-T>2!P<G9N[6UU
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@
M(E-I97)R82!,96]N92(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P
M+G!H<#HR-C4*;7-G:60@(E-I9VX@=7`B"FUS9W-T<B`B4F5G:7-T<F]V870@
M<V4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<Q,@IM
M<V=I9"`B4VEG;F%T=7)E(@IM<V=S='(@(E!O9'!I<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q"FUS9VED(")3:6=N871U<F4@
M06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M=7,@<')O('!O9'!I<R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R(")3:6YG87!U
M<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*;7-G:60@(E-I
M>F4B"FUS9W-T<B`B5F5L:6MO<W0B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN=&5N86YC
M92(*;7-G<W1R(")6>6YE8VAA="#Z9'*^8G4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS
M9VED(")3;&]V86MI82(*;7-G<W1R(")3;&]V96YS:V\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U"FUS9VED(")3;&]V96YI82(*;7-G<W1R(")3;&]V:6YS:V\B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VYO=R(*;7-G<W1R(")3;NR^96[M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-34*;7-G:60@(E-N;W<@4VAO=V5R(@IM<V=S
M='(@(E-N[&AO=N$@</AE:.'R:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S
M='(@(E-N[&AO=ND@</AE:.'R:WDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY
M(@IM<V=S='(@(E)A;F[M('-N[&AO=ND@</AE:.'R:WDB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3
M:&]W97)S($QA=&4B"FUS9W-T<B`B4&]Z9&[M('-N[&AO=ND@</AE:.'R:WDB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO=R!D97!T
M:#H@(@IM<V=S='(@(E-N[&AO=N$@<&]K<OUV:V$Z(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR.#(*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E
M<CH@(@IM<V=S='(@(E9O9&[M(&5K=FEV86QE;G0@<')O('-N[6@Z("(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`R(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R("*I
M86QA;6]U;F]V>2!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M
M86QI82(*;7-G<W1R(")3;VWA;'-K;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")0[7-N["!A
M(&+A<V[L(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR-@IM<V=I
M9"`B4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B4VWL<B!T^.UD[&[M
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B6F1R
M;VIO=N$@861R97-A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R
M:6-A(@IM<V=S='(@(DIIOF[M($%F<FEK82(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB
M"FUS9W-T<B`B2FEH;V5V<F]P<VO]("A)4T\M.#@U.2TS*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',B"FUS9W-T<B`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O
M=71H(%-A;F1W:6-H($ES;&%N9',B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,S,@;&EB+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI
M<W!H97)E(@IM<V=S='(@(DIIOF[M('!O;&]K;W5L92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C
M92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S='(@(E!R;W-T;W(@;65Z
M:2!S;W5S961N[6UI(&)U\FMA;6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$Q-0IM<V=I9"`B4W!A8V4@8F5T=V5E;B!C
M;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;"(*;7-G<W1R(")0<F]S=&]R(&UE
M>FD@;V)S86AE;2!A(&AR86YI8V5M:2!V(&)U\F-E(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#$U"FUS9VED(")3<&%C97(B"FUS9W-T<B`B365Z
M97)N[6LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B365Z97)Y(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R(")/9'-T
M=7!Y(&$@;65Z97)Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S
M='(@(JEP86[L;'-K;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M.`IM<V=I9"`B4W!A;2(*;7-G<W1R(")3<&%M(@H*(SH@<V5R=FEC97,O:V5Y
M8F]A<F0N<&AP.C$T"FUS9VED(")3<&5C:6%L($-H87)A8W1E<B!);G!U="(*
M;7-G<W1R(")6<W1U<"!P<F\@>G9LX;ET;NT@>FYA:WDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED
M(")3<&QI="!C96QL(@IM<V=S='(@(E)O>F3L;&ET(&)U\FMU(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM
M<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(E)O>F3L;&ET('-L;W5P96,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<Q"FUS9VED(")3<&QI="!R;W<B"FUS9W-T<B`B4F]Z9.QL:70@^.%D
M96LB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*;7-G:60@(E-P;W)T
M<R(*;7-G<W1R(")3<&]R="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA
M;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO;65T87(N<&AP.C<T"FUS9VED(")3
M=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E
M:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@P.0IM<V=I9"`B4W1A<G0@>65A<B(*;7-G<W1R
M(")2;VL@>F'HX71K=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G<W1R(")3
M=.%T(.AI('!R;W9I;F-I92(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]I
M;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS9W-T<B`B4W1A=B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,34*;7-G:60@(E-T;W)A9V4@
M9F]R;6%T(@IM<V=S='(@(D9O<FWA="!U;&^^96[M(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R
M97-S(@IM<V=S='(@(E5L:6-E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G
M<W1R(")0^&6Y:W)T;G5T_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$R,S,*;7-G:60@(E-T<FEN9R!L:7-T(@IM<V=S='(@(E-E>FYA;2#X973L
M>F-E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@W,PIM<V=I9"`B
M4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B"FUS9W-T<B`B3V1S=')A
M;FET(&1O;>EN;W;I(&IMZ6YO('H@861R97-Y(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y
M;&4@6T-34UTB"FUS9W-T<B`B4W1Y;"!;0U-372(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S
M='(@(DYE(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,W"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B4&]D861R97/A^"`G)7,G(&YE8GEL(&YA;&5Z96XN
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")0^&5D;>QT(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N
M9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(E!O9&%T(@H*
M(SH@<VEG;G5P+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T
M(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B)">6QA('!O9.%N82"^
MX61O<W0@;R!P^&EDX6[M("<E<R<@9&\@<WES=.EM=2X@0G5D971E('-E(&UO
M8VD@</AI:&SA<VET(&&^('!O("(*(FML861NZ6T@=GGX[7IE;NT@5F&Y[2"^
MX61O<W1I+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R(")$;VQN[2!I;F1E
M>"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR
M.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+:<W#LN6[L(@H*(SH@861M:6XO
M=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B
M)R5S)R!B>6PH82D@^G-P[+EN["!P^&EDX6XH82D@9&\@<WES=.EM=2XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@7"(E<UPB
M(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1&%T82!P<F\@=;YI=F%T96QE
M("5S(&)Y;&$@^G-P[+EN["!O9'-T<F%N[&YA('IE('-Y<W3I;74N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L
M971E9"!<(B5S7"(N(@IM<V=S='(@(MIS<.RY;NP@;V1S=')A;NQN82`G)7,G
M+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R#Z<W#LN6[L(&]D<W1R86[L;BAA*2!Z
M92!S>7-TZ6UU+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G
M:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(DMO;F9I9W5R86-E(&)Y;&$@
M^G-P[+EN["!Z;>QN[&YA+B!/8FYO=G1E('-T<N%N:W4N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W
M"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(MIS<.RY;ND@=6QOOF5N[2!ZX6QOOF[M(&MO;F9I9W5R
M86-E+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R("+:<W#LN6[I('5L;[YE;NT@
M>N%L;VAY(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,38X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C
M97-S9G5L;'D@=7!D871E9"!<(B5S7"(B"FUS9W-T<B`BVG-P[+ENX2!A:W1U
M86QI>F%C92!P<F\@)R5S)R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!B>6QO(/IS
M<.RY;NP@>F%P<^%N;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM
M<V=S='(@(E-U9.%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3
M:')N=73M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8U"FUS9VED(")3
M=6X@4FES92(*;7-G<W1R(")3=NUTX6[M(@H*(SH@;&EB+T)L;V-K+W-U;G)I
M<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S='(@(EKA<&%D(%-L=6YC
M92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y
M"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;'5N9>AN;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,38*;7-G:60@(E-U;G)I<V4B"FUS9W-T
M<B`B5OUC:&]D(%-L=6YC92(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HS
M(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@IM<V=I9"`B4W5N<FES92]3=6YS
M970B"FUS9W-T<B`B5OUC:&]D+WKA<&%D(%-L=6YC92(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G
M<W1R(")6_6-H;V0@4VQU;F-E.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C$Y"FUS9VED(")3=6YS970B"FUS9W-T<B`B6N%P860@4VQU
M;F-E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q.`IM<V=I
M9"`B4W5N<V5T.B`B"FUS9W-T<B`B6N%P860@4VQU;F-E.B`B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$S"FUS9VED(")3
M=7!E<G-C<FEP="(*;7-G<W1R(")(;W)N[2!I;F1E>"(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS-S@*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B
M4&]D<&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S
M='(@(E-U<FEN86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS9W-T<B`B4/CM:FUE;NTB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA>65N(@IM
M<V=S='(@(E-V86QB87)D(&%N9"!*86X@36%Y96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W=A>FEL<VMO(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(JEVZ61S:V\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV-@IM<V=I9"`B4W=I='IE<FQA;F0B"FUS9W-T<B`BJ7;]8V%R<VMO
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#8*(RP@9G5Z>GD*
M;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS9W-T<B`B3F5S;6%Z870B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30R"FUS9VED(")3>6YC34PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.CDW
M"FUS9VED(")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS(@IM<V=S='(@
M(E-Y;G1A>&]VX2!C:'EB82!V(&AL961A;NEM('1E>'1U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-PIM<V=I9"`B4WER:6%N($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B4_UR
M:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M,`IM<V=I9"`B5"U3=&]R;2(*;7-G<W1R(")";W7X:V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R
M;2!A;F0@5VEN9'DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-C(*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@
M(D)O=?AK>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G<W1R
M(")"<GIKZ2!P^&5HX?)K>2(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(E135B!S;W5B;W(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`B5&%B=6QK82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A8FQE(%!R;W!E
M<G1I97,B"FUS9W-T<B`B5FQA<W1N;W-T:2!T86)U;&MY(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU-PHC+"!F=7IZ>0IM
M<V=I9"`B5&%B;&4@4V5T(@IM<V=S='(@(E1A8G5L:V$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS9VED
M(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E9L87-T;F]S=&D@=&%B=6QK
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,T(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M(")486EW86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(Q.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R
M(")486EW86XL('!R;W9I;F-I92#([6YY(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I
M9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")4862^:6MI<W3A;B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3(*;7-G:60@(E1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B5&%N>N%N:64L(%-P;VIE;N$@<F5P=6)L:6MA(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R
M9V5T.B(*;7-G<W1R(")#[6PZ(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.CDY-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K
M<R(*;7-G<W1R("+::V]L>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3<S"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@
M(E1E;&5F;VYN[2#H[7-L;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP
M"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")497!L;W1A
M('IA('!O<VQE9&[M(&AO9&EN=3H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR,30*;7-G:60@(E1E;7!E<F%T=7)E(@IM<V=S='(@(E1E<&QO=&$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP
M97)A='5R93H@(@IM<V=S='(@(E1E<&QO=&$Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X-PHC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&QA=&4@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B5GIO<B`G)7,G(&YE8GEL(&YA;&5Z96XN(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D
M;6EN:7-T<F%T:6]N(@IM<V=S='(@(E9Z;W(@<')O(&%D;6EN:7-T<F%C:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-@IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-0IM<V=I9"`B5&5X="!/;FQY
M(@IM<V=S='(@(E!O=7IE('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N
M(@IM<V=S='(@(EIA<F]V;N%N[2!T97AT=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S$*;7-G:60@(E1E>'1T;W`B"FUS
M9W-T<B`B5G)C:"!T97AT=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(LAT(@H*(SH@
M8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E1H86D@*%1)4RTV,C`I
M(@IM<V=S='(@(E1H86IS:WD@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&AA:G-K;R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN
M9R!T:&4@<WES=&5M+B(*;7-G<W1R(")$[&MU:F5M92!Z82!P;W6^[7;A;NT@
M<WES=.EM=2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R,`IM
M<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS
M9W-T<B`B4/CM<&]N82!P<F\@1E10(&YE;NT@9&]S='5P;N$N(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("));G1E9W)AZ&[M(&%L9V]R:71M
M>2!V($AO<F1E+TMO;&%B(&YE<&]D<&]R=6KM(%PB)7-<(B(*"B,Z(&9R86UE
M=V]R:R].971?24U34"])35-0+T)O;VLN<&AP.C$R.3(*(RP@9G5Z>GD*;7-G
M:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM
M<V=S='(@(E#X96YE<V5N_2!S;W5B;W(@;F5L>F4@=6QOOFET+B(*"B,Z('-E
M<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA
M;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R
M(").9?IS<.RY;ND@;F'H=&5N[2!T^.UD>2!-86EN=&5N86YC93HZ(@H*(SH@
M<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@
M(D)Y;&\@=7IA=OAE;F\@;VMN;R!S(&UOOFYO<W1M:2X@56MO;NAE;F\N(@H*
M(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HR,3$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HR-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S
M:6]N<RXB"FUS9W-T<B`B(@HB061M:6YI<W1R[71O<B!P;W3X96)U:F4@;F%K
M;VYF:6=U<F]V870@=')V86SA('!RX79A('8@<WES=.EM=2P@<&]K=60@<VD@
M(@HB</AE:F5T92!P;W6^[70@<'+A=F$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O
M='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B4&]U>F4@<W!O9&[M('-T<F%N82(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-C,Y"FUS9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@
M(@HB9&%T86)A<V4N(@IM<V=S='(@(B(*(DYE8GEL;R!U=F5D96YO($E$('!R
M;R!K;VYT86MT+"!N96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y
M;&\@^G!L;NP@(@HB=GEN96-HX6YO+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S
M('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS
M9W-T<B`B2V]N=&%K="!B>6P@^G-P[+EN["!P^&EDX6X@9&\@5F&Y96AO(&%D
M<F5SX?AE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q
M-CD*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K
M(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(DL@;W;L^&5N[2!P;V1E<'-A;ND@>G!RX79Y(&IE('3X96)A(&]D
M9.QL96[](&)L;VL@<R!01U`@<&]D<&ES96TN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H
M92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S
M92XB"FUS9W-T<B`B(@HB3F5B>6QO('5V961E;F\@240@9&ES=')I8G7H;NUH
M;R!S97IN86UU+"!N96)Y;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O("(*
M(F)Y;&\@^G!L;NP@=GEN96-HX6YO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(DYE8GEL
M('5V961E;B!D:7-T<FEB=>AN[2!S97IN86TN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+G!H<#HQ,3,*;7-G:60@(E1H92!E;F-R>7!T:6]N(&9E871U
M<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(@IM<V=S='(@
M(B(*(JEI9G)O=F%C[2!M;[YN;W-T:2!L>F4@=GEUONUT('!O=7IE('#X:2!B
M97IP9>ANZ6T@<W!O:F5N[2!S('=E8F5M("AH='1P<RDN(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HU,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(*;7-G<W1R(")3;W5B;W(@)7,@
M8GD@;>QL(&]B<V%H;W9A="!N87-T879E;NT@)7,N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B4V]U8F]R("5S
M(&)Y(&WL;"!O8G-A:&]V870@;NQK=&5RX2!Z(&YA<W1A=F5N[2`E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3D*;7-G:60@(E1H92!F
M:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R(")3
M;W5B;W(@;F5L>F4@:V]P[7)O=F%T('/A;2!D;R!S96)E+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(X,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(E-O=6)O<B!N96]B<V%H=6IE(+[A9&[A
M(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B3N%S
M;&5D=6KM(&AL879IZ&MY('!R;R!M97-S86=E+W)F8S@R,B!Z<'+A=G4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS
M9VED("(B"B)4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S
M92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@
M8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U
M;F0N("!9;W4@;6EG:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@
M:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B
M"B)0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN
M66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@
M>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N
M(@IM<V=S='(@(B(*(DIE('INX6WI+""^92!M\V0@</AE<R!C96QO=2!O8G)A
M>F]V:W4@=B!);G1E<FYE="!%>'!L;W)E<G4@</ES;V+M('!R;V)LZ6UY+"`B
M"B)P<F]T;[YE('-E('8@;NQM('9Y<VMY='5J92!C:'EB82P@:W1E<ND@<V4@
M;F5L>F4@=GEH;F]U="X@2F%K;R!NX7-L961E:R!M^;YE("(*(F+]="!NX6AO
M9&[I('IH<F]U8V5N[2!T;VAO=&\@<')O9W)A;74L(&-H>6+L:NUC[2!F=6YK
M8V4@961I=&]R=2!N96)O("(*(FYE<W!RX79NZ2!Z;V)R87IO=N%N[2X@4&]K
M=60@:F4@5N&Y('-Y<W1E;>EM(%=I;F]D=W,@.7@L(&IE('9E;&UI("(*(G!R
M879D['!O9&]B;NDL(+YE('-E(&]B:F5V[2!C:'EB;W;I(&ALX;EE;NT@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@82`B"B)B=61E=&4@;75S970@<F5S
M=&%R=&]V870@<&_H[71AZ"Y<7&Y<7&Y">6QI(&IS=&4@=F%R;W;A;FDN(%!R
M;W/M;2!S=&ES:V[L=&4@(@HB3TL@<&]K=60@<VD@</AE:F5T92!P;VMR8>AO
M=F%T('8@;?-D=2!P^&5S(&-E;&]U(&]B<F%Z;W9K=2XB"@HC.B!S97)V:6-E
M<R]P<F5F<RYP:'`Z.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT
M:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R("))9&5N=&ET
M82!<(B5S7"(@8GEL82!S;6%ZX6YA+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T
M+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E!O=7IE(&YA(&QE=ND@<W1R86[L
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED
M("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B56WM
M<W3L;NT@8FENX7)N[6AO('-O=6)O<G4@1VYU4$<@;75S[2!B_70@>F%DX6YO
M(&1O('3X[61Y($-R>7!T7W!G<#HZ+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE(&UE
M<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@7"(E<UPB(&AA
M<R!B965N(&1I<W!L87EE9"Y<;B(*(E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+B(*
M;7-G<W1R("(B"B):<'+A=F$@>F%S;&%NX2!V("5S(&L@)7,@<R!P^&5D;>QT
M96T@7"(E<UPB(&)Y;&$@>F]B<F%Z96YA+EQN(@HB5&]T;R!N97IA<G7H=6IE
M+""^92!Z<'+A=F$@8GEL82!P^&7H=&5N82!N96)O(+YE(&KM(&%D<F5SX70H
M:V$I(')O>G5M[&PH82DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3@W-PIM<V=I9"`B5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T
M:&4@8V]M<&]S92!P86=E(@IM<V=S='(@(D[A>F5V+"!K=&5R_2!B=61E('!O
M=;YI="!P^&D@;V1K87IO=N%N[2!N82!S='+A;F-E('1V;W)B>2!Z<'+A=B(*
M"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C0T,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+B(*
M;7-G<W1R(")4;W1O('!O;&4@;75S[2!B_70@<&QA=&[I(.CM<VQO+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(S,0IM<V=I9"`B
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B5/CM9&$@2&]R9&5?0W)Y
M<'1?<VUI;64Z.B!V>;YA9'5J92!M;V1U;"!O<&5N<W-L+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@
M8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO
M=V%B;&4@<VEZ92(*;7-G<W1R("(B"B).96QZ92!U;&^^:70@;F%S=&%V96[M
M(%PB)7-<(BP@<')O=&^^92!J96AO('9E;&EK;W-T('#X97/A:&QA('!O=F]L
M96[](&QI;6ET+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E
M8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I
M<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W
M97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R
M<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P
M<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG
M:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS
M97AC96PN<&AP.C,R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G
M<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@
M9F]U;F0@;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`B3F5B>6QA(&YA;&5Z96YA
M(&%P;&EK86-E('!R;R#H=&5N[2!T;VAO=&\@='EP=2!D870@*"5S*2XB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q
M=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F$@<')A=ND@82!L97;I('-T<F%N
M["(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S@*;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G
M<W1R(")0;W5Z92!N82!P<F%VZ2!S=')A;NPB"@HC.B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B
M92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
M4V5R=F5R(%PB)7-<(B!B>6P@=GEM87KA;BXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R(%PB
M)7-<(B!B>6P@=6QOOF5N+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N(@IM<V=S='(@(D)Y;&$@;V1S=')A;NQN82"^X61O
M<W0@;R!P^&EH;.&Y96[M('!R;R`E<RXB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@(E1H92!S<&5C:69I960@<F]W
M(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")0;[YA9&]V86[](/CA9&5K(&YE
M97AI<W1U:F4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<
M(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1&_H87-N_2!S;W5B;W(@7"(E
M<UPB(&YE97AI<W1U:F4N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C
M:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS
M9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")0
M;W5Z92!N86AO^&4@82!D;VQE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E
M(&]N;'DB"FUS9W-T<B`B4&]U>F4@;F%H;_AE(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82YP:'`Z,S(W"FUS9VED(")4:&4@=7!L;V%D960@9&%T82!W87,@
M;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"XB"FUS9W-T<B`B6G1R871I
M;&$@<V4@</AE;F5S96[A(&1A=&$@>B!P^&5D8VAO>NUH;R!K<F]K=2XB"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R(&9R86UE=V]R:R]$
M871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE
M(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`B4/AE;F5S96[]('-O=6)O
M<B!N96QZ92!U;&^^:70N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C0V(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$U(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ,3D*;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")";&]K('=E871H97(N8V]M(&YE
M;NT@9&]S='5P;OTN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C(U"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB
M)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(DYE8GEL(&YA;&5Z96X@861R97/A
M^"!S('3I;6%T>2`G)7,G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3<X"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(J[A9&[I('H@;6^^;F]S=.T@;F5J<V]U(&1O<W1U<&[I
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C,T,@IM
M<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N(@IM<V=S='(@(DYE8GEL>2!N86QE>F5N>2"^X61NZ2#HX7-T
M:2P@:W1E<ND@8GD@8GEL;R!M;[YN;R!Z;V)R87II="!V(/CA9&MU+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(E#X[6QI
MN2!M;F]H;R!Z;F%K^2!V('!O;&DN(%IA9&%L:2!J<W1E("5S('IN86OY.R!M
M=7/M=&4@>F%D870@;>EN["!N9;X@)7,@(@HB>FYA:_DN(@H*(SH@<VEG;G5P
M+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O
M('1H92!S>7-T96TZ("5S(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI('#X
M:63A=N%N[2`G)7,G(&1O('-Y<W3I;74Z("5S(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3(R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@
M=&AE('-Y<W1E;3H@(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI(&]D<W1R
M8?)O=N%N[2!UOFEV871E;'-K_6-H(&1A="`G)7,G('IE('-Y<W3I;74Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O
M;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B3F%S=&%L82!C:'EB82!P^&D@;V1S
M=')A\F]VX6[M("<E<R<@>F4@<WES=.EM=3H@(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B3F%S=&%L
M82!C:'EB82!P^&D@86MT=6%L:7IA8VD@)R5S)SH@)7,B"@HC.B!F<F%M97=O
M<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(").87-T86QA(&-H>6)A('#X
M:2!P^&5N;W-U('-O=6)O<G4Z("5S(&YE8GEL('#X96YE<V5N+B(*"B,Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@X.0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M("(*
M(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R("(B"B).87-T86QA
M(&-H>6)A('#X:2!P^&5N;W-U('-O=6)O<G4N("5S(&YE;?F^92!B_70@=NQT
MN>T@;F6^(&UA>&EMX6QN[2`B"B)P;W9O;&5NX2!V96QI:V]S="`H)60@8GET
M^2DN(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#DQ"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@
M=7!L;V%D960N(@IM<V=S='(@(DYA<W1A;&$@8VAY8F$@</AI('#X96YO<W4@
M<V]U8F]R=3H@8GEL82!P^&5N97-E;F$@:F5N(.CA<W0@<V]U8F]R=2`E<RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U
M"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R="(*;7-G<W1R(")$;[EL;R!K(&-H>6+L('#X:2!Z;V)R87IO
M=N%N[2!TZ71O(.CA<W1I('IP<N%V>2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-#@*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB"FUS9W-T<B`B3F%S=&%L
M82!C:'EB82!P^&D@:6UP;W)T;W;A;NT@:V]N=&%K='4N(@H*(SH@9G)A;65W
M;W)K+T1A=&$O1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@
M97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B
M4/AI(&EM<&]R=&]VX6[M(&E#86QE;F1A<B!D870@9&^Y;&\@:R!C:'EB["XB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"FUS9VED("(B"B)4:&5R
M92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R
M:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS9W-T
M<B`B(@HB0VAY8F$@=B!K;VYF:6=U<F'H;NUM(&9O<FUU;.'X:2X@6OAE:FWL
M(&IS=&4@=GEN96-H86QI('!OOF%D;W9A;ND@<&]L92XB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE
M9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@
M;&%T97(N(@IM<V=S='(@(B(*(DYA<W1A;&$@8VAY8F$@</AI('!R;W;A9.QN
M[2!Z861A;ND@;W!E<F%C92!V(&%D<F5SX?AI+B!0<F]S[6T@>FMU<W1E('1O
M("(*(G!O>F3L:FDN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HV-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O
M<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R(").87-T86QA(&-H>6)A('#X:2!A:W1U86QI
M>F%C:2!K;VYT86MT=2X@4')O<^UM('IK=7-T92!T;R!P;WID[&II+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"FUS
M9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G<W1R
M("(B"B).87-T86QA(&-H>6)A('#X:2!A:W1U86QI>F%C:2!D:7-T<FEB=>AN
M[6AO('-E>FYA;74N(%!R;W/M;2!Z:W5S=&4@=&\@(@HB<&]Z9.QJ:2XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-#@*;7-G
M:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N(@IM<V=S='(@(E1E;G1O($E-05`@<V5R=F5R(&YE<&]D<&]R
M=6IE('-D[6QE;NT@<VQOOF5K+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-#@*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N(@IM<V=S='(@(E1O=&\@;F5V
M>7!A9.$@:F%K;R!P;&%T;OT@<F%R(&%R8VAI=BXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")4
M;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]('II<"!S;W5B;W(N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$T-0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(E1O
M=&\@;F5V>7!A9.$@:F%K;R!P;&%T;ND@Z.US;&\@:V%R='DN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@U"FUS
M9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O(@HB8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B
M"B)496YT;R!O=FQA9&'H('5M;[[R=6IE('!O<^ULX6[M('IP<N%V('!O;6]C
M[2!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"XB"B)C;VTI(&)RX6YY
M('#X:2!P;W6^:73M($A45%`@05!)(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(B(*(E1H:7,@
M9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE
M(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)496YT;R!O=FQA9&'H('5M;[[R=6IE
M('!O<^ULX6[M('IP<N%V('!O;6]C[2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN(@HB8V]M*2!B<N%N>2!P^&D@<&]UOFET[2!(5%10($%022(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HB5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO
M8^T@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+B(*(F-O;2D@8G+A;GD@
M</AI('!O=;YI=.T@2%144"!!4$DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR
M;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6
M;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT
M('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB
M"FUS9W-T<B`B(@HB5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z
M<'+A=B!P;VUO8^T@4TU44"!D;R!6;V1A9F]N92!)=&%L>2!B<N%N>2`B"B)P
M;W5Z92!P<F\@Z.US;&$@<&]S:WET;G5TZ2!6;V1A9F]N96TN($UU<^UT92!M
M[70@96UA:6QO=OT@^NAE="!U(%9O9&%F;VYE("(*(DET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3<X
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3<*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3$U
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#(@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S.3@*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P-S@*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C@*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HS,S`V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,X,30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R,@IM<V=I9"`B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB"FUS9W-T<B`B5&]T;R!P;VQE(&IE(&YU=&[I('9Y<&QN
M:70N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R
M(")4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$X"FUS9VED(")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(*;7-G<W1R(")4;W1O('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5L
MX2#H[7-L82!A(&1V;VIT9>AK=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R(")4;W1O('!O;&4@;?F^92!O8G-A:&]V
M870@<&]U>F4@;W-M:>AK;W;I(.CM<VQA+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(E1O=&\@<&]L92!M=7/M(&+]="!S97IN86T@8V5L_6-H(.CM<V5L(&]D
M9.QL96[]8V@@Z.%R:V]U(&YE8F\@;65Z97)O=2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDX.0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+B(*;7-G<W1R(")4;W1O('!O;&4@;75S[2!B_70@<&QA
M=&[I(.CM<VQO+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,S8*
M;7-G:60@(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S
M-&%F)RXB"FUS9W-T<B`B(@HB5&]T;R!P;VQE(&UU<^T@<&)S86AO=F%T(&)A
M<F5V;OT@:_-D('8@N65S=&[A8VMO=NEM(%)'0B!F;W)MX71U+"!N87#X+B`B
M"B(G(S$R,S1A9B<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q
M"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M(@IM<V=S='(@(E1E;G1O(&9O<FUU;.'X(&IIOB!B>6P@>G!R86-O=N%N+B(*
M"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(E1O=&\@:F4@)7,N(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"`B"B)C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N=',@<&QE
M87-E('9I<VET("5S(@IM<V=S='(@(B(*(E1O=&\@:F4@;V)J96MT($MO;&%B
M($=R;W5P=V%R=2X@2R!Z:&SI9&YU=.T@=&]H;W1O(&]B:F5K='4@:F4@>F%P
M;W3X96+M(&WM="`B"B)P;[ET;W9N[6AO(&ML:65N=&$L(&MT97+](')O>G5M
M[2!F;W)MX71U($MO;&%B($=R;W5P=V%R=2X@4')O('-E>FYA;2`B"B)T86MO
M=OUC:"!K;&EE;G3Y('!R;W/M;2!N87:Y=&EV=&4@)7,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S='(@(E1A=&\@
M>G!RX79A(&)Y;&$@;F%P<^%N82!V(&II;ND@>FYA:V]VZ2!S863L("@E<RD@
M;F6^(%9AN>TN("(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB
M"FUS9W-T<B`B5&]T;R#H[7-L;R!M=7/M(&+]="!N96IMZ6[L(&IE9&YA+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM
M<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N(@IM<V=S='(@(E-E<G9E<B!N96WYOF4@<F]Z8F%L:70@>FEP
M(&$@9WII<"!S;W5B;W)Y+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y<W1E;2!I<R!C=7)R96YT
M;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E1E;G1O('-Y<W3I;2!J92!V('-O
M=>AA<VYO<W1I(&1E86MT:79O=F%N_2XB"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+B(*;7-G<W1R(")4871O(&AO9&YO=&$@;75S[2!B_70@Z.US;&\N
M(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HS-0IM<V=I
M9"`B5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS
M('=I;F1O=R(*;7-G<W1R(")4;W1O(&]K;F\@;76^92!B_70@=F]LX6YO('!O
M=7IE('H@;VMN82!M;[YN;W-T[2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(DCX
M;>QN[2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@
M(E1I8VME=',B"FUS9W-T<B`B3.US=&MY(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M;7-G:60@(E1I;64B"FUS9W-T<B`BR&%S(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R(")3
M;&5D;W;A;NT@Z&%S=2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I
M9"`B5&EM92!F;W)M870B"FUS9W-T<B`B1F]R;>%T(.AA<W4B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"FUS9VED(")4:6UE('-E;&5C=&EO
M;B(*;7-G<W1R(")6_6+L<B#H87-U(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5&EM;W(M3&5S=&4B"FUS9W-T<B`B5&EM;W(M3&5S=&4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R(")4:71U;"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G
M:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B5&ET=6P@*'1I<"DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`B2V]M=2(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*(E!O:W5D('-I('#X96IE=&4@=GEB<F%T(';M8V4@<&]L;[YE:RP@>FWA
MZ&MN['1E(&MLX79E<W4@0V]N=')O;"`H4$,I(&YE8F\@(@HB0V]M;6%N9"`H
M36%C*2!A(&ML:6MN['1E(&YA('!O;&^^:W4N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D87DB"FUS9W-T<B`B1&YE
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C@*;7-G:60@(E1O9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")0^&5P;F]U
M="!N82!(5$U,('ID<F]J(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G;R(*
M;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*
M;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,Q,PIM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B6NUT<F$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(R-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")4;VYG82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PIM
M<V=I9"`B5&]P(@IM<V=S='(@(E9R8V@B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T
M;W`I(@IM<V=S='(@(DAO<F[M('+A;2`H7W1O<"DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")0
M^&5K;&%D>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1R:6YI9&%D(&%N9"!4
M;V)A9V\B"FUS9W-T<B`B5')I;FED860@82!4;V)A9V\B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ-SDP"FUS9VED(")4<G5E(&]R(&9A;'-E(@IM
M<V=S='(@(E-P<N%V;NP@;F5B;R"Y<&%T;NPB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R
M("+:="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5'5N:7-K;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R
M(")4=7)E8VMO(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<F5C:WD@*$E33RTX
M.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE;FES=&%N(@IM
M<V=S='(@(E1U<FMM96YI<W3A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E1U
M<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4=7)K<R!A($-A:6-O
M<R!O<W1R;W9Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S,@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S
M='(@(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G
M:60@(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R(").87!IN71E(%9AN6D@
M=F]L8G4Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(V.0IM
M<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E4N5BX@:6YD97@Z("(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#D@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*;7-G<W1R(")54DPB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(E523"!P<F\@>G!RX79U(&\@<W1A=G4@>F%S
M;&%NZ6AO('-K<FEP='4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R"FUS9VED(")59V%N9&$B"FUS9W-T<B`B56=A;F1A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,S,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,@IM<V=I9"`B56MR86EN92(*;7-G<W1R(")5:W)A:FEN
M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@IM<V=I9"`B
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@
M861R97/A^"!J92!N97#X[7-T=7!N_2XB"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM<V=S='(@(E#X
M:2!R96=I<W1R86-I(&YE;'IE('#X:61A="!E>'1R82!UOFEV871E;'-KZ2#Z
M9&%J92XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,X.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@>FWL;FET('!R
MX79A('!R;R!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HS.#4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C0V.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").96QZ92!Z
M;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@)7,O)7,N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H86YG92!T;R`E<RXB"FUS9W-T<B`B3F5L>F4@>FWL;FET
M(&YA("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B3F5L>F4@</AE<W5N;W5T(%9&
M4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<
M(B5S+R5S7"(N(@IM<V=S='(@(DYE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B
M;W(@)7,O)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S
M-0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS
M9W-T<B`B3F5L>F4@<V4@</AI<&]J:70@:R!344P@<V5R=F5R=2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0IM<V=I9"`B56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(DYE;'IE('-E('#X:7!O:FET
M('!O;6]C[2!34TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z
M,C(U(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(@IM
M<V=S='(@(DYE;'IE(&MO<.UR;W9A="!61E,@<V]U8F]R+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S
M='(@(DYE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-30@9G)A;65W;W)K+U9&4R]6
M1E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C4V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(DYE;'IE('9Y='9O^&ET(%9&4R!A9')E<^'X+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM<V=S='(@(DYE;'IE('9Y='9O^&ET
M(%9&4R!S;W5B;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@(DYE;'IE('#X96IM96YO
M=F%T(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(V-0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@=GET=F_X:70@<'+A>F1N_2!61E,@
M<V]U8F]R+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N
M<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T
M<B`B3F5L>F4@<F]Z8F%L:70@9&%T82XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S;6(N<&AP.C(R-"!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN(@IM<V=S='(@(DYE;'IE('9Y
M;6%Z870@7"(E<UPB+"!P<F]T;[YE(&%D<F5SX?@@;F5N[2!P<N%Z9&[]+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O9&5L971E+G!H
M<#HT-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!<(B5S7"(Z("5S+B(*;7-G<W1R(").96QZ92!V>6UA>F%T("<E<R<Z
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3F5L>F4@
M=GEM87IA="`E<RP@<')O=&^^92!A9')E<^'X(&YE;NT@<'+A>F1N_2XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0X(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2XB"FUS9W-T<B`B3F5L
M>F4@<F5K=7)Z:7;L(&]D<W1R86YI="!61E,@861R97/A^"XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O
M;75S<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,S,U(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").96QZ92!V>6UA>F%T
M(%9&4R!A9')E<^'X+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M-#$W(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-#(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M(@IM<V=S='(@(DYE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C`W"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(").96QZ92!V>6UA>F%T(%9&4R!S;W5B;W(@7"(E<UPB+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,P,R!F<F%M97=O<FLO5D93+U9&
M4R]S<6PN<&AP.C(X.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,38W(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#`*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X-R!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S@S"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS.3$*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM
M<V=S='(@(DYE;'IE('9Y;6%Z870@5D93('-O=6)O<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS
M9W-T<B`B3F5L>F4@=GEM87IA="!61E,@<V]U8F]R(%PB)7-<(BXB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0P-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM
M<V=S='(@(DYE;'IE(')E:W5R>FEV;NP@;V1S=')A;FET(%9&4SH@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DYE
M;'IE('5RZ&ET(&%K='7A;&[M(&%D<F5SX?@N(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3F5L>F4@>FII<W1I
M="!P;V1R;V)N;W-T:2!O(&-E<G1I9FEKX71U+B(*"B,Z(&9R86UE=V]R:R].
M971?24U34"])35-0+G!H<#HT-3$@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M075T:"YP:'`Z,3$X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!L
M;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R(")$969I;FEC92`E
M<R!N96[M(&1O<W1U<&[A+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$V-B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,3<Q"FUS9VED(")5;F%B;&4@=&\@;6]V92!6
M1E,@9FEL92XB"FUS9W-T<B`B3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO
M5D93+U9&4R]S;6(N<&AP.C$P,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C8T."!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.CDX"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB
M"FUS9W-T<B`B3F5L>F4@</AE<W5N;W5T(%9&4R!S;W5B;W(@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,P"B,Z(&9R86UE=V]R:R]61E,O5D93
M+W-Q;%]F:6QE+G!H<#HQ,S,*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(")61E,@<V]U8F]R(&YE;'IE(&]T
M97;X[70@<')O('KA<&ES+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!O=&5V^.UT(%9&4R!S
M;W5B;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E
M+B(*;7-G<W1R(").96QZ92!O=&5V^.UT(&%R8VAI=F]V86[]('-O=6)O<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I
M+B(*;7-G<W1R(").96QZ92!Z87!S870@9&%T82!D;R!61E,@<V]U8F]R=2`H
M<V5L:&%L;R!C;W!Y*"DI+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX
M-C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG
M971&:6QE4VEZ92@I(&9A:6QE9"DN(@IM<V=S='(@(DYE;'IE('IA<'-A="!D
M871A(&1O(%9&4R!S;W5B;W)U("AS96QH86QO(&-O<'DH*2DN(@H*(SH@9G)A
M;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP
M.C,X"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS
M9W-T<B`B3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R
M96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`B3F5L>F4@Z.US
M="!Z('9F<W)O;W0@861R97/A^&4N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HQ,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="`E<R!N82`E<SH@8^UL
M;W;A('-L;[YK82!J:;X@97AI<W1U:F4B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!A9')E<^'X(&YE;'IE('#X96IM
M96YO=F%T+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(E9&4R!A9')E<^'X(&YE;'IE('#X96IM96YO
M=F%T.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(V-R!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,T,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T
M<B`B3F5L>F4@</AE:FUE;F]V870@5D93('-O=6)O<B!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B3F5L>F4@</AE
M:FUE;F]V870@5D93('-O=6)O<B`E<R\E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z
M,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-3(@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(X-0HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS9VED(")5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+B(*;7-G<W1R(").96QZ92!P^&5J;65N;W9A="!61E,@<V]U
M8F]R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M
M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F<R<N
M(@IM<V=S='(@(DYE;'IE('!R;W;I<W0@)VUK:7-O9G,G+B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z-3D*;7-G:60@(E5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@
M(E1E;G1O(&1O:W5M96YT(%=O<F0@;F5L>F4@</AE;&^^:70B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").96QZ92!Z87!S870@9&\@
M5D93('-O=6)O<G4@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B3F5L>F4@>F%P<V%T(&1A=&$@9&\@
M5D93('-O=6)O<G4@*'-E;&AA;&\@8V]P>2@I*2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C$S.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,30S"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`B3F5L>F4@>F%P<V%T(&1A=&$@9&\@5D93('-O=6)O<G4B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N
M(@IM<V=S='(@(DYE;'IE('IA<'-A="!D871A(&1O(%9&4R!S;W5B;W)U("AS
M96QH86QO(&-O<'DH*2DN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E!O
M9'1R:&YU=.DB"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHV"FUS9VED
M(")5;F1O($-H86YG97,B"FUS9W-T<B`B4W1O<FYO('IM[&XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")3=&]R;F]V870@<&]S
M;&5N[2!A:V-I(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Y,`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E
M<B!O;B!C;VYN96-T:6]N.B`B"FUS9W-T<B`B3F5OZ&5KX79A;N$@;V1P;W;L
M[R!S97)V97)U(&YA('-P;VIE;NTZ("(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F
M<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(DYE;^AE:^%V86[A(&]D<&]V[.\@
M<V5R=F5R=3H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B3F5V>7!L
M;NQN;R(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DS"FUS9VED(")5;FEC
M;V1E("A55$8M."DB"FUS9W-T<B`B56YI8V]D92`H551&+3@I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(E-P
M;VIE;ND@07)A8G-KZ2!%;6ERX71Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,S@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5
M;FET960@2VEN9V1O;2(*;7-G<W1R(")696QKX2!"<FETX6YI92(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B4W!O:F5N
MZ2!3=.%T>2!!;65R:6-KZ2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R(")3<&]J
M96[I(%-TX71Y($UE;KEI;F]V_6-H(&]S=')O=ODB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM
M<V=I9"`B56YI=',B"FUS9W-T<B`B2F5D;F]T:WDB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(DYE>F[A;>DB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2XB"FUS9W-T<B`B3F5Z;N%MZ2!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A
M9V4@240I+B(*;7-G<W1R(").97INX6WI(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M.0HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"XB
M"FUS9W-T<B`B3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS
M9VED(")5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(").
M97INX6WI('6^:79A=&5L<VOI(&IMZ6YO(&YE8F\@:&5S;&\N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X
M"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R(")/
M9'!O:FET('-O=>AA<V[]('!R=F5K(@H*(SH@9G)A;65W;W)K+TED96YT:71Y
M+TED96YT:71Y+G!H<#HR.38*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B0F5Z
M92!J;>EN82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO
M="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B
M"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI
M8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB
M"FUS9W-T<B`B(@HB3F5P<FEV:6QE9V]V86[I('-K<FEP='D@;F5M;VAO=2!V
M>76^[79A="!F=6YK8V$@5GEJ;6]U="]+;W#M<F]V870O5FQOOB!Z("(*(F)E
M>G!EZ&YO<W1N[6-H(&3Y=F]D^2X@2VQI:V[L=&4@;F$@3TL@86)Y<W1E('9I
M9.QL:2!T96-H;FEC:V]U('IP<N%V=2!Z("(*(FUO>FEL;&$N;W)G+"!K=&5R
MX2!V>7-V['1L=6IE+"!J86L@;F%S=&%V:70@<VMR:7!T('!R;R!P^.US='5P
M(&ME('-C:'+A;F-E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S
M='(@(DYE;F%S=&%V96[A(&)A<G9A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV.#8@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HY,C8*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HY
M,S(*;7-G:60@(E5N<W5P<&]R=&5D($5X=&5N<VEO;B(*;7-G<W1R(").97!O
M9'!O<F]V86[A('#X[7!O;F$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C$Y-R!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHS,PIM
M<V=I9"`B57!D871E(@IM<V=S='(@(D%K='5A;&EZ;W9A="(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,CD*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B57!D871E("5S(@IM<V=S='(@(D%K='5A;&EZ;W9A="`E<R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-S8*;7-G:60@(E5P
M9&%T92!U<V5R(@IM<V=S='(@(D%K='5A;&EZ;W9A="!UOFEV871E;&4B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C$T-"!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#(@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(D%K='5A
M;&EZ;W;A;GD@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX
M,PIM<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4VMR
M:7!T('!R;R!A:W1U86QI>F%C:2!B>6P@=GEM87KA;BXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A9"(*;7-G<W1R(")0^&5N;W,B
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@V"FUS9VED(")5<&QO861E
M9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB
M"FUS9W-T<B`B5KEE8VAN>2!S;W5B;W)Y('!R;R!N87-T879E;NT@87!L:6MA
M8^T@8GEL>2!P^&5N97-E;GD@;F$@<V5R=F5R+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@
M(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B5F5L:^$@=&ES:V%C[2!P
M[7-M96YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*
M;7-G<W1R(")696QKZ2#X[6US:^D@Z.US;&EC92(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B57)U9W5A>2(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C0U"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*;7-G<W1R(")0;W6^[70@
M86MT=>%L;NTZ("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B4&]U
MONUT(%-33"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@
M(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S
M97)V97(N(@IM<V=S='(@(E!O=;[M="!P;VMU9"!J;>EN;R]H97-L;R!J<V]U
M(&II;ND@;F6^('!R;R!)35-0('-E<G9E<BXB"@HC.B!T96UP;&%T97,O861M
M:6XO9W)O=7!S+V5D:70N:6YC.C(Q"B,L(&9U>GIY"FUS9VED(")5<V5R(@IM
M<V=S='(@(E6^:79A=&5LZ2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]2
M96=I<W1R>2YP:'`Z-S(S"B,L('!H<"UF;W)M870*;7-G:60@(E5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R(")5OFEV871E;"`E
M<R!N96[M(&]P<N%V;NQN(&L@<&]UONUVX6[M("5S+B(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R
M(")!9&UI;FES=')A8V4@=;YI=F%T96SY(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M(")5OFEV871E;'-KZ2!M;[YN;W-T:2(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES=')A8V4@=;YI
M=F%T96SY(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I<W1R
M871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T
M<B`B3F$@=&]M=&\@<V5R=F5R=2!N96[M(&UOOF[A(')E9VES=')A8V4@=;YI
M=F%T96SY+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*(RP@9G5Z
M>GD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@
M;F5B>6QO(&YA;&5Z96YO+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*;7-G:60@
M(E5S97)N86UE(@IM<V=S='(@(E6^:79A=&5L<VOI(&IMZ6YO(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S
M+B(*;7-G<W1R(")5OFEV871E;'-KZ2!J;>EN;R`G)7,G(&IIOB!E>&ES='5J
M92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@
M(E5S97)N86UE.B(*;7-G<W1R(")5OFEV871E;'-KZ2!J;>EN;SHB"@HC.B!T
M96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX"FUS9VED(")5<V5R;F%M93H@
M(@IM<V=S='(@(E6^:79A=&5L<VOI(&IMZ6YO.B`B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES
M=&5M.B(*;7-G<W1R(")397IN86T@=;YI=F%T96SY.B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B57IB96MI<W3A;B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$V,R!F<F%M97=O<FLO5D93
M+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@(E9&4R!D:7)E8W1O<GD@9&]E<R!N
M;W0@97AI<W0N(@IM<V=S='(@(E9&4R!A9')E<^'X(&YE97AI<W1U:F4N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q.`IM<V=I9"`B5F%C871I
M;VXB"FUS9W-T<B`B1&]V;VQE;N$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B`B"FUS9W-T<B`B3F%L97IE;N$@<&QA=&[A(&WM<W1A('IA:')N=6KM.B`B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I
M9"`B5F%L:61I='DB"FUS9W-T<B`B4&QA=&YO<W0B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@
M(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N(@IM<V=S='(@(DAO9&YO=&$@
M=B!M:6YU=.%C:"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$W-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS
M9VED(")686QU97,B"FUS9W-T<B`B2&]D;F]T>2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-@IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(E9Y8G)A
M;ND@:&]D;F]T>2!Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5F%N=6%T=2(*
M;7-G<W1R(")686YU871U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(T-`IM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B4')O;>QN;NDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$U"FUS9VED(")696YE>G5E;&$B"FUS9W-T<B`B5F5N97IU
M96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,3@*
M;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y
M(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R(")396QH86QA('9E
M<FEF:6MA8V4@+2!T871O('IP<N%V82!M;VAL82!B_70@>F9A;+EO=N%N82XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I
M9"`B5F5R<VEO;B(*;7-G<W1R(")697)Z92(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR,C8*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R
M(")697)S:6]N($-O;G1R;VPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;"!A;&EG
M;B(*;7-G<W1R(")697)T:6OA;&[M('IA<F]V;N%N[2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#0*;7-G:60@(E9E<G1I
M8V%L('!A9&1I;F<B"FUS9W-T<B`B5F5R=&EKX6QN[2!O9'-T=7`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;#HB"FUS9W-T<B`B5F5R=&EKX6QN[3HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R>2!(
M:6=H(@IM<V=S='(@(E9E;&UI('9Y<V]KX2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(E9I971N86TB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$Y-`IM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)*2(*;7-G
M<W1R(")6:65T;F%M<VMY("A625-#24DI(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]#;VYT96YT<RYP:'`Z.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I
M97<@)7,B"FUS9W-T<B`B6F]B<F%Z:70@)7,B"@HC.B!L:6(O0FQO8VLO:69R
M86UE+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM
M<V=S='(@(EIO8G)A>FET(&5X=&5R;NT@=V5B<W1RX6YK=2(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(EIO8G)A>FET(&IA:V\@)7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES
M:"(*;7-G<W1R(")086YN96YS:^D@3W-T<F]V>2P@0G)I='-KZ2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0W(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C0T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@
M(E!A;FYE;G-KZ2!/<W1R;W9Y+"!5+E,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,#D*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FED:71E;&YO
M<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED
M(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B5FED:71E;&YO<W0Z(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*
M;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S='(@(E9O9&%F
M;VYE($ET86QY('#X97,@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I
M;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@
M(E=!4DXB"FUS9W-T<B`B55!/6D]23DE4(@H*(SH@861M:6XO<V5T=7`O<V-R
M:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!2
M14U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@(E503UI/
M4D[,3LTA(2$@3T135%)!TE1%(%-+4DE05"!25<A.S"!:("5S+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"B,L(&9U>GIY
M"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B<VUS,F5M86EL('IA('!O
M=;YI=.T@2%144"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4P
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0U"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E=A;&QI<R!A;F0@
M1G5T=6YA(@IM<V=S='(@(E=A;&QI<R!A;F0@1G5T=6YA(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S
M+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H
M<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG
M(@IM<V=S='(@(E5P;WIO<F[L;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")3="(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.0IM<V=I9"`B5V5A
M=&AE<B!&;W)E8V%S="(*;7-G<W1R(")0^&5D<&]V[.\@<&_H87/M(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(D1A=&$@;R!P;^AA<^T@<&]S
M:WET=6IE(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR"FUS9VED
M(")796%T:&5R+F-O;2(*;7-G<W1R(")796%T:&5R+F-O;2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B5V5B(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S-PIM<V=I9"`B5V5B(%-I
M=&4B"FUS9W-T<B`B5V5B('-E<G9E<B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R
M(")4_61N["(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS
M9VED(")796QC;VUE(@IM<V=S='(@(E;M=&5J=&4B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R
M(")6[71E:G1E('8@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H
M<#HR.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5V5L8V]M92P@)7,B"FUS9W-T<B`B5NUT96IT92P@)7,B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,2DB"FUS9W-T<B`B6N%P861N[2`H25-/+3@X-3DM,2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,34I(@IM<V=S='(@(EKA<&%D;NT@*$E33RTX.#4Y+3$U*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR-#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<Q"FUS9VED(")797-T97)N(%-A:&%R82(*;7-G<W1R("):X7!A9&[M
M(%-A:&%R82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\B"FUS9W-T<B`B2W1E<F]U(&%P;&EK86-I(&WA
M("5S('IO8G)A>FET('!O('#X:6ALX;EE;NT@9&\@<WES=.EM=3\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-`IM<V=I9"`B5VAA="!I<R!T
M:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B2F%K_2!J92!O9&3L
M;&]V86/M('IN86L_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z
M,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T
M<B`B2F%K_2!J92!Z;F%K('!R;R!C:71A8VD_(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C$*(RP@9G5Z>GD*;7-G:60@
M(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")!=7-T<N%L:64B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G:60@(E=H:6-H('!H87-E<R(*
M;7-G<W1R(")+=&5RZ2!FX7IE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2
M:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")6;VQB82!R;WJY[?AE;NT@<')O
M(%)I8V@@5&5X="!E9&ET;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T
M<B`BJ>WX:V$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(U"FUS
M9VED(")7:61T:"!I;B!#4U,@=6YI=',B"FUS9W-T<B`BJ>WX:V$@=B!#4U,@
M:F5D;F]T:^%C:"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE
M(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@
M(JGM^&MA("5S(&UE;G4@=FQE=F\@*'IM[&YA('-E(&]B:F5V[2!P^&D@9&%L
MN>UM('#X:6ALX;EE;NTI.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B
M"FUS9W-T<B`BJ>WX:V$@=&%B=6QK>2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM
M<V=S='(@(DIE9&YO=&MA(+GM^&MY(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R
M("*I[?AK83HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$S"FUS
M9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S`P(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8U"FUS9VED(")7:6YD(@IM<V=S='(@(E;M='(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN
M9"!%87)L>2(*;7-G<W1R(")286YN[2!V[71R(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HX,`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G<W1R
M(")2>6-H;&]S="!V['1R=2!V('5Z;&5C:"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,34V"FUS9VED(")7:6YD.B(*;7-G<W1R(")6[71R.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R(")6[71R.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R(")-;W5D<F]S="(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.38*(RP@9G5Z>GD*;7-G:60@(E=I<VAL:7-T
M(@IM<V=S='(@(E-E>FYA;2!P^.%N[2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R(")0<N%C92(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V-`IM<V=I9"`B5V]R
M:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S82!D;R!Z86WL<W1NX6[M(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I
M9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N(&1O('IA;>QS=&[A;NTB
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HS,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D
M:6YG(&$@5D93(&9I;&4N(@IM<V=S='(@(E9Y='9O^&5N[2!61E,@<V]U8F]R
M=2!N96)Y;&\@<&]V;VQE;F\N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T,PIM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P.78S
M($)A<VEC($-O;G-T<F%I;G1S(@IM<V=S='(@(E@U,#EV,R!ZX6ML861N[2!O
M;65Z96[M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B"FUS9W-T<B`B
M6#4P.78S(')O>KGM^&5NZ2!P;W6^:73M(&ML[>AE(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J
M96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(&%L=&5R;F%T
M:79N[2!J;>EN;R!O<V]B>2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DU"FUS9VED(")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I
M9FEE<B(*;7-G<W1R(")8-3`Y=C,@:61E;G1I9FEKX71O<B!K;.WH92(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8
M-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@<F]ZN>WX96[M(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9(@IM<V=S='(@(E)2
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q
M,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4U
M"FUS9VED(")965E9(@IM<V=S='(@(E)24E(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H;V\A(&UA
M<"(*;7-G<W1R(")-87!A(%EA:&]O(2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N
M86YC92]-86EN=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R
M(")2;^AN["(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM<V=S='(@
M(DIE;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(D%N;R(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED(")997,L
M($D@06=R964B"FUS9W-T<B`B06YO+"!S;W5H;&%S[6TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS9VED(")9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HB2G-T92!V(%1%6%1/
M5LE-($W31%4N(%!O=;YI:G1E(%L\/ET@=&QAZ.UT:V$@:R!Z<.QT;NEM=2!P
M^&5P;G5T[2!D;R!765-)5UE'+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET
M+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W4@87)E(&YO="!A;&QO
M=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T,3$*;7-G:60@(EEO
M=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(DYE8GEL:2!J<W1E
M('-P<N%V;NP@;W;L^&5N:2XB"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E
M;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<
M)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(EIN86L@
M)UQ<)R!N96WYOF4@8OUT('-O=>CA<W3M(%9AN65H;R!J;>EN82XB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@
M96UA:6P@861D<F5S<RXB"FUS9W-T<B`B0GEL82!Z863A;F$@;F5P;&%T;N$@
M92UM86EL;W;A(&%D<F5S82XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H
M<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB3F5M87!O
M=F%L:2!J<W1E(+[A9&[A('!O;&4@>B!I;7!O<G1O=F%NZ6AO('-O=6)O<G4@
M:R!O9'!O=NUD86KM8^UM('!O;.UM('8@)2(*(G,N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9;W4@:&%V92!B965N(&QO9V=E
M9"!O=70N(@IM<V=S='(@(D)Y;&D@:G-T92!O9&ALX;EE;FD@>F4@<WES=.EM
M=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8Q"FUS9VED("(B
M"B)9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L
M(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG("(*(F9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"XB"FUS9W-T<B`B(@HB5FQO
MOG1E(.CM<VQO(&UO8FEL;NUH;R!T96QE9F]N=2P@<&]UOFEJ=&4@:F5N(.CM
M<VQI8R!N96)O('#X[7!A9&[L("<K)R!P<F\@(@HB;65Z:6[A<F]D;NT@Z&ES
M;&$N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X.`IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B375S
M[71E('IA9&%T('!L871N;W4@:&]D;F]T=2XB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N(@IM<V=S='(@
M(B(*(DUU<^UT92!K;VYF:6=U<F]V870@9&%T86+A>FD@9&%T+"!P;VMU9"!S
M:2!P^&5J971E('!O=;[M=F%T(%)E9VES=')A8V4N(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M=7-T(&-O;F9I9W5R
M92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")-=7/M=&4@:V]N9FEG=7)O=F%T
M(%9&4R!B86-K96YD+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN
M:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B
M969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="XB"FUS9W-T
M<B`B375S[71E(&YE:F3X[79E('!O<'-A="!P<F]B;.EM(&$@<&]TZ2!H;R!O
M9&5S;&%T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3@*;7-G:60@(EEO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;R(*;7-G<W1R(")-=7/M=&4@>F%D870@55),
M(&YA(&MT97+I(&)U9&4@=&5N=&\@;V1K87H@=6MA>F]V870B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L
M96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+B(*;7-G<W1R(")-=7/M=&4@
M=GEB<F%T('-E<G9E<BP@:W1E<OT@8G5D92!S;6%ZX6XN(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")-=7/M=&4@=GEB<F%T('6^:79A
M=&5L<VOI(&IMZ6YO+"!K=&5RZ2!B=61E('-M87KA;F\N(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+B(*;7-G<W1R(")-=7/M=&4@>F%D870@=;YI=F%T96QS
M:^D@:FWI;F\L(&MT97+I(&)U9&4@;V1S=')A;NQN;RXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C@*
M;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"XB
M"FUS9W-T<B`B3F5U=F5D;&D@:G-T92!UOFEV871E;'-KZ2!J;>EN;RP@:W1E
M<ND@8G5D92!P^&EDX6YO+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R(").975V961L:2!J<W1E('6^:79A=&5L<VOI(&IMZ6YO('!R;R!A
M:W1U86QI>F%C:2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M>FEP+G!H<#HQ,S@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I
M;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`B375S[71E('IA9&%T(&%K8VDL(&MT
M97+A(&)U9&4@<')O=F5D96YA+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E
M(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(DUU<^UT92!Z861A="!J
M;>EN;R!N;W;I(&MA=&5G;W)I92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW,PIM<V=I9"`B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN(@IM<V=S='(@(E9AN64@)7,@<F5L86-E(&)Y;&$@=6MO
M;NAE;F$N($]P['0@<V4@</AI:&QAN71E+"!P<F]S[6TN(@H*(SH@=&5M<&QA
M=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO=7(@16UA:6P@
M061D<F5S<R(*;7-G<W1R(")68;EE(&5M86EL;W;A(&%D<F5S82(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G:60@(EEO=7(@1G)O;3H@861D
M<F5S<SHB"FUS9W-T<B`B5F&Y92!/9"UK;VAO.B!A9')E<V$Z(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW
M-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R;6%T:6]N(@IM<V=S='(@(E9A
MN64@:6YF;W)M86-E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S
M<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@HB5B!R96QA8VD@)7,@<V4@>FWL
M;FEL82!68;EE(&EN=&5R;F5T;W;A(&%D<F5S82X@6B!B97IP9>AN;W-T;NUC
M:"!D^79O9/D@<V4@(@HB;75S[71E(&]P['0@</AI:&SA<VET+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA
M;64B"FUS9W-T<B`B5F&Y92!J;>EN;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VYO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E
M<G,N($EF('EO=2!W:7-H('1O("(*(G5S92!(;W)D92!T;R!A9&UI;FES=&5R
M('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A
M=71H96YT:6-A=&EO;B!B86-K96YD+B(*;7-G<W1R("(B"B)6X;D@;W;L^&]V
M86/M('-Y<W3I;2!N97!O9'!O<G5J92!P^&EDX7;A;NT@=;YI=F%T96SY(&%N
M96)O('1A=&\@;6^^;F]S="!N96[M("(*(G#X[7-T=7!NX2!Z(&II;OUC:"!D
M^79O9/DN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHU
M"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92`B"B)H
M87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S
M='(@(B(*(E;AN2!O=NSX;W9A8^T@<WES=.EM(&YE<&]D<&]R=6IE(';]<&ES
M('6^:79A=&5L^2!A;F5B;R!T871O(&UOOFYO<W0@;F5N[2`B"B)P^.US='5P
M;N$@>B!J:6[]8V@@9/EV;V3Y+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E8W0@>6]U<B!S96-U<FET
M>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*(EIDX2!S92P@
MOF4@=B!P<OEB[&AU(')E;&%C92`E<R!S92!Z;>QN:6P@5N&Y('!R;VAL[;YE
MZ"X@6B!B97IP9>AN;W-T;NUC:"`B"B)D^79O9/D@<V4@;75S[71E(&]P['0@
M</AI:&SA<VET+B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C4P"FUS9VED
M(")9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M(@IM<V=S='(@(E;AN2!P<F]H;.V^9>@@;F5P;V1P;W)U:F4@='5T;R!M;[YN
M;W-T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"B,L
M(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@
M4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5N&Y('!R;VAL[;YEZ"!N975M
M;[[R=6IE('1I<VL@=.UM=&\@>G#Y<V]B96TN(%!R;W9E9&5N[6T@<W1I<VMN
M=73M($-T<FPO(@HB3W!T:6]N("L@4"!S<'5S=.UT92!T:7-K+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z(@IM<V=S='(@(E9AN64@<V]UZ&%S;ND@Z&%S;W;I('#A<VUO
M.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N(@IM<V=S
M='(@(E9AN64@:6UP;&EC:71N[2!I9&5N=&ET82(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ-3@*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>3HB
M"FUS9W-T<B`B5F&Y92!I;7!L:6-I=&[M(&ED96YT:71A(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM
M<V=S='(@(E9AN64@^G!L;ND@:FWI;F\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"YP:'`Z,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@
M97AP:7)E9"XB"FUS9W-T<B`B5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI
M>F]VX6YO+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L
M('!H<"UF;W)M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I
M<SH@)7,B"FUS9W-T<B`B5F&Y92!N;W;I(&AE<VQO('!R;R`E<R!J93H@)7,B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B
M66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I
M;VX@;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")68;EE(&YA<W1A=F5N[2!B
M>6QO(&%K='5A;&EZ;W;A;F\@<')O('1R=N%N[2!TZ71O(')E;&%C92XB"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R(")68;EE(&YA
M<W1A=F5N[2!B>6QO(&%K='5A;&EZ;W;A;F\N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B5F&Y92!H97-L;R!B>6QO(')E<V5T;W;A;F\N
M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*;7-G:60@(B(*
M(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA
M:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W;W)D+B(*;7-G
M<W1R("(B"B)68;EE(&AE<VQO(&)Y;&\@<F5S971O=N%N;RP@>FMO;G1R;VQU
M:G1E('-I('IP<N%V>2!E;&5K=')O;FEC:^D@<&^Y='D@82`B"B)P^&EH;&&Y
M=&4@<V4@<R!68;GM;2!N;W;];2!H97-L96TN(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"YP:'`Z-S,R"B,L(&9U>GIY"FUS9VED(")9;W5R('!A<W-W;W)D
M(&AA<R!E>'!I<F5D+B(*;7-G<W1R(")68;EE(&AE<VQO(&)Y;&\@<F5S971O
M=N%N;RXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-3@*;7-G
M:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(E9AN64@=GIDX6QE
M;ND@<V5R=F5R>3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U
M-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O
M<VQA=FEA(@IM<V=S='(@(DIU9V]S;.%V:64B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EIA;6)I
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII
M;6)A8G9E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED("):
M:7!P>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E
M<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E(%%U
M;W1E9"!497AT72(*;7-G<W1R(");56MR_70@8VET;W9A;OT@=&5X=%TB"@HC
M.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P
M;W)T72(*;7-G<W1R(");2&SAN65N[2!P<F]B;.EM=5TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I9"`B6U-H;W<@
M475O=&5D(%1E>'0@+2(*;7-G<W1R(");6F]B<F%Z:70@8VET;W9A;OT@=&5X
M="`M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG
M:'1Q=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1
M=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");6F]B<F%Z:70@8VET
M;W9A;OT@=&5X="`M("5S(/CA9&OY72(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DS"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F
M("5S72(*;7-G<W1R(");^.%D96L@)7,@>B`E<UTB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN
M8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(E]!9&UI;FES
M=')A8V4B"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(E]$871A5')E92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7U-M87IA="#XX61E:R(*"B,Z(&QI8B]A<&DN<&AP.C$S
M,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?4VMU<&EN>2(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](96QP(@IM
M<V=S='(@(E].X7!O=NQD82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R;W!E
M<G1I97,N+BXB"FUS9W-T<B`B7U9L87-T;F]S=&D@;V)RX7IK=2XN+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ.30*;7-G:60@(E],
M;V<@:6XB"FUS9W-T<B`B7U#X:6ALX;EE;NTB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*;7-G<W1R
M(")?3V1H;.&Y96[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`B7TUO9&EF:6MO=F%T(&]D:V%Z+BXN(@H*(SH@9G)A;65W;W)K
M+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS
M9W-T<B`B7TUOOFYO<W1I(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!RX79A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7T]D<W1R86YI="!O9&MA>BXN+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E].
M87-T879E;NTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN
M(@IM<V=S='(@(E]6;&%S=&YO<W1I('1A8G5L:WDN+BXB"@HC.B!L:6(O87!I
M+G!H<#HQ,CD*;7-G:60@(E]5<V5R<R(*;7-G<W1R(")?5;YI=F%T96SI(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C$*;7-G:60@(F%D9')E
M<W,@8F]O:R(*;7-G<W1R(")A9')E<^'X(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W-E
M92!U;FMN;W=N(@IM<V=S='(@(F%D<F5SX?@B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.CDQ,PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L
M96YDX?@B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T"FUS9VED(")C86QM(@IM<V=S
M='(@(F)E>G;L=/CM(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-3@*;7-G:60@(F-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S`*;7-G:60@(F-A;FYO="!O<&5N(&EN<'5T(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C4Y,@IM<V=I9"`B8VQI
M8VL@:&5R92(*;7-G<W1R(")K;&EK;F]U="!Z9&4B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$R,@IM<V=I9"`B8V]M;6%N9"!L:6YE
M('5S86=E(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<X"B,L(&9U>GIY"FUS9VED(")C;VYF:6=U<F%T
M:6]N(&5R<F]R(@IM<V=S='(@(E)O>F3M;'D@=B!N87-T879E;NTB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B8W)I
M=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T82!F
M;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO="!F
M;W5N9"(*;7-G<W1R(")N96YA;&5Z96YO(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*;7-G:60@(F9A;&QI;F<B"FUS9W-T
M<B`B<W+AOFMY(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z
M.#4U"FUS9VED(")F:6QE(@IM<V=S='(@(G-O=6)O<B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C:R]M971A<BYP:'`Z,S8P(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,S@V"B,L('!H<"UF;W)M870*;7-G:60@(F9R;VT@
M=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B>B`E<R`H)7,I(')Y8VAL
M;W-T[2`E<R`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-3`*(RP@9G5Z>GD*;7-G:60@(F=U<W1I;F<B"FUS9W-T<B`B+"!NX7)A>F]V
M_2`E<R`E<R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR-#D*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.`IM<V=I9"`B:&@B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ
M,S@*;7-G:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38U"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R
M,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(F]K86V^:73L(@H*(SH@861M
M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*
M;7-G:60@(FEN;&EN92(*;7-G<W1R(")V(/AA9.PB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T
M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,PIM<V=I9"`B;&EN97-=(@IM<V=S='(@(OCA9&OY72(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@
M=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T<B`B8VAY8F]V_2!K\V0@;6MI<V]F
M<R`E9"!P^&D@=GET=N'X96[M($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED(")M;2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(Y,2!S97)V:6-E
M<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS9W-T<B`B:FWI;F\B"@HC
M.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED(")N;W0@:6UP;&5M
M96YT960B"FUS9W-T<B`B;F5N[2!I;7!L96UE;G1O=N%N;R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,3(Q.0IM<V=I9"`B;F]T('EE
M="!I;7!L96UE;G1E9"(*;7-G<W1R(")N96[M(&1O<W5D(&EM<&QE;65N=&]V
MX6YO(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4*;7-G:60@
M(FYO=&5P860B"FUS9W-T<B`B>N%P:7-N[6LB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C
M96YT(@IM<V=S='(@(G!R;V-E;G0B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I9"`B<&5R;6ES<VEO;B!D
M96YI960B"FUS9W-T<B`B4'+A=F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS
M9W-T<B`B<&EX96SY(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,PIM<V=I9"`B<FES:6YG(@IM<V=S='(@(G-T;W5P86KM8^TB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T,@HC+"!F=7IZ>0IM
M<V=I9"`B<V5R=FEC92!U;F%V86EL86)L92(*;7-G<W1R(")";&]K(&\@<&_H
M87/M(&YE;NT@9&]S='5P;OTN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H
M<#HY.0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")Z;V)R87II
M="!R;WID[6QY(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,30*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G
M<W1R(")S;7,R96UA:6P@>F$@<&]UOFET[2!(5%10(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-S(*;7-G:60@(G-T96%D>2(*;7-G<W1R(")V>71R=F%LZ2(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S`Y"FUS9VED(")S=VET8V@@;V9F
M(&IA=F%S8W)I<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O<B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0IM<V=I9"`B
M=&%S:R!L:7-T(@IM<V=S='(@(G-E>FYA;2#Z:V]L^2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@
M9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(DMA
MOF3I('#X:6ALX;EE;NT@9&\@<WES=.EM=2(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@
M(G1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B
M<')O('!O='9R>F5N[2!N87!IN71E(&AE<VQO(&1V86MRX70B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM
M<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")S:F5D;F]C96[](@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]087)T+G!H<#HR-PIM<V=I9"`B=6YN86UE9"(*;7-G
M<W1R(")B97H@;N%Z=G4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T(@IM
M<V=S='(@(G9Y8G)A="!UOFEV871E;&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@
M(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T,0IM<V=I9"`B=SHB"FUS9W-T<B`B=SHB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE<BYC;VTB"FUS9W-T
M<B`B=V5A=&AE<BYC;VTB"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]P=%]"4BYP;P``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`W,S,W
M,S4@,3`U,34T,S0Q-#(@,#$W-30P`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````",@=')A;G-L871I;VX@;V8@:&]R9&4N<&\@
M=&\@0G)A>FEL:6%N(%!O<G1U9W5E<V4*(R!#;W!Y<FEG:'0@*$,I(%E%05(@
M2&]R9&4@4')O:F5C=`HC(%1H:7,@9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E
M<B!T:&4@<V%M92!L:6-E;G-E(&%S('1H92!(;W)D92!P86-K86=E+@HC"B,@
M1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R/BP@,C`P-BX*;7-G:60@
M(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E7&XB"B)2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB
M4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,%QN(@HB
M4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP,BTQ-2`Q-CHU,"TP,C`P7&XB"B),
M87-T+51R86YS;&%T;W(Z($9A8FEO($=O;65S(#QF;&=O;7-`=6]L+F-O;2YB
M<CY<;B(*(DQA;F=U86=E+51E86TZ($)R87II;&EA;B!0;W)T=6=U97-E(#QI
M,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB6"U'
M96YE<F%T;W(Z($M"86)E;"`Q+C,N,5QN(@HB4&QU<F%L+49O<FUS.B`@;G!L
M=7)A;',],CL@<&QU<F%L/2AN(#X@,2D[7&XB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,S<S"B,L('!H<"UF;W)M870*;7-G:60@(B`H)7,@9&%Y
M<R!A9V\I(@IM<V=S='(@(B`H)7,@9&EA<R!A='+A<RDB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H5&5C;&$@9&4@071A;&AO("5S
M*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@*&5M("5S(&1I
M87,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PIM<V=I9"`B
M("AT;V1A>2DB"FUS9W-T<B`B("AH;VIE*2(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(S-SD*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`H
M86UA;FCC*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G
M:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&]N=&5M*2(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#4@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,U,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,SDV"FUS9VED("(@870@(@IM<V=S='(@(B!A("(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!I<R!N;W0@82!D:7)E8W1O<GDN(@IM<V=S='(@(EPB)7-<(B!.XV\@Z2!U
M;2!D:7)E=/-R:6\N(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(W,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L:60@8VAO
M:6-E+B(*;7-G<W1R("(G)7,G(&[C;R#I('5M82!E<V-O;&AA(';A;&ED82XB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$P.3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES(&YO="!C;VYF:6=U<F5D(&EN
M('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S)R!NXV\@97-TX2!C
M;VYF:6=U<F%D;R!N;R!296=I<W1R;R!D;R!(;W)D92XB"@HC.B!F<F%M97=O
M<FLO5')E92]4<F5E+G!H<#HQ-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E
M<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R(")R96YD97)I
M>F%D;W(@9&4@X7)V;W)E(%PB)7-<(B!NXV\@96YC;VYT<F%D;RXB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C4V"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<
M(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM<V=S='(@(EPB
M)7-<(B!F;VD@861I8VEO;F%D;R!A;R!S:7-T96UA(&1E(&=R=7!O<RXB"@HC
M.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES
M=&5M+B(*;7-G<W1R(")<(B5S7"(@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M
M82!D92!P97)M:7-S]65S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4P"B,L('!H<"UF;W)M870*;7-G:60@
M(EPB)7-<(B!W87,@;F]T(&-R96%T960Z("5S+B(*;7-G<W1R(")<(B<E<UPB
M(&[C;R!F;VD@8W)I861O.B`E<RXB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP
M:'`Z-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR
M9DU"(&%L;&]W960@*"4N,F8E)2DB"FUS9W-T<B`B)2XR9DU"('5S861O<R!D
M924N,F9-0B!P97)M:71I9&]S("@E+C)F)24I(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(R-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E
M<R!A;F0@)7,B"FUS9W-T<B`B)60@)7,@92`E<R(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&1A<"YP:'`Z,C8X(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HU
M-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N(@IM<V=S='(@(B5D(&1I87,@873I('-U82!S96YH
M82!E>'!I<F%R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S
M='(@(B5D('!R979I<^-O(&1O(&1I82(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HV.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R`M($YO=&EC92(*
M;7-G<W1R("(E<R`M($%V:7-O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R
M<')I;G0B"FUS9W-T<B`B26UP<F5S<^-O($1I9VET86P@9&4@)7,B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#`@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0R"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S($M"(@IM<V=S='(@(B5S($M"(@H*(SH@<V5R=FEC97,O;6%I;G1E
M;F%N8V4N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA
M;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@3W!E
M<F'G]65S(&1E($UA;G5T96[GXV\@+2!#;VYF:7)M8>?C;R(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q
M-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R(")#;VYF
M:6=U<F'GXV\@9&4@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS
M9W-T<B`B0V%D87-T<F\@9&4@)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R
M965M96YT(@IM<V=S='(@(B5S(%1E<FUO<R!D;R!!8V]R9&\B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0S,B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C0Y-`HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X,B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<U,`HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!A;')E861Y(&5X:7-T<RXB"FUS9W-T<B`B)7,@:N$@97AI<W1E
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&$@)7,@
M)7,B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-#@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I
M;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@
M(@HB8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R("(B"B(E<R!E<W3A('!R;VYT;R!P
M87)A(&5X96-U=&%R(&%S(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&UA<F-A
M9&%S(&%B86EX;RX@(@HB36%R<75E(&$@8V%I>&$@<&%R82!Q=6%L<75E<B!O
M<&5R8>?C;R!Q=64@=F]CZB!Q=65I<F$@97AE8W5T87(@9&5S=&$@=F5Z+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@Z2!O8G)I9V%T
M\W)I;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDS"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@;6EN=71O<R(*"B,Z
M(&9R86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("(E<R!N
MXV\@96YC;VYT<F%D;RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F("5S(@IM
M<V=S='(@(B5S(&$@)7,@9&4@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")#873A;&]G;R!D92!%;F1E<F7G;W,@9&4@)7,B"@HC
M.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(D%G96YD82!D92`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")!;F]T8>?U97,@9&4@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM<V=S='(@(DQI<W1A(&1E
M(%1A<F5F87,@9&4@)7,B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.CDV"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C$*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@(@HB
M86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I
M=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R("(B"B(E<SH@
M17-T82!M96YS86=E;2!P;V1E(&[C;R!S97(@9&4@<75E;2!E;&$@9&EZ('-E
M<BX@5&]M92!C=6ED861O(&-O;2`B"B)Q=6%L<75E<B!L:6YK('!R97-E;G1E
M(&YE;&$@;W4@96T@9F]R;F5C97(@86\@<F5M971E;G1E('%U86QQ=65R(&EN
M9F]R;6'GXV\@(@HB<&5S<V]A;"XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.3D*
M;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!B<FES82`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N<&AP.C(P,`HC
M+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B
M+"!B<FES82`E<R`E<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`X"B,L
M('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*
M;7-G<W1R("(L('9A<FGA=F5L(&1E("5S('!A<F$@)7,B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<S
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,S(*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<T-@IM<V=I9"`B+2T@<V5L96-T
M("TM(@IM<V=S='(@(BTM('-E;&5C:6]N92`M+2(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R
M;6%T;R`Q,B!(;W)A<R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I
M9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B1F]R;6%T;R`R-"!(;W)A<R(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R
M<R(*;7-G<W1R("(R-"!H;W)A<R(*"B,Z(&9R86UE=V]R:R]522]522]086=E
M<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\4.%G:6YA($%N
M=&5R:6]R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C8*;7-G:60@(D$@
M9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB
M"FUS9W-T<B`B56T@8V]N96-T;W(@9&4@8F%N8V\@9&4@9&%D;W,@Z2!O8G)I
M9V%T\W)I;R!P87)A(&5S=&4@8FQO8V\N(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R
M<F5D(@IM<V=S='(@(E5M(&5R<F\@9F%T86P@;V-O<G)E=2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS-0IM<V=I9"`B02!P=6)L:6,@
M4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB"FUS
M9W-T<B`B56UA(&-H879E('#Z8FQI8V$@4$=0(.D@;V)R:6=A=/-R:6$@<&%R
M82!C<FEP=&]G<F%F87(@=6UA(&UE;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C$Q-C@*;7-G:60@(D$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N(@IM
M<V=S='(@(B(*(E5M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B<FEG873S<FEA
M('!A<F$@=F5R:69I8V%R('5M82!M96YS86=E;2!A<W-I;F%D82XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS
M9W-T<B`B(@HB56UA(&-H879E('!R:79A9&$@4$=0(&4@=6UA('-E;FAA('/C
M;R!O8G)I9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@=6UA("(*(FUE
M;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M,38*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B)5;6$@8VAA=F4@<')I=F%D82!01U`@92!U
M;6$@<V5N:&$@<^-O(&]B<FEG873S<FEA<R!P87)A(&%S<VEN87(@=6UA(&UE
M;G-A9V5M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3`V"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D
M96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B(@HB56UA(&-H879E('#Z8FQI
M8V$@4R]-24U%+"!U;6$@8VAA=F4@<')I=F%D82!3+TU)344@92!U;6$@<V5N
M:&$@<^-O("(*(F]B<FEG873S<FEA<R!P87)A(&1E<V-R:7!T;V=R869A<B!U
M;6$@;65N<V%G96TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A
M=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)5;6$@8VAA=F4@</IB
M;&EC82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!S
M96YH82!SXV\@(@HB;V)R:6=A=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@;65N
M<V%G96TN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS
M-C0*;7-G:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B56UA(&-H879E('#Z8FQI8V$@
M4R]-24U%(.D@;V)R:6=A=/-R:6$@<&%R82!C<FEP=&]G<F%F87(@=6UA(&UE
M;G-A9V5M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(").=79E;G,@;6%T=71I
M;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3`*;7-G:60@(D%-($QI9VAT(%)A:6XB"FUS9W-T<B`B0VAU=F$@1G)A8V$@
M5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C$Q"FUS9VED(")!32!286EN(@IM<V=S='(@(D-H=79A(&UA='5T
M:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B0VAU=F%S(&UA='5T:6YA
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$S
M"FUS9VED(")!32!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B3F5V87-C87,@36%T
M=71I;F%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*;7-G:60@
M(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS
M9W-T<B`B05!)($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T
M<B`B4V]B<F4@97-T92!E9&ET;W(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B4V]B<F4N+BXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS
M9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B06)S8F]T=&]M(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S
M;6ED9&QE(@IM<V=S='(@(D%B<VUI9&1L92(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR-S`*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B06-E<W-O(&YE9V%D;R!A;R!C
M<FEA<B!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ,S8*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&9I;&4N(@IM<V=S='(@(D%C97-S;R!N96=A9&\@86\@8W)I87(@87)Q=6EV
M;R!61E,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C,*;7-G:60@(D%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B4W5A<R!);F9O<FUAY_5E<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.`IM<V=I9"`B06-C;W5N="!0
M87-S=V]R9"(*;7-G<W1R(")396YH82!D82!#;VYT82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I9"`B
M06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(D-O;G1A(&1E<V%T:79A9&$N(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-0IM<V=I9"`B06-C;W5N
M=&EN9R(*;7-G<W1R(")#;VYT87,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@
M(D%D9"(*;7-G<W1R(")!9&EC:6]N87(B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I9"`B061D($-H:6QD($=R
M;W5P(@IM<V=S='(@(D%D:6-I;VYA<B!'<G5P;R!3=6)O<F1I;F%D;R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3@@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B061I8VEO;F%R(%!E<FUI<W/U97,@4W5B;W)D:6YA9&%S
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(
M97)E.B(*;7-G<W1R(")!9&EC:6]N92!!<75I.B(*"B,Z(&%D;6EN+V=R;W5P
M<RYP:'`Z,C$X(&%D;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W
M($=R;W5P(@IM<V=S='(@(D%D:6-I;VYA<B!.;W9O($=R=7!O(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS
M9W-T<B`B061I8VEO;F%R($YO=F$@4&5R;6ES<^-O(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z-PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R!<(B5S7"(B"FUS9W-T<B`B061I
M8VEO;F%R('5M(&=R=7!O('-U8F]R9&EN861O(&$@)R5S)R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L('!H<"UF;W)M870*;7-G
M:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@7"(E<UPB(@IM<V=S='(@
M(D%D:6-I;VYA<B!U;6$@<&5R;6ES<^-O('-U8F]R9&EN861A(&$@)R5S)R(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB
M"FUS9W-T<B`B061I8VEO;F%R('5M(&YO=F\@=7-UX7)I;SHB"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34T"FUS9VED(")!
M9&0@8V]L=6UN(@IM<V=S='(@(D%D:6-I;VYA<B!C;VQU;F$B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C,T"FUS9VED(")!9&0@;F5W
M(&UE;6)E<G,B"FUS9W-T<B`B061I8VEO;F%R(&YO=F]S(&UE;6)R;W,B"@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I
M<B(*;7-G<W1R(")!9&EC:6]N87(@<&%R(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`B061I8VEO;F%R(&\@
M365N=2`E<R!C;VUO('5M82!"87)R82!,871E<F%L(&1O($UO>FEL;&$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G
M:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S='(@(D%D:6-I;VYA<B!A
M;R!C873A;&]G;R!D92!E;F1E<F7G;W,Z(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS9VED(")!9&0@=&\@;7D@861D
M<F5S<R!B;V]K(@IM<V=S='(@(D%D:6-I;VYA<B!A;R!M974@8V%TX6QO9V\@
M9&4@96YD97)EYV]S(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D
M9"!U<V5R(@IM<V=S='(@(D%D:6-I;VYA<B!U<W7A<FEO(@H*(SH@861M:6XO
M=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB061D960@7"(E
M<UPB('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N
M86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`B"B(E<RXB"FUS9W-T<B`B(@HB)R5S
M)R!A9&EC:6]N861O(&%O('-I<W1E;6$L(&UA<R!NXV\@<'5D92!I;F-L=6ER
M(&EN9F]R;6'G]65S(&%D:6-I;VYA:7,@9&\@(@HB8V%D87-T<F\Z("5S+B(*
M"B,Z('-I9VYU<"YP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@
M7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RXB"FUS
M9W-T<B`B)7,@861I8VEO;F%D;R!A;R!S:7-T96UA+B!6;V/J('!O9&4@<V4@
M8V]N96-T87(@86=O<F$N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C(*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B061IY^-O(&1E('5S=>%R:6]S(&5S=.$@9&5S86)I;&ET861A+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$W,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0U"FUS9VED(")!9&1R97-S(@IM
M<V=S='(@(D5N9&5R9>=O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$T,0IM<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D-A=.%L;V=O(&1E
M($5N9&5R9>=O<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS
M(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A<B`M(&-O;F9I
M9W5R82!P97)M:7-S]65S('!A<F$@;W5T<F]S('5S=>%R:6]S(@H*(SH@861M
M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ
M,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'G
MXV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0S"FUS9VED(")!
M9',B"FUS9W-T<B`B06[Z;F-I;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H
M86YI<W1A;B(*;7-G<W1R(")!9F5G86YI<W3C;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3<*;7-G
M:60@(D%L8F%N:6$B"FUS9W-T<B`B06QBXFYI82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G
M:60@(D%L9V5R:6$B"FUS9W-T<B`B07)GZ7)I82(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#<*;7-G:60@(D%L:6%S(@IM
M<V=S='(@(D%P96QI9&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R(")!
M;&EN:&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV-PIM<V=I9"`B06QI9VYM96YT.B(*;7-G<W1R(")!;&EN:&%M96YT
M;SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*
M;7-G<W1R(")4;V1O<R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,C`W('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L
M;"!!=71H96YT:6-A=&5D(%5S97)S(@IM<V=S='(@(E1O9&]S(%5S=>%R:6]S
M($%U=&5N=&EC861O<R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO
M9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B5&]D
M;W,@1W)U<&]S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"FUS9VED
M(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B5&]D87,@4&5R;6ES<_5E<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM<V=S='(@(E1O9&]S('%U
M871R;R!L861O<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S4*
M;7-G:60@(D%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<R(*;7-G<W1R(")097)M
M:71I<B!M^FQT:7!L;W,@96YD97)EYV]S(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C4S.`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI
M<W0@='EP93\B"FUS9W-T<B`B4&5R;6ET:7(@8V]N9FEG=7)A<B!O('1I<&\@
M9&4@;&ES=&%S(&]R9&5N861A<S\B"@HC.B!F<F%M97=O<FLO1&%T851R964O
M1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM
M<V=S='(@(DKA(&5X:7-T92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,C8*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S='(@(DQO9VEN
M($E-4U`@06QT97)N871I=F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-3$Q"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R(")3
M96YH82!)35-0($%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C4P,PIM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T
M<B`B57-UX7)I;R!)35-0($%L=&5R;F%T:79O(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R
M97-S(@IM<V=S='(@(D5N9&5R9>=O(&1E(&4M;6%I;"!A;'1E<FYA=&EV;R(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@
M=&5M<&QA=&5S(@IM<V=S='(@(DUO9&5L;W,@86QT97)N871I=F]S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B5&5X=&\@
M86QT97)N871I=F\Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06UE<FEC86X@4V%M
M;V$B"FUS9W-T<B`B4V%M;V$@06UE<FEC86YA(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C$Q-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D
M+B(*;7-G<W1R(")5;2!V86QO<B!I;&5G86P@9F]I(&5S<&5C:69I8V%D;RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34U"FUS9VED(")!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+B(*;7-G<W1R(")/8V]R<F5U
M('5M(&5R<F\@9&5S8V]N:&5C:61O+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N
M9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N
M9V]L82(*;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U
M:6QL82(*;7-G<W1R(")!;F=U:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R
M(")0<F]X>2!A;O1N:6UO(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP
M:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")297-P;W-T82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YTX7)T:61A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@0F%R8G5D82(*;7-G<W1R
M(")!;G1I9W5A(&4@0F%R8F%D;W,B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO54DN<&AP.C4X('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH
M=&UL.C8*;7-G:60@(D%P<&QI8V%T:6]N(@IM<V=S='(@(D%P;&EC8>?C;R(*
M"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I
M;VX@3&ES="(*;7-G<W1R("),:7-T82!D92!!<&QI8V'G]65S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`IM<V=I9"`B07!P;&EC871I;VX@:7,@
M<F5A9'DN(@IM<V=S='(@(D$@87!L:6-AY^-O(&5S=.$@<')O;G1A+B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T
M;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B07!L:6-A<B!A;W,@0V]M<&%R=&EL
M:&%M96YT;W,@4W5B;W)D:6YA9&]S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O87!P<F]V92YI;F,Z,C$*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B07!R
M;W9A<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T
M,`IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")486UA;FAO($%P
M<F]X:6UA9&\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHV.`IM<V=I9"`B07!R:6PB"FUS9W-T<B`B06)R:6PB"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$W-`IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R
M-38I(@IM<V=S='(@(D%RX6)I8V\@*%=I;F1O=W,M,3(U-BDB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B07)C:&EV92!&:6QE(%-I
M>F4B"FUS9W-T<B`B5&%M86YH;R!D;R!!<G%U:79O(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S<*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M(").;VUE(&1O($%R<75I=F\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$P"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_(@IM<V=S='(@(E9O8^H@=&5M(&-E<G1E>F$@<75E('%U97(@
M<F5M;W9E<B!A('-O;&EC:71AY^-O(&1E(&-A9&%S=')O(&1E("5S/R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHW"B,L('!H<"UF
M;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M7"(E<UPB(&%N9"!A;GD@<W5B+6=R;W5P<S\B"FUS9W-T<B`B5F]CZB!T96T@
M8V5R=&5Z82!Q=64@9&5S96IA(&5X8VQU:7(@)R5S)R!E('-E=7,@<W5B9W)U
M<&]S/R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R(")!
M<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!<FUE;FEA(@IM<V=S='(@
M(D%R;>IN:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W-0IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)MZFYI;R`H05)-4T-)
M22TX*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T
M(@IM<V=S='(@(D%R=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G
M<W1R(")!<G5B82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*
M;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B26QH82!!<V-E;G/C
M;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B07-C:6D@
M07)T(@IM<V=S='(@(D%R=&4@07-C:6DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS
M9W-T<B`BP7-I82]296=IXV\@9&\@4&%C[69I8V\B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#(Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B
M4V]L:6-I=&%R(&-O;F9I<FUAY^-O(&%N=&5S(&1E(&5X96-U=&%R(&%S(&]P
M97)AY_5E<R!D92!M86YU=&5NY^-O/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,#(*;7-G:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R
M(")#;VQU;F%S(&1E(&1E<VEG;F'GXV\B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"XB"FUS9W-T<B`B5&5N=&]U(&5X8VQU:7(@=6T@9W)U<&\@:6YE>&ES
M=&5N=&4N(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HR.0IM<V=I9"`B
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB
M"FUS9W-T<B`B5&5N=&]U(&5X8VQU:7(@=6UA('!E<FUI<W/C;R!NXV\@97AI
M<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C@W"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B5&5N=&]U(&5D:71A<B!U;6$@<&5R;6ES<^-O(&[C;R!E>&ES=&5N
M=&4N(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!
M='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@
M(E1E;G1O=2!E9&ET87(@=6T@8V]M<&%R=&EL:&%M96YT;R!NXV\@97AI<W1E
M;G1E+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z
M-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@S"FUS9VED(")!
M='1R:6)U=&5S(@IM<V=S='(@(D%T<FEB=71O<R(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS
M9W-T<B`B06=O<W1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B075S=')A;&EA(@IM
M<V=S='(@(D%U<W1RX6QI82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B
M"FUS9W-T<B`BP75S=')I82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M<W%L+G!H<#HQ-C@*;7-G:60@(D%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!.
MXV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED
M(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@
M8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($\@8V]N96-T;W(@
M;N-O('!O<W-U:2!A<R!C87!A8VED861E<R!N96-E<W/A<FEA<RXB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(*;7-G:60@(D%U=&A?
M8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]C>7)U<SH@3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YS
MXV\@:6UA<"!N96-E<W/A<FEA+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M9G1P+G!H<#HS-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92TB"B)F='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@3N-O
M(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@1E10(&YE8V5S<^%R:6$N($-O
M;7!I;&4@;R!02%`@8V]M(&$@(@HB;W#GXV\@+2UE;F%B;&4M9G1P+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0*;7-G:60@(D%U=&A?
M:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7VEM87`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O
M(&EM87`@;F5C97-SX7)I82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR
M8C4N<&AP.C4Q"FUS9VED(")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]K<F(U.B!.XV\@9F]I
M(&5N8V]N=')A9&$@82!E>'1E;G/C;R!K<F(U(&YE8V5S<^%R:6$N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(*;7-G:60@(D%U=&A?
M;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV
M92!$:7)E8W1O<GDB"FUS9W-T<B`B075T:%]L9&%P.B!);F-L=7/C;R!D92!U
M<W7A<FEO<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@
M(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD87`Z($5X8VQU
M<^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D82!P87)A($%C=&EV92!$
M:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C8S
M"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!.XV\@9F]I(&5N8V]N=')A
M9&$@82!E>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HS,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("(B"B)!=71H7VQD87`Z($EM
M<&]S<^UV96P@861I8VEO;F%R(&\@=7-UX7)I;R`E<RX@27-T;R!F;VD@;R!Q
M=64@;R!S97)V:61O<B`B"B)R97!O<G1O=3H@(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T
M:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T
M:%]L9&%P.B!);7!O<W/M=F5L(')E;6]V97(@;R!U<W7A<FEO("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT.3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B
M"FUS9W-T<B`B075T:%]L9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!O('5S
M=>%R:6\@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0P
M-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R("(B"B)!=71H
M7VQD87`Z($%T=6%L:7IAY^-O(&1E('5S=>%R:6]S(&[C;R#I('-U<&]R=&%D
M82!P87)A($%C=&EV92!$:7)E8W1O<GDN(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;6-A;#H@
M3N-O(&9O:2!E;F-O;G1R861A(&$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,`IM<V=I9"`B
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?<VUB875T:#H@3N-O(&9O:2!E;F-O;G1R
M861A(&$@97AT96YSXV\@<VUB875T:"!N96-E<W/A<FEA+B(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC
M871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I
M8V'GXV\@;F\@<V5R=FED;W(@24U!4"!F86QH;W4N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDP"FUS9VED(")!
M=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`B1F%L:&$@;F$@875T96YT
M:6-AY^-O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R(")&86QH82!N82!A=71E;G1I8V'G
MXV\Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W
M-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BXB"FUS9W-T<B`B075T96YT:6-AY^-O(')E:F5I=&%D82!P96QO('-E
M<G9I9&]R(%)!1$E54RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C@X,@IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL
M960N(@IM<V=S='(@(D$@875T96YT:6-AY^-O(&YO('-E<G9I9&]R($944"!F
M86QH;W4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW,`IM<V=I
M9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*
M;7-G<W1R(")!(&%U=&5N=&EC8>?C;R!N;R!S97)V:61O<B!334(@9F%L:&]U
M+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-S4*;7-G:60@(D%V
M86EL86)L92!F:65L9',Z(@IM<V=S='(@(D-A;7!O<R!D:7-P;V[M=F5I<SHB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R8F%I:F%N(@IM<V=S='(@(D%Z97)B
M86EJXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/
M1D@@17AC=7-E<R(*;7-G<W1R(")$97-C=6QP87,@9&\@0D]&2"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3@*
M;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B1G5N9&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS9VED(")"86-K
M9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O<B!D92!&=6YD;R(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#$*;7-G:60@(D)A9"!K97)B97)O
M<R!P87-S=V]R9"XB"FUS9W-T<B`B4V5N:&$@:V5R8F5R;W,@:6YC;W)R971A
M+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#,*;7-G:60@
M(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS9W-T<B`B57-UX7)I;R!K97)B
M97)O<R!I;F-O<G)E=&\N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F%H<F%I;B(*
M;7-G<W1R(")"86AR86EN(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*
M;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM,3,I(@IM<V=S='(@(D+A;'1I8V\@
M*$E33RTX.#4Y+3$S*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A;F=L861E<V@B
M"FUS9W-T<B`B0F%N9VQA9&5S:"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A
M9&]S(@IM<V=S='(@(D)A<F)A9&]S(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(D[C;R!F;VD@96YC
M;VYT<F%D;R!O(&1I<F5T\W)I;R!B87-E(&1E(&EM86=E;G,@)R5S)RXB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S='(@(DQI;FAA(&1E(%!A<G1I9&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")"96QA<G5S(@IM<V=S='(@(D)E;&]R^G-S
M:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8P"FUS9VED(")"96QG:75M(@IM<V=S='(@(D+I;&=I
M8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")"96QI>F4B"FUS9W-T<B`B0F5L:7IE
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,0IM<V=I9"`B0F5N:6XB"FUS9W-T<B`B0F5N:6XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E<FUU9&%S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)U=.-O(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Q,0IM<V=I
M9"`B0FER=&AD87DB"FUS9W-T<B`B06YI=F5R<^%R:6\B"@HC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4T"B,L('!H<"UF;W)M
M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@
M;F]T(&9O=6YD+B(*;7-G<W1R(").XV\@9F]I(&5N8V]N=')A9&\@;R!B;&]C
M;R!<(B5S7"(@9&$@87!L:6-AY^-O(%PB)7-<(BXB"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM
M<V=S='(@(D-O;F9I9W5R8>?U97,@9&\@0FQO8V\B"@HC.B!T96UP;&%T97,O
M<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G:60@(D)L;V-K(%1Y<&4B"FUS9W-T
M<B`B5&EP;R!D92!";&]C;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R(").96=R:71O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R(")";VSM=FEA
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(P-PIM<V=I9"`B0F]O
M:VUA<FMS(@IM<V=S='(@(D9A=F]R:71O<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E
M<B(*;7-G<W1R(")";W)D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.#4*;7-G:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM
M<V=S='(@(DQA<F=U<F$@9&$@8F]R9&$Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R
M<R(*;7-G<W1R(")";W)D87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@
M86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(D+S<VYI82!E($AE<GIE9V]V:6YA
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED(")";W1H(@IM
M<V=S='(@(D%M8F]S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS
M9W-T<B`B0F]T<W5A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")2
M;V1A<.DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W5V970@27-L86YD(@IM<V=S
M='(@(DEL:&$@0F]U=F5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)A>FEL(@IM
M<V=S='(@(D)R87-I;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN
M9&EA;B!/8V5A;B!497)R:71O<GDB"FUS9W-T<B`B5&5R<FET\W)I;R!D;R!/
M8V5A;F\@S6YD:6-O($EN9VSJ<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE
M:2!$87)U<W-A;&%M(@IM<V=S='(@(D)R=6YE:2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&?A<FEA(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T
M960@3&ES="(*;7-G<W1R("),:7-T82!C;VT@36%R8V%D;W)E<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)K:6YA($9A
M<V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(D)U<G5N
M9&DB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#0V"FUS9VED(")#
M35,B"FUS9W-T<B`B0TU3(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#(@IM<V=S='(@(D-20R(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")#4DP@
M1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")0;VYT;W,@9&4@1&ES=')I
M8G5IY^-O($-23"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR-PIM<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@0^E?;'5L82XN+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3$*;7-G:60@(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(@IM<V=S='(@(D$@;&ES=&$@9&4@9&ES
M=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#,@8V]N9FEG+VAO;VMS
M+G!H<"YD:7-T.CDX-PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,34W
M"FUS9VED(")#86QE;F1A<B(*;7-G<W1R(")!9V5N9&$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U"FUS9VED(")#86QM(@IM<V=S='(@
M(D-A;&UO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C@@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S='(@
M(D-A;6)O9&IA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T
M<B`B0V%M87+U97,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR
M,`IM<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY
M+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3N-O
M(.D@<&]S<^UV96P@9V5R87(@=6UA(&YO=F$@<V5N:&$@875T;VUA=&EC86UE
M;G1E+"!E;G1R92!E;2!C;VYT871O(&-O;2!O("(*(F%D;6EN:7-T<F%D;W(N
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S4P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS
M9W-T<B`B3N-O(&-O;G-I9V\@9W)A=F%R(&\@87)Q=6EV;R!<(B5S7"(B"@HC
M.B!A9&UI;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T
M97(@97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B3N-O(.D@
M<&]S<^UV96P@861M:6YI<W1R87(@9V5R96YC:6%D;W)E<R!E>'1E<FYO<R!D
M92!S97-SXV\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z
M,C,U(&9R86UE=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,B"FUS9W-T<B`B3N-O(.D@<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED
M;W(@24U!4#H@)7,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B3N-O(&-O;G-I9V\@86)R:7(@;R!A<G%U:79O(%PB)7-<
M(BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T<B`B0V%N863A
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N<&AP.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0W"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C4*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS9W-T<B`B0V%N
M8V5L87(B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM
M<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D-A;F-E;&%R
M(%)E;&%T\W)I;R!D92!0<F]B;&5M82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z,S(S"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!D96QE
M=&4@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&5X8VQU
M:7(@;R!A<G%U:79O(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P
M=713=')A=&5G>2]C;W!Y+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@Z2!P;W-S[79E;"!E
M;F-O;G1R87(@=6T@9&ER973S<FEO('1E;7!O<N%R:6\N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HY,0IM<V=I9"`B0V%N
M;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*
M;7-G<W1R(").XV\@Z2!P;W-S[79E;"!C;VYT:6YU87(@<V5M(&\@<&%RXFUE
M=')O("=T87)G971&:6QE)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(D[C;R#I('!O<W/M=F5L(&5X8VQU
M:7(@;R!D:7)E=/-R:6\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]$871A5')E
M92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R:R]$871A5')E92]$871A5')E
M92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M
M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B3N-O(.D@<&]S<^UV
M96P@97AC;'5I<BP@)60@<&]S<W5I('-U8F]R9&EN861O<RXB"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV,#@*;7-G:60@(B(*
M(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F
M;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*
M;7-G<W1R("(B"B).XV\@Z2!P;W-S[79E;"!R96]R9&5N87(L(&[Z;65R;R!D
M92!R96=I<W1R;W,@9F]R;F5C:61O<R!P87)A(')E;W)D96YA<B!NXV\@(@HB
M8V]R<F5S<&]N9&4@86\@;OIM97)O(&%R;6%Z96YA9&\N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED
M(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*
M;7-G<W1R(").XV\@Z2!P;W-S[79E;"!R;W1E87(@;65N<V%G96T@<&%R82!O
M(&[Z;65R;R!E<W!E8VEF:6-A9&\N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0V%P
M92!697)D92(*;7-G<W1R(")#86)O(%9E<F1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R(")4[71U;&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B3W!E<F%D;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDS"FUS
M9VED(")#871E9V]R:65S(&%N9"!,86)E;',B"FUS9W-T<B`B0V%T96=O<FEA
M<R!E($YO;65S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A>6UA;B!)<VQA;F1S
M(@IM<V=S='(@(DEL:&%S($-A>6UA;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS
M9W-T<B`B5&5L969O;F4@0V5L=6QA<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O
M<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@0^EL=6QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G
M:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B36%R9V5M(&1A(&/I;'5L83HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I
M961A9&5S(&1A($/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P86-I;F<Z(@IM<V=S
M='(@(D5S<&'G86UE;G1O(&1A(&/I;'5L83HB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C<X"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`B5&5L
M969O;F4@8V5L=6QA<B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS
M9VED(")#96QT:6,@*$E33RTX.#4Y+3$T*2(*;7-G<W1R(")#Z6QT:6-O("A)
M4T\M.#@U.2TQ-"DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B0V5N
M=')O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(E)E</IB;&EC82!D82#!9G)I8V$@0V5N=')A;"(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<X"FUS9VED(")#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R(")%=7)O<&$@0V5N=')A;"`H25-/
M+3@X-3DM,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,`IM<V=I9"`B0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")$971A
M;&AE<R!D;R!#97)T:69I8V%D;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C$R"FUS9VED(")#97)T:69I8V%T92!/=VYE<B(*;7-G
M<W1R(")0<F]P<FEE=.%R:6\@9&\@0V5R=&EF:6-A9&\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-PIM<V=I9"`B0V5R=&EF:6-A
M=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L[71I8V%S(&1O($-E<G1I9FEC861O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(E1C:&%D92(*
M"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR-"!T96UP;&%T97,O
M<G!C<W5M+W)P8W-U;2YI;F,Z.38*;7-G:60@(D-H86YG92(*;7-G<W1R(")!
M;'1E<F%R(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"FUS
M9VED(")#:&%N9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")!;'1E<F4@4W5A
M(%-E;FAA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8Y"FUS9VED("(B
M"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E
M('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB
M"FUS9W-T<B`B(@HB06QT97)A<B!O(&YO;64@92!O(&5N9&5R9>=O('%U92!A
M<R!P97-S;V%S(';J96T@<75A;F1O(&5L87,@;.IE;2!E(')E<W!O;F1E;2`B
M"B)S=6%S(&UE;G-A9V5N<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,C0*;7-G:60@(B(*(D-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@
M;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN
M("`B"B)#;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB
M06QT97)AY^-O(&1E('-E;FAA(&[C;R#I('-U<&]R=&%D82!N82!C;VYF:6=U
M<F'GXV\@871U86PN("!%;G1R92!E;2!C;VYT871O("(*(F-O;2!O(&%D;6EN
M:7-T<F%D;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")#:&%R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")697)I9FEC
M87(@3&EN7VLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#:&EL92(*;7-G<W1R
M(")#:&EL92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S='(@(D-H
M:6YA(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-H:6YE
M<V4@4VEM<&QI9FEE9"`H1T(R,S$R*2(*;7-G<W1R(")#:&ENZG,@4VEM<&QI
M9FEC861O("A'0C(S,3(I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#`*
M;7-G:60@(D-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I(@IM<V=S='(@(D-H
M:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2DB"@HC.B!T96UP;&%T97,O<')E9G,O
M87!P+FEN8SHW"FUS9VED(")#:&]O<V4@07!P;&EC871I;VXZ(@IM<V=S='(@
M(D5S8V]L:&$@82!!<&QI8V'GXV\Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`B17-C;VQH82!U;6$@<V5N:&$B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R(")%<V-O;&AA('5M('5S=>%R:6\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T
M97,Z(@IM<V=S='(@(D5S8V]L:&$@8V]M;R!E>&EB:7(@9&%T87,Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R
M960@;&ES=',I(@IM<V=S='(@(D5S8V]L:&$@;R!T:7!O(&1E(&5S=&EL;R!D
M92!L:7-T87,@*'!A<F$@;&ES=&%S(&]R9&5N861A<RDB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(DEL:&%S($-H<FES
M=&UA<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HY,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B0VQA
M<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N(@IM<V=S='(@(D[C;R!F
M;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C;R!D92!C;&%S<V4@9&4@)7,N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,30*;7-G
M:60@(D-L96%R(@IM<V=S='(@(DQI;7!A<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F
M:6-E('1A9W,B"FUS9W-T<B`B3&EM<&%R('1A9W,@35-/9F9I8V4B"@HC.B!A
M9&UI;B]S<6QS:&5L;"YP:'`Z,3(X"FUS9VED(")#;&5A<B!1=65R>2(*;7-G
M<W1R(")%>&-L=6ER('5S=>%R:6\B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]C;&5A<BYI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A<B!O=70@
M=7-E<CH@)7,B"FUS9W-T<B`B17AC;'5I<B!U<W7A<FEO.B`E<R(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,0IM<V=I9"`B0VQE87(@
M=7-E<B(*;7-G<W1R(")%>&-L=6ER('5S=>%R:6\B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]L:7-T+FEN8SHS-`IM<V=I9"`B0VQE87(@=7-E<B!D871A
M(@IM<V=S='(@(D5X8VQU:7(@9&%D;W,@9&\@=7-UX7)I;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A
M<FEN9R!,871E(@IM<V=S='(@(D/I=2!A8F5R=&\@82!487)D92(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED
M(")#;&EC:R!T;R!#;VYT:6YU92(*;7-G<W1R(")#;&EQ=64@<&%R82!#;VYT
M:6YU87(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HQ.#0*;7-G:60@(D-L:6-K871E;&P@=FEA($A45%`B"FUS9W-T
M<B`B0VQI8VMA=&5L;"!V:6$@2%144"(*"B,Z('-E<G9I8V5S+VME>6)O87)D
M+G!H<#HQ-#8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,@IM<V=I9"`B
M0VQO<V4@5VEN9&]W(@IM<V=S='(@(D9E8VAA<B!*86YE;&$B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(U,0IM<V=I9"`B0VQO=61S(@IM<V=S='(@(DYU
M=F5N<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B3G5B;&%D;R!P96QA
M($UA;FCC(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,3<*;7-G:60@(D-L;W5D>2(*;7-G<W1R(").=6)L861O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-`IM<V=I9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B
M26QH87,@9&4@0V]C;W,B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N
M:6YC.C(S"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(D-O;G1R
M86ER($)A<G)A($QA=&5R86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C(X"FUS9VED(")#;VQL87!S960@8F]R
M9&5R<R(*;7-G<W1R(")#;VYT<F%I<B!B;W)D87,B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;VQO;6)I82(*;7-G<W1R(")#;VST;6)I82(*"B,Z(&QI8B]";&]C
M:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y"FUS
M9VED(")#;VQO<B(*;7-G<W1R(")#;W(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(U"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,C8*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4P,2!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4&%L
M:&5T82!D92!#;W)E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,S4*;7-G:60@(D-O;&]U<B!S96QE8W1I;VXB"FUS9W-T<B`B4V5L9>?C;R!D
M92!#;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B0V]L<SHB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34P"FUS9VED(")#;VQU;6X@=&ET;&5S
M(@IM<V=S='(@(E3M='5L;W,@9&%S($-O;'5N87,B"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,C8V"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B475A
M9')I;FAO<R(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M
M;6%N9"(*;7-G<W1R(")#;VUA;F1O(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(DQI;FAA(&1E($-O
M;6%N9&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*
M;7-G:60@(D-O;6UE;G0B"FUS9W-T<B`B0V]M96YT87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA
M;64B"FUS9W-T<B`B3F]M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S
M(@IM<V=S='(@(D-O;6]R;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D5M
M<')E<V$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S$*;7-G:60@(D-O
M;7!U=&5R<R(*;7-G<W1R(")#;VUP=71A9&]R97,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")#;VYD:71I;VXB"FUS9W-T
M<B`B0V]N9&GGXV\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U-@IM<V=I
M9"`B0V]N9&ET:6]N<R(*;7-G<W1R(")#;VYD:>?U97,B"@HC.B!A9&UI;B]S
M971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F97)E
M;F-E<R(*;7-G<W1R(")$:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C;R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#8*;7-G:60@(D-O;F9I9W5R871I
M;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T
M;&]O:RXB"FUS9W-T<B`B0V]N9FEG=7)AY^-O(&1E('-I;F-R;VYI>F'GXV\@
M8V]M(%!$07,L(%-M87)T<&AO;F5S(&4@3W5T;&]O:RXB"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z,3,U"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U
M="!O9B!D871E+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@;F5C97-S:71A(&1E
M(&%T=6%L:7IAY^-O+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(D-O
M;F9I9W5R87(@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N
M:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D-O;F9I
M<FUE(&$@4V5N:&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R
M(")#;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B0V]N9V\L(%)E</IB;&EC
M82!$96UO8W+A=&EC82!D;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G
M<W1R(")&86QH82!N82!C;VYE>.-O+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS,3`*;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D
M.B`B"FUS9W-T<B`B1F%L:&$@;F$@8V]N97CC;SH@(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDP"FUS9VED(")#;VYN96-T:6]N(')E
M9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@(D-O;F5X
MXV\@<F5C=7-A9&$@<&5L;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-SDR"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(D-O;F5X
MXV\@<F5C=7-A9&$@<&5L;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N
M($UO=&EV;SH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#<V"FUS9VED(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")!(&-O;F5XXV\@86\@<V5R=FED;W(@1E10(&9A;&AO=2XB
M"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z,3`Q-`IM<V=I9"`B0V]N=&%C
M=',B"FUS9W-T<B`B0V]N=&%T;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-3,*;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R
M("(B"B)/<R!C;VYT871O<R!F;W)A;2!A9&EC:6]N861O<R!C;VT@<W5C97-S
M;R!A;R!S974@8V%TX6QO9V\@9&4@96YD97)EYV]S+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@
M='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4:7!E(&1E(&-O
M;G1E^F1O(&1O(&%R<75I=F\@8V]M<')I;6ED;SH@(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU-B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N
M=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1E^F1O(&1E("<E<R<B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR.2!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z,S,*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D-O;G1I
M;G5A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R
M("));&AA<R!#;V]K(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,R"FUS
M9VED(")#;V]K:64B"FUS9W-T<B`B0V]O:VEE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#
M;W!Y(@IM<V=S='(@(D-O<&EA<B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#<R"B,L('!H<"UF;W)M870*;7-G:60@(D-O<'D@9F%I;&5D.B`E
M<R(*;7-G<W1R(")&86QH82!N82!C\W!I83H@)7,B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,V"FUS9VED(")#;W!Y('-E
M;&5C=&EO;B(*;7-G<W1R(")#;W!I87(@<V5L9>?C;R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU"FUS9VED(")#;W-T($E$(@IM
M<V=S='(@(DE$(&1E($-U<W1O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@
M4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B
M0V]T92!D)TEV;VER92(*;7-G<W1R(")#;W-T82!D;R!-87)F:6TB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S<*;7-G:60@(D-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E.B`B"FUS9W-T<B`B26UP;W-S[79E
M;"!C<FEP=&]G<F%F87(@82!M96YS86=E;2!C;VT@4$=0.B`B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#;W5L9"!N
M;W0@4$=0('-I9VX@;65S<V%G93H@(@IM<V=S='(@(DEM<&]S<^UV96P@87-S
M:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`Z("(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z,SDS"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C
M<FEP=&]G<F%F87(@82!M96YS86=E;2!C;VT@4R]-24U%+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M(%,O34E-12XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$X-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@861I8VEO;F%R(&-O;G1A=&\N("5S
M(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE
M=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HT-3<*;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E
M<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L('9E<FEF:6-A<B!O('-A;&1O+B`E<R(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HT-#$*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O($Q$
M05`@<V5R=F5R+B(*;7-G<W1R("));7!O<W/M=F5L(&-O;F5C=&%R(&%O('-E
M<G9I9&]R($Q$05`N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B!<(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R("<E<R<@=71I;&EZ86YD;R!&5%`Z
M("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!C<FEA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,3(X"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T83H@(@IM<V=S='(@(DEM<&]S<^UV96P@
M9&5S8W)I<'1O9W)A9F%R(&]S(&1A9&]S(%!'4#H@(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D
M96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&1E<V-R:7!T;V=R869A<B!O(&1A9&\@4R]-24U%+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C0V"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&\@8V]N=&%T;RX@)7,B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C,U-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&5X8VQU:7(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@861M
M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97AC;'5I<B!O('-C<FEP="!D
M92!A='5A;&EZ8>?C;R!D92!C;VYF:6=U<F'GXV\@)R5S)RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G:60@(D-O=6QD(&YO="!D971E<FUI
M;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(&1E=&5R;6EN87(@;R!E;F1E<F7G;R!D92!E+6UA
M:6P@9&\@9&5S=&EN873A<FEO+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C@S"FUS9VED(")#;W5L9"!N;W0@9F5T
M8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@;R!C873A;&]G;R!D92!E;F1E
M<F7G;W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!C;VUP;&5T86UE;G1E(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@
M;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("(B"B).XV\@9F]I('!O
M<W/M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@82!L:7-T82!D92!L:7-T87,@
M9&4@9&ES=')I8G5IY^-O+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-A
M<G)E9V%R(&$@97-T<F%TZ6=I82`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H
M<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@8W)I87(@;R!D:7)E=/-R:6\@)R5S)RXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@82!C:&%V92!P^F)L:6-A(&$@
M<&%R=&ER(&1O('-E<G9I9&]R(&1E(&-H879E<RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N
M(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!A8G)I<B`G)7,G('!A<F$@9W)A=F'GXV\N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("5S+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&%B<FER("5S+B(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D=6QE("5S(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!M\V1U;&\@)TUA:6YT96YA
M;F-E7U1A<VLG("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2!<(B5S7"(N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@86)R:7(@;R!D:7)E=/-R:6\@
M)R5S)RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,3$Q
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ-#0*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Q
M,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C4V(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*;7-G:60@(D-O=6QD(&YO
M="!R96%C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@<&5S<75I<V%R(&YO('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O3V)J96-T+G!H<#HR-#`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(')E860@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@;&5R("5S+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U
M"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB
M"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!G97)A<B!U;6$@;F]V82!S
M96YH82!P87)A(&\@=7-UX7)I;R!S;VQI8VET861O+B!!;&=U;G,@;W4@(@HB
M=&]D;W,@;W,@9&5T86QH97,@;N-O(&5S=.-O(&-O<G)E=&]S+B!496YT92!N
M;W9A;65N=&4@;W4@96YT<F4@96T@8V]N=&%T;R`B"B)C;VT@;R!A9&UI;FES
M=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA:7,@86IU9&$N(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B0V]U;&0@
M;F]T(')E=')I979E($%#3"(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&]B
M=&5R(&$@04-,(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(')E=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!O(&-A=.%L;V=O(&1E(&5N9&5R9>=O<RX@)7,B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X
M-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T<RX@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A
M<R!L:7-T87,@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y.0HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3D*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T
M<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(D[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@87,@8V%P86-I9&%D97,@9&\@<V5R=FED;W(B"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"FUS9VED(")#;W5L9"!N;W0@
M<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@<F5V97)T97(@82!C;VYF:6=U<F'GXV\N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP.CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<
M(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!O(&1I
M<F5T\W)I;R`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<V%L=F%R(&$@
M8V]N9FEG=7)AY^-O("5S+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV
M,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T
M('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@8V]N9FEG=7)AY^-O+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<V%L=F%R('5M(&)A8VMU<"!D
M82!C;VYF:6=U<F'GXV\Z("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP
M:'`Z.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B(@HB3N-O
M(&9O:2!P;W-S[79E;"!S86QV87(@;R!S8W)I<'0@9&4@871U86QI>F'GXV\@
M9&4@8V]N9FEG=7)AY^-O(&5M.B`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A
M=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@
M(D[C;R!C;VYS96=U:2!S86QV87(@;R!B86-K=7`@9&\@87)Q=6EV;R!D92!C
M;VYF:6=U<F'GXV\@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#;W5L9"!N;W0@<V%V92!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE
M(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+B(*;7-G
M<W1R("(B"B).XV\@8V]N<V5G=6D@<V%L=F%R(&\@87)Q=6EV;R!D92!C;VYF
M:6=U<F'GXV\@)7,N(%9O8^H@<&]D92!O=2!U=&EL:7IA<B!U;6$@(@HB9&%S
M(&]PY_5E<R!P87)A('-A;'9A<B!O(&/S9&EG;R!D92!V;VQT82!E;2`E<R!O
M=2!C;W!I87(@;6%N=6%L;65N=&4@;R`B"B)C\V1I9V\@86)A:7AO('!A<F$@
M)7,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,*;7-G
M:60@(D-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(").XV\@9F]I('!O<W/M=F5L('!E<W%U:7-A<B!N;R!S97)V:61O<B!,1$%0
M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!R96UO=F5R(&\@;&EN:R`G)7,G+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C$Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!A='5A;&EZ87(@;R!C;VYT871O+B`E<R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,SDV"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M871U86QI>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E<R(*
M;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=R879A<B!A(&-O;F9I9W5R8>?C
M;R!D92`G)7,G.B`E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S`*
M;7-G:60@(D-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K
M92!S=7)E('1H92!S:61E8F%R(&ES(&]P96XN(@IM<V=S='(@(B(*(D[C;R!F
M;VD@<&]S<^UV96P@96YC;VYT<F%R(&$@0F%R<F$@3&%T97)A;"!D;R!-;WII
M;&QA+B!#97)T:69I<75E+7-E('%U92!E;&$@(@HB97-TX2!A8F5R=&$N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S
M7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB
M.B`E<R(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&1A<B!A;R!U<W7A
M<FEO("5S(&]S('-E9W5I;G1E<R!D:7)E:71O<R!P87)A(&$@<&%S=&$@)R5S
M)SH@)2(*(G,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"FUS
M9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B5&5X=&\@8V]N=&%D;R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#
M;W5N=')Y(@IM<V=S='(@(E!A[7,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(D-U<G-O<R(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(D-R:6%R(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(D-R:6%R('5M(&QI;FLB
M"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS
M9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(D-R:6%R('5M82!N;W9A
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*
M;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#<FEA<B!S=6(@
M<&%S=&%S(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR-#`*
M;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R;6ES<_5E
M<R!D;R!C<FEA9&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(Q
M.0IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(D[Z;65R;R!D
M;R!C87)TXV\@9&4@8W+I9&ET;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")#<F]A
M=&EA(@IM<V=S='(@(D-R;^%C:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C4*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A
M(@IM<V=S='(@(D-U8F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G
M:60@(D-U<G)E;G0@-"!0:&%S97,B"FUS9W-T<B`B-"!&87-E<R!!='5A:7,B
M"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U<G)E;G0@4V5S
M<VEO;G,B"FUS9W-T<B`B4V5S<_5E<R!!='5A:7,B"@HC.B!L:6(O0FQO8VLO
M=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E
M;G0@5&EM92(*;7-G<W1R(")(;W)A($%T=6%L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4T"FUS9VED(")#
M=7)R96YT(%523"!I<R(*;7-G<W1R(")!(%523"!A='5A;"#I(@H*(SH@861M
M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT(%5S97)S(@IM<V=S
M='(@(E5S=>%R:6]S(&YO(&UO;65N=&\B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B0VQI;6$@
M071U86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C8T"FUS
M9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(D-O;F1IY^-O(&%T
M=6%L.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D5S=&EL;R!A
M='5A;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N
M('1O("5S+B(*;7-G<W1R(")#=7-T;VUI>F$@=&%R969A<R!A('-E<F5M(&5X
M96-U=&%D87,@86\@8V]N96-T87(@82`E<RXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C`*;7-G:60@(D-U
M="(*;7-G<W1R(")#;W)T87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S
M='(@(D-O<G1A<B!S96QEY^-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B0WEP<G5S
M(@IM<V=S='(@(D-H:7!R92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Q
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")#:7+M;&EC;R`H
M2T])."U2*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*2(*;7-G<W1R(")#:7+M;&EC;R`H5VEN
M9&]W<RTQ,C4Q*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@S"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B0VER[6QI
M8V\O56-R86YI86YO("A+3TDX+54I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HV."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B0WIE
M8V@@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A(%1C:&5C82(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-3`@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W.0IM<V=I9"`B(@HB1%-.("AS
M964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*2(*;7-G<W1R("(B"B)$4TX@*'9E:F$@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S
M92YD8BYI;G1R;RUD<VXN<&AP*2(*"B,Z(&9R86UE=V]R:R]-86EN=&5N86YC
M92]-86EN=&5N86YC92YP:'`Z-3D*;7-G:60@(D1A:6QY(@IM<V=S='(@(D1I
M87)I86UE;G1E(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$
M871A5')E92!"<F]W<V5R(@IM<V=S='(@(DYA=F5G861O<B!D92!$871A5')E
M92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-S<*;7-G:60@(D1A
M=&%B87-E($QO;VMU<"(*;7-G<W1R(")097-Q=6ES82!N;R!"86YC;R!D92!$
M861O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P,@IM<V=I9"`B1&%T
M92(*;7-G<W1R(")$871A(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T
M82!D92!296-E8FEM96YT;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(W.38*;7-G:60@(D1A=&4@<V5L96-T:6]N(@IM<V=S='(@(E-E;&7GXV\@
M9&4@9&%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B1&%Y(@IM
M<V=S='(@(D1I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS
M9W-T<B`B15]X8VQU:7(@0V]L=6YA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@
M(D1E>F5M8G)O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM
M<V=S='(@(D[Z;65R;W,@9&5C:6UA:7,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E
M;G0B"FUS9W-T<B`B4F5C=6%R($ED96YT8>?C;R(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI8B]P<F5F<RYP:'`Z,3$W"FUS9VED
M(")$969A=6QT(@IM<V=S='(@(E!A9'+C;R(*"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O
M;&]R(@IM<V=S='(@(D-O<B!0861RXV\B"@HC.B!F<F%M97=O<FLO261E;G1I
M='DO261E;G1I='DN<&AP.CDV"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM
M<V=S='(@(DED96YT:61A9&4@4&%D<N-O(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C8W"FUS9VED(")$969A=6QT(%-H96QL(@IM<V=S='(@(E-H96QL
M(%!A9'+C;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B
M1&5F:6YI=&EO;G,B"FUS9W-T<B`B1&5F:6YIY_5E<R(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,38*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M.`HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*
M;7-G<W1R(")%>&-L=6ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")$96QE=&4@0V5L;"(*
M;7-G<W1R(")%>&-L=6ER(&/I;'5L82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M,3DY(&%D;6EN+V=R;W5P<RYP:'`Z,C(W"FUS9VED(")$96QE=&4@1W)O=7`B
M"FUS9W-T<B`B17AC;'5I<B!'<G5P;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M>6YC;6PN<&AP.C(T.0IM<V=I9"`B1&5L971E($QO9R(*;7-G<W1R(")%>&-L
M=6ER($QO9R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T
M92!097)M:7-S:6]N(@IM<V=S='(@(D5X8VQU:7(@4&5R;6ES<^-O(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*;7-G:60@
M(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`B17AC;'5I<B!E
M('!U<F=A<B!M96YS86=E;G,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*
M;7-G<W1R(")%>&-L=6ER(&/I;'5L82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`B17AC;'5I<B!C;VQU;F$B"@HC.B!A9&UI;B]T96UP
M;&%T97,N<&AP.C$T.`IM<V=I9"`B1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T92(*;7-G<W1R(")%>&-L=6ER(&UO9&5L;R!S=6)S=&ET=71O
M(&5X:7-T96YT92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@7"(E<UPB(@IM<V=S='(@(D5X8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E
M<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<
M(B!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B17AC;'5I<B!P
M97)M:7-S]65S('!A<F$@)R5S)R!E('%U86QQ=65R(&]U=')A('-U8BUP97)M
M:7-SXV\_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")%>&-L
M=6ER(&QI;FAA(@H*(SH@=&5M<&QA=&5S+W!R969S+V1E;&5T96ED96YT:71Y
M+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D(&ED96YT:71Y(@IM<V=S
M='(@(D5X8VQU:7(@:61E;G1I9&%D92!S96QE8VEO;F%D82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM
M<V=I9"`B1&5L971E('1H92!C=7)R96YT(&-O;'5M;B(*;7-G<W1R(")%>&-L
M=6ER(&$@8V]L=6YA(&%T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W(@IM<V=S='(@(D5X8VQU:7(@82!L:6YH82!A='5A;"(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*
M;7-G<W1R(")38W)I<'0@9&4@871U86QI>F'GXV\@9&4@8V]N9FEG=7)AY^-O
M("<E<R<@97AC;'7M9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PIM<V=I9"`B1&5L:79E
M<GD@=&EM92(*;7-G<W1R(")(;W)A(&1E(&5N=')E9V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$96YM87)K(@IM<V=S='(@(D1I;F%M87)C82(*"B,Z('1E;7!L
M871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T
M:&4@4')O8FQE;2(*;7-G<W1R(")$97-C<F5V82!O('!R;V)L96UA(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.30R('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T
M:6]N(@IM<V=S='(@(D1E<V-R:>?C;R(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3DW"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ(@IM<V=S='(@(D1E=&%L:&5S("AT86UBZ6T@;F\@<F5G:7-T
M<F\@9&4@871I=FED861E<R!D;R!(;W)D92DZ(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D]S(&1E=&%L
M:&5S(&9O<F%M(&=R879A9&]S(&5M(&QO9R!P87)A(&\@861M:6YI<W1R861O
M<BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(Q"FUS9VED(")$
M979E;&]P;65N="(*;7-G<W1R(")$97-E;G9O;'9I;65N=&\B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-`IM<V=I9"`B1&5W(%!O:6YT(@IM<V=S='(@
M(E!O;G1O(&1E($]R=F%L:&\B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M,0IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")0
M;VYT;R!D92!/<G9A;&AO('!A<F$@82#Z;'1I;6$@:&]R83H@(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT
M.B`B"FUS9W-T<B`B4&]N=&\@9&4@3W)V86QH;SH@(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0B"FUS9W-T<B`B1&ER9>?C;R!D82!E<W%U97)D
M82!P87)A(&1I<F5I=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F
M="(*;7-G<W1R(")$:7)EY^-O(&1A(&1I<F5I=&$@<&%R82!E<W%U97)D82(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B1&ER973S<FEO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C(W,`IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R(")%
M>&EB:7(@96T@9F]R;6%T;R`R-"!H;W)A<S\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`P"FUS9VED(")$:7-P;&%Y($]P=&EO;G,B"FUS9W-T<B`B
M3W#G]65S(&1E($5X:6)IY^-O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C@Y"FUS9VED(")$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T(@IM
M<V=S='(@(D5X:6)I<B!P<F5V:7/C;R!D971A;&AA9&$B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.CDR"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I
M(@IM<V=S='(@(D5X:6)I<B!P<F5V:7/C;R`H5$%&*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(X,#8*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM
M<V=S='(@(D5X:6)I<B!F;W)M871O(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C$Y,0IM<V=I9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M(@IM<V=S='(@(DYO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB=71I(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(*;7-G:60@(D1O(&YO="!D
M96QE=&4B"FUS9W-T<B`B3N-O(&5X8VQU:7(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,C4*;7-G:60@(D1O(&YO="!D:7)E8W1L>2!A8V-E<W,@
M;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(D[C;R!A8V5S<V4@9&ER971A;65N
M=&4@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF
M;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@
M(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`B(@HB02!P<FEM96ER
M82!L:6YH82!C;VYTZ6T@;W,@;F]M97,@9&]S(&-A;7!O<S\@4V4@<VEM+"!C
M;&EQ=64@;F5S=&$@8V%I>&$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&]M:6YI
M8V$B"FUS9W-T<B`B1&]M:6YI8V%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW
M,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O
M;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R(")297#Z8FQI8V$@1&]M:6YI8V%N
M82(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B3N-O('1E
M;2!U;6$@8V]N=&$_($-A9&%S=')E+7-E+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@U,0IM<V=I9"`B1&]W;FQO860B"FUS9W-T
M<B`B0F%I>&%R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z.#4Q"B,L('!H<"UF;W)M870*;7-G:60@(D1O=VYL;V%D("5S(@IM<V=S
M='(@(D)A:7AA<B`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*
M;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(
M4"!S8W)I<'0N(@IM<V=S='(@(D)A:7AA<B!A(&-O;F9I9W5R8>?C;R!G97)A
M9&$@8V]M;R!U;2!S8W)I<'0@4$A0+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,3$*;7-G:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(DQI
M<W1A(&1E('-E;&7GXV\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*
M;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=A<R(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q,PIM<V=I9"`B12U-86EL(@IM<V=S='(@
M(D-O<G)E:6\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I8U]S
M;71P+G!H<#HY,@IM<V=I9"`B14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R
M+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N(@IM
M<V=S='(@(B(*(D-O;F5C=&]R(&1O(&=A=&5W87D@14UA:6PM<&%R82U335,L
M('!A<F$@;W!E<F%D;W)A<R!Q=64@9&ES<&]N:6)I;&EZ86T@97-T92`B"B)S
M97)V:>=O+B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@(D524B(*;7-G<W1R
M(")%4E(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S(*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(D5Q
M=6%D;W(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*;7-G:60@(D5D:70B
M"FUS9W-T<B`B161I=&%R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU,`IM<V=I9"`B161I="!";&]C:R(*;7-G<W1R(")%9&ET87(@0FQO
M8V\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y."!A9&UI;B]G<F]U<',N<&AP
M.C(R-@IM<V=I9"`B161I="!'<F]U<"(*;7-G<W1R(")%9&ET87(@1W)U<&\B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`P"FUS9VED(")%9&ET(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B161I=&%R(%!E<FUI<W/C;R(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,S<*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`B161I=&%R(%!E<FUI<W/U97,B"@HC.B!S97)V:6-E<R]S:&%R97,O
M961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S(@IM<V=S='(@(D5D:71A<B!097)M:7-S]65S('!A<F$@
M)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%9&ET
M(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")%9&ET87(@;W#G]65S(&1E.B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S8W"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G<W1R
M(")%9&ET87(@<&5R;6ES<_5E<R!P87)A("5S(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E
M<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R(")%9&ET87(@<&5R;6ES<_5E<R!P
M87)A("5S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,U"FUS9VED(")%
M9'5C871I;VXB"FUS9W-T<B`B161U8V'GXV\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED
M(")%9WEP="(*;7-G<W1R(")%9VET;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B
M16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*;7-G
M:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N=&\N+BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.0IM<V=I9"`B
M16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*
M;7-G:60@(D5M86EL(@IM<V=S='(@(D4M;6%I;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-38V('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,3`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHV.`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R(")%;F1E<F7G
M;R!D92!%+4UA:6PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38W
M"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M871C:"XB"FUS9W-T<B`B
M3R!E;F1E<F7G;R!D92!E+6UA:6P@9&5V92!C;W)R97-P;VYD97(N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B365N<V%G96T@8V]M(&-O;F9I<FUA
MY^-O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP
M:'`Z.3$*;7-G:60@(D5M86EL+71O+5--4R!'871E=V%Y(@IM<V=S='(@(D=A
M=&5W87D@9&4@14UA:6PM<&%R82U335,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,CDW"FUS9VED(")%;6]T:6-O;G,B"FUS
M9W-T<B`B16UO=&EC;VYS(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*
M;7-G<W1R(")-96YS86=E;2!E;2!B<F%N8V\N(@H*(SH@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HV-C(@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@
M<F5S=6QT+B(*;7-G<W1R(")297-U;'1A9&\@96T@8G)A;F-O+B(*"B,Z(&9R
M86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ,3,*;7-G:60@(D5M<'1Y
M('-E87)C:"!T97)M<R(*;7-G<W1R(")497)M;W,@9&4@<&5S<75I<V$@96T@
M8G)A;F-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4T-PIM<V=I9"`B
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\B"FUS9W-T<B`B2&%B:6QI=&%R(&EN<V5RY^-O(&1E(&EM
M86=E;G,@82!P87)T:7(@9&$@1V%L97)I82!D92!);6%G96YS(&YO('1E>'1O
M/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L
M92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@(DAA8FEL:71A
M<B!M96YU(&1E(&-O;G1E>'1O(&-O;2!O(&)O=.-O(&1I<F5I=&\_(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y,B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.#`P"FUS9VED(")%;F0@>65A<B(*;7-G<W1R(")&:6YA;"!D
M;R!A;F\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R(")!=6UE;G1A
M<B!%9&ET;W(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(T"FUS9VED
M("(B"B)%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS
M9W-T<B`B(@HB1F]R;F7G82!U;6$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A(&$@
M<75A;"!V;V/J('-E<N$@<&5R9W5N=&%D;R!S92!V;V/J("(*(FYE8V5S<VET
M87(@9V5R87(@=6UA(&YO=F$@<V5N:&$L(&5X+B`G<75A;"!O(&YO;64@9&\@
M<V5U(&-A8VAO<G)O/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@
M:6UA9V4@55),(&AE<F4B"FUS9W-T<B`B1F]R;F7G82!A(%523"!D82!I;6%G
M96T@87%U:2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HX.3`*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E;&]W.B(*;7-G
M<W1R(")$:6=I=&4@87,@;&5T<F%S(&%B86EX;SHB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")%<75A=&]R:6%L($=U:6YE82(*;7-G<W1R(")'=6ENZ2!%<75A=&]R
M:6%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET
M<NEI82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,C<*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="]6:65W+G!H<#HY-"!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#@*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-@IM<V=I9"`B17)R
M;W(B"FUS9W-T<B`B17)R;R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-#8S"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R(&-R96%T
M:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")%<G)O(&%O(&-R:6%R(&)L;V-O.B`E
M<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*
M;7-G<W1R(")%<G)O(&%O(&5X8VQU:7(@XFYC;W)A(&1E('-I;F-R;VYI>F'G
MXV\Z("5S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z.#,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S
M(@IM<V=S='(@(D5R<F\@86\@97AC;'5I<B!L;V<@9&4@<VEN8W)O;FEZ8>?C
M;SH@)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S(@IM<V=S='(@(D5R<F\@86\@;V)T97(@8V]N=&7Z9&\Z("5S(@H*(SH@
M<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M870*
M;7-G:60@(D5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<R(*;7-G<W1R(")%
M<G)O(&%O(&%T=6%L:7IA<B!A('-E;FAA.B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+B(*;7-G<W1R(")%<G)O(&YA(&UE;G-A
M9V5M+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D5R<F\@9W)A
M=F%N9&\@)R5S)RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S
M='(@(D5S=/1N:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")%=&AI;W!I82(*;7-G
M<W1R(")%=&GS<&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")%=&AN:6,B"FUS9W-T<B`BR71N:6-O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R
M;W!A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E
M<GD@,34@;6EN=71E<R(*;7-G<W1R(")#861A(#$U(&UI;G5T;W,B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDS"FUS9VED(")%=F5R>2`R(&UI;G5T
M97,B"FUS9W-T<B`B0V%D82`R(&UI;G5T;W,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0P(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@
M(D5V97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=U;F1O<R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#(@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,Y-`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D-A
M9&$@-2!M:6YU=&]S(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B0V%D
M82!#;VYE>.-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T-`IM<V=I
M9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@(D-A9&$@;65I82!H;W)A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T,2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDR"FUS9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B0V%D82!M
M:6YU=&\B"@HC.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I
M9"`B17AA;7!L92!V86QU97,Z(@IM<V=S='(@(E9A;&]R97,@9&4@97AE;7!L
M;SHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN
M<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C<*;7-G:60@(D5X96-U=&4B
M"FUS9W-T<B`B17AE8W5T87(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+TUA;F%G97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(D5X<&%N9&ER(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHS
M,@IM<V=I9"`B17AP86YD(%-I9&5B87(B"FUS9W-T<B`B17AP86YD:7(@0F%R
M<F$@3&%T97)A;"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H
M<#HQ-C@*;7-G:60@(D5X<&5C=&5D("<I)R(*;7-G<W1R(")%<W!E<F%D;R`G
M*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS
M9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M(@IM<V=S='(@(D5S<&5R861O('5M82!P86QA=G)A(&]U('1E<FUO(&1E('!E
M<W%U:7-A(&5N=')E(&%S<&%S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T:6]N($1A=&4B"FUS9W-T<B`B
M1&%T82!D92!%>'!I<F'GXV\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W-PIM<V=I9"`B17AP;VYE;G0B"FUS9W-T<B`B17AP;V5N
M=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R(")#;W(@9&\@<')I
M;65I<F\@<&QA;F\B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS
M9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D-O;F9I9W5R8>?C
M;R!D92!E;G9I;R!D92!A<G%U:79O<R!&5%`B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O<W%L+G!H<#HR,C4*;7-G:60@(D9A:6QE9"!R971R:65V:6YG
M('!R969E<F5N8V5S+B(*;7-G<W1R(")&86QH82!O8G1E;F1O('!R969E<NIN
M8VEA<RXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(D9A;&AA(&%O
M(&-O;F5C=&%R(&%O('-E<G9I9&]R($Q$05`N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C="!T
M;R!334(@<V5R=F5R+B(*;7-G<W1R(")&86QH82!A;R!C;VYE8W1A<B!A;R!S
M97)V:61O<B!334(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW
M,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<
M(B5S7"(N(@IM<V=S='(@(D9A;&AA(&%O(&-O<&EA<B!D92!<(B5S7"(N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")&
M86QH82!A;R!C;W!I87(@<&%R82!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N
M97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")&86QH82!A;R!C<FEA<B!U
M;6$@;F]V82!C;VYE>.-O(%-!4TPN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<VUB+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&UO=F4@=&\@7"(E<UPB+B(*
M;7-G<W1R(")&86QH82!A;R!M;W9E<B!P87)A(%PB)7-<(BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@<F5T<FEE=F4Z("5S(@IM<V=S='(@(D9A;&AA(&%O(&]B
M=&5R.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(DIU<W1O(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HX-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,@IM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I(@IM<V=S='(@
M(DEL:&%S($9A;&ML86YD("A-86QV:6YA<RDB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED
M(")&87)O92!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($9A<F]E(@H*(SH@9G)A
M;65W;W)K+T-,22]#3$DN<&AP.C(S.`IM<V=I9"`B1F%T86P@17)R;W(Z(@IM
M<V=S='(@(D5R<F\@1F%T86PZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X(@IM<V=S='(@(D9A>"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3$*;7-G:60@(D9A>&5S
M(@IM<V=S='(@(D9A>&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(D9E=F5R
M96ER;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(W"FUS9VED(")&965L
M<R!,:6ME(@IM<V=S='(@(E-E;G-AY^-O(%3I<FUI8V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(P"FUS9VED(")&965L<R!L:6ME.B`B
M"FUS9W-T<B`B4V5N<V'GXV\@=.ER;6EC83H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S
M(@IM<V=S='(@(E!A;F-A9&%S(&1E($-H=79A(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B3F5V92!&<F%C82(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G<W1R(")-
M871R:7H@9&\@8V%M<&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS
M,S,R"FUS9VED(")&:6=L970@0T%05$-(02(*;7-G<W1R(")&:6=L970@0T%0
M5$-(02(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S8*;7-G:60@
M(D9I9VQE="!F;VYT(@IM<V=S='(@(D9O;G1E($9I9VQE="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B1FEJ:2(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B1FEL92(*;7-G<W1R(")A<G%U
M:79O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")#;VYT
M86=E;2!D92!!<G%U:79O<SH@)7,@87)Q=6EV;R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U
M;G0Z("5S(&9I;&5S(@IM<V=S='(@(D-O;G1A9V5M(&1E($%R<75I=F]S.B`E
M<R!A<G%U:79O<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#D*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")'97)E;F-I861O<B!D92!!
M<G%U:79O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R"FUS9VED
M(")&:6QE($YA;64B"FUS9W-T<B`B3F]M92!D;R!!<G%U:79O(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDX-`IM<V=I9"`B1FEL92!S96QE8W1I
M;VXB"FUS9W-T<B`B4V5L9>?C;R!D92!A<G%U:79O(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,30Y,`IM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T
M<B`B16YV:6\@9&4@87)Q=6EV;R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@X-0IM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T
M960N(@IM<V=S='(@(D5N=FEO(&1E(&%R<75I=F]S(&[C;R#I('-U<&]R=&%D
M;RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G:60@(D9I
M;'1E<G,B"FUS9W-T<B`B1FEL=')O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I
M;FQA;F0B"FUS9W-T<B`B1FEN;.)N9&EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$V-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")0<FEM96ER82!-
M971A9&4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO
M;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(E!R:6UE
M:7)O(%%U87)T;R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HR-34*;7-G:60@(D9I>"!R871I;R(*;7-G<W1R(")487AA(&9I
M>&$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C,P"FUS9VED(")&;&EP(@IM<V=S='(@(D=I<F%R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,@IM<V=I9"`B
M1FQO870B"FUS9W-T<B`B1&ES<&]S:>?C;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B
M3NEV;V$B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(S-R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G
M:60@(D9O;&1E<B`E<R!D;V5S(&YO="!E>&ES="(*;7-G<W1R(")087-T82`E
M<R!NXV\@97AI<W1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R(")#;W(@
M9&$@1F]N=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@
M(D9O;V0B"FUS9W-T<B`B0V]M:61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"FUS9VED(")&;W(@
M8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*;7-G<W1R(")0
M87)A(&YA=F5G861O<F5S('%U92!NXV\@<W5P;W)T86T@:6UA9V5N<R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&
M*2(*;7-G<W1R(")0<F5V:7/C;R`H5$%&*2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HW,@IM<V=I9"`B(@HB1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82`B"B)L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*2(*;7-G<W1R("(B"B)$:6%S(%!R979I<W1O
M<R`H3F]T92!Q=64@82!P<F5V:7/C;R!R971O<FYA9&$@97AI8F4@86UB;W,@
M9&EA(&4@;F]I=&4[('5M("(*(F[Z;65R;R!M=6ET;R!A;'1O(&%Q=6D@<&]D
M92!R97-U;'1A<B!E;2!U;2!B;&]C;R!E>'1E;G-O*2(*"B,Z('1E;7!L871E
M<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`B17-Q=65C974@82!S96YH83\B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R(")&
M;W)M=6SA<FEO<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I
M9"`B1F]R='5N92(*;7-G<W1R(")3;W)T92(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HY.0IM<V=I9"`B1F]R='5N92!T>7!E(@IM<V=S='(@(E1I<&\@
M9&4@4V]R=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@
M(D9O<G1U;F5S(@IM<V=S='(@(E-O<G1E<R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HS.0IM<V=I9"`B1F]R='5N97,@,B(*;7-G<W1R(")3;W)T97,@
M,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-34*;7-G:60@(D9O
M<G5M<R(*;7-G<W1R(")&\W)U;G,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3$Q"FUS9VED(")&;W)W87)D<R(*;7-G<W1R(")2961I<F5C:6]N
M86UE;G1O<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C`*;7-G:60@(D9R(@IM<V=S='(@(E-E>"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")1=6%D<F]S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HX-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C@S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E(@IM<V=S='(@(D9R86[G82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E+"!-971R;W!O;&ET86XB"FUS
M9W-T<B`B1G)A;N=A($UE=')O<&]L:71A;F$B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"FUS9VED
M(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(D=U:6%N82!&<F%N8V5S82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(E!O
M;&ENZ7-I82!&<F%N8V5S82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(E1E<G)I=/-R:6]S($9R
M86YC97-E<R!D;R!3=6PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@(D1E(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S-R!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S0Y"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS.34*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")$;RAA*2(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"FUS9VED(")&=6QL
M($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:>?C;R!#;VUP;&5T82(*"B,Z
M(&QI8B]";&]C:R]M;V]N+G!H<#HX,2!L:6(O0FQO8VLO;6]O;BYP:'`Z,3<V
M"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B3'5A($-H96EA(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(").;VUE($-O
M;7!L971O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B
MXV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F
M<F]M(@IM<V=S='(@(D=A;&5R:6$@9&4@;VYD92!O8G1E<B!A<R!I;6%G96YS
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FEA
M.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.38@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=A;6)I82(*;7-G<W1R(")'XFUB:6$B
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*
M;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B1V5R
M87(@82!#;VYF:6=U<F'GXV\@9&4@)7,B"@HC.B!T96UP;&%T97,O861M:6XO
M<V5T=7`O8V]N9FEG+FAT;6PZ.`IM<V=I9"`B1V5N97)A=&5D($-O9&4B"FUS
M9W-T<B`B0_-D:6=O($=E<F%D;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G
M:6$B"FUS9W-T<B`B1V7S<F=I82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E<FUA
M;GDB"FUS9W-T<B`B06QE;6%N:&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.3$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':&%N
M82(*;7-G<W1R(")'86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB<F%L=&%R
M(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<V"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E!R
M:6UE:7)O($YO;64B"@HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3<U('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$P"B,Z('1E;7!L871E<R]P
M<F5F<R]A<'`N:6YC.C$Y"FUS9VED(")';&]B86P@3W!T:6]N<R(*;7-G<W1R
M(")/<.?U97,@1VQO8F%I<R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC
M.C$W"FUS9VED(")';R(*;7-G<W1R("))<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,3(Y"FUS
M9VED(")';V]G;&4@36%P<R(*;7-G<W1R(")';V]G;&4@36%P87,B"@HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H
M(@IM<V=S='(@(E!E<W%U:7-A<B!N;R!';V]G;&4B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,V"FUS9VED(")'<F%Y<V-A
M;&4B"FUS9W-T<B`B17-C86QA(&1E($-I;GIA<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V"FUS
M9VED(")'<F5E8V4B"FUS9W-T<B`B1W+I8VEA(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#0*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R
M(")'<F5G;R`H25-/+3@X-3DM-RDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.CDU(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E
M;FQA;F0B"FUS9W-T<B`B1W)O96SB;F1I82(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=R96YA9&$B"FUS9W-T<B`B1W)A;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3<Y"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M9&UI;FES=')AY^-O(&1E($=R=7!O<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"YP:'`Z-3D@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V
M.0IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T
M<B`B3F]M97,@9&4@9W)U<&]S(&[C;R!D979E;2!E<W1A<B!E;2!B<F%N8V\B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S`W"B,L('!H
M<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R
M("(B"B)'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&%D:6-I;VYA<B!G<G5P;R`E
M<RX@27-T;R#I(&\@<75E(&\@<V5R=FED;W(@9&ES<V4Z("(*"B,Z(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A
M<#H@26UP;W-S[79E;"!E>&-L=6ER(&=R=7!O("5S(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S<Y"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?
M;&1A<#H@26UP;W-S[79E;"!A='5A;&EZ87(@9W)U<&\@)7,B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE
M+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I
M9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!O<R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@
M(D=U861E;&]U<&4B"FUS9W-T<B`B1W5A9&%L=7!E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*
M;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS9VED
M(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5L86UA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B
M1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'=65S="!0
M97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S(&1E($-O;G9I9&%D;R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S(*;7-G:60@(D=U97-T
M8F]O:R(*;7-G<W1R("),:79R;R!D92!6:7-I=&%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM
M<V=I9"`B1W5I;F5A(@IM<V=S='(@(D=U:6[I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<X"FUS
M9VED(")'=6EN96$M0FES<V%U(@IM<V=S='(@(D=U:6[I+4)I<W-A=2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW.`IM<V=I9"`B1W5Y86YA(@IM<V=S='(@(D=U:6%N82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G
M<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(DA434Q!<F5A('-E(&YE9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL
M=&EM82!CZ6QU;&$@9&$@;&EN:&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!S92!N96=A(&-O=F%R9&5M96YT
M92!A(&5X8VQU:7(@82#Z;'1I;6$@8V]L=6YA(&1A('1A8F5L82XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@W
M"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!<F5A('-E(&YE
M9V$@8V]V87)D96UE;G1E(&$@97AC;'5I<B!A(/IL=&EM82!L:6YH82!D82!T
M86)E;&$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*
M;7-G:60@(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71E;G1I8V'GXV\@2%144"!NXV\@96YC;VYT<F%D82XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$P,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(DAA:71I(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R
M:71H;2(*;7-G<W1R(")!;&=O<FET;6\@2&%S:"(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM<V=S
M='(@(DYE8FQI;F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,C,@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR,0IM<V=I9"`B2&5A9&5R(@IM
M<V=S='(@(D-A8F7G86QH;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP
M92]T86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B0V%B
M9>=A;&AO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B26QH82!(96%R9"!E($EL:&%S
M($UC1&]N86QD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B5&5M<&5S
M=&%D92!&;W)T92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@U"FUS9VED
M(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5U("A)4T\M
M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@(D%L='5R
M82(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#0@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z-`IM
M<V=I9"`B2&5L<"(*;7-G<W1R(")!:G5D82(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@
M961I=&]R(@IM<V=S='(@(D%J=61A(&1O(&5D:71O<B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S4*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!
M<W-I<W1E;G1E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9NER:6\B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ,"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ,`IM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.B(*;7-G<W1R(")!<75I(&5S=.$@;R!I;NUC:6\@9&\@87)Q=6EV;SHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I
M9"`B2&EG:"(*;7-G<W1R(")!;'1A(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M
M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU
M"FUS9VED(")(;U]M92(*;7-G<W1R("))7V[M8VEO(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T
M<B`B4V%N=&$@4^D@*$-I9&%D92U%<W1A9&\@9&\@5F%T:6-A;F\I(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-3,Y"FUS9VED(")(;VUE(@IM
M<V=S='(@(DEN[6-I;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5N
M9&5R9>=O(%)E<VED96YC:6%L(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C8T"FUS9VED(")(;VUE($1I<F5C=&]R>2(*;7-G<W1R(")$:7)E=/-R:6\@
M4&5S<V]A;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B1F]N92!297-I
M9&5N8VEA;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T
M<B`B2&]N9'5R87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@
M:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@1&%D;R!834P@
M)7,@:6YVX6QI9&\@96YC;VYT<F%D;R!N82!M96YS86=E;2`E<R(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B
M:F5C="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5N:'5M82!M96YS86=E
M;2!C;W)R97-P;VYD92!A;R!O8FIE=&\@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C0S-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@3F5N:'5M(&]B:F5T;R!D;R!T:7!O
M("5S(&9O:2!E;F-O;G1R861O(&YA(&UE;G-A9V5M("5S(@H*(SH@9G)A;65W
M;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0V"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<(B5S7"(B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%)E;6]V:61O(&-O;2!S=6-E<W-O("5S
M(%PB)7-<(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS
M9VED(")(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R(")(;W)D
M92]+;VQA8CH@02!E;F=I;F4@9&4@:6YT96=R8>?C;R!R97%U97(@82!E>'1E
M;G/C;R!02%`@)V1O;7AM;"<B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C4P,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26UP;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A
M<G9O<F4@6$U,('!A<F$@;R!O8FIE=&\@)7,B"@HC.B!F<F%M97=O<FLO2V]L
M86(O2V]L86(N<&AP.C$R-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R
M(")(;W)D92]+;VQA8CH@26UP;W-S[79E;"!R96UO=F5R("5S(%PB)7-<(CH@
M)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@HB
M2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@;V)T97(@82!I9&5N=&EF:6-AY^-O
M($U)344@<&%R82!A('!A<G1E(&1O('1I<&\@)7,B"@HC.B!F<F%M97=O<FLO
M2V]L86(O2V]L86(N<&AP.C$Q.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);7!O<W/M=F5L('-I;F-R;VYI>F%R
M("5S(%PB)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$S,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!);7!O<W/M=F5L('-I;F-R;VYI>F%R(&-O;7!A<G1I;&AA;65N=&]S
M.B`E<R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,S0P"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E(%PB
M)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@0V]M<&%R=&EL:&%M96YT;R!D
M97-C;VYH96-I9&\@7"(E<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM
M<V=S='(@(DQI;FAA($AO<FEZ;VYT86PB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N=&%L('!A
M9&1I;F<B"FUS9W-T<B`B36%R9V5M(&AO<FEZ;VYT86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS9VED(")(;W)I
M>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N=&%L.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,0IM<V=I9"`B
M2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2DB"FUS9W-T
M<B`B0V]M;R!V;V/J(&-H96=O=2!A<75I/R`H4&]R(&9A=F]R(&-O;75N:7%U
M92$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\B"FUS9W-T<B`B475A;G1A<R!C;VQU;F%S('9O8^H@
M9V]S=&%R:6$@9&4@;65S8VQA<C\B"@HC.B!T96UP;&%T97,O9&%T82]C<W9I
M;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_(@IM<V=S='(@(E%U86YT;W,@8V%M<&]S("AC;VQU;F%S*2!E
M>&ES=&5M/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT87,@;&EN:&%S('9O8^H@
M9V]S=&%R:6$@9&4@;65S8VQA<C\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W"FUS9VED(")(
M=6UI9&ET>2(*;7-G<W1R(")5;6ED861E(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(T.`IM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R(")5
M;6ED861E.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R(")(=6UO<FES=&%S(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DAU;F=R[6$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O075T
M:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")&86QH82!A;R!C
M<FEA<B!C86EX82!P;W-T86P@24U!4#H@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")&86QH82!A;R!E>&-L=6ER
M(&-A:7AA('!O<W1A;"!)34%0.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T
M82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(D9A;&AA(&%O(&-R:6%R
M('%U;W1A(&1A(&-A:7AA('!O<W1A;"!)34%0.B`E<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`B16YD97)EYV\@25`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S
M:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D5N9&5R9>=O($E0(&[C;R!D:7-P;V[M=F5L+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z.#D*;7-G:60@(DE0($%D9')E
M<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN(@IM<V=S='(@(D5N
M9&5R9>=O($E0(&[C;R!E<W3A(&YO(&)L;V-O('!E<FUI=&ED;R!#2412+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-0IM<V=I9"`B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")6
M:6]L8>?C;R!D;R!B;&]Q=65I;R!)4"XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E
M<G0@4F]W($)E9F]R92(*;7-G<W1R("))7VYS:7)A($QI;FAA($%N=&5S(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD(@IM<V=S='(@(DES;.)N9&EA
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,`IM<V=I9"`B26-O;G,@
M3VYL>2(*;7-G<W1R(")3;VUE;G1E(,UC;VYE<R(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("))8V]N<R!F;W(@
M)7,B"FUS9W-T<B`BS6-O;F5S('!A<F$@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
MS6-O;F5S(&4@=&5X=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3DS
M"FUS9VED("))9&5N=&ET>2=S(&YA;64Z(@IM<V=S='(@(DYO;64@9&$@:61E
M;G1I9&%D93HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L
M87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W
M+B(*;7-G<W1R(")392!NXV\@9F]R(&5X:6)I9&\@8V]R<F5T86UE;G1E+"`E
M<R!P87)A(&%B<NTM;&\@96T@=6UA(&YO=F$@:F%N96QA+B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT-3D*;7-G:60@(B(*(DEF('EO=2!D;VXG="!S
M964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y
M(&YE960@=&\@8VAE8VL@(@HB=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2XB"FUS9W-T<B`B(@HB4V4@=F]CZB!NXV\@=NH@;F5N:'5M
M(.UC;VYE(&%O('5T:6QI>F%R(&\@26YT97)N970@17AP;&]R97(L('9O8^H@
M<&]D92`B"B)C:&5C87(@97-T82!C86EX82!P87)A(&1E<V%B:6QI=&%R(&$@
M=')A;G-P87+J;F-I82!03D<N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C$W,@IM<V=I9"`B(@HB268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E("(*(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M(@IM<V=S='(@(B(*(E-E('9O8^H@=NH@97-T82!M96YS86=E;2!M87,@;N-O
M(&$@:6UA9V5M+"!A(&EM86=E;2!Q=64@=F]CZB!Q=65R(&5N=FEA<B!NXV\@
M(@HB<&]D92!S97(@97AI8FED82!P96QO('-E=2!N879E9V%D;W(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(X"FUS9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R(")0<NDM=FES
M=6%L:7IAY^-O(&1A($EM86=E;3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB
M"FUS9W-T<B`B55),(&1A($EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA
M9V4@55),.B(*;7-G<W1R(")54DP@9&$@26UA9V5M.B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM
M<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM86=E;2!D82!G
M86QE<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ
M(@IM<V=S='(@(DEM86=E;2!D82!G86QE<FEA.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(DEM86=E('5P;&]A9"(*;7-G<W1R
M(")%;G9I;R!D92!);6%G96TB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M-PIM<V=I9"`B26UA9V5S(@IM<V=S='(@(DEM86=E;G,B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N
M:6YC.C<*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T
M97,O9&%T82]C<W9I;F9O+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R="P@4W1E<"`E9"(*;7-G<W1R("));7!O<G1A<BP@4&%S<V\@)60B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T
M"FUS9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`B0V%M<&\@:6UP
M;W)T861O.B`E<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*
M;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B0V%M<&]S(&EM<&]R
M=&%D;W,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C,P"FUS9VED("));E]S97)T(%)O=R!!9G1E<B(*;7-G
M<W1R("));E]S97)I<B!,:6YH82!!</-S(@H*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED("));F-O<G)E8W0@86-T
M:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D/S9&EG;R!D92!AY^-O(&9O<FYE
M8VED;R!E<W3A(&EN8V]R<F5T;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,@IM<V=I9"`B26YC;W)R96-T('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"XB"FUS9W-T<B`B57-UX7)I;R!E+V]U
M('-E;FAA(&EN8V]R<F5T;W,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R
M9"YP:'`Z-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E
M<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T
M<B`B(@HB57-UX7)I;R!O=2!E;F1E<F7G;R!A;'1E<FYA=&EV;R!I;F-O<G)E
M=&]S+B!496YT92!N;W9A;65N=&4@;W4@96YT<F4@96T@(@HB8V]N=&%T;R!C
M;VT@;R!A9&UI;FES=')A9&]R('-E('9O8^H@;F5C97-S:71A(&1E(&UA:7,@
M86IU9&$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(D%U;65N
M=&%R($ED96YT8>?C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B26YD:6$B"FUS
M9W-T<B`BS6YD:6$B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD
M:79I9'5A;"!5<V5R<R(*;7-G<W1R(")5<W7A<FEO<R!I;F1I=FED=6%I<R(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA(@IM<V=S='(@(DEN9&]N
MZ7-I82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M8>?C;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-3D*;7-G:60@(DEN9F]R;6%T:6]N
M(@IM<V=S='(@(DEN9F]R;6'GXV\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S$Y"FUS9VED("));F9O<FUA=&EO;B!N;R!L;VYG97(@879A
M:6QA8FQE+B(*;7-G<W1R(").XV\@97AI<W1E;2!O<.?U97,@9&ES<&]N[79E
M:7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G
M<W1R("));G-E<FER($-?;VQU;F$@07#S<R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,`IM<V=I9"`B
M26YS97)T($EM86=E(@IM<V=S='(@(DEN<V5R:7(@26UA9V5M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,`IM<V=I9"`B
M26YS97)T(%1A8FQE(@IM<V=S='(@(DEN<V5R:7(@5&%B96QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B
M26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN<V5R:7(@3&EN:R!D82!796(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R
M("));G-E<FER(%]#;VQU;F$@06YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN<V5R
M="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@
M(DEN<V5R:7(@=6UA(&YO=F$@8V]L=6YA(&%P\W,@82!A='5A;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(DEN<V5R:7(@=6UA(&YO=F$@8V]L=6YA(&%N=&5S
M(&1A(&%T=6%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C8R"FUS9VED("));G-E<G0@82!N97<@<F]W(&%F
M=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));G-E<FER('5M82!N;W9A
M(&QI;FAA(&%P\W,@82!A='5A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN<V5R
M:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@9&$@871U86PB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G
M:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(DEN<V5R:7(@=6T@<&%RX6=R869O(&%P\W,@;R!A='5A;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHV.0IM<V=I9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN<V5R:7(@=6T@<&%RX6=R869O(&%N
M=&5S(&1O(&%T=6%L(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G
M:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YS97)I
M<B!U;2!M;V1E;&\@86QT97)N871I=F\B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C0R"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W
M:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T
M<B`B1F]R;F7G82!U;2!E;F1E<F7G;R!D92!E+6UA:6P@;F\@<75A;"!V;V/J
M('!O9&4@<F5C96)E<B!A(&YO=F$@<V5N:&$Z(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I9"`B26YS
M97)T(&-E;&P@869T97(B"FUS9W-T<B`B26YS97)I<B!CZ6QU;&$@87#S<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));G-E
M<FER(&/I;'5L82!A;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU;6X@
M869T97(B"FUS9W-T<B`B26YS97)I<B!C;VQU;F$@87#S<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(DEN<V5R:7(@8V]L
M=6YA(&%N=&5S(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("));G-E
M<FER(&UE;G-A9V5N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!A9G1E<B(*;7-G<W1R("));G-E<FER('!A<N%G<F%F;R!A</-S(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0T"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("))
M;G-E<FER('!A<N%G<F%F;R!A;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!R
M;W<@869T97(B"FUS9W-T<B`B26YS97)I<B!L:6YH82!A</-S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM
M<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B26YS97)I<B!L:6YH
M82!A;G1E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S,*;7-G:60@
M(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CHB"FUS9W-T<B`B1F]R;F7G82!A(')E<W!O<W1A(&]B<FEG873S
M<FEA('!A<F$@82!P97)G=6YT82!D92!S96=U<F%NYV$Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-@IM<V=I9"`B26YS
M97)T+TUO9&EF>2!);6%G92(*;7-G<W1R("));G-E<FER+T%L=&5R87(@26UA
M9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DEN<V5R
M:7(O06QT97)A<B!,:6YK(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(D-RZ61I=&\@:6YS=69I8VEE;G1E('!A<F$@96YV:6%R('!A<F$@82!L:7-T
M82!D92!D:7-T<FEB=6GGXV\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C
M<F5D:70N(@IM<V=S='(@(D-RZ61I=&\@:6YS=69I8VEE;G1E+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-SD*;7-G:60@(DEN=&5G97(B"FUS
M9W-T<B`B3OIM97)O($EN=&5I<F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B3&ES=&$@
M9&4@26YT96ER;W,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN(@IM<V=S='(@(D-$52`H0V%B9>=A;&AO(&1E($1A9&]S
M(&1E(%5S=>%R:6\I(&EN=N%L:61O+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$V-PHC.B!F<F%M97=O<FLO0V]M<')E<W,O
M0V]M<')E<W,O>FEP+G!H<#HQ.30*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+WII<"YP:'`Z,C$R"FUS9VED("));G9A;&ED(%I)4"!D871A(@IM
M<V=S='(@(D1A9&]S(%I)4"!I;G;A;&ED;W,B"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G
M<W1R(")!<&QI8V'GXV\@:6YVX6QI9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED
M(&)A=&-H($E$+B(*;7-G<W1R("))9&5N=&EF:6-AY^-O(&1O(&)A=&-H(&EN
M=N%L:61A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$V,@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,C,V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,#,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HS-PIM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B1&%D;W,@96YV
M:6%D;W,@<^-O(&EN=N%L:61O<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S
M=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`B16YD97)EYV\@9&4@9&5S=&EN
M;R#I(&EN=N%L:61O+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S
M<R]D8G@N<&AP.C$P.0HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9&)X+G!H<#HQ,SD*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z,C0Q"FUS9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@
M(D9O<FUA=&\@9&\@87)Q=6EV;R#I(&EN=N%L:61O(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$V-0IM<V=I9"`B26YV86QI9"!L:6-E;G-E
M(&ME>2XB"FUS9W-T<B`B3OIM97)O(&1E(&QI8V5NYV$@:6YVX6QI9&\N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U.0IM<V=I9"`B26YV
M86QI9"!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B3&]C86QI>F'GXV\@
M9F]R;F5C:61A(.D@:6YVX6QI9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A;&ED(&US
M9U]T>7!E+B(*;7-G<W1R(")4:7!O(&1A(&UE;G-A9V5M(.D@:6YVX6QI9&\N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`S"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+B(*;7-G
M<W1R(")!<&E?:60@Z2!I;G;A;&ED;R!O=2!E<W3A(&9A;'1A;F1O+B(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M-@IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S
M='(@(E!A<N)M971R;W,@:6YVX6QI9&]S(&]U(&9A;'1A;F1O+B(*"B,Z(&%D
M;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HR-PIM<V=I9"`B26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B4&5R;6ES<_5E<R!D;R!P86D@<^-O
M(&EN=N%L:61A<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38Q"FUS9VED("));G9A;&ED('!A<G1N97(@:60N(@IM<V=S='(@(E!E<FUI
M<W/U97,@9&\@<&%I('/C;R!I;G;A;&ED87,N(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$V,PIM<V=I9"`B26YV86QI9"!P<F]D=6-T(&-O
M9&4N(@IM<V=S='(@(D/S9&EG;R!D;R!P<F]D=71O(.D@:6YVX6QI9&\N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T;V-O
M;&\@:6YVX6QI9&\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HY,PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C<Q(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP
M:'`Z.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26YV86QI9"!R96-I<&EE;G0Z
M(%PB)7-<(B(*;7-G<W1R(")$97-T:6YA=.%R:6\@:6YVX6QI9&\Z("<E<R<B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P-S4@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HQ,C4X"FUS9VED("));G9A;&ED('-H87)E(&]B
M:F5C="(*;7-G<W1R(")/8FIE=&\@8V]M<&%R=&EL:&%D;R!I;G;A;&ED;R(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P,0IM<V=I9"`B26YV86QI9"!S;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B
M1F]N=&4@9&\@96YD97)EYV\@:6YVX6QI9&$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED("));G9A
M;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B1&%D;W,@=6YI8V]D92!I;G;A
M;&ED;W,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U.0IM<V=I
M9"`B26YV96YT;W)Y(@IM<V=S='(@(DEN=F5N=.%R:6\B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<V"FUS9VED("));G9E
M<G0@<V5L96-T:6]N(@IM<V=S='(@(DEN=F5R=&5R('-E;&7GXV\B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#(*;7-G:60@(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B"FUS
M9W-T<B`B27+C+"!297#Z8FQI8V$@27-LXFUI8V$@9&\B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*;7-G:60@(DER87$B"FUS9W-T<B`B27)A<75E(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED("))<F5L86YD(@IM<V=S='(@(DER;&%N9&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-0IM<V=I9"`B27-L92!O9B!-86XB"FUS
M9W-T<B`B26QH82!D;R!(;VUE;2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*
M;7-G<W1R(")496UP97-T861E<R!)<V]L861A<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B27-R865L(@IM<V=S='(@(DES<F%E;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C(V"FUS9VED("))<W-U97(B"FUS9W-T
M<B`B16UI<W-O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC(@IM<V=S='(@(DETX6QI8V\B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z.#(*;7-G:60@(DET86QY(@IM<V=S='(@(DETX6QI82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,@IM<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6-A(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,`HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,X"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G
M:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N96ER;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2F%P86XB"FUS9W-T<B`B2F%PXV\B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X-@IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G
M<W1R(")*87!O;NIS("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E
M>2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(DIO<F3B
M;FEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0P-@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S$*;7-G:60@(DIU;'DB"FUS9W-T<B`B2G5L:&\B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R(")*=6YH;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,S@*;7-G:60@(DIU<W1I9GDB"FUS9W-T<B`B2G5S
M=&EF:6-A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R
M(")!;&EN:&%R(&%O($-E;G1R;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U
M;&PB"FUS9W-T<B`B2G5S=&EF:6-A<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`B06QI;FAA<B#@($5S<75E<F1A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G
M:60@(DIU<W1I9GD@4FEG:'0B"FUS9W-T<B`B06QI;FAA<B#@($1I<F5I=&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B0V%Z
M87%U:7-TXV\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C8S"FUS9VED(")+965P(&]R:6=I;F%L/R(*;7-G<W1R(")-86YT
M97(@;R!O<FEG:6YA;#\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM
M<V=S='(@(E%UZFYI82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP
M:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B4V5R=FED;W(@:V5R8F5R;W,@<F5J96ET;W4@
M82!A=71E;G1I8V'GXV\N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R
M"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G<W1R(").;W9A=&]S(&1E($ME
M<FYE;"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,0IM
M<V=I9"`B2V5Y($-R96%T:6]N(@IM<V=S='(@(D-R:6'GXV\@9&4@0VAA=F4B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30*;7-G:60@
M(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("));7!R97-SXV\@1&EG:71A;"!D
M82!#:&%V92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")486UA;FAO(&1A($-H879E
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"FUS9VED
M(")+97D@5'EP92(*;7-G<W1R(")4:7!O(&1A($-H879E(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3D*;7-G:60@(DME>2!5<V%G
M92(*;7-G<W1R(")5<V\@9&$@0VAA=F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B0VAA=F4@:N$@97AI
M<W1E(&YO('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B0W)I
M86[G87,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(DMI<FEB871I(@IM<V=S='(@
M(DMI<FEB871I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S(@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R
M871I8R!096]P;&4G<R!297!U8FQI8R!O9B(*;7-G<W1R(")#;W+I:6$L(%)E
M</IB;&EC82!0;W!U;&%R($1E;6]C<N%T:6-A(&1A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`B0V]RZ6EA+"!2
M97#Z8FQI8V$@9&$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@(D-O<F5A;F\@*$550RU+4BDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I="(*;7-G<W1R(")+=7=A:70B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DMY<F=Y>G-T86XB"FUS9W-T<B`B475I
M<F=U:7-TXV\B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G
M:60@(DQA7WEO=70B"FUS9W-T<B`B3&%?>6]U="(*"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z.#,*;7-G:60@(DQA;F=U86=E(@IM<V=S='(@(DED
M:6]M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B3&%O(%)E</IB;&EC82!$96UO8W+A
M=&EC82!0;W!U;&%R(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I
M9"`B3&%S="!(86QF(@IM<V=S='(@(MIL=&EM82!-971A9&4B"@HC.B!L:6(O
M0FQO8VLO86-C;W5N="YP:'`Z-S8*;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA
M;F=E(@IM<V=S='(@(D=E<F%R($YO=F$@4V5N:&$B"@HC.B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.#8@;&EB+T)L;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T
M(%%U87)T97(B"FUS9W-T<B`BVFQT:6UO(%%U87)T;R(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34X"FUS9VED("),87-T(%5P9&%T960Z(@IM<V=S='(@
M(MIL=&EM82!!='5A;&EZ8>?C;SHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B
M"FUS9W-T<B`BVFQT:6UO(&QO9VEN.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T(&QO9VEN
M.B`E<R!F<F]M("5S(@IM<V=S='(@(MIL=&EM;R!L;V=I;CH@)7,@X"!P87)T
M:7(@9&4@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,30*;7-G
M:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(MIL=&EM;R!L;V=I;CH@
M3G5N8V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQA='9I82(*;7-G<W1R("),
M973T;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0T"FUS9VED("),
M87<B"FUS9W-T<B`B3&5I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T<B`B
M3&%Y;W5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G
M<W1R(")$96EX82!V87II;R!S92!Q=6ES97(@<V5M(&)O<F1A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DSM8F%N;R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM
M<V=I9"`B3&5F="(*;7-G<W1R(")%<W%U97)D82(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,#@*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@
M(D-A8F7G86QH;R!E<W%U97)D;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,Q,#0*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E9A;&]R97,@
M9&$@97-Q=65R9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS
M9W-T<B`B3&5S;W1O(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z
M,C4U"FUS9VED("),979E;"(*;7-G<W1R(")!;6]R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X
M"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8NER:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B3.UB
M:6$@P7)A8F4@2F%M86AI<FEY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE
M8VAT96YS=&5I;B(*;7-G<W1R("),:65C:'1E;G-T96EN(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT
M($1R:7IZ;&4B"FUS9W-T<B`B0VAI=FES8V]&<F%C;R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!2
M86EN(@IM<V=S='(@(D-H=79A($9R86-A(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C<*;7-G:60@(DQI9VAT(%)A:6X@16%R
M;'DB"FUS9W-T<B`B0VAU=F$@1G)A8V$@36%T=71I;F$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@
M4F%I;B!,871E(@IM<V=S='(@(D-H=79A($9R86-A(%9E<W!E<G1I;F$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I
M9"`B3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B3&5V97,@4&%N8V%D87,@
M9&4@0VAU=F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HS,`IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T
M<B`B0VAU=F%S($9R86-A<R!C;VT@5')O=O5E<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W
M(@IM<V=S='(@(DYE=F4@1G)A8V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HS,@IM<V=I9"`B3&EG:'0@4VYO=R!3:&]W97(B
M"FUS9W-T<B`B0G)E=F4@3F5V87-C82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`B4&_J;6%S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G
M<W1R("),:6YK(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS
M9W-T<B`B3&EN:R!A<&]N=&$@<&%R83HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#<Y"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(DQI
M9V%R(&\@96YD97)EYV\@9&4@92UM86EL(.`@<.%G:6YA(&1E(&-O;7!O<VGG
MXV\@86\@97AI8FER(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]H=&UL,G1E>'0N<&AP.C$X,@IM<V=I9"`B3&EN:W,B"FUS9W-T<B`B3&EN
M:W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X
M($-O;VMI92(*;7-G<W1R(")#;V]K:64@9&\@3&EN=7@B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M
M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S='(@(DQI<W1A<B`M('5S
M=>%R:6\@<&]D92!V97(@82!P87-T82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HQ,S,*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(DQI<W1A<B!"
M86YC;W,@9&4@1&%D;W,B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU
M,0IM<V=I9"`B3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("),:7-T87(@5/-P
M:6-O<R!D92!!:G5D82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G
M:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQI<W1A<B!486)E;&%S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.30*;7-G:60@(DQI
M<W0M07)C:&EV92(*;7-G<W1R("),:7-T+4%R8VAI=F4B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP
M(@IM<V=S='(@(DQI<W0M2&5L<"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DQI<W0M
M260B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@IM
M<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M
M4&]S="(*;7-G<W1R("),:7-T+5!O<W0B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y,0IM<V=I9"`B3&ES="U3=6)S8W)I8F4B"FUS
M9W-T<B`B3&ES="U3=6)S8W)I8F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U8G-C<FEB92(*;7-G
M<W1R("),:7-T+55N<W5B<V-R:6)E(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@<V5S<VEO;G,@9F%I
M;&5D.B`E<R(*;7-G<W1R(")!(&QI<W1A9V5M(&1E('-E<W/U97,@9F%L:&]U
M.B`E<R(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("),:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`B02!L
M:7-T86=E;2!D92!U<W7A<FEO<R!F86QH;W4Z("5S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),:7-T86=E;2!D92!U<W7A<FEO<R!E
M<W3A(&1E<V%B:6QI=&%D82XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B3&ET97)A='5R82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(DQI='7B;FEA
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6UA9V5S+G!H<#HW
M-PIM<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R(")#87)R96=A;F1O+BXN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B3&]C
M86P@=&EM93H@(@IM<V=S='(@(DAO<F$@;&]C86PZ("(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-@IM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S
M='(@(DQO8V%L:7IAY^-O(&4@2&]R82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3<R(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HU-PHC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HW,@IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B4F5G:>-O(@H*
M(SH@;&]G:6XN<&AP.C$X.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,C`P('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN
M8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(D-O;F5C=&%R(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C0U"FUS9VED("),;V<@;V8@<')E
M=FEO=7,@<WEN8R!S97-S:6]N(@IM<V=S='(@(DQO9R!D82!S97-SXV\@9&4@
M<VEN8W)O;FEZ8>?C;R!A;G1E<FEO<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ.30*;7-G:60@(DQO9R!O=70B"FUS9W-T<B`B1&5S8V]N
M96-T87(B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-3D*;7-G:60@(DQO
M9VEN(@IM<V=S='(@(D-O;F5C=&%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Q,`IM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&%R969A<R!D
M92!#;VYE>.-O(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DU"FUS
M9VED("),;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R(")/(&QO
M9VEN(&9A;&AO=2!P;W)Q=64@<V5U('5S=>%R:6\@;W4@<V5N:&$@97-T879A
M(&EN8V]R<F5T82XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY.3$*
M;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B1F%L:&$@9&4@3&]G:6XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N
M9R!T97AT(@IM<V=S='(@(E1E>'1O(&QO;F=O(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0X"FUS9VED("),;W9E(@IM<V=S='(@(D%M;W(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B
M3&]W(@IM<V=S='(@(D)A:7AA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E
M96L@;&5T=&5R<R(*;7-G<W1R(")!;&9A8F5T;R!G<F5G;R!E;2!M:6[Z<V-U
M;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$Y"FUS9VED("),;W=E<B!L871I;B!L971T97)S(@IM<V=S
M='(@(D%L9F%B971O(&QA=&EN;R!E;2!M:6[Z<V-U;&\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS
M9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(D[Z;65R;W,@<F]M
M86YO<R!E;2!M:6[Z<V-U;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G;R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.3D*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0S-R!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-@IM<V=I
M9"`B35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G
M<W1R(")/(&%N97AO($U3+51.148@;N-O(&-O;G3I;2!D861O<RXB"@HC.B!F
M<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M
M;V)I;&4N<&AP.C,W"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D;VYI82P@06YT:6=A(%)E</IB;&EC
M82!)=6=O<VSA=FEA(&1A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S
M8V%R(@IM<V=S='(@(DUA9&%G87-C87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#D*;7-G:60@(DUA9VEC(@IM<V=S='(@(DWA9VEC;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R
M(")#;W)R96EO(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R-`IM
M<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')A9&]R(&1O($-O
M<G)E:6\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#$*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B
M0W)I87(@;&EN7VLN+BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&%W:2(*
M;7-G<W1R(")-86QA=VDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUA;&%Y<VEA
M(@IM<V=S='(@(DUA;.%S:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;&1I
M=F5S(@IM<V=S='(@(DUA;&1I=F%S(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-
M86QI(@IM<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A
M(@IM<V=S='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDT
M"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@
M:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C
M:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R(")'97)E;F-I
M82!A(&QI<W1A(&1E(&-A=&5G;W)I87,@92!A<R!C;W)E<R!A<W-O8VEA9&%S
M(&$@96QA<RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$U-`IM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<&5A;65N
M=&\@36%P,C0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`X-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3$V.0IM<V=I9"`B36%P475E<W0@;6%P(@IM<V=S='(@(DUA<&5A
M;65N=&\@36%P475E<W0B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HQ,#4*;7-G:60@(DUA<'!I;F=S('-T;W)E9"XB"FUS9W-T<B`B36%P96%M
M96YT;W,@9W)A=F%D;W,N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(DUA<N=O(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT,0IM<V=I9"`B36%R9VEN(@IM<V=S='(@(DUA<F=E;2(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B36%R8V%R(&-O;2!F
M;&%G<R!,:61A+T[C;R!,:61A(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I(@IM<V=S='(@(DUA<F-A<B!C
M;VT@;W5T<F]S(&9L86=S("AE>"X@26UP;W)T86YT92]297-P;VYD:61A*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L86YD<R(*;7-G<W1R
M("));&AA<R!-87)S:&%L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R=&EN
M:7%U92(*;7-G<W1R(")-87)T:6YI8V$B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@
M(D-A;7!O<R!C;W)R97-P;VYD96YT97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$T-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@
M(DUA=7)I=&%N:6$B"FUS9W-T<B`B36%U<FETXFYI82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%U<FET:75S(@IM<V=S='(@(DUA=7+M8VEO(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$U"FUS
M9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S='(@(D-RZ61I=&\@;>%X
M:6UO('!E<FUI=&ED;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#@*;7-G:60@(DUA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+B(*;7-G<W1R(").^FUE<F\@;>%X:6UO(&1E('!A<G1E<R!D
M82!M96YS86=E;2!E>&-E9&5U+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S$S"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B
M5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S.B`B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-0IM<V=I9"`B36%X('1E;7`@;&%S
M="`V(&AO=7)S.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>%X:6UA(&YA<R#Z
M;'1I;6%S(#8@:&]R87,Z("(*"B,Z(&QI8B]A<&DN<&AP.C@V"FUS9VED(")-
M87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS(@IM<V=S='(@(D[Z;65R
M;R!-X7AI;6\@9&4@0FQO8V]S(&1E(%!O<G1A;"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.CDP,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C(Q
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-#,*;7-G:60@(DUA>&EM
M=6T@;&5N9W1H(@IM<V=S='(@(E1A;6%N:&\@;>%X:6UO(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P-`HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*
M;7-G<W1R(")-86EO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*
M;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P
M"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8VEN82(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B
M"FUS9W-T<B`B365M8G)O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B36]D;R!D;R!M96YU.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(DUE<V-L87(@8^EL
M=6QA<R(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE;G-A9V5M
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G
M:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@
M<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D
M+B(*;7-G<W1R("(B"B)-96YS86=E;2!697)I9FEC861A(&-O;2!3=6-E<W-O
M(&UA<R!O(&-E<G1I9FEC861O(&1O(&%S<VEN86YT92!NXV\@</1D92!S97(@
M(@HB=F5R:69I8V%D;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP:7)E9"XB
M"FUS9W-T<B`B365N<V%G96T@97AP:7)A9&$N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V,`IM
M<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@;65N<V%G96TB
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E871H
M97(B"FUS9W-T<B`B0VQI;6$@365T87(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")";&]C;R!-971A<B!NXV\@9&ES<&]N[79E;"XB"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$Q.0IM<V=I9"`B(@HB365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB0FQO8V\@365T87(@;N-O(&1I<W!O
M;NUV96PN($1E=&%L:&5S(&9O<F%M(&=R879A9&]S(&5M(&QO9R!P87)A(&\@
M(@HB861M:6YI<W1R861O<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,34S"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM
M<V=S='(@(D\@365T87)$0B!NXV\@97-TX2!C;VYE8W1A9&\N(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<T"FUS9VED(")-971H;V0B"FUS
M9W-T<B`B3>ET;V1O(@H*(SH@9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H
M<#HX,2!F<F%M97=O<FLO4E!#+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G
M<W1R(")-Z71O9&\@)R5S)R!NXV\@97-TX2!D969I;FED;R(*"B,Z(&9R86UE
M=V]R:R]24$,O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T
M<B`B3>ET;V1O(&[C;R!D969I;FED;RX@3>ET;V1O(&-H86UA9&\Z("5S(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8W(&QI8B]";&]C:R]M
M971A<BYP:'`Z.#(*;7-G:60@(DUE=')I8R(*;7-G<W1R(")-Z71R:6-A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDU"FUS9VED(")-97AI8V\B"FUS9W-T<B`B3>EX:6-O(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T
M97,@;V8B"FUS9W-T<B`B36EC<F]NZ7-I82P@17-T861O<R!&961E<F%D;W,@
M9&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z-S8*;7-G:60@(DUI9&1L92(*;7-G<W1R(")-96EO(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DUI
M;64@5'EP92(*;7-G<W1R(")4:7!O($UI;64B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM
M<V=S='(@(E1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A
M<SH@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#D*;7-G:60@(DUI;B!T
M96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WM;FEM
M82!N87,@^FQT:6UA<R`V(&AO<F%S.B`B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R("))9&%D92!M[6YI;6$@9&$@
M<V5N:&$@86EN9&$@;N-O(&5X<&ER;W4B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,S"FUS9VED(")-:7)R;W(B"FUS9W-T
M<B`B17-P96QH;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM<V=I
M9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")$:79E<G-O<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM<V=I
M9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R
M(")086-O=&4@4$5!4B!(5%107U)E<75E<W0@9F%L=&%N9&\N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$Q-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF
M:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U
M('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*
M(D-O;F9I9W5R8>?C;R!F86QT86YD;RX@5F]CZB!T96T@<75E(&=E<F%R(&5L
M82!A9V]R82!S92!V;V/J('%U97(@=71I;&EZ87(@(@HB97-T82!A<&QI8V'G
MXV\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`T"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N(@IM<V=S='(@
M(DE$(&1A(&UE;G-A9V5M(&9A;'1A;F1O+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S
M:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")086-O
M=&4@;V)R:6=A=/-R:6\@4$5!4B!-86EL(&9A;'1A;F1O+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("))1"!D82!S97-SXV\@
M9F%L=&%N9&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`B4V5G(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G
M<W1R(")#;W)R96EO($WS=F5L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-CD*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(DUO
M9&5R87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C8V(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-0IM<V=I9"`B
M36]D:69I960@1&%T92(*;7-G<W1R(")$871A($UO9&EF:6-A9&$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B06QT97)A<B!54DPB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8W-`IM<V=I9"`B
M36]D=6QU<R(*;7-G<W1R(")-\V1U;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@
M(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO;&1O=F$L(%)E</IB
M;&EC82!D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36]N86-O(@IM<V=S='(@
M(DWT;F%C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34V(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B36]N9V]L:6$B"FUS9W-T
M<B`B36]N9_-L:6$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3@X
M"FUS9VED(")-;VYT:"!A;F0@>65A<B(*;7-G<W1R(")-ZG,@92!A;F\B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4W"FUS
M9VED(")-;VYT:&QY(@IM<V=S='(@(DUE;G-A;&UE;G1E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-;VYT<V5R<F%T(@IM<V=S='(@(DUO;G1S97)R870B"@HC
M.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*
M;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S='(@(D9A<V5S(&1A($QU82(*"B,Z
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$Y-B!F<F%M97=O<FLO1FEL
M95]#4U8O0U-6+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F
M:65L9',@9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB
M"FUS9W-T<B`B36%I<R!C86UP;W,@96YC;VYT<F%D;W,@;F$@;&EN:&$@)60@
M<75E(&\@;OIM97)O(&5S<&5R861O("5D+B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B36]R;V-C;R(*;7-G<W1R(")-87)R;V-O<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T;'D@0VQE
M87(B"FUS9W-T<B`B1W)A;F1E(%!A<G1E($QI;7!A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L>2!#
M;&]U9'DB"FUS9W-T<B`B1W)A;F1E(%!A<G1E($YU8FQA9&\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(D=R86YD92!087)T92!%;G-O;&%R861O(@H*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV
M-#@*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")-;W9E<B!!8F%I>&\B"@HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8U
M,@IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(DUO=F5R(.`@17-Q=65R9&$B
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP
M.C8U-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")-;W9E<B#@($1I<F5I
M=&$B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")-;W9E<B!!8VEM82(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*
M;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")!8F%I>&\B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,C0*;7-G:60@(DUO=F4@
M=7`B"FUS9W-T<B`B06-I;6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$V."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO>F%M
M8FEQ=64B"FUS9W-T<B`B36_G86UB:7%U92(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Q.#@*;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:7-T<R(*;7-G<W1R("),:7-T87,@9&4@<V5L9>?C;R!D92!M^FQT:7!L;W,@
M;NUV96ES(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P-38*;7-G:60@(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-87!A
M<R!);F=L97-E<R!-=6QT:6UA<"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(R-#8*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R(")3
M96QEY^-O(&WZ;'1I<&QA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0P,@IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")-:6YH82!#;VYT82(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR.`IM<V=I9"`B37D@06-C;W5N
M="!);F9O<FUA=&EO;B(*;7-G<W1R(")3=6%S($EN9F]R;6'G]65S(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HT-0IM<V=I9"`B37D@4&]R=&%L
M(@IM<V=S='(@(DUE=2!0;W)T86PB"@HC.B!S97)V:6-E<R]P;W)T86PO961I
M="YP:'`Z-#,*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B365U
M($QA>6]U="!D92!0;W)T86PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM
M87(B"FUS9W-T<B`B0FER;>)N:6$B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HU-PIM<V=I9"`B3D\L($D@1&\@3D]4($%G
M<F5E(@IM<V=S='(@(D[#3RP@174@3L-/($-O;F-O<F1O(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`B3F]M
M92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R(").86WM
M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").875R=2(*;7-G<W1R(").875R
M=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F5P86PB"FUS9W-T<B`B3F5P86PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DAO
M;&%N9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL
M97,B"FUS9W-T<B`B06YT:6QH87,@2&]L86YD97-A<R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").971S8V%P92!"
M87-E(%523"(*;7-G<W1R(")54DP@0F%S92!D;R!.971S8V%P92(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S
M8V%P92!#02!2979O8V%T:6]N(%523"(*;7-G<W1R(")54DP@9&4@4F5V;V=A
MY^-O(&1E($-!(&1O($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#8*;7-G:60@(DYE='-C87!E($-!('!O;&EC>2!5
M4DPB"FUS9W-T<B`B55),(&1E('!O;.UT:6-A<R!D92!#02!D;R!.971S8V%P
M92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS
M9VED(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(")54DP@9&4@4F5N
M;W9AY^-O(&1O($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@55),
M(@IM<V=S='(@(E523"!D92!2979O9V'GXV\@9&\@3F5T<V-A<&4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B3F5T
M<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYO;64@9&\@<V5R=FED
M;W(@4U-,(&1O($YE='-C87!E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.#@*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O
M;6UE;G0B"FUS9W-T<B`B0V]M96YTX7)I;R!D;R!C97)T:69I8V%D;R!D;R!.
M971S8V%P92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@
M(E1I<&\@9&4@8V5R=&EF:6-A9&\@9&\@3F5T<V-A<&4B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@
M(E)E9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S.0HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,SDP"FUS9VED(").979E<B(*;7-G<W1R(").=6YC82(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D;VYI82(*;7-G<W1R(").;W9A($-A
M;&5D]&YI82(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T96=O<GDB"FUS9W-T<B`B3F]V
M82!#871E9V]R:6$B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]E;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT
M97(O96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`Z,3`Q"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!-
M97-S86=E('1O("5S(@IM<V=S='(@(DYO=F$@365N<V%G96T@<&%R82`E<R(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W-`IM<V=I9"`B3F5W($UO;VXB"FUS
M9W-T<B`B3'5A($YO=F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G
M<W1R(").;W9O(%5S=>%R:6\@*&]P8VEO;F%L*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM
M<V=I9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B3F]V82!:96SB;F1I82(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A
M<W-W;W)D(@IM<V=S='(@(DYO=F$@<V5N:&$B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*;7-G:60@(DYE=R!P
M87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T<B`B3F]V82!S96YH
M82!E>'!I<F%RX2!E;2`E>"XB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z-3(*;7-G:60@(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM
M<V=S='(@(D%S(&YO=F%S('-E;FAA<R!NXV\@<^-O(&EG=6%I<RXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED
M(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(DYO=F$@:F%N96QA("A?
M8FQA;FLI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M.3$*;7-G:60@(DYE=W,B"FUS9W-T<B`B3F]T[6-I87,B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").97=S9W)O=7!S(@IM<V=S
M='(@(D=R=7!O<R!D92!.;W3M8VEA<R(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$U('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3(Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C(U"FUS9VED(").97AT(@IM<V=S='(@(E!R\WAI;6$B
M"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C<*;7-G:60@(DYE>'0@-"!0:&%S
M97,B"FUS9W-T<B`B4'+S>&EM87,@-"!&87-E<R(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]522YP:'`Z,S8V(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,S<P"FUS9VED(").97AT(&]P=&EO;G,B"FUS9W-T<B`B4'+S>&EM
M87,@;W#G]65S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,*
M;7-G:60@(DYE>'0^(@IM<V=S='(@(E!R\WAI;6$^(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDV
M"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B3FEC87+A9W5A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6?I<FEA(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.0IM<V=I9"`B3FEG:'0B"FUS
M9W-T<B`B3F]I=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T
M<B`B3FEU92(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY-C0*;7-G:60@(DYO(@IM<V=S='(@(D[C;R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB
M"FUS9W-T<B`B3F5N:'5M(&1A9&\@9&4@8V]N9FEG=7)AY^-O(&1I<W!O;NUV
M96P@<&%R82!E>&EB:7(@87,@9&EF97)E;N=A<RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-@IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B3F5N:'5M82!E<W1R873I9VEA(&1I<W!O;NUV96P@<&%R82!C<FEA<B!I
M;6%G96YS($E33RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*
M;7-G<W1R(").96YH=6T@;6]D96QO(&1E(&)A=&-H+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`Q"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,S@U"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-#`W"FUS
M9VED(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;B(*;7-G<W1R(").96YH=6T@8FQO8V\@97AI<W1E(&YA('!O<VGGXV\@<V]L
M:6-I=&%D82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A;"YP:'`Z-3`*
M;7-G:60@(DYO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DYE;FAU;2!N;VUE(&1E(&%G96YD82!F
M;W)N96-I9&\@<&%R82!A(&%U=&5N=&EC8>?C;R!-0T%,+B(*"B,Z(&%D;6EN
M+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").;R!C:&%N9V4N(@IM<V=S='(@
M(DYE;FAU;6$@86QT97)AY^-O+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D960@
M=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R(").96YH=6T@<W5B;W)D:6YA
M9&\@<&]D92!S97(@861I8VEO;F%D;R!A(&5S=&$@<&5R;6ES<^-O+B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,38Y(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z-3`X"B,Z(&9R86UE=V]R:R]5=&EL+U5T:6PN<&AP.C<V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N(@IM<V=S='(@(DYE;FAU;6$@:6YF
M;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I9FEC861A('!A<F$@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-34*;7-G:60@(DYO
M(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@
M5D93+B(*;7-G<W1R(").96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)A
MY^-O(&5S<&5C:69I8V%D82!P87)A($944"!61E,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV-S(*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(").
M96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C:69I8V%D
M82!P87)A(%-13"!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C<R-0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB"FUS9W-T<B`B3F5N:'5M
M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R
M82!344PM1FEL92!61E,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$T"FUS9VED(").;R!C<F5D:70@;&5F="XB
M"FUS9W-T<B`B3F5N:'5M(&-RZ61I=&\@<F5S=&%N=&4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S0*;7-G:60@
M(DYO(&1E<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R(").96YH=6T@9&5S
M=&EN;R!F;W)N96-I9&\N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.3`S"FUS9VED(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DYE
M;FAU;2!A<G%U:79O(&5N=FEA9&\B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD+B(*;7-G<W1R(").96YH=6T@
M[6-O;F4@96YC;VYT<F%D;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$S,`IM<V=I9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*
M;7-G<W1R(").96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3<*;7-G:60@(DYO(&QO
M8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(").96YH=6UA(&QO8V%L:7IAY^-O
M(&-O;F9I9W5R861A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"FUS9VED(").;R!M97-S86=E('-U<'!L:65D
M+B(*;7-G<W1R(").96YH=6UA(&UE;G-A9V5M(&9O<FYE8VED82XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM
M<V=I9"`B3F\@;F%M92!S<&5C:69I960N(@IM<V=S='(@(DYE;FAU;2!N;VUE
M(&5S<&5C:69I8V%D;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE
M9"XB"FUS9W-T<B`B3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@
M9F]R='5N97,B"FUS9W-T<B`B4V5M('-O<G1E<R!O9F5N<VEV87,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C
M;R!(5%10+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z,3`X
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT
M:6-A=&EO;BXB"FUS9W-T<B`B3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R
M82!A(&%U=&5N=&EC8>?C;R!)34%0+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5N:'5M82!S
M96YH82!F;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!+97)B97)O<RXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%M+G!H<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(").96YH=6UA('-E;FAA
M(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($QO9VEN+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%S<W=D+G!H<#HQ,S4*;7-G:60@(DYO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DYE;FAU;6$@<V5N:&$@9F]R;F5C:61A('!A<F$@82!A=71E;G1I
M8V'GXV\@4$%34U=$+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H
M<#HX-`IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BXB"FUS9W-T<B`B3F5N:'5M82!S96YH82!F;W)N96-I9&$@
M<&%R82!A(&%U=&5N=&EC8>?C;R!334(N(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HQ,C@W"FUS9VED("(B"B).;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*
M;7-G<W1R("(B"B).96YH=6T@<&%T:"!P87)A(&\@8FENX7)I;R!D;R!/<&5N
M4U-,(&9O:2!F;W)N96-I9&\N($\@8FENX7)I;R!D;R!/<&5N4U-,(.D@(@HB
M;F5C97-SX7)I;R!P87)A(&UA;FEP=6QA<B!O<R!D861O<R!02T-3(#$R+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G:60@
M(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B3F5N:'5M(&-A9&%S=')O
M('!E;F1E;G1E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW-C8*;7-G
M:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B475O=&$@;N-O(&-O;F9I9W5R
M861A+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S(@IM<V=S='(@(E-E;2!L:6YH
M87,B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT.#(*;7-G:60@
M(DYO('-E<&%R871O<B!S<&5C:69I960N(@IM<V=S='(@(DYE;FAU;2!S97!A
M<F%D;W(@9F]I(&5S<&5C:69I8V%D;RXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS9VED(").;R!S:61E
M<R(*;7-G<W1R(")396T@;&%D;W,B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M;6(N<&AP.C4X-PIM<V=I9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(D%R<75I
M=F\@:6YE>&ES=&5N=&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3(V"FUS9VED(").;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L
M92!F;W(@8V%C:&4N(@IM<V=S='(@(DYE;FAU;2!D:7)E=/-R:6\@=&5M<&]R
MX7)I;R!D:7-P;V[M=F5L('!A<F$@;R!C86-H92XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S,0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(R,0IM<V=I9"`B3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM<V=S='(@(DYE;FAU;2!U
M<W7A<FEO(&4O;W4@<V5N:&$@9F]R;F5C:61O<RXB"@HC.B!F<F%M97=O<FLO
M4E!#+U)00R]X;6QR<&,N<&AP.C$T,`IM<V=I9"`B3F\@=F%L:60@6$U,(&1A
M=&$@<F5T=7)N960B"FUS9W-T<B`B3F5N:'5M(&1A9&\@6$U,(';A;&ED;R!R
M971O<FYA9&\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z.3<R"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HY.#(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDY,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`Q,`IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(E-E;2!V86QO<F5S
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R
M<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(DYE;FAU;2!V97)SXV\@
M96YC;VYT<F%D82!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN($=E<F4@;F]V
M86UE;G1E(&$@(@HB8V]N9FEG=7)AY^-O+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*(DYE;FAU;6$@=F5R<^-O(&5N8V]N=')A9&$@;F$@<W5A(&-O;F9I
M9W5R8>?C;RX@1V5R92!N;W9A;65N=&4@82!C;VYF:6=U<F'GXV\N(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,PIM<V=I9"`B3F]N
M92(*;7-G<W1R(").96YH=6UA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I9"`B3F]N92`H=7-E(&EM<&QI8VET
M*2(*;7-G<W1R(").96YH=6UA("AU<V\@:6UP;.UC:71O*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@X"FUS9VED(").;W)D:6,@*$E33RTX.#4Y+3$P
M*2(*;7-G<W1R(").\W)D:6-O("A)4T\M.#@U.2TQ,"DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DEL:&$@3F]R9F]L
M:R(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B2&5M
M:7-FZ7)I;R!.;W)T92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($UA<FEA;F$@9&\@3F]R
M=&4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYO<G=A>2(*;7-G<W1R(").;W)U
M96=A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-#$*
M;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(").XV\@07#S<R(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P"FUS9VED(").;W0@0F5F
M;W)E(@IM<V=S='(@(D[C;R!!;G1E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q-0IM<V=I9"`B3F]T(&$@9&ER96-T;W)Y(@IM<V=S='(@
M(D[C;R#I('5M(&1I<F5T\W)I;R(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#0*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.34*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(D[C;R!);7!L96UE
M;G1A9&\N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHV.`IM<V=I9"`B3F]T('-E="(*;7-G<W1R(").XV\@8V]N9FEG=7)A
M9&\B"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L
M97(N<&AP.C$T-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO
M;DAA;F1L97(N<&AP.C$V,`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O
M4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X.0HC.B!F<F%M97=O<FLO4V5S
M<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-B!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,#@@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S-`HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,C4R(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C(X-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S`Q
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,38@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C,S,PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8V(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HT,C8*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP
M.C4P-2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<T"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HU.3$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V.0IM<V=I
M9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3N-O('-U<&]R=&%D;RXB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0T(&-O
M;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#`U"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@(D%N;W1AY_5E<R(*
M"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H<#HS-@IM<V=I9"`B3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S='(@(DYA9&$@<&%R82!E
M>&EB:7(L('9O;'1E+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,3`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A
M;&5N9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(").;W9E;6)R
M;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-3`*;7-G:60@(DYU
M;6)E<B(*;7-G<W1R(").^FUE<F\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(Y"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R
M(").^FUE<F\@9&4@8V%R86-T97)E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-PHC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0Y('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"FUS9VED(").=6UB97(@;V8@8V]L
M=6UN<R(*;7-G<W1R(").^FUE<F\@9&4@8V]L=6YA<R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$S-S$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,30R-0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#0W('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB
M97(@;V8@<F]W<R(*;7-G<W1R(").^FUE<F\@9&4@;&EN:&%S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G
M:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D[Z;65R;R!NXV\@97-P96-I9FEC
M861O('!A<F$@871U86QI>F'GXV\@;F$@;&ES=&$@9&4@9&ES=')I8G5IY^-O
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV
M-`IM<V=I9"`B3TLB"FUS9W-T<B`B3TLB"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#<Q"FUS9VED(")/8FIE8W0B"FUS9W-T
M<B`B3V)J971O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,3$*
M;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@(D-R:6%D;W(@9&\@3V)J
M971O(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P.`IM<V=I9"`B
M3V-T86PB"FUS9W-T<B`B3V-T86PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")/
M=71U8G)O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/
M9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")&:6QT<F\@;V9E;G-I=F\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S(X"FUS9VED(")/9F9I8V4B"FUS
M9W-T<B`B17-C<FET\W)I;R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D
M+G!H<#HU.`IM<V=I9"`B3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@
M9&EF9F5R96YT+B(*;7-G<W1R(")396YH87,@86YT:6=A(&4@;F]V82!D979E
M;2!S97(@9&EF97)E;G1E<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S8*;7-G:60@(D]L9"!P87-S=V]R9"(*;7-G<W1R(")396YH82!A
M;G1I9V$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-#8*;7-G
M:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="XB"FUS9W-T<B`B4V5N
M:&$@86YT:6=A(&[C;R!E<W3A(&-O<G)E=&$N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(")/;6%N(@IM<V=S='(@(D]MXR(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C<S"FUS9VED(")/;FQY($E-05`@<V5R=F5R
M<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+B(*;7-G<W1R(")3;VUE;G1E('-E
M<G9I9&]R97,@24U!4"!S=7!O<G1A;2!P87-T87,@8V]M<&%R=&EL:&%D87,N
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R(")3;VUE;G1E('-O<G1E<R!O9F5N
M<VEV87,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-S4*;7-G:60@(D]N;'D@;VYE(&5M86EL
M(&%D9')E<W,@86QL;W=E9"XB"FUS9W-T<B`B4V]M96YT92!U;2!E;F1E<F7G
M;R!D92!E+6UA:6P@<&5R;6ET:61O+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB4V]M96YT
M92!O('!R;W!R:65TX7)I;R!O=2!O(&%D;6EN:7-T<F%D;W(@9&\@<VES=&5M
M82!P;V1E;2!A;'1E<F%R(&%S("(*(G!E<FUI<W/U97,@9&4@<')O<')I961A
M9&4@;W4@<')O<')I973A<FEO(&1E('5M(&-O;7!A<G1I;&AA;65N=&\B"@HC
M.B!L:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H
M<#HT,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B06)R
M:7(@96T@=6UA(&YO=F$@:F%N96QA(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM
M<V=S='(@(D5R<F\@9&\@3W!E;E-33#H@3N-O('!U9&4@97AT<F%I<B!D861O
M<R!D82!P87)T92!A<W-I;F%D82!3+TU)344N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")/
M<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(D%B<F4@
M97-T92!L:6YK(&5M('5M82!N;W9A(&IA;F5L82(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R
M(")3:7-T96UA($]P97)A8VEO;F%L(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")/<.?U97,B
M"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P
M<"YI;F,Z,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B
M"FUS9W-T<B`B3W#G]65S(&1E("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM
M<V=S='(@(DQI<W1A($]R9&5N861A(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU-C@*;7-G:60@(D]R9V%N:7-A=&EO;B(*;7-G<W1R
M(")/<F=A;FEZ8>?C;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@
M(E5N:61A9&4@3W)G86YI>F%C:6]N86PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3,T"FUS9VED(")/<F=A;FEZ:6YG(@IM<V=S='(@(D]R9V%N
M:7IA;F1O(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(DUO9&5L;R!O
M<FEG:6YA;"!D92!A<&QI8V'GXV\B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP
M.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP;&%T97,@
M:6X@)7,Z(@IM<V=S='(@(DUO9&5L;R!O<FEG:6YA;"!E;2`E<SHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B3W5T<F\B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3D@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$P.0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$V(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,C4*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S-"!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30T"FUS9VED(")/=&AE<B!);F9O<FUA
M=&EO;B(*;7-G<W1R(")/=71R87,@26YF;W)M8>?U97,B"@HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N
M<R(*;7-G<W1R(")097)M:7-S]65S(&1O(%!R;W!R:65TX7)I;R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0IM<V=I9"`B4$%-(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%U=&5N=&EC
M8>?C;R!004T@;N-O(&5S=.$@9&ES<&]N[79E;"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z
M.DUA:6P@8F%C:V5N9"(*;7-G<W1R(")#;VYE8W1O<B!014%2.CI-86EL(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3(W-@IM<V=I9"`B
M4$=0($1I9VET86P@4VEG;F%T=7)E(@IM<V=S='(@(D%S<VEN871U<F$@1&EG
M:71A;"!01U`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,S(R"FUS9VED(")01U`@16YC<GEP=&5D($1A=&$B"FUS9W-T<B`B1&%D;W,@
M0W)I<'1O9W)A9F%D;W,@8V]M(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(D-H879E(%#Z8FQI8V$@4$=0(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,U-@IM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")$861O<R!!<W-I;F%D;W,O0W)I<'1O9W)A9F%D;W,@
M8V]M(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0
M($-O9&4B"FUS9W-T<B`B0_-D:6=O(%!(4"(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S='(@(DQI;FAA(&1E($-O
M;6%N9&\@4$A0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S<*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B0VAU=F$@
M1G)A8V$@5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,X"FUS9VED(")032!286EN(@IM<V=S='(@(D-H=79A
M(%9E<W!E<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.0IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R(")#:'5V87,@
M5F5S<&5R=&EN87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R(*;7-G<W1R(").979E(%9E<W!E
M<G1I;F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT,0IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S='(@(DYE=F%S8V$@
M5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C0R"FUS9VED(")032!3=6XB"FUS9W-T<B`B3F5V92!697-P97)T
M:6YA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#,*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E1R;W9O861A<R!697-P
M97)T:6YA<R(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@
M(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(D5S=.$@9F%L
M=&%N9&\@82!E>'1E;G/C;R!03U-)6"(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM
M<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("),:6YH82!D92!#;VUA;F1O(%!?
M2%`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(DUA<F=E;2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T<B`B4&%Q=6ES=.-O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.30@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L874B"FUS9W-T<B`B4&%L874B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`Q"FUS9VED(")086QE<W1I;FEA;B!497)R:71O<GDL
M($]C8W5P:65D(@IM<V=S='(@(E!A;&5S=&EN;RP@5&5R<FET\W)I;R!/8W5P
M861O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N
M86WA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM
M<V=S='(@(E#A<'5A($YO=F$@1W5I;NDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED
M(")087)A9W5A>2(*;7-G<W1R(")087)A9W5A:2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO
M=61Y(@IM<V=S='(@(E!A<F-I86QM96YT92!.=6)L861O(@H*(SH@861M:6XO
M=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R,@HC.B!T96UP;&%T97,O;&]G:6XO
M;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R-0IM<V=I9"`B4&%S
M<W=O<F0B"FUS9W-T<B`B4V5N:&$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S
M=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U
M;&QY+B(*;7-G<W1R(")396YH82!A;'1E<F%D82!C;VT@<W5C97-S;RXB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C,*;7-G:60@
M(E!A<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")396YH82!I;F-O<G)E=&$B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP:'`Z,34R"FUS9VED
M(")087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(")396YH82!O8G)I9V%T\W)I82!P87)A(&$@875T96YT:6-A
MY^-O(%)!1$E54RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4W
M"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")3
M96YH82!C;VT@8V]N9FER;6'GXV\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")396YH83HB
M"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S
M<W=O<F0Z("(*;7-G<W1R(")396YH83H@(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S@*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N(@IM<V=S='(@(E-E;FAA<R!D979E;2!S97(@:6=U86ES+B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*
M;7-G<W1R(")#;VQA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM
M<V=S='(@(D-O;&%R(&1A(.%R96$@9&4@=')A;G-F97+J;F-I82(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@
M(E!A=&@B"FUS9W-T<B`B4&%T:"(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z(@IM<V=S='(@(D-A
M9&%S=')O<R!096YD96YT97,Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4T"FUS9VED(")096]P;&4B"FUS9W-T<B`B4&5S<V]A<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")0
M97)C96YT(@IM<V=S='(@(E!O<F-E;G1A9V5M(@H*(SH@=&5M<&QA=&5S+VUA
M:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-#D*;7-G:60@(E!E<F9O<FT@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G<W1R(")%>&5C=71A<B!/<&5R
M8>?U97,@9&4@36%N=71E;N?C;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;C\B"FUS9W-T<B`B17AE8W5T87(@;W!E<F'G]65S(&1E(&UA;G5T
M96[GXV\@86\@8V]N96-T87(_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B4&5R;6ES
M<^-O(@H*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS
M9W-T<B`B4&5R;6ES<^-O(%PB)7-<(B!NXV\@97AC;'7M9&$N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.3`*;7-G:60@(E!E<FUI<W-I;VX@
M1&5N:65D(@IM<V=S='(@(E!E<FUI<W/C;R!.96=A9&$B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C$V-`IM<V=I9"`B4&5R;6ES<VEO;G,B"FUS9W-T<B`B4&5R
M;6ES<_5E<R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P.2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP
M.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G:60@(E!E<FUI<W-I
M;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN:7-T<F'GXV\@9&4@
M4&5R;6ES<_5E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV.`IM<V=I
M9"`B4&5R<V]N86P@26YF;W)M871I;VXB"FUS9W-T<B`B26YF;W)M8>?U97,@
M4&5S<V]A:7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B
M4&5R=2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T
M<R(*;7-G<W1R(")!;FEM86ES(&1E($5S=&EM8>?C;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M.0IM<V=I9"`B4&AI;&EP<&EN97,B"FUS9W-T<B`B1FEL:7!I;F%S(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-@IM<V=I
M9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;F4B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R(")0:71C
M86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4&EX96QS(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T:71U9&5S(@IM<V=S
M='(@(D-L:6-HZ2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#<*;7-G:60@(E!L96%S92!C;&EC:R!I;G1O('-O
M;64@8V5L;"(*;7-G<W1R(")0;W(@9F%V;W(@8VQI<75E(&5M(&%L9W5M82!C
MZ6QU;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-#D*;7-G:60@(E!L96%S92!C;VYF:7)M('1H870@>6]U
M('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#HB"FUS9W-T<B`B4&]R(&9A
M=F]R(&-O;F9I<FUE('%U92!V;V/J('%U97(@<F5M;W9E<B!E<W1E(&5L96UE
M;G1O.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G<W1R(")0;W(@9F%V
M;W(@8V]N9FER;64@<75E('9O8^H@<75E<B!R96UO=F5R(&\@;&EN:R!D97-T
M92!E;&5M96YT;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-38V
M"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*;7-G
M<W1R(")0;W(@9F%V;W(@9F]R;F7G82!U;2!MZG,@92!U;2!A;F\N(@H*(SH@
M=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*;7-G
M:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ
M(@IM<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('5M(&YO;64@<&%R82!A(&YO
M=F$@8V%T96=O<FEA.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M,#4*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(@IM
M<V=S='(@(E!O<B!F879O<B!F;W)N9>=A('5M(&5N9&5R9>=O($E0(';A;&ED
M;RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0W"FUS9VED(")0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G
M82!U;6$@9&%T82!VX6QI9&$L('9E<FEF:7%U92!O(&[Z;65R;R!D92!D:6%S
M(&YO(&WJ<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4Q"FUS
M9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G<W1R(")0;W(@
M9F%V;W(@9F]R;F7G82!U;6$@:&]R82!VX6QI9&$N(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R(")0;W(@9F%V;W(@
M9F]R;F7G82!U;2!R97-U;6\@9&\@<')O8FQE;6$N(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHR,B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C(V"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P
M87-S=V]R9"(*;7-G<W1R(")0;W(@9F%V;W(@9F]R;F7G82!S974@=7-UX7)I
M;R!E('-E;FAA(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C4X"FUS
M9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-
M55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M
M+B(*;7-G<W1R("(B"B)0;W(@9F%V;W(@;&5I82!O('1E>'1O(&$@<V5G=6ER
M+B!6;V/J($1%5D4@8V]N8V]R9&%R(&-O;2!O<R!T97)M;W,@9&4@=7-O(&1O
M("(*(G-I<W1E;6$N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S92!T>7!E('1H92!N97<@
M8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4&]R(&9A=F]R(&1I9VET92!O(&YO
M;64@9&$@;F]V82!C871E9V]R:6$Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`B4&]L]&YI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L[71I8V$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*
M;7-G<W1R(")%;G%U971E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G
M86PB"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET
M:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B4&]S:>?C;R!D97-T82!I
M;6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R(")0;W-IY^-O(&1E<W1A('1A8F5L82(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED(")0;W-T('1O('1H:7,@
M9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB"FUS9W-T<B`B16YV:64@
M<&%R82!E<W1A('!A<W1A("ANXV\@Z2!O8G)I9V%D;R!P96QO($E-05`I(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-S,@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HR-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B4')E8VEP:71AY^-O('!A<F$@
M82AS*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(X-PIM<V=I9"`B4')E8VEP:71A=&EO;CQB<B`O
M/F-H86YC92(*;7-G<W1R(")0<F5C:7!I=&'GXV\\8G(@+SYC:&%N8V4B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R
M969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B4')E9G-?;&1A<#H@17AT96YSXV\@3$1!4"!O8G)I9V%T\W)I
M82!NXV\@96YC;VYT<F%D82XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M<V5S<VEO;BYP:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?
M<V5S<VEO;CH@17AT96YSXV\@9&4@<V5S<^-O(&]B<FEG873S<FEA(&[C;R!E
M;F-O;G1R861A+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C,R"FUS9VED
M(")0<F5S<W5R92(*;7-G<W1R(")0<F5S<^-O(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR-C8*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(E!R97-SXV\@96T@;NUV96P@9&\@;6%R.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(T"FUS9VED(")0<F5S<W5R93H@(@IM
M<V=S='(@(E!R97-SXV\Z("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(S"FUS9VED(")0<F5V:65W(@IM
M<V=S='(@(E!RZ2UV:7-U86QI>F'GXV\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C0*;7-G:60@(E!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")0<F5V
M97(@82!I;6%G96T@96T@=6UA(&YO=F$@:F%N96QA(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-38@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C`*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B
M3W#G]65S(&%N=&5R:6]R97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G
M<W1R("));7!R:6UI<B!D;V-U;65N=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@
M(D-H879E(%!R:79A9&$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N
M=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96UA(@H*
M(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z,3(W"FUS9VED(")0<F]B;&5M($1E
M<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:>?C;R!D;R!0<F]B;&5M82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S$*;7-G:60@(E!R;VIE8W1S
M(@IM<V=S='(@(E!R;VIE=&]S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3DR"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#,*;7-G:60@(E!R;VUP="!T97AT(@IM
M<V=S='(@(E1E>'1O(&)R979E(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#(S"FUS9VED(")0=6)L:6,@2V5Y(@IM<V=S='(@(D-H879E
M(%#Z8FQI8V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8T-@IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B06QG
M;W)I=&UO(&1A($-H879E(%#Z8FQI8V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!);F9O(@IM
M<V=S='(@(D-H879E(%#Z8FQI8V$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U8FQI8R]0<FEV871E(&ME>7!A:7(@
M;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S='(@(E!A<B!D92!C
M:&%V97,@4/IB;&EC82]0<FEV861A(&[C;R!F;W)A;2!G97)A9&]S(&-O;2!S
M=6-E<W-O+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DQ(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM
M<V=S='(@(E!O<G1O(%)I8V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Y-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")1871A
M<B(*;7-G<W1R(")1871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,PIM
M<V=I9"`B475E<GDB"FUS9W-T<B`B0V]N<W5L=&%R(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")1871A<B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8T"B,L('!H
M<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@2V5Y("@E9"!B:70I(@IM<V=S
M='(@(D-H879E(%#Z8FQI8V$@4E-!("@E9"!B:70I(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C(V.`IM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM
M<V=S='(@(D)O=/5E<R!D92!S96QEY^-O(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6XB"FUS9W-T<B`B
M0VAU=F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-0IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")#:'5V82!-871U=&EN
M82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0V
M"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B0VAU=F$@5F5S<&5R=&EN82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS
M9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")086YC861A<R!D92!#:'5V82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0X"FUS
M9VED(")286EN(&%N9"!3;F]W(@IM<V=S='(@(D-H=79A(&4@3F5V92(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED
M(")286EN('1O(%-N;W<B"FUS9W-T<B`B0VAU=F$@<&%R82!.979E(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G:60@(E)A;F1O;2!&;W)T=6YE
M(@IM<V=S='(@(E-O<G1E($%L96%T\W)I82(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW-@IM<V=I9"`B4F%T:6\B"FUS9W-T<B`B4F5L8>?C
M;R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS
M9VED(")296%D(@IM<V=S='(@(DQE<B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM
M<V=S='(@(DQE<B!M96YS86=E;G,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]R96UO=F4N:6YC.C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS
M9W-T<B`B17AC;'5I<B!R96%L;65N=&4@)7,_($5S=&$@;W!E<F'GXV\@;N-O
M('!O9&4@<V5R(&1E<V9E:71A+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO
M=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)296UO=F5R(')E86QM96YT92!O
M<R!D861O<R!D;R!U<W7A<FEO("5S/R!%<W1A(&]P97)AY^-O(&[C;R!P;V1E
M('-E<B`B"B)D97-F96ET82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C
M=&EO;B(*;7-G<W1R(")2969A>B!S=6$@^FQT:6UA(&'GXV\B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T
M-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")!='5A;&EZ87(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2969R97-H($1Y;F%M:6,@
M365N=2!%;&5M96YT<SHB"FUS9W-T<B`B071U86QI>F%R($UE;G4@9&4@16QE
M;65N=&]S($1I;N)M:6-O<SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")!='5A
M;&EZ87(@17AI8FGGXV\@9&\@4&]R=&%L.B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$W"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD*;7-G:60@(E)E9V5X(@IM
M<V=S='(@(E)E9V5X(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S
M.`IM<V=I9"`B4F5L871I;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B3F%V96=A
M9&]R(&1E(%)E;&'G]65S(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I9"`B
M4F5L;V%D(@IM<V=S='(@(DQE<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S,S"FUS9VED(")296UA<FMS(@IM<V=S='(@(D]B<V5R=F'G]65S(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM<V=I9"`B4F5M;W1E(%-E<G9E
M<G,B"FUS9W-T<B`B4V5R=FED;W)E<R!296UO=&]S(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B55),(%)E;6]T
M82`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,B!T96UP;&%T97,O861M:6XO
M=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F5Q=65U960N:6YC.C$S"FUS9VED(")296UO=F4B"FUS9W-T<B`B4F5M
M;W9E<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0IM<V=I
M9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E)E;6]V97(@0FQO8V\B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED
M(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)E;6]V97(@8V]L=6YA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM<V=I
M9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4F5M;W9E<B!F;W)M871A
MY^-O(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G:60@
M(E)E;6]V92!P86ER(@IM<V=S='(@(E)E;6]V97(@<&%R(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C(P,@IM<V=I9"`B4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S='(@
M(E)E;6]V97(@<V-R:7!T(&=R879A9&\@;F\@9&ER973S<FEO('1E;7!O<N%R
M:6\@9&\@<V5R=FED;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0R"FUS9VED(")296UO=F4@=&AE(@IM
M<V=S='(@(E)E;6]V97(@;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")296UO=F5R(&5S=&4@
M;O,@9&\@9&]C=6UE;G1O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M
M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B4F5M;W9E
M<B!U<W7A<FEO(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN
M8SHU"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G
M<W1R(")296UO=F5R('5S=>%R:6\Z("5S(@H*(SH@9G)A;65W;W)K+U)00R]2
M4$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(E-O;&EC
M:71AY^-O(&[C;R!P]&1E('-E<B!R97-P;VYD:61A+B!#\V1I9V\@9&4@97)R
M;R!R971O<FYA9&\Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HQ-#4*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F
M;W5N9"XB"FUS9W-T<B`B3R!S97)V:>=O(')E<75I<VET861O(&[C;R!P;V1E
M('-E<B!E;F-O;G1R861O+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP
M:'`Z,3<V(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$X"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B<E<R<@;V)R:6=A=/-R:6\@
M;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O("5S+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z-C<X(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#8Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N
M9FEG=7)AY^-O(%9&4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW
M-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO="!S
M<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B)R5S)R!O8G)I
M9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S,U"FUS
M9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R(")#86UP;R!/8G)I9V%T\W)I
M;R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,T,PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS
M,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G
M<W1R("),:6UP87(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`B1V5R87(@3F]V82!3
M96YH82(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"FUS9VED
M(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(D=E<F%R($YO=F$@4V5N
M:&$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E
M($QA<W0@475E<GDB"FUS9W-T<B`BVFQT:6UO(%%U87)T;R(*"B,Z(&%D;6EN
M+W!H<'-H96QL+G!H<#HW,2!A9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO
M<W%L<VAE;&PN<&AP.C8V"FUS9VED(")297-U;'1S(@IM<V=S='(@(E)E<W5L
M=&%D;W,B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E
M;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I
M;VYS(@IM<V=S='(@(E)E=&]R;F%R(.`@3W#G]65S(@H*(SH@<V5R=FEC97,O
M8VAA;F=E<&%S<W=O<F0N<&AP.C,X"FUS9VED(")2971Y<&4@;F5W('!A<W-W
M;W)D(@IM<V=S='(@(D1I9VET92!A(&YO=F$@<V5N:&$@;F]V86UE;G1E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R(")2975N:>-O
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G
M<W1R(")2979E<G1E<B!#;VYF:6=U<F'GXV\B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B
M"FUS9W-T<B`B3W#G]65S(&1O($5D:71O<B!2:6-H(%1E>'0B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS9W-T<B`B
M0VAA<F%D87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(D1I<F5I=&$B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$P"FUS9VED(")2:6=H
M="!H96%D97(B"FUS9W-T<B`B0V%B9>=A;&AO(&1I<F5I=&\B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`V"FUS9VED(")2:6=H="!V86QU97,B
M"FUS9W-T<B`B5F%L;W)E<R!D82!D:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2
M;U]W(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%],
M:6YH82XN+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B1G5NY^-O(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R(")2;VWJ;FEA(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R-`IM<V=I
M9"`B4F]T871E(#$X,"(*;7-G<W1R(")':7)A<B`Q.#`@9W)A=7,B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(Q"FUS9VED
M(")2;W1A=&4@3&5F="(*;7-G<W1R(")':7)A<B!P87)A(&$@17-Q=65R9&$B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(W
M"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B1VER87(@<&%R82!A($1I
M<F5I=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE<R(*;7-G<W1R(")0
M<F]P<FEE9&%D97,@9&$@3&EN:&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@;&EN:&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,0IM<V=I9"`B
M4F]W<SHB"FUS9W-T<B`B3&EN:&%S.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM
M<V=S='(@(DQI;FAA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`B3&EN:&%S
M(&%P87)E8V5RXV\@96YT<F4@=&]D87,@87,@;&EN:&%S(&4@8V]L=6YA<R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN
M<R!O;FQY(@IM<V=S='(@(DQI;FAA<R!A<&%R96-E<N-O('-O;65N=&4@96YT
M<F4@8V]L=6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E
M='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(DQI;FAA<R!A<&%R96-E<N-O('-O
M;65N=&4@96YT<F4@;&EN:&%S(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R
M,`IM<V=I9"`B4G5N(@IM<V=S='(@(D5X96-U=&%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(D9E9&5R8>?C
M;R!2=7-S82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R
M(")2=6%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C(X-0IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM
M<V=S='(@(D%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3+TU)344B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-
M24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(DUE;G-A9V5M($-R:7!T
M;V=R869A9&$@8V]M(%,O34E-12(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z.#$*;7-G:60@(E-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92XB"FUS9W-T<B`B075T96YT:6-AY^-O(%-!4TP@;N-O(&5S
M=.$@9&ES<&]N[79E;"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(D-O<G)E:6\@4TU3
M(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS9VED(")344P@4VAE;&PB
M"FUS9W-T<B`B3&EN:&$@9&4@8V]M86YD;R!344PB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C@Q"FUS9VED(")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(@IM<V=S='(@(E-E;G1E;N=A(%-13"!P87)A('!E<W%U
M:7-A<R!D92!V86QO<F5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0S,PIM<V=I9"`B4U-((@IM<V=S='(@(E-32"(*"B,Z(&9R86UE=V]R:R].
M;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z
M,S4*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`B4U5#15-33R(*"B,Z(&QI8B]A
M<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("),:6YH82!D
M92!C;VUA;F1O(%-?44PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C8Q"FUS9VED(")382(*;7-G<W1R(")386(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE;F$B"FUS9W-T<B`B4V%N=&$@
M2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S$@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")386EN="!+:71T<R!A;F0@
M3F5V:7,B"FUS9W-T<B`B4^-O($MI='1S(&4@3F5V:7,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(E-A;G1A($QU>FEA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#D@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,`IM<V=I9"`B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO
M;B(*;7-G<W1R(")3XV\@4&5D<F\@92!-:7%U96QO;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(E/C;R!6:6-E;G1E(&4@1W)A;F%D:6YA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@
M9G)A;64@*%]S96QF*2(*;7-G<W1R(")-97-M;R!Q=6%D<F\@*%]S96QF*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A;6]A(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R(")386X@
M36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@86YD(%!R
M:6YC:7!E(@IM<V=S='(@(E/C;R!4;VWI(&4@4'+M;F-I<&4B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E;&QI=&4@
M4')O=FED97(B"FUS9W-T<B`B4')O=F5D;W(@9&4@4V%TZ6QI=&4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B07+A8FEA
M(%-A=61I=&$B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3D*
M;7-G:60@(E-A=F4B"FUS9W-T<B`B4V%L=F%R(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R(")386QV87(@)7,B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E
M("5S(@IM<V=S='(@(E-A;'9A<B`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")386QV87(@
M3W#G]65S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM<V=I9"`B
M(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I
M<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"B)386QV87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M
M('-C<FEP="!02%`@<&%R82!O(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1O("(*
M(G-E=2!S97)V:61O<BXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N
M+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@)7,@<V%L=F$N(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B
M4V-R:7!T(&1E(&%T=6%L:7IAY^-O(&1E(&-O;F9I9W5R8>?C;R!S86QV;R!E
M;3H@)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HU,`IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E1E
M;7!E<W1A9&5S($ES;VQA9&%S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4Y"FUS9VED(")38VEE;F-E(@IM<V=S='(@(D-IZFYC:6$B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHQ-@IM<V=I9"`B4V5A<F-H(@IM<V=S='(@(E!E<W%U
M:7-A<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C(*;7-G:60@
M(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(D5N9VEN97,@9&4@4&5S<75I<V$@
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDV,@IM<V=I9"`B4V5L
M96-T($9I;&5S(@IM<V=S='(@(E-E;&5C:6]N92!O<R!!<G%U:79O<R(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT.#,*;7-G
M:60@(E-E;&5C="!A(&1A=&4B"FUS9W-T<B`B4V5L96-I;VYE('5M82!D871A
M(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.3@*;7-G:60@(E-E
M;&5C="!A(&=R;W5P('1O(&%D9"(*;7-G<W1R(")396QE8VEO;F4@=6T@9W)U
M<&\@<&%R82!A9&EC:6]N87(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C0S"FUS9VED(")396QE8W0@82!N97<@;W=N97(B"FUS9W-T<B`B4V5L
M96-I;VYE('5M(&YO=F\@;65M8G)O(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B
M4V5L96-I;VYE('5M('-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S
M='(@(E-E;&5C:6]N92!U;2!U<W7A<FEO('!A<F$@861I8VEO;F%R(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8W-`IM<V=I
M9"`B4V5L96-T(&%L;"(*;7-G<W1R(")396QE8VEO;F%R('1O9&]S(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8U,`IM<V=I9"`B4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(E-E;&5C:6]N92!T;V1O<R!O
M<R!C;VUP;VYE;G1E<R!D92!D871A+B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S$*;7-G:60@(E-E;&5C="!A;B!O8FIE
M8W0B"FUS9W-T<B`B4V5L96-I;VYE('5M(&]B:F5T;R(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S4*;7-G:60@(E-E;&5C
M="!N;VYE(@IM<V=S='(@(D[C;R!S96QE8VEO;F%R(&YE;FAU;2(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T97AT
M(&%R96$N(@IM<V=S='(@(B(*(E-E;&5C:6]N92!O<R!C87)A8W1E<F5S('%U
M92!V;V/J('!R96-I<V$@;F$@8V%I>&$@86)A:7AO+B!6;V/J('!O9&4@96YT
MXV\@(@HB8V]P:>$M;&]S(&4@8V]LX2UL;W,@;F$@X7)E82!D92!T97AT;RXB
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS-`IM<V=I9"`B4V5L96-T
M('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B4V5L96-I;VYE('5M(&1E
M;&EM:71A9&]R(&1E(&1A=&$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@
M(E-E;&5C:6]N92!O(&9O<FUA=&\@9&4@9&%T83HB"@HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDP"FUS9VED(")396QE8W0@=&AE
M(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93HB"FUS9W-T<B`B4V5L96-I
M;VYE(&$@:61E;G1I9&%D92!Q=64@=F]CZB!Q=65R(&%L=&5R87(Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z(@IM<V=S='(@(E-E;&5C:6]N92!U;2!D96QI;6ET
M861O<B!D92!H;W)A.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U
M"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R(")396QE
M8VEO;F4@;R!F;W)M871O(&1E(&AO<F$Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N(@IM<V=S='(@(E-E;&5C:6]N92!D;VES(&-A;7!O<R!C;W)R97-P;VYD
M96YT97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Q,`IM<V=I9"`B
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R(")396QE8VEO;F4@
M<V5U(&5S<75E;6$@9&4@8V]R97,N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U,@IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E
M.B(*;7-G<W1R(")396QE8VEO;F4@<V5U(&ED:6]M82!P<F5F97)I9&\Z(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E
M;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B16YV:6%R(%)E;&%T\W)I;R!D
M92!0<F]B;&5M82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#0P"FUS9VED(")396YD(%--4R(*;7-G<W1R(")%;G9I87(@
M4TU3(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")3
M96YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@(E-E
M;G-O<CH@(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0V"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G
M<W1R(")3971E;6)R;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B4V5R=FEA(&4@36]N=&5N96=R;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-S`R"FUS9VED(")397)I86P@3G5M8F5R(@IM<V=S
M='(@(D[Z;65R;R!D92!3Z7)I92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(D1A9&]S(&1O('-E<G9I9&]R(&5R<F%D;W,@
M;W4@;N-O(&1I<W!O;NUV96ES+B(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HR
M-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R(")!9&UI;FES=')A9&]R
M(&1E(%-E<W/C;R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(Y,@IM<V=I9"`B4V5S<VEO;B!)1"!E>'!I<F5D+B(*
M;7-G<W1R("))1"!D82!397-SXV\@97AP:7)O=2XB"@HC.B!L:6(O87!I+G!H
M<#HQ-#4*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(E-E<W/U97,B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$X"FUS9VED(")3970B"FUS9W-T
M<B`B06IU<W1A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW.0IM<V=I
M9"`B4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)#;VYF
M:6=U<F$@87,@;W#G]65S('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A<B!U;6$@
M;F]V82!S96YH82!S92!V;V/J(&5S<75E8^HM(@HB;&$N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$Q.`IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M(@IM<V=S='(@(B(*(D-O;F9I9W5R82!O<R!S97)V:61O<F5S(')E;6]T;W,@
M<75E('9O8^H@<75E<B!A8V5S<V%R(.`@<&%R=&ER(&1O('!O<G1A;"XB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#<*;7-G:60@(E-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RXB
M"FUS9W-T<B`B0V]N9FEG=7)A('-E=2!I9&EO;6$@<')E9F5R:61O+"!F=7-O
M(&AO<N%R:6\@92!O<.?U97,@9&4@9&%T82XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI
M8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T
M:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB0V]N9FEG=7)A
M('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@97-Q=65M82!D92!C;W)E<RP@871U
M86QI>F'GXV\@9&4@<.%G:6YA<R!E("(*(F]U=')A<R!O<.?U97,@9&4@97AI
M8FGGXV\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW-PIM<V=I9"`B
M4V5T=7`B"FUS9W-T<B`B0V]N9FEG=7)AY^-O(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@
M<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T<B`B4V-R:7!T<R!D92!A='5A;&EZ
M8>?C;R!D92!C;VYF:6=U<F'GXV\@9&ES<&]N[79E:7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<U"FUS9VED(")3979E<F%L(&QO8V%T
M:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*;7-G<W1R(")$
M:79E<G-A<R!L;V-A;&ED861E<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O
M.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")397EC:&5L;&5S(@IM<V=S='(@
M(E-E:6-H96QE<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.3@*
M;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(D-O;7!R87,B"@HC.B!T96UP;&%T
M97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PIM<V=I9"`B4VAO<G0@4W5M;6%R
M>2(*;7-G<W1R(")297-U;6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#4P"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@
M;6]S="!L:6YK<S\B"FUS9W-T<B`B5&5C;&%S(&1E(&%T86QH;R!D979E<N-O
M('-E<B!D969I;FED87,@<&%R82!A(&UA:6]R:6$@9&]S(&QI;FMS/R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS9VED(")3
M:&]W(@IM<V=S='(@(D5X:6)I<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B17AI8FER(&%S(&1I9F5R96[G87,@96YT<F4@
M82!C;VYF:6=U<F'GXV\@871U86P@92!A(&YO=F$@9V5R861A+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B17AI8FER(&1A=&$@
M92!H;W)A(&1A(/IL=&EM82!C;VYE>.-O(&%O('-E(&-O;F5C=&%R/R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86PB"FUS9W-T<B`B17AI8FER(&$@;W#GXV\@
M9&4@;6%N=&5R(&\@;W)I9VEN86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`R"FUS9VED(")3:&]W('!I8VME<B(*;7-G<W1R(")%>&EB:7(@
M<V5L971O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S`*;7-G:60@
M(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`B17AI
M8FER(&)A<G)A(&1E(&UE;G4@8V]M(&]P97)AY_5E<R!D92!T86)E;&$_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")%
M>&EB:7(@;R!-96YU("5S(.`@97-Q=65R9&$_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(D5X:6)I<B!D:>%L;V=O(&1E(%!R;W!R:65D861E<R!D92!#Z6QU;&%S(&1A
M(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R
M=&EE<R!D:6%L;V<B"FUS9W-T<B`B17AI8FER(&1IX6QO9V\@9&4@4')O<')I
M961A9&5S(&1A(%1A8F5L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,`IM<V=I9"`B4VAO=R!T:&4@5&%B
M;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D5X:6)I<B!D:>%L
M;V=O(&1E(%!R;W!R:65D861E<R!D92!,:6YH87,@9&$@5&%B96QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9R(*
M;7-G<W1R(")%>&EB:7(@9&GA;&]G;R!D92!P<F]P<FEE9&%D97,@9&4@:6UA
M9V5M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V-PIM<V=I9"`B
M4VAO=R!U<&QO860B"FUS9W-T<B`B17AI8FER('5P;&]A9"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W
M97)S(@IM<V=S='(@(D-H=79A<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4R"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S
M='(@(D-H=79A<R!M871I;F%I<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4S"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T
M<B`B0VAU=F%S(%9E<W!E<G1I;F%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-30*;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I
M8VEN:71Y(@IM<V=S='(@(D-H=79A<R!N87,@<F5D;VYD97IA<R(*"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z-C$Y"FUS
M9VED(")3:')I;FLB"FUS9W-T<B`B4F5D=7II<B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3$P"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z.3<R"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP:'`Z,3`U.`HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$Q,C`*
M(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ
M,3@S"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70O36%N86=E<BYP
M:'`Z,3(R,PHC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C$R-3(*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-
M86YA9V5R+G!H<#HQ,C@U"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B
M4')I;65I<F%M96YT92!R961U>F$@;W4@=&ER92!D;R!C86UI;FAO(&\H<RD@
M8FQO8V\H<RD@861J86-E;G1E*',I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B
M4VEE<G)A($QE;VYE(@IM<V=S='(@(E-E<G)A($QE;V$B"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(E)E9VES=')A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-S$S"FUS9VED(")3:6=N871U<F4B"FUS9W-T<B`B07-S:6YA
M='5R82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$R
M"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@(D%L9V]R:71M
M;R!D82!!<W-I;F%T=7)A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(D-I;F=A<'5R82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O>FEP+G!H<#HW,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M9WHN<&AP.C@T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDP,`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$Y(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-#$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(U,"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3$Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,Q,3(*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M86YH;R(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4R"FUS
M9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@(DEG;F]R87(@36%N=71E
M;N?C;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@
M(D5S;&]VX7%U:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*
M;7-G<W1R(")%<VQO=F5N:6$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R(").979E(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-38*;7-G
M:60@(E-N;W<@4VAO=V5R(@IM<V=S='(@(DYE=F%S8V$B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3
M:&]W97)S(@IM<V=S='(@(DYE=F%S8V%S(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!%
M87)L>2(*;7-G<W1R(")#:'5V87,@;6%T:6YA:7,B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.0IM<V=I9"`B4VYO=R!3:&]W
M97)S($QA=&4B"FUS9W-T<B`B3F5V87-C87,@5F5S<&5R=&EN87,B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X-0IM<V=I9"`B4VYO=R!D97!T:#H@(@IM
M<V=S='(@(E!R;V9U;F1I9&%D92!D82!.979E.B`B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(X.0IM<V=I9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R
M.B`B"FUS9W-T<B`B17%U:79A;&5N=&4@9&4@;F5V92!E;2#A9W5A.B`B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES;&%N9',B"FUS9W-T<B`B
M26QH87,@4V%L;VWC;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B4V]MX6QI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*;7-G<W1R(")#86[G]65S("8@4&]E
M;6%S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ-0IM<V=I9"`B
M4V]R="!O<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`B3W)D96YA<B!S96QEY^-O
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU-3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.#D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C$W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(T-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN
M7VAT='`N<&AP.C$V-@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT
M='`N<&AP.C$X.0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`B16YD
M97)EYV\@9&4@;W)I9V5M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@
M069R:6-A(@IM<V=S='(@(L%F<FEC82!D;R!3=6PB"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.0IM<V=I9"`B4V]U=&@@175R;W!E86X@*$E33RTX.#4Y
M+3,I(@IM<V=S='(@(E-U;"!%=7)O<&5U("A)4T\M.#@U.2TS*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A
M;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B4W5L(&1A($=E;W)G:6$@92!3=6P@
M9&%S($EL:&%S(%-A;F1U[6-H92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@(E-O=71H97)N($AE;6ES
M<&AE<F4B"FUS9W-T<B`B2&5M:7-FZ7)I;R!3=6PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")%<W!AYV\@96YT<F4@
M8^EL=6QA<R!A9&IA8V5N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B17-P8>=O(&5N=')E
M(&\@8V]N=&7Z9&\@92!B;W)D82!D82!CZ6QU;&$B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX,3D*;7-G:60@(E-P86-E<B(*;7-G<W1R(")%<W!A
MYV%D;W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#`*;7-G:60@(E-P86-I;F<B"FUS9W-T<B`B17-P8>=A;65N
M=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4T"FUS9VED(")3<&%C:6YG(&%N9"!P861D:6YG(@IM<V=S='(@
M(D5S<&'G86UE;G1O(&4@;6%R9V5M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P
M86EN(@IM<V=S='(@(D5S<&%N:&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S97)V
M:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R
M($EN<'5T(@IM<V=S='(@(D5N=')A9&$@9&4@0V%R86-T97)E<R!%<W!E8VEA
M:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL(@IM<V=S='(@(D1I=FED:7(@
M8^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-@IM<V=I9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(D1I
M=FED:7(@8V]L=6YA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW,0IM<V=I9"`B4W!L:70@<F]W(@IM<V=S='(@
M(D1I=FED:7(@;&EN:&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C$*
M;7-G:60@(E-P;W)T<R(*;7-G<W1R(")%<W!O<G1E<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T87(N
M<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")0861RXV\B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G:60@(E-T87(@5')E:R(*;7-G
M<W1R(")3=&%R(%1R96LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M-3DP(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(W.3@*;7-G:60@(E-T87)T
M('EE87(B"FUS9W-T<B`B06YO(&EN:6-I86PB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,0IM<V=I9"`B4W1A=&4@;W(@4')O=FEN
M8V4B"FUS9W-T<B`B17-T861O(&]U(%!R;W;M;F-I82(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4VET=6'GXV\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR
M.#`T"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1O
M(&%R;6%Z96YA;65N=&\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4W,PIM<V=I9"`B4W1R965T($%D9')E<W,B"FUS9W-T<B`B3F]M
M92!D82!2=6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$Q"FUS9VED(")3=')I:V5T:')O=6=H(@IM<V=S='(@(E1R8>=A
M9&\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,W"FUS9VED(")3
M=')I;F<@;&ES="(*;7-G<W1R("),:7-T82!D92!C861E:6%S(&1E(&-A<F%C
M=&5R97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W"FUS9VED
M(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G<W1R(")2971I
M<F%R(&$@<&%R=&4@9&\@9&]M[6YI;R!D;R!E;F1E<F7G;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G
M:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(D5S=&EL;R!;0U-372(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G:60@
M(E-U(@IM<V=S='(@(D1O;2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4W5B9&ER973S<FEO("<E<R<@;N-O(&5N8V]N
M=')A9&\N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!<W-U;G1O(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,V(&9R86UE=V]R:R]&;W)M+T9O
M<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S='(@(D5N
M=FEA<B(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E<75E<W0@
M:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D5N=FEA9&$@82!S;VQI
M8VET8>?C;R!D92!A9&EC:6]N87(@7"(E<UPB(&%O('-I<W1E;6$N(%9O8^H@
M;N-O('!O9&4@8V]N96-T87(M(@HB<V4@873I('%U92!S=6$@<V]L:6-I=&'G
MXV\@<V5J82!A<')O=F%D82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
M4W5B<V-R979E<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HR.`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R(")3=6-E<W-O(@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R
M("(G)7,G(&%D:6-I;VYA9&\@8V]M('-U8V5S<V\@86\@<VES=&5M82XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M+B(*;7-G<W1R(")/<R!D861O<R!D;R!U<W7A<FEO("<E<R<@
M9F]R86T@<F5M;W9I9&]S(&1O('-I<W1E;6$@8V]M('-U8V5S<V\N(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V
M"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!D96QE=&5D(%PB
M)7-<(BXB"FUS9W-T<B`B)R5S)R!E>&-L=>UD;R!C;VT@<W5C97-S;RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B17AC;'7M9&\@)R5S)R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-3$*;7-G:60@(E-U8V-E<W-F
M=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H
M86YG97,N(@IM<V=S='(@(D-O;F9I9W5R8>?C;R!R979E<G1I9&$@8V]M('-U
M8V5S<V\N($%T=6%L:7IE('!A<F$@=F5R(&%S(&%L=&5R8>?U97,N(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C4W"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(D)A8VMU<"!D82!C;VYF:6=U<F'GXV\@<V%L
M=F$@8V]M('-U8V5S<V\N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(D\@8F%C
M:W5P(&1O(&%R<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S(&9O:2!S86QV;R!C
M;VT@<W5C97-S;RXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S
M='(@(B<E<R<@871U86QI>F%D;R!C;VT@<W5C97-S;R(*"B,Z(&%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T=7`O:6YD97@N<&AP.C<R"B,L
M('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!W<F]T92`E<R(*;7-G
M<W1R("(E<R!G<F%V861O(&-O;2!S=6-E<W-O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM
M<V=I9"`B4W5D86XB"FUS9W-T<B`B4W5DXV\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(E)E<W5M;R(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H
M<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T<B`B06UA;FAE8V5R(@H*(SH@
M;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C8X"FUS9VED(")3=6X@4V5T(@IM<V=S
M='(@(E#T<BUD;RU3;VPB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV,`IM<V=I9"`B4W5N;GDB"FUS9W-T<B`B16YS;VQA<F%D
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#4*;7-G:60@
M(E-U;G)I<V4B"FUS9W-T<B`B06UA;FAE8V5R(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C,@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C$V"FUS9VED(")3
M=6YR:7-E+U-U;G-E="(*;7-G<W1R(")!;6%N:&5C97(O4/1R+61O+5-O;"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U
M;G)I<V4Z("(*;7-G<W1R(")!;6%N:&5C97(Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,#@*;7-G:60@(E-U;G-E="(*;7-G<W1R(")0
M]'(M9&\M4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P
M-PIM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B4/1R+61O+5-O;#H@(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I
M9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B4V]B<F5S8W)E=F5R(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,`IM<V=I9"`B4W5P<&]R="(*;7-G
M<W1R(")3=7!O<G1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4W5R:6YA;64B
M"FUS9W-T<B`B4W5R:6YA;64B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4W-0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R(")3;V)R96YO
M;64B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P.2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L8F%R9"!A;F0@2F%N($UA
M>65N(@IM<V=S='(@(E-V86QB87)D(&4@2F%N($UA>65N(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P.`IM<V=I9"`B4W=A>FEL86YD(@IM<V=S='(@(E-U87II;.)N9&EA(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@(E-UZ6-I82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-38@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,38*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")3=VET>F5R;&%N9"(*;7-G<W1R(")3=>WG
M82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3
M>6YC(&QO9R!D96QE=&5D(@IM<V=S='(@(D[C;R!E>&-L=6ER(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I9"`B4WEN8TU,(@IM<V=S='(@
M(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HY
M-PIM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<R(*;7-G<W1R
M(")%<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D82!P97-Q=6ES82(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S
M='(@(E)E</IB;&EC82#!<F%B92!D82!3[7)I82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(@IM
M<V=S='(@(E1E;7!E<W1A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B5&5M<&5S=&%D97,@92!696YT86YI82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8S"FUS9VED(")4+5-T;W)M<R(*
M;7-G<W1R(")496UP97-T861E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4+5-T;W)M<R!%87)L>2(*;7-G
M<W1R(")496UP97-T861E<R!-871I;F%I<R(*"B,Z(&9R86UE=V]R:R]$871A
M+T1A=&$O='-V+G!H<#HQ-C8*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(D%R
M<75I=F\@5%-6(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ,S0*
M;7-G:60@(E1A8FQE(@IM<V=S='(@(E1A8F5L82(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A
M8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%1A8F5L
M82(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R(")486)E;&$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<R"FUS
M9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(E!R;W!R:65D861E<R!D
M82!T86)E;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-"!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB
M"FUS9W-T<B`B5&%I=V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3@*;7-G:60@(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B
M"FUS9W-T<B`B5&%I=V%N+"!0<F]V[6YC:6$@9&$@0VAI;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A:FEQ=6ES=.-O
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U
M8FQI8R!O9B(*;7-G<W1R(")486YZXFYI82P@4F5P^F)L:6-A(&1A(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I
M9"`B5&%R9V5T.B(*;7-G<W1R(")!;'9O.B(*"B,Z(&-O;F9I9R]H;V]K<RYP
M:'`N9&ES=#HY.38@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$X.0IM<V=I
M9"`B5&%S:W,B"FUS9W-T<B`B5&%R969A<R(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R
M(@IM<V=S='(@(D[Z;65R;R!D92!496QE9F]N92(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,CDW"FUS9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G
M<W1R(")496UP97)A='5R82!P87)A(&$@^FQT:6UA(&AO<F$Z("(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R(")496UP97)A='5R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R
M871U<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A='5R83QB<B`O/B@E
M<T%L=&$E<R\E<T)A:7AA)7,I("9D96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M
M<&QA=&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4
M96UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")-;V1E;&\@)R5S
M)R!NXV\@96YC;VYT<F%D;RXB"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$V
M.0IM<V=I9"`B5&5M<&QA=&4@061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M
M:6YI<W1R8>?C;R!D92!-;V1E;&]S(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3(Q-2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,T"FUS9VED
M(")497AT(@IM<V=S='(@(E1E>'1O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,W.0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(E-O;65N=&4@5&5X
M=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@(D%L:6YH86UE
M;G1O(&1E(%1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")";W)D82!S
M=7!E<FEO<B!D;R!497AT;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(E%U:2(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")4:&%I("A425,M-C(P
M*2(*;7-G<W1R(")486EL86YDZG,@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`B5&%I;.)N9&EA(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*;7-G:60@(E1H92!&5%`@97AT
M96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D$@97AT96YSXV\@
M1E10(&[C;R!E<W3A(&1I<W!O;NUV96PN(@H*(SH@9G)A;65W;W)K+TAI<W1O
M<GDO2&ES=&]R>2YP:'`Z-34*;7-G:60@(E1H92!(:7-T;W)Y('-Y<W1E;2!I
M<R!D:7-A8FQE9"XB"FUS9W-T<B`B3R!H:7-T\W)I8V\@9&\@<VES=&5M82!E
M<W3A(&1E<V%B:6QI=&%D;RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.CDS,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@
M:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM
M<V=S='(@(D$@96YG:6YE(&1E(&EN=&5G<F'GXV\@2&]R9&4O2V]L86(@;N-O
M('-U<&]R=&$@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M0F]O:RYP:'`Z,3(Y.`IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B
M92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B3R!L;V<@24U34"!NXV\@<&]D92!S
M97(@:6YI8VEA;&EZ861O+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H
M<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L
M;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")!(&-L87-S92!<(DUA:6YT96YA
M;F-E7"(@;N-O(&9O:2!C87)R96=A9&$@8V]M('-U8V5S<V\B"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B02!J
M86YE;&$@9&4@3W#G]65S(&9O:2!F96-H861A+B!386EN9&\N(@H*(SH@9G)A
M;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HQ.#D@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+G!H<#HR,#`*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,3$@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR,C,*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+G!H<#HR,S0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR
M-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR-C0@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+G!H<#HS,#,*;7-G:60@(B(*(E1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2`B"B)W86YT('1O('5S92!097)M:7-S:6]N<RXB
M"FUS9W-T<B`B(@HB3R!A9&UI;FES=')A9&]R('!R96-I<V$@8V]N9FEG=7)A
M<B!U;2!C;VYE8W1O<B!P97)M86YE;G1E(&1E(%!E<FUI<W/U97,@<V4@(@HB
M=F]CZB!Q=65R('5T:6QI>F%R(%!E<FUI<W/U97,N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-0IM<V=I9"`B
M5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`B4V]M96YT92!O(&QA9&\@
M9&4@8F%I>&\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8S.0IM<V=I9"`B(@HB5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE("(*(F1A=&%B87-E+B(*;7-G<W1R("(B"B)/(&[Z;65R;R!)
M1"!D;R!C;VYT871O(&[C;R!F;VD@97-P96-I9FEC861O+"!D96EX861O(&5M
M(&)R86YC;R!O=2!NXV\@9F]I("(*(F5N8V]N=')A9&\@;F\@8F%N8V\@9&4@
M9&%D;W,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C4Q"FUS9VED(")4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")/(&-O;G1A=&\@
M9F]I(&%D:6-I;VYA9&\@8V]M('-U8V5S<V\@86\@<V5U(&-A=.%L;V=O(&1E
M(&5N9&5R9>=O<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,3<R"FUS9VED("(B"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B
M;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E
M+B(*;7-G<W1R("(B"B)087)A('9E<FEF:6-A<B!A(&UE;G-A9V5M(&%S<VEN
M861A(.D@;F5C97-SX7)I;R!U;2!B;&]C;R!S97!A<F%D;R!D82`B"B)A<W-I
M;F%T=7)A(%!'4"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L
M:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!N;W0@9F]U;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)/
M($E$(&1A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I
M8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O("(*(F9O:2!E;F-O;G1R
M861O(&YO(&)A;F-O(&1E(&1A9&]S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4:&4@9&ES=')I
M8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O(&[C;R!F;VD@97-P96-I9FEC861A+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$V"FUS9VED(")4:&4@96YC
M<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T
M:6]N+B(*;7-G<W1R(")!<R!F=6[G]65S(&1E(&-R:7!T;V=R869I82!R97%U
M97)E;2!U;6$@8V]N97CC;R!W96(@<V5G=7)A+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<W(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-3$Y"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B3R!A<G%U:79O("5S(&1E
M=F5R:6$@8V]N=&5R('5M82!C;VYF:6=U<F'GXV\@9&4@)7,N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S`@9G)A;65W;W)K+TAO<F1E+TAO
M<F1E+G!H<#HU,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B3R!A
M<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R(&%L9W5M87,@8V]N9FEG=7)AY_5E
M<R!D92`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C8*
M;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N
M(@IM<V=S='(@(D\@87)Q=6EV;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A
M(&5L92!M97-M;RXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*
M;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")/
M(&%R<75I=F\@;N-O(&-O;G3I;2!D861O<RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W
M:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M
M97-S86=E+B(*;7-G<W1R(")396=U96T@;W,@8V%B9>=A;&AO<R!D97-T82!M
M96YS86=E;2]M96YS86=E;2!R9F,X,C(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@
M<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!)
M;G1E<FYE="!%>'!L;W)E<BP@9'5E("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T
M('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X
M<&5R:65N8V4@(@HB9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F
M=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B`B
M"B)Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@
M=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@(@HB4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R
M;F5D+B`@4&QE87-E("(*(G!R97-S($]+(&EF('EO=2!S=&EL;"!W86YT('1O
M('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+B(*;7-G<W1R("(B"B+)('-A
M8FED;R!Q=64@;R!M;V1O('1E;&$@8VAE:6$@8V%U<V$@<')O8FQE;6%S(&-O
M;2!O($EN=&5R;F5T($5X<&QO<F5R+"!E;2`B"B)V:7)T=61E(&1E(&)U9W,@
M9&\@;F%V96=A9&]R('%U92!N\W,@;N-O(&5S=&%M;W,@87!T;W,@82!C;VYT
M;W)N87(N(%9O8^H@(@HB<&]D92!O8G-E<G9A<B!E<G)O<R!D92!E>&EB:>?C
M;RP@9F%L=&$@9&4@9G5NY_5E<R!D;R!E9&ET;W(@92]O=2!T<F%V86UE;G1O
M<R`B"B)A;&5A=/-R:6]S(&1O(&YA=F5G861O<BX@4V4@<V5U('-I<W1E;6$@
MZ2!7:6YD;W=S(#EX(.D@;75I=&\@<')O=N%V96P@<75E("(*(G9O8^H@<F5C
M96)A('5M(&5R<F\@9&4@)T9A;&AA($=E<F%L(&1E(%!R;W1EY^-O)R!E('!R
M96-I<V%RX2!R96EN:6-I87(N(%Q<;B(*(EQ<;B!6;V/J(&9O:2!A=FES861O
M+B!0;W(@9F%V;W(@<')E<W-I;VYE($]+('-E('9O8^H@86EN9&$@<75E<B!T
M96YT87(@=7-A<B`B"B)O(&5D:71O<B!D92!T96QA(&-H96EA+B(*"B,Z('-E
M<G9I8V5S+W!R969S+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M(&ED96YT:71Y(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!
M(&ED96YT:61A9&4@7"(E<UPB(&9O:2!E>&-L=>UD82XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED
M(")4:&4@;&5F="UH86YD('-I9&4@;VYL>2(*;7-G<W1R(")3;VUE;G1E(&\@
M;&%D;R!E<W%U97)D;R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$U-PIM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B
M:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N
M(@IM<V=S='(@(B(*(D$@;&]C86QI>F'GXV\@9&\@8FENX7)I;R!D;R!';G50
M1R!D979E('-E<B!F;W)N96-I9&$@X"!C;&%S<V4@7")#<GEP=%]P9W!<(BXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@
M=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB"B)4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB02!M96YS86=E;2!E
M;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&\@87-S=6YT;R!<(B5S7"(@9F]I
M(&5X:6)I9&$N7&XB"B))<W1O(&[C;R!G87)A;G1E('%U92!A(&UE;G-A9V5M
M(&9O:2!L:61A(&]U(&5N=&5N9&ED82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK
M:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3R!N;VUE('5T:6QI
M>F%D;R!A;R!V:6YC=6QA<B!A('#A9VEN82!D92!C;VUP;W-IY^-O(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#<T"FUS9VED(")4:&4@;G5M
M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(@IM<V=S='(@(D\@;OIM
M97)O(&1E(&-A;7!O<R!D979E('-E<B!N=6WI<FEC;RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S(*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(D\@;?-D=6QO(&]P96YS<VP@Z2!O8G)I
M9V%T\W)I;R!P87)A(&$@8VQA<W-E(%PB2&]R9&5?0W)Y<'1?<VUI;65<(BXB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R
M;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T
M(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA
M>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB02!P<F5F97+J;F-I
M82!<(B5S7"(@;N-O('!O9&4@<V5R('-A;'9A('!O<G%U92!S975S(&1A9&]S
M(&5X8V5D97)A;2!O("(*(G1A;6%N:&\@;>%X:6UO('!E<FUI=&ED;R(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2XB"FUS9W-T<B`B(@HB3R!P<F]G<F%M82!U=&EL:7IA9&\@<&%R82!V
M:7-U86QI>F%R(&5S=&4@=&EP;R!D92!D861O("@E<RD@;N-O(&9O:2`B"B)E
M;F-O;G1R861O(&YO('-I<W1E;6$N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#@W"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@
M8F4@;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(D\@8V%R86-T97)E
M('!A<F$@8VET8>?C;R!D92!S97(@87!E;F%S('5M+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@
M(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E-O;65N
M=&4@;W,@;&%D;W,@9&ER96ET;R!E(&5S<75E<F1O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B
M5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(E-O;65N=&4@;R!L
M861O(&1I<F5I=&\B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT
M-SD*;7-G:60@(E1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H
M87)A8W1E<BXB"FUS9W-T<B`B3R!S97!A<F%D;W(@9&5V92!S97(@=6T@^FYI
M8V\@8V%R86-T97)E+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP
M.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(D\@<V5R=FED;W(@7"(E<UPB(&9O
M:2!E>&-L=>UD;RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@
M8F5E;B!S879E9"XB"FUS9W-T<B`B3R!S97)V:61O<B!<(B5S7"(@9F]I('-A
M;'9O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y.`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V
M960N(@IM<V=S='(@(D$@<V]L:6-I=&'GXV\@9&4@8V%D87-T<F\@9&4@)7,@
M9F]I(&5X8VQU[61A+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO
M=70O36%N86=E<BYP:'`Z-#<P"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D$@
M;&EN:&$@97-P96-I9FEC861A("@E9"D@;N-O(&5X:7-T92XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@=&5M<&]R87)Y(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*
M;7-G<W1R(")/(&%R<75I=F\@=&5M<&]RX7)I;R!<(B5S7"(@;N-O(&5X:7-T
M92XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`Y"FUS9VED(")4
M:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N
M('1H92!S8W)E96XN(@IM<V=S='(@(D\@=&5X=&\@<75E('9O8^H@9&EG:71O
M=2!NXV\@8V]R<F5S<&]N9&4@86\@=&5X=&\@;F$@=&5L82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS
M9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R(")3
M;VUE;G1E(&]S(&QA9&]S(&1E(&-I;6$@92!D92!B86EX;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G
M:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E-O;65N=&4@;R!L861O
M(&1E(&-I;6$B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G
M:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V
M:6]U<R!S=&5P+B(*;7-G<W1R(")/<R!D861O<R!E;G9I861O<R!F;W)A;2!P
M97)D:61O<R!D97-D92!O('!A<W-O(&%N=&5R:6]R+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O8W-V+G!H<#HR-C(@9G)A;65W;W)K+T1A=&$O1&%T82]T
M<W8N<&AP.C$W,@IM<V=I9"`B5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T
M(&)E('-A=F5D+B(*;7-G<W1R(")/(&%R<75I=F\@96YV:6%D;R!NXV\@</1D
M92!S97(@<V%L=F\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3`*;7-G:60@(E1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R
M(")/(&)L;V-O(%PB=V5A=&AE<BYC;VU<(B!NXV\@97-TX2!D:7-P;V[M=F5L
M+B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&5M97,@9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D\@9&ER973S<FEO(&1E('1E;6%S("<E<R<@;N-O(&9O:2!E;F-O
M;G1R861O+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3<X
M"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N(@IM<V=S
M='(@(D[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#D*;7-G:60@(E1H97)E
M(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*
M;7-G<W1R(").XV\@97AI<W1E;2!P87)T97,@<75E('!O<W-A;2!S97(@97AI
M8FED87,@:6YC;W)P;W)A9&%S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L97-S('1H
M86X@)7,N(@IM<V=S='(@(B(*(D5X:7-T96T@;75I=&]S(&-A<F%C=&5R97,@
M;F5S=&4@8V%M<&\N(%9O8^H@<')E96YC:&5U(&-O;2`E<R!C87)A8W1E<F5S
M.R`B"B)V;V/J(&1E=F4@<')E96YC:&5R(&-O;2`E<R!O=2!M96YO<RXB"@HC
M.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<(B!T
M;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")(;W5V92!U;2!P<F]B;&5M82!A
M9&EC:6]N86YD;R`G)7,G(&%O('-I<W1E;6$Z("5S(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,3(R"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@
M<WES=&5M.B`B"FUS9W-T<B`B2&]U=F4@=6T@<')O8FQE;6$@86\@97AC;'5I
M<B!D;R!S:7-T96UA(&]S(&1A9&]S(&1O('5S=>%R:6\@)R5S)SH@(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@<F5M;W9I;F<@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(DAO=79E('5M('!R;V)L96UA(&%O(&5X8VQU:7(@)R5S
M)R!D;R!S:7-T96UA.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<
M(B5S7"(Z("5S(@IM<V=S='(@(DAO=79E('5M('!R;V)L96UA(&%O(&%T=6%L
M:7IA<B`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N
M<&AP.CDQ,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N
M(@IM<V=S='(@(DAO=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O(&%R
M<75I=F\Z($YE;FAU;2`E<R!F;VD@96YV:6%D;RXB"@HC.B!F<F%M97=O<FLO
M0G)O=W-E<B]"<F]W<V5R+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB2&]U=F4@=6T@<')O8FQE
M;6$@8V]M(&\@96YV:6\@9&\@87)Q=6EV;RX@3R`E<R!E<F$@;6%I;W(@<75E
M(&\@=&%M86YH;R`B"B)MX7AI;6\@<&5R;6ET:61O("@E9"!B>71E<RDN(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3$W"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N(@IM<V=S='(@(B(*(DAO=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO
M(&1O(&%R<75I=F\N($\@)7,@9F]I(&5N=FEA9&\@<&%R8VEA;&UE;G1E+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(DAO=79E('5M(&5R<F\@86\@97AI8FER(&5S
M=&$@<&%R=&4@9&$@;65N<V%G96TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,SD*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(DAO=79E('5M
M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@9&\@8V]N=&%T;RXB"@HC.B!F
M<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*;7-G:60@(E1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G
M<W1R(")(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O(&E#
M86QE;F1A<BXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C@R"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@
M9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L
M9"XB"FUS9W-T<B`B(@HB2&]U=F4@=6T@97)R;R!N;R!F;W)M=6SA<FEO(&1E
M(&-O;F9I9W5R8>?C;RX@5&%L=F5Z('9O8^H@9&5I>&]U('5M(&-A;7!O("(*
M(F]B<FEG873S<FEO(&5M(&)R86YC;RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(DAO=79E('5M(&5R<F\@86\@97AE8W5T87(@82!F=6[GXV\@
M9&4@8V%TX6QO9V\@9&4@96YD97)EYV]S(&5S<&5C:69I8V%D82X@(@HB4&]R
M(&9A=F]R('1E;G1E(&YO=F%M96YT92!M86ES('1A<F1E+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0P"FUS9VED
M("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@
M9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M2&]U=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@;W,@9&5T86QH97,@9&\@8V]N
M=&%T;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M96YT92`B"B)M86ES('1A<F1E
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B)(;W5V92!U;2!E<G)O(&%O(&%T=6%L:7IA<B!A(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX@4&]R(&9A=F]R('1E;G1E("(*(FYO=F%M96YT
M92!M86ES('1A<F1E+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO
M="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS9W-T<B`B17-T92!S97)V
M:61O<B!)34%0(&[C;R!S=7!O<G1A('!A<W1A<R!C;VUP87)T:6QH861A<RXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS
M9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+B(*;7-G<W1R(")%<W1E(&[C;R!P87)E8V4@<V5R('5M(&%R<75I
M=F\@<F%R(';A;&ED;RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B
M92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(")%<W1E(&[C;R!P87)E8V4@
M<V5R('5M(&%R<75I=F\@>FEP(';A;&ED;RXB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3,T"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B17-T92!NXV\@<&%R
M96-E('-E<B!U;2!N^FUE<F\@9&4@8V%R=.-O(';A;&ED;RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#4*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL
M+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*
M(D5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%V
MZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2P@
M=71I;&EZ86YD;R!A($%022!(5%10(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T
M<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)%<W1E(&-O;F5C=&]R('!E<FUI=&4@96YV:6%R(&UE
M;G-A9V5N<R!A=')A=NES(&1O(&=A=&5W87D@<VUS,F5M86EL("AH='1P.B\O
M(@HB<VUS,F5M86EL+F-O;2DL('5T:6QI>F%N9&\@;R!!4$D@2%144"(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R\B"B)S;7,R96UA
M:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B
M(@HB17-T92!C;VYE8W1O<B!P97)M:71E(&5N=FEA<B!M96YS86=E;G,@871R
M87;I<R!D;R!G871E=V%Y('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E;6%I
M;"YC;VTI+"!U=&EL:7IA;F1O(&\@05!)($A45%`B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@(@HB9V%T97=A>2P@
M;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I
M;"!A8V-O=6YT('=I=&@@(@HB5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2XB"FUS9W-T<B`B(@HB17-T92!C;VYE8W1O<B!P97)M:71E(&5N
M=FEA<B!U;6$@;65N<V%G96T@=FEA(%--5%`@871R87;I<R!D;R!6;V1A9F]N
M92`B"B))=&%L:6%N;RP@<V]M96YT92!P87)A(&[Z;65R;W,@5F]D869O;F4N
M(,D@;V)R:6=A=/-R:6\@<&]S<W5I<B!U;6$@8V]N=&$@;F\@(@HB5F]D869O
M;F4@271A;&EA;F\@*&AT='`Z+R]W=W<N,3DP+FET*2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HY.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3`V,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DP(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Q,3D*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3$X-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C8P"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$S,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30P,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-38Q(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-#,*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DV,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Y"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P,S,@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C`X,@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34S(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C4*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0Q,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-#0@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C@Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(V
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S,#0*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S@Q,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(P
M"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(*;7-G<W1R(")%<W1E
M(&-A;7!O(.D@;V)R:6=A=/-R:6\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+B(*;7-G<W1R(")%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P
M96YA<R!N^FUE<F]S(&EN=&5I<F]S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(T,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D5S=&4@8V%M<&\@
M<&]D92!C;VYT97(@87!E;F%S(&[Z;65R;W,@92!V[7)G=6QA+B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.3@*;7-G:60@(E1H:7,@9FEE;&0@
M;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(D5S=&4@
M8V%M<&\@<&]D92!C;VYT97(@87!E;F%S('9A;&]R97,@;V-T86ES+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C<*;7-G:60@(E1H:7,@9FEE
M;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F
M(&EN=&5G97)S(@IM<V=S='(@(B(*(D5S=&4@8V%M<&\@9&5V92!S97(@=6UA
M(&QI<W1A(&1E(&[Z;65R;W,@:6YT96ER;W,@<V5P87)A9&$@<&]R(';M<F=U
M;&%S(&]U("(*(F5S<&'G;W,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY.3,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E
M<BXB"FUS9W-T<B`B17-T92!C86UP;R!D979E('-E<B!U;2!N^FUE<F\@=N%L
M:61O+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C4*;7-G:60@
M(B(*(E1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB
M"FUS9W-T<B`B(@HB17-T92!C86UP;R!D979E(&-O;G1E<B!U;2!C\V1I9V\@
M9&4@8V]R(&5M(&9O<FUA=&\@4D="($AE>&$L('!O<B!E>&5M<&QO("(*(B<C
M,3(S-&%F)RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HU-C4*;7-G
M:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS
M9W-T<B`B17-T92!F;W)M=6SA<FEO(&KA(&9O:2!P<F]C97-S861O+B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(DES=&\@Z2`E<RXB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE
M=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@
M=FES:70@)7,B"FUS9W-T<B`B(@HB17-T92#I('5M(&]B:F5T;R!+;VQA8B!'
M<F]U<'=A<F4N(%!A<F$@=FES=6%L:7IA<B!E<W1E(&]B:F5T;R!V;V/J('!R
M96-I<V%RX2`B"B)D92!U;2!C;&EE;G1E(&1E(&-O<G)E:6\@<75E(&5N=&5N
M9&$@;R!F;W)M871O($MO;&%B($=R;W5P=V%R92X@4&%R82!U;6$@(@HB;&ES
M=&$@9&4@8VQI96YT97,@9&4@8V]R<F5I;R!C;VT@97-T87,@9G5NY_5E<R!P
M;W(@9F%V;W(@=FES:71E("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#
M;VYT96YT<RYP:'`Z-3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"B)%<W1A(&UE;G-A9V5M(&9O
M:2!E<V-R:71A(&5M('5M(&-O;FIU;G1O(&1E(&-A<F%C=&5R97,@*"5S*2!Q
M=64@;N-O(.D@;R`B"B)M97-M;R!Q=64@;R!S974N(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R(")%<W1E(&[Z;65R;R!D979E
M('-E<B!P96QO(&UE;F]S('5M+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@8V%N)W0@
M=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@(D5S=&4@
M<V5R=FED;W(@;N-O('!O9&4@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!E
M(&=Z:7`N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H
M<#HQ.#D*;7-G:60@(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV
M871E9"XB"FUS9W-T<B`B17-T92!S:7-T96UA(&5S=.$@871U86QM96YT92!D
M97-A=&EV861O+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z
M,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N(@IM<V=S
M='(@(D5S=&4@=F%L;W(@9&5V92!S97(@=6T@;OIM97)O+B(*"B,Z('-E<G9I
M8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN
M9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS
M9W-T<B`B17-T82!J86YE;&$@9&5V92!S97(@8VAA;6%D82!A('!A<G1I<B!D
M82!J86YE;&$@9&4@3W#G]65S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C4*;7-G:60@(E1H=6YD97(B"FUS9W-T<B`B4F%I
M;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S8*;7-G:60@(E1I
M8VME=',B"FUS9W-T<B`B0FEL:&5T97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#(Y('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM
M<V=I9"`B5&EM92(*;7-G<W1R(")(;W)A(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,X.`IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R(")!
M8V]M<&%N:&%M96YT;R!D92!(;W+A<FEO(@H*(SH@;&EB+T)L;V-K+W1I;64N
M<&AP.C$W"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1E
M(&AO<F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,U"FUS9VED
M(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")396QEY^-O(&1E(&AO<F$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO
M<B!,97-T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR,CD@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE
M(@IM<V=S='(@(E3M='5L;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS
M9W-T<B`B07-S=6YT;R`H9&EC82DZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-0IM<V=I9"`B5&\B"FUS9W-T<B`B4&%R
M82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-3(*;7-G:60@(B(*(E1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D
M;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@(@HB
M=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@(B(*(E!A<F$@<V5L96-I;VYA<B!M
M^FQT:7!L;W,@[71E;G,L('-E9W5R92!A('1E8VQA($-O;G1R;VP@*%!#*2!O
M=2!#;VUM86YD("(*(BA-86,I(&%O(&-L:6-A<BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S`P"FUS9VED(")4;V1A>2(*;7-G<W1R(")(
M;VIE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR.`IM<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(E1R;V-A
M<B!P87)A(&/S9&EG;R!(5$U,(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&]G
M;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA
M=2(*;7-G<W1R(")4;VME;&%U(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,P,@IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B06UA;FCC(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]N9V$B"FUS9W-T<B`B5&]N9V$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C@Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-S<*;7-G:60@(E1O<"(*;7-G<W1R(")4;W!O(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B5&]P(&9R86UE
M("A?=&]P*2(*;7-G<W1R(")1=6%D<F\@9&\@5&]P;R`H7W1O<"DB"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*
M;7-G<W1R(")4<F%D=>?U97,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN
M:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YD861E(&4@5&]B86=O(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<Y-`IM<V=I9"`B5')U92!O
M<B!F86QS92(*;7-G<W1R(")697)D861E:7)O(&]U(&9A;'-O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B
M5'4B"FUS9W-T<B`B5&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5N:7-I
M82(*;7-G<W1R(")4=6[M<VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5R
M:V5Y(@IM<V=S='(@(E1U<G%U:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$Y,0IM<V=I9"`B5'5R:VES:"`H25-/+3@X-3DM.2DB"FUS9W-T<B`B5'5R
M8V\@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R:VUE
M;FES=&%N(@IM<V=S='(@(E1U<F-O;65N:7-TXV\B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X
M"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B26QH
M87,@5'5R:W,@92!#86EC;W,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C(S,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B5'5V86QU(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP
M.C(V-`IM<V=I9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(E!R965N
M8VAA(&-O;2!S=6$@97-C;VQH83H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(LUN
M9&EC92!5+E8N.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")5
M4DPB"FUS9W-T<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-#$*;7-G:60@(E523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R="(*;7-G<W1R(")54DP@9&\@<V5U
M(')E;&%T\W)I;R!D92!S:71U8>?C;R!D92!E;G1R96=A(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B55),
M.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A;F1A
M(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I
M;F4B"FUS9W-T<B`B56-RXFYI82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R("));7!O<W/M=F5L(&%C97-S87(@9&ER973S<FEO(%9&
M4RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G
M:60@(E5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N
M('-I9VYI;F<@=7`N(@IM<V=S='(@(DEM<&]S<^UV96P@861I8VEO;F%R(&EN
M9F]R;6'G]65S(&5X=')A<R!D92!U<W7A<FEO(&%O(')E9VES=')A<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!A;'1E<F%R('!E<FUI
M<W/C;R!D;R!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,SDR(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`B26UP;W-S
M[79E;"!A;'1E<F%R('!E<FUI<W/C;R!D;R!A<G%U:79O(%9&4R`E<R\E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<X-@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&%L=&5R87(@<&%R82`E<RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S
M[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R<75I=F\@9&4@7"(E<UPB
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Y-2!F<F%M97=O
M<FLO5D93+U9&4R]S<6PN<&AP.C$P,C@*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C@U,`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB"FUS9W-T<B`B26UP
M;W-S[79E;"!V97)I9FEC87(@;R!T86UA;FAO(&1O(&%R<75I=F\@9&4@7"(E
M<R\E<UPB+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H<#HT,SD*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N(@IM<V=S
M='(@(DEM<&]S<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@4U%,+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B26UP;W-S[79E;"!C;VYE
M8W1A<B!U=&EL:7IA;F1O(%-33"XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR,S(@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C,W"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#0@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0HC.B!F<F%M97=O<FLO5D93+U9&
M4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92XB"FUS9W-T<B`B26UP;W-S[79E;"!C;W!I87(@87)Q=6EV;R!61E,N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB
M)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!C<FEA<B!D:7)E=/-R:6\@5D93
M(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-C$@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(U.`HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E
M871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<^UV96P@8W)I87(@
M9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(*;7-G
M<W1R("));7!O<W/M=F5L(&-R:6%R(&%R<75I=F\@5D93+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,CDP"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM<V=S='(@
M(DEM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,@IM<V=I9"`B56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T<B`B26UP;W-S[79E
M;"!C<FEA<B!A<G%U:79O(%9&4R!V87II;RXB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N(@IM<V=S='(@(DEM<&]S<^UV96P@9&5S8V]M<')I;6ER
M(&1A9&]S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(X(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S`S"B,L('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES
M(&YO="!E;7!T>2XB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER(%PB)7-<
M(BP@;R!D:7)E=/-R:6\@;N-O(&5S=.$@=F%Z:6\N(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HW."!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS
M9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER(%PB)7-<(CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,X(&9R86UE=V]R:R]61E,O5D93
M+W-Q;"YP:'`Z,SDU"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS
M,3$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>2(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@
M)7,L(&\@9&ER973S<FEO(&[C;R!E<W3A('9A>FEO(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U-B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(DEM<&]S<^UV96P@97AC
M;'5I<B!R96-U<G-I=F%M96YT92!O(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S0T(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP
M.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-3(*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B26UP;W-S[79E;"!E
M>&-L=6ER(&1I<F5T\W)I;R!61E,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HT,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y.B`E<RXB"FUS9W-T<B`B26UP;W-S[79E;"!E>&-L=6ER(&1I<F5T\W)I
M;R!61E,Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C$R
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV
M;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C,Q,"!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(Y,0HC.B!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,38W(&9R86UE=V]R:R]61E,O5D93+VUU
M<W%L+G!H<#HQ.#`*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$X
M-R!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,SDQ"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.3D*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV96P@97AC;'5I
M<B!A<G%U:79O(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP
M.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&5X8VQU:7(@
M87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B26UP;W-S[79E;"!E
M>&-L=6ER(%9&4R!R96-U<G-I=F%M96YT93H@)7,N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI
M;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<^UV96P@9&5T
M97)M:6YA<B!O(&1I<F5T\W)I;R!A='5A;"XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8P-`IM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("));7!O<W/M=F5L(&5X
M=')A:7(@9&5T86QH97,@9&\@8V5R=&EF:6-A9&\B"@HC.B!F<F%M97=O<FLO
M3F5T7TE-4U`O24U34"YP:'`Z-#,W(&9R86UE=V]R:R].971?24U34"])35-0
M+T%U=&@N<&AP.C$R,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B26UP;W-S[79E
M;"!C87)R96=A<B!A(&1E9FEN:>?C;R!D92`E<RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR,#,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C`X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S0@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$W.0IM<V=I9"`B56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S='(@(DEM<&]S<^UV96P@;6]V
M97(@;R!A<G%U:79O(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.CDS(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,3`V"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-C4R(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&]P96X@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(&%B<FER(&%R
M<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HR.#0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B
M26UP;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&4R!P87)A(&=R879AY^-O+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@S(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C$S-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S8*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*
M;7-G<W1R("));7!O<W/M=F5L(&%B<FER(&%R<75I=F\@5D93+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B26UP
M;W-S[79E;"!A8G)I<B!A<G%U:79O(&-O;7!R:6UI9&\N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93
M(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S[79E
M;"!L97(@87)Q=6EV;R!61E,@*&9I;&5S:7IE*"D@9F%L:&]U*2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#@W"FUS9VED(")5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+B(*;7-G<W1R("))
M;7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H9V5T1FEL95-I>F4H*2!F86QH
M;W4I+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N
M9&QE<B]N;VYE+G!H<#HS.`IM<V=I9"`B56YA8FQE('1O(')E860@9FEL93H@
M(@IM<V=S='(@(DEM<&]S<^UV96P@;&5R(&\@87)Q=6EV;SH@(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C<V"FUS9VED(")5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN(@IM<V=S='(@(DEM<&]S<^UV
M96P@;&5R(&$@<F%I>B!D;R!D:7)E=/-R:6\@5D93+B(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B26UP;W-S[79E;"!R96YO;65A<B`E
M<R!P87)A("5S.B!A('!A<W1A(&1E(&1E<W1I;F\@:N$@97AI<W1E(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA
M8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("));7!O<W/M
M=F5L(')E;F]M96%R(&\@9&ER973S<FEO(%9&4RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R("));7!O
M<W/M=F5L(')E;F]M96%R(&1I<F5T\W)I;R!61E,Z("5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C<Q(&9R86UE=V]R:R]61E,O5D93+V9T
M<"YP:'`Z,S0X"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("));7!O<W/M=F5L(')E;F]M
M96%R(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HV,3<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(R
M.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+B(*;7-G<W1R("));7!O<W/M=F5L(')E;F]M96%R(&%R<75I
M=F\@5D93("5S+R5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z
M,S(V(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S
M<6Q?9FEL92YP:'`Z,CDS"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N(@IM
M<V=S='(@(DEM<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP
M.C4P"FUS9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B
M26UP;W-S[79E;"!E>&5C=71A<B`G;6MI<V]F<R<N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE
M('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B26UP
M;W-S[79E;"!T<F%D=7II<B!E<W1E(&1O8W5M96YT;R!7;W)D(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-30@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HQ-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!G<F%V
M87(@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C$X-@IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B26UP;W-S[79E;"!G<F%V87(@
M87)Q=6EV;R!61E,@*&-O<'DH*2!F86QH;W4I+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(X."!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,30V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-3$*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G
M<W1R("));7!O<W/M=F5L(&=R879A<B!D861O<R!D;R!A<G%U:79O(%9&4RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#8R"FUS9VED(")5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(@IM
M<V=S='(@(DEM<&]S<^UV96P@9W)A=F%R(&%R<75I=F\@5D93+"!Q=6]T82!E
M>&-E9&5RX2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P"FUS9VED(")5;F1E<FQI;F4B"FUS9W-T<B`B4W5B;&EN:&%D
M;R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@
M0VAA;F=E<R(*;7-G<W1R(")$97-F87IE<B!!;'1E<F'G]65S(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B
M56YD;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B1&5S9F%Z('-U82#Z
M;'1I;6$@8>?C;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS.3`*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S='(@(E)E<W!O<W1A(&EN97-P97)A
M9&$@9&\@<V5R=FED;W(@9'5R86YT92!A(&-O;F5XXV\Z("(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E
M9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(E)E<W!O<W1A
M(&EN97-P97)A9&$@9&\@<V5R=FED;W(@<&%R83H@(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N
M9FEL960B"FUS9W-T<B`B4V5M(&-A=&5G;W)I82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DR"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B
M56YI8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!
M<F%B($5M:7)A=&5S(@IM<V=S='(@(D5M:7)A9&]S(,%R86)E<R!5;FED;W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@
M(E)E:6YO(%5N:61O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T
M871E<R(*;7-G<W1R(")%<W1A9&]S(%5N:61O<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*
M;7-G<W1R("));&AA<R!097)I9NER:6-A<R!-96YO<F5S(&1O<R!%<W1A9&]S
M(%5N:61O<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV,B!L
M:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED(")5;FET<R(*;7-G<W1R(")5
M;FED861E<R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R
M.2!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,S`*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W
M;B(*;7-G<W1R(")$97-C;VYH96-I9&\B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@
M87!I;7-G:60@*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B87!I;7-G:60@
M9&5S8V]N:&5C:61O("A!4$D@365S<V%G92!)1"DN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5
M;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@
M(F-L:6US9VED(&1E<V-O;FAE8VED;R`H0VQI96YT($UE<W-A9V4@240I+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#<*;7-G:60@(E5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(DYE;FAU;6$@;&]C
M86QI>F'GXV\@8V]N9FEG=7)A9&$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDQ"FUS9VED(")5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+B(*;7-G<W1R(")5<W7A<FEO(&]U('-E;FAA
M(&1E<V-O;FAE8VED;W,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS9VED(")5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N="(*;7-G<W1R(")$97-V:6YC=6QA<B!O(&5L96UE;G1O
M(&%T=6%L(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HS
M,#(*;7-G:60@(E5N;F%M960B"FUS9W-T<B`B4V5M($YO;64B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B
M"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y
M+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I
M<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM<V=S='(@(B(*(E-C<FEP
M=',@;N-O('!R:79I;&5G:6%D;W,@;N-O('!O9&5M('5T:6QI>F%R($-O<G1A
M<B]#;W!I87(O0V]L87(@<&]R(')A>O5E<R`B"B)D92!S96=U<F%NYV$N($-L
M:7%U92!E;2!/2R!P87)A('9E<B!A(&YO=&$@=.EC;FEC82!E;2!M;WII;&QA
M+F]R9R!A('%U86P@(@HB96YS:6YA(&-O;6\@<&5R;6ET:7(@<V-R:7!T<R!A
M8V5S<V%R96T@82#A<F5A(&1E('1R86YS9F5RZFYC:6$N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@IM<V=I
M9"`B56YS970@8V]L;W(B"FUS9W-T<B`B1&5S;6%R8V%R(&-O<B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@W(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.3(W"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z.3,S"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E;G-I
M;VXB"FUS9W-T<B`B17AT96YSXV\@3N-O(%-U<&]R=&%D82(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,3DW('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B071U86QI
M>F%R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&4@)7,B"FUS9W-T<B`B)7,@871U
M86QI>F%D;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z
M-S8*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(D%T=6%L:7IA<B!U<W7A
M<FEO(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(B<E<R<@
M871U86QI>F%D;RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM
M<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B4V-R:7!T
M(&1E(&%T=6%L:7IAY^-O(')E;6]V:61O+B(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Y.`IM<V=I9"`B57!L;V%D(@IM<V=S='(@(D5N=FEA<B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A
M<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R
M("(B"B)4;V1O<R!A<G%U:79O<R!D92`@8V]N9FEG=7)AY_5E<R!D87,@87!L
M:6-AY_5E<R!F;W)A;2!E;G9I861O<R!A;R!S97)V:61O<BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(P
M"FUS9VED(")5<'!E<B!L871I;B!L971T97)S(@IM<V=S='(@(D%L9F%B971O
M(&QA=&EN;R!E;2!M86GZ<V-U;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R
M;VUA;B!N=6UB97)S(@IM<V=S='(@(D[Z;65R;W,@<F]M86YO<R!E;2!M86GZ
M<V-U;&\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5<G5G=6%Y(@IM<V=S='(@
M(E5R=6=U86DB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-
M86YA9V5R+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`B571I;&EZ87(@071U86PZ("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S@*;7-G:60@
M(E5S92!34TPB"FUS9W-T<B`B571I;&EZ87(@4U-,(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$R-PIM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`B571I;&EZ
M87(@<V4@;R!N;VUE+W-E;FAA(.D@9&EF97)E;G1E(&YO('-E<G9I9&]R($E-
M4U`N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,0IM
M<V=I9"`B57-E<B(*;7-G<W1R(")5<W7A<FEO<R(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92]296=I<W1R>2YP:'`Z-S<T"B,L('!H<"UF;W)M870*;7-G
M:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*;7-G<W1R
M(")5<W7A<FEO("5S(&[C;R!E<W3A(&%U=&]R:7IA9&\@<&%R82`E<RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I
M;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!5<W7A<FEO<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C0U"FUS9VED(")5<V5R($]P
M=&EO;G,B"FUS9W-T<B`B3W#G]65S(&1E(%5S=>%R:6]S(@H*(SH@<VEG;G5P
M+G!H<#HV,@IM<V=I9"`B57-E<B!296=I<W1R871I;VXB"FUS9W-T<B`B4F5G
M:7-T<F\@9&4@57-UX7)I;W,B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+B(*;7-G<W1R(")296=I<W1R;R!D92!5<W7A<FEO<R!E<W3A(&1E<V%B
M:6QI=&%D;R!N97-T92!S:71E+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H
M<#HT-CD*;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B
M0V]N=&$@9&4@=7-UX7)I;R!NXV\@96YC;VYT<F%D82(*"B,Z(&%D;6EN+W5S
M97(N<&AP.C,U(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-SD*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z.3@*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,3DX"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,34P
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-S(@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,3(*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(E5S=>%R:6\B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L('!H<"UF
M;W)M870*;7-G:60@(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB
M"FUS9W-T<B`B57-UX7)I;R`G)7,G(&KA(&5X:7-T92XB"@HC.B!T96UP;&%T
M97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G
M<W1R(")5<W7A<FEO.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C@*;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B57-UX7)I;SH@(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@
M:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`B57-UX7)I;W,@;F\@<VES=&5M83HB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$T"FUS9VED(")5>F)E:VES=&%N(@IM<V=S='(@(E5Z
M8F5Q=6ES=.-O(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<P
M(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(V,@IM<V=I9"`B5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B3R!D:7)E=/-R:6\@
M5D93(&[C;R!E>&ES=&4N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B1NER:6%S(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#<P"FUS9VED(")686QI9"!L;V-A=&EO
M;G,@9F]U;F0@:6YC;'5D93H@(@IM<V=S='(@(DQO8V%L:7IAY_5E<R!VX6QI
M9&%S(&5N8V]N=')A9&%S(&EN8VQU96TZ("(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-C,Y"FUS9VED(")686QI9&ET>2(*;7-G<W1R
M(")686QI9&%D92(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F
M<F]M(&YO=RXB"FUS9W-T<B`B5F%L;W(@96T@;6EN=71O<R!A('!A<G1I<B!D
M92!A9V]R82XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C`@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS
M9W-T<B`B3R!V86QO<B!E<W3A(&%C:6UA(&1O('1A;6%N:&\@;>%X:6UO(&1E
M("5S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#@@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C(W,`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S(P(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,3<*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I9"`B
M5F%L=65S(@IM<V=S='(@(E9A;&]R97,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3$S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.3`*;7-G
M:60@(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")686QO<F5S('!A
M<F$@<V5L96-I;VYA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B
M"FUS9W-T<B`B5F%N=6%T=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,S,*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E9A<FGA=F5L(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z
M=65L82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X
M"FUS9VED(")697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"XB"FUS9W-T<B`B1F%L:&$@;F$@
M=F5R:69I8V'GXV\@+2!E<W1A(&UE;G-A9V5M('!O9&4@=&5R('-I9&\@861U
M;'1E<F%D82XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)SXV\B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C(X"FUS9VED(")697)S:6]N($-O;G1R
M;VPB"FUS9W-T<B`B0V]N=')O;&4@9&4@5F5R<^-O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I9"`B
M5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B06QI;FAA;65N=&\@=F5R=&EC86PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T
M"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(DUA<F=E;2!V97)T
M:6-A;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T:6-A;#HB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,0IM<V=I
M9"`B5F5R>2!(:6=H(@IM<V=S='(@(DUU:71O($%L=&$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(T."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;N,B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B5FEE=&YA;65S92`H5DE30TE)
M*2(*;7-G<W1R(")6:65T;F%M:71A("A625-#24DI(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38Y"B,L('!H<"UF;W)M870*;7-G
M:60@(E9I97<@)7,B"FUS9W-T<B`B5F5R("5S(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R(")6:7-U86QI>F%R('5M82!PX6=I;F$@=V5B(&5X=&5R;F$B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,C@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R(")6:7-U86QI>F%R
M(&-O;6\@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD
M<RP@0G)I=&ES:"(*;7-G<W1R("));&AA<R!6:7)G96YS+"!"<FETXFYI8V%S
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#<@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN($ES;&%N9',L(%4N4RXB
M"FUS9W-T<B`B26QH87,@5FER9V5N<RP@12Y5+D$N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR,38*;7-G:60@(E9I<VEB:6QI='DB"FUS9W-T<B`B5FES
M:6)I;&ED861E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U
M,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E9I<VEB:6QI9&%D93H@
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM<V=S
M='(@(E9O9&%F;VYE($ET86QI86YO('9I82!33510(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")!5$5.Q\-/(@H*(SH@861M:6XO
M<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S
M='(@(D%414['PT\A(2$@4D5-3U9!($\@4T-225!4($U!3E5!3$U%3E1%($1%
M("5S+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z
M,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T<B`B5TE.('9I82!(5%10
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B"FUS
M9W-T<B`B5V%L;&ES(&4@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HQ,C$@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(D%T
M96[GXV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C4X"FUS9VED(")792(*;7-G<W1R(")1=6$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B
M"FUS9W-T<B`B4')E=FESXV\@9&\@5&5M<&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z-#$V"FUS9VED(")796%T:&5R(&1A=&$@<')O=FED
M960@8GDB"FUS9W-T<B`B1&%D;W,@9&\@0VQI;6$@9F]R;F5C:61O('!O<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@IM<V=I9"`B5V5A=&AE
M<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O
M9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(E=E8B!3:71E(@IM<V=S
M='(@(E-I=&4@5V5B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT
M96YA;F-E+G!H<#HU.`IM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E-E;6%N86QM
M96YT92(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED
M(")796QC;VUE(@IM<V=S='(@(D)E;2UV:6YD;R(*"B,Z('1E;7!L871E<R]L
M;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@
M(D)E;2UV:6YD;R!A;R`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N
M<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")"96TM=FEN9&\L("5S
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$I(@IM<V=S='(@(D]C:61E;G1A;"`H25-/+3@X-3DM,2DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-0IM<V=I9"`B5V5S=&5R;B`H
M25-/+3@X-3DM,34I(@IM<V=S='(@(D]C:61E;G1A;"`H25-/+3@X-3DM,34I
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@
M(E-A:&%R82!/8VED96YT86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#0Q"B,L('!H<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(E%U92!A<&QI
M8V'GXV\@)7,@9&5V97)I82!E>&EB:7(@87#S<R!A(&-O;F5XXV\_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E%U86P@;R!C87)A
M8W1E<F4@9&5L:6UI=&%D;W(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF
M;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\B
M"FUS9W-T<B`B475A;"!O(&-A<F%C=&5R92!D92!C:71AY^-O/R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#8R"FUS9VED
M(")7:&5R96ES($%U<W1R86QI82!M87`B"FUS9W-T<B`B36%P87,@075S=')A
M;&EA;F]S(%=H97)E:7,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C,*;7-G
M:60@(E=H:6-H('!H87-E<R(*;7-G<W1R(")1=6%I<R!F87-E<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S8*;7-G:60@(E=H:6-H('!L=6=I;G,@
M=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS9W-T<B`B
M475A:7,@<&QU9VEN<R!H86)I;&ET87(@<&%R82!O(&5D:71O<B!2:6-H(%1E
M>'0N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&%R9W5R82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,30*;7-G:60@(E=I9'1H(&EN
M($-34R!U;FET<R(*;7-G<W1R("),87)G=7)A(&5M('5N:61A9&5S($-34R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(DQA<F=U<F$@9&\@
M;65N=2`E<R!D;R!L861O(&5S<75E<F1O("AT97+A(&5F96ET;R!N82!P<O-X
M:6UA(&-O;F5XXV\I.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS
M9W-T<B`B3&%R9W5R82!D82!T86)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*
M;7-G<W1R(")5;FED861E(&1E($QA<F=U<F$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM
M<V=S='(@(DQA<F=U<F$Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C4Q-0IM<V=I9"`B5VEK:2(*;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(X.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-@IM<V=I9"`B5VEN9"(*;7-G<W1R(")696YT;R(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8W"FUS
M9VED(")7:6YD($5A<FQY(@IM<V=S='(@(E9E;G1O<R!P96QA(&UA;FCC(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I
M;B!K;F]T<R(*;7-G<W1R(")696QO8VED861E(&1O('9E;G1O(&5M(&[S<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G
M<W1R(")696YT;SHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C,Q"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B5F5N=&\Z("(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(E-A
M8F5D;W)I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3@*;7-G
M:60@(E=I<VAL:7-T(@IM<V=S='(@(DQI<W1A(&1E('!E9&ED;W,B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-C4*;7-G:60@(E=O<FLB"FUS9W-T<B`B
M5')A8F%L:&\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R(")%;F1E<F7G
M;R!#;VUE<F-I86PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3DR"FUS9VED(")7;W)K(%!H;VYE(@IM<V=S='(@(D9O;F4@
M0V]M97)C:6%L(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,3DS
M(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(Y-`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X
M<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B3OIM97)O(&EN8V]R<F5T
M;R!D92!C86UP;W,@;F$@;&EN:&$@)60N($5S<&5R861O<R`E9"P@96YC;VYT
M<F%D;W,@)60N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,S,R
M"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N
M($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B3OIM97)O(&5R<F%D
M;R!D92!C86UP;W,N($5S<&5R861O<R`E9"P@96YC;VYT<F%D;W,@)60N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(D]F9G-E="`E9"!I;F-O<G)E=&\@86\@;&5R(&\@
M87)Q=6EV;R!61E,N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(T
M-0IM<V=I9"`B6"U2968B"FUS9W-T<B`B6"U2968B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-`IM<V=I9"`B6#4P.78S($)A<VEC
M($-O;G-T<F%I;G1S(@IM<V=S='(@(E)E<W1R:>?U97,@0N%S:6-A<R!8-3`Y
M=C,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM
M<V=I9"`B6#4P.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")5=&EL
M:7IAY^-O(&1E($-H879E($5X=&5N9&ED82!8-3`Y=C,B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R(").;VUE($%L=&5R;F%T
M:79O(&1E($%S<W5N=&\@6#4P.78S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.38*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)
M9&5N=&EF:65R(@IM<V=S='(@(DED96YT:69I8V%D;W(@9&$@0VAA=F4@9&4@
M07-S=6YT;R!8-3`Y=C,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X,PIM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B
M17AT96YS]65S(%@U,#EV,R(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS
M9VED(")962(*;7-G<W1R(")!02(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0U-`IM<V=I9"`B65E962(*;7-G<W1R(")!04%!
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M,#D*;7-G:60@(EEA:&]O(2!M87`B"FUS9W-T<B`B36%P82!986AO;R$B"@HC
M.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C4V"FUS
M9VED(")996%R;'DB"FUS9W-T<B`B06YU86QM96YT92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(EEE;65N(@IM<V=S='(@(DSJ;65N(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-`IM<V=I9"`B665S(@IM
M<V=S='(@(E-I;2(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N
M86YC92YH=&UL.C4V"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B4VEM
M+"!%=2!#;VYC;W)D;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-3T1%+B`@
M57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'
M+B(*;7-G<W1R("(B"B)6;V/J(&5S=.$@96T@34]$3R!415A43RX@(%5T:6QI
M>F$@;R!B;W3C;R!;/#Y=('!A<F$@=F]L=&%R('!A<F$@;R!M;V1O("(*(E=9
M4TE764<N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="]-86YA
M9V5R+G!H<#HR,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T
M<B`B5F]CZB!NXV\@97-TX2!A=71O<FEZ861O(&$@8W)I87(@;6%I<R!D92`E
M9"!B;&]C;W,N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$U
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")6
M;V/J(&[C;R!E<W3A(&%U=&5N=&EC861O+B(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z,S`X"FUS9VED(")9;W4@8V%N;F]T(&AA=F4@
M=&AE("=<7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R
M(")6;V/J(&[C;R!P;V1E('1E<B!O(&-A<F%C=&5R(%Q<(&YO('-E=2!N;VUE
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3D@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")6;V/J(&[C;R!F;W)N
M96-E=2!U;2!E;F1E<F7G;R!D92!E+6UA:6P@=N%L:61O+B(*"B,Z(&9R86UE
M=V]R:R]$871A+T1A=&$N<&AP.C(Y,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D
M(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*
M;7-G<W1R("(B"B)6;V/J(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O(&1O(&%R
M<75I=F\@:6UP;W)T861O(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N=&5S("(*
M(F5M("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX-PIM<V=I
M9"`B66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R(")6;V/J(&9O
M:2!D97-C;VYE8W1A9&\N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(V-0IM<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R`B"B)F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM
M<V=S='(@(B(*(E9O8^H@9&5V92!P<F5E;F-H97(@=6T@;OIM97)O(&1E('1E
M;&5F;VYE(&-E;'5L87(@=N%L:61O+"!S;VUE;G1E(&3M9VET;W,@(@HB8V]M
M('5M(&]P8VEO;F%L("<K)R!P87)A(&1I<V-A9V5M(&1E('!R969I>&\@:6YT
M97)N86-I;VYA;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3DR
M"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*;7-G
M<W1R(")6;V/J(&1E=F4@<')E96YC:&5R('5M('9A;&]R(';A;&ED;RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S<*;7-G:60@(EEO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N(@IM<V=S='(@(E9O8^H@9&5V92!C;VYF:6=U<F%R('5M(&-O;F5C
M=&]R($1A=&%4<F5E('!A<F$@=71I;&EZ87(@0V%D87-T<F]S+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z-#8R"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB"FUS9W-T<B`B5F]CZB!D979E(&-O
M;F9I9W5R87(@=6T@8V]N96-T;W(@5D93+B(*"B,Z('1E;7!L871E<R]P<F]B
M;&5M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="XB"FUS9W-T<B`B(@HB5F]CZB!D979E(&1E<V-R979E<B!O('!R;V)L
M96UA(&%N=&5S(&1E(&5N=FEA<B!O(')E;&%T\W)I;R!D92!P<F]B;&5M82XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX
M"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN
M:R!P;VEN=',@=&\B"FUS9W-T<B`B5F]CZB!D979E(&9O<FYE8V5R(&$@55),
M(&]N9&4@;R!L:6YK(&%P;VYT82(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C@P"FUS9VED(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O
M(&)E(&1E;&5T960N(@IM<V=S='(@(E9O8^H@9&5V92!S96QE8VEO;F%R('5M
M('-E<G9I9&]R('!A<F$@<V5R(&5X8VQU[61O+B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(&-L96%R(&]U="XB"FUS9W-T<B`B5F]CZB!D979E(&5S<&5C:69I8V%R('5M
M('5S=>%R:6\@<&%R82!E>&-L=6ER+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P
M,`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V
M92XB"FUS9W-T<B`B5F]CZB!D979E(&5S<&5C:69I8V%R('5M('5S=>%R:6\@
M<&%R82!R96UO=F5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")6;V/J(&1E=F4@
M97-P96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&%D:6-I;VYA<BXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`B5F]CZB!D979E(&5S<&5C
M:69I8V%R('5M('5S=>%R:6\@<&%R82!A='5A;&EZ87(N(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,3,X"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN(@IM<V=S='(@
M(E9O8^H@9&5V92!E<W!E8VEF:6-A<B!U;6$@8>?C;R!P87)A(&5X96-U=&%R
M+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA
M;64N(@IM<V=S='(@(E9O8^H@9&5V92!P<F5E;F-H97(@=6T@;F]M92!P87)A
M(&$@;F]V82!C871E9V]R:6$N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B5F]C
MZB!P<F5C:7-A(&9O<FYE8V5R('5M(&[Z;65R;R!D92!T96QE9F]N92!I=&%L
M:6%N;R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B4W5A('-E<W/C;R`E<R!E>'!I
M<F]U+B!0;W(@9F%V;W(L(&-O;F5C=&4M<V4@;F]V86UE;G1E+B(*"B,Z('1E
M;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R($5M
M86EL($%D9')E<W,B"FUS9W-T<B`B4V5U($5N9&5R9>=O(&1E($4M;6%I;"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,34*;7-G:60@(EEO=7(@1G)O
M;3H@861D<F5S<SHB"FUS9W-T<B`B4V5U($5N9&5R9>=O(&1E(%)E;65T96YT
M92`H1&4Z*3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C<@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C<W(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-0HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3(*;7-G:60@(EEO=7(@26YF;W)M
M871I;VXB"FUS9W-T<B`B4W5A<R!);F9O<FUAY_5E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S='(@(B(*
M(E-E=2!%;F1E<F7G;R!D92!);G1E<FYE="!M=61O=2!D97-D92!O(&EN[6-I
M;R!D92!S=6$@<V5S<^-O("5S+B!087)A("(*(G!R;W1E9V5R('-U82!S96=U
M<F%NYV$@=F]CZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT92XB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(E-E=2!.;VUE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O;F]A9&0N:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T
M:6]N(&)A8VME;F0N(@IM<V=S='(@(B(*(E-E=2!B86-K96YD(&1E(&%U=&5N
M=&EC8>?C;R!NXV\@<W5P;W)T82!A9&GGXV\@9&4@=7-UX7)I;W,L(&]U(&$@
M9G5NY^-O(&9O:2`B"B)D97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R
M87KC;RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C4*
M;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E("(*(FAA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB"FUS9W-T
M<B`B(@HB4V5U(&)A8VME;F0@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A
M(&QI<W1A9V5M(&1E('5S=>%R:6]S+"!O=2!A(&9U;N?C;R`B"B)F;VD@9&5S
M86)I;&ET861A('!O<B!A;&=U;6$@;W5T<F$@<F%ZXV\N(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"YP:'`Z.3@S"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T
M<B`B(@HB4V5U(&YA=F5G861O<B!P87)E8V4@=&5R(&%L=&5R861O(&1E<V1E
M(&\@:6[M8VEO(&1E('-U82!S97-SXV\@)7,N(%!A<F$@(@HB<')O=&5G97(@
M<W5A('-E9W5R86[G82P@=F]CZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT
M92XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU-0IM<V=I9"`B66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+B(*;7-G<W1R
M(")3974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5S=&$@9G5NY^-O+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS9VED("(B"B)9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO
M;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P<FEN="XB"FUS
M9W-T<B`B(@HB4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&]PY^-O
M(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE($-O;G1R;VPO3W!T:6]N("(*(BL@
M4"!P87)A(&EM<')I;6ER+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(E-E
M=2!F=7-O(&AO<N%R:6\@871U86PZ(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP
M.C$Q,0IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N(@IM<V=S='(@(E-U82!I9&5N=&ED861E('!A9'+C;R!F;VD@86QT
M97)A9&$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$V,0IM<V=I9"`B
M66]U<B!D969A=6QT(&ED96YT:71Y.B(*;7-G<W1R(")3=6$@:61E;G1I9&%D
M92!P861RXV\Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(P-`IM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(E-E=2!N;VUE(&-O;7!L971O
M.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY.0IM<V=I9"`B66]U
M<B!L;V=I;B!H87,@97AP:7)E9"XB"FUS9W-T<B`B4W5A(&-O;F5XXV\@97AP
M:7)O=2XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z
M("5S(@IM<V=S='(@(E-U82!N;W9A('-E;FAA('!A<F$@)7,@Z3H@)7,B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-`IM<V=I9"`B66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+B(*;7-G<W1R(")3=6%S(&]PY_5E<R!F;W)A;2!A
M='5A;&EZ861A<R!P;W(@8V%U<V$@9&$@9'5R8>?C;R!D97-T82!S97-SXV\N
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-38*;7-G:60@
M(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB"FUS9W-T<B`B4W5A
M<R!O<.?U97,@9F]R86T@871U86QI>F%D87,N(@H*(SH@<V5R=FEC97,O<F5S
M971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970B"FUS9W-T<B`B4W5A(&YO=F$@<V5N:&$@9F]I(&=E<F%D82(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T
M<B`B(@HB4W5A(&YO=F$@<V5N:&$@9F]I(&=E<F%D82P@=F5R:69I<75E('-E
M=2!E+6UA:6P@92!C;VYE8W1E+7-E(&-O;2!S=6$@;F]V82`B"B)S96YH82XB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HW,S,*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S='(@(E-U82!S96YH82!E>'!I
M<F]U+B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I
M9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B4V5U<R!S97)V:61O
M<F5S(')E;6]T;W,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-30@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B675G
M;W-L879I82(*;7-G<W1R("))=6=O<VSA=FEA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I
M<F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED("):86UB:6$B"FUS9W-T<B`B6N)M
M8FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#D*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6FEM8F%B=V4B"FUS9W-T<B`B
M6FEM8F%B=V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@
M(EII<'!Y(@IM<V=S='(@(EII<'!Y(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@
M475O=&5D(%1E>'1=(@IM<V=S='(@(EM/8W5L=&%R(%1E>'1O($-I=&%D;UTB
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HX.0IM<V=I9"`B6U!R;V)L96T@
M4F5P;W)T72(*;7-G<W1R(");4F5L873S<FEO(&1E(%!R;V)L96UA72(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M(@IM<V=S='(@(EM%>&EB:7(@5&5X=&\@
M0VET861O("TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,L('!H<"UF;W)M870*;7-G:60@(EM3
M:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=(@IM<V=S='(@(EM%>&EB:7(@
M5&5X=&\@0VET861O("T@)7,@;&EN:&%S72(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DU"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S
M(&]F("5S72(*;7-G<W1R(");;&EN:&$@)7,@9&4@)7-=(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30U('1E;7!L871E<R]P;W)T86PO;65N
M=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M
M:6YI<W1R8>?C;R(*"B,Z(&QI8B]A<&DN<&AP.C$U-PIM<V=I9"`B7T-,22(*
M;7-G<W1R(")?0TQ)(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"FUS9VED(")?1&%T
M851R964B"FUS9W-T<B`B1&%T85]4<F5E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L
M971E(%)O=R(*;7-G<W1R(")%7WAC;'5I<B!#;VQU;F$B"@HC.B!L:6(O87!I
M+G!H<#HQ,S,*;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!O<R(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](
M96QP(@IM<V=S='(@(D%?:G5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B4')O<')I961A9&5S(&1A(%]);6%G96TN
M+BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"FUS
M9VED(")?3&]G(&EN(@IM<V=S='(@(E]#;VYE8W1A<B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(E]$97-C;VYE8W1A<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,
M:6YK+BXN(@IM<V=S='(@(D%?;'1E<F%R($QI;FLN+BXB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T"FUS9VED(")?3W!T:6]N<R(*
M;7-G<W1R(")?3W#G]65S(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?
M4&5R;6ES<VEO;G,B"FUS9W-T<B`B7U!E<FUI<W/U97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*;7-G
M:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")?4F5M;W9E<B!,:6YK+BXN
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(U"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B
M0V]N9FEG=7)A7W(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S
M+BXN(@IM<V=S='(@(E!R;W!R:65D861E<R!D82!?5&%B96QA+BXN(@H*(SH@
M;&EB+V%P:2YP:'`Z,3(Y"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7U5S=>%R
M:6]S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C`*;7-G:60@
M(F%D9')E<W,@8F]O:R(*;7-G<W1R(")C873A;&]G;R!D92!E;F1E<F7G;W,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`IM<V=I
M9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B8V%TX6QO9V\@9&4@96YD
M97)EYV]S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3(*;7-G
M:60@(F-A;&5N9&%R(@IM<V=S='(@(F%G96YD82(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<Y(&QI8B]";&]C:R]M971A<BYP:'`Z,S8U"B,L('!H<"UF
M;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6\B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R
M96%T92!O=71P=70@9FEL92(*;7-G<W1R(")I;7!O<W/M=F5L(&-R:6%R(&%R
M<75I=F\@9&4@9&5S=&EN;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S
M<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*;7-G<W1R
M(")I;7!O<W/M=F5L(&%B<FER(&$@;W)I9V5M(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z-3DY"FUS9VED(")C;&EC:R!H97)E(@IM
M<V=S='(@(F-L:7%U92!A<75I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-
M97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O
M<B(*;7-G<W1R(")E<G)O(&1E('-I;G1A>&4@9&$@;&EN:&$@9&4@8V]M86YD
M;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<X"FUS
M9VED(")C;VYF:6=U<F%T:6]N(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@8V]N
M9FEG=7)AY^-O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-30*;7-G:60@(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B"FUS
M9W-T<B`B=6T@87)Q=6EV;R!C<NUT:6-O(&1O('-I<W1E;6$@97-TX2!F86QT
M86YD;R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3(V
M"FUS9VED(")D871A(&9O<FUA="!E<G)O<B(*;7-G<W1R(")E<G)O(&YO(&9O
M<FUA=&\@9&]S(&1A9&]S(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN
M8SHS,`IM<V=I9"`B961I="(*;7-G<W1R(")E9&ET87(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$X,@IM<V=I9"`B96YT<GD@;F]T
M(&9O=6YD(@IM<V=S='(@(G)E9VES=')O(&[C;R!E;F-O;G1R861O(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@
M(F9A;&QI;F<B"FUS9W-T<B`B<75E9&$B"@HC.B!F<F%M97=O<FLO0G)O=W-E
M<B]"<F]W<V5R+G!H<#HX.#$*;7-G:60@(F9I;&4B"FUS9W-T<B`B87)Q=6EV
M;R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H<"UF;W)M
M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B
M82!P87)T:7(@9&4@)7,@*"5S*2#@("5S("5S(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(S.0IM<V=I9"`B9W5S=&EN9R(*;7-G<W1R(")B
M<FES82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#@*;7-G:60@(F@Z(@IM<V=S='(@(F@Z(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U-PIM<V=I9"`B:&@B"FUS9W-T
M<B`B:&@B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S
M.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB"FUS9W-T<B`B;F]M92!D;R!H
M;W-T(.D@9&5S8V]N:&5C:61O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B
M"FUS9W-T<B`B:6UE9&EA=&\B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV
M-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0IM<V=I9"`B:6YL:6YE(@IM<V=S
M='(@(FEN8V]R<&]R861O(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S
M86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M(")E<G)O(&1E(&5N=')A9&$O<V'M9&$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N86P@<V]F='=A<F4@
M97)R;W(B"FUS9W-T<B`B97)R;R!I;G1E<FYO(&1O('!R;V=R86UA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@
M(FQI;F5S72(*;7-G<W1R(")L:6YH87-=(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M
M870*;7-G:60@(FUK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@
M25-/+B(*;7-G<W1R(")C\V1I9V\@9&4@97)R;R`E9"!D;R!M:VES;V9S(&5N
M<75A;G1O(&=E<F%V82!A($E33RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S8X"FUS9VED(")M;2(*;7-G<W1R(")M;2(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@U('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S`*(SH@<V5R=FEC97,O<&]R=&%L+W-I
M9&5B87(N<&AP.C(T,0IM<V=I9"`B;F%M92(*;7-G<W1R(")N;VUE(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,N<&AP.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N
M=&5D(@IM<V=S='(@(F[C;R!I;7!L96UE;G1A9&\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@(FYO="!Y970@:6UP
M;&5M96YT960B"FUS9W-T<B`B;N-O(&EM<&QE;65N=&%D;R!A:6YD82(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`T"FUS9VED(")N;W1E<&%D
M(@IM<V=S='(@(F)L;V-O(&1E(&YO=&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.`IM<V=I9"`B<&5R8V5N
M="(*;7-G<W1R(")P;W)C96YT86=E;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3<T"FUS9VED(")P97)M:7-S:6]N(&1E;FEE9"(*
M;7-G<W1R(")097)M:7-SXV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T
M<B`B<&EX96QS(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-S`*;7-G:60@(G)E;6]T92!E<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R
M(")E<G)O(')E;6]T;R!N;R!P<F]T;V-O;&\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B<FES:6YG(@IM<V=S
M='(@(FYA<V-E;G1E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E
M+G!H<#HQ-#(*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS9W-T<B`B
M<V5R=FGG;R!I;F1I<W!O;NUV96PB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C$P,0IM<V=I9"`B<VAO=R!D:69F97)E;F-E<R(*;7-G<W1R(")E>&EB
M:7(@9&EF97)E;N=A<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3$T"FUS9VED(")S;7,R96UA:6P@=FEA($A45%`B
M"FUS9W-T<B`B<VUS,F5M86EL('9I82!(5%10(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0IM<V=I9"`B<W,B"FUS9W-T
M<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,PIM<V=I9"`B<W1E861Y(@IM<V=S='(@(F5S=.%V96PB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B<WES=&5M
M(&5R<F]R(@IM<V=S='(@(F5R<F\@9&4@<VES=&5M82(*"B,Z(&9R86UE=V]R
M:R]+;VQA8B]+;VQA8BYP:'`Z.3(X"FUS9VED(")T87-K(&QI<W0B"FUS9W-T
M<B`B;&ES=&$@9&4@=&%R969A<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M365S<V%G92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G
M<W1R(")F86QH82!T96UP;W+A<FEA(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(W,`IM<V=I9"`B='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G<W1R(")P<F5E
M;F-H82!S=6$@<V5N:&$@9'5A<R!V97IE<R!P87)A(&-O;F9I<FUA<B(*"B,Z
M(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP
M.C<Y"FUS9VED(")U;FEF:65D(@IM<V=S='(@(G5N:69I8V%D;R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B
M"FUS9W-T<B`B<V5M(&YO;64B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@(G5S97(@<V5L96-T
M(@IM<V=S='(@(G-E;&7GXV\@9&4@=7-UX7)I;R(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS
M9W-T<B`B=D-A<F0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C0P"FUS9VED(")W.B(*;7-G<W1R(")W.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV"FUS9VED(")W96%T:&5R+F-O;2(*
M;7-G<W1R(")W96%T:&5R+F-O;2(*````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]P=%]05"YP
M;P``````````````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`W,C`U,C`@,3`U,34T,S0Q-#(@,#$W-30T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````",@2&]R9&4@4&]R='5G86P@
M4&]R='5G=65S92!T<F%N<VQA=&EO;BX*(R!-86YU96P@365N97IE<R!D92!3
M97%U96ER82`\36%N=65L+E-E<75E:7)A/BP@,C`P-2X*(R!"87-E9"!O;B!A
M('!R979I;W5S('1R86YS;&%T:6]N(&)Y($YU;F\@3&]U<F5I<F\@/&YU;F]`
M971H+G!T/BP@,C`P,BX*(PIM<V=I9"`B(@IM<V=S='(@(B(*(E!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<UQN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$Q+3(T(#`Q.C$X*S`P,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#(M,#$M,C$@,3@Z,C(M,#`P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!.=6YO($QO=7)E:7)O(#QN=6YO0&5T:"YP=#Y<;B(*(DQA;F=U86=E+51E
M86TZ(%!O<G1U9V%L(%!O<G1U9W5E<V4@/&1E=D!L:7-T<RYH;W)D92YO<F<^
M7&XB"B)-24U%+59E<G-I;VXZ(#$N,%QN(@HB0V]N=&5N="U4>7!E.B!T97AT
M+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3%<;B(*(D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:71<;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT
M.0IM<V=I9"`B(@HB("`M32P@+2UM97-S86=E/4U%4U-!1T4@(%5S92!T:&ES
M(&-O;6UI="!M97-S86=E(&EN<W1E860@;V8@=&AE(&1E9F%U;'0@;VYE<RXB
M"FUS9W-T<B`B(@HB("`M32P@+2UM97-S86=E/4U%3E-!1T5-(%5S87(@97-T
M82!M96YS86=E;2!D92!C;VUE=&EM96YT;R!E;2!V97H@9&%<;B(*(B`@("`@
M("`@("`@("`@("`@("`@("`@("!M96YS86=E;2!P;W(@;VUI<W/C;RXB"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3,*;7-G:60@(B(*(B`@+6$L("TM861D
M/49)3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I
M=6TN(%5S969U;"!T;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@:6YC
M;'5D92!A(&-O;7!E;F1I=6T@9G)O;2!A(&1I9F9E<F5N="!B<F%N8V@@=&]<
M;B(*(B`@("`@("`@("`@("`@("`@("`@("`@('1H92!G96YE<F%T960@8V]M
M<&5N9&EU;2XB"FUS9W-T<B`B(@HB("`M82P@+2UA9&0]05)154E63R`@("`@
M061I8VEO;F%R(&5S=&4@87)Q=6EV;R!03R!A;R!C;VUPZFYD:6\N(%5T:6P@
M<&%R85QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5I<B!U;2!C
M;VUPZFYD:6\@9&4@=6T@<F%M;R!D:69E<F5N=&4@;F]<;B(*(B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;7#J;F1I;R!G97)A9&\N(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$Q,PIM<V=I9"`B(@HB("`M8BP@+2UB87-E/2]0051(
M("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@8F%S92!D:7)E8W1O<GD@=&AA
M="!S:&]U;&0@8F5<;B(*(B`@("`@("`@("`@("`@("`@("`@=7-E9"XB"FUS
M9W-T<B`B("`M8BP@+2UB87-E/2]#04U)("!#86UI;FAO('!A<F$@;R!D:7)E
M8W3S<FEO(&)A<V4@*$AO<F1E*2!A('5S87(N(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C8Y"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@
M365R9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL
M95QN(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE
M(&1E9F%U;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H95QN(@HB("`@("`@
M("`@("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2XB"FUS9W-T
M<B`B(@HB("`M8RP@+2UC;VUP96YD:75M/4%2454@($EN=&5G<F%R(&YO=F%S
M('1R861UY_5E<R!A(&5S=&4@87)Q=6EV;R!D92`B"B)C;VUPZFYD:6]<;B(*
M(B`@("`@("`@("`@("`@("`@("`@("`@("!E(&[C;R!A;R!C;VUPZFYD:6\@
M<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F%<;B(*(B`@("`@("`@("`@
M("`@("`@("`@("`@("!P87-T82!H;W)D92]P;RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C,@<&\O=')A;G-L871I;VXN<&AP.C@Q('!O+W1R86YS;&%T
M:6]N+G!H<#HX-PIM<V=I9"`B(@HB("`M8RP@+2UC;VUP96YD:75M/49)3$4@
M(%5S92!T:&ES(&-O;7!E;F1I=6T@9FEL92!I;G-T96%D(&]F('1H92!D969A
M=6QT7&XB"B(@("`@("`@("`@("`@("`@("`@("`@("`@;VYE("AC;VUP96YD
M:75M+G!O(&EN('1H92!H;W)D92]P;R!D:7)E8W1O<GDI+B(*;7-G<W1R("(B
M"B(@("UC+"`M+6-O;7!E;F1I=6T]05)152`@57-A<B!E<W1E(&%R<75I=F\@
M9&4@8V]M<.IN9&EO(&5M('9E>B!D;R!A<G%U:79O7&XB"B(@("`@("`@("`@
M("`@("`@("`@("`@("`@<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@;F$@
M<&%S=&$@:&]R9&4O<&\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-`IM
M<V=I9"`B("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+B(*;7-G<W1R("(@("UD+"`M
M+61E8G5G("`@("`@($UO<W1R87(@;65N<V%G96YS(&1E(&5R<F\@9&]S(&)I
M;N%R:6]S(&5X96-U=&%D;W,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C4T
M"FUS9VED("(@("UD+"`M+61I<F5C=&]R>3U$25(@("!#<F5A=&4@8V]M<&5N
M9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2XB"FUS9W-T<B`B("`M9"P@+2UD:7)E
M8W1O<GD]4$%35$$@0W)I87(@=6T@8V]M<.IN9&EO(&YE<W1A('!A<W1A+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,34*;7-G:60@(B`@+6@L("TM:&5L
M<"`@("`@("`@4VAO=R!T:&ES(&AE;'`@;65S<V%G92XB"FUS9W-T<B`B("`M
M:"P@+2UH96QP("`@("`@("!-;W-T<F%R(&5S=&$@;65N<V%G96T@9&4@86IU
M9&$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R('!O+W1R86YS;&%T:6]N
M+G!H<#HV-R!P;R]T<F%N<VQA=&EO;BYP:'`Z-S4*;7-G:60@(B`@+6PL("TM
M;&]C86QE/6QL7T-#("`@("!5<V4@;VYL>2!T:&ES(&QO8V%L92XB"FUS9W-T
M<B`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S87(@87!E;F%S(&5S=&$@
M;&]C86QI>F'GXV\N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0W('!O+W1R
M86YS;&%T:6]N+G!H<#HV,2!P;R]T<F%N<VQA=&EO;BYP:'`Z-SD*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#
M0R`@("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R("(@("UL+"`M+6QO8V%L
M93UL;%]#0R`@("`@57-A<B!E<W1A(&QO8V%L:7IAY^-O+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HU-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@
M("`@57-E('1H:7,@;&]C86QE+B(*;7-G<W1R("(@("UL+"`M+6QO8V%L93UL
M;%]#0R`@("!5<V%R(&5S=&$@;&]C86QI>F'GXV\N(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C8X"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M0G5I;&0@34\@9FEL97,@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L92XB
M"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($-O;G-T<G5I
M<B!A<G%U:79O<R!-3R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;UQN(@HB("`@
M("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C0S"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M0VQE86YU<"!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE
M+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-TT153$\@("`@3&EM<&%R
M(&%R<75I=F]S(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO7&XB"B(@("`@
M("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2XB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-#@*;7-G:60@(B(*(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!#;VUM:70@=')A;G-L871I;VYS(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M
M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#
M;VUE=&5R(&%S('1R861UY_5E<R!A<&5N87,@<&%R82!E<W1E(&WS9'5L;UQN
M(@HB("`@("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8R"FUS9VED("(@("UM+"`M+6UO9'5L93U-3T15
M3$4@("`@0W)E871E(&$@4$\@9FEL92!O;FQY(&9O<B!T:&ES("A(;W)D92D@
M;6]D=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-TT153$\@("`@
M0W)I87(@;R!A<G%U:79O(%!/(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO7&XB
M"B(@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2XB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#`*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,
M12`@("!-97)G92!03R!F:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+B(*;7-G<W1R("(B"B(@("UM+"`M+6UO9'5L93U-TT153$\@("`@26YT
M96=R87(@87)Q=6EV;W,@4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&]<;B(*
M(B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+B(*"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HW-@IM<V=I9"`B(@HB("`M;2P@+2UM;V1U;&4]34]$
M54Q%("`@(%5P9&%T92!H96QP(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E
M*2!M;V1U;&4N(@IM<V=S='(@(B(*(B`@+6TL("TM;6]D=6QE/4W31%5,3R`@
M("!!8W1U86QI>F%R(&%R<75I=F]S(&1E(&%J=61A(&%P96YA<R!P87)A(&5S
M=&5<;B(*(B`@("`@("`@("`@("`@("`@("`@("`@("!M\V1U;&\@*$AO<F1E
M*2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.#8*;7-G:60@(B`@+6TL("TM
M;6]D=6QE/4U/1%5,12`@("!5<&1A=&4@;VYL>2!T:&ES("A(;W)D92D@;6]D
M=6QE+B(*;7-G<W1R("(@("UM+"`M+6UO9'5L93U-3T153$4@("`@06-T=6%L
M:7IA<B!A<&5N87,@97-T92!M\V1U;&\@*$AO<F1E*2XB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-3@*;7-G:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R9&4I(&UO9'5L
M92XB"FUS9W-T<B`B(@HB("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($=E<F%R
M(&%R8VAI=F\@4$]4(&%P96YA<R!P87)A(&5S=&4@;?-D=6QO7&XB"B(@("`@
M("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2XB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-S`*;7-G:60@(B(*(B`@+6XL("TM;F\M8V]M<&5N9&EU;2`@
M("!$;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O('1H92!C;VUP96YD
M:75M+B(*;7-G<W1R("(@("UN+"`M+6YO+6-O;7!E;F1I=6T@("`@3N-O(&EN
M=&5G<F%R(&YO=F%S('1R861UY_5E<R!N;R!C;VUPZFYD:6\N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C8T('!O+W1R86YS;&%T:6]N+G!H<#HX,B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#@*;7-G:60@(B`@+6XL("TM;F\M8V]M<&5N9&EU
M;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+B(*;7-G<W1R("(@("UN+"`M
M+6YO+6-O;7!E;F1I=6T@("`@3N-O('5S87(@=6T@8V]M<.IN9&EO+B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HW,0IM<V=I9"`B("`M<RP@+2US=&%T:7-T
M:6-S("`@("`@(%-A=F4@=')A;G-L871I;VX@<W1A=&ES=&EC<R!I;B!A(&QO
M8V%L(&9I;&4N(@IM<V=S='(@(B(*(B`@+7,L("TM<W1A=&ES=&EC<R`@("`@
M("!'=6%R9&%R(&5S=&%T[7-T:6-A<R!D92!T<F%D=>?C;R!N=6T@9FEC:&5I
M<F\@;&]C86PN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-@IM<V=I9"`B
M("`M="P@+2UT97-T("`@("`@("!3:&]W('1H92!E>&5C=71E9"!C;VUM86YD
M<R!B=70@9&]N)W0@<G5N(&%N>71H:6YG+B(*;7-G<W1R("(@("UT+"`M+71E
M<W0@("`@("`@($UO<W1R87(@;W,@<')O9W)A;6%S(&$@97AE8W5T87(@;6%S
M(&[C;R!O(&9A>F5R+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4*;7-G
M:60@(B(*(B`@8VQE86YU<"`@("`@0VQE86YS('1H92!03R!F:6QE<R!U<"!F
M<F]M('5N=')A;G-L871E9"!A;F0@;V)S;VQE=&4@96YT<FEE<RXB"FUS9W-T
M<B`B(@HB("!C;&5A;G5P("`@("!,:6UP87(@;V8@87)Q=6EV;W,@4$\@9&4@
M96YT<F%D87,@<&]R('1R861U>FER(&]U(&]B<V]L971A<RXB"@HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3`X"FUS9VED("(@(&-O;6UI="`@("`@($-O;6UI
M="!T<F%N<VQA=&EO;G,@=&\@=&AE($-64R!S97)V97(N(@IM<V=S='(@(B`@
M8V]M;6ET("`@("`@0V]M971E<B!A<R!T<F%D=>?U97,@;F\@<V5R=FED;W(@
M0U93+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#D*;7-G:60@(B`@8V]M
M;6ET+6AE;'`@0V]M;6ET(&AE;'`@9FEL97,@=&\@=&AE($-64R!S97)V97(N
M(@IM<V=S='(@(B`@8V]M;6ET+6AE;'`@0V]M971E<B!A<G%U:79O<R!D92!A
M:G5D82!N;R!S97)V:61O<B!#5E,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.CDY"FUS9VED("(B"B(@(&-O;7!E;F1I=6T@(%)E8G5I;&0@=&AE(&-O;7!E
M;F1I=6T@9FEL92X@5V%R;FEN9SH@5&AI<R!O=F5R=W)I=&5S('1H95QN(@HB
M("`@("`@("`@("`@("!C=7)R96YT(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*
M(B`@8V]M<&5N9&EU;2`@4F5C;VYS=')U:7(@;R!A<G%U:79O(&1E(&-O;7#J
M;F1I;RX@071E;N?C;SH@3R!N;W9O(&%R<75I=F]<;B(*(B`@("`@("`@("`@
M("`@<V]B<F5P]64M<V4@86\@86YT:6=O+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#`*;7-G:60@(B`@97AT<F%C="`@("`@1V5N97)A=&4@4$\@=&5M
M<&QA=&4@*"YP;W0I(&9I;&5S+B(*;7-G<W1R("(@(&5X=')A8W0@("`@($=E
M<F%R(&%R<75I=F]S(&UO9&5L;R!03R`H+G!O="DN(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.CDX"FUS9VED("(@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H
M96QP(&UE<W-A9V4N(@IM<V=S='(@(B`@:&5L<"`@("`@("`@36]S=')A<B!E
M<W1A(&UE;G-A9V5M(&1E(&%J=61A+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#$*;7-G:60@(B(*(B`@:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M
M;W)E(%!/(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7-<
M;B(*(B`@("`@("`@("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@
M9FEL97,@;V8@=&AI<R!L;V-A;&4N(@IM<V=S='(@(B(*(B`@:6YI="`@("`@
M("`@0W)I87(@=6T@;W4@;6%I<R!A<G%U:79O<R!03R!P87)A('5M82!N;W9A
M(&QO8V%L:7IAY^-O+EQN(@HB("`@("`@("`@("`@("!!=&5NY^-O.B!/<R!N
M;W9O<R!A<G%U:79O<R!S;W!R97#U96TM<V4@86]S(&%N=&EG;W,N(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P-@IM<V=I9"`B("!M86ME("`@("`@("!"
M=6EL9"!B:6YA<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I
M;&5S+B(*;7-G<W1R("(B"B(@(&UA:V4@("`@("`@($-O;G-T<G5I<B!A<G%U
M:79O<R!B:6[A<FEO<R!-3R!A('!A<G1I<B!D;W,@87)Q=6EV;W-<;B(*(B`@
M("`@("`@("`@("`@4$\@97-P96-I9FEC861O<RXB"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z,3`W"FUS9VED("(B"B(@(&UA:V4M:&5L<"`@($UA<FL@86QL
M(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I;&4@8F5I;F<@=7`M=&\M9&%T
M92!A;F1<;B(*(B`@("`@("`@("`@("`@<')E<&%R92!T:&4@9FEL92!F;W(@
M=&AE(&YE>'0@97AE8W5T:6]N(&]F('5P9&%T92UH96QP+B!9;W5<;B(*(B`@
M("`@("`@("`@("`@<VAO=6QD(&]N;'D@<G5N(&UA:V4M:&5L<"!!1E1%4B!U
M<&1A=&4M:&5L<"!A;F0@<F5V:7-I;F<@=&AE7&XB"B(@("`@("`@("`@("`@
M(&AE;'`@9FEL92XB"FUS9W-T<B`B(@HB("!M86ME+6AE;'`@("!-87)C87(@
M=&]D87,@87,@96YT<F%D87,@;F\@87)Q=6EV;R!834P@9&4@86IU9&$@8V]M
M;R!E<W1A;F1O7&XB"B(@("`@("`@("`@("`@(&%C='5A;&EZ861A<R!E('!R
M97!A<F%R(&\@87)Q=6EV;R!P87)A(&$@<'+S>&EM82!E>&5C=>?C;UQN(@HB
M("`@("`@("`@("`@("!D92!U<&1A=&4M:&5L<"X@1&5V92US92!E>&5C=71A
M<B!M86ME+6AE;'`@1$503TE3(&1E7&XB"B(@("`@("`@("`@("`@('5P9&%T
M92UH96QP(&4@9&4@<F5V97(@;R!A<G%U:79O(&1E(&%J=61A+B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,#(*;7-G:60@(B(*(B`@;65R9V4@("`@("`@
M365R9V4@=&AE(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/
M('1E;7!L871E(&9I;&4N(@IM<V=S='(@(B(*(B`@;65R9V4@("`@("`@26YT
M96=R87(@;R!A<G%U:79O(%!/(&-O<G)E;G1E(&-O;2!O(&%R<75I=F\@;6]D
M96QO(%!/("(*(F-O<G)E;G1E+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#,*;7-G:60@(B`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E
M('-E<75E;G0N(@IM<V=S='(@(B`@=7!D871E("`@("`@17AE8W5T87(@97AT
M<F%C="!E(&UE<F=E(&5M('-E<77J;F-I82XB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3`T"FUS9VED("(B"B(@('5P9&%T92UH96QP($5X=')A8W0@86QL
M(&YE=R!A;F0@8VAA;F=E9"!E;G1R:65S(&9R;VT@=&AE($5N9VQI<V@@6$U,
M(&AE;'!<;B(*(B`@("`@("`@("`@("`@9FEL92!A;F0@;65R9V4@=&AE;2!W
M:71H('1H92!E>&ES=&EN9R!O;F5S+B(*;7-G<W1R("(B"B(@('5P9&%T92UH
M96QP($5X=')A:7(@=&]D87,@87,@96YT<F%D87,@;F]V87,@92!M;V1I9FEC
M861A<R!D;R!A<G%U:79O(&1E7&XB"B(@("`@("`@("`@("`@(&%J=61A(%A-
M3"!E;2!I;F=LZG,@92!I;G1E9W+A+6QA<R!C;VT@87,@97AI<W1E;G1E+B(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D>2!T
M;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@
M8F5L;W<N(@IM<V=S='(@(B(*(B`F(S$U,3L@)7,@97-TX2!P<F]N=&\@<&%R
M82!E9F5C='5A<B!A<R!O<&5R8>?U97,@9&4@;6%N=71E;N?C;R!M87)C861A
M<R`B"B)A8F%I>&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-C@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E
M<R!D:6%S(&%T<N%S*2(*"B,Z(&QI8B](;W)D92YP:'`Z,3(U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED("(@*$%C8V5S<VME>2`E<RDB"FUS9W-T<B`B("A#:&%V
M92!D92!A8V5S<V\@)7,I(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E<R!D87ES*2(*;7-G<W1R("(@
M*&1E;G1R;R!D92`E<R!D:6%S*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,S<R"FUS9VED("(@*'1O9&%Y*2(*;7-G<W1R("(@*&AO:F4I(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(S-S0*;7-G:60@(B`H=&]M;W)R;W<I(@IM<V=S
M='(@(B`H86UA;FCC*2(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S<P"FUS
M9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T<B`B("AO;G1E;2DB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0T(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y-0IM<V=I9"`B(&%T("(*;7-G<W1R("(@8V]M("(*"B,Z(&QI8B](;W)D
M92]#3$DN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@
M;F]T(&$@=F%L:60@8VAO:6-E+B(*;7-G<W1R(")<(B5S7"(@;N-O(.D@=6UA
M(&5S8V]L:&$@=N%L:61A+B(*"B,Z(&QI8B](;W)D92]296=I<W1R>2YP:'`Z
M-34T(&QI8B](;W)D92]296=I<W1R>2YP:'`Z.3,T"B,L('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@
M4F5G:7-T<GDN(@IM<V=S='(@(EPB)7-<(B!NXV\@97-TX2!C;VYF:6=U<F%D
M;R!N;R!296=I<W1O(&1O($AO<F1E+B(*"B,Z(&QI8B](;W)D92]4<F5E+G!H
M<#HQ-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R
M97(@;F]T(&9O=6YD+B(*;7-G<W1R(")<(B5S7"(@<F5P<F5S96YT861O<B!D
M92#A<G9O<F4@;N-O(&5N8V]N=')A9&\N(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HU-PHC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(*;7-G<W1R(")<(B5S7"(@9F]I(&%D:6-I
M;VYA9&\@86\@<VES=&5M82!D92!G<G5P;W,N(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C@U"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T<B`B
M7"(E<UPB)R!F;VD@861I8VEO;F%D;R!A;R!S:7-T96UA(&1E('!E<FUI<W/U
M97,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-2!A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N
M;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(EPB)7-<(B!NXV\@9F]I(&-R:6%D
M;SH@)7,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R-0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS9W-T<B`B)60@
M)7,@92`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3<V"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&)Y=&5S('=R:71T96XN(@IM<V=S='(@(B5D(&)Y
M=&5S(&5S8W)I=&]S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)60@;V8@)60@96YT<FEE<R!M87)K960@87,@
M=7`M=&\M9&%T92(*;7-G<W1R("(E9"!D92`E9"!E;G1R861A(&UA<F-A9&%S
M(&-O;6\@86-T=6%L:7IA9&%S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"UD87D@9F]R96-A
M<W0B"FUS9W-T<B`B<')E=FESXV\@9&4@)60@9&EA<R(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L('!H<"UF;W)M870*
M;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@3F]T:69I8V'GXV\B
M"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N+6AE861E<BYI;F,Z,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@061M:6YI<W1R871I;VXB"FUS9W-T<B`B
M)7,@061M:6YI<W1R8>?C;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S`T"B,L('!H<"UF;W)M870*;7-G:60@(B5S($9I;F=E<G!R:6YT(@IM
M<V=S='(@(B5S($EM<')E<W/C;R!$:6=I=&%L(@H*(SH@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@S,"!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP
M:'`Z.#,R"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@(B5S
M($M"(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@3W!E<F'G]65S(&1E
M($UA;G5T96[GXV\@+2!#;VYF:7)M8>?C;R(*"B,Z(&%D;6EN+W-E='5P+V-O
M;F9I9RYP:'`Z,S`@861M:6XO<V5T=7`O:6YD97@N<&AP.C(Q.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E<R!3971U<"(*;7-G<W1R(")#;VYF:6=U<F%R("5S
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(E<R!3=6)S8W)E=F5R
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]T;W`N:6YC
M.C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT
M(@IM<V=S='(@(B5S(%1E<FUO<R!D;R!!8V]R9&\B"@HC.B!L:6(O5D93+V9T
M<"YP:'`Z-38X(&QI8B]61E,O9G1P+G!H<#HV,S8*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&KA(&5X:7-T
M92XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U.2!L:6(O0FQO8VLO;65T
M87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T87(N<&AP.C(S.0HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO8VLO;65T87(N<&AP.C,U,0HC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R!E;2`E
M<R`E<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.#<@<&\O=')A;G-L871I
M;VXN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!N;W0@=W)I
M=&%B;&4N(@IM<V=S='(@(F[C;R!S92!P;V1E(&5S8W)E=F5R(&5M("5S+B(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,S,Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B5S(.D@;V)R:6=A=/-R:6\B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X-@HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!M:6YU=&5S(@IM<V=S='(@(B5S(&UI;G5T;W,B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,S4P"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`B)7,@;N-O(&9O:2!E;F-O;G1R861O+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HU.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O
M=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I<G-T+B(*;7-G<W1R
M("(E<R!NXV\@9F]I(&5N8V]N=')A9&\N($5X96-U=&%R("=T<F%N<VQA=&EO
M;B!E>'1R86-T)R!P<FEM96ER;RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S('1O("5S(&]F
M("5S(@IM<V=S='(@(B5S(&$@)7,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.C@Y,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($%D9')E<W,@
M0F]O:R(*;7-G<W1R(")#;VYT86-T;W,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C@X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(D-A;&5N9.%R:6\@9&4@)7,B"@HC.B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C@W-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($YO=&5P
M860B"FUS9W-T<B`B3F]T87,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C@Y.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S(%1A<VML:7-T(@IM
M<V=S='(@(E1A<F5F87,@9&4@)7,B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-3,@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,Y.`IM<V=I9"`B+"!G=7-T:6YG("(*;7-G<W1R("(L(&-O;2!R86IA9&%S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@8V]M(')A:F%D87,@)7,@)7,B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE
M(&9R;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)IX79E;"!D92`E<R!A("5S
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(P-S`@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,CD*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C8X.`IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S='(@(BTM(&5S8V]L:&$@
M+2TB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,R."!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,S,`IM<V=I9"`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M(@IM<V=S='(@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS
M9W-T<B`B1F]R;6%T;R!D92`Q,B!H;W)A<R`H04TO4$TI(@H*(SH@;&EB+T)L
M;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O<FUA="(*;7-G<W1R
M(")&;W)M871O(&1E(#(T(&AO<F%S(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM
M92YI;F,Z,C@*;7-G:60@(C(T(&AO=7)S(@IM<V=S='(@(C(T(&AO<F%S(@H*
M(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HV.0IM<V=I9"`B/%!R979I;W5S
M(@IM<V=S='(@(CQ!;G1E<FEO<B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS
M-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB/&=E='1E>'0^('1A9R!N;W0@
M8VQO<V5D(&EN(&9I;&4@)7,N7&XB"B)/<&5N:6YG('1A9R!F;W5N9"!I;B!L
M:6YE("5D+B(*;7-G<W1R("(B"B)E=&EQ=65T82`\9V5T=&5X=#X@<&]R(&9E
M8VAA<B!N;R!F:6-H96ER;R`E<RY<;B(*(D%B<FEN9&\@82!E=&EQ=65T82!E
M;F-O;G1R861A(&YA(&QI;FAA("5D+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3$Y"FUS9VED(")!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@
M9F]R('1H:7,@8FQO8VLN(@IM<V=S='(@(D5S=&4@8FQO8V\@97AI9V4@=6T@
M;65C86YI<VUO('5S86YD;R!B87-E<R!D92!D861O<RXB"@HC.B!L:6(O2&]R
M9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B
M"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&9A=&%L(@H*(SH@;&EB+TAO<F1E
M+T-R>7!T+W!G<"YP:'`Z.3(P"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+)(&YE
M8V5S<^%R:6$@=6UA(&-H879E('#Z8FQI8V$@4$=0('!A<F$@96YC<FEP=&%R
M(&$@;65N<V%G96TN(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$T
M-0IM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HBR2!N96-E<W/A<FEA
M('5M82!C:&%V92!P^F)L:6-A(%!'4"!P87)A('9E<FEF:6-A<B!A(&%S<VEN
M871U<F$@9&4@=6UA("(*(FUE;G-A9V5M(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,3`W-PIM<V=I9"`B(@HB02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(E!A<F$@9&5C:69R
M87(@=6UA(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB
M;&EC82!01U`L('5M82!C:&%V92`B"B)P<FEV861A(%!'4"!E('5M82!F<F%S
M92UP87-S92XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY.34*;7-G
M:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S86=E
M+B(*;7-G<W1R("(B"B)087)A(&%S<VEN87(@=6UA(&UE;G-A9V5M('/C;R!N
M96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC82!01U`L('5M82!C:&%V92`B
M"B)P<FEV861A(%!'4"!E('5M82!F<F%S92UP87-S92XB"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4P-0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@(@HB9&5C<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@
M(B(*(E!A<F$@9&5C:69R87(@=6UA(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA
M<R!U;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82`B"B)C:&%V92!P<FEV
M861A(%,O34E-12!E('5M82!F<F%S92UP87-S92XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C0S,0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(E!A
M<F$@87-S:6YA<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S<^%R:6%S('5M82!C
M:&%V92!P^F)L:6-A(%,O34E-12P@=6UA("(*(F-H879E('!R:79A9&$@4R]-
M24U%(&4@=6UA(&9R87-E+7!A<W-E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,S8T"FUS9VED(")!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N(@IM<V=S='(@(LD@;F5C97-S
MX7)I82!U;6$@8VAA=F4@</IB;&EC82!3+TU)344@<&%R82!E;F-R:7!T87(@
M=6UA(&UE;G-A9V5M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*;7-G<W1R(").^G9E;G,@
M9&4@;6%N:.,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ,`IM<V=I9"`B04T@3&EG:'0@4F%I;B(*;7-G<W1R(")#:'5V:7-C
M;W,@9&4@36%N:.,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G<W1R(")#:'5V82!D92!M
M86YHXR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@(D%G=6%C96ER;W,@9&4@
M;6%N:.,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(DYE=O5E<R!D
M92!M86YHXR(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(Y"FUS9VED
M(")!32]032(*;7-G<W1R(")!32]032(*"B,Z(&QI8B].970O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED(")!4$D@240B"FUS9W-T<B`B05!)
M($E$(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B"FUS9W-T<B`B06-E<F-A
M(&1E<W1E(&5D:71O<B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R
M"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")!8V5R8V$N+BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<T"FUS9VED(")!
M8G-B;W1T;VTB"FUS9W-T<B`B0F%S97,@86QI;FAA9&%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S
M;6ED9&QE(@IM<V=S='(@(D-E;G1R;W,@86QI;FAA9&]S(@H*(SH@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,C<P"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(D%C97-S;R!N96=A9&\@86\@8W)I
M87(@<&%S=&$@5D93+B(*"B,Z(&QI8B]61E,O;75S<6PN<&AP.C$S-@IM<V=I
M9"`B06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B
M06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@4&%S<W=O<F0B
M"FUS9W-T<B`B4&%L879R82U087-S92!D82!#;VYT82(*"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R
M;WIE;BXB"FUS9W-T<B`B0V]N=&$@8V]N9V5L861A+B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,3<*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T
M<B`B0V]N=&%B:6QI9&%D92(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H
M<#HU-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$S,@HC.B!T96UP;&%T97,O
M<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C
M:&EL9"YI;F,Z,38*;7-G:60@(D%D9"(*;7-G<W1R(")!9&EC:6]N87(B"@HC
M.B!A9&UI;B]G<F]U<',N<&AP.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0IM
M<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%D:6-I;VYA<B!'<G5P
M;R!&:6QH;R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z.#0@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HX-0IM<V=I9"`B061D($-H:6QD(%!E<FUI<W-I
M;VXB"FUS9W-T<B`B061I8VEO;F%R(%!E<FUI<W/C;R!&:6QH82(*"B,Z('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS9VED(")!9&0@2&5R93HB"FUS
M9W-T<B`B06-R97-C96YT87(@07%U:3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(P."!A9&UI;B]G<F]U<',N<&AP.C(P.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R(")!9&1I8VEO;F%R($YO=F\@1W)U<&\B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C<S(&QI8B](;W)D92]097)M<R]522YP:'`Z-S0*
M;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R(")!9&EC:6]N87(@
M3F]V82!097)M:7-SXV\B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D
M9&-H:6QD+FEN8SHY"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD
M(&=R;W5P('1O(%PB)7-<(B(*;7-G<W1R(")!9&EC:6]N87(@=6T@9W)U<&\@
M9FEL:&\@82!<(B5S7"(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z
M-3,@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,S$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B"FUS9W-T
M<B`B061I8VEO;F%R('5M82!P97)M:7-SXV\@9FEL:&$@82!<(B5S7"(B"@HC
M.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM
M<V=S='(@(D%D:6-I;VYA<B!N;W9O('5T:6QI>F%D;W(Z(@H*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R-@IM<V=I9"`B061D(&-O
M;'5M;B(*;7-G<W1R(")!9&EC:6]N87(@8V]L=6YA(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHS-0IM<V=I9"`B061D(&YE=R!M96UB
M97)S(@IM<V=S='(@(D%D:6-I;VYA<B!N;W9O<R!M96UB<F]S(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER(@IM
M<V=S='(@(D%D:6-I;VYA<B!P87)C96ER;R(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-
M96YU(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(D%D:6-I;VYA<B!O
M($UE;G4@)7,@8V]M;R!"87)R82!,871E<F%L($UO>FEL;&$B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q"FUS9VED(")!9&0@=&\@
M861D<F5S<R!B;V]K.B(*;7-G<W1R(")!9&EC:6]N87(@86]S($-O;G1A8W1O
M<SHB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<X"FUS
M9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(D%D:6-I;VYA
M<B!A;W,@;65U<R!C;VYT86-T;W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM
M<V=I9"`B061D('5S97(B"FUS9W-T<B`B061I8VEO;F%R('5T:6QI>F%D;W(B
M"@HC.B!A9&UI;B]U<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G
M<W1R("(B"B)!9&EC:6]N96D@7"(E<UPB(&%O('-I<W1E;6$L(&UA<R!NXV\@
M<'5D92!A9&EC:6]N87(@:6YF;W)M8>?C;R!D92!S=6)S8W)IY^-O("(*(F%D
M:6-I;VYA;#H@)7,N(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+B(*;7-G<W1R(")!9&EC:6]N96D@7"(E<UPB(&%O('-I<W1E
M;6$N($KA('!O9&4@96YT<F%R+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY
M-C(*;7-G:60@(D%D9&EN9R!N97<@9FEL97,@=&\@<F5P;W-I=&]R>3HB"FUS
M9W-T<B`B061I8VEO;F%N9&\@;F]V;W,@87)Q=6EV;W,@86\@<F5P;W-I=/-R
M:6\Z(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C0*;7-G
M:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B02!A9&GG
MXV\@9&4@=71I;&EZ861O<F5S(&5S=.$@9&5S86-T:79A9&$N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$T-#,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O
M;VLB"FUS9W-T<B`B0V]N=&%C=&]S(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,
M+W)F8S(P.#8N<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")!9&UI;FES=')A<B`M
M(&%T<FEB=6ER('!E<FUI<W/U97,@82!O=71R;W,@=71I;&EZ861O<F5S(@H*
M(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R
M+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(D%D;6EN
M:7-T<F'GXV\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,SDR"FUS
M9VED(")!9',B"FUS9W-T<B`B06[Z;F-I;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!9F=H86YI<W1A
M;B(*;7-G<W1R(")!9F5G86YI<W3C;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B06QBXFYI82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW-"!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B07)GZ6QI82(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED
M(")!;&EA<R(*;7-G<W1R(")!;&-U;FAA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB
M"FUS9W-T<B`B06QI;FAA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`B
M06QI;FAA;65N=&\Z(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C@W"FUS
M9VED(")!;&PB"FUS9W-T<B`B5'5D;R(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$Q."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"FUS9VED(")!
M;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R(")4;V1O<R!O<R!5=&EL
M:7IA9&]R97,@075T96YT:6-A9&]S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HS
M,R!A9&UI;B]G<F]U<',N<&AP.C(Q,@IM<V=I9"`B06QL($=R;W5P<R(*;7-G
M<W1R(")4;V1O<R!O<R!'<G5P;W,B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL
M9"YP:'`Z,S@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW-PIM<V=I9"`B06QL
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E1O9&%S(&%S(%!E<FUI<W/U97,B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$W"FUS9VED(")!;&P@9F]U<B!S:61E<R(*;7-G<W1R(")4;V1O<R!O<R`H
M<75A=')O*2!L861O<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#<R"FUS
M9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B4&5R;6ET
M:7(@;?IL=&EP;&]S(&5N9&5R9>=O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HU,C8*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T
M('1Y<&4_(@IM<V=S='(@(E!E<FUI=&ER(&%T<FEB=6GGXV\@9&\@=&EP;R!D
M92!L:7-T87,@;W)D96YA9&%S/R(*"B,Z(&QI8B](;W)D92]$871A5')E92]S
M<6PN<&AP.C0P.`IM<V=I9"`B06QR96%D>2!E>&ES=',B"FUS9W-T<B`B2N$@
M97AI<W1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM<V=I9"`B
M06QT97)N871E($E-4U`@3&]G:6XB"FUS9W-T<B`B16YT<F%D82!)35-0($%L
M=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Y.0IM<V=I
M9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B"FUS9W-T<B`B4&%L879R82U0
M87-S92!)35-0($%L=&5R;F%T:79A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C0Y,0IM<V=I9"`B06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T
M<B`B3F]M92!D92!5=&EL:7IA9&]R($E-4U`@06QT97)N871I=F\B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E
M(&5M86EL(&%D9')E<W,B"FUS9W-T<B`B16YD97)EYV\@:6YVX6QI9&\B"@HC
M.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@IM<V=I9"`B06QT97)N871E('1E
M;7!L871E<R(*;7-G<W1R(")-;V1E;&]S(&%L=&5R;F%T:79O<R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(E1E>'1O(&%L
M=&5R;F%T:79O.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(E-A
M;6]A($%M97)I8V%N82(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@
M;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@
M=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`B1F]I(&5S<&5C:69I8V%D
M;R!U;2!V86QO<B!I;G;A;&ED;RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,34T"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U
M<F5D+B(*;7-G<W1R(")/8V]R<F5U('5M(&5R<F\@9&5S8V]N:&5C:61O+B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B06YD;W)R82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L
M82(*;7-G<W1R(")!;F=O;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!
M;F=U:6QA(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED
M(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T<B`B16YT<F5P;W-T;R`H<')O>'DI
M($%N\VYI;6\B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM
M<V=I9"`B06YS=V5R(@IM<V=S='(@(E)E<W!O<W1A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C
M=&EC82(*;7-G<W1R(")!;G3A<F-T:6-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B06YT:6=U82!A;F0@
M0F%R8G5D82(*;7-G<W1R(")!;G3M9W5A(&4@0F%R8G5D82(*"B,Z(&%D;6EN
M+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP.C,U(&QI8B](
M;W)D92]";&]C:R]522YP:'`Z-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!L
M:6-AY^-O(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S.0IM<V=I9"`B
M07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@(D%P;&EC8>?C;R!P<F]N
M=&$N(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHR,3@*;7-G:60@
M(D%P<&QY('1O($-H:6QD(%-H87)E<R(*;7-G<W1R(")!<&QI8V%R(&$@4&%R
M=&EL:&%S($9I;&AA<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O
M=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E(@IM<V=S='(@(D%P<F]V87(B"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#,P"FUS9VED(")!<'!R
M;WAI;6%T92!3:7IE(@IM<V=S='(@(E1A;6%N:&\@07!R;WAI;6%D;R(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-S<@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-`HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8X"FUS9VED(")!<')I;"(*
M;7-G<W1R(")!8G)I;"(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS
M9VED(")!<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B07+A8FEC;R`H
M5VEN9&]W<RTQ,C4V*2(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N
M<&AP.C4Y(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8V"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<X"FUS9VED(")!<F-H:79E
M($9I;&4@4VEZ92(*;7-G<W1R(")486UA;FAO(&1O($9I8VAE:7)O(&1E($%R
M<75I=F\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HU."!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O=&=Z+G!H<#HW-PIM<V=I9"`B07)C:&EV92!.86UE(@IM
M<V=S='(@(DYO;64@9&\@07)Q=6EV;R(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!
M<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q
M=65S="!F;W(@)7,@/R(*;7-G<W1R(")496T@82!C97)T97IA('%U92!Q=65R
M(')E;6]V97(@;R!P961I9&\@9&4@<W5B<V-R:>?C;R!P87)A("5S(#\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z.0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E
M(%PB)7-<(B!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(E1E;2!A(&-E
M<G1E>F$@<75E('%U97(@<F5M;W9E<B!<(B5S7"(@92!Q=6%I<W%U97(@<W5B
M+6=R=7!O<S\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C8@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C4X"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`B07)G96YT:6YA
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-PIM<V=I9"`B07)M96YI82(*;7-G<W1R(")!<FWI;FEA(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I
M(@IM<V=S='(@(D%R;>EN:6\@*$%235-#24DM."DB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R="(*;7-G<W1R(")!<G1E(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B07)U8F$B"FUS9W-T<B`B07)U8F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B26QH
M82!D92!!<V-E;G/C;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM
M<V=I9"`B07-C:6D@07)T(@IM<V=S='(@(D%R=&4@05-#24DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B07-I82]086-I9FEC(%)E
M9VEO;B(*;7-G<W1R(")296=IXV\@P7-I82]086/M9FEC;R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,3<*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G
M<W1R(")0961I<B!C;VYF:7)M8>?C;R!A;G1E<R!D92!R96%L:7IA<B!O<&5R
M8>?U97,@9&4@;6%N=71E;N?C;S\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,S$Q,@IM<V=I9"`B07-S:6=N;65N="!C;VQU;6YS(@IM<V=S='(@(D-O;'5N
M87,@9&4@871R:6)U:>?C;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S4*;7-G
M:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+B(*
M;7-G<W1R(")496YT871I=F$@9&4@<F5M;^?C;R!D92!U;2!G<G5P;R!I;F5X
M:7-T96YT92XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C,X"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")496YT871I=F$@9&4@<F5M;^?C;R!D92!U;6$@<&5R;6ES
M<^-O(&EN97AI<W1E;G1E+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.CDX
M"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES
M<VEO;BXB"FUS9W-T<B`B5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@<&5R
M;6ES<^-O(&EN97AI<W1E;G1E+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R(")496YT871I=F$@9&4@961IY^-O(&1E('5M82!P
M87)T:6QH82!I;F5X:7-T96YT92XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O<F%R+G!H<#HV-"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW
M,0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,PIM<V=I9"`B
M071T<FEB=71E<R(*;7-G<W1R(")!=')I8G5T;W,B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@Q(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,@IM<V=I9"`B075G=7-T(@IM<V=S='(@(D%G
M;W-T;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R(")!=7-T<N%L:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS
M9VED(")!=7-T<FEA(@IM<V=S='(@(L%U<W1R:6$B"@HC.B!L:6(O2&]R9&4O
M075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C
M>7)S<6PZ($$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA(&[C;R!F;VD@96YC
M;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER=7,Z($\@;65C86YI
M<VUO(&[C;R!T96T@87,@8V%P86-I9&%D97,@;F5C97-SX7)I87,N(@H*(SH@
M;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U
M<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7V-Y<G5S.B!!(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82!NXV\@
M9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O9G1P+G!H<#HS
M-@IM<V=I9"`B(@HB075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92TB"B)F
M='`@<W=I=&-H+B(*;7-G<W1R("(B"B)!=71H7V9T<#H@02!E>'1E;G/C;R!&
M5%`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N($-O;7!I;&4@;R!0
M2%`@8V]M(&$@(@HB;W#GXV\@+2UE;F%B;&4M9G1P+B(*"B,Z(&QI8B](;W)D
M92]!=71H+VEM87`N<&AP.C8T"FUS9VED(")!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;6%P
M.B!!(&5X=&5N<^-O($E-05`@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A
M9&$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z-3$*;7-G:60@(D%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")!=71H7VMR8C4Z($$@97AT96YSXV\@:W)B-2!N96-E<W/A<FEA
M(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P
M+G!H<#HU.`IM<V=I9"`B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?;&1A<#H@02!E>'1E;G/C
M;R!,1$%0(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI
M8B](;W)D92]!=71H+VQD87`N<&AP.C$X-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(B(*(D%U=&A?;&1A<#H@
M26UP;W-S[79E;"!A9&EC:6]N87(@=71I;&EZ861O<B`E<RX@16ES(&\@<75E
M(&\@<V5R=FED;W(@9&ES<V4Z("(*"B,Z(&QI8B](;W)D92]!=71H+VQD87`N
M<&AP.C(R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G<W1R(")!=71H7VQD87`Z($EM<&]S
M<^UV96P@<F5M;W9E<B!O('5T:6QI>F%D;W(@)7,B"@HC.B!L:6(O2&]R9&4O
M075T:"]L9&%P+G!H<#HR.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L
M9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,B"FUS9W-T<B`B075T:%]L
M9&%P.B!);7!O<W/M=F5L(&%C='5A;&EZ87(@;R!U=&EL:7IA9&]R("5S(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A
M;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")!=71H7VUC86PZ($$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA(&[C;R!F
M;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C8P
M"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B!!(&5X=&5N
M<^-O('-M8F%U=&@@;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@
M(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")!(&%U=&5N=&EC8>?C
M;R!F86QH;W4B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C8W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G
M<W1R(")!(&%U=&5N=&EC8>?C;R!F86QH;W4N("5S(@H*(SH@;&EB+TAO<F1E
M+T%U=&@O<F%D:75S+G!H<#HQ-S8*;7-G:60@(D%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N(@IM<V=S='(@(D$@875T96YT:6-A
MY^-O(&9O:2!R96IE:71A9&$@<&5L;R!S97)V:61O<B!2041)55,N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C<V.`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D$@875T96YT:6-AY^-O(&YO
M('-E<G9I9&]R($944"!F86QH;W4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M;6%P+FEN8SHX,PIM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B
M0V%M<&]S(&1I<W!O;NUV96ES.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HS,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C4*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ86XB"FUS9W-T
M<B`B07IE<F)A:6KC;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM
M<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D1E<V-U;'!A<R!<(D)/1DA<
M(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,3@*;7-G:60@(D)A8VMG<F]U;F0B"FUS9W-T<B`B1G5N9&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(S"FUS
M9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@(D-O<B!D;R!&=6YD;R(*
M"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@Q"FUS9VED(")"860@:V5R
M8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4@:V5R8F5R
M;W,@97)R861A+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS
M9VED(")"860@:V5R8F5R;W,@=7-E<FYA;64N(@IM<V=S='(@(DYO;64@9&4@
M571I;&EZ861O<B!K97)B97)O<R!E<G)A9&\N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F%H86UA<R(*
M;7-G<W1R(")"86%M87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S@@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR86EN(@IM<V=S='(@(D)A<NEM
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H
M25-/+3@X-3DM,3,I(@IM<V=S='(@(D+A;'1I8V\@*$E33RTX.#4Y+3$S*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)A;F=L861E<V@B"FUS9W-T<B`B0F%N9VQA9&5C:&4B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED
M(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM<V=I9"`B0F%S
M96QI;F4B"FUS9W-T<B`B3&EN:&$@8F%S92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&%R=7,B"FUS
M9W-T<B`B0FEE;&]R<OIS<VEA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C,U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F5L9VEU;2(*;7-G<W1R(")"
MZ6QG:6-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,PIM<V=I9"`B0F5L:7IE(@IM<V=S='(@(D)E;&EZ92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@
M(D)E;FEN(@IM<V=S='(@(D)E;FEM(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C0Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D82(*;7-G<W1R
M(")"97)M=61A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,PIM<V=I9"`B0FAU=&%N(@IM<V=S='(@(D)U=.-O(@H*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,3$*;7-G:60@(D)I
M<G1H9&%Y(@IM<V=S='(@(D%N:79E<G/A<FEO(@H*(SH@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,R.`HC+"!P:'`M9F]R;6%T"FUS9VED(")"
M;&]C:R!<(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB
M"FUS9W-T<B`B3R!B;&]C;R!<(B5S7"(@9&$@87!L:6-AY^-O(%PB)7-<(B!N
MXV\@9F]I(&5N8V]N=')A9&\N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO
M=70N:6YC.C@Y"FUS9VED(")";&]C:R!3971T:6YG<R(*;7-G<W1R(")#;VYF
M:6=U<F'G]65S(&1E($)L;V-O<R(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y
M;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R(")4:7!O(&1E
M($)L;V-O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX"FUS9VED(")";VQD(@IM<V=S='(@(DYE9W)I=&\B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"
M;VQI=FEA(@IM<V=S='(@(D)O;.UV:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,3DQ"FUS9VED(")";V]K;6%R:W,B"FUS9W-T<B`B36%R8V%D
M;W)E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C`*;7-G:60@(D)O<F1E<B(*;7-G<W1R(")";W)D82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#4*;7-G
M:60@(D)O<F1E<B!T:&EC:VYE<W,Z(@IM<V=S='(@(D5S<&5S<W5R82!D82!B
M;W)D83HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(D)O<F1A<R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*
M;7-G:60@(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B"FUS9W-T<B`B0O-S;FEA
M+4AE<GIE9V]V:6YA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS
M9VED(")";W1H(@IM<V=S='(@(D%M8F%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C0X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.`HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS
M9W-T<B`B0F]T<W5A;F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")"
M87-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R("));&AA($)O=79E
M="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)R87II;"(*;7-G<W1R(")"<F%S:6PB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HT,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I
M=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y(@IM<V=S='(@(E1E<G)I=/-R
M:6\@0G)I=.)N:6-O(&1O($]C96%N;R#-;F1I8V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0R
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<G5N96D@
M1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96D@1&%R=7-S86QA;2(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV-C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0G5I
M;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+B(*;7-G<W1R(")#;VYS
M=')U:6YD;R!A<G%U:79O<R!-3R!P87)A(&\@;?-D=6QO("5S+BXN(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C8W,PHC+"!P:'`M9F]R;6%T"FUS9VED(")"
M=6EL9&EN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(D-O;G-T<G5I;F1O(&QO
M8V%L:7IAY^-O("5S+BXN("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U
M;&?A<FEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G<W1R("),:7-T($ET
M96UI>F%D82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C$*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R(")"=7)Q=6EN
M82!&87-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,Y(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HT-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV,0IM<V=I9"`B0G5R=6YD:2(*;7-G<W1R(")"=7+Z;F1I(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,X,PIM<V=I9"`B0TU3(@IM<V=S
M='(@(D--4R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<U
M"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@IM<V=S='(@(E!O;G1O<R!D92!$:7-T<FEB=6GGXV\@0U),(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(W
M"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@(E!R;W!R:65D
M861E<R!D82AS*2!#Z5]L=6QA*',I+BXN(@H*(R!C+69O<FUA=`HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34P"FUS9VED(")#86-H92!I;FET
M('=A<R!N;W0@8V]M<&QE=&5D+B(*;7-G<W1R("));FEC:6%L:7IAY^-O(&1A
M(%PB8V%C:&5<(B!NXV\@9F]I(&-O;F-L=>UD82XB"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-#@*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(D-A;&5N9.%R
M:6\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,T"FUS9VED
M(")#86QM(@IM<V=S='(@(D-A;&UO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#8*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@(D-A;6)O9&EA(@IM<V=S
M='(@(D-A;6)O9&IA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`B0V%M87+U
M97,B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM<V=I9"`B
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB3N-O('!O<W-O(')E
M:6YI8VEA<B!A('!A;&%V<F$M<&%S<V4@875T;VUA=&EC86UE;G1E+"!C;VYT
M86-T92!O('-E=2`B"B)A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S+B(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,S4@;&EB+TAO<F1E+T%U=&@O
M8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B26UP;W-S[79E;"!C
M;VYE8W1A<B!A;R!S97)V:61O<B!)34%0.B`E<R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*
M;7-G<W1R(")#86YA9.$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO
M=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$W"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3<*;7-G:60@(D-A;F-E
M;"(*;7-G<W1R(")#86YC96QA<B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R
M;V)L96TN:6YC.C4Y"FUS9VED(")#86YC96P@4')O8FQE;2!297!O<G0B"FUS
M9W-T<B`B0V%N8V5L87(@4F5L873S<FEO(&1E(%!R;V)L96UA<R(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HR-38*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T
M(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B3N-O(&-O;G-I9V\@<F5M
M;W9E<B!O(&9I8VAE:7)O(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!L:6(O5D93+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3(*;7-G:60@
M(D-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M3N-O(&-O;G-I9V\@96YC;VYT<F%R('5M(&1I<F5C=/-R:6\@=&5M<&]RX7)I
M;RXB"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z.3$*;7-G:60@(D-A;FYO
M="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS
M9W-T<B`B26UP;W-S[79E;"!C;VYT:6YU87(@<V5M(&\@<&%RXFUE=')O("=T
M87)G971&:6QE)RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,C4R"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@7"(E
M<UPB+B(*"B,Z(&QI8B](;W)D92]$871A5')E92YP:'`Z,3$R(&QI8B](;W)D
M92]$871A5')E92]S<6PN<&AP.C4X-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#
M86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS9W-T<B`B26UP
M;W-S[79E;"!R96UO=F5R+"!E>&ES=&5M("5D(&9I;&AO<RXB"@HC.B!L:6(O
M2&]R9&4O1&%T851R964O<W%L+G!H<#HU,3(*;7-G:60@(B(*(D-A;FYO="!R
M96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E
M<B!D;V5S(&YO="!M871C:"!N=6UB97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B
M"B).XV\@Z2!P;W-S[79E;"!R96]R9&5N87(Z(&\@;OIM97)O(&1E(&5N=')A
M9&%S(&9O<FYE8VED87,@;N-O(&-O<G)E<W!O;F1E(&%O("(*(F[Z;65R;R!G
M=6%R9&%D;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!E;F-A;6EN:&%R
M(&$@;65N<V%G96T@<&%R82!O(&[Z;65R;R!I;F1I8V%D;RXB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#
M87!E(%9E<F1E(@IM<V=S='(@(E)E</IB;&EC82!D92!#86)O(%9E<F1E(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R("),96=E;F1A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.CDP"FUS9VED(")#871E9V]R:65S(&%N9"!,
M86)E;',B"FUS9W-T<B`B0V%T96=O<FEA<R!E($-O<F5S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(D-A
M>6UA;B!)<VQA;F1S(@IM<V=S='(@(DEL:&%S($-A:6WC;R(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL(%!H
M;VYE(@IM<V=S='(@(E1E;&5F;VYE($-E;'5L87(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#
M96QL(%!R;W!E<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A<R!#Z6QU
M;&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,30*;7-G:60@(D-E;&P@<&%D9&EN9SHB"FUS9W-T<B`B16YC:&EM96YT
M;R!D87,@0^EL=6QA<SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B
M"FUS9W-T<B`B4')O<')I961A9&5S(&1A<R!CZ6QU;&%S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3(*;7-G:60@(D-E
M;&P@<W!A8VEN9SHB"FUS9W-T<B`B17-P8>=A;65N=&\@9&%S(&/I;'5L87,Z
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N
M92(*;7-G<W1R(")496QE;?-V96PB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W.`IM<V=I9"`B0V5L=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0^EL
M=&EC;R`H25-/+3@X-3DM,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S
M='(@(D-E;G1R87(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-30@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F<FEC86X@4F5P=6)L:6,B
M"FUS9W-T<B`B4F5P^F)L:6-A($-E;G1R;R!!9G)I8V%N82(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*2(*;7-G<W1R(")%=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM
M,BDB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B
M0V5R=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")0;W)M96YO<F5S(&1O($-E
M<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3$*
M;7-G:60@(D-E<G1I9FEC871E($]W;F5R(@IM<V=S='(@(D1O;F\@9&\@0V5R
M=&EF:6-A9&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM
M<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`B4&]L[71I8V%S
M(&1E($-E<G1I9FEC861O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")#:&%D(@IM<V=S='(@(E)E</IB
M;&EC82!D;R!#:&%D92(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@(D-H
M86YG92(*;7-G<W1R(")!;'1E<F%R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@
M=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y
M;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B(@HB06QT97)E(&\@;F]M92!E(&5N
M9&5R9>=O('%U92!A<R!P97-S;V%S('9E<N-O('%U86YD;R!L97)E;2!E(')E
M<W!O;F1E<F5M(.!S("(*(G-U87,@;65N<V%G96YS+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C<*;7-G:60@
M(D-H87(B"FUS9W-T<B`B0V%R86-T97)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#:&5C
M7VL@3&EN:RXN+B(*;7-G<W1R(")697)I7V9I8V%R($QI9V'GXV\N+BXB"@HC
M.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S"FUS
M9VED(")#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W
M86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")-87)Q=64@
M87,@;W!E<F'G]65S('%U92!D97-E:F$@97AE8W5T87(@;F5S=&4@;6]M96YT
M;RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8W"FUS9VED(")#:&EL92(*;7-G<W1R(")297#Z8FQI8V$@9&\@0VAI;&4B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W
M"FUS9VED(")#:&EN82(*;7-G<W1R(")297#Z8FQI8V$@4&]P=6QA<B!D82!#
M:&EN82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0VAI;NIS(%-I;7!L
M:69I8V%D;W,@*$=",C,Q,BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T<B`B
M0VAI;NIS(%1R861I8VEO;F%L("A":6<U*2(*"B,Z(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,C8Y"FUS9VED(")#:&]O<V4@82!P87-S=V]R9"(*;7-G
M<W1R(")%<V-O;&AA(&$@<&%L879R82UP87-S92(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8X"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*
M;7-G<W1R(")%<V-O;&AA('5M($YO;64@9&4@571I;&EZ861O<B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR.3`*;7-G:60@(D-H;V]S92!H;W<@=&\@
M9&ES<&QA>2!D871E<SHB"FUS9W-T<B`B17-C;VQH82!C;VUO(&UO<W1R87(@
M87,@9&%T87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(D5S8V]L:&$@;R!E
M<W1I;&\@9&%S(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8V(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HU-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0VAR:7-T;6%S($ES;&%N9"(*;7-G<W1R("));&AA(&1O($YA=&%L(@H*
M(SH@;&EB+U9&4RYP:'`Z-C$U(&QI8B].970O4TU3+G!H<#HR.30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U
M;F0N(@IM<V=S='(@(D[C;R!F;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C;R!D
M82!C;&%S<V4@)7,N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C@U-0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D
M=6QE("5S+BXN(@IM<V=S='(@(DQI;7!A;F1O(&]S(&%R<75I=F]S(%!/(&1O
M(&WS9'5L;R`E<RXN+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-C<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0VQE86YI;F<@=7`@;&]C86QE("5S+BXN("(*
M;7-G<W1R("),:6UP86YD;R!A(&QO8V%L:7IAY^-O("5S+BXN("(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"FUS9VED(")#
M;&5A<B(*;7-G<W1R("),:6UP87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T
M86=S(@IM<V=S='(@(DQI;7!A<B!E=&EQ=65T87,@9&\@35-/9F9I8V4B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`B3&EM<&%R
M(&1A9&]S(&1O('5T:6QI>F%D;W(Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$V"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@
M(DQI;7!A<B!D861O<R!D;R!U=&EL:7IA9&]R(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G:60@(D-L96%R('5S97(@9&%T82(*
M;7-G<W1R("),:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$U"FUS9VED(")#;&5A
M<FEN9R!,871E(@IM<V=S='(@(DQI;7!A(%1A<F1E(@H*(SH@=&5M<&QA=&5S
M+VUA:6YT96YA;F-E+VYO=&EC95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K
M('1O($-O;G1I;G5E(@IM<V=S='(@(D-L:7%U92!P87)A($-O;G1I;G5A<B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T"FUS9VED
M(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(D-L:6-K871E;&P@=FEA
M($A45%`B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G
M<W1R(")&96-H87(@:F%N96QA(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(").^G9E;G,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-@IM<V=I9"`B0VQO=61S
M($5A<FQY(@IM<V=S='(@(D[Z=F5N<R!-871I;F%I<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W"FUS9VED(")#;&]U9'DB
M"FUS9W-T<B`B16YE=F]A9&\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<R(*;7-G<W1R("));&AA<R!#;V-O<R`H2V5E;&EN9RDB"@HC.B!T96UP
M;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*;7-G:60@(D-O;&QA<'-E(%-I
M9&5B87(B"FUS9W-T<B`B0V]L87!S87(@0F%R<F$@3&%T97)A;"(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C@*
M;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM<V=S='(@(D)O<F1A<R!#;VQA
M<'-A9&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HU-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-PIM<V=I9"`B0V]L;VUB:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A
M($-O;/1M8FEA(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO
M8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(D-O
M<F5S(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.2!L
M:6(O2&]R9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S`P"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HT-S(@<V5R=FEC97,O:6UA9V5S
M+V-O;&]R<&EC:V5R+G!H<#HQ-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHU,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHU,@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV.`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHV.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O
M<GEM86YA9V5M96YT+FEN8SHX-@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S
M='(@(E!A;&5T92(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#0U"FUS9VED
M(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O(&1E(&-O<F5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#,*;7-G:60@(D-O;',Z(@IM<V=S='(@(D-O;'5N87,Z(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-#<*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T
M<B`B5.UT=6QO<R!D87,@8V]L=6YA<R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR.#8*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")"1"(*"B,Z(&%D
M;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R(")#
M;VUA;F1O(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP.C(P"FUS9VED(")#;VUM
M86YD(%-H96QL(@IM<V=S='(@(D-O;G-O;&$@9&4@0V]M86YD;W,B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,S@*;7-G:60@(D-O;6UA;F0@;W!T:6]N<SHB
M"FUS9W-T<B`B3W#G]65S(&1O(&-O;6%N9&\Z(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.CDW"FUS9VED(")#;VUM86YD<SHB"FUS9W-T<B`B0V]M86YD;W,Z
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`R"FUS9VED(")#;VUM
M96YT(@IM<V=S='(@(D-O;65N=.%R:6\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3`P,`IM<V=I9"`B0V]M;6ET=&EN9SHB"FUS9W-T<B`B0V]M971E;F1O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8*;7-G:60@(D-O
M;6UO;B!.86UE(@IM<V=S='(@(DYO;64@0V]M=6TB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B0V]M;W)O
M<R(*;7-G<W1R(")#;VUO<F]S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B16UP<F5S
M82(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@Q(&QI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&QI8B](;W)D
M92]497AT+T9I;'1E<B]E;6%I;',N<&AP.CDW(&QI8B](;W)D92]497AT+T9I
M;'1E<B]E;6%I;',N<&AP.C$P,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VUP
M;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")%<V-R979E<B`H)7,I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS
M9W-T<B`B0V]M<'5T861O<F5S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C(X-0IM<V=I9"`B0V]N9&ET:6]N(@IM<V=S='(@(D-O;F1IY^-O
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#D*;7-G:60@(D-O;F1I=&EO
M;G,B"FUS9W-T<B`B0V]N9&GG]65S(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T
M<B`B1&EF97)E;N=A<R!D92!#;VYF:6=U<F'GXV\B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3,T"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O
M9B!D871E+B(*;7-G<W1R(")!(&-O;F9I9W5R8>?C;R!E<W3A(&1E<V%C='5A
M;&EZ861A(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.CDY"B,L('!H<"UF
M;W)M870*;7-G:60@(D-O;F9I9W5R92`E<R(*;7-G<W1R(")#;VYF:6=U<F%R
M("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-PIM
M<V=I9"`B0V]N9FER;2!087-S=V]R9"(*;7-G<W1R(")#;VYF:7)M92!A(%!A
M;&%V<F$M4&%S<V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")297#Z8FQI8V$@
M1&5M;V-RX71I8V$@9&\@0V]N9V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE(@IM<V=S='(@(E)E</IB;&EC82!$96UO
M8W+A=&EC82!D;R!#;VYG;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HQ.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q
M,`IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960N(@IM<V=S='(@(D-O;F5XXV\@
M9F%L:&]U+B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Q,`IM<V=I9"`B
M0V]N;F5C=&EO;B!F86EL960Z("(*;7-G<W1R(")#;VYE>.-O(&9A;&AO=3H@
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S<Y"FUS9VED(")#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S
M='(@(D-O;F5XXV\@86\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S(')E
M8W5S861A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<X,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")#;VYE
M>.-O(&%O('-E<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<R!R96-U<V%D82X@
M4F%ZXV\Z("5S("@E<RDB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S8R"FUS9VED
M(")#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")#
M;VYE>.-O(&%O('-E<G9I9&]R($944"!R96-U<V%D82XB"@HC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C4S"FUS9VED(")#;VYT86-T<R!W
M97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B0V]N=&%C=&]S(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O(&%O
M('-E=2!L:79R;R!D92!E;F1E<F7G;W,N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP
M<F5S<V5D(&9I;&4Z("(*;7-G<W1R(")4:7!O(&1E(&-O;G1E^F1O(&1O(&%R
M<75I=F\@8V]M<')I;6ED;SH@(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-38@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(D-O;G1E
M^F1O(&1E("5S(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,CD*
M;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@(D-O;G1I;G5A<B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O
M;VL@27-L86YD<R(*;7-G<W1R("));&AA<R!#;V]K(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`B0F]L:6YH
M;R!C:&ENZG,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B0V]P:6%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS
M-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B0V]P:6%R('-E;&5C
MY^-O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P.#0*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]P>6EN9R`E<R!T;R`E<R(*;7-G<W1R(")#;W!I86YD;R!D
M92`E<R!P87)A("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-PIM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")297#Z
M8FQI8V$@9&$@0V]S=&$@4FEC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)=F]I<F4B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1A($-O<W1A(&1O($UA<F9I;2(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.CDU-@IM<V=I9"`B0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@96YC
M<FEP=&%R(&$@;65N<V%G96T@8V]M(%!'4"XB"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HQ,#,S"FUS9VED(")#;W5L9"!N;W0@4$=0('-I9VX@;65S
M<V%G92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R(&$@;65N
M<V%G96T@8V]M(%!'4"XB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C,Y,PIM<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@96YC<FEP87(@82!M96YS86=E
M;2!C;VT@4R]-24U%+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M
M(%,O34E-12XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N87(@;R!C
M;VYT86-T;RX@)7,B"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,3`*
M;7-G:60@(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R
M(")&86QH82!N82!L:6=AY^-O("AB:6YD*2!A;R!S97)V:61O<B!,1$%0+B(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38@;&EB+TYE
M="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&-H96-K(&)A;&%N8V4N("5S(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@=F5R:69I8V%R(&\@<V%L9&\N("5S(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S7"(@=7-I;F<@1E10.B`E
M<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I
M9&]R(%PB)7-<(B!U<V%N9&\@1E10.B`E<R(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,#@W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;W!Y
M("5S('1O("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@8V]P:6%R("5S
M('!A<F$@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S(R"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M8W)I87(@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C$P-S<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@9&ER96-T
M;W)Y(&9O<B!L;V-A;&4@)7,Z(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M8W)I87(@<&%S=&$@9&4@;&]C86QI>F'GXV\@<&%R82!A(&QO8V%L:7IAY^-O
M("5S.B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q,#4*;7-G:60@
M(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&1E<V5N8W)I<'1A<B!O<R!D861O<R!C;VT@;R!01U`N(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD
M(&YO="!D96-R>7!T(%,O34E-12!D871A+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&1E<V5N8W)I<'1A<B!O<R!D861O<R!C;VT@4R]-24U%+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@8V]N=&%C=&\N("5S(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,U-@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP
M=',N<&AP.C,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE
M=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(").XV\@
M9F]I('!O<W/M=F5L(')E;6]V97(@;R!<(G-C<FEP=%PB(&1E(&%C='5A;&EZ
M8>?C;R!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS
M.#$@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z.3,X"FUS9VED(")#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB
M"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!D971E<FUI;F%R(&\@96YD
M97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R!D;R`B"B)D97-T:6YA=.%R
M:6\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PIM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!O(&QI=G)O(&1E(&5N
M9&5R9>=O<R!C;VUP;&5T;RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#DS"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M;V)T97(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\@8V]M<&QE=&$N(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0T-@IM<V=I9"`B0V]U
M;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO
M;B!L:7-T<RXB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!A(&QI
M<W1A(&-O;7!L971A(&1A<R!L:7-T87,@9&4@9&ES=')I8G5IY^-O+B(*"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-C@*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@T
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y
M(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S[79E;"!C87)R96=A<B!E<W1R873I
M9VEA(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A
M;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]U;&0@;F]T(&UK9&ER(%PB)7-<(BXB"FUS9W-T<B`B26UP;W-S
M[79E;"!M:V1I<B!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP
M:'`Z-S`X"FUS9VED(")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O
M;2!T:&4@:V5Y<V5R=F5R+B(*;7-G<W1R("(B"B).XV\@9F]I('!O<W/M=F5L
M(&]B=&5R(&$@8VAA=F4@</IB;&EC82!A('!A<G1I<B!D;R!S97)V:61O<B!D
M92!C:&%V97,@(@HB</IB;&EC87,N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!<(B5S7"(@<&%R82!E<V-R
M:71A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<@
M;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@)7,N(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@86)R:7(@)7,N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HT,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T<B`B3N-O(&9O
M:2!P;W-S[79E;"!A8G)I<B!O(&WS9'5L;R!D92!-86YU=&5NY^-O(&1E(%1A
M<F5F87,@)7,B"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HW,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&%B<FER('!A<W1A(%PB)7-<(BXB"@HC.B!L:6(O5D93+T]B:F5C
M="YP:'`Z,C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R96%D
M("5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&QE<B`E<RXB"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@
M;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R
M+B!3;VUE(&]R(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E
M8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(D[C;R!F
M;VD@<&]S<^UV96P@<F5I;FEC:6%R(&$@<&%L879R82UP87-S92!D;R!U=&EL
M:7IA9&]R(&EN9&EC861O+B!!;&=U;2!O=2`B"B)T;V1O<R!O<R!P;W)M96YO
M<F5S(&[C;R!E<W1A=F%M(&-O<G)E8W1O<RX@4&]R(&9A=F]R('1E;G1E(&1E
M(&YO=F\@;W4@(@HB8V]N=&%C=&4@;R!S974@861M:6YI<W1R861O<B!D92!S
M:7-T96UA<R!S92!P<F5C:7-A<B!D92!M86ES(&%J=61A+B(*"B,Z(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#D@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C,T,`HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S<W(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#,*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I
M9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&]B=&5R($%#3"(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B3N-O(&9O:2!P;W-S
M[79E;"!O8G1E<B!L:79R;R!D92!E;F1E<F7G;W,N("5S(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&ES=&$@9&4@9&ES
M=')I8G5IY^-O+B`E<R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HT,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!L:7-T87,@9&4@9&ES=')I8G5IY^-O+B`E<R(*"B,Z
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ.3D@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M<V5R=F5R)W,@8V%P86)I;&ET:65S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@87,@8V]M<&5TZFYC:6%S(&1O('-E<G9I9&]R(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E
M=F5R=&5R(&$@8V]N9FEG=7)AY^-O+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DEM<&]S
M<^UV96P@<FUD:7(@7"(E<UPB+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A
M<F1A<B!A(&-O;F9I9W5R8>?C;R!D92`E<RXB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z-C,@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E
M('-A;'9A9W5A<F1A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A
M<F1A<B!A(&-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D83H@)7,B"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E
M<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&=U87)D87(@;R!<(G-C
M<FEP=%PB(&1E(&%C='5A;&EZ8>?C;R!E;3H@7"(E<UPB+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R
M8>?C;R!D92!S86QV86=U87)D82`E<RXB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B
M86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@
M)7,N(@IM<V=S='(@(B(*(D[C;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!O(&%R
M<75I=F\@9&4@8V]N9FEG=7)AY^-O("5S+B!0;V1E('5S87(@=6UA(&1A<R`B
M"B)O<.?U97,@<&%R82!G=6%R9&%R(&\@8_-D:6=O(&5M("5S(&]U(&-O<&EA
M<B!M86YU86QM96YT92!O(&/S9&EG;R!A8F%I>&\@(@HB<&%R82`E<RXB"@HC
M.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,C`*;7-G:60@(D-O=6QD(&YO
M="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L('!R;V-U<F%R(&YO('-E<G9I9&]R($Q$05`N(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5N;&EN:R!<(B5S7"(N(@IM
M<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5S;&EG87(@7"(E<UPB+B(*"B,Z
M(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G
M<W1R(").XV\@9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@8V]N=&%C=&\N("5S
M(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&%C='5A;&EZ
M87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B!<(B5S7"(Z("5S(@IM<V=S='(@
M(D[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@82!C;VYF:6=U<F'GXV\@<&%R
M82!<(B5S7"(Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U.`IM
M<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB3N-O(&5N
M8V]N=')E:2!A($)A<G)A($QA=&5R86P@9&\@36]Z:6QL82X@07-S96=U<F4M
M<V4@<75E(&$@8F%R<F$@;&%T97)A;"`B"B)E<W3A(&%B97)T82XB"@HC.B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34T"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O
M;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@7"(E<UPB.B`E<R(*;7-G
M<W1R("(B"B).XV\@9F]I('!O<W/M=F5L(&%T<FEB=6ER(&%O('5T:6QI>F%D
M;W(@7"(E<UPB(&]S('-E9W5I;G1E<R!D:7)E:71O<R!S;V)R92!A("(*(G!A
M<W1A(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R,0IM
M<V=I9"`B0V]U;G1E9"!T97AT(@IM<V=S='(@(E1E>'1O($-O;G1A9&\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V.0IM<V=I9"`B0V]U;G1R
M>2(*;7-G<W1R(")08>US(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(W,`IM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")#=7)S;W,B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,C$@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.CDW"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#$*;7-G:60@(D-R96%T92(*;7-G<W1R(")#<FEA<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I
M9"`B0W)E871E(&$@;&EN:R(*;7-G<W1R(")#<FEA<B!U;6$@;&EG8>?C;R(*
M"B,Z('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3,*;7-G
M:60@(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`B0W)I87(@=6UA(&YO=F$B
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*;7-G:60@
M(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R(")#<FEA<B!S=6(M<&%S=&%S
M(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3,V(&QI8B](;W)D92]097)M
M<R]522YP:'`Z,C$T"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S
M='(@(E!E<FUI<W/U97,@9&\@0W)I861O<B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HS,C(Y"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B
M3OIM97)O(&1O(&-A<G3C;R!D92!C<NED:71O(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D-R;V%T:6$B
M"FUS9W-T<B`B4F5P^F)L:6-A(&1A($-R;^%C:6$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C8U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#=6)A(@IM
M<V=S='(@(E)E</IB;&EC82!D92!#=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(E%U871R
M;R!F87-E<R!C;W)R96YT97,B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,R!L
M:6(O0FQO8VLO=&EM92YP:'`Z,S`*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G
M<W1R(")$871A+TAO<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-3,*;7-G:60@(D-U<G)E;G0@55),(&ES
M(@IM<V=S='(@(E523"!C;W)R96YT92#I(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR-0IM<V=I9"`B0W5R<F5N="!796%T:&5R(@IM<V=S='(@(D5S=&%D
M;R!D;R!496UP;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-C,*;7-G:60@(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B4VET=6'G
MXV\@86-T=6%L.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D5S
M=&EL;R!A8W1U86PB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`X"B,L
M('!H<"UF;W)M870*;7-G:60@(D-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O
M;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B4&5R<V]N86QI>F%R(&%S('1A<F5F
M87,@<75E('-E<N-O(&5X96-U=&%D87,@87%U86YD;R!O(&QO9VEN(&YO("5S
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(D-O<G1A<B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@
M(D-U="!S96QE8W1I;VXB"FUS9W-T<B`B0V]R=&%R(&$@<V5L96/GXV\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C8V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS
M9VED(")#>7!R=7,B"FUS9W-T<B`B4F5P^F)L:6-A(&1E($-H:7!R92(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R"FUS9VED(")#>7)I;&QI8R`H2T])
M."U2*2(*;7-G<W1R(")#:7+M;&EC;R`H2T])."U2*2(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3@S"FUS9VED(")#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q
M*2(*;7-G<W1R(")#:7+M;&EC;R`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3@T"FUS9VED(")#>7)I;&QI8R]5:W)A:6YI86X@
M*$M/23@M52DB"FUS9W-T<B`B0VER[6QI8V\O56-R86YI86YO("A+3TDX+54I
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($-H
M96-A(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R
M,R!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.0HC.B!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B
M1$0B"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")$:6%R:6%M96YT92(*"B,Z(&%D;6EN+V1A=&%T<F5E
M+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R(").879E
M9V%D;W(@9&4@P7)V;W)E(&1E($1A9&]S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(S.3@@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B1&%T82(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$S"FUS9VED(")$871E(%)E8V5I=F5D(@IM
M<V=S='(@(D1A=&$@9&4@4F5C97#GXV\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C@P-@IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`B4V5L96/G
MXV\@9&4@9&%T82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M.#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,`IM<V=I9"`B1&%Y
M(@IM<V=S='(@(D1I82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB
M"FUS9W-T<B`B4F5M;W9E<B!#;U]L=6YA(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D1E>F5M
M8G)O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@
M(D[Z;65R;W,@9&5C:6UA:7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B4F5D=7II<B!I;F1E;G1AY^-O(@H*(SH@;&EB+W!R969S+G!H<#HQ
M,3$@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.#<*;7-G:60@(D1E9F%U;'0B
M"FUS9W-T<B`B4&]R($]M:7-SXV\B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#;VQO<B(*
M;7-G<W1R(")#;W(@4&]R($]M:7-SXV\B"@HC.B!L:6(O2&]R9&4O261E;G1I
M='DN<&AP.CDQ"FUS9VED(")$969A=6QT($ED96YT:71Y(@IM<V=S='(@(DED
M96YT:61A9&4@4&%D<N-O(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$Y
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,3DV"FUS9VED(")$969A=6QT(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@4&]R($]M:7-SXV\B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$Y-PIM<V=I9"`B1&5F875L="!P
M97)M:7-S:6]N<R(*;7-G<W1R(")097)M:7-S]65S('!O<B!O;6ES<^-O(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R(")$969I;FGG]65S(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW
M,B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V(&%D;6EN+W!E<FUS+V1E;&5T
M92YP:'`Z-3(*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR.34@;&EB+TAO<F1E
M+U!E<FUS+U5)+G!H<#HS,34*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS
M,S(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C<P('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#(@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<S"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.2!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3,*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")296UO=F5R(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*
M;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")296UO=F5R($=R=7!O(@H*
M(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HV,R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C@W"FUS9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R(")2
M96UO=F5R(%!E<FUI<W/C;R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,PIM<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*
M;7-G<W1R(")296UO=F5R(&4@<'5R9V%R(&UE;G-A9V5N<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G
M:60@(D1E;&5T92!C96QL(@IM<V=S='(@(E)E;6]V97(@8^EL=6QA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R(")296UO=F5R(&-O;'5N
M82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@
M97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(E)E;6]V97(@
M;6]D96QO(&%L=&5R;F%T:79O(&5X:7-T96YT92(*"B,Z(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-3`@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,30*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S
M7"(B"FUS9W-T<B`B4F5M;W9E<B!P97)M:7-S]65S(&1E(%PB)7-<(B(*"B,Z
M(&QI8B](;W)D92]097)M<R]522YP:'`Z,S$W"B,L('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP
M97)M:7-S:6]N<S\B"FUS9W-T<B`B4F5M;W9E<B!P97)M:7-S]65S('!A<F$@
M)R5S)R!E('%U86ES<75E<B!S=6(M<&5R;6ES<_5E<S\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED
M(")$96QE=&4@<F]W(@IM<V=S='(@(E)E;6]V97(@;&EN:&$B"@HC.B!T96UP
M;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE
M=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B4F5M;W9E<B!I9&5N=&ED
M861E('-E;&5C8VEO;F%D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;B(*;7-G<W1R(")296UO=F5R(&$@8V]L=6YA(&-O<G)E
M;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8R"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM
M<V=S='(@(E)E;6]V97(@82!L:6YH82!C;W)R96YT92(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#@*;7-G:60@(D1E;&5T92!T:&ES('!E<FUI<W-I
M;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)E;6]V97(@
M97-T82!P97)M:7-SXV\@92!T;V1A<R!A<R!S=6%S('-U8BUP97)M:7-S]65S
M/R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"B,L('!H<"UF;W)M
M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB
M+B(*;7-G<W1R(")<(E-C<FEP=%PB(&1E(&%C='5A;&EZ8>?C;R!<(B5S7"(@
M<F5M;W9I9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4V,R!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"FUS9VED(")$96QI=F5R>2!T:6UE
M(@IM<V=S='(@(DUO;65N=&\@9&4@96YT<F5G82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HW,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D1E;FUA<FLB
M"FUS9W-T<B`B1&EN86UA<F-A(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z
M,3$P('-E<G9I8V5S+W!R;V)L96TN<&AP.C$Q-"!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HQ,C0*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@
M(D1E<V-R979A(&\@4')O8FQE;6$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:>?C;R(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3DU"FUS9VED(")$971A:6QS("AA;'-O(&EN
M($AO<F1E)W,@;&]G9FEL92DZ(@IM<V=S='(@(E!O<FUE;F]R97,@*'1A;6+I
M;2!N;R!R96=I<W1O+"!<(FQO9UPB+"!D;R!(;W)D92DZ(@H*(SH@;&EB+TAO
M<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F
M;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D]S(&1E=&%L:&5S(&9O
M<F%M(&5N=FEA9&]S('!A<F$@;R!A9&UI;FES=')A9&]R(&1O('-I<W1E;6$N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y.`IM<V=I9"`B1&5V
M96QO<&UE;G0B"FUS9W-T<B`B1&5S96YV;VQV:6UE;G1O(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R(")0
M;VYT;R!D92!/<G9A;&AO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.30*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B4&]N
M=&\@9&4@3W)V86QH;R!N82#Z;'1I;6$@:&]R83H@(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Q-0IM<V=I9"`B1&5W('!O:6YT.B`B"FUS
M9W-T<B`B4&]N=&\@9&4@;W)V86QH;SH@(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0B"FUS9W-T<B`B1&ER96/GXV\@9&$@97-Q=65R9&$@<&%R
M82!A(&1I<F5I=&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C,Y"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*
M;7-G<W1R(")$:7)E8^?C;R!D82!D:7)E:71A('!A<F$@82!E<W%U97)D82(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y"FUS9VED(")$:7)E8W1O<GDB
M"FUS9W-T<B`B1&ER96-T\W)I;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-3@*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T:6UE<S\B"FUS9W-T<B`B
M36]S=')A<B!T96UP;W,@8V]M(#(T(&AO<F%S/R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HY-PIM<V=I9"`B1&ES<&QA>2!/<'1I;VYS(@IM<V=S='(@
M(D]PY_5E<R!D92!6:7-U86QI>F'GXV\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z.#@*;7-G:60@(D1I<W!L87D@9&5T86EL960@9F]R96-A
M<W0B"FUS9W-T<B`B36]S=')A<B!P<F5V:7/C;R!P;W)M96YO<FEZ861A(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0IM<V=I9"`B1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*2(*;7-G<W1R(")-;W-T<F%R('!R979I<^-O("A4048I(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,38*;7-G:60@(D1I<W!L87D@9F]R
M;6%T(@IM<V=S='(@(D9O<FUA=&\@9&4@=FES=6%L:7IAY^-O(@H*(SH@;&EB
M+TAO<F1E+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B(*;7-G<W1R(").;W1I9FEC8>?C;R!D92!$:7-P;W-IY^-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<P(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M.0IM<V=I9"`B1&II8F]U=&DB"FUS9W-T<B`B1&II8G5T:2(*"B,Z(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS
M,34*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B3N-O(')E;6]V97(B
M"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,C0*;7-G:60@(D1O(&YO
M="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP(@IM<V=S='(@(D[C
M;R!U=&EL:7IE(&\@;6%I;G1E;F%N8V4N<&AP(&1I<F5C=&%M96YT92(*"B,Z
M('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$Y('1E;7!L871E<R]D871A
M+V-S=FEN9F\N:6YC.C$Y"FUS9VED(")$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M(@IM<V=S='(@(B(*(D$@<')I;65I<F$@;&EN:&$@8V]N=.EM(&]S(&YO;65S
M(&1O<R!C86UP;W,_(%-E('-I;2P@87-S:6YA;&%R(&5S=&$@8V%I>&$Z(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.0IM
M<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B1&]M:6YI8V$B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")$;VUI
M;FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A($1O;6EN:6-A;F$B
M"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q"FUS9VED(")$
M;W=N;&]A9"(*;7-G<W1R(")296-E8F5R(@H*(SH@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R(")296-E8F5R("5S(@H*(SH@861M:6XO<V5T=7`O:6YD
M97@N<&AP.C$V-0IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`B1&5S8V%R<F5G87(@82!C
M;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@7")S8W)I<'1<(B!02%`N(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,#@*;7-G:60@(D1R;W`@9&]W;B!L
M:7-T(@IM<V=S='(@(DQI<W1A(&1E(&1E<V5N<F]L87(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(D1R;V=A
M<R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@IM<V=I9"`B12U-
M86EL(@IM<V=S='(@(D-O<G)E:6\@96QE8W1R\VYI8V\B"@HC.B!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S0*;7-G:60@
M(D524B(*;7-G<W1R(")%4E(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%8W5A9&]R(@IM<V=S='(@(E)E
M</IB;&EC82!D;R!%<75A9&]R(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H<#HR
M.30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M.3(*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E
M;7!L871E<R]P;W)T86PO961I="YI;F,Z,C(*;7-G:60@(D5D:70B"FUS9W-T
M<B`B161I=&%R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,"!T96UP
M;&%T97,O<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET($)L;V-K(@IM
M<V=S='(@(D5D:71A<B!";&]C;R(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3@X
M(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET($=R;W5P(@IM<V=S
M='(@(D5D:71A<B!'<G5P;R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M-C(@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX-@IM<V=I9"`B161I="!097)M
M:7-S:6]N(@IM<V=S='(@(D5D:71A<B!097)M:7-S]65S(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N
M<R(*;7-G<W1R(")%9&ET87(@4&5R;6ES<_5E<R(*"B,Z('-E<G9I8V5S+W-H
M87)E<R]E9&ET+G!H<#HR,SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B161I="!0
M97)M:7-S:6]N<R!F;W(@)7,B"FUS9W-T<B`B161I=&%R('!E<FUI<W/U97,@
M9&4@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU"FUS9VED(")%
M9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")%9&ET87(@;W#G]65S(&1E.B(*
M"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P-"!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C(X,`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I
M;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B161I=&%R('!E<FUI<W/U97,@9&4@
M7"(E<UPB(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R(")%9&ET87(@<&5R;6ES<_5E<R!D92`E<R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HS-0IM<V=I9"`B161U8V%T:6]N(@IM<V=S='(@(D5D=6-A
MY^-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<W(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HW,`IM<V=I9"`B16=Y<'0B"FUS9W-T<B`B16=I<'1O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`W"FUS9VED(")%
M;"!386QV861O<B(*;7-G<W1R(")297#Z8FQI8V$@9&4@16P@4V%L=F%D;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-#(*;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N=&\N
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3@W,"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R
M-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B0V]R<F5I;R!%;&5C='+S;FEC;R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38U('1E;7!L871E<R]A
M9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA:6P@061D<F5S<R(*;7-G<W1R
M(")%;F1E<F7G;R!D92!#;W)R96EO($5L96-T<O-N:6-O(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Y-C0*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T
M(&UA=&-H+B(*;7-G<W1R(")/<R!E;F1E<F7G;W,@=.IM('%U92!C;VEN8VED
M:7(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y.3`*;7-G:60@(D5M86EL
M('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@(DUE;G-A9V5M(&-O;2!C;VYF
M:7)M8>?C;R(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR.#`*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R(")3[6UB;VQO<R!D92!%
M;6_GXV\B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M,@IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`B365N<V%G96T@=F%Z
M:6$N(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3(X"FUS9VED(")%
M;7!T>2!R97-U;'0N(@IM<V=S='(@(E-E;2!R97-U;'1A9&]S+B(*"B,Z(&QI
M8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A
M<F-H('1E<FUS(@IM<V=S='(@(E-E;2!T97)M;W,@9&4@<')O8W5R82(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S4*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(D%C=&EV87(@:6YS97+GXV\@9&4@:6UA9V5N<R!D92!'86QE
M<FEA<R!&;W1O9W+A9FEC87,@;F\@=&5X=&\_(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4Q,`IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E
M>'0@;65N=3\B"FUS9W-T<B`B06-T:79A<B!M96YU(&1E(&-O;G1E>'1O(&YO
M(&)O=.-O(&1I<F5I=&\@9&\@<F%T;S\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4Y-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@Q,`IM<V=I9"`B16YD('EE
M87(B"FUS9W-T<B`B06YO(&1E(&9I;2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(D%U;65N=&%R($5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,3,*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"B));G1R;V1U>F$@=6UA('!E<F=U
M;G1A(&1E('-E9W5R86[G82!Q=64@<V5RX2!C;VYV:61A9&\@82!R97-P;VYD
M97(@<V4@(@HB<')E8VES87(@9&4@<F5I;FEC:6%R(&$@<W5A('!A;&%V<F$M
M<&%S<V4L(&4N9RXL("=C;VUO('-E(&-H86UA(&\@<V5U(&%N:6UA;"`B"B)D
M92!E<W1I;6'GXV\_)SHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N=&5R('1H92!I
M;6%G92!54DP@:&5R92(*;7-G<W1R("));G1R;V1U>F$@;R!54DP@9&$@:6UA
M9V5M(&%Q=6DB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$V,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T
M92P@)60@;F5W+"`E9"!C:&%N9V5D+"`E9"!U;FMN;W=N(@IM<V=S='(@(B(*
M(D5N=')A9&%S.B`E9"!T;W1A;"P@)60@86-T=6%L:7IA9&%S+"`E9"!N;W9A
M<RP@)60@86QT97)A9&%S+"`E9"!D97-C;VYH96-I9&%S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B17%U
M871O<FEA;"!'=6EN96$B"FUS9W-T<B`B1W5I;ND@17%U871O<FEA;"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HW.2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G
M:60@(D5R:71R96$B"FUS9W-T<B`B17-T861O(&1A($5R:71R96EA(@H*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-R!L:6(O0FQO8VLO
M;65T87(N<&AP.C,V"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-SD*
M;7-G:60@(D5R<F]R(@IM<V=S='(@(D5R<F\B"@HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+B(*;7-G<W1R(")%<G)O(&YA(&UE;G-A9V5M(&1E(&-O<G)E
M:6\@96QE8W1R\VYI8V\N(@H*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN
M<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF;W)M870*;7-G:60@
M(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R(")%<G)O(&%O(&5S8W)E
M=F5R(%PB)7-<(BXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#$S('!O+W1R
M86YS;&%T:6]N+G!H<#HU,C(@<&\O=')A;G-L871I;VXN<&AP.C$S-S<*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$T,S@@<&\O=')A;G-L871I;VXN<&AP.C$U
M,#$*;7-G:60@(D5R<F]R.B`B"FUS9W-T<B`B17)R;SH@(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C<V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B17-T
M;VYI82(*;7-G<W1R(")297#Z8FQI8V$@9&$@17-T\VYI82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HX,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-S@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T
M:&EO<&EA(@IM<V=S='(@(E)E</IB;&EC82!$96UO8W+A=&EC82!&961E<F%L
M(&1A($5T:?-P:6$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S8*;7-G
M:60@(D5T:&YI8R(*;7-G<W1R("+)=&EC;R(*"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,S,0IM<V=I9"`B179E<GD@,34@
M;6EN=71E<R(*;7-G<W1R(")#861A(#$U(&UI;G5T;W,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S@Q"FUS9VED(")%=F5R>2`R(&UI;G5T97,B"FUS
M9W-T<B`B0V%D82`R(&UI;G5T;W,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S(X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(D5V97)Y
M(#,P('-E8V]N9',B"FUS9W-T<B`B0V%D82`S,"!S96=U;F1O<R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S`@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C,X,@IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(D-A9&$@-2!M
M:6YU=&]S(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HV,`IM<V=I
M9"`B179E<GD@3&]G:6XB"FUS9W-T<B`B0V%D82!%;G1R861A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,S,@IM<V=I9"`B179E<GD@:&%L9B!H;W5R
M(@IM<V=S='(@(D-A9&$@;65I82!H;W)A(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,R.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED(")%
M=F5R>2!M:6YU=&4B"FUS9W-T<B`B0V%D82!M:6YU=&\B"@HC.B!T96UP;&%T
M97,O9&%T82]D871E;6%P+FEN8SHR.`IM<V=I9"`B17AA;7!L92!V86QU97,Z
M(@IM<V=S='(@(E9A;&]R97,@97AE;7!L;SHB"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL
M+G!H<#HQ,C@*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B17AE8W5T87(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,CDY('!O+W1R86YS;&%T:6]N+G!H<#HS
M,C`@<&\O=')A;G-L871I;VXN<&AP.C,V,@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-#0Q('!O+W1R86YS;&%T:6]N+G!H<#HU-#$@<&\O=')A;G-L871I;VXN
M<&AP.C8P,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S`R('!O+W1R86YS;&%T
M:6]N+G!H<#HW,S<@<&\O=')A;G-L871I;VXN<&AP.C<Y.`HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z.#<U('!O+W1R86YS;&%T:6]N+G!H<#HY.30@<&\O=')A
M;G-L871I;VXN<&AP.C$P,38*;7-G:60@(D5X96-U=&EN9SHB"FUS9W-T<B`B
M17AE8W5T86YD;SHB"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS
M.30*;7-G:60@(D5X<&%N9"(*;7-G<W1R(")%>'!A;F1I<B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S$*;7-G:60@(D5X<&%N9"!3:61E
M8F%R(@IM<V=S='(@(DUO<W1R87(@0F%R<F$@3&%T97)A;"(*"B,Z(&QI8B](
M;W)D92]344PO2V5Y=V]R9',N<&AP.C$V.`IM<V=I9"`B17AP96-T960@)RDG
M(@IM<V=S='(@(B<I)R!E<W!E<F%D;R(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R(")%<W!E<F%V82!U;6$@<VEM<&QE
M<R!P86QA=G)A(&]U('5M('1E<FUO(&1E('!R;V-U<F$@96YT<F4@87-P87,B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,#$*;7-G:60@(D5X<&ER
M871I;VX@1&%T92(*;7-G<W1R(")$871A(&1E($5X<&ER8>?C;R(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<V"FUS9VED(")%>'!O;F5N="(*
M;7-G<W1R(")%>'!O96YT92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR-S(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17AT<F%C=&EN9R!F<F]M("5S+BXN("(*
M;7-G<W1R(")%>'1R86EN9&\@9&4@)7,N+BX@(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@
M0V]L;W(B"FUS9W-T<B`B0V]R(&1O(%!R:6UE:7)O(%!L86YO(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`IM<V=I9"`B1E10('5P;&]A9"!O9B!S
M971U<"(*;7-G<W1R(")#87)R96=A<B!C;VYF:6=U<F'GXV\@9&4@:6YS=&%L
M8>?C;R!P;W(@1E10(@H*(SH@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C$V
M"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!P=7AA<B!A<R!P<F5F97+J;F-I87,N(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,3`P"FUS9VED(")&86EL960@
M=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`B1F%L:&$@;F$@
M;&EG8>?C;R!A;R!S97)V:61O<B!,1$%0+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S
M97)V97(N(@IM<V=S='(@(D9A;&AA(&YA(&QI9V'GXV\@86\@<V5R=FED;W(@
M4TU"+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(D9A
M;&AA(&%O(&-O<&EA<B!D92!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F='`N<&AP
M.C8P.`HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@8V]P>2!T;R!<
M(B5S7"(N(@IM<V=S='(@(D9A;&AA(&%O(&-O<&EA<B!P87)A(%PB)7-<(BXB
M"@HC.B!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX-PIM<V=I9"`B1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*;7-G<W1R(")&86QH
M82!A;R!C<FEA<B!U;6$@;F]V82!C;VYE>.-O(%-!4TPN(@H*(SH@;&EB+U9&
M4R]F='`N<&AP.C8T,0HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@
M;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(D9A;&AA(&%O(&UO=F5R('!A<F$@
M7"(E<UPB+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C$X"FUS9VED(")&86ER(@IM<V=S='(@(D)O;2(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HX-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-SD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*2(*;7-G<W1R("));&AA<R!&86QK;&%N
M9"`H36%L=FEN87,I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%R;V4@27-L86YD<R(*;7-G<W1R("))
M;&AA<R!&87)O92(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(S.`IM<V=I9"`B
M1F%T86P@17)R;W(Z(@IM<V=S='(@(D5R<F\@1F%T86PZ(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.#<*;7-G:60@(D9A>"(*;7-G
M<W1R(")&87@B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM
M<V=I9"`B1F5B<G5A<GDB"FUS9W-T<B`B1F5V97)E:7)O(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B
M07!A<F5N=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y
M"FUS9VED(")&965L<R!L:6ME.B`B"FUS9W-T<B`B07!A<F5N=&$Z("(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$Y"FUS9VED
M(")&97<@4VAO=V5R<R(*;7-G<W1R(")!;&=U;G,@06=U86-E:7)O<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(P"FUS9VED
M(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D%L9W5N<R!.97;U97,B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DT-0IM<V=I9"`B1FEE;&0@;6%T<FEX
M(@IM<V=S='(@(DUA=')I>B!D92!C86UP;W,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Q"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")&:6II(@IM<V=S
M='(@(D9I:FDB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<#HV
M,"!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HV-PHC.B!L:6(O2&]R
M9&4O34E-12]6:65W97(O=&=Z+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(D-O;G1A9V5M(&1E($%R
M<75I=F]S.B`E<R!A<G%U:79O(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C`@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-SD*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS9W-T<B`B0V]N
M=&%G96T@9&4@07)Q=6EV;W,Z("5S(&%R<75I=F]S(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T-@IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(D=E<W3C;R!D92!&:6-H96ER;W,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H
M<#HW,`HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX,@IM<V=I
M9"`B1FEL92!.86UE(@IM<V=S='(@(DYO;64@9&\@07)Q=6EV;R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3DT"FUS9VED(")&:6QE('-E;&5C=&EO;B(*
M;7-G<W1R(")396QE8^?C;R!D;R!A<G%U:79O(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$T.#@*;7-G:60@(D9I;&4@=7!L;V%D(@IM<V=S='(@(D-A<G)E
M9V%M96YT;R!D92!A<G%U:79O(@H*(SH@;&EB+TAO<F1E+T)R;W=S97(N<&AP
M.C@V,PIM<V=I9"`B1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N(@IM<V=S
M='(@(D-A<G)E9V%M96YT;W,@9&4@9FEC:&5I<F]S(&[C;R!SXV\@<W5P;W)T
M861O<RXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@
M(D9I;'1E<G,B"FUS9W-T<B`B1FEL=')O<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D9I;FQA;F0B"FUS
M9W-T<B`B1FEN;.)N9&EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$W,0IM
M<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")1=6%R=&\@0W)E<V-E;G1E(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI8B]";&]C:R]M;V]N+G!H<#HW
M-@IM<V=I9"`B1FER<W0@475A<G1E<B(*;7-G<W1R(")1=6%R=&\@0W)E<V-E
M;G1E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S
M.0IM<V=I9"`B1FEX(')A=&EO(@IM<V=S='(@(D9I>&%R('+A8VEO(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`IM<V=I9"`B
M1FQI<"(*;7-G<W1R("));G9E<G1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM
M<V=S='(@(D9L=71U86YT92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B3F5V;V5I<F\B
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,38P(&QI8B]61E,O;75S<6PN<&AP.C$P
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0B"FUS9W-T<B`B02!P87-T82`E<R!NXV\@97AI<W1E+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O
M;G0@0V]L;W(B"FUS9W-T<B`B0V]R(&1O(%1E>'1O(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(D-O;6ED82(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHR-@IM<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P
M<&]R="!I;6%G97,B"FUS9W-T<B`B4&%R82!N879E9V%D;W)E<R!Q=64@;N-O
M('-U<&]R=&%M(&EM86=E;G,B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S
M-`IM<V=I9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B4')E=FESXV\@*%1!
M1BDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S$*;7-G:60@
M(B(*(D9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R
M96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@(@HB;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RDB"FUS
M9W-T<B`B(@HB1&EA<R!D92!0<F5V:7/C;R`H;F]T92US92!Q=64@87,@<')E
M=FES]65S(&EN8VQU96T@=&%N=&\@9&EA<R!C;VUO(&YO:71E<SL@(@HB=6T@
M=F%L;W(@9&5M87-I861O(&=R86YD92!P;V1E(')E<W5L=&%R(&YU;2!B;&]C
M;R!M=6ET;R!L87)G;RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.CDX"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B17-Q
M=65C974M<V4@9&$@<&%L879R82UP87-S93\B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#`Y"FUS9VED(")&;W)M<R(*;7-G<W1R(")-;V1E;&]S
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE
M(@IM<V=S='(@(D1I=&]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDY
M"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5&EP;R!D92!D:71O<R(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM<V=I9"`B1F]R='5N97,B
M"FUS9W-T<B`B1&ET;W,B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*
M;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B1&ET;W,@,B(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HT,#`*;7-G:60@(D9O<G5M<R(*;7-G<W1R
M(")&\W)U;G,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`Y"FUS
M9VED(")&;W)W87)D<R(*;7-G<W1R(")2965N=FEO<R(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ-#4X"B,L('!H<"UF;W)M870*;7-G:60@(D9O=6YD(&%P
M<&QI8V%T:6]N<SH@)7,B"FUS9W-T<B`B07!L:6-AY_5E<R`H;?-D=6QO<RD@
M96YC;VYT<F%D87,Z("5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T-3(*
M;7-G:60@(D9O=6YD(&1I<F5C=&]R:65S.B(*;7-G<W1R(")087-T87,@96YC
M;VYT<F%D87,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B-JHB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S"FUS9VED
M(")&<F%M97,B"FUS9W-T<B`B36]L9'5R87,B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&<F%N8V4B"FUS
M9W-T<B`B4F5P^F)L:6-A($9R86YC97-A(@H*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P;VQI=&%N(@IM<V=S
M='(@(D9R86[G82P@365T<F]P;VQI=&%N82(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R96YC:"!'=6EA
M;F$B"FUS9W-T<B`B1W5I86YA($9R86YC97-A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B4&]L:6[I<VEA($9R86YC97-A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Y"FUS9VED
M(")&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,B"FUS9W-T<B`B5&5R<F%S
M($%U<W1R86ES(&4@06YTX7)C=&EC87,@1G)A;F-E<V%S(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS
M9W-T<B`B1&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,V
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#@*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,Y-`IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S
M='(@(D1E("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X
M"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D1E<V-R:>?C;R!#
M;VUP;&5T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX,B!L:6(O0FQO8VLO
M;6]O;BYP:'`Z,3@Q"FUS9VED(")&=6QL($UO;VXB"FUS9W-T<B`B3'5A($-H
M96EA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS.0IM
M<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(DYO;64@0V]M<&QE=&\B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")&=7IZ>2(*;7-G<W1R(")$
M:69U<V%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HX-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B4F5P^F)L:6-A($=A8F]N
M97-A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL97)Y('1O('1A:V4@:6UA9V4@
M9G)O;2(*;7-G<W1R(")'86QE<FEA(&1E(&]N9&4@<F5T:7)A<B!A(&EM86=E
M;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T<B`B1V%L97)I
M83HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.38@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($?B;6)I
M82(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;B(*;7-G<W1R(")'
M97)A<B!#;VYF:6=U<F'GXV\@)7,B"@HC.B!T96UP;&%T97,O861M:6XO<V5T
M=7`O8V]N9FEG+FAT;6PZ,3`*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S
M='(@(D/S9&EG;R!'97)A9&\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=E;F5R871I;F<@<W1A='5S(&9O<B!M
M;V1U;&4@)7,N+BXB"FUS9W-T<B`B1V5R86YD;R!O(&5S=&%D;R!D;R!M\V1U
M;&\@)7,N+BXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3`@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C@Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")'96]R9VEA(@IM<V=S='(@(D=E\W)G:6$B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.CDP"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS
M9VED(")'97)M86YY(@IM<V=S='(@(E)E</IB;&EC82!&961E<F%L(&1A($%L
M96UA;FAA(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-S$*;7-G:60@(D=E
M=&]P="!%<G)O<CH@(@IM<V=S='(@(D5R<F\@96T@9V5T;W!T.B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@
M(D=H86YA(@IM<V=S='(@(E)E</IB;&EC82!D;R!'86YA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDT(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VEB
M<F%L=&%R(@IM<V=S='(@(D=I8G)A;'1A<B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(DYO
M;64@4'+S<')I;R(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$R"FUS
M9VED(")';R(*;7-G<W1R("))<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(D?V9&5L(@H*(SH@;&EB+T)L
M;V-K+V=O;V=L92YP:'`Z,R!L:6(O0FQO8VLO9V]O9VQE+G!H<#HR,2!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HT,0IM<V=I9"`B1V]O9VQE(%-E87)C:"(*;7-G
M<W1R(")097-Q=6ES82!';V]G;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C(P"FUS9VED(")'<F%Y<V-A;&4B"FUS9W-T<B`B
M3NUV96ES(&1E(&-I;GIE;G1O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C92(*;7-G<W1R(")'
M<NEC:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-0IM<V=I9"`B1W)E
M96L@*$E33RTX.#4Y+3<I(@IM<V=S='(@(D=R96=O("A)4T\M.#@U.2TW*2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*
M;7-G:60@(D=R965N;&%N9"(*;7-G<W1R(")'<F]N96SB;F1I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=R96YA9&$B"FUS9W-T<B`B1W)A;F%D82(*"B,*(SH@861M:6XO9W)O=7!S
M+G!H<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F'GXV\@9&4@1W)U<&]S(@H*(SH@;&EB+TAO<F1E+T=R;W5P
M+G!H<#HU.`IM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB
M"FUS9W-T<B`B3F]M97,@9&4@9W)U<&]S(&[C;R!P;V1E;2!E<W1A<B!V87II
M;W,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HR,#$@;&EB+TAO<F1E+U!E
M<FUS+U5)+G!H<#HR-S<*;7-G:60@(D=R;W5P('!E<FUI<W-I;VYS(@IM<V=S
M='(@(E!E<FUI<W/U97,@9&4@9W)U<&\B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-3`@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P;W,B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.CDV"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V"FUS9VED(")'=6%D
M96QO=7!E(@IM<V=S='(@(D=U861A;'5P92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDW"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%M(@IM<V=S
M='(@(D=U86TB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(E)E</IB;&EC
M82!D82!'=6%T96UA;&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*
M;7-G:60@(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@861M:6XO
M<&5R;7,O961I="YP:'`Z,3(W(&QI8B](;W)D92]097)M<R]522YP:'`Z,C`U
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U97-T
M(%!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U97,@9&%S(%9I<VET87,B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,C@@;&EB+TAO<F1E+U!E<FUS
M+U5)+G!H<#HR,#8*;7-G:60@(D=U97-T('!E<FUI<W-I;VYS(@IM<V=S='(@
M(E!E<FUI<W/U97,@9&%S(%9I<VET87,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#$W"FUS9VED(")'=65S=&)O;VLB"FUS9W-T<B`B3&EV<F\@
M9&4@5FES:71A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S4*;7-G:60@(D=U:6YE82(*;7-G<W1R(")'=6ENZ2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#0@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R(")'=6ENZ2U":7-S874B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*
M;7-G:60@(D=U>6%N82(*;7-G<W1R(")297#Z8FQI8V$@0V\M;W!E<F%T:79A
M(&1A($=U:6%N82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-C`*;7-G:60@
M(DA434PB"FUS9W-T<B`B2%1-3"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#4*;7-G:60@(DA434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W
M+B(*;7-G<W1R(")/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E;65N=&4@
M82!R96UO=F5R(&$@^FQT:6UA(&/I;'5L82!D82!L:6YH82XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@V"FUS
M9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(D\@2%1-3$%R96$@<F5C
M=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V97(@82#Z;'1I;6$@8V]L=6YA
M(&1A('1A8F5L82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C@W"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N(@IM<V=S
M='(@(D\@2%1-3$%R96$@<F5C=7-A+7-E(&-O8F%R9&5M96YT92!A(')E;6]V
M97(@82#Z;'1I;6$@;&EN:&$@9&$@=&%B96QA+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VAT='`N<&AP.C$U-PIM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(D%U=&5N=&EC8>?C;R!(5%!0(&[C;R!F;VD@
M96YC;VYT<F%D82XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$P(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#`*;7-G:60@(DAA:71I(@IM<V=S='(@(E)E</IB;&EC
M82!D;R!(86ET:2(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P,@IM
M<V=I9"`B2&%S:"U!;&=O<FET:&TB"FUS9W-T<B`B06QG;W)I=&UO(&1E(%PB
M2&%S:%PB(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C(*;7-G:60@(DAA>F4B"FUS9W-T<B`B3F5B;&EN82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HY,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,S$*;7-G
M:60@(DAE861E<B(*;7-G<W1R(")#86)EYV%L:&\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(DAE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("));&AA<R!(
M96%R9"!E($UC1&]N86QD(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,C,*;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B
M5&5M<&]R86PM5"!&;W)T92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V
M"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS9W-T<B`B2&5B<F5U
M("A)4T\M.#@U.2TX+4DI(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@
M(D%L='5R82(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ-SD@;&EB+TAO<F1E
M+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC.B!T
M96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G<W1R
M(")!:G5D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D%J
M=61A('-O8G)E(&\@961I=&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$S
M-S,*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")!:G5D82(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HY-0IM<V=I9"`B(@HB2&5L<&5R(&%P<&QI8V%T:6]N('1O
M(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O<B!T:&4@2&]R
M9&5<;B(*(F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N<RY<;B(*(D9O
M<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI
M<R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D%P;&EC8>?C;R!A=7AI;&EA<B!P
M87)A(&-R:6%R(&4@;6%N=&5R('1R861UY_5E<R!D82!P;&%T869O<FUA7&XB
M"B)(;W)D92!E(&1A<R!S=6%S(&%P;&EC8>?U97,@*&WS9'5L;W,I+EQN(@HB
M4&%R82!U;6$@:6YT<F]D=>?C;R!L97(@;R!F:6-H96ER;R!214%$344@;F5S
M=&$@<&%S=&$N(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"FUS9VED(")(
M96UI<W!H97)E(@IM<V=S='(@(DAE;6ES9NER:6\B"@HC.B!T96UP;&%T97,O
M9&%T82]T<W9I;F9O+FEN8SHQ-R!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHQ-PIM<V=I9"`B2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE
M.B(*;7-G<W1R(")!<75I(&5S=.$@;R!I;NUC:6\@9&\@87)Q=6EV;SHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.0IM<V=I
M9"`B2&EG:"(*;7-G<W1R(")!;'1A(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN
M<&AP.C,R,0IM<V=I9"`B2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>2(*;7-G<W1R(").;VUE<R!D87,@96YT<F%D87,@:&ES=/-R:6%S
M(&[C;R!P;V1E;2!E<W1A<B!V87II;W,B"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC
M.C0*;7-G:60@(DAO7VUE(@IM<V=S='(@(D-A7W-A(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L
M>2!3964@*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B17-T861O(&1A
M($-I9&%D92!D;R!6871I8V%N;R(*"B,Z(&QI8B](;W)D92YP:'`Z,30S-0IM
M<V=I9"`B2&]M92(*;7-G<W1R(")#87-A(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ-34*;7-G:60@(DAO;64@061D<F5S<R(*;7-G<W1R(")%;F1E
M<F7G;R!D92!#87-A(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ.3`*;7-G:60@(DAO;64@4&AO;F4B"FUS9W-T<B`B5&5L969O;F4@
M9&4@0V%S82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW.0IM<V=I9"`B2&]N9'5R87,B"FUS9W-T<B`B4F5P^F)L:6-A
M(&1A<R!(;VYD=7)A<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO
M;F=U96-O;F=U92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM
M<V=I9"`B2&]R9&4B"FUS9W-T<B`B2&]R9&4B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,3,R.0IM<V=I9"`B2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R
M(@IM<V=S='(@(D=E<F%D;W(@9&4@=')A9'7G]65S($AO<F1E(@H*(SH@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HT,C`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@1&%D;W,@6$U,("5S
M(&EN=N%L:61O<R!N82!M96YS86=E;2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,C<W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!.
M;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@3F5N:'5M82!M96YS86=E;2!C;W)R97-P;VYD92!A;R!O
M8FIE8W1O("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($YE;FAU;2!O8FIE8W1O(&1O('1I<&\@)7,@96YC;VYT<F%D;R!N82!M96YS
M86=E;2`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V
M960@)7,@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!296UOY^-O(&1E
M("5S(%PB)7-<(B!T979E('-U8V5S<V\B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C$Q-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!S>6YC:')O;FES960@)7,@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B.B!3:6YC<F]N:7IAY^-O(&1E("5S(%PB)7-<(B!T979E('-U
M8V5S<V\B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R
M9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE
M("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($\@;6]T;W(@9&4@:6YT96=R8>?C;R!R97%U97(@82!E>'1E;G/C;R!02%`@
M)V1O;7AM;"<B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N
M97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R("(B"B)(;W)D92]+
M;VQA8CH@3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O<F5S
M(%A-3"!P87)A(&\@;V)J96-T;R`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3(P-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@)7,@7"(E<UPB.B`E<R(*
M"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#4R"B,L('!H<"UF;W)M870*;7-G
M:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F
M;W(@=&AE('!A<G0@;V8@='EP92`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@
M3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!O($E$($U)344@<&%R82!A('!A<G1E
M(&1E('1I<&\@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$Q-3$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC
M:')O;FES92`E<R!<(B5S7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.
MXV\@9F]I('!O<W/M=F5L('-I;F-R;VYI>F%R("5S(%PB)7-<(CH@)7,B"@HC
M.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$R.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!.XV\@9F]I('!O<W/M=F5L('-I
M;F-R;VYI>F%R('!A<G1I;&AA<SH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C,Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YK
M;F]W;B!S:&%R92!<(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%!A<G1I
M;&AA(%PB)7-<(B!D97-C;VYH96-I9&$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(;W)I>F]N=&%L(%)U
M;&4B"FUS9W-T<B`B5')AYV\@2&]R:7IO;G1A;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO<FEZ;VYT
M86P@<&%D9&EN9R(*;7-G<W1R(")%;F-H:6UE;G1O(&AO<FEZ;VYT86PB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Q"FUS
M9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I>F]N=&%L.B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,`IM<V=I9"`B2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2DB"FUS9W-T<B`B0V]M;R!C:&5G;W4@87%U:3\@*%!O<B!F879O<B!R97!O
M<G1E+6\A*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(E%U86YT87,@8V]L=6YA<R!P
M<F5T96YD92!J=6YT87(_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,C@*;7-G:60@(DAO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/R(*;7-G<W1R(")1=6%N=&]S(&-A;7!O<R`H8V]L=6YA<RD@97AI<W1E
M;3\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,V"FUS9VED(")(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/R(*;7-G<W1R(")1=6%N=&%S(&QI;FAA<R!P<F5T96YD92!J
M=6YT87(_(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X."!L
M:6(O0FQO8VLO;65T87(N<&AP.C(S,`IM<V=I9"`B2'5M:61I='DB"FUS9W-T
M<B`B2'5M:61A9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,C0W"FUS9VED(")(=6UI9&ET>3H@(@IM<V=S='(@(DAU;6ED861E.B`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*
M;7-G<W1R(")(=6UO<FES=&%S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@
M(E)E</IB;&EC82!D82!(=6YG<FEA(@H*(SH@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$W,B!L:6(O2&]R9&4O075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P
M:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<R(*;7-G<W1R(")!(&-R:6'GXV\@9&$@8V%I>&$@<&]S=&%L($E-05`@
M9F%L:&]U.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@
M;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T
M<B`B4F5M;^?C;R!D82!C86EX82!P;W-T86P@24U!4"!F86QH;W4Z("5S(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O8WER=7,N<&AP.C$W.2!L:6(O2&]R9&4O075T
M:"]C>7)S<6PN<&AP.C(T,@HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")#<FEA
MY^-O(&1E('%U;W1A(&1E(&-A:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,Q-PIM<V=I9"`B25`@061D<F5S
M<R(*;7-G<W1R(")%;F1E<F7G;R!)4"(*"B,Z(&QI8B](;W)D92]!=71H+VEP
M8F%S:6,N<&AP.C<W"FUS9VED("))4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D5N9&5R9>=O($E0(&EN9&ES<&]N[79E;"XB"@HC.B!L:6(O
M2&]R9&4O075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B16YD97)E
MYV\@25`@9F]R82!D;R!B;&]C;R!#2412('!E<FUI=&ED;RXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-0IM<V=I9"`B25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+B(*;7-G<W1R(")6:6]L8>?C;R!D92!B;&]Q=65I
M;R!D92!)4"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@0F5F;W)E(@IM
M<V=S='(@(DE?;G-E<FER($QI;FAA($%N=&5S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))8V5L86YD
M(@IM<V=S='(@(E)E</IB;&EC82!D82!)<VSB;F1I(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R(")!
M<&5N87,@S6-O;F5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V.0IM
M<V=I9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(LUC;VYE<R!C;VT@5&5X
M=&\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@R"FUS9VED("))9&5N
M=&ET>2=S(&YA;64Z(@IM<V=S='(@(DYO;64@9&$@:61E;G1I9&%D93HB"@HC
M.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3@Y"B,L('!H<"UF;W)M
M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E
M<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`B4V4@;N-O
M(&9O<B!M;W-T<F%D;R!C;W)R96-T86UE;G1E+"`E<R!P87)A(&\@86)R:7(@
M;G5M82!N;W9A(&IA;F5L82XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-#0W"FUS9VED("(B"B))9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN
M9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*
M(G1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S
M='(@(B(*(E-E(&[C;R!V:7(@<75A;'%U97(@[6-O;F4@86\@=7-A<B!O($EN
M=&5R;F5T($5X<&QO<F5R+"!P;V1E('!R96-I<V%R(&1E("(*(G-E;&5C8VEO
M;F%R(&5S=&$@8V%I>&$@<&%R82!D97-L:6=A<B!A('1R86YS<&%RZFYC:6$N
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$U.`IM
M<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E
M+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*(F1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(E-E('9I<B!E
M<W1A(&UE;G-A9V5M(&YM87,@;N-O(&$@:6UA9V5M('!R;W!R:6%M96YT92!D
M:71A+"!A(&EM86=E;2!Q=64@(@HB<')E=&5N9&4@8V%R<F5G87(@;N-O('!O
M9&4@<V5R(&UO<W1R861A('!E;&\@<V5U(&YA=F5G861O<BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z
M,C@*;7-G:60@(DEM86=E(%!R979I97<Z(@IM<V=S='(@(E!R979I<^-O(&1A
M($EM86=E;3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,W"FUS9VED("));6%G92!54DPB"FUS9W-T<B`B55),
M(&1A(&EM86=E;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G
M<W1R(")54DP@9&$@:6UA9V5M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,@IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y(@IM<V=S='(@(DEM86=E;2!D92!G86QE<FEA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C,Q"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(DEM
M86=E;2!D92!G86QE<FEA.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-S8R
M"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B0V%R<F5G86UE;G1O(&1A
M(&EM86=E;2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("))
M;6%G97,B"FUS9W-T<B`B26UA9V5N<R(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$P"B,Z
M('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3
M=&5P("5D(@IM<V=S='(@(DEM<&]R=&%R+"!087-S;R`E9"(*"B,Z('1E;7!L
M871E<R]D871A+V1A=&5M87`N:6YC.C(P"B,L('!H<"UF;W)M870*;7-G:60@
M(DEM<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R(")#86UP;R!I;7!O<G1A9&\Z
M("5S(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW,PIM<V=I9"`B
M26UP;W)T960@9FEE;&1S.B(*;7-G<W1R(")#86UP;W,@:6UP;W)T861O<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S`*;7-G:60@(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(DEN
M7W-E<FER($QI;FAA($1E<&]I<R(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z
M:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+B(*;7-G<W1R(")#\V1I9V\@9&4@86/GXV\@:6YT<F]D=7II9&\@97-TX2!I
M;F-O<G)E8W1O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S(*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O
M<F0N(@IM<V=S='(@(DYO;64@9&4@=71I;&EZ861O<B!O=2!P86QA=G)A+7!A
M<W-E(&5R<F%D;W,N(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-3$*;7-G:60@(B(*(DEN8V]R<F5C="!U<V5R;F%M92!O<B!A;'1E<FYA=&4@
M861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B`B"B)A9&UI;FES
M=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M3F]M92!D92!U=&EL:7IA9&]R(&]U(&5N9&5R9>=O(&%L=&5R;F%T:79O(&5R
M<F%D;W,N($-O;G1A8W1E(&\@<V5U("(*(F%D;6EN:7-T<F%D;W(@9&4@<VES
M=&5M82!P87)A(&]B=&5R(&%J=61A+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N
M="(*;7-G<W1R(")!=6UE;G1A<B!A($EN9&5N=&'GXV\B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(DEN
M9&EA(@IM<V=S='(@(E)E</IB;&EC82!D82#-;F1I82(*"B,Z(&%D;6EN+W!E
M<FUS+V5D:70N<&AP.C$T,2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S
M-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")5=&EL:7IA9&]R
M97,@26YD:79I9'5A:7,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$R
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G<W1R(")2
M97#Z8FQI8V$@9&$@26YD;V[I<VEA(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z-C<*;7-G:60@(DEN9F\B"FUS9W-T<B`B26YF;W)M
M8>?C;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#8*;7-G:60@
M(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6'GXV\B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$X"FUS9VED("));F9O<FUA=&EO;B!N
M;R!L;VYG97(@879A:6QA8FQE+B(*;7-G<W1R("));F9O<FUAY^-O(&KA(&[C
M;R!E<W3A(&1I<W!O;NUV96PB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-3@R
M"B,L('!H<"UF;W)M870*;7-G:60@(DEN:71I86QI>FEN9R!M;V1U;&4@)7,N
M+BX@(@IM<V=S='(@(DEN:6-I86QI>F%N9&\@;R!M\V1U;&\@)7,N+BX@(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,T"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E<B(*;7-G<W1R("))
M;G-E<FER($-?;VQU;F$@1&5P;VES(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E
M<G0@26UA9V4B"FUS9W-T<B`B26YS97)I<B!);6%G96TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E
M<G0@5&%B;&4B"FUS9W-T<B`B26YS97)I<B!486)E;&$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED("));G-E
M<G0@5V5B($QI;FLB"FUS9W-T<B`B26YS97)I<B!,:6=AY^-O(.`@5V5B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C,S"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS9W-T<B`B
M26YS97)I<B!?0V]L=6YA($%N=&5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@
M82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("))
M;G-I<FER('5M82!N;W9A(&-O;'5N82!D97!O:7,@9&$@8V]R<F5N=&4B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C0*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("));G-I<FER('5M82!N;W9A(&-O;'5N82!A
M;G1E<R!D82!C;W)R96YT92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@;F5W
M(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B26YS:7)I<B!U
M;6$@;F]V82!L:6YH82!D97!O:7,@9&$@8V]R<F5N=&4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("));G-I<FER('5M82!N;W9A(&QI;FAA(&%N=&5S(&1A(&-O<G)E
M;G1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@
M=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("));G-E<FER('5M('!A<N%G<F%F
M;R!A</-S(&\@;O,@8V]R<F5N=&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R("))
M;G-E<FER('5M('!A<N%G<F%F;R!A;G1E<R!D;R!N\R!C;W)R96YT92(*"B,Z
M(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED("));G-E<G0@86QT97)N
M871E('1E;7!L871E(@IM<V=S='(@(DEN<VER:7(@;6]D96QO(&%L=&5R;F%T
M:79O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S,0IM<V=I9"`B26YS
M97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E
M('1H92!N97<@<&%S<W=O<F0Z(@IM<V=S='(@(B(*(DEN=')O9'5Z82!U;2!E
M;F1E<F7G;R!D92!C;W)R96EO(&5L96-T<O-N:6-O(&]N9&4@<&]S<V$@<F5C
M96)E<B!A(&YO=F$@(@HB<&%L879R82UP87-S93HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("))
M;G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));G-I<FER(&/I;'5L82!A</-S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(DEN
M<V5R:7(@8^EL=6QA<R!A;G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B26YS97)I<B!CZ6QU;&$@9&5P;VES(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M-0IM<V=I9"`B26YS97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YS97)I
M<B!C;VQU;F$@86YT97,B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("));G-E
M<FER(&UE;G-A9V5N<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A<F%G<F%P
M:"!A9G1E<B(*;7-G<W1R("));G-E<FER('!A<N%G<F%F;R!A;G1E<R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHT,PIM<V=I9"`B26YS97)T('!A<F%G<F%P:"!B969O<F4B"FUS9W-T<B`B
M26YS97)I<B!P87+A9W)A9F\@86YT97,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M<F]W(&%F=&5R(@IM<V=S='(@(DEN<V5R:7(@;&EN:&$@9&5P;VES(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV
M.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B26YS97)I<B!L
M:6YH82!A;G1E<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C(*;7-G
M:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CHB"FUS9W-T<B`B26YT<F]D=7IA(&$@<F5S<&]S=&$@97AI
M9VED82!P87)A(&$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN
M<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B26YS97)I<B]-;V1I9FEC87(@
M26UA9V5M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX.0IM<V=I9"`B26YS97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(DEN
M<V5R:7(O36]D:69I8V%R($QI9V'GXV\B"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED("));G-U9F9I8VEE;G0@8W)E9&ET
M('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")#
M<NED:71O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!P87)A(&$@;&ES=&$@
M9&4@9&ES=')I8G5IY^-O+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70N(@IM<V=S
M='(@(D-RZ61I=&\@:6YS=69I8VEE;G1E+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(DEN=&5I<F\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$S,PIM<V=I9"`B26YT96=E<B!L:7-T
M(@IM<V=S='(@(DQI<W1A(&1E(&EN=&5I<F]S(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L:60@541(+B`H
M57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(E5$2"`H57-E<B!$871A($AE
M861E<BD@:6YVX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP
M:'`Z,3<P(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(P,0HC.B!L:6(O
M2&]R9&4O0V]M<')E<W,O>FEP+G!H<#HR,3`*;7-G:60@(DEN=F%L:60@6DE0
M(&1A=&$B"FUS9W-T<B`B1&%D;W,@6DE0(&EN=N%L:61O<R(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z,S0*;7-G:60@(DEN=F%L:60@87!P;&EC871I
M;VXN(@IM<V=S='(@(D%P;&EC8>?C;R!I;G;A;&ED82XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,@IM<V=I9"`B26YV86QI9"!B
M871C:"!)1"XB"FUS9W-T<B`B240@9&4@;&]T92`H7")B871C:%PB*2!I;G;A
M;&ED;RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`X."!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C$U.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(S,PHC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C(Y.`IM<V=I9"`B26YV86QI9"!D871A('-U8FUI
M='1E9"XB"FUS9W-T<B`B3W,@9&%D;W,@<W5B;65T:61O<R!SXV\@:6YVX6QI
M9&]S+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`P
M"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM<V=S='(@
M(D5N9&5R9>=O(&1E(&1E<W1I;F\@:6YVX6QI9&\N(@H*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+V1B>"YP:'`Z.#$@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]D8G@N<&AP.C(R,`IM<V=I
M9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G<W1R(")&;W)M871O(&1O(&%R
M<75I=F\@:6YVX6QI9&\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38T"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*;7-G<W1R(")#
M:&%V92!D82!L:6-E;N=A(&EN=N%L:61A+B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-3@*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O
M=FED960N(@IM<V=S='(@(DQO8V%L:7IAY^-O(&EN=N%L:61A(&5S<&5C:69I
M8V%D82XB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P
M-PIM<V=I9"`B26YV86QI9"!M<V=?='EP92XB"FUS9W-T<B`B;7-G7W1Y<&4@
M:6YVX6QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S
M='(@(F%P:5]I9"!I;G;A;&ED;R!O=2!E;2!F86QT82XB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-@IM<V=I9"`B26YV86QI9"!O
M<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(E!A<N)M971R;W,@:6YV
MX6QI9&]S(&]U(&5M(&9A;'1A+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HT,PIM<V=I9"`B26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS
M9W-T<B`B4&5R;6ES<^-O('!A<F5N=&%L(&EN=N%L:61A+B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C`*;7-G:60@(DEN=F%L:60@<&%R
M=&YE<B!I9"XB"FUS9W-T<B`B240@9&4@<&%R8V5I<F\@:6YVX6QI9&\N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$V,@IM<V=I9"`B26YV
M86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(D/S9&EG;R!D92!P<F]D=71O
M(&EN=N%L:61O+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`V"FUS9VED("));G9A;&ED('!R;W1O8V]L+B(*;7-G<W1R(")0<F]T
M;V-O;&\@:6YVX6QI9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.CDS"B,L('!H<"UF;W)M870*;7-G:60@(DEN=F%L:60@<F5C:7!I
M96YT.B!<(B5S7"(B"FUS9W-T<B`B1&5S=&EN873A<FEO(&EN=N%L:61O.B!<
M(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$P-#,@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,C(P"FUS9VED("));G9A;&ED('-H87)E(&]B:F5C="(*
M;7-G<W1R(")/8FIE8W1O(&1E('!A<G1I;&AA(&EN=N%L:61O(@H*(SH@;&EB
M+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L
M:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(D5N9&5R9>=O(&1A(&]R:6=E
M;2!I;G;A;&ED;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,Q,0IM<V=I9"`B26YV86QI9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@
M(D1A9&]S('5N:6-O9&4@:6YVX6QI9&]S+B(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HS,C4*;7-G:60@(DEN=F5N=&]R>2(*;7-G<W1R("));G9E
M;G3A<FEO(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q.2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C@R"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(E)E</IB;&EC82!)<VSB;6EC82!D;R!)<N-O(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M<F%Q(@IM<V=S='(@(E)E</IB;&EC82!D;R!)<F%Q=64B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3$S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER
M96QA;F0B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($ER;&%N9&$B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G
M<W1R("));&AA(&1E($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G
M<W1R(")496UP;W)A:7,M5"!)<V]L861O<R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B27-R865L(@IM
M<V=S='(@(D5S=&%D;R!D92!)<W)A96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(D5M:7-S;W(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R("))=.%L:6-O(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$R,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3$U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@R"FUS9VED("))=&%L
M>2(*;7-G<W1R(")297#Z8FQI8V$@271A;&EA;F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I
M8V$B"FUS9W-T<B`B2F%M86EC82(*"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HS-S0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0Q,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(DIA;F5I<F\B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(U(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIA<&%N(@IM<V=S='(@(DIA<.-O(@H*(SH@8V]N9FEG+VYL<RYP
M:'`N9&ES=#HQ.#<*;7-G:60@(DIA<&%N97-E("A)4T\M,C`R,BU*4"DB"FUS
M9W-T<B`B2F%P;V[J<R`H25-/+3(P,C(M2E`I(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R,@IM<V=I9"`B2F5R<V5Y(@IM<V=S='(@(DIE<G-E>2(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C0@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B2F]R9&%N(@IM<V=S='(@(E)E:6YO($AA<VAE;6ET82!D82!*
M;W)DXFYI82(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-PHC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS
M9VED(")*=6QY(@IM<V=S='(@(DIU;&AO(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S`*;7-G:60@(DIU;F4B"FUS9W-T<B`B2G5N:&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W1I9FEC87(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N=')A<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHS.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T<B`B2G5S=&EF:6-A<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHS-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$T"FUS9VED(")*=7-T:69Y($QE9G0B"FUS9W-T<B`B2G5S=&EF:6-A
M<B#@($5S<75E<F1A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I9GD@4FEG:'0B"FUS
M9W-T<B`B2G5S=&EF:6-A<B#@($1I<F5I=&$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMA>F%K:'-T
M86XB"FUS9W-T<B`B4F5P^F)L:6-A(&1O($-A>F%Q=6ES=.-O(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T-@IM<V=I9"`B2V5E
M<"!O<FEG:6YA;#\B"FUS9W-T<B`B4')E<V5R=F%R(&\@;W)I9VEN86P_(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S
M"FUS9VED(")+96YY82(*;7-G<W1R(")297#Z8FQI8V$@9&\@477I;FEA(@H*
M(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3R!S
M97)V:61O<B!+97)B97)O<R!R96IE:71O=2!A(&%U=&5N=&EC8>?C;RXB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B
M:65S(@IM<V=S='(@(DYO=F%T;W,@;F\@7")+97)N96Q<(B(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0P,`IM<V=I9"`B2V5Y($-R96%T:6]N(@IM
M<V=S='(@(D-R:6'GXV\@9&$@0VAA=F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,#,*;7-G:60@(DME>2!&:6YG97)P<FEN="(*;7-G<W1R("))
M;7!R97-SXV\@9&EG:71A;"!D82!C:&%V92(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.C0P,0IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R(")#;VUP
M<FEM96YT;R!D82!C:&%V92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0P,`IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B5&EP;R!D82!#:&%V92(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"FUS9VED(")+97D@
M57-A9V4B"FUS9W-T<B`B571I;&EZ8>?C;R!D82!#:&%V92(*"B,Z(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<R.0IM<V=I9"`B2V5Y(&%L<F5A9'D@97AI
M<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!(&-H879E
M(&KA(&5X:7-T92!N;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S(@IM<V=S
M='(@(DUI^F1O<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,CD@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B2VER:6)A=&DB"FUS9W-T<B`B475I<FEB
M871I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3(R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@U"FUS9VED(")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9B(*;7-G<W1R(")297#Z8FQI8V$@4&]P=6QA<B!$96UO8W+A=&EC
M82!D82!#;W)E:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,S(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C,*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#4*;7-G:60@(DMO<F5A+"!297!U8FQI8R!O9B(*;7-G
M<W1R(")297#Z8FQI8V$@9&$@0V]R96EA(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#@*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R(")#;W)E
M86YO("A%54,M2U(I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S-"!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C@V"FUS9VED(")+=7=A:70B"FUS9W-T<B`B2W5W86ET
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@S"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S='(@(E)E</IB;&EC82!1=6ER
M9W5I>F4B"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@
M(DQA7WEO=70B"FUS9W-T<B`B7T1I<W!O<VGGXV\B"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C<Y('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G
M:60@(DQA;F=U86=E(@IM<V=S='(@(DED:6]M82(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I9"`B3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B"FUS9W-T<B`B4F5P^F)L:6-A
M(%!O<'5L87(@1&5M;V-RX71I8V$@3&%O(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C$W-`IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E%U87)T;R!$96-R
M97-C96YT92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX."!L:6(O0FQO8VLO
M;6]O;BYP:'`Z.3`*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")1=6%R
M=&\@1&5C<F5S8V5N=&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$U,0IM
M<V=I9"`B3&%S="!5<&1A=&5D.B(*;7-G<W1R("+:;'1I;6$@06-T=6%L:7IA
MY^-O.B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,B"FUS9W-T<B`BVFQT:6UA(&5N=')A
M9&$Z("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8X.`HC+"!P:'`M9F]R
M;6%T"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(MIL
M=&EM82!E;G1R861A.B`E<R!D92`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H
M<#HV.#,*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(MIL=&EM
M82!E;G1R861A.B!.=6YC82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&%T=FEA(@IM<V=S='(@(E)E
M</IB;&EC82!D82!,973S;FEA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0T"FUS9VED("),87<B"FUS9W-T<B`B3&5I(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO
M=70B"FUS9W-T<B`B1&ES<&]S:>?C;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(B"FUS9W-T<B`B1&5I>&%R('9A>FEO('!A<F$@9FEC87(@
M<V5M(&)O<F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DSM8F%N;R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.0IM<V=I9"`B3&5F="(*;7-G<W1R(")%<W%U97)D82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3$X"FUS9VED("),969T(&AE861E<B(*;7-G<W1R
M(")#86)EYV%L:&\@9&$@97-Q=65R9&$B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S$Q-`IM<V=I9"`B3&5F="!V86QU97,B"FUS9W-T<B`B5F%L;W)E<R#@
M(&5S<75E<F1A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Y"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@X"FUS9VED("),97-O=&AO(@IM<V=S='(@(DQE<V]T;R(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$S,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M.`IM<V=I9"`B3&EB97)I82(*;7-G<W1R("),:6+I<FEA(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S='(@(D=R86YD92!*86UA:&ER
M:7EA(%-O8VEA;&ES=&$@4&]P=6QA<B#!<F%B92!D82!,[6)I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I
M9"`B3&EE8VAT96YS=&5I;B(*;7-G<W1R("),:7-T96YS=&%I;F4B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-0IM<V=I9"`B
M3&EG:'0@1')I>GIL92(*;7-G<W1R(")#:'5V82!<(DUO;&AA+51O;&]S7"(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-@IM
M<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R(")#:'5V:7-C;W,B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-PIM<V=I9"`B3&EG
M:'0@4F%I;B!%87)L>2(*;7-G<W1R(")#:'5V:7-C;W,@36%T:6YA:7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I
M9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@(D-H=79I<V-O<R!697-P97)T
M:6YO<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(Y"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G<W1R(")097%U96YO
M($%G=6%C96ER;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G
M<W1R(")#:'5V:7-C;R!C;VT@5')O=F]A9&$B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I9"`B3&EG:'0@4VYO=R(*
M;7-G<W1R(")1=65D82!D92!.979E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R
M(@IM<V=S='(@(DYE=F4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#4*
M;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(EPB3&EM97)I8VM<(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ.#$U"FUS9VED("),:6YK(@IM<V=S='(@(DQI
M9V'GXV\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-38*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R
M("),:6=AY^-O(&%P;VYT82!P87)A.B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#<V"FUS9VED("),:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C
M;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG(@IM<V=S='(@(B(*(DQI9V%R
M(&\@96YD97)EYV\@9&4@8V]R<F5I;R!E;&5C='+S;FEC;R#@('#A9VEN82!D
M92!C;VUP;W-IY^-O(&%O(&UO<W1R87(B"@HC.B!L:6(O2&]R9&4O5&5X="]&
M:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*;7-G:60@(DQI;FMS(@IM<V=S='(@
M(DQI9V'G]65S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0V"FUS9VED
M("),:6YU>"!#;V]K:64B"FUS9W-T<B`B0F]L:6YH;R!L:6YU>.IS(@H*(SH@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&$@+2!O
M('5T:6QI>F%D;W(@<&]D92!V97(@82!P87-T82(*"B,Z(&%D;6EN+W-Q;'-H
M96QL+G!H<#HQ,S`*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(DQI
M<W1A<B!"87-E<R!D92!$861O<R(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N
M<&AP.C4P"FUS9VED("),:7-T($AE;'`@5&]P:6-S(@IM<V=S='(@(DUO<W1R
M87(@5/-P:6-O<R!D92!!:G5D82(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,CD*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQI<W1A<B!486)E;&%S
M(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DT"FUS9VED("),
M:7-T+4%R8VAI=F4B"FUS9W-T<B`B3&ES=&%G96TM07)Q=6EV;R(*"B,Z(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP
M(@IM<V=S='(@(DQI<W1A9V5M+4%J=61A(@H*(SH@;&EB+TAO<F1E+TU)344O
M2&5A9&5R<RYP:'`Z-3DV"FUS9VED("),:7-T+4ED(@IM<V=S='(@(DE$(&1A
M($QI<W1A(@H*(SH@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS
M9VED("),:7-T+4]W;F5R(@IM<V=S='(@(DQI<W1A9V5M+41O;F\B"@HC.B!L
M:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.3,*;7-G:60@(DQI<W0M4&]S
M="(*;7-G<W1R("),:7-T86=E;2U3=6)M:7-S]65S(@H*(SH@;&EB+TAO<F1E
M+TU)344O2&5A9&5R<RYP:'`Z-3DQ"FUS9VED("),:7-T+5-U8G-C<FEB92(*
M;7-G<W1R("),:7-T86=E;2U3=6)S8W)I=&%S(@H*(SH@;&EB+TAO<F1E+TU)
M344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),:7-T+55N<W5B<V-R:6)E(@IM
M<V=S='(@(DQI<W1A9V5M+4[C;R!S=6)S8W)I=&%S(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHT"FUS9VED("),:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+B(*;7-G<W1R(")!(&QI<W1A9V5M(&1E('5T:6QI>F%D
M;W)E<R!E<W3A(&1E<V%C=&EV861A+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-PIM<V=I9"`B3&ET97)A='5R92(*;7-G<W1R("),:71E<F%T=7)A
M.B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.0IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S='(@(E)E</IB;&EC82!D82!,
M:71UXFYI82(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S,X"FUS9VED("),
M;V%D:6YG(&QI8G)A<FEE<RXN+B(*;7-G<W1R(")#87)R96=A;F1O(&)I8FQI
M;W1E8V%S+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E<RYP
M:'`Z.3(*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B0V%R<F5G86YD;RXN
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3D*;7-G:60@
M(DQO8V%L('1I;64Z("(*;7-G<W1R(")496UP;R!L;V-A;#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@5&EM92(*
M;7-G<W1R("),;V-A;&EZ8>?C;R!E($9U<V\@2&]RX7)I;R(*"B,Z(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-3<Q(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU-@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HV-0IM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`B3&]C
M86QI>F'GXV\B"@HC.B!L;V=I;BYP:'`Z,38R('-E<G9I8V5S+W!O<G1A;"]S
M:61E8F%R+G!H<#HQ-C0@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,PHC
M.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ-2!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C@V"FUS9VED("),;V<@:6XB"FUS9W-T<B`B16YT<F%R
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U.`IM<V=I9"`B
M3&]G(&]U="(*;7-G<W1R(")386ER(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`B5&%R969A<R!D
M92!%;G1R861A(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDS,0IM<V=I9"`B
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B(@HB02!A=71E
M;G1I8V'GXV\@9F%L:&]U('!O<B!O($YO;64@9&4@571I;&EZ861O<B!O=2!A
M(%!A;&%V<F$M4&%S<V4@97-T87)E;2`B"B)I;F-O<G)E8W1O<RXB"@HC.B!L
M:6(O2&]R9&4O075T:"YP:'`Z.3(W"FUS9VED("),;V=I;B!F86EL960N(@IM
M<V=S='(@(D$@875T96YT:6-AY^-O(&9A;&AO=2XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,V-PIM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(E1E>'1O
M(&QO;F=O(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0X"FUS9VED("),
M;W9E(@IM<V=S='(@(D%M;W(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(D)A:7AO(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N
M9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R("),
M971R87,@9W)E9V%S(&UI;OIS8W5L87,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),;W=E
M<B!L871I;B!L971T97)S(@IM<V=S='(@(DQE=')A<R!L871I;F%S(&UI;OIS
M8W5L87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB97)S(@IM
M<V=S='(@(D[Z;65R;W,@<F]M86YO<R!M:6[Z<V-U;&]S(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$T-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),
M=7AE;6)O=7)G(@IM<V=S='(@(DQU>&5M8G5R9V\B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<S(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,3`*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI
M;F,Z-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S
M+V1A=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*
M;7-G:60@(DU-(@IM<V=S='(@(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C(U,PIM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,V"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(D\@86YE
M>&\@35,M5$Y%1B!NXV\@8V]N=&EN:&$@9&%D;W,N(@H*(SH@;&EB+TAO<F1E
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"FUS9VED(")-
M4T<B"FUS9W-T<B`B35-'(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86-A;R(*;7-G<W1R(")-86-A
M=2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(DUA8V5D\VYI82P@06YT:6=A(%)E</IB;&EC
M82!*=6=O<VQA=F$@9&$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,S<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DUA9&%G87-C87(B"FUS9W-T<B`B
M36%D86?A<V-A<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.0IM<V=I
M9"`B36%G:6,B"FUS9W-T<B`B36%G:6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z.#$*;7-G:60@(DUA:6PB"FUS9W-T<B`B0V]R<F5I;R(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S<*;7-G:60@(DUA:6P@061M
M:6XB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!#;W)R96EO(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0P
M"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D9A>F5R(&QI7V=AY^-O
M+BXN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S-3<*;7-G:60@(DUA:V4@
M<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS=&%L;&5D(&%N9"!I;B!Y;W5R
M(&EN8VQU9&4@<&%T:"XB"FUS9W-T<B`B(@HB07-S96=U<F4M<V4@9&4@<75E
M('1E;2!O(%!%05(@:6YS=&%L861O(&4@;F\@8V%M:6YH;R!D92!I;F-L=7/U
M97,@*&EN8VQU9&4@(@HB<&%T:"DN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C8W."!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")-86MI;F<@9&ER96-T;W)Y("5S(@IM<V=S='(@(D-R:6%N9&\@82!P
M87-T82`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@(DUA;&%U:2(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM
M<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%LX7-I82(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L
M9&EV97,B"FUS9W-T<B`B36%L9&EV87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA;&DB"FUS9W-T
M<B`B36%L:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G92!T:&4@
M;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I
M=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N(@IM<V=S='(@(B(*(D=I<F$@82!L:7-T82!D92!C871E9V]R:6%S
M('%U92!P;V1E(&%T<FEB=6ER(&%O<R!I=&5N<RP@8F5M(&-O;6\@87,@8V]R
M97,@(@HB<75E(&QH97,@97-TXV\@87-S;V-I861A<RXB"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0IM<V=I9"`B36%P,C0@
M;6%P(@IM<V=S='(@(DUA<&$@36%P,C0B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3<W"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#4T"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B36%P82!-87!1=65S="(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HS-S8@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8W"FUS9VED(")-87)C:"(*;7-G<W1R(")-87+G;R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G
M:60@(DUA<F=I;B(*;7-G<W1R(")-87)G96TB"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<R(*;7-G<W1R(")-87)C87(@8V]M;R!,:61A+T[C;R!L:61A
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED
M(")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E
M<F5D*2(*;7-G<W1R(")-87)C87(@9&4@;W5T<F%S(&9O<FUA<R`H92YG+BP@
M26UP;W)T86YT92]0;W(@<F5S<&]N9&5R*2(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@
M27-L86YD<R(*;7-G<W1R("));&AA<R!-87)S:&%L;"(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%R
M=&EN:7%U92(*;7-G<W1R(")-87)T:6YI8V$B"@HC.B!T96UP;&%T97,O9&%T
M82]C<W9M87`N:6YC.C$Q,0IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S
M='(@(D-A;7!O<R!Q=64@8V]R<F5S<&]N9&5M(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A
M;FEA(@IM<V=S='(@(DUA=7)I=.)N:6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*
M;7-G<W1R(")-875R[6-I;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S$U"FUS9VED(")-87@@86QL;W=E9"!C<F5D:70N(@IM<V=S
M='(@(DWA>&EM;R!C<NED:71O('!E<FUI=&ED;RXB"@HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N(@IM<V=S='(@(DWA>&EM;R!N^FUE<F\@9&4@<&%R
M=&5S(&YU;6$@;65N<V%G96T@97AC961I9&\N(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP(&QA<W0@,C0@:&]U<G,Z("(*
M;7-G<W1R(")496UP97)A='5R82!MX7AI;6$@;F%S(/IL=&EM87,@,C0@:&]R
M87,Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")496UP97)A='5R82!MX7AI
M;6$@;F%S(/IL=&EM87,@-B!H;W)A<SH@(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C@Y."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(Q-R!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3(S.0IM<V=I9"`B36%X:6UU;2!L96YG=&@B"FUS9W-T<B`B0V]M
M<')I;65N=&\@;>%X:6UO(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,W."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$U"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R(")-86EO(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(U,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B36%Y
M;W1T92(*;7-G<W1R(")-87EO='1E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C4P"FUS9VED(")-961I8VEN92(*;7-G<W1R(")-961I8VEN82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3D*;7-G:60@(DUE
M;6)E<G,B"FUS9W-T<B`B365M8G)O<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-S`*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B36]D;R!D;R!M
M96YU.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E;&QS(@IM<V=S='(@(E5N:7(@
M8^EL=6QA<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU,C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O
M;7!E;F1I=6TN+BX@(@IM<V=S='(@(DEN=&5G<F%N9&\@=&]D;W,@;W,@9FEC
M:&5I<F]S("5S+G!O(&-O;2!O(&-O;7#J;F1I;RXN+B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HT,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B365R9VEN9R!L
M;V-A;&4@)7,N+BX@(@IM<V=S='(@(DEN=&5G<F%N9&\@82!L;V-A;&EZ8>?C
M;R`E<RXN+B`B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S@X"B,L('!H<"UF
M;W)M870*;7-G:60@(DUE<F=I;F<@=&AE(%!/(&9I;&4@9F]R("5S('1O('1H
M92!C;VUP96YD:75M+BXN("(*;7-G<W1R("));G1E9W)A;F1O(&\@87)Q=6EV
M;R!03R!D92`E<R!C;VT@;R!C;VUPZFYD:6\N+BX@(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C0R-0HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1R
M86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B26YT96=R86YD
M;R!A('1R861UY^-O(&1O(&WS9'5L;R`E<RXN+B(*"B,Z(&QI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`IM<V=I9"`B365S
M<V%G92(*;7-G<W1R(")-96YS86=E;2(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z,C$V"FUS9VED("(B"B)-97-S86=E(%9E<FEF:65D(%-U8V-E
M<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO
M="!B92`B"B)V97)I9FEE9"XB"FUS9W-T<B`B(@HB365N<V%G96X@5F5R:69I
M8V%D82!C;VT@4W5C97-S;RP@;6%S(&\@8V5R=&EF:6-A9&\@9&\@<W5B<V-R
M:71O<B!NXV\@</1D92`B"B)S97(@=F5R:69I8V%D;RXB"@HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B365S<V%G92!E
M>'!I<F5D+B(*;7-G<W1R(")-96YS86=E;2!E>'!I<F]U+B(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8P,@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C(R-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(E1I<&\@9&4@;65N
M<V%G96TB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R
M(%=E871H97(B"FUS9W-T<B`B365T96]R;VQO9VEA($U%5$%2(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HS-PIM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`B0FQO8V\@345405(@:6YD:7-P;V[M=F5L+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"FUS9VED("(B"B)-971A<B!B
M;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)";&]C;R!-151!
M4B!I;F1I<W!O;NUV96PN($]S('!O<FUE;F]R97,@9F]R86T@<F5G:7-T861O
M<R!P87)A(&\@(@HB861M:6YI<W1R861O<BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,34R"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN
M96-T960N(@IM<V=S='(@(D$@365T87)$0B!NXV\@97-TX2!C;VYE8W1A9&$N
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@(DUE=&AO9"(*;7-G
M<W1R(")-Z71O9&\B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z.#$@
M;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B365T:&]D(%PB)7-<(B!I<R!N;W0@9&5F:6YE9"(*;7-G<W1R(")/(&WI
M=&]D;R!<(B5S7"(@;N-O(&5S=.$@9&5F:6YI9&\B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C8@;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM
M<V=I9"`B365T<FEC(@IM<V=S='(@(DWI=')I8V\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,38V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC
M;R(*;7-G<W1R(")-Z7AI8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6-R;V[I<VEA+"!%<W1A9&]S($9E
M9&5R861O<R!D82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D-E;G1R
M;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`IM<V=I
M9"`B36EM92!4>7!E(@IM<V=S='(@(E1I<&\@34E-12(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T(&AO=7)S
M.B`B"FUS9W-T<B`B5&5M<&5R871U<F$@;>UN:6UA(&YA<R#Z;'1I;6%S(#(T
M(&AO<F%S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#(*;7-G:60@(DUI
M;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM<V=S='(@(E1E;7!E<F%T=7)A(&WM
M;FEM82!N87,@^FQT:6UA<R`V(&AO<F%S(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-PIM<V=I9"`B36ER<F]R(@IM<V=S='(@
M(D5S<&5L:&\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B36ES8V5LXFYE82(*"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S(@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K
M86=E($A45%!?4F5Q=65S="XB"FUS9W-T<B`B4&%C;W1E($A45%!?4F5Q=65S
M="!D;R!014%2(&5M(&9A;'1A+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,30*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"B)#;VYF:6=U<F'GXV\@96T@
M9F%L=&$N(%1E<N$@9&4@82!G97)A<B!A9V]R82!S92!Q=6ES97(@=7-A<B!E
M<W1A(&%P;&EC8>?C;RXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E($E$+B(*;7-G<W1R
M("))1"!D82!M96YS86=E;2!E;2!F86QT82XB"@HC.B!L:6(O3F5T+U--4R]V
M;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED(")-:7-S:6YG(')E<75I
M<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R(")086-O=&4@36%I;"!D
M;R!014%2(&5M(&9A;'1A+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,CDT"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S
M='(@(DE$(&1A('-E<W/C;R!E;2!F86QT82XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R
M("(RJB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW-`IM<V=I9"`B
M36]B:6QE($UA:6PB"FUS9W-T<B`B0V]R<F5I;R!-\W9E;"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R(")-;V1E<F%D;R(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R87(N<&AP.C8V(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C<S"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@U"FUS9VED
M(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D1A=&$@9&4@36]D:69I8V'GXV\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3(*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`B36]D:69I8V%R
M(%523"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(DUO9'5L
M92(*;7-G<W1R(")-\V1U;&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C8W,PIM<V=I9"`B36]D=6QU<R(*;7-G<W1R(")-\V1U;&\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G
M:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(E)E</IB;&EC82!D
M82!-;VQD;W9A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Q"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B4')I;F-I<&%D
M;R!D;R!-\VYA8V\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3(*;7-G:60@(DUO;F=O;&EA(@IM<V=S='(@(DUO;F?S
M;&EA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(U.3,*;7-G:60@(DUO;G1H
M(&%N9"!Y96%R(@IM<V=S='(@(DWJ<R!E(&%N;R(*"B,Z(&QI8B](;W)D92]-
M86EN=&5N86YC92YP:'`Z-3<*;7-G:60@(DUO;G1H;'DB"FUS9W-T<B`B365N
M<V%L;65N=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B36]N='-E
M<G)A="(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-@IM<V=I9"`B36]O;B!0:&%S97,B"FUS9W-T<B`B1F%S92!D82!,
M=6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B4F5I;F\@9&4@36%R<F]C
M;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M,PIM<V=I9"`B36]S=&QY($-L96%R(@IM<V=S='(@(E-O8G)E='5D;R!,:6UP
M;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,T
M"FUS9VED(")-;W-T;'D@0VQO=61Y(@IM<V=S='(@(E-O8G)E='5D;R!%;F5V
M;V%D;R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C,U"FUS9VED(")-;W-T;'D@4W5N;GDB"FUS9W-T<B`B4V]B<F5T=61O(%-O
M;&%R96YG;R(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R.`IM
M<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(D1E<V-E<B(*"B,Z(&QI8B](;W)D
M92]";&]C:R],87EO=70N<&AP.C0S,@IM<V=I9"`B36]V92!,969T(@IM<V=S
M='(@(DUO=F5R('!A<F$@82!%<W%U97)D82(*"B,Z(&QI8B](;W)D92]";&]C
M:R],87EO=70N<&AP.C0S-@IM<V=I9"`B36]V92!2:6=H="(*;7-G<W1R(")-
M;W9E<B!P87)A(&$@1&ER96ET82(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO
M=70N<&AP.C0R-`IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")3=6)I<B(*"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT.38*;7-G:60@
M(DUO=F4@9&]W;B(*;7-G<W1R(")$97-C97(B"@HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#DU(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT.38*;7-G:60@(DUO=F4@=7`B"FUS9W-T<B`B4W5B
M:7(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.34*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B4F5P^F)L:6-A(&1E
M($UOYV%M8FEQ=64B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X-0IM<V=I
M9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(DQI<W1A
M<R!D92!D97-E;G)O;&%R(&UU;'1I+6[M=F5L(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(R-#,*;7-G:60@(DUU;'1I<&QE('-E;&5C=&EO;B(*;7-G<W1R
M(")396QE8^?C;R!M^FQT:7!L82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,S$@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S.`IM<V=I9"`B
M37D@06-C;W5N="(*;7-G<W1R(")!($UI;FAA($-O;G1A(@H*(SH@<V5R=FEC
M97,O<&]R=&%L+VEN9&5X+G!H<#HU,0IM<V=I9"`B37D@4&]R=&%L(@IM<V=S
M='(@(D\@365U(%!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H
M<#HQ,C0*;7-G:60@(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B1&ES<&]S
M:>?C;R!D;R!0;W)T86PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34U
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-38*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B56YI
MXV\@9&4@37EA;FUA<B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?8F]T=&]M+FEN8SHW"FUS9VED(").3RP@22!$;R!.3U0@06=R964B
M"FUS9W-T<B`B3N-O+"!NXV\@8V]N8V]R9&\B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,#`@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ,#(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(DYO;64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3<*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1A($YA;>UB:6$B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3<X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYA=7)U(@IM
M<V=S='(@(DYA=7)U(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-PIM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B4F5I;F\@9&]S(%!A[7-E
M<R!"86EX;W,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`B06YT:6QH87,@2&]L86YD97-A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@Q"FUS9VED(").971S8V%P92!"87-E(%523"(*;7-G<W1R
M(")54DP@9&4@0F%S92!.971S8V%P92(*"B,Z(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-3@S"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N(%52
M3"(*;7-G<W1R(")54DP@9&4@4F5V;V=AY^-O($-!($YE='-C87!E(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#4*;7-G:60@(DYE='-C87!E
M($-!('!O;&EC>2!54DPB"FUS9W-T<B`B55),(&-O;2!A('!O;.UT:6-A(&1E
M($-!($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU
M.#0*;7-G:60@(DYE='-C87!E(%)E;F5W86P@55),(@IM<V=S='(@(E523"!D
M92!296YO=F'GXV\@3F5T<V-A<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS
M9W-T<B`B55),(&1E(%)E=F]G8>?C;R!.971S8V%P92(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!34TP@<V5R
M=F5R(&YA;64B"FUS9W-T<B`B3F]M92!D;R!S97)V:61O<B!34TP@3F5T<V-A
M<&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R(")#;VUE;G3A
M<FEO(&1E(&-E<G1I9FEC861O($YE='-C87!E(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU.#`*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4B"FUS9W-T<B`B5&EP;R!D92!C97)T:69I8V%D;R!.971S8V%P92(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,SD*;7-G:60@(DYE='=O
M<FLB"FUS9W-T<B`B4F5D92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C0Q-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S(W"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HS-S@*;7-G:60@(DYE=F5R(@IM<V=S='(@(DYU;F-A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU
M"FUS9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(DYO=F$@0V%L963S;FEA
M(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-3`*
M(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,C<*
M;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(").;W9A($-A=&5G;W)I82(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HT-B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M-C@@;&EB+T)L;V-K+VUO;VXN<&AP.C$W.0IM<V=I9"`B3F5W($UO;VXB"FUS
M9W-T<B`B3'5A($YO=F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A
M=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P=&EO;F%L*2(*;7-G
M<W1R(").;W9O($YO;64@9&4@571I;&EZ861O<B`H;W!C:6]N86PI(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS
M9VED(").97<@6F5A;&%N9"(*;7-G<W1R(").;W9A(%IE;.)N9&EA(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I
M9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R(").;W9A(&IA;F5L82`H
M7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C8Q"FUS9VED(").97=S(@IM<V=S='(@(DYO=.UC:6%S(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(Y-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G
M<W1R(")'<G5P;W,@9&4@3F]T[6-I87,B"@HC.B!T96UP;&%T97,O9&%T82]T
M<W9I;F9O+FEN8SHR,2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT-@HC
M.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-R!T96UP;&%T97,O9&%T
M82]C<W9I;F9O+FEN8SHS,@IM<V=I9"`B3F5X="(*;7-G<W1R(")0<O-X:6UA
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"FUS9VED(").97AT(#0@4&AA
M<V5S(@IM<V=S='(@(E!R\WAI;6%S(#0@1F%S97,B"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C,W,"!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,W-`IM
M<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E!R\WAI;6%S(&]PY_5E<R(*
M"B,Z(&QI8B](;W)D92]522]086=E<BYP:'`Z,3`S"FUS9VED(").97AT/B(*
M;7-G<W1R(")0<O-X:6UA/B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEC87)A9W5A(@IM<V=S='(@
M(E)E</IB;&EC82!D82!.:6-A<N%G=6$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C4*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*;7-G:60@(DYI9V5R(@IM<V=S
M='(@(E)E</IB;&EC82!D;R!.[6=E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V-@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R(")297#Z8FQI8V$@1F5D97)A;"!D82!.:6=E<FEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,V.`IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`B3F]I=&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3<*;7-G:60@(DYI=64B"FUS9W-T<B`B3FEU92(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX.#4*;7-G:60@(DYO
M(@IM<V=S='(@(D[C;R(*"B,Z('1E;7!L871E<R]A9&UI;B]S971U<"]D:69F
M+FAT;6PZ,38*;7-G:60@(DYO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A
M=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM<V=S='(@(B(*(D[C;R!H
MX2!D861O<R!D92!C;VYF:6=U<F'GXV\@9&ES<&]N[79E:7,@96T@<F5L8>?C
M;R!A;W,@<75A:7,@;6]S=')A<B`B"B)D:69E<F5NYV%S+B(*"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+G!H<#HQ,#4*;7-G:60@(DYO(&%V86EL86)L92!S=')A
M=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(@IM<V=S='(@(D[C;R!HX2!N
M96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N[79E;"!P87)A(')E86QI>F%R(&EM
M86=E;G,@25-/+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$S"FUS9VED(").;R!B871C:"!T96UP;&%T92XB"FUS9W-T<B`B3N-O
M(&CA(&UO9&5L;R!D92!L;W1E(%PB8F%T8VA<(BXB"@HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+G!H<#HW.2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H
M<#HR,S`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C4R"FUS9VED
M(").;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;B(*
M;7-G<W1R(").XV\@97AI<W1E(&)L;V-O(&YA('!O<VGGXV\@:6YD:6-A9&$B
M"@HC.B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B3F\@8V%L
M96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB
M"FUS9W-T<B`B3N-O(&9O:2!F;W)N96-I9&\@=6T@;F]M92!D92!C86QE;F3A
M<FEO('!A<F$@82!A=71E;G1I8V'GXV\@34-!3"XB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")396T@
M;6]D:69I8V'G]65S+B(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z,30P
M"FUS9VED(").;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@
M8F5L;W<@=&AI<R!L979E;"XB"FUS9W-T<B`B3N-O('-E('!O9&4@861I8VEO
M;F%R('!E<FUI<W/U97,@9&4@9FEL:&]S(&%B86EX;R!D97-T92!N[79E;"XB
M"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$*;7-G:60@(DYO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S
M='(@(D[C;R!S92!P;V1E(&%D:6-I;VYA<B!F:6QH;W,@82!E<W1A('!E<FUI
M<W/C;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,W-PIM<V=I9"`B3F\@
M8V]M;6%N9"!S<&5C:69I960N(@IM<V=S='(@(DYE;FAU;2!C;VUA;F1O(&5S
M<&5C:69I8V%D;RXB"@HC.B!L:6(O2&]R9&4N<&AP.C$V-R!L:6(O2&]R9&4N
M<&AP.C0W-R!L:6(O2&]R9&4O571I;"YP:'`Z-S<V"B,L('!H<"UF;W)M870*
M;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RXB"FUS9W-T<B`B3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I;F9O
M<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!P87)A("5S+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW-#$*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+B(*;7-G<W1R("(B"B).XV\@9F]I
M(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A
M<F$@5D93(&)A<V5A9&\@96T@1E10+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HU
M.3$*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+B(*;7-G<W1R("(B"B).XV\@9F]I(&5S<&5C:69I
M8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@
M<&%R82!O(%9&4R`B"B)B87-E861O(&5M(%-13"XB"@HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HW,#0*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N(@IM<V=S='(@(B(*
M(D[C;R!F;VD@97-P96-I9FEC861A(&$@:6YF;W)M8>?C;R!D92!C;VYF:6=U
M<F'GXV\@;F5C97-SX7)I82!P87)A(&\@5D93("(*(F)A<V5A9&\@96T@4U%,
M+49I;&4N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,30*;7-G:60@(DYO(&-R961I="!L969T+B(*;7-G<W1R(")#<NED:71O(&5S
M9V]T;W4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S
M-`IM<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DYE
M;FAU;2!D97-T:6YA=.%R:6\@9F]I(&9O<FYE8VED;RXB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z,3(W,0HC+"!P:'`M9F]R;6%T"FUS9VED(").;R!E;G1R
M>2!W:71H('1H92!I9"!<(B5S7"(@97AI<W1S(&EN('1H92!O<FEG:6YA;"!H
M96QP(&9I;&4N(@IM<V=S='(@(B(*(D[C;R!E>&ES=&4@<75A;'%U97(@96YT
M<F%D82!C;VT@;R!I9"!<(B5S7"(@;F\@87)Q=6EV;R!D92!A:G5D82!O<FEG
M:6YA;"XB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@Q"FUS9VED(").
M;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(D[C;R!S92!C87)R96=O=2!N861A
M+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,3,@<&\O=')A;G-L871I;VXN
M<&AP.C4R,@IM<V=I9"`B3F\@;&]C86QE('-P96-I9FEE9"XB"FUS9W-T<B`B
M3F5N:'5M82!L;V-A;&EZ8>?C;R!E<W!E8VEF:6-A9&$N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q-2!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C,*;7-G:60@(DYO(&QO
M8V%T:6]N(&ES('-E="XB"FUS9W-T<B`B1F%L=&$@:6YD:6-A<B!U;6$@;&]C
M86QI>F'GXV\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U
M-@IM<V=I9"`B3F\@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(D$@;&]C
M86QI>F'GXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S
M=7!P;&EE9"XB"FUS9W-T<B`B3F5N:'5M82!M96YS86=E;2!F;VD@9F]R;F5C
M:61A+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*
M;7-G:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R(").96YH=6T@;F]M
M92!E<W!E8VEF:6-A9&\N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8S-PIM<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T
M<B`B3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A9&\N(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.CDT"FUS9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B
M"FUS9W-T<B`B4V5M(&1I=&]S(&]F96YS:79O<R(*"B,Z(&QI8B](;W)D92]!
M=71H+VAT='`N<&AP.CDQ"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2%144"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!F;W)N
M96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($A45%`N
M(@H*(SH@;&EB+TAO<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS
M9W-T<B`B3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@
M875T96YT:6-AY^-O($E-05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:W)B-2YP
M:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!F;W)N96-I9&$@
M<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($ME<F)E<F]S+B(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.CDT"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T
M96YT:6-AY^-O($Q$05`N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z
M-S<@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&QI8B](;W)D92]!
M=71H+W!A;2YP:'`Z-S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B3N-O(&9O:2!F;W)N
M96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($QO9VEN
M+B(*"B,Z(&QI8B](;W)D92]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N
M+B(*;7-G<W1R(").XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A<W-E('!A
M<F$@82!A=71E;G1I8V'GXV\@4$%34U=$+B(*"B,Z(&QI8B](;W)D92]!=71H
M+W-M8BYP:'`Z.#0*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!3
M34(@875T:&5N=&EC871I;VXN(@IM<V=S='(@(D[C;R!F;VD@9F]R;F5C:61A
M('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!334(N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@V"FUS9VED("(B"B).;R!P
M871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y3
M4TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W;W)K('=I=&@@4$M#4R`Q
M,B!D871A+B(*;7-G<W1R("(B"B).XV\@9F]I(&EN9&EC861O(&-A;6EN:&\@
M<&%R82!O(&)I;N%R:6\@3W!E;E-33"X@3R!B:6[A<FEO($]P96Y34TP@Z2`B
M"B)N96-E<W/A<FEO('!A<F$@=')A8F%L:&%R(&-O;2!D861O<R!02T-3(#$R
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B3N-O(&CA('-U8G-C
M<FGG]65S('!E;F1E;G1E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*;7-G
M<W1R(")396T@=')AYV]S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-`IM<V=I9"`B3F\@<VED97,B"FUS9W-T
M<B`B4V5M(&QA9&]S(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C$R-0IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@
M9F]R(&-A8VAE+B(*;7-G<W1R(").XV\@:.$@<&%S=&$@=&5M<&]RX7)I82!D
M:7-P;V[M=F5L('!A<F$@7")C86-H95PB+B(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV,S$*;7-G:60@(DYO('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"!S96YT+B(*;7-G<W1R(").XV\@9F]R86T@96YV:6%D;W,@
M;R!N;VUE(&1O('5T:6QI>F%D;W(@;W4@82!P86QA=G)A+7!A<W-E+B(*"B,Z
M(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED
M(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(D[C;R!F;W)A;2!R971O<FYA
M9&]S(&1A9&]S(&5M(%A-3"!VX6QI9&]S(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Y,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3`S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HY,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDS,0IM<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(E-E;2!V86QO<F5S(@H*
M(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q.0IM<V=I9"`B3F\@=F5R<VEO
M;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(D[C;R!F;VD@96YC;VYT<F%D
M82!V97)SXV\@;F$@8V]N9FEG=7)AY^-O(&]R:6=I;F%L+B!296=E;F5R87(@
M8V]N9FEG=7)AY^-O+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C<*
M;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D[C;R!F;VD@
M96YC;VYT<F%D82!V97)SXV\@;F$@<W5A(&-O;F9I9W5R8>?C;RX@4F5G96YE
M<F%R(&-O;F9I9W5R8>?C;RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H
M<#HT,38@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC
M.CDR"FUS9VED(").;VYE(@IM<V=S='(@(DYE;FAU;6$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE
M("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(DYE;FAU;2`H=7-A<B!I;7!L[6-I
M=&\I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DYO<F1I
M8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(D[S<F1I8V\@*$E33RTX.#4Y+3$P
M*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B"FUS9W-T<B`B26QH82!D92!.
M;W)F;VQK(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,R(&QI8B]";&]C:R]M
M;V]N+G!H<#HV,`IM<V=I9"`B3F]R=&AE<FX@2&5M:7-P:&5R92(*;7-G<W1R
M(")(96UI<V;I<FEO($YO<G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA
M($ES;&%N9',B"FUS9W-T<B`B26QH87,@36%R:6%N87,@9&\@3F]R=&4B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3<*
M;7-G:60@(DYO<G=A>2(*;7-G<W1R(")296EN;R!D82!.;W)U96=A(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E
M<B(*;7-G<W1R(").=6YC82!$97!O:7,@9&4B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<VUI;64N<&AP.C8S.0IM<V=I9"`B3F]T($)E9F]R92(*;7-G<W1R(").
M=6YC82!!;G1E<R!D92(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S,Q"FUS9VED
M(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B3N-O(.D@=6T@9&ER96-T\W)I
M;R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H<#HV,R!L:6(O5D93+TE33U=R
M:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&QI8B]61E,O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.30*(SH@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C0X"B,Z(&QI8B]61E,O
M25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(").XV\@:6UP;&5M96YT861A+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C@*;7-G
M:60@(DYO="!S970B"FUS9W-T<B`B4&]R(&%T<FEB=6ER(@H*(SH@;&EB+U9&
M4RYP:'`Z,3<U(&QI8B]61E,N<&AP.C$Y,R!L:6(O5D93+G!H<#HR,3`@;&EB
M+U9&4RYP:'`Z,C(V"B,Z(&QI8B]61E,N<&AP.C(T,B!L:6(O5D93+G!H<#HR
M-3<@;&EB+U9&4RYP:'`Z,C<T(&QI8B]61E,N<&AP.C,P-PHC.B!L:6(O5D93
M+G!H<#HS-C<@;&EB+U9&4RYP:'`Z-#0V(&QI8B]61E,N<&AP.C4Q-2!L:6(O
M5D93+G!H<#HU,S(*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-#,@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@;&EB+TAO
M<F1E+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,@;&EB+TAO<F1E+U-E<W-I;VY(
M86YD;&5R+G!H<#HQ.#<*(SH@;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R+G!H
M<#HR,S0*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S='(@(D[C;R!S=7!O
M<G1A9&\N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M-#0@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$V-`IM<V=I9"`B3F]T97,B
M"FUS9W-T<B`B3F]T87,B"@HC.B!S97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP
M:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G
M<W1R(").861A('!A<F$@;F%V96=A<BP@=F]L=&4@<&%R82!T<N%S+B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3`*;7-G
M:60@(DYO=&EC92(*;7-G<W1R(").;W1A(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,X-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#(Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DYO=F5M
M8G)O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$P-#8*;7-G:60@(DYU;6)E
M<B(*;7-G<W1R(").^FUE<F\B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,30R
M-PIM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B3OIM97)O
M(&1E(&-A<F%C=&5R97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,W,2!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T
M-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B3OIM97)O(&1E
M(&-O;'5N87,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,30R,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,30T-0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,@IM<V=I
M9"`B3G5M8F5R(&]F(')O=W,B"FUS9W-T<B`B3OIM97)O(&1E(&QI;FAA<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*;7-G:60@
M(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*(DYA(&QI<W1A(&1E(&1I<W1R:6)U
M:>?C;R!HX2!N^FUE<F]S('%U92!NXV\@9F]R86T@97-P96-I9FEC861O<R!P
M87)A("(*(F%C='5A;&EZ8>?C;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-C0@<&\O=')A;G-L871I;VXN<&AP.C$T.`HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,T.`IM<V=I9"`B3TLB"FUS9W-T<B`B
M3TLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#$Q
M"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B3V)J96-T;R(*"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS9VED(")/8FIE8W0@0W)E871O<B(*
M;7-G<W1R(")#<FEA9&]R(&1O($]B:F5C=&\B"@HC.B!A9&UI;B]P97)M<R]E
M9&ET+G!H<#HQ,S<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,34*;7-G:60@
M(D]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS(@IM<V=S='(@(E!E<FUI<W/U
M97,@9&\@8W)I861O<B!D;R!O8FIE8W1O(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Q,#0*;7-G:60@(D]C=&%L(@IM<V=S='(@(D]C=&%L(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,R!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B3W5T=6)R;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=')O(&1E(&UA=&5R
M:6%L(&]F96YS:79O(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P
M,0IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(D=A8FEN971E(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/
M;6%N(@IM<V=S='(@(E-U;'1A;F%T;R!D;R!/;>,B"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(E/S(&]S('-E
M<G9I9&]R97,@24U!4"!S=7!O<G1A;2!P87-T87,@<&%R=&EL:&%D87,N(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDU"FUS9VED(")/;FQY(&]F9F5N
M<VEV92!F;W)T=6YE<R(*;7-G<W1R(")!<&5N87,@9&ET;W,@;V9E;G-I=F]S
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3(@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y-S(*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"XB"FUS9W-T<B`B4_,@Z2!P97)M:71I9&\@=6T@96YD97)EYV\@9&4@8V]R
M<F5I;R!E;&5C='+S;FEC;RXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP
M:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E
M<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D%P96YA<R!O(&1O
M;F\@;W4@=6T@861M:6YI<W1R861O<B!D92!S:7-T96UA<R!P;V1E(&%L=&5R
M87(@82!T:71U;&%R:61A9&4@9&4@(@HB=6UA('!A<G1I;&AA(&]U(&%S('!E
M<FUI<W/U97,@9&\@<V5U(&1O;F\B"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H
M<#HS-0IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`B06)R
M92!N=6UA(&YO=F$@:F%N96QA(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE
M+G!H<#HR-#4*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R
M86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*
M(D5R<F\@3W!E;E-33#H@3N-O(&9O:2!P;W-S[79E;"!E>'1R86ER(&1A9&]S
M(&1E('5M82!P87)T92!A<W-I;F%D82!C;VT@4R\B"B)-24U%+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M-`IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*;7-G
M<W1R(")!8G)E(&5S=&$@;&EG8>?C;R!N=6UA(&YO=F$@:F%N96QA(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4S"FUS9VED(")/<&5R871I;F<@4WES
M=&5M(@IM<V=S='(@(E-I<W1E;6$@3W!E<F%T:79O(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R
M(")/<.?U97,B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,CD@=&5M<&QA=&5S
M+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N
M<R!F;W(@)7,B"FUS9W-T<B`B3W#G]65S(&1O("5S(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$Q,@IM<V=I9"`B3W!T:6]N<SHB"FUS9W-T<B`B3W#G]65S
M.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("),:7-T82!/<F1E;F%D
M82(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-38W"FUS9VED(")/
M<F=A;FES871I;VXB"FUS9W-T<B`B3W)G86YI>F'GXV\B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI<V%T:6]N86P@
M56YI="(*;7-G<W1R(")5;FED861E($]R9V%N:7IA8VEO;F%L(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$S,@IM<V=I9"`B3W)G86YI>FEN9R(*
M;7-G<W1R(")/<F=A;FEZ8>?C;R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,3,U"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G
M<W1R(")-;V1E;&\@;W)I9VEN86P@9&$@87!L:6-AY^-O(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")-;V1E;&]S(&]R:6=I;F%I
M<R!E;2`E<SHB"@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")/
M=71R;R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HY-B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3,@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")/
M=71R87,@26YF;W)M8>?U97,B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R(")097)M
M:7-S]65S(&1O($1O;F\B"@HC.B!L:6(O2&]R9&4O075T:"]P86TN<&AP.C<Y
M"FUS9VED(")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B075T96YT:6-AY^-O(%!!32!NXV\@97-TX2!D:7-P;V[M=F5L
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$R-3,*;7-G:60@(E!'
M4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G<W1R(")!<W-I;F%T=7)A($1I9VET
M86P@4$=0(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3(Y.0IM<V=I
M9"`B4$=0($5N8W)Y<'1E9"!$871A(@IM<V=S='(@(D1A9&]S(&5N8W)I<'1A
M9&]S(%!'4"(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$S-3$*;7-G
M:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(D-H879E(%#Z8FQI8V$@4$=0
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3,S,PIM<V=I9"`B4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R(")$861O<R!!<W-I;F%D
M;W,O16YC<FEP=&%D;W,@8V]M(%!'4"(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H
M<#HV.`IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B0_-D:6=O(%!(4"(*"B,Z
M(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM<V=S
M='(@(D-O;6%N9&]S(%!(4"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,W"FUS9VED(")032!,:6=H="!286EN(@IM<V=S='(@
M(D-H=79I<V-O<R!P96QA(%1A<F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@(E!-(%-H;W=E<G,B"FUS9W-T
M<B`B06=U86-E:7)O<R!D92!487)D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED(")032!3;F]W(@IM<V=S='(@
M(DYE=F4@X"!487)D92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0P"FUS9VED(")032!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B
M3F5V]65S(.`@5&%R9&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HT,0IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(E-O;"#@(%1A
M<F1E(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!O<F%I<RU4(.`@
M5&%R9&4B"@HC.B!L:6(O87!I+G!H<#HQ,C@*;7-G:60@(E!?2%`@4VAE;&PB
M"FUS9W-T<B`B0V]M86YD;W,@4%](4"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B
M"FUS9W-T<B`B16YC:&EM96YT;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W,@HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%K:7-T86XB"FUS9W-T
M<B`B4F5P^F)L:6-A($ES;.)M:6-A(&1O(%!A<75I<W3C;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!A;&%U(@IM<V=S='(@(E)E</IB;&EC82!D92!086QA=2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$W-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@
M(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B5&5R
M<FET\W)I;R!086QE<W1I;FEA;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!A;F%M82(*;7-G<W1R
M(")086YA;>$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@U(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3D*;7-G:60@(E!A<'5A($YE=R!'=6EN96$B"FUS9W-T<B`B
M4&%P=6$@3F]V82!'=6ENZ2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(E)E</IB;&EC82!D;R!087)A9W5A:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM
M<V=S='(@(E!A<F-I86QM96YT92!%;F-O8F5R=&\B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@S(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#$Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HU,S<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,R!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,V"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HS-C(*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(E!A;&%V<F$M4&%S<V4B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A
M<W-W;W)D(&EN8V]R<F5C="(*;7-G<W1R(")086QA=G)A+5!A<W-E(&EN8V]R
M<F5C=&$B"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U,@IM<V=I
M9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B4&%L879R82U087-S92!N96-E<W/A<FEA('!A<F$@875T
M96YT:6-AY^-O(%)!1$E54R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#4T
M"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R(")0
M86QA=G)A+5!A<W-E(&-O;2!C;VYF:7)M8>?C;R(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I9"`B4&%S<W=O<F0Z(@IM<V=S='(@
M(E!A;&%V<F$M4&%S<V4Z(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI
M;F,Z,3$*;7-G:60@(E!A<W-W;W)D.B`B"FUS9W-T<B`B4&%L879R82U087-S
M93H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&QI8B](;W)D92]&;W)M+G!H
M<#HR,#,U"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,34*
M;7-G:60@(E!A<W-W;W)D<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")!<R!P86QA
M=G)A<RUP87-S92!TZFT@9&4@<V5R(&EG=6%I<RXB"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`B0V]L87(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,W
M"FUS9VED(")087-T92!F<F]M(&-L:7!B;V%R9"(*;7-G<W1R(")#;VQA<B!D
M92!R96-O<G1E<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`B0V%M:6YH;R(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHT"FUS9VED(")096YD:6YG
M(%-I9VYU<',Z(@IM<V=S='(@(E-U8G-C<FGG]65S(%!E;F1E;G1E<SHB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G
M<W1R(")097-S;V%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,#<*;7-G:60@(E!E<F-E;G0B"FUS9W-T<B`B4&5R8V5N
M=&%G96TB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T
M;VTN:6YC.C8*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R(*;7-G<W1R(")%>&5C=71A<B!/<&5R8>?U97,@9&4@36%N=71E;N?C;R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3@*;7-G:60@(E!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B17AE
M8W5T87(@;W!E<F'G]65S(&1E(&UA;G5T96[GXV\@87%U86YD;R!D82!E;G1R
M861A/R(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV,2!A9&UI;B]P
M97)M<R]A9&1C:&EL9"YP:'`Z-C0*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C8W"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(E!E<FUI<W/C;R(*
M"B,@8RUF;W)M870*(SH@861M:6XO<&5R;7,O9&5L971E+G!H<#HV.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<(B!N;W0@9&5L971E
M9"XB"FUS9W-T<B`B02!P97)M:7-SXV\@7"(E<UPB(&[C;R!F;VD@<F5M;W9I
M9&$N(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,C(T(&%D;6EN+W!E<FUS
M+V%D9&-H:6QD+G!H<#HY,PHC.B!A9&UI;B]P97)M<R]I;F1E>"YP:'`Z,C(@
M861M:6XO<&5R;7,O9&5L971E+G!H<#HW-`IM<V=I9"`B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB"FUS9W-T<B`B061M:6YI<W1R8>?C;R!D92!097)M
M:7-S]65S(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ-#4@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ-#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H
M<#HQ-3(*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R(")097)M:7-S
M]65S(&1E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8U"FUS9VED(")0
M97)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("));F9O<FUAY_5E<R!097-S
M;V%I<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#,@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY.`IM<V=I9"`B4&5R=2(*;7-G<W1R(")097+Z(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0971S(@IM<V=S='(@(D%N:6UA
M:7,@9&4@17-T:6UAY^-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0:&EL:7!P:6YE<R(*;7-G<W1R
M(")&:6QI<&EN87,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y-@IM<V=I9"`B4&AO;F4B"FUS9W-T<B`B5&5L969O;F4B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(U"FUS9VED(")0:&]T;W,B"FUS
M9W-T<B`B1F]T;V=R869I87,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DP(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")0:71C86ER;B(*;7-G<W1R
M("));&AA<R!0:71C86ER;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`B4.UX
M96ES(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4V"FUS9VED(")0;&%T
M:71U9&5S(@IM<V=S='(@(E!L871I='5D97,B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B4&]R(&9A=F]R(&-L
M:7%U92!S;V)R92!U;6$@8^EL=6QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0X"FUS9VED(")0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M(@IM<V=S='(@(E!O<B!F879O<B!C;VYF:7)M92!S92!R96%L;65N=&4@<')E
M=&5N9&4@<F5M;W9E<B!E<W1E(&5L96UE;G1O.B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-0IM<V=I9"`B
M4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E
M;&5M96YT+B(*;7-G<W1R(")0;W(@9F%V;W(@8V]N9FER;64@<V4@<F5A;&UE
M;G1E('!R971E;F1E(&1E<VQI9V%R(&5S=&4@96QE;65N=&\N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(U-S`*;7-G:60@(E!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E!O<B!F879O<B!I;G1R;V1U>F$@
M=6T@;>IS(&4@=6T@86YO+B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R
M>6UA;F%G96UE;G0N:6YC.C$R"FUS9VED(")0;&5A<V4@96YT97(@82!N86UE
M(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")0;W(@9F%V;W(@:6YT
M<F]D=7IA(&\@;F]M92!D82!N;W9A(&-A=&5G;W)I83HB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@
M25`@861D<F5S<RXB"FUS9W-T<B`B4&]R(&9A=F]R(&EN=')O9'5Z82!U;2!E
M;F1E<F7G;R!)4"!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(V
M-3D*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H
M92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(B(*(E!O
M<B!F879O<B!I;G1R;V1U>F$@=6UA(&1A=&$@=N%L:61A.R!V97)I9FEQ=64@
M;R!N^FUE<F\@9&4@9&EA<R!D;R!MZG,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(T-3`*;7-G:60@(E!L96%S92!E;G1E<B!A('9A;&ED('1I;64N(@IM
M<V=S='(@(E!O<B!F879O<B!I;G1R;V1U>F$@=6UA(&AO<F$@=N%L:61A+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@(E!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS9W-T
M<B`B4&]R(&9A=F]R+"!F;W)N9>=A('5M82!B<F5V92!D97-C<FGGXV\@9&\@
M<')O8FQE;6$N(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHQ."!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R"FUS9VED(")0;&5A<V4@<')O
M=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"(*;7-G<W1R(")0;W(@
M9F%V;W(L(&EN=')O9'5Z82!O('-E=2!.;VUE(&1E(%5T:6QI>F%D;W(@92!A
M('-U82!086QA=G)A+5!A<W-E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E
M+V%G<F5E;65N=%]T;W`N:6YC.C$R"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@(%EO=2!-55-4(&%G
M<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB<WES=&5M+B(*;7-G
M<W1R("(B"B)0;W(@9F%V;W(@;&5I82!O('1E>'1O('-E9W5I;G1E+B!496T@
M9&4@0T].0T]21$%2(&-O;2!O<R!T97)M;W,@9&5S=&4@86-O<F1O("(*(G!A
M<F$@=7-A<B!O('-I<W1E;6$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$W
M"FUS9VED(")0;&5A<V4@<F5P;W)T(&%N>2!B=6=S('1O(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G+B(*;7-G<W1R(")0;W(@9F%V;W(@<F5P;W)T92!O<R!E<G)O
M<R!P87)A(&DQ.&Y`;&ES=',N:&]R9&4N;W)G(@H*(SH@;&EB+TAO<F1E+U!R
M969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S$*;7-G:60@(E!L96%S92!T>7!E
M('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B4&]R(&9A=F]R(&EN
M=')O9'5Z82!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0
M;VQA;F0B"FUS9W-T<B`B4&]L\VYI82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B4&]L[71I8V$B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,T"FUS9VED(")0;VQL<R(*
M;7-G<W1R(")3;VYD86=E;G,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3DS(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0;W)T=6=A;"(*;7-G<W1R
M(")297#Z8FQI8V$@4&]R='5G=65S82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R(")0;W-I8VEO;F%M96YT
M;R!D97-T82!I;6%G96TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T
M86)L92(*;7-G<W1R(")0;W-I8VEO;F%M96YT;R!D97-T82!T86)E;&$B"@HC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(E!O
M<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G
M<W1R(")<(E!O<W1<(B!P87)A(&5S=&$@<&%S=&$@*&[C;R#I(')E<75I<VET
M;R!D;R!)34%0*2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C8V(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I
M<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(E!R96-I
M<&ET8>?C;R!N87,@^FQT:6UA<R`E<R!H;W)A*',I.B`B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@V"FUS9VED(")0<F5C:7!I=&%T:6]N
M/&)R("\^8VAA;F-E(@IM<V=S='(@(E!R;V)A8FEL:61A9&4@9&4\8G(@+SY0
M<F5C:7!I=&'GXV\B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A<"YP:'`Z.3@*
M;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@02!E>'1E;G/C;R!,1$%0
M(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+B(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]S97-S:6]N+G!H<#HS,PIM<V=I9"`B4')E9G-?<V5S<VEO;CH@
M4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R
M(")0<F5F<U]S97-S:6]N.B!!(&5X=&5N<^-O(&1E('-E<W/C;R!N96-E<W/A
M<FEA(&[C;R!F;VD@96YC;VYT<F%D82XB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B4')E<W/C;R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Y"FUS9VED(")0<F5S<W5R92!A="!S
M96$@;&5V96PZ("(*;7-G<W1R(")0<F5S<^-O(&%O(&[M=F5L(&1O(&UA<CH@
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(R,PIM<V=I9"`B
M4')E<W-U<F4Z("(*;7-G<W1R(")0<F5S<^-O.B`B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@X"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B
M4')E=FEE=R(*;7-G<W1R(")0<F5V:7/C;R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(Q"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-`IM<V=I9"`B
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(E!R
M979E<B!A(&EM86=E;2!N=6UA(&YO=F$@:F%N96QA(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HS-C`@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C0*
M;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B3W#G]65S(&%N=&5R
M:6]R97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R("));7!R:6UI
M<B!O(&1O8W5M96YT;R(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M,@IM<V=I9"`B4')I=F%T92!+97DB"FUS9W-T<B`B0VAA=F4@4')I=F%D82(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS
M9W-T<B`B4')O8FQE;6$B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*
M;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B1&5S8W)IY^-O
M(&1O(%!R;V)L96UA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q
M,PIM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B4')O:F5C=&]S(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Q,3(@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#D*
M;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(DUE;G-A9V5M+7!R;VYT;R(*
M"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B4'5B;&EC
M($ME>2(*;7-G<W1R(")#:&%V92!0^F)L:6-A(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM
M(@IM<V=S='(@(D%L9V]R:71M;R!D92!#:&%V92!0^F)L:6-A(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@
M26YF;R(*;7-G<W1R("));F9O<FUAY^-O(%-O8G)E(&$@0VAA=F4B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HR,S`*;7-G:60@(E!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN(@IM<V=S
M='(@(D\@<&%R(&1E(&-H879E<R!0=6)L:6-A+U!R:79A9&$@;N-O(&9O:2!G
M97)A9&$@8V]M('-U8V5S<V\N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Y,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B"FUS
M9W-T<B`B4&]R=&\@4FEC;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M.38@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-`HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A=&%R(@IM<V=S='(@(D5S
M=&%D;R!D;R!1871A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HV,@IM<V=I
M9"`B475E<GDB"FUS9W-T<B`B4&5D:61O(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B4E-!(%!U8FQI
M8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B0VAA=F4@4/IB;&EC82!24T$@*"5D
M(&)I="DB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(V-0IM<V=I9"`B4F%D
M:6\@<V5L96-T:6]N(@IM<V=S='(@(E-E;&5CY^-O(%PB<N%D:6]<(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")286EN(@IM<V=S='(@(D-H=79A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB"FUS9W-T
M<B`B0VAU=F$@36%T:6YA;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C0U"FUS9VED(")286EN($QA=&4B"FUS9W-T<B`B0VAU
M=F$@5F5S<&5R=&EN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")!9W5A
M8V5I<F\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HT-PIM<V=I9"`B4F%I;B!A;F0@4VYO=R(*;7-G<W1R(")#:'5V82!E($YE
M=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M.`IM<V=I9"`B4F%I;B!T;R!3;F]W(@IM<V=S='(@(D-H=79A(&$@3F5V92(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@1F]R
M='5N92(*;7-G<W1R(")$:71O($%L96%T\W)I;R(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")296QAY^-O(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+G!H<#HR.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHS-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ,30@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS
M9W-T<B`B3&5R(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@W"FUS9VED(")296%D(&UE<W-A9V5S(@IM<V=S='(@(DQE<B!M96YS86=E
M;G,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"B,L
M('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E
M<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N(@IM<V=S='(@(E%U97(@;65S;6\@
M<F5M;W9E<B`E<S\@17-T82!O<&5R8>?C;R!NXV\@=&5M(')E9W)E<W-O+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T
M<B`B(@HB4F5M;W9E<B!M97-M;R!O<R!D861O<R!D;R!U=&EL:7IA9&]R("5S
M/R!%<W1A(&]P97)AY^-O(&[C;R!T96T@<F5G<F5S<V\N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`B4F5F87H@82!S=6$@^FQT
M:6UA(&%CY^-O(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X,PIM<V=I
M9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z(@IM<V=S='(@(E)E
M9G)E<V-A<B!%;&5M96YT;W,@9&4@365N=2!$:6[B;6EC;SHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,S"FUS9VED(")2969R97-H(%!O<G1A;"!6
M:65W.B(*;7-G<W1R(")2969R97-C87(@5FES=6%L:7IAY^-O(&1O(%!O<G1A
M;#HB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#DT(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C$S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,U"FUS9VED(")296=E
M>"(*;7-G<W1R(")%>'!R97-SXV\@4F5G=6QA<B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,C0X"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E<B(*;7-G
M<W1R(").879E9V%D;W(@9&4@4F5L8>?U97,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,R-@IM<V=I9"`B4F5M87)K<R(*;7-G<W1R(")/8G-E<G9AY_5E
M<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*;7-G:60@(E)E;6]T
M92!397)V97)S(@IM<V=S='(@(E-E<G9I9&]R97,@4F5M;W1O<R(*"B,Z('1E
M;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHX-`IM<V=I9"`B4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ(@IM<V=S='(@(E52
M3"!296UO=&\@*&AT='`Z+R]W=W<N97AE;7!L;RYP="]H;W)D92DZ(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHR,2!T96UP;&%T97,O
M861M:6XO=7-E<B]A<'!R;W9E+FEN8SHR.`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]R96UO=F5Q=65U960N:6YC.C$U"FUS9VED(")296UO=F4B"FUS9W-T
M<B`B4F5M;W9E<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ
M,0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(E)E;6]V97(@0FQO8V\B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(Y"FUS
M9VED(")296UO=F4@8V]L=6UN(@IM<V=S='(@(E)E;6]V97(@8V]L=6YA(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,`IM
M<V=I9"`B4F5M;W9E(&9O<FUA='1I;F<B"FUS9W-T<B`B4F5M;W9E<B!F;W)M
M871AY^-O(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S8*;7-G
M:60@(E)E;6]V92!P86ER(@IM<V=S='(@(E)E;6]V97(@<&%R(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C(P-0IM<V=I9"`B4F5M;W9E('-A=F5D('-C
M<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(E)E;6]V97(@;R!<(G-C<FEP=%PB(&=U87)D861O(&1A('!A<W1A('1E
M;7!O<N%R:6$@9&\@<V5R=FED;W(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")296UO=F4@
M=&AE(@IM<V=S='(@(E)E;6]V97(@;R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R(")296UO=F5R
M(&5S=&4@;O,@9&\@9&]C=6UE;G1O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E+FEN8SHQ-@IM<V=I9"`B4F5M;W9E('5S97(B"FUS9W-T<B`B
M4F5M;W9E<B!5=&EL:7IA9&]R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R
M.B`E<R(*;7-G<W1R(")296UO=F5R('5T:6QI>F%D;W(Z("5S(@H*(SH@;&EB
M+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L
M9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T
M<B`B3N-O(&9O:2!P;W-S[79E;"!R97-P;VYD97(@86\@<&5D:61O+B!#\V1I
M9V\@9&4@97)R;R!D979O;'9I9&\Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-#0*;7-G:60@(E)E<75E<W1E9"!S97)V:6-E(&-O=6QD
M(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B3R!S97)V:>=O('!E9&ED;R!NXV\@
M9F]I(&5N8V]N=')A9&$N(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S0@;&EB+TAO
M<F1E+G!H<#HT.#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E
M<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B7"(E<UPB(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O(&YA
M(&-O;F9I9W5R8>?C;R!D92`E<RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z-3DW
M(&QI8B]61E,O9G1P+G!H<#HW-#<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S$P
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")<(B5S7"(@
M;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A
MY^-O(%9&4RXB"@HC.B!L:6(O2&]R9&4O571I;"YP:'`Z-S@T"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(EPB)7-<(B!O8G)I9V%T\W)I;R!N
MXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\N(@H*(SH@;&EB
M+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,R.`IM<V=I9"`B4F5Q=6ER960@
M1FEE;&0B"FUS9W-T<B`B0V%M<&\@3V)R:6=A=/-R:6\B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,Y(&QI8B](;W)D92]&
M;W)M+U)E;F1E<F5R+G!H<#HS,34*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C$P,2!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0T
M"FUS9VED(")297-E="(*;7-G<W1R("),:6UP87(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HT-@IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS
M9W-T<B`B4F5I;FEC:6%R(%!A;&%V<F$M4&%S<V4B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R
M9"(*;7-G<W1R(")296EN:6-I92!A(%-U82!086QA=G)A+5!A<W-E(@H*(SH@
M861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A
M9&UI;B]S<6QS:&5L;"YP:'`Z-C4*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B
M4F5S=6QT861O<R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,C$*;7-G:60@
M(E)E<W5L=',@*&EN8VQU9&EN9R!(;W)D92DZ(@IM<V=S='(@(E)E<W5L=&%D
M;W,@*&EN8VQU:6YD;R!(;W)D92DZ(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C@Q.0IM<V=I9"`B4F5S=6QT<SHB"FUS9W-T<B`B4F5S=6QT861O<SHB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P
M<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S
M='(@(E9O;'1A<B#@<R!/<.?U97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3DW(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N(@IM<V=S
M='(@(E)E=6YIXV\B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D
M;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#;VYF:6=U
M<F%T:6]N(@IM<V=S='(@(E)%=F5R=&5R($-O;F9I9W5R8>?C;R(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S(*;7-G:60@(E)I8V@@5&5X="!%9&ET
M;W(@3W!T:6]N<R(*;7-G<W1R(")/<.?U97,@9&4@161IY^-O(%)I8V$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*;7-G:60@(E)I9&1L97,B"FUS
M9W-T<B`B061I=FEN:&%S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C<P"FUS9VED(")2:6=H="(*;7-G<W1R(")$
M:7)E:71A(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C`*;7-G:60@(E)I
M9VAT(&AE861E<B(*;7-G<W1R(")#86)EYV%L:&\@9&$@9&ER96ET82(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HS,3$V"FUS9VED(")2:6=H="!V86QU97,B
M"FUS9W-T<B`B5F%L;W)E<R#@(&1I<F5I=&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O
M7W<@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@3&EN
M7VAA+BXN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR
M,S0*;7-G:60@(E)O;&4B"FUS9W-T<B`B4F5G<F$B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2;VUA
M;FEA(@IM<V=S='(@(E)O;>EN:6$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C`X"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@
M(E)O9&%R(#$X,"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,#4*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(E)O9&%R(.`@
M17-Q=65R9&$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C$Q"FUS9VED(")2;W1A=&4@4FEG:'0B"FUS9W-T<B`B4F]D87(@X"!D
M:7)E:71A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T<B`B
M4')O<')I961A9&5S(&1A($QI;FAA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E
M<G1I97,B"FUS9W-T<B`B4')O<')I961A9&5S(&1A(&QI;FAA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@
M(E)O=W,Z(@IM<V=S='(@(DQI;FAA<SHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R(")4<F'G;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(E1R8>=O
M<R!A<&%R96-E<N-O(&5N=')E('1O9&%S(&%S(&QI;FAA<R!E(&-O;'5N87,B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4Q"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M
M;G,@;VYL>2(*;7-G<W1R(")4<F'G;W,@87!A<F5C97+C;R!A<&5N87,@96YT
M<F4@87,@8V]L=6YA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G:60@(E)U;&5S('=I;&P@87!P96%R
M(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S='(@(E1R8>=O<R!A<&%R96-E<N-O
M(&%P96YA<R!E;G1R92!L:6YH87,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3(Q"FUS9VED(")2=6XB"FUS9W-T<B`B17AE8W5T87(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DY(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")2
M=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B1F5D97)AY^-O(%)U<W-A(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3@X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)E</IB;&EC82!D;R!2=6%N9&$B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-
M24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(D%S<VEN871U
M<F$@0W)I<'1O9W+A9FEC82!3+TU)344B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E
M(@IM<V=S='(@(DUE;G-A9V5M($5N8W)I<'1A9&$@8V]M(%,O34E-12(*"B,Z
M(&QI8B](;W)D92]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE
M;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D%U=&5N=&EC
M8>?C;R!305-,(&EN9&ES<&]N[79E;"XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#4Y"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S='(@(DUE
M;G-A9V5N<R!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@
M(E-13"!3:&5L;"(*;7-G<W1R(")#;VUA;F1O<R!344PB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,S<P"FUS9VED(")34T@B"FUS9W-T<B`B4U-(
M(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,U"FUS9VED(")354-#15-3(@IM<V=S='(@(E-50T534T\B"@HC.B!L
M:6(O87!I+G!H<#HQ,S(*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B0V]M
M86YD;W,@4U]13"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(G/A(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B
M4V%I;G0@2&5L96YA(@IM<V=S='(@(E-A;G1A($AE;&5N82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E/C;R!+:71T<R!E($YE
M=FES(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R(")386YT82!,^F-I
M82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#D@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#`*;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T
M<B`B4^-O(%!E9')O(&4@36EQ=65L;VXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$U"FUS9VED(")386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<R(*;7-G<W1R(")3XV\@5FEC96YT92!E
M($=R96YA9&EN97,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.CDR"FUS9VED(")386UE(&9R86UE("A?<V5L9BDB"FUS9W-T
M<B`B365S;6$@;6]L9'5R82`H7W-E;&8I(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C(U,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B4V%M;V$B"FUS
M9W-T<B`B17-T861O($EN9&5P96YD96YT92!D82!386UO82(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,3(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@
M(E-A;B!-87)I;F\B"FUS9W-T<B`B4F5P^F)L:6-A(%-E<F5N[7-S:6UA(&1E
M(%/C;R!-87)I;F\B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B
M"FUS9W-T<B`B4^-O(%1O;>D@92!0<NUN8VEP92(*"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM
M<V=S='(@(D9O<FYE8V5D;W(@9&\@4V%TZ6QI=&4B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3875D
M:2!!<F%B:6$B"FUS9W-T<B`B07+A8FEA(%-A=61I=&$B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B
M1W5A<F1A<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$V"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B1W5A<F1A<B`E
M<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4V%V92`G)7,G(@IM<V=S='(@(D=U87)D87(@
M)R5S)R(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A
M=F4@3W!T:6]N<R(*;7-G<W1R(")'=6%R9&%R($]PY_5E<R(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S`*;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R
M)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB1W5A<F1A
M<B!C;VYF:6=U<F'GXV\@9V5R861A(&-O;6\@=6T@7")S8W)I<'1<(B!02%`@
M;F\@9&ER96-T\W)I;R!T96UP;W+A<FEO("(*(F1O('-E=2!S97)V:61O<BXB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HV.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'=6%R
M9&5I(&-O;F9I9W5R8>?C;R`E<RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S
M+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S971U<"!U<&=R
M861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")'=6%R9&5I(&\@7")S
M8W)I<'1<(B!D92!A8W1U86QI>F'GXV\@96TZ(%PB)7-<(BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT.0IM<V=I9"`B4V-A
M='1E<F5D(%0M4W1O<FUS(@IM<V=S='(@(E1E;7!O<F%I<RU4($1I<W!E<G-O
M<R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC
M92(*;7-G<W1R(")#:>IN8VEA(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;&ES="YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*
M;7-G:60@(E-E87)C:"(*;7-G<W1R(")0<F]C=7)A<B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HR-S@*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM
M<V=S='(@(DUO=&]R97,@9&4@4')O8W5R82(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ-#0X"B,L('!H<"UF;W)M870*;7-G:60@(E-E87)C:&EN9R!(;W)D
M92!A<'!L:6-A=&EO;G,@:6X@)7,B"FUS9W-T<B`B4')O8W5R86YD;R!A<&QI
M8V'G]65S("AM\V1U;&]S*2!(;W)D92!E;2`E<R(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,C,*;7-G:60@(E-E87)C:&EN9R!G971T97AT(&)I;F%R:65S
M+BXN(@IM<V=S='(@(E!R;V-U<F%N9&\@;W,@8FENX7)I;W,@9&4@9V5T=&5X
M="XN+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3<R"FUS9VED(")396QE
M8W0@1FEL97,B"FUS9W-T<B`B4V5L96-C:6]N87(@07)Q=6EV;W,B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V"FUS9VED(")3
M96QE8W0@82!D871E(@IM<V=S='(@(E-E;&5C8VEO;F4@=6UA(&1A=&$B"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B4V5L96-T
M(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(E-E;&5C8VEO;F4@=6T@9W)U<&\@
M82!A8W)E<V-E;G1A<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")396QE8V-I
M;VYA<B!U;2!N;W9O(&1O;F\B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z-C`*;7-G:60@(E-E;&5C="!A('-E<G9E<B(*;7-G<W1R(")396QE
M8V-I;VYE('5M('-E<G9I9&]R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ-38*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM<V=S='(@
M(E-E;&5C8VEO;F4@=6T@=71I;&EZ861O<B!A(&%D:6-I;VYA<B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-C8R"FUS9VED(")396QE8W0@86QL(&1A=&4@
M8V]M<&]N96YT<RXB"FUS9W-T<B`B4V5L96-C:6]N92!T;V1O<R!O<R!C;VUP
M;VYE;G1E<R!D82!D871A+B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HX,3$*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T
M<B`B4V5L96-C:6]N92!U;2!O8FIE8W1O(@H*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82XB"FUS9W-T
M<B`B(@HB4V5L96-C:6]N92!O<R!C87)A8W1E<F5S(&YA<R!C86EX87,@86)A
M:7AO+B!0;V1E<N$@96YTXV\@8V]P:>$M;&]S(&4@8V]LX2TB"B)L;W,@;F$@
MX7)E82!D92!T97AT;RXB"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHS
M-`IM<V=I9"`B4V5L96-T('1H92!D871E(&1E;&EM:71E<CHB"FUS9W-T<B`B
M4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A=&$Z(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!F
M;W)M870Z(@IM<V=S='(@(E-E;&5C8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z
M(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHX.0IM
M<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M(@IM<V=S='(@(E-E;&5C8VEO;F4@82!I9&5N=&ED861E('%U92!P<F5T96YD
M92!A;'1E<F%R.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS
M9VED(")396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")396QE
M8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&%S(&AO<F%S.B(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R
M;6%T.B(*;7-G<W1R(")396QE8V-I;VYE(&\@9F]R;6%T;R!D82!H;W)A.B(*
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C0*;7-G:60@(E-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R(")396QE8V-I;VYE(&1O
M:7,@8V%M<&]S(')E;&%C:6]N861O<RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,CDX"FUS9VED(")396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N(@IM
M<V=S='(@(D5S8V]L:&$@;R!S974@8V]N:G5N=&\@9&4@8V]R97,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,`IM<V=I9"`B4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R(")396QE8V-I;VYE(&\@<V5U
M(&ED:6]M82!P<F5F97)I9&\Z(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T
M<B`B16YV:6%R(%)E;&%T\W)I;R!D92!0<F]B;&5M87,B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38Q"FUS9VED(")396YD(%--
M4R(*;7-G<W1R(")%;G9I87(@4TU3(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G
M<W1R(")297#Z8FQI8V$@9&\@4V5N96=A;"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S$V"FUS9VED(")396YS;W(Z("(*;7-G<W1R("(@4V5N<V]R.B`B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@R(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3D*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,PIM<V=I9"`B4V5P
M=&5M8F5R(@IM<V=S='(@(E-E=&5M8G)O(@H*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O
M(@IM<V=S='(@(E/I<G9I82!E($UO;G1E;F5G<F\B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*;7-G
M<W1R(").^FUE<F\@9&4@4^ER:64B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,30X"FUS9VED(")397)V97(@9&%T82!W<F]N9R!O<B!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R(")$861O<R!D;R!S97)V:61O<B!E<G)A9&]S
M(&]U(&EN9&ES<&]N[79E:7,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E9"XB"FUS
M9W-T<B`B240@9&4@<V5S<^-O(&5X<&ER;W4N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S,3,*;7-G:60@(E-E="(*;7-G<W1R(")!=')I8G5I<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+B(*;7-G<W1R("(B"B)%<W1A8F5L9>=A(&]PY_5E<R!Q
M=64@;&AE('!E<FUI=&%M(')E:6YI8VEA<B!A('-U82!P86QA=G)A+7!A<W-E
M('-E(&%L9W5M82`B"B)V97H@9&5L82!S92!E<W%U96-E<BXB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"XB"FUS9W-T<B`B17-P96-I9FEC87(@<V5R=FED;W)E<R!R96UO=&]S('%U
M92!D97-E:F$@86-E9&5R(&YO('-E=2!P;W)T86PN(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C@T"FUS9VED(")3970@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(B(*
M(E-E;&5C8VEO;F4@;R!S974@:61I;VUA('!R969E<FED;RP@;R!S974@9G5S
M;R!H;W+A<FEO(&4@87,@<W5A<R!O<.?U97,@9&4@(@HB9&%T87,N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"FUS9VED("(B"B)3970@>6]U<B!S
M=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S
M:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B
M(@HB17-C;VQH82!A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@;R!E<W%U96UA
M(&1E(&-O<F5S+"!O(')E9G)E<V-A;65N=&\@9&4@(@HB<.%G:6YA<R!E(&]U
M=')A<R!O<.?U97,@9&4@=FES=6%L:7IAY^-O+B(*"B,Z(&%D;6EN+W-E='5P
M+V-O;F9I9RYP:'`Z-S0*;7-G:60@(E-E='5P(@IM<V=S='(@(D-O;F9I9W5R
M87(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HS.0IM
M<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L92(*;7-G<W1R
M(")<(E-C<FEP='-<(B!D92!A8W1U86QI>F'GXV\@9&ES<&]N[79E:7,B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<T"FUS9VED(")3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z("(*
M;7-G<W1R(")6X7)I87,@;&]C86QI>F'G]65S('!O<W/M=F5I<R!C;VT@;R!P
M87+B;65T<F\Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5I
M8VAE;&5S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U,0IM<V=I
M9"`B4VAO<'!I;F<B"FUS9W-T<B`B0V]M<')A<R(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM
M<V=S='(@(D)R979E(%-U;>%R:6\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#,X"FUS9VED(")3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F
M;W(@;6]S="!L:6YK<S\B"FUS9W-T<B`B1&5V96TM<V4@9&5F:6YI<B!T96-L
M87,@9&4@86-E<W-O('!A<F$@82!M86EO<FEA(&1A<R!L:6=AY_5E<S\B"@HC
M.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y,B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C,S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-C<@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$Q,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W.0IM<V=I9"`B4VAO=R(*
M;7-G<W1R(")-;W-T<F%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$U
M.`IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L
M>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"`B"B)C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("(B"B)-;W-T<F%R(&1I9F5R96[G87,@96YT<F4@82!C
M;VYF:6=U<F'GXV\@9W5A<F1A9&$@92!A<75E(&9O:2!A9V]R82!G97)A9&$N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X,@IM<V=I9"`B4VAO=R!L
M87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/R(*;7-G<W1R(")-;W-T
M<F%R(&UO;65N=&\@9&$@^FQT:6UA(&5N=')A9&$@;F\@<VES=&5M83\B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-@IM<V=I9"`B4VAO=R!O<'1I;VX@
M=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R(")-;W-T<F%R(&]PY^-O('!A<F$@
M<')E<V5R=F%R(&\@;W)I9VEN86PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,C@Q,@IM<V=I9"`B4VAO=R!P:6-K97(B"FUS9W-T<B`B36]S=')A<B!P86QE
M=&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")3:&]W
M('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(DUO<W1R87(@
M82!B87)R82!D92!M96YU(&-O;2!A<R!O<&5R8>?U97,@<V]B<F4@=&%B96QA
M<S\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"B,L('!H<"UF;W)M
M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_(@IM<V=S
M='(@(DUO<W1R87(@;R!-96YU("5S(.`@97-Q=65R9&$_(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X"FUS
M9VED(")3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(DUO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P<FEE
M9&%D97,@9&4@0^EL=6QA<R!D92!486)E;&$_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8S"FUS9VED(")3
M:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")-;W-T
M<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S(&1E(%1A
M8F5L87,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-3D*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(")-;W-T<F%R(&$@8V%I>&$@9&4@9&GA
M;&]G;R!D87,@4')O<')I961A9&5S(&1E($QI;FAA<R!D92!486)E;&$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3$*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M(@IM<V=S='(@(DUO<W1R87(@82!C86EX82!D92!D:>%L;V=O(&1A<R!0<F]P
M<FEE9&%D97,@9&4@26UA9V5M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W
M-C0*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(DUO<W1R87(@8V%R<F5G
M86UE;G1O(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3`*;7-G:60@(E-H;W=E<G,B"FUS9W-T<B`B06=U86-E:7)O<R(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED
M(")3:&]W97)S($5A<FQY(@IM<V=S='(@(D%G=6%C96ER;W,@36%T:6YA:7,B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM
M<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(D%G=6%C96ER;W,@5F5S<&5R
M=&EN;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!I;B!T:&4@5FEC:6YI='DB"FUS9W-T<B`B
M06=U86-E:7)O<R!N82!6:7II;FAA;N=A(@H*(SH@;&EB+TAO<F1E+T)L;V-K
M+TQA>6]U="YP:'`Z,SDY"FUS9VED(")3:')I;FLB"FUS9W-T<B`B16YC;VQH
M97(B"@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HV.3(@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="YP:'`Z-S4T"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C@Q,B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX-S0*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3`Y(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.CDT-@HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HY-S0@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3`P-`IM<V=I
M9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O
M9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(D5N8V]L:&$@;W4@;6]V82!O*',I
M(&)L;V-O*',I('9I>FEN:&\H<RD@<')I;65I<F\B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C$Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3:65R
M<F$@3&5O;F4B"FUS9W-T<B`B4V5R<F$@3&7C;R(*"B,Z(&QI8B](;W)D92]!
M=71H+U-I9VYU<"YP:'`Z,C8U"FUS9VED(")3:6=N('5P(@IM<V=S='(@(E-U
M8G-C<F5V97(B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDR"FUS
M9VED(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S='(@(E-U8G-C
M<F5V82P@<V4@86EN9&$@;N-O(&5S=.$@<F5G:7-T861O(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G
M<W1R(")!<W-I;F%T=7)A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HW,3$*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`B06QG
M;W)I=&UO(&1E($%S<VEN871U<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS
M9W-T<B`B4F5P^F)L:6-A(&1E(%-I;F=A<'5R82(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HX.38@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,34@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R,S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-#<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(Y,CD@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,C(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C4@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#0*;7-G:60@(E-I>F4B"FUS9W-T<B`B5&%M86YH;R(*
M"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C;VYF:7)M7V)O='1O;2YI;F,Z
M.0IM<V=I9"`B4VMI<"!-86EN=&5N86YC92(*;7-G<W1R(")386QT87(@36%N
M=71E;N?C;R(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,S$@<&\O=')A;G-L
M871I;VXN<&AP.C0X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8V"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HX-C`@<&\O=')A;G-L871I;VXN<&AP.C$R,C,*;7-G
M:60@(E-K:7!P960N+BXB"FUS9W-T<B`B3N-O('!R;V-E<W-A9&\N+BXB"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$P(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U
M"FUS9VED(")3;&]V86MI82(*;7-G<W1R(")%<VQO=N%Q=6EA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VQO=F5N:6$B"FUS9W-T<B`B4F5P^F)L:6-A(&1A($5S;&]VZ6YI82(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS
M9VED(")3;F]W(@IM<V=S='(@(DYE=F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS
M9W-T<B`B3F5VXV\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-@IM<V=I9"`B4VYO=R!3:&]W97)S(@IM<V=S='(@(DYE=O5E
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W
M"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB"FUS9W-T<B`B3F5V]65S($UA
M=&EN86ES(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(DYE=O5E
M<R!697-P97)T:6YO<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"FUS
M9VED(")3;F]W(&1E<'1H.B`B"FUS9W-T<B`B06QT=7)A(&1E(&YE=F4Z("(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z("(*;7-G<W1R(")-;W-T<F%R(&5Q=6EV86QE;G1E
M(&YA(.%G=6$Z("(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*;7-G<W1R
M("));&AA<R!386QO;>-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI82(*;7-G<W1R(")3
M;VWA;&EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P"FUS9VED(")3
M;VYG<R`F(%!O96US(@IM<V=S='(@(D-A;N?U97,@92!0;V5M87,B"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,CDR-0IM<V=I9"`B4V]R="!O<F1E<B!S96QE
M8W1I;VXB"FUS9W-T<B`B4V5L96/GXV\@9&\@<V5N=&ED;R!D82!O<F1E;F'G
MXV\B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34Y(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@;&EB+TYE="]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,3<@;&EB+TYE="]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR-#<*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S
M='(@(D5N9&5R9>=O(&1E(&]R:6=E;2(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-34@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC
M82(*;7-G<W1R("+!9G)I8V$@9&\@4W5L(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.3`*;7-G:60@(E-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*2(*
M;7-G<W1R(")%=7)O<&$@9&\@4W5L("A)4T\M.#@U.2TS*2(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B
M"FUS9W-T<B`B1V7S<F=I82!D;R!3=6P@92!);&AA<R!386YD=VEC:"!D;R!3
M=6PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM<V=S='(@(DAE
M;6ES9NER:6\@4W5L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J86-E;G0@
M8V5L;',B"FUS9W-T<B`B17-P8>=O(&5N=')E(&/I;'5L87,@861J86-E;G1E
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL(@IM<V=S='(@(D5S<&'G;R!E;G1R92!O(&-O;G1E^F1O(&4@82!B
M;W)D82!D92!U;6$@8^EL=6QA(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q
M-0IM<V=I9"`B4W!A8V5R(@IM<V=S='(@(D5S<&'G861O<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I
M9"`B4W!A8VEN9R(*;7-G<W1R(")%<W!AYV%M96YT;R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-30*;7-G:60@
M(E-P86-I;F<@86YD('!A9&1I;F<B"FUS9W-T<B`B17-P8>=A;65N=&\@92!E
M;F-H:6UE;G1O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(E)E:6YO(&1E($5S
M<&%N:&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@
M(E-P86TB"FUS9W-T<B`B0V]R<F5I;R!NXV\@<V]L:6-I=&%D;R(*"B,Z('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T
M97(@26YP=70B"FUS9W-T<B`B26YS97)I<B!#87)A8W1E<B!%<W!E8VEA;"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C(*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B1&EV:61I<B!CZ6QU
M;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB"FUS9W-T<B`B061I8VEO
M;F%R(&-O;'5N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R(")$
M:79I9&ER(&QI;FAA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS
M9VED(")3<&]R=',B"FUS9W-T<B`B1&5S<&]R=&]S(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED(")3<FD@
M3&%N:V$B"FUS9W-T<B`B4F5P^F)L:6-A($1E;6]C<N%T:6-A(%-O8VEA;&ES
M=&$@9&\@4W)I($QA;FMA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8U(&QI8B]";&]C:R]M971A<BYP:'`Z-S0*;7-G:60@(E-T86YD87)D
M(@IM<V=S='(@(E!A9'+C;R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,@IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-3DU(&QI8B](;W)D92]&;W)M+G!H<#HR.#`X
M"FUS9VED(")3=&%R="!Y96%R(@IM<V=S='(@(D%N;R!D92!I;NUC:6\B"@HC
M.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,`IM<V=I9"`B4W1A=&4@
M;W(@4')O=FEN8V4B"FUS9W-T<B`B17-T861O(&]U(%!R;W;M;F-I82(*"B,Z
M('1E;7!L871E<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3
M=&%T=7,B"FUS9W-T<B`B4W1A='5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C0Y,0HC+"!P:'`M9F]R;6%T"FUS9VED(")3=&%T=7,@9F]R(&QO8V%L92`E
M<RXN+B`B"FUS9W-T<B`B17-T861O(&1A(&QO8V%L:7IAY^-O("5S+BXN("(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.#$T"FUS9VED(")3=&]R86=E(&9O
M<FUA="(*;7-G<W1R(")&;W)M871O(&1E(&%R;6%Z96YA;65N=&\B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4W,@IM<V=I9"`B4W1R965T($%D
M9')E<W,B"FUS9W-T<B`B16YD97)EYV\@9&4@4G5A(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R:6ME
M=&AR;W5G:"(*;7-G<W1R(")287-U<F%D;R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,C,S"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R("),:7-T82!D
M92!C861E:6%S(&1E(&-A<F%C=&5R97,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3@W-`IM<V=I9"`B4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,B
M"FUS9W-T<B`B4F5T:7)A<B!D;VWM;FEO(&1O(&5N9&5R9>=O(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM
M<V=I9"`B4W1Y;&4@6T-34UTB"FUS9W-T<B`B17-T:6QO(%M#4U-=(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,@IM<V=I
M9"`B4W4B"FUS9W-T<B`B9&\B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R(")!<W-U;G1O
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,B!L:6(O2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'`Z,S$R"FUS9VED(")3=6)M:70B"FUS9W-T<B`B4W5B;65T
M97(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*
M(E-U8FUI='1E9"!R97%U97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H
M87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T<B`B(@HB1F]I('-U8FUE=&ED;R!P
M961I9&\@<&%R82!A9&EC:6]N87(@7"(E<UPB(&%O('-I<W1E;6$N($[C;R!P
M;V1E<N$@96YT<F%R("(*(F5N<75A;G1O(&\@<V5U('!E9&ED;R!NXV\@9F]R
M(&%P<F]V861O+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G<W1R("));F9E<FEO
M<B#@(&QI;FAA(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$P-2!L:6(O2&]R
M9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@
M(E-U8V-E<W,B"FUS9W-T<B`B4W5C97-S;R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B7"(E<UPB(&%D:6-I;VYA
M9&\@8V]M('-U8V5S<V\@86\@<VES=&5M82XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"B),:6UP97IA(&1O('-I<W1E;6$@9&]S(&1A9&]S(&1O('5T:6QI
M>F%D;W(@7"(E<UPB(')E86QI>F%D82!C;VT@<W5C97-S;RXB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C@Q(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB
M+B(*;7-G<W1R(")296UOY^-O(&1E(%PB)7-<(B!C;VT@<W5C97-S;RXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B4F5M;^?C;R!D92!<(B5S7"(@9&\@<VES=&5M82!C;VT@<W5C97-S
M;RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@<F5V97)T:61A(&-O
M;2!S=6-E<W-O+B!296-A<G)E9W5E('!A<F$@=F5R(&%S(&UU9&%NYV%S+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I
M<'1S+G!H<#HU-0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")#;VYF:6=U<F'GXV\@9&4@<V%L=F%G
M=6%R9&$@9W5A<F1A9&$@8V]M('-U8V5S<V\N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HV,@HC+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L
M;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM
M<V=S='(@(D9I8VAE:7)O(&1E(&-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D
M82`E<R!G=6%R9&%D;R!C;VT@<W5C97-S;RXB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('5P9&%T
M960@7"(E<UPB(@IM<V=S='(@(EPB)7-<(B!A8W1U86QI>F%D;R!C;VT@<W5C
M97-S;R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F
M=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!E<V-R:71O(&-O;2!S=6-E<W-O
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P-"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P-`IM<V=I9"`B4W5D86XB"FUS9W-T<B`B4F5P^F)L:6-A(&1O(%-U9.-O
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")297-U;6\B"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z-C8*;7-G:60@(E-U;B!2:7-E(@IM<V=S
M='(@(DYA<V-E<B!D;R!3;VPB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M-S$*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B4/1R(&1O(%-O;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3
M=6YN>2(*;7-G<W1R(")3;VQA<F5N9V\B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C`T"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(DYA<V-E
M<B!D;R!3;VPB"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO
M8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S
M='(@(DYA<V-E<B]0]'(@9&\@4V]L(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(P,PIM<V=I9"`B4W5N<FES93H@(@IM<V=S='(@(DYA<V-E
M<B!D;R!3;VPZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,#<*;7-G:60@(E-U;G-E="(*;7-G<W1R(")0]'(@9&\@4V]L(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P-@IM<V=I9"`B4W5N<V5T.B`B
M"FUS9W-T<B`B4/1R(&1O(%-O;#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,PIM<V=I9"`B4W5P97)S8W)I<'0B"FUS
M9W-T<B`B4W5P97)I;W(@X"!L:6YH82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#,*;7-G:60@(E-U<'!O<G0B"FUS9W-T<B`B4W5P;W)T92(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN86UE(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS
M9W-T<B`B07!E;&ED;R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,PHC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@(E-V86QB87)D(&%N9"!*86X@36%Y
M96XB"FUS9W-T<B`B4W9A;&)A<F0@92!*86X@36%Y96XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,30*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")3
M=V%Z:6QA;F0B"FUS9W-T<B`B4F5I;F\@9&$@4W5A>FELXFYD:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS
M9VED(")3=V5D96XB"FUS9W-T<B`B4F5I;F\@9&$@4W7I8VEA(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C4V(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@
M(E-W:71Z97)L86YD(@IM<V=S='(@(E-U[>=A(@H*(SH@;&EB+TAO<F1E+U-1
M3"]+97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,B"FUS9W-T<B`B17)R;R!D92!S:6YT87AE(&YO<R!T97)M;W,@
M9&4@<')O8W5R82(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM
M<V=S='(@(E)E</IB;&EC82#!<F%B92!3[7)I82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM
M<V=S='(@(E1E;7!O<F%L+50B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,0IM<V=I9"`B5"U3=&]R;2!A;F0@5VEN9'DB"FUS
M9W-T<B`B5&5M<&]R86PM5"!E(%9E;G1O<V\B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS
M9W-T<B`B5&5M<&]R86ES+50B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HV,PIM<V=I9"`B5"U3=&]R;7,@16%R;'DB"FUS9W-T
M<B`B5&5M<&]R86ES+50@36%T:6YA:7,B"@HC.B!L:6(O2&]R9&4O1&%T82]T
M<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B07)Q=6EV;R!4
M4U8B"@HC.B!L:6(O2&]R9&4O54DO5&%B;&4N<&AP.C$S-@IM<V=I9"`B5&%B
M;&4B"FUS9W-T<B`B5&%B96QA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,PIM<V=I9"`B5&%B;&4@4')O<&5R
M=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@9&$@5&%B96QA(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM
M<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")0<F]P<FEE9&%D97,@
M9&$@=&%B96QA(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-"!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1A:7=A;B(*;7-G<W1R
M(")&;W)M;W-A(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q
M.`IM<V=I9"`B5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")&
M;W)M;W-A(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P.0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")297#Z8FQI
M8V$@9&\@5&%D:FEQ=6ES=.-O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E
M9"!297!U8FQI8R!O9B(*;7-G<W1R(")486YZXFYI82(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E
M=#HB"FUS9W-T<B`B06QV;SHB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,3<S"FUS9VED(")487-K<R(*;7-G<W1R(")487)E9F%S(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.
M=6UB97(B"FUS9W-T<B`B3OIM97)O(&1E(%1E;&5F;VYE(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U<CH@
M(@IM<V=S='(@(E1E;7!E<F%T=7)A(&1A(/IL=&EM82!H;W)A.B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS9VED(")496UP97)A='5R92(*;7-G
M<W1R(")496UP97)A='5R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3$*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T<B`B5&5M<&5R
M871U<F$Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S
M+R5S3&\E<RD@)F1E9SLE<R(*;7-G<W1R(")496UP97)A='5R83QB<B`O/B@E
M<T%L=&$E<R\E<T)A:7AA)7,I("9D96<[)7,B"@HC.B!L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP.C(Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")496UP;&%T92!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")/(&UO9&5L;R!<(B5S7"(@;N-O
M(&9O:2!E;F-O;G1R861O+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y
M"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI
M;FES=')AY^-O(&1E($UO9&5L;W,B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3(Q,0IM<V=I9"`B5&5X="(*;7-G<W1R(")497AT;R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-C<*;7-G:60@(E1E>'0@3VYL>2(*;7-G<W1R(")!
M<&5N87,@5&5X=&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(D%L:6YH86UE;G1O(&1O('1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R
M(")4;W!O(&1O('1E>'1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B-:HB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM<V=I9"`B5&AA:2`H5$E3+38R,"DB
M"FUS9W-T<B`B5&%I;&%N9.IS("A425,M-C(P*2(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R
M,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1H86EL
M86YD(@IM<V=S='(@(E)E:6YO(&1A(%1A:6SB;F1I82(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY,C,*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE
M('-Y<W1E;2XB"FUS9W-T<B`B3V)R:6=A9&\@<&]R('5S87(@97-T92!S:7-T
M96UA+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N)W0@>65T
M(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N(@IM<V=S='(@(D\@87)Q=6EV
M;R!D92!A:G5D82`E<R!P87)A("5S(&[C;R!E>&ES=&4@86EN9&$N($-R:6%N
M9&\@=6T@;F]V;RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S,W"FUS9VED(")4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")!
M(&5X=&5N<^-O($944"!NXV\@97-TX2!D:7-P;V[M=F5L+B(*"B,Z(&QI8B](
M;W)D92]+;VQA8BYP:'`Z.3`S"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!(
M;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R
M="!<(B5S7"(B"FUS9W-T<B`B3R!E;F=E;FAO(&1E(&EN=&5G<F'GXV\@2&]R
M9&4O2V]L86(@;N-O('-U<&]R=&$@7"(E<UPB(@H*(SH@;&EB+TYE="])35-0
M+T)O;VLN<&AP.C$R.30*;7-G:60@(E1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(D\@<F5G:7-T;R`H7")L;V=<(BD@
M24U34"!NXV\@</1D92!S97(@:6YI8VEA;&EZ861O+B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HR.0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")!(&-L
M87-S92!-86EN=&5N86YC93HZ(&[C;R!F;VD@8V%R<F5G861A(&-O;2!S=6-E
M<W-O(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM
M<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M(@IM<V=S='(@(D$@:F%N96QA(&1E($]PY_5E<R!F96-H;W4N(%-A[6YD;RXB
M"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$U."!L:6(O2&]R9&4O4&5R;7,N
M<&AP.C$V.2!L:6(O2&]R9&4O4&5R;7,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O
M4&5R;7,N<&AP.C$Y,B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(P,R!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(S,R!L
M:6(O2&]R9&4O4&5R;7,N<&AP.C(W,@IM<V=I9"`B(@HB5&AE(&%D;6EN:7-T
M<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I
M;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS
M+B(*;7-G<W1R("(B"B)/(&%D;6EN:7-T<F%D;W(@=&5M(&1E(&-O;F9I9W5R
M87(@=6T@;65C86YI<VUO(&1E('!E<FUI<W/U97,@<&5R;6%N96YT92!S92`B
M"B)Q=6ES97(@=7-A<B!097)M:7-S]65S+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H92!B
M;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(D%P96YA<R!O(&QA9&\@:6YF97)I
M;W(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS
M9VED("(B"B)4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I
M960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T
M86)A<V4N(@IM<V=S='(@(B(*(D\@;OIM97)O(&1E($E$(&1O(&-O;G1A8W1O
M(&[C;R!F;VD@97-P96-I9FEC861O+"!F;VD@9&5I>&%D;R!E;2!B<F%N8V\@
M;W4@(@HB;N-O(&9O:2!E;F-O;G1R861O(&YA(&)A<V4@9&4@9&%D;W,N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I9"`B
M5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D
M9')E<W,@8F]O:RXB"FUS9W-T<B`B3R!C;VYT86-T;R!F;VD@861I8VEO;F%D
M;R#@(&QI<W1A(&1E(&-O;G1A8W1O<R!C;VT@<W5C97-S;RXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,30Y"FUS9VED("(B"B)4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B)/(&)L;V-O(&1E(&%S
M<VEN871U<F$@4$=0(&1E<W1A8V%D;R#I(&YE8V5S<^%R:6\@<&%R82!V97)I
M9FEC87(@=6UA(&UE;G-A9V5M("(*(F%S<VEN861A+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#$*;7-G:60@(B(*(E1H92!D:7-T
M<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE
M9G0@8FQA;FL@;W(@;F]T(&9O=6YD("(*(FEN('1H92!D871A8F%S92XB"FUS
M9W-T<B`B(@HB3R!)1"!D82!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O
M:2!E<W!E8VEF:6-A9&\L(&9O:2!D96EX861O(&5M(&)R86YC;R!O=2`B"B)N
MXV\@9F]I(&5N8V]N=')A9&\@;F$@8F%S92!D92!D861O<RXB"@HC(&,M9F]R
M;6%T"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*;7-G
M:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"XB
M"FUS9W-T<B`B02!L:7-T82!D92!D:7-T<FEB=6GGXV\@;N-O(&9O:2!E<W!E
M8VEF:6-A9&$N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+G!H<#HQ,3,*;7-G:60@
M(E1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN(@IM<V=S='(@(D%S(&9U;F-I;VYA;&ED861E<R!D92!E
M;F-R:7!T8>?C;R!E>&EG96T@=6UA(&QI9V'GXV\@<V5G=7)A+B(*"B,Z(&QI
M8B](;W)D92YP:'`Z,3<U(&QI8B](;W)D92YP:'`Z-#@X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T
M=&EN9RXB"FUS9W-T<B`B3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R('5M
M(&%T<FEB=71O("5S+B(*"B,Z(&QI8B](;W)D92YP:'`Z,38X(&QI8B](;W)D
M92YP:'`Z-#<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(D\@87)Q
M=6EV;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U;G,@871R:6)U=&]S("5S+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,34R"FUS9VED(")4:&4@9FEL92!C86X@
M;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B3R!F:6-H96ER
M;R!NXV\@<&]D92!S97(@8V]P:6%D;R!P87)A('-I('!R\W!R:6\N(@H*(SH@
M;&EB+TAO<F1E+T1A=&$N<&AP.C(V,`IM<V=I9"`B5&AE(&9I;&4@8V]N=&%I
M;F5D(&YO(&1A=&$N(@IM<V=S='(@(D\@9FEC:&5I<F\@;N-O(&-O;G3I;2!D
M861O<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HV
M-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H
M:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B06)A:7AO(&5S
M=.-O(&]S(&-A8F7G86QH;W,@9&5S=&$@;65N<V%G96TO;65N<V%G96T@<F9C
M.#(R+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N
M('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U
M92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@
M=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@
M9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD
M;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN
M9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='
M96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O
M="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S
M<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N
M(&5D:71O<BXB"FUS9W-T<B`B(@HB3R!M;V1O(&1E(&5C<N,@:6YT96ER;R!C
M875S82!P<F]B;&5M87,@;F\@26YT97)N970@17AP;&]R97(L(&1E=FED;R!A
M(&5R<F]S("(*(FYO(&YA=F5G861O<B!Q=64@;N-O(&-O;G-E9W5I;6]S('5L
M=')A<&%S<V%R+B`@4&]D92!S=7)G:7(@;&EX;RP@<&]D96T@(@HB9&5S87!A
M<F5C97(@9G5N8VEO;F%L:61A9&5S(&1O(&5D:71O<B!E+V]U(&\@<V5U(&YA
M=F5G861O<B!P;V1E(&%B;W)T87(N(%-E("(*(F\@<V5U('-I<W1E;6$@Z2!U
M;2!7:6YD;W=S(#EX+"#I(&UU:71O('!R;W;A=F5L('%U92!O8G1E;FAA('5M
M("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&4@<')E8VES92!D92!R
M96EN:6-I87(@;R!S:7-T96UA+EQ<;EQ<;D9O:2!A=FES861O+B`@4&]R("(*
M(F9A=F]R('!R97-S:6]N92!/2R!S92!A:6YD82!A<W-I;2!Q=6ES97(@97AP
M97)I;65N=&%R(&\@961I=&]R(&1E(&5C<N,@(@HB:6YT96ER;RXB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y-R!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:&5L<"!F:6QE("5S(&1I9&XG
M="!S=&%R="!W:71H(#P_>&UL(@IM<V=S='(@(D\@9FEC:&5I<F\@9&4@86IU
M9&$@)7,@;N-O(&-O;67G82!C;VT@/#]X;6PB"@HC.B!S97)V:6-E<R]P<F5F
M<RYP:'`Z.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&ED96YT:71Y(%PB
M)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*;7-G<W1R(")!(&ED96YT:61A9&4@
M7"(E<UPB(&9O:2!R96UO=FED82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH
M86YD('-I9&4@;VYL>2(*;7-G<W1R(")!<&5N87,@;R!L861O(&5S<75E<F1O
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,30V"FUS9VED("(B"B)4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@HB02!L;V-A
M;&EZ8>?C;R!D;R!A<G%U:79O(&5X96-U=.%V96P@9&4@1VYU4$<@=&5M(&1E
M('-E<B!I;F1I8V%D82#@(&-L87-S92`B"B)#<GEP=%]P9W`Z.BXB"@HC.B!L
M:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N(@IM<V=S='(@(B(*(D$@;65N<V%G96T@96YV:6%D82!E;2`E
M<R!P87)A("5S(&-O;2!A<W-U;G1O(%PB)7-<(B!F;VD@;6]S=')A9&$N7&XB
M"B).XV\@:.$@9V%R86YT:6$@9&4@<75E(&$@;65N<V%G96T@=&5N:&$@<VED
M;R!R96%L;65N=&4@;&ED82!O=2!C;VUP<F5E;F1I9&$N(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-S@*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(")/(&YO;64@
M82!U<V%R('%U86YD;R!L:6=A;F1O(.`@<.%G:6YA(&1E(&-O;7!O<VGGXV\B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,S$*;7-G:60@(E1H
M92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R
M>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(D\@;?-D=6QO(&]P96YS<VP@
MZ2!N96-E<W/A<FEO('!A<F$@82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.BXB"@HC.B!L:6(O2&]R9&4O4')E9G,N<&AP.C(X-0HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM
M=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@HB02!O<.?C;R!<(B5S7"(@
M;N-O('#T9&4@<V5R(&=U87)D861A+"!P;VES(&]S('-E=7,@9&%D;W,@97AC
M961E;2!A(&1I;65N<^-O("(*(FWA>&EM82!P97)M:71I9&$B"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS,B!L:6(O2&]R9&4O34E-12]6
M:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]M<W!O=V5R<&]I;G0N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]M<W=O<F0N<&AP.C,R(&QI8B](;W)D92]-24U%+U9I97=E<B]R<&TN<&AP
M.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C<'`N<&AP.C,W"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R"B,L('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B(@HB3R!P<F]G<F%M82!U<V%D;R!P87)A('9E<B!E<W1E('1I
M<&\@9&4@9&%D;W,@*"5S*2!NXV\@9F]I(&5N8V]N=')A9&\@;F\@(@HB<VES
M=&5M82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<W"FUS9VED(")4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@
M;VYL>2(*;7-G<W1R(")!<&5N87,@;W,@;&%D;W,@97-Q=65R9&\@92!D:7)E
M:71O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM
M<V=S='(@(D%P96YA<R!O(&QA9&\@9&ER96ET;R(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]R<&-S=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(D\@<V5R
M=FED;W(@7"(E<UPB(&9O:2!R96UO=FED;RXB"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R
M=F5R(%PB)7-<(B!H87,@8F5E;B!S879E9"XB"FUS9W-T<B`B3R!S97)V:61O
M<B!<(B5S7"(@9F]I(&=U87)D861O+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(D\@<&5D:61O(&1E('-U
M8G-C<FGGXV\@9&4@)7,@9F]I(')E;6]V:61O+B(*"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C(Y,`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@
M9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D$@;&EN:&$@:6YD:6-A9&$@;N-O
M(&5X:7-T92XB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,3`X"B,L('!H<"UF;W)M
M870*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S7"(@9&]E<R!N;W0@
M97AI<W0N(@IM<V=S='(@(D\@87)Q=6EV;R!T96UP;W+A<FEO(%PB)7-<(B!N
MXV\@97AI<W1E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S
M:61E<R!O;FQY(@IM<V=S='(@(D%P96YA<R!O<R!L861O<R!S=7!E<FEO<B!E
M(&EN9F5R:6]R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX,`IM<V=I9"`B5&AE('1O<"!S:61E(&]N;'DB"FUS
M9W-T<B`B07!E;F%S(&\@;&%D;R!S=7!E<FEO<B(*"B,Z(&QI8B](;W)D92]$
M871A+G!H<#HS,#<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T
M('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")/<R!D861O<R!C
M87)R96=A9&]S('!E<F1E<F%M+7-E(&1E<V1E(&\@<&%S<V\@86YT97)I;W(N
M(@H*(SH@;&EB+TAO<F1E+T1A=&$O8W-V+G!H<#HR-#`@;&EB+TAO<F1E+T1A
M=&$O='-V+G!H<#HQ-S(*;7-G:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD
M(&YO="!B92!S879E9"XB"FUS9W-T<B`B3R!A<G%U:79O(&-A<G)E9V%D;R!N
MXV\@</1D92!S97(@9W5A<F1A9&\N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C0X(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,#D*
M;7-G:60@(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")/(&)L;V-O('=E871H97(N8V]M(&[C;R!E<W3A(&1I<W!O
M;NUV96PN(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@
M(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B3N-O
M(&CA(&]PY_5E<R!D:7-P;V[M=F5I<RXB"@HC.B!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z,S0Q"FUS9VED(")4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB"FUS9W-T<B`B3N-O(&CA('!A
M<G1E<R!Q=64@<&]S<V%M('-E<B!M;W-T<F%D87,@96T@;&EN:&$N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(DCA(&1E;6%S:6%D
M;W,@8V%R86-T97)E<R!N97-T92!C86UP;RX@26YT<F]D=7II=2`E<R!C87)A
M8W1E<F5S.R!T96T@9&4@(@HB:6YT<F]D=7II<B!M96YO<R!D;R!Q=64@)7,N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$P-C`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@9&]E<VXG="!Y970@97AI<W0@82!H96QP(&9I;&4@9F]R
M("5S+B(*;7-G<W1R(").XV\@97AI<W1E(&%I;F1A('5M(&%R<75I=F\@9&4@
M86IU9&$@<&%R82`E<RXB"@HC.B!S:6=N=7`N<&AP.C4S(&%D;6EN+W5S97(N
M<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L
M96T@861D:6YG(%PB)7-<(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R(")/
M8V]R<F5U('5M('!R;V)L96UA(&YA(&%D:>?C;R!D92!<(B5S7"(@86\@<VES
M=&5M83H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,C(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O
M<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(B"B)/
M8V]R<F5U('5M('!R;V)L96UA(&%O(&QI;7!A<B!O<R!D861O<R!D;R!U=&EL
M:7IA9&]R(%PB)7-<(B!D;R!S:7-T96UA+B(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R(")/
M8V]R<F5U('5M('!R;V)L96UA(&YA(')E;6_GXV\@9&4@7"(E<UPB(&1O('-I
M<W1E;6$N(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E
M<R(*;7-G<W1R(")/8V]R<F5U('5M('!R;V)L96UA(&%O(&%C='5A;&EZ87(@
M7"(E<UPB.B`E<RXB"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#@X"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T
M:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"XB"FUS9W-T<B`B
M(@HB2&]U=F4@=6T@<')O8FQE;6$@8V]M(&\@8V%R<F5G86UE;G1O(&1O(&9I
M8VAE:7)O.B`E<R!NXV\@9F]I(&-A<G)E9V%D;RXB"@HC.B!L:6(O2&]R9&4O
M0G)O=W-E<BYP:'`Z.#DS"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN(@IM<V=S='(@(B(*(D]C;W)R974@=6T@<')O8FQE;6$@8V]M
M(&\@8V%R<F5G86UE;G1O(&1O(&%R<75I=F\Z($\@)7,@97AC961E(&\@=&%M
M86YH;R`B"B)MX7AI;6\@<&5R;6ET:61O("@E9"!B>71E<RDN(@H*(SH@;&EB
M+TAO<F1E+T)R;W=S97(N<&AP.C@Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B
M"B)/8V]R<F5U('5M('!R;V)L96UA(&-O;2!O(&-A<G)E9V%M96YT;R!D;R!A
M<G%U:79O.B!/("5S(&9O:2!A<&5N87,@(@HB<&%R8VEA;&UE;G1E(&-A<G)E
M9V%D;RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HS
M-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`B3V-O<G)E=2!U;2!E<G)O(&%O(&UO<W1R
M87(@97-T82!P87)T92!D82!M96YS86=E;2(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,SD@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R(")/8V]R<F5U('5M(&5R<F\@
M86\@:6UP;W)T87(@9&%D;W,@9&4@8V]N=&%C=&\N(@H*(SH@;&EB+TAO<F1E
M+T1A=&$O:6UC+G!H<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(D]C;W)R974@
M=6T@97)R;R!A;R!I;7!O<G1A<B!D861O<R!I0V%L96YD87(N(@H*(SH@861M
M:6XO<V5T=7`O8V]N9FEG+G!H<#HW.0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(D]C
M;W)R974@=6T@97)R;R!N;R!F;W)M=6SA<FEO(&1E(&-O;F9I9W5R8>?C;RX@
M5&%L=F5Z('1E;FAA(&]M:71I9&\@=6T@8V%M<&\@(@HB;V)R:6=A=/-R:6\N
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,#<@<&\O=')A;G-L871I;VXN
M<&AP.C$Q,3,@<&\O=')A;G-L871I;VXN<&AP.C$R-#4*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C$R-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R(&]P96YI;F<@=&AE(&9I;&4@)7,N(%1R>2!R=6YN:6YG
M('1R86YS;&%T:6]N+G!H<"!W:71H('1H92`B"B)F;&%G("UD('1O('-E92!A
M;GD@97)R;W(@;65S<V%G97,@9G)O;2!T:&4@>&UL('!A<G-E<BXB"FUS9W-T
M<B`B(@HB3V-O<G)E=2!U;2!E<G)O(&%O(&%B<FER(&\@87)Q=6EV;R`E<RX@
M17AP97)I;65N=&4@97AE8W5T87(@=')A;G-L871I;VXN<&AP("(*(F-O;2!A
M(&]PY^-O("UD('!A<F$@8V]N<V5G=6ER('9E<B!A<R!M96YS86=E;G,@9&4@
M97)R;R!D;R!A;F%L:7-A9&]R(%A-3"XB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,X"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB
M3V-O<G)E=2!U;2!E<G)O(&%O(')E86QI>F%R(&$@9G5NY^-O(&1E(&QI=G)O
M(&1E(&5N9&5R9>=O<R!E<W!E8VEF:6-A9&$N(%!O<B`B"B)F879O<B!T96YT
M92!D92!N;W9O(&UA:7,@=&%R9&4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C8T,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(B(*(D]C;W)R974@=6T@97)R;R!A;R!A8W1U
M86QI>F%R(&]S('!O<FUE;F]R97,@9&\@8V]N=&%C=&\N(%!O<B!F879O<B!T
M96YT92!D92`B"B)N;W9O(&UA:7,@=&%R9&4N(@H*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8T-0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E
M('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HB3V-O<G)E=2!U;2!E<G)O
M(&%O(&%C='5A;&EZ87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(%!O<B!F
M879O<B!T96YT92!D92`B"B)N;W9O(&UA:7,@=&%R9&4N(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`IM<V=I9"`B5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RXB"FUS
M9W-T<B`B17-T92!S97)V:61O<B!)34%0(&[C;R!S=7!O<G1A('!A<G1I;&AA
M(&1E('!A<W1A<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H
M<#HT.`IM<V=I9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!R87(@87)C:&EV92XB"FUS9W-T<B`B3N-O('!A<F5C92!S97(@=6T@87)Q
M=6EV;R!R87(@=N%L:61O+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z
M:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+B(*;7-G<W1R(").XV\@<&%R96-E('-E<B!U;2!A
M<G%U:79O('II<"!VX6QI9&\N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M-#0*;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+B(*;7-G<W1R(").XV\@<&%R96-E('-E<B!U;6$@;OIM97)O
M(&1E(&-A<G3C;R!VX6QI9&\N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HQ.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A4
M5%`@05!)(@IM<V=S='(@(B(*(D5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O
M(&5N=FEO(&1E(&UE;G-A9V5N<R!A=')A=NES(&1O($-L:6-K871E;&P@*&AT
M='`Z+R\B"B)C;&EC:V%T96QL+F-O;2DL('5S86YD;R!A($%022!(5%10(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B
M(@HB5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D5S=&4@
M8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO(&1E(&UE;G-A9V5N<R!A=')A
M=NES(&1O('-M<S)M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2DL('5S
M86YD;R!A($%022!(5%10(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L
M>5]S;71P+G!H<#HX-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O
M;F4@271A;'D@(@HB9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@(@HB5F]D869O
M;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2XB"FUS9W-T<B`B(@HB17-T
M92!C;VYT<F]L861O<B!P97)M:71E(&\@96YV:6\@9&4@;65N<V%G96YS('9I
M82!33510(&%T<F%VZ7,@9&$@5F]D869O;F4@(@HB273A;&EA(&4@87!E;F%S
M('!A<F$@;OIM97)O<R!6;V1A9F]N92X@17AI9V4@=6UA(&-O;G1A(&1E(&-O
M<G)E:6\@(@HB96QE8W1R\VYI8V\@;F$@5F]D869O;F4@273A;&EA("AH='1P
M.B\O=W=W+C$Y,"YI="DN(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDW."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3`U-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,3`X
M-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Q-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3$X,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(U-@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3,P-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,30P,"!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,34U.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@T,"!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3DU.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`P
M-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`S,"!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C`W.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$U,`HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(R,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0P.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0U,PHC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C8U-B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@R-R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S
M-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S<R,R!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S<S,0IM<V=I9"`B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB"FUS9W-T
M<B`B17-T92!C86UP;R#I(&]B<FEG873S<FEO+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@:6YT96=E<G,N(@IM<V=S='(@(D5S=&4@8V%M<&\@<&]D92!C;VYT97(@
M87!E;F%S(&EN=&5I<F]S+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#$W
M"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A
M;F0@=&AE(&-O;&]N+B(*;7-G<W1R(")%<W1E(&-A;7!O('!O9&4@87!E;F%S
M(&-O;G1E<B!N^FUE<F]S(&4@;R!S[6UB;VQO(&1O:7,M<&]N=&]S+B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DT"FUS9VED(")4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+B(*;7-G<W1R(")%<W1E(&-A
M;7!O('!O9&4@8V]N=&5R(&%P96YA<R!V86QO<F5S(&]C=&%I<RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3$R,PIM<V=I9"`B5&AI<R!F:65L9"!M=7-T
M(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E
M<G,B"FUS9W-T<B`B(@HB17-T92!C86UP;R!T96T@9&4@8V]N=&5R('5M82!L
M:7-T82!D92!I;G1E:7)O<R!S97!A<F%D;W,@<&]R(&5S<&'G;W,@;W4@(@HB
M=NUR9W5L87,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDX.0IM<V=I9"`B
M5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+B(*;7-G<W1R(")%
M<W1E(&-A;7!O('1E;2!D92!S97(@=6T@;OIM97)O(';A;&ED;RXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"B)%<W1E
M(&-A;7!O('1E;2!D92!C;VYT97(@=6T@8_-D:6=O(&1E(&-O<B!N;R!F;W)M
M871O(%)'0B!H97AA9&5C:6UA;"P@<&]R("(*(F5X96UP;&\@)R,Q,C,T868G
M+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HU-C$*;7-G:60@(E1H:7,@9F]R
M;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"XB"FUS9W-T<B`B17-T92!M
M;V1E;&\@:N$@9F]I('!R;V-E<W-A9&\N(@H*(SH@=&5M<&QA=&5S+VAE;'`O
M86)O=70N:6YC.C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB
M"FUS9W-T<B`B27-T;R#I("5S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z
M-#,W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"B)%
M<W1E(.D@=6T@;V)J96-T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R(&5S
M=&4@;V)J96-T;R!P<F5C:7-A(&1E('5M("(*(F-L:65N=&4@9&4@8V]R<F5I
M;R!E;&5C='+S;FEC;R!Q=64@8V]N:&7G82!O(&9O<FUA=&\@2V]L86(@1W)O
M=7!W87)E+B!087)A("(*(G5M82!L:7-T82!D92!C;&EE;G1E<R!D92!C;W)R
M96EO(&5L96-T<O-N:6-O(&YE<W-A<R!C:7)C=6YS=.)N8VEA<R!V:7-I=&4@
M)7,B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z-3@X"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A
M(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G
M<W1R(")%<W1A(&UE;G-A9V5M(&9O:2!E<V-R:71A(&YU;2!C\V1I9V\@*"5S
M*2!D:69E<F5N=&4@9&\@<V5U+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N
M92XB"FUS9W-T<B`B17-T92!N^FUE<F\@<')E8VES82!D92!S97(@<&5L;R!M
M96YO<R!U;2XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,P-`IM<V=I9"`B
M5&AI<R!S8W)I<'0@;75S="!B92!R=6X@9G)O;2!T:&4@8V]M;6%N9"!L:6YE
M+B(*;7-G<W1R(")%<W1E(%PB<V-R:7!T7"(@=&5M('-E<B!E>&5C=71A9&\@
M82!P87)T:7(@9&4@=6UA(&QI;FAA(&1E(&-O;6%N9&]S+B(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]G>FEP+G!H<#HT-0IM<V=I9"`B5&AI<R!S97)V97(@
M8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N(@IM<V=S='(@
M(D5S=&4@<V5R=FED;W(@;N-O(&-O;G-E9W5E(&1E<V-O;7!R:6UI<B!A<G%U
M:79O<R!Z:7`@;W4@9WII<"XB"@HC.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$T-PIM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R(")%<W1E('-I<W1E;6$@96YC;VYT<F$M<V4@9&5S86-T
M:79A9&\N(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C0*;7-G:60@
M(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B17-T82!V
M86QO<B!T96T@9&4@<V5R('5M(&[Z;65R;RXB"@HC.B!S97)V:6-E<R]I;6%G
M97,O8V]L;W)P:6-K97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T
M(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(D5S
M=&$@:F%N96QA('1E;2!D92!S97(@8VAA;6%D82!A('!A<G1I<B!D92!U;6$@
M:F%N96QA(&1E($]PY_5E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R(@IM<V=S='(@(E1R;W9O
M861A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R,@IM<V=I9"`B
M5&EC:V5T<R(*;7-G<W1R(")":6QH971E<R(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-#(W"FUS9VED(")4:6UE(@IM<V=S='(@(D1A=&$O2&]R82(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#@*;7-G:60@(E1I;64@5')A
M8VMI;F<B"FUS9W-T<B`B4V5G=6EM96YT;R!496UP;W)A;"(*"B,Z(&QI8B]"
M;&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F;W)M870B"FUS9W-T<B`B
M1F]R;6%T;R!D;R!T96UP;R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3,X
M"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")396QE8^?C;R!D871A
M+VAO<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,C(*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R(")4:6UO<BU,
M97-T92(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R
M(")4[71U;&\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDV"FUS9VED(")4:71L92`H=&]O;'1I<"DZ(@IM<V=S='(@(E3M
M='5L;R`H9&EC82DZ(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S4*;7-G:60@(E1O(@IM<V=S='(@(E!A<F$B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(V"FUS9VED("(B"B)4;R!S
M96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H
M4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y("(*(G=H:6QE(&-L:6-K:6YG+B(*
M;7-G<W1R("(B"B)087)A('-E;&5C8VEO;F%R(&WZ;'1I<&QO<R!I=&5N<RP@
M8V%R<F5G=64@96T@0V]N=')O;"`H4$,I(&]U($-O;6UA;F0@*$UA8RD@(@HB
M96YQ=6%N=&\@8VQI8V%R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3D*;7-G:60@(E1O9&%Y(@IM<V=S='(@(DAO:F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4
M;V=G;&4@2%1-3"!3;W5R8V4B"FUS9W-T<B`B5')O8V%R($9O;G1E($A434PB
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(S(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`Y"FUS9VED(")4;V=O(@IM<V=S='(@(E)E</IB;&EC82!4;V=O;&5S82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3`*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B5&]Q=65L874B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`Q"FUS9VED(")4;VUO<G)O=R(*
M;7-G<W1R(")!;6%N:.,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(Y
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G<W1R(")296EN
M;R!D;R!4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(E1O<&\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS
M9VED(")4;W`@9G)A;64@*%]T;W`I(@IM<V=S='(@(DUO;&1U<F$@9&4@=&]P
M;R`H7W1O<"DB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C4W"FUS9VED(")4
M<F%N<VQA=&5D(@IM<V=S='(@(E1R861U>FED87,B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R(")4
M<F%D=>?U97,B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Q"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S
M='(@(E1R:6YD861E(&4@5&]B86=O(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$W.3$*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B5F5R9&%D96ER
M;R!O=2!F86QS;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3<*;7-G:60@(E1U(@IM<V=S='(@(C.J(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C(W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B
M5'5N:7-I82(*;7-G<W1R(")297#Z8FQI8V$@9&$@5'5N[7-I82(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(R.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G
M:60@(E1U<FME>2(*;7-G<W1R(")297#Z8FQI8V$@9&$@5'5R<75I82(*"B,Z
M(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M
M.#@U.2TY*2(*;7-G<W1R(")4=7)C;R`H25-/+3@X-3DM.2DB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,C(W(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR,CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED
M(")4=7)K;65N:7-T86XB"FUS9W-T<B`B5'5R<75E;65N:7-TXV\B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(P(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR,S`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS
M9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B26QH87,@
M5'5R8V%S(&4@0V%I8V]S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@(E1U
M=F%L=2(*"B,Z(&QI8B](;W)D92]#3$DN<&AP.C(V-`IM<V=I9"`B5'EP92!Y
M;W5R(&-H;VEC93H@(@IM<V=S='(@(D5S8W)E=F$@82!S=6$@97-C;VQH83HB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4W"FUS9VED(")5
M+E8N(&EN9&5X.B`B"FUS9W-T<B`BS6YD:6-E(%4N5BXZ("(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C0Y(&QI8B]";&]C:R]I9G)A
M;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T<B`B55),(@H*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y
M;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(E52
M3"!D;R!S974@<F5L873S<FEO(&1E(&5S=&%D;R!D;R!E;G9I;R!D92!<(G-C
M<FEP='-<(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.3<*;7-G:60@(E523#HB"FUS9W-T<B`B55),.B(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(S,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@
M(E5G86YD82(*;7-G<W1R(")297#Z8FQI8V$@9&\@56=A;F1A(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,@IM<V=I
M9"`B56MR86EN92(*;7-G<W1R(")58W+B;FEA(@H*(SH@;&EB+U9&4R]F:6QE
M+G!H<#HS,S4*;7-G:60@(E5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R
M>2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!A8V5D97(@X"!P87-T82!6
M1E,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HY-@IM<V=I9"`B
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"XB"FUS9W-T<B`B(@HB3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N
M87(@:6YF;W)M8>?C;R!D92!U=&EL:7IA9&]R(&5X=')A(&%Q=6%N9&\@9&$@
M(@HB<W5B<V-R:>?C;RXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z,S(V"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F
M;W(@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L
M(&UU9&%R(&%S('!E<FUI<W/U97,@9&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S`X(&QI8B]61E,O;75S<6PN<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&UU9&%R(&%S('!E<FUI<W/U97,@9&\@87)Q=6EV;R!61E,@)7,O
M)7,N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8W,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&UU9&%R('!A<F$@)7,N(@H*(SH@;&EB+TAO<F1E+T%U=&@O
M<W%L+G!H<#HS-S$*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@;&EG87(@86\@<V5R
M=FED;W(@4U%,+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW-38*;7-G:60@(E5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R(").XV\@9F]I('!O
M<W/M=F5L(&QI9V%R('5S86YD;R!34TPN(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HQ-3@@;&EB+U9&4R]F:6QE+G!H<#HQ-C,@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,3@X"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$Y,R!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HR,#$*;7-G:60@(E5N86)L92!T;R!C;W!Y(%9&4R!F:6QE
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-O<&EA<B!O(&%R<75I=F\@
M5D93+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,#,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!A('!A<W1A(%9&4R!<
M(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR-S<@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C4X(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(T.`IM<V=I9"`B56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93+B(*"B,Z(&QI8B]61E,O;75S
M<6PN<&AP.C$R-`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB
M"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!O(&%R<75I=F\@5D93
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,3DX"FUS9VED(")5;F%B;&4@=&\@
M8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&-R:6%R('5M(&%R<75I=F\@5D93('9A>FEO+B(*"B,Z(&QI8B](;W)D
M92]#;VUP<F5S<R]T87(N<&AP.C<V(&QI8B](;W)D92]#;VUP<F5S<R]G>FEP
M+G!H<#HW.0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS
M9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!D97-C;VUP<FEM:7(@;W,@9&%D;W,N
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C(S-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!<
M(B5S7"(L('!O:7,@82!P87-T82!NXV\@97-TX2!V87II82XB"@HC.B!A9&UI
M;B]G<F]U<',N<&AP.C<Y(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3D*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S
M+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;6]V97(@7"(E<UPB.B`E
M<RXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(U-"!L:6(O5D93+W-Q;"YP:'`Z
M,S$T(&QI8B]61E,O;75S<6PN<&AP.C,Q,0HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R("5S+"!P;VES(&$@<&%S=&$@;N-O(&5S
M=.$@=F%Z:6$B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-#`@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(D[C;R!F;VD@<&]S
M<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4R!R96-U<G-I=F%M96YT92XB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C(V,"!L:6(O5D93+VUU<W%L+G!H<#HS,C(@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,S,U"B,Z(&QI8B]61E,O;75S<6PN<&AP.C,T
M,R!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS,S8*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R(&$@<&%S=&$@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS
M,SD@;&EB+U9&4R]S<6PN<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(").
MXV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,Z("5S+B(*"B,Z
M(&QI8B]61E,O9G1P+G!H<#HQ-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B!O(&%R<75I=F\@5D93(%PB)7-<(BXB"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C(R-B!L:6(O5D93+W-Q;"YP:'`Z,C$P(&QI
M8B]61E,O;75S<6PN<&AP.C$V-PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#`@
M;&EB+U9&4R]M=7-Q;"YP:'`Z,3@W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W
M,`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS-S@*;7-G:60@(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@
M<F5M;W9E<B!O(&%R<75I=F\@5D93+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HS
M,C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E
M;6]V97(@<F5C=7)S:79A;65N=&4Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HW,C`*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E
M8W1O<GDN(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@9&5T97)M:6YA<B!A
M('!A<W1A(&-O<G)E;G1E+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C`S"FUS9VED(")5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D
M971A:6QS(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97AT<F%I<B!O<R!P
M;W)M96YO<F5S(&1O(&-E<G1I9FEC861O(@H*(SH@;&EB+TYE="])35-0+G!H
M<#HT-3$@;&EB+TYE="])35-0+T%U=&@N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB
M"FUS9W-T<B`B26UP;W-S[79E;"!L97(@82!D969I;FGGXV\@9&4@)7,N(@H*
M(SH@;&EB+U9&4R]F:6QE+G!H<#HQ,CD@;&EB+U9&4R]F:6QE+G!H<#HQ,S0@
M;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,34X"B,Z(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$V,PIM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM<V=S
M='(@(D[C;R!F;VD@<&]S<^UV96P@;6]V97(@;R!A<G%U:79O(%9&4RXB"@HC
M.B!L:6(O5D93+V9T<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C`U(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$R,B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,C4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+B(*;7-G<W1R(").XV\@9F]I('!O<W/M
M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,@<&%R82!E<V-R:71A+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-C<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&%B<FER(&\@87)Q=6EV;R!61E,N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@(E5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!A8G)I<B!O(&%R<75I=F\@8V]M<')I;6ED;RXB"@HC.B!L:6(O2&]R9&4O
M4V5S<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R
M96%D(&9I;&4Z("(*;7-G<W1R(").XV\@8V]N<VEG;R!L97(@;R!A<G%U:79O
M.B`B"@HC.B!L:6(O5D93+V9I;&4N<&AP.C4Y,@IM<V=I9"`B56YA8FQE('1O
M(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(").XV\@9F]I
M('!O<W/M=F5L(&QE<B!A('!A<W1A('9F<W)O;W0N(@H*(SH@;&EB+TAO<F1E
M+TMO;&%B+G!H<#HQ,#8W"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y
M(&5X:7-T<R(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(')E;F]M96%R("5S
M(&-O;6\@)7,Z(&$@<&%S=&$@9&4@9&5S=&EN;R!JX2!E>&ES=&4B"@HC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HR.#4*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E;"!R
M96YO;65A<B!A('!A<W1A(%9&4RXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C4Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5N;VUE
M87(@82!P87-T82!61E,Z("5S+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR.#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@
M;R!A<G%U:79O(%9&4R!<(B5S7"(N(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HU
M,S,@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(D[C
M;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@;R!A<G%U:79O(%9&4R`E<R\E<RXB
M"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,C0U(&QI8B]61E,O;75S<6PN<&AP.C(Q
M,R!L:6(O5D93+VUU<W%L+G!H<#HT-3(*(SH@;&EB+U9&4R]S<6Q?9FEL92YP
M:'`Z,C<W(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,PIM<V=I9"`B56YA8FQE
M('1O(')E;F%M92!61E,@9FEL92XB"FUS9W-T<B`B3N-O(&9O:2!P;W-S[79E
M;"!R96YO;65A<B!A<G%U:79O(%9&4RXB"@HC.B!L:6(O5D93+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`IM<V=I9"`B56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV96P@97AE8W5T87(@)VUK:7-O
M9G,G+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y
M"FUS9VED(")5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M="(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&-O;G9E<G1E<B!E<W1E(&1O
M8W5M96YT;R!7;W)D(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$R,B!L:6(O5D93
M+V9T<"YP:'`Z,3(U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W
M<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(D[C;R!F;VD@<&]S<^UV
M96P@97-C<F5V97(@87)Q=6EV;R!61E,@7"(E<UPB+B(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,3$R"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M*&-O<'DH*2!F86EL960I+B(*;7-G<W1R(").XV\@9F]I('!O<W/M=F5L(&5S
M8W)E=F5R(&\@87)Q=6EV;R!61E,@*&-O<'DH*2!F86QH;W4I+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z,C`Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S,"!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S4*;7-G:60@(E5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+B(*;7-G<W1R(").XV\@8V]N<VEG;R!R96UO=F5R
M("<E<R<Z("5S+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R(")3=6)L:6YH
M861O(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD
M;R!#:&%N9V5S(@IM<V=S='(@(D1E<V9A>F5R($%L=&5R8>?U97,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED
M(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R(")$97-F87H@82!S
M=6$@^FQT:6UA(&%CY^-O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP
M"FUS9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ("(*;7-G<W1R(")297-P;W-T82!I;F5S<&5R861A(&1O('-E
M<G9I9&]R(&YA(&-O;F5XXV\Z("(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HR,3D@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,T,0HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<X(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#0*;7-G:60@(E5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")297-P
M;W-T82!I;F5S<&5R861A(&1O('-E<G9I9&]R(&$Z("(*"B,Z(&QI8B](;W)D
M92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8T"FUS9VED(")5;F9I;&5D
M(@IM<V=S='(@(E-E;2!C871E9V]R:6$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,PIM<V=I9"`B56YI8V]D92`H551&+3@I(@IM<V=S='(@(E5N:6-O
M9&4@*%541BTX*2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-R!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4V"FUS9VED(")5;FET960@07)A8B!%;6ER871E<R(*;7-G
M<W1R(")%;6ER861O<R#!<F%B97,@56YI9&]S(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(S."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")5;FET960@
M2VEN9V1O;2(*;7-G<W1R(")296EN;R!5;FED;R(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5N:71E
M9"!3=&%T97,B"FUS9W-T<B`B17-T861O<R!5;FED;W,@9&$@06WI<FEC82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,SD@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD
M<R(*;7-G<W1R("));&AA<R!-96YO<F5S($1I<W1A;G1E<R!D;W,@17-T861O
M<R!5;FED;W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C$@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B
M56YI9&%D97,B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3@@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#$Y"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C4X"FUS9VED(")5;FMN;W=N(@IM<V=S='(@(D1E<V-O
M;FAE8VED;R(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,CDX"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M(@IM<V=S='(@(F%P:6US9VED("A)1"!D92!-96YS86=E;2!D92!!4$DI+B(*
M"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED
M(")5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S
M='(@(F-L:6US9VED(&1E<V-O;FAE8VED;R`H240@9&4@365N<V%G96T@9&4@
M0VQI96YT92DN(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$U,#$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YK;F]W;B!C;VUM86YD.B`E<R(*;7-G<W1R(")#
M;VUA;F1O(&1E<V-O;FAE8VED;SH@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,30V"FUS9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+B(*;7-G<W1R(")&;VD@9F]R;F5C:61A('5M82!L;V-A;&EZ8>?C;R!D
M97-C;VYH96-I9&$N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR.3$*;7-G:60@(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M(@IM<V=S='(@(DYO;64@9&4@=71I;&EZ861O<B!O=2!P86QA=G)A+7!A<W-E
M(&5R<F%D;W,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(E5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT(@IM<V=S='(@(E)E;6]V97(@;&EG8>?C;R!D;R!E;&5M96YT;R!C
M;W)R96YT92(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,CDV"FUS9VED
M(")5;FYA;65D(@IM<V=S='(@(E-E;2!N;VUE(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU.0IM<V=I9"`B(@HB56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R("(*(G-E8W5R:71Y(')E87-O;G,N("!#;&EC
M:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W
M:&EC:"`B"B)S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C
M8V5S<R!T:&4@8VQI<&)O87)D+B(*;7-G<W1R("(B"B)0;W(@<F%Z]65S(&1E
M('-E9W5R86[G82P@7")S8W)I<'1S7"(@<V5M('!R:79I;.EG:6\@;N-O('!O
M9&5M(&%C961E<B!A("(*(D-O<G1A<B]#;W!I87(O0V]L87(@<')O9W)A;6%T
M:6-A;65N=&4N($-A<G)E9W5E(&5M($]+('!A<F$@=F5R('5M82!N;W1A("(*
M(G3I8VYI8V$@96T@;6]Z:6QL82YO<F<@<75E(&QH92!M;W-T<F%RX2!C;VUO
M(&%U=&]R:7IA<B!U;2!<(G-C<FEP=%PB(&$@(@HB86-E9&5R(&%O<R!R96-O
M<G1E<RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*;7-G<W1R(")296UO
M=F5R(&-O;&]R8>?C;R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C@V(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U<'!O<G1E9"!%>'1E
M;G-I;VXB"FUS9W-T<B`B17AT96YSXV\@;N-O(%-U<&]R=&%D82(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@(E5N=')A;G-L871E9"(*;7-G
M<W1R(")0;W(@=')A9'5Z:7(B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.#,*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*;7-G<W1R(")-
M;V1I9FEC87(B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*;7-G<W1R(")!
M8W1U86QI>F%R("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHT,PIM<V=I9"`B57!D871E('5S97(B"FUS9W-T<B`B06-T=6%L:7IA
M<B!U=&EL:7IA9&]R(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ,S<@861M:6XO
M<&5R;7,O961I="YP:'`Z,C$W('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR
M,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S
M='(@(EPB)7-<(B!A8W1U86QI>F%D;RXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3`Y,B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")5<&1A=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+B(*;7-G<W1R
M(")!8W1U86QI>F%N9&\@87)Q=6EV;R!D92!A:G5D82`E<R!P87)A("5S+B(*
M"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Q"FUS9VED(")5<&=R861E
M('-C<FEP="!D96QE=&5D+B(*;7-G<W1R(")<(E-C<FEP=%PB(&1E(&%C='5A
M;&EZ8>?C;R!R96UO=FED;RXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3@Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#(*;7-G
M:60@(E5P;&]A9"(*;7-G<W1R(")5<&QO860B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3@Y"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I;VX@
M<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B0V%R<F5G861O
M<R!N;R!S97)V:61O<B!T;V1O<R!O<R!A<G%U:79O<R!D92!I;G-T86QAY^-O
M(&1E(&%P;&EC8>?U97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@
M;&5T=&5R<R(*;7-G<W1R("),971R87,@;&%T:6YA<R!E;2!M86GZ<V-U;&%S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?
M;&%N9RYJ<SHQ.`IM<V=I9"`B57!P97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R
M(").^FUE<F]S(')O;6%N;W,@96T@;6%I^G-C=6QA<R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R
M=6=U87DB"FUS9W-T<B`B4F5P^F)L:6-A($]R:65N=&%L(&1O(%5R=6=U86DB
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S4@<&\O=')A;G-L871I;VXN<&AP
M.CDR('!O+W1R86YS;&%T:6]N+G!H<#HY,PIM<V=I9"`B57-A9V4Z(@IM<V=S
M='(@(E5T:6QI>F'GXV\Z(@H*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G;W)Y
M36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E
M;G0Z("5S(@IM<V=S='(@(E5S87(@;R!#;W)R96YT93H@)7,B"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,
M(@IM<V=S='(@(E5S87(@4U-,+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ,C0*;7-G:60@(E5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N
M="!F;W(@24U34"!S97)V97(N(@IM<V=S='(@(B(*(E5S87(@<V4@;R!N;VUE
M(&1E('5T:6QI>F%D;W(@;W4@82!P86QA=G)A+7!A<W-E(&9O<F5M(&1I9F5R
M96YT97,@;F\@<V5R=FED;W(@(@HB24U34"XB"@HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C8Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES
M(&YO="!A=71H;W)I<V5D(&9O<B`E<RXB"FUS9W-T<B`B571I;&EZ861O<B`E
M<R!NXV\@97-TX2!A=71O<FES861O('!A<F$@)7,N(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,C`S"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(D%D;6EN:7-T<F'GXV\@9&4@571I;&EZ861O<F5S(@H*(SH@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M(")/<.?U97,@9&\@571I;&EZ861O<B(*"B,Z('-I9VYU<"YP:'`Z-C(*;7-G
M:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@(E)E9VES=&\@9&4@571I
M;&EZ861O<F5S(@H*(SH@<VEG;G5P+G!H<#HR,@IM<V=I9"`B57-E<B!296=I
M<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS
M9W-T<B`B3R!296=I<W1O(&1E(%5T:6QI>F%D;W)E<R!E<W3A(&EN86-T:79O
M+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$W,B!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(T-@IM<V=I9"`B57-E<B!P97)M:7-S:6]N<R(*;7-G<W1R
M(")097)M:7-S]65S(&1O('5T:6QI>F%D;W(B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HS-2!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3@R"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU,S8@;&EB+TYE="]335,O=F]D869O;F5I
M=&%L>5]S;71P+G!H<#HY.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C$Y."!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS,PHC.B!T
M96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8X('1E;7!L871E<R]A9&UI;B]U
M<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M92(*;7-G<W1R(").
M;VUE(&1E(%5T:6QI>F%D;W(B"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N
M<&AP.C$R-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@
M86QR96%D>2!E>&ES=',N(@IM<V=S='(@(D\@3F]M92!D92!5=&EL:7IA9&]R
M(%PB)7-<(B!JX2!E>&ES=&4N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B3F]M92!D92!5
M=&EL:7IA9&]R.B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*
M;7-G:60@(E5S97)N86UE.B`B"FUS9W-T<B`B3F]M92!D92!5=&EL:7IA9&]R
M.B`B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Q.0IM<V=I9"`B57-E
M<G,B"FUS9W-T<B`B571I;&EZ861O<F5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,@IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB
M"FUS9W-T<B`B571I;&EZ861O<F5S(&1O('-I<W1E;6$Z(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B
M57IB96MI<W1A;B(*;7-G<W1R(")297#Z8FQI8V$@9&\@57IB97%U:7-TXV\B
M"@HC.B!L:6(O5D93+V9I;&4N<&AP.C$P,2!L:6(O5D93+V9I;&4N<&AP.C$X
M.`IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B02!P87-T82!61E,@;N-O(&5X:7-T92XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,3$X"FUS9VED(")686-A=&EO;B(*;7-G<W1R(")!=7/J
M;F-I82(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B07,@;&]C86QI
M>F'G]65S(';A;&ED87,@96YC;VYT<F%D87,@:6YC;'5E;3HB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS
M9W-T<B`B5F%L:61A9&4N(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C4Y-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U
M-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B
M5F%L;W(@96T@;6EN=71O<R!A('!A<G1I<B!D97-T92!I;G-T86YT92XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.#4V(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE(&UA
M>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R(")686QO<B!E>&-E9&4@;R!C
M;VUP<FEM96YT;R!MX7AI;6\@9&4@)7,N(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(R-#4@;&EB+TAO<F1E+T9O<FTN<&AP.C(R-C<@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(S,34*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,C<*;7-G:60@
M(E9A;'5E<R(*;7-G<W1R(")686QO<F5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C(Q,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q.#<*;7-G:60@(E9A;'5E
M<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R(")0;W-S[79E;"!V86QO<F5S(&$@
M97-C;VQH97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM<V=S='(@(E9A;G5A='4B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,R"FUS9VED(")6
M87)I86)L92(*;7-G<W1R(")687)IX79E;"(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L
M82(*;7-G<W1R(")696YE>G5E;&$B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@
M;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@
M(E9E<FEF:6-AY^-O(&9A;&AO=2`M(&5S=&$@;65N<V%G96T@<&]D92!T97(@
M<VED;R!A9'5L=&5R861A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S`P"FUS9VED(")697)S:6]N(@IM<V=S='(@(E9E<G/C;R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(E9E<G-I;VX@0V]N
M=')O;"(*;7-G<W1R(")#;VYT<F]L;R!D92!697)S]65S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,PIM<V=I
M9"`B5F5R=&EC86P@86QI9VXB"FUS9W-T<B`B06QI;FAA;65N=&\@5F5R=&EC
M86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(D-A;.=O(%9E
M<G1I8V%L(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX,PIM<V=I9"`B5F5R=&EC86PZ(@IM<V=S='(@(E9E<G1I8V%L.B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<P"FUS
M9VED(")697)Y($AI9V@B"FUS9W-T<B`B375I=&\@06QT;R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I970@3F%M(@IM<V=S='(@(E)E</IB;&EC82!3;V-I86QI<W1A(&1O(%9I
M971N86UE(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I
M971N86UE<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;6ET82`H5DE30TE)
M*2(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R(")6:7-U86QI>F%R("5S
M(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E
M>'1E<FYA;"!W96(@<&%G92(*;7-G<W1R(")697(@=6UA('#A9VEN82!E>'1E
M<FYA(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@Q.`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(E9I<W5A;&EZ
M87(@8V]M;R`E<R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T,PHC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA;F1S+"!"<FET:7-H
M(@IM<V=S='(@(DEL:&%S(%9I<F=E;G,@0G)I=.)N:6-A<R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(T-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@
M(E9I<F=I;B!)<VQA;F1S+"!5+E,N(@IM<V=S='(@(DEL:&%S(%9I<F=E;G,@
M06UE<FEC86YA<R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C`Y"FUS9VED
M(")6:7-I8FEL:71Y(@IM<V=S='(@(E9I<VEB:6QI9&%D92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3$*;7-G:60@(E9I<VEB:6QI='DZ
M("(*;7-G<W1R(")6:7-I8FEL:61A9&4Z("(*"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY
M('9I82!33510(@IM<V=S='(@(E9O9&%F;VYE($ETX6QI82!V:6$@4TU44"(*
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-@IM<V=I9"`B5T%23B(*;7-G<W1R(")!5DE3(@H*(SH@861M:6XO<V5T
M=7`O<V-R:7!T<RYP:'`Z.#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5T%23DE.
M1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N(@IM<V=S='(@
M(D%414['PT\A(2$@4D5-3U9!($\@7")30U))4%1<(B!-04Y504Q-14Y412!$
M12`E<RXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G<W1R(")7
M86QL:7,@92!&=71U;F$B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,CD*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B
M079I<V\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U('!O+W1R86YS;&%T
M:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-S(U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#8P('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,#8Y"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<W
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,#@W('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#DW"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,3`W('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,3$S('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,U"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,C0U('!O+W1R86YS;&%T:6]N+G!H<#HQ,C4Q('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,C<Q"FUS9VED(")787)N:6YG.B`B"FUS9W-T<B`B
M079I<V\Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-3@*;7-G:60@(E=E(@IM<V=S='(@(C2J(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T
M(@IM<V=S='(@(E!R979I<^-O(&1O(%1E;7!O(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C0Q-0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I
M9&5D(&)Y(@IM<V=S='(@(D1A9&]S(&UE=&5O<F]L\V=I8V]S(&9O<FYE8VED
M;W,@<&]R(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A
M=&AE<BYC;VTB"FUS9W-T<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS-@IM<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S8*;7-G:60@(E=E8B!3:71E(@IM
M<V=S='(@(E#A9VEN82(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z
M-3@*;7-G:60@(E=E96ML>2(*;7-G<W1R(")396UA;F%L;65N=&4B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*
M;7-G<W1R(")"96TM=FEN9&$H;RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")"96TM=FEN
M9&$H;RD@82`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")"96TM=FEN9&$H;RDL("5S(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@*$E3
M3RTX.#4Y+3$I(@IM<V=S='(@(D]C:61E;G1A;"`H25-/+3@X-3DM,2DB"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y-@IM<V=I9"`B5V5S=&5R;B`H25-/
M+3@X-3DM,34I(@IM<V=S='(@(D]C:61E;G1A;"`H25-/+3@X-3DM,34I(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*
M;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E-A87)A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7
M:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN
M/R(*;7-G<W1R(")1=64@87!L:6-AY^-O(&1E=F4@;R`E<R!M;W-T<F%R(&%P
M\W,@82!E;G1R861A/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C(Q"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R(")1=6%L(.D@;R!C87)A8W1E<F4@9&5L:6UI=&%D;W(_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C0*;7-G:60@(E=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`B475A;"#I(&\@8V%R86-T
M97)E(&1E(&-I=&'GXV\_(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS
M9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B475E(&9A<V5S(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C$S,PIM<V=I9"`B5VAI8V@@<&QU9VEN<R!T
M;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")1
M=64@7")P;'5G:6YS7"(@86-T:79A<B!P87)A(&$@161IY^-O(%)I8V$N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX-`IM<V=I9"`B5VED=&@B"FUS9W-T<B`B3&%R9W5R82(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HS,3(T"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B
M"FUS9W-T<B`B3&%R9W5R82!E;2!U;FED861E<R!#4U,B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S0Y"B,L('!H<"UF;W)M870*;7-G:60@(E=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.B(*;7-G<W1R("),87)G=7)A(&1O($UE;G4@)7,@X"!E
M<W%U97)D82`H=&5M(&5F96ET;R!N82!P<O-X:6UA(&5N=')A9&$I.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS
M9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B3&%R9W5R82!D82!T
M86)E;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")5;FED861E(&1E
M(&QA<F=U<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(DQA<F=U<F$Z(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0V.`IM<V=I9"`B5VEK:2(*
M;7-G<W1R(")7:6MI(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(X."!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-0IM
M<V=I9"`B5VEN9"(*;7-G<W1R(")696YT;R(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD($5A<FQY(@IM
M<V=S='(@(E9E;G1O($UA=&EN86PB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@P"FUS9VED(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(E9E;&]C
M:61A9&4@9&\@=F5N=&\@96T@;O-S(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-38*;7-G:60@(E=I;F0Z(@IM<V=S='(@(E9E;G1O.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S`*;7-G:60@(E=I;F0Z("(*;7-G
M<W1R(")696YT;SH@(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"FUS
M9VED(")7:7-D;VTB"FUS9W-T<B`B4V%B961O<FEA(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$X,@IM<V=I9"`B5VES:&QI<W1S(@IM<V=S='(@
M(DQI<W1A<R!D92!$97-E:F]S(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C8U"FUS9VED(")7;W)K(@IM<V=S='(@(E1R86)A;&AO(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C0@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R(")%;F1E<F7G;R`H16UP<F5G;RDB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$Y,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R
M(")496QE9F]N92`H16UP<F5G;RDB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3$V.0HC+"!P:'`M9F]R;6%T"FUS9VED(")7<FET:6YG('5P9&%T960@:&5L
M<"!F:6QE('1O("5S+B(*;7-G<W1R(")%<V-R979E;F1O(&%R<75I=F\@9&4@
M86IU9&$@86-T=6%L:7IA9&\@<&%R82`E<RXB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,C,Q"FUS9VED(")8+5)E9B(*;7-G<W1R(")2969E<NIN
M8VEA<R!C<G5Z861A<R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',B"FUS9W-T<B`B
M4F5S=')IY_5E<R!"X7-I8V%S(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-3DR"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E(@IM<V=S='(@(E5T:6QI>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U
M,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED
M(")8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(DYO
M;64@06QT97)N871I=F\@9&4@4W5J96ET;R!8-3`Y=C,B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@
M2V5Y($ED96YT:69I97(B"FUS9W-T<B`B261E;G1I9FEC861O<B!#:&%V92!D
M92!3=6IE:71O(%@U,#EV,R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")%>'1E
M;G/U97,@6#4P.78S(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(EE9(@IM<V=S='(@(D%!(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#(W"FUS9VED(")965E9(@IM<V=S='(@(D%!04$B"@HC.B!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`P,0IM<V=I9"`B66%H;V\A
M(&UA<"(*;7-G<W1R(")-87!A(%EA:&]O(2(*"B,Z(&QI8B](;W)D92]-86EN
M=&5N86YC92YP:'`Z-38*;7-G:60@(EEE87)L>2(*;7-G<W1R(")!;G5A;&UE
M;G1E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$Q-PIM<V=I9"`B665M96XB"FUS9W-T<B`B2>EM96XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#@U"FUS9VED(")997,B
M"FUS9W-T<B`B4VEM(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]B;W1T;VTN:6YC.C8*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M(")3:6TL($-O;F-O<F1O(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N
M("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE7
M64<N(@IM<V=S='(@(B(*(D5S=.$@96T@34]$3R!D92!415A4+B`@57-E(&\@
M8F]TXV\@6SP^72!P87)A('1R;V-A<B!P87)A(&\@;6]D;R!625-504PN(@H*
M(SH@;&EB+TAO<F1E+G!H<#HQ,CDW"FUS9VED(")9;W4@87)E(&YO="!A=71H
M96YT:6-A=&5D+B(*;7-G<W1R(").XV\@97-TX2!A=71E;G1I8V%D;RXB"@HC
M.B!L:6(O2&]R9&4O261E;G1I='DN<&AP.C,P,@IM<V=I9"`B66]U(&-A;B!N
M;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M(@IM<V=S='(@(D[C;R!P;V1E('1E<B!O(&-A<F%C=&5R92`G7%PG(&YO('-E
M=2!N;VUE(&-O;7!L971O+B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#4V
M(&QI8B](;W)D92]&;W)M+G!H<#HQ.3<V"FUS9VED(")9;W4@9&ED(&YO="!E
M;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S='(@(D[C;R!I;G1R
M;V1U>FEU('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\@=N%L
M:61O+B(*"B,Z(&QI8B](;W)D92]$871A+G!H<#HR-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R`B
M"B)I;B`E<RXB"FUS9W-T<B`B(@HB3N-O(&UA<&5O=2!N96YH=6T@8V%M<&\@
M9&\@87)Q=6EV;R!I;7!O<G1A9&\@<&%R82!O<R!C86UP;W,@8V]R<F5S<&]N
M9&5N=&5S("(*(F5M("5S+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,C,*
M;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`B06-A
M8F]U(&1E('-A:7(N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-C$*;7-G
M:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU
M;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B
M"B)496T@9&4@:6YT<F]D=7II<B!U;2!N^FUE<F\@9&4@=&5L96WS=F5L(';A
M;&ED;RP@<_,@8V]M(&3M9VET;W,L(&UA<R!C;VT@=6T@(@HB)RLG(&]P8VEO
M;F%L('!A<F$@;R!P<F5F:7AO(&EN=&5R;F%C:6]N86PN(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$Q.#@*;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N(@IM<V=S='(@(E1E;2!D92!I;G1R;V1U>FER('5M('9A
M;&]R(';A;&ED;RXB"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C,W
M"FUS9VED(")9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+B(*;7-G<W1R("(B"B)496T@9&4@8V]N9FEG=7)A
M<B!U;2!M96-A;FES;6\@8N%S:6-O('!A<F$@1&%T851R964@<V4@<75I<V5R
M('5S87(@(@HB4W5B<V-R:>?U97,B"@HC.B!L:6(O2&]R9&4N<&AP.C0S,0IM
M<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S
M='(@(E1E;2!D92!C;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!B87-E('!A<F$@
M;R!61E,N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,3$*
M;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*;7-G<W1R(")$979E
M(&1E<V-R979E<B!O('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!O(')E;&%T
M\W)I;RXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H
M:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B5&5M(&1E(&EN=')O9'5Z:7(@
M;R!54DP@9&\@<F5C=7)S;R!Q=64@97-T82!L:6=AY^-O('-E(')E9F5R92(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(E1E;2!D92!S96QE8V-I;VYA<B!U;2!S97)V:61O<B!A(')E;6]V97(N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R(")$979E(&5S<&5C
M:69I8V%R(&\@=71I;&EZ861O<B!A(&QI;7!A<BXB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N(@IM<V=S='(@(D1E=F4@97-P96-I9FEC87(@;R!N;VUE(&1O
M('5T:6QI>F%D;W(@82!R96UO=F5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R(")4
M96T@9&4@97-P96-I9FEC87(@;R!N;VUE(&1O('5T:6QI>F%D;W(@82!A9&EC
M:6]N87(N(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"FUS9VED(")9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(@IM<V=S='(@(E1E
M;2!D92!E<W!E8VEF:6-A<B!O('5T:6QI>F%D;W(@82!A8W1U86QI>F%R+B(*
M"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U
M(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R
M(")496T@9&4@97-P96-I9FEC87(@82!A8^?C;R!A(&1E<V5M<&5N:&%R+B(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C<R"FUS
M9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S
M='(@(E1E;2!D92!I;G1R;V1U>FER('5M(&YO=F\@;F]M92!D92!C871E9V]R
M:6$N(@H*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HW
M,PIM<V=I9"`B66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE
M(&YU;6)E<B(*;7-G<W1R(")496T@9&4@9F]R;F5C97(@=6T@;OIM97)O(&1E
M('1E;&5F;VYE(&ET86QI86YO(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.CDQ
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R("5S('-E<W-I;VX@:&%S(&5X
M<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B02!S=6$@<V5S
M<^-O("5S(&5X<&ER;W4N(%!O<B!F879O<B!E;G1R92!D92!N;W9O+B(*"B,Z
M('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9;W5R
M($5M86EL($%D9')E<W,B"FUS9W-T<B`B3R!S974@16YD97)EYV\@9&4@0V]R
M<F5I;R!%;&5C='+S;FEC;SHB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C`T"FUS9VED(")9;W5R($9R;VTZ(&%D9')E<W,Z(@IM<V=S='(@(D\@<V5U
M(&5N9&5R9>=O(%PB1&4Z7"(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*;7-G:60@(EEO
M=7(@26YF;W)M871I;VXB"FUS9W-T<B`B02!S=6$@26YF;W)M8>?C;R(*"B,Z
M(&QI8B](;W)D92]!=71H+G!H<#HY,34*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T
M('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R
M("(B"B)/('-E=2!E;F1E<F7G;R!)4"!P87)E8V4@=&5R(&UU9&%D;R!D97-D
M92!O(&EN[6-I;R!D82!S97-SXV\@)7,N(%!A<F$@(@HB9V%R86YT:7(@82!S
M=6$@<V5G=7)A;N=A+"!D979E(&%U=&5N=&EC87(M<V4@9&4@;F]V;RXB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U
M<B!.86UE(@IM<V=S='(@(D\@4V5U($YO;64B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]N;V%D9"YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O
M=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(D\@<V5U(&UE8V%N:7-M;R!D92!A
M=71E;G1I8V'GXV\@;N-O('-U<&]R=&$@861IY^-O(&1E('5T:6QI>F%D;W)E
M<R!O=2!E<W1A("(*(F]PY^-O(&9O:2!D97-A8W1I=F%D82!P;W(@86QG=6T@
M;W5T<F\@;6]T:79O+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES
M="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U
M<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+B(*;7-G<W1R("(B"B)/('-E=2!M96-A;FES;6\@9&4@875T96YT:6-AY^-O
M(&[C;R!S=7!O<G1A(&QI<W1A9V5M(&1E('5T:6QI>F%D;W)E<R!O=2!E<W1A
M("(*(F]PY^-O(&9O:2!D97-A8W1I=F%D82!P;W(@86QG=6T@;W5T<F\@;6]T
M:79O+B(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY,3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N
M9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B`B
M"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+B(*;7-G<W1R("(B"B)/('-E=2!N879E9V%D;W(@<&%R96-E('1E<B!M
M=61A9&\@9&5S9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A(&=A<F%N
M=&ER("(*(F$@<W5A('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E
M(&YO=F\N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS
M9W-T<B`B3R!S974@;F%V96=A9&]R(&[C;R!S=7!O<G1A(&5S=&$@9G5N8VEO
M;F%L:61A9&4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I;G0N:G,Z
M-#(*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H
M:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*
M(G1O('!R:6YT+B(*;7-G<W1R("(B"B)/('-E=2!N879E9V%D;W(@;N-O('-U
M<&]R=&$@97-T82!O<.?C;R!D92!I;7!R97-SXV\N(%!R97-S:6]N92!#;VYT
M<F]L+R(*(D-O;6UA;F0@*R!0('!A<F$@:6UP<FEM:7(N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T.0IM<V=I9"`B66]U<B!C=7)R96YT('1I;64@
M>F]N93HB"FUS9W-T<B`B1G5S;R!H;W+A<FEO(&%C='5A;#HB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,34P"FUS9VED(")9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ(@IM<V=S='(@(DED96YT:61A9&4@<&%D<N-O.B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ.3,*;7-G:60@(EEO=7(@9G5L;"!N86UE.B(*
M;7-G<W1R(").;VUE(&-O;7!L971O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$T-0IM<V=I9"`B(@HB66]U<B!G971T97AT('9E<G-I;VX@:7,@=&]O(&]L
M9"!A;F0@9&]E<R!N;W0@<W5P<&]R="!02%`@;F%T:79E;'DN7&XB"B).;W0@
M86QL('-T<FEN9W,@=VEL;"!B92!E>'1R86-T960N(@IM<V=S='(@(B(*(D$@
M<W5A('9E<G/C;R!D;R!G971T97AT(.D@9&5M87-I861O(&%N=&EG82P@;N-O
M('-U<&]R=&%N9&\@4$A0(&1E(&9O<FUA("(*(FYA=&EV82X@3F5M('1O9&%S
M(&%S(&-A9&5I87,@9&4@8V%R86-T97)E<R!S97+C;R!E>'1R8>UD87,N(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G
M<W1R(")!('-U82!N;W9A('!A;&%V<F$M<&%S<V4@<&%R82`E<R#I.B`E<R(*
M"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P
M=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T
M:&ES('-E<W-I;VXN(@IM<V=S='(@(D%S('-U87,@;W#G]65S(&9O<F%M(&%L
M=&5R861A<R!A=.D@86\@9FEN86P@9&5S=&$@<V5S<^-O+B(*"B,Z(&QI8B](
M;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960N(@IM<V=S='(@(D%S('-U87,@;W#G]65S(&9O<F%M
M(&%C='5A;&EZ861A<RXB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H
M<#HW-0IM<V=I9"`B66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="(*;7-G
M<W1R(")!('-U82!P86QA=G)A+7!A<W-E(&9O:2!R96-R:6%D82(*"B,Z('-E
M<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<Y"FUS9VED("(B"B)9;W5R('!A
M<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L
M;V<@:6X@=VET:"!Y;W5R(&YE=R`B"B)P87-S=V]R9"XB"FUS9W-T<B`B(@HB
M02!S=6$@<&%L879R82UP87-S92!F;VD@<F5C<FEA9&$L('9E<FEF:7%U92!O
M('-E=2!C;W)R96EO(&5L96-T<O-N:6-O(&4@(@HB96YT<F4@8V]M(&$@<W5A
M(&YO=F$@<&%L879R82UP87-S92XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P
M8W-U;2YI;F,Z-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S
M='(@(D]S('-E=7,@<V5R=FED;W)E<R!R96UO=&]S.B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X
M"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@(DIU9V]S;.%V:6$B"@HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA:7)E(@IM<V=S
M='(@(EIA:7)E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%M8FEA(@IM<V=S='(@(EKB;6)I82(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(T.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A8G7I(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("):
M:7!P>2(*"B,Z(&QI8B](;W)D92]497AT+T9I;'1E<B]H:6=H;&EG:'1Q=6]T
M97,N<&AP.C$W,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K
M<RYJ<SHQ,@IM<V=I9"`B6TAI9&4@475O=&5D(%1E>'1=(@IM<V=S='(@(EM%
M<V-O;F1E<B!497AT;R!#:71A9&]=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP
M:'`Z-38*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6U)E;&%T
M\W)I;R!D92!0<F]B;&5M87-=("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED(");4VAO=R!1=6]T960@5&5X="`M
M(@IM<V=S='(@(EM-;W-T<F%R(%1E>'1O($-I=&%D;R`M(@H*(SH@;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<R"B,L('!H
M<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=
M(@IM<V=S='(@(EM-;W-T<F%R(%1E>'1O($-I=&%D;R`M("5S(&QI;FAA<UTB
M"@HC.B!L:6(O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R;6%T"FUS9VED(");
M;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6VQI;FAA("5S(&1E("5S72(*"B,Z
M(&QI8B](;W)D92YP:'`Z,30T,2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC
M.C$Q"FUS9VED(")?061M:6YI<W1R871I;VXB"FUS9W-T<B`B7T%D;6EN:7-T
M<F'GXV\B"@HC.B!L:6(O87!I+G!H<#HQ,S8*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-O;G-O;&$B"@HC.B!L:6(O87!I+G!H<#HQ,C0*;7-G:60@(E]$871A
M5')E92(*;7-G<W1R("+!<E]V;W)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS9VED(")?1&5L971E
M(%)O=R(*;7-G<W1R(")?4F5M;W9E<B!,:6YH82(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q-@IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&]S(@H*(SH@;&EB
M+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B7TAE;'`B"FUS9W-T<B`B05]J
M=61A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R=&EE<RXN+B(*;7-G
M<W1R(")0<F]P<FEE9&%D97,@9&$@7TEM86=E;2(*"B,Z(&QI8B](;W)D92]-
M96YU+G!H<#HQ.30*;7-G:60@(E],;V<@:6XB"FUS9W-T<B`B7T5N=')A<B(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM
M<V=S='(@(E]386ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?36]D:69Y($QI;FLN+BXB
M"FUS9W-T<B`B7TUO9&EF:6-A<B!,:6=AY^-O(@H*(SH@;&EB+TAO<F1E+TUE
M;G4N<&AP.C$V-`IM<V=I9"`B7T]P=&EO;G,B"FUS9W-T<B`B7T]PY_5E<R(*
M"B,Z(&QI8B]A<&DN<&AP.C$R,`IM<V=I9"`B7U!E<FUI<W-I;VYS(@IM<V=S
M='(@(E]097)M:7-S]65S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?4F5M;W9E($QI;FLN
M+BXB"FUS9W-T<B`B7U)E;6]V97(@3&EG8>?C;RXN+B(*"B,Z(&QI8B]A<&DN
M<&AP.C$P.`IM<V=I9"`B7U-E='5P(@IM<V=S='(@(E]#;VYF:6=U<F'GXV\B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S(*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E!R;W!R:65D861E<R!D82!?5&%B96QA(@H*(SH@;&EB+V%P:2YP:'`Z,3$R
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7U5T:6QI>F%D;W)E<R(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.#DP"FUS9VED(")A9&1R97-S(&)O;VLB"FUS
M9W-T<B`B8V]N=&%C=&]S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q,0IM
M<V=I9"`B86X@97)R;W(@:&%S(&]C8W5R960Z(@IM<V=S='(@(F]C;W)R974@
M=6T@97)R;SHB"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C@X,@IM<V=I9"`B
M8V%L96YD87(B"FUS9W-T<B`B8V%L96YDX7)I;R(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF
M;W)M870*;7-G:60@(F-A;&TB"FUS9W-T<B`B8V%L;6\B"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z-3@Y"FUS9VED(")C;&EC:R!H97)E(@IM
M<V=S='(@(F-L:7%U92!A<75I(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0T
M-2!P;R]T<F%N<VQA=&EO;BYP:'`Z-34P('!O+W1R86YS;&%T:6]N+G!H<#HV
M,3$*(SH@<&\O=')A;G-L871I;VXN<&AP.C<T.2!P;R]T<F%N<VQA=&EO;BYP
M:'`Z.#$P('!O+W1R86YS;&%T:6]N+G!H<#HX.#<*;7-G:60@(F1O;F4B"FUS
M9W-T<B`B9F5I=&\B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-34R('!O+W1R
M86YS;&%T:6]N+G!H<#HU.#0@<&\O=')A;G-L871I;VXN<&AP.C8Q,PHC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-S<X('!O+W1R86YS;&%T:6]N+G!H<#HX,3(@
M<&\O=')A;G-L871I;VXN<&AP.C@Y,`IM<V=I9"`B9F%I;&5D(@IM<V=S='(@
M(F9A;&AO=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(F1I;6EN=6EN9&\B"@HC
M.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#4Y"FUS9VED(")F:6QE(@IM<V=S
M='(@(F9I8VAE:7)O(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.0IM<V=I
M9"`B9F]U;F0Z("(*;7-G<W1R(")E;F-O;G1R861O.B`B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C$W-"!L:6(O0FQO8VLO;65T87(N<&AP.C,V,"!L:6(O
M0FQO8VLO;65T87(N<&AP.C,X-@HC+"!P:'`M9F]R;6%T"FUS9VED(")F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(F1O("5S("@E<RD@X',@
M)7,@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,X"FUS
M9VED(")G=7-T:6YG(@IM<V=S='(@(G)A:F%D87,B"@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*;7-G<W1R
M(")H.B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M,S$*;7-G:60@(FAH(@IM<V=S='(@(FAH(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PIM<V=I9"`B:6UM961I871E(@IM<V=S='(@(FEM961I871O
M(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF
M9BYP:'`Z-SD*;7-G:60@(FEN;&EN92(*;7-G<W1R(")E;2!L:6YH82(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"FUS9VED
M(")L:6YE<UTB"FUS9W-T<B`B;&EN:&%S72(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+VUK:7-O9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O
M9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")%
M<G)O(&UK:7-O9G,@8V]M(&/S9&EG;R`E9"!A;R!C;VYS=')U:7(@25-/+B(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS-#(*;7-G
M:60@(FUM(@IM<V=S='(@(FUM(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HR.#@@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C(P-0IM<V=I9"`B
M;F%M92(*;7-G<W1R(")N;VUE(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C,W
M.`IM<V=I9"`B;F]T(&-H86YG960B"FUS9W-T<B`B<V5M(&%L=&5R8>?U97,B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q"FUS9VED(")N;W0@9F]U;F0B
M"FUS9W-T<B`B;N-O(&5N8V]N=')A9&\B"@HC.B!L:6(O2&]R9&4O4E!#+G!H
M<#HQ,C$*;7-G:60@(FYO="!I;7!L96UE;G1E9"(*;7-G<W1R(")NXV\@:6UP
M;&5M96YT861A(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y
M"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(F%I;F1A('!O
M<B!I;7!L96UE;G1A<B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.#<T"FUS
M9VED(")N;W1E<&%D(@IM<V=S='(@(F-A9&5R;F\@9&4@;F]T87,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@X
M"FUS9VED(")P97)C96YT(@IM<V=S='(@(G!E<F-E;G1A9V5M(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM
M<V=I9"`B<&EX96QS(@IM<V=S='(@(G#M>&5I<R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C<S"FUS9VED(")R:7-I;F<B"FUS
M9W-T<B`B<W5B:6YD;R(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3@*
M;7-G:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`B;6]S=')A<B!D:69E
M<F5NYV%S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(G-M<S)E;6%I
M;"!V:6$@2%144"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-3@*;7-G:60@(G-S(@IM<V=S='(@(G-S(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S(*;7-G:60@(G-T96%D>2(*
M;7-G<W1R(")E<W3A=F5L(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.3@*
M;7-G:60@(G1A<VL@;&ES="(*;7-G<W1R(")L:7-T82!D92!T87)E9F%S(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")T:&4@2&]R9&4@4$\@9FEL92!F;W(@=&AE(&QO8V%L92`E<R!D;V5S(&YO
M="!E>&ES=#HB"FUS9W-T<B`B3R!F:6-H96ER;R!03R!P87)A(&\@;&]C86QE
M("5S(&[C;R!E>&ES=&4N(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@;&EB+TAO
M<F1E+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B:6YT<F]D=7IA(&$@<&%L
M879R82UP87-S92!D=6%S('9E>F5S+"!P87)A(&-O;F9I<FUAY^-O(@H*(SH@
M861M:6XO<V5T=7`O9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z
M-SD*;7-G:60@(G5N:69I960B"FUS9W-T<B`B=6YI9FEC861O(@H*(SH@;&EB
M+TAO<F1E+TU)344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T
M<B`B<V5M(&YO;64B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S<U"FUS9VED
M(")U<&1A=&5D(@IM<V=S='(@(F%C='5A;&EZ861O(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS9W-T<B`B
M<V5L96-C:6]N861A('!E;&\@=71I;&EZ861O<B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@
M(G9#87)D(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(R-`IM<V=I9"`B=SHB"FUS9W-T<B`B4F5E;F,Z(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@(G=E871H97(N8V]M(@IM<V=S
M='(@(G=E871H97(N8V]M(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!O+VYB7TY/
M+G!O````````````````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#8V-30R-B`Q,#4Q-30S-#$T,B`P,3<U,C8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````(R!.;W)W96=I86X@2&]R
M9&4@5')A;G-L871I;VXN"B,@0V]P>7)I9VAT("A#*2`R,#`Q+3(P,#(@2&]R
M9&4@4')O:F5C="X*(R!/>7-T96EN(%-T96EM;&5R(#QO>7-T96EN0')E>'1A
M+FYE=#XL(#(P,#$N"B,@5&]R<W1E:6X@4RX@2&%N<V5N(#QH=6QE8F]E<D!T
M96-H8F5E+FYO/BP@,C`P,BX*(R!!;F1R96%S($=U;FQE:6MS:V%A<R`\86YD
M<F5A<T!G=6YL96EK<VMA87,N;F\^+"`R,#`S+@HC($=E:7(@3RX@2&]G8F5R
M9R`\:&]R9&5`<VMY9&EV97(N;F\^+"`R,#`U+@HC"FUS9VED("(B"FUS9W-T
M<B`B(@HB4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`N-%QN(@HB4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`U+3`U+3$X(#$R.C0S*S`R,#!<;B(*(E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#4M,#4M,3@@,30Z,S<K,#(P,%QN(@HB3&%S
M="U4<F%N<VQA=&]R.B!'96ER($\N($AO9V)E<F<@/&AO<F1E0'-K>61I=F5R
M+FYO/EQN(@HB3&%N9W5A9V4M5&5A;3H@3F]R=V5G:6%N("A";VMM86PI(#QI
M,3AN0&QI<W1S+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM
M,5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C0Y"FUS9VED("(B"B(@("U-+"`M+6UE<W-A
M9V4]34534T%'12`@57-E('1H:7,@8V]M;6ET(&UE<W-A9V4@:6YS=&5A9"!O
M9B!T:&4@9&5F875L="!O;F5S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-3,*;7-G:60@(B(*(B`@+6$L("TM861D/49)3$4@("`@("`@
M($%D9"!T:&ES(%!/(&9I;&4@=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T
M;UQN(@HB("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D92!A(&-O;7!E
M;F1I=6T@9G)O;2!A(&1I9F9E<F5N="!B<F%N8V@@=&]<;B(*(B`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!G96YE<F%T960@8V]M<&5N9&EU;2XB"FUS
M9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q,PIM<V=I9"`B(@HB
M("`M8BP@+2UB87-E/2]0051(("!&=6QL('!A=&@@=&\@=&AE("A(;W)D92D@
M8F%S92!D:7)E8W1O<GD@=&AA="!S:&]U;&0@8F5<;B(*(B`@("`@("`@("`@
M("`@("`@("`@=7-E9"XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C8Y"FUS9VED("(B"B(@("UC+"`M+6-O;7!E;F1I=6T]1DE,12`@365R
M9V4@;F5W('1R86YS;&%T:6]N<R!T;R!T:&ES(&-O;7!E;F1I=6T@9FEL95QN
M(@HB("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@=&AE(&1E
M9F%U;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H95QN(@HB("`@("`@("`@
M("`@("`@("`@("`@("`@(&AO<F1E+W!O(&1I<F5C=&]R>2XB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8S('!O+W1R86YS;&%T:6]N+G!H
M<#HX,2!P;R]T<F%N<VQA=&EO;BYP:'`Z.#<*;7-G:60@(B(*(B`@+6,L("TM
M8V]M<&5N9&EU;3U&24Q%("!5<V4@=&AI<R!C;VUP96YD:75M(&9I;&4@:6YS
M=&5A9"!O9B!T:&4@9&5F875L=%QN(@HB("`@("`@("`@("`@("`@("`@("`@
M("`@(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T
M;W)Y*2XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-`IM
M<V=I9"`B("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S
M(&9R;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+B(*;7-G<W1R("(B"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-30*;7-G:60@(B`@+60L("TM9&ER96-T;W)Y
M/41)4B`@($-R96%T92!C;VUP96YD:75M(&EN('1H:7,@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U"FUS9VED("(@
M("UH+"`M+6AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,B!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C<@<&\O=')A;G-L871I;VXN<&AP.C<U"FUS9VED("(@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT-R!P;R]T<F%N<VQA
M=&EO;BYP:'`Z-C$@<&\O=')A;G-L871I;VXN<&AP.C<Y"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HX-0IM<V=I9"`B("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@
M(%5S92!T:&ES(&QO8V%L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C4U"FUS9VED("(@("UL+"`M+6QO8V%L93UL;%]#0R`@("!5<V4@
M=&AI<R!L;V-A;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HV.`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("`@($)U:6QD($U/
M(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@
M(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HT,PIM<V=I9"`B("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@($-L96%N=7`@4$\@9FEL97,@;VYL>2!F;W(@=&AI
M<R`H2&]R9&4I(&UO9'5L92XB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C0X"FUS9VED("(B"B(@("UM+"`M+6UO9'5L93U-3T153$4@("`@
M0V]M;6ET('1R86YS;&%T:6]N<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D
M=6QE+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C(*;7-G
M:60@(B`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#<F5A=&4@82!03R!F:6QE
M(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HX,`IM<V=I9"`B("`M;2P@+2UM;V1U;&4]
M34]$54Q%("`@($UE<F=E(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E
M*2!M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HW
M-@IM<V=I9"`B(@HB("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!H
M96QP(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-@IM<V=I9"`B("`M;2P@
M+2UM;V1U;&4]34]$54Q%("`@(%5P9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M
M;V1U;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU.`IM
M<V=I9"`B("`M;2P@+2UM;V1U;&4]34]$54Q%("!'96YE<F%T92!03U0@9FEL
M92!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+B(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S`*;7-G:60@(B(*(B`@+6XL("TM;F\M
M8V]M<&5N9&EU;2`@("!$;VXG="!M97)G92!N97<@=')A;G-L871I;VYS('1O
M('1H92!C;VUP96YD:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-C0@<&\O=')A;G-L871I;VXN<&AP.C@R('!O+W1R86YS;&%T:6]N
M+G!H<#HX.`IM<V=I9"`B("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T
M('5S92!A(&-O;7!E;F1I=6TN(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HW,0IM<V=I9"`B("`M<RP@+2US=&%T:7-T:6-S("`@("`@(%-A
M=F4@=')A;G-L871I;VX@<W1A=&ES=&EC<R!I;B!A(&QO8V%L(&9I;&4N(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,38*;7-G:60@(B`@
M+70L("TM=&5S="`@("`@("`@4VAO=R!T:&4@97AE8W5T960@8V]M;6%N9',@
M8G5T(&1O;B=T(')U;B!A;GET:&EN9RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$P-0IM<V=I9"`B(@HB("!C;&5A;G5P("`@("!#;&5A
M;G,@=&AE(%!/(&9I;&5S('5P(&9R;VT@=6YT<F%N<VQA=&5D(&%N9"!O8G-O
M;&5T92!E;G1R:65S+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3`X"FUS9VED("(@(&-O;6UI="`@("`@($-O;6UI="!T<F%N<VQA=&EO
M;G,@=&\@=&AE($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#D*;7-G:60@(B`@8V]M;6ET+6AE;'`@0V]M;6ET(&AE
M;'`@9FEL97,@=&\@=&AE($-64R!S97)V97(N(@IM<V=S='(@(B(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HY.0IM<V=I9"`B(@HB("!C;VUP96YD:75M("!2
M96)U:6QD('1H92!C;VUP96YD:75M(&9I;&4N(%=A<FYI;F<Z(%1H:7,@;W9E
M<G=R:71E<R!T:&5<;B(*(B`@("`@("`@("`@("`@8W5R<F5N="!C;VUP96YD
M:75M+B(*;7-G<W1R("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`P"FUS
M9VED("(@(&5X=')A8W0@("`@($=E;F5R871E(%!/('1E;7!L871E("@N<&]T
M*2!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.CDX
M"FUS9VED("(@(&AE;'`@("`@("`@(%-H;W<@=&AI<R!H96QP(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#$*;7-G:60@
M(B(*(B`@:6YI="`@("`@("`@0W)E871E(&]N92!O<B!M;W)E(%!/(&9I;&5S
M(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H:7-<;B(*(B`@("`@("`@
M("`@("`@;W9E<G=R:71E<R!T:&4@97AI<W1I;F<@4$\@9FEL97,@;V8@=&AI
M<R!L;V-A;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#8*;7-G:60@(B`@;6%K92`@("`@("`@0G5I;&0@8FEN87)Y($U/(&9I;&5S
M(&9R;VT@=&AE('-P96-I9FEE9"!03R!F:6QE<RXB"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C$P-PIM<V=I9"`B(@HB("!M86ME+6AE;'`@
M("!-87)K(&%L;"!E;G1R:65S(&EN('1H92!834P@:&5L<"!F:6QE(&)E:6YG
M('5P+71O+61A=&4@86YD7&XB"B(@("`@("`@("`@("`@('!R97!A<F4@=&AE
M(&9I;&4@9F]R('1H92!N97AT(&5X96-U=&EO;B!O9B!U<&1A=&4M:&5L<"X@
M66]U7&XB"B(@("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE
M;'`@049415(@=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H95QN(@HB("`@
M("`@("`@("`@("!H96QP(&9I;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#(*;7-G:60@(B(*(B`@;65R9V4@("`@("`@365R9V4@
M=&AE(&-U<G)E;G0@4$\@9FEL92!W:71H('1H92!C=7)R96YT(%!/('1E;7!L
M871E(&9I;&4N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#,*;7-G:60@(B`@=7!D871E("`@("`@4G5N(&5X=')A8W0@86YD(&UE<F=E
M('-E<75E;G0N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#0*;7-G:60@(B(*(B`@=7!D871E+6AE;'`@17AT<F%C="!A;&P@;F5W(&%N
M9"!C:&%N9V5D(&5N=')I97,@9G)O;2!T:&4@16YG;&ES:"!834P@:&5L<%QN
M(@HB("`@("`@("`@("`@("!F:6QE(&%N9"!M97)G92!T:&5M('=I=&@@=&AE
M(&5X:7-T:6YG(&]N97,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]C;VYF:7)M7W1O<"YI;F,Z,3$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB("8C,34Q.R`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN
M=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N(@IM<V=S='(@(B(*
M(B`F(S$U,3L@)7,@97(@:VQA<B!F;W(@Y2!U=&;X<F4@=F5D;&EK96AO;&1S
M;W!E<F%S:F]N96YE('-O;2!E<B!V86QG="`B"B)N961E;F9O<BXB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,U,@HC+"!P:'`M9F]R;6%T"FUS9VED("(@
M*"5S(&1A>7,@86=O*2(*;7-G<W1R("(@*"5S(&1A9V5R('-I9&5N*2(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*$%C
M8V5S<VME>2`E<RDB"FUS9W-T<B`B("AH=7)T:6=T87-T("5S*2(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR,S8P"B,L('!H<"UF;W)M870*;7-G:60@(B`H
M:6X@)7,@9&%Y<RDB"FUS9W-T<B`B("AI;FYE;B`E<R!D86=E<BDB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C,U-@IM<V=I9"`B("AT;V1A>2DB"FUS9W-T
M<B`B("AI(&1A9RDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,U.`IM<V=I
M9"`B("AT;VUO<G)O=RDB"FUS9W-T<B`B("AI(&UO<F=E;BDB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,U-`IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S
M='(@(B`H:2!GY7(I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q-`IM<V=I9"`B(&%T("(*;7-G<W1R("(@9&5N("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)60@)7,@86YD("5S(@IM<V=S='(@(B5D("5S(&]G("5S(@H*(SH@<&\O=')A
M;G-L871I;VXN<&AP.C$Q-C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B)60@8GET
M97,@=W)I='1E;BXB"FUS9W-T<B`B)60@8GET97,@<VMR979E="XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z,3(V-0HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M9"!O9B`E9"!E;G1R:65S(&UA<FME9"!A<R!U<"UT;RUD871E(@IM<V=S='(@
M(B5D(&%V("5D(&]P<&;X<FEN9V5R(&UA<FME="!S;VT@;W!P9&%T97)T(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M9&%G97)S
M('9A<G-E;"(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P
M+FEN8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S
M='(@(B5S("T@5&EL(&EN9F\B"@HC.B!T96UP;&%T97,O861M:6XO8V]M;6]N
M+6AE861E<BYI;F,Z,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@061M:6YI
M<W1R871I;VXB"FUS9W-T<B`B)7,@861M:6YI<W1R87-J;VXB"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<R.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!&:6YG97)P<FEN="(*"B,Z
M(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-3<@;&EB+TAO<F1E+TU)
M344O0V]N=&5N=',N<&AP.C@U.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!+
M0B(*;7-G<W1R("(E<R!+0B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN
M=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S
M('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R("T@0F5K<F5F=&5L<V4B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HR,#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B
M)7,@:6YS=&EL;&EN9V5R(@H*(SH@;&EB+TAO<F1E+T%U=&@O4VEG;G5P+G!H
M<#HR-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R
M("(E<R!R96=I<W1R97)I;F<B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M86=R965M96YT7W1O<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!4
M97)M<R!O9B!!9W)E96UE;G0B"FUS9W-T<B`B)7,@879T86QE=FEL:^5R(@H*
M(SH@;&EB+U9&4R]F='`N<&AP.C4Y-B!L:6(O5D93+V9T<"YP:'`Z-C8V"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R
M("(E<R!F:6YN97,@86QL97)E9&4N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-3<@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-C,@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,S<*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-#,@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@870@)7,@
M)7,B"FUS9W-T<B`B)7,@<.4@)7,@)7,B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:&%S(&-A;F-E;&QE9"`E<RXB"FUS9W-T<B`B)7,@:&%R(&MA;G-E;&QE
M<G0@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#(V"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O
M(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(&AA<B!B97-V87)T
M(&5N(&9O<F5S</AR<V5L(&]M(&EN9F]R;6%S:F]N(&%N9^5E;F1E(&QE9&EG
M+V]P<'1A='0N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3(T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D
M('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R!H87(@<W9A
M<G0@<.4@:6YV:71A<VIO;F5N('1I;"`E<RXB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS
M9W-T<B`B)7,@:&%R('-E;F1T(&1E9R!I;F9O<FUA<VIO;B!O;2!L961I9R]O
M<'!T871T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HR.#<@<&\O=')A;G-L
M871I;VXN<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!I<R!N;W0@
M=W)I=&%B;&4N(@IM<V=S='(@(B5S(&5R('-K<FEV96)E<VMY='1E="XB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,R,@HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!E<B!PY6MR979D(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@;6EN=71E<R(*;7-G<W1R("(E<R!M:6YU='1E<B(*"B,Z(&QI8B](;W)D
M92]";&]C:R]#;VQL96-T:6]N+G!H<#HQ,C,@<&\O=')A;G-L871I;VXN<&AP
M.C$S,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G
M<W1R("(E<R!I:VME(&9U;FYE="XB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z
M-3@U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&YO="!F;W5N9"X@4G5N("=T
M<F%N<VQA=&EO;B!E>'1R86-T)R!F:7)S="XB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R
M;6%T:6]N+B(*;7-G<W1R("(E<R!F;W)E<W#X<B!I;F9O<FUA<VIO;B!O;2!N
MY7(@9'4@97(@;&5D:6<O;W!T=&%T="XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HU,#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E<RXB"FUS9W-T<B`B)7,@
M9F]R97-P^'(@9&EN(&1E;'1A9V5L<V4@<.4@)7,N(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O;&ES="YI;F,Z-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E
M<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R`M("5S(&%V("5S(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S('=I<VAE<R!T;R!A9&0@=&\@)7,N(@IM<V=S='(@
M(B5S(/AN<VME<B#E(&QE9V=E('1I;"`E<RXB"@HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+B(*;7-G<W1R
M("(E<R#X;G-K97(@Y2!G:OAR92!D96<@;W!P;65R:W-O;2!PY2`E<RXB"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3@*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(')E8V5I=F4@=&AE(&QA
M=&5S="!I;F9O<FUA=&EO;B!A8F]U="`E<RXB"FUS9W-T<B`B)7,@^&YS:V5R
M(.4@;6]T=&$@9&5N('-I<W0@;W!P9&%T97)T92!I;F9O<FUA<VIO;F5N(&]M
M("5S+B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$R"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%D9')E<W-E
M8F]K(&9O<B`E<R(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z.3`T"B,L('!H
M<"UF;W)M870*;7-G:60@(B5S)W,@0V%L96YD87(B"FUS9W-T<B`B2V%L96YD
M97(@9F]R("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D(@IM<V=S='(@(DYO=&%T8FQO
M:VL@9F]R("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,C`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R(")/<'!G879E
M;&ES=&4@9F]R("5S(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T
M96YE<B]M;V)I;&4N<&AP.CDW"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E
M<R(*;7-G<W1R("(E<SH@)7,B"@HC.B!L:6(O2&]R9&4O0TQ)+G!H<#HR-S`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)R5S)R!I<R!N;W0@82!V86QI9"!C:&]I
M8V4N(@IM<V=S='(@(B<E<R<@97(@:6MK92!E="!G>6QD:6<@=F%L9RXB"@HC
M.B!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C4X,B!L:6(O2&]R9&4O4F5G:7-T
M<GDN<&AP.CDX,@HC+"!P:'`M9F]R;6%T"FUS9VED("(G)7,G(&ES(&YO="!C
M;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T<B`B)R5S
M)R!E<B!I:VME(&-O;F9I9W5R97)T(&D@2&]R9&4@4F5G:7-T97)E="XB"@HC
M.B!L:6(O2&]R9&4O5')E92YP:'`Z,38P"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED("(G)7,G('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(*;7-G<W1R
M("(E<R!I:VME(&9U;FYE="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4W"B,L
M('!H<"UF;W)M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+B(*;7-G<W1R("(E<R!B;&4@;&%G="!T:6P@9W)U<'!E<WES
M=&5M970N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C@U"B,L('!H
M<"UF;W)M870*;7-G:60@(B<E<R<@=V%S(&%D9&5D('1O('1H92!P97)M:7-S
M:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@8FQE(&QA9W0@=&EL(')E='1I
M9VAE='-S>7-T96UE="XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C4U(&%D;6EN
M+W!E<FUS+V%D9&-H:6QD+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED("(G
M)7,G('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B5S(&)L92!I:VME
M(&]P<')E='1E=#H@)7,N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#8@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3$*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(BP@9W5S=&EN9R`E<R`E<R(*;7-G<W1R("(E<R!PY2`E<R`E<R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3DY"B,L('!H<"UF;W)M870*;7-G
M:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L('9A<FEA
M8F5L(&UE;&QO;2`E<R!O9R`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M,#4S(&QI8B](;W)D92]&;W)M+G!H<#HR,3$R"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV.3$*;7-G:60@(BTM('-E;&5C="`M+2(*
M;7-G<W1R("(M+2!V96QG("TM(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$S
M,#D@<&\O=')A;G-L871I;VXN<&AP.C$S,3$*;7-G:60@(BTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=&EM
M92YP:'`Z,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R(%1I
M;65R<R!F;W)M870B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3D*;7-G:60@
M(C(T($AO=7(@1F]R;6%T(@IM<V=S='(@(C(T(%1I;65R<R!F;W)M870B"@HC
M.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR.`IM<V=I9"`B,C0@:&]U<G,B
M"FUS9W-T<B`B,C0@=&EM97(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,S0T
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(CQG971T97AT/B!T86<@;F]T(&-L
M;W-E9"!I;B!F:6QE("5S+EQN(@HB3W!E;FEN9R!T86<@9F]U;F0@:6X@;&EN
M92`E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3<*
M;7-G:60@(D$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI
M<R!B;&]C:RXB"FUS9W-T<B`B16X@9&%T86)A<V5K;V)L:6YG(&5R('#E:W)E
M=F0@9F]R(&1E;FYE(&)L;VMK96XN(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-C8*
M;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(D5N
M(&9A=&%L(&9E:6P@:&%R(&]P<'-TY71T(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z.30Q"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L
M:6<@4$=0+6[X:VME;"!E<B!PY6MR979D(&9O<B#E(&MR>7!T97)E(&UE;&1I
M;F=E;BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,38W"FUS9VED
M(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+B(*;7-G<W1R(")%;B!O9F9E;G1L:6<@4$=0+6[X:VME
M;"!E<B!PY6MR979D(&9O<B#E('9E<FEF:7-E<F4@<VEG;F5R="!M96QD:6YG
M+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$P.3@*;7-G:60@(B(*
M(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*
M;7-G<W1R("(B"B)%;B!O9F9E;G1L:6<@4$=0+6[X:VME;"P@<')I=F%T(%!'
M4"UN^&MK96P@;V<@<&%S<W!H<F%S92!E<B!PY6MR979D(&9O<B#E("(*(F1E
M:W)Y<'1E<F4@96X@;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P
M+G!H<#HQ,#$W"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB16X@;V9F96YT;&EG(%!'4"UN
M^&MK96PL('!R:79A="!01U`M;OAK:V5L(&]G('!A<W-P:')A<V4@97(@<.5K
M<F5V9"!F;W(@Y2`B"B)S:6=N97)E(&5N(&UE;&1I;F<N(@H*(SH@;&EB+TAO
M<F1E+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(B(*(D$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R
M("(B"B)%;B!O9F9E;G1L:6<@4R]-24U%+6[X:VME;"P@<')I=F%T(%,O34E-
M12UN^&MK96PL(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"`B"B)F;W(@Y2!D
M96MR>7!T97)E(&5N(&UE;&1I;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HT-#D*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"B)%;B!O9F9E;G1L
M:6<@4R]-24U%+6[X:VME;"P@<')I=F%T(%,O34E-12UN^&MK96PL(&]G('!A
M<W-P:')A<V4@97(@<.5K<F5V9"`B"B)F;W(@Y2!S:6=N97)E(&5N(&UE;&1I
M;F<N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HS.#(*;7-G:60@
M(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B16X@;V9F96YT;&EG(%,O34E-12UN^&MK96P@
M97(@<.5K<F5V9"!F;W(@Y2!K<GEP=&5R92!E;B!M96QD:6YG+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C4*(RP@9G5Z>GD*;7-G:60@
M(D%-(%)A:6XB"FUS9W-T<B`B4F5G;B!PY2!F;W)M:61D86=E;B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C8*(RP@9G5Z>GD*;7-G:60@
M(D%-(%-H;W=E<G,B"FUS9W-T<B`B4F5G;F)Y9V5R('#E(&9O<FUI9&1A9V5N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,R-PHC+"!F=7IZ
M>0IM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S='(@(E-N^&)Y9V5R('#E
M(&9O<FUI9&1A9V5N(@H*(SH@=&5M<&QA=&5S+V1A=&$O=&EM92YI;F,Z,CD*
M;7-G:60@(D%-+U!-(@IM<V=S='(@(D%-+U!-(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HR,#0*;7-G:60@(D%022!)1"(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O<B(*;7-G<W1R(")/;2!D96YN
M92!E9&ET;W)E;B(*"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C4R"FUS
M9VED(")!8F]U="XN+B(*;7-G<W1R(")/;2XN+B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O
M;2(*;7-G<W1R(")!8G-O;'5T="!N961E<G-T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE
M(@IM<V=S='(@(D%B<V]L=71T(&UI9'0B"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HV-#`*;7-G:60@(D%C8V5P="!R97%U97-T
M(@IM<V=S='(@(D=O9&MJ96YN(&9O<F5S</AR<V5L(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Q"FUS9VED(")!8V-E<'1E
M9"(*;7-G<W1R(")';V1T871T(@H*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,C@U
M"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M(@IM<V=S='(@(E1I;&=A;F<@;F5K=&5T('9E9"!O<'!R971T96QS92!A=B!6
M1E,@:V%T86QO9RXB"@HC.B!L:6(O5D93+VUU<W%L+G!H<#HQ,S@*;7-G:60@
M(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N(@IM<V=S='(@(E1I
M;&=A;F<@;F5K=&5T('9E9"!O<'!R971T96QS92!A=B!61E,@9FEL+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HW-0IM<V=I9"`B06-C;W5N="!087-S
M=V]R9"(*;7-G<W1R(")+;VYT;R!087-S;W)D(@H*(SH@;&EB+TYE="]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#(*;7-G:60@(D%C8V]U;G0@9G)O>F5N
M+B(*;7-G<W1R(")+;VYT;R!F<OAS970N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,R,`IM<V=I9"`B06-C;W5N=&EN9R(*;7-G<W1R(")";VMH
M;VQD:6YG+T%C8V]U;G1I;F<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT-3$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C(U"FUS9VED(")!8W1I;VYS(@IM<V=S='(@(DAA;F1L
M:6YG97(B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-30@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HQ,S8*(SH@=&5M<&QA=&5S+W!O<G1A;"]A9&0N
M:6YC.C$T('1E;7!L871E<R]A9&UI;B]G<F]U<',O861D8VAI;&0N:6YC.C$V
M"FUS9VED(")!9&0B"FUS9W-T<B`B3&5G9R!T:6PB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C(Q-"!A9&UI;B]G<F]U<',N<&AP.C(Q-0IM<V=I9"`B061D($-H
M:6QD($=R;W5P(@IM<V=S='(@(DQE9V<@=&EL('5N9&5R9W)U<'!E(@H*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HX,2!L:6(O2&]R9&4O4&5R;7,O54DN
M<&AP.C@R"FUS9VED(")!9&0@0VAI;&0@4&5R;6ES<VEO;B(*;7-G<W1R("),
M96=G('1I;"!U;F1E<G)E='1I9VAE=&5R(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*;7-G<W1R("),96=G('1I
M;"!H97(Z(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,#@@861M:6XO9W)O=7!S
M+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@1W)O=7`B"FUS9W-T<B`B3&5G9R!T
M:6P@;GD@9W)U<'!E(@H*(SH@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HW,"!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C<Q"FUS9VED(")!9&0@3F5W(%!E<FUI
M<W-I;VXB"FUS9W-T<B`B3&5G9R!T:6P@;GD@<F5T=&EG:&5T(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T;R`G)7,G(@IM<V=S='(@
M(DQE9V<@=&EL(&5N('5N9&5R9W)U<'!E('1I;"`G)7,G(@H*(SH@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C4S(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,3,U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD('!E<FUI<W-I
M;VX@=&\@)R5S)R(*;7-G<W1R("),96=G('1I;"!U;F1E<G)E='1I9VAE="!T
M:6P@)R5S)R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,P"FUS9VED(")!9&0@82!N
M97<@=7-E<CHB"FUS9W-T<B`B3&5G9R!T:6P@;GD@8G)U:V5R.B(*"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,CD*;7-G:60@(D%D
M9"!C;VQU;6XB"FUS9W-T<B`B3&5G9R!T:6P@:V]L;VYN92(*"B,Z('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,S4*;7-G:60@(D%D9"!N97<@
M;65M8F5R<R(*;7-G<W1R("),96=G('1I;"!N>64@;65D;&5M;65R(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,#,*;7-G:60@(D%D9"!P86ER
M(@IM<V=S='(@(DQE9V<@=&EL('!A<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU
M(&%S(&$@36]Z:6QL82!3:61E8F%R(@IM<V=S='(@(DQE9V<@=&EL("5S(&UE
M;GEE;B!S;VT@36]Z:6QL82!3:61E8F%R(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,Q"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@
M8V%L96YD87(B"FUS9W-T<B`B3&5G9R!T:6P@:2!M:6X@:V%L96YD97(B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C<T"FUS9VED(")!
M9&0@=&\@861D<F5S<R!B;V]K.B(*;7-G<W1R("),96=G('1I;"!I(&%D9')E
M<W-E8F]K.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M.#$*;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B3&5G
M9R!T:6P@:2!M:6X@861D<F5S<V5B;VLB"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,0IM<V=I9"`B061D('5S97(B"FUS9W-T<B`B3&5G9R!T:6P@8G)U:V5R(@H*
M(SH@861M:6XO=7-E<BYP:'`Z-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M061D960@)R5S)R!T;R!T:&4@<WES=&5M+"!B=70@8V]U;&0@;F]T(&%D9"!A
M9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@)2(*(G,N(@IM<V=S='(@
M(B(*(DQA('1I;"`G)7,G(&D@<WES=&5M970L(&UE;B!K=6YN92!I:VME(&QE
M9V=E('1I;"!E:W-T<F$@<F5G:7-T<F5R:6YG<VEN9F\Z("4B"B)S+B(*"B,Z
M('-I9VYU<"YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B061D960@)R5S
M)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@
M(DQA("<E<R<@=&EL('-Y<W1E;65T+B!$=2!K86X@;&]G9V4@:6YN(&[E+B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HY-38*;7-G:60@(D%D9&EN9R!N97<@
M9FEL97,@=&\@<F5P;W-I=&]R>3HB"FUS9W-T<B`B3&$@=&EL(&YY92!F:6QE
M<B!I(')E<&]S:71O<GDZ(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A
M9&0N:6YC.C0*;7-G:60@(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS
M9W-T<B`B375L:6=H970@9F]R(.4@;&5G9V4@=&EL(&YY92!B<G5K97)E(&5R
M(&1E86MT:79E<G0N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,S@@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,CD*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-S8*;7-G:60@(D%D9')E<W,B"FUS
M9W-T<B`B061R97-S92(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ
M,S0*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R(")!9')E<W-E($)O:R(*
M"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-PIM<V=I9"`B
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,B
M"FUS9W-T<B`B061M:6YI<W1R97(@+2!S971T(')E='1I9VAE=&5R(&9O<B!A
M;F1R92!B<G5K97)E(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(D%D;6EN:7-T<F%S:F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0P-@IM<V=I9"`B061S(@IM<V=S='(@(E)E:VQA;65R(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU-PIM
M<V=I9"`B069G:&%N:7-T86XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06QB86YI82(*
M;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S0@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")!;&=E<FEA(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$P"FUS9VED(")!;&EA<R(*
M;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(DIU
M<W1E<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(DIU<W1E<FEN9SHB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G
M<W1R(")!;&QE(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$X('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-C4*;7-G:60@(D%L;"!!=71H96YT:6-A
M=&5D(%5S97)S(@IM<V=S='(@(D%L;&4@875T96YT:7-E<G1E(&)R=6ME<F4B
M"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C$R
M"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S='(@(D%L;&4@1W)U<'!E<B(*"B,Z
M(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HS."!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C<T"FUS9VED(")!;&P@4&5R;6ES<VEO;G,B"FUS9W-T<B`B06QL
M92!R961D:6=H971E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S(@IM
M<V=S='(@(D%L;&4@9FER92!S:61E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.#4U"FUS9VED(")!;&QO=R!M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T
M<B`B5&EL;&%T="!F;&5R92!A9')E<W-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HU,C,*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L
M:7-T('1Y<&4_(@IM<V=S='(@(E1I;&QA='0@96YD<FEN9R!A=B!F;W)M871E
M="!PY2!N=6UM97)E<G1E(&QI<W1E<C\B"@HC.B!L:6(O2&]R9&4O1&%T851R
M964O<W%L+G!H<#HT,#,*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@
M(D5K<VES=&5R97(@86QL97)E9&4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,3(R"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G<W1R(")!
M;'1E<FYA=&EV($E-4U`@3&]G:6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-#DV"FUS9VED(")!;'1E<FYA=&4@24U34"!087-S=V]R9"(*;7-G<W1R
M(")!;'1E<FYA=&EV="!)35-0('!A<W-O<F0B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-#@X"FUS9VED(")!;'1E<FYA=&4@24U34"!5<V5R;F%M92(*
M;7-G<W1R(")!;'1E<FYA=&EV="!)35-0(&)R=6ME<FYA=FXB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M
M86EL(&%D9')E<W,B"FUS9W-T<B`B06QT97)N871I=B!E+7!O<W0@861R97-S
M92(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E<FYA
M=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L=&5R;F%T:79E(&UA;&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS9W-T<B`B06QT97)N
M871I=B!T96MS=#HB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C<@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C4Y"FUS9VED(")!;65R:6-A;B!386UO82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.CDW(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,3$W"FUS9VED(")!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C
M:69I960N(@IM<V=S='(@(D5N('5L;W9L:6<@=F5R9&D@=F%R(&]P<&=I='0N
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU
M-@IM<V=I9"`B06YD;W)R82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!;F=O;&$B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HU.`IM<V=I9"`B06YG=6EL;&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3(P"FUS9VED(")!;F]N>6UO=7,@4')O>'DB
M"FUS9W-T<B`B06YO;GEM(%!R;WAY(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-#D*;7-G:60@(D%N<W=E<B(*;7-G<W1R(")3=F%R(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;G1I9W5A(&%N9"!"
M87)B=61A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@
M861M:6XO<&AP<VAE;&PN<&AP.C,P(&QI8B](;W)D92]";&]C:R]522YP:'`Z
M-3D*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B4')O9W)A;2(*"B,Z('5T:6PO:6-O
M;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*;7-G
M<W1R(")0<F]G<F%M;&ES=&4B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,3,P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T<B`B4')O
M9W)A;6UE="!E<B!K;&%R="XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C(Q.`IM<V=I9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@
M(D]P<&1A=&5R(&]G<^4@<F5K=7)S:79T(&YE9&]V97(@9F]R('5N9&5R;6%P
M<&5R+V9I;&5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,S,*;7-G:60@(D%P<')O=F4B"FUS9W-T<B`B1V]D:VIE;FXB"@HC.B!L
M:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#4W"FUS9VED(")!<'!R;WAI
M;6%T92!3:7IE(@IM<V=S='(@(D]M=')E;G1L:6<@<W3X<G)E;'-E(@H*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-R!L:6(O2&]R
M9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<Q"FUS9VED(")!
M<F%B:6,@*%=I;F1O=W,M,3(U-BDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C(@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+WII<"YP:'`Z-C8*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z
M.#$*;7-G:60@(D%R8VAI=F4@1FEL92!3:7IE(@IM<V=S='(@(D9I;'-T^')R
M96QS92!PY2!A<FMI=F5T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C$@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C4*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#`*;7-G:60@(D%R8VAI
M=F4@3F%M92(*;7-G<W1R(")!<FMI=FYA=FXB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.CD*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(#\B"FUS9W-T<B`B17(@9'4@4TE+2T52('#E(&%T
M(&1U('9I;"!F:F5R;F4@<F5G:7-T<F5R:6YG<V9O<F5S</AR<V5L96X@9F]R
M("5S/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY
M"B,L('!H<"UF;W)M870*;7-G:60@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T
M;R!D96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_(@IM<V=S='(@(D5R
M(&1U('-I:VME<B!PY2!A="!D=2!V:6P@<VQE='1E("<E<R<@;V<@9&5N<R!U
M;F1E<F=R=7!P97(_(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)G96YT:6YA(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G
M:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S(*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S
M='(@(DMU;G-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,P(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,`IM<V=I9"`B07)U8F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$U"FUS9VED(")!<V-E;G-I;VX@27-L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR.0IM<V=I9"`B
M07-C:6D@07)T(@IM<V=S='(@(D%S8VEI(&MU;G-T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0Q-0IM<V=I
M9"`B07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_(@IM<V=S='(@(D)E(&]M(&)E:W)E9G1E;'-E(&;X
M<B!G:F5N;F]M9OAR:6YG(&%V('9E9&QI:V5H;VQD<V]P97)A<VIO;F5R(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3@*;7-G:60@(D%S<VEG;FUE;G0@
M8V]L=6UN<R(*;7-G<W1R(")+;VQO;FYE86YV:7-N:6YG(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,38V"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C(T.0HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS,3@*;7-G:60@(D%T=&%C:&5D
M(&ES(&%N(&E#86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@
M<V5N="(*;7-G<W1R(")6961L86=T(&D@<W9A<F5T(&5R(&5N(&E#86QE;F1A
M<B!F:6P@9F]R(&5N(&9O<F5S</AR<V5L(&1U('-E;F1T92(*"B,Z(&%D;6EN
M+V=R;W5P<RYP:'`Z-S4*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N
M+65X:7-T96YT(&=R;W5P+B(*;7-G<W1R(")&;W)S^&MT92#E('-L971T92!E
M;B!G<G5P<&4@<V]M(&EK:V4@96MS:7-T97)E<BXB"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C,X"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&;W)S^&MT92#E('-L
M971T92!E;B!R971T:6=H970@<V]M(&EK:V4@96MS:7-T97)E<BXB"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HY.`IM<V=I9"`B071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@(D9O<G/X:W1E
M(.4@<F5D:6=E<F4@96X@<F5T=&EG:&5T('-O;2!I:VME(&5K<VES=&5R97(N
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(D9O
M<G/X:W1E(.4@<F5D:6=E<F4@96X@9&5L="!R97-S=7)S('-O;2!I:VME(&5K
M<VES=&5R97(N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3<W"FUS9VED(")!='1E;F1E97,B"FUS9W-T<B`B1&5L=&%G97)E
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W1G>BYP:'`Z.#8*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T<B`B
M071T<FEB=70B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S@Q(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,@IM
M<V=I9"`B075G=7-T(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D%U<W1R86QI82(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C@@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")!=7-T<FEA(@IM<V=S='(@(MAS=&5R<FEK92(*"B,Z
M(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,38S"FUS9VED(")!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!=71H7V-Y<G-Q;#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I
M9V4@24U!4"!U='9I9&5L<V5N+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ,S<*;7-G:60@(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@
M:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB"FUS9W-T<B`B075T:%]C>7)U
M<SH@0F%C:V5N9"!I;FYE:&%R(&EK:V4@;OAD=F5N9&EG(&9U;FMS:F]N86QI
M=&5T+B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ,C0*;7-G:60@
M(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@2V%N(&EK:V4@9FEN;F4@9&5N(&[X
M9'9E;F1I9V4@24U!4"!U='9I9&5L<V5N+B(*"B,Z(&QI8B](;W)D92]!=71H
M+V9T<"YP:'`Z-#`*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@
M97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE
M;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@HB075T:%]F='`Z($MA
M;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($944"!U='9I9&5L<V5N+B!+
M;VUP:6QE<B!02%`@;65D("TM(@HB96YA8FQE+69T<"XB"@HC.B!L:6(O2&]R
M9&4O075T:"]I;6%P+G!H<#HV.`IM<V=I9"`B075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@(D%U=&A?:6UA
M<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I9&5L
M<V5N+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4S"FUS9VED(")!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB
M"FUS9W-T<B`B075T:%]K<F(U.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N
M9&EG92!K<F(U('5T=FED96QS96XN(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A
M<"YP:'`Z-C$*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VQD87`Z($MA;B!I:VME
M(&9I;FYE(&1E;B!N^&1V96YD:6=E($Q$05`@=71V:61E;'-E;BXB"@HC.B!L
M:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ.#D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@
M=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R(")!=71H7VQD87`Z($MU
M;FYE(&EK:V4@;&5G9V4@=&EL(&)R=6ME<B`E<RX@4V5R=F5R96X@<V$Z("(*
M"B,Z(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C(R.0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*
M;7-G<W1R(")!=71H7VQD87`Z($MU;FYE(&EK:V4@9FIE<FYE(&)R=6ME<F5N
M("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;&1A<"YP:'`Z,C@Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2W5N;F4@:6MK92!O<'!D871E<F4@
M8G)U:V5R("5S(@H*(SH@;&EB+TAO<F1E+T%U=&@O;6-A;"YP:'`Z-3`*;7-G
M:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R(")!=71H7VUC86PZ($MA;B!I:VME(&9I;FYE(&1E;B!N
M^&1V96YD:6=E($U#04P@=71V:61E;'-E;BXB"@HC.B!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C8U"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A
M=71H.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!S;6)A=71H('5T
M=FED96QS96XN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HR.3D*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G<W1R(")!
M=71E;G1I<V5R:6YG(&9E:6QE="(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z-CD@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HW.`HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H96YT:6-A=&EO;B!F86EL
M960N("5S(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@9F5I;&5T+B`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+W)A9&EU<RYP:'`Z,3@Q"FUS9VED(")!=71H96YT
M:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")!
M=71E;G1I<V5R:6YG(&YE:W1E="!A=B!2041)55,@=&IE;F5R+B(*"B,Z(&QI
M8B]61E,O9G1P+G!H<#HX,#`*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG(&UO="!&
M5%`@=&IE;F5R96X@9F5I;&5T+B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.#,*;7-G:60@(D%V86EL86)L92!F:65L9',Z(@IM<V=S='(@(E1I
M;&=J96YG96QI9V4@9F5L=#HB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E(@IM
M<V=S='(@(E9E;G1E<B!PY2!S=F%R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C,Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B07IE<F)A:6IA;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/
M1D@@17AC=7-E<R(*;7-G<W1R(")"3T9(($5X8W5S97,B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED
M(")"86-K9W)O=6YD(@IM<V=S='(@(D)A:V=R=6YN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R
M;W5N9"!#;VQO<B(*;7-G<W1R(")"86MG<G5N;G-F87)G92(*"B,Z(&QI8B](
M;W)D92]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"860@:V5R8F5R;W,@<&%S
M<W=O<F0N(@IM<V=S='(@(D9E:6P@:V5R8F5R;W,@<&%S<V]R9"XB"@HC.B!L
M:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B0F%D(&ME<F)E<F]S
M('5S97)N86UE+B(*;7-G<W1R(")&96EL(&ME<F)E<F]S(&)R=6ME<FYA=FXN
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0U(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M,PIM<V=I9"`B0F%H86UA<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"86AR86EN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<S"FUS9VED(")"
M86QT:6,@*$E33RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,S0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86YG;&%D
M97-H(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS,R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C$*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR-3DS"FUS9VED(")"87)E(@IM<V=S='(@
M(D)L86YK(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C,Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E<R<@;F]T
M(&9O=6YD+B(*;7-G<W1R(")"87-E:V%T86QO9R!F;W(@9W)A9FEK:R`G)7,G
M(&)L92!I:VME(&9U;FYE="XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@(D)A<V5L:6YE(@IM<V=S
M='(@(D=R=6YN;&EN:F4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#D@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8T"FUS9VED(")"96QA<G5S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G
M:60@(D)E;&=I=6TB"FUS9W-T<B`B0F5L:6=A(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS,@HC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0F5L:7IE(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HT,"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C(*;7-G:60@(D)E;FEN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HT,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E<FUU
M9&$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0V(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV-`IM<V=I9"`B0FAU=&%N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$T"FUS9VED(")":7)T
M:&1A>2(*;7-G<W1R(")"=7)S9&%G(@H*(SH@;&EB+TAO<F1E+T)L;V-K+T-O
M;&QE8W1I;VXN<&AP.C,R-@HC+"!P:'`M9F]R;6%T"FUS9VED(")";&]C:R!<
M(B5S7"(@;V8@87!P;&EC871I;VX@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T
M<B`B0FQO:VL@7"(E<UPB(&%V('!R;V=R86UM970@7"(E<UPB(&)L92!I:VME
M(&9U;FYE="XB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.#D*
M;7-G:60@(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;VMK(&EN;G-T:6QL
M:6YG97(B"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z-S0*;7-G
M:60@(D)L;V-K(%1Y<&4B"FUS9W-T<B`B0FQO:VL@='EP92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L
M9"(*;7-G<W1R(")&970B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#,@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8S"FUS9VED(")";VQI=FEA(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#8*;7-G:60@(D)O;VMM87)K
M<R(*;7-G<W1R(")";VMM97)K97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C(P"FUS9VED(")";W)D97(B"FUS
M9W-T<B`B4F%M;64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@U"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R
M(")286UM971Y:VME;'-E.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T
M<B`B4F%M;65R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV,0IM<V=I9"`B0F]S;FEA(&%N9"!(97)Z96=O=FEN82(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.38*;7-G:60@(D)O
M=&@B"FUS9W-T<B`B0F5G9V4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#@@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8T"FUS9VED(")";W1S=V%N82(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S4*;7-G:60@(D)O='1O;2(*;7-G<W1R(")"=6YN(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C0W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I9"`B0F]U
M=F5T($ES;&%N9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(D)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8S"FUS9VED(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R("(B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-C8Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D)U:6QD:6YG($U/(&9I;&5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8W,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")"=6EL9&EN9R!L;V-A;&4@)7,N+BX@(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HS-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@
M(D)U;&=A<FEA(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`B4'5N:W1L:7-T92(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)U<FMI;F$@1F%S;R(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,SD@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8R"FUS9VED(")"=7)U;F1I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS.3<*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I9"`B0U)#
M(@IM<V=S='(@(D-20R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C(Q"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*;7-G<W1R(")#
M4DP@1&ES=')I8G5S:F]N<W!U;FMT97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL
M(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B16=E;G-K87!E<B!F;W(@8U]E;&QE
M+BXN(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,30S"FUS9VED(")#86QE;F1A
M<B(*;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HR,#D*;7-G:60@(D-A;&TB"FUS9W-T<B`B4W1I;&QE(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#0*;7-G
M:60@(D-A;6)O9&EA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#<*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-A;65R;V]N(@IM<V=S
M='(@(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED
M(")#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R(")+86X@:6MK92!N=6QL
M<W1I;&QE('!A<W-O<F0@875T;VUA=&ES:RP@:V]N=&%K="!D:6X@861M:6YI
M<W1R871O<BXB"@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,C0Q(&QI
M8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$R"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@
M(DMA;B!I:VME(&MO8FQE('1I;"!)34%0('1J96YE<F5N.B`E<R(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C4*;7-G:60@
M(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S
M+V1E;&5T92YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$W"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3<*;7-G
M:60@(D-A;F-E;"(*;7-G<W1R(")!=F)R>70B"@HC.B!T96UP;&%T97,O<')O
M8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P
M;W)T(@IM<V=S='(@(D%V8G)Y="!P<F]B;&5M<F%P<&]R="(*"B,Z(&QI8B]6
M1E,O9G1P+G!H<#HR-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E
M;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EK:V4@<VQE='1E(&9I
M;&5N(%PB)7-<(BXB"@HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HT-PHC.B!L:6(O5D93+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3,*;7-G:60@(D-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@9FEN
M;F4@96X@=&5M<"UK871A;&]G+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+G!H
M<#HY-PIM<V=I9"`B0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL
M92<@<&%R86UE=&5R+B(*;7-G<W1R(")+86X@:6MK92!F;W)T<V5T=&4@=71E
M;B`G=&%R9V5T1FEL92<@<&%R86UE=&5R+B(*"B,Z(&QI8B]61E,O9G1P+G!H
M<#HR-C4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92!D:7)E
M8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!S;&5T=&4@:V%T86QO
M9V5N(%PB)7-<(BXB"@HC.B!L:6(O2&]R9&4O1&%T851R964N<&AP.C$Q,B!L
M:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HU-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N(@IM<V=S
M='(@(DMA;B!I:VME('-L971T92P@)60@8F%R;B!E:W-I<W1E<F5R+B(*"B,Z
M(&QI8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B(@HB0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S
M='(@(B(*(DMA;B!I:VME(&5N9')E(')E:VME9OAL9V5N+"!A;G1A;&QE="!O
M<'!F^')I;F=E<B!V86QG="!F;W(@;VUS;W)T97)I;F<@(@HB<W1E;6UE<B!I
M:VME(&UE9"!A;G1A;&QE="!L86=R961E(&]P<&;X<FEN9V5R+B(*"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$X"FUS9VED(")#86YN
M;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R
M(")+86X@:6MK92!S96YD92!M96QD:6YG96X@=&EL(&1E="!S<&5S:69I<V5R
M=&4@;G5M;65R970N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8U(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HT.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV.0IM<V=I9"`B0V%P92!697)D92(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(T"FUS9VED(")#87!T:6]N(@IM<V=S='(@(E5T9')A9R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B
M96QS(@IM<V=S='(@(DMA=&5G;W)I97(@;V<@971I:V5T=&5R(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@
M(D-A>6UA;B!)<VQA;F1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DW"FUS9VED(")#96QL(%!H;VYE(@IM<V=S
M='(@(DUO8FEL=&5L969O;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E;&P@4')O<&5R=&EE
M<R(*;7-G<W1R(")%9V5N<VMA<&5R(&9O<B!C96QL92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL
M('!A9&1I;F<Z(@IM<V=S='(@(DQU9G0@<G5N9'0@:6YN:&]L9"!A=B!C96QL
M93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B16=E
M;G-K87!E<B!F;W(@8V5L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G
M<W1R("),=69T(')U;F1T(&-E;&QE;CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,3(V-@IM<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(DUO8FEL=&5L969O
M;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<T"FUS9VED(")#96QT:6,@
M*$E33RTX.#4Y+3$T*2(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(V"FUS9VED(")#96YT97(B
M"FUS9W-T<B`B4V5N=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<U"FUS
M9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<R,PIM<V=I9"`B0V5R
M=&EF:6-A=&4@1&5T86EL<R(*;7-G<W1R(")$971A;&IE<B!F;W(@<V5R=&EF
M:6MA="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C(P"FUS9VED
M(")#97)T:69I8V%T92!0;VQI8VEE<R(*;7-G<W1R(")2971T;FEN9W-L:6YJ
M97(@9F]R('-E<G1I9FEK870B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(D-H860B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3DV"FUS
M9VED(")#:&%I<B!097)S;VXB"FUS9W-T<B`B3W)D<W1Y<F5R(@H*(SH@=&5M
M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO
M<G!C<W5M+FEN8SHY-PIM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D5N9')E(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8V"FUS9VED("(B"B)#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R("(*(F5M86EL<RXB"FUS9W-T<B`B
M(@HB16YD<F4@;F%V;B!O9R!A9')E<W-E('-O;2!M;W1T86ME<F4@<V5R(&[E
M<B!D92!L97-E<B!O9R!S=F%R97(@<.4@<&]S=&5N(&1I;BXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"FUS
M9VED(")#:&%R(@IM<V=S='(@(E1E9VXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?
M:R!,:6YK+BXN(@IM<V=S='(@(E-J96M?:R!L:6YK+BXN(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,PIM<V=I9"`B0VAE
M8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P
M97)F;W)M(&%T('1H:7,@=&EM92XB"FUS9W-T<B`B5F5L9R!D92!O<&5R87-J
M;VYE;F4@9'4@=FEL('5T9OAR92!NY2XB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8X"FUS9VED(")#:&EL92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C$@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C4T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C8X"FUS9VED(")#:&EN82(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$W-@IM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED
M(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C(X,@IM<V=I9"`B0VAO;W-E(&$@
M<&%S<W=O<F0B"FUS9W-T<B`B5F5L9R!E='0@<&%S<V]R9"(*"B,Z(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C@Q"FUS9VED(")#:&]O<V4@82!U<V5R
M;F%M92(*;7-G<W1R(")696QG(&5T="!B<G5K97)N879N(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4R"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8R-@IM<V=I9"`B0VAO;W-E
M(&%N(&%C=&EO;CHB"FUS9W-T<B`B5F5L9R!H86YD;&EN9SHB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C@X"FUS9VED(")#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z(@IM<V=S='(@(E9E;&<@:'9O<F1A;B!D=2!V:6P@=FES
M92!D871O97(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&ES='1Y<&5?;&%N9RYJ<SHR,@IM<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@
M='EP92`H9F]R(&]R9&5R960@;&ES=',I(@IM<V=S='(@(E9E;&<@<W1I;"!P
MY2!L:7-T971Y<&4@*&9O<B!N=6UM97)E<G1E(&QI<W1E<BDB"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C4U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#
M:')I<W1M87,@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]61E,N<&AP.C8U
M-2!L:6(O3F5T+U--4RYP:'`Z,S$Q"B,L('!H<"UF;W)M870*;7-G:60@(D-L
M87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S
M<V5D969I;FES:F]N(&9O<B`E<R!B;&4@:6MK92!F=6YN970N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C@U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;&5A
M;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE("5S+BXN(@IM<V=S='(@(B(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-C<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQE86YI;F<@=7`@;&]C86QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(X"FUS9VED(")#;&5A<B(*
M;7-G<W1R(")+;&%R="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B"FUS
M9W-T<B`B1FIE<FX@35-/9F9I8V4@=&%G<R(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V-L96%R+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(D-L96%R
M(&]U="!U<V5R.B`E<R(*;7-G<W1R(")&:F5R;B!B<G5K97(Z("5S(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$V"FUS9VED(")#;&5A
M<B!U<V5R(@IM<V=S='(@(D9J97)N(&)R=6ME<B(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+VQI<W0N:6YC.C,W"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B
M"FUS9W-T<B`B1FIE<FX@8G)U:V5R9&%T82(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]N;W1I8V5?8F]T=&]M+FEN8SHV"FUS9VED(")#;&EC:R!T;R!#
M;VYT:6YU92(*;7-G<W1R(")+;&EK:R!F;W(@Y2!F;W)T<V5T=&4B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-@IM<V=I9"`B0VQI
M8VMA=&5L;"!V:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10
M(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B
M3'5K:R!V:6YD=2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0R"FUS9VED
M(")#;&]U9',B"FUS9W-T<B`B4VMY97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S(Y"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B4VMY970B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8U
M"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*;7-G:60@(D-O;&QA
M<'-E(%-I9&5B87(B"FUS9W-T<B`B4VSE('-A;6UE;B!S:61E;&EN:F5N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B4V%M;65N
M<VSE='0@<F%M;64B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO8V]L;W(N<&AP.C$X(&QI8B]";&]C:R]C;VQO<BYP:'`Z,CD*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR.0IM<V=I9"`B0V]L;W(B"FUS9W-T<B`B1F%R9V4B"@HC.B!L:6(O2&]R
M9&4O0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,CDW(&QI8B](;W)D92]";&]C:R]#
M;VQL96-T:6]N+G!H<#HR.3@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0W,B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP
M.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C4R"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8X"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C8Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC
M.C@V"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B1F%R9V5V96QG97(B
M"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@S-0IM<V=I9"`B0V]L;W5R('-E
M;&5C=&EO;B(*;7-G<W1R(")&87)G979A;&<B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P,PHC+"!F=7IZ>0IM<V=I9"`B
M0V]L<SHB"FUS9W-T<B`B2V]L;VYN97(Z(@H*(SH@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$Y,S`*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS9W-T<B`B2V]L;VYN
M92UT:71L97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS
M9VED(")#;VUI8W,B"FUS9W-T<B`B5&5G;F5S97)I97(B"@HC.B!A9&UI;B]C
M;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M;6%N
M9&\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA;F0@
M4VAE;&PB"FUS9W-T<B`B2V]M;6%N9&]V:6YD=2(*"B,Z('!O+W1R86YS;&%T
M:6]N+G!H<#HS.`IM<V=I9"`B0V]M;6%N9"!O<'1I;VYS.B(*;7-G<W1R(")6
M86QG(&9O<B!K;VUM86YD;SHB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3<*
M;7-G:60@(D-O;6UA;F1S.B(*;7-G<W1R(")+;VUM86YD;V5R.B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C,Y.0IM<V=I9"`B0V]M;65N="(*;7-G
M<W1R(")+;VUM96YT87(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z.3DU"FUS
M9VED(")#;VUM:71T:6YG.B(*;7-G<W1R(")3:F5K:R!I;FXZ(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3`*;7-G:60@(D-O;6UO;B!.86UE
M(@IM<V=S='(@(E9A;FQI9R!N879N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#4*;7-G:60@(D-O;6]R;W,B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR-#(*
M;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`B1FER;6$B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.3<*;7-G:60@(D-O;7!L971E
M9"(*;7-G<W1R(")&97)D:6<B"@HC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY-R!L
M:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]M<&]S92!-97-S86=E("@E<RDB"FUS9W-T<B`B4VMR
M:78@;65L9&EN9R`H)7,I(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Q
M"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`B1&%T86UA<VMI;F5R(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-#<*;7-G:60@(D-O;F1I=&EO;G,B"FUS
M9W-T<B`B5FEL:^5R(@H*(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z.#D*;7-G
M:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B"FUS9W-T<B`B1F]R<VMJ
M96QL97(@:2!I;FYS=&EL;&EN9V5N92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ,C4*;7-G:60@(D-O;F9I9W5R871I;VX@;F5E9',@=7!D871I;F<N
M(@IM<V=S='(@(DEN;G-T:6QL:6YG97(@8F5H^'9E<B!O<'!D871E<FEN9RXB
M"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z.3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(DMO;F9I9W5R97(@)7,B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,W"FUS9VED(")#
M;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(D)E:W)E9G0@<&%S<V]R9"(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G
M:60@(D-O;F=O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HU,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C`*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R
M871I8R!297!U8FQI8R!O9B!T:&4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-B!L:6(O2&]R9&4O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S$Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS
M9W-T<B`B5&EL:V]B;&EN9R!M:7-L>6MT97,N(@H*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(P-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$Y"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(E1I;&MO8FQI;F<@;6ES;'EK=&5S.B`B"@HC.B!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HW.3,*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T
M:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B2V]B;&EN9V5N('1I;"!D
M96X@;V9F96YT;&EG92!N^&MK96QT:F5N97)E;B!F96EL970N(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-SDU"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@
M4F5A<V]N.B`E<R`H)7,I(@IM<V=S='(@(DMO8FQI;F=E;B!T:6P@9&5N(&]F
M9F5N=&QI9V4@;OAK:V5L=&IE;F5R96X@9F5I;&5T+B#%<G-A:SH@)7,@*"5S
M*2(*"B,Z(&QI8B]61E,O9G1P+G!H<#HW.30*;7-G:60@(D-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(DMO8FQI;F=E;B!T:6P@
M1E10('1J96YE<F5N(&UI<VQY:W1E<RXB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C4V"FUS9VED(")#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
M2V]N=&%K=&5N92!B;&4@;&%G="!T:6P@861R97-S96)O:V5N(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-3D@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G
M>BYP:'`Z-S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@)R5S
M)R(*;7-G<W1R("));FYH;VQD(&D@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(Y"FUS9VED(")#;VYT:6YU92(*;7-G<W1R(")&;W)T
M<V5T="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU."!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-C<*;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G<W1R(")#
M;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P:65R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM
M<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:65R('9A;&=T(&]M
M<N5D92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<R"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O<'EI;F<@)7,@=&\@)7,B"FUS9W-T<B`B2V]P:65R97(@
M)7,@=&EL("5S(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV,@HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HV.`IM<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED
M(")#;W1E(&0G279O:7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE
M<W-A9V4N(@IM<V=S='(@(DMU;FYE(&EK:V4@4$=0+6MR>7!T97)E(&UE;&1I
M;F<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#4U"FUS9VED(")#
M;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92XB"FUS9W-T<B`B2W5N;F4@:6MK
M92!01U`M<VEG;F5R92!M96QD:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HT,3$*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M
M97-S86=E+B(*;7-G<W1R(")+=6YN92!I:VME(&MR>7!T97)E(&UE;&1I;F=E
M;B!M960@4R]-24U%+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-#@U"FUS9VED(")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS
M9W-T<B`B2W5N;F4@:6MK92!S:6=N97)E(&UE;&1I;F=E;B!M960@4R]-24U%
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*
M;7-G<W1R(")+=6YN92!I:VME(&QE9V=E('1I;"!K;VYT86MT.B`E<R(*"B,Z
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$Q,PIM<V=I9"`B0V]U;&0@;F]T
M(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(E1I;&MO8FQI;F<@=&EL
M($Q$05`M<V5R=F5R(&9E:6QE="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,34T(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<R(*;7-G<W1R(")+=6YN92!I:VME('-J96MK92!T:6QG:F5N
M9V5L:6<@:W)E9&ET="X@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M-#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@
M<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")+;&%R=&4@:6MK
M92#E(&MO8FQE('1I;"!T:F5N97)E;B`G)7,G('9E9"!B<G5K(&%V($944#H@
M)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`W-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<R(*;7-G<W1R(")+=6YN
M92!I:VME(&MO<&EE<F4@)7,@=&EL("5S(@H*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,R.0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")+
M=6YN92!I:VME(&QA9V4@9&ES=')I8G5S:F]N<VQI<W1E+B`E<R(*"B,Z('!O
M+W1R86YS;&%T:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C$P-C4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-R96%T92!L;V-A;&4@
M9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z(@IM<V=S='(@(DMU;FYE(&EK:V4@
M;W!P<F5T=&4@;&]C86QE(&MA=&%L;V<@9F]R(&QO8V%L92`E<SHB"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,3(V"FUS9VED(")#;W5L9"!N;W0@
M9&5C<GEP="!01U`@9&%T82XB"FUS9W-T<B`B2W5N;F4@:6MK92!D96MR>7!T
M97)E(%!'4"!M96QD:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-30P"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB
M"FUS9W-T<B`B2W5N;F4@:6MK92!D96MR>7!T97)E(%,O34E-12!M96QD:6YG
M+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-3`*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E
M<R(*;7-G<W1R(")+;&%R=&4@:6MK92#E('-L971T92!K;VYT86MT+B`E<R(*
M"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-C4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!S;&5T=&4@9&ES=')I
M8G5S:F]N<VQI<W1E+B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C,W"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!S
M;&5T=&4@<V5T=7`@;W!P9W)A9&5R:6YG<W-C<FEP="`G)7,G+B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,SDY(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.CDU.0IM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(DMU;FYE(&EK:V4@
M9FEN;F4@;6]T=&%K97)S(&4M<&]S="!A9')E<W-E+B(*"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#@*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(DMU;FYE(&EK
M:V4@:&5N=&4@=70@:&5L92!A9')E<W-E8F]K96XN(@H*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C4Q,`IM<V=I9"`B0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")+=6YN
M92!I:VME('5T(&AE;&4@9&ES=')I8G5S:F]N<VQI<W1E;BXB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#8Q"FUS9VED(")#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+B(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&AE;&4@;&ES=&5N
M(&UE9"!D:7-T<FEB=7-J;VYS;&ES=&5R+B(*"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z-CD*(SH@;&EB+U9&4R])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@U"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N(@IM<V=S='(@
M(DMU;FYE(&EK:V4@;&%S=&4@:6YN('-T<F%T96=I("<E<R<N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$Q
M"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E
M8W0N<&AP.C,Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I
M<B`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&]P<')E='1E(&MA=&%L;V=E
M;B`G)7,G+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C<R,`IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B2W5N;F4@:6MK92!H96YT92!U="!O9F9E;G1L:6<@
M;OAK:V5L(&9R82!N^&MK96QT:F5N97)E;BXB"@HC.B!L:6(O3F5T+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-S`R(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S4T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O
M<&5N("5S+B(*;7-G<W1R(")+=6YN92!I:VME(.5P;F4@)7,N(@H*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30P
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N("<E<R<@9F]R
M('=R:71I;F<N(@IM<V=S='(@(DMU;FYE(&EK:V4@Y7!N92`G)7,G(&9O<B!S
M:W)I=FEN9RXB"@HC.B!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0Q-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<R(*;7-G<W1R(")+86X@:6MK92#E<&YE($UA:6YT
M96YA;F-E7U1A<VLM;6]D=6QE;B`E<R(*"B,Z(&QI8B]61E,O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<Q"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R
M(")+=6YN92!I:VME(.5P;F4@:V%T86QO9V5N("<E<R<N(@H*(SH@;&EB+U9&
M4R]/8FIE8W0N<&AP.C(W,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@<F5A9"`E<RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L97-E("5S(@H*(SH@
M<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*;7-G:60@(B(*(D-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*(F1E=&%I;',@87)E(&YO="!C;W)R
M96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@
M:68@>6]U(&YE960@(@HB9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)+=6YN
M92!I:VME(&YU;&QS=&EL;&4@<&%S<V]R9&5T(&9O<B!D96X@9F]R97-P=7)T
M92!B<G5K97)E;BX@3F]E;B!E;&QE<B!A;&QE("(*(F1E=&%L:F5N92!E<B!U
M<FEK=&EG92X@1F]R<_AK(&EG:F5N(&5L;&5R(&MO;G1A:W0@861M:6YI<W1R
M871O<F5N(&AV:7,@9'4@(@HB=')E;F=E<B!Y='1E<FQI9V5R92!H:F5L<"XB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS-#D*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,X-B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,SDR"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H
M<#HS.3@*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`B
M2W5N;F4@:6MK92!H96YT92!U="!!0TPB"@HC.B!L:6(O3F5T+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DMU;FYE
M(&EK:V4@:&5N=&4@=70@861R97-S96)O:RX@)7,B"@HC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3`Q"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B2W5N;F4@:6MK92!H96YT92!U="!D:7-T<FEB=7-J;VYS;&ES=&4N
M("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C0U,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T
M(&1I<W1R:6)U<VIO;G-L:7-T92X@)7,B"@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C`V(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V
M+G!H<#HR,C8*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C(S
M,`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI
M=&EE<R(*;7-G<W1R(")+=6YN92!I:VME(&AE;G1E('5T(&EN9F]R;6%S:F]N
M(&]M('1J96YE<F5N<R!F=6YK<VIO;F%L:71E=&5R(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E=F5R="!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")+=6YN92!I:VME(')E=F5R=&5R92!K;VYF
M:6=U<F%S:F]N96YE+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.CDU"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G<W1R(")+=6YN92!I:VME(&9J97)N
M92!K871A;&]G96X@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H
M<#HW,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92`E<R!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9W)E("5S(&MO
M;F9I9W5R87-J;VXN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(DMU;FYE(&EK:V4@
M;&%G<F4@96X@8F%C:W5P(&MO;F9I9W5R87-J;VXN(@H*(SH@861M:6XO<V5T
M=7`O:6YD97@N<&AP.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B2W5N
M;F4@:6MK92!L86=R92!E;B!B86-K=7`@8V]N9FEG=7)A<VIO;CH@)7,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!L86=R92!S971U<"!O<'!G<F%D
M97)I;F=S+7-C<FEP=&5T('1I;#H@)R5S)RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M(")+=6YN92!I:VME(&QA9W)E(&)A8VMU<"!K;VYF:6=U<F%S:F]N<V9I;&5N
M("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@(@HB
M;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M
M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T<B`B(@HB2W5N
M;F4@:6MK92!L86=R92!K;VYF:6=U<F%S:F]N<V9I;&5N("5S+B!$=2!K86X@
M96YT96X@8F5N>71T92!D96<@878@96X@878@(@HB;75L:6=H971E;F4@9F]R
M(.4@;&%G<F4@9&%T82!T:6QB86ME('1I;"`E<R!E;&QE<B!K;W!I97)E(&MO
M9&5N('5N9&5R("(*(FUA;G5E;'0@=&EL("5S+B(*"B,Z(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C$R,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@
M3$1!4"!S97)V97(N(@IM<V=S='(@(DMU;FYE(&EK:V4@=71F^')E('/X:R!P
MY2!,1$%0('1J96YE<F5N+B(*"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@W"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!U;FQI;FL@)R5S)RXB"FUS9W-T<B`B2W5N;F4@:6MK92!F
M:F5R;F4@)R5S)RXB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z,C(Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,B"FUS9W-T<B`B2W5N;F4@:6MK92!O<'!D871E<F4@:V]N
M=&%K="X@)7,B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-#`Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMU;FYE(&EK:V4@;W!P9&%T
M97)E(&1I<W1R:6)U<VIO;G-L:7-T96XN("5S(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`G)7,G.B`E<R(*;7-G<W1R(")+=6YN
M92!I:VME('-K<FEV92!K;VYF:6=U<F%S:F]N(&9O<B`G)7,G.B`E<R(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-38*;7-G:60@(D-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN(@IM<V=S='(@(DMU;FYE(&EK:V4@9FEN;F4@36]Z:6QL82!3
M:61E8F%R+B!3:F5K:R!A="!D96X@97(@Y7!E;BXB"@HC.B!L:6(O2&]R9&4O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD;B=T(&=I=F4@=7-E<B`G)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S
M(&9O<B!T:&4@9F]L9&5R("<E<R<Z("5S(@IM<V=S='(@(D)R=6ME<F5N("<E
M<R<@8FQE(&=I='0@9OAL9V5N9&4@<F5T=&EG:&5T97(@=&EL(&UA<'!E;B`G
M)7,G.B`E<R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#$V"FUS9VED(")#
M;W5N=&5D('1E>'0B"FUS9W-T<B`B5&%L="!T96MS="(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")#;W5N=')Y(@IM<V=S='(@
M(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C<S"FUS9VED
M(")#;W5R<V5S(@IM<V=S='(@(DMU<G-E<B(*"B,Z('1E;7!L871E<R]R<&-S
M=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M.3<*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,0IM<V=I9"`B
M0W)E871E(@IM<V=S='(@(D]P<')E='0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D-R96%T
M92!A(&QI;FLB"FUS9W-T<B`B3W!P<F5T="!E;B!L:6YK(@H*(SH@=&5M<&QA
M=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHX.0IM<V=I9"`B0W)E871E
M(&$@;F5W(&]N92(*;7-G<W1R(")/<'!R971T(&5N(&YY(@H*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.CDU"FUS9VED(")#<F5A=&4@<W5B
M(&9O;&1E<G,B"FUS9W-T<B`B3W!P<F5T="!U;F1E<FUA<'!E<B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(R,@IM<V=I9"`B0W)E871O<B!097)M:7-S:6]N<R(*;7-G<W1R(")2971T
M:6=H971E<B!F;W(@96EE<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,C$U
M"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS9W-T<B`B2W)E9&ET=&MO
M<G1N=6UM97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HV-`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B0W)O871I82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C8U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#
M=6)A(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@IM<V=I
M9"`B0W5R<F5N="!0:&%S92(*;7-G<W1R(")':F5L9&5N9&4@9F%S92(*"B,Z
M(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM
M<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(D=J96QD96YD92!T:60B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-3,*(RP@9G5Z>GD*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@
M(D=J96QD96YD92!54DP@97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T<B`B1VIE;&1E;F1E(';F
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S,*;7-G:60@
M(D-U<G)E;G0@8V]N9&ET:6]N.B`B"FUS9W-T<B`B1VIE;&1E;F1E('5T<VEK
M=&5R.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C,R"FUS9VED(")#=7)R96YT('-T>6QE(@IM<V=S='(@(D=J96QD96YD
M92!S=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N(@IM<V=S='(@(E1I;'!A<W,@;W!P9V%V97(@<V]M(&MJ^')E
M<R!V960@:6YN;&]G9VEN9R!T:6P@)7,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(P"FUS9VED(")#=70B
M"FUS9W-T<B`B2VQI<'`@=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,U"FUS9VED(")#=70@<V5L96-T:6]N(@IM<V=S
M='(@(DML:7!P('5T('9A;&=T(&]M<N5D92(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C8*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D-Y<')U<R(*;7-G
M<W1R(")+>7!R;W,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I
M9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-SD*;7-G:60@(D-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED
M(")#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HV-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I
M9"`B0WIE8V@@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,R!T96UP;&%T97,O9&%T82]D871E
M+FEN8SHT-PHC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T
M97,O9&%T82]D871E+FEN8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHU,`IM<V=I9"`B1$0B"FUS9W-T<B`B1$0B"@HC.B!L:6(O2&]R9&4O36%I
M;G1E;F%N8V4N<&AP.C,X"FUS9VED(")$86EL>2(*;7-G<W1R(")$86=L:6<B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#(S"FUS9VED(")$871A
M(@IM<V=S='(@(D1A=&$B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z-C4*;7-G
M:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R92!U=&9O<G-K
M97(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C,X,B!L:6(O2&]R9&4O34E-
M12]6:65W97(O<F9C.#(R+G!H<#HW-PIM<V=I9"`B1&%T92(*;7-G<W1R(")$
M871O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3(*
M;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T;R!-;W1T871T(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(W.38*;7-G:60@(D1A=&4@<V5L96-T
M:6]N(@IM<V=S='(@(D1A=&\@=F%L9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HR-S<*;7-G:60@(D1A>2(*;7-G<W1R(")$86<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,S4*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM<V=S='(@(E-L971T(&MO;&]N
M;F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@U
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,C(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-@IM<V=I9"`B
M1&5C96UB97(B"FUS9W-T<B`B1&5S96UB97(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$V"FUS9VED(")$
M96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B1&5S:6UA;'1A;&PB"@HC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#4*;7-G:60@(D1E
M8VQI;F5D(@IM<V=S='(@(D%V<VSE='0B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E
M;G0B"FUS9W-T<B`B4F5D=7-E<B!I;FYR>6MK(@H*(SH@;&EB+W!R969S+G!H
M<#HQ,#@@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ.3$*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`B4W1A;F1A<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHT-PHC.B!T96UP;&%T97,O<')E9G,O8V%T
M96=O<GEM86YA9V5M96YT+FEN8SHX,0IM<V=I9"`B1&5F875L="!#;VQO<B(*
M;7-G<W1R(")3=&%N9&%R9"!F87)G92(*"B,Z(&QI8B](;W)D92])9&5N=&ET
M>2YP:'`Z.3(*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B4W1A
M;F1A<F1I9&5N=&ET970B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3D@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR,#0*;7-G:60@(D1E9F%U;'0@4&5R
M;6ES<VEO;G,B"FUS9W-T<B`B4W1A;F1A<F0@<F5T=&EG:&5T97(B"@HC.B!L
M:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(P-0IM<V=I9"`B1&5F875L="!P97)M
M:7-S:6]N<R(*;7-G<W1R(")3=&%N9&%R9"!R971T:6=H971E<B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HS,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS
M9W-T<B`B1&5F:6YI<VIO;F5R(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C0S"FUS9VED(")$96QE9V%T92!P;W-I=&EO;B(*
M;7-G<W1R(")$96QE9V5R('!O<VES:F]N(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-CDS"FUS9VED(")$96QE9V%T960B"FUS
M9W-T<B`B1&5L96=E<G0B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<R(&%D;6EN
M+W!E<FUS+V1E;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU
M,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-R!L:6(O2&]R9&4O4&5R;7,O
M54DN<&AP.C,R-PHC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,T-R!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-S`@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,PHC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.CDY('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHQ,PHC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN
M8SHS-`IM<V=I9"`B1&5L971E(@IM<V=S='(@(E-L971T(@H*(SH@861M:6XO
M9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR,3<*;7-G:60@(D1E
M;&5T92!'<F]U<"(*;7-G<W1R(")3;&5T="!G<G5P<&4B"@HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C8P(&QI8B](;W)D92]097)M<R]522YP:'`Z.#0*
M;7-G:60@(D1E;&5T92!097)M:7-S:6]N(@IM<V=S='(@(E-L971T(')E='1I
M9VAE="(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HY-@IM
M<V=I9"`B1&5L971E(&%N9"!P=7)G92!M97-S86=E<R(*;7-G<W1R(")3;&5T
M="!O9R!F:F5R;B!M96QD:6YG97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L
M;"(*;7-G<W1R(")3;&5T="!C96QL92(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C
M;VQU;6XB"FUS9W-T<B`B4VQE='0@:V]L;VYN92(*"B,Z(&%D;6EN+W1E;7!L
M871E<RYP:'`Z,30X"FUS9VED(")$96QE=&4@97AI<W1I;F<@86QT97)N871E
M('1E;7!L871E(@IM<V=S='(@(E-L971T(&5K<VES=&5R96YD92!A;'1E<FYA
M=&EV(&UA;"(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3`@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HS,C8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(@IM<V=S='(@(D9J97)N(')E='1I
M9VAE=&5N92!T:6P@)R5S)R(*"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,S(Y"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T<B`B1FIE
M<FX@<F5T=&EG:&5T96YE('1I;"`G)7,G(&]G(&%L;&4@=6YD97(M<F5T=&EG
M:&5T97(_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-PIM<V=I9"`B1&5L971E(')O=R(*;7-G<W1R(")3;&5T
M="!R860B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN:6YC
M.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I='DB"FUS9W-T<B`B
M4VQE='0@=F%L9W0@:61E;G1I=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V"FUS9VED(")$96QE=&4@
M=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S='(@(E-L971T(&=J96QD96YD92!K
M;VQO;FYE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8R"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W
M(@IM<V=S='(@(E-L971T(&=J96QD96YD92!R860B"@HC.B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C0X"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S:6]N
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/R(*;7-G<W1R(")3;&5T=&4@9&5N
M;F4@<F5T=&EG:&5T96X@;V<@86QL92!U;F1E<BUR971T:6=H971E<C\B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S
M='(@(E-L971T('-E='5P(&]P<&=R861E<FEN9W,M<V-R:7!T("<E<R<N(@H*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X-2!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$Y"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C8Q"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(DQE
M=F5R:6YG<W1I9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,2!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S`*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N;6%R:R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,@IM
M<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(D%V<VSE(&9O<F5S</AR<V5L
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<Q
M"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B(*;7-G<W1R(")!=G-LY2!F;W)E<W#X<G-E;"!F;W(@;&5D:6<O;W!P=&%T
M="UI;F9O<FUA<VIO;B(*"B,Z('-E<G9I8V5S+W!R;V)L96TN<&AP.CDU('-E
M<G9I8V5S+W!R;V)L96TN<&AP.CDY('-E<G9I8V5S+W!R;V)L96TN<&AP.C$P
M.0IM<V=I9"`B1&5S8W)I8F4@=&AE(%!R;V)L96TB"FUS9W-T<B`B0F5S:W)I
M=B!P<F]B;&5M970B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3,S(&QI8B](
M;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V-0HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,P"FUS9VED
M(")$97-C<FEP=&EO;B(*;7-G<W1R(")"97-K<FEV96QS92(*"B,Z(&QI8B](
M;W)D92YP:'`Z,C`Q"FUS9VED(")$971A:6QS("AA;'-O(&EN($AO<F1E)W,@
M;&]G9FEL92DZ(@IM<V=S='(@(D1E=&%L:F5R("AO9W/E(&D@2&]R9&4G<R!L
M;V=G9FEL*3HB"@HC.B!L:6(O2&]R9&4N<&AP.C(P-0IM<V=I9"`B1&5T86EL
M<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS
M9W-T<B`B1&5T86QJ97(@:&%R(&)L:71T(&QO9V=E="!F;W(@861M:6YI<W1R
M871O<F5N+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3,*;7-G
M:60@(D1E=F5L;W!M96YT(@IM<V=S='(@(E5T=FEK;&EN9R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C$U"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B
M1&]G9W!U;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.3(*;7-G:60@
M(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1&]G9W!U;FMT
M(&9O<B!D96X@<VES=&4@=&EM96XZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ.3`*;7-G:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(D1O
M9V=P=6YK=#H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHS.`IM<V=I9"`B1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0B"FUS
M9W-T<B`B4F5T;FEN9R!F<F$@=F5N<W1R92!M;W0@:/AY<F4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED(")$
M:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")2971N:6YG(&9R82!H
M^'ER92!M;W0@=F5N<W1R92(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,Y
M"FUS9VED(")$:7)E8W1O<GDB"FUS9W-T<B`B2V%T86QO9R(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HR-38*;7-G:60@(D1I<W!L87D@,C0M:&]U<B!T
M:6UE<S\B"FUS9W-T<B`B5FES(#(T+71I;65R<R!T:61E<C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I<W!L87D@3W!T:6]N<R(*
M;7-G<W1R(")6:7-N:6YG<W9A;&<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C@S"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM<V=S='(@(E9I
M<R!F;W)V87)S96P@*%1!1BDB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C@P
M-@IM<V=I9"`B1&ES<&QA>2!F;W)M870B"FUS9W-T<B`B5FES;FEN9W-F;W)M
M870B"@HC.B!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C(P,PIM<V=I9"`B1&ES
M<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(DUE;&1I;F<@;VT@;W)D
M;FEN9R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,"!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-CD*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S`*;7-G:60@(D1J:6)O=71I(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E
M<FUS+V1E;&5T92YP:'`Z-#8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HS,C<*
M;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T<B`B26MK92!S;&5T="(*"B,Z
M('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-`IM<V=I9"`B1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS9W-T<B`B26MK92#E
M<&YE(&UA:6YE;F%N8V4N<&AP(&1I<F5K=&4B"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHQ.2!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ
M.0IM<V=I9"`B1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD
M(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.B(*;7-G<W1R(")+<GES
M<R!A=B!H97(@:'9I<R!D96X@9OAR<W1E(')A9&5N(&EN;F5H;VQD97(@9F5L
M="UN879N970Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<R(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C<S(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HW,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B
M1&]M:6YI8V%N(%)E<'5B;&EC(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+T-O;G1E;G1S+G!H<#HX-C@*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@
M(DQA<W0@;F5D(@H*(SH@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@V
M.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS
M9W-T<B`B3&%S="!N960@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z
M,34V"FUS9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!02%`@<V-R:7!T+B(*;7-G<W1R("),87-T(&YE9"!G96YE<F5R="!K;VYF
M:6=U<F%S:F]N('-O;2!02%`@<V-R:7!T+B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,#DQ"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(").961T
M<F5K:W-L:7-T92(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I
M9"`B1')U9W,B"FUS9W-T<B`B365D:7-I;F5R(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,SDY"FUS9VED(")%+4UA:6PB"FUS9W-T<B`B12UP;W-T
M(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,W"FUS9VED(")%4E(B"FUS9W-T<B`B15)2(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C<U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW
M,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B16-U861O
M<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C(Y-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHY,@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$X
M,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="(*;7-G<W1R(")2961I
M9V5R(@H*(SH@;&EB+TAO<F1E+T)L;V-K+U5)+G!H<#HU,2!T96UP;&%T97,O
M<&]R=&%L+V5D:70N:6YC.C(R"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@
M(E)E9&EG97)E(&)L;VMK(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#@@861M
M:6XO9W)O=7!S+G!H<#HR,38*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`B
M4F5D:6=E<B!'<G5P<&4B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C4Y
M(&QI8B](;W)D92]097)M<R]522YP:'`Z.#,*;7-G:60@(D5D:70@4&5R;6ES
M<VEO;B(*;7-G<W1R(")2961I9V5R(')E='1I9VAE=&5R(@H*(SH@<V5R=FEC
M97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N
M<R(*;7-G<W1R(")2961I9V5R(')E='1I9VAT97(B"@HC.B!S97)V:6-E<R]S
M:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@(D5D:70@
M4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(E)E9&EG97(@<F5T=&EG:&5T
M97(@9F]R("5S(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z.0IM<V=I
M9"`B161I="!O<'1I;VYS(&9O<CHB"FUS9W-T<B`B4F5D:6=E<B!V86QG(&9O
M<CHB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$T"B,L('!H<"UF
M;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@
M(E)E9&EG97(@<F5T=&EG:&5T97(@9F]R("5S(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z,C`T(&QI8B](;W)D92]097)M<R]522YP:'`Z,C@X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS
M9W-T<B`B4F5D:6=E<B!R971T:6=H971E<B!F;W(@)7,B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")/
M<'!LYG)I;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C<S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C<Q"FUS9VED(")%9WEP="(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C$W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D5L
M(%-A;'9A9&]R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT,@IM<V=I9"`B16QE;65N="XN
M+B(*;7-G<W1R(")%;&5M96YT+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(D5M
M(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-3,@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HR,C<*;7-G:60@(D5M86EL(@IM<V=S='(@(D4M
M<&]S="(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@Y('1E;7!L
M871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA:6P@061D<F5S<R(*
M;7-G<W1R(")%+7!O<W1A9')E<W-E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$Y-#<*;7-G:60@(D5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+B(*;7-G
M<W1R(")%+7!O<W1A9')E<W-E(&WE('-T96UM92XB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3DW,PIM<V=I9"`B16UA:6P@=VET:"!C;VYF:7)M871I;VXB
M"FUS9W-T<B`B12UP;W-T(&UE9"!B96MR969T96QS92(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HR.#`*;7-G:60@(D5M;W1I8V]N
M<R(*;7-G<W1R(")&^&QE;'-E<B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S$Q"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R
M(")4;VT@;65L9&EN9RXB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ
M,S$*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B5&]M="!R97-U;'1A
M="XB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ,30*;7-G:60@
M(D5M<'1Y('-E87)C:"!T97)M<R(*;7-G<W1R(")4^&T@<_AK96MR:71E<FEE
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S(*;7-G:60@(D5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_(@IM<V=S='(@(D%K=&EV97(@;75L:6=H970@9F]R(.4@<V5T=&4@
M:6YN(&)I;&1E<B!F<F$@9V%L;&5R:65R(&D@=&5K<W1E;C\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3`W"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")!:W1I=F5R92!H^'ER96ML:6MK
M(&UE;GD_(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-#0X"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C4U,PIM<V=I9"`B16YD(@IM<V=S='(@(E-L=71T(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(U.3$@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#`*;7-G:60@
M(D5N9"!Y96%R(@IM<V=S='(@(L5R<W-L=71T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.0IM<V=I9"`B16YL87)G92!%
M9&ET;W(B"FUS9W-T<B`B1VKX<B!E9&ET;W)E;B!S=/AR<F4B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C$Q"FUS9VED("(B"B)%;G1E<B!A('-E8W5R
M:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N
M965D('1O(')E<V5T('EO=7(@(@HB<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@
M=&AE(&YA;64@;V8@>6]U<B!P970_)SHB"FUS9W-T<B`B(@HB4VMR:78@:6YN
M(&5T="!S:6MK97)H971S<W#X<G-MY6P@<V]M(&1U('9I;"!B;&D@<W!U<G0@
M;VT@:'9I<R!D=2#X;G-K97(@Y2`B"B)N=6QL<W1I;&QE('!A<W-O<F1E="!D
M:71T+"!F+F5K<RX@)VAV82!E<B!N879N970@<.4@:VKF;&5D>7)E="!D:71T
M/R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI
M;6%G95]L86YG+FIS.C(R"FUS9VED(")%;G1E<B!T:&4@:6UA9V4@55),(&AE
M<F4B"FUS9W-T<B`B4VMR:78@:6YN(&%D<F5S<V5N('1I;"!B:6QD970@:&5R
M(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$Q-3$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B16YT<FEE<SH@)60@=&]T86PL("5D('5P+71O+61A=&4L("5D(&YE
M=RP@)60@8VAA;F=E9"P@)60@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")%
M<75A=&]R:6%L($=U:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")%<FET<F5A(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.0HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M-#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4Q"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HW.`IM
M<V=I9"`B17)R;W(B"FUS9W-T<B`B1F5I;"(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HR-S@*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,S0W"B,L('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R('-E;F1I;F<@<F5P;'DZ("5S+B(*;7-G<W1R(")&96EL('9E9"!S96YD
M:6YG(&%V('-V87(Z("5S(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,30*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B1F5I;"!M960@92UP;W-T(&UE;&1I;F=E;BXB"@HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#,*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@=W)I=&EN9R`G)7,G+B(*;7-G
M<W1R(")&96EL('9E9"!S:W)I=FEN9R!T:6P@)R5S)RXB"@HC.B!P;R]T<F%N
M<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU,C(@<&\O=')A
M;G-L871I;VXN<&AP.C$S-3@*(SH@<&\O=')A;G-L871I;VXN<&AP.C$T,3D@
M<&\O=')A;G-L871I;VXN<&AP.C$T.#(*;7-G:60@(D5R<F]R.B`B"FUS9W-T
M<B`B1F5I;#H@(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B17-T;VYI82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<R"FUS9VED(")%
M=&AI;W!I82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S8*;7-G:60@(D5T:&YI8R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HU-@IM<V=I9"`B175R;W!E(@IM<V=S='(@(D5U<F]P82(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,CD*;7-G:60@(D5V97)Y(#$U
M(&UI;G5T97,B"FUS9W-T<B`B2'9E<G0@,34N(&UI;G5T="(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS-SD*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*
M;7-G<W1R(")(=F5R="`R+B!M:6YU='0B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(V(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S<*;7-G:60@(D5V
M97)Y(#,P('-E8V]N9',B"FUS9W-T<B`B2'9E<G0@,S`N('-E:W5N9"(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(DAV97)T
M(#4N(&UI;G5T="(*"B,Z(&QI8B](;W)D92]-86EN=&5N86YC92YP:'`Z,SD*
M;7-G:60@(D5V97)Y($QO9VEN(@IM<V=S='(@(DAV97(@:6YN;&]G9VEN9R(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S`*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R(")(=F5R(&AA;'9T:6UE(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,R-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<X"FUS
M9VED(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`B2'9E<G0@;6EN=71T(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C@*;7-G:60@(D5X86UP;&4@
M=F%L=65S.B(*;7-G<W1R(")%:W-E;7!E;'9E<F1I97(Z(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<V(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,V"FUS9VED(")%>&5C=71E(@IM<V=S='(@(DMJ^'(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,CDY('!O+W1R86YS;&%T:6]N+G!H
M<#HS,C`@<&\O=')A;G-L871I;VXN<&AP.C,V,@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z-#0Q('!O+W1R86YS;&%T:6]N+G!H<#HU-#$@<&\O=')A;G-L871I
M;VXN<&AP.C8P,0HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-S`R('!O+W1R86YS
M;&%T:6]N+G!H<#HW,S<@<&\O=')A;G-L871I;VXN<&AP.C<Y.`HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z.#<U('!O+W1R86YS;&%T:6]N+G!H<#HY.#D@<&\O
M=')A;G-L871I;VXN<&AP.C$P,3$*;7-G:60@(D5X96-U=&EN9SHB"FUS9W-T
M<B`B2VKX<F5R.B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C,X
M-@IM<V=I9"`B17AP86YD(@IM<V=S='(@(E5T=FED(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,0IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B571V:60@4VED96)A<B(*"B,Z(&QI8B](;W)D92]344PO2V5Y
M=V]R9',N<&AP.C$V.0IM<V=I9"`B17AP96-T960@)RDG(@IM<V=S='(@(D9O
M<G9E;G1E="`G*2<B"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HQ
M-S8*;7-G:60@(D5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FTB"FUS9W-T<B`B1F]R=F5N=&5T(&)L86YK="!O<F0@96QL97(@<75O
M=&5T('/X:V5K<FET97)I92(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C,Y.`IM<V=I9"`B17AP:7)A=&EO;B!$871E(@IM<V=S='(@(E5T;/AP<V1A
M=&\B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B
M17AP;VYE;G0B"FUS9W-T<B`B16MS<&]N96YT(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%>'1R86-T:6YG(&9R
M;VT@)7,N+BX@(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(D9O<F=R=6YN<V9A<F=E(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$W,0IM<V=I9"`B1E10('5P;&]A9"!O9B!S971U<"(*;7-G<W1R(")/
M<'!L87-T:6YG(&%V('-E='5P('9I82!&5%`B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O<W%L+G!H<#HR-#`*;7-G:60@(D9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+B(*;7-G<W1R(")5=&AE;G1I;F<@878@:6YS=&EL;&EN9V5R(&9E
M:6QE="XB"@HC.B!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HQ,#,*;7-G:60@
M(D9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")4
M:6QK;V)L:6YG('1I;"!,1$%0+71J96YE<B!F96EL970N(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O<VUB+G!H<#HQ,#,*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N(@IM<V=S='(@(E1I;&MO8FQI;F<@=&EL(%--0BUT
M:F5N97(@9F5I;&5T+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HV,S$*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM
M<V=S='(@(D9E:6QE="!V960@:V]P:65R:6YG(&9R82!<(B5S7"(N(@H*(SH@
M;&EB+U9&4R]F='`N<&AP.C8S-@HC+"!P:'`M9F]R;6%T"FUS9VED(")&86EL
M960@=&\@8V]P>2!T;R!<(B5S7"(N(@IM<V=S='(@(D9E:6QE="!V960@:V]P
M:65R:6YG('1I;"!<(B5S7"(N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP
M:'`Z.3(*;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B1F5I;&5T('9E9"!O<'!R971T96QS92!A=B!N>2!3
M05-,(&MO8FQI;F<N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C8W,0HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S
M='(@(D9E:6QE="!V960@9FQY='1I;F<@=&EL(%PB)7-<(BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,P"FUS9VED(")&86ER(@IM<V=S
M='(@(E!E;G0@=N9R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@T(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,PIM<V=I9"`B1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C,U"FUS9VED(")&871A;"!%<G)O
M<CHB"FUS9W-T<B`B1F%T86P@1F5I;#H@(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.3`*;7-G:60@(D9A>"(*;7-G<W1R(")&87@B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<U(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,3(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-@IM<V=I9"`B1F5B
M<G5A<GDB"FUS9W-T<B`B1F5B<G5A<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C$X"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(D;X;&5S('-O;2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.30*;7-G:60@(D9E
M96QS(&QI:V4Z("(*;7-G<W1R(")&^&QE<R!S;VTZ("(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,S$*;7-G:60@(D9E=R!3:&]W97)S(@IM
M<V=S='(@(D;E(&)Y9V5R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,S,@IM<V=I9"`B1F5W(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")&Y2!S
M;OAB>6=E<B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.3(X"FUS9VED(")&
M:65L9"!M871R:7@B"FUS9W-T<B`B1F5L=&UA=')I<V4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C@Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")&:6II
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&4B"FUS9W-T<B`B06YT86QL(&9I;&5R
M.B`E<R!F:6QE<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP
M.C8S(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%N=&%L;"!F:6QE
M<CH@)7,@9FEL97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S0Y
M"FUS9VED(")&:6QE($UA;F%G97(B"FUS9W-T<B`B1FEL8F5H86YD;&5R(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")&:6QN
M879N(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y.#`*;7-G:60@(D9I;&4@
M<V5L96-T:6]N(@IM<V=S='(@(D9I;'9A;&<B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,30X,PIM<V=I9"`B1FEL92!U<&QO860B"FUS9W-T<B`B3&%S="!O
M<'`@9FEL97(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#<T"FUS9VED
M(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B3W!P;&%S
M=&EN9R!A=B!F:6QE<B!S=/AT=&5S(&EK:V4N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C@V"FUS9VED(")&:6QT97)S(@IM<V=S='(@(D9I;'1E
M<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S(*;7-G:60@(D9I;FQA;F0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W,0IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R(")&^')S=&4@
M:&%L=FWE;F4B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K
M+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(D;X
M<G-T92!K=F%R=&WE;F4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B1F%S="!F
M;W)H;VQD(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(Q-`IM<V=I9"`B1FQI<"(*;7-G<W1R(")3;G4B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,R"FUS9VED(")&
M;&]A="(*;7-G<W1R(")&;'ET(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,S,PIM<V=I9"`B1F]G(@IM<V=S='(@(E3E:V4B"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z,38S(&QI8B]61E,O;75S<6PN<&AP.C$P.`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T
M<B`B36%P<&5N("5S(&5K<VES=&5R97(@:6MK92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C(*;7-G:60@(D9O;G0@0V]L
M;W(B"FUS9W-T<B`B1F]N=&9A<F=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(DUA="(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM
M<V=I9"`B1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B
M"FUS9W-T<B`B1F]R(&YE='1L97-E<F4@<V]M(&EK:V4@<W3X='1E<B!B:6QD
M97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S,@IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B1F]R=F%R<V5L("A4048I(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C<T"FUS9VED("(B"B)&;W)E8V%S="!$
M87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@
M8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O
M=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D%N=&%L
M;"!D86=E<G,@9F]R=F%R<V5L("AVYG(@;V)S('#E(&%T(&1E="!R971U<FYE
M<G1E(&9O<G9A<G-L970@:6YN96AO;&1E<B`B"B)BY61E(&1A9R!O9R!N871T
M.R!E;B!S=&]R('9E<F1I(&AE<B!K86X@<F5S=6QT97)E(&D@96X@<W1O<B!B
M;&]K:RDB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.CDU"FUS9VED
M(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T<B`B1VQE;70@<&%S<V]R
M9&5T/R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,S$*;7-G:60@
M(D9O<FUS(@IM<V=S='(@(E-K:F5M865R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(E-K:F5B;F4O;'EK
M:V4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U
M;F4@='EP92(*;7-G<W1R(")4>7!E('-K:F5B;F4O;'EK:V4B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@
M(E-K:F5B;F5R+VQY:VME(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,Y
M"FUS9VED(")&;W)T=6YE<R`R(@IM<V=S='(@(E-K:F5B;F5R+VQY:VME(#(B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#$T"FUS9VED(")&;W)U
M;7,B"FUS9W-T<B`B1F]R=6UE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS-3@*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@(E9I9&5R97-E;F1T
M92(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-#,Y"B,L('!H<"UF;W)M870*
M;7-G:60@(D9O=6YD(&%P<&QI8V%T:6]N<SH@)7,B"FUS9W-T<B`B1F%N="!P
M<F]G<F%M;65N93H@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30S,PIM
M<V=I9"`B1F]U;F0@9&ER96-T;W)I97,Z(@IM<V=S='(@(D9A;G0@:V%T86QO
M9V5N93HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R
M+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")&<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@(D9R
M86UE<R(*;7-G<W1R(")286UM97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@S"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F%N8V4B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D9R86YC
M92P@365T<F]P;VQI=&%N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C0Q-PIM<V=I9"`B1G)E92]"=7-Y($EN
M9F]R;6%T:6]N(@IM<V=S='(@(DQE9&EG+V]P<'1A='0M:6YF;W)M87-J;VXB
M"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C<*
M;7-G:60@(D9R964O0G5S>2!297!L>2(*;7-G<W1R("),961I9R]O<'!T871T
M('-V87(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT,C(*;7-G:60@(D9R964O0G5S>2!297%U97-T(@IM<V=S='(@(DQE9&EG
M+V]P<'1A='0@9F]R97-P^')S96PB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HR-S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,S0Q"FUS9VED(")&<F5E+T)U<WD@4F5Q=65S="!2
M97-P;VYS92(*;7-G<W1R(")3=F%R('#E(&QE9&EG+V]P<'1A='0@9F]R97-P
M^')S96PB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3$@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C<U"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ.#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED
M(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<Y"FUS9VED(")&<F]M(@IM<V=S
M='(@(D9R82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*
M;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")&<F$@(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-#@*;7-G:60@(D9U;&P@1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B1G5L;"!B97-K<FEV96QS92(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HX,B!L:6(O0FQO8VLO;6]O;BYP:'`Z,3@Q"FUS9VED(")&=6QL
M($UO;VXB"FUS9W-T<B`B1G5L;&WE;F4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C,Y"FUS9VED(")&=6QL($YA;64B"FUS9W-T<B`B
M1G5L;'0@;F%V;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@
M(D9U>GIY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX
M."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=A8F]N(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VTB"FUS
M9W-T<B`B1V%L;&5R:2!D=2#X;G-K97(@Y2!H96YT92!B:6QD92!F<F$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S='(@(D=A;&QE<FDZ(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDV(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM
M<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B1V5N97)A=&4@)7,@0V]N
M9FEG=7)A=&EO;B(*;7-G<W1R(")'96YE<F5R("5S(&MO;F9I9W5R87-J;VXB
M"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O8V]N9FEG+FAT;6PZ,3`*;7-G
M:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@(D=E;F5R97)T(&MO9&4B"@HC
M.B!P;R]T<F%N<VQA=&EO;BYP:'`Z-#<Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871I;F<@<W1A='5S(&9O<B!M;V1U;&4@)7,N+BXB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDP(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M-0IM<V=I9"`B1V5O<F=I82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z-CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")'97)M86YY(@IM
M<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S4R"FUS9VED(")'
M971O<'0@17)R;W(Z("(*;7-G<W1R(")'971O<'0@1F5I;#H@(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.CDS(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HY,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B
M1VAA;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.CDT
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HW-@IM<V=I9"`B1VEB<F%L=&%R(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DY"FUS9VED(")':79E
M;B!.86UE(@IM<V=S='(@(D=I='0@3F%V;B(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C$V"FUS9VED(")';R(*;7-G<W1R(")';R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B1V]E9&5L(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!3
M96%R8V@B"FUS9W-T<B`B4_AK('#E($=O;V=L92(*"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR,C`*;7-G:60@(D=R87ES8V%L92(*
M;7-G<W1R(")'<N5T;VYE(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=R965C92(*;7-G<W1R(")(96QL
M87,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B1W)E96L@
M*$E33RTX.#4Y+3<I(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965N;&%N9"(*;7-G
M<W1R(")'<OAN;&%N9"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HX.2!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(D=R=7!P92!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](
M;W)D92]'<F]U<"YP:'`Z-3<*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y(@IM<V=S='(@(D=R=7!P96YA=FX@:V%N(&EK:V4@=N9R92!T
M;VUM92(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(X-0IM<V=I9"`B1W)O=7`@<&5R;6ES<VEO;G,B"FUS
M9W-T<B`B1W)U<'!E<F5T=&EG:&5T97(B"@HC.B!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HQ-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR-3@@;&EB+T)L;V-K
M+V=O;V=L92YP:'`Z,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M-S<*;7-G:60@(D=R;W5P<R(*;7-G<W1R(")'<G5P<&5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.CDX(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HY-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-PIM<V=I9"`B1W5A
M9&5L;W5P92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW.`IM<V=I9"`B1W5A;2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`R(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HY.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.`IM
M<V=I9"`B1W5A=&5M86QA(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS9W-T<B`B(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3(W(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,C$S"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.#@*;7-G:60@(D=U
M97-T(%!E<FUI<W-I;VYS(@IM<V=S='(@(E)E='1I9VAE=&5R(&9O<B!G:F5S
M="(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R."!L:6(O2&]R9&4O4&5R
M;7,O54DN<&AP.C(Q-`IM<V=I9"`B1W5E<W0@<&5R;6ES<VEO;G,B"FUS9W-T
M<B`B4F5T=&EG:&5T97(@9F]R(&=J97-T(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0S.0IM<V=I9"`B1W5E<W1B;V]K(@IM<V=S='(@(D=J97-T
M96)O:R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HY-R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S8*;7-G:60@(D=U:6YE82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-SD*;7-G:60@(D=U:6YE
M82U":7-S874B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$P-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,S,0IM
M<V=I9"`B2$@B"FUS9W-T<B`B2$@B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.34U"FUS9VED(")(5$U,(@IM<V=S='(@(DA434PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@U"FUS9VED(")(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C
M96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R96$@;F5K=&5R(.4@<VQE='1E
M(&1E;B!S:7-T92!C96QL96X@:2!E;B!R860N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-@IM<V=I9"`B2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L
M=6UN(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N96MT97(@Y2!S;&5T
M=&4@9&5N('-I<W1E(&MO;&]N;F5N(&D@=&%B96QL96XN(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R(")(5$U,07)E82!N96MT97(@Y2!S
M;&5T=&4@9&5N('-I<W1E(')A9&5N(&D@=&%B96QL96XN(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O:'1T<"YP:'`Z,38T"FUS9VED(")(5%10($%U=&AE;G1I8V%T
M:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%144"!A=71E;G1I<V5R:6YG(&EK
M:V4@9G5N;F5T+B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3`@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDY"FUS9VED(")(87-H+4%L9V]R:71H
M;2(*;7-G<W1R(")(87-H+6%L9V]R:71M92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,S0*;7-G:60@(DAA>F4B"FUS9W-T<B`B1&ES(@H*
M(SH@;&EB+TAO<F1E+T9O<FTN<&AP.CDQ-"!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,CDR,0IM<V=I9"`B2&5A9&5R(@IM<V=S='(@(DAO9&4B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAE
M87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(*;7-G<W1R("(B"@HC
M.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B2&5B<F5W("A)4T\M
M.#@U.2TX+4DI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G
M<W1R(")(^'ED92(*"B,Z(&QI8B](;W)D92](96QP+G!H<#HQ-SD@;&EB+TAO
M<F1E+TAE;'`N<&AP.C$X-B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HQ-PHC
M.B!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L<"(*;7-G
M<W1R(")(:F5L<"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@
M(DAJ96QP('1I;"!B<G5K(&%V(&5D:71O<B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,S8X"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&IE;'!E<B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HY-0IM<V=I9"`B(@HB2&5L<&5R(&%P<&QI
M8V%T:6]N('1O(&-R96%T92!A;F0@;6%I;G1A:6X@=')A;G-L871I;VYS(&9O
M<B!T:&4@2&]R9&5<;B(*(F9R86UE=V]R:R!A;F0@:71S(&%P<&QI8V%T:6]N
M<RY<;B(*(D9O<B!A;B!I;G1R;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$
M344@:6X@=&AI<R!D:7)E8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R(")(86QV
M:W5L92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$W('1E;7!L
M871E<R]D871A+V-S=FEN9F\N:6YC.C$W"FUS9VED(")(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(DAE<B!E<B!B96=Y;FYE
M;'-E;B!PY2!F:6QE;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S<V"FUS9VED(")(:6=H(@IM<V=S='(@(DCX>2(*"B,Z(&QI8B](;W)D
M92](:7-T;W)Y+G!H<#HS,C(*;7-G:60@(DAI<W1O<GD@96YT<GD@;F%M97,@
M;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`B2&ES=&]R:65O<'!F^')I;F=E
M<B!PY2!H82!N879N('-O;2!I:VME(&5R('1O;6UE(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L871E<R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8SHT"FUS9VED(")(;U]M92(*;7-G<W1R(")(:F5?;2(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-#,@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$P-`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G
M:60@(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,30V-@IM<V=I9"`B2&]M92(*;7-G<W1R(")(
M:F5M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C4@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ-3@*;7-G:60@(DAO
M;64@061D<F5S<R(*;7-G<W1R(")(:F5M;65A9')E<W-E(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3,*;7-G:60@(DAO;64@4&AO
M;F4B"FUS9W-T<B`B5&5L969O;B!H:F5M;64B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3`X(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#4*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DAO;F1U<F%S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW.0IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV,@IM<V=I9"`B2&]R9&4B"FUS
M9W-T<B`B2&]R9&4B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,Q,`IM<V=I
M9"`B2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]+;VQA8BYP:'`Z-#(P"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%5G>6QD:6<@
M)7,@6$U,(&1A=&$@9G5N;F5T(&D@;65L9&EN9R`E<R(*"B,Z(&QI8B](;W)D
M92]+;VQA8BYP:'`Z,C<W"B,L('!H<"UF;W)M870*;7-G:60@(DAO<F1E+TMO
M;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<R(*;7-G
M<W1R(")(;W)D92]+;VQA8CH@26YG96X@;65L9&EN9R!P87-S97(@;65D(&]B
M:F5K=&5T("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HT,3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z
M($EN=&5T(&]B:F5K="!A=B!T>7!E;B`E<R!F=6YN970@:2!M96QD:6YG("5S
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C,V"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($9J97)N970@)7,@7"(E<UPB
M(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,3@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI<V5D
M("5S(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA8CH@4WEN:W)O;FES97)T
M92`E<R!<(B5S7"(B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C(R,PIM<V=I
M9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER
M97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B2&]R9&4O
M2V]L86(Z($EN=&5G<F%S:F]N<VUO=&]R96X@:W)E=F5R(%!(4"`G9&]M>&UL
M)R!U='9I9&5L<V4B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C0X,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T
M92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@2W5N;F4@:6MK92!O<'!R971T92!N>71T(%A-3"!T<F4@9F]R(&]B
M:F5K=&5T("5S(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C,S"B,L('!H
M<"UF;W)M870*;7-G:60@(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MU;FYE(&EK
M:V4@9FIE<FYE("5S(%PB)7-<(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N
M<&AP.C0U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@:&5N=&4@34E-
M12!)1"!F;W(@9&5L96X@878@='EP92`E<R(*"B,Z(&QI8B](;W)D92]+;VQA
M8BYP:'`Z,3$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B
M2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@<WEN:W)O;FES97)E("5S(%PB)7-<
M(CH@)7,B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP.C$S,3`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES
M92!S:&%R97,Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+=6YN92!I:VME
M('-Y;FMR;VYI<V5R92!D96QT92!R97-S=7)S97(Z("5S(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E+TMO
M;&%B.B!5:VIE;G0@9&5L="!R97-S=7)S(%PB)7-<(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ
M;VYT86P@4G5L92(*;7-G<W1R(")(;W)I<V]N=&%L(&QI;FIE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM<V=I9"`B
M2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(DAO<FES;VYT86P@<&%D9&EN
M9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#$*;7-G:60@(DAO<FEZ;VYT86PZ(@IM<V=S='(@(DAO<FES;VYT86PZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C4P"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*2(*;7-G<W1R(")(=F]R9&%N(&MO;2!D=2!H:70_("A696YN;&EG
M<W0@<F%P<&]R=&5R(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=F]R(&UA;F=E
M(&MO;&]N;F5R(/AN<VME<B!D=2#E('-LY2!S86UM96X_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C@*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")(=F]R(&UA;F=E(&9E
M;'1E<B`H:V]L;VYN97(I(&5R(&1E=#\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=F]R
M(&UA;F=E(')A9&5R(/AN<VME<B!D=2#E('-LY2!S86UM96X_(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR,C@*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@
M(D9U:W1I9VAE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M,3<*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T<B`B1G5K=&EG:&5T.B`B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@(DAU;6]R:7-T<R(*
M;7-G<W1R(")(=6UO<FES=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED(")(=6YG87)Y(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S+G!H<#HQ-S8@;&EB+TAO<F1E
M+T%U=&@O8WER<W%L+G!H<#HR,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B3W!P<F5T
M=&5L<V4@878@24U!4"!P;W-T8F]K<R!F96EL970Z("5S(@H*(SH@;&EB+TAO
M<F1E+T%U=&@O8WER=7,N<&AP.C(R,"!L:6(O2&]R9&4O075T:"]C>7)S<6PN
M<&AP.C(X.`HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@9&5L
M971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R(")3;&5T=&EN9R!A=B!)34%0('!O
M<W1B;VMS96X@9F5I;&5T.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+V-Y<G5S
M+G!H<#HQ.#,@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B3W!P<F5T=&5L<V4@878@:W9O=&4@<.4@24U!
M4"!P;W-T8F]K<R!F96EL970Z("5S(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$S,3(*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T<B`B25`@061R97-S92(*
M"B,Z(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@R"FUS9VED("))4"!!
M9&1R97-S(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(DE0($%D<F5S<V4@:6MK
M92!T:6QG:F5N9V5L:6<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O:7!B87-I8RYP
M:'`Z.30*;7-G:60@(DE0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN(@IM<V=S='(@(DE0($%D<F5S<V4@:6MK92!I;FYE;F9O<B!T
M:6QA='1E($-)1%(@8FQO:VLN(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#0*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB
M"FUS9W-T<B`B0G)U9&0@<.4@25`@;&]C:V1O=VXN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(Y"FUS9VED
M("))7VYS97)T(%)O=R!"969O<F4B"FUS9W-T<B`B4U]E='0@:6YN(&YY(')A
M9"!F^'(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(P(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.#,*;7-G:60@(DEC96QA;F0B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R
M(")+=6X@:6MO;F5R(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O<B`E<R(*;7-G<W1R(")):V]N
M97(@9F]R("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PIM<V=I
M9"`B26-O;G,@=VET:"!T97AT(@IM<V=S='(@(DEK;VYE<B!M960@=&5K<W0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3@P"FUS9VED("))9&5N=&ET
M>2=S(&YA;64Z(@IM<V=S='(@(DED96YT:71E=&5N<R!N879N.B(*"B,Z(&QI
M8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HV,#@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O
M(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R(")(=FES(&1E;B!I
M:VME('9I<V5S(')I:W1I9RP@)7,@9F]R(.4@Y7!N92!I(&YY='0@=FEN9'4N
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-0IM<V=I9"`B(@HB268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N
M(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)(=FES(&1U(&EK
M:V4@<V5R(&YO96X@:6MO;F5R(&[E<B!D=2!B96YY='1E<B!);G1E<FYE="!%
M>'!L;W)E<BP@:V%N(&1E="`B"B)H96YD92!D=2!T<F5N9V5R(.4@:W)Y<W-E
M(&%V(&1E;FYE(&)O:W-E;B!F;W(@Y2!S:W)U(&%V('1R86YS<&%R96YT(%!.
M1RXB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,34X
M"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@(@HB
M9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T<B`B(@HB2'9I<R!D
M=2!S97(@9&5N;F4@;65L9&EN9V5N(&UE;B!I;G1E="!B:6QD92P@:V%N(&1E
M="!H96YD92!A="!B:6QD970@9'4@=FEL("(*(FQA<W1E(&]P<"!I:VME(&MA
M;B!V:7-E<R!I(&1I;B!N971T;&5S97(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS9VED("))
M;6%G92!0<F5V:65W.B(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<@878@8FEL
M9&4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D)I;&1E861R
M97-S92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R(")"
M:6QD96%D<F5S<V4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A
M;&QE<GDB"FUS9W-T<B`B0FEL9&4@9G)A(&=A;&QE<FDB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S$*
M;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>3HB"FUS9W-T<B`B0FEL9&4@9G)A
M(&=A;&QE<FDZ(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$W-#D*;7-G:60@
M(DEM86=E('5P;&]A9"(*;7-G<W1R(")/<'!L87-T:6YG(&%V(&)I;&1E(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S<*;7-G:60@(DEM86=E<R(*;7-G
M<W1R(")":6QD97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN8SHQ
M,"!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHQ,`HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C4W('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$P"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G
M<W1R("));7!O<G1E<FEN9RP@<W1E9R`E9"(*"B,Z('1E;7!L871E<R]D871A
M+V1A=&5M87`N:6YC.C(P"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R=&5D
M(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1E<G1E(&9E;'0Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHW,PIM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("));7!O<G1E<G1E(&9E;'0Z(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`Q"FUS9VED("));B!0
M<F]C97-S(@IM<V=S='(@(E5N9&5R(&%R8F5I9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,`IM<V=I9"`B
M26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B7U-E='0@:6YN(')A9"!E='1E
M<B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C$T,0IM<V=I9"`B
M26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")&96EL(&AA
M;F1L:6YG<VMO9&4@9VET="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C4W"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D+B(*;7-G<W1R(")59WEL9&EG(&)R=6ME<FYA=FX@;V<O96QL
M97(@<&%S<V]R9"XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU
M,0IM<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T
M<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)&
M96EL(&)R=6ME<FYA=FX@96QL97(@86QT97)N871I=B!A9')E<W-E+B!696YN
M;&EG<W0@9F]R<_AK(&EG:F5N(&5L;&5R("(*(FMO;G1A:W0@<WES=&5M861M
M:6YI<W1R871O<F5N(&1I;B!F;W(@>71T97)L:6=E<F5R92!H:F5L<"XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS
M9VED("));F-R96%S92!);F1E;G0B"FUS9W-T<B`BV&L@:6YN<GEK:R(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,38@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$P.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B26YD:6$B"FUS9W-T<B`B(@H*(SH@861M:6XO<&5R;7,O961I="YP
M:'`Z,30Q('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,T"FUS9VED("))
M;F1I=FED=6%L(%5S97)S(@IM<V=S='(@(DEN9&EV:61U96QL92!B<G5K97)E
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@Q"FUS9VED("));F1O;F5S:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(DEN9F\B"FUS9W-T
M<B`B26YF;R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-#D*;7-G
M:60@(DEN9F]R;6%T:6]N(@IM<V=S='(@(DEN9F]R;6%S:F]N(@H*(SH@<&\O
M=')A;G-L871I;VXN<&AP.C4X,@HC+"!P:'`M9F]R;6%T"FUS9VED("));FET
M:6%L:7II;F<@;6]D=6QE("5S+BXN("(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S0*;7-G
M:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(E-E='0@:6YN(&M?
M;VQO;FYE(&5T=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("));G-E<G0@26UA9V4B
M"FUS9W-T<B`B4V5T="!I;FX@8FEL9&4B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B
M"FUS9W-T<B`B4V5T="!I;FX@=&%B96QL(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR-0IM<V=I9"`B26YS97)T(%=E8B!,
M:6YK(@IM<V=S='(@(E-E='0@:6YN('=E8FQI;FLB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S,*;7-G:60@
M(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G<W1R(")3971T(&EN;B!?:V]L
M;VYN92!F^'(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(E-E='0@:6YN(&5N(&YY
M(&MO;&]N;F4@971T97(@9&5N(&=J96QD96YD92(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-`IM<V=I9"`B
M26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM
M<V=S='(@(E-E='0@:6YN(&5N(&YY(&MO;&]N;F4@9OAR(&1E;B!G:F5L9&5N
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE(@IM<V=S='(@(E-E='0@:6YN(&5N(&YY(')A9"!E='1E
M<B!D96X@9VIE;&1E;F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8P"FUS9VED("));G-E<G0@82!N97<@
M<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B4V5T="!I;FX@
M96X@;GD@<F%D(&;X<B!D96X@9VIE;&1E;F1E(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("))
M;G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R(")3971T(&EN;B!L:6YJ97-K:69T(&5T=&5R(&1E;B!G:F5L9&5N9&4@
M;F]D96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z-C@*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!B969O
M<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G<W1R(")3971T(&EN;B!L:6YJ97-K
M:69T(&;X<B!D96X@9VIE;&1E;F1E(&YO9&5N(@H*(SH@861M:6XO=&5M<&QA
M=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B4V5T="!I;FX@86QT97)N871I=B!M86PB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,C(Y"FUS9VED("));G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#HB"FUS9W-T<B`B4V5T="!I;FX@96X@92UP;W-T(&%D<F5S<V4@9'4@^&YS
M:V5R(.4@;6]T=&$@9&5T(&YY92!P87-S;W)D970@<.4Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU.`IM<V=I
M9"`B26YS97)T(&-E;&P@869T97(B"FUS9W-T<B`B4V5T="!I;FX@8V5L;&4@
M971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B"FUS9W-T
M<B`B4V5T="!I;FX@8V5L;&4@971T97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8T"FUS9VED("));G-E<G0@
M8V]L=6UN(&%F=&5R(@IM<V=S='(@(E-E='0@:6YN(&MO;&]N;F4@971T97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")3
M971T(&EN;B!K;VQO;FYE(&;X<B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R
M9F,R,#@V+G!H<#HY,PIM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@
M(E-E='0@:6YN(&UE;&1I;F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-`IM<V=I9"`B26YS97)T('!A
M<F%G<F%P:"!A9G1E<B(*;7-G<W1R(")3971T(&EN;B!L:6YJ97-K:69T(&5T
M=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C0S"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*
M;7-G<W1R(")3971T(&EN;B!L:6YJ97-K:69T(&;X<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-CD*;7-G:60@
M(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`B4V5T="!I;FX@<F%D(&5T=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B4V5T
M="!I;FX@<F%D(&;X<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,C`*
M;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`B4V5T="!I;FX@9&5T('#E:W)E=F1E
M('-V87)E="!T:6P@9OAL9V5N9&4@<VEK:V5R:&5T<W-P^')S;>5L.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G
M:60@(DEN<V5R="]-;V1I9GD@26UA9V4B"FUS9W-T<B`B4V5T="!I;FXO<F5D
M:6=E<F4@8FEL9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T
M<B`B4V5T="!I;FXO<F5D:6=E<F4@;&EN:R(*"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-C@*;7-G:60@(DEN<W5F9FEC:65N="!C<F5D
M:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@
M(DEK:V4@;F]K(&MR961I='0@9F]R(.4@:W5N;F4@<V5N9&4@=&EL(&1I<W1R
M:6)U<VIO;G-L:7-T96XN(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8V,`IM<V=I9"`B26YS=69F:6-I96YT(&-R961I="XB"FUS9W-T
M<B`B26MK92!N;VL@:W)E9&ET="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`W,`IM<V=I9"`B26YT96=E<B(*;7-G<W1R("));G1E9V5R(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(DEN=&5G97(@
M;&ES="(*;7-G<W1R("));G1E9V5R(&QI<W1E(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@S"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C,U,@IM<V=I9"`B26YV86QI9"!!8W1I
M;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R(")59WEL
M9&EG(&AA;F1L:6YG('9A;&=T(&9O<B!D96YN92!K;VUP;VYE;G1E;BXB"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I9"`B
M26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B56=Y
M;&1I9R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"@HC.B!A9&UI;B]S971U
M<"]C;VYF:6<N<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*
M;7-G<W1R(")59WEL9&EG('!R;V=R86TN(@H*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,C$*;7-G:60@(DEN=F%L:60@8F%T8V@@240N
M(@IM<V=S='(@(E5G>6QD:6<@8F%T8V@@240B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C`W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$T,B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(Q-@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C(X,0IM<V=I
M9"`B26YV86QI9"!D871A('-U8FUI='1E9"XB"FUS9W-T<B`B56=Y;&1I9R!D
M871A('-E;F1T+B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Y"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(E5G>6QD:6<@;6]T=&%K97(@861R97-S92XB"@HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O9&)X+G!H<#HX-"!L:6(O2&]R9&4O0V]M<')E<W,O9&)X
M+G!H<#HQ,#,*(SH@;&EB+TAO<F1E+T-O;7!R97-S+V1B>"YP:'`Z,C(S"FUS
M9VED("));G9A;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(E5G>6QD:6<@9FEL
M9F]R;6%T(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,38*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(E5G>6QD:6<@
M;65L9&EN9W-T>7!E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM
M<V=S='(@(E5G>6QD:6<@96QL97(@;6%N9VQE;F1E(&%P:5]I9"XB"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-0IM<V=I9"`B26YV
M86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N(@IM<V=S='(@(E5G>6QD:6<@
M96QL97(@;6%N9VQE;F1E('!A<F%M971E<F4N(@H*(SH@861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP.C0S"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R(")59WEL9&EG92!R971T:6=H971E<BXB"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B26YV86QI
M9"!P<F]T;V-O;"XB"FUS9W-T<B`B56=Y;&1I9R!P<F]T;VMO;&PN(@H*(SH@
M;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.CDQ"B,L('!H<"UF;W)M
M870*;7-G:60@(DEN=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S='(@(E5G
M>6QD:6<@;6]T=&%K97(Z("<E<R<B"@HC.B!L:6(O2&]R9&4O2V]L86(N<&AP
M.C$P-S$@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C0X"FUS9VED("));G9A;&ED
M('-H87)E(&]B:F5C="(*;7-G<W1R(")59WEL9&EG(&1E;'0@;V)J96MT(@H*
M(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@
M(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM<V=S='(@(E5G>6QD:6<@:VEL
M9&5A9')E<W-E(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HS,C`*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R(")5
M9WEL9&EG('5N:6-O9&4@9&%T82XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S(X"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B26YN:&]L9"(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX
M,PIM<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3$X(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.#(*;7-G:60@(DER87$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F5L86YD(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,34*;7-G:60@
M(DES;&4@;V8@36%N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS,S4*;7-G:60@(DES;VQA=&5D(%0M4W1O<FUS(@IM<V=S
M='(@(DES;VQE<G1E('1O<F1E;BUS=&]R;65R(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<W)A96PB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#D*
M;7-G:60@(DES<W5E<B(*;7-G<W1R(")5=&=I=F5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B
M"FUS9W-T<B`B2W5R<VEV(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$U"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@S"FUS9VED("))=&%L>2(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(S(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,38*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*
M;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C,W-"!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`B2F%N=6%R
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R-2!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@T"FUS9VED(")*87!A;B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H
M<"YD:7-T.C$X,PIM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*
M97)S97DB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$R
M-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$X"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")*;W)D86XB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,"!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$W"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S$*;7-G:60@(DIU;'DB
M"FUS9W-T<B`B2G5L:2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HS-SD@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<P"FUS9VED(")*=6YE(@IM<V=S='(@(DIU;FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*
M=7-T:69Y(@IM<V=S='(@(DIU<W1E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y
M($-E;G1E<B(*;7-G<W1R(")-:61T<W1I;&PB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PHC+"!F=7IZ>0IM
M<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S='(@(D)L;VMK:G5S=&5R(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C,V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,30*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@3&5F="(*;7-G<W1R(")696YS
M=')E:G5S=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,38*(RP@9G5Z>GD*;7-G:60@(DIU<W1I9GD@4FEG
M:'0B"FUS9W-T<B`B2/AY<F5J=7-T97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3,V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,3D*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(DMA>F%K:'-T86XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T-@IM<V=I9"`B2V5E<"!O<FEG:6YA;#\B"FUS9W-T<B`B0F5H;VQD
M92!O<F=I;F%L/R(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C8@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX-`IM<V=I9"`B2V5N>6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#<*;7-G:60@(DME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W,@
M=&IE;F5R96X@879V:7-T92!A=71E;G1I<V5R:6YG96XN(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE<R(*;7-G
M<W1R(")+97)N96P@3GEB96=Y;FYE<F4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HS.3<*;7-G:60@(DME>2!#<F5A=&EO;B(*;7-G<W1R(").^&MK
M96QG96YE<F5R:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`P
M"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T<B`B3OAK:V5L(&9I;F=E
M<G!R:6YT(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,SDX"FUS9VED
M(")+97D@3&5N9W1H(@IM<V=S='(@(D[X:VME;"!L96YG9&4B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HS.3<*;7-G:60@(DME>2!4>7!E(@IM<V=S
M='(@(D[X:VME;"!T>7!E(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV,C(*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R(").^&MK96QB<G5K(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-S0S"FUS9VED(")+97D@86QR
M96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N(@IM<V=S='(@
M(D[X:VME;"!E:W-I<W1E<F5R(&%L;&5R961E('#E(&1E;B!O9F9E;G1L:6=E
M(&[X:VME;'1J96YE<F5N+B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M,PIM<V=I9"`B2VED<R(*;7-G<W1R(")"87)N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")+:7)I8F%T
M:2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,C(*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.#8*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,S,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R,PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2V]R96$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z
M,3@T"FUS9VED(")+;W)E86X@*$550RU+4BDB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$S-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED
M(")+=7=A:70B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+>7)G>7IS=&%N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z.`IM<V=I9"`B
M3&%?>6]U="(*;7-G<W1R(")5=%]S965N9&4B"@HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<V('!O+W1R86YS;&%T:6]N+G!H<#HV-3<*;7-G:60@
M(DQA;F=U86=E(@IM<V=S='(@(E-P<N5K(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$S-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(V"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@X"FUS9VED("),86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,3<T"FUS9VED("),87-T($AA;&8B"FUS9W-T<B`B4VES
M=&4@:&%L=&EM92(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HX."!L:6(O0FQO
M8VLO;6]O;BYP:'`Z.3`*;7-G:60@(DQA<W0@475A<G1E<B(*;7-G<W1R(")3
M:7-T92!K=F%R=&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-#D*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B4VES=&4@;W!P9&%T97)I;F<Z
M(@H*(SH@;&EB+TAO<F1E+T%U=&@N<&AP.C8Y,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("),87-T(&QO9VEN.B`E<R(*;7-G<W1R(")3:7-T92!I;FYL;V=G:6YG
M.B`E<R(*"B,Z(&QI8B](;W)D92]!=71H+G!H<#HV.3,*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")3:7-T
M92!I;FYL;V=G:6YG.B`E<R!F<F$@)7,B"@HC.B!L:6(O2&]R9&4O075T:"YP
M:'`Z-C@X"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R(")3:7-T
M92!I;FYL;V=G:6YG.B!!;&1R:2(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#8@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R-PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B3&%T=FEA(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B3&%W(@IM
M<V=S='(@(DQO=B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW.0IM<V=I9"`B3&%Y;W5T(@IM<V=S='(@(E5T<V5E
M;F1E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX-@IM<V=I9"`B3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<B(*;7-G<W1R
M("+8;G-K97,@:6YG96X@<F%M;65R(&QA<B!D=2!F96QT970@=N9R92!T;VUT
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3(X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),96)A;F]N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#`*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.0IM<V=I9"`B3&5F
M="(*;7-G<W1R(")696YS=')E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q
M,#0*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E9E;G-T<F4@:&]D92(*
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,3`P"FUS9VED("),969T('9A;'5E
M<R(*;7-G<W1R(")696YS=')E('9E<F1I97(B"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,30S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,CD*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQE<V]T:&\B
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,P"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Y"FUS9VED("),:6)E<FEA(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-#<@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I
M9"`B3&EB>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,30P(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@
M(DQI96-H=&5N<W1E:6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,S-@IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R
M("),971T(&1U<VMR96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,S-PIM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("),971T(')E9VXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,X"FUS9VED("),
M:6=H="!286EN($5A<FQY(@IM<V=S='(@(DQE='0@9F]R;6ED9&%G<W)E9VXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S,Y"FUS9VED("),
M:6=H="!286EN($QA=&4B"FUS9W-T<B`B3&5T="!E='1E<FUI9&1A9W-R96=N
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T,`IM<V=I9"`B
M3&EG:'0@4F%I;B!3:&]W97(B"FUS9W-T<B`B3&5T=&4@<F5G;F)Y9V5R(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,T,0IM<V=I9"`B3&EG
M:'0@4F%I;B!W:71H(%1H=6YD97(B"FUS9W-T<B`B3&5T="!R96=N(&UE9"!T
M;W)D96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0R"FUS
M9VED("),:6=H="!3;F]W(@IM<V=S='(@(DQE='0@<V[X9F%L;"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#,*;7-G:60@(DQI9VAT(%-N
M;W<@4VAO=V5R(@IM<V=S='(@(DQE='1E('-N^&)Y9V5R(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0U"FUS9VED("),:6UE<FEC:R(*;7-G<W1R("),
M:6UE<FEC:R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#`R"FUS9VED("),
M:6YK(@IM<V=S='(@(DQI;FLB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(DQI;FL@<&]I;G1S
M('1O.B(*;7-G<W1R("),:6YK('!E:V5R('1I;#HB"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3@U.0IM<V=I9"`B3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9R(*;7-G<W1R("),
M:6YK(&4M<&]S="!A9')E<W-E;B!T:6P@)W-K<FEV(&YY)RUS:61E('9E9"!V
M:7-N:6YG(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP
M:'`Z,3@Q"FUS9VED("),:6YK<R(*;7-G<W1R("),:6YK97(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G
M<W1R("),:6YU>"!#;V]K:64B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z.#D*;7-G:60@(DQI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<B(*;7-G<W1R("),:7-T("T@8G)U:V5R96X@:V%N('-E(&UA<'!E;B(*
M"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S@*;7-G:60@(DQI<W0@1&%T86)A
M<V5S(@IM<V=S='(@(DQI<W0@9&%T86)A<V5R(@H*(SH@<V5R=FEC97,O:&5L
M<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I8W,B"FUS9W-T
M<B`B16UN97(@:2!(:F5L<"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S<*
M;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@(DQI<W0@=&%B96QL97(B"@HC
M.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S<*;7-G:60@(DQI<W0M
M07)C:&EV92(*;7-G<W1R("),:7-T92UA<FMI=B(*"B,Z(&QI8B](;W)D92]-
M24U%+TAE861E<G,N<&AP.C8S,@IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@
M(DQI<W1E:&IE;'`B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV
M,SD*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&4M260B"@HC.B!L:6(O
M2&]R9&4O34E-12](96%D97)S+G!H<#HV,S4*;7-G:60@(DQI<W0M3W=N97(B
M"FUS9W-T<B`B16EE<B!A=B!L:7-T92(*"B,Z(&QI8B](;W)D92]-24U%+TAE
M861E<G,N<&AP.C8S-@IM<V=I9"`B3&ES="U0;W-T(@IM<V=S='(@(DQI<W1E
M+7!O<W0B"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S0*;7-G
M:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S='(@(D%B8F]N97(@<.4@;&ES=&4B
M"@HC.B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HV,S,*;7-G:60@(DQI
M<W0M56YS=6)S8W)I8F4B"FUS9W-T<B`B4W1O<'`@86)B;VYN96UE;G0@<.4@
M;&ES=&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N:6YC.C0*
M;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(DUU
M;&EG:&5T(&9O<B#E(&QI<W1E(&)R=6ME<F4@97(@9&5A:W1I=F5R="XB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B
M"FUS9W-T<B`B3&ET=&5R871U<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ-#0@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B3&ET:'5A;FEA(@IM<V=S
M='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$Y"FUS9VED("),;V%D
M:6YG(&QI8G)A<FEE<RXN+B(*;7-G<W1R("),87-T97(@8FEB;&EO=&5K97(N
M+BXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H<#HX-@IM
M<V=I9"`B3&]A9&EN9RXN+B(*;7-G<W1R("),87-T97(N+BXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3<T"FUS9VED("),;V-A;"!T:6UE
M.B`B"FUS9W-T<B`B3&]K86P@=&ED.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HX,PIM<V=I9"`B3&]C86QE(&%N9"!4:6UE(@IM<V=S='(@(E-P<N5K
M(&]G('1I9"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DU(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W,`HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-C`@;&EB+T)L;V-K+W-U;G)I<V4N
M<&AP.C(R"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z-C,*;7-G:60@(DQO8V%T
M:6]N(@IM<V=S='(@(DQO:V%S:F]N(@H*(SH@;&]G:6XN<&AP.C$U-2!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,38T('1E;7!L871E<R]L;V=I;B]M
M;V)I;&4N:6YC.C,*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@
M=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&]G(&EN(@IM
M<V=S='(@(DQO9V<@:6YN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N
M<&AP.C$U.`IM<V=I9"`B3&]G(&]U="(*;7-G<W1R("),;V=G('5T(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B
M"FUS9W-T<B`B26YN;&]G9VEN9W-O<'!G879E<B(*"B,Z(&QI8B](;W)D92]!
M=71H+G!H<#HY-3(*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M(@IM<V=S='(@(DQO9VEN(&9E:6QE="!F;W)D:2!B<G5K97)N879N970@96QL
M97(@<&%S<V]R9&5T(&1U('-K<F5V(&EN;B!V87(@9F5I;"XB"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.30X"FUS9VED("),;V=I;B!F86EL960N(@IM<V=S
M='(@(DQO9VEN(&9E:6QE="XB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V
M,@IM<V=I9"`B3&]N9R!T97AT(@IM<V=S='(@(DQA;F<@=&5K<W0B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`B
M2VKF<FQI9VAE="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-S0*;7-G:60@(DQO=R(*;7-G<W1R("),878B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),
M;W=E<B!G<F5E:R!L971T97)S(@IM<V=S='(@(E-MY2!G<F5S:V4@8F]K<W1A
M=F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ.0IM<V=I9"`B3&]W97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R(")3;>4@;&%T:6YS:V4@8F]K<W1A=F5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHQ-PIM<V=I9"`B
M3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3`*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,T,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,S<S"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3`@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#D*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(DU-(@IM<V=S='(@
M(DU-(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-@IM<V=I9"`B
M34]41"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=&YE
M9BYP:'`Z,SD*;7-G:60@(DU3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO
M;B],:7-T96YE<B]M;V)I;&4N<&AP.C0P"B,L(&9U>GIY"FUS9VED(")-4T<B
M"FUS9W-T<B`B0U93(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U-R!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-86-A;R(*;7-G<W1R
M("),;VMA<VIO;B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-3,@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S-@HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY,@IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HW,0IM<V=I9"`B36%I;"(*;7-G<W1R
M("));FYB;VMS(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Q-`IM
M<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*;7-G:60@(DUA
M:V4@;&EN7VLN+BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP
M.C$S,S@*;7-G:60@(DUA:V4@<W5R92!T:&%T('EO=2!H879E(%!%05(@:6YS
M=&%L;&5D(&%N9"!I;B!Y;W5R(&EN8VQU9&4@<&%T:"XB"FUS9W-T<B`B(@H*
M(SH@<&\O=')A;G-L871I;VXN<&AP.C8W."!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3`V,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B36%K:6YG(&1I<F5C
M=&]R>2`E<R(*;7-G<W1R(")3;W)T97)I;F=S<F5K:V5F^&QG92(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C4@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F
M=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(D4M<&]S="(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B12UP;W-T(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,30P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"B,L(&9U>GIY
M"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")0;W-T(@H*(SH@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$U-"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,30Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS
M9VED(")-86QI(@IM<V=S='(@(E!O<W0B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,38R(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#(*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*(RP@9G5Z>GD*;7-G:60@(DUA
M;'1A(@IM<V=S='(@(D4M<&]S="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY,0IM<V=I9"`B(@HB36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R`B"B)A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RXB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-#`*;7-G
M:60@(DUA<#(T(&UA<"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.3<X"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-87!1=65S="!M87`B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W
M-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C<*(RP@9G5Z
M>GD*;7-G:60@(DUA<F-H(@IM<V=S='(@(E/X:R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*(RP@9G5Z>GD*
M;7-G:60@(DUA<F=I;B(*;7-G<W1R(")!9'9A<G-E;"(*"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,0IM<V=I9"`B36%R:R!W:71H(%-E
M96XO56YS965N(&9L86=S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B36%R:R!W:71H(&]T:&5R(&9L
M86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"DB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDR"B,L
M(&9U>GIY"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(D]P<&1A
M=&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U.2!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-87)T:6YI<75E(@IM<V=S='(@(D%D
M=F%R<V5L(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,3$*;7-G
M:60@(DUA=&-H:6YG(&9I96QD<R(*;7-G<W1R(")386US=F%R96YD92!F96QT
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,"!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"B,L(&9U>GIY"FUS9VED(")-875R:71A;FEA(@IM<V=S='(@(D%D=F%R
M<V5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V,R!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDU"B,L(&9U>GIY"FUS9VED(")-875R:71I=7,B"FUS9W-T<B`B061V
M87)S96PB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R
M-`IM<V=I9"`B36%X(&%L;&]W960@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-PHC+"!F=7IZ>0IM
M<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(DUE
M;&1I;F=E;B!B;&4@<VQE='1E="XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP
M.C,P-`IM<V=I9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.#DS(&QI8B](;W)D92]&;W)M+G!H<#HQ,C`Y(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C,Q"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0HC+"!F=7IZ>0IM
M<V=I9"`B36%Y(@IM<V=S='(@(D1A9VQI9R(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HR-3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G:60@
M(DUA>6]T=&4B"FUS9W-T<B`B571S965N9&4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(DUE9&EC:6YE(@IM<V=S='(@
M(D%V<VSE='0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T:6]N(@IM<V=S='(@
M(DWX=&5A=FQY<VYI;F<B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU,#,*;7-G:60@(DUE971I;F<@26YF;W)M871I;VXB"FUS
M9W-T<B`B3?AT96EN9F]R;6%S:F]N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3`Y"FUS9VED(")-965T:6YG(%!R;W!O<V%L
M(@IM<V=S='(@(DWX=&5I;FYK86QL96QS92(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4R-0IM<V=I9"`B365E=&EN9R!297!L
M>2(*;7-G<W1R(")-^'1E<W9A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4Q-`IM<V=I9"`B365E=&EN9R!5<&1A=&4B"FUS
M9W-T<B`B3?AT96]P<&1A=&5R:6YG(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-3$Y"FUS9VED(")-965T:6YG(%5P9&%T92!2
M97%U97-T(@IM<V=S='(@(D9O<F5S^')S96P@;VT@;?AT96]P<&1A=&5R:6YG
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN8SHQ.0HC+"!F
M=7IZ>0IM<V=I9"`B365M8F5R<R(*;7-G<W1R(")-96UO(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,V.`IM<V=I9"`B365N=2!M;V1E.B(*;7-G<W1R
M(")-96YY;6]D=7,Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHV,`HC+"!F=7IZ>0IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`B365L9&EN9W-F96QT(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C4R-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG(&%L;"`E<RYP
M;R!F:6QE<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T<B`B(@H*(SH@
M<&\O=')A;G-L871I;VXN<&AP.C0S.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-
M97)G:6YG(&QO8V%L92`E<RXN+B`B"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L
M871I;VXN<&AP.C<X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")-97)G:6YG('1H
M92!03R!F:6QE(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B`B"FUS9W-T
M<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0R-0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@)7,N+BXB
M"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP.C,R"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE;&1I
M;F<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(R-@IM<V=I9"`B
M(@HB365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N
M97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$Y"B,L(&9U>GIY"FUS9VED(")-97-S86=E(&5X<&ER960N(@IM<V=S='(@
M(DUE;&1I;F=S9F5L="(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU.3$@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R-@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(S,R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(V.`HC+"!F=7IZ>0IM<V=I9"`B
M365S<V%G92!T>7!E(@IM<V=S='(@(DUE;&1I;F=S9&%T;R(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B365T87(@5V5A=&AE
M<B(*;7-G<W1R(")3=&%R="(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DUE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(D1E="!E<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K
M<V5N+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$P"B,L(&9U>GIY"FUS
M9VED("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA
M=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R
M(")$971A;&IE<B!H87(@8FQI='0@;&]G9V5T(&9O<B!A9&UI;FES=')A=&]R
M96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-S`@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R("),879E<W0B"@HC.B!L:6(O2&]R9&4O4E!#+WAM
M;')P8RYP:'`Z.#(@;&EB+TAO<F1E+U)00R]S;V%P+G!H<#HQ,3<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"`G)7,G(&ES(&YO="!D969I
M;F5D(@IM<V=S='(@(DUA<'!E8G)U:R!E<B!I:VME('1I;&=J96YG96QI9RXB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HW,PIM<V=I9"`B365T<FEC(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$T.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<S"FUS9VED(")-:6-R;VYE<VEA+"!&961E
M<F%T960@4W1A=&5S(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@HC+"!F=7IZ>0IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(E-K:G5L="(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]T;F5F+G!H<#HT,0IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`X"FUS9VED(")-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,#`*;7-G:60@(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,3<*(RP@9G5Z>GD*;7-G:60@(DUI<G)O<B(*;7-G<W1R(")&96EL(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Q"FUS9VED(")-:7-C96QL86YE
M;W5S(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV.3<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-#D*
M;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="XB"FUS
M9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$P-0IM<V=I9"`B
M(@HB36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$S"B,L(&9U>GIY"FUS9VED(")-:7-S:6YG(&UE<W-A9V4@240N
M(@IM<V=S='(@(D1E;FYE(&UE;&1I;F=E;B!T:6PB"@HC.B!L:6(O3F5T+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4W"FUS9VED(")-:7-S:6YG(')E
M<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R("(B"@HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I
M9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")$96YN92!M96QD:6YG
M96X@=&EL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHU-@HC+"!F=7IZ>0IM<V=I9"`B36\B"FUS9W-T<B`B1FQY='0B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(R"B,L(&9U>GIY"FUS9VED
M(")-;V)I;&4@36%I;"(*;7-G<W1R(").>2!P;W-T(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C,W-0HC+"!F=7IZ>0IM<V=I9"`B36]D97)A
M=&4B"FUS9W-T<B`B4VES="!M;V1I9FES97)T(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)A<BYP:'`Z-CD@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII
M<"YP:'`Z-S,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z.#@*
M(RP@9G5Z>GD*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`B4VES="!M
M;V1I9FES97)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"B,L(&9U>GIY"FUS9VED(")-;V1I9GD@55),
M(@IM<V=S='(@(D5N9')E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC
M+"!F=7IZ>0IM<V=I9"`B36]D=6QE(@IM<V=S='(@(E)O;&QE(@H*(SH@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV.3<*(RP@9G5Z>GD*;7-G:60@(DUO
M9'5L=7,B"FUS9W-T<B`B4F]L;&4B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,34P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-3`*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3$*;7-G:60@(DUO;&1O=F$L(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ
M-#D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U,0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HY,0HC+"!F=7IZ>0IM<V=I9"`B36]N86-O(@IM
M<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$U
M-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.CDS"B,L(&9U>GIY"FUS9VED(")-;VYG;VQI82(*
M;7-G<W1R(")4:6PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X-PHC+"!F
M=7IZ>0IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B4VQU='0@<.4@
M;65L9&EN9V5N(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E+G!H<#HS-@IM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")-Y6YE9'1L:6<B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUO
M;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C,@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED(")-;V]N(%!H87-E<R(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3$*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B36]S
M=&QY($-L96%R(@IM<V=S='(@(DMO<&EE<B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-#4*(RP@9G5Z>GD*;7-G:60@(DUO<W1L>2!#;&]U
M9'DB"FUS9W-T<B`B2V]P:65R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,T-@HC+"!F=7IZ>0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S
M='(@(DMO<&EE<B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R
M,`HC+"!F=7IZ>0IM<V=I9"`B36]V92!$;W=N(@IM<V=S='(@(F9L>71T(&YE
M9"(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R-`HC+"!F=7IZ
M>0IM<V=I9"`B36]V92!,969T(@IM<V=S='(@(F9L>71T(&]P<"(*"B,Z(&QI
M8B](;W)D92]";&]C:R],87EO=70N<&AP.C0R.`HC+"!F=7IZ>0IM<V=I9"`B
M36]V92!2:6=H="(*;7-G<W1R(")&;'ET="!T:6P@:/AY<F4B"@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HT,38*(RP@9G5Z>GD*;7-G:60@(DUO
M=F4@57`B"FUS9W-T<B`B9FQY='0@;W!P(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PIM<V=I9"`B36]V92!D;W=N(@IM<V=S
M='(@(F9L>71T(&YE9"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H
M=&UL+G!H<#HT.38@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Y-PIM<V=I9"`B36]V92!U<"(*;7-G<W1R(")F;'ET="!O<'`B"@HC.B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.38*(RP@
M9G5Z>GD*;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B061V87)S96PB"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$V.`IM<V=I9"`B375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C(V"B,L(&9U>GIY"FUS9VED(")-=6QT:7!L92!S96QE8W1I;VXB
M"FUS9W-T<B`B1FEL=&5R:6YN<W1I;&QI;F=E<B(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HS,S0@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,T
M,0HC+"!F=7IZ>0IM<V=I9"`B37D@06-C;W5N="(*;7-G<W1R(")+;VY?=&]E
M<B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I;F1E>"YP:'`Z-3$*;7-G:60@(DUY
M(%!O<G1A;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO961I="YP
M:'`Z,3(T"FUS9VED(")->2!0;W)T86P@3&%Y;W5T(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,PHC
M+"!F=7IZ>0IM<V=I9"`B37EA;FUA<B(*;7-G<W1R(")N879N(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*;7-G
M:60@(DY/+"!)($1O($Y/5"!!9W)E92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<&=P+G!H<#HS.3<@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C
M87)D+G!H<#HQ,#4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP
M.C0Q(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PIM
M<V=I9"`B3F%M92(*;7-G<W1R(").879N(@H*(SH@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$V.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34W"B,Z
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDV"FUS9VED(").86UI8FEA(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S@@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U.`HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HY.`IM<V=I9"`B3F%U<G4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED(").965D
M<R!!8W1I;VXB"FUS9W-T<B`B5')E;F=E<B!H86YD;&EN9R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-S<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ
M>0IM<V=I9"`B3F5P86PB"FUS9W-T<B`B3GD@<&]S="(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-S4@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY.`HC+"!F=7IZ>0IM
M<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`B3GD@<&]S="(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38Q"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4X"B,L(&9U>GIY
M"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(").>2!P;W-T
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#4*;7-G:60@(DYE
M='-C87!E($)A<V4@55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-C`W"FUS9VED(").971S8V%P92!#02!2979O8V%T:6]N
M(%523"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8P.0IM<V=I9"`B3F5T<V-A<&4@0T$@<&]L:6-Y(%523"(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8P.`IM<V=I9"`B3F5T
M<V-A<&4@4F5N97=A;"!54DPB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HV,#8*;7-G:60@(DYE='-C87!E(%)E=F]C871I;VX@
M55),(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-C$P"FUS9VED(").971S8V%P92!34TP@<V5R=F5R(&YA;64B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,3$*(RP@9G5Z>GD*
M;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B
M26YT970@<&5R<V]N;&EG('-E<G1I9FEK870@=&EL9VIE;F=E;&EG+B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C`T"B,L(&9U>GIY"FUS9VED
M(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@(E-E='0@:6YN
M('-E<G1I9FEK870@:&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(T,@HC+"!F=7IZ>0IM<V=I9"`B3F5T=V]R:R(*;7-G<W1R(").>2(*"B,Z
M(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q,2!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S8*;7-G:60@
M(DYE=F5R(@IM<V=S='(@(D%L9')I(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38R"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDV"B,L(&9U>GIY"FUS9VED(").97<@
M0V%L961O;FEA(@IM<V=S='(@(DQE9V<@=&EL(&5N(&YY(&MO;G1A:W0B"@HC
M.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,0HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-PHC+"!F
M=7IZ>0IM<V=I9"`B3F5W($-A=&5G;W)Y(@IM<V=S='(@(D9I<FUA:V%T96=O
M<FDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN
M<&AP.C8X(&QI8B]";&]C:R]M;V]N+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!-;V]N(@IM<V=S='(@(DYY('!O<W0B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C,U"FUS9VED(").97<@57-E<FYA;64@*&]P
M=&EO;F%L*2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3@P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(DYE=R!:96%L
M86YD(@IM<V=S='(@(DYY('!O<W0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA
M;FLI(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C0P(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C8T"FUS9VED(").97=S(@IM<V=S='(@(DYY:&5T97(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`V"B,L(&9U>GIY"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(D=R=7!P92(*"B,Z('1E;7!L871E<R]D871A
M+W1S=FEN9F\N:6YC.C(Q('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C0V
M"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z,3,W('1E;7!L871E<R]D
M871A+V-S=FEN9F\N:6YC.C,R"FUS9VED(").97AT(@IM<V=S='(@(DYE<W1E
M(@H*(SH@;&EB+TAO<F1E+U5)+U!A9V5R+G!H<#HQ,34@;&EB+TAO<F1E+U5)
M+U!A9V5R+G!H<#HQ,38*;7-G:60@(DYE>'0@4&%G92(*;7-G<W1R(").97-T
M92!S:61E(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS
M9VED(").97AT(%!H87-E(@IM<V=S='(@(DYE<W1E('-I9&4B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C,V-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP
M.C,W,`HC+"!F=7IZ>0IM<V=I9"`B3F5X="!O<'1I;VYS(@IM<V=S='(@(E1I
M;&)A:V4@=&EL(%9A;&<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<Q(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*(RP@9G5Z>GD*;7-G:60@(DYI9V5R(@IM<V=S='(@(D%L9')I(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,R!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"B,L
M(&9U>GIY"FUS9VED(").:6=E<FEA(@IM<V=S='(@(D%L9')I(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X.0HC+"!F=7IZ>0IM<V=I9"`B
M3FEG:'0B"FUS9W-T<B`B2/AY97-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(").:75E
M(@IM<V=S='(@(D]B<R$B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.#@X"FUS9VED(").;R(*;7-G<W1R(").96DB"@HC.B!T96UP
M;&%T97,O861M:6XO<V5T=7`O9&EF9BYH=&UL.C$V"FUS9VED(").;R!A=F%I
M;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@
M9F]R+B(*;7-G<W1R("(B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3$Q
M"FUS9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@
M:6UA9V5S+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,R,@IM<V=I9"`B3F\@8F%T8V@@=&5M<&QA=&4N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<X(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(R-`HC.B!L:6(O2&]R9&4O0FQO8VLO
M3&%Y;W5T+G!H<#HR-#8*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]!
M=71H+VUC86PN<&AP.C4T"B,L(&9U>GIY"FUS9VED(").;R!C86QE;F1A<B!N
M86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M("));F=E;B!K;VYF:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM
M875T96YT:7-E<FEN9RXB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HU-0HC
M+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R(")!;F=R92!E;F1R
M:6YG97(B"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T-`IM<V=I9"`B
M3F\@8VAI;&0@<&5R;6ES<VEO;G,@87)E('1O(&)E(&%D9&5D(&)E;&]W('1H
M:7,@;&5V96PN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV,0HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BXB"FUS9W-T<B`B)R5S)R!B;&4@;&%G
M="!T:6P@<F5T=&EG:&5T<W-Y<W1E;65T+B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HQ,S4X"B,L(&9U>GIY"FUS9VED(").;R!C;VUM86YD('-P96-I9FEE
M9"XB"FUS9W-T<B`B26YG96X@8G)U:V5R('9A;&=T+B(*"B,Z(&QI8B](;W)D
M92YP:'`Z,3<S(&QI8B](;W)D92YP:'`Z-#DS(&QI8B](;W)D92]5=&EL+G!H
M<#HW-3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
M26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6MA
M=&5G;W)I97(N(@H*(SH@;&EB+U9&4R]F='`N<&AP.C<W,PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R($944"!61E,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@
M<W!E<VEF:7-E<G0@9F]R($Q$05`M:6YS=&EL;&EN9V5N92XB"@HC.B!L:6(O
M5D93+W-Q;"YP:'`Z-3DU"B,L(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T
M<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,
M+6MA=&5G;W)I97(N(@H*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S4W"B,L
M(&9U>GIY"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("));F=E;B!K;VYF
M:6=U<F%S:F]N(&5R('-P97-I9FES97)T(&9O<B!344PM:V%T96=O<FEE<BXB
M"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,PIM<V=I
M9"`B3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-3D*(RP@9G5Z>GD*;7-G:60@(DYO(&1E
M<W1I;F%T:6]N('-U<'!L:65D+B(*;7-G<W1R("));F=E;B!M96QD:6YG97(B
M"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(U,@HC+"!P:'`M9F]R;6%T"FUS
M9VED(").;R!E;G1R>2!W:71H('1H92!I9"`G)7,G(&5X:7-T<R!I;B!T:&4@
M;W)I9VEN86P@:&5L<"!F:6QE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0G)O=W-E<BYP:'`Z.#DR"B,L(&9U>GIY"FUS9VED(").;R!F:6QE('5P;&]A
M9&5D(@IM<V=S='(@(E9I<R!S;&5T=&5D92!E;&5M96YT97(B"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R("));F=E;B!V961L96=G(&9U;FYE="XB"@HC.B!P
M;R]T<F%N<VQA=&EO;BYP:'`Z-#$S('!O+W1R86YS;&%T:6]N+G!H<#HU,C(*
M(RP@9G5Z>GD*;7-G:60@(DYO(&QO8V%L92!S<&5C:69I960N(@IM<V=S='(@
M(DEN9V5N(&)R=6ME<B!V86QG="XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HT,`HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I9"`B3F\@;&]C871I
M;VX@:7,@<V5T+B(*;7-G<W1R(")3=F%R('1I;"!L:7-T96XB"@HC.B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4X"B,L(&9U>GIY"FUS9VED
M(").;R!M97-S86=E('-U<'!L:65D+B(*;7-G<W1R("));F=E;B!M96QD:6YG
M97(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8Q"B,L
M(&9U>GIY"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B26YG
M96X@8G)U:V5R('9A;&=T+B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-C(*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I
M960N(@IM<V=S='(@(DEN9V5N(&)R=6ME<B!V86QG="XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.30*(RP@9G5Z>GD*;7-G:60@(DYO(&]F9F5N<VEV
M92!F;W)T=6YE<R(*;7-G<W1R("));F=E;B!V961L96=G(&9U;FYE="XB"@HC
M.B!L:6(O2&]R9&4O075T:"]H='1P+G!H<#HY,PHC+"!F=7IZ>0IM<V=I9"`B
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@
M9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D92]!=71H+VEM
M87`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO
M;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R
M:6YG+B(*"B,Z(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C<T"B,L(&9U>GIY
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T
M:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@
M<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](
M;W)D92]!=71H+VQD87`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,
M+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z
M.#(@;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP.C@X"B,Z(&QI8B](;W)D92]!
M=71H+W!A;2YP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG
M96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I<V5R="!F;W(@4U%,+6%U=&5N
M=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H<#HQ,SD*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-3
M5T0@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J
M;VX@97(@<W!E<VEF:7-E<G0@9F]R(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z
M(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DEN9V5N(&MO;F9I9W5R87-J;VX@97(@<W!E<VEF:7-E<G0@9F]R
M(%-13"UA=71E;G1I<V5R:6YG+B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z,3,Q.`IM<V=I9"`B(@HB3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@(@HB=V]R:R!W:71H(%!+0U,@,3(@9&%T82XB"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI;F,Z,3D*;7-G:60@
M(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ
M>0IM<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`B3F]T871E<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#0*(RP@
M9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DEN9V5N(&UE;&1I;F=E
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,C8*;7-G:60@
M(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB
M"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C8U-@HC+"!F=7IZ>0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N(@IM<V=S='(@(E9E;FYL:7-T('-K<FEV(&EN;B!B<G5K97)N
M879N(&]G('!A<W-O<F0B"@HC.B!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z
M,30Q"B,L(&9U>GIY"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE
M9"(*;7-G<W1R("));F=E;B!V0V%R9"!D871A(&9U;FYE="XB"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DV(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HY,#8*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.3,T"B,L(&9U>GIY"FUS9VED(").;R!V86QU97,B"FUS
M9W-T<B`B26YG96X@;65L9&EN9V5R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C$Q,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,3@*;7-G:60@(DYO
M('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R
M871E(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8P-`IM<V=I9"`B3F]N(%!A<G1I
M8VEP86YT(@IM<V=S='(@(DEK:V4@9&5L=&%G97(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<&=P+G!H<#HT,3,@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y
M<V5L96-T+FEN8SHX.`IM<V=I9"`B3F]N92(*;7-G<W1R("));F=E;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3`*;7-G
M:60@(DYO;F4@*'5S92!I;7!L:6-I="DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-S(@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V.`HC.B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B
M"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S(@
M;&EB+T)L;V-K+VUO;VXN<&AP.C8P"B,L(&9U>GIY"FUS9VED(").;W)T:&5R
M;B!(96UI<W!H97)E(@IM<V=S='(@(DAJ96QP(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$U."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDT"FUS9VED(").;W)T:&5R
M;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED
M(").;W)W87DB"FUS9W-T<B`B3F]R;6%L(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W-M:6UE+G!H<#HV-C0*(RP@9G5Z>GD*;7-G:60@(DYO="!!9G1E<B(*;7-G
M<W1R(")):VME(&ML861D(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HV-C,*(RP@9G5Z>GD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`B26MK
M92!K;&%D9"(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S4V"B,L(&9U>GIY"FUS
M9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B4V]R=&5R:6YG<W)E:VME
M9OAL9V4B"@HC.B!L:6(O5D93+TE33U=R:71E<BYP:'`Z-C<@;&EB+U9&4R])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HX-`HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU"B,Z(&QI8B]6
M1E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.0HC.B!L:6(O
M5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z-C`*(RP@9G5Z
M>GD*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B26MK92!S;&5T
M=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHV.`HC+"!F=7IZ>0IM<V=I9"`B3F]T('-E="(*;7-G<W1R(")):VME('-L
M971T970B"@HC.B!L:6(O5D93+G!H<#HQ.#0@;&EB+U9&4RYP:'`Z,C`S(&QI
M8B]61E,N<&AP.C(R,2!L:6(O5D93+G!H<#HR,S@*(SH@;&EB+U9&4RYP:'`Z
M,C4U(&QI8B]61E,N<&AP.C(W,2!L:6(O5D93+G!H<#HR.#D@;&EB+U9&4RYP
M:'`Z,S(U"B,Z(&QI8B]61E,N<&AP.C,X."!L:6(O5D93+G!H<#HT-S(@;&EB
M+U9&4RYP:'`Z-30T(&QI8B]61E,N<&AP.C4V,@HC+"!F=7IZ>0IM<V=I9"`B
M3F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P9V%V
M96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0W(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-3D*
M;7-G:60@(DYO=&5S(@IM<V=S='(@(DYO=&%T97(B"@HC.B!S97)V:6-E<R]O
M8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@=&\@8G)O=W-E
M+"!G;R!B86-K+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O8V]N9FER;5]T;W`N:6YC.C$P"FUS9VED(").;W1I8V4B"FUS9W-T<B`B
M3V)S(2(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HS
M.#0@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<U"B,L(&9U
M>GIY"FUS9VED(").;W9E;6)E<B(*;7-G<W1R(")!;&1R:2(*"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,#0Q"B,L(&9U>GIY"FUS9VED(").=6UB97(B"FUS
M9W-T<B`B3F%V;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ-#(R"B,L(&9U
M>GIY"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("(Q,#`@
M=&5G;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S8V(&QI8B](;W)D92]&
M;W)M+G!H<#HQ-#(P(&QI8B](;W)D92]&;W)M+G!H<#HQ-#0R"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`T"B,L(&9U>GIY
M"FUS9VED(").=6UB97(@;V8@8V]L=6UN<R(*;7-G<W1R(")!;G1A;&P@:V]L
M;VYN97(@:2!O<'!S=6UM97)I;F=S=FES;FEN9V5N.B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,S8T(&QI8B](;W)D92]&;W)M+G!H<#HQ-#$X(&QI8B](
M;W)D92]&;W)M+G!H<#HQ-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3`R"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@
M<F]W<R(*;7-G<W1R(")!;G1A;&P@:V]L;VYN97(@:2!O<'!S=6UM97)I;F=S
M=FES;FEN9V5N.B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-CD*(RP@9G5Z>GD*;7-G:60@(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(D1U
M(&QA9V5R(&5N(&1I<W1R:6)U<VIO;G,@;&ES=&4N(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#@S"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8V,PHC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0V"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C0@<&\O=')A;G-L871I;VXN<&AP
M.C$T.`HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3,R.0IM<V=I9"`B3TLB"FUS
M9W-T<B`B3TLB"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.#$T"B,L(&9U>GIY"FUS9VED(")/8FIE8W0B"FUS9W-T<B`B16UN92(*
M"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"B,L(&9U>GIY"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1E="!B;&4@:6MK
M92!F=6YN970B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,S<@;&EB+TAO
M<F1E+U!E<FUS+U5)+G!H<#HR,C,*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!C
M<F5A=&]R('!E<FUI<W-I;VYS(@IM<V=S='(@(D]R9'-T>7)E<B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,#DY"B,L(&9U>GIY"FUS9VED(")/8W1A;"(*
M;7-G<W1R(")$86=L:6<B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@S(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT,C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHW-`IM<V=I9"`B3V-T;V)E<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.3(*;7-G:60@(D]F9F5N<V4@9FEL=&5R(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,#0*;7-G:60@(D]F
M9FEC92(*;7-G<W1R(")+;VYT;W(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3@Q(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(D]M86XB"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C<V"B,L(&9U
M>GIY"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F
M;VQD97)S+B(*;7-G<W1R(")$96YN92!T:F5N97)E;B!S=/AT=&5R(&EK:V4@
M9&5L:6YG(&%V(&UA<'!E<BXB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.34*(RP@9G5Z>GD*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(DEN9V5N('9E9&QE9V<@9G5N;F5T+B(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.#,U(&QI8B](;W)D92]&;W)M+G!H<#HQ.34U"B,L(&9U>GIY
M"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(@IM<V=S
M='(@(D5P;W-T861R97-S96X@9&EN.B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E
M9&ET+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M
M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@
M(@HB<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VEF<F%M92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(D]P96X@:6X@
M82!N97<@=VEN9&]W(@IM<V=S='(@(E9I<V4@:6YN:&]L9"!I(&5T(&5G970@
M=FEN9'4N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HR-3<*;7-G
M:60@(D]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O
M;2!S:6=N960@4R]-24U%('!A<G0N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-`HC+"!F
M=7IZ>0IM<V=I9"`B3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=R(*
M;7-G<W1R(")(96YT92!N>64@;65L9&EN9V5R(&D@970@96=E="!V:6YD=3\B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN
M9R!3>7-T96TB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C`P"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N
M="(*;7-G<W1R(")686QG9G)I(&1E;'1A9V5R(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+W-I9&5B87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R(")6
M86QG(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.C(Y('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D]P=&EO
M;G,@9F]R("5S(@IM<V=S='(@(E9A;&<B"@HC.B!P;R]T<F%N<VQA=&EO;BYP
M:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")/<'1I;VYS.B(*;7-G<W1R(")686QG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`HC+"!F=7IZ>0IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E9E;&<@
M;&ES=&4B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,0HC+"!F
M=7IZ>0IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-E<FEN
M9R(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DR"B,L(&9U>GIY
M"FUS9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(D]R9V%N:7-E
M<FEN9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,C<*;7-G:60@
M(D]R9V%N:7II;F<B"FUS9W-T<B`B3W)G86YI<V5R:6YG(@H*(SH@861M:6XO
M=&5M<&QA=&5S+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(D]R:6=I;F%L(&%P
M<&QI8V%T:6]N('1E;7!L871E(@IM<V=S='(@(DAA;F1L:6YG97(B"@HC.B!A
M9&UI;B]T96UP;&%T97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/
M<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(B(*"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$R,"!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,3$W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.30*;7-G:60@(D]T:&5R(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`V"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ,3,@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R
M,0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Y"FUS9VED(")/=&AE<B!)
M;F9O<FUA=&EO;B(*;7-G<W1R(")!;FYE;B!I;F9O<FUA<VIO;B(*"B,Z('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*(RP@9G5Z>GD*;7-G:60@(D]W
M;F5R(%!E<FUI<W-I;VYS(@IM<V=S='(@(DQA9W)E(%9A;&<B"@HC.B!L:6(O
M2&]R9&4O075T:"]P86TN<&AP.C@S"B,L(&9U>GIY"FUS9VED(")004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3VUA9')E
M<W-E<FEN9R!F96EL970N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z
M,3(W.0HC+"!F=7IZ>0IM<V=I9"`B4$=0($1I9VET86P@4VEG;F%T=7)E(@IM
M<V=S='(@(E-K>6=G96QE9V<@<VEG;F%T=7(_(@H*(SH@;&EB+TAO<F1E+T-R
M>7!T+W!G<"YP:'`Z,3,R.`HC+"!F=7IZ>0IM<V=I9"`B4$=0($5N8W)Y<'1E
M9"!$871A(@IM<V=S='(@(E!'4"UK<GEP=&5R(&UE;&1I;F<B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S@W"B,L(&9U>GIY"FUS9VED(")01U`@
M4'5B;&EC($ME>2(*;7-G<W1R(")/9F9E;G1L:6<@4$=0+6[X:VME;')I;F<B
M"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S8V"B,L(&9U>GIY"FUS
M9VED(")01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!S
M:6=N97(O:W)Y<'1E<B!M96QD:6YG(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP
M.C8S"B,L(&9U>GIY"FUS9VED(")02%`@0V]D92(*;7-G<W1R(")(;W)D92(*
M"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HR,`IM<V=I9"`B4$A0(%-H96QL(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#@*
M(RP@9G5Z>GD*;7-G:60@(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`B3&]G9R!I
M;FXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0Y"B,L(&9U
M>GIY"FUS9VED(")032!3:&]W97)S(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4P"B,L(&9U>GIY"FUS9VED(")0
M32!3;F]W(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S4Q"B,L(&9U>GIY"FUS9VED(")032!3;F]W(%-H;W=E<G,B
M"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS-3(*(RP@9G5Z>GD*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@(D9R
M82(*"B,Z(&QI8B]A<&DN<&AP.C$R-@IM<V=I9"`B4%](4"!3:&5L;"(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0V"B,L(&9U>GIY"FUS9VED(")0861D:6YG(@IM<V=S='(@
M(E5T=FED97(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@W(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S(*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`P"B,L(&9U>GIY"FUS9VED(")086MI<W1A;B(*;7-G<W1R
M(")$871O(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-"!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,@HC+"!F=7IZ>0IM<V=I9"`B4&%L874B"FUS9W-T<B`B12UP
M;W-T(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y,B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C$P,@IM<V=I9"`B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@R(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S4*(SH@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!A;F%M82(*;7-G<W1R
M(")N879N(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X-2!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DU(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-S<*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M,3`S"B,L(&9U>GIY"FUS9VED(")087)A9W5A>2(*;7-G<W1R(")%+7!O<W0B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S0W"B,L(&9U>GIY
M"FUS9VED(")087)T;'D@0VQO=61Y(@IM<V=S='(@(DMO<&EE<B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C,V(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S0@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(P,#(*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(P,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<P('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S8*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C,V-PIM<V=I9"`B4&%S<W=O<F0B"FUS9W-T<B`B4&%S<V]R
M9"(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,U-`HC+"!F=7IZ
M>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(E!A<W-O<F0B
M"@HC.B!L:6(O2&]R9&4O075T:"]R861I=7,N<&AP.C$U-PHC+"!F=7IZ>0IM
M<V=I9"`B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B26YG96X@:V]N9FEG=7)A<VIO;B!E<B!S<&5S:69I
M<V5R="!F;W(@4U%,+6%U=&5N=&ES97)I;F<N(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(P,S<*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N(@IM<V=S='(@(E9I<R!M86EL;&ES=&4@:6YF;W)M87-J;VXB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*(RP@9G5Z>GD*
M;7-G:60@(E!A<W-W;W)D.B(*;7-G<W1R(")087-S;W)D(@H*(SH@=&5M<&QA
M=&5S+VQO9VEN+VUO8FEL92YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E!A<W-W
M;W)D.B`B"FUS9W-T<B`B4&%S<V]R9"(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U
M,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C$U"B,L(&9U>GIY"FUS9VED(")087-S=V]R9',@
M;75S="!M871C:"XB"FUS9W-T<B`B4&%S<W!H<F%S92!S=&5M;65R(&EK:V4@
M;W9E<F5N<R(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(R"B,L(&9U
M>GIY"FUS9VED(")087-T92(*;7-G<W1R(")$871O(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B4&%S=&4@
M9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,0HC+"!F=7IZ>0IM<V=I9"`B4&%T
M:"(*;7-G<W1R(")$871O(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-"!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F5Q=65U960N
M:6YC.C0*;7-G:60@(E!E;F1I;F<@4VEG;G5P<SHB"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T"B,L(&9U>GIY"FUS9VED(")096]P
M;&4B"FUS9W-T<B`B4F]L;&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P-PHC+"!F=7IZ>0IM<V=I9"`B4&5R8V5N="(*
M;7-G<W1R(")3:W)I=B!U="(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]C
M;VYF:7)M7V)O='1O;2YI;F,Z-@IM<V=I9"`B4&5R9F]R;2!-86EN=&5N86YC
M92!/<&5R871I;VYS(@IM<V=S='(@(E5T9OAR('9E9&QI:V5H;VQD<V]P97)A
M<VIO;F5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y-@IM<V=I9"`B
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/R(*;7-G
M<W1R(")5=&;X<B!V961L:6ME:&]L9'-O<&5R87-J;VYE<B!V960@:6YN;&]G
M9VEN9S\B"@HC.B!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C$@861M:6XO
M<&5R;7,O861D8VAI;&0N<&AP.C8T"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B(*;7-G<W1R(")0
M97)S;VYL:6<B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C8X"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N("<E<R<@;F]T(&1E
M;&5T960N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R(&EK
M:V4@:6UP;&5M96YT97)T+B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(R
M-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z.3,*(SH@861M:6XO<&5R;7,O
M:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-S0*(RP@9G5Z
M>GD*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(B5S(%!'4"!A9&UI;FES=')A<VIO;B(*"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,30Y(&QI8B](;W)D92]097)M<R]522YP:'`Z,34R"B,Z(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")097)M:7-S
M:6]N<R!F;W(B"FUS9W-T<B`B4&5R<V]N;&EG(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R(")097)S;VYL:6<@:6YF;W)M87-J;VXB"@HC.B!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-S@*
M(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!E<G4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"FUS9VED(")0
M971S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W.0HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DY"FUS
M9VED(")0:&]N92(*;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0T-PIM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#$*
M(RP@9G5Z>GD*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(D1A=&\B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P.`IM<V=I
M9"`B4&EX96QS(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED
M(")0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0X"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D5R(&1U(%-)
M2TM%4B!PY2!A="!D=2#X;G-K97(@Y2!S;&5T=&4@9&4@=F%L9W1E(&]P<&;X
M<FEN9V5N93\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-34*(RP@9G5Z>GD*;7-G:60@(E!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="XB"FUS
M9W-T<B`B17(@9'4@4TE+2T52('#E(&%T(&1U(/AN<VME<B#E('-L971T92!D
M92!V86QG=&4@;W!P9OAR:6YG96YE/R(*"B,Z(&QI8B](;W)D92]&;W)M+G!H
M<#HR-34V"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+B(*;7-G<W1R(")696YN;&EG<W0@<VMR:78@:6YN(&1E="!N
M>64@;F%V;F5T.B(*"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C$R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.B(*;7-G<W1R(")696YN;&EG<W0@
M<VMR:78@:6YN(&YA=FYE="!PY2!D96X@;GEE(&UA<'!E;CHB"@HC.B!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3(Y.0HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B5F5N;FQI9W-T(')E
M='0@='9E='ED:6=E(&5L;&5R('5G>6QD:6=E(&%D<F5S<V5R+B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HR-C4R"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO
M;G1H+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C0S-`HC
M+"!F=7IZ>0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92XB"FUS
M9W-T<B`B5F5N;FQI9W-T('-K<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@
M(E9E;FYL:6=S="!G:2!E="!S86UM96YD<F%G(&%V('!R;V)L96UE="XB"@HC
M.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C$X('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z,C(*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D(@IM<V=S='(@(E9E;FYL:7-T('-K<FEV(&EN
M;B!B<G5K97)N879N(&]G('!A<W-O<F0B"@HC.B!T96UP;&%T97,O;6%I;G1E
M;F%N8V4O86=R965M96YT7W1O<"YI;F,Z,3(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B(@HB4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U5
M4U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN
M(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ-PIM<V=I9"`B
M4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN0&QI<W1S+FAO<F1E+F]R
M9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-30P"FUS9VED("(B"B)0;&5A<V4@<F5V:65W('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VXL(&%N9"!T:&5N('-E;&5C="!A;B!A8W1I;VX@
M9G)O;2!T:&4@(@HB;65N=2!B96QO=RXB"FUS9W-T<B`B(@HB5F5N;FQI9W-T
M('-E(&]V97(@9&5N(&;X;&=E;F1E(&EN9F]R;6%S:F]N96XL('9E;&<@<^4@
M96X@:&%N9&QI;F<@9G)A(&UE;GEE;B`B"B)N961E;G5N9&5R+B(*"B,Z(&QI
M8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0S-0IM<V=I9"`B
M4&QE87-E('-E;&5C="!A;B!A8W1I;VX@9G)O;2!T:&4@;65N=2!B96QO=RXB
M"FUS9W-T<B`B5F5N;FQI9W-T('9E;&<@96X@:&%N9&QI;F<@9G)A(&UE;GEE
M;B!N961E;G5N9&5R+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA
M;F%G97(N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@='EP92!T:&4@
M;F5W(&-A=&5G;W)Y(&YA;64Z(@IM<V=S='(@(E9E;FYL:6=S="!S:W)I=B!I
M;FX@9&5T(&YY92!N879N970Z(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$X."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Q"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P,`HC+"!F=7IZ>0IM<V=I9"`B4&]L86YD
M(@IM<V=S='(@(D9I<FUA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4W
M"B,L(&9U>GIY"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")3;.4@<V%M;65N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-@HC+"!F=7IZ>0IM
M<V=I9"`B4&]L;',B"FUS9W-T<B`B4VSE('-A;6UE;B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ.3,@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$X,@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!O
M<G1U9V%L(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3(T"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-PIM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!I;6%G92(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI
M;F<@;V8@=&AI<R!T86)L92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD
M97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(V-"!L:6(O0FQO8VLO;65T87(N<&AP.C(V.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S
M(&AO=7(H<RDZ("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E9G,O;&1A
M<"YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z
M($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E
M;BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z,S8*(RP@9G5Z
M>GD*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]I;7`Z($MA;B!I:VME
M(&9I;FYE(&1E;B!N^&1V96YD:6=E($E-05`@=71V:61E;'-E;BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,CDX"B,L(&9U>GIY"FUS9VED(")0
M<F5S96YT871I;VYS(@IM<V=S='(@(D9O<G)I9V4@;65L9&EN9R(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R
M92(*;7-G<W1R(")087-S;W)D(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-3<*(RP@9G5Z>GD*;7-G:60@(E!R97-S=7)E(&%T('-E82!L979E;#H@(@IM
M<V=S='(@(E!A<W-O<F0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,3DX"B,L(&9U>GIY"FUS9VED(")0<F5S<W5R93H@(@IM<V=S='(@(E!A
M<W-O<F0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3@X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA
M9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R(")&;W)HY6YD
M<W9I<VYI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A
M;G-E;&EM86=E7VQA;F<N:G,Z,C0*(RP@9G5Z>GD*;7-G:60@(E!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R(")6:7,@=F5D;&5G
M9R!I(&5T(&5G970@=FEN9'4B"@HC.B!L:6(O2&]R9&4O54DO4&%G97(N<&AP
M.C<Q(&QI8B](;W)D92]522]086=E<BYP:'`Z-S(*;7-G:60@(E!R979I;W5S
M(%!A9V4B"FUS9W-T<B`B1F]R<FEG92!S:61E(@H*(SH@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HS-38@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-C`*(RP@
M9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B"FUS9W-T<B`B1F]R<FEG
M92!M96QD:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@9&]C=6UE;G0B"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#`Y"B,L(&9U>GIY"FUS9VED
M(")0<FEV871E($ME>2(*;7-G<W1R(")$:6X@<')I=F%T92!N^&MK96PB"@HC
M.B!L:6(O2&]R9&4O365N=2YP:'`Z,3<U"B,L(&9U>GIY"FUS9VED(")0<F]B
M;&5M(@IM<V=S='(@(EM0<F]B;&5M<F%P<&]R=%TB"@HC.B!S97)V:6-E<R]P
M<F]B;&5M+G!H<#HQ,3(*;7-G:60@(E!R;V)L96T@1&5S8W)I<'1I;VXB"FUS
M9W-T<B`B4')O8FQE;6)E<VMR:79E;'-E(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C(Q-@IM<V=I9"`B4')O:F5C=',B"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(P.34@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q
M-S(*(RP@9G5Z>GD*;7-G:60@(E!R;VUP="!T97AT(@IM<V=S='(@(E)E='1E
M="!T96MS="(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0P.0HC+"!F
M=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")$:6X@;V9F96YT;&EG
M92!N^&MK96PB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8V.0HC
M+"!F=7IZ>0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS9W-T<B`B
M3V9F96YT;&EG(%!'4"UN^&MK96QR:6YG(@H*(SH@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")0=6)L:6,O4')I=F%T92!K
M97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R(")0
M97)S;VYL:6<@4$=0+6[X:VME;'!A<B!G96YE<F5R="XB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DQ(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ.#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"B,L(&9U>GIY
M"FUS9VED(")0=65R=&\@4FEC;R(*;7-G<W1R(")0<F]T;VMO;&PZ(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y-B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,PHC
M+"!F=7IZ>0IM<V=I9"`B46%T87(B"FUS9W-T<B`B4W1A<G0B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z-S`*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C@W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET*2(*;7-G<W1R
M(")/9F9E;G1L:6<@4$=0+6[X:VME;"!T96MS="(*"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,C0X"B,L(&9U>GIY"FUS9VED(")2861I;R!S96QE8W1I;VXB
M"FUS9W-T<B`B1FEL=&5R:6YN<W1I;&QI;F=E<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS-3,*(RP@9G5Z>GD*;7-G:60@(E)A:6XB"FUS
M9W-T<B`B3&]K87-J;VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S4T"B,L(&9U>GIY"FUS9VED(")286EN($5A<FQY(@IM<V=S='(@(D%V
M<VSE='0Z("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-34*
M(RP@9G5Z>GD*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("),;V=G(&EN;B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-38*(RP@9G5Z>GD*
M;7-G:60@(E)A:6X@4VAO=V5R(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4W"B,L(&9U>GIY"FUS9VED(")286EN
M(&%N9"!3;F]W(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,S4X"B,L(&9U>GIY"FUS9VED(")286EN('1O(%-N;W<B
M"FUS9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"B,L
M(&9U>GIY"FUS9VED(")286YD;VT@1F]R='5N92(*;7-G<W1R(").;W1A=&5R
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-S$@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*(RP@9G5Z>GD*;7-G:60@(E)A
M=&EO(@IM<V=S='(@(DQO:V%S:F]N(@H*(SH@;&EB+TAO<F1E+U!E<FUS+G!H
M<#HR.34@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#`*(RP@9G5Z>GD*;7-G:60@(E)E860B"FUS9W-T<B`B3W!P
M9&%T97(B"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*
M(RP@9G5Z>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`B3GEE(&UE
M;&1I;F=E<B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5A;&QY(&1E;&5T92`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$R"B,L('!H<"UF;W)M
M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T
M"B,L(&9U>GIY"FUS9VED(")2961O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G
M<W1R(")':F5N;W!P=&$@<V5S:F]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,X,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S$*(RP@
M9G5Z>GD*;7-G:60@(E)E9G)E<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(D]P
M<&1A=&5R(&UA<'!E=FES;FEN9SHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M.#@Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,C`U(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,C(W"B,L(&9U>GIY"FUS9VED(")296=E>"(*;7-G<W1R(").=6QL<W1I
M;&PB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S(S-`IM<V=I9"`B4F5L871I
M;VYS:&EP($)R;W=S97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS,C0*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#4W"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0W-@IM<V=I9"`B4F5M96UB
M97(@=&AE(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B2'5S:R!L
M961I9R]O<'!T871T+6EN9F]R;6%S:F]N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,30*(RP@9G5Z>GD*;7-G:60@(E)E;6]T92!397)V97)S(@IM
M<V=S='(@(E1J96YE<B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN
M8SHX-`IM<V=I9"`B4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O961I="YI;F,Z,C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z-#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN
M8SHQ-0HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(D9J97)N('!A
M<B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHQ,0HC+"!F=7IZ
M>0IM<V=I9"`B4F5M;W9E($)L;V-K(@IM<V=S='(@(D9J97)N(&MI;&1E(@H*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4S,@HC+"!F
M=7IZ>0IM<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")&:F5R;B!K:6QD
M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-#`*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@
M(D9J97)N('!A<B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8U.`HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E(&9R;VT@;7D@8V%L
M96YD87(B"FUS9W-T<B`B4VQE='0@9G)A(&MA;&5N9&5R96X@;6EN(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,S8*;7-G:60@(E)E;6]V92!P
M86ER(@IM<V=S='(@(D9J97)N('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.38*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*
M(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B1FIE<FX@:VEL
M9&4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-#D*;7-G:60@(E)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@
M9&]C=6UE;G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M<F5M;W9E+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I9"`B4F5M;W9E('5S97(B"FUS
M9W-T<B`B1FIE<FX@:VEL9&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R
M96UO=F4N:6YC.C<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V
M92!U<V5R.B`E<R(*;7-G<W1R(")&:F5R;B!K:6QD92(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$Y-PHC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR.#`*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0Y"FUS9VED(")297!L>2!396YT
M+B(*;7-G<W1R(")3=F%R('-E;F1T+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0U.0HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT-C@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO="!3=7!P
M;W)T960@365S<V%G92(*;7-G<W1R(")3=F%R(&%T(&UE;&1I;F=E;B!I:VME
M('-T^'1T97,B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT
M(#(@;6]N=&AS+B(*;7-G<W1R(")3=F%R(&UE9"!L961I9R]O<'!T871T(&9O
M<B!D92!N97-T92!T;R!MY6YE9&5N92XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-C4*;7-G:60@(E)E<&QY('=I=&@@<F5Q
M=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B4W9A<B!M
M960@9&5N(&9O<F5S<'5R=&4@;&5D:6<O;W!P=&%T="UI;F9O<FUA<VIO;F5N
M+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$X
M.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4F5P;'DZ("5S(@IM<V=S
M='(@(E-V87(Z(@H*(SH@;&EB+TAO<F1E+U)00R]X;6QR<&,N<&AP.C$S.0IM
M<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ.#`@
M;&EB+TAO<F1E+G!H<#HU,#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R(")0Y6MR979D("=U:60G(&5R(&EK:V4@<W!E<VEF:7-E
M<G0@:2!I;G-T:6QL:6YG<VMO;F9I9W5R87-J;VYE;BXB"@HC.B!L:6(O5D93
M+W-Q;"YP:'`Z-C`Q(&QI8B]61E,O9G1P+G!H<#HW-SD@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z-S8S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(E#E:W)E=F0@)W5I9"<@97(@:6MK92!S<&5S:69I<V5R="!I
M(&EN<W1I;&QI;F=S:V]N9FEG=7)A<VIO;F5N+B(*"B,Z(&QI8B](;W)D92]5
M=&EL+G!H<#HW-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E)E<75I
M<F5D("<E<R<@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")0Y6MR979D("=U:60G(&5R(&EK:V4@<W!E<VEF:7-E<G0@:2!I;G-T
M:6QL:6YG<VMO;F9I9W5R87-J;VYE;BXB"@HC.B!L:6(O2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'`Z,S(Y"FUS9VED(")297%U:7)E9"!&:65L9"(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M.3(*;7-G:60@(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(D]B;&EG
M871O<FES:R!D96QT86=E<B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&QI8B](
M;W)D92]&;W)M+G!H<#HS,SD@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP
M.C,Q-@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0*;7-G:60@(E)E<V5T(@IM
M<V=S='(@(DYU;&QS=&EL;"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C0V"B,L(&9U>GIY"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R
M(")087-S;W)D(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C<*
M(RP@9G5Z>GD*;7-G:60@(E)E<V5T(%EO=7(@4&%S<W=O<F0B"FUS9W-T<B`B
M1VIE;F]P<'1A('-E<VIO;B(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV-B!A
M9&UI;B]C;61S:&5L;"YP:'`Z,C@@861M:6XO<W%L<VAE;&PN<&AP.C<S"B,L
M(&9U>GIY"FUS9VED(")297-U;'1S(@IM<V=S='(@(E/X:V5R97-U;'1A="(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX,C$*;7-G:60@(E)E<W5L=',@*&EN
M8VQU9&EN9R!(;W)D92DZ(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HX,3D*(RP@9G5Z>GD*;7-G:60@(E)E<W5L=',Z(@IM<V=S='(@(E/X
M:V5R97-U;'1A="(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHQ
M,#(@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-PIM<V=I9"`B4F5T=7)N('1O
M($]P=&EO;G,B"FUS9W-T<B`B5&EL8F%K92!T:6P@5F%L9R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$X-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@9G5Z
M>GD*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B3V)S97)V97(B"@HC.B!A9&UI
M;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z
M-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(D)E(&]M(&QE=F5R:6YG<V)E:W)E9G1E;'-E(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$S,`HC+"!F=7IZ>0IM<V=I9"`B4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS(@IM<V=S='(@(E1I;&)A:V4@=&EL(%9A;&<B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-3@*(RP@9G5Z>GD*;7-G:60@(E)I9&1L
M97,B"FUS9W-T<B`B4VMJ=6QT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT.`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<P"B,L(&9U>GIY"FUS9VED(")2:6=H
M="(*;7-G<W1R(")(^'EE<W0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P
M-@HC+"!F=7IZ>0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(D5K<V5M
M<&5L=F5R9&EE<CHB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$P,@HC+"!F
M=7IZ>0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(D5K<V5M<&5L=F5R
M9&EE<CHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT
M97AT7VQA;F<N:G,Z,C@*(RP@9G5Z>GD*;7-G:60@(E)O7W<@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("),878@<')I;W)I=&5T(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,S<@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-3@S"FUS9VED(")2;VQE(@IM<V=S='(@(E)O;&QE
M(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Y."!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P,PHC+"!F=7IZ>0IM<V=I9"`B4F]M86YI82(*;7-G<W1R(").;W)M86PB
M"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C`X"B,L
M(&9U>GIY"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(F9L>71T(&]P<"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(RP@
M9G5Z>GD*;7-G:60@(E)O=&%T92!,969T(@IM<V=S='(@(F9L>71T(&]P<"(*
M"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,3$*(RP@
M9G5Z>GD*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R(")&;'ET="!T:6P@
M:/AY<F4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0Y"B,L(&9U>GIY"FUS9VED(")2;W<@4')O<&5R=&EE<R(*
M;7-G<W1R("),878@<')I;W)I=&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`HC+"!F=7IZ>0IM<V=I9"`B
M4F]W('!R;W!E<G1I97,B"FUS9W-T<B`B3&%V('!R:6]R:71E="(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"B,L(&9U
M>GIY"FUS9VED(")2;W=S.B(*;7-G<W1R(")3;.4@<V%M;65N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,PHC
M+"!F=7IZ>0IM<V=I9"`B4G5L97,B"FUS9W-T<B`B4F]L;&4B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4P"FUS
M9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C
M;VQU;6YS(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G
M:60@(E)U;B(*;7-G<W1R(")/8G-E<G9E<B(*"B,Z(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-PHC
M.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E)U<W-I86X@
M1F5D97)A=&EO;B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#@*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"B,L(&9U>GIY"FUS9VED(")2=V%N
M9&$B"FUS9W-T<B`B2V%L96YD97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI
M;64N<&AP.C,P,`IM<V=I9"`B4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T
M=7)E(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,S0Q"B,L(&9U>GIY"FUS9VED(")3+TU)344@16YC<GEP=&5D($UE<W-A9V4B
M"FUS9W-T<B`B2W)Y<'1E<B!M960@4R]-24U%(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<V%S;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B3VUA9')E<W-E<FEN
M9R!F96EL970N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X,0HC
M+"!F=7IZ>0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R(")-96QD:6YG
M<W9I<VYI;F<B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-1
M3"!3:&5L;"(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,S4X"FUS9VED(")34R(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S<U"FUS9VED(")34T@B"FUS9W-T<B`B
M(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N
M<&AP.C,X"FUS9VED(")354-#15-3(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN
M<&AP.C$S,`IM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8Q"B,L(&9U>GIY
M"FUS9VED(")382(*;7-G<W1R("),86=R92!S;VTB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`W(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.#D*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")386EN
M="!(96QE;F$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$S,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DP"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@U"FUS9VED(")386EN="!+:71T<R!A;F0@
M3F5V:7,B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S
M.2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C@X"FUS9VED(")386EN="!,=6-I82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@Y(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`Q"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#0@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G
M<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4Q(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$X"B,L(&9U>GIY"FUS9VED(")386UO82(*;7-G<W1R("),86=R
M92!S;VTB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$R(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`W"B,L(&9U>GIY"FUS9VED(")386X@36%R:6YO(@IM<V=S='(@
M(D%D=F%R<V5L(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DV"B,Z(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C$P.`IM<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$R,`HC+"!F
M=7IZ>0IM<V=I9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E-T870O
M1GEL:V4@*$%R8F5I9"DB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDX"FUS9VED
M(")3879E(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,C$V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E("5S(@IM<V=S='(@(DQA9W)E('-O;2(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-A=F4@)R5S)R(*;7-G<W1R("),86=R92!S;VTB"@HC.B!T96UP;&%T
M97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T
M<B`B3&%G<F4@5F%L9R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*
M;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E-E;F0@<VES=&4@:6YF;W)M87-J;VXB"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY,`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("<E
M<R<N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3D*(RP@9G5Z>GD*;7-G:60@
M(E-C:65N8V4B"FUS9W-T<B`B4VEG;F5R="(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VQI<W0N:6YC.C$U('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C$W"FUS9VED(")396%R8V@B"FUS9W-T<B`B4_AK(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C(X,0HC+"!F=7IZ>0IM<V=I9"`B4V5A<F-H
M($5N9VEN97,B"FUS9W-T<B`B4_AK("5S(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$T,CD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-E87)C:&EN
M9R!(;W)D92!A<'!L:6-A=&EO;G,@:6X@)7,B"FUS9W-T<B`B26YN<W1I;&QI
M;F=E<B!F;W(@<_AK(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R,PHC+"!F
M=7IZ>0IM<V=I9"`B4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N+BXB"FUS
M9W-T<B`B26YN<W1I;&QI;F=E<B!F;W(@<_AK(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C(Y-3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G
M<W1R(")696QG(&%L;&4B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#4V"FUS9VED(")396QE8W0@82!D871E(@IM<V=S='(@(E9E
M;&<@96X@9&%T;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3DX
M"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T
M<B`B5F5L9R!E;B!K;VYT;R(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z-#,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G
M<W1R(")696QG(&EN9V5N(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T
M<B`B5F5L9R!E;B!D871O(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S97(@=&\@861D(@IM
M<V=S='(@(E9E;&<@970@9F5L="(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR
M-C4U"B,L(&9U>GIY"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N96YT
M<RXB"FUS9W-T<B`B5F5L9R!E;B!D871O(@H*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@Q-`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%N(&]B:F5C="(*;7-G<W1R(")696QG(&EN9V5N(@H*(SH@<V5R=FEC97,O
M:V5Y8F]A<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED("(B"B)396QE8W0@=&AE
M(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO
M=2!C86X@=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82XB"FUS9W-T<B`B(@HB5F5L9R!K87)A:W1E<F5N92!D=2!T<F5N
M9V5R(&9R82!B;VMS96X@=6YD97(N($1U(&MA;B!D97)E='1E<B!K;W!I97)E
M(&]G("(*(FQI;64@9&5M(&EN;B!F<F$@=&5K<W1F96QT970N(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z(@IM<V=S='(@(E9E;&<@9&%T;W-K:6QL971E9VXZ(@H*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T
M:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(E9E;&<@9&%T;V9O<FUA="(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.#4*;7-G:60@
M(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ
M>0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`B
M5F5L9R!D871O<VMI;&QE=&5G;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE
M+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T
M<B`B5F5L9R!T:61S9F]R;6%T.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z-C0*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*
M;7-G<W1R(")696QG('1O('-A;7-V87)E;F1E(&9E;'0N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(Y-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@
M<V-H96UE+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,X"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM
M<V=S='(@(E9E;&<@^&YS:V5T('-P<N5K.B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8U,PIM<V=I9"`B4V5N9"!,871E<W0@
M26YF;W)M871I;VXB"FUS9W-T<B`B4V5N9"!S:7-T92!I;F9O<FUA<VIO;B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C4X"FUS9VED(")3
M96YD(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-E;F0@<')O8FQE;7)A<'!O
M<G0B"@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T
M"B,L(&9U>GIY"FUS9VED(")396YD(%--4R(*;7-G<W1R(")396YD(&UE;&1I
M;F<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C$S(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S$T"B,L(&9U>GIY"FUS9VED(")396YS;W(Z("(*;7-G
M<W1R("(@("`@16UN93H@(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R(")-96UO
M(@H*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B
M4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S(U"B,L(&9U>GIY"FUS9VED(")397)I86P@
M3G5M8F5R(@IM<V=S='(@(DYA=FXB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;B!)1"!E
M>'!I<F5D+B(*;7-G<W1R(")-96QD:6YG<V9E;'0B"@HC.B!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C(Y-@HC+"!F=7IZ>0IM<V=I9"`B4V5T(@IM<V=S='(@(E9E
M;&<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$Q-0IM<V=I9"`B4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ
M>0IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")3971T('-I9&4@;W!P9&%T
M97)I;F<L(&]G('9I<VYI;F=S('9A;&<N(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.CDX"B,L(&9U>GIY"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B4V5T="!S
M:61E(&]P<&1A=&5R:6YG+"!O9R!V:7-N:6YG<R!V86QG+B(*"B,Z(&%D;6EN
M+W-E='5P+V-O;F9I9RYP:'`Z-S0*(RP@9G5Z>GD*;7-G:60@(E-E='5P(@IM
M<V=S='(@(E9E;&<B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS.`IM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,30Y"FUS9VED(")3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")397EC:&5L;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S,*
M(RP@9G5Z>GD*;7-G:60@(E-H;W!P:6YG(@IM<V=S='(@(E9I<W0B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT,PHC+"!F=7IZ>0IM<V=I
M9"`B4VAO<G0@4W5M;6%R>2(*;7-G<W1R(")+;W)T('-A;6UE;F1R86<Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S-@IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,CDT('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV
M-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"B,L(&9U>GIY
M"FUS9VED(")3:&]W(@IM<V=S='(@(E9I<W0B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30Y"FUS9VED("(B"B)3:&]W(&1I9F9E<F5N8V5S(&)E='=E
M96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D("(*
M(F-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HT.#`*;7-G:60@(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C$W-3,*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86PB"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#(*(RP@9G5Z>GD*
M;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(E9I<W0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-3$U"B,L(&9U>GIY"FUS9VED(")3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_(@IM<V=S='(@(E9I<V4@9FEL=&5R:6MO
M;F5T(&D@;65N>65N/R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-H;W<@=&AE("5S($UE;G4@
M;VX@=&AE(&QE9G0_(@IM<V=S='(@(E9I<V4@9FEL=&5R:6MO;F5T(&D@;65N
M>65N/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU.`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI
M;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-C,*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHU.0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G(@IM<V=S='(@(D9O<FCE;F1S=FES;FEN9R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B1F]R:.5N9'-V:7-N:6YG(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$W-3$*(RP@9G5Z>GD*;7-G:60@(E-H;W<@=7!L;V%D(@IM
M<V=S='(@(E9I<R!S;&5T=&5D92!E;&5M96YT97(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S4Y"B,L(&9U>GIY"FUS9VED(")3:&]W97)S
M(@IM<V=S='(@(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,S8P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@
M(E9I<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8Q"B,L
M(&9U>GIY"FUS9VED(")3:&]W97)S($QA=&4B"FUS9W-T<B`B5FES="(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-C(*;7-G:60@(E-H;W=E
M<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.C,Y,0HC+"!F=7IZ>0IM<V=I9"`B4VAR:6YK(@IM
M<V=S='(@(DQO9V<@:6YN(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP
M:'`Z-C@T(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<T-@HC.B!L:6(O
M2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,#0@;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="YP:'`Z.#8V"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.CDP
M,2!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HY,S@*(SH@;&EB+TAO<F1E
M+T)L;V-K+TQA>6]U="YP:'`Z.38V(&QI8B](;W)D92]";&]C:R],87EO=70N
M<&AP.CDY-@IM<V=I9"`B4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3$@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(P,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G
M:60@(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.C(W.`HC+"!F=7IZ>0IM<V=I9"`B4VEG;B!U<"(*;7-G
M<W1R(")3:6=N97)T(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX
M.0IM<V=I9"`B4VEG;B!U<"!I9B!N;W0@<F5G:7-T97)E9"(*;7-G<W1R(")2
M96=I<W1R97(@9&5G(&]M(&EK:V4@<F5G:7-T<F5R="(*"B,Z(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-S,V"B,L(&9U>GIY"FUS9VED(")3:6=N871U
M<F4B"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI8B](;W)D92]#<GEP
M="]S;6EM92YP:'`Z-S,U"B,L(&9U>GIY"FUS9VED(")3:6=N871U<F4@06QG
M;W)I=&AM(@IM<V=S='(@(D1I;B!S:6=N871U<CHB"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`V(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,#(*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"B,L(&9U>GIY"FUS
M9VED(")3:6YG87!O<F4B"FUS9W-T<B`B1&EN('-I9VYA='5R.B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HX.3$@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#<@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$R,CD*(SH@;&EB+TAO<F1E+T9O<FTN<&AP
M.C(R,S`@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,Q,#@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S(*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<*;7-G:60@(E-I>F4B"FUS9W-T<B`B
M4W3X<G)E;'-E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?
M8F]T=&]M+FEN8SHY"FUS9VED(")3:VEP($UA:6YT96YA;F-E(@IM<V=S='(@
M(DAO<'`@;W9E<B!V961L:6ME:&]L9"(*"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HT,S$@<&\O=')A;G-L871I;VXN<&AP.C0X-"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z-C8V"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HX-C`@<&\O=')A;G-L871I
M;VXN<&AP.C$R,#0*;7-G:60@(E-K:7!P960N+BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`S"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T<B`B3F]R;6%L(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(P."!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C`T"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-@HC
M+"!F=7IZ>0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B3F]R;6%L(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,PHC+"!F=7IZ>0IM<V=I
M9"`B4VYO=R(*;7-G<W1R(")6:7-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,V-`HC+"!F=7IZ>0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS
M9W-T<B`B5FES="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS
M-C4*(RP@9G5Z>GD*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")6:7-T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V-@HC+"!F=7IZ
M>0IM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@(E9I<W0B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8W"B,L(&9U>GIY"FUS
M9VED(")3;F]W(%-H;W=E<G,@3&%T92(*;7-G<W1R(")6:7-T(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR-S8*(RP@9G5Z>GD*;7-G:60@(E-N;W<@9&5P
M=&@Z("(*;7-G<W1R("(@("`@16UN93H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR.#`*;7-G:60@(E-N;W<@97%U:79A;&5N="!I;B!W871E<CH@(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,#(@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-O;&]M;VX@27-L86YD<R(*
M;7-G<W1R(")/<'!D871E<B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,30@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-@HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#<*(RP@9G5Z>GD*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B3F]R;6%L(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P
M"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR.3$U"B,L(&9U>GIY"FUS9VED(")3;W)T(&]R9&5R('-E
M;&5C=&EO;B(*;7-G<W1R(")3;W)T97)I;F=S<F5K:V5F^&QG92(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#$@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C8Q,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C(R,R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(U-0HC+"!F=7IZ>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T
M<B`B1FER;6%A9')E<W-E(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U
M-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`W"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@V"FUS9VED(")3;W5T
M:"!%=7)O<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$P,2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<X"FUS9VED(")3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L;V-K
M+VUO;VXN<&AP.C8R"B,L(&9U>GIY"FUS9VED(")3;W5T:&5R;B!(96UI<W!H
M97)E(@IM<V=S='(@(DAJ96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,3,*;7-G:60@(E-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@Q-0HC+"!F=7IZ>0IM<V=I9"`B4W!A8V5R(@IM
M<V=S='(@(DQA9W)E('-O;2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`HC+"!F=7IZ>0IM<V=I9"`B4W!A8VEN
M9R(*;7-G<W1R(")5='9I9&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A;F0@
M<&%D9&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,@HC+"!F=7IZ>0IM<V=I9"`B4W!A:6XB"FUS
M9W-T<B`B571V:61E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HY
M-0HC+"!F=7IZ>0IM<V=I9"`B4W!A;2(*;7-G<W1R("),86=R92!S;VTB"@HC
M.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G:60@(E-P96-I86P@0VAA
M<F%C=&5R($EN<'5T(@IM<V=S='(@(E-P97-I86QT96=N:6YN=&%S=&EN9R(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C(*(RP@9G5Z>GD*;7-G:60@(E-P;&ET(&-E;&PB"FUS9W-T<B`B5F5L
M9R!A;&QE(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV-@HC+"!F=7IZ>0IM<V=I9"`B4W!L:70@8V]L=6UN(@IM
M<V=S='(@(E9E;&<@86QL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P;&ET
M(')O=R(*;7-G<W1R(")696QG(&%L;&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")6:6MT
M:6<B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,3`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.#D*(RP@9G5Z>GD*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R("),;V=G
M(&EN;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV."!L:6(O
M0FQO8VLO;65T87(N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*
M;7-G<W1R(")+86QE;F1E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV
M,@HC+"!F=7IZ>0IM<V=I9"`B4W1A<B!4<F5K(@IM<V=S='(@(E-T87)T(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4T.`IM<V=I
M9"`B4W1A<G0B"FUS9W-T<B`B4W1A<G0B"@HC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C4X.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y.`HC+"!F=7IZ>0IM<V=I
M9"`B4W1A<G0@>65A<B(*;7-G<W1R(")3=&%R="(*"B,Z(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3DT"B,L(&9U>GIY"FUS9VED(")3=&%T92!O<B!0
M<F]V:6YC92(*;7-G<W1R(")3=&%T+T9Y;&ME("A!<F)E:60I(@H*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3@S('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C$R"FUS9VED(")3=&%T=7,B"FUS
M9W-T<B`B4W1A='5S(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C0Y,0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B`B"FUS
M9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(X,#0*(RP@9G5Z>GD*
M;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO
M;B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DV"B,L(&9U>GIY
M"FUS9VED(")3=')E970@061D<F5S<R(*;7-G<W1R(")&<F$M861R97-S92(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$*
M;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$R,C4*(RP@9G5Z>GD*;7-G:60@(E-T<FEN9R!L:7-T(@IM
M<V=S='(@(E-V87)T96QI<W1E(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$X
M-3<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C(*;7-G
M:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B9&ER96-T;W)Y("<E
M<R<@;F]T(&9O=6YD+B(*;7-G<W1R(").;W1I<R!L>71T97(@)7,@:6MK92!F
M=6YN970N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,S4@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-S@*;7-G:60@(E-U8FIE
M8W0B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-C8X"B,L(&9U>GIY"FUS9VED(")3=6)J96-T(%!U8FQI8R!+97D@26YF
M;R(*;7-G<W1R(")$:6X@;V9F96YT;&EG92!N^&MK96PB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S,R(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS
M,3,*;7-G:60@(E-U8FUI="(*;7-G<W1R(")396YD(@H*(SH@<VEG;G5P+G!H
M<#HU,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S
M="!T;R!A9&0@)R5S)R!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@
M:6X@=6YT:6P@>6]U<B`B"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$R"B,L(&9U>GIY"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
M4V5N9"(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3,@;&EB+TAO<F1E+TYO
M=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C,P"FUS9VED(")3=6-C
M97-S(@IM<V=S='(@(E-U:W-E<W,B"@HC.B!A9&UI;B]U<V5R+G!H<#HX-0HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D9&5D
M("<E<R<@=&\@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA9W0@=&EL
M("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E
M<B`G)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`B)7,@8FQE(&QA9W0@
M=&EL("5S+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C
M8V5S<V9U;&QY(&1E;&5T960@)R5S)RXB"FUS9W-T<B`B2&5N9&5L<V5N(&)L
M92!S;&5T=&5T+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P-0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(')E;6]V960@)R5S)R!F
M<F]M('1H92!S>7-T96TN(@IM<V=S='(@(B5S(&)L92!L86=T('1I;"`E<RXB
M"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"B,L(&9U>GIY"FUS9VED
M(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D
M('1O('-E92!C:&%N9V5S+B(*;7-G<W1R(")+=6YN92!I:VME(&QA9V4@5D93
M+6)A8VME;F0Z("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C4Y(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4U"B,L(&9U>GIY"FUS9VED(")3=6-C
M97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N9#H@)7,B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(@IM<V=S='(@(DMU;FYE(&EK:V4@;&%G92!61E,M8F%C:V5N
M9#H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-C@*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D("<E<R<B"FUS9W-T
M<B`B26YN<W1I;&QI;F=E;F4@8FQE(&]P<&1A=&5R="XB"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E
M("5S(@IM<V=S='(@(B5S(&)L92!L86=T('1I;"`E<RXB"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C`T(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"B,L(&9U>GIY
M"FUS9VED(")3=61A;B(*;7-G<W1R(")5='9I9&5R(@H*(SH@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34X"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM
M87)Y(@IM<V=S='(@(E-A;6UE;F1R86<B"@HC.B!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(D5M
M;F4B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-S$*(RP@9G5Z>GD*;7-G
M:60@(E-U;B!3970B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS-C@*;7-G:60@(E-U;FYY(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G
M:60@(E-U;G)I<V4B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]";&]C:R]S=6YR
M:7-E+G!H<#HS(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HQ-@HC+"!F=7IZ>0IM
M<V=I9"`B4W5N<FES92]3=6YS970B"FUS9W-T<B`B16UN92(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S@*(RP@9G5Z>GD*;7-G:60@(E-U
M;G)I<V4Z("(*;7-G<W1R("(@("`@16UN93H@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$X,@HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T(@IM
M<V=S='(@(D5M;F4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3@Q"B,L(&9U>GIY"FUS9VED(")3=6YS970Z("(*;7-G<W1R("(@("`@16UN
M93H@(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,PHC+"!F=7IZ>0IM<V=I9"`B4W5P97)S8W)I<'0B"FUS9W-T<B`B0F5S
M:W)I=F5L<V4B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8U"B,L
M(&9U>GIY"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(DEM<&]R=&5R(@H*(SH@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-2!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PHC
M+"!F=7IZ>0IM<V=I9"`B4W5R:6YA;64B"FUS9W-T<B`B;F%V;B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3DX"B,L(&9U>GIY"FUS9VED(")3
M=7)N86UE(@IM<V=S='(@(FYA=FXB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C`Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`V"FUS9VED(")3=F%L8F%R9"!A;F0@
M2F%N($UA>65N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E-W87II
M;&%N9"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C`U(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3`U"B,L(&9U>GIY"FUS9VED(")3=V5D96XB
M"FUS9W-T<B`B3&5S="(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HU-B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C8W"B,L(&9U>GIY"FUS9VED(")3=VET>F5R;&%N9"(*
M;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<#HY
M.`HC+"!F=7IZ>0IM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<R(*;7-G<W1R(")4^&T@<_AP<&5L:W5R=F5N(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(Q."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P.`IM<V=I9"`B4WER:6%N
M($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C,V.0HC+"!F=7IZ>0IM<V=I9"`B5"U3=&]R;2(*;7-G
M<W1R(")&<F$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<P
M"B,L(&9U>GIY"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R(")&<F$B"@HC.B!L
M:6(O2&]R9&4O1&%T82]T<W8N<&AP.C$W,0HC+"!F=7IZ>0IM<V=I9"`B5%-6
M(&9I;&4B"FUS9W-T<B`B5&ET=&5L(@H*(SH@;&EB+TAO<F1E+U5)+U1A8FQE
M+G!H<#HQ,S4*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(@IM<V=S='(@(E1I='1E
M;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%!R;W!E<G1I97,B"FUS
M9W-T<B`B1F]R:.5N9'-V:7-N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@HC+"!F=7IZ>0IM<V=I9"`B
M5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,T(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@HC+"!F=7IZ>0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(E/X
M:R(*"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,3@*;7-G:60@
M(E1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(R-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C$Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,`HC+"!F
M=7IZ>0IM<V=I9"`B5&%J:6MI<W1A;B(*;7-G<W1R(")$871O(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(S-2!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q,PIM<V=I
M9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDU"B,L
M(&9U>GIY"FUS9VED(")487)G970Z(@IM<V=S='(@(D)R=6ME<FYA=FXZ(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$V.`IM<V=I9"`B5&%S:W,B
M"FUS9W-T<B`B3W!P9V%V97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4Y-PHC+"!F=7IZ>0IM<V=I9"`B5&5L97!H;VYE($YU;6)E<B(*;7-G
M<W1R(").879N(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#@*;7-G:60@
M(E1E;7`@9F]R(&QA<W0@:&]U<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C$R"B,L(&9U>GIY"FUS9VED(")496UP97)A='5R92(*
M;7-G<W1R(")$:6X@<VEG;F%T=7(Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$X-@HC+"!F=7IZ>0IM<V=I9"`B5&5M<&5R871U<F4Z("(*
M;7-G<W1R(")$:6X@<VEG;F%T=7(Z(@H*(SH@;&EB+TAO<F1E+U1E;7!L871E
M+G!H<#HR,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R(")6961L96=G970@8FQE(&EK:V4@
M9G5N;F5T+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,38Y"B,L(&9U>GIY
M"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!0
M1U`@861M:6YI<W1R87-J;VXB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HV-#$*;7-G:60@(E1E;G1A=&EV96QY($%C8V5P="!R
M97%U97-T(@IM<V=S='(@(D=O9'1A(&9O<F5S</AR<V5L(&9O<F5L^'!I9R(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8X.0IM
M<V=I9"`B5&5N=&%T:79E;'D@06-C97!T960B"FUS9W-T<B`B1V]D=&$@9F]R
M96SX<&EG(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R,#,*(RP@9G5Z>GD*
M;7-G:60@(E1E>'0B"FUS9W-T<B`B5&5?:W-T(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,V-0IM<V=I9"`B5&5X="!/;FQY(@IM<V=S='(@(DMU;B!T
M96MS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-S0*(RP@9G5Z>GD*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T
M<B`B3F5S=&4@<VED92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z-S$*(RP@9G5Z>GD*;7-G:60@(E1E>'1T;W`B"FUS9W-T
M<B`B5&5?:W-T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU.0IM<V=I9"`B5&@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.#<*;7-G:60@(E1H86D@*%1)4RTV,C`I(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C0@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(R,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E1H86EL86YD(@IM<V=S='(@(E/X:R(*
M"B,Z(&QI8B](;W)D92]!=71H+G!H<#HY-#0*(RP@9G5Z>GD*;7-G:60@(E1H
M86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS9W-T<B`B1'4@:&%R
M(&)L:70@;&]G9V5T('5T+B`\8G(@+SX@5&%K:R!F;W(@870@9'4@8G)U:W1E
M('-Y<W1E;65T+B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#4W"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92`E<R!H96QP(&9I;&4@9F]R("5S(&1O97-N
M)W0@>65T(&5X:7-T+B!#<F5A=&EN9R!A(&YE=R!O;F4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW-CD*(RP@9G5Z>GD*;7-G:60@(E1H92!&
M5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(D1E="!E
M<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P;W-T8F]K<V5N+B(*"B,Z(&QI
M8B](;W)D92]+;VQA8BYP:'`Z.3(T"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N
M8V4N<&AP.C(Y"FUS9VED(")4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@
M;F]T(&QO860@<W5C8V5S<V9U;&QY(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S
M+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,CD*(RP@9G5Z>GD*;7-G:60@(E1H
M92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+B(*;7-G<W1R
M(")-96QD:6YG96X@<V]M(&AA<B!B;&ET="!S:W)E=F5T(&AA<B!B;&ET="!S
M=&5N9W0N($%V<VQU='1E<BXB"@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$V
M,"!L:6(O2&]R9&4O4&5R;7,N<&AP.C$W,2!L:6(O2&]R9&4O4&5R;7,N<&AP
M.C$X,@HC.B!L:6(O2&]R9&4O4&5R;7,N<&AP.C$Y-"!L:6(O2&]R9&4O4&5R
M;7,N<&AP.C(P-2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(R,PHC.B!L:6(O2&]R
M9&4O4&5R;7,N<&AP.C(S-2!L:6(O2&]R9&4O4&5R;7,N<&AP.C(W-`IM<V=I
M9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U("(*(G=A;G0@
M=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<U"FUS9VED(")4
M:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT.0IM<V=I9"`B5&AE(&-A;&5N
M9&%R(&1A=&$@:7,@:6YV86QI9"(*;7-G<W1R(")+86QE;F1E<F1A=&$@97(@
M=6=Y;&1I9R(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-C0*(RP@9G5Z>GD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E<B!W
M87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD
M(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@
M;W!P9V%V96X@97(@:6MK92!S=&]T=&5T+B(*"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z-30*(RP@9G5Z>GD*;7-G:60@(E1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(D]P<&;X<FEN9V5N(%PB)7-<(B!B;&4@;&%G="!T:6P@
M861R97-S96)O:V5N(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$W
M,0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U
M<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S
M<V%G92XB"FUS9W-T<B`B16X@;V9F96YT;&EG(%!'4"UN^&MK96P@97(@<.5K
M<F5V9"!F;W(@Y2!V97)I9FES97)E('-I9VYE<G0@;65L9&EN9RXB"@HC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8V"B,L(&9U>GIY"FUS
M9VED("(B"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T
M:&4@9&%T86)A<V4N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N
M(&5R(&EK:V4@<W1O='1E="XB"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C8W"B,L(&9U>GIY"FUS9VED(")4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S='(@(D1E;B!F;W)E<W!U
M<G1E(&]P<&=A=F5N(&5R(&EK:V4@<W1O='1E="XB"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0N<&AP.C$R-PHC+"!F=7IZ>0IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@
M9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS
M9W-T<B`B4_AT=&4@9F]R('!E<G-O;FQI9R!01U`@;OAK:V5L<&%R(&MR979E
M<B!E;B!S:6MK97(@=V5B+71I;&MO8FQI;F<N(@H*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S@*(RP@9G5Z>GD*;7-G:60@(E1H
M92!E=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A;&5N9&%R+B(*;7-G
M<W1R(")(96YD96QS96X@8FQE(&QA9W0@=&EL(&D@9&EN(&MA;&5N9&5R+B(*
M"B,Z(&QI8B](;W)D92YP:'`Z,3@Q(&QI8B](;W)D92YP:'`Z-3`T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@
M)7,@<V5T=&EN9RXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-S0@
M;&EB+TAO<F1E+G!H<#HT.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RXB"FUS9W-T
M<B`B(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HQ-C0*;7-G:60@(E1H92!F:6QE
M(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1&%T82YP:'`Z,C8T"FUS9VED(")4:&4@9FEL92!C;VYT
M86EN960@;F\@9&%T82XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S(*;7-G:60@(E1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-38*;7-G:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES
M(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R
M97(L(&1U92`B"B)T;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B
M;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A
M<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O
M<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@
M:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E
M="!A("='96YE<F%L("(*(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O
M(')E8F]O="Y<7&Y<7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B
M"B)P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@
M<V-R965N(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN
M<&AP.C$P.#4@<&\O=')A;G-L871I;VXN<&AP.C$R,38*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE(&AE;'`@9FEL92`E<R!D:61N)W0@<W1A<G0@=VET:"`\
M/WAM;"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.#@*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@
M:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB
M(&)L92!S;&5T=&5T+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$S-@IM<V=I9"`B(@HB5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+TU$3BYP:'`Z,C$T"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@
M)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N7&XB
M"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$X-C$*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N
M(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R-3D*;7-G:60@(E1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<RYP
M:'`Z,CDQ"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E
M(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O9&5B+G!H<#HS-2!L:6(O
M2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,W"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,U"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,U(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R<&TN<&AP.C,U"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]W96)C
M<'`N<&AP.C0P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]S<F-H:6=H;&ET
M92YP:'`Z,SD*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS97AC96PN<&AP
M.C,U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B
M5&AE(')I9VAT+6AA;F0@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C<X"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E;B!D96QE=&5D+B(*
M;7-G<W1R("))9&5N=&ET971E;B!<(B5S7"(@8FQE('-L971T970N(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D
M+B(*;7-G<W1R("))9&5N=&ET971E;B!<(B5S7"(@8FQE(&QA9W)E="XB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ.3@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"XB"FUS9W-T<B`B261E;G1I=&5T96X@7"(E<UPB(&)L92!L86=R970N(@H*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,C@T"B,L(&9U>GIY"FUS
M9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T
M<B`B1&5N('-P97-I9FES97)T92!F:6QE;B!E:W-I<W1E<F5R(&EK:V4N(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`X"FUS
M9VED(")4:&4@=&%S:R!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R('1A<VML:7-T
M+B(*;7-G<W1R(")(86YD;&EN9V5N(&AA<B!B;&ET="!L86=T('1I;"!D:6X@
M;&ES=&4@;W9E<B!H86YD;&EN9V5R+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HQ
M,3$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H92!T96UP;W)A<GD@
M9FEL92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(D1E;B!S<&5S
M:69I<V5R=&4@9FEL96X@96MS:7-T97)E<B!I:VME+B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@
M(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M.#`*;7-G:60@(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]$871A+G!H<#HS,3$*;7-G:60@(E1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("(B
M"@HC.B!L:6(O2&]R9&4O1&%T82]C<W8N<&AP.C(U,"!L:6(O2&]R9&4O1&%T
M82]T<W8N<&AP.C$W-PHC+"!F=7IZ>0IM<V=I9"`B5&AE('5P;&]A9&5D(&9I
M;&4@8V]U;&0@;F]T(&)E('-A=F5D+B(*;7-G<W1R(")3:6=N871U<F5N(&MU
M;FYE(&EK:V4@97)S=&%T=&5S+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.CDS"FUS9VED(")4:&4@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;B!W87,@<W5C97-S9G5L;'D@<W1O<F5D+B(*;7-G<W1R
M(")"<G5K97)E;G,@;&5D:6<O;W!P=&%T="!I;F9O<FUA<VIO;B!B;&4@;&%G
M<F5T+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-3(*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C$P,R!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,3`W"B,L(&9U>GIY"FUS9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92XB"FUS9W-T<B`B1&5T(&5R(&EN9V5N(&UE;&1I;F=E
M<B!I(&1E;FYE('!O<W1B;VMS96XN(@H*(SH@=71I;"]I8V]N7V)R;W=S97(N
M<&AP.C(U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5M97,@9&ER
M96-T;W)Y("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R(")6961L96=G970@8FQE
M(&EK:V4@9G5N;F5T+B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@R
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B
M;&4N(@IM<V=S='(@(D1E="!E<B!I;F=E;B!M96QD:6YG97(@:2!D96YN92!P
M;W-T8F]K<V5N+B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HS
M-#`*(RP@9G5Z>GD*;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A
M;B!B92!D:7-P;&%Y960@:6YL:6YE+B(*;7-G<W1R(")$970@97(@:6YG96X@
M86QT97)N871I=F4@9&5L97(@<V]M(&MA;B!V:7-E<R!I;FQI;F4N(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$S.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L
M9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S
M="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('!O+W1R86YS
M;&%T:6]N+G!H<#HQ,#0X"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E(&1O
M97-N)W0@>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RXB"FUS9W-T<B`B
M(@H*(SH@<VEG;G5P+G!H<#HU-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES
M=&5M+B`E<RXB"FUS9W-T<B`B1&5T(&]P<'-T;V0@970@<')O8FQE;2!U;F1E
M<B!S;&5T=&EN9V5N(&%V("5S+B!-96QD:6YG(&9R82!S97)V97)E;B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`G)7,G('1O('1H92!S>7-T
M96TZ("5S(@IM<V=S='(@(D1E="!O<'!S=&]D(&5T('!R;V)L96T@=6YD97(@
M<VQE='1I;F=E;B!A=B`E<RX@365L9&EN9R!F<F$@<V5R=F5R96XB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`G
M)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@(B(*(D1E="!O<'!S=&]D
M(&5T('!R;V)L96T@=F5D(&9J97)N:6YG(&%V('!O<W1B;VMS96XN($UE;&1I
M;F<@9G)A('-E<G9E<F5N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES=&5M.B`B"FUS9W-T<B`B1&5T(&]P
M<'-T;V0@970@<')O8FQE;2!U;F1E<B!S;&5T=&EN9V5N(&%V("5S+B!-96QD
M:6YG(&9R82!S97)V97)E;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$U.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R`G)7,G.B`E<R(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL
M('5N9&5R(&]P<&1A=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,B"@HC.B!L:6(O
M2&]R9&4O0G)O=W-E<BYP:'`Z.#DY"B,L('!H<"UF;W)M870*;7-G:60@(E1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T)R;W=S
M97(N<&AP.CDP-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA
M<F=E<B!T:&%N('1H92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET
M97,I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`V
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L
M;'D@=7!L;V%D960N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]R9F,X,C(N<&AP.C,X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R(")$970@;W!P
M<W1O9"!E;B!F96EL('5N9&5R(&9O<G/X:R!PY2#E('9I<V4@9&5N;F4@;65L
M9&EN9W-D96QE;B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0HC+"!F
M=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+B(*;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('9E
M9"!I;7!O<G1E<FEN9R!A=B!H96YD96QS96XZ("5S+B(*"B,Z(&QI8B](;W)D
M92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<U"B,L('!H<"UF;W)M870*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT
M.B`E<RXB"FUS9W-T<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!I;7!O
M<G1E<FEN9R!A=B!H96YD96QS96XZ("5S+B(*"B,Z(&QI8B](;W)D92]$871A
M+VEM8RYP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(*;7-G<W1R(")$970@
M;W!P<W1O9"!E;B!F96EL('5N9&5R(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E
M;CH@)7,N(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O
M<B!I;7!O<G1I;F<@=&AE('1A<VLZ("5S+B(*;7-G<W1R(")$970@;W!P<W1O
M9"!E;B!F96EL('9E9"!I;7!O<G1E<FEN9R!A=B!H96YD96QS96XZ("5S+B(*
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.CDQ"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N(@IM<V=S='(@
M(B(*(D1E="!O<'!S=&]D(&5N(&9E:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&)R
M=6ME<F5N<R!L961I9R]O<'!T871T+6EN9F]R;6%S:F]N.B`E(@HB<R(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-SD*(RP@9G5Z>GD*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M
M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E<75I<F5D(&9I96QD+B(*
M;7-G<W1R(")$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&]P<&1A=&5R:6YG
M(&%V(&AE;F1E;'-E;CH@)7,B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`Y
M-2!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$P,2!P;R]T<F%N<VQA=&EO;BYP:'`Z
M,3(R-@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3(S,@HC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@;W!E;FEN9R!T:&4@9FEL
M92`E<RX@5')Y(')U;FYI;F<@=')A;G-L871I;VXN<&AP('=I=&@@=&AE("(*
M(F9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M97-S86=E<R!F<F]M('1H92!X
M;6P@<&%R<V5R+B(*;7-G<W1R("(B"@HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-C8S"B,L(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E("(*(G1R>2!A9V%I;B!L871E<BXB"FUS9W-T
M<B`B1&5T(&]P<'-T;V0@96X@9F5I;"!U;F1E<B!O<'!D871E<FEN9R!A=B!H
M96YD96QS96XZ("5S(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8V-0HC+"!F=7IZ>0IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N(@IM<V=S='(@(D1E="!O<'!S=&]D(&5N(&9E:6P@=6YD97(@
M;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E<R(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV-S`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@(D1E="!O<'!S
M=&]D(&5N(&9E:6P@=6YD97(@;W!P9&%T97)I;F<@878@:&5N9&5L<V5N.B`E
M<R(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-3,*(RP@
M9G5Z>GD*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R
M="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D1E;FYE('1J96YE<F5N('-T
M^'1T97(@:6MK92!D96QI;F<@878@;6%P<&5R+B(*"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.CDV"B,Z(&QI8B](;W)D92]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C$Q,@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HR,#`*;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO
M="!S=7!P;W)T960N(@IM<V=S='(@(D1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N
M(&5R(&EK:V4@<W1O='1E="XB"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z,S4Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N;W0@>65T
M(&EM<&QE;65N=&5D+B(*;7-G<W1R(")$96X@9F]R97-P=7)T92!O<'!G879E
M;B!E<B!I:VME(&EM<&QE;65N=&5R="XB"@HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O<F%R+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`B
M)7,@<V5R(&EK:V4@=70@<V]M(&5N(&=Y;&1I9R!P;W-T8F]K<RXB"@HC.B!L
M:6(O2&]R9&4O34E-12]6:65W97(O>FEP+G!H<#HU-0HC+"!F=7IZ>0IM<V=I
M9"`B5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92XB"FUS9W-T<B`B)7,@<V5R(&EK:V4@=70@<V]M(&5N(&=Y;&1I9R!P;W-T
M8F]K<RXB"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,S$S,`HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N(@IM<V=S='(@(B5S('-E<B!I:VME('5T('-O;2!E;B!G>6QD:6<@
M<&]S=&)O:W,N(@H*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HQ.#<*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+R(*(G-M<S)E
M;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R
M("(B"@HC.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@R
M"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G
M871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S
M(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T
M<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z.3<S(&QI8B](;W)D92]&;W)M+G!H<#HQ,#4R(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,#@Q"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,3$P(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,3<T(&QI8B](;W)D92]&;W)M+G!H<#HQ,C0X"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HQ,C@R(&QI8B](;W)D92]&;W)M+G!H<#HQ
M,SDU(&QI8B](;W)D92]&;W)M+G!H<#HQ-30W"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HQ.#(W(&QI8B](;W)D92]&;W)M+G!H<#HQ.30R(&QI8B](;W)D92]&
M;W)M+G!H<#HQ.3@Y"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,#$S(&QI8B](
M;W)D92]&;W)M+G!H<#HR,#8R(&QI8B](;W)D92]&;W)M+G!H<#HR,3,S"B,Z
M(&QI8B](;W)D92]&;W)M+G!H<#HR,C`U(&QI8B](;W)D92]&;W)M+G!H<#HR
M,SDS(&QI8B](;W)D92]&;W)M+G!H<#HR-#,W"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HR-C0Y(&QI8B](;W)D92]&;W)M+G!H<#HR.#$W(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3(R"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS-CDR(&QI8B](
M;W)D92]&;W)M+G!H<#HS-S`P"B,L(&9U>GIY"FUS9VED(")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(*;7-G<W1R("(E<R!H87(@879S;.5T="XB"@HC.B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3`V,`IM<V=I9"`B5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C0P,0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BXB"FUS9W-T<B`B(@H*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$P.#D*;7-G:60@(E1H:7,@9FEE;&0@;6%Y
M(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]&;W)M+G!H<#HQ,3$X"FUS9VED(")4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@T"B,L(&9U
M>GIY"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N
M(@IM<V=S='(@(D1E='1E(&WE(';F<F4@970@=&%L;"XB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,C@R-0IM<V=I9"`B(@HB5&AI<R!F:65L9"!M=7-T(&-O
M;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R
M(&5X86UP;&4@(@HB)R,Q,C,T868G+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z-38Q"FUS9VED(")4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]H96QP
M+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@:7,@)7,N
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]+;VQA8BYP:'`Z-#,W"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(E1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@
M96UA:6P@(@HB8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R
M;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"`B"B)C
M;&EE;G1S('!L96%S92!V:7-I="`E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`Z-C`W"B,L('!H<"UF;W)M870*;7-G:60@
M(E1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@
M*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O4')E9G,O54DN<&AP.C$R.`IM<V=I9"`B5&AI<R!N=6UB97(@;75S
M="!B92!A="!L96%S="!O;F4N(@IM<V=S='(@(D1E='1E('1A;&QE="!MY2!V
MYG)E(&UI;G-T(#$N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C$R.#4*(RP@
M9G5Z>GD*;7-G:60@(E1H:7,@<V-R:7!T(&UU<W0@8F4@<G5N(&9R;VT@=&AE
M(&-O;6UA;F0@;&EN92XB"FUS9W-T<B`B1&5T=&4@=FEN9'5E="!MY2!B;&D@
MY7!N970@9G)A("=.>2!M96QD:6YG)R!V:6YD=65T(@H*(SH@;&EB+TAO<F1E
M+T-O;7!R97-S+V=Z:7`N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")4:&ES('-E
M<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS
M9W-T<B`B1&5N;F4@=&IE;F5R96X@<W3X='1E<B!I:VME(&1E;&EN9R!A=B!M
M87!P97(N(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y+G!H<#HQ-#<*;7-G:60@
M(E1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"XB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*;7-G:60@(E1H
M:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B1&5T=&4@;>4@
M=N9R92!E="!T86QL+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME
M<BYP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@
M8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B1&5T=&4@
M=FEN9'5E="!MY2!B;&D@Y7!N970@9G)A("=.>2!M96QD:6YG)R!V:6YD=65T
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W,0IM<V=I9"`B
M5&AU;F1E<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(U"FUS9VED(")4:6-K971S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]&;W)M+G!H<#HR-#$Q"B,L(&9U>GIY"FUS9VED(")4:6UE(@IM<V=S='(@
M(E1I='1E;"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,3$*;7-G
M:60@(E1I;64@5')A8VMI;F<B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I
M;64N<&AP.C$W"B,L(&9U>GIY"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R
M(")&;W)M870@<.4@;F%V;B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-3(R
M"B,L(&9U>GIY"FUS9VED(")4:6UE('-E;&5C=&EO;B(*;7-G<W1R(")&:6QT
M97)I;FYS=&EL;&EN9V5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S
M,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5&EM;W(M3&5S=&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S(@
M;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@(E1I=&QE(@IM<V=S='(@
M(E1I='1E;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP*3HB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z.#`*;7-G:60@
M(E1O(@IM<V=S='(@(E1I;"(*"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV,CD*(RP@9G5Z>GD*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*(D9O<B#E('9E;&=E(&9L97)E+"!H;VQD(&YE9&4@0V]N=')O;"`H4$,I
M(&5L;&5R($-O;6UA;F0@*$UA8RD@;65N<R!D=2!K;&EK:V5R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,0HC+"!F=7IZ>0IM<V=I9"`B
M5&]D87DB"FUS9W-T<B`B365L9&EN9W-T96MS="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O9V=L92!(
M5$U,(%-O=7)C92(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C(S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C,*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"B,L(&9U>GIY"FUS9VED(")4;V=O
M(@IM<V=S='(@(E1I;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C8@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-`HC.B!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1O:V5L874B"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(U,PHC+"!F=7IZ>0IM
M<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`B3GD@;65L9&EN9R(*"B,Z(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,CD@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(R-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z
M>GD*;7-G:60@(E1O;F=A(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-PHC+"!F=7IZ>0IM
M<V=I9"`B5&]P(@IM<V=S='(@(E1I;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G:60@(E1O<"!F<F%M92`H7W1O
M<"DB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F
M=7IZ>0IM<V=I9"`B5')A;G-L871E9"(*;7-G<W1R(")58F5S=F%R="(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PHC+"!F=7IZ>0IM<V=I9"`B5')A
M;G-L871I;VYS(@IM<V=S='(@(D]R9V%N:7-E<FEN9R(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,S(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E1R
M:6YI9&%D(&%N9"!4;V)A9V\B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$W-S@*;7-G:60@(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM
M<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(R."!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W"B,Z(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5N:7-I82(*;7-G<W1R
M("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,Q(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR,C@*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3$R"B,L(&9U>GIY"FUS9VED(")4=7)K97DB"FUS9W-T<B`B;OAK:V5L
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#@*;7-G:60@(E1U<FMI<V@@
M*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,C<@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R.0HC.B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*(RP@9G5Z>GD*;7-G:60@(E1U
M<FMM96YI<W1A;B(*;7-G<W1R(")/8G-E<G9E<B(*"B,Z(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR,C`@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S
M,`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G:60@(E1U<FMS
M(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C,S(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR
M,S$*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$R"FUS9VED(")4=79A
M;'4B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-,22YP:'`Z,C8R"FUS9VED
M(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(R-PIM<V=I9"`B52Y6+B!I;F1E>#H@(@IM
M<V=S='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C4R(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V
M,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z.3<*(RP@9G5Z>GD*;7-G:60@(E523#HB"FUS9W-T
M<B`B55),(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-R!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B56=A;F1A(@IM<V=S='(@(DMA
M;&5N9&5R(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S"B,Z(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,PHC+"!F=7IZ>0IM<V=I9"`B56MR86EN92(*;7-G<W1R(")'
M:F5N;W!P<F5T="(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,S8P"B,L(&9U>GIY
M"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(@IM<V=S
M='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O
M2&]R9&4O075T:"]3:6=N=7`N<&AP.C$P,`IM<V=I9"`B56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB"FUS
M9W-T<B`B(@H*(SH@;&EB+U9&4R]F='`N<&AP.C,T-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I
M;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C,S,"!L:6(O
M5D93+VUU<W%L+G!H<#HU,#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O
M)7,N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S`T"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R(")+86X@
M:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+T%U
M=&@O<W%L+G!H<#HS-S4*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V
M97)E;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S@X"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"XB"FUS9W-T<B`B2V%N(&EK
M:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,3<P(&QI8B]61E,O9FEL92YP:'`Z,3<U(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$Y-PHC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#(@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,C$P"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8V]P
M>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E
M<G9E<F5N+B(*"B,Z(&QI8B]61E,O9G1P+G!H<#HS,C`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R
M>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V
M97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(Y-2!L:6(O5D93+VUU<W%L
M+G!H<#HR-S,@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C<P"B,L(&9U>GIY"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@
M(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93
M+VUU<W%L+G!H<#HQ,C8*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A
M=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS
M97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C(Q,@HC+"!F=7IZ>0IM
M<V=I9"`B56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92XB"FUS9W-T
M<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B](
M;W)D92]#;VUP<F5S<R]T87(N<&AP.C<Y(&QI8B](;W)D92]#;VUP<F5S<R]G
M>FEP+G!H<#HX,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82XB"FUS9W-T<B`B2VQA<G1E(&EK:V4@Y2!H96YT92!I;F9O<FUA
M<VIO;B!O;2!K=F]T92(*"B,Z(&QI8B]61E,O9G1P+G!H<#HR-#D*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB"FUS9W-T<B`B2V%N(&EK
M:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O9FEL92YP
M:'`Z,C<P(&QI8B]61E,O<W%L+G!H<#HS,C,@;&EB+U9&4R]M=7-Q;"YP:'`Z
M,S,U"B,Z(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,V,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='DB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL
M(%-13'-E<G9E<F5N+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-SD@861M:6XO
M<&5R;7,O9&5L971E+G!H<#HU.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92`G)7,G.B`E<RXB"FUS9W-T<B`B2V%N(&EK
M:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C,W."!L:6(O5D93+W-Q;%]F:6QE+G!H<#HS.#(*(RP@9G5Z>GD*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N
M+B(*"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C<V(&QI8B]61E,O;75S<6PN<&AP
M.C,T."!L:6(O5D93+VUU<W%L+G!H<#HS-C$*(SH@;&EB+U9&4R]M=7-Q;"YP
M:'`Z,S8Y(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,W-`HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")+
M86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]S
M<6PN<&AP.C,T."!L:6(O5D93+W-Q;"YP:'`Z,S8P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+B(*;7-G<W1R(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN
M(@H*(SH@;&EB+U9&4R]F='`N<&AP.C$W.0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM
M<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L
M:6(O5D93+V9I;&4N<&AP.C(T,B!L:6(O5D93+W-Q;"YP:'`Z,C$S(&QI8B]6
M1E,O;75S<6PN<&AP.C$W,PHC.B!L:6(O5D93+VUU<W%L+G!H<#HQ.#8@;&EB
M+U9&4R]M=7-Q;"YP:'`Z,3DS(&QI8B]61E,O<W%L7V9I;&4N<&AP.C0Q,@HC
M.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HT,C`*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I:VME(&MO
M8FQE('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+W-Q;"YP:'`Z,S,W
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E
M(%9&4R!R96-U<G-I=F5L>3H@)7,N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE
M('1I;"!344QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9T<"YP:'`Z-S4R"B,L
M(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R(")+86X@:6MK92!R96=I<W1R97)E(&EN<W1I;&QI
M;F=E;F4@:2#X:W1E;BXB"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C8R-PHC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&5X=')A8W0@8V5R=&EF
M:6-A=&4@9&5T86EL<R(*;7-G<W1R(")3971T(&EN;B!S97)T:69I:V%T(&AE
M<B(*"B,Z(&QI8B].970O24U34"YP:'`Z-#8P(&QI8B].970O24U34"]!=71H
M+G!H<#HQ,3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*;7-G<W1R("(E<R!H87(@
M<W9A<G0@<.4@:6YV:71A<VIO;F5N('1I;"`E<RXB"@HC.B!L:6(O5D93+V9I
M;&4N<&AP.C$S.2!L:6(O5D93+V9I;&4N<&AP.C$T-"!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HQ-C4*(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<P"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS9W-T<B`B
M2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI8B]61E,O
M9G1P+G!H<#HW.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6MK92!K
M;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&4R]F:6QE+G!H<#HR
M,3D@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3(W(&QI8B]61E,O<W%L7V9I;&4N
M<&AP.C$S,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I
M;&4@9F]R('=R:71I;F<N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!3
M44QS97)V97)E;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C<S(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E
M;B!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E
M<G9E<F5N+B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C0W
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R
M8VAI=F4N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E
M;BXB"@HC.B!L:6(O5D93+V9I;&4N<&AP.C8R,@HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R
M(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HQ,#DU"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E
M861Y(&5X:7-T<R(*;7-G<W1R("(B"@HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HS,38*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E
M<F5N+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-34*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N(@IM<V=S='(@(DMA;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BXB
M"@HC.B!L:6(O5D93+V9T<"YP:'`Z,CDV"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E<G9E<F5N+B(*"B,Z(&QI
M8B]61E,O9FEL92YP:'`Z-38S(&QI8B]61E,O;75S<6PN<&AP.C(T,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92`E<R\E<RXB"FUS9W-T<B`B2V%N(&EK:V4@:V]B;&4@=&EL(%-13'-E
M<G9E<F5N+B(*"B,Z(&QI8B]61E,O<W%L+G!H<#HR-#D@;&EB+U9&4R]M=7-Q
M;"YP:'`Z,C(R(&QI8B]61E,O;75S<6PN<&AP.C0X-0HC.B!L:6(O5D93+W-Q
M;%]F:6QE+G!H<#HS,#4@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S(W"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R
M(")+86X@:6MK92!K;V)L92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+U9&
M4R])4T]7<FET97(O;6MI<V]F<RYP:'`Z-3$*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R(")+86X@:6MK92!K;V)L
M92!T:6P@4U%,<V5R=F5R96XN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+VUS=V]R9"YP:'`Z-C(*;7-G:60@(E5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT(@IM<V=S='(@(DMA;B!I:VME(&]V97)S971T92!D
M971T92!7;W)D+61O:W5M96YT970B"@HC.B!L:6(O5D93+V9T<"YP:'`Z,3(W
M(&QI8B]61E,O9G1P+G!H<#HQ,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(DML87)T92!I:VME(.4@:&5N=&4@:6YF;W)M87-J;VX@;VT@:W9O=&4B"@HC
M.B!L:6(O5D93+V9I;&4N<&AP.C$R,`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2XB"FUS9W-T<B`B
M2VQA<G1E(&EK:V4@Y2!H96YT92!I;F9O<FUA<VIO;B!O;2!K=F]T92(*"B,Z
M(&QI8B]61E,O9FEL92YP:'`Z,C(S(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$S
M-2!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ-#`*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!W<FET92!61E,@9FEL92!D871A+B(*;7-G<W1R(")+;&%R=&4@
M:6MK92#E(&AE;G1E(&EN9F]R;6%S:F]N(&]M(&MV;W1E(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,`HC+"!F=7IZ>0IM
M<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(D=J96YO<'!R971T(@H*(SH@=&5M
M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM
M<V=S='(@(D%N9W)E(&5N9')I;F=E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5N9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N(@IM<V=S='(@(D=J96YO<'!T82!S97-J;VXB
M"@HC.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,C,P(&QI8B](
M;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3D*;7-G:60@(E5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C8@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,U,`HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS.3,*;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@
M9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O4')E
M9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU.`HC.B!T96UP;&%T97,O<')E9G,O
M8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-`HC+"!F=7IZ>0IM<V=I9"`B56YF
M:6QE9"(*;7-G<W1R(")%+7!O<W0B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HS.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YH
M86YD;&5D(&-O;7!O;F5N="!O9B!T>7!E.B`E<R(*;7-G<W1R(")5:.5N9'1E
M<G0@:V]M<&]N96YT(&%V('1Y<&5N.B`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@Y"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B(@H*
M(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR,S0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*
M;7-G:60@(E5N:71E9"!!<F%B($5M:7)A=&5S(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,S@@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S-0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I
M9"`B56YI=&5D($MI;F=D;VTB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C(T,"!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,V
M"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B56YI=&5D
M(%-T871E<R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C,Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C8U(&QI8B]";&]C:R]M971A<BYP:'`Z-CD*
M;7-G:60@(E5N:71S(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q-2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,38*(RP@9G5Z
M>GD*;7-G:60@(E5N:VYO=VXB"FUS9W-T<B`B56MJ96YT(&1A=&\B"@HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B56YK
M;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*;7-G<W1R("(B"@HC
M.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B
M56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R
M("(B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30X,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B56YK;F]W;B!C;VUM86YD.B`E<R(*;7-G<W1R("),
M87-T(&YE9"!M87!P96XH92DB"@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,`HC+"!F=7IZ>0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"XB"FUS9W-T<B`B5F5N;FQI<W0@<VMR:78@:6YN(&)R
M=6ME<FYA=FX@;V<@<&%S<V]R9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-PHC+"!F=7IZ>0IM<V=I9"`B
M56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B"FUS9W-T<B`B4VQE='0@;N5V
MYG)E;F1E(&[X:VQE<B(*"B,Z(&QI8B](;W)D92])9&5N=&ET>2YP:'`Z,CDX
M"FUS9VED(")5;FYA;65D(@IM<V=S='(@(E5T96X@;F%V;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*
M(E5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO
M4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP
M="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX,@HC
M+"!F=7IZ>0IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B4V5T="!I;FX@
M<V5R=&EF:6MA="!H97(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.C<Q,"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.CDU,@HC.B!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.CDU.`HC+"!F=7IZ>0IM<V=I9"`B56YS=7!P
M;W)T960@17AT96YS:6]N(@IM<V=S='(@(E5S=7!P;W)T97)T(&EN;FAO;&1S
M+71Y<&4N(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C8U-PHC+"!F=7IZ>0IM
M<V=I9"`B56YT<F%N<VQA=&5D(@IM<V=S='(@(E5B97-V87)T(@H*(SH@861M
M:6XO<&5R;7,O961I="YP:'`Z,3`V(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,3DQ"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,V"B,L(&9U
M>GIY"FUS9VED(")5<&1A=&4B"FUS9W-T<B`B4VES=&4@;W!P9&%T97)I;F<Z
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(E-I
M<W1E(&]P<&1A=&5R:6YG.B(*"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8T.`IM<V=I9"`B57!D871E(')E<W!O;F1E;G0@<W1A
M='5S(@IM<V=S='(@(D]P<&1A=&5R('-T871U<R!PY2!A=G-E;F1E<F4B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,L(&9U>GIY
M"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")3:7-T92!O<'!D871E<FEN
M9SHB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$S-R!A9&UI;B]P97)M<R]E9&ET
M+G!H<#HR,3<@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S,`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E9"`G)7,G+B(*;7-G<W1R(")2
M961I9V5R("<E<R<B"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3`X,"!P;R]T
M<F%N<VQA=&EO;BYP:'`Z,3(Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A
M=&EN9R`E<R!H96QP(&9I;&4@9F]R("5S+B(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]S8W)I<'1S+G!H<#HX,0IM<V=I9"`B57!G<F%D92!S8W)I<'0@
M9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C$W,B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3@R"FUS
M9VED(")5<&QO860B"FUS9W-T<B`B3&%S="!O<'`B"@HC.B!A9&UI;B]S971U
M<"]I;F1E>"YP:'`Z,3@P"FUS9VED(")5<&QO861E9"!A;&P@87!P;&EC871I
M;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#$@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C(S.`HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,30*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@<&\O=')A;G-L871I
M;VXN<&AP.C,U('!O+W1R86YS;&%T:6]N+G!H<#HY,B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@(E5S86=E.B(*;7-G<W1R(")"<G5K
M97)N879N.B(*"B,Z(&QI8B](;W)D92]0<F5F<R]#871E9V]R>4UA;F%G97(N
M<&AP.C0V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5<V4@0W5R<F5N
M=#H@)7,B"FUS9W-T<B`B4VQE='0@;N5VYG)E;F1E(&[X:VQE<B(*"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3@*;7-G:60@(E5S92!3
M4TPB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R,PIM
M<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BXB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+U)E9VES=')Y
M+G!H<#HV-3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B57-E<B`E<R!I<R!N;W0@
M875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C(P-`HC+"!F=7IZ>0IM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R("(E<R!01U`@861M:6YI<W1R87-J;VXB"@HC.B!L:6(O2&]R9&4O
M4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B57-E<B!/<'1I;VYS(@IM<V=S='(@
M(DQA9W)E(%9A;&<B"@HC.B!S:6=N=7`N<&AP.C8T"B,L(&9U>GIY"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R("),86=R92!686QG(@H*(SH@
M<VEG;G5P+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I9"`B57-E<B!296=I<W1R871I
M;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92XB"FUS9W-T<B`B
M1FEL=&5R<W3X='1E(&5R(&%V<VSE='0@:2!D971T92!S>7-T96UE="XB"@HC
M.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S(@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HR-30*(RP@9G5Z>GD*;7-G:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS
M9W-T<B`B3&%G<F4@5F%L9R(*"B,Z(&%D;6EN+W5S97(N<&AP.C,U(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HQ-S,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U-B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.CDW"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`R
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,S"B,Z('1E;7!L871E<R]L
M;V=I;B]L;V=I;BYI;F,Z-C4@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V
M92YI;F,Z,3$*;7-G:60@(E5S97)N86UE(@IM<V=S='(@(D)R=6ME<FYA=FXB
M"@HC.B!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$S,0HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B57-E<FYA;64@)R5S)R!A;')E861Y(&5X:7-T
M<RXB"FUS9W-T<B`B36%P<&5N(%PB)7-<(B!F:6YN97,@86QL97)E9&4B"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R(")"<G5K97)N879N.B(*"B,Z('1E;7!L871E<R]L;V=I
M;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N86UE.B`B"FUS
M9W-T<B`B0G)U:V5R;F%V;CHB"@HC.B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP
M.C(R-PHC+"!F=7IZ>0IM<V=I9"`B57-E<G,B"FUS9W-T<B`B0G)U:V5R;F%V
M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*;7-G:60@
M(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C(S.0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*(RP@9G5Z>GD*
M;7-G:60@(E5Z8F5K:7-T86XB"FUS9W-T<B`B1&%T;R(*"B,Z(&QI8B]61E,O
M9FEL92YP:'`Z,3`Y(&QI8B]61E,O9FEL92YP:'`Z,C`R"B,L(&9U>GIY"FUS
M9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")$
M96X@<W!E<VEF:7-E<G1E(&9I;&5N(&5K<VES=&5R97(@:6MK92XB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S@S"B,L(&9U>GIY"FUS9VED(")6
M86-A=&EO;B(*;7-G<W1R("),;VMA<VIO;B(*"B,Z(&QI8B](;W)D92]&;W)M
M+G!H<#HX-C$*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV
M-C(*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HV,C$@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR-C,*;7-G:60@(E9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(X(&QI
M8B](;W)D92]&;W)M+G!H<#HR,C4P(&QI8B](;W)D92]&;W)M+G!H<#HR,CDX
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR.3$W"B,L(&9U>GIY"FUS9VED(")6
M86QU97,B"FUS9W-T<B`B26YG96X@;65L9&EN9V5R(@H*(SH@;&EB+TAO<F1E
M+T9O<FTN<&AP.C(P.3,@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-S`*;7-G:60@
M(E9A;'5E<R!T;R!S96QE8W0@9G)O;2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C0Y(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR-#`*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")6
M86YU871U(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,#<*(RP@9G5Z>GD*;7-G:60@(E9A<FEA8FQE(@IM<V=S='(@(E1I
M='1E;"(*"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-#4@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,38*;7-G:60@(E9E;F5Z=65L82(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(R.`IM<V=I9"`B5F5R:69I8V%T:6]N
M(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D
M('=I=&@N(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP
M:'`Z-S(T"B,L(&9U>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(E!E<G-O
M;FQI9R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#`*(RP@9G5Z
M>GD*;7-G:60@(E9E<G-I;VX@0V]N=')O;"(*;7-G<W1R(")097)S;VYL:6<B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R
M(")&971C:&UA:6PZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#0*(RP@9G5Z>GD*;7-G:60@(E9E<G1I8V%L('!A9&1I
M;F<B"FUS9W-T<B`B1F5T8VAM86EL.B`B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C@S"B,L(&9U>GIY"FUS9VED(")697)T
M:6-A;#HB"FUS9W-T<B`B1F5T8VAM86EL.B`B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S<W"B,L(&9U>GIY"FUS9VED(")697)Y($AI9V@B
M"FUS9W-T<B`B2/AY(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T."!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q-PHC+"!F=7IZ>0IM<V=I9"`B5FEE="!.86TB"FUS
M9W-T<B`B3F%V;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED
M(")6:65T;F%M97-E("A625-#24DI(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HY.30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5FEE=R`E<R(*;7-G<W1R(")6:7,@)7,B"@HC.B!L:6(O0FQO8VLO:69R86UE
M+G!H<#HS"FUS9VED(")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HX-#4*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@)7,B"FUS9W-T<B`B
M5FES("5S(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-SD*;7-G:60@(E9I97<@979E;G0B"FUS9W-T<B`B5FES(&AE;F1E;'-E
M(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`Y
M"FUS9VED(")6:65W('1A<VLB"FUS9W-T<B`B5FES(&AA;F1L:6YG97(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0V(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#,*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0W(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W
M"FUS9VED(")6:7)G:6X@27-L86YD<RP@52Y3+B(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(P-PIM<V=I9"`B5FES:6)I;&ET>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(Q"FUS
M9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T<B`B(@H*(SH@;&EB+TYE="]335,O
M=F]D869O;F5I=&%L>5]S;71P+G!H<#HX,0IM<V=I9"`B5F]D869O;F4@271A
M;'D@=FEA(%--5%`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TYO=&EF:6-A
M=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,Y"FUS9VED(")705).(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@S"B,L('!H<"UF
M;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,
M62!&4D]-("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,C4P(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")786QL:7,@86YD($9U
M='5N82(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI
M<W1E;F5R+W-T871U<RYP:'`Z,S$*;7-G:60@(E=A<FYI;F<B"FUS9W-T<B`B
M061V87)S96PB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,30U('!O+W1R86YS
M;&%T:6]N+G!H<#HV.#$@<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC.B!P;R]T
M<F%N<VQA=&EO;BYP:'`Z-S(U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#0X('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,#4W"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M,#8U('!O+W1R86YS;&%T:6]N+G!H<#HQ,#<U('!O+W1R86YS;&%T:6]N+G!H
M<#HQ,#@U"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ,#DU('!O+W1R86YS;&%T
M:6]N+G!H<#HQ,3`Q('!O+W1R86YS;&%T:6]N+G!H<#HQ,C$V"B,Z('!O+W1R
M86YS;&%T:6]N+G!H<#HQ,C(V('!O+W1R86YS;&%T:6]N+G!H<#HQ,C,R('!O
M+W1R86YS;&%T:6]N+G!H<#HQ,C4R"B,L(&9U>GIY"FUS9VED(")787)N:6YG
M.B`B"FUS9W-T<B`B061V87)S96PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")792(*;7-G<W1R("(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4*;7-G:60@(E=E871H
M97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,P-0IM<V=I9"`B5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HX.#<*;7-G:60@
M(E=E871H97(N8V]M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C,V"FUS9VED(")796(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,Y,`HC+"!F=7IZ>0IM<V=I9"`B5V5B(%-I=&4B"FUS
M9W-T<B`B5V5B<VED92!A9')E<W-E(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HS-PIM<V=I9"`B5V5E:VQY(@IM<V=S='(@(E5K96YT;&EG(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,C@*(RP@9G5Z>GD*;7-G
M:60@(E=E;&-O;64B"FUS9W-T<B`B5F5L:V]M;65N(@H*(SH@=&5M<&QA=&5S
M+VQO9VEN+VUO8FEL92YI;F,Z-"!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC
M.C4P"B,L('!H<"UF;W)M870*;7-G:60@(E=E;&-O;64@=&\@)7,B"FUS9W-T
M<B`B5F5L:V]M;65N('1I;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I
M;&4N<&AP.C(Y('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")796QC;VUE+"`E<R(*;7-G<W1R(")696QK;VUM96XL
M("5S(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3$*;7-G:60@(E=E<W1E
M<FX@*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DR"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HR-#8*(SH@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S(*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT,C<*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_(@IM<V=S='(@(E9I<VYI;F<@96QL97(@<&]S=&)O:W,@<V]M
M('-K86P@=FES97,@971T97(@:6YN;&]G9VEN9SHB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B5VAA="!I<R!T:&4@9&5L:6UI
M=&5R(&-H87)A8W1E<C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,C0*;7-G:60@(E=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S"FUS
M9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$S,0IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@
M9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@T"B,L
M(&9U>GIY"FUS9VED(")7:61T:"(*;7-G<W1R(")3^&LB"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,S$Q,`IM<V=I9"`B5VED=&@@:6X@0U-3('5N:71S(@IM
M<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE
M9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3`*(RP@9G5Z
M>GD*;7-G:60@(E=I9'1H('5N:70B"FUS9W-T<B`B4_AK(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*(RP@9G5Z>GD*
M;7-G:60@(E=I9'1H.B(*;7-G<W1R(")3^&LB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#DP"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-S(*(RP@9G5Z>GD*;7-G:60@
M(E=I;F0B"FUS9W-T<B`B4_AK(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C,W,PHC+"!F=7IZ>0IM<V=I9"`B5VEN9"!%87)L>2(*;7-G<W1R
M(")!=G-LY71T.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<X"FUS9VED
M(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34T"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R
M(")3^&LB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"B,L
M(&9U>GIY"FUS9VED(")7:6YD.B`B"FUS9W-T<B`B079S;.5T=#H@(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8T"B,L(&9U>GIY"FUS9VED(")7:7-D
M;VTB"FUS9W-T<B`B4_AK(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C$W-PHC+"!F=7IZ>0IM<V=I9"`B5VES:&QI<W1S(@IM<V=S='(@(D)E=')O
M9&1E(&%D<F5S<V5R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"B,L
M(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S='(@(F5L;&5R(@H*(SH@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C<@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ-C<*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G
M<W1R(")&:7)M86%D<F5S<V4B"@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$Y-0IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")&:7)M
M871E;&5F;VXB"@HC.B!P;R]T<F%N<VQA=&EO;BYP:'`Z,3$U-PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")7<FET:6YG('5P9&%T960@:&5L<"!F:6QE('1O("5S
M+B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C,T
M"FUS9VED(")8+5)E9B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C8Q-PIM<V=I9"`B6#4P.78S($)A<VEC($-O;G-T<F%I;G1S
M(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$V
M"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(B(*
M"B,Z(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$X"FUS9VED(")8-3`Y
M=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE(@IM<V=S='(@(B(*"B,Z(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C$Y"FUS9VED(")8-3`Y=C,@4W5B
M:F5C="!+97D@261E;G1I9FEE<B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C<P-@IM<V=I9"`B6#4P.78S(&5X=&5N<VEO;G,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@(EE9
M(@IM<V=S='(@(N7E(@H*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X-B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#(W"B,L(&9U>GIY"FUS9VED(")965E9(@IM<V=S='(@(N7E(@H*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,#(*;7-G:60@(EEA
M:&]O(2!M87`B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TUA:6YT96YA;F-E
M+G!H<#HS-0IM<V=I9"`B665A<FQY(@IM<V=S='(@(N5R;&EG(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U,B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0W"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.`HC+"!F
M=7IZ>0IM<V=I9"`B665M96XB"FUS9W-T<B`B3&5S="(*"B,Z(&QI8B](;W)D
M92]522]687)296YD97)E<B]H=&UL+G!H<#HX.#@*;7-G:60@(EEE<R(*;7-G
M<W1R(")*82(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E96UE;G1?
M8F]T=&]M+FEN8SHV"FUS9VED(")997,L($D@06=R964B"FUS9W-T<B`B(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM
M<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*"B,Z
M(&QI8B](;W)D92YP:'`Z,3,R-@IM<V=I9"`B66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"XB"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E+TED96YT:71Y+G!H
M<#HS,#0*;7-G:60@(EEO=2!C86X@;F]T(&AA=F4@=&AE("=<7"<@8VAA<F%C
M=&5R(&EN('EO=7(@9G5L;"!N86UE+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3@S.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DU.0HC+"!F
M=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+B(*;7-G<W1R(")696YN;&EG<W0@<F5T="!T=F5T>61I9V4@96QL
M97(@=6=Y;&1I9V4@861R97-S97(N(@H*(SH@;&EB+TAO<F1E+T1A=&$N<&AP
M.C(W-`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)9;W4@9&ED;B=T(&UA<"!A
M;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E
M<W!O;F1I;F<@9FEE;&1S("(*(FEN("5S+B(*;7-G<W1R("(B"@HC.B!L:6(O
M2&]R9&4O075T:"YP:'`Z.30T"B,L(&9U>GIY"FUS9VED(")9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D1I;F4@=F%L9R!H87(@8FQI='0@
M;W!P9&%T97)T(@H*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$R-3,*;7-G:60@
M(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E
M<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H
M92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"@HC
M.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$X,`HC+"!F=7IZ>0IM<V=I9"`B66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B5F5N;FQI
M9W-T('-K<FEV(&EN;B!D970@;GEE(&YA=FYE=#HB"@HC.B!L:6(O2&]R9&4O
M075T:"]3:6=N=7`N<&AP.C,X"B,L(&9U>GIY"FUS9VED(")9;W4@;75S="!C
M;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+B(*
M;7-G<W1R(")+=6YN92!I:VME(&QA9V4@5D93+6)A8VME;F0Z("5S(@H*(SH@
M;&EB+TAO<F1E+G!H<#HT-#<*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R(")+=6YN92!I:VME(&QA
M9V4@5D93+6)A8VME;F0Z("5S(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*
M;7-G<W1R(")$=2!MY2!B97-K<FEV92!P<F]B;&5M970@9OAR(&1U(&MA;B!S
M96YD92!E;B!P<F]B;&5M<F%P<&]R="XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDX"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B1'4@;>4@:&$@;6EN<W0@Z6X@;6]T=&%K97(N(@H*(SH@<V5R
M=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO
M=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T
M<B`B1'4@;>4@=F5L9V4@96X@:61E;G1I=&5T('-O;2!S:V%L('-L971T97,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED(")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(*;7-G<W1R
M(")$=2!MY2!S<&5S:69I<V5R92!E;B!M;W1T86ME<BXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(D1U(&WE('-P97-I9FES
M97)E(&5N(&UO='1A:V5R+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`HC+"!F=7IZ>0IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R
M(")$=2!MY2!F^')S="!S<&5S:69I<V5R92!F:6QE;B!S;VT@<VMA;"!L96=G
M97,@=F5D+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@HC+"!F=7IZ>0IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R(")$=2!MY2!F^')S="!S<&5S:69I<V5R92!F:6QE;B!S;VT@<VMA
M;"!L96=G97,@=F5D+B(*"B,Z(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP
M.C$T-`HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E
M;B!M;W1T86ME<BXB"@HC.B!L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<#HW,PHC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")$=2!MY2!S<&5S:69I<V5R92!E
M;B!M;W1T86ME<BXB"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.3,R"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R(")$:6X@)7,@=&EL:V]B:6YG
M(&AA<B!GY71T('5T+B!696YN;&EG<W0@;&]G(&EN;B!I9VIE;BXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`HC+"!F=7IZ>0IM<V=I
M9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(D5P;W-T861R97-S96X@
M9&EN.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#(*(RP@9G5Z>GD*
M;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`B17!O<W1A9')E
M<W-E;B!D:6XZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C8T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HW-"!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#(*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@Y"FUS9VED(")9;W5R($EN9F]R
M;6%T:6]N(@IM<V=S='(@(D1I;B!I;F9O<FUA<VIO;B(*"B,Z(&QI8B](;W)D
M92]!=71H+G!H<#HY,S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!)
M;G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C
M=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS,PIM<V=I9"`B66]U<B!.
M86UE(@IM<V=S='(@(D9U;&QT(&YA=FXB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]N;V%D9"YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+VYO;&ES="YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE
M(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+B(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O075T:"YP:'`Z.30P
M"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S
M(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`B3F5T=&QE<V5R
M96X@9&EN('-T^'1T97(@:6MK92!V:7-N:6YG(&%V(&1E;FYE('1Y<&4@8FEL
M9&5R(&EN;&EN92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]P<FEN="YJ
M<SHR-PIM<V=I9"`B(@HB66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T
M;R`B"B)P<FEN="XB"FUS9W-T<B`B(@HB3F5T=&QE<V5R96X@9&EN('-T^'1T
M97(@:6MK92!D96YN92!U='-K:69T<V]P97)A<VIO;F5N+B!4<GEK:R!+;VYT
M<F]L;"\B"B)/<'-J;VX@*R!0(&9O<B#E('-K<FEV92!U="XB"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C0W"FUS9VED(")9;W5R(&-U<G)E;G0@=&EM
M92!Z;VYE.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,30X"B,L(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='DZ(@IM
M<V=S='(@(E-T86YD87)D:61E;G1I=&5T(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$Y,0HC+"!F=7IZ>0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM
M<V=S='(@(DYA=FYE="!D:71T.B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HQ
M-#4*;7-G:60@(B(*(EEO=7(@9V5T=&5X="!V97)S:6]N(&ES('1O;R!O;&0@
M86YD(&1O97,@;F]T('-U<'!O<G0@4$A0(&YA=&EV96QY+EQN(@HB3F]T(&%L
M;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@
M(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"B,L(&9U>GIY"FUS
M9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D
M=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S='(@(D1I;F4@=F%L9R!H
M87(@8FQI='0@;W!P9&%T97)T(@H*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H
M<#HQ-3@*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"XB
M"FUS9W-T<B`B1&EN92!V86QG(&AA<B!B;&ET="!O<'!D871E<G0B"@HC.B!S
M97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW-0IM<V=I9"`B66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H
M87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I
M=&@@>6]U<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`HC+"!F=7IZ>0IM<V=I9"`B66]U
M<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`B5&IE;F5R(@H*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3D*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B(@H*(SH@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z,3$Y"B,L(&9U>GIY"FUS9VED("):86ER92(*;7-G
M<W1R(")&<F$B"@HC.B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4V(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#@*(SH@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$Y"FUS9VED("):86UB:6$B"FUS9W-T<B`B(@H*(SH@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C(U-R!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B6FEM8F%B=V4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C8V"FUS9VED(")::7!P>2(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O
M5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3(*;7-G:60@(EM(:61E
M(%%U;W1E9"!497AT72(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F]B;&5M
M+G!H<#HU-@IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");4')O
M8FQE;7)A<'!O<G1=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5"
M;&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T
M<B`B(@H*(SH@;&EB+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E
M<RYP:'`Z,3<R"B,L('!H<"UF;W)M870*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=(@IM<V=S='(@(B(*"B,Z(&QI8B](;W)D92YP:'`Z
M,3DY"B,L('!H<"UF;W)M870*;7-G:60@(EML:6YE("5S(&]F("5S72(*;7-G
M<W1R(");;&EN:F4@)7,@878@)7-=(@H*(SH@;&EB+TAO<F1E+G!H<#HQ-#<R
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@
M(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<R!01U`@861M:6YI<W1R87-J
M;VXB"@HC.B!L:6(O87!I+G!H<#HQ,S0*;7-G:60@(E]#3$DB"FUS9W-T<B`B
M(@H*(SH@;&EB+V%P:2YP:'`Z,3(R"B,L(&9U>GIY"FUS9VED(")?1&%T851R
M964B"FUS9W-T<B`B1&%T;R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0HC+"!F=7IZ>0IM<V=I9"`B7T1E
M;&5T92!2;W<B"FUS9W-T<B`B7U-L971T(@H*(SH@;&EB+V%P:2YP:'`Z,3$T
M"B,L(&9U>GIY"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(D=R=7!P92(*"B,Z
M(&QI8B](;W)D92]-96YU+G!H<#HQ.#$*;7-G:60@(E](96QP(@IM<V=S='(@
M(DAJ96QP(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(S"B,L(&9U>GIY"FUS9VED(")?26UA9V4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B"@HC.B!L:6(O2&]R
M9&4O365N=2YP:'`Z,C`P"B,L(&9U>GIY"FUS9VED(")?3&]G(&EN(@IM<V=S
M='(@(DQO9V<@:6YN(@H*(SH@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y-@IM<V=I
M9"`B7TQO9R!O=70B"FUS9W-T<B`B3&]G9R!U="(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-`HC+"!F=7IZ
M>0IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(D9J97)N('!A<B(*
M"B,Z(&QI8B](;W)D92]-96YU+G!H<#HQ-S`*;7-G:60@(E]/<'1I;VYS(@IM
M<V=S='(@(E9A;&<B"@HC.B!L:6(O87!I+G!H<#HQ,3@*(RP@9G5Z>GD*;7-G
M:60@(E]097)M:7-S:6]N<R(*;7-G<W1R(")097)S;VYL:6<B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C8*
M(RP@9G5Z>GD*;7-G:60@(E]296UO=F4@3&EN:RXN+B(*;7-G<W1R(")&:F5R
M;B!P87(B"@HC.B!L:6(O87!I+G!H<#HQ,#8*(RP@9G5Z>GD*;7-G:60@(E]3
M971U<"(*;7-G<W1R(")696QG(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")?
M5&%B;&4@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")&;W)HY6YD<W9I<VYI;F<B
M"@HC.B!L:6(O87!I+G!H<#HQ,3`*(RP@9G5Z>GD*;7-G:60@(E]5<V5R<R(*
M;7-G<W1R(")"<G5K97)N879N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HY
M,3$*(RP@9G5Z>GD*;7-G:60@(F%D9')E<W,@8F]O:R(*;7-G<W1R(")!9')E
M<W-E8F]K(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<Q,0HC+"!F=7IZ>0IM
M<V=I9"`B86X@97)R;W(@:&%S(&]C8W5R960Z(@IM<V=S='(@(CQB/D5N(&9A
M=&%L(&9E:6P@:&%R(&]P<'-TY71T.CPO8CXB"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDP,PHC+"!F=7IZ>0IM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W,"!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M8V%L;2(*;7-G<W1R(")!=F)R>70B"@HC.B!L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'`Z-C`X"FUS9VED(")C;&EC:R!H97)E(@IM<V=S='(@(B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HT-#4@<&\O=')A;G-L871I;VXN<&AP.C4U
M,"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$Q"B,Z('!O+W1R86YS;&%T:6]N+G!H
M<#HW-#D@<&\O=')A;G-L871I;VXN<&AP.C@Q,"!P;R]T<F%N<VQA=&EO;BYP
M:'`Z.#@W"B,L(&9U>GIY"FUS9VED(")D;VYE(@IM<V=S='(@(D9E<F1I9R(*
M"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HU-3(@<&\O=')A;G-L871I;VXN<&AP
M.C4X-"!P;R]T<F%N<VQA=&EO;BYP:'`Z-C$S"B,Z('!O+W1R86YS;&%T:6]N
M+G!H<#HW-S@@<&\O=')A;G-L871I;VXN<&AP.C@Q,B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z.#@Y"B,L(&9U>GIY"FUS9VED(")F86EL960B"FUS9W-T<B`B12UP
M;W-T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,W.`IM<V=I
M9"`B9F%L;&EN9R(*;7-G<W1R("(B"@HC.B!L:6(O2&]R9&4O0G)O=W-E<BYP
M:'`Z.#<P"B,L(&9U>GIY"FUS9VED(")F:6QE(@IM<V=S='(@(D9I;"(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,CD*(RP@9G5Z>GD*;7-G:60@(F9O=6YD
M.B`B"FUS9W-T<B`B079S;.5T=#H@(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HQ-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(F9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,B"FUS9W-T<B`B)7,@<.4@)7,@)7,B"@HC.B!L
M:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H
M.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`X
M"FUS9VED(")I,3AN(@IM<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E
M;6%I;%]H='1P+G!H<#HU.#<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,CD*;7-G:60@(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H<#HW-@HC
M+"!F=7IZ>0IM<V=I9"`B:6YL:6YE(@IM<V=S='(@(DEN;&EN92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$S"B,L(&9U>GIY
M"FUS9VED(")L:6YE<UTB"FUS9W-T<B`B26YL:6YE(@H*(SH@;&EB+U9&4R])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-30*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S
M='(@(B(*"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,C@X('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HR,#8*;7-G:60@(FYA;64B"FUS9W-T<B`B
M;F%V;B(*"B,Z('!O+W1R86YS;&%T:6]N+G!H<#HS-S@*(RP@9G5Z>GD*;7-G
M:60@(FYO="!C:&%N9V5D(@IM<V=S='(@(D%N9W)E(&5N9')I;F=E<B(*"B,Z
M('!O+W1R86YS;&%T:6]N+G!H<#HQ,S$*(RP@9G5Z>GD*;7-G:60@(FYO="!F
M;W5N9"(*;7-G<W1R(")/8FIE:W1E="!B;&4@:6MK92!F=6YN970B"@HC.B!L
M:6(O2&]R9&4O4E!#+G!H<#HQ,C(*(RP@9G5Z>GD*;7-G:60@(FYO="!I;7!L
M96UE;G1E9"(*;7-G<W1R(")&97)D:6<B"@HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C$R-#4*(RP@9G5Z>GD*;7-G:60@(FYO="!Y970@:6UP;&5M
M96YT960B"FUS9W-T<B`B1&5N(&9O<F5S<'5R=&4@;W!P9V%V96X@97(@:6MK
M92!I;7!L96UE;G1E<G0N(@H*(SH@;&EB+TAO<F1E+TMO;&%B+G!H<#HX.34*
M(RP@9G5Z>GD*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B3F]T871B;&]K:R!F
M;W(@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@X"B,L(&9U>GIY"FUS9VED(")P97)C96YT(@IM<V=S='(@
M(E-K<FEV('5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS.#`*(RP@9G5Z>GD*;7-G
M:60@(G)I<VEN9R(*;7-G<W1R(")/<F=A;FES97)I;F<B"@HC.B!A9&UI;B]S
M971U<"]C;VYF:6<N<&AP.CDX"FUS9VED(")S:&]W(&1I9F9E<F5N8V5S(@IM
M<V=S='(@(B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S,*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S<Y"B,L(&9U>GIY"FUS9VED
M(")S=&5A9'DB"FUS9W-T<B`B3W!P9&%T97(B"@HC.B!L:6(O2&]R9&4O2V]L
M86(N<&AP.CDQ.0HC+"!F=7IZ>0IM<V=I9"`B=&%S:R!L:7-T(@IM<V=S='(@
M(E-V87)T96QI<W1E(@H*(SH@<&\O=')A;G-L871I;VXN<&AP.C<R-0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B=&AE($AO<F1E(%!/(&9I;&4@9F]R
M('1H92!L;V-A;&4@)7,@9&]E<R!N;W0@97AI<W0Z(@IM<V=S='(@(D1E;B!S
M<&5S:69I<V5R=&4@9FEL96X@96MS:7-T97)E<B!I:VME+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C,V(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z,C@R"B,L
M(&9U>GIY"FUS9VED(")T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M(@IM<V=S='(@(E9I<R!M86EL;&ES=&4@:6YF;W)M87-J;VXB"@HC.B!A
M9&UI;B]S971U<"]D:69F+G!H<#HV."!A9&UI;B]S971U<"]D:69F+G!H<#HW
M-@HC+"!F=7IZ>0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")%+7!O<W0B"@HC
M.B!L:6(O2&]R9&4O34E-12]087)T+G!H<#HQ-PHC+"!F=7IZ>0IM<V=I9"`B
M=6YN86UE9"(*;7-G<W1R(")5=&5N(&YA=FXB"@HC.B!P;R]T<F%N<VQA=&EO
M;BYP:'`Z,S<U"B,L(&9U>GIY"FUS9VED(")U<&1A=&5D(@IM<V=S='(@(E-I
M<W1E(&]P<&1A=&5R:6YG.B(*"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#<@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,CD*(RP@9G5Z>GD*;7-G:60@(G5S97(@<V5L96-T(@IM<V=S='(@(FEN9V5N
M(&UA<'!E('9A;&=T(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS.`IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,L(&9U>GIY"FUS
M9VED(")W.B(*;7-G<W1R(")&=V0Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,*;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(B(*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O<W9?4T4N<&\`````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`Q
M,3,Q,#<U(#$P-3$U-#,T,30R(#`Q-S4S-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````C($AO<F1E(%-W961I<V@@=')A;G-L
M871I;VX*(R!#;W!Y<FEG:'0@*$,I(#(P,#(M,C`P-B!(;W)D92!0<F]J96-T
M"B,@5&AI<R!F:6QE(&ES(&1I<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI
M8V5N<V4@87,@=&AE($AO<F1E('!A8VMA9V4N"B,@2F]A<75I;2!(;VUR:6=H
M875S96X@/&IO:&]`=V5B8G!L871S96XN<V4^+"`R,#`V+@HC($%N9')E87,@
M1&%H;.EN(#QA;F1R96%S0&1A:&QE;BYW<SXL(#(P,#4N"B,*;7-G:60@(B(*
M;7-G<W1R("(B"B)0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,5QN(@HB
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*
M(E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`R+3$U(#$Q.C(Q*S`Q,#!<;B(*
M(E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,38@,#`Z,C8K,#$P,%QN(@HB
M3&%S="U4<F%N<VQA=&]R.B!*;V%Q=6EM($AO;7)I9VAA=7-E;B`\:F]H;T!W
M96)B<&QA='-E;BYS93Y<;B(*(DQA;F=U86=E+51E86TZ(%-W961I<V@@/&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G/EQN(@HB34E-12U697)S:6]N.B`Q+C!<;B(*
M(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ
M7&XB"B)#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET7&XB"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$Q"B,L('!H
M<"UF;W)M870*;7-G:60@(B(*(B`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B(*;7-G<W1R("(B"B(@)B,Q-3$[("5S(&MO;6UE<B!A='0@=71F]G)A(&1E
M('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A=',@;F5D86XN
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,V.2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,C,W,PHC+"!P:'`M9F]R;6%T"FUS9VED("(@*"5S(&1A>7,@
M86=O*2(*;7-G<W1R("(@*"5S(&1A9V%R('-E9&%N*2(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3,R-B!L:6(O2&]R9&4N<&AP.C$S-S0*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H
M<VYA8F)T86YG96YT("5S*2(*"B,Z('1E;7!L871E<R]L:6YK<R]L:6YK<RYI
M;F,Z-`IM<V=I9"`B("A296%D(&]N;'DI(@IM<V=S='(@(B`H4VMR:79S:WED
M9&%D*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(S.#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B("AI;B`E
M<R!D87ES*2(*;7-G<W1R("(@*&]M("5S(&1A9V%R*2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(S-S,@;&EB+TAO<F1E+T9O<FTN<&AP.C(S-S<*
M;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H:61A9RDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,S<U(&QI8B](;W)D92]&;W)M+G!H<#HR,S<Y
M"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R("(@*&EM;W)G;VXI(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C,W-0IM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H:6?E<BDB
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C0U(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS-3`*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C,Y-@IM<V=I9"`B(&%T("(*;7-G<W1R("(@:VP@(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR,34@;&EB+U9&4R]S;6(N<&AP
M.C(Q.0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER
M96-T;W)Y+B(*;7-G<W1R("(G)7,G(.1R(&EN=&4@96X@:V%T86QO9RXB"@HC
M.B!F<F%M97=O<FLO0TQ)+T-,22YP:'`Z,C<R(&QI8B](;W)D92]#3$DN<&AP
M.C(W,@HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@=F%L
M:60@8VAO:6-E+B(*;7-G<W1R("(G)7,G(.1R(&EN=&4@971T(&=O9&OD;G0@
M=F%L+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M-C4V"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,3`S
M.2!L:6(O2&]R9&4O4F5G:7-T<GDN<&AP.C<Q,`HC.B!L:6(O2&]R9&4O4F5G
M:7-T<GDN<&AP.C$P.3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB(&ES
M(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS9W-T
M<B`B)R5S)R#D<B!I;G1E(&MO;F9I9W5R97)A="!I($AO<F1E<F5G:7-T<F5R
M="XB"@HC.B!F<F%M97=O<FLO5')E92]4<F5E+G!H<#HQ-S$@;&EB+TAO<F1E
M+U1R964N<&AP.C$W,0HC+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=')E
M92!R96YD97)E<B!N;W0@9F]U;F0N(@IM<V=S='(@(E1RY&1H86YT97)A<F5N
M(&;V<B`E<R!S86MN87,N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!G<F]U
M<',@<WES=&5M+B(*;7-G<W1R("(G)7,G(&QA9&5S('1I;&P@:2!G<G5P<'-Y
M<W1E;65T+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HU,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN(@IM<V=S='(@(B<E<R<@;&%D97,@=&EL;"!I(&)E
M:/9R:6=H971S<WES=&5M970N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-"!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM<V=S='(@(B<E<R<@
M<VMA<&%D97,@:6YT93H@)7,N(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(B4N,F9-0B!U<V5D(&]F("4N,F9-
M0B!A;&QO=V5D("@E+C)F)24I(@IM<V=S='(@(B4N,F9-0B!A;G;D;G0@878@
M)2XR9DU"('1I;&SE=&5T("@E,F8E)2DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C(V"B,L('!H<"UF;W)M870*;7-G:60@(B5D("5S(&%N
M9"`E<R(*;7-G<W1R("(E9"`E<R!O8V@@)7,B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C(V."!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HR
M-C@*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4U-PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RXB
M"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!U<'!H]G(@871T(&?D;&QA(&]M("5D
M(&1A9V%R+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-S0*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)60M9&%Y(&9O<F5C87-T(@IM<V=S='(@
M(B5D+61A9W-P<F]G;F]S(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C8X('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S("T@3F]T:6-E(@IM<V=S='(@(B5S("T@
M1O9R(&OD;FYE9&]M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,#0@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HW,#4*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@1FEN9V5R<')I;G0B"FUS9W-T<B`B1FEN9V5R
M<')I;G0@9O9R("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,R(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S
M-`HC.B!L:6(O2&]R9&4O34E-12]#;VYT96YT<RYP:'`Z.#0Q(&QI8B](;W)D
M92]-24U%+T-O;G1E;G1S+G!H<#HX-#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@2T(B"FUS9W-T<B`B)7,@2T(B"@HC.B!S97)V:6-E<R]M86EN=&5N86YC
M92YP:'`Z-#D@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN
M8SHT"B,L('!H<"UF;W)M870*;7-G:60@(B5S($UA:6YT96YA;F-E($]P97)A
M=&EO;G,@+2!#;VYF:7)M871I;VXB"FUS9W-T<B`B)7,@56YD97)HY6QL<V9U
M;FMT:6]N("T@0F5K<N1F=&5L<V4B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,34*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B)7,@4V5T=7`B"FUS9W-T<B`B)7,@4V5T=7`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S(&QI8B](;W)D92]!=71H
M+U-I9VYU<"YP:'`Z,C8T"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B)7,@86YMY&QA;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HU.2!T96UP;&%T97,O;6%I;G1E;F%N8V4O86=R965M96YT7W1O
M<"YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!497)M<R!O9B!!9W)E
M96UE;G0B"FUS9W-T<B`B5&KD;G-T96%V=&%L(&;V<B`E<R(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,Z(&QI8B]61E,O<VUB+G!H
M<#HT,S(@;&EB+U9&4R]S;6(N<&AP.C0Y-"!L:6(O5D93+V9T<"YP:'`Z-C@R
M"B,Z(&QI8B]61E,O9G1P+G!H<#HW-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S(&9I;FYS(')E9&%N+B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,38V(&QI8B]";&]C:R]M971A<BYP
M:'`Z,3<R(&QI8B]";&]C:R]M971A<BYP:'`Z,C0V"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,S4R(&QI8B]";&]C:R]M971A<BYP:'`Z,S4X"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(&%T("5S("5S(@IM<V=S='(@(B5S(&ML("5S("5S
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@:&%S(&-A;F-E;&QE9"`E
M<RXB"FUS9W-T<B`B)7,@:&%R(&%N;G5L;&5R870@)7,N(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@:&%S(')E<&QI960@=&\@82!F<F5E+V)U<WD@
M<F5Q=65S="XB"FUS9W-T<B`B)7,@:&%R('-V87)A="!PY2!E;B!B96?D<F%N
M(&]M(&EN9F]R;6%T:6]N(&%N9^5E;F1E(&QE9&EG+W5P<'1A9V5N+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3(T
M"B,L('!H<"UF;W)M870*;7-G:60@(B5S(&AA<R!R97!L:65D('1O('1H92!I
M;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R!H87(@<W9A<F%T('#E(&EN
M8FIU9&%N('1I;&P@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@
M:&%S('-E;G0@>6]U(&9R964O8G5S>2!I;F9O<FUA=&EO;BXB"FUS9W-T<B`B
M)7,@:&%R('-K:6-K870@9&EG(&EN9F]R;6%T:6]N(&]M(&QE9&EG+W5P<'1A
M9V5N+B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(B"B(E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M
M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H
M92`B"B)B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R
M9F]R;2!A="!T:&ES('1I;64N(@IM<V=S='(@(B(*(B5S(&MO;6UE<B!A='0@
M=71F]G)A(&1E('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A
M=',@;F5D86XN($UA<FME<F$@(@HB9&4@86MT:79I=&5T97(@<V]M(&1U('9I
M;&P@=71F]G)A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-#`@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(S-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,@:7,@<F5Q=6ER960B"FUS9W-T<B`B)7,@:W+D=G,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(Y,PHC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!M:6YU
M=&5S(@IM<V=S='(@(B5S(&UI;G5T97(B"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,3(S(&QI8B](;W)D92]";&]C:R]#;VQL
M96-T:6]N+G!H<#HQ,CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O
M=6YD+B(*;7-G<W1R("(E<R!S86MN87,N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,C$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F<F5E+V)U<WD@:6YF;W)M871I;VXN
M(@IM<V=S='(@(B5S(&5F=&5R9G+E9V%R(&EN9F]R;6%T:6]N(&]M(&[D<B!D
M=2#D<B!L961I9R]U<'!T86=E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4P.`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+B(*;7-G<W1R("(E
M<R!E9G1E<F9RY6=A<B!D:6X@;N1R=F%R;R!V:60@)7,N(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R("(E<R!T:6QL("5S(&%V("5S(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU
M,3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&%D9"!T;R`E
M<RXB"FUS9W-T<B`B)7,@=FEL;"!LY&=G82!T:6QL('1I;&P@)7,N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@=VES:&5S('1O(&UA:V4@>6]U(&%W
M87)E(&]F("5S+B(*;7-G<W1R("(E<R!V:6QL(&?V<F$@9&EG(&UE9'9E=&5N
M(&]M("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-3$X"B,L('!H<"UF;W)M870*;7-G:60@(B5S('=I<VAE<R!T
M;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N(@IM
M<V=S='(@(B5S('9I;&P@97)HY6QL82!D96X@<V5N87-T92!I;F9O<FUA=&EO
M;F5N(&]M("5S+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(R
M(&QI8B](;W)D92]+;VQA8BYP:'`Z.3(V"B,L('!H<"UF;W)M870*;7-G:60@
M(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V)O:R!F]G(@)7,B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ-"!L:6(O2&]R9&4O
M2V]L86(N<&AP.CDQ.`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N
M9&%R(@IM<V=S='(@(DMA;&5N9&5R(&;V<B`E<R(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`V(&QI8B](;W)D92]+;VQA8BYP:'`Z.3$P"B,L
M('!H<"UF;W)M870*;7-G:60@(B5S)W,@3F]T97!A9"(*;7-G<W1R(")!;G1E
M8VMN:6YG87(@9O9R("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,S`@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,G<R!487-K;&ES="(*;7-G<W1R(")5<'!G:69T97(@9O9R("5S
M(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES
M=&5N97(O;6]B:6QE+G!H<#HY-@HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N
M+TQI<W1E;F5R+VUO8FEL92YP:'`Z.38*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M)7,Z("5S(@IM<V=S='(@(B5S.B`E<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VAT;6PN<&AP.C(W,B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES
M(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E
M+B!"97=A<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O
M9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B(@HB)7,Z($UE9&1E;&%N9&5T(&MA;G-K92!I
M;G1E(.1R(&9RY6X@9&5N('-O;2!D970@=F5R:V%R+B!687(@9O9R<VEK=&EG
M(&UE9"`B"B)A='0@9O9L:F$@;.1N:V%R(&5L;&5R('-K:6-K82!A=G/D;F1A
M<F5N('!E<G-O;FQI9R!I;F9O<FUA=&EO;BXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,S4T(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.3D*;7-G:60@(BP@9W5S=&EN9R`B"FUS9W-T<B`B+"!S=&]R;6)Y87(B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Y-2!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P,`HC+"!P:'`M9F]R;6%T"FUS9VED("(L(&=U<W1I;F<@)7,@)7,B
M"FUS9W-T<B`B+"!S=&]R;6)Y87(@)7,@)7,B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C(P.`HC+"!P:'`M9F]R;6%T"FUS9VED("(L('9A<FEA8FQE(&9R
M;VT@)7,@=&\@)7,B"FUS9W-T<B`B+"!V87)I97)A;F1E(&UE;&QA;B`E<R!O
M8V@@)7,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Y-"!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q
M,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C<R
M,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`W,PHC.B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,C$S,B!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C(Y-`HC.B!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C,T."!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-S0X"FUS9VED("(M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@
M=N1L:B`M+2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HR,`IM<V=I9"`B,3(@
M2&]U<B!&;W)M870B"FUS9W-T<B`B,3(M=&EM;6%R<V9O<FUA="(*"B,Z(&QI
M8B]";&]C:R]T:6UE+G!H<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS
M9W-T<B`B,C0M=&EM;6%R<V9O<FUA="(*"B,Z('1E;7!L871E<R]D871A+W1I
M;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"!T:6UM87(B
M"@HC.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C8Y(&QI8B](;W)D92]5
M22]086=E<BYP:'`Z-CD*;7-G:60@(CQ0<F5V:6]U<R(*;7-G<W1R("(\1O9R
M96?E96YD92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3(V"FUS9VED(")!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M(@IM<V=S='(@(D5N(&1A=&%B87-K;W!P;&EN9R!K<N1V<R!F]G(@86MT=65L
M;'0@8FQO8VLN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`@
M;&EB+TAO<F1E+G!H<#HQ-C(*;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D(@IM<V=S='(@(D5T="!F871A;'0@9F5L(&AA<B!I;G1RY&9F870B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,C`@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R(")%
M;B!P=6)L:6L@4$=0+6YY8VME;"!K<N1V<R!F]G(@871T(&MR>7!T97)A(&5T
M="!M961D96QA;F1E+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C$Q-#4@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3$V.`IM<V=I9"`B
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92XB"FUS9W-T<B`B16X@<'5B;&EK(%!'4"UN>6-K96P@:W+D
M=G,@9O9R(&%T="!V97)I9FEE<F$@971T('-I9VYE<F%T(&UE9&1E;&%N9&4N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`W-R!L:6(O
M2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,#DY"FUS9VED("(B"B)!('!U8FQI8R!0
M1U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R
M97%U:7)E9"!T;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@HB
M16X@<'5B;&EK(&]C:"!P<FEV870@4$=0+6YY8VME;"!S86UT(&SV<V5N;W)D
M(&MRY'9S(&;V<B!A='0@9&5K<GEP=&5R82!E='0@(@HB;65D9&5L86YD92XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY.34@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z,3`Q-@IM<V=I9"`B(@HB02!P=6)L:6,@4$=0
M(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q
M=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*(D5N('!U
M8FQI:R!O8V@@<')I=F%T(%!'4"UN>6-K96P@<V%M="!L]G-E;F]R9"!K<N1V
M<R!F]G(@871T('-I9VYE<F$@971T("(*(FUE9&1E;&%N9&4N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,#4@;&EB+TAO<F1E+T-R
M>7!T+W-M:6UE+G!H<#HU,#8*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K
M97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O("(*(F1E8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B)%
M;B!P=6)L:6L@;V-H('!R:79A="!3+TU)344M;GEC:V5L('-A;70@;/9S96YO
M<F0@:W+D=G,@9O9R(&%T="!D96MR>7!T97)A("(*(F5T="!M961D96QA;F1E
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-#,Q"FUS9VED("(B"B)!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*(F$@;65S<V%G92XB"FUS9W-T
M<B`B(@HB16X@<'5B;&EK(&]C:"!P<FEV870@4R]-24U%+6YY8VME;"!S86UT
M(&SV<V5N;W)D(&MRY'9S(&;V<B!A='0@<VEG;F5R82!E='0@(@HB;65D9&5L
M86YD92XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V
M-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R(")%;B!P=6)L:6L@4R]-24U%+6YY8VME;"!K<N1V<R!F]G(@
M871T(&MR>7!T97)A(&5T="!M961D96QA;F1E+B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.CD*;7-G:60@(D%-($-L;W5D<R(*
M;7-G<W1R(")&]G)M:61D86=S;6]L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C$P"FUS9VED(")!32!,:6=H="!286EN(@IM
M<V=S='(@(DSD='0@9O9R;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ,0IM<V=I9"`B04T@4F%I;B(*;7-G
M<W1R(")&]G)M:61D86=S<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C$R"FUS9VED(")!32!3:&]W97)S(@IM<V=S='(@
M(D;V<FUI9&1A9W-S:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HQ,PIM<V=I9"`B04T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(D;V<FUI9&1A9W-S:W5R87(@;65D('-N]B(*"B,Z('1E;7!L871E<R]D
M871A+W1I;64N:6YC.C(Y"FUS9VED(")!32]032(*;7-G<W1R(")!32]032(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(P,`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,`IM
M<V=I9"`B05!)($E$(@IM<V=S='(@(D%022!)1"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T('1H
M:7,@961I=&]R(@IM<V=S='(@(D]M(&5D:71O<FXB"@HC.B!S97)V:6-E<R]H
M96QP+VEN9&5X+G!H<#HU,PIM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B3VTN
M+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B0F]T=&5N(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B
M06)S;6ED9&QE(@IM<V=S='(@(DUI='1E;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0P"FUS9VED(")!8V-E<'0@
M<F5Q=65S="(*;7-G<W1R(")!8V-E<'1E<F$@8F5GY')A;B(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Q"FUS9VED
M(")!8V-E<'1E9"(*;7-G<W1R(")!8V-E<'1E<F%D(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C(W,"!L:6(O5D93+VUU<W%L+G!H<#HR-S`*
M;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2XB
M"FUS9W-T<B`B0F5H]G)I9VAE="!S86MN87,@871T('-K87!A(%9&4RUM87!P
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,S8@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3,V"FUS9VED(")!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+B(*;7-G<W1R(")"96CV<FEG:&5T('-A:VYA<R!A='0@<VMA
M<&$@5D93+69I;"XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,PIM<V=I
M9"`B06-C;W5N="!);F9O<FUA=&EO;B(*;7-G<W1R(")+;VYT;VEN9F]R;6%T
M:6]N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<X"FUS9VED(")!8V-O
M=6YT(%!A<W-W;W)D(@IM<V=S='(@(DSV<V5N;W)D(&;V<B!K;VYT;R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M,PHC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,PIM<V=I
M9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(DMO;G1O="!F<GES="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,S4*;7-G:60@(D%C8V]U;G1I
M;F<B"FUS9W-T<B`B0G5D9V5T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HT-3$*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,C4*;7-G:60@(D%C=&EO;G,B"FUS
M9W-T<B`BQ71GY')D97(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C$T."!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C$T.`HC.B!T96UP;&%T
M97,O<&]R=&%L+V%D9"YI;F,Z,30@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]A
M9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G<W1R("),Y&=G('1I;&PB
M"@HC.B!T96UP;&%T97,O;&EN:W,O;&EN:W,N:6YC.C$S"B,L('!H<"UF;W)M
M870*;7-G:60@(D%D9"`E<R(*;7-G<W1R("),Y&=G('1I;&P@)7,B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP.C(R-0IM<V=I
M9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(DSD9V<@=&EL;"!U;F1E<F=R
M=7!P(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY."!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDY"B,Z(&QI8B](;W)D92]097)M
M<R]522YP:'`Z.3@@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HY.0IM<V=I9"`B
M061D($-H:6QD(%!E<FUI<W-I;VXB"FUS9W-T<B`B;.1G9R!T:6QL('5N9&5R
M8F5H]G)I9VAE="(*"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHU"FUS
M9VED(")!9&0@2&5R93HB"FUS9W-T<B`B3.1G9R!T:6QL(&CD<CHB"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I
M9"`B061D($YE=R!'<F]U<"(*;7-G<W1R("),Y&=G('1I;&P@;GD@9W)U<'`B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@W(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.#@*(SH@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HX-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C@X"FUS9VED(")!9&0@
M3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B3.1G9R!T:6QL(&YY(&)E:/9R:6=H
M970B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW
M"B,L('!H<"UF;W)M870*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O(%PB
M)7-<(B(*;7-G<W1R("),Y&=G('1I;&P@=6YD97)G<G5P<"!T:6QL("<E<R<B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$T-R!L:6(O2&]R
M9&4O4&5R;7,O54DN<&AP.C$T-PHC+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<(B(*;7-G<W1R("),Y&=G('1I
M;&P@=6YD97)B96CV<FEG:&5T('1I;&P@)R5S)R(*"B,Z(&%D;6EN+W5S97(N
M<&AP.C,P"FUS9VED(")!9&0@82!N97<@=7-E<CHB"FUS9W-T<B`B3.1G9R!T
M:6QL(&5N(&YY(&%N=N1N9&%R93HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-3(Y"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HU-38*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`B
M3.1G9R!T:6QL(&MO;'5M;B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,S0*;7-G:60@(D%D9"!N97<@;65M8F5R<R(*;7-G<W1R("),
MY&=G('1I;&P@;GEA(&UE9&QE;6UA<B(*"B,Z('1E;7!L871E<R]D871A+V-S
M=FUA<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(DSD9V<@=&EL
M;"!P87(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<Q"B,L('!H<"UF
M;W)M870*;7-G:60@(D%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED
M96)A<B(*;7-G<W1R("),Y&=G('1I;&P@;65N>6X@9O9R("5S('-O;2!-;WII
M;&QA(%-I9&5B87(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C8S,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C8S-PIM<V=I9"`B061D('1H:7,@=&\@;7D@8V%L
M96YD87(B"FUS9W-T<B`B3.1G9R!T:6QL(&D@;6EN(&MA;&5N9&5R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C<Q(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A
M9&1R97-S(&)O;VLZ(@IM<V=S='(@(DSD9V<@=&EL;"!I(&%D<F5S<V)O:SHB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D
M('1O(&UY(&%D9')E<W,@8F]O:R(*;7-G<W1R("),Y&=G('1I;&P@:2!M:6X@
M861R97-S8F]K(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$*;7-G:60@(D%D9"!U
M<V5R(@IM<V=S='(@(DSD9V<@=&EL;"!A;G;D;F1A<F4B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S
M7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA
M;"!S:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"B),861E
M('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+"!M96X@:W5N9&4@:6YT92!LY&=G
M82!T:6QL(&5X=')A("!I;F9O<FUA=&EO;CH@)2(*(G,N(@H*(SH@<VEG;G5P
M+G!H<#HT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")!9&1E9"!<(B5S7"(@=&\@
M=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("),861E
M('1I;&P@)R5S)R!T:6QL('-Y<W1E;65T+B!$=2!K86X@;&]G9V$@:6X@;G4N
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N:6YC.C(*;7-G:60@
M(D%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B57!P;.1G9R!A
M=B!A;G;D;F1A<F4@Y'(@:6YA:W1I=F5R870N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#4@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C8*(SH@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ-S,*;7-G:60@(D%D9')E<W,B"FUS9W-T
M<B`B061R97-S(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$T,0IM
M<V=I9"`B061D<F5S<R!";V]K(@IM<V=S='(@(D%D<F5S<V)O:R(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDT(&QI8B](;W)D
M92])34%0+T%#3"]R9F,T,S$T+G!H<#HU-@HC.B!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.30*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R
M;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S(@IM<V=S='(@(D%D;6EN:7-T<F%T
M:6]N("T@86YG92!B96CV<FEG:&5T(&;V<B!A;F1R82!A;G;D;F1A<F4B"@HC
M.B!A9&UI;B]I;F1E>"YP:'`Z,3D@<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP
M.C$Q,PHC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!9&UI;FES=')A=&EO;B(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-#,*;7-G:60@(D%D<R(*;7-G
M<W1R(")296ML86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(D%F9V%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%L8F%N:6$B"FUS9W-T
M<B`B06QB86YI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D%L9V5R:6$B"FUS9W-T<B`B
M06QG97)I970B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3`W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R(")!;&EA<R(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,38*;7-G:60@
M(D%L:6=N(@IM<V=S='(@(DIU<W1E<F$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C8W"FUS9VED(")!;&EG;FUE;G0Z(@IM
M<V=S='(@(DIU<W1E<FEN9SHB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M.#<*;7-G:60@(D%L;"(*;7-G<W1R(")!;&QA(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,#<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,#<*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV-0IM<V=I9"`B06QL
M($%U=&AE;G1I8V%T960@57-E<G,B"FUS9W-T<B`B06QL82!A=71E;G1I<V5R
M861E(&%N=N1N9&%R92(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,S,@861M:6XO
M9W)O=7!S+G!H<#HR,C(*;7-G:60@(D%L;"!'<F]U<',B"FUS9W-T<B`B06QL
M82!G<G5P<&5R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HY
M,2!F<F%M97=O<FLO4&5R;7,O4&5R;7,O9&%T871R964N<&AP.C<U"B,Z(&QI
M8B](;W)D92]097)M<R]522YP:'`Z.3$@;&EB+TAO<F1E+U!E<FUS+V1A=&%T
M<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM<V=S='(@(D%L
M;&$@8F5H]G)I9VAE=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED97,B
M"FUS9W-T<B`B06QL82!F>7)A('-I9&]R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W-0IM<V=I9"`B
M06QL;W<@;75L=&EP;&4@861D<F5S<V5S(@IM<V=S='(@(E1I;&SE="!F;&5R
M82!A9')E<W-E<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,S@*;7-G
M:60@(D%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S
M='(@(E1I;&SE="!I;G-TY&QL;FEN9R!F]G(@<V]R=&5R860@;&ES=&$_(@H*
M(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T(&QI
M8B](;W)D92]$871A5')E92]S<6PN<&AP.C4P-`IM<V=I9"`B06QR96%D>2!E
M>&ES=',B"FUS9W-T<B`B1FEN;G,@<F5D86XB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,3(V"FUS9VED(")!;'1E<FYA=&4@24U34"!,;V=I;B(*;7-G
M<W1R(")!;'1E<FYA=&EV($E-4U`M:6YL;V=G;FEN9R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,3$*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D(@IM<V=S='(@(D%L=&5R;F%T:79T(&SV<V5N;W)D(&;V<B!)35-0(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4P,PIM<V=I9"`B06QT97)N871E
M($E-4U`@57-E<FYA;64B"FUS9W-T<B`B06QT97)N871I=G0@86YVY&YD87)N
M86UN(&;V<B!)35-0(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M,S4*;7-G:60@(D%L=&5R;F%T92!E;6%I;"!A9&1R97-S(@IM<V=S='(@(D%L
M=&5R;F%T:78@92UP;W-T(&%D<F5S<R(*"B,Z(&%D;6EN+W1E;7!L871E<RYP
M:'`Z,30R"FUS9VED(")!;'1E<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(D%L
M=&5R;F%T:78@;6%L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E
M>'0Z(@IM<V=S='(@(D%L=&5R;F%T:78@=&5X=#HB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@
M(D%M97)I8V%N(%-A;6]A(@IM<V=S='(@(D%M97)I:V%N<VMA(%-A;6]A(@H*
M(SH@9G)A;65W;W)K+TQI;FMS+TQI;FMS+G!H<#HR-#<*(SH@9G)A;65W;W)K
M+U)E;&%T:6]N<VAI<"]296QA=&EO;G-H:7!-86YA9V5R+G!H<#HR-#(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B06X@97)R;W(@;V-C=7)R960@9F]L;&]W:6YG
M('1H:7,@;&EN:SH@)7,B"FUS9W-T<B`B171T(&9E;"!U<'!S=&]D(&[D<B!L
MY&YK96X@*"5S*2!S:W5L;&4@86YVY&YD87,B"@HC.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O54DN<&AP.CDU(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z,3$U"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z.34@;&EB+TAO<F1E
M+U!R969S+U5)+G!H<#HQ,34*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S
M('-P96-I9FEE9"XB"FUS9W-T<B`B171T(&9E;&%K=&EG="!VY')D92!A;F=A
M=G,N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-0IM<V=I
M9"`B06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB"FUS9W-T<B`B171T
M(&]KY&YT(&9E;"!H87(@:6YT<N1F9F%T(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O
M<G)A(@IM<V=S='(@(D%N9&]R<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HR-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*
M;7-G<W1R(")!;F=O;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S
M='(@(D%N9W5I;&QA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY
M;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N>6T@<')O>'DB"@HC.B!S97)V:6-E
M<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S='(@
M(E-V87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N=&%R8W1I8V$B"FUS9W-T<B`B06YT
M87)K=&ES(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3D*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM
M<V=S='(@(D%N=&EG=6$@;V-H($)A<F)U9&$B"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C<T(&%D;6EN+W!H<'-H96QL+G!H<#HS-0HC.B!F<F%M97=O<FLO
M0FQO8VLO0FQO8VLO54DN<&AP.C4X(&QI8B](;W)D92]";&]C:R]522YP:'`Z
M-3@*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I
M9"`B07!P;&EC871I;VXB"FUS9W-T<B`B07!P;&EK871I;VXB"@HC.B!U=&EL
M+VEC;VY?8G)O=W-E<BYP:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B
M"FUS9W-T<B`B07!P;&EK871I;VYS;&ES=&$B"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,30P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS
M9W-T<B`B07!P;&EK871I;VYE;B#D<B!K;&%R+B(*"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,C$X"FUS9VED(")!<'!L>2!T;R!#:&EL9"!3:&%R
M97,B"FUS9W-T<B`B5F5R:W-TY&QL('1I;&P@=6YD97)U=&1E;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED
M(")!<'!R;W9E(@IM<V=S='(@(D=O9&OD;FXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+T-O;G1E;G1S+G!H<#HX,S(@;&EB+TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP.C@T,0IM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R(")5
M;F=E9N1R;&EG('-T;W)L96LB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,S@P"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT,3<*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0P-2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0S"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C@*;7-G:60@(D%P<FEL(@IM<V=S='(@(F%P<FEL(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V
M*2(*;7-G<W1R(")!<F%B:7-K("A7:6YD;W=S+3$R-38I(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HU.2!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-3D*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-C8@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*;7-G:60@(D%R8VAI
M=F4@1FEL92!3:7IE(@IM<V=S='(@(D%R:VEV9FEL<W1O<FQE:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-3@@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV,@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]T9WHN<&AP.C@P(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R87(N<&AP.C4X"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8U(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<W"FUS9VED(")!
M<F-H:79E($YA;64B"FUS9W-T<B`B07)K:79F:6QN86UN(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHQ,`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/R(*;7-G<W1R("+$<B!D970@<^1K
M97)T(&%T="!D=2!V:6QL('1A(&)O<G0@8F5GY')A;B!F]G(@)7,_(@H*(SH@
M=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92!<
M(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+$<B!D970@<^1K
M97)T(&%T="!D=2!V:6QL(')A9&5R82`G)7,G(&]C:"!E=F5N='5E;&QA('5N
M9&5R9W)U<'!E<C\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4X(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%R9V5N=&EN82(*;7-G<W1R
M(")!<F=E;G1I;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B
M07)M86YI96XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.0IM<V=I9"`B
M07)M96YI86X@*$%235-#24DM."DB"FUS9W-T<B`B07)M96YI<VL@*$%235-#
M24DM."DB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C@*;7-G:60@(D%R
M="(*;7-G<W1R(")+;VYS="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C,P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,B!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07)U8F$B"FUS9W-T
M<B`B07)U8F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-0IM<V=I9"`B07-C96YS:6]N($ES;&%N
M9"(*;7-G<W1R(")!<V-E;G-I;VX@27-L86YD(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS9W-T<B`B07-C:6D@
M:V]N<W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%S:6$O4&%C:69I8R!2
M96=I;VXB"FUS9W-T<B`B07-I96XO4W1I;&QA(&AA=G-R96=I;VYE;B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,CD*;7-G:60@(D%S:R!F;W(@8V]N
M9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS
M/R(*;7-G<W1R(")&<N5G82!E9G1E<B!B96MRY&9T96QS92!I;FYA;B!U;F1E
M<FCE;&QS86MT:79I=&5T97(@=71F]G)S/R(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3,@;&EB+TAO<F1E+T9O<FTN<&AP.C,P.3D*;7-G:60@
M(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R(")4:6QL9&5L;FEN9W-K;VQU
M;6XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C$V-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C(T.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C,Q.`IM<V=I9"`B071T86-H960@:7,@86X@:4-A;&5N9&%R
M(&9I;&4@<F5P;'D@=&\@82!R97%U97-T('EO=2!S96YT(@IM<V=S='(@(D)I
M9F]G860@Y'(@96X@:4-A;&5N9&5R(&9I;"!M960@971T('-V87(@<.4@96X@
M8F5GY')A;B!S;VT@9'4@<VMI8VMA="PB"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C<T"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G
M<F]U<"XB"FUS9W-T<B`B1O9R<_9K('1I;&P@871T(')A9&5R82!E;B!G<G5P
M<"!S;VT@:6YT92!F:6YN<RXB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP
M.C(Y"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+B(*;7-G<W1R(")&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N
M(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N(@H*(SH@861M:6XO<&5R;7,O
M961I="YP:'`Z.#<*;7-G:60@(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+B(*;7-G<W1R(")&]G)S]FL@871T(.1N9')A(&5N
M(&)E:/9R:6=H970@<V]M(&EN=&4@9FEN;G,N(@H*(SH@<V5R=FEC97,O<VAA
M<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(D;V<G/V:R!A='0@Y&YD<F$@96X@
M=71D96QN:6YG('-O;2!I;G1E(&9I;FYS+B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<W"FUS9VED(")!='1E;F1E
M97,B"FUS9W-T<B`B1&5L=&%G87)E(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV-"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#8@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S$@;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W1G>BYP:'`Z.#,*;7-G:60@(D%T=')I8G5T97,B"FUS9W-T
M<B`B071T<FEB=70B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,S@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,C$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P.2!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S(*
M;7-G:60@(D%U9W5S="(*;7-G<W1R(")A=6=U<W1I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,CD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED
M(")!=7-T<F%L:6$B"FUS9W-T<B`B075S=')A;&EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(X"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HR-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I
M9"`B075S=')I82(*;7-G<W1R("+6<W1E<G)I:V4B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G-Q;"YP:'`Z,38X(&QI8B](;W)D92]!=71H+V-Y<G-Q
M;"YP:'`Z,38X"FUS9VED(")!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G-Q;#H@24U!
M4"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$S-2!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3,U"FUS
M9VED(")!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER
M960@8V%P86)I;&ET97,N(@IM<V=S='(@(D%U=&A?8WER<W%L.B!+;W!P;&EN
M9V5N('-A:VYA<B!F=6YK=&EO;F5R('-O;2!K<N1V<RXB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,C(@;&EB+TAO<F1E+T%U=&@O8WER
M=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7V-Y<G5S.B!)34%0
M+65X=&5N<VEO;B!S86MN87,N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]F
M='`N<&AP.C,V(&QI8B](;W)D92]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*
M(D%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB
M"FUS9W-T<B`B075T:%]F='`Z($944"UT:6QLY&=G('-A:VYA<RX@2V]M<&EL
M97)A(%!(4"!M960@<W=I=&-H96X@+2UE;F%B;&4M9G1P+B(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:6UA<"YP:'`Z-C0@;&EB+TAO<F1E+T%U=&@O:6UA
M<"YP:'`Z-C0*;7-G:60@(D%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")!=71H7VEM87`Z($E-05`M97AT
M96YS:6]N('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N
M<&AP.C4Q(&QI8B](;W)D92]!=71H+VMR8C4N<&AP.C4Q"FUS9VED(")!=71H
M7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]K<F(U.B!K<F(U+65X=&5N<VEO;B!S86MN87,N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS,#(@;&EB+TAO<F1E+T%U
M=&@O;&1A<"YP:'`Z,S`R"FUS9VED(")!=71H7VQD87`Z($%D9&EN9R!U<V5R
M<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y(@IM<V=S
M='(@(D%U=&A?;&1A<#H@1&5T(&?E<B!I;G1E(&%T="!LY&=G82!T:6QL(&%N
M=N1N9&%R92!I($%C=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C,U-R!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HS
M-3<*;7-G:60@(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U
M<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R(")!=71H7VQD
M87`Z($1E="!GY7(@:6YT92!A='0@<F%D97)A(&%N=N1N9&%R92!F<N5N($%C
M=&EV92!$:7)E8W1O<GDB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C8S(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS
M9W-T<B`B075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S,Y(&QI8B](;W)D92]!=71H
M+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z
M(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V
M97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EN=&4@;.1G9V$@
M=&EL;"!A;G;D;F1A<F4@)R5S)RX@4V5R=F5R;B!S=F%R861E.B`B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-2!L:6(O2&]R9&4O075T
M:"]L9&%P+G!H<#HS.#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:%]L9&%P
M.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@)7,B"FUS9W-T<B`B075T:%]L9&%P
M.B!+86X@:6YT92!R861E<F$@86YVY&YD87)E("5S(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]L9&%P+G!H<#HT.3D@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z-#DY"B,L('!H<"UF;W)M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S(@IM<V=S='(@(D%U=&A?;&1A<#H@2V%N(&EN
M=&4@=7!P9&%T97)A(&%N=N1N9&%R92`E<R(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-#`U(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C0P
M-0IM<V=I9"`B075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+B(*;7-G<W1R(")!=71H7VQD
M87`Z($1E="!GY7(@:6YT92!A='0@=7!P9&%T97)A(&%N=N1N9&%R92!I($%C
M=&EV92!$:7)E8W1O<GDN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L
M+G!H<#HT-B!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?;6-A;#H@34-!3"UE>'1E;G-I;VX@<V%K;F%S+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HV,"!L:6(O2&]R9&4O075T
M:"]S;6(N<&AP.C8P"FUS9VED(")!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A
M=71H.B!S;6)A=71H+65X=&5N<VEO;B!S86MN87,N(@H*(SH@;&EB+TAO<F1E
M+TE-05`O061M:6XN<&AP.C$P-@IM<V=I9"`B075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG('1I
M;&P@24U!4"US97)V97(@;6ES<VQY8VMA9&5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,`IM<V=I9"`B075T:&5N=&EC
M871I;VX@9F%I;&5D(@IM<V=S='(@(D%U=&5N=&ES97)I;F<@;6ES<VQY8VMA
M9&5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z-S8*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H
M<#HV-R!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C<V"B,L('!H
M<"UF;W)M870*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B"FUS
M9W-T<B`B075T96YT:7-E<FEN9R!M:7-S;'EC:V%D97,N("5S(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-B!L:6(O2&]R9&4O075T
M:"]R861I=7,N<&AP.C$W-@IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BXB"FUS9W-T<B`B075T96YT:7-E<FEN9R!A
M=G9I<V%D97,@878@4D%$2553+7-E<G9E<FXN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9G1P+G!H<#HX-3$@;&EB+U9&4R]F='`N<&AP.C@X,@IM<V=I9"`B
M075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@
M(D%U=&5N=&ES97)I;F<@=&EL;"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C<P(&QI8B]61E,O<VUB
M+G!H<#HW,`IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V
M97(@9F%I;&5D+B(*;7-G<W1R(")!=71E;G1I<V5R:6YG('1I;&P@4TU"+7-E
M<G9E<B!M:7-S;'EC:V%D97,N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B5&EL
M;&?D;F=L:6=A(&;D;'0Z(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HV,30*;7-G:60@(D%W86ET:6YG(%)E<W!O;G-E
M(@IM<V=S='(@(E;D;G1A<B!PY2!S=F%R(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C4Y"FUS9VED(")!>F5R
M8F%I:F%N(@IM<V=S='(@(D%Z97)B86EJ86XB"@HC.B!C;VYF:6<O=&AE;65S
M+V%Z=7(N<&AP.C@*;7-G:60@(D%Z=7(B"FUS9W-T<B`B07IU<F)LY2(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S
M(@IM<V=S='(@(D)/1D@M=7)SY&MT97(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O
M=6YD(@IM<V=S='(@(D)A:V=R=6YD(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO
M<B(*;7-G<W1R(")"86MG<G5N9'-FY')G(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,2!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,0IM
M<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")&96QA:W1I
M9W0@;/9S96YO<F0@9O9R($ME<F)E<F]S(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]K<F(U+G!H<#HX,R!L:6(O2&]R9&4O075T:"]K<F(U+G!H<#HX,PIM
M<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R(")&96QA:W1I
M9W0@86YVY&YD87)N86UN(&;V<B!+97)B97)O<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C(@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C0U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HR-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B
M0F%H86UA<R(*;7-G<W1R(")"86AA;6%S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,S@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"86AR
M86EN(@IM<V=S='(@(D)A:')A:6XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,`IM<V=I9"`B0F%L=&EC("A)4T\M.#@U.2TQ,RDB"FUS9W-T<B`B0F%L
M=&ES:R`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,S0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(X
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG;&%D97-H
M(@IM<V=S='(@(D)A;F=L861E<V@B"@HC.B!L:6(O0FQO8VLO8F%R=&EM92YP
M:'`Z-`IM<V=I9"`B0F%R(%1I;64B"FUS9W-T<B`B0F%R=&ED(@H*(SH@;&EB
M+T)L;V-K+V)A<G1I;64N<&AP.C,U"FUS9VED(")"87(@=&EM92(*;7-G<W1R
M(")2861T:60B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P(&QI8B](;W)D92].3%,O=&QD+G!H<#HS
M,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,CD@;&EB+TAO<F1E
M+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S(@IM<V=S='(@(D)A
M<F)A9&]S(@H*(SH@8V]N9FEG+W1H96UE<R]B87)B:64N<&AP.C8*;7-G:60@
M(D)A<F)I92(*;7-G<W1R(")"87)B:64B"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D
M:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`B0F%S:V%T86QO
M9R`G)7,G(&;V<B!B:6QD97(@:&ET=&%D97,@:6YT92XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*;7-G:60@
M(D)A<V5L:6YE(@IM<V=S='(@(D)A<VQI;FIE(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-#D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QA<G5S(@IM<V=S='(@(E9I=')Y<W-L86YD(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,"!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z,S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C,Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"
M96QG:75M(@IM<V=S='(@(D)E;&=I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C4P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HU,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ
M92(*;7-G<W1R(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HT,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)E;FEN(@IM<V=S
M='(@(D)E;FEN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M-#$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"97)M=61A(@IM<V=S='(@(D)E
M<FUU9&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8S(&QI8B](;W)D92].3%,O=&QD+G!H<#HT-@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T86XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q
M"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3$Q"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R(")&]F1E;'-E9&%G(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,U,B!L:6(O2&]R9&4O0FQO
M8VLO0V]L;&5C=&EO;BYP:'`Z,S8P"B,L('!H<"UF;W)M870*;7-G:60@(D)L
M;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD+B(*
M;7-G<W1R(")";&]C:R`G)7,G(&;V<B!A<'!L:6MA=&EO;B`G)7,G('-A:VYA
M<RXB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z.3`*;7-G:60@
M(D)L;V-K(%-E='1I;F=S(@IM<V=S='(@(D)L;V-K:6YS=.1L;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO
M8VL@5'EP92(*;7-G<W1R(")";&]C:W1Y<"(*"B,Z(&-O;F9I9R]T:&5M97,O
M8FQU96UO;VXN<&AP.C8*;7-G:60@(D)L=64@36]O;B(*;7-G<W1R(")";.4@
M;>5N92(*"B,Z(&-O;F9I9R]T:&5M97,O8FQU97=H:71E+G!H<#HV"FUS9VED
M(")";'5E(&%N9"!7:&ET92(*;7-G<W1R(")";.5T="!O8V@@=FET="(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I
M9"`B0F]L9"(*;7-G<W1R(")&970B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C0S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HT,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)O;&EV:6$B
M"FUS9W-T<B`B0F]L:79I82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HR,#<*;7-G:60@(D)O;VMM87)K<R(*;7-G<W1R(")";VMMY')K96XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C(P"FUS9VED(")";W)D97(B"FUS9W-T<B`B4F%M(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-0IM<V=I9"`B0F]R9&5R
M('1H:6-K;F5S<SHB"FUS9W-T<B`B4F%M8G)E9&0Z(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B
M0F]R9&5R<R(*;7-G<W1R(")286UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C,R"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HS-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,`IM<V=I9"`B0F]S;FEA
M(&%N9"!(97)Z96=O=FEN82(*;7-G<W1R(")";W-N:65N(&]C:"!(97)Z96=O
M=FEN82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T
M:"(*;7-G<W1R(")"Y61A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z-#@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C,X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G
M<W1R(")";W1S=V%N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D)O
M='1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C0W"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HS.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]U=F5T($ES;&%N9"(*;7-G<W1R(")"
M;W5V970@27-L86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z-#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C0P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B
M0G)A<VEL:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3<@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$Q-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#$*;7-G:60@(D)R:71I<V@@26YD:6%N($]C
M96%N(%1E<G)I=&]R>2(*;7-G<W1R(")"<FET=&ES:V$@=&5R<FET;W)I970@
M:2!);F1I<VMA(&]C96%N96XB"@HC.B!C;VYF:6<O=&AE;65S+V)R;W=N+G!H
M<#HV"FUS9VED(")"<F]W;B(*;7-G<W1R(")"<G5N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C0R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C0R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8R"FUS9VED
M(")"<G5N96D@1&%R=7-S86QA;2(*;7-G<W1R(")"<G5N96DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HS-PHC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U;&=A<FEA(@IM<V=S='(@(D)U;&=A<FEE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U
M;&QE=&5D($QI<W0B"FUS9W-T<B`B4'5N:W1L:7-T82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C,V"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HT-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&-O
M;F9I9R]T:&5M97,O8G5R;G1O<F%N9V4N<&AP.CD*;7-G:60@(D)U<FYT($]R
M86YG92(*;7-G<W1R(")"<N1N9"!/<F%N9V4B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HS.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U
M<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#8*;7-G:60@(D--4R(*;7-G<W1R(")#35,B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS9VED(")#4D,B"FUS9W-T<B`B0U)#
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<@;&EB
M+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G:60@(D-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S(@IM<V=S='(@(D-23"!$:7-T<FEB=71I;VX@4&]I;G1S
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(D-?96QL(&EN<W3D;&QN:6YG87(N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,34Q"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M
M<&QE=&5D+B(*;7-G<W1R(")#86-H96EN:71I97)I;F<@Y'(@:6YT92!F=6QL
M<W3D;F1I9RXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#4Y"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HT.#4@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P-#`*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$U-PIM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B
M2V%L96YD97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,U
M"FUS9VED(")#86QM(@IM<V=S='(@(DQU9VYT(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HT-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C$R.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#,*;7-G:60@
M(D-A;6)O9&EA(@IM<V=S='(@(DMA;6)O9&IA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-R!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z-C`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C0W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R(")+86UE<G5N(@H*(SH@8V]N9FEG+W1H96UE<R]C
M86UO=69L86=E+G!H<#HV"FUS9VED(")#86UO=69L86=E(@IM<V=S='(@(DMA
M;6]U9FQA9V4B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR,`IM
M<V=I9"`B0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BXB"FUS9W-T<B`B2V%N(&EN=&4@
M;F]L;'-TY&QL82!L]G-E;F]R9"!A=71O;6%T:7-K="P@:V]N=&%K=&$@9&EN
M(&%D;6EN:7-T<F%T]G(N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,S$X(&QI8B]&:6QE+T-35BYP:'`Z,S4P"B,L('!H<"UF;W)M870*;7-G
M:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B"FUS9W-T<B`B2V%N
M(&EN=&4@<VMR:79A('1I;&P@9FEL("<E<R<B"@HC.B!A9&UI;B]S97-S:6]N
M<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S
M<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B1&5T(&?E<B!I;G1E(&%T="!A9&UI
M;FES=')E<F$@97AT97)N82!S97-S:6]N<VAA;G1E<F%R92XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,S4@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C,Q.0HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP
M:'`Z,C,U(&QI8B](;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L('!H<"UF
M;W)M870*;7-G:60@(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M(@IM<V=S='(@(DMA;B!I;G1E(&MO;G1A:W1A($E-05`M<V5R=F5R;CH@)7,B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT,3,@;&EB+T9I;&4O
M0U-6+G!H<#HT-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@;W!E;B!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@9FEL("<E<R<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8T(&QI8B](;W)D92].3%,O=&QD+G!H<#HU,0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-C0*;7-G:60@(D-A;F%D82(*;7-G<W1R(")+86YA9&$B"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O8VQE87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E
M;6]V92YI;F,Z,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R(")!=F)R>70B"@HC
M.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHU.0IM<V=I9"`B0V%N
M8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(D%V8G)Y="!P<F]B;&5M<F%P
M<&]R="(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S$X(&QI8B]6
M1E,O9G1P+G!H<#HS,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E
M;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E
M<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C0V"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP
M:'`Z-3(*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C0W"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO8V]P>2YP:'`Z-3,*(SH@;&EB
M+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*
M(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN
M<&AP.C4R"FUS9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I;G1E(&AI='1A(&5N('1E;7!RY'(@;6%P<"XB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ
M(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<BYP:'`Z.3<*(SH@;&EB+U9&
M4R])4T]7<FET97(N<&AP.CDQ"FUS9VED(")#86YN;W0@<')O8V5E9"!W:71H
M;W5T("=T87)G971&:6QE)R!P87)A;65T97(N(@IM<V=S='(@(DMA;B!I;G1E
M(&9O<G1SY'1T82!U=&%N("=MY6QF:6PG+7!A<F%M971E<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q-"!L:6(O5D93+V9T<"YP:'`Z,S$Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RXB
M"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP.C$R."!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*(SH@;&EB+TAO
M<F1E+T1A=&%4<F5E+G!H<#HQ,C@@;&EB+TAO<F1E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C@P"B,L('!H<"UF;W)M870*;7-G:60@(D-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R(")+86X@:6YT92!R861E<F$[("5D
M(&)A<FX@97AI<W1E<F%R+B(*"B,Z(&9R86UE=V]R:R]$871A5')E92]$871A
M5')E92]S<6PN<&AP.C8P."!L:6(O2&]R9&4O1&%T851R964O<W%L+G!H<#HV
M,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE
M<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@
M(@HB<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#D*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#D*;7-G:60@(D-A;FYO="!R;W5T92!M97-S
M86=E('1O('-P96-I9FEE9"!N=6UB97(N(@IM<V=S='(@(DMA;B!I;G1E(&1I
M<FEG97)A(&UE9&1E;&%N9&4@=&EL;"!A;F=I=F5T(&YU;6UE<BXB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-C@*;7-G:60@(D-A<&4@5F5R9&4B"FUS9W-T<B`B2V%P(%9E<F1E(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR
M-`IM<V=I9"`B0V%P=&EO;B(*;7-G<W1R(")2=6)R:6LB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O9V5N97)I8U]S;71P+G!H<#HQ,#0@;&EB+TYE="]3
M35,O9V5N97)I8U]S;71P+G!H<#HQ,#0*;7-G:60@(D-A<G)I97(B"FUS9W-T
M<B`B3W!E<F%T]G(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3,*;7-G
M:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R:65R
M(&]C:"!R=6)R:6ME<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4P(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@V"FUS9VED(")#87EM86X@27-L86YD
M<R(*;7-G<W1R(")#87EM86X@27-L86YD<R(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.30*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ.30*;7-G:60@(D-E;&P@4&AO;F4B"FUS9W-T
M<B`B36]B:6QT96QE9F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-0IM<V=I9"`B0V5L;"!0<F]P97)T:65S
M(@IM<V=S='(@(D-E;&QI;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,30*;7-G:60@(D-E;&P@<&%D
M9&EN9SHB"FUS9W-T<B`B0V5L;'5T9GEL;&YA9#HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#
M96QL('!R;W!E<G1I97,B"FUS9W-T<B`B0V5L;&EN<W3D;&QN:6YG87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,@IM
M<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R(")#96QL;65L;&%N<G5M.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-S0@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-S@*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")-;V)I;'1E
M;&5F;VXB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,0IM<V=I9"`B0V5L
M=&EC("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B0V5L=&ES:R`H25-/+3@X-3DM
M,30I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR-@IM<V=I9"`B0V5N=&5R(@IM<V=S='(@(D-E;G1R97)A9"(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-C4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4T"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HU,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HV-0IM<V=I9"`B0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC(@IM<V=S
M='(@(D-E;G1R86QA9G)I:V%N<VMA(')E<'5B;&EK96XB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X,@IM<V=I9"`B0V5N=')A;"!%=7)O<&5A;B`H25-/
M+3@X-3DM,BDB"FUS9W-T<B`B0V5N=')A;&5U<F]P96ES:R`H25-/+3@X-3DM
M,BDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,`IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")#97)T:69I:V%T9&5T86QJ97(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,2!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.C8Q,@IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B
M"FUS9W-T<B`B0V5R=&EF:6MA=.1G87)E(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU.38@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU.3<*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM<V=S='(@(D-E
M<G1I9FEK871P;VQI8VEE<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C(Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,C(Q"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HU
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(D-H860B"FUS
M9W-T<B`B5&-H860B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C4Y-@IM<V=I9"`B0VAA:7(@4&5R<V]N(@IM<V=S='(@
M(D]R9&;V<F%N9&4B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M,C0@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDV"FUS9VED(")#:&%N
M9V4B"FUS9W-T<B`BQ&YD<F$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R
M9"YP:'`Z,S$*;7-G:60@(D-H86YG92!9;W5R(%!A<W-W;W)D(@IM<V=S='(@
M(L1N9')A(&1I='0@;/9S96YO<F0B"@HC.B!T96UP;&%T97,O<')E9G,O8VAA
M;F=E9&5F875L=&ED96YT:71Y+FEN8SHQ,PIM<V=I9"`B0VAA;F=E(&1E9F%U
M;'0@:61E;G1I='DB"FUS9W-T<B`BQ&YD<F$@9O9R=F%L9"!I9&5N=&ET970B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-CD*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R
M("(B"B+$;F1R82!N86UN(&]C:"!A9')E<W,@<V]M(&UO='1A9V%R;F$@<V5R
M(&[D<B!D92!LY'-E<B!O8V@@<W9A<F%R('#E(&1I;F$@(@HB;65D9&5L86YD
M96XN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C(T"FUS9VED
M("(B"B)#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@
M=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@(@HB0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*(D%T="!B>71A(&SV<V5N
M;W)D('-T]F1S(&EN=&4@;65D(&1E;B!N=79A<F%N9&4@:V]N9FEG=7)A=&EO
M;F5N+B`@5F%R(&=O9"`B"B)K;VYT86MT82!A9&UI;FES=')A=/9R96XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHR-PIM<V=I9"`B0VAA<B(*;7-G<W1R(")4:VXB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C4*;7-G:60@
M(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(DMO;G1R;VQL97)A(&SD;FLN+BXB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]T;W`N:6YC.C$S
M"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO
M=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+B(*;7-G<W1R(")-87)K
M97)A(&1E(&%K=&EV:71E=&5R(&1U('9I;&P@=71F]G)A(&YU+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C4Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HU,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV
M-PIM<V=I9"`B0VAI;&4B"FUS9W-T<B`B0VAI;&4B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HV,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@
M(D-H:6YA(@IM<V=S='(@(DMI;F$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,PIM<V=I9"`B0VAI;F5S92!3:6UP;&EF:65D("A'0C(S,3(I(@IM<V=S
M='(@(DMI;F5S:7-K="!F]G)E;FML870@*$=",C,Q,BDB"@HC.B!C;VYF:6<O
M;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2DB"FUS9W-T<B`B2VEN97-I<VMT('1R861I=&EO;F5L;'0@*$)I9S4I
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z-PIM<V=I9"`B0VAO;W-E
M($%P<&QI8V%T:6]N.B(*;7-G<W1R(")6Y&QJ(&%P<&QI:V%T:6]N.B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD@;&EB+TAO<F1E
M+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(D-H;V]S92!A('!A<W-W;W)D
M(@IM<V=S='(@(E;D;&H@;/9S96YO<F0B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8X(&QI8B](;W)D92]!=71H+U-I9VYU<"YP:'`Z
M,C8Y"FUS9VED(")#:&]O<V4@82!U<V5R;F%M92(*;7-G<W1R(")6Y&QJ(&%N
M=N1N9&%R;F%M;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-#4R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-C(V"FUS9VED(")#:&]O<V4@86X@86-T:6]N.B(*
M;7-G<W1R(")6Y&QJ(.5T9^1R9#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S`R"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM
M<V=S='(@(E;D;&H@:'5R(&1A='5M('-K86QL('9I<V%S.B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C(*
M;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*2(*;7-G<W1R(")6Y&QJ(&QI<W1S=&EL("AF]G(@<V]R=&5R861E(&QI
M<W1O<BDB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8X(&QI8B](;W)D92].3%,O=&QD+G!H<#HV-@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-34@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-C@*;7-G:60@(D-H<FES=&UA<R!)<VQA;F0B"FUS9W-T
M<B`B2G5L]FXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,N<&AP.C(Y-"!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#DT(&QI8B]61E,N<&AP.CDQ-`HC.B!L
M:6(O3F5T+U--4RYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(D-L87-S
M(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R(")+;&%S<V1E
M9FEN:71I;VX@9O9R("5S('-A:VYA<RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B"FUS9W-T<B`B
M4F5N<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0R"FUS9VED(")#;&5A<B!-4T]F9FEC92!T86=S(@IM<V=S='(@(E)E
M;G-A($U33V9F:6-E+71A9V=A<B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C@*;7-G:60@(D-L96%R(%%U97)Y(@IM<V=S='(@(E)E;G-A(&9RY6=A(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(E)E;G-A
M(&%N=N1N9&%R93H@)7,B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A
M<BYI;F,Z,3$*;7-G:60@(D-L96%R('5S97(B"FUS9W-T<B`B4F5N<V$@86YV
MY&1N87)E(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*
M;7-G:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")296YS82!A;G;D;F1A
M<F1A=&$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HQ-0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R(")396YA<F4@=7!P
M:VQA<FYA;F1E(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC95]B
M;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA
M;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S='(@
M(DML:6-K82!F]G(@871T(&9O<G1SY'1T82(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V
M:6$@2%144"(*;7-G<W1R(")#;&EC:V%T96QL('9I82!(5%10(@H*(SH@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$T-B!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$R"FUS9VED(")#;&]S92!7:6YD;W<B"FUS9W-T<B`B4W3D;F<@9O9N
M<W1E<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4Q"FUS9VED(")#;&]U
M9',B"FUS9W-T<B`B36]L;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C$V"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B
M5&ED:6=A(&UO;&XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HQ-PIM<V=I9"`B0VQO=61Y(@IM<V=S='(@(DUO;&YI;F=T(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3(*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4V(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8T"FUS9VED(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*;7-G<W1R
M(")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(*"B,Z('1E;7!L871E<R]P;W)T
M86PO<VED96)A<BYI;F,Z,C,*;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS
M9W-T<B`B2V]M<')I;65R82!S:61O9N1L=&5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L
M;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`B2V]M<')I;65R861E(')A;6%R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HV-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-C(*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C4W(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C8W"FUS9VED(")#;VQO;6)I82(*;7-G<W1R(")+;VQO;6)I82(*"B,Z
M(&QI8B]";&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR
M.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Y"FUS9VED(")#;VQO<B(*;7-G<W1R(")&Y')G(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C,R,PHC.B!F<F%M97=O
M<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-S4@;&EB+TAO<F1E+T)L
M;V-K+T-O;&QE8W1I;VXN<&AP.C,S,0HC.B!L:6(O2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`Z,S,R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HU,#,*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HQ
M-`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M.0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHU
M,`HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV
M-@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHX
M,@IM<V=I9"`B0V]L;W(@4&EC:V5R(@IM<V=S='(@(D;D<F=H86YT97)A<F4B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V(&QI8B](;W)D92]&
M;W)M+G!H<#HR.#,R"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@
M(D;D<F=V86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`B2V]L=6UN97(Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3DU,`IM<V=I9"`B0V]L=6UN('1I=&QE<R(*;7-G<W1R(")+;VQU
M;6X@<G5B<FEK97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8V
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B3'5S=&EG:&5T97(B"@HC.B!A9&UI
M;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O;6UA;F0B"FUS9W-T<B`B2V]M
M;6%N9&\B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*;7-G:60@(D-O;6UA
M;F0@4VAE;&PB"FUS9W-T<B`B2V]M;6%N9&]F]FYS=&5R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`R(&QI8B](;W)D92]#<GEP="]P
M9W`N<&AP.C0Q,PIM<V=I9"`B0V]M;65N="(*;7-G<W1R(")+;VUM96YT87(B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-B!L:6(O
M2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V-PIM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`B3F%M;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3@*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HQ,S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C4X(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")#;VUO<F]S(@IM<V=S
M='(@(D-O;6]R;W,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,C,Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,C,Y"FUS9VED(")#;VUP86YY(@IM<V=S='(@(D;V<F5T86<B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y-PIM
M<V=I9"`B0V]M<&QE=&5D(@IM<V=S='(@(E-L=71F]G)D(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@Q"B,Z(&9R86UE
M=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HX-PHC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.3<*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C$P,0HC.B!F
M<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]E;6%I;',N<&AP.C@R"B,Z(&9R
M86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+V5M86EL<RYP:'`Z.#@*(SH@9G)A
M;65W;W)K+U1E>'0O5&5X="]&:6QT97(O96UA:6QS+G!H<#HY.`HC.B!F<F%M
M97=O<FLO5&5X="]497AT+T9I;'1E<B]E;6%I;',N<&AP.C$P,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*;7-G<W1R(")3
M:W)I=B!M961D96QA;F1E("@E<RDB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z,S$*;7-G:60@(D-O;7!U=&5R<R(*;7-G<W1R(")$871O<F5R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(X-@IM<V=I9"`B0V]N9&ET
M:6]N(@IM<V=S='(@(E;D9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-38*;7-G:60@(D-O;F1I=&EO;G,B"FUS9W-T<B`B5N1D97(B"@HC.B!A9&UI
M;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<R(*;7-G<W1R(")+;VYF:6=U<F%T:6]N<W-K:6QL;F%D97(B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T
M:6]N(&9O<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U
M=&QO;VLN(@IM<V=S='(@(B(*(DEN<W3D;&QN:6YG87(@9O9R(&%T="!S>6YK
M<F]N:7-E<F$@;65D(&AA;F1D871O<F5R+"!S;6%R=&$@=&5L969O;F5R(&]C
M:"`B"B)/=71L;V]K(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$S-0IM
M<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92XB"FUS9W-T<B`B
M2V]N9FEG=7)A=&EO;B!B96CV=F5R('5P<&1A=&5R87,N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;VYF
M:6=U<F4@)7,B"FUS9W-T<B`B2V]N9FEG=7)E<F$@)7,B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED(")#;VYF:7)M(%!A
M<W-W;W)D(@IM<V=S='(@(D)E:W+D9G1A(&SV<V5N;W)D(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C4Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-34*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C4Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V"FUS
M9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C4@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C4S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HV,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B0V]N
M9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R(")+
M;VYG;R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C$Y.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M,3`@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T
M:6]N(&9A:6QE9"XB"FUS9W-T<B`B1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S
M+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y-PHC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`X"FUS9VED(")#;VYN96-T:6]N
M(&9A:6QE9#H@(@IM<V=S='(@(D;V<F)I;F1E;'-E(&UI<W-L>6-K861E<SH@
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S<Y(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")&]G)B:6YD
M96QS92!M960@<'5B;&EK(&YY8VME;'-E<G9E<B!N96MA9&5S+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<X,2!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HW.3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO
M;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S
M("@E<RDB"FUS9W-T<B`B1O9R8FEN9&5L<V4@;65D('!U8FQI:R!N>6-K96QS
M97)V97(@;F5K861E<SH@)7,@*"5S*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#0U(&QI8B]61E,O9G1P+G!H<#HX-S8*;7-G:60@(D-O;FYE
M8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N(@IM<V=S='(@(D;V<F)I;F1E
M;'-E(&UE9"!&5%`M<V5R=F5R(&UI<W-L>6-K861E<RXB"@HC.B!C;VYF:6<O
M:&]O:W,N<&AP+F1I<W0Z,3`V-PIM<V=I9"`B0V]N=&%C=',B"FUS9W-T<B`B
M2V]N=&%K=&5R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C4S(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-3,*
M;7-G:60@(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+B(*;7-G<W1R(")+;VYT86MT97(@;&%D97,@=&EL
M;"!I(&1I;B!A9')E<W-B;VLN(@H*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R
M+W1G>BYP:'`Z-C`*;7-G:60@(D-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D
M(&9I;&4Z("(*;7-G<W1R("));FYE:.5L;'-T>7`@9O9R(&MO;7!R:6UE<F%D
M(&9I;#H@(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8P"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@@;&EB+TAO
M<F1E+TU)344O5FEE=V5R+W)A<BYP:'`Z-38*(SH@;&EB+TAO<F1E+TU)344O
M5FEE=V5R+WII<"YP:'`Z-C,@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP
M:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB
M(@IM<V=S='(@(DEN;F5HY6QL(&D@)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T
M<&%S<W=O<F0N<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS
M,PIM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`B1F]R='/D='0B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V(&QI8B](;W)D92].3%,O=&QD+G!H<#HU.`HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R(")#;V]K($ES;&%N9',B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S(*;7-G:60@(D-O;VMI92(*;7-G
M<W1R(")#;V]K:64B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C$*;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P
M:65R82(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#8X(&QI8B]6
M1E,O<VUB+G!H<#HT-S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL
M960Z("5S(@IM<V=S='(@(DMO<&EE<FEN9R!M:7-S;'EC:V%D97,Z("5S(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-@IM
M<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B2V]P:65R82!M87)K97)I
M;F<B"@HC.B!C;VYF:6<O=&AE;65S+V-O<FYF;&]W97(N<&AP.C8*;7-G:60@
M(D-O<FYF;&]W97(B"FUS9W-T<B`B36%J<V)L;VUM82(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3<P"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,3DU(&QI8B].970O4TU3+W=I;E]H
M='1P+G!H<#HQ-S`*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C$Y-0IM
M<V=I9"`B0V]S="!)1"(*;7-G<W1R(")+;W-T;F%D<RU)1"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HV,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8S"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV-PIM
M<V=I9"`B0V]S=&$@4FEC82(*;7-G<W1R(")#;W-T82!2:6-A(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-3<*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8V
M"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D5L9F5N8F5N<VMU<W1E
M;B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.CDU-@IM<V=I
M9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S='(@(DMA
M;B!I;G1E(%!'4"UK<GEP=&5R82!M961D96QA;F1E+B(*"B,Z(&QI8B](;W)D
M92]#<GEP="]P9W`N<&AP.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R
M>7!T(&UE<W-A9V4Z("(*;7-G<W1R(")+86X@:6YT92!01U`M:W)Y<'1E<F$@
M;65D9&5L86YD93H@(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3`S,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4N(@IM
M<V=S='(@(DMA;B!I;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4N(@H*(SH@
M;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z,3`U-0IM<V=I9"`B0V]U;&0@;F]T
M(%!'4"!S:6=N(&UE<W-A9V4Z("(*;7-G<W1R(")+86X@:6YT92!01U`M<VEG
M;F5R82!M961D96QA;F1E.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C,Y,R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C,Y,PIM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N(@IM<V=S
M='(@(DMA;B!I;G1E(%,O34E-12UK<GEP=&5R82!M961D96QA;F1E+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W(&QI8B](;W)D
M92]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92XB"FUS9W-T<B`B2V%N(&EN=&4@4R]-24U%+7-I9VYE
M<F$@;65D9&5L86YD92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C$X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,3@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,B"FUS9W-T<B`B2V%N(&EN=&4@;.1G9V$@=&EL;"!K
M;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HY-B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC.B!L:6(O
M2&]R9&4O1W)O=7`O;&1A<"YP:'`Z.38@;&EB+TAO<F1E+T%U=&@O;&1A<"YP
M:'`Z,3(Q"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-3<*;7-G:60@(D-O
M=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R(")-:7-S;'EC
M:V%D97,@871T(&MO;G1A:W1A($Q$05`@<V5R=F5R+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C$W,PHC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,34V(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*;7-G:60@
M(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")+86X@:6YT
M92!V97)I9FEE<F$@:V]N=&]S86QD;RX@)7,B"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-#0Q"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BXB"FUS9W-T<B`B2W5N9&4@:6YT92!A;G-L=71A('1I;&P@3$1!
M4"US97)V97(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L('!H
M<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<
M(B5S7"(@=7-I;F<@1E10.B`E<R(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT
M82!S97)V97(@)R5S)R!V:6$@1E10.B`E<R(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,Z(&QI8B].970O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HS,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B2V%N(&EN=&4@<VMA<&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$Q,#4*;7-G:60@(D-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+B(*;7-G<W1R(")+86X@:6YT92!D
M96MR>7!T97)A(%!'4"UD871A+B(*"B,Z(&QI8B](;W)D92]#<GEP="]P9W`N
M<&AP.C$Q,C@*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B`B
M"FUS9W-T<B`B2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M9&%T83H@(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU,C(@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HU,C,*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+B(*;7-G<W1R(")+86X@:6YT92!D96MR>7!T97)A(%,O
M34E-12UD871A+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z,C0V"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<R(*;7-G<W1R(")+86X@:6YT92!R861E<F$@:V]N=&%K
M="X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,U-@HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M,S4V"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!D
M:7-T<FEB=71I;VYS;&ES=&$N("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z,S@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T
M92!S971U<"!U<&=R861E('-C<FEP="!<(B5S7"(N(@IM<V=S='(@(DMA;B!I
M;G1E(')A9&5R82!U<'!G<F%D97)I;F=S<V-R:7!T('1I;&PZ("5S+B(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.CDS.`HC.B!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C,X,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HY-3,*;7-G
M:60@(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I
M;"!A9&1R97-S+B(*;7-G<W1R(")+86X@:6YT92!B97-TY&UM82!M;W1T86=A
M<F5N<R!E4&]S="UA9')E<W,N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*(SH@;&EB+TYE="]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C(X,PIM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@:V]M
M<&QE='0@861R97-S8F]K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#DS"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT.3,*;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="XB"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@
M:V]M<&QE='0@9&ES=')I8G5T:6]N<VQI<W1A+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#0V"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A(&MO;7!L971T(&QI<W1A(/9V97(@
M9&ES=')I8G5T:6]N<VQI<W1O<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.`HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R
M871E9WDN<&AP.C@T"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`Z-C@*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDN<&AP.C@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@;&%D
M9&$@<W1R871E9VD@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7
M<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HV.0HC.B!F<F%M97=O<FLO
M5D937TE33R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C@U"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E
M<R<N(@IM<V=S='(@(DMA;B!I;G1E(&QA9&1A('-T<F%T96=I("<E<R<N(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P
M>2YP:'`Z,3$P"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]D:7)E8W0N<&AP.C,P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!M:V1I<B!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(&UA
M<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,3$Q"B,Z(&9R86UE=V]R:R]61E-?
M25-/+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDO9&ER96-T+G!H<#HS
M,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD:7(@)R5S)RXB
M"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@;6%P<"`G)7,G+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<P."!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HW,3D*;7-G:60@(D-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME
M>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(DMA;B!I;G1E(&CD;71A
M('!U8FQI:R!N>6-K96P@9G+E;B!N>6-K96QS97)V97)N+B(*"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2]C;W!Y+G!H<#HQ,SD*(SH@;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,3,Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N
M(&EN=&4@]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S0U"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C8R(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-S<*(SH@;&EB+TYE="]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS-#4@;&EB+TYE="]335,O=VEN7VAT='`N<&AP
M.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`E<RXB
M"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T
M,`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B`G)7,G(&9O
M<B!W<FET:6YG+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82`G)7,G(&;V<B!S
M:W)I=FEN9RXB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C0Q."!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C0R,`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<R(*;7-G<W1R(")+86X@:6YT92#V<'!N82!-86EN=&5N
M86YC95]487-K(&UO9'5L("5S(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,Z
M(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP
M.C<P"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(&1I<F5C
M=&]R>2!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(/9P<&YA(&UA<'!E;B`G
M)7,G(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R(")+86X@:6YT
M92#V<'!N82!M87!P("<E<R<B"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O
M;&1A<"YP:'`Z,3$Q(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ
M-#0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C(S-R!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#<X"B,Z(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HU,38@9G)A;65W;W)K+T=R;W5P+T=R;W5P
M+VQD87`N<&AP.C8Q,@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-C4V(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV.3D*(SH@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$Q,2!L:6(O2&]R9&4O1W)O=7`O
M;&1A<"YP:'`Z,30T"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HR,S<@
M;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C0W.`HC.B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-3$V(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HV,3(*
M(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C8U-B!L:6(O2&]R9&4O1W)O
M=7`O;&1A<"YP:'`Z-CDY"FUS9VED(")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(*;7-G<W1R(")+86X@:6YT92!K;VYT86MT82!,1$%0('-E
M<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S."!L
M:6(O5D93+T]B:F5C="YP:'`Z,C0P"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R96%D("5S+B(*;7-G<W1R(")+86X@:6YT92!LY'-A("5S+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C@U"FUS9VED("(B"B)#
M;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D
M('5S97(N(%-O;64@;W(@86QL(&]F('1H92`B"B)D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D("(*(F9U<G1H97(@:&5L<"XB"FUS9W-T<B`B(@HB
M1&5T(&=I8VL@:6YT92!A='0@Y71E<G-TY&QL82!L]G-E;F]R9&5T(&;V<B!D
M96X@86YG:79N82!A;G;D;F1A<F5N+B!.Y6=O;B`B"B)E;&QE<B!NY6=R82!A
M=B!U<'!G:69T97)N82#D<B!I;G1E(&MO<G)E:W1A+B!&]G)S]FL@:6=E;B!E
M;&QE<B!K;VYT86MT82`B"B)A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H]G9E
M<B!H:N1L<"XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HS,#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,S0P"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,W-PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M.#,*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@Y
M(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS,#<*(SH@;&EB+TAO
M<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S."!L:6(O2&]R9&4O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,S<U"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS.#$@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X
M-PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(")+86X@
M:6YT92!HY&UT82!!0TPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(W-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z,C<T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S(@IM<V=S='(@(DMA;B!I;G1E(&CD
M;71A(&%D<F5S<V)O:RX@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C0X-`HC.B!L:6(O3F5T+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B2V%N
M(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI<W1A+B`E<R(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-#,W"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M<RX@)7,B"FUS9W-T<B`B2V%N(&EN=&4@:.1M=&$@9&ES=')I8G5T:6]N<VQI
M<W1O<BX@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C(R,R!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,3DW"B,Z(&QI
M8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C(R,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")+86X@:6YT92!H
MY&UT82!D<V5R=F5R9G5N:W1I;VYE<B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I
M9RYP:'`Z-30*;7-G:60@(D-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO
M;BXB"FUS9W-T<B`B2V%N(&EN=&4@Y71E<G-TY&QL82!K;VYF:6=U<F%T:6]N
M96XN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,Z(&QI8B]61E,O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDT"B,L('!H<"UF;W)M
M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B!<(B5S7"(N(@IM<V=S='(@(DMA
M;B!I;G1E(')A9&5R82!M87!P("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])
M4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.CDU"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G
M<W1R(")+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+B(*"B,Z(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C<S"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD
M(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(DMA;B!I;G1E
M('-P87)A(&MO;F9I9W5R871I;VX@9O9R("5S+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU.0IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+B(*;7-G
M<W1R(")+86X@:6YT92!S<&%R82!B86-K=7`M:V]N9FEG=7)A=&EO;BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*
M;7-G<W1R(")+86X@:6YT92!S<&%R82!E;B!B86-K=7`M:V]N9FEG=7)A=&EO
M;CH@)7,N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.34*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@=&\Z(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<W!A<F$@=7!P
M9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C8T"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R
M(")+86X@:6YT92!S<&%R82!B86-K=7`M:V]N9FEG=7)A=&EO;B`E<RXB"@HC
M.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B(*(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@
M=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@
M=&AE(&-O9&4@8F5L;W<@=&\@)7,N(@IM<V=S='(@(B(*(DMA;B!I;G1E('-P
M87)A(&MO;F9I9W5R871I;VYS9FEL96X@)7,N($1U(&MA;B!A;G1I;F=E;B!A
M;G;D;F1A(&5N(&%V("(*(F%L=&5R;F%T:79E;B!A='0@<W!A<F$@:V]D96X@
M=&EL;"`E<R!E;&QE<B!K;W!I97)A(&MO9&5N(&YE9&%N('1I;&P@)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ-#,@;&EB+TAO<F1E
M+T%U=&@O;&1A<"YP:'`Z,30S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EN=&4@<_9K82!I($Q$05`M
M:V%T86QO9V5N+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC.B!L:6(O5D93
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HX-@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@=6YL:6YK(%PB)7-<(BXB"FUS
M9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T\O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@W
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@)R5S)RXB
M"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A("<E<R<N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR,3D*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S(@IM<V=S='(@(DMA
M;B!I;G1E('5P<&1A=&5R82!K;VYT86MT+B`E<R(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,SDV"B,Z(&QI8B].970O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS.38*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS
M9W-T<B`B2V%N(&EN=&4@=7!P9&%T97)A(&1I<W1R:6)U=&EO;G-L:7-T82X@
M)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-S`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R(%PB
M)7-<(CH@)7,B"FUS9W-T<B`B2V%N(&EN=&$@<W!A<F$@:V]N9FEG=7)A=&EO
M;B!F]G(@)R5S)SH@)7,B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<P
M"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R(")+86X@:6YT
M92!H:71T82!-;WII;&QA<R!S:61O9N1L="X@5F5R:69I97)A(&%T="!S:61O
M9N1L=&5T(.1R(/9P<&5T+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C$U-"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,34T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD;B=T(&=I=F4@
M=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD
M97(@7"(E<UPB.B`E<R(*;7-G<W1R(")+86X@:6YT92!G92!A;G;D;F1A<F5N
M("<E<R<@86YG:79N82!RY'1T:6=H971E<B!T:6QL(&UA<'!E;B`G)7,G.B`E
M<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$T,C,*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R(")2
MY&MN860@=&5X="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-38Y(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<P"FUS9VED(")#
M;W5N=')Y(@IM<V=S='(@(DQA;F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,C<U"FUS9VED(")#;W5R<V5S(@IM<V=S='(@(DMU<G-E<B(*"B,Z
M('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C$P,`IM<V=I9"`B0W)E871E(@IM<V=S='(@(E-K87!A(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8X
M"FUS9VED(")#<F5A=&4@82!L:6YK(@IM<V=S='(@(E-K87!A(&SD;FLB"@HC
M.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDT"FUS9VED
M(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(E-K87!A(&YY(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S0S,30N<&AP.C4R"B,Z(&QI8B](;W)D92])34%0+T%#
M3"]R9F,R,#@V+G!H<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM
M<V=S='(@(E-K87!A('5N9&5R;6%P<"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,C0P(&QI8B](;W)D92]097)M<R]522YP:'`Z,C0P"FUS
M9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(D)E:/9R:6=H971E
M<B!F]G(@Y&=A<F$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C,P
M(&QI8B](;W)D92]&;W)M+G!H<#HS,C$V"FUS9VED(")#<F5D:70@8V%R9"!N
M=6UB97(B"FUS9W-T<B`B2W)E9&ET:V]R='-N=6UM97(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$P.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C8T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HV-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW.0IM
M<V=I9"`B0W)O871I82(*;7-G<W1R(")+<F]A=&EE;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8T"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0W5B82(*;7-G<W1R(")+=6)A(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(V"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(D%K='5E;&QA
M(#0@9F%S97(B"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z-3`*;7-G:60@(D-U
M<G)E;G0@4V5S<VEO;G,B"FUS9W-T<B`B06MT=65L;"!S97-S:6]N(@H*(SH@
M;&EB+T)L;V-K+W1I;64N<&AP.C,@;&EB+T)L;V-K+W1I;64N<&AP.C,P"FUS
M9VED(")#=7)R96YT(%1I;64B"FUS9W-T<B`B06MT=65L;"!T:60B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-30*;7-G:60@(D-U<G)E;G0@55),(&ES(@IM<V=S='(@(D%K='5E;&P@55),
M(.1R(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,U"FUS9VED(")#=7)R96YT
M(%5S97)S(@IM<V=S='(@(D%K=&EV82!A;G;D;F1A<F4B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C(U"FUS9VED(")#=7)R96YT(%=E871H97(B"FUS9W-T
M<B`B06MT=65L;'0@=N1D97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8T"FUS9VED(")#=7)R96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@
M(D%K='5E;&QA('9I;&QK;W(Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,S(*;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS
M9W-T<B`B06MT=65L;"!S=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C$Q,0HC+"!P:'`M9F]R;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N(@IM<V=S='(@(E-K<N1D9&%R<WD@86MT
M:79I=&5T97(@<V]M(&OV<G,@=FED(&EN;&]G;FEN9R!T:6QL("5S+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(DML:7!P('5T(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B0W5T
M('-E;&5C=&EO;B(*;7-G<W1R(")+;&EP<"!U<G9A;"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C8W"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HV-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I
M9"`B0WEP<G5S(@IM<V=S='(@(D-Y<&5R;B(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3@U"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R(")+
M>7)I;&QI<VL@*$M/23@M4BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X
M-@IM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2WER
M:6QL:7-K("A7:6YD;W=S+3$R-3$I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#<*;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G
M<W1R(")+>7)I;&QI<VLO56MR86EN<VL@*$M/23@M52DB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HV.`HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G
M:60@(D-Z96-H(%)E<'5B;&EC(@IM<V=S='(@(E1J96-K:65N(@H*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R-@HC.B!L:6(O
M2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4R('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X
M('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C4P"FUS9VED(")$1"(*;7-G<W1R(")$1"(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,R.#`@;&EB+TAO<F1E+T9O<FTN<&AP.C,R
M-S8*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N
M=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E
M+G!H<#HU.2!L:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4Y"FUS9VED(")$
M86EL>2(*;7-G<W1R(")$86=L:6<B"@HC.B!A9&UI;B]D871A=')E92YP:'`Z
M-C4*;7-G:60@(D1A=&%4<F5E($)R;W=S97(B"FUS9W-T<B`B1&%T851R964@
M8FSD9&1R87)E(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(W."!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,S(W-`IM<V=I9"`B1&%T86)A<V4@3&]O:W5P
M(@IM<V=S='(@(D1A=&%B87-U<'!S;&%G(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F9C.#(R+G!H<#HW,B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,SDY"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-#`R(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED(")$871E(@IM<V=S
M='(@(D1A='5M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P<F]V92YI
M;F,Z,3,*;7-G:60@(D1A=&4@4F5C96EV960B"FUS9W-T<B`B1&%T=6T@;6]T
M=&%G970B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`W(&QI8B](
M;W)D92]&;W)M+G!H<#HR-SDS"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G
M<W1R(")$871U;79A;"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR.#$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B
M1&%Y(@IM<V=S='(@(D1A9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B7U)A9&5R82!K;VQU;6XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,C4*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#4Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(F1E8V5M
M8F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHQ-@IM<V=I9"`B1&5C:6UA;"!N=6UB97)S(@IM<V=S='(@
M(D1E8VEM86QE<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z-C@U"FUS9VED(")$96-L:6YE9"(*;7-G<W1R(")!=F+V
M:G0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS9W-T<B`B36EN<VMA(&EN
M9')A9R(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"B,Z(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,3@W
M"FUS9VED(")$969A=6QT(@IM<V=S='(@(D;V<G9A;'0B"@HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT-0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW-PIM<V=I9"`B1&5F
M875L="!#;VQO<B(*;7-G<W1R(")&]G)V86QD(&;D<F<B"@HC.B!F<F%M97=O
M<FLO261E;G1I='DO261E;G1I='DN<&AP.CDQ(&QI8B](;W)D92])9&5N=&ET
M>2YP:'`Z.38*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`B1O9R
M=F%L9"!I9&5N=&ET970B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*
M;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`B1O9R=F%L="!S:V%L(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S"FUS9VED(")$969I;FET:6]N
M<R(*;7-G<W1R(")$969I;FET:6]N97(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,PIM<V=I9"`B1&5L96=A=&4@
M<&]S:71I;VXB"FUS9W-T<B`B1&5L96=E<F$@<&]S:71I;VXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Y,PIM<V=I
M9"`B1&5L96=A=&5D(@IM<V=S='(@(D1E;&5G97)A9"(*"B,Z(&%D;6EN+V=R
M;W5P<RYP:'`Z-S$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C8*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C(@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,SD*(SH@9G)A;65W;W)K+TQI;FMS+TQI;FMS
M+G!H<#HR-C,*(SH@9G)A;65W;W)K+U)E;&%T:6]N<VAI<"]296QA=&EO;G-H
M:7!-86YA9V5R+G!H<#HR-3@@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C8*(SH@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C(@;&EB+TAO<F1E+U!E<FUS+U5)
M+G!H<#HT,SD*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-B!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C<P"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z.3,@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,38*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,SD@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.#(*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC
M.C<S('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY.`HC.B!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z,3`@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O;&ES="YI;F,Z,S$*;7-G:60@(D1E;&5T92(*;7-G<W1R(")2861E
M<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S(*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@(E)A9&5R
M82!C96QL(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3D@861M:6XO9W)O=7!S
M+G!H<#HR,C<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R(")2861E<F$@
M9W)U<'`B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*;7-G
M:60@(D1E;&5T92!,;V<B"FUS9W-T<B`B4F%D97)A(&QO9V<B"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,3`Q"B,Z(&QI8B](;W)D92]097)M<R]522YP:'`Z-S<@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#$*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED(")$96QE=&4@86YD('!U<F=E
M(&UE<W-A9V5S(@IM<V=S='(@(E)A9&5R82!O8V@@<F5N<V$@;65D9&5L86YD
M96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R(")2861E<F$@
M8V5L;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB"FUS9W-T<B`B4F%D
M97)A(&MO;'5M;B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30X"FUS9VED
M(")$96QE=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E(@IM<V=S='(@
M(E)A9&5R82!B969I;G1L:6<@86QT97)N871I=FUA;&PB"@HC.B!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-30*;7-G:60@(D1E;&5T92!M97-S
M86=E<R(*;7-G<W1R(")2861E<F%D92!M961D96QA;F1E;B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#(Q"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@7"(E<UPB(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(&;V
M<B`G)7,G(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C0@
M;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HT,C0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B1&5L971E('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(@86YD(&%N>2!S=6(M
M<&5R;6ES<VEO;G,_(@IM<V=S='(@(E)A9&5R82!B96CV<FEG:&5T(&;V<B`G
M)7,G(&]C:"!U;F1E<F)E:/9R:6=H971E<C\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE
M=&4@<F]W(@IM<V=S='(@(E)A9&5R82!R860B"@HC.B!T96UP;&%T97,O<')E
M9G,O9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T
M960@:61E;G1I='DB"FUS9W-T<B`B4F%D97)A('9A;&0@:61E;G1I=&5T(@H*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4S"FUS9VED(")$
M96QE=&4@<W5B(&9O;&1E<G,B"FUS9W-T<B`B4F%D97)A('5N9&5R;6%P<&%R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C8W"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM
M<V=S='(@(E)A9&5R82!A:W1U96QL(&MO;'5M;B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,PIM<V=I9"`B
M1&5L971E('1H92!C=7)R96YT(')O=R(*;7-G<W1R(")2861E<F$@86MT=65L
M;"!R860B"@HC.B!F<F%M97=O<FLO3&EN:W,O3&EN:W,N<&AP.C(V,PHC.B!F
M<F%M97=O<FLO4F5L871I;VYS:&EP+U)E;&%T:6]N<VAI<$UA;F%G97(N<&AP
M.C(U.`IM<V=I9"`B1&5L971E('1H:7,@;&EN:R(*;7-G<W1R(")2861E<F$@
M9&5N(&CD<B!LY&YK96XB"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS
M-@HC+"!P:'`M9F]R;6%T"FUS9VED(")$96QE=&5D('-E='5P('5P9W)A9&4@
M<V-R:7!T(%PB)7-<(BXB"FUS9W-T<B`B4F%D97)A9&4@=7!P9W)A9&5R:6YG
M<W-C<FEP=&5T("<E<R<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU-C,*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<#HU.34*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U,PHC.B!L:6(O3F5T+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-38S(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HR,C$@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*
M;7-G:60@(D1E;&EV97)Y('1I;64B"FUS9W-T<B`B3&5V97)A;G-T:60B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HW,0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1E;FUA<FLB"FUS9W-T<B`B1&%N;6%R:R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C0R"FUS
M9VED(")$96YY(')E<75E<W0B"FUS9W-T<B`B079S;.4@8F5GY')A;B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<Q
M"FUS9VED(")$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;B(*;7-G<W1R(")!=G-LY2!B96?D<F%N(&]M(&QE9&EG+W5P<'1A9V5N+6EN
M9F]R;6%T:6]N(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z
M,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(D)E<VMR
M:78@<')O8FQE;65T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU-C4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3,X
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HY-#(@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I
M;VXB"FUS9W-T<B`B0F5S:W)I=FYI;F<B"@HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$Y-2!L:6(O2&]R9&4N<&AP.C$Y-PIM<V=I9"`B1&5T86EL
M<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R(")$971A;&IE
M<B`H;V-K<^4@:2!(;W)D97,@;&]G9V9I;"DZ(@H*(SH@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HQ.3D@;&EB+TAO<F1E+G!H<#HR,#$*;7-G:60@(D1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M(@IM<V=S='(@(D1E=&%L:F5R(&AA<B!L;V=G871S(&;V<B!S>7-T96UA9&UI
M;FES=')A=/9R96XN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R
M,0IM<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B571V96-K;&EN9R(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,C(T"FUS9VED(")$97<@4&]I;G0B"FUS
M9W-T<B`B1&%G9W!U;FMT(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#$*
M;7-G:60@(D1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B1&%G
M9W!U;FMT(&;V<B!S96YA<W1E('1I;6UE;CH@(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q-@IM<V=I9"`B1&5W('!O:6YT.B`B"FUS9W-T
M<B`B1&%G9W!U;FMT.B`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C,X"FUS9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M="(*;7-G<W1R(")2:6MT;FEN9R!VY&YS=&5R('1I;&P@:/9G97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED
M(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R(")2:6MT;FEN9R!H
M]F=E<B!T:6QL(';D;G-T97(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@(DMA=&%L;V<B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,C<P"FUS9VED(")$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_(@IM<V=S='(@(E9I<V$@,C0M=&EM;6%R<R!K;&]C:V$_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P,`IM<V=I9"`B1&ES<&QA>2!/<'1I
M;VYS(@IM<V=S='(@(E9I<VYI;F=S:6YS=.1L;&YI;F=A<B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HX.0IM<V=I9"`B1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S="(*;7-G<W1R(")6:7-A(&1E=&%L:F5R860@9O9R=71S
MY&=E;'-E(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HY,@IM<V=I9"`B1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R(")6:7-A(&;V<G5T<^1G96QS
M92`H5$%&*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<@;&EB
M+TAO<F1E+T9O<FTN<&AP.C(X,#,*;7-G:60@(D1I<W!L87D@9F]R;6%T(@IM
M<V=S='(@(E9I<VYI;F=S9F]R;6%T(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]-1$XN<&AP.C$Y,"!L:6(O2&]R9&4O34E-12]-1$XN<&AP.C$Y,0IM<V=I
M9"`B1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]D:79I9&5R+G!H<#HT(&QI8B]";&]C:R]D:79I9&5R+G!H<#HT
M-0IM<V=I9"`B1&EV:61E<B(*;7-G<W1R(")!=G-K:6QJ87)E(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C8Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C8Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y
M"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")$:FEB;W5T:2(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-#(R"FUS9VED(")$;R!N;W0@9&5L971E(@IM<V=S='(@(E)A9&5R
M82!I;G1E(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(U"FUS9VED
M(")$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G
M<W1R(")!;G;D;F0@:6YT92!M86EN=&5N86YC92YP:'`@9&ER96MT(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O
M8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT
M86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB
M"FUS9W-T<B`B26YN96CE;&QE<B!F]G)S=&$@<F%D96X@9N1L=&YA;6YE;C\@
M3VT@)VIA)RP@;6%R:V5R82!HY'(Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<P
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z-S(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C<P(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HW,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-S$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI
M8R(*;7-G<W1R(")$;VUI;FEK86YS:V$@<F5P=6)L:6ME;B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G:60@(D1O;B=T(&AA=F4@86X@
M86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B2&%R(&1U(&EN9V5T(&MO;G1O
M/R!296=I<W1R97)A(&1I9RXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O
M;G1E;G1S+G!H<#HX-#,@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C@U
M,@IM<V=I9"`B1&]W;FQO860B"FUS9W-T<B`B2.1M=&$B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX-#,@;&EB+TAO<F1E+TU)344O
M0V]N=&5N=',N<&AP.C@U,@HC+"!P:'`M9F]R;6%T"FUS9VED(")$;W=N;&]A
M9"`E<R(*;7-G<W1R(")(Y&UT82`E<R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(DCD;71A(&=E;F5R97)A9"!K
M;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q,#<@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q,3$*;7-G
M:60@(D1R;W`@9&]W;B!L:7-T(@IM<V=S='(@(D1R;W!P;&ES=&$B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@
M(D1R;V=E<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P
M,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*
M;7-G<W1R(")%+7!O<W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N
M97)I8U]S;71P+G!H<#HY,B!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP
M.CDR"FUS9VED(")%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92XB"FUS9W-T<B`B
M(@HB1')I=G)U=&EN(&;V<B!%+7!O<W0@=&EL;"!335,M8G)Y9V=A.R!F]G(@
M;W!E<F%T]G)E<B!S;VT@=&EL;&AA;F1A:.5L;&5R("(*(F1E;FYA('1JY&YS
M="XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],
M:7-T96YE<B]M;V)I;&4N<&AP.C,T"B,Z(&QI8B](;W)D92].;W1I9FEC871I
M;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-`IM<V=I9"`B15)2(@IM<V=S='(@
M(D9%3"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S4@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<U"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HW,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R(")%:W5A9&]R
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@;&EB+TAO<F1E
M+U!E<FUS+G!H<#HS,C4*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS
M-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8Y"B,Z('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z.3(@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M,34*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ.#$*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S
M=6TN:6YC.C<R"FUS9VED(")%9&ET(@IM<V=S='(@(L1N9')A(@H*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H<#HU,"!L:6(O2&]R9&4O0FQO8VLO
M54DN<&AP.C4P"FUS9VED(")%9&ET($)L;V-K(@IM<V=S='(@(L1N9')A(&)L
M;V-K(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.3@@861M:6XO9W)O=7!S+G!H
M<#HR,C8*;7-G:60@(D5D:70@1W)O=7`B"FUS9W-T<B`BQ&YD<F$@9W)U<'`B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C<V(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,3`P"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z-S8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ,#`*;7-G:60@(D5D
M:70@4&5R;6ES<VEO;B(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M
M:7-S:6]N<R(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T97(B"@HC.B!S97)V
M:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M870*;7-G:60@
M(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(L1N9')A(&)E:/9R
M:6=H971E<B!F]G(@)7,B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHU
M"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R("+$;F1R82!I;G-T
MY&QL;FEN9V%R(&;V<CHB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C,V-R!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T
M<B`BQ&YD<F$@8F5H]G)I9VAE=&5R(&;V<B`G)7,G(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("+$;F1R82!B96CV<FEG:&5T
M97(@9O9R("<E<R<B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*;7-G
M:60@(D5D=6-A=&EO;B(*;7-G<W1R(")5=&)I;&1N:6YG(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z-S<*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C<S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS
M9VED(")%9WEP="(*;7-G<W1R(")%9WEP=&5N(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`W(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,3<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C<T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM<V=I
M9"`B16P@4V%L=F%D;W(B"FUS9W-T<B`B16P@4V%L=F%D;W(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#,*
M;7-G:60@(D5L96UE;G0N+BXB"FUS9W-T<B`B16QE;65N="XN+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Y"FUS9VED
M(")%;2(*;7-G<W1R(")%;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W9C87)D+G!H<#HR,C0@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V
M.0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@W,R!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(R-`IM<V=I9"`B16UA:6PB"FUS9W-T<B`B12UP
M;W-T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-C4@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-C8*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHQ,"!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8X"FUS9VED(")%;6%I;"!!9&1R97-S(@IM<V=S='(@(D4M
M<&]S=&%D<F5S<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y-C,@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-C<*;7-G:60@(D5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+B(*;7-G<W1R(")%+7!O<W1A9')E<W-E<B!MY7-T92!S
M=.1M;6$@]G9E<G)E;G,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DX.2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DY,PIM<V=I9"`B16UA:6P@=VET
M:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B12UP;W-T;65D9&5L86YD92!M960@
M8F5K<N1F=&5L<V4B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,2!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.CDQ
M"FUS9VED(")%;6%I;"UT;RU335,@1V%T97=A>2(*;7-G<W1R(")%+7!O<W0@
M=&EL;"!335,M8G)Y9V=A(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(X,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,CDY"FUS9VED(")%;6]T:6-O;G,B"FUS9W-T<B`B2^1N<VQO
M:6MO;F5R(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R(")4;VUT(&UE
M9&1E;&%N9&4N(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#@T"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@9G)A;65W;W)K+T=R
M;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VQD87`N<&AP.C$U,"!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,C0S"B,Z
M(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HT.#0@;&EB+TAO<F1E+T=R;W5P
M+VQD87`N<&AP.C8V,@HC.B!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-S`U
M(&QI8B](;W)D92]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S
M=6QT+B(*;7-G<W1R(")4;VUT(')E<W5L=&%T+B(*"B,Z(&9R86UE=V]R:R]3
M44PO4U%,+TME>7=O<F1S+G!H<#HQ,3,@;&EB+TAO<F1E+U-13"]+97EW;W)D
M<RYP:'`Z,3$S"FUS9VED(")%;7!T>2!S96%R8V@@=&5R;7,B"FUS9W-T<B`B
M5&]M="!S]FMK<FET97)I82(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU
M-#<*;7-G:60@(D5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO
M=&\@1V%L;&5R:65S(&EN('1E>'0_(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HU,C(*;7-G:60@(D5N86)L92!R:6=H="!C;&EC:R!C
M;VYT97AT(&UE;G4_(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0X"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-34S"FUS9VED(")%;F0B"FUS
M9W-T<B`B4VQU="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@Q,0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4Y,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-PIM<V=I9"`B16YD
M('EE87(B"FUS9W-T<B`B4VQU="#E<B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(D;V<G-T;W)A(&5D:71O<B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HR,C0*;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B`B"B)P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C(*;7-G:60@(D5N
M=&5R('1H92!I;6%G92!54DP@:&5R92(*;7-G<W1R(")!;F=E('/V:W;D9R`H
M55),*2!T:6QL(&)I;&1E;B!HY'(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z.#8S"B,Z(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HX.3(*;7-G:60@(D5N=&5R('1H92!L971T97)S(&)E
M;&]W.B(*;7-G<W1R(")32W)I=B!B;VMS=.1V97)N82!N961A;CHB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDY(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D5Q=6%T;W)I86P@1W5I;F5A(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-SD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<Y"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HW-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(W
M"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HR-PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+U9I97<N<&AP.CDT(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT.`HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,V"FUS9VED(")%<G)O<B(*;7-G<W1R(")&96PB"@HC.B!F<F%M
M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C0V,R!L:6(O2&]R9&4O5&5M
M<&QA=&4N<&AP.C0V,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!C<F5A
M=&EN9R!B;&]C:SH@)7,B"FUS9W-T<B`B1F5L('9I9"!S:V%P86YD92!A=B!B
M;&]C:SH@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HW,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO
M<CH@)7,B"FUS9W-T<B`B1F5L('9I9"!R861E<FEN9R!A=B!S>6YK<F]N:7-E
M<FEN9W-MY')K93H@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&QO9SH@)7,B"FUS9W-T<B`B1F5L('9I9"!R861E<FEN9R!A=B!S>6YK<F]N
M:7-E<FEN9W-L;V=G.B`E<R(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z-#8X(&QI8B](;W)D92]496UP;&%T92YP:'`Z-#8X"B,L('!H
M<"UF;W)M870*;7-G:60@(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B"FUS
M9W-T<B`B1F5L(&[D<B!I;FYE:.5L(&CD;71A9&5S.B`E<R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DU"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C<X"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0W
M"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R('-E;F1I;F<@<F5P;'DZ("5S
M+B(*;7-G<W1R(")&96P@=6YD97(@<^1N9&YI;F<@878@<W9A<G-M961D96QA
M;F1E.B`E<R(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HW-@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,B"FUS9W-T<B`B1F5L('9I9"!U<'!D871E<FEN9R!A=B!L]G-E;F]R9#H@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#4*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,@HC.B!L:6(O5D93+TE33U=R:71E
M<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ-#(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B17)R;W(@=W)I=&EN9R!<(B5S7"(N(@IM<V=S='(@(D9E;"!V
M:60@<VMR:79N:6YG("<E<R<N(@H*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/
M5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")%<G)O<B!W<FET:6YG("<E<R<N(@IM<V=S='(@(D9E
M;"!V:60@<VMR:79N:6YG(&%V("<E<R<N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,"!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z-S8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C<W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<P"FUS9VED(")%<W1O
M;FEA(@IM<V=S='(@(D5S=&QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HX,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-S@@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA
M(@IM<V=S='(@(D5T:6]P:65N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`B171N:7-K(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C4U"FUS9VED(")%=7)O<&4B"FUS9W-T<B`B175R;W!A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,T,PIM<V=I9"`B179E<GD@,34@;6EN=71E
M<R(*;7-G<W1R(")687(@,34Z92!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS.3,*;7-G:60@(D5V97)Y(#(@;6EN=71E<R(*;7-G<W1R(")6
M87)A;FYA;B!M:6YU="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B179E<GD@,S`@<V5C
M;VYD<R(*;7-G<W1R(")687(@,S`Z92!S96MU;F0B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,S0R(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.30*;7-G
M:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")687(@-3IE(&UI;G5T(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HV,"!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C8P"FUS9VED(")%=F5R>2!,;V=I
M;B(*;7-G<W1R(")687)J92!I;FQO9V=N:6YG(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,T-`IM<V=I9"`B179E<GD@:&%L9B!H;W5R(@IM<V=S='(@
M(E9A<FIE(&AA;'9T:6UM92(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-#$@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,@IM<V=I9"`B179E<GD@;6EN
M=71E(@IM<V=S='(@(E9A<FIE(&UI;G5T(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T96UA<"YI;F,Z,C0*;7-G:60@(D5X86UP;&4@=F%L=65S.B(*;7-G<W1R
M(")%>&5M<&5L('#E(';D<F1E;CHB"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M.#$@861M:6XO8VUD<VAE;&PN<&AP.C4P(&%D;6EN+W-Q;'-H96QL+G!H<#HQ
M,C<*;7-G:60@(D5X96-U=&4B"FUS9W-T<B`B2_9R(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#<U(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C0W-0HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP.C8Q-`IM<V=I9"`B17AP86YD(@IM<V=S='(@(D5X<&%N9&5R82(*
M"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z,S(*;7-G:60@(D5X
M<&%N9"!3:61E8F%R(@IM<V=S='(@(D5X<&%N9&5R82!S:61O9N1L="(*"B,Z
M(&9R86UE=V]R:R]344PO4U%,+TME>7=O<F1S+G!H<#HQ-C@@;&EB+TAO<F1E
M+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G*2<B"FUS
M9W-T<B`B1O9R=N1N=&%D92`G*2<B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z,3<U(&QI8B](;W)D92]344PO2V5Y=V]R9',N<&AP.C$W
M-0IM<V=I9"`B17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@
M=&5R;2(*;7-G<W1R(")&]G)VY&YT861E(&5N<VMI;'0@;W)D(&5L;&5R(&-I
M=&5R870@<_9K8F5G<F5P<"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0P,2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@
M(D5X<&ER871I;VX@1&%T92(*;7-G<W1R(")&]G)F86QL;V1A='5M(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8@;&EB+TAO<F1E
M+T-R>7!T+W-M:6UE+G!H<#HV-S<*;7-G:60@(D5X<&]N96YT(@IM<V=S='(@
M(D5X<&]N96YT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`B1O9R
M9W)U;F1S9N1R9R(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S<*;7-G
M:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`B3&%D9&$@=7!P(&MO
M;F9I9W5R871I;VX@=FEA($944"XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E
M9G,O<W%L+G!H<#HR,38@;&EB+TAO<F1E+U!R969S+W-Q;"YP:'`Z,C(U"FUS
M9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB"FUS9W-T<B`B
M36ES<VQY8VMA9&5S(&%T="!HY&UT82!I;G-TY&QL;FEN9V%R+B(*"B,Z(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HW-2!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.CDX"B,Z(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H
M<#HW-2!L:6(O2&]R9&4O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DUI<W-L>6-K
M861E<R!A='0@:V]N=&%K=&$@3$1!4"!S97)V97(N(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX(&QI8B](;W)D92]!=71H+W-M8BYP:'`Z
M.3@*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N(@IM
M<V=S='(@(DUI<W-L>6-K861E<R!A='0@:V]N=&%K=&$@4TU"('-E<G9E<BXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C8X-B!L:6(O5D93+V9T
M<"YP:'`Z-S$W"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T;R!C;W!Y
M(&9R;VT@7"(E<UPB+B(*;7-G<W1R(")-:7-S;'EC:V%D97,@871T(&MO<&EE
M<F$@9G+E;B`G)7,G+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M-CDQ(&QI8B]61E,O9G1P+G!H<#HW,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M1F%I;&5D('1O(&-O<'D@=&\@7"(E<UPB+B(*;7-G<W1R(")-:7-S;'EC:V%D
M97,@871T(&MO<&EE<F$@=&EL;"`G)7,G+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<V%S;"YP:'`Z.#<@;&EB+TAO<F1E+T%U=&@O<V%S;"YP:'`Z.#<*
M;7-G:60@(D9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BXB
M"FUS9W-T<B`B36ES<VQY8VMA9&5S(&%T="!S:V%P82!N>2!305-,+6;V<F)I
M;F1E;'-E+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T"B,Z(&QI8B]61E,O<VUB+G!H
M<#HU,#$@;&EB+U9&4R]F='`N<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(DUI<W-L>6-K
M861E<R!A='0@9FQY='1A('1I;&P@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C0V,2!L:6(O5D93+W-M8BYP:'`Z-#8U"B,L('!H<"UF
M;W)M870*;7-G:60@(D9A:6QE9"!T;R!R971R:65V93H@)7,B"FUS9W-T<B`B
M36ES<VQY8VMA9&5S(&%T="!HY&UT83H@)7,B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ.`IM<V=I9"`B1F%I<B(*;7-G<W1R
M(")"<F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@T(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C<R(&QI8B](;W)D92].3%,O=&QD+G!H<#HX-`HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z-SD@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I
M;F%S*2(*;7-G<W1R(")&86QK;&%N9'/V87)N82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB
M+TAO<F1E+TY,4R]T;&0N<&AP.C@V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R
M:65S+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1F%R;V4@27-L86YD<R(*;7-G<W1R(")&Y'+V87)N82(*"B,Z(&9R86UE=V]R
M:R]#3$DO0TQ)+G!H<#HR,S@@;&EB+TAO<F1E+T-,22YP:'`Z,C,X"FUS9VED
M(")&871A;"!%<G)O<CHB"FUS9W-T<B`B1F%T86QT(&9E;#HB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3@W"FUS9VED(")&87@B"FUS
M9W-T<B`B1F%X(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,U,0IM
M<V=I9"`B1F%X97,B"FUS9W-T<B`B1F%X87(B"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<X"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HT,34*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0P,R!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?
M8V%L96YD87(N:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(F9E8G)U
M87)I(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,C<*;7-G:60@(D9E96QS
M($QI:V4B"FUS9W-T<B`B2^1N;G,@<V]M(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VTN<&AP.C(R,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@
M(DOD;FYS('-O;3H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3D*;7-G:60@(D9E=R!3:&]W97)S(@IM<V=S='(@(D;E=&%L
M:6=A('-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C(P"FUS9VED(")&97<@4VYO=R!3:&]W97)S(@IM<V=S='(@(D;E
M=&%L:6=A('-N]G-K=7)A<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-#0@;&EB+TAO<F1E+T9O<FTN<&AP.C$Y-#@*;7-G:60@(D9I96QD(&UA
M=')I>"(*;7-G<W1R(")&Y&QT;6%T<FES(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S,S,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,S,R.0IM<V=I9"`B
M1FEG;&5T($-!4%1#2$$B"FUS9W-T<B`B1FEG;&5T($-!4%1#2$$B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,W(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S,S"FUS9VED(")&:6=L970@9F]N="(*;7-G<W1R(")&:6=L971T>7!S
M;FET="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@S"B,Z
M(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HX,2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ:2(*;7-G<W1R(")&:6II(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")&:6QE(@IM
M<V=S='(@(D9I;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HV
M-`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8P"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C8W(&QI8B](;W)D92]-24U%+U9I97=E<B]T
M9WHN<&AP.C<Y"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S
M(&9I;&4B"FUS9W-T<B`B06YT86P@9FEL97(Z("5S(&9I;"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O>FEP+G!H<#HV-`HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]T9WHN<&AP.C@R(&QI8B](;W)D92]-24U%+U9I97=E<B]R
M87(N<&AP.C8P"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C8W
M(&QI8B](;W)D92]-24U%+U9I97=E<B]T9WHN<&AP.C<Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S='(@(D%N=&%L
M(&9I;&5R.B`E<R!F:6QE<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HT,#D*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R(")&:6QH86YT97)A
M<F4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8S
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C<*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX-2!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV,PHC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,"!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M,@IM<V=I9"`B1FEL92!.86UE(@IM<V=S='(@(D9I;&YA;6XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU(&QI8B](;W)D92]&;W)M+G!H<#HR
M.3@Q"FUS9VED(")&:6QE('-E;&5C=&EO;B(*;7-G<W1R(")&:6QV86PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#@V(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-#DP"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R(")&:6QU<'!L
M861D;FEN9R(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M-"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3`R"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B1FEL=7!P;&%D9&YI;F<@<W3V
M9',@:6YT92XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3$*;7-G
M:60@(D9I;'1E<G,B"FUS9W-T<B`B1FEL=&5R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,2!L:6(O
M2&]R9&4O3DQ3+W1L9"YP:'`Z.#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C@R(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Q"FUS9VED(")&
M:6YL86YD(@IM<V=S='(@(D9I;FQA;F0B"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,38V"FUS9VED(")&:7)S="!(86QF(@IM<V=S='(@(D;V<G-T82!H86QV
M86XB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB+T)L;V-K+VUO;VXN
M<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S='(@(D;V<G-T82!K
M=F%R=&5N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(S.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C4W"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(Q-`HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")&;&EP(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$P-PHC.B!L:6(O5D93+W-Q
M;"YP:'`Z,C,W(&QI8B]61E,O;75S<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`B36%P
M<"`E<R!E>&ES=&5R87(@:6YT92XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C(R"FUS9VED(")&;VYT($-O;&]R(@IM<V=S
M='(@(D9O;G1FY')G(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,W"FUS
M9VED(")&;V]D(@IM<V=S='(@(DUA="(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(S"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-@IM<V=I9"`B1F]R
M(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,B"FUS9W-T<B`B
M1O9R('=E8F)LY'-A<F4@<V]M(&EN=&4@<W3V9&5R(&)I;&1E<B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S0Q"FUS9VED(")&;W)E8V%S="`H5$%&*2(*
M;7-G<W1R(")0<F]G;F]S("A4048I(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C<R"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H
M870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD
M(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I
M;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*(D%N=&%L(&1A9V%R(&;V<B!P
M<F]G;F]S("AV87)J92!D86<@8F5T>61E<B!E;B!P<F]G;F]S(&;V<B!D86<@
M;V-H(&5N(&;V<B`B"B)N871T*2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U<B!P87-S=V]R9#\B"FUS9W-T
M<B`B1VSV;70@9&ET="!L]G-E;F]R9#\B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-#8T"FUS9VED(")&;W)M<R(*;7-G<W1R(")&;W)M=6SD<B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0IM<V=I9"`B1F]R='5N92(*
M;7-G<W1R(")6:7-H971S;W)D(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T<B`B5'EP(&%V('9I<VAE
M='-O<F0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S@*;7-G:60@(D9O
M<G1U;F5S(@IM<V=S='(@(E9I<VAE='-O<F0B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B5FES:&5T
M<V]R9"`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0U-0IM<V=I
M9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$Q,0IM<V=I9"`B1F]R=V%R9',B"FUS9W-T<B`B5FED87)B
M969O<F1R87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R(")&<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S,*;7-G:60@
M(D9R86UE<R(*;7-G<W1R(")286UA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX
M,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C@W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HX,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1G)A;F-E
M(@IM<V=S='(@(D9R86YK<FEK92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B
M1G)A;F-E+"!-971R;W!O;&ET86XB"FUS9W-T<B`B1G)A;FMR:6ME+"!-971R
M;W!O;"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#$W"FUS9VED(")&<F5E+T)U<WD@26YF;W)M871I;VXB"FUS9W-T
M<B`B3&5D:6<O57!P=&%G96X@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R-PIM<V=I9"`B1G)E
M92]"=7-Y(%)E<&QY(@IM<V=S='(@(DQE9&EG+U5P<'1A9V5N('-V87(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R
M,@IM<V=I9"`B1G)E92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`B3&5D:6<O=7!P
M=&%G96XM9O9R9G+E9V%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HR-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O:6-A;&5N9&%R+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U
M97-T(%)E<W!O;G-E(@IM<V=S='(@(E-V87(@<.4@;&5D:6<O=7!P=&%G96XM
M9O9R9G+E9V%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.3$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@T(&QI8B](;W)D
M92].3%,O1V5O25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S
M='(@(D9R86YS:V$@1W5I86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0
M;VQY;F5S:6$B"FUS9W-T<B`B1G)A;G-K82!0;VQY;F5S:65N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C(*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C@V(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S
M='(@(D9R86YS:V$@<_9D<F$@=&5R<FET;W)I97(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"B,Z(&QI8B](;W)D92]-
M24U%+U9I97=E<B]R9F,X,C(N<&AP.C<T"FUS9VED(")&<F]M(@IM<V=S='(@
M(D9RY6XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C,W(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-#D*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,Y-0IM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@
M(D9RY6X@9&5N("(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0X"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(D9U;&QS=.1N
M9&EG(&)E<VMR:79N:6YG(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M(")&=6QL;>5N92(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C8P"FUS9VED(")&=6QL($YA
M;64B"FUS9W-T<B`B1G5L;'-TY&YD:6=T(&YA;6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C@X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HX.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@
M(D=A8F]N(@IM<V=S='(@(D=A8F]N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,P"FUS9VED(")'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;2(*;7-G<W1R(")'86QL97)I(&%T="!T
M82!B:6QD(&9RY6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]A;G-E;&EM86=E7VQA;F<N:G,Z,CD*;7-G:60@(D=A;&QE<GDZ(@IM<V=S
M='(@(D=A;&QE<FDZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C@X(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'86UB:6$B"FUS9W-T<B`B
M1V%M8FEA(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N(@IM<V=S
M='(@(D=E;F5R97)A(&MO;F9I9W5R871I;VX@9O9R("5S(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E
M9"!#;V1E(@IM<V=S='(@(D=E;F5R97)A9"!K;V0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.CDP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HY,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.#D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@
M(D=E;W)G:6$B"FUS9W-T<B`B1V5O<F=I96XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C8Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Y(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HV.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.3`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@(D=E
M<FUA;GDB"FUS9W-T<B`B5'ES:VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.CDS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<U(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HY,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.3$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=H86YA
M(@IM<V=S='(@(D=H86YA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HY-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDR"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z.30*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDR(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")':6)R86QT87(B"FUS
M9W-T<B`B1VEB<F%L=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S8*;7-G
M:60@(D=I=F5N($YA;64B"FUS9W-T<B`B1O9R;F%M;B(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*;7-G:60@(D=L
M;V)A;"!/<'1I;VYS(@IM<V=S='(@(D=L;V)A;&$@:6YS=.1L;&YI;F=A<B(*
M"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C$W"FUS9VED(")';R(*;7-G
M<W1R(")/2R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,`IM<V=I9"`B
M1V]E9&5L(@IM<V=S='(@(D=O961E;"(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,3`P"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HQ,3,Q"FUS9VED(")';V]G;&4@36%P<R(*;7-G
M<W1R(")';V]G;&5K87)T;W(B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C(Q(&QI8B]";&]C:R]G;V]G;&4N<&AP
M.C0Q"FUS9VED(")';V]G;&4@4V5A<F-H(@IM<V=S='(@(D=O;V=L97/V:VYI
M;F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,C(P"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR,S@*
M;7-G:60@(D=R87ES8V%L92(*;7-G<W1R(")'<N5S:V%L82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<V(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,#`*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.CDS(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B1W)E:VES:R`H25-/+3@X-3DM-RDB
M"@HC.B!C;VYF:6<O=&AE;65S+V=R965N+G!H<#HV"FUS9VED(")'<F5E;B(*
M;7-G<W1R(")'<O9N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDT"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z.34*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.CDT(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C<U"FUS9VED(")'<F5E;FQA;F0B"FUS9W-T
M<B`B1W+V;FQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HX.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z.34@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA9&$B"FUS9W-T<B`B
M1W)A;F%D82(*"B,Z(&-O;F9I9R]T:&5M97,O9W)E>2YP:'`Z-@IM<V=I9"`B
M1W)E>2(*;7-G<W1R(")'<N4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$W.0IM
M<V=I9"`B1W)O=7`@061M:6YI<W1R871I;VXB"FUS9W-T<B`B1W)U<'!A9&UI
M;FES=')A=&EO;B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`Z-3D@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$V.0HC.B!L:6(O2&]R
M9&4O1W)O=7`N<&AP.C4Y(&QI8B](;W)D92]'<F]U<"]L9&%P+G!H<#HQ-CD*
M;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS,#<@;&EB
M+TAO<F1E+T=R;W5P+VQD87`N<&AP.C,P-PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B"FUS9W-T<B`B1W)O=7!?;&1A<#H@
M2V%N(&EN=&4@;.1G9V$@=&EL;"!G<G5P<"`G)7,G+B!397)V97)N('-V87)A
M9&4Z("(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HQ,3@@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$R-`HC.B!F<F%M97=O
M<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X(&QI8B](;W)D92]'<F]U<"]L
M9&%P+G!H<#HQ,3@*(SH@;&EB+TAO<F1E+T=R;W5P+VQD87`N<&AP.C$R-"!L
M:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L('!H<"UF;W)M870*;7-G
M:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,B"FUS
M9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EN=&4@<F%D97)A(&=R=7!P("<E<R<B
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE
M=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HS-SD*(SH@;&EB+TAO<F1E+T=R
M;W5P+VQD87`N<&AP.C,S."!L:6(O2&]R9&4O1W)O=7`O;&1A<"YP:'`Z,S<Y
M"B,L('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,B"FUS9W-T<B`B1W)O=7!?;&1A<#H@2V%N(&EN=&4@
M=7!P9&%T97)A(&=R=7!P("<E<R<B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,Q-"!L:6(O2&]R9&4O4&5R;7,O54DN<&AP.C,Q-`HC.B!L
M:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!T96UP;&%T97,O<VAA<F5S+V5D:70N
M:6YC.C$W-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!P97(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C<V(&QI8B](;W)D92].3%,O=&QD+G!H<#HY.`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.38@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M-S8*;7-G:60@(D=U861E;&]U<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P,PHC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z.3<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S<*;7-G
M:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ,#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.CDX(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<W"FUS9VED(")'=6%T
M96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z.3(*;7-G:60@
M(D=U97)N<V5Y(@IM<V=S='(@(D=U97)N<V5Y(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HR,C8@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HR
M,C8*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHX.`IM<V=I9"`B1W5E
M<W0@4&5R;6ES<VEO;G,B"FUS9W-T<B`B1^1S=&)E:/9R:6=H971E<B(*"B,Z
M('1E;7!L871E<R]G=65S="]G=65S="YI;F,Z,3$*;7-G:60@(D=U97-T(%-E
M<G9I8V5S(@IM<V=S='(@(E1JY&YS=&5R(&;V<B!GY'-T97(B"@HC.B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#<R"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`B1^1S=&)O:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.CDW"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HY.2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1W5I;F5A(@IM<V=S='(@
M(D=U:6YE82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`T(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3`T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#`@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U:6YE82U":7-S874B"FUS
M9W-T<B`B1W5I;F5A+4)I<W-A=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#$@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U>6%N
M82(*;7-G<W1R(")'=6EN96$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HY-C`@;&EB+TAO<F1E+T9O<FTN<&AP.CDV-`IM<V=I9"`B2%1-3"(*;7-G
M<W1R(")(5$U,(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@
M(DA434Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&-E;&QE;B!I(&5N
M(')A9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@
M(DA434Q!<F5A(';D9W)A<B!A='0@<F%D97)A('-I<W1A(&MO;'5M;F5N(&D@
M96X@=&%B96QL+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T
M<B`B2%1-3$%R96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@<F%D96X@:2!E
M;B!T86)E;&PN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ
M-3<@;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z,34W"FUS9VED(")(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B2%144"!!=71E;G1I
M<V5R:6YG('-A:VYA<RXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Q,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Q,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@P"FUS9VED(")(86ET:2(*;7-G
M<W1R(")(86ET:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C0P,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M
M06QG;W)I=&AM(@IM<V=S='(@(DAA<VAA;&=O<FET;2(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C(R"FUS9VED(")(87IE(@IM
M<V=S='(@(D1I;6UA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3$Y
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,S(*(SH@;&EB+TAO<F1E+T9O
M<FTN<&AP.CDR,R!L:6(O2&]R9&4O1F]R;2YP:'`Z,CDQ.`IM<V=I9"`B2&5A
M9&5R(@IM<V=S='(@(E)U8G)I:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-C$*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T
M86)L97-E="YP:'`Z-C$*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B4G5B<FEK
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$P-PHC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`S(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD($UC1&]N
M86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0M(&]C:"!-8T1O;F%L9/9A<FYA
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*
M;7-G:60@(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B2W)A9G1I9V$@Y7-K<VMU
M<F%R(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#D*;7-G:60@(DAE8G)E
M=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R(")(96)R96ES:R`H25-/+3@X-3DM
M."U)*2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,S0*;7-G:60@(DAE:6=H="(*;7-G<W1R(")(]FID(@H*(SH@
M;&EB+T)L;V-K+V)A<G1I;64N<&AP.C(T(&QI8B]";&]C:R]D:79I9&5R+G!H
M<#HR-`IM<V=I9"`B2&5I9VAT("AI;B!P:7AE;',I(@IM<V=S='(@(DCV:F0@
M*'!I>&QA<BDB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z
M,3<Y(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@;&EB
M+TAO<F1E+TAE;'`N<&AP.C$X-"!L:6(O2&]R9&4O2&5L<"YP:'`Z,3@V('-E
M<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W"B,Z('1E;7!L871E<R]H96QP+VEN
M9&5X+FEN8SHT"FUS9VED(")(96QP(@IM<V=S='(@(DAJY&QP(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,0IM<V=I9"`B
M2&5L<"!U<VEN9R!E9&ET;W(B"FUS9W-T<B`B2&KD;'`@;65D(&5D:71O<FXB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S<Q(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,S<U"FUS9VED(")(96QP97(B"FUS9W-T<B`B2&KD;'!F=6YK
M=&EO;B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P
M:&5R92(*;7-G<W1R(")(96UI<V;D<B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(DCD<B#D<B!B]G)J86X@878@9FEL96XZ(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S`*;7-G:60@(DAI9V@B"FUS9W-T
M<B`B2/9G(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHV('1E;7!L
M871E<R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8SHU"FUS9VED(")(;U]M92(*
M;7-G<W1R(")(95]M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$T"FUS9VED(")(;VQY(%-E92`H
M5F%T:6-A;B!#:71Y(%-T871E*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$T.3$@;&EB+TAO<F1E+G!H<#HQ-3,Y"FUS9VED
M(")(;VUE(@IM<V=S='(@(DAE;2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C$U-0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$R,B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@:&5M
M(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8T"FUS9VED(")(;VUE($1I
M<F5C=&]R>2(*;7-G<W1R(")(96UK871A;&]G(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,`HC.B!L:6(O2&]R9&4O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$Y,`IM<V=I9"`B2&]M92!0:&]N92(*;7-G
M<W1R(")496QE9F]N+"!H96TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$P."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-SD@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$P.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3`U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3`V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,#8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@
M2V]N9R(*;7-G<W1R(")(;VYG($MO;F<B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z-C<*;7-G:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-#(@;&EB+TAO<F1E+TMO;&%B
M+G!H<#HT-3(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(*
M;7-G<W1R(")(;W)D92]+;VQA8CH@3V=I;'1I9W0@)7,@6$U,+61A=&$@<.5T
M<N1F9F%D97,@:2!M961D96QA;F1E("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HR.3D@;&EB+TAO<F1E+TMO;&%B+G!H<#HR.3D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!);F=E
M="!M961D96QA;F1E(&UA=&-H87(@;V)J96MT970@)7,B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C0S-2!L:6(O2&]R9&4O2V]L86(N<&AP.C0T
M-0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<R(*;7-G<W1R(")(;W)D
M92]+;VQA;CH@26YG970@;V)J96MT(&%V('1Y<&5N("5S(&AI='1A9&5S(&D@
M;65D9&5L86YD970@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C$R-3`@;&EB+TAO<F1E+TMO;&%B+G!H<#HQ,C4Q"B,L('!H<"UF;W)M870*
M;7-G:60@(DAO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R!<
M(B5S7"(B"FUS9W-T<B`B2&]R9&4O2V]L86(Z(%)A9&5R861E("5S("<E<R<B
M"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,R!L:6(O2&]R9&4O
M2V]L86(N<&AP.C(R,PIM<V=I9"`B2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VXB"FUS9W-T<B`B2&]R9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUO=&]R;B!K
M<N1V97(@)V1O;7AM;"<M=&EL;.1G9V5T(&;V<B!02%`B"@HC.B!F<F%M97=O
M<FLO2V]L86(O2V]L86(N<&AP.C4P,R!L:6(O2&]R9&4O2V]L86(N<&AP.C4Q
M,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O
M(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<R(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@2V%N(&EN=&4@<VMA<&$@;GET="!834PM='+D9"!F]G(@
M;V)J96MT("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,C0W
M(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(T.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S
M(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!+86X@:6YT92!R861E<F$@)7,@)R5S
M)SH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-"!L:6(O
M2&]R9&4O2V]L86(N<&AP.C0X,PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B2&]R9&4O2V]L86(Z($MA;B!I;G1E
M(&CD;71A($U)341%+4E$(&;V<B!D96QE;B!M960@='EP("5S(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS(&QI8B](;W)D92]+;VQA8BYP
M:'`Z,3$Y-PHC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA
M8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R
M9&4O2V]L86(Z($MA;B!I;G1E('-Y;FMR;VYI<V5R82`E<R`G)7,G.B`E<R(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3,S-B!L:6(O2&]R9&4O
M2V]L86(N<&AP.C$S,S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@
M(DAO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK<F]N:7-E<F$@=71D96QN:6YG
M87(Z("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS-#`@;&EB
M+TAO<F1E+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(DAO<F1E
M+TMO;&%B.B!/:^1N9"!U=&1E;&YI;F<@)R5S)R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO<FEZ;VYT
M86P@4G5L92(*;7-G<W1R(")(;W)I<V]N=&5L;"!L:6YJ92(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#(*;7-G:60@(DAO
M<FEZ;VYT86P@<&%D9&EN9R(*;7-G<W1R(")(;W)I<V]N=&5L;"!U=&9Y;&QN
M860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")(;W)I<V]N=&5L;#HB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E
M(')E<&]R="$I(@IM<V=S='(@(DAU<B!H86UN861E(&1U(&CD<C\@*%9A<B!G
M;V0@<F%P<&]R=&5R82!D971T82$I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-0IM<V=I9"`B2&]W(&UA;GD@
M8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\B"FUS9W-T<B`B2'5R
M(&WE;F=A(&MO;'5M;F5R('9I;&P@9'4@<VSE(&EH;W`_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,C$*;7-G:60@(DAO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/R(*;7-G<W1R(")(=7(@;>5N9V$@9N1L
M="`H:V]L=6UN97(I(&9I;FYS(&1E=#\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,V"FUS9VED(")(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")(=7(@
M;>5N9V$@<F%D97(@=FEL;"!D=2!S;.4@<V%M;6%N/R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR.#D@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,S<*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(D9U:W1I9VAE="(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@*;7-G:60@(DAU;6ED:71Y
M.B`B"FUS9W-T<B`B1G5K=&EG:&5T.B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S(@IM<V=S='(@(DAU;6]R:7-T97(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q,0HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`W(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@P"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(E5N9V5R;B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$W,B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,U"B,Z(&QI8B](;W)D92]!=71H
M+V-Y<G5S+G!H<#HQ-S(@;&EB+TAO<F1E+T%U=&@O8WER<W%L+G!H<#HR,S4*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`B4VMA<&%N9&4@878@24U!4"UM87!P(&UI<W-L
M>6-K861E.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP
M.C(Q-"!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,CDU"B,Z(&QI
M8B](;W)D92]!=71H+V-Y<G5S+G!H<#HR,30@;&EB+TAO<F1E+T%U=&@O8WER
M<W%L+G!H<#HR.34*(RP@<&AP+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B4F%D97)I;F<@878@24U!
M4"UM87!P(&UI<W-L>6-K861E<SH@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+V-Y<G5S+G!H<#HQ-SD@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN
M<&AP.C(T,@HC.B!L:6(O2&]R9&4O075T:"]C>7)U<RYP:'`Z,3<Y(&QI8B](
M;W)D92]!=71H+V-Y<G-Q;"YP:'`Z,C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(DE-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(@IM<V=S
M='(@(E-K87!A;F1E(&%V('%U;W1A(&;V<B!)34%0+6UA<'`@;6ES<VQY8VMA
M9&5S.B`E<R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,38@;&EB
M+TAO<F1E+T9O<FTN<&AP.C$S,C`*;7-G:60@(DE0($%D9')E<W,B"FUS9W-T
M<B`B25`M861R97-S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC
M+G!H<#HW-R!L:6(O2&]R9&4O075T:"]I<&)A<VEC+G!H<#HW-PIM<V=I9"`B
M25`@061D<F5S<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"UA9')E<W,@
MY'(@:6YT92!T:6QL9^1N9VQI9RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VEP8F%S:6,N<&AP.C@Y(&QI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP.C@Y
M"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+B(*;7-G<W1R("))4"UA9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD;G0@
M0TE$4BUB;&]C:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.34*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HR.34*;7-G:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS
M9W-T<B`B1O9R<_9K(&%T="!K<FEN9V?E($E0+6SE<RXB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G
M:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("))7VYF;V=A(')A9"!F
M]G)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,C`*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$P."!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("))<VQA
M;F0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@P"FUS9VED("))8V]N
M<R!/;FQY(@IM<V=S='(@(D5N8F%R="!I:V]N97(B"@HC.B!U=&EL+VEC;VY?
M8G)O=W-E<BYP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R
M("5S(@IM<V=S='(@(DEK;VYE<B!F]G(@)7,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S@Q"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B
M26MO;F5R(&UE9"!T97AT(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y
M,PIM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("))9&5N=&ET971E
M;G,@;F%M;CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C4Y.0HC+"!P:'`M
M9F]R;6%T"FUS9VED("))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(@IM<V=S='(@(D]M
M(&1E="!I;G1E('9I<V%S(&MO<G)E:W0L("5S(&;V<B!A='0@]G!P;F$@:2!N
M>71T(&;V;G-T97(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0U.0IM
M<V=I9"`B(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT
M97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B
M"B)/;2!D=2!I;G1E('-E<B!NY6=R82!I:V]N97(@;N1R(&1U(&%N=N1N9&5R
M($EN=&5R;F5T($5X<&QO<F5R+"!SY2!K86X@9'4@(@HB8F5H]G9A(&UA<FME
M<F$@9&5N;F$@<G5T82!F]G(@871T('-TY&YG82!A=B!G96YO;7-K:6YL:6=A
M(%!.1RUB:6QD9FEL97(N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C$U.`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3<R"FUS9VED("(B"B))9B!Y;W4@<V5E('1H:7,@;65S<V%G
M92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@
M8V%N)W0@8F4@(@HB9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BXB"FUS9W-T
M<B`B(@HB3VT@9'4@<V5R(&1E;FYA('1E>'0@;65N(&EN9V5N(&)I;&0L('/E
M(&MA;B!I;G1E(&1I;B!W96)B;.1S87)E('9I<V$@9&5N("(*(F)I;&0@9'4@
M9O9R<_9K97(@;&%D9&$@=7!P+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.`IM<V=I9"`B26UA9V4@
M4')E=FEE=SHB"FUS9W-T<B`B1O9R:&%N9'-G<F%N<VMA(&)I;&0Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(D)I;&1A9')E<W,B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q.`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C$*;7-G:60@(DEM86=E(%523#HB"FUS9W-T<B`B0FEL9&%D<F5S<SHB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@9V%L;&5R>2(*;7-G<W1R
M(")":6QD(&9RY6X@9V%L;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@
M9G)O;2!G86QL97)Y.B(*;7-G<W1R(")":6QD(&9RY6X@9V%L;&5R:3HB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q(&QI8B](;W)D92]&;W)M
M+G!H<#HQ-S8U"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`B3&%D9&$@
M=7!P(&)I;&0B"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B
M26UA9V5S(@IM<V=S='(@(D)I;&1E<B(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C<@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z-PHC.B!T
M96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C4T('1E;7!L871E<R]D871A+V-S
M=FEN9F\N:6YC.C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B26UP;W)T+"!3=&5P
M("5D(@IM<V=S='(@(DEM<&]R=&5R82P@<W1E9R`E9"(*"B,Z('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM
M<&]R=&5D(&9I96QD.B`E<R(*;7-G<W1R("));7!O<G1E<F%D92!FY&QT.B`E
M<R(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-C4*;7-G:60@(DEM
M<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B26UP;W)T97)A9&4@9N1L=#HB"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<P
M,0IM<V=I9"`B26X@4')O8V5S<R(*;7-G<W1R(")0Y6?E96YD92(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T<B`B26Y?9F]G82!R
M860@969T97(B"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<#HQ,S4@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3,T"FUS9VED
M("));F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN(@IM<V=S='(@(D9E;&%K
M=&EV(&%K=&EV:71E='-K;V0@<W!E8VEF:6-E<F%D+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,R"B,Z(&QI8B].
M970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S(*;7-G:60@(DEN8V]R<F5C
M="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(D9E;&%K=&EG
M="!A;G;D;F1A<FYA;6X@;V-H+V5L;&5R(&SV<V5N;W)D+B(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N(@IM<V=S='(@(B(*(D]G:6QT:6=T(&%N=N1N9&%R;F%M;B!E
M;&QE<B!A;'1E<FYA=&EV(&%D<F5S<RX@1O9R<_9K(&EG96X@96QL97(@:V]N
M=&%K=&$@(@HB861M:6YI<W1R873V<F5N(&]M(&1U(&)E:/9V97(@:&KD;'`N
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M,0IM<V=I9"`B26YC<F5A<V4@26YD96YT(@IM<V=S='(@(M9K82!I;F1R86<B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$Q-@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`Y(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED("));F1I82(*;7-G<W1R("));F1I96XB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!L:6(O2&]R9&4O
M4&5R;7,O54DN<&AP.C(U-`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R("));F1I=FED
M=65L;&$@86YVY&YD87)E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ,3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q
M,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,`IM<V=I9"`B26YD;VYE<VEA
M(@IM<V=S='(@(DEN9&]N97-I96XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]R9F,X,C(N<&AP.C8W"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(DEN9F\B"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C4Y"FUS9VED("));F9O<FUA
M=&EO;B(*;7-G<W1R("));F9O<FUA=&EO;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(DEN9F]R;6%T:6]N(&YO(&QO;F=E
M<B!A=F%I;&%B;&4N(@IM<V=S='(@(DEN9F]R;6%T:6]N(.1R(&EN=&4@=&EL
M;&?D;F=L:6<@;.1N9W)E+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-0IM<V=I9"`B26YS97)T($-?;VQU
M;6X@069T97(B"FUS9W-T<B`B26YF;V=A(&M?;VQU;6X@969T97(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q-PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("));F9O9V$@8FEL
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#`*;7-G:60@(DEN<V5R="!486)L92(*;7-G<W1R("));F9O9V$@=&%B96QL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR
M-0IM<V=I9"`B26YS97)T(%=E8B!,:6YK(@IM<V=S='(@(DEN9F]G82!W96)B
M;.1N:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS-`IM<V=I9"`B26YS97)T(%]#;VQU;6X@0F5F;W)E(@IM
M<V=S='(@(DEN9F]G82!?:V]L=6UN(&;V<F4B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C8*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(DEN9F]G82!N>2!K;VQU;6X@969T97(@86MT=65L;"!K;VQU;6XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C4*;7-G:60@(DEN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C
M=7)R96YT(&]N92(*;7-G<W1R("));F9O9V$@;GD@:V]L=6UN(&;V<F4@86MT
M=65L;"!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(DEN9F]G82!R860@969T
M97(@86MT=65L;"!R860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("));F9O9V$@;GD@
M<F%D(&;V<F4@96MT=65L;"!R860B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-S`*;7-G:60@(DEN<V5R="!A
M('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(DEN
M9F]G82!P87)A9W)A9B!E9G1E<B!A:W1U96QL(&YO9"(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.0IM<V=I
M9"`B26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E
M(@IM<V=S='(@(DEN9F]G82!P87)A9W)A9B!F]G)E(&%K='5E;&P@;F]D(@H*
M(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-3`*;7-G:60@(DEN<V5R="!A;'1E
M<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B26YF;V=A(&%L=&5R;F%T:78@;6%L
M;"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-#(*;7-G:60@(DEN<V5R
M="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T
M:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4X"FUS9VED("));G-E
M<G0@8V5L;"!A9G1E<B(*;7-G<W1R("));F9O9V$@8V5L;"!E9G1E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R("));F9O9V$@
M8V5L;"!F]G)E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A9G1E<B(*
M;7-G<W1R("));F9O9V$@:V]L=6UN(&5F=&5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-0IM<V=I9"`B26YS
M97)T(&-O;'5M;B!B969O<F4B"FUS9W-T<B`B26YF;V=A(&MO;'5M;B!F]G)E
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`@
M;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N<&AP.C4P"B,Z(&QI8B](;W)D
M92])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B26YS97)T(&UE<W-A
M9V5S(@IM<V=S='(@(DEN9F]G82!M961D96QA;F1E;B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT-0IM<V=I
M9"`B26YS97)T('!A<F%G<F%P:"!A9G1E<B(*;7-G<W1R("));F9O9V$@<&%R
M86=R868@969T97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@
M8F5F;W)E(@IM<V=S='(@(DEN9F]G82!P87)A9W)A9B!F]G)E(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.0IM
M<V=I9"`B26YS97)T(')O=R!A9G1E<B(*;7-G<W1R("));F9O9V$@<F%D(&5F
M=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T<B`B
M26YF;V=A(')A9"!F]G)E(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,PIM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R(")!;F=E(&5R9F]R9')A="!S=F%R
M('1I;&P@<^1K97)H971S9G+E9V%N.B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C8*;7-G:60@(DEN<V5R="]-;V1I9GD@
M26UA9V4B"FUS9W-T<B`B26YF;V=A+\1N9')A(&)I;&0B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E
M<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B26YF;V=A+\1N9')A(&SD;FLB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0S"FUS9VED
M("));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U
M=&EO;B!L:7-T+B(*;7-G<W1R(")/=&EL;'+D8VML:6<@:W)E9&ET(&;V<B!A
M='0@<VMI8VMA('1I;&P@9&ES=')I8G5T:6]N<VQI<W1A+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"B,Z(&QI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S4*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70N(@IM<V=S='(@(D]T:6QL<N1C:VQI9R!K<F5D:70N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`W-2!L:6(O2&]R9&4O
M1F]R;2YP:'`Z,3`W.0IM<V=I9"`B26YT96=E<B(*;7-G<W1R(")(96QT86PB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3,W"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`B2&5L
M=&%L<VQI<W1A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HR.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HS-3(*;7-G:60@(DEN=F%L:60@06-T:6]N('-E;&5C
M=&5D(&9O<B!T:&ES(&-O;7!O;F5N="XB"FUS9W-T<B`B3V=I;'1I9R#E=&?D
M<F0@9O9R(&1E;B!HY'(@:V]M<&]N96YT96XN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"B,Z(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS9VED("));G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R(")/9VEL=&EG(%5$2"`H
M)W5S97(@9&%T82!H96%D97(G*2XB"@HC.B!L:6(O2&]R9&4O0V]M<')E<W,O
M>FEP+G!H<#HQ-C<@;&EB+TAO<F1E+T-O;7!R97-S+WII<"YP:'`Z,3DT"B,Z
M(&QI8B](;W)D92]#;VUP<F5S<R]Z:7`N<&AP.C(Q,@IM<V=I9"`B26YV86QI
M9"!:25`@9&%T82(*;7-G<W1R(")/9VEL=&EG="!:25`M87)K:79D871A(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B1F5L86MT:6<@87!P;&EK871I;VXN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS
M9VED("));G9A;&ED(&)A=&-H($E$+B(*;7-G<W1R(")&96QA:W1I9W0@8F%T
M8V@M240B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#@W(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q-3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C(S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,CDY"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(P.3$*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C(Q-C(@
M;&EB+TAO<F1E+T9O<FTN<&AP.C(R,S8@;&EB+TAO<F1E+T9O<FTN<&AP.C(S
M,#,*(SH@;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'`Z,S<*;7-G
M:60@(DEN=F%L:60@9&%T82!S=6)M:71T960N(@IM<V=S='(@(D9E;&%K=&EG
M(&1A=&$@<VMI8VMA9"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,#`*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,#`*;7-G:60@(DEN=F%L:60@9&5S=&EN871I;VX@861D
M<F5S<RXB"FUS9W-T<B`B1F5L86MT:6<@9&5S=&EN871I;VYS861R97-S+B(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C@Q"B,Z
M(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP.C$P,`HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HR,C`@;&EB+TAO
M<F1E+T-O;7!R97-S+V1B>"YP:'`Z,3`Y"B,Z(&QI8B](;W)D92]#;VUP<F5S
M<R]D8G@N<&AP.C$S.2!L:6(O2&]R9&4O0V]M<')E<W,O9&)X+G!H<#HR-#$*
M;7-G:60@(DEN=F%L:60@9FEL92!F;W)M870B"FUS9W-T<B`B1F5L86MT:6=T
M(&9I;&9O<FUA="(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M-C4*;7-G:60@(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D]G:6QT
M:6<@;&EC96YS;GEC:V5L+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ-3D*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM
M<V=S='(@(D9E;&%K=&EG(&]R="!S<&5C:69I8V5R860N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"B,Z(&QI
M8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`W"FUS9VED("));G9A
M;&ED(&US9U]T>7!E+B(*;7-G<W1R(")&96QA:W1I9R!M961D96QA;F1E7W1Y
M<"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,#,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#,*;7-G:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@
M(D9E;&%K=&EG(&5L;&5R('-A:VYA9"!A<&E?:60N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,Z(&QI8B].
M970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B1F5L86MT:6=T(&5L
M;&5R('-A:VYA9"!P87)A;65T97(N(@H*(SH@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N+B(*
M;7-G<W1R(")&96QA:W1I9R#V=F5R;&EG9V%N9&4@8F5H]G)I9VAE="XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"FUS9VED("));G9A
M;&ED('!A<G1N97(@:60N(@IM<V=S='(@(D9E;&%K=&EG="!P87)T;F5R+6ED
M+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C,*;7-G:60@
M(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")&96QA:W1I9R!P<F]D
M=6MT:V]D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-@HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P-@IM<V=I9"`B26YV86QI9"!P<F]T;V-O;"XB"FUS9W-T<B`B1F5L
M86MT:6=T('!R;W1O:V]L;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H
M='1P+G!H<#HX,`HC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M.3,@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C<Q"B,Z(&QI8B].970O4TU3
M+W=I;E]H='1P+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED
M(')E8VEP:65N=#H@7"(E<UPB(@IM<V=S='(@(D9E;&%K=&EG(&UO='1A9V%R
M93H@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3`W-B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(SH@;&EB+TAO<F1E+TMO
M;&%B+G!H<#HQ,#@P(&QI8B](;W)D92]+;VQA8BYP:'`Z,3(V,PIM<V=I9"`B
M26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B1F5L86MT:6=T('5T9&5L
M;FEN9W-O8FIE:W0B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,#$*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#$*;7-G:60@(DEN=F%L:60@<V]U<F-E(&%D9')E<W,N(@IM
M<V=S='(@(D9E;&%K=&EG(&%V<^1N9&%R861R97-S+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0HC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q,0IM<V=I9"`B26YV86QI
M9"!U;FEC;V1E(&1A=&$N(@IM<V=S='(@(D9E;&%K=&EG="!U;FEC;V1E+61A
M=&$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S4Y"FUS9VED("))
M;G9E;G1O<GDB"FUS9W-T<B`B26YV96YT87)I97(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C4T"B,Z(&QI8B](;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<#HV-S@*;7-G:60@(DEN=F5R="!S96QE
M8W1I;VXB"FUS9W-T<B`B26YV97)T97)A('5R=F%L(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3D*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$Q,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("))<F%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C@Q(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3@*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HX,0IM<V=I9"`B27)A<2(*;7-G<W1R("))<F%K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,3,*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HX,`IM<V=I9"`B27)E;&%N9"(*;7-G<W1R("))<FQA;F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G<W1R("))<VQE(&]F
M($UA;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C(T"FUS9VED("))<V]L871E9"!4+5-T;W)M<R(*;7-G<W1R(")%;G-T86MA
M(.5S:W-K=7)A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,"!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,3$T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,30@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E;"(*;7-G<W1R
M("))<W)A96PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8R-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8R-@IM<V=I9"`B27-S
M=65R(@IM<V=S='(@(E5T9N1R9&%T(&%V(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T
M<B`B2W5R<VEV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HQ,C$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Q-2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B271A;'DB"FUS9W-T<B`B
M271A;&EE;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$V"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3(S"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#(*;7-G:60@(DIA;6%I8V$B"FUS9W-T<B`B
M2F%M86EC82(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HS-S<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Q-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT-#`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-0IM<V=I
M9"`B2F%N=6%R>2(*;7-G<W1R(")J86YU87)I(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,C4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ,3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ,C4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I
M9"`B2F%P86XB"FUS9W-T<B`B2F%P86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B2F%P86YE<V4@*$E33RTR,#(R+4I0*2(*;7-G<W1R
M(")*87!A;G-K("A)4T\M,C`R,BU*4"DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$R,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED
M(")*97)S97DB"FUS9W-T<B`B2F5R<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,C0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Q."!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B
M2F]R9&%N(@IM<V=S='(@(DIO<F1A;FEE;B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HS.#,*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0R,`HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`X(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT-#8*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")J=6QI(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$Y"B,Z(&QI
M8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HT,#<@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<P"FUS9VED(")*=6YE(@IM<V=S
M='(@(FIU;FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y(@IM<V=S='(@(DIU<W1E
M<F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`B0V5N
M=&5R:G5S=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$W"FUS9VED(")*=7-T:69Y($9U;&PB"FUS9W-T
M<B`B2G5S=&5R82!JY&UT(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,W"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,30*;7-G:60@(DIU<W1I9GD@3&5F="(*
M;7-G<W1R(")6Y&YS=&5R:G5S=&5R82(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$V"FUS9VED(")*=7-T:69Y
M(%)I9VAT(@IM<V=S='(@(DCV9V5R:G5S=&5R82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!L
M:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3,V"B,Z(&QI8B](;W)D92].3%,O8V]U
M;G1R:65S+G!H<#HQ,3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G
M:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T-@HC.B!L:6(O2&]R9&4O54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,C8U"FUS9VED(")+965P(&]R:6=I;F%L/R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$R-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(P(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*;7-G<W1R(")+
M96YY82(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z.#4@;&EB
M+TAO<F1E+T%U=&@O:W)B-2YP:'`Z.#4*;7-G:60@(DME<F)E<F]S('-E<G9E
M<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B2V5R8F5R;W-S
M97)V97)N(&%V=FES861E(&%U=&5N=&ES97)I;F=E;BXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#(*;7-G:60@(DME<FYE;"!.97=B:65S(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0P,"!L
M:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO
M;B(*;7-G<W1R(").>6-K96P@<VMA<&%D(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z-#`S(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C0Q
M-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S='(@(D9I;F=E<G!R:6YT
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Q(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C0Q,@IM<V=I9"`B2V5Y($QE;F=T:"(*;7-G
M<W1R(").>6-K96QLY&YG9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C0P,"!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@
M(DME>2!4>7!E(@IM<V=S='(@(DYY8VME;'1Y<"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3DY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`B3GEC:V5L86YV
MY&YD86YD92(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<R
M.2!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HW-#`*;7-G:60@(DME>2!A;')E
M861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B
M3GEC:V5L(&9I;FYS(')E9&%N('#E(&1E;B!P=6)L:6MA(&YY8VME;'-E<G9E
M<FXN(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(D)A<FXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$R.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$R.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(Q
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*
M;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&-O;F9I9R]T:&5M97,O:V]L86(N<&AP
M.CD*;7-G:60@(DMO;&%B(@IM<V=S='(@(DMO;&%B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U
M(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ,S(*(SH@;&EB+TAO<F1E+TY,4R]C
M;W5N=')I97,N<&AP.C$R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM
M<V=I9"`B2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B
M"FUS9W-T<B`B3F]R9&MO<F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@U(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ,S,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$R,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(E-Y9&MO<F5A(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3$*;7-G:60@(DMO<F5A;B`H155#+4M2*2(*;7-G<W1R
M(")+;W)E86YS:R`H155#+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3,T"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#8*;7-G:60@(DMU=V%I
M="(*;7-G<W1R(")+=7=A:70B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$R-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$R-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(U(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+>7)G>7IS
M=&%N(@IM<V=S='(@(DMI<F=I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R("),85]Y;W5T(@H*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I9"`B3&%N9W5A
M9V4B"FUS9W-T<B`B4W!RY6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$S-PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C@W"FUS9VED("),86\@4&5O
M<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),86]S(@H*(SH@
M;&EB+T)L;V-K+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S
M='(@(E-I<W1A(&AA;'9A;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW
M-@IM<V=I9"`B3&%S="!087-S=V]R9"!#:&%N9V4B"FUS9W-T<B`B3/9S96YO
M<F0@Y&YD<F%D97,B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L
M;V-K+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`B
M4VES=&$@:W9A<G1A;&5T(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3@*
M;7-G:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`B4V5N87-T('5P<&1A=&5R
M860Z(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y(&QI8B](;W)D
M92]!=71H+G!H<#HW,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3&%S="!L;V=I
M;CH@)7,B"FUS9W-T<B`B4V5N87-T92!I;FQO9V=N:6YG.B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,2!L:6(O2&]R9&4O075T:"YP:'`Z
M-S$Y"B,L('!H<"UF;W)M870*;7-G:60@(DQA<W0@;&]G:6XZ("5S(&9R;VT@
M)7,B"FUS9W-T<B`B4V5N87-T92!I;FQO9V=N:6YG.B`E<R!F<N5N("5S(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-S$V(&QI8B](;W)D92]!=71H
M+G!H<#HW,30*;7-G:60@(DQA<W0@;&]G:6XZ($YE=F5R(@IM<V=S='(@(E-E
M;F%S=&4@:6YL;V=G;FEN9SH@06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ-#8*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$R-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B
M3&%T=FEA(@IM<V=S='(@(DQE='1L86YD(@H*(SH@8V]N9FEG+W1H96UE<R]L
M879E;F1E<BYP:'`Z-@IM<V=I9"`B3&%V96YD97(B"FUS9W-T<B`B3&%V96YD
M97(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#0*;7-G:60@(DQA=R(*
M;7-G<W1R("),86<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G<W1R("),87EO
M=70B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C@V"FUS9VED("),96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@
M(DSD;6YA('1O;2!F]G(@871T('-TY&YG82!A=B!K86YT;&EN:F4B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$S.`HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(X(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.C@W"FUS9VED("),96)A;F]N(@IM<V=S='(@(DQI8F%N;VXB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*
M;7-G:60@(DQE9G0B"FUS9W-T<B`B5N1N<W1E<B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3D@;&EB+TAO<F1E+T9O<FTN<&AP.C,Q,#4*;7-G
M:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E;D;G-T97)R=6)R:6LB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$U(&QI8B](;W)D92]&;W)M+G!H
M<#HS,3`Q"FUS9VED("),969T('9A;'5E<R(*;7-G<W1R(")6Y&YS=&5R=N1R
M9&5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,CD*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#,*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$R.2!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&5S;W1H;R(*;7-G<W1R("),97-O
M=&AO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M("),979E;"(*;7-G<W1R(").:7;E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@X(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EB
M97)I82(*;7-G<W1R("),:6)E<FEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$S,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX.0IM<V=I9"`B3&EB
M>6%N($%R86(@2F%M86AI<FEY82(*;7-G<W1R("),:6)Y96XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T,`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:65C:'1E;G-T96EN(@IM<V=S='(@(DQI96-H=&5N<W1E
M:6XB"@HC.B!C;VYF:6<O=&AE;65S+VQI9VAT8FQU92YP:'`Z-@IM<V=I9"`B
M3&EG:'0@0FQU92(*;7-G<W1R("),:G5S8FSE(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C4*;7-G:60@(DQI9VAT($1R:7IZ
M;&4B"FUS9W-T<B`B1'5G9W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HR-@IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R
M("),Y'1T(')E9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HR-PIM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("),
MY'1T(&;V<FUI9&1A9W-R96=N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,C@*;7-G:60@(DQI9VAT(%)A:6X@3&%T92(*;7-G
M<W1R("),Y'1T(&5F=&5R;6ED9&%G<W)E9VXB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR.0IM<V=I9"`B3&EG:'0@4F%I;B!3
M:&]W97(B"FUS9W-T<B`B3.1T="!R96=N<VMU<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P"FUS9VED("),:6=H="!286EN
M('=I=&@@5&AU;F1E<B(*;7-G<W1R("),Y'1T(')E9VX@;65D(.5S:V$B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,0IM<V=I
M9"`B3&EG:'0@4VYO=R(*;7-G<W1R("),Y'1T('-N]B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3
M;F]W(%-H;W=E<B(*;7-G<W1R("),Y'1T('-N]G-K=7(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(DQI
M;65R:6-K(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@Q-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3@Q.`IM<V=I9"`B3&EN:R(*;7-G<W1R("),Y&YK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4W"FUS9VED("),:6YK('!O:6YT<R!T;SHB"FUS9W-T<B`B3.1N
M:V5N('!E:V%R('#E.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M-S4@;&EB+TAO<F1E+T9O<FTN<&AP.C$X-SD*;7-G:60@(DQI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<B"FUS9W-T<B`B3.1N:V$@92UP;W-T861R97-S96X@=&EL;"!F=6YK=&EO
M;F5N(&;V<B!A='0@<VMA<&$@;GET="!M961D96QA;F1E(@H*(SH@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$X,PHC.B!F
M<F%M97=O<FLO5&5X="]497AT+T9I;'1E<B]H=&UL,G1E>'0N<&AP.C$U.`HC
M.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O:'1M;#)T97AT+G!H<#HQ.#(*;7-G
M:60@(DQI;FMS(@IM<V=S='(@(DSD;FMA<B(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DMA:V$B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-B!L
M:6(O2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#8*(SH@;&EB+TAO<F1E
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C@V"FUS9VED("),:7-T("T@=7-E<B!C
M86X@<V5E('1H92!F;VQD97(B"FUS9W-T<B`B3&ES=&$@+2!A;G;D;F1A<F4@
M:V%N('-E(&UA<'!E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*;7-G
M:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(E9I<V$@9&%T86)A<V5R(@H*
M(SH@<V5R=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3$*;7-G:60@(DQI<W0@2&5L
M<"!4;W!I8W,B"FUS9W-T<B`B5FES82!H:N1L<.1M;F5N(@H*(SH@861M:6XO
M<W%L<VAE;&PN<&AP.C$S,@IM<V=I9"`B3&ES="!486)L97,B"FUS9W-T<B`B
M3&ES=&$@=&%B96QL97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E
M<G,N<&AP.C4Y-"!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.30*;7-G
M:60@(DQI<W0M07)C:&EV92(*;7-G<W1R("),:7-T+4%R8VAI=F4B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.2!L:6(O2&]R9&4O
M34E-12](96%D97)S+G!H<#HU.#D*;7-G:60@(DQI<W0M2&5L<"(*;7-G<W1R
M("),:7-T+4AE;'`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N
M<&AP.C4Y-B!L:6(O2&]R9&4O34E-12](96%D97)S+G!H<#HU.38*;7-G:60@
M(DQI<W0M260B"FUS9W-T<B`B3&ES="U)9"(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O2&5A9&5R<RYP:'`Z-3DR(&QI8B](;W)D92]-24U%+TAE861E<G,N
M<&AP.C4Y,@IM<V=I9"`B3&ES="U/=VYE<B(*;7-G<W1R("),:7-T+4]W;F5R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3,@;&EB
M+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O<W0B
M"FUS9W-T<B`B3&ES="U0;W-T(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](
M96%D97)S+G!H<#HU.3$@;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'`Z-3DQ
M"FUS9VED("),:7-T+5-U8G-C<FEB92(*;7-G<W1R("),:7-T+5-U8G-C<FEB
M92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP(&QI
M8B](;W)D92]-24U%+TAE861E<G,N<&AP.C4Y,`IM<V=I9"`B3&ES="U5;G-U
M8G-C<FEB92(*;7-G<W1R("),:7-T+55N<W5B<V-R:6)E(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<R(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T
M="!L:7-T82!S97-S:6]N97(Z("5S(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP
M.C,W"B,L('!H<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D
M.B`E<R(*;7-G<W1R(")$970@9VEC:R!I;G1E(&%T="!L:7-T82!A;G;D;F1A
M<F4Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L:7-T+FEN8SHR
M"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("),
M:7-T;FEN9R!A=B!A;G;D;F1A<F4@879A:W1I=F5R860N(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C0W"FUS9VED("),:71E<F%T=7)E(@IM<V=S='(@
M(DQI='1E<F%T=7(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T
M-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$T-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,S(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),:71H=6%N:6$B"FUS
M9W-T<B`B3&ET875E;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEM86=E<RYP:'`Z.#,*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VEM86=E
M<RYP:'`Z-S<*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B3&%D9&%R+BXN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(P,`IM<V=I9"`B
M3&]C86P@=&EM93H@(@IM<V=S='(@(DQO:V%L('1I9#H@(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C@V"FUS9VED("),;V-A;&4@86YD(%1I;64B"FUS
M9W-T<B`B4F5G:6]N86QT(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HU-S$*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-S`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S(*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4W(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HR,@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C<R"FUS9VED
M("),;V-A=&EO;B(*;7-G<W1R(")0;&%T<R(*"B,Z(&QO9VEN+G!H<#HQ.#D@
M<V5R=FEC97,O<&]R=&%L+VUE;G4N<&AP.C$V,R!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C`P"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC
M.C,@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34*(SH@=&5M<&QA=&5S
M+VQO9VEN+VQO9VEN+FEN8SHY,"!T96UP;&%T97,O9W5E<W0O9W5E<W0N:6YC
M.C,P"FUS9VED("),;V<@:6XB"FUS9W-T<B`B3&]G9V$@:6XB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#4*;7-G:60@(DQO9R!O9B!P<F5V
M:6]U<R!S>6YC('-E<W-I;VXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R
M=&%L+VUE;G4N<&AP.C$U-R!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z
M,3DT"FUS9VED("),;V<@;W5T(@IM<V=S='(@(DQO9V=A('5T(@H*(SH@;&EB
M+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"FUS9VED("),;V=I;B(*;7-G<W1R("),
M;V=I;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3`*;7-G:60@(DQO
M9VEN(%1A<VMS(@IM<V=S='(@(DQO9VEN86MT:79I=&5T97(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+G!H<#HY.38@;&EB+TAO<F1E+T%U=&@N<&AP.CDY
M-0IM<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B
M(@HB26YL;V=G;FEN9R!M:7-S;'EC:V%D97,N(%1R;VQI9W1V:7,@=F%R(&%N
M=N1N9&%R;F%M;B!E;&QE<B!L]G-E;F]R9"`B"B)F96QA:W1I9W0N(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR(&QI8B](;W)D92]!=71H+G!H
M<#HY.3$*;7-G:60@(DQO9VEN(&9A:6QE9"XB"FUS9W-T<B`B26YL;V=G;FEN
M9R!M:7-S;'EC:V%D97,N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,V.0IM<V=I9"`B3&]N9R!T97AT
M(@IM<V=S='(@(DSE;F<@=&5X="(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R(")+Y')L96LB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV.`IM<V=I9"`B3&]W(@IM
M<V=S='(@(DSE9R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C$*;7-G:60@(DQO=V5R(&=R965K(&QE='1E
M<G,B"FUS9W-T<B`B1W)E:VES:V$@9V5M96YE<B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@
M(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B3&%T:6YS:V$@9V5M96YE
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,Z,3<*;7-G:60@(DQO=V5R(')O;6%N(&YU;6)E<G,B"FUS9W-T
M<B`B4VWE(')O;65R<VMA('-I9F9R;W(B"@HC.B!C;VYF:6<O=&AE;65S+VQU
M8RYP:'`Z-@IM<V=I9"`B3&]Y;VQA(@IM<V=S='(@(DQO>6]L82(*"B,Z(&-O
M;F9I9R]T:&5M97,O;'5C8FQU92YP:'`Z-@IM<V=I9"`B3&]Y;VQA($)L=64B
M"FUS9W-T<B`B3&]Y;VQA($)LY2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,30U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,30U"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQU>&5M
M8F]U<F<B"FUS9W-T<B`B3'5X96UB=7)G(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S"B,Z(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#$@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.2!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B
M34TB"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C@S"FUS9VED(")-3U1$(@IM<V=S='(@(DU/5$0B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS-B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%1B!B:6QA9V$@:6YN
M96CV;&P@:6YG96X@9&%T82XB"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N
M+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W"B,Z(&QI8B](
M;W)D92].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-PIM<V=I
M9"`B35-'(@IM<V=S='(@(DU31R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,34W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,U
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,34W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3(*;7-G:60@(DUA8V%O
M(@IM<V=S='(@(DUA8V%O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDQ(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-3,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$S
M-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%C961O;FEA
M+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUA
M8V5D;VYI96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$U,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-861A9V%S8V%R(@IM<V=S
M='(@(DUA9V%G87-K87(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M;7-G:60@(DUA9VEC(@IM<V=S='(@(DUA9VES:R(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HX,PIM<V=I9"`B36%I;"(*;7-G<W1R(")%+7!O<W0B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3(T"FUS9VED(")-86EL
M($%D;6EN(@IM<V=S='(@(D4M<&]S=&%D;6EN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")-
M86ME(&QI;E]K+BXN(@IM<V=S='(@(E-K87!A(&SD;FLN+BXB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-0HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QA=VDB"FUS9W-T<B`B36%L87=I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C<*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$S.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T<B`B36%L87ES:6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30P(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.CDT"FUS9VED(")-86QD:79E<R(*;7-G<W1R(")-86QD:79E<FYA(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDR(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-30*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T,2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HY,@IM<V=I9"`B36%L:2(*;7-G<W1R(")-86QI(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDT(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-C(*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C$T,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY
M-`IM<V=I9"`B36%L=&$B"FUS9W-T<B`B36%L=&$B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z.30*;7-G:60@(B(*(DUA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N(@IM
M<V=S='(@(B(*(E5N9&5R:.5L;"!L:7-T86X@;65D(&MA=&5G;W)I97(@9'4@
M86YVY&YD97(@9O9R(&%T="!K871E9V]R:7-E<F$@<&]S=&5R(&UE9"`B"B)O
M8V@@9N1R9V5R;F$@<V]M('1I;&QH]G(@9&5S<V$@:V%T96=O<FEE<BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$R-0HC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$U-@IM<V=I
M9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T+6MA<G1A(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-38*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-#`*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#<*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q-S$*;7-G:60@(DUA<%%U97-T
M(&UA<"(*;7-G<W1R(")-87!1=65S="UK87)T82(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I9"`B36%P<&EN9W,@<W1O<F5D+B(*
M;7-G<W1R("+6=F5R<^1T=&YI;F=A<B!S<&%R861E+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-SD*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-@HC.B!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T(&QI8B](;W)D92]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS9W-T<B`B;6%R
M<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")-87)G:6YA;"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X(&QI8B](
M;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT.`HC.B!L:6(O2&]R9&4O24U!
M4"]!0TPO<F9C,C`X-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N
M<V5E;B!F;&%G<R(*;7-G<W1R(")&;&%G9V$@<V]M(&SD<W0O;VSD<W0B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.2!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C-#,Q-"YP:'`Z-#D*(SH@;&EB+TAO<F1E+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C@Y"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R(")&;&%G
M9V$@;65D(&%N;F%N('-T871U<R`H="!E>"!V:6MT:6=T+V)E<W9A<F%T*2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,34R"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#,@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z.3$*;7-G:60@(DUA<G-H86QL($ES;&%N9',B"FUS9W-T<B`B
M36%R<VAA;&SV87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,34Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,34Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B
M"FUS9W-T<B`B36%R=&EN:7%U92(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3`S"FUS9VED(")-871C:&EN9R!F:65L9',B"FUS9W-T<B`B36%T
M8VAA;F1E(&;D;'0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$V,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.CDS"FUS9VED(")-875R:71A;FEA(@IM
M<V=S='(@(DUA=7)I=&%N:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#8*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].
M3%,O=&QD+G!H<#HQ-C,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP
M.C$T-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%U<FET
M:75S(@IM<V=S='(@(DUA=7)I=&EU<R(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@8W)E
M9&ET+B(*;7-G<W1R(")-87@@=&EL;.5T96X@:W)E9&ET+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`HC.B!L
M:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P.`IM<V=I9"`B36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM<V=S='(@(D=RY&YS(&;V<B!M
M87@@86YT86P@9&5L87(@:2!M961D96QA;F1E(/9V97)S:W)I9&5N+B(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S$S"FUS9VED(")-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B`B"FUS9W-T<B`B2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S
M=&4@,C0@=&EM;6%R;F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S`U
M"FUS9VED(")-87@@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R(")(]F=S
M=&$@=&5M<&5R871U<F4@<V5N87-T92`V('1I;6UA<FYA.B`B"@HC.B!L:6(O
M87!I+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L
M;V-K<R(*;7-G<W1R(")-87AI;6%L="!A;G1A;"!P;W)T86QB;&]C:R(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y."!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$W"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,SD@
M;&EB+TAO<F1E+T9O<FTN<&AP.CDP,B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(R
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3(T,PIM<V=I9"`B36%X:6UU;2!L
M96YG=&@B"FUS9W-T<B`B36%X:6UA;"!LY&YG9"(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HS.#$*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q.`HC.B!L:6(O2&]R9&4O54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V(&QI8B](;W)D92]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM<V=S='(@(FUA:B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(U,PHC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-PIM<V=I9"`B36%Y;W1T92(*;7-G<W1R(")-87EO='1E(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4P"FUS9VED(")-961I8VEN92(*
M;7-G<W1R(")-961I8VEN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HU,S$*;7-G:60@(DUE971I;F<@0V%N8V5L;&%T
M:6]N(@IM<V=S='(@(D%V8F]K82!M]G1E(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#,*;7-G:60@(DUE971I;F<@
M26YF;W)M871I;VXB"FUS9W-T<B`B3?9T97-I;F9O<FUA=&EO;B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3`Y"FUS
M9VED(")-965T:6YG(%!R;W!O<V%L(@IM<V=S='(@(DWV=&5S9O9R9G+E9V%N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,C4*;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B3?9T97-S=F%R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HU,30*;7-G:60@(DUE971I;F<@57!D871E(@IM<V=S='(@(DWV=&5S=7!P
M9&%T97)I;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C4Q.0IM<V=I9"`B365E=&EN9R!5<&1A=&4@4F5Q=65S="(*
M;7-G<W1R(")5<'!D871E<FEN9W-B96?D<F%N(&]M(&WV=&4B"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$V"FUS9VED(")-96UB97)S
M(@IM<V=S='(@(DUE9&QE;6UA<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS.#(*;7-G:60@(DUE;G4@;6]D93HB"FUS9W-T<B`B365N>6SD9V4Z(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS9W-T<B`B4VSE(&EH;W`@8V5L
M;&5R(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO
M3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+W-T871U<RYP:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")-97-S86=E(@IM<V=S='(@(DUE9&1E
M;&%N9&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q
M-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(Q-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(DUE9&1E;&%N9&5T('9E<FEF:65R861E<R!M96X@9&5N('-I9VYE<F%D
M97,@8V5R=&EF:6MA="!K=6YD92!I;G1E('9E<FEF:65R87,N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"B,Z
M(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$P"FUS9VED(")-
M97-S86=E(&5X<&ER960N(@IM<V=S='(@(DUE9&1E;&%N9&4@9^1L;&5R(&EN
M=&4@;.1N9W)E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C`R"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R-PHC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-C`*(SH@;&EB+TYE="]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C4V.2!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C`R"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8P"FUS9VED
M(")-97-S86=E('1Y<&4B"FUS9W-T<B`B365D9&5L86YD971Y<"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,PIM<V=I9"`B365T87(@5V5A=&AE<B(*;7-G
M<W1R(")-971A<G;D9&5R(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-PIM
M<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B365T
M87)B;&]C:V5T(.1R(&EN=&4@=&EL;&?D;F=L:70N(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HQ,3D*;7-G:60@(B(*(DUE=&%R(&)L;V-K(&YO="!A=F%I
M;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN
M:7-T<F%T;W(N(@IM<V=S='(@(B(*(DUE=&%R+6)L;V-K(&5J('1I;&QGY&YG
M;&EG="X@1&5T86QJ97(@:&%R(&QO9V=A=',@9O9R('-Y<W1E;6%D;6EN:7-T
M<F%T]G)E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34S
M"FUS9VED(")-971A<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(DUE
M=&%R1$(@Y'(@:6YT92!A;G-L=71E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8W(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-S$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)A<BYP
M:'`Z-C<@;&EB+TAO<F1E+TU)344O5FEE=V5R+WII<"YP:'`Z-S0*;7-G:60@
M(DUE=&AO9"(*;7-G<W1R(")-971O9"(*"B,Z(&9R86UE=V]R:R]24$,O4E!#
M+WAM;')P8RYP:'`Z.#$@9G)A;65W;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W
M"B,Z(&QI8B](;W)D92]24$,O>&UL<G!C+G!H<#HX,2!L:6(O2&]R9&4O4E!#
M+W-O87`N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")-971H;V0@7"(E
M<UPB(&ES(&YO="!D969I;F5D(@IM<V=S='(@(DUE=&]D96X@)R5S)R#D<B!I
M;G1E(&1E9FEN:65R860B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]R97-T+G!H
M<#HV,2!L:6(O2&]R9&4O4E!#+W)E<W0N<&AP.C@R"B,L('!H<"UF;W)M870*
M;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,B
M"FUS9W-T<B`B365T;V1E;B!H87(@:6YT92!D969I;F5R871S+B!!;G)O<&%D
M(&UE=&]D.B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV
M-R!L:6(O0FQO8VLO;65T87(N<&AP.C@R"FUS9VED(")-971R:6,B"FUS9W-T
M<B`B365T<FES:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-2!L:6(O2&]R9&4O3DQ3+W1L9"YP
M:'`Z,38V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-#@@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DUE>&EC;R(*;7-G<W1R
M(")-97AI:V\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M.#4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$T.2!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B(*;7-G<W1R(")-:6MR;VYE<VEE;B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I
M9"`B36ED9&QE(@IM<V=S='(@(DUI='1E;B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W1N968N<&AP.C,X(&QI8B](;W)D92]-24U%+U9I97=E
M<B]T;F5F+G!H<#HS.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;65T
M>7`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,Q-PIM<V=I9"`B36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(DSD9W-T82!T96UP97)A='5R
M('-E;F%S=&4@,C0@=&EM;6%R;F$Z("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S`Y"FUS9VED(")-:6X@=&5M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R
M("),Y&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#8@=&EM;6%R;F$Z("(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#,Y(&QI8B](;W)D92]!
M=71H+VQD87`N<&AP.C0S.0IM<V=I9"`B36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9"(*;7-G<W1R(")-:6YS=&$@;/9S96YO<F1S
MY6QD97(@:&%R(&EN=&4@=7!P;N5T=',@Y&XB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C$W"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR,S4*;7-G:60@(DUI<G)O<B(*;7-G<W1R
M(")3<&5G;&$B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@
M(DUI<V-E;&QA;F5O=7,B"FUS9W-T<B`B1&EV97)S92(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,"!L:6(O3F5T
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z(&QI8B].970O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S0P(&QI8B].970O4TU3+W=I;E]H='1P+G!H
M<#HR-3`*;7-G:60@(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="XB"FUS9W-T<B`B3V)L:6=A=&]R:7-K="!P86ME="!S86MN87,@*%!%05(@
M2%144%]297%U97-T*2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$U
M"FUS9VED("(B"B)-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R`B"B)A
M<'!L:6-A=&EO;BXB"FUS9W-T<B`B(@HB2V]N9FEG=7)A=&EO;B!S86MN87,N
M($1U(&WE<W1E('-K87!A(&1E;B!N=2!O;2!D=2!V:6QL(&%N=N1N9&$@9&5N
M(&CD<B`B"B)A<'!L:6MA=&EO;F5N+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-`HC.B!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,P-`IM<V=I9"`B36ES<VEN9R!M97-S86=E
M($E$+B(*;7-G<W1R(")386MN87(@;65D9&5L86YD92U)1"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HU.`HC
M.B!L:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C4X"FUS9VED
M(")-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+B(*;7-G<W1R
M(")/8FQI9V%T;W)I<VMT('!A:V5T('-A:VYA<R`H4$5!4B!-86EL*2XB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.30*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.30*;7-G
M:60@(DUI<W-I;F<@<V5S<VEO;B!)1"XB"FUS9W-T<B`B4V%K;F%R('-E<W-I
M;VYS+4E$+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-38*;7-G:60@(DUO(@IM<V=S='(@(DWE(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C<V"FUS9VED(")-;V)I;&4@36%I;"(*;7-G<W1R
M(")-;V)I;"!E+7!O<W0B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HV.0IM<V=I9"`B36]D97)A=&4B"FUS9W-T<B`B36]D97)E
M<F$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C8V
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-S`*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX."!L:6(O2&]R9&4O
M34E-12]6:65W97(O<F%R+G!H<#HV-@HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O>FEP+G!H<#HW,R!L:6(O2&]R9&4O34E-12]6:65W97(O=&=Z+G!H<#HX
M-0IM<V=I9"`B36]D:69I960@1&%T92(*;7-G<W1R("+$;F1R860@9&%T=6TB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3,*;7-G:60@(DUO9&EF>2!54DPB"FUS9W-T<B`BQ&YD<F$@;.1N
M:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C<T"FUS9VED(")-;V1U;'5S(@IM
M<V=S='(@(DUO9'5L=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$U,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34P
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VQD;W9A+"!2
M97!U8FQI8R!O9B(*;7-G<W1R(")-;VQD879I96XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$T.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$U,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3`@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$T.0HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDP"FUS
M9VED(")-;VYA8V\B"FUS9W-T<B`B36]N86-O(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HQ-38*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C$U,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I
M9"`B36]N9V]L:6$B"FUS9W-T<B`B36]N9V]L:65T(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C4Y-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C4X.`IM
M<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B3>5N860@;V-H(.5R(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-R!L
M:6(O2&]R9&4O36%I;G1E;F%N8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM
M<V=S='(@(DWE;F%T;&EG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3,*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-C$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$U
M,R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36]N='-E<G)A
M="(*;7-G<W1R(")-;W1S97)R870B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z
M,R!L:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM
M<V=S='(@(DWE;F9A<V5R(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,3<R(&9R86UE=V]R:R]&:6QE7T-35B]#4U8N<&AP.C(U,PHC.B!L:6(O
M1FEL92]#4U8N<&AP.C$Y-B!L:6(O1FEL92]#4U8N<&AP.C(X,`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+B(*;7-G<W1R(")&;&5R(&;D;'0@:&ET=&%D
M97,@<.4@<F%D("5D(.1N(&1E="!F]G)VY&YT861E("5D+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,30X"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-30@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3`*;7-G:60@(DUO<F]C8V\B"FUS9W-T<B`B36%R;V-K;R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S"FUS9VED(")-;W-T
M;'D@0VQE87(B"FUS9W-T<B`B365S=&%D96QS(&ML87)T(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*;7-G:60@(DUO<W1L
M>2!#;&]U9'DB"FUS9W-T<B`B365S=&%D96QS(&UO;&YI9W0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S
M=&QY(%-U;FYY(@IM<V=S='(@(DUE<W1A9&5L<R!S;VQI9W0B"@HC.B!F<F%M
M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU,#D@;&EB+TAO<F1E+T)L
M;V-K+TQA>6]U="YP:'`Z-3`Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z-C0X"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`B1FQY
M='1A(&YE9"(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP
M.C4Q,R!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HU,3,*(SH@;&EB+TAO
M<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HV-3(*;7-G:60@(DUO=F4@
M3&5F="(*;7-G<W1R(")&;'ET=&$@=N1N<W1E<B(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.C4Q-R!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HU,3<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HV-38*;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`B1FQY='1A(&CV
M9V5R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3`U
M(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C4P-0HC.B!L:6(O2&]R9&4O
M0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8T-`IM<V=I9"`B36]V92!5<"(*
M;7-G<W1R(")&;'ET=&$@=7!P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Y.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(V"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T<B`B1FQY
M='1A(&YE9"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HT.3@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0Y.0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-3(U(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HU,C8*;7-G
M:60@(DUO=F4@=7`B"FUS9W-T<B`B1FQY='1A('5P<"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,38X"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HQ-34@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUO>F%M8FEQ=64B"FUS9W-T<B`B36_G86UB:7%U92(*"B,Z(&-O
M;F9I9R]T:&5M97,O;6]Z:6QL82YP:'`Z-@IM<V=I9"`B36]Z:6QL82(*;7-G
M<W1R(")-;WII;&QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X
M-"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C$X.`IM<V=I9"`B375L=&DM;&5V96P@
M9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(D9L97)N:7;E<VQI<W1A(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,C<*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-3@*;7-G:60@
M(DUU;'1I;6%P(%5+(&UA<"(*;7-G<W1R(")-=6QT:6UA<"!3=&]R8G)I=&%N
M;FEE;FMA<G1A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,B!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,C(T-@IM<V=I9"`B375L=&EP;&4@<V5L96-T
M:6]N(@IM<V=S='(@(D9L97)V86PB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#`R"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(DUI='0@:V]N
M=&\B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z,C@*;7-G:60@(DUY($%C
M8V]U;G0@26YF;W)M871I;VXB"FUS9W-T<B`B36EN(&MO;G1O:6YF;W)M871I
M;VXB"@HC.B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C0U"FUS9VED(")-
M>2!0;W)T86PB"FUS9W-T<B`B36EN('!O<G1A;"(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]E9&ET+G!H<#HT,PIM<V=I9"`B37D@4&]R=&%L($QA>6]U="(*;7-G
M<W1R(")-:6X@<&]R=&%L;&%Y;W5T(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HQ-34*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$U-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY,@IM<V=I9"`B37EA
M;FUA<B(*;7-G<W1R(")->6%N;6%R(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C<*(SH@=&5M<&QA=&5S+VUA:6YT
M96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3<*;7-G:60@(DY/+"!)($1O($Y/
M5"!!9W)E92(*;7-G<W1R(").14HL($IA9R!A8V-E<'1E<F%R(&EN=&4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#`@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$P,@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS.`HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,R!L:6(O2&]R9&4O0W)Y
M<'0O<&=P+G!H<#HT,3$*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W1N968N<&AP.C,X"FUS
M9VED(").86UE(@IM<V=S='(@(DYA;6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$V.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34W(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDU"FUS9VED(").
M86UI8FEA(@IM<V=S='(@(DYA;6EB:6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C$W.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M875R=2(*;7-G<W1R(").875R=2(*"B,Z(&-O;F9I9R]T:&5M97,O3F585&=R
M97DN<&AP.C8*;7-G:60@(DYE6%0B"FUS9W-T<B`B3F585"(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S`V"FUS9VED
M(").965D<R!!8W1I;VXB"FUS9W-T<B`B0F5H]G9E<B#E=&?D<F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-PHC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDW"FUS9VED(").97!A;"(*;7-G<W1R(").97!A;"(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<U"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.3<*;7-G:60@(DYE=&AE<FQA;F1S(@IM<V=S='(@(DYE9&5R;.1N9&5R;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HU-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V,2!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HU-PIM<V=I9"`B3F5T:&5R;&%N9',@06YT:6QL97,B"FUS9W-T
M<B`B3F5D97)LY&YD<VMA($%N=&EL;&5R;F$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4X,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5S
M8V%P92!B87,M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#0*;7-G:60@
M(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U(&QI8B](;W)D92]#
M<GEP="]S;6EM92YP:'`Z-3@V"FUS9VED(").971S8V%P92!#02!P;VQI8WD@
M55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-3@T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED
M(").971S8V%P92!296YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!F]G)N
M>65L<V4M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HU.#(@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE
M='-C87!E(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE='-C87!E(.5T97)K
M86QL96QS92U54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X-B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE='-C87!E(%-3
M3"US97)V97)N86UN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.#<@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU.#@*;7-G:60@
M(DYE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V%P
M92!C97)T:69I:V%T<VMO;6UE;G1A<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@P(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M-3@Q"FUS9VED(").971S8V%P92!C97)T:69I8V%T92!T>7!E(@IM<V=S='(@
M(DYE='-A<&4@8V5R=&EF:6MA='-T>7`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C4S"FUS9VED(").971W;W)K(@IM<V=S='(@(D[D='9E<FLB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,30@;&EB+TAO
M<F1E+T-R>7!T+W!G<"YP:'`Z-#(U"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HS,SD@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,Y,`IM<V=I9"`B3F5V97(B
M"FUS9W-T<B`B06QD<FEG(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU(&QI8B](;W)D92].3%,O
M=&QD+G!H<#HQ-S`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$V
M,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B3F5W($-A;&5D
M;VYI82(*;7-G<W1R(").>6$@2V%L961O;FEE;B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z(&QI8B](;W)D
M92]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4P"B,Z('1E;7!L871E<R]P
M<F5F<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C(V"FUS9VED(").97<@0V%T
M96=O<GDB"FUS9W-T<B`B3GD@:V%T96=O<FDB"@HC.B!L:6(O2&]R9&4O5&5X
M="]&:6QT97(O96UA:6QS+G!H<#HX,2!L:6(O2&]R9&4O5&5X="]&:6QT97(O
M96UA:6QS+G!H<#HX-PHC.B!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS
M+G!H<#HY-R!L:6(O2&]R9&4O5&5X="]&:6QT97(O96UA:6QS+G!H<#HQ,#$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A9V4@=&\@)7,B"FUS9W-T
M<B`B3GET="!M961D96QA;F1E('1I;&P@)7,B"@HC.B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C:R]M;V]N
M+G!H<#HQ-S0*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(DYY;>5N92(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S4*;7-G:60@(DYE
M=R!5<V5R;F%M92`H;W!T:6]N86PI(@IM<V=S='(@(DYY='0@86YVY&YD87)N
M86UN("AV86QF<FET="DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$X,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38S
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX"FUS9VED(").97<@6F5A;&%N
M9"(*;7-G<W1R(").>6$@6F5E;&%N9"(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HS-PIM<V=I9"`B3F5W('!A<W-W;W)D(@IM<V=S='(@(DYY
M='0@;/9S96YO<F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M,C(W(&QI8B](;W)D92]!=71H+W-Q;"YP:'`Z,C(W"B,L('!H<"UF;W)M870*
M;7-G:60@(DYE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"XB"FUS9W-T
M<B`B3GET="!L]G-E;F]R9"!K;VUM97(@871T(&?E('5T("5X+B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HU,@IM<V=I9"`B3F5W('!A<W-W
M;W)D<R!D;VXG="!M871C:"XB"FUS9W-T<B`B3/9S96YO<F0@;>5S=&4@=F%R
M82!S86UM82XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@
M(DYY='0@9O9N<W1E<B`H7V)L86YK*2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N
M<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,CDQ"FUS9VED(").97=S(@IM<V=S='(@(DYY:&5T
M97(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S`W"FUS9VED(").
M97=S9W)O=7!S(@IM<V=S='(@(DYY:&5T<V=R=7!P97(B"@HC.B!T96UP;&%T
M97,O9&%T82]T<W9I;F9O+FEN8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P
M+FEN8SHT,0HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R
M(").Y'-T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-PIM<V=I9"`B3F5X
M="`T(%!H87-E<R(*;7-G<W1R(")+;VUM86YD92`T(&9A<V5R(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S`@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HS-S0*(SH@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS
M-C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HS-S`*;7-G:60@(DYE>'0@;W!T
M:6]N<R(*;7-G<W1R(").Y'-T82!I;G-TY&QL;FEN9V%R(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,#,@;&EB+TAO<F1E+U5)+U!A9V5R+G!H
M<#HQ,#,*;7-G:60@(DYE>'0^(@IM<V=S='(@(D[D<W1A/B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<T"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI8V%R86=U82(*;7-G<W1R(").:6-A<F%G=6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$V-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.38@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W,0HC.B!L:6(O2&]R
M9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38U(&QI8B](;W)D92].3%,O1V5O25`N
M<&AP.CDV"FUS9VED(").:6=E<B(*;7-G<W1R(").:6=E<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<S"B,Z(&QI8B](;W)D92].
M3%,O8V]U;G1R:65S+G!H<#HQ-C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYI9V5R:6$B"FUS9W-T<B`B3FEG97)I82(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS-CD*;7-G:60@(DYI9VAT(@IM<V=S
M='(@(DYA='0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C$W.0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.CDW"FUS9VED(").:75E(@IM<V=S='(@(DYI
M=64B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M.3,U"B,Z(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HY-C8*
M;7-G:60@(DYO(@IM<V=S='(@(DYE:B(*"B,Z('1E;7!L871E<R]A9&UI;B]S
M971U<"]D:69F+FAT;6PZ.0IM<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`B
M1&5T(&9I;FYS(&EN9V5T(&MO;F9I9W5R871I;VYS9&%T82!A='0@=FES82!S
M:VEL;&YA9&5R(&;V<BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(N<&AP.C$P-0HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(N<&AP.C$Q,2!L:6(O5D93+TE33U=R:71E<BYP:'`Z,3`V"FUS9VED(").
M;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+B(*
M;7-G<W1R("));F=E;B!T:6QL9^1N9VQI9R!S=')A=&5G:2!F]G(@871T('-K
M87!A($E33RUI;6%G92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,3,*(SH@;&EB+TYE="]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HS,3,*;7-G:60@(DYO(&)A=&-H('1E;7!L871E+B(*;7-G
M<W1R("));G1E(&5N(&)A=&-H;6%L;"XB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO3&%Y;W5T+G!H<#HW.2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+G!H<#HR-#4*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z,C8W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C<Y"B,Z(&QI8B](
M;W)D92]";&]C:R],87EO=70N<&AP.C(T-2!L:6(O2&]R9&4O0FQO8VLO3&%Y
M;W5T+G!H<#HR-C<*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R
M+G!H<#HQ,#$*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HS.#4*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M,#<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(@IM<V=S='(@(D1E="!F:6YN<R!I;F=E="!B;&]C:R!PY2!D96X@
M8F5GY')D82!P;W-I=&EO;F5N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]M
M8V%L+G!H<#HU,"!L:6(O2&]R9&4O075T:"]M8V%L+G!H<#HU,`IM<V=I9"`B
M3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A
M=&EO;BXB"FUS9W-T<B`B26YG970@:V%L96YD97)N86UN(&;V<B!-0T%,(&%U
M=&5N=&ES97)I;F<@86YG:79E="XB"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HU-`IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G<W1R("));F=E;B#D;F1R:6YG
M+B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V(&QI8B](
M;W)D92]097)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@
M8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("));F=A('5N
M9&5R8F5H]G)I9VAE=&5R(&MA;B!LY&=G87,@=&EL;"!D96X@:.1R(&)E:/9R
M:6=H971E;BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X,@HC.B!F<F%M97=O<FLO571I
M;"]5=&EL+G!H<#HW-S,@;&EB+TAO<F1E+G!H<#HQ-CD@;&EB+TAO<F1E+G!H
M<#HU,#@*(SH@;&EB+TAO<F1E+U5T:6PN<&AP.C<V.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@)7,N(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M
M871I;VX@86YG:79E;B!F]G(@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HX,C0@;&EB+U9&4R]F='`N<&AP.C@U-0IM<V=I9"`B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N
M(@IM<V=S='(@(DEN9V5N(&MO;F9I9W5R97)I;F=S:6YF;W)M871I;VX@86YG
M:79E;B!F]G(@1E10(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN
M<&AP.C8V.2!L:6(O5D93+W-Q;"YP:'`Z-C<R"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS
M9W-T<B`B26YG96X@:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N
M(&;V<B!344P@5D93+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HW,3<@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z-S(U"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R("));F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T
M:6]N(&%N9VEV96X@9O9R(%-13"UF:6P@5D93+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`HC.B!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B3F\@8W)E9&ET
M(&QE9G0N(@IM<V=S='(@(DEN9V5N(&MR961I="!K=F%R+B(*"B,Z(&9R86UE
M=V]R:R],:6YK<R],:6YK<RYP:'`Z,C4V"B,Z(&9R86UE=V]R:R]296QA=&EO
M;G-H:7`O4F5L871I;VYS:&EP36%N86=E<BYP:'`Z,C4Q"FUS9VED(").;R!D
M97-C<FEP=&EO;B!F;W5N9"(*;7-G<W1R(")"97-K<FEV;FEN9R!S86MN87,N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S0*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM
M<V=I9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DEN9V5N
M(&UO='1A9V%R92!A;F=I=F5N+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R
M;W=S97(N<&AP.C@W,B!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.3(P"FUS9VED
M(").;R!F:6QE('5P;&]A9&5D(@IM<V=S='(@(DEN9V5N(&9I;"!U<'!L861D
M860B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC
M;VYS(&9O=6YD+B(*;7-G<W1R("));F=A(&EK;VYE<B!H:71T861E<RXB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$V(&QI8B]";&]C:R]S
M=6YR:7-E+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$S,`IM<V=I
M9"`B3F\@;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R("));F=E;B!O<G0@86YG
M:79E;BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"FUS
M9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B26YG96X@;W)T
M(&%N9VEV96XN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S,*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8S,PIM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS9W-T<B`B
M26YG970@;65D9&5L86YD92!B:69O9V%D97,N(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(SH@;&EB+TYE="]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8S-@IM<V=I9"`B3F\@;F%M92!S<&5C
M:69I960N(@IM<V=S='(@(DEN9V5T(&YA;6X@86YG:79E="XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-PHC.B!L
M:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N
M=6UB97(@<W!E8VEF:65D+B(*;7-G<W1R("));F=E;B!N=6UM97(@86YG:79E
M="XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.30*;7-G:60@(DYO(&]F
M9F5N<VEV92!F;W)T=6YE<R(*;7-G<W1R("));F=A(&]F]G)S:^1M9&$@=FES
M:&5T<V]R9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$@
M;&EB+TAO<F1E+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R("))
M;F=E="!L]G-E;F]R9"!F]G(@2%144"UA=71E;G1I<V5R:6YG(&%N9VEV970N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HQ,#@@;&EB+TAO
M<F1E+T%U=&@O:6UA<"YP:'`Z,3`X"FUS9VED(").;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@
M;/9S96YO<F0@9O9R($E-05`M875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(@;&EB+TAO<F1E+T%U
M=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B26YG970@;/9S
M96YO<F0@9O9R($ME<F)E<F]S+6%U=&5N=&ES97)I;F<@86YG:79E="XB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C<W(&9R86UE=V]R:R]!
M=71H+T%U=&@O;&]G:6XN<&AP.C@T"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%M+G!H<#HW-2!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HW-PHC.B!L:6(O
M2&]R9&4O075T:"]L;V=I;BYP:'`Z.#0@;&EB+TAO<F1E+T%U=&@O<&%M+G!H
M<#HW-0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+B(*;7-G<W1R("));F=E="!L]G-E;F]R9"!F]G(@3&]G
M:6XM875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O<&%S<W=D+G!H<#HQ,S4@;&EB+TAO<F1E+T%U=&@O<&%S<W=D+G!H
M<#HQ,S4*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(DEN9V5T(&SV<V5N;W)D(&;V<B!0
M05-35T0M875T96YT:7-E<FEN9R!A;F=I=F5T+B(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<VUB+G!H<#HX-"!L:6(O2&]R9&4O075T:"]S;6(N<&AP.C@T
M"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I
M8V%T:6]N+B(*;7-G<W1R("));F=E="!L]G-E;F]R9"!F]G(@4TU"+6%U=&5N
M=&ES97)I;F<@86YG:79E="XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C$R.#8@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HQ,C@W
M"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R`B"B)W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P96YD:6YG
M('-I9VYU<',N(@IM<V=S='(@(DEN9V$@=N1N=&%N9&4@<F5G:7-T<F5R:6YG
M87(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C<T.`IM<V=I9"`B3F\@
M<75O=&$@<V5T(@IM<V=S='(@(DEN9V5N(&MV;W1A(&%N9VEV96XB"@HC.B!L
M:6(O5D93+G!H<#HW-C8*;7-G:60@(DYO('%U;W1A('-E="XB"FUS9W-T<B`B
M26YG96X@:W9O=&$@86YG:79E;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0S"FUS9VED(").;R!R=6QE<R(*
M;7-G<W1R("));F=A(')E9VQE<B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T.2!L:6(O1FEL92]#4U8N<&AP.C0X,@IM<V=I9"`B3F\@<V5P
M87)A=&]R('-P96-I9FEE9"XB"FUS9W-T<B`B26YG96X@879G<N1N<V%R92!A
M;F=I=F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z-#0*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(DEN9V$@
M<VED;W(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,R!L:6(O
M5D93+W-M8BYP:'`Z-3@W"FUS9VED(").;R!S=6-H(&9I;&4B"FUS9W-T<B`B
M26YG96X@<^5D86X@9FEL(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C$R-@IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+B(*;7-G<W1R("));F=E;B!T96UP;W+D<FMA=&%L;V<@
M=&EL;&?D;F=L:6<@9O9R(&-A8VAE+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,S$*(SH@;&EB+TYE="]335,O=VEN7VAT='`N<&AP.C(R
M,0IM<V=I9"`B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N(@IM
M<V=S='(@(DEN9V5T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO<F0@
M<VMI8VMA="XB"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR<&,N<&AP.C$T
M,"!L:6(O2&]R9&4O4E!#+WAM;')P8RYP:'`Z,30P"FUS9VED(").;R!V86QI
M9"!834P@9&%T82!R971U<FYE9"(*;7-G<W1R("));F=E="!G:6QT:6<@6$U,
M+61A=&$@<F5T=7)N97)A9&5S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.CDT,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z.34S"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HY-C0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.CDX,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z.3<T(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.#0*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDY
M-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`Q,@IM
M<V=I9"`B3F\@=F%L=65S(@IM<V=S='(@(DEN9V$@=N1R9&5N(@H*(SH@861M
M:6XO<V5T=7`O:6YD97@N<&AP.C$R,`IM<V=I9"`B3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(DEN9V5N('9E<G-I;VX@:&ET=&%D97,@
M:2!D96X@=7)S<')U;F=L:6=A(&MO;F9I9W5R871I;VYE;BX@Q71E<G-K87!A
M("(*(FMO;F9I9W5R871I;VYE;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3(X"FUS9VED(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG
M=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("))
M;F=E;B!V97)S:6]N(&AI='1A9&5S(&D@9&EN(&MO;F9I9W5R871I;VXN(,5T
M97)S:V%P82!K;VYF:6=U<F%T:6]N96XN(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,#0*;7-G:60@(DYO;B!087)T
M:6-I<&%N="(*;7-G<W1R("))8VME+61E;'1A9V%R92(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q-@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,"!L:6(O2&]R9&4O0W)Y<'0O
M<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES
M96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S='(@(DEN9V5N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,`IM<V=I
M9"`B3F]N92`H=7-E(&EM<&QI8VET*2(*;7-G<W1R("));F=E;B`H86YVY&YD
M('5N9&5R9O9R<W3E9&0I(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3(*
M;7-G:60@(DYO<F1I8R`H25-/+3@X-3DM,3`I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3<R"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ-C@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(DYO<F9O;&OV
M87)N82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O
M;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B
M3F]R<F$@:&5M:7-FY')E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38Y"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,R!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,34X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M-CD@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DYO<G1H97)N
M($UA<FEA;F$@27-L86YD<R(*;7-G<W1R(").;W)R82!-87)I86YA]F%R;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.3<@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$W-@HC.B!L
M:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<P(&QI8B](;W)D92].3%,O
M1V5O25`N<&AP.CDW"FUS9VED(").;W)W87DB"FUS9W-T<B`B3F]R9V4B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8T,"!L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP.C8T,0IM<V=I9"`B3F]T($%F=&5R(@IM<V=S
M='(@(DEN=&4@969T97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8S.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8T,`IM<V=I
M9"`B3F]T($)E9F]R92(*;7-G<W1R("));G1E(&;V<F4B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HT,#@@;&EB+U9&4R]F:6QE+G!H<#HT,34*
M;7-G:60@(DYO="!A(&1I<F5C=&]R>2(*;7-G<W1R("));G1E(&5N(&MA=&%L
M;V<B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP
M.C8S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L
M3W5T<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0HC.B!F<F%M97=O<FLO5D93
M7TE33R])4T]7<FET97(N<&AP.C8W"B,Z(&9R86UE=V]R:R]61E-?25-/+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C@T"B,Z(&9R86UE=V]R
M:R]61E-?25-/+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDU
M"B,Z(&9R86UE=V]R:R]61E-?25-/+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2YP:'`Z-#D*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+G!H<#HV,`HC.B!L:6(O5D93+TE33U=R:71E<BYP
M:'`Z-C,@;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H
M<#HX-`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN
M<&AP.CDU"B,Z(&QI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y
M+G!H<#HT.`HC.B!L:6(O5D93+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-3D*;7-G:60@(DYO="!I;7!L96UE;G1E9"XB"FUS9W-T<B`B16H@
M:6UP;&5M96YT97)A9"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8X"FUS9VED(").;W0@<V5T(@IM<V=S='(@(D5J(&%N
M9VEV96XB"@HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T,PHC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L97(O4V5S
M<VEO;DAA;F1L97(N<&AP.C$U.`HC.B!F<F%M97=O<FLO4V5S<VEO;DAA;F1L
M97(O4V5S<VEO;DAA;F1L97(N<&AP.C$W,PHC.B!F<F%M97=O<FLO4V5S<VEO
M;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C$X-PHC.B!F<F%M97=O<FLO
M4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(N<&AP.C(S-"!F<F%M97=O
M<FLO5D93+U9&4RYP:'`Z,3DP"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR
M,#4@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C0X(&9R86UE=V]R:R]61E,O5D93+G!H<#HR-C4*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,CDW"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,3(@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C,R.0HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S8R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HT,C(*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C4P,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3<P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU.#<@9G)A;65W;W)K+U9&4R]61E,N<&AP.C8V-2!L
M:6(O5D93+G!H<#HQ.3,*(SH@;&EB+U9&4RYP:'`Z,C`X(&QI8B]61E,N<&AP
M.C(S-"!L:6(O5D93+G!H<#HR-3(@;&EB+U9&4RYP:'`Z,C8Y"B,Z(&QI8B]6
M1E,N<&AP.C(X-2!L:6(O5D93+G!H<#HS,#$@;&EB+U9&4RYP:'`Z,S$V(&QI
M8B]61E,N<&AP.C,S,PHC.B!L:6(O5D93+G!H<#HS-C8@;&EB+U9&4RYP:'`Z
M-#(V(&QI8B]61E,N<&AP.C4P-2!L:6(O5D93+G!H<#HU-S0*(SH@;&EB+U9&
M4RYP:'`Z-3DQ(&QI8B]61E,N<&AP.C8V.2!L:6(O2&]R9&4O4V5S<VEO;DAA
M;F1L97(N<&AP.C$T-0HC.B!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP
M.C$V,"!L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$W-0HC.B!L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP.C$X.2!L:6(O2&]R9&4O4V5S<VEO
M;DAA;F1L97(N<&AP.C(S-@IM<V=I9"`B3F]T('-U<'!O<G1E9"XB"FUS9W-T
M<B`B4W3V9',@:6YT92XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]V8V%R9"YP:'`Z,C0T"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0T(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#4X"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#`*;7-G:60@(DYO=&5S(@IM<V=S='(@
M(D%N=&5C:VYI;F=A<B(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN9&5X+G!H
M<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN(@IM<V=S
M='(@(DEN9V5N=&EN9R!A='0@=FES82P@9^4@=&EL;&)A:V$N(@H*(SH@=&5M
M<&QA=&5S+VUA:6YT96YA;F-E+V-O;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B
M3F]T:6-E(@IM<V=S='(@(D]"4R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HS.#<*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0R-`HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#$R(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL
M+G!H<#HT-3`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A
M<BYJ<SHW-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`B;F]V96UB97(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#0V(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#4P"FUS9VED(").=6UB97(B"FUS9W-T<B`B3G5M;65R(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30R-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,30R.0IM<V=I9"`B3G5M8F5R(&]F(&-H87)A8W1E<G,B"FUS9W-T<B`B
M06YT86P@=&5C:V5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$T-#4@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S,*(SH@
M;&EB+TAO<F1E+T9O<FTN<&AP.C$T,C<@;&EB+TAO<F1E+T9O<FTN<&AP.C$T
M-#D*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS(@IM<V=S='(@(D%N=&%L(&MO
M;'5M;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#,@;&EB+TAO<F1E+T9O<FTN<&AP.C$S-S$*(SH@;&EB+TAO
M<F1E+T9O<FTN<&AP.C$T,C4@;&EB+TAO<F1E+T9O<FTN<&AP.C$T-#<*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#(*;7-G
M:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(D%N=&%L(')A9&5R(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#0*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T-`IM<V=I9"`B
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`B3G5M;65R(&EN=&4@<W!E8VEF:6-E<F%D
M92!F]G(@871T('5P<&1A=&5R82!I(&1I<W1R:6)U=&EO;G-L:7-T86XN(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M.#,*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HV-C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C8T"FUS9VED(")/2R(*;7-G<W1R(")/2R(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX-#8*(SH@;&EB+TAO<F1E+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I9"`B3V)J96-T(@IM<V=S='(@
M(D]B:F5K="(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Q"FUS
M9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R(")/8FIE:W1S:V%P87)E(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$P-"!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,3$P.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B3VMT86PB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S@V"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,C,*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,2!L:6(O2&]R9&4O
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS
M9W-T<B`B;VMT;V)E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B1FEL=&5R(&;V<B!O9O9R
M<VOD;61H971E<B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C@*
M;7-G:60@(D]F9FEC92(*;7-G<W1R(")+;VYT;W(B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="XB"FUS9W-T<B`B1V%M;6%L="!O8V@@
M;GET="!L]G-E;F]R9"!FY7(@:6YT92!V87)A('-A;6UA+B(*"B,Z('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@IM<V=I9"`B3VQD('!A<W-W;W)D
M(@IM<V=S='(@(D=A;6UA;'0@;/9S96YO<F0B"@HC.B!S97)V:6-E<R]C:&%N
M9V5P87-S=V]R9"YP:'`Z-#8*;7-G:60@(D]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="XB"FUS9W-T<B`B1V%M;6%L="!L]G-E;F]R9"#D<B!F96QA:W1I
M9W0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,0HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Q(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(D]M86XB"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HW,R!L:6(O
M2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G:60@(D]N;'D@24U!
M4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N(@IM<V=S='(@(D1E
M;&%D92!M87!P87(@<W3V9',@96YB87)T(&%V($E-05`M<V5R=G)A<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-0IM<V=I9"`B3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,B"FUS9W-T<B`B16YB87)T(&]F]G)S:^1M9&$@=FES:&5T
M<V]R9"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3DW,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3@U-2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3DW-0IM<V=I9"`B3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R(")%;F1A<W0@96X@92UP
M;W-T861R97-S('1I;&SE=&5N+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HV-0IM<V=I9"`B(@HB3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D
M;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@(@HB
M<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4B"FUS9W-T<B`B(@HB16YD87-T(.1G
M87)E(&5L;&5R('-Y<W1E;6%D;6EN:7-T<F%T]G(@:V%N(.1N9')A(.1G87)E
M(&5L;&5R(&)E:/9R:6=H971E<B!PY2`B"B)E;B!U=&1E;&YI;F<B"@HC.B!L
M:6(O0FQO8VLO:69R86UE+G!H<#HS.2!L:6(O0FQO8VLO:69R86UE+G!H<#HT
M,`IM<V=I9"`B3W!E;B!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BUG!P;F$@
M:2!N>71T(&;V;G-T97(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C(T-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(T-0IM<V=I
M9"`B3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M
M('-I9VYE9"!3+TU)344@<&%R="XB"FUS9W-T<B`B(@HB3W!E;E-33"UF96PZ
M($1E="!G:6-K(&EN=&4@871T(&5X=')A:&5R82!D871A(&9RY6X@<VEG;F5R
M860@4R]-24U%+61E;"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BUG!P;F$@;.1N:R!I(&YY='0@
M9O9N<W1E<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B
M3W!E<F%T:6YG(%-Y<W1E;2(*;7-G<W1R(")/<&5R871I=G-Y<W1E;2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C`P
M"FUS9VED(")/<'1I;VYA;"!087)T:6-I<&%N="(*;7-G<W1R("))8VME(&]B
M;&EG871O<FES:V$@9&5L=&%G87)E(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUE
M;G4N<&AP.C$U,"!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS
M9VED(")/<'1I;VYS(@IM<V=S='(@(DEN<W3D;&QN:6YG87(B"@HC.B!S97)V
M:6-E<R]P<F5F<RYP:'`Z,S$@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3D*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B
M26YS=.1L;&YI;F=A<B!F]G(@)7,B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$X"FUS9VED(")/<F1E<F5D($QI<W0B"FUS
M9W-T<B`B4V]R=&5R860@;&ES=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C4V-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4V
M.`IM<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(D]R9V%N:7-A=&EO;B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-38X(&QI8B](
M;W)D92]#<GEP="]S;6EM92YP:'`Z-38Y"FUS9VED(")/<F=A;FES871I;VYA
M;"!5;FET(@IM<V=S='(@(D]R9V%N:7-A=&EO;G-E;FAE="(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S0*;7-G:60@(D]R9V%N:7II;F<B"FUS
M9W-T<B`B3W)G86YI<V5R82(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3,U
M"FUS9VED(")/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T92(*;7-G<W1R
M(")5<G-P<G5N9VQI9R!A<'!L:6MA=&EO;G-M86QL(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.B(*;7-G<W1R(")5<G-P<G5N9VQI9V$@;6%L;&%R
M(&D@)7,Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3D*(SH@<V5R=FEC97,O:V5Y8F]A
M<F0N<&AP.C$Q-R!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R(")!;FYA;B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HY.2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`Y
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,38@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$R-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3,T(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HQ-#0*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D%N9')A(&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C,Q"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*
M;7-G<W1R("+$9V%R8F5H]G)I9VAE=&5R(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]P86TN<&AP.C<Y(&QI8B](;W)D92]!=71H+W!A;2YP:'`Z-SD*;7-G
M:60@(E!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G
M<W1R(")004TM075T96YT:7-E<FEN9R#D<B!I;G1E('1I;&QGY&YG;&EG+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P
M-2!L:6(O3F5T+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!
M4CHZ36%I;"!B86-K96YD(@IM<V=S='(@(E!%05(Z.DUA:6PM:V]P<&QI;F<B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,C4S(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C$R-S8*;7-G:60@(E!'4"!$:6=I=&%L(%-I
M9VYA='5R92(*;7-G<W1R(")01U`@1&EG:71A;"!3:6=N871U<F4B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,CDY(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C$S,C(*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*
M;7-G<W1R(")01U`@16YC<GEP=&5D($1A=&$B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,S4Q(&QI8B](;W)D92]#<GEP="]P9W`N<&AP
M.C$S-S0*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S='(@(E!U8FQI:R!0
M1U`M;GEC:V5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3,S,R!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HQ,S4V"FUS9VED(")01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(E!'4"!3:6=N960O16YC
M<GEP=&5D($1A=&$B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C@*;7-G:60@
M(E!(4"!#;V1E(@IM<V=S='(@(E!(4"UK;V0B"@HC.B!A9&UI;B]P:'!S:&5L
M;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`M<VMA;"(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,W"FUS
M9VED(")032!,:6=H="!286EN(@IM<V=S='(@(DSD='0@9O9R;6ED9&%G<W)E
M9VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS
M.`IM<V=I9"`B4$T@4F%I;B(*;7-G<W1R(")&]G)M:61D86=S<F5G;B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,Y"FUS9VED
M(")032!3:&]W97)S(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-K=7)A<B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0P"FUS9VED
M(")032!3;F]W(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-N]B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"FUS9VED(")032!3
M;F]W(%-H;W=E<G,B"FUS9W-T<B`B169T97)M:61D86=S<VMU<F%R(&UE9"!S
M;O8B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT
M,@IM<V=I9"`B4$T@4W5N(@IM<V=S='(@(D5F=&5R;6ED9&%G<W-O;"(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"FUS9VED
M(")032!4+5-T;W)M<R(*;7-G<W1R("+%<VMS:W5R87(@<.4@969T97)M:61D
M86=E;B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G:60@(E!/
M4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(E!/4TE8+71I;&SD
M9V<@<V%K;F%S(@H*(SH@;&EB+V%P:2YP:'`Z,30Y"FUS9VED(")07TA0(%-H
M96QL(@IM<V=S='(@(E!?2%`M<VMA;"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I;F<B
M"FUS9W-T<B`B571F>6QL;F%D.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<R
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3@W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!A:VES
M=&%N(@IM<V=S='(@(E!A:VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,2!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,3DT"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HQ-S,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`Q"FUS9VED(")0
M86QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C$Y,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&%L
M97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9"(*;7-G<W1R(")086QE<W1I
M;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,@HC
M.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<U(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDY(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.#4*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$W-B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R
M(")087!U82U.>6$@1W5I;F5A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,B!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,3DU"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HQ-S<@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")087)A
M9W5A>2(*;7-G<W1R(")087)A9W5A>2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,V"FUS9VED(")087)T;'D@0VQO=61Y(@IM
M<V=S='(@(D1E;'9I<R!M;VQN:6=T(@H*(SH@861M:6XO=7-E<BYP:'`Z,S8@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C`Q.`HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,C`R,B!L:6(O
M3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,W"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DY(&QI8B].970O4TU3+W=I;E]H='1P
M+G!H<#HQ-3$*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW-R!T96UP
M;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C0S"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,C4*;7-G:60@(E!A<W-W;W)D(@IM<V=S='(@(DSV
M<V5N;W)D(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C@R"FUS
M9VED(")087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M3/9S96YO<F0@Y&YD<F%D97,N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HQ,S(R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,3,R
M,PIM<V=I9"`B4&%S<W=O<F0@:6YC;W)R96-T(@IM<V=S='(@(DSV<V5N;W)D
M(&9E;&%K=&EG="(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H
M<#HQ-3(@;&EB+TAO<F1E+T%U=&@O<F%D:75S+G!H<#HQ-3(*;7-G:60@(E!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN(@IM
M<V=S='(@(DSV<V5N;W)D(&MRY'9S(&;V<B!2041)55,@875T96YT:7-E<FEN
M9RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4S(&QI8B](;W)D
M92]&;W)M+G!H<#HR,#4W"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA
M=&EO;B(*;7-G<W1R("),]G-E;F]R9"!M960@8F5K<N1F=&5L<V4B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3`*;7-G:60@(E!A<W-W;W)D
M.B(*;7-G<W1R("),]G-E;F]R9#HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("),]G-E;F]R
M9#H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P,S0@;&EB+TAO<F1E+T9O<FTN<&AP.C(P,S@*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N(@IM<V=S='(@(DSV<V5N;W)D(&WE<W1E('9A<F$@;&EK
M82XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3$Y('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S
M=&4B"FUS9W-T<B`B2VQI<W1R82!I;B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI
M<&)O87)D(@IM<V=S='(@(DML:7-T<F$@:6X@9G+E;B!U<FML:7!P<VAA;G1E
M<F%R96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(E/V:W;D9R(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN
M+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU
M<',Z(@IM<V=S='(@(E;D;G1A;F1E(')E9VES=')E<FEN9V%R.B(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-`IM<V=I9"`B4&5O<&QE(@IM<V=S='(@
M(DWD;FYI<VMO<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(E!R;V-E;G0B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R(")5=&;V<B!U;F1E<FCE;&QS9G5N:W1I;VYE<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HT,3`*;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@
M;W!E<F%T:6]N<R!O;B!L;V=I;C\B"FUS9W-T<B`B571F]G(@=6YD97)HY6QL
M<V%K=&EV:71E=&5R('9I9"!I;FQO9V=N:6YG/R(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,34V(&QI8B](;W)D92]097)M<R]522YP:'`Z
M,34V"FUS9VED(")097)M:7-S:6]N(@IM<V=S='(@(D)E:/9R:6=H970B"@HC
M.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R"B,L('!H<"UF;W)M870*;7-G
M:60@(E!E<FUI<W-I;VX@7"(E<UPB(&YO="!D96QE=&5D+B(*;7-G<W1R(")"
M96CV<FEG:&5T("<E<R<@<F%D97)A9&5S(&EN=&4N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#8@;&EB+U9&4R]S;6(N<&AP.C4Y,`IM<V=I
M9"`B4&5R;6ES<VEO;B!$96YI960B"FUS9W-T<B`BQ71K;VUS="!N96MA9"(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,38Q(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,38T"B,Z(&QI8B](;W)D92]097)M<R]5
M22YP:'`Z,38Q(&QI8B](;W)D92]097)M<R]522YP:'`Z,38T"FUS9VED(")0
M97)M:7-S:6]N<R(*;7-G<W1R(")B96CV<FEG:&5T97(B"@HC.B!A9&UI;B]P
M97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8P
M"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4X"FUS9VED(")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(*
M;7-G<W1R(")"96CV<FEG:&5T<V%D;6EN:7-T<F%T:6]N(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C8X"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO
M;B(*;7-G<W1R(")097)S;VYL:6<@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3@@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C$X,PHC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")097)U(@IM<V=S='(@(E!E<G4B"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z-34*;7-G:60@(E!E=',B"FUS9W-T<B`B2'5S9&IU<B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY.2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3@V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ-SD@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z.3D*;7-G:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP<&EN
M97)N82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HQ.38*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*
M;7-G:60@(E!H;VYE(@IM<V=S='(@(E1E;&5F;VXB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-#@P"FUS9VED(")0:&]T;W,B"FUS9W-T<B`B1F]T
M;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3`*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,"!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!I=&-A:7)N(@IM<V=S='(@(E!I
M=&-A:7)N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#@*;7-G:60@(E!I>&5L<R(*;7-G<W1R(")0:7AL87(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B"FUS
M9W-T<B`B2VQI8VCI97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&PB"FUS9W-T<B`B5F%R(&=O9"!K;&EC:V$@:2!E;B!C96QL
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C0Y"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT
M('1O(')E;6]V92!T:&ES(&5L96UE;G0Z(@IM<V=S='(@(D)E:W+D9G1A(&%T
M="!D=2!V:6QL(')A9&5R82!V86QD('!O<W0_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4V"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N(@IM<V=S='(@(D)E:W+D9G1A(&%T="!D=2!V:6QL(')A9&5R82!A
M:W1U96QL="!E;&5M96YT+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(U-S$@;&EB+TAO<F1E+T9O<FTN<&AP.C(U-C8*;7-G:60@(E!L96%S92!E
M;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(E9A<B!G;V0@86YG
M92!MY6YA9"!O8V@@Y7(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@
M9F]R('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(E9A<B!G;V0@86YG92!N
M86UN(&;V<B!K871E9V]R:6XZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,P,2!L:6(O2&]R9&4O1F]R;2YP:'`Z,3,P-0IM<V=I9"`B4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B5F%R(&=O9"!A
M;F=E(&=O9&OD;F0@25`M861R97-S+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(V-C`@;&EB+TAO<F1E+T9O<FTN<&AP.C(V-#0*;7-G:60@(E!L
M96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@
M9&%Y<R!I;B!T:&4@;6]N=&@N(@IM<V=S='(@(E9A<B!G;V0@86YG92!E='0@
M9VEL=&EG="!D871U;3L@:V]N=')O;&QE<F$@86YT86QE="!D86=A<B!I(&WE
M;F%D96XN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U,2!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C0U,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@=F%L
M:60@=&EM92XB"FUS9W-T<B`B5F%R(&=O9"!A;F=E(&5N(&=O9&OD;F0@=&ED
M+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C<*;7-G:60@
M(E!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2XB"FUS
M9W-T<B`B5F%R(&=O9"!S=6UM97)A(&1I='0@<')O8FQE;2XB"@HC.B!T96UP
M;&%T97,O;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I
M;BYI;F,Z,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@
M86YD('!A<W-W;W)D(@IM<V=S='(@(D%N9V4@9&ET="!A;G;D;F1A<FYA;6X@
M;V-H(&SV<V5N;W)D+B(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]A9W)E
M96UE;G1?=&]P+FEN8SHQ,@IM<V=I9"`B(@HB4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9A<B!G;V0@;.1S
M(&EG96YO;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT>6-K82!M960@
M=FEL;&MO<F5N(&;V<B!A='0@(@HB86YVY&YD82!S>7-T96UE="XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*;7-G:60@(B(*(E!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(E9A
M<B!G;V0@;.1S(&EG96YO;2!F]FQJ86YD92!T97AT+B!$=2!-Q5-412!S86UT
M>6-K82!M960@=FEL;&MO<F5N(&;V<B!A='0@(@HB86YVY&YD82!S>7-T96UE
M="XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C4T,`IM<V=I9"`B(@HB4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W:6YG
M(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R;VT@
M=&AE("(*(FUE;G4@8F5L;W<N(@IM<V=S='(@(B(*(DMO;G1R;VQL97)A(&;V
M;&IA;F1E(&EN9F]R;6%T:6]N(&]C:"!VY&QJ('-E9&%N(&5N(&AA;F1L:6YG
M(&D@;65N>6Y<;B(*(FYE9&%N+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#,U"FUS9VED(")0;&5A<V4@<V5L96-T
M(&%N(&%C=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R(")6Y&QJ
M(&5N(&AA;F1L:6YG(&9RY6X@;65N>6X@;F5D86XN(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*(SH@;&EB+TAO
M<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-S`*;7-G:60@(E!L96%S
M92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93HB"FUS9W-T<B`B06YG92!N
M>71T(&MA=&5G;W)I;F%M;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$X.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@Q(&QI8B](;W)D92].3%,O1V5O25`N<&AP.CDY"FUS9VED(")0;VQA;F0B
M"FUS9W-T<B`B4&]L96XB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3<*
M;7-G:60@(E!O;&ET:6-S(@IM<V=S='(@(E!O;&ET:6LB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-#@Y"FUS9VED(")0;VQL<R(*;7-G<W1R(")5
M;F1E<G/V:VYI;F=A<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$@;&EB+TAO<F1E+TY,4R]T
M;&0N<&AP.C$Y,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@R
M(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G86PB
M"FUS9W-T<B`B4&]R='5G86PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R-`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C<*;7-G:60@(E!O<VET:6]N
M:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T<B`B4&]S:71I;VYE<FEN9R!A=B!B
M:6QD96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L92(*;7-G
M<W1R(")0;W-I=&EO;F5R:6YG(&%V('1A8F5L;&5N(@H*(SH@9G)A;65W;W)K
M+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3$@;&EB+TAO<F1E+TE-05`O
M04-,+W)F8S0S,30N<&AP.C4Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R
M,#@V+G!H<#HY,0IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I(@IM<V=S='(@(E-K<FEV('1I;&P@9&5N(&CD<B!M
M87!P96X@*&5J('1V:6YG870@878@24U!4"DB"@HC.B!C;VYF:6<O=&AE;65S
M+W!O<W1N=6ME+G!H<#HV"FUS9VED(")0;W-T;G5K92(*;7-G<W1R(")0;W-T
M;G5K92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<S(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C<X"B,L('!H<"UF;W)M870*;7-G:60@(E!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@(@IM<V=S='(@(DYE9&5R8O9R9"!D
M92!S96YA<W1E("5S('1I;6UA<FYA.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,C@W"FUS9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA
M;F-E(@IM<V=S='(@(D-H86YS('1I;&P\8G(O/FYE9&5R8O9R9"(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY."!L:6(O2&]R9&4O4')E
M9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P.B!,
M1$%0+71I;&SD9V<@<V%K;F%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]S97-S:6]N+G!H<#HS,R!L:6(O2&]R9&4O4')E9G,O<V5S<VEO;BYP:'`Z
M,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@3V)L
M:6=A=&]R:7-K="!S97-S:6]N<W1I;&SD9V<@:&ET=&%D97,@:6YT92XB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(S,@IM<V=I9"`B4')E<W-U<F4B"FUS
M9W-T<B`B5')Y8VLB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(V-@IM<V=I
M9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`B3'5F='1R>6-K
M('9I9"!H879E=#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(R-`IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("),=69T=')Y8VLZ("(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.#@*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P,PHC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`B1O9R:&%N9'-V:7-N:6YG
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G
M95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<B"FUS9W-T<B`B1O9R:&%N9'-G<F%N<VMA(&)I;&0@:2!N>71T
M(&;V;G-T97(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V
M,"!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-`HC.B!L:6(O2&]R
M9&4O4')E9G,O54DN<&AP.C,U-B!L:6(O2&]R9&4O4')E9G,O54DN<&AP.C,V
M,`IM<V=I9"`B4')E=FEO=7,@;W!T:6]N<R(*;7-G<W1R(")&]G)E9^5E;F1E
M(&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*;7-G<W1R
M(")3:W)I=B!U="!D;VMU;65N="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C0Q,B!L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G
M:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(E!R:79A=&$@;GEC:V5L(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$V.2!L:6(O2&]R9&4O
M365N=2YP:'`Z,38Y"FUS9VED(")0<F]B;&5M(@IM<V=S='(@(E!R;V)L96TB
M"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C<*;7-G:60@(E!R;V)L96T@
M1&5S8W)I<'1I;VXB"FUS9W-T<B`B4')O8FQE;6)E<VMR:79N:6YG(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W,0IM<V=I9"`B4')O:F5C=',B
M"FUS9W-T<B`B4')O:F5K="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,C@T(&QI8B](;W)D92]&;W)M+G!H<#HR,3$U
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,3DR(&QI8B](;W)D92]&;W)M+G!H
M<#HS,C@P"FUS9VED(")0<F]M<'0@=&5X="(*;7-G<W1R(")497AT(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R(&QI8B](;W)D92]#
M<GEP="]P9W`N<&AP.C0R,PIM<V=I9"`B4'5B;&EC($ME>2(*;7-G<W1R(")0
M=6)L:6L@;GEC:V5L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#4@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV-#8*;7-G:60@
M(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S='(@(E!U8FQI:R!N>6-K96QA
M;&=O<FET;2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C0T(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C0U"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`B4'5B;&EK(&YY8VME;&EN9F]R;6%T:6]N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C,P(&QI8B](
M;W)D92]#<GEP="]P9W`N<&AP.C(T,0IM<V=I9"`B4'5B;&EC+U!R:79A=&4@
M:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS9W-T<B`B
M1F5L('9I9"!G96YE<F5R:6YG(&%V('!U8FQI:W0O<')I=F%T(&YY8VME;'!A
M<BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X,PHC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`P(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3$*
M(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X,R!L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2:6-O(@IM<V=S='(@
M(E!U97)T;R!2:6-O(@H*(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S0S,30N
M<&AP.C4U"FUS9VED(")0=7)G92!M97-S86=E<R(*;7-G<W1R(")296YS82!M
M961D96QA;F1E;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DV
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$Y-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B46%T87(B"FUS9W-T
M<B`B46%T87(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z-C,*;7-G:60@(E%U
M97)Y(@IM<V=S='(@(D9RY6=A(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP
M.C<P"FUS9VED(")1=6]T82(*;7-G<W1R(")+=F]T82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8S(&QI8B](;W)D92]#<GEP="]S
M;6EM92YP:'`Z-C8T"B,L('!H<"UF;W)M870*;7-G:60@(E)302!0=6)L:6,@
M2V5Y("@E9"!B:70I(@IM<V=S='(@(E!U8FQI:R!24T$M;GEC:V5L("@E9"!B
M:71A<BDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C8T(&QI8B](
M;W)D92]&;W)M+G!H<#HR,C8X"FUS9VED(")2861I;R!S96QE8W1I;VXB"FUS
M9W-T<B`B16YS:VEL="!V86PB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT-`IM<V=I9"`B4F%I;B(*;7-G<W1R(")296=N(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#4*;7-G
M:60@(E)A:6X@16%R;'DB"FUS9W-T<B`B5&ED:6=T(')E9VXB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I
M;B!,871E(@IM<V=S='(@(E-E;G0@<F5G;B(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0W"FUS9VED(")286EN(%-H;W=E<B(*
M;7-G<W1R(")296=N<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#@*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B4F5G;B!O8V@@<V[V(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z-#D*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R(")2
M96=N('1I;&P@<V[V(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E-L=6UP;>1S<VEG="!V:7-H
M971S;W)D(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HV."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<S"B,Z
M(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8X(&QI8B](;W)D92]-
M24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I;R(*;7-G<W1R(")&
M]G)HY6QL86YD92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T
M(&QI8B](;W)D92]097)M<RYP:'`Z,S(T"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,S0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHV.`HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$T"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3,W
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"FUS9VED(")296%D(@IM
M<V=S='(@(DSD<R(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C@W(&QI8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<#HT-PHC
M.B!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*;7-G:60@(E)E
M860@;65S<V%G97,B"FUS9W-T<B`B3.1S(&UE9&1E;&%N9&5N(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(E/D:V5R="!A='0@9'4@=FEL;"!R861E
M<F$@)7,_(%)A9&5R:6YG96X@:V%N(&EN=&4@Y6YG<F%S+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"B)3Y&ME
M<G0@871T(&1U('9I;&P@<F%D97)A(&%N=N1N9&%R9&%T82!F]G(@)7,_(%)A
M9&5R:6YG96X@:V%N(&EN=&4@Y6YG<F%S+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N(@IM<V=S='(@(D?V<B!O;2!D:6X@<V5N87-T92!I;FUA
M=&YI;F<B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ-#<@<V5R
M=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C`X"B,Z('-E<G9I8V5S+W!O<G1A
M;"]S>6YC;6PN<&AP.C(T-@IM<V=I9"`B4F5F<F5S:"(*;7-G<W1R(")5<'!D
M871E<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,SDU"FUS9VED(")2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T<B`B57!P9&%T
M97)A(&1Y;F%M:7-K82!M96YY96QE;65N=#HB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S0U"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G
M<W1R(")5<'!D871E<F$@<&]R=&%L=GDZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z.#DT(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-2!L:6(O2&]R9&4O1F]R;2YP
M:'`Z.#DX(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$W"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,C,Y"FUS9VED(")296=E>"(*;7-G<W1R(")296=E>"(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D@;&EB+TAO<F1E+T9O<FTN
M<&AP.C,R,S4*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@
M(E9I<V$@9O9R:.5L;&%N9&5N(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,30W('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(P.`IM<V=I
M9"`B4F5L;V%D(@IM<V=S='(@(DQA9&1A(&]M(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,S,*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`B2V]M;65N=&%R
M97(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0U-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C0W-@IM<V=I9"`B4F5M96UB97(@=&AE(&9R964O8G5S>2!I;F9O
M<FUA=&EO;BXB"FUS9W-T<B`B2V]M(&EHY6<@:6YF;W)M871I;VX@;VT@;&5D
M:6<O=7!P=&%G96XN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-PIM
M<V=I9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`B1FKD<G)S97)V<F%R(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO
M=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T
M<B`B55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A
M9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R
M(")482!B;W)T(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q
M"FUS9VED(")296UO=F4@0FQO8VLB"FUS9W-T<B`B5&$@8F]R="!B;&]C:R(*
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HU,S(*
M(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U.0IM<V=I
M9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R(")482!B;W)T(&MO;'5M;B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G
M:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(E1A(&)O<G0@9F]R;6%T
M97)I;F<B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C8U.`IM<V=I9"`B4F5M;W9E(&9R;VT@;7D@8V%L96YD87(B"FUS
M9W-T<B`B5&$@8F]R="!F<N5N(&UI;B!K86QE;F1E<B(*"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z,3(X"FUS9VED(")296UO=F4@<&%I<B(*;7-G
M<W1R(")482!B;W)T('!A<B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR
M,#(*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R(")2861E<F$@<W!A<F%T('-K
M<FEP="!F<N5N('-E<G9E<FYS('1E;7!O<N1R:V%T86QO9RXB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#(*
M;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B5&$@8F]R="(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM
M<V=I9"`B4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G
M<W1R(")2861E<F$@9&5N;F$@;F]D(&9RY6X@9&]K=6UE;G1E="(*"B,Z('1E
M;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z,3$*;7-G:60@(E)E;6]V
M92!U<V5R(@IM<V=S='(@(E1A(&)O<G0@86YVY&YD87)E(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHU"B,L('!H<"UF;W)M870*;7-G
M:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R(")482!B;W)T(&%N=N1N9&%R
M93H@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C$Y-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C(X,`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C,T.0IM<V=I9"`B4F5P;'D@4V5N="XB"FUS9W-T<B`B
M4W9A<B!S:VEC:V%T+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#4Y"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-#8X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#<X"FUS9VED(")297!L>2!W:71H($YO
M="!3=7!P;W)T960@365S<V%G92(*;7-G<W1R(")3=F%R82!A='0@8F5GY')A
M;B!I;G1E('-T]F1S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HT-C8*;7-G:60@(E)E<&QY('=I=&@@9G)E92]B=7-Y
M(&9O<B!N97AT(#(@;6]N=&AS+B(*;7-G<W1R(")3=F%R82!M960@:6YF;W)M
M871I;VX@;VT@;&5D:6<O=7!P=&%G96X@9O9R(&MO;6UA;F1E('1VY2!MY6YA
M9&5R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-#8U"FUS9VED(")297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U
M<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(E-V87)A(&UE9"!D96X@8F5GY')D
M82!L961I9R]U<'!T86=E;BUI;F9O<FUA=&EO;F5N+B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3@Y"B,L('!H<"UF
M;W)M870*;7-G:60@(E)E<&QY.B`E<R(*;7-G<W1R(")3=F%R.B`E<R(*"B,Z
M(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X(&QI8B](;W)D92]2
M4$,O>&UL<G!C+G!H<#HQ,S@*;7-G:60@(E)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@(@IM<V=S='(@(D)E9^1R
M86X@:W5N9&4@:6YT92!B97-V87)A<RX@4F5T=7)N97)A9"!F96QK;V0Z("(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-#4*;7-G:60@(E)E
M<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"XB"FUS9W-T<B`B
M1&5N(&5F=&5R9G+E9V%D92!T:N1N<W1E;B!K=6YD92!I;G1E(&AI='1A<RXB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$W-"!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0Y,@HC.B!L:6(O2&]R9&4N<&AP.C$W-B!L:6(O
M2&]R9&4N<&AP.C4Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<
M(B5S7"(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R(")%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I9W5R
M871I;VYE;B!A=B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S,`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(S(&QI8B]61E,O<W%L+G!H<#HV
M-S@@;&EB+U9&4R]F='`N<&AP.C@V,0HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H
M<#HW,S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(D5R
M9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N
M(&%V(%9&4RXB"@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW.#$@;&EB
M+TAO<F1E+U5T:6PN<&AP.C<W-@HC+"!P:'`M9F]R;6%T"FUS9VED(")297%U
M:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R(")%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E;B!I(&MO;F9I
M9W5R97)I;F=E;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R
M+G!H<#HS,S4@;&EB+TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,S-0IM<V=I
M9"`B4F5Q=6ER960@1FEE;&0B"FUS9W-T<B`B3V)L:6=A=&]R:7-K='0@9N1L
M="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3DR"FUS9VED(")297%U:7)E9"!087)T:6-I<&%N="(*;7-G<W1R(")/
M8FQI9V%T;W)I<VL@9&5L=&%G87)E(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTO4F5N9&5R97(N<&AP.C,R,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,S0S
M"B,Z(&QI8B](;W)D92]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R,`HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`P('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T
M92YI;F,Z-S<*;7-G:60@(E)E<V5T(@IM<V=S='(@(L5T97)S=.1L;"(*"B,Z
M('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!0
M87-S=V]R9"(*;7-G<W1R("+%=&5R<W3D;&P@;/9S96YO<F0B"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!0
M87-S=V]R9"(*;7-G<W1R("+%=&5R<W3D;&P@;/9S96YO<F0B"@HC.B!A9&UI
M;B]S<6QS:&5L;"YP:'`Z,3,P"FUS9VED(")297-T;W)E($QA<W0@475E<GDB
M"FUS9W-T<B`BQ7-T97)TY&QL('-E;F%S=&4@9G+E9V%N(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S
M<6QS:&5L;"YP:'`Z-C8*;7-G:60@(E)E<W5L=',B"FUS9W-T<B`B4F5S=6QT
M870B"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L
M871E<R]P<F5F<R]E;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS
M(@IM<V=S='(@(L5T97)VY&YD('1I;&P@:6YS=.1L;&YI;F=A<B(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`IM<V=I9"`B4F5T>7!E(&YE
M=R!P87-S=V]R9"(*;7-G<W1R(")!;F=E(&YY='0@;/9S96YO<F0B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-R!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`R(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ.3<*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X-2!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#(*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`B4NEU;FEO;B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#0@861M:6XO<V5T=7`O8V]N9FEG
M+G!H<#HT.`IM<V=I9"`B4F5V97)T($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
MQ71E<G-TY&QL(&MO;F9I9W5R871I;VXB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,3,U"FUS9VED(")2:6-H(%1E>'0@161I=&]R($]P=&EO;G,B"FUS
M9W-T<B`B26YS=.1L;&YI;F=A<B!F]G(@4FEC:"!497AT($5D:71O<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM<V=I9"`B4FED9&QE<R(*;7-G
M<W1R(")'Y71O<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW,`IM<V=I9"`B4FEG:'0B"FUS9W-T<B`B2/9G97(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3(Q(&QI8B](;W)D92]&
M;W)M+G!H<#HS,3`W"FUS9VED(")2:6=H="!H96%D97(B"FUS9W-T<B`B2/9G
M97)R=6)R:6LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3$W(&QI
M8B](;W)D92]&;W)M+G!H<#HS,3`S"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`B2/9G97)VY')D96XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R(")285]D:6YS=.1L;&YI;F=A<BXN+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*(SH@
M;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HR,S0*;7-G:60@(E)O
M;&4B"FUS9W-T<B`B4F]L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3DX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@V"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(@;&EB+TAO<F1E+TY,
M4R]T;&0N<&AP.C$Y.`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3@V(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R(")2=6WD;FEE;B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,#@*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R-@IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R(")2
M;W1E<F$@,3@P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C(P-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C(S"FUS9VED(")2;W1A=&4@3&5F="(*;7-G<W1R(")2;W1E<F$@=N1N
M<W1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,3$*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(R
M.0IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@(E)O=&5R82!H]F=E<B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#D*;7-G:60@(E)O=R!0<F]P97)T:65S(@IM<V=S='(@(E)A9&EN<W3D
M;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R=&EE<R(*;7-G<W1R
M(")2861I;G-TY&QL;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#$*;7-G:60@(E)O=W,Z(@IM<V=S='(@(E)A
M9&5R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S='(@(DQI;FIE<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3`*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@
M86YD(&-O;'5M;G,B"FUS9W-T<B`B3&EN:F5R('9I<V%S(&UE;&QA;B!A;&QA
M(')A9&5R(&]C:"!K;VQU;6YE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY(@IM<V=S='(@(DQI;FIE<B!V
M:7-A<R!E;F)A<G0@;65L;&%N(&MO;'5M;F5R(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU,@IM<V=I9"`B4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'DB"FUS9W-T<B`B3&EN
M:F5R('9I<V%S(&5N8F%R="!M96QL86X@<F%D97(B"@HC.B!A9&UI;B]S<6QS
M:&5L;"YP:'`Z,3(P"FUS9VED(")2=6XB"FUS9W-T<B`B2_9R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3DY"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HQ.#<@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z,3`S"FUS9VED(")2=7-S:6%N($9E9&5R871I;VXB"FUS9W-T<B`B4GES
M<VQA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X.`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,#`*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$X."!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E)W86YD82(*;7-G<W1R(")2
M=V%N9&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(X
M-2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C(X-0IM<V=I9"`B4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E(@IM<V=S='(@(E,O34E-12!S:6=N
M871U<B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,S(S
M(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,S(S"FUS9VED(")3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4B"FUS9W-T<B`B4R]-24U%+6MR>7!T97)A="!M
M961D96QA;F1E(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX
M,2!L:6(O2&]R9&4O075T:"]S87-L+G!H<#HX,0IM<V=I9"`B4T%33"!A=71H
M96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R(")305-,+6%U
M=&5N=&ES97)I;F<@Y'(@:6YT92!T:6QL9^1N9VQI9RXB"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z-3`V"FUS9VED(")335,@365S<V%G:6YG(@IM
M<V=S='(@(E--4R!M961D96QA;F1E;B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H
M<#HR,0IM<V=I9"`B4U%,(%-H96QL(@IM<V=S='(@(E-13"US:V%L(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X,B!L:6(O2&]R9&4O1F]R;2YP
M:'`Z,S(W.`IM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P
M<R(*;7-G<W1R(")344PM<V5K=F5N<R!F]G(@=7!P<VQA9R!A=B!VY')D96XB
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,S"FUS9VED(")34T@B
M"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS-0HC.B!L:6(O2&]R9&4O
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S4*;7-G:60@(E-5
M0T-%4U,B"FUS9W-T<B`B3%E#2T%4(@H*(SH@;&EB+V%P:2YP:'`Z,34S"FUS
M9VED(")37U%,(%-H96QL(@IM<V=S='(@(E-?44PM<VMA;"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C$*;7-G:60@(E-A
M(@IM<V=S='(@(DSV(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#D*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.#D@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")386EN="!(96QE
M;F$B"FUS9W-T<B`B4V%I;G0@2&5L96YA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ.3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HQ,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HX-`IM<V=I9"`B
M4V%I;G0@2VET=',@86YD($YE=FES(@IM<V=S='(@(E-A:6YT($MI='1S(&]C
M:"!.979I<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HX-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,3,Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3$@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z.#<*;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S
M='(@(E-A:6YT($QU8VEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,"!L:6(O2&]R9&4O3DQ3
M+W1L9"YP:'`Z,3@Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ
M.3(@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`P"FUS9VED(")386EN="!0
M:65R<F4@86YD($UI<75E;&]N(@IM<V=S='(@(E-A:6YT+5!I97)R92!O8V@@
M36EQ=65L;VXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$U(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR-#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y,R!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S(@IM<V=S='(@(E-A:6YT(%9I;F-E;G0@;V-H
M($=R96YA9&EN97)N82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A;64@9G)A;64@*%]S96QF*2(*;7-G
M<W1R(")386UM82!R86T@*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U,0HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B
M4V%M;V$B"FUS9W-T<B`B4V%M;V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(Q,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,3(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C$Y-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-A
M;B!-87)I;F\B"FUS9W-T<B`B4V%N($UA<FEN;R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DV"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<@
M;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(Q-@HC.B!L:6(O2&]R9&4O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3DV(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$P-PIM
M<V=I9"`B4V%O(%1O;64@86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE
M(&]C:"!0<FEN8VEP92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3D@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Y"FUS9VED(")3871E
M;&QI=&4@4')O=FED97(B"FUS9W-T<B`B4V%T=&5L:71L979E<F%N=/9R(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`Q"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HQ.3<@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3`S"FUS9VED(")3875D:2!!<F%B:6$B"FUS9W-T<B`B4V%U
M9&EA<F%B:65N(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.CDY
M"FUS9VED(")3879E(@IM<V=S='(@(E-P87)A(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHT-0HC+"!P:'`M9F]R;6%T"FUS9VED(")3
M879E(%PB)7-<(B(*;7-G<W1R(")3<&%R82`G)7,G(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,38*(RP@<&AP+69O<FUA=`IM<V=I9"`B4V%V
M92`E<R(*;7-G<W1R(")3<&%R82`E<R(*"B,Z('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R(")3<&%R82!I
M;G-TY&QL;FEN9V%R(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$V-PIM
M<V=I9"`B(@HB4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@(@HB9&ER96-T
M;W)Y+B(*;7-G<W1R("(B"B)3<&%R82!G96YE<F5R860@:V]N9FEG=7)A=&EO
M;B!S;VT@4$A0+7-K<FEP="!T:6QL(&1I;B!S97)V97)S("!T96UP+6MA=&%L
M;V<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-S$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4V%V960@)7,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M4W!A<F%D92!K;VYF:6=U<F%T:6]N(&;V<B`E<RXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HY,PHC+"!P:'`M9F]R;6%T"FUS9VED(")3879E9"!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*;7-G<W1R(")3<&%R
M861E('5P<&=R861E<FEN9W-S8W)I<'0@=&EL;#H@)7,N(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3`*;7-G:60@(E-C871T
M97)E9"!4+5-T;W)M<R(*;7-G<W1R(")3<')I9&1A(.5S:W-K=7)A<B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.0IM<V=I9"`B4V-I96YC92(*;7-G
M<W1R(")6971E;G-K87`B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T
M+FEN8SHQ-"!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-@IM<V=I
M9"`B4V5A<F-H(@IM<V=S='(@(E/V:R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C(*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(E/V
M:VUO=&]R97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3<S(&QI
M8B](;W)D92]&;W)M+G!H<#HR.34Y"FUS9VED(")396QE8W0@1FEL97,B"FUS
M9W-T<B`B5N1L:B!F:6QE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3D*(SH@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C0X-0IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")6
MY&QJ(&5T="!D871U;2(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3DX"FUS9VED(")396QE8W0@82!G<F]U<"!T;R!A9&0B"FUS9W-T<B`B5N1L
M:B!G<G5P<"!A='0@;.1G9V$@=&EL;"(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R
M(")6Y&QJ(&YY(.1G87)E(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C8P"FUS9VED(")396QE8W0@82!S97)V97(B"FUS9W-T<B`B5N1L:B!S
M97)V97(B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I
M9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B5N1L:B!A;G;D;F1A
M<F4@871T(&SD9V=A('1I;&PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-C4R"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HV-S8*;7-G:60@(E-E;&5C="!A;&PB"FUS9W-T<B`B5N1L
M:B!A;&QA(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,R!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C8T-PIM<V=I9"`B4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N(@IM<V=S='(@(E;D;&H@9&%T=6UK;VUP;VYE;G1E<BXB"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#0V"B,Z
M(&QI8B](;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HX-S,*;7-G:60@
M(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B5N1L:B!E='0@;V)J96MT(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U,PHC
M.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C<W"FUS9VED
M(")396QE8W0@;F]N92(*;7-G<W1R(")6Y&QJ(&EN9V5N(@H*(SH@<V5R=FEC
M97,O:V5Y8F]A<F0N<&AP.C,W"FUS9VED("(B"B)396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"`B"B)P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E
M82XB"FUS9W-T<B`B(@HB06YG92!D92!T96-K96X@9'4@8F5H]G9E<B!I(')U
M=&]R;F$@;F5D86XN($1U(&MA;B!S961A;B!K;W!I97)A(&]C:"!K;&ES=')A
M("(*(FEN(&1E;2!I('1E>'1A<G5T86XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z,S0*;7-G:60@(E-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z
M(@IM<V=S='(@(E;D;&H@879G<N1N<V%R92!F]G(@9&%T=6TZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E;D;&H@9&%T=6UF;W)M870Z(@H*(SH@=&5M
M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN8SHY,`IM<V=I9"`B4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@
M(E;D;&H@:61E;G1I=&5T(&1U('9I;&P@Y&YD<F$Z(@H*(SH@=&5M<&QA=&5S
M+V1A=&$O=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI
M;6ET97(Z(@IM<V=S='(@(E;D;&H@879G<N1N<V%R92!F]G(@=&ED.B(*"B,Z
M('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U"FUS9VED(")396QE8W0@=&AE
M('1I;64@9F]R;6%T.B(*;7-G<W1R(")6Y&QJ('1I9'-F;W)M870Z(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHU-PIM<V=I9"`B4V5L96-T('1W
M;R!M871C:&EN9R!F:65L9',N(@IM<V=S='(@(E;D;&H@=';E(&UA=&-H86YD
M92!FY&QT.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,3`*;7-G:60@
M(E-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92XB"FUS9W-T<B`B5N1L:B!D:71T
M(&;D<F=S8VAE;6$N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(U,@IM
M<V=I9"`B4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.B(*;7-G<W1R
M(")!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LZ(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3,*;7-G:60@(E-E;F0@
M3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(E-K:6-K82!S96YA<W1E(&EN
M9F]R;6%T:6]N96XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E<&]R="(*;7-G<W1R(")3:VEC
M:V$@<')O8FQE;7)A<'!O<G0B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,3`Q,0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,3`T,@IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`B4VMI
M8VMA(%--4R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DX(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R
M(")396YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,C,*;7-G:60@
M(E-E;G-O<CH@(@IM<V=S='(@(E-E;G-O<CH@(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#(R"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,3`@;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0T.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C<S"FUS9VED(")397!T96UB97(B"FUS9W-T<B`B<V5P
M=&5M8F5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M.3D@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM<V=I9"`B4V5R
M8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(E-E<F)I96X@;V-H($UO;G1E
M;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P
M,2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<P,@IM<V=I9"`B4V5R:6%L
M($YU;6)E<B(*;7-G<W1R(")397)I96YU;6UE<B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HQ-#D*;7-G:60@(E-E<G9E<B!D871A('=R;VYG
M(&]R(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-E<G9E<FEN<W3D;&QN:6YG
M87(@9F5L86MT:6=A(&5L;&5R(&EN86MT:78@<V5R=F5R+B(*"B,Z(&%D;6EN
M+W-E<W-I;VYS+G!H<#HR-PIM<V=I9"`B4V5S<VEO;B!!9&UI;B(*;7-G<W1R
M(")397-S:6]N<V%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"B,Z(&QI8B].970O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDR"FUS9VED(")397-S:6]N($E$(&5X
M<&ER960N(@IM<V=S='(@(E-E<W-I;VYS+4E$(&AA<B!GY71T('5T+B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T-0IM<V=I9"`B4V5S<VEO;G,B"FUS9W-T<B`B4V5S
M<VEO;F5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,C,Q.`IM<V=I9"`B4V5T(@IM<V=S='(@(E/D='0B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-SD*;7-G:60@(E-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="XB"FUS9W-T<B`B(@HB2V]N9FEG=7)E<F$@86QT
M97)N871I=B!S;VT@;?9J;&EG9_9R(.5T97)S=.1L;&YI;F<@878@8F]R=&=L
M]FUT(&SV<V5N;W)D+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,3@*
M;7-G:60@(E-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+B(*;7-G<W1R(")+;VYF:6=U<F5R
M82!F:N1R<G-E<G9R87(@<V]M(&1U('9I;&P@:V]M;6$@Y70@9G+E;B!D:6X@
M<&]R=&%L+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HX-PIM<V=I9"`B
M4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T
M92!O<'1I;VYS+B(*;7-G<W1R(")!;F=E(&1I='0@9O9R=F%L9&$@<W!RY6LL
M('1I9'-Z;VX@8V]H(&1A='5M:6YS=.1L;&YI;F=A<BXB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3`Q"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P
M(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@
M86YD(&]T:&5R("(*(F1I<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HB4^1T
M="!D:71T(&EN:71I86QA(&%P<&QI:V%T:6]N+"!FY')G<V-H96UA+"!S:61U
M<'!D871E<FEN9R!O8V@@86YD<F$@(@HB=FES;FEN9W-I;G-TY&QL;FEN9V%R
M+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S<*;7-G:60@(E-E='5P
M(@IM<V=S='(@(E-E='5P(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ,S<*;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I
M;&%B;&4B"FUS9W-T<B`B2V]N9FEG=7)A=&EO;G-U<'!G<F%D97)I;F=S<VMR
M:7!T(&9I;FYS('1I;&QGY&YG;&EG82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-S4*;7-G:60@(E-E=F5R86P@;&]C871I;VYS('!O<W-I
M8FQE('=I=&@@=&AE('!A<F%M971E<CH@(@IM<V=S='(@(D1E="!F:6YN<R!F
M;&5R82!O<G1E<B!M960@<&%R86UE=&5R;CHB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(P,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(P,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI
M8B](;W)D92].3%,O=&QD+G!H<#HR,#,*(SH@;&EB+TAO<F1E+TY,4R]C;W5N
M=')I97,N<&AP.C(P,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y8VAE;&QE<FYA(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0Y.`IM<V=I9"`B4VAO<'!I;F<B"FUS
M9W-T<B`B2&%N9&5L(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`B2V]R="!S=6UM
M97)I;F<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4P"FUS9VED(")3
M:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\B
M"FUS9W-T<B`B4VMA;&P@9V5N=N1G<W1A;F=E;G1E<B!D969I;F5R87,@9O9R
M(&1E(&9L97-T82!LY&YK87(_(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+G!H<#HS,C,@;&EB+TAO<F1E+U!E<FUS+G!H<#HS,C,*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHS,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC
M.C8W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3`@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHQ,3,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHQ,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-SD*;7-G:60@
M(E-H;W<B"FUS9W-T<B`B5FES82(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@HB5FES82!S:VEL;&YA9&5R(&UE;&QA;B!D
M96X@86MT=65L;&$@;V-H(&1E;B!N>6QI9V5N('-K87!A9&4@:V]N9FEG=7)A
M=&EO;F5N+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT.30*;7-G:60@
M(E-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T
M<B`B5FES82!S96YA<W1E(&EN;&]G9VYI;F=S=&ED('9I9"!I;FQO9V=N:6YG
M/R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W-C4@;&EB+TAO<F1E
M+T9O<FTN<&AP.C$W-CD*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME97`@;W)I
M9VEN86PB"FUS9W-T<B`B5FES82!I;G-TY&QL;FEN9R!F]G(@871T(&)E:.5L
M;&$@;W)I9VEN86PB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S
M(&QI8B](;W)D92]&;W)M+G!H<#HR-SDY"FUS9VED(")3:&]W('!I8VME<B(*
M;7-G<W1R(")6:7-A('!A;&5T="(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,S`*;7-G:60@(E-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B
M"FUS9W-T<B`B5FES82`G=&%B96QL86MT:79I=&5T97(G(&D@;65N>6X_(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,U,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R(")6
M:7-A(&UE;GD@9O9R("5S('1I;&P@=N1N<W1E<C\B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*;7-G:60@
M(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T
M<B`B5&%B96QL8V5L;&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(E1A8F5L
M;&EN<W3D;&QN:6YG87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G:60@(E-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9R(*;7-G<W1R(")486)E;&QI;G-TY&QL
M;FEN9V%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9R(*;7-G<W1R(")6:7-A(&1I86QO9W)U=&$@9O9R(&)I;&1E
M9V5N<VMA<&5R(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,R!L
M:6(O2&]R9&4O1F]R;2YP:'`Z,3<V-PIM<V=I9"`B4VAO=R!U<&QO860B"FUS
M9W-T<B`B5FES82!U<'!L861D;FEN9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Q"FUS9VED(")3:&]W97)S(@IM<V=S='(@
M(E-K=7)A<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4R"FUS9VED(")3:&]W97)S($5A<FQY(@IM<V=S='(@(E1I9&EG82!S
M:W5R87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HU,PIM<V=I9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(E-E;F$@<VMU<F%R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-30*
M;7-G:60@(E-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y(@IM<V=S='(@(E-K=7)A
M<B!I(&[D<FAE=&5N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z-#@P(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C0X,`HC.B!L
M:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C8Q.0IM<V=I9"`B
M4VAR:6YK(@IM<V=S='(@(D;V<FUI;G-K82(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C<W-"!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HX,S8*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z.3(R(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDX
M-`HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,#0W(&9R
M86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ,30Y"B,Z(&QI8B](;W)D92]";&]C:R],
M87EO=70N<&AP.C<W-"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HX,S8*
M(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z.3(R(&QI8B](;W)D92]"
M;&]C:R],87EO=70N<&AP.CDX-`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T
M+G!H<#HQ,#0W(&QI8B](;W)D92]";&]C:R],87EO=70N<&AP.C$P.#<*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="YP:'`Z,3$Q-B!L:6(O2&]R9&4O0FQO
M8VLO3&%Y;W5T+G!H<#HQ,30Y"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O
M36%N86=E<BYP:'`Z.3$P"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N
M86=E<BYP:'`Z.3<R"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E
M<BYP:'`Z,3`U.`HC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N
M<&AP.C$Q,C`*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H
M<#HQ,3@S"B,Z(&QI8B](;W)D92]";&]C:R],87EO=70O36%N86=E<BYP:'`Z
M,3(R,PHC.B!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G97(N<&AP.C$R
M-3(*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HQ,C@U
M"FUS9VED(")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0B"FUS9W-T<B`B2W)Y;7`@96QL97(@9FQY
M='1A(&)O<G0@;N1R;&EG9V%N9&4@8FQO8VL@9O9R<W0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`U(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3$*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(P,2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#4*;7-G:60@(E-I97)R82!,96]N92(*;7-G<W1R(")3:65R<F$@3&5O;F4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8U(&QI8B](
M;W)D92]!=71H+U-I9VYU<"YP:'`Z,C8V"FUS9VED(")3:6=N('5P(@IM<V=S
M='(@(E)E9VES=')E<F$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C<Q,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C<Q,PIM<V=I
M9"`B4VEG;F%T=7)E(@IM<V=S='(@(E-I9VYA='5R(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T
M<B`B4VEG;F%T=7)A;&=O<FET;2(*"B,Z(&-O;F9I9R]T:&5M97,O<VEM<&QE
M>"YP:'`Z-@IM<V=I9"`B4VEM<&QE>"(*;7-G<W1R(")3:6UP;&5X(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C`V"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#(@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3`T"FUS9VED(")3:6YG87!O<F4B"FUS9W-T<B`B4VEN9V%P;W)E
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV-2!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8Y"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#<@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R
M,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S-PHC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$R,R!L:6(O2&]R9&4O
M1F]R;2YP:'`Z.3`P(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$Y"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HQ,C0Q(&QI8B](;W)D92]&;W)M+G!H<#HR,C4P(&QI
M8B](;W)D92]&;W)M+G!H<#HR.3$V"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS
M,3`Y(&QI8B](;W)D92]-24U%+U9I97=E<B]R87(N<&AP.C8U"B,Z(&QI8B](
M;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C<R(&QI8B](;W)D92]-24U%+U9I
M97=E<B]T9WHN<&AP.C@T"FUS9VED(")3:7IE(@IM<V=S='(@(E-T;W)L96LB
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.CD*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-3(*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`B079B<GET('5N
M9&5R:.5L;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(Q,`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`S(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4VQO=F%K:6$B"FUS9W-T
M<B`B4VQO=F%K:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C`X"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#0@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3;&]V96YI82(*
M;7-G<W1R(")3;&]V96YI96XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R(*;7-G<W1R(")3;O8B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I
M9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B4V[V<VMU<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H
M;W=E<G,B"FUS9W-T<B`B4V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!%
M87)L>2(*;7-G<W1R(")4:61I9V$@<V[V<VMU<F%R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-N;W<@4VAO
M=V5R<R!,871E(@IM<V=S='(@(E-E;F$@<V[V<VMU<F%R(@H*(SH@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR.#4*;7-G:60@(E-N;W<@9&5P=&@Z("(*;7-G<W1R
M(")3;O9D:G5P.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(X.0IM<V=I
M9"`B4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B`B"FUS9W-T<B`B36]T<W9A
M<F%N9&4@<V[V(&D@=F%T=&5N.B`B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(P,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S(&QI8B](;W)D
M92].3%,O=&QD+G!H<#HR,#(*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N
M<&AP.C(P-2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#,*;7-G:60@(E-O
M;&]M;VX@27-L86YD<R(*;7-G<W1R(")386QO;6]N]F%R;F$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(P-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,30*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(P-B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,#8*;7-G:60@(E-O;6%L:6$B"FUS9W-T<B`B4V]M86QI82(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV,`IM<V=I9"`B4V]N9W,@)B!0;V5M<R(*
M;7-G<W1R(")3Y6YG97(@;V-H(&1I:W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y,C8@;&EB+TAO<F1E+T9O<FTN<&AP.C(Y,3(*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E-O<G1E<FEN9W-I;W)D
M;FEN9W-V86PB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-3D*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X
M.2!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Q-PHC.B!L:6(O
M3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-R!L:6(O3F5T+U--4R]W
M:6Y?:'1T<"YP:'`Z,38V"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ
M.#D*;7-G:60@(E-O=7)C92!A9&1R97-S(@IM<V=S='(@(FOD;&QA9')E<W,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-34*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(P-R!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(E-O=71H($%F<FEC82(*;7-G<W1R(")3
M>61A9G)I:V$B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,PIM<V=I9"`B
M4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,3`Q"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,#@@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(E-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD
M=VEC:"!)<VQA;F1S(@IM<V=S='(@(E/V9')A($=E;W)G:6$@;V-H(%-Y<W-A
M;F1W:6-H]F%R;F$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB+T)L
M;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E(@IM
M<V=S='(@(E/D9')A(&AE;6ES9N1R96XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")5=')Y;6UE(&UE;&QA;B!I;G1I
M;&QI9V=A;F1E(&-E;&QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O;G1E
M;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(E5T<GEM;64@;65L;&%N
M(&EN;F5HY6QL(&]C:"!K86YT96X@:2!C96QL96XB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HX,34@;&EB+TAO<F1E+T9O<FTN<&AP.C@Q.0IM<V=I
M9"`B4W!A8V5R(@IM<V=S='(@(DUE;&QA;G)U;2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-34*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,`IM<V=I9"`B4W!A
M8VEN9R(*;7-G<W1R(")-96QL86YR=6TB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4T"FUS9VED(")3<&%C:6YG
M(&%N9"!P861D:6YG(@IM<V=S='(@(DUE;&QA;G)U;2!O8V@@=71JY&UN:6YG
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C@P"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,#D@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(E-P86YI96XB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3`P"FUS9VED(")3<&%M(@IM
M<V=S='(@(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30*;7-G
M:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@(DEN;6%T;FEN
M9R!A=B!S<&5C:65L;&$@=&5C:V5N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,@IM<V=I9"`B4W!L:70@8V5L
M;"(*;7-G<W1R(")$96QA(&-E;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU
M;6XB"FUS9W-T<B`B1&5L82!K;VQU;6XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED(")3<&QI="!R
M;W<B"FUS9W-T<B`B1&5L82!R860B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-C$*;7-G:60@(E-P;W)T<R(*;7-G<W1R(")3<&]R=&5R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,3`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@X(&QI8B](;W)D92].3%,O=&QD+G!H<#HQ-#$*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(Q,"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(E-R:2!,86YK82(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HV-B!L:6(O0FQO8VLO;65T
M87(N<&AP.C@Q"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R(")3=&%N9&%R9"(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,@IM<V=I9"`B4W1A<B!4<F5K
M(@IM<V=S='(@(E-T87(@5')E:R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-#0S"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-30X"FUS9VED(")3=&%R="(*;7-G
M<W1R(")3=&%R="(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.38@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P.0HC.B!L:6(O2&]R9&4O1F]R
M;2YP:'`Z,C4Y,"!L:6(O2&]R9&4O1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B4W1A
M<G0@>65A<B(*;7-G<W1R(")3=&%R=.5R(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S`@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H
M<#HU-S$*;7-G:60@(E-T871E(&]R(%!R;W9I;F-E(@IM<V=S='(@(E-T870@
M96QL97(@<F5G:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HU.#,*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN
M9&5X+FAT;6PZ,3(*;7-G:60@(E-T871U<R(*;7-G<W1R(")3=&%T=7,B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$U(&QI8B](;W)D92]&;W)M
M+G!H<#HR.#`Q"FUS9VED(")3=&]R86=E(&9O<FUA="(*;7-G<W1R("),86=R
M:6YG<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3<R(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-3<S"FUS9VED(")3
M=')E970@061D<F5S<R(*;7-G<W1R(")'871U861R97-S(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,0IM<V=I9"`B4W1R
M:6ME=&AR;W5G:"(*;7-G<W1R(")'96YO;7-T<G5K96XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C,S(&QI8B](;W)D92]&;W)M+G!H<#HQ,C,W
M"FUS9VED(")3=')I;F<@;&ES="(*;7-G<W1R(")3='+D;F=L:7-T82(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,@;&EB+TAO<F1E+T9O<FTN
M<&AP.C$X-S<*;7-G:60@(E-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M(@IM<V=S='(@(E1A(&)O<G0@9&]MY&X@9G+E;B!A9')E<W-E;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*
M;7-G:60@(E-T>6QE(%M#4U-=(@IM<V=S='(@(E-T:6P@6T-34UTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED
M(")3=2(*;7-G<W1R(")3]B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS
M-PHC+"!P:'`M9F]R;6%T"FUS9VED(")3=6)D:7)E8W1O<GD@7"(E<UPB(&YO
M="!F;W5N9"XB"FUS9W-T<B`B2V%N(&EN=&4@:&ET=&$@=6YD97)K871A;&]G
M("<E<R<N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R
M+G!H<#HW,PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,PIM<V=I9"`B4W5B:F5C="(*;7-G<W1R("+$<F5N9&4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`Z,S$W"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HS,S8@;&EB+TAO
M<F1E+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I9"`B4W5B;6ET(@IM<V=S
M='(@(E-K:6-K82(*"B,Z('-I9VYU<"YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB4W5B;6ET=&5D(')E<75E<W0@=&\@861D(%PB)7-<(B!T;R!T
M:&4@<WES=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R("(*(G)E
M<75E<W0@:&%S(&)E96X@87!P<F]V960N(@IM<V=S='(@(B(*(D1I;B!B96?D
M<F%N(&%T="!LY&=G82!T:6QL(%PB)7-<(B!T:6QL('-Y<W1E;65T(&AA<B!S
M:VEC:V%T<RX@1'4@:V%N(&EN=&4@(@HB;&]G9V$@:6X@:6YN86X@9&EN(&)E
M9^1R86X@:&%R(&%C8V5P=&5R871S+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(*;7-G:60@(E-U8G-C<FEP="(*;7-G
M<W1R(").961SY&YK="(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,#0*(SH@
M9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O
M<W1A='5S+G!H<#HR.`HC.B!L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B3'EC
M:V%T(@H*(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&%D9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*
M;7-G<W1R("(G)7,G(&QA9&5S('1I;&P@:2!S>7-T96UE="XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,C0*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")2861E<F%D92!I;F9O<FUA=&EO;B!O;2!A;G;D;F1A
M<F4@)R5S)RXB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C@P(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U
M;&QY(&1E;&5T960@7"(E<UPB+B(*;7-G<W1R("(G)7,G(')A9&5R861E<RXB
M"@HC.B!A9&UI;B]U<V5R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY(')E;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B)R5S)R!T;V=S(&)O<G0@9G+E;B!S>7-T96UE="XB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C97-S9G5L;'D@
M<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S
M+B(*;7-G<W1R("(B"B)+;VYF:6=U<F%T:6]N96X@:&%R(.5T97)S=.1L;'1S
M+B!,861D82!O;2!S:61A;B!F]G(@871T('-E(&;V<N1N9')I;F=A<BXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T
M<RYP:'`Z-3<*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B4W!A<F%D92!B86-K=7!K;VYF:6=U<F%T
M:6]N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B(*;7-G<W1R(")3<&%R861E(&)A8VMU<&MO
M;F9I9W5R871I;VX@)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,38X"B,L('!H
M<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D(%PB)7-<(B(*
M;7-G<W1R("(G)7,G('5P<&1A=&5R861E<RXB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!P:'`M
M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@=W)O=&4@)7,B"FUS9W-T<B`B
M4VMR978@)7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,#0*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,2!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-U9&%N(@IM<V=S='(@
M(E-U9&%N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU-3@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU-C`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU-@IM<V=I9"`B4W5M;6%R>2(*;7-G<W1R(")3
M86UM86YS=.1L;&YI;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C4*
M;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(E-O;'5P<&?E;F<B"@HC.B!L:6(O
M0FQO8VLO<W5N<FES92YP:'`Z-C@*;7-G:60@(E-U;B!3970B"FUS9W-T<B`B
M4V]L;F5D9^5N9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C8P"FUS9VED(")3=6YN>2(*;7-G<W1R(")3;VQI9W0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`U"FUS9VED(")3=6YR:7-E
M(@IM<V=S='(@(E-O;'5P<&?E;F<B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O
M4W5N<V5T(@IM<V=S='(@(E-O;'5P<&?E;F<O;F5D9^5N9R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#0*;7-G:60@(E-U;G)I<V4Z("(*
M;7-G<W1R(")3;VQU<'!GY6YG.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C`X"FUS9VED(")3=6YS970B"FUS9W-T<B`B4V]L;F5D9^5N
M9R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,#<*;7-G:60@
M(E-U;G-E=#H@(@IM<V=S='(@(E-O;&YE9&?E;F<Z("(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R
M<V-R:7!T(@IM<V=S='(@(E5P<&CV:F0B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,S@P"FUS9VED(")3=7!P;W)T(@IM<V=S='(@(E-U<'!O<G0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`V(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,34*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q,B!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(E-U<FEN
M86UE(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0@
M;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HU-S4*;7-G:60@(E-U<FYA;64B
M"FUS9W-T<B`B169T97)N86UN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-2!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C`Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,3,@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`U"FUS9VED(")3=F%L
M8F%R9"!A;F0@2F%N($UA>65N(@IM<V=S='(@(E-V86QB87)D(&]C:"!*86X@
M36%Y96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3`X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,3D*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-"!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,#@*;7-G:60@(E-W87II;&%N9"(*;7-G<W1R
M(")3=V%Z:6QA;F0B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`T(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR,#4*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-2!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-W961E;B(*;7-G
M<W1R(")3=F5R:6=E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C4V"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,38@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM
M<V=S='(@(E-C:'=E:7HB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HX-@IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3>6MR;VYI
M<V5R:6YG<VQO9V<@<F%D97)A9"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HQ-#4*;7-G:60@(E-Y;F--3"(*;7-G<W1R(")3>6YC34PB"@HC.B!F<F%M
M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z.3<@;&EB+TAO<F1E+U-13"]+
M97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B4WEN=&%X9F5L(&D@<_9K:W)I=&5R:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(Q-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,3@*(SH@;&EB+TAO
M<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q-R!L:6(O2&]R9&4O3DQ3+T=E;TE0
M+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC(@IM<V=S='(@
M(E-Y<FEE;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C8Q"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(L5S:W-K=7(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV,@IM<V=I9"`B
M5"U3=&]R;2!A;F0@5VEN9'DB"FUS9W-T<B`BQ7-K<VMU<F%R(&]C:"!B;.5S
M:6=T(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C,*;7-G:60@(E0M4W1O<FUS(@IM<V=S='(@(L5S:W-K=7)A<B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4
M+5-T;W)M<R!%87)L>2(*;7-G<W1R(")4:61I9V$@Y7-K<VMU<F%R(@H*(SH@
M9G)A;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP.C$V-B!L:6(O2&]R9&4O1&%T
M82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B5%-6+69I
M;"(*"B,Z(&9R86UE=V]R:R]522]522]486)L92YP:'`Z,3,T(&QI8B](;W)D
M92]522]486)L92YP:'`Z,3,T"FUS9VED(")486)L92(*;7-G<W1R(")486)E
M;&PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C<S"FUS9VED(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(E1A
M8F5L;&EN<W3D;&QN:6YG87(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y
M<&4O=&%B;&5S970N<&AP.C4W"B,Z(&QI8B](;W)D92]&;W)M+U1Y<&4O=&%B
M;&5S970N<&AP.C4W"FUS9VED(")486)L92!3970B"FUS9W-T<B`B5&%B96QL
M=7!P<^1T=&YI;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM
M<V=S='(@(E1A8F5L;&EN<W3D;&QN:6YG87(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S-"!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$Q"B,Z(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S0@;&EB+TAO<F1E+TY,
M4R]'96])4"YP:'`Z,3$Q"FUS9VED(")486EW86XB"FUS9W-T<B`B5&%I=V%N
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3@@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(Q.`IM<V=I9"`B5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN82(*;7-G<W1R(")486EW86XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3`Y(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,C4*(SH@;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP.C(Q.2!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,#D*;7-G:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B5&%J:6MI<W1A;B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3(@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(S-0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(P(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q,@IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O
M9B(*;7-G<W1R(")486YZ86YI82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.34*;7-G:60@(E1A<F=E=#HB"FUS9W-T<B`B
M3>5L.B(*"B,Z(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HQ,#0Y(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ.#D*;7-G:60@(E1A<VMS(@IM<V=S='(@(E5P
M<&=I9G1E<B(*"B,Z(&-O;F9I9R]T:&5M97,O9V5N;F5V:6QL:65R<RYP:'`Z
M,30*;7-G:60@(E1E86PB"FUS9W-T<B`B5&5A;"(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<S(&QI8B](;W)D92]#<GEP="]S;6EM
M92YP:'`Z-3<T"FUS9VED(")496QE<&AO;F4@3G5M8F5R(@IM<V=S='(@(E1E
M;&5F;VYN=6UM97(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-PIM<V=I
M9"`B5&5M<"!F;W(@;&%S="!H;W5R.B`B"FUS9W-T<B`B2/9G<W1A('1E;7!E
M<F%T=7(@<V5N87-T92!T:6UM96XZ("(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C(Q"FUS9VED(")496UP97)A='5R92(*;7-G<W1R(")496UP97)A='5R
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Q,@IM<V=I9"`B
M5&5M<&5R871U<F4Z("(*;7-G<W1R(")496UP97)A='5R.B`B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@R"B,L('!H<"UF;W)M870*;7-G
M:60@(E1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B
M"FUS9W-T<B`B5&5M<&5R871U<CQB<B`O/B@E<TUA>"5S+R5S36EN)7,I("9D
M96<[)7,B"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA=&4N<&AP.C8X
M-R!L:6(O2&]R9&4O5&5M<&QA=&4N<&AP.C8Y-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")+86X@
M:6YT92!H:71T82!M86QL("5S+B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z
M,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")!
M;G;D;F1A<F%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#$*;7-G:60@(E1E;G1A=&EV96QY
M($%C8V5P="!R97%U97-T(@IM<V=S='(@(D=O9&OD;FX@8F5GY')A;B!P<F5L
M:6UI;N1R="(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-C@Y"FUS9VED(")496YT871I=F5L>2!!8V-E<'1E9"(*;7-G
M<W1R(")0<F5L:6UI;N1R="!A8V-E<'1E<F%T(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(Q,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S,U
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,C$U(&QI8B](;W)D92]&;W)M+G!H
M<#HS,S,Q"FUS9VED(")497AT(@IM<V=S='(@(E1E>'0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<Y"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M16YB87)T('1E>'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C<T"FUS9VED(")497AT(&%L:6=N(@IM<V=S='(@
M(E1E>'1J=7-T97)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C<Q"FUS9VED(")497AT=&]P(@IM<V=S='(@(E1E>'1T
M;W`B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C4Y"FUS9VED(")4:"(*;7-G<W1R(")4;R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DT"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G<W1R(")4:&%I
M("A425,M-C(P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C(R-`HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Q(&QI
M8B](;W)D92].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA:6QA;F0B"FUS
M9W-T<B`B5&AA:6QA;F0B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#@*;7-G:60@(E1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y<W1E;2XB"FUS
M9W-T<B`B5&%C:R!F]G(@871T(&1U(&%N=N1N9&5R('-Y<W1E;65T+B(*"B,Z
M('-E<G9I8V5S+VQI;FMS+V1E;&5T92YP:'`Z,S0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE("5S(&QI;FL@=&\@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS
M9W-T<B`B3.1N:V5N("5S('1I;&P@)7,@:&%R(')A9&5R871S+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(P(&QI8B]61E,O9G1P+G!H<#HX
M-3$*;7-G:60@(E1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M(@IM<V=S='(@(D944"UT:6QLY&=G970@Y'(@:6YT92!T:6QL9^1N9VQI9W0N
M(@H*(SH@;&EB+TAO<F1E+TAI<W1O<GDN<&AP.C4U"FUS9VED(")4:&4@2&ES
M=&]R>2!S>7-T96T@:7,@9&ES86)L960N(@IM<V=S='(@(DAI<W1O<FEK<WES
M=&5M970@Y'(@879A:W1I=F5R870N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO
M;&%B+G!H<#HY,S0@;&EB+TAO<F1E+TMO;&%B+G!H<#HY,S@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN
M92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R(")(;W)D92]+;VQA
M8BUI;G1E9W)A=&EO;G-G<N1N<W-N:71T970@<W3V9&5R(&EN=&4@7"(E<UPB
M(@H*(SH@;&EB+TYE="])35-0+T)O;VLN<&AP.C$R.3@*;7-G:60@(E1H92!)
M35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N(@IM<V=S='(@(DE-
M4U`M;&]G9V5N(&MU;F1E(&EN=&4@:6YI=&EE<F%S+B(*"B,Z('-E<G9I8V5S
M+VUA:6YT96YA;F-E+G!H<#HS,0IM<V=I9"`B5&AE($UA:6YT96YA;F-E.CH@
M8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>2(*;7-G<W1R(")+;&%S
M<V5N($UA:6YT96YA;F-E.CH@:W5N9&4@:6YT92!L861D87,B"@HC.B!S97)V
M:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C(Y"FUS9VED(")4:&4@3W!T
M:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RXB"FUS9W-T<B`B26YS
M=.1L;&YI;F=S9O9N<W1R970@:&%R('-TY&YG=',N($%V<VQU=&%R+B(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE
M=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"B,Z(&QI8B](;W)D92]097)M<RYP
M:'`Z,3@Y(&QI8B](;W)D92]097)M<RYP:'`Z,C`P(&QI8B](;W)D92]097)M
M<RYP:'`Z,C$Q"B,Z(&QI8B](;W)D92]097)M<RYP:'`Z,C(S(&QI8B](;W)D
M92]097)M<RYP:'`Z,C,T(&QI8B](;W)D92]097)M<RYP:'`Z,C4R"B,Z(&QI
M8B](;W)D92]097)M<RYP:'`Z,C8T(&QI8B](;W)D92]097)M<RYP:'`Z,S`S
M"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB
M=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D%D;6EN:7-T
M<F%T]G)E;B!MY7-T92!K;VYF:6=U<F5R82!E;B!P97)M86YE;G0@0F5H]G)I
M9VAE=',M:V]P<&QI;F<@;VT@9'4@(@HB=FEL;"!A;G;D;F1A($)E:/9R:6=H
M971E<BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C<U"FUS9VED(")4:&4@8F]T=&]M('-I9&4@;VYL>2(*;7-G
M<W1R(")%;F)A<G0@;F5D<F4@<VED86XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0Y"FUS9VED(")4:&4@8V%L96YD
M87(@9&%T82!I<R!I;G9A;&ED(@IM<V=S='(@(DMA;&5N9&5R:6YF;W)M871I
M;VYE;B#D<B!F96QA:W1I9R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV,SD*;7-G:60@(B(*(E1H92!C;VYT86-T($E$(&YU;6)E
M<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O
M=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B2V]N=&%K=&5N<R!)
M1"!A;F=A=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B
M87-E;BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z-3$@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D+G!H<#HU,0IM<V=I
M9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B2V]N=&%K=&5N(&QA9&5S('1I;&P@
M:2!A9')E<W-B;VME;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P
M+G!H<#HQ,30Y(&QI8B](;W)D92]#<GEP="]P9W`N<&AP.C$Q-S(*;7-G:60@
M(B(*(E1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N(@IM<V=S='(@(B(*
M(D1E;B!L]G-G:F]R9&$@4$=0+7-I9VYA='5R96X@:W+D=G,@9O9R(&%T="!V
M97)I9FEE<F$@9&5T('-I9VYE<F%D92`B"B)M961D96QA;F1E="XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0HC
M.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0Q"FUS9VED("(B
M"B)4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T
M86)A<V4N(@IM<V=S='(@(B(*(D1I<W1R:6)U=&EO;G-L:7-T86YS($E$(&%N
M9V%V<R!I;G1E(&5L;&5R(&MU;F1E(&EN=&4@:&ET=&%S(&D@9&%T86)A<V5N
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C0R"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#(*
M;7-G:60@(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"XB"FUS9W-T<B`B1&ES=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I
M=FET<RXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,R!L:6(O
M2&]R9&4O0W)Y<'0N<&AP.C$Q-@IM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T
M<B`B2W)Y<'1E<FEN9W-F=6YK=&EO;F5R;F$@:W+D=F5R(&5N('/D:V5R('=E
M8F;V<F)I;F1E;'-E("A(5%104RDN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HW.`IM<V=I9"`B5&AE(&5V96YT(&AA
M<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N(@IM<V=S='(@(DCD;F1E
M;'-E;B!L861E<R!T:6QL(&D@:V%L96YD97)N+B(*"B,Z(&9R86UE=V]R:R](
M;W)D92](;W)D92YP:'`Z,3<U(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M-#DS"B,Z(&QI8B](;W)D92YP:'`Z,3<W(&QI8B](;W)D92YP:'`Z-3$Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN
M(&$@)7,@<V5T=&EN9RXB"FUS9W-T<B`B1FEL96X@)7,@<VMA;&P@:6YN96CE
M;&QA(&5N(&EN<W3D;&QN:6YG(&;V<B`E<RXB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0X
M,PHC.B!L:6(O2&]R9&4N<&AP.C$W,"!L:6(O2&]R9&4N<&AP.C4P.0HC+"!P
M:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+B(*;7-G<W1R(")&:6QE;B`E<R!S:V%L;"!I;FYE
M:.5L;&$@:6YS=.1L;&YI;F=A<B!F]G(@)7,N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C$Y"FUS9VED(")4:&4@9FEL92!C86X@;F]T(&)E
M(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS9W-T<B`B1FEL96X@:V%N(&EN=&4@
M:V]P:65R87,@=&EL;"!S:6<@<VKD;'8N(@H*(SH@;&EB+U9&4R]F:6QE+G!H
M<#HR,C8*;7-G:60@(E1H92!F:6QE(&-A;FYO="!B92!C;W!I960@;VYT;R!I
M='-E;&8N(@IM<V=S='(@(D9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@
M<VEG('-JY&QV+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(X,"!L
M:6(O2&]R9&4O1&%T82YP:'`Z,C@P"FUS9VED(")4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82XB"FUS9W-T<B`B1FEL96X@:6YN96CV;&P@:6YG96X@:6YF
M;W)M871I;VXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C
M.#(R+G!H<#HV-PHC.B!L:6(O2&]R9&4O34E-12]6:65W97(O<F9C.#(R+G!H
M<#HV-PIM<V=I9"`B5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92XB"FUS9W-T<B`B2'5V=61F
MY&QT(&;V<B!D971T82!M961D96QA;F1E+W)F8S@R,FUE9&1E;&%N9&4@9O9L
M:F5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHU-@IM<V=I9"`B(@HB5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@
M=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E
M("(*(G1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W
M;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@(@HB9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B`B"B)Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@(@HB4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T
M+EQ<;EQ<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E("(*(G!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,3$Q
M"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!I9&5N=&ET>2!<(B5S7"(@:&%S
M(&)E96X@9&5L971E9"XB"FUS9W-T<B`B261E;G1I=&5T96X@)R5S)R!R861E
M<F%D97,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-@IM<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB
M"FUS9W-T<B`B0F%R82!VY&YS=&5R('-I9&$B"@HC.B!S97)V:6-E<R]L:6YK
M<R]D96QE=&4N<&AP.C,W"FUS9VED(")4:&4@;&EN:R!H87,@8F5E;B!R96UO
M=F5D(@IM<V=S='(@(DSD;FME;B!H87(@=&%G:71S(&)O<G0B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ-#8@;&EB+TAO<F1E+T-R>7!T
M+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C871I;VX@;V8@=&AE($=N
M=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C
M;&%S<RXB"FUS9W-T<B`B(@HB4_9K=N1G96X@=&EL;"!';G501RUP<F]G<F%M
M;65T(&WE<W1E('9A<F$@86YG:79E;B!T:6QL(&ML87-S96X@0W)Y<'1?<&=P
M.CHN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,2!L:6(O
M2&]R9&4O34E-12]-1$XN<&AP.C(P,@HC+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="!<
M(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N;R!G=6%R
M86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R
M<W1O;V0N(@IM<V=S='(@(B(*(DUE9&1E;&%N9&5T('-K:6-K870@)7,@=&EL
M;"`E<R!M960@Y')E;F1E(%PB)7-<(B!H87(@=FES871S+EQN(@HB1&5T=&$@
MY'(@:6YG96X@9V%R86YT:2!F]G(@871T(&UE9&1E;&%N9&5T(&AA<B!LY'-T
M<RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<W(&QI8B](;W)D
M92]&;W)M+G!H<#HQ.#@Q"FUS9VED(")4:&4@;F%M92!T;R!U<V4@=VAE;B!L
M:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4B"FUS9W-T<B`B3F%M;F5T('-O
M;2!S:V%L;"!A;G;D;F1A<R!F]G(@871T(&SD;FMA('1I;&P@<VMA<&$M<VED
M86XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$@;&EB+T9I
M;&4O0U-6+G!H<#HT-S0*;7-G:60@(E1H92!N=6UB97(@;V8@9FEE;&1S(&UU
M<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`B06YT86P@9N1L="!MY7-T92!V87)A
M(&5T="!N=6UE<FES:W0@=N1R9&4N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C,Q(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z
M,3(S,@IM<V=I9"`B5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RXB"FUS9W-T<B`B36]D
M=6QE;B!O<&5N<W-L(&MRY'9S(&%V(&ML87-S96X@2&]R9&5?0W)Y<'1?<VUI
M;64Z.BXB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y,"!L:6(O
M2&]R9&4O4')E9G,N<&AP.C(X,PHC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4
M:&4@<')E9F5R96YC92!<(B5S7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE
M('-I>F4B"FUS9W-T<B`B(@HB26YS=.1L;&YI;F=E;B!<(B5S7"(@:W5N9&4@
M:6YT92!S<&%R87,@<.4@9W)U;F0@878@871T(&1A=&%MY&YG9&5N("(*(O9V
M97)S:W)I=F5R(&1E;B!M87AI;6%L="!T:6QLY71N82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+V1E8BYP:'`Z,S(*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O96YS8W)I<'0N<&AP.C,U"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS<&]W97)P;VEN="YP:'`Z,S(*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O;7-W;W)D+G!H<#HS,@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R<&TN<&AP.C,R"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O<W)C:&EG:&QI=&4N<&AP.C,W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,R(&QI8B](;W)D92]-
M24U%+U9I97=E<B]D96(N<&AP.C,R"B,Z(&QI8B](;W)D92]-24U%+U9I97=E
M<B]E;G-C<FEP="YP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M<&]W97)P;VEN="YP:'`Z,S(*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS
M=V]R9"YP:'`Z,S(@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*
M(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'`Z,S<*(SH@;&EB
M+TAO<F1E+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS-PHC.B!L:6(O
M2&]R9&4O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G
M<W1R("(B"B)0<F]G<F%M;65T('-O;2!A;G;D;F1S(&;V<B!A='0@=FES82!D
M96X@:.1R(&UE9&1E;&%N9&5T>7!E;B`H)7,I('-A:VYA<R!PY2`B"B)S>7-T
M96UE="XB"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30@;&EB
M+T9I;&4O0U-6+G!H<#HT.#<*;7-G:60@(E1H92!Q=6]T92!C:&%R86-T97(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B5&5C:VYE
M="!F]G(@8VET97)I;F<@;>5S=&4@=F%R82!E='0@=&5C:V5N+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*
M;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@
M(D)A<F$@:/9G97(@;V-H(';D;G-T97(@<VED;W(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<X"FUS9VED(")4
M:&4@<FEG:'0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B0F%R82!H]F=E<B!S
M:61A(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0V(&QI8B]&
M:6QE+T-35BYP:'`Z-#<Y"FUS9VED(")4:&4@<V5P87)A=&]R(&UU<W0@8F4@
M;VYE('-I;F=L92!C:&%R86-T97(N(@IM<V=S='(@(E-E<&%R871O<FX@;>5S
M=&4@=F%R82!E='0@=&5C:V5N+B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S
M=6TN<&AP.C<X"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S97)V97(@7"(E
M<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(E-E<G9E<B`G)7,G(')A
M9&5R861E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<V5R=F5R(%PB)7-<(B!H87,@8F5E
M;B!S879E9"XB"FUS9W-T<B`B4V5R=F5R("<E<R<@<W!A<F%D97,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z,3DX"B,L('!H<"UF;W)M870*;7-G:60@(E1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"XB"FUS9W-T
M<B`B4')E;G5M97)A=&EO;G-B96?D<F%N(&;V<B`E<R!H87(@=&%G:71S(&)O
M<G0N(@H*(SH@;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HT
M-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B06YG:79E;B!R860@*"5D*2!F
M:6YN<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C,S,"!L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+G!H<#HS,S`*;7-G:60@
M(E1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")!
M;F=I=F5N(')A9"!E>&ES=&5R87(@:6YT92XB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.`IM<V=I9"`B5&AE('1A
M<VL@:&%S(&)E96X@861D960@=&\@>6]U<B!T87-K;&ES="XB"FUS9W-T<B`B
M57!P9VEF=&5N(&AA<B!L86=T<R!T:6QL(&D@9&EN('5P<&=I9G1S;&ES=&$N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<@;&EB+U9&4R]S
M<6PN<&AP.C$W.0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@=&5M<&]R87)Y
M(&9I;&4@7"(E<UPB(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R(")496UP;W+D
M<B!F:6P@)R5S)R!F:6YN<R!I;G1E+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,S,3`@;&EB+TAO<F1E+T9O<FTN<&AP.C,S,#8*;7-G:60@(E1H
M92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@
M=&AE('-C<F5E;BXB"FUS9W-T<B`B5&5X=&5N(&1U(&UA=&%T(&EN('-TY&UM
M97(@:6YT92#V=F5R96YS(&UE9"!T97AT96X@<.4@<VOD<FUE;B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*
M;7-G:60@(E1H92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@
M(D)A<F$@=&]P<"!O8V@@8F]T=&5N('-I9&$B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@
M=&]P('-I9&4@;VYL>2(*;7-G<W1R(")"87)A('1O<'!S:61A(@H*(SH@9G)A
M;65W;W)K+T1A=&$O1&%T82YP:'`Z,S(W(&QI8B](;W)D92]$871A+G!H<#HS
M,C<*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H
M92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R(")5<'!L861D870@9&%T82!F]G)S
M=F%N;B!S961A;B!F]G)E9^5E;F1E('-T96<N(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]C<W8N<&AP.C(V,B!F<F%M97=O<FLO1&%T82]$871A+W1S=BYP
M:'`Z,3<R"B,Z(&QI8B](;W)D92]$871A+V-S=BYP:'`Z,C8R(&QI8B](;W)D
M92]$871A+W1S=BYP:'`Z,3<R"FUS9VED(")4:&4@=7!L;V%D960@9FEL92!C
M;W5L9"!N;W0@8F4@<V%V960N(@IM<V=S='(@(D1E;B!U<'!L861D861E(&9I
M;&5N(&MU;F1E(&EN=&4@<W!A<F%S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.3,*;7-G:60@(E1H92!U<V5R)W,@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R960N
M(@IM<V=S='(@(DQE9&EG+W5P<'1A9V5N+6EN9F]R;6%T:6]N(&;V<B!A;G;D
M;F1A<F5N(&AA<B!S<&%R871S+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT.2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3$P"FUS
M9VED(")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`B5V5A=&AE<BYC;VTM8FQO8VME="#D<B!I;G1E('1I;&QGY&YG
M;&EG="XB"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD
M+B(*;7-G<W1R(")496UA:V%T86QO9R`G)7,G(&9I;FYS(&EN=&4N(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ-S@@;&EB+TAO<F1E+U!R
M969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V
M86EL86)L92XB"FUS9W-T<B`B26YG82!I;G-TY&QL;FEN9V%R('1I;&QGY&YG
M;&EG82XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS
M-#$@;&EB+TAO<F1E+TU)344O0V]N=&5N=',N<&AP.C,T.0IM<V=I9"`B5&AE
M<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N
M(@IM<V=S='(@(D1E="!F:6YN<R!I;F=A(&%L=&5R;F%T:79A(&1E;&%R('-O
M;2!K86X@=FES87,@:6YL:6YE+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$T,#$@;&EB+TAO<F1E+T9O<FTN<&AP.C$T,#4*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B
M"B)Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*(D;V
M<B!MY6YG82!T96-K96X@:2!FY&QT970N($1U(&AA<B!A;F=E='0@)7,@=&5C
M:V5N.R!M87AI;6%L="!A;G1A;"!T96-K96X@Y'(@(@HB)7,N(@H*(SH@<VEG
M;G5P+G!H<#HU,R!A9&UI;B]U<V5R+G!H<#HW,PHC+"!P:'`M9F]R;6%T"FUS
M9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@=&\@=&AE
M('-Y<W1E;3H@)7,B"FUS9W-T<B`B4')O8FQE;2!M960@871T(&SD9V=A('1I
M;&P@)R5S)R!T:6QL('-Y<W1E;65T.B`E<R(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C$R,@HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M
M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E
M;3H@(@IM<V=S='(@(E!R;V)L96T@;65D(&%T="!R96YS82!I;F9O<FUA=&EO
M;B!O;2!A;G;D;F1A<F4@)R5S)R!F<N5N('-Y<W1E;65T.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B
M"FUS9W-T<B`B4')O8FQE;2!M960@871T('1A(&)O<G0@)R5S)R!F<N5N('-Y
M<W1E;65T.B`B"@HC.B!A9&UI;B]U<V5R+G!H<#HQ-3D*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R!<(B5S7"(Z
M("5S(@IM<V=S='(@(E!R;V)L96T@=FED('5P<&1A=&5R:6YG(&%V("<E<R<Z
M("5S(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<Y(&QI
M8B](;W)D92]"<F]W<V5R+G!H<#HY,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@
M)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")0<F]B;&5M('9I9"!U<'!L861D
M;FEN9R!A=B!F:6QE;BX@26YG82`E<R!L861D861E<R!U<'`N(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@T(&QI8B](;W)D92]"<F]W
M<V5R+G!H<#HY,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L
M87)G97(@=&AA;B!T:&4@;6%X:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y
M=&5S*2XB"FUS9W-T<B`B(@HB1&5T('5P<'-T;V0@<')O8FQE;2!V:60@=7!P
M;&%D9&YI;F<@878@9FEL96XZ("5S(.1R('-T]G)R92#D;B!M87AI;6%L="`B
M"B)T:6QLY71E;B!S=&]R;&5K("@E9"!B>71E<RDN(@H*(SH@9G)A;65W;W)K
M+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#@V(&QI8B](;W)D92]"<F]W<V5R+G!H
M<#HY,S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"XB"FUS9W-T<B`B(@HB1&5T('5P<'-T;V0@<')O
M8FQE;2!V:60@=7!P;&%D9&YI;F<@878@9FEL96XZ("5S(&QA9&1A9&5S(&5N
M8F%R="!U<'`@9&5L=FES+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)F8S@R,BYP:'`Z,S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F
M8S@R,BYP:'`Z,S4*;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y
M:6YG('1H:7,@;65S<V%G92!P87)T(@IM<V=S='(@(D1E="!U<'!S=&]D(&5T
M="!F96P@=FED('9I<VYI;F<@878@;65D9&5L86YD961E;&5N+B(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-#@@;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HS.0HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=F-A<F0N<&AP.C0X"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N(@IM<V=S='(@(D9E;"!V:60@
M:6UP;W)T(&%V(&MO;G1A:W1D871A+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-S4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S
M+B(*;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!HY&YD96QS96XZ("5S+B(*
M"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H<#HS,2!L:6(O2&]R9&4O
M1&%T82]I;6,N<&AP.C,Q"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82XB"FUS9W-T<B`B1F5L('9I9"!I
M;7!O<G0@878@:4-A;&5N9&%R(&1A=&$N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,#4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@
M)7,N(@IM<V=S='(@(D9E;"!V:60@:6UP;W)T(&%V('5P<&=I9G1E;CH@)7,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HY,0HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('5S97(G<R!F<F5E+V)U<WD@:6YF;W)M871I;VXZ("5S+B(*
M;7-G<W1R(")&96P@=FED(&EM<&]R="!A=B!I;F9O<FUA=&EO;B!O;2!L961I
M9R]U<'!T86=E;CH@)7,N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HX
M,@IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U
M<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@(@HB<F5Q=6ER
M960@9FEE;&0N(@IM<V=S='(@(B(*(D5T="!F96P@<.5T<N1F9F%D97,@:2!F
M;W)M=6SD<F5T+B!+;VYT<F]L;&5R82!A='0@9'4@:6YT92!G;/9M="!F>6QL
M82!I(&5T="`B"B)O8FQI9V%T;W)I<VMT(&;D;'0N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*(SH@;&EB+TYE
M="]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`IM<V=I9"`B(@HB5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@86=A:6X@;&%T97(N(@IM
M<V=S='(@(B(*(D1E="!G:6-K(&EN=&4@871T('5T9O9R82!D96X@8F5GY')D
M82!A9')E<W-B;VMS9G5N:W1I;VYE;BX@5F%R(&=O9"!F]G)S]FL@(@HB<V5N
M87)E+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C0P"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV
M-#`*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+B(*;7-G
M<W1R(")&96P@=FED('5P<&1A=&5R:6YG(&%V(&MO;G1A:W1U<'!G:69T97(N
M($;V<G/V:R!I9V5N('-E;F%R92XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C8T-0HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C(R,B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0U"B,Z(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HR,C(*
M;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(D9E;"!V:60@=7!P9&%T97)I;F<@878@9&ES=')I8G5T:6]N<VQI<W1A
M;BX@1O9R<_9K(&EG96X@<V5N87)E+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C$T."!L:6(O2&]R9&4O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,30X"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T
M('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R(")$:6X@24U!4"US
M97)V97(@<W3V9&5R(&EN=&4@9&5L861E(&UA<'!A<BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C@R"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.38*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HR,#`*
M;7-G:60@(E1H:7,@86-T:6]N(&ES(&YO="!S=7!P;W)T960N(@IM<V=S='(@
M(D1E;FYA(&AA;F1L:6YG('-T]F1S(&EN=&4N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HQ,3@*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HS-3D*;7-G:60@(E1H
M:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N(@IM<V=S='(@(D1E
M;FYA(&9U;FMT:6]N(.1R(&EN=&4@:6UP;&5M96YT97)A9"#D;BXB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X(&QI8B](;W)D
M92]-24U%+U9I97=E<B]R87(N<&AP.C0X"FUS9VED(")4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R(")&
M:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%)!4BUA<FMI=BXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C4R(&QI
M8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP.C4R"FUS9VED(")4:&ES(&1O
M97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+B(*;7-G<W1R
M(")&:6QE;B!V97)K87(@:6YT92!V87)A(&5T="!G:6QT:6=T(%I)4"UA<FMI
M=BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,30U(&QI8B](;W)D
M92]&;W)M+G!H<#HS,3,Q"FUS9VED(")4:&ES(&1O97,@;F]T('-E96T@=&\@
M8F4@82!V86QI9"!C87)D(&YU;6)E<BXB"FUS9W-T<B`B1F5L86MT:6=T(&MO
M<G1N=6UM97(N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,3@U"B,Z(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,3@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN
M9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O
M(@HB8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M22(*;7-G<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E="!M]FIL:6=T
M(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA($-L:6-K871E;&PM(@HB8G)Y
M9V=A;B`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G96YO;2!A='0@86YVY&YD
M82!(5%10($%023IT+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,3,T(&QI8B].970O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G
M:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W
M87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)$96YN82!D<FEV
M<G5T:6X@9_9R(&1E="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@
M=FEA(%=)3BUB<GEG9V%N("(*(BAH='1P.B\O=VEN<&QC+F-O;2D@9V5N;VT@
M871T(&%N=N1N9&$@2%144"!!4$DZ="(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3$U"B,Z(&QI8B].970O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HU,34*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I
M;"`H:'1T<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%022(*;7-G<W1R("(B"B)$96YN82!D<FEV<G5T:6X@9_9R(&1E
M="!M]FIL:6=T(&%T="!S:VEC:V$@;65D9&5L86YD96X@=FEA('-M<S)E;6%I
M;"UB<GEG9V%N("(*(BAH='1P.B\O<VUS,F5M86EL+F-O;2D@9V5N;VT@871T
M(&%N=N1N9&$@2%144"!!4$DZ="(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z.#4*;7-G:60@(B(*(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY("(*(F=A=&5W87DL(&]N;'D@=&\@5F]D869O
M;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H
M("(*(E9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(@IM<V=S
M='(@(B(*(D1E;FYA(&1R:79R=71I;B!G]G(@9&5T(&WV:FQI9W0@871T('-K
M:6-K82!M961D96QA;F1E;B!V:6$@4TU44"!G96YO;2`B"B)6;V1A9F]N92!)
M=&%L:65N+6)R>6=G86X@*&5N8F%R="!T:6QL(%9O9&%F;VYN=6UM97(I+B!$
M<FEV<G5T:6YE;B!K<N1V97(@971T("(*(F4M<&]S=&MO;G1O(&AO<R!6;V1A
M9F]N92!)=&%L:65N("AH='1P.B\O=W=W+C$Y,"YI="DN(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.3<X(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$P-3<*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,3$U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$Q.#(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(U-@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`U(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$S.3@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,34U-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$Y-3@@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`P-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#(Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-S@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$T.2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C(Q"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0U-`HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C4W(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,C@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$S
M-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S`U"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,X,3,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@R
M,0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z.3@R(&QI8B](;W)D92]&;W)M+G!H
M<#HQ,#8Q(&QI8B](;W)D92]&;W)M+G!H<#HQ,#DP"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HQ,3$Y(&QI8B](;W)D92]&;W)M+G!H<#HQ,3@V(&QI8B](;W)D
M92]&;W)M+G!H<#HQ,C8P"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ,S`Y(&QI
M8B](;W)D92]&;W)M+G!H<#HQ-#`R(&QI8B](;W)D92]&;W)M+G!H<#HQ-38Q
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HQ.#0S(&QI8B](;W)D92]&;W)M+G!H
M<#HQ.38R(&QI8B](;W)D92]&;W)M+G!H<#HR,#`Y"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HR,#,S(&QI8B](;W)D92]&;W)M+G!H<#HR,#@R(&QI8B](;W)D
M92]&;W)M+G!H<#HR,34S"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C(U(&QI
M8B](;W)D92]&;W)M+G!H<#HR-#$R(&QI8B](;W)D92]&;W)M+G!H<#HR-#4T
M"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR-C0Q(&QI8B](;W)D92]&;W)M+G!H
M<#HR.#$T(&QI8B](;W)D92]&;W)M+G!H<#HS,3(S"B,Z(&QI8B](;W)D92]&
M;W)M+G!H<#HS,S`Q(&QI8B](;W)D92]&;W)M+G!H<#HS.#`Y(&QI8B](;W)D
M92]&;W)M+G!H<#HS.#$W"FUS9VED(")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(*;7-G<W1R(")&Y&QT970@;>5S=&4@=F%R82!I9GEL;'0N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-2!L:6(O2&]R9&4O1F]R;2YP:'`Z
M,3`V.0IM<V=I9"`B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G
M97)S+B(*;7-G<W1R(")&Y&QT970@9N5R(&5N8F%R="!I;FYE:.5L;&$@:&5L
M=&%L+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3@@;&EB+TAO
M<F1E+T9O<FTN<&AP.C(T,C`*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D;D;'1E
M="!FY7(@96YB87)T(&EN;F5HY6QL82!S:69F<F]R(&]C:"!K;VQO;BXB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#DT(&QI8B](;W)D92]&;W)M
M+G!H<#HQ,#DX"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+B(*;7-G<W1R(")&Y&QT970@9N5R(&5N8F%R="!I;FYE
M:.5L;&$@;VMT86QA('1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3(S(&QI8B](;W)D92]&;W)M+G!H<#HQ,3(W"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O
M9B!I;G1E9V5R<R(*;7-G<W1R("(B"B)&Y&QT970@<VMA;&P@=F%R82!E;B!K
M;VUM82T@96QL97(@;65L;&%N<VQA9W-S97!A<F%R860@;&ES=&$@;65D(&AE
M;'1A;"(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z.3DS"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V
M86QI9"!N=6UB97(N(@IM<V=S='(@(D;D;'1E="!MY7-T92!V87)A(&5T="!G
M;V1KY&YT('1A;"XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V
M(&QI8B](;W)D92]&;W)M+G!H<#HR.#(R"FUS9VED("(B"B)4:&ES(&9I96QD
M(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R
M;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@(B(*(D1E
M='1A(&;D;'0@;>5S=&4@:6YN96CE;&QA(&5N(%)'0BUFY')G:V]D(&D@:&5X
M861E8VEM86QT(&9O<FUA="P@="!E>"`B"B(G(S$R,S1A9B<N(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z-38Q(&QI8B](;W)D92]&;W)M+G!H<#HU
M-C4*;7-G:60@(E1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"XB"FUS9W-T<B`B1&5T=&$@9F]R;75LY'(@:&%R(')E9&%N(&)E87)B971A
M=',N(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B1&5T(&CD<B#D<B`E
M<RXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0U.2!L:6(O2&]R
M9&4O2V]L86(N<&AP.C0V.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&ES
M(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B
M:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES:70@)7,B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DP(&QI8B](;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3@*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@
M8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN(@IM<V=S
M='(@(DUE9&1E;&%N9&5T('-K<F5V<R!I(&5N(&%N;F%N('1E8VME;G5P<'/D
M='1N:6YG("@E<RD@Y&X@9&EN(&5G96XN(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HQ,C8@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HQ,C8*
M;7-G:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G
M<W1R(")$970@:.1R(&YU;7)E="!MY7-T92!V87)A(&UI;G-T(&5T="XB"@HC
M.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4@;&EB
M+TAO<F1E+T-O;7!R97-S+V=Z:7`N<&AP.C0U"FUS9VED(")4:&ES('-E<G9E
M<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB"FUS9W-T
M<B`B4V5R=F5R;B!K86X@:6YT92!P86-K82!U<'`@>FEP(&]C:"!G>FEP(&9I
M;&5R+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z
M,3@V(&QI8B](;W)D92]296=I<W1R>2YP:'`Z,3@Y"FUS9VED(")4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(E-Y<W1E
M;65T(.1R(&;V<B!T:6QL9N1L;&5T(&%V86MT:79E<F%T+B(*"B,Z(&9R86UE
M=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(T(&QI8B](;W)D92]0<F5F<R]5
M22YP:'`Z,3(T"FUS9VED(")4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M(@IM<V=S='(@(D1E="!HY'(@=N1R9&5T(&WE<W1E('9A<F$@;G5M97)I<VMT
M+B(*"B,Z('-E<G9I8V5S+VEM86=E<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G
M:60@(E1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<B"FUS9W-T<B`B1&5T=&$@9O9N<W1E<B!MY7-T92!A;G)O<&%S
M(&9RY6X@971T(&MO;F9I9W5R871I;VYS9O9N<W1E<B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8U"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(L5S:V$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C,V"FUS9VED(")4:6-K971S(@IM<V=S='(@(L1R96YD96XB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#(X(&QI8B](;W)D92]&;W)M+G!H<#HR
M-#(Y"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0IM<V=I9"`B
M5&EM92(*;7-G<W1R(")4:60B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,S@X"FUS9VED(")4:6UE(%1R86-K:6YG(@IM<V=S='(@(E1I9'-R961O
M=FES;FEN9R(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM
M92!F;W)M870B"FUS9W-T<B`B5&ED<V9O<FUA="(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,SD@;&EB+TAO<F1E+T9O<FTN<&AP.C(U,S4*;7-G
M:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@(E1I9'-V86PB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$P(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S`*(SH@;&EB+TAO<F1E
M+TY,4R]C;W5N=')I97,N<&AP.C(R,B!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H
M<#HQ,3`*;7-G:60@(E1I;6]R+4QE<W1E(@IM<V=S='(@(M9S='1I;6]R(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.0HC
M.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO
M8VLO:69R86UE+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B4G5B<FEK
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M-@IM<V=I9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")2=6)R:6L@*'1O
M;VQT:7`I.B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R
M,BYP:'`Z-S4*(SH@;&EB+TAO<F1E+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z
M-S4*;7-G:60@(E1O(@IM<V=S='(@(E1I;&PB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-C(Y"B,Z(&QI8B](;W)D92]522]6
M87)296YD97)E<B]H=&UL+G!H<#HV-30*;7-G:60@(B(*(E1O('-E;&5C="!M
M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@
M0V]M;6%N9"`H36%C*2!K97D@(@HB=VAI;&4@8VQI8VMI;F<N(@IM<V=S='(@
M(B(*(D;V<B!A='0@;6%R:V5R82!F;&5R82!V86PL(&CE;&P@;F5D($-T<FP@
M*%!#*2!E;&QE<B!#;VUM86YD("A-86,I('1A;F=E;G1E;B`B"B)NY'(@9'4@
M:VQI8VMA<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`P
M"FUS9VED(")4;V1A>2(*;7-G<W1R("))9&%G(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM<V=I9"`B5&]G9VQE($A4
M34P@4V]U<F-E(@IM<V=S='(@(E9I<V$@2%1-3"UKY&QL82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#D@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(R,PHC.B!L:6(O2&]R9&4O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S(&QI8B](;W)D92].3%,O1V5O25`N<&AP
M.C$P.0IM<V=I9"`B5&]G;R(*;7-G<W1R(")4;V=O(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C(V"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C0@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P
M"FUS9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S`R"FUS9VED(")4;VUO<G)O=R(*;7-G
M<W1R("));6]R9V]N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C(Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,C4@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4;VYG82(*;7-G
M<W1R(")4;VYG82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z.#$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHW-PIM<V=I9"`B5&]P(@IM<V=S='(@(E1O<"(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3,*;7-G
M:60@(E1O<"!F<F%M92`H7W1O<"DB"FUS9W-T<B`B5&]P(&9R86UE("A?=&]P
M*2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HV,PIM<V=I9"`B5')A;G-L
M871I;VYS(@IM<V=S='(@(M9V97)SY'1T;FEN9V%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,2!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,R"B,Z(&QI8B](;W)D92].3%,O
M8V]U;G1R:65S+G!H<#HR,C8@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$Q
M"FUS9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D
M(&]C:"!4;V)A9V\B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-SDP
M(&QI8B](;W)D92]&;W)M+G!H<#HQ-SDT"FUS9VED(")4<G5E(&]R(&9A;'-E
M(@IM<V=S='(@(E-A;G0@96QL97(@9F%L<VMT(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T
M<B`B5&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R."!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R-PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$P(&QI8B](;W)D92].3%,O=&QD+G!H<#HR
M,C@*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R-R!L:6(O2&]R
M9&4O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U;FES:6$B"FUS9W-T<B`B
M5'5N:7-I96XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q(&QI8B](;W)D92].3%,O=&QD+G!H
M<#HR,S$*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(R."!L:6(O
M2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@(E1U<FME>2(*;7-G<W1R
M(")4=7)K:65T(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@
M(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(E1U<FMI<VL@*$E33RTX
M.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C(W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,CD@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$P"FUS9VED(")4=7)K;65N:7-T86XB"FUS
M9W-T<B`B5'5R:VUE;FES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P."!L:6(O2&]R9&4O
M3DQ3+W1L9"YP:'`Z,C(P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H
M<#HR,S`@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K
M<R!A;F0@0V%I8V]S($ES;&%N9',B"FUS9W-T<B`B5'5R:W,M(&]C:"!#86EC
M;W/V87)N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,S(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP
M.C(S,PHC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Q(&QI8B](
M;W)D92].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM<V=S='(@
M(E1U=F%L=2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0@;&EB+TAO
M<F1E+T-,22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS
M9W-T<B`B06YG92!D:71T('9A;#H@(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(U.`IM<V=I9"`B52Y6+B!I;F1E>#H@(@IM<V=S='(@(E56
M+6EN9&5X.B`B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,C0Y"B,Z(&QI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,C0Y(&QI8B]";&]C:R]I9G)A;64N<&AP.C$W"FUS9VED(")54DPB"FUS9W-T
M<B`B55),(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU-#$*(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T(@IM<V=S='(@(E523"!F]G(@9&ET="!L979E<F%N<W)A<'!O
M<G1E<FEN9W-S:W)I<'0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.CDW"FUS9VED(")54DPZ(@IM<V=S='(@(E523#HB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S<*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,B!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5G86YD82(*;7-G<W1R(")59V%N9&$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-B!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(S,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3$R(&QI8B](;W)D92].3%,O=&QD+G!H<#HR,S8*(SH@;&EB
M+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(S,R!L:6(O2&]R9&4O3DQ3+T=E
M;TE0+G!H<#HQ,3(*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`B56MR86EN82(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,B!L:6(O5D93+V9I
M;&4N<&AP.C0Q.0IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T
M;W)Y+B(*;7-G<W1R(")+86X@:6YT92!LY'-A(%9&4RUM87!P+B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HY-B!L:6(O2&]R9&4O075T
M:"]3:6=N=7`N<&AP.CDV"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S
M97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("(B"B)$
M970@9VEC:R!I;G1E(&%T="!LY&=G82!T:6QL('5T]FMA9"!A;G;D;F1A<FEN
M9F]R;6%T:6]N('9I9"!R96=I<W1E<FEN9RXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]F='`N<&AP.C,X."!L:6(O5D93+V9T<"YP:'`Z,SDS"B,L('!H<"UF
M;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")+86X@:6YT92#D;F1R82!B96CV
M<FEG:&5T(&;V<B!61E,M9FEL("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C,X-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z-#8X
M"B,Z(&QI8B]61E,O9FEL92YP:'`Z,SDR(&QI8B]61E,O;75S<6PN<&AP.C0V
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(*;7-G<W1R(")+86X@:6YT92#D
M;F1R82!B96CV<FEG:&5T(&;V<B!61E,M9FEL("5S+R5S+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9T<"YP:'`Z-S4U(&QI8B]61E,O9G1P+G!H<#HW.#8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H86YG92!T;R`E<RXB
M"FUS9W-T<B`B2V%N(&EN=&4@Y&YD<F$@=&EL;"`E<RXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92`E<R\E<R(*;7-G<W1R(")+86X@
M:6YT92!K;VYT<F]L;&5R82!F:6QS=&]R;&5K("5S+R5S(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(@;&EB+U9&4R]F='`N<&AP.C(S-PHC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=')O;&QE<F$@9FEL
M<W1O<FQE:R!PY2`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C$P,38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC.B!L
M:6(O5D93+V9I;&4N<&AP.C8Y-2!L:6(O5D93+W-Q;"YP:'`Z,3`R."!L:6(O
M5D93+W-Q;%]F:6QE+G!H<#HX-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S+R5S7"(N(@IM<V=S='(@
M(DMA;B!I;G1E(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@<.4@)7,O)7,N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-2!L:6(O2&]R9&4O
M075T:"]S<6PN<&AP.C0S.0IM<V=I9"`B56YA8FQE('1O(&-O;FYE8W0@=&\@
M4U%,('-E<G9E<BXB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=&%K=&$@4U%,+7-E
M<G9E<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.2!L:6(O
M5D93+V9T<"YP:'`Z.#<P"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!W:71H
M(%-33"XB"FUS9W-T<B`B2V%N(&EN=&4@:V]N=&%K=&$@=FEA(%-33"XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,C4@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,C,P"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HQ.38@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P
M,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Y(&QI8B]6
M1E,O9FEL92YP:'`Z,C,R"B,Z(&QI8B]61E,O9FEL92YP:'`Z,C,W(&QI8B]6
M1E,O<W%L7V9I;&4N<&AP.C(P-"!L:6(O5D93+W-Q;%]F:6QE+G!H<#HR,#D*
M(SH@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,C$W"FUS9VED(")5;F%B;&4@=&\@
M8V]P>2!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@:V]P:65R82!61E,M
M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S8U(&QI8B]6
M1E,O9G1P+G!H<#HS-S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN
M=&4@<VMA<&$@5D93+6UA<'`@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S4T(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR-3@*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(U-B!L:6(O5D93
M+V9I;&4N<&AP.C,V,0HC.B!L:6(O5D93+VUU<W%L+G!H<#HR-3@@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,C8T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E('-K87!A(%9&4RUM87!P
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ,C0@;&EB+U9&
M4R]M=7-Q;"YP:'`Z,3(T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R(")+86X@:6YT92!S:V%P82!61E,M9FEL+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V(&QI8B]61E,O<VUB+G!H<#HR
M.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@
M9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@<VMA<&$@5D93+6UA
M<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-C4@
M;&EB+U9&4R]F:6QE+G!H<#HR-S(*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@
M96UP='D@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E('-K87!A('1O;2!6
M1E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N
M<&AP.C<V"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H
M<#HW.2!L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!L:6(O2&]R
M9&4O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T;R!D96-O
M;7!R97-S(&1A=&$N(@IM<V=S='(@(DMA;B!I;G1E('!A8VMA('5P<"!D871A
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C(T(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z,CDX"B,Z(&QI8B]61E,O<VUB+G!H<#HR,C@@
M;&EB+U9&4R]F='`N<&AP.C,P,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP
M='DN(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN
M=&4@=&]M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-S@@861M:6XO<&5R;7,O
M9&5L971E+G!H<#HT-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%PB)7-<(CH@)7,N(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82`G
M)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F
M<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE
M+G!H<#HS,S0*(SH@;&EB+U9&4R]F:6QE+G!H<#HS,S@@;&EB+U9&4R]S<6PN
M<&AP.C,Y-2!L:6(O5D93+VUU<W%L+G!H<#HS,3$*(SH@;&EB+U9&4R]S<6Q?
M9FEL92YP:'`Z,S0R"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@
M(DMA;B!I;G1E(')A9&5R82`E<RP@;6%P<&5N(.1R(&EN=&4@=&]M+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,U,@HC.B!L:6(O5D93+W-Q;%]F:6QE
M+G!H<#HS-38@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,S8P"FUS9VED(")5;F%B
M;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S
M='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<"!R96MU<G-I=G0N(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,W(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HS,C(*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,S-2!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S0S"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#0@;&EB+U9&4R]F:6QE
M+G!H<#HS-#0*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,S(R(&QI8B]61E,O;75S
M<6PN<&AP.C,S-2!L:6(O5D93+VUU<W%L+G!H<#HS-#,*(SH@;&EB+U9&4R]S
M<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E(')A9&5R82!61E,M;6%P<"XB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0R.0HC.B!L:6(O5D93+W-Q;"YP:'`Z-#(P(&QI
M8B]61E,O<W%L+G!H<#HT,S(*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B2V%N(&EN
M=&4@<F%D97)A(%9&4RUM87!P.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C(P-R!L:6(O5D93+V9T<"YP:'`Z,C$R"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")+86X@:6YT92!R861E<F$@5D93+69I;"`E<RXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V
M-R!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R
M:R]61E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,SDQ(&QI8B]61E,O9FEL92YP:'`Z,S$P(&QI8B]61E,O<W%L+G!H<#HR
M.3$*(SH@;&EB+U9&4R]M=7-Q;"YP:'`Z,38W(&QI8B]61E,O;75S<6PN<&AP
M.C$X,"!L:6(O5D93+VUU<W%L+G!H<#HQ.#<*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,SDQ(&QI8B]61E,O<W%L7V9I;&4N<&AP.C,Y.0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B2V%N(&EN=&4@<F%D
M97)A(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HR
M-#0@;&EB+U9&4R]S;6(N<&AP.C(T.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E<UPB+B(*;7-G<W1R(")+
M86X@:6YT92!R861E<F$@5D93+6UA<'`@)R5S)RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0P-B!L:6(O5D93+W-Q;"YP:'`Z-#`Y"B,L('!H
M<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV
M96QY.B`E<RXB"FUS9W-T<B`B2V%N(&EN=&4@<F%D97)A(%9&4R!R96MU<G-I
M=G0Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#`S(&QI
M8B]61E,O9G1P+G!H<#HX,S0*;7-G:60@(E5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(DMA;B!I;G1E(&%V9_9R82!A
M:W1U96QL(&UA<'`N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV,#,@;&EB+TAO<F1E+T-R>7!T+W-M:6UE+G!H<#HV,#0*;7-G:60@
M(E5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T
M<B`B2V%N(&EN=&4@97AT<F%H97)A($-E<G1I9FEK871S9&5T86QJ97(B"@HC
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].
M971?24U34"])35-0+T%U=&@N<&AP.C$Q.`HC.B!L:6(O3F5T+TE-4U`N<&AP
M.C0S-R!L:6(O3F5T+TE-4U`O075T:"YP:'`Z,3(S"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(*
M;7-G<W1R(")+86X@:6YT92!L861D82!D969I;FET:6]N96X@878@)7,N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]6
M1E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ
M-S$*(SH@;&EB+U9&4R]F:6QE+G!H<#HR,#,@;&EB+U9&4R]F:6QE+G!H<#HR
M,#@@;&EB+U9&4R]S<6Q?9FEL92YP:'`Z,3<T"B,Z(&QI8B]61E,O<W%L7V9I
M;&4N<&AP.C$W.0IM<V=I9"`B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I;G1E(&9L>71T82!61E,M9FEL+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-M8BYP:'`Z.3,@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H
M<#HQ,#(*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HV-#@@9G)A;65W
M;W)K+U9&4R]61E,O9G1P+G!H<#HY.`HC.B!L:6(O5D93+W-M8BYP:'`Z.3,@
M;&EB+U9&4R]S;6(N<&AP.C$P-B!L:6(O5D93+W-M8BYP:'`Z-C4R"B,Z(&QI
M8B]61E,O9G1P+G!H<#HY.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(DMA;B!I;G1E(/9P
M<&YA(%9&4RUF:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,C<W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ,S`*(SH@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S,R!L:6(O5D93+V9I
M;&4N<&AP.C(X-`HC.B!L:6(O5D93+W-Q;%]F:6QE+G!H<#HQ,S@@;&EB+U9&
M4R]S<6Q?9FEL92YP:'`Z,30Q"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B2V%N(&EN=&4@]G!P;F$@5D93
M+69I;"!F]G(@<VMR:79N:6YG+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(@;&EB+U9&4R]F:6QE
M+G!H<#HX,R!L:6(O5D93+V9I;&4N<&AP.C$S-PHC.B!L:6(O5D93+W-Q;%]F
M:6QE+G!H<#HW-@IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(@IM
M<V=S='(@(DMA;B!I;G1E(/9P<&YA(%9&4RUF:6PN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-2!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HT-0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+B(*;7-G<W1R(")+86X@:6YT92#V<'!N82!K;VUP<FEM
M97)A="!A<FMI=BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,V(&QI
M8B]61E,N<&AP.C@U-@IM<V=I9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B2V%N(&EN=&4@;.1S82!6
M1E,M9FEL("AF:6QE<VEZ92@I(&UI<W-L>6-K861E<RDN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C@V-R!L:6(O5D93+G!H<#HX.#<*;7-G:60@(E5N
M86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN
M(@IM<V=S='(@(DMA;B!I;G1E(&SD<V$@5D93+69I;"`H9V5T1FEL95-I>F4H
M*2!M:7-S;'EC:V%D97,I+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE
M<B]397-S:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC.B!L:6(O2&]R9&4O4V5S
M<VEO;DAA;F1L97(O;F]N92YP:'`Z,S@*;7-G:60@(E5N86)L92!T;R!R96%D
M(&9I;&4Z("(*;7-G<W1R(")+86X@:6YT92!LY'-A(&9I;#H@(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C8Y(&QI8B]61E,O9FEL92YP:'`Z
M-C<V"FUS9VED(")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN(@IM<V=S='(@(DMA;B!I;G1E(&SD<V$@:V%T86QO9V5N(&;V<B`G=F9S
M<F]O="<N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3`U(&QI
M8B](;W)D92]+;VQA8BYP:'`Z,3$P.0HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',B"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E
M("5S('1I;&P@)7,Z(&1E<W1I;F%T:6]N<VUA<'`@9FEN;G,@<F5D86XB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS(&QI8B]61E,O
M<W%L7V9I;&4N<&AP.C,P,0IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@
M9&ER96-T;W)Y+B(*;7-G<W1R(")+86X@:6YT92!B>71A(&YA;6X@<.4@5D93
M+6UA<'`N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,CD@;&EB
M+U9&4R]S<6PN<&AP.C,S,@HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")+86X@:6YT
M92!B>71A(&YA;6X@<.4@5D93+6UA<'`Z("5S+B(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M,S0S"B,Z(&QI8B]61E,O<VUB+G!H<#HR-S$@;&EB+U9&4R]F='`N<&AP.C,T
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`B2V%N(&EN=&4@8GET82!N86UN('#E(%9&
M4RUF:6P@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-C$P
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(SH@;&EB+U9&4R]F
M:6QE+G!H<#HV,3<@;&EB+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM
M<V=S='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL("5S+R5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C@U
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,#$@;&EB+U9&
M4R]S<6PN<&AP.C,R-@HC.B!L:6(O5D93+VUU<W%L+G!H<#HR,3,@;&EB+U9&
M4R]M=7-Q;"YP:'`Z-#4R(&QI8B]61E,O<W%L7V9I;&4N<&AP.C(Y,PHC.B!L
M:6(O5D93+W-Q;%]F:6QE+G!H<#HS,#D*;7-G:60@(E5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N(@IM<V=S='(@(DMA;B!I;G1E(&)Y=&$@;F%M;B!PY2!6
M1E,M9FEL+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]M:VES;V9S+G!H<#HU,`HC.B!F<F%M97=O<FLO5D937TE33R])4T]7<FET
M97(O;6MI<V]F<RYP:'`Z-3$@;&EB+U9&4R])4T]7<FET97(O;6MI<V]F<RYP
M:'`Z-3`*;7-G:60@(E5N86)L92!T;R!R=6X@)VUK:7-O9G,G+B(*;7-G<W1R
M(")+86X@:6YT92!K]G)A("=M:VES;V9S)RXB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C4Y"B,Z(&QI8B](;W)D92]-24U%
M+U9I97=E<B]M<W=O<F0N<&AP.C4Y"FUS9VED(")5;F%B;&4@=&\@=')A;G-L
M871E('1H:7,@5V]R9"!D;V-U;65N="(*;7-G<W1R(")+86X@:6YT92#V=F5R
M<^1T=&$@5V]R9&1O:W5M96YT970B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC.B!L
M:6(O5D93+V9T<"YP:'`Z,34T(&QI8B]61E,O9G1P+G!H<#HQ-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(%PB)7-<
M(BXB"FUS9W-T<B`B2V%N(&EN=&4@<VMR:79A('1I;&P@5D93+69I;"`E<RXB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-SD@;&EB+U9&4R]F
M:6QE+G!H<#HQ.#8*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(DMA;B!I;G1E('-K<FEV82!T:6QL
M(%9&4RUF:6P@*&-O<'DH*2!M:7-S;'EC:V%D97,I+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9I;&4N<&AP.C(X,2!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HQ-#,@;&EB+U9&4R]F:6QE+G!H<#HR.#@*(SH@;&EB+U9&4R]S<6Q?9FEL
M92YP:'`Z,30V(&QI8B]61E,O<W%L7V9I;&4N<&AP.C$U,0IM<V=I9"`B56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N(@IM<V=S='(@(DMA;B!I;G1E
M('-K<FEV82!D871A('1I;&P@5D93+69I;"XB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z.#0R(&QI8B]61E,N<&AP.C@V,@IM<V=I9"`B56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+B(*;7-G
M<W1R(")+86X@:6YT92!S:W)I=F$@=&EL;"!61E,M9FEL+"!K=F]T82!S:W5L
M;&4@]G9E<G-K<FED87,N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,`IM<V=I9"`B56YD97)L:6YE(@IM<V=S='(@(E5N
M9&5R<W1R=6ME;B(*"B,Z('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G
M:60@(E5N9&\@0VAA;F=E<R(*;7-G<W1R("+%;F=R82#D;F1R:6YG87(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS
M9VED(")5;F1O97,@>6]U<B!L87-T(&%C=&EO;B(*;7-G<W1R("+%;F=R87(@
M9&EN('-E;F%S=&4@Y71GY')D(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,C(S"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,
M+W)F8S(P.#8N<&AP.C,Y,"!L:6(O2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z,C(Q"B,Z(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HS.#@*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(D]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!P
MY2!F]G)B:6YD96QS93H@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,T,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HS-S@*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,S@T(&QI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<#HR,3<*
M(SH@;&EB+TAO<F1E+TE-05`O04-,+W)F8S(P.#8N<&AP.C,S.2!L:6(O2&]R
M9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S<V"B,Z(&QI8B](;W)D92])34%0
M+T%#3"]R9F,R,#@V+G!H<#HS.#(*;7-G:60@(E5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@=&\Z("(*;7-G<W1R(")/=N1N=&%T('-V87(@9G+E
M;B!S97)V97(@=&EL;#H@(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A
M=&5G;W)Y36%N86=E<BYP:'`Z-3<*(SH@;&EB+TAO<F1E+U!R969S+T-A=&5G
M;W)Y36%N86=E<BYP:'`Z-3<*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C$*;7-G:60@(E5N9FEL960B"FUS9W-T<B`B16H@
M:V%T96=O<FES97)A9"(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,S@T"B,L('!H<"UF;W)M870*;7-G:60@(E5N:&%N
M9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,B"FUS9W-T<B`B26-K92!H86YT
M97)A9"!K;VUP;VYE;G0@878@='EP.B`E<R(*"B,Z(&-O;F9I9R]N;',N<&AP
M+F1I<W0Z,3DV"FUS9VED(")5;FEC;V1E("A55$8M."DB"FUS9W-T<B`B56YI
M8V]D92`H551&+3@I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-38@;&EB+TAO<F1E+TY,4R]T;&0N
M<&AP.C$W"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S0@;&EB
M+TAO<F1E+TY,4R]'96])4"YP:'`Z-38*;7-G:60@(E5N:71E9"!!<F%B($5M
M:7)A=&5S(@IM<V=S='(@(D;V<F5N861E($%R86)E;6ER871E;B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-"!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C,X"B,Z(&QI8B](;W)D
M92].3%,O8V]U;G1R:65S+G!H<#HR,S4@;&EB+TAO<F1E+TY,4R]'96])4"YP
M:'`Z-S0*;7-G:60@(E5N:71E9"!+:6YG9&]M(@IM<V=S='(@(E-T;W)B<FET
M86YN:65N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#`@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S8*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z
M,C0P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR,S8@;&EB+TAO
M<F1E+TY,4R]'96])4"YP:'`Z,3$S"FUS9VED(")5;FET960@4W1A=&5S(@IM
M<V=S='(@(D;V<F5N=&$@4W1A=&5R;F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(S-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$S(&QI8B](
M;W)D92].3%,O=&QD+G!H<#HR,SD*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I
M97,N<&AP.C(S-R!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G:60@
M(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<R(*;7-G<W1R
M(")!;65R:6MA;G-K82!3=&EL;&%H879S]F%R;F$B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z-C(@;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM
M<V=I9"`B56YI=',B"FUS9W-T<B`B16YH971E<B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C0Q."!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,3D*(SH@;&EB+TAO<F1E+T-R>7!T+W!G<"YP:'`Z-#(Y(&QI
M8B](;W)D92]#<GEP="]P9W`N<&AP.C0S,`HC.B!L:6(O2&]R9&4O34E-12]6
M:65W97(O=&=Z+G!H<#HU.`IM<V=I9"`B56YK;F]W;B(*;7-G<W1R(")/:^1N
M9"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y.`HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y
M.`IM<V=I9"`B56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(*
M;7-G<W1R(")/:^1N="!G<N1N<W-N:71T<VUE9&1E;&%N9&5I9"`H87!I;7-G
M:60I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(Y.0HC.B!L:6(O3F5T+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+B(*;7-G<W1R(")/:^1N="!K;&EE;G1M961D96QA;F1E:60@*&-L:6US
M9VED*2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,30W"FUS
M9VED(")5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R(")/:^1N
M9"!O<G0@<W!E8VEF:6-E<F%D+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC.B!L:6(O3F5T+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`B3VOD;G0@86YVY&YD87)N86UN(&5L;&5R
M(&SV<V5N;W)D+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT
M(&5L96UE;G0B"FUS9W-T<B`B5&$@8F]R="!LY&YK96X@9G+E;B!N=79R86YD
M92!E;&5M96YT(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H
M<#HR.38@;&EB+TAO<F1E+TED96YT:71Y+G!H<#HS,#(*;7-G:60@(E5N;F%M
M960B"FUS9W-T<B`B3F%M;FSV<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I=FEL96=E9"!S
M8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T
M:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@
M<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@(@HB
M<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE
M(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HB26-K92UP<FEV:6QI9V5R861E('-K
M<FEP="!K86X@:6YT92!K;VUM82#E="!+;&EP<"!U="]+;W!I97)A+TML:7-T
M<F$M(@HB9G5N:W1I;VYE<FYA(&%V('/D:V5R:&5T<W-KY&PN($ML:6-K82!/
M2R!F]G(@871T('-E(&5N('1E:VYI<VL@8F5S:W)I=FYI;F<@(@HB9G+E;B!M
M;WII;&QA+F]R9R!O;2!H=7(@9'4@:V%N('1I;&SE=&$@871T('-K<FEP="!K
M;VUM97(@Y70@=7)K;&EP<"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS9VED(")5;G-E="!C;VQO<B(*
M;7-G<W1R(")482!B;W)T(&;D<F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<VUI;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.CDR-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS
M,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C8X-PHC.B!L:6(O2&]R9&4O
M0W)Y<'0O<VUI;64N<&AP.CDR-R!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP
M.CDS,PIM<V=I9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(E1I
M;&SD9V=E="!S=/9D<R!I;G1E(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ.3<@;&EB+TAO<F1E+U!E<FUS+U5)+G!H<#HQ.3<*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S,*;7-G:60@(E5P9&%T92(*
M;7-G<W1R(")5<'!D871E<F$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T92`E<R(*
M;7-G<W1R(")5<'!D871E<F$@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C8T.`IM<V=I9"`B57!D871E(')E<W!O
M;F1E;G0@<W1A='5S(@IM<V=S='(@(E5P<&1A=&5R82!S=&%T=7,@<.4@<W9A
M<F%N9&4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V
M"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R(")5<'!D871E<F$@86YVY&YD
M87)E(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ-#0@861M:6XO<&5R;7,O961I
M="YP:'`Z,3`R('-E<G9I8V5S+W-H87)E<R]E9&ET+G!H<#HR,S`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B57!D871E9"!<(B5S7"(N(@IM<V=S='(@(E5P<&1A
M=&5R861E("<E<R<N(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#,*
M;7-G:60@(E5P9W)A9&4@<V-R:7!T(&1E;&5T960N(@IM<V=S='(@(E5P<&1A
M=&5R:6YG<W-C<FEP="!R861E<F%T+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ-S@@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$X,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3DX
M"FUS9VED(")5<&QO860B"FUS9W-T<B`B3&%D9&$@=7!P(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N(@IM<V=S='(@(DQA
M9&1A9&4@=7!P(&%L;&$@:V]N9FEG=7)A=&EO;G-F:6QE<B!T:6QL('-E<G9E
M<FXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y
M<&5?;&%N9RYJ<SHR,`IM<V=I9"`B57!P97(@;&%T:6X@;&5T=&5R<R(*;7-G
M<W1R(")697)S86QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P<&5R(')O;6%N(&YU
M;6)E<G,B"FUS9W-T<B`B4F]M97)S:V$@<VEF9G)O<B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3,@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T,0HC.B!L:6(O2&]R9&4O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C,X(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q
M,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(SH@;&EB
M+TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(D%N=N1N9"!A
M:W1U96QL.B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,X"B,Z(&QI8B].970O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU,S@*;7-G:60@(E5S92!34TPB"FUS9W-T<B`B06YVY&YD(%-33"(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C<*;7-G:60@(E5S92!I9B!N
M86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N(@IM
M<V=S='(@(D%N=N1N9"!O;2!N86UN+VSV<V5N;W)D(.1R(&%N;F]R;'5N9&$@
M9O9R($E-4U`M<V5R=F5R+B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,C$*;7-G:60@(E5S97(B"FUS9W-T<B`B06YVY&YD87)E(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HW,C`@;&EB
M+TAO<F1E+U)E9VES=')Y+G!H<#HW-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(D%N
M=N1N9&%R92`E<R#D<B!I;G1E(&)E:/9R:6<@9O9R("5S+B(*"B,Z(&%D;6EN
M+W5S97(N<&AP.C(P,PIM<V=I9"`B57-E<B!!9&UI;FES=')A=&EO;B(*;7-G
M<W1R(")!;G;D;F1A<F%D;6EN:7-T<F%T:6]N(@H*(SH@9G)A;65W;W)K+U!R
M969S+U!R969S+U5)+G!H<#HR-3`@;&EB+TAO<F1E+U!R969S+U5)+G!H<#HR
M-#4*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R(")!;G;D;F1A<FEN<W3D
M;&QN:6YG87(B"@HC.B!S:6=N=7`N<&AP.C8R"FUS9VED(")5<V5R(%)E9VES
M=')A=&EO;B(*;7-G<W1R(")!;G;D;F1A<G)E9VES=')E<FEN9R(*"B,Z('-I
M9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(D%N=N1N9&%R<F5G
M:7-T<F5R:6YG(&AA<B!A=F%K=&EV97)A=',N(@H*(SH@;&EB+T)L;V-K+V%C
M8V]U;G0N<&AP.C0V.0IM<V=I9"`B57-E<B!A8V-O=6YT(&YO="!F;W5N9"(*
M;7-G<W1R(")!;G;D;F1A<FMO;G1O="!H:71T861E<R!I;G1E(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H
M<#HY.`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H
M<#HQ-3`@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!L
M:6(O3F5T+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.CDX(&QI8B].970O
M4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3DX"B,Z(&QI8B].970O4TU3+W=I
M;E]H='1P+G!H<#HQ-3`@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,S,*
M(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHW,B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T
M<B`B06YVY&YD87)N86UN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N
M=7`N<&AP.C$R-"!L:6(O2&]R9&4O075T:"]3:6=N=7`N<&AP.C$R-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES
M=',N(@IM<V=S='(@(D%N=N1N9&%R;F%M;B`E<R!F:6YN<R!R961A;BXB"@HC
M.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*;7-G:60@(E5S97)N
M86UE.B(*;7-G<W1R(")!;G;D;F1A<FYA;6XZ(@H*(SH@=&5M<&QA=&5S+VQO
M9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E<FYA;64Z("(*;7-G<W1R(")!
M;G;D;F1A<FYA;6XZ("(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N
M:6YC.C(*;7-G:60@(E5S97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(D%N
M=N1N9&%R92!I('-Y<W1E;65T.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C0R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30@;&EB+TAO<F1E
M+TY,4R]T;&0N<&AP.C(T,@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,Y(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B57IB
M96MI<W1A;B(*;7-G<W1R(")5>F)E:VES=&%N(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,38S(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(U-0HC.B!L:6(O5D93+V9I;&4N<&AP.C$W,"!L:6(O5D93+V9I;&4N<&AP
M.C(V,@IM<V=I9"`B5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB"FUS
M9W-T<B`B5D93+6UA<'`@97AI<W1E<F%R(&EN=&4N(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C$R,`IM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`B
M4V5M97-T97(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C8@;&EB
M+TAO<F1E+T9O<FTN<&AP.C@W,`IM<V=I9"`B5F%L:60@;&]C871I;VYS(&9O
M=6YD(&EN8VQU9&4Z("(*;7-G<W1R(")':6QT:6=A('!L871S97(@<V]M(&AI
M='1A9&5S(&EN:VQU9&5R87(Z("(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-C,X(&QI8B](;W)D92]#<GEP="]S;6EM92YP:'`Z-C,Y
M"FUS9VED(")686QI9&ET>2(*;7-G<W1R(")':6QT:6=H970B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-PHC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*
M(SH@;&EB+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-R!L:6(O3F5T
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T<B`B36EN=71E<B!F<N5N(&YU(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q-S<*(SH@;&EB+TAO<F1E+T9O<FTN<&AP.C@V,"!L:6(O
M2&]R9&4O1F]R;2YP:'`Z,3$X,0HC+"!P:'`M9F]R;6%T"FUS9VED(")686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RXB"FUS9W-T<B`B
M5N1R9&5T(/9V97)S=&EG97(@9&5T(&CV9W-T82!T:6QLY71N82`H)7,I(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR,C8V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S
M,38@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDR.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y(&QI8B](;W)D92]&;W)M
M+G!H<#HR,C0X"B,Z(&QI8B](;W)D92]&;W)M+G!H<#HR,C<P(&QI8B](;W)D
M92]&;W)M+G!H<#HR,S(P(&QI8B](;W)D92]&;W)M+G!H<#HR.3$T"B,Z(&QI
M8B](;W)D92]&;W)M+U1Y<&4O=&%B;&5S970N<&AP.C4Y"FUS9VED(")686QU
M97,B"FUS9W-T<B`B5N1R9&5N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$P.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3@V"B,Z(&QI8B](
M;W)D92]&;W)M+G!H<#HR,3$S(&QI8B](;W)D92]&;W)M+G!H<#HR,3DP"FUS
M9VED(")686QU97,@=&\@<V5L96-T(&9R;VTB"FUS9W-T<B`B5N1R9&5N(&%T
M="!VY&QJ82!F<N5N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L
M9"YP:'`Z,C0Y"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#`@
M;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")686YU871U(@IM
M<V=S='(@(E9A;G5T874B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C,S"FUS9VED(")687)I86)L92(*;7-G<W1R(")687)I86)E;"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,34@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C(T-0HC.B!L:6(O
M2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q(&QI8B](;W)D92].3%,O1V5O
M25`N<&AP.C$Q-0IM<V=I9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L
M82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C$X(&QI
M8B](;W)D92]#<GEP="]S;6EM92YP:'`Z,C$X"FUS9VED(")697)I9FEC871I
M;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M<&5R
M960@=VET:"XB"FUS9W-T<B`B5F5R:69I97)I;F<@;6ES<VQY8VMA9&5S("T@
M;65D9&5L86YD970@:V%N(&AA(&UA;FEP=6QE<F%T<RXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P,"!L:6(O2&]R9&4O0W)Y<'0O
M<VUI;64N<&AP.C<P,0IM<V=I9"`B5F5R<VEO;B(*;7-G<W1R(")697)S:6]N
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(R.`IM<V=I9"`B5F5R
M<VEO;B!#;VYT<F]L(@IM<V=S='(@(E9E<G-I;VYH86YT97)I;F<B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S
M"FUS9VED(")697)T:6-A;"!A;&EG;B(*;7-G<W1R(")697)T:6MA;"!J=7-T
M97)I;F<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(E9E<G1I
M:V%L('5T9GEL;&YA9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R(")697)T
M:6MA;#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,0IM<V=I9"`B5F5R>2!(:6=H(@IM<V=S='(@(E;D;&1I9W0@:/9G(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-B!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C0X"B,Z(&QI
M8B](;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#(@;&EB+TAO<F1E+TY,4R]'
M96])4"YP:'`Z,3$V"FUS9VED(")6:65T($YA;2(*;7-G<W1R(")6:65T;F%M
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.3<*;7-G:60@(E9I971N86UE
M<V4@*%9)4T-)22DB"FUS9W-T<B`B5FEE=&YA;65S:7-K("A625-#24DI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.38Q(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HY-S`*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5FEE=R`E<R(*;7-G<W1R(")6:7-A("5S(@H*(SH@;&EB+T)L;V-K+VEF
M<F%M92YP:'`Z,PIM<V=I9"`B5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G92(*
M;7-G<W1R(")6:7-A(&5N(&5X=&5R;B!W96)B<VED82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@R,"!L:6(O2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`Z.#(Y"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@87,@
M)7,B"FUS9W-T<B`B5FES82!S;VT@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C<Y"FUS9VED(")6:65W(&5V96YT
M(@IM<V=S='(@(E9I<V$@:.1N9&5L<V4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$P.0IM<V=I9"`B5FEE=R!T87-K
M(@IM<V=S='(@(E9I<V$@=7!P9VEF="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C0V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C0S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(T-@HC.B!L:6(O2&]R9&4O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C0S(&QI8B](;W)D92].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B
M5FER9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B2G5N9V9R=?9A<FYA
M+"!"<FET=&ES:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$V(&QI8B](;W)D92].3%,O=&QD
M+G!H<#HR-#<*(SH@;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T-"!L
M:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ,38*;7-G:60@(E9I<F=I;B!)<VQA
M;F1S+"!5+E,N(@IM<V=S='(@(DIU;F=F<G7V87)N82P@06UE<FEK86YS:V$B
M"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-@IM<V=I9"`B5FES:6)I;&ET
M>2(*;7-G<W1R(")3:6MT(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(U,@IM<V=I9"`B5FES:6)I;&ET>3H@(@IM<V=S='(@(E-I:W0Z(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP
M:'`Z.#0*(SH@;&EB+TYE="]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX
M-`IM<V=I9"`B5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B5F]D
M869O;F4@271A;&EE;B!V:6$@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC
M871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*(SH@
M;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,V
M"FUS9VED(")705).(@IM<V=S='(@(E9!4DXB"@HC.B!A9&UI;B]S971U<"]S
M8W)I<'1S+G!H<#HX-0HC+"!P:'`M9F]R;6%T"FUS9VED(")705).24Y'(2$A
M(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RXB"FUS9W-T<B`B5D%2
M3DE.1R$A(2!2041%4D$@4TM225!4150@34%.545,3%0@1E+%3B`E<RXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,R!L:6(O
M3F5T+U--4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B
M"FUS9W-T<B`B5TE.('9I82!(5%10(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HR-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR
M-#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-R!L:6(O2&]R
M9&4O3DQ3+W1L9"YP:'`Z,C4P"B,Z(&QI8B](;W)D92].3%,O8V]U;G1R:65S
M+G!H<#HR-#4@;&EB+TAO<F1E+TY,4R]'96])4"YP:'`Z,3$W"FUS9VED(")7
M86QL:7,@86YD($9U='5N82(*;7-G<W1R(")786QL:7,@;V-H($9U='5N82(*
M"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E
M;F5R+W-T871U<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:'1M;"YP:'`Z,C<R"B,Z(&QI8B](;W)D92].;W1I9FEC871I;VXO3&ES
M=&5N97(O<W1A='5S+G!H<#HR.0HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O
M:'1M;"YP:'`Z,3(W(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HX,PIM<V=I9"`B
M5V%R;FEN9R(*;7-G<W1R(")687)N:6YG(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`B
M3VXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CD*;7-G:60@
M(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B5N1D97)P<F]G;F]S(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0Q-@IM<V=I9"`B5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(E;D9&5R9&%T82!F<N5N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DR(&QI8B](;W)D92]&;W)M
M+G!H<#HX.38*;7-G:60@(E=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N
M8V]M(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*
M;7-G<W1R(")796)B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0S
M.0IM<V=I9"`B5V5B(%-I=&4B"FUS9W-T<B`B5V5B8G!L871S(@H*(SH@8V]N
M9FEG+W1H96UE<R]W96)B<&QA='-E;BUS;V)E<BYP:'`Z,38*;7-G:60@(E=E
M8F)P;&%T<V5N("T@4V]B97(B"FUS9W-T<B`B5V5B8G!L871S96X@+2!3;V)E
M<B(*"B,Z(&-O;F9I9R]T:&5M97,O=V5B8G!L871S96XM<V]B97)?;F5W+G!H
M<#HV"FUS9VED(")796)B<&QA='-E;B`M(%-O8F5R($Y%5R(*;7-G<W1R(")7
M96)B<&QA='-E;B`M(%-O8F5R($Y9(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA
M;F-E+TUA:6YT96YA;F-E+G!H<#HU."!L:6(O2&]R9&4O36%I;G1E;F%N8V4N
M<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B5F5C:V]V:7,B"@HC.B!S
M97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*
M;7-G<W1R(")6Y&QK;VUM96XB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE
M+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R(")6Y&QK;VUM96X@
M=&EL;"`E<R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(Y('1E
M;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")796QC;VUE+"`E<R(*;7-G<W1R(")6Y&QK;VUM96XL("5S(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.3@*;7-G:60@(E=E<W1E<FX@*$E33RTX.#4Y
M+3$I(@IM<V=S='(@(E;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,2DB"@HC.B!C
M;VYF:6<O;FQS+G!H<"YD:7-T.C$Y.0IM<V=I9"`B5V5S=&5R;B`H25-/+3@X
M-3DM,34I(@IM<V=S='(@(E;D<W1E<FSD;F1S:R`H25-/+3@X-3DM,34I(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$@;&EB+TAO<F1E+TY,4R]T;&0N<&AP.C<X"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#8@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(E;D<W1R
M82!386AA<F$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#0Q"B,L('!H
M<"UF;W)M870*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(E9I;&ME;B!A<'!L:6MA=&EO
M;B!S:V%L;"`E<R!V:7-A(&5F=&5R(&EN;&]G9VYI;F<_(@H*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_(@IM<V=S='(@(E9I;&ME;B#D<B!A=F=RY&YS
M;FEN9W-T96-K;F5T/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$W"FUS9VED(")7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_(@IM<V=S
M='(@(E9I;&ME="#D<B!T96-K;F5T(&;V<B!C:71E<F%D('1E>'0_(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P,S,*(SH@
M;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P-C0*;7-G:60@
M(E=H97)E:7,@075S=')A;&EA(&UA<"(*;7-G<W1R(")7:&5R96ES($%U<W1R
M86QI96YK87)T82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B
M5VAI8V@@<&AA<V5S(@IM<V=S='(@(E9I;&MA(&9A<V5R(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C$S-@IM<V=I9"`B5VAI8V@@<&QU9VEN<R!T;R!E
M;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G<W1R(")6:6QK
M82!P;'5G:6X@<VMA;&P@86MT:79E<F%S(&;V<B!2:6-H(%1E>'0@961I=&]R
M;BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@T"FUS9VED(")7:61T:"(*;7-G<W1R(")"<F5D9"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C4@;&EB+TAO<F1E+T9O<FTN<&AP
M.C,Q,3$*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R(")"<F5D
M9"!I($-34RUU;FET<R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C$*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@
M=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ(@IM<V=S
M='(@(D)R961D('#E(&UE;GEN(&;V<B`G)7,G('1I;&P@=N1N<W1E<B`H9^1L
M;&5R(&9RY6X@;N1S=&$@:6YL;V=G;FEN9R(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V"FUS9VED(")7:61T:"!O9B!T
M:&4@=&%B;&4B"FUS9W-T<B`B5&%B96QL8G)E9&0B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@
M=6YI="(*;7-G<W1R(")"<F5D9&5N:&5T(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G
M<W1R(")"<F5D9#HB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-3$U
M"FUS9VED(")7:6MI(@IM<V=S='(@(E=I:VDB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C@Y(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C8V"FUS9VED(")7:6YD(@IM<V=S='(@(E9I;F0B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV-PIM<V=I9"`B
M5VEN9"!%87)L>2(*;7-G<W1R(")4:61I9R!V:6YD(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HX-PIM<V=I9"`B5VEN9"!S<&5E9"!I;B!K;F]T<R(*;7-G
M<W1R(")6:6YD:&%S=&EG:&5T(&D@:VYO<"(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,38S"FUS9VED(")7:6YD.B(*;7-G<W1R(")6:6YD.B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@(E=I;F0Z("(*
M;7-G<W1R(")6:6YD.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C0*
M;7-G:60@(E=I<V1O;2(*;7-G<W1R(")6:7-D;VTB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z,3DX"FUS9VED(")7:7-H;&ES="(*;7-G<W1R("+6
M;G-K96QI<W1A(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8U"FUS9VED
M(")7;W)K(@IM<V=S='(@(D%R8F5T92(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HQ,C0*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C$V-`HC.B!L:6(O2&]R9&4O34E-12]6:65W
M97(O=F-A<F0N<&AP.C$R-"!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$V-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(D%D<F5S<RP@
M87)B971E(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$Y,@HC.B!L:6(O2&]R9&4O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y
M,@IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R(")496QE9F]N+"!A<F)E=&4B
M"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K
M+T9I;&5?0U-6+T-35BYP:'`Z,C8R"B,Z(&QI8B]&:6QE+T-35BYP:'`Z,3DS
M(&QI8B]&:6QE+T-35BYP:'`Z,CDT"B,L('!H<"UF;W)M870*;7-G:60@(E=R
M;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L
M(&9O=6YD("5D+B(*;7-G<W1R(")&96P@86YT86P@9N1L="!PY2!R860@)60N
M($;V<G;D;G1A9&4@)60L(&AI='1A9&4@)60N(@H*(SH@9G)A;65W;W)K+T9I
M;&5?0U-6+T-35BYP:'`Z,S`P(&QI8B]&:6QE+T-35BYP:'`Z,S,R"B,L('!H
M<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B1F5L(&%N=&%L(&;D;'0N($;V
M<G;D;G1A9&4@)60L(&AI='1A9&4@)60N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9FEL92YP:'`Z,3$T(&QI8B]61E,O9FEL92YP:'`Z,3(Q"B,L('!H<"UF
M;W)M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@
M5D93(&9I;&4N(@IM<V=S='(@(D9E;"!P;W-I=&EO;B`E9"!V:60@;.1S;FEN
M9R!A=B!61E,M9FEL+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#4*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A:6YT<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C4Y,B!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y,PIM<V=I9"`B6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G92(*;7-G<W1R(")8-3`Y5C,@573V:V%D
M(&YY8VME;&%N=N1N9&YI;F<B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y-"!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-0IM
M<V=I9"`B6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-2!L
M:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV.#(@;&EB+TAO<F1E+T-R>7!T+W-M
M:6UE+G!H<#HV.#,*;7-G:60@(E@U,#EV,R!E>'1E;G-I;VYS(@IM<V=S='(@
M(E@U,#E6,RUT:6QLY&=G(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z
M-#<@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@*(SH@=&5M<&QA=&5S+V1A
M=&$O9&%T92YI;F,Z-#D@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(EE9(@IM<V=S='(@(EE9(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C,X.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#,P"B,Z(&QI8B](;W)D92]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,30@;&EB+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0U-@IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P.#`*(SH@;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,3$*;7-G:60@(EEA:&]O
M(2!M87`B"FUS9W-T<B`B66%H;V\A(&UA<"(*"B,Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`Z-38@;&EB+TAO<F1E+TUA:6YT96YA
M;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM<V=S='(@(L5R;&EG(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-R!L:6(O2&]R9&4O3DQ3+W1L9"YP:'`Z,C4R"B,Z(&QI8B](
M;W)D92].3%,O8V]U;G1R:65S+G!H<#HR-#<@;&EB+TAO<F1E+TY,4R]'96])
M4"YP:'`Z,3$W"FUS9VED(")996UE;B(*;7-G<W1R(")996UE;B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,S4*(SH@;&EB
M+TAO<F1E+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDV-@IM<V=I9"`B665S
M(@IM<V=S='(@(DIA(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E
M;65N=%]B;W1T;VTN:6YC.C8*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA
M:6YT96YA;F-E+FAT;6PZ-38*;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R
M(")*82P@:F%G('-A;71Y8VME<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-3(*;7-G:60@(EEO=2!A<F4@:6X@5$585"!-
M3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!7
M65-)5UE'+B(*;7-G<W1R(")$=2!H87(@86MT:79E<F%T('1E>'1LY&=E+B!!
M;G;D;F0@6SP^72!F]G(@871T(.5T97)GY2!T:6QL(%=94TE764<N(@H*(SH@
M;&EB+TAO<F1E+T)L;V-K+TQA>6]U="]-86YA9V5R+G!H<#HR,S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@
M;6]R92!T:&%N("5D(&)L;V-K<RXB"FUS9W-T<B`B1'4@:&%R(&EN=&4@8F5H
M]G)I9VAE="!S:V%P82!F;&5R(.1N("5D(&)L;V-K+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92YP:'`Z,3,V-R!L:6(O2&]R9&4N<&AP.C$T,34*;7-G
M:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@(D1U(.1R
M(&EN=&4@875T96YT:7-E<F%D+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])
M9&5N=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G
M7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B1'4@
M:V%N(&EN=&4@86YVY&YD82`G7%PG(&D@9&ET="!N86UN(@H*(SH@;&EB+TAO
M<F1E+TED96YT:71Y+G!H<#HS,#@*;7-G:60@(EEO=2!C86YN;W0@:&%V92!T
M:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@
M(D1U(&MA;B!I;G1E(&%N=N1N9&$@)UQ<)R!I(&1I='0@;F%M;B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,3DW-0HC.B!L:6(O2&]R9&4O1F]R;2YP:'`Z,3@U.2!L:6(O2&]R
M9&4O1F]R;2YP:'`Z,3DW.0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R(")$=2!A;F=A=B!I;G1E(&5N
M(&=O9&OD;F0@92UP;W-T861R97-S+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A
M=&$N<&AP.C(Y,"!L:6(O2&]R9&4O1&%T82YP:'`Z,CDP"B,L('!H<"UF;W)M
M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M(@HB:6X@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDX."!L:6(O2&]R9&4O075T:"YP:'`Z.3@W"FUS9VED(")9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(D1U(.1R('5T;&]G9V%D+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$@;&EB+TAO<F1E+T9O
M<FTN<&AP.C$R-C4*;7-G:60@(B(*(EEO=2!H879E('1O(&5N=&5R(&$@=F%L
M:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I
M;VYA;"`G*R<@(@HB9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E
M9FEX+B(*;7-G<W1R("(B"B)$=2!MY7-T92!A;F=E(&5T="!G:6QT:6=T(&UO
M8FEL;G5M;65R.R!E;F)A<G0@<VEF9G)O<B!O8V@@971T("<K)R!F]G)E("(*
M(FEN=&5R;F%T:6]N96QL="!P<F5F:7@N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3$X."!L:6(O2&]R9&4O1F]R;2YP:'`Z,3$Y,@IM<V=I9"`B
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92XB"FUS9W-T<B`B1'4@
M86YG878@:6YT92!E='0@9V]D:^1N="!VY')D92XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,S<@;&EB+TAO<F1E+T%U=&@O4VEG;G5P
M+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@
M8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@HB1'4@;>5S=&4@
M:V]N9FEG=7)E<F$@96X@1&%T851RY&1S+6MO<'!L:6YG(&;V<B!A='0@86YV
MY&YD82!R96=I<W1R97)I;F<B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C0S-B!L:6(O2&]R9&4N<&AP.C0V,@IM<V=I9"`B66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(D1U(&WE<W1E(&MO;F9I
M9W5R97)A(&5N(%9&4RUK;W!P;&EN9R(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`B1'4@;>5S=&4@8F5S:W)I=F$@<')O8FQE;65N+"!I;FYA
M;B!D=2!K86X@<F%P<&]R=&5R82!E='0@<')O8FQE;2XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`B1'4@;>5S=&4@86YG92!E;B!54DP@<V]M(&SD;FME;B!P96MA
M<B!PY2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED
M(")9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM
M<V=S='(@(D1U(&WE<W1E(&%N9V4@96X@<V5R=F5R('-O;2!S:V%L;"!R861E
M<F%S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B1'4@
M;>5S=&4@86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!R96YS87,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`P"FUS9VED(")9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+B(*;7-G<W1R(")$=2!MY7-T92!A
M;F=E(&5T="!A;G;D;F1A<FYA;6X@<V]M('-K86QL(')A9&5R87,N(@H*(SH@
M861M:6XO=7-E<BYP:'`Z-C(@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E
M+FEN8SHX"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M
M;B!S;VT@<VMA;&P@;.1G9V%S('1I;&PN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,30V"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U
M<&1A=&4N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T(&%N=N1N9&%R;F%M
M;B!S;VT@<VMA;&P@=7!P9&%T97)A<RXB"@HC.B!F<F%M97=O<FLO0V]M<')E
M<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S@@;&EB+TAO<F1E+T-O;7!R97-S+WII
M<"YP:'`Z,3,X"FUS9VED(")9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N
M('1O('!E<F9O<FTN(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@96X@Y71GY')D
M('-O;2!S:V%L;"!U=&;V<F%S+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F
M<R]#871E9V]R>4UA;F%G97(N<&AP.C<Q"B,Z(&QI8B](;W)D92]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP.C<Q"FUS9VED(")9;W4@;75S="!T>7!E(&$@
M;F5W(&-A=&5G;W)Y(&YA;64N(@IM<V=S='(@(D1U(&WE<W1E(&%N9V4@971T
M(&YY='0@:V%T96=O<FEN86UN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C<S"B,Z(&QI8B].970O4TU3+W9O
M9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO=2!N965D('1O('!R
M;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS9W-T<B`B1'4@;>5S
M=&4@86YG92!E='0@:71A;&EE;G-K="!T96QE9F]N;G5M;65R(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V(&QI8B](;W)D92]!=71H+G!H<#HY
M-S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U<B`E<R!S97-S:6]N(&AA<R!E
M>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN(@IM<V=S='(@(D1I;B`E<R!S
M97-S:6]N(&AA<B!U<'!H]G)T+B!687(@9V]D(&QO9V=A(&EN(&EG96XN(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S@*;7-G:60@(EEO
M=7(@16UA:6P@061D<F5S<R(*;7-G<W1R(")$:6X@92UP;W-T861R97-S(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q-0IM<V=I9"`B66]U<B!&<F]M
M.B!A9&1R97-S.B(*;7-G<W1R(")$:6X@1G+E;CH@861R97-S.B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HV-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M-S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@U"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,@IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$
M:6X@:6YF;W)M871I;VXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#`@;&EB+TAO<F1E+T%U=&@N<&AP.CDW.0HC+"!P:'`M9F]R;6%T"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(D1I;B!I;G1E<FYE=&%D<F5S<R!H87(@Y&YD<F%T<R!E9G1E<B!A
M='0@9'4@;&]G9V%T(&EN('1I;&P@)R5S)RX@1O9R(&%T="`B"B)S:WED9&$@
M9&EG+"!MY7-T92!D=2!L;V=G82!I;B!I9V5N+B(*"B,Z('1E;7!L871E<R]P
M<F]B;&5M+W!R;V)L96TN:6YC.C,S"FUS9VED(")9;W5R($YA;64B"FUS9W-T
M<B`B1&ET="!N86UN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]A9&0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@
M(@HB=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT("(*(F%U=&AE;G1I8V%T:6]N(&)A8VME
M;F0N(@IM<V=S='(@(B(*(D1I;B!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T
M]F1E<B!I;G1E('5P<&SD9V<@878@86YVY&YD87)E+B!/;2!D=2!V:6QL("(*
M(F%N=N1N9&$@2&]R9&4@9O9R(&%T="!A9&UI;FES=')E<F$@86YVY&YD87)E
M('/E(&WE<W1E(&1U(&%N=N1N9&$@96X@86YN86X@(@HB875T96YT:7-E<FEN
M9W-K;W!P;&EN9RXB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI<W0N
M:6YC.C4*;7-G:60@(B(*(EEO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D
M;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E
M("(*(FAA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BXB
M"FUS9W-T<B`B(@HB1&ET="!A=71E;G1I<V5R:6YG<VMO<'!L:6YG('-T]F1E
M<B!I;G1E(&QI<W1N:6YG(&%V(&%N=N1N9&%R92P@96QL97(@<^4@Y'(@(@HB
M9G5N:W1I;VYE;B!A=G-TY&YG9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0@;&EB+TAO<F1E+T%U=&@N<&AP.CDX,PHC+"!P:'`M9F]R;6%T
M"FUS9VED("(B"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*
M(E1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN(@IM<V=S='(@(B(*(D1I;B!W96)B;.1S87)E+VEN=&5R;F5T861R97-S
M(&AA<B#D;F1R871S(&5F=&5R(&%T="!D=2!L;V=G870@:6X@=&EL;"`G)7,G
M+B`B"B)&]G(@871T('-K>61D82!D:6<L(&WE<W1E(&1U(&QO9V=A(&EN(&EG
M96XN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-34*;7-G:60@(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T
M<B`B1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@9&5N(&CD<B!F=6YK=&EO
M;F5N+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS.C0R"FUS
M9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"`B"B)T;R!P
M<FEN="XB"FUS9W-T<B`B(@HB1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@
M=71S:W)I9G1S9G5N:W1I;VYE;BX@5')Y8VL@0W1R;"]/<'1I;VX@*R!0(&;V
M<B`B"B)A='0@<VMR:79A('5T+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HR-C$*;7-G:60@(EEO=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@
M(D1I;B!A:W1U96QL82!T:61S>F]N.B(*"B,Z('-E<G9I8V5S+W!R969S+G!H
M<#HQ,3<*;7-G:60@(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C
M:&%N9V5D+B(*;7-G<W1R(")$:6X@9O9R=F%L9&$@:61E;G1I=&5T(&AA<B#D
M;F1R871S+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-C$*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>3HB"FUS9W-T<B`B1&EN(&;V<G9A;&1A
M(&ED96YT:71E=#HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C`T"FUS
M9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`B1&ET="!F=6QL<W3D;F1I
M9V$@;F%M;CHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HQ,#`P(&QI
M8B](;W)D92]!=71H+G!H<#HY.3D*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X
M<&ER960N(@IM<V=S='(@(D1I;B!I;FQO9V=N:6YG(&AA<B!GY71T('5T+B(*
M"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C<V"B,L('!H<"UF;W)M
M870*;7-G:60@(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS
M9W-T<B`B1&ET="!N>6$@;/9S96YO<F0@9O9R("5S(.1R.B`E<R(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T(&QI8B](;W)D92]0<F5F
M<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN(@IM<V=S
M='(@(D1I;F$@:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',@9O9R(&1E
M;B!HY'(@<V5S<VEO;F5N+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,34V(&QI8B](;W)D92]0<F5F<R]522YP:'`Z,34V"FUS9VED(")9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(D1I;F$@
M:6YS=.1L;&YI;F=A<B!H87(@=7!P9&%T97)A=',N(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970B"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!H87(@8FQI=FET
M(.5T97)S=.1L;'0B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HW
M.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE
M8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@(@HB<&%S
M<W=O<F0N(@IM<V=S='(@(B(*(D1I='0@;/9S;F]R9"!H87(@Y71E<G-TY&QL
M=',L(&MO;G1R;VQL97)A(&1I;B!E+7!O<W0@;V-H(&QO9V=A(&EN(&UE9"!D
M:71T("(*(FYY82!L]G-E;F]R9"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HW,S(@;&EB+TAO<F1E+T%U=&@N<&AP.C<S,PIM<V=I9"`B66]U<B!P
M87-S=V]R9"!H87,@97AP:7)E9"XB"FUS9W-T<B`B1&ET="!L]G-E;F]R9"!H
M87(@9^5T="!U="XB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-3@*;7-G:60@(EEO=7(@<F5M;W1E('-E<G9E<G,Z(@IM<V=S='(@(D1I;F$@
M9FKD<G)S97)V<F%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4T(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*(SH@;&EB+TAO
M<F1E+TY,4R]T;&0N<&AP.C(U-"!L:6(O2&]R9&4O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EEU9V]S;&%V:6$B"FUS9W-T<B`B2G5G;W-L879I96XB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].
M3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B6F%I<F4B"FUS9W-T<B`B6F%I<F4B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-38*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T."!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$X(&QI8B](;W)D92].3%,O=&QD+G!H<#HR-3<*(SH@
M;&EB+TAO<F1E+TY,4R]C;W5N=')I97,N<&AP.C(T.2!L:6(O2&]R9&4O3DQ3
M+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EII;6)A8G=E(@IM<V=S='(@(EII;6)A
M8G=E(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8V"FUS9VED(")::7!P
M>2(*;7-G<W1R(")::7!P>2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(SH@9G)A;65W;W)K+U1E
M>'0O5&5X="]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-CD*(SH@;&EB
M+TAO<F1E+U1E>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`Z,3<T"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E0FQO8VMS+FIS.C$R"FUS9VED
M(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T<B`B6T?V;2!C:71E<F%D('1E
M>'1=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#D*;7-G:60@(EM0<F]B
M;&5M(%)E<&]R=%TB"FUS9W-T<B`B6T9E;')A<'!O<G1=(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W
M(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6U9I<V$@8VET97)A9"!T97AT("TB
M"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H='%U
M;W1E<RYP:'`Z,3<R"B,Z(&9R86UE=V]R:R]497AT+U1E>'0O1FEL=&5R+VAI
M9VAL:6=H='%U;W1E<RYP:'`Z,38Y"B,Z(&QI8B](;W)D92]497AT+T9I;'1E
M<B]H:6=H;&EG:'1Q=6]T97,N<&AP.C$W-`HC+"!P:'`M9F]R;6%T"FUS9VED
M(");4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");5FES
M82!C:71E<F%D('1E>'0@+2`E<R!R861E<ETB"@HC.B!F<F%M97=O<FLO2&]R
M9&4O2&]R9&4N<&AP.C$Y,R!L:6(O2&]R9&4N<&AP.C$Y-0HC+"!P:'`M9F]R
M;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B6W)A9"`E<R!A
M=B`E<UTB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T.3<@;&EB
M+TAO<F1E+G!H<#HQ-30U"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z
M,3$*;7-G:60@(E]!9&UI;FES=')A=&EO;B(*;7-G<W1R(")?061M:6YI<W1R
M871I;VXB"@HC.B!L:6(O87!I+G!H<#HQ-3<*;7-G:60@(E]#3$DB"FUS9W-T
M<B`B7T-,22(*"B,Z(&QI8B]A<&DN<&AP.C$T,0IM<V=I9"`B7T1A=&%4<F5E
M(@IM<V=S='(@(E]$871A5'+D9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`B7U)A9&5R82!R860B"@HC.B!L:6(O87!I+G!H<#HQ,S,*
M;7-G:60@(E]'<F]U<',B"FUS9W-T<B`B7T=R=7!P97(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3<U(&QI8B](;W)D92]-96YU+G!H
M<#HQ-S4*;7-G:60@(E](96QP(@IM<V=S='(@(E](:N1L<"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM
M<V=I9"`B7TEM86=E(%!R;W!E<G1I97,N+BXB"FUS9W-T<B`B7T)I;&1I;G-T
MY&QL;FEN9V%R+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N
M<&AP.C$Y-"!L:6(O2&]R9&4O365N=2YP:'`Z,3DT"FUS9VED(")?3&]G(&EN
M(@IM<V=S='(@(E],;V=G82!I;B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ.3`@;&EB+TAO<F1E+TUE;G4N<&AP.C$Y,`IM<V=I9"`B
M7TQO9R!O=70B"FUS9W-T<B`B7TQO9V=A('5T(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(T"FUS9VED(")?
M36]D:69Y($QI;FLN+BXB"FUS9W-T<B`BQ%]N9')A(&SD;FLN+BXB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,38T(&QI8B](;W)D92]-
M96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]);G-TY&QL
M;FEN9V%R(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B7T)E:/9R:6=H971E<B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM<V=I9"`B7U)E
M;6]V92!,:6YK+BXN(@IM<V=S='(@(E]482!B;W)T(&SD;FLN+BXB"@HC.B!L
M:6(O87!I+G!H<#HQ,C4*;7-G:60@(E]3971U<"(*;7-G<W1R(")?4V5T=7`B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S,*;7-G:60@(E]486)L92!0<F]P97)T:65S+BXN(@IM<V=S='(@
M(E]486)E;&QI;G-TY&QL;FEN9V%R+BXN(@H*(SH@;&EB+V%P:2YP:'`Z,3(Y
M"FUS9VED(")?57-E<G,B"FUS9W-T<B`B7T%N=N1N9&%R92(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q(&QI8B](;W)D92]+;VQA8BYP:'`Z
M.3(U"FUS9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`B861R97-S8F]K(@H*
M(SH@;&EB+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3,T"FUS9VED(")A9&1R
M97-S964@=6YK;F]W;B(*;7-G<W1R(")O:^1N9"!M;W1T86=A<F4B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDQ,R!L:6(O2&]R9&4O2V]L86(N
M<&AP.CDQ-PIM<V=I9"`B8V%L96YD87(B"FUS9W-T<B`B:V%L96YD97(B"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C$W.2!L:6(O0FQO8VLO;65T87(N<&AP
M.C,V-0IM<V=I9"`B8V%L;2(*;7-G<W1R(")L=6=N="(*"B,Z(&QI8B](;W)D
M92]-24U%+TUE<W-A9V4N<&AP.C$U.`IM<V=I9"`B8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL92(*;7-G<W1R(")K86X@:6YT92!S:V%P82!U=&9I;"(*"B,Z
M(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$S,`IM<V=I9"`B8V%N;F]T
M(&]P96X@:6YP=70B"FUS9W-T<B`B:V%N(&EN=&4@]G!P;F$@:6YD871A(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-3DQ(&QI8B](
M;W)D92]-24U%+T-O;G1E;G1S+G!H<#HU.3D*;7-G:60@(F-L:6-K(&AE<F4B
M"FUS9W-T<B`B:VQI8VMA(&CD<B(*"B,Z(&QI8B]";&]C:R]B87)T:6UE+G!H
M<#HU-@IM<V=I9"`B8VQO8VLB"FUS9W-T<B`B:VQO8VMA(@H*(SH@;&EB+TAO
M<F1E+TU)344O365S<V%G92YP:'`Z,3(R"FUS9VED(")C;VUM86YD(&QI;F4@
M=7-A9V4@97)R;W(B"FUS9W-T<B`B:V]M;6%N9&]R861S9F5L(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,3<X"FUS9VED(")C;VYF:6=U<F%T
M:6]N(&5R<F]R(@IM<V=S='(@(FMO;F9I9W5R871I;VYS9F5L(@H*(SH@;&EB
M+TAO<F1E+TU)344O365S<V%G92YP:'`Z,34T"FUS9VED(")C<FET:6-A;"!S
M>7-T96T@9FEL92!M:7-S:6YG(@IM<V=S='(@(FMR:71I<VL@<WES=&5M9FEL
M('-A:VYA<R(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$R-@IM
M<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B9&%T869O<FUA=&9E
M;"(*"B,Z('1E;7!L871E<R]P;W)T86PO961I="YI;F,Z,S`*;7-G:60@(F5D
M:70B"FUS9W-T<B`BY&YD<F$B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ.#(*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")P;W-T
M96X@:W5N9&4@:6YT92!H:71T87,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B9F%L;&EN9R(*;7-G<W1R(")F
M86QL86YD92(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U
M,"!L:6(O2&]R9&4O0G)O=W-E<BYP:'`Z.#DX"FUS9VED(")F:6QE(@IM<V=S
M='(@(F9I;"(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3@Q(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8W(&QI8B]";&]C:R]M971A<BYP:'`Z,SDS"B,L('!H
M<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS
M9W-T<B`B9G+E;B!D96X@)7,@*"5S*2!K;"`E<R`E<R(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HR,SD*;7-G:60@(F=U<W1I;F<B"FUS9W-T
M<B`B<W1O<FUB>6%R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S,@HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,C4P"FUS9VED(")H.B(*;7-G<W1R(")H.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS,S0*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,U.0IM<V=I9"`B:&@B"FUS9W-T
M<B`B:&@B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ,S@*;7-G
M:60@(FAO<W0@;F%M92!U;FMN;W=N(@IM<V=S='(@(F]KY&YD(';D<F1D871O
M<B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-38U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R,PHC.B!L:6(O3F5T+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z
M-38U(&QI8B].970O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED
M(")I;6UE9&EA=&4B"FUS9W-T<B`B9V5N87-T(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z-C<@861M:6XO<V5T=7`O9&EF9BYP:'`Z-SD*;7-G:60@(FEN
M;&EN92(*;7-G<W1R(")I;FQI;F4B"@HC.B!L:6(O2&]R9&4O34E-12]-97-S
M86=E+G!H<#HQ-C(*;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R
M(")B96%R8F5T;FEN9W-F96PB"@HC.B!L:6(O2&]R9&4O34E-12]-97-S86=E
M+G!H<#HQ-#8*;7-G:60@(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(@IM<V=S
M='(@(DEN=&5R;G0@87!P;&EK871I;VYS9F5L(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")R861E<ETB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O;6MI<V]F<RYP:'`Z-3,*(SH@9G)A;65W;W)K+U9&4U])4T\O25-/
M5W)I=&5R+VUK:7-O9G,N<&AP.C4T(&QI8B]61E,O25-/5W)I=&5R+VUK:7-O
M9G,N<&AP.C4S"B,L('!H<"UF;W)M870*;7-G:60@(FUK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+B(*;7-G<W1R(")F96QK;V0@)60@
M9G+E;B!M:VES;V9S(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,T-0HC.B!L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S<P"FUS9VED(")M;2(*;7-G<W1R(")M;2(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,CDP(&QI8B](;W)D92]0<F5F<R]522YP
M:'`Z,C@U"B,Z('-E<G9I8V5S+W!O<G1A;"]M96YU+G!H<#HR,3(@<V5R=FEC
M97,O<&]R=&%L+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO
M<VED96)A<BYP:'`Z,C0Q"FUS9VED(")N86UE(@IM<V=S='(@(FYA;6XB"@HC
M.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q(&QI8B](;W)D92]24$,N<&AP
M.C$R-`IM<V=I9"`B;F]T(&EM<&QE;65N=&5D(@IM<V=S='(@(FEN=&4@:6UP
M;&5M96YT97)A9"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z,3(Q.2!L:6(O2&]R9&4O0W)Y<'0O<VUI;64N<&AP.C$R,C`*;7-G:60@
M(FYO="!Y970@:6UP;&5M96YT960B"FUS9W-T<B`B:6YT92!I;7!L96UE;G1E
M<F%D(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,#4@;&EB+TAO
M<F1E+TMO;&%B+G!H<#HY,#D*;7-G:60@(FYO=&5P860B"FUS9W-T<B`B86YT
M96-K;FEN9W-B;&]C:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z.#@*;7-G:60@(G!E<F-E;G0B"FUS9W-T<B`B
M<')O8V5N="(*"B,Z(&QI8B](;W)D92]-24U%+TUE<W-A9V4N<&AP.C$W-`IM
M<V=I9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`BY71K;VUS="!N96MA
M9"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#D*;7-G:60@(G!I>&5L<R(*;7-G<W1R(")P:7AL87(B"@HC.B!L
M:6(O2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-S`*;7-G:60@(G)E;6]T92!E
M<G)O<B!I;B!P<F]T;V-O;"(*;7-G<W1R(")P<F]T;VMO;&QF96PB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW-`IM<V=I9"`B
M<FES:6YG(@IM<V=S='(@(G-T:6=A;F1E(@H*(SH@;&EB+TAO<F1E+TU)344O
M365S<V%G92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM
M<V=S='(@(E1JY&YS=&5N(.1R(&5J('1I;&QGY&YG;&EG(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HQ,#$*;7-G:60@(G-H;W<@9&EF9F5R96YC97,B
M"FUS9W-T<B`B=FES82!S:VEL;&YA9&5R(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,30*(SH@;&EB+TYE="]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I9"`B<VUS,F5M86EL('9I82!(
M5%10(@IM<V=S='(@(G-M<S)E;6%I;"!V:6$@2%144"(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-C$*(SH@;&EB+TAO<F1E
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,X-PIM<V=I9"`B<W,B"FUS9W-T
M<B`B<W,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HW,PIM<V=I9"`B<W1E861Y(@IM<V=S='(@(G-T861I9W0B"@HC.B!L:6(O
M2&]R9&4O34E-12]-97-S86=E+G!H<#HQ-3`*;7-G:60@(G-Y<W1E;2!E<G)O
M<B(*;7-G<W1R(")S>7-T96UF96PB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L
M86(N<&AP.CDR.2!L:6(O2&]R9&4O2V]L86(N<&AP.CDS,PIM<V=I9"`B=&%S
M:R!L:7-T(@IM<V=S='(@(G5P<&=I9G1S;&ES=&$B"@HC.B!L:6(O2&]R9&4O
M34E-12]-97-S86=E+G!H<#HQ-C8*;7-G:60@(G1E;7!O<F%R>2!F86EL=7)E
M(@IM<V=S='(@(G1I;&QFY&QL:6=T(&9E;"(*"B,Z(&%D;6EN+W5S97(N<&AP
M.C,V(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*(SH@;&EB
M+TAO<F1E+T%U=&@O4VEG;G5P+G!H<#HR-S`*;7-G:60@(G1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`B86YG92!L]G-E;F]R
M9&5T('1VY2!GY6YG97(@9O9R(&%T="!B96MRY&9T82(*"B,Z(&%D;6EN+W-E
M='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<Y"FUS9VED
M(")U;FEF:65D(@IM<V=S='(@(F5N860B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U!A<G0N<&AP.C(W(&QI8B](;W)D92]-24U%+U!A<G0N<&AP.C(W"FUS
M9VED(")U;FYA;65D(@IM<V=S='(@(FYA;6YL]G,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*(SH@;&EB
M+TYE="]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-2!L:6(O3F5T+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,PIM<V=I9"`B=7-E<B!S96QE8W0B"FUS
M9W-T<B`B86YVY&YD87)V86PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]V8V%R9"YP:'`Z,S4@;&EB+TAO<F1E+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HS-0IM<V=I9"`B=D-A<F0B"FUS9W-T<B`B=D-A<F0B"@HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(T"B,Z(&QI8B](
M;W)D92]522]687)296YD97)E<B]H=&UL+G!H<#HR-#(*;7-G:60@(G<Z(@IM
M<V=S='(@(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*
M;7-G:60@(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&\O=')?5%(N<&\`````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-S(P,C<T(#$P
M-3$U-#,T,30R(#`Q-S4U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````C(%1U<FMI<V@@=')A;G-L871I;VYS(&9O<B!(;W)D
M92!P86-K86=E"B,@2&]R9&4@<&%K971I(&GG:6X@5/QR:^=E(,=E=FER:6QE
M<BX*(R!#;W!Y<FEG:'0@*$,I(#(P,#4@2&]R9&4@4')O:F5C=`HC(%1H:7,@
M9FEL92!I<R!D:7-T<FEB=71E9"!U;F1E<B!T:&4@<V%M92!L:6-E;G-E(&%S
M('1H92!(;W)D92!P86-K86=E+@HC($=E;F5R871E9"!B>0HC(%-E<G9E="!'
M_&YE>2`\<V=U;F5Y0&UE='4N961U+G1R/@HC($%H;65T(-9Z=/QR:R`\;V%H
M;65T0&UE='4N961U+G1R/@HC"FUS9VED("(B"FUS9W-T<B`B(@HB4')O:F5C
M="U)9"U697)S:6]N.B!(;W)D978S+C`N-%QN(@HB4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F=<;B(*(E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#!<;B(*(E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#4M,#8M,C@@,30Z-#@K,#,P,%QN(@HB3&%S="U4<F%N<VQA=&]R
M.B!!=71O;6%T:6-A;&QY(&=E;F5R871E9%QN(@HB3&%N9W5A9V4M5&5A;3H@
M:3$X;D!L:7-T<RYH;W)D92YO<F=<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB
M"B)#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM
M.5QN(@HB0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=%QN(@HB4&QU
M<F%L+49O<FUS.B!N<&QU<F%L<STQ.R!P;'5R86P],#M<;B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B("@E<R!G_&X@]FYC92DB"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S-S`*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(BA%<FG^:6T@06YA:'1A
M<OT@)7,I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W-PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H)7,@
M9_QN9&4I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,W,PIM<V=I
M9"`B("AT;V1A>2DB"FUS9W-T<B`B("AB=6?\;BDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<U"FUS9VED("(@*'1O;6]R<F]W*2(*;7-G<W1R
M("(@*'EA<OUN*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S$*
M;7-G:60@(B`H>65S=&5R9&%Y*2(*;7-G<W1R("(@*&3\;BDB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C4V(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HS-C$*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C0P-PIM<V=I9"`B(&%T("(*;7-G<W1R("(@9&4H9&$I("(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(*;7-G<W1R(")$
M:7II;B!D9?!I;"(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-S(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N;W0@82!V86QI
M9"!C:&]I8V4N(@IM<V=S='(@(B<E<R<@:7,@9V7G97)L:2!B:7(@<V7G96YE
M:R!D9?!I;"XB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN
M<&AP.C8U.0HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$P-#(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN(@IM<V=S='(@
M(B<E<R<@2&]R9&4@2V%Y_71L87+];F1A('EA</UL86YD_7+];&UA;?W^+B(*
M"B,Z(&9R86UE=V]R:R]4<F5E+U1R964N<&AP.C$W,0HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+B(*;7-G<W1R("(G)7,G(&'P8><@YV5V:7)I8VES:2!B=6QU;F%M863]+B(*
M"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-38*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN
M(@IM<V=S='(@(B<E<R<@9W)U<"!S:7-T96UI;F4@96ML96YD:2XB"@HC.B!A
M9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(EPB)7-<(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2XB"FUS9W-T<B`B)R5S)R!I>FEN('-I<W1E;6EN92!E:VQE;F1I
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-30@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB"FUS9W-T<B`B)R5S)WEA<F%T_6QA;6%D
M_3H@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S`*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N
M,F8E)2DB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(S-PHC+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A;F0@)7,B"FUS
M9W-T<B`B)60@)7,@=F4@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD
M87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-34W"B,L('!H<"UF
M;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I
M<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@(B5D+61A>2!F;W)E8V%S="(*
M;7-G<W1R("(E9"UG_&YL_&L@:&%V82!T86AM:6YI(@H*(SH@<V5R=FEC97,O
M;6%I;G1E;F%N8V4N<&AP.C8X"B,L('!H<"UF;W)M870*;7-G:60@(B5S("T@
M3F]T:6-E(@IM<V=S='(@(B5S("T@0FEL9&ER:6TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!&:6YG97)P<FEN="(*;7-G<W1R("(E<R!087)M86L@W7II(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#,S(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@S-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(E<R!+0B(*;7-G<W1R("(E<R!+0B(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N(@IM<V=S='(@(B5S($)A
M:_UM(-W^;&5M;&5R:2`M($]N87EL86UA(@H*(SH@861M:6XO<V5T=7`O8V]N
M9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,C$U"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@(B5S($%Y87)L87(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,C8S"B,L('!H<"UF
M;W)M870*;7-G:60@(B5S(%-I9VX@57`B"FUS9W-T<B`B)7,@1VER:?XB"@HC
M.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B5S($%N;&'^
M;6$@2V_^=6QL87+](@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT
M,C@@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HT.3`*(SH@9G)A;65W;W)K
M+U9&4R]61E,O9G1P+G!H<#HV-3$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(B5S('IA=&5N('9A<BXB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$U.2!L:6(O0FQO8VLO;65T87(N<&AP.C$V-2!L:6(O0FQO8VLO;65T
M87(N<&AP.C(S.0HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,T-2!L:6(O0FQO
M8VLO;65T87(N<&AP.C,U,0HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E
M<R`E<R(*;7-G<W1R("(E<R!D92`E<R`E<R(*"B,Z('-E<G9I8V5S+VUA:6YT
M96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B(@HB
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A;GD@
M;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE
M+B(*;7-G<W1R("(B"B)'97+G:V7^=&ER:6QM97-I;FD@:7-T961I\&EN:7H@
M:?YL96UL97(@:>=I;B!O;F%Y(&MU='5L87+];OT@:?YA<F5T;&5Y:6XN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,T,`HC+"!P:'`M9F]R;6%T
M"FUS9VED("(E<R!I<R!R97%U:7)E9"(*;7-G<W1R("(E<R!I<W1E;FUE:W1E
M9&ER+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C@V"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&UI;G5T97,B"FUS9W-T<B`B)7,@9&%K:6MA(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!P
M:'`M9F]R;6%T"FUS9VED("(E<R!N;W0@9F]U;F0N(@IM<V=S='(@(B5S(&)U
M;'5N86UA9/TN(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!T;R`E<R!O9B`E<R(*;7-G<W1R
M("(E<R`M("5S("\@)7,@(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HY,C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!!9&1R97-S($)O;VLB
M"FUS9W-T<B`B)7,@061R97,@1&5F=&5R:2(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.3$T"B,L('!H<"UF;W)M870*;7-G:60@(B5S)W,@0V%L
M96YD87(B"FUS9W-T<B`B)7,@5&%K=FEM(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E
M<&%D(@IM<V=S='(@(B5S($YO="!$969T97)I(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HY,S`*(RP@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!4
M87-K;&ES="(*;7-G<W1R("(E<R!']G)E=B!,:7-T97-I(@H*(SH@9G)A;65W
M;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE
M+G!H<#HY-@HC+"!P:'`M9F]R;6%T"FUS9VED("(E<SH@)7,B"FUS9W-T<B`B
M)7,Z("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:'1M;"YP
M:'`Z,C<R"B,L('!H<"UF;W)M870*;7-G:60@(B(*(B5S.B!4:&ES(&UE<W-A
M9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A
M<F4@;V8@9F]L;&]W:6YG("(*(F%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C,V-2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#$P"B,L(&9U>GIY
M"FUS9VED("(L(&=U<W1I;F<@(@IM<V=S='(@(BP@9OUR=/UN86S]("5S("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T:6YG("5S("5S
M(@IM<V=S='(@(BP@9OUR=/UN86S]("5S("5S(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,#$*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!V87)I86)L92!F
M<F]M("5S('1O("5S(@IM<V=S='(@(BP@9&7P:?YI;2`E<R`M/B`E<R(*"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,CDT(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,S0X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P-CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$R.`HC.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-S0Y"FUS9VED("(M
M+2!S96QE8W0@+2TB"FUS9W-T<B`B+2T@4V7G("TM(@H*(SH@;&EB+T)L;V-K
M+W1I;64N<&AP.C(P"FUS9VED("(Q,B!(;W5R($9O<FUA="(*;7-G<W1R("(Q
M,B!386%T;&EK(%IA;6%N($)IYVEM:2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HQ.0IM<V=I9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`B,C0@4V%A=&QI
M:R!:86UA;B!":>=I;6DB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.`IM<V=I9"`B,C0@:&]U<G,B"FUS9W-T<B`B,C0@<V%A="(*"B,Z(&9R86UE
M=V]R:R]522]522]086=E<BYP:'`Z-CD*(RP@9G5Z>GD*;7-G:60@(CQ0<F5V
M:6]U<R(*;7-G<W1R("+6;F-E:VD@4V%Y9F$B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C$Q.0IM<V=I9"`B02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+B(*;7-G<W1R(")"=2#V8F5K(&GG:6X@=F5R
M:71A8F%N_2!S;VX@=7IA;G3]<_T@9V5R96MM96MT961I<BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V,`IM<V=I9"`B02!F871A;"!E<G)O
M<B!H87,@;V-C=7)R960B"FUS9W-T<B`B3VYU;&UA>B!B:7(@:&%T82!O;'7^
M='4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY,S4*;7-G
M:60@(D$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N(@IM<V=S='(@(MUL971I>6D@_FEF<F5L97EE8FEL;65K(&GG
M:6X@4$=0(&'G_6L@86YA:'1A<OT@9V5R96MM96MT961I<BXB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!('!U8FQI
M8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S
M86=E+B(*;7-G<W1R("(B"B+=;7IA;&%N;?W^(&EL971I>6D@9&_P<G5L=?!U
M;G4@<V'P;&%M86L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E
M9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P.3<*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82`B"B)M
M97-S86=E+B(*;7-G<W1R("(B"B+=;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K
M(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@
M9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M(MUL971I>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!01U`@86YA:'1A<OTL]GIE
M;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K
M=&5D:7(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M,#4*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O("(*(F1E
M8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"B+=;&5T:6YI;B#^:69R97-I
M;FD@Y_9Z;65K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@4R]-
M24U%(&%N86AT87+]('9E("(*(F=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E
M9&ER+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#,Q
M"FUS9VED("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N("(*
M(F$@;65S<V%G92XB"FUS9W-T<B`B(@HBW6QE=&EY:2!I;7IA;&%M86L@:>=I
M;B!AY_UK(%,O34E-12!A;F%H=&%R_2P@]GIE;"!3+TU)344@86YA:'1A<OT@
M=F4@9V7G:?X@(@HB=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS-C0*;7-G:60@(D$@<'5B
M;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G
M92XB"FUS9W-T<B`BW6QE=&EY:2#^:69R96QE>65B:6QM96L@:>=I;B!AY_UK
M(%--24U%(&%N86AT87+](&=E<F5K;65K=&5D:7(N(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z.0HC+"!F=7IZ>0IM<V=I9"`B
M04T@0VQO=61S(@IM<V=S='(@(D)U;'5T;&%R(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3`*(RP@9G5Z>GD*;7-G:60@(D%-
M($QI9VAT(%)A:6XB"FUS9W-T<B`BUE,@2&%F:68@66'P;75R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3$*;7-G:60@(D%-
M(%)A:6XB"FUS9W-T<B`BUM8@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*;7-G:60@(D%-(%-H;W=E<G,B"FUS
M9W-T<B`BUM8@4V'P;F%K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?
M<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO=V5R<R(*;7-G<W1R
M("+6UB!(869I9B!+87(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`BUM8OUE,B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,#`*;7-G:60@(D%0
M22!)1"(*;7-G<W1R(")!4$D@240B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,P"FUS9VED(")!8F]U="!T:&ES(&5D:71O
M<B(*;7-G<W1R(")$_'IE;FQE>6EC:2!H86MK_6YD82(*"B,Z('-E<G9I8V5S
M+VAE;'`O:6YD97@N<&AP.C4R"FUS9VED(")!8F]U="XN+B(*;7-G<W1R(")(
M86MK_6YD82XN+BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<T"FUS9VED(")!8G-B;W1T;VTB"FUS9W-T<B`B16YA;'0B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R
M"FUS9VED(")!8G-M:61D;&4B"FUS9W-T<B`B3W)T87EA(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O;75S<6PN<&AP.C(W,`IM<V=I9"`B06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")61E,@9&EZ:6YI
M('EA<F%T_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O;75S<6PN<&AP.C$S-@IM<V=I9"`B06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9FEL92XB"FUS9W-T<B`B5D93(&1I>FEN:2!Y87)A=/UL
M_7)K96X@97)I_FEM(&5N9V5L;&5N9&DN(@H*(SH@;&EB+T)L;V-K+V%C8V]U
M;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M871I;VXB
M"FUS9W-T<B`B0FEL9VEL97)I;FEZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C<U"FUS9VED(")!8V-O=6YT(%!A<W-W;W)D(@IM<V=S='(@(DAE<V%P
M(%!A<F%L;W/](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,CDS"FUS9VED(")!8V-O=6YT(&9R;WIE;BXB"FUS9W-T
M<B`B2&5S87`@1&]N9'5R=6QD=2XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S,S"FUS9VED(")!8V-O=6YT:6YG(@IM<V=S='(@(DAE<V%P;&%N
M_7EO<B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30X('1E
M;7!L871E<R]P;W)T86PO861D+FEN8SHQ-`HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V%D9&-H:6QD+FEN8SHQ,0IM<V=I9"`B061D(@IM<V=S='(@(D5K
M;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C(R-"!A9&UI;B]G<F]U<',N<&AP
M.C(R-0IM<V=I9"`B061D($-H:6QD($=R;W5P(@IM<V=S='(@(D%L="!'<G5P
M($5+;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.3D*;7-G:60@(D%D9"!#:&EL
M9"!097)M:7-S:6]N(@IM<V=S='(@(D%L="#=>FEN($5+;&4B"@HC.B!T96UP
M;&%T97,O<&]R=&%L+V%D9"YI;F,Z-0IM<V=I9"`B061D($AE<F4Z(@IM<V=S
M='(@(D)U<F%Y82!%:VQE.B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,C$X(&%D
M;6EN+V=R;W5P<RYP:'`Z,C$Y"FUS9VED(")!9&0@3F5W($=R;W5P(@IM<V=S
M='(@(EEE;FD@1W)U<"!%:VQE(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HX-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C@X"FUS
M9VED(")!9&0@3F5W(%!E<FUI<W-I;VXB"FUS9W-T<B`B665N:2#=>FEN($5K
M;&4B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U
M<"!T;R!<(B5S7"(B"FUS9W-T<B`B06QT(&=R=6)U("<E<R<@:>=I;F4@96ML
M92(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O(%PB)7-<(B(*;7-G<W1R("(G)7,G(/QZ97)I;F1E(&%L="!I>FEN(&5K
M;&4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,`IM<V=I9"`B061D(&$@;F5W('5S
M97(Z(@IM<V=S='(@(EEE;FD@:W5L;&%N_6/](&5K;&4Z(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-`IM<V=I9"`B061D
M(&-O;'5M;B(*;7-G<W1R(")+;VQO;B!%:VQE(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+V=R;W5P<R]E9&ET+FEN8SHS-`IM<V=I9"`B061D(&YE=R!M96UB97)S
M(@IM<V=S='(@(EEE;FD@_'EE(&5K;&4B"@HC.B!T96UP;&%T97,O9&%T82]C
M<W9M87`N:6YC.CDU"FUS9VED(")!9&0@<&%I<B(*;7-G<W1R("+=:VEL:2!%
M:VQE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(B"FUS9W-T<B`B)7,@365N_'/\;OP@36]Z:6QL82!+96YA<B#'=6)U\'4@
M3VQA<F%K($5K;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z-S$*;7-G:60@(D%D9"!T;R!A9&1R97-S(&)O;VLZ(@IM<V=S
M='(@(D%D<F5S(&1E9G1E<FEN92!E:VQE.B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HW.`IM<V=I9"`B061D('1O(&UY(&%D
M9')E<W,@8F]O:R(*;7-G<W1R(")!9')E<R!D969T97)I;64@96ML92(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C,Q"FUS9VED(")!9&0@=7-E<B(*;7-G<W1R(")+
M=6QL86[]8_T@16ML92(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@=&\@=&AE('-Y
M<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF
M;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(G)7,G('-I<W1E;64@96ML96YD
M:2P@86UA(&AE<FAA;F=I(&5K(&)I<B!G:7)I_B!B:6QG:7-I(&5K;&5N96UE
M9&DZ("5S(@H*(SH@<VEG;G5P+G!H<#HT-0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B061D960@7"(E<UPB('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RXB"FUS9W-T<B`B)R5S)R!S:7-T96UE(&5K;&5N9&DN(-YI
M;61I(&=I<FG^('EA<&%B:6QI<G-I;FEZ+B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!9&1I;F<@=7-E<G,@:7,@9&ES
M86)L960N(@IM<V=S='(@(DMU;&QA;OUC_2!E:VQE;64@<V7G:6QE;65Z(&O]
M;/UN9/TN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP
M:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@(D%D
M9')E<W,B"FUS9W-T<B`B061R97,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,3,Y"FUS9VED(")!9&1R97-S($)O;VLB"FUS9W-T<B`B061R97,@
M1&5F=&5R:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.CDT"FUS9VED(")!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<R(*;7-G<W1R(")9]FYE=&EM+2U$:?!E<B!K=6QL86[]
M;&%R(&GG:6X@:7II;FQE<FD@8F5L:7)L97EI;B(*"B,Z(&%D;6EN+VEN9&5X
M+G!H<#HQ.2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3$S"FUS9VED
M(")!9&UI;FES=')A=&EO;B(*;7-G<W1R(")9]FYE=&EM(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C,T,0IM<V=I9"`B061S(@IM<V=S='(@(D%D
M<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-38*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S='(@(D%F
M9V%N:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;&)A;FEA(@IM<V=S='(@
M(D%R;F%V=71L=6LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"FUS9VED(")!;&=E<FEA(@IM<V=S
M='(@(D-E>F%Y:7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V
M8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA<R(*;7-G<W1R("+6=&5K:2!A9"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z,38*;7-G:60@(D%L:6=N(@IM<V=S='(@(DAI>F%L82(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-C<*;7-G:60@(D%L
M:6=N;65N=#HB"FUS9W-T<B`B2&EZ86QA;6%K.B(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HX-PIM<V=I9"`B06QL(@IM<V=S='(@(E3\;?PB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-R!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8U"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R
M<R(*;7-G<W1R(")4_&T@1&_P<G5L86YM_?X@2W5L;&%N_6/];&%R(@H*(SH@
M861M:6XO9W)O=7!S+G!H<#HS,R!A9&UI;B]G<F]U<',N<&AP.C(R,@IM<V=I
M9"`B06QL($=R;W5P<R(*;7-G<W1R(")4_&T@1W)U<&QA<B(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.3$@9G)A;65W;W)K+U!E<FUS+U!E
M<FUS+V1A=&%T<F5E+G!H<#HW-0IM<V=I9"`B06QL(%!E<FUI<W-I;VYS(@IM
M<V=S='(@(E3\;2#=>FEN;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-PIM<V=I9"`B06QL(&9O=7(@<VED
M97,B"FUS9W-T<B`B5/QM(&3V<G0@>?QZ(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3@W,0IM<V=I9"`B06QL;W<@;75L=&EP;&4@861D<F5S<V5S
M(@IM<V=S='(@(L=O:VQU(&%D<F5S;&5R92!I>FEN('9E<B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HU,S0*;7-G:60@(D%L;&]W('-E='1I;F<@;V8@
M;W)D97)E9"!L:7-T('1Y<&4_(@IM<V=S='(@(E/]<F%L86YM_?X@;&ES=&4@
M=/QR_&[\(&%Y87)L86UA>6$@:7II;B!V97)I;'-I;B!M:3\B"@HC.B!F<F%M
M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HU,#0*;7-G:60@(D%L
M<F5A9'D@97AI<W1S(@IM<V=S='(@(EIA=&5N('9A<B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN
M(@IM<V=S='(@(M9T96MI($E-4U`@1VER:?YI(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4P-PIM<V=I9"`B06QT97)N871E($E-4U`@4&%S<W=O<F0B
M"FUS9W-T<B`BUG1E:VD@24U34"!087)O;&%S_2(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE
M(@IM<V=S='(@(M9T96MI($E-4U`@2W5L;&%N_6/]($%D_2(*"B,Z('-E<G9I
M8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"FUS9VED(")!;'1E<FYA=&4@96UA
M:6P@861D<F5S<R(*;7-G<W1R("+6=&5K:2!E;&5K=')O;FEK('!O<W1A(&%D
M<F5S:2(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,30R"FUS9VED(")!;'1E
M<FYA=&4@=&5M<&QA=&5S(@IM<V=S='(@(M9T96MI('1A<VQA:VQA<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHR-0IM<V=I9"`B06QT97)N871E('1E>'0Z(@IM<V=S='(@(M9T96MI
M(&UE=&EN.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A;6]A(@IM
M<V=S='(@(D%M97)I:V%N(%-A;6]A(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HY-2!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$Q
M-0IM<V=I9"`B06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+B(*;7-G
M<W1R(")'9>=E<G-I>B!D9?!E<B!B96QI<G1I;&1I+B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*(RP@9G5Z>GD*;7-G:60@(D%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N(@IM<V=S='(@(F)I<B!H871A(&]L
M=?YT=3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C4U"FUS9VED(")!;F1O<G)A(@IM<V=S='(@(D%N
M9&]R82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%N9V]L82(*;7-G<W1R(")!;F=O
M;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C4W"FUS9VED(")!;F=U:6QL82(*;7-G<W1R(")!;F=U
M:6QL82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G
M:60@(D%N;VYY;6]U<R!0<F]X>2(*;7-G<W1R(")!;F]N:6T@4')O>'DB"@HC
M.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R
M(@IM<V=S='(@(D-E=F%P(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC
M82(*;7-G<W1R(")!;G1A<G1I:V$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")!;G1I
M9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(D%N=&EG=6$@=F4@0F%R8G5D82(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP
M.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@IM<V=I9"`B07!P;&EC871I
M;VXB"FUS9W-T<B`B57EG=6QA;6$B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#(*;7-G:60@(D%P<&QI8V%T:6]N($QI<W0B"FUS9W-T<B`B57EG=6QA
M;6$@3&ES=&5S:2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-#`*;7-G
M:60@(D%P<&QI8V%T:6]N(&ES(')E861Y+B(*;7-G<W1R(")5>6=U;&%M82!(
M87K]<B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,C$X"FUS9VED
M(")!<'!L>2!T;R!#:&EL9"!3:&%R97,B"FUS9W-T<B`B06QT('!A>6QA_OUM
M;&%R82!U>6=U;&$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHR,0IM<V=I9"`B07!P<F]V92(*;7-G<W1R(")/;F%Y;&$B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX,S,*;7-G:60@(D%P
M<')O>&EM871E(%-I>F4B"FUS9W-T<B`B66%K;&'^_6L@0F]Y=70B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I9"`B
M07!R:6PB"FUS9W-T<B`B3FES86XB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$W-0IM<V=I9"`B07)A8FEC("A7:6YD;W=S+3$R-38I(@IM<V=S='(@(D%R
M87#G82`H5VEN9&]W<RTQ,C4V*2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-3D@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R(")"96QG
M96QI:R!$;W-Y82!"=7EU='4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]R87(N<&AP.C4X(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII
M<"YP:'`Z-C4*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H
M<#HX,`IM<V=I9"`B07)C:&EV92!.86UE(@IM<V=S='(@(D)E;&=E;&EK($%D
M_2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z
M,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W86YT
M('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\B"FUS9W-T
M<B`B)7,@:>=I;B!G:7)I_B!I<W1E\&EN:2!K86QD_7)M86L@:7-T961I\&EN
M>F4@96UI;B!M:7-I;FEZ/R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M9&5L971E+FEN8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!<F4@
M>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E(%PB)7-<(B!A;F0@86YY('-U
M8BUG<F]U<',_(@IM<V=S='(@(B<E<R<@=F4@=/QM(&%L="!G<G5P;&%R_6[]
M('-I;&UE:R!I<W1I>6]R(&UU<W5N=7H_(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.`IM<V=I9"`B
M07)G96YT:6YA(@IM<V=S='(@(D%R:F%N=&EN(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HR,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-PIM<V=I
M9"`B07)M96YI82(*;7-G<W1R(")%<FUE;FES=&%N(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!4DU30TE)+3@I(@IM
M<V=S='(@(D5R;65N:6-E("A!4DU30TE)+3@I(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C(X"FUS9VED(")!<G0B"FUS9W-T<B`B4V%N870B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4Y"FUS9VED(")!<G5B82(*;7-G<W1R(")!<G5B82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA
M;F0B"FUS9W-T<B`B07-C96YS:6]N($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,CD*;7-G:60@(D%S8VEI($%R="(*;7-G<W1R(")!<V-I
M:2!386YA=/TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-34*
M;7-G:60@(D%S:6$O4&%C:69I8R!296=I;VXB"FUS9W-T<B`B07-Y82]087-I
M9FEK($+V;&=E<VDB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#(U"FUS
M9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`B0F%K_6T@:?YL96UL97)I;F1E
M;B#V;F-E(&1O\')U;&%M82!S;W)U;'-U;B!M=3\B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3$S"FUS9VED(")!<W-I9VYM96YT(&-O;'5M;G,B
M"FUS9W-T<B`B071A;6$@2V]L;VYL87+](@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N(@IM<V=S='(@(E9A<B!O;&UA>6%N(&)I<B!G<G5B=2!S:6QM92!G
M:7)I_FEM:2XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C(Y"FUS9VED
M(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")687(@;VQM87EA;B!B:7(@:7IN:2!S:6QM92!G:7)I_FEM
M:2XB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HX-PIM<V=I9"`B071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN(@IM<V=S='(@
M(E9A<B!O;&UA>6%N(&)I<B!G<G5B=2!D_'IE;FQE;64@9VER:?YI;6DN(@H*
M(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C4S"FUS9VED(")!='1E;7!T
M('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N(@IM<V=S='(@(E9A<B!O
M;&UA>6%N(&)I<B!P87EL8?[];?T@9/QZ96YL96UE(&=I<FG^:6UI+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C0@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S
M(@IM<V=S='(@(M9Z;FET96QI:VQE<B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`B
M0?!U<W1O<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,CD@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R86QI82(*;7-G<W1R
M(")!=G5S='5R86QY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%U<W1R:6$B"FUS
M9W-T<B`B079U<W1U<GEA(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S
M<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)S<6PZ(-US
M=&5N96X@:6UA<"!U>F%T873]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ,S4*;7-G:60@(D%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RXB
M"FUS9W-T<B`B075T:%]C>7)U<SH@W7-T96YE;B!Y971E;F5K;&5R92!S86AI
M<"!D9?!I;"XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ
M,C(*;7-G:60@(D%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]C>7)U<SH@W7-T96YE;B!I;6%P
M('5Z86YT_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]F='`N<&AP.C,V"FUS9VED("(B"B)!=71H7V9T<#H@4F5Q=6ER960@1E10
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM
M96YA8FQE+2(*(F9T<"!S=VET8V@N(@IM<V=S='(@(B(*(D%U=&A?9G1P.B#=
M<W1E;F5N($944"!U>F%N=/US_2!B=6QU;F%M863]+B!02%`G>6D@+2UE;F%B
M;&4M9G1P('-W:71C:"`B"B)D9?!I_G1I<F=E<VEY;&4@9&5R;&5Y:6XN(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM
M<V=S='(@(D%U=&A?:6UA<#H@W7-T96YE;B!)34%0('5Z86YT_7/](&)U;'5N
M86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HU,0IM
M<V=I9"`B075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(D%U=&A?:W)B-3H@W7-T96YE;B!K<F(U('5Z86YT
M_7/](&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P
M+G!H<#HS,#(*;7-G:60@(D%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO
M="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HS-3<*;7-G:60@(D%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VQD87`N<&AP.C8S"FUS9VED(")!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B075T:%]L9&%P
M.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?:6UA<#H@
M)7,@:W5L;&%N_6/]<_T@96ML96YE;65D:2X@4W5N=6-U.B`B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,X-0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(*;7-G
M<W1R(")!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]('-I;&EN96UE9&DB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C0Y.0HC+"!P:'`M9F]R
M;6%T"FUS9VED(")!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<R(*;7-G<W1R(")!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/](&?\;F-E;&QE
M;F5M961I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,#4*
M;7-G:60@(D%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O
M<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<#HT-@IM<V=I9"`B075T:%]M8V%L
M.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(D%U=&A?;6-A;#H@W7-T96YE;B!-0T%,('5Z86YT_7/](&)U;'5N86UA9/TN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S;6(N<&AP.C8P"FUS9VED(")!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"XB"FUS9W-T<B`B075T:%]S;6)A=71H.B#=<W1E;F5N('-M8F%U=&@@
M=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3`*;7-G:60@(D%U=&AE;G1I8V%T
M:6]N(&9A:6QE9"(*;7-G<W1R(")$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z-C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I9"`B075T:&5N=&EC871I;VX@
M9F%I;&5D+B`E<R(*;7-G<W1R(")$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N
M("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$W-@IM
M<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E
M<BXB"FUS9W-T<B`B1&_P<G5L86UA(%)!1$E54R!S=6YU8W5S=2!T87)A9OUN
M9&%N(&=E<FD@YV5V<FEL9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HX-3$*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+B(*;7-G<W1R(")&5%`@<W5N=6-U<W5N82!D;_!R=6QA;6$@8F'^
M87+]<_UZ(&]L9'4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HW
M,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S
M97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@<W5N=6-U<W5N82!D;_!R=6QA
M;6$@8F'^87+]<_UZ(&]L9'4N(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P
M+FEN8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`B2W5L
M;&%N_6S]<B!A;&%N;&%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@(D%Z97)B86EJ
M86XB"FUS9W-T<B`B07IE<F)A>6-A;B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HS,`IM<V=I9"`B0D]&2"!%>&-U<V5S(@IM<V=S='(@(D)/1D@@0>?]
M:VQA;6%L87+](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHQ.`IM<V=I9"`B0F%C:V=R;W5N9"(*;7-G<W1R(")!
M<G1A;&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHR,PIM<V=I9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R(")!<G1A
M;&%N(%)E;F=I(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M,0IM<V=I9"`B0F%D(&ME<F)E<F]S('!A<W-W;W)D+B(*;7-G<W1R(")+]G3\
M(&ME<F)E<F]S('!A<F]L87/]+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M:W)B-2YP:'`Z.#,*;7-G:60@(D)A9"!K97)B97)O<R!U<V5R;F%M92XB"FUS
M9W-T<B`B2_9T_"!K97)B97)O<R!K=6QL86[]8_T@863]+B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)A:&%M87,B"FUS9W-T<B`B0F%H86UA;&%R(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS."!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,0IM<V=I9"`B0F%H<F%I;B(*;7-G<W1R(")"86AR97EN(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ-S<*;7-G:60@(D)A;'1I8R`H25-/+3@X-3DM
M,3,I(@IM<V=S='(@(D)A;'3]:R`H25-/+3@X-3DM,3,I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HS-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV
M,`IM<V=I9"`B0F%N9VQA9&5S:"(*;7-G<W1R(")"86YG;&%D9?XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8P"FUS9VED(")"87)B861O<R(*;7-G<W1R(")"87)B861O<R(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F
M;W5N9"XB"FUS9W-T<B`B5&%B86X@9W)A9FEK(&1I>FEN:2`G)7,G(&)U;'5N
M86UA9/TN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHQ.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<S"FUS9VED(")"87-E;&EN92(*;7-G<W1R(")486)A;B#G
M:7IG:7-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT.2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,P"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F5L87)U<R(*;7-G<W1R(")"
M97EA>B!2=7-Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,S4@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)E;&=I=6TB"FUS9W-T
M<B`B0F5LYVEK82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)E;&EZ92(*;7-G<W1R
M(")"96QI>F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS9VED(")"96YI;B(*;7-G<W1R(")"
M96YI;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#$@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)E<FUU9&$B"FUS9W-T<B`B0F5R
M;75D82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#8@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C,*;7-G:60@(D)H=71A;B(*;7-G<W1R(")":'5T
M86XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3$Q"FUS9VED(")":7)T:&1A>2(*;7-G<W1R(")$;_!U;6?\;OPB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S4S"B,L('!H
M<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<
M(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R(")5>6=U;&%M82!<(B5S7"(@<V%H
M:7`@;VQD=?!U(%PB)7-<(B#V8F7P:2!B=6QU;F%M863]+B(*"B,Z('1E;7!L
M871E<R]P;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN
M9W,B"FUS9W-T<B`BUF)E:R!!>6%R;&%R_2(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;&%Y;W5T+FEN8SHW-`IM<V=I9"`B0FQO8VL@5'EP92(*;7-G<W1R("+6
M8F5K(%3\<OPB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@*;7-G:60@(D)O;&0B"FUS9W-T<B`B2V]Y=2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C(*;7-G:60@(D)O;&EV:6$B"FUS9W-T<B`B0F]L:79Y82(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR,#4*;7-G:60@(D)O;VMM87)K<R(*;7-G
M<W1R(")997(@W6UL97)I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@
M(E/];OUR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHX-0IM<V=I9"`B0F]R9&5R('1H:6-K;F5S<SHB"FUS9W-T<B`B4_UN
M_7(@2V%L_6YL_?#].B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,C$*;7-G:60@(D)O<F1E<G,B"FUS9W-T<B`B
M4_UN_7)L87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE
M9V]V:6YA(@IM<V=S='(@(D)O<VYA($AE<G-E:R(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G<W1R(")(97(@26MI<VDB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8S"FUS9VED(")";W1S=V%N82(*;7-G<W1R(")";W1S=F%N
M82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHW-0IM<V=I9"`B0F]T=&]M(@IM<V=S='(@(D%L="(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B0F]U=F5T($%D86QA
M<OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0T(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#`*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C8R"FUS9VED(")"<F%Z:6PB"FUS9W-T<B`B0G)E>FEL
M>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0Q"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,0IM<V=I9"`B0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y(@IM<V=S='(@(D)R:71A;GEA($AI;G0@3VMY86YU<W4@0O9L
M9V5S:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-C(*;7-G:60@(D)R=6YE:2!$87)U<W-A;&%M(@IM
M<V=S='(@(D)R=6YE:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HT,PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*;7-G:60@(D)U;&=A<FEA(@IM
M<V=S='(@(D)U;&=A<FES=&%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ.0IM<V=I9"`B0G5L;&5T960@3&ES="(*;7-G
M<W1R(")-861D92#=;6QI($QI<W1E(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HS-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I9"`B0G5R
M:VEN82!&87-O(@IM<V=S='(@(D)U<FMI;F$@1F%S;R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,SD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HT-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C$*
M;7-G:60@(D)U<G5N9&DB"FUS9W-T<B`B0G5R=6YD:2(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HT-#0*;7-G:60@(D--4R(*;7-G<W1R(")#35,B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<U"FUS
M9VED(")#4D,B"FUS9W-T<B`B0U)3(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(D-23"!$:7-T<FEB=71I;VX@4&]I
M;G1S(@IM<V=S='(@(D-23"!$8?#]=/UM($YO:W1A;&%R_2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-PIM
M<V=I9"`B0U]E;&P@4')O<&5R=&EE<RXN+B(*;7-G<W1R(")?2/QC<F4@UGIE
M;&QI:VQE<FDN+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,38S"B,L(&9U>GIY"FUS9VED(")#86-H92!I;FET('=A<R!N;W0@8V]M<&QE
M=&5D+B(*;7-G<W1R(")$8?#]=/UM(&QI<W1E<VD@8F5L:7)L96YE;65D:2XB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#@T
M(&-O;F9I9R]H;V]K<RYP:'`N9&ES=#HY.#<*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C$U-0IM<V=I9"`B0V%L96YD87(B"FUS9W-T<B`B5&%K=FEM
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T-@IM<V=I9"`B
M0V%L;2(*;7-G<W1R(")$=7)G=6XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B0V%M
M8F]D:6$B"FUS9W-T<B`B2V%M8F_G>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C8P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M-#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#
M86UE<F]O;B(*;7-G<W1R(")+86UE<G5N(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z,C`*;7-G:60@(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@
M875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM
M<V=S='(@(B(*(E!A<F]L82#V>F1E=FEN:6UL:2!O;&%R86L@<_UF_7)L86YA
M;6%M86MT863]<BP@;/QT9F5N('GV;F5T:6-I;FEZ;&4@9_9R_/[\;BXB"@HC
M.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS,3@*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D-A;B!N;W0@=W)I=&4@=&\@9FEL92!<(B5S7"(B
M"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@<VEL:6YE;65D:2XB"@HC.B!A9&UI
M;B]S97-S:6]N<RYP:'`Z,C(*;7-G:60@(D-A;B=T(&%D;6EN:7-T97(@97AT
M97)N86P@<V5S<VEO;B!H86YD;&5R<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C,U(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER<W%L+G!H<#HS,3D*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N)W0@
M8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,B"FUS9W-T<B`B24U!4"!S=6YU
M8W5S=6YA(&)A\&QA;OUL863].B`E<R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-3
M5B]#4U8N<&AP.C0Q,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V%N
M)W0@;W!E;B!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@
M<VEL:6YE;65D:2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4Q
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#@*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8T"FUS9VED(")#86YA9&$B"FUS9W-T
M<B`B2V%N861A(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`Q(&%D;6EN+W5S97(N
M<&AP.C$R,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-C4*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC.C$Q
M('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHQ,@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")#86YC96PB"FUS
M9W-T<B`BW7!T86PB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN
M8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S='(@(E-O
M<G5N(%)A<&]R=6YU(-UP=&%L($5T(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(&1E;&5T
M92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&1O<WEA<_T@<VEL:6YE
M;65D:2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#8*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y
M+G!H<#HU,@IM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T
M;W)Y+B(*;7-G<W1R(")'9>=I8VD@9&EZ:6X@8G5L=6YA;6%D_2XB"@HC.B!F
M<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.CDQ"FUS9VED
M(")#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T
M97(N(@IM<V=S='(@(B=T87)G971&:6QE)R!D9?!I_G1I<F=E<VD@;VQM861A
M;B!D979A;2!E9&EL96UE>BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C,Q-`HC+"!P:'`M9F]R;6%T"FUS9VED(")#86YN;W0@<F5M;W9E(&1I
M<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!D:7II;FD@:V%L9/UR
M_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964N<&AP
M.C$R."!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H<#HV.#`*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B0V%N;F]T(')E;6]V92P@)60@8VAI;&1R
M96X@97AI<W0N(@IM<V=S='(@(DMA;&3]<OUL86UA9/T@+"5D(&%L="!Y87#]
M('9A<BXB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O<W%L+G!H
M<#HV,#@*;7-G:60@(B(*(D-A;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT
M<FEE<R!S=7!P;&EE9"!F;W(@<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB
M97(@(@HB<W1O<F5D+B(*;7-G<W1R("(B"B)996YI9&5N(&3\>F5N;&5M961I
M+"!Y96YI9&5N(&3\>F5N;&5M92!IYVEN('-A\&QA;F%N(&MA>?UT;&%R_6X@
M<V%Y_7/](&EL92`B"B)D97!O;&%N;?W^(&]L86YL87+];B!S87G]<_T@9?YL
M9?YM96UE:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P.0IM<V=I9"`B0V%N;F]T(')O=71E(&UE<W-A
M9V4@=&\@<W!E8VEF:65D(&YU;6)E<BXB"FUS9W-T<B`B0F5L:7)T:6QM:?X@
M;G5M87)A>6$@:6QE=&D@>?9N;&5N9&ER:6QE;65D:2XB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8X
M"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(D-A<&4@5F5R9&4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(T
M"FUS9VED(")#87!T:6]N(@IM<V=S='(@(D)A_FS]:R(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*
M;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R(")+871E9V]R
M:6QE<B!V92!%=&EK971L97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B0V%Y;6%N
M($ES;&%N9',B"FUS9W-T<B`B0V%Y;6%N($%D86QA<OTB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DT"FUS9VED(")#96QL
M(%!H;VYE(@IM<V=S='(@(D-E<"!496QE9F]N=2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C4*;7-G:60@(D-E
M;&P@4')O<&5R=&EE<R(*;7-G<W1R(")(_&-R92#6>F5L;&EK;&5R:2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS
M9VED(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(DC\8W)E('EA<W3]:VQA;6%S
M_3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C8Q"FUS9VED(")#96QL('!R;W!E<G1I97,B"FUS9W-T<B`B2/QC
M<F4@UGIE;&QI:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$Q,@IM<V=I9"`B0V5L;"!S<&%C:6YG.B(*;7-G<W1R
M(")(_&-R92!";_YL=6ML87+].B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$R-S0*;7-G:60@(D-E;&QP:&]N92(*;7-G<W1R(")#97`@5&5L969O
M;G4B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$W.`IM<V=I9"`B0V5L=&EC
M("A)4T\M.#@U.2TQ-"DB"FUS9W-T<B`B2V5L=&EK("A)4T\M.#@U.2TQ-"DB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(V"FUS9VED(")#96YT97(B"FUS9W-T<B`B3W)T82(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-30@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HU,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-C4*;7-G:60@(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(*;7-G<W1R(")/
M<G1A($%F<FEK82!#=6UH=7)I>65T:2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3<Y"FUS9VED(")#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*2(*
M;7-G<W1R(")/<G1A($%V<G5P82`H25-/+3@X-3DM,BDB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Y.0IM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R(")/;F%Y($)E;&=E<VD@07ER_6YT_6QA<OTB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8Q,0HC+"!F
M=7IZ>0IM<V=I9"`B0V5R=&EF:6-A=&4@3W=N97(B"FUS9W-T<B`B3VYA>2!"
M96QG97-I($%Y<OUN=/UL87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.38*;7-G:60@(D-E<G1I9FEC871E(%!O;&EC:65S(@IM
M<V=S='(@(D]N87D@0F5L9V5S:2!+=7)A;&QA<OTB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C4R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#@*
M;7-G:60@(D-H860B"FUS9W-T<B`BQV%D(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(D1E\&G^=&ER(@H*(SH@<V5R=FEC
M97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,Q"B,L(&9U>GIY"FUS9VED(")#:&%N
M9V4@66]U<B!087-S=V]R9"(*;7-G<W1R(")087)O;&%N_7K]('/]9OUR;&%Y
M_6XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C8*;7-G:60@(B(*(D-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G
M<W1R("(B"B+=;G-A;FQA<OUN('-I>F1E;B!G96QE;B!E;&5K=')O;FEK('!O
M<W1A;&%R_2!O:W5R:V5N('9E(&-E=F%P;&%R:V5N("(*(F?V<F3\:VQE<FD@
M860@=F4@861R97-I;FEZ:2!D9?!I_G1I<FEN+B(*"B,Z('-E<G9I8V5S+V-H
M86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I9"`B(@HB0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(DMA<F%K=&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C(U"FUS9VED(")#:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")"8?!L
M86YT_7G]($1E7VYE=&QE+BXN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HU.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I9"`B0VAI;&4B
M"FUS9W-T<B`BWFEL:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C<*;7-G:60@(D-H:6YA(@IM<V=S
M='(@(L=I;B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@P"FUS9VED(")#
M:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BDB"FUS9W-T<B`B0F%S:71L9?YT
M:7)I;&UI_B#':6YC92`H1T(R,S$R*2(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3@Q"FUS9VED(")#:&EN97-E(%1R861I=&EO;F%L("A":6<U*2(*;7-G
M<W1R(")'96QE;F5K<V5L(,=I;F-E("A":6<U*2(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR-CD*;7-G:60@(D-H;V]S92!A('!A<W-W
M;W)D(@IM<V=S='(@(E!A<F]L82!S9>=I;B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O4VEG;G5P+G!H<#HR-C@*;7-G:60@(D-H;V]S92!A('5S97)N86UE
M(@IM<V=S='(@(DMU;&QA;OUC_2!A9/T@<V7G:6XB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,CDX"FUS9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z(@IM<V=S='(@(E1A<FEH;&5R:6X@;F%S_6P@9_9S=&5R:6QE8V7P
M:6YI('-EYVEN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE
M('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*2(*;7-G<W1R("),:7-T92!":>=E
M;2!4_'+\;OP@4V7G:6X@*'/]<F%L86YM_?X@;&ES=&5L97(@:>=I;BDB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@(D-H
M<FES=&UA<R!!9&%L87/](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+G!H
M<#HR.30@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@Y,PHC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB"FUS
M9W-T<B`B4_UN_68@=&%N_6W](&)U;'5N86UA9/TZ)7,B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HQ-`IM<V=I9"`B0VQE87(B
M"FUS9W-T<B`B5&5M:7IL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-#(*;7-G:60@(D-L96%R($U33V9F:6-E('1A9W,B
M"FUS9W-T<B`B35-/9F9I8V4@8FGG:6T@:6UL97)I;FD@=&5M:7IL92(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(DMU;&QA;OUC_2!T96UI>FQE(@H*(SH@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C4*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(DMU;&QA;OUC_7G]('1E
M;6EZ;&4Z("5S(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC
M.C$Q"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(DMU;&QA;OUC_2!T96UI
M>FQE(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,S0*;7-G
M:60@(D-L96%R('5S97(@9&%T82(*;7-G<W1R(")+=6QL86[]8_T@=F5R:7-I
M('1E;6EZ;&4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HQ-0HC+"!F=7IZ>0IM<V=I9"`B0VQE87)I;F<@3&%T92(*;7-G<W1R
M(")'9><@4V%A=&QE<F1E(%EA\&UU<B(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]M86EN=&5N86YC92YH=&UL.C8P"FUS9VED(")#;&EC:R!T;R!#;VYT
M:6YU92(*;7-G<W1R(")$979A;2!E=&UE:R!IYVEN('3]:VQA>?UN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3@T
M"FUS9VED(")#;&EC:V%T96QL('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L
M=7EL82!#;&EC:V%T96QL(@H*(SH@<V5R=FEC97,O:V5Y8F]A<F0N<&AP.C$T
M-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R"FUS9VED(")#;&]S92!7
M:6YD;W<B"FUS9W-T<B`B4&5N8V5R97EI($MA<&%T(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HR-#0*;7-G:60@(D-L;W5D<R(*;7-G<W1R(")"=6QU=&QA
M<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$V
M"B,L(&9U>GIY"FUS9VED(")#;&]U9',@16%R;'DB"FUS9W-T<B`B0G5L=71L
M=2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$W
M"FUS9VED(")#;&]U9'DB"FUS9W-T<B`B0G5L=71L=2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HU-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C0*
M;7-G:60@(D-O8V]S("A+965L:6YG*2!)<VQA;F1S(@IM<V=S='(@(D-O8V]S
M($%D86QA<OTB"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C(S
M"FUS9VED(")#;VQL87!S92!3:61E8F%R(@IM<V=S='(@(DME;F%R(,=U8G7P
M=6YU($1A<F%L="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z,C@*;7-G:60@(D-O;&QA<'-E9"!B;W)D97)S(@IM
M<V=S='(@(D1A<F%L=/UL;?W^(%/];OUR;&%R(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HV,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-PIM<V=I
M9"`B0V]L;VUB:6$B"FUS9W-T<B`B2V]L;VUB:7EA(@H*(SH@;&EB+T)L;V-K
M+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N<&AP.C(Y"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,CD*;7-G
M:60@(D-O;&]R(@IM<V=S='(@(E)E;FLB"@HC.B!F<F%M97=O<FLO0FQO8VLO
M0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E<R]I;6%G97,O8V]L;W)P
M:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F<R]C871E9V]R>6UA;F%G
M96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K97(B"FUS9W-T<B`B4F5N
M:R!39>=I8VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#0V"FUS
M9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(E)E;FL@4V7G:6UI(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#,*
M;7-G:60@(D-O;',Z(@IM<V=S='(@(DMO;&]N;&%R.B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#8*;7-G:60@(D-O;'5M;B!T:71L97,B"FUS
M9W-T<B`B2V]L;VX@0F'^;/UK;&%R_2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HR-C0*;7-G:60@(D-O;6EC<R(*;7-G<W1R(")+;VUI:R(*"B,Z
M(&%D;6EN+V-M9'-H96QL+G!H<#HR-0IM<V=I9"`B0V]M;6%N9"(*;7-G<W1R
M(")+;VUU="(*"B,Z(&%D;6EN+V-M9'-H96QL+G!H<#HR,`IM<V=I9"`B0V]M
M;6%N9"!3:&5L;"(*;7-G<W1R(")+;VUU="!+86)U\'4B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D-O;6UE;G0B"FUS
M9W-T<B`B0>?]:VQA;6$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4V-@IM<V=I9"`B0V]M;6]N($YA;64B"FUS9W-T<B`B3W)T86L@
M063](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(D-O;6]R;W,B"FUS9W-T<B`B0V]M
M;W)O<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T<B`BWFER:V5T(@H*(SH@;&EB
M+T)L;V-K+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T
M<B`B0FEL9VES87EA<FQA<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR.3<*(RP@9G5Z>GD*;7-G:60@(D-O;F1I=&EO;B(*;7-G<W1R(")+
M;_YU;&QA<B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C0Y"FUS9VED(")#
M;VYD:71I;VYS(@IM<V=S='(@(DMO_G5L;&%R(@H*(SH@861M:6XO<V5T=7`O
M9&EF9BYP:'`Z.38*;7-G:60@(D-O;F9I9W5R871I;VX@1&EF9F5R96YC97,B
M"FUS9W-T<B`B66%P_6QA;F3]<FUA($9A<FML87+](@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$T,PIM<V=I9"`B0V]N9FEG=7)A=&EO;B!F;W(@<WEN
M8VEN9R!W:71H(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+B(*;7-G
M<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3,U"B,L(&9U>GIY
M"FUS9VED(")#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B(*;7-G<W1R
M(")987#];&%N9/UR;6%N_6X@9_QN8V5L;&5N;65S:2!G97)E:VUE:W1E9&ER
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N9FEG=7)E("5S(@IM<V=S='(@(EEA</UL86YD_7(Z)7,B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C4Q"FUS9VED
M(")#;VYF:7)M(%!A<W-W;W)D(@IM<V=S='(@(E!A<F%L;WG]($1O\')U;&$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8V"FUS9VED(")#;VYG;R(*;7-G<W1R(")+;VYG;R(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HV,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-C4*;7-G:60@(D-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI
M8R!O9B!T:&4B"FUS9W-T<B`B1&5M;VMR871I:R!+;VYG;R!#=6UH=7)I>65T
M:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$Y
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3`*
M;7-G:60@(D-O;FYE8W1I;VX@9F%I;&5D+B(*;7-G<W1R(")"8?!L86YT_2!B
M8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,S$P"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S
M='(@(D)A\&QA;G3](&)A_F%R_7/]>B!O;&1U.B(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]P9W`N<&AP.C<Y,`IM<V=I9"`B0V]N;F5C=&EO;B!R969U
M<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G<W1R(")!Y_UK(&%N
M86AT87(@<W5N=6-U<W5N82!B8?!L86YT_2!R961D961I;&1I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Y,@HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N(%)E87-O;CH@)7,@*"5S*2(*;7-G<W1R(")!Y_UK(&%N86AT87(@
M<W5N=6-U<W5N82!B8?!L86YT_2!R961D961I;&1I+B!396)E8CH@)7,@*"5S
M*2(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#0U"FUS9VED(")#
M;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")&5%`@
M<W5N=6-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ(&]L9'4N(@H*(SH@8V]N9FEG
M+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G:60@(D-O;G1A8W1S(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU
M,PIM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(MUL971I_FEM(&YO:W1A;&%R
M_2!B8?YA<OUY;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4V(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&=Z+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]N=&5N=',@;V8@7"(E<UPB(@IM<V=S='(@(MWG97)I:SH@
M)R5S)R(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(Y('-E<G9I
M8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PIM<V=I9"`B0V]N=&EN=64B"FUS
M9W-T<B`B1&5V86TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4X
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8V"FUS9VED(")#;V]K($ES;&%N9',B
M"FUS9W-T<B`B0V]O:R!!9&%L87+](@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,R"FUS9VED(")#;V]K:64B"FUS9W-T<B`BQV5R97HB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C$*
M;7-G:60@(D-O<'DB"FUS9W-T<B`B2V]P>6%L82(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+W-M8BYP:'`Z-#8X"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W!Y(&9A:6QE9#H@)7,B"FUS9W-T<B`B0F'P;&%N=/T@8F'^87+]<_UZ
M(&]L9'4Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHS-@IM<V=I9"`B0V]P>2!S96QE8W1I;VXB"FUS9W-T<B`B4V7G:6UI
M($MO<'EA;&$B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N
M<&AP.C$W,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP
M.C$Y-0IM<V=I9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS
M9VED(")#;W-T82!2:6-A(@IM<V=S='(@(DMO<W1A(%)I:V$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C4W(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8V"FUS9VED(")#;W1E(&0G279O:7)E(@IM<V=S='(@(D-O=&4@9"=)=F]I
M<F4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-S8*;7-G
M:60@(D-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+=
M;&5T:2!01U`@:6QE(/YI9G)E;&5N96UE9&DN(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,3`U,PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4N(@IM<V=S='(@(MUL971I(%!'4"!I;&4@:6UZ86QA;F%M
M863]+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,SDS
M"FUS9VED(")#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB"FUS
M9W-T<B`BW6QE=&D@4R]-24U%(&EL92!S:69R96QE;F5M961I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-#8W"FUS9VED(")#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`BW6QE=&D@4R]-
M24U%(&EL92!I;7IA;&%N86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ.#0*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R("+=;&5T:?YI
M;2!N;VMT87/](&5K;&5N96UE9&DN("5S(@H*(SH@9G)A;65W;W)K+T=R;W5P
M+T=R;W5P+VQD87`N<&AP.CDV(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,3(Q"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB
M"FUS9W-T<B`B3$1!4"!S=6YU8W5S=6YA(&)A\&QA;OUL86UA9/TN(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C0U-PHC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&)I;F0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3$1!4"!S=6YU
M8W5S=6YA(&)A\&QA;OUL86UA9/TN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O
M4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L('!H<"UF;W)M870*
M;7-G:60@(D-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R(")"
M86MI>64@9&5N971L96YE;65D:2X@)7,B"@HC.B!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-#0Q"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!L9&%P('-E<G9E<B(*;7-G<W1R(")334(@<W5N=6-U<W5N82!B8?!L86YT
M_2!B8?YA<OUS_7HN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C0X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T
M;R!S97)V97(@7"(E<UPB('5S:6YG($944#H@)7,B"FUS9W-T<B`B)R5S)R!S
M=6YU8W5N82!&5%`@>6]L=7EL82!B8?!L86[];&%M863].B`E<R(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S(R"B,L
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!Y87)A=/UL
M86UA9/TN("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M,3$R-0IM<V=I9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$N(@IM<V=S
M='(@(E!'4"!V97)I<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3(R"FUS9VED(")#;W5L
M9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82XB"FUS9W-T<B`B4R]-24U%('9E
M<FES:6YI;B#^:69R97-I(.?V>OQL96UE9&DN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR-#8*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M("+=;&5T:?YI;2!N;VMT87/]('-I;&EN96UE9&DN("5S(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS-38*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T97-I('-I;&EN96UE9&DN
M("5S(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z,S@*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R(")!>6%R(&?\;F-E;&QE;64@
M8F5T:?!I("<E<R<@<VEL:6YE;65D:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z,S@Q(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.CDU,PIM<V=I9"`B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N(@IM<V=S='(@(D%L_6/];OUN(&5L96MT
M<F]N:6L@<&]S=&$@861R97-I(&)E;&ER;&5N96UE9&DN(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR.#,*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S
M='(@(D%D<F5S(&1E9G1E<FD@=&%M86UE;B!G971I<FEL96UE9&DN(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT.3,*
M;7-G:60@(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="XB"FUS9W-T<B`B1&'P_73];2!L:7-T97-I('1A;6%M96X@9V5T:7)I
M;&5M961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-#0V"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L
M971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R(")$8?#]
M=/UM(&QI<W1E;&5R:6YI;B!L:7-T97-I('1A;6%M96X@9V5T:7)L96UE9&DN
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/
M=71P=713=')A=&5G>2YP:'`Z-C@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HX-`HC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&QO860@<W1R871E9WD@
M7"(E<UPB+B(*;7-G<W1R(")3=')A=&5J:2`G)7,G('G\:VQE;F5M961I+B(*
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP
M=713=')A=&5G>2]C;W!Y+G!H<#HQ,3`*(SH@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP
M.C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;6MD
M:7(@7"(E<UPB+B(*;7-G<W1R(")M:V1I<B`G)7,G(&)A_F%R_7/]>B!O;&1U
M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0IM<V=I
M9"`B0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BXB"FUS9W-T<B`B06YA:'1A<B!S=6YU8W5S=6YD86X@8>?]:R!A;F%H
M=&%R(&5D:6YI;&5M961I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HQ,SD*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!O<&5N(%PB)7-<
M(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B)R5S)R!Y87K];&UA:R!IYVEN(&'G
M_6QA;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8W-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS-#4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I
M;E]H='1P+G!H<#HR-C(*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T
M(&]P96X@)7,N(@IM<V=S='(@(B5S(&'G_6QA;6%D_2XB"@HC.B!F<F%M97=O
M<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO
M9'5L92`E<R(*;7-G<W1R(")-86EN=&5N86YC95]487-K(&)I<FEM:2`E<R!A
MY_UL86UA9/TN(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C<P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E
M<UPB+B(*;7-G<W1R("(G)7,G(&1I>FEN:2!AY_UL86UA9/TN(@H*(SH@9G)A
M;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C$Q,2!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,30T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HR,S<@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0W.`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-3$V(&9R
M86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV,3(*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8U-B!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z-CDY"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@<F5A
M8V@@=&AE($Q$05`@<V5R=F5R+B(*;7-G<W1R("),1$%0('-U;G5C=7-U(&%R
M86YA;6%D_2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP.C(S
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS
M9W-T<B`B)7,@;VMU;F%M863]+B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O
M<F0N<&AP.C@U"FUS9VED("(B"B)#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92`B"B)D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D("(*(F9U<G1H
M97(@:&5L<"XB"FUS9W-T<B`B(@HBW7-T96YE;B!K=6QL86YC_2!IYVEN('!A
M<F]L82!S_6;]<FQA;F%M863]+B!"87K]('EA9&$@=/QM(&%Y<OUN=/UL87(@
M9&_P<G4@(@HB9&7P:6PN(%EE;FED96X@9&5N97EI;B!Y861A(&1A:&$@9F%Z
M;&$@>6%R9/UM(&GG:6X@<VES=&5M('GV;F5T:6YI>FQE("(*(F?V<OS^_&XN
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S`Y
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0IM<V=I9"`B
M0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R(")!0TP@97)I_FEL96UE
M9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HR-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,B"FUS9W-T<B`B061R97,@9&5F=&5R:6YE
M(&5R:?YI;&5M961I+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-#@T"B,L('!H<"UF;W)M870*;7-G:60@(D-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`B1&'P_73];2!L:7-T97-I;F4@97)I_FEL96UE9&DN("5S(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,B"FUS9W-T<B`B1&'P_73];2!L:7-T96QE<FEN92!E
M<FG^:6QE;65D:2X@)7,B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R
M9F,R,#@V+G!H<#HQ.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C
M,C`X-BYP:'`Z,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P
M.#8N<&AP.C(R,PIM<V=I9"`B0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<R(*;7-G<W1R(")3=6YU8W5N=6X@>65T96YE:VQE<FEN
M92!E<FG^:6QE;65D:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(EEA</UL86YD_7)M82!G97)I(&3V;F3\<OQL96UE9&DN+B(*"B,Z(&9R
M86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A
M=&5G>2]C;W!Y+G!H<#HY-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB"FUS9W-T<B`B<FUD:7(@)7,@YV%L
M_?YT_7+];&%M863]+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C<S
M"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B5S('EA</UL86YD_7)M82!K87ED961I;&5M
M961I+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HV,R!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HU.0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@82!B86-K
M=7`@8V]N9FEG=6%T:6]N+B(*;7-G<W1R(")9961E:R!B:7(@>6%P_6QA;F3]
M<FUA(&MA>61E9&EL96UE9&DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP
M.C8Q"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!S879E(&$@8F%C
M:W5P(&-O;F9I9W5A=&EO;CH@)7,B"FUS9W-T<B`B665D96L@8FER('EA</UL
M86YD_7)M82!K87ED961I;&5M961I.B`E<R(*"B,Z(&%D;6EN+W-E='5P+W-C
M<FEP=',N<&AP.CDU"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E<UPB+B(*
M;7-G<W1R(")!>6%R(&?\;F-E;&QE;64@8F5T:?!I(&MA>61E9&EL96UE9&DZ
M("<E<R<N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I
M9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B665D96L@>6%P_6QA;F3]<FUA
M(&1O<WEA<_T@)7,@:V%Y9&5D:6QE;65D:2XB"@HC.B!A9&UI;B]S971U<"]C
M;VYF:6<N<&AP.C<U"B,L('!H<"UF;W)M870*;7-G:60@(B(*(D-O=6QD(&YO
M="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET
M:&5R('5S92!O;F4@;V8@=&AE("(*(F]P=&EO;G,@=&\@<V%V92!T:&4@8V]D
M92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@
M=&\@)7,N(@IM<V=S='(@(B(*(EEA</UL86YD_7)M82!D;W-Y87/]("5S(&MA
M>61E9&EL96UE9&DN($)U(&1U<G5M9&$L(&MO9'4@=&5K<F%R("5S(&GG:6YE
M("(*(FMA>61E=&UE:R!Y861A('1A:VEP(&5D96X@:V]D=2!E;"!I;&4@)7,@
M:>=I;F4@:V]P>6%L86UA:RP@<V7G96YE:VQE<FEN:2`B"B)K=6QL86YA8FEL
M:7)S:6YI>BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$T
M,PIM<V=I9"`B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(@IM
M<V=S='(@(DQ$05`@<W5N=6-U<W4@87)A;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C
M;W!Y+G!H<#HX-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T('5N;&EN:R!<(B5S7"(N(@IM<V=S='(@(D)A\"#G]GK\;&5M961I.B`G
M)7,G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z,C$Y"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!U<&1A
M=&4@8V]N=&%C="X@)7,B"FUS9W-T<B`BW6QE=&G^:6T@;F]K=&%S_2!G_&YC
M96QL96YE;65D:2X@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C,Y-@HC+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")$
M8?#]=/UM(&QI<W1E<VD@9_QN8V5L;&5N96UE9&DN("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@7"(E<UPB.B`E
M<R(*;7-G<W1R("(G)7,G(&GG:6X@>6%P_6QA;F3]<FUA('EA>OUL86UA9/TZ
M("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,V-@IM<V=I9"`B0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B(@HB36]Z:6QL82!K96YA<B#G
M=6)U\'4@8G5L=6YA;6%D_2X@2V5N87(@YW5B=?!U;G5N(&'G_6L@;VQD=?!U
M;F1A;B!E;6EN(&]L=6XN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,34T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(B
M"B)#;W5L9&XG="!G:79E('5S97(@7"(E<UPB('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R(%PB)7-<(CH@)7,B"FUS9W-T<B`B)R5S)R!D
M:7II;FD@:>=I;B`G)7,G(&MU;&QA;OUC_7/]('1A:VEP(&5D96X@:&%K;&%R
M_2!V97)E;65D:3H@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M-#$Y"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`B4V%Y_6QM_?X@;65T
M:6XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.0IM
M<V=I9"`B0V]U;G1R>2(*;7-G<W1R("+<;&ME(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*;7-G<W1R(")$97)S
M;&5R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C(Q('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-@HC.B!T96UP;&%T97,O<G!C<W5M
M+W)P8W-U;2YI;F,Z,3`P"FUS9VED(")#<F5A=&4B"FUS9W-T<B`B66%R870B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-C@*;7-G:60@(D-R96%T92!A(&QI;FLB"FUS9W-T<B`B0F'P;&%N
M=/T@>6%R870B"@HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N
M:6YC.CDT"FUS9VED(")#<F5A=&4@82!N97<@;VYE(@IM<V=S='(@(EEE;FD@
M66%R870B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H
M<#HY,@IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(D%L="!D
M:7II;B!Y87)A="(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,C0P"FUS9VED(")#<F5A=&]R(%!E<FUI<W-I;VYS(@IM<V=S='(@(EEA<F%T
M_6/](-UZ:6YL97)I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(S
M,`IM<V=I9"`B0W)E9&ET(&-A<F0@;G5M8F5R(@IM<V=S='(@(DMR961I(&MA
M<G0@;G5M87)A<_TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.0IM<V=I9"`B0W)O871I82(*;7-G
M<W1R(")(_7)V871I<W1A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B"FUS
M9W-T<B`B2_QB82(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR-@HC+"!F=7IZ
M>0IM<V=I9"`B0W5R<F5N="`T(%!H87-E<R(*;7-G<W1R("+>=2!!;F1A:VD@
M179R92(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HT.`HC+"!F=7IZ>0IM<V=I
M9"`B0W5R<F5N="!397-S:6]N<R(*;7-G<W1R(")987)A=/UC_2#=>FEN;&5R
M:2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H
M<#HS,`IM<V=I9"`B0W5R<F5N="!4:6UE(@IM<V=S='(@(MYU($%N9&%K:2!:
M86UA;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHU-`IM<V=I9"`B0W5R<F5N="!54DP@:7,B"FUS9W-T<B`B
MWG4@86YD86MI(%523"(*"B,Z(&%D;6EN+W-E<W-I;VYS+G!H<#HS,PHC+"!F
M=7IZ>0IM<V=I9"`B0W5R<F5N="!5<V5R<R(*;7-G<W1R("+>=2!!;F1A:VD@
M179R92(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E
M;G0@5V5A=&AE<B(*;7-G<W1R("+>=2!!;F1A:VD@2&%V82!$=7)U;74B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C<U"FUS9VED(")#=7)R
M96YT(&-O;F1I=&EO;CH@(@IM<V=S='(@(MYU($%N9&%K:2#>87)T;&%R.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S(*
M;7-G:60@(D-U<G)E;G0@<W1Y;&4B"FUS9W-T<B`B6?QR_')L_&MT96MI('-I
M=&EL(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@
M=&\@)7,N(@IM<V=S='(@(B5S(&4@9VER:?YT92#G86S]_F%C86L@9_9R979L
M97)I(&MI_FES96QL9?YT:7)I;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,`IM<V=I9"`B0W5T(@IM<V=S
M='(@(DME<R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S4*;7-G:60@(D-U="!S96QE8W1I;VXB"FUS9W-T<B`BWF7G:6QI
M(&]L86YL87+](&ME<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M-C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-Y<')U<R(*;7-G
M<W1R(")+_6)R_7,B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,@IM<V=I
M9"`B0WER:6QL:6,@*$M/23@M4BDB"FUS9W-T<B`B2VER:6P@*$M/23@M4BDB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@
M*%=I;F1O=W,M,3(U,2DB"FUS9W-T<B`B2VER:6P@*%=I;F1O=W,M,3(U,2DB
M"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X-`IM<V=I9"`B0WER:6QL:6,O
M56MR86EN:6%N("A+3TDX+54I(@IM<V=S='(@(DMI<FEL+U5K<F%Y;F$@*$M/
M23@M52DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")#>F5C:"!297!U8FQI8R(*;7-G
M<W1R("+'96L@0W5M:'5R:7EE=&DB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4Q('1E;7!L871E<R]D871A+V1A=&4N:6YC
M.C0W"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0X('1E;7!L871E<R]D
M871A+V1A=&4N:6YC.C0Y"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C4P
M"FUS9VED(")$1"(*;7-G<W1R(")'1R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C,R.#$*;7-G:60@(B(*(D133B`H<V5E(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N
M+G!H<"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA
M:6YT96YA;F-E+G!H<#HU.0IM<V=I9"`B1&%I;'DB"FUS9W-T<B`B1_QN;/QK
M(@H*(SH@861M:6XO9&%T871R964N<&AP.C8U"FUS9VED(")$871A5')E92!"
M<F]W<V5R(@IM<V=S='(@(E9E<FD@0?!A8_T@5&%R87G]8_US_2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-SD*;7-G:60@(D1A=&%B87-E($QO
M;VMU<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<R(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3D*
M;7-G:60@(D1A=&4B"FUS9W-T<B`B5&%R:6@B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ,PIM<V=I9"`B1&%T92!296-E:79E9"(*
M;7-G<W1R(")'96QI_B!487)I:&DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#`W"FUS9VED(")$871E('-E;&5C=&EO;B(*;7-G<W1R(")487)I
M:"!39>=I;6DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDR
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,C(*;7-G:60@(D1A>2(*
M;7-G<W1R(")'_&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,S8*;7-G:60@(D1E7VQE=&4@0V]L=6UN(@IM
M<V=S='(@(DM?;VQO;G4@4VEL(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(D%R
M86S]:R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T
M>7!E7VQA;F<N:G,Z,38*;7-G:60@(D1E8VEM86P@;G5M8F5R<R(*;7-G<W1R
M(")/;F1A;/UK('-A>?UL87(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(P"FUS9VED(")$96-R96%S92!);F1E;G0B"FUS
M9W-T<B`B1VER:6YT:7EI($%Z86QT(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HQ.#<@;&EB+W!R969S+G!H<#HQ,3<*;7-G:60@(D1E9F%U
M;'0B"FUS9W-T<B`BUFX@=&%N_6UL_2(*"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C0U"B,Z('1E;7!L871E<R]P<F5F<R]C
M871E9V]R>6UA;F%G96UE;G0N:6YC.C<W"FUS9VED(")$969A=6QT($-O;&]R
M(@IM<V=S='(@(M9N(%1A;OUM;/T@4F5N:R(*"B,Z(&9R86UE=V]R:R])9&5N
M=&ET>2])9&5N=&ET>2YP:'`Z.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB
M"FUS9W-T<B`BUFX@5&%N_6UL_2!+:6UL:6LB"@HC.B!L:6(O0FQO8VLO86-C
M;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D1E9F%U;'0@4VAE;&PB"FUS
M9W-T<B`BUFX@=&%N_6UL_2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS
M,PIM<V=I9"`B1&5F:6YI=&EO;G,B"FUS9W-T<B`B5&%N_6UL87(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C<Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,S(V"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(R(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#,Y"B,Z('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHW,`HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDS('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3$V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3,Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@R"B,Z('1E;7!L871E
M<R]R<&-S=6TO<G!C<W5M+FEN8SHW,R!T96UP;&%T97,O<G!C<W5M+W)P8W-U
M;2YI;F,Z.3@*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]D96QE=&4N:6YC
M.C$P('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,Q"FUS9VED(")$
M96QE=&4B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,R"B,L(&9U>GIY"FUS9VED(")$
M96QE=&4@0V5L;"(*;7-G<W1R(")(_&-R92!3:6PB"@HC.B!A9&UI;B]G<F]U
M<',N<&AP.C$Y.2!A9&UI;B]G<F]U<',N<&AP.C(R-PIM<V=I9"`B1&5L971E
M($=R;W5P(@IM<V=S='(@(D=R=7`@4VEL(@H*(SH@<V5R=FEC97,O<&]R=&%L
M+W-Y;F-M;"YP:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")$96QE=&4@3&]G(@IM
M<V=S='(@(E-A=/UR_2!S:6PB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C<W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`Q"FUS
M9VED(")$96QE=&4@4&5R;6ES<VEO;B(*;7-G<W1R("+=>FEN(%-I;"(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDS"FUS9VED
M(")$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S(@IM<V=S='(@(MUL971I;&5R
M:2!S:6P@=F4@=&5M:7IL92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C96QL(@IM
M<V=S='(@(DC\8W)E(%-I;"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!C;VQU;6XB
M"FUS9W-T<B`B2V]L;VX@4VEL(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B
M"FUS9W-T<B`B5F%R;VQA;B#V=&5K:2!T87-L8?#]('-I;"(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z-#(Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(*;7-G
M<W1R("(G)7,G(&GG:6X@:7II;FQE<FD@<VEL(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HT,C0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B
M+7!E<FUI<W-I;VYS/R(*;7-G<W1R("(G)7,G(&GG:6X@:7II;FQE<B!V92!A
M;'0@:7II;FQE<B!S:6QI;G-I;B!M:3\B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@
M<F]W(@IM<V=S='(@(E-A=/UR_2!S:6PB"@HC.B!T96UP;&%T97,O<')E9G,O
M9&5L971E:61E;G1I='DN:6YC.C$U"FUS9VED(")$96QE=&4@<V5L96-T960@
M:61E;G1I='DB"FUS9W-T<B`B4V7G:6QM:?X@:VEM;&GP:2!S:6PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-C<*;7-G:60@(D1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`B
MWG4@86YD86MI(&MO;&]N=2!S:6PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(D1E;&5T92!T
M:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BWG4@86YD86MI('-A=/UR_2!S:6PB
M"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="!<
M(B5S7"(N(@IM<V=S='(@(DMU<G5L=6T@9_QN8V5L;&5M92!B971I\&D@)R5S
M)R!S:6QI;F1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-38S"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-3DU"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C(R,0HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-3,*;7-G:60@(D1E;&EV97)Y('1I
M;64B"FUS9W-T<B`B5&5S;&EM('IA;6%N_2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z-S$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HV.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-CD*;7-G:60@
M(D1E;FUA<FLB"FUS9W-T<B`B1&%N:6UA<FMA(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z,CD*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B
M;&5M(@IM<V=S='(@(E-O<G5N=2!486[];6QA>?UN(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.3,X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S`*;7-G:60@(D1E<V-R:7!T:6]N(@IM<V=S
M='(@(D'G_6ML86UA(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M.34*;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB
M"FUS9W-T<B`B07ER_6YT_6QA<B`H07EN_2!Z86UA;F1A($AO<F1E)W5N(&?\
M;FS\:R!D;W-Y87/];OUN(&GG:6YD92DZ(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HQ.3D*;7-G:60@(D1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(D%Y<OUN=/UL87(@
M>?9N971I8VD@:>=I;B!G_&YL_&L@;VQA<F%K(&MA>61E9&EL9&DN(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM<V=I9"`B1&5V96QO<&UE
M;G0B"FUS9W-T<B`B1V5L:?YI;2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C$W"FUS9VED(")$97<@4&]I;G0B"FUS9W-T<B`B3F5M($UI:W1A<OTB"@HC
M.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z("(*;7-G<W1R(")3;VX@<V%A='1E:VD@;F5M(&UI:W1A
M<OTZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,C<*;7-G
M:60@(D1E=R!P;VEN=#H@(@IM<V=S='(@(DYE;2!M:6MT87+].B`B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS9VED
M(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R(")3;VQD86X@<V'P
M82!Y]FYL_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,SD*;7-G:60@(D1I<F5C=&EO;B!R:6=H="!T;R!L969T(@IM<V=S
M='(@(E-A\&1A;B!S;VQA('GV;FS\(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP
M:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R(")$:7II;B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HR-C8*;7-G:60@(D1I<W!L87D@,C0M:&]U
M<B!T:6UE<S\B"FUS9W-T<B`B,C0@<V%A=&QI:R!Z86UA;B!M_2!G]G-T97)I
M;'-I;C\B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@(D1I
M<W!L87D@3W!T:6]N<R(*;7-G<W1R(")']G+\;G3\;&5M92!39>=E;F5K;&5R
M:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HY-@HC+"!F=7IZ
M>0IM<V=I9"`B1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S="(*;7-G<W1R(")(
M879A('1A:&UI;FEN:2!G]G+\;G3\;&4@*%1!1BDB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@U"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM
M<V=S='(@(DAA=F$@=&%H;6EN:6YI(&?V<OQN=/QL92`H5$%&*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3<*;7-G:60@(D1I<W!L87D@9F]R
M;6%T(@IM<V=S='(@(D?V<OQN=/QL96UE($)IYVEM:2(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O341.+G!H<#HQ.3`*;7-G:60@(D1I<W!O<VET:6]N($YO
M=&EF:6-A=&EO;B(*;7-G<W1R(")$_'IE;B!":6QD:7)I;6DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Y"FUS9VED(")$:FEB;W5T:2(*;7-G<W1R(")#:6)U=&DB"@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C0R,@IM<V=I9"`B1&\@;F]T(&1E
M;&5T92(*;7-G<W1R(")3:6QM97EI;B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA
M;F-E+G!H<#HR-0IM<V=I9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN
M=&5N86YC92YP:'`B"FUS9W-T<B`B;6%I;G1E;F%N8V4N<&AP(&1O<WEA<_UN
M82!D;_!R=61A;B!E<FG^;65Y:6XN(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3(@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`BW6QK('-A=/UR
M(&%L86X@861L87+];OT@:>=E<FEY;W(@;74_($5V970@:7-E(&)U(&MU='5Y
M=2!S9>=I;CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S`*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C8Y"FUS9VED(")$;VUI;FEC82(*;7-G<W1R
M(")$;VUI;FEK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW,R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<Q"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B1&]M:6YI8V%N(%)E<'5B
M;&EC(@IM<V=S='(@(D1O;6EN:6L@0W5M:'5R:7EE=&DB"@HC.B!T96UP;&%T
M97,O;&]G:6XO;&]G:6XN:6YC.CDV"FUS9VED(")$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O0V]N=&5N=',N<&AP.C@T-`IM<V=I9"`B1&]W;FQO860B"FUS9W-T
M<B`BW6YD:7(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B1&]W;FQO860@)7,B"FUS9W-T
M<B`B)7,@W6YD:7(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,38R"FUS
M9VED(")$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@
M<V-R:7!T+B(*;7-G<W1R(")/;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!0
M2%`@8F5T:?!I(&]L87)A:R!I;F1I<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,3`W"FUS9VED(")$<F]P(&1O=VX@;&ES="(*;7-G<W1R(")!
M_F'P_2!AY_UL_7(@;&ES=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S0*;7-G:60@(D1R=6=S(@IM<V=S='(@(MUL8>=L87(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(D4M36%I;"(*;7-G
M<W1R(")%+5!O<W1A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V=E;F5R
M:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL+71O+5--4R!G871E=V%Y(&1R
M:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF
M:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,T"FUS9VED(")%4E(B"FUS
M9W-T<B`B15)2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW-2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<R"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B16-U861O<B(*;7-G<W1R
M(")%:W9A=&]R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HS,C4@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-0HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C8Y('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3(*
M(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,34@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ,S@*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ.#$@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C<R"B,Z('1E;7!L
M871E<R]P;W)T86PO961I="YI;F,Z,C4*;7-G:60@(D5D:70B"FUS9W-T<B`B
M1/QZ96YL92(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3`@
M=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="!";&]C
M:R(*;7-G<W1R(")";&]K($3\>F5N;&4B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C$Y."!A9&UI;B]G<F]U<',N<&AP.C(R-@IM<V=I9"`B161I="!'<F]U<"(*
M;7-G<W1R(")'<G5P($3\>F5N;&4B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P
M"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BW7II;B!$_'IE;FQE
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PIM<V=I9"`B161I
M="!097)M:7-S:6]N<R(*;7-G<W1R("+=>FEN;&5R:2!$_'IE;FQE(@H*(SH@
M<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S.0HC+"!P:'`M9F]R;6%T"FUS
M9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R#=YVEN
M(-UZ:6YL97)I($3\>F5N;&4B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN
M8SHU"FUS9VED(")%9&ET(&]P=&EO;G,@9F]R.B(*;7-G<W1R(")39>=E;F5K
M;&5R:2!D_'IE;FQE.B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,S8W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI
M<W-I;VYS(&9O<B!<(B5S7"(B"FUS9W-T<B`B)7,@:>=I;B!I>FEN;&5R:2!D
M_'IE;FQE(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")%9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G
M<W1R("(E<R!IYVEN(&EZ:6YL97)I(&3\>F5N;&4B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S4*;7-G:60@(D5D=6-A=&EO;B(*;7-G<W1R(")%\&ET
M:6TB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S,*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.C<P"FUS9VED(")%9WEP="(*;7-G<W1R(")-_7/]<B(*
M"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z,S$P"B,L('!H<"UF;W)M
M870*;7-G:60@(D5I=&AE<B!E;F%B;&4@:70@=&AE;CH@)7,L(&]R('5S92!T
M:&4@8F%S:6,@2%1-3"!V97)S:6]N.B`E<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`W"FUS9VED(")%;"!386QV861O<B(*;7-G<W1R(")%;"!386QV861O
M<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("+6\&4N+BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.0IM<V=I9"`B16TB"FUS9W-T<B`B16TB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(T(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C$X-CD*;7-G:60@(D5M86EL(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S
M=&$B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T
M96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*;7-G:60@(D5M86EL($%D9')E
M<W,B"FUS9W-T<B`B16QE:W1R;VYI:R!0;W-T82!!9')E<VDB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.38S"FUS9VED(")%;6%I;"!A9&1R97-S
M97,@;75S="!M871C:"XB"FUS9W-T<B`B16QE:W1R;VYI:R!P;W-T82!A<W)E
M<VQE<FD@9?YL9?YM96QI+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y.#D*;7-G:60@(D5M86EL('=I=&@@8V]N9FER;6%T:6]N(@IM<V=S='(@
M(D]N87EL_2!E;&5K=')O;FEK('!O<W1A(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3$*;7-G:60@(D5M86EL+71O+5--
M4R!'871E=V%Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR.3@*;7-G:60@(D5M;W1I8V]N<R(*;7-G<W1R
M(")$=7EG=2!S:6UG97)L97)I(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`R"FUS9VED(")%;7!T>2!M97-S86=E
M+B(*;7-G<W1R(")";_X@:6QE=&DN(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R
M;W5P+VQD87`N<&AP.C(T,R!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP
M:'`Z-#@T"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HV-C(@
M9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C<P-0HC.B!F<F%M97=O
M<FLO075T:"]!=71H+VQD87`N<&AP.C$U,`IM<V=I9"`B16UP='D@<F5S=6QT
M+B(*;7-G<W1R(")";_X@<V]N=><N(@H*(SH@9G)A;65W;W)K+U-13"]344PO
M2V5Y=V]R9',N<&AP.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM
M<V=S='(@(D)O_B!A<F%M82!T97)I;6QE<FDB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-30S"FUS9VED(")%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E
M<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/R(*;7-G<W1R("(B"B)&
M;W1O\')A9B!'86QE<FES:6YD96X@;65T:6YL97)I;B!IYV5R:7-I;F4@9_9R
M_&YT_"!E:VQE;64@971K:6YL9?YT:7)I;'-I;B`B"B)M:3\B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-3$X"FUS9VED(")%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/R(*;7-G<W1R(")38?`@=/UK(&GG97)I:R!M96[\
M<_P@971K:6YL9?YT:7)I;'-I;B!M:3\B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-3DX(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,3$*;7-G
M:60@(D5N9"!Y96%R(@IM<V=S='(@(D)I=&G^('G];/TB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Y"FUS9VED(")%;FQA
M<F=E($5D:71O<B(*;7-G<W1R(")$_'IE;FQE>6EC:7EI($=E;FG^;&5T(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W
M:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z(@IM<V=S='(@(B(*(E!A
M<F]L86[]>OT@<_UF_7)L86UA:R!I<W1E9&GP:6YI>F1E('-O<G5L;6%K(/QZ
M97)E(&)I<B!G_'9E;FQI:R!S;W)U<W4@(@HB9VER:6XL(-9R+B`G179C:6P@
M:&%Y=F%N_6[]>OUN(&%D_2!N961I<C\G.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B
M16YT97(@=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(D?V<OQN=/P@861R
M97-I;FD@8G5R87EA(&=I<FEN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C@Y,0IM<V=I9"`B16YT97(@=&AE(&QE='1E<G,@
M8F5L;W<Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D5Q=6%T;W)I
M86P@1W5I;F5A(@IM<V=S='(@(D5K=F%T;W(@1VEN97-I(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW
M,0IM<V=I9"`B17)I=')E82(*;7-G<W1R(")%<FET<F4B"@HC.B!F<F%M97=O
M<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N
M<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED(")%
M<G)O<B(*;7-G<W1R(")(871A(@H*(SH@9G)A;65W;W)K+U1E;7!L871E+U1E
M;7!L871E+G!H<#HT-C,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R
M;65D92!H871A.B`E<RXB"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H
M<#HW,@HC+"!P:'`M9F]R;6%T"FUS9VED(")%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y
M;F-M;"YP:'`Z.#,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R
M;65D92!H871A.B`E<RXB"@HC.B!F<F%M97=O<FLO5&5M<&QA=&4O5&5M<&QA
M=&4N<&AP.C0V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D
M92!H871A.B`E<RXB"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-S8*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D5R<F]R('5P9&%T:6YG
M('!A<W-W;W)D.B`E<R(*;7-G<W1R(")986[]=/T@9_9N9&5R;65D92!H871A
M.B`E<RXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#4*;7-G:60@(D5R<F]R('=I=&@@96UA:6P@;65S<V%G92XB
M"FUS9W-T<B`B16QE=')O;FEK('!O<W1A(&3V;F1E<FUE9&4@:&%T82XB"@HC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T
M4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")%<G)O<B!W<FET:6YG(%PB)7-<(BXB"FUS9W-T<B`B)R5S)R!Y87IA
M<FME;B!H871A+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW-PHC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*;7-G:60@(D5S=&]N:6$B"FUS9W-T
M<B`B17-T;VYY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S
M='(@(D5T:7EO<'EA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,V"FUS
M9VED(")%=&AN:6,B"FUS9W-T<B`B171N:6LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D5U<F]P92(*;7-G<W1R(")!=G)U
M<&$B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,Y"FUS9VED(")%=F5R
M>2`Q-2!M:6YU=&5S(@IM<V=S='(@(DAE<B`Q-2!D86MI:V$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S@Y"FUS9VED(")%=F5R>2`R(&UI;G5T97,B
M"FUS9W-T<B`B2&5R(#(@9&%K:6MA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(DAE<B`S,"!S86YI>64B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,S,X(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M.3`*;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R(")(97(@-2!D86MI
M:V$B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C8P"FUS9VED(")%=F5R>2!,;V=I;B(*;7-G<W1R(")(97(@1VER:?YT92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-#`*;7-G:60@(D5V97)Y(&AA
M;&8@:&]U<B(*;7-G<W1R(")(97(@>6%R_6T@<V%A="(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS,S<@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.`IM
M<V=I9"`B179E<GD@;6EN=71E(@IM<V=S='(@(DAE<B!D86MI:V$B"@HC.B!T
M96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHR-`IM<V=I9"`B17AA;7!L92!V
M86QU97,Z(@IM<V=S='(@(M9R;F5K(&1E\&5R;&5R.B(*"B,Z(&%D;6EN+W!H
M<'-H96QL+G!H<#HX,2!A9&UI;B]C;61S:&5L;"YP:'`Z-3`@861M:6XO<W%L
M<VAE;&PN<&AP.C$R-PIM<V=I9"`B17AE8W5T92(*;7-G<W1R("+'86S]_G3]
M<B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C0W-0IM
M<V=I9"`B17AP86YD(@IM<V=S='(@(D=E;FG^;&5T(@H*(SH@=&5M<&QA=&5S
M+W!O<G1A;"]S:61E8F%R+FEN8SHS,@IM<V=I9"`B17AP86YD(%-I9&5B87(B
M"FUS9W-T<B`B2V5N87(@QW5B=?!U;G4@1V5N:?YL970B"@HC.B!F<F%M97=O
M<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS9VED(")%>'!E8W1E9"`G
M*2<B"FUS9W-T<B`B)RDG($)E:VQE;FEY;W(B"@HC.B!F<F%M97=O<FLO4U%,
M+U-13"]+97EW;W)D<RYP:'`Z,3<U"FUS9VED(")%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M(@IM<V=S='(@(E-A9&4@:V5L:6UE
M('9E>6$@86S];G3](&%R86UA('1E<FEM:2!B96ML96YI>6]R(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$R"FUS9VED(")%>'!I<F%T
M:6]N($1A=&4B"FUS9W-T<B`B1V7G97)L:6QI:R!3;VX@5&%R:6AI(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-S8*;7-G:60@(D5X
M<&]N96YT(@IM<V=S='(@(MQS="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S$*;7-G:60@(D9'($-O;&]R(@IM
M<V=S='(@(M9N($%L86X@4F5N9VDB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,3<W"FUS9VED(")&5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(D%Y
M87)L87(@:>=I;B!&5%`@>?QK;&5M97-I(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-Q;"YP:'`Z,C$V"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RXB"FUS9W-T<B`B5&5R8VEH;&5R:6X@9V5T:6QM97-I(&)A
M_F%R_7/]>BXB"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z
M-S4@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@
M<W5N=6-U<W5N82!B8?!L86YT_2!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]S;6(N<&AP.CDX"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R(")334(@<W5N=6-U<W5N82!B8?!L
M86YT_2!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@9G)O
M;2!<(B5S7"(N(@IM<V=S='(@(EPB)7-<(B!K;VYU;75N9&%N(&MO<'EA;&%M
M82!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV
M.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O<'D@=&\@7"(E
M<UPB+B(*;7-G<W1R(")<(B5S7"(@:V]N=6UU;F$@:V]P>6%L86UA(&)A_F%R
M_7/]>BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-A<VPN<&AP.C@W"FUS
M9VED(")&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN(@IM
M<V=S='(@(EEE;FD@4T%33"!B8?!L86YT_7/](&]L=?YT=7)U;&%M863]+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]6
M1E,O5D93+V9T<"YP:'`Z-S(T"B,L('!H<"UF;W)M870*;7-G:60@(D9A:6QE
M9"!T;R!M;W9E('1O(%PB)7-<(BXB"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA
M('1A_OUM82!B8?YA<OUS_7HN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HT-C$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D9A:6QE9"!T
M;R!R971R:65V93H@)7,B"FUS9W-T<B`B7"(E<UPB(&MO;G5M=6YA('1A_OUM
M82!B8?YA<OUS_7HN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,3@*;7-G:60@(D9A:7(B"FUS9W-T<B`B57EG=6X@2&%V82(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S
M*2(*;7-G<W1R(")&86QK;&%N9"!!9&%L87+]("A-86QV:6YA*2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#8@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HX,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S,*;7-G:60@(D9A<F]E($ES;&%N9',B"FUS9W-T<B`B1F%R;V4@061A
M;&%R_2(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR,S@*;7-G:60@(D9A
M=&%L($5R<F]R.B(*;7-G<W1R(")/;G5L;6%Z($AA=&$Z(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X-PIM<V=I9"`B1F%X
M(@IM<V=S='(@(D9A:W,B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R(")&86MS(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0P"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C8*;7-G:60@
M(D9E8G)U87)Y(@IM<V=S='(@(MYU8F%T(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HR,C`*;7-G:60@(D9E96QS($QI:V4B"FUS9W-T<B`B2&ES<V5D:6QI
M>6]R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S,0IM<V=I
M9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(DAI<W-E9&EL:7EO<CH@(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3D*;7-G:60@
M(D9E=R!3:&]W97)S(@IM<V=S='(@(DAA9FEF(%-A\&%N86LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR,`IM<V=I9"`B1F5W
M(%-N;W<@4VAO=V5R<R(*;7-G<W1R(")(869I9B!+87(@4V'P86YA\/TB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.30T"FUS9VED(")&:65L9"!M
M871R:7@B"FUS9W-T<B`B06QA;B!M871R:7-I(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,S-`IM<V=I9"`B1FEG;&5T($-!4%1#2$$B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S.`IM<V=I9"`B
M1FEG;&5T(&9O;G0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HX,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,@IM<V=I9"`B1FEJ
M:2(*;7-G<W1R(")&:6II(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP
M:'`Z,C4U"B,L(&9U>GIY"FUS9VED(")&:6QE(@IM<V=S='(@(F1O<WEA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV,"!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL92(*;7-G<W1R(")$;W-Y82!387G]
M<_TZ("5S(&1O<WEA(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M<F%R+G!H<#HV,"!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP
M.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z.#(*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B1FEL92!#;W5N=#H@)7,@9FEL97,B"FUS
M9W-T<B`B1&]S>6$@4V%Y_7/].B`E<R!D;W-Y82(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HT,#<*;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R
M(")$;W-Y82!9]FYE=&EC:7-I(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R(")$;W-Y82!!9/TB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3DU"FUS9VED(")&:6QE('-E
M;&5C=&EO;B(*;7-G<W1R(")$;W-Y82!S9>=I;6DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"FUS9VED(")&:6QE('5P;&]A9"(*;7-G<W1R
M(")$;W-Y82!Y_&ML96UE(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B1&]S>6$@>?QK;&5M92!D97-T96ML96YM:7EO<BXB"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.#D*;7-G:60@(D9I;'1E<G,B"FUS
M9W-T<B`B4_QZ9V7G;&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HX,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,0IM<V=I9"`B1FEN;&%N9"(*
M;7-G<W1R(")&:6YL86YD:7EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C$V
M-@IM<V=I9"`B1FER<W0@2&%L9B(*;7-G<W1R("+=;&L@66%R_2(*"B,Z(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-"!L:6(O0FQO8VLO;6]O;BYP:'`Z-S8*;7-G
M:60@(D9I<G-T(%%U87)T97(B"FUS9W-T<B`BW6QK(,=E>7)E:R(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@
M(D9I>"!R871I;R(*;7-G<W1R(")/<F%N_2!S86)I=&QE(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S,0IM<V=I9"`B1FQI
M<"(*;7-G<W1R("+'979I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L;V%T(@IM<V=S='(@
M(DMA>6%N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C$*;7-G:60@(D9O9R(*;7-G<W1R(")3:7,B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(S-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP
M:'`Z,3`W"B,L('!H<"UF;W)M870*;7-G:60@(D9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES="(*;7-G<W1R("(E<R!D:7II;FD@>6]K(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#
M;VQO<B(*;7-G<W1R(")987K](%)E;F=I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C,W"FUS9VED(")&;V]D(@IM<V=S='(@(EEE;65K(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(V"FUS9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<R(*;7-G<W1R(")']G+\;G3\;&5R:2!D97-T96ML96UE>65N('1A<F%Y
M_6/];&%R(&GG:6XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I
M9"`B1F]R96-A<W0@*%1!1BDB"FUS9W-T<B`B5&%H;6EN("A4048I(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E
M8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E
M='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H
M97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*
M(E1A:&UI;B!'_&YL97)I("A.;W0Z($=E<FD@9/9N_&QE8V5K;&5R(&AE;2!G
M_&X@:&5M(&=E8V4@;VQA<F%K(&3V;OQL96-E:SL@*2(*(F+\>?QK(&)I<B!S
M87G](&=E;FG^(&)I<B#V8F5K;&4@<V]N=>=L86YA8V%K=/UR*2(*"B,Z('1E
M;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,3`R"FUS9VED(")&;W)G;W0@>6]U
M<B!P87-S=V]R9#\B"FUS9W-T<B`B4&%R;VQA;OUZ_2!M_2!U;G1T=6YU>C\B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#8R"FUS9VED(")&;W)M
M<R(*;7-G<W1R(")&;W)M;&%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C(Q"FUS9VED(")&;W)T=6YE(@IM<V=S='(@(D1E>6G^(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.CDY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS9W-T
M<B`B1&5Y:?X@=/QR_"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`IM
M<V=I9"`B1F]R='5N97,B"FUS9W-T<B`B1&5Y:?YL97(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS9W-T<B`B
M1&5Y:?YL97(@,B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-3,*
M;7-G:60@(D9O<G5M<R(*;7-G<W1R(")&;W)U;6QA<B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HQ,#D*;7-G:60@(D9O<G=A<F1S(@IM<V=S='(@
M(EGV;FQE;F1I<FUE;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E
M;E]C86QE;F1A<BYJ<SHV,`IM<V=I9"`B1G(B"FUS9W-T<B`B0W4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,S
M"FUS9VED(")&<F%M97,B"FUS9W-T<B`BQV5RYV5V96QE<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-S,*;7-G:60@(D9R86YC92(*;7-G<W1R(")&<F%N<V$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S,*;7-G:60@(D9R86YC92P@365T<F]P
M;VQI=&%N(@IM<V=S='(@(D9R86YS82P@365R=&]P;VQI=&%N(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C@T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-`IM<V=I9"`B1G)E;F-H($=U:6%N82(*;7-G<W1R(")&<F%N<_UZ($=U
M>6%N87/](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX-0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(D9R96YC:"!0;VQY;F5S:6$B
M"FUS9W-T<B`B1G)A;G/]>B!0;VQI;F5Z>6%S_2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM
M<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S(@IM<V=S='(@(D9R
M86YS_7H@1_QN97D@0O9L9V5S:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`B2VEM
M9&5N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T."!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HT,#8*;7-G:60@(D9R;VT@=&AE("(*;7-G<W1R(")+
M:6UD96XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM
M<V=I9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R(")486T@0F5T:6UL96UE
M(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@Q(&QI8B]";&]C:R]M;V]N+G!H
M<#HQ-S8*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R(")$;VQU;F%Y(@H*(SH@
M;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C8Q('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-C`*;7-G:60@(D9U;&P@3F%M92(*;7-G<W1R(")!Y_UK
M($%D(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX."!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW,PIM<V=I9"`B1V%B;VXB"FUS9W-T<B`B1V%B;VXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(D?V<OQN=/QL97)I;B!A;/UN86-A\/T@9V%L97)I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(Y"FUS9VED(")'86QL97)Y.B(*;7-G<W1R(")'86QE<FDZ(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(D=A;6)I>6$B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0R"B,L('!H<"UF;W)M870*;7-G:60@
M(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B)7,@66%P_6QA
M;F3]<FUA<_UN_2!/;'7^='5R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(D]L=?YT=7)U;&%N($MO9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B
M"FUS9W-T<B`B1_QR8VES=&%N(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDP"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1V5R;6%N
M>2(*;7-G<W1R(")!;&UA;GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDQ"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1VAA;F$B
M"FUS9W-T<B`B1V%N82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M.30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*
M;7-G<W1R(")#96)E;&ET87+]:R(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<U"FUS9VED(")':79E;B!.86UE(@IM<V=S='(@(E9E
M<FEL96X@060B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ,@IM<V=I
M9"`B1V\B"FUS9W-T<B`B1VET(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C0P"FUS9VED(")';V5D96PB"FUS9W-T<B`B1V]E9&5L(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,C@*(RP@9G5Z>GD*
M;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@(D=O;V=L92!!<F%M82(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#$*;7-G:60@(D=O;V=L92!396%R
M8V@B"FUS9W-T<B`B1V]O9VQE($%R86UA(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM
M<V=S='(@(E-I>6%H($)E>6%Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=R965C
M92(*;7-G<W1R(")9=6YA;FES=&%N(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*;7-G<W1R(")9=6YA
M;F-A("A)4T\M.#@U.2TW*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S4*;7-G:60@(D=R965N;&%N
M9"(*;7-G<W1R(")'<O9N;&%N9"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z.#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S0*;7-G:60@(D=R96YA
M9&$B"FUS9W-T<B`B1W)E;F%D82(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3<Y
M"FUS9VED(")'<F]U<"!!9&UI;FES=')A=&EO;B(*;7-G<W1R(")'<G5P(%GV
M;F5T:6UI(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H<#HU.2!F<F%M
M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,38Y"FUS9VED(")'<F]U<"!N
M86UE<R!M=7-T(&)E(&YO;BUE;7!T>2(*;7-G<W1R(")'<G5P(&ES:6UL97)I
M(&1O;'4@;VQM86S]9/UR(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD
M87`N<&AP.C,P-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I<R!W:&%T('1H
M92!S97)V97(@<V%I9#H@(@IM<V=S='(@(D%U=&A?:6UA<#H@)7,@:W5L;&%N
M_6/]<_T@96ML96YE;65D:2X@4W5N=6-U.B`B"@HC.B!F<F%M97=O<FLO1W)O
M=7`O1W)O=7`O;&1A<"YP:'`Z,3$X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HQ,C0*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C0Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@
M56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<R(*;7-G<W1R(")!=71H7VQD87`Z
M("5S(&MU;&QA;OUC_7/](&?\;F-E;&QE;F5M961I(@H*(SH@9G)A;65W;W)K
M+T=R;W5P+T=R;W5P+VQD87`N<&AP.C,S."!F<F%M97=O<FLO1W)O=7`O1W)O
M=7`O;&1A<"YP:'`Z,S<Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S(@IM<V=S='(@
M(D%U=&A?;&1A<#H@)7,@:W5L;&%N_6/]<_T@9_QN8V5L;&5N96UE9&DB"@HC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO
M9V]O9VQE+G!H<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W
M-PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@(D=R=7!L87(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.CDX(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<V
M"FUS9VED(")'=6%D96QO=7!E(@IM<V=S='(@(D=U861A;'5P(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#,@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S<*;7-G:60@(D=U86TB"FUS9W-T<B`B1W5A;2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3`R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z.3@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W
M"FUS9VED(")'=6%T96UA;&$B"FUS9W-T<B`B1W5A=&5M86QA(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,@IM<V=I9"`B1W5E<FYS97DB"FUS
M9W-T<B`B1W5E<FYS97DB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(R-B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C@X"FUS9VED(")'
M=65S="!097)M:7-S:6]N<R(*;7-G<W1R(")+;VYU:R#=>FEN;&5R:2(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT-S`*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")+;VYU:R!$969T97)I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HY-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.CDY"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B
M1W5I;F5A(@IM<V=S='(@(D=I;F4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$P-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(D=U
M:6YE82U":7-S874B"FUS9W-T<B`B1W5I;F4@0FES<V%U(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#4@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<X"FUS9VED(")'=7EA;F$B"FUS9W-T<B`B1W5Y86YA(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z.38P"FUS9VED(")(5$U,(@IM<V=S='(@(DA4
M34PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C@U"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O
M(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RXB"FUS9W-T<B`B2%1-3$%R
M96$@<V%T_7)D86MI('-O;B!H_&-R97EI('-I;&UE>6D@<F5D9&5D:7EO<BXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@V"FUS9VED(")(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N(@IM<V=S='(@(DA434Q!
M<F5A(.=I>F5L9V5D96MI('-O;B!K;VQO;G4@<VEL;65Y:2!R961D961I>6]R
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z.#<*;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@
M9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92XB"FUS9W-T<B`B2%1-3$%R
M96$@YVEZ96QG961E:VD@<V]N('-A=/UR_2!S:6QM97EI(')E9&1E9&EY;W(N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]H='1P+G!H<#HQ-3<*;7-G:60@
M(DA45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+B(*;7-G<W1R(")(5%10
M($MI;6QI:R!$96YE=&EM:2!B=6QA;F%M863]+B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`IM
M<V=I9"`B2&%I=&DB"FUS9W-T<B`B2&%I=&DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3,*;7-G:60@(DAA<V@M06QG;W)I=&AM(@IM
M<V=S='(@(DAA<V@@06QG;W)I=&UA<_TB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR,@IM<V=I9"`B2&%Z92(*;7-G<W1R(")(
M869I9B!3:7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY,3D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDS,@IM<V=I9"`B2&5A9&5R(@IM<V=S
M='(@(D)A_FS]:R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L
M97-E="YP:'`Z-C$*(RP@9G5Z>GD*;7-G:60@(DAE861E<G,B"FUS9W-T<B`B
M0F'^;/UK(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R9"!)<VQA;F0@86YD
M($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B2&5A<F0@061A<_T@=F4@36-$
M;VYA;&0@061A;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(S"B,L(&9U>GIY"FUS9VED(")(96%V>2!4+5-T;W)M(@IM
M<V=S='(@(D?V:R!G_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@V"FUS9VED(")(96)R97<@*$E33RTX.#4Y+3@M22DB"FUS
M9W-T<B`BW6)R86YI8V4@*$E33RTX.#4Y+3@M22DB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,T"FUS9VED(")(
M96EG:'0B"FUS9W-T<B`B6?QK<V5K;&EK(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+TAE;'`N<&AP.C$W.2!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L
M<"YP:'`Z,3@V"B,Z('-E<G9I8V5S+VAE;'`O:6YD97@N<&AP.C$W('1E;7!L
M871E<R]H96QP+VEN9&5X+FEN8SHS"FUS9VED(")(96QP(@IM<V=S='(@(EEA
M<F3];2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S$*;7-G:60@(DAE;'`@=7-I;F<@961I=&]R(@IM<V=S='(@(D3\>F5N
M;&5Y:6-I(&MU;&QA<F%K('EA<F3];2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$S-S$*;7-G:60@(DAE;'!E<B(*;7-G<W1R(")987)D_6UC_2(*
M"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*
M;7-G<W1R(")987+]:_QR92(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N
M:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS9VED(")(
M97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S='(@(D1O
M<WEA;OUN(&)A_FQA;F?]8_TZ("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C8Y"FUS9VED(")(:6=H(@IM<V=S='(@(EG\:W-E
M:R(*"B,Z('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z-B!T96UP;&%T97,O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,Z-0IM<V=I9"`B2&]?;64B"FUS9W-T
M<B`B7T%N87-A>69A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M-#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92DB"FUS9W-T<B`B5F%T:6MA;B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92YP:'`Z,34S-0IM<V=I9"`B2&]M92(*;7-G
M<W1R(")!;F%S87EF82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HQ,C(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=F-A<F0N<&AP.C$U-0IM<V=I9"`B2&]M92!!9&1R97-S(@IM<V=S='(@(D5V
M($%D<F5S:2(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B2&]M92!$:7)E8W1O<GDB"FUS9W-T<B`B1&EZ:6XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED
M(")(;VUE(%!H;VYE(@IM<V=S='(@(D5V(%1E;&5F;VYU(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<Y"FUS9VED(")(;VYD=7)A<R(*;7-G<W1R(")(;VYD=7)A<R(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`V(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3`V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW.`IM<V=I9"`B2&]N9R!+;VYG(@IM<V=S='(@(DAO;F<@2V]N9R(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HV-0IM<V=I9"`B2&]R9&4B
M"FUS9W-T<B`B2&]R9&4B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C0T,@HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S(@IM<V=S
M='(@(B(*(DAO<F1E+TMO;&%B.B!"=2!M97-A:B!IYVEN9&4@9V7G97)S:7H@
M)7,@6$U,('9E<FES:2!I;&4@:V%R_OUL8?[];&3].B`E<R(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,CDY"B,L('!H<"UF;W)M870*;7-G:60@
M(DAO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C
M="`E<R(*;7-G<W1R(")(;W)D92]+;VQA8CH@)7,@;F5S;F5S:2!I;&4@:6QG
M:6QI(&)I<B!I;&5T:2!B=6QU;F%M863](@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B
M"FUS9W-T<B`B2&]R9&4O2V]L86(Z("5S('3\<OQN9&4@:&GG(&)I<B!N97-N
M92`E<R!M97-A:OT@:>=I;F1E('EO:RXB"@HC.B!F<F%M97=O<FLO2V]L86(O
M2V]L86(N<&AP.C$R-3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(*;7-G<W1R(")(
M;W)D92]+;VQA8CH@)7,@7"(E<UPB(&)A_F%R_2!I;&4@<VEL:6YD:2(*"B,Z
M(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,C(S"FUS9VED(")(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;B(*;7-G<W1R("(B"B)(;W)D92]+;VQA8CH@
M0OQT_&YL96UE(&UO=&]R=2`G9&]M>&UL)R!02%`@=7IA;G3]<_UN82!I:'1I
M>6'G(&1U>6UA:W1A9/UR(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H
M<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,B"FUS9W-T
M<B`B2&]R9&4O2V]L86(Z("5S(&YE<VYE<VD@:>=I;B!Y96YI(%A-3"!A\&%C
M_2!O;'7^='5R=6QA;?UY;W(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N
M<&AP.C$R-#<*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@7"(E<UPB.B`E<R(*;7-G<W1R(")(;W)D92]+
M;VQA8CH@4VEL:6YE;65D:2`E<R!<(B5S7"(Z("5S(@H*(SH@9G)A;65W;W)K
M+TMO;&%B+TMO;&%B+G!H<#HT-S0*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R
M9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@
M<&%R="!O9B!T>7!E("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B`E<R!T_'+\
M;F1E:VD@:_US_6T@:>=I;B!-24U%($E$(&)U;'5N86UA9/TB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$Q.3,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R!<(B5S
M7"(Z("5S(@IM<V=S='(@(DAO<F1E+TMO;&%B.B!%_FQE;F5M961I("5S(%PB
M)7-<(CH@)7,B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$S,S8*
M(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S(@IM<V=S='(@(E!A>6QA_OUM;&%R(&7^
M;&5N96UE9&DZ("5S(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HS
M-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L86(Z(%5N:VYO=VX@
M<VAA<F4@7"(E<UPB(@IM<V=S='(@(D)I;&EN;65Y96X@<&%Y;&'^_6T@7"(E
M<UPB(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR-`IM<V=I9"`B2&]R:7IO;G1A;"!2=6QE(@IM<V=S='(@(EEA=&%Y(,=I
M>F=I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHX,@IM<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(EEA=&%Y
M('EA<W3]:VQA;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R(")9871A
M>3HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE
M87-E(')E<&]R="$I(@IM<V=S='(@(D)U<F%Y82!N87/];"!G96QD:6YI>C\@
M*$S\=&9E;B!R87!O<B!E9&EN(2DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U"FUS9VED(")(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/R(*;7-G<W1R(")+8><@
M861E="!K;VQO;G4@8FER;&7^=&ER;65K(&ES=&EY;W)S=6YU>C\B"@HC.B!T
M96UP;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@
M9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(DMAYR!A;&%N
M("AK;VQO;BD@=F%R/R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G:60@(DAO=R!M86YY(')O=W,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM<V=S='(@(DMAYR!A9&5T('-A=/UR
M_2!B:7)L9?YT:7)M96L@:7-T:7EO<G-U;G5Z/R(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE=&%R+G!H<#HR,S`*
M;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(DYE;2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y.B`B"FUS9W-T
M<B`B3F5M.B`B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#$*;7-G:60@
M(DAU;6]R:7-T<R(*;7-G<W1R(")-:7IA:.?];&%R(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P
M"FUS9VED(")(=6YG87)Y(@IM<V=S='(@(DUA8V%R:7-T86XB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-S(@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C(S-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0
M(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O
M<W1A(&MU='5S=2!O;'7^='5R=6QA;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W;W)K+T%U=&@O075T:"]C
M>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB
M;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("))34%0('!O<W1A(&MU
M='5S=2!S:6QI;F5M961I.B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W.2!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C0R"B,L('!H<"UF;W)M870*;7-G:60@(DE-05`@;6%I;&)O>"!Q=6]T82!C
M<F5A=&EO;B!F86EL960Z("5S(@IM<V=S='(@(DE-05`@<&]S=&$@:W5T=7-U
M(&MO=&%S_2!O;'7^='5R=6QA;6%D_3H@)7,B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,S$V"FUS9VED("))4"!!9&1R97-S(@IM<V=S='(@(DE0
M($%D<F5S:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:7!B87-I8RYP:'`Z
M-S<*;7-G:60@(DE0($%D9')E<W,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B
M25`@861R97-I(&UE=F-U="!D9?!I;"X@(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]I<&)A<VEC+G!H<#HX.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB"FUS9W-T<B`B25`@061R97-I(&EZ
M:6X@=F5R:6QE;B!#2412(&)L;_!U(&GG:6YD92!D9?!I;"XB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.34*;7-G
M:60@(DE0(&QO8VMD;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`B25`@:VEL:71L
M96UE(&EH;&%L:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R
M92(*;7-G<W1R("+6;E]C97EE(%-A=/UR(%EE<FQE_G1I<B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(P(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX,@IM<V=I9"`B26-E;&%N9"(*;7-G<W1R("+=>FQA;F1A(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G
M<W1R(")3861E8V4@4VEM9V5L97(B"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP
M:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S
M='(@(B5S(&GG:6X@<VEM9V5L97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,S<W"FUS9VED("))8V]N<R!W:71H('1E>'0B"FUS9W-T<B`B365T:6X@
M:6QE(&)I<FQI:W1E('-I;6=E;&5R(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C$Y,`IM<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R(")+:6UL
M:?!I;B!A9/TZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DR"B,L('!H<"UF;W)M870*;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P
M;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O
M=RXB"FUS9W-T<B`B1?!E<B!D;_!R=2!G]G+\;G3\;&5N96UI>6]R<V$L('EE
M;FD@<&5N8V5R961E(&'G;6%K(&GG:6X@=/UK;&%Y_6X@)7,N(@H*(SH@8V]N
M9FEG+W!R969S+G!H<"YD:7-T.C0U-0IM<V=I9"`B(@HB268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@
M=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B)%\&5R($EN=&5R;F5T($5X<&QO
M<F5R(&EL92!S:6UG96QE<FD@9_9R96UI>6]R<V%N_7H@8G4@:W5T=7EU('-E
MYV5R96L@4$Y'("(*(G-A>61A;6S]\/UN_2!K87!A=&UA;OUZ(&=E<F5K:7(N
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$W
M,PIM<V=I9"`B(@HB268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E("(*
M(F1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N(@IM<V=S='(@(B(*(D?V<OQN
M=/QL97)I(&?V<F5M:7EO<B!F86MA="!B=2!M97-A:OT@9_9R96)I;&ER>6]R
M<V%N_7HL('G\:VQE;65K("(*(FES=&5D:?!I;FEZ(&?V<OQN=/P@=&%R87G]
M8_UN_7H@=&%R86;];F1A;B!G]G-T97)I;&5M96UE:W1E9&ER+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(U"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ
M<SHR.`IM<V=I9"`B26UA9V4@4')E=FEE=SHB"FUS9W-T<B`B1_9R_&YT_"#6
M;FEZ;&5M92(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z,S<*;7-G:60@(DEM86=E(%523"(*;7-G<W1R(")']G+\
M;G3\(%523"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N
M<V5L:6UA9V5?;&%N9RYJ<SHR,0IM<V=I9"`B26UA9V4@55),.B(*;7-G<W1R
M(")']G+\;G3\(%523#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,S(*;7-G:60@(DEM86=E(&9R;VT@
M9V%L;&5R>2(*;7-G<W1R(")397)G:61E;B!G]G+\;G3\(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q
M"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(E-E<F=I9&5N
M(&?V<OQN=/PZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V,0IM
M<V=I9"`B26UA9V4@=7!L;V%D(@IM<V=S='(@(D?V<OQN=/P@>?QK;&5M96LB
M"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-PIM<V=I9"`B26UA9V5S(@IM
M<V=S='(@(D?V<OQN=/QL97(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O
M+FEN8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA
M=&5S+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHW"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*
M;7-G<W1R("+=YV5R:2!!:W1A<BP@063];2`E9"(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C$V"B,L('!H<"UF;W)M870*;7-G:60@(DEM<&]R
M=&5D(&9I96QD.B`E<R(*;7-G<W1R("+=YV5R:2!A:W1A<OUL86X@86QA;CH@
M)7,B"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C8U"FUS9VED("))
M;7!O<G1E9"!F:65L9',Z(@IM<V=S='(@(MWG97)I(&%K=&%R_6QA;B!A;&%N
M;&%R.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS,`IM<V=I9"`B26Y?<V5R="!2;W<@069T97(B"FUS9W-T
M<B`B4V]N7W)A>6$@4V%T_7(@16ML92(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S
M<R]#;VUP<F5S<R]Z:7`N<&AP.C$S-0IM<V=I9"`B26YC;W)R96-T(&%C=&EO
M;B!C;V1E(&=I=F5N+B(*;7-G<W1R(")986YL_?X@97EL96T@:V]D=2!G:7)I
M;&1I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T
M<"YP:'`Z-C,R"FUS9VED("));F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+B(*;7-G<W1R(")986YL_?X@:W5L;&%N_6/](&%D_2!V92]V97EA
M('!A<F]L82XB"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HU,0IM
M<V=I9"`B(@HB26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R
M97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R("(*(F%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+B(*;7-G<W1R("(B"B)986YL
M_?X@:W5L;&%N_6/](&%D_2!V97EA(/9T96MI(&%D<F5S+EEE;FED96X@9&5N
M97EI;B!V97EA(&1A:&$@9F%Z;&$@>6%R9/UM("(*(FGG:6X@>?9N971I8VEN
M:7IL92!G]G+\_OQN+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R
M(")':7)I;G1I>6D@07)T=/UR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#D*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("));F1I
M82(*;7-G<W1R(")(:6YD:7-T86XB"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S-`IM
M<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G<W1R(")":7)E>7-E;"!+=6QL
M86[]8_UL87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DEN9&]N97-I82(*;7-G
M<W1R(")%;F1O;F5Z>6$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED("));F9O(@IM<V=S='(@(D)I;&=I(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PIM<V=I9"`B26YF;W)M
M871I;VXB"FUS9W-T<B`B0FEL9VDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S,P"B,L(&9U>GIY"FUS9VED("));F9O<FUA=&EO;B!N;R!L
M;VYG97(@879A:6QA8FQE+B(*;7-G<W1R(")(:>=B:7(@<V7G96YE:R!M979C
M=70@9&7P:6PN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,U"FUS9VED("));G-E<G0@0U]O;'5M;B!!9G1E
M<B(*;7-G<W1R(")3;VYR87EA($MO7VQO;B!%:VQE(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS
M9VED("));G-E<G0@26UA9V4B"FUS9W-T<B`B1_9R_&YT_"!997)L9?YT:7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(W
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`P
M"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BQVEZ96QG92!997)L9?YT
M:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(U"FUS9VED("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`B5V5B($)A\&QA
M;G3]<_T@665R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,T"FUS9VED("));G-E<G0@7T-O;'5M
M;B!"969O<F4B"FUS9W-T<B`BUFYC97EE($MO;&]?;B!%:VQE(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8V
M"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N92(*;7-G<W1R(")996YI(&MO;&]N=2#^=2!A;F1A:VD@:V]L;VYD86X@
M<V]N<F$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8U"FUS9VED("));G-E<G0@82!N97<@
M8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`B665N:2!K
M;VQO;G4@_G4@86YD86MI(&MO;&]N9&%N(/9N8V5Y92!Y97)L9?YT:7(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N
M:G,Z-C(*;7-G:60@(DEN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE(@IM<V=S='(@(EEE;FD@<V%T_7+](/YU(&%N9&%K:2!S873]<F1A
M;B!S;VYR87EA('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,0IM<V=I9"`B26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE(@IM<V=S='(@(EEE;FD@
M<V%T_7+](/YU(&%N9&%K:2!S873]<F1A;B#V;F-E>64@>65R;&7^=&ER(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C<P"FUS9VED("));G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U
M<G)E;G0@;F]D92(*;7-G<W1R(")996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@
M9/SP_&UD96X@<V]N<F%Y82!Y97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-CD*;7-G:60@(DEN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D92(*;7-G
M<W1R(")996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP_&UD96X@]FYC97EE
M('EE<FQE_G1I<B(*"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,34P"FUS9VED
M("));G-E<G0@86QT97)N871E('1E;7!L871E(@IM<V=S='(@(M9T96MI('1A
M<VQA:R!Y97)L9?YT:7(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C,Y
M"FUS9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@
M8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B665N:2!B
M:7(@<&%R86QO>?T@86QA8FEL96-E\&EN:7H@8FER(&5L96MT<F]N:6L@<&]S
M=&$@861R97-I(&=I<FEN.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R="!C96QL(&%F
M=&5R(@IM<V=S='(@(DC\8W)E>6D@<V]N<F%S_6YA('EE<FQE_G1I<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-3D*;7-G:60@(DEN<V5R="!C96QL(&)E9F]R92(*;7-G<W1R(")(_&-R97EI
M(/9N8V5S:6YE('EE<FQE_G1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C0*;7-G:60@(DEN<V5R="!C;VQU
M;6X@869T97(B"FUS9W-T<B`B2V]L;VYU('-O;G)A<_UN82!Y97)L9?YT:7(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C8U"FUS9VED("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R(")+
M;VQO;G4@]FYC97-I;F4@>65R;&7^=&ER(@H*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3`*;7-G:60@(DEN<V5R="!M97-S86=E
M<R(*;7-G<W1R(")-97-A:B!G:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#4*;7-G:60@(DEN<V5R="!P
M87)A9W)A<&@@869T97(B"FUS9W-T<B`B4&%R86=R86;]('-O;G)A<_UN82!Y
M97)L9?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A<&@@8F5F
M;W)E(@IM<V=S='(@(E!A<F%G<F%F_2#V;F-E<VEN92!Y97)L9?YT:7(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C8Y"FUS9VED("));G-E<G0@<F]W(&%F=&5R(@IM<V=S='(@(E-A=/UR_2!S
M;VYR87/];F$@>65R;&7^=&ER(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B
M969O<F4B"FUS9W-T<B`B4V%T_7+](/9N8V5S:6YE('EE<FQE_G1I<B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,S`*;7-G:60@(DEN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CHB"FUS
M9W-T<B`B1_QV96YL:6L@<V]R=7-U;G5N(&-E=F%B_3HB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E
M<G0O36]D:69Y($EM86=E(@IM<V=S='(@(D?V<OQN=/QY_"!997)L9?YT:7(O
M1&7P:?YT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS9W-T<B`B
M0F'P;&%N=/T@665R;&7^=&ER+T1E\&G^=&ER(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*;7-G:60@(DEN<W5F
M9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(@IM<V=S='(@(D1A\/UT_6T@;&ES=&5S:2!G]FYD97)M96L@:>=I;B!Y
M971E<G-I>B!K<F5D:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C8S-0IM<V=I9"`B26YS=69F:6-I96YT(&-R961I
M="XB"FUS9W-T<B`B665T97)S:7H@:W)E9&DB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#<U"FUS9VED("));G1E9V5R(@IM<V=S='(@(E1A;7-A
M>?TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3,S"FUS9VED("))
M;G1E9V5R(&QI<W0B"FUS9W-T<B`B5&%M<V%Y_2!L:7-T97-I(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDW"FUS
M9VED("));G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+B(*;7-G<W1R
M(")'9>=E<G-I>B!51$@N("A+=6QL86[]8_T@5F5R:2!"8?YL_6L@0FEL9VES
M:2DB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C`Q
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C(Q,`HC
M+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!:25`@9&%T82(*;7-G<W1R(")'9>=E
M<G-I>B!U;FEC;V1E('9E<FES:2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N
M<&AP.C,T"FUS9VED("));G9A;&ED(&%P<&QI8V%T:6]N+B(*;7-G<W1R(")'
M9>=E<G-I>B!U>6=U;&%M82XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,3(*;7-G:60@(DEN=F%L:60@8F%T8V@@
M240N(@IM<V=S='(@(D=EYV5R<VEZ('G]\/UN(&MI;6QI\&DN(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,34X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+U1Y<&4O=&%B;&5S970N<&AP.C,W"FUS9VED("));G9A;&ED(&1A=&$@
M<W5B;6ET=&5D+B(*;7-G<W1R(")'9>=E<G-I>B!V97)I(&?V;F1E<FEL9&DN
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`P"FUS9VED("));G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N(@IM
M<V=S='(@(D=EYV5R<VEZ('1E<VQI;2!A9')E<VDB"@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX,0HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#`*(SH@9G)A;65W;W)K+T-O;7!R
M97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(P"FUS9VED("));G9A;&ED(&9I;&4@
M9F]R;6%T(@IM<V=S='(@(D=EYV5R<VEZ(&1O<WEA(&)IYVEM:2(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S<*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@;&EC96YS92!K97DN(@IM<V=S='(@(D=EYV5R<VEZ('5Y9W5L
M86UA+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S$*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@;&]C871I;VX@<')O=FED960N(@IM<V=S
M='(@(D=EYV5R<VEZ('5Y9W5L86UA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-PIM<V=I9"`B26YV86QI9"!M
M<V=?='EP92XB"FUS9W-T<B`B1V7G97)S:7H@;7-G7W1Y<&4B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#,*;7-G
M:60@(DEN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N(@IM<V=S='(@(D=EYV5R
M<VEZ('EA9&$@871L86YM_?X@87!I7VED(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"FUS9VED("));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS9W-T<B`B1V7G97)S:7H@>6%D
M82!A=&QA;FW]_B!D9?!I_G1I<F=E;&5R(@H*(SH@861M:6XO<&5R;7,O861D
M8VAI;&0N<&AP.C(W"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S:6]N
M+B(*;7-G<W1R(")'9>=E<G-I>B#\<W0@:7II;BXB"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3<S"B,L(&9U>GIY"FUS9VED("));G9A;&ED
M('!A<G1N97(@:60N(@IM<V=S='(@(D=EYV5R<VEZ(/QS="!I>FEN+B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S4*(RP@9G5Z>GD*;7-G
M:60@(DEN=F%L:60@<')O9'5C="!C;V1E+B(*;7-G<W1R(")'9>=E<G-I>B!I
M;&5T:?YI;2!K=7)A;&QA<OTB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#8*;7-G:60@(DEN=F%L:60@<')O=&]C
M;VPN(@IM<V=S='(@(D=EYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3,*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HW,2!F<F%M
M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C@P"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(@IM
M<V=S='(@(D=EYV5R<VEZ(&%L_6/].B`G)7,G(@H*(SH@9G)A;65W;W)K+TMO
M;&%B+TMO;&%B+G!H<#HQ,#<V(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3(V,@IM<V=I9"`B26YV86QI9"!S:&%R92!O8FIE8W0B"FUS9W-T<B`B1V7G
M97)S:7H@<&%Y;&'^_6QA;B!N97-N92(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,0IM<V=I9"`B26YV86QI9"!S
M;W5R8V4@861D<F5S<RXB"FUS9W-T<B`B1V7G97)S:7H@:V%Y;F%K(&%D<F5S
M:2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P
M+G!H<#HS,3$*;7-G:60@(DEN=F%L:60@=6YI8V]D92!D871A+B(*;7-G<W1R
M(")'9>=E<G-I>B!U;FEC;V1E('9E<FES:2XB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S4W"FUS9VED("));G9E;G1O<GDB"FUS9W-T<B`B4W1O
M:R(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV
M-SD*(RP@9G5Z>GD*;7-G:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`B
MWF7G:6QI(&]L86YL87+](&ME<R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3$Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$Q
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM<V=I9"`B27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B(*;7-G<W1R("+=<F%N(-US;&%M($-U
M;6AU<FEY971I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3@@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3(*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))<F%Q(@IM<V=S='(@
M(DER86LB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DER96QA;F0B"FUS9W-T<B`B
MW7)L86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS
M9VED("))<VQE(&]F($UA;B(*;7-G<W1R(")-86X@061A($1E=FQE=&DB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR-`IM<V=I
M9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B66%L_73];&W]_B!G]FL@
M9_QR_&QT_&S\(&;]<G3];F$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$Q-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#`*;7-G:60@(DES<F%E
M;"(*;7-G<W1R("+=<W)A:6PB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(L?]:V%R86XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CD*
M;7-G:60@(DET86QI8R(*;7-G<W1R("+==&%L:6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$R,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#(*
M;7-G:60@(DET86QY(@IM<V=S='(@(MUT86QY82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,@IM
M<V=I9"`B2F%M86EC82(*;7-G<W1R(")*86UA:6MA(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#,Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C4*;7-G:60@(DIA;G5A<GDB
M"FUS9W-T<B`B3V-A:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS
M9W-T<B`B2F%P;VYY82(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS
M9VED(")*87!A;F5S92`H25-/+3(P,C(M2E`I(@IM<V=S='(@(DIA<&]N8V$@
M*$E33RTR,#(R+4I0*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,S$P"FUS9VED("(B"B)*879A<V-R:7!T(&AA<R!B965N(&1I<V%B;&5D(&]N
M('EO=7(@8G)O=W-E<B!A;F0@=&AI<R!P86=E(&UA>2!N;W0@8F4@(@HB9&ES
M<&QA>6EN9R!C;W)R96-T;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(R"FUS9VED(")*97)S97DB"FUS9W-T<B`B2F5R
M<V5Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,C0@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")*;W)D86XB"FUS9W-T<B`BW')D
M_&XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#`W"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M,0IM<V=I9"`B2G5L>2(*;7-G<W1R(")496UM=7HB"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G
M<W1R(")(87II<F%N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R(")9
M87-L82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E
M>'1?;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$U"FUS9VED(")*=7-T:69Y($-E;G1E<B(*;7-G<W1R(")/
M<G1A>6$@66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&=6QL(@IM<V=S
M='(@(E1A;6%M96X@66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I9"`B2G5S=&EF>2!,969T
M(@IM<V=S='(@(E-O;&$@66%S;&$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-@IM<V=I9"`B2G5S=&EF>2!2
M:6=H="(*;7-G<W1R(")38?!A(%EA<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@V"FUS9VED
M(")+87IA:VAS=&%N(@IM<V=S='(@(DMA>F%K:7-T86XB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C8T"FUS9VED(")+965P
M(&]R:6=I;F%L/R(*;7-G<W1R("+6>F?\;B!O;&%N('-A:VQA;G/];B!M_3\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R-B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#,*;7-G:60@(DME;GEA(@IM<V=S='(@(DME;GEA(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX-0IM<V=I9"`B2V5R
M8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R
M(")+97)B97)O<R!S=6YU8W4@9&_P<G5L86UA>?T@<F5D9&5T=&DN(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@3F5W8FEE
M<R(*;7-G<W1R("+'96MI<F1E:R!!8V5M:6QE<FDB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!#<F5A=&EO;B(*
M;7-G<W1R(")!;F%H=&%R(%EA<F%T(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z-#$T"FUS9VED(")+97D@1FEN9V5R<')I;G0B"FUS9W-T
M<B`B06YA:'1A<B!087)M86MI>FDB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HT,3(*;7-G:60@(DME>2!,96YG=&@B"FUS9W-T<B`B06YA
M:'1A<B!5>G5N;'7P=2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N
M<&AP.C0Q,0IM<V=I9"`B2V5Y(%1Y<&4B"FUS9W-T<B`B06YA:'1A<B!4:7!I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*;7-G
M:60@(DME>2!5<V%G92(*;7-G<W1R(")!;F%H=&%R($MU;&QA;OUM_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,`IM<V=I9"`B2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(*;7-G
M<W1R(")!Y_UK(&%N86AT87(@<W5N=6-U<W5N9&$@86YA:'1A<B!Z871E;B!V
M87(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0S"FUS9VED(")+:61S
M(@IM<V=S='(@(L=O8W5K;&%R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@T"FUS9VED(")+:7)I
M8F%T:2(*;7-G<W1R(")+:7)I8F%T:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3,R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B
M2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B"FUS9W-T
M<B`B2W5Z97D@2V]R92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-0IM<V=I9"`B2V]R96$L(%)E
M<'5B;&EC(&]F(@IM<V=S='(@(D?\;F5Y($MO<F4B"@HC.B!C;VYF:6<O;FQS
M+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N("A%54,M2U(I(@IM<V=S='(@
M(DMO<F5C92`H975C+4M2*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-@IM<V=I9"`B2W5W86ET
M(@IM<V=S='(@(DMU=F5Y="(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(U"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2WER9WEZ
M<W1A;B(*;7-G<W1R(")+_7)G_7II<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T
M86PO;65N=2YI;F,Z.`IM<V=I9"`B3&%?>6]U="(*;7-G<W1R(")387EF82!?
M1/QZ96YI(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHX,PIM<V=I
M9"`B3&%N9W5A9V4B"FUS9W-T<B`B1&EL(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W"FUS9VED
M("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G<W1R("),
M86\@1&5M;VMR871I8R!(86QK($-U;6AU<FEY971I(@H*(SH@;&EB+T)L;V-K
M+VUO;VXN<&AP.C$V.0IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(E-O;B!$
M]G)D_&XB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-S8*(RP@9G5Z>GD*
M;7-G:60@(DQA<W0@4&%S<W=O<F0@0VAA;F=E(@IM<V=S='(@(E!A<F]L87G]
M('/]9OUR;&$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#8@;&EB+T)L;V-K
M+VUO;VXN<&AP.C@X"FUS9VED("),87-T(%%U87)T97(B"FUS9W-T<B`BWFG^
M:VEN($%Y(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*;7-G:60@(DQA
M<W0@57!D871E9#HB"FUS9W-T<B`B4V]N($?\;F-E;&QE;64Z(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G:60@
M(DQA<W0@;&]G:6XZ("5S(@IM<V=S='(@(E-O;B!':7)I_CH@)7,B"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+G!H<#HW,C$*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(*;7-G<W1R(")3;VX@1VER:?XZ
M("5S(/QZ97)I;F1E;B`E<R(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.C<Q-@IM<V=I9"`B3&%S="!L;V=I;CH@3F5V97(B"FUS9W-T<B`B4V]N($=I
M<FG^.B!!<VQA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#8@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),871V:6$B"FUS9W-T
M<B`B3&5T;VYY82(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I
M9"`B3&%W(@IM<V=S='(@(EEA<V$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C,Y"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-SD*;7-G:60@(DQA>6]U="(*;7-G
M<W1R(")$_'IE;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`B2&GG8FER('/];OUR(&GG:6X@8F_^(&+]<F%K;6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S."!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.#<*;7-G:60@(DQE8F%N;VXB"FUS9W-T<B`B3/QB;F%N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT
M,`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8Y
M"FUS9VED("),969T(@IM<V=S='(@(E-O;"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,Q,3D*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(E-O
M;"!B8?YL_6L@8FEL9VES:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,Q,34*;7-G:60@(DQE9G0@=F%L=65S(@IM<V=S='(@(E-O;&1A:VD@9&7P
M97)L97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$R.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQE<V]T:&\B"FUS9W-T<B`B
M3&5S;W1H;R(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(U-0HC
M+"!F=7IZ>0IM<V=I9"`B3&5V96PB"FUS9W-T<B`B0?YK(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@X"FUS9VED("),:6)E<FEA(@IM<V=S='(@(DQI8F5R>6$B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$S,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#D*;7-G:60@(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B"FUS9W-T<B`B
M3&EB>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI96-H=&5N<W1E:6XB"FUS
M9W-T<B`B3&EE8VAT96YS=&5I;B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C(U"FUS9VED("),:6=H="!$<FEZ>FQE(@IM<V=S
M='(@(L=I<V5L:7EO<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(V"FUS9VED("),:6=H="!286EN(@IM<V=S='(@(DAA9FEF
M(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(W"FUS9VED("),:6=H="!286EN($5A<FQY(@IM<V=S='(@(D5R:V5N
M(%-A871L97)D92!(869I9B!98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HR.`IM<V=I9"`B3&EG:'0@4F%I;B!,871E
M(@IM<V=S='(@(D=EYR!386%T;&5R9&4@2&%F:68@66'P;75R(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,CD*;7-G:60@(DQI
M9VAT(%)A:6X@4VAO=V5R(@IM<V=S='(@(DAA9FEF(%EA\&UU<B!38?!A;F'P
M_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,P
M"FUS9VED("),:6=H="!286EN('=I=&@@5&AU;F1E<B(*;7-G<W1R(")']FL@
M9_QR_&QT_&S\(&AA9FEF('EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C,Q"FUS9VED("),:6=H="!3;F]W(@IM<V=S
M='(@(DAA9FEF($MA<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C,R"FUS9VED("),:6=H="!3;F]W(%-H;W=E<B(*;7-G<W1R
M(")(869I9B!+87(@4V'P86YA\/TB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#4*;7-G:60@(DQI;65R:6-K(@IM<V=S='(@(D[\:W1E;&D@WFEI<B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X,30*;7-G:60@(DQI;FLB
M"FUS9W-T<B`B0F'P;&%N=/TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S
M('1O.B(*;7-G<W1R(")"8?!L86YT_2!N;VMT87/].B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S4*;7-G:60@(DQI;FL@=&AE(&5M86EL(&%D
M9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<B"FUS
M9W-T<B`B1_9R_&YT_&QE<FME;B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YI
M(&]L=?YT=7)M82!S87EF87/];F$@8F'P;&$B"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,3@S"FUS9VED("),:6YK
M<R(*;7-G<W1R(")"8?!L86YT_6QA<B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-@IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S='(@(DQI;G5X(,=E
M<F5Z:2(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C@V"FUS9VED("),:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(B"FUS
M9W-T<B`B3&ES=&5L92`M(&MU;&QA;OUC_2!D:7II;FD@9_9R96)I;&ER(@H*
M(SH@861M:6XO<W%L<VAE;&PN<&AP.C$S,PIM<V=I9"`B3&ES="!$871A8F%S
M97,B"FUS9W-T<B`B5F5R:2!486)A;FQA<OUN_2!,:7-T96QE(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`B66%R9/UM($MO;G5L87+];OT@3&ES=&5L92(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S(*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S
M='(@(L=I>F5L9V5L97)I($QI<W1E;&4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TAE861E<G,N<&AP.C4Y-`IM<V=I9"`B3&ES="U!<F-H:79E(@IM<V=S
M='(@(DQI<W1E;&4M07+^:78B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TAE
M861E<G,N<&AP.C4X.0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(DQI<W1E
M;&4M66%R9/UM(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H
M<#HU.38*;7-G:60@(DQI<W0M260B"FUS9W-T<B`B3&ES=&5L92U)9"(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DR"FUS9VED("),
M:7-T+4]W;F5R(@IM<V=S='(@(DQI<W1E;&4M4V%H:7`B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,PIM<V=I9"`B3&ES="U0;W-T
M(@IM<V=S='(@(DQI<W1E;&4M1_9N9&5R:6QM:?X@UO!E;&5R(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.3$*;7-G:60@(DQI<W0M
M4W5B<V-R:6)E(@IM<V=S='(@(DQI<W1E;&4M4_QR9/QR_&UC_&QE<B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DP"FUS9VED("),
M:7-T+55N<W5B<V-R:6)E(@IM<V=S='(@(DQI<W1E;&4M4_QR9/QR_&UC_"!/
M;&UA>6%N;&%R(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@
M)7,B"FUS9W-T<B`B2W5L;&%N_6/](&QI<W1E;&5M92!S9>=I;&5M97H@:_UL
M_6YD_2XB"@HC.B!A9&UI;B]S97-S:6]N<RYP:'`Z,S4*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(DQI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<R(*;7-G
M<W1R(")+=6QL86[]8_T@;&ES=&5L96UE('-EYVEL96UE>B!K_6S];F3]+B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z,@IM<V=I9"`B
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"XB"FUS9W-T<B`B2W5L;&%N_6/]
M(&QI<W1E;&5M92!S9>=I;&5M97H@:_UL_6YD_2XB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z-#<*;7-G:60@(DQI=&5R871U<F4B"FUS9W-T<B`B161E
M8FEY870B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T-"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#D*;7-G:60@(DQI=&AU86YI82(*;7-G<W1R
M("),:71V86YY82(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM
M86=E<RYP:'`Z.#,*;7-G:60@(DQO861I;F<N+BXB"FUS9W-T<B`B6?QK;&5N
M:7EO<BXN+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,3$*
M;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R(")997)E;"!Z86UA;CHB"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#,*;7-G:60@(DQO8V%L92!A;F0@
M5&EM92(*;7-G<W1R(")997(@=F4@6F%M86XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C4W,2!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-C0*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C(R(&QI8B]";&]C
M:R]M971A<BYP:'`Z-C4*;7-G:60@(DQO8V%T:6]N(@IM<V=S='(@(EEE<B(*
M"B,Z(&QO9VEN+G!H<#HQ-S(@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP
M.C$Y,2!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHS"B,Z('1E;7!L871E
M<R]L;V=I;B]M;V)I;&4N:6YC.C$U('1E;7!L871E<R]L;V=I;B]L;V=I;BYI
M;F,Z.3`*;7-G:60@(DQO9R!I;B(*;7-G<W1R(")':7)I_B(*"B,Z('-E<G9I
M8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G(&]F('!R979I
M;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM<V=S='(@(L?]
M:_W^(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y"B,L(&9U>GIY"FUS
M9VED("),;V=I;B(*;7-G<W1R(")':7)I_B(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#<*;7-G:60@(DQO9VEN(%1A<VMS(@IM<V=S='(@(D=I<FG^
M($?V<F5V;&5R:2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDY-@IM
M<V=I9"`B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P
M87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB"FUS9W-T<B`B2W5L
M;&%N_6/](&%D_2!V97EA('!O<F]L82!D;_!R=2!O;&UA9/WP_2!IYVEN(&=I
M<FG^(&)A_F%R_7/]>B!O;&1U+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N
M<&AP.CDY,@IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R(")':7)I_B!B
M8?YA<OUS_7H@;VQD=2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S8U"FUS9VED("),;VYG('1E>'0B"FUS9W-T<B`B57IU;B!M971I;B(*"B,Z
M(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT.`IM<V=I9"`B3&]V92(*;7-G<W1R
M(")!_FLB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV-PIM<V=I9"`B3&]W(@IM<V=S='(@(D3\_OQK(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,0IM<V=I
M9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*;7-G<W1R(")+_.?\:R!Y=6YA;B!H
M87)F;&5R:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI
M<W1T>7!E7VQA;F<N:G,Z,3D*;7-G:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B
M"FUS9W-T<B`B2_SG_&L@;&%T:6X@:&%R9FQE<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED
M("),;W=E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(DO\Y_QK(')O;6$@<F%K
M86UL87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G(@IM<V=S
M='(@(DS\:W-E;6)U<F<B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-#`P"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HT,S@@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*(SH@
M=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O9&%T
M92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G:60@
M(DU-(@IM<V=S='(@(D%!(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X,0IM<V=I9"`B34]41"(*;7-G<W1R(")-3U1$(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S8*;7-G:60@(DU3+51.148@
M071T86-H;65N="!C;VYT86EN960@;F\@9&%T82XB"FUS9W-T<B`B35,M5$Y%
M1B!%:VD@=F5R:2!IYV5R;65M96MT961I<BXB"@HC.B!F<F%M97=O<FLO3F]T
M:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP.C,W
M"FUS9VED(")-4T<B"FUS9W-T<B`B35-'(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED
M(")-86-A;R(*;7-G<W1R(")-86-A;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F(@IM
M<V=S='(@(DUA:V5D;VYY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,W"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B36%D86=A
M<V-A<B(*;7-G<W1R(")-861A9V%S:V%R(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C0Y"FUS9VED(")-86=I8R(*;7-G<W1R(")"_'G\(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Q"FUS9VED(")-86EL(@IM<V=S='(@
M(E!O<W1A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R,@IM<V=I
M9"`B36%I;"!!9&UI;B(*;7-G<W1R(")0;W-T82!9]FYE=&EC:7-I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C0Q"FUS9VED(")-86ME(&QI;E]K+BXN(@IM<V=S='(@(D)A\&QA7VYT_2!9
M87)A="XN+B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L87=I(@IM<V=S='(@
M(DUA;&%V:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B36%L87ES:6$B"FUS9W-T
M<B`B36%L97IY82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38T
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30P"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM<V=I9"`B36%L9&EV97,B"FUS
M9W-T<B`B36%L9&EV;&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#$*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-86QI(@IM
M<V=S='(@(DUA;&DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T,@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA;'1A(@IM<V=S
M='(@(DUA;'1A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDQ"FUS9VED
M("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S("(*(F%S<V]C:6%T960@
M=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G<W1R("(B"B+6\&5L97)I(&5T
M:6ME=&QE>65C9?!I;FEZ(&MA=&5G;W)I(&QI<W1E<VEN:2!V92!K871E9V]R
M:6QE<FD@(@HB:6QI_FMI;&5N9&ER96-E\&EN:7H@<F5N:VQE<FD@>?9N971I
M;BXB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,3$U,PIM<V=I9"`B36%P,C0@;6%P(@IM<V=S='(@(DUA<#(T(&AA<FET87/]
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$P
M.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q
M-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R(")-87!1=65S="!H87)I
M=&%S_2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$P-0IM<V=I
M9"`B36%P<&EN9W,@<W1O<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`S"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HT-#$*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM<V=I9"`B36%R8V@B"FUS
M9W-T<B`B36%R="(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R(")+96YA
M<B!B;_YL=?!U(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.#@*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<R(*
M;7-G<W1R(")/:W5N;77^+T]K=6YM86W]_B!O;&%R86L@:?YA<F5T;&4B"@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX.0IM<V=I
M9"`B36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W
M97)E9"DB"FUS9W-T<B`B1&GP97(@:6QE=&D@:?YA<F5T;&5R:7EL92!I_F%R
M971L92`H]G)N96LZ(-9N96UL:2]#979A<&QA;FW]_BD@(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3(@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-#,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDQ"FUS9VED(")-87)S:&%L;"!)<VQA;F1S(@IM<V=S='(@(DUA<G-H86QL
M($%D86QA<OTB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U.2!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*;7-G:60@(DUA<G1I;FEQ=64B"FUS
M9W-T<B`B36%R=&EN:6LB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(D7^;&5L96X@
M86QA;FQA<B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38P(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY,PIM<V=I9"`B36%U<FET86YI82(*;7-G
M<W1R(")-;W)I=&%N>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.30*;7-G:60@(DUA=7)I=&EU
M<R(*;7-G<W1R(")-875R:71U<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-0IM<V=I9"`B36%X(&%L;&]W960@
M8W)E9&ET+B(*;7-G<W1R("+=>FEN('9E<FEL96X@96X@>?QK<V5K(&MR961I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C,P.`IM<V=I9"`B36%X(&UE<W-A9V4@<&%R=',@97AC965D960N(@IM
M<V=S='(@(D5N('G\:W-E:R!M97-A:B!P87+G87/]('-A>?US_2!A_OUL9/TN
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,#8*;7-G:60@(DUA>"!T96UP
M(&QA<W0@,C0@:&]U<G,Z("(*;7-G<W1R(")3;VX@,C0@<V%A='1E:VD@96X@
M>?QK<V5K('/]8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Y
M.`IM<V=I9"`B36%X('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B4V]N
M(#8@<V%A='1E:VD@96X@>?QK<V5K('/]8V%K;/UK.B`B"@HC.B!L:6(O87!I
M+G!H<#HX-@IM<V=I9"`B36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C,Y"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R
M(")%;B!Y_&MS96L@=7IU;FQU:R(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#4*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0T,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8Y"FUS9VED(")-87DB"FUS9W-T<B`B36%Y_7,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-PHC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")-87EO='1E(@IM<V=S='(@(DUA>6]T
M=&4B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3`*;7-G:60@(DUE9&EC
M:6YE(@IM<V=S='(@(E3]<"(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O
M961I="YI;F,Z,38*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`BW'EE;&5R(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W.`IM<V=I9"`B365N=2!M;V1E
M.B(*;7-G<W1R(")-96[\($MI<&DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L
M;',B"FUS9W-T<B`B2/QC<F5L97)I(&)I<FQE_G1I<B(*"B,Z(&9R86UE=V]R
M:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP
M:'`Z,S`*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED
M(")-97-S86=E(@IM<V=S='(@(MUL971I(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I
M960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@
M8V]U;&0@;F]T(&)E("(*(G9E<FEF:65D+B(*;7-G<W1R("(B"B+=;&5R:2!B
M8?YA<OUY;&$@9&_P<G5L86YD_2!A;6$@:6UZ86QA>?UC_6[];B!O;F%Y(&)E
M;&=E<VD@9&_P<G5L86YA;6%D_2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*;7-G:60@(DUE<W-A9V4@97AP
M:7)E9"XB"FUS9W-T<B`B365S86K];B!S_')E<VD@8FET=&DN(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-CD*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,#(*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,C(W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(V,`IM<V=I9"`B365S<V%G92!T>7!E(@IM<V=S='(@(DUE<V%J('1I
M<&DB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@(DUE=&%R(%=E
M871H97(B"FUS9W-T<B`B2&%V82!287!O<G4B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI<B!D9?!I
M;"XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$Q,@IM<V=I9"`B(@HB365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G
M9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BXB"FUS9W-T<B`B(@HB2&%V82!R
M87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN($%Y<OUN=/UL87(@
M>?9N971I8VD@:>=I;B!G_&YL_&ML96YD:2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-C4*;7-G:60@(DUE=&%R1$(@:7,@;F]T(&-O;FYE
M8W1E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HV-R!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N
M<&AP.C<T"FUS9VED(")-971H;V0B"FUS9W-T<B`B6?9N=&5M(@H*(SH@9G)A
M;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HX,2!F<F%M97=O<FLO4E!#+U)0
M0R]S;V%P+G!H<#HQ,3<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DUE
M=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B6?9N=&5M("<E
M<R<@=&%N_6UL86YM86W]_B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+W)E<W0N
M<&AP.C@R"B,L('!H<"UF;W)M870*;7-G:60@(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C<T(&QI8B]";&]C:R]M971A<BYP:'`Z-S4*
M;7-G:60@(DUE=')I8R(*;7-G<W1R(")-971R:6LB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$V-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*
M;7-G:60@(DUE>&EC;R(*;7-G<W1R(")-96MS:6MA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HX-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S(*
M;7-G:60@(DUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8B"FUS9W-T
M<B`B36EK<F]N97-Y82(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(D]R
M=&$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T;F5F+G!H<#HS
M.`IM<V=I9"`B36EM92!4>7!E(@IM<V=S='(@(DUI;64@5/QR_"(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S$P"FUS9VED(")-:6X@=&5M<"!L87-T(#(T
M(&AO=7)S.B`B"FUS9W-T<B`B4V]N(#(T('-A871T96MI(&5N(&3\_OQK('/]
M8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I9"`B
M36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B4V]N(#8@<V%A='1E
M:VD@96X@9/S^_&L@<_UC86ML_6LZ("(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`Z-#,Y"FUS9VED(")-:6YI;75M('!A<W-W;W)D(&%G92!H
M87,@;F]T('EE="!E>'!I<F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,S0*;7-G:60@(DUI<G)O<B(*
M;7-G<W1R(")986YS_2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,0IM
M<V=I9"`B36ES8V5L;&%N96]U<R(*;7-G<W1R(")-=6AT96QI9B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C<R"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C(U,`IM
M<V=I9"`B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G
M<W1R(")"=6QU;F%M87EA;B!014%2('!A:V5T:3H@2%144%]297%U97-T+B(*
M"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,34*;7-G:60@(B(*(DUI<W-I
M;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W
M(&EF('EO=2!W86YT('1O('5S92!T:&ES("(*(F%P<&QI8V%T:6]N+B(*;7-G
M<W1R("(B"B)!=&QA;FW]_B!Y87#];&%N9/UR;6$N($)U('5Y9W5L86UA>?T@
M:W5L;&%N;6%K(&ES=&EY;W)S86[]>B!Y87#];&%N9/UR;6%Y_2`B"B+\<F5T
M;65K('IO<G5N9&%S_6[]>BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DUI<W-I;F<@;65S<V%G
M92!)1"XB"FUS9W-T<B`B071L86YM_?X@;65S86H@240N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3@*;7-G
M:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM<V=S
M='(@(D%T;&%N;?W^(&]L86X@9V5R96ML:2!014%2('!A:V5T:2!-86EL+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(Y-`IM<V=I9"`B36ES<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R(")!=&QA
M;FW]_B!O='5R=6UA(&%I="!)1"XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]O<&5N7V-A;&5N9&%R+FIS.C4V"FUS9VED(")-;R(*;7-G<W1R(")0>G0B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-S0*;7-G:60@(DUO8FEL
M92!-86EL(@IM<V=S='(@(D=E>FEC:2!0;W-T82(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8X"FUS9VED(")-;V1E<F%T92(*
M;7-G<W1R(")386MI;B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)A<BYP:'`Z-C8@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H
M<#HW,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X
M"FUS9VED(")-;V1I9FEE9"!$871E(@IM<V=S='(@(D1E\&G^:6T@5&%R:6AI
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4S"FUS9VED(")-;V1I9GD@55),(@IM<V=S='(@(D1E\&G^=&ER
M.E523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C<S
M"FUS9VED(")-;V1U;'5S(@IM<V=S='(@(DUO9"!486)A;OTB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3`*;7-G:60@(DUO;&1O=F$L(%)E<'5B;&EC(&]F(@IM<V=S='(@(DUO
M;&1O=GEA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B
M36]N86-O(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R
M(")-;_!O;&ES=&%N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4Y
M-`IM<V=I9"`B36]N=&@@86YD('EE87(B"FUS9W-T<B`B07D@=F4@>?UL(@H*
M(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-PIM
M<V=I9"`B36]N=&AL>2(*;7-G<W1R(")!>6S]:R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,38Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,34S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-`IM
M<V=I9"`B36]N='-E<G)A="(*;7-G<W1R(")-;VYT<V5R<F%T(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R(")!>2!%=G)E;&5R:2(*"B,Z(&9R86UE
M=V]R:R]&:6QE7T-35B]#4U8N<&AP.C$W,B!F<F%M97=O<FLO1FEL95]#4U8O
M0U-6+G!H<#HR-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B36]R92!F:65L9',@
M9F]U;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-30*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.CDP"FUS9VED(")-;W)O8V-O(@IM<V=S='(@(D9A
M<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C,S
M"FUS9VED(")-;W-T;'D@0VQE87(B"FUS9W-T<B`B1V5N96QL:6ML92!!Y_UK
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S0*
M;7-G:60@(DUO<W1L>2!#;&]U9'DB"FUS9W-T<B`B1V5N96QL:6ML92!"=6QU
M=&QU(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M,S4*;7-G:60@(DUO<W1L>2!3=6YN>2(*;7-G<W1R(")'96YE;&QI:VQE($?\
M;F7^;&DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HU
M,#D*;7-G:60@(DUO=F4@1&]W;B(*;7-G<W1R(")!_F'P_2!48?[](@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"FUS9VED(")-
M;W9E($QE9G0B"FUS9W-T<B`B4V]L82!48?[](@H*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"FUS9VED(")-;W9E(%)I9VAT(@IM
M<V=S='(@(E-A\&$@5&'^_2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R(")9=6MA<OT@
M5&'^_2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HU,C0*;7-G:60@(DUO=F4@9&]W;B(*;7-G<W1R(")!_F'P_2!T8?[](@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4R,PHC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3(T"FUS
M9VED(")-;W9E('5P(@IM<V=S='(@(EEU:V%R_2!T8?[](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDU"FUS9VED(")-;WIA;6)I<75E(@IM<V=S='(@(DUO>F%M8FEK(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-`IM<V=I9"`B375L=&DM;&5V
M96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@(L=O:VQU(&3\>F5Y(&'^8?#]
M(&'G_6S]<B!L:7-T96QE<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HQ,#4U"FUS9VED(")-=6QT:6UA<"!52R!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T,@IM<V=I
M9"`B375L=&EP;&4@<V5L96-T:6]N(@IM<V=S='(@(L=O:VQU(%-EYVEM(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0P,`IM<V=I9"`B37D@06-C
M;W5N="(*;7-G<W1R(")(97-A8OUM(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN9F]R;6%T:6]N
M(@IM<V=S='(@(D)I;&=I;&5R:6YI>B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]I
M;F1E>"YP:'`Z-30*;7-G:60@(DUY(%!O<G1A;"(*;7-G<W1R(")0;W)T86S]
M;2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,S8*;7-G:60@(DUY
M(%!O<G1A;"!,87EO=70B"FUS9W-T<B`B4&]R=&%L($3\>F5N:6TB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.3(*;7-G:60@(DUY86YM87(B"FUS9W-T<B`B37EA;FUA<B(*"B,Z
M('1E;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS
M9VED(").3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`B2V%B=6P@151-25E/
M4E5-(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z,S@*;7-G:60@(DYA
M;64B"FUS9W-T<B`B060B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$V.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.34*;7-G:60@(DYA;6EB:6$B
M"FUS9W-T<B`B3F%M:6)Y82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3<X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34X"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3F%U<G4B
M"FUS9W-T<B`B3F%U<G4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$W-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G:60@(DYE<&%L(@IM
M<V=S='(@(DYE<&%L(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C`*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").971H97)L86YD
M<R(*;7-G<W1R(")(;VQL86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4W"FUS9VED(").971H
M97)L86YD<R!!;G1I;&QE<R(*;7-G<W1R(")(;VQL86YD82!!;G1I;&QE<FDB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,0IM<V=I
M9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B3F5T<V-A<&4@5&%B86X@
M55),(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*
M;7-G:60@(DYE='-C87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(DYE
M='-C87!E($-!(-UP=&%L(%523"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#02!P;VQI8WD@55),
M(@IM<V=S='(@(DYE='-C87!E($-!(&MU<F%L(%523"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!2
M96YE=V%L(%523"(*;7-G<W1R(").971S8V%P92!996YI;&5M92!23"(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@R"FUS9VED(").
M971S8V%P92!2979O8V%T:6]N(%523"(*;7-G<W1R(").971S8V%P92#=<'1A
M;"!54DPB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M-@IM<V=I9"`B3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE(@IM<V=S='(@(DYE
M='-C87!E(%-33"!S=6YU8W4@863](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU.#<*;7-G:60@(DYE='-C87!E(&-E<G1I9FEC871E
M(&-O;6UE;G0B"FUS9W-T<B`B3F5T<V-A<&4@;VYA>2!B96QG97-I(&'G_6ML
M86UA<_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,`IM<V=I9"`B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R(").
M971S8V%P92!O;F%Y(&)E;&=E<VD@=/QR_"(*"B,Z(&-O;F9I9R]R96=I<W1R
M>2YP:'`N9&ES=#HR-3$*;7-G:60@(DYE='=O<FLB"FUS9W-T<B`B0?`B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C4@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-0HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@V
M"FUS9VED(").979E<B(*;7-G<W1R(")!<VQA(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ-S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HQ-C(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS
M9VED(").97<@0V%L961O;FEA(@IM<V=S='(@(EEE;FD@2V%L961O;GEA(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z
M-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z
M,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R(")996YI($MA=&5G;W)I
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP
M.C@Q"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H
M<#HX-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP
M:'`Z.3<*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N
M<&AP.C$P,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B3F5W($UE<W-A
M9V4@=&\@)7,B"FUS9W-T<B`BW6QE=&D@3VQU_G1U<B`H)7,I(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O
M0FQO8VLO;6]O;BYP:'`Z,3<T"FUS9VED(").97<@36]O;B(*;7-G<W1R(")9
M96YI($%Y(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS
M-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T<B`B665N
M:2!+=6QL86[]8_T@063]("A39>=I;6QI*2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3@P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.`IM<V=I
M9"`B3F5W(%IE86QA;F0B"FUS9W-T<B`B665N:2!:96QL86YD82(*"B,Z('-E
M<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B
M3F5W('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<W%L+G!H<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@
M(DYE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N(@IM<V=S='(@(E!A<F]L86QA
M<B!E_FQE_FUE:R!Z;W)U;F1A9/UR+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3$*;7-G:60@(DYE=R!W:6YD;W<@*%]B
M;&%N:RDB"FUS9W-T<B`B665N:2!096YC97)E("A?8F_^*2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C0P(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Y"FUS9VED(").97=S(@IM
M<V=S='(@(DAA8F5R;&5R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,P-0IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R(")(86)E<B!'<G5P;&%R
M_2(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC.C$U('1E;7!L871E
M<R]D871A+V1A=&5M87`N:6YC.C0Q"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z,3(Y('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(U"FUS9VED
M(").97AT(@IM<V=S='(@(E-O;G)A:VDB"@HC.B!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,C<*(RP@9G5Z>GD*;7-G:60@(DYE>'0@-"!0:&%S97,B"FUS9W-T<B`B
M4V]N<F%K:2!%=G)E(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H
M<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS-S8*;7-G:60@
M(DYE>'0@;W!T:6]N<R(*;7-G<W1R(")3;VYR86MI(%-EYV5N96ML97(B"@HC
M.B!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP.C$P,PHC+"!F=7IZ>0IM<V=I
M9"`B3F5X=#XB"FUS9W-T<B`B4V]N<F%K:2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,38T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I
M9"`B3FEC87)A9W5A(@IM<V=S='(@(DYI:V%R86=U82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97(B"FUS9W-T<B`B3FEJ97)Y82(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-@IM<V=I9"`B3FEG97)I82(*;7-G<W1R(").:6IE<GEA(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C,X,`IM<V=I9"`B3FEG:'0B"FUS9W-T
M<B`B1V5C92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PIM<V=I9"`B3FEU92(*;7-G<W1R(").
M:75E(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`B2&%Y_7(B"@HC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O9&EF9BYH=&UL.CD*;7-G:60@(DYO(&%V86EL86)L92!C
M;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N(@IM
M<V=S='(@(D9A<FML87+];B!G]G-T97)I;&5B:6QE8V7P:2!K=6QL86[];&%B
M:6QI<B!Y87#];&%N9/UR;6$@=F5R:7-I('EO:RXB"@HC.B!F<F%M97=O<FLO
M5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C$P-0IM<V=I9"`B3F\@879A
M:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T
M<B`B25-/(&EM86IL87+](&]U_G1U<FUA:R!IYVEN(&MU;&QA;OUL86)I;&ER
M(&)I<B!Y]FYT96T@>6]K+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,PIM<V=I9"`B3F\@8F%T8V@@=&5M<&QA
M=&4N(@IM<V=S='(@(EG]\/UN('1A<VQA\/T@>6]K+B(*"B,Z(&9R86UE=V]R
M:R]";&]C:R]";&]C:R],87EO=70N<&AP.C<Y(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C(T-0HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HR-C<*;7-G:60@(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@
M<F5Q=65S=&5D('!O<VET:6]N(@IM<V=S='(@(MUS=&5N96X@:V]N=6UD82!H
M:>=B:7(@]F)E:R!B=6QU;FUA;6%K=&%D_7(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VUC86PN<&AP.C4P"FUS9VED(").;R!C86QE;F1A<B!N86UE('!R
M;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")-0T%,
M(&1O\')U;&%M87/](&GG:6X@:&GG8FER('1A:W9I;2!A9/T@<V'P;&%N;6%M
M_?YT_7(N("(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4T"FUS9VED(").
M;R!C:&%N9V4N(@IM<V=S='(@(D1E\&G^:6ML:6L@66]K(@H*(SH@9G)A;65W
M;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-38*;7-G:60@(DYO(&-H:6QD<F5N
M(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN(@IM<V=S='(@(D)U
M(&EZ;F4@:&GG8FER(&%L="!I>FEN(&5K;&5N96UE>65C96MT:7(N(@H*(SH@
M9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C<@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+G!H<#HU,#(*(SH@9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S<S
M"B,L('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B)7,@:>=I;B!H:>=B
M:7(@>6%P_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS
M9W-T<B`B1E10(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES
M:2!B96QI<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H
M<#HV-CD*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!344P@5D93+B(*;7-G<W1R(")344P@5D93(&GG:6X@:&GG
M8FER('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D:2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S$W"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+B(*;7-G<W1R(")344PM1FEL92!61E,@:>=I;B!H:>=B:7(@>6%P
M_6QA;F3]<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,Q-`IM<V=I9"`B
M3F\@8W)E9&ET(&QE9G0N(@IM<V=S='(@(DMR961I('EO:RXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`IM<V=I
M9"`B3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(DAIYV)I<B!T
M97-L:6T@;F]K=&%S_2!B96QI<G1I;&UE;6G^=&ER+B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@W-PIM<V=I9"`B3F\@9FEL92!U<&QO
M861E9"(*;7-G<W1R(")(:>=B:7(@9&]S>6$@>?QK;&5N96UE9&DB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS(&9O=6YD
M+B(*;7-G<W1R(")(:>=B:7(@<VEM9V4@8G5L=6YA;6%D_2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3(X(&QI8B]";&]C:R]S=6YR:7-E
M+G!H<#HT,`HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C$R,PIM<V=I9"`B3F\@
M;&]C871I;VX@:7,@<V5T+B(*;7-G<W1R(")(:>=B:7(@>65R(&)E;&ER=&EL
M;65D:2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Y"B,L
M(&9U>GIY"FUS9VED(").;R!L;V-A=&EO;B!P<F]V:61E9"XB"FUS9W-T<B`B
M2&GG8FER('EE<B!B96QI<G1I;&UE9&DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S,*;7-G:60@(DYO(&UE<W-A
M9V4@<W5P<&QI960N(@IM<V=S='(@(DAIYV)I<B!M97-A:B!S8?!L86YM863]
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-C,V"FUS9VED(").;R!N86UE('-P96-I9FEE9"XB"FUS9W-T<B`B060@
M8F5L:7)T:6QM961I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,W"FUS9VED(").;R!N=6UB97(@<W!E8VEF:65D
M+B(*;7-G<W1R(").=6UA<F$@8F5L:7)T:6QM961I+B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HY-`IM<V=I9"`B3F\@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(E-A;&3]<F=A;B!D97EI_B!K=6QL86YM82(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O:'1T<"YP:'`Z.3$*;7-G:60@(DYO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")(
M5%10(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P.`IM<V=I9"`B3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN(@IM<V=S
M='(@(DE-05`@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-S(*;7-G:60@(DYO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B2V5R8F5R;W,@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@
M9VER:6QM961I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<V%S;"YP:'`Z
M-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"FUS9VED(").;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN(@IM<V=S='(@(DQO
M9VEN(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2XB"@HC.B!F
M<F%M97=O<FLO075T:"]!=71H+W!A<W-W9"YP:'`Z,3,U"FUS9VED(").;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+B(*
M;7-G<W1R(")005-35T0@9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM
M961I+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<VUB+G!H<#HX-`IM<V=I
M9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO
M;BXB"FUS9W-T<B`B4TU"(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL
M;65D:2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R
M.#8*;7-G:60@(B(*(DYO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R
M;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O("(*
M(G=O<FL@=VET:"!02T-3(#$R(&1A=&$N(@IM<V=S='(@(B(*(D]P96Y34TP@
M:6MI;&ES:6YE(&AIYV)I<B!Y;VP@8G5L=6YA;6%D_2Y/<&5N4U-,(&EK:6QI
M<VD@4$M#4R`Q,B!V97)I<VEY;&4@(@HB8V%L_?YM86L@:>=I;B!G97)E:VQI
M+B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C8*;7-G
M:60@(DYO('!E;F1I;F<@<VEG;G5P<RXB"FUS9W-T<B`BW'EE(&]L;6%K(&GG
M:6X@8F5K;&5Y96X@>6]K+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HW
M-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U;W1A('-E="XB
M"FUS9W-T<B`B0F5L:7)T:6QM96UI_B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#,*;7-G:60@(DYO(')U;&5S
M(@IM<V=S='(@(DMU<F%L('EO:R(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A=&]R('-P96-I
M9FEE9"XB"FUS9W-T<B`B3G5M87)A(&)E;&ER=&EL;65D:2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T"FUS
M9VED(").;R!S:61E<R(*;7-G<W1R(")986X@>6]K(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HU.#,*(RP@9G5Z>GD*;7-G:60@(DYO('-U8V@@
M9FEL92(*;7-G<W1R(")986X@>6]K(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$S.`IM<V=I9"`B3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A
M=F%I;&%B;&4@9F]R(&-A8VAE+B(*;7-G<W1R("+6;F)E;&QE:R!IYVEN(&=E
MYVEC:2!D:7II;B!B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"FUS9VED(").;R!U<V5R;F%M92!A
M;F0O;W(@<&%S<W=O<F0@<V5N="XB"FUS9W-T<B`B2W5L;&%N_6/](&%D_2!V
M92]V97EA('!A<F]L82!G]FYD97)I;&UE9&DN(@H*(SH@9G)A;65W;W)K+U)0
M0R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D(@IM<V=S='(@(D=EYV5R;&D@6$U,('9E<FES:2!G97)I(&3V
M;FUE9&DN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.CDW,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z.3@Q"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HY.3(*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C$P,#D*;7-G:60@(DYO('9A;'5E<R(*;7-G<W1R(")$9?!E<B!Y;VLB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(P"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BUGIG_&X@>6%P_6QA;F3]<FUA9&$@
M<_QR_&T@8G5L=6YA;6%D_2Y987#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C@*;7-G:60@(DYO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(M9Z9_QN('EA</UL86YD_7)M86[]
M>F1A('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]<FUA>?T@=&5K<F%R(/QR
M971I;BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHT-0HC.B!T96UP;&%T97,O<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS
M"FUS9VED(").;VYE(@IM<V=S='(@(DAIYV)I<FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU
M<V4@:6UP;&EC:70I(@IM<V=S='(@(DAIYV)I<FD@*-9R=/QL_"!K=6QL86[]
M;BDB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.0IM<V=I9"`B3F]R9&EC
M("A)4T\M.#@U.2TQ,"DB"FUS9W-T<B`B2W5Z97D@079R=7!A;/T@*$E33RTX
M.#4Y+3$P*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HY-@IM<V=I9"`B3F]R9F]L:R!)<VQA;F0B
M"FUS9W-T<B`B3F]R9F]L:R!!9&%S_2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H
M<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE
M;6ES<&AE<F4B"FUS9W-T<B`B2W5Z97D@66%R_6UK_')E(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.CDS"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B
M2W5Z97D@36%R:6%N82!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDW"FUS9VED(").
M;W)W87DB"FUS9W-T<B`B3F]R=F7G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV-#`*;7-G:60@(DYO="!!9G1E<B(*;7-G<W1R(")3
M;VYR87/];F1A($1E\&EL(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV,SD*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`BUFYC97-I
M;F1E($1E\&EL(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z-#`X
M"FUS9VED(").;W0@82!D:7)E8W1O<GDB"FUS9W-T<B`B1&EZ:6X@9&7P:6PB
M"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(N<&AP.C8S
M"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L3W5T
M<'5T4W1R871E9WDN<&AP.C@S"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.CDT"B,Z(&9R86UE
M=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G
M>2YP:'`Z-#@*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R
M+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HU.0IM<V=I9"`B3F]T(&EM<&QE;65N
M=&5D+B(*;7-G<W1R(")'97+G96ML9?YT:7)I;&UE;6G^(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T
M('-E="(*;7-G<W1R(")"96QI<G1I;&UE;6G^(@H*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ
M-S,*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R
M+G!H<#HQ.#<*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(
M86YD;&5R+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S$R(&9R86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R
M"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]6
M1E,N<&AP.C4W,`HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE
M=V]R:R]61E,O5D93+G!H<#HV-C4*;7-G:60@(DYO="!S=7!P;W)T960N(@IM
M<V=S='(@(D1E<W1E:VQE;FUI>6]R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M3F]T97,B"FUS9W-T<B`B3F]T;&%R(@H*(SH@<V5R=FEC97,O;V)R;W=S97(O
M:6YD97@N<&AP.C,V"FUS9VED(").;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RXB"FUS9W-T<B`B1_9Z(&%T_6QA8V%K(&)I<OYE>2!Y;VLL(&=E<FD@9/9N
M_&XN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q,0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#0Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-S4*;7-G:60@(DYO=F5M8F5R(@IM<V=S='(@(DMA<_UM(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@IM<V=I9"`B3G5M8F5R(@IM<V=S='(@
M(E-A>?TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(U"FUS9VED
M(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R(")+87)A:W1E<B!S87G]
M<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Y(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$T,C,*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,30T-2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T<B`B2V]L;VX@
M<V%Y_7/](@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,V-R!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T-#,@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#(*;7-G:60@(DYU;6)E<B!O9B!R;W=S(@IM<V=S='(@(E-A=/UR
M('-A>?US_2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?
M:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")$8?#]
M=/UM(&QI<W1E;&5R:6YI;B!G_&YC96QL96YM97-I(&GG:6X@;G5M87)A;&%R
M(&)E;&ER=&EL;65M:?XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHT-@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C8T"FUS9VED(")/2R(*;7-G<W1R(")%=F5T(@H*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W,PIM<V=I
M9"`B3V)J96-T(@IM<V=S='(@(DYE<VYE(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ,3$*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@
M(DYE<VYE(%EA<F%T_6/]<_TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3`T"FUS9VED(")/8W1A;"(*;7-G<W1R(")396MI>FQI:R!3:7-T96TB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$P
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#@*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW-`IM
M<V=I9"`B3V-T;V)E<B(*;7-G<W1R(")%:VEM(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I;'1E<B(*;7-G<W1R(")3
M86QD_7)G86YL_6L@<_QZ9V5C:2(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HS,C8*;7-G:60@(D]F9FEC92(*;7-G<W1R(")/9FES(@H*(SH@<V5R
M=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C4X"FUS9VED(")/;&0@86YD(&YE
M=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N(@IM<V=S='(@(B(*"B,Z
M('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS-@HC+"!F=7IZ>0IM<V=I
M9"`B3VQD('!A<W-W;W)D(@IM<V=S='(@(E!A<F]L82(*"B,Z('-E<G9I8V5S
M+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3VQD('!A
M<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G<W1R(")986YL_?X@<&%R;VQA
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W;W)K+TY,4R].
M3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@(E5M;6%N(@H*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z-S,*;7-G
M:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N
M(@IM<V=S='(@(E-A9&5C92!)34%0('-U;G5C=6QA<OT@<&%Y;&'^_6QA;B!D
M:7II;FQE<FD@9&5S=&5K;&5M96MT961I<BXB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM
M<V=S='(@(E-A9&5C92!S86QD_7)G86X@9&5Y:?YL97(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S$*;7-G:60@(D]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"XB
M"FUS9W-T<B`B4V%D96-E(&)I<B!E;&5K=')O;FEK('!O<W1A(&%D<F5S:6YE
M(&EZ:6X@=F5R:6QM96MT961I<BXB"@HC.B!S97)V:6-E<R]S:&%R97,O961I
M="YP:'`Z-C4*;7-G:60@(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A
M9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*
M(G!E<FUI<W-I;VYS(&9O<B!A('-H87)E(@IM<V=S='(@(B(*(D)I<B!P87EL
M8?[];?UN('-A:&EP;&GP:6YI('9E>6$@<V%H:6)I;FD@<V%D96-E('-I<WEE
M;2!Y]FYE=&EC:7-I('9E>6$@(@HB<V%H:6)I(&1E\&G^=&ER96)I;&ER+B(*
M"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"FUS9VED(")/<&5N(&EN(&$@
M;F5W('=I;F1O=R(*;7-G<W1R(")996YI('!E;F-E<F5D92!AYR(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+B(*;7-G<W1R(")/<&5N4U-,(&AA=&%S_3K=;7IA;&%N
M;?W^(%,O34E-12!P87+G87/];F1A;B!V97)I('-EYVEP(.?]:V%T_6QA;6%D
M_2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`B0G4@8F'P;&%N=/UY_2!Y96YI('!E;F-E<F5D92!A
MYR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E<F%T
M:6YG(%-Y<W1E;2(*;7-G<W1R("+=_FQE=&EM(%-I<W1E;6DB"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,34Q"FUS9VED(")/<'1I;VYS(@IM
M<V=S='(@(E-EYV5N96ML97(B"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z,S$@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,30*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`B)7,@:>=I;B!S9>=E;F5K;&5R
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ
M.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(E/]<F%L86YM_?X@3&ES
M=&4B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(DMU<G5L=?XB"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`IM<V=I9"`B3W)G86YI
M<V%T:6]N86P@56YI="(*;7-G<W1R(")+=7)U;7-A;"!":7)I;2(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,S(*;7-G:60@(D]R9V%N:7II;F<B
M"FUS9W-T<B`B1/QZ96YL96UE(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E(@IM<V=S
M='(@(M9Z9_QN('5Y9W5L86UA('1A<VQA\/TB"@HC.B!A9&UI;B]T96UP;&%T
M97,N<&AP.C$Q-PHC+"!P:'`M9F]R;6%T"FUS9VED(")/<FEG:6YA;"!T96UP
M;&%T97,@:6X@)7,Z(@IM<V=S='(@(B5S(&GG:6YD96MI(/9Z9_QN('1A<VQA
M:VQA<CHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Y('-E
M<G9I8V5S+VME>6)O87)D+G!H<#HQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-`IM<V=I9"`B3W1H97(B"FUS9W-T<B`B
M1&GP97(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.38@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$S
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,30Q"FUS9VED(")/
M=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R(")$:?!E<B!":6QG:6QE<B(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,S$*;7-G:60@(D]W;F5R(%!E
M<FUI<W-I;VYS(@IM<V=S='(@(E-A:&EP(&EZ:6YL97)I(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]P86TN<&AP.C<Y"FUS9VED(")004T@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B4$%-(&1O\')U;&%M
M87/](&UE=F-U="!D9?!I;"XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M9V5N97)I8U]S;71P+G!H<#HQ,#4*;7-G:60@(E!%05(Z.DUA:6P@8F%C:V5N
M9"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H
M<#HQ,C<S"FUS9VED(")01U`@1&EG:71A;"!3:6=N871U<F4B"FUS9W-T<B`B
M4$=0(%-A>?US86P@W6UZ82(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G<W1R
M(")01U`@WFEF<F5L96YM:?X@5F5R:2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C$S-S$*;7-G:60@(E!'4"!0=6)L:6,@2V5Y(@IM<V=S
M='(@(E!'4"!!Y_UK($%N86AT87+](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W!G<"YP:'`Z,3,U,PIM<V=I9"`B4$=0(%-I9VYE9"]%;F-R>7!T960@
M1&%T82(*;7-G<W1R(")01U`@:6QE(-UM>F%L86YM_?XOWFEF<F5L96YM:?X@
M5F5R:2(*"B,Z(&%D;6EN+W!H<'-H96QL+G!H<#HV.`IM<V=I9"`B4$A0($-O
M9&4B"FUS9W-T<B`B4$A0($MO9'4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z
M,C`*;7-G:60@(E!(4"!3:&5L;"(*;7-G<W1R(")02%`@2V%B=?!U(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S<*;7-G:60@
M(E!-($QI9VAT(%)A:6XB"FUS9W-T<B`BUE,@2&%F:68@66'P;75R(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,S@*;7-G:60@
M(E!-(%-H;W=E<G,B"FUS9W-T<B`BUE,@4V'P86YA:VQA<OTB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B4$T@
M4VYO=R(*;7-G<W1R("+64R!+87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM
M<V=S='(@(M93($MA<B!38?!A;F%K;&%R_2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0Q"B,L(&9U>GIY"FUS9VED(")032!3
M=6XB"FUS9W-T<B`BUE,@2V%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS(@IM<V=S='(@
M(M93($?V:R!G_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HR-S0*;7-G:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG
M(@IM<V=S='(@(B(*"B,Z(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3
M:&5L;"(*;7-G<W1R(")07TA0($MA8G7P=2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#8*;7-G:60@(E!A9&1I
M;F<B"FUS9W-T<B`B66%S=/UK;&%M82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,3@W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY.0IM<V=I9"`B
M4&%K:7-T86XB"FUS9W-T<B`B4&%K:7-T86XB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$Y-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Q"FUS
M9VED(")086QA=2(*;7-G<W1R(")086QA=2(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DR(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3<T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G
M:60@(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B
MW?YG86P@161I;&UI_B!&:6QI<W1I;B!"]FQG97-I(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"FUS9VED(")086YA;6$B"FUS9W-T<B`B4&%N86UA(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY
M"FUS9VED(")087!U82!.97<@1W5I;F5A(@IM<V=S='(@(E!A<'5A(%EE;FD@
M1VEN92(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DU(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<W"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E!A<F%G=6%Y(@IM<V=S='(@
M(E!A<F%G=6%Y(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z,S8*;7-G:60@(E!A<G1L>2!#;&]U9'DB"FUS9W-T<B`B2_US;65N
M($)U;'5T;'4B"@HC.B!A9&UI;B]U<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$Y.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M=VEN7VAT='`N<&AP.C$U,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$X
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-S<@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O=7!D871E+FEN8SHT,PHC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#(S"FUS9VED(")087-S=V]R9"(*;7-G<W1R(")087)O;&$B"@HC
M.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z.#(*;7-G:60@(E!A<W-W
M;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$S,C(*;7-G:60@(E!A<W-W
M;W)D(&EN8V]R<F5C="(*;7-G<W1R(")986YL_?X@<&%R;VQA(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$U,@IM<V=I9"`B4&%S<W=O
M<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BXB"FUS9W-T
M<B`B4D%$2553(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=E<F5K;65K=&5D
M:7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`U,PIM<V=I9"`B
M4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VXB"FUS9W-T<B`B3VYA>6S](%!A
M<F]L82(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY,`IM<V=I
M9"`B4&%S<W=O<F0Z(@IM<V=S='(@(E!A<F]L83HB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;6]B:6QE+FEN8SHQ,0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R
M(")087)O;&$Z(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHQ-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S
M='(@(E!A<F]L86QA<B!E_FQE_FUE:R!Z;W)U;F1A9/UR+B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,3D@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C(R"FUS9VED(")087-T92(*;7-G<W1R(")9
M87#]_G3]<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(E!A;F]D86X@>6%P_?YT_7(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Q"FUS9VED(")0871H(@IM<V=S='(@(EEO;"(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA
M=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD
M:6YG(%-I9VYU<',Z(@IM<V=S='(@(D)E:VQE>65N(-QY96QI:VQE<CHB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-30*;7-G:60@(E!E;W!L92(*;7-G
M<W1R("+=;G-A;FQA<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`W"FUS9VED(")097)C96YT(@IM<V=S='(@(EG\>F1E
M(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ
M-#D*;7-G:60@(E!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R(*;7-G
M<W1R(")"86O];2#=_FQE;6QE<FEN:2!'97+G96ML9?YT:7(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#`V"FUS9VED(")097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM<V=S='(@(D)A:_UM(&G^;&5M
M;&5R:2!G:7)I_G1E(&=E<N=E:VQE_G1I<FEL<VEN(&UI/R(*"B,Z(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z,34V"FUS9VED(")097)M:7-S:6]N
M(@IM<V=S='(@(MUZ:6XB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C4R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N(%PB)7-<
M(B!N;W0@9&5L971E9"XB"FUS9W-T<B`BW7II;B`G)7,G('-I;&EN96UE9&DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<#HU.#8*(RP@9G5Z>GD*
M;7-G:60@(E!E<FUI<W-I;VX@1&5N:65D(@IM<V=S='(@(MUZ:6XB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C$V,2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$V-`HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO
M;G,B"FUS9W-T<B`B7TAA:VQA<B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C$P.2!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-C`*(SH@861M:6XO<&5R
M;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-3@*;7-G
M:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(MUZ:6X@
M6?9N971I;6DB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-C4*;7-G:60@
M(E!E<G-O;F%L($EN9F]R;6%T:6]N(@IM<V=S='(@(DMI_FES96P@0FEL9VEL
M97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X,R!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS9W-T<B`B4&5R=2(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-0IM<V=I9"`B4&5T<R(*;7-G
M<W1R(")%=F-I;"!(87EV86YL87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W
M.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G:60@(E!H
M:6QI<'!I;F5S(@IM<V=S='(@(D9I;&EP:6YL97(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DV"FUS9VED(")0:&]N92(*
M;7-G<W1R(")496QE9F]N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0W.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(D9O=&_P<F%F;&%R(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3`@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.#`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,`IM<V=I9"`B4&ET8V%I<FXB"FUS9W-T<B`B4&ET8V%I<FXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P
M.`IM<V=I9"`B4&EX96QS(@IM<V=S='(@(E)E<VEM($)I<FEM:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B4&QA=&ET=61E<R(*;7-G
M<W1R(")"97EL:6L@4_9Z;&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-PIM<V=I9"`B4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL(@IM<V=S='(@(DS\=&9E;B!B:7)K8><@:/QC<F5Y
M92!T_6ML87G];B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4&QE87-E(&-O;F9I<FT@=&AA
M="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G<W1R("),
M_'1F96X@8G4@]O!E>6D@Y_UK87)M86L@:7-T961I\&EN:7II(&1O\')U;&%Y
M_6XZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4V"FUS9VED(")0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N(@IM<V=S='(@(DS\=&9E;B!B
M=2#V\&5N:6X@8F'P_6[](.?V>FUE:R!I<W1E9&GP:6YI>B!D;_!R=6QA>?UN
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U-S$*;7-G:60@(E!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(DS\=&9E
M;B!B:7(@87D@=F4@8FER('G];"!G:7)I;BXB"@HC.B!T96UP;&%T97,O<')E
M9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHQ,@IM<V=I9"`B4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3HB"FUS9W-T<B`B3/QT
M9F5N('EE;FD@:V%T96=O<FEN:6X@863];OT@9VER:6XZ(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,P,0IM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RXB"FUS9W-T<B`B3/QT9F5N(&=EYV5R;&D@8FER
M($E0(&%D<F5S:2!G:7)I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C8P"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("),
M_'1F96X@9V7G97)L:2!B:7(@9_QN(&=I<FEN+"!A>61A:VD@9_QN('-A>?US
M_6[](&MO;G1R;VP@961I;BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-#4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+B(*;7-G
M<W1R("),_'1F96X@9V7G97)L:2!B:7(@>F%M86X@9VER:6XN(@H*(SH@=&5M
M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-PIM<V=I9"`B4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+B(*;7-G<W1R("),_'1F
M96X@<V]R=6YU;B!B:7(@]GIE=&EN:2!Y87#];BXB"@HC.B!T96UP;&%T97,O
M;&]G:6XO;&]G:6XN:6YC.C(R('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z
M,C8*;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A
M<W-W;W)D(@IM<V=S='(@(DS\=&9E;B!K=6QL86[]8_T@863]('9E('!A<F]L
M86[]>OT@9VER:6XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3@*
M(RP@9G5Z>GD*;7-G:60@(B(*(E!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92`B"B)S>7-T96TN(@IM<V=S='(@(B(*(DS\=&9E;B!M971N:2!O:W5Y=6XN
M(%-I<W1E;6D@:W5L;&%N86)I;&UE:R!IYVEN(&MU;&QA;OUM(&MO_G5L;&%R
M_6[]($M!0E5,("(*(F5T;65K('IO<G5N9&%S_6[]>BXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,`IM<V=I9"`B
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("),
M_'1F96X@>65N:2!K871E9V]R:6YI(&%D_2!G:7)I;CHB"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$X."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$X,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3D*;7-G:60@(E!O;&%N9"(*;7-G<W1R(")0;VQO;GEA(@H*(SH@;&EB+T)L
M;V-K+V9O<G1U;F4N<&AP.C4W"FUS9VED(")0;VQI=&EC<R(*;7-G<W1R(")0
M;VQI=&EK82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT.#<*;7-G
M:60@(E!O;&QS(@IM<V=S='(@(D]Y;&%M86QA<B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3DS(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3@R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*
M;7-G:60@(E!O<G1U9V%L(@IM<V=S='(@(E!O<G1E:VEZ(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(W
M"FUS9VED(")0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E(@IM<V=S='(@(D?V
M<OQN=/P@:V]N=6UL86YD_7+];/UY;W(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,0IM<V=I9"`B4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L92(*;7-G<W1R("+':7IE;&=E(&MO;G5M;&%N9/UR_6S]
M>6]R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3$*;7-G:60@(E!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*2(*;7-G<W1R(")"=2!D:7II;F4@9_9N9&5R("A)34%0('1A<F%F
M_6YD86X@>F]R;&%N;6%M86MT863]<BDB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(V-B!L:6(O0FQO8VLO;65T87(N<&AP.C(W,0HC+"!P:'`M9F]R;6%T
M"FUS9VED(")0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ("(*
M;7-G<W1R(")3;VX@)7,@<V%A='1E(&3\_F5N('EA\&UU<B!V92!K87(@;6EK
M=&%R_3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDX"FUS
M9VED(")0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]L9&%P+G!H<#HY.`IM<V=I9"`B4')E
M9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*
M;7-G<W1R(")0<F5F<U]L9&%P.B#=<W1E;F5N($Q$05`@=7IA;G3]<_T@8G5L
M=6YA;6%D_2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O<V5S<VEO;BYP
M:'`Z,S,*;7-G:60@(E!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@
M97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?<V5S<VEO;CH@
MW7-T96YE;B!O='5R=6T@=7IA;G3]<_T@8G5L=6YA;6%D_2XB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(R-0IM<V=I9"`B4')E<W-U<F4B"FUS9W-T<B`B
M0F%S_6[G(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-3D*;7-G:60@(E!R
M97-S=7)E(&%T('-E82!L979E;#H@(@IM<V=S='(@(D1E;FEZ('-E=FEY97-I
M;F1E:VD@8F%S_6[G.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HR,S4*;7-G:60@(E!R97-S=7)E.B`B"FUS9W-T<B`B0F%S_6[G.B(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,#4*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C`*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(S"FUS9VED(")0<F5V:65W(@IM<V=S='(@(M9N:7IL96UE(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG
M+FIS.C(T"FUS9VED(")0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD
M;W<B"FUS9W-T<B`B1_9R_&YT_'G\('EE;FD@<&5N8V5R961E(/9N:7IL92(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8R(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8V"FUS9VED(")0<F5V:6]U<R!O<'1I
M;VYS(@IM<V=S='(@(M9N8V5K:2!S9>=E;F5K;&5R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,0IM<V=I9"`B4')I;G0@
M9&]C=6UE;G0B"FUS9W-T<B`B0F5L9V5Y:2!Y87ID_7(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y
M(@IM<V=S='(@(M9Z96P@06YA:'1A<B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-CD*;7-G:60@(E!R;V)L96TB"FUS9W-T<B`B4V]R
M=6XB"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HQ,C8*;7-G:60@(E!R;V)L
M96T@1&5S8W)I<'1I;VXB"FUS9W-T<B`B4V]R=6X@5&%N_6UL86UA<_TB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T
M<R(*;7-G<W1R(")0<F]J96QE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,C@U"FUS9VED(")0<F]M<'0@=&5X="(*
M;7-G<W1R(")-971I;B!B:6QG:2!I<W1E;6DB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,C,*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`B0>?]:R!!;F%H=&%R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M
M:6UE+G!H<#HV-#4*;7-G:60@(E!U8FQI8R!+97D@06QG;W)I=&AM(@IM<V=S
M='(@(D'G_6L@06YA:'1A<B!A;&=O<FET;6%S_2(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-C0T"B,L(&9U>GIY"FUS9VED(")0=6)L
M:6,@2V5Y($EN9F\B"FUS9W-T<B`B0>?]:R!!;F%H=&%R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,C0Q"FUS9VED(")0=6)L:6,O4')I
M=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+B(*;7-G
M<W1R(")!Y_UK+]9Z96P@86YA:'1A<B!I:VEL:7-I(&)A_F%R_7EL82!Y87)A
M=/UL86UA9/TN(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,`IM<V=I9"`B4'5E<G1O(%)I8V\B
M"FUS9W-T<B`B4&]R=&\@4FEK;R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*;7-G:60@(E%A
M=&%R(@IM<V=S='(@(DMA=&%R(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C8S
M"FUS9VED(")1=65R>2(*;7-G<W1R(")3;W)G=2(*"B,Z(&QI8B]";&]C:R]A
M8V-O=6YT+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B475O=&$B"FUS9W-T<B`B
M2V%T87(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8V
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")24T$@4'5B;&EC($ME>2`H)60@8FET
M*2(*;7-G<W1R(")24T$@0>?]:R!!;F%H=&%R_2`H)60@8FET*2(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-C0*;7-G:60@(E)A9&EO('-E;&5C
M=&EO;B(*;7-G<W1R(")2861Y;R!39>=I;6DB"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT,PIM<V=I9"`B4F%I;B(*;7-G<W1R
M(")98?!M=7(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S
M+G!H<#HT-`IM<V=I9"`B4F%I;B!%87)L>2(*;7-G<W1R(")%<FME;B!386%T
M;&5R9&4@66'P;75R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R(")'9><@4V%A
M=&QE<F1E(%EA\&UU<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C0V"FUS9VED(")286EN(%-H;W=E<B(*;7-G<W1R(")38?!A
M;F%K(%EA\/W^(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T<B`B66'P;75R
M('9E($MA<B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C0X"FUS9VED(")286EN('1O(%-N;W<B"FUS9W-T<B`B2V%R82!D]F[\
M_F5C96L@>6'P;75R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,*;7-G
M:60@(E)A;F1O;2!&;W)T=6YE(@IM<V=S='(@(E)A<W1G96QE($1E>6G^(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H<#HV."!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C<V"FUS9VED(")2871I
M;R(*;7-G<W1R(")/<F%N(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H
M<#HS,C0@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHS-`HC.B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C8X('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z.3$*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,30@=&5M<&QA
M=&5S+W-H87)E<R]E9&ET+FEN8SHQ,S<*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHQ.#`*;7-G:60@(E)E860B"FUS9W-T<B`B3VMU;6$B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX-PIM<V=I9"`B
M4F5A9"!M97-S86=E<R(*;7-G<W1R("+=;&5T:6QE<FD@3VMU(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHX"B,L('!H<"UF;W)M870*
M;7-G:60@(E)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N(@IM<V=S='(@(B(*(E-I;&UE:R!I<W1E9&GP:6YI>F4@
M9V5RYV5K=&5N(&5M:6X@;6ES:6YI>C\H0G4@:?YL96T@9V5R:2#G979R:6QE
M;65Z*3HE<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHX
M"B,L('!H<"UF;W)M870*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+B(*;7-G<W1R("(B"B)+=6QL86[]8_T@)7,@92!A:70@:W5L;&%N_6/]('9E
M<FEL97)I;FD@<VEL;65K(&ES=&5D:?!I;FEZ92!E;6EN(&UI<VEN:7HN($)U
M("(*(FG^;&5M(&=E<FD@YV5V<FEL96UE>BXB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,T"FUS9VED(")2961O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R(")3;VX@97EL96UI('1E:W)A<FQA(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,30W('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C(P.`HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-#8*;7-G:60@(E)E9G)E<V@B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,Y,0IM<V=I9"`B4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z(@IM<V=S='(@(D1E=FEN9V5N($UE;OP@UO!E;&5R:6YI
M(%1A>F5L93HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED
M(")2969R97-H(%!O<G1A;"!6:65W.B(*;7-G<W1R(")0;W)T86P@1_9R_&[\
M;?QN_"!487IE;&4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DT
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,3,*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,3(S-0IM<V=I9"`B4F5G97@B"FUS9W-T<B`B1/QZ96YL
M:2#=9F%D92(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R-#D*;7-G
M:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM<V=S='(@(MUL:?YK:2!487)A
M>?UC_2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@(E)E
M;&]A9"(*;7-G<W1R(")/:W5M82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(D'G_6ML86UA;&%R(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I9"`B4F5M;W1E(%-E<G9E
M<G,B"FUS9W-T<B`B57IA:W1A:VD@4W5N=6-U;&%R(@H*(SH@=&5M<&QA=&5S
M+W)P8W-U;2]R<&-S=6TN:6YC.C@T"FUS9VED(")296UO=&4@55),("AH='1P
M.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"FUS9W-T<B`B57IA:W1A:VD@
M55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3HB"@HC.B!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W)E;6]V97%U975E9"YI;F,Z,3,*;7-G:60@(E)E;6]V92(*;7-G<W1R(")3
M:6PB"@HC.B!T96UP;&%T97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*;7-G:60@
M(E)E;6]V92!";&]C:R(*;7-G<W1R("+68F7P:2!3:6PB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-34W"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(DMO;&]N=2!3:6PB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C0P"FUS9VED(")296UO=F4@
M9F]R;6%T=&EN9R(*;7-G<W1R(")":>=I;6QE;65Y:2!3:6PB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9M87`N:6YC.C$R.`IM<V=I9"`B4F5M;W9E('!A:7(B
M"FUS9W-T<B`B26MI;&EY:2!3:6PB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C`R"FUS9VED(")296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2XB"FUS9W-T<B`B2V%Y9&5D:6QM:?X@
M8F5T:?!I('-U;G5C=6YU(&=EYVEC:2!D:7II;FEN9&5N('-I;"XB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#(*;7-G:60@(E)E;6]V92!T:&4B"FUS9W-T<B`B4VEL(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4P"FUS
M9VED(")296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT(@IM<V=S
M='(@(D)U('!A<N=A>?T@8F5L9V5D96X@Y_UK87)T(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ,0IM<V=I9"`B4F5M;W9E('5S97(B
M"FUS9W-T<B`B2W5L;&%N_6/](%-I;"(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W)E;6]V92YI;F,Z-0HC+"!P:'`M9F]R;6%T"FUS9VED(")296UO=F4@
M=7-E<CH@)7,B"FUS9W-T<B`B2W5L;&%N_6/]>?T@<VEL.B`E<R(*"B,Z(&9R
M86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,X"FUS9VED(")297%U97-T
M(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*
M;7-G<W1R("+=<W1E:R!C979A<&QA;F%M863]+D3V;OQL96X@:&%T82!K;V1U
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,34W"B,L(&9U
M>GIY"FUS9VED(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N(@IM<V=S='(@(EG\:VQE;F5N(&1O<WEA(&MA>61E9&EL96UE9&DN(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+G!H<#HU,3(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(D=E<F5K96X@)R5S)R`E<R!Y87#];&%N9/UR;6%S
M_6YD82!B96QI<G1I;&UE;6G^+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;"YP:'`Z-C<U(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.#,P"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HW,C,*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")'97)E:V5N("<E<R<@
M5D93('EA</UL86YD_7)M87/];F1A(&)E;&ER=&EL;65M:?XN(@H*(SH@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R(")'97)E:V5N("<E<R<@>6%P_6QA;F3]<FUA
M9&$@8F5L:7)T:6QM96UI_BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@
M(D=E<F5K96X@06QA;B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E
M;F1E<F5R+G!H<#HS,C`@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P
M,`HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED
M(")297-E="(*;7-G<W1R(")496UI>FQE(@H*(SH@<V5R=FEC97,O<F5S971P
M87-S=V]R9"YP:'`Z-#8*;7-G:60@(E)E<V5T(%!A<W-W;W)D(@IM<V=S='(@
M(E!A<F]L87G]('/]9OUR;&$B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HR-PIM<V=I9"`B4F5S970@66]U<B!087-S=V]R9"(*;7-G<W1R(")0
M87)O;&%N_7K]('/]9OUR;&%Y_6XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3,P"B,L(&9U>GIY"FUS9VED(")297-T;W)E($QA<W0@475E<GDB"FUS9W-T
M<B`BWFG^:VEN($%Y(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN
M+V-M9'-H96QL+G!H<#HR."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*;7-G:60@
M(E)E<W5L=',B"FUS9W-T<B`B4V]N=>=L87(B"@HC.B!T96UP;&%T97,O<G!C
M<W5M+W)P8W-U;2YI;F,Z,3`Q('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C<*
M;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(E-EYV5N96ML97)E
M($3V;OQN(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N<&AP.C,X"B,L
M(&9U>GIY"FUS9VED(")2971Y<&4@;F5W('!A<W-W;W)D(@IM<V=S='(@(E!A
M<F]L87G]('/]9OUR;&$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$Y-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$X-0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`R"FUS9VED(")2975N:6]N
M(@IM<V=S='(@(E)E=6YI;VXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP
M.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#@*;7-G:60@(E)E=F5R="!#
M;VYF:6=U<F%T:6]N(@IM<V=S='(@(EEA</UL86YD_7)M87G]($=E<FD@1/9N
M9/QR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,@IM<V=I9"`B4FEC
M:"!497AT($5D:71O<B!/<'1I;VYS(@IM<V=S='(@(EIE;F=I;B!-971I;B!$
M_'IE;FQE>6EC:7-I(%-EYV5N96ML97)I(@H*(SH@;&EB+T)L;V-K+V9O<G1U
M;F4N<&AP.C4X"FUS9VED(")2:61D;&5S(@IM<V=S='(@(D)I;&UE8V5L97(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(E-A\"(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@(E)I9VAT(&AE861E<B(*;7-G
M<W1R(")38?`@8F'^;/UK(&)I;&=I<VDB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$W"FUS9VED(")2:6=H="!V86QU97,B"FUS9W-T<B`B1&_P
M<G4@9&7P97)L97(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C@*;7-G:60@(E)O7W<@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R(")385]T_7(@UGIE;&QI:VQE<FDN+BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C,T"FUS9VED(")2;VQE
M(@IM<V=S='(@(D?V<F5V(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI
M82(*;7-G<W1R(")2;VUA;GEA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C(R-0IM<V=I9"`B4F]T871E(#$X,"(*;7-G<W1R
M("(Q.#`@9&5R96-E(&3V;F3\<B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HR,C(*;7-G:60@(E)O=&%T92!,969T(@IM<V=S
M='(@(E-O;&$@1/9N9/QR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C(R.`IM<V=I9"`B4F]T871E(%)I9VAT(@IM<V=S='(@
M(E-A\&$@1/9N9/QR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS
M9W-T<B`B4V%T_7(@UGIE;&QI:VQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O
M<&5R=&EE<R(*;7-G<W1R(")3873]<B#V>F5L;&EK;&5R:2(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2
M;W=S.B(*;7-G<W1R(")3873]<FQA<CHB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4S"FUS9VED(")2=6QE<R(*
M;7-G<W1R("+':7IG:6QE<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3`*;7-G:60@(E)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,B"FUS9W-T<B`BQVEZ
M9VEL97(@=/QM('-A=/UR('9E(&MO;&]N;&%R(&%R87/];F1A(&)E;&ER96-E
M:W1I<B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-3$*;7-G:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@
M8V]L=6UN<R!O;FQY(@IM<V=S='(@(L=I>F=I;&5R('-A9&5C92!K;VQO;FQA
M<B!A<F%S_6YD82!B96QI<F5C96MT:7(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4R"FUS9VED(")2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>2(*;7-G<W1R("+':7IG:6QE
M<B!S861E8V4@<V%T_7)L87(@87)A<_UN9&$@8F5L:7)E8V5K=&ER(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$R,`IM<V=I9"`B4G5N(@IM<V=S='(@(L=A
M;/W^=/UR(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3D@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S<VEA;B!&961E<F%T
M:6]N(@IM<V=S='(@(E)U<WEA($9E9&5R87-Y;VYU(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ.#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M,PIM<V=I9"`B4G=A;F1A(@IM<V=S='(@(E)U86YD82(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z,C@U"FUS9VED(")3+TU)344@0W)Y
M<'1O9W)A<&AI8R!3:6=N871U<F4B"FUS9W-T<B`B4R]-24U%(-YI9G)E;&5M
M92#=;7IA<_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C,R,PIM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@
M(E,O34E-12!I;&4@WFEF<F5L96YM:?X@W6QE=&DB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-A<VPN<&AP.C@Q"FUS9VED(")305-,(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@(E-!4TP@9&_P<G5L86UA
M<_T@;65V8W5T(&1E\&EL+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES
M=#HU,#0*;7-G:60@(E--4R!-97-S86=I;F<B"FUS9W-T<B`B4TU3($UE<V%J
M;&'^;6$B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G:60@(E-13"!3
M:&5L;"(*;7-G<W1R(")344P@2V%B=?!U(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B4U-((@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H
M<#HS-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R(")"0=Y!4DE,22(*"B,Z(&QI
M8B]A<&DN<&AP.C$U,PIM<V=I9"`B4U]13"!3:&5L;"(*;7-G<W1R(")37U%,
M($MA8G7P=2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C$*;7-G:60@(E-A(@IM<V=S='(@(D-T<R(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3@Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#0*;7-G:60@(E-A:6YT($AE;&5N82(*;7-G<W1R(")386EN="!(96QE;F$B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A:6YT($MI='1S(&%N9"!.979I<R(*
M;7-G<W1R(")386EN="!+:71T<R!V92!.979I<R(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM
M<V=I9"`B4V%I;G0@3'5C:6$B"FUS9W-T<B`B4V%I;G0@3'5C:6$B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`P"FUS9VED(")386EN="!0:65R<F4@86YD($UI<75E;&]N(@IM
M<V=S='(@(E-A:6YT(%!I97)R92!V92!-:7%U96QO;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,34*;7-G:60@(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(@IM
M<V=S='(@(E-A:6YT(%9I;F-E;G0@=F4@1W)E;F%D:6YE<R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.3(*;7-G:60@(E-A
M;64@9G)A;64@*%]S96QF*2(*;7-G<W1R(")!>6[](.=E<N=E=F4@*&ME;E]D
M:7-I*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(E-A;6]A(@IM<V=S='(@(E-A
M;6]A(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.34*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V%N($UA<FEN;R(*;7-G<W1R
M(")386X@36%R:6YO(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,38@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.38*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4V%O(%1O;64@
M86YD(%!R:6YC:7!E(@IM<V=S='(@(E-A;R!4;VUE('9E(%!R:6YC:7!E(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I9"`B4V%T
M96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(E5Y9'4@4V'P;&%Y_6/](@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#$@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ.3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V%U9&D@07)A8FEA(@IM<V=S='(@(E-U=61I
M($%R86)I<W1A;B(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY
M.`IM<V=I9"`B4V%V92(*;7-G<W1R(")+87ED970B"@HC.B!T96UP;&%T97,O
M861M:6XO9W)O=7!S+V5D:70N:6YC.C0U"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")3879E(%PB)7-<(B(*;7-G<W1R(")+87ED970@)7,B"@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q-@HC+"!P:'`M9F]R;6%T"FUS
M9VED(")3879E("5S(@IM<V=S='(@(DMA>61E="`E<R(*"B,Z('1E;7!L871E
M<R]P<F5F<R]E;F0N:6YC.C4*;7-G:60@(E-A=F4@3W!T:6]N<R(*;7-G<W1R
M(")39>=E;F5K;&5R:2!+87ED970B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,38W"FUS9VED("(B"B)3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2`B
M"B)D:7)E8W1O<GDN(@IM<V=S='(@(B(*(D]L=?YT=7)U;&%N('EA</UL86YD
M_7)M87G](%!(4"!B971I\&D@;VQA<F%K('-U;G5C=6YU;B!G9>=I8VD@9&EZ
M:6YI;F4@(@HB:V%Y9&5T+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C<Q"B,L('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I
M;VXN(@IM<V=S='(@(B5S('EA</UL86YD_7)M87/](&MA>61E9&EL9&DN(@H*
M(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B!<
M(B5S7"(N(@IM<V=S='(@(D%Y87(@9_QN8V5L;&5M92!B971I\&D@:V%Y9&5D
M:6QD:3H@)R5S)RXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HT.0HC+"!F=7IZ>0IM<V=I9"`B4V-A='1E<F5D(%0M4W1O<FUS
M(@IM<V=S='(@(EEA;/UT_6QM_?X@9_9K(&?\<OQL=/QL_"!F_7)T_6YA(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS9VED(")38VEE;F-E(@IM
M<V=S='(@(D)I;&EM(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI
M;F,Z,30@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z,38*;7-G:60@
M(E-E87)C:"(*;7-G<W1R(")!<F%M82(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,C`*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(D%R
M86UA($UO=&]R;&%R_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y
M-S,*;7-G:60@(E-E;&5C="!&:6QE<R(*;7-G<W1R(")$;W-Y86QA<OT@4V7G
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0X
M-`IM<V=I9"`B4V5L96-T(&$@9&%T92(*;7-G<W1R(")":7(@=&%R:6@@<V7G
M:6XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Y.`IM<V=I9"`B
M4V5L96-T(&$@9W)O=7`@=&\@861D(@IM<V=S='(@(D5K;&5M96L@:>=I;B!B
M:7(@9W)U<"!S9>=I;B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M-#,*;7-G:60@(E-E;&5C="!A(&YE=R!O=VYE<B(*;7-G<W1R(")996YI('-A
M:&EB:2!S9>=I;B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHV
M,`IM<V=I9"`B4V5L96-T(&$@<V5R=F5R(@IM<V=S='(@(D)I<B!S=6YU8W4@
M<V7G:6XB"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$U-@IM<V=I
M9"`B4V5L96-T(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`B16ML96UE:R!IYVEN
M(&)I<B!K=6QL86[]8_T@<V7G:6XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-C<W"B,L(&9U>GIY"FUS9VED(")396QE8W0@
M86QL(@IM<V=S='(@(D1O<WEA;&%R_2!39><B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR-C8S"FUS9VED(")396QE8W0@86QL(&1A=&4@8V]M<&]N
M96YT<RXB"FUS9W-T<B`B0OQT_&X@=&%R:6@@8FEL9?YE;FQE<FEN:2!S9>=I
M;B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX
M-S,*;7-G:60@(E-E;&5C="!A;B!O8FIE8W0B"FUS9W-T<B`B0FER(&YE<VYE
M('-EYVEN(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C8W.`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&YO;F4B"FUS9W-T<B`B
M665N:2!S86AI8FD@<V7G:6XB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z
M,S<*;7-G:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F
M<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*
M(G!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("(B"B+=
M<W1E9&GP;FEZ(&MA<F%K=&5R;&5R:2!A_F'P_61A:VD@:W5T=6QA<F1A;B!S
M9>=I;BX@1&%H82!S;VYR82!M971I;B`B"B)A;&%N_6YD86X@:V]P>6%L87G]
M<"!Y87#]_G3]<F%B:6QI<G-I;FEZ+B(*"B,Z('1E;7!L871E<R]D871A+V1A
M=&4N:6YC.C,T"FUS9VED(")396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*
M;7-G<W1R(")487)I:"!S_6[]<FQA>?UC_7/];OT@<V7G_6XZ(@H*(SH@=&5M
M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G:60@(E-E;&5C="!T:&4@9&%T
M92!F;W)M870Z(@IM<V=S='(@(E1A<FEH(&)IYVEM:6YI('-EYVEN.B(*"B,Z
M('1E;7!L871E<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.3`*;7-G:60@
M(E-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.B(*;7-G
M<W1R(")$9?!I_G1I<FUE:R!I<W1E9&GP:6YI>B!K:6UL:?!I('-EYVEN.B(*
M"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C$V"FUS9VED(")396QE8W0@
M=&AE('1I;64@9&5L:6UI=&5R.B(*;7-G<W1R(")386%T('/];OUR;&%Y_6/]
M<_UN_2!S9>=I;CHB"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM
M<V=I9"`B4V5L96-T('1H92!T:6UE(&9O<FUA=#HB"FUS9W-T<B`B4V%A="!B
M:>=I;6EN:2!S9>=I;CHB"@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC
M.C4W"FUS9VED(")396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RXB"FUS9W-T
M<B`B1?YL9?YE;B!I:VD@86QA;OT@<V7G:6XN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+B(*;7-G<W1R(")296YK(&3\>F5N:6YI>FD@<V7G:6XN(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C(T.`IM<V=I9"`B4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.B(*;7-G<W1R(")497)C:6@@971T:?!I;FEZ(&1I;&D@
M<V7G:6XZ(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-3@*
M;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B"FUS9W-T<B`B4V]R=6X@4F%P
M;W)U($?V;F1E<B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HQ,#,Y"FUS9VED(")396YD(%--4R(*;7-G<W1R(")335,@1_9N
M9&5R(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,3,@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.3@*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V5N96=A;"(*;7-G<W1R(")3
M96YE9V%L(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS,38*;7-G:60@(E-E
M;G-O<CH@(@IM<V=S='(@(D%L9_UL87G]8_TZ(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*
M;7-G<W1R(")%>6S\;"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DY"FUS9VED(")397)B:6$@86YD($UO;G1E;F5G<F\B"FUS9W-T
M<B`B4_UR8FES=&%N('9E($UO;G1E;F5G<F\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C<P,0IM<V=I9"`B4V5R:6%L($YU;6)E<B(*
M;7-G<W1R(")397)I($YU;6%R87/](@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,0HC+"!F=7IZ>0IM<V=I9"`B4V5R=F5R(&1A=&$@=W)O
M;F<@;W(@;F]T(&%V86EL86)L92XB"FUS9W-T<B`B2&%V82!R87!O<G4@]F)E
M\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN(@H*(SH@861M:6XO<V5S<VEO;G,N
M<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S='(@
M(MUZ:6X@6?9N971I;6DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3(*;7-G:60@(E-E<W-I;VX@240@97AP:7)E
M9"XB"FUS9W-T<B`B3W1U<G5M(&MI;6QI\&EN:6X@<_QR97-I(&1O;&1U+B(*
M"B,Z(&QI8B]A<&DN<&AP.C$T-0HC+"!F=7IZ>0IM<V=I9"`B4V5S<VEO;G,B
M"FUS9W-T<B`B7TAA:VQA<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(S,30*;7-G:60@(E-E="(*;7-G<W1R(")"96QI<G0B"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="XB"FUS9W-T<B`B(@HB4&%R;VQA;OUZ_6[]('5N=71U<G-A;OUZ('/]
M9OUR;&%M86[]>F$@:7II;B!V97)E8V5K('-EYV5N96ML97)I(&)E;&ER=&EN
M+B`B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"XB"FUS9W-T<B`B56QA_FUA:R!I<W1E\&EN:7H@=7IA
M:W1A:VD@<W5N=6-U;&%R_2!B96QI<FQE>6EN+B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX-`IM<V=I9"`B4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*;7-G<W1R(")497)C
M:6@@971T:?!I;FEZ(&1I;"P@<V%A="!D:6QI;6D@=F4@=&%R:6@@<V7G96YE
M:VQE<FEN:2!B96QI<FQE>6EN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HY.`IM<V=I9"`B(@HB4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@
M8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B`B"B)D
M:7-P;&%Y(&]P=&EO;G,N(@IM<V=S='(@(B(*(D)A_FQA;F?]YR!U>6=U;&%M
M86[]>OTL(')E;FL@9/QZ96YI;FEZ:2P@<V%Y9F$@=&%Z96QE;64L('9E(&1I
M\&5R(&?V<OQN=/P@(@HB<V7G96YE:VQE<FEN:2!B96QI<FQE>6EN+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S4*;7-G:60@(E-E='5P(@IM<V=S
M='(@(D%Y87)L87(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N
M:'1M;#HS-PIM<V=I9"`B4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L
M92(*;7-G<W1R(")+=7)U;'5M(&?\;F-E;&QE;64@8F5T:6ML97)I(&MU;&QA
M;OUL86)I;&ER(&1U<G5M9&$N(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C$X-@IM<V=I9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@
M=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`B1&7P:?YT:7)G92!I;&4@
M8FER9&5N(&9A>FQA('EE<B!M_&UK_&XZ("(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C`P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G
M:60@(E-E>6-H96QL97,B"FUS9W-T<B`B4V5Y_F5L(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C0Y-@IM<V=I9"`B4VAO<'!I;F<B"FUS9W-T<B`B
M06S]_B!V97)I_B(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC
M.C0S"FUS9VED(")3:&]R="!3=6UM87)Y(@IM<V=S='(@(DO]<V$@UGIE="(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT-#8*;7-G:60@(E-H;W5L9"!A
M8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R
M("+';_!U(&)A\&QA;G3](&GG:6X@97)I_FEM(&%N86AT87+]('1A;OUM;&%N
M<_UN(&W]/R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3<Y"FUS9VED(")3:&]W(@IM<V=S='(@(D?V<W1E<B(*"B,Z(&%D;6EN+W-E
M='5P+VEN9&5X+G!H<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@(@HB8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB2&%L96X@:V%Y_71L
M_2!O;&%N('EA</UL86YD_7)M82!I;&4@>65N:2!Y87)A=/UL86X@>6%P_6QA
M;F3]<FUA(&%R87/];F1A:VD@(@HB9F%R:VQA<OT@9_9S=&5R+B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HT.3`*;7-G:60@(E-H;W<@;&%S="!L;V=I
M;B!T:6UE('=H96X@;&]G9VEN9R!I;C\B"FUS9W-T<B`B1VER:?YT92!E;B!S
M;VX@9VER:?X@=&%R:6AI(&?V<W1E<FEL<VEN(&UI/R(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$W-C4*;7-G:60@(E-H;W<@;W!T:6]N('1O(&ME
M97`@;W)I9VEN86PB"FUS9W-T<B`BUGIG_&X@;VQA;OT@<V%K;&%M82!S9>=E
M;F7P:6YI(&?V<W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,3,*;7-G:60@(E-H;W<@<&EC:V5R(@IM<V=S='(@(E-EYVEC:7EI(&?V<W1E
M<B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,C8*;7-G:60@(E-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\B"FUS9W-T<B`BQVEZ96QG92!I
M_FQE;6QE<FD@;65N_"#G=6)U\'5N9&$@9_9S=&5R:6QS:6X@;6D_(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(E<R!-
M96[\<_P@<V]L9&$@9_9S=&5R:6QS:6X@;6D_(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3
M:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@
M(E1A8FQO($C\8W)E(-9Z96QL:6ML97)I($MU='5S=6YU(&?V<W1E<B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHV-`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`B5&%B;&\@UGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<B"FUS9W-T<B`B5&%B;&\@4V%T_7(@UGIE;&QI:VQE<FD@2W5T=7-U
M;G4@9_9S=&5R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C4R"FUS9VED(")3:&]W('1H92!I;6%G92!P<F]P
M97)T:65S(&1I86QO9R(*;7-G<W1R(")']G+\;G3\(/9Z96QL:6ML97)I(&MU
M='5S=6YU(&?V<W1E<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W
M-C,*;7-G:60@(E-H;W<@=7!L;V%D(@IM<V=S='(@(EG\:VQE;65Y:2!G]G-T
M97(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU
M,`IM<V=I9"`B4VAO=V5R<R(*;7-G<W1R(")38?!A;F%K(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3$*;7-G:60@(E-H;W=E
M<G,@16%R;'DB"FUS9W-T<B`B17)K96X@4V%A=&QE<F1E(%-A\&%N86LB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I
M9"`B4VAO=V5R<R!,871E(@IM<V=S='(@(D=EYR!386%T;&5R9&4@4V'P86YA
M:R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4S
M"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R("+'979R
M961E(%-A\&%N86LB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T
M+G!H<#HT.#`*;7-G:60@(E-H<FEN:R(*;7-G<W1R(")+_.?\;'0B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(MUL:R!O;&%R86L@:V]M_G4@]O!E;&5R
M(&O\Y_QL='/\;B!Y861A('1A_OUN<_UN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I
M9"`B4VEE<G)A($QE;VYE(@IM<V=S='(@(E-I97)R82!,96]N92(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C4*;7-G:60@(E-I9VX@
M=7`B"FUS9W-T<B`BW'EE(&]L(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,3(*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("+=;7IA
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,3$*;7-G
M:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS9W-T<B`BW6UZ82!!;&=O<FET
M;6%S_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`V(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-I;F=A<&]R92(*;7-G<W1R
M(")3:6YG87!U<B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-C4@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@W(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Y-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C$U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S<*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR.3,P"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C,*
M;7-G:60@(E-I>F4B"FUS9W-T<B`B0F]Y=70B"@HC.B!T96UP;&%T97,O;6%I
M;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU,@IM<V=I9"`B4VMI<"!-86EN
M=&5N86YC92(*;7-G<W1R(")"86O];?T@071L82(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*
M;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(E-L;W9A:WEA(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$P-0IM<V=I9"`B4VQO=F5N:6$B"FUS9W-T<B`B4VQO=F5N>6$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-`IM<V=I9"`B
M4VYO=R(*;7-G<W1R(")+87(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU-0IM<V=I9"`B4VYO=R!3:&]W97(B"FUS9W-T<B`B
M2V%R(%-A\&%N8?#](@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z-38*;7-G:60@(E-N;W<@4VAO=V5R<R(*;7-G<W1R(")+87(@
M4V'P86YA:VQA<OTB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HU-PIM<V=I9"`B4VYO=R!3:&]W97)S($5A<FQY(@IM<V=S='(@
M(D5R:V5N(%-A871L97)D92!+87(@4V'P86YA:VQA<OTB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU.`IM<V=I9"`B4VYO=R!3
M:&]W97)S($QA=&4B"FUS9W-T<B`B1V7G(%-A871L97)D92!+87(@4V'P86YA
M:VQA<OTB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(W.`IM<V=I9"`B4VYO
M=R!D97!T:#H@(@IM<V=S='(@(DMA<B!$97)I;FQI\&DZ("(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@
M=V%T97(Z("(*;7-G<W1R(")98?!A;B!K87+];B!S=2!E_FET:3H@(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#(@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR,#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$P,PIM<V=I9"`B4V]L;VUO;B!)<VQA;F1S(@IM<V=S='(@(E-O
M;&]M;VX@061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C$T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C`V"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*;7-G:60@(E-O;6%L:6$B
M"FUS9W-T<B`B4V]M86QI(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8P
M"FUS9VED(")3;VYG<R`F(%!O96US(@IM<V=S='(@(MYA<FO];&%R("8@WFEI
M<FQE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C8*;7-G:60@
M(E-O<G0@;W)D97(@<V5L96-T:6]N(@IM<V=S='(@(E/]<F%L86UA(&3\>F5N
M:2!S9>=I;6DB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4U.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4X.0HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR,3<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C0W"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]W:6Y?:'1T<"YP:'`Z,38V"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3@Y"FUS9VED(")3;W5R8V4@861D<F5S<R(*;7-G
M<W1R(")+87EN86L@861R97-I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-34@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U
M=&@@069R:6-A(@IM<V=S='(@(D?\;F5Y($%F<FEK82(*"B,Z(&-O;F9I9R]N
M;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RDB"FUS9W-T<B`B1_QN97D@079R=7!A("A)4T\M.#@U.2TS*2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C`X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW-PIM<V=I9"`B4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H
M(%-A;F1W:6-H($ES;&%N9',B"FUS9W-T<B`B1_QN97D@1V5O<F=I82!V92!'
M_&YE>2!386YD=VEC:"!!9&%L87+](@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C,S(&QI8B]";&]C:R]M;V]N+G!H<#HV,@IM<V=I9"`B4V]U=&AE<FX@2&5M
M:7-P:&5R92(*;7-G<W1R(")'_&YE>2!987+];6O\<F4B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q,PIM<V=I9"`B4W!A
M8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<R(*;7-G<W1R(")":71I_FEK(&C\
M8W)E;&5R(&%R87/];F1A:VD@8F_^;'5K(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,34*;7-G:60@(E-P86-E(&)E='=E
M96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&PB"FUS9W-T<B`B2/QC<F5D
M96MI('/];OUR('9E(&GG97)I:R!A<F%S_6YD86MI(&)O_FQU:R(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C@Q-0IM<V=I9"`B4W!A8V5R(@IM<V=S
M='(@(D)O_FQU:R!!>6%R;&%Y_6/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@P"FUS9VED(")3<&%C:6YG(@IM
M<V=S='(@(D%R86S]:R!B_7)A:VUA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B4W!A8VEN9R!A
M;F0@<&%D9&EN9R(*;7-G<W1R(")!<F%L_6L@8OUR86MM82!V92!Y87-T_6ML
M86UA(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@(E-P86EN(@IM<V=S='(@(MUS<&%N
M>6$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*;7-G:60@(E-P
M86TB"FUS9W-T<B`BW7-T96YM97EE;B#=;&5T:2(*"B,Z('-E<G9I8V5S+VME
M>6)O87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B
M"FUS9W-T<B`BUGIE;"!+87)A:W1E<B!':7)I_FDB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3
M<&QI="!C96QL(@IM<V=S='(@(DC\8W)E>6D@8O9L(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I9"`B
M4W!L:70@8V]L=6UN(@IM<V=S='(@(DMO;&]N=2!B]FPB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Q"FUS9VED
M(")3<&QI="!R;W<B"FUS9W-T<B`B4V%T_7+](&+V;"(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV,0IM<V=I9"`B4W!O<G1S(@IM<V=S='(@(E-P;W)L
M87(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,2!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,`HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z.#@*;7-G:60@(E-R:2!,86YK82(*;7-G<W1R(")3
M<FD@3&%N:V$B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S,@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-`IM<V=I9"`B4W1A;F1A<F0B"FUS9W-T
M<B`B4W1A;F1A<G0B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C(*;7-G
M:60@(E-T87(@5')E:R(*;7-G<W1R(")5>F%Y(%EO;'4B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DV(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(X,#D*;7-G:60@(E-T87)T('EE87(B"FUS9W-T<B`B0F'^;&%N9_WG('G]
M;/TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W,`IM
M<V=I9"`B4W1A=&4@;W(@4')O=FEN8V4B"FUS9W-T<B`B17EA;&5T('9E>6$@
MW6PB"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM
M<V=I9"`B4W1A='5S(@IM<V=S='(@(D1U<G5M(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C@Q-0IM<V=I9"`B4W1O<F%G92!F;W)M870B"FUS9W-T
M<B`B1&5P;VQA;6$@8FGG:6UI(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-S(*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@
M(E-O:V%K($%D<F5S:2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3$*;7-G:60@(E-T<FEK971H<F]U9V@B"FUS9W-T<B`B
MW'-T_"#G:7IG:6QI(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(S
M,PIM<V=I9"`B4W1R:6YG(&QI<W0B"FUS9W-T<B`B1&EZ9VD@;&ES=&5S:2(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-S,*;7-G:60@(E-T<FEP
M(&1O;6%I;B!F<F]M('1H92!A9&1R97-S(@IM<V=S='(@(D%D<F5S=&5N(&%L
M86X@863];OT@Y_UK87)T(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,PIM<V=I9"`B4W1Y;&4@6T-34UTB"FUS
M9W-T<B`B4VET:6P@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R(")0>G(B"@HC
M.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,S<*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E-U8F1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G
M<W1R(")!;'1D:7II;B`G)7,G(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R(")+;VYU(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I
M9"`B4W5B;6ET(@IM<V=S='(@(D?V;F1E<B(*"B,Z('-I9VYU<"YP:'`Z-#D*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U
M97-T('1O(&%D9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@
M;&]G(&EN('5N=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"XB"FUS9W-T<B`B(@HB)R5S)R!I;B!S:7-T96UE(&5K;&5N;65S:2!I<W1E
M\&EN:7H@9_9N9&5R:6QD:2X@W7-T9?!I;FEZ(&]N87EL86YA(&MA9&%R("(*
M(F=I<FG^('EA<&%M87IS_6[]>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T
M<B`B06QT<VEM9V4B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3`T"B,Z(&9R
M86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T
M871U<RYP:'`Z,C@*;7-G:60@(E-U8V-E<W,B"FUS9W-T<B`B0F'^87+](@H*
M(SH@861M:6XO=7-E<BYP:'`Z.#4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G
M:60@(E-U8V-E<W-F=6QL>2!A9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2XB
M"FUS9W-T<B`B)R5S)R!B8?YA<OUY;&$@<VES=&5M92!E:VQE;F1I+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,G(&GG:6X@;VQA;B!V97)I
M(&)A_F%R_7EL82!S:7-T96UD96X@=&5M:7IL96YM:?YT:7(N(@H*(SH@861M
M:6XO9W)O=7!S+G!H<#HX,"!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@9&5L971E
M9"!<(B5S7"(N(@IM<V=S='(@(D)A_F%R_7EL82!S:6QI;F1I("<E<R<N(@H*
M(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@9G)O;2!T:&4@<WES
M=&5M+B(*;7-G<W1R(")3:7-T96UD96X@8F'^87+]>6QA('-I;&EN9&D@)R5S
M)RXB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q"FUS9VED(")3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+B(*;7-G<W1R("(B"B)987#];&%N9/UR;6$@8F'^87+]>6QA
M(&=E<FD@9/9N9/QR_&QD_"X@1&7P:?YI:VQI:VQE<FD@9_9R;65K(&GG:6X@
M>65N:61E;B`B"B)Y_&ML97EI;BXB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*;7-G:60@(E-U8V-E
M<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B
M665D96L@>6%P_6QA;F3]<FUA(&)A_F%R_7EL82!K87ED961I;&1I+B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R(")9961E:R!Y87#];&%N9/UR;6$@9&]S>6%S
M_2`E<R!B8?YA<OUY;&$@:V%Y9&5D:6QD:2XB"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-U8V-E<W-F=6QL
M>2!U<&1A=&5D(%PB)7-<(B(*;7-G<W1R("(G)7,G(&)A_F%R_7EL82!G_&YC
M96QL96YD:2(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-S$@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(E-U8V-E
M<W-F=6QL>2!W<F]T92`E<R(*;7-G<W1R("(E<R!B8?YA<OUY;&$@>6%Z_6QD
M_2XB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R(")3=61A
M;B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA
M;F<N:G,Z-38*;7-G:60@(E-U;6UA<GDB"FUS9W-T<B`BUGIE="(*"B,Z(&QI
M8B]";&]C:R]S=6YR:7-E+G!H<#HV-0IM<V=I9"`B4W5N(%)I<V4B"FUS9W-T
M<B`B1_QN($1O\'5M=2(*"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HV.`IM
M<V=I9"`B4W5N(%-E="(*;7-G<W1R(")'_&X@8F%T_6W](@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-3D*;7-G:60@(E-U;FYY
M(@IM<V=S='(@(D?\;F7^;&DB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C$V"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(D?\;B!D;_!U;74B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES
M92YP:'`Z,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(D?\;B!D
M;_!U;74O1_QN(&)A=/UM_2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,34*;7-G:60@(E-U;G)I<V4Z("(*;7-G<W1R(")'_&X@9&_P=6UU
M.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$Y"FUS9VED
M(")3=6YS970B"FUS9W-T<B`B1_QN(&)A=/UM_2(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3@*;7-G:60@(E-U;G-E=#H@(@IM<V=S='(@
M(D?\;B!B873];?TZ("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(MQS
M='-I;6=E(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,W.`IM<V=I
M9"`B4W5P<&]R="(*;7-G<W1R(")$97-T96LB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(Q-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(Q,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`V"FUS
M9VED(")3=7)I;F%M92(*;7-G<W1R(")3=7)I;F%M(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU-S0*;7-G:60@(E-U<FYA;64B"FUS
M9W-T<B`B4V]Y863](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3,*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-0IM<V=I9"`B4W9A;&)A<F0@
M86YD($IA;B!-87EE;B(*;7-G<W1R(")3=F%L8F%R9"!V92!*86X@36%Y96XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T<B`B4W9A
M>FEL86YD(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#4@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,34*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4W=E9&5N(@IM<V=S='(@
M(MUS=F7G(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HU-B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(Q-@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(E-W:71Z97)L86YD(@IM<V=S
M='(@(MUS=FGG<F4B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX
M-@HC+"!F=7IZ>0IM<V=I9"`B4WEN8R!L;V<@9&5L971E9"(*;7-G<W1R(")3
M:6QM97EI;B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G:60@
M(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW
M;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R
M;7,B"FUS9W-T<B`B07)A;6$@=&5R:6UL97)I;F1E('/V>F1I>FEM(&AA=&%S
M_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$X(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(E-Y<FEA;B!!<F%B(%)E<'5B;&EC
M(@IM<V=S='(@(E-U<FEY92(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8P"FUS9VED(")4+5-T;W)M(@IM<V=S='(@(D?V:R!G
M_'+\;'3\;/P@9OUR=/UN82(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8Q"FUS9VED(")4+5-T;W)M(&%N9"!7:6YD>2(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HV,@IM<V=I9"`B5"U3=&]R;7,B"FUS9W-T<B`B1_9K(&?\<OQL=/QL_"!F
M_7)T_6YA;&%R(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-C,*(RP@9G5Z>GD*;7-G:60@(E0M4W1O<FUS($5A<FQY(@IM<V=S
M='(@(D5R:V5N(%-A871L97)D92!38?!A;F%K(@H*(SH@9G)A;65W;W)K+T1A
M=&$O1&%T82]T<W8N<&AP.C$V-@IM<V=I9"`B5%-6(&9I;&4B"FUS9W-T<B`B
M5%-6(&1O<WEA<_TB"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S
M-`IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BQVEZ96QG92(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@
M(E1A8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BQTEZ96QG92#6>F5L;&EK;&5R
M:2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z
M-3<*(RP@9G5Z>GD*;7-G:60@(E1A8FQE(%-E="(*;7-G<W1R("+':7IE;&=E
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHW,@IM<V=I9"`B5&%B;&4@<')O<&5R=&EE<R(*;7-G<W1R("+':7IE
M;&=E(/9Z96QL:6ML97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B
M5&%I=V%N(@IM<V=S='(@(E1A>79A;B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R;W9I;F-E(&]F
M($-H:6YA(@IM<V=S='(@(E1A>79A;BP@QVEN(&5Y86QE=&DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R-2!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`Y"FUS9VED(")486II:VES=&%N(@IM<V=S='(@(E1A8VEK:7-T86XB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(S-2!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$R"FUS9VED(")486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F(@IM<V=S='(@(E1A;GIA;GEA(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G
M<W1R(")(961E9CHB"@HC.B!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3DV(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.#<*;7-G:60@(E1A<VMS(@IM<V=S
M='(@(D?V<F5V;&5R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B5&5L
M969O;B!.=6UA<F%S_2(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDP"FUS
M9VED(")496UP(&9O<B!L87-T(&AO=7(Z("(*;7-G<W1R(")3;VX@<V%A="!I
MYVEN('/]8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(Q-`IM
M<V=I9"`B5&5M<&5R871U<F4B"FUS9W-T<B`B4_UC86ML_6LB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R
M93H@(@IM<V=S='(@(E/]8V%K;/UK.B`B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,CDS"B,L('!H<"UF;W)M870*;7-G:60@(E1E;7!E<F%T
M=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HV.#<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E1E;7!L871E(%PB)7-<(B!N;W0@9F]U
M;F0N(@IM<V=S='(@(B<E<R<@=&%S;&'P_2!B=6QU;F%M863]+B(*"B,Z(&%D
M;6EN+W1E;7!L871E<RYP:'`Z,38Y"FUS9VED(")496UP;&%T92!!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")487-L86L@6?9N971I;6DB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ,C$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S,S8*;7-G:60@(E1E>'0B"FUS9W-T<B`B365T:6XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`B
M4V%D96-E($UE=&EN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW-`IM<V=I9"`B5&5X="!A;&EG;B(*;7-G<W1R
M(")-971I;B!H:7IA;&%M87/](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW,0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R(")-
M971N:6X@W'-T_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-3D*;7-G:60@(E1H(@IM<V=S='(@(E!R_B(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DQ"FUS9VED(")4:&%I("A425,M-C(P*2(*;7-G
M<W1R(")486D@*%1)4RTV,C`I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P.0IM<V=I9"`B5&AA
M:6QA;F0B"FUS9W-T<B`B5&%Y;&%N9"(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+B(*;7-G<W1R(")3:7-T96UI(&MU;&QA;OUD_?#];OUZ(&GG:6X@=&7^
M96MK_'(@961E<FEZ+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z
M.#(P"FUS9VED(")4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R(")&5%`@=7IA;G3]<_T@:W5L;&%N_6QA8FEL:7(@9'5R=6UD
M82!D9?!I;"XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDS-`HC
M+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@2&]R9&4O2V]L86(@:6YT96=R871I
M;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@7"(E<UPB(@IM<V=S='(@(DAO
M<F1E+TMO;&%B(&+\=/QN;&7^=&ER;64@;6]T;W)U(&1E<W1E:VQE;65M96MT
M961I<CH@7"(E<UPB(@H*(SH@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O
M:RYP:'`Z,3(Y,@HC+"!F=7IZ>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD
M(&YO="!B92!I;FET:6%L:7IE9"XB"FUS9W-T<B`B6?QK;&5N96X@9&]S>6$@
M:V%Y9&5D:6QE;65D:2XB"@HC.B!S97)V:6-E<R]M86EN=&5N86YC92YP:'`Z
M,S$*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A
M9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`B0F%K_6TZ.B!S_6[]9B!B8?YA<OUY
M;&$@>?QK;&5N96UE9&DN(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC
M:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N(@IM<V=S='(@(MYEYV5N96ML97(@<&5N8V5R97-I(&MA
M<&%N9/TNQ_UK_?X@>6%P_6S]>6]R+B(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<RYP:'`Z,3@Y(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M
M<R]097)M<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C,T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP
M:'`Z,S`S"FUS9VED("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@(@HB=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*(D7P
M97(@:7II;FQE<FD@:W5L;&%N;6%K(&ES=&EY;W)S86[]>B!Y]FYE=&EC:6YI
M>FEN(-UZ:6X@<VES=&5M:6YI("(*(GEA</UL86YD_7)M87/](&=E<F5K;65K
M=&5D:7(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS
M9W-T<B`B4V%D96-E(&%L="!T87)A9B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4:&4@8V]N
M=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM<V=S='(@
M(B(*(MUL971I_FEM(&YO:W1A<_UN_6X@240G<VD@8F5L:7)L96YE;65D:2P@
M8F_^(&+]<F%K_6QM_?X@=F5Y82!V97)I('1A8F%N_6YD82`B"B)B=6QU;F%M
M863]+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E
M9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`BW6QE=&G^:6T@;F]K
M=&%S_2!B8?YA<OUY;&$@861R97,@9&5F=&5R:6YI>F4@96ML96YD:2XB"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B
M"B)4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"B+'
M_6MA<G3];&W]_B!01U`@:6UZ82#V8F7P:2!I;7IA;&%N;?W^(&EL971I;FEN
M(&1O\')U;'7P=6YU;B!S8?!L86YM87/](&GG:6X@(@HB9V5R96MM96MT961I
M<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C8T,0IM<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A
M<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U
M;F0@(@HB:6X@=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"B)$8?#]=/UM(&QI
M<W1E<VD@240G<VD@8F5L:7)L96YE;65D:2P@8F_^(&+]<F%K_6QM_?X@=F5Y
M82!V97)I('1A8F%N_6YD82`B"B)B=6QU;F%M863]+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0R"FUS9VED(")4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N(@IM<V=S
M='(@(D1A\/UT_6T@;&ES=&5S:2!B96QI<FQE;F5M961I+B(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="YP:'`Z,3$S"FUS9VED(")4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+B(*
M;7-G<W1R("+>:69R96QE;64@]GIE;&QI:VQE<FD@9_QV96YL:2!B:7(@=V5B
M(&)A\&QA;G3]<_T@9V5R96MT:7)M96MT961I<BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C$W-2!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C4Q,PHC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@(B5S(&1O<WEA<_T@)7,@
M87EA<OT@:>=E<FUE;&ED:7(N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-C@@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,#,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M
M92`E<R!S971T:6YG<RXB"FUS9W-T<B`B)7,@9&]S>6%S_2`E<R!A>6%R;&%R
M_2!IYV5R;65L:61I<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HR,3D*;7-G:60@(E1H92!F:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@
M:71S96QF+B(*;7-G<W1R(")$;W-Y82!K96YD:2#\>F5R:6YE(&MO<'EA;&%N
M86UA>BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.#`*;7-G:60@
M(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*;7-G<W1R(")$;W-Y82!V
M97)I(&GG97)M:7EO<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C8W"FUS9VED(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@
M:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(*;7-G
M<W1R(")486MI<"!E9&5N;&5R(&)U(&EL971I+W)F8S@R,B!I;&5T:7-I(&GG
M:6X@8F'^;/UK(&)I;&=I;&5R:61I<BXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@9G5L;"!S
M8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN
M=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S('1H870@
M=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP
M97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U
M;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF("(*
M(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T
M:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N($9A=6QT
M)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@
M=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*(D'^86UA
M9/WP_6W]>B!T87)A>?UC_2!H871A;&%R_2!S96)E8FEY;&4@=&%M(&5K<F%N
M(&MI<&EN:6X@26YT97)N970@(@HB17AP;&]R97(G;&$@8FER;&EK=&4@<V]R
M=6X@Y_UK87)D_?#](&)I;&EN;65K=&5D:7(N($%N;&%M<_UZ(&?V<OQN=/QL
M97)L92P@(@HBYV%L_?YM87EA;B!M971I;B!D_'IE;FQE>6EC:2!I_FQE<FEY
M;&4@=F4O=F5Y82!T87)A>?UC_6[];B!R87-T9V5L92`B"B+G]FMM97-I>6QE
M(&MA<O[];&'^86)I;&ER<VEN:7HN($7P97(@<VES=&5M:6YI>B!7:6YD;W=S
M(#EX(&ES92!Y_&MS96L@(@HB:6AT:6UA;"`G1V5N97)A;"!0<F]T96-T:6]N
M($9A=6QT)R!H871A<_T@86S]<"!S:7-T96UI('EE;FED96X@8F'^;&%T;6%N
M_7H@(@HB9V5R96ME8V5K+EQ<;EQ<;D)U(&)I<B!U>6%R_7ED_2X@1?!E<B!H
M86QA('1A;2!E:W)A;B!M971I;B!D_'IE;FQE>6EC:7-I;FD@(@HB9&5N96UE
M:R!I<W1I>6]R<V%N_7H@179E="=I('3]:VQA>?UN+B(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@:61E;G1I
M='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S='(@(DMI;6QI:R!<
M(B5S7"(@<VEL:6YD:2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C<V"FUS9VED(")4:&4@;&5F="UH86YD('-I
M9&4@;VYL>2(*;7-G<W1R(")3861E8V4@<V]L('1A<F%F(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4:&4@;&]C
M871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H
M92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B0W)Y<'1?<&=P.CH@<_UN
M_6;];F$@1VYU4$<@:6MI;&ES:6YI;B!K;VYU;74@=F5R:6QM96L@>F]R=6YD
M863]<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TU$3BYP:'`Z,C`Q"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y960N
M7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA
M<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HB)7,@=&%R
M:6AI;F1E("5S(&4@9_9N9&5R:6QE;B!<(B5S7"(@:V]N=6QU(&EL971I(&?V
M<OQN=/QL96YD:2Y<;B(*(D)U(&EL971I;FEN(&]K=6YD=?!U('9E>6$@86YL
M8?[];&3]\/UN_2!G87)A;G1I;&5M96UE:W1E9&ER+B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W
M:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R(")/;'7^
M='5R('!E;F-E<F5S:6YE(&)A\&QA;OUR:V5N(&MU;&QA;OUL86-A:R!I<VEM
M(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#0Q"B,L(&9U>GIY
M"FUS9VED(")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M(@IM<V=S='(@(D)U(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L_63]
M<BXB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C$R,S$*
M;7-G:60@(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(@IM<V=S='(@(DAO<F1E7T-R
M>7!T7W-I;64Z.B!S_6[]9OT@;W!E;G-S;"!B:7)I;6D@:>=I;B!G97)E:VUE
M:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<RYP:'`Z,CDP"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F5F97)E;F-E(%PB)7-<(B!C
M;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T
M:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G<W1R("(B"B)<(B5S
M7"(@=&5R8VEH:2!V97)I<VD@:7II;B!V97)I;&5N(&5N('G\:W-E:R!B;WEU
M='4@9V7G=&GP:2!IYVEN("(*(FMA>61E9&EL96UE;65K=&5D:7(N(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS,@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W
M('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES
M=&5M+B(*;7-G<W1R("(B"B)"=2!V97)I('EA<'/];OTH)7,I(&?V<W1E<FUE
M:R!IYVEN(&MU;&QA;OUL86X@<')O9W)A;2!S:7-T96UD92`B"B)B=6QU;FUA
M;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z-#4T
M"FUS9VED(")4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L
M92!C:&%R86-T97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S<*;7-G:60@(E1H92!R:6=H
M="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S='(@(E-A9&5C92!S;VP@=F4@
M<V'P('1A<F%F;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@<VED
M92!O;FQY(@IM<V=S='(@(E-A9&5C92!S8?`@=&%R868B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#8*;7-G:60@(E1H92!S97!A<F%T;W(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-S@*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS
M9W-T<B`B7"(E<UPB('-U;G5C=7-U('-I;&EN9&DN(@H*(SH@<V5R=FEC97,O
M<&]R=&%L+W)P8W-U;2YP:'`Z-#D*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S='(@(EPB)7-<
M(B!S=6YU8W5S=2!K87ED961I;&1I+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Y
M.`HC+"!P:'`M9F]R;6%T"FUS9VED(")4:&4@<VEG;G5P(')E<75E<W0@9F]R
M("5S(&AA<R!B965N(')E;6]V960N(@IM<V=S='(@(B5S(&GG:6X@;VQA;B#\
M>65L:6L@:7-T9?!I('-I;&EN9&DN(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L
M;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D
M;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B0F5L:7)T:6QE;B!S873]<B!B=6QU
M;FUA;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ
M-S<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB
M)7-<(B!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B1V7G:6-I(&1O<WEA(%PB
M)7-<(B!B=6QU;FUA;6%K=&%D_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO
M="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C<Y"FUS9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G
M<W1R(")3861E8V4@_'-T('9E(&%L="!T87)A9FQA<B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#`*;7-G:60@
M(E1H92!T;W`@<VED92!O;FQY(@IM<V=S='(@(E-A9&5C92#\<W0@=&%R868B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+B(*;7-G<W1R(")":7(@]FYC96MI(&%D_6T@<_UR87/];F1A('G\:VQE;F5N
M('9E<FD@:V%Y8F5D:6QD:2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S
M=BYP:'`Z,C8R(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*;7-G
M:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS
M9W-T<B`B6?QK;&5N96X@9&]S>6$@:V%Y9&5D:6QE;65D:2XB"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,34@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0IM<V=I9"`B5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM<V=S='(@
M(G=E871H97(N8V]M(&MU;&QA;OUL86)I;&ER(&1E\&EL+B(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HR-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE;65S(&1I<F5C=&]R>2!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R
M(")496UA(&1I>FEN:2`G)7,G(&)U;'5N86UA9/TN(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HQ-S@*;7-G:60@(E1H97)E(&%R92!N;R!O
M<'1I;VYS(&%V86EL86)L92XB"FUS9W-T<B`B2&GG8FER('-EYV5N96L@;65V
M8W5T(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C,T,@IM<V=I9"`B5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E
M(&1I<W!L87EE9"!I;FQI;F4N(@IM<V=S='(@(DUE=&YE(&?V;?QL_"!O;&%R
M86L@9_9S=&5R:6QE8FEL96-E:R!K_7/];2!Y;VLB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#`Q"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H
M97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO
M=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@(@HB>6]U(&UU<W0@96YT
M97(@;&5S<R!T:&%N("5S+B(*;7-G<W1R("(B"B)"=2!A;&%N9&$@YV]K(&9A
M>FQA(&MA<F%K=&5R('9A<BXE<R!T86YE(&MA<F%K=&5R(&=I<F1I;FEZ.R`E
M<R!T86YE9&5N(&%Z("(*(F=I<FUE;FEZ(&=E<F5K:7)D:2XB"@HC.B!S:6=N
M=7`N<&AP.C4S(&%D;6EN+W5S97(N<&AP.C<S"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R!<(B5S7"(@
M=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B)R5S)R!S:7-T96UE(&5K;&5N
M:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,B"@HC.B!A9&UI;B]U<V5R+G!H
M<#HQ,C(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E('=A<R!A
M('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B)R5S)R!K=6QL86[]8_UN_6X@=F5R:6QE
M<FEN:6X@<VES=&5M9&5N('-I;&EN;65S:6YD92!S;W)U;B!V87(Z("(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$P,PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R!<(B5S7"(@9G)O;2!T
M:&4@<WES=&5M.B`B"FUS9W-T<B`B)R5S)R!K=6QL86[]8_US_6[]('-I<W1E
M;61E;B#G_6MA<G3];&UA<_UN9&$@<V]R=6X@=F%R.B`B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ-3D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E1H97)E
M('=A<R!A('!R;V)L96T@=7!D871I;F<@7"(E<UPB.B`E<R(*;7-G<W1R("(G
M)7,G(&?\;F-E;&QE;FER:V5N('-O<G5N(&]L=?YT=3H@)7,B"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@3F\@)7,@=V%S('5P;&]A9&5D+B(*;7-G<W1R(")$;W-Y82`H:V%R_OUD
M86XI('G\:VQE;FUE<VEN9&4@<V]R=6X@=F%R.B`E<R!Y_&ML96YE;65D:2XB
M"@HC.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2`B"B)A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2XB"FUS9W-T<B`B(@HB
M1&]S>6$@>?QK;&5N:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,@96X@8OQY
M_&L@:7II;B!V97)I;&5N(&)O>75T=&%N("@E9"`B"B)B>71E*2!D86AA(&+\
M>?QK+B(*"B,Z(&9R86UE=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@Y,0HC
M+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY
M('5P;&]A9&5D+B(*;7-G<W1R(")$;W-Y82!Y_&ML96YI<FME;B!B:7(@<V]R
M=6X@;VQU_G1U.B`E<R!S861E8V4@:_US;6D@;VQA<F%K('G\:VQE;F1I+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z,S4*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S
M<V%G92!P87)T(@IM<V=S='(@(DEL971I;FEN(&)U(&O]<VW];OT@9_9R_&YT
M_&QE;FUE<VEN9&4@:&%T82!O;'7^='4N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O=F-A<F0N<&AP.C,Y"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HT.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("+=;&5T
M:?YI;2!N;VMT87/];OUN('9E<FEL97)I("AIYV5R:2D@86MT87+];/UR:V5N
M(&AA=&$@;VQU_G1U+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O:6UC+G!H
M<#HS,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(FE#86QE;F1A<B!V97)I<VD@*&GG
M97)I*2!A:W1A<OUL_7)K96X@:&%T82!O;'7^='4N(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HX,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@(@HB<F5Q=6ER960@9FEE;&0N(@IM<V=S='(@(B(*(EEA</UL86YD
M_7)M82!F;W)M=6YD82!B:7(@:&%T82!V87(N($=E<F5K;&D@8FER(&%L86[]
M(&1O;&1U<FUA;?W^("(*(F]L86)I;&ER<VEN:7HN(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S@*;7-G:60@(B(*
M(E1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA
M=&5R+B(*;7-G<W1R("(B"B)"96QI<G1I;&5N(&%D<F5S(&1E9G1E<FD@:?YL
M979I;FEN(&=E<N=E:VQE_G1I<FEL;65S:2!S_7)A<_UN9&$@<V]R=6X@(@HB
M;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T96MR87(@9&5N97EI;BXB"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T
M,`IM<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S
M='(@(B(*(MUL971I_FEM(&YO:W1A<_UN_6X@87ER_6YT_6QA<OUN_2!G_&YC
M96QL97)K96X@:&%T82!O;'7^='4N($S\=&9E;B!D86AA("(*(G-O;G)A('1E
M:W)A<B!D96YE>6EN+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z,C(R"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+B(*;7-G<W1R("(B"B)$8?#]=/UM(&QI<W1E<VEN:2!G_&YC
M96QL97)K96X@8FER(&AA=&$@;VQU_G1U+B!,_'1F96X@9&%H82!S;VYR82!T
M96MR87(@(@HB9&5N97EI;BXB"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HQ-#@*;7-G:60@(E1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N(@IM<V=S='(@(D)U($E-
M05`@<W5N=6-U<W4@<&%Y;&'^_6QA;B!D:7II;FQE<FD@9&5S=&5K;&5M:7EO
M<BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C0X
M"FUS9VED(")4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A
M<B!A<F-H:79E+B(*;7-G<W1R(")"=2!G9>=E<FQI(&)I<B!R87(@87+^:79I
M(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP
M:'`Z-3(*;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N(@IM<V=S='(@(D)U(&=EYV5R;&D@8FER('II<"!D;W-Y
M87/](&1E\&EL+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q-#4*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+B(*;7-G<W1R(")"=2!G9>=E<FQI(&)I<B!K87)T(&YU;6%R87/]
M(&1E\&EL+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T
M<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$DB"FUS9W-T<B`B(@HB0G4@<_QR_&/\($-L:6-K871E;&P@*&AT='`Z
M+R]C;&EC:V%T96QL+F-O;2D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10($%0
M22`B"B)K=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*(RP@
M9G5Z>GD*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F
M(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI
M("(*(F=A=&5W87DL('5S:6YG('1H92!(5%10($%022(*;7-G<W1R("(B"B)"
M=2!S_'+\8_P@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL*2!A\"!G9>=I
M9&D@_'IE<FEN9&5N($A45%`@05!)("(*(FMU;&QA;F%R86L@;65S86H@871M
M86[]>F$@:7II;B!V97)I<BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*(D)U('/\<OQC_"!S;7,R96UA:6P@
M*&AT='`Z+R]S;7,R96UA:6PI(&'P(&=EYVED:2#\>F5R:6YD96X@2%144"!!
M4$D@(@HB:W5L;&%N87)A:R!M97-A:B!A=&UA;OUZ82!I>FEN('9E<FER+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N
M<&AP.C@U"FUS9VED("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L
M>2`B"B)G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E
M<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*;7-G<W1R("(B"B)"=2!S_'+\8_P@
M4TU44"!Y;VQU>6QA(%9O9&%F;VYE($ET86QY(&'P(&=EYVED:2#\>F5R:6YD
M96XL('-A9&5C92!6;V1E9F]N92`B"B)N=6UA<F%L87+];F$@;65S86H@871M
M86[]>F$@:7II;B!V97)I<BX@5F]D969O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2`B"B)E;&5K=')O;FEK('!O<W1A(&%D<F5S:2!G97)E:W1I<FUE
M:W1E9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDW."!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4W"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$P.#8@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-0HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3@R(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$R-38*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,P-2!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,SDX"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$U-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S.0HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(P,#4*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`R
M.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#<X"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(Q-#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(R
M,0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-#$P(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(T-30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C8U-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#(X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,Q,S<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,P-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#$T(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C,X,C(*;7-G:60@(E1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N(@IM<V=S='(@(D)U(&=E<F5K;&D@8FER(&%L86YD_7(N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`V-0IM<V=I9"`B5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+B(*;7-G<W1R(")"=2!A;&%N
M('-A9&5C92!S87G](&GG97)M96QI9&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(D)U(&%L86X@
M<V%D96-E('-A>?T@=F4@:6MI(&YO:W1A(/QS=/QS=&4@:?YA<F5T:2!IYV5R
M96)I;&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G
M:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N
M(@IM<V=S='(@(D)U(&%L86X@<V%D96-E('-E:VEZ;&EK('-A>?T@<VES=&5M
M:6YD96X@9&7P97)L92!IYV5R96)I;&ER+B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S(@IM<V=S
M='(@(D)U(&%L86X@=FER9_QL('9E>6$@8F_^;'5K;&$@87ER_6QM_?X@<V%Y
M_2!L:7-T92!O;&UA;/UD_7(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z.3@Y"FUS9VED(")4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N(@IM<V=S='(@(D)U(&%L86X@9V7G97)L:2!B:7(@;G5M87)A(&]L;6%L
M_63]<BXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED
M("(B"B)4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@
M=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N
M(@IM<V=S='(@(D)U(&%L86X@4D="($AE>"!B:>=I;6EN9&4@8FER(')E;FL@
M:V]D=2!IYV5R;65L:61I<BP@]G)N96LZ("<C,3(S-&%F)R(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R(")"=2!F;W)M('IA=&5N
M(&G^;&5N9&DN(@H*(SH@=&5M<&QA=&5S+VAE;'`O86)O=70N:6YC.C$*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!I<R`E<RXB"FUS9W-T<B`B0G4@)7,N
M(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT-3D*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B(@HB5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE
M8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I
M;"`B"B)C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W
M87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL("(*(F-L:65N
M=',@<&QE87-E('9I<VET("5S(@IM<V=S='(@(B(*(D)U(&)I<B!+;VQA8B!'
M<F]U<'=A<F4@;F5S;F5S:61I<BX@0G4@;F5S;F5Y:2!G]G)E8FEL;65K(&GG
M:6X@2V]L86(@(@HB1W)O=7!W87)E(&)IYVEM:6YI(&%N;&%Y86)I;&5N(&)I
M<B!E;&5K=')O;FEK('!O<W1A(&ES=&5M8VES:6YE(&=E<F5K('9A<BY"=2`B
M"B)E;&5K=')O;FEK(&ES=&5M8VD@;&ES=&5S:2!IYVEN("5S(&%D<F5S:6YE
M('7P<F%Y_6XN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP
M:'`Z-3DQ"B,L('!H<"UF;W)M870*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R(")"=2!I;&5T:2!S:7II;B!K87)A:W1E<B!K_&UE
M;FEZ9&5N(&9A<FML_2!O;&%R86LH)7,I('EA>OUL;?W^=/UR+B(*"B,Z(&9R
M86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3(V"FUS9VED(")4:&ES(&YU
M;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92XB"FUS9W-T<B`B0G4@;G5M87)A
M(&5N(&%Z_6YD86X@8FER(&]L;6%L_63]<BXB"@HC.B!F<F%M97=O<FLO0V]M
M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R
M(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R
M(")"=2!S=6YU8W4@>FEP('9E(&=Z:7`@9&]S>6%L87+];OT@8>=A;6%M86MT
M863]<BXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP
M.C$X.0IM<V=I9"`B5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A
M=&5D+B(*;7-G<W1R(")3:7-T96UI;B!E=&MI;FQI\&D@:V%L9/UR_6QM_?YT
M_7(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,C0*;7-G
M:60@(E1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BXB"FUS9W-T<B`B0G4@
M9&7P97(@8FER('-A>?T@;VQM86S]9/UR+B(*"B,Z('-E<G9I8V5S+VEM86=E
M<R]C;VQO<G!I8VME<BYP:'`Z,S4*;7-G:60@(E1H:7,@=VEN9&]W(&UU<W0@
M8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<B"FUS9W-T<B`B0G4@
M<&5N8V5R92!39>=E;F5K;&5R('!E;F-E<F5S:6YD96X@YV'P<OUL;6%L_63]
M<BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HV
M-`IM<V=I9"`B5&AU;F1E<B(*;7-G<W1R(")']FL@9_QR_&QT_'/\(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(S-`IM<V=I9"`B5&EC:V5T<R(*
M;7-G<W1R(")":6QE=&QE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(T,C@@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"FUS9VED(")4
M:6UE(@IM<V=S='(@(EIA;6%N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C,X-@IM<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("):86UA;B#=
M>FQE;64B"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z,3<*;7-G:60@(E1I;64@
M9F]R;6%T(@IM<V=S='(@(EIA;6%N($)IYVEM:2(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C(U,SD*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S
M='(@(EIA;6%N(%-EYVEM:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C,P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1I;6]R
M+4QE<W1E(@IM<V=S='(@(E1I;6]R+4QE<W1E(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R.2!L:6(O0FQO8VLO:69R86UE
M+G!H<#HR,`IM<V=I9"`B5&ET;&4B"FUS9W-T<B`B0F'^;/UK(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I9"`B
M5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R(")"8?YL_6L@*&'G_6ML86UA*3HB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<U
M"FUS9VED(")4;R(*;7-G<W1R(")+:6UE(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T
M<B`B(@HBQV]K;'4@]O!E('-EYVEM:2!IYVEN+"!T_6ML87)K96X@0V]N=')O
M;"`H4$,I('9E>6$@0V]M;6%N9"`H36%C*2!T=?YU;F$@(@HB8F%S_6XN(@H*
M(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0IM<V=I9"`B5&]D
M87DB"FUS9W-T<B`B0G5G_&XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C(X"FUS9VED(")4;V=G;&4@2%1-3"!3;W5R8V4B
M"FUS9W-T<B`B2%1-3"!+87EN8?#];F$@1V7G:6XB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C(R,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C(R,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`Y
M"FUS9VED(")4;V=O(@IM<V=S='(@(E1O9V\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(R-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$P"FUS
M9VED(")4;VME;&%U(@IM<V=S='(@(E1O:V5L874B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R
M(")987+];B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(Y(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1O;F=A(@IM<V=S='(@
M(E1O;F=A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`BW'-T(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,PIM<V=I9"`B
M5&]P(&9R86UE("A?=&]P*2(*;7-G<W1R("+<<W0@QV5RYV5V92`HW%]S="DB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T
M:6]N<R(*;7-G<W1R("+'979I<FEL97(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED
M(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(E1R:6YI9&%D('9E(%1O
M8F%G;R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@
M(E1R=64@;W(@9F%L<V4B"FUS9W-T<B`B1&_P<G4@=F5Y82!986YL_?XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4W"FUS
M9VED(")4=2(*;7-G<W1R(")382(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C(X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(W
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U
M;FES:6$B"FUS9W-T<B`B5'5N=7,B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(R
M.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS9VED(")4
M=7)K97DB"FUS9W-T<B`B5/QR:VEY92(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DR"FUS9VED(")4=7)K:7-H("A)4T\M.#@U.2TY*2(*;7-G<W1R(")4
M_')KYV4@*$E33RTX.#4Y+3DI(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,CD*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5'5R
M:VUE;FES=&%N(@IM<V=S='(@(E3\<FMM96YI<W1A;B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C(P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C,P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#@*;7-G:60@(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(*;7-G<W1R(")4
M=7)K<R!V92!#86EC;W,@061A;&%R_2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3$*;7-G:60@
M(E1U=F%L=2(*;7-G<W1R(")4=79A;'4B"@HC.B!F<F%M97=O<FLO0TQ)+T-,
M22YP:'`Z,C8T"FUS9VED(")4>7!E('EO=7(@8VAO:6-E.B`B"FUS9W-T<B`B
M4V7G:6UI;FEZ:2!G:7)I;CHB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS9W-T<B`B52Y6+B!E
M;F1E:W,Z("(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HR-#D@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,3<*;7-G:60@(E523"(*
M;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M
M86EL7VAT='`N<&AP.C4T,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C<FEP="!D
M96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(D)E=&EK;&5R:6X@9'5R
M=6T@<F%P;W)L87+];OUN('1E<VQI;2!E9&EL96-E\&D@55),(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PIM<V=I9"`B
M55),.B(*;7-G<W1R(")54DPZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@IM<V=I9"`B56=A
M;F1A(@IM<V=S='(@(E5G86YD82(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,S
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*;7-G:60@(E5K
M<F%I;F4B"FUS9W-T<B`B56MR87EN82(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C0Q,@IM<V=I9"`B56YA8FQE('1O(&%C8V5S<R!61E,@9&ER
M96-T;W)Y+B(*;7-G<W1R(")61E,@9&EZ:6YI;F4@97)I_FEL96UE;6EY;W(N
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.CDV"FUS9VED
M(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S
M:6=N:6YG('5P+B(*;7-G<W1R("+<>64@;VQU<FME;B!E:R!K=6QL86[]8_T@
M8FEL9VES:2!E:VQE;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C,X.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M7"(E<UPB(%9&4R!D;W-Y87/];OUN(&EZ:6YL97)I(&1E\&G^=&ER:6QE;6EY
M;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE
M=V]R:R]61E,O5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RXB"FUS9W-T<B`B)7,O)7,@5D93(&1O<WEA<_UN_6X@:7II;FQE<FD@
M9&7P:?YT:7)I;&5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C<U-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+B(*;7-G<W1R("(E<R!D9?!I_G1I<FEL96UE9&DN(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,S(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<UPB
M+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@8>?];&%M_7EO<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HV.#@@9G)A;65W;W)K+U9&
M4R]61E,O<W%L+G!H<#HQ,#$V"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F
M:6QE+G!H<#HX,S0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E<R\E<UPB+B(*;7-G<W1R("(E
M<R\E<R!61E,@9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S<6PN<&AP.C0S-0IM<V=I9"`B56YA
M8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB"FUS9W-T<B`B4U%,('-U
M;G5C=7-U;F$@8F'P;&%N_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HX,SD*;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+B(*;7-G<W1R(")34TP@:6QE(&)A\&QA;OUL86W]>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,S`*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N
M<&AP.C$Y-B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#D*;7-G:60@(E5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!K
M;W!Y86QA;F%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C,V-0HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@7"(E<UPB+B(*;7-G<W1R(")<(B5S7"(@5D93(&1I>FEN
M:2!Y87)A=/UL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C4X"B,Z(&9R
M86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-38*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`B5D93(&1I>FEN
M:2!Y87)A=/UL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HQ,C0*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N(@IM
M<V=S='(@(E9&4R!D;W-Y87/]('EA<F%T_6QA;?UY;W(N(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<VUB+G!H<#HR.#8*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E<B!<(B5S7"(N(@IM
M<V=S='(@(E9&4R!D;W-Y87/](%PB)7-<(B!Y96YI9&5N(&%D;&%N9/UR_6QA
M;?UY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C8U"FUS
M9VED(")5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R
M(")";_X@5D93(&1O<WEA<_T@>6%R873];&%M_7EO<BXB"@HC.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<#HW-@HC.B!F<F%M97=O<FLO
M0V]M<')E<W,O0V]M<')E<W,O9WII<"YP:'`Z-SD*;7-G:60@(E5N86)L92!T
M;R!D96-O;7!R97-S(&1A=&$N(@IM<V=S='(@(E9E<FD@<_UK_?YT_7+];&%M
M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DN(@IM<V=S='(@(EPB)7-<(B!D:7II;FD@<VEL:6YE;6EY;W(L
M(&1I>FEN(&)O_B!D9?!I;"XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X(&%D
M;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T<B`B
M)R5S)R!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,SDR"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS,3$@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,S-`HC+"!P:'`M9F]R;6%T"FUS9VED(")5
M;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2(*;7-G<W1R("(E<R!S:6QI;F5M:7EO<BP@9&EZ:6X@8F_^(&1E\&EL(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T."!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S4R"FUS9VED(")5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN(@IM<V=S='(@(E9&
M4R!D:7II;FD@]GIY:6YE;&D@;VQA<F%K('-I;&EN96UI>6]R+B(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S-R!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,S(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H
M<#HS,S4@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C,T,PHC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S0T"FUS9VED(")5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(@IM<V=S='(@(E9&4R!D:7II;FD@
M<VEL:6YE;6EY;W(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT
M,3<@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB
M"FUS9W-T<B`B5D93(&1I>FEN:2!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(E9&4R!D;W-Y87/](%PB)7-<(B!S:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,#,@9G)A;65W;W)K+U9&4R]61E,O<W%L
M+G!H<#HR.#@*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$V-R!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3@P"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+VUU<W%L+G!H<#HQ.#<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I
M;&4N<&AP.C,X,PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,SDQ"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+B(*;7-G<W1R
M(")61E,@9&]S>6%S_2!S:6QI;F5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S;6(N<&AP.C(T-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R(%PB)7-<(BXB"FUS9W-T<B`B
M5D93(&1O<WEA<_T@7"(E<UPB('-I;&EN96UI>6]R+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;"YP:'`Z-#`V"B,L('!H<"UF;W)M870*;7-G:60@(E5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B
M5D93(/9Z>6EN96QI(&]L87)A:R!S:6QI;F5M:7EO<CH@)7,N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX,#,*;7-G:60@(E5N86)L92!T;R!D
M971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN(@IM<V=S='(@(EG\<OQR;/QK
M=&5K:2!D:7II;F4@:V%R87(@=F5R:6QE;6EY;W(N(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV,#,*;7-G:60@(E5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',B"FUS9W-T<B`B3VYA>2!B96QG
M97-I(&%Y<OUN=/UL87+](.?]:V%R=/UL86W]>6]R(@H*(SH@9G)A;65W;W)K
M+TYE=%])35-0+TE-4U`N<&AP.C0U,2!F<F%M97=O<FLO3F5T7TE-4U`O24U3
M4"]!=71H+G!H<#HQ,3@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N(@IM<V=S='(@(E1A;OUM_2!Y
M_&ML96YE;6EY;W(Z("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HQ-S$*;7-G:60@(E5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!T8?[];F%M_7EO<BXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.CDS(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z,3`R"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M-C0X(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z.3@*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B56YA8FQE('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G
M<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@8>?];&%M_7EO<BXB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,3,S"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@
M=W)I=&EN9RXB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%M86L@:>=I;B!AY_UL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C@P(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-S(*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE+B(*;7-G<W1R(")61E,@9&]S>6%S_2!AY_UL86W]>6]R+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#4*;7-G:60@
M(E5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`B
M4_UK_?YT_6S];?W^(&%R_FEV(&'G_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,N<&AP.C@S-0HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2XB"FUS9W-T<B`B5D93
M(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH*2!B8?YA<OUS_7H@;VQD=2DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B5D93(&1O<WEA<_T@>6%Z_6QA;?UY;W(@*&-O<'DH
M*2!B8?YA<OUS_7H@;VQD=2DN(@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD
M;&5R+U-E<W-I;VY(86YD;&5R+VYO;F4N<&AP.C,X"B,L(&9U>GIY"FUS9VED
M(")5;F%B;&4@=&\@<F5A9"!F:6QE.B`B"FUS9W-T<B`B5D93(&1O<WEA<_T@
M>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C8V.0IM<V=I9"`B56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+B(*;7-G<W1R(")69G-R;V]T(&1I>FEN:2!O:W5N
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z,3$P-0HC
M+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE("5S('1O("5S
M.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',B"FUS9W-T<B`B
M)7,M/B5S(&]L87)A:R!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(Z(&AE9&5F
M(&1I>FEN('IA=&5N('9A<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,CDS"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN(@IM<V=S='(@(E9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]<OUL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(E9&4R!D:7II;FD@>65N:61E;B!A9&QA;F3]
M<OUL86W]>6]R.B`E<R(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z
M,C8W(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S0S"B,L('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E<UPB+B(*
M;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@>65N:61E;B!A9&QA;F3]<OUL
M86W]>6]R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C8Q,"!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C(Y"B,L('!H<"UF;W)M870*
M;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N(@IM<V=S
M='(@(B5S+R5S(%9&4R!D;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO
M<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,R,R!F<F%M97=O
M<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C$S"B,Z(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HT-3(@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C(X-0HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S`Q"FUS
M9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@
M9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W
M;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4P"FUS
M9VED(")5;F%B;&4@=&\@<G5N("=M:VES;V9S)RXB"FUS9W-T<B`B)VUK:7-O
M9G,G(.=A;/W^=/UR_6QA;?UY;W(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`B0G4@5V]R9"!B96QG
M97-I(.=E=FER:6QI;&5M:7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C$T.2!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$U,@HC+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R(")61E,@9&]S>6%S_2!<(B5S7"(@>6%Z_6QA;?UY;W(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Y"FUS9VED(")5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+B(*;7-G
M<W1R(")61E,@9&]S>6%S_2!Y87K];&%M_7EO<B`H8V]P>2@I(&)A_F%R_7/]
M>B!O;&1U*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR.#$@
M9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S.`HC.B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"FUS9VED(")5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B5D93(&1O<WEA('9E<FES
M:2!Y87K];&%M_7EO<BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z.#0Q
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N(@IM<V=S='(@(E9&4R!D;W-Y87/]('EA
M>OUL86W]>6]R("AC;W!Y*"D@8F'^87+]<_UZ(&]L9'4I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N
M9&5R;&EN92(*;7-G<W1R(")!;'3];OT@YVEZ(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#:&%N9V5S(@IM<V=S='(@(D1E
M\&G^:6ML:6ML97)I($=E<FD@06PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;B(*;7-G<W1R(")3;VX@97EL96UI(&=E<FD@86PB"@HC.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,SDP"FUS9VED(")5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(*
M;7-G<W1R(")"8?!L86YT_61A('-U;G5C=61A;B!B96ML96YM97EE;B!Y86[]
M=#H@(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,C$Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S@*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@T"FUS
M9VED(")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B"FUS
M9W-T<B`B4W5N=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B`B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU-PHC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV,0IM<V=I
M9"`B56YF:6QE9"(*;7-G<W1R(")$;VQD=7)U;&UA;?W^(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G
M<W1R(")5;FEC;V1E("A55$8M."DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-@IM<V=I9"`B56YI
M=&5D($%R86(@16UI<F%T97,B"FUS9W-T<B`B0FER;&7^:6L@07)A<"!%;6ER
M;&EK;&5R:2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B56YI=&5D($MI;F=D;VTB
M"FUS9W-T<B`B0FER;&7^:6L@2W)A;&S]:R(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*;7-G
M:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`B06UE<FEK82!":7)L9?YI:R!$
M979L971L97)I(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,SD@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S<*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,PIM<V=I9"`B56YI=&5D(%-T871E
M<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S(@IM<V=S='(@(D%M97)I:V$@0FER
M;&7^:6L@1&5V;&5T;&5R:6YI;B!+_.?\:R!5>F%K($%D86QA<OTB"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-CD@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS9W-T<B`B0FER:6UL97(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,CD@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z-#,P"FUS9VED(")5;FMN;W=N(@IM<V=S='(@
M(D)I;&EN;65Y96XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@*$%0
M22!-97-S86=E($E$*2XB"FUS9W-T<B`B0FEL:6YM97EE;B!A<&EM<V=I9"`H
M05!)($UE<V%J($E$*2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C(Y.0IM<V=I9"`B56YK;F]W;B!C;&EM<V=I9"`H
M0VQI96YT($UE<W-A9V4@240I+B(*;7-G<W1R(")":6QI;FUE>65N(&-L:6US
M9VED("C=<W1E;6-I(&UE<V%J($E$*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M+G!H<#HQ-3D*(RP@9G5Z>GD*;7-G:60@(E5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N(@IM<V=S='(@(DAIYV)I<B!Y97(@8F5L:7)T:6QM961I
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N
M<&AP.C(Y,0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB
M"FUS9W-T<B`B0FEL:6YM97EE;B!K=6QL86[]8_T@863]('9E>6$@<&%R;VQA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHU.`IM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0B
M"FUS9W-T<B`BWG4@86YK:2#V\&5N:6X@8F'P_6[](.?V>B(*"B,Z(&9R86UE
M=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z,CDV"FUS9VED(")5;FYA;65D
M(@IM<V=S='(@(MUS:6US:7HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R
M:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC
M86QL>2!F;W(@(@HB<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E
M92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H
M;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C
M;&EP8F]A<F0N(@IM<V=S='(@(B(*(D%Y<OUC86S]:W/]>B!B971I:VQE<B!P
M<F]G<F%M<V%L(&]L87)A:R!+97,O2V]P>6%L82]987#]_G3]<B=A(&?\=F5N
M;&EK("(*(FYE9&5N:7EL92!E<FG^96UE>FQE<BX@0F5T:6ML97)I;B!P86YO
M>6$@;F%S_6P@=6QA_F%C8?#];OT@9_9S=&5R96X@;6]Z:6QL82XB"B)O<F<@
M=&5K;FEK(&YO='5N=2!G]G)M96L@:>=I;B!%5D54(&D@=/UK;&%Y_6XN(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX,@IM<V=I9"`B56YS970@8V]L;W(B"FUS9W-T<B`B0F5L:7)T:6QM:?X@
M<F5N:W1E;B!V87IG9><B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C8X-B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDR
M-@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.CDS,@IM<V=I
M9"`B56YS=7!P;W)T960@17AT96YS:6]N(@IM<V=S='(@(D1E<W1E:VQE;FUE
M>65N(%5Z86YT_2(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M,3DW('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,S"FUS9VED(")5
M<&1A=&4B"FUS9W-T<B`B1_QN8V5L;&4B"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]U<&1A=&4N:6YC.C(Y"B,L('!H<"UF;W)M870*;7-G:60@(E5P9&%T
M92`E<R(*;7-G<W1R(")'_&YC96QL93H@)7,B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G
M<W1R(")+=6QL86[]8_UY_2!G_&YC96QL92(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$P,B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5
M<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B1_QN8V5L;&5N9&DZ("<E<R<B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM<V=I9"`B57!G<F%D92!S
M8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B6?QK<V5L=&UE(&)E=&GP:2!S:6QI
M;&YD:2XB"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<X(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ.3D*;7-G:60@(E5P;&]A
M9"(*;7-G<W1R(")9_&ML92(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ
M.#8*;7-G:60@(E5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+B(*;7-G<W1R(")"_'3\;B!U>6=U;&%M86QA<OUN
M(&%Y87(@9&]S>6%L87+]('-U;G5C=7EA('G\:VQE;F1I+B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*
M;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`B0OQY_&L@;&%T
M:6X@:&%R9FQE<FDB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(D+\>?QK(')O;6$@<F%K86UL87+](@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HR-#$@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HR,S@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q,PIM<V=I9"`B57)U9W5A>2(*;7-G<W1R(")5<G5G=6%Y(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B57-E($-U<G)E;G0Z("5S(@IM<V=S='(@(DMU
M;&QA;CH@)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C4S.`IM<V=I9"`B57-E(%-33"(*;7-G<W1R(")34TP@:W5L
M;&%N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$R-`IM<V=I9"`B57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BXB"FUS9W-T<B`B2W5L;&%N_6/](&%D_6[]>B]P87)O;&%N_7H@24U34"!S
M=6YU8W4@:>=I;B!F87)K;/T@:7-E(&MU;&QA;OUN+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S
M97(B"FUS9W-T<B`B2W5L;&%N_6/];&%R(@H*(SH@9G)A;65W;W)K+TAO<F1E
M+TAO<F1E+U)E9VES=')Y+G!H<#HW,C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N(@IM<V=S='(@(B5S
M(&MU;&QA;OUC_7/]("5S(&GG:6X@9&_P<G5L86YA;6%D_2XB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HR,#,*;7-G:60@(E5S97(@061M:6YI<W1R871I;VXB"FUS
M9W-T<B`B2W5L;&%N_6/](%GV;F5T:6UI(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R
M(")+=6QL86[]8_T@4V7G96YE:VQE<FDB"@HC.B!S:6=N=7`N<&AP.C8R"FUS
M9VED(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")+=6QL86[]8_T@2V%Y
M_70B"@HC.B!S:6=N=7`N<&AP.C(R"FUS9VED(")5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+B(*;7-G<W1R(")"
M=2!S:71E(&GG:6X@:W5L;&%N_6/](&MA>63]('-EYVEL;65Z(&O];/UN;?W^
M=/UR+B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*(RP@9G5Z>GD*
M;7-G:60@(E5S97(@86-C;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B)7,@8G5L
M=6YA;6%D_2XB"@HC.B!A9&UI;B]U<V5R+G!H<#HS-2!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-3,V"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.CDX"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O=VEN7VAT='`N<&AP.C$U,"!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C<R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")5<V5R;F%M
M92(*;7-G<W1R(")+=6QL86[]8_T@063](@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]3:6=N=7`N<&AP.C$R-`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B57-E<FYA;64@7"(E<UPB(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")+
M=6QL86[]8_T@)R5S)R!Z871E;B!V87(N(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C@W"FUS9VED(")5<V5R;F%M93HB"FUS9W-T<B`B2W5L
M;&%N_6/]($%D_3HB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHX
M"FUS9VED(")5<V5R;F%M93H@(@IM<V=S='(@(DMU;&QA;OUC_2!A9/TZ("(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C(*;7-G:60@(E5S
M97)S(&EN('1H92!S>7-T96TZ(@IM<V=S='(@(E-I<W1E;61E:VD@:W5L;&%N
M_6/];&%R.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0R(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,Y"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,30*;7-G:60@(E5Z8F5K:7-T86XB"FUS
M9W-T<B`BUGIB96MI<W1A;B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N
M<&AP.C$V,R!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-34*;7-G:60@
M(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(E9&4R!D
M:7II;FD@>6]K+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*
M;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(E1A=&EL(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z.#8V"FUS9VED(")686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@(@IM<V=S='(@(D=EYV5R;&D@:V]N=6UL87+];B!IYV5R
M9&EK;&5R:3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8S.`IM<V=I9"`B5F%L:61I='DB"FUS9W-T<B`B1V7G97)L:6QI:R(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3DW
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB"FUS9W-T
M<B`BWG4@86YD86X@:71I8F%R96X@9&%K:6MA(&1E\&5R:2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C@U-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3<W"B,L('!H<"UF;W)M870*;7-G:60@(E9A;'5E(&ES(&]V97(@=&AE
M(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,C0T(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R-C8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C,Q-B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.3(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO
M5'EP92]T86)L97-E="YP:'`Z-3D*;7-G:60@(E9A;'5E<R(*;7-G<W1R(")$
M9?!E<FQE<B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#D@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B5F%L=65S('1O('-E
M;&5C="!F<F]M(@IM<V=S='(@(D1E\&5R;&5R:6X@<V7G:6QE8V7P:2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B5F%N=6%T=2(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#0*;7-G:60@(E9A
M<FEA8FQE(@IM<V=S='(@(D1E\&G^:V5N(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-0IM<V=I
M9"`B5F5N97IU96QA(@IM<V=S='(@(E9E;F5Z=65L;&$B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T
M:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E
M<F5D('=I=&@N(@IM<V=S='(@(D1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2`M
M(&)U(&EL971I(&MU<F-A;&%N;?W^(&]L86)I;&ER+B`@(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,#`*;7-G:60@(E9E<G-I;VXB
M"FUS9W-T<B`B4_QR_&TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M,C(V"FUS9VED(")697)S:6]N($-O;G1R;VPB"FUS9W-T<B`B4_QR_&T@2V]N
M=&]L_"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#,*;7-G:60@(E9E<G1I8V%L(&%L:6=N(@IM<V=S='(@(D3\
M_F5Y($AI>F$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@T"FUS9VED(")697)T:6-A;"!P861D:6YG(@IM<V=S='(@(D3\
M_F5Y('EA<W3]:VQA;6$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@S"FUS9VED(")697)T:6-A;#HB"FUS9W-T<B`B1/S^
M97DZ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-S`*;7-G:60@(E9E<GD@2&EG:"(*;7-G<W1R("+';VL@6?QK<V5K(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#@@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HR-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-@IM<V=I9"`B5FEE="!.86TB"FUS9W-T<B`B5FEE=&YA;2(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DT"FUS9VED(")6:65T;F%M97-E
M("A625-#24DI(@IM<V=S='(@(E9I971N86UC82`H5DE30TE)*2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.CDV,@HC+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W("5S(@IM<V=S='(@(D?V<OQN=/QL92`E<R(*"B,Z
M(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@86X@97AT97)N
M86P@=V5B('!A9V4B"FUS9W-T<B`B0FER(&3]_B!W96(@<V%Y9F%S_2!G]G+\
M;G3\;&4B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HX
M,C$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("(E
M<R!O;&%R86L@9_9R_&YT_&QE(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER
M9VEN($ES;&%N9',L($)R:71I<V@B"FUS9W-T<B`B0G)I=&%N>6$G>6$@86ET
M(%9I<F=I;B!!9&%L87+](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR-#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#0*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-@IM<V=I9"`B5FER9VEN
M($ES;&%N9',L(%4N4RXB"FUS9W-T<B`B06UE<FEK82!":7)L97+^:6L@1&5V
M;&5T;&5R:2=N92!A:70@5FER9VEN($%D86QA<OTB"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(P.0IM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R(")']G+\
M_B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@
M(E9I<VEB:6QI='DZ("(*;7-G<W1R(")']G+\_CHB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HX-`IM<V=I9"`B
M5F]D869O;F4@271A;'D@=FEA(%--5%`B"FUS9W-T<B`B4TU44"!Y;VQU>6QA
M(%9O9&%F;VYE(-UT86QY82(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!
M4DXB"FUS9W-T<B`B5T%23B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP
M.C@U"B,L('!H<"UF;W)M870*;7-G:60@(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(*;7-G<W1R(")564%222$A(25S(-W'
MW4Y$14X@0D54W=#=($5,(-U,12#'24M!4E1)3BXB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$S,PHC+"!F=7IZ>0IM<V=I9"`B
M5TE.('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L=7EL82!S;7,R96UA:6PB
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3$W"FUS9VED(")786QL:7,@86YD($9U='5N82(*;7-G
M<W1R(")786QL:7,@=F4@1G5T=6YA(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A
M=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L
M;V-K+V%C8V]U;G0N<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(E5Y
M87+](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ
M<SHU.`IM<V=I9"`B5V4B"FUS9W-T<B`BQW+^(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Y"FUS9VED(")796%T:&5R($9O<F5C87-T(@IM
M<V=S='(@(DAA=F$@5&%H;6EN:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HT,C<*;7-G:60@(E=E871H97(@9&%T82!P<F]V:61E9"!B>2(*
M;7-G<W1R(")(879A('9E<FES:2!S8?!L87G]8_US_2(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T
M<B`B5V5A=&AE<BYC;VTB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS-@IM
M<V=I9"`B5V5B(@IM<V=S='(@(E=E8B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT,S<*;7-G:60@(E=E8B!3:71E(@IM<V=S='(@(E=E8B!3:71E
M<VDB"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`B2&%F=&%L_6LB"@HC.B!S97)V
M:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM<V=I9"`B5V5L8V]M92(*;7-G
M<W1R(")(;_YG96QD:6YI>B(*"B,Z('1E;7!L871E<R]L;V=I;B]M;V)I;&4N
M:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN+FEN8SHU-PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")796QC;VUE('1O("5S(@IM<V=S='(@(B5S($AO_F=E;&1I
M;FEZ(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP:'`Z,CD@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M870*;7-G:60@(E=E
M;&-O;64L("5S(@IM<V=S='(@(DAO_F=E;&1I;FEZ+"`E<R(*"B,Z(&-O;F9I
M9R]N;',N<&AP+F1I<W0Z,3DU"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ
M*2(*;7-G<W1R(")"873]("A)4T\M.#@U.2TQ*2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS
M9W-T<B`B0F%T_2`H25-/+3@X-3DM,34I(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S$*;7-G:60@
M(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@(D)A=/T@4V%H<F$B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z-#,W"B,L('!H<"UF;W)M870*;7-G:60@(E=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M(@IM<V=S='(@(B5S(&=I<FG^=&5N('-O;G)A(&AA;F=I('5Y9W5L86UA>?T@
M9_9R_&YT_&QE<VEN/R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC
M.C$T"FUS9VED(")7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*
M;7-G<W1R(")3_6[]<FQA>?UC_2!K87)A:W1E<B!N961I<C\B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHQ-PIM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R(")!:W1A<OUM(&MA<F%K=&5R:2!N
M961I<C\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,3`V,0HC+"!F=7IZ>0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P
M(@IM<V=S='(@(D%V=7-T=7)A;'EA(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP
M.C(S"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`B2&%N9VD@179R92(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,S,*;7-G:60@(E=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BXB"FUS
M9W-T<B`B(@HB6F5N9VEN($UE=&EN(&3\>F5N;&5Y:6-I<VD@:>=I;B!H86YG
M:2!U>75M;'4@96ML97(@<V7G:6QE8FEL:7(@:_UL_6YS_6XN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM
M<V=I9"`B5VED=&@B"FUS9W-T<B`B1V5N:?YL:6LB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,3(U"FUS9VED(")7:61T:"!I;B!#4U,@=6YI=',B
M"FUS9W-T<B`B0U-3(&)I<FEM:7EL92!G96YI_FQI:R(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HS-3<*(RP@<&AP+69O<FUA=`IM<V=I9"`B5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ(@IM<V=S='(@(E-O;&1A:VD@)7,@;65N_'/\;OQN(&=E
M;FG^;&GP:2`H8FER('-O;G)A:VD@9VER:?YT92!E=&MI;B!O;&%C86LI.B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`V
M"FUS9VED(")7:61T:"!O9B!T:&4@=&%B;&4B"FUS9W-T<B`BQVEZ96QG96YI
M;B!G96YI_FQI\&DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$Q,`IM<V=I9"`B5VED=&@@=6YI="(*;7-G<W1R(")'96YI
M_FQI:R!B:7)I;6DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-0IM<V=I9"`B5VED=&@Z(@IM<V=S='(@(D=E;FG^;&EK
M.B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HU,3,*;7-G:60@(E=I
M:VDB"FUS9W-T<B`B5VEK:2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HS,#`@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C4*;7-G:60@(E=I;F0B"FUS9W-T<B`B4OQZ9V%R(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C8*;7-G:60@(E=I;F0@16%R
M;'DB"FUS9W-T<B`B17)K96X@4V%A=&QE<F1E(%+\>F=A<B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z.#`*;7-G:60@(E=I;F0@<W!E960@:6X@:VYO=',B
M"FUS9W-T<B`B2VYO="!B:7)I;6EN9&4@<OQZ9V%R(&C]>OTB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C$U-@IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B4OQZ
M9V%R.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#(*;7-G
M:60@(E=I;F0Z("(*;7-G<W1R(")2_'IG87(Z("(*"B,Z(&QI8B]";&]C:R]F
M;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(D)I;&=E;&EK
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y-@HC+"!F=7IZ>0IM
M<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`BW7-T96L@3&ES=&5S:2(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("+=
M_B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M,C0*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$V
M-`IM<V=I9"`B5V]R:R!!9&1R97-S(@IM<V=S='(@(MW^($%D<F5S:2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.3(*;7-G
M:60@(E=O<FL@4&AO;F4B"FUS9W-T<B`BW?X@5&5L969O;G4B"@HC.B!F<F%M
M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HQ-CD@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z,C8R"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E
M<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HS
M,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ,30*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N(@IM<V=S='(@(E9&4R!D:7II;FD@>6%R873];/UR:V5N(&5R:?YI
M;2!E;F=E;&QE;F1I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3,*;7-G:60@(E@U,#EV,R!"87-I
M8R!#;VYS=')A:6YT<R(*;7-G<W1R(")8-3`Y=C,@5&5M96P@2_US_71L86UA
M;&%R_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR
M"FUS9VED(")8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U
M,#EV,R!'96YI_FQE=&EL;6G^($%N86AT87(@2W5L;&%N_6W](@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.30*;7-G:60@(E@U,#EV
M,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64B"FUS9W-T<B`B6#4P.78S(-9T
M96MI($MO;G4@063](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(E@U,#EV,R!+;VYU($%N86AT87(@5&%N_73]8_US_2(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C@R"FUS9VED(")8
M-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R(")8-3`Y=C,@=7IA;G3];&%R_2(*
M"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0W('1E;7!L871E<R]D871A
M+V1A=&4N:6YC.C0X"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C0Y('1E
M;7!L871E<R]D871A+V1A=&4N:6YC.C4P"FUS9VED(")962(*;7-G<W1R(")9
M62(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,3,*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0U
M-0IM<V=I9"`B65E962(*;7-G<W1R(")965E9(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C$Q,#@*;7-G:60@(EEA:&]O(2!M
M87`B"FUS9W-T<B`B66%H;V\A(&AA<FET87/](@H*(SH@9G)A;65W;W)K+TUA
M:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HU-@IM<V=I9"`B665A<FQY(@IM
M<V=S='(@(EG];&S]:R(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C4R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*;7-G:60@(EEE;65N(@IM
M<V=S='(@(EEE;65N(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.CDV,PIM<V=I9"`B665S(@IM<V=S='(@(D5V970B"@HC.B!T
M96UP;&%T97,O;6%I;G1E;F%N8V4O;6%I;G1E;F%N8V4N:'1M;#HU-@IM<V=I
M9"`B665S+"!)($%G<F5E(@IM<V=S='(@(D5V970L($MA8G5L($5D:7EO<G5M
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU
M,@IM<V=I9"`B66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N(@IM<V=S='(@(B(*
M(DU%5-U.($U/1%5.1$%324Y)6BX@6SP^72!D_/!M96QE<FEN:2!K=6QL86YA
M<F%K(%=94TE764<@9_9R_&[\;?QN92!D]F[\;BXB"@HC.B!S97)V:6-E<R]P
M;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B66]U(&%R
M92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-#$Q
M"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*;7-G<W1R(")$
M;_!R=6QA;F%M863];OUZ+B(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N
M=&ET>2YP:'`Z,S`R"FUS9VED(")9;W4@8V%N(&YO="!H879E('1H92`G7%PG
M(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS9W-T<B`B)UQ<)R!K
M87)A:W1E<FD@=&%M(&%D_6[]>F1A(&)U;'5N86UA>BXB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HQ.#4U(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C$Y-S4*;7-G:60@(EEO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@
M861D<F5S<RXB"FUS9W-T<B`B1V7G97)L:2!B:7(@96QE:W1R;VYI:R!P;W-T
M82!A9')E<VD@9VER;65D:6YI>BXB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB)7,@
M:>=I;F1E(&MA<O[];/UK(&=E;&5N(&%L86YL87)L82`H:>=E<FDI(&%K=&%R
M_6QA;B!D;W-Y861A:VD@86QA;FQA<OT@(@HB9?YL9?YT:7)M961I;FEZ+B(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B66]U(&AA
M=F4@8F5E;B!L;V=G960@;W5T+B(*;7-G<W1R("+'_6O]_B!Y87!M863];OUZ
M+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R-C$*;7-G:60@(B(*
M(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@
M9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@(@HB9F]R('1H92!I
M;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+B(*;7-G<W1R("(B"B)'9>=E
M<FQI(&)I<B!C97`@=&5L969O;G4@;G5M87)A<_T@9VER;65L:7-I;FEZ+"!S
M87G];&%R('9E('-EYV5N96ML:2!O;&%R86L@(@HB=6QU<VQA<F%R87/](&%R
M86UA(/9N96MI("<K)R`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,3@X"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+B(*
M;7-G<W1R(")'9>=E<FQI(&)I<B!D9?!E<B!G:7)M96QI<VEN:7HN(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C,W"FUS9VED(")9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+B(*;7-G<W1R("+<>64@:V%Y9/T@>6%P86)I;&UE:R!IYVEN(&)I<B!6
M97)I0?!A8_T@>6%P_6QA;F3]<FUA;/US_6[]>BXB"@HC.B!F<F%M97=O<FLO
M2&]R9&4O2&]R9&4N<&AP.C0U-@IM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N(@IM<V=S='(@(E9&4R!S;VX@8?YA;6%S_6[]('EA
M</UL86YD_7)M86S]<_UN_7HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O
M8FQE;2YI;F,Z,3$*;7-G:60@(EEO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+B(*
M;7-G<W1R(")0<F]B;&5M(')A<&]R=2!G]FYD97)M961E;B#V;F-E('-O<G5N
M=2!T87)F:2!E=&UE;&ES:6YI>BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@;75S="!E;G1E<B!T
M:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B"FUS9W-T<B`B0G4@
M8F'P;&%N=/UN_6X@9_9S=&5R9&GP:2!B:7(@55),(&=I<FUE;&ES:6YI>B(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]R<&-S=6TN<&AP.C@P"FUS9VED(")9;W4@
M;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N(@IM<V=S='(@
M(E-I;&EN;65S:2!IYVEN(&)I<B!S=6YU8W4@<V7G;65L:7-I;FEZ+B(*"B,Z
M(&%D;6EN+W5S97(N<&AP.C$Q.0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A
M('5S97)N86UE('1O(&-L96%R(&]U="XB"FUS9W-T<B`B5&5M:7IL96YM97-I
M;B!IYVEN(&)I<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N(@IM<V=S='(@(E-I;&EN;65S:2!IYVEN
M(&)I<B!K=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!A9&UI
M;B]U<V5R+G!H<#HV,B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC
M.C@*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"XB"FUS9W-T<B`B16ML96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@
M8F5L:7)T;65L:7-I;FEZ+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$T-@IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+B(*
M;7-G<W1R(")'_&YC96QL96YM97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@
M8F5L:7)T;65L:7-I;FEZ+B(*"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP
M<F5S<R]Z:7`N<&AP.C$S.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G<W1R(")'97+G96ML9?YT:7)I;&5C
M96L@8FER(&5Y;&5M(&)E;&ER=&UE;&ES:6YI>BXB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HW,0IM<V=I9"`B66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+B(*;7-G<W1R(")996YI
M(&MA=&5G;W)Y(&%D_2!G:7)M96QI<VEN:7HN(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-S,*;7-G:60@(EEO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3<V"B,L('!H
M<"UF;W)M870*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+B(*;7-G<W1R("(E<R!O='5R=6UU;G5N('/\
M<F5S:2!D;VQD=2X@3/QT9F5N('1E:W)A<B!G:7)I_B!Y87#];BXB"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHS.`IM<V=I9"`B66]U<B!%
M;6%I;"!!9&1R97-S(@IM<V=S='(@(D5L96MT<F]N:6L@4&]S=&$@061R97-I
M;FEZ(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Q,@IM<V=I9"`B66]U
M<B!&<F]M.B!A9&1R97-S.B(*;7-G<W1R(")+:6UD96XZ(&%D<F5S.B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G<W1R
M(")":6QG:6QE<FEN:7HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M.#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R`B"B)P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B(E<R!O='5R=6UU;G5Z=6X@
M8F'^;&%N9_UC_6YD82#=;G1E<FYE="!!9')E<VEN:6YI>B!D9?!I_G1I+B!'
M_'9E;FQI\&EN:7II("(*(FMO<G5M86L@:>=I;BP@>65N:61E;B!G:7)I_B!Y
M87!M86S]<_UN_7HN(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI
M;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R(")!9/UN_7HB"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-0HC+"!F=7IZ>0IM<V=I
M9"`B(@HB66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R`B"B)U<V4@2&]R
M9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@
M82!D:69F97)E;G0@(@HB875T:&5N=&EC871I;VX@8F%C:V5N9"XB"FUS9W-T
M<B`B(@HB2VEM;&EK(&1E;F5T:6UI;FEZ(&MU;&QA;OUC_2!E:VQE;65Y:2!D
M97-T96ML96UE;65K=&5D:7(L('9E>6$@8G4@]GIE;&QI:R`B"B)B:7(@;F5D
M96X@>?QZ_&YD96X@<V7G:6QE;65Z(&O];/UN;?W^=/UR+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B)+:6UL:6L@9&5N
M971I;6EN:7H@:W5L;&%N_6/](&QI<W1E;&5M97EI(&1E<W1E:VQE;65M96MT
M961I<B!V97EA(&)U(/9Z96QL:6L@(@HB8FER(&YE9&5N('G\>OQN9&5N('-E
MYVEL96UE>B!K_6S];FW]_G3]<BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+G!H<#HY.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B(@HB66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B`B"B)4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+B(*;7-G<W1R("(B"B(E<R!O='5R
M=6UU;G5Z=6X@8F'^;&%N9_UC_6YD82!T87)A>?UC_6[]>B!D9?!I_G1I+B!'
M_'9E;FQI\&EN:7II(&MO<G5M86L@(@HB:>=I;BP@>65N:61E;B!G:7)I_B!Y
M87!M86S]<_UN_7HN(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP:'`Z-3`*;7-G
M:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92XB"FUS9W-T<B`B5&%R87G]8_UN_7H@8G4@]GIE;&QI\&D@9&5S=&5K;&5M
M96UE:W1E9&ER+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W!R:6YT+FIS
M.C0R"B,L(&9U>GIY"FUS9VED("(B"B)9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"`B"B)T;R!P<FEN="XB"FUS9W-T<B`B(@HB5&%R87G]8_UN_7H@
M8G4@>6%Z9/UR;6$@=&5R8VEH:6YI(&1E<W1E:VQE;65M96MT961I<BY987ID
M_7)M86L@:>=I;B!#;VYT<F]L+R(*(D]P=&EO;B`K(%`@='7^;&%R_6YA(&)A
M<_UN+B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR-3<*;7-G:60@(EEO
M=7(@8W5R<F5N="!T:6UE('IO;F4Z(@IM<V=S='(@(EIA;6%N($1I;&EM:6YI
M>CHB"@HC.B!S97)V:6-E<R]P<F5F<RYP:'`Z.38*(RP@9G5Z>GD*;7-G:60@
M(EEO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+B(*;7-G
M<W1R("+6;B!T86[];6S](&MI;6QI\&EN:7HZ(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$U.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y.B(*
M;7-G<W1R("+6;B!T86[];6S](&MI;6QI\&EN:7HZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C(P,0IM<V=I9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S
M='(@(E1A;2!!9/UN_7HZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M,3`P,`HC+"!F=7IZ>0IM<V=I9"`B66]U<B!L;V=I;B!H87,@97AP:7)E9"XB
M"FUS9W-T<B`B4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN(@H*(SH@<V5R
M=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<R(*;7-G<W1R("(E
M<R!IYVEN('EE;FD@<&%R;VQA;OUZ.B`E<R(*"B,Z(&9R86UE=V]R:R]0<F5F
M<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@:&%V92!B
M965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN
M(@IM<V=S='(@(E-EYV5N96ML97)I;FEZ(&)U(&]T=7)U;75N('/\<F5S:2!I
MYVEN9&4@9_QN8V5L;&5N9&DN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HQ-38*;7-G:60@(EEO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"XB"FUS9W-T<B`B4V7G96YE:VQE<FEN:7H@9_QN8V5L;&5N9&DN(@H*
M(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@
M<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T<B`B4&%R;VQA;OUZ('/]
M9OUR;&%N9/TN(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-SD*
M;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A<W-W
M;W)D+B(*;7-G<W1R("(B"B)087)O;&%N_7H@<_UF_7)L86YD_2P@96QE:W1R
M;VYI:R!P;W-T86[]>OT@:V]N=&]L(&5D:6X@=F4@>65N:2!P87)O;&%N_7IL
M82`B"B)G:7)I_B!Y87#];BXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*(RP@9G5Z>GD*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N(@IM<V=S='(@(E!A<F]L86[]>B!S_6;]<FQA;F3]+B(*"B,Z('1E;7!L
M871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@
M<V5R=F5R<SHB"FUS9W-T<B`B57IA:W1A:VD@<W5N=6-U;&%R_6[]>CHB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-"!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z,3$X"FUS9VED(")9=6=O<VQA=FEA(@IM<V=S='(@
M(EEU9V]S;&%V>6$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED("):86ER92(*;7-G<W1R("):86ER92(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("):86UB:6$B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R(")::6UB86)V92(*"B,Z(&QI
M8B]";&]C:R]F;W)T=6YE+G!H<#HV-@IM<V=I9"`B6FEP<'DB"FUS9W-T<B`B
M2/UZ;/TB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL
M:6=H='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U
M;W1E0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS
M9W-T<B`B6T%L_6YT_2!-971N:2!386ML85TB"@HC.B!S97)V:6-E<R]P<F]B
M;&5M+G!H<#HX.`IM<V=I9"`B6U!R;V)L96T@4F5P;W)T72(*;7-G<W1R(");
M4')O8FQE;2!287!O<G5=(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O
M=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS
M9W-T<B`B6T%L_6YT_2!-971N:2!']G-T97(@+2(*"B,Z(&9R86UE=V]R:R]4
M97AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UTB"FUS9W-T<B`B6T%L_6YT_2!-971N:2!']G-T97(@+2`E<R!S873]<ETB
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(");;&EN92`E<R!O9B`E<UTB"FUS9W-T<B`B)7,O)7,@<V%T
M_7(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$U-#$@=&5M<&QA
M=&5S+W!O<G1A;"]M96YU+FEN8SHQ,0IM<V=I9"`B7T%D;6EN:7-T<F%T:6]N
M(@IM<V=S='(@(E]9]FYE=&EM(@H*(SH@;&EB+V%P:2YP:'`Z,34W"FUS9VED
M(")?0TQ)(@IM<V=S='(@(E]#3$DB"@HC.B!L:6(O87!I+G!H<#HQ-#$*;7-G
M:60@(E]$871A5')E92(*;7-G<W1R(")?5F5R:4'P86/](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Q"FUS
M9VED(")?1&5L971E(%)O=R(*;7-G<W1R(")3873]<OT@7U-I;"(*"B,Z(&QI
M8B]A<&DN<&AP.C$S,PIM<V=I9"`B7T=R;W5P<R(*;7-G<W1R(")?1W)U<&QA
M<B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G
M:60@(E](96QP(@IM<V=S='(@(EEA<E]D_6TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,C,*;7-G:60@(E])
M;6%G92!0<F]P97)T:65S+BXN(@IM<V=S='(@(D?V<OQN=/P@UE]Z96QL:6ML
M97)I+BXN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$Y
M-`IM<V=I9"`B7TQO9R!I;B(*;7-G<W1R(")':5]R:?XB"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DP"FUS9VED(")?3&]G(&]U="(*
M;7-G<W1R("+'_5]K_?XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN
M+B(*;7-G<W1R(")?0F'P;&%N=/UY_2!$9?!I_G1I<BXN+B(*"B,Z(&9R86UE
M=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS
M(@IM<V=S='(@(E]39>=E;F5K;&5R(@H*(SH@;&EB+V%P:2YP:'`Z,3,W"FUS
M9VED(")?4&5R;6ES<VEO;G,B"FUS9W-T<B`B7TAA:VQA<B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR-@IM
M<V=I9"`B7U)E;6]V92!,:6YK+BXN(@IM<V=S='(@(D)A\&QA7VYT_7G](%-I
M;"XN+B(*"B,Z(&QI8B]A<&DN<&AP.C$R-0IM<V=I9"`B7U-E='5P(@IM<V=S
M='(@(E]!>6%R;&%R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R("+':7IE7VQG92#6>F5L;&EK;&5R:2XN+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R.0IM<V=I9"`B7U5S97)S(@IM<V=S='(@(DM?=6QL86[]
M8_UL87(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,0IM<V=I
M9"`B861D<F5S<R!B;V]K(@IM<V=S='(@(F%D<F5S(&1E9G1E<FDB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$S-`HC+"!F=7IZ>0IM
M<V=I9"`B861D<F5S<V5E('5N:VYO=VXB"FUS9W-T<B`B861R97,@9&5F=&5R
M:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"FUS9VED(")C
M86QE;F1A<B(*;7-G<W1R(")T86MV:6TB"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C$W,B!L:6(O0FQO8VLO;65T87(N<&AP.C,U.`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")C86QM(@IM<V=S='(@(OUL_6UL_2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B8G5R87EA('3]:VQA
M>?UN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*
M;7-G:60@(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ
M>0IM<V=I9"`B8V]N9FEG=7)A=&EO;B!E<G)O<B(*;7-G<W1R(")987#];&%N
M9/UR;6$@1F%R:VQA<OTB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A
M9V4N<&AP.C$U-`IM<V=I9"`B8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N
M<&AP.C$R-@IM<V=I9"`B9&%T82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z
M>GD*;7-G:60@(F5N=')Y(&YO="!F;W5N9"(*;7-G<W1R(")B=6QU;F%M863]
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-S$*
M;7-G:60@(F9A;&QI;F<B"FUS9W-T<B`B9/S^_'EO<B(*"B,Z(&9R86UE=V]R
M:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0IM<V=I9"`B9FEL92(*;7-G<W1R
M(")D;W-Y82(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<T(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S8P(&QI8B]";&]C:R]M971A<BYP:'`Z,S@V"B,L('!H
M<"UF;W)M870*;7-G:60@(F9R;VT@=&AE("5S("@E<RD@870@)7,@)7,B"FUS
M9W-T<B`B)7,@*"5S*2!D96X@)7,@)7,@9&4B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM
M<V=S='(@(BP@9OUR=/UN86S]("5S("5S(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(T.0IM<V=I9"`B:#HB"FUS9W-T<B`B
M:#HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S4X"FUS9VED(")H:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TUE<W-A9V4N<&AP.C$S.`IM<V=I9"`B:&]S="!N86UE('5N:VYO=VXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K
M871E;&Q?:'1T<"YP:'`Z,C(S"FUS9VED(")I;6UE9&EA=&4B"FUS9W-T<B`B
M06-I;"(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C8W(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C<Y"FUS9VED(")I;FQI;F4B"FUS9W-T<B`B365T;F4@9_9M
M_&S\(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ-C(*
M;7-G:60@(FEN<'5T+V]U='!U="!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$T-@IM<V=I9"`B:6YT97)N
M86P@<V]F='=A<F4@97)R;W(B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(FQI;F5S72(*;7-G
M<W1R(")S873]<FQA<ETB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O;6MI<V]F<RYP:'`Z-3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N(@IM<V=S
M='(@(FUK:7-O9G,@25-/('EA<&%R:V5N(&AA=&$@:V]D=3HE9"XB"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S8Y"FUS9VED
M(")M;2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN
M<&AP.C(Y,2!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3<P"B,Z('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,S(*;7-G:60@(FYA;64B"FUS
M9W-T<B`B860B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(Q"FUS9VED
M(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`B9V5RYV5K;&7^=&ER:6QM961I
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"FUS
M9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(FAE;OQZ(&=E<N=E
M:VQE_G1I<FEL;65D:2(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3`U"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(FYO="!D969T97)I(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R(")Y_'ID92(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O365S<V%G92YP:'`Z,3<T"B,L(&9U>GIY"FUS9VED(")P
M97)M:7-S:6]N(&1E;FEE9"(*;7-G<W1R("+=>FEN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX.0IM<V=I9"`B
M<&EX96QS(@IM<V=S='(@(G)E<VEM(&)I<FEM:2(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,3<P"FUS9VED(")R96UO=&4@97)R;W(@
M:6X@<')O=&]C;VPB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z-S,*;7-G:60@(G)I<VEN9R(*;7-G<W1R(")Y
M_&MS96QI>6]R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]-97-S86=E+G!H
M<#HQ-#(*(RP@9G5Z>GD*;7-G:60@(G-E<G9I8V4@=6YA=F%I;&%B;&4B"FUS
M9W-T<B`B2&%V82!R87!O<G4@]F)E\&D@:W5L;&%N_6QA8FEL:7(@9&7P:6PN
M(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HY.0IM<V=I9"`B<VAO=R!D
M:69F97)E;F-E<R(*;7-G<W1R(")F87)K;&%R_2!G]G-T97(B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q-`IM<V=I
M9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(DA45%`@>6]L=7EL82!S
M;7,R96UA:6PB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,S@U"FUS9VED(")S<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,@IM<V=I9"`B<W1E861Y(@IM
M<V=S='(@(G-A8FET(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS
M,#D*;7-G:60@(G-W:71C:"!O9F8@:F%V87-C<FEP="(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U,`IM<V=I9"`B
M<WES=&5M(&5R<F]R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+
M;VQA8BYP:'`Z.3(Y"FUS9VED(")T87-K(&QI<W0B"FUS9W-T<B`B9_9R978@
M;&ES=&5S:2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM<V=I9"`B
M=')Y(&%G86EN(@IM<V=S='(@(DAE<B!':7)I_G1E(@H*(SH@861M:6XO=7-E
M<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0IM
M<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(*;7-G
M<W1R(")P87)O;&%Y_2!D;_!R=6QA;6%K(&GG:6X@:6MI(&1E9F$@9VER:6XB
M"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI;B]S971U<"]D:69F
M+G!H<#HW.0IM<V=I9"`B=6YI9FEE9"(*;7-G<W1R(")B:7)L9?YT:7)I;&UI
M_B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O4&%R="YP:'`Z,C<*;7-G:60@
M(G5N;F%M960B"FUS9W-T<B`B861L86YD_7+];&UA;?W^(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-C4*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C(S"FUS
M9VED(")U<V5R('-E;&5C="(*;7-G<W1R(")K=6QL86[]8_T@<V7G:6UI(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,U"FUS
M9VED(")V0V%R9"(*;7-G<W1R(")V0V%R9"(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HR-#$*;7-G:60@(G<Z(@IM<V=S='(@
M(G<Z(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C8*;7-G:60@
M(G=E871H97(N8V]M(@IM<V=S='(@(G=E871H97(N8V]M(@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P;R]E;%]'4BYP;P``````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`U-C`V-S$@
M,3`U,34T,S0Q-#,@,#$W-3(P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````",@2&]R9&4@1W)E96L@=')A;G-L871I;VXN"B,@
M0V]P>7)I9VAT("A#*2`R,#`R(%-T969A;F]S($DN($1I;6ET<FEO=2X*(R!3
M=&5F86YO<R!)+B!$:6UI=')I;W4@/'-U<'!O<G1?=V5B;6%I;$!T96EA=&@N
M9W(^+"`R,#`R+@HC(%-I;&QI9V%R9&]S(%AR:7-T;V9O<F]S+"`R,#`R+@HC
M($%N86=N;W-T;W!O=6QO<R!!<&]S=&]L:7,L(#(P,#(N"B,@36EL;W-I<R!#
M+B!+;VYS=&%N=&EN;W,L(#(P,#4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E.B`S+C`M8W9S7&XB"B)297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9UQN(@HB4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#(M,3$M,#<@,3(Z,#8K,#(P,%QN(@HB4$\M4F5V
M:7-I;VXM1&%T93H@,C`P-2TP-"TR-B`Q,3HQ,RLP,C`P7&XB"B),87-T+51R
M86YS;&%T;W(Z($MO;G-T86YT:6YO<R!#+B!-:6QO<VES(#QK;6EL;W-I<T!Y
M86AO;RYC;VT^7&XB"B),86YG=6%G92U496%M.B!'<F5E:R`\9&5V0&QI<W1S
M+FAO<F1E+F]R9SY<;B(*(DU)344M5F5R<VEO;CH@,2XP7&XB"B)#;VYT96YT
M+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM-UQN(@HB0V]N
M=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@."UB:71<;B(*"B,L(&,M9F]R;6%T
M"FUS9VED("(B"B(@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RXB"FUS9W-T
M<B`B(@HB("8C,34Q.R`E<R#%W^WAZ2#G(//TZ>/LWB#MX2#CW^WO]>T@[^D@
MZ^7I]._U\>/?Y?(@\_7M]-[QY_/G\B#P[_4@Y=_MX>D@(@HBY?#IZ^7C[-WM
MY?(@\.'QX>K<]/DN(@H*;7-G:60@(B`@5&AE(&UA:6QB;W@@=')A<V@@:7,@
M86QR96%D>2!E;7!T>2XB"FUS9W-T<B`B("#'(./QX>SLX?3OZ/7QW^3A("?J
MW.3O\B<@Y=_MX>D@WN3G(-SDY>GA+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(S-3$*;7-G:60@(B`H)7,@9&%Y<R!A9V\I(@IM<V=S='(@(B`H
M\/'I[2#A\/P@)7,@Y^S=\>7R*2(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,3(W-PIM<V=I9"`B("A!8V-E<W-K97D@)7,I(@IM<V=S='(@(B`H
MRNOEZ>3?(/#Q_//BX?/G\B`E<RDB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR,S4Y"FUS9VED("(@*&EN("5S(&1A>7,I(@IM<V=S='(@(B`H\^4@
M)7,@Y^S=\>7R*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-34*
M;7-G:60@(B`H=&]D87DI(@IM<V=S='(@(B`H\][LY?'A*2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S-3<*;7-G:60@(B`H=&]M;W)R;W<I(@IM
M<V=S='(@(B`HX?WQZ>\I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C,U,PIM<V=I9"`B("AY97-T97)D87DI(@IM<V=S='(@(B`H]^CE\BDB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`P"FUS9VED("(@870@
M(@IM<V=S='(@(B#S].GR("(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HQ.#8*;7-G:60@(B5D("5S(&%N9"`E<R(*;7-G<W1R("(E9"`E<R#J
MX>D@)7,B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C(W"FUS
M9VED("(E9"UD87D@9F]R96-A<W0B"FUS9W-T<B`B)60M[.7QYR#P\?SBZ^7X
MYR(*"B,Z('1E;7!L871E<R]M86EN=&5N86YC92]N;W1I8V5?=&]P+FEN8SHT
M"FUS9VED("(E<R`M($YO=&EC92(*;7-G<W1R("(E<R`M(-/G[.7?^?/G(@H*
M(SH@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC.C(Y"FUS9VED
M("(E<R!!9&UI;FES=')A=&EO;B(*;7-G<W1R("(E<RW$Z>'WY=_QZ?/G(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HW,C@*;7-G:60@
M(B5S($9I;F=E<G!R:6YT(@IM<V=S='(@(B5S(,3AZO3UZ^GJ_"#A\._T_?#Y
M[.$B"@HC+"!C+69O<FUA=`IM<V=I9"`B)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;B(*;7-G<W1R("(E<R#+Y>GT[_7QX]_E\B#3
M]>WTWO'G\^?R("T@Q?#IXN7BX=_Y\^<B"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C,P(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#D*;7-G:60@(B5S
M(%-E='5P(@IM<V=S='(@(B5S+=#A\>'LY?3Q[_#OW^?SYR(*"B,Z(&9R86UE
M=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-S8*;7-G:60@(B5S(%-I9VX@
M57`B"FUS9W-T<B`B)7,@Q>/C\>'VWB(*"B,Z('1E;7!L871E<R]M86EN=&5N
M86YC92]A9W)E96UE;G1?=&]P+FEN8SHT"FUS9VED("(E<R!497)M<R!O9B!!
M9W)E96UE;G0B"FUS9W-T<B`B)7,@S_'OZ2#W\=[SY_(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C4Y-B!F<F%M97=O<FLO5D93+U9&4R]F='`N
M<&AP.C8V-@IM<V=I9"`B)7,@86QR96%D>2!E>&ES=',N(@IM<V=S='(@(B5S
M(-[DYR#U\-SQ]^7I+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34W(&QI
M8B]";&]C:R]M971A<BYP:'`Z,38S(&QI8B]";&]C:R]M971A<BYP:'`Z,C,W
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,S0S(&QI8B]";&]C:R]M971A<BYP
M:'`Z,S0Y"FUS9VED("(E<R!A="`E<R`E<R(*;7-G<W1R("(E<R#SY2`E<R`E
M<R(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-3,P"FUS9VED("(E<R!H87,@8V%N8V5L;&5D("5S+B(*;7-G<W1R("(E
M<R#AZO7Q_NCGZN4@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT,C8*;7-G:60@(B5S(&AA<R!R97!L:65D('1O
M(&$@9G)E92]B=7-Y(')E<75E<W0N(@IM<V=S='(@(B5S(.'PW.WTY_/E(//E
M(.7Q_O3G[.$@Y.GAZ.7SZ>S\].?TX?(N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,C0*;7-G:60@(B5S(&AA<R!R
M97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+B(*;7-G<W1R("(E<R#A
M\-SM].?SY2#S].?M(/#Q_//JZ^?SYR#CZ>$@)7,N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,38*;7-G:60@(B5S
M(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@
M(B5S(//A\B#=\_3EZ>OE(/#KY_'O]N_QW^7R(.3IX>CE\^GL_/3G].'R+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S,C$*;7-G:60@(B5S(&ES
M(')E<75I<F5D(@IM<V=S='(@(B5S(.7?[>'I(.'PX>GT[_WLY>WO(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR.#0*;7-G:60@(B5S(&UI;G5T97,B"FUS
M9W-T<B`B)7,@Z^7P]-PB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C0R,0IM<V=I9"`B)7,@<F5Q=65S=',@>6]U<B!F
M<F5E+V)U<WD@:6YF;W)M871I;VXN(@IM<V=S='(@(B5S(//A\B#FWO3G\^4@
M\.OG\>_V[_'?Y?(@Y.GAZ.7SZ>S\].?TX?(N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#@*;7-G:60@(B5S(')E
M<75E<W1S('EO=7(@<')E<V5N8V4@870@)7,N(@IM<V=S='(@(B5S(.;>].?S
MY2#TY^T@\.'Q[_7SW^$@\^'R(//TZ?(@)7,N(@H*(SH@=&5M<&QA=&5S+V%D
M;6EN+W5S97(O;&ES="YI;F,Z-@IM<V=I9"`B)7,@=&\@)7,@;V8@)7,B"FUS
M9W-T<B`B)7,@^?(@)7,@X?#\("5S(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,3,*;7-G:60@(B5S('=I<VAE<R!T
M;R!A9&0@=&\@)7,N(@IM<V=S='(@(B5S(.7PZ>CU[.7?(/3G[2#P\>_SZ-[J
MYR#S].\@)7,N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU,#(*;7-G:60@(B5S('=I<VAE<R!T;R!M86ME('EO=2!A
M=V%R92!O9B`E<RXB"FUS9W-T<B`B)7,@Y?#IZ/7LY=\@[>$@\^'R(.7MY^SE
M\?[SY>D@X^GA("5S+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-3$X"FUS9VED("(E<R!W:7-H97,@=&\@<F5C96EV
M92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+B(*;7-G<W1R("(E
M<R#E\.GH]>SEWR#MX2#KW.+EZ2#TZ?(@].7KY?7TX=_E\B#PZ^?Q[_;O\=_E
M\B#CZ>$@)7,N(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3(*
M;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM<V=S='(@(B5S)W,@Q.GE]>CU
M[?/I[^/QW/;O\B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`T
M"FUS9VED("(E<R=S($-A;&5N9&%R(@IM<V=S='(@(B5S)W,@Q^SE\>_K_./I
M[R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.#DV"FUS9VED("(E
M<R=S($YO=&5P860B"FUS9W-T<B`B)7-S(-/G[.7I^>SA]-SQZ>\B"@HC.B!F
M<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR,`IM<V=I9"`B)7,G<R!487-K
M;&ES="(*;7-G<W1R("(E<W,@R]_S].$@Q?'CX?/I_NTB"@HC.B!F<F%M97=O
M<FLO0TQ)+T-,22YP:'`Z,C<P"FUS9VED("(G)7,G(&ES(&YO="!A('9A;&ED
M(&-H;VEC92XB"FUS9W-T<B`B)R5S)R#DY>T@Y=_MX>D@W>/J]?'G(.7PZ>OO
MX]XN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HU
M.#(*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HY.#(*
M;7-G:60@(B<E<R<@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(*;7-G<W1R("(G)7,G(.3E[2#=]^7I(/'UZ.SI\_3EWR#S].\@
M<F5G:7-T<GD@].?R(.7VX?'L[^/>\B!(;W)D92(*"B,Z(&9R86UE=V]R:R]4
M<F5E+U1R964N<&AP.C$V,`IM<V=I9"`B)R5S)R!T<F5E(')E;F1E<F5R(&YO
M="!F;W5N9"XB"FUS9W-T<B`B)7,@X>WA\.'QX?/TW/3G\B#DY>WD\>GJWO(@
MY._LWO(@Y.7M(.+QW>CGZN4N(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU-PIM
M<V=I9"`B)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN(@IM
M<V=S='(@(B<E<R<@\/'O\_3=Z.?JY2#S].GR(._LW.3E\B#S]?/TWNSA]._R
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HX-0IM<V=I9"`B)R5S
M)R!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2XB"FUS9W-T
M<B`B)R5S)R#P\>_S]-WHY^KE(//TZ?(@W.3EZ>7R(/3O]2#S]?/TWNSA]._R
M+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z-34@861M:6XO<&5R;7,O861D8VAI
M;&0N<&AP.C@S"FUS9VED("(G)7,G('=A<R!N;W0@8W)E871E9#H@)7,N(@IM
M<V=S='(@(B<E<R<@Y.7M(.3G[.GO]?'CWNCGZN4Z("5S+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3@V(&QI8B]";&]C:R]M971A<BYP:'`Z,3DQ"FUS
M9VED("(L(&=U<W1I;F<@)7,@)7,B"FUS9W-T<B`B+"!G=7-T:6YG("5S("5S
M(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.3D*;7-G:60@(BP@=F%R:6%B
M;&4@9G)O;2`E<R!T;R`E<R(*;7-G<W1R("(L(.SE].'BZ^?TWB#A\/P@)7,@
M\^4@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#4R(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C8Y,0IM<V=I9"`B+2T@<V5L96-T("TM(@IM
M<V=S='(@(BTM(.7PZ>OOX]X@+2TB"@HC.B!L:6(O0FQO8VLO=&EM92YP:'`Z
M,C`*;7-G:60@(C$R($AO=7(@1F]R;6%T(@IM<V=S='(@(C$R^?'G(.SO\?;>
M(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$Y"FUS9VED("(R-"!(;W5R($9O
M<FUA="(*;7-G<W1R("(R-/GQYR#L[_'VWB(*"B,Z('1E;7!L871E<R]D871A
M+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R-"#^\>7R
M(@H*;7-G:60@(CQB/D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D.CPO8CXB
M"FUS9W-T<B`B/&(^T.'Q[_7SZ=SS].?JY2#=[>$@\^_BX?'\(.O<Z._R.CPO
M8CXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$V-@IM<V=I9"`B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B"FUS9W-T<B`BT.'Q[_7SZ=SS
MZ.?JY2#J\=_SZ>SO(.O<Z._R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z.30Q"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("+!\.'I].7?].'I
M(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#CZ>$@].?M(.KQ]?#T[^/QW/;G\^<@Y>W\
M\B#LY^W][.'T[_(N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP
M:'`Z,3$V-PIM<V=I9"`B02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92XB"FUS9W-T<B`B(@HBP?#AZ?3E
MW_3AZ2#DY^S\\^GO(.KKY>GDWR!01U`@X^GA(.7PZ>+EXN'?^?/G(.7M_/(@
M]?#OX^7C\>'L[-WM[_4@[.?M_>SA]._R+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$P.3@*;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O(&1E8W)Y<'0@82`B"B)M97-S86=E+B(*;7-G<W1R("(B"B+!\.'I
M].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ_"!01U`@ZNOEZ>3?(.KAZ2#KW>[G
M+>KYY.GJ_/(@X^GA(.WA("(*(N'P[^KQ]?#T[^/QX?;>\^7TY2#=[>$@[-[M
M]>SA+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P,3<*
M;7-G:60@(B(*(D$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82`B"B)M97-S
M86=E+B(*;7-G<W1R("(B"B+!\.'I].7?].'I(.3G[/SSZ>\L(/#Q[_/Y\.GJ
M_"!01U`@ZNOEZ>3?(.KAZ2#KW>[G+>KYY.GJ_/(@X^GA(.WA(/7P[^/QW/CE
M].4@(@HB^.?VZ>'JW"#=[>$@[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3(S"FUS9VED("(B"B)!('!U8FQI8R!3+TU)
M344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@;65S<V%G92XB"FUS9W-T<B`B
M(@HBP?#AZ?3EW_3AZ2#DY^S\\^GO+"#P\>_S^?#IZOP@4R]-24U%(.KKY>GD
MWR#JX>D@Z]WNYRWJ^>3IZOSR(./IX2#MX2`B"B+A\._J\?7P]._C\>'VWO/E
M].4@W>WA(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C0T.0IM<V=I9"`B(@HB02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@<VEG;B`B"B)A(&UE<W-A9V4N(@IM<V=S='(@(B(*(L'PX>GTY=_TX>D@
MY.?L_//I[RP@\/'O\_GPZ>K\(%,O34E-12#JZ^7IY-\@ZN'I(.O=[N<MZOGD
MZ>K\\B#CZ>$@[>$@(@HB]?#OX_'<^.7TY2#XY_;IX>K<(-WMX2#LWNWU[.$N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.#(*;7-G
M:60@(D$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92XB"FUS9W-T<B`BP?#AZ?3EW_3AZ2#DY^S\\^GO(.KKY>GD
MWR!3+TU)344@X^GA(/3G[2#J\?7P]._C\=SVY_/G(.7M_/(@[.?M_>SA]._R
M+B(*"FUS9VED(")!32]032(*;7-G<W1R("+P["_L["(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S`*;7-G:60@(D%B;W5T
M('1H:7,@961I=&]R(@IM<V=S='(@(M#E\=\@X?7T[_T@]._U(,KEZ>SE[>_C
M\=SV[_4B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,@IM<V=I9"`B
M06)O=70N+BXB"FUS9W-T<B`BT.7QWRXN+B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S0*;7-G:60@(D%B<V)O='1O;2(*
M;7-G<W1R("+!\/SK]?3O(/3=Z^_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHW,@IM<V=I9"`B06)S;6ED9&QE(@IM<V=S
M='(@(L'P_.OU].<@S-WSYR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z-C0P"FUS9VED(")!8V-E<'0@<F5Q=65S="(*
M;7-G<W1R("+!\._D[_?>(.'I]-[LX?3O\B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C@Q"FUS9VED(")!8V-E<'1E
M9"(*;7-G<W1R("+%X^GMY2#A\._DY>KT_"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HR.#4*;7-G:60@(D%C8V5S<R!D96YI960@8W)E871I
M;F<@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BQR#P\?SSXN'SYR#A\._Q\=_V
MZ.?JY2#JX?3<(/3G(.3G[.GO]?'CW^$@5D93(.KA].'K_./O]2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3,X"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R("+'(/#Q_//BX?/G
M(.'P[_'QW_;HY^KE(.KA]-P@].<@Y.?LZ>_U\>/?X2!61E,@X?'WY=_O]2XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-S4*;7-G:60@(D%C8V]U;G0@
M4&%S<W=O<F0B"FUS9W-T<B`BROGDZ>K\\B#+[^/A\>GA\^SO_2(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P,@IM
M<V=I9"`B06-C;W5N="!F<F]Z96XN(@IM<V=S='(@(L\@Z^_CX?'IX?/L_/(@
M\-SC^?/E+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS,C`*;7-G
M:60@(D%C8V]U;G1I;F<B"FUS9W-T<B`BRN'TX>/QX?;>(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3$*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,C4*;7-G
M:60@(D%C=&EO;G,B"FUS9W-T<B`BQ>W=\>/EZ>7R(@H*(SH@861M:6XO<&5R
M;7,O861D8VAI;&0N<&AP.C4T(&9R86UE=V]R:R]097)M<R]097)M<R]522YP
M:'`Z,3,V"B,Z('1E;7!L871E<R]P;W)T86PO861D+FEN8SHQ-"!T96UP;&%T
M97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHQ-@IM<V=I9"`B061D(@IM
M<V=S='(@(M#Q[_/HWNKG(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,30@861M
M:6XO9W)O=7!S+G!H<#HR,34*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G
M<W1R("+0\>_SZ-[JYR#U\._O[-SDX?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,O54DN<&AP.C@Q(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z
M.#(*;7-G:60@(D%D9"!#:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(M#Q[_/H
MWNKG(-SDY>GA\B#U\._O[-SDX?(@*&-H:6QD('!E<FUI<W-I;VXI(@H*(SH@
M=&5M<&QA=&5S+W!O<G1A;"]A9&0N:6YC.C4*;7-G:60@(D%D9"!(97)E.B(*
M;7-G<W1R("+0\>_SZ-[JYR#EY/XZ(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR
M,#@@861M:6XO9W)O=7!S+G!H<#HR,#D*;7-G:60@(D%D9"!.97<@1W)O=7`B
M"FUS9W-T<B`BT/'O\^C>ZN<@S=WA\B#/[-SDX?(B"@HC.B!F<F%M97=O<FLO
M4&5R;7,O4&5R;7,O54DN<&AP.C<P(&9R86UE=V]R:R]097)M<R]097)M<R]5
M22YP:'`Z-S$*;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("+0
M\>_SZ-[JYR#MW>'R(-SDY>GA\B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U
M<',O861D8VAI;&0N:6YC.CD*;7-G:60@(D%D9"!A(&-H:6QD(&=R;W5P('1O
M("<E<R<B"FUS9W-T<B`BT/'O\^C>ZN<@]?#O[^S<Y.'R(//T[R`G)7,G(@H*
M(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C4S(&9R86UE=V]R:R]097)M
M<R]097)M<R]522YP:'`Z,3,U"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S
M:6]N('1O("<E<R<B"FUS9W-T<B`BT/'O\^C>ZN<@W.3EZ>'R("AP97)M:7-S
M:6]N*2#U\._O[-SDX?(@\_3O("<E<R<B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(M#Q[_/HWNKG(.W=
M[_4@]_'>\_3G.B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HU,CD*;7-G:60@(D%D9"!C;VQU;6XB"FUS9W-T<B`BT/'O\^C>
MZN<@\_3>Z^?R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+V=R;W5P<R]E9&ET+FEN
M8SHS-0IM<V=I9"`B061D(&YE=R!M96UB97)S(@IM<V=S='(@(M#Q[_/HWNKG
M(.W=[_4@[-WK[_7R(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ
M,#,*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(M#Q[_/HWNKG(.;E_>/O]?(B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4Q"FUS9VED(")!9&0@=&AE
M("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(B"FUS9W-T<B`BT/'O\^C>
MZN<@]._U("5S(//T[R#LY>WO_2#T[_4@36]Z:6QL82(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,Q"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-C,W"FUS9VED
M(")!9&0@=&AI<R!T;R!M>2!C86QE;F1A<B(*;7-G<W1R("+0\>_SZ-[JYR#A
M]?3O_2#S].\@Y^SE\>_K_./I_"#L[_4B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z-S0*;7-G:60@(D%D9"!T;R!A9&1R97-S
M(&)O;VLZ(@IM<V=S='(@(M#Q[_/HWNKG(//T[R#$Z>7UZ/7M\^GOX_'<]N\Z
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C@Q
M"FUS9VED(")!9&0@=&\@;7D@861D<F5S<R!B;V]K(@IM<V=S='(@(M#Q[_/H
MWNKG(//T[R#$Z>7UZ/7M\^GOX_'<]N\@[._U(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,S$*;7-G:60@(D%D9"!U<V5R(@IM<V=S='(@(M#Q[_/HWNKG(/?QWO/T
MYR(*"B,Z(&%D;6EN+W5S97(N<&AP.C<Y"FUS9VED("(B"B)!9&1E9"`G)7,G
M('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@
M<VEG;G5P(&EN9F]R;6%T:6]N.B`E(@HB<RXB"FUS9W-T<B`B(@HBT/'O\_3=
MZ.?JY2`G)7,G(//T[R#S_?/TY^SA+"#AZ^O<(.3E[2#L\/SQY?/A(.WA(/#Q
M[_/HW?/Y(//U[/#KY_'Y[.'TZ>K=\B`B"B+PZ^?Q[_;O\=_E\B(*"B,Z('-I
M9VYU<"YP:'`Z-#8*;7-G:60@(D%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2X@
M66]U(&-A;B!L;V<@:6X@;F]W+B(*;7-G<W1R("+0\>_S]-WHY^KE("<E<R<@
M\_3O(//]\_3G[.$N(,SP[_'EW_3E(.WA(//U[>3EZ.7?].4@]/[QX2XB"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z-`IM<V=I9"`B061D
M:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*;7-G<W1R("+'(/#Q[_/HWNKG(/?Q
MY_/T_NT@W??EZ2#A\.7MY?'C[_#OZ>?HY=\N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3<V(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$T,S<*;7-G:60@(D%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G
M(@H*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+$Z>7UZ/7M\^GOX_'<
M]N_R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M.3<*;7-G:60@(D%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T
M:&5R('5S97)S(@IM<V=S='(@(L3IX??EW_'I\^<@+2#$_O/TY2#DZ>KAZ?[L
MX?3A(//E(-SKZ^_U\B#W\=[S].7R(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN
M:7-T<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<B"@IM<V=I9"`B06MT:6]N
M($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@P>KTW^_U(@H*;7-G:60@
M(D%L97AA;F1R;W5P;VQI($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-[M(,'K
MY>[A[>3Q[_WP[^OG\B(*"FUS9VED(")!;&EA<R(*;7-G<W1R("+8Y?7D_NWU
M[.\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C$V"FUS9VED(")!;&EG;B(*;7-G<W1R("+%]>CUX_'<[.SI\^4B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C8W
M"FUS9VED(")!;&EG;FUE;G0Z(@IM<V=S='(@(L7UZ/7C\=SL[.GSYSHB"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G<W1R
M("+/Z^$B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,3@@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHW,0IM<V=I9"`B06QL($%U=&AE;G1I8V%T960@
M57-E<G,B"FUS9W-T<B`BS^OOZ2#OZ2#=X^KU\>_I(/?QWO/TY?(B"@HC.B!A
M9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R;W5P<RYP:'`Z,C$R"FUS9VED
M(")!;&P@1W)O=7!S(@IM<V=S='(@(L_KY?(@[^D@S^S<Y.7R(@H*(SH@861M
M:6XO<&5R;7,O861D8VAI;&0N<&AP.C,X(&9R86UE=V]R:R]097)M<R]097)M
M<R]522YP:'`Z-S0*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("+/
MZ^$@].$@Y.GJX>G^[.'TX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3<*;7-G:60@(D%L;"!F;W5R('-I9&5S
M(@IM<V=S='(@(LKAZ2#OZ2#TW?/SY?'I\B`H-"D@\.OE]?'=\B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-30*;7-G:60@(D%L;&]W(&UU;'1I
M<&QE(&%D9')E<W-E<R(*;7-G<W1R("+-X2#E\.GT\=WP[^WTX>D@\._KZ^'P
MZ]WR(.3IY?7H_>WSY>GR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C4Q
M-PIM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\B
M"FUS9W-T<B`BS>$@Y?#I]/'=\._M].'I(/'UZ.S?\^7I\B#TX>[I[>_LZ>S=
M[?GM(.OI\_3^[3LB"@HC.B!F<F%M97=O<FLO1&%T851R964O1&%T851R964O
M<W%L+G!H<#HT,#$*;7-G:60@(D%L<F5A9'D@97AI<W1S(@IM<V=S='(@(L?D
MYR#U\-SQ]^7I(@H*;7-G:60@(D%L=&5R;F%T92!)35-0($QO9VEN(@IM<V=S
M='(@(L7MX>OKX>KTZ>K>($E-4U`@Q=_S[^3O\B(*"FUS9VED(")!;'1E<FYA
M=&4@24U34"!087-S=V]R9"(*;7-G<W1R("+%[>'KZ^'J].GJ_/(@24U34"#*
M^>3IZOSR(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0X,@IM<V=I9"`B
M06QT97)N871E($E-4U`@57-E<FYA;64B"FUS9W-T<B`BQ>WAZ^OAZO3IZOP@
M24U34""\[>_LX2#7\=[S].<B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D
M+G!H<#HS-0IM<V=I9"`B06QT97)N871E(&5M86EL(&%D9')E<W,B"FUS9W-T
M<B`BQ>WAZ^OAZO3IZMX@Y.GE_>CU[?/G(&5M86EL(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ-#(*;7-G:60@(D%L=&5R;F%T92!T96UP;&%T97,B"FUS
M9W-T<B`BQ>WAZ^OAZO3IZMP@\/'\]/7PX2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3(R"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR-0IM<V=I9"`B
M06QT97)N871E('1E>'0Z(@IM<V=S='(@(L7MX>OKX>KTZ>K\(.KEW^SE[>\Z
M(@H*;7-G:60@(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS
M9W-T<B`BS_'?\_3GZN4@[-_A(.SG(.7PZ?3QY?#\[.7MYR#TZ>S>+B(*"FUS
M9VED(")!;F-H:6%L;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#!
MX_??X>OO]2XB"@IM<V=I9"`B06YD<F%V:61A($%I<G!O<G0B"FUS9W-T<B`B
MP>7Q[^OI[-WMX?(@P>WD\>'BW^3A\BXB"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3(P"FUS9VED(")!;F]N>6UO=7,@4')O>'DB"FUS9W-T
M<B`BP>W^[?7L[_(@Q.GA[.SE\^_KX>+G]-[R("A0<F]X>2DB"@HC.B!S97)V
M:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0IM<V=I9"`B06YS=V5R(@IM<V=S
M='(@(L'PW.WTY_/G(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HW-"!A9&UI
M;B]P:'!S:&5L;"YP:'`Z,S`*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)
M+G!H<#HU.2!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HV"FUS
M9VED(")!<'!L:6-A=&EO;B(*;7-G<W1R("+%]N'Q[._CWB(*"B,Z('5T:6PO
M:6-O;E]B<F]W<V5R+G!H<#HT,@IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*
M;7-G<W1R("++W_/TX2#%]N'Q[._CWO(B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z,3,P"FUS9VED(")!<'!L:6-A=&EO;B!I<R!R96%D>2XB"FUS9W-T
M<B`BQR#E]N'Q[._CWB#EW^WAZ2#=]._I[.<N(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHR,C0*;7-G:60@(D%P<&QY('1O($-H:6QD(%-H87)E
M<R(*;7-G<W1R("+%]N'Q[._CWB#JX>D@\_3A(.7NX?'T_NSE[>$@ZN_I[?SW
M\>?S].$B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHS
M,PIM<V=I9"`B07!P<F]V92(*;7-G<W1R("+%X^KQW^WY(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W-PHC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$T"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-C@*;7-G:60@(D%P<FEL
M(@IM<V=S='(@(L'P\=_KZ>_R(@H*;7-G:60@(D%R87AO<R!!:7)P;W)T(@IM
M<V=S='(@(L'E\>_KZ>S=[>'R(,'QW.[O]2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C(@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HV-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@Q"FUS9VED(")!<F-H:79E($9I;&4@4VEZ92(*;7-G<W1R
M("+,W>/EZ._R(.'Q]^7?[_4@X?'WY>GOZ-WTY_/G\B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C$@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HV-0HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]T9WHN<&AP.C@P"FUS9VED(")!<F-H:79E($YA;64B"FUS9W-T
M<B`BS^WO[.$@X?'WY=_O]2#A\??EZ>C=].?SY_(B"@HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]R96UO=F5Q=65U960N:6YC.CD*;7-G:60@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_(@IM<V=S='(@(L7?\_3E(//?X^_U\><@X^GA(/3G(.3IX>/QX?;>
M(/3G\B#AW_3G\^?R(/7P[^/QX?;>\B#CZ>$@)7,@/R(*"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHY"FUS9VED(")!<F4@>6]U('-U
M<F4@>6]U('=I<V@@=&\@9&5L971E("<E<R<@86YD(&%N>2!S=6(M9W)O=7!S
M/R(*;7-G<W1R("+%W_/TY2#SW^/O]?'OZ2#\].D@Z-WKY?3E(.WA(.3IX>/Q
MW/CE].4@)R5S)R#JX>D@_.OE\B#TZ?(@]?#O[^S<Y.7R/R(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(M3=]^WG
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!
M<G0B"FUS9W-T<B`B05-#24D@U-WW[><B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-#`Y"FUS9VED(")!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@
M9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\B"FUS9W-T<B`BS>$@YN?T
MY=_TY2#E\.GBY>+AW_GSYR#P\=_M(.'P_"#JW.CE(.7MW?'CY>GA(.3IX??E
MW_'I\^?R.R(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3<*;7-G
M:60@(D%S<VEG;FUE;G0@8V]L=6UN<R(*;7-G<W1R("+![=SHY?/G(//TY^O^
M[2(*"FUS9VED(")!=&AI;F%I($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WM
MX?(@P>CG[?[M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HQ-C8*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HR-#D*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HS,3@*;7-G:60@(D%T=&%C:&5D(&ES(&%N(&E#
M86QE;F1A<B!F:6QE(')E<&QY('1O(&$@<F5Q=65S="!Y;W4@<V5N="(*;7-G
M<W1R("+4[R#S]>WG[.S=[>\@Y=_MX>D@W>WA(.'Q]^7?[R#G[.7Q[^OOX]_O
M]2#SY2#A\-SM].?SYR#AZ?3>[.'T_/(@\^'R(@H*(SH@861M:6XO9W)O=7!S
M+G!H<#HW-0IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N(@IM<V=S='(@(M#Q[_/PW.CEZ>$@Y.GAX_'A]M[R(.SG(/7P
MX?'J]-[R(._LW.3A\BXB"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C,X
M"FUS9VED(")!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+B(*;7-G<W1R("+0\>_S\-SHY>GA(.3IX>/QX?;>\B#LYR#U\.'Q
MZO3O_2#DZ>KAZ?[LX?3O\BXB"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HY
M.`IM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN(@IM<V=S='(@(M#Q[_/PW.CEZ>$@Y?#E[N7QX^'SW^'R(.SG(/7P
MX?'J]._](.3IZN'I_NSA]._R+B(*"B,Z('-E<G9I8V5S+W-H87)E<R]E9&ET
M+G!H<#HU,PIM<V=I9"`B071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT
M('-H87)E+B(*;7-G<W1R("+0\>_S\-SHY>GA(.7PY>[E\>/A\]_A\B#LYR#U
M\.'QZO3O_2#DZ>'L[^GQX?/LW>WO]2XB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4W-PIM<V=I9"`B071T96YD965S
M(@IM<V=S='(@(M#A\>7U\>GSZOSLY>WOZ2(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O>FEP+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]T9WHN<&AP.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(LGDZ?ST
MY_3E\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HS.#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C0Q.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS
M.C<R"FUS9VED(")!=6=U<W0B"FUS9W-T<B`BP?WC[_7S]._R(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS
M9VED(")!=71H96YT:6-A=&EO;B!F86EL960B"FUS9W-T<B`BQR#A]>CE[?3I
MZN_P[]_G\^<@X?#=]/7WY2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C8Y"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C<X"FUS9VED(")!=71H96YT:6-A=&EO
M;B!F86EL960N("5S(@IM<V=S='(@(L<@X?7HY>WTZ>KO\._?Y_/G(.'PW?3U
M]^4N("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]R861I=7,N<&AP.C$X
M,0IM<V=I9"`B075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553('-E
M<G9E<BXB"FUS9W-T<B`BQR#A]>CE[?3IZN_P[]_G\^<@X?#O\?'?]NCGZN4@
MX?#\(/3O[2!2041)55,@<V5R=F5R+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9T<"YP:'`Z.#`P"FUS9VED(")!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"XB"FUS9W-T<B`BQR#A]>CE[?3IZN_P[]_G\^<@\_3O[2!&
M5%`M4V5R=F5R(.'PW?3U]^4N(@H*;7-G:60@(D%V86EL86)L92!F:65L9',Z
M(@IM<V=S='(@(L3IX>C=\^GLX2#0Y>3?X3HB"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8Q-`IM<V=I9"`B07=A:71I
M;F<@4F5S<&]N<V4B"FUS9W-T<B`BP>WA[-WM[^WTX?(@X?#<[?3G\^<B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C$X"FUS9VED(")"86-K9W)O=6YD(@IM<V=S='(@(M7P_.+AZ/'O(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR,PIM<V=I
M9"`B0F%C:V=R;W5N9"!#;VQO<B(*;7-G<W1R("+7\?[LX2#U\/SBX>CQ[_4B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@S"FUS9VED(")"
M860@:V5R8F5R;W,@<&%S<W=O<F0N(@IM<V=S='(@(LO<Z._R($ME<F)E<F]S
M+>KYY.GJ_/(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX
M-0IM<V=I9"`B0F%D(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("++W.CO
M\B!+97)B97)O<RV\[>_LX2#7\=[S].<N(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C4Y,@IM<V=I9"`B0F%R92(*;7-G<W1R("+!Y.7I[R(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0IM<V=I9"`B0F%S92!G<F%P:&EC
M<R!D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N(@IM<V=S='(@(L\@ZOWQZ>_R
M(.KA]-SK[^/O\B#C\>'VZ>K^[2`G)7,G(.3E[2#B\=WHY^KE+B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,3D*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,PIM
M<V=I9"`B0F%S96QI;F4B"FUS9W-T<B`BPN'SZ>K>(./QX>SLWB(*"FUS9VED
M(")":7)T:&1A>2(*;7-G<W1R("+#Y>W=Z.OIX2(*"B,Z('1E;7!L871E<R]P
M;W)T86PO;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS
M9W-T<B`BT?7H[-_SY>GR(/3LWNSA]._R(@H*(SH@=&5M<&QA=&5S+W!O<G1A
M;"]L87EO=70N:6YC.C<T"FUS9VED(")";&]C:R!4>7!E(@IM<V=S='(@(M3]
M\._R(/3LWNSA]._R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+T-O;&QE
M8W1I;VXN<&AP.C,R-@IM<V=I9"`B0FQO8VL@7"(E<UPB(&]F(&%P<&QI8V%T
M:6]N(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(M3O(/3LWNSA(%PB)7-<
M(B#TY_(@Y?;A\>SOX][R(%PB)7-<(B#DY>T@XO'=Z.?JY2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@*;7-G:60@(D)O
M;&0B"FUS9W-T<B`BN.WT[^WA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR,0IM<V=I9"`B0F]R9&5R<R(*;7-G
M<W1R("*\\>GA(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDV"FUS9VED
M(")";W1H(@IM<V=S='(@(LKAZ2#TX2#D_>\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(R"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S4*;7-G:60@(D)O='1O
M;2(*;7-G<W1R("+*X?3^].'T[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE=&5D($QI<W0B"FUS
M9W-T<B`BR]_S].$@[.4@].7KY=_E\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C(Q"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<R(*;7-G<W1R("+3Y^SEW^$@Y.GA[>_LWO(@0U),(@H*;7-G:60@(D-6
M4R(*;7-G<W1R("+!\??EW^\@ZN7I[-WM[_4@]_GQZ?/LW>WO(.SE(.K\[.SA
M("A#5E,I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C(W"FUS9VED(")#7V5L;"!0<F]P97)T:65S+BXN(@IM
M<V=S='(@(LGDZ?STY_3E\B#*Y>OI_NTN+BXB"@HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#4V(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ-#,*;7-G:60@(D-A;&5N9&%R(@IM<V=S='(@(L?LY?'OZ_SC
MZ>\B"@IM<V=I9"`B0V%L96YD87(Z(@IM<V=S='(@(L?LY?'OZ_SCZ>\Z(@H*
M;7-G:60@(D-A;&5N9&%R(%-U;6UA<GDB"FUS9W-T<B`BT.7QW^OG^.<@Q^SE
M\>_K_./I[_4B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,3DU
M"FUS9VED(")#86QM(@IM<V=S='(@(L?QY>S?X2(*"B,Z('-E<G9I8V5S+W)E
M<V5T<&%S<W=O<F0N<&AP.C(P"FUS9VED(")#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+B(*;7-G<W1R("(B"B+!Y/WMX?3G(.<@X?'WZ>KO\._?Y_/G(/3O]2#J^>3I
MZN_](.'U]/SLX?3A+"#E\.GJ[^GM^>W>\_3E(.SE(/3O(.3IX??EZ?'I\_3>
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,C0Q(&9R86UE
M=V]R:R]!=71H+T%U=&@O8WER<W%L+G!H<#HS,3(*;7-G:60@(D-A;B=T(&-O
M;FYE8W0@=&\@24U!4"!S97)V97(Z("5S(@IM<V=S='(@(L'D_>WA].<@YR#S
M_>WDY?/G(.SE(/3O[2!)34%0+5-E<G9E<CH@)7,B"@IM<V=I9"`B0V%N8V5L
M(@IM<V=S='(@(L'J_?'Y\^<B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B
M;&5M+FEN8SHU.0IM<V=I9"`B0V%N8V5L(%!R;V)L96T@4F5P;W)T(@IM<V=S
M='(@(L'J_?'Y\^<@P>WA]N_QW/(@T/'OXNO>[.'T[_(B"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F='`N<&AP.C(V.0IM<V=I9"`B0V%N;F]T(&1E;&5T92!F
M:6QE(%PB)7-<(BXB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>(/3O]2#A
M\??EW^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-#<*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2]C;W!Y+G!H<#HU,PIM<V=I9"`B0V%N;F]T(&9I;F0@82!T96UP;W)A
M<GD@9&ER96-T;W)Y+B(*;7-G<W1R("+$Y2#B\=_SZOD@\/'O\_GQZ>W\(/;<
MZN7K[R`H=&5M<"!D:7(I+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<BYP:'`Z.3<*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO
M=70@)W1A<F=E=$9I;&4G('!A<F%M971E<BXB"FUS9W-T<B`BP>3][>'TYR#G
M(//U[=WWY>GA(/?Y\=_R(/3G[2#PX?'<[.7T\>\@7")T87)G971&:6QE7"(N
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR-C4*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`BP>3][>'T
MYR#G(.3IX>/QX?;>(/3O]2#VX>K=Z^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO1&%T851R964O1&%T851R964N<&AP.C$Q,B!F<F%M97=O<FLO1&%T851R
M964O1&%T851R964O<W%L+G!H<#HU-S8*;7-G:60@(D-A;FYO="!R96UO=F4L
M("5D(&-H:6QD<F5N(&5X:7-T+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A
M]MXL("5D(/7P]MSJY>OO\B#U\-SQ]^7I+B(*"B,Z(&9R86UE=V]R:R]$871A
M5')E92]$871A5')E92]S<6PN<&AP.C4P,@IM<V=I9"`B(@HB0V%N;F]T(')E
M;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R
M(&1O97,@;F]T(&UA=&-H(&YU;6)E<B`B"B)S=&]R960N(@IM<V=S='(@(B(*
M(L'D_>WA].<@YR#E\.'MX?3A[NGM_.SG\^<L(.\@X?'IZ.S\\B#T^>T@Y>/C
M\>'V_NT@\._U(.3^\^'TY2#CZ>$@(@HBY?#A[>'TX>[I[?SLY_/G+"#DY>T@
M].'I\>G<YN7I(.SE(/3O[2#A\>GH[/P@]/GM(.'P[^CGZN7U[-WM^>TN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S$X"FUS9VED(")#86YN;W0@<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@
M;G5M8F5R+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#D\>_L[^OOX][S^2#LWNWU
M[.$@\_3O[2#A\>GH[/P@\._U(._QW_/A].4N(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR-`IM<V=I9"`B0V%P
M=&EO;B(*;7-G<W1R("+%\.GJY?;AZ]_DX2(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HY,`IM<V=I9"`B0V%T96=O<FEE<R!A;F0@3&%B96QS(@IM<V=S
M='(@(LKA].?C[_'?Y?(@ZN'I(,7TZ>K=].7R(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-PIM<V=I9"`B0V5L;"!0:&]N
M92(*;7-G<W1R("+*Z>WG]/P@U.?KW?;Y[>\B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#96QL
M(%!R;W!E<G1I97,B"FUS9W-T<B`BR>3I_/3G].7R(,KEZ^GO_2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED
M(")#96QL('!A9&1I;F<Z(@IM<V=S='(@(L/=[.GS[.$@RN7KZ>_].B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-C$*;7-G:60@(D-E;&P@<')O<&5R=&EE<R(*;7-G<W1R("+)Y.G\].?TY?(@
MRN7KZ>_](@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,3(*;7-G:60@(D-E;&P@<W!A8VEN9SHB"FUS9W-T<B`BQ.G<ZN7M
M[R#*Y>OI_NTZ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V-0IM
M<V=I9"`B0V5L;'!H;VYE(@IM<V=S='(@(LKI[>?T_"#4Y^O=]OGM[R(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C8*;7-G:60@(D-E;G1E<B(*;7-G<W1R("+*W>WT\>\B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<R,PIM<V=I9"`B0V5R=&EF:6-A
M=&4@1&5T86EL<R(*;7-G<W1R("++Y?#T[^S=\>7IY?(@T.GS]._P[^GG].GJ
M[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8R,`IM
M<V=I9"`B0V5R=&EF:6-A=&4@4&]L:6-I97,B"FUS9W-T<B`BT._KZ?3IZMX@
MT.GS]._P[^GG].GJ[_TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C4Y-B`_/S\*;7-G:60@(D-H86ER(%!E<G-O;B(*
M;7-G<W1R("+0\?SEY/'O\B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M
M+FEN8SHR-"!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.3<*;7-G:60@
M(D-H86YG92(*;7-G<W1R("+!Z^OAX]XB"@IM<V=I9"`B0VAA;F=E(%!A<W-W
M;W)D(@IM<V=S='(@(L'KZ^'CWB#J^>3IZN_](@H*;7-G:60@(B(*(D-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@(@HB96UA:6QS+B(*;7-G<W1R
M("(B"B+!Z^O<[O3E(/3O(/SM[^SA(.KAZ2#TYR#DZ>7]Z/7M\^<@\._U(.CA
M(.+KW?#O]>T@_/3A[2#DZ>'BW.;O]>T@WB#A\.'M]._][2`B"B+SY2#LY^W]
M[.'TW"#SX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C(W"FUS9VED(")#:&%R(@IM<V=S='(@(M?A\>'J]-[Q
MX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,C4*;7-G:60@(D-H96-?:R!,:6YK+BXN(@IM<V=S='(@(KCK
MY>/W[_(@\_WMY.7SY_(N+BXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O
M8V]N9FER;5]T;W`N:6YC.C$S"FUS9VED(")#:&5C:R!T:&4@8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+B(*;7-G<W1R("(B"B+3Y^SEZ?[S].4@].\@].7T\>'C^>W?Y.GO(./I
MX2#O\._IX>3>\._TY2#E\>/A\]_A*.7R*2#HW>OE].4@[>$@Y>KTY>OE\_3O
M_>T@(@HBX?7TWB#TYR#S].GC[-XN(@H*;7-G:60@(D-H:6]S($%I<G!O<G0B
M"FUS9W-T<B`BP>7Q[^OI[-WMX?(@U]_O]2(*"B,Z('1E;7!L871E<R]P<F5F
M<R]A<'`N:6YC.C<*;7-G:60@(D-H;V]S92!!<'!L:6-A=&EO;CHB"FUS9W-T
M<B`BQ?#IZ]WN].4@Q?;A\>SOX]XZ(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(X,@IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS
M9W-T<B`BQ?#IZ]WN].4@ZOGDZ>K\(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]3:6=N=7`N<&AP.C(X,0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS
M9W-T<B`BQ?#IZ]WN].4@_.WO[.$@]_'>\_3G(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT-3(*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV,C8*;7-G:60@(D-H
M;V]S92!A;B!A8W1I;VXZ(@IM<V=S='(@(L7PZ>O=[O3E(.SIX2#E[=WQX^7I
MX3HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C@R"FUS9VED(")#:&]O
M<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(L7PZ>O=[O3E(/#Y
M\B#HX2#E[/;A[=_F[^WTX>D@[^D@Y^SE\>_LY^W?Y?(Z(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ<SHR,@IM
M<V=I9"`B0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES
M=',I(@IM<V=S='(@(L7PZ>O=[O3E(/3]\.\@Z]_S].'R("CCZ>$@].'NZ>WO
M[.?LW>WE\B#KW_/TY?(I(@H*;7-G:60@(D-H<GES;W5P;VQI($%I<G!O<G0B
M"FUS9W-T<B`BP>7Q[^OI[-WMX?(@U_'U\^_]\._KY_(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,N<&AP.C,Q,2!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M-C4U"FUS9VED(")#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"XB
M"FUS9W-T<B`BQ.7M(.+QW>CGZN4@[_'I\^S\\B#JZ]SSY_(@]._U("5S+B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,30*;7-G:60@(D-L
M96%R(@IM<V=S='(@(LKAZ-SQZ?/E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/9F9I8V4@
M=&%G<R(*;7-G<W1R("+*X>CA\>GS[/SR(.7TZ>KE]/[M("AT86=S*2!-4RU/
M9F9I8V4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]C;&5A<BYI;F,Z-PIM
M<V=I9"`B0VQE87(@;W5T('5S97(Z("5S(@IM<V=S='(@(B?!Y.7IX?/LX2<@
MU_'>\_3G.B`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+V-L96%R+FEN
M8SHQ-@IM<V=I9"`B0VQE87(@=7-E<B(*;7-G<W1R("+*X>CA\>GS[/SR(-?Q
MWO/TYR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,W"FUS
M9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BRN'HX?'I\^S\\B#DY>3O
M[-WM^>T@]_'>\_3G(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+VYO=&EC
M95]B;W1T;VTN:6YC.C8*;7-G:60@(D-L:6-K('1O($-O;G1I;G5E(@IM<V=S
M='(@(LK<[?3E(.KKZ>H@X^GA(//U[=WWY>GA(@H*;7-G:60@(D-L;W-E($AE
M;'`@5VEN9&]W(@IM<V=S='(@(LKKY=_SZ>SO(-#A\=SH]?'O]2#"[][HY>GA
M\B(*"FUS9VED(")#;&]S92!(96QP(@IM<V=S='(@(LKKY=_SZ>SO(,+OWNCE
MZ>'R(@H*;7-G:60@(D-L;W-E(%=I;F1O=R(*;7-G<W1R("+*Z^7?\^GL[R#0
MX?'<Z/7Q[_4B"@HC.B!T96UP;&%T97,O<&]R=&%L+W-I9&5B87(N:6YC.C0*
M;7-G:60@(D-O;&QA<'-E(%-I9&5B87(B"FUS9W-T<B`BP>WAY-_PZ_GSYR#0
MZ^7U\>GJWO(@S/#<\>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B0V]L;&%P<V5D(&)O<F1E
M<G,B"FUS9W-T<B`BP>WAY.GPZ_GLW>WA(-#E\>GH_O'IX2(*"B,Z(&QI8B]"
M;&]C:R]C;VQO<BYP:'`Z,3@@;&EB+T)L;V-K+V-O;&]R+G!H<#HR.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(Y
M"FUS9VED(")#;VQO<B(*;7-G<W1R("+7\?[LX2(*"B,Z(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HR.3<*(SH@9G)A;65W;W)K+T)L
M;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C(Y.`HC.B!F<F%M97=O<FLO54DO
M54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#<R('-E<G9I8V5S+VEM86=E<R]C
M;VQO<G!I8VME<BYP:'`Z,30*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3$*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-3(*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-C@*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z-CD*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#4*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y
M;6%N86=E;65N="YI;F,Z.#8*;7-G:60@(D-O;&]R(%!I8VME<B(*;7-G<W1R
M("+%\.GKW>KTY_(@U_'^[.'T[_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HR.#,T"FUS9VED(")#;VQO=7(@<V5L96-T:6]N(@IM<V=S='(@(L7P
MZ>OOX]X@U_'^[.'T[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`BT_3>Z^7R
M.B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Y,CD*;7-G:60@(D-O
M;'5M;B!T:71L97,B"FUS9W-T<B`BU-_TZ^_I(-/TY^O^[2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HR.#D*;7-G:60@(D-O;6EC<R(*;7-G<W1R
M(")#;VUI8W,B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C4*;7-G:60@(D-O
M;6UA;F0B"FUS9W-T<B`BQ>WT[^O>(@H*(SH@861M:6XO8VUD<VAE;&PN<&AP
M.C(P"FUS9VED(")#;VUM86YD(%-H96QL(@IM<V=S='(@(LK=Z_7V[_(@Q>WT
M[^O^[2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y.0IM
M<V=I9"`B0V]M;65N="(*;7-G<W1R("+3]_SKZ>\B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y,`IM<V=I9"`B0V]M;6]N($YA;64B
M"FUS9W-T<B`BRN_I[?P@O.WO[.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,C0R"FUS9VED(")#;VUP86YY(@IM<V=S='(@
M(L7TX>GQY=_A(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HV.3<*;7-G:60@(D-O;7!L971E9"(*;7-G<W1R("+/Z^_J
MZ^?Q_NCGZN4B"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M
M86EL<RYP:'`Z.#$*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E
M;6%I;',N<&AP.C@W"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M96UA:6QS+G!H<#HY-PHC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R
M+V5M86EL<RYP:'`Z,3`Q"FUS9VED(")#;VUP;W-E($UE<W-A9V4@*"5S*2(*
M;7-G<W1R("+3_>WHY?/G(,SG[?WLX?3O\B`H)7,I(@H*(SH@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C,Q"FUS9VED(")#;VUP=71E<G,B"FUS9W-T<B`BU?#O
MZ^_CZ?/TW?(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(T-PIM<V=I9"`B
M0V]N9&ET:6]N<R(*;7-G<W1R("+3]>WHWNKE\B(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C@Y"FUS9VED(")#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S
M(@IM<V=S='(@(L3IX?;O\=WR(-#A\>'LY?3Q[_#OW^?SY_(B"@HC.B!C;VYF
M:6<O<')E9G,N<&AP+F1I<W0Z,30V"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O
M<B!S>6YC:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN
M(@IM<V=S='(@(L7PZ>OOX]WR(./IX2#S]>/W\>_MZ?/L_"#LY2!01$%S+"#=
M[O7P[>$@U.?KW?;Y[>$@ZN'I($]U=&QO;VLN(@H*(SH@861M:6XO<V5T=7`O
M:6YD97@N<&AP.C$S-0IM<V=I9"`B0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@
M9&%T92XB"FUS9W-T<B`B1&EE($MO;F9I9W5R871I;VX@;75S<R!A:W1U86QI
M<VEE<G0@=V5R9&5N+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,C4*
M;7-G:60@(D-O;F9I9W5R871I;VX@;F5E9',@=7!D871I;F<N(@IM<V=S='(@
M(L<@\.'QX>SE]/'O\._?Y_/G(/?QY>G<YN7TX>D@Y>WG[-WQ^?/G+B(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HY.0IM<V=I9"`B0V]N9FEG=7)E("5S
M(@IM<V=S='(@(M#A\>'LY?3Q[_#OW^?SYR`E<R(*"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z,S<*;7-G:60@(D-O;F9I<FT@4&%S<W=O
M<F0B"FUS9W-T<B`BQ?#IXN7BX=_Y\^<@ROGDZ>KO_2(*"B,Z(&9R86UE=V]R
M:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(P-@HC.B!F<F%M97=O<FLO
M24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS,3D*;7-G:60@(D-O;FYE8W1I
M;VX@9F%I;&5D+B(*;7-G<W1R("+'(//][>3E\^<@X?#=]/7WY2XB"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,#8*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$Y"FUS9VED(")#
M;VYN96-T:6]N(&9A:6QE9#H@(@IM<V=S='(@(L<@\_WMY.7SYR#A\-WT]??E
M.B`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW.3,*;7-G
M:60@(D-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BXB"FUS9W-T<B`BP?'MY_/G(//][>3E\^?R(.'P_"#T[R#DY^S\\^GO(.7N
M]?#G\>7TY_3>(.KKY>GDZ?[M+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C<Y-0IM<V=I9"`B0V]N;F5C=&EO;B!R969U<V5D('1O('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB"FUS9W-T<B`B
MP?'MY_/G(//][>3E\^?R(.'P_"#T[R#DY^S\\^GO(.7N]?#G\>7TY_3>(.KK
MY>GDZ?[M+B#+_./O\B`Z("5S("@E<RDB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C<Y-`IM<V=I9"`B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB"FUS9W-T<B`BQR#S_>WDY?/G(.SE(/3O($944"U397)V97(@
MX?#=]/7WY2XB"@IM<V=I9"`B0V]N=&%C="!396%R8V@B"FUS9W-T<B`BP>WA
MYM[TY_/G(,7PX?;>\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HU-@IM<V=I9"`B0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN(@IM<V=S='(@(L_I(.7P
MX?;=\B#P\>_S]-WHY^KA[2#E\.GT]??^\B#S].\@Q.GE]>CU[?/I[^/QW/;O
M(//A\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP
M.C4Y(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C,*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HW.`IM<V=I9"`B
M0V]N=&5N=',@;V8@)R5S)R(*;7-G<W1R("+0Y?'IY??\[.7MX2#T[_4@)R5S
M)R(*"FUS9VED(")#;VYT96YT<R!O9B!T:&4@4D%2(&%R8VAI=F4B"FUS9W-T
M<B`BT.7QZ>7W_.SE[>$@]/GM(.'Q]^7?^>T@4D%2(@H*(SH@<V5R=FEC97,O
M<F5S971P87-S=V]R9"YP:'`Z,CD*;7-G:60@(D-O;G1I;G5E(@IM<V=S='(@
M(M/U[=WWY>GA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(L'M].GC
M\>'VWB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(L'M].GC\>'V
MWB#%\.GK[^/>\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.CDW-PIM<V=I9"`B0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N(@IM
M<V=S='(@(L'D_>WA].<@YR#J\?7P]._C\=SVY_/G(/3O]2#LY^W][.'T[_(@
M[.4@4$=0+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M-34*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+B(*;7-G<W1R
M("+!Y/WMX?3G(.<@]?#OX_'A]MX@]._U(.SG[?WLX?3O\B#LY2!01U`N(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HT,3$*;7-G:60@
M(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*;7-G<W1R("+!
MY/WMX?3G(.<@ZO'U\/3OX_'<]N?SYR#T[_4@[.?M_>SA]._R(.SE(%,O34E-
M12XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C0X-0IM
M<V=I9"`B0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N(@IM<V=S='(@
M(L'D_>WA].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R(.SE(%,O34E-12XB
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP
M.C$X-`IM<V=I9"`B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(*;7-G<W1R
M("+$Y>T@[/#\\>7SX2#MX2#P\>_SZ-WS^2#TY^T@Y?#A]MXN("5S(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ,3,*;7-G:60@(D-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(*;7-G<W1R("+!Y/WMX?3G(.<@
M\_WMY.7SYR#LY2#T[R!,1$%0+5-E<G9E<BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C$U-`HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ-S,*;7-G:60@(D-O
M=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<R(*;7-G<W1R("+!Y/WMX?3O\B#O
M(-WKY>/O\B#U\._K[]_P[_4N("5S(@H*(SH@861M:6XO<V5T=7`O:6YD97@N
M<&AP.C0X"FUS9VED(")#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@)R5S
M)R!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(L'D_>WA].<@YR#S_>WDY?/G(//T
M[^T@Y>[U\.?QY?3G]-X@)R5S)R#W\>?SZ>SP[^G^[?3A\B!&5%`Z("5S(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HS
M,CD*;7-G:60@(D-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S(@IM<V=S='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A(.O?\_3A\R#DZ>'M
M[^S>\BX@)7,B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ
M,3(V"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82XB"FUS9W-T
M<B`BP>3][>'TYR#G(.'P[^KQ]?#T[^/QW/;G\^<@4$=0(.3EY._LW>WY[2XB
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4T,`IM<V=I
M9"`B0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N(@IM<V=S='(@(L'D
M_>WA].<@YR#A\._J\?7P]._C\=SVY_/G(%,O34E-12#DY>3O[-WM^>TN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HR
M-3`*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,B"FUS9W-T
M<B`BP>3][>'TYR#G(.3IX>/QX?;>(.7PX?;>\BX@)7,B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C,V-0IM<V=I9"`B
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T
M<B`BP>3][>'TYR#G(.3IX>/QX?;>(.O?\_3A\B#DZ>'M[^S>\BX@)7,B"@HC
M.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HS-PIM<V=I9"`B0V]U;&0@;F]T
M(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+B(*;7-G<W1R("+!
MY/WMX?3G(.<@Y.GAX_'A]MX@<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)R`N
M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3D@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z.34Y"FUS9VED(")#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB
M"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y.GE]>KQZ>W>\_D@].<@Y.GE_>CU[?/G
M(/3O]2#PX?'AZ][P].<N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HR.#@*;7-G:60@(D-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!A9&1R97-S(&)O;VLN(@IM<V=S='(@(L'D_>WA].<@YR#PZ][Q
MY_(@\/'\\^+A\^<@]._U(,3IY?7H]>WSZ>_C\=SV[_4N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU,3`*;7-G:60@
M(D-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB
M"FUS9W-T<B`BP>3][>'TYR#G(/#KWO'G\B#P\?SSXN'SYR#TY_(@Z]_S].'R
M(.3IX>WO[-[R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-#8Q"FUS9VED(")#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+B(*;7-G<W1R("+!
MY/WMX?3G(.<@\.O>\>?R(/#Q_//BX?/G(.O?\_3A\B#A\/P@Z]_S].7R(.3I
MX>WO[-[R+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E
M<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8Y"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP:'`Z.#4*
M;7-G:60@(D-O=6QD(&YO="!L;V%D('-T<F%T96=Y("<E<R<N(@IM<V=S='(@
M(L'D_>WA].\@].\@]OSQ]/GLX2#S]/'A].?CZ>K>\B!<(B5S7"(N(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.C$Q,0HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z,S$*
M;7-G:60@(D-O=6QD(&YO="!M:V1I<B`G)7,G+B(*;7-G<W1R("+!Y/WMX?3G
M(.<@Y.?LZ>_U\>/?X2#VX>K=Z^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HW,C`*;7-G:60@(D-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N(@IM<V=S='(@(L'D
M_>WA].<@YR#A[=SJ].?SYR#DY^S\\^GO]2#JZ^7IY.GO_2#A\/P@]._M(.7N
M]?#G\>7TY_3>(,3G["[*Z^7IY.G^[2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C<P,@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS-30*;7-G:60@(D-O=6QD
M(&YO="!O<&5N("5S+B(*;7-G<W1R("+!Y/WMX?3O(/3O(-SM[^GC[.$@)7,N
M(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q)
M;G!U=%-T<F%T96=Y+V-O<'DN<&AP.C$T,`IM<V=I9"`B0V]U;&0@;F]T(&]P
M96X@)R5S)R!F;W(@=W)I=&EN9RXB"FUS9W-T<B`BP>3][>'T[R#T[R#<[>_I
MX^SA(%PB)7-<(B#CZ>$@Y>/C\>'VWBXB"@HC.B!F<F%M97=O<FLO36%I;G1E
M;F%N8V4O36%I;G1E;F%N8V4N<&AP.C0Q-2!C+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,B"FUS9W-T
M<B`BP>3][>'T[R#T[R#<[>_IX^SA(/3O]2#LW?'O]?(@Q.GA]^7?\>GSY_(@
M)7,B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A
M;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z-S$*;7-G:60@(D-O=6QD(&YO="!O
M<&5N(&1I<F5C=&]R>2`G)7,G+B(*;7-G<W1R("+$Y>T@[/#O\?X@[>$@X>WO
MW^[Y(/3O(/;<ZN7K[R!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M3V)J96-T+G!H<#HR-S`*;7-G:60@(D-O=6QD(&YO="!R96%D("5S+B(*;7-G
M<W1R("+$Y>T@[/#O\?X@[>$@Y.GAXMSS^2`E<RXB"@HC.B!S97)V:6-E<R]R
M97-E='!A<W-W;W)D+G!H<#HX-0IM<V=I9"`B(@HB0V]U;&0@;F]T(')E<V5T
M('1H92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R
M(&%L;"!O9B!T:&4@(@HB9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A
M9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E
M9"`B"B)F=7)T:&5R(&AE;'`N(@IM<V=S='(@(B(*(L'D_>WA].<@YR#A\??I
MZN_P[]_G\^<@]._U(.KYY.GJ[_T@X^GA(/3O[2#AZ?3O_>SE[>\@]_'>\_3G
M+B#*W/#OZ>$@WB#\Z^7R("(*(N_I(.OE\/3O[-WQY>GE\B#DY>T@Y=_MX>D@
M\_GS]-WR+B#.X>WAY._JZ>S<\_3E(-X@Y?#IZN_I[?GMWO/TY2#LY2#T[R#D
MZ>'WY>DM(@HB\>GS]-X@X>T@]_'EZ=SSY?/HY2#PY?'I\_/\].7QYR#B[][H
MY>GA+B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP
M.C,Q.`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS
M-#D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@V
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,Y,@HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3@*;7-G
M:60@(D-O=6QD(&YO="!R971R:65V92!!0TPB"FUS9W-T<B`BP>3][>'TYR#G
M(.'MW.KTY_/G(,O?\_3A\B#*X>W\[?GM(-#Q_//BX?/G\B`H04-,*2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<Y
M"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<R(*
M;7-G<W1R("+!Y/WMX?3G(.<@X>W<ZO3G\^<@Q.GE]>CU[?/I[^/QW/;O]2X@
M)7,B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N
M<&AP.C4P,0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO
M;B!L:7-T+B`E<R(*;7-G<W1R("+!Y/WMX?3G(.<@X>W<ZO3G\^<@R]_S].'R
M(,3IX>WO[-[R+B`E<R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-#4R"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@
M9&ES=')I8G5T:6]N(&QI<W1S+B`E<R(*;7-G<W1R("+!Y/WMX?3G(.<@X>W<
MZO3G\^<@R^GS]/[M(,3IX>WO[-[R+B`E<R(*"B,Z(&9R86UE=V]R:R])34%0
M+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R-@HC.B!F<F%M97=O<FLO24U!4"])
M34%0+T%#3"]R9F,R,#@V+G!H<#HR,S`*;7-G:60@(D-O=6QD(&YO="!R971R
M:65V92!S97)V97(G<R!C87!A8FEL:71I97,B"FUS9W-T<B`BP>3][>'TYR#G
M(.'MW.KTY_/G(/3Y[2#IY.GO]-[T^>T@]._U(.7N]?#G\>7TY_3>(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HU-`IM<V=I9"`B0V]U;&0@;F]T(')E
M=F5R="!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y?#A[>'V
M[_'<(/'UZ.S?\^7Y[2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.34*;7-G:60@
M(D-O=6QD(&YO="!R;61I<B`G)7,G+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GA
MX_'A]MX@]N'JW>OO]2`H<FUD:7(I(%PB)7-<(BXB"@HC.B!A9&UI;B]S971U
M<"]S8W)I<'1S+G!H<#HW,0IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2`E
M<R#Q]>CLW_/EZ?(N(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C4W"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(L3E(.SP[_'^(.WA
M(.K<[?D@Y?;EY/'IZOP@X>WTW^/QX?;O(/3Y[2#Q]>CLW_/E^>TN(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C8Q"FUS9VED(")#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S(@IM<V=S='(@(L3E(.SP[_'^
M(.WA(.K<[?D@Y?;EY/'IZOP@X>WTW^/QX?;O(/3Y[2#Q]>CLW_/E^>TZ("5S
M(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.3(*;7-G:60@(D-O=6QD
M(&YO="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`G)7,G+B(*;7-G
M<W1R("+$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y(/#Q_./QX>SLX2#E[>?LW?'Y
M\^?R(//T[R`G)7,G+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C0*
M;7-G:60@(D-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y(.7V
MY>3QZ>K\(.'Q]^7?[R#Q]>CLW_/E^>T@)7,N(@H*(SH@861M:6XO<V5T=7`O
M8V]N9FEG+G!H<#HW-`IM<V=I9"`B(@HB0V]U;&0@;F]T('-A=F4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O
M9B!T:&4@(@HB;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RXB"FUS9W-T
M<B`B(@HBQ.4@[/#O\?X@[>$@X?#OZ.?JY?WS^2#T[R#A\??EW^\@\?7H[-_S
MY?GM("5S+B#,\._QY=_TY2#EW_3E(.WA(/?QY_/I[._P[^G>+2(*(O/E].4@
M[.GA(.'P_"#TZ?(@Y?#IZ^_CW?(@X^GA(.WA(.'P[^CGZN7]\^7TY2#PW_/Y
M(//T[R`E<R#>(.'M].GC\=SX].4@[.4@].\@(@HB]]WQZ2#T[^T@ZO[DZ>KA
M(/#?\_D@\_3O("5S+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP
M:'`Z,3(S"FUS9VED(")#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BXB"FUS9W-T<B`BP>3][>'TYR#G(.'MX>;>].?SYR#S]._M(.7N]?#G\>7T
MY_3>($Q$05`N(@H*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN<&AP.C@W"FUS9VED(")#;W5L
M9"!N;W0@=6YL:6YK("<E<R<N(@IM<V=S='(@(L3E(.SP[_'^(.WA(.'P[_/U
M[>3=\_D@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,C(Q"FUS9VED(")#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S(@IM<V=S='(@(L3E(.SP[_'^(.WA(.7MY^SE\?[S^2#TY^T@
MY?#A]MXN("5S(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HT,#D*;7-G:60@(D-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(L3E(.SP[_'^(.WA(.7MY^SE\?[S
M^2#TYR#+W_/TX2#$Z>'M[^S>\BX@)7,B"@HC.B!A9&UI;B]S971U<"]I;F1E
M>"YP:'`Z-S`*;7-G:60@(D-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N
M(&9O<B`G)7,G.B`E<R(*;7-G<W1R("+$Y2#L\._Q_B#MX2#C\=SX^2#TZ?(@
M\?7LW_/EZ?(@X^GA("<E<R<Z("5S(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,U,`IM<V=I9"`B0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E
M8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BXB"FUS9W-T<B`B
M(@HBQ.4@[/#O\?X@[>$@XO'^(/3G(/#KY?7QZ>K>(.SPW/'A(/3O]2!-;WII
M;&QA+B#"Y>+AZ?GHY=_TX>D@_/3I(.7?[>'I("(*(N'M[^GJ]-XN(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,34Y"FUS9VED
M(")#;W5L9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT
M<R!F;W(@=&AE(&9O;&1E<B`G)7,G.B`E<R(*;7-G<W1R("(B"B+$Y2#L\._Q
M_B#MX2#D_O/Y(//T[R#W\=[S].<@)R5S)R#TX2#PX?'AZMST^2#DZ>KAZ?[L
MX?3A(//T[R#VW.KEZ^\@)R5S)SH@)7,B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-#$U"FUS9VED(")#;W5N=&5D('1E>'0B"FUS9W-T<B`BS.7T
M\>?LW>WO(.KEW^SE[>\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI
M;64N<&AP.C4Y,PIM<V=I9"`B0V]U;G1R>2(*;7-G<W1R("+7_O'A(@H*(SH@
M8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(W,PIM<V=I9"`B0V]U<G-E<R(*
M;7-G<W1R("+0[_'EW^7R(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN
M:6YC.C(Q('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY-PHC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"FUS9VED(")#<F5A=&4B"FUS
M9W-T<B`BQ.?LZ>_U\>/?X2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-PIM<V=I9"`B0W)E871E(&$@;&EN
M:R(*;7-G<W1R("+$Y^SI[_7QX]_A(.7M_/(@\_7MY-WS[._U(@H*;7-G:60@
M(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BQ.?LZ>_U\>/?X2#LZ>'R(.W=
MX?(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-0IM<V=I9"`B0W)E871E('-U8B!F;VQD97)S(@IM<V=S='(@(L3G[.GO]?'C
MW^$@]?#O]N'JW>OY[2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$S-B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R,@IM<V=I9"`B0W)E871O
M<B!097)M:7-S:6]N<R(*;7-G<W1R("+%[N_U\^GOY._TWO/EZ?(@Q.?LZ>_U
M\>/O_2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,R,30*;7-G:60@
M(D-R961I="!C87)D(&YU;6)E<B(*;7-G<W1R("+!\>GH[/SR(-#I\_3Y].GJ
MWO(@RMSQ].'R(@H*;7-G:60@(D-R961I=',B"FUS9W-T<B`BQ?7WX?'I\_3?
MY?(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,C8*;7-G:60@(D-U<G)E;G0@
M4&AA<V4B"FUS9W-T<B`BU/'=]^_U\^$@UMSSYR(*"B,Z(&QI8B]";&]C:R]T
M:6UE+G!H<#HS(&QI8B]";&]C:R]T:6UE+G!H<#HS,`IM<V=I9"`B0W5R<F5N
M="!4:6UE(@IM<V=S='(@(M3QW??O]?/A(/[QX2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B
M0W5R<F5N="!54DP@:7,B"FUS9W-T<B`BU.\@]/'=]^_M(%523"#EW^WAZ2(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C4*;7-G:60@(D-U<G)E;G0@5V5A
M=&AE<B(*;7-G<W1R("+4\=WW[^T@RN'I\?SR(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(Q.0IM<V=I9"`B0W5R<F5N="!C;VYD:71I;VXZ
M("(*;7-G<W1R("+4\=WW[_7SX2#S]>WHWNKG.B`B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,R"FUS9VED(")#=7)R96YT
M('-T>6QE(@IM<V=S='(@(M3QW??Y[2#S]/WK(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P.`IM<V=I9"`B0W5S=&]M:7IE('1A<VMS('1O(')U;B!U
M<&]N(&QO9V]N('1O("5S+B(*;7-G<W1R("+0X?'A[.7T\>_P[]_G\^<@Y.GA
MY.GJX?/I_NT@\._U(.7J].7K[_WM].'I(.KA]-P@].?M(.7?\^_D[R`E<RXB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,C`*;7-G:60@(D-U="(*;7-G<W1R("+!\._J[_#>(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-0IM<V=I9"`B
M0W5T('-E;&5C=&EO;B(*;7-G<W1R("+!\._J[_#>(.7PZ>OOX][R(@H*;7-G
M:60@(D1$(@IM<V=S='(@(LS,(@H*;7-G:60@(D1A:6QY(@IM<V=S='(@(L?L
MY?'>\^GA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I
M9"`B1&%T82(*;7-G<W1R("+$Y>3O[-WMX2(*"B,Z(&%D;6EN+V1A=&%T<F5E
M+G!H<#HV-0IM<V=I9"`B1&%T851R964@0G)O=W-E<B(*;7-G<W1R("+%[/;<
M[>GSYR`H0G)O=W-E<BD@1&%T851R964B"@IM<V=I9"`B1&%T86)A<V4@<75E
M<GD@9F%I;&5D+B(*;7-G<W1R("+'(.'MX>;>].?SYR#S].<@PMSSYR#$Y>3O
M[-WM^>T@X?#=]/7WY2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]R9F,X,C(N<&AP.C<W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S.#$*
M;7-G:60@(D1A=&4B"FUS9W-T<B`BQ^SE\>_LY^W?X2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$R"FUS9VED(")$871E(%)E8V5I
M=F5D(@IM<V=S='(@(L?LY?'O[.?MW^$@\.'QX>OAXM[R(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C<Y-0IM<V=I9"`B1&%T92!S96QE8W1I;VXB
M"FUS9W-T<B`BQ?#IZ^_CWB#'[.7Q[^SG[=_A\B(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR-C,*;7-G:60@(D1A>2(*;7-G<W1R("+'[-WQ
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS-0IM<V=I9"`B1&5?;&5T92!#;VQU;6XB"FUS9W-T<B`BQ.GA
MX_'A]MX@T_3>Z^?R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C,X-0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-#(R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L
M96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@(L3EZMWLXO'I
M[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP
M95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T<B`B
MQ.7JX>3IZN_?(.'QZ>CL[]\B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C8X-0IM<V=I9"`B1&5C;&EN960B"FUS9W-T
M<B`BN/?O]>T@X?'MY^CEWR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G
M<W1R("+,Y=_Y\^<@T.7QZ>CY\=_O]2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]522YP:'`Z,3DR(&QI8B]P<F5F<RYP:'`Z,3`X"FUS9VED(")$969A
M=6QT(@IM<V=S='(@(M#Q[^KAZ._QZ?/LW>WO(@H*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z-#<*(SH@=&5M<&QA=&5S+W!R
M969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z.#$*;7-G:60@(D1E9F%U;'0@
M0V]L;W(B"FUS9W-T<B`BT/'OY?#IZ^7C[-WM[R#7\?[LX2(*"FUS9VED(")$
M969A=6QT($ED96YT:71Y(@IM<V=S='(@(M#Q[^7PZ>OEX^S=[><@U.'U]/ST
MY_3A(@H*(SH@861M:6XO<&5R;7,O961I="YP:'`Z,3$Y(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z,C`T"FUS9VED(")$969A=6QT(%!E<FUI<W-I
M;VYS(@IM<V=S='(@(M#Q[^KAZ._QZ?/LW>WE\B#%[N_U\^GOY._TWO/EZ?(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(P-0IM<V=I9"`B
M1&5F875L="!P97)M:7-S:6]N<R(*;7-G<W1R("+0\>_JX>CO\>GS[-WMY?(@
MQ>[O]?/I[^3O]-[SY>GR(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C,S
M"FUS9VED(")$969I;FET:6]N<R(*;7-G<W1R("+/\>GS[._?(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#,*;7-G
M:60@(D1E;&5G871E('!O<VET:6]N(@IM<V=S='(@(LC=\^<@X>WTZ?#Q[_/^
M\._U(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HV.3,*;7-G:60@(D1E;&5G871E9"(*;7-G<W1R("+![?3I\/'O\_GP
MY^S=[>\B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<R(&%D;6EN+W!E<FUS+V1E
M;&5T92YP:'`Z-#8@861M:6XO<&5R;7,O9&5L971E+G!H<#HU,@HC.B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(Y-R!F<F%M97=O<FLO4&5R;7,O4&5R
M;7,O54DN<&AP.C,R-PHC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,T-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C0R"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z-S8@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHY.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$R,B!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T-0HC.B!T96UP;&%T97,O<VAA<F5S+V5D
M:70N:6YC.C$X."!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S,*(SH@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDY('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O9&5L971E+FEN8SHQ,PHC.B!T96UP;&%T97,O861M:6XO=7-E
M<B]L:7-T+FEN8SHS-`IM<V=I9"`B1&5L971E(@IM<V=S='(@(L3IX>/QX?;>
M(@H*(SH@861M:6XO9W)O=7!S+G!H<#HQ.#D@861M:6XO9W)O=7!S+G!H<#HR
M,3<*;7-G:60@(D1E;&5T92!'<F]U<"(*;7-G<W1R("+$Z>'C\>'VWB#/[-SD
MX?(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C8P(&9R86UE
M=V]R:R]097)M<R]097)M<R]522YP:'`Z.#0*;7-G:60@(D1E;&5T92!097)M
M:7-S:6]N(@IM<V=S='(@(L3IX>/QX?;>(,7N[_7SZ>_D_/3G\^?R(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.38*;7-G:60@
M(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BQ.GAX_'A]MX@
MZN'I(.7JZMWM^?/G(.SG[?7LW/3Y[2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3<*;7-G:60@(D1E;&5T92!C
M96QL(@IM<V=S='(@(L3IX>/QX?;>(.KEZ^GO_2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C,*;7-G:60@(D1E
M;&5T92!C;VQU;6XB"FUS9W-T<B`BQ.GAX_'A]MX@T_3>Z^?R(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T92!E>&ES=&EN9R!A
M;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`BQ.GAX_'A]MX@]?#<\??O[?3O
M\B#E[>'KZ^'J].GJ[_T@\/'O]/WP[_4B"@HC.B!A9&UI;B]P97)M<R]D96QE
M=&4N<&AP.C4P(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,S(V"FUS
M9VED(")$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`BQ.GA
MX_'A]MX@Y>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G(@H*(SH@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HS,CD*;7-G:60@(D1E;&5T92!P97)M:7-S
M:6]N<R!F;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\B"FUS9W-T
M<B`BQ.GAX_'A]MX@Y>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G(.KAZ2#JW.CE
M(/7P[RWE[N_U\^GOY/STY_/G.R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T92!R;W<B
M"FUS9W-T<B`BQ.GAX_'A]MX@\_3>Z^?R(@H*(SH@=&5M<&QA=&5S+W!R969S
M+V1E;&5T96ED96YT:71Y+FEN8SHQ-0IM<V=I9"`B1&5L971E('-E;&5C=&5D
M(&ED96YT:71Y(@IM<V=S='(@(M#Q[^7PZ>OEX^S=[><@U.'U]/STY_3A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8V"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN(@IM<V=S
M='(@(L3IX>/QX?;>(/3QW??O]?/A\B#S]-[KY_(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C(*;7-G:60@
M(D1E;&5T92!T:&4@8W5R<F5N="!R;W<B"FUS9W-T<B`BQ.GAX_'A]MX@]/'=
M]^_U\^'R(./QX>SLWO(B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N<&AP.C0X
M"FUS9VED(")$96QE=&4@=&AI<R!P97)M:7-S:6]N(&%N9"!A;GD@<W5B+7!E
M<FUI<W-I;VYS/R(*;7-G<W1R("+$Z>'C\>'VWB#A]?3>\B#TY_(@Y>[O]?/I
M[^3\].?SY_(@ZN'I(.K<Z.4@]?#O+>7N[_7SZ>_D_/3G\^?R.R(*"B,Z(&%D
M;6EN+W-E='5P+W-C<FEP=',N<&AP.C,U"FUS9VED(")$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T("<E<R<N(@IM<V=S='(@(L3IX>/QW/;GZN4@].\@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@)R5S)RXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4X-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8Q.0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C<*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8Q"FUS
M9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(K_QX2#<]NGNY_(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,@IM
M<V=I9"`B1&5N>2!R97%U97-T(@IM<V=S='(@(L'Q[>?SYR#AZ?3>[.'T[_(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0W,0IM<V=I9"`B1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M
M871I;VXB"FUS9W-T<B`BP?'MY_/G(.'I]-[LX?3O\B#CZ>$@\.OG\>_V[_'?
MY?(@Y.GAZ.7SZ>S\].?TX?(B"@HC.B!S97)V:6-E<R]P<F]B;&5M+G!H<#HY
M-2!S97)V:6-E<R]P<F]B;&5M+G!H<#HY.2!S97)V:6-E<R]P<F]B;&5M+G!H
M<#HQ,#D*;7-G:60@(D1E<V-R:6)E('1H92!0<F]B;&5M(@IM<V=S='(@(M#E
M\>GC\>'VWB#T[_4@T/'OXNO>[.'T[_(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4V-2!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HY,S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
MT.7QZ>/QX?;>(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HR,#$*
M;7-G:60@(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB"FUS
M9W-T<B`BR^7P]._LW?'EZ>7R("CE\-_SY_(@ZN'I(//T[R#A\??EW^\@ZN'T
MX>/QX?;>\B#T[_4@2&]R9&4I.B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92YP:'`Z,C`U"FUS9VED(")$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("+/Z2#KY?#T[^S=\>7IY?(@
MW??O]>T@ZN'TX>/QX?;EWR#CZ>$@]._M(.3IX??EZ?'I\_3>+B(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ.3,*;7-G:60@(D1E=F5L;W!M96YT
M(@IM<V=S='(@(L'MW/#T]>[G(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M,34*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("+3Y^SEW^\@Q/'O\^G<\B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-S8*;7-G:60@(D1E
M=R!P;VEN=#H@(@IM<V=S='(@(M/G[.7?[R#$\>_SZ=SR.B`B"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(Y,@IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L87-T
M(&AO=7(Z("(*;7-G<W1R("+3Y^SEW^\@Q/'O\^G<\B#CZ>$@].?M(/3EZ^7U
M].'?X2#^\>$Z("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,S@*;7-G:60@(D1I<F5C=&EO;B!L969T('1O(')I9VAT(@IM
M<V=S='(@(LKA].7]Z/7M\^<@X?#\(.'QZ?/TY?'<(/#Q[_(@].$@Y.7NZ=PB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y
M"FUS9VED(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("+*X?3E
M_>CU[?/G(.'P_"#TX2#DY>[IW"#P\>_R(/3A(.'QZ?/TY?'<(@H*(SH@;&EB
M+T)L;V-K+V=O;V=L92YP:'`Z,SD*;7-G:60@(D1I<F5C=&]R>2(*;7-G<W1R
M("+*X?3<Z^_C[_(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C4P"FUS
M9VED(")$:7-P;&%Y(#(T+6AO=7(@=&EM97,_(@IM<V=S='(@(L7L]MSMZ?/G
M(/[QX?(@\^4@,C3Y\><@[._Q]MX[(@H*;7-G:60@(D1I<W!L87D@3W!T:6]N
M<R(*;7-G<W1R("+%\.GK[^/=\B#%[/;<[>GSY_(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C@S"FUS9VED(")$:7-P;&%Y(&9O<F5C87-T("A4048I(@IM
M<V=S='(@(L7L]MSMZ?/G(/#Q[^+KW?CE^>T@*%1!1BDB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR.#`U"FUS9VED(")$:7-P;&%Y(&9O<FUA="(*
M;7-G<W1R("+,[_'VWB#%[/;<[>GSY_(B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+TU$3BYP:'`Z,C`S"FUS9VED(")$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VXB"FUS9W-T<B`BQ>WG[-WQ^?/G(,3IW/3A[N?R(@H*(SH@861M:6XO<&5R
M;7,O9&5L971E+G!H<#HT-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C,R-PIM<V=I9"`B1&\@;F]T(&1E;&5T92(*;7-G<W1R("+,YR#DZ>'C\=SV
MY>GR(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP.C(T"FUS9VED(")$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<"(*;7-G<W1R
M("+,Y^T@Y?#I]^7I\=[SY?3E(.WA(.'M[]_NY?3E(.'PY?7HY=_A\B#T[R#A
M\??EW^\@;6%I;G1E;F%N8V4N<&AP(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V
M:6YF;RYI;F,Z,3D@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3D*;7-G
M:60@(D1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#HB"FUS9W-T<B`BT.7QZ=WWY>D@
MYR#P\?[TYR#C\>'L[-X@[^W\[.'TX2#PY>3?^>T[(,'M(.WAZ2#T\^7JW/'E
M].4@X?7T_#HB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HX-C8*;7-G:60@(D1O=VYL;V%D(@IM<V=S='(@(LKA]-WBX?/LX2(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@V-@IM<V=I9"`B
M1&]W;FQO860@)7,B"FUS9W-T<B`BRN'TW>+A\^SA("5S(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$U-@IM<V=I9"`B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB"FUS9W-T<B`BRN'TW>+A
M\^SA(/3O]2#A\??EW^_U(/#A\>'LW?3Q^>T@\^'M(%!(4"US8W)I<'0N(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Y,`IM<V=I9"`B1')O<"!D
M;W=N(&QI<W0B"FUS9W-T<B`BR]_S].$@RN'TX?'<ZO3G\B(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS-`IM<V=I9"`B1')U9W,B"FUS9W-T<B`BUMSQ
M[.'JX2WMX?'J^?3IZMPB"@IM<V=I9"`B161I="(*;7-G<W1R("+%\.7NY?'C
MX?/?X2(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3$@=&5M
M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR,@IM<V=I9"`B161I="!";&]C:R(*
M;7-G<W1R("+%\.7NY?'CX?/?X2!";&]C:R(*"B,Z(&%D;6EN+V=R;W5P<RYP
M:'`Z,3@X(&%D;6EN+V=R;W5P<RYP:'`Z,C$V"FUS9VED(")%9&ET($=R;W5P
M(@IM<V=S='(@(L7PY>[E\>/A\]_A(,_LW.3A\B(*"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<R]522YP:'`Z-3D@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HX,PIM<V=I9"`B161I="!097)M:7-S:6]N(@IM<V=S='(@(L7PY>[E
M\>/A\]_A(,7N[_7SZ>_D_/3G\^?R(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D
M:70N<&AP.C(S-PIM<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("+%
M\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>TB"@HC.B!S97)V:6-E<R]S:&%R
M97,O961I="YP:'`Z,C,Y"FUS9VED(")%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<R(*;7-G<W1R("+%\.7NY?'CX?/?X2#%[N_U\^GOY._TWO/E^>T@X^GA("5S
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z.0IM<V=I9"`B161I="!O
M<'1I;VYS(&9O<CHB"FUS9W-T<B`BQ?#E[N7QX^'SW^$@Y?#IZ^_C_NT@X^GA
M.B(*"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,30*;7-G:60@(D5D
M:70@<&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(L7PY>[E\>/A\]_A(,7N
M[_7SZ>_D[_3>\^7Y[2#CZ>$@)7,B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H
M<#HR,#0@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR.#@*;7-G:60@
M(D5D:70@<&5R;6ES<VEO;G,@9F]R("<E<R<B"FUS9W-T<B`BQ?#E[N7QX^'S
MW^$@Q>[O]?/I[^3O]-[SY?GM(./IX2`G)7,G(@H*;7-G:60@(D5L969S:7,@
M06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#%Z^7U\]_MX?(B"@IM<V=I
M9"`B2&5R86ML:6]N($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI[-WMX?(@Q_'A
MZNOEW^_U(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0R"FUS9VED(")%;&5M96YT+BXN(@IM<V=S='(@(M/T
M[^GWY=_O+BXN(@H*;7-G:60@(D5M86EL(@IM<V=S='(@(L'KZ^?K[^/QX?;?
MX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@Y('1E
M;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,3(*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O=7!D871E+FEN8SHT,`IM<V=I9"`B16UA:6P@061D<F5S
M<R(*;7-G<W1R("+$Z>7]Z/7M\^<@16UA:6PB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.30V"FUS9VED(")%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"XB"FUS9W-T<B`BQR#DZ>7]Z/7M\^<@16UA:6P@\/'=\.7I(.WA(/3A
MZ?'IW.;EZ2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3<R"FUS
M9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R("+,WNWU[.$@
M[.4@\?7H[-_SY>GR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(X,`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(L'I\^C>
M[.'TX2(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,Q,0IM<V=I9"`B16UP='D@;65S<V%G92XB"FUS9W-T<B`BRN7M
M_"#LWNWU[.$N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HQ
M,S$*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`BQ.7M(.7PZ?/T\=SV
MY^KA[2#!\._TY>O=\^SA].$N(@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y
M=V]R9',N<&AP.C$Q-`IM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S
M='(@(L'DY>GE\B#S]>WHWNKE\B#A[>'FWO3G\^?R(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C4R-@IM<V=I9"`B16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\B"FUS9W-T<B`B
MQ>WE\>/O\._?Y_/G(.7I\^'C^>/>\B#EZ>K\[?GM(.'P[R!0:&]T;R!#86QL
M97)I97<@\_3O(.KEW^SE[>\[(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C4P,0IM<V=I9"`B16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\B
M"FUS9W-T<B`BS>$@Y>WE\>/O\._IY^CEWR#T[R#LY>WO_2#LY2#DY>[?(.KK
MZ>H[(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HT-#@*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HU-3,*;7-G:60@(D5N9"(*;7-G<W1R("+4W>OO\B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3`@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,C<Y.0IM<V=I9"`B16YD('EE87(B"FUS9W-T<B`BN/3O\B#4W>OO
M]?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C(Y"FUS9VED(")%;FQA<F=E($5D:71O<B(*;7-G<W1R("+,Y>/=[>CU\^<@
MRN7I[.7M[^/QW/;O]2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,#4*
M;7-G:60@(B(*(D5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U
M('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B`B"B)P
M87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G
M.B(*;7-G<W1R("(B"B+$_O/TY2#LZ>$@Y?'^].?SYR#A\_;AZ^7?X?(L(.<@
M[_#OW^$@Z.$@\^'R(.;G].?HY=\@X>T@]_'EZ>'SZ.7?(.WA(.'KZ]SNY2TB
M"B+TY2#T[^T@ZOGDZ>K\(//A\BP@\"[W+B`GT._I_"#EW^WAZ2#T[R#\[>_L
MX2#T[_4@ZN'T[^GJZ>3?[_4@\^'R.R<Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3D*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(R"FUS9VED(")%
M;G1E<B!T:&4@:6UA9V4@55),(&AE<F4B"FUS9W-T<B`BQ/[S].4@].<@\_WM
MY.7SYR#TY_(@Y>GJ_.WA\B#EY/XB"@IM<V=I9"`B17)R;W(B"FUS9W-T<B`B
MR]SH[_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C$Y-0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C(W.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C,T-PIM<V=I9"`B17)R;W(@<V5N9&EN9R!R97!L>3H@
M)7,N(@IM<V=S='(@(LO<Z._R(.'P[_/TW>OK[^WTX?(@X?#<[?3G\^<Z("5S
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S$T"FUS9VED(")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(@IM<V=S
M='(@(LO<Z._R(.SE(.S>[?7LX2!E;6%I;"XB"@HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP
M:'`Z,30S"FUS9VED(")%<G)O<B!W<FET:6YG("<E<R<N(@IM<V=S='(@(LO<
MZ._R(./QW/;O[?3A\B!<(B5S7"(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N
M<&AP.C,V"FUS9VED(")%=&AN:6,B"FUS9W-T<B`BQ>CMZ>K\(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4V"FUS9VED(")%=7)O<&4B"FUS
M9W-T<B`BQ?7Q_O#G(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,R,PIM
M<V=I9"`B179E<GD@,34@;6EN=71E<R(*;7-G<W1R("+*W.CE(#$U(.OE\/3<
M(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W,PIM<V=I9"`B179E<GD@
M,B!M:6YU=&5S(@IM<V=S='(@(LK<Z.4@,B#+Y?#TW"(*"FUS9VED(")%=F5R
M>2`S,"!S96-O;F1S(@IM<V=S='(@(LK<Z.4@,S`@Y.7U].7Q_.OE\/3A(@H*
M;7-G:60@(D5V97)Y(#4@;6EN=71E<R(*;7-G<W1R("+*W.CE(#4@Z^7P]-PB
M"@IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BRMSHY2#V[_'<(/#O]2#L
M\.'?[>7TY2#S].?M(/7PY_'E\]_A(@H*;7-G:60@(D5V97)Y(&AA;&8@:&]U
M<B(*;7-G<W1R("+*W.CE(.SI\]X@_O'A(@H*;7-G:60@(D5V97)Y(&UI;G5T
M92(*;7-G<W1R("+*W.CE(.OE\/3\(@H*;7-G:60@(D5X86UP;&4@=F%L=65S
M.B(*;7-G<W1R("+0X?'AY.7IX^SA].GJW?(@].GLW?(Z(@H*(SH@861M:6XO
M<&AP<VAE;&PN<&AP.C<V(&%D;6EN+V-M9'-H96QL+G!H<#HU,"!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3,V"FUS9VED(")%>&5C=71E(@IM<V=S='(@(L7J]-WK
MY?/G(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S@V
M"FUS9VED(")%>'!A;F0B"FUS9W-T<B`BQ?#=ZO3A\^<B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+W-I9&5B87(N:6YC.C,Q"FUS9VED(")%>'!A;F0@4VED96)A
M<B(*;7-G<W1R("+%\-WJ].'SYR#0Z^7U\>GJWO(@S/#<\>'R(@H*(SH@9G)A
M;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP.C$V.0IM<V=I9"`B17AP96-T
M960@)RDG(@IM<V=S='(@(L'MX>S=[>_M].'M("<I)R(*"B,Z(&,M9F]R;6%T
M"FUS9VED(")%>'!E8W1E9"!<(D)%1TE.7"(@:6X@=&AE(&QI;F4@)60N(@IM
M<V=S='(@(L'MX>SE[?SLY>WO(%PB0D5'24Y<(B#S].<@X_'A[.S>("5D+B(*
M"B,Z(&,M9F]R;6%T"FUS9VED(")%>'!E8W1E9"!<(D5.1#HE<UPB(&EN(&QI
M;F4@)60N(@IM<V=S='(@(L'MX>SE[?SLY>WO(%PB14Y$.B5S7"(@\_3G(./Q
MX>SLWB`E9"XB"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z
M,3<V"FUS9VED(")%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C
M:"!T97)M(@IM<V=S='(@(L'MX>S=[>_M].'M(.'PZ]X@Z]WNYR#>(//U[>C>
MZN<@X>WAYM[TY_/G\B#SY2#EZ?/AX_GCZ>K<(@H*(SH@9G)A;65W;W)K+T-R
M>7!T+T-R>7!T+W!G<"YP:'`Z,SDX"FUS9VED(")%>'!I<F%T:6]N($1A=&4B
M"FUS9W-T<B`BQ^SE\>_LY^W?X2#+WN[G\B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-S`P"FUS9VED(")%>'!O;F5N="(*;7-G<W1R
M("+%ZNC=].?R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,0IM<V=I9"`B1D<@0V]L;W(B"FUS9W-T<B`BU_'^
M[.$@\/'O\^K>[>GO]2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-S$*
M;7-G:60@(D944"!U<&QO860@;V8@<V5T=7`B"FUS9W-T<B`BT?7H[-_SY>GR
M(./IX2!&5%`@=7!L;V%D(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-Q
M;"YP:'`Z,C0P"FUS9VED(")&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E
M<RXB"FUS9W-T<B`BP?#O]/7WW^$@ZN'TW"#TY^T@\/'O\_#<Z.7IX2#A[=SJ
M].?SY_(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED(")&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BXB"FUS9W-T<B`BP?#O]/7WW^$@\_WMY.7S
MY_(@\_3O[2#DZ>'J[^SI\_3>(,KA].'K_./O]2XB"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+W-M8BYP:'`Z,3`S"FUS9VED(")&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+B(*;7-G<W1R("+!\._T]???X2#S_>WDY?/G\B#S
M]._M(%--0BU397)V97(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HV,S$*;7-G:60@(D9A:6QE9"!T;R!C;W!Y(&9R;VT@7"(E<UPB+B(*;7-G
M<W1R("+!\._T]???X2#A[?3IX_'A]M[R(.'P_"!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9G1P+G!H<#HV,S8*;7-G:60@(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB"FUS9W-T<B`BP?#O]/7WW^$@X>WTZ>/QX?;>\B#S
MY2!<(B5S7"(N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HY
M,@IM<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N
M+B(*;7-G<W1R("+!\._T]???X2#DY^SI[_7QX]_A\B#S_>WDY?/G\B!305-,
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C<Q"FUS9VED(")&
M86EL960@=&\@;6]V92!T;R!<(B5S7"(N(@IM<V=S='(@(L'P[_3U]]_A(.SE
M].'V[_'<\B#SY2!<(B5S7"(N(@H*;7-G:60@(D9A:6QU<F4@:6X@8VAA;F=I
M;F<@<&%S<W=O<F0@9F]R('5S97(@)7,@9G)O;2!C;&EE;G0@)7,L(')E87-O
M;B`E<R(*;7-G<W1R("(B"B+!\._T]???X2#JX?3<(/3G[2#AZ^OAX]X@ZOGD
MZ>KO_2#CZ>$@]._M(/?QWO/TYR`E<R#A\/P@].\@\_3AZ.S\("5S+"#K_./O
M\B`E<R(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,38*;7-G
M:60@(D9A:7(B"FUS9W-T<B`BP=_H\>GO\B(*"B,Z(&9R86UE=V]R:R]#3$DO
M0TQ)+G!H<#HR,S4*;7-G:60@(D9A=&%L($5R<F]R.B(*;7-G<W1R("+0[^O]
M(//OXN'Q_"#+W.CO\CHB"@IM<V=I9"`B1F%X(@IM<V=S='(@(M;!SB(*"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS-S4*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8V"FUS9VED
M(")&96)R=6%R>2(*;7-G<W1R("+6Y>+Q[_7<\>GO\B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,C$X"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@(L3I
MW.CE\^<@X^GA(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X
M,`IM<V=I9"`B1F5E;',@;&EK93H@(@IM<V=S='(@(L3IW.CE\^<@X^GA.B`B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$W"FUS9VED(")&
M97<@4VAO=V5R<R(*;7-G<W1R("++W^/E\B#B\>_WW?(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$X"FUS9VED(")&97<@4VYO=R!3:&]W
M97)S(@IM<V=S='(@(LO?X^7R(/?I[^WO\/3^\^7I\B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y,C<*;7-G:60@(D9I96QD(&UA=')I>"(*;7-G
M<W1R("+0W^WAZN'R(-#EY-_O]2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M>FEP+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN
M<&AP.C@R"FUS9VED(")&:6QE($-O=6YT.B`E<R!F:6QE(@IM<V=S='(@(L'Q
MZ>CL_/(@X?'WY=_O]3H@)7,@X?'WY=_O(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV,R!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C8W"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#(*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S(@IM<V=S
M='(@(L'QZ>CL_/(@X?'WY=_O]3H@)7,@X?'WY=_A(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,T.0IM<V=I9"`B1FEL92!-86YA9V5R(@IM<V=S
M='(@(L3IX??EZ?'I\_3>\B#!\??EW_GM(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O<F%R+G!H<#HV-B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]Z:7`N<&AP.C<P"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W1G>BYP:'`Z.#4*;7-G:60@(D9I;&4@3F%M92(*;7-G<W1R("*\[>_LX2#!
M\??EW^_U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDW.0IM<V=I
M9"`B1FEL92!S96QE8W1I;VXB"FUS9W-T<B`BQ?#IZ^_CWB#!\??EW^_U(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30X,@IM<V=I9"`B1FEL92!U
M<&QO860B"FUS9W-T<B`B)\'MW>+A\^SA)R#!\??EW^_U(@H*(SH@9G)A;65W
M;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<T"FUS9VED(")&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`B)\'MW>+A\^SA)R#!\??EW^_U
M(.3E[2#U\._S].?QW^;E].'I+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HX-@IM<V=I9"`B1FEL=&5R<R(*;7-G<W1R("+6W^OT\>$B"@HC.B!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,3<Q"FUS9VED(")&:7)S="!(86QF(@IM<V=S
M='(@(M#Q_O3O(,SI\_PB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z-S0@;&EB
M+T)L;V-K+VUO;VXN<&AP.C<V"FUS9VED(")&:7)S="!1=6%R=&5R(@IM<V=S
M='(@(M#Q_O3O(-3=].'Q].\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z,C,Y"FUS9VED(")&:7@@<F%T:6\B"FUS9W-T<B`B
MT_3AZ.7Q_/(@Z_SC[_(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z,C$T"FUS9VED(")&;&EP(@IM<V=S='(@(D9L:7`B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS
M.C,R"FUS9VED(")&;&]A="(*;7-G<W1R(")&;&]A="(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M+G!H<#HS,3D*;7-G:60@(D9O9R(*;7-G<W1R("+/
M[-_WZ^<B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$V,R!F<F%M
M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,3`X"FUS9VED(")&;VQD97(@)7,@
M9&]E<R!N;W0@97AI<W0B"FUS9W-T<B`BSR#VW.KEZ^_R("5S(.3E[2#U\-SQ
M]^7I(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G<W1R("+7\?[LX2#C\=SL[.'T
M[_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*;7-G:60@(D9O;V0B
M"FUS9W-T<B`BU/'O]MXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C$R,PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C8*;7-G:60@(D9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S(@IM<V=S='(@(L/IX2!"<F]W
M<V5R<RP@\._U(.3E[2#U\._S].?QW^;O]>T@Y>GJ_.WE\B(*"B,Z('1E;7!L
M871E<R]L;V=I;B]L;V=I;BYI;F,Z.34*;7-G:60@(D9O<F=O="!Y;W5R('!A
M<W-W;W)D/R(*;7-G<W1R("+.Y??<\^'TY2#T[^T@ZOGDZ>K\(//A\CLB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,Q"FUS9VED(")&;W)M<R(*
M;7-G<W1R("+6_/'LY?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,C$*
M;7-G:60@(D9O<G1U;F4B"FUS9W-T<B`BT/'\XNOE^.<B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z.3D*;7-G:60@(D9O<G1U;F4@='EP92(*;7-G<W1R
M("+4_?#O\B#0\?SBZ^7XY_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z
M,S@*;7-G:60@(D9O<G1U;F5S(@IM<V=S='(@(M#Q[^+KW?CEZ?(B"@HC.B!L
M:6(O0FQO8VLO9F]R='5N92YP:'`Z,SD*;7-G:60@(D9O<G1U;F5S(#(B"FUS
M9W-T<B`BT/'OXNO=^.7I\B`R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C0Q-`IM<V=I9"`B1F]R=6US(@IM<V=S='(@(D9O<G5M<R(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-3@*;7-G:60@(D9O<G=A<F1S(@IM
M<V=S='(@(M#Q[_GHWO/EZ?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8P"FUS9VED(")&<B(*;7-G<W1R("+0X2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S,*;7-G:60@(D9R86UE<R(*;7-G<W1R("+0Z^'?\^GA(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT,3<*;7-G:60@
M(D9R964O0G5S>2!);F9O<FUA=&EO;B(*;7-G<W1R("+0Z^?Q[_;O\=_E\B#$
MZ>'HY?/I[/STY_3A\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#(W"FUS9VED(")&<F5E+T)U<WD@4F5P;'DB"FUS
M9W-T<B`BP?#<[?3G\^<@Q.GAZ.7SZ>S\].?TX?(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C0R,@IM<V=I9"`B1G)E
M92]"=7-Y(%)E<75E<W0B"FUS9W-T<B`BP=_TY^SA(,3IX>CE\^GL_/3G].'R
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HR-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R
M+G!H<#HS-#$*;7-G:60@(D9R964O0G5S>2!297%U97-T(%)E<W!O;G-E(@IM
M<V=S='(@(L'PW.WTY_/G(//E(.'?].?LX2#$Z>'HY?/I[/STY_3A\B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP:'`Z-SD*;7-G
M:60@(D9R;VTB"FUS9W-T<B`BP?#\(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$Y-PIM<V=I9"`B1G)O;2!T:&4@(@IM<V=S='(@(L'P_"#T
M[R`B"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHT.`IM<V=I
M9"`B1G5L;"!$97-C<FEP=&EO;B(*;7-G<W1R("+![>'K]?3IZMX@T.7QZ>/Q
MX?;>(@H*;7-G:60@(D9U;&P@1&5S8W)I<'1I;VXZ(@IM<V=S='(@(L'MX>OU
M].GJWB#0Y?'IX_'A]MXZ(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@R(&QI
M8B]";&]C:R]M;V]N+G!H<#HQ.#$*;7-G:60@(D9U;&P@36]O;B(*;7-G<W1R
M("+0Z][QY_(@T^7KWNWG(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D
M871E+FEN8SHS.0IM<V=I9"`B1G5L;"!.86UE(@IM<V=S='(@(M#KWO'E\B"\
M[>_LX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L
M:6UA9V5?;&%N9RYJ<SHS,`IM<V=I9"`B1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VTB"FUS9W-T<B`B1V%L;&5R>2#A\/P@].?M(._P[]_A(.CA(/#AW_'M
M[^WTX>D@[^D@Y>GJ_.WE\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB
M"FUS9W-T<B`B1V%L;&5R>3HB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C4Y.0IM<V=I9"`B1VEV96X@3F%M92(*;7-G<W1R("+,Z>KQ
M_""\[>_LX2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ-S4@
M=&5M<&QA=&5S+W!R969S+V%P<"YI;F,Z,3`*(SH@=&5M<&QA=&5S+W!R969S
M+V%P<"YI;F,Z,3D*;7-G:60@(D=L;V)A;"!/<'1I;VYS(@IM<V=S='(@(L/E
M[>GJW?(@Q?#IZ^_CW?(B"@HC.B!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ
M-@IM<V=I9"`B1V\B"FUS9W-T<B`BS.7TW.+A\^<B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.CDS"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-PIM
M<V=I9"`B1W)E96-E(@IM<V=S='(@(L7KZ]SDX2(*"B,Z(&-O;F9I9R]N;',N
M<&AP+F1I<W0Z,3@Q"FUS9VED(")'<F5E:R`H25-/+3@X-3DM-RDB"FUS9W-T
M<B`BQ>OKY^WIZMP@*$E33RTX.#4Y+3<I(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HQ-S`*;7-G:60@(D=R;W5P($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(L3I
MX??EW_'I\^<@S^S<Y/GM(@H*(SH@9G)A;65W;W)K+T=R;W5P+T=R;W5P+G!H
M<#HU-PIM<V=I9"`B1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS
M9W-T<B`BU.$@[^W\[.'TX2#T^>T@[^S<Y/GM(.3E[2#P\=WPY>D@[>$@Y=_M
MX>D@ZN7MW"(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C(P,2!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(X-0IM<V=I9"`B1W)O=7`@<&5R;6ES
M<VEO;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR(,_LW.3Y[2(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C$W-B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O
M54DN<&AP.C(U.`HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HS."!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$X,PIM<V=I9"`B1W)O=7!S(@IM<V=S='(@
M(L_LW.3E\B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$R-R!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(Q,PHC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.CDT"FUS9VED(")'=65S="!097)M:7-S:6]N<R(*;7-G<W1R
M("+)Y.G\].?TY?(@1W5E<W0B"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ
M,C@@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,30*;7-G:60@(D=U
M97-T('!E<FUI<W-I;VYS(@IM<V=S='(@(LGDZ?STY_3E\B!'=65S="(*"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,SD*;7-G:60@(D=U97-T8F]O
M:R(*;7-G<W1R(")'=65S=&)O;VLB"@HC.B!F<F%M97=O<FLO075T:"]!=71H
M+VAT='`N<&AP.C$V-`IM<V=I9"`B2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N(@IM<V=S='(@(M3O(//]\_3G[.$@X?7HY>WTZ>KO\._?Y_/G\B!(
M5%10(.3E(.+QW>CGZN4N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS-`IM<V=I9"`B2&5I9VAT(@IM<V=S='(@
M(K[X[_(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O2&5L<"YP:'`Z,3<Y
M(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ.#8*(SH@<V5R=FEC
M97,O:&5L<"]I;F1E>"YP:'`Z,3<@=&5M<&QA=&5S+VAE;'`O:6YD97@N:6YC
M.C,*;7-G:60@(DAE;'`B"FUS9W-T<B`BPN_>Z.7IX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S$*;7-G:60@(DAE;'`@
M=7-I;F<@961I=&]R(@IM<V=S='(@(L+OWNCEZ>$@X^GA(/3G(/?QWO/G(/3O
M]2#JY>GLY>WOX_'<]N_U(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3,V-PIM<V=I9"`B2&5L<&5R(@IM<V=S='(@(L+OY^C\\B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HR.0IM<V=I9"`B2&5M:7-P:&5R92(*;7-G<W1R("+'
M[.GS]N'?\>GO(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3<@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(DAE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93HB"FUS9W-T<B`BQ>3^(.7?[>'I
M(.<@X?'WWB#T[_4@X?'WY=_O]3HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,S8Q"FUS9VED(")(:6=H(@IM<V=S='(@(MCGZ]PB"@HC.B!F
M<F%M97=O<FLO2&ES=&]R>2](:7-T;W)Y+G!H<#HS,C(*;7-G:60@(DAI<W1O
M<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP='DB"FUS9W-T<B`BQR#E
MX^/QX?;>(.GS]._QZ>KO_2#DY>T@\/'=\.7I(.WA(.7?[>'I(.KE[=XB"@HC
M.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN
M+V-O;6UO;BUH96%D97(N:6YC.C0*;7-G:60@(DAO7VUE(@IM<V=S='(@(L'Q
M]^GJWB#3Y>O?Y.$B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$T
M-C`*;7-G:60@(DAO;64B"FUS9W-T<B`BP?'WZ>K>(-/EZ]_DX2(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,C4*(SH@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$U.`IM<V=I9"`B
M2&]M92!!9&1R97-S(@IM<V=S='(@(L3IY?WH]>WSYR#3\.GTZ>_](@H*;7-G
M:60@(DAO;64@4&AO;F4B"FUS9W-T<B`BU.?KW?;Y[>\@T_#I].GO_2(*"FUS
M9VED(")(;W)D92(*;7-G<W1R("+!\??IZMX@T^7KW^3A(@H*;7-G:60@(DAO
M<F1E($QO9VEN(@IM<V=S='(@(L7?\^_D[_(@\_3G[2#5\.?QY?/?X2#'R^7J
M]/'O[>GJ[_T@U.'W]>3Q[^SEW^_U(@H*;7-G:60@(DAO<F1E(%-Y<W1E;2(*
M;7-G<W1R("+3_?/TY^SA("=(;W)D92<B"@IM<V=I9"`B2&]R9&4@5VER96QE
M<W,B"FUS9W-T<B`B)TAO<F1E)R#!\_WQ[.'TYR(*"FUS9VED(")(;W)D92!I
M<R!N;W0@<')O<&5R;'D@8V]N9FEG=7)E9"(*;7-G<W1R("+4[R#P\?SC\>'L
M[.$@)TAO<F1E)R#DY>T@W??EZ2#Q]>CLZ?/TY=\@\_GS]-PB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(T"FUS9VED(")(
M;W)I>F]N=&%L(%)U;&4B"FUS9W-T<B`BS_'IYOSM].GO\B#*X>W\[>'R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,@IM
M<V=I9"`B2&]R:7IO;G1A;"!P861D:6YG(@IM<V=S='(@(L_QZ>;\[?3I[R`G
MX]WLZ?/LX2<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C@Q"FUS9VED(")(;W)I>F]N=&%L.B(*;7-G<W1R("+/\>GF_.WT
MZ>\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C4P"FUS9VED(")(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*2(*;7-G<W1R("+0^?(@]NC<\^'TY2#EY/X[("CPX?'A
MZN'K_B#MX2#T[R#A[>'VW?'E].4@\_3O(.3IX??EZ?'I\_3>(2DB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,U
M"FUS9VED(")(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/R(*;7-G<W1R("+0_//E\B#S]-[KY?(@Z-WKY?3E(.WA(.7M[_#OZ=[S
MY?3E.R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(X"FUS9VED
M(")(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\B"FUS9W-T
M<B`BT/SSX2#PY>3?X2`H\_3>Z^7R*2#EW^WAZ2#EZN7?.R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S8*;7-G
M:60@(DAO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_(@IM
M<V=S='(@(M#\\^7R(./QX>SLW?(@Z-WKY?3E(.WA(.7M[_#OZ=[SY?3E.R(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C(X"FUS9VED(")(=6UI9&ET>2(*
M;7-G<W1R("+5X_'A\]_A(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C(P,PIM<V=I9"`B2'5M:61I='DZ("(*;7-G<W1R("+5X_'A\]_A.B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,0IM<V=I9"`B2'5M;W)I<W1S
M(@IM<V=S='(@(M?I[_7L[_'?\_3A\B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O8WER=7,N<&AP.C$W-B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`Z,C(S"FUS9VED("))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E
M<R(*;7-G<W1R("+'(,3G[.GO]?'CW^$@X_'A[.SA]._H]?'?Y.'R($E-05`@
MX?#=]/7WY3H@)7,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H
M<#HR,C`@9G)A;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(X.`IM<V=I
M9"`B24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,B"FUS9W-T<B`B
MQR#DZ>'C\>'VWB#C\>'L[.'T[^CU\=_DX?(@24U!4"#A\-WT]??E.B`E<R(*
M"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C$X,R!F<F%M97=O
M<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z,C,P"FUS9VED("))34%0(&UA:6QB
M;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("+'(,3G[.GO
M]?'CW^$@\.7I\>_QZ?/L_NT@*'%U;W1A*2#C\>'L[.'T[^CU\=_DX?(@24U!
M4"#A\-WT]??E.B`E<R(*"FUS9VED("))3D)/6"(*;7-G<W1R("+%Z?/E\??\
M[.7MX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S,3$*;7-G:60@
M(DE0($%D9')E<W,B"FUS9W-T<B`B25`MQ.GE_>CU[?/G(@H*(SH@9G)A;65W
M;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX,@IM<V=I9"`B25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("))4"W$Z>7]Z/7M\^<@Y.7M(.7?
M[>'I(.3IX>C=\^GLYRXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S
M:6,N<&AP.CDT"FUS9VED("))4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+B(*;7-G<W1R("))4"W$Z>7]Z/7M\^<@[.<@Y?#I]/'E
M\/3>(.S=\^$@\^4@0TE$4BU";&]C:RXB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*;7-G:60@(DE0(&QO8VMD
M;W=N('9I;VQA=&EO;BXB"FUS9W-T<B`BRNOEW^3Y[.$MT.'QX>+?X?/G($E0
M+B(*"FUS9VED("))7VYB;W@B"FUS9W-T<B`BQ>GSY?'W_.SE[>$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M,CD*;7-G:60@(DE?;G-E<G0@4F]W($)E9F]R92(*;7-G<W1R("+%Z?/AX_GC
MWB##\>'L[-[R(-#QZ>TB"@IM<V=I9"`B26-O;G,@3VYL>2(*;7-G<W1R("+,
M_.WO(,7IZN_MW^3IX2(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HT.0IM
M<V=I9"`B26-O;G,@9F]R("5S(@IM<V=S='(@(L7IZN_MW^3IX2#CZ>$@)7,B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8Q"FUS9VED("))8V]N<R!W
M:71H('1E>'0B"FUS9W-T<B`BQ>GJ[^W?Y.GA(.KAZ2#*Y=_LY>WO(@H*;7-G
M:60@(DED96YT:71Y)W,@;F%M93HB"FUS9W-T<B`BS^WO[.$@].'U]/STY_3A
M\CHB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HV,#@*
M;7-G:60@(DEF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RXB"FUS9W-T<B`BP>T@Y.7M(.7L
M]N'MW^;E].'I(//Y\_3<+"`E<R#CZ>$@[>$@X>WOW^[EZ2#SY2#MW>\@\.'Q
MW.CU\>\N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0S.0IM<V=I9"`B
M(@HB268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@
M17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R`B"B)T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+B(*;7-G<W1R("(B"B+![2#D
MY2#BZ]WPY?3E(.KA[=WMX2#EZ>KO[=_DZ>\@]_'G\^GL[_#OZ?[M].'R(/3O
M[2!);G1E<FYE="!%>'!L;W)E<BP@W_/Y\B`B"B+P\=WPY>D@[>$@]//EZMSQ
MY?3E(.7D_B#CZ>$@[>$@X?#E[>7QX^_P[^G>\^7TY2#TYR#DZ>'VW.WEZ>$@
M4$Y'+B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HQ-3@*;7-G:60@(B(*(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92`B"B)D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"B+!
M[2#BZ]WPY?3E(.'U]/P@].\@[-[M]>SA(/?Y\=_R(.7IZOSMX2P@YR#EZ>K\
M[>$@\._U(.C=Z^7TY2#MX2#JX?3EXMSSY?3E(.3E("(*(NSP[_'EWR#MX2#E
M[/;A[>GSZ.7?(.'P_"#T[^T@8G)O=W-E<B#SX?(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C4*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(X"FUS
M9VED("));6%G92!0<F5V:65W.B(*;7-G<W1R("+0\>_E\.GSZOSPZ?/G(,7I
MZOSMX?(Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHS-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(E523"#%
MZ>K\[>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C,R"FUS9VED("));6%G92!F<F]M(&=A;&QE<GDB
M"FUS9W-T<B`BQ>GJ_.WA(.'P_"!'86QL97)Y(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C,Q"FUS9VED
M("));6%G92!F<F]M(&=A;&QE<GDZ(@IM<V=S='(@(L7IZOSMX2#A\/P@1V%L
M;&5R>3HB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S0X"FUS9VED
M("));6%G92!U<&QO860B"FUS9W-T<B`BP?#O\_3OZ]X@Q>GJ_.WA\B(*"B,Z
M(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,W"FUS9VED("));6%G97,B"FUS9W-T
M<B`BQ>GJ_.WE\B(*"FUS9VED("));7!O<G0B"FUS9W-T<B`BQ>GSX>/YX]XB
M"@IM<V=I9"`B26UP;W)T($5R<F]R.B`B"FUS9W-T<B`BR]SH[_(@ZN'TW"#T
MY^T@Q>GSX>/YX]XZ("(*"B,Z('1E;7!L871E<R]D871A+W1S=FEN9F\N:6YC
M.C$P('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C$P"B,Z('1E;7!L871E
M<R]D871A+V-S=FUA<"YI;F,Z-3<@=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI
M;F,Z,3`*;7-G:60@(DEM<&]R="P@4W1E<"`E9"(*;7-G<W1R("+%Z?/AX_GC
MWBP@PM[LX2`E9"(*"B,@=&5M<&QA=&5S+V1A=&$O9&%T96UA<"YI;F,Z,C`L
M(&,M9F]R;6%T"B,Z('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C(P"FUS
M9VED("));7!O<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BT.7DW^\@\._U(.7I
M\][WZ.<Z("5S(@H*;7-G:60@(DEM<&]R=&5D(&9I96QD<SHB"FUS9W-T<B`B
MT.7DW^$@\._U(.7I\][WZ.?SX>TZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HW,#$*;7-G:60@(DEN(%!R;V-E<W,B
M"FUS9W-T<B`BT^4@Q?#E[N7QX^'SW^$B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@(DEN7W-E
M<G0@4F]W($%F=&5R(@IM<V=S='(@(L7I\^'C^>/>(,/QX>SLWO(@S.7TW"(*
M"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$T,0IM
M<V=I9"`B26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+B(*;7-G<W1R("+$
M_.CGZN4@Z]SH[_(@ZOGDZ>K\\B#E[=WQX^7IX?(N(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-3<*;7-G:60@(DEN
M8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N(@IM<V=S='(@(LO<
MZ._R(/SM[^SA(/?QWO/TYR#>+^KAZ2#J^>3IZOSR+B(*"B,Z('-E<G9I8V5S
M+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"FUS9VED("(B"B));F-O<G)E8W0@=7-E
M<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT
M86-T('EO=7(@(@HB861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N(@IM<V=S='(@(B(*(LO<Z._R(/SM[^SA(/?QWO/TYR#>(.7MX>OK
MX>KTZ>K>(.3IY?WH]>WSYRX@SN'MX>3OZNGLW//TY2#>(.7PZ>KOZ>WY[=[S
M].4@[.4@(@HB].\@Y.GA]^7I\>GS]-X@X^GA(/#E\>'I]-WQ^2#B[][HY>GA
M+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C$*;7-G:60@(DEN8W)E87-E($EN9&5N="(*;7-G<W1R("+!_>[G\^<@T.7Q
MZ>CY\=_O]2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP.C$T,2!T96UP;&%T
M97,O<VAA<F5S+V5D:70N:6YC.C$T,`IM<V=I9"`B26YD:79I9'5A;"!5<V5R
M<R(*;7-G<W1R("+)Y.GAW_3E\>_I(-?QWO/TY?(B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C<R"FUS9VED("));F9O(@IM
M<V=S='(@(M#KY_'O]N_QW^7R(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD
M:7-T.C(T.0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`BT.OG\>_V[_'?
MY?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S
M='(@(L7I\^'C^>/>(-/TWNOG\B#,Y?3<(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(P"FUS9VED("))
M;G-E<G0@26UA9V4B"FUS9W-T<B`BQ>GSX>/YX]X@Q>GJ_.WA\B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C<*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#`*;7-G:60@
M(DEN<V5R="!486)L92(*;7-G<W1R("+%Z?/AX_GCWB#0W^WAZN$B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(U"FUS9VED
M("));G-E<G0@5V5B($QI;FLB"FUS9W-T<B`BQ>GSX>/YX]X@\_WMY.7SY_(@
M5V5B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X
M=%]L86YG+FIS.C,S"FUS9VED("));G-E<G0@7T-O;'5M;B!"969O<F4B"FUS
M9W-T<B`BQ>GSX>/YX]X@T_3>Z^?R(-#QZ>TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN
M<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE(@IM<V=S
M='(@(L7I\^'C^>/>(.W=X?(@\_3>Z^?R(.SE]-P@].?M(/3QW??O]?/A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8T"FUS9VED("));G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4B"FUS9W-T<B`BQ>GSX>/YX]X@[=WA\B#S]-[KY_(@\/'I
M[2#A\/P@].?M(/3QW??O]?/A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Q"FUS9VED("));G-E<G0@82!N
M97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+%Z?/AX_GC
MWB#MW>'R(./QX>SLWO(@[.7TW"#TY^T@]/'=]^_U\^$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C`*;7-G
M:60@(DEN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*
M;7-G<W1R("+%Z?/AX_GCWB#MW>'R(./QX>SLWO(@[.7TW"#TY^T@]/'=]^_U
M\^$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-CD*;7-G:60@(DEN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T
M:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@(L7IX>/YX]X@\.'QX>/QW/;O]2#L
MY?3<(/3O[2#T\=WW[^WTX2#J_.SB[R(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T
M(&$@<&%R86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E(@IM<V=S='(@
M(L7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[2#T[^T@]/'=]^_M].$@ZOSLXN\B
M"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$U,`IM<V=I9"`B26YS97)T(&%L
M=&5R;F%T92!T96UP;&%T92(*;7-G<W1R("+%Z?/AX_GCWB#E[>'KZ^'J].GJ
M[_T@\/'O]/WP[_4B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C(S"FUS
M9VED("));G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N
M(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#HB"FUS9W-T<B`B(@HBQ/[S].4@
M96UA:6P@Y.GE_>CU[?/G(//TY^T@[_#OW^$@Y?#IZ/7LY=_TY2#MX2#PX?'A
MZ]SBY?3E(/3O(.W=[R#SX?(@ZOGDZ>K\.B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3@*;7-G:60@(DEN<V5R
M="!C96QL(&%F=&5R(@IM<V=S='(@(L7I\^'C^>/>(.KEZ^GO_2#LY?3<(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHU.0IM<V=I9"`B26YS97)T(&-E;&P@8F5F;W)E(@IM<V=S='(@(L7I\^'C
M^>/>(.KEZ^GO_2#P\>GM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O;'5M;B!A
M9G1E<B(*;7-G<W1R("+%Z?/AX_GCWB#S]-[KY_(@[.7TW"(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C4*;7-G
M:60@(DEN<V5R="!C;VQU;6X@8F5F;W)E(@IM<V=S='(@(L7I\^'C^>/>(//T
MWNOG\B#P\>GM(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z.3,*;7-G:60@(DEN<V5R="!M97-S86=E<R(*;7-G<W1R("+%Z?/A
MX_GCWB#LY^W][.'T[_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z-#0*;7-G:60@(DEN<V5R="!P87)A9W)A
M<&@@869T97(B"FUS9W-T<B`BQ>GSX>/YX]X@\.'QX>/QW/;O]2#LY?3<(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C0S"FUS9VED("));G-E<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R
M("+%Z?/AX_GCWB#PX?'AX_'<]N_U(/#QZ>TB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Y"FUS9VED("));G-E
M<G0@<F]W(&%F=&5R(@IM<V=S='(@(L7I\^'C^>/>(./QX>SLWO(@[.7TW"(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-C@*;7-G:60@(DEN<V5R="!R;W<@8F5F;W)E(@IM<V=S='(@(L7I\^'C
M^>/>(./QX>SLWO(@\/'I[2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR
M,30*;7-G:60@(DEN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S
M96-U<FET>2!Q=65S=&EO;CHB"FUS9W-T<B`BQ>GSX>/YX]X@].?R(.'PX>GT
M[_WLY>WG\B#A\-SM].?SY_(@\_3G[2#E\?[TY_/G(.'S]N'KY=_A\CHB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS
M9VED("));G-E<G0O36]D:69Y($EM86=E(@IM<V=S='(@(L7I\^'C^>/>+\3I
M_/'H^?/G(,7IZOSMX?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]L86YG+FIS.C@Y"FUS9VED("));G-E<G0O36]D:69Y($QI;FLB"FUS
M9W-T<B`BQ>GSX>/YX]XOQ.G\\>CY\^<@T_WMY.7SY_(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V.`IM<V=I9"`B
M26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I
M;VX@;&ES="XB"FUS9W-T<B`BS.<@Y?#A\>K=\B#U\/SK[^GP[R#CZ>$@X?#O
M\_3OZ]X@\_3G(.O?\_3A(.3IX>WO[-[R+B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8P"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET+B(*;7-G<W1R("+,YR#E\.'QZMWR(/7P_.OOZ?#O+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$P-CD*;7-G:60@(DEN=&5G
M97(B"FUS9W-T<B`BP>K=\>'I[_(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,3(W"FUS9VED("));G1E9V5R(&QI<W0B"FUS9W-T<B`BR]_S].$@
MP>KE\>'?^>TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L
M96YD87(N<&AP.C(X,PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M8V%L96YD87(N<&AP.C,U,@IM<V=I9"`B26YV86QI9"!!8W1I;VX@<V5L96-T
M960@9F]R('1H:7,@8V]M<&]N96YT+B(*;7-G<W1R("+%\.GKW>[A].4@R]SH
M[_(@Q>W=\>/EZ>$@X^DG(.'U]/P@].\@\_7S].'TZ>K\+B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,P-@IM<V=I
M9"`B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2XB"FUS9W-T<B`B
MP>KU\>\@541(+B`H57-E<B!$871A($AE861E<BDN(@H*(SH@861M:6XO<V5T
M=7`O8V]N9FEG+G!H<#HS-`IM<V=I9"`B26YV86QI9"!A<'!L:6-A=&EO;BXB
M"FUS9W-T<B`BS.<@W>/J]?'G(.7VX?'L[^/>+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,0IM<V=I9"`B26YV
M86QI9"!B871C:"!)1"XB"FUS9W-T<B`BP>KU\>\@0F%T8V@M240N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W,"!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,30Q"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,34@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(X,`IM<V=I9"`B26YV86QI9"!D
M871A('-U8FUI='1E9"XB"FUS9W-T<B`BT_3<Z^CGZN'M(.O<Z._R(.3EY._L
MW>WA+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P.0IM<V=I9"`B26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+B(*;7-G<W1R("+!ZO7QYR#DZ>7]Z/7M\^<@\/'O[_'I\^SO_2XB"@HC.B!F
M<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HX-`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O9&)X+G!H<#HQ,#,*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP:'`Z,C(S"FUS9VED("));G9A
M;&ED(&9I;&4@9F]R;6%T(@IM<V=S='(@(LSG(-WCZO7QYR#L[_'VWB#A\??E
MW^_U(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S$V"FUS9VED("));G9A;&ED(&US9U]T>7!E+B(*;7-G<W1R("+,
MYR#=X^KU\>\@;7-G7W1Y<&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3
M+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$R"FUS9VED("));G9A;&ED(&]R(&UI
M<W-I;F<@87!I7VED+B(*;7-G<W1R("+,YR#=X^KU\>\@WB#KY=_PY>D@87!I
M7VED+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C,P-0IM<V=I9"`B26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E
M<G,N(@IM<V=S='(@(LSG(-WCZO7QY?(@WB#EZ^OI\.7?\B#PX?'<[.7T\>_I
M+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HT,PIM<V=I9"`B26YV
M86QI9"!P87)E;G0@<&5R;6ES<VEO;BXB"FUS9W-T<B`B26YV86QI9"!P87)E
M;G0@<&5R;6ES<VEO;BXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN
M(@IM<V=S='(@(LSG(-WCZO7Q[R#P\?GT_.KOZ^OO+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z.3$*;7-G:60@(DEN
M=F%L:60@<F5C:7!I96YT.B`G)7,G(@IM<V=S='(@(LSG(-WCZO7Q[_(@\.'Q
MX>O>\/3G\CH@)R5S)R(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M,3`W,2!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-#@*;7-G:60@(DEN
M=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(LSG(-WCZO7Q[R#J[^GM_/?Q
MY_/T[R#A[?3IZN7?[.7M[R(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C
M;&EC:V%T96QL7VAT='`N<&AP.C,Q,`IM<V=I9"`B26YV86QI9"!S;W5R8V4@
M861D<F5S<RXB"FUS9W-T<B`BS.<@W>/J]?'G(.'Q]^GJWB#DZ>7]Z/7M\^<N
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S(P"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T<B`B
MS.<@W>/J]?'A(.3EY._LW>WA(%5N:6-O9&4N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C,R.`IM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(LKA
M]-SK[^/O\B#5\.'Q]_SM]/GM(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY"FUS9VED("))=&%L:6,B"FUS9W-T<B`BT.OA
MX^GA(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C,W-`HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M-#$Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z
M-C4*;7-G:60@(DIA;G5A<GDB"FUS9W-T<B`BR>'M[_7<\>GO\B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#`*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q-PHC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<Q"FUS9VED(")*
M=6QY(@IM<V=S='(@(LGO_>OI[_(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,S<Y"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,38*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,`IM<V=I9"`B2G5N92(*;7-G<W1R("+)[_WM
MZ>_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS.`IM<V=I9"`B2G5S=&EF>2(*;7-G<W1R("+%]>CUX_'<[.SI
M\^<B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S<*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B"FUS9W-T<B`BQ?7H
M]>/QW.SLZ?/G(//T[R#*W>WT\>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,SD*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(M#KWO'G\B#%]>CUX_'<[.SI\^<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S8*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-`IM<V=I
M9"`B2G5S=&EF>2!,969T(@IM<V=S='(@(L7UZ/7C\=SL[.GSYR#!\>GS].7Q
MW"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHS.`HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$V"FUS9VED(")*=7-T:69Y(%)I9VAT(@IM<V=S='(@(L7UZ/7C
M\=SL[.GSYR#$Y>[IW"(*"FUS9VED(")+86QA;6%T82!!:7)P;W)T(@IM<V=S
M='(@(L'E\>_KZ>S=[>'R(,KAZ^'LW/3A\B(*"FUS9VED(")+87)P871H;W,@
M06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#*X?'PW.CO]2(*"FUS9VED
M(")+87-T;W)I82!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KA\_3O
M\>G<\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR-#8*;7-G:60@(DME97`@;W)I9VEN86P_(@IM<V=S='(@(LWA(.KQX?3>
M\_D@].\@X?7HY>WTZ>K\.R(*"FUS9VED(")+969A;&AN:6$@06ER<&]R="(*
M;7-G<W1R("+!Y?'OZ^GLW>WA\B#*Y?;AZ^_MZ=SR(@H*(SH@9G)A;65W;W)K
M+T%U=&@O075T:"]K<F(U+G!H<#HX-PIM<V=I9"`B2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")+97)B97)O<RU3
M97)V97(@X?'MWNCGZN4@].?M(.'UZ.7M].GJ[_#OW^?SYRXB"@IM<V=I9"`B
M2V5R:WER82!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,K=\>KU\>'R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0R"FUS9VED(")+97)N96P@
M3F5W8FEE<R(*;7-G<W1R("+-W>$@X?#\($ME<FYE;"(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C,Y-PIM<V=I9"`B2V5Y($-R96%T:6]N
M(@IM<V=S='(@(L3G[.GO]?'CW^$@RNOEZ>3I[_TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,#`*;7-G:60@(DME>2!&:6YG97)P<FEN
M="(*;7-G<W1R("+!\._T_?#Y[.$@RNOEZ>3I[_TB"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HS.3@*;7-G:60@(DME>2!,96YG=&@B"FUS
M9W-T<B`BS-[J[_(@RNOEZ>3I[_TB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HS.3<*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@(M3]\._R
M(,KKY>GDZ>_](@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HV,C(*;7-G:60@(DME>2!5<V%G92(*;7-G<W1R("+7\=[SYR#*Z^7IY.GO
M_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C<T,PIM<V=I
M9"`B2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+B(*;7-G<W1R("+4[R#JZ^7IY-\@]?#<\??EZ2#>Y.<@\_3O[2#E[O7PY_'E
M].?TWB#DY^S\\^GY[2#JZ^7IY.G^[2XB"@HC.B!L:6(O0FQO8VLO9F]R='5N
M92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`BT.'IY.G<(@H*;7-G:60@
M(DMO<R!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KY(@H*;7-G:60@
M(DMO>F%N:2!!:7)P;W)T(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,KOYMSMY_(B
M"@HC.B!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C@*;7-G:60@(DQA7WEO
M=70B"FUS9W-T<B`BQ.G<].'NYR(*"FUS9VED("),87)I<V$@06ER<&]R="(*
M;7-G<W1R("+!Y?'OZ^GLW>WA\B#+W/'I\^'R(@H*(SH@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-`IM<V=I9"`B3&%S="!(86QF(@IM<V=S='(@(M3EZ^7U].'?
M[R#,Z?/\(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C@X(&QI8B]";&]C:R]M
M;V]N+G!H<#HY,`IM<V=I9"`B3&%S="!1=6%R=&5R(@IM<V=S='(@(M3EZ^7U
M].'?[R#4W?3A\?3O(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-#D*;7-G
M:60@(DQA<W0@57!D871E9#HB"FUS9W-T<B`BU.7KY?7TX=_A(,7MY^S=\?GS
MYSHB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HV.3$*;7-G:60@(DQA
M<W0@;&]G:6XZ("5S(@IM<V=S='(@(M3EZ^7U].'?X2#%W_/OY._R(//TY^T@
M]?#G\>7SW^$Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z-CDS
M"FUS9VED("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(M3EZ^7U
M].'?X2#%W_/OY._R(//TY^T@]?#G\>7SW^$Z("5S(.'P_"`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C8X.`IM<V=I9"`B3&%S="!L;V=I;CH@
M3F5V97(B"FUS9W-T<B`BU.7KY?7TX=_A(,7?\^_D[_(@\_3G[2#U\.?QY?/?
MX3H@T._TW2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-`IM<V=I9"`B
M3&%W(@IM<V=S='(@(LW\[._R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED("),87EO=70B"FUS9W-T
M<B`BQ.G<].'NYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z.#8*;7-G:60@(DQE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(B
M"FUS9W-T<B`BP?;>\_3E(.KE[?P@X^GA(.WA(.SG[2#U\-SQ]^_U[2#PY?'I
MZ/[QZ>$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T<B`BP?'I\_3E\=PB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3`S"FUS9VED("),969T(&AE
M861E<B(*;7-G<W1R("+!\>GS].7QWB#%\.GJY?;AZ]_DX2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,P.3D*;7-G:60@(DQE9G0@=F%L=65S(@IM
M<V=S='(@(L'QZ?/TY?'=\B#4Z>S=\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE
M+G!H<#HT-0IM<V=I9"`B3&EM97)I8VLB"FUS9W-T<B`BT.7M]-SS].GW[R(*
M"FUS9VED("),:6UN;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#+
MWNSM[_4B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#`Q"FUS9VED
M("),:6YK(@IM<V=S='(@(M/][>3E\^<B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-38*;7-G:60@(DQI;FL@
M<&]I;G1S('1O.B(*;7-G<W1R("+3_>WDY?/G(/#O]2#DY=_W[>7I(//E.B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3@*;7-G:60@(DQI;FL@
M=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I
M<W!L87EI;F<B"FUS9W-T<B`BT_WMY.7SYR#TY_(@Y.GE_>CU[?/G(./IX2#<
M[>_IX^SA(/#A\>'H_?'O]2#S_>WHY?/G\CLB"@HC.B!F<F%M97=O<FLO5&5X
M=%]&:6QT97(O1FEL=&5R+VAT;6PR=&5X="YP:'`Z,38R"FUS9VED("),:6YK
M<R(*;7-G<W1R("+3]>WDW?/EZ?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#8*;7-G:60@(DQI;G5X($-O;VMI92(*;7-G<W1R("),:6YU>"U#;V]K
M:64B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HX
M.0IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R(@IM<V=S
M='(@(DQI<W0@+2#/(/?QWO/TY_(@[/#O\>7?(.WA(.3EWR#T[R#VW.KEZ^\B
M"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3,X"FUS9VED("),:7-T($1A=&%B
M87-E<R(*;7-G<W1R("++W_/TX2#"W//E^>T@Q.7D[^S=[?GM(@H*(SH@<V5R
M=FEC97,O:&5L<"]I;F1E>"YP:'`Z-3`*;7-G:60@(DQI<W0@2&5L<"!4;W!I
M8W,B"FUS9W-T<B`BR]_S].$@Z.7LW/3Y[2#"[][HY>GA\B(*"B,Z(&%D;6EN
M+W-Q;'-H96QL+G!H<#HQ,S<*;7-G:60@(DQI<W0@5&%B;&5S(@IM<V=S='(@
M(LO?\_3A(-#I[=SJ^>TB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]N;VQI
M<W0N:6YC.C0*;7-G:60@(DQI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM
M<V=S='(@(L<@Y.?LZ>_U\>/?X2#KW_/TX?(@]_'G\_3^[2#=]^7I(.'PY>WE
M\>/O\._IY^CEWRXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I
M;6%G97,N<&AP.C@V"FUS9VED("),;V%D:6YG+BXN(@IM<V=S='(@(M;\\?3Y
M\^<N+BXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38P"FUS
M9VED("),;V-A;"!T:6UE.B`B"FUS9W-T<B`BU._PZ>K>(+_QX3H@(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),;V-A;&4@86YD(%1I
M;64B"FUS9W-T<B`BU/SP[_(@ZN'I(/[QX2(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DU"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3<P(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M+G!H<#HU,`HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,C(@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HV,PIM<V=I9"`B3&]C871I;VXB"FUS9W-T<B`BU/SP
M[^CE\]_A(@H*;7-G:60@(DQO9R!I;B(*;7-G<W1R("+%W_/OY._R(@H*;7-G
M:60@(DQO9R!O=70B"FUS9W-T<B`BN.[OY._R(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C$P-PIM<V=I9"`B3&]G:6X@5&%S:W,B"FUS9W-T<B`BQ.GE
M\>/A\]_E\B#EZ?/\Y._U(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z
M.34R"FUS9VED("(B"B),;V=I;B!F86EL960@9F]R('-O;64@<F5A<V]N+B!-
M;W-T(&QI:V5L>2!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R`B"B)E
M;G1E<F5D(&EN8V]R<F5C=&QY+B(*;7-G<W1R("(B"B+'(.7?\^_D[_(@P?#=
M]/7WY2X@T.GHX>W\].'TX2#D_.CGZN4@Z]SH[_(@].\@O.WO[.$@U_'>\_3G
M(-X@[R#*^>3IZOSR+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDT
M.`IM<V=I9"`B3&]G:6X@9F%I;&5D+B(*;7-G<W1R("+%W_/OY._R(,'PW?3U
M]^4N(@H*;7-G:60@(DQO9V]U="(*;7-G<W1R("*X[N_D[_(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8Q"FUS9VED("),;VYG('1E>'0B"FUS
M9W-T<B`BS.7CW.OO(,KEW^SE[>\B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#@*;7-G:60@(DQO=F4B"FUS9W-T<B`BP>/<\.<B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S4Y"FUS9VED("),;W<B"FUS9W-T<B`B
MU^'LY^O\(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES
M='1Y<&5?;&%N9RYJ<SHR,0IM<V=I9"`B3&]W97(@9W)E96L@;&5T=&5R<R(*
M;7-G<W1R("+,Z>KQW"#%Z^OG[>GJW"#C\=SL[.'TX2(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3D*;7-G
M:60@(DQO=V5R(&QA=&EN(&QE='1E<G,B"FUS9W-T<B`BS.GJ\=P@Z^'TZ>WI
MZMP@X_'<[.SA].$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C$W"FUS9VED("),;W=E<B!R;VUA;B!N=6UB
M97)S(@IM<V=S='(@(LSIZO'<(-'Y[.'ZZMX@P?'?Z.SG\^<B"@IM<V=I9"`B
M34TB"FUS9W-T<B`BS,PB"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-#D*
M;7-G:60@(DUA9VEC(@IM<V=S='(@(LSAX^GJ_"(*"B,Z(&-O;F9I9R]R96=I
M<W1R>2YP:'`N9&ES=#HW,0IM<V=I9"`B36%I;"(*;7-G<W1R("+!Z^OGZ^_C
M\>'VW^$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3$T"FUS9VED
M(")-86EL($%D;6EN(@IM<V=S='(@(L3IX??EW_'I\^<@16UA:6PB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-#`*;7-G:60@(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`BQ.?LZ>_U\>/?X2#3
M_>WDY?/G\BXN+B(*"FUS9VED("(B"B)-86YA9V4@=&AE(&QI<W0@;V8@8V%T
M96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L
M;W)S("(*(F%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+B(*;7-G
M<W1R("+$Z>'WY=_QZ?/G(.KA].?C[_'I_NT@ZN'I(/?Q^>S<]/GM(/#O]2#H
MX2#E[/;A[=_F[^WTX>D@X?7TW?(N(@H*;7-G:60@(DUA;G5A;"(*;7-G<W1R
M("+%X_?EZ?'?Y.GO(@H*;7-G:60@(DUA<"!$871E(&%N9"!4:6UE($9I96QD
M<R(*;7-G<W1R("+0Y>3?X2#'[.7Q[^SG[=_A\B#JX>D@O_'A\B(*"FUS9VED
M(")-87`@26UP;W)T($9I96QD<R(*;7-G<W1R("+0Y>3?X2#EZ?/AX_GCWO(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,S<V
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,3,*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV-PIM
M<V=I9"`B36%R8V@B"FUS9W-T<B`BS-SQ].GO\B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-#$*;7-G:60@(DUA
M<F=I;B(*;7-G<W1R("*\\>GO(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z.3$*;7-G:60@(DUA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<R(*;7-G<W1R("+,X?'JW/'I\^SA(.SE(-WMY.7I[N<@P>WAX^WY
M\^S=[>_U+\SG(.'MX>/M^?/LW>WO]2(*"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.CDR"FUS9VED(")-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*2(*;7-G<W1R("+,X?'J
MW/'I\^SA(.SE(-SKZ^<@W>WDY>GNYR`H\"[W+B#3Y^SA[?3IZOPOP?#A[?3G
M[-WM[RDB"@IM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM<V=S='(@(M#EY-_A
M(/#O]2#TX>GQZ=SF[_7M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S(T"FUS9VED(")-87@@86QL;W=E9"!C<F5D
M:70N(@IM<V=S='(@(LS=X^GS].<@Y?#I]/'E\/3>(/#?\_3Y\^<N(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$W
M"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B
MU?#=\>+A\^<@[_'?[_4@[.?M_>SA]._R+B(*"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,S`T"FUS9VED(")-87@@=&5M<"!L87-T(#(T(&AO=7)S.B`B"FUS
M9W-T<B`BS-WCZ?/TYR#HY?'L[^KQX?/?X2#TY>OE]?3AW_GM(#(T(/GQ_NTZ
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,CDV"FUS9VED(")-87@@=&5M
M<"!L87-T(#8@:&]U<G,Z("(*;7-G<W1R("+,W>/I\_3G(.CE\>SOZO'A\]_A
M(/3EZ^7U].'?^>T@-B#Y\?[M.B`B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HX.3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,P"FUS9VED(")-87AI;75M(&QE;F=T
M:"(*;7-G<W1R("+,W>/I\_3O(.S>ZN_R(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C,W.`HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$U"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+V]P96Y?8V%L96YD87(N:G,Z-CD*;7-G:60@(DUA>2(*;7-G<W1R("+,
MW.GO\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A
M<BYP:'`Z-3,Q"FUS9VED(")-965T:6YG($-A;F-E;&QA=&EO;B(*;7-G<W1R
M("+!ZOWQ^?/G(-/U[=SM].?SY_(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4P,PIM<V=I9"`B365E=&EN9R!);F9O
M<FUA=&EO;B(*;7-G<W1R("+0Z^?Q[_;O\=_E\B#3]>W<[?3G\^?R(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU,#D*
M;7-G:60@(DUE971I;F<@4')O<&]S86PB"FUS9W-T<B`BT/'\].'SYR#CZ>$@
MT_7MW.WTY_/G(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A
M;&5N9&%R+G!H<#HU,C4*;7-G:60@(DUE971I;F<@4F5P;'DB"FUS9W-T<B`B
MP?#<[?3G\^<@X^GA(-/U[=SM].?SYR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$T"FUS9VED(")-965T:6YG(%5P
M9&%T92(*;7-G<W1R("+%[>?LW?'Y\^<@X^GA(-/U[=SM].?SYR(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z-3$Y"FUS
M9VED(")-965T:6YG(%5P9&%T92!297%U97-T(@IM<V=S='(@(L'?].?LX2#E
M[>?LW?'Y\^?R(./IX2#3]>W<[?3G\^<B"@HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V5D:70N:6YC.C$Y"FUS9VED(")-96UB97)S(@IM<V=S='(@(LS=
MZ^<B"@IM<V=I9"`B365M;W,B"FUS9W-T<B`BT^?LY>G^\^7I\B(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C(*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`BRN'TW//TX?/G(,SE[>_].B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C`*;7-G:60@(DUE<F=E(&-E
M;&QS(@IM<V=S='(@(M/UX_?^[>7U\^<@ZN7KZ?[M(@H*(SH@9G)A;65W;W)K
M+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H
M<#HS,@IM<V=I9"`B365S<V%G92(*;7-G<W1R("+,WNWU[.$B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C(R-@IM<V=I9"`B(@HB365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@(@HB=F5R:69I960N(@IM<V=S='(@
M(B(*(M3O(.S>[?7LX2#E\.GBY>+AZ?[HY^KE(.7PZ?3U]_[R+"#AZ^O<(/3O
M(/#I\_3O\._IY_3IZOP@]._U(/7P[^/QW/;O[?3A(.3E("(*(NSP[_'EWR#M
MX2#E\.GBY>+AZ?GHY=\N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,S$Y"FUS9VED(")-97-S86=E(&5X<&ER960N
M(@IM<V=S='(@(M3O(.S>[?7LX2#=Z^?NY2XB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y,0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8R-@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,S,*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8X"FUS
M9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`BU/WP[_(@[.?M_>SA]._R(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HS"FUS9VED(")-971A<B!796%T:&5R
M(@IM<V=S='(@(LKAZ?'\\B#A\/P@365T87(B"@HC.B!L:6(O0FQO8VLO;65T
M87(N<&AP.C,W"FUS9VED(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*
M;7-G<W1R(")-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,3$P"FUS9VED("(B"B)-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"B)-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A
M<BYP:'`Z-S`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW
M-`IM<V=I9"`B365T:&]D(@IM<V=S='(@(LS=Z._D[_(B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00R]X;6QR<&,N<&AP.C@R(&9R86UE=V]R:R]24$,O4E!#+W-O
M87`N<&AP.C$Q-PIM<V=I9"`B365T:&]D("<E<R<@:7,@;F]T(&1E9FEN960B
M"FUS9W-T<B`BQR#,W>COY._R("<E<R<@Y.7M(._QW_/HY^KE(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C4Y(&QI8B]";&]C:R]M971A<BYP
M:'`Z-S,*;7-G:60@(DUE=')I8R(*;7-G<W1R("+,Y?3QZ>K\(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<V"FUS
M9VED(")-:61D;&4B"FUS9W-T<B`BS.7SX=_O(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O=&YE9BYP:'`Z-#$*;7-G:60@(DUI;64@5'EP92(*
M;7-G<W1R(")-:6UE(%1Y<&4B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P
M.`IM<V=I9"`B36EN('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(LSI
MZO'\].7QYR#HY?'L[^KQX?/?X2#TY>OE]?3AW_GM(#(T(/GQ_NTZ("(*"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S`P"FUS9VED(")-:6X@=&5M<"!L87-T
M(#8@:&]U<G,Z("(*;7-G<W1R("+,Z>KQ_/3E\><@Z.7Q[._J\>'SW^$@].7K
MY?7TX=_Y[2`V(/GQ_NTZ("(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HR,3<*;7-G:60@(DUI<G)O<B(*;7-G<W1R("+*X>CQ
MW?#TY_(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI
M<V-E;&QA;F5O=7,B"FUS9W-T<B`BQ.G<]N_QX2(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-CDW"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,T.0IM<V=I9"`B
M36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+B(*;7-G<W1R(")-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$P-0IM<V=I9"`B(@HB36ES<VEN9R!C;VYF:6=U
M<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A
M;G0@=&\@=7-E('1H:7,@(@HB87!P;&EC871I;VXN(@IM<V=S='(@(B(*(LOE
MW_#EZ2#T[R!C;VYF:6=U<F%T:6]N+B#0\=WPY>D@[>$@].\@Y.?LZ>_U\>/>
M\^7TY2#A[2#HW>OE].4@[>$@]_'G\^DM(@HB[._P[^G>\^7TY2#A]?3>(/3G
M[2#E]N'Q[._CWBXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HS,3,*;7-G:60@(DUI<W-I;F<@;65S<V%G92!)1"XB
M"FUS9W-T<B`BR^7?\.7I(/3O($E$(/3O]2#LY^W][.'T[_(N(@H*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT<"YP:'`Z-3<*
M;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@IM
M<V=S='(@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`S"FUS9VED(")-:7-S:6YG('-E<W-I;VX@240N(@IM<V=S='(@(LOEW_#E
MZ2#T[R!)1"#TY_(@\_WMY.7SY_(N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O;W!E;E]C86QE;F1A<BYJ<SHU-@IM<V=I9"`B36\B"FUS9W-T<B`BQ.4B
M"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(R"FUS9VED(")-;V)I
M;&4@36%I;"(*;7-G<W1R(")%;6%I;"#*Z>WG]-[R(-3GZ^7V^>W?X?(B"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8P"FUS9VED(")-;V1E
M<F%T92(*;7-G<W1R("+,W?3QZ>_R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HV.2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C<S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#@*;7-G:60@(DUO9&EF:65D($1A=&4B"FUS9W-T<B`BQ^SE\>_L
MY^W?X2#T\>_P[_#OW^?SY_(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3(*;7-G:60@(DUO9&EF>2!54DPB
M"FUS9W-T<B`BU/'O\._P[]_G\^<@55),(@H*;7-G:60@(DUO;G1H(%9I97<B
M"FUS9W-T<B`BQ>SVW.WI\^<@S-[MX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(U.#8*;7-G:60@(DUO;G1H(&%N9"!Y96%R(@IM<V=S='(@(LS>
M[>'R(.KAZ2#=]._R(@H*;7-G:60@(DUO;G1H;'D@179E;G1S($QI<W0B"FUS
M9W-T<B`BS.?MZ>'?X2#+W_/TX2##Y>/O[?ST^>TB"@HC.B!F<F%M97=O<FLO
M36%I;G1E;F%N8V4O36%I;G1E;F%N8V4N<&AP.C,V"FUS9VED(")-;VYT:&QY
M(@IM<V=S='(@(LSG[>GAW^$B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,R!L
M:6(O0FQO8VLO;6]O;BYP:'`Z,38*;7-G:60@(DUO;VX@4&AA<V5S(@IM<V=S
M='(@(M;<\^7I\B#3Y>O>[>?R(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K
M+TQA>6]U="YP:'`Z-#(P"FUS9VED(")-;W9E($1O=VXB"FUS9W-T<B`BRM_M
MY_/G(.K<]/DB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H
M<#HT,C0*;7-G:60@(DUO=F4@3&5F="(*;7-G<W1R("+*W^WG\^<@X?'I\_3E
M\=PB"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT,C@*
M;7-G:60@(DUO=F4@4FEG:'0B"FUS9W-T<B`BRM_MY_/G(.3E[NG<(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-#$V"FUS9VED(")-
M;W9E(%5P(@IM<V=S='(@(LK?[>?SYR#PW.WY(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-PIM<V=I9"`B36]V92!D;W=N
M(@IM<V=S='(@(LK?[>?SYR#JW/3Y(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Y-@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#DW"FUS9VED(")-;W9E('5P(@IM<V=S='(@
M(LK?[>?SYR#PW.WY(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$V
M-PIM<V=I9"`B375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S(@IM<V=S='(@
M(M#OZ^OA\.O=\B#KW_/TY?(@Y?#IZ^_CWO(@*.KA].'Q\=SJ].7R*2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,C4*;7-G:60@(DUU;'1I<&QE
M('-E;&5C=&EO;B(*;7-G<W1R("+0[^OKX?#KWB#E\.GK[^/>(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,S-"!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0Q"FUS9VED(")->2!!8V-O=6YT(@IM<V=S='(@(L\@R^_CX?'I
MX?/L_/(@[._U(@H*(SH@<V5R=FEC97,O<&]R=&%L+VEN9&5X+G!H<#HU,0IM
M<V=I9"`B37D@4&]R=&%L(@IM<V=S='(@(L\@Z?/T_/3O\/SR(.SO]2`H<&]R
M=&%L*2(*"B,Z('-E<G9I8V5S+W!O<G1A;"]E9&ET+G!H<#HQ,C0*;7-G:60@
M(DUY(%!O<G1A;"!,87EO=70B"FUS9W-T<B`BQR#E[/;<[>GSYR#T[_4@Z?/T
M_/3O\._](.SO]2`H<&]R=&%L*2(*"FUS9VED(")->2!3=6UM87)Y(@IM<V=S
M='(@(L<@T.7QW^OG^.<@[._U.B(*"FUS9VED(")->71I;&EN:2!!:7)P;W)T
M(@IM<V=S='(@(L'E\>_KZ>S=[>'R(,SU].?KWNWG\B(*"B,Z('1E;7!L871E
M<R]M86EN=&5N86YC92]A9W)E96UE;G1?8F]T=&]M+FEN8SHW"FUS9VED(").
M3RP@22!$;R!.3U0@06=R964B"FUS9W-T<B`BS]?)+"#$Q2#S]>SV^>W^(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,SDW(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ,#4*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=&YE9BYP:'`Z-#$*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.#,*;7-G:60@(DYA;64B
M"FUS9W-T<B`BO.WO[.$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C<P-@IM<V=I9"`B3F5E9',@06-T:6]N(@IM<V=S
M='(@(L'PX>GTY=_TX>D@Y>W=\>/EZ>$B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C0R"FUS9VED(").971W;W)K(@IM<V=S='(@(L3?ZO3U[R(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,2!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,S$Y"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS
M-S`*;7-G:60@(DYE=F5R(@IM<V=S='(@(M#O]-TB"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU,0HC.B!T96UP;&%T
M97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHR-PIM<V=I9"`B3F5W
M($-A=&5G;W)Y(@IM<V=S='(@(LW=X2#*X?3GX^_QW^$B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z-#8@;&EB+T)L;V-K+VUO;VXN<&AP.C8X(&QI8B]";&]C
M:R]M;V]N+G!H<#HQ-SD*;7-G:60@(DYE=R!-;V]N(@IM<V=S='(@(LW=X2#3
MY>O>[><B"@IM<V=I9"`B3F5W(%!A<W-W;W)D(@IM<V=S='(@(LW=[_(@ROGD
MZ>K\\B(*"FUS9VED(").97<@4&%S<W=O<F0@*&%G86EN*2(*;7-G<W1R("+-
MW>_R(,KYY.GJ_/(@*.[A[=PI(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M=7!D871E+FEN8SHS-0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB
M"FUS9W-T<B`BS=WO(/SM[^SA(-?QWO/TYR`H\/'OX>GQY?3IZOPI(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY,0IM<V=I
M9"`B3F5W('=I;F1O=R`H7V)L86YK*2(*;7-G<W1R("+-W>\@\.'QW.CU\>\@
M*.KE[?PI(@H*(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z-#`@;&EB+T)L;V-K
M+V9O<G1U;F4N<&AP.C4R"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-C0*;7-G:60@(DYE=W,B"FUS9W-T<B`BS=WA(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C$P-@IM<V=I9"`B3F5W<V=R;W5P<R(*;7-G<W1R("+/
M[-SDY?(@X^GA(.W=X2`H;F5W<V=R;W5P<RDB"@HC.B!T96UP;&%T97,O9&%T
M82]T<W9I;F9O+FEN8SHR,2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT
M-@HC.B!T96UP;&%T97,O9&%T82]C<W9M87`N:6YC.C$S-R!T96UP;&%T97,O
M9&%T82]C<W9I;F9O+FEN8SHS,@IM<V=I9"`B3F5X="(*;7-G<W1R("+%\/SL
MY>WO(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,34@9G)A;65W
M;W)K+U5)+U5)+U!A9V5R+G!H<#HQ,38*;7-G:60@(DYE>'0@4&%G92(*;7-G
M<W1R("+%\/SLY>WG(-/EZ]_DX2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR
M-PIM<V=I9"`B3F5X="!0:&%S92(*;7-G<W1R("+%\/SLY>WG(-;<\^<B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C,V-B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O54DN<&AP.C,W,`IM<V=I9"`B3F5X="!O<'1I;VYS(@IM
M<V=S='(@(L7P_.SE[>7R(,7PZ>OOX]WR(@H*(SH@9G)A;65W;W)K+U5)+U5)
M+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@X.`IM<V=I9"`B3F\B"FUS9W-T<B`B
MS_?I(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HQ-@IM
M<V=I9"`B3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BXB"FUS9W-T<B`BQ.7M(/7PW/'WY>D@Y.GAZ-WS
MZ>SO(&-O;F9I9W5R871I;VX@X^GA(.WA(.3EW^[Y(.3IX?;O\=WR+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP:'`Z,3$Q"FUS
M9VED(").;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA
M9V5S+B(*;7-G<W1R("+$Y>T@]?#<\??EZ2#DZ>'HW?/I[.<@\_3QX?3GX^GJ
MWB#CZ>$@Y.?LZ>_U\>/?X2!)4T\@:6UA9V5S+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C,R,@IM<V=I9"`B3F\@
M8F%T8V@@=&5M<&QA=&4N(@IM<V=S='(@(L3E[2#U\-SQ]^7I(/#Q_/3U\.\@
MX^GA($)A=&-H+B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C<X(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C(R-`HC
M.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HR-#8*;7-G:60@
M(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N(@IM
M<V=S='(@(L3E[2#U\-SQ]^7I($)L;V-K(//TY^T@X>GT[_WLY>WG(.C=\^<B
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VUC86PN<&AP.C4T"FUS9VED(").
M;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T
M:6]N+B(*;7-G<W1R("+$Y2#D_.CGZN4@_.WO[.$@X^GA(.'UZ.7M].GJ[_#O
MW^?SYR!-0T%,+B(*"B,Z(&%D;6EN+W-E='5P+V1I9F8N<&AP.C4U"FUS9VED
M(").;R!C:&%N9V4N(@IM<V=S='(@(L3E[2#U\-SQ]^_U[2#AZ^OAX]WR+B(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30T"FUS9VED(").
M;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@=&\@8F4@861D960@8F5L;W<@=&AI
M<R!L979E;"XB"FUS9W-T<B`BQ.4@[/#O\>_][2#MX2#P\>_S].7H[_WM(.7N
M[_7SZ>_D[_3>\^7I\B#JW/3Y(.'P)R#A]?3\(/3O(.7PW_#EY.\N(@H*(SH@
M861M:6XO<&5R;7,O861D8VAI;&0N<&AP.C8Q"FUS9VED(").;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("+$
MY>T@[/#O\>_][2#MX2#P\>_S].7H[_WM(/7P[^KA].?C[_'?Y?(@\^4@X?7T
MWB#TY^T@Y>[O]?/I[^3\].?SYRXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R
M9&4N<&AP.C$W,R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C0Y,PHC.B!F
M<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-3,*;7-G:60@(DYO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B
MQ.7M(._QW_/HY^KA[2#PZ^?Q[_;O\=_E\B#Q]>CLW_/E^>T@X^GA("5S+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S<S"FUS9VED(").;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&
M4RXB"FUS9W-T<B`BQ.7M(._QW_/HY^KA[2#PZ^?Q[_;O\=_E\B#Q]>CLW_/E
M^>T@X^GA($944"!61E,N(@H*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!,1$%0(%!R969E<F5N8V5S+B(*;7-G
M<W1R("+$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2#T
MY^T@]?#G\>7SW^$@RN'TX>O\X^_U+B(*"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,($-A=&5G;W)I97,N
M(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@
MX^GA(/3I\B#JX?3GX^_QW^7R(/3G\B!344PN(@H*;7-G:60@(DYO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@4')E9F5R
M96YC97,N(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V
M[_'?Y?(@X^GA(/3I\B#P\>_TZ>S>\^7I\B#TY_(@4U%,+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;"YP:'`Z-3DU"FUS9VED(").;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RXB"FUS9W-T
M<B`BQ.7M(-WW[_7M(/'UZ.SI\_3EWR#OZ2#PZ^?Q[_;O\=_E\B#CZ>$@4U%,
M(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S0Y
M"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R("+$Y>T@W??O]>T@\?7H[.GS
M].7?(._I(/#KY_'O]N_QW^7R(./IX2!344PM1FEL92!61E,N(@H*;7-G:60@
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@875T:&5N=&EC871I;VXN(@IM<V=S='(@(L3E[2#=]^_U[2#Q]>CLZ?/T
MY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3G[2#A]>CE[?3IZN_P[]_G\^<@\_3G
M[2!344PN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S(S"FUS9VED(").;R!C<F5D:70@;&5F="XB"FUS9W-T<B`B
MQ.7M(-WLY>GMY2#PW_/T^?/G+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C4Y"FUS9VED(").;R!D97-T:6YA=&EO
M;B!S=7!P;&EE9"XB"FUS9W-T<B`BQ.4@Y/[SX?3E(/#Q[^_QZ?/L_"XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3(*;7-G:60@(DYO
M(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BQ.4@]N_Q]/[HY^KA[2#A\??EW^$B
M"@HC.B!U=&EL+VEC;VY?8G)O=W-E<BYP:'`Z-S$*;7-G:60@(DYO(&EC;VYS
M(&9O=6YD+B(*;7-G<W1R("+$Y2#B\=WHY^KA[2#EZ>KO[=_DZ>$N(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$P,B!L:6(O0FQO8VLO<W5N
M<FES92YP:'`Z-#`*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,C$*;7-G:60@
M(DYO(&QO8V%T:6]N(&ES('-E="XB"FUS9W-T<B`BQ.7M(._QW_/HY^KE(/3O
M\._HY?/?X2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C8U.`IM<V=I9"`B3F\@;65S<V%G92!S=7!P;&EE9"XB"FUS
M9W-T<B`BQ.4@Y/[SX?3E(.S>[?7LX2XB"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V,0IM<V=I9"`B3F\@;F%M92!S
M<&5C:69I960N(@IM<V=S='(@(L3E[2#O\=_SZ.?JY2#\[>_LX2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V,@IM
M<V=I9"`B3F\@;G5M8F5R('-P96-I9FEE9"XB"FUS9W-T<B`BQ.7M(._QW_/H
MY^KE(.'QZ>CL_/(N(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDT"FUS
M9VED(").;R!O9F9E;G-I=F4@9F]R='5N97,B"FUS9W-T<B`BQ.7M(/7PW/'W
M[_7M(.3U\]SQY?/TY?(@\/'OXNO=^.7I\B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]U<V5R+V%P<')O=F4N:6YC.C$Y"FUS9VED(").;R!P96YD:6YG('-I9VYU
M<',N(@IM<V=S='(@(L3E[2#EZNKQY>SO_>T@Y=_S[^3OZ2XB"@IM<V=I9"`B
M3F\@<')E9F5R96YC97,@87)E(&%V86EL86)L92XB"FUS9W-T<B`BS^D@\/'O
M].GLWO/EZ?(@Y.7M(.7?[>'I(.3IX>C=\^GLY?(N(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PIM<V=I9"`B
M3F\@<G5L97,B"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(.KA[?SMY?(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0T
M"FUS9VED(").;R!S:61E<R(*;7-G<W1R("+$Y>T@]?#<\??O]>T@\.OE]?'=
M\B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,3(*;7-G:60@
M(DYO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92XB
M"FUS9W-T<B`BQ.7M(/7PW/'WY>D@\/'O\_GQZ>W\\B#W_O'O\B#CZ>$@[.W>
M[.<@8V%C:&4N(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HV-38*;7-G:60@(DYO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+B(*;7-G<W1R("+$Y>T@Y/SHY^KE(/SM[^SA(/?QWO/TYR#>
M+^KAZ2#J^>3IZOSR+B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP
M:'`Z,30Q"FUS9VED(").;R!V86QI9"!834P@9&%T82!R971U<FYE9"(*;7-G
M<W1R("+$Y>T@Y?#I\_3QW/;GZN'M(-WCX_7QX2!834P@Y.7D[^S=[>$B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DV"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY,#8*(SH@
M9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDQ-PHC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3,T"FUS9VED
M(").;R!V86QU97,B"FUS9W-T<B`BQ.7M(/7PW/'W[_7M(/3I[-WR(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$Q,`IM<V=I9"`B3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(L3E(.+QW>CGZN4@W>KD[_/G(//T[R#A
M\??IZOP@8V]N9FEG=7)A=&EO;BX@SN'MX>3G[.GO]?'CWO/TY2#T[RXB"@HC
M.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3$X"FUS9VED(").;R!V97)S:6]N
M(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+$Y2#B\=WHY^KE(-WJY._SYR#S].\@X?'W
MZ>K\(//A\B!C;VYF:6=U<F%T:6]N+B#.X>WAY.?LZ>_U\>/>\_3E(/3O+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-C`T"FUS9VED(").;VX@4&%R=&EC:7!A;G0B"FUS9W-T<B`BRN'MW>WA\B#3
M]>SLY?3=]_GM(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#$S"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-38P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z-#4*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T
M+FEN8SHX.`IM<V=I9"`B3F]N92(*;7-G<W1R("+*X>SLW^$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").
M;VYE("AU<V4@:6UP;&EC:70I(@IM<V=S='(@(LKA[=WMX2`HU_'>\^<@\/'O
MZN'H[_'I\^S=[>_U*2(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HS,B!L:6(O
M0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@(DYO<G1H97)N($AE;6ES<&AE<F4B
M"FUS9W-T<B`BPOSQY>GO(,?LZ?/VX=_QZ>\B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8V-`IM<V=I9"`B3F]T($%F=&5R(@IM<V=S
M='(@(KSWZ2#,Y?3<(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-C,*;7-G:60@(DYO="!"969O<F4B"FUS9W-T<B`BO/?I(-#QZ>TB
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HS-3<*;7-G:60@(DYO
M="!A(&1I<F5C=&]R>2(*;7-G<W1R("+$Y>T@Y=_MX>D@ZN'TW.OOX^_R(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+G!H<#HV-PHC
M.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$]U='!U
M=%-T<F%T96=Y+G!H<#HX-`HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])
M4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+G!H<#HY-0HC.B!F<F%M97=O
M<FLO5D937TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN
M<&AP.C0Y"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]2
M96%L26YP=713=')A=&5G>2YP:'`Z-C`*;7-G:60@(DYO="!I;7!L96UE;G1E
M9"XB"FUS9W-T<B`BQ.7M(-WWY>D@[^OOZNOG\?GHY=\N(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV.`IM<V=I9"`B3F]T
M('-E="(*;7-G<W1R("+$Y>T@W??IY2#TY>CEWR(*"B,Z(&9R86UE=V]R:R]6
M1E,O5D93+G!H<#HQ.#0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(P,PHC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z,C(Q(&9R86UE=V]R:R]61E,O5D93+G!H
M<#HR,S@*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C(U-2!F<F%M97=O<FLO
M5D93+U9&4RYP:'`Z,C<Q"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#D@
M9G)A;65W;W)K+U9&4R]61E,N<&AP.C,R-0HC.B!F<F%M97=O<FLO5D93+U9&
M4RYP:'`Z,S@X(&9R86UE=V]R:R]61E,O5D93+G!H<#HT-S(*(SH@9G)A;65W
M;W)K+U9&4R]61E,N<&AP.C4T-"!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-38R
M"FUS9VED(").;W0@<W5P<&]R=&5D+B(*;7-G<W1R("+$Y>T@]?#O\_3G\=_F
MY?3E+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HR-#<@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$U.0IM<V=I9"`B3F]T
M97,B"FUS9W-T<B`BT^?LY>G^\^7I\B(*"FUS9VED(").;W1E<SHB"FUS9W-T
M<B`BT^?LY>G^\^7I\CHB"@IM<V=I9"`B3F]T97,@4W5M;6%R>2(*;7-G<W1R
M("+3Y^SEZ?[SY>GR("T@T.7QW^OG^.<B"@IM<V=I9"`B(@HB3F]T97,@:7,@
M86X@87!P;&EC871I;VX@=VAI8V@@86QL;W=S('EO=2!T;R!C<F5A=&4@=&AE
M(&-O;7!U=&5R(&5Q=6EV86QE;G0@(@HB;V8@<W1I8VMY(&YO=&5S+B!.;W1E
M<R!C86X@8F4@8W)E871E9"P@;6]D:69I960L(&1E;&5T960L(&%N9"!P<FEN
M=&5D+B!9;W4@(@HB8V%N(&%L<V\@<V5A<F-H(&]N('EO=7(@;F]T97,@=&\@
M;&]C871E(&EN9F]R;6%T:6]N+B!3=7!P;W)T(&9O<B!I;7!O<G1I;F<@(@HB
M86YD(&5X<&]R=&EN9R!N;W1E<R!I<R!A;'-O(&%V86EL86)L92XB"FUS9W-T
M<B`B(@HBS^D@\^?LY>G^\^7I\B#EW^WAZ2#LZ>$@Y?;A\>SOX]X@\._U(//A
M\B#E\.GT\=WPY>D@[>$@Y.?LZ>_U\>/>\^7TY2#T[R`B"B+A[?3?\_3OZ??O
M(/3Y[2#JW_3QZ>WY[2#LZ>KQ_NT@]^'Q].G^[2#S]._M(/7P[^OOX^GS]-XN
M(,SP[_'EW_3E(.WA("(*(N3G[.GO]?'CWO/E].4L(.WA(/3Q[_#O\._IWO/E
M].4L(.WA(.3IX>/QW/CE].4@ZN'I(.WA(/3U\/[SY?3E+B#,\._QY=_TY2`B
M"B+E\-_SY_(@[>$@^-SNY?3E(//TZ?(@\^?LY=_Y\^7I\B#SX?(@X^GA(.WA
M(.7M]._PW_/E].4@[.GA(/#KY_'O]N_QW^$N("(*(M7P[_/TY_'?YN7TX>D@
MZN'I(.7I\^'C^>/>("T@Y>[AX_GCWB#T^>T@\^?LY>G^\^7Y[2XB"@HC.B!S
M97)V:6-E<R]O8G)O=W-E<B]I;F1E>"YP:'`Z,S8*;7-G:60@(DYO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+B(*;7-G<W1R("+4W_#O].$@X^GA(.7L]MSM
MZ?/G+"#E\.GS]/'O]MXN(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA;F-E+V-O
M;F9I<FU?=&]P+FEN8SHQ,`IM<V=I9"`B3F]T:6-E(@IM<V=S='(@(L'MX>KO
MZ>W^\^7I\B(*"B,L(&,M9F]R;6%T"FUS9VED(").;W1I9FEC871I;VX@;&ES
M=&5N97(@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+4[R#P\?SC\>'L[.$@\._U
M(.3IX??EZ?'?YN7TX>D@].GR(.7IY._P[^G>\^7I\B`E<R#DY>T@XO'=Z.?J
MY2XB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S@T"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW
M-0IM<V=I9"`B3F]V96UB97(B"FUS9W-T<B`BS>_=[.+QZ>_R(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T,`IM<V=I9"`B3G5M8F5R(@IM<V=S
M='(@(L'QZ>CL_/(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(Q
M"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R<R(*;7-G<W1R("+!\>GH[/SR
M(/?A\>'J]-[Q^>TB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S8U
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,30T,2!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C$P-`IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,B"FUS9W-T
M<B`BP?'IZ.S\\B#S].?K_NTB"@IM<V=I9"`B3G5M8F5R(&]F(&-O;'5M;G,@
M:6X@=&AE('-U;6UA<GD@=FEE=SHB"FUS9W-T<B`BP?'IZ.S\\B#S].?K_NT@
M\_3G[2#E[/;<[>GSYR#TY_(@\.7QW^OG^.?R.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,30Q
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#,Y('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`R"FUS9VED(").=6UB97(@
M;V8@<F]W<R(*;7-G<W1R("+!\>GH[/SR(./QX>SL_NTB"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V.0IM<V=I9"`B
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="XB"FUS9W-T<B`BQ.7M(._QW_/HY^KE(.'QZ>CL_/(@X^GA
M(.7MY^S=\?GSYR#T^>T@Z^GS]/[M(.3IX>WO[-[R+B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HX,30*;7-G:60@(D]B:F5C
M="(*;7-G<W1R("+![?3IZN7?[.7M[R(*"B,Z('1E;7!L871E<R]S:&%R97,O
M961I="YI;F,Z,3$W"FUS9VED(")/8FIE8W0@0W)E871O<B(*;7-G<W1R("+$
MY^SI[_7QX_SR(,'M].GJY>GLW>WO]2(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$S-R!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(R,PIM<V=I
M9"`B3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>[O]?/I
M[^3O]-[SY>GR(,3G[.GO]?'C[_T@P>WTZ>KEZ>S=[>_U(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3`Y.`IM<V=I9"`B3V-T86PB"FUS9W-T<B`B
MS^KTX>3IZOSR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B"FUS9W-T<B`BS^KT_N+QZ>_R(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.CDR"FUS9VED(")/9F9E;G-E(&9I
M;'1E<B(*;7-G<W1R("+6W^OT\>\@\/'O\^+OZ_[M(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,P-`IM<V=I9"`B3V9F:6-E(@IM<V=S='(@(L/Q
MX?;EW^\B"@IM<V=I9"`B3VQD(%!A<W-W;W)D(@IM<V=S='(@(M#AZ^G\\B#*
M^>3IZOSR(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP
M:'`Z-S8*;7-G:60@(D]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D
M(&9O;&1E<G,N(@IM<V=S='(@(LS\[>\@24U!4"U397)V97)S(/7P[_/TY_'?
MYN_U[2#J[_7M_/?QY_/T[_7R(/;AZMWKZ^_U\BXB"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z.34*;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S
M(@IM<V=S='(@(LS\[>\@Y/7SW/'E\_3E\B#P\>_BZ]WXY>GR(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@S-"!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ.34T"FUS9VED(")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W
M960N(@IM<V=S='(@(LS\[>\@[.GA($5M86EL(.3IY?WH]>WSYR#E\.GT\=WP
MY?3AZ2XB"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@
M(B(*(D]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA
M>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O
M<B!A('-H87)E(@IM<V=S='(@(B(*(LS\[>\@[R#IY.GOZO3>].?R(-X@[R#D
MZ>'WY>GQZ?/TWO(@\_7S]-[LX?3O\B#L\._QY=\@[>$@X>OKW.[EZ2#TY^T@
M(@HBZ>3I[^KTY_/?X2#>(/3I\B#E[N_U\^GOY._TWO/EZ?(@]._U(.GDZ>_J
M]-[TYR#CZ>$@ZN_I[=X@]_'>\^<N(@H*(SH@;&EB+T)L;V-K+VEF<F%M92YP
M:'`Z,S4*;7-G:60@(D]P96X@:6X@82!N97<@=VEN9&]W(@IM<V=S='(@(L'M
M[^GC[.$@\^4@[=WO(/#A\=SH]?'O(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HR-3<*;7-G:60@(D]P96Y34TP@97)R;W(Z($-O=6QD
M(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N(@IM
M<V=S='(@(B(*(D]P96Y34TPMR]SH[_(Z(,3E[2#L\._Q_B#MX2#BX]SK^2#D
MY>3O[-WMX2#A\/P@4R]-24U%(/7P[^/EX_'A[.S=[>\@[-WQ[_(N(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS
M.C4T"FUS9VED(")/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W(@IM
M<V=S='(@(L'M[^GC[.$@X?7TWO(@].?R(//][>3E\^?R(//E(.W=[R#PX?'<
MZ/7Q[R(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU,PIM<V=I9"`B3W!E
M<F%T:6YG(%-Y<W1E;2(*;7-G<W1R("++Y>GT[_7QX^GJ_"#3_?/TY^SA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV
M,#`*;7-G:60@(D]P=&EO;F%L(%!A<G1I8VEP86YT(@IM<V=S='(@(M#Q[^7Q
MX>GTZ>K\\B#3]>SLY?3=]_GM(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B
M87(N<&AP.C$U,0IM<V=I9"`B3W!T:6]N<R(*;7-G<W1R("+%\.GK[^/=\B(*
M"FUS9VED(")/<'1I;VYS(&9O<B(*;7-G<W1R("+%\.GK[^/=\B#CZ>$B"@HC
M.B!S97)V:6-E<R]P<F5F<RYP:'`Z,CD@=&5M<&QA=&5S+W!R969S+V%P<"YI
M;F,Z-`IM<V=I9"`B3W!T:6]N<R!F;W(@)7,B"FUS9W-T<B`BQ?#IZ^_CW?(@
MX^GA("5S(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ.`IM<V=I9"`B3W)D97)E9"!,:7-T(@IM<V=S='(@(M3A[NGM[^SG
M[-WMYR#+W_/TX2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-3DQ"FUS9VED(")/<F=A;FES871I;VXB"FUS9W-T<B`BS_'CX>WI\^S\
M\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DR"FUS
M9VED(")/<F=A;FES871I;VYA;"!5;FET(@IM<V=S='(@(M3LWNSA(,_QX^'M
MZ?/L[_TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3(W"FUS9VED
M(")/<F=A;FEZ:6YG(@IM<V=S='(@(L_QX]SM^?/G(@H*(SH@861M:6XO=&5M
M<&QA=&5S+G!H<#HQ,S4*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E(@IM<V=S='(@(L'UZ.7M].GJ_"#P\?ST]?#O(.7VX?'L[^/>\B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z,3$W"FUS9VED(")/<FEG:6YA;"!T
M96UP;&%T97,@:6X@)7,Z(@IM<V=S='(@(L'UZ.7M].GJW"#P\?ST]?#A(/-E
M("5S.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,C`@<V5R
M=FEC97,O:V5Y8F]A<F0N<&AP.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.CDT"FUS9VED(")/=&AE<B(*;7-G<W1R("+!
MZ^OO(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDV(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HQ,#8*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q,R!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3(Q"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HQ,CD*;7-G:60@(D]T:&5R($EN9F]R;6%T:6]N(@IM<V=S='(@(L'K
MZ^7R(-#KY_'O]N_QW^7R(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHS-PIM<V=I9"`B3W=N97(@4&5R;6ES<VEO;G,B"FUS9W-T<B`BQ>[O]?/I
M[^3O]-[SY>GR(,GDZ>_J]-[TYR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<&%M+G!H<#HX,PIM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N(@IM<V=S='(@(L<@P?7HY>WTZ>KO\._?Y_/G(%!!32#DY>T@
MY=_MX>D@Y.GAZ-WSZ>SG+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$R-SD*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA='5R92(*;7-G
M<W1R("+8Y_;IX>K>(-7P[^/QX?;>(%!'4"(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]P9W`N<&AP.C$S,C@*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T
M82(*;7-G<W1R("+*\?7P]._C\>'VY^S=[>$@Y.7D[^S=[>$@4$=0(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,X-PIM<V=I9"`B4$=0
M(%!U8FQI8R!+97DB"FUS9W-T<B`BQ.?L_//I[R#*Z^7IY-\@4$=0(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3,V-@IM<V=I9"`B4$=0
M(%-I9VYE9"]%;F-R>7!T960@1&%T82(*;7-G<W1R("+5\._CY>/QX>SLW>WA
M+\KQ]?#T[^/QX?;G[-WMX2!01U`@Y.7D[^S=[>$B"@HC.B!A9&UI;B]P:'!S
M:&5L;"YP:'`Z-C,*;7-G:60@(E!(4"!#;V1E(@IM<V=S='(@(E!(4"#*_N3I
MZN'R(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C(P"FUS9VED(")02%`@4VAE
M;&PB"FUS9W-T<B`B4$A0(,K=Z_7V[_(B"@HC.B!L:6(O87!I+G!H<#HQ,C8*
M;7-G:60@(E!?2%`@4VAE;&PB"FUS9W-T<B`B4$A0(,K=Z_7V[_(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0V
M"FUS9VED(")0861D:6YG(@IM<V=S='(@(L/=[.GS[.$B"@HC.B!A9&UI;B]U
M<V5R+G!H<#HS-B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<T"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-34W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,R!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#`Q"B,Z('1E;7!L871E<R]L;V=I
M;B]L;V=I;BYI;F,Z-S`@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN
M8SHS-@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,S8W"FUS9VED(")0
M87-S=V]R9"(*;7-G<W1R("+*^>3IZOSR(@H*;7-G:60@(E!A<W-W;W)D(&-H
M86YG960@9F]R('5S97(@)7,@9G)O;2!C;&EE;G0@)7,B"FUS9W-T<B`BSR#J
M^>3IZOSR(-SKZ^'NY2#CZ>$@]._M(/?QWO/TYR`E<R#A\/P@].\@\_3AZ.S\
M("5S(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,S4T
M"FUS9VED(")087-S=V]R9"!I;F-O<G)E8W0B"FUS9W-T<B`BR]SH[_(@ZOGD
MZ>K\\B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<#HQ-3<*
M;7-G:60@(E!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(L'PX>GTY=_TX>D@ZOGDZ>K\\B#CZ>$@X?7HY>WT
MZ>KO\._?Y_/G(%)!1$E54RXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR,#,V"FUS9VED(")087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G
M<W1R("+*^>3IZOSR(.SE(.7PZ>+EXN'?^?/G(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.CDP"FUS9VED(")087-S=V]R9#HB"FUS9W-T<B`B
MROGDZ>K\\CHB"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN8SHQ,0IM
M<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("+*^>3IZOSR.B`B"@HC.B!A9&UI
M;B]U<V5R+G!H<#HQ-3`@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q-PHC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C$U"FUS9VED(")0
M87-S=V]R9',@;75S="!M871C:"XB"FUS9W-T<B`BSR#J^>3IZOSR(/#QW?#E
MZ2#MX2#TX>GQZ=SFY>DN(@H*;7-G:60@(E!A<W0@179E;G1S($QI<W0B"FUS
M9W-T<B`BR]_S].$@T.7QX?/LW>WY[2#CY>/O[?ST^>TB"@HC.B!A9&UI;B]S
M<6QS:&5L;"YP:'`Z,3(X('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V-O;G1E>'1?;&%N9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BQ?#I
MZOSKZ^?SYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S<*;7-G:60@(E!A<W1E(&9R;VT@8VQI<&)O87)D(@IM<V=S='(@
M(L7PZ>K\Z^OG\^<@X?#\(/3O(&-L:7!B;V%R9"(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3$*;7-G:60@(E!A=&@B"FUS
M9W-T<B`BQ.GAY/'O[-XB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R
M;W9E+FEN8SHT('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U975E9"YI
M;F,Z-`IM<V=I9"`B4&5N9&EN9R!3:6=N=7!S.B(*;7-G<W1R("+%W_/OY._I
M(/#O]2#EZNKQY>SO_>TZ(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4T
M"FUS9VED(")096]P;&4B"FUS9W-T<B`BP>WH\?GP[^DB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R("+0[_/O\_3\(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+V-O;F9I<FU?8F]T=&]M+FEN8SHV"FUS9VED(")097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,B"FUS9W-T<B`BQ>KTW>OE\^<@R^7I]._U\>/I
M_NT@T_7M]-[QY_/G\B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS.3`*
M;7-G:60@(E!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I
M;C\B"FUS9W-T<B`BQ>KTW>OE\^<@R^7I]._U\>/I_NT@T_7M]-[QY_/G\B#J
MX?3<(/3G[2#EW_/OY.\[(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N<&AP
M.C8Q(&%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<#HV-`HC.B!A9&UI;B]P97)M
M<R]A9&1C:&EL9"YP:'`Z-C<*;7-G:60@(E!E<FUI<W-I;VXB"FUS9W-T<B`B
MQ>[O]?/I[^3\].?SYR(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-C@*
M;7-G:60@(E!E<FUI<W-I;VX@)R5S)R!N;W0@9&5L971E9"XB"FUS9W-T<B`B
MQ>[O]?/I[^3\].?SYR#CZ>$@)R5S)R#DY2#DZ>'C\=SVY^KE+B(*"B,Z(&%D
M;6EN+W!E<FUS+V5D:70N<&AP.C(R-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP
M:'`Z.3,*(SH@861M:6XO<&5R;7,O:6YD97@N<&AP.C(R(&%D;6EN+W!E<FUS
M+V1E;&5T92YP:'`Z-S0*;7-G:60@(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(@IM<V=S='(@(L3IX??EW_'I\^<@Q>[O]?/I[^3O]-[SY?GM(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-#D@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ-3(*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HQ-38*;7-G:60@(E!E<FUI<W-I;VYS(&9O<B(*;7-G<W1R("+%
M[N_U\^GOY._TWO/EZ?(@X^GA(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G<W1R("+0\>_S
M^?#IZMWR(/#KY_'O]N_QW^7R(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4U"FUS9VED(")0971S(@IM<V=S='(@(LKA]._IZM_DZ>$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3DY"FUS9VED(")0
M:&]N92(*;7-G<W1R("+4Y^O=]OGM[R(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HT-#<*;7-G:60@(E!H;W1O<R(*;7-G<W1R("+6^?3OX_'A]M_E
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3`X"FUS9VED(")0:7AE;',B"FUS9W-T<B`BQ>GJ[^WO\_3OZ??EW^$B"@HC
M.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-38*;7-G:60@(E!L871I='5D97,B
M"FUS9W-T<B`BRN_I[>_T]?#?Y?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`BT.'QX>KAZ_X@ZMSM].4@ZNOI
MZB#SY2#JW/#OZ>\@ZN7KWR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.`IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.B(*;7-G
M<W1R("+0X?'AZN'K_B#E\.GBY>+AZ?[S].4@_/3I(.C=Z^7TY2#MX2#DZ>'C
M\=SXY?3E(.'U]/P@].\@\_3OZ??EW^\Z(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4U"FUS9VED(")0;&5A
M<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE
M;G0N(@IM<V=S='(@(M#A\>'JX>O^(.7PZ>+EXN'I_O/TY2#\].D@Z-WKY?3E
M(.WA(.'P[_/U[>3=\^7TY2#A]?3\(/3O(//T[^GWY=_O+B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(U-34*;7-G:60@(E!L96%S92!E;G1E<B!A
M(&UO;G1H(&%N9"!A('EE87(N(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(.S>
M[>$@ZN'I(-WT[_(N(@H*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N
M86=E;65N="YI;F,Z,3(*;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R
M('1H92!N97<@8V%T96=O<GDZ(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(-WM
MX2#\[>_LX2#CZ>$@].<@[=WA(.KA].?C[_'?X3HB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ,CDX"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+B(*;7-G<W1R("+0X?'AZN'K_B#D_O/TY2#LZ>$@W>/J
M]?'G($E0(.3IY?WH]>WSYRXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HR-C4Q"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B
M"B+0X?'AZN'K_B#D_O/TY2#LZ>$@W>/J]?'G(.?LY?'O[.?MW^$L(.7KW>[T
MY2#T[^T@X?'IZ.S\(/3Y[2#G[.7Q_NT@]._U(.S>[>$N(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C0S,PIM<V=I9"`B4&QE87-E(&5N=&5R(&$@
M=F%L:60@=&EM92XB"FUS9W-T<B`BT.'QX>KAZ_X@Y/[S].4@W>/J]?'G(/[Q
MX2XB"@IM<V=I9"`B4&QE87-E('!R;W9I9&4@82!N97<@<&%S<W=O<F0B"FUS
M9W-T<B`BT.'QX>KAZ_X@Y/[S].4@].\@[=WO(.KYY.GJ_"#SX?(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS9VED(")0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN(@IM<V=S='(@(M#A
M\>'JX>O^(.3^\_3E(.SIX2#PY?'?Z^?XYR#T[_4@\/'OXNO>[.'T[_(N(@H*
M;7-G:60@(E!L96%S92!P<F]V:61E('EO=7(@<&%S<W=O<F0B"FUS9W-T<B`B
MT.'QX>KAZ_X@Y/[S].4@]._M(.KYY.GJ_"#SX?(B"@IM<V=I9"`B4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92(*;7-G<W1R("+0X?'AZN'K_B#D_O/T
MY2#T[R"\[>_LX2#7\=[S].<B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN
M:6YC.C$X('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(*;7-G:60@(E!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D(@IM<V=S
M='(@(M#A\>'JX>O^(.3^\_3E(/3O(/SM[^SA(.KAZ2#T[^T@ZOGDZ>K\(//A
M\B(*"FUS9VED(")0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE('=I=&@@
M0&1O;6%I;B(*;7-G<W1R("+3]>SPZ^?Q_O/TY2#T[R#\[>_LX2#W\=[S].<@
M[.4@]._M(/3O[-WA("A`97)M:7,N>61T*2(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]A9W)E96UE;G1?=&]P+FEN8SHQ,@IM<V=I9"`B(@HB4&QE87-E
M(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92`B"B)S>7-T96TN(@IM<V=S='(@(B(*
M(M#A\>'JX>O^(.3IX>+<\_3E(/3O(.'J_.OO]>CO(.KEW^SE[^TN(-#QW?#E
MZ2#MX2#S]>SV^>WEW_3E(.SE(/3O]?(@_/'O]?(@(@HBX^GA(.WA(/?QY_/I
M[._P[^G>\^7TY2#A]?3\(/3O(//]\_3G[.$N(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU-#`*;7-G:60@(B(*(E!L
M96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;BP@86YD('1H
M96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92`B"B)M96YU(&)E;&]W+B(*
M;7-G<W1R("(B"B+0X?'AZN'K_B#DY=_TY2#TZ?(@X>K\Z^_UZ.7R(/#KY_'O
M]N_QW^7R(.KAZ2#E\.GKW>[TY2#LZ>$@Y>W=\>/EZ>$@X?#\(/3O("(*(O#A
M\>'JW/3Y(.SE[>_]+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z-#,U"FUS9VED(")0;&5A<V4@<V5L96-T(&%N(&%C
M=&EO;B!F<F]M('1H92!M96YU(&)E;&]W+B(*;7-G<W1R("+0X?'AZN'K_B#E
M\.GKW>[TY2#LZ>$@Y>W=\>/EZ>$@X?#\(/3O(/#A\>'JW/3Y(.SE[>_]+B(*
M"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G97(N<&AP
M.C<R"FUS9VED(")0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z
M(@IM<V=S='(@(M#A\>'JX>O^(.3^\_3E(/3O(/SM[^SA(/3G\B#MW>'R(.KA
M].?C[_'?X?(Z(@H*;7-G:60@(E!L96%S92!V97)I9GD@>6]U<B!N97<@<&%S
M<W=O<F0B"FUS9W-T<B`BT.'QX>KAZ_X@Y?#IXN7BX>G^\_3E(/3O(.W=[R#J
M^>3IZOP@\^'R(@H*;7-G:60@(E!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET
M:"!D87-H97,@*"<M+2`G*3\B"FUS9W-T<B`BS>$@\/'O]-SS\^_M].'I(.3]
M[R#PX?WKY?(@\/'?[2#TY^T@]?#OX_'A]MX@\^'R("@G+2TG*3LB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-`HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,Z,C<*;7-G:60@(E!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4B"FUS9W-T
M<B`BR-WSYR#A]?3>\B#TY_(@Y>GJ_.WA\B(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"FUS9VED(")0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(M3O\._HY?3^[?3A\B#A]?3\(/3O
M[2#PW^WAZN$B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V
M+G!H<#HY-`IM<V=I9"`B4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I(@IM<V=S='(@(L'P[_/T[^O>(//E(.'U]/P@].\@]MSJ
MY>OO("CDY>T@]?#O\_3G\=_FY?3AZ2#A\/P@].\@24U!4"DB"@HC.B!L:6(O
M0FQO8VLO;65T87(N<&AP.C(V-"!L:6(O0FQO8VLO;65T87(N<&AP.C(V.0IM
M<V=I9"`B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS
M9W-T<B`BRN'TX>KQWNSMZ?/G(./IX2#TZ?(@].7KY?7TX=_E\B`E<R#^\>$H
MY?(I.B`B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O;&1A<"YP:'`Z.3D*
M;7-G:60@(E!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"XB"FUS9W-T<B`B4')E9G-?;&1A<#H@Q.4@XO'=Z.?JY2#G(.'P
MX>GT[_WLY>WG(.7PW>KTX?/G($Q$05`N(@H*(SH@9G)A;65W;W)K+U!R969S
M+U!R969S+W-E<W-I;VXN<&AP.C,V"FUS9VED(")0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S='(@
M(E!R969S7W-E<W-I;VXZ(,3E(.+QW>CGZN4@YR#A\.'I]._][.7MYR#E\-WJ
M].'SYR#S]>WEY/'?X?(N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(Y.`IM<V=I9"`B4')E<V5N=&%T:6]N<R(*;7-G<W1R("+0X?'O]?/IW//E
MZ?(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(R,PIM<V=I9"`B4')E<W-U
M<F4B"FUS9W-T<B`BT-_E\^<B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(U
M-PIM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B"FUS9W-T<B`BT-_E
M\^<@\_3O(.7PW_#EY.\@].?R(.C<Z^'S\^'R.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3@T"FUS9VED(")0<F5S<W5R93H@(@IM<V=S
M='(@(M#?Y?/G.B`B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z,3@X"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3(P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,PIM<V=I9"`B4')E=FEE=R(*;7-G<W1R
M("+0\>_E\.GSZOSPZ?/G(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?;&%N9RYJ<SHQ,C$*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(T"FUS9VED(")0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<B"FUS9W-T<B`BT/'OY?#I\^K\\.GS
MYR#TY_(@Y>GJ_.WOX?(@\^4@[=WO(/#A\=SH]?'O(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U!A9V5R+G!H<#HW,2!F<F%M97=O<FLO54DO54DO4&%G97(N<&AP
M.C<R"FUS9VED(")0<F5V:6]U<R!086=E(@IM<V=S='(@(M#Q[^?C[_WLY>WG
M(-/EZ]_DX2(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S4V
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,S8P"FUS9VED(")0<F5V
M:6]U<R!O<'1I;VYS(@IM<V=S='(@(M#Q[^?C[_WLY>WE\B#%\.GK[^/=\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#$*
M;7-G:60@(E!R:6YT(&1O8W5M96YT(@IM<V=S='(@(L7J]/WP^?/G(.7CX_'<
M]N_U(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#`Y"FUS
M9VED(")0<FEV871E($ME>2(*;7-G<W1R("+0\>_S^?#IZOP@RNOEZ>3?(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+TUE;G4N<&AP.C$W-0IM<V=I9"`B
M4')O8FQE;2(*;7-G<W1R("+0\?SBZ^?LX2(*"B,Z('-E<G9I8V5S+W!R;V)L
M96TN<&AP.C$Q,@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO;B(*;7-G<W1R
M("+0Y?'IX_'A]MX@T/'OXNO>[.'T[_(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN
M<&AP+F1I<W0Z,C$V"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("*X\>/O("AP
M<F]J96-T*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(P.30@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$W,0IM<V=I9"`B4')O;7!T('1E>'0B
M"FUS9W-T<B`BRN7?[.7M[R#P\>_T\>_PWO(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,#D*;7-G:60@(E!U8FQI8R!+97DB"FUS9W-T
M<B`BQ.?L_//I[R#*Z^7IY-\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8V.0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET:&TB"FUS
M9W-T<B`BP>OC_/'IZ.SO\B#$Y^S\\^GO]2#*Z^7IY.GO_2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C(R,PIM<V=I9"`B4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB"FUS
M9W-T<B`BU.\@YN7]X^_R(,3G[/SSZ>_U+]#Q[_/Y\.GJ[_T@ZNOEZ>3I[_T@
MY.4@Y.?LZ>_U\>/>Z.?JY2#E\.GT]??^\BXB"@HC.B!A9&UI;B]S<6QS:&5L
M;"YP:'`Z-S`*;7-G:60@(E%U97)Y(@IM<V=S='(@(L7Q_O3G\^<B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C8X-PIM<V=I9"`B4E-!
M(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`BQ.?L_//I[R#*Z^7IY-\@
M4E-!("@E9"!":70I(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T
M-PIM<V=I9"`B4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(L7PZ>OOX]\@Y>W\
M\B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS"FUS9VED(")286YD;VT@
M1F]R='5N92(*;7-G<W1R("+4]??AW^$@T/'\XNOE^.<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C<Q(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+WII<"YP:'`Z-S8*;7-G:60@(E)A=&EO(@IM<V=S='(@
M(LO\X^_R(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<#HR.34@=&5M
M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHT,`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C<T('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z.3<*(SH@
M=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ,C`@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ-#,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN8SHQ
M.#8*;7-G:60@(E)E860B"FUS9W-T<B`BP>W<X^WY\^<B"@HC.B!F<F%M97=O
M<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`IM<V=I9"`B4F5A9"!M
M97-S86=E<R(*;7-G<W1R("+![=SC[?GSYR#LY^W][.'T[_(B"@HC.B!T96UP
M;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$R"FUS9VED(")296%L;'D@
M9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+B(*
M;7-G<W1R("+%W_/TY2#BW>+AZ>_R(./IX2#TYR#DZ>'C\>'VWB`E<SL@P?7T
M_"#DY>T@[/#O\>7?(.WA(.7PX>W=Z^CEZ2XB"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z,3(*;7-G:60@(E)E86QL>2!R96UO=F4@=7-E
M<B!D871A(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+B(*;7-G<W1R("(B"B+%W_/TY2#SW^/O]?'O\B#CZ>$@].<@Y.GA
MX_'A]MX@]/GM(.3EY._LW>WY[2#T[_4@]_'>\_3G("5S.R#!]?3\(.3E[2#L
M\._QY=\@(@HB[>$@Y?#A[=WKZ.7I+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S0*;7-G:60@(E)E9&]E<R!Y;W5R(&QA
M<W0@86-T:6]N(@IM<V=S='(@(L7PX>WEZO3=Z^7SYR#TY_(@].7KY?7TX=_A
M\B#E\>/A\]_A\B#SX?(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S<U
M"FUS9VED(")2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SHB"FUS9W-T
M<B`BP>WA[=WY\^<@]/GM(.3U[>'LZ>K^[2#S]._I]^7?^>T@]._U(,SE[>_]
M.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,C4*;7-G:60@(E)E9G)E
M<V@@4&]R=&%L(%9I97<Z(@IM<V=S='(@(L'MX>W=^?/G(/3G\B#E[/;<[>GS
MY_(@]._U(%!O<G1A;#HB"@IM<V=I9"`B4F5F<F5S:"!3=6UM87)Y(%9I97<Z
M(@IM<V=S='(@(L'MX>W=^?/G(/3G\B#0\>_B[^O>\B#0Y?'?Z^?XY_(Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#@X(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,#0*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(R
M-@IM<V=I9"`B4F5G97@B"FUS9W-T<B`B4F5G97@B"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HS,C,S"FUS9VED(")296QA=&EO;G-H:7`@0G)O=W-E
M<B(*;7-G<W1R("+%[/;<[>GSYR#3]]WSY?GM(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS,C0*;7-G:60@(E)E;6%R:W,B"FUS9W-T<B`BT_?\Z^GA(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HT
M-3<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HT-S8*;7-G:60@(E)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN(@IM<V=S='(@(L'P[^SMY^S\[>7U\^<@\.OG\>_V[_'I_NT@Y.GAZ.7S
MZ>S\].?TX?(N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-`IM<V=I
M9"`B4F5M;W1E(%-E<G9E<G,B"FUS9W-T<B`BP?#O[.'J\?7S[-WM[^D@Q>[U
M\.?QY?3G]-WR(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C@T
M"FUS9VED(")296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3HB"FUS9W-T<B`BP?#O[.'J\?7S[-WMYR#DZ>7]Z/7M\^<@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*"B,Z('1E;7!L871E<R]A9&UI
M;B]G<F]U<',O961I="YI;F,Z,C$@=&5M<&QA=&5S+V%D;6EN+W5S97(O87!P
M<F]V92YI;F,Z-#`*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E<75E
M=65D+FEN8SHQ-0IM<V=I9"`B4F5M;W9E(@IM<V=S='(@(L'VX=_QY?/G(@H*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C$Q"FUS9VED(")296UO
M=F4@0FQO8VLB"FUS9W-T<B`BP?;AW_'E\^<@S/#K_.HB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-3,R"FUS9VED(")296UO
M=F4@8V]L=6UN(@IM<V=S='(@(L'VX=_QY?/G(-/TWNOG\B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*;7-G:60@(E)E
M;6]V92!F;W)M871T:6YG(@IM<V=S='(@(L'VX=_QY?/G(.SO\?;O\._?Y_/G
M\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP
M:'`Z-C4X"FUS9VED(")296UO=F4@9G)O;2!M>2!C86QE;F1A<B(*;7-G<W1R
M("+!]N'?\>7SYR#A\/P@].\@Y^SE\>_K_./I_"#L[_4B"@HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$S-@IM<V=I9"`B4F5M;W9E('!A:7(B"FUS
M9W-T<B`BP?;AW_'E\^<@YN7]X^_U\B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X
M+G!H<#HQ.38*;7-G:60@(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*;7-G<W1R("(B"B+!]N'?\>7S
MYR#A\._HY^KE]>S=[>_U('-C<FEP="#A\/P@]._M(/#Q[_/Y\>GM_"#JX?3<
MZ^_C[R#T[_4@Y>[U\.?QY?3G]-XN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Q"FUS9VED(")296UO=F4@
M=&AE(@IM<V=S='(@(L'VX=_QY?/G(/3O]2(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHT.0IM<V=I9"`B4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("+!]N'?
M\>7SYR#A]?3O_2#T[_4@ZOSLXN_U(.'P_"#T[R#=X^/QX?;O(@H*(SH@=&5M
M<&QA=&5S+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHQ-@IM<V=I9"`B4F5M;W9E
M('5S97(B"FUS9W-T<B`BQ.GAX_'A]MX@]_'>\_3G(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W5S97(O<F5M;W9E+FEN8SHW"FUS9VED(")296UO=F4@=7-E<CH@
M)7,B"FUS9W-T<B`BQ.GAX_'A]MX@U_'>\_3G.B`E<R(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3DW"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,C@P"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S0Y"FUS
M9VED(")297!L>2!396YT+B(*;7-G<W1R("+3]-SKZ.?JY2#!\-SM].?SYRXB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C0U.0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0V.`HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD
M87(N<&AP.C0W.`IM<V=I9"`B4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D($UE
M<W-A9V4B"FUS9W-T<B`BP?#<[?3G\^<@[.4@S,<@]?#O\_3G\>GF_.SE[>\@
M[-[M]>SA+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE
M;F1A<BYP:'`Z-#8V"FUS9VED(")297!L>2!W:71H(&9R964O8G5S>2!F;W(@
M;F5X="`R(&UO;G1H<RXB"FUS9W-T<B`BP?#<[?3G\^<@[.4@\.OG\>_V[_'?
MY?(@Y.GAZ.7SZ>S\].?TX?(@X^GA(/3O]?(@Y?#\[.7M[_7R(.3][R#LWNWE
M\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N
M<&AP.C0V-0IM<V=I9"`B4F5P;'D@=VET:"!R97%U97-T960@9G)E92]B=7-Y
M(&EN9F]R;6%T:6]N+B(*;7-G<W1R("+!\-SM].?SYR#LY2#TZ?(@YN?T[_WL
MY>WE\B#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\BXB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C$X.0IM<V=I9"`B
M4F5P;'DZ("5S(@IM<V=S='(@(L'PW.WTY_/G.B`E<R(*"B,Z(&9R86UE=V]R
M:R]24$,O4E!#+WAM;')P8RYP:'`Z,3,Y"FUS9VED(")297%U97-T(&-O=6QD
M;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z("(*;7-G<W1R
M("+4[R#AW_3G[.$@Y.4@[/#O\>7?(.WA(.'PX>WTY^CEWRX@Q?#I\_3QY?;\
M[.7M[_(@ZOGDZ>K\\B#KW.CO]?(Z("(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92YP:'`Z,3@P(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`S"FUS
M9VED(")297%U:7)E9"`G)7,G(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`BU.\@X?#AZ?3O_>SE[>\@)R5S)R#DY>T@ZN'H
M[_'?\^CGZN4@\_3O("5S(&-O;F9I9W5R871I;VXN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L+G!H<#HV,#$@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HW-SD*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C<U-0IM
M<V=I9"`B4F5Q=6ER960@)R5S)R!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF
M:6=U<F%T:6]N+B(*;7-G<W1R("+4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#J
MX>CO\=_SZ.?JY2#S].\@5D93(&-O;F9I9W5R871I;VXN(@H*(SH@9G)A;65W
M;W)K+U5T:6PO571I;"YP:'`Z-S8Q"FUS9VED(")297%U:7)E9"`G)7,G(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`BU.\@X?#A
MZ?3O_>SE[>\@)R5S)R#DY>T@ZN'H[_'?\^CGZN4@\_3O(&-O;F9I9W5R871I
M;VXN(@H*;7-G:60@(E)E<75I<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@
M:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
MU.\@X?#AZ?3O_>SE[>\@)V)A<V5D;B<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S
M].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED(")297%U
M:7)E9"`G8F%S961N)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O
M;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=B87-E
M9&XG(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q
M[_3I[-[SY?GM+B(*"FUS9VED(")297%U:7)E9"`G9&%T86)A<V4G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS
M9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#J
MX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR("(*(N'UZ.7M].GJ[_#OW^?SY_(N
M(@H*;7-G:60@(E)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I
M;B!C871E9V]R:65S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'P
MX>GT[_WLY>WO("=D871A8F%S92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR
M(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+B(*"FUS9VED(")297%U:7)E9"`G9&%T
M86)A<V4G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@)V1A=&%B87-E)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>
M\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF
M:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN(@IM<V=S='(@
M(B(*(M3O(.'PX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M(-WWY>D@ZN'H[_'I
M\_3EWR#S].GR(/'UZ.S?\^7I\B`B"B+A]>CE[?3IZN_P[]_G\^?R+B(*"FUS
M9VED(")297%U:7)E9"`G:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@8V%T
M96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I]._]
M[.7M[R`G:&]S='-P96,G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CL
MW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I9"`B4F5Q=6ER960@)VAO<W1S<&5C
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M(-WW
MY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN
M(@H*;7-G:60@(E)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I
M;B!A=71H96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4
M[R#A\.'I]._][.7M[R`G<&%S<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@
M\_3I\B#Q]>CLW_/EZ?(@(@HBX?7HY>WTZ>KO\._?Y_/G\BXB"@IM<V=I9"`B
M4F5Q=6ER960@)W!A<W-W;W)D)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I
M97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O_>SE[>\@
M)W!A<W-W;W)D)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR
M(.KA].?C[_'I_NTN(@H*;7-G:60@(E)E<75I<F5D("=P87-S=V]R9"<@;F]T
M('-P96-I9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+B(*;7-G
M<W1R("(B"B+4[R#A\.'I]._][.7M[R`G<&%S<W=O<F0G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS
M9VED(")297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!A=71H
M96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+4[R#A\.'I
M]._][.7M[R`G<&AP='EP92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'U
MZ.S?\^7I\B#A]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED(")297%U:7)E9"`G
M<&AP='EP92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I9W5R
M871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=P:'!T>7!E)R#D
MY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN
M(@H*;7-G:60@(E)E<75I<F5D("=P:'!T>7!E)R!N;W0@<W!E8VEF:65D(&EN
M('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'P
MX>GT[_WLY>WO("=P:'!T>7!E)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@
M\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB"@IM<V=I9"`B4F5Q=6ER960@
M)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=T86)L92<@
MY.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P
M[]_G\^?R+B(*"FUS9VED(")297%U:7)E9"`G=&%B;&4G(&YO="!S<&5C:69I
M960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("+4[R#A
M\.'I]._][.7M[R`G=&%B;&4G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q
M]>CLW_/EZ?(@ZN'TY^/O\>G^[2XB"@IM<V=I9"`B4F5Q=6ER960@)W1A8FQE
M)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN
M(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=T86)L92<@Y.7M(-WWY>D@
MZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN(@H*
M;7-G:60@(E)E<75I<F5D("=U:60G(&YO="!S<&5C:69I960@:6X@875T:&5N
M=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O
M_>SE[>\@)W5I9"<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I
M\B#A]>CE[?3IZN_P[]_G\^?R+B(*"FUS9VED(")297%U:7)E9"`G=6ED)R!N
M;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN(@IM
M<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=U:60G(.3E[2#=]^7I(.KAZ._Q
MZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+B(*"FUS9VED
M(")297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I960@:6X@875T:&5N
M=&EC871I;VX@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HBU.\@X?#AZ?3O
M_>SE[>\@)W5S97)N86UE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR("(*(N'UZ.7M].GJ[_#OW^?SY_(N(@H*;7-G:60@(E)E<75I<F5D
M("=U<V5R;F%M92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(B(*(M3O(.'PX>GT[_WLY>WO("=U<V5R;F%M
M92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_Q
MZ?[M+B(*"FUS9VED(")297%U:7)E9"`G=7-E<FYA;64G(&YO="!S<&5C:69I
M960@:6X@<')E9F5R96YC97,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T<B`B(@HB
MU.\@X?#AZ?3O_>SE[>\@)W5S97)N86UE)R#DY>T@W??EZ2#JX>CO\>GS].7?
M(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2XB"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C@*;7-G:60@(E)E<75I<F5D
M($9I96QD(@IM<V=S='(@(L'PX>GT[_WLY>WO(-#EY-_O(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HU.3(*;7-G:60@
M(E)E<75I<F5D(%!A<G1I8VEP86YT(@IM<V=S='(@(L'PX>GT[_WLY>WO\B#3
M]>SLY?3=]_GM(@H*(SH@861M:6XO=7-E<BYP:'`Z,S$@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,S,Y"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R
M97(N<&AP.C,Q-2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`Q"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z-#0*;7-G:60@(E)E
M<V5T(@IM<V=S='(@(L7PX>WA]N_QW"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S
M<W=O<F0N<&AP.C0V"FUS9VED(")297-E="!087-S=V]R9"(*;7-G<W1R("+!
MZ^OAX]X@ROGDZ>KO_2(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP
M.C(W"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(L'KZ]SN
M].4@]._M(,KYY.GJ_"#SX?(B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z-C8@
M861M:6XO8VUD<VAE;&PN<&AP.C(X(&%D;6EN+W-Q;'-H96QL+G!H<#HW,PIM
M<V=I9"`B4F5S=6QT<R(*;7-G<W1R("+!\._TY>O=\^SA].$B"@HC.B!T96UP
M;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z,3`R('1E;7!L871E<R]P<F5F<R]E
M;F0N:6YC.C<*;7-G:60@(E)E='5R;B!T;R!/<'1I;VYS(@IM<V=S='(@(L7P
MZ?/T\>_VWB#S].GR(,7PZ>OOX]WR(@H*;7-G:60@(E)E='5R;B!T;R!M86EL
M(@IM<V=S='(@(L7PZ?/T\>_VWB#S].?M(.'KZ^?K[^/QX?;?X2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DW(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3@U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#,*;7-G:60@(E)E=6YI;VXB"FUS9W-T<B`BQ?#A[=WM^?/G(@H*
M(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HT-"!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C0X"FUS9VED(")2979E<G0@0V]N9FEG=7)A=&EO;B(*;7-G<W1R
M("+%\.'MX?;O\=P@0V]N9FEG=7)A=&EO;B(*"FUS9VED(")2:&]D97,@06ER
M<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#1_.3O]2(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ,S`*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<R(*;7-G<W1R("+%\.GK[^/=\B#E\.7NY?'CX?/TWB#E[/#K[_7TZ?/L
MW>WO]2#JY>GLW>WO]2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU.`IM
M<V=I9"`B4FED9&QE<R(*;7-G<W1R("+!Z>W?X^SA].$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@
M(E)I9VAT(@IM<V=S='(@(L3E[NG<(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$P-0IM<V=I9"`B4FEG:'0@:&5A9&5R(@IM<V=S='(@(L3E[NG<
M(.7PZ>KE]N'KW^3A(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S$P
M,0IM<V=I9"`B4FEG:'0@=F%L=65S(@IM<V=S='(@(L3E[NG=\B#TZ>S=\B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR.`IM<V=I9"`B4F]?=R!0<F]P97)T:65S+BXN(@IM<V=S='(@(LGD
MZ?STY_3E\B#C\>'L[-[R+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O=F-A<F0N<&AP.C(S-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4X,PIM<V=I9"`B4F]L92(*;7-G<W1R("+1
M_.OO\B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H
M<#HR,#@*;7-G:60@(E)O=&%T92`Q.#`B"FUS9W-T<B`BT.7QZ?/T\>_VWB`Q
M.#"P(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.C(P-0IM<V=I9"`B4F]T871E($QE9G0B"FUS9W-T<B`BT.7QZ?/T\>_VWB#!
M\>GS].7QW"(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HR,3$*;7-G:60@(E)O=&%T92!2:6=H="(*;7-G<W1R("+0Y?'I\_3Q
M[_;>(,3E[NG<(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHT.0IM<V=I9"`B4F]W(%!R;W!E<G1I97,B"FUS9W-T
M<B`BR>3I_/3G].7R(,/QX>SLWO(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C<P"FUS9VED(")2;W<@<')O<&5R
M=&EE<R(*;7-G<W1R("+)Y.G\].?TY?(@P_'A[.S>\B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S
M.B(*;7-G<W1R("+#\>'L[-WR.B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3,*;7-G:60@(E)U;&5S(@IM<V=S
M='(@(LKA[?SMY?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4P"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS(@IM<V=S='(@(L_I(.KA[?SM
MY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#\Z_GM(/3Y[2#C\>'L[/[M(.KA
MZ2#T^>T@\_3GZ_[M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?=&%B;&5?;&%N9RYJ<SHU,0IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!C;VQU;6YS(&]N;'DB"FUS9W-T<B`BS^D@ZN'M_.WE\B#HX2#E
M[/;A[=_F[^WTX>D@[.7TX>[](/3Y[2#S].?K_NT@[/SM[R(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-3(*;7-G
M:60@(E)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W<R!O;FQY(@IM<V=S
M='(@(L_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#T^>T@X_'A
M[.S^[2#L_.WO(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C$R.0IM<V=I9"`B
M4G5N(@IM<V=S='(@(L7J]-WKY?/G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HS,#`*;7-G:60@(E,O34E-12!#<GEP=&]G<F%P:&EC
M(%-I9VYA='5R92(*;7-G<W1R("+5\._C\>'VWB#*\?7P]._C\=SVY_/G\B!3
M+TU)344B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,T
M,0IM<V=I9"`B4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(LKQ
M]?#T[^/QX?;G[-WM[R#LWNWU[.$@4R]-24U%(@H*(SH@9G)A;65W;W)K+T%U
M=&@O075T:"]S87-L+G!H<#HX-@IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+'(.'UZ.7M].GJ[_#OW^?S
MYR!305-,(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N(@H*(SH@8V]N9FEG+W)E9VES
M=')Y+G!H<"YD:7-T.C0X,0IM<V=I9"`B4TU3($UE<W-A9VEN9R(*;7-G<W1R
M("+,Y^W][.'TX2!335,B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,C$*;7-G
M:60@(E-13"!3:&5L;"(*;7-G<W1R(")344P@RMWK]?;O\B(*"B,Z(&9R86UE
M=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL
M92YP:'`Z,S@*;7-G:60@(E-50T-%4U,B"FUS9W-T<B`BQ=#)U-77V=,B"@HC
M.B!L:6(O87!I+G!H<#HQ,S`*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B
M4U]13"#*W>OU]N_R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C
M86QE;F1A<BYJ<SHV,0IM<V=I9"`B4V$B"FUS9W-T<B`BT^$B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDR"FUS9VED(")3
M86UE(&9R86UE("A?<V5L9BDB"FUS9W-T<B`BNN3I[R#PZ^'?\^GO("A?<V5L
M9BDB"@IM<V=I9"`B4V%M;W,@06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA
M\B#3W.SO]2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,C`*
M;7-G:60@(E-A=&5L;&ET92!0<F]V:61E<B(*;7-G<W1R("+0W/'O]^_R(,3O
M\?7V_/'O]2(*"B,Z('1E;7!L871E<R]P;W)T86PO;&%Y;W5T+FEN8SHY.`IM
M<V=I9"`B4V%V92(*;7-G<W1R("+!\._HWNKE]?/G(@H*(SH@=&5M<&QA=&5S
M+W-H87)E<R]E9&ET+FEN8SHR,C(*;7-G:60@(E-A=F4@)7,B"FUS9W-T<B`B
MP?#OZ-[JY?7SYR`E<R(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z-#D*;7-G:60@(E-A=F4@)R5S)R(*;7-G<W1R("+!\._HWNKE]?/G
M("<E<R<B"@HC.B!T96UP;&%T97,O<')E9G,O96YD+FEN8SHU"FUS9VED(")3
M879E($]P=&EO;G,B"FUS9W-T<B`BP?#OZ-[JY?7SYR#%\.GK[^/^[2(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C$*;7-G:60@(B(*(E-A=F4@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@
M<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C=&]R>2XB"FUS9W-T<B`B(@HB
MP?#OZ-[JY?7SYR#T[_4@8V]N9FEG=7)A=&EO;B#P[_4@Y.?LZ>_U\>/>Z.?J
MY2#SX>T@4$A0(%-C<FEP="#S]._M(/#Q[_/Y\>GM_"`B"B+JX?3<Z^_C[R#T
M[_4@Y>[U\.?QY?3G]-XN(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-CD*;7-G:60@(E-A=F5D("5S(&-O;F9I9W5R871I;VXN(@IM<V=S='(@(L'P
M[^CGZN7U[-WM[R`E<R!C;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P
M+W-C<FEP=',N<&AP.CDP"FUS9VED(")3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@)R5S)RXB"FUS9W-T<B`BU.\@<V-R:7!T(.7MY^S=\?GSY_(@
M].\@<V5T=7`@X?#OZ.?JY?WHY^KE(//T[SH@)R5S)RXB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3D*;7-G:60@(E-C:65N8V4B"FUS9W-T<B`BQ?#I
M\_3>[.<B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-2!T
M96UP;&%T97,O861M:6XO=7-E<B]L:7-T+FEN8SHQ-PIM<V=I9"`B4V5A<F-H
M(@IM<V=S='(@(L'MX>;>].?SYR(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N
M9&ES=#HR.#$*;7-G:60@(E-E87)C:"!%;F=I;F5S(@IM<V=S='(@(LSG]^'M
MW?(@P>WAYM[TY_/G\B(*"FUS9VED(")396%R8V@@36%I;"(*;7-G<W1R("+!
M[>'FWO3G\^<@S.?M]>S<]/GM(@H*;7-G:60@(E-E87)C:"!297-U;'1S(@IM
M<V=S='(@(L'P[_3EZ]WS[.'TX2#![>'FWO3G\^?R(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,CDU-PIM<V=I9"`B4V5L96-T($9I;&5S(@IM<V=S
M='(@(L7PZ>OOX]X@P?'WY=_Y[2(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-38*;7-G:60@(E-E;&5C="!A(&1A=&4B"FUS
M9W-T<B`BQ?#IZ]WN].4@[.GA(.?LY?'O[.?MW^$B"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C(P-`IM<V=I9"`B4V5L96-T(&$@9W)O=7`@=&\@
M861D(@IM<V=S='(@(L7PZ>O=[O3E(._LW.3A(./IX2#P\>_SZ-[JYR(*"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z-#D*;7-G:60@(E-E;&5C="!A
M(&YE=R!O=VYE<B(*;7-G<W1R("+%\.GKW>[TY2#MW>\@R>3I[^KTWO3G(@H*
M(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C8P"FUS9VED(")396QE
M8W0@82!S97)V97(B"FUS9W-T<B`BQ?#IZ]WN].4@Y>[U\.?QY?3G]-XB"@HC
M.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$V,@IM<V=I9"`B4V5L96-T
M(&$@=7-E<B!T;R!A9&0B"FUS9W-T<B`BQ?#IZ]WN].4@]_'>\_3G(./IX2#P
M\>_SZ-[JYR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(V-30*;7-G
M:60@(E-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+B(*;7-G<W1R("+%\.GK
M[^/>(/SK^>T@]/GM(.?LY?'O[.?MZ?[M+B(*"B,Z(&9R86UE=V]R:R]522]5
M22]687)296YD97)E<B]H=&UL+G!H<#HX,30*;7-G:60@(E-E;&5C="!A;B!O
M8FIE8W0B"FUS9W-T<B`BQ?#IZ^_CWB#E[?SR(.'M].GJY>GLW>WO]2(*"B,Z
M('-E<G9I8V5S+VME>6)O87)D+G!H<#HS-PIM<V=I9"`B(@HB4V5L96-T('1H
M92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9
M;W4@8V%N('1H96X@8V]P>2!A;F0@(@HB<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT87)E82XB"FUS9W-T<B`B(@HBQ?#IZ]WN].4@]._U\B#WX?'AZO3>\>7R
M(/#O]2#HW>OE].4@X?#\(/3I\B#PX?'AZMST^2#KW_/TY?(N(,KA]/SPZ>WL
M\._QY=_TY2`B"B+MX2#TX2#A[?3IX_'<^.7TY2#JX>D@[>$@].$@Y?#IZN_K
MZ][SY?3E(//T[R#LWNWU[.$@\^'R+B(*"FUS9VED(")396QE8W0@=&AE(&1A
M=&4@9&5L:6UI=&5R.B(*;7-G<W1R("+%\.GK[^/>(/3O]2#DZ>'W^?'I\_3>
M(.?LY?'O[.?MW^'R.B(*"FUS9VED(")396QE8W0@=&AE(&1A=&4@9F]R;6%T
M.B(*;7-G<W1R("+%\.GK[^/>(/3G\B#L[_'VWO(@\._U(.CA(-WWY>D@YR#G
M[.7Q[^SG[=_A.B(*"FUS9VED(")396QE8W0@=&AE(&ED96YT:71Y('EO=2!W
M86YT('1O(&-H86YG93HB"FUS9W-T<B`BQ?#IZ]WN].4@].<@].'U]/STY_3A
M(/#O]2#HW>OE].4@[>$@X>OKW.[E].4Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O
M=&EM92YI;F,Z,38*;7-G:60@(E-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z
M(@IM<V=S='(@(L7PZ>O=[O3E(/3O(.3IX??Y\>GS]-X@_O'A\CHB"@HC.B!T
M96UP;&%T97,O9&%T82]T:6UE+FEN8SHR-0IM<V=I9"`B4V5L96-T('1H92!T
M:6UE(&9O<FUA=#HB"FUS9W-T<B`BQ?#IZ]WN].4@].<@[._Q]MX@\._U(.CA
M(-WWY>D@YR#^\>$Z(@H*;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+B(*;7-G<W1R("+%\.GKW>[TY2#D_>\@\.7DW^$@\._U(/3AZ?'IW.;O
M]>TN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(Y,`IM<V=I9"`B4V5L
M96-T('EO=7(@8V]L;W(@<V-H96UE+B(*;7-G<W1R("+%\.GKW>[TY2#T[R#W
M\?GLX?3IZOP@)_/WWNSA)RXB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z
M,C,R"FUS9VED(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM
M<V=S='(@(L7PZ>O=[O3E(/3G(./K_O/SX2#SX?(Z(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-3,*;7-G:60@(E-E
M;F0@3&%T97-T($EN9F]R;6%T:6]N(@IM<V=S='(@(L'P[_/T[^O>(/3Y[2#P
MZ>\@\/'\\_;A]/GM(/#KY_'O]N_QZ?[M(@H*(SH@=&5M<&QA=&5S+W!R;V)L
M96TO<')O8FQE;2YI;F,Z-3@*;7-G:60@(E-E;F0@4')O8FQE;2!297!O<G0B
M"FUS9W-T<B`BP?#O\_3OZ]X@P>WA]N_QW/(@T/'OXNO>[.'T[_(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.38T"FUS9VED
M(")396YD(%--4R(*;7-G<W1R("+!\._S]._KWB!335,B"@HC.B!L:6(O0FQO
M8VLO;65T87(N<&AP.C,Q-`IM<V=I9"`B4V5N<V]R.B`B"FUS9W-T<B`BP>GS
MZ.?TWO'A\CH@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C,X,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-#$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("+3Y?#TW>SB\>GO
M\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S(U"FUS
M9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(M/EZ?'IX>K\\B#!\>GH[/SR
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,S`Q"FUS9VED(")397-S:6]N($E$(&5X<&ER960N(@IM<V=S='(@(M3O
M($E$(/3G\B#S_>WDY?/G\B#=Z^?NY2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,CDU"FUS9VED(")3970B"FUS9W-T<B`BR-WSY2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HW-@IM<V=I9"`B4V5T(&]P=&EO;G,@=&\@
M86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@
M9F]R9V5T(&ET+B(*;7-G<W1R("(B"B+(W?/TY2#E\.GK[^/=\B#P[_4@Z.$@
M\^'R(.7PZ?3QW?#O]>T@[>$@X>OKW.;E].4@]._M(.KYY.GJ_"#SX?(L(.'J
M_.SG(.KAZ2`B"B+A[2#T[^T@W??E].4@[N7WW//EZ2XB"@HC.B!C;VYF:6<O
M<')E9G,N<&AP+F1I<W0Z,3$U"FUS9VED(")3970@=7`@<F5M;W1E('-E<G9E
M<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"XB
M"FUS9W-T<B`BT.'QX>SE]/'O\._?Y_/G(.'P[^SAZO'U\^S=[?GM(.7N]?#G
M\>7TY_3^[2#P[_4@Z-WKY?3E(/#Q_//BX?/G+B(*"FUS9VED(")3970@>6]U
M<B!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M(@IM<V=S='(@(B(*(M'UZ.S?\_3E(.3IW/;O\>7R(.7PZ>OOX]WR(.7L]MSM
MZ?/G\B#JX>D@].\@]_'\[>\@X>WA[=WY\^?R(/3Y[2#SY>O?Y/GM+B(*"FUS
M9VED(")3970@>6]U<B!P<F5F97)R960@9&ES<&QA>2!L86YG=6%G92XB"FUS
M9W-T<B`BQ?#IZ^_CWB#TY_(@\/'O].GL[_WLY>WG\B#CZ_[S\^'R+B(*"FUS
M9VED(")3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N
M9"!D871E(&]P=&EO;G,N(@IM<V=S='(@(LKAZ._QW_/TY2#TY^T@\/'O].GL
M_NSE[><@X^O^\_/A+"#F_NWG(/[QX?(@ZN'I(.SO\?;>(.?LY?'O[.?MW^'R
M+B(*"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I
M<W!L87D@;W!T:6]N<RXB"FUS9W-T<B`B(@HBRN'H[_'?\_3E(/3G[2#E]N'Q
M[._CWB#EZNK?[>?SY_(L(/3A(/#Q[_3I[/[LY>WA(/?Q_NSA].$L(/3G(/#E
M\=_OY.\@(@HBX>WA[=WY\^?R(/3G\B#SY>O?Y.'R(.KAZ2#<Z^OE\B#E\.GK
M[^/=\B#E[/;<[>GSY_(N(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HW
M-`IM<V=I9"`B4V5T=7`B"FUS9W-T<B`BT?WH[.GSYR(*"B,Z('1E;7!L871E
M<R]A9&UI;B]S971U<"]I;F1E>"YH=&UL.C,X"FUS9VED(")3971U<"!U<&=R
M861E('-C<FEP=',@879A:6QA8FQE(@IM<V=S='(@(L7?[>'I(.3IX>C=\^GL
MX2!38W)I<'1S(.7MY^S=\?GSY_(@\?7H[-_SY?GM(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C$S-0IM<V=I9"`B4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B"FUS9W-T<B`BT._K
MZ]WR(/3O\._HY?/?Y?(@Y=_MX>D@\.GHX>W=\B#LY2#A]?3>(/3G(/#A\=SL
MY?3Q[SH@(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W,PIM<V=I
M9"`B4VAO<'!I;F<B"FUS9W-T<B`BP>/O\=WR(@H*(SH@=&5M<&QA=&5S+W!R
M;V)L96TO<')O8FQE;2YI;F,Z-#,*;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS
M9W-T<B`BT_WM]._LYR#0Y?'?Z^?XYR(*"FUS9VED(")3:&]R="!3=6UM87)Y
M.B(*;7-G<W1R("+3_>WT[^SG(-#E\=_KY_CG.B(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,S`*;7-G:60@(E-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/R(*;7-G<W1R("+0\=WPY>D@].\@ZNOE
MZ>3?(/#Q_//BX?/G\B#MX2#O\>GSZ.7?(./IX2#PY?'I\_/\].7QY?(@\_7M
MY-WSY>GR.R(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,CDT('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,SD*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHW,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDV"B,Z
M('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3$Y('1E;7!L871E<R]S:&%R
M97,O961I="YI;F,Z,30R"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z
M,3@U"FUS9VED(")3:&]W(@IM<V=S='(@(L7L]MSMZ?/G(@H*(SH@861M:6XO
M<V5T=7`O:6YD97@N<&AP.C$T.0IM<V=I9"`B(@HB4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"`B"B)C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"B+%[/;<[>GSYR#D
MZ>'V[_'^[2#LY?3A[OT@]._U(.'P[^CGZN7U[-WM[_4@ZN'I(/3O]2#DY^SI
M[_7QX^?HW>WT[_(@(@HB8V]N9FEG=7)A=&EO;BXB"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z-#<T"FUS9VED(")3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_(@IM<V=S='(@(L7L]MSMZ?/G(/3G\B#^\>'R(/3E
MZ^7U].'?X?(@Y>GS_.3O]2#\].'M(.SPX=_M[_7LY2#S].\@\_WS].?LX3LB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S4R"FUS9VED(")3:&]W
M(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L(@IM<V=S='(@(L7L]MSMZ?/G(.7P
MZ>OOX][R(./IX2#A\._HWNKE]?/G(/3O]2#A]>CE[?3IZN_](@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P,0IM<V=I9"`B4VAO=R!P:6-K97(B
M"FUS9W-T<B`BQ>SVW.WI\^<@\_7KZ]WJ].<B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-3`Y"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N
M=2!B87(_(@IM<V=S='(@(LWA(.7L]N'MW^;E].'I(/3O(.SE[>_](.SE(.7Q
MX^'SW^7R(/#?[>'JX3LB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S,S
M"FUS9VED(")3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R
M("+%[/;<[>GSYR#T[_4@)7,@S.7M[_T@\_3A(.'QZ?/TY?'<.R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M.`IM<V=I9"`B4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO
M9R(*;7-G<W1R("+%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,KE
MZ^G^[2#0W^WAZN$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z-C,*;7-G:60@(E-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L7L]MSMZ?/G(/3O]2#DZ>'K_./O
M]2#)Y.GO]-[T^>T@T-_MX>KA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4Y"FUS9VED(")3:&]W('1H92!4
M86)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BQ>SVW.WI\^<@
M]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2##\>'L[/[M(-#?[>'JX2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU
M,0IM<V=I9"`B4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<B"FUS
M9W-T<B`BQ>SVW.WI\^<@]._U(.3IX>O\X^_U(,GDZ>_TWO3Y[2#%Z>K\[>'R
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<U,`IM<V=I9"`B4VAO
M=R!U<&QO860B"FUS9W-T<B`BQ>SVW.WI\^<@]OSQ]/GSY_(@*'5P;&]A9"DB
M"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HS.3$*;7-G
M:60@(E-H<FEN:R(*;7-G<W1R("+3]?'QW^KM^?/G(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-C@T(&9R86UE=V]R:R]";&]C:R]"
M;&]C:R],87EO=70N<&AP.C<T-@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HX,#0@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP
M:'`Z.#8V"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.CDP
M,2!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HY,S@*(SH@9G)A
M;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.38V(&9R86UE=V]R:R]"
M;&]C:R]";&]C:R],87EO=70N<&AP.CDY-@IM<V=I9"`B4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M(@IM<V=S='(@(M#Q_O3A(//U\?'?ZNWY\^<@WB#LY?3AZM_MY_/G(./EZ?3O
M[>GJ_NT@].SG[-ST^>TB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,C<X"FUS9VED(")3:6=N('5P(@IM<V=S='(@(L7?\^_D[_(MU?#O
MX_'A]MXB"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@Y"FUS9VED
M(")3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D(@IM<V=S='(@(L<@Q=_S[^3O
M\BW5\._C\>'VWB#DY>T@W??EZ2#JX?3A]_GQY^CEWRXB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<S-@IM<V=I9"`B4VEG;F%T=7)E
M(@IM<V=S='(@(M7P[^/QX?;>(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HW,S4*;7-G:60@(E-I9VYA='5R92!!;&=O<FET:&TB"FUS
M9W-T<B`BP>OC_/'IZ.SO\B#5\._C\>'VWO(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R87(N<&AP.C8X(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+WII<"YP:'`Z-S(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O=&=Z+G!H<#HX-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3`*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(P-B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C(X"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R,CD@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ.`HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HS,3`W"FUS9VED(")3:7IE(@IM<V=S='(@(LS=X^7H[_(B
M"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N8V4O8V]N9FER;5]B;W1T;VTN:6YC
M.CD*;7-G:60@(E-K:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BP>K]\?GSYR#3
M]>WTWO'G\^?R(@H*;7-G:60@(E-O;64@;V8@2&]R9&4G<R!C;VYF:6=U<F%T
M:6]N(&9I;&5S(&%R92!M:7-S:6YG.B(*;7-G<W1R("+,Y?'IZMP@X?#\(/3A
M(.'Q]^7?X2#DZ>'WY=_QZ?/G\B#T[_4@2&]R9&4@W??O]>T@]^'HY=\Z(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,CDQ-`IM<V=I9"`B4V]R="!O
M<F1E<B!S96QE8W1I;VXB"FUS9W-T<B`BQ?#IZ^_CWB#JX?3E_>CU[?/G\B#T
MX>[I[?SLY_/G\B(*"FUS9VED(")3;W5D82!!:7)P;W)T(@IM<V=S='(@(L'E
M\>_KZ>S=[>'R(-/O_>3A\B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S
M;7,R96UA:6Q?:'1T<"YP:'`Z-3@Q"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C$S"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(R,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR-34*;7-G:60@(E-O=7)C
M92!A9&1R97-S(@IM<V=S='(@(L3IY?WH]>WSYR#0Y^/>\B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,R!L:6(O0FQO8VLO;6]O;BYP:'`Z-C(*;7-G:60@
M(E-O=71H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`BS?STZ>\@Q^SI\_;AW_'I
M[R(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS(@IM<V=S
M='(@(L3IW//TY^SA(.SE].'N_2#CY>GT[^WIZO[M(.KEZ^G^[2(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED
M(")3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM
M<V=S='(@(L3IW//TY^SA(.SE].'N_2#PY?'IY??O[-WM[_4@ZN'I(./QX>SL
MWO(@ZN7KZ?[M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#$T"FUS
M9VED(")3<&%C97(B"FUS9W-T<B`BT.O>ZO3Q[R#$Z>'S]-[LX?3O\B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("+!\>'?^?/G(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I
M9"`B4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("+!\>'?^?/G(.KAZ2#C
MW>SI\^SA(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.CDU"FUS9VED
M(")3<&%M(@IM<V=S='(@(E-P86TB"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP
M:'`Z,30*;7-G:60@(E-P96-I86P@0VAA<F%C=&5R($EN<'5T(@IM<V=S='(@
M(L7I\^'C^>/>(,7IY.GJ_NT@U^'QX>KTWO'Y[2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-C(*;7-G:60@(E-P
M;&ET(&-E;&PB"FUS9W-T<B`BQ.GAW_'E\^<@ZN7KZ>_](@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-@IM<V=I
M9"`B4W!L:70@8V]L=6UN(@IM<V=S='(@(L3IX=_QY?/G(//TWNOG\B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G<W1R("+$Z>'?\>7SYR#C\>'L[-[R
M(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"FUS9VED(")3<&]R=',B
M"FUS9W-T<B`BP>CKWNSA].$B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C0T,PHC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4T.`IM<V=I9"`B4W1A<G0B"FUS9W-T
M<B`BN.WA\>[G(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C4X."!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-SDW"FUS9VED(")3=&%R="!Y96%R
M(@IM<V=S='(@(KCT[_(@N.WA\>[G\B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3DT"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*
M;7-G<W1R("+0[^OI].7?X2#>(,7PX?'WW^$B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C4X,PHC.B!T96UP;&%T97,O
M861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ,@IM<V=I9"`B4W1A='5S(@IM<V=S
M='(@(LKA]-SS].'SYR(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X
M,#,*;7-G:60@(E-T;W)A9V4@9F]R;6%T(@IM<V=S='(@(LSO\?;>(.'P[^C>
MZN7U\^?R(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M.38*;7-G:60@(E-T<F5E="!!9&1R97-S(@IM<V=S='(@(L3IY?WH]>WSYRW/
MY/SR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,0IM<V=I9"`B4W1R:6ME=&AR;W5G:"(*;7-G<W1R("+$Z>'C\>'L[.GS
M[-WMX2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,C0*;7-G:60@
M(E-T<FEN9R!L:7-T(@IM<V=S='(@(LO?\_3A(.O=[N7Y[2(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$X-38*;7-G:60@(E-T<FEP(&1O;6%I;B!F
M<F]M('1H92!A9&1R97-S(@IM<V=S='(@(L'VX=_QY?/G(/3O]2!D;VUA:6X@
MX?#\(/3G(.3IY?WH]>WSYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C,*;7-G:60@(E-T>6QE(%M#4U-=(@IM
M<V=S='(@(M/T_>L@6T-34UTB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8R"FUS9VED(")3=2(*;7-G<W1R("+*]2(*"B,Z
M('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS-PIM<V=I9"`B4W5B9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("+/(/7P[_;<ZN7K[_(@)R5S)R#D
MY2#B\=WHY^KE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C,U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)F8S@R,BYP
M:'`Z-S@*;7-G:60@(E-U8FIE8W0B"FUS9W-T<B`BR-WLX2(*"B,Z(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8X"FUS9VED(")3=6)J96-T
M(%!U8FQI8R!+97D@26YF;R(*;7-G<W1R("+(W>SA("?0Z^?Q[_;O\=_E\B#$
MY^S\\^GO]2#*Z^7IY.GO_2<B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,S(@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD97)E<BYP:'`Z,S$R"FUS
M9VED(")3=6)M:70B"FUS9W-T<B`BP?#O\_3OZ]XB"@HC.B!S:6=N=7`N<&AP
M.C4P"FUS9VED("(B"B)3=6)M:71T960@<F5Q=65S="!T;R!A9&0@)R5S)R!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B`B
M"B)R97%U97-T(&AA<R!B965N(&%P<')O=F5D+B(*;7-G<W1R("(B"B+4[R#A
MW_3G[.$@X^GA(/#Q[_/HWNKG("<E<R<@\_3O(//]\_3G[.$@X?#E\_3<Z^<N
M(,3E(.SP[_'EW_3E(.WA(.[A[>'L\.7?].4@(@HB[-WW\>D@[>$@Y>/J\>GH
MY=\@].\@X=_TY^S<(//A\BXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$R"FUS9VED(")3=6)S8W)I<'0B"FUS9W-T<B`B
MU?#OY.7?ZO3G\B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,3,*(SH@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A
M='5S+G!H<#HS,`IM<V=I9"`B4W5C8V5S<R(*;7-G<W1R("+%\.GT]???X2(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C@U"FUS9VED(")3=6-C97-S9G5L;'D@861D
M960@)R5S)R!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("+%\.GT]??>\B#P\>_S
MZ-[JYR`G)7,G(//T[R#S_?/TY^SA+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R
M-`IM<V=I9"`B4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`G
M)7,G(&9R;VT@=&AE('-Y<W1E;2XB"FUS9W-T<B`BU.$@Y.7D[^S=[>$@]._U
M(/?QWO/TYR`G)7,G(.3IX>/QW/;GZN'M(.7PZ?3U]_[R(.'P_"#T[R#S_?/T
MY^SA+B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z.#$@861M:6XO<&5R;7,O9&5L
M971E+G!H<#HV,0IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E;&5T960@)R5S)RXB
M"FUS9W-T<B`BQ?#I]/7WWO(@Y.GAX_'A]MX@)R5S)RXB"@HC.B!A9&UI;B]U
M<V5R+G!H<#HQ,#4*;7-G:60@(E-U8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("+%\.GT]??>\B#DZ>'C\>'VWB`G
M)7,G(.'P_"#T[R#S_?/TY^SA+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-3$*;7-G:60@(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N(@IM<V=S='(@(B(*(L_I(/'U
MZ.S?\^7I\B#E\.'MX?;=\>CGZN'M(.7PZ?3U]_[R+B#*W.WTY2#E\.'MX?;\
M\?3Y\^<@X^GA(.WA(.3EW_3E(/3I\B`B"B+AZ^OAX]WR+B(*"B,Z(&%D;6EN
M+W-E='5P+VEN9&5X+G!H<#HU.2!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HU
M-0IM<V=I9"`B4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N+B(*;7-G<W1R("+%\.GT]??>\B#E\._HWNKE]?/G(.7VY>3QZ>KO_2!C
M;VYF:6=U<F%T:6]N+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-C(*
M;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RXB"FUS9W-T<B`BQ?#I]/7WWO(@X?#OZ-[JY?7SYR#T
M[_4@Y?;EY/'IZN_](.'Q]^7?[_4@8V]N9FEG=7)A=&EO;B`E<RXB"@HC.B!A
M9&UI;B]U<V5R+G!H<#HQ-C@*;7-G:60@(E-U8V-E<W-F=6QL>2!U<&1A=&5D
M("<E<R<B"FUS9W-T<B`BQ?#I]/7WWO(@Y>WG[-WQ^?/G("<E<R<B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HW,@IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S='(@(L7P
MZ?3U]][R(.7CX_'A]MX@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C4U.`HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]I8V%L96YD87(N<&AP.C4V,`HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3=6UM87)Y
M(@IM<V=S='(@(M/][>_XYR`M(-#E\=_KY_CG(@H*(SH@;&EB+T)L;V-K+W-U
M;G)I<V4N<&AP.C8V"FUS9VED(")3=6X@4FES92(*;7-G<W1R("+![>'T[^O>
M(@H*(SH@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C<Q"FUS9VED(")3=6X@4V5T
M(@IM<V=S='(@(L3]\^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,38U"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(L'MX?3OZ]XB"@HC.B!L
M:6(O0FQO8VLO<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z
M,38*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(L'MX?3OZ]XOQ/WS
MYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C0*;7-G:60@
M(E-U;G)I<V4Z("(*;7-G<W1R("+![>'T[^O>.B`B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,38X"FUS9VED(")3=6YS970B"FUS9W-T<B`B
MQ/WSYR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-C<*;7-G
M:60@(E-U;G-E=#H@(@IM<V=S='(@(L3]\^<Z("(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3,*;7-G:60@(E-U<&5R<V-R
M:7!T(@IM<V=S='(@(M7PY?'DY=_J].7R(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V-0IM<V=I9"`B4W5P<&]R="(*;7-G<W1R("+5\._S]-[Q
MZ>[G(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3@*
M;7-G:60@(E-U<FYA;64B"FUS9W-T<B`BQ?#?Z.7T[R(*"B,Z('-E<G9I8V5S
M+W!O<G1A;"]S>6YC;6PN<&AP.C@V"FUS9VED(")3>6YC(&QO9R!D96QE=&5D
M(@IM<V=S='(@(M3O(.'Q]^7?[R#JX?3AX_'A]M[R(//UX_?Q[^WI\^SO_2#D
MZ>'C\=SVY^KE(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T-0IM<V=I
M9"`B4WEN8TU,(@IM<V=S='(@(E-Y;F--3"(*"B,Z(&9R86UE=V]R:R]344PO
M4U%,+TME>7=O<F1S+G!H<#HY.`IM<V=I9"`B4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<R(*;7-G<W1R("++W.CO\B#S_>WTX>[G\B#S]._U\B#\\>_U
M\B#A[>'FWO3G\^?R(@H*(SH@9G)A;65W;W)K+U5)+U5)+U1A8FQE+G!H<#HQ
M,S4*;7-G:60@(E1A8FQE(@IM<V=S='(@(M#?[>'JX?(B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<S"FUS9VED
M(")486)L92!0<F]P97)T:65S(@IM<V=S='(@(LGDZ?STY_3E\B#0W^WAZN$B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C<R"FUS9VED(")486)L92!P<F]P97)T:65S(@IM<V=S='(@(LGDZ?ST
MY_3E\B#0W^WAZN$B"@IM<V=I9"`B5&%N86=R82!!:7)P;W)T(@IM<V=S='(@
M(L'E\>_KZ>S=[>'R(-3A[=SC\>'R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHY-0IM<V=I9"`B5&%R9V5T.B(*;7-G<W1R
M("+3]/SW[_(Z(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$V.`IM
M<V=I9"`B5&%S:W,B"FUS9W-T<B`BQ?'CX?/?Y?(B"@IM<V=I9"`B5&%T;VD@
M06ER<&]R="(*;7-G<W1R("+!Y?'OZ^GLW>WA\B#4X?3O^N_U(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.3<*;7-G:60@(E1E;&5P
M:&]N92!.=6UB97(B"FUS9W-T<B`BP?'IZ.S\\B#4Y^OE]O[M[_4B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(X.`IM<V=I9"`B5&5M<"!F;W(@;&%S="!H
M;W5R.B`B"FUS9W-T<B`BR.7Q[._J\>'SW^$@].?M(/3EZ^7U].'?X2#^\>$Z
M("(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$R"FUS9VED(")496UP97)A
M='5R92(*;7-G<W1R("+(Y?'L[^KQX?/?X2(*"B,Z(&QI8B]";&]C:R]W96%T
M:&5R9&]T8V]M+G!H<#HQ-S(*;7-G:60@(E1E;7!E<F%T=7)E.B`B"FUS9W-T
M<B`BR.7Q[._J\>'SW^$Z("(*"B,Z(&9R86UE=V]R:R]496UP;&%T92]496UP
M;&%T92YP:'`Z,C$Q"FUS9VED(")496UP;&%T92`G)7,G(&YO="!F;W5N9"XB
M"FUS9W-T<B`BU.\@\/'\]/7P[R`G)7,G(.3E(.+QW>CGZN4N(@H*(SH@861M
M:6XO=&5M<&QA=&5S+G!H<#HQ-CD*;7-G:60@(E1E;7!L871E($%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(L3IX??EW_'I\^<@T/'O]/WP[_4B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP.C8T,0IM<V=I
M9"`B5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0B"FUS9W-T<B`BT/'O\_GQ
MZ>W>(,'P[^3O]]X@X>GTWNSA]._R(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O:6-A;&5N9&%R+G!H<#HV.#D*;7-G:60@(E1E;G1A=&EV96QY
M($%C8V5P=&5D(@IM<V=S='(@(M#Q[_/Y\>GMW"#!\._DY>KT_"(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,#(*;7-G:60@(E1E>'0B"FUS9W-T
M<B`BRN7?[.7M[R(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-3D*;7-G
M:60@(E1E>'0@3VYL>2(*;7-G<W1R("+,_.WO(,KEW^SE[>\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<T"FUS
M9VED(")497AT(&%L:6=N(@IM<V=S='(@(M/T[]_WY_/G(.KEZ>S=[>_U(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0IM
M<V=I9"`B5&5X='1O<"(*;7-G<W1R("+*[_'U]MX@ZN7I[-WM[_4B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R("+4Y2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP
M.CDT-`IM<V=I9"`B5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*
M;7-G<W1R("+%]??A\>GS]._][.4@\._U(/?QY_/I[._P[^G>\^'TY2#T[R#3
M_?/TY^S<(.SA\BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C<V
M.0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB
M"FUS9W-T<B`BQR#E\-WJ].'SYR!&5%`@Y.7M(.7?[>'I(.'J_.SG(.3IX>C=
M\^GLYRXB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.CDR-`IM<V=I
M9"`B5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T(%PB)7-<(B(*;7-G<W1R("+4[R#S_?/TY^SA($AO<F1E+TMO
M;&%B(.3E[2#U\._S].?QW^;EZ2!<(B5S7"(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z,CD*;7-G:60@(E1H92!-86EN=&5N86YC93HZ(&-L87-S
M(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T<B`BQ.GA]^7?\>GS
MYSHZ(,<@ZNO<\^<@Y.4@]N_Q]/[HY^KE(.7PZ?3U]_[R(@H*(SH@<V5R=FEC
M97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM<V=I9"`B5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N(@IM<V=S='(@(M3O(/#A
M\=SH]?'O(.7PZ>OOX_[M(-WJZ^7I\^4N(+CN[^3O\BXB"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,N<&AP.C$V,"!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C$W,0HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$X,B!F<F%M
M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C$Y-`HC.B!F<F%M97=O<FLO4&5R;7,O
M4&5R;7,N<&AP.C(P-2!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(R,PHC
M.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C(S-2!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,N<&AP.C(W-`IM<V=I9"`B(@HB5&AE(&%D;6EN:7-T<F%T;W(@
M;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A
M8VME;F0@:68@>6]U("(*(G=A;G0@=&\@=7-E(%!E<FUI<W-I;VYS+B(*;7-G
M<W1R("(B"B+/(.3IX??EZ?'I\_3>\B#P\=WPY>D@[>$@\?7H[-_SY>D@W>WA
M(.S\[>GL[R#PZ^'?\^GO(,7N[_7SZ>_D[_3>\^7Y[2P@X^GA(.WA("(*(NSP
M[_'EW_3E(.WA(/?QY_/I[._P[^G>\^7TY2#E[N_U\^GOY._TWO/EZ?(N(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHW-0IM<V=I9"`B5&AE(&)O='1O;2!S:61E(&]N;'DB"FUS9W-T<B`BQR#J
MW/3Y(/#KY?7QW"#L_.WO(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O:6-A;&5N9&%R+G!H<#HT.0IM<V=I9"`B5&AE(&-A;&5N9&%R(&1A=&$@
M:7,@:6YV86QI9"(*;7-G<W1R("+4X2#DY>3O[-WMX2#G[.7Q[^OOX]_O]2#D
MY>T@Y=_MX>D@W>/J]?'A(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M
M<S)E;6%I;%]H='1P+G!H<#HV-C0*;7-G:60@(B(*(E1H92!C;VYT86-T($E$
M(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@
M;F]T(&9O=6YD(&EN('1H92`B"B)D871A8F%S92XB"FUS9W-T<B`B(@HBU.\@
M240@].?R(.7PX?;>\B#DY>T@ZN'H[_'?\^CGZN4L(-[TX>T@ZN7M_"#>(.3E
M(.+QW>CGZN4@\_3G(.+<\^<@Y.7D[^S=[?GM+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HU-`IM<V=I9"`B5&AE(&-O;G1A
M8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O
M:RXB"FUS9W-T<B`BQR#E\.'VWB#P\>_S]-WHY^KE(.7PZ?3U]_[R(//T[R#$
MZ>7UZ/7M\^GOX_'<]N\@\^'R+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$Q-S$*;7-G:60@(B(*(E1H92!D971A8VAE9"!01U`@<VEG
M;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D
M(&UE<W-A9V4N(@IM<V=S='(@(B(*(M3O(/3LWNSA(%!'4"#P[_4@X?#O\_#<
M\^CGZN4@X?#AZ?3EW_3O(./IX2#TY^T@Y?#AZ][HY?7SYR#T[_4@]?#OX^7C
M\>'L[-WM[_4@(@HB[.?MWNSA]._R+B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C8V"FUS9VED("(B"B)4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"`B"B)I;B!T:&4@9&%T86)A<V4N(@IM
M<V=S='(@(B(*(M3O($E$(/3G\B#KW_/TX?(@Y.GA[>_LWO(@Y.7M(._QW_/H
MY^KE+"#>].'M(.KE[?P@WB#DY2#B\=WHY^KE(//TYR#BW//G("(*(N3EY._L
MW>WY[2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C8V-PIM<V=I9"`B5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+B(*;7-G<W1R("+'(.O?\_3A(.3IX>WO[-[R(.3E[2#J
MX>CO\=_SZ.?JY2XB"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$R
M-PIM<V=I9"`B5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BXB"FUS9W-T<B`BS^D@Y/7MX?3\].?TY?(@
MZO'U\/3OX_'<]N?SY_(@X?#AZ?3O_>T@X?/VX>O>(//][>3E\^<@5T5"+B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z
M-S@*;7-G:60@(E1H92!E=F5N="!H87,@8F5E;B!A9&1E9"!T;R!Y;W5R(&-A
M;&5N9&%R+B(*;7-G<W1R("+4[R#CY>/O[?SR(/#Q[_/TW>CGZN4@\_3O(.?L
MY?'OZ_SCZ?P@\^'R+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z
M,3@Q(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3`T"FUS9VED(")4:&4@
M9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N(@IM<V=S='(@
M(M3O(.'Q]^7?[R`E<R#P\=WPY>D@[>$@\.7QZ=WWY>D@[.GA("5S(/']Z.SI
M\^<N(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-S0@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HT.30*;7-G:60@(E1H92!F:6QE("5S('-H
M;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N(@IM<V=S='(@(M3O(.'Q
M]^7?[R`E<R#P\=WPY>D@[>$@\.7QZ=WWY>D@ZMSP[^GE\B`E<R#Q]>CLW_/E
MZ?(N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,38U"FUS9VED
M(")4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BXB"FUS
M9W-T<B`BU.\@X?'WY=_O(.3E(.SP[_'EWR#MX2#A[?3IX_'A]N7?(//T[^T@
MY>'U]/P@]._U+B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$N<&AP.C(V-`IM
M<V=I9"`B5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(M3O
M(.'Q]^7?[R#DY>T@\.7QZ=WWY>D@Y.7D[^S=[>$N(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,@IM<V=I9"`B5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92XB"FUS9W-T<B`BU.$@\.'QX>K<]/D@Y=_MX>D@Y?#IZN7V
MX>O?Y.7R(./IX2#A]?3\(/3O(.S>[?7LX2]R9F,X,C(@[-[M]>SA+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-38*;7-G
M:60@(B(*(E1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E
M('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92`B"B)T;R!B
M<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N
M9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E("(*(F=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@(@HB>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I
M="=S('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L("(*
M(E!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<7&Y<7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92`B"B)P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BXB
M"FUS9W-T<B`B(@HBQR#JX?3<\_3A\^<@\.O>\>_U\B#OZ/SMY_(@Y=_MX>D@
MX^WY\_3\(/STZ2#DY^SI[_7QX^7?(/#Q_.+KY^SA(.SE(/3O[2`B"B));G1E
M<FYE="!%>'!L;W)E<BP@Y>[AZ?3?X?(@\/'OXNOG[-ST^>T@*&)U9W,I(/3O
M]2!B<F]W<V5R+"#TX2#O\._?X2#DY>T@(@HBY=_AZ2#D]>WA]/P@[>$@[N7P
MY?'A\^CO_>TN(,SP[_'EWR#MX2#DY=_TY2`G\^KO]?#?Y.GA)R#S].?M(._H
M_.WG+"`B"B+P\>_BZ][LX?3A(//TYR#KY>GT[_7QX]_A(/3O]2!B<F]W<V5R
M(-X@ZN'I(.K\Z^?LW"#T[_4N(,'M(/3O(//]\_3G[-P@\^'R("(*(N7?[>'I
M(%=I;F1O=R`Y>"#EW^WAZ2#P[^O](/#IZ.'M_"#MX2#DY=_TY2`GP^7MZ>K>
M(,'P[_3U]]_A(-#Q[_/TX?/?X?(G(.KAZ2`B"B+MX2#P\=WPY>D@[>$@Y?#A
M[>7JZNGMWO/E].4@*')E8F]O="DN7%QN7%S!]?3>(.7?[>'I(/#Q[^7IY._P
M[]_G\^<N(-#A]-[S].4@(@HBS\H@X>T@Z-WKY?3E(.'J_.SG(.WA(.3O]>O=
M^.7TY2#SY2#JX?3<\_3A\^<@\.O>\>_U\B#OZ/SMY_(N(@H*(SH@<V5R=FEC
M97,O<')E9G,N<&AP.C@X"FUS9VED(")4:&4@:61E;G1I='D@7"(E<UPB(&AA
M<R!B965N(&1E;&5T960N(@IM<V=S='(@(L<@].'U]/STY_3A(%PB)7-<(B#D
MZ>'C\=SVY^KE+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7W1A8FQE7VQA;F<N:G,Z-S8*;7-G:60@(E1H92!L969T+6AA;F0@<VED92!O
M;FQY(@IM<V=S='(@(L<@X?'I\_3E\=X@\.OE]?'<(.S\[>\B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S8*;7-G:60@(B(*(E1H92!L
M;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@
M=&AE($-R>7!T7W!G<#HZ(&-L87-S+B(*;7-G<W1R("(B"B+'(.C=\^<@]._U
M(/#Q[^/QW.SLX?3O\B!';G501R#P\=WPY>D@[>$@Y._HY=\@X^GA(/3G($-R
M>7!T7W!G<#HZ(.KKW//G+B(*"FUS9VED(")4:&4@;6%I;&)O>"!T<F%S:"!I
M<R!A;')E861Y(&5M<'1Y+B(*;7-G<W1R("+'(./QX>SLX?3OZ/7QW^3A("?J
MW.3O\B<@Y=_MX>D@WN3G(-SDY>GA+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O341.+G!H<#HR,30*;7-G:60@(B(*(E1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T(%PB)7-<(B!H87,@8F5E;B!D:7-P;&%Y
M960N7&XB"B)4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"XB"FUS9W-T<B`B(@HBU.\@
M[-[M]>SA(/#O]2#S]-SKZ.?JY2#S].GR("5S(//T[^T@)7,@[.4@Z-WLX2`E
M<R#E[/;A[=_SZ.?JY2Y<;B(*(L'U]/P@Y.7M(.'P[_3EZ^7?(.7PZ>+EXN'?
M^?/G(/STZ2#DZ>'BW//HY^KE(.KAZ2#=X^GMY2#JX?3A[>_G]/PN(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3@V,`IM<V=I9"`B5&AE(&YA;64@
M=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E(@IM<V=S
M='(@(M3O(/SM[^SA(/#O]2#HX2#W\>?SZ>SO\._IY=_TX>D@_/3A[2#S]>WD
MW>7S].4@\_3G(//EZ]_DX2#S_>WHY?/G\BXB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C$R-3D*;7-G:60@(E1H92!O<&5N<W-L(&UO
M9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@
M8VQA<W,N(@IM<V=S='(@(L<@XNGBZ^GOZ-[JYR!/<&5N4U-,(.'PX>GTY=_T
MX>D@X^GA($AO<F1E7T-R>7!T7W-M:6UE.CH@ZNO<\^<N(@H*(SH@9G)A;65W
M;W)K+U!R969S+U!R969S+G!H<#HR.3$*;7-G:60@(B(*(E1H92!P<F5F97)E
M;F-E(%PB)7-<(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T
M82!E>&-E961E9"!T:&4@(@HB;6%X:6UU;2!A;&QO=V%B;&4@<VEZ92(*;7-G
M<W1R("(B"B+'(/#Q[_3?[.?SYR!<(B5S7"(@Y.7M(.SP_/'E\^4@[>$@X?#O
MZ.?JY?7HY=\@X^GA]-\@].$@Y.7D[^S=[>$@].?R("(*(O7PY?'BX=_M[_7M
M(/3O(.S=X^GS].\@Y?#I]/'E\/3\(.S=X^7H[_(B"@HC(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+VUS97AC96PN<&AP.C,U+"!C+69O<FUA=`HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D96(N<&AP.C,U"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<#HS-PHC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W!O=V5R<&]I;G0N<&AP.C,U"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VUS=V]R9"YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<G!M+G!H<#HS-0HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]W96)C<'`N<&AP.C0P"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W-R8VAI9VAL:71E+G!H<#HS.0HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<V5X8V5L+G!H<#HS-0IM<V=I
M9"`B(@HB5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@;65S<V%G92!T
M>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(*;7-G<W1R
M("(B"B+4[R#P\?SC\>'L[.$@\._U(/?QY_/I[._P[^GEW_3E(./IX2#TY^T@
MY>SVW.WI\^<@X?7T[_T@]._U(.7?Y._U\B#LY^WU[-ST^>T@(@HB*"5S*2#D
MY>T@XO'=Z.?JY2#S].\@\_WS].?LX2XB"@IM<V=I9"`B(@HB5&AE(')E9VES
M=')Y(&ES(&AO=R!(;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O
M('1A;&L@=&\@96%C:"!O=&AE<BX@(@HB66]U('-H;W5L9"!L:7-T(&%N>2!I
M;G-T86QL960@2&]R9&4@87!P;&EC871I;VYS('1H870@>6]U(&AA=F4@:&5R
M92XB"FUS9W-T<B`B(@HBQR!R96=I<W1R>2#EW^WAZ2#O(/3Q_/#O\B#LY2#T
M[^T@[_#OW^\@[^D@Y?;A\>SOX]WR(/3O]2!(;W)D92#E\.GJ[^GM^>WO_>TN
M("(*(NSE].'N_2#T[_7R+B#%Y/X@\/'=\.7I(.WA(./QW/CE].4@_/3I(.7V
MX?'L[^/=\B#T[_4@2&]R9&4@W??E].4@(@HBY>/JX?3A\_3>\^7I+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-S<*;7-G:60@(E1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY(@IM<V=S
M='(@(L<@X?'I\_3E\=X@ZN'I(.3E[NG<(/#KY?7QW?(@[/SM[R(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S@*
M;7-G:60@(E1H92!R:6=H="UH86YD('-I9&4@;VYL>2(*;7-G<W1R("+'(.3E
M[NG<(/#KY?7QW"#L_.WO(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP
M:'`Z-S@*;7-G:60@(E1H92!S97)V97(@7"(E<UPB(&AA<R!B965N(&1E;&5T
M960N(@IM<V=S='(@(L\@Y>[U\.?QY?3G]-[R(%PB)7-<(B#DZ>'C\=SGZN4N
M(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U;2YP:'`Z-#D*;7-G:60@(E1H
M92!S97)V97(@7"(E<UPB(&AA<R!B965N('-A=F5D+B(*;7-G<W1R("+/(.7N
M]?#G\>7TWO(@7"(E<UPB(.'P[^CGZN7]Z.?JY2XB"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ.3@*;7-G:60@(E1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"XB"FUS9W-T<B`BU.\@X=_TY^SA(.7I\_SD[_4@X^GA
M("5S(.3IX>/QW/;GZN4N(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C@T"FUS9VED(")4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO
M="!E>&ES="XB"FUS9W-T<B`BQR#C\>'L[-X@\._U(._QW_/A].4@Y.7M(/7P
MW/'WY>DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N
M9&%R+G!H<#HQ,#@*;7-G:60@(E1H92!T87-K(&AA<R!B965N(&%D9&5D('1O
M('EO=7(@=&%S:VQI<W0N(@IM<V=S='(@(L<@Y?'CX?/?X2#P\>_S]-WHY^KE
M(//TYR#KW_/TX2#E\>/A\^G^[2#SX?(N(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L+G!H<#HQ,3$*;7-G:60@(E1H92!T96UP;W)A<GD@9FEL92!<(B5S
M7"(@9&]E<R!N;W0@97AI<W0N(@IM<V=S='(@(M3O(/#Q[_/Y\>GM_"#A\??E
MW^\@7"(E<UPB(.3E[2#U\-SQ]^7I+B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-SD*;7-G:60@(E1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY(@IM<V=S='(@(L<@\-SM^2#JX>D@ZMST
M^2#PZ^7U\=WR(.S\[>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL
M>2(*;7-G<W1R("+'(/#<[?D@\.OE]?'<(.S\[>\B"@HC.B!F<F%M97=O<FLO
M1&%T82]$871A+G!H<#HS,3$*;7-G:60@(E1H92!U<&QO861E9"!D871A('=A
M<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*;7-G<W1R("+4X2#D
MY>3O[-WMX2#P[_4@\_3=Z^WA].4@]]SHY^KA[2#A\/P@].\@\/'OY^/O_>SE
M[>\@XM[LX2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C4P
M(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S<*;7-G:60@(E1H92!U
M<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS9W-T<B`BU.\@
MX?'WY=_O(/#O]2#S].7?Z^'TY2#DY2#L\/SQY?/E(.WA(//YZ.7?+B(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z.3,*
M;7-G:60@(E1H92!U<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S
M=6-E<W-F=6QL>2!S=&]R960N(@IM<V=S='(@(L_I(/#KY_'O]N_QW^7R(.3I
MX>CE\^GL_/3G].'R(.'P[^CGZN7]Z.?JX>T@Y?#I]/7W_O(N(@H*(SH@=71I
M;"]I8V]N7V)R;W=S97(N<&AP.C(U"FUS9VED(")4:&5M97,@9&ER96-T;W)Y
M("<E<R<@;F]T(&9O=6YD+B(*;7-G<W1R("+/(.KA]-SK[^/O\B#HY>S<]/GM
M("<E<R<@Y.4@XO'=Z.?JY2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M54DN<&AP.C$X,PIM<V=I9"`B5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA
M8FQE+B(*;7-G<W1R("+$Y>T@]?#<\??O]>T@Q?#IZ^_CW?(@Y.GAZ-WSZ>SE
M\BXB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HS-#`*
M;7-G:60@(E1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y
M960@:6YL:6YE+B(*;7-G<W1R("+$Y>T@]?#<\??O]>T@].S>[.'TX2#P[_4@
MY.4@[/#O\>_][2#MX2#E[/;A[>GSZ._][2#E[?/Y[.'T^>S=[>$N(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y-PIM<V=I9"`B(@HB5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y;W4@;75S="!E;G1E<B!L
M97-S('1H86X@)7,N(@IM<V=S='(@(B(*(M7PW/'W[_7M(/#OZ^OOWR#WX?'A
MZO3>\>7R(//E(.'U]/P@].\@\.7DW^\N(,7I\^'CW./A].4@)7,@]^'QX>KT
MWO'E\BP@(@HB\/'=\.7I(.WA(/7PW/'W[_7M(.OIX_STY?'OZ2#A\/P@)7,N
M(@H*(SH@<VEG;G5P+G!H<#HU-0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!A9&1I;F<@)R5S)R!T;R!T:&4@<WES=&5M+B`E<RXB"FUS9W-T<B`BT/'\
MXNOG[.$@ZN'TW"#TY^T@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX2X@)7,N
M(@H*(SH@861M:6XO=7-E<BYP:'`Z-S,*;7-G:60@(E1H97)E('=A<R!A('!R
M;V)L96T@861D:6YG("<E<R<@=&\@=&AE('-Y<W1E;3H@)7,B"FUS9W-T<B`B
MT/'\XNOG[.$@ZN'TW"#TY^T@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX3H@
M)7,N(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(R"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H
M92!S>7-T96TZ("(*;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G(.3IX>/QX?;>
M(.3EY._LW>WY[2#T[_4@]_'>\_3G("<E<R<@X?#\(/3O(//]\_3G[.$Z("(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C$P,PIM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!R96UO=FEN9R`G)7,G(&9R;VT@=&AE('-Y<W1E;3H@(@IM<V=S='(@
M(M#Q_.+KY^SA(.KA]-P@].<@Y.GAX_'A]MX@)R5S)R#A\/P@].\@\_WS].?L
MX3H@(@H*(SH@861M:6XO=7-E<BYP:'`Z,34Y"FUS9VED(")4:&5R92!W87,@
M82!P<F]B;&5M('5P9&%T:6YG("<E<R<Z("5S(@IM<V=S='(@(M#Q_.+KY^SA
M(.KA]-P@].?M(.7MY^S=\?GSYR`G)7,G.B`E<R(*"B,Z(&9R86UE=V]R:R]"
M<F]W<V5R+T)R;W=S97(N<&AP.C@Y.0IM<V=I9"`B5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+B(*;7-G<W1R("+0\?SBZ^?LX2#JX?3<(/3G[2#A\._S]._KWB#A\??EW^_U
M.B#$Y>T@\_3<Z^CGZN4@)7,N(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O
M=W-E<BYP:'`Z.3`T"FUS9VED("(B"B)4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H
M92!M87AI;75M("(*(F%L;&]W960@<VEZ92`H)60@8GET97,I+B(*;7-G<W1R
M("(B"B+0X?'O]?/IW//HY^KE(/#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T[^O>
M(/3O]2#A\??EW^_U.B#4[R`E<R#EW^WAZ2#LY>/AZ_WTY?'O("(*(N'P_"#T
M[R#LW>/I\_3O(.7PZ?3QY?#\[.7M[R#LW>/EZ._R("@E9"!">71E<RDN(@H*
M(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.3`V"FUS9VED("(B
M"B)4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+B(*;7-G<W1R("(B
M"B+0X?'O]?/IW//HY^KE(/#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T[^O>(/3O
M]2#A\??EW^_U.B#3]-SKZ.?JY2#L_.WO(-WMX2`B"B+T[-[LX2#T[_4@)7,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HS
M.`IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M
M97-S86=E('!A<G0B"FUS9W-T<B`B(@HBT.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@
MZN'TW"#TY^T@Y>SVW.WI\^<@X?7T[_T@]._U(/3LWNSA]._R(/3O]2#LY^W]
M[.'T[_(N(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C0R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H
M<#HU,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@
M8V]N=&%C="!D871A+B(*;7-G<W1R("+0X?'O]?/IW//HY^KE(//VW.OLX2#J
MX?3<(/3G[2#EZ?/AX_GCWB#DY>3O[-WM^>T@Q.GE]>CU[?/I[^/QW/;O]2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]I8V%L96YD87(N<&AP
M.C<U"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!E
M=F5N=#H@)7,N(@IM<V=S='(@(M#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@
M].?M(.7I\^'C^>/>(/3O]2#CY>/O[>_T[_(Z("5S+B(*"B,Z(&9R86UE=V]R
M:R]$871A+T1A=&$O:6UC+G!H<#HS,@IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R
M<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N(@IM<V=S='(@(M#A
M\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(.3EY._LW>WY
M[2#G[.7Q[^OOX]_O]2XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$P-0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N(@IM<V=S='(@(M#A\>_U\^G<\^CG
MZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>(/3G\B#E\>/A\]_A\CH@)7,N
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H
M<#HY,0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N.B`E<RXB"FUS9W-T<B`BT.'Q[_7S
MZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@\.OG\>_V[_'I_NT@
MY.GAZ.7SZ>S\].?TX?(Z("5S+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-SD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N
M9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A("(*(G)E
M<75I<F5D(&9I96QD+B(*;7-G<W1R("(B"B+0X?'O]?/IW//HY^KE(//VW.OL
MX2#S].<@]OSQ[.$@\?7H[-_SY?GM+B"Z\_GR(.'VWO/A].4@ZN7M_"#JW/#O
MZ>\@(@HBX?#AZ?3O_>SE[>\@\.7DW^\N(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-C,*;7-G:60@(B(*(E1H97)E
M('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S
M<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@(@HB=')Y(&%G86EN(&QA=&5R+B(*
M;7-G<W1R("(B"B+0X?'O]?/IW//HY^KE(//VW.OLX2#S].?M(.7J]-WKY?/G
M(/3G\B#JX>CO\>GS[-WMY_(@Z^7I]._U\>/?X?(@]._U("(*(L3IY?7H]>WS
MZ>_C\=SV[_4N(-#A\>'JX>O^(.3OZNGLW//TY2#A\>/\].7QX2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8V-0IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(@IM<V=S='(@
M(B(*(D)E:2!D97(@06MT=6%L:7-I97)U;F<@9&5R($MO;G1A:W1D971A:6QS
M(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!":71T92`B"B)V97)S=6-H
M96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8W,`IM<V=I9"`B(@HB
M5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@
M;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BXB"FUS9W-T<B`B(@HBT.'Q
M[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>WG[-WQ^?/G(/3G\B#KW_/T
MX?(@Y.GA[>_LWO(N(-#A\>'JX>O^("(*(N3OZNGLW//TY2#A\>/\].7QX2XB
M"@IM<V=I9"`B5&AE<W-A;&]N:6MI($%I<G!O<G0B"FUS9W-T<B`BP>7Q[^OI
M[-WMX?(@R.7S\^'K[^W?ZN?R(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!
M0TPO<F9C,C`X-BYP:'`Z,34S"FUS9VED(")4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+B(*;7-G<W1R("+/(.7N
M]?#G\>7TY_3>\B!)34%0(.3E[2#U\._S].?QW^;EZ2#J[^GM_/?QY_/T[_7R
M(/;AZMWK[_7R+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC
M86QE;F1A<BYP:'`Z.#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M:6-A;&5N9&%R+G!H<#HY-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C$Q,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I
M97=E<B]I8V%L96YD87(N<&AP.C(P,`IM<V=I9"`B5&AI<R!A8W1I;VX@:7,@
M;F]T('-U<'!O<G1E9"XB"FUS9W-T<B`BP?7TWB#G(.7MW?'CY>GA(.3E[2#U
M\._S].?QW^;E].'I+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VEC86QE;F1A<BYP:'`Z,3$X"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+VEC86QE;F1A<BYP:'`Z,S4Y"FUS9VED(")4:&ES(&%C=&EO;B!I<R!N
M;W0@>65T(&EM<&QE;65N=&5D+B(*;7-G<W1R("+!]?3>(.<@Z^7I]._U\>/?
MX2#DY>T@W??EZ2#OZ^_JZ^?Q^>CEWR#AZOSLYRXB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Q"FUS9VED(")4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(*;7-G<W1R
M("+!]?3\(.3E(/;AW^WE].'I(.WA(.7?[>'I(-WCZO7Q[R#A\??EW^\@<F%R
M+B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-34*
M;7-G:60@(E1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N(@IM<V=S='(@(L'U]/P@Y.4@]N'?[>7TX>D@[>$@Y=_MX>D@W>/J
M]?'O(.'Q]^7?[R!Z:7`N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S$R.0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N(@IM<V=S='(@(L'U]/P@Y.4@]N'?[>7TX>D@[>$@Y=_M
MX>D@W>/J]?'O\B#A\>GH[/SR(.K<\?3A\BXB"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.#<*;7-G:60@(B(*(E1H
M:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@
M=&AE($-L:6-K871E;&P@*&AT='`Z+R\B"B)C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(@IM<V=S='(@(B(*(L'U]/SR(.\@
M[^3GX_SR(//A\B#E\.GT\=WPY>D@[>$@\_3=Z^WE].4@[.?M_>SA].$@[-WS
M^2!#;&EC:V%T96QL+2AH='1P.B\O(@HB8VQI8VMA=&5L;"YC;VTI(.S=\_D@
M2%144"U!4$DN(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I
M;%]H='1P+G!H<#HU,S0*;7-G:60@(B(*(E1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+R(*(G-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%022(*;7-G<W1R("(B"B+!]?3\\B#O(._DY^/\\B#SX?(@Y?#I]/'=\.7I
M(.WA(//TW>OMY?3E(.SG[?WLX?3A(.S=\_D@<VUS,F5M86EL+2AH='1P.B\O
M(@HB<VUS,FUA:6PN8V]M*2#LW?/Y($A45%`M05!)+B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@R"FUS9VED
M("(B"B)4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y
M+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M
M86EL(&%C8V]U;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W
M=RXQ.3`N:70I+B(*;7-G<W1R("(B"B+!]?3\\B#O(._DY^/\\B#SX?(@Y?#I
M]/'=\.7I(.WA(//TW>OMY?3E(.SG[?WLX?3A(.S=\_D@4TU44"`@ZN'I(/3G
M\B`B"B)6;V1A9F]N92U)=&%L>2#L_.WO(//E(.'QZ>CL[_WR(%9O9&%F;VYE
M+B#!\.'I].7?(-WMX2#K[^/A\>GA\^S\(&5M86EL(//TYR`B"B)6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$Q-S,@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(T
M-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C@Q(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S.30*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,34T-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#(V"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$Y-#$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DX.`HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#$R(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(P-C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$S,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C`T"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(S.3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C0S-@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C0X(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(X,38*(SH@9G)A;65W;W)K+T9O<FTO1F]R
M;2YP:'`Z,S$R,2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HS,S@V"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S.30*;7-G:60@(E1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N(@IM<V=S='(@(M3O(/#EY-_O(.'U]/P@X?#AZ?3EW_3A
MZ2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,#4Y"FUS9VED(")4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N(@IM<V=S='(@
M(M3O(/#EY-_O(.'U]/P@[/#O\>7?(.WA(-WWY>D@[/SM[R#AZMWQX>GO]?(N
M(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0P,`IM<V=I9"`B5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BXB"FUS9W-T<B`B(@HBP?7T_"#T[R#PY>3?[_4@[/#O\>7?(.WA(/#E\>G=
M]^7I(.S\[>\@X?'IZ.SO_?(@ZN'I(-SM^2#JW/3Y(/3EZ^7?X2`H.BDN(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`X.`IM<V=I9"`B5&AI<R!F
M:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RXB"FUS9W-T<B`B
MP?7T_"#T[R#PY>3?[R#L\._QY=\@[>$@\.7QZ=WWY>D@[/SM[R#OZO3AY.GJ
MW?(@].GLW?(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$Q-PIM
M<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,B"FUS9W-T<B`B(@HBP?7T_"#T[R#P
MY>3?[R#L\._QY=\@[>$@\.7QZ=WWY>D@[/SM[R#KW_/TX2#A\>GH[/[M(/?Y
M\>GS[-WM^>T@[.4@ZN7M_"#>("(*(N7KZ^?MZ>K\(.7Q^?3G[.'TZ>K\(@H*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.3@S"FUS9VED(")4:&ES(&9I
M96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N(@IM<V=S='(@(L'U]/P@].\@
M\.7DW^\@\/'=\.7I(.WA(.7?[>'I(-WMX?(@W>/J]?'O\B#A\>GH[/SR+B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(X,C0*;7-G:60@(B(*(E1H
M:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="
M($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("(*(B<C,3(S-&%F)RXB"FUS9W-T
M<B`B(@HBP?7T_"#T[R#PY>3?[R#P\=WPY>D@[>$@\.7QZ=WWY>D@ZOGDZ>K\
M(/?Q_NSA]._R(//E(%)'0B#DY>KAY>[AY.GJWB#L[_'VWBP@\"XB"B+W+B`G
M(S$R,S1A9B<N(@H*;7-G:60@(B(*(E1H:7,@9FEL92!C;VYT<F]L<R!T:&4@
M9VQO8F%L('-E="!O9B!-24U%(&1R:79E<G,@9F]R('1H92!(;W)D92!F<F%M
M97=O<FLL("(*(F%L;&]W:6YG(&%P<&QI8V%T:6]N<R!T;R!M86ME('5S92!O
M9B!P<F]G<F%M<R!S=6-H(&%S(&5N<V-R:7!T(&]R(&US=V]R9'9I97<@(@HB
M=&\@<F5N9&5R(&-O;G1E;G0@:6YT;R!(5$U,(&9O<B!V:65W:6YG(&EN(&$@
M8G)O=W-E<BXB"FUS9W-T<B`B(@HBP?7T_"#T[R#A\??EW^\@\.7QZ=WWY>D@
M]._U\B!-24U%(&1R:79E<G,@\._U(/?QY_/I[._P[^GO_>WTX>D@X?#\(/3G
M[2`B"B+U\.?QY?/?X2#E\.GT\=WP[^WTX?(@Y.G<]N_QX2#P\>_C\=SL[.'T
MX2#MX2#DZ>'WY>GQW^;O[?3AZ2#TX2#PY?'IY??\[.7MX2`B"B+T^>T@96UA
M:6P@ZN'I(.WA(/3A(.7L]N'MW^;O]>T@[.4@]._M(.KA]-SKZ^?K[R#T\?SP
M[RXB"@IM<V=I9"`B(@HB5&AI<R!F:6QE(&-O;G1R;VQS('1H92!S='EL97-H
M965T('1H870@:7,@=7-E9"!T;R!S970@8V]L;W)S(&%N9"!F;VYT<R!F;W(@
M(@HB=&AE($AO<F1E(&9R86UE=V]R:R!A;F0@86QL(&%P<&QI8V%T:6]N<R!T
M:&%T(&1O(&YO="!P<F]V:61E('1H96ER(&]W;B`B"B)S971T:6YG<RXB"FUS
M9W-T<B`B(@HBP?7T_"#T[R#A\??EW^\@Y>O=X_?EZ2#TZ?(@\?7H[-_SY>GR
M(/3Y[2#W\?GLW/3Y[2#JX>D@]/GM(./QX>SLX?3O\^7I\?[M(./IX2`B"B+\
MZ^$@].\@\/'\X_'A[.SA(/3O]2!(;W)D92P@ZN'I(./IX2#TZ?(@Y?;A\>SO
MX]WR(/#O]2#EW^WAZ2#EX^KA].7S].?LW>WE\B`B"B+SY2#A]?3\(.KAZ2#D
MY>T@\.'QW??O]>T@Y.GJW?(@]._U\B#E\.GK[^/=\B#CZ>$@X?7TW?(@].GR
M(/'UZ.S?\^7I\BXB"@IM<V=I9"`B(@HB5&AI<R!F:6QE(&UA<',@9FEL92!E
M>'1E;G-I;VYS('1O(&QO9VEC86P@34E-12!T>7!E<RP@96YA8FQI;F<@2&]R
M9&4@(@HB87!P;&EC871I;VYS('1O(&9I9W5R92!O=70@:&]W('1O(&AA;F1L
M92!S;VUE(&-O;G1E;G0@<W5C:"!A<R!E;6%I;"`B"B)A='1A8VAM96YT<R!O
M<B!#5E,@8VAE8VMO=71S+B(*;7-G<W1R("(B"B+!]?3\(/3O(.'Q]^7?[R#J
MX?3AX_'<]N7I(/3I\B#E\.7J]-SSY>GR(/3Y[2#T_?#Y[2#,R<S%+"#^\_3E
M(/3A(/#E\>GE]_SLY>WA("(*(N_QZ?/LW>WY[2!M86EL(.WA(.7L]N'MW^;O
M[?3AZ2#LY2#T[^T@ZN'TW.OKY^OO(/3Q_/#O+B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C4V,@IM<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+B(*;7-G<W1R("+!]?3>(.<@]OSQ[.$@W??EZ2#>
MY.<@Y?#E[N7QX^'SZ.7?+B(*"B,Z('1E;7!L871E<R]H96QP+V%B;W5T+FEN
M8SHQ"FUS9VED(")4:&ES(&ES("5S+B(*;7-G<W1R("+!]?3\(.7?[>'I("5S
M+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z-#,W"FUS9VED("(B
M"B)4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL("(*(F-L:65N="!T
M:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&
M;W(@82!L:7-T(&]F('-U8V@@96UA:6P@(@HB8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,B"FUS9W-T<B`B(@HBP?7T_"#EW^WAZ2!+;VQA8B!'<F]U<'=A<F4@
M;V)J96-T+B##Z>$@[>$@Y.7?].4@].\@X>WTZ>KEW^SE[>\@X?7T_"`B"B+W
M\>7IW.;E\^CE(-WMX2#P\?SC\>'L[.$@96UA:6P@\._U(.KA].'KX>+AW^WE
MZ2#A]?3>(/3G(.SO\?;>+B##Z>$@Z]_S].$@(@HB]-WT[^GY[2#P\>_C\>'L
M[-ST^>T@[/#O\>7?].4@[>$@Y?#I\^KE]>CEW_3E(/3O("5S(@H*;7-G:60@
M(B(*(E1H:7,@:7,@=&AE(&UA:6X@2&]R9&4@8V]N9FEG=7)A=&EO;B!F:6QE
M+B!)="!C;VYT86EN<R!P871H<R!A;F0@8F%S:6,@:71E;7,@(@HB=&AA="!A
M<'!L>2!T;R!T:&4@8V]R92!F<F%M97=O<FL@86YD(&%L;"!(;W)D92!A<'!L
M:6-A=&EO;G,N(@IM<V=S='(@(B(*(L'U]/P@Y=_MX>D@].\@XN'SZ>K\(.'Q
M]^7?[R#Q]>CLW_/E^>T@]._U(/#Q[^/QW.SLX?3O\B`G2&]R9&4G+B#0Y?'I
MW??EZ2#TX2`B"B+L[^WO\-STZ>$@ZN'I(/3A(.+A\^GJW"#LW?'G(/#O]2#W
M\>?SZ>SO\._I[_WM].'I(.'P_"#T[^T@\/7QWNWA(.KAZ2#TZ?(@(@HBY?;A
M\>SOX]WR(/3O]2#S]?/TWNSA]._R+B`B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+T-O;G1E;G1S+G!H<#HV,#<*;7-G:60@(E1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+B(*;7-G<W1R("(B"B+4[R#LWNWU[.$@X?7T_"#C\=SVZ.?JY2#L
MY2#J^>3IZN_SY>O?Y.$@*"5S*2#DZ>'V[_'E].GJWB#A\/P@].<@Y.GJWB#S
MX?(N(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,CD*;7-G
M:60@(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(*;7-G<W1R
M("+!]?3\\B#O(.'QZ>CL_/(@\/'=\.7I(.WA(.7?[>'I(/3O]>O<]^GS]._M
M(-WMX2XB"@IM<V=I9"`B(@HB5&AI<R!P<F]B;&5M(')E<&]R="!W87,@<F5C
M96EV960@9G)O;2`E<RX@5&AE('5S97(@8VQI8VME9"!T:&4@<')O8FQE;2`B
M"B)R97!O<G0@;&EN:R!F<F]M('1H92!F;VQL;W=I;F<@;&]C871I;VXZ)7,@
M86YD(&ES('5S:6YG('1H92!F;VQL;W=I;F<@(@HB8G)O=W-E<CHE<R(*;7-G
M<W1R("(B"B+4[R#P\?SBZ^?LX2#A]?3\(.'MX?;=\>CGZN4@X?#\("5S+B#/
M(/?QWO/TY_(@ZMSKY?/E(/3G[3QB<B\^X>WA]N_QW"`B"B+P\>_BZ][LX?3O
M\B#A\/P@].\@\.'QX>K<]/D@55),.CQB<B\^)7,@ZN'I(/?QY_/I[._P[^GE
MWR#T[^T@X>K\Z^_UZ.\@(@HB8G)O=W-E<CH\8G(O/B5S(@H*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+V=Z:7`N<&AP.C0X"FUS9VED(")4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RXB
M"FUS9W-T<B`BP?7T_/(@[R#E[O7PY_'E].?TWO(@Y.4@[/#O\>7?(.WA(.'P
M[_/U[/#IW?/EZ2!Z:7`@ZN'I(&=Z:7`@X?'WY=_A+B(*"B,Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]296=I<W1R>2YP:'`Z,30W"FUS9VED(")4:&ES('-Y
M<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N(@IM<V=S='(@(M3O(//]
M\_3G[.$@X?7T_"#=]^7I(.'PY>WE\>/O\._IY^CEWRXB"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-PIM<V=I9"`B5&AI<R!V86QU92!M
M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+!]?3>(.<@].GLWB#P\=WPY>D@
M[>$@Y=_MX>D@X?'IZ.S\\BXB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z,C(U"FUS9VED(")4:6-K971S(@IM<V=S='(@(L7I\^GTWO'IX2(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(T,3`*;7-G:60@(E1I;64B"FUS
M9W-T<B`BV?'A(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,Q,0IM
M<V=I9"`B5&EM92!4<F%C:VEN9R(*;7-G<W1R("+)]^WGZ^'T_NWTX?(@].?M
M(/[QX2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ-PIM<V=I9"`B5&EM92!F
M;W)M870B"FUS9W-T<B`BS._Q]MX@_O'A\B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(U,C$*;7-G:60@(E1I;64@<V5L96-T:6]N(@IM<V=S='(@
M(L7PZ>OOX]X@_O'A\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HR,S(@;&EB+T)L;V-K+VEF<F%M92YP:'`Z,C`*;7-G:60@
M(E1I=&QE(@IM<V=S='(@(M3?].OO\B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.38*;7-G:60@(E1I=&QE("AT;V]L=&EP
M*3HB"FUS9W-T<B`BU-_TZ^_R("A4;V]L=&EP*3HB"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C@P"FUS9VED(")4;R(*;7-G
M<W1R("+0\?SR(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C8R.0IM<V=I9"`B(@HB5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS9W-T<B`B(@HBP^GA(.WA(.KQ
MX?3>\^7TY2#P[^OKX?#KW"#A[?3IZN7?[.7MX2P@ZO'A]-[S].4@\.'TY^S<
M[>\@].\@0V]N=')O;"`H4$,I(-X@(@HB].\@0V]M;6%N9"`H36%C*2#PZ][J
M]/'O+"#E[?X@ZMSMY?3E(.KKZ>HN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C(S-PIM<V=I9"`B5&]D87DB"FUS9W-T<B`BT][LY?'A(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHR.`IM
M<V=I9"`B5&]G9VQE($A434P@4V]U<F-E(@IM<V=S='(@(L7MX>OKX>/>(//E
M(/#GX^'?[R!(5$U,(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(S.0IM<V=I9"`B5&]M;W)R;W<B"FUS9W-T<B`BP?WQZ>\B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@Q"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S<*;7-G
M:60@(E1O<"(*;7-G<W1R("+*[_'U]MXB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@9G)A;64@*%]T
M;W`I(@IM<V=S='(@(M#<[?D@\.OAW_/I[R`H7W1O<"DB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C,*;7-G:60@(E1R86YS;&%T:6]N<R(*;7-G<W1R
M("+,Y?3A]O'<\^7I\B(*"FUS9VED(")4<FEP;VQI<R!!:7)P;W)T(@IM<V=S
M='(@(L'E\>_KZ>S=[>'R(-3QW_#OZ^?R(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3<W-PIM<V=I9"`B5')U92!O<B!F86QS92(*;7-G<W1R("+!
MZ^?HW?(@WB#XY?7DW?(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N
M7V-A;&5N9&%R+FIS.C4W"FUS9VED(")4=2(*;7-G<W1R("+4\2(*"FUS9VED
M(")4>7!E(&UI<VUA=&-H+B(*;7-G<W1R("++X>WHX?/LW>WO\B#T_?#O\B#D
MY>3O[-WM^>TN(@H*(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(V,@IM<V=I
M9"`B5'EP92!Y;W5R(&-H;VEC93H@(@IM<V=S='(@(M#KY^KT\>_K[^/>\_3E
M(/3G[2#E\.GK[^/>(//A\CH@(@H*;7-G:60@(E523"(*;7-G<W1R("+'Z^7J
M]/'O[>GJWB#$Z>7]Z/7M\^<B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4V,0IM<V=I9"`B55),(&9O<B!Y;W5R('-C
M<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T(@IM<V=S='(@(B(*(L?KY>KT
M\>_MZ>K>(,3IY?WH]>WSYR#CZ>$@Y?#I\_3Q[_;>(.'MX?;O\=SR(.KA]-SS
M].'SY_(@]._U(/#Q[^/QW.SLX?3\\B#SX?(B"@IM<V=I9"`B55),.B(*;7-G
M<W1R("+'Z^7J]/'O[>GJWB#$Z>7]Z/7M\^<Z(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O9FEL92YP:'`Z,S8Q"FUS9VED(")5;F%B;&4@=&\@86-C97-S(%9&
M4R!D:7)E8W1O<GDN(@IM<V=S='(@(L'D_>WA].<@YR#P\?SSXN'SYR#S]._M
M(%9&4R#JX?3<Z^_C[RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`Z,3`P"FUS9VED(")5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+B(*;7-G<W1R("+!Y/WMX?3G(.<@
M\/'O\^C>ZN4@Y?#I\.O=[^T@\.OG\>_V[_'I_NT@ZN'TW"#TY^T@Y=_S[^3O
M(/3O]2#W\=[S].<N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS
M-#8*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@X>OKX>/>(.7N[_7S
MZ>_D[_3>\^7Y[2#CZ>$@].\@5D93(.'Q]^7?[R!<(B5S7"(N(@H*(SH@9G)A
M;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S,Q(&9R86UE=V]R:R]61E,O5D93
M+VUU<W%L+G!H<#HU,#(*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N(@IM<V=S='(@(L'D_>WA].<@YR#A
MZ^OAX]X@Y>[O]?/I[^3O]-[SY?GM(./IX2#T[R!61E,@X?'WY=_O("5S+R5S
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S`T"FUS9VED(")5
M;F%B;&4@=&\@8VAA;F=E('1O("5S+B(*;7-G<W1R("+!Y/WMX?3G(.<@X>OK
MX>/>(/3O]2`E<RXB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M,S<U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R("+$Y>T@Y=_MX>D@Y/7MX?3>(.<@\_WMY.7SYR#S].\@Y.GAZN_L
MZ?/TWB!344PN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.#@*
M;7-G:60@(E5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+B(*;7-G<W1R("+$
MY>T@Y=_MX>D@Y/7MX?3>(.<@\_WMY.7SYR#LY2!34TPN(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O9FEL92YP:'`Z,3<Q(&9R86UE=V]R:R]61E,O5D93+V9I
M;&4N<&AP.C$W-@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M,3DV(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR,#$*(SH@9G)A
M;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C(P.0IM<V=I9"`B56YA8FQE
M('1O(&-O<'D@5D93(&9I;&4N(@IM<V=S='(@(L'D_>WA].<@YR#A[?3IX_'A
M]MX@5D93(.'Q]^7?[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HS,C`*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<
M(B5S7"(N(@IM<V=S='(@(L'D_>WA].<@YR#DY^SI[_7QX]_A(.KA].'K_./O
M]2!61E,@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C(Y-B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,C<S"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HR-CD*;7-G:60@(E5N86)L92!T
M;R!C<F5A=&4@5D93(&1I<F5C=&]R>2XB"FUS9W-T<B`BP>3][>'TYR#G(.3G
M[.GO]?'CW^$@ZN'TX>O\X^_U(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]M=7-Q;"YP:'`Z,3(V"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2!61E,@X?'WY=_O
M]2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,3,*;7-G:60@
M(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N(@IM<V=S='(@(L'D
M_>WA].<@YR#DY^SI[_7QX]_A(.KE[>_](%9&4R#A\??EW^_U+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]T87(N<&AP.C<Y"B,Z(&9R86UE
M=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP+G!H<#HX,@IM<V=I9"`B56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82XB"FUS9W-T<B`BP>3][>'TYR#G(.'P
M[_/U[/#?Y?/G(.3EY._LW>WY[2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C(T.0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H
M92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R("+!Y/WMX?3G(.<@
MY.GAX_'A]MX@7"(E<UPB+"#O(/;<ZN7K[_(@Y.7M(.7?[>'I(.KE[?SR+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(W,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,R,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S,U(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-C$*
M;7-G:60@(E5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@
M;F]T(&5M<'1Y(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB`E<RP@[R#V
MW.KEZ^_R(.3E[2#EW^WAZ2#JY>W\\B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z
M-SD@861M:6XO<&5R;7,O9&5L971E+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O
M(&1E;&5T92`G)7,G.B`E<RXB"FUS9W-T<B`BP>3][>'TYR#G(.3IX>/QX?;>
M("<E<R<Z("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HS-S<@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,X,0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY
M+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@ZN'TX>O\X^_U(%9&4R#E
M\.'MX>OLXN'M_.SE[>$@*')E8W5R<VEV96QY*2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN
M<&AP.C,T.`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S8Q(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-CD*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,W,PIM<V=I9"`B56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!Y/WMX?3G(.<@Y.GAX_'A]MX@
MZN'TX>O\X^_U(%9&4RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C,T."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C,V,`IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`B1&%S
M(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C:'0@=V5R9&5N
M.B`E<RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$W.0IM<V=I
M9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@
M(L'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@5D93(.'Q]^7?[_4@7"(E<UPB+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(T,R!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C(Q,PHC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3<S(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ.#8*(SH@
M9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$Y,R!F<F%M97=O<FLO5D93
M+U9&4R]S<6Q?9FEL92YP:'`Z-#$Q"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q
M;%]F:6QE+G!H<#HT,3D*;7-G:60@(E5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4N(@IM<V=S='(@(L'D_>WA].<@YR#DZ>'C\>'VWB#T[_4@5D93(.'Q]^7?
M[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HS,S<*;7-G:60@
M(E5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T
M<B`BP>3][>'TYR#G(.3IX>/QX?;>(%9&4R#E\.'MX>OA[.+A[?SLY>WA("AR
M96-U<G-I=F5L>2DZ("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z-S4R"FUS9VED(")5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER
M96-T;W)Y+B(*;7-G<W1R("+$Y2#L\._Q_B#MX2#P\>_SY.GO\=_S^2#T[^T@
M]/'=]^_M].$@ZN'TW.OOX^\N(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HV,C<*;7-G:60@(E5N86)L92!T;R!E>'1R86-T(&-E<G1I
M9FEC871E(&1E=&%I;',B"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y>[<X_D@\.OG
M\>_V[_'?Y?(@\.GS]._P[^GG].GJ[_TB"@HC.B!F<F%M97=O<FLO3F5T7TE-
M4U`O24U34"YP:'`Z-#8P(&9R86UE=V]R:R].971?24U34"])35-0+T%U=&@N
M<&AP.C$Q.0IM<V=I9"`B56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@
M;V8@)7,N(@IM<V=S='(@(L'D_>WA].<@YR#V_/'T^?/G(._QZ?/L[_T@]._U
M("5S+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$T,"!F<F%M
M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ-#4*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$V-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,38Y"FUS9VED(")5;F%B;&4@=&\@;6]V92!61E,@9FEL92XB"FUS
M9W-T<B`BP>3][>'TYR#G(.SE].'JW^WG\^<@]._U(%9&4R#A\???[_4N(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW.0IM<V=I9"`B56YA8FQE
M('1O(&]P96X@5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R("+!Y/WMX?3O(/3O
M(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HR,C`@9G)A;65W;W)K+U9&4R]61E,O<W%L
M7V9I;&4N<&AP.C$R-PHC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP
M:'`Z,3,P"FUS9VED(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RXB"FUS9W-T<B`BP>3][>'T[R#T[R#<[>_IX^SA(/3O]2!61E,@X?'W
MY=_O]2#CZ>$@X_'<^.GL[RXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE
M+G!H<#HW-"!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S,*;7-G
M:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R("+!Y/WMX?3O
M(/3O(-SM[^GC[.$@]._U(%9&4R#A\??EW^_U+B(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-#<*;7-G:60@(E5N86)L92!T;R!O
M<&5N(&-O;7!R97-S960@87)C:&EV92XB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@
MX>WOW^[Y(/3O(//U[/#IY?/LW>WO(.'Q]^7?[RXB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F:6QE+G!H<#HV,C,*;7-G:60@(E5N86)L92!T;R!R96%D('1H
M92!V9G-R;V]T(&1I<F5C=&]R>2XB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@Y.GA
MXMSS^2#T[^T@ZOWQZ>\@ZN'TW.OOX^\@5D93("AV9G-R;V]T*2XB"@IM<V=I
M9"`B56YA8FQE('1O(')E9VES=&5R('!R969E<F5N8V5S(&EN('-E<W-I;VXN
M(@IM<V=S='(@(L3E[2#EW^WAZ2#D]>WA]/SM(.WA(.KA].'W^?'GZ._][2#O
MZ2#P\>_TZ>S>\^7I\B#CZ>$@X?7TWB#TY^T@\_WMY.7SYRXB"@HC.B!F<F%M
M97=O<FLO2V]L86(O2V]L86(N<&AP.C$P.34*;7-G:60@(E5N86)L92!T;R!R
M96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X
M:7-T<R(*;7-G<W1R("+!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U("5S(//E
M("5S.B#O(/;<ZN7KZ^_R(/7PW/'WY>D@WN3G(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<W%L7V9I;&4N<&AP.C,Q-0IM<V=I9"`B56YA8FQE('1O(')E;F%M
M92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R("+!Y/WMX?3G(.<@[.7T[^WO[.'S
MW^$@]._U(%9&4R#JX?3AZ_SC[_4N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M<W%L+G!H<#HR-34*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C
M=&]R>3H@)7,N(@IM<V=S='(@(L'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@
M5D93(.KA].'K_./O]3H@)7,N(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P
M+G!H<#HR.38*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4@7"(E
M<UPB+B(*;7-G<W1R("+!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A
M\??EW^_U(%PB)7-<(BXB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HU-C0@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C(T,0IM<V=I9"`B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB"FUS9W-T<B`BP>3]
M[>'TYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@X?'WY=_O]2`E<R\E<RXB"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C(T.2!F<F%M97=O<FLO5D93
M+U9&4R]M=7-Q;"YP:'`Z,C(R"B,Z(&9R86UE=V]R:R]61E,O5D93+VUU<W%L
M+G!H<#HT.#4@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,P-`HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,S(V"FUS9VED(")5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(*;7-G<W1R("+!Y/WMX?3G(.<@
M[.7T[^WO[.'SW^$@]._U(%9&4R#A\??EW^_U+B(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,0IM<V=I9"`B
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N(@IM<V=S='(@(L'D_>WA].<@YR#E
MZO3=Z^7SYR#T[_4@7")M:VES;V9S7"(N(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;7-W;W)D+G!H<#HV,@IM<V=I9"`B56YA8FQE('1O('1R
M86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BQ.7M(.SP_/'E
M\^4@[>$@[.7TX?;QX?/TY=\@X?7T_"#T[R#=X^/QX?;O(%=O<F0B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C$R-R!F<F%M97=O<FLO5D93+U9&
M4R]F='`N<&AP.C$S,`IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M(%PB)7-<(BXB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@X_'<^/D@\_3O(%9&4R#A
M\??EW^\@7"(E<UPB+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C$R,0IM<V=I9"`B56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@
M9F%I;&5D*2XB"FUS9W-T<B`BQ.4@[/#O\?X@[>$@X_'<^.<@\_3O(%9&4R#A
M\??EW^\@*&-O<'DH*2#A\-WT]??E*2XB"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,C0@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP
M.C$S-`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,3,Y"FUS
M9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS9W-T<B`B
MQ.4@[/#O\?X@[>$@X_'<^/D@Y.7D[^S=[>$@]._U(%9&4R#A\??EW^_U+B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`*
M;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("+5\._C\>'L[.GS[-WMX2(*"B,Z
M('1E;7!L871E<R]P<F5F<R]E;F0N:6YC.C8*;7-G:60@(E5N9&\@0VAA;F=E
M<R(*;7-G<W1R("+!ZOWQ^?/G(,'KZ^'C_NTB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,S"FUS9VED(")5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;B(*;7-G<W1R("+!ZO7Q_NWEZ2#TYR#TY>OE]?3AW^$@
M\^'R(.7MW?'CY>GA(@H*;7-G:60@(E5N97AP96-T960@96YD(&]F(&9I;&4N
M(@IM<V=S='(@(LSG(.'MX>SE[?SLY>WO(/3=Z^_R(/3O]2#A\??EW^_U+B(*
M"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(S,`HC
M.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3D*;7-G
M:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C
M=&EO;CH@(@IM<V=S='(@(LSG(.'MX>SE[?SLY>WG(.'PW.WTY_/G(.'P_"#T
M[^T@Y>[U\.?QY?3G]-X@\_3G(//][>3E\^<Z("(*"B,Z(&9R86UE=V]R:R])
M34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R-@HC.B!F<F%M97=O<FLO24U!
M4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-3`*(SH@9G)A;65W;W)K+TE-05`O
M24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@W"B,Z(&9R86UE=V]R:R])34%0+TE-
M05`O04-,+W)F8S(P.#8N<&AP.C,Y,PIM<V=I9"`B56YE>'!E8W1E9"!R97-P
M;VYS92!F<F]M('-E<G9E<B!T;SH@(@IM<V=S='(@(LSG(.'MX>SE[?SLY>WG
M(.'PW.WTY_/G(.'P_"#T[^T@Y>[U\.?QY?3G]-X@\_3O.B`B"@HC.B!F<F%M
M97=O<FLO4')E9G,O4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HU.`HC.B!T
M96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHV-`IM<V=I
M9"`B56YF:6QE9"(*;7-G<W1R("+,YR#!\??EZ>_HY?3G[-WM[R(*"B,Z(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEC86QE;F1A<BYP:'`Z,S@T"FUS
M9VED(")5;FAA;F1L960@8V]M<&]N96YT(&]F('1Y<&4Z("5S(@IM<V=S='(@
M(LSG(/?EZ?'IYOSLY>WO(//T[^GWY=_O(/3]\._U.B`E<R(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HU-2!L:6(O0FQO8VLO;65T87(N<&AP
M.C8Y"FUS9VED(")5;FET<R(*;7-G<W1R("+,[^W<Y.7R(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$U(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q-@IM<V=I9"`B56YK;F]W;B(*;7-G<W1R("+!X^WY
M\_3O(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T
M<"YP:'`Z,S`W"FUS9VED(")5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G
M92!)1"DN(@IM<V=S='(@(E5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H
M='1P+G!H<#HS,#@*;7-G:60@(E5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2XB"FUS9W-T<B`B56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT
M($UE<W-A9V4@240I+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C,P,`IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O
M<B!P87-S=V]R9"XB"FUS9W-T<B`BP>/M^?/T[R#\[>_LX2#W\=[S].<@WB#J
M^>3IZOSR+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHU-PIM<V=I9"`B56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0B"FUS9W-T<B`BP?#O\_WMY.7SYR#T\=WW[^WT[_(@\_3OZ??EW^_U
M(@H*(SH@9G)A;65W;W)K+TED96YT:71Y+TED96YT:71Y+G!H<#HR.3@*;7-G
M:60@(E5N;F%M960B"FUS9W-T<B`BP>W^[?7L[R(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-3D*;7-G:60@(B(*(E5N<')I
M=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@
M<')O9W)A;6%T:6-A;&QY(&9O<B`B"B)S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@(@HB<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A
M8V-E<W,@=&AE(&-L:7!B;V%R9"XB"FUS9W-T<B`B(@HBS.<@Y>[O]?/I[^3O
M].?LW>WA(/#Q[^/QW.SLX?3A(.3E(.SP[_'O_>T@[>$@W??O]>T@\/'\\^+A
M\^<@\^4@Z^7I]._U\>/?Y?(@(@HBX?#OZN_PWO(OX>WTZ>/QX?;>\B_E\.GJ
M_.OG\^?R(./IX2#K_./O]?(@X?/VX>OEW^'R+B#0X?3>\_3E(,_*(./IX2#M
MX2#DY=_TY2`B"B+TY??MZ>K=\B#SY^SEZ?[SY>GR(//T[R!M;WII;&QA+F]R
M9R#P[_4@\^'R(.3EW_?M[_7M(/#Y\B#MX2#E\.GT\=WXY?3E(//E("(*(O#Q
M[^/QW.SLX?3A(/3G(/#Q_//BX?/G(//T[R!C;&EP8F]A<F0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@R"FUS
M9VED(")5;G-E="!C;VQO<B(*;7-G<W1R("+,YR#O\>GS[-WM[R#W\?[LX2(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$P(&9R86UE
M=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.34R"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z.34X"FUS9VED(")5;G-U<'!O<G1E9"!%
M>'1E;G-I;VXB"FUS9W-T<B`BS.<@]?#O\_3G\>GF_.SE[><@Y?#=ZO3A\^<B
M"@HC.B!A9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#8@9G)A;65W;W)K+U!E<FUS
M+U!E<FUS+U5)+G!H<#HQ.3$*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S8*;7-G:60@(E5P9&%T92(*;7-G<W1R("+%[>?LW?'Y\^<B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C,Q"FUS9VED(")5
M<&1A=&4@)7,B"FUS9W-T<B`BQ>WG[-WQ^?/G("5S(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O:6-A;&5N9&%R+G!H<#HV-#@*;7-G:60@(E5P
M9&%T92!R97-P;VYD96YT('-T871U<R(*;7-G<W1R("+%[>?LW?'Y\^<@ZN'T
MW//TX?/G\B#A\.'M].?LW>WO]2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R
M+W5P9&%T92YI;F,Z-#,*;7-G:60@(E5P9&%T92!U<V5R(@IM<V=S='(@(L7M
MY^S=\?GSYR#W\=[S].<B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$S-R!A9&UI
M;B]P97)M<R]E9&ET+G!H<#HR,3<@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP
M.C(S,`IM<V=I9"`B57!D871E9"`G)7,G+B(*;7-G<W1R("(G)7,G(,7MY^SE
M\?[HY^KE+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C@Q"FUS9VED
M(")5<&=R861E('-C<FEP="!D96QE=&5D+B(*;7-G<W1R("+4[R#P\?SC\>'L
M[.$@X>WAXMSH[.GSY_(@Y.GAX_'<]N?JY2XB"@HC.B!A9&UI;B]S971U<"]I
M;F1E>"YP:'`Z,3<R(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL
M+G!H<#HQ.#(*;7-G:60@(E5P;&]A9"(*;7-G<W1R("+!\._S]._KWB(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ.#`*;7-G:60@(E5P;&]A9&5D(&%L
M;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(*;7-G
M<W1R("+!\._S]._KWB#\Z_GM(/3Y[2#A\??EW_GM(/'UZ.S?\^7Y[2#S]._M
M(.7N]?#G\>7TY_3>+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE
M='1E<G,B"FUS9W-T<B`BRN7VX>OAW^$@Z^'TZ>WIZMP@X_'<[.SA].$B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG
M+FIS.C$X"FUS9VED(")5<'!E<B!R;VUA;B!N=6UB97)S(@IM<V=S='(@(M'Y
M[.'ZZN_?(.'QZ>CL[]\MRN7VX>OAW^$B"@HC.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O0V%T96=O<GE-86YA9V5R+G!H<#HT-@IM<V=I9"`B57-E($-U<G)E
M;G0Z("5S(@IM<V=S='(@(M?QWO/G(/3QW??O[?3O\CH@)7,B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4U.`IM<V=I
M9"`B57-E(%-33"(*;7-G<W1R("+7\=[SYR!34TPB"@IM<V=I9"`B57-E($1E
M9F%U;'0@5F%L=64B"FUS9W-T<B`BS>$@]_'G\^GL[_#OZ>?HY=\@YR#P\>_E
M\.GKY>/LW>WG(/3I[-XB"@IM<V=I9"`B57-E(&EF(&YA;64O<&%S<W=O<F0@
M:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BXB"FUS9W-T<B`BU_'G\^GL
M[_#OZ>7?].'I(.'M(/3O(/SM[^SA+^KYY.GJ_/(@Y=_MX>D@Y.GA]N_QY?3I
MZMPN(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+U)E9VES=')Y+G!H<#HV
M-3$*;7-G:60@(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+B(*
M;7-G<W1R("+/(/?QWO/TY_(@)7,@Y.7M(.7?[>'I(.7N[_7SZ>_D[_3G[-WM
M[_(@X^GA("5S+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C(P-`IM<V=I9"`B57-E
M<B!!9&UI;FES=')A=&EO;B(*;7-G<W1R("+$Z>'WY=_QZ?/G(-?QY_/T_NTB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C(U,0IM<V=I9"`B
M57-E<B!/<'1I;VYS(@IM<V=S='(@(L7PZ>OOX]WR(-?QWO/TYR(*"B,Z('-I
M9VYU<"YP:'`Z-C0*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N(@IM<V=S='(@
M(L7CX_'A]MX@U_'>\_3G(@H*(SH@<VEG;G5P+G!H<#HQ.0IM<V=I9"`B57-E
M<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET
M92XB"FUS9W-T<B`BQR#EX^/QX?;>(/?QWO/TYR#=]^7I(.'PY>WE\>/O\._I
MY^CEWR#CZ2<@X?7T_"#T[R!S:71E+B(*"FUS9VED(")5<V5R('!A<W-W;W)D
M(&-H86YG92(*;7-G<W1R("+!Z^OAX]X@ZOGDZ>KO_2#W\=[S].<B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ-S(@9G)A;65W;W)K+U!E<FUS+U!E<FUS
M+U5)+G!H<#HR-30*;7-G:60@(E5S97(@<&5R;6ES<VEO;G,B"FUS9W-T<B`B
MQ>[O]?/I[^3O]-[SY>GR(-?QWO/TYR(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(P,B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HS,PHC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C8U
M('1E;7!L871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C$Q"FUS9VED(")5
M<V5R;F%M92(*;7-G<W1R("*\[>_LX2#7\=[S].<B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+U-I9VYU<"YP:'`Z,3,Q"FUS9VED(")5<V5R;F%M92`G)7,G
M(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R("+4[R#\[>_LX2#W\=[S].<@)R5S
M)R#U\-SQ]^7I(-[DYRXB"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.#<*;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("*\[>_LX2#7\=[S].<Z
M(@H*(SH@=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z.`IM<V=I9"`B57-E
M<FYA;64Z("(*;7-G<W1R("*\[>_LX2#7\=[S].<Z("(*"B,Z(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z,C(W"FUS9VED(")5<V5R<R(*;7-G<W1R
M("+7\=[S].7R(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES="YI;F,Z
M-`IM<V=I9"`B57-E<G,@:6X@=&AE('-Y<W1E;3HB"FUS9W-T<B`BU_'>\_3E
M\B#S].\@T_WS].?LX3HB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H
M<#HQ,3`@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C`S"FUS9VED(")6
M1E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+B(*;7-G<W1R("+/(.KA]-SK
M[^/O\B!61E,@Y.7M(/7PW/'WY>DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H
M<"YD:7-T.C,X,PIM<V=I9"`B5F%C871I;VXB"FUS9W-T<B`BQ.GAZN_PW?(B
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX-C`*;7-G:60@(E9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`BN./J]?'E\B#T
M[_#OZ.7SW^7R(/#O]2#B\=WHY^KA[2#S]>SPY?'IZ^'LXMSM[^WTX>DZ("(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C8R"FUS9VED
M(")686QI9&ET>2(*;7-G<W1R("+%X^KU\?STY_3A(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,C$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C8S"FUS9VED
M(")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(*;7-G<W1R("+4Z>S>(//E
M(.OE\/3<(.'P_"#T_O'A+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,C<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(T.0HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,CDW(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(Y,38*;7-G:60@(E9A;'5E<R(*;7-G<W1R("+4Z>S=\B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(P.3(@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C$V.0IM<V=I9"`B5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@
M(L3^\_3E(/3I[-WR(./IX2#MX2#E\.GKW>[Y(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$Y,PIM<V=I9"`B5F%R:6%B;&4B"FUS9W-T<B`B
MS.7TX>+KY_3>(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,C@*;7-G:60@(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A
M9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(*;7-G<W1R("+'(.7P
MZ>+EXN'?^?/G(.'PW?3U]^4@+2#A]?3\(/3O(.S>[?7LX2#L\._QY=\@[>$@
MW.OKX>[E(.SE+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-S(T"FUS9VED(")697)S:6]N(@IM<V=S='(@(KCJY._SYR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,#`*;7-G:60@(E9E<G-I;VX@0V]N
M=')O;"(*;7-G<W1R("*XZ^7C]^_R(+CJY._SY_(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED(")6
M97)T:6-A;"!A;&EG;B(*;7-G<W1R("+*W.CE].<@Q?7H]>/QW.SLZ?/G(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX-`IM
M<V=I9"`B5F5R=&EC86P@<&%D9&EN9R(*;7-G<W1R("+*W.CE].\@X]WLZ?/L
MX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M.#,*;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("+*W.CE].$Z(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,@IM<V=I9"`B5F5R>2!(:6=H
M(@IM<V=S='(@(M#OZ_T@^.?KWB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.CDY,@IM<V=I9"`B5FEE=R`E<R(*;7-G<W1R("+%[/;<
M[>GSYR`E<R(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I
M97<@86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`BQ>SVW.WI\^<@Y>[Y
M].7QZ>K>\B#I\_3O\^7KW^3A\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M0V]N=&5N=',N<&AP.C@T-0IM<V=I9"`B5FEE=R!A<R`E<R(*;7-G<W1R("+%
M[/;<[>GSYR#SX>T@)7,B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]I8V%L96YD87(N<&AP.C<Y"FUS9VED(")6:65W(&5V96YT(@IM<V=S='(@
M(L7L]MSMZ?/G(./EX^_M_/3O\B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VEC86QE;F1A<BYP:'`Z,3`Y"FUS9VED(")6:65W('1A<VLB"FUS
M9W-T<B`BQ>SVW.WI\^<@Y?'CX?/?X?(B"@HC.B!L:6(O0FQO8VLO;65T87(N
M<&AP.C(P-PIM<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("+/\>'T_/3G].$B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C`W"FUS9VED(")6
M:7-I8FEL:71Y.B`B"FUS9W-T<B`BS_'A]/STY_3A.B(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@Q"FUS9VED
M(")6;V1A9F]N92!)=&%L>2!V:6$@4TU44"(*;7-G<W1R(")6;V1A9F]N92#)
M].'KW^'R(.S=\_D@4TU44"(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO
M3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,SD*;7-G:60@(E=!
M4DXB"FUS9W-T<B`BT-'/T\_7QR(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C@S"FUS9VED(")705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,
M3%D@1E)/32`E<RXB"FUS9W-T<B`BT-'/T\_7QR$A(2#!UL')T<73U,4@U,\@
MT-'/P]'!S,S!(,S/S<_)(-/!TR#!T,\@)7,N(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS
M,0IM<V=I9"`B5V%R;FEN9R(*;7-G<W1R("+0\>_EZ>3O\._?Y_/G(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHU.`IM<V=I
M9"`B5V4B"FUS9W-T<B`BU.4B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C,W"FUS9VED(")7965K;'DB"FUS9W-T<B`BQ>+D
M[^SAY.GAW^$B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR.`IM
M<V=I9"`B5V5L8V]M92(*;7-G<W1R("+*X>OY\][KZ.'TY2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C0@=&5M<&QA=&5S+VQO9VEN+VQO9VEN
M+FEN8SHU,`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+*X>OY\][K
MZ.'TY2#S].\@)7,B"@HC.B!S97)V:6-E<R]P;W)T86PO;6]B:6QE+G!H<#HR
M.2!T96UP;&%T97,O<&]R=&%L+VUE;G4N:6YC.C(*;7-G:60@(E=E;&-O;64L
M("5S(@IM<V=S='(@(LKAZ_GSWNOHX?3E+"`E<R(*"B,Z(&-O;F9I9R]P<F5F
M<RYP:'`N9&ES=#HT,C$*;7-G:60@(E=H870@87!P;&EC871I;VX@<VAO=6QD
M("5S(&1I<W!L87D@869T97(@;&]G:6X_(@IM<V=S='(@(M#OZ=P@Y?;A\>SO
MX]X@Z.$@Y>SVX>S?YN7I(/3O("5S(.'V[_T@\_7MY.7HY=_TY2#S].?M(/7P
MY_'E\]_A.R(*"FUS9VED(")7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"!(;W)D
M92!D:7-P;&%Y(&%F=&5R(&QO9VEN/R(*;7-G<W1R("+0[^GA(.7VX?'L[^/>
M(.WA(.7L]N'MW^;E].'I(.'V[_T@\_7MY.7HY=_TY2#S].?M(/7PY_'E\]_A
M.R(*"B,Z('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C(Q"FUS9VED(")7
M:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/R(*;7-G<W1R("+0[^G\
M\B#EW^WAZ2#O(.3IX??Y\>GS].GJ_/(@]^'QX>KTWO'A\CLB"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR-`IM<V=I9"`B5VAA="!I<R!T:&4@
M<75O=&4@8VAA<F%C=&5R/R(*;7-G<W1R("+0[^G\\B#EW^WAZ2#O(/?A\>'J
M]-[QX?(@Y>GSX>/YX^GJ_NT[(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(S
M"FUS9VED(")7:&EC:"!P:&%S97,B"FUS9W-T<B`BT._IW?(@UMSSY>GR(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,0IM<V=I9"`B5VAI8V@@<&QU
M9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+B(*;7-G
M<W1R("(B"B+*X>CO\=_S].4@\._IW"#P\?SSZ.7TX2#HX2#E[>7QX^_P[^GG
MZ._][2#S]._M(.7PY>[E\>/A\_3>(.7L\.OO]?3I\^S=[>_U("(*(NKEZ>S=
M[>_U+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z.#0*;7-G:60@(E=I9'1H(@IM<V=S='(@(M#KW/3O\B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,#D*;7-G:60@(E=I9'1H(&EN
M($-34R!U;FET<R(*;7-G<W1R("+0Z]ST[_(@\^4@[._MW.3E\B!#4U,B"@HC
M.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0Q"FUS9VED(")7:61T:"!O9B!T
M:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@
M;&]G+6EN*3HB"FUS9W-T<B`BT.O<]._R(/3O]2`E<R#LY>WO_2#S].$@X?'I
M\_3E\=P@*.CA(.7VX?'L[_/HY=\@\_3G[2#E\/SLY>WG(.7?\^_D[RDZ(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,#8*
M;7-G:60@(E=I9'1H(&]F('1H92!T86)L92(*;7-G<W1R("+0Z]ST[_(@]._U
M(/#?[>'JX2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(LSO[=SDX2#P
MZ]ST[_7R(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#4*;7-G:60@(E=I9'1H.B(*;7-G<W1R("+0Z]ST[_(Z(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW.`IM<V=I9"`B5VEN9"!S<&5E9"!I;B!K
M;F]T<R(*;7-G<W1R("*X[?3A\^<@X>W=[._U(//E(.K\[.+O]?(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C$U-`IM<V=I9"`B5VEN9#HB"FUS9W-T<B`B
MP>WE[._R.B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ.3$*
M;7-G:60@(E=I;F0Z("(*;7-G<W1R("+![>7L[_(Z("(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-`IM<V=I9"`B5VES9&]M(@IM<V=S='(@(M/O]M_A
M(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W-PIM<V=I9"`B5VES
M:&QI<W1S(@IM<V=S='(@(LO?\_3A(.7PZ>CU[.G^[2(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HV-0IM<V=I9"`B5V]R:R(*;7-G<W1R("+%\>/A\]_A
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R
M-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,38W
M"FUS9VED(")7;W)K($%D9')E<W,B"FUS9W-T<B`BQ.GE_>CU[?/G(,7QX^'S
MW^'R(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Y-0IM<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+4Y^O=]OGM[R#%\>/A
M\]_A\B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*;7-G:60@
M(E@M4F5F(@IM<V=S='(@(E@M4F5F(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HV,3<*;7-G:60@(E@U,#EV,R!"87-I8R!#;VYS=')A
M:6YT<R(*;7-G<W1R(")8-3`Y=C,@PN'SZ>KOWR#0Y?'I[_'I\^SOWR(*"B,Z
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$V"FUS9VED(")8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E(@IM<V=S='(@(E@U,#EV,R#7\=[S
MYR#E\.7J].'LW>WO]2#JZ^7IY.GO_2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-C$X"FUS9VED(")8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE(@IM<V=S='(@(E@U,#EV,R#%[>'KX>KTZ>K\(+SM[^SA
M(,C=[.'T[_(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP
M.C8Q.0IM<V=I9"`B6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(B"FUS
M9W-T<B`B6#4P.78S(,'MX>/M^?'I\_3IZOP@RNOEZ>3?(,C=[.'T[_(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C<P-@IM<V=I9"`B
M6#4P.78S(&5X=&5N<VEO;G,B"FUS9W-T<B`B6#4P.78S(,7PY>KTW//EZ?(B
M"@HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T
M82]D871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T
M96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B
MQ<4B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z
M,S@V"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT
M,C<*;7-G:60@(EE965DB"FUS9W-T<B`BQ<7%Q2(*"B,Z(&9R86UE=V]R:R]-
M86EN=&5N86YC92]-86EN=&5N86YC92YP:'`Z,S4*;7-G:60@(EEE87)L>2(*
M;7-G<W1R("+%]-[SZ>$B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z.#@X"FUS9VED(")997,B"FUS9W-T<B`BS>'?(@H*(SH@
M=&5M<&QA=&5S+VUA:6YT96YA;F-E+V%G<F5E;65N=%]B;W1T;VTN:6YC.C8*
M;7-G:60@(EEE<RP@22!!9W)E92(*;7-G<W1R("+-X>DL(-/U[/;Y[?XB"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4R"FUS
M9VED(")9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T
M;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RXB"FUS9W-T<B`B(@HBQ=_S
M].4@\^4@ZN'TW//TX?/G(,K%R<S%S<_5+B#7\>?SZ>SO\._IY=_S].4@].\@
M6SP^72#PZ][J]/'O(./IX2#MX2`B"B+E\.GS]/'=^.7TY2#SY2#JX?3<\_3A
M\^<@5UE325=)1RXB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$S
M,C`*;7-G:60@(EEO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N(@IM<V=S='(@
M(L3E[2#=]^7TY2#A]>CE[?3IZN_P[^GGZ.7?+B(*"B,Z(&9R86UE=V]R:R])
M9&5N=&ET>2])9&5N=&ET>2YP:'`Z,S`T"FUS9VED(")9;W4@8V%N(&YO="!H
M879E('1H92`G7%PG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92XB"FUS
M9W-T<B`BQ.7M(.7PZ?3QW?#E].'I(.WA(-WWY?3E(/3O(/?A\>'J]-[QX2`G
M7%PG(//T[R"\[>_LW"#SX?(N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@S."!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.34X"FUS9VED(")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(@IM<V=S
M='(@(L3E(.3^\^'TY2#=X^/U\><@Y.GE_>CU[?/G(&5M86EL+B(*"B,Z(&9R
M86UE=V]R:R]$871A+T1A=&$N<&AP.C(W-`IM<V=I9"`B(@HB66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R`B"B)I;B`E<RXB"FUS9W-T<B`B(@HB
MQ.7M(.'M].GS]._I]]_SX?3E(.KA[=WMX2#PY>3?[R#A\/P@].\@X?'WY=_O
M(.7I\^'C^>/>\B#SY2#A[?3?\_3OZ??A(/#EY-_A("(*(O/T[R`E<RXB"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY-#0*;7-G:60@(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB"FUS9W-T<B`BN/?E].4@X?#O\_7MY.7HY=\N
M(@H*;7-G:60@(EEO=2!H879E(&)E96X@;&]G9V5D(&]U="X\8G(@+SY4:&%N
M:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN(@IM<V=S='(@(KCWY?3E(.'P
M[_/U[>3EZ.7?+CQB<B`O/L7U]^'QZ?/T[_WLY2#P[_4@]_'G\^GL[_#OZ=[S
MX?3E(/3G[2#U\.?QY?/?X2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,3<Y"FUS9VED(")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E
M+B(*;7-G<W1R("+0\=WPY>D@[>$@Y/[SY?3E(.SIX2#=X^KU\><@].GLWBXB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,S@*;7-G:60@
M(EEO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N(@IM<V=S='(@(M#QW?#EZ2#MX2#Q]>CLW_/E].4@].\@1&%T
M851R964@X^GA(.WA(/?QY_/I[._P[^GEW_3E(%-I9VYU<',N(@H*(SH@9G)A
M;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-#<*;7-G:60@(EEO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("+0\=WPY>D@[>$@\?7H
M[-_SY?3E(/3O(%9&4RU"86-K96YD+B(*"B,Z('1E;7!L871E<R]P<F]B;&5M
M+W!R;V)L96TN:6YC.C$Q"FUS9VED(")9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="XB"FUS9W-T<B`BT/'=\.7I(.WA(/#E\>GC\=SXY?3E(/3O(/#Q_.+KY^SA
M(/#QZ>T@\_3EW^OE].4@X>WA]N_QW"#CZ>$@X?7T_"XB"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDX"FUS9VED(")9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\B
M"FUS9W-T<B`BT/'=\.7I(.WA(//U[/#KY_'^\^7TY2#T[R!54DP@\._U(.3E
MW_?MY>D@X?7TWB#G(//][>3E\^<B"@HC.B!S97)V:6-E<R]P;W)T86PO<G!C
M<W5M+G!H<#HX,`IM<V=I9"`B66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T
M;R!B92!D96QE=&5D+B(*;7-G<W1R("+0\=WPY>D@[>$@Y?#IZ]WNY?3E(/3O
M[2#E[O7PY_'E].?TWB#CZ>$@Y.GAX_'A]MXN(@H*(SH@861M:6XO=7-E<BYP
M:'`Z,3$Y"FUS9VED(")9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@
M8VQE87(@;W5T+B(*;7-G<W1R("+0\=WPY>D@[>$@[_'?\^7TY2#=[>$@_.WO
M[.$@]_'>\_3G(./IX2#DZ>'C\>'VWBXB"@HC.B!A9&UI;B]U<V5R+G!H<#HQ
M,#`*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N(@IM<V=S='(@(M#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S
M].<@X^GA(.3IX>/QX?;>+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L
M871E<R]A9&UI;B]U<V5R+W5P9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@
M<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+B(*;7-G<W1R("+0\=WPY>D@
M[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#P\>_SZ-[JYRXB"@HC
M.B!A9&UI;B]U<V5R+G!H<#HQ-#8*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92XB"FUS9W-T<B`BT/'=\.7I(.WA(._Q
MW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@Y>WG[-WQ^?/G+B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$T-`IM<V=I9"`B
M66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+B(*;7-G
M<W1R("+0\=WPY>D@[>$@[_'?\^7TY2#LZ>$@Y>W=\>/EZ>$@X^GA(.7J]-WK
MY?/G+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#871E9V]R>4UA;F%G
M97(N<&AP.C<S"FUS9VED(")9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y
M(&YA;64N(@IM<V=S='(@(M#QW?#EZ2#MX2#D_O/E].4@W>WA(/SM[^SA(./I
MX2#TYR#MW>$@ZN'TY^/O\=_A+B(*"B,@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3,R+"!C+69O<FUA=`HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H<#HY
M,S(*;7-G:60@(EEO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+B(*;7-G<W1R("+'(//][>3E\^<@\^'R("5S(.3IX>K\
M\.?JY2X@T.'QX>KAZ_X@Y._JZ>S<\_3E(.WA(.[A[>'S]>WDY>CEW_3E+B(*
M"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C,X"FUS9VED(")9
M;W5R($5M86EL($%D9')E<W,B"FUS9W-T<B`BQR#'Z^7J]/'O[>GJWB#SX?(@
MQ.GE_>CU[?/G(@H*;7-G:60@(EEO=7(@16UA:6P@061D<F5S<SHB"FUS9W-T
M<B`BQR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU[?/G.B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HQ.38*;7-G:60@(EEO=7(@1G)O;3H@861D<F5S<SHB
M"FUS9W-T<B`BQR#!\/PZ(,3IY?WH]>WSYSHB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-C0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C<T(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX,@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.#D*
M;7-G:60@(EEO=7(@26YF;W)M871I;VXB"FUS9W-T<B`BS^D@T.OG\>_V[_'?
MY?(@\^'R(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3,V"FUS9VED
M("(B"B)9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O("(*(G!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(L<@26YT97)N970@Y.GE_>CU[?/>(//A\B#<Z^OA[N4@X?#\(/3G
M[2#=[>'Q[N<@].?R("5S(//][>3E\][R(//A\BX@P^GA(/3G[2`B"B+P\>_S
M].'SW^$@].?R(.'S]MSKY>GA\B#P\=WPY>D@[>$@[N'MX?/U[>3EZ.7?].4N
M(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z,S,*;7-G:60@
M(EEO=7(@3F%M92(*;7-G<W1R("+4[R#\[>_LW"#SX?(B"@HC.B!T96UP;&%T
M97,O861M:6XO=7-E<B]N;V%D9"YI;F,Z.0IM<V=I9"`B(@HB66]U<B!A=71H
M96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN(@IM<V=S='(@(B(*(M3O(//]\_3G[.$@X?7H
MY>WTZ>KO\._?Y_/G\B#DY>T@]?#O\_3G\=_FY>D@\/'O\^C>ZN<@]_'G\_3^
M[2P@WB#G(.OEZ?3O]?'CW^$@(@HBX?7TWB#=]^7I(.'PY>WE\>/O\._IY^CE
MWR#CZ>$@ZMSP[^GO(.O\X^\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O
M;F]L:7-T+FEN8SHY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92`B"B)H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN(@IM<V=S='(@(B(*(M3O(//]\_3G[.$@X?7HY>WTZ>KO\._?Y_/G
M\B#DY>T@]?#O\_3G\=_FY>D@Z]_S].$@]_'G\_3^[2P@WB#G(.OEZ?3O]?'C
MW^$@(@HBX?7TWB#=]^7I(.'PY>WE\>/O\._IY^CEWR#CZ>$@ZMSP[^GO(.O\
MX^\N(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.30P"FUS9VED("(B
M"B)9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN("(*(E1O('!R;W1E
M8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN(@IM<V=S
M='(@(B(*(L\@0G)O=W-E<B#SX?(@]N'?[>7TX>D@[>$@W??EZ2#AZ^O<[N7I
M(.'P_"#TY^T@W>WA\>[G(/3G\B`E<R#S_>WDY?/>\B#SX?(N("(*(L/IX2#T
MY^T@\/'O\_3A\]_A(/3G\B#A\_;<Z^7IX?(L(.CA(/#QW?#EZ2#MX2#NX>WA
M\_7MY.7HY=_TY2XB"@HC.B!L:6(O0FQO8VLO:69R86UE+G!H<#HU,`IM<V=I
M9"`B66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E
M+B(*;7-G<W1R("+/($)R;W=S97(@\^'R(.3E[2#U\._S].?QW^;EZ2#A]?3>
M(/3G(.OEZ?3O]?'CW^$N(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<')I
M;G0N:G,Z,C<*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO;B`K
M(%`@=&\@(@HB<')I;G0N(@IM<V=S='(@(B(*(L\@0G)O=W-E<B#SX?(@Y.7M
M(/7P[_/TY_'?YN7I(.'U]-X@].?M(.7PZ>OOX]X@Y>KT_?#Y\^?R+B#0X?3>
M\_3E($-O;G1R;VPO(@HB3W!T:6]N("L@4"#CZ>$@Y>KT_?#Y\^<N(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C(T,0IM<V=I9"`B66]U<B!C=7)R96YT
M('1I;64@>F]N93HB"FUS9W-T<B`BQR#T\=WW[_7SX2#F_NWG(/[QX?(Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$T.`IM<V=I9"`B66]U<B!D969A
M=6QT(&ED96YT:71Y.B(*;7-G<W1R("+'(/#Q[^KAZ._QZ?/LW>WG(//A\B#T
MX?7T_/3G].$Z(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$X-PIM<V=I
M9"`B66]U<B!F=6QL(&YA;64Z(@IM<V=S='(@(M3O(/#KWO'E\B#\[>_LW"#S
MX?(Z(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z-S8*;7-G:60@
M(EEO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,B"FUS9W-T<B`BSR#M
MW>_R(//A\B#J^>3IZOSR(./IX2`E<R#EW^WAZ3H@)7,B"@HC.B!F<F%M97=O
M<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-PIM<V=I9"`B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+B(*;7-G<W1R("+/Z2#E\.GK[^/=\B#SX?(@W??O]>T@Y>WG[.7Q
M^>CEWR#CZ>$@].<@Y.G<\>KEZ>$@X?7TWO(@].?R(//][>3E\^?R+B(*"B,Z
M(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,34Y"FUS9VED(")9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N(@IM<V=S='(@(L_I(.7PZ>OO
MX]WR(//A\B#=]^_U[2#E[>?LY?'YZ.7?+B(*"FUS9VED(")9;W5R('!A<W-W
M;W)D<R!D;R!N;W0@;6%T8V@B"FUS9W-T<B`BS^D@[=WOZ2#J^>3IZN_?(.3E
M[2#TX>GQZ=SF[_7M(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970B"FUS9W-T
M<B`BSR#J^>3IZOSR(//A\B#<Z^OA[N4B"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW.0IM<V=I9"`B(@HB66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U
M<B!N97<@(@HB<&%S<W=O<F0N(@IM<V=S='(@(B(*(L\@ZOGDZ>K\\B#SX?(@
MW.OKX>[E+"#EZ]WC[O3E(/3A(.SG[?WLX?3<(//A\B#JX>D@ZMSM].4@Y=_S
M[^3O(.SE(/3O(.W=[R#SX?(@(@HBZOGDZ>K\+B(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHU.`IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R
M<SHB"FUS9W-T<B`BS^D@X?#O[.'J\?7S[-WM[^D@\^'R(.7N]?#G\>7TY_3=
M\CHB"@HC.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+VAI9VAL:6=H
M='%U;W1E<RYP:'`Z,3<R"B,Z('1E;7!L871E<R]J879A<V-R:7!T+W%U;W1E
M0FQO8VMS+FIS.C$R"FUS9VED(");2&ED92!1=6]T960@5&5X=%TB"FUS9W-T
M<B`B6\'P_.KQ]?CG(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMQ=(@H*(SH@<V5R
M=FEC97,O<')O8FQE;2YP:'`Z-38*;7-G:60@(EM0<F]B;&5M(%)E<&]R=%TB
M"FUS9W-T<B`B6\'MX?;O\=P@T/'OXNO>[.'T[_)=(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G:60@(EM3:&]W(%%U
M;W1E9"!497AT("TB"FUS9W-T<B`B6\7L]MSMZ?/G(.KEZ>S=[>_U(//E(.7I
M\^'C^>/IZMP@+2(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O
M:&EG:&QI9VAT<75O=&5S+G!H<#HQ-S(*;7-G:60@(EM3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=(@IM<V=S='(@(EO%[/;<[>GSYR#JY>GLW>WO]2#S
MY2#EZ?/AX_GCZ>K<("T@)7,@X_'A[.S=\ETB"@HC(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3DY+"!C+69O<FUA=`HC.B!F<F%M97=O<FLO2&]R9&4O
M2&]R9&4N<&AP.C$Y.0IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@
M(EOC\>'L[-X@)7,@X?#\("5S72(*"FUS9VED(")?061M:6YI<W1R871I;VXB
M"FUS9W-T<B`BQ.GA]^7?\>GSYR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS,0IM<V=I9"`B7T1E;&5T92!2
M;W<B"FUS9W-T<B`BQ.GAX_'A]MX@P_'A[.S>\B(*"B,Z(&QI8B]A<&DN<&AP
M.C$Q-`IM<V=I9"`B7T=R;W5P<R(*;7-G<W1R("+/[-SDY?(B"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3@Q"FUS9VED(")?2&5L<"(*
M;7-G<W1R("+"[][HY>GA(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(S"FUS9VED(")?26UA9V4@4')O<&5R
M=&EE<RXN+B(*;7-G<W1R("+)Y.G\].?TY?(@Q>GJ_.WA\BXN+B(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HR,#`*;7-G:60@(E],;V<@
M:6XB"FUS9W-T<B`BQ=_S[^3O\B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D
M92]-96YU+G!H<#HQ.38*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@(L7N[^3O
M\B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?
M;&%N9RYJ<SHR-`IM<V=I9"`B7TUO9&EF>2!,:6YK+BXN(@IM<V=S='(@(M3Q
M[_#O\._?Y_/G(-/][>3E\^SO]2XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-S`*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(L7P
MZ>OOX]WR(@H*(SH@;&EB+V%P:2YP:'`Z,3$X"FUS9VED(")?4&5R;6ES<VEO
M;G,B"FUS9W-T<B`BQ>[O]?/I[^3O]-[SY>GR(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`BQ.GAX_'A]MX@T_7MY-WS[._U+BXN
M(@H*(SH@;&EB+V%P:2YP:'`Z,3`V"FUS9VED(")?4V5T=7`B"FUS9W-T<B`B
MT?7H[-_SY>GR(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C,R"FUS9VED(")?5&%B;&4@4')O<&5R=&EE<RXN
M+B(*;7-G<W1R("+)Y.G\].?TY?(@T-_MX>KA+BXN(@H*(SH@;&EB+V%P:2YP
M:'`Z,3$P"FUS9VED(")?57-E<G,B"FUS9W-T<B`BU_'>\_3E\B(*"B,Z(&9R
M86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$Q"FUS9VED(")A9&1R97-S(&)O
M;VLB"FUS9W-T<B`BQ.GE]>CU[?/I[^/QW/;O\B(*"B,Z(&9R86UE=V]R:R]+
M;VQA8B]+;VQA8BYP:'`Z.3`S"FUS9VED(")C86QE;F1A<B(*;7-G<W1R("+'
M[.7Q[^O\X^GO(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-S`@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HS-38*;7-G:60@(F-A;&TB"FUS9W-T<B`BY_'E[-_A
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z-C`X"FUS
M9VED(")C;&EC:R!H97)E(@IM<V=S='(@(O#A]-[S].4@Y>3^(@H*(SH@9G)A
M;65W;W)K+T)R;W=S97(O0G)O=W-E<BYP:'`Z.#<P"FUS9VED(")F:6QE(@IM
M<V=S='(@(N'Q]^7?[R(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3<R(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S4X(&QI8B]";&]C:R]M971A<BYP:'`Z,S@T
M"FUS9VED(")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(@IM<V=S='(@(N'P
M_"#T[R`E<R`H)7,I(//TZ?(@)7,@)7,B"@HC.B!F<F%M97=O<FLO54DO54DO
M5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C,R"FUS9VED(")H.B(*;7-G<W1R(")H
M.B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3@W"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(R.0IM<V=I9"`B:6UM961I871E(@IM<V=S='(@(MSLY?/A(@H*
M(SH@861M:6XO<V5T=7`O9&EF9BYP:'`Z-C@@861M:6XO<V5T=7`O9&EF9BYP
M:'`Z-S8*;7-G:60@(FEN;&EN92(*;7-G<W1R("+E[?/Y[.'T^>S=[>\B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM<V=I
M9"`B;&EN97-=(@IM<V=S='(@(N/QX>SLW?)=(@H*(SH@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+VUK:7-O9G,N<&AP.C4T"FUS9VED(")M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RXB"FUS9W-T
M<B`B;6MI<V]F<RWJ^>3IZOSR(.O<Z._U\B`E9"#JX?3<(/3G(.3G[.GO]?'C
MW^$@25-/+B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,C@X
M('-E<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HR,#8*;7-G:60@(FYA;64B
M"FUS9W-T<B`B_.WO[.$B"@HC.B!F<F%M97=O<FLO4E!#+U)00RYP:'`Z,3(R
M"FUS9VED(")N;W0@:6UP;&5M96YT960B"FUS9W-T<B`BY.7M(-WWY>D@Y>/J
MX?3A\_3AZ.7?(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C0U"FUS9VED(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(N3E
M[2#=]^7I(.7CZN'TX?/TX>CEWR#AZOSLYR(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z.#DU"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(O/G[.7I
M^>SA]-SQZ>\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T
M86)L95]L86YG+FIS.C@X"FUS9VED(")P97)C96YT(@IM<V=S='(@(O3OZ?(@
MY>KA]/PB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C@Y"FUS9VED(")P:7AE;',B"FUS9W-T<B`BY>GJ[^WO\_3O
MZ??EW^$B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.CDX"FUS9VED(")S
M:&]W(&1I9F9E<F5N8V5S(@IM<V=S='(@(N7L]MSMZ?/G(.3IX?;O\?[M(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU
M,S,*;7-G:60@(G-M<S)E;6%I;"!V:6$@2%144"(*;7-G<W1R(")S;7,@\^4@
M96UA:6P@[-WS^2!(5%10(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C,V-`IM<V=I9"`B<W1E861Y(@IM<V=S='(@(O/TX>CE\?SR(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,3D*;7-G:60@(G1A<VL@;&ES
M="(*;7-G<W1R("+KW_/TX2#E\>/A\^G^[2(*"FUS9VED(")T<F%S:"(*;7-G
M<W1R("+JW.3O\B(*"B,Z(&%D;6EN+W5S97(N<&AP.C,V(&9R86UE=V]R:R]!
M=71H+T%U=&@O4VEG;G5P+G!H<#HR.#(*;7-G:60@(G1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FTB"FUS9W-T<B`BP_'<^/3E(/3O[2#J^>3I
MZOP@Y/WO(/;O\=WR(./IX2#E\.GBY>+AW_GSYR(*"B,Z(&%D;6EN+W-E='5P
M+V1I9F8N<&AP.C8X(&%D;6EN+W-E='5P+V1I9F8N<&AP.C<V"FUS9VED(")U
M;FEF:65D(@IM<V=S='(@(N7M[_#OZ>?LW>WA(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]087)T+G!H<#HQ-PIM<V=I9"`B=6YN86UE9"(*;7-G<W1R("+A
M[?[M]>SA(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HU.#<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,C(Y"FUS9VED(")U<V5R('-E;&5C="(*;7-G<W1R("+E
M\.GK[^/>(/?QWO/TYR(*"FUS9VED(")V0V%R9"(*;7-G<W1R("+8Y_;IX>K>
M(,K<\?3A(@H`````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!O+VMO7TM2+G!O````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#8U,#`P,R`Q,#4Q-30S-#$T
M,R`P,3<U,C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````(R!+;W)E86X@=')A;G-L871I;VYS(&9O<B!H;W)D92!P86-K86=E
M"B,@:&]R9&4@QM#%L,'VOZ$@M.O'T2#'T;&YONX@N?B_JKFN+@HC($-O<'ER
M:6=H="`H0RD@,C`P-2!(;W)D92!0<F]J96-T"B,@5&AI<R!F:6QE(&ES(&1I
M<W1R:6)U=&5D('5N9&5R('1H92!S86UE(&QI8V5N<V4@87,@=&AE(&AO<F1E
M('!A8VMA9V4N"B,*;7-G:60@(B(*;7-G<W1R("(B"B)0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,"UC=G-<;B(*(E)E<&]R="U-<V=I9"U"=6=S+51O
M.B!D979`;&ES=',N:&]R9&4N;W)G7&XB"B)03U0M0W)E871I;VXM1&%T93H@
M,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P7&XB"B)03RU2979I<VEO;BU$871E.B`R
M,#`Q+3$Q+3`Y(#$V.C(Y*S`Y,#!<;B(*(DQA<W0M5')A;G-L871O<CH@2FEN
M:'EO:R!(96\@/&YO=F5M8G)E0&]U<FYA='5R92YO<F<^7&XB"B),86YG=6%G
M92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9UQN(@HB34E-12U697)S:6]N
M.B`Q+C!<;B(*(D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U%
M54,M2U)<;B(*(D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:71<;B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-CD*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B("@E<R!D87ES(&%G;RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TAO<F1E+TAO<F1E+G!H<#HQ,S<P"B,L('!H<"UF;W)M870*;7-G:60@
M(B`H06-C97-S:V5Y("5S*2(*;7-G<W1R("(@*+3<P^#%L"`E<RDB"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S<W"B,L('!H<"UF;W)M870*;7-G
M:60@(B`H:6X@)7,@9&%Y<RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,C,W,PIM<V=I9"`B("AT;V1A>2DB"FUS9W-T<B`B("B_
MP+3#*2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(S-S4*;7-G:60@
M(B`H=&]M;W)R;W<I(@IM<V=S='(@(B`HL[O`SRDB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,S<Q"FUS9VED("(@*'EE<W1E<F1A>2DB"FUS9W-T
M<B`B("B^[L&F*2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR
M-38@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,V,0HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#`W"FUS9VED("(@870@(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C$U"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")<(B5S7"(@:7,@;F]T(&$@9&ER96-T;W)Y
M+B(*;7-G<W1R("*U\+>ZQ>2XKB(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H
M<#HR-S(*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!I<R!N
M;W0@82!V86QI9"!C:&]I8V4N(@IM<V=S='(@(K_#N=FXI2"PR[OV(+G\P=:X
MIB#`U+?"Q\^\O+_D+B(*"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I
M<W1R>2YP:'`Z-C4Y"B,Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R
M>2YP:'`Z,3`T,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2XB"FUS
M9W-T<B`B)7,GP,PHL*$I($AO<F1E(+>YP?:]NL:NN*Z_H;RM(+RSP:2UQ[[N
M(,#6P?8@OLJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U1R964O5')E92YP:'`Z
M,3<Q"B,L('!H<"UF;W)M870*;7-G:60@(EPB)7-<(B!T<F5E(')E;F1E<F5R
M(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@861M:6XO9W)O=7!S+G!H<#HU
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!A9&1E
M9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2XB"FUS9W-T<B`B)R5S)["A(+W#O;K%
MV[^A(,/?L*&UQ[[ZO<"TS[39+B(*"B,Z(&%D;6EN+W!E<FUS+V%D9&-H:6QD
M+G!H<#HU,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A
M<R!A9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B(*;7-G<W1R("(G
M)7,GL*$@O<.]NL7;OZ$@P]^PH;7'OOJ]P+3/M-DN(@H*(SH@861M:6XO9W)O
M=7!S+G!H<#HU-"!A9&UI;B]P97)M<R]A9&1C:&EL9"YP:'`Z-3`*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B7"(E<UPB('=A<R!N;W0@8W)E871E9#H@)7,N(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HW,`HC+"!P:'`M
M9F]R;6%T"FUS9VED("(E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H
M)2XR9B4E*2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C,W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E9"`E<R!A
M;F0@)7,B"FUS9W-T<B`B)60@+R`E9"`HN-Z]P\'V.B`E9"DB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C(V."!L:6(O0FQO8VLO86-C;W5N
M="YP:'`Z-34W"B,L('!H<"UF;W)M870*;7-G:60@(B5D(&1A>7,@=6YT:6P@
M>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C@U"B,L('!H<"UF;W)M870*;7-G:60@
M(B5D+61A>2!F;W)E8V%S="(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]M86EN
M=&5N86YC92YP:'`Z-C@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M("T@3F]T:6-E(@IM<V=S='(@(L+\P;8B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C<P-`HC+"!P:'`M9F]R;6%T"FUS9VED("(E<R!&
M:6YG97)P<FEN="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+T-O;G1E;G1S+G!H<#HX,S,@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT
M<RYP:'`Z.#,U"B,L('!H<"UF;W)M870*;7-G:60@(B5S($M"(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HT.0HC+"!P:'`M9F]R
M;6%T"FUS9VED("(E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER
M;6%T:6]N(@IM<V=S='(@(B5S(,"OP?:P_+BN(,#;OO<@+2#(KL#.(@H*(SH@
M861M:6XO<V5T=7`O8V]N9FEG+G!H<#HS,"!A9&UI;B]S971U<"]I;F1E>"YP
M:'`Z,C$U"B,L('!H<"UF;W)M870*;7-G:60@(B5S(%-E='5P(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O4VEG;G5P+G!H<#HR-C,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B)7,@4VEG;B!5<"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z-3D*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B)7,@5&5R;7,@;V8@06=R965M96YT(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+W-M8BYP:'`Z-#(X(&9R86UE=V]R:R]61E,O5D93+W-M
M8BYP:'`Z-#DP"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-C4Q(&9R
M86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S$Y"B,L('!H<"UF;W)M870*;7-G
M:60@(B5S(&%L<F5A9'D@97AI<W1S+B(*;7-G<W1R(")<(B5S7"*TPB#`S+G,
M(,#6O<"TS[39+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,34Y(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,38U(&QI8B]";&]C:R]M971A<BYP:'`Z,C,Y"B,Z
M(&QI8B]";&]C:R]M971A<BYP:'`Z,S0U(&QI8B]";&]C:R]M971A<BYP:'`Z
M,S4Q"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R!A="`E<R`E<R(*
M;7-G<W1R("(E9"`O("5D("BXWKW#P?8Z("5D*2(*"B,Z('-E<G9I8V5S+VUA
M:6YT96YA;F-E+G!H<#HT.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M(@HB)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@(@HB8F]X(&9O<B!A
M;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T
M:6UE+B(*;7-G<W1R("+!]K'=(+SVQ^#'TB#`V[[WP+L@O+'%P\?/O+R_Y"XB
M"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S0P"B,L('!H<"UF;W)M
M870*;7-G:60@(B5S(&ES(')E<75I<F5D(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C@V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M("(E<R!M:6YU=&5S(@IM<V=S='(@(C6ZT""XMK39(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+T-O;&QE8W1I;VXN<&AP.C$R,PHC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BN
MO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C0*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(B5S('1O("5S(&]F("5S(@IM<V=S='(@(B5D("\@)60@*+C>O</!
M]CH@)60I(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HY,C(*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S)W,@061D<F5S<R!";V]K(@IM
M<V=S='(@(L'6O-*WSR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z
M.3$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("(E<R=S($-A;&5N9&%R
M(@IM<V=S='(@(K3>M\(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.CDP-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B)7,G<R!.;W1E<&%D
M(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B5S
M)W,@5&%S:VQI<W0B"FUS9W-T<B`BO/:]Q;#%NLXB"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.CDV"B,L('!H<"UF;W)M870*;7-G:60@(B5S.B`E<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B(@HB)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T
M(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL
M;W=I;F<@(@HB86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@
M<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S8U(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT,3`*;7-G:60@(BP@9W5S=&EN9R`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ.#@@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HQ.3,*(RP@<&AP+69O<FUA=`IM<V=I9"`B+"!G=7-T
M:6YG("5S("5S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C`Q"B,L('!H<"UF;W)M870*;7-G:60@(BP@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(Y-"!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,T.`HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,#8Y(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(Q,C@*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C<T.0HC+"!F=7IZ>0IM<V=I9"`B+2T@<V5L96-T("TM(@IM<V=S
M='(@(K'4Q*(HM_PI(+RQQ<,@O\"W^2(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H
M<#HR,`HC+"!F=7IZ>0IM<V=I9"`B,3(@2&]U<B!&;W)M870B"FUS9W-T<B`B
MP:2ZN"(*"B,Z(&QI8B]";&]C:R]T:6UE+G!H<#HQ.0HC+"!F=7IZ>0IM<V=I
M9"`B,C0@2&]U<B!&;W)M870B"FUS9W-T<B`BP:2ZN"(*"B,Z('1E;7!L871E
M<R]D871A+W1I;64N:6YC.C(X"FUS9VED("(R-"!H;W5R<R(*;7-G<W1R("(R
M-""]P["C(@H*(SH@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H<#HV.0HC+"!F
M=7IZ>0IM<V=I9"`B/%!R979I;W5S(@IM<V=S='(@(L#,P/P@QN3`S,'V(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ,3D*;7-G:60@(D$@9&%T86)A<V4@
M8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-C`*(RP@9G5Z>GD*
M;7-G:60@(D$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D(@IM<V=S='(@(CQB
M/L2AN.W`^\#.(+_`M_D@N=^[_3H\+V(^(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W!G<"YP:'`Z.3,U"FUS9VED(")!('!U8FQI8R!01U`@:V5Y(&ES
M(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38U"FUS9VED(")!
M('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE
M9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y
M<'0O<&=P+G!H<#HQ,#DW"FUS9VED("(B"B)!('!U8FQI8R!01U`@:V5Y+"!P
M<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T
M;R!D96-R>7!T(&$@(@HB;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,3`Q-0IM<V=I9"`B(@HB02!P=6)L
M:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@<VEG;B!A("(*(FUE<W-A9V4N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3`U"FUS9VED
M("(B"B)!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R`B"B)D96-R>7!T(&$@
M;65S<V%G92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HT,S$*;7-G:60@(B(*(D$@<'5B;&EC(%,O34E-12!K97DL
M('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@(@HB82!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,V-`IM<V=I9"`B02!P=6)L
M:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HY"B,L(&9U>GIY"FUS9VED(")!32!#;&]U9',B"FUS9W-T<B`B
MNKF[YR(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$P"B,L(&9U>GIY"FUS9VED(")!32!,:6=H="!286EN(@IM<V=S='(@(K?.
ML=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C$Q"B,L(&9U>GIY"FUS9VED(")!32!286EN(@IM<V=S='(@(K"AP.7`VKBN
M(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3(*
M;7-G:60@(D%-(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3,*;7-G:60@(D%-(%-N;W<@4VAO
M=V5R<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHR
M.0IM<V=I9"`B04TO4$TB"FUS9W-T<B`BO\#`_"^_P,C$(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C`P"FUS9VED
M(")!4$D@240B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHS,`IM<V=I9"`B06)O=70@=&AI<R!E9&ET;W(B
M"FUS9W-T<B`BP,P@OZ&U\,7-M,(B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HU,@IM<V=I9"`B06)O=70N+BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW-`HC+"!F=7IZ>0IM
M<V=I9"`B06)S8F]T=&]M(@IM<V=S='(@(K[&MZ$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<R"B,L(&9U>GIY"FUS9VED
M(")!8G-M:61D;&4B"FUS9W-T<B`BL*&_[K6E(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C(W,`HC+"!F=7IZ>0IM<V=I9"`B06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T
M(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]M=7-Q;"YP:'`Z,3,V"B,L(&9U>GIY"FUS9VED(")!8V-E<W,@
M9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E
M<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@26YF;W)M
M871I;VXB"FUS9W-T<B`BP:2ZN"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HW-0HC+"!F=7IZ>0IM<V=I9"`B06-C;W5N="!087-S=V]R9"(*;7-G<W1R
M("*^S\BC(,BNP,XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA
M=&5L;%]H='1P+G!H<#HR.3,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G0@9G)O
M>F5N+B(*;7-G<W1R("*_P+BGPO>\^"(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HS,S,*(RP@9G5Z>GD*;7-G:60@(D%C8V]U;G1I;F<B"FUS9W-T
M<B`BO\"XI\+WO/@B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C$T."!T96UP;&%T97,O<&]R=&%L+V%D9"YI;F,Z,30*(SH@=&5M<&QA=&5S
M+V%D;6EN+V=R;W5P<R]A9&1C:&EL9"YI;F,Z,3$*;7-G:60@(D%D9"(*;7-G
M<W1R("+#W["A(@H*(SH@861M:6XO9W)O=7!S+G!H<#HR,C0@861M:6XO9W)O
M=7!S+G!H<#HR,C4*;7-G:60@(D%D9"!#:&EL9"!'<F]U<"(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDX(&9R86UE=V]R
M:R]097)M<R]097)M<R]522YP:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(D%D9"!#
M:&EL9"!097)M:7-S:6]N(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z('1E;7!L
M871E<R]P;W)T86PO861D+FEN8SHU"B,L(&9U>GIY"FUS9VED(")!9&0@2&5R
M93HB"FUS9W-T<B`BN^>_Z\#:(,/?L*$B"@HC.B!A9&UI;B]G<F]U<',N<&AP
M.C(Q."!A9&UI;B]G<F]U<',N<&AP.C(Q.0IM<V=I9"`B061D($YE=R!'<F]U
M<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP
M.C@W(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z.#@*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!.97<@4&5R;6ES<VEO;B(*;7-G<W1R("*PL\#.(+C>P,\B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V%D9&-H:6QD+FEN8SHW"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!G<F]U<"!T
M;R!<(B5S7"(B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,30W"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O(%PB)7-<
M(B(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B"@HC.B!A9&UI;B]U<V5R+G!H<#HS
M,`IM<V=I9"`B061D(&$@;F5W('5S97(Z(@IM<V=S='(@(KOUM\Z_[B"[Y[_K
MP-H@P]^PH3HB"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-34T"B,L(&9U>GIY"FUS9VED(")!9&0@8V]L=6UN(@IM<V=S='(@
M(K^M(+K0Q](B"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC
M.C,T"B,L(&9U>GIY"FUS9VED(")!9&0@;F5W(&UE;6)E<G,B"FUS9W-T<B`B
MN_6WSK_N(+OGO^O`VB##W["A.B(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA
M<"YI;F,Z.34*;7-G:60@(D%D9"!P86ER(@IM<V=S='(@(L;DONXH<&%I<BD@
MP]^PH2(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS-C<*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E
M8F%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W9C87)D+G!H<#HW,0HC+"!F=7IZ>0IM<V=I9"`B061D('1O(&%D9')E<W,@
M8F]O:SHB"FUS9W-T<B`B*"5S*;BF(,'6O-*WS[^A(,/?L*$B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z-S@*(RP@9G5Z>GD*
M;7-G:60@(D%D9"!T;R!M>2!A9&1R97-S(&)O;VLB"FUS9W-T<B`B*"5S*;BF
M(,'6O-*WS[^A(,/?L*$B"@HC.B!A9&UI;B]U<V5R+G!H<#HS,0IM<V=I9"`B
M061D('5S97(B"FUS9W-T<B`BN^>_Z\#:(,/?L*$B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HW.0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)!9&1E9"!<(B5S7"(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("(*(B5S+B(*;7-G<W1R("(B"@HC.B!S:6=N
M=7`N<&AP.C0U"B,L('!H<"UF;W)M870*;7-G:60@(D%D9&5D(%PB)7-<(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHR"FUS9VED(")!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N(@IM<V=S='(@(KOGO^O`VB##W["A
M(+OGO^N^R,?4(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A
M<F0N<&AP.C$R-@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R
M9"YP:'`Z,3<S(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#$*;7-G:60@
M(D%D9')E<W,B"FUS9W-T<B`BP=:\TB(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP
M:'`N9&ES=#HQ,SD*;7-G:60@(D%D9')E<W,@0F]O:R(*;7-G<W1R("+!UKS2
MM\\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY
M-`IM<V=I9"`B061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H
M97(@=7-E<G,B"FUS9W-T<B`B(@H*(SH@861M:6XO:6YD97@N<&AP.C$Y('-E
M<G9I8V5S+W!O<G1A;"]S:61E8F%R+G!H<#HQ,3,*;7-G:60@(D%D;6EN:7-T
M<F%T:6]N(@IM<V=S='(@(K#\N*XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")!9',B"FUS9W-T<B`BP]^PH2(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-38*(RP@9G5Z>GD*;7-G:60@(D%F9VAA;FES=&%N(@IM<V=S
M='(@(K3<P[PB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C4W"B,L(&9U>GIY"FUS9VED(")!;&)A;FEA
M(@IM<V=S='(@(K[SMO/`S+[NO;HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C<T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<P"B,L(&9U>GIY"FUS
M9VED(")!;&=E<FEA(@IM<V=S='(@(K[SMO/`S+[NO;HB"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,3`W"FUS9VED(")!;&EA
M<R(*;7-G<W1R("*^\[;SP,R^[KVZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ-@IM<V=I9"`B06QI9VXB"FUS
M9W-T<B`BP:2WQ"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z-C<*;7-G:60@(D%L:6=N;65N=#HB"FUS9W-T<B`BP:2WQ#HB
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.#<*;7-G:60@(D%L;"(*;7-G
M<W1R("*X\+7.(+RQQ<,B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C(P-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C8U"B,L(&9U>GIY
M"FUS9VED(")!;&P@075T:&5N=&EC871E9"!5<V5R<R(*;7-G<W1R("*XWL#/
M(,#\M-X@O\"W^3HB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C,S(&%D;6EN+V=R
M;W5P<RYP:'`Z,C(R"B,L(&9U>GIY"FUS9VED(")!;&P@1W)O=7!S(@IM<V=S
M='(@(KOHP:8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.CDQ
M(&9R86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`Z-S4*(RP@9G5Z
M>GD*;7-G:60@(D%L;"!097)M:7-S:6]N<R(*;7-G<W1R("+%Y+?0(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHQ
M-PIM<V=I9"`B06QL(&9O=7(@<VED97,B"FUS9W-T<B`BN/"UYR`TN.DB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<Q"FUS9VED(")!;&QO=R!M
M=6QT:7!L92!A9&1R97-S97,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C4S-`IM<V=I9"`B06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E
M+T1A=&%4<F5E+W-Q;"YP:'`Z-3`T"B,L(&9U>GIY"FUS9VED(")!;')E861Y
M(&5X:7-T<R(*;7-G<W1R(")<(B5S7"*TPB#`S+G,(,#6O<"TS[39+B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C,*;7-G:60@(D%L=&5R;F%T92!)
M35-0($QO9VEN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HU,#<*(RP@9G5Z>GD*;7-G:60@(D%L=&5R;F%T92!)35-0(%!A<W-W;W)D
M(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES
M=#HT.3D*;7-G:60@(D%L=&5R;F%T92!)35-0(%5S97)N86UE(@IM<V=S='(@
M(B(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C,U"B,L(&9U>GIY
M"FUS9VED(")!;'1E<FYA=&4@96UA:6P@861D<F5S<R(*;7-G<W1R("+`W[CX
MM<@@P,RXWL#/(,'6O-(B"@HC.B!A9&UI;B]T96UP;&%T97,N<&AP.C$T,@HC
M+"!F=7IZ>0IM<V=I9"`B06QT97)N871E('1E;7!L871E<R(*;7-G<W1R("*T
MZ\.\(+';(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,C(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS
M96QI;6%G95]L86YG+FIS.C(U"FUS9VED(")!;'1E<FYA=&4@=&5X=#HB"FUS
M9W-T<B`BM.O#O""QVR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3@*;7-G:60@(D%M97)I8V%N(%-A
M;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP
M:'`Z.34@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HQ,34*;7-G:60@
M(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"XB"FUS9W-T<B`BP-^X
M^+7((+FNP-JPH2#`UKW`M,^TV2XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,38W"B,L(&9U>GIY"FUS9VED(")!;B!U;FMN;W=N(&5R<F]R
M(&AA<R!O8V-U<F5D+B(*;7-G<W1R("(\8C[$H;CMP/O`SB"_P+?Y(+G?N_TZ
M/"]B/B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-34*;7-G:60@(D%N9&]R<F$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YG;VQA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M-3<*;7-G:60@(D%N9W5I;&QA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HQ,3D*;7-G:60@(D%N;VYY;6]U<R!0<F]X>2(*
M;7-G<W1R("(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT.0HC
M+"!F=7IZ>0IM<V=I9"`B06YS=V5R(@IM<V=S='(@(LBXO<7'T2"XWL#/(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HU.`IM<V=I9"`B06YT87)C=&EC82(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C4V"FUS9VED(")!;G1I9W5A(&%N9"!"87)B=61A(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W1E;7!L871E<RYP:'`Z-S0@861M:6XO<&AP<VAE;&PN<&AP
M.C,U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R]522YP:'`Z-3@@=&5M<&QA
M=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ-@HC+"!F=7IZ>0IM<V=I9"`B
M07!P;&EC871I;VXB"FUS9W-T<B`BO<?'X"(*"B,Z('5T:6PO:6-O;E]B<F]W
M<V5R+G!H<#HT,@HC+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@3&ES="(*
M;7-G<W1R("*]Q\?@(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$T,`HC
M+"!F=7IZ>0IM<V=I9"`B07!P;&EC871I;VX@:7,@<F5A9'DN(@IM<V=S='(@
M(KW'Q^`B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C(Q.`IM<V=I
M9"`B07!P;'D@=&\@0VAI;&0@4VAA<F5S(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(Q"FUS9VED(")!<'!R;W9E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O0V]N=&5N=',N
M<&AP.C@S,PIM<V=I9"`B07!P<F]X:6UA=&4@4VEZ92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`T"B,Z
M(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#(*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.`IM<V=I
M9"`B07!R:6PB"FUS9W-T<B`B-+_Y(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ-S4*;7-G:60@(D%R86)I8R`H5VEN9&]W<RTQ,C4V*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R87(N<&AP.C4Y(&9R
M86UE=V]R:R]-24U%+TU)344O5FEE=V5R+WII<"YP:'`Z-C8*(SH@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HX,0IM<V=I9"`B07)C:&EV
M92!&:6QE(%-I>F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<F%R+G!H<#HU."!F<F%M97=O<FLO34E-12]-24U%+U9I97=E
M<B]Z:7`N<&AP.C8U"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G
M>BYP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(D%R8VAI=F4@3F%M92(*;7-G<W1R
M("+'RK7EP,RXIR(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V97%U
M975E9"YI;F,Z,3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_(@IM<V=S='(@(K#HO-,@P?C'X,?/O<.PVKW`M,^Q[C\B"@HC
M.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V1E;&5T92YI;F,Z-PHC+"!F=7IZ
M>2P@<&AP+69O<FUA=`IM<V=I9"`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O
M(&1E;&5T92!<(B5S7"(@86YD(&%N>2!S=6(M9W)O=7!S/R(*;7-G<W1R("+`
MS""XWKW#P?:XIB"_M;_XR/<@N^C!IL?/O<.PVKW`M,^Q[C\B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(V(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C4X"B,L(&9U>GIY"FUS9VED(")!<F=E;G1I;F$B"FUS9W-T<B`BOO.V\\#,
MONZ]NB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,0HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]'96])4"YP:'`Z-3<*;7-G:60@(D%R;65N:6$B"FUS9W-T<B`B(@H*
M(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S8*;7-G:60@(D%R;65N:6%N("A!
M4DU30TE)+3@I(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HR.`IM<V=I9"`B07)T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*;7-G:60@
M(D%R=6)A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,34*;7-G:60@(D%S8V5N<VEO;B!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C(Y"FUS9VED(")!<V-I:2!!<G0B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C4U"FUS
M9VED(")!<VEA+U!A8VEF:6,@4F5G:6]N(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HT,C4*;7-G:60@(D%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/R(*;7-G
M<W1R("+`K\'VL/RXKKW'Q^#`_"#(KL#.Q\^QXB(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C,Q,3,*(RP@9G5Z>GD*;7-G:60@(D%S<VEG;FUE;G0@
M8V]L=6UN<R(*;7-G<W1R("*_K2"ZT,?2(@H*(SH@861M:6XO9W)O=7!S+G!H
M<#HW-`IM<V=I9"`B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M9W)O=7`N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z
M,CD*;7-G:60@(D%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!E<FUS+V5D:70N<&AP
M.C@W"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BXB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N
M<&AP.C4S"FUS9VED(")!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<VAA<F4N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C0@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW,0HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@V"FUS9VED(")!='1R:6)U=&5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT,#@*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0T-@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C<R"FUS9VED(")!=6=U<W0B
M"FUS9W-T<B`B.+_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU.0HC+"!F=7IZ>0IM<V=I9"`B075S
M=')A;&EA(@IM<V=S='(@(CB_^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-`HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-3D*(RP@9G5Z>GD*;7-G
M:60@(D%U<W1R:6$B"FUS9W-T<B`B.+_Y(@H*(SH@9G)A;65W;W)K+T%U=&@O
M075T:"]C>7)S<6PN<&AP.C$V.`IM<V=I9"`B075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]C>7)U<RYP:'`Z,3,U"FUS9VED(")!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O8WER
M=7,N<&AP.C$R,@IM<V=I9"`B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M075T:"]!=71H+V9T<"YP:'`Z,S8*;7-G:60@(B(*(D%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M(@HB9G1P('-W:71C:"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T%U=&@O075T:"]I;6%P+G!H<#HV-`IM<V=I9"`B075T:%]I
M;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z-3$*;7-G
M:60@(D%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N
M<&AP.C,P,@IM<V=I9"`B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,U-PIM<V=I9"`B075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H
M+T%U=&@O;&1A<"YP:'`Z-C,*;7-G:60@(D%U=&A?;&1A<#H@4F5Q=6ER960@
M3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C,S.0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N
M(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z("(*;7-G<W1R("+`T[W#
MNKBP_,?4(,#ZP.4@O\"W^2X@O*VY]L#'(+_`M_D@N-Z]P\'V.B`E<R(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z,S@U"B,L('!H<"UF;W)M
M870*;7-G:60@(D%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;&1A<"YP:'`Z
M-#DY"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<R(*;7-G<W1R("+`T[W#NKBP_,?4(,#Z
MP.4@O\"W^2X@O*VY]L#'(+_`M_D@N-Z]P\'V.B`E<R(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@O;&1A<"YP:'`Z-#`U"FUS9VED(")!=71H7VQD87`Z(%5P
M9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GDN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O;6-A
M;"YP:'`Z-#8*;7-G:60@(D%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+W-M8BYP:'`Z-C`*;7-G:60@(D%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M.3`*(RP@9G5Z>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"(*;7-G
M<W1R("*[Z,&F(+W'QM`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HV-PHC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M8VQI8VMA=&5L;%]H='1P+G!H<#HW-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B075T:&5N=&EC871I;VX@9F%I;&5D+B`E<R(*;7-G<W1R("*XWL#/
M(,#\M-X@O\"W^3HB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A9&EU<RYP
M:'`Z,3<V"B,L(&9U>GIY"FUS9VED(")!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`
MM_DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HX-3$*(RP@9G5Z
M>GD*;7-G:60@(D%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+B(*;7-G<W1R(")F='`@O*VY]B"_K+#A(+_`M_DN(@H*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<VUB+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")F='`@
MO*VY]B"_K+#A(+_`M_DN(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN
M8SHW-0IM<V=I9"`B079A:6QA8FQE(&9I96QD<SHB"FUS9W-T<B`BL*&TR<?1
M(,?*M>4Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HS,2!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(U"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HU.0IM<V=I9"`B07IE<F)A:6IA;B(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S`*;7-G:60@(D)/1D@@
M17AC=7-E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C$X"FUS9VED(")"86-K9W)O=6YD(@IM
M<V=S='(@(KGHL.8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L86YG+FIS.C(S"FUS9VED(")"86-K9W)O=6YD($-O;&]R(@IM<V=S='(@
M(KGHL.8@N_:Q\B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O:W)B-2YP:'`Z
M.#$*;7-G:60@(D)A9"!K97)B97)O<R!P87-S=V]R9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H<#HX,PIM<V=I9"`B0F%D
M(&ME<F)E<F]S('5S97)N86UE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8R"B,L
M(&9U>GIY"FUS9VED(")"86AA;6%S(@IM<V=S='(@(L#,N*<B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8Q"B,L(&9U>GIY"FUS9VED(")"86AR86EN(@IM<V=S='(@(L"EN-[`SR(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3<W"FUS9VED(")"86QT:6,@*$E3
M3RTX.#4Y+3$S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C,T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C@*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8P"FUS9VED(")"86YG
M;&%D97-H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR.0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*;7-G:60@(D)A<F)A9&]S
M(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B<F]W<V5R+G!H<#HS,0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BQ>O!]B"XKKVZL\H@)7/`
MNRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C$Y"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-S,*(RP@9G5Z>GD*;7-G:60@
M(D)A<V5L:6YE(@IM<V=S='(@(L6IL>(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]T;&0N<&AP.C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,S`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")"
M96QA<G5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS,0HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C`*(RP@9G5Z>GD*;7-G:60@
M(D)E;&=I=6TB"FUS9W-T<B`BQ:FQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z-3`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HS
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C,*(RP@9G5Z>GD*
M;7-G:60@(D)E;&EZ92(*;7-G<W1R("+%J;'B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HT,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0F5N:6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HT,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,T"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F5R;75D
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C0V
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,S4*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C8S"FUS9VED(")":'5T86XB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP
M.C$Q,0IM<V=I9"`B0FER=&AD87DB"FUS9W-T<B`BN_W`SR(*"B,Z(&9R86UE
M=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS-3,*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO
M;B!<(B5S7"(@;F]T(&9O=6YD+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[
M*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L871E<R]P;W)T86PO
M;&%Y;W5T+FEN8SHX.0IM<V=I9"`B0FQO8VL@4V5T=&EN9W,B"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+W!O<G1A;"]L87EO=70N:6YC.C<T"FUS9VED(")"
M;&]C:R!4>7!E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z.`IM<V=I9"`B0F]L9"(*;7-G<W1R("*QO;#4
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT,R!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HV,@IM<V=I9"`B0F]L:79I82(*;7-G<W1R("(B"@HC.B!C
M;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C`U"FUS9VED(")";V]K;6%R:W,B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHR,`IM<V=I9"`B0F]R9&5R(@IM<V=S='(@(K#FL.@B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@U
M"FUS9VED(")";W)D97(@=&AI8VMN97-S.B(*;7-G<W1R("*PYK#H(+7.LK(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C(Q"FUS9VED(")";W)D97)S(@IM<V=S='(@(K#FL.@B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C,R(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,S<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C8P"FUS9VED(")";W-N:6$@86YD($AE<GIE9V]V:6YA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY-@IM<V=I9"`B0F]T:"(*;7-G
M<W1R("*X\+7.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT."!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C,X"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HV,PIM<V=I9"`B0F]T<W=A;F$B"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHR,@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<U"FUS9VED(")";W1T;VTB"FUS9W-T<B`BOL:WH2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-#<@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HS.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C,*;7-G:60@(D)O=79E="!)<VQA;F0B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HT-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV,@HC+"!F=7IZ>0IM<V=I9"`B0G)A>FEL(@IM<V=S='(@(L"EN-[`SR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C@Q"FUS9VED(")"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HT,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0R"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,@IM<V=I9"`B0G)U;F5I($1A
M<G5S<V%L86TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HS-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C0S"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0HC+"!F=7IZ>0IM<V=I
M9"`B0G5L9V%R:6$B"FUS9W-T<B`BOO.V\\#,ONZ]NB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3D*;7-G:60@(D)U;&QE
M=&5D($QI<W0B"FUS9W-T<B`BL>+(HR"XKKVZQJXB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z-#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8Q"FUS
M9VED(")"=7)K:6YA($9A<V\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HS.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C0U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV,0IM<V=I
M9"`B0G5R=6YD:2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-#0T"B,L(&9U>GIY"FUS9VED(")#35,B"FUS9W-T<B`B0U93(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW-0IM<V=I
M9"`B0U)#(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-3DW"FUS9VED(")#4DP@1&ES=')I8G5T:6]N(%!O:6YT<R(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z,C<*;7-G:60@(D-?96QL(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B7V6\OR"\T[RZ+BXN(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VTN<&AP.C$V,PIM<V=I9"`B0V%C:&4@:6YI="!W87,@;F]T(&-O;7!L
M971E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C0X-"!C;VYF:6<O:&]O:W,N<&AP+F1I<W0Z.3@W"B,Z
M(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ-34*;7-G:60@(D-A;&5N9&%R
M(@IM<V=S='(@(K3>M\(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z,C0V"B,L(&9U>GIY"FUS9VED(")#86QM(@IM<V=S='(@(L/KO-(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$R."!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C0V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,PIM<V=I9"`B0V%M8F]D:6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV,"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C0W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HV-PHC+"!F=7IZ>0IM<V=I9"`B0V%M97)O;VXB"FUS9W-T<B`BL+/`SB"X
MWL#/(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z,C`*;7-G:60@
M(D-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&:6QE7T-35B]#4U8N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B0V%N(&YO="!W<FET92!T;R!F:6QE(%PB)7-<(B(*;7-G<W1R(")6
M1E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@
M861M:6XO<V5S<VEO;G,N<&AP.C(R"FUS9VED(")#86XG="!A9&UI;FES=&5R
M(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O8WER=7,N<&AP.C(S-2!F<F%M97=O<FLO075T
M:"]!=71H+V-Y<G-Q;"YP:'`Z,S$Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS
M9VED(")#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<R(*;7-G<W1R
M("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6
M+T-35BYP:'`Z-#$S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#86XG
M="!O<&5N(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[
M*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`HC+"!F=7IZ
M>0IM<V=I9"`B0V%N861A(@IM<V=S='(@(K3>M\(B"@HC.B!A9&UI;B]U<V5R
M+G!H<#HQ,#$@861M:6XO=7-E<BYP:'`Z,3(P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHV-0HC.B!T96UP;&%T97,O861M:6XO
M9W)O=7!S+V1E;&5T92YI;F,Z,3$@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE
M87(N:6YC.C$R"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z
M,3(*;7-G:60@(D-A;F-E;"(*;7-G<W1R("+#Z[S2(@H*(SH@=&5M<&QA=&5S
M+W!R;V)L96TO<')O8FQE;2YI;F,Z-3D*;7-G:60@(D-A;F-E;"!0<F]B;&5M
M(%)E<&]R="(*;7-G<W1R("*_P+?Y(+JXL.W'S['B(,/KO-(B"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]F='`N<&AP.C,Q.`HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V%N;F]T(&1E;&5T92!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B
M5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713
M=')A=&5G>2]C;W!Y+G!H<#HT-@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E
M<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V-O<'DN<&AP.C4R"FUS
M9VED(")#86YN;W0@9FEN9"!A('1E;7!O<F%R>2!D:7)E8W1O<GDN(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R:71E<BYP
M:'`Z.3$*;7-G:60@(D-A;FYO="!P<F]C965D('=I=&AO=70@)W1A<F=E=$9I
M;&4G('!A<F%M971E<BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U9&4R]6
M1E,O9G1P+G!H<#HS,30*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y(%PB)7-<(BXB"FUS9W-T<B`B36%I;G1E
M;F%N8V5?5&%S:R"X\+7B("5SP+LHN*8I(+^M(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`Z,3(X(&9R86UE=V]R
M:R]$871A5')E92]$871A5')E92]S<6PN<&AP.C8X,`HC+"!P:'`M9F]R;6%T
M"FUS9VED(")#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="XB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP
M:'`Z-C`X"FUS9VED("(B"B)#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R("(*(G-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`Y"FUS9VED(")#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8U(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#87!E(%9E<F1E(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,C0*;7-G:60@(D-A<'1I;VXB"FUS9W-T<B`BQ+B\QR(*"B,Z(&9R86UE=V]R
M:R].971?4TU3+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-`IM<V=I9"`B0V%R
M<FEE<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3`*
M;7-G:60@(D-A=&5G;W)I97,@86YD($QA8F5L<R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S-2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C4P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HX-@IM<V=I9"`B0V%Y;6%N($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y-`IM<V=I
M9"`B0V5L;"!0:&]N92(*;7-G<W1R("+(WK3KQODB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(U"FUS9VED(")#
M96QL(%!R;W!E<G1I97,B"FUS9W-T<B`BO+\@O-.\NB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$T"FUS9VED(")#96QL
M('!A9&1I;F<Z(@IM<V=S='(@(KR_(,;DM?DB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8Q"FUS9VED(")#96QL
M('!R;W!E<G1I97,B"FUS9W-T<B`BO+\@O-.\NB(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$R"FUS9VED(")#96QL('-P
M86-I;F<Z(@IM<V=S='(@(KR_(+"CL-TB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,C<T"FUS9VED(")#96QL<&AO;F4B"FUS9W-T<B`BR-ZTZ\;Y
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ-S@*;7-G:60@(D-E;'1I8R`H
M25-/+3@X-3DM,30I(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,C8*;7-G:60@(D-E;G1E<B(*
M;7-G<W1R("*PH;_NM:4B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C4T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-3$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8U"FUS9VED(")#96YT<F%L($%F
M<FEC86X@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ-SD*;7-G:60@(D-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-CDY"FUS9VED(")#97)T:69I8V%T92!$971A:6QS(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C$Q"FUS9VED
M(")#97)T:69I8V%T92!/=VYE<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4Y-@IM<V=I9"`B0V5R=&EF:6-A=&4@
M4&]L:6-I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HR,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU,@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS
M9VED(")#:&%D(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+W)P8W-U
M;2]R<&-S=6TN:6YC.C(T('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHY
M-@IM<V=I9"`B0VAA;F=E(@IM<V=S='(@(KJOL.8B"@HC.B!S97)V:6-E<R]C
M:&%N9V5P87-S=V]R9"YP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(D-H86YG92!9
M;W5R(%!A<W-W;W)D(@IM<V=S='(@(K[/R*,@R*[`SB(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HV-@HC+"!F=7IZ>0IM<V=I9"`B(@HB0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B`B"B)E;6%I;',N(@IM<V=S='(@(KC>
MP,_`NR"ZN+.^MJ<@N^>_Z\?2(,#,N*<L(,'6O-(L(+RMN.W`NR"ZK[#FQ]6T
MS[39+B(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HR-`IM<V=I
M9"`B(@HB0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D
M('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;BX@("(*(D-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C(W"B,L(&9U>GIY
M"FUS9VED(")#:&%R(@IM<V=S='(@(G9#87)D(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(U"FUS9VED(")#
M:&5C7VL@3&EN:RXN+B(*;7-G<W1R(")?:[BUQ:D@L,N[YRXN+B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HU,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-C<*(RP@9G5Z>GD*;7-G:60@(D-H:6QE(@IM<V=S='(@(L&FN/$B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8Q(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z-30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C8W"FUS9VED(")#:&EN82(*;7-G<W1R("+!W[&Y(@H*(SH@8V]N
M9FEG+VYL<RYP:'`N9&ES=#HQ.#`*;7-G:60@(D-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*2(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T
M.C$X,0IM<V=I9"`B0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2DB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V.0HC
M+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@<&%S<W=O<F0B"FUS9W-T<B`BOL_(
MHR#(KL#.(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP.C(V
M.`HC+"!F=7IZ>0IM<V=I9"`B0VAO;W-E(&$@=7-E<FYA;64B"FUS9W-T<B`B
MN-Z]P\'V(,#;O+HB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,CDX"FUS
M9VED(")#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA
M;F<N:G,Z,C(*;7-G:60@(D-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*2(*;7-G<W1R("*\^+RM(+BNO;K&KB#!OK?Y(+RQQ<,B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-34*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8X"FUS9VED(")#:')I<W1M87,@27-L86YD(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4RYP:'`Z,CDT(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HX.3,*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@
M(D-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+B(*;7-G<W1R("+%
MZ\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"TS[39+B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C$T"B,L(&9U>GIY
M"FUS9VED(")#;&5A<B(*;7-G<W1R("*TWK?"(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHT,@IM<V=I9"`B0VQE87(@35-/
M9F9I8V4@=&%G<R(*;7-G<W1R(")-4[_`Q\>]NB#%U['7(,'VO^RQXB(*"B,Z
M(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,C@*(RP@9G5Z>GD*;7-G:60@(D-L96%R
M(%%U97)Y(@IM<V=S='(@(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V-L96%R+FEN8SHU"B,L(&9U>GIY+"!P:'`M9F]R;6%T
M"FUS9VED(")#;&5A<B!O=70@=7-E<CH@)7,B"FUS9W-T<B`BL,N[]L?7N/$@
MP\JQXLBM(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O8VQE87(N:6YC.C$Q
M"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(@IM<V=S='(@(K#+N_;'U[CQ
M(,/*L>+(K2(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC.C,T
M"B,L(&9U>GIY"FUS9VED(")#;&5A<B!U<V5R(&1A=&$B"FUS9W-T<B`BL,N[
M]L?7N/$@P\JQXLBM(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R
M:6YG<RYP:'`Z,34*(RP@9G5Z>GD*;7-G:60@(D-L96%R:6YG($QA=&4B"FUS
M9W-T<B`BL,N[]L?7N/$@P\JQXLBM(@H*(SH@=&5M<&QA=&5S+VUA:6YT96YA
M;F-E+VUA:6YT96YA;F-E+FAT;6PZ-C`*;7-G:60@(D-L:6-K('1O($-O;G1I
M;G5E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC
M:V%T96QL7VAT='`N<&AP.C$X-`IM<V=I9"`B0VQI8VMA=&5L;"!V:6$@2%14
M4"(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,30V('1E
M;7!L871E<R]S:&%R97,O961I="YI;F,Z,3(*;7-G:60@(D-L;W-E(%=I;F1O
M=R(*;7-G<W1R("+#HB"TW;'B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR
M-#0*(RP@9G5Z>GD*;7-G:60@(D-L;W5D<R(*;7-G<W1R("*ZN;OG(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,38*(RP@9G5Z
M>GD*;7-G:60@(D-L;W5D<R!%87)L>2(*;7-G<W1R("*ZN;OG(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,3<*(RP@9G5Z>GD*
M;7-G:60@(D-L;W5D>2(*;7-G<W1R("*ZN;OG(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HU,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C4V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-`IM<V=I
M9"`B0V]C;W,@*$ME96QI;F<I($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@=&5M
M<&QA=&5S+W!O<G1A;"]S:61E8F%R+FEN8SHR,PIM<V=I9"`B0V]L;&%P<V4@
M4VED96)A<B(*;7-G<W1R("*_WL+*N+>TZR"TW;'B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHR.`IM<V=I9"`B
M0V]L;&%P<V5D(&)O<F1E<G,B"FUS9W-T<B`BQ]7#Q,'X(+#FL.@B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8R(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-3<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8W"B,L(&9U>GIY"FUS9VED(")#;VQO;6)I82(*;7-G<W1R("*[]K'R
M(@H*(SH@;&EB+T)L;V-K+V-O;&]R+G!H<#HQ."!L:6(O0FQO8VLO8V]L;W(N
M<&AP.C(Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE
M7VQA;F<N:G,Z,CD*;7-G:60@(D-O;&]R(@IM<V=S='(@(KOVL?(B"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO0V]L;&5C=&EO;BYP:'`Z,S(T"B,Z(&9R
M86UE=V]R:R]";&]C:R]";&]C:R]#;VQL96-T:6]N+G!H<#HS,C4*(SH@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4P,"!S97)V:6-E
M<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP.C$T"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C0Y"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C4P"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8U"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8V"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@Q"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C@R"FUS9VED(")#;VQO<B!0:6-K
M97(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@T
M-@HC+"!F=7IZ>0IM<V=I9"`B0V]L;W5R('-E;&5C=&EO;B(*;7-G<W1R("*\
ML<7#N^?'USHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C$P,PIM<V=I9"`B0V]L<SHB"FUS9W-T<B`BOZTZ(@H*(SH@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-@IM<V=I9"`B0V]L=6UN('1I=&QE
M<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C8T
M"FUS9VED(")#;VUI8W,B"FUS9W-T<B`B0V]M:6-S(@H*(SH@861M:6XO8VUD
M<VAE;&PN<&AP.C(U"B,L(&9U>GIY"FUS9VED(")#;VUM86YD(@IM<V=S='(@
M(LBXN^<B"@HC.B!A9&UI;B]C;61S:&5L;"YP:'`Z,C`*(RP@9G5Z>GD*;7-G
M:60@(D-O;6UA;F0@4VAE;&PB"FUS9W-T<B`BR+B[YR(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,PHC+"!F=7IZ>0IM<V=I9"`B0V]M
M;65N="(*;7-G<W1R("+(N+OG(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU-C8*(RP@9G5Z>GD*;7-G:60@(D-O;6UO;B!.86UE(@IM
M<V=S='(@(L#,N*<Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,S`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HU.`HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*(RP@9G5Z>GD*;7-G:60@(D-O
M;6]R;W,B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR,SD*;7-G:60@(D-O;7!A;GDB"FUS9W-T
M<B`BR+B[YR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS,0HC+"!F=7IZ
M>0IM<V=I9"`B0V]M<'5T97)S(@IM<V=S='(@(KOU(+C>P,\B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,CDW"B,L(&9U>GIY"FUS9VED(")#
M;VYD:71I;VXB"FUS9W-T<B`BL.&WT"(*"B,Z(&QI8B]";&]C:R]M971A<BYP
M:'`Z,C0Y"B,L(&9U>GIY"FUS9VED(")#;VYD:71I;VYS(@IM<V=S='(@(K#A
MM]`B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HY-@IM<V=I9"`B0V]N9FEG
M=7)A=&EO;B!$:69F97)E;F-E<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,30S"FUS9VED(")#;VYF:6=U<F%T:6]N(&9O<B!S>6YC
M:6YG('=I=&@@4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN(@IM<V=S
M='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ,S4*;7-G:60@(D-O
M;F9I9W5R871I;VX@:7,@;W5T(&]F(&1A=&4N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ,#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B
M0V]N9FEG=7)E("5S(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+W5P9&%T92YI;F,Z-3$*;7-G:60@(D-O;F9I<FT@4&%S<W=O<F0B"FUS
M9W-T<B`BOL_(HR#(KL#.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HU-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C4Y"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@HC+"!F=7IZ>0IM<V=I9"`B
M0V]N9V\B"FUS9W-T<B`BN=ZTPB"[Y[;W(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HU,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-0IM<V=I9"`B
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H92(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S$P
M"B,L(&9U>GIY"FUS9VED(")#;VYN96-T:6]N(&9A:6QE9"XB"FUS9W-T<B`B
MN^C!IB"]Q\;0(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X
M-BYP:'`Z,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N
M<&AP.C,Q,`HC+"!F=7IZ>0IM<V=I9"`B0V]N;F5C=&EO;B!F86EL960Z("(*
M;7-G<W1R("*[Z,&F(+W'QM`B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HW.3`*(RP@9G5Z>GD*;7-G:60@(D-O;FYE8W1I;VX@<F5F=7-E
M9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BXB"FUS9W-T<B`B9G1P(+RMN?8@
MOZRPX2"_P+?Y+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP
M.C<Y,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RDB"FUS9W-T<B`B9G1P(+RMN?8@OZRPX2"_P+?Y+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+V9T<"YP:'`Z.#0U"B,L(&9U>GIY"FUS9VED(")#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+B(*;7-G<W1R(")F='`@O*VY]B"_
MK+#A(+_`M_DN(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.C$P,30*;7-G
M:60@(D-O;G1A8W1S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HU,PHC+"!F=7IZ>0IM<V=I9"`B0V]N=&%C
M=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN(@IM<V=S='(@(L?7N/$@7"(E<UPBL*$@P=:\TK?/OZ$@P]^PH;7'OOJ]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F%R+G!H
M<#HU-B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z:7`N<&AP.C8S"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP:'`Z-S@*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D-O;G1E;G1S(&]F(%PB)7-<(B(*;7-G
M<W1R("(G)7,GP,<@L[N_ZR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N
M<&AP.C(Y('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS,PHC+"!F=7IZ
M>0IM<V=I9"`B0V]N=&EN=64B"FUS9W-T<B`BL.&WT"(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HV,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*
M;7-G:60@(D-O;VL@27-L86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M9F]R='5N92YP:'`Z,S(*(RP@9G5Z>GD*;7-G:60@(D-O;VMI92(*;7-G<W1R
M("*[]2"XWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(Q"FUS9VED(")#;W!Y(@IM<V=S='(@(KJYN^<B
M"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]P>2!F86EL960Z("5S(@IM<V=S='(@(KOH
MP:8@O<?&T"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,S8*;7-G:60@(D-O<'D@<V5L96-T:6]N(@IM<V=S='(@(KJYN^<B
M"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$W,`HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$Y-0IM<V=I
M9"`B0V]S="!)1"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C8S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C(*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C8W"FUS9VED(")#;W-T
M82!2:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z-3<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV,PHC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C8*;7-G:60@(D-O=&4@9"=)
M=F]I<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G
M<"YP:'`Z.3<V"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4$=0(&5N8W)Y
M<'0@;65S<V%G92XB"FUS9W-T<B`B,;"SP,<@N_6WSK_N(+C>O</!]K"A(,#6
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C$P
M-3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E
M+B(*;7-G<W1R("(QL+/`QR"[];?.O^X@N-Z]P\'VL*$@P-:]P+3/M-DN(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HS.3,*(RP@9G5Z
M>GD*;7-G:60@(D-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+B(*
M;7-G<W1R("*XWKW#P?8@P/R\VR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-#8W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@4R]-
M24U%('-I9VX@;65S<V%G92XB"FUS9W-T<B`B,;"SP,<@N_6WSK_N(+C>O</!
M]K"A(,#6O<"TS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z,3@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S(@IM<V=S='(@(B5SN*8@O[&T
MS[39/R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HY-B!F
M<F%M97=O<FLO075T:"]!=71H+VQD87`N<&AP.C$R,0HC+"!F=7IZ>0IM<V=I
M9"`B0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$
M05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z
M-#4W"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E
M<G9E<B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HQ-38*(SH@9G)A
M;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,3<S"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,B"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C0T,0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@;&1A<"!S97)V97(B"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@
MO<?&T"(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HT.`HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M(%PB)7-<(B!U<VEN9R!&5%`Z("5S(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3
M(+W'QM`B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT
M='`N<&AP.C,R,@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@
M;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`BOK*Q
MXK"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HQ,3(U"FUS9VED(")#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T82XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HU,C(*;7-G:60@(D-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O<VUS,F5M86EL7VAT='`N<&AP.C(T-@HC+"!F=7IZ>2P@<&AP+69O<FUA
M=`IM<V=I9"`B0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<R(*;7-G<W1R
M(")(;W)D9;"A(+G9N*.PU""\L\&DM<?!]B"^RK[2O<"TS[39+B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,S4V"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@9&5L971E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<R(*;7-G<W1R(")(;W)D9;"A(+G9N*.PU""\
ML\&DM<?!]B"^RK[2O<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N
M<&AP.C,X"B,L('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!D96QE=&4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,X,2!F<F%M97=O<FLO
M0W)Y<'0O0W)Y<'0O<&=P+G!H<#HY-3,*(RP@9G5Z>GD*;7-G:60@(D-O=6QD
M(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S
M+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C(X,PHC+"!F=7IZ>0IM
M<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RXB
M"FUS9W-T<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C0Y,PHC
M+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+B(*;7-G<W1R(")-86EN=&5N86YC95]487-K(+CPM>(@
M)7/`NRBXIBD@OZT@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT-#8*;7-G:60@(D-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE3
M3U=R:71E<B]296%L3W5T<'5T4W1R871E9WDN<&AP.C8X"B,Z(&9R86UE=V]R
M:R]61E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2YP
M:'`Z.#0*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!L
M;V%D('-T<F%T96=Y(%PB)7-<(BXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*
M(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V-O<'DN<&AP.C$Q,`HC.B!F<F%M97=O<FLO5D937TE33U=R
M:71E<B])4T]7<FET97(O4F5A;$]U='!U=%-T<F%T96=Y+V1I<F5C="YP:'`Z
M,S`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO="!M:V1I
M<B!<(B5S7"(N(@IM<V=S='(@(B5SN*8@O[&TS[39/R(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]P9W`N<&AP.C<Q.0HC+"!F=7IZ>0IM<V=I9"`B0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BXB
M"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE=V]R:R]6
M1E-?25-/5W)I=&5R+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y
M+G!H<#HQ,SD*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-O=6QD(&YO
M="!O<&5N(%PB)7-<(B!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B)7.XIB"_L;3/
MM-D_(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV-S<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,S0U"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T
M<"YP:'`Z,C8R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N
M;W0@;W!E;B`E<RXB"FUS9W-T<B`B)7.XIB"_L;3/M-D_(@H*(SH@9G)A;65W
M;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H<#HT,3@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,B"FUS9W-T<B`B36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S(+BF
M(+^M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R
M+TE33U=R:71E<B]296%L26YP=713=')A=&5G>2]C;W!Y+G!H<#HW,`HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T(&]P96X@9&ER96-T
M;W)Y(%PB)7-<(BXB"FUS9W-T<B`B36%I;G1E;F%N8V5?5&%S:R"X\+7B("5S
MP+LHN*8I(+^M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'
M<F]U<"]L9&%P+G!H<#HQ,3$@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N
M<&AP.C$T-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z,C,W
M(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H<#HT-S@*(SH@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C4Q-B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z-C$R"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L
M9&%P+G!H<#HV-38@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C8Y
M.0HC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BXB"FUS9W-T<B`B3$1!4""\K;GV(,&BO-,@O<?&T"(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+T]B:F5C="YP:'`Z,C,X"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")#;W5L9"!N;W0@<F5A9"`E<RXB"FUS9W-T<B`B)7.XIB"_
ML;3/M-D_(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z.#4*(RP@
M9G5Z>GD*;7-G:60@(B(*(D-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@
M9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE("(*
M(F1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@(@HB9G5R=&AE<B!H
M96QP+B(*;7-G<W1R("(B"B+#W["AQ\^TPK6E(+_`M_FPH2"YW[O]Q]^]P+3/
MM-DN(+W#O;K%V[#\N*[`VK^AL-0@M;6_\L"[(+_DP[O'S[W#L>(@N=FV^+3/
MM-DN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,S`Y"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,T
M,`HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS-S<*
M(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z,S@S"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C,X.0HC+"!F
M=7IZ>0IM<V=I9"`B0V]U;&0@;F]T(')E=')I979E($%#3"(*;7-G<W1R("*^
MLK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z,C<T"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<R(*;7-G<W1R("*^LK'BL*&TR<?1(,'6O-*WS\#,(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-#@T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@
M<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S(@IM<V=S='(@(KZRL>*P
MH;3)Q]$@P=:\TK?/P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TYE=%]3
M35,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HT,S<*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S(@IM<V=S='(@(KZRL>*PH;3)Q]$@P=:\TK?/P,P@OOB]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z
M,3DY"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(Q
M.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HR,C,*
M(RP@9G5Z>GD*;7-G:60@(D-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C
M87!A8FEL:71I97,B"FUS9W-T<B`BOK*QXK"AM,G'T2#!UKS2M\_`S""^^+W`
MM,^TV2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4T"B,L(&9U>GIY
M"FUS9VED(")#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN(@IM<V=S
M='(@(DAO<F1EL*$@N=FXH[#4(+RSP:2UQ\'V(+[*OM*]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T
M<F%T96=Y+V-O<'DN<&AP.CDT"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<FUD:7(@7"(E<UPB+B(*;7-G<W1R("(E<[BF(+^QM,^T
MV3\B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HW,PHC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]
MP+3/M-DN(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C8S(&%D;6EN+W-E
M='5P+W-C<FEP=',N<&AP.C4Y"B,L(&9U>GIY"FUS9VED(")#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN(@IM<V=S='(@(E9&4R"\L\&D
M(,&DNKB_H;RM("=P;W)T)\#,(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P
M+VEN9&5X+G!H<#HV,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<R(*;7-G<W1R
M(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!A
M9&UI;B]S971U<"]S8W)I<'1S+G!H<#HY-0HC+"!P:'`M9F]R;6%T"FUS9VED
M(")#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@7"(E
M<UPB+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C8T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")#;W5L9"!N;W0@<V%V92!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB"FUS9W-T<B`B5D93
M(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@861M:6XO
M<V5T=7`O8V]N9FEG+G!H<#HW-0HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)#
M;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@
M8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92`B"B)O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+VQD87`N<&AP.C$T,PHC+"!F=7IZ>0IM<V=I9"`B0V]U;&0@;F]T('-E
M87)C:"!T:&4@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3
M(+W'QM`B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z.#8*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(D-O=6QD(&YO="!U;FQI;FL@7"(E<UPB+B(*;7-G<W1R
M("(E<[BF(+^QM,^TV3\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.C(Q.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(*;7-G<W1R("(E<[BF
M(+^QM,^TV3\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL
M7VAT='`N<&AP.C,Y-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,B"FUS9W-T<B`B
M36%I;G1E;F%N8V5?5&%S:R"X\+7B("5SP+LHN*8I(+^M(+SV(+[XO<"TS[39
M+B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,`HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@
M9F]R(%PB)7-<(CH@)7,B"FUS9W-T<B`B2&]R9&6PH2"YV;BCL-0@O+/!I+7'
MP?8@OLJ^TKW`M,^TV2XB"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S8V
M"FUS9VED(")#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA
M:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HQ-30*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B(@HB0V]U;&1N)W0@9VEV92!U<V5R(%PB)7-<(B!T
M:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B!<(B5S7"(Z("5S
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,3D*
M(RP@9G5Z>GD*;7-G:60@(D-O=6YT960@=&5X="(*;7-G<W1R("*QL\&DM<@@
MN:[`VK^M(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-CD*(RP@9G5Z>GD*;7-G:60@(D-O=6YT<GDB"FUS9W-T<B`BN_4@N-[`SR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR-S,*(RP@9G5Z>GD*;7-G
M:60@(D-O=7)S97,B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHR,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI
M;F,Z.38*(SH@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`IM<V=I
M9"`B0W)E871E(@IM<V=S='(@(KBXM>FQXB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV.`IM<V=I9"`B0W)E
M871E(&$@;&EN:R(*;7-G<W1R("*XM<6I(+BXM>FQXB(*"B,Z('1E;7!L871E
M<R]P<F5F<R]I9&5N=&ET>7-E;&5C="YI;F,Z.30*(RP@9G5Z>GD*;7-G:60@
M(D-R96%T92!A(&YE=R!O;F4B"FUS9W-T<B`BR-[!]L7K(+OUM\X@N+BUZ;'B
M(@H*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3(*
M(RP@9G5Z>GD*;7-G:60@(D-R96%T92!S=6(@9F]L9&5R<R(*;7-G<W1R("*[
M]<;ZM/4@N+BUZ;'B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H
M<#HR-#`*(RP@9G5Z>GD*;7-G:60@(D-R96%T;W(@4&5R;6ES<VEO;G,B"FUS
M9W-T<B`BN^>_Z\#:(+''Q]$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HS,C,P"B,L(&9U>GIY"FUS9VED(")#<F5D:70@8V%R9"!N=6UB97(B"FUS
M9W-T<B`BO/W`VB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`Y
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C0*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")#<F]A
M=&EA(@IM<V=S='(@(KBXM>FQXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HV-0HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-C@*;7-G:60@(D-U8F$B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(V"B,L(&9U>GIY
M"FUS9VED(")#=7)R96YT(#0@4&AA<V5S(@IM<V=S='(@(L?VP.<@O;K%N,#/
M(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C0X"B,L(&9U>GIY"FUS9VED(")#
M=7)R96YT(%-E<W-I;VYS(@IM<V=S='(@(L?VP.<@55),P+HB"@HC.B!L:6(O
M0FQO8VLO=&EM92YP:'`Z,R!L:6(O0FQO8VLO=&EM92YP:'`Z,S`*(RP@9G5Z
M>GD*;7-G:60@(D-U<G)E;G0@5&EM92(*;7-G<W1R("*QL\&DM<@@N:[`VK^M
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L
M86YG+FIS.C4T"FUS9VED(")#=7)R96YT(%523"!I<R(*;7-G<W1R("+']L#G
M(%523,"Z(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C,S"B,L(&9U>GIY"FUS
M9VED(")#=7)R96YT(%5S97)S(@IM<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HR-0HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!796%T:&5R(@IM<V=S='(@(L?VP.<@O;K%N,#/(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VTN<&AP.C(W-0HC+"!F=7IZ>0IM<V=I9"`B0W5R<F5N
M="!C;VYD:71I;VXZ("(*;7-G<W1R("*PX;?0(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,@IM<V=I9"`B0W5R<F5N="!S
M='EL92(*;7-G<W1R("+']L#G(+VZQ;C`SR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,#@*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D-U<W1O
M;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RXB"FUS9W-T<B`B
M24U0(+?.L=>_PKW#(+W#P-NUQ[3"(,#;OO?`NR"\L\&DQ]6TS[39+B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ
M<SHR,`IM<V=I9"`B0W5T(@IM<V=S='(@(L#:N*.QXB(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,S4*;7-G:60@(D-U="!S
M96QE8W1I;VXB"FUS9W-T<B`BP-JXH['B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HV-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C8V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.`IM<V=I9"`B
M0WEP<G5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@R
M"FUS9VED(")#>7)I;&QI8R`H2T])."U2*2(*;7-G<W1R("(B"@HC.B!C;VYF
M:6<O;FQS+G!H<"YD:7-T.C$X,PIM<V=I9"`B0WER:6QL:6,@*%=I;F1O=W,M
M,3(U,2DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.#0*
M;7-G:60@(D-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*2(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C8X(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-C<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C8Y"B,L(&9U>GIY"FUS9VED(")#>F5C:"!297!U8FQI8R(*
M;7-G<W1R("*TZ\?1N<ZQN2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD
M97)E<B]H=&UL+G!H<#HT-3$@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#<*
M(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#@@=&5M<&QA=&5S+V1A=&$O
M9&%T92YI;F,Z-#D*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-3`*;7-G
M:60@(D1$(@IM<V=S='(@(D1$(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S(X,0IM<V=I9"`B(@HB1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP
M*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E
M;F%N8V4N<&AP.C4Y"FUS9VED(")$86EL>2(*;7-G<W1R("+`S[JP(@H*(SH@
M861M:6XO9&%T871R964N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")$871A5')E
M92!"<F]W<V5R(@IM<V=S='(@(L#/P-HB"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,C<Y"FUS9VED(")$871A8F%S92!,;V]K=7`B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW
M,B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,SDY"FUS9VED(")$871E(@IM
M<V=S='(@(K.OPJ4B"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E
M+FEN8SHQ,PHC+"!F=7IZ>0IM<V=I9"`B1&%T92!296-E:79E9"(*;7-G<W1R
M("*\]KW%(+.OPJ4Z(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@P
M-PHC+"!F=7IZ>0IM<V=I9"`B1&%T92!S96QE8W1I;VXB"FUS9W-T<B`BP-JX
MH['B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y,B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S(R"B,L(&9U>GIY"FUS9VED(")$
M87DB"FUS9W-T<B`BP,^ZL"(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-@IM<V=I9"`B1&5?;&5T92!#;VQU
M;6XB"FUS9W-T<B`B7VR_K2"[Z,&F(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A
M<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#4P"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+V]P96Y?8V%L96YD87(N:G,Z-S8*;7-G:60@(D1E8V5M8F5R(@IM<V=S='(@
M(C$RO_DB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L:7-T
M='EP95]L86YG+FIS.C$V"FUS9VED(")$96-I;6%L(&YU;6)E<G,B"FUS9W-T
M<B`BO/W`VB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,C`*;7-G:60@(D1E8W)E87-E($EN9&5N="(*;7-G<W1R("*SN[[N
MOK*QXB(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]522YP:'`Z,3@W(&QI
M8B]P<F5F<RYP:'`Z,3$W"FUS9VED(")$969A=6QT(@IM<V=S='(@(K'BNKLB
M"@HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHT
M-0HC.B!T96UP;&%T97,O<')E9G,O8V%T96=O<GEM86YA9V5M96YT+FEN8SHW
M-PHC+"!F=7IZ>0IM<V=I9"`B1&5F875L="!#;VQO<B(*;7-G<W1R("*QXKJ[
ML*H@N^>_ZR(*"B,Z(&9R86UE=V]R:R])9&5N=&ET>2])9&5N=&ET>2YP:'`Z
M.3$*;7-G:60@(D1E9F%U;'0@261E;G1I='DB"FUS9W-T<B`BL>*ZNR"]Q+JP
MP-HB"@HC.B!L:6(O0FQO8VLO86-C;W5N="YP:'`Z-C<*(RP@9G5Z>GD*;7-G
M:60@(D1E9F%U;'0@4VAE;&PB"FUS9W-T<B`BL>*ZNR(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS,PHC+"!F=7IZ>0IM<V=I9"`B1&5F:6YI=&EO;G,B
M"FUS9W-T<B`BL=3$HB#!I,#'(@H*(SH@861M:6XO9W)O=7!S+G!H<#HW,2!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,N<&AP.C,R-@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C0R,B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C0S.0HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,V('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-S`*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHY,R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-@HC.B!T
M96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.2!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z
M-S,@=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.CDX"B,Z('1E;7!L871E
M<R]A9&UI;B]G<F]U<',O9&5L971E+FEN8SHQ,"!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHS,0IM<V=I9"`B1&5L971E(@IM<V=S='(@(KOHP:8B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z,S(*(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!#96QL(@IM<V=S='(@
M(KR_(+OHP:8B"@HC.B!A9&UI;B]G<F]U<',N<&AP.C$Y.2!A9&UI;B]G<F]U
M<',N<&AP.C(R-PHC+"!F=7IZ>0IM<V=I9"`B1&5L971E($=R;W5P(@IM<V=S
M='(@(KOHP:8B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-#D*
M(RP@9G5Z>GD*;7-G:60@(D1E;&5T92!,;V<B"FUS9W-T<B`BQ^`@N^C!IB(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z-S<@9G)A;65W;W)K
M+U!E<FUS+U!E<FUS+U5)+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(D1E;&5T
M92!097)M:7-S:6]N(@IM<V=S='(@(KC>O</!]B"[Z,&F(@H*(SH@9G)A;65W
M;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.3,*(RP@9G5Z>GD*;7-G
M:60@(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B"FUS9W-T<B`BN^C!IK7(
M(+C>P,\B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C4W"FUS9VED(")$96QE=&4@8V5L;"(*;7-G<W1R("*\OR"[
MZ,&F(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHV,PIM<V=I9"`B1&5L971E(&-O;'5M;B(*;7-G<W1R("*_K2"[
MZ,&F(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ-#@*;7-G:60@(D1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HT,C$*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB
M(@IM<V=S='(@(B5S(+''Q]$@O/;!I"(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z-#(T"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T92!P
M97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS
M/R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C8W"FUS9VED(")$96QE=&4@<F]W(@IM<V=S='(@
M(L?@(+OHP:8B"@HC.B!T96UP;&%T97,O<')E9G,O9&5L971E:61E;G1I='DN
M:6YC.C$U"B,L(&9U>GIY"FUS9VED(")$96QE=&4@<V5L96-T960@:61E;G1I
M='DB"FUS9W-T<B`BO<2ZL,#:(+RQQ<,B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C<*;7-G:60@(D1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6XB"FUS9W-T<B`BQ_;`YR"_K2#!]K_R(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG
M+FIS.C8S"FUS9VED(")$96QE=&4@=&AE(&-U<G)E;G0@<F]W(@IM<V=S='(@
M(L?VP.<@Q^`@P?:_\B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.C,V
M"B,L('!H<"UF;W)M870*;7-G:60@(D1E;&5T960@<V5T=7`@=7!G<F%D92!S
M8W)I<'0@7"(E<UPB+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V,PHC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Y-0HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C$*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C4S"B,L(&9U
M>GIY"FUS9VED(")$96QI=F5R>2!T:6UE(@IM<V=S='(@(KOHP:8B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<Q(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z-C@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C8Y"FUS9VED(")$96YM87)K(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]P<F]B;&5M+W!R;V)L96TN:6YC.C(Y"FUS9VED(")$97-C<FEB92!T:&4@
M4')O8FQE;2(*;7-G<W1R("*_P+?Y(+RSN.TB"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HY,S@@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M=&%B;&5?;&%N9RYJ<SHS,`IM<V=I9"`B1&5S8W)I<'1I;VXB"FUS9W-T<B`B
MO+.X[3HB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y-0IM<V=I
M9"`B1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C$Y.0IM<V=I9"`B
M1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O
M<BXB"FUS9W-T<B`BO+RZSL&DNKBPH2"P_+BNP-JXIB#`I\?8(+'BM\^UQ[[N
MP;.]P+3/M-DN(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(Q.0IM
M<V=I9"`B1&5V96QO<&UE;G0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,3<*;7-G:60@(D1E=R!0;VEN="(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO;65T87(N<&AP.C(Y-`IM<V=I9"`B1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O
M=&-O;2YP:'`Z,C(W"FUS9VED(")$97<@<&]I;G0Z("(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,X"FUS
M9VED(")$:7)E8W1I;VX@;&5F="!T;R!R:6=H="(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C,Y"FUS9VED
M(")$:7)E8W1I;VX@<FEG:'0@=&\@;&5F="(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO9V]O9VQE+G!H<#HS.0IM<V=I9"`B1&ER96-T;W)Y(@IM<V=S='(@
M(K7PM[K%Y+BN(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(V-@HC+"!F
M=7IZ>0IM<V=I9"`B1&ES<&QA>2`R-"UH;W5R('1I;65S/R(*;7-G<W1R("+(
MK;CI(+RSP:0B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3<*;7-G:60@
M(D1I<W!L87D@3W!T:6]N<R(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z.38*(RP@9G5Z>GD*;7-G:60@(D1I
M<W!L87D@9&5T86EL960@9F]R96-A<W0B"FUS9W-T<B`BR*VXZ2"\L\&D(@H*
M(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HX-0HC+"!F=7IZ>0IM<V=I9"`B1&ES
M<&QA>2!F;W)E8V%S="`H5$%&*2(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$W"B,L(&9U>GIY"FUS9VED(")$
M:7-P;&%Y(&9O<FUA="(*;7-G<W1R("+(K;CI(+RSP:0B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+TU$3BYP:'`Z,3DP"FUS9VED(")$:7-P;W-I=&EO;B!.
M;W1I9FEC871I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HW,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C8Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV.0IM<V=I9"`B1&II
M8F]U=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HT,C(*(RP@9G5Z>GD*;7-G:60@(D1O(&YO="!D96QE=&4B"FUS9W-T
M<B`BNKFQN"(*"B,Z('-E<G9I8V5S+VUA:6YT96YA;F-E+G!H<#HR-0IM<V=I
M9"`B1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'`B"FUS
M9W-T<B`B;6%I;G1E;F%N8V4N<&APOZ$@P??!HB#!HK'9Q\_!]B"XMKR\O^0N
M(@H*(SH@=&5M<&QA=&5S+V1A=&$O='-V:6YF;RYI;F,Z,3(@=&5M<&QA=&5S
M+V1A=&$O8W-V:6YF;RYI;F,Z,3(*;7-G:60@(D1O97,@=&AE(&9I<G-T(')O
M=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES
M(&)O>#HB"FUS9W-T<B`BP[FY^,*P(,?@P+H@Q]>X\2#`S+BGP+L@L*ZP[2#`
MUKW`M,^Q[C\@L=>WN+39N.DL(+^IL>*XIB##O,6IQ\^\O+_D.B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z-S(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-CD*;7-G:60@(D1O;6EN:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z-S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HW,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S`*
M(RP@9G5Z>GD*;7-G:60@(D1O;6EN:6-A;B!297!U8FQI8R(*;7-G<W1R("*T
MZ\?1N<ZQN2(*"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z.38*;7-G
M:60@(D1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"XB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#0T"FUS
M9VED(")$;W=N;&]A9"(*;7-G<W1R("*SN[?!N=ZQXB(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O0V]N=&5N=',N<&AP.C@T-`HC+"!P:'`M9F]R;6%T"FUS
M9VED(")$;W=N;&]A9"`E<R(*;7-G<W1R("(E<R"SN[?!N=ZQXB(*"B,Z(&%D
M;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C(*;7-G:60@(D1O=VYL;V%D(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q,#<*;7-G:60@(D1R;W`@
M9&]W;B!L:7-T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H
M<#HS-`HC+"!F=7IZ>0IM<V=I9"`B1')U9W,B"FUS9W-T<B`BN?JWN;7I(@H*
M(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"B,L(&9U>GIY
M"FUS9VED(")%+4UA:6PB"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V=E;F5R:6-?<VUT<"YP:'`Z.3(*;7-G:60@(D5-86EL
M+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R
M;W9I9&4@=&AI<R!S97)V:6-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M.C,T"FUS9VED(")%4E(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16-U861O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,N
M<&AP.C,R-2!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,U"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z-CD@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHY,@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$Q-2!T96UP
M;&%T97,O<VAA<F5S+V5D:70N:6YC.C$S.`HC.B!T96UP;&%T97,O<VAA<F5S
M+V5D:70N:6YC.C$X,2!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z-S(*
M(SH@=&5M<&QA=&5S+W!O<G1A;"]E9&ET+FEN8SHR-0IM<V=I9"`B161I="(*
M;7-G<W1R("*\]L&D(@H*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+U5)+G!H
M<#HU,"!T96UP;&%T97,O<&]R=&%L+V5D:70N:6YC.C(U"FUS9VED(")%9&ET
M($)L;V-K(@IM<V=S='(@(B(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,3DX(&%D
M;6EN+V=R;W5P<RYP:'`Z,C(V"B,L(&9U>GIY"FUS9VED(")%9&ET($=R;W5P
M(@IM<V=S='(@(KOHP:8B"@HC.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN
M<&AP.C<V(&9R86UE=V]R:R]097)M<R]097)M<R]522YP:'`Z,3`P"B,L(&9U
M>GIY"FUS9VED(")%9&ET(%!E<FUI<W-I;VXB"FUS9W-T<B`BL+/`SB"XWL#/
M(@H*(SH@<V5R=FEC97,O<VAA<F5S+V5D:70N<&AP.C(S-PHC+"!F=7IZ>0IM
M<V=I9"`B161I="!097)M:7-S:6]N<R(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,Y"B,L('!H<"UF;W)M
M870*;7-G:60@(D5D:70@4&5R;6ES<VEO;G,@9F]R("5S(@IM<V=S='(@(B5S
M(+''Q]$@O/;!I"(*"B,Z('1E;7!L871E<R]P<F5F<R]A<'`N:6YC.C4*;7-G
M:60@(D5D:70@;W!T:6]N<R!F;W(Z(@IM<V=S='(@(KRQQ<.[Y\?7(+SVP:0Z
M(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HS-C<*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(D5D:70@<&5R;6ES<VEO;G,@9F]R(%PB
M)7-<(B(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B"@HC.B!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$T"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")%
M9&ET('!E<FUI<W-I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R"QQ\?1(+SVP:0B
M"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S4*(RP@9G5Z>GD*;7-G:60@
M(D5D=6-A=&EO;B(*;7-G<W1R("*\TK"S(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HW-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP
M.C<S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW,`IM<V=I9"`B
M16=Y<'0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HS,3`*(RP@<&AP+69O<FUA=`IM<V=I9"`B16ET:&5R(&5N86)L92!I="!T
M:&5N.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-R!F
M<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C<T"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#<*;7-G:60@(D5L(%-A;'9A9&]R(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O
M;G1E>'1?;&%N9RYJ<SHT,PIM<V=I9"`B16QE;65N="XN+B(*;7-G<W1R("*_
MY+S2+BXN(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N
M9RYJ<SHQ,#D*;7-G:60@(D5M(@IM<V=S='(@(F5M(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C(R-"!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ.#8Y"FUS9VED(")%;6%I;"(*;7-G<W1R("+`S+C>P,\B
M"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-2!T96UP
M;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C$P"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W5P9&%T92YI;F,Z-C@*(RP@9G5Z>GD*;7-G:60@(D5M86EL
M($%D9')E<W,B"FUS9W-T<B`BP,RXWL#/(,'6O-(Z(@H*(SH@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,3DV,PHC+"!F=7IZ>0IM<V=I9"`B16UA:6P@861D
M<F5S<V5S(&UU<W0@;6%T8V@N(@IM<V=S='(@(K[/R*.PH2#`S\2AQ\_!]B"^
MRKW`M,^TV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.3@Y"B,L
M(&9U>GIY"FUS9VED(")%;6%I;"!W:71H(&-O;F9I<FUA=&EO;B(*;7-G<W1R
M("*QXL6X(,&DNK@B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O9V5N97)I
M8U]S;71P+G!H<#HY,0IM<V=I9"`B16UA:6PM=&\M4TU3($=A=&5W87DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(Y.`IM<V=I9"`B16UO=&EC;VYS(@IM<V=S='(@(L#,N/#&O,3<(@H*
M(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z
M,S`R"B,L(&9U>GIY"FUS9VED(")%;7!T>2!M97-S86=E+B(*;7-G<W1R("+!
MW[_DQ]$@N-[`SR(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HR-#,@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP.C0X-`HC.B!F
M<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-C8R(&9R86UE=V]R:R]'
M<F]U<"]'<F]U<"]L9&%P+G!H<#HW,#4*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]L9&%P+G!H<#HQ-3`*;7-G:60@(D5M<'1Y(')E<W5L="XB"FUS9W-T<B`B
ML.&P^B"^^,"](@H*(SH@9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP
M.C$Q,PIM<V=I9"`B16UP='D@<V5A<F-H('1E<FUS(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU-#,*;7-G:60@(D5N86)L92!I;G-E
M<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HU,3@*;7-G
M:60@(D5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(U.3@@9G)A;65W;W)K
M+T9O<FTO1F]R;2YP:'`Z,C@Q,0HC+"!F=7IZ>0IM<V=I9"`B16YD('EE87(B
M"FUS9W-T<B`BO]["RKBWM.L@R*[`Y2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,CD*;7-G:60@(D5N;&%R9V4@161I=&]R
M(@IM<V=S='(@(L;MP?VQXB#(KK3K(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(R,0IM<V=I9"`B(@HB16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W
M:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y
M;W5R("(*(G!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO
M=7(@<&5T/R<Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$Y"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N9RYJ<SHR,@IM<V=I9"`B16YT97(@
M=&AE(&EM86=E(%523"!H97)E(@IM<V=S='(@(K'7N+(@55),(,#4M\(B"@HC
M.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.#DQ"FUS
M9VED(")%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SHB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C<U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HW-@IM<V=I9"`B17%U871O<FEA;"!'=6EN96$B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HW,0IM<V=I9"`B17)I=')E82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T
M=7,N<&AP.C(W"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HT-2!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-34*(SH@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HS-B!S97)V:6-E<R]P;W)T86PO:6YD97@N<&AP.C@R"FUS9VED
M(")%<G)O<B(*;7-G<W1R("*_P+?Y(@H*(SH@9G)A;65W;W)K+U1E;7!L871E
M+U1E;7!L871E+G!H<#HT-C,*(RP@<&AP+69O<FUA=`IM<V=I9"`B17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S(@IM<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O
M<G1A;"]S>6YC;6PN<&AP.C<R"B,L('!H<"UF;W)M870*;7-G:60@(D5R<F]R
M(&1E;&5T:6YG('-Y;F,@86YC:&]R.B`E<R(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HX,PHC+"!P:'`M9F]R;6%T"FUS9VED
M(")%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U1E;7!L871E+U1E;7!L871E+G!H<#HT-C@*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<R(*;7-G<W1R
M("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z-S8*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P-0IM<V=I9"`B17)R;W(@=VET:"!E;6%I;"!M97-S86=E
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7
M<FET97(O4F5A;$EN<'5T4W1R871E9WDO8V]P>2YP:'`Z,30R"B,L('!H<"UF
M;W)M870*;7-G:60@(D5R<F]R('=R:71I;F<@7"(E<UPB+B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C<V(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z-S<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C<P"FUS9VED(")%<W1O;FEA(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HW.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z-S$*;7-G:60@(D5T:&EO<&EA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]F;W)T=6YE+G!H<#HS-@IM<V=I9"`B171H;FEC(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HU-0IM<V=I9"`B175R;W!E
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,SD*;7-G
M:60@(D5V97)Y(#$U(&UI;G5T97,B"FUS9W-T<B`B,36ZT""XMK39(@H*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C,X.0HC+"!F=7IZ>0IM<V=I9"`B179E
M<GD@,B!M:6YU=&5S(@IM<V=S='(@(C6ZT""XMK39(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C,S-B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@W"FUS
M9VED(")%=F5R>2`S,"!S96-O;F1S(@IM<V=S='(@(C,PP\H@N+:TV2(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S@@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C,Y,`IM<V=I9"`B179E<GD@-2!M:6YU=&5S(@IM<V=S='(@(C6ZT""X
MMK39(@H*(SH@9G)A;65W;W)K+TUA:6YT96YA;F-E+TUA:6YT96YA;F-E+G!H
M<#HV,`IM<V=I9"`B179E<GD@3&]G:6XB"FUS9W-T<B`BN/"UYR"WSK'7P,XB
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S0P"FUS9VED(")%=F5R>2!H
M86QF(&AO=7(B"FUS9W-T<B`B,S"ZT""XMK39(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,S-R!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S@X"FUS9VED
M(")%=F5R>2!M:6YU=&4B"FUS9W-T<B`BN,6ZT"(*"B,Z('1E;7!L871E<R]D
M871A+V1A=&5M87`N:6YC.C(T"FUS9VED(")%>&%M<&QE('9A;'5E<SHB"FUS
M9W-T<B`BO[DZ(@H*(SH@861M:6XO<&AP<VAE;&PN<&AP.C@Q(&%D;6EN+V-M
M9'-H96QL+G!H<#HU,"!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(W"FUS9VED(")%
M>&5C=71E(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],
M87EO=70N<&AP.C0W-0HC+"!F=7IZ>0IM<V=I9"`B17AP86YD(@IM<V=S='(@
M(KCPM<X@R*[`Y2(*"B,Z('1E;7!L871E<R]P;W)T86PO<VED96)A<BYI;F,Z
M,S(*;7-G:60@(D5X<&%N9"!3:61E8F%R(@IM<V=S='(@(K_>PLJXM[3K(,BN
MP.4B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+97EW;W)D<RYP:'`Z,38X"FUS
M9VED(")%>'!E8W1E9"`G*2<B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U-1
M3"]344PO2V5Y=V]R9',N<&AP.C$W-0IM<V=I9"`B17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,3(*;7-G:60@(D5X<&ER871I
M;VX@1&%T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<VUI;64N<&AP.C8W-@HC+"!F=7IZ>0IM<V=I9"`B17AP;VYE;G0B"FUS9W-T
M<B`BOZ*]NL;WQJXB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C,Q"FUS9VED(")&1R!#;VQO<B(*;7-G<W1R("+`
M_+#FN_8B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3<W"FUS9VED(")&
M5%`@=7!L;V%D(&]F('-E='5P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0
M<F5F<R]0<F5F<R]S<6PN<&AP.C(Q-@IM<V=I9"`B1F%I;&5D(')E=')I979I
M;F<@<')E9F5R96YC97,N(@IM<V=S='(@(LBOL.:\L\&D(,#0L>(@O\"W^2XB
M"@HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-S4@9G)A;65W
M;W)K+T%U=&@O075T:"]L9&%P+G!H<#HY.`IM<V=I9"`B1F%I;&5D('1O(&-O
M;FYE8W0@=&\@3$1!4"!S97)V97(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3
M(+W'QM`B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.3@*(RP@
M9G5Z>GD*;7-G:60@(D9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N
M(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.C8X-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S7"(N(@IM<V=S='(@(DQ$05`@
MO*VY]B#!HKS3(+W'QM`B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP
M.C8Y,0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B1F%I;&5D('1O(&-O
M<'D@=&\@7"(E<UPB+B(*;7-G<W1R("),1$%0(+RMN?8@P:*\TR"]Q\;0(@H*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX-PHC+"!F=7IZ>0IM
M<V=I9"`B1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+B(*
M;7-G<W1R("),1$%0(+^LL.$@)7,@O<?&T"(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-M8BYP:'`Z-#DW(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z-S(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")&86EL960@=&\@;6]V92!T
M;R!<(B5S7"(N(@IM<V=S='(@(DQ$05`@O*VY]B#!HKS3(+W'QM`B"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C0V,0HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B1F%I;&5D('1O(')E=')I979E.B`E<R(*;7-G<W1R("),
M1$%0(+RMN?8@P:*\TR"]Q\;0(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,3@*(RP@9G5Z>GD*;7-G:60@(D9A:7(B"FUS9W-T
M<B`BQ\K%S2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#0@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HW.0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9A;&ML86YD($ES;&%N9',@
M*$UA;'9I;F%S*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C@V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#`*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<S"B,L(&9U>GIY"FUS
M9VED(")&87)O92!)<VQA;F1S(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*
M(SH@9G)A;65W;W)K+T-,22]#3$DN<&AP.C(S.`HC+"!F=7IZ>0IM<V=I9"`B
M1F%T86P@17)R;W(Z(@IM<V=S='(@(L#0ONZ_P+'B*,#3QO?&KBD@O\"W^3H@
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$X
M-PIM<V=I9"`B1F%X(@IM<V=S='(@(L;1O;HB"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z,S0Y"B,L(&9U>GIY"FUS9VED(")&87AE<R(*;7-G<W1R
M("+&T;VZ(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C0P,@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z-#0P"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD87(N
M:G,Z-C8*;7-G:60@(D9E8G)U87)Y(@IM<V=S='(@(C*_^2(*"B,Z(&QI8B]"
M;&]C:R]M971A<BYP:'`Z,C(P"FUS9VED(")&965L<R!,:6ME(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR,S$*;7-G:60@
M(D9E96QS(&QI:V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HQ.0IM<V=I9"`B1F5W(%-H;W=E<G,B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP
M:'`Z,C`*;7-G:60@(D9E=R!3;F]W(%-H;W=E<G,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DT-`IM<V=I9"`B1FEE;&0@;6%T
M<FEX(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,S
M,S0*;7-G:60@(D9I9VQE="!#05!40TA!(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C,S,S@*;7-G:60@(D9I9VQE="!F;VYT(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#,@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,0HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S(*;7-G:60@(D9I:FDB"FUS9W-T<B`B(@H*
M(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M;"YP:'`Z,C4U"B,L(&9U>GIY"FUS
M9VED(")&:6QE(@IM<V=S='(@(L&FN/$B"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]R87(N<&AP.C8P(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+WII<"YP:'`Z-C<*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M=&=Z+G!H<#HX,@HC+"!P:'`M9F]R;6%T"FUS9VED(")&:6QE($-O=6YT.B`E
M<R!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C`@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HV-PHC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP
M.C@R"B,L('!H<"UF;W)M870*;7-G:60@(D9I;&4@0V]U;G0Z("5S(&9I;&5S
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HT,#<*
M;7-G:60@(D9I;&4@36%N86=E<B(*;7-G<W1R("+&Q,#/(+#\N*[`VB(*"B,Z
M(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C,@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,`HC.B!F<F%M97=O<FLO
M34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@U"B,L(&9U>GIY"FUS9VED(")&
M:6QE($YA;64B"FUS9W-T<B`BQ\JUY<#,N*<B"@HC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HR.3DU"B,L(&9U>GIY"FUS9VED(")&:6QE('-E;&5C=&EO
M;B(*;7-G<W1R("*QU,2B*+?\*2"\L<7#(+_`M_DB"@HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-#@V"B,L(&9U>GIY"FUS9VED(")&:6QE('5P;&]A
M9"(*;7-G<W1R("+'RK7E(@H*(SH@9G)A;65W;W)K+T)R;W=S97(O0G)O=W-E
M<BYP:'`Z.#4Y"FUS9VED(")&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C@Y"FUS
M9VED(")&:6QT97)S(@IM<V=S='(@(L?*Q<TB"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Q"B,L(&9U
M>GIY"FUS9VED(")&:6YL86YD(@IM<V=S='(@(L.CL>(B"@HC.B!L:6(O0FQO
M8VLO;6]O;BYP:'`Z,38V"B,L(&9U>GIY"FUS9VED(")&:7)S="!(86QF(@IM
M<V=S='(@(L.YQN3`S,'V(@H*(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C<T(&QI
M8B]";&]C:R]M;V]N+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B1FER<W0@475A
M<G1E<B(*;7-G<W1R("+#N<;DP,S!]B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HR-38*;7-G:60@(D9I>"!R871I;R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP
M:'`Z,C,Q"FUS9VED(")&;&EP(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z,S(*;7-G:60@(D9L
M;V%T(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C(Q"FUS9VED(")&;V<B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L+G!H<#HR,S0@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C$P-PHC+"!P:'`M9F]R;6%T"FUS9VED(")&;VQD97(@)7,@9&]E
M<R!N;W0@97AI<W0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHR,@IM<V=I9"`B1F]N="!#;VQO<B(*;7-G
M<W1R("*QV\#:(+OVL?(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z,S<*
M;7-G:60@(D9O;V0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,C,*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS.C(V"B,L(&9U>GIY"FUS
M9VED(")&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<R(*
M;7-G<W1R("*ZZK;SO^S`^K"A(,#,(+'BM,G`NR#!]K_XQ\_!]B"^RKW`M,^T
MV2XB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,S-`IM<V=I9"`B1F]R96-A
M<W0@*%1!1BDB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C<Y"FUS9VED("(B"B)&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A("(*(FQA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A
M('=I9&4@8FQO8VLI(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]L;V=I;B]L
M;V=I;BYI;F,Z,3`R"B,L(&9U>GIY"FUS9VED(")&;W)G;W0@>6]U<B!P87-S
M=V]R9#\B"FUS9W-T<B`BOL_(HR#(KL#.(@H*(SH@8V]N9FEG+W)E9VES=')Y
M+G!H<"YD:7-T.C0V,@HC+"!F=7IZ>0IM<V=I9"`B1F]R;7,B"FUS9W-T<B`B
MP*?$H2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HR,0HC+"!F=7IZ>0IM
M<V=I9"`B1F]R='5N92(*;7-G<W1R("+"_,&V(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.CDY"B,L(&9U>GIY"FUS9VED(")&;W)T=6YE('1Y<&4B"FUS
M9W-T<B`BPOS!MB(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HS.`HC+"!F
M=7IZ>0IM<V=I9"`B1F]R='5N97,B"FUS9W-T<B`BPOS!MB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HS.0HC+"!F=7IZ>0IM<V=I9"`B1F]R='5N97,@
M,B(*;7-G<W1R("+"_,&V(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C0U,PHC+"!F=7IZ>0IM<V=I9"`B1F]R=6US(@IM<V=S='(@(KC>P,_'U"(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,#D*(RP@9G5Z>GD*;7-G
M:60@(D9O<G=A<F1S(@IM<V=S='(@(L#\M-XB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C8P"B,L(&9U>GIY"FUS9VED(")&
M<B(*;7-G<W1R("+`I\2A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHS,PIM<V=I9"`B1G)A;65S(@IM<V=S='(@
M(L?!M[G`TR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#<@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX,PHC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z-S,*(RP@9G5Z>GD*;7-G:60@(D9R86YC92(*
M;7-G<W1R("+#Z[S2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C<S"FUS9VED(")&<F%N8V4L($UE=')O<&]L:71A;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDQ(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<T"FUS9VED(")&<F5N8V@@1W5I86YA(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@T(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDX"FUS9VED(")&<F5N8V@@4&]L>6YE<VEA(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(R(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#8*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P.0IM<V=I9"`B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R
M:65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+W)F8S@R,BYP:'`Z-S0*;7-G:60@(D9R;VTB"FUS9W-T<B`BP*?$H2(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-#@@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C,V,`HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z-#`V"B,L(&9U>GIY"FUS9VED(")&<F]M('1H92`B"FUS9W-T<B`B
MP*?$H2(*"B,Z('1E;7!L871E<R]P<F]B;&5M+W!R;V)L96TN:6YC.C0X"B,L
M(&9U>GIY"FUS9VED(")&=6QL($1E<V-R:7!T:6]N(@IM<V=S='(@(L#\P[P@
MO+.X[3HB"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#$@;&EB+T)L;V-K+VUO
M;VXN<&AP.C$W-@IM<V=I9"`B1G5L;"!-;V]N(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HV,2!T96UP;&%T97,O861M:6XO=7-E<B]U
M<&1A=&4N:6YC.C8P"B,L(&9U>GIY"FUS9VED(")&=6QL($YA;64B"FUS9W-T
M<B`BP,RXISHB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C@X(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.#<*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<S"FUS9VED(")'86)O;B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E
M7VQA;F<N:G,Z,S`*;7-G:60@(D=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7V%N<V5L:6UA9V5?;&%N9RYJ<SHR.0IM<V=I9"`B1V%L;&5R>3HB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY-B!F<F%M97=O
M<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C@X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HW-0IM<V=I9"`B1V%M8FEA(@IM<V=S='(@(B(*"B,Z
M(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z-#(*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB"FUS9W-T<B`B
MN-[`SR"\K;GV(,&DNKB[Y\?7(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL.C@*;7-G:60@(D=E;F5R871E9"!#;V1E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.3`@9G)A;65W;W)K
M+TY,4R].3%,O8V]U;G1R:65S+G!H<#HX.0HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S0*;7-G:60@(D=E;W)G:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HV.2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.CDP"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HV.0IM<V=I9"`B1V5R;6%N>2(*;7-G<W1R("*UML#/(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.CDQ"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1VAA;F$B"FUS9W-T<B`BP=^QN2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HY,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z-S4*;7-G:60@(D=I8G)A;'1A<B(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-0HC+"!F=7IZ>0IM<V=I
M9"`B1VEV96X@3F%M92(*;7-G<W1R("+'RK7EP,RXIR(*"B,Z('1E;7!L871E
M<R]P<F5F<R]A<'`N:6YC.C$R"FUS9VED(")';R(*;7-G<W1R("*PH;'B(@H*
M(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0P"FUS9VED(")';V5D96PB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q,C@*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!-87!S(@IM<V=S='(@
M(K#+N_;'U[CQ(,/*L>+(K2(*"B,Z(&QI8B]";&]C:R]G;V]G;&4N<&AP.C,@
M;&EB+T)L;V-K+V=O;V=L92YP:'`Z,C$@;&EB+T)L;V-K+V=O;V=L92YP:'`Z
M-#$*(RP@9G5Z>GD*;7-G:60@(D=O;V=L92!396%R8V@B"FUS9W-T<B`BL,N[
M]L?7N/$@P\JQXLBM(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R
M+VAT;6PN<&AP.C(S-PIM<V=I9"`B1W)A>7-C86QE(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3`P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<V"FUS9VED(")'<F5E8V4B"FUS9W-T<B`B(@H*(SH@8V]N9FEG
M+VYL<RYP:'`N9&ES=#HQ.#4*;7-G:60@(D=R965K("A)4T\M.#@U.2TW*2(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDU(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z.30*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C<U"B,L(&9U>GIY"FUS9VED(")'<F5E;FQA
M;F0B"FUS9W-T<B`BP-#!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z.34*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<T"B,L(&9U
M>GIY"FUS9VED(")'<F5N861A(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*
M(SH@861M:6XO9W)O=7!S+G!H<#HQ-SD*(RP@9G5Z>GD*;7-G:60@(D=R;W5P
M($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@(K#\N*XB"@HC.B!F<F%M97=O<FLO
M1W)O=7`O1W)O=7`N<&AP.C4Y(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HQ-CD*;7-G:60@(D=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P+G!H
M<#HS,#<*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(D=R;W5P7VQD87`Z
M(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z("(*;7-G<W1R("+`T[W#NKBP_,?4(,#ZP.4@O\"W^2X@O*VY
M]L#'(+_`M_D@N-Z]P\'V.B`E<R(*"B,Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]L9&%P+G!H<#HQ,3@@9G)A;65W;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP
M.C$R-`HC.B!F<F%M97=O<FLO1W)O=7`O1W)O=7`O;&1A<"YP:'`Z-#$X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")'<F]U<%]L9&%P.B!5;F%B;&4@
M=&\@9&5L971E(&=R;W5P("5S(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LH
MN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1W)O=7`O
M1W)O=7`O;&1A<"YP:'`Z,S,X(&9R86UE=V]R:R]'<F]U<"]'<F]U<"]L9&%P
M+G!H<#HS-SD*(RP@<&AP+69O<FUA=`IM<V=I9"`B1W)O=7!?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!G<F]U<"`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO4&5R;7,O4&5R;7,O54DN<&AP.C,Q-"!L:6(O0FQO8VLO9V]O9VQE+G!H
M<#HS.`HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C$W-PIM<V=I9"`B
M1W)O=7!S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z.3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S8*;7-G:60@(D=U861E;&]U
M<&4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY-PHC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*(RP@9G5Z>GD*;7-G:60@(D=U
M86TB"FUS9W-T<B`B-K_Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HY.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S<*;7-G:60@(D=U871E;6%L
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.CDR
M"B,L(&9U>GIY"FUS9VED(")'=65R;G-E>2(*;7-G<W1R("*UML#/(@H*(SH@
M9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HR,C8@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHX.`HC+"!F=7IZ>0IM<V=I9"`B1W5E<W0@4&5R;6ES
M<VEO;G,B"FUS9W-T<B`BN-Z]P\'V(+OHP:8B"@HC.B!C;VYF:6<O<F5G:7-T
M<GDN<&AP+F1I<W0Z-#<P"B,L(&9U>GIY"FUS9VED(")'=65S=&)O;VLB"FUS
M9W-T<B`BP=:\TK?/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HY
M-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.CDY"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-0HC+"!F=7IZ>0IM<V=I9"`B1W5I
M;F5A(@IM<V=S='(@(C:_^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,3`T(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3`P"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW.`HC+"!F=7IZ>0IM<V=I
M9"`B1W5I;F5A+4)I<W-A=2(*;7-G<W1R("(VO_DB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$P-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$P,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*
M(RP@9G5Z>GD*;7-G:60@(D=U>6%N82(*;7-G<W1R("(VO_DB"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HY-C`*;7-G:60@(DA434PB"FUS9W-T<B`B
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHX-0IM<V=I9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D
M96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N(@IM<V=S='(@(B(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z.#8*
M;7-G:60@(DA434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(&-O;'5M;B!I;B!T86)L92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-PIM<V=I
M9"`B2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA
M<W0@<F]W(&EN('1A8FQE+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T
M:"]!=71H+VAT='`N<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B2%144"!!=71H
M96YT:6-A=&EO;B!N;W0@9F]U;F0N(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3$P(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3`R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HX,`IM<V=I9"`B2&%I=&DB"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$S"FUS9VED(")(87-H+4%L9V]R
M:71H;2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HR,@HC+"!F=7IZ>0IM<V=I9"`B2&%Z92(*;7-G<W1R("+'
M[+7EMO/`SB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDQ.2!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR.3,R"B,L(&9U>GIY"FUS9VED(")(96%D
M97(B"FUS9W-T<B`BQ^RUY;;SP,XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+U1Y<&4O=&%B;&5S970N<&AP.C8Q"B,L(&9U>GIY"FUS9VED(")(96%D97)S
M(@IM<V=S='(@(L?LM>6V\\#.(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,#<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#,*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z,C,*;7-G:60@
M(DAE879Y(%0M4W1O<FTB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N
M9&ES=#HQ.#8*;7-G:60@(DAE8G)E=R`H25-/+3@X-3DM."U)*2(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C,T"FUS9VED(")(96EG:'0B"FUS9W-T<B`BL_3`S"(*"B,Z(&9R
M86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<#HQ-SD@9G)A;65W;W)K+TAO
M<F1E+TAO<F1E+TAE;'`N<&AP.C$X-@HC.B!S97)V:6-E<R]H96QP+VEN9&5X
M+G!H<#HQ-R!T96UP;&%T97,O:&5L<"]I;F1E>"YI;F,Z,PIM<V=I9"`B2&5L
M<"(*;7-G<W1R("*UM;_RN+LB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C,Q"FUS9VED(")(96QP('5S:6YG(&5D:71O<B(*
M;7-G<W1R("*UM;_RN+LB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M,S<Q"B,L(&9U>GIY"FUS9VED(")(96QP97(B"FUS9W-T<B`BM;6_\KB[(@H*
M(SH@;&EB+T)L;V-K+VUO;VXN<&AP.C(Y"B,L(&9U>GIY"FUS9VED(")(96UI
M<W!H97)E(@IM<V=S='(@(K6UO_*XNR(*"B,Z('1E;7!L871E<R]D871A+W1S
M=FEN9F\N:6YC.C$P('1E;7!L871E<R]D871A+V-S=FEN9F\N:6YC.C$P"FUS
M9VED(")(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z(@IM<V=S
M='(@(L;$P,_`QR"]P\#;P,P@M-G`O;#Z(+"PO<"TS[39.B(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8Y"B,L(&9U>GIY"FUS
M9VED(")(:6=H(@IM<V=S='(@(K/TP,PB"@HC.B!T96UP;&%T97,O<&]R=&%L
M+VUE;G4N:6YC.C8@=&5M<&QA=&5S+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC
M.C4*(RP@9G5Z>GD*;7-G:60@(DAO7VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#,@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,#0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C$Q-`IM<V=I9"`B2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ
M-3,U"B,L(&9U>GIY"FUS9VED(")(;VUE(@IM<V=S='(@(DAO<F1E(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$R,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,34U"FUS9VED
M(")(;VUE($%D9')E<W,B"FUS9W-T<B`BP?T@P=:\TB(*"B,Z(&QI8B]";&]C
M:R]A8V-O=6YT+G!H<#HV-`HC+"!F=7IZ>0IM<V=I9"`B2&]M92!$:7)E8W1O
M<GDB"FUS9W-T<B`BM?"WNL7DN*XB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]V8V%R9"YP:'`Z,3DP"FUS9VED(")(;VUE(%!H;VYE(@IM<V=S
M='(@(L'](,#\R*VY^,BC(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,#4*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<Y"FUS9VED(")(;VYD=7)A
M<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$P
M-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$P-@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z-S@*;7-G:60@(DAO;F<@2V]N9R(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-C4*;7-G
M:60@(DAO<F1E(@IM<V=S='(@(DAO<F1E(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HT-#(*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G
M92`E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP
M.C(Y.0HC+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HT,S4*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C4P"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@7"(E<UPB(@IM
M<V=S='(@(KC>P,_'U"!<(B5S7"+`S"!<(B5S7"*WSB"ZK[#FM<>^^KW`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C(R,PIM<V=I9"`B
M2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@
M=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HU,#,*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HQ,C0W"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R!<(B5S7"(Z("5S(@IM
M<V=S='(@(KC>P,_'U"!<(B5S7"+`S"!<(B5S7"*WSB"ZK[#FM<>^^KW`M,^T
MV2XB"@HC.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C0W-`HC+"!P:'`M
M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E
M($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ,3DS"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S(%PB)7-<(CH@)7,B"FUS9W-T<B`B7"(E<UPB(+C>P,_'U,"[
M(+OGO^O'U;3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,S,V"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,B"FUS9W-T<B`B7"(E
M<UPB(+C>P,_'U,"[(+OGO^O'U;3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HS-#`*(RP@<&AP+69O<FUA=`IM<V=I9"`B2&]R9&4O2V]L
M86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(@IM<V=S='(@(B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C0*;7-G:60@(DAO
M<FEZ;VYT86P@4G5L92(*;7-G<W1R("*\]L;RO+$B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@R"FUS9VED(")(;W)I>F]N
M=&%L('!A9&1I;F<B"FUS9W-T<B`BL*&WSB##I+_R(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX,0IM<V=I9"`B2&]R:7IO
M;G1A;#HB"FUS9W-T<B`BL*&WSCHB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3$*;7-G:60@(DAO=R!D:60@
M>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I(@IM<V=S='(@(B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M,S4*;7-G:60@(DAO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_(@IM<V=S='(@(L?5Q*&P[2"]S<"Z(+^MP,<@O/8B"@HC.B!T96UP
M;&%T97,O9&%T82]C<W9I;F9O+FEN8SHR,0IM<V=I9"`B2&]W(&UA;GD@9FEE
M;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_(@IM<V=S='(@(L?7N/$HOZTIP,<@
MO/8_(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHS-@IM<V=I9"`B2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK
M92!T;R!M97)G93\B"FUS9W-T<B`BQ]7$H;#M(+W-P+H@Q^#`QR"\]B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+VUE
M=&%R+G!H<#HR,S`*;7-G:60@(DAU;6ED:71Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR-3D*;7-G:60@(DAU;6ED:71Y
M.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C0Q"FUS
M9VED(")(=6UO<FES=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,3$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@P"FUS9VED
M(")(=6YG87)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M8WER=7,N<&AP.C$W,B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP:'`Z
M,C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("))34%0(&UA:6QB;W@@
M8W)E871I;VX@9F%I;&5D.B`E<R(*;7-G<W1R("*XWL#/(,#\M-X@O\"W^3HB
M"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HR,30@9G)A;65W
M;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(Y-0HC+"!P:'`M9F]R;6%T"FUS
M9VED("))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G5S+G!H<#HQ-SD@9G)A
M;65W;W)K+T%U=&@O075T:"]C>7)S<6PN<&AP.C(T,@HC+"!F=7IZ>2P@<&AP
M+69O<FUA=`IM<V=I9"`B24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,B"FUS9W-T<B`BN-[`SR#`_+3>(+_`M_DZ(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,3,Q-@HC+"!F=7IZ>0IM<V=I9"`B25`@061D
M<F5S<R(*;7-G<W1R("+!UKS2(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I
M<&)A<VEC+G!H<#HW-PHC+"!F=7IZ>0IM<V=I9"`B25`@061D<F5S<R!N;W0@
M879A:6QA8FQE+B(*;7-G<W1R("+`S+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]I<&)A<VEC+G!H<#HX
M.0IM<V=I9"`B25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B
M;&]C:RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L
M:6-K871E;&Q?:'1T<"YP:'`Z,CDU"FUS9VED("))4"!L;V-K9&]W;B!V:6]L
M871I;VXN(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR.0IM<V=I9"`B25]N<V5R="!2;W<@
M0F5F;W)E(@IM<V=S='(@(E]NOM6_H2#'X"##W["A(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,C`@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R
M"B,L(&9U>GIY"FUS9VED("))8V5L86YD(@IM<V=S='(@(L#0P?8@OLK`NB"X
MWL#/(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C,W-@IM<V=I9"`B26-O
M;G,@3VYL>2(*;7-G<W1R("*^QL#,Q-PB"@HC.B!U=&EL+VEC;VY?8G)O=W-E
M<BYP:'`Z-#D*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DEC;VYS(&9O
M<B`E<R(*;7-G<W1R("(E<[^AL-0@O-*PLR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HS-S<*;7-G:60@(DEC;VYS('=I=&@@=&5X="(*;7-G<W1R("*^
MQL#,Q-RP^B"YKL#:(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Y,`IM
M<V=I9"`B261E;G1I='DG<R!N86UE.B(*;7-G<W1R("*]Q+JPP-H@P,RXISHB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H<#HU.3(*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#4U"FUS9VED("(B"B))
M9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L
M;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K("(*(G1H:7,@8F]X('1O('1U
M<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HQ-S,*;7-G:60@(B(*
M(DEF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I;6%G92P@=&AE(&EM
M86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92`B"B)D:7-P;&%Y960@
M8GD@>6]U<B!B<F]W<V5R+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R-0HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N:G,Z,C@*;7-G:60@
M(DEM86=E(%!R979I97<Z(@IM<V=S='(@(K'7N+(@N<RXKKJXL>(Z(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS
M-PIM<V=I9"`B26UA9V4@55),(@IM<V=S='(@(K'7N+(@55),(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ,3@*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?86YS96QI;6%G95]L86YG+FIS
M.C(Q"FUS9VED("));6%G92!54DPZ(@IM<V=S='(@(K'7N+(@55),.B(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?;&%N
M9RYJ<SHS,@IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y(@IM<V=S='(@(B(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V%N<V5L:6UA9V5?
M;&%N9RYJ<SHS,0IM<V=I9"`B26UA9V4@9G)O;2!G86QL97)Y.B(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-S8Q"B,L(&9U>GIY
M"FUS9VED("));6%G92!U<&QO860B"FUS9W-T<B`BQ\JUY2(*"B,Z(&QI8B]"
M;&]C:R]G;V]G;&4N<&AP.C,W"B,L(&9U>GIY"FUS9VED("));6%G97,B"FUS
M9W-T<B`BL=>XLB!54DPB"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHW('1E;7!L871E<R]D871A+V1A=&5M87`N:6YC.C<*(SH@=&5M<&QA=&5S
M+V1A=&$O8W-V;6%P+FEN8SHU-"!T96UP;&%T97,O9&%T82]C<W9I;F9O+FEN
M8SHW"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("));7!O<G0L(%-T97`@
M)60B"FUS9W-T<B`BL*'!KK_`L>(L(+3<L.@@)7,B"@HC.B!T96UP;&%T97,O
M9&%T82]D871E;6%P+FEN8SHQ-@HC+"!P:'`M9F]R;6%T"FUS9VED("));7!O
M<G1E9"!F:65L9#H@)7,B"FUS9W-T<B`BL*'!KK_"(,?7N/$Z("5S(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHV-0IM<V=I9"`B26UP;W)T960@
M9FEE;&1S.B(*;7-G<W1R("*PH<&NO\(@Q]>X\3HB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S`*;7-G:60@
M(DEN7W-E<G0@4F]W($%F=&5R(@IM<V=S='(@(E]SM-G`O;^A(,?@(,/?L*$B
M"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HQ,S4*
M;7-G:60@(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV,S(*(RP@9G5Z>GD*;7-G:60@(DEN8V]R<F5C="!U<V5R;F%M92!A;F0O
M;W(@<&%S<W=O<F0N(@IM<V=S='(@(KOGO^O`VL#,N*>P^B"^S\BCN*8@P-2W
MPL?/O+R_Y"(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C4Q"B,L
M(&9U>GIY"FUS9VED("(B"B));F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N
M871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@(@HB861M
M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N(@IM<V=S='(@
M(B(*(L/?L*''S[3"M:4@O\"W^;"A(+G?N_W'W[W`M,^TV2X@O<.]NL7;L/RX
MKL#:OZ&PU""UM;_RP+L@O^3#N\?/O<.QXB"YV;;XM,^TV2XB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(Q"FUS9VED("))
M;F-R96%S92!);F1E;G0B"FUS9W-T<B`BM>F_J;ZRL>(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.#$*(RP@9G5Z>GD*;7-G:60@(DEN9&EA(@IM<V=S='(@(K[XP+TB"@HC.B!F
M<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP.C(U-"!T96UP;&%T97,O<VAA
M<F5S+V5D:70N:6YC.C$S-`IM<V=I9"`B26YD:79I9'5A;"!5<V5R<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Q,B!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Q,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(DEN9&]N97-I
M82(*;7-G<W1R("*^^,"](@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F9C.#(R+G!H<#HV-PHC+"!F=7IZ>0IM<V=I9"`B26YF;R(*;7-G<W1R
M("*YJ[W#(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C(U-PHC+"!F
M=7IZ>0IM<V=I9"`B26YF;W)M871I;VXB"FUS9W-T<B`BP:2ZN"(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,S`*(RP@9G5Z>GD*;7-G:60@
M(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N(@IM<V=S='(@(L#,
MO^NPH;3)Q]$@O+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z,S4*;7-G:60@
M(DEN<V5R="!#7V]L=6UN($%F=&5R(@IM<V=S='(@(E]OM-G`O;^A(+^M(,/?
ML*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$Q-PHC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM
M86=E7VQA;F<N:G,Z,C`*;7-G:60@(DEN<V5R="!);6%G92(*;7-G<W1R("*Q
MU[BR(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C(W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3`P"FUS9VED("));G-E<G0@5&%B;&4B"FUS9W-T<B`BQZ4@P]^P
MH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,C4*;7-G:60@(DEN<V5R="!796(@3&EN:R(*;7-G<W1R("+`I2"XM<6I(,/?
ML*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z,S0*;7-G:60@(DEN<V5R="!?0V]L=6UN($)E9F]R92(*;7-G
M<W1R(")?8[[5OZ$@OZT@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV-@IM<V=I9"`B26YS97)T(&$@
M;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BQ_;`
MYR"_K2"UVK^A(+OU(+^M(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C4*;7-G:60@(DEN<V5R="!A
M(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+'
M]L#G(+^M(+[5OZ$@N_4@OZT@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHV,@IM<V=I9"`B26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4B"FUS9W-T<B`BQ_;`
MYR#'X""UVK^A(+OU(,?@(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C$*;7-G:60@(DEN<V5R="!A
M(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N92(*;7-G<W1R("+']L#G
M(,?@(+[5OZ$@N_4@Q^`@P]^PH2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHW,`IM<V=I9"`B26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`BQ_;`
MYR#!]L&A(+7:OZ$@M-RV]"##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C8Y"FUS9VED("));G-E<G0@
M82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4B"FUS9W-T<B`B
MQ_;`YR#!]L&A(+[5OZ$@M-RV]"##W["A(@H*(SH@861M:6XO=&5M<&QA=&5S
M+G!H<#HQ-3`*(RP@9G5Z>GD*;7-G:60@(DEN<V5R="!A;'1E<FYA=&4@=&5M
M<&QA=&4B"FUS9W-T<B`BM.O#O""QVR(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N
M9&ES=#HR,SD*;7-G:60@(DEN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4X"FUS9VED("));G-E<G0@8V5L;"!A9G1E<B(*;7-G<W1R("*U
MVK^A(+R_(,/?L*$B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]T86)L95]L86YG+FIS.C4Y"FUS9VED("));G-E<G0@8V5L;"!B969O<F4B
M"FUS9W-T<B`BOM6_H2"\OR##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHV-`IM<V=I9"`B26YS97)T(&-O
M;'5M;B!A9G1E<B(*;7-G<W1R("*UVK^A(+^M(,/?L*$B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C8U"FUS9VED
M("));G-E<G0@8V]L=6UN(&)E9F]R92(*;7-G<W1R("*^U;^A(+^M(,/?L*$B
M"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HY,`HC
M+"!F=7IZ>0IM<V=I9"`B26YS97)T(&UE<W-A9V5S(@IM<V=S='(@(LBXO<7'
MT2"XWL#/(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C0U"FUS9VED("));G-E<G0@<&%R86=R87!H(&%F=&5R
M(@IM<V=S='(@(K7:OZ$@M-RV]"##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0T"FUS9VED("));G-E
M<G0@<&%R86=R87!H(&)E9F]R92(*;7-G<W1R("*^U;^A(+3<MO0@P]^PH2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-CD*;7-G:60@(DEN<V5R="!R;W<@869T97(B"FUS9W-T<B`BM=J_H2#'
MX"##W["A(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHV.`IM<V=I9"`B26YS97)T(')O=R!B969O<F4B"FUS9W-T
M<B`BOM6_H2#'X"##W["A(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C(S
M,`IM<V=I9"`B26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E
M8W5R:71Y('%U97-T:6]N.B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C(V"FUS9VED("));G-E<G0O36]D
M:69Y($EM86=E(@IM<V=S='(@(K'7N+(@P]^PH2^\]L&D(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX.0IM<V=I9"`B26YS
M97)T+TUO9&EF>2!,:6YK(@IM<V=S='(@(KBUQ:D@P]^PH2^\]L&D(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV-#,*
M;7-G:60@(DEN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?
M4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,U"FUS9VED("));G-U9F9I
M8VEE;G0@8W)E9&ET+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ,#<U"B,L(&9U>GIY"FUS9VED("));G1E9V5R(@IM<V=S='(@
M(K"AO^ZUI2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,S,*;7-G
M:60@(DEN=&5G97(@;&ES="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR.3<*;7-G:60@(DEN=F%L
M:60@541(+B`H57-E<B!$871A($AE861E<BDN(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]Z:7`N<&AP.C$W,`HC.B!F<F%M
M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H<#HR,#$*(SH@9G)A;65W
M;W)K+T-O;7!R97-S+T-O;7!R97-S+WII<"YP:'`Z,C$P"B,L(&9U>GIY"FUS
M9VED("));G9A;&ED(%I)4"!D871A(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*
M"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z,S0*(RP@9G5Z>GD*;7-G:60@
M(DEN=F%L:60@87!P;&EC871I;VXN(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP
M.C,Q,@HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!B871C:"!)1"XB"FUS9W-T
M<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C`X-R!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,34X"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(R,S(@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,C(Y.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N<&AP
M.C,W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(*
M;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#`*(RP@9G5Z>GD*;7-G:60@(DEN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB"FUS9W-T<B`BP-^X^+7((,#,
MN-[`SR#!UKS2(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B
M>"YP:'`Z.#$*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R97-S+V1B>"YP
M:'`Z,3`P"B,Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]D8G@N<&AP
M.C(R,`HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!F:6QE(&9O<FUA="(*;7-G
M<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,3<W"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QI8V5N<V4@:V5Y
M+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;2YP:'`Z,3<Q"B,L(&9U>GIY"FUS9VED("));G9A;&ED(&QO8V%T
M:6]N('!R;W9I9&5D+B(*;7-G<W1R("+`W[CXM<@@P,RXIRXB"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#<*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@;7-G7W1Y<&4N(@IM<V=S='(@(L#?N/BU
MR"#`S+BG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL
M7VAT='`N<&AP.C,P,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!O<B!M:7-S
M:6YG(&%P:5]I9"XB"FUS9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDV"B,L(&9U
M>GIY"FUS9VED("));G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB"FUS
M9W-T<B`BP-^X^+7((,#,N*<N(@H*(SH@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C(W"B,L(&9U>GIY"FUS9VED("));G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+B(*;7-G<W1R("+`W[CXM<@@P=:\TK?/(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C$W,PHC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!P
M87)T;F5R(&ED+B(*;7-G<W1R("+`W[CXM<@@P=:\TK?/(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$W-0HC+"!F=7IZ>0IM<V=I9"`B26YV
M86QI9"!P<F]D=6-T(&-O9&4N(@IM<V=S='(@(L#?N/BUR"#!UKS2M\\B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS
M,#8*(RP@9G5Z>GD*;7-G:60@(DEN=F%L:60@<')O=&]C;VPN(@IM<V=S='(@
M(L#?N/BUR"#!UKS2M\\B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS
M,F5M86EL7VAT='`N<&AP.CDS"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W
M:6Y?:'1T<"YP:'`Z-S$@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P
M+G!H<#HX,`HC+"!P:'`M9F]R;6%T"FUS9VED("));G9A;&ED(')E8VEP:65N
M=#H@7"(E<UPB(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA
M8BYP:'`Z,3`W-B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP.C$R-C(*(RP@
M9G5Z>GD*;7-G:60@(DEN=F%L:60@<VAA<F4@;V)J96-T(@IM<V=S='(@(L#?
MN/BUR"#`S+BG+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T
M96QL7VAT='`N<&AP.C,P,0HC+"!F=7IZ>0IM<V=I9"`B26YV86QI9"!S;W5R
M8V4@861D<F5S<RXB"FUS9W-T<B`BP-^X^+7((,#,N-[`SR#!UKS2(@H*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$Q
M"B,L(&9U>GIY"FUS9VED("));G9A;&ED('5N:6-O9&4@9&%T82XB"FUS9W-T
M<B`BP-^X^+7((,#,N*<N(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C,U-PIM<V=I9"`B26YV96YT;W)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-SD*(RP@9G5Z>GD*;7-G
M:60@(DEN=F5R="!S96QE8W1I;VXB"FUS9W-T<B`BP-JXH['B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,3D@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ,3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C@R"B,L(&9U>GIY"FUS9VED("))<F%N+"!)<VQA;6EC(%)E<'5B;&EC
M(&]F(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M=&QD+G!H<#HQ,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ
M,3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Q"FUS9VED("))
M<F%Q(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3$S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,`HC+"!F=7IZ>0IM<V=I9"`B
M27)E;&%N9"(*;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,3$U"FUS9VED("))<VQE(&]F($UA;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-`IM<V=I9"`B27-O;&%T960@5"U3=&]R;7,B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,30@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,30*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@P"B,L(&9U>GIY"FUS9VED("))<W)A96PB"FUS9W-T<B`BP-#!
M]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C8R-0IM<V=I9"`B27-S=65R(@IM<V=S='(@(B(*"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.0IM<V=I9"`B271A;&EC
M(@IM<V=S='(@(K'BO^_`S+'B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ,C$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,34*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"B,L(&9U>GIY"FUS
M9VED("))=&%L>2(*;7-G<W1R("+`S[JP(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HQ,C,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HQ,38*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@R"FUS9VED
M(")*86UA:6-A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT,#$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0S.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O
M<&5N7V-A;&5N9&%R+FIS.C8U"FUS9VED(")*86YU87)Y(@IM<V=S='(@(C&_
M^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3(U(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3$W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX,PIM<V=I9"`B2F%P86XB"FUS9W-T<B`BP,^ZNR(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@W"FUS9VED(")*87!A;F5S92`H
M25-/+3(P,C(M2E`I(@IM<V=S='(@(L#/NKN^[B`H25-/+3(P,C(M2E`I(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HS,3`*;7-G:60@(B(*(DIA
M=F%S8W)I<'0@:&%S(&)E96X@9&ES86)L960@;VX@>6]U<B!B<F]W<V5R(&%N
M9"!T:&ES('!A9V4@;6%Y(&YO="!B92`B"B)D:7-P;&%Y:6YG(&-O<G)E8W1L
M>2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M,C(*;7-G:60@(DIE<G-E>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$R-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$Q.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#,*;7-G
M:60@(DIO<F1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z-#`W"B,Z(&9R86UE=V]R:R]522]522]687)2
M96YD97)E<B]H=&UL+G!H<#HT-#4*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M;W!E;E]C86QE;F1A<BYJ<SHW,0IM<V=I9"`B2G5L>2(*;7-G<W1R("(WO_DB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`V
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#0*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHW,`IM
M<V=I9"`B2G5N92(*;7-G<W1R("(VO_DB"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C,X"FUS9VED(")*=7-T:69Y
M(@IM<V=S='(@(L&DM\0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,Z,S@*(SH@=&5M<&QA=&5S+VIA=F%S8W)I
M<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-0IM<V=I9"`B2G5S=&EF>2!#96YT97(B
M"FUS9W-T<B`BL*&_[K6E(,&DM\0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#`*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHQ-PIM<V=I9"`B2G5S=&EF>2!&
M=6QL(@IM<V=S='(@(K[GPLH@P:2WQ"(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS-PHC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$T"FUS9VED(")*=7-T:69Y
M($QE9G0B"FUS9W-T<B`BO]["RB#!I+?$(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C,Y"B,Z('1E;7!L871E
M<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,38*;7-G:60@(DIU<W1I
M9GD@4FEG:'0B"FUS9W-T<B`BO\"XI<+*(,&DM\0B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Q.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#8*
M;7-G:60@(DMA>F%K:'-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(V-`IM<V=I9"`B2V5E<"!O<FEG
M:6YA;#\B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ,C8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@S"FUS9VED(")+96YY82(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP.C@U
M"FUS9VED(")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT,@IM
M<V=I9"`B2V5R;F5L($YE=V)I97,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#$Q"B,L(&9U>GIY"FUS9VED(")+97D@
M0W)E871I;VXB"FUS9W-T<B`BQ+B\QR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]P9W`N<&AP.C0Q-`IM<V=I9"`B2V5Y($9I;F=E<G!R:6YT(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0Q,@IM
M<V=I9"`B2V5Y($QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<&=P+G!H<#HT,3$*;7-G:60@(DME>2!4>7!E(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3DX"B,L
M(&9U>GIY"FUS9VED(")+97D@57-A9V4B"FUS9W-T<B`BN-Z]P\'V(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-S0P"B,L(&9U>GIY"FUS
M9VED(")+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V
M97(N(@IM<V=S='(@(F9T<""\K;GV(+^LL.$@O\"W^2XB"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-#,*;7-G:60@(DMI9',B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ,CD@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@T"FUS9VED(")+:7)I8F%T:2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$S,B!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.#4*(RP@9G5Z>GD*;7-G:60@(DMO<F5A+"!$96UO8W)A=&EC(%!E;W!L
M92=S(%)E<'5B;&EC(&]F(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@9G)A;65W
M;W)K+TY,4R].3%,O=&QD+G!H<#HQ,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U
M;G1R:65S+G!H<#HQ,C,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C@U"FUS9VED(")+;W)E82P@4F5P=6)L:6,@;V8B"FUS9W-T<B`BM.O'T;G.
ML;DB"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$X.`IM<V=I9"`B2V]R96%N
M("A%54,M2U(I(@IM<V=S='(@(L?1L;F^[B`H155#+4M2*2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3,T(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,3(T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HX-@IM<V=I9"`B2W5W86ET(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3(W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3(U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX,PIM
M<V=I9"`B2WER9WEZ<W1A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O<&]R
M=&%L+VUE;G4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(DQA7WEO=70B"FUS9W-T
M<B`BM\ZQU[[&O_0B"@HC.B!T96UP;&%T97,O;&]G:6XO;&]G:6XN:6YC.C@S
M"FUS9VED("),86YG=6%G92(*;7-G<W1R("*^\+[N(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ,S<@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ,C8*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@W
M"FUS9VED("),86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8R(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,38Y"B,L(&9U>GIY"FUS
M9VED("),87-T($AA;&8B"FUS9W-T<B`BN+;!]KBW(,;DP,S!]B(*"B,Z(&QI
M8B]";&]C:R]A8V-O=6YT+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B3&%S="!0
M87-S=V]R9"!#:&%N9V4B"FUS9W-T<B`BOL_(HR(*"B,Z(&QI8B]";&]C:R]M
M;V]N+G!H<#HX-B!L:6(O0FQO8VLO;6]O;BYP:'`Z.#@*(RP@9G5Z>GD*;7-G
M:60@(DQA<W0@475A<G1E<B(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*(SH@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HQ-3$*(RP@9G5Z>GD*;7-G:60@(DQA<W0@
M57!D871E9#HB"FUS9W-T<B`BN+;!]KBW(,;DP,S!]B(*"B,Z(&9R86UE=V]R
M:R]!=71H+T%U=&@N<&AP.C<Q.0HC+"!P:'`M9F]R;6%T"FUS9VED("),87-T
M(&QO9VEN.B`E<R(*;7-G<W1R("*XML'VN+<@M\ZQU\#..B`E<R(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.C<R,0HC+"!P:'`M9F]R;6%T"FUS9VED
M("),87-T(&QO9VEN.B`E<R!F<F]M("5S(@IM<V=S='(@(KBVP?:XMR"WSK'7
MP,XZ("5S+"#!HKS3(,"GQ*$Z("5S(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"YP:'`Z-S$V"FUS9VED("),87-T(&QO9VEN.B!.979E<B(*;7-G<W1R("*X
MML'VN+<@M\ZQU\#..B"^^,"](@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ-#8@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,C<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"B,L(&9U>GIY"FUS
M9VED("),871V:6$B"FUS9W-T<B`BN+BUZ;'B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C0T"FUS9VED("),87<B"FUS9W-T<B`B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHS.0HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C<Y"FUS9VED
M("),87EO=70B"FUS9W-T<B`BM[G`S+[&O_0B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@V"FUS9VED("),96%V92!E;7!T
M>2!F;W(@;F\@8F]R9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3(X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX-PIM<V=I
M9"`B3&5B86YO;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0P"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-CD*;7-G:60@(DQE9G0B"FUS9W-T
M<B`BO]["RB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,3D*(RP@
M9G5Z>GD*;7-G:60@(DQE9G0@:&5A9&5R(@IM<V=S='(@(K^Y.B(*"B,Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,34*(RP@9G5Z>GD*;7-G:60@(DQE
M9G0@=F%L=65S(@IM<V=S='(@(K^Y.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,30S(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B
M3&5S;W1H;R(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T86PO<WEN8VUL
M+G!H<#HR-34*(RP@9G5Z>GD*;7-G:60@(DQE=F5L(@IM<V=S='(@(L#,M;\B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$T,B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.#@*;7-G:60@(DQI8F5R:6$B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-#<@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ,S$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C@Y"FUS9VED("),:6)Y86X@07)A8B!*86UA:&ER:7EA(@IM<V=S
M='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30P(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,R"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B3&EE8VAT96YS=&5I;B(*;7-G
M<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-0HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@1')I>GIL92(*;7-G<W1R("*W
MSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR-@HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B(*;7-G<W1R("*WSK'7
MP,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HR
M-PHC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!%87)L>2(*;7-G<W1R("*W
MSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H
M<#HR.`HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!,871E(@IM<V=S='(@
M(K?.L=?`SB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C(Y"B,L(&9U>GIY"FUS9VED("),:6=H="!286EN(%-H;W=E<B(*;7-G
M<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS,`HC+"!F=7IZ>0IM<V=I9"`B3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(B"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D
M;W1C;VU?<W1R:6YG<RYP:'`Z,S$*(RP@9G5Z>GD*;7-G:60@(DQI9VAT(%-N
M;W<B"FUS9W-T<B`BM\ZQU\#.(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z,S(*;7-G:60@(DQI9VAT(%-N;W<@4VAO=V5R(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT-0IM<V=I9"`B
M3&EM97)I8VLB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3@Q-`HC+"!F=7IZ>0IM<V=I9"`B3&EN:R(*;7-G<W1R("*WSK'7P,XB
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA
M;F<N:G,Z-3<*;7-G:60@(DQI;FL@<&]I;G1S('1O.B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ.#<U"FUS9VED("),:6YK('1H
M92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P
M;&%Y:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&
M:6QT97(O:'1M;#)T97AT+G!H<#HQ.#,*(RP@9G5Z>GD*;7-G:60@(DQI;FMS
M(@IM<V=S='(@(K?.L=?`SB"]P\#;P-N^]R(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HT-@HC+"!F=7IZ>0IM<V=I9"`B3&EN=7@@0V]O:VEE(@IM<V=S
M='(@(KOU(+C>P,\B"@HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R
M,#@V+G!H<#HX-@IM<V=I9"`B3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L
M9&5R(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S,*(RP@
M9G5Z>GD*;7-G:60@(DQI<W0@1&%T86)A<V5S(@IM<V=S='(@(KBVP?:XMR#&
MY,#,P?8B"@HC.B!S97)V:6-E<R]H96QP+VEN9&5X+G!H<#HU,`IM<V=I9"`B
M3&ES="!(96QP(%1O<&EC<R(*;7-G<W1R("*UM;_ROLL@N/'"]R(*"B,Z(&%D
M;6EN+W-Q;'-H96QL+G!H<#HQ,S(*(RP@9G5Z>GD*;7-G:60@(DQI<W0@5&%B
M;&5S(@IM<V=S='(@(KBVP?:XMR#&Y,#,P?8B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TAE861E<G,N<&AP.C4Y-`HC+"!F=7IZ>0IM<V=I9"`B3&ES="U!
M<F-H:79E(@IM<V=S='(@(KOGO^O'S\'V(+[*M,(@N-[`S\?4(+S[L>@B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4X.0HC+"!F=7IZ
M>0IM<V=I9"`B3&ES="U(96QP(@IM<V=S='(@(K6UO_*^RR"X\<+W(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<#HU.38*(RP@9G5Z>GD*
M;7-G:60@(DQI<W0M260B"FUS9W-T<B`BM;6_\K[+(+CQPO<B"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TAE861E<G,N<&AP.C4Y,@HC+"!F=7IZ>0IM<V=I
M9"`B3&ES="U/=VYE<B(*;7-G<W1R("*UM;_ROLL@N/'"]R(*"B,Z(&9R86UE
M=V]R:R]-24U%+TU)344O2&5A9&5R<RYP:'`Z-3DS"FUS9VED("),:7-T+5!O
M<W0B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12](96%D97)S
M+G!H<#HU.3$*(RP@9G5Z>GD*;7-G:60@(DQI<W0M4W5B<V-R:6)E(@IM<V=S
M='(@(KOGO^O'S\'V(+[*M,(@N-[`S\?4(+S[L>@B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TAE861E<G,N<&AP.C4Y,`HC+"!F=7IZ>0IM<V=I9"`B3&ES
M="U5;G-U8G-C<FEB92(*;7-G<W1R("*[Y[_KQ\_!]B"^RK3"(+C>P,_'U""\
M^['H(@H*(SH@861M:6XO<V5S<VEO;G,N<&AP.C4P"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED("),:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,B"FUS
M9W-T<B`BN^>_Z\?2(+SV(+[XM,(@N^>_Z\#:(+CQM\\N(@H*(SH@861M:6XO
M<V5S<VEO;G,N<&AP.C,U"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED("),
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,B"FUS9W-T<B`BN^>_Z\?2(+SV(+[X
MM,(@N^>_Z\#:(+CQM\\N(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O;F]L
M:7-T+FEN8SHR"FUS9VED("),:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+B(*
M;7-G<W1R("*[Y[_KQ](@O/8@OOBTPB"[Y[_KP-H@N/&WSRXB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-#<*(RP@9G5Z>GD*;7-G:60@(DQI=&5R871U
M<F4B"FUS9W-T<B`BO*VX[3HB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$T-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$S,PHC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#D*(RP@9G5Z>GD*;7-G
M:60@(DQI=&AU86YI82(*;7-G<W1R("*SRKKQ(+3<P*<B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]I;6%G97,N<&AP.C@S"FUS9VED("),;V%D
M:6YG+BXN(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<#HR,3$*(RP@9G5Z>GD*;7-G:60@(DQO8V%L('1I;64Z("(*;7-G<W1R
M("*]Q\?@(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@S"FUS9VED("),
M;V-A;&4@86YD(%1I;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HU-S$@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN
M<&AP.C8T"B,Z(&QI8B]";&]C:R]S=6YR:7-E+G!H<#HR,B!L:6(O0FQO8VLO
M;65T87(N<&AP.C8U"B,L(&9U>GIY"FUS9VED("),;V-A=&EO;B(*;7-G<W1R
M("*]Q\?@(@H*(SH@;&]G:6XN<&AP.C$W,B!S97)V:6-E<R]P;W)T86PO<VED
M96)A<BYP:'`Z,3DQ('1E;7!L871E<R]L;V=I;B]M;V)I;&4N:6YC.C,*(SH@
M=&5M<&QA=&5S+VQO9VEN+VUO8FEL92YI;F,Z,34@=&5M<&QA=&5S+VQO9VEN
M+VQO9VEN+FEN8SHY,`IM<V=I9"`B3&]G(&EN(@IM<V=S='(@(K?.L=?`SB(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C(T-0IM<V=I9"`B3&]G
M(&]F('!R979I;W5S('-Y;F,@<V5S<VEO;B(*;7-G<W1R("(B"@HC.B!S97)V
M:6-E<R]P;W)T86PO<VED96)A<BYP:'`Z,3@U"FUS9VED("),;V<@;W5T(@IM
M<V=S='(@(K?.L=>^QK_T(@H*(SH@;&EB+T)L;V-K+V%C8V]U;G0N<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED("),;V=I;B(*;7-G<W1R("*WSK'7P,XB"@HC.B!C
M;VYF:6<O<')E9G,N<&AP+F1I<W0Z,3`W"FUS9VED("),;V=I;B!487-K<R(*
M;7-G<W1R("*WSK'7P,X@O</`V\#;OO<B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+G!H<#HY.38*(RP@9G5Z>GD*;7-G:60@(DQO9VEN(&9A:6QE9"!B96-A
M=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC
M;W)R96-T;'DN(@IM<V=S='(@(B(*(K[NMK(@P,S`K[?.(+?.L=?`SL#,(+W'
MQM#'W[W`M,^TV2X@M.NZSKK0P,<@L.:_[""[Y[_KP-H@P,RXIR"VQ[3"(+[/
MR*.PH2#`WR(*(KCX(,#4M\*UR""PYK_L(+G?N_W'U;3/M-DN(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"YP:'`Z.3DR"B,L(&9U>GIY"FUS9VED("),;V=I
M;B!F86EL960N(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C$S-C4*(RP@9G5Z>GD*;7-G:60@(DQO;F<@=&5X="(*
M;7-G<W1R("*WSK'7OL:_]"(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HT
M.`HC+"!F=7IZ>0IM<V=I9"`B3&]V92(*;7-G<W1R("+`S+6_(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C<*;7-G:60@(DQO
M=R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]L:7-T='EP95]L86YG+FIS.C(Q"FUS9VED("),;W=E<B!G<F5E:R!L971T
M97)S(@IM<V=S='(@(K'7N*Z]NB"\TKFNP-HB"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]L:7-T='EP95]L86YG+FIS.C$Y"FUS9VED("),
M;W=E<B!L871I;B!L971T97)S(@IM<V=S='(@(K;SQKX@O-*YKL#:(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&ES='1Y<&5?;&%N9RYJ
M<SHQ-PIM<V=I9"`B3&]W97(@<F]M86X@;G5M8F5R<R(*;7-G<W1R("*WSKBV
M(+S2N:[`VB"\_<#:(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-#4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ,S0*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C@Y"FUS9VED("),=7AE;6)O=7)G
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,#`*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0S."!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-PHC.B!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHT."!T96UP;&%T97,O9&%T82]D871E+FEN
M8SHT.0HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B34TB
M"FUS9W-T<B`B34TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,C@Q
M"FUS9VED(")-3U1$(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W1N968N<&AP.C,V"B,L(&9U>GIY"FUS9VED(")-4RU43D5&
M($%T=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N(@IM<V=S='(@(L;$P,^_
MH2"^QKFKM[$@P-JWX;"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R].;W1I
M9FEC871I;VXO3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S<*
M(RP@9G5Z>GD*;7-G:60@(DU31R(*;7-G<W1R(")#5E,B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$U-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$S-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.3(*(RP@9G5Z>GD*;7-G:60@(DUA8V%O(@IM<V=S='(@(C._^2(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34S(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,0IM<V=I9"`B36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,34Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,`IM<V=I9"`B
M36%D86=A<V-A<B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP
M:'`Z-#D*(RP@9G5Z>GD*;7-G:60@(DUA9VEC(@IM<V=S='(@(L"EN-[`SR(*
M"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HX,0IM<V=I9"`B36%I;"(*
M;7-G<W1R("*XWL#/(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C4R
M,@IM<V=I9"`B36%I;"!!9&UI;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-#$*;7-G:60@
M(DUA:V4@;&EN7VLN+BXB"FUS9W-T<B`B7VNXM<6I(+BXM>FQXBXN+B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38U(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,3,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HY-`HC+"!F=7IZ>0IM<V=I9"`B36%L87=I(@IM<V=S='(@(L"E
MN-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38W(&9R86UE
M=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3,Y"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+T=E;TE0+G!H<#HY-0HC+"!F=7IZ>0IM<V=I9"`B36%L87ES:6$B
M"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ-C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDT"B,L(&9U>GIY"FUS9VED
M(")-86QD:79E<R(*;7-G<W1R("*XWL#/(,?*Q<TB"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$U-"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$T,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*
M(RP@9G5Z>GD*;7-G:60@(DUA;&DB"FUS9W-T<B`BP*6XWL#/(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-C(@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-#(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDT"B,L(&9U>GIY"FUS9VED(")-86QT82(*;7-G<W1R("+`I;C>P,\B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z.3$*;7-G:60@(B(*(DUA;F%G
M92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET
M96US('=I=&@L(&%N9"!C;VQO<G,@(@HB87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HQ,34S"FUS9VED(")-87`R-"!M87`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$P.#0*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C$Q-C@*;7-G:60@(DUA<%%U97-T(&UA<"(*;7-G<W1R("(B"@HC.B!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HQ,#4*;7-G:60@(DUA<'!I;F=S
M('-T;W)E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P,PHC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0Q"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-C<*;7-G:60@(DUA<F-H(@IM<V=S='(@(C._^2(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-#$*;7-G:60@(DUA<F=I;B(*;7-G<W1R("*PH<#EP-JXKB(*"B,Z(&9R
M86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C@X"FUS9VED(")-
M87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#D*;7-G:60@(DUA
M<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,34R
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30S"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY,0IM<V=I9"`B36%R<VAA;&P@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$U.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T-`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*;7-G:60@
M(DUA<G1I;FEQ=64B"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!T96UP;&%T97,O
M9&%T82]C<W9M87`N:6YC.C$P,PIM<V=I9"`B36%T8VAI;F<@9FEE;&1S(@IM
M<V=S='(@(L#/Q*''S[3"(,?7N/$B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$V,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$T
M-0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3,*(RP@9G5Z>GD*
M;7-G:60@(DUA=7)I=&%N:6$B"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$T-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.30*;7-G:60@(DUA=7)I=&EU<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,34*;7-G:60@
M(DUA>"!A;&QO=V5D(&-R961I="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S`X"B,L(&9U>GIY
M"FUS9VED(")-87@@;65S<V%G92!P87)T<R!E>&-E961E9"XB"FUS9W-T<B`B
MN-Z]P\'V(,?7N/$B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P-@IM<V=I
M9"`B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,CDX"FUS9VED(")-87@@=&5M<"!L87-T(#8@
M:&]U<G,Z("(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HX-@IM<V=I9"`B
M36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HX.3@@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(Q-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C,Y
M"FUS9VED(")-87AI;75M(&QE;F=T:"(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#`U"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-#,*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV.0IM<V=I9"`B36%Y(@IM
M<V=S='(@(C6_^2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4S
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30W"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(DUA
M>6]T=&4B"FUS9W-T<B`B-;_Y(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP
M.C4P"B,L(&9U>GIY"FUS9VED(")-961I8VEN92(*;7-G<W1R("*[Z,&FM<@@
MN-[`SR(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z,38*
M(RP@9G5Z>GD*;7-G:60@(DUE;6)E<G,B"FUS9W-T<B`B,3&_^2(*"B,Z(&-O
M;F9I9R]P<F5F<RYP:'`N9&ES=#HS-S@*;7-G:60@(DUE;G4@;6]D93HB"FUS
M9W-T<B`BN-ZTNB"X\+7E(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHV,`IM<V=I9"`B365R9V4@8V5L;',B"FUS
M9W-T<B`BO+\@Q]7$H;'B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].
M;W1I9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HS,`HC.B!S97)V:6-E
M<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*;7-G:60@(DUE<W-A9V4B"FUS9W-T
M<B`BN-Z]P\'V(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HR,38*;7-G:60@(B(*(DUE<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY
M(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E("(*
M(G9E<FEF:65D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,3`*(RP@9G5Z>GD*;7-G:60@(DUE
M<W-A9V4@97AP:7)E9"XB"FUS9W-T<B`BN-Z]P\'V(,?7N/$B"@HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V.0HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8P,@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR
M,C<*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP
M:'`Z,C8P"B,L(&9U>GIY"FUS9VED(")-97-S86=E('1Y<&4B"FUS9W-T<B`B
MN-Z]P\'V(,#/P-HB"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,*;7-G:60@
M(DUE=&%R(%=E871H97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R
M+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92XB"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39
M+B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,3$R"B,L(&9U>GIY"FUS9VED
M("(B"B)-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+B(*;7-G<W1R("*\
MO+K.P:2ZN+"A(+#\N*[`VKBF(,"GQ]@@L>*WS[7'ON[!L[W`M,^TV2XB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38U"FUS9VED(")-971A
M<D1"(&ES(&YO="!C;VYN96-T960N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C<@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O>FEP+G!H<#HW-`IM<V=I9"`B365T:&]D(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`Z.#$@9G)A;65W
M;W)K+U)00R]24$,O<V]A<"YP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@
M(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O<F5S="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<R(*
M;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-S0@
M;&EB+T)L;V-K+VUE=&%R+G!H<#HW-0IM<V=I9"`B365T<FEC(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,38V(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,30X"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-0IM<V=I9"`B365X:6-O(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z.#4@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-#D*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.C<R"FUS9VED(")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7W1A8FQE7VQA;F<N:G,Z-#(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHW-@IM<V=I9"`B36ED9&QE(@IM<V=S='(@(K"A
MO^ZUI2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1N968N<&AP
M.C,X"FUS9VED(")-:6UE(%1Y<&4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K
M+VUE=&%R+G!H<#HS,3`*;7-G:60@(DUI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C,P,@IM<V=I
M9"`B36EN('1E;7`@;&%S="`V(&AO=7)S.B`B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T%U=&@O075T:"]L9&%P+G!H<#HT,SD*;7-G:60@(DUI;FEM=6T@
M<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(S-`HC
M+"!F=7IZ>0IM<V=I9"`B36ER<F]R(@IM<V=S='(@(K_`M_DB"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-3$*;7-G:60@(DUI<V-E;&QA;F5O=7,B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H
M='1P+G!H<#HV-S(*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E
M;&Q?:'1T<"YP:'`Z,S0P"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?
M:'1T<"YP:'`Z,C4P"FUS9VED(")-:7-S:6YG(%!%05(@<&%C:V%G92!(5%10
M7U)E<75E<W0N(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ,34*;7-G:60@(B(*(DUI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M("(*(F%P<&QI8V%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,#0*(RP@9G5Z>GD*;7-G
M:60@(DUI<W-I;F<@;65S<V%G92!)1"XB"FUS9W-T<B`BN-Z]P\'V(,#,M;_'
MS['B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z-3@*;7-G:60@(DUI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K
M86=E($UA:6PN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y-`HC+"!F=7IZ>0IM<V=I9"`B36ES
M<VEN9R!S97-S:6]N($E$+B(*;7-G<W1R("*XWKW#P?8@P,RUO\?/L>(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4V"B,L
M(&9U>GIY"FUS9VED(")-;R(*;7-G<W1R("+`S+6_(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C<T"B,L(&9U>GIY"FUS9VED(")-;V)I;&4@36%I
M;"(*;7-G<W1R("*[]2"XWL#/(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-C@*;7-G:60@(DUO9&5R871E(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)A<BYP:'`Z-C8@9G)A
M;65W;W)K+TU)344O34E-12]6:65W97(O>FEP+G!H<#HW,PHC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]T9WHN<&AP.C@X"FUS9VED(")-;V1I9FEE
M9"!$871E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,PIM<V=I9"`B36]D:69Y(%523"(*
M;7-G<W1R(")54DP@O/;!I"(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z-C<S"B,L(&9U>GIY"FUS9VED(")-;V1U;'5S(@IM<V=S='(@
M(K^JQ](B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$U,"!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U,`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z.3`*(RP@9G5Z>GD*;7-G:60@(DUO;&1O=F$L
M(%)E<'5B;&EC(&]F(@IM<V=S='(@(K3KQ]&YSK&Y(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-3$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDP
M"B,L(&9U>GIY"FUS9VED(")-;VYA8V\B"FUS9W-T<B`B,[_Y(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-38@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-3(*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDR"FUS9VED(")-;VYG;VQI82(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-3DT"FUS9VED(")-;VYT:"!A;F0@>65A<B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O36%I;G1E;F%N
M8V4N<&AP.C4W"FUS9VED(")-;VYT:&QY(@IM<V=S='(@(KC%O_DB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$V,2!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$U,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z.30*;7-G:60@(DUO;G1S97)R870B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUO;VXN<&AP.C,@;&EB+T)L;V-K+VUO;VXN<&AP.C$V"FUS9VED
M(")-;V]N(%!H87-E<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1FEL95]#
M4U8O0U-6+G!H<#HQ-S(@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,C4S
M"B,L('!H<"UF;W)M870*;7-G:60@(DUO<F4@9FEE;&1S(&9O=6YD(&EN(&QI
M;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30X(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,34T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY,`IM<V=I9"`B36]R;V-C;R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS,PIM<V=I9"`B36]S=&QY
M($-L96%R(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C,T"B,L(&9U>GIY"FUS9VED(")-;W-T;'D@0VQO=61Y
M(@IM<V=S='(@(KJYN^<B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S
M=')I;F=S+G!H<#HS-0IM<V=I9"`B36]S=&QY(%-U;FYY(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C4P.0IM<V=I
M9"`B36]V92!$;W=N(@IM<V=S='(@(K[&MZ&WSB#`S+6_(@H*(SH@9G)A;65W
M;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$S"B,L(&9U>GIY"FUS9VED
M(")-;W9E($QE9G0B"FUS9W-T<B`BP*>WSB#`S+6_(@H*(SH@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z-3$W"B,L(&9U>GIY"FUS9VED(")-
M;W9E(%)I9VAT(@IM<V=S='(@(K_`N*7"RB(*"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.C4P-0IM<V=I9"`B36]V92!5<"(*;7-G<W1R
M("+`I[?.(,#,M;\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O
M:'1M;"YP:'`Z-3(T"B,L(&9U>GIY"FUS9VED(")-;W9E(&1O=VXB"FUS9W-T
M<B`BOL:WH;?.(,#,M;\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R
M97(O:'1M;"YP:'`Z-3(S"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HU,C0*(RP@9G5Z>GD*;7-G:60@(DUO=F4@=7`B"FUS9W-T
M<B`BP*>WSB#`S+6_(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ
M-C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-34*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDU"FUS9VED(")-;WIA;6)I<75E
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Q.#0*
M;7-G:60@(DUU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<R(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`U
M-0IM<V=I9"`B375L=&EM87`@54L@;6%P(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#(*(RP@9G5Z>GD*;7-G:60@(DUU;'1I
M<&QE('-E;&5C=&EO;B(*;7-G<W1R("*QU,2B*+?\*2"\L<7#(+_`M_DB"@HC
M.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#`P"B,L(&9U>GIY"FUS9VED
M(")->2!!8V-O=6YT(@IM<V=S='(@(K_`N*?"][SX(@H*(SH@;&EB+T)L;V-K
M+V%C8V]U;G0N<&AP.C(X"B,L(&9U>GIY"FUS9VED(")->2!!8V-O=6YT($EN
M9F]R;6%T:6]N(@IM<V=S='(@(L&DNK@B"@HC.B!S97)V:6-E<R]P;W)T86PO
M:6YD97@N<&AP.C4T"FUS9VED(")->2!0;W)T86PB"FUS9W-T<B`B(@H*(SH@
M<V5R=FEC97,O<&]R=&%L+V5D:70N<&AP.C$S-@IM<V=I9"`B37D@4&]R=&%L
M($QA>6]U="(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N
M<&AP.C$U-2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$U-@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3(*(RP@9G5Z>GD*;7-G
M:60@(DUY86YM87(B"FUS9W-T<B`BP,RXIR(*"B,Z('1E;7!L871E<R]M86EN
M=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4W"FUS9VED(").3RP@22!$;R!.
M3U0@06=R964B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W!G<"YP:'`Z-#$Q(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HQ,#(*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&YE9BYP
M:'`Z,S@*;7-G:60@(DYA;64B"FUS9W-T<B`BP,RXIR(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,38Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,34W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY
M-0IM<V=I9"`B3F%M:6)I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$W."!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$U.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3<*;7-G
M:60@(DYA=7)U(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,3<W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,34Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM
M<V=I9"`B3F5P86PB"FUS9W-T<B`BN_4@N-[`SR(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3<U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,38P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HY-PHC
M+"!F=7IZ>0IM<V=I9"`B3F5T:&5R;&%N9',B"FUS9W-T<B`BN_4@N-[`SR(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-C$*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C4W"FUS9VED(").971H97)L86YD<R!!;G1I;&QE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X
M,0IM<V=I9"`B3F5T<V-A<&4@0F%S92!54DPB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#,*;7-G:60@(DYE='-C
M87!E($-!(%)E=F]C871I;VX@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-3@U"FUS9VED(").971S8V%P92!#
M02!P;VQI8WD@55),(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#
M<GEP="]S;6EM92YP:'`Z-3@T"FUS9VED(").971S8V%P92!296YE=V%L(%52
M3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C4X,@IM<V=I9"`B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU.#8*
M;7-G:60@(DYE='-C87!E(%-33"!S97)V97(@;F%M92(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X-PIM<V=I9"`B
M3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N="(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4X,`IM<V=I9"`B3F5T
M<V-A<&4@8V5R=&EF:6-A=&4@='EP92(*;7-G<W1R("(B"@HC.B!C;VYF:6<O
M<F5G:7-T<GDN<&AP+F1I<W0Z,C4Q"FUS9VED(").971W;W)K(@IM<V=S='(@
M(K/7QJZ_]L6I(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z
M-#(U(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HS,S4*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C,X-@IM<V=I9"`B3F5V97(B"FUS9W-T<B`BN^>_Z[[(Q]0B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$V,@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z.34*;7-G:60@(DYE=R!#86QE9&]N:6$B"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-3`*(SH@=&5M<&QA=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI
M;F,Z,C8*;7-G:60@(DYE=R!#871E9V]R>2(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z.#$*(SH@9G)A
M;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]E;6%I;',N<&AP.C@W"B,Z(&9R
M86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UA:6QS+G!H<#HY-PHC.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+V5M86EL<RYP:'`Z,3`Q"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(").97<@365S<V%G92!T;R`E<R(*
M;7-G<W1R("*XWKW#P?8@P-N\NB`H)7,I(@H*(SH@;&EB+T)L;V-K+VUO;VXN
M<&AP.C0V(&QI8B]";&]C:R]M;V]N+G!H<#HV."!L:6(O0FQO8VLO;6]O;BYP
M:'`Z,3<T"B,L(&9U>GIY"FUS9VED(").97<@36]O;B(*;7-G<W1R("*[]2"X
MWL#/(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHS-0HC
M+"!F=7IZ>0IM<V=I9"`B3F5W(%5S97)N86UE("AO<'1I;VYA;"DB"FUS9W-T
M<B`BM;6_\KB[(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#`@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-C,*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"B,L(&9U>GIY"FUS9VED(").97<@
M6F5A;&%N9"(*;7-G<W1R("*[]2"XWL#/(@H*(SH@<V5R=FEC97,O8VAA;F=E
M<&%S<W=O<F0N<&AP.C,W"B,L(&9U>GIY"FUS9VED(").97<@<&%S<W=O<F0B
M"FUS9W-T<B`BOL_(HR(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<W%L+G!H
M<#HR,C<*(RP@<&AP+69O<FUA=`IM<V=I9"`B3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]C:&%N9V5P
M87-S=V]R9"YP:'`Z-3(*(RP@9G5Z>GD*;7-G:60@(DYE=R!P87-S=V]R9',@
M9&]N)W0@;6%T8V@N(@IM<V=S='(@(K[/R*.PH2#`S\2AQ\_!]B"^RKW`M,^T
MV2XB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.CDQ"FUS9VED(").97<@=VEN9&]W("A?8FQA;FLI(@IM<V=S='(@(KOU(,.B
M*%]B;&%N:RDB"@HC.B!L:6(O0FQO8VLO9V]O9VQE+G!H<#HT,"!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3(*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T
M.C(X.0HC+"!F=7IZ>0IM<V=I9"`B3F5W<R(*;7-G<W1R("*[]2"XWL#/(@H*
M(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C,P-0IM<V=I9"`B3F5W<V=R
M;W5P<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O9&%T82]T<W9I;F9O+FEN
M8SHQ-2!T96UP;&%T97,O9&%T82]D871E;6%P+FEN8SHT,0HC.B!T96UP;&%T
M97,O9&%T82]C<W9M87`N:6YC.C$R.2!T96UP;&%T97,O9&%T82]C<W9I;F9O
M+FEN8SHR-0IM<V=I9"`B3F5X="(*;7-G<W1R("*TV<"](@H*(SH@;&EB+T)L
M;V-K+VUO;VXN<&AP.C(W"B,L(&9U>GIY"FUS9VED(").97AT(#0@4&AA<V5S
M(@IM<V=S='(@(K39P+T@QN3`S,'V(@H*(SH@9G)A;65W;W)K+U!R969S+U!R
M969S+U5)+G!H<#HS-S(@9G)A;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HS
M-S8*(RP@9G5Z>GD*;7-G:60@(DYE>'0@;W!T:6]N<R(*;7-G<W1R("*_R;S'
MP+BWSB"UN;[&L*&QXB(*"B,Z(&9R86UE=V]R:R]522]522]086=E<BYP:'`Z
M,3`S"B,L(&9U>GIY"FUS9VED(").97AT/B(*;7-G<W1R("*TV<"](@H*(SH@
M9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S0@9G)A;65W;W)K+TY,4R].
M3%,O8V]U;G1R:65S+G!H<#HQ-C0*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O
M25`N<&AP.CDV"FUS9VED(").:6-A<F%G=6$B"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S$@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HQ-C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.CDV"B,L(&9U>GIY"FUS9VED(").:6=E<B(*;7-G<W1R("*[Y[_KOLC'
MU"(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<S(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38V"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HY-@HC+"!F=7IZ>0IM<V=I9"`B3FEG97)I82(*;7-G
M<W1R("*[Y[_KOLC'U"(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H
M<#HS.#`*(RP@9G5Z>GD*;7-G:60@(DYI9VAT(@IM<V=S='(@(K_`N*7"RB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3<Y(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,38W"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HY-PHC+"!F=7IZ>0IM<V=I9"`B3FEU92(*;7-G<W1R("+"
M_,&V(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP
M.CDV,PIM<V=I9"`B3F\B"FUS9W-T<B`BOL:TS[_`(@H*(SH@=&5M<&QA=&5S
M+V%D;6EN+W-E='5P+V1I9F8N:'1M;#HY"FUS9VED(").;R!A=F%I;&%B;&4@
M8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(N<&AP.C$P-0IM<V=I9"`B3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,S$S"FUS9VED(").;R!B
M871C:"!T96UP;&%T92XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T)L;V-K
M+T)L;V-K+TQA>6]U="YP:'`Z-SD@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA
M>6]U="YP:'`Z,C0U"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N
M<&AP.C(V-PIM<V=I9"`B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T
M960@<&]S:71I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T%U=&@O075T
M:"]M8V%L+G!H<#HU,`HC+"!F=7IZ>0IM<V=I9"`B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B
M4U%,(,#.P?4@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!A9&UI;B]S971U
M<"]D:69F+G!H<#HU-`HC+"!F=7IZ>0IM<V=I9"`B3F\@8VAA;F=E+B(*;7-G
M<W1R("*ZK[#FN^?'UR"UQ[6YN*ZQXB(*"B,Z(&9R86UE=V]R:R]097)M<R]0
M97)M<R]522YP:'`Z,34V"FUS9VED(").;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4N<&AP.C$V-R!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C4P,@HC.B!F<F%M97=O<FLO571I;"]5=&EL+G!H<#HW-S,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B`E<RXB"FUS9W-T<B`B4U%,(%9&4R"\L\&D
MP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP
M:'`Z.#(T"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RXB"FUS9W-T<B`B1E10(%9&4[BF(,"GQ]$@
MO+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S
M<6PN<&AP.C8V.0IM<V=I9"`B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R(%-13"!61E,N(@IM<V=S='(@(E-13"!61E,@O+/!
MI,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z-S$W"FUS9VED(").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+B(*;7-G<W1R(")344PM
M1FEL92!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HS,30*;7-G:60@(DYO
M(&-R961I="!L969T+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S-`HC+"!F=7IZ>0IM<V=I9"`B
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N(@IM<V=S='(@(KOU(+C>P,\B"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX-S<*(RP@9G5Z>GD*
M;7-G:60@(DYO(&9I;&4@=7!L;V%D960B"FUS9W-T<B`BQ\JUY2(*"B,Z('5T
M:6PO:6-O;E]B<F]W<V5R+G!H<#HW,0IM<V=I9"`B3F\@:6-O;G,@9F]U;F0N
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ
M,C@@;&EB+T)L;V-K+W-U;G)I<V4N<&AP.C0P"B,Z(&QI8B]";&]C:R]M971A
M<BYP:'`Z,3(S"FUS9VED(").;R!L;V-A=&EO;B!I<R!S970N(@IM<V=S='(@
M(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-CD*(RP@9G5Z
M>GD*;7-G:60@(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(*;7-G<W1R("+&^K3U
MN*8@O+'%P\?/O+R_Y"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C,S"B,L(&9U>GIY"FUS9VED(").;R!M97-S86=E
M('-U<'!L:65D+B(*;7-G<W1R("*[]2"XWL#/(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HV,S8*(RP@9G5Z>GD*;7-G
M:60@(DYO(&YA;64@<W!E8VEF:65D+B(*;7-G<W1R("*YKL#:OZT@P-2WPB"_
MP+?Y(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HV,S<*(RP@9G5Z>GD*;7-G:60@(DYO(&YU;6)E<B!S<&5C:69I960N
M(@IM<V=S='(@(KFNP-J_K2#`U+?"(+_`M_DB"@HC.B!L:6(O0FQO8VLO9F]R
M='5N92YP:'`Z.30*;7-G:60@(DYO(&]F9F5N<VEV92!F;W)T=6YE<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VAT='`N<&AP.CDQ"B,L
M(&9U>GIY"FUS9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+VEM87`N<&AP.C$P
M.`HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-
M05`@875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!I+JX
ML*$@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]K<F(U+G!H
M<#HW,@HC+"!F=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!]2"\
ML\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O
M<V%S;"YP:'`Z-S<@9G)A;65W;W)K+T%U=&@O075T:"]L;V=I;BYP:'`Z.#0*
M(SH@9G)A;65W;W)K+T%U=&@O075T:"]P86TN<&AP.C<U"B,L(&9U>GIY"FUS
M9VED(").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC
M871I;VXN(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!I+JXL*$@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]P87-S=V0N<&AP.C$S-0HC+"!F
M=7IZ>0IM<V=I9"`B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BXB"FUS9W-T<B`B4U%,(,#.P?4@O+/!I,&DNKBPH2"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`Z.#0*
M(RP@9G5Z>GD*;7-G:60@(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@
M875T:&5N=&EC871I;VXN(@IM<V=S='(@(E-13"#`SL'U(+RSP:3!I+JXL*$@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H
M<#HQ,C@V"FUS9VED("(B"B).;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R`B"B)W;W)K('=I=&@@4$M#4R`Q,B!D871A+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHV"FUS9VED(").;R!P
M96YD:6YG('-I9VYU<',N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+G!H<#HW-3`*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(DYO('%U
M;W1A('-E="XB"FUS9W-T<B`BP::X\2"^^,"](@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT,PHC+"!F=7IZ>0IM
M<V=I9"`B3F\@<G5L97,B"FUS9W-T<B`BPOS!MB(*"B,Z(&9R86UE=V]R:R]&
M:6QE7T-35B]#4U8N<&AP.C0T.0HC+"!F=7IZ>0IM<V=I9"`B3F\@<V5P87)A
M=&]R('-P96-I9FEE9"XB"FUS9W-T<B`BN:[`VK^M(,#4M\(@O\"W^2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-#0*(RP@9G5Z>GD*;7-G:60@(DYO('-I9&5S(@IM<V=S='(@(L+\P;8B"@HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C4X,PHC+"!F=7IZ>0IM<V=I
M9"`B3F\@<W5C:"!F:6QE(@IM<V=S='(@(L+\P;8B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,3,X"FUS9VED(").;R!T96UP;W)A<GD@9&ER
M96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Q"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(Q"B,L(&9U
M>GIY"FUS9VED(").;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="XB
M"FUS9W-T<B`BN^>_Z\#:P,RXI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D(@H*(SH@
M9G)A;65W;W)K+U)00R]24$,O>&UL<G!C+G!H<#HQ-#`*;7-G:60@(DYO('9A
M;&ED(%A-3"!D871A(')E='5R;F5D(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HY-S$*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.CDX,0HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z.3DR"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HQ,#`Y"B,L(&9U>GIY"FUS9VED
M(").;R!V86QU97,B"FUS9W-T<B`BPOS!MB(*"B,Z(&%D;6EN+W-E='5P+VEN
M9&5X+G!H<#HQ,C`*;7-G:60@(DYO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN
M86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*
M;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]I;F1E>"YP:'`Z,3(X"FUS9VED
M(").;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G
M96YE<F%T92!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HT,C<*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHT-0HC.B!T96UP;&%T97,O
M<')E9G,O:61E;G1I='ES96QE8W0N:6YC.CDS"FUS9VED(").;VYE(@IM<V=S
M='(@(KRQQ</'S\'V(+[*P+TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.CDP"FUS9VED(").;VYE("AU<V4@:6UP;&EC:70I
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3@Y"FUS9VED
M(").;W)D:6,@*$E33RTX.#4Y+3$P*2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C$W,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C$V.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M.38*;7-G:60@(DYO<F9O;&L@27-L86YD(@IM<V=S='(@(B(*"B,Z(&QI8B]"
M;&]C:R]M;V]N+G!H<#HS,B!L:6(O0FQO8VLO;6]O;BYP:'`Z-C`*;7-G:60@
M(DYO<G1H97)N($AE;6ES<&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ-3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-CD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDS
M"FUS9VED(").;W)T:&5R;B!-87)I86YA($ES;&%N9',B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ-S8@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ-S`*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.CDW"B,L(&9U>GIY"FUS9VED(").;W)W87DB"FUS9W-T<B`B
MP/RTWB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-C0P
M"B,L(&9U>GIY"FUS9VED(").;W0@069T97(B"FUS9W-T<B`BP-.]P[JXL/RU
MQ\'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM
M92YP:'`Z-C,Y"B,L(&9U>GIY"FUS9VED(").;W0@0F5F;W)E(@IM<V=S='(@
M(L#3O<.ZN+#\M<?!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HT,#@*(RP@9G5Z>GD*;7-G:60@(DYO="!A(&1I<F5C=&]R
M>2(*;7-G<W1R("*U\+>ZQ>2XKB(*"B,Z(&9R86UE=V]R:R]61E-?25-/5W)I
M=&5R+TE33U=R:71E<BYP:'`Z-C,*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET
M97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'`Z.#,*(SH@9G)A
M;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A
M=&5G>2YP:'`Z.30*(SH@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I
M=&5R+U)E86Q);G!U=%-T<F%T96=Y+G!H<#HT.`HC.B!F<F%M97=O<FLO5D93
M7TE33U=R:71E<B])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP.C4Y
M"B,L(&9U>GIY"FUS9VED(").;W0@:6UP;&5M96YT960N(@IM<V=S='(@(KOH
MP::UQ\'V(+[*P+H@N-[`SR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7VQA;F<N:G,Z-C@*(RP@9G5Z>GD*;7-G:60@(DYO="!S970B"FUS
M9W-T<B`BP::X\2"^^,"](@H*(SH@9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R
M+U-E<W-I;VY(86YD;&5R+G!H<#HQ-#,*(SH@9G)A;65W;W)K+U-E<W-I;VY(
M86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-3@*(SH@9G)A;65W;W)K+U-E
M<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ-S,*(SH@9G)A;65W
M;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HQ.#<*(SH@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<#HR
M,S0@9G)A;65W;W)K+U9&4R]61E,N<&AP.C$Y,`HC.B!F<F%M97=O<FLO5D93
M+U9&4RYP:'`Z,C`U(&9R86UE=V]R:R]61E,O5D93+G!H<#HR,S`*(SH@9G)A
M;65W;W)K+U9&4R]61E,N<&AP.C(T."!F<F%M97=O<FLO5D93+U9&4RYP:'`Z
M,C8U"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HR.#$@9G)A;65W;W)K+U9&
M4R]61E,N<&AP.C(Y-PHC.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z,S$R(&9R
M86UE=V]R:R]61E,O5D93+G!H<#HS,CD*(SH@9G)A;65W;W)K+U9&4R]61E,N
M<&AP.C,V,B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-#(R"B,Z(&9R86UE=V]R
M:R]61E,O5D93+G!H<#HU,#$@9G)A;65W;W)K+U9&4R]61E,N<&AP.C4W,`HC
M.B!F<F%M97=O<FLO5D93+U9&4RYP:'`Z-3@W(&9R86UE=V]R:R]61E,O5D93
M+G!H<#HV-C4*(RP@9G5Z>GD*;7-G:60@(DYO="!S=7!P;W)T960N(@IM<V=S
M='(@(KOHP::UQ\'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O5FEE=V5R+W9C87)D+G!H<#HR-#0@8V]N9FEG+VAO;VMS+G!H<"YD:7-T
M.C$P,#4*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$W.`IM<V=I9"`B
M3F]T97,B"FUS9W-T<B`BPOS!MB(*"B,Z('-E<G9I8V5S+V]B<F]W<V5R+VEN
M9&5X+G!H<#HS-@IM<V=I9"`B3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H
M=&UL+G!H<#HT,3$*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT
M;6PN<&AP.C0T.0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N
M9&%R+FIS.C<U"FUS9VED(").;W9E;6)E<B(*;7-G<W1R("(Q,;_Y(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`T-@HC+"!F=7IZ>0IM<V=I9"`B
M3G5M8F5R(@IM<V=S='(@(C$QO_DB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ-#(U"B,L(&9U>GIY"FUS9VED(").=6UB97(@;V8@8VAA<F%C=&5R
M<R(*;7-G<W1R("+'X,#'(+SV(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,3,V.2!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ-#(S"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$T-#4@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHQ,#0*;7-G:60@(DYU;6)E<B!O9B!C;VQU;6YS
M(@IM<V=S='(@(K^MP,<@O/8B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H
M<#HQ,S8W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,C$*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,30T,R!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]L86YG+FIS.C$P,@IM<V=I9"`B3G5M8F5R(&]F(')O=W,B"FUS
M9W-T<B`BQ^#`QR"\]B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R
M96UA:6Q?:'1T<"YP:'`Z-C0T"FUS9VED(").=6UB97)S(&YO="!S<&5C:69I
M960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C0V"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M-C0*;7-G:60@(D]+(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HX-S,*(RP@9G5Z>GD*;7-G:60@(D]B:F5C
M="(*;7-G<W1R("+!IKCQ(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHQ,3$*(RP@9G5Z>GD*;7-G:60@(D]B:F5C="!#<F5A=&]R(@IM<V=S='(@
M(L&FN/$B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,3`T"B,L(&9U
M>GIY"FUS9VED(")/8W1A;"(*;7-G<W1R("+`S[JP(@H*(SH@9G)A;65W;W)K
M+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C0Q,`HC.B!F<F%M97=O<FLO
M54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#0X"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+V]P96Y?8V%L96YD87(N:G,Z-S0*;7-G:60@(D]C=&]B97(B
M"FUS9W-T<B`B,3"_^2(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HY,@IM
M<V=I9"`B3V9F96YS92!F:6QT97(B"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W)E
M9VES=')Y+G!H<"YD:7-T.C,R-@HC+"!F=7IZ>0IM<V=I9"`B3V9F:6-E(@IM
M<V=S='(@(L&FN/$B"@HC.B!S97)V:6-E<R]C:&%N9V5P87-S=V]R9"YP:'`Z
M-3@*;7-G:60@(D]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="XB"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O8VAA;F=E<&%S<W=O<F0N
M<&AP.C,V"B,L(&9U>GIY"FUS9VED(")/;&0@<&%S<W=O<F0B"FUS9W-T<B`B
MOL_(HR(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HT-@HC+"!F
M=7IZ>0IM<V=I9"`B3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+B(*;7-G
M<W1R("*^S\BC(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.#$@
M9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ-S$*(SH@9G)A;65W
M;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX"FUS9VED(")/;6%N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C<S
M"FUS9VED(")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z.34*
M;7-G:60@(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X-3$@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3DW,0HC+"!F=7IZ>0IM<V=I9"`B3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B
M"@HC.B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z-C4*;7-G:60@(B(*(D]N
M;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N
M9V4@;W=N97)S:&EP(&]R(&]W;F5R("(*(G!E<FUI<W-I;VYS(&9O<B!A('-H
M87)E(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,U"B,L
M(&9U>GIY"FUS9VED(")/<&5N(&EN(&$@;F5W('=I;F1O=R(*;7-G<W1R("*[
M]2##HK^A(+BUQ:D@OZVQXB(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,C0U"FUS9VED(")/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@
M97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT
M7VQA;F<N:G,Z-34*;7-G:60@(D]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<B"FUS9W-T<B`BN_4@PZ*_H2"XM<6I(+^ML>(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-3,*;7-G:60@(D]P97)A=&EN9R!3>7-T96TB"FUS
M9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-I9&5B87(N<&AP.C$U,0IM
M<V=I9"`B3W!T:6]N<R(*;7-G<W1R("*\L<7#N^?'UR(*"B,Z('-E<G9I8V5S
M+W!R969S+G!H<#HS,2!T96UP;&%T97,O<')E9G,O87!P+FEN8SHQ-`HC+"!P
M:'`M9F]R;6%T"FUS9VED(")/<'1I;VYS(&9O<B`E<R(*;7-G<W1R("(E<R"\
ML<7#N^?'UR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA
M;F<N:G,Z,3@*;7-G:60@(D]R9&5R960@3&ES="(*;7-G<W1R("*\_<#:(+CQ
MM\\B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V-PIM
M<V=I9"`B3W)G86YI<V%T:6]N(@IM<V=S='(@(K3<P[PB"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4V.`HC+"!F=7IZ>0IM<V=I9"`B
M3W)G86YI<V%T:6]N86P@56YI="(*;7-G<W1R("*TW,.\(@H*(SH@8V]N9FEG
M+W)E9VES=')Y+G!H<"YD:7-T.C$S,@HC+"!F=7IZ>0IM<V=I9"`B3W)G86YI
M>FEN9R(*;7-G<W1R("*TW,.\(@H*(SH@861M:6XO=&5M<&QA=&5S+G!H<#HQ
M,S4*(RP@9G5Z>GD*;7-G:60@(D]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E(@IM<V=S='(@(L#?N/BUR"#`S+BG+B(*"B,Z(&%D;6EN+W1E;7!L871E
M<RYP:'`Z,3$W"B,L('!H<"UF;W)M870*;7-G:60@(D]R:6=I;F%L('1E;7!L
M871E<R!I;B`E<SHB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.2!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,3$W"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.30*;7-G:60@
M(D]T:&5R(@IM<V=S='(@(K'BQ;@B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z.38@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$P-@HC.B!C;VYF:6<O<')E
M9G,N<&AP+F1I<W0Z,3$S(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C(*(SH@
M8V]N9FEG+W!R969S+G!H<"YD:7-T.C$S,2!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z,30Q"FUS9VED(")/=&AE<B!);F9O<FUA=&EO;B(*;7-G<W1R("*QXL6X
M(,&DNK@B"@HC.B!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.C,Q"B,L(&9U
M>GIY"FUS9VED(")/=VYE<B!097)M:7-S:6]N<R(*;7-G<W1R("*[Y[_KP-H@
ML<?'T2(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H<#HW.0HC+"!F
M=7IZ>0IM<V=I9"`B4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B
M;&4N(@IM<V=S='(@(KOHP:8@O<?&T"(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]G96YE<FEC7W-M='`N<&AP.C$P-0IM<V=I9"`B4$5!4CHZ36%I;"!B
M86-K96YD(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P
M9W`N<&AP.C$R-S,*(RP@9G5Z>GD*;7-G:60@(E!'4"!$:6=I=&%L(%-I9VYA
M='5R92(*;7-G<W1R("*\K;CM.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]P9W`N<&AP.C$S,3D*;7-G:60@(E!'4"!%;F-R>7!T960@1&%T82(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S<Q
M"FUS9VED(")01U`@4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,S4S"FUS9VED(")01U`@4VEG;F5D
M+T5N8W)Y<'1E9"!$871A(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W!H<'-H96QL
M+G!H<#HV.`HC+"!F=7IZ>0IM<V=I9"`B4$A0($-O9&4B"FUS9W-T<B`B2&]R
M9&4B"@HC.B!A9&UI;B]P:'!S:&5L;"YP:'`Z,C`*;7-G:60@(E!(4"!3:&5L
M;"(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS-PHC+"!F=7IZ>0IM<V=I9"`B4$T@3&EG:'0@4F%I;B(*;7-G
M<W1R("*WSK'7P,XB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I
M;F=S+G!H<#HS.`IM<V=I9"`B4$T@4VAO=V5R<R(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS.0IM<V=I9"`B
M4$T@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HT,`IM<V=I9"`B4$T@4VYO=R!3:&]W97)S(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP
M.C0Q"FUS9VED(")032!3=6XB"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#(*;7-G:60@(E!-(%0M4W1O<FUS
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HR-S0*;7-G
M:60@(E!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG(@IM<V=S='(@(B(*"B,Z
M(&QI8B]A<&DN<&AP.C$T.0IM<V=I9"`B4%](4"!3:&5L;"(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C0V"FUS9VED(")0861D:6YG(@IM<V=S='(@(L;DM?DB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$X-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C$W,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z.3D*(RP@9G5Z>GD*;7-G:60@(E!A:VES=&%N(@IM<V=S='(@(KK9P,RQ
MXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DT(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<S"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,#$*(RP@9G5Z>GD*;7-G:60@(E!A;&%U(@IM<V=S
M='(@(L"EN-[`SR(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3DR
M(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3<T"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#$*;7-G:60@(E!A;&5S=&EN:6%N
M(%1E<G)I=&]R>2P@3V-C=7!I960B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HQ.#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HQ-S4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDX
M"B,L(&9U>GIY"FUS9VED(")086YA;6$B"FUS9W-T<B`BP,RXIR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,3@U(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,3<V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HY.0IM<V=I9"`B4&%P=6$@3F5W($=U:6YE82(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$Y-2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$W-PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`R"FUS9VED(")087)A9W5A>2(*;7-G<W1R("(B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HS-@HC+"!F=7IZ
M>0IM<V=I9"`B4&%R=&QY($-L;W5D>2(*;7-G<W1R("*ZN;OG(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X,`HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ
M.3D*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3$@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`Q.`HC.B!T96UP;&%T97,O;&]G
M:6XO;&]G:6XN:6YC.C<W('1E;7!L871E<R]A9&UI;B]U<V5R+W5P9&%T92YI
M;F,Z-#,*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0R,PIM<V=I9"`B
M4&%S<W=O<F0B"FUS9W-T<B`BOL_(HR(*"B,Z('-E<G9I8V5S+V-H86YG97!A
M<W-W;W)D+G!H<#HX,@IM<V=I9"`B4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S
M9G5L;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S
M;6EM92YP:'`Z,3,R,@HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0@:6YC;W)R
M96-T(@IM<V=S='(@(K[/R*,B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W)A
M9&EU<RYP:'`Z,34R"B,L(&9U>GIY"FUS9VED(")087-S=V]R9"!R97%U:7)E
M9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+B(*;7-G<W1R(")344P@P,[!
M]2"\L\&DP:2ZN+"A(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C(P-3,*(RP@9G5Z>GD*;7-G:60@(E!A<W-W;W)D('=I=&@@8V]N
M9FER;6%T:6]N(@IM<V=S='(@(K'BQ;@@P:2ZN"(*"B,Z('1E;7!L871E<R]R
M<&-S=6TO<G!C<W5M+FEN8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z
M(@IM<V=S='(@(K[/R*,B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B:6QE+FEN
M8SHQ,0HC+"!F=7IZ>0IM<V=I9"`B4&%S<W=O<F0Z("(*;7-G<W1R("*^S\BC
M(@H*(SH@861M:6XO=7-E<BYP:'`Z,34P(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(P,S0*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHQ
M-0IM<V=I9"`B4&%S<W=O<F1S(&UU<W0@;6%T8V@N(@IM<V=S='(@(K[/R*.P
MH2#`S\2AQ\_!]B"^RKW`M,^TV2XB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M,3$Y('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N
M9RYJ<SHR,@IM<V=I9"`B4&%S=&4B"FUS9W-T<B`BNMG`S+'B(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-PIM<V=I9"`B
M4&%S=&4@9G)O;2!C;&EP8F]A<F0B"FUS9W-T<B`BQ:RXL[JXM>6_H;RM(+K9
MP,RQXB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z-3$*;7-G:60@(E!A=&@B"FUS9W-T<B`BL.:WSB(*"B,Z('1E;7!L871E
M<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(@=&5M<&QA=&5S+V%D;6EN+W5S
M97(O<F5M;W9E<75E=65D+FEN8SHW"FUS9VED(")096YD:6YG(%-I9VYU<',Z
M(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-`HC+"!F
M=7IZ>0IM<V=I9"`B4&5O<&QE(@IM<V=S='(@(K^JQ](B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$P-PIM<V=I9"`B4&5R
M8V5N="(*;7-G<W1R("+&V[R^QJXB"@HC.B!T96UP;&%T97,O;6%I;G1E;F%N
M8V4O;6%I;G1E;F%N8V4N:'1M;#HT.0IM<V=I9"`B4&5R9F]R;2!-86EN=&5N
M86YC92!/<&5R871I;VYS(@IM<V=S='(@(L"OP?8@L/RXKB#`V[[W(+W'Q^`B
M"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z-#`V"B,L(&9U>GIY"FUS9VED
M(")097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_(@IM
M<V=S='(@(L"OP?8@L/RXKB#`V[[W(+W'Q^`B"@HC.B!F<F%M97=O<FLO4&5R
M;7,O4&5R;7,O54DN<&AP.C$U-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO
M;B(*;7-G<W1R("*PL\#.(+C>P,\B"@HC.B!A9&UI;B]P97)M<R]D96QE=&4N
M<&AP.C4R"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")097)M:7-S:6]N
M(%PB)7-<(B!N;W0@9&5L971E9"XB"FUS9W-T<B`BO<2ZL,#:(%PB)7-<(B"P
MH2"[Z,&FM<>^^KW`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N
M<&AP.C4X-@HC+"!F=7IZ>0IM<V=I9"`B4&5R;6ES<VEO;B!$96YI960B"FUS
M9W-T<B`BL+/`SB"XWL#/(@H*(SH@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)
M+G!H<#HQ-C$@9G)A;65W;W)K+U!E<FUS+U!E<FUS+U5)+G!H<#HQ-C0*(RP@
M9G5Z>GD*;7-G:60@(E!E<FUI<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC.B!A
M9&UI;B]P97)M<R]E9&ET+G!H<#HQ,#D@861M:6XO<&5R;7,O861D8VAI;&0N
M<&AP.C8P"B,Z(&%D;6EN+W!E<FUS+VEN9&5X+G!H<#HR,B!A9&UI;B]P97)M
M<R]D96QE=&4N<&AP.C4X"B,L(&9U>GIY"FUS9VED(")097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;B(*;7-G<W1R("*P_+BN(@H*(SH@8V]N9FEG+W!R969S
M+G!H<"YD:7-T.C8U"FUS9VED(")097)S;VYA;"!);F9O<FUA=&EO;B(*;7-G
M<W1R("*PL\#.(,&DNK@B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP
M.C$X,R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$W.`HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3@*;7-G:60@(E!E<G4B"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4U"B,L(&9U>GIY
M"FUS9VED(")0971S(@IM<V=S='(@(L?(O+\B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C$X-B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C$W.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.3D*;7-G
M:60@(E!H:6QI<'!I;F5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ.38*;7-G:60@(E!H;VYE(@IM<V=S
M='(@(L#\R*VY^,BC(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0W
M.`IM<V=I9"`B4&AO=&]S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,3DP(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G
M:60@(E!I=&-A:7)N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`X"FUS9VED(")0:7AE;',B"FUS9W-T
M<B`BQ\B\OR(*"B,Z(&QI8B]";&]C:R]F;W)T=6YE+G!H<#HU-@IM<V=I9"`B
M4&QA=&ET=61E<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C0W"FUS9VED(")0;&5A<V4@8VQI
M8VL@:6YT;R!S;VUE(&-E;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C0Y"FUS9VED(")0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L
M96UE;G0Z(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU-@IM<V=I9"`B4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+B(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3<Q"B,L(&9U
M>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+B(*
M;7-G<W1R("*[];?.O^X@P,RXI\"[(,#4M\+'S[R\O^0Z(@H*(SH@=&5M<&QA
M=&5S+W!R969S+V-A=&5G;W)Y;6%N86=E;65N="YI;F,Z,3(*(RP@9G5Z>GD*
M;7-G:60@(E!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O
M<GDZ(@IM<V=S='(@(EQ<;KOUM\Z_[B"XWL#/Q]3`QR#`S+BGP+L@P-2WPL?/
MO+R_Y#I<7&XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,S`Q"B,L
M(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S
M+B(*;7-G<W1R("*_P[G9N*4@L,N[]B"Y_,'6N*8@P-2WPL?/O+R_Y"XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-C8P"FUS9VED(")0;&5A<V4@
M96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@
M:6X@=&AE(&UO;G1H+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR-#4Q"B,L(&9U>GIY"FUS9VED(")0;&5A<V4@96YT97(@82!V
M86QI9"!T:6UE+B(*;7-G<W1R("*_P[G9N*4@L,N[]B"Y_,'6N*8@P-2WPL?/
MO+R_Y"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHW"FUS
M9VED(")0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M(@IM<V=S='(@(KFNP::_H2"TZ\?1(+_DON#`NR#`U+?"Q]@@P=:\O+_D+B(*
M"B,Z('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z,C(@=&5M<&QA=&5S+VQO
M9VEN+VQO9VEN+FEN8SHR-@IM<V=I9"`B4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0B"FUS9W-T<B`BN^>_Z\#:P,RXI[#Z(+[/
MR*.XIB#`U+?"Q\^\O+_D(@H*(SH@<V5R=FEC97,O;6%I;G1E;F%N8V4N<&AP
M.C4X"FUS9VED("(B"B)0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@(@HB
M<WES=&5M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O
M0V%T96=O<GE-86YA9V5R+G!H<#HW,`HC+"!F=7IZ>0IM<V=I9"`B4&QE87-E
M('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.B(*;7-G<W1R("*[];?.O^X@
MP,RXI\"[(,#4M\+'S[R\O^0Z(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.#@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#$*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.CDY"B,L(&9U>GIY"FUS
M9VED(")0;VQA;F0B"FUS9W-T<B`BR+B[YR(*"B,Z(&QI8B]";&]C:R]F;W)T
M=6YE+G!H<#HU-PIM<V=I9"`B4&]L:71I8W,B"FUS9W-T<B`B(@H*(SH@8V]N
M9FEG+W)E9VES=')Y+G!H<"YD:7-T.C0X-PHC+"!F=7IZ>0IM<V=I9"`B4&]L
M;',B"FUS9W-T<B`BOZTZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HQ.3,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#(*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,0IM<V=I9"`B4&]R='5G
M86PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?;&%N9RYJ<SHQ,C0*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?86YS96QI;6%G95]L86YG+FIS.C(W"FUS9VED(")0;W-I=&EO;FEN9R!O
M9B!T:&ES(&EM86=E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R
M:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3$Q"B,L(&9U>GIY"FUS9VED(")0;W-I
M=&EO;FEN9R!O9B!T:&ES('1A8FQE(@IM<V=S='(@(L>EP,<@L\JZ\2(*"B,Z
M(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.CDQ"FUS9VED
M(")0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HR-C8@;&EB+T)L
M;V-K+VUE=&%R+G!H<#HR-S$*(RP@<&AP+69O<FUA=`IM<V=I9"`B4')E8VEP
M:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B"FUS9W-T<B`B(@H*(SH@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(Y.`IM<V=I9"`B4')E8VEP
M:71A=&EO;CQB<B`O/F-H86YC92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M4')E9G,O4')E9G,O;&1A<"YP:'`Z.3@*;7-G:60@(E!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U!R969S+U!R969S+W-E<W-I;VXN<&AP.C,S"FUS9VED
M(")0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z
M,C(U"FUS9VED(")0<F5S<W5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M;65T87(N<&AP.C(U.0IM<V=I9"`B4')E<W-U<F4@870@<V5A(&QE=F5L.B`B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(S
M-0HC+"!F=7IZ>0IM<V=I9"`B4')E<W-U<F4Z("(*;7-G<W1R("*^S\BC(@H*
M(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C(P-0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,`HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C,*;7-G:60@(E!R979I97<B"FUS9W-T<B`BN<RXKKJXL>(B"@HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$R,0HC
M.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]A;G-E;&EM86=E7VQA
M;F<N:G,Z,C0*;7-G:60@(E!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=R(*;7-G<W1R("*[]2##HK^A(+G,N*ZZN+'B(@H*(SH@9G)A;65W;W)K
M+U!R969S+U!R969S+U5)+G!H<#HS-C(@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HS-C8*(RP@9G5Z>GD*;7-G:60@(E!R979I;W5S(&]P=&EO;G,B
M"FUS9W-T<B`BP,S`_""XWKW#P?8B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]L86YG+FIS.C0Q"FUS9VED(")0<FEN="!D;V-U;65N="(*
M;7-G<W1R("*YKKRM(,#.O.(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O
M<&=P+G!H<#HT,C,*;7-G:60@(E!R:79A=&4@2V5Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-CD*(RP@9G5Z>GD*
M;7-G:60@(E!R;V)L96TB"FUS9W-T<B`BN:[!IB"YW[O]/R(*"B,Z('-E<G9I
M8V5S+W!R;V)L96TN<&AP.C$R-@IM<V=I9"`B4')O8FQE;2!$97-C<FEP=&EO
M;B(*;7-G<W1R("*YKL&F(+RSN.TB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z,S8Y"FUS9VED(")0<F]J96-T<R(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HR,3$Q(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q.#@*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S(X-0HC+"!F
M=7IZ>0IM<V=I9"`B4')O;7!T('1E>'0B"FUS9W-T<B`BL;/!I+7((+FNP-J_
MK2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0R,PIM<V=I
M9"`B4'5B;&EC($ME>2(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O
M0W)Y<'0O<VUI;64N<&AP.C8T-0IM<V=I9"`B4'5B;&EC($ME>2!!;&=O<FET
M:&TB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HV-#0*;7-G:60@(E!U8FQI8R!+97D@26YF;R(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HR-#$*;7-G:60@(E!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DQ(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@S"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*;7-G:60@(E!U97)T;R!2
M:6-O(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,3DV(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@T"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#(*(RP@9G5Z>GD*;7-G:60@
M(E%A=&%R(@IM<V=S='(@(L#/P-HB"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z
M-C,*;7-G:60@(E%U97)Y(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]A8V-O
M=6YT+G!H<#HW,`IM<V=I9"`B475O=&$B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HV-C,*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B4E-!(%!U8FQI8R!+97D@*"5D(&)I="DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-`HC+"!F=7IZ>0IM<V=I9"`B
M4F%D:6\@<V5L96-T:6]N(@IM<V=S='(@(KW#L*,@O+/!I"(*"B,Z(&QI8B]"
M;&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C0S"B,L(&9U>GIY"FUS
M9VED(")286EN(@IM<V=S='(@(K"AP.7`VKBN(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-#0*;7-G:60@(E)A:6X@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-#4*;7-G:60@(E)A:6X@3&%T92(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HT-@IM<V=I9"`B4F%I
M;B!3:&]W97(B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VU?<W1R:6YG<RYP:'`Z-#<*;7-G:60@(E)A:6X@86YD(%-N;W<B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-#@*;7-G:60@(E)A:6X@=&\@4VYO=R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z,PHC+"!F=7IZ>0IM<V=I9"`B4F%N9&]M($9O<G1U
M;F4B"FUS9W-T<B`BPOS!MB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE
M=V5R+W)A<BYP:'`Z-C@@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O>FEP
M+G!H<#HW-@HC+"!F=7IZ>0IM<V=I9"`B4F%T:6\B"FUS9W-T<B`BQ+B\QR(*
M"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(T('1E;7!L871E<R]S
M:&%R97,O961I="YI;F,Z,S0*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET+FEN
M8SHV."!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDQ"B,Z('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,3$T('1E;7!L871E<R]S:&%R97,O961I="YI
M;F,Z,3,W"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3@P"B,L(&9U
M>GIY"FUS9VED(")296%D(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@
M9G)A;65W;W)K+TE-05`O24U!4"]!0TPO<F9C,C`X-BYP:'`Z.#<*(RP@9G5Z
M>GD*;7-G:60@(E)E860@;65S<V%G97,B"FUS9W-T<B`BN_4@N-[`SR(*"B,Z
M('1E;7!L871E<R]A9&UI;B]U<V5R+W)E;6]V92YI;F,Z.`HC+"!P:'`M9F]R
M;6%T"FUS9VED(")296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C
M86YN;W0@8F4@=6YD;VYE+B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O861M
M:6XO=7-E<B]C;&5A<BYI;F,Z.`HC+"!P:'`M9F]R;6%T"FUS9VED(")296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92XB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS-`IM<V=I9"`B4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BN+;!]KBW(+CMM\D@N=VZN2(*
M"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S97)V:6-E<R]P
M;W)T86PO<WEN8VUL+G!H<#HR,#@*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z,C0V"FUS9VED(")2969R97-H(@IM<V=S='(@(B(*"B,Z(&-O;F9I
M9R]P<F5F<RYP:'`N9&ES=#HS.3$*;7-G:60@(E)E9G)E<V@@1'EN86UI8R!-
M96YU($5L96UE;G1S.B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,S0Q"B,L(&9U>GIY"FUS9VED(")2969R97-H(%!O<G1A;"!6:65W
M.B(*;7-G<W1R("*XWL#/Q]0@N_6WSB#`T+'B.B(*"B,Z(&9R86UE=V]R:R]&
M;W)M+T9O<FTN<&AP.C@Y-"!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ,C$S
M"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$R,S4*(RP@9G5Z>GD*;7-G
M:60@(E)E9V5X(@IM<V=S='(@(L#GO+/!I"(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C,R-#D*;7-G:60@(E)E;&%T:6]N<VAI<"!"<F]W<V5R(@IM
M<V=S='(@(B(*"B,Z('-E<G9I8V5S+W!O<G1A;"]S>6YC;6PN<&AP.C$T-R!S
M97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR,#@*(RP@9G5Z>GD*;7-G:60@
M(E)E;&]A9"(*;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,S(V"FUS9VED(")296UA<FMS(@IM<V=S='(@(B(*"B,Z
M(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,30*(RP@9G5Z>GD*;7-G:60@(E)E
M;6]T92!397)V97)S(@IM<V=S='(@(KRQQ<.UR""XWL#/(+OHP:8B"@HC.B!T
M96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#0*;7-G:60@(E)E;6]T92!5
M4DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O861M:6XO9W)O=7!S+V5D:70N:6YC.C(R('1E;7!L
M871E<R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC.C(X"B,Z('1E;7!L871E<R]A
M9&UI;B]U<V5R+W)E;6]V97%U975E9"YI;F,Z,3,*(RP@9G5Z>GD*;7-G:60@
M(E)E;6]V92(*;7-G<W1R("+&Y+[N*'!A:7(I(+OHP:8B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z,3$*(RP@9G5Z>GD*;7-G:60@(E)E;6]V
M92!";&]C:R(*;7-G<W1R("*\L<7#M<@@N-[`SR"[Z,&F(@H*(SH@9G)A;65W
M;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C4U-PHC+"!F=7IZ>0IM
M<V=I9"`B4F5M;W9E(&-O;'5M;B(*;7-G<W1R("*^QK>AM\X@P,RUOR(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z-#`*(RP@
M9G5Z>GD*;7-G:60@(E)E;6]V92!F;W)M871T:6YG(@IM<V=S='(@(K[&MZ&W
MSB#`S+6_(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V;6%P+FEN8SHQ,C@*;7-G
M:60@(E)E;6]V92!P86ER(@IM<V=S='(@(L;DONXH<&%I<BD@N^C!IB(*"B,Z
M(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HR,#(*;7-G:60@(E)E;6]V92!S879E
M9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(*
M;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C
M;VYT97AT7VQA;F<N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(E)E;6]V92!T:&4B
M"FUS9W-T<B`BO+'%P[7((+C>P,\@N^C!IB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHU,`IM<V=I9"`B4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N="(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C$Q"B,L(&9U>GIY
M"FUS9VED(")296UO=F4@=7-E<B(*;7-G<W1R("+&Y+[N*'!A:7(I(+OHP:8B
M"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]R96UO=F4N:6YC.C4*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E)E;6]V92!U<V5R.B`E<R(*;7-G<W1R
M("+&Y+[N*'!A:7(I(+OHP:8B"@HC.B!F<F%M97=O<FLO4E!#+U)00R]X;6QR
M<&,N<&AP.C$S.`IM<V=I9"`B4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E
M9"X@4F5T=7)N960@97)R;W)C;V1E.B`B"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+W=E871H97)D;W1C;VTN<&AP.C$U-PHC+"!F=7IZ>0IM<V=I9"`B4F5Q
M=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(*;7-G<W1R("*\
MK;CMP+L@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92YP:'`Z,3<T(&9R86UE=V]R:R](;W)D92](;W)D92YP:'`Z-3$R
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@
M;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")6
M1E,@O+/!I"#!I+JXOZ&\K2`G<&]R="?`S""^^+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO5D93+U9&4R]S<6PN<&AP.C8W-2!F<F%M97=O<FLO5D93+U9&4R]F
M='`N<&AP.C@S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z
M-S(S"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")297%U:7)E9"!<(B5S
M7"(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB"FUS9W-T
M<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0GP,P@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+U5T:6PO571I;"YP:'`Z-S@Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")297%U:7)E9"!<(B5S7"(@;F]T('-P96-I9FEE9"!I;B!C
M;VYF:6=U<F%T:6]N+B(*;7-G<W1R(")61E,@O+/!I"#!I+JXOZ&\K2`G<&]R
M="?`S""^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E
M<F5R+G!H<#HS,S4*;7-G:60@(E)E<75I<F5D($9I96QD(@IM<V=S='(@(B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C,Q(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C,S.0HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+U)E;F1E<F5R+G!H<#HS,C`@
M=&5M<&QA=&5S+W)P8W-U;2]R<&-S=6TN:6YC.C$P,`HC.B!T96UP;&%T97,O
M861M:6XO=7-E<B]U<&1A=&4N:6YC.C<W"FUS9VED(")297-E="(*;7-G<W1R
M("+`U+?"(,/KO-(B"@HC.B!S97)V:6-E<R]R97-E='!A<W-W;W)D+G!H<#HT
M-@HC+"!F=7IZ>0IM<V=I9"`B4F5S970@4&%S<W=O<F0B"FUS9W-T<B`BOL_(
MHR(*"B,Z('-E<G9I8V5S+W)E<V5T<&%S<W=O<F0N<&AP.C(W"B,L(&9U>GIY
M"FUS9VED(")297-E="!9;W5R(%!A<W-W;W)D(@IM<V=S='(@(K[/R*,@R*[`
MSB(*"B,Z(&%D;6EN+W-Q;'-H96QL+G!H<#HQ,S`*(RP@9G5Z>GD*;7-G:60@
M(E)E<W1O<F4@3&%S="!1=65R>2(*;7-G<W1R("*XML'VN+<@QN3`S,'V(@H*
M(SH@861M:6XO<&AP<VAE;&PN<&AP.C<Q(&%D;6EN+V-M9'-H96QL+G!H<#HR
M."!A9&UI;B]S<6QS:&5L;"YP:'`Z-C8*(RP@9G5Z>GD*;7-G:60@(E)E<W5L
M=',B"FUS9W-T<B`BL,N[]B"PX;#Z(@H*(SH@=&5M<&QA=&5S+W)P8W-U;2]R
M<&-S=6TN:6YC.C$P,2!T96UP;&%T97,O<')E9G,O96YD+FEN8SHW"FUS9VED
M(")2971U<FX@=&\@3W!T:6]N<R(*;7-G<W1R("*_R;S'P+BWSB"UN;[&L*&Q
MXB(*"B,Z('-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<#HS.`HC+"!F=7IZ
M>0IM<V=I9"`B4F5T>7!E(&YE=R!P87-S=V]R9"(*;7-G<W1R("*^S\BC(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3<@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.#4*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$P,@IM<V=I9"`B4F5U;FEO;B(*;7-G<W1R("(B"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C0T(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-#@*(RP@9G5Z>GD*;7-G:60@(E)E=F5R="!#;VYF:6=U<F%T:6]N(@IM
M<V=S='(@(KC>P,\@O*VY]B#!I+JXN^?'UR(*"B,Z(&-O;F9I9R]P<F5F<RYP
M:'`N9&ES=#HQ,S(*(RP@9G5Z>GD*;7-G:60@(E)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<R(*;7-G<W1R("*_R;S'P+BWSB"UN;[&L*&QXB(*"B,Z(&QI8B]"
M;&]C:R]F;W)T=6YE+G!H<#HU.`HC+"!F=7IZ>0IM<V=I9"`B4FED9&QE<R(*
M;7-G<W1R("*PH;_NM:4B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL
M87)E85]T86)L95]L86YG+FIS.C0X"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z-S`*;7-G:60@(E)I9VAT(@IM<V=S='(@(K_`
MN*7"RB(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q,C$*;7-G:60@
M(E)I9VAT(&AE861E<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HS,3$W"B,L(&9U>GIY"FUS9VED(")2:6=H="!V86QU97,B"FUS
M9W-T<B`BO[DZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?
M8V]N=&5X=%]L86YG+FIS.C(X"FUS9VED(")2;U]W(%!R;W!E<G1I97,N+BXB
M"FUS9W-T<B`B7W?'X""\T[RZ+BXN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O=F-A<F0N<&AP.C(S-`IM<V=I9"`B4F]L92(*;7-G<W1R("*_
MJL?2(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HQ.3@@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#8*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$P,@IM<V=I9"`B4F]M86YI82(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,C(U
M"FUS9VED(")2;W1A=&4@,3@P(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]5
M22]522]687)296YD97)E<B]H=&UL+G!H<#HR,C(*(RP@9G5Z>GD*;7-G:60@
M(E)O=&%T92!,969T(@IM<V=S='(@(L"GM\X@P,RUOR(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR,C@*;7-G:60@(E)O=&%T
M92!2:6=H="(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C0Y"FUS9VED(")2;W<@4')O<&5R=&EE
M<R(*;7-G<W1R("+'X""\T[RZ(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,`IM<V=I9"`B4F]W('!R;W!E<G1I
M97,B"FUS9W-T<B`BQ^`@O-.\NB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3`Q"FUS9VED(")2;W=S.B(*;7-G<W1R("+'
MX#HB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L
M86YG+FIS.C4S"B,L(&9U>GIY"FUS9VED(")2=6QE<R(*;7-G<W1R("*_JL?2
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N
M9RYJ<SHU,`IM<V=I9"`B4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<R(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O:F%V
M87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4Q"FUS9VED(")2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C4R"FUS9VED(")2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@
M;VYL>2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S<6QS:&5L;"YP:'`Z,3(P"FUS
M9VED(")2=6XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD
M+G!H<#HQ.3D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HQ.#<*
M(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P,PIM<V=I9"`B4G5S
M<VEA;B!&961E<F%T:6]N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C`P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,3@X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#,*(RP@
M9G5Z>GD*;7-G:60@(E)W86YD82(*;7-G<W1R("*TWK?"(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HR.#4*;7-G:60@(E,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C,R,PHC+"!F=7IZ>0IM<V=I9"`B
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E(@IM<V=S='(@(KC>O</!]B#`_+S;
M(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"]S87-L+G!H<#HX,0HC+"!F=7IZ
M>0IM<V=I9"`B4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE
M+B(*;7-G<W1R("*[Z,&F(+W'QM`B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP
M+F1I<W0Z-3`T"B,L(&9U>GIY"FUS9VED(")335,@365S<V%G:6YG(@IM<V=S
M='(@(KC>O</!]B"ZN+'B(@H*(SH@861M:6XO<W%L<VAE;&PN<&AP.C(Q"FUS
M9VED(")344P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S(X,PIM<V=I9"`B4U%,('-T871E;65N="!F;W(@=F%L=64@
M;&]O:W5P<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I
M<W0Z-#,Q"FUS9VED(")34T@B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO
M=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(O;6]B:6QE+G!H<#HS
M-0IM<V=I9"`B4U5#0T534R(*;7-G<W1R("(B"@HC.B!L:6(O87!I+G!H<#HQ
M-3,*;7-G:60@(E-?44P@4VAE;&PB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O;W!E;E]C86QE;F1A<BYJ<SHV,0HC+"!F=7IZ>0IM<V=I
M9"`B4V$B"FUS9W-T<B`BP/K`Y2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L
M9"YP:'`Z,C`W(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,3@Y
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*;7-G:60@(E-A
M:6YT($AE;&5N82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C$S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y
M,`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#0*;7-G:60@(E-A
M:6YT($MI='1S(&%N9"!.979I<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]T;&0N<&AP.C$S.2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I
M97,N<&AP.C$Y,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z.#<*
M;7-G:60@(E-A:6YT($QU8VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,3@Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DR"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#`*
M;7-G:60@(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-#0@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HQ.3,*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q-0IM<V=I9"`B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O
M:'1M;&%R96%?;&%N9RYJ<SHY,@IM<V=I9"`B4V%M92!F<F%M92`H7W-E;&8I
M(@IM<V=S='(@(K"PP+H@Q\&WN<#3*%]S96QF*2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C4Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,3DT"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3<*
M;7-G:60@(E-A;6]A(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$R(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,3DU"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#8*(RP@9G5Z
M>GD*;7-G:60@(E-A;B!-87)I;F\B"FUS9W-T<B`BL*'`Y<#:N*XB"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C$Y-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3`W"FUS9VED(")386\@5&]M92!A;F0@4')I;F-I<&4B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q.0IM<V=I
M9"`B4V%T96QL:71E(%!R;W9I9&5R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C`Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,3DW"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#,*;7-G:60@(E-A=61I($%R86)I82(*;7-G<W1R("(B"@HC.B!T96UP;&%T
M97,O<&]R=&%L+VQA>6]U="YI;F,Z.3@*;7-G:60@(E-A=F4B"FUS9W-T<B`B
MP/K`Y2(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I="YI;F,Z-#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@7"(E<UPB(@IM<V=S
M='(@(K39N*7`S+BGP+BWSB#`^L#E(@H*(SH@=&5M<&QA=&5S+W-H87)E<R]E
M9&ET+FEN8SHR,38*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F4@
M)7,B"FUS9W-T<B`BM-FXI<#,N*?`N+?.(,#ZP.4B"@HC.B!T96UP;&%T97,O
M<')E9G,O96YD+FEN8SHU"FUS9VED(")3879E($]P=&EO;G,B"FUS9W-T<B`B
MO+'%P[OGQ]<@P/K`Y2(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HQ-C<*
M;7-G:60@(B(*(E-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!0
M2%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y("(*(F1I<F5C
M=&]R>2XB"FUS9W-T<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z
M-S$*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E-A=F5D("5S(&-O;F9I
M9W5R871I;VXN(@IM<V=S='(@(E9&4R"\L\&D(,&DNKB_H;RM("=P;W)T)\#,
M(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W-E='5P+W-C<FEP=',N<&AP.CDS"B,L
M('!H<"UF;W)M870*;7-G:60@(E-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T
M('1O.B!<(B5S7"(N(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C0Y"FUS9VED(")38V%T=&5R960@5"U3=&]R
M;7,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C4Y"FUS
M9VED(")38VEE;F-E(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]U
M<V5R+VQI<W0N:6YC.C$T('1E;7!L871E<R]A9&UI;B]U<V5R+VQI<W0N:6YC
M.C$V"FUS9VED(")396%R8V@B"FUS9W-T<B`BL,N[]B(*"B,Z(&-O;F9I9R]R
M96=I<W1R>2YP:'`N9&ES=#HS,C`*(RP@9G5Z>GD*;7-G:60@(E-E87)C:"!%
M;F=I;F5S(@IM<V=S='(@(K#+N_8@L.&P^B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(Y-S,*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!&:6QE<R(*
M;7-G<W1R("*X\+7.(+RQQ<,B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#@T"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!D
M871E(@IM<V=S='(@(KW$NK#`VB"\L<7#(@H*(SH@=&5M<&QA=&5S+W-H87)E
M<R]E9&ET+FEN8SHQ.3@*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A(&=R;W5P
M('1O(&%D9"(*;7-G<W1R("*YKL#:OZT@O+'%PSHB"@HC.B!T96UP;&%T97,O
M<VAA<F5S+V5D:70N:6YC.C0S"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!N
M97<@;W=N97(B"FUS9W-T<B`BO+'%PR##Z[S2(@H*(SH@=&5M<&QA=&5S+W)P
M8W-U;2]R<&-S=6TN:6YC.C8P"B,L(&9U>GIY"FUS9VED(")396QE8W0@82!S
M97)V97(B"FUS9W-T<B`BN:[`VK^M(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+W-H
M87)E<R]E9&ET+FEN8SHQ-38*(RP@9G5Z>GD*;7-G:60@(E-E;&5C="!A('5S
M97(@=&\@861D(@IM<V=S='(@(KFNP-J_K2"\L<7#.B(*"B,Z(&9R86UE=V]R
M:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HV-S<*(RP@9G5Z>GD*;7-G
M:60@(E-E;&5C="!A;&PB"FUS9W-T<B`BN/"USB"\L<7#(@H*(SH@9G)A;65W
M;W)K+T9O<FTO1F]R;2YP:'`Z,C8V,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T
M(&%L;"!D871E(&-O;7!O;F5N=',N(@IM<V=S='(@(K.OP-H@Q_R]Q""\L<7#
M(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C@W
M,PHC+"!F=7IZ>0IM<V=I9"`B4V5L96-T(&%N(&]B:F5C="(*;7-G<W1R("*\
ML<7#(,/KO-(B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z-C<X"B,L(&9U>GIY"FUS9VED(")396QE8W0@;F]N92(*;7-G<W1R
M("*\L<7#(,/KO-(B"@HC.B!S97)V:6-E<R]K97EB;V%R9"YP:'`Z,S<*;7-G
M:60@(B(*(E-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD("(*(G!A<W1E
M('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+B(*;7-G<W1R("*^QK>A(+OSP-J_
MH;RM(,?*O^3'T2"YKL#:N*8@O+'%P\?/L.T@NKF[Y\?/OZD@NMF_J;/6P+B\
MO+_D+B(*"B,Z('1E;7!L871E<R]D871A+V1A=&4N:6YC.C,T"FUS9VED(")3
M96QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.B(*;7-G<W1R("*SK\#:(+&XNM#'
MI;W#(+RQQ<,Z(@H*(SH@=&5M<&QA=&5S+V1A=&$O9&%T92YI;F,Z-#0*;7-G
M:60@(E-E;&5C="!T:&4@9&%T92!F;W)M870Z(@IM<V=S='(@(K.OP-H@Q_R]
MQ""\L<7#(@H*(SH@=&5M<&QA=&5S+W!R969S+VED96YT:71Y<V5L96-T+FEN
M8SHY,`HC+"!F=7IZ>0IM<V=I9"`B4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z(@IM<V=S='(@(L#3QO?&KL?2(,"GQ*$@O+'%PSHB
M"@HC.B!T96UP;&%T97,O9&%T82]T:6UE+FEN8SHQ-@HC+"!F=7IZ>0IM<V=I
M9"`B4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CHB"FUS9W-T<B`BLZ_`VB"Q
MN+K0QZ6]PR"\L<7#.B(*"B,Z('1E;7!L871E<R]D871A+W1I;64N:6YC.C(U
M"FUS9VED(")396QE8W0@=&AE('1I;64@9F]R;6%T.B(*;7-G<W1R("*]P["C
M(,?\O<0@O+'%PR(*"B,Z('1E;7!L871E<R]D871A+V-S=FUA<"YI;F,Z-3<*
M;7-G:60@(E-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+B(*;7-G<W1R("*U
MSK"SP,<@P,_$H<?/M,(@Q]>X\2"\L<7#(@H*(SH@8V]N9FEG+W!R969S+G!H
M<"YD:7-T.C,P-@IM<V=I9"`B4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+B(*
M;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,C0X"FUS9VED
M(")396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z(@IM<V=S='(@(L#:
MP=:[Y[_KQ\^TPB"^\+[NN*8@O+'%P\?/O+R_Y"XB"@HC.B!T96UP;&%T97,O
M<')O8FQE;2]P<F]B;&5M+FEN8SHU.`IM<V=I9"`B4V5N9"!0<F]B;&5M(%)E
M<&]R="(*;7-G<W1R("*YKL&FN=^[_2"ZN+#MO*T@P/R\V\?/L>(B"@HC.B!F
M<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3`S.0HC+"!F
M=7IZ>0IM<V=I9"`B4V5N9"!335,B"FUS9W-T<B`BN-Z]P\'V(,#\O-LB"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q,R!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C$Y.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`V"FUS9VED(")396YE9V%L(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]M971A<BYP:'`Z,S$V"B,L(&9U>GIY"FUS9VED(")396YS;W(Z
M("(*;7-G<W1R("(@P::X\3H@(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E
M;F1E<F5R+VAT;6PN<&AP.C0P.0HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N
M9&5R97(O:'1M;"YP:'`Z-#0W"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P
M96Y?8V%L96YD87(N:G,Z-S,*;7-G:60@(E-E<'1E;6)E<B(*;7-G<W1R("(Y
MO_DB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C$Y.0IM
M<V=I9"`B4V5R8FEA(&%N9"!-;VYT96YE9W)O(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`Q"B,L(&9U>GIY"FUS
M9VED(")397)I86P@3G5M8F5R(@IM<V=S='(@(KS]P-HB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,38Q"B,L(&9U>GIY"FUS9VED(")397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(*;7-G<W1R("+`S+_K
ML*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5S<VEO
M;G,N<&AP.C(W"B,L(&9U>GIY"FUS9VED(")397-S:6]N($%D;6EN(@IM<V=S
M='(@(K#\N*XB"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L
M;%]H='1P+G!H<#HR.3(*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VX@240@97AP
M:7)E9"XB"FUS9W-T<B`BN-Z]P\'V(,?7N/$B"@HC.B!L:6(O87!I+G!H<#HQ
M-#4*(RP@9G5Z>GD*;7-G:60@(E-E<W-I;VYS(@IM<V=S='(@(L7DM]`B"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,S$T"B,L(&9U>GIY"FUS9VED
M(")3970B"FUS9W-T<B`BN-Z]P\'V(+RQQ<,B"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z-S8*;7-G:60@(E-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="XB
M"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C$Q-0IM<V=I
M9"`B4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C
M97-S(&9R;VT@>6]U<B!P;W)T86PN(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX-`HC+"!F=7IZ>0IM<V=I9"`B4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+B(*
M;7-G<W1R("+&Y,#,P?8@L+N]Q<'6L>(@N=<@L>+%N"#(K;CI(+RSP:3`NR#'
MS[R\O^0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.CDX"B,L(&9U>GIY
M"FUS9VED("(B"B)3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO
M<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R("(*(F1I<W!L
M87D@;W!T:6]N<RXB"FUS9W-T<B`BQN3`S,'V(+"[O<7!UK'B(+G7(+'BQ;@@
MR*VXZ2"\L\&DP+L@Q\^\O+_D+B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP
M:'`Z-S4*(RP@9G5Z>GD*;7-G:60@(E-E='5P(@IM<V=S='(@(KC>O</!]B"\
ML<7#(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PZ,S<*
M;7-G:60@(E-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4B"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$X-@IM<V=I
M9"`B4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,#,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#`*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-`IM<V=I9"`B4V5Y8VAE
M;&QE<R(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z
M-#DV"B,L(&9U>GIY"FUS9VED(")3:&]P<&EN9R(*;7-G<W1R("*PQ;BN(@H*
M(SH@=&5M<&QA=&5S+W!R;V)L96TO<')O8FQE;2YI;F,Z-#,*(RP@9G5Z>GD*
M;7-G:60@(E-H;W)T(%-U;6UA<GDB"FUS9W-T<B`BL*.TW,?1(+_DON`Z(@H*
M(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T.C0T-@IM<V=I9"`B4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S(S('1E;7!L871E
M<R]S:&%R97,O961I="YI;F,Z,S,*(SH@=&5M<&QA=&5S+W-H87)E<R]E9&ET
M+FEN8SHV-R!T96UP;&%T97,O<VAA<F5S+V5D:70N:6YC.CDP"B,Z('1E;7!L
M871E<R]S:&%R97,O961I="YI;F,Z,3$S('1E;7!L871E<R]S:&%R97,O961I
M="YI;F,Z,3,V"B,Z('1E;7!L871E<R]S:&%R97,O961I="YI;F,Z,3<Y"FUS
M9VED(")3:&]W(@IM<V=S='(@(B(*"B,Z(&%D;6EN+W-E='5P+VEN9&5X+G!H
M<#HQ-34*;7-G:60@(B(*(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@(@HB8V]N9FEG
M=7)A=&EO;BXB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD:7-T
M.C0Y,`HC+"!F=7IZ>0IM<V=I9"`B4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/R(*;7-G<W1R("*WSK'7P,Z]PR##UL&^(+?.L=?`SB"]
MP["C(+JXOZG!UK'B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3<V
M-0IM<V=I9"`B4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;"(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#$S"FUS9VED(")3
M:&]W('!I8VME<B(*;7-G<W1R("(B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I
M<W0Z-3(V"B,L(&9U>GIY"FUS9VED(")3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_(@IM<V=S='(@(L>E(+S3O+K#HB"ZN+'B(@H*(SH@8V]N9FEG
M+W!R969S+G!H<"YD:7-T.C,T.0HC+"!P:'`M9F]R;6%T"FUS9VED(")3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/R(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-3D*
M;7-G:60@(E-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<B
M"FUS9W-T<B`BO+\@O-.\NL.B(+JXL>(B"@HC.B!T96UP;&%T97,O:F%V87-C
M<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z-C0*;7-G:60@(E-H;W<@
M=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G(@IM<V=S='(@(L>E(+S3O+K#
MHB"ZN+'B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N
M=&5X=%]L86YG+FIS.C8P"FUS9VED(")3:&]W('1H92!486)L92!2;W<@4')O
M<&5R=&EE<R!D:6%L;V<B"FUS9W-T<B`BOZT@O-.\NL.B(+JXL>(B"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]C;VYT97AT7VQA;F<N:G,Z
M-3(*;7-G:60@(E-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G(@IM
M<V=S='(@(K'7N+(@O-.\NL.B(+JXL>(B"@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HQ-S8S"B,L(&9U>GIY"FUS9VED(")3:&]W('5P;&]A9"(*;7-G
M<W1R("*SN[?!N=ZQXB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C4P"B,L(&9U>GIY"FUS9VED(")3:&]W97)S(@IM<V=S='(@
M(L#0ONZ_P+'B*,#3QO?&KBDB"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;5]S=')I;F=S+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B4VAO=V5R<R!%87)L
M>2(*;7-G<W1R("*PH[3<Q]$@O^2^X#HB"@HC.B!L:6(O0FQO8VLO=V5A=&AE
M<F1O=&-O;5]S=')I;F=S+G!H<#HU,@IM<V=I9"`B4VAO=V5R<R!,871E(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4S"FUS9VED(")3:&]W97)S(&EN('1H92!6:6-I;FET>2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HT.#`*
M(RP@9G5Z>GD*;7-G:60@(E-H<FEN:R(*;7-G<W1R("*WSK'7P,XB"@HC.B!F
M<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HW-S0@9G)A;65W;W)K
M+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z.#,V"B,Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R],87EO=70N<&AP.CDR,B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+G!H<#HY.#0*(SH@9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U
M="YP:'`Z,3`T-R!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y;W5T+G!H<#HQ
M,#@W"B,Z(&9R86UE=V]R:R]";&]C:R]";&]C:R],87EO=70N<&AP.C$Q,38@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,3$T.0IM<V=I9"`B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C$Q(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C`Q"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#4*;7-G:60@
M(E-I97)R82!,96]N92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!
M=71H+U-I9VYU<"YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")3:6=N('5P(@IM
M<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HW,3(*(RP@9G5Z>GD*;7-G:60@(E-I9VYA='5R92(*;7-G<W1R("*\
MK;CM.B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S$Q
M"B,L(&9U>GIY"FUS9VED(")3:6=N871U<F4@06QG;W)I=&AM(@IM<V=S='(@
M(KRMN.TZ(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,#8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#(*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$P-`HC+"!F=7IZ>0IM<V=I9"`B4VEN9V%P
M;W)E(@IM<V=S='(@(KRMN.TZ(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6
M:65W97(O<F%R+G!H<#HV-2!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]Z
M:7`N<&AP.C<R"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W1G>BYP
M:'`Z.#<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#DV"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$R,34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3(S-PHC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR,C0V(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C(Y,S`*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,S$R,PIM<V=I9"`B4VEZ92(*;7-G<W1R("+%J;'B(@H*(SH@=&5M<&QA
M=&5S+VUA:6YT96YA;F-E+VUA:6YT96YA;F-E+FAT;6PZ-3(*;7-G:60@(E-K
M:7`@36%I;G1E;F%N8V4B"FUS9W-T<B`BP*_!]K#\N*X@N_VWJR(*"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C$P(&9R86UE=V]R:R].3%,O3DQ3
M+V-O=6YT<FEE<RYP:'`Z,C`S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0
M+G!H<#HQ,#4*;7-G:60@(E-L;W9A:VEA(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`X(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C`T"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,#4*;7-G:60@(E-L;W9E;FEA(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C4T"FUS9VED(")3;F]W(@IM
M<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP.C4U"FUS9VED(")3;F]W(%-H;W=E<B(*;7-G<W1R("(B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HU-@IM<V=I9"`B4VYO
M=R!3:&]W97)S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T
M8V]M7W-T<FEN9W,N<&AP.C4W"FUS9VED(")3;F]W(%-H;W=E<G,@16%R;'DB
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG
M<RYP:'`Z-3@*;7-G:60@(E-N;W<@4VAO=V5R<R!,871E(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C<X"B,L(&9U>GIY"FUS9VED(")3
M;F]W(&1E<'1H.B`B"FUS9W-T<B`B(,&FN/$Z("(*"B,Z(&QI8B]";&]C:R]M
M971A<BYP:'`Z,C@R"FUS9VED(")3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z
M("(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P
M,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(P-0HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3`S"FUS9VED(")3;VQO;6]N($ES
M;&%N9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,30@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,#8*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-@IM<V=I9"`B4V]M86QI
M82(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO9F]R='5N92YP:'`Z-C`*;7-G
M:60@(E-O;F=S("8@4&]E;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O
M<FTO1F]R;2YP:'`Z,CDR-@HC+"!F=7IZ>0IM<V=I9"`B4V]R="!O<F1E<B!S
M96QE8W1I;VXB"FUS9W-T<B`BP:2WQ""YYKG](@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU-3D*(SH@9G)A;65W;W)K
M+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H<#HU.#D*(SH@9G)A;65W
M;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,C$W"B,Z(&9R
M86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(T-PHC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$V-@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP.C$X.0HC+"!F=7IZ
M>0IM<V=I9"`B4V]U<F-E(&%D9')E<W,B"FUS9W-T<B`BP??`Y2#!UKS2(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-34@9G)A;65W;W)K+TY,
M4R].3%,O8V]U;G1R:65S+G!H<#HR,#<*(SH@9G)A;65W;W)K+TY,4R].3%,O
M1V5O25`N<&AP.C$Q.`IM<V=I9"`B4V]U=&@@069R:6-A(@IM<V=S='(@(B(*
M"B,Z(&-O;F9I9R]N;',N<&AP+F1I<W0Z,3DP"FUS9VED(")3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RDB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,
M4R].3%,O=&QD+G!H<#HQ,#$@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S
M+G!H<#HR,#@*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C<W"FUS
M9VED(")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;6]O;BYP:'`Z,S,@;&EB
M+T)L;V-K+VUO;VXN<&AP.C8R"FUS9VED(")3;W5T:&5R;B!(96UI<W!H97)E
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQA;F<N:G,Z,3$S"FUS9VED(")3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS(@IM<V=S='(@(KR_L*.PW2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7VQA;F<N:G,Z,3$U"FUS9VED(")3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL(@IM<V=S='(@(KR_(+#FL.B_S2"S
MN[_K(+OGP,S`QR"PH[#=(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M.#$U"B,L(&9U>GIY"FUS9VED(")3<&%C97(B"FUS9W-T<B`BP/K`Y2(*"B,Z
M('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z
M-34*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHX
M,`IM<V=I9"`B4W!A8VEN9R(*;7-G<W1R("*PQ;BN(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHU-`IM<V=I9"`B
M4W!A8VEN9R!A;F0@<&%D9&EN9R(*;7-G<W1R("*PQ;BNO\T@PZ2_[+'B(@H*
M(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HX,"!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(P.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(E-P86EN(@IM<V=S='(@(K#%
MN*XB"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z.3@*(RP@9G5Z>GD*
M;7-G:60@(E-P86TB"FUS9W-T<B`BP/K`Y2(*"B,Z('-E<G9I8V5S+VME>6)O
M87)D+G!H<#HQ-`IM<V=I9"`B4W!E8VEA;"!#:&%R86-T97(@26YP=70B"FUS
M9W-T<B`BQJ^\]B"YKL#:(,#4M\(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP
M="]H=&UL87)E85]T86)L95]L86YG+FIS.C8R"FUS9VED(")3<&QI="!C96QL
M(@IM<V=S='(@(KR_(+K0Q](B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H
M=&UL87)E85]T86)L95]L86YG+FIS.C8V"FUS9VED(")3<&QI="!C;VQU;6XB
M"FUS9W-T<B`BOZT@NM#'TB(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT
M;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S$*;7-G:60@(E-P;&ET(')O=R(*;7-G
M<W1R("+'X""ZT,?2(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8Q"B,L
M(&9U>GIY"FUS9VED(")3<&]R=',B"FUS9W-T<B`BP-"^[K_`L>(HP-/&]\:N
M*2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,30Q(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$P"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HX.`IM<V=I9"`B4W)I($QA;FMA(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HW,R!L:6(O0FQO8VLO
M;65T87(N<&AP.C<T"B,L(&9U>GIY"FUS9VED(")3=&%N9&%R9"(*;7-G<W1R
M("*TWK?"(@H*(SH@;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8R"FUS9VED(")3
M=&%R(%1R96LB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP
M:'`Z,C4Y-B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#`Y"FUS9VED(")3
M=&%R="!Y96%R(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP
M="]S;6EM92YP:'`Z-3<P"FUS9VED(")3=&%T92!O<B!0<F]V:6YC92(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O861M:6XO<V5T=7`O:6YD97@N:'1M;#HQ
M,@IM<V=I9"`B4W1A='5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C(X,34*(RP@9G5Z>GD*;7-G:60@(E-T;W)A9V4@9F]R;6%T
M(@IM<V=S='(@(KC>P,\@O*VY]B#!I+JXN^?'UR(*"B,Z(&9R86UE=V]R:R]#
M<GEP="]#<GEP="]S;6EM92YP:'`Z-3<R"B,L(&9U>GIY"FUS9VED(")3=')E
M970@061D<F5S<R(*;7-G<W1R("+!]\#E(,'6O-(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C$Q"FUS9VED(")3=')I:V5T
M:')O=6=H(@IM<V=S='(@(K"AO^ZUI<'9(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,3(S,PHC+"!F=7IZ>0IM<V=I9"`B4W1R:6YG(&QI<W0B"FUS
M9W-T<B`BO/:]Q;#%NLXB"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HQ
M.#<S"FUS9VED(")3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<R(*;7-G
M<W1R("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L
M95]L86YG+FIS.C(S"FUS9VED(")3='EL92!;0U-372(*;7-G<W1R("*]NL6X
MP,];0U-372(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+V]P96Y?8V%L96YD
M87(N:G,Z-C(*;7-G:60@(E-U(@IM<V=S='(@(B(*"B,Z('5T:6PO:6-O;E]B
M<F]W<V5R+G!H<#HS-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5B
M9&ER96-T;W)Y(%PB)7-<(B!N;W0@9F]U;F0N(@IM<V=S='(@(L7KP?8@N*Z]
MNK/*("5SP+LHN*8I(,.CP+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW,PIM<V=I9"`B4W5B:F5C
M="(*;7-G<W1R("+!IKCQ(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,R(&9R86UE=V]R:R]&;W)M+T9O<FTO4F5N9&5R97(N<&AP.C,Q-PIM<V=I
M9"`B4W5B;6ET(@IM<V=S='(@(L&FP^(B"@HC.B!S:6=N=7`N<&AP.C0Y"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(E-U8FUI='1E9"!R97%U97-T('1O(&%D
M9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N
M=&EL('EO=7(@(@HB<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"XB"FUS9W-T
M<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ
M<SHQ,@IM<V=I9"`B4W5B<V-R:7!T(@IM<V=S='(@(K[&MZ'#M\#:(@H*(SH@
M861M:6XO<W%L<VAE;&PN<&AP.C$P-`HC.B!F<F%M97=O<FLO3F]T:69I8V%T
M:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]S=&%T=7,N<&AP.C(X"FUS9VED
M(")3=6-C97-S(@IM<V=S='(@(KRZL/@B"@HC.B!A9&UI;B]U<V5R+G!H<#HX
M-0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&%D
M9&5D(%PB)7-<(B!T;R!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,GL*$@O<.]
MNL7;OZ$@P]^PH;7'OOJ]P+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3(T
M"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T96TN(@IM
M<V=S='(@(B<E<R>PH2"]P[VZQ=N_H;RM(+OHP::UQ[[ZO<"TS[39+B(*"B,Z
M(&%D;6EN+V=R;W5P<RYP:'`Z.#`@861M:6XO<&5R;7,O9&5L971E+G!H<#HT
M-@HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY(&1E
M;&5T960@7"(E<UPB+B(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ$@P]^PH;7'
MOOJ]P+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`U"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<F5M;W9E9"!<(B5S7"(@
M9G)O;2!T:&4@<WES=&5M+B(*;7-G<W1R("(G)7,GL*$@O<.]NL7;OZ&\K2"[
MZ,&FM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]C;VYF:6<N<&AP.C4Q
M"FUS9VED(")3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@
M4F5L;V%D('1O('-E92!C:&%N9V5S+B(*;7-G<W1R("(B"@HC.B!A9&UI;B]S
M971U<"]I;F1E>"YP:'`Z-3D@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z-3<*
M(RP@9G5Z>GD*;7-G:60@(E-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BXB"FUS9W-T<B`B5D93(+RSP:0@P:2ZN+^AO*T@)W!O<G0G
MP,P@OOB]P+3/M-DN(@H*(SH@861M:6XO<V5T=7`O8V]N9FEG+G!H<#HV,@HC
M+"!P:'`M9F]R;6%T"FUS9VED(")3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(@IM<V=S='(@(B(*"B,Z(&%D
M;6EN+W5S97(N<&AP.C$V.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M4W5C8V5S<V9U;&QY('5P9&%T960@7"(E<UPB(@IM<V=S='(@(B<E<R>PH2"]
MP[VZQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!A9&UI;B]S971U<"]C;VYF
M:6<N<&AP.C<Q(&%D;6EN+W-E='5P+VEN9&5X+G!H<#HW,@HC+"!F=7IZ>2P@
M<&AP+69O<FUA=`IM<V=I9"`B4W5C8V5S<V9U;&QY('=R;W1E("5S(@IM<V=S
M='(@(B<E<R>PH2"]P[VZQ=N_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(P-"!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(Q,0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3`T"FUS9VED(")3=61A;B(*;7-G<W1R("(B"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C4V"FUS9VED(")3
M=6UM87)Y(@IM<V=S='(@(K_DON`B"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP
M:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E-U;B!2:7-E(@IM<V=S='(@(L&FN/$B
M"@HC.B!L:6(O0FQO8VLO<W5N<FES92YP:'`Z-C@*(RP@9G5Z>GD*;7-G:60@
M(E-U;B!3970B"FUS9W-T<B`BP::X\2(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C4Y"FUS9VED(")3=6YN>2(*;7-G<W1R("(B
M"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$V"B,L(&9U>GIY
M"FUS9VED(")3=6YR:7-E(@IM<V=S='(@(L&FN/$B"@HC.B!L:6(O0FQO8VLO
M<W5N<FES92YP:'`Z,R!L:6(O0FQO8VLO<W5N<FES92YP:'`Z,38*(RP@9G5Z
M>GD*;7-G:60@(E-U;G)I<V4O4W5N<V5T(@IM<V=S='(@(L&FN/$B"@HC.B!L
M:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,C$U"B,L(&9U>GIY"FUS9VED
M(")3=6YR:7-E.B`B"FUS9W-T<B`B(,&FN/$Z("(*"B,Z(&QI8B]";&]C:R]W
M96%T:&5R9&]T8V]M+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E-U;G-E="(*
M;7-G<W1R("+!IKCQ(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP
M.C(Q.`HC+"!F=7IZ>0IM<V=I9"`B4W5N<V5T.B`B"FUS9W-T<B`B(,&FN/$Z
M("(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z
M,3,*;7-G:60@(E-U<&5R<V-R:7!T(@IM<V=S='(@(L"MP[?`VB(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HS-S@*(RP@9G5Z>GD*;7-G:60@(E-U
M<'!O<G0B"FUS9W-T<B`BP-"^[K_`L>(HP-/&]\:N*2(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C$U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C$R"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,#8*(RP@9G5Z>GD*;7-G:60@(E-U<FEN86UE(@IM<V=S='(@(L#,N*<B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP.C4W-`HC+"!F=7IZ
M>0IM<V=I9"`B4W5R;F%M92(*;7-G<W1R("+`S+BG(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,#D@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,3,*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M-0IM<V=I9"`B4W9A;&)A<F0@86YD($IA;B!-87EE;B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(Q.2!F<F%M97=O<FLO3DQ3
M+TY,4R]C;W5N=')I97,N<&AP.C(Q-`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'
M96])4"YP:'`Z,3`X"B,L(&9U>GIY"FUS9VED(")3=V%Z:6QA;F0B"FUS9W-T
M<B`BPZ.QXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C`U(&9R
M86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$U"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#0*(RP@9G5Z>GD*;7-G:60@(E-W961E
M;B(*;7-G<W1R("+`T,"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C4V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$V
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HV-@IM<V=I9"`B4W=I
M='IE<FQA;F0B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<&]R=&%L+W-Y;F-M
M;"YP:'`Z.#8*(RP@9G5Z>GD*;7-G:60@(E-Y;F,@;&]G(&1E;&5T960B"FUS
M9W-T<B`BNKFQN"(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ-#(*;7-G
M:60@(E-Y;F--3"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4U%,+U-13"]+
M97EW;W)D<RYP:'`Z.3<*;7-G:60@(E-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@
M=&5R;7,B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H
M<#HR,3@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,3<*(SH@
M9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P-PIM<V=I9"`B4WER:6%N
M($%R86(@4F5P=6)L:6,B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H
M97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C`*;7-G:60@(E0M4W1O<FTB"FUS9W-T
M<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z
M-C$*;7-G:60@(E0M4W1O<FT@86YD(%=I;F1Y(@IM<V=S='(@(B(*"B,Z(&QI
M8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8R"B,L(&9U>GIY
M"FUS9VED(")4+5-T;W)M<R(*;7-G<W1R("+`I\2A(@H*(SH@;&EB+T)L;V-K
M+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C,*;7-G:60@(E0M4W1O<FUS
M($5A<FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]$871A+T1A=&$O='-V
M+G!H<#HQ-C8*(RP@9G5Z>GD*;7-G:60@(E135B!F:6QE(@IM<V=S='(@(L&F
MN/$B"@HC.B!F<F%M97=O<FLO54DO54DO5&%B;&4N<&AP.C$S-`HC+"!F=7IZ
M>0IM<V=I9"`B5&%B;&4B"FUS9W-T<B`BP::X\2(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S,*;7-G:60@(E1A
M8FQE(%!R;W!E<G1I97,B"FUS9W-T<B`BQZ4@O-.\NB(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTO5'EP92]T86)L97-E="YP:'`Z-3<*(RP@9G5Z>GD*;7-G
M:60@(E1A8FQE(%-E="(*;7-G<W1R("+!IKCQ(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW,@IM<V=I9"`B5&%B
M;&4@<')O<&5R=&EE<R(*;7-G<W1R("+'I2"\T[RZ(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,S0@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,0IM<V=I9"`B5&%I=V%N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C$X"FUS9VED(")486EW86XL(%!R
M;W9I;F-E(&]F($-H:6YA(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+W1L9"YP:'`Z,C(U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP
M:'`Z,C$Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,#D*;7-G
M:60@(E1A:FEK:7-T86XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR,S4@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,C`*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,@HC+"!F
M=7IZ>0IM<V=I9"`B5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B(*;7-G
M<W1R("*TZ\?1N<ZQN2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z.34*(RP@9G5Z>GD*;7-G:60@(E1A<F=E=#HB"FUS9W-T
M<B`BN-Z]P\'V(@H*(SH@8V]N9FEG+VAO;VMS+G!H<"YD:7-T.CDY-B!C;VYF
M:6<O<F5G:7-T<GDN<&AP+F1I<W0Z,3@W"FUS9VED(")487-K<R(*;7-G<W1R
M("+`V[[W(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HU
M-S,*;7-G:60@(E1E;&5P:&]N92!.=6UB97(B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+VUE=&%R+G!H<#HR.3`*;7-G:60@(E1E;7`@9F]R(&QA<W0@:&]U
M<CH@(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]M971A<BYP:'`Z,C$T"FUS
M9VED(")496UP97)A='5R92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C(S"FUS9VED(")496UP97)A='5R93H@(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HR.3,*(RP@
M<&AP+69O<FUA=`IM<V=I9"`B5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S
M3&\E<RD@)F1E9SLE<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5&5M<&QA
M=&4O5&5M<&QA=&4N<&AP.C8X-PHC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I
M9"`B5&5M<&QA=&4@7"(E<UPB(&YO="!F;W5N9"XB"FUS9W-T<B`BQ>O!]B"X
MKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]T
M96UP;&%T97,N<&AP.C$V.0HC+"!F=7IZ>0IM<V=I9"`B5&5M<&QA=&4@061M
M:6YI<W1R871I;VXB"FUS9W-T<B`BL/RXKB(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C$R,3$@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S,S-@IM
M<V=I9"`B5&5X="(*;7-G<W1R("*YKL#:OZTB"@HC.B!C;VYF:6<O<')E9G,N
M<&AP+F1I<W0Z,S<U"FUS9VED(")497AT($]N;'DB"FUS9W-T<B`BN:[`VB(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N
M:G,Z-S0*;7-G:60@(E1E>'0@86QI9VXB"FUS9W-T<B`BN:[`VB#!I+?$(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHW,0HC
M+"!F=7IZ>0IM<V=I9"`B5&5X='1O<"(*;7-G<W1R("*YKL#:OZTB"@HC.B!T
M96UP;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4Y"FUS9VED
M(")4:"(*;7-G<W1R("(B"@HC.B!C;VYF:6<O;FQS+G!H<"YD:7-T.C$Y,0IM
M<V=I9"`B5&AA:2`H5$E3+38R,"DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C0@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C$*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$P
M.0HC+"!F=7IZ>0IM<V=I9"`B5&AA:6QA;F0B"FUS9W-T<B`BPZ.QXB(*"B,Z
M(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.CDX.`IM<V=I9"`B5&AA;FL@>6]U
M(&9O<B!U<VEN9R!T:&4@<WES=&5M+B(*;7-G<W1R("*[Y[_KQ]C!UKS%O*T@
ML*B[Y\?5M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@R
M,`HC+"!F=7IZ>0IM<V=I9"`B5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V
M86EL86)L92XB"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3,T"B,L('!H
M<"UF;W)M870*;7-G:60@(E1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E
M;F=I;F4@9&]E<R!N;W0@<W5P<&]R="!<(B5S7"(B"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`Z,3(Y,@HC+"!F=7IZ
M>0IM<V=I9"`B5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"XB"FUS9W-T<B`BO*VX[<"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!S
M97)V:6-E<R]M86EN=&5N86YC92YP:'`Z,S$*;7-G:60@(E1H92!-86EN=&5N
M86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'DB"FUS9W-T
M<B`B(@H*(SH@<V5R=FEC97,O:6UA9V5S+V-O;&]R<&EC:V5R+G!H<#HR.0IM
M<V=I9"`B5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,3@Y
M(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C`P"B,Z(&9R86UE=V]R:R]0
M97)M<R]097)M<RYP:'`Z,C$Q(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z
M,C(S"B,Z(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,C,T(&9R86UE=V]R
M:R]097)M<R]097)M<RYP:'`Z,C4R"B,Z(&9R86UE=V]R:R]097)M<R]097)M
M<RYP:'`Z,C8T(&9R86UE=V]R:R]097)M<R]097)M<RYP:'`Z,S`S"FUS9VED
M("(B"B)4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@(@HB=V%N="!T
M;R!U<V4@4&5R;6ES<VEO;G,N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J
M879A<V-R:7!T+VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,Z-S4*;7-G:60@(E1H
M92!B;W1T;VT@<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].
M971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C,Y"FUS9VED("(B"B)4
M:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@(@HB9&%T86)A<V4N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D
M+G!H<#HU,0HC+"!F=7IZ>0IM<V=I9"`B5&AE(&-O;G1A8W0@=V%S('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RXB"FUS9W-T<B`B
MQ]>X\2!<(B5S7"*PH2#!UKS2M\^_H2##W["AM<>^^KW`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<#HQ,38Y"FUS9VED("(B"B)4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+B(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,0IM
M<V=I9"`B(@HB5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@
M;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@(@HB:6X@
M=&AE(&1A=&%B87-E+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--
M4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8T,@IM<V=I9"`B5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0N<&AP.C$Q,PIM<V=I9"`B5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H
M<#HQ-S4@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HU,3,*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N
M<&AP.C$V."!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C4P,PHC+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE
M("5S('-E='1I;F=S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HR,3D*(RP@9G5Z>GD*;7-G:60@(E1H92!F:6QE(&-A;B!N
M;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+B(*;7-G<W1R("+&Q,#/OZ$@OL:Y
MJ[>Q(,#:M^&PH2"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO1&%T82]$871A
M+G!H<#HR.#`*;7-G:60@(E1H92!F:6QE(&-O;G1A:6YE9"!N;R!D871A+B(*
M;7-G<W1R("+&Q,#/OZ$@OL:YJ[>Q(,#:M^&PH2"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C8W"FUS9VED
M(")4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S
M86=E+W)F8S@R,B!M97-S86=E+B(*;7-G<W1R("*^QK>AM,(@P,P@;65S<V%G
M92]R9F,X,C(@QNW!]L#'(+C3N+2XN\#4M,^TV2XB"@HC.B!T96UP;&%T97,O
M:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C4V"FUS9VED("(B"B)4:&4@
M9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W
M:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@(@HB=&\@8G)O=W-E<B!B=6=S
M('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG
M:'0@97AP97)I96YC92`B"B)G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I
M=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@
M($EF("(*(GEO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI
M:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"`B"B)0<F]T96-T:6]N
M($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7%QN7%QN66]U(&AA=F4@8F5E
M;B!W87)N960N("!0;&5A<V4@(@HB<')E<W,@3TL@:68@>6]U('-T:6QL('=A
M;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N(@IM<V=S='(@(B(*
M"B,Z('-E<G9I8V5S+W!R969S+G!H<#HY,`HC+"!P:'`M9F]R;6%T"FUS9VED
M(")4:&4@:61E;G1I='D@7"(E<UPB(&AA<R!B965N(&1E;&5T960N(@IM<V=S
M='(@(KW$NK#`VB!<(B5S7"(@L*$@N^C!IK7'OOJ]P+3/M-DN(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHW-@IM
M<V=I9"`B5&AE(&QE9G0M:&%N9"!S:61E(&]N;'DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z,34W"FUS9VED("(B"B)4
M:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N
M('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+TU)344O34E-12]-1$XN<&AP.C(P,0HC+"!P:'`M9F]R;6%T"FUS
M9VED("(B"B)4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B
M:F5C="!<(B5S7"(@:&%S(&)E96X@9&ES<&QA>65D+EQN(@HB5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O
M<FTN<&AP.C$X-S<*;7-G:60@(E1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<#HT-#$*(RP@9G5Z>GD*;7-G:60@(E1H92!N
M=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RXB"FUS9W-T<B`BP,P@
ML*K`NB"\_<#:OZF^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R
M>7!T+W-M:6UE+G!H<#HQ,C,Q"FUS9VED(")4:&4@;W!E;G-S;"!M;V1U;&4@
M:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,N<&AP.C(Y
M,`HC+"!P:'`M9F]R;6%T"FUS9VED("(B"B)4:&4@<')E9F5R96YC92!<(B5S
M7"(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE("(*(FUA>&EM=6T@86QL;W=A8FQE('-I>F4B"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O9&5B+G!H<#HS,@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G-C<FEP="YP:'`Z,S4*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-P;W=E<G!O:6YT+G!H<#HS
M,@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP.C,R
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W)P;2YP:'`Z,S(*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=V5B8W!P+G!H<#HS-PHC.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`Z,S<*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O;7-E>&-E;"YP:'`Z,S(*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(B(*(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB"FUS9W-T<B`BP,P@N-Z]P\'V(,?\Q<(H)7,IN*8@
MNKBQXB#`I\?1(,?!M\ZQU[>EP+L@PZ/`NR"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO1FEL95]#4U8O0U-6+G!H<#HT-30*;7-G:60@(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB"FUS
M9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B
M;&5?;&%N9RYJ<SHW-PIM<V=I9"`B5&AE(')I9VAT(&%N9"!L969T('-I9&5S
M(&]N;'DB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M
M;&%R96%?=&%B;&5?;&%N9RYJ<SHW.`IM<V=I9"`B5&AE(')I9VAT+6AA;F0@
M<VED92!O;FQY(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&:6QE7T-35B]#
M4U8N<&AP.C0T-@IM<V=I9"`B5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+B(*;7-G<W1R("(B"@HC.B!S97)V:6-E<R]P;W)T
M86PO<G!C<W5M+G!H<#HW.`HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B
M5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@9&5L971E9"XB"FUS9W-T<B`B
MO<2ZL,#:(%PB)7-<(B"PH2"[Z,&FM<>^^KW`M,^TV2XB"@HC.B!S97)V:6-E
M<R]P;W)T86PO<G!C<W5M+G!H<#HT.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM
M<V=I9"`B5&AE('-E<G9E<B!<(B5S7"(@:&%S(&)E96X@<V%V960N(@IM<V=S
M='(@(KW$NK#`VB!<(B5S7"(@L*$@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,3DX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N(@IM
M<V=S='(@(KW$NK#`VB!<(B5S7"(@L*$@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+T)L;V-K+T)L;V-K+TQA>6]U="YP:'`Z,S,P"FUS9VED(")4
M:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="XB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HQ-S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5&AE('1E;7!O<F%R>2!F:6QE(%PB)7-<(B!D;V5S(&YO="!E
M>&ES="XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,S,Q,0IM<V=I9"`B5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C
M:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(*;7-G<W1R("(B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C<Y"FUS
M9VED(")4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>2(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG
M+FIS.C@P"FUS9VED(")4:&4@=&]P('-I9&4@;VYL>2(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HS,C<*;7-G:60@(E1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1&%T82]$871A+V-S=BYP:'`Z,C8R
M(&9R86UE=V]R:R]$871A+T1A=&$O='-V+G!H<#HQ-S(*(RP@9G5Z>GD*;7-G
M:60@(E1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"XB"FUS
M9W-T<B`BO*VX[<"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!L:6(O0FQO
M8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-#8@;&EB+T)L;V-K+W=E871H97)D;W1C
M;VTN<&AP.C4V"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ,34@
M;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C$Q.0HC+"!F=7IZ>0IM<V=I
M9"`B5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N(@IM
M<V=S='(@(L#,O^NPH;3)Q]$@O+'%P[OGQ]?`S""^^+W`M,^TV2XB"@HC.B!U
M=&EL+VEC;VY?8G)O=W-E<BYP:'`Z,C4*(RP@9G5Z>GDL('!H<"UF;W)M870*
M;7-G:60@(E1H96UE<R!D:7)E8W1O<GD@7"(E<UPB(&YO="!F;W5N9"XB"FUS
M9W-T<B`BQ>O!]B"XKKVZL\H@)7/`NRBXIBD@PZ/`NR"\]B"^^+W`M,^TV2XB
M"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$W.`IM<V=I9"`B
M5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+B(*;7-G<W1R("+`S+_K
ML*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)
M344O34E-12]#;VYT96YT<RYP:'`Z,S0R"B,L(&9U>GIY"FUS9VED(")4:&5R
M92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92XB
M"FUS9W-T<B`BP,R_Z["AM,G'T2"\L<7#N^?'U\#,(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$T,#$*(RP@<&AP+69O<FUA=`IM
M<V=I9"`B(@HB5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI
M<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R`B"B)Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N(@IM<V=S='(@(B(*"B,Z('-I
M9VYU<"YP:'`Z-3,@861M:6XO=7-E<BYP:'`Z-S,*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(E1H97)E('=A<R!A('!R;V)L96T@861D:6YG(%PB)7-<
M(B!T;R!T:&4@<WES=&5M.B`E<R(*;7-G<W1R("(G)7,GN*8@O<.]NL7;OZ$@
MP]^PH<?2(+SV(+[XO<"TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$R,@HC
M+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B5&AE<F4@=V%S(&$@<')O8FQE
M;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R(%PB)7-<(B!F<F]M('1H92!S>7-T
M96TZ("(*;7-G<W1R("(G)7,GN*8@O<.]NL7;OZ&\K2"[Z,&FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,3`S"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG(%PB
M)7-<(B!F<F]M('1H92!S>7-T96TZ("(*;7-G<W1R("(G)7,GN*8@O<.]NL7;
MOZ&\K2"[Z,&FQ](@O/8@OOB]P+3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,34Y"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG(%PB)7-<(CH@)7,B"FUS9W-T<B`B)R5S)[BF(+W#
MO;K%V[^A(,/?L*''TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0G)O
M=W-E<B]"<F]W<V5R+G!H<#HX.#0*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@
M=V%S('5P;&]A9&5D+B(*;7-G<W1R("+&Q,#/(+_#N*ZQXK^A(+FNP::PH2#`
MUKW`M,^TV2X@)7,@QL3`S\#,(+[WM\ZUY;7'P?8@OLJ^TKW`M,^TV2XB"@HC
M.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.#D*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@(@HB86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(@IM<V=S='(@
M(B(*(L;$P,\@OO>WSK7E(+_`M_DN(,#,QL3`S\"Z(+[WM\ZUY2#'X[_KM<@@
MP]:TZR#%J;'B*"5D($U"*;JXM-D@Q:NPS2"PL+W`M,^TV2XB"@HC.B!F<F%M
M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<#HX.3$*(RP@9G5Z>GDL('!H<"UF
M;W)M870*;7-G:60@(B(*(E1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N(@IM<V=S='(@(B(*(K[WM\ZUY2#&Q,#/OZ$@N:[!IK"A(,#6O<"TS[39
M+B#`S,;$P,_`NB"^][?.M>4@P]:TZ\?CO^O%J;'BN*8@P\JP^L?5M,^TV2XB
M"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]R9F,X,C(N<&AP.C,U
M"B,L(&9U>GIY"FUS9VED(")4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R="(*;7-G<W1R("*XWKW#P?8@P/R\VR"_P+?Y
M(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C,Y
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HT.`HC
M+"!F=7IZ>0IM<V=I9"`B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T
M:&4@8V]N=&%C="!D871A+B(*;7-G<W1R("*UI<#,Q;@@P-/&]\:N(+_`M_DB
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+VEM8RYP:'`Z,S$*(RP@9G5Z>GD*
M;7-G:60@(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE
M;F1A<B!D871A+B(*;7-G<W1R("*UI<#,Q;@@P-/&]\:N(+_`M_DB"@HC.B!A
M9&UI;B]S971U<"]C;VYF:6<N<&AP.C@P"B,L(&9U>GIY"FUS9VED("(B"B)4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82`B"B)R97%U:7)E9"!F:65L9"XB"FUS
M9W-T<B`BO^3#N[7((+C>O</!]B#`T+'B(+_`M_DB"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C8S.`HC+"!F=7IZ>0IM
M<V=I9"`B(@HB5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P
M96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92`B"B)T<GD@
M86=A:6X@;&%T97(N(@IM<V=S='(@(K_DP[NUR""XWKW#P?8@P-"QXB"_P+?Y
M(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P+G!H
M<#HV-#`*(RP@9G5Z>GD*;7-G:60@(B(*(E1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+B(*;7-G<W1R("*^][?.M>4@QL3`SR#`T\;WQJX@O\"W^2(*"B,Z
M(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-C0U
M"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]W:6Y?:'1T<"YP:'`Z,C(R"B,L
M(&9U>GIY"FUS9VED("(B"B)4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+B(*;7-G<W1R("*_Y,.[M<@@N-Z]P\'V(,#0L>(@O\"W^2(*"B,Z(&9R86UE
M=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C$T.`HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I
M;F<@9F]L9&5R<RXB"FUS9W-T<B`BNNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_
M^,?/P?8@OLJ]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O<F%R+G!H<#HT.`HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92XB"FUS9W-T<B`BP,P@
ML*K`NB"\_<#:OZF^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O>FEP+G!H<#HU,@HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92XB"FUS9W-T<B`B
MP,P@L*K`NB"\_<#:OZF^WR#'U;3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,S$T-0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!D;V5S(&YO="!S
M965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N(@IM<V=S='(@(L#,(+"J
MP+H@O/W`VK^IOM\@Q]6TS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]C;&EC:V%T96QL7VAT='`N<&AP.C$X-0IM<V=I9"`B(@HB5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+R(*(F-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U
M<VEN9R!T:&4@2%144"!!4$DB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ,S0*;7-G:60@(B(*(E1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI("(*(F=A=&5W87DL('5S:6YG('1H92!(
M5%10($%022(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O
M<VUS,F5M86EL7VAT='`N<&AP.C4Q-0IM<V=I9"`B(@HB5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M
M86EL("AH='1P.B\O(@HB<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3
M+U--4R]V;V1A9F]N96ET86QY7W-M='`N<&AP.C@U"FUS9VED("(B"B)4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T
M:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2`B"B)G871E=V%Y+"!O;FQY('1O
M(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U
M;G0@=VET:"`B"B)6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HY-S@@
M9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3`U-PHC.B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,#@V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,34*
M(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3$X,B!F<F%M97=O<FLO1F]R
M;2]&;W)M+G!H<#HQ,C4V"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$S
M,#4@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3,Y.`HC.B!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HQ-34W(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$X
M,SD*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3DU."!F<F%M97=O<FLO
M1F]R;2]&;W)M+G!H<#HR,#`U"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(P,CD@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C`W.`HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR,30Y(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP
M.C(R,C$*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C0Q,"!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HR-#4T"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(V-3<@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C@R.`HC.B!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS,3,W(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C,S,#8*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,S@Q-"!F<F%M
M97=O<FLO1F]R;2]&;W)M+G!H<#HS.#(R"FUS9VED(")4:&ES(&9I96QD(&ES
M(')E<75I<F5D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO1F]R;2]&;W)M
M+G!H<#HQ,#8U"FUS9VED(")4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M:6YT96=E<G,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(T,3@*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N
M=6UB97)S(&%N9"!T:&4@8V]L;VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$P.30*;7-G:60@(E1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$Q,C,*;7-G:60@(E1H:7,@9FEE;&0@;75S
M="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G
M97)S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.CDX
M.0HC+"!F=7IZ>0IM<V=I9"`B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+B(*;7-G<W1R("+`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2XB"@HC
M.B!F<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR.#,V"FUS9VED("(B"B)4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`B"B(G(S$R,S1A9B<N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C4V,0HC+"!F=7IZ>0IM
M<V=I9"`B5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(*
M;7-G<W1R("+`S+G,(,'6O-*WS[^A(+7NM\^UQ[[N(,#6O<"TS[39+B(*"B,Z
M('1E;7!L871E<R]H96QP+V%B;W5T+FEN8SHQ"B,L('!H<"UF;W)M870*;7-G
M:60@(E1H:7,@:7,@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]+;VQA
M8B]+;VQA8BYP:'`Z-#4Y"B,L('!H<"UF;W)M870*;7-G:60@(B(*(E1H:7,@
M:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J
M96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@(@HB8VQI96YT('1H870@=6YD
M97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI
M<W0@;V8@<W5C:"!E;6%I;"`B"B)C;&EE;G1S('!L96%S92!V:7-I="`E<R(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3$*(RP@<&AP+69O<FUA=`IM<V=I9"`B5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]5
M22YP:'`Z,3(V"FUS9VED(")4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92XB"FUS9W-T<B`BP,P@O/W`VK3"(,/6O-+'T2`QP-JXKB#`S+OSP,R^
M[K[?(,?5M,^TV2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O
M9WII<"YP:'`Z-#4*;7-G:60@(E1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E
M<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C$X.0IM<V=I9"`B5&AI<R!S
M>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+B(*;7-G<W1R("(B"@HC
M.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$R-`IM<V=I9"`B5&AI
M<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+B(*;7-G<W1R("+`S""PJL"Z(+S]
MP-J_J;[?(,?5M,^TV2XB"@HC.B!S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K
M97(N<&AP.C,U"FUS9VED(")4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F
M<F]M(&%N($]P=&EO;G,@=VEN9&]W(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N<&AP.C8T"FUS9VED(")4:'5N9&5R
M(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,S0*
M;7-G:60@(E1I8VME=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO
M1F]R;2YP:'`Z,C0R."!S97)V:6-E<R]P;W)T86PO<WEN8VUL+G!H<#HR-34*
M(RP@9G5Z>GD*;7-G:60@(E1I;64B"FUS9W-T<B`BP::X\2(*"B,Z(&-O;F9I
M9R]R96=I<W1R>2YP:'`N9&ES=#HS.#8*;7-G:60@(E1I;64@5')A8VMI;F<B
M"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W1I;64N<&AP.C$W"B,L(&9U>GIY
M"FUS9VED(")4:6UE(&9O<FUA="(*;7-G<W1R("*]P["C(+RSP:0B"@HC.B!F
M<F%M97=O<FLO1F]R;2]&;W)M+G!H<#HR-3,Y"B,L(&9U>GIY"FUS9VED(")4
M:6UE('-E;&5C=&EO;B(*;7-G<W1R("*]P["C(+RSP:0B"@HC.B!F<F%M97=O
M<FLO3DQ3+TY,4R]T;&0N<&AP.C(S,"!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N
M=')I97,N<&AP.C(R,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z
M,3$P"FUS9VED(")4:6UO<BU,97-T92(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z,C(Y(&QI8B]";&]C:R]I
M9G)A;64N<&AP.C(P"FUS9VED(")4:71L92(*;7-G<W1R("+!IKCQ(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-@IM<V=I
M9"`B5&ET;&4@*'1O;VQT:7`I.B(*;7-G<W1R("+%N,#,QK(HQ?C&P2DZ(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O<F9C.#(R+G!H<#HW-0IM
M<V=I9"`B5&\B"FUS9W-T<B`BN=ZTPB"[Y[;W(@H*(SH@9G)A;65W;W)K+U5)
M+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP.C8U-`IM<V=I9"`B(@HB5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2`B"B)W:&EL92!C;&EC:VEN9RXB"FUS
M9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C,Q,0HC
M+"!F=7IZ>0IM<V=I9"`B5&]D87DB"FUS9W-T<B`BNKNYKB(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,C@*;7-G:60@(E1O
M9V=L92!(5$U,(%-O=7)C92(*;7-G<W1R(")(5$U,(+S2O;H@NKBQXB(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(S(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C(S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,#D*(RP@9G5Z>GD*;7-G:60@(E1O9V\B"FUS9W-T<B`BN=ZT
MPB"[Y[;W(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,C8@9G)A
M;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,C0*(SH@9G)A;65W;W)K
M+TY,4R].3%,O1V5O25`N<&AP.C$Q,`IM<V=I9"`B5&]K96QA=2(*;7-G<W1R
M("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z,S$S"B,L(&9U
M>GIY"FUS9VED(")4;VUO<G)O=R(*;7-G<W1R("(@*+.[P,\I(@H*(SH@9G)A
M;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR,CD@9G)A;65W;W)K+TY,4R].3%,O
M8V]U;G1R:65S+G!H<#HR,C4*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N
M<&AP.C$Q,`HC+"!F=7IZ>0IM<V=I9"`B5&]N9V$B"FUS9W-T<B`BN=ZTPB"[
MY[;W(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?
M;&%N9RYJ<SHX,0HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L
M86YG+FIS.C<W"FUS9VED(")4;W`B"FUS9W-T<B`BP*<B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.CDS"FUS9VED(")4;W`@
M9G)A;64@*%]T;W`I(@IM<V=S='(@(KOSP*<@Q\&WN<#3*%]T;W`I(@H*(SH@
M;&EB+T)L;V-K+V9O<G1U;F4N<&AP.C8S"B,L(&9U>GIY"FUS9VED(")4<F%N
M<VQA=&EO;G,B"FUS9W-T<B`BR*^PYKRSP:0B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,B!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R-@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4<FEN:61A9"!A;F0@5&]B86=O(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]&;W)M+T9O<FTN<&AP.C$W.3`*;7-G:60@(E1R=64@;W(@9F%L<V4B
M"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O;W!E;E]C86QE
M;F1A<BYJ<SHU-PIM<V=I9"`B5'4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TY,4R].3%,O=&QD+G!H<#HR,C@@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R
M:65S+G!H<#HR,C<*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q
M,`IM<V=I9"`B5'5N:7-I82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3
M+TY,4R]T;&0N<&AP.C(S,2!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N
M<&AP.C(R.`HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$Q"FUS
M9VED(")4=7)K97DB"FUS9W-T<B`B(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES
M=#HQ.3(*;7-G:60@(E1U<FMI<V@@*$E33RTX.#4Y+3DI(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C(W(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C(Y"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3`*;7-G:60@(E1U<FMM96YI<W1A;B(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(R,"!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S,`HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z,3`X"FUS9VED(")4=7)K<R!A;F0@0V%I8V]S($ES;&%N
M9',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR
M,S,@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR,S$*(SH@9G)A
M;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q,0IM<V=I9"`B5'5V86QU(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#3$DO0TQ)+G!H<#HR-C0*;7-G:60@
M(E1Y<&4@>6]U<B!C:&]I8V4Z("(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO
M=V5A=&AE<F1O=&-O;2YP:'`Z,C8Y"FUS9VED(")5+E8N(&EN9&5X.B`B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N
M<&AP.C(T.2!L:6(O0FQO8VLO:69R86UE+G!H<#HQ-PIM<V=I9"`B55),(@IM
M<V=S='(@(E523"(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA
M:6Q?:'1T<"YP:'`Z-30Q"FUS9VED(")54DP@9F]R('EO=7(@<V-R:7!T(&1E
M;&EV97)Y('-T871U<R!R97!O<G0B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S
M+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY-PHC+"!F=7IZ>0IM<V=I
M9"`B55),.B(*;7-G<W1R(")54DPB"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T
M;&0N<&AP.C(S-R!F<F%M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(S
M,@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP:'`Z,3$R"B,L(&9U>GIY
M"FUS9VED(")59V%N9&$B"FUS9W-T<B`BM-ZWPB(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C,V(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,S"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3(*
M(RP@9G5Z>GD*;7-G:60@(E5K<F%I;F4B"FUS9W-T<B`BN=C!V2(*"B,Z(&9R
M86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C0Q,@HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R
M;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z.38*;7-G:60@(E5N86)L92!T;R!A
M9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,S@X"B,L
M(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$
MP,\@)7,O)7/`QR#&V[G,O,?`NR"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,S@U(&9R86UE=V]R:R]61E,O
M5D93+VUU<W%L+G!H<#HT-C@*(RP@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE
M('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RXB"FUS
M9W-T<B`B5D93(,;$P,\@)7,O)7/`QR#&V[G,O,?`NR"ZK[#FQ](@O/8@OOB]
MP+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HW-34*(RP@
M9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!C:&%N9V4@=&\@
M)7,N(@IM<V=S='(@(E-13""\K;GVOZ$@P:*\T\?2(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`Z,C,R"B,L(&9U>GIY+"!P
M:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F
M(%PB)7-<(BXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2
M(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP
M.C8X."!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP.C$P,38*(SH@9G)A;65W
M;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C@S-`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B!<(B5S
M+R5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`Z
M-#,U"FUS9VED(")5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+B(*
M;7-G<W1R(")344P@O*VY]K^A(,&BO-/'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C@S.0HC+"!F=7IZ>0IM<V=I9"`B
M56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN(@IM<V=S='(@(E-13""\K;GV
MOZ$@P:*\T\?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93
M+V9I;&4N<&AP.C(R-2!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR,S`*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$Y-B!F<F%M97=O
M<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,C`Q"B,Z(&9R86UE=V]R:R]61E,O
M5D93+W-Q;%]F:6QE+G!H<#HR,#D*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF
M*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9G1P+G!H<#HS-C4*(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(@IM<V=S='(@(G9F
M<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE
M=V]R:R]61E,O5D93+V9I;&4N<&AP.C,U-"!F<F%M97=O<FLO5D93+U9&4R]M
M=7-Q;"YP:'`Z,C4X"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H
M<#HR-38*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2XB"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP.C$R
M-`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&-R96%T92!61E,@9FEL92XB
M"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C@V"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL
M92YP:'`Z,C8U"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@8W)E871E(&5M
M<'1Y(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O
M;7!R97-S+W1A<BYP:'`Z-S8*(SH@9G)A;65W;W)K+T-O;7!R97-S+T-O;7!R
M97-S+V=Z:7`N<&AP.C<Y"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+B(*;7-G<W1R("+(K[#FO+/!I,"[(+JOL.;'TB"\]B"^
M^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C(R-"!F
M<F%M97=O<FLO5D93+U9&4R]F='`N<&AP.C(Y.`HC+"!F=7IZ>2P@<&AP+69O
M<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!<(B5S7"(L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y+B(*;7-G<W1R(")V9G-R;V]T(+7PM[K%Y+BN
MN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!A9&UI;B]G<F]U<',N<&AP.C<X
M(&%D;6EN+W!E<FUS+V1E;&5T92YP:'`Z-#0*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@7"(E<UPB.B`E<RXB"FUS9W-T
M<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*
M"B,Z(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C,S,2!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C,Y,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,S$Q(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS,S0*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(@IM<V=S='(@(G9F<W)O
M;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS-#@@9G)A;65W;W)K+U9&4R]61E,O
M<W%L7V9I;&4N<&AP.C,U,@HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+B(*;7-G<W1R(")V9G-R
M;V]T(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O
M<FLO5D93+U9&4R]F:6QE+G!H<#HS,S<@9G)A;65W;W)K+U9&4R]61E,O;75S
M<6PN<&AP.C,R,@HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q;"YP:'`Z,S,U
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HS-#,*(SH@9G)A;65W;W)K
M+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,T-`HC+"!F=7IZ>0IM<V=I9"`B56YA
M8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T
M(+7PM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO
M5D93+U9&4R]S<6PN<&AP.C0Q-R!F<F%M97=O<FLO5D93+U9&4R]S<6PN<&AP
M.C0R.0HC+"!F=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y.B`E<RXB"FUS9W-T<B`BM?"WNL7DN*X@L,N[
M]K_`M_DZ("5S(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HR,#<*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF
M*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,S`S(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,C@X"B,Z
M(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HQ-C<@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C$X,`HC.B!F<F%M97=O<FLO5D93+U9&4R]M=7-Q
M;"YP:'`Z,3@W(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS.#,*
M(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C,Y,0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB"FUS9W-T<B`B
M5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z
M(&9R86UE=V]R:R]61E,O5D93+W-M8BYP:'`Z,C0T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@7"(E
M<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@
MOOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<W%L+G!H<#HT,#8*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!D96QE=&4@
M5D93(')E8W5R<VEV96QY.B`E<RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`
MNRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9T<"YP:'`Z.#`S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+B(*;7-G<W1R(")V9G-R;V]T(+7P
MM[K%Y+BNN*8@P-#`NR"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO0W)Y
M<'0O0W)Y<'0O<VUI;64N<&AP.C8P,PIM<V=I9"`B56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<R(*;7-G<W1R("(B"@HC.B!F<F%M97=O
M<FLO3F5T7TE-4U`O24U34"YP:'`Z-#4Q(&9R86UE=V]R:R].971?24U34"])
M35-0+T%U=&@N<&AP.C$Q.`HC+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@
M=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RXB"FUS9W-T<B`B)7,@P:3`
MQ[BF(,#0P+L@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O
M9FEL92YP:'`Z,3DV(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C(P,0HC
M.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,38V(&9R86UE=V]R
M:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HQ-S$*(RP@9G5Z>GD*;7-G:60@(E5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E
M<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&
M4R]61E,O<VUB+G!H<#HY,R!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C$P
M,@HC.B!F<F%M97=O<FLO5D93+U9&4R]S;6(N<&AP.C8T."!F<F%M97=O<FLO
M5D93+U9&4R]F='`N<&AP.CDX"B,L(&9U>GIY+"!P:'`M9F]R;6%T"FUS9VED
M(")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(@IM<V=S='(@(E9&
M4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HR-S<@9G)A;65W;W)K+U9&4R]6
M1E,O<W%L7V9I;&4N<&AP.C$S,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?
M9FEL92YP:'`Z,3,S"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`
MNRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O
M5D93+V9I;&4N<&AP.C@P(&9R86UE=V]R:R]61E,O5D93+V9I;&4N<&AP.C$S
M,`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z-S(*(RP@9G5Z
M>GD*;7-G:60@(E5N86)L92!T;R!O<&5N(%9&4R!F:6QE+B(*;7-G<W1R(")6
M1E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@
M9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<#HT-0HC+"!F=7IZ
M>0IM<V=I9"`B56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+B(*
M;7-G<W1R("+(K[#FO+/!I,"[(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F
M<F%M97=O<FLO5D93+U9&4RYP:'`Z.#,U"B,L(&9U>GIY"FUS9VED(")5;F%B
M;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+B(*;7-G
M<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#FQ](@O/8@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U9&4R]61E,N<&AP.C@V-@HC+"!F=7IZ>0IM<V=I
M9"`B56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I
M;&5D*2XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV
M(+[XO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S
M:6]N2&%N9&QE<B]N;VYE+G!H<#HS.`HC+"!F=7IZ>0IM<V=I9"`B56YA8FQE
M('1O(')E860@9FEL93H@(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HV-CD*;7-G:60@(E5N86)L92!T;R!R96%D('1H92!V9G-R;V]T
M(&1I<F5C=&]R>2XB"FUS9W-T<B`B=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@
MO/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TMO;&%B+TMO;&%B+G!H<#HQ
M,3`U"B,L('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@)7,@
M=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<R(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,CDS
M"B,L(&9U>GIY"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN(@IM<V=S='(@(G9F<W)O;W0@M?"WNL7DN*ZXIB#`T,"[(+SV(+[XO<"T
MS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(Y"B,L(&9U
M>GIY+"!P:'`M9F]R;6%T"FUS9VED(")5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDZ("5S+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"Z
MK[#FQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O<VUB
M+G!H<#HR-C<@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HS-#,*(RP@9G5Z
M>GDL('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@7"(E<UPB+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#F
MQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP
M:'`Z-C$P(&9R86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,CD*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E
M<RXB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[X
MO<"TS[39+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP:'`Z,S(S(&9R
M86UE=V]R:R]61E,O5D93+VUU<W%L+G!H<#HR,3,*(SH@9G)A;65W;W)K+U9&
M4R]61E,O;75S<6PN<&AP.C0U,B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL
M92YP:'`Z,C@U"B,Z(&9R86UE=V]R:R]61E,O5D93+W-Q;%]F:6QE+G!H<#HS
M,#$*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^^+W`
MM,^TV2XB"@HC.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET97(O
M;6MI<V]F<RYP:'`Z-3`*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!R=6X@
M)VUK:7-O9G,G+B(*;7-G<W1R(")61E,@QL3`SR`E<R\E<\"[*+BF*2"ZK[#F
MQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W
M97(O;7-W;W)D+G!H<#HU.0IM<V=I9"`B56YA8FQE('1O('1R86YS;&%T92!T
M:&ES(%=O<F0@9&]C=6UE;G0B"FUS9W-T<B`BP,P@O_:UY;FNO*VXIB"ZK[#F
MQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H
M<#HQ-#D@9G)A;65W;W)K+U9&4R]61E,O9G1P+G!H<#HQ-3(*(RP@9G5Z>GDL
M('!H<"UF;W)M870*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92!<
M(B5S7"(N(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\
M]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F:6QE+G!H<#HQ
M-SD*(RP@9G5Z>GD*;7-G:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92`H
M8V]P>2@I(&9A:6QE9"DN(@IM<V=S='(@(E9&4R#&Q,#/("5S+R5SP+LHN*8I
M(+JOL.;'TB"\]B"^^+W`M,^TV2XB"@HC.B!F<F%M97=O<FLO5D93+U9&4R]F
M:6QE+G!H<#HR.#$@9G)A;65W;W)K+U9&4R]61E,O<W%L7V9I;&4N<&AP.C$S
M.`HC.B!F<F%M97=O<FLO5D93+U9&4R]S<6Q?9FEL92YP:'`Z,30S"B,L(&9U
M>GIY"FUS9VED(")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82XB"FUS
M9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2(+SV(+[XO<"TS[39
M+B(*"B,Z(&9R86UE=V]R:R]61E,O5D93+G!H<#HX-#$*(RP@9G5Z>GD*;7-G
M:60@(E5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E
M>&-E961E9"XB"FUS9W-T<B`B5D93(,;$P,\@)7,O)7/`NRBXIBD@NJ^PYL?2
M(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA
M<F5A7VQA;F<N:G,Z,3`*;7-G:60@(E5N9&5R;&EN92(*;7-G<W1R("*YV,'9
M(@H*(SH@=&5M<&QA=&5S+W!R969S+V5N9"YI;F,Z-@IM<V=I9"`B56YD;R!#
M:&%N9V5S(@IM<V=S='(@(KJOL.:[Y\?7(+7'M;FXKK'B(@H*(SH@=&5M<&QA
M=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHS,PIM<V=I9"`B56YD
M;V5S('EO=7(@;&%S="!A8W1I;VXB"FUS9W-T<B`BN+;!]KBW(+CMM\D@P^N\
MTB(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F8S(P.#8N<&AP.C(R
M,PHC.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<#HS.3`*
M;7-G:60@(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R])34%0+TE-05`O
M04-,+W)F8S(P.#8N<&AP.C(Q.0HC.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"]R9F,R,#@V+G!H<#HS-#$*(SH@9G)A;65W;W)K+TE-05`O24U!4"]!0TPO
M<F9C,C`X-BYP:'`Z,S<X"B,Z(&9R86UE=V]R:R])34%0+TE-05`O04-,+W)F
M8S(P.#8N<&AP.C,X-`IM<V=I9"`B56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]0<F5F<R]0
M<F5F<R]#871E9V]R>4UA;F%G97(N<&AP.C4W"B,Z('1E;7!L871E<R]P<F5F
M<R]C871E9V]R>6UA;F%G96UE;G0N:6YC.C8Q"B,L(&9U>GIY"FUS9VED(")5
M;F9I;&5D(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.3,*;7-G:60@(E5N:6-O9&4@*%541BTX*2(*;7-G<W1R
M("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C$W(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,T"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HU-@HC+"!F=7IZ>0IM<V=I9"`B56YI=&5D($%R86(@
M16UI<F%T97,B"FUS9W-T<B`BN<RQN2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+W1L9"YP:'`Z,C,X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z
M,C,U"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HW-`IM<V=I9"`B
M56YI=&5D($MI;F=D;VTB"FUS9W-T<B`BO[6QN2(*"B,Z(&9R86UE=V]R:R].
M3%,O3DQ3+W1L9"YP:'`Z,C0P(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE
M<RYP:'`Z,C,V"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3,*
M;7-G:60@(E5N:71E9"!3=&%T97,B"FUS9W-T<B`BN<RQN2(*"B,Z(&9R86UE
M=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C,Y(&9R86UE=V]R:R].3%,O3DQ3+V-O
M=6YT<FEE<RYP:'`Z,C,W"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H
M<#HQ,3,*;7-G:60@(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP
M:'`Z-CD@;&EB+T)L;V-K+VUE=&%R+G!H<#HW,0IM<V=I9"`B56YI=',B"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W!G<"YP:'`Z-#(Y
M(&9R86UE=V]R:R]#<GEP="]#<GEP="]P9W`N<&AP.C0S,`IM<V=I9"`B56YK
M;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO3F5T7U--4R]335,O8VQI
M8VMA=&5L;%]H='1P+G!H<#HR.3@*;7-G:60@(E5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYE
M=%]335,O4TU3+V-L:6-K871E;&Q?:'1T<"YP:'`Z,CDY"FUS9VED(")5;FMN
M;W=N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HQ-3D*;7-G:60@(E5N
M:VYO=VX@;&]C871I;VX@<')O=FED960N(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT='`N<&AP.C(Y,0HC+"!F
M=7IZ>0IM<V=I9"`B56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"XB"FUS
M9W-T<B`BN^>_Z\#:P,RXI[#Z(+[/R*.XIB#`U+?"Q\^\O+_D(@H*(SH@=&5M
M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C4X
M"FUS9VED(")5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N="(*;7-G<W1R("+'
M]L#G(+_DO-*_H2"XM<6I(,&FL,4B"@HC.B!F<F%M97=O<FLO261E;G1I='DO
M261E;G1I='DN<&AP.C(Y-@IM<V=I9"`B56YN86UE9"(*;7-G<W1R("+`S+BG
M(+[XP+TB"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG
M+FIS.C4Y"FUS9VED("(B"B)5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@
M86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@(@HB
M<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A
M;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H("(*(G-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N(@IM
M<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7W1A
M8FQE7VQA;F<N:G,Z.#(*;7-G:60@(E5N<V5T(&-O;&]R(@IM<V=S='(@(KOV
ML?(@P::PQ2(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z
M-C@V(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3(V"B,Z(&9R
M86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z.3,R"FUS9VED(")5;G-U
M<'!O<G1E9"!%>'1E;G-I;VXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U!E
M<FUS+U!E<FUS+U5)+G!H<#HQ.3<@=&5M<&QA=&5S+V%D;6EN+W5S97(O;&ES
M="YI;F,Z,S,*(RP@9G5Z>GD*;7-G:60@(E5P9&%T92(*;7-G<W1R("+`S\#:
M(@H*(SH@=&5M<&QA=&5S+V%D;6EN+W5S97(O=7!D871E+FEN8SHR.0HC+"!F
M=7IZ>2P@<&AP+69O<FUA=`IM<V=I9"`B57!D871E("5S(@IM<V=S='(@(L#/
MP-HB"@HC.B!T96UP;&%T97,O861M:6XO=7-E<B]U<&1A=&4N:6YC.C<V"B,L
M(&9U>GIY"FUS9VED(")5<&1A=&4@=7-E<B(*;7-G<W1R("*[Y[_KP-H@P]^P
MH2(*"B,Z(&%D;6EN+V=R;W5P<RYP:'`Z,30T(&%D;6EN+W!E<FUS+V5D:70N
M<&AP.C$P,B!S97)V:6-E<R]S:&%R97,O961I="YP:'`Z,C,P"B,L(&9U>GIY
M+"!P:'`M9F]R;6%T"FUS9VED(")5<&1A=&5D(%PB)7-<(BXB"FUS9W-T<B`B
MN^>_Z\#:(,/?L*$B"@HC.B!A9&UI;B]S971U<"]S8W)I<'1S+G!H<#HX,PIM
M<V=I9"`B57!G<F%D92!S8W)I<'0@9&5L971E9"XB"FUS9W-T<B`B(@H*(SH@
M861M:6XO<V5T=7`O:6YD97@N<&AP.C$W."!F<F%M97=O<FLO54DO54DO5F%R
M4F5N9&5R97(O:'1M;"YP:'`Z,3DY"FUS9VED(")5<&QO860B"FUS9W-T<B`B
M(@H*(SH@861M:6XO<V5T=7`O:6YD97@N<&AP.C$X-@IM<V=I9"`B57!L;V%D
M960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N
M(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A
M7VQI<W1T>7!E7VQA;F<N:G,Z,C`*;7-G:60@(E5P<&5R(&QA=&EN(&QE='1E
M<G,B"FUS9W-T<B`BMO/&OK[N(+3KN:[`VB(*"B,Z('1E;7!L871E<R]J879A
M<V-R:7!T+VAT;6QA<F5A7VQI<W1T>7!E7VQA;F<N:G,Z,3@*;7-G:60@(E5P
M<&5R(')O;6%N(&YU;6)E<G,B"FUS9W-T<B`BM\ZXMB"TZ[FNP-H@O/W`VB(*
M"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C0Q(&9R86UE=V]R:R].
M3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C,X"B,Z(&9R86UE=V]R:R].3%,O3DQ3
M+T=E;TE0+G!H<#HQ,3,*;7-G:60@(E5R=6=U87DB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`Z-#4*
M(RP@9G5Z>GDL('!H<"UF;W)M870*;7-G:60@(E5S92!#=7)R96YT.B`E<R(*
M;7-G<W1R("+']L#G(+VZQ;C`SR(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]S;7,R96UA:6Q?:'1T<"YP:'`Z-3,X"FUS9VED(")5<V4@4U-,(@IM<V=S
M='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ,C0*;7-G:60@(E5S
M92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V
M97(N(@IM<V=S='(@(B(*"B,Z('1E;7!L871E<R]A9&UI;B]G<F]U<',O961I
M="YI;F,Z,C$*(RP@9G5Z>GD*;7-G:60@(E5S97(B"FUS9W-T<B`BN^>_Z\#:
MN.TB"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O4F5G:7-T<GDN<&AP.C<R
M,PHC+"!P:'`M9F]R;6%T"FUS9VED(")5<V5R("5S(&ES(&YO="!A=71H;W)I
M<V5D(&9O<B`E<RXB"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z,C`S
M"B,L(&9U>GIY"FUS9VED(")5<V5R($%D;6EN:7-T<F%T:6]N(@IM<V=S='(@
M(DAO<F1E(+OGO^O`VB"P_+BN(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S
M+U5)+G!H<#HR-3$*;7-G:60@(E5S97(@3W!T:6]N<R(*;7-G<W1R("*[Y[_K
MP-H@O+'%P[OGQ]<B"@HC.B!S:6=N=7`N<&AP.C8R"B,L(&9U>GIY"FUS9VED
M(")5<V5R(%)E9VES=')A=&EO;B(*;7-G<W1R(")(;W)D92"[Y[_KP-H@L/RX
MKB(*"B,Z('-I9VYU<"YP:'`Z,C(*;7-G:60@(E5S97(@4F5G:7-T<F%T:6]N
M(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N(@IM<V=S='(@(B(*
M"B,Z(&QI8B]";&]C:R]A8V-O=6YT+G!H<#HT-CD*;7-G:60@(E5S97(@86-C
M;W5N="!N;W0@9F]U;F0B"FUS9W-T<B`B(@H*(SH@861M:6XO=7-E<BYP:'`Z
M,S4@861M:6XO<V5T=7`O:6YD97@N<&AP.C$W.0HC.B!F<F%M97=O<FLO3F5T
M7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4S-@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O=F]D869O;F5I=&%L>5]S;71P+G!H<#HY.`HC.B!F<F%M
M97=O<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HQ.3@*(SH@
M9G)A;65W;W)K+TYE=%]335,O4TU3+W=I;E]H='1P+G!H<#HQ-3`@<V5R=FEC
M97,O<F5S971P87-S=V]R9"YP:'`Z,S,*(SH@=&5M<&QA=&5S+VQO9VEN+VQO
M9VEN+FEN8SHW,B!T96UP;&%T97,O861M:6XO=7-E<B]A<'!R;W9E+FEN8SHQ
M,@IM<V=I9"`B57-E<FYA;64B"FUS9W-T<B`BN^>_Z\#:N.TB"@HC.B!F<F%M
M97=O<FLO075T:"]!=71H+U-I9VYU<"YP:'`Z,3(T"B,L(&9U>GIY+"!P:'`M
M9F]R;6%T"FUS9VED(")5<V5R;F%M92!<(B5S7"(@86QR96%D>2!E>&ES=',N
M(@IM<V=S='(@(KC>P,_'U"!<(B5S7"*PH2#`S+G,(+OGO^O!W\#4M,^TV2XB
M"@HC.B!T96UP;&%T97,O<G!C<W5M+W)P8W-U;2YI;F,Z.#<*(RP@9G5Z>GD*
M;7-G:60@(E5S97)N86UE.B(*;7-G<W1R("*[Y[_KP-JX[2(*"B,Z('1E;7!L
M871E<R]L;V=I;B]M;V)I;&4N:6YC.C@*(RP@9G5Z>GD*;7-G:60@(E5S97)N
M86UE.B`B"FUS9W-T<B`BN^>_Z\#:N.TB"@HC.B!T96UP;&%T97,O861M:6XO
M=7-E<B]L:7-T+FEN8SHR"FUS9VED(")5<V5R<R!I;B!T:&4@<WES=&5M.B(*
M;7-G<W1R("*]P[VZQ=O`QR"[Y[_KP-HZ(@H*(SH@9G)A;65W;W)K+TY,4R].
M3%,O=&QD+G!H<#HR-#(@9G)A;65W;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H
M<#HR,SD*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP.C$Q-`IM<V=I
M9"`B57IB96MI<W1A;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO5D93+U9&
M4R]F:6QE+G!H<#HQ-C,@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,C4U
M"B,L(&9U>GIY"FUS9VED(")61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+B(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV(+[XO<"T
MS[39+B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HQ,3@*(RP@9G5Z
M>GD*;7-G:60@(E9A8V%T:6]N(@IM<V=S='(@(KW'Q^`B"@HC.B!F<F%M97=O
M<FLO1F]R;2]&;W)M+G!H<#HX-C8*;7-G:60@(E9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B`B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T
M+T-R>7!T+W-M:6UE+G!H<#HV,S@*;7-G:60@(E9A;&ED:71Y(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]S;7,R96UA:6Q?:'1T<"YP
M:'`Z-3DW"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]C;&EC:V%T96QL7VAT
M='`N<&AP.C(U-0IM<V=I9"`B5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RXB
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z.#4V(&9R
M86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q-S<*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(R-#0@9G)A
M;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C(V-@HC.B!F<F%M97=O<FLO1F]R;2]&
M;W)M+G!H<#HR,S$V(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C(Y,C@*(SH@
M9G)A;65W;W)K+T9O<FTO1F]R;2]4>7!E+W1A8FQE<V5T+G!H<#HU.0IM<V=I
M9"`B5F%L=65S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN
M<&AP.C(Q,#D@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,C$X-@IM<V=I9"`B
M5F%L=65S('1O('-E;&5C="!F<F]M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R].3%,O3DQ3+W1L9"YP:'`Z,C0Y(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT
M<FEE<RYP:'`Z,C0P"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ
M,3<*;7-G:60@(E9A;G5A='4B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VTN<&AP.C(T-`HC+"!F=7IZ>0IM<V=I9"`B5F%R:6%B;&4B
M"FUS9W-T<B`BP::X\2(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z
M,C0U(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0Q"B,Z(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,34*;7-G:60@(E9E;F5Z=65L
M82(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO0W)Y<'0O0W)Y<'0O<VUI;64N
M<&AP.C(Q.`IM<V=I9"`B5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S
M<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP:'`Z-S`P"B,L(&9U
M>GIY"FUS9VED(")697)S:6]N(@IM<V=S='(@(K"SP,X@N-[`SR(*"B,Z(&-O
M;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR,C8*(RP@9G5Z>GD*;7-G:60@(E9E
M<G-I;VX@0V]N=')O;"(*;7-G<W1R("*PL\#.(+C>P,\B"@HC.B!T96UP;&%T
M97,O:F%V87-C<FEP="]H=&UL87)E85]T86)L95]L86YG+FIS.C@S"FUS9VED
M(")697)T:6-A;"!A;&EG;B(*;7-G<W1R("*\]L'W(,&DM\0B"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS.C@T"FUS9VED(")6
M97)T:6-A;"!P861D:6YG(@IM<V=S='(@(KSVP?<@PZ2_\B(*"B,Z('1E;7!L
M871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z.#,*(RP@9G5Z>GD*
M;7-G:60@(E9E<G1I8V%L.B(*;7-G<W1R("*\]L'W(,&DM\0B"@HC.B!L:6(O
M0FQO8VLO=V5A=&AE<F1O=&-O;5]S=')I;F=S+G!H<#HW,`IM<V=I9"`B5F5R
M>2!(:6=H(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP
M:'`Z,C0X(&9R86UE=V]R:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0R"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,38*(RP@9G5Z>GD*;7-G
M:60@(E9I970@3F%M(@IM<V=S='(@(L?*M>7`S+BG(@H*(SH@8V]N9FEG+VYL
M<RYP:'`N9&ES=#HQ.30*;7-G:60@(E9I971N86UE<V4@*%9)4T-)22DB"FUS
M9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O34E-12]#;VYT96YT<RYP:'`Z
M.38R"B,L('!H<"UF;W)M870*;7-G:60@(E9I97<@)7,B"FUS9W-T<B`B)7,@
MNKBQXB(*"B,Z(&QI8B]";&]C:R]I9G)A;64N<&AP.C,*;7-G:60@(E9I97<@
M86X@97AT97)N86P@=V5B('!A9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K
M+TU)344O34E-12]#;VYT96YT<RYP:'`Z.#(Q"B,L(&9U>GIY+"!P:'`M9F]R
M;6%T"FUS9VED(")6:65W(&%S("5S(@IM<V=S='(@(B5S(+JXL>(B"@HC.B!F
M<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-B!F<F%M97=O<FLO3DQ3+TY,
M4R]C;W5N=')I97,N<&AP.C(T,PHC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])
M4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(*;7-G
M<W1R("(B"@HC.B!F<F%M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(T-R!F<F%M
M97=O<FLO3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-`HC.B!F<F%M97=O<FLO
M3DQ3+TY,4R]'96])4"YP:'`Z,3$V"FUS9VED(")6:7)G:6X@27-L86YD<RP@
M52Y3+B(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C(P.0IM
M<V=I9"`B5FES:6)I;&ET>2(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'`Z,C8S"FUS9VED(")6:7-I8FEL:71Y.B`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?
M<VUT<"YP:'`Z.#0*;7-G:60@(E9O9&%F;VYE($ET86QY('9I82!33510(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VUO8FEL92YP:'`Z,S8*;7-G:60@(E=!4DXB"FUS9W-T
M<B`B(@H*(SH@861M:6XO<V5T=7`O<V-R:7!T<RYP:'`Z.#4*(RP@<&AP+69O
M<FUA=`IM<V=I9"`B5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9
M($923TT@)7,N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--
M4R]W:6Y?:'1T<"YP:'`Z,3,S"FUS9VED(")724X@=FEA($A45%`B"FUS9W-T
M<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HR-3`@9G)A;65W
M;W)K+TY,4R].3%,O8V]U;G1R:65S+G!H<#HR-#4*(SH@9G)A;65W;W)K+TY,
M4R].3%,O1V5O25`N<&AP.C$Q-PIM<V=I9"`B5V%L;&ES(&%N9"!&=71U;F$B
M"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC
M871I;VXO3&ES=&5N97(O<W1A='5S+G!H<#HR.0HC.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]H=&UL+G!H<#HR-S(@;&EB+T)L;V-K+V%C8V]U;G0N
M<&AP.C@S"FUS9VED(")787)N:6YG(@IM<V=S='(@(K#FL.TB"@HC.B!T96UP
M;&%T97,O:F%V87-C<FEP="]O<&5N7V-A;&5N9&%R+FIS.C4X"FUS9VED(")7
M92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z
M,CD*;7-G:60@(E=E871H97(@1F]R96-A<W0B"FUS9W-T<B`B(@H*(SH@;&EB
M+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C0R-PIM<V=I9"`B5V5A=&AE<B!D
M871A('!R;W9I9&5D(&)Y(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]&;W)M
M+T9O<FTN<&AP.C@Y,@IM<V=I9"`B5V5A=&AE<BYC;VTB"FUS9W-T<B`B(@H*
M(SH@;&EB+T)L;V-K+V=O;V=L92YP:'`Z,S8*;7-G:60@(E=E8B(*;7-G<W1R
M("(B"@HC.B!C;VYF:6<O<F5G:7-T<GDN<&AP+F1I<W0Z-#,W"FUS9VED(")7
M96(@4VET92(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4X"FUS9VED(")7965K;'DB"FUS9W-T<B`BN,7!
MUB(*"B,Z('-E<G9I8V5S+W!O<G1A;"]M;V)I;&4N<&AP.C(X"FUS9VED(")7
M96QC;VUE(@IM<V=S='(@(LBOO[4B"@HC.B!T96UP;&%T97,O;&]G:6XO;6]B
M:6QE+FEN8SHT('1E;7!L871E<R]L;V=I;B]L;V=I;BYI;F,Z-3<*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B5V5L8V]M92!T;R`E<R(*;7-G<W1R("+(K[^UQ]6T
MS[39(2`E<R#`U+3/M-DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+VUO8FEL92YP
M:'`Z,CD@=&5M<&QA=&5S+W!O<G1A;"]M96YU+FEN8SHR"B,L('!H<"UF;W)M
M870*;7-G:60@(E=E;&-O;64L("5S(@IM<V=S='(@(LBOO[7'U;3/M-DL("5S
M(@H*(SH@8V]N9FEG+VYL<RYP:'`N9&ES=#HQ.34*;7-G:60@(E=E<W1E<FX@
M*$E33RTX.#4Y+3$I(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]N;',N<&AP+F1I
M<W0Z,3DV"FUS9VED(")797-T97)N("A)4T\M.#@U.2TQ-2DB"FUS9W-T<B`B
M(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<#HW."!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP.C(T-@HC.B!F<F%M97=O<FLO3DQ3+TY,
M4R]'96])4"YP:'`Z-S$*;7-G:60@(E=E<W1E<FX@4V%H87)A(@IM<V=S='(@
M(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HT,S<*(RP@<&AP+69O<FUA
M=`IM<V=I9"`B5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A
M9G1E<B!L;V=I;C\B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+V1A=&$O8W-V
M:6YF;RYI;F,Z,30*;7-G:60@(E=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_(@IM<V=S='(@(K&XNM`@N:[`VK3"(+FKOOG`U+3/L>X_(@H*(SH@
M=&5M<&QA=&5S+V1A=&$O8W-V:6YF;RYI;F,Z,3<*;7-G:60@(E=H870@:7,@
M=&AE('%U;W1E(&-H87)A8W1E<C\B"FUS9W-T<B`BP,Z_ZR"ZSLBCM,(@N:N^
M^<#4M,^Q[C\B"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M
M;"YP:'`Z,3`V,0IM<V=I9"`B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(@IM<V=S
M='(@(B(*"B,Z(&QI8B]";&]C:R]M;V]N+G!H<#HR,PIM<V=I9"`B5VAI8V@@
M<&AA<V5S(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HQ
M,S,*;7-G:60@(E=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX-`IM<V=I9"`B5VED=&@B
M"FUS9W-T<B`BL\JZ\2(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C,Q
M,C4*(RP@9G5Z>GD*;7-G:60@(E=I9'1H(&EN($-34R!U;FET<R(*;7-G<W1R
M("*SRKKQ(+3<P*<B"@HC.B!C;VYF:6<O<')E9G,N<&AP+F1I<W0Z,S4W"B,L
M('!H<"UF;W)M870*;7-G:60@(E=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H
M92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.B(*;7-G<W1R
M("(B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E85]L86YG+FIS
M.C$P-@IM<V=I9"`B5VED=&@@;V8@=&AE('1A8FQE(@IM<V=S='(@(L>EP,<@
ML\JZ\2(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N
M:G,Z,3$P"FUS9VED(")7:61T:"!U;FET(@IM<V=S='(@(K/*NO$@M-S`IR(*
M"B,Z('1E;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7VQA;F<N:G,Z,3`U
M"FUS9VED(")7:61T:#HB"FUS9W-T<B`BL\JZ\3HB"@HC.B!C;VYF:6<O<F5G
M:7-T<GDN<&AP+F1I<W0Z-3$S"FUS9VED(")7:6MI(@IM<V=S='(@(B(*"B,Z
M(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M+G!H<#HS,#`@;&EB+T)L;V-K+W=E
M871H97)D;W1C;VU?<W1R:6YG<RYP:'`Z-C4*(RP@9G5Z>GD*;7-G:60@(E=I
M;F0B"FUS9W-T<B`BPZ.QXB(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M
M7W-T<FEN9W,N<&AP.C8V"B,L(&9U>GIY"FUS9VED(")7:6YD($5A<FQY(@IM
M<V=S='(@(L.CL>(B"@HC.B!L:6(O0FQO8VLO;65T87(N<&AP.C@P"FUS9VED
M(")7:6YD('-P965D(&EN(&MN;W1S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C
M:R]M971A<BYP:'`Z,34V"B,L(&9U>GIY"FUS9VED(")7:6YD.B(*;7-G<W1R
M("+#H['B(@H*(SH@;&EB+T)L;V-K+W=E871H97)D;W1C;VTN<&AP.C(T,@HC
M+"!F=7IZ>0IM<V=I9"`B5VEN9#H@(@IM<V=S='(@(L.CL>(B"@HC.B!L:6(O
M0FQO8VLO9F]R='5N92YP:'`Z-C0*(RP@9G5Z>GD*;7-G:60@(E=I<V1O;2(*
M;7-G<W1R("+#H['B(@H*(SH@8V]N9FEG+W)E9VES=')Y+G!H<"YD:7-T.C$Y
M-@IM<V=I9"`B5VES:&QI<W0B"FUS9W-T<B`B(@H*(SH@;&EB+T)L;V-K+V9O
M<G1U;F4N<&AP.C8U"B,L(&9U>GIY"FUS9VED(")7;W)K(@IM<V=S='(@(K;'
MM,(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]V8V%R9"YP:'`Z
M,3(T"B,Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W9C87)D+G!H<#HQ
M-C0*;7-G:60@(E=O<FL@061D<F5S<R(*;7-G<W1R("+!]\#E(,'6O-(Z(@H*
M(SH@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP.C$Y,@IM
M<V=I9"`B5V]R:R!0:&]N92(*;7-G<W1R("+!]\#E(,#\R*VY^,BC(@H*(SH@
M9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP:'`Z,38Y(&9R86UE=V]R:R]&:6QE
M7T-35B]#4U8N<&AP.C(V,@HC+"!P:'`M9F]R;6%T"FUS9VED(")7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N
M9"`E9"XB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T9I;&5?0U-6+T-35BYP
M:'`Z,S`P"B,L('!H<"UF;W)M870*;7-G:60@(E=R;VYG(&YU;6)E<B!O9B!F
M:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB"FUS9W-T<B`B(@H*(SH@
M9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`Z,3$T"B,L('!H<"UF;W)M870*
M;7-G:60@(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I
M;&4N(@IM<V=S='(@(B(*"B,Z(&-O;F9I9R]R96=I<W1R>2YP:'`N9&ES=#HR
M-#,*;7-G:60@(E@M4F5F(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP
M="]#<GEP="]S;6EM92YP:'`Z-3DS"FUS9VED(")8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T
M+W-M:6UE+G!H<#HU.3(*;7-G:60@(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A
M9V4B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.30*;7-G:60@(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA
M;64B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+T-R>7!T+T-R>7!T+W-M:6UE
M+G!H<#HU.34*;7-G:60@(E@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]#<GEP="]#<GEP="]S;6EM92YP
M:'`Z-C@R"FUS9VED(")8-3`Y=C,@97AT96YS:6]N<R(*;7-G<W1R("(B"@HC
M.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT-R!T96UP;&%T97,O9&%T82]D
M871E+FEN8SHT.`HC.B!T96UP;&%T97,O9&%T82]D871E+FEN8SHT.2!T96UP
M;&%T97,O9&%T82]D871E+FEN8SHU,`IM<V=I9"`B65DB"FUS9W-T<B`B65DB
M"@HC.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z-#$S
M"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HT-34*
M(RP@9G5Z>GD*;7-G:60@(EE965DB"FUS9W-T<B`B65DB"@HC.B!F<F%M97=O
M<FLO54DO54DO5F%R4F5N9&5R97(O:'1M;"YP:'`Z,3$P.`IM<V=I9"`B66%H
M;V\A(&UA<"(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO36%I;G1E;F%N8V4O
M36%I;G1E;F%N8V4N<&AP.C4V"FUS9VED(")996%R;'DB"FUS9W-T<B`BN,6S
MXB(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4R(&9R86UE=V]R
M:R].3%,O3DQ3+V-O=6YT<FEE<RYP:'`Z,C0W"B,Z(&9R86UE=V]R:R].3%,O
M3DQ3+T=E;TE0+G!H<#HQ,3<*(RP@9G5Z>GD*;7-G:60@(EEE;65N(@IM<V=S
M='(@(L#0P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E
M<B]H=&UL+G!H<#HY-C,*;7-G:60@(EEE<R(*;7-G<W1R("*_N2(*"B,Z('1E
M;7!L871E<R]M86EN=&5N86YC92]M86EN=&5N86YC92YH=&UL.C4V"FUS9VED
M(")997,L($D@06=R964B"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+VIA=F%S
M8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHU,@IM<V=I9"`B66]U(&%R92!I;B!4
M15A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K
M('1O(%=94TE764<N(@IM<V=S='(@(E1%6%2X\+7EP-2TS[39+B!;/#Y=(+GV
MQK#`NR"TJ;BCN.D@5UE325=91R"X\+7EM\X@M;F^QK"IM,^TV2XB"@HC.B!S
M97)V:6-E<R]P;W)T86PO961I="YP:'`Z.#(*(RP@<&AP+69O<FUA=`IM<V=I
M9"`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&)L;V-K<RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E
M+G!H<#HQ-#$Q"FUS9VED(")9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO261E;G1I='DO261E;G1I='DN<&AP
M.C,P,@IM<V=I9"`B66]U(&-A;B!N;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T
M97(@:6X@>6]U<B!F=6QL(&YA;64N(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]&;W)M+T9O<FTN<&AP.C$X-34@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z
M,3DW-0HC+"!F=7IZ>0IM<V=I9"`B66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+B(*;7-G<W1R("+`W[CXM<@@P,RXWL#/(,'6O-(B
M"@HC.B!F<F%M97=O<FLO1&%T82]$871A+G!H<#HR.3`*(RP@9G5Z>GDL('!H
M<"UF;W)M870*;7-G:60@(B(*(EEO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@
M9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F
M:65L9',@(@HB:6X@)7,N(@IM<V=S='(@(L#3QO?&KK7((,;$P,_`QR"^[K:R
M(,?7N/&UM2!4=7)B8<#'(,?7N/&_H2"XPK#4(+RSP:3'S\'V(+[*OM*]P+3/
MM-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@X"FUS9VED(")9
M;W4@:&%V92!B965N(&QO9V=E9"!O=70N(@IM<V=S='(@(K?.L=>^QK_T(,?/
MO[2]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T9O<FTO1F]R;2YP:'`Z,3(V,0IM
M<V=I9"`B(@HB66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@
M;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R`B"B)F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N(@IM<V=S='(@
M(B(*"B,Z(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP.C$Q.#@*(RP@9G5Z>GD*
M;7-G:60@(EEO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N(@IM<V=S
M='(@(L#?N/BUR"#`S+C>P,\@P=:\TB(*"B,Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O4VEG;G5P+G!H<#HS-PIM<V=I9"`B66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RXB"FUS9W-T<B`B(@H*
M(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HT-38*;7-G:60@(EEO=2!M
M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+B(*;7-G<W1R("(B"@HC.B!T
M96UP;&%T97,O<')O8FQE;2]P<F]B;&5M+FEN8SHQ,0IM<V=I9"`B66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N(@IM<V=S='(@(KFNP:8@NKBP[;RMN*8@NKBS
MN['BP/R_H2#`S+FNP::_H2"TZ\?1(+RSN.W`NR#`U+?"Q]B^WR#'U;3/M-DN
M(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?;&%N9RYJ<SHY
M.`IM<V=I9"`B66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI
M;FL@<&]I;G1S('1O(@IM<V=S='(@(L#,(+BUQ:FPH2"PH;BNQ*&TPB!54DS`
MNR#`U+?"Q]B^WR#'U;3/M-DN(@H*(SH@<V5R=FEC97,O<&]R=&%L+W)P8W-U
M;2YP:'`Z.#`*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"XB"FUS9W-T<B`BN-7`^B"[Z,&FQ](@O<2Z
ML,#:N*8@O+'%P\?8OM\@Q]6TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$Q
M.0HC+"!F=7IZ>0IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="XB"FUS9W-T<B`BN^C!IL?2(+OGO^O`VB#`S+BGP+L@
MP-2WPL?8OM\@Q]6TS[39+B(*"B,Z(&%D;6EN+W5S97(N<&AP.C$P,`IM<V=I
M9"`B66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92XB"FUS
M9W-T<B`BN^C!IL?2(+OGO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+B(*
M"B,Z(&%D;6EN+W5S97(N<&AP.C8R('1E;7!L871E<R]A9&UI;B]U<V5R+W5P
M9&%T92YI;F,Z.`IM<V=I9"`B66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@861D+B(*;7-G<W1R("+#W["AQ](@N^>_Z\#:(,#,N*?`NR#`U+?"
MQ]B^WR#'U;3/M-DN(@H*(SH@861M:6XO=7-E<BYP:'`Z,30V"B,L(&9U>GIY
M"FUS9VED(")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N(@IM<V=S='(@(L/?L*''TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5
MM,^TV2XB"@HC.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP+G!H
M<#HQ,S@*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB"FUS9W-T<B`BO/:]Q<#.P,P@OOB]P+3/M-DN
M(@H*(SH@9G)A;65W;W)K+U!R969S+U!R969S+T-A=&5G;W)Y36%N86=E<BYP
M:'`Z-S$*(RP@9G5Z>GD*;7-G:60@(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T
M96=O<GD@;F%M92XB"FUS9W-T<B`BN^C!IL?2(+OGO^O`VB#`S+BGP+L@P-2W
MPL?8OM\@Q]6TS[39+B(*"B,Z(&9R86UE=V]R:R].971?4TU3+U--4R]V;V1A
M9F]N96ET86QY7W-M='`N<&AP.C<S"FUS9VED(")9;W4@;F5E9"!T;R!P<F]V
M:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]!=71H+T%U=&@N<&AP.CDW-@HC+"!P:'`M9F]R;6%T"FUS9VED
M(")9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A
M9V%I;BXB"FUS9W-T<B`B)7,@O+R\Q\#,(+BXM^&UQ[[ZO<"TS[39+B"TV;W#
M(+?.L=?`SL?/O+R_Y"XB"@HC.B!T96UP;&%T97,O<')O8FQE;2]P<F]B;&5M
M+FEN8SHS.`IM<V=I9"`B66]U<B!%;6%I;"!!9&1R97-S(@IM<V=S='(@(L#,
MN-[`SR#!UKS2.B(*"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HR,3(*;7-G
M:60@(EEO=7(@1G)O;3H@861D<F5S<SHB"FUS9W-T<B`BN-[`SR#!UKS2.B(*
M"B,Z(&-O;F9I9R]P<F5F<RYP:'`N9&ES=#HV-"!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z-S0@8V]N9FEG+W!R969S+G!H<"YD:7-T.C@R"B,Z(&-O;F9I9R]P
M<F5F<RYP:'`N9&ES=#HX.0IM<V=I9"`B66]U<B!);F9O<FUA=&EO;B(*;7-G
M<W1R("+!I+JX(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP:'`Z.3@P"B,L
M('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@(@HB<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@=&5M<&QA=&5S+W!R;V)L96TO
M<')O8FQE;2YI;F,Z,S,*;7-G:60@(EEO=7(@3F%M92(*;7-G<W1R("+`S+BG
M.B(*"B,Z('1E;7!L871E<R]A9&UI;B]U<V5R+VYO861D+FEN8SHU"B,L(&9U
M>GIY"FUS9VED("(B"B)9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O("(*
M(G5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M
M=7-T('5S92!A(&1I9F9E<F5N="`B"B)A=71H96YT:6-A=&EO;B!B86-K96YD
M+B(*;7-G<W1R("(B"B*TY[W%P,<@P,[!]<6LMO/`S+[PQJZPH2"[Y[_KP-JX
MIB##W["AQ](@O/8@OOB]P+3/M-DN(+;'M,(@M-FXI2#`S,"OM\X@N^>_Z\#:
M("(*(L/?L*&QXK3)P+L@N^>_Z\?2(+SV(+[XO<"TS[39+B(*"B,Z('1E;7!L
M871E<R]A9&UI;B]U<V5R+VYO;&ES="YI;F,Z-0IM<V=I9"`B(@HB66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@(@HB:&%S(&)E96X@9&ES86)L960@
M9F]R('-O;64@;W1H97(@<F5A<V]N+B(*;7-G<W1R("(B"B*TY[W%P,<@P,[!
M]<6LMO/`S+[PQJZPH2"[Y[_KP-H@N/&WS[JXL>*XIB#!]K_XQ\_!]B"^RKW`
MM,^TV2X@ML>TPB"TV;BE(,#,P*\B"B*WSB"[Y[_KP-H@N/&WS[JXL>*XIB"[
MY[_KQ](@O/8@OOB]P+3/M-DN(@H*(SH@9G)A;65W;W)K+T%U=&@O075T:"YP
M:'`Z.3@T"B,L('!H<"UF;W)M870*;7-G:60@(B(*(EEO=7(@8G)O=W-E<B!A
M<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F
M('EO=7(@)7,@<V5S<VEO;BX@(@HB5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB"FUS9W-T<B`B(@H*(SH@;&EB+T)L
M;V-K+VEF<F%M92YP:'`Z-3`*;7-G:60@(EEO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@9F5A='5R92XB"FUS9W-T<B`BNNJV\[_LP/JPH2#`
MS""QXK3)P+L@P?:_^,?/P?8@OLJ]P+3/M-DN(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O<')I;G0N:G,Z-#(*(RP@9G5Z>GD*;7-G:60@(B(*(EEO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0("(*(G1O('!R:6YT+B(*;7-G<W1R
M("(B"B*[Y[_KQ\^P[2"PZ+W%(+KJMO._[,#ZM,(@P,Z\XB"_R;S'P+L@P?:_
M^,?/P?8@OLJ]P+3/M-DN(,#.O.+'S['B(,"GQ]B\K;3"(,3!(@HBQJZWT2^_
MR;S'Q;"_S2!0N*8@M*FXH[R\O^0N(@H*(SH@8V]N9FEG+W!R969S+G!H<"YD
M:7-T.C(U-PIM<V=I9"`B66]U<B!C=7)R96YT('1I;64@>F]N93HB"FUS9W-T
M<B`BQ_;`YR"]P["CM.LZ(@H*(SH@<V5R=FEC97,O<')E9G,N<&AP.CDV"B,L
M(&9U>GIY"FUS9VED(")9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@
M8VAA;F=E9"XB"FUS9W-T<B`BL>*ZNR"]Q+JPP-HZ(@H*(SH@8V]N9FEG+W!R
M969S+G!H<"YD:7-T.C$U.`IM<V=I9"`B66]U<B!D969A=6QT(&ED96YT:71Y
M.B(*;7-G<W1R("*QXKJ[(+W$NK#`VCHB"@HC.B!C;VYF:6<O<')E9G,N<&AP
M+F1I<W0Z,C`Q"FUS9VED(")9;W5R(&9U;&P@;F%M93HB"FUS9W-T<B`BP/S#
MO"#`S+BG.B(*"B,Z(&9R86UE=V]R:R]!=71H+T%U=&@N<&AP.C$P,#`*(RP@
M9G5Z>GD*;7-G:60@(EEO=7(@;&]G:6X@:&%S(&5X<&ER960N(@IM<V=S='(@
M(K_)O,?`S"#`^L#EM<>^^KW`M,^TV2XB"@HC.B!S97)V:6-E<R]R97-E='!A
M<W-W;W)D+G!H<#HW-@HC+"!P:'`M9F]R;6%T"FUS9VED(")9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R
M:R]0<F5F<R]0<F5F<R]522YP:'`Z,34T"FUS9VED(")9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN(@IM<V=S='(@(L#,(+R\O,<@M;^^R""_R;S'P,P@P/K`Y;7+M,^T
MV2XB"@HC.B!F<F%M97=O<FLO4')E9G,O4')E9G,O54DN<&AP.C$U-@IM<V=I
M9"`B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+B(*;7-G<W1R("*_
MR;S'P,P@P/K`Y;7'OOJ]P+3/M-DN(@H*(SH@<V5R=FEC97,O<F5S971P87-S
M=V]R9"YP:'`Z-S4*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970B"FUS9W-T<B`B(@H*(SH@<V5R=FEC97,O<F5S971P87-S=V]R9"YP:'`Z
M-SD*;7-G:60@(B(*(EEO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W("(*(G!A
M<W-W;W)D+B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO075T:"]!=71H+G!H
M<#HW,S(*;7-G:60@(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N(@IM<V=S
M='(@(B(*"B,Z('1E;7!L871E<R]R<&-S=6TO<G!C<W5M+FEN8SHU.`HC+"!F
M=7IZ>0IM<V=I9"`B66]U<B!R96UO=&4@<V5R=F5R<SHB"FUS9W-T<B`BN-[`
MSR#!UKS2.B(*"B,Z(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4T(&9R
M86UE=V]R:R].3%,O3DQ3+T=E;TE0+G!H<#HQ,3@*;7-G:60@(EEU9V]S;&%V
M:6$B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TY,4R].3%,O1V5O25`N<&AP
M.C$Q.`HC+"!F=7IZ>0IM<V=I9"`B6F%I<F4B"FUS9W-T<B`BQ\K%S2(*"B,Z
M(&9R86UE=V]R:R].3%,O3DQ3+W1L9"YP:'`Z,C4V(&9R86UE=V]R:R].3%,O
M3DQ3+V-O=6YT<FEE<RYP:'`Z,C0X"B,Z(&9R86UE=V]R:R].3%,O3DQ3+T=E
M;TE0+G!H<#HQ,3@*;7-G:60@(EIA;6)I82(*;7-G<W1R("(B"@HC.B!F<F%M
M97=O<FLO3DQ3+TY,4R]T;&0N<&AP.C(U-R!F<F%M97=O<FLO3DQ3+TY,4R]C
M;W5N=')I97,N<&AP.C(T.0HC.B!F<F%M97=O<FLO3DQ3+TY,4R]'96])4"YP
M:'`Z,3$X"FUS9VED(")::6UB86)W92(*;7-G<W1R("(B"@HC.B!L:6(O0FQO
M8VLO9F]R='5N92YP:'`Z-C8*;7-G:60@(EII<'!Y(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O:&EG:&QI9VAT<75O=&5S
M+G!H<#HQ-S(*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N
M:G,Z,3(*;7-G:60@(EM(:61E(%%U;W1E9"!497AT72(*;7-G<W1R(");P,Z_
MZR"\^['BL>)=(@H*(SH@<V5R=FEC97,O<')O8FQE;2YP:'`Z.#@*;7-G:60@
M(EM0<F]B;&5M(%)E<&]R=%TB"FUS9W-T<B`B6[_`M_D@NKBP[<?/L>)=(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O<75O=&5";&]C:W,N:G,Z,3,*;7-G
M:60@(EM3:&]W(%%U;W1E9"!497AT("TB"FUS9W-T<B`B6\#.O^L@NKBQXB`M
M(@H*(SH@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H:6=H;&EG:'1Q
M=6]T97,N<&AP.C$W,@HC+"!P:'`M9F]R;6%T"FUS9VED(");4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S72(*;7-G<W1R(");P,Z_ZR"ZN+'B("T@)7,@
MP=E=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ.3,*(RP@<&AP
M+69O<FUA=`IM<V=I9"`B6VQI;F4@)7,@;V8@)7-=(@IM<V=S='(@(ENV\\#.
M("5S("\@)7-=(@H*(SH@9G)A;65W;W)K+TAO<F1E+TAO<F1E+G!H<#HQ-30Q
M('1E;7!L871E<R]P;W)T86PO;65N=2YI;F,Z,3$*;7-G:60@(E]!9&UI;FES
M=')A=&EO;B(*;7-G<W1R(")?0;#\N*XB"@HC.B!L:6(O87!I+G!H<#HQ-3<*
M;7-G:60@(E]#3$DB"FUS9W-T<B`B(@H*(SH@;&EB+V%P:2YP:'`Z,30Q"B,L
M(&9U>GIY"FUS9VED(")?1&%T851R964B"FUS9W-T<B`BP,_`VB(*"B,Z('1E
M;7!L871E<R]J879A<V-R:7!T+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHS
M,0IM<V=I9"`B7T1E;&5T92!2;W<B"FUS9W-T<B`B7T3'X"#!]K_R(@H*(SH@
M;&EB+V%P:2YP:'`Z,3,S"FUS9VED(")?1W)O=7!S(@IM<V=S='(@(B(*"B,Z
M(&9R86UE=V]R:R](;W)D92](;W)D92]-96YU+G!H<#HQ-S4*;7-G:60@(E](
M96QP(@IM<V=S='(@(K6UO_*XNR(*"B,Z('1E;7!L871E<R]J879A<V-R:7!T
M+VAT;6QA<F5A7V-O;G1E>'1?;&%N9RYJ<SHR,PIM<V=I9"`B7TEM86=E(%!R
M;W!E<G1I97,N+BXB"FUS9W-T<B`B7TFQU[BR(+S3O+HN+BXB"@HC.B!F<F%M
M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP:'`Z,3DT"B,L(&9U>GIY"FUS9VED
M(")?3&]G(&EN(@IM<V=S='(@(K?.L=?`SB(*"B,Z(&9R86UE=V]R:R](;W)D
M92](;W)D92]-96YU+G!H<#HQ.3`*;7-G:60@(E],;V<@;W5T(@IM<V=S='(@
M(E],M\ZQU[[&O_0B"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]H=&UL87)E
M85]C;VYT97AT7VQA;F<N:G,Z,C0*;7-G:60@(E]-;V1I9GD@3&EN:RXN+B(*
M;7-G<W1R(")?;;BUQ:D@O/;!I"XN+B(*"B,Z(&9R86UE=V]R:R](;W)D92](
M;W)D92]-96YU+G!H<#HQ-C0*;7-G:60@(E]/<'1I;VYS(@IM<V=S='(@(E]/
MO+'%P[OGQ]<B"@HC.B!L:6(O87!I+G!H<#HQ,S<*(RP@9G5Z>GD*;7-G:60@
M(E]097)M:7-S:6]N<R(*;7-G<W1R("+%Y+?0(@H*(SH@=&5M<&QA=&5S+VIA
M=F%S8W)I<'0O:'1M;&%R96%?8V]N=&5X=%]L86YG+FIS.C(V"FUS9VED(")?
M4F5M;W9E($QI;FLN+BXB"FUS9W-T<B`B7W*XM<6I(+OHP:8N+B(*"B,Z(&QI
M8B]A<&DN<&AP.C$R-0HC+"!F=7IZ>0IM<V=I9"`B7U-E='5P(@IM<V=S='(@
M(KC>O</!]B"\L<7#(@H*(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R
M96%?8V]N=&5X=%]L86YG+FIS.C,S"FUS9VED(")?5&%B;&4@4')O<&5R=&EE
M<RXN+B(*;7-G<W1R(")?=,>E(+S3O+HN+BXB"@HC.B!L:6(O87!I+G!H<#HQ
M,CD*(RP@9G5Z>GD*;7-G:60@(E]5<V5R<R(*;7-G<W1R("*[Y[_KP-JX[2(*
M"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3(Q"B,L(&9U>GIY"FUS
M9VED(")A9&1R97-S(&)O;VLB"FUS9W-T<B`BP=:\TK?/(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,S0*(RP@9G5Z>GD*;7-G:60@
M(F%D9')E<W-E92!U;FMN;W=N(@IM<V=S='(@(L'6O-*WSR(*"B,Z(&9R86UE
M=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3$S"B,L(&9U>GIY"FUS9VED(")C86QE
M;F1A<B(*;7-G<W1R("*TWK?"(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S(@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-3@*(RP@9G5Z>GDL('!H<"UF;W)M
M870*;7-G:60@(F-A;&TB"FUS9W-T<B`BP^N\TB(*"B,Z(&9R86UE=V]R:R]-
M24U%+TU)344O365S<V%G92YP:'`Z,34X"FUS9VED(")C86YN;W0@8W)E871E
M(&]U='!U="!F:6QE(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O365S<V%G92YP:'`Z,3,P"FUS9VED(")C86YN;W0@;W!E;B!I;G!U="(*
M;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<#HU.3(*;7-G:60@(F-L:6-K(&AE<F4B"FUS9W-T<B`B(@H*(SH@9G)A;65W
M;W)K+TU)344O34E-12]-97-S86=E+G!H<#HQ,C(*;7-G:60@(F-O;6UA;F0@
M;&EN92!U<V%G92!E<G)O<B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP.C$W.`HC+"!F=7IZ>0IM<V=I9"`B8V]N9FEG
M=7)A=&EO;B!E<G)O<B(*;7-G<W1R("*XWL#/(+RMN?8@P:2ZN+OGQ]<B"@HC
M.B!F<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$U-`IM<V=I9"`B
M8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9R(*;7-G<W1R("(B"@HC.B!F
M<F%M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$R-@IM<V=I9"`B9&%T
M82!F;W)M870@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TU)344O
M34E-12]-97-S86=E+G!H<#HQ.#(*(RP@9G5Z>GD*;7-G:60@(F5N=')Y(&YO
M="!F;W5N9"(*;7-G<W1R("+%Z\'V(+BNO;JSRB`E<\"[*+BF*2##H\"[(+SV
M(+[XO<"TS[39+B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN
M9W,N<&AP.C<Q"FUS9VED(")F86QL:6YG(@IM<V=S='(@(B(*"B,Z(&9R86UE
M=V]R:R]"<F]W<V5R+T)R;W=S97(N<&AP.C@U-0HC+"!F=7IZ>0IM<V=I9"`B
M9FEL92(*;7-G<W1R("+!IKCQ(@H*(SH@;&EB+T)L;V-K+VUE=&%R+G!H<#HQ
M-S0@;&EB+T)L;V-K+VUE=&%R+G!H<#HS-C`@;&EB+T)L;V-K+VUE=&%R+G!H
M<#HS.#8*(RP@<&AP+69O<FUA=`IM<V=I9"`B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(*;7-G<W1R("(B"@HC.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O
M;2YP:'`Z,C4P"B,L(&9U>GIY"FUS9VED(")G=7-T:6YG(@IM<V=S='(@(CB_
M^2(*"B,Z(&9R86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HR
M-#D*;7-G:60@(F@Z(@IM<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]522]522]6
M87)296YD97)E<B]H=&UL+G!H<#HS-3@*;7-G:60@(FAH(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,3,X"FUS9VED
M(")H;W-T(&YA;64@=6YK;F]W;B(*;7-G<W1R("(B"@HC.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4V-0HC.B!F<F%M97=O
M<FLO3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<#HR,C,*;7-G:60@
M(FEM;65D:6%T92(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H
M<#HV-R!A9&UI;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B
M:6YL:6YE(@IM<V=S='(@(K[XP+TB"@HC.B!F<F%M97=O<FLO34E-12]-24U%
M+TUE<W-A9V4N<&AP.C$V,@IM<V=I9"`B:6YP=70O;W5T<'5T(&5R<F]R(@IM
M<V=S='(@(B(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z
M,30V"FUS9VED(")I;G1E<FYA;"!S;V9T=V%R92!E<G)O<B(*;7-G<W1R("(B
M"@HC.B!T96UP;&%T97,O:F%V87-C<FEP="]Q=6]T94)L;V-K<RYJ<SHQ,PIM
M<V=I9"`B;&EN97-=(@IM<V=S='(@(L'972(*"B,Z(&9R86UE=V]R:R]61E-?
M25-/5W)I=&5R+TE33U=R:71E<B]M:VES;V9S+G!H<#HU,PHC+"!P:'`M9F]R
M;6%T"FUS9VED(")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG
M($E33RXB"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E
M<F5R+VAT;6PN<&AP.C,V.0IM<V=I9"`B;6TB"FUS9W-T<B`B(@H*(SH@9G)A
M;65W;W)K+U!R969S+U!R969S+U5)+G!H<#HR.3$@<V5R=FEC97,O<&]R=&%L
M+W-I9&5B87(N<&AP.C$W,`HC.B!S97)V:6-E<R]P;W)T86PO<VED96)A<BYP
M:'`Z,C,R"FUS9VED(")N86UE(@IM<V=S='(@(L#,N*<B"@HC.B!F<F%M97=O
M<FLO4E!#+U)00RYP:'`Z,3(Q"B,L(&9U>GIY"FUS9VED(")N;W0@:6UP;&5M
M96YT960B"FUS9W-T<B`BN^C!IK7'P?8@OLK`NB"XWL#/(@H*(SH@9G)A;65W
M;W)K+T-R>7!T+T-R>7!T+W-M:6UE+G!H<#HQ,C$Y"B,L(&9U>GIY"FUS9VED
M(")N;W0@>65T(&EM<&QE;65N=&5D(@IM<V=S='(@(KOHP::UQ\'V(+[*P+H@
MN-[`SR(*"B,Z(&9R86UE=V]R:R]+;VQA8B]+;VQA8BYP:'`Z.3`U"B,L(&9U
M>GIY"FUS9VED(")N;W1E<&%D(@IM<V=S='(@(L#0P?8@OLK`NB"XWL#/(@H*
M(SH@=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ
M<SHX.`IM<V=I9"`B<&5R8V5N="(*;7-G<W1R("+&V[R^QJXB"@HC.B!F<F%M
M97=O<FLO34E-12]-24U%+TUE<W-A9V4N<&AP.C$W-`HC+"!F=7IZ>0IM<V=I
M9"`B<&5R;6ES<VEO;B!D96YI960B"FUS9W-T<B`BL+/`SB"XWL#/(@H*(SH@
M=&5M<&QA=&5S+VIA=F%S8W)I<'0O:'1M;&%R96%?=&%B;&5?;&%N9RYJ<SHX
M.0IM<V=I9"`B<&EX96QS(@IM<V=S='(@(L?(O+\B"@HC.B!F<F%M97=O<FLO
M34E-12]-24U%+TUE<W-A9V4N<&AP.C$W,`IM<V=I9"`B<F5M;W1E(&5R<F]R
M(&EN('!R;W1O8V]L(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R
M9&]T8V]M7W-T<FEN9W,N<&AP.C<S"B,L(&9U>GIY"FUS9VED(")R:7-I;F<B
M"FUS9W-T<B`BL.:P[2(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,30R"FUS9VED(")S97)V:6-E('5N879A:6QA8FQE(@IM<V=S='(@
M(B(*"B,Z(&%D;6EN+W-E='5P+V-O;F9I9RYP:'`Z.3D*(RP@9G5Z>GD*;7-G
M:60@(G-H;W<@9&EF9F5R96YC97,B"FUS9W-T<B`BN^>_Z\#:(,BOL.8B"@HC
M.B!F<F%M97=O<FLO3F5T7U--4R]335,O<VUS,F5M86EL7VAT='`N<&AP.C4Q
M-`IM<V=I9"`B<VUS,F5M86EL('9I82!(5%10(@IM<V=S='(@(B(*"B,Z(&9R
M86UE=V]R:R]522]522]687)296YD97)E<B]H=&UL+G!H<#HS.#4*;7-G:60@
M(G-S(@IM<V=S='(@(B(*"B,Z(&QI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T
M<FEN9W,N<&AP.C<R"B,L(&9U>GIY"FUS9VED(")S=&5A9'DB"FUS9W-T<B`B
MP-#!]B"^RL"Z(+C>P,\B"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP
M.C,P.0IM<V=I9"`B<W=I=&-H(&]F9B!J879A<V-R:7!T(@IM<V=S='(@(B(*
M"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G92YP:'`Z,34P"FUS9VED
M(")S>7-T96T@97)R;W(B"FUS9W-T<B`B(@H*(SH@9G)A;65W;W)K+TMO;&%B
M+TMO;&%B+G!H<#HY,CD*(RP@9G5Z>GD*;7-G:60@(G1A<VL@;&ES="(*;7-G
M<W1R("*\]KW%L,6ZSB(*"B,Z(&9R86UE=V]R:R]-24U%+TU)344O365S<V%G
M92YP:'`Z,38V"FUS9VED(")T96UP;W)A<GD@9F%I;'5R92(*;7-G<W1R("(B
M"@HC.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP.C,P-0HC+"!F=7IZ>0IM
M<V=I9"`B=')Y(&%G86EN(@IM<V=S='(@(KCPM><@M\ZQU\#.(@H*(SH@861M
M:6XO=7-E<BYP:'`Z,S8@9G)A;65W;W)K+T%U=&@O075T:"]3:6=N=7`N<&AP
M.C(V.0IM<V=I9"`B='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER
M;2(*;7-G<W1R("(B"@HC.B!A9&UI;B]S971U<"]D:69F+G!H<#HV-R!A9&UI
M;B]S971U<"]D:69F+G!H<#HW.0HC+"!F=7IZ>0IM<V=I9"`B=6YI9FEE9"(*
M;7-G<W1R("+`T,'V(+[*P+H@N-[`SR(*"B,Z(&9R86UE=V]R:R]-24U%+TU)
M344O4&%R="YP:'`Z,C<*;7-G:60@(G5N;F%M960B"FUS9W-T<B`BP,RXIR"^
M^,"](@H*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+W-M<S)E;6%I;%]H='1P
M+G!H<#HU-C4*(SH@9G)A;65W;W)K+TYE=%]335,O4TU3+V-L:6-K871E;&Q?
M:'1T<"YP:'`Z,C(S"B,L(&9U>GIY"FUS9VED(")U<V5R('-E;&5C="(*;7-G
M<W1R("*QU,2B*+?\*2"\L<7#(+_`M_DB"@HC.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]V8V%R9"YP:'`Z,S4*;7-G:60@(G9#87)D(@IM<V=S='(@
M(G9#87)D(@H*(SH@9G)A;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN
M<&AP.C(T,0HC+"!F=7IZ>0IM<V=I9"`B=SHB"FUS9W-T<B`BP/RTWCHB"@HC
M.B!L:6(O0FQO8VLO=V5A=&AE<F1O=&-O;2YP:'`Z-@IM<V=I9"`B=V5A=&AE
M<BYC;VTB"FUS9W-T<B`B(@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]K;5]+2```````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P
M,3<W,#(`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V%R7U-9````````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,30Q(#`Q-S<R-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O8V%?15,`````````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$W-C8S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B<U]"00``````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T,2`P,3<V-3<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A7T1+
M````````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S8U,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O9&5?1$4`````````````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$W-C4Q
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]C<U]#6@``````````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T,2`P,3<W,3(`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+V5L7T=2````````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<P,0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O9F%?25(`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@
M,#$W-C<Q`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E;E]54P``````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$T,2`P,3<W,C(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V5S7T53````````````````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<P-P`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DD`````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q-#$@,#$W-C8U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E=%]%
M10``````````````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<V-S(`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+V9R7T92````````````````````````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<P
M-P`@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9VQ?15,`````````````
M````````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q-#$@,#$W-S`R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]H95])3```````````````````````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<V-S$`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VED7TE$````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q
M(#`Q-S8V,0`@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:'5?2%4`````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q-#$@,#$W-S(Q`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQO8V%L92]J85]*4```````````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<V-S0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VES7TE3````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,30Q(#`Q-S<Q-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:71?
M250`````````````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$W-S(Q`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]B9U]"1P``````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<V
M-3$`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VMO7TM2````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,30Q(#`Q-S<Q-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O;'1?3%0`````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$W-S(W`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]M:U]-2P``````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T
M,2`P,3<W,#<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VQV7TQ6````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<S,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O;F)?3D\`````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$W-S`T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N;%].3```````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$T,2`P,3<W,3,`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYN
M7TY/````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<R,``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O<&Q?4$P`````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#$W
M-S$W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]P=%]"4@``````````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$T,2`P,3<W,3<`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W!T7U!4````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<S-P`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O<F]?4D\`````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M-#$@,#$W-S,Q`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R=5]250``
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<W-#4`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&]C86QE+W-K7U-+````````````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-S<R,P`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VQ?4TD`````````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q-#$@,#$W-S(R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S
M=E]310``````````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<W,S``(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+W1R7U12````````````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q
M-S<T,P`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O=6M?54$`````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q-#$@,#$W-S$U`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]Z:%]#3@``````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<W,3(`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&]C86QE+WIH7U17````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,30R(#`Q-S<T-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O+FAT86-C
M97-S````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,38@,3`U,34T,S0Q-#(@,#(P-38T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````$1E;GD@9G)O;2!A;&P*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+WIH7U17+TQ#7TU%4U-!1T53
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,30R(#`R,34S,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M>FA?5%<O:&5L<"YX;6P`````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(U-#`@,3`U,34T,S0Q-#(@,#(Q-#<W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_>&UL('9E<G-I;VX]
M(C$N,"(@96YC;V1I;F<](D))1S4B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO
M8V%L92]Z:%]45R]H96QP+GAM;"QV(#$N,RXQ,"XQ(#(P,#8O,#(O,3`@,30Z
M,#$Z,C,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA
M<GDB(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B('-T
M871E/2)U<'1O9&%T92(^"CQT:71L93ZD2J1FK;:ML3PO=&ET;&4^"B`\<&%R
M83X*(""S;ZW3K;:ML;2CJ-&ITJ:SP_:I\Z=!JKJMJ\))NDNM;KCJL%2A0ZC2
MIG"A0:6FI6FE2,7CI=RE6*9BIT&JNJ:LI?.]8Z2DI=BK9::SM%BKRK=SMFRE
M\Z%#IN:HQK[DI*2G6;%.J-.H[*JZJ,:QH:%!I4Z_[,.OI*2JNJ:SK?ZHQZO=
MO^RHQK:UH4&W<[M$JD&PR*JZL\RW<Z[XKJ>UI;6EH4.FT[-OJ,>Z2ZUNIE"N
MR:1=I5VG=*1&I]:QMJ5<K^"A0<2TIG"V;*7SO&>G0*%!J]BEW[=SJKJFYJC&
MON2HQJ7SM:6UI:%#"B`\+W!A<F$^"B`\<&%R83X*(*;3LV^HQ[I+K6ZJNJ2Z
MKF6E::5(Q?VG0;AGI=&JJ:VQL'2X;:OVMG.FVZ;FIG>QQJ%#J-*F<*%!IT&E
M::5(O^^^W*UNI5ND2JW^I$"HQ[:UI=BH[*1*I&:MMJVQI*2HP['&ID.HY+:V
MI\>A0PH@/"]P87)A/@H@(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B
M(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B('-T871E
M/2)U<'1O9&%T92(^"CQT:71L93[`LZ7.M7NFH;[)Q/VF0SPO=&ET;&4^"B`\
M<&%R83X*(""F8JVVK;&SS*6JP^2JNJ1`L<:YSZ[7NMFLL,"SI<ZU>Z:AOLG$
M_:9#H4/"2;_OI%>ML:JZI?2D0*W3I'"YSZ7<L4ZE:;NTJ?:GUK-TJKJDP;2K
MJ?.DHZ90JKK`LZ7.M7NFH:%#"B`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B
M(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@("`@
M/'1I=&QE/K"^IFZS7:EW.B"Z^\5`.B"P]:;FNOO%0#PO=&ET;&4^"B`@("`\
M<&%R83X*("`@(*3$O^^FN:1`MK6EV*%!IG"J1Z=!I\:QYJ9BM6ZD2JJZIE"N
MR;#UIN:Z^\5`I'6G0*%#"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT
M<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O
M9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^
M"B`@("`\=&ET;&4^L+ZF;K-=J7<Z(+K[Q4`Z(+U4NWNP]:;FNOO%0#PO=&ET
M;&4^"B`@("`\<&%R83X*("`@(*3$O^^FN:1`MK6EV*%!IG"J1Z=!I\:QYJ9B
ML/6FYKK[Q4"D=:=`JV6[W:9!IKB\>*A$IT&JNJ90MTZA0Z=?JVBITJ:SNOO%
M0*1UIT"Q3JGSM6ZD2JOAIMNPRK#UIN:A0PH@("`@/"]P87)A/@H@(#PO96YT
M<GD^"CPO:&5L<#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]45R],0U]-15-304=%4R]H;W)D
M92YM;P``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#,T,3`V,R`Q,#4Q-30S
M-#$T,B`P,C,R-38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````!-!P``'````(0Z``#'"0``['0````````(G```
M#@````F<```/````&)P```T````HG```"````#:<```+````/YP```P```!+
MG```!````%B<```8````79P``!L```!VG```+0```)*<```=````P)P``"0`
M``#>G```*0````.=```9````+9T``"8```!'G0``#````&Z=```D````>YT`
M``\```"@G0``"P```+"=```.````O)T```4```#+G0``*````-&=```(````
M^IT```H````#G@``%0````Z>```2````))X```L````WG@``A0```$.>```.
M````R9X```H```#8G@``#0```..>```.````\9X``!$`````GP``#0```!*?
M```,````()\```T````MGP``!@```#N?``"4````0I\```H```#7GP``#P``
M`.*?```8````\I\```P````+H```#@```!B@```.````)Z````@````VH```
M"0```#^@```N````2:```!H```!XH```,@```).@```X````QJ```%0```#_
MH```40```%2A``!:````IJ$``%<````!H@``-````%FB```)````CJ(```T`
M``"8H@``!P```*:B```*````KJ(```\```"YH@``!0```,FB```&````SZ(`
M`!$```#6H@``"````.BB```)````\:(```D```#[H@``)0````6C```@````
M*Z,``!,```!,HP``$````&"C```/````<:,```H```"!HP```P```(RC```/
M````D*,``!0```"@HP``"0```+6C```-````OZ,``!(```#-HP``&0```."C
M```>````^J,```\````9I```"@```"FD```/````-*0```@```!$I```)```
M`$VD```4````<J0``!8```"'I```"````)ZD``!.````IZ0``"T```#VI```
M&0```"2E```'````/J4```P```!&I0``+````%.E```.````@*4```,```"/
MI0``"P```).E```'````GZ4```<```"GI0``!0```*^E```%````M:4```H`
M``"[I0```P```,:E```7````RJ4```H```#BI0``#P```.VE```.````_:4`
M`!@````,I@``(P```"6F```.````2:8``!0```!8I@``%P```&VF```7````
MA:8``!<```"=I@``$P```+6F```/````R:8```X```#9I@``'P```.BF```=
M````"*<```<````FIP``!@```"ZG```(````-:<```\````^IP``!@```$ZG
M```*````5:<``!,```!@IP``"P```'2G```0````@*<``!4```"1IP``%0``
M`*>G```'````O:<``!````#%IP``!0```-:G```5````W*<``!$```#RIP``
M#`````2H```[````$:@``#@```!-J```"0```(:H```'````D*@``!0```"8
MJ````P```*VH```%````L:@``!````"WJ```"0```,BH```3````TJ@``#D`
M``#FJ```$@```""I```G````,ZD``"P```!;J0``*@```(BI```E````LZD`
M``H```#9J0``!@```.2I```)````ZZD```<```#UJ0``+P```/VI```W````
M+:H``"X```!EJ@``50```)2J```M````ZJH``"T````8JP``/0```$:K```_
M````A*L``"T```#$JP``0````/*K```C````,ZP``",```!7K```0````'NL
M```M````O*P``#,```#JK```)0```!ZM```5````1*T``!D```!:K0``*0``
M`'2M```D````GJT``"@```##K0``$0```.RM```*````_JT```H````)K@``
M$````!2N```6````):X``!8````\K@``!P```%.N```'````6ZX``!0```!C
MK@``"@```'BN```(````@ZX``"<```",K@``"````+2N```'````O:X```<`
M``#%K@``!@```,VN```%````U*X```<```#:K@``!@```.*N```(````Z:X`
M`"D```#RK@``#@```!RO```*````*Z\```0````VKP``!P```#NO```)````
M0Z\```8```!-KP``$0```%2O```'````9J\``!8```!NKP``!````(6O```(
M````BJ\```8```"3KP``#0```)JO```&````J*\``!X```"OKP``$0```,ZO
M```(````X*\```T```#IKP``#````/>O```'````!+````,````,L````P``
M`!"P```7````%+```!,````LL```'0```$"P```(````7K````0```!GL```
M"````&RP```(````=;```$$```!^L```&@```,"P```@````V[```!4```#\
ML```!@```!*Q```&````&;$``!4````@L0``&````#:Q```B````3[$``"X`
M``!RL0``'0```*&Q```A````O[$``%0```#AL0``*0```#:R```*````8+(`
M``<```!KL@``%0```'.R```.````B;(```H```"8L@``#P```*.R```-````
ML[(```\```#!L@``#0```-&R```)````W[(``!0```#IL@``!@```/ZR```8
M````!;,``!T````>LP``$P```#RS```1````4+,``!0```!BLP``!````'>S
M```&````?+,``!0```"#LP``5````)BS``!D````[;,```0```!2M```#@``
M`%>T```%````9K0```4```!LM```&P```'*T```:````CK0``!,```"IM```
M$0```+VT```1````S[0``!P```#AM```*@```/ZT```0````*;4``"$````Z
MM0``!0```%RU```3````8K4```L```!VM0``$@```(*U```*````E;4```\`
M``"@M0``#0```+"U```1````OK4``!,```#0M0``#````.2U```&````\;4`
M``P```#XM0``!@````6V```7````#+8``!`````DM@``$0```#6V```(````
M1[8```4```!0M@``#````%:V```0````8[8```4```!TM@``#0```'JV```&
M````B+8```<```"/M@``#0```)>V```'````I;8```L```"MM@``!P```+FV
M```'````P;8```D```#)M@``"0```-.V```*````W;8``!D```#HM@``/0``
M``*W```=````0+<```P```!>MP``$````&NW```%````?+<``"4```""MP``
M$@```*BW```3````N[<``"L```#/MP``.P```/NW```@````-[@```@```!8
MN```-@```&&X```A````F+@``!````"ZN```"````,NX```,````U+@```0`
M``#AN```#P```.:X```.````]K@```H````%N0``#0```!"Y```?````'KD`
M`!P````^N0``(0```%NY```>````?;D``!D```"<N0``'@```+:Y```=````
MU;D``!L```#SN0``(`````^Z```N````,+H``"8```!?N@``'````(:Z```>
M````H[H``!P```#"N@``)@```-^Z```K````!KL``#,````RNP``)@```&:[
M```K````C;L``#@```"YNP``'0```/*[```5````$+P``"\````FO```(```
M`%:\```2````=[P``"D```"*O```'@```+2\```@````T[P``!(```#TO```
MH@````>]```6````JKT``",```#!O0``*````.6]```I````#KX``"@````X
MO@``'P```&&^```5````@;X``"````"7O@``)0```+B^```H````WKX``"T`
M```'OP``,````#6_``"2````9K\``"$```#YOP``%@```!O````<````,L``
M`"8```!/P```*@```';```!!````H<```$0```#CP```#````"C!```'````
M-<$```<````]P0``!@```$7!```-````3,$``!````!:P0``$@```&O!```3
M````?L$``!(```"2P0``!P```*7!```$````K<$``!````"RP0``#````,/!
M```.````T,$```T```#?P0``#P```.W!```3````_<$```T````1P@``*```
M`!_"```#````2,(```T```!,P@``!@```%K"```1````8<(``!<```!SP@``
M&P```(O"```.````I\(```(```"VP@``20```+G"```%`````\,``!`````)
MPP``#P```!K#```$````*L,```T````OPP``#@```#W#```#````3,,```X`
M``!0PP``"````%_#```/````:,,```\```!XPP``!P```(C#```-````D,,`
M`!````">PP``#0```*_#```+````O<,```8```#)PP``"P```-##```,````
MW,,```H```#IPP``$0```/3#```9````!L0```L````@Q```#0```"S$```B
M````.L0``!L```!=Q```-````'G$```*````KL0``!@```"YQ```&0```-+$
M```6````[,0``"(````#Q0``#0```";%```'````-,4``!0````\Q0``"P``
M`%'%```B````7<4``"\```"`Q0``"P```+#%```)````O,4``!D```#&Q0``
M"P```.#%```7````[,4``!<````$Q@``"0```!S&```6````)L8```\````]
MQ@``&0```$W&```6````9\8```X```!^Q@``&````(W&```(````IL8```T`
M``"OQ@``)@```+W&``!#````Y,8```@````HQP``$@```#''```?````1,<`
M``@```!DQP``"P```&W'```O````><<```X```"IQP``!0```+C'```&````
MOL<```,```#%QP``!P```,G'```$````T<<```H```#6QP``"@```.''```/
M````[,<``!````#\QP``%P````W(```1````)<@``!D````WR```%P```%'(
M```)````:<@```4```!SR```"P```'G(```*````A<@```4```"0R```#0``
M`);(```;````I,@``!<```#`R```%````-C(```)````[<@```X```#WR```
M#0````;)```2````%,D``#@````GR0``(````&#)```(````@<D```X```"*
MR0``>P```)G)```8````%<H``!$````NR@``!P```$#*```%````2,H``!@`
M``!.R@``'@```&?*```;````ALH``!D```"BR@``&P```+S*```3````V,H`
M``<```#LR@``"````/3*```&````_<H```8````$RP``$`````O+```/````
M',L``!`````LRP``#P```#W+```+````3<L```\```!9RP``#````&G+```/
M````=LL```<```"&RP``!@```([+```.````E<L```P```"DRP``#P```+'+
M```(````P<L```@```#*RP``$P```-/+```>````Y\L``"$````&S```(```
M`"C,```9````2<P``!<```!CS```)0```'O,```7````H<P``!8```"YS```
M!````-#,```;````U<P```T```#QS```#````/_,```#````#,T```4````0
MS0``"````!;-```*````'\T```P````JS0``"P```#?-```0````0\T```P`
M``!4S0``!````&'-```3````9LT``!0```!ZS0``#````(_-```)````G,T`
M``X```"FS0``"P```+7-```;````P<T```<```#=S0``!P```.7-```*````
M[<T```T```#XS0``"0````;.```$````$,X```4````5S@```P```!O.```8
M````'\X```H````XS@``!````$/.```F````2,X```X```!OS@``?````'[.
M```5````^\X```4````1SP``!P```!?/```,````'\\```@````LSP``"@``
M`#7/```&````0,\```@```!'SP```@```%#/```&````4\\```8```!:SP``
M%````&'/```-````=L\``!````"$SP``&P```)7/```$````L<\```D```"V
MSP``$````,#/```)````T<\```D```#;SP``!0```.7/```(````Z\\```8`
M``#TSP``&0```/O/```.````%=````<````DT```!P```"S0```%````--``
M``D````ZT```"@```$30```"````3]````8```!2T```"P```%G0```-````
M9=````D```!ST```!@```'W0```2````A-````D```"7T```!P```*'0```4
M````J=```!T```"^T```0@```-S0```E````']$``"4```!%T0``!@```&O1
M```*````<M$```0```!]T0``"0```(+1```(````C-$``!$```"5T0``"0``
M`*?1```&````L=$```T```"XT0``!@```,;1```$````S=$``!X```#2T0``
M!0```/'1```.````]]$```0````&T@``!@````O2```'````$M(``"$````:
MT@``#0```#S2```5````2M(```8```!@T@``!````&?2```1````;-(```8`
M``!^T@``"@```(72```B````D-(```0```"ST@``!0```+C2```=````OM(`
M``0```#<T@``#````.'2```.````[M(```H```#]T@``"`````C3```)````
M$=,```4````;TP``.@```"'3```P````7-,``#4```"-TP``*0```,/3``!'
M````[=,``#@````UU```*0```&[4```_````F-0``"X```#8U```+0````?5
M```?````-=4```\```!5U0``$@```&75```+````>-4``"8```"$U0``*0``
M`*O5```D````U=4``"8```#ZU0``"````"'6```*````*M8```D````UU@``
M!P```#_6```@````1]8``"````!HU@``)@```(G6```*````L-8``!D```"[
MU@``*0```-76```2````_]8```<````2UP``"@```!K7```,````)=<```\`
M```RUP``$````$+7``!`````4]<``'````"4UP``9@````78```.````;-@`
M``D```![V```"@```(78```2````D-@``!,```"CV```#````+?8```&````
MQ-@```\```#+V```$@```-O8```0````[M@``!$```#_V```'````!'9```C
M````+MD``&H```!2V0``#P```+W9```%````S=D``!````#3V0``"0```.39
M```$````[MD```L```#SV0``(````/_9```4````(-H```P````UV@``#```
M`$+:```/````3]H``!4```!?V@``*0```'7:```J````G]H``"8```#*V@``
M)P```/':```I````&=L``"H```!#VP``&0```&[;``!"````B-L``!$```#+
MVP``$@```-W;```3````\-L``!0````$W```#P```!G<```6````*=P``!<`
M``!`W```$````%C<```1````:=P``#0```![W```$P```+#<```2````Q-P`
M`#4```#7W```%`````W=```'````(MT```P````JW0``(````#?=```0````
M6-T``!0```!IW0``$0```'[=```7````D-T``!P```"HW0``$P```,7=```4
M````V=T``!H```#NW0``$0````G>```:````&]X``!X````VW@``&@```%7>
M```3````<-X``!4```"$W@``$0```)K>```7````K-X``!0```#$W@``%P``
M`-G>```5````\=X```D````'WP``$````!'?```9````(M\```0````\WP``
M!P```$'?```+````2=\``!$```!5WP``!@```&??```&````;M\```8```!U
MWP``!0```'S?```'````@M\```<```"*WP``!0```)+?```6````F-\```8`
M``"OWP``!@```+;?```$````O=\```0```#"WP``!P```,??```.````S]\`
M``P```#>WP``#````.O?```-````^-\```H````&X```#@```!'@```%````
M(.```"@````FX```#@```$_@```,````7N````\```!KX```"@```'O@```(
M````AN````D```"/X```*P```)G@```$````Q>````@```#*X```)@```-/@
M```2````^N````\````-X0``!@```!WA```*````).$```<````OX0``"```
M`#?A```@````0.$```D```!AX0``%````&OA```,````@.$```T```"-X0``
M#@```)OA```6````JN$``!$```#!X0``!@```-/A```#````VN$```8```#>
MX0``!P```.7A```$````[>$```L```#RX0``"P```/[A```'````"N(```<`
M```2X@``%@```!KB```-````,>(```T````_X@``"@```$WB```0````6.(`
M``\```!IX@``$0```'GB```7````B^(```H```"CX@``$0```*[B```(````
MP.(```0```#)X@``#P```,[B```Z````WN(```4````9XP``'@```!_C```.
M````/N,``!````!-XP``"P```%[C```,````:N,```D```!WXP``!P```('C
M```*````B>,```D```"4XP``#@```)[C```0````K>,``!L```"^XP``&```
M`-KC```:````\^,```H````.Y```"0```!GD```*````(^0```P````NY```
M#P```#OD```(````2^0```8```!4Y```!P```%OD```%````8^0```L```!I
MY```1P```'7D```-````O>0```D```#+Y```!````-7D```#````VN0``!,`
M``#>Y```$P```/+D```3````!N4```H````:Y0```@```"7E```$````*.4`
M`"4````MY0```P```%/E```%````5^4``"H```!=Y0``"@```(CE```%````
MD^4```0```"9Y0``"@```)[E```-````J>4```8```"WY0``"````+[E```(
M````Q^4```0```#0Y0``!0```-7E``!H````V^4```D```!$Y@``#````$[F
M```%````6^8```8```!AY@``&P```&CF```O````A.8``!````"TY@``"@``
M`,7F```/````T.8```H```#@Y@``"0```.OF```3````]>8``!L````)YP``
M&````"7G```7````/N<``!\```!6YP``#@```';G```#````A><```<```")
MYP``"````)'G```'````FN<```H```"BYP``"P```*WG```'````N><``%$`
M``#!YP``$````!/H```,````).@``!H````QZ```2@```$SH```9````E^@`
M``8```"QZ```&@```+CH```E````T^@```8```#YZ```!@````#I```?````
M!^D```8````GZ0``"0```"[I```8````..D``!<```!1Z0``*````&GI```&
M````DND```T```"9Z0``(@```*?I``!7````RND``!,````BZ@``(P```#;J
M```3````6NH```(```!NZ@``"P```''J```(````?>H```T```"&Z@``"@``
M`)3J```'````G^H``!0```"GZ@``!@```+SJ```(````P^H```X```#,Z@``
M!P```-OJ```*````X^H```L```#NZ@``,@```/KJ```'````+>L```P````U
MZP``#0```$+K```,````4.L```D```!=ZP``"0```&?K```*````<>L```<`
M``!\ZP``"0```(3K```'````CNL```H```"6ZP``&P```*'K```2````O>L`
M``H```#0ZP``%@```-OK```)````\NL``!````#\ZP``!P````WL```2````
M%>P```0````H[```!P```"WL```%````->P```4````[[```"P```$'L```4
M````3>P``!$```!B[```&@```'3L```6````C^P``!0```"F[```%P```+OL
M```8````T^P``!P```#L[```&0````GM```'````(^T```4````K[0``#0``
M`#'M```,````/^T``!$```!,[0``"````%[M```7````9^T```L```!_[0``
M#````(OM```?````F.T``!H```"X[0``$P```-/M```$````Y^T```H```#L
M[0``!````/?M```,````_.T```4````)[@``"0````_N```%````&>X```<`
M```?[@``!0```"?N```$````+>X```(````R[@``.````#7N```L````;NX`
M`!(```";[@``*0```*[N```R````V.X```H````+[P``+````!;O```N````
M0^\``#,```!R[P``,P```*;O```X````VN\```\````3\```&````"/P```0
M````//````\```!-\```$P```%WP```5````<?```!0```"'\```$@```)SP
M```4````K_```"T```#$\```+0```/+P```Q````(/$``"X```!2\0``+P``
M`('Q```L````L?$``&(```#>\0``$P```$'R```-````5?(```@```!C\@``
M%P```&SR```(````A/(```P```"-\@``*P```)KR```A````QO(``!H```#H
M\@``"0````/S``!%````#?,``$$```!3\P``!````)7S```3````FO,``!0`
M``"N\P``#@```,/S```3````TO,``!@```#F\P``!@```/_S```)````!O0`
M``H````0]```#P```!OT```0````*_0```<````\]```#@```$3T```%````
M4_0``!L```!9]```"````'7T```&````?O0``!0```"%]```$0```)KT```.
M````K/0``#@```"[]````@```/3T```&````]_0```X```#^]```!0````WU
M```'````$_4```8````;]0``*````"+U```,````2_4``!P```!8]0``!```
M`'7U```I````>O4``!\```"D]0``7````,3U```4````(?8``#X````V]@``
M'P```'7V```0````E?8```<```"F]@``#@```*[V```,````O?8```P```#*
M]@``$P```-?V```*````Z_8``!T```#V]@``&0```!3W```%````+O<``!$`
M```T]P``$0```$;W```D````6/<``!(```!]]P``%0```)#W```2````IO<`
M``X```"Y]P``&0```,CW```(````XO<```D```#K]P``#0```/7W```*````
M`_@```<````.^```#P```!;X```&````)O@```L````M^```&@```#GX```*
M````5/@```<```!?^```"````&?X```%````</@``!\```!V^```!@```);X
M```0````G?@```@```"N^```#0```+?X```(````Q?@``!X```#.^```$@``
M`.WX```L`````/D``!H````M^0``"0```$CY```*````4OD``!4```!=^0``
M!0```'/Y```4````>?D```0```".^0``$````)/Y```&````I/D```<```"K
M^0``'@```+/Y```H````TOD```H```#[^0``'`````;Z```1````(_H```L`
M```U^@``&@```$'Z```4````7/H```0```!Q^@``!````';Z```+````>_H`
M``4```"'^@``!@```(WZ```(````E/H```8```"=^@``&P```*3Z```T````
MP/H``#0```#U^@``(````"K[```I````2_L``"````!U^P``00```);[```:
M````V/L``"@```#S^P``*0```!S\``!0````1OP``"(```"7_```!@```+K\
M```(````P?P```4```#*_```"````-#\```9````V?P``!D```#S_```*@``
M``W]```C````./T``!D```!<_0``+@```';]```T````I?T```@```#:_0``
M%P```./]```*````^_T```<````&_@``(0````[^```0````,/X```X```!!
M_@``"P```%#^```'````7/X``!,```!D_@``"````'C^```+````@?X```H`
M``"-_@``%````)C^```/````K?X``#(```"]_@``"P```/#^```%````_/X`
M``4````"_P``!0````C_```7````#O\```\````F_P``!````#;_```*````
M._\```D```!&_P``"P```%#_```-````7/\```P```!J_P``#@```'?_```%
M````AO\```0```",_P``#0```)'_```R````G_\``$4```#2_P``%P```!@`
M`0`'````,``!`!X````X``$`%````%<``0`%````;``!`!0```!R``$`!@``
M`(<``0`'````C@`!``X```"6``$`*@```*4``0`&````T``!``P```#7``$`
M#0```.0``0`1````\@`!``L````$`0$`-@```!`!`0`*````1P$!`"(```!2
M`0$`"P```'4!`0`/````@0$!`#(```"1`0$`)0```,0!`0`P````Z@$!`#$`
M```;`@$`+0```$T"`0`.````>P(!``4```"*`@$`#@```)`"`0`3````GP(!
M`!(```"S`@$`!P```,8"`0`1````S@(!`!,```#@`@$`!P```/0"`0`4````
M_`(!`!@````1`P$`!P```"H#`0`%````,@,!``P````X`P$`#````$4#`0`2
M````4@,!``0```!E`P$`!P```&H#`0`*````<@,!``L```!]`P$`#````(D#
M`0`.````E@,!``X```"E`P$`!0```+0#`0`%````N@,!`"X```#``P$`)@``
M`.\#`0`C````%@0!``,````Z!`$`$@```#X$`0`&````400!`!X```!8!`$`
M&````'<$`0`E````D`0!``T```"V!`$`"0```,0$`0`#````S@0!``<```#2
M!`$`"@```-H$`0`"````Y00!``P```#H!`$`%0```/4$`0`+````"P4!`!D`
M```7!0$`(````#$%`0`2````4@4!``4```!E!0$`"@```&L%`0`5````=@4!
M`!(```",!0$`#````)\%`0`$````K`4!``D```"Q!0$`!P```+L%`0`,````
MPP4!`%(```#0!0$`%P```",&`0`D````.P8!`!(```!@!@$`!P```',&`0`&
M````>P8!``X```""!@$`#````)$&`0`-````G@8!`!4```"L!@$`$@```,(&
M`0`/````U08!`!0```#E!@$`"@```/H&`0`;````!0<!`!`````A!P$`"P``
M`#('`0!I````/@<!`!H```"H!P$`%P```,,'`0`G````VP<!`!H````#"`$`
M%P```!X(`0`;````-@@!`!D```!2"`$`'P```&P(`0`3````C`@!``@```"@
M"`$`!P```*D(`0`(````L0@!``D```"Z"`$`%0```,0(`0`-````V@@!`",`
M``#H"`$`#0````P)`0`3````&@D!``@````N"0$``P```#<)`0!&````.PD!
M`#\```"""0$`-P```,()`0!7````^@D!``4```!2"@$`'P```%@*`0`O````
M>`H!``H```"H"@$`"````+,*`0`-````O`H!`"T```#*"@$`!````/@*`0!/
M````_0H!`"4```!-"P$`"P```',+`0`?````?PL!`!T```"?"P$`)0```+T+
M`0`@````XPL!`"0````$#`$`(````"D,`0`+````2@P!``<```!6#`$`#0``
M`%X,`0`,````;`P!`!<```!Y#`$`!@```)$,`0`,````F`P!``<```"E#`$`
M"0```*T,`0`3````MPP!``D```#+#`$`!````-4,`0`0````V@P!``@```#K
M#`$`"````/0,`0`$````_0P!``L````"#0$`#`````X-`0`2````&PT!`!$`
M```N#0$`#````$`-`0`/````30T!``<```!=#0$`#0```&4-`0`4````<PT!
M``X```"(#0$`#````)<-`0`;````I`T!`"P```#`#0$`$P```.T-`0`&````
M`0X!``<````(#@$`$P```!`.`0`%````)`X!``0````J#@$`%P```"\.`0`*
M````1PX!``P```!2#@$`"0```%\.`0`&````:0X!``D```!P#@$`"````'H.
M`0`)````@PX!``H```"-#@$`$0```)@.`0`&````J@X!``X```"Q#@$`#@``
M`,`.`0`-````SPX!``L```#=#@$`'0```.D.`0`+````!P\!``(````3#P$`
M'````!8/`0`'````,P\!``8````[#P$`9````$(/`0`)````IP\!``<```"Q
M#P$`)@```+D/`0`X````X`\!`!H````9$`$`*@```#00`0`[````7Q`!`"@`
M``";$`$`-````,00`0`9````^1`!`!4````3$0$`!0```"D1`0`'````+Q$!
M``@````W$0$`!P```$`1`0`%````2!$!``<```!.$0$`#@```%81`0`)````
M91$!``8```!O$0$`"````'81`0`+````?Q$!``<```"+$0$`"````),1`0`'
M````G!$!`!8```"D$0$`"0```+L1`0`&````Q1$!``L```#,$0$`$````-@1
M`0`&````Z1$!`!P```#P$0$`%`````T2`0`'````(A(!`!$````J$@$`"```
M`#P2`0`.````11(!``@```!4$@$`!0```%T2`0`0````8Q(!`!````!T$@$`
M!@```(42`0`9````C!(!``H```"F$@$`'````+$2`0`'````SA(!``4```#6
M$@$`$````-P2`0`4````[1(!``L````"$P$`#0````X3`0`H````'!,!`!@`
M``!%$P$`%P```%X3`0`$````=A,!``D```![$P$`"@```(43`0`'````D!,!
M``(```"8$P$`#@```)L3`0`(````JA,!`",```"S$P$`.````-<3`0`F````
M$!0!`#$````W%`$`)P```&D4`0!D````D10!`!0```#V%`$`50````L5`0`X
M````814!`$H```":%0$`6P```.45`0`H````018!`#@```!J%@$`*````*,6
M`0`L````S!8!`"8```#Y%@$`&P```"`7`0`^````/!<!`",```![%P$`%P``
M`)\7`0!(````MQ<!`(4`````&`$`,````(88`0`E````MQ@!`$$```#=&`$`
M6P```!\9`0!)````>QD!`#$```#%&0$`'0```/<9`0`8````%1H!`"L````N
M&@$`(0```%H:`0`?````?!H!`"L```"<&@$`(0```,@:`0`G````ZAH!`#H`
M```2&P$`'0```$T;`0`1````:QL!`#,```!]&P$`)0```+$;`0`G````UQL!
M`"````#_&P$`'P```"`<`0`P````0!P!`&D```!Q'`$`,0```-L<`0!!````
M#1T!`#,```!/'0$`)0```(,=`0`]````J1T!`&4```#G'0$`30```$T>`0`O
M````FQX!`"X```#+'@$`,````/H>`0!4````*Q\!`%H```"`'P$`2````-L?
M`0!*````)"`!`#(```!O(`$`+P```*(@`0`L````TB`!`"T```#_(`$`%P``
M`"TA`0`E````12$!`#(```!K(0$`*0```)XA`0`^````R"$!`"(````'(@$`
M4@```"HB`0`E````?2(!``L```"C(@$`L0```*\B`0!%````82,!`"$```"G
M(P$`,````,DC`0`E````^B,!`!P````@)`$`,0```#TD`0`'````;R0!``<`
M``!W)`$`!````'\D`0`-````A"0!``L```"2)`$`#@```)XD`0`+````K20!
M``4```"Y)`$`$````+\D`0`"````T"0!`%D```#3)`$`!0```"TE`0`2````
M,R4!``0```!&)0$`!P```$LE`0`(````4R4!``4```!<)0$``P```&(E`0`0
M````9B4!`!,```!W)0$`#0```(LE`0`"````F24!``<```"<)0$`!@```*0E
M`0`4````JR4!``P```#`)0$`&````,TE`0`&````YB4!`!(```#M)0$`#```
M```F`0`#````#28!``0````1)@$`!@```!8F`0`'````'28!`!\````E)@$`
M-0```$4F`0`N````>R8!`"\```"J)@$`%P```-HF`0`B````\B8!`"4````5
M)P$`(````#LG`0`;````7"<!`!@```!X)P$`)````)$G`0`?````MB<!`!H`
M``#6)P$`(0```/$G`0`@````$R@!`!H````T*`$`,@```$\H`0`:````@B@!
M`"\```"=*`$`*P```,TH`0`?````^2@!`",````9*0$`'P```#TI`0`:````
M72D!`"$```!X*0$`)0```)HI`0`F````P"D!`"4```#G*0$`)`````TJ`0`8
M````,BH!`!T```!+*@$`)````&DJ`0`8````CBH!`"(```"G*@$`+````,HJ
M`0`O````]RH!`!4````G*P$`)0```#TK`0`\````8RL!`!\```"@*P$`(P``
M`,`K`0`?````Y"L!`"`````$+`$`&@```"4L`0`8````0"P!`"8```!9+`$`
M'@```(`L`0`I````GRP!`!X```#)+`$`,0```.@L`0`)````&BT!``P````D
M+0$`%P```#$M`0`O````22T!`"0```!Y+0$`!P```)XM`0`/````IBT!`!0`
M``"V+0$`#@```,LM`0`-````VBT!`"0```#H+0$`!0````TN`0`'````$RX!
M`"(````;+@$`)0```#XN`0`:````9"X!`!T```!_+@$`&@```)TN`0`'````
MN"X!`,<```#`+@$`"P```(@O`0`5````E"\!``8```"J+P$`"0```+$O`0`+
M````NR\!``T```#'+P$`%P```-4O`0`&````[2\!`#,```#T+P$`$P```"@P
M`0`3````/#`!``<```!0,`$`#P```%@P`0`'````:#`!`#(```!P,`$`!```
M`*,P`0`A````J#`!`!,```#*,`$`#````-XP`0`1````ZS`!`#(```#],`$`
M%@```#`Q`0`(````1S$!`!T```!0,0$`"0```&XQ`0`*````>#$!`!0```"#
M,0$`"@```)@Q`0`=````HS$!``@```#!,0$`'P```,HQ`0`(````ZC$!`!H`
M``#S,0$`!@````XR`0`5````%3(!``<````K,@$`"````#,R`0`)````/#(!
M`#\```!&,@$`!P```(8R`0`/````CC(!``X```">,@$`$````*TR`0`)````
MOC(!``D```#(,@$`"````-(R`0`3````VS(!``<```#O,@$`&0```/<R`0`*
M````$3,!`!<````<,P$`%````#0S`0`*````23,!``P```!4,P$`%P```&$S
M`0`$````>3,!`"H```!^,P$`#````*DS`0`1````MC,!``<```#(,P$``@``
M`-`S`0`0````TS,!`!@```#D,P$`"P```/TS`0`#````"30!``@````--`$`
M!@```!8T`0`'````'30!``T````E-`$`"P```#,T`0`4````/S0!`!4```!4
M-`$`#@```&HT`0`O````>30!`"````"I-`$`'````,HT`0`5````YS0!``P`
M``#]-`$`,0````HU`0`%````/#4!`!(```!"-0$`/P```%4U`0`2````E34!
M``H```"H-0$`!@```+,U`0`$````NC4!``0```"_-0$`"@```,0U`0`3````
MSS4!``4```#C-0$`!@```.DU`0`&````\#4!``@```#W-0$`!``````V`0`,
M````!38!``H````2-@$`.0```!TV`0`N````5S8!`!D```"&-@$`'P```*`V
M`0`=````P#8!`!$```#>-@$``@```/`V`0`$````\S8!``H```#X-@$`!@``
M``,W`0`%````"C<!``,````0-P$`#````!0W`0!%````(3<!`#(```!G-P$`
M&@```)HW`0`T````M3<!`"@```#J-P$`4P```!,X`0`9````9S@!`'(```"!
M.`$`(````/0X`0`U````%3D!`"$```!+.0$`10```&TY`0`P````LSD!`"@`
M``#D.0$`*0````TZ`0`F````-SH!`"4```!>.@$`*````(0Z`0`H````K3H!
M`"(```#6.@$`*P```/DZ`0`P````)3L!`!(```!6.P$`$P```&D[`0`0````
M?3L!`'D```"..P$`"0````@\`0"A````$CP!`',```"T/`$`?````"@]`0`K
M````I3T!`%0```#1/0$`%P```"8^`0`G````/CX!`!8```!F/@$`#P```'T^
M`0`7````C3X!`!\```"E/@$`0````,4^`0`?````!C\!`!P````F/P$`40``
M`$,_`0`:````E3\!`!0```"P/P$`"@```,4_`0`%````T#\!``8```#6/P$`
M"````-T_`0`2````YC\!`!````#Y/P$`$P````I``0`=````'D`!``\````\
M0`$`#P```$Q``0`$````7$`!``D```!A0`$`"P```&M``0`'````=T`!``4`
M``!_0`$`%````(5``0`'````FD`!``@```"B0`$`#P```*M``0`(````NT`!
M``P```#$0`$`#P```-%``0`&````X4`!`!0```#H0`$`!@```/U``0`,````
M!$$!``@````100$`&0```!I!`0`1````-$$!``H```!&00$`&````%%!`0`3
M````:D$!`!P```!^00$`$0```)M!`0`/````K4$!``0```"]00$`&0```,)!
M`0`'````W$$!``(```#D00$``@```.=!`0`1````ZD$!``D```#\00$`!@``
M``9"`0`2````#4(!`!<````@0@$`!@```#A"`0`"````/T(!``0```!"0@$`
M#P```$="`0`3````5T(!``<```!K0@$`!P```'-"`0`1````>T(!``8```"-
M0@$`&````)1"`0`&````K4(!`!,```"T0@$`$````,A"`0`2````V4(!``(`
M``#L0@$`!@```.]"`0`,````]D(!``D````#0P$`$0````U#`0`B````'T,!
M``<```!"0P$`!P```$I#`0`+````4D,!``4```!>0P$``@```&1#`0`+````
M9T,!`&$!``!S0P$`"@```-5$`0`,````X$0!``H```#M1`$`!P```/A$`0`'
M`````$4!``<````(10$``@```!!%`0`1````$T4!`!@````E10$`*P```#Y%
M`0`:````:D4!`!T```"%10$`$P```*-%`0`1````MT4!`"D```#)10$`#0``
M`/-%`0`;`````48!`!(````=1@$`"P```#!&`0`'````/$8!``4```!$1@$`
M$@```$I&`0`'````748!``<```!E1@$`"P```&U&`0`)````>48!``L```"#
M1@$`/````(]&`0`)````S$8!``4```#61@$`"@```-Q&`0`/````YT8!``H`
M``#W1@$`"@````)'`0`*````#4<!``H````81P$`!@```"-'`0!9````*D<!
M``<```"$1P$`#````(Q'`0`2````F4<!``H```"L1P$`"0```+='`0`)````
MP4<!``D```#+1P$`!@```-5'`0`=````W$<!`!0```#Z1P$`)0````](`0`M
M````-4@!`$````!C2`$`1````*1(`0!$````Z4@!`$H````N20$`)P```'E)
M`0`(````H4D!``@```"J20$`"````+-)`0`(````O$D!``@```#%20$`"0``
M`,Y)`0`(````V$D!``X```#A20$`!P```/!)`0`&````^$D!``8```#_20$`
M&P````9*`0`;````(DH!``@````^2@$`"@```$=*`0`+````4DH!``0```!>
M2@$`!````&-*`0`*````:$H!``H```!S2@$`"0```'Y*`0`(````B$H!``@`
M``"12@$`$0```)I*`0`0````K$H!``\```"]2@$`"````,U*`0`-````UDH!
M``8```#D2@$`&0```.M*`0`/````!4L!`!`````52P$`"@```"9+`0`S````
M,4L!`"L```!E2P$`&P```)%+`0`$````K4L!``8```"R2P$`(0```+E+`0`$
M````VTL!``0```#@2P$`%````.5+`0`4````^DL!`!0````/3`$`"````"1,
M`0`$````+4P!``D````R3`$`!````#Q,`0`2````04P!``@```!43`$`"```
M`%U,`0`&````9DP!`!8```!M3`$`%P```(1,`0`&````G$P!``X```"C3`$`
M#@```+),`0`0````P4P!`!````#23`$`"````.-,`0`(````[$P!`!T```#U
M3`$`$P```!--`0`5````)TT!`!`````]30$`#P```$Y-`0`3````7DT!``P`
M``!R30$`!````']-`0`5````A$T!`"H```":30$`"````,5-`0`,````SDT!
M``X```#;30$`$@```.I-`0`$````_4T!``@````"3@$`!`````M.`0`7````
M$$X!``H````H3@$`"@```#-.`0`:````/DX!`"0```!93@$`$@```'Y.`0`2
M````D4X!`!8```"D3@$`!````+M.`0`0````P$X!`!````#13@$`"````.).
M`0`/````ZTX!`!L```#[3@$`"````!=/`0`9````($\!`!D````Z3P$`&0``
M`%1/`0`9````;D\!``0```"(3P$`!````(U/`0`4````DD\!`!````"G3P$`
M*@```+A/`0`C````XT\!`"D````'4`$`:P```#%0`0`H````G5`!`"@```#&
M4`$`,0```.]0`0`Q````(5$!`"@```!340$`*0```'Q1`0`<````IE$!`!P`
M``##40$`,0```.!1`0`H````$E(!`"X````[4@$`%````&I2`0`)````?U(!
M``P```")4@$`$````)92`0`-````IU(!``T```"U4@$`"P```,-2`0`5````
MSU(!``0```#E4@$`"````.I2`0`2````\U(!`!@````&4P$`$````!]3`0`.
M````,%,!`!@````_4P$`$P```%A3`0`1````;%,!`!0```!^4P$`!````)-3
M`0`'````F%,!`!````"@4P$`#P```+%3`0`,````P5,!`!````#.4P$`#0``
M`-]3`0`$````[5,!`"$```#R4P$`"````!14`0`(````'50!``0````F5`$`
M$@```"M4`0`$````/E0!``0```!#5`$`"````$A4`0`$````450!`"T```!6
M5`$`!````(14`0`1````B50!``0```";5`$`#0```*!4`0`-````KE0!`!X`
M``"\5`$`&````-M4`0`3````]%0!``@````(50$`&0```!%5`0`0````*U4!
M``@````\50$``P```$55`0`*````254!``\```!450$`$P```&15`0`&````
M>%4!``8```!_50$`$0```(95`0`1````F%4!`"8```"J50$`$0```-%5`0`:
M````XU4!`!(```#^50$`#P```!%6`0`$````(58!``P````F5@$`$@```#-6
M`0`/````1E8!`",```!65@$`$@```'I6`0`:````C58!`#$```"H5@$`&0``
M`-I6`0`3````]%8!``@````(5P$`"@```!%7`0`9````'%<!``@````V5P$`
M"@```#]7`0`+````2E<!``H```!65P$`"P```&%7`0`(````;5<!`!8```!V
M5P$`!````(U7`0`E````DE<!`!$```"X5P$`"````,I7`0`*````TU<!``@`
M``#>5P$`"P```.=7`0`$````\U<!``P```#X5P$`&P````58`0`M````(5@!
M``0```!/6`$`#0```%18`0`,````8E@!``P```!O6`$`$0```'Q8`0`/````
MCE@!``T```">6`$`"````*Q8`0`2````M5@!``T```#(6`$`$@```-98`0`9
M````Z5@!`!4````#60$``@```!E9`0`4````'%D!``@````Q60$`#@```#I9
M`0`*````25D!`!````!460$`!@```&59`0`.````;%D!`!0```![60$`"```
M`)!9`0`$````F5D!``8```">60$``@```*59`0`7````J%D!``H```#`60$`
M"````,M9`0`3````U%D!``0```#H60$`!@```.U9`0`.````]%D!``,````#
M6@$`"`````=:`0`$````$%H!``0````56@$`"````!I:`0`$````(UH!``0`
M```H6@$`$````"U:`0`$````/EH!``0```!#6@$`!````$A:`0`$````35H!
M``0```!26@$`-````%=:`0`-````C%H!``<```":6@$`"````*):`0`,````
MJUH!`#(```"X6@$`"0```.M:`0`*````]5H!`!L`````6P$`*0```!Q;`0`:
M````1EL!``8```!A6P$`'P```&A;`0`4````B%L!``T```"=6P$`!````*M;
M`0`7````L%L!``0```#(6P$`#````,U;`0`$````VEL!`!<```#?6P$`&```
M`/=;`0`5````$%P!`!D````F7`$`%P```$!<`0`7````6%P!`!(```!P7`$`
M%````(-<`0`4````F%P!`!````"M7`$`%@```+Y<`0`B````U5P!`!0```#X
M7`$`$P````U=`0`5````(5T!`!(````W70$`%````$I=`0`6````7UT!`!T`
M``!V70$`%0```)1=`0`7````JET!`!D```#"70$`$@```-Q=`0`2````[UT!
M`!T````"7@$`%0```"!>`0`,````-EX!`!<```!#7@$`$@```%M>`0`6````
M;EX!``P```"%7@$`2P```))>`0`G````WEX!`!(````&7P$`%````!E?`0`4
M````+E\!`!@```!#7P$`#0```%Q?`0`2````:E\!`!,```!]7P$`$0```)%?
M`0`5````HU\!`!D```"Y7P$`%````--?`0!,````Z%\!`!8````U8`$`#@``
M`$Q@`0`2````6V`!`!0```!N8`$`&0```(-@`0`J````G6`!`"T```#(8`$`
M!@```/9@`0`$````_6`!``0````"80$`!`````=A`0`,````#&$!``P````9
M80$`#````"9A`0`,````,V$!``H```!`80$`$@```$MA`0`+````7F$!``@`
M``!J80$`"````'-A`0`(````?&$!``P```"%80$`"````))A`0`,````FV$!
M``H```"H80$`'P```+-A`0`$````TV$!``0```#880$`$0```-UA`0`1````
M[V$!`!<````!8@$`&@```!EB`0`;````-&(!``(```!08@$`50```%-B`0`$
M````J6(!``P```"N8@$`"@```+MB`0`$````QF(!``@```#+8@$`"````-1B
M`0`$````W6(!``H```#B8@$`!@```.UB`0`*````]&(!``@```#_8@$`!```
M``AC`0`(````#6,!``X````68P$`%0```"5C`0`$````.V,!``0```!`8P$`
M"@```$5C`0`(````4&,!``@```!98P$`"````&)C`0`.````:V,!``H```!Z
M8P$`"````(5C`0`2````CF,!``X```"A8P$`(````+!C`0`&````T6,!`!@`
M``#88P$`#@```/%C`0`,`````&0!`!4````-9`$`"````"-D`0`.````+&0!
M``@````[9`$`!````$1D`0`=````260!`!<```!G9`$`!````']D`0`(````
MA&0!`!8```"-9`$`"@```*1D`0`(````KV0!``@```"X9`$`!````,%D`0`1
M````QF0!``@```#89`$`#@```.%D`0`.````\&0!``@```#_9`$`"`````AE
M`0`1````$64!``8````C90$`'````"IE`0`I````1V4!`!,```!Q90$`(P``
M`(5E`0`3````J64!``0```"]90$`!P```,)E`0`<````RF4!``H```#G90$`
M!````/)E`0`(````]V4!``0`````9@$`$@````5F`0`$````&&8!``@````=
M9@$`"````"9F`0`(````+V8!``@````X9@$`#````$%F`0`(````3F8!``X`
M``!79@$`#````&9F`0`$````<V8!``P```!X9@$`%@```(5F`0`'````G&8!
M``@```"D9@$`#````*UF`0`5````NF8!``P```#09@$`$P```-UF`0`(````
M\68!``D```#Z9@$`"0````1G`0`,````#F<!`"H````;9P$`$P```$9G`0`(
M````6F<!``H```!C9P$`/````&YG`0`2````JV<!`!X```"^9P$`%````-UG
M`0`$````\F<!`!0```#W9P$`&P````QH`0`;````*&@!`!8```!$:`$`%P``
M`%MH`0`5````<V@!`!(```"):`$`$P```)QH`0`$````L&@!``T```"U:`$`
M"@```,-H`0`)````SF@!``H```#8:`$`"0```.-H`0`(````[6@!``H```#V
M:`$`"0````%I`0`'````"VD!``0````3:0$`!````!AI`0`*````'6D!``@`
M```H:0$`!@```#%I`0`&````.&D!``@````_:0$`#0```$AI`0`0````5FD!
M`!<```!G:0$`%@```']I`0`0````EFD!`!````"G:0$`&P```+AI`0`0````
MU&D!``P```#E:0$`!````/)I`0`N````]VD!``T````F:@$`"0```#1J`0`$
M````/FH!``0```!#:@$`!````$AJ`0`$````36H!``8```!2:@$`!@```%EJ
M`0`(````8&H!``@```!I:@$`"P```')J`0`3````?FH!`!$```"2:@$`"```
M`*1J`0`(````K6H!``@```"V:@$`"````+]J`0`5````R&H!``8```#>:@$`
M#@```.5J`0`&````]&H!``0```#[:@$`"`````!K`0`(````"6L!``0````2
M:P$``@```!=K`0`.````&FL!``@````I:P$`!````#)K`0`;````-VL!``X`
M``!3:P$`3@```&)K`0`*````L6L!``0```"\:P$`!````,%K`0`(````QFL!
M``0```#/:P$`!@```-1K`0`$````VVL!``@```#@:P$`!@```.EK`0`$````
M\&L!``T```#U:P$`%`````-L`0`:````&&P!`"$````S;`$`&P```%5L`0`&
M````<6P!``(```!X;`$`"````'ML`0`$````A&P!``0```");`$`#````(YL
M`0`%````FVP!``\```"A;`$`$@```+%L`0`0````Q&P!`!8```#5;`$`#@``
M`.QL`0`,````^VP!`!0````(;0$`!````!UM`0`$````(FT!``8````G;0$`
M"P```"YM`0`+````.FT!``0```!&;0$`#0```$MM`0`3````66T!`!0```!M
M;0$`$@```()M`0`(````E6T!`!````">;0$`*0```*]M`0`;````V6T!`!L`
M``#U;0$`!````!%N`0`5````%FX!``L````L;@$`%````#AN`0`(````36X!
M``@```!6;@$`"````%]N`0`/````:&X!`"````!X;@$`#P```)EN`0`,````
MJ6X!`!$```"V;@$`#````,AN`0`)````U6X!``(```#?;@$`!````.)N`0`$
M````YVX!`"$```#L;@$`!@````YO`0`7````%6\!``0````M;P$`!````#)O
M`0`.````-V\!``0```!&;P$`!````$MO`0`1````4&\!``(```!B;P$`!```
M`&5O`0`1````:F\!``(```!\;P$`"````']O`0`&````B&\!``@```"/;P$`
M$P```)AO`0`0````K&\!``4```"];P$`,````,-O`0`>````]&\!`"P````3
M<`$`(0```$!P`0`N````8G`!`"8```"1<`$`(0```+AP`0`Q````VG`!`"$`
M```,<0$`'0```"YQ`0`<````3'$!``8```!I<0$`"````'!Q`0`%````>7$!
M`!8```!_<0$`%0```)9Q`0`-````K'$!`!$```"Z<0$`!````,QQ`0`&````
MT7$!``@```#8<0$`$````.%Q`0`5````\G$!`!4````(<@$`'0```!YR`0`'
M````/'(!`!````!$<@$`(````%5R`0`.````=G(!``X```"%<@$`!@```)1R
M`0`(````FW(!``H```"D<@$`#P```*]R`0`P````OW(!`&D```#P<@$`/@``
M`%IS`0`)````F7,!``@```"C<P$`"0```*QS`0`,````MG,!``T```##<P$`
M"````-%S`0`$````VG,!``T```#?<P$`#````.US`0`)````^G,!``X````$
M=`$`$P```!-T`0`:````)W0!`$8```!"=`$`"````(ET`0`,````DG0!``H`
M``"?=`$`$````*IT`0`$````NW0!``0```#`=`$`#0```,5T`0`0````TW0!
M``@```#D=`$`"````.UT`0`,````]G0!`!`````#=0$`'````!1U`0`<````
M,74!`!@```!.=0$`&````&=U`0`:````@'4!`!H```";=0$`#@```+9U`0`;
M````Q74!`!````#A=0$`$````/)U`0`.`````W8!``X````2=@$`"````"%V
M`0`.````*G8!``X````Y=@$`#````$AV`0`,````578!``\```!B=@$`#0``
M`')V`0`1````@'8!`"$```"2=@$`"0```+1V`0`$````OG8!``8```##=@$`
M&P```,IV`0`0````YG8!``\```#W=@$`#P````=W`0`/````%W<!``X````G
M=P$`#@```#9W`0`-````17<!``L```!3=P$`$````%]W`0`6````<'<!`!,`
M``"'=P$`#0```)MW`0`1````J7<!``T```"[=P$`#P```,EW`0`1````V7<!
M``\```#K=P$`#P```/MW`0`1````"W@!``0````=>`$`"````")X`0`@````
M*W@!``T```!,>`$`$````%IX`0`2````:W@!``@```!^>`$`#P```(=X`0`&
M````EW@!``0```">>`$`#@```*-X`0`0````LG@!``0```##>`$`#````,AX
M`0`2````U7@!``8```#H>`$`#0```.]X`0`$````_7@!``0````">0$`!```
M``=Y`0`$````#'D!``@````1>0$`"````!IY`0`(````(WD!``H````L>0$`
M"@```#=Y`0`,````0GD!`!(```!/>0$`"````&)Y`0`(````:WD!``@```!T
M>0$`"````'UY`0`(````AGD!``@```"/>0$`*````)AY`0`$````P7D!`!,`
M``#&>0$`+0```-IY`0`9````"'H!``T````B>@$`#P```#!Z`0`*````0'H!
M``H```!+>@$`!````%9Z`0`G````6WH!``8```"#>@$`$@```(IZ`0`&````
MG7H!``D```"D>@$`#@```*YZ`0`4````O7H!`!8```#2>@$`$0```.EZ`0`$
M````^WH!``@`````>P$`$`````E[`0`$````&GL!``@````?>P$`!@```"A[
M`0`0````+WL!`!(```!`>P$`'P```%-[`0`:````<WL!``0```".>P$`!```
M`)-[`0`(````F'L!``@```"A>P$`!@```*I[`0`(````L7L!``0```"Z>P$`
M!@```+][`0`&````QGL!``0```#->P$`"0```-)[`0`@````W'L!``0```#]
M>P$`'P````)\`0`*````(GP!``P````M?`$`"````#I\`0`/````0WP!``T`
M``!3?`$`$0```&%\`0`/````<WP!``\```"#?`$`#0```)-\`0`1````H7P!
M`!````"S?`$`$@```,1\`0`6````UWP!``0```#N?`$`$@```/-\`0`)````
M!GT!``H````0?0$`"@```!M]`0`$````)GT!``0````K?0$`!````#!]`0`$
M````-7T!``@````Z?0$`+0```$-]`0`)````<7T!``0```![?0$`!````(!]
M`0`"````A7T!``P```"(?0$`#````)5]`0`,````HGT!`!,```"O?0$``@``
M`,-]`0`(````QGT!`!L```#/?0$``P```.M]`0`,````[WT!`#D```#\?0$`
M%P```#9^`0`$````3GX!``0```!3?@$`"````%A^`0`-````87X!``\```!O
M?@$`$P```']^`0`3````DWX!``L```"G?@$`#@```+-^`0`@````PGX!``H`
M``#C?@$`#0```.Y^`0`$````_'X!``0````!?P$`$@````9_`0`D````&7\!
M`!T````^?P$`%P```%Q_`0`*````='\!`!<```!_?P$`%````)=_`0`/````
MK'\!`!<```"\?P$`&````-1_`0`7````[7\!``P````%@`$`#````!*``0`$
M````'X`!`!(````D@`$`!````#>``0`$````/(`!``D```!!@`$`"@```$N`
M`0`$````5H`!`"X```!;@`$`"P```(J``0`(````EH`!`!,```"?@`$`*P``
M`+.``0`1````WX`!``0```#Q@`$`$@```/:``0`:````"8$!``0````D@0$`
M#P```"F!`0`N````.8$!``0```!H@0$`"0```&V!`0`8````=X$!`!<```"0
M@0$`%````*B!`0`$````O8$!``0```#"@0$`'@```,>!`0`U````YH$!`!``
M```<@@$`'````"V"`0`0````2H(!``8```!;@@$`"````&*"`0`$````:X(!
M``@```!P@@$`"````'F"`0`$````@H(!`!\```"'@@$`#P```*>"`0`/````
MMX(!``8```#'@@$`!````,Z"`0`(````TX(!``0```#<@@$`(P```.&"`0`&
M````!8,!``@````,@P$`"````!6#`0`(````'H,!``0````G@P$`!````"R#
M`0`$````,8,!``0````V@P$`!````#N#`0`$````0(,!`!4```!%@P$`$```
M`%N#`0`$````;(,!``@```!Q@P$`#````'J#`0`(````AX,!`!````"0@P$`
M#@```*&#`0`+````L(,!``0```"\@P$`$@```,&#`0`,````U(,!``X```#A
M@P$`$@```/"#`0`C`````X0!`!4````GA`$`%0```#V$`0`5````4X0!`!$`
M``!IA`$`$0```'N$`0`7````C80!`!,```"EA`$`$0```+F$`0`(````RX0!
M``0```#4A`$`'````-F$`0`(````]H0!``D```#_A`$`!`````F%`0`5````
M#H4!`!0````DA0$`!@```#F%`0`1````0(4!``T```!2A0$`#P```&"%`0`$
M````<(4!``@```!UA0$`!@```'Z%`0`*````A84!``8```"0A0$`%````)>%
M`0`,````K(4!`!(```"YA0$`!````,R%`0`-````T84!``(```#?A0$`&0``
M`.*%`0`:````_(4!``T````7A@$`&@```"6&`0`A````0(8!``D```!BA@$`
M&P```&R&`0`7````B(8!`!P```"@A@$`&P```+V&`0`@````V88!``L```#Z
MA@$`"P````:'`0`*````$H<!``L````=AP$`$````"F'`0`1````.H<!``L`
M``!,AP$`"P```%B'`0`+````9(<!`!L```!PAP$`&P```(R'`0`?````J(<!
M`!P```#(AP$`'0```.6'`0`:`````X@!`$@````>B`$`$P```&>(`0`.````
M>X@!``8```"*B`$`%0```)&(`0`&````IX@!``@```"NB`$`$P```+>(`0`7
M````RX@!`!<```#CB`$`!@```/N(`0`K`````HD!`"T````NB0$``@```%R)
M`0`1````7XD!`!8```!QB0$`&0```(B)`0`&````HHD!`!@```"IB0$`#0``
M`,*)`0`&````T(D!``8```#7B0$`#````-Z)`0`-````ZXD!``8```#YB0$`
M"`````"*`0`&````"8H!`!(````0B@$`!@```".*`0`$````*HH!``8````O
MB@$`"````#:*`0`$````/XH!`!D```!$B@$``@```%Z*`0`$````88H!``H`
M``!FB@$`!@```'&*`0`$````>(H!``8```!]B@$`%P```(2*`0`&````G(H!
M``P```"CB@$`"P```+"*`0`C````O(H!`!,```#@B@$`)@```/2*`0`.````
M&XL!`"T````JBP$`$@```%B+`0`(````:XL!``0```!TBP$`!@```'F+`0`(
M````@(L!``0```")BP$`"````(Z+`0`$````EXL!`!````"<BP$`%````*V+
M`0`$````PHL!``@```#'BP$`"@```-"+`0`-````VXL!`!````#IBP$`#```
M`/J+`0`,````!XP!``P````4C`$`%@```"&,`0`*````.(P!``@```!#C`$`
M"````$R,`0`(````58P!``@```!>C`$`"````&>,`0`&````<(P!``@```!W
MC`$`%````(",`0`*````E8P!``0```"@C`$`$P```*6,`0`,````N8P!`#``
M``#&C`$`#P```/>,`0`A````!XT!`!$````IC0$`!````#N-`0`$````0(T!
M``T```!%C0$`"@```%.-`0`=````7HT!``@```!\C0$`!0```(6-`0`&````
MBXT!``T```"2C0$`!````*"-`0`$````I8T!``0```"JC0$`"@```*^-`0`$
M````NHT!``8```"_C0$`#````,:-`0`3````TXT!``0```#GC0$`$P```.R-
M`0`(`````(X!``0````)C@$`"`````Z.`0`$````%XX!``L````<C@$`!```
M`"B.`0`4````+8X!``0```!"C@$`!````$>.`0`(````3(X!``0```!5C@$`
M$````%J.`0`3````:XX!`!L```!_C@$`%0```)N.`0`5````L8X!`!@```#'
MC@$`)@```.".`0`5````!X\!`!$````=CP$`&@```"^/`0`N````2H\!`!,`
M``!YCP$`#0```(V/`0`$````FX\!``0```"@CP$`$0```*6/`0`(````MX\!
M``@```#`CP$`*P```,F/`0`6````]8\!``X````,D`$`*0```!N0`0`O````
M19`!``0```!UD`$`#````'J0`0`&````AY`!``0```".D`$`$@```).0`0`*
M````II`!``@```"QD`$`"````+J0`0`$````PY`!``@```#(D`$`!````-&0
M`0`(````UI`!``@```#?D`$`#````.B0`0`,````]9`!`!H````"D0$`%@``
M`!V1`0`,````-)$!``0```!!D0$`"````$:1`0`6````3Y$!``8```!FD0$`
M`@```&V1`0`&````<)$!``8```!WD0$`!````'Z1`0`&````@Y$!``8```"*
MD0$`"````)&1`0`$````FI$!``0```"?D0$`"````*21`0`E````K9$!`#(`
M``#3D0$`"`````:2`0`(````#Y(!`!4````8D@$`%0```"Z2`0`*````1)(!
M``H```!/D@$`!````%J2`0`$````7Y(!``H```!DD@$`*````&^2`0`$````
MF)(!``@```"=D@$`"````*:2`0`(````KY(!``8```"XD@$`)P```+^2`0`$
M````YY(!`!0```#LD@$`"@````&3`0`.````#),!`!<````;DP$`$0```#.3
M`0`:````19,!`!<```!@DP$`%0```'B3`0`(````CI,!``0```"7DP$`"```
M`)R3`0`-````I9,!`!````"SDP$`!````,23`0`(````R9,!``X```#2DP$`
M$@```.&3`0`(````]),!``X```#]DP$`!`````R4`0`$````$90!``@````6
ME`$`!@```!^4`0`+````)I0!``0````RE`$`$@```#>4`0`+````2I0!`!``
M``!6E`$`$````&>4`0`&````>)0!``8```!_E`$``@```(:4`0`$````B90!
M``P```".E`$`"````)N4`0`&````I)0!``0```"KE`$`&P```+"4`0`/````
MS)0!``\```#<E`$`%@```.R4`0`.`````Y4!``0````2E0$`"@```!>5`0`*
M````(I4!``0````ME0$`#````#*5`0`&````/Y4!`!<```!&E0$`+````%Z5
M`0`6````BY4!`!D```"BE0$`,P```+R5`0`2````\)4!`!(````#E@$`%0``
M`!:6`0`H````+)8!``H```!5E@$`&P```&"6`0`$````?)8!``D```"!E@$`
M!P```(N6`0`(````DY8!`#@```"<E@$`#P```-66`0`7````Y98!``@```#]
ME@$`!`````:7`0`$````"Y<!``@````0EP$`"````!F7`0`,````(I<!`!0`
M```OEP$`$@```$27`0`.````5Y<!`!8```!FEP$`"````'V7`0`1````AI<!
M``P```"8EP$`!@```*67`0!#````K)<!``T```#PEP$`$0```/Z7`0`5````
M$)@!``T````FF`$`$0```#28`0`7````1I@!`!````!>F`$`#0```&^8`0`,
M````?9@!``@```"*F`$`$@```).8`0`(````II@!``0```"OF`$`+````+28
M`0`$````X9@!`!L```#FF`$`"`````*9`0`/````"YD!``0````;F0$`"```
M`""9`0`H````*9D!`"$```!2F0$`(P```'29`0`Z````F)D!``0```#3F0$`
M#````-B9`0`<````Y9D!`!,````"F@$`!````!::`0`(````&YH!`"$````D
MF@$`!````$::`0`?````2YH!`"````!KF@$`"@```(R:`0`4````EYH!`!4`
M``"LF@$`%@```,*:`0`4````V9H!`!(```#NF@$`%`````&;`0`(````%IL!
M``@````?FP$`"````"B;`0`(````,9L!``H````ZFP$`!````$6;`0`7````
M2IL!``0```!BFP$`!````&>;`0`(````;)L!`!(```!UFP$`!````(B;`0`(
M````C9L!`!,```"6FP$`%0```*J;`0`"````P)L!``0```##FP$`!````,B;
M`0`(````S9L!``@```#6FP$`"@```-^;`0`<````ZIL!`!(````'G`$`!@``
M`!J<`0`,````(9P!``@````NG`$`$P```#><`0`1````2YP!`"P```!=G`$`
M!@```(J<`0`&````D9P!``0```"8G`$`"@```)V<`0`.````J)P!``@```"W
MG`$`#````,"<`0`(````S9P!``@```#6G`$`!@```-^<`0`$````YIP!`!0`
M``#KG`$`!`````"=`0`*````!9T!``@````0G0$``@```!F=`0`$````')T!
M``@````AG0$`!````"J=`0`&````+YT!``8````VG0$`&````#V=`0`*````
M5IT!``8```!AG0$`$0```&B=`0`$````>IT!``0```!_G0$`/P```(2=`0`$
M````Q)T!``0```#)G0$`&0```,Z=`0`E````Z)T!``\````.G@$`&````!Z>
M`0`E````-YX!`!4```!=G@$`&````'.>`0`/````C)X!``\```"<G@$`#```
M`*R>`0`$````N9X!``0```"^G@$`!````,.>`0`"````R)X!``0```#+G@$`
M"0```-">`0`&````VIX!``0```#AG@$`!@```.:>`0`$````[9X!``0```#R
MG@$`$0```/>>`0`$````"9\!`!8````.GP$`%````"6?`0`-````.I\!`!(`
M``!(GP$`#@```%N?`0`,````:I\!`!0```!WGP$`'0```(R?`0`$````JI\!
M``@```"OGP$`!````+B?`0`,````O9\!`!````#*GP$`!````-N?`0`(````
MX)\!``@```#IGP$`!````/*?`0`$````]Y\!`!4```#\GP$`)P```!*@`0`%
M````.J`!``@```!`H`$`"````$F@`0`2````4J`!``0```!EH`$`!@```&J@
M`0`A````<:`!`!````"3H`$`"````*2@`0`$````K:`!``8```"RH`$`"```
M`+F@`0`,````PJ`!``8```#/H`$`#@```-:@`0`/````Y:`!`!@```#UH`$`
M(0````ZA`0`4````,*$!`!P```!%H0$`%@```&*A`0`[````>:$!``8```"U
MH0$`)@```+RA`0`?````XZ$!`"@````#H@$`.@```"RB`0`/````9Z(!`!L`
M``!WH@$`'0```).B`0`=````L:(!`!,```#/H@$`$0```..B`0`9````]:(!
M`!4````/HP$`!@```"6C`0`P````+*,!`&4```!=HP$`'@```,.C`0`/````
MXJ,!`"\```#RHP$`,0```"*D`0`O````5*0!`!4```"$I`$`"````)JD`0`&
M````HZ0!`!D```"JI`$`%P```,2D`0`7````W*0!`!8```#TI`$`$P````NE
M`0`3````'Z4!`!T````SI0$`"````%&E`0`&````6J4!`!\```!AI0$`$P``
M`(&E`0`9````E:4!`!@```"OI0$`#0```,BE`0`1````UJ4!`$(```#HI0$`
M)````"NF`0`E````4*8!`!\```!VI@$`'````):F`0`D````LZ8!`#D```#8
MI@$`+P```!*G`0`7````0J<!`!L```!:IP$`(@```':G`0`X````F:<!`#$`
M``#2IP$`*P````2H`0`I````,*@!`"4```!:J`$`'@```("H`0`>````GZ@!
M`!L```"^J`$`$0```-JH`0`9````[*@!`!L````&J0$`&P```"*I`0`D````
M/JD!``\```!CJ0$`/0```'.I`0`3````L:D!``@```#%J0$`:@```,ZI`0`S
M````.:H!`!,```!MJ@$`+0```(&J`0`7````KZH!``\```#'J@$`)````->J
M`0`"````_*H!``@```#_J@$`!`````BK`0`(````#:L!``@````6JP$`"```
M`!^K`0`+````**L!``0````TJP$`#P```#FK`0`&````2:L!`$L```!0JP$`
M!````)RK`0`+````H:L!``L```"MJP$`!P```+FK`0`$````P:L!``P```#&
MJP$`!````-.K`0`1````V*L!``X```#JJP$`!@```/FK`0`&`````*P!`!(`
M```'K`$`#P```!JL`0`5````*JP!``P```!`K`$`&````$VL`0`/````9JP!
M``X```!VK`$`#````(6L`0`$````DJP!``4```"7K`$`#P```)VL`0`0````
MK:P!`!(```"^K`$`'P```-&L`0`>````\:P!`!\````0K0$`#@```#"M`0`6
M````/ZT!`!D```!6K0$`%````'"M`0`2````A:T!`!(```"8K0$`%P```*NM
M`0`2````PZT!`!(```#6K0$`%P```.FM`0`8`````:X!`!$````:K@$`'0``
M`"RN`0`1````2JX!`!H```!<K@$`$0```'>N`0`2````B:X!`!8```"<K@$`
M%P```+.N`0`2````RZX!`!<```#>K@$`%0```/:N`0`3````#*\!`!`````@
MKP$`$0```#&O`0`2````0Z\!`!<```!6KP$`$@```&ZO`0`2````@:\!``\`
M``"4KP$`)@```*2O`0`I````RZ\!``X```#UKP$`%@````2P`0`G````&[`!
M`!@```!#L`$`%@```%RP`0`>````<[`!`!\```"2L`$`&````+*P`0`3````
MR[`!`!(```#?L`$`%P```/*P`0`B````"K$!`!8````ML0$`(````$2Q`0`$
M````9;$!``@```!JL0$`!````'.Q`0`>````>+$!`!L```"7L0$`!@```+.Q
M`0`.````NK$!`"<```#)L0$`%0```/&Q`0`4````![(!`"0````<L@$`!```
M`$&R`0`&````1K(!`"4```!-L@$`)````'.R`0`/````F+(!`!<```"HL@$`
M$@```,"R`0`&````T[(!`(T```#:L@$`"````&BS`0`.````<;,!``0```"`
MLP$`!P```(6S`0`*````C;,!``L```"8LP$`#P```*2S`0`$````M+,!`",`
M``"YLP$`#````-VS`0`,````ZK,!`!````#WLP$`#@````BT`0`(````%[0!
M`#4````@M`$`!@```%:T`0`?````7;0!``H```!]M`$`"@```(BT`0`*````
MD[0!`!T```">M`$`$````+RT`0`*````S;0!`!<```#8M`$`"P```/"T`0`(
M````_+0!``\````%M0$`%0```!6U`0`1````*[4!``0````]M0$`$@```$*U
M`0`&````5;4!`!@```!<M0$``@```'6U`0`(````>+4!`!(```"!M0$`!```
M`)2U`0`4````F;4!`"0```"NM0$`!````-.U`0`(````V+4!``@```#AM0$`
M"````.JU`0`%````\[4!``8```#YM0$`#P````"V`0`/````$+8!``<````@
MM@$`#````"BV`0`*````-;8!`"8```!`M@$`(P```&>V`0`&````B[8!``@`
M``"2M@$`'0```)NV`0`$````N;8!`!L```"^M@$`#0```-JV`0`1````Z+8!
M``0```#ZM@$`!@```/^V`0`(````!K<!``P````/MP$`$````!RW`0`$````
M+;<!``0````RMP$`!````#>W`0`$````/+<!``D```!!MP$`"````$NW`0`1
M````5+<!`!(```!FMP$`&0```'FW`0`C````D[<!``\```"WMP$`#P```,>W
M`0`6````U[<!``@```#NMP$`(@```/>W`0`$````&K@!`!,````?N`$`(P``
M`#.X`0`(````5[@!``@```!@N`$`!0```&FX`0`(````;[@!``(```!XN`$`
M!@```'NX`0`(````@K@!``4```"+N`$`!@```)&X`0`$````F+@!``@```"=
MN`$`!````*:X`0`*````J[@!``H```"VN`$`.````,&X`0`P````^K@!`!,`
M```KN0$`$P```#^Y`0`5````4[D!``T```!IN0$``@```'>Y`0`"````>KD!
M``P```!]N0$`!````(JY`0`,````C[D!``(```"<N0$`"P```)^Y`0`]````
MJ[D!`!D```#IN0$`"P````.Z`0`A````#[H!`"$````QN@$`)0```%.Z`0`+
M````>;H!`%,```"%N@$`%P```-FZ`0!!````\;H!`"@````SNP$`(0```%R[
M`0`<````?KL!`!4```";NP$`%0```+&[`0`5````Q[L!`!4```#=NP$`%0``
M`/.[`0`3````";P!`!<````=O`$`(@```#6\`0`>````6+P!`!````!WO`$`
M%P```(B\`0`(````H+P!`%,```"IO`$`"````/V\`0!6````!KT!`"T```!=
MO0$`40```(N]`0`;````W;T!`#8```#YO0$`$P```#"^`0`9````1+X!`!,`
M``!>O@$`"0```'*^`0`/````?+X!`!@```",O@$`&P```*6^`0`/````P;X!
M`!(```#1O@$`.@```.2^`0`/````'[\!``\````OOP$`%0```#^_`0`,````
M5;\!``\```!BOP$`$0```'*_`0`*````A+\!``H```"/OP$`"P```)J_`0`2
M````IK\!`!0```"YOP$`!@```,Z_`0`(````U;\!``H```#>OP$`"````.F_
M`0`&````\K\!``8```#YOP$`#0````#``0`&````#L`!``8````5P`$`#0``
M`!S``0`&````*L`!``8````QP`$`#P```#C``0`&````2,`!``T```!/P`$`
M"````%W``0`&````9L`!``8```!MP`$`$````'3``0`,````A<`!``0```"2
MP`$`#@```)?``0`(````IL`!`!(```"OP`$`#````,+``0`*````S\`!``0`
M``#:P`$`$P```-_``0`$````\\`!``,```#XP`$``@```/S``0`2````_\`!
M``0````2P0$`$````!?!`0`-````*,$!``P````VP0$``P```$/!`0`"````
M1\$!``0```!*P0$`"0```$_!`0`)````6<$!``8```!CP0$`!@```&K!`0`(
M````<<$!``0```!ZP0$`$````'_!`0`$````D,$!``P```"5P0$`"````*+!
M`0`3````J\$!``(```"_P0$`!````,+!`0`(````Q\$!``8```#0P0$`#```
M`-?!`0`:````Y,$!``0```#_P0$`!@````3"`0`*````"\(!``4````6P@$`
M!0```!S"`0`0````(L(!``$```!-!0```````/`&``"!!0``300``#L&``#"
M````E@(``*0$``#(!0``-00``)8!````````-@``````````````````````
M``"P`0``?0,``!4$``!C`@``FP````````#M`0``KP0``,T```"X!@``````
M`.`!``!O!```\0````````#5``````````````#D`0```````*,%``!<`0``
M;P8```````!)!P``4P8``/\"````````I`4``!0!````````[P$``$P```"&
M!0``````````````!P````0``/<$``!T`0``(P8``)L&``""!0```````*8&
M``!"!```K@,``#\"``!U`0```P4``/T&``#'`````````.4$``!'`P``)P,`
M`)0!```_!0``(0<``#X"``"Y!@``@@8``'8$``!X!@``3`(```$#``!E````
M@P```/(#``!S`@``:@(```````#8!@``!@,``(D&````````"P```.0&````
M````>04```````#[`@``(0,``.<&```(````J`,```````!O````7@4`````
M`````````````$@&````````H`(````````G!0``M@8``"P$``!,`P``$@(`
M``````#R!````````!X$``"O!0``&P<``-4!```O`@``5`4``,P!````````
M8`(```````#T!@``G`,``&H&``````````````4%`````````````.@%```G
M!@`````````````8``````````````"T`P``Y04``)$"`````````````%$!
M``"J`0``KP8``'H````0!```W00``!P$```'!@``>P,``$0"``"*!```-P0`
M`%D%``"U`@``104``,D`````````^@0```('``"-`0``;P,``-`$```U`0``
M9@```!(&````````OP4``*T&````````E08``,\!``#Y!@``K`$``-P#``!(
M!P``DP(``/P"``#:!```V@,``!8%````````0`(``&\%```W!0``9P8``)``
M``!6`P``R`0``/@%````````$@0````````%`@```````*("```T`P``;```
M``````""`P``_@$```````!9!```A`,```0`````````8P8```````#*````
M`````),$``!\!0``?`````$"``#8!0``,0`````````5!P``(08```````#*
M!```````````````````0@`````````\!```;`4``/\&``"0!0``,`4`````
M``#)`@``804````"``"?!@``-P,```````!1!```+04``(P!```P````````
M`(4%``!#!@``#@4``)$#``#&!@``Q@4``&0!``":!0````````````"Q!@``
M"@0``&(&``#B!````````"8!`````````````/T```#^!0``F@,``.<```!K
M````H0````````!K!@``%08``(0!```B`````````/`#``#L!```;0,``%`#
M`````````````)0&`````````````,(&``#%!@``-0,``*0&```/!0``&`$`
M`"X'`````````@$``.@$````````3`$``)(#``!K!```#@0`````````````
MC00``!D````T`0``ZP,``)<#```)`P``M`$``$@$```'!```5P(```8"``!X
M!0``Y`(``$D```"T!0``908``````````````P```(T"`````````````$0#
M```E`P``+P4`````````````,0<``(\$```#!P``UP```'0$``!5!@``````
M`,0$``!%````]08``&H````*`P``4@,``,`&``#1````-`4```````!A`P``
MZ@(``.X```!?````5P8```````!'`@``/P<``#`"`````````````"0#``",
M!0``<````!<%````````V`0``!`!```V!@``2P,``!(%``"!`P``7```````
M``#Y`0``$P8``!\&````````````````````````?@,``,@"```^`P``````
M`(,"``#<`0``Q`$``!X#``"]````5@```(\"``"F`@``$P,``)<&````````
M2@<``-D%````````0@,```````"W!0``>`$```````#.`@``1@,``)0````_
M````+P8``)H!``#1!```/`4`````````````W@,```8&``!X````A0,``#8$
M``#M`P`````````````3````OP,````````=`@``````````````````%0$`
M`(0&```+!````````'T$``#3!0```````/(%```I!P``;`8``$$$``#[`P``
MWP,``.H$``!!!0``J0(```T'``#C`0```````"H%``#'`P``&0,``+T%``#?
M!@``N04````````R`@``X@(``#4'``#\!@```````/P!```<`@```````'H!
M````````>@,``!X"````````8@4``&D&````````JP4```````#-!0``````
M``````#)`P``#04```````"<`@```````(P#``!V`P``X@$``*8!````````
MTP$```````"%`@```````*T%```)!0````````````#^`````````'$!```/
M````Y08```````#Z`P``N`0```````"]!@````````````"O`P``C@8``.8$
M``"?!```AP(````````@!P````````(%``""!`````````````"0`0``U`8`
M`.$&``"2!@`````````````:`P``T@0``.`````%````(`$``$D&```Y`P``
M\@8``+,&````````(@$``&8%```P!P``@08``!0'````````]P4``#8%``!,
M!0``?P(``)4!``!'!```"0```!T`````````=P```!X&````````_0$``*,"
M````````30$``!0#````````3@$``````````````````"`#````````<00`
M`/("```4!0``(P$```````!U!@``*@(```````#C!`````````````#D!0``
M$`,``)D%````````<04```````#I`0```````)T!````````!P,``%(&```)
M!```BP(```````"X`@````````````!2````"`(``&4"````````&08``"X"
M``!?!@```````#`!``"#!@``,04```````"+!```````````````````M```
M`(T%```1`0``G`4``)T#``"O`0``?@$``"0&```^````<P4``(("``!5`P``
M`````&8#``!<!@``B@8``%$```"@!```H0$```````!V````M00````````=
M!P```````"P!````````IP,`````````````L04``$,!````````'P```,4!
M```4!```U@0``!```````````````!4%``!"!@```````(8"``#V````````
M`.8```#S`````````$`$```@`@```````,(%``"+!@``WP0```````#,`P``
MY@8``*L#```A`@```````&8"````````S08``$4$``#>!```900``'L!```#
M`0``B0$``/,!`````````````+8%````````3`0``+D```#^!```7@8`````
M```]!P`````````````:`0``-P````````"X````,`0``+0"````````[P,`
M````````````K0(`````````````>0````````#'!@``R08``#4&``"\`0``
M`````/H&```L`P``Z@4``,@#``#T!```D`0``'4$````````'P,``,8"``#%
M`P``C@```-<$```M!`````````````#/````^`8``"@%```]`@``-`0`````
M```S````\`$``.(`````````B00```````#0!0``H@0``)`#``"A!@``NP0`
M`"@'``!.`P``=P8```````"V`@``8`,``/0``````````````,0"``#.`P``
M!`<``)$$```<!@``+`(``&`%```<!0``P````$L$```>````F````*L`````
M````M08``````````````````(H!````````RP$````````*````O@$`````
M``#Y`P``J@(``-,&````````60```,L```#B!@```````.<!````````7@$`
M`-D```!*`0``L`0``*D&````````)@,``````````````````(,#````````
M@`4``,,``````````````*`%``!?`P``B`0````````\!@``]@$``/4!````
M````3@0``$H```")!0``YP4``!`%````````4`4```````#\!0``/@4``,P`
M````````00(```````"'````6`4``&$```!?`0``:@4```````#]`P``*0$`
M`'L```!2!```````````````````^P0``"P&````````KP```'H$``#1`P``
M`````.X!```X!@``%@8``/,&``#/!0``P@0``/<!``#W!@```````.P#```\
M`````````.@!```7!@``@`(```````!4`0``<`8```````!:!```W0(``+`#
M``"H!@``$`(``+4#``#6````*0```&D!``"(`P```````*8#````````````
M``````"Q!```K@8````````:!```#0```%L#``!*!```S`0``%<#``"%!```
M[P0``),!``!8`@``G`$``",#````````\`(``%@!````````QP0``#@%``#`
M`P``D08``"8&``#6!0``GP4````````J!@``9`4``$$`````````'`,`````
M``"@`0``!P<``"0%``````````````````#9`@``8P4``.4"```O`P``\P,`
M`.(#``!#````K`8``'$"``!?`@``90,```````#1`0``,@$`````````````
MPP0``,@!````````4P4```````#<````(@,``"@`````````U`(```````#Z
M`0``"0<``'<!``!H`````````````````````````+<"````````0`8``*L$
M``"[!@``,@0```,$````!0``K@```````````````P(``(T#````````ZP(`
M```````%!@``8P$``"@!````````5P0`````````````:`$```````!.````
M"`,``%4%````````*`8```P$``"P!0```````&8$````````,P,``-D&````
M````3@(````````[!```=`(``)<```!S````60$``.`%``!"`@``40,``$4#
M``!`````W0````````!N`0``?`0```L#```1!```S`(``($$```?`0``4P$`
M`)4%`````````````*D````Q`P``?P0``&X$````````JP$``(X#```K````
M.P,``$\#``"7`0``10(````````?!0```````-L"``````````````````!-
M`@``R@8``,$!``">`P``?P```)X```"G!@``4@4```````#@`P``6@```$(!
M```R!0``R@$``)D```#Z!0``N`$``(\```!A`0``#`(``*4#```9!P``````
M`/,"```2!P``Z04``&``````````(0```&8!````````%@,`````````````
M```````````;`P``<@0``'@"``"M!````````$T&```&!0``/04```````!K
M`P``Y0```-H&```9`0``LP(``/\#``"<!```N`4````````$`P``8@0``"4&
M````````?0$``"8$```F!0``,`,``",'``#!!0``"`<`````````````````
M`!@%```H`@``*@<``$@%````````\08``%D#``!5`0``HP$``!L%``"+`0``
MI04`````````````MP``````````````"P4```````!Q!@``N`,``+(%````
M````T@$``+\!````````C`8``-<%````````%````(,$``!*`@``(@8``%0&
M```M`0``.@8``.$%``!@!@``V`$```P%``"6!0``\`````````"3!0``````
M`&X#``"9`0``D`(``(X$``````````````0"````````'P<```````"7`@``
M`````$8$``#Y````=04````````/`0``NP```&H!``"\!0``YP,``$$#``"\
M!@```````&(```#[````X0(``&<%```C!```40(``!L"`````````````!<'
M```!!@``6@(``%P"````````E`(```````!;!0``$P(``"H```"Z!```9`(`
M`#D$``!]````#P0``*<"```Q`0``$P$`````````````K0````X#````````
M?P8````````_!@``(`4``#T#``!`!0``*00``*@$``"H`0``3P$``,\&````
M````4P```(\!``````````````````"C!```J@0`````````````0@4```<!
M``!(`@```````!P```"?`@``S@4``!D"``!R`0`````````````O````5@$`
M`!@$```I`P``7@(``"T"``"0!@``W`(``,X&``````````````\#````````
MH@8``%T&``!4`@``*@,```````!V!0``9````-8"````````VP````X&````
M````;`$``&H$``"]!```U`$```````"I`0``>00``#@#``!8!```>@8``/P$
M``#I````U@8``$8"``#H````N00```````#T`@```0<``!8'````````+0``
M```````D`0``<@```"0```"6````20$```````"=!0``B`(``$\```"(!@``
MLP,``/@```"Z`0``[P```#,%```5`@``XP4```````!H`P``AP,``-`"``#`
M!0``;`(```@$```3!0``'08``/$"``#=`P``TP(``%L!```H`P``.`$``%X`
M``!+!@``6P8```````"2`````````,8```!5!```Z@,``*@"```D`@``````
M`/(!``!.!@```````!@&```K!```````````````````J0,``*,```#V!0``
M`````!T$```]!@``"@8``/X#```!!0``M0```.8%``#(!@``0P4``&,$``"$
M!0``ZP$``.X#``#:````B@,``#`&```$!@```````$<'````````#`<``/$$
M``"_!@``"@4``-H%```W!P``A@````````!D!@```````%4```#?`0``!`0`
M````````````Y0,``#P'````````W08```````!L!```N@(``'P&````````
M`````.<"``````````````````!)!0``Q`4``)\!````````>P4``"L%``!#
M`@``]0(``$$&``!:`P````````````#5!```.`(``"\$``"2!````````'H"
M``#O`@``Z0,``!L!``#"`@``L``````````;!````````.P&````````.`<`
M`/4$``"8!@``#````)L$````````J@,``,\"``#>````T@8``!<$``!7!0``
M(00````````7`P```````'`$````````DP```)("````````V0,````````2
M`P``LP4``#$&``!=`@``+P<``'`"``"G`0``IP4```\&`````````````-@"
M``"L`P``_P```!L&``#G!```_P0``+T!````````@`$``%D&``!K`0``C@4`
M`/H"``!;````5`,``/<#``!$````N0$``#L"``"D`P``<`$```````!E!0``
M&00``.@#````````]`4``,$$```G!```^P$``*\"``#S!0``C@(``)T```!B
M`@``H0(``.P!```8!P``'@<``'(%``#M!```/@8```````!Y!@``70```+L!
M``!,!@``[P8``!,'````````Y@$```````!M!0``,00``&,#```"!@``````
M`#0'```K`P````````````"N`@````````````"^`@``T08``$L!``"+````
M`````$0$````````20,``)D#``"B````-P8``-(#``"]`P``H@,```<```#;
M`0```````#(&```E!0````````8`````````T@(``+D#``#;`P``%0```*@%
M```C`@``#0$```````!'!0```````&@$``",!```@`0`````````````"P<`
M`$8````Z!P``+08``%`&````````.P4``-`&``#O!0``ZP```+L"```^!```
M:`4``$4!``!;!```1@8``+0&``!U`P```````*@```#*`@``704````````7
M````Z@$``%8$``!I!0``V@(``(P"``!C```````````````,!@``O0(`````
M``#5`@``^`0```````#L!0``-0```&T!````````<P,``,X!```B!```<`,`
M`#H`````````O@````````!S`0``U````$$!````````&@(``&<$``"B!0``
M`@```$H&````````D@$``.L$````````H````*4````+!@```````#\!``!W
M`P``7P4``,$"````````6@8``,H%``"(!0``/`(``!T%``"'!```5P``````
M``";`0``R00``-X"````````:@,`````````````<0,``)D&``!A`@``;0(`
M`"````#N!0```````#,'````````K0,``.4!```Y!P``-@,```@%``#$````
M4@(``+8#``#Q`0``S00```````!0`0``-@<````````D!```V0$``,$#``#D
M`P``(0$``%`$``"3`P``U08``%@&``#I!@``S0,``"0'````````````````
M``!$!P``<0`````````Q`@``T@4``#X!``":!```.@4```4'````````U@,`
M`+H&``!$!0``+@8``,P%``";!0```````*`#``!W!0```````%D"``!M!```
M```````````S`0```````,$`````````9P,``((```!5`@``K@0``(,%``"C
M`P``G````"D%``#I`@``I0(``*0"``!-!P``*P$``,`$``"A!0``````````
M``"=`@``#P<``$,'``!(````<@,``,@```!G`0``^`,``*8$```I!@``````
M`/$#````````EP0````````'!0``F`4```````#>!@```````$4&```.`0``
M`````)X%``!``0````````````";`P``$0(``#4%``")````!@$``"X#```"
M`@``1P```)0$```G`0```````,,#``"P!@```````.H&``#8````L0$``"H!
M````````,@```&0$``"I!0``$`<``,H#``!>`P``````````````````H@$`
M```````M`P``.`0``)$``````````````,<!``"R`P``K0$``.T%````````
M4`(``$D"``"N!0``X`8``(8!``!6`@`````````````C!0``HP8``*0!``!*
M!0``VP0``*`&``!4!```A@,``(<%``"?`P``SP0`````````````-P(``.H`
M````````G@(``,D%````````6@$`````````````RP8``*4&````````````
M`#\#```B!0``F@```(4&``!_`0````````````````````````````!'`0``
M`````'P!``"8`@```````"`$``#D`````````!8$```8`@``%@```!0"```7
M`@``A0$``-,$``#\`P``_@8`````````````[`(``````````````````&X`
M```2`0```````-0#``";`@````,```````#?!0``\`4`````````````@0``
M```````\`0``2P```+<$``"&!```O@4``+4!``!<!0``;P(``!P!``#9!```
M``````8'``#Q!0``:P(``+8!````````T0(```D&```^!P```````(\%````
M````2`$``+("``"-`````````.0$````````Z`(``&0#``#X`@```````*L"
M``"*`@```````/`$``![!@```````+X#`````````00``)T$``"E`0``AP$`
M`-4%``#V`@``8@,``%````"F````]@,``,L"``##`@``MP,``/0!``#<!0``
MRP,``&T&````````'@4``"L'```N!`````````````!$!@``````````````
M````7P0``,0&``#@`@```````.P`````````)P```$8'````````X0```"P'
M```@!@``0@<``$\%``!_!0``Q00``)4#````````10<``$P'``"L!0``_@(`
M`*$#``#F`P``?@(``/D$``#7`0``5````+`"`````````````,4%```S!@``
MI````+X&``"J!@``=`````T&``!Y`@``"P(``&@"``##!@``408``/P```".
M`0``4P(``)<%```:!0``GP```",````T`@``>@4``#T!``"$!```.````-X!
M````````;P$``"X`````````^P8``%T#````````#`,``+L%``!I````70$`
M````````````)00``*$$``#7`@``NP,``/T$``"Q`@``#0,``/T"``#N`@``
MW@4````````-!````````)D"````````"`$``%P$````````>0,``(P`````
M``````````H'`````````````'P"``"'!@``:00``&X%``#"`0``````````
M``#W`@``;@(``'("``"<!@``W`0``$`'````````"@(``$8!````````````
M`(\#```````````````````L````-0(``.L&``"I!```-P$``.$$``!I`@``
M4P,``)@$````````XP```,$&```B`@``404``!$%``#H!@``$0<``+8```"8
M`P```````$$'``"T!````````(H```"+!0``S@0``*8%````````808``!$`
M``#$`P``^0(``(0"```F````L@``````````````7`,``#8!``##!0``````
M`/4#`````````````.$#``":!@``0P0```````!T`P``=`8``#8"````````
M@`,``%L"````````%0,```````#0`````````!`&``"G````)P(```,&``"Z
M!0```0$``-$%``">!@``"0(``-L&```S!``````````&``"S`0``<P8``&$$
M````````+@4````````Z`P``0P,``&<"``!/!```#@(``.,"``#N!```SP,`
M`"4"```[`0````````````#2`````````-T!``!^!@``W`8``+$````?`@``
MJP8``,4"``#I!```X@4``!<!``"G!```$@```/4```!>!`````````````"Z
M`````````'L$````````;@8``+\```#U!0``!0$``$H#``"L`````````#T`
M```F!P``QP4``,8$``"(````<P0``"\!``#4!0```````)T&````````````
M`.,#```"`P``$0,```````"Z`P``)P<``+8$````````OP0``"@$``"(`0``
M=P(```````!+!P``0`,``(8&``!=!```#@<``.T````T`````P,``)H"``#&
M`0``?P,```````!+!0``V@$``'T"``#Z````````````````````)@(``'0%
M``"!`@``]@0``!P'``#R````'P0``'@#``"E!````````#P#``")`P``@0$`
M``````"L`@``[@8``+4%```Z`0``K@$```````#_`0```````&`$````````
M```````````B!P``L@0``#\$``"%````200``)4$``"1!0``_04``(`&``#+
M!```MP8``+(!``!E`0``3@4````````-`@``C08``-0$``!6!0``%`8``'T&
M``"J!0``G@0``#L'```Z!```F`$``&L%```%`P``@P$``&(!```Y`@``MP$`
M`!$&``!V!@``````````````````#P(``(0```#7!@``````````````````
M#@```$<&``"*!0``1`$```````#X`0``[0(``"4'``#'`@``"P$``#D!``"+
M`P``^04``)8#``!I`P``D0$```````"4`P``F00```````"/!@```````'@$
M```"!```*@0```````!Y`0``X0$```````!]!0``S0(``'L"````````.P``
M`.8"```Y``````````P!```3!```B0(`````````````;0`````````8`P``
MN0(``,`!``````````````````"\`@``L0,``/,$````````/00``!T!````
M````!`$``-8!````````S0$``-`#````````-`8``)(%``"\!```P@,``'X`
M````````UP,``%(!```)`0``!@0``%<!``!G````K`0```````!U`@``=@$`
M`'`%``#[!0``+`4``,4````M!P``2P(``(````````````````````#5`P``
M4P0``-`!``!/!@``&@8```0%``"\`P``[08``"4!```````````````````I
M`@``5@8``#('```=`P``Q@,```4$``#``@``!P(``"$%``!8`P``ZP4``-\"
M```>`0``]P````````"^!```X`0``$@#```R`P``3P(`````````````?@0`
M``````!@`0```````-@#```S`@````````````"6!@```````,P&````````
ME@0```````"4!0```````),&````````WP```&@&``!^!0``30```!D%````
M````XP8``+P````:````;`,``,D!````````=@(``"4```!U`````````"X!
M``#=!0``"@$````````;````*P(``)X!``!8````&@<``$T#``#3````.@(`
M``````!&!0````$```````!\`P``]@8````````Y!0``E0````````"R!@``
M_P4```````##`0``RP4``+,$`````````````)4"```6`0```````!8"``!F
M!@```````%H%``"J````"`8``,X`````````.08```````#3`P``<@8`````
M````````*P8``+,```""`0``=P0``-L%````````]`,``+\"````("@E<R!D
M87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A
M>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@
M82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B
M(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S
M(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@
M=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M
M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR
M9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD
M("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD
M87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`
M)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3
M971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E
M861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R
M;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU
M=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO
M;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI
M;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R
M($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U
M<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO
M8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A
M<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!
M('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@
M4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3
M34E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-
M($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3
M;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B
M;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A
M=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&
M4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`
M06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U
M<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U
M<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S
M(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S
M97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T
M:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S
M<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I
M;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H
M92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@
M<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO
M;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N
M`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'
M<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES
M="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!
M;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M
M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S
M`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A
M;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R
M960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T
M:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P
M<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`
M07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE
M`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U
M('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E
M;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`
M07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO
M;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T
M92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@
M82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@
M;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L
M:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA
M=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D
M(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D
M($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H
M92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K
M<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!
M8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E
M<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A
M<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@
M:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M
M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U
M=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE
M;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z
M`$%Z97)B86EJ86X`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K
M97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA
M;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"
M87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M
M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N
M("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O
M;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z
M`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA
M`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L
M;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@
M:6YI="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I
M80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E
M('1O(&9I;&4@(B5S(@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E
M<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!2
M97!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H
M;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S
M($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE
M87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@
M3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L
M;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B
M;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L
M96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M
M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N
M>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@
M4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT
M86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL
M93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O
M<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`
M0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD
M('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E
M<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S
M(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E
M<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT(%52
M3"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O
M;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O(')U
M;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R=7,`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$`$13
M3B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N
M9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@0G)O
M=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A=&4@
M<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L
M(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`
M1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G`$1E
M;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L
M971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT97)N
M871E('1E;7!L871E`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$
M96QE=&5D('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I
M;64`1&5N;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$
M971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V
M92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M
M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P
M;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H
M="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I
M<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L
M87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@
M3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I
M<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@
M<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H
M:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V
M92!A;B!A8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I
M=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I
M;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE
M;65N="XN+@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU3
M35,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET
M;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S
M>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R
M<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O
M<F0Z("5S`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%
M=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN
M`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z
M`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%
M>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O
M9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D
M('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T
M('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I
M;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%3
M3"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@
M=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R
M=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@
M4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&:6II`$9I;&4@0V]U;G0Z("5S
M(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@
M3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@
M;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER
M<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S
M(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@
M=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E
M8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E
M='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E
M(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A
M<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&
M;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R
M86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN
M97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H
M92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N
M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E
M;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`
M1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C
M:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA
M;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R
M;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U
M86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T
M8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5%10($%U
M=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`
M2&%Z90!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD
M($ES;&%N9',`2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`
M2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE
M<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO
M7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!
M9&1R97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N
M9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A
M(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE
M<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.
M;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E
M+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO
M;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M
M>&UL)R!02%`@97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E
M871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E
M<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S
M.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT
M86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I
M9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L
M=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S
M("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U
M(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S
M`$AU;F=A<GD`24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!
M4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U
M;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S
M(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D
M($-)1%(@8FQO8VLN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS
M($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A
M;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E
M9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E
M;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H
M92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D
M(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM
M86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R
M>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T
M960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T
M97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@
M86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E
M87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!)
M;F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@
M5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!)
M;G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W
M(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P
M:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B
M969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L
M871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@
M<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!)
M;G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@
M8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P
M:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F
M=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS
M=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!)
M;6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T
M;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT
M(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P
M<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B
M;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@
M9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A
M=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M
M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N
M`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I
M9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN
M=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN
M=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!)
M;G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T
M;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A
M<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N
M`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L
M;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@
M;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&
M:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`
M2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@
M;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`
M2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG
M90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,87<`3&%Y;W5T`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A
M;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,
M:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!2
M86EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,
M:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@
M4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<`3&EN:W,`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI
M<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S
M97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,
M:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI
M80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C
M871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@
M9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@
M96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`
M3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T
M97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3
M+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O
M`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-
M861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN
M`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T
M:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US
M('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G
M;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%R8V@`36%R9VEN`$UA
M<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA
M9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S
M`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET
M:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC
M965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T
M(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA
M>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N
M=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R:69I960@
M4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A=&4@8V]U
M;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N`$UE<W-A9V4@
M='EP90!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE
M=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI
M<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC
M871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I
M;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D
M=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N
M=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO
M<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@
M)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY
M(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P
M`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O
M<"!D;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY
M($%C8V]U;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO
M=70`37EA;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA
M=7)U`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE
M='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE
M='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T
M<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE
M`$YE='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF
M:6-A=&4@='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A
M=&5G;W)Y`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M
M92`H;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S
M<W=O<F0@=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@
M;6%T8V@N`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE
M>'0`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA
M`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T
M82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T
M96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N
M`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO
M(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I
M;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H
M:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO
M(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL
M92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T
M+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`
M3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P
M87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC
M871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D
M+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET
M:"!02T-3(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@
M<V5T+@!.;R!R=6QE<P!.;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E
M<P!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B
M;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N
M="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E
M<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE
M<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE
M`$YO;F4@*'5S92!I;7!L:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R
M9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I
M86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A
M(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O
M<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M
M8F5R`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L
M=6UN<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R
M('5P9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J
M96-T($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9I8V4`3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-3
M3"!E<G)O<CH@0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3
M+TU)344@<&%R="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/
M<&5R871I;F<@4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E
M9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N
M:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@
M=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE
M<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4$5!4CHZ36%I;"!B86-K96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R
M90!01U`@16YC<GEP=&5D($1A=&$`4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE
M9"]%;F-R>7!T960@1&%T80!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`
M4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@
M9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT
M+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT
M97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@
M82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E
M+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X
M="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S
M>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L
M86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H
M:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H
M:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO
M;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS
M:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L
M.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@
M;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R
M>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I
M;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN
M(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!2
M96%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R
M871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A
M=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$
M>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E
M9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T
M92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO
M:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M
M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP
M="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T
M:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@
M=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W
M97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@
M8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`
M4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T
M;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y
M<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`
M4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@
M:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2
M;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A
M=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O
M34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-32`!3
M54-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S
M(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E
M;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A
M;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN
M8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V
M92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E
M9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE
M8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`
M4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U
M<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE
M;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@
M8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U
M(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A
M<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A
M=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H
M86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C
M="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA
M;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N
M`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3
M970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL
M86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A
M;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO
M=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H
M;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A
M;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA
M<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@<&EC:V5R`%-H
M;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N
M=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO9P!3:&]W
M('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA
M9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W
M97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6:6-I;FET
M>0!3:')I;FL`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA
M='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC
M90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO
M=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO
M=R!D97!T:#H@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E
M;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R
M9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(
M96UI<W!H97)E`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL
M`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N
M9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O
M<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE
M`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW
M86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA
M;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO
M;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E
M;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@
M)F1E9SLE<P!496UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M
M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P
M`%1H`%1H86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO
M;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C
M;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE
M961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K
M96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O
M;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N=&\@:71S
M96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN
M9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S
M<V%G92X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T
M("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE
M;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@
M;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M
M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT
M96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES
M(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(
M97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H
M87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I
M<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE
M8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T
M86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O
M9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S
M<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE
M<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T
M(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z
M:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E
M9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M
M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`
M5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S
M96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4
M;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N
M=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG
M+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R
M<F]W`%1O;F=A`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R:6YI9&%D(&%N9"!4
M;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H
M("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@
M`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T
M:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L
M92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O
M;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!3
M4TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T
M>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE
M('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`
M56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E
M<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L
M9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E
M<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@
M;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5
M;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I
M+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F
M<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D
M97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E
M;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@
M=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I
M=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC
M;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N
M`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E
M961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T
M(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O
M;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O
M.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T
M97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S
M($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N
M(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@
M*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E
M9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@
M9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U
M<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P
M<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E
M(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-
M4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5
M<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93
M(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C
M871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU
M=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A
M9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@
M27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&
M=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T
M82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)
M4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA
M<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``
M5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I
M9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@
M;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI
M=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K
M;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R
M92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@
M8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E
M<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F
M:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N
M9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`
M66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D
M:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R
M;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@
M=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A
M8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&
M4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@
M96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M
M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@
M<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E
M8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T
M:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@
M=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE
M+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R
M`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G
M86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9
M;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA
M;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@
M5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I
M;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S
M(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E
M($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@
M=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@
M875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I
M;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@
M:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES
M(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R
M:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E
M;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y
M.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U
M<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V
M92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I
M;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S
M=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E
M<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE
M=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R
M96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B
M=V4`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@
M475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;
M;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E
M`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N
M+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`
M7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R
M;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E;G1R>2!N;W0@9F]U;F0`9FEL90!F<F]M('1H92`E<R`H)7,I
M(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM
M961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F
M='=A<F4@97)R;W(`;&EN97-=`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO
M="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@
M9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG
M`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA
M:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`
M=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S
M"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/
M5"U#<F5A=&EO;BU$871E.B`R,#`V+3`Q+3`U(#$U.C`T*S`X,#`*4$\M4F5V
M:7-I;VXM1&%T93H@,C`P,2TQ,BTR,"`Q,CHP,"LP.#`P"DQA<W0M5')A;G-L
M871O<CH@1&%V:60@0VAA;F<@/&1A=FED0'1M=BYG;W8N='<^"DQA;F=U86=E
M+51E86TZ(%1R861I=&EO;F%L($-H:6YE<V4@/&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA
M:6X[(&-H87)S970]0DE'-0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M+6)I=`H`("@E<R"DT:ME*0`@**?6L;;!Y"`E<RD`("@E<R"DT:2Z*0`@**2U
MI-$I`"`HJ?JDT2D`("BL4:31*0"I\P`B)7,B(*2CK$^D0*W3I=B__0`B)7,B
M(*2CK$^D0*W3IK.NQ*JZO^^^W"X`(B5S(B"I?*6\IF(@2$]21$4@JKJU^:55
MP,DH4F5G:7-T<GDII*2S7:EW+@"GY*2CJ.P@(B5S(B!T<F5E(')E;F1E<F5R
M+@`B)7,BI'>FJ*5<JKJE6Z1*J.RX<[+5J'2RSJ2D+@`B)7,BI'>E6Z1*Q7:M
MK:ATLLXN`"(E<R*HPZ6\J]BEWSH@)7,N`*1WJ,^ESB`E+C)F34(@+*YEMG$@
M)2XR9DU"("RST;YL("@E+C)F)24I`"5D("5S(*5(I,X@)7,`L\RJ\:1`IKBQ
M2[U8Q=RG\ZGS("5D(*31JV4N`+/,JO$@)60@I-&N\+9(N7>S^``E<R`M(+/&
MI]&__0`E<R"K_*^^`"5S($M"`"5S(+K[Q4"^WJ=`("T@O52[>P`E<R"S7:EW
M`"5S(+7YI54`)7,@IE"W3K:UI=@`)7,@I'>F<Z9B`"5S(*9B("5S("5S`"5S
M(*1WM$ZD5:9#J,:VM:JZNOO%0+[>IT"T3KK\+B"]T*GSIKFNR:3$O^^G0;=1
MK6Z^WJ=`JKJVM:78+@"ELKO=K6X@)7,`)7,@I,``I^2DHZCL("5S+@`@)7,@
MJ.P@)7,@ID`@)7,`)7.JNK-QL%2__0`E<ZJZIN:HQK[D`"5SJKJSQJ?1O_T`
M)7.JNJO=O^S#KP`E<SH@)7,`)7,Z(+-OJ\JK2*7SI*.D0*EWKW6ET:M(I*2J
MNK%(I?.D2*G2L4BU;RX@O="J8+=.I%6F0ZG2IK.JNKKTN/2S<[6RIK.E::_@
MK*JZ?*=!JKJMTZ1(N.JNQBX`+""P?:VW(``L(+!]K;<@)7,@)7,`+,7<I,:V
M<;%Q("5S(*CL("5S`"TM(+_OOMP@+2T`,3(@I'"NR:CN`#(T(*1PKLFH[@`R
M-""D<*[)J.X`I%>D0*VV`*:YL,^V]*6RMK>M;JO\J7>XZJ[&KG>F^*I!NMTN
M`+5OI<VD1J1`K=/$6:VKJKJ_^;M^`+']I5NQ2[9LI?,LP=F[W:UNIK.D0*W3
M(%!'4""DO;9]JO?&7RX`L?W%Y\/2I'?#L;.YJKJV;*7S+,'9N]VM;J:SI$"M
MTR!01U`@I+VV?:KWQE\N`+']N-&Q2[9LI?,LP=F[W:UNIK.D0*W3I+VV?2!0
M1U`@JO?&7RRH<+%+(%!'4""J]\9?+*5(I,ZS<</VI&:E3RX`L?VP]:;FMFRE
M\\.QL[DLP=F[W:UNIK.D0*W3I+VV?2!01U`@JO?&7RRH<+%+(%!'4""J]\9?
M+*5(I,ZS<</VI&:E3RX`L?VXT;%+MFRE\RS!V;O=K6ZFLZ1`K=.DO;9](%--
M24U%(*KWQE\LJ'"Q2R!334E-12"J]\9?+*5(I,ZS<</VI&:E3RX`L?VP]:;F
MMFRE\\.QL[DLP=F[W:UNIK.D0*W3I+VV?2!3+TU)344@JO?&7RRH<+%+(%,O
M34E-12"J]\9?+*5(I,ZS<</VI&:E3RX`L?VE6[%+MFRE\RS!V;O=K6ZFLZ1`
MK=,@4TU)344@I+VV?:KWQE\N`*3(JV6FL[:S`*3(JV6D<*M"`*3(JV6FLZM"
M`*3(JV6P?:M"`*3(JV6P?;.W`*3(JV4OI,BKX0!!4$D@O7.XN0##]JGSLV^M
MT[USO^B^N0##]JGS+BXN`*6_I%6DZ`"EOZ2DI:$`Q7:MK:2CJ*PLM4RJ:ZO8
MI=\@5D93(*78O_TN`,5VK:VDHZBL++5,JFNKV*7?(%9&4R#`R:[7+@"Q8KBY
MN.JP5`"Q8KBYNU"Q2[U8`+%BN+FD=ZWAM;(N`+6RL6(`MW.\5P"W<[Q7IKBX
M<[+5`+=SO%>D;,5VK:T`IF*FN;=SO%<Z`+=SO%>X<[+5`+=SO%?%=JVM`+=S
MO%>FN+ASLM6H["`B)7,B`+=SO%>FN,5VK:VFW"(E<R(`MW.\5Z1`K=.HSZ7.
MJLPZ`+=SO%?$YJ;L`+=SO%>D0*W3IJBM^SH`MW.\5[GO`+=SO%<@)7,@K+`@
M36]Z:6QL82"JNJ3`K;8`MW.\5ZCLJKJS<;!4O_TZ`+=SO%>H[*?:JKJS<;!4
MO_T`MW.\5ZC/I<ZJS`"D=[=SO%<@(B5S(B"H[*ATLLZDI"X@IOVU3*IKMW.\
M5\-"I7ZJNK7YI56XZK!4.B`E<RX`I'>W<[Q7("(E<R(@J.RH=++.I*0N(*=!
MLGNF8J5II4BV::;FM6ZD2J1&+@"W<[Q7J,^ESJK,JKJE7*_@I=BK9;-1P_:S
MK"X`IF&G?0"S<;!4O_T`IJBLL+K>LGJM^R`M(*RPJ.2E3*C/I<ZJS+-=J7?%
M=JVM`+K>LGH`O'.G:0!!9F=H86YI<W1A;B`HJORT2::]*0!!;&)A;FEA("BJ
M_+JXI-JEIZC(*0!!;&=E<FEA("BJ_+JXI,ZG4:C(*0"V;*7SIT^F5P"Y[[OT
M`+GON_2DZ*:A.@"ITJ:S`*G2IK.D=\7GP]*JNJC/I<ZJS`"ITJ:SN'.RU0"I
MTJ:SQ7:MK0"E?J[8O74`I+FS7*9NM%BMT[EQI&RV;*7SIF&G?0"DN;-<Q=RG
M\[:UI=B]<[BYJKJKK+I!/P"D=Z9SIF(`Q=RG\R!)35-0(+5NI$H`Q=RG\R!)
M35-0(+%+O5@`Q=RG\R!)35-0(*C/I<ZJS`#%W*?SN7&D;+9LI?.F[:=]`,7<
MI_.\RZI/`+3`I4ZDY:9R`$%M97)I8V%N(%-A;6]A("BL_,12L.W"Q+ROJ,@I
M`*1`K=.U3*[$JKJMR+-1J,^ESBX`M6^ES:1&I$"MTZ6\JKZJNK_YNWXN`$%N
M9&]R<F$@**9WN42FU2D`06YG;VQA("BF=ZWTJ=0I`$%N9W5I;&QA("BF=Z9C
MJ=2N<2D`L,ZF5Z5.LGJF<ZCZ`+6JKM<`06YT87)C=&EC82`HJVZWI:1JL[`I
M`$%N=&EG=6$@86YD($)A<F)U9&$@**9WM*.ERJYQI,ZDVKJXI:RY1JYQ*0#`
MLZ7.M7NFH0#`LZ7.M7NFH;)-L^8`P+.ESK5[IJ&D=[1.NOP`KDVESJCLJ=*F
MLZJZIKBF0*C)`*?EK>,`N7>F]*1JI'``I7RDZP"J_*G4IT*DY2`H5VEN9&]W
M<RTQ,C4V*0#`H\%9P,FD:J1P`,"CP5G`R:97NMD`IT&]5*EWK6ZG4K"C("5S
M(*JZM?FE5;;<(#\`IT&]5*EWK6ZG4K"C("(E<R(@I4BDSJ7TIO.JNJ:XN'.R
MU2`_`$%R9V5N=&EN82`HJORNVJ?**0!!<FUE;FEA("BHR*S\I:>HR"D`J,BL
M_*6GJ,BDY2`H05)-4T-)22TX*0##P+-.`$%R=6)A("BJ_+Y\I-JN<2D`07-C
M96YS:6]N($ES;&%N9`"DY:9RP\"S3@"HR*QW+Z33I:VL=J9AL,\`L/6FYK[>
MIT"Z^\5`JV7%XZ7<O52[>[GON-P_`*3`L'3$YJ;L`,!\N-6G4K"CI$"MTZ2C
MIG.F8JJZN'.RU2X`P'RXU:=2L*.D0*W3I*.F<Z9BJKK%=JVM+@#`?+C5O7._
MZ*1`K=.DHZ9SIF*JNKASLM4N`,!\N-6]<[_HI$"MTZ2CIG.F8JJZID"HR2X`
MQ-VIR@"D2Z3K`$%U<W1R86QI82`HOT2D:J=1J,@I`$%U<W1R:6$@*+;XIF&G
M42D`075T:%]C<GES<6PZ(*?DI*.H[*G2N]VM;JJZ(&EM87`@J;6F^:Y-I?,N
M`$%U=&A?8WER=7,Z(*;XJD&ZW:C#I;RTHZC1N-.VM:3DM*DN`$%U=&A?8W)Y
M=7,Z(*?DI*.H[*G2N]VM;JJZ(&EM87`@J;6F^:Y-I?,N`$%U=&A?9G1P.B"G
MY*2CJ.RITKO=K6ZJNB!&5%`@J;6F^:Y-I?,NO="MJ[=SO7/$MB!02%`@J,.E
M0J5;I$H@+2UE;F%B;&4M9G1P(+_OMK4LJ-*F<"!C;VYF:6=U<F4@+2UE;F%B
M;&4M9G1P`$%U=&A?:6UA<#H@I^2DHZCLJ=*[W:UNJKH@24U!4""IM:;YKDVE
M\RX`075T:%]K<F(U.B"GY*2CJ.RITKO=K6ZJNB!K<F(U(*FUIOFN3:7S+@!!
M=71H7VQD87`Z(+=SO%>HSZ7.JLRS;[:UI5ROX*78JV6HPZ2CI.2TJ:78O_VJ
M0;#(`$%U=&A?;&1A<#H@IU*PHZC/I<ZJS+-OMK6E7*_@I=BK9:C#I*.DY+2I
MI=B__:I!L,@`075T:%]L9&%P.B"GY*2CJ.RITKO=K6ZJNB!,1$%0(*FUIOFN
M3:7S+@!!=71H7VQD87`Z(+5,JFNW<[Q7J,^ESJK,("5S+B"F^*I!OKFF7L"S
M.@!!=71H7VQD87`Z(+5,JFNROK"CJ,^ESJK,("5S`$%U=&A?;&1A<#H@M4RJ
M:Z?SMW.HSZ7.JLP@)7,`075T:%]L9&%P.B"G\[=SJ,^ESJK,LV^VM:5<K^"E
MV*MEJ,.DHZ3DM*FEV+_]JD&PR`!!=71H7VUC86PZ(*?DI*.H[*G2N]VM;JJZ
M($U#04P@J;6F^:Y-I?,N`$%U=&A?<VUB875T:#H@I^2DHZCLJ=*[W:UNJKH@
M<VUB875T:""IM:;YKDVE\RX`24U!4""F^*I!OKG%Y\/2O_F[?BX`Q>?#TJ6B
ML=$N`,7GP]*EHK'1+B`E<P!2041)55,@Q>?#TK_YNWXN`$944"#%Y\/2O_F[
M?BX`4TU"(,7GP]*_^;M^+@"E::7.JKK$YJ;L.@!!>F5R8F%I:F%N("BHR+;K
MJ_2U32D`K4FTN@"M2;2ZPT.FX@!K97)B97)O<R"Q2[U8O_F[?BX`:V5R8F5R
M;W,@J,^ESJK,IE>ZV;_YNWXN`$)A:&%M87,@**3:JZ*PJ"D`0F%H<F%I;B`H
MI-JJ3"D`JFG#N:JZKORDY2`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@@**ES
MI5NIU"D`0F%R8F%D;W,@**3:J*FF:"D`I^2DHZCLN<^EW*78O_T@(B5S(BX`
ML/*]=0!"96QA<G5S`$)E;&=I=6T@**3QIU&NR2D`0F5L:7IE("BHJ:B]M+4I
M`$)E;FEN("BHJ;GG*0!"97)M=61A("BFRKQ]N48I`$)H=71A;B`HI*.DIBD`
MI<VDZ0"GY*2CJ.S`LZ7.M7NFH2(E,B1S(JJZL,^V]"(E,21S(BX`L,^V]+-=
MJ7<`L,^V]*NLND$`LLK%Z0!";VQI=FEA("BLP:=1NONHR"D`KM'%T@"NV+UU
M`*[8O76D:J1P`*[8O74`0F]S;FEA(&%N9"!(97)Z96=O=FEN82`HJFFD:*6G
MJ,BDSK;"P<FM]+K[J+HI`*7^LZ$`0F]T<W=A;F$@**III;ZHNBD`J;.SH0!"
M;W5V970@27-L86YD`$)R87II;"`HI-JFZ"D`0G)I=&ES:"!);F1I86X@3V-E
M86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M("BH6K7<*0!"=6QG87)I
M82`HJT^E6Z=1J,@I`+:UI=BRQ;BY`$)U<FMI;F$@1F%S;R`HI:RT6*_'JFNO
MP2D`0G5R=6YD:2`HNUJVJ:9A*0"JJ:VQNMZR>@!#4D,`0U),(*3`LZ'"20#`
M>*9SKN:DNJYE+BXN7V4`I]:H^JKLJ6RDQJE\I;RGN::H+@"FYJC&ON0`N7.O
MQ:VW`$-A;6)O9&EA("BL6JY(N>LI`$-A;65R;V]N("BSV+/!MJDI`+5,JFNF
MV[#*K:NX;;%+O5@LO=#!<+6XIT&JNJATLLZZWK)ZK?LN`+5,JFN\9Z1*P,FN
MUR`B)7,B`+5,JFNS<[UUIMP@24U!4""F^*I!OKDZ("5S`+5,JFNV?;'2P,FN
MUR`B)7,B+@!#86YA9&$@**5;KK.D:BD`J/JN^`"H^J[XL-W#1*9>L_@`M4RJ
M:Z=2L*/`R:[7("(E<R(N`*?DI*.H[+S(IG.EV+_]+@"ORJ36("=T87)G971&
M:6QE)R"PT;S&M4RJ:\1^Q/*S0K)Z+@"U3*IKLKZPHZ78O_T@(B5S(BX`M4RJ
M:[*^L*,[("5D(*W3I&RVL*1WIG.F8BX`M4RJ:ZVKLM6A0ZG2M*.HT:JZL$^_
M_;S&I=B[4*7]JV6ITL!XIG.JNKCJKL:DH[+%+@"U3*IKML>P9<*RL%2H[*O\
MJ7>JNKBYO5@N`$-A<&4@5F5R9&4@*+K[O'>HI"D`NZ&I^J3EIG(`I,##_KM0
MO-#%T@!#87EM86X@27-L86YD<R`HMGVPTKASKG$I`*;FL,JY<;C<`,!XIG.N
MYJ2ZKF4`P'BF<Z[FN=2E4CH`P'BF<Z[FI+JN90#`>*9SKN:VH;9:.@"FYK#*
MN7&XW`"VZ[JXKU.DY2`H25-/+3@X-3DM,30I`+AMI*0`0V5N=')A;"!!9G)I
M8V%N(%)E<'5B;&EC("BDI*M$ID"I3;#J*0"DI+S:("A)4T\M.#@U.2TR,`"^
MS,/2LM.X8`"^S,/2OM:FLZK,`+[,P]*L1K6F`$-H860@**QDO'<I`*?SI^\`
MI_.G[Z=!JKJQ2[U8`*?SI^^G0:JZJKJE_J97I4BDSJ9>MFRF8:=]+@"EV*ME
MJKJS7:EWJ,.EO*3DM*FQ2[U8Q=RG\RX@O=#!<+6XIT&JNKK>LGJM^RX`IG*D
MN`#`RZQDLW.ULBXN+E]K`$-H:6QE("BTO*=1*0!#:&EN82`HI*2PZBD`PK+%
MZ:2DI.4@*$=",C,Q,BD`I;_%Z:2DI.4@*$)I9S4I`+_OOMS`LZ7.M7NFH3H`
MO^^^W+%+O5@`O^^^W*1`K=.HSZ7.JLRF5[K9`*3IM,'%XZ7<I.BFH3H`O^^^
MW+:UI=BKK+I!JKJMMZ[F`$-H<FES=&UA<R!)<VQA;F0@*+ATO<^N<2D`I^2D
MHZCL("5S(*JZP_ZG3ZEWN'$N`+2X`+)-L*.W3+-N($]F9FEC92"\T,72`+)-
ML*.L9+C?`+)-L*.HSZ7.JLPZ("5S`+)-L*.HSZ7.JLP`LDVPHZC/I<ZJS*JZ
MN.JNQ@"QW\+@M+@`J_:WQKFKP>2E2,1^Q/(`0VQI8VMA=&5L;""S>KE,($A4
M5%``P_:SK+7XM:$`MK.V<0"FK:9HMK,`L[$`0V]C;W,@*$ME96QI;F<I($ES
M;&%N9',`I^G%?+CJKL:GJ`"GZ<5\P^2LR0!#;VQO;6)I82`HK?2MVZ3QJ,@I
M`,-#IN(`O=6FXKU,`#$VMFFF[,-#IN*E3KU8`,3F.@#$YJ;LO-##1`"E9+-Q
M`*E2I4\`I^6FN*E2I4\`M?N]UP"ZV:E)`$-O;6]R;W,@**SLO*_#N2D`I+VE
M<0"Y<;BC`,#TN=(`L?BE\P"N=+*G`+M0(%!$02"T>*17JZRY<;BC++2\O'JK
MK*3BOO>E2*3.($]U=&QO;VL@JKJF4*A"LUVI=RX`LUVI=[CJKL:Y3+3!+@"S
M7:EW("5S`+U4NWNQ2[U8`$-O;F=O("BMZ*I'*0!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE("BMZ*I'ID"I3;#J*0"S<[6RI:*QT2X`
MLW.ULJ6BL=$Z(`"S<[6RIMRDO;9]JO?&7Z;XJD&^N:[)OD2IVBX`LW.ULJ;<
MI+VV?:KWQE^F^*I!OKFNR;Y$J=HN(*WLIETZ("5S("@E<RD`LW.ULJ;<($94
M4"#`R:[7IOBJ0;ZYI:*QT2X`LW.UN*1(`+!/O_VD=Z:HI5RF8;=SO%>FW*=!
MJKJS<;!4O_VDI"X`P*/!6<#)KM>JNJ2ZKF6KK+I!.B``(B5S(B#`R:[7I+JN
M90#$?L3R`$-O;VL@27-L86YD<R`HK.RG2KASKG$I`+W&NW,`O<:[<Z6BL=$Z
M("5S`+W&NW,`0V]S=&$@4FEC82`HK?2TM:1JOJ2E6RD`0V]T92!D)TEV;VER
M92`HMDBD^J[\J:0I`+5,JFNE2"!01U`@I5NQ2[9LI?,Z(`"U3*IKI4@@4$=0
M(+#UIN:V;*7SP[&SN3H@`+5,JFNE2"!3+TU)344@I5NQ2[9LI?,N`+5,JFNL
ML"!3+TU)344@MFRE\\.QL[DN`+5,JFNW<[Q7LW.UN*1(+B`E<P"U3*IKP[2U
MLB!,1$%0(*;XJD&^N0"U3*IKP[2ULB!L9&%P(*;XJD&^N0"U3*IKP,NL9+=L
MKW$N("5S`+5,JFNS<[6RIMP@;&1A<""F^*I!OKD`M4RJ:[-SM;*FW*;XJD&^
MN2`B)7,B(*C/I<X@1E10.B`E<P"U3*IKJ]BEW[!TN&VX<[+5+B`E<P"U3*IK
MN-&Q2R!01U`@N.JNQCH@`+5,JFNXT;%+(%,O34E-12"XZJ[&+@"U3*IKIU*P
MH[-SM;BD2"X@)7,`M4RJ:Z=2L*.P=+AMLDVSYBX@)7,`M4RJ:Z=2L*.G\[=S
MM7NFH2`B)7,B+@"U3*IKJ$VI=Z:LI?.D2*JZN7&D;+9LI?.F[*=]+@"U3*IK
MP/*H^J>YON.JNK-QL%2__2X`M4RJ:\#RJ/JGN;[CJKJP=+AMLDVSYBX`M4RJ
M:\#RJ/JP=+AMLDVSYJ2DJKJX<[+5+@"U3*IKN/RD2K6FLJ0@(B5S(BX`M4RJ
M:ZO8I=^EV+_]("(E<R(N`+5,JFNFVZKWQE^F^*I!OKFH^K%OI+VV?:KWQE\N
M`+5,JFNV?;'2("(E<R(@I4B\9Z1*+@"U3*IKMGVQTB`E<RX`M4RJ:[9]L=*Z
M^\5`I'6G0+S2LM4@)7,`M4RJ:[9]L=*EV+_]("(E<R(N`+5,JFNS<[&U($Q$
M05`@(*;XJD&^N2X`M4RJ:\6JJ/H@)7,N`+5,JFNMJ[=SLUVI=ZC/I<ZJS*JZ
ML4N]6"X@LZ&DP*JZLM.X8*2CI;^]5"X@O=#!<+6XIT&JNJATLLZZWK)ZK?NE
M2*CSIU6S0K)Z+@"U3*IKQ:JH^J9SJ/JQL:CNJNTH06-C97-S($-O;G1R;VP@
M3&ES="D`M4RJ:\6JJ/JS<;!4O_TN("5S`+5,JFO%JJCZL'2X;;)-I54N("5S
M`+5,JFO%JJCZL'2X;;)-I54N("5S`+5,JFO%JJCZIOBJ0;ZYJKJLV\/VKU.I
MR@"U3*IKIEZT7[-=J7<N`+5,JFNG4K"CI=B__2`B)7,B+@"U3*IKP'BF<R`E
M<R"JNK-=J7<N`+5,JFO`>*9SL\:E][-=J7<N`+5,JFO`>*9SL\:E][-=J7<Z
M("5S+@"U3*IKP'BF<Z?SMW.U>Z:AJ.PZ("(E<R(N`+5,JFO`>*9SL\:E][-=
MJ7<@)7,N`+5,JFO`>*9SLUVI=\#))7,N(*=!I6FE2*C/I<XE<Z2DJKJHY*5,
MI5ROX,!XIG.S7:EWJ<ZDXK#*O<:[<Z15K;&U>Z:AO5BH["`E<RX`M4RJ:[=J
MM$T@3$1!4"`@IOBJ0;ZY+@"U3*IKIU*PHR`B)7,B+@"U3*IKI_.W<[-SM;BD
M2"X@)7,`M4RJ:Z?SMW.P=+AMLDVE52X@)7,`M4RJ:\+0O&<@(B5S(CH@)7,@
MJKJS7:EW+@"GY*2CJ.P@36]Z:6QL82"JNJ3`K;8N(+W0O52[>Z3`K;:L3Z=?
MMGVQTBX`M4RJ:[WAI*FHSZ7.JLP@(B5S(B"D5:9#Q7:MK:CLJTBE\Z=8("(E
M<R(Z("5S`*?>LTZE>0"PZJYA`+W2JNT`J]BEWP"KV*7?I$"MT[-SM;(`J]BE
MWZ1`K=.W<ZJZ`*O8I=^FN*M(I?.G6`"KV*7?JLRJNL5VK:T`JTBESJ5DN+F]
M6`!#<F]A=&EA("BG2L.YINBHR"D`0W5B82`HI6JDVBD`I=BK9;=\M,$`I=BK
M9:[)MJ$`I=BK9;KTIWT`I=BK9:JZJ,^ESJK,`*78JV6DT:[P`*78JV6JNJJL
MJG`Z(`"EV*MEJKJMMZ[F`*;;K7&D0*C'M6ZD2B5SJ^&ITJUNL/6FYJJZI'6G
M0"X`L,6D50"PQ:15`$-Y<')U<R`HP<FTMK#'M+4I`*;HJ+VZN*3E("A+3TDX
M+5(I`*;HJ+VZN*3E("A7:6YD;W=S+3$R-3$I`*;HJ+VZN*3E+Z]1ITK$]:3E
M("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC("BQMJ=*ID"I3;#J*0"DZ0"XZJ[&
MJ-.WO:97NMD@*+W0L-&FTB!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E
M;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`*A#I.D`OO"J
MK+CJKL;"<\3]`+CJKL:N=[=JM$T`I.FTP0"FK*CLI.FTP0"_[[[<I.FTP0"E
MU:31`*=2L*/$YJ;L7VP`I%&D1Z3K`*11MFFF[+S&IG(`M.ZDUL%9L<8`N7>S
M70"Y=[-=PT.FX@"Y=[-=JKJHK:7WP]&G3P"Y=[-=J5*E3[C1JE*^N2A3:&5L
M;"D`J7>X<0"G4K"C`*=2L*/`>*9SKN8`IU*PH[ASLM4`IU*PHZSVO_T`IU*P
MH\5VK:T`IU*PHZ%"LDVJQ;9LI?,`IU*PH\!XIG.NY@"G4K"CQ.:F[`"G4K"C
MLGNF<ZJZM,"E3KS+JD\`IU*PHR(E<R*JNL5VK:T`O52I=ZUNIU*PHR(E<R*J
MNL5VK:VE2*3.IKC%=JVM(#\`IU*PHZ9#`*=2L*.ITK_OOMRJNJBMI??#T:=/
MN.JNQ@"G4K"CI=BK9:JZQ.:F[`"G4K"CI=BK9:JZID,`I_.W<[5[IJ$@(B5S
M(B"D=Z=2L*,N`+N\L&6NR;:A`$1E;FUA<FL@**2FL\$I`+#=PT2T>:UZ`+1Y
MK7H`LM.X8"`HO="PT:;2($AO<F1E(+!/O_W`R:[7*3H`LM.X8+W0L-&FTJAT
MLLZZWK)ZM6Z__2X`K..U;P#%4\))M\6KUP"SS*OAI$"D<*[)JKK%4\))M\6K
MUSH@`,53PDFWQ:O7.B``L7&EJJ;<I6L`L7&E:Z;<I:H`I=B__0"E2"`R-""D
M<*[)J.[%XZ7</P#%XZ7<O^^VM0#%XZ7<N-2RTZJZN7>S^`#%XZ7<N7>S^"`H
M5$%&*0#%XZ7<KN:FH0"VQ[!EIEZQ^`!$:FEB;W5T:2`HIDZEK*9A*0"DHZ=2
ML*,`I*.M;JJ]L;6F<ZCZ(&UA:6YT96YA;F-E+G!H<`"RQ*1`M:>P3[_]K$^G
M7Z5=IW3$YJ;LIE>ZV3\@IG"J1ZQ/O="DQ+_O+@!$;VUI;FEC82`HIFBI^J6G
MI5LI`$1O;6EN:6-A;B!297!U8FQI8R`HIFBI^J6GI5NF0*E-L.HI`,'9J%.F
ML[%BN+FVW#\@M?FE52X`I%6X_`"D5;C\("5S`*15N/RS7:EWP,FNUZ5TIG.L
ML"!02%`@M7NFH2X`I%6IU*5<K^"J[0##Q*M^`+EQI&RV;*7S`+_YNWX`16-U
M861O<B`HI,RERJ9HNK@I`+USO^@`O7._Z+#/MO0`O7._Z+ASLM4`O7._Z,5V
MK:T`O7._Z,5VK:T`O7._Z"5SJKK%=JVM`+USO^B_[[:U`+USO^@B)7,BJKK%
M=JVM`+USO^@E<ZJZQ7:MK0"QT*A\`$5G>7!T("BN2J3.*0!%;"!386QV861O
M<B`HPL2ZN*7+IF@I`*2XI?,N+BX`N7&D;+9LI?,`N7&D;+9LI?.F[:=]`+EQ
MI&RV;*7SINVG?:6RMK>G:Z98+@"Y<:1LMFRE\[U4NWL`16UA:6PM=&\M4TU3
M(+EHN42^N0"J[;&ALL6XN0"JQ:75JTBE\RX`JL6EU;6RJD<N`*K%I=6W:K1-
MMK6EV`"DN;-<IMO#P+19M*&D2K?3I/FH[*M(I?.DI"BZ]*VVO7.\9[S2IJ$I
M(#\`L=*PRK?&N:NE:\'DI5ROX*KM/P"ULJ?TIGZE]P"I\:1JO7._Z+ZY`*9P
MJD>G0;O=K6ZMJ[-=L4N]6"R]T+_II$JD0*W3IG>E_K#=I7DLJ-*F<"`GIT'#
M9*JKJKJF5[K9(#\G.@"F8J:YO^FD2KQVN;.JNKKTIWT`17%U871O<FEA;"!'
M=6EN96$@**BJN42T6*2ZJ,@I`$5R:71R96$@**3,I=^O4ZB]IG<I`+_YNWX`
MJ]BEW[#/MO0E<Z[)M6^ES;_YNWX`IU*PHZ90J$+!X\)).B`E<R"NR;5OI<V_
M^;M^`*=2L*.F4*A"L$^__3H@)7,@KLFU;Z7-O_F[?@#%JJCZI+JN93HE<R"N
MR;5OI<V_^;M^`*?SMW.Q2[U8.B`E<R"NR;5OI<V_^;M^`+QGI$H@(B5S(B"N
MR;5OI<V_^;M^+@!%<W1O;FEA("BW4JA&I:>HR"D`171H:6]P:6$@**;GK\&D
M\:C(*0"ZV+':`$5U<F]P92`HO-JL=RD`J$,@,34@I,#$P0"H0R`R(*3`Q,$`
MJ$,@,S`@K.W$P0"H0R`U(*3`Q,$`J$.FN+5NI$H`J$,@,S`@I,#$P0"H0R`Q
M(*3`Q,$`O62HTJW(.@"P]:;F`*YIMGT`KFFV?;CJKL:GJ`"M;JA$("<I)P"H
M[+3!I.D`N-&[H:W[`*MEM+K#0Z;B`$944""D5[;'LUVI=RX`Q:JH^K"^IFZS
M7:EWI:*QT0"U3*IKLW.]=:;<($Q$05`@IOBJ0;ZY+@"U3*IKLW.]=:;<(%--
M0B"F^*I!OKDN`+W&NW.EHK'1IML@(B5S(BX`O<:[<Z6BL=&H["`B)7,B+@"U
M3*IKJ]BEWZ1`K=.W<ZJZ(%-!4TP@LW.QM2X`MVBROJ6BL=&H["`B)7,B+@#"
M7JCZI:*QT3H@)7,`M+:S<0!&86QK;&%N9"!)<VQA;F1S(*IKQ/6G2KK6N'.N
M<2`HL*BZN+K[K\>TM;ASKG$I`$9A<F]E($ES;&%N9',`Q%FMJ[_YNWXZ`+;'
MKW4`ML>O=0"D1Z3K`+=0Q+$`MU#$L3H@`*3RI/*K0@"U=;S(L'VSMP#$YJ;L
ML'VF0P!&:6II("BTM,#9*0#`R:[7O,:EV#H@)7,@K=/`R:[7`,#)KM>\QJ78
M.B`E<R#`R:[7`,#)KM?!8+K>`,#)KM>F5[K9`,#)KM>_[[[<`,#)KM>D5[;'
M`,#)KM>D5[;'I5ROX*6\LU&DY+2I+@"Y3,)OOKD`1FEN;&%N9"`HJN+$]2D`
MI%>E8J3K`*17J;8`J52I=Z3QJ-(`I%>D5<1!K<L`KT*PR@##^@"EV+_]("5S
M(*2CIG.F8@"F<JNLPT.FX@"MN:JK`*9=K+#"<\3]OKFHPZ6\I.2TJ;QVN;.E
M7*_@+@"N\+9(N7>S^"`H5$%&*0"Y=[/XI-&\QB`HN7>S^*31O,:E7:Q!I=6D
MT:5(I,ZI7;:AJKJXZJ[&.Z9PJD>Y=[/XI-&\QKC[JOBQ3J;[I<ZD\;C[O&6T
M5*JZJJFML2D`I]&P3[%+O5@@/P"J[;/F`*1PNWD`I'"[></^JZP`I'"[>0"D
M<+MY(#(`O=>^P@"FV[#*PN"K2`"L4+3!I*T`KMBL6P!&<F%N8V4@**IKL.HI
M`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$@**IKQ-V[7*C(
MJ+HI`$9R96YC:"!0;VQY;F5S:6$@**IKQ-VLP:=1I:>FZ*C(*0!&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,`L4BE\Z1(`+%Q`*>YON.T>:UZ`+JAI.L`
MI?ZF5P!'86)O;B`HI5NT7BD`P\"T63H`1V%M8FEA("BES*3QJ,@I`+*CI<T@
M)7,@K=.H=++.LUVI=P"D=[*CI<VJNK-=J7>XZJ[&`$=E;W)G:6$@*+/LJG:H
MR*9`J4VPZBD`1V5R;6%N>2`HO'>PZBD`1VAA;F$@**U[K\<I`$=I8G)A;'1A
M<B`HJKVEK,.YJOLI`*97NMD`JV6IN0"M]+QWNK@`1V]O9VQE(*9AN<\`1V]O
M9VQE(+=JM$T`IL>VI0!'<F5E8V4@**?&P[XI`*?&P[ZDY2`H25-/+3@X-3DM
M-RD`1W)E96YL86YD("BNYK.NQ/6N<2D`9W)E;F%D82`HKN:WYZ_'N48I`+AS
MLM6ZWK)Z`+ASLM6F5[K9I*.Q;ZK%I=4`1W)O=7!?;&1A<#H@M4RJ:[=SO%>X
M<[+5("5S+B"F^*I!OKFF7L"S.B``1W)O=7!?;&1A<#H@M4RJ:Z=2L*.X<[+5
M("5S`$=R;W5P7VQD87`Z(+5,JFNG\[=SN'.RU2`E<P"X<[+5`$=U861E;&]U
M<&4@**WTO'>LI;2V*0!'=6%M("C#]JYQ*0!'=6%T96UA;&$@**7*IF&PJ*G4
M*0"NYJZFINBN<0"HT[NKQ7:MK0"S6*O(KV2HI0!'=6EN96$@*+18I+JHR"D`
M1W5I;F5A+4)I<W-A=2`HM%BDNJC(I/&OP:9`J4VPZBD`1W5Y86YA("B[7*C(
MJ+HI`+97I.6S<[6RNWFHI0"GY*2CJ.P@2%144"#%Y\/2+@!(86ET:2`HKORF
M82D`POBTZBVZ=+KB`,9'`*KMP%D`JNW`60!(96%R9"!)<VQA;F0@86YD($UC
M1&]N86QD($ES;&%N9',`I&JY<*M"`*?&IT*HTZ3E("A)4T\M.#@U.2TX+4DI
M`+"JJ]<`NZ&I^@"]<[_HOKFHSZ7.NZ&I^@"[H:GZ`*5BLGD`LV^XS*Q/P,FN
MUZJZMGVI;#H`L*H`KF%?;0!(;VQY(%-E92`HL>N_S:FC*0"N80"F[:YAIF&G
M?0"N8:78O_T`INVN8;EQN-P`2&]N9'5R87,@**>[LZ.IU+2U*0!(;VYG($MO
M;F<@**V[M.0I`$AO<F1E`$AO<F1E+TMO;&%B.B"V;*7S("4R)',@I*2Y2JCL
MM4RNQ*JZ("4Q)',@6$U,N.JNQ@!(;W)D92]+;VQA8CH@M4RV;*7SOD&F6*JK
MI?,@)7,`2&]R9&4O2V]L86(Z(+9LI?,@)3(D<R"DI*?DI*.H[*JKI?.KK+I!
M("4Q)',`2&]R9&4O2V]L86(Z(*1WIJBE7*JZLKZPHR`E<R`B)7,B`$AO<F1E
M+TMO;&%B.B"^XZ98I'6U>[O=K6X@)V1O;7AM;"<@JKH@4$A0(*FUIOD`2&]R
M9&4O2V]L86(Z(+5,JFNKV*7?("5S(*JKI?.JNB!834P@OO``2&]R9&4O2V]L
M86(Z(+5,JFNROK"C("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B"U3*IKP/*H
M^K.AI?<@)7,@JZRZ0:JZ($U)344@P]&G3[BYO5@`2&]R9&4O2V]L86(Z(+5,
MJFNF4*A"("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B"U3*IKIE"H0J3`J,DZ
M("5S`$AO<F1E+TMO;&%B.B"EO*J^JKJDP*C)("(E<R(`I/2EK;UU`*3TI:VY
MU*52`*3TI:TZ`*=!IG"F\ZCLIKD@/R`HO="QU*UZ(2D`IT&M;J98J-:F:*36
MK=/$YJ;LJ4\_`,3FINR\QJ78ID"M<#\`IT&M;J98J-:F:*36ID.I3S\`M\.K
MUP"WPZO7.B``M\:]7:1JKG8`2'5N9V%R>2`HIDFD^J=1*0!)34%0(+9LO6.K
MV*7?I:*QT3H@)7,`24U!4""V;+UCIU*PHZ6BL=$Z("5S`$E-05`@MFR]8[K/
MNM"P=+AMJ]BEWZ6BL=$Z("5S`$E0(*;LIWT`25`@INRG?;5,JFNHSZ7.+@!)
M4""F[*=]J,.DHZ9B($-)1%(@JKJDN;-<L,^V]*2D+@"F8JOAK;&TH:1*ID-?
M;@!)8V5L86YD("BF0JYQ*0"OPKG/I=P`)7.JNKG/I=P`N<^EW*3.I.6F<@"H
MK:7WP]&G3ZJZIE>ZV3H`IG"J1[5,JFNEO[U4IF'%XZ7<+"`E<R"E2*5TMGVQ
MTK9LI?.I\[=SM?BUH;?MI*0N`*C/I<X@26YT97)N970@17AP;&]R97(@PG/$
M_;ZYKLFF<*I'J%.FLZS=J.RE]*;SJKJD<+G/I=PL(*=!I6FOX+O=K6ZDQ+_O
MLV^MT[:UI=BE2,/VLZP@4$Y'(+QVN;.JNL'TPL.NQ*I'+@"F<*I'K-VH[+-O
MJVBH4Z:SO':YLZJZL%2NIRRS;ZKMI=RG0:JZPG/$_;ZYM4RJ:\7CI=RD5[;'
MJKJ\=KFS+@"\=KFSN7?$_3H`O':YL[KTIWT`O':YL[KTIWTZ`+QVN;.HTZ;;
MP\"T60"\=KFSJ-.FV\/`M%DZ`*17ML>\=KFS`+QVN;,`MM>D2BP@J$+&2B`E
M9`"VUZ1*Q.:F[#H@)7,`MM>D2L3FINPZ`*9BJ^&ML;2AI$JF0U]S`+_II$JD
MHZ6_O52JNJ=`I<Z]6"X`O=#`RZQDIT&JNJC/I<ZJS*97NMFDSK%+O5@`J,^E
MSJK,IE>ZV:2CI;^]5*G.JLRY<:1LMFRE\Z;MIWVD=\7<I_,NO=#!<+6XIT&J
MNJATLLZZWK)ZK?NE2*CSIU6S0K)Z+@"\5Z5;P5FQQ@!);F1I82`HIDRKURD`
MK=.G3ZC/I<ZJS`!);F1O;F5S:6$@**9,I:<I`+CJL%0`N.JP5`"U3*5II<ZJ
MNKCJL%0N`*9BJ^&ML;2AI$K$YJ;L7V\`M*&D2KG/I/D`M*&D2JKMKN8`M*&D
M2KKTN/2S<[6R`*9BJV6ML;2AI$K$YJ;L7T,`IF*EV*MEQ.:F[*OAK;&TH:1*
MI$"MT[=SQ.:F[`"F8J78JV7$YJ;LJV6ML;2AI$JD0*W3MW/$YJ;L`*9BI=BK
M9:9#J^&ML;2AI$JD0*W3MW.F0P"F8J78JV6F0ZMEK;&TH:1*I$"MT[=SID,`
MIF*EV*MEN&#"2:OAK;&TH:1*I$"MTZQQN*@`IF*EV*MEN&#"2:MEK;&TH:1*
MI$"MTZQQN*@`M*&D2J5IM,"E3KS+JD\`MW.Q2[U8L4ZQ2+5OJ.RS;ZW3MFRE
M\Z9AIWTZ`*9BJ^&ML;2AI$K`>*9SKN8`IF*K9:VQM*&D2L!XIG.NY@"F8JOA
MK;&TH:1*Q.:F[`"F8JMEK;&TH:1*Q.:F[`"TH:1*MFRE\P"F8JOAK;&TH:1*
MK'&XJ`"F8JMEK;&TH:1*K'&XJ`"F8JOAK;&TH:1*ID,`IF*K9:VQM*&D2J9#
M`*9WI?ZPW:5YJKJUJJ[7.@"TH:1*+\7<I_.\=KFS`+2AI$HOQ=RG\[KTN/2S
M<[6R`,))O,:DHZBLI4BFW*GSM4RJ:[;'L&6UN;!TN&VX<[+5+@#"2;S&I*.H
MK"X`ON.\Q@"^X[S&ID,`M4RNQ*JZ(%5$2"BHSZ7.JLRXZJ[&JNW`62DN`+5,
MKL2JNB!:25`@N.JNQBX`M4RNQ*JZP+.ESK5[IJ$N`+5,KL2JNJ?EIKBXN;U8
M+@"P9:58JKJXZJ[&M4RNQ"X`M4RNQ*JZI=B\T*;MIWT`M4RNQ*JZP,FNUZ[F
MIJ$`M4RNQ*JZL<+%=KU8+@"U3*[$JKJF8;#/+@"U3*[$JKH@;7-G7W1Y<&4N
M`+5,KL2JNJG.I^2DHZCL(&%P:5]I9"X`M4RNQ*JZJ<ZGY*2CJ.RPT;S&+@"U
M3*[$JKJD]\5VK:TN`+5,KL2JNKG9IO'#T:=/O5@N`+5,KL2JNK*CJWZ]6"X`
MM4RNQ*JZLW&P5*CSJ7<N`+5,KL2JNJ:LI?.D2#HB)7,B`+5,KL2JNJ3`J,FJ
MJZ7S+@"U3*[$JKJHT[>]INVG?2X`M4RNQ*JZN%6PZKU8N.JNQBX`N.JRHP"F
M7K1?O^^^W`!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F("BE[*[4*0!)<F%Q
M("BE[*G4ITHI`$ER96QA;F0@*+=2NKC$]2D`27-L92!O9B!-86X@*+#2KG$I
M`*>]LZ&Y<*M"`$ES<F%E;"`HI4BFXJ9#*0##L;5OJLP`L=?%Z0!)=&%L>2`H
MN'&D:J=1*0!*86UA:6-A("BD^K92I5LI`*1`I.L`2F%P86X@**3II;LI`*3I
MI.4@*$E33RTR,#(R+4I0*0"_0:;HKG$`2F]R9&%N("BL^:6Y*0"D0Z3K`*2[
MI.L`N>^[]`"X;:2D`*6JI6NY[[OT`+YAI:JY[[OT`+YAI6NY[[OT`$MA>F%K
M:'-T86X`JT^O9*WLO,L@/P!+96YY82`HJM:HR"D`2V5R8F5R;W,@NWO#TK_Y
MNWXN`*[6I-^W<Z3B`*KWQE^KV*7?`*KWQE^O4[QX`*KWQE^J^*O7`*KWQE^K
MK+I!`*KWQE^[>:IK`*78JV6JNJ2]MGVJ]\9?IOBJ0;ZYI*0LI'>X9Z9SIF*G
M0:JZJO?&7RX`J."UHP!+:7)I8F%T:2`HL/*HO:3:M+4I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F("BE7\'Z*0!+;W)E82P@4F5P
M=6)L:6,@;V8@**MNP?HI`,'ZI.4@*$550RU+4BD`2W5W86ET("BL[*O"KU,I
M`$MY<F=Y>G-T86X`JJFML;!TN&U?>0"[>:BE`$QA;R!096]P;&4G<R!$96UO
M8W)A=&EC(%)E<'5B;&EC("B\9+#J*0"D5:5BI.L`L\RJ\:1`IKBQ2[U8Q=RG
M\ZGS`*15J;:DZP"D5Z:XI_.W<SH`I%>D0*:XM6ZD2CH@)7,`I%>D0*:XM6ZD
M2CH@)7,@IML@)7,`I%>D0*:XM6ZD2CH@LL2D0*:XM6ZD2@!,871V:6$@**G4
MLN:Z^ZC(*0"J:ZO?`*JIK;&P=+AM`$QE8F%N;VX@*+ZDI-JYX"D`I:K#Y`"E
MJL/DJNW`60"EJL/DK<@`3&5S;W1H;R`HO^"OP::K*0!,:6)E<FEA("B_X*3Q
MM^>HR"D`3&EB>6%N($%R86(@2F%M86AI<FEY82`HIU&D\:C(*0!,:65C:'1E
M;G-T96EN("BF0Z3DM+"TM;5N*0"W3*M"`*1PJT(`IJVFLZ1PJT(`L=^FLZ1P
MJT(`I'"P?:M"`*1PJT*FL[EP`*1PL[<`I'"P?;.W`*6TJF^XU@"S<[6R`+-S
MM;+"2:CL.@#%XZ7<KLFS<[6RMFRE\Z;MIWVH[+USO&>V;*7SK;:ML0"S<[6R
M`*9#I5@@+2"HSZ7.JLRE::5(K-VH[+-OK=.K2*7SIU@`ID.E6+CJKL:N=P"F
M0Z58NZ&I^KS0PT0`ID.E6*KMKN8`L%&]U[ASLM4MP,FNU\)D`+!1O=>X<[+5
M+:A$IU4`L%&]U[ASLM4MP]&G3[BYO5@`L%&]U[ASLM4MOM:FLZK,`+!1O=>X
M<[+5+;%(I?.D2`"P4;W7N'.RU2VM<;Y<`+!1O=>X<[+5+:CZKOBM<;Y<`*9#
MI5BW?+3!I:*QT3H@)7,`ID.E6*C/I<ZJS*6BL=$Z("5S`*9#I5BHSZ7.JLRJ
MNJ5<K^"S4</VLZP`I.6^QP!,:71H=6%N:6$@**7?L[.I>RD`N/RD2J2D+BXN
M`+?MIF&NR;:A.B``IF&PS[M0KLFVH0"F8;#/`+5NI$H`M6ZE6`"U;J1*`+5N
MI$JD=:=``+5NI$JEHK'1+""]T,#+K&2[U:15JKJESJ3AIE>I3;%+O5@L(+5-
MJ^&MJ[C5+@"U;J1*I:*QT2X`JOBE>0"W4K&A`*=#`*1PO&>GQL.^O,:F<@"D
M<+QGJ=2D0KS&IG(`I'"\9\.YL*B\QJ9R`$QU>&5M8F]U<F<@*+]CM,NS^2D`
MI.L`J$.DZ;!4KJ<`35,M5$Y%1B"J_J5;P,FNUZ2DJ%.FL[CJKL8N`$U31P!-
M86-A;R`HOT2J^2D`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E
M<'5B;&EC(&]F("BPJ*CDN7FF0*E-L.HI`$UA9&%G87-C87(@*+"HN4:E6[2U
MI5LI`,5=LTX`MFRE\P"V;*7SNMZR>@"KV*7?LW.ULE]K+BXN`$UA;&%W:2`H
ML*BIU*O"*0!-86QA>7-I82`HL*BHTZ;HJ,@I`$UA;&1I=F5S("BPJ+JXIF&D
MTBD`36%L:2`HL*BG42D`36%L=&$@*+"HNKBE3"D`NMZR>J=!JKJDP,/^+*C#
MI4*LL*3`P_ZS7:EWPT.FXBX`36%P,C0@IF&YSP!-87!1=65S=""F8;G/`*14
MI.L`P^2LR0"\T+!/IJ@@K-VY3"^EO*S=N4P`O-"P3Z:HJ.2E3*JZP]&G3R`H
MJ-*F<"X@K:NM;B^D=Z9>PM`I`$UA<G-H86QL($ES;&%N9',@*+"HKDRZN+AS
MKG$I`$UA<G1I;FEQ=64@*+"HM*.EIZ=*KG$I`*3'L'3$YJ;LI*0`36%U<FET
M86YI82`HK52G4;;PI:>HR"D`36%U<FET:75S("B\KZB]INBTM2D`I+FS7*JZ
ML\RD:L))O,8N`*K^I?.\QJ78I'>V5Z58I+FS7*17K:TN`+/,JO$@,C0@I'"N
MR:JZL\RPJK?%J]<Z(`"SS*KQ(#8@I'"NR:JZL\RPJK?%J]<Z(`"PS[;TI%>M
MK;S&I=@`I+FS7+/,I&JJ^*O7`*2MI.L`36%Y;W1T92`HL*BL^:]3KG$I`,+E
MOL<`IJBM^P"_[[/FO-*FH3H`IEBHUL!XIG.NY@"V;*7S`+9LI?/%Y\/2I'>G
MN::H+*;]K$^HSZ7.JLRJNL.QL[FK;[5,JFNS<;E,Q>?#TBX`PK*P5*1WN4RT
MP2X`PK*P5*NLND$`365T87(@L,^V]+5,JFNHSZ7.+@!-971A<B"PS[;TM4RJ
M:ZC/I<XN(++3N&"]T+#1IM*H=++.NMZR>K5NO_TN`$UE=&%R1$(@J7REO+-S
ML;4N`*3HJFL`I.BJ:R`B)7,B(*6\LU&I=[AQ`*3HJFNEO*EWN'$N(*5(J4FE
M<Z3HJFLZ("5S`*2]J.X`365X:6-O("B^I:;HK?0I`$UI8W)O;F5S:6$L($9E
M9&5R871E9"!3=&%T97,@;V8@*+%+ITK#N:6GINBHR"D`I*2VH0!-:6UE(*NL
MND$`L\RJ\2`R-""D<*[)JKJSS*=#M\6KUSH@`+/,JO$@-B"D<*[)JKJSS+"J
MM\6KUSH@`+/,M76Q2[U8KL2TP:E\I;RH[+3!`*Q-KF<`POBVM0"GY*2CJ.P@
M4$5!4B"E7;C+($A45%!?4F5Q=65S="X`LUVI=\#)O_*EHBX@IG"J1ZUNJ,^E
MSK-OK=/`LZ7.M7NFH:=!I;*VM[)[IF*T3K*CI<VE3"X`I^2DHZCLPK*P5*JZ
M($E$+@"GY*2CJ.RELK:WJKH@4$5!4B"E7;C+($UA:6PN`*?DI*.H[+=\M,&J
MNB!)1"X`K%"TP:1``*;FL,JV;*7S`+?%J4T`I_.W<Z3IM,$`K=>G[[KTIWT`
MO-*RU0!-;VQD;W9A+"!297!U8FQI8R!O9B`HO*^ZN*9HI<LI`$UO;F%C;R`H
MO*^OQZWT*0!-;VYG;VQI82`HNUBE:BD`I.NDSJ9^`*A#I.L`NUBVZZG4KU,`
MI.NLVP"F8K+$)62FYJ?DJ.RJNL3FINR\QJ78I'>V5Z58N7>TP25D+@"\KZRE
MK?0`IFBVLZ[)M+@`IFBVLZ[)L[$`M+BNR:9HMK,`I%6RO@"EJK*^`*5KLKX`
MI%>RO@"D5;*^`*17LKX`36]Z86UB:7%U92`HLO:D5*3QITHI`+W&O^^FH:15
MJ=2E7*_@JNT`O<:_[P"GVJJZL6*XN0"GVJJZL6*XN;CJL%0`K=.D2*^XI7@`
MK=.D2*^XI7BMMJVQL'2X;0!->6%N;6%R("B]<:AL*0"DHRRGVJ2CIE"W3@"F
M5[K9`$YA;6EB:6$@**BZILRD\:C(*0!.875R=2`HO]6^?"D`3F5P86P@**6G
MJGFZN"D`3F5T:&5R;&%N9',@*++\Q/4I`$YE=&AE<FQA;F1S($%N=&EL;&5S
M("BR_,3=IG>F8:9#M+4I`$YE='-C87!E(*RPL/+"IJJZNO2G?0!.971S8V%P
M92"^S,/2IT"\;[KTIWT`3F5T<V-A<&4@OLS#TJQ&M::Z]*=]`$YE='-C87!E
M(*?SMW.Z]*=]`$YE='-C87!E(*=`O&^Z]*=]`$YE='-C87!E(%-33""F^*I!
MOKFF5[K9`$YE='-C87!E(+[,P]*JNK7YN-$`3F5T<V-A<&4@OLS#TJNLND$`
MNO2X]*1UJ.,`L7&EO`!.97<@0V%L961O;FEA("BW<[/8J+VF:*6GJ,@I`+=S
MO%>DP,/^`+QGJTBUN2`E<P"W<Z3K`+=SJ,^ESJK,IE>ZV2`HJT2ELJUN*0!.
M97<@6F5A;&%N9"`HK\.FZ,3U*0"W<[%+O5@`MW.Q2[U8L4ZI\R5XJ.RTP2X`
MMW.Q2[U8I*.RQ:98+@"W<[7XM:$@*%]B;&%N:RD`MW.[1`"W<[M$N'.RU0"D
M5:1`J$(`I%6D0*W3O^^VM0"D5:1`K;8`3FEC87)A9W5A("BEIZ5;J=2ERBD`
M3FEG97(@**6GI.DI`$YI9V5R:6$@**E@I,ZG4:C(*0"QWZ17`$YI=64@**_#
MKDJN<2D`IU\`M4RE::C1Q>.EW*YTLJ>JNK-=J7>XZJ[&+@"U3*5II<ZJNK6F
MLJ2KV+-Y($E33R"\=KFS+@"H4Z:SI^6FN+S+IJ$N`*G2J_RI=ZJZINRX;:17
MJ%.FL[#/MO2F<Z9B`*A3IK.THZC1IN:HQK[DIE>ZV:5(J-$@34-!3"#%Y\/2
M+@"H4Z:SQ=RG\RX`M4RJ:Z9BI=BK9<5VK:VDI+Q7I5NFN,5VK:TN`*A3IK.K
M_*EWJKH@)7,@LUVI=[CJL%0N`*A3IK.K_*EWJKH@1E10(%9&4R"S7:EWN.JP
M5"X`J%.FLZO\J7>JNB!344P@5D93LUVI=[CJL%0N`*A3IK.K_*EWJKH@4U%,
M+49I;&4@5D93LUVI=[CJL%0N`+5,L]&^;,))O,8N`*6\M*.HT:78JKHN`,#)
MKM>EO*17ML<`I^2DHZCLN<^EW"X`INRX;;CJL%2I?*6\LUVI=P"I?*6\M*.H
MT:;LN&VXZK!4+@"EO+2CJ-'"LK!4+@"EO*O\J7>F5[K9+@"EO*O\J7>XN;U8
M+@"H4Z:SJ_RI=[%+O5BE2*C1($A45%`@Q>?#TBX`J%.FLZO\J7>Q2[U8I4BH
MT2!)34%0(,7GP](N`*A3IK.K_*EWL4N]6*5(J-$@2V5R8F5R;W,@Q>?#TBX`
MJ%.FLZO\J7>Q2[U8I4BHT2!,;V=I;B#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1
M(%!!4U-71"#%Y\/2+@"H4Z:SJ_RI=[%+O5BE2*C1(%--0B#%Y\/2+@"EO+_I
MI$H@3W!E;E-33""D1Z2XL/6FYL#)JKJE_KCTKGPN(%!+0U,@,3(@LU>NYJJZ
MI5NQ2[CJKL:[W:UNI<ZH[+C3M7NFH2X`J%.FLZO=O&:JNK7YI56ET[W0+@"Z
MS[K0L'3#0J6\LUVI=P"U3*[FO74`J7REO*O\J7?$YJ;LI,"Y:J9RI+@N`+5,
MKMB]=0"U3*:YP,FNUP"U3+S(IG.EV+_]I6FHT:?6J/HN`*6\ML>P9:C/I<ZJ
MS*97NMFISK%+O5@N`+5,I6FESJJZ(%A-3""XZJ[&LU&VQZ9>`*K%I=6MR`"M
M[*ELLUVI=\#)I*2GY*2CJ.RJJ:6[N.JP5"X@K:NW<[*CI<VS7:EWP,DN`*9B
MIT&JNK-=J7?`R:2DI^2DHZCLJJFEN[CJL%0N(*VKMW.RHZ7-LUVI=\#)+@"U
M3`"U3"`H=7-E(&EM<&QI8VET*0"DZ:;5L-*DY2`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@27-L86YD("B_U;K6ITJN<2D`I5^E8K)Y`$YO<G1H97)N($UA<FEA
M;F$@27-L86YD<P!.;W)W87D@**Z_J\(I`*M$I*>KX0"K1*2GJV4`I*.L3Z1`
MK=.EV+_]`+5[IJ&I?*6\I[FFJ"X`I*.S7:EW`*6\LU&DY+2I`+/&I]&__0"H
M4Z:SI6G"<\3]JKHLIEZE:"X`I%&D0*3K`+S&IG(`IG*DN+S&`*9RI+B\9:O7
M`*;FO,8`I_.W<[!TN&VX<[+5KLFEO*O\J7>\QJ78+@!/2P"JJZ7S`*JKI?.K
MV*7?JLP`I$NV::;L`*11I.L`O^RDO:O'`+=SL4N]6*6RMK>[4,+"L4N]6*2C
MIE`N`,+"L4N]6`#"PK%+O5BDHZ6_O50`3VUA;B`HJORPTBD`I76FLR!)34%0
M(*;XJD&^N:3DM*FK2*7SIUBDP*C)I5ROX"X`I76DN;-<I$"MT[9LI?.F[:=]
M+@"E=::SOM:FLZK,NU"H=++.NMZR>JW[I6FE2,7<I_.F0*C)Q7:MK0"F8K=S
MJKJU^+6AMGVQT@!/<&5N4U-,(+_YNWXZ(+5,JFNQ<2!3+TU)344@P[&SN:K^
MI?.XT;9]N.JNQBX`IF*W<ZJZM?BUH;9]L=*S<[6R`*=`MWZH=++.`+_OMK4`
M)7._[[:U`+:UI=B]<[BY`++5PK0`LM7"M+/FINP`LM7"M`"M[*ELP+.ESK5[
MIJ&\RZI/`*9B("5S.B"DI*JZK>RI;+S+JD\N`*CDI4P`J.2E3+CJL%0`OM:F
MLZK,Q7:MK0!004T@Q>?#TK5,KL0N`%!%05(Z.K9LI?.F^*I!NMT`4$=0(+S&
MINS#L;.Y`%!'4""E6[%+N.JNQ@!01U`@I+VV?:KWQE\`4$=0(*1WP[&SN2^D
M=Z5;L4L@N.JNQ@!02%`@M7NFH;U8`%!(4""O\[U:`*3(J^&D<*M"`*3(J^&P
M?:M"`*3(J^&FL[.W`*3(J^&P?;.W`*3(J^&TN`"DR*OAN7"K0@!03U-)6"!E
M>'1E;G-I;VX@O_*EH@!02%`@K_.]6E](`+G4I5(`4&%K:7-T86X@**3:L/*T
MM:E:*0!086QA=2`HJ:VO6RD`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U
M<&EE9"`HI-JPQ[2UJ5JF^[OBL,\I`%!A;F%M82`HI-JNL["H*0!087!U82!.
M97<@1W5I;F5A("BDVJ6LJ,BW<[18I+JHR"D`4&%R86=U87D@**3:J=2F8RD`
MIFBVLP"Q2[U8`+%+O5C%W*?SI[FFJ"X`L4N]6*2CI;^]5`"H4Z:SJ_RI=[%+
MO5BE2*C1(%)!1$E54R#%Y\/2+@"Q2[U8O52[>P"Q2[U8.@"Q2[U8.B``L4N]
M6*6RMK>G:Z98+@"V2Z17`+9+I%<`N/2N?`"KW;QFM6Z__:%'`*:HK?L`ILJD
MP*3Q`+#UIN:Z^\5`OMZG0`"U;J1*J^&P]:;FNOO%0+[>IT`_`,5VK:T`(B5S
M(JJZQ7:MK:6\LU&G4K"C+@"F<ZCZOD2IV@#%=JVM`,5VK:VZWK)Z`*?:JKH`
M4&5R=2`HK[6^?"D`PV2JJP!0:&EL:7!P:6YE<R`HM>&KW[NK*0"Y<;C<`,/`
MM%D`4&ET8V%I<FX`N;.OP`"]T+9II$K`>*9SKN;"2;_O`+W0O52I=ZUNLKZP
MHZ:YI+BE\SH`O="]5*EWIT&M;J2DPE^FN:2XI?.JNK-SM;(N`+W0O^FD2J1`
MK=.DZZ7WI,ZF?J7W+@"]T+_II$JW<[Q7I,##_JJZIE>ZV3H`O="_Z:1*I$"M
MTZ:SKL2JNB!)4""F[*=]`+W0O^FD2J1`K=.FLZ[$JKJDZ;3!.Z3$O^^FN:3K
MI?>JNJ3IM,$N`+W0O^FD2J1`K=.FLZ[$JKJNR;:A+@"]T+2CJ-&PW<-$JKJZ
M2ZUN+@"]T+_II$JG0:JZJ,^ESJK,IE>ZV:3.L4N]6`"]T+Y<Q:JD5:9#I+JN
M92ZG0:6RMK>F4+=.LV^HQZC&MK6D?J_@J,^ESJATLLXN`+W0O^FD2K=SJKJD
MP,/^IE>ZV3H`4&]L86YD("BJ:<3U*0"L1JIV`*?KLKP`4&]R='5G86P@*+BR
MM>6D^BD`O':YLZ;LN&T`JNVNYJ;LN&T`N[RP9;9LI?.H[+-OK=.K2*7SIU@@
M*&YO="!E;F9O<F-E9"!B>2!)34%0*0"SS*KQ("5S(*1PKLFJNJVPJT*V<3H@
M`*VPJT(\8G(@+SZ^][)V`%!R969S7VQD87`Z(*?DI*.H[*G2N]VM;JJZ($Q$
M05`@J;6F^:Y-I?,N`%!R969S7W-E<W-I;VXZ(*?DI*.H[*G2N]VM;JJZ('-E
M<W-I;VX@J;6F^:Y-I?,N`*[PP*,`KOREK:VQKO#`HSH@`*[PP*,Z(`"Y=\3]
M`*9BMW.JNK7XM:&Y=\3]O':YLP"D5Z1`K=._[[:U`*9#IDRDY:7S`*APL4NJ
M]\9?`+#=PT0`L-W#1+1YK7H`L4VNUP"THZ7<I+JN90"DO;9]JO?&7P"DO;9]
MJO?&7[ITNN(`I+VV?:KWQE^XZK!4`*2]MGTOJ'"Q2ZKWQE^Y[ZC#I;RS4;*C
MI<TN`%!U97)T;R!2:6-O("BJ::9HOJ2F52D`46%T87(@**5DN48I`*QDN-\`
MNL^ZT+!TN&T`4E-!(*2]MGVJ]\9?("@E9""F[*2X*0"_[[[<MG,`JT(`IJVF
MLZM"`+'?IK.K0@"P?:M"`*M"IK.SMP"K0L+@L[<`P$B^]Z1PNWD`I/&R=@#%
MJJCZ`,6JJ/JV;*7S`*]UJKJM;J=2L*,@)7,@MMP_(+-OMK6^WJ=`L4ZU3*IK
MJ^RT7RX`KW6JNJUNLDVPHZC/I<ZJS"`E<R"JNKCJKL:VW"`_(+-OMK6^WJ=`
ML4ZU3*IKJ^RT7RX`J/JN^+1?K>P`K:NW<[[CLGH`K:NW<[[CLGJPRKI!I=B_
M_:2XI?,Z`*VKMW.^X[)ZK=.D2*^XI7BDNJYE.@"Q8+-7JNVEW*:A`,/VP7#"
M<\3]OKD`K:O%J@"U^[W7`+NWNMVF^*I!OKD`N[>ZW;KTIWT@*&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO:&]R9&4I.@"ROK"C`+*^L*.PS[;T`+*^L*/$YJ;L
M`*5HL*.NYJ:A`+*^L*.Y[P"FVZ;XJD&^N;S(IG.EV+_]I*2ROK"CI'?`>*9S
MJKJS7:EWM7NFH2X`LKZPHP"FVZ3EI?.DI+*^L*.FN:1`N&#"20"ROK"CJ,^E
MSJK,`+*^L*.HSZ7.JLPZ("5S`+O=J$2EO+-1IE[`LSH@O_F[?KBYO5@Z`*?D
MI*.H[*G2N]VJNJI!L,@N`"4R)',@JKJS7:EWI;*VMZO\J7<@(B4Q)',B`%9&
M4R"JNK-=J7>ELK:WJ_RI=R`B)7,B`+-=J7>XZJ[&I;*VMZO\J7<@(B5S(@"E
MLK:WQ.:F[`"MJ[-=`*VKLUVQ2[U8`*VKLUVG0:JZL4N]6#H`IEZF<[/,J^&D
M0*W3K&2XWP"ULJI'`*KPIEZ_[[:U`*9!IKB_Z:1*MW.Q2[U8`%)E=6YI;VX@
M**]DI:>I]*YQ*0"F7K1?LUVI=P"Z]*VVO7._Z+ZYO^^VM0#!O+MY`*5KP^0`
MI6O#Y*KMP%D`I6O#Y*W(`*9#I+JN95]W+BXN`*BDIN(`4F]M86YI82`HP[FP
MJ*6GJ,@I`+';PN`@,3@P(*O7`+!FKLFP=R`Y,""KU[';PN``MK:NR;!W(#DP
M(*O7L=O"X`"F0Z2ZKF4`ID.DNJYE`*9#`*[FO74`Q.:F[+M0ID.NYKUU`,3F
MINRNYKUU`*9#KN:]=0"P]:;F`%)U<W-I86X@1F5D97)A=&EO;B`HJUC#N;2U
M*0!2=V%N9&$@*+]CIG>Y1BD`4R]-24U%(*5;L4O#L;.Y`+9LI?.D=ZC/I<X@
M4R]-24U%(*5;L4L`4T%33"#%Y\/2M4RNQ"X`PK*P5`"XZJ[&KG>O\[U:`*5;
ML4NRU[K=OO<`IJBE7`"XZJ[&KG>O\[U:7U$`K%"TP:2[`%-A:6YT($AE;&5N
M82`HN'2[KK#'K\<I`%-A:6YT($MI='1S(&%N9"!.979I<R`HN'2G2JB]M+6F
M:+K6I,ZEI[K[M+4I`%-A:6YT($QU8VEA("BX=,53INBHR"D`4V%I;G0@4&EE
M<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D
M:6YE<R`HN'2DY;3+I,ZNYK?GJ+JD0BD`IE"D0*W3M?BUH2`H7W-E;&8I`%-A
M;6]A("C"Q+ROJ,BX<ZYQ*0!386X@36%R:6YO("BX=+"HIU&_U2D`4V%O(%1O
M;64@86YD(%!R:6YC:7!E("BX=*9HK/RDSK2VJDRFZ*3Q*0"]PZQ0M*.HT:K,
M`%-A=61I($%R86)I82`HJ$:O4:9AJORIU*="*0#`>*9S`,!XIG,@(B5S(@#`
M>*9S("5S`,!XIG._[[:U`+%.LJ.ES:JZLUVI=\#)I4@@4$A0(+MYJ*6NYJ:A
MP'BF<ZCLIT&JNJ;XJD&^N;S(IG.EV+_]I*0N`+-=J7<@)7,@I'?`>*9S+@"G
M\[=SM7NFH:1WP'BF<ZCL.B`B)7,B+@"Y<ZQ0N7"K0@"L[+['`+=JM$T`MVJT
M3:3>P+H`O^^^W,#)KM<`O^^^W*1`K=.DZ;3!`+_OOMRD0*W3N'.RU:7.I4BW
M<[Q7`+_OOMRD0*;LMW.JNK[6IK.JS`"_[[[<I$"SH:;XJD&^N0"_[[[<I$"F
M[*C/I<ZJS*7.I4BW<[Q7`+_OOMRITJ:S`+_OOMRITJ:SI.FTP:2XI?,N`+_O
MOMRD0*W3JJNE\P"DH[_OOMP`J?.E2*15JKJU^+6AI*2_[ZCZIT&M;JJZIG*D
MN"ZE2+?&N:N]QKMSJ=*_[Z3EIG(LM4VKX;9+I%>DY:7SO7._Z+#/+@"_[[[<
MI.FTP:3`N6HZ`+_OOMRDZ;3!I.FTP:[FIJ$Z`+_OOMRQ_<7<I_.JNJBMI??#
MT:=/.@"_[[[<KLFVH:3`N6HZ`+_OOMRDZ;3!KLFVH:[FIJ$Z`+_OOMRLVZ2L
MI,>P=*JZI$>MT\3FINPN`+_OOMRG0:JZPT.FXK!TN&T`O^^^W+"^IFZ[>:BE
M.@"VQ[!EL-W#1*3/P+,`ML>P9<*RL%0`4V5N96=A;"`HMNNDNJ5;NK@I`+=0
MM/J^N3H@`*1%I.L`4V5R8FEA(&%N9"!-;VYT96YE9W)O("BVZ[JXNONHR+M0
MNUBO4Z6GK?3#N2D`I\>XN0"F^*I!OKFXZJ[&O_F[?JG.JLRU3*IKJ,^ESBX`
MMWRTP;K>LGH`MWRTP2!)1""D=[E,M,$N`+=\M,$`KM:H^J3HMO0`I+FS7*=!
MJ?.GT;!/L4N]6*JZKLFMU"RE::5(IMNFYJVKLUVQ2[U8+@"S7:EWN[>ZW:;X
MJD&^N:17Q-VI\Z=!JKJMTZ1(K[BE>"X`LUVI=Z=!JKJPOJ9NNWFHI2P@KLFP
MSZ5(I,ZDZ;3!KN:FH2X`LUVI=Z=!JKJQTJELP+.ESK5[IJ$LPT.FXK!TN&TL
MK;:ML:?SMW/`5[)V+*3.J.2E3,7CI=R_[[:U+@"S7:EW`*?SMW.U>Z:AM$ZZ
M_`"FLZ9NM%BMTZ9APDFI3;-OK=.PT;S&IK/#]CH@`%-E>6-H96QL97,@*+;K
MJ?6ZN"D`P<JJJP#"LK5UNDNM;@"L3Z=?K+"D:K.AI?>JNK-SM;*I=[AQI]:Q
MMJ5<K^#!Y#\`Q>.EW`#%XZ7<MW.RHZ7-NU"M[,!XIG.S7:EWP,FJNJYTLJ<N
M`*A#IKBU;J1*J^'%XZ7<I%>D0*:XJKJU;J1*KLFVH2`_`,7CI=S"2;_OOKD`
MQ>.EW*KMKN:^WJ=`I5ROX*KM(#\`J?.EJL/DQ>.EW"`E<R"E7*_@JNT_`,7C
MI=S`>*9SKN:DNJYEN>^XW*3HMO0`Q>.EW*KMKN:DNJYEN>^XW*3HMO0`Q>.E
MW*9#I+JN9;GON-RDZ+;T`,7CI=R\=KFSI+JN9;GON-RDZ+;T`,7CI=RD5[;'
M`*OYQ/*P?:M"`*:MIK.P?:M"`+'?IK.P?:M"`+NWI.BFL[!]JT(`IJS!60!3
M:65R<F$@3&5O;F4@*+?@I&RD<[#J*0"U^:55`,.QL[D`P[&SN;ITNN(`4VEN
M9V%P;W)E("BW<Z5;J5DI`*1JI'``LJ2Y3+K[Q4``4VQO=F%K:6$@*+2UK*6E
M[Z=**0!3;&]V96YI82`HM+6LI:7OI:>HR"D`L[<`L'VSMP"P?;.W`*:MIK.P
M?;.W`+'?IK.P?;.W`+]NL[>R8*O7.B``4V]L;VUO;B!)<VQA;F1S("BOP<.Y
MJOFX<ZYQ*0!3;VUA;&EA("BOP;"HIU&HR"D`NG&[4+C6`+'&ID.DZ*96O^^^
MW`"HT[>]IF&G?0!3;W5T:"!!9G)I8V$@**MNJT0I`*MNO-H@*$E33RTX.#4Y
M+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA
M;F1S`*MNI6*R>0"JQ:75IN8`MJ&V6@"VH;9:NU"YU*52`%-P86EN("BFZ*]:
MI/HI`*E5IZ.V;*7S`*]3KNVF<J2XO^FD2@"DP+/.P'BF<P"DP+/.Q.:F[`"D
MP+/.ID,`N4*PR@!3<FD@3&%N:V$@*+2UJ+W$]:5D*0"\T+?'`*Q0N]JJI\51
MOM0`L=*I;*9^I?<`K-D`JJRZ00#`>*9SKN:FH0"U\[E$`*=2L*.]=0"F<J;J
MID,`IMNV;*7SIF&G?:2DI6BPH[KTL.RF5[K9`+S+IJ$@6T-34UT`K%"TP:31
M`*?DI*.H[*:XI=B__2`B)7,B`*5$IJX`L&6E6`"\5Z5;("(E<R(@J.RH=++.
MJKJET[W0I'>P9:58+B"G0:6RMK>UI:CLN-.ET[W0LU&NUJWCJ^&D?J_@M6ZD
M2BX`I%6\T`"FJ*5<`*:HI5RJNJ5;I$H@(B5S(B"H[*ATLLZDI"X`IJBE7*JZ
MIMNH=++.I*2R3;"CJ,^ESJK,("(E<R(@JKJXZJ[&+@`B)7,BI'>G4K"CI[FF
MJ"X`IJBE7*JZIMNH=++.I*2ROK"C("(E<R(N`*1WIJBE7*JZIEZT7[-=J7<N
M(+W0K:NW<[C\I$K`R[7XKG2RIRX`I'>FJ*5<JKJSQJ7WLUVI=[CJKL8N`*1W
MIJBE7*JZL\:E][-=J7>XZJ[&("5S+@"FJ*5<JKJG\[=S("(E<R(`I'>FJ*5<
MJKK"T+QG("5S`%-U9&%N("C$K*2F*0"Z2ZUN`*3II5@`I.FXJ`"TN`"DZ:58
M`*3II5@OI.FXJ`"DZ:58.B``I.FXJ`"DZ;BH.B``I%>\T`"DY+2I`%-U<FEN
M86UE("C$K*=1JVXI`+KON+D`4W9A;&)A<F0@86YD($IA;B!-87EE;@!3=V%Z
M:6QA;F0@**5VI<O`V<3U*0!3=V5D96X@*+?GJ.4I`%-W:71Z97)L86YD("BW
MYZ1H*0"F4*A"L$^__:1WIU*PHP"F4*A"IN:PRKC+N&T`MVJT3;:UI=BDI*JZ
MNWFJ:[_YNWX`4WER:6%N($%R86(@4F5P=6)L:6,@*+'4IU&HR"D`N7"K0@"Y
M<*M"IK.MMP"Y<*M"`*:MIK.K^<3RN7"K0@!404(@I,"Y:J[FIJ'`R:[7`*KM
ML^8`JNVNYJ2ZKF4`JNVNYJ2ZKF4`I7C&5P"E>,97`%1A:FEK:7-T86X@*+;P
MIDZTM:E:*0!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F("BI6JE\I:>H
MR"D`I=B\T#H`J]V_[*C&MK4`N7&XW+BYO5@`L\RJ\:1`I'"NR:JZM\6KUSH@
M`+?%J]<`M\6KUSH@`+?%J]<\8G(@+SXH)7.PJB5S+R5SIT,E<RD@)F1E9SLE
M<P"GY*2CJ.R\RZI/("(E<R(N`+S+JD^ZWK)Z`*2ZKF4`K\*DY:9R`+GON_2D
MY:9R`+GON_2DY:9RL[NZW0"L4+3!I7P`KO6DY2`H5$E3+38R,"D`5&AA:6QA
M;F0@**[UL.HI`$944""IM:;Y*&5X=&5N<VEO;BFU3*[$+@!(;W)D92]+;VQA
M8B"^XZ98I'6U>ZC#I;RDY+2I("(E<R(`24U34""L]K_]M4RJ:[-1JNRI;"X`
M36%I;G1E;F%N8V4@P_ZG3ZC#I;RFJ*5<N/RD2@"_[[:UM?BUH:5(P_:SK"["
M][9]I*0N`*=!JKJH=++.NMZR>JW[I;*VMZ7]LUVI=Z9NI$"MT\5VK:VKX;K=
MI'ZOX,7]IT&HSZ7.Q7:MK:ATLLXN`*FSKMB]=0#!<+6XN+F]6*6\J_RI=RRJ
MQ:75J<ZF8KCJKL:N=Z2DI^2DHZCL+@"D=Z:HI5RJNK%.P7"UN*1(MW.\5Z;<
MLW&P5+_]I*0N`,7GP]*V;*7SP[&SN;O=K6ZFLZ1`K=.D=[C1MGVJNB!01U`@
ML,^V]"X`L'2X;;ASLM6JNL/1IT^XN;U8*$E$*:2CK$^EO*O\J7<LM$ZL3ZK%
MI=6ISJK,I*.F8KCJKL:N=Z2D+@"P=+AMN'.RU:6\J_RI=RX`N]VM;J1`K=.X
M9[E,I5NQ2ZJZNO2X]+-SM;(N`,#)KM<@)7,@P+.XTZ5=IW2D0*W3("5S(+-=
MJ7<N`,#)KM<@)7,@P+.XTZ5=IW2D0*C'("5S(+-=J7<N`+5,JFN]QKMSJ.RF
MVZBMP,FNURX`IKG`R:[7I*2H4Z:SN.JNQBX`I4BD5:Q/(')F8S@R,B"V;*7S
MJKJJ[<!9+@"HK:7WP]&G3R`E<R"D=[-1IU*PHRX`I:JNV+UU`$=N=5!'(*1'
MI+C`R:JZN/2N?*6RMK>I=[AQIF(@0W)Y<'1?<&=P.CH@P_ZG3Z2D+@"G0;2_
MJ?,@)7,@L4BUN2`E<R"D0*O*I42FKJRP("(E<R(@JKJK2*7SI'>S4;9]L=(N
M"J;]LV^HPZ2CK^"K3\/2N-.K2*7SJKJDNJYEI'>GN:7^LU&FK*7SI$BLW:>Y
MJ<ZD1KC1+@"S<[6RJ.R]<[QGMFRE\ZVVK;&ITJC/I<ZJNJ97NMD`I;*VMZQ/
MI$"MT[S&IG(N`$AO<F1E7T-R>7!T7W-M:6UE.CH@P_ZG3RRELKO=K6ZFLR!O
M<&5N<W-L(+S2LM4N`*:YL+ZF;B`B)7,B(+CJKL:F7:RPME>Y3+/,I&JDN;-<
MK<@LJ=*E2+5,JFNS4<!XIG,`I<ZE2,#+M?BFN;CJKL;#_JNL("@E<RD@JKJU
M>Z:AJ,.DHZ9SIF*I\ZATLLZD5RX`I-ZM>J9RI;*VMZRPL^:D0*9RI+@N`*6J
MI6NNV+UU`*5KKMB]=0#$YJ;LI,"Y:J9RI;*VMZRPL^:D0*9RI+@N`*:YIOBJ
M0;ZY("(E<R(@I'>S4:=2L*,N`*:YIOBJ0;ZY("(E<R(@I'>S4<!XIG,N`"5S
M(*JZM?FE5;O=J$2D=[-1LKZPHRX`J_RI=ZJZL$^__:C#I*.F<Z9B+@"\R*9S
MP,FNUR(E<R*DHZ9SIF(N`*=!J=*_Z:1*JKJXZJ[&NU"U9:VQN.JNQJ2CLL4N
M`*17I%6NV+UU`*17KMB]=0"Q<:17I$"MTZA"QDJDIZOAI%>VQZJZN.JNQK_R
MI:(N`*17ML?`R:[7J,.EO+-1P'BF<RX`=V5A=&AE<BYC;VT@L,^V]+5,JFNH
MSZ7.+@"GY*2CJ.R\RZ:AL'2X;:78O_T@(B5S(BX`M4RE::7.JKJ_[[:U+@"U
M3*K^I?.E::J]L;6V?;'2+@"FN<3FINRDI*5=IW2DTZ9HJKJF<KS&+J=!I'>_
MZ:1*("5S(*W3IG*\QCNG0;_II$JJNJ9RO,:ELK:WI'"I\R`E<RX`MW.\5R`B
M)7,B(*CLJ'2RSCH@)7,@KLFU;Z7-I$"MT[#=PT0N`*;;J'2RSK)-L*,@(B5S
M(B"JNKCJKL:NR;5OI<VD0*W3L-W#1#H`IMNH=++.LKZPHR`B)7,B(*[)M6^E
MS:1`K=.PW<-$.@"G\[=S("(E<R(Z("5S(*[)M6^ES:1`K=.PW<-$`*17ML?`
MR:[7KLFU;Z7-I$"MT[#=PT0Z("5S(*6\LU&D5[;'+@"D5[;'P,FNUZ[)M6^E
MS:1`K=.PW<-$.B`E<R"D:J1PME>Y3*2YLURSS*1JK<@@*"5D(&)Y=&5S*2X`
MI%>VQ\#)KM>NR;5OI<VD0*W3L-W#1#H@MLBSH:3`JKH@)7,@P,FNU[-1I%>V
MQRX`P,NU^+9LI?.NR;5OI<VD0*W3O_F[?BX`MM>D2J:YLW&P5+_]N.JNQJ[)
MM6^ES;_YNWXN`+;7I$H@:4-A;&5N9&%R(+CJKL:NR;5OI<VD0*W3O_F[?BX`
MIF*S7:EWJNVSYJ2DM6^ES:1&I$"MT[_YNWXNIK.E::_@IT&_\KI\I$:ELK:W
MMO&\9ZJZQ.:F["X`L/6FYK-QL%2__:O\J7>E7*_@KLFU;Z7-I$"MT[_YNWXN
M(+W0M7FKX:9!N-6D0*:X+@"G\[=SP7"UN*1(N.JNQJ[)M6^ES:1&I$"MT[_Y
MNWXN(+W0M7FKX:9!N-4N`*?SMW.P=+AMN'.RU:[)M6^ES:1&I$"MT[_YNWXN
M(+W0M7FKX:9!N-4N`*:Y($E-05`@IOBJ0;ZYJ,.EO*3DM*FK2*7SIUBDP*C)
MI5ROX"X`LV^F_*5'I*.L3Z6_O52JNB!R87(@P*/!6<#)KM<N`+-OIORE1Z2C
MK$^EO[U4JKH@>FEP(,"CP5G`R:[7+@"S;Z;\I4>DHZQ/I;^]5*JZJTBESJ5D
MN+F]6"X`IKG$YJ;LK$^ELKO=K6ZJNBX`IKG$YJ;LI+JN9:5UI+FS7+[CO,:\
MQJ9R+@"FN<3FINRDNJYEI76DN;-<O,:F<J3.JU^XN2X`IKG$YJ;LI+JN9:5U
MI+FS7*1+MFFF[+S&K<@N`*:YQ.:F[*2ZKF6ELK:WK+"S<KBYJ<ZJQ:75I,"Y
M:JJZO,:F<@"ELK:WK$^D0*W3O,:F<BX`IKG$YJ;LI+JN9:6RMK>E7:=TI$"R
MU:11I+NV::;LJKH@4D="(,-#IN*E3KU8+*C2IG`@)R,Q,C,T868G+@"S;ZW3
MJNVSYJ1WLU&S0K)ZN4PN`+-OK$\@)7,N`+-OK$\@2V]L86(@N'.RU:JZI$"M
MTZJKI?,N(+']P,NU^*:YJJNE\[O=K6ZOX*3DM*E+;VQA8B"X<[+5KN:FH:JZ
MN7&D;+9LI?.S;L7I+KW0L-&FTB`E<R"E2*1&N-&S;ZC'MFRE\[-NQ>D`LV^K
MRK9LI?.HPZM$I4BG0;I$I<ZJNJ9RI+BVL*;3K$^HSZ7.("@E<RD@KM&\9Z;3
MIJ@N`*:YO,:MR+/,I-:ELK:WK$\@,2X`IKFF^*I!OKFU3*IKN>\@>FEP(*3.
M(&=Z:7`@KN:FH<#)KM>V::;FN-'`H\%9`*:YJ'2RSJ78JV6L3["QI<ZJNJJL
MND$N`*6RMK>L3Z1`K=.\QJ9R+@"FN;7XM:&ELK:WK6ZET;_OMK6U^+6A*$]P
M=&EO;BFITJE)I7,`N7``L-W#1+!LPMP`KLFVH0"NR;:AJ_RK;@"NR;:AKN:F
MH0"NR;#/O^^^W`!4:6UO<BU,97-T90"\T,-$`+S0PT0@*'1O;VQT:7`I.@"F
MK*7SI$@`IG"J1ZUNO<:_[RR]T*9BPDF_[[?&N:NJNJ90KLFK]B!#;VYT<F]L
MP>0HK=.D2+EQN*,I(*G.($-O;6UA;F3!Y"C$JZI'N7&XHRDN`*2UI-$`2%1-
M3""M[*ELP,D`5&]G;R`HIFBM]"D`5&]K96QA=0"I^J31`%1O;F=A("BJ1J5;
M*0"SN[.A`+/,I%>\:*[8K%L@*%]T;W`I`*1DJ+VY1J3.IJNHJ:WT`*]UJ<ZP
ML`"L4+3!I$<`5'5N:7-I82`HK/"EIZ;HJ,@I`%1U<FME>2`HI&>FU:CD*0"D
M9Z;5J.2DY2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4@**1GI<N^?"D`O^FD2J=!JKJ_[[[<.B``
MM;6E?KUUJ_R\QCH@`+KTIWT`NO2G?3H`56=A;F1A("BO4:1ZN48I`%5K<F%I
M;F4@**]1ITK$]2D`M4RJ:Z9SJ/H@5D93(*78O_TN`+7YI56NR;5,JFN\5Z5;
MPT*E?JJZJ,^ESJK,N.JP5"X`M4RJ:Z?OQ=P@5D93(,#)KM<@(B5S(B"JNL5V
MK:TN`+5,JFO%W*?S(%9&4R#`R:[7("5S+R5S(*JZQ7:MK2X`M4RJ:\7<I_.L
ML"`E<RX`M4RJ:\#+K&3`R:[7I&JD<"`B)7,B+@"U3*IKP,NL9,#)KM>D:J1P
M("(E<R\E<R(N`+5,JFNS<[6R(%-13""F^*I!OKDN`+5,JFNHSZ7.(%-33""S
M<[6R+@"U3*IKO<:[<R!61E,@P,FNURX`M4RJ:ZO8I=\@5D93(*78O_T@(B5S
M(BX`M4RJ:ZO8I=\@5D93(*78O_TN`+5,JFNKV*7?(%9&4R#`R:[7+@"U3*IK
MJ]BEWR!61E,@I=B__2`B)7,B+@"U3*IKJ]BEWZK%I=6JNB!61E,@P,FNURX`
MM4RJ:[%.N.JNQKC1P*/!62X`M4RJ:Z=2L*,@(B5S(BRFN:78O_VHPZM$JL6E
MU2X`M4RJ:Z=2L*,@(B5S(CH@)7,`M4RJ:Z=2L*,@)7,LIKFEV+_]J,.K1*K%
MI=4`M4RJ:[N\L&JG4K"CI=B__2X`M4RJ:Z=2L*,@5D93(*78O_TN`+5,JFNG
M4K"C(%9&4R"EV+_].B`E<RX`M4RJ:Z=2L*,@5D93(,#)KM<@(B5S(BX`M4RJ
M:Z=2L*,@5D93(,#)KM<N`+5,JFNG4K"C(%9&4R"EV+_]("(E<R(N`+5,JFN[
MO+!JIU*PHR!61E,Z("5S+@"U3*IKIU#"7Z78JV6JNJ78O_TN`+5,JFNXT;9]
MOLS#TK+3N&``M4RJ:[C\I$HE<ZJZJ7>X<2X`M4RJ:[=HLKX@5D93(,#)KM<N
M`+5,JFNV?;'2(%9&4R#`R:[7("(E<R(N`+5,JFN\9Z1*(%9&4R#`R:[7+@"U
M3*IKMGVQTB!61E,@P,FNURX`M4RJ:[9]L=+`H\%9P,DN`+5,JFO%JJCZ(%9&
M4R#`R:[7("AF:6QE<VEZ92@I(&9A:6QE9"DN`+5,JFO%JJCZ(%9&4R#`R:[7
M("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`+5,JFO%JJCZP,FNUSH@`+5,JFO%
MJJCZ('9F<W)O;W0@I=B__2X`M4RJ:Z?SIE<@)7,@K+`@)7,Z(*9=K+"EV+S0
MJTBE\Z=8I'>F<Z9B`+5,JFO%W*?S(%9&4R"EV+_]JKJF5[K9+@"U3*IKLKZP
MHR!61E,@I=B__3H@)7,N`+5,JFO%W*?S(%9&4R#`R:[7("(E<R(@JKJF5[K9
M+@"U3*IKQ=RG\R!61E,@P,FNUR`E<R\E<R"JNJ97NMDN`+5,JFO%W*?S(%9&
M4R#`R:[7JKJF5[K9+@"U3*IKL/6FYB`G;6MI<V]F<R<N`+5,JFO"X+2K(%=O
M<F0@I.6E\P"U3*IKO&>D2B!61E,@(B5S(B#`R:[7+@"U3*IKO&>D2B!61E,@
MP,FNUR`H8V]P>2@I(&9A:6QE9"DN`+5,JFN\9Z1*(%9&4R#`R:[7N.JNQBX`
MM4RJ:[QGI$H@5D93(,#)KM<L(+K/NM"P=,-"I'>ZH2X`J;.]=0"H^J[XI_.G
M[P"T7ZWL`*;XJD&^N;-SM;*NR;5OI<VEO+EWM,&JNJ9>P+,Z(`"U;Z7-I;RY
M=[3!JKJF7L"S+*71IOBJ0;ZY.B``I;RDP,/^`+A5L.J]6"`H551&+3@I`%5N
M:71E9"!!<F%B($5M:7)A=&5S("BJ_*G4IT+!<*98I&JDO;#J*0!5;FET960@
M2VEN9V1O;2`HK5ZPZBD`56YI=&5D(%-T871E<R`HK/RPZBD`56YI=&5D(%-T
M871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`+/FINP`I;RJOJJZ`*6\JKZJ
MNB!!4$D@L%2NI[USN+D@*$%022!-97-S86=E($E$*2X`I;RJOJJZJ\BDX;!4
MKJ>]<[BY("A!4$D@365S<V%G92!)1"DN`*6\JKZJNJ;LN&VXZK!4+@"EO*J^
MJKJHSZ7.JLRF5[K9J<ZQ2[U8+@"DI,)?I=BK9:2XI?.JNK-SM;(`I;RI4J97
M`*9=IG>E_L55O'NDHZ2YLUREO+'"Q7:JNK5[IJ&P]:;FL,6D52^]QKMS+[9+
MI%<N(,))O^^]5*EWI4C`R[7X(&UO>FEL;&$N;W)G(*G2M*.HT:JZK-O#]J?>
MLTZDY:7S+,7]IT&E::5(N-&PHZ:YI$"MK:CNJ,.FVZ;FMGVI\;5[IJ&F<ZCZ
ML,6V2\.O+@"H^J[XPT.FX@"EO*3DM*FJNK#&P,FF5P#%W*?S`*?SMW,@)7,`
MI_.W<ZC/I<ZJS``B)7,BI'>G\[=S+@"G\[=SM7NFH:1WIU*PHRX`I%>VQP"D
M=Z17ML>ITJ:SP+.ESK5[IJ&JNK-=J7?`R:CLIOBJ0;ZY+@"D:KQGJ=2D0KS&
MIG(`I&J\9\.YL*B\QJ9R`%5R=6=U87D@**]1J=2F8RD`J,^ESJ78JV6JNCH@
M)7,`J,^ESB!34TP`IG"J1Z=!JKJHSZ7.JLRF5[K9+[%+O5B[4"!)35-0(*;X
MJD&^N:2CIE`LI6FF8J:YLUVI=RX`J,^ESJK,`*C/I<ZJS"`E<R"EO+-QN4P@
M)7,@JKJQPL5VQ>?#TBX`J,^ESJK,NMZR>@"HSZ7.JLR_[[:U`*C/I<ZJS+7Y
MI54`IKFON*5XJKJHSZ7.JLRU^:55J'2RSJ1WL+&ESBX`I^2DHZCLJ,^ESJK,
ML6*XN0"HSZ7.JLRF5[K9`*C/I<ZJS*97NMD@(B5S(B"D=Z9SIF(N`*C/I<ZJ
MS*97NMDZ`*C/I<ZJS#H@`*ATLLZDI*JZJ,^ESJK,.@!5>F)E:VES=&%N("BO
M4:_WIT^G2BD`5D93(*78O_VHPZ2CIG.F8BX`L+*TP0"D=Z?DJ.RFLZ[$JKJF
M8<)).B``IK.NQ*G*`*5(I,#$P:RPL^:F["BQ<;)[IF*P7[KB*0"MR`"_[ZCZ
MK<BFVP!686YU871U("BERZ6CJORYSRD`Q=RDQ@!696YE>G5E;&$@**EEI+JW
MYZG4*0#%Y\/2I:*QT2`M(*:YMFRE\Z5IK^"D=[Y$I$B^U:;;OWFG[RX`JJFE
MNP"JJ:6[L;&H[@"KJZJ]N>^[]`"KJZJ]N=2E4@"KJZJ].@"K1+%@L*H`5FEE
M="!.86T@*+96JVXI`+96JVZDY2`H5DE30TE)*0#`R[7X("5S`*9BMW.U^+6A
MMGVQT@"E2"`E<R#`R[7X`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H("BM7L3=
MNONHRKASKG$I`%9I<F=I;B!)<VQA;F1S+"!5+E,N("BL_,3=NONHRKASKG$I
M`*_@J*.KUP"OX*BCJ]<Z(`"X<:1JIU&E\;QWK;>Y<:M(I+VE<;-ZN4P@4TU4
M4`#$M:=I`,2UIVDA(2$@L7$@)7,@I.*PRK*^L*.U>Z:A+@!724X@N&>ET2!(
M5%10`%=A;&QI<R!A;F0@1G5T=6YA`,2UIVD`K%"TP:14`*31KO"Y=[3Z`*[P
MMDBXZJ[&M*.HT0!W96%T:&5R+F-O;2"Z]*^X`+KTK[@`NO2ON`"H0[9G`,5W
MJN\`Q7>J[ZCL("5S`,5WJN\L("5S`*;HO-H@*$E33RTX.#4Y+3$I`*;HO-H@
M*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R82`HINB\NZNBJ=0I`+5NI$JK
MX<"SN-.E_<7CI=P@)7,@K?ZD0*W3P+.ESK5[IJ$_`,3FINRJNJ3`N6JF<J2X
M/P"DWJUZJKJK9;AMIG*DN#\`5VAE<F5I<R!!=7-T<F%L:6$@IF&YSP"M_JW3
MI.NLVP"Z]*VVO7._Z+ZYJKJTH:7S*'!L=6=I;G,IL=*PRK&QJ.XN`+QEJ]<`
MI4@@0U-3(*RPL^:F[*JZO&6KUP"EJL/D)7.E7*_@JNVJNKQEJ]<HI%6FN+5N
MI$JI;*7-KL0I.@"J[:[FO&6KUP"\9:O7L^:F[`"\9:O7.@"VL,7IL]"G0`"M
MMP"FK::SK;<`K;>S="BX8"D`K;>S=#H`K;>S=#H@`+2\O'H`M,&KW<*GJJL`
MI'6G0`"_[*2]J\>F8:=]`+_LI+VKQ[EQN-P`LL0E9*;FJKK$YJ;LO,:EV*2C
MI;^]5"X@P+.XTZUNIK,E9*W3Q.:F["RE=:?DJ.PE9*W3Q.:F["X`Q.:F[+S&
MI=BDHZ6_O50N(,"SN-.M;J:S)62MT\3FINPLI76GY*CL)62MT\3FINPN`%@U
M,#EV,R"IM:;YJO?&7[MYJFL`6#4P.78S(*5$IJZTP*5.IE>ZV0!8-3`Y=C,@
MI42FKJKWQE_#T:=/JLP`6#4P.78S(+#&P,FF5P"F?@"F?@!986AO;R`A(*9A
MN<\`J$.F?@!996UE;B`HN*VJ^2D`K$\`K$^JNBRGVJ90MTX`IT&EV*MEJ,^E
MSJ_"I.6F<KUSO&>\TJ:A+B"HSZ7.(%L\/ET@J_:V<Z5II,&TJZRPNO2MMKUS
MO&>\TJ:A+@"DHZ2YLURG0:O8I=\E9*5(I%>JNK#/MO0N`*=!I;RS4;'"Q78N
M`*=!JKJE_J97I*2DHZ5IIK,@)UPG(+-OO,NJNJ9RI+@N(`"G0:C#I;R_Z:1*
MI$"MTZ:SKL2JNKEQI&RV;*7SINRG?2X`IT&HPZ6\I=&VUZ1*JKK`R:[7I*2Y
M[ZQ-I?2F\\3FINRH["`E<P"G0:1WN&>U;J58+@"]T+_II$JD0*W3IK.NQ*JZ
MN7&XW+BYO5@LL.J[VKEQN-RXN;U8MLBE=:2YLUR\QJ9RN+F]6"RHP[7XL:&J
M<*5IJ?.K9:VQID&E6Z1`K=,@)RLG+@"G0:6RMK>_Z:1*I$"MTZ:SKL2JNJW(
M+@"G0:6RMK>E_;-7N;JF;K[PJJRXZJ[&*$1A=&%4<F5E*:;XJD&ZW:1^K^#$
M?L3RJ,^ESK=SI<ZDX;7YI56J0;#(+@"G0:6RMK>E_;-7N;JD0*W3M>K`P,#)
MKM>H=++.*%9&4RFF^*I!NMTN`+W0M'FM>K#=PT2A0:9BIT&VQ[!EL-W#1+/X
MIVFDIZME+@"G0:6RMK>_Z:1*IKFS<[6RJ=*K_*96JKJZ]*=]`+W0J_RI=ZUN
MIU*PHZJZIOBJ0;ZY+@"]T*O\J7>M;K)-L*.JNJC/I<ZJS"X`O="K_*EWK6ZR
MOK"CJKJHSZ7.JLPN`+W0J_RI=ZUNMW.\5ZJZJ,^ESJK,+@"]T*O\J7>M;J?S
MMW.JNJC/I<ZJS"X`O="K_*EWK6ZP]:;FJKJG0*7.+@"G0:6RMK>_Z:1*MW.D
MP,/^JKJF5[K9+@"G0:6RMK>THZC1I$"MT[AQI&JG4;G2I+JJNKEQN-RXN;U8
M`*=!JKH@)7,@MWRTP:1WN4RNR2Z]T*VKMW.U;J1*+@"G0:JZN7&D;+9LI?.F
M[:=]`*=!JKJQ2*7SI$BY<:1LMFRE\Z;MIWTZ`*=!JKJXZK!4`*;;L7&G0:JZ
M("5S(+=\M,&V?:ELI4BHTZ=!JKJZ]+O:NO2X]*;LIWVD=\7<I_,N(*RPJT_%
M0*=!JKJF=Z7^L%^HHZ%!IT&ELK:WK:NW<[5NI$HN`*=!JKJF5[K9`*=!JKK%
MY\/2IOBJ0;K=J,.DHZ3DM*FW<[Q7J,^ESJK,+B"F<*I'IT&GQK'FNMZR>JC/
MI<ZJS+%BN+DLIT&ELK:WI72_[ZCDI4RJNL7GP]*F^*I!NMTN`*=!JKK%Y\/2
MNMVHPZ6\I.2TJ:9#I5BHSZ7.JLRISKC3I5ROX*1WLU'#]K.L+@"FV[%QIT&J
MNB`E<R"W?+3!MGVI;*5(J-.G0:JZPG/$_;ZYIORE1Z1WQ=RG\RX@K+"K3\5`
MIT&JNJ9WI?ZP7ZBCH4&G0:6RMK>MJ[=SM6ZD2BX`IT&JNL)SQ/V^N:C#I;RD
MY+2ILV^MTZ5<K^`N`*=!JKK"<\3]OKFHPZ6\I.2TJ:9#IDR_[[:U+KW0J_8@
M0U123"]#;VUM86YD("L@4""F0Z9,+@"G0:78JV6ITK-=J7>JNJ[)L,\Z`+O5
MI%6Y=[-=JKJHK:7WP]&G3Z1WQ=RG\RX`N]6D5;EWLUVJNJBMI??#T:=/.@"G
M0:JZI?ZF5SH`IT&JNK5NI$JD=ZCLM,$N`*=!IF(@)7,@I*2JNK=SL4N]6*Q/
M.B`E<P"G0:9BM6ZD2K3!MJ&JNK_OMK6D=[-1I_.W<RX`IT&JNK_OMK6D=Z?S
MMW,N`*=!JKJQ2[U8I'>MJ[=SLUVI=P"Q2[U8I'>S4:VKMW.S7:EW++=SJKJQ
M2[U8I'>S>KE,N7&D;+9LI?.Q2+5OO="E2+C3L4N]6+5NI$HN`*=!JKJQ2[U8
MI'>H[+3!+@"G0:JZN[>ZW:;XJD&^N3H`675G;W-L879I82`HJVZTM:G4I-(I
M`%IA:7)E("C"Q*7L*0!:86UB:6$@**E\I/&HR"D`6FEM8F%B=V4@**BOI-JK
MPBD`6\'TPL.DWJUZ70!;L-W#1*3/K$U=`%O%XZ7<I-ZM>B`M`%O%XZ7<I-ZM
M>B`M("5S(*;F70!;INRI\Z;F("5S(*9`("5S(*;F70"ZWK)Z7T$`J5*E3Z9#
M7T,`OO"JK+CJKL9?1`"G4K"CID-?1`"X<[+57T<`NZ&I^E](`+QVN;.DNJYE
M7TDN+BX`M6ZD2E],`+5NI5A?3`"MUZ?OLW.ULE]-+BXN`+_OMK5?3P#%=JVM
M7U``LKZPH[GOLW.ULE]2+BXN`+-=J7=?4P"J[:[FI+JN95]4+BXN`*C/I<ZJ
MS%]5`+-QL%2__0"FYJC&ON0`M4RJ:ZO8I=^_Z:58P,FNUP"U3*IKMGVQTK_I
MI$H`J_:FN0"Q2Z5/ID.[>:IKO_F[?@"S7:EWO_F[?@"_\J6BK:NM;JJZJ'2R
MSL#)KM<`N.JNQJ[FIJ&_^;M^`*?DI*.H[+!/O_T`P,FNUP"Q<2`E<R`H)7,I
M(*GS("5S("5S`+!]K;<`KLDZ`*[)`*6\JKZJNK9LI?.E1+[WIE>ZV0"EWZ=9
M`*J]L;7%XZ7<J?.ENZ3EL,\`O^FD2B^_Z:58O_F[?@"DNK.ALV[%Z;_YNWX`
MIN9=`*3``*97NMD`J7REO+GJIT`N`*E\I;RYZJ=`+@"SQJ?1O_T`ILJDP*3Q
M`*9SJ/J^1*G:`+FSK\``LW&K2*CSJ7>[M[K=O_F[?@"D5Z3)`+5,I6FESJJZ
MJD&PR`#%XZ7<KG2RIP!S;7,R96UA:6P@N&>ET2!(5%10`*SM`,.MJ7<`J'2R
MSK_YNWX`J]V_[,.O`+S(KLFIRJJZI:*QT0"F0::XO^FD2J=!JKJQ2[U8I4B]
M5+M[M4R[?@"^XZ98`*6\J5*F5P"HSZ7.JLR_[[[<`'9#87)D`*Q0M,$Z`'=E
M871H97(N8V]M(+KTK[@`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O>FA?0TXO3$-?34534T%'15,`````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#<W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]Z:%]#3B]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S,R,"`Q
M,#4Q-30S-#$T,2`P,C$T-#$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!H;W)D92]L;V-A;&4O>FA?0TXO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P
M-2\R-R`R,#HR,CHQ,B!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A
M9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E
M<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF
M;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY
M(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8
M+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@
M>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE
M=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM
M87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@
M9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S
M<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@
M971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@
M<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B
M=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET
M96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@
M87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET
M;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP
M87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@
M:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N
M('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@
M86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P
M;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@
M8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E
M(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I
M;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@
M=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O>FA?0TXO3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q-S<U,S$@,3`U,34T
M,S0Q-#$@,#(S,C,R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````>P0``!P```#T(P``^P4``,Q'````````N%\`
M``X```"Y7P``#P```,A?```(````V%\```P```#A7P``!````.Y?```/````
M\U\```L````#8```#@````]@```%````'F```"@````D8```"@```$U@```5
M````6&```!(```!N8```"P```(%@```.````C6````H```"<8```#0```*=@
M```.````M6````8```#$8```#P```,M@```8````VV````P```#T8```"```
M``%A```N````"F$``!H````Y80``,@```%1A```X````AV$``%0```#`80``
M40```!5B``!:````9V(``%<```#"8@``-````!IC```%````3V,```8```!5
M8P``$0```%QC```(````;F,``"4```!W8P``(````)UC```/````OF,```H`
M``#.8P```P```-EC```/````W6,``!0```#M8P``"0````)D```-````#&0`
M`!(````:9```#P```"UD```/````/60```@```!-9```)````%9D```(````
M>V0``!D```"$9```!P```)YD```,````IF0``"P```"S9```#@```.!D```#
M````[V0```L```#S9```!P```/]D```'````!V4```4````/90``%P```!5E
M```*````+64```\````X90``&````$AE```.````864``!0```!P90``%P``
M`(5E```7````G64``!,```"U90``#@```,EE```?````V&4```<```#X90``
M!@````!F```(````!V8```\````09@``"@```"!F```3````*V8```L````_
M9@``%0```$MF```5````868```<```!W9@``!0```']F```5````A68``!$`
M``";9@``#````*UF```[````NF8```D```#V9@``!P````!G```4````"&<`
M``4````=9P``$````"-G```3````-&<``#D```!(9P``)P```()G```L````
MJF<``"H```#79P``)0````)H```*````*&@```8````S:```"0```#IH```'
M````1&@``"\```!,:```-P```'QH```N````M&@``%4```#C:```+0```#EI
M```M````9VD``"T```"5:0``0````,-I```C````!&H``",````H:@``+0``
M`$QJ```S````>FH``!4```"N:@``&0```,1J```I````WFH``"0````(:P``
M$0```"UK```*````/VL``!````!*:P``%@```%MK```6````<FL```<```")
M:P``!P```)%K```4````F6L```H```"N:P``"````+EK```'````PFL```<`
M``#*:P``!@```-)K```%````V6L```<```#?:P``!@```.=K```(````[FL`
M``X```#W:P``"@````9L```$````$6P```<````6;```"0```!YL```6````
M*&P```@````_;```#0```$AL```&````5FP``!X```!=;```$0```'QL```(
M````CFP```T```"7;```#````*5L```'````LFP```,```"Z;````P```+YL
M```7````PFP```@```#:;```!````.-L```(````Z&P```@```#Q;```(```
M`/IL```&````&VT```8````B;0``%0```"EM```8````/VT``!T```!8;0``
M5````'9M```I````RVT```H```#U;0``#@````!N```*````#VX``!0````:
M;@``&````"]N```=````2&X``!,```!F;@``%````'IN```$````CVX```8`
M``"4;@``!0```)MN```%````H6X``!L```"G;@``&@```,-N```1````WFX`
M`!$```#P;@``'`````)O```0````'V\``"$````P;P``$0```%)O```,````
M9&\```8```!Q;P``%P```'AO```(````D&\```4```"9;P``#````)]O```&
M````K&\```<```"S;P``#0```+MO```'````R6\```L```#1;P``!P```-UO
M```'````Y6\```H```#M;P``#````/AO```0````!7````4````6<```)0``
M`!QP```3````0G```#L```!6<```(````))P```,````LW````X```#`<```
M"@```,]P```-````VG```!X```#H<```&P````=Q```A````(W$``!X```!%
M<0``'@```&1Q```;````@W$``!X```"?<0``,P```+YQ```O````\G$``!(`
M```B<@``*0```#5R```2````7W(``!8```!R<@``*````(ER```@````LG(`
M`"$```#3<@``00```/5R```'````-W,```8````_<P``$@```$9S```3````
M67,``!(```!M<P``!P```(!S```$````B',```P```"-<P``#P```)IS```3
M````JG,```T```"^<P``#0```,QS```&````VG,``!$```#A<P``%P```/-S
M```;````"W0```X````G=````@```#9T```%````.70```0````_=```#0``
M`$1T```.````4G0```,```!A=```"````&5T```/````;G0``!````!^=```
M!@```(]T```,````EG0``!$```"C=```&0```+5T```-````SW0```<```#=
M=```%````.5T```+````^G0``"(````&=0``+P```"EU```+````674```D`
M``!E=0``&0```&]U```+````B74``!<```"5=0``%P```*UU```)````Q74`
M`!8```#/=0``#P```.9U```.````]G4```@````%=@``#0````YV```F````
M''8``$,```!#=@``"````(=V```2````D'8```@```"C=@``"P```*QV```O
M````N'8```X```#H=@``!@```/=V```#````_G8```<````"=P``!`````IW
M```*````#W<```H````:=P``#P```"5W```0````-7<``!<```!&=P``$0``
M`%YW```7````<'<```4```"(=P``"P```(YW```%````FG<```T```"@=P``
M&P```*YW```7````RG<```D```#B=P``#@```.QW```-````^W<```@````)
M>```#@```!)X```1````(7@```<````S>```!0```#MX```'````07@```@`
M``!)>```!@```%)X```0````67@``!````!J>```#P```'MX```+````BW@`
M``\```"7>```#````*=X```/````M'@```<```#$>```!@```,QX```/````
MTW@```@```#C>```$P```.QX```>`````'D``"$````?>0``(````$%Y```9
M````8GD``!<```!\>0``)0```)1Y```7````NGD``!L```#2>0``#0```.YY
M```#````_'D```@`````>@``"@````EZ```,````%'H```0````A>@``$P``
M`"9Z```4````.GH```P```!/>@``"0```%QZ```+````9GH``!L```!R>@``
M!P```(YZ```'````EGH```H```">>@``#0```*EZ```)````MWH```0```#!
M>@``&````,9Z```*````WWH``'P```#J>@``!0```&=[```'````;7L```P`
M``!U>P``"````()[```&````BWL```@```"2>P```@```)M[```&````GGL`
M``T```"E>P``$````+-[```$````Q'L```D```#)>P``$````--[```)````
MY'L```D```#N>P``!0```/A[```&````_GL``!D````%?```!P```!]\```'
M````)WP```4````O?```"0```#5\```*````/WP```(```!*?```#0```$U\
M```)````6WP```8```!E?```$@```&Q\```)````?WP```<```")?```%```
M`)%\```=````IGP```8```#$?```"@```,M\```$````UGP```D```#;?```
M"````.5\```1````[GP```D`````?0``!@````I]```-````$7T```8````?
M?0``!````"9]```>````*WT```4```!*?0``#@```%!]```&````7WT``"$`
M``!F?0``%0```(A]```$````GGT``!$```"C?0``!@```+5]```B````O'T`
M`!T```#??0``!````/U]```,`````GX```H````/?@``"````!I^```)````
M(WX```4````M?@``#P```#-^```D````0WX```@```!H?@``"@```'%^```'
M````?'X``"````"$?@``(````*5^```F````QGX``!D```#M?@``*0````=_
M```'````,7\```H````Y?P``#P```$1_```,````5'\```8```!A?P``#P``
M`&A_```2````>'\``!````"+?P``'````)Q_```/````N7\```4```#)?P``
M$````,]_```)````X'\```0```#J?P``"P```.]_```,````^W\```\````(
M@```&0```!B````/````,H```!,```!"@```$@```%:````'````:8````P`
M``!Q@```(````'Z````4````GX```!$```"T@```%P```,:````<````WH``
M`!,```#[@```$0````^!```:````(8$``!X````\@0``&@```%N!```1````
M=H$``!<```"(@0``%0```*"!```9````MH$```0```#0@0``!P```-6!```+
M````W8$```8```#I@0``!@```/"!```&````]X$```4```#^@0``!P````2"
M```'````#((```4````4@@``%@```!J"```&````,8(```8````X@@``!```
M`#^"```$````1((```X```!)@@``#````%B"```,````98(```T```!R@@``
M"@```(""```.````BX(```4```":@@``*````*""```,````R8(```\```#6
M@@``"@```.:"```(````\8(```D```#Z@@``*P````2#```(````,(,``"8`
M```Y@P``$@```&"#```/````<X,```8```"#@P``"@```(J#```(````E8,`
M`"````">@P``"0```+^#```,````R8,```T```#6@P``#@```.2#```6````
M\X,``!$````*A```!@```!R$```&````(X0```<````JA```!P```#*$```'
M````.H0``!8```!"A```#0```%F$```$````9X0```4```!LA```'@```'*$
M```0````D80```P```"BA```"0```*^$```'````N80```H```#!A```"0``
M`,R$```.````UH0``!````#EA```&@```/:$```*````$84```D````<A0``
M#````":%```/````,X4```@```!#A0``!@```$R%```'````4X4```4```!;
MA0``1P```&&%```-````J84```H```"WA0```@```,*%```$````Q84``"4`
M``#*A0```P```/"%```%````](4``"H```#ZA0``"@```"6&```$````,(8`
M``H````UA@``!@```$"&```(````1X8```@```!0A@``!````%F&```%````
M7H8```4```!DA@``&P```&J&```O````AH8``!````"VA@``"@```,>&```/
M````TH8```H```#BA@``"0```.V&```;````]X8``!@````3AP``%P```"R'
M```.````1(<```,```!3AP``!P```%>'```'````7X<```H```!GAP``!P``
M`'*'``!1````>H<``!````#,AP``#````-V'```:````ZH<``$H````%B```
M!@```%"(```&````5X@```8```!>B```'P```&6(```)````A8@``!@```"/
MB```%P```*B(```&````P(@``%<```#'B```$P```!^)```3````,XD```(`
M``!'B0``"P```$J)```-````5HD```<```!DB0``%````&R)```&````@8D`
M``@```"(B0``#@```)&)```'````H(D```H```"HB0``"P```+.)```'````
MOXD```D```#'B0``"0```-&)```*````VXD```<```#FB0``"0```.Z)```'
M````^(D```H`````B@``$@````N*```*````'HH```D````IB@``$````#.*
M```'````1(H``!(```!,B@``!````%^*```'````9(H```4```!LB@``!0``
M`'**```+````>(H``!0```"$B@``$0```)F*```8````JXH``!P```#$B@``
M&0```.&*```'````^XH```4````#BP``#0````F+```(````%XL``!<````@
MBP``"P```#B+```3````1(L```0```!8BP``!````%V+```,````8HL```D`
M``!OBP``!0```'F+```'````?XL```4```"'BP``!````(V+```I````DHL`
M`#(```"\BP``+@```.^+```S````'HP``#,```!2C```.````(:,```0````
MOXP``!,```#0C```+0```.2,```M````$HT``#$```!`C0``+@```'*-```O
M````H8T``"P```#1C0``$P```/Z-```K````$HX``!H````^C@``"0```%F.
M``!%````8XX``$$```"IC@``!````.N.```4````\(X```X````%CP``$P``
M`!2/```8````*(\```8```!!CP``"0```$B/```*````4H\```\```!=CP``
M#@```&V/```%````?(\```@```""CP``!@```(N/```4````DH\``!$```"G
MCP``#@```+F/```"````R(\```X```#+CP``!0```-J/```'````X(\```8`
M``#HCP``!````.^/```I````](\``!\````>D```7````#Z0```4````FY``
M``<```"PD```#@```+B0```,````QY````P```#4D```$P```.&0```=````
M]9```!D````3D0``!0```"V1```1````,Y$``!$```!%D0``)````%>1```5
M````?)$``!(```"2D0``#@```*61```9````M)$```@```#.D0``"0```->1
M```(````X9$```4```#JD0``'P```/"1```&````$)(``!`````7D@``"```
M`"B2```(````,9(``"P````ZD@``&@```&>2```)````@I(```H```",D@``
M%0```)>2```%````K9(``!0```"SD@``!````,B2```0````S9(``!X```#>
MD@``*````/V2```*````)I,``!$````QDP``"P```$.3```:````3Y,``!0`
M``!JDP``!````'^3```+````A),```4```"0DP``!@```):3```(````G9,`
M`"````"FDP``00```,>3```:````"90``"@````DE```*0```$V4```&````
M=Y0```4```!^E```"````(24```J````C90``",```"XE```+@```-R4```T
M````"Y4```@```!`E0``%P```$F5```*````894```<```!LE0``$````'25
M```+````A94``!,```"1E0``"````*65```+````KI4```H```"ZE0``%```
M`,65```R````VI4```L````-E@``!0```!F6```7````'Y8```\````WE@``
M!0```$>6```$````398```T```!2E@``,@```&"6```7````DY8``!0```"K
ME@``!0```,"6```'````QI8```X```#.E@``*@```-V6```&````")<```P`
M```/EP``"P```!R7```V````*)<```L```!?EP``#P```&N7```R````>Y<`
M``4```"NEP``!P```+27```1````O)<```<```#.EP``!````-:7```'````
MVY<```H```#CEP``"P```.Z7```,````^I<```,````'F```$@````N8```&
M````'I@``!X````EF```&````$28```E````79@```T```"#F```"0```)&8
M```#````FY@```<```"?F````@```*>8```,````JI@``!4```"WF```"P``
M`,V8```9````V9@``"````#SF```$@```!29```%````)YD```H````MF0``
M%0```#B9```2````3ID```P```!AF0``!````&Z9```'````<YD```P```![
MF0``4@```(B9```7````VYD```8```#SF0``#0```/J9```5````")H``!(`
M```>F@``#P```#&:```4````09H``!L```!6F@``:0```'*:```:````W)H`
M`!<```#WF@``&@````^;```7````*IL``!L```!"FP``&0```%Z;```?````
M>)L``!,```"8FP``!P```*R;```(````M)L```D```"]FP``%0```,>;```-
M````W9L``!,```#KFP```P```/^;```_`````YP``#<```!#G```5P```'N<
M```O````TYP```H````#G0``"`````Z=```-````%YT``"T````EG0``!```
M`%.=```E````6)T```L```!^G0``'0```(J=```&````J)T```P```"OG0``
M!P```+R=```)````Q)T``!,```#.G0``"0```.*=```$````[)T``!````#Q
MG0``"`````*>```(````"YX```P````4G@``#P```"&>```'````,9X``!0`
M```YG@``#@```$Z>```,````79X``!L```!JG@``+````(:>```3````LYX`
M``4```#'G@``!````,V>```7````TIX```D```#JG@``"````/2>```*````
M_9X``!$````(GP``!@```!J?```.````(9\```X````PGP``#0```#^?```+
M````39\```(```!9GP``!P```%R?```&````9)\```D```!KGP``!P```'6?
M```5````?9\```4```"3GP``!P```)F?```(````H9\```<```"JGP``!P``
M`+*?```.````NI\```D```#)GP``!@```-.?```(````VI\```L```#CGP``
M!P```.^?```(````]Y\```<`````H```%@````B@```)````'Z````8````I
MH```"P```#"@```4````/*````@```!1H```!@```%J@```9````8:````H`
M``![H```'````(:@```'````HZ````4```"KH```$````+&@```4````PJ``
M``L```#7H```#0```..@```7````\:````0````)H0``"0````ZA```"````
M&*$```X````;H0``"````"JA```?````,Z$``",```!3H0``,0```'>A```G
M````J:$``$H```#1H0``.````!RB```H````5:(``"P```!^H@``&P```*NB
M```^````QZ(``$@````&HP``00```$^C``!;````D:,``$D```#MHP``(0``
M`#>D```?````6:0``"L```!YI```(0```*6D```S````QZ0``"4```#[I```
M)P```"&E```P````2:4``&D```!ZI0``/0```.2E``!E````(J8``$T```"(
MI@``+P```-:F```N````!J<``%0````UIP``,@```(JG```O````O:<``"P`
M``#MIP``+0```!JH```7````2*@``"4```!@J```,@```(:H```I````N:@`
M`#X```#CJ```(@```"*I``!2````1:D``"4```"8J0``"P```+ZI```A````
MRJD``#````#LJ0``)0```!VJ```<````0ZH``#$```!@J@``!````)*J```-
M````EZH```L```"EJ@``#@```+&J```+````P*H```4```#,J@```@```-*J
M``!9````U:H```4````OJP``$@```#6K```$````2*L```<```!-JP``"```
M`%6K```%````7JL``!,```!DJP``#0```'BK```"````AJL```<```")JP``
M!@```)&K```4````F*L```P```"MJP``&````+JK```&````TZL``!(```#:
MJP``#````.VK```#````^JL```0```#^JP``!@````.L```'````"JP``!\`
M```2K```-0```#*L```N````:*P``"\```"7K```%P```,>L```@````WZP`
M`!L`````K0``&````!RM```D````-:T``!\```!:K0``&@```'JM```:````
ME:T``"\```"PK0``*P```."M```?````#*X``",````LK@``'P```%"N```:
M````<*X``"4```"+K@``)@```+&N```E````V*X``"0```#^K@``&````".O
M```=````/*\``"0```!:KP``&````'^O```B````F*\``"4```"[KP``'P``
M`.&O```C`````;```!\````EL```(````$6P```:````9K```"8```"!L```
M'@```*BP```>````Q[````D```#FL```#````/"P```7````_;```"\````5
ML0``)````$6Q```/````:K$``!0```!ZL0``#@```(^Q```-````GK$``"0`
M``"LL0``!0```-&Q```'````U[$``!T```#?L0``%0```/VQ```&````$[(`
M``D````:L@``"P```"2R```7````,+(```8```!(L@``,P```$^R```'````
M@[(``"$```"+L@``$P```*VR```,````P;(``!$```#.L@``,@```."R```(
M````$[,```D````<LP``"@```":S```4````,;,```H```!&LP``'0```%&S
M```(````;[,``!\```!XLP``"````)BS```:````H;,```8```"\LP``!P``
M`,.S```(````R[,```D```#4LP``/P```-ZS```'````'K0```\````FM```
M"````#:T```3````/[0```<```!3M```&0```%NT```*````=;0``!<```"`
MM```%````)BT```*````K;0```P```"XM```%P```,6T```$````W;0``"H`
M``#BM```$0````VU```'````'[4```(````GM0``$````"JU```#````.[4`
M``@````_M0``!@```$BU```'````3[4```T```!7M0``"P```&6U```4````
M<;4``!4```"&M0``#@```)RU```O````J[4``"````#;M0``'````/RU```3
M````&;8```4````MM@``!@```#.V```,````.K8```H```!'M@``$0```%*V
M```"````9+8```0```!GM@``"@```&RV```&````=[8```4```!^M@``#```
M`(2V``!%````D;8``"@```#7M@``4P````"W```9````5+<``"````!NMP``
M-0```(^W``!%````Q;<``#`````+N```*````#RX```F````9;@``"4```",
MN```*````+*X```H````V[@``#`````$N0``$@```#6Y```0````2+D``'D`
M``!9N0``"0```-.Y``!S````W;D``'P```!1N@``*P```,ZZ```7````^KH`
M`!\````2NP``%````#*[```*````1[L```4```!2NP``!@```%B[```(````
M7[L``!````!HNP``#P```'F[```$````B;L``!D```".NP```@```*B[```)
M````J[L```0```"UNP``#P```+J[```3````RKL``"(```#>NP``!P````&\
M```+````";P```4````5O````@```!N\```+````'KP``$\!```JO```"@``
M`'J]```,````A;T```<```"2O0``!P```)J]```"````HKT``!(```"EO0``
M"P```+B]```'````Q+T```4```#,O0``$@```-*]```'````Y;T```L```#M
MO0``"0```/F]```+`````[X```D````/O@``!0```!F^```*````'[X```\`
M```JO@``!@```#J^```,````0;X``!(```!.O@``"@```&&^```)````;+X`
M`!T```!VO@``%````)2^```E````J;X``"T```#/O@``/````/V^``!`````
M.K\``$````![OP``1@```+R_```G`````\````4````KP```"````#'````.
M````.L````<```!)P```&P```%'````;````;<````L```")P```!````)7`
M```$````FL````H```"?P```#````*K````*````M\````H```#"P```"```
M`,W````-````UL````T```#DP```!@```/+````?````^<````@````9P0``
M&0```"+!```$````/,$```8```!!P0``'P```$C!```$````:,$```@```!M
MP0``!@```';!```*````?<$```H```"(P0``!````)/!```0````F,$```H`
M``"IP0``"````+3!```4````O<$```8```#2P0``#@```-G!```.````Z,$`
M``X```#WP0``"`````;"```*````#\(``!4````:P@``!@```##"```&````
M-\(```8````^P@``"````$7"```&````3L(``!````!5P@``"````&;"```.
M````;\(``!(```!^P@``!````)'"```$````EL(``!<```";P@``#````+/"
M```,````P,(``!H```#-P@``!@```.C"```(````[\(``!8```#XP@``!@``
M``_#```*````%L,```\````APP``'0```#'#```;````3\,``!D```!KPP``
M&P```(7#```9````H<,```0```"[PP``!````,##```(````Q<,```8```#.
MPP``*@```-7#```C`````,0``"D````DQ```:P```$[$```H````NL0``"@`
M``#CQ```*`````S%```G````-<4``!H```!=Q0``&@```'C%```H````D\4`
M`"X```"\Q0``"0```.O%```,````]<4``!`````"Q@``#0```!/&```+````
M(<8```@````MQ@``"````#;&```2````/\8``!0```!2Q@``"@```&?&```$
M````<L8``!@```!WQ@``"````)#&```(````F<8```@```"BQ@``!@```*O&
M```&````LL8```0```"YQ@``"@```+[&```$````R<8```0```#.Q@``"```
M`-/&```(````W,8```0```#EQ@``"````.K&```$````\\8``!0```#XQ@``
M"`````W'```(````%L<```0````?QP``#@```"3'```$````,\<```@````X
MQP``"````$''```*````2L<```8```!5QP``#````%S'```#````:<<```H`
M``!MQP``!````'C'```&````?<<```8```"$QP``!@```(O'```:````DL<`
M``8```"MQP``!````+3'```,````N<<``!(```#&QP``$@```-G'```Q````
M[,<``!D````>R```!@```#C(```(````/\@```@```!(R```%@```%'(```*
M````:,@``!$```!SR```"````(7(```(````CL@```0```"7R```!````)S(
M```$````H<@```0```"FR```$0```*O(```/````O<@```@```#-R```#@``
M`-;(```-````Y<@```8```#SR```%0```/K(```,````$,D```@````=R0``
M!````";)```*````*\D```@````VR0``!````#_)```&````1,D```0```!+
MR0``!````%#)```(````5<D```0```!>R0``!@```&/)```&````:LD```0`
M``!QR0``!````';)```'````>\D```@```"#R0``!````(S)```*````D<D`
M``H```"<R0``*P```*?)```:````T\D```@```#NR0``"````/?)```*````
M`,H```@````+R@``%````!3*```8````*<H``!<```!"R@``%P```%K*```4
M````<LH``!(```"'R@``%0```)K*```=````L,H``!T```#.R@``#````.S*
M```7````^<H```P````1RP``%P```![+```8````-LL``!,```!/RP``%@``
M`&/+```P````>LL```0```"KRP``!````+#+```,````M<L```P```#"RP``
M"@```,_+```(````VLL```0```#CRP``"````.C+```(````\<L```H```#Z
MRP``"`````7,```(````#LP```@````7S```$0```"#,```7````,LP``!H`
M``!*S```"@```&7,```"````<,P```0```!SS```!````'C,```(````?<P`
M``@```"&S```!````(_,```&````E,P```@```";S```#````*3,```$````
ML<P```H```"VS```"````,',```.````RLP```@```#9S```!````.+,```(
M````Y\P```0```#PS```'0```/7,```7````$\T```0````KS0``"````##-
M```6````.<T```H```!0S0``"````%O-```(````9,T```0```!MS0``$0``
M`'+-```(````A,T```@```"-S0``!@```);-```&````G<T``!P```"DS0``
M*0```,'-```(````Z\T```X```#TS0``!`````/.```'````",X``!X````0
MS@``"````"_.```(````.,X```0```!!S@``"````$;.```$````3\X```@`
M``!4S@``"@```%W.```(````:,X```@```!QS@``#@```'K.```(````B<X`
M``X```"2S@``!````*'.```(````ILX```@```"OS@``#````+C.```5````
MQ<X```P```#;S@``"````.C.```)````\<X```D```#[S@``!`````7/```*
M````"L\```H````5SP``"@```"#/```$````*\\```@````PSP``"@```#G/
M```$````1,\```H```!)SP``"@```%3/```)````7\\```@```!ISP``"@``
M`'+/```)````?<\```<```"'SP``!````(_/```$````E,\```8```"9SP``
M!@```*#/```-````I\\``!````"USP``%0```,;/```4````W,\``!````#Q
MSP``$`````+0```;````$]```!`````OT```'0```$#0```(````7M````0`
M``!GT```!````&S0```(````<=````H```!ZT```!````(70```3````BM``
M`!$```">T```"@```+#0```(````N]````@```#$T```%0```,W0```&````
MX]````0```#JT```!@```._0```&````]M````@```#]T```!`````;1```.
M````"]$```@````:T0``3@```"/1```$````<M$```0```!WT0``"````'S1
M```$````A=$```0```"*T0``"````(_1```&````F-$```0```"?T0``"@``
M`*31```.````K]$```8```"^T0```@```,71```(````R-$```0```#1T0``
M!````-;1```$````V]$```8```#@T0``$@```.?1```(````^M$```0````#
MT@``!`````C2```(````#=(```(````6T@``!````!G2```+````'M(```0`
M```JT@``!````"_2```3````--(```8```!(T@``"````$_2```*````6-(`
M`!(```!CT@``!@```';2```*````?=(```0```"(T@``"````(W2```(````
MEM(```@```"?T@``"````*C2```&````L=(``!````"XT@``!@```,G2```$
M````T-(``!$```#5T@``!````.?2```)````[-(```0```#VT@``$````/O2
M```7````#-,```0````DTP``#@```"G3```$````.-,``!$````]TP``!@``
M`$_3```$````5M,```@```!;TP``"````&33```(````;=,```@```!VTP``
M!0```'_3```&````A=,```T```",TP``!````)K3```&````G],```8```"F
MTP``%0```*W3```5````P],``!T```#9TP``$````/?3```@````"-0```0`
M```IU```"````"[4```*````-]0```@```!"U```!````$O4```-````4-0`
M``P```!>U```"0```&O4```3````==0```@```")U```!````)+4```(````
ME]0```H```"@U```!````*O4```$````L-0```@```"UU```#````+[4```.
M````R]0```@```#:U```#0```./4```1````\=0```0````#U0``!@````C5
M```9````#]4```\````IU0``#P```#G5```/````2=4```X```!9U0``$```
M`&C5```0````>=4``!8```"*U0``$P```*'5```/````M=4```\```#%U0``
M#P```-75```1````Y=4``!````#WU0``!@````C6```&````#]8```0````6
MU@``!@```!O6```&````(M8```0````IU@``!@```"[6```&````-=8```0`
M```\U@``#````$'6```2````3M8```8```!AU@``!````&C6```$````;=8`
M``0```!RU@``!````'?6```(````?-8```@```"%U@``"````([6```*````
ME]8```H```"BU@``!@```*W6```2````M-8```@```#'U@``"````-#6```(
M````V=8```@```#BU@``"````.O6```H````]-8```X````=UP``!````"S7
M```$````,=<```T````VUP``!@```$37```*````2]<```0```!6UP``!```
M`%O7```&````8-<```8```!GUP``"0```&[7```.````>-<``!0```"'UP``
M%@```)S7```(````L]<```@```"\UP``!@```,77```&````S-<```@```#3
MUP``!@```-S7```*````X]<```0```#NUP``!````//7```=````^-<```P`
M```6V```$0```"/8```/````-=@``!,```!%V```$0```%G8```1````:]@`
M``\```!]V```$P```(W8```4````H=@```0```"VV```!@```+O8```*````
MPM@```H```#-V```!````-C8```$````W=@```0```#BV```!````.?8```K
M````[-@```D````8V0``!@```"+9```"````*=D```@````LV0``&P```#79
M```#````4=D```@```!5V0``#````%[9```,````:]D```0```!XV0``"```
M`'W9```&````AMD```@```"-V0``"````);9```$````G]D```8```"DV0``
M!````*O9```2````L-D``"0```##V0``"@```.C9```*````\]D```P```#^
MV0``"@````O:```(````%MH``!<````?V@``&````#?:```7````4-H```P`
M``!HV@``!````'7:```*````>MH```0```"%V@``"0```(K:```$````E-H`
M`"P```"9V@``"P```,;:```(````TMH``!,```#;V@``*P```._:```$````
M&]L```0````@VP``!@```"7;```2````+-L```D````_VP``&````$G;```7
M````8ML```0```!ZVP``-P```'_;```0````M]L``!````#(VP``!@```-G;
M```(````X-L```@```#IVP``!````/+;```(````]]L```8`````W```!```
M``?<```&````#-P```0````3W```"@```!C<```(````(]P```8````LW```
M!````#/<```$````.-P```0````]W```!````$+<```$````1]P```0```!,
MW```"````%'<```$````6MP```@```!?W```"````&C<```0````<=P```0`
M``""W```"P```(?<```$````D]P```@```"8W```!````*'<```&````IMP`
M``0```"MW```#````++<```3````O]P``!<```#3W```$P```.O<```1````
M_]P```0````1W0``!````!;=```,````&]T```0````HW0``$0```"W=```&
M````/]T```\```!&W0``!````%;=```&````6]T```H```!BW0``"````&W=
M```&````=MT```@```!]W0``!````(;=```&````B]T``!H```"2W0``'P``
M`*W=```7````S=T``!P```#EW0``&P````+>```@````'MX```H````_W@``
M$````$K>```;````6]X``!L```!WW@``'P```)/>```<````L]X``!T```#0
MW@``&@```.[>```3````"=\``!,````=WP``&0```#'?```&````2]\``"\`
M``!2WP``,0```(+?```"````M-\``!8```"WWP``"````,[?```&````U]\`
M``X```#>WP``!````.W?```&````\M\```8```#YWP``#`````#@```(````
M#>````8````6X```!@```!W@```$````).````8````IX```"````##@```$
M````.>````(````^X```"@```$'@```&````3.````0```!3X```!@```%C@
M```$````7^```",```!DX```$P```(C@```F````G.````X```##X```!```
M`-+@```)````U^````@```#AX```!````.K@```(````[^```!````#XX```
M%`````GA```$````'N$```@````CX0``"@```"SA```-````-^$```P```!%
MX0``#````%+A```,````7^$``!8```!LX0``#````(/A```(````D.$```@`
M``"9X0``!````*+A```0````I^$```8```"XX0``#@```+_A```&````SN$`
M``0```#5X0``'0```-KA```(````^.$```4````!X@``!@````?B```-````
M#N(```0````<X@``!````"'B```$````)N(```H````KX@``#````#;B```3
M````0^(```0```!7X@``"````%SB```$````9>(```@```!JX@``!````'/B
M```$````>.(```8```!]X@``!````(3B```$````B>(```@```".X@``%0``
M`)?B```F````K>(``!$```#4X@``$0```.;B```6````^.(```0````/XP``
M!````!3C```&````&>,``"L````@XP``%@```$SC```I````8^,``"\```"-
MXP``!````+WC```,````PN,```8```#/XP``!````-;C```*````V^,```@`
M``#FXP``"````._C```$````^.,```@```#]XP``"`````;D```,````#^0`
M`!H````<Y```"````#?D```&````0.0``!0```!'Y```!````%SD```$````
M8>0```0```!FY```"````&OD```E````=.0```@```":Y```#0```*/D```*
M````L>0```0```"\Y```"@```,'D```H````S.0```0```#UY```"````/KD
M```&`````^4``"<````*Y0``"````#+E```,````.^4``!<```!(Y0``!```
M`&#E```$````9>4```@```!JY0``$@```'/E```$````AN4``!(```"+Y0``
M"P```)[E```(````JN4```@```"SY0``!````+SE```;````P>4```\```#=
MY0``#P```.WE```6````_>4```X````4Y@``!````"/F```*````*.8```H`
M```SY@``!````#[F```&````0^8```H```!*Y@``#@```%7F```*````9.8`
M`!0```!OY@``$@```(3F```2````E^8```8```"JY@``"````+'F```0````
MNN8```H```#+Y@``"@```-;F```$````X>8```<```#FY@``"````.[F```Z
M````]^8```\````RYP``!````$+G```,````1^<``!8```!4YP``$@```&OG
M```.````?N<``!0```"-YP``$0```*+G``!#````M.<```T```#XYP``$0``
M``;H```-````&.@``!$````FZ```%P```#CH```0````4.@```T```!AZ```
M#````&_H```2````?.@```@```"/Z```!````)CH```L````G>@```0```#*
MZ```#P```,_H```$````W^@``"$```#DZ```(P````;I```Z````*ND``!P`
M``!EZ0``$P```(+I```$````END```@```";Z0``(0```*3I```$````QND`
M`"````#+Z0``"@```.SI```3````]^D```0````+Z@``%P```!#J```$````
M*.H```0````MZ@``"````#+J```2````.^H```0```!.Z@``"````%/J```3
M````7.H``!4```!PZ@``"@```(;J```<````D>H``!(```"NZ@``#````,'J
M```(````SNH``!,```#7Z@``$0```.OJ```L````_>H```8````JZP``#@``
M`#'K```(````0.L```P```!)ZP``%````%;K```$````:^L```@```!PZP``
M`@```'GK```$````?.L```@```"!ZP``!````(KK```&````C^L```@```"6
MZP``!@```)_K```$````INL```0```"KZP``!````+#K```$````M>L```T`
M``"ZZP``#````,CK```$````U>L```0```#:ZP``!````-_K```$````Y.L`
M``D```#IZP``!@```//K```$````^NL```8```#_ZP``!`````;L```$````
M"^P``!$````0[```!````"+L```6````)^P``!0````^[```#0```%/L```2
M````8>P``!T```!T[```$````)+L```$````H^P```0```"H[```%0```*WL
M```G````P^P```4```#K[```"````/'L```(````^NP``!(````#[0``!```
M`!;M```&````&^T```@````B[0``!````"OM```&````,.T```8````W[0``
M#@```#[M```/````3>T``!$```!=[0``&````&_M```<````B.T``!8```"E
M[0``*````+SM```;````Y>T``!T````![@``'0```!_N```1````/>X``!D`
M``!/[@``,@```&GN```O````G.X``#$```#,[@``+P```/[N```7````+N\`
M`!<```!&[P``%@```%[O```3````=>\``!\```")[P``$P```*GO```9````
MO>\``!$```#7[P``0@```.GO```D````+/```#D```!1\```+P```(OP```7
M````N_```!L```#3\```.````._P```E````*/$``!X```!.\0``'@```&WQ
M```;````C/$``!$```"H\0``&0```+KQ```;````U/$``!L```#P\0``)```
M``SR```/````,?(``#T```!!\@``$P```'_R```(````D_(``!,```"<\@``
M+0```+#R```7````WO(```\```#V\@``)`````;S```$````*_,```@````P
M\P``"````#GS```(````0O,```L```!+\P``!````%?S```&````7/,``$\`
M``!C\P``!````+/S```-````N/,```0```#&\P``"@```,OS```$````UO,`
M``0```#;\P``$````.#S```&````\?,```8```#X\P``!@```/_S```&````
M!O0``!4````-]```"@```"/T```2````+O0```8```!!]```#@```$CT```,
M````5_0```0```!D]```!0```&GT```&````;_0```8```!V]```$@```'WT
M```=````D/0``!X```"N]```'P```,WT```.````[?0``!8```#\]```$@``
M`!/U```2````)O4``!<````Y]0``$@```%'U```2````9/4``!$```!W]0``
M&@```(GU```1````I/4``!(```"V]0``%@```,GU```7````X/4``!(```#X
M]0``%0````OV```3````(?8``!`````U]@``%P```$;V```2````7O8``!<`
M``!Q]@``$@```(GV```2````G/8``!$```"O]@``%@```,'V```8````V/8`
M`!8```#Q]@``'@````CW```?````)_<``!@```!']P``$@```&#W```7````
M<_<``!8```"+]P``!@```*+W```(````J?<```0```"R]P``'@```+?W```;
M````UO<```X```#R]P``$`````'X```$````$O@```0````7^```)````!SX
M```$````0?@```8```!&^```$P```$WX```.````8?@```0```!P^```!P``
M`'7X```(````??@```\```"&^```!````);X```E````F_@```8```#!^```
M'0```,CX```(````YO@```@```#O^```"````/CX```;`````?D```8````=
M^0``!P```"3Y```&````+/D```T````S^0``#````$'Y```1````3OD```0`
M``!@^0``$@```&7Y```&````>/D``!@```!_^0```@```)CY```(````F_D`
M``0```"D^0``"````*GY```D````LOD```0```#7^0``"````-SY```$````
MY?D```\```#J^0``!P```/KY```,`````OH```H````/^@``#@```!KZ```,
M````*?H```8````V^@``"````#WZ```=````1OH```0```!D^@``&P```&GZ
M```0````A?H```0```"6^@``!@```)OZ```(````HOH```0```"K^@``!```
M`+#Z```$````M?H```0```"Z^@``"0```+_Z```(````R?H``!$```#2^@``
M$@```.3Z```(````]_H``",`````^P``#P```"3[```-````-/L```@```!"
M^P``!0```$O[```&````4?L```H```!8^P``"@```&/[```-````;OL```(`
M``!\^P```@```'_[```,````@OL```0```"/^P``!````)3[```+````F?L`
M`#T```"E^P``(0```./[```E````!?P```L````K_```%P```#?\```_````
M3_P``"$```"/_```'````+'\```5````SOP``!,```#D_```$P```/C\```3
M````#/T``!,````@_0``'@```#3]```0````4_T```@```!D_0``40```&W]
M```(````O_T``"L```#(_0``40```/3]```;````1OX``!,```!B_@``#P``
M`';^```/````AOX```@```"6_@``!@```)_^```&````IOX```@```"M_@``
M"@```+;^```4````P?X```0```#6_@``$P```-O^```#````[_X```0```#S
M_@``!````/C^```)````_?X```D````'_P``&@```!'_```&````+/\```@`
M```S_P``!0```#S_```%````0O\``!````!(_P```0```"H#``#X`0``'`,`
M`)@"``#M`P```````'`#``#&`@``"`,```0$``!7`@``E`(```````">`0``
M4@$``%,#``"N`0``L@```#T$```)`@````````````"A`0``Y`,``)P#```E
M`0``E0$``)D#````````K@(```````!2`P``B`$``/@#````````%P0`````
M````````/`$``#L"```W`@``%P,``&(#```/`0``\@$``,0```#`````F0$`
M`$\"``````````````````!<`````````$@#``!C!`````````````#J`P``
M;0,``#D#``#``0``M0```.4#```>!````````&L"```?`P````````P"````
M`````````&<!``#5`P```````(D```"#`@``=`0``%\```#J`````P$`````
M``!5````M0(``````````````````&8"``"M`@```````!P!``!4`@``````
M`.,#``"8`````````(H````*`@``!@```.\```""`````````$4#```%`@``
MW`(`````````````.`(````````6!````````&<$``"J````'0(``#`!````
M````T0,``.,`````````X@```%H```"(`P```````/4````F`P``BP$``.T`
M```3`@```````#,```!R`@``8P(``!@!``!?!```2@(``+(#``"6`P``A`,`
M`$0!``!1!```4````%<$```X`````````&8````"`@```````$<"``"!`0``
MAP$``/L#``````````````````!9````8`(``!,!````````F0```.P#``#_
M`0``#`,``&H!``!<!```@````"L#``!A!```D0```'H#``!X!```[P$``,T`
M``#3````.`,``/P!``#0`@``;@,```H#``"A`P``X0``````````````6@$`
M`"$#``"X`@``^@``````````````SP$``+L```!J`P``MP(``#\#``!A`0``
MKP(``"P"````````]````````````````````!P````2`0```````*(````\
M````N@,``!<"``!X````'@(``$4$```?`0```````"(`````````"P(``-T`
M````````K`$``````````````````'D```#Q``````````````#8`P``````
M``````!O`P```````#0$``!"`````````&D#```M!```^0```-`!```'!```
MCP$``*,#````````T@(``(X!```^`P``)@$``*0#`````````````"````!)
M`0``-`(``)0````1`@``<0,```T"```F`@``=0(``!<```!U````[@(`````
M``#7`@``G0$```````"K`P``I0(````````C!`````,``!<!``!J`@``````
M`%D"``!Y`P`````````````K!````````#<````^`@``)`0``!@```#-`0``
MS0(```````"F`@``=`(``$X#``#C`0```````",`````````;@(``%X$````
M````+0,``!0$``#+`P``H0````,"```Q`P``,@```$(!``!H````````````
M`````````````.$#`````````````,H#``"J`@``1@(````````$`P``6@0`
M`%@!````````O`(``-$!```T`0``0`(``',$``#H`P``-@0``!H"``!.````
MK0```-L#```G!```KP,``"L```!;!```D`(``/8!```4`0``+@$``/D"```U
M`P``+@(``$P#``!Z````FP````````!+````Q0$``.L```"``@``\`,``*P#
M``#Z`0``?@,```````#'`@``7P(````````P!```/P0``%($```;`0``2P(`
M`)H`````````EP$```````!A`P``%`,``#,$````````6P$````````W`0``
M_`,```````!+`P````````````!6````<`0``%\#````````(0(``'$$``!P
M`0``^@,``-T#```X!```W`,````````"`0``^`(````````O`@``S`,``%P"
M```E`@``6P(```$!``!#!```5`````````!O`0``K@```!D```#)`@``\P(`
M```````Q`0``X@,``+0```!`````\P```'```````````````)T"``"1`@``
M6P```-L"``"?````[@$``-$`````````2`(``,D!````````*@0```````"<
M`@``>@$``.L"```L!```U0(``/X"``"/`@````````````!=`````````"$!
M```K`@``2P$``+$!```5`P``D`$``%`$``#T`@```````$8```#.`@``?0``
M`',#``!)!```C@(``'L#``#_`P``@@(``$X"``#A`0``2`0```````"P`@``
M.P$``%$!``"@`P``0P(```````"&`0```````*,`````````1`,``&8$``#G
M`P``2@$``*(!``".````10````````!'`````````%\!````````$00``+0"
M```A!```S`(``!D$````````/`(``-T!````````IP(```````!L`P``9`(`
M`$`$``#D`@````````\$``"Y`P``BP```*,"```````````````````&`0``
M=@0``'X"``"W````EP(```````!X`0````$``$@!`````````````/L!```.
M!```8P,``/<````[!````````%$#````````RP(```,$````````@P,``'8"
M``#O`@``B@$```````"T`0``P@```$\!```D````30$````````Y!```````
M``````")`0``<0$``"@```!^`0``2````````````````````#`````Q````
M?0$``+$#```I`P``1`0```L!``"<`0``@P$``#X$``!D`P``A0,``-X`````
M````_0(```````#!`0```````#T"``#``@``$`$``!$#`````````````$T$
M``#(`@``(`,```4#``!:`@```````,(!```3`P``0`$``+@#```&`P``*`(`
M`.(!``!8`@``[@,```````"F`P``]@(``$\#``!\````0P,``,<```"$````
M`````)@!``!6`P``Y`$``%8"```(````Y0(````````+`P``^0,``,$#``#6
M`P``1@0`````````````R0```(8```!G````"P0``"8```"-`0``\@,``'\`
M``#\`@``Z0$```````!7`0``#0$``/<#``"]`@``5`,``,L!```Z`P``````
M`'4$```\!```OP(``!@$``"G`P```````/$#``!B!````````#D!```B`@``
M(@0``&0$``#6`@``^````%4#``"(`@``)00```D#``"E`P``30````0"````
M````^@(``,8!``"=````>`(``#D``````````````%4"```W`P``S@``````
M````````0`,````````:!```&`,```````#O`P``QP,``'0#```&`@``U```
M`%P#````````<0```#`#```````````````````>`0``=@,``%@````5`@``
MB@(```````#_````.0(``*\!`````````````(L"``#J`@````````4$``#/
M`````````&L!```&!```\0(``'D"```(!```'@,``/L`````````J`,``-D`
M```.`0``NP(``.P!```]`0``8P$``````````````````*0"``"'````ZP,`
M```````=````5`$```````!\`P``&`(``)`````I`@```````#(#````````
M+0(``%$````S`@```````,@#``"D`0``?`(``-<#``#%`P```````%T"``#$
M`0``X`````0```!I````?P,``)0!```G`P``WP,`````````````9@,``+X#
M```@`0``'0$``/````!)``````````````#P`0``P@(``-H#``"'`P``&P,`
M`%D$````````J`$``.P"```O!```7@$``!X````O`0```````)4"````````
M``````````#*````RP``````````````6`,``.L!`````````````-X!``"Z
M````Y@,````````"`P``L@$``````````````````'L"````````D@$`````
M``"Y````7`$```````!V````C`$```````!K`P```````,0"``"!`@``O0``
M`$0```#8`0``CP```"D!```6`0``/0```,,!````````A@,``)4#``"L`@``
MD@````````"C`0```````+X!````````S@$````````O`P``LP$```````!=
M`0``#0,``/T#``#7````N@$``-X#````````E@```#8"`````````````+T#
M``!=!```GP(``*0```#\`````````)H!````````:`(``+T!````````%@,`
M`+8`````````+@```"@$````````Q@```'H$```H`0``DP```)\#````````
MZ0````````!L`0``.@$``#L`````````3P```!`$```Q`@``8P```!L"``#I
M`@```````+L!```S`0``#`0``#H$``!>`P``S`$```````"G`0``#````*D"
M``!!``````````,#``````````````````"B`@``N0(``&P"```U````````
M`)\!````````\P$`````````````4@```%4!``````````````````!_`0``
M`````)(#```-`````````(0!```_```````````````)!```=P,```````!/
M!````````.D#````````4`,``-D!```H`P``/@$``$X!````````V@```,4"
M``"R`@``'`(```````">````$@(``(D"```3````-00``"H!``!!!```U@``
M```````1``````````````"F````/`,```````!'!````````/L"```=!```
MY````"L!``#5`````````%,"``"4`P```````$$!````````0@0``/<"````
M````#`$`````````````M@,``.8```!S````:`,```````"^````````````
M``````````````````!.!````@0``$8!```2````F@(``&4"``#2`0``````
M`.,"``#]````#P,```H$``"0`P``:@0````````=`P``,P,``#(!```"````
M]P$```<!```A````'P(``*L!````````.P,``&(!``!>````3`$``-T"```$
M`0``D0,```````!E!```H`(``)L!````````"@````````"<````V0,``*L"
M``",`P``C`(``*@`````````;@`````````B`0``X`$`````````````#@``
M`!4`````````.@(``$<!```N`P``U0$```````#0`P``0@,``$P"``#,````
M&@$```````#/`P``8`,``````````````````+\````I````K@,``&<"```G
M````)P$```````!-`@```````!4$``!%`0``VP```-,#``".`P``D0$`````
M``!I`0``F`,``(4"````````I@$``,,```"3`P``^0$```````"K````OP,`
M`($`````````DP$``)("```6`@```````'L$``!!`P``?`$``+`!``!9`0``
MWP(``+$"``!2`@``%0$``)T#````````KP```%<#``!=`P``````````````
M````C0```#("```V`0``\@(``($#````````>`,``/(`````````;00``.`"
M````````%`(```````!0`0``+````-$"``"'`@``MP,``-,!``#9`@``````
M`-,"````````)`(``,@````E````9`$``+P````_`0``#P```'L```#?````
M`````%L#``"6`0````````````#H````5@0``-H!``";`@```````)8"``#"
M`P```````$D"```V`````````/8```"J`0``G@,``-L!`````@``CP,``,X#
M``#N`````````!($``!#````]0,``(8"```D`0``(`0```````#2````]@,`
M`'T#``!^````````````````````H0(`````````````N0$``.T"``#B`@``
M(P$````````<!`````````````"X`0``(@,```$#```I!````````+8"````
M````<P$``'(```#^``````````````!U`P``K0,``'4!````````O`,`````
M```9`@``L`,``%,```#^`P``P0`````````0`P``M`,``.4!````````;@$`
M`*D#```T````=P0``$0"```T`P``M0,``&D$``#%``````````````"G````
M!P```,$"``!@!````````&@!``!K````500```````"B`P``\0$``/T!````
M````A`(``*4```"5`````````-X"``!Y`0``9P,```````!"`@``K````&\$
M``!S`@``"`(``$D#````````=`$``%$"``"S`@``<@0``,`#``"^`@``+0$`
M`-P!``!W````/0,```````"*`P``%@```&P$````````@`,``%,!```.`@``
M%````#4"``"U`0``A0$``'D$````````X`,``"T```````````````````"J
M`P``2@```-``````````4P0```$"``"@````"`$``-0#``!@`0```````$P`
M``#?`0``)`,``,H"````````"0$```````!H!```PP,```````!6`0``````
M`/X!``#'`0``-@,``````````````````'L!```9`P``T@,``,\"``#U`@``
M,00``.<````.`P``S0,```$$````````F0(``+P!``"V`0``LP```%H#```0
M````[````"8$```?`````````.8"``````````````D```!8!```8@```!\$
M``!%`@``;@0```````!M`0``N@(``/0#``!E`0```````,D#````````F@,`
M``````"-`@``(`(``&\"```_`@``;````+L#`````````````$<#```;````
M`````(L#``!T````80(``*@"``#$`P```````.<"````````<`(``'8!```-
M!````````-P````1`0``:@`````````:````7@(``#4!````````Q@,`````
M``!Q`@``C0,``&T"```C`@``>@(`````````````3`0```````#M`0``!P(`
M`+````##`@``\P,``-@"````````=P$``"<"````````````````````````
MX0(``.8!``">`@``UP$``$$"``"``0```````.H!``!]`@``.`$``!D!````
M````]0$``%D#``!*`P``$@,````````E`P``2P0```,````N!````````+\!
M`````````````),"``"(`````````'<"````````"P```/\"``!B`@``:0(`
M``H!``!E`P``V@(``+,#``#*`0``5P```%`"``!4!```FP,``-0!``")`P``
M0P$``*4!``!O`````````&`````P`@``N````&T`````````+`,```4```!E
M````+`$```\"``#8``````````````#4`@``C`````````"7`P``&P0``.<!
M````````&@,````````J`@``9@$```4!``#6`0``@P```*D```"M`0``A0``
M`'(!````!```J0$``$8#```W!```2@0````````^````+P```)<````J````
M`````((!```3!```,@0```<#````````Z`(``*`!````````@@,``!`"```C
M`P``\`(``.4````Z`````````'(#``!-`P````````````!_`@``L0```&0`
M````````MP$``.@!``#T`0```````,@!``!A````:P0````@*"5S(&1A>7,@
M86=O*0`@*$%C8V5S<VME>2`E<RD`("AT;V1A>2D`("AY97-T97)D87DI`"!A
M="``)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT
M`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<SH@)7,`+"!G=7-T
M:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@
M+2T`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O
M<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E9`!!('!U
M8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I
M9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@
M;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N
M9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`
M02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+@!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N
M+BX`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(&9R;WIE;BX`
M06-C;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M
M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES
M<VEO;@!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D9"!P86ER
M`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=7-E
M<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!"
M;V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S
M97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L
M9V5R:6$`06QI87,`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P
M<P!!;&P@4&5R;6ES<VEO;G,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L
M<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T
M92!T96UP;&%T97,`06UE<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W
M87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO
M=7,@4')O>'D`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3
M:&%R97,`07!P<F]V90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U-BD`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R92!Y;W4@
M=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R
M9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!4DU30TE)+3@I`$%R=6)A`$%S
M8V5N<VEO;B!)<VQA;F0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O
M;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<S\`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T
M=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E
M;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I8G5T97,`
M075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z($)A8VME
M;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`075T:%]C
M>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N($-O;7!I
M;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U=&A?:6UA
M<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VMR
M8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S
M97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I
M;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R
M=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`079A
M:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"86-K9W)O=6YD($-O;&]R`$)A
M9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"
M86AA;6%S`$)A:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861O<P!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU
M9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`
M0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W-N:6$@86YD($AE<GIE9V]V:6YA
M`$)O='-W86YA`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N
M($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"
M=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),
M($1I<W1R:6)U=&EO;B!0;VEN=',`0V%L96YD87(`0V%L;0!#86UB;V1I80!#
M86UE<F]O;@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA
M9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E
M(&9I;&4@(B5S(BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@(B5S(BX`0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`
M0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T
M*0!#96YT<F%L($%F<FEC86X@4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H
M25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86YG90!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L
M:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO
M;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO;W-E(&AO=R!T
M;R!D:7-P;&%Y(&1A=&5S.@!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&EC:R!T;R!#;VYT:6YU90!#;&]S
M92!7:6YD;W<`0VQO=61S`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&]M
M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VUI8W,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O
M;F1I=&EO;G,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`
M0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T
M:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;VL@27-L86YD<P!#;W!Y('-E;&5C=&EO;@!#
M;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S
M:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@
M4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP:65N
M="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@
M;F]T(')E860@)7,N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<V%V
M92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0
M('-E<G9E<BX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-
M86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1R>0!#<F5A=&4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%1I;64`0W5R<F5N
M="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#
M=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`
M0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T90!$871E(%)E8V5I=F5D`$1A
M=&4@<V5L96-T:6]N`$1A>0!$96-E;6)E<@!$96-R96%S92!);F1E;G0`1&5F
M875L="!)9&5N=&ET>0!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!097)M
M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`1&5L:79E<GD@=&EM
M90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E
M=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E
M(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE
M;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O
M:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT
M('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES
M<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R;6%T`$1J:6)O=71I`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P
M=6)L:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`
M12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5G>7!T`$5L(%-A;'9A9&]R`$5M86EL`$5M86EL($%D9')E
M<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N
M9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U
M;'0N`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5Q=6%T;W)I86P@1W5I;F5A
M`$5R:71R96$`17)R;W(`17-T;VYI80!%=&AI;W!I80!%=7)O<&4`179E<GD@
M,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%
M=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP
M;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!I<F%T:6]N($1A=&4`17AP
M;VYE;G0`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@
M27-L86YD<P!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``
M1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!U<&QO860`1FEL92!U<&QO
M861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF
M`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1F]L9&5R("5S(&1O97,@
M;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T
M('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N
M:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W
M:61E(&)L;V-K*0!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE
M<P!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;F-E`$9R96YC:"!'=6EA;F$`1G)E
M;F-H(%!O;'EN97-I80!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N
M`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%M8FEA`$=E;F5R871E("5S
M($-O;F9I9W5R871I;VX`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A
M<@!':79E;B!.86UE`$=O`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965C
M90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O=7`@
M061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP='D`
M1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E
M<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U
M`$=U>6%N80!(5$U,`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(
M86ET:0!(87-H+4%L9V]R:71H;0!(96%D97(`2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96QP`$AE
M;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO
M;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<FEZ;VYT86P@4G5L90!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D
M<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`26-E;&%N9`!)
M8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);6%G92!U<&QO860`26UA9V5S
M`$EM<&]R="P@4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@
M9FEE;&1S.@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8W)E87-E
M($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O
M`$EN9F]R;6%T:6]N`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS
M97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@;65S<V%G97,`26YS97)T
M+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@
M9&%T82X`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC
M80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&=6QL
M`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T86X`2V5E<"!O
M<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C=&5D(&%U=&AE
M;G1I8V%T:6]N+@!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,
M96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,86YG=6%G90!,
M86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S
M="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%Y
M;W5T`$QE8F%N;VX`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H
M:7)I>6$`3&EE8VAT96YS=&5I;@!,:6YK`$QI;FMS`$QI<W0@+2!U<V5R(&-A
M;B!S964@=&AE(&9O;&1E<@!,:7-T($AE;'`@5&]P:6-S`$QI<W0M07)C:&EV
M90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T
M+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@=7-E<G,@:7,@
M9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO8V%L('1I;64Z(`!,
M;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`
M3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R
M9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,=7AE
M;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N
M;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S
M;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%I;`!-86EL($%D;6EN`$UA
M;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA<F-H`$UA<FL@
M=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@
M*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA
M<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S
M`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T
M(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L96YG
M=&@`36%Y`$UA>6]T=&4`365M8F5R<P!-96YU(&UO9&4Z`$UE<W-A9V4`365S
M<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C
M97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP
M:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N
M`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&AO9`!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36EM92!4
M>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-:7)R;W(`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V
M92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@
M87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!S97-S
M:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1I9FEE9"!$871E`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&EP;&4@<V5L96-T:6]N`$UY
M($%C8V]U;G0`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA<@!.
M3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE<&%L`$YE
M=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E($)A<V4@
M55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H
M;W!T:6]N86PI`$YE=R!:96%L86YD`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W
M<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.
M:6=H=`!.:75E`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N
M(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!F
M:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A
M<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`
M3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V
M86EL86)L92!F;W(@8V%C:&4N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D
M`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO
M;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N
M9FEG=7)A=&EO;BX`3F]N90!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK
M($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@
M27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER
M96-T;W)Y`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=F5M8F5R`$YU;6)E<@!.
M=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@
M;V8@<F]W<P!/2P!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9FEC
M90!/;6%N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@
M;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE
M<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I
M;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D
M($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)I9VEN
M86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN
M("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N
M<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I
M9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC
M($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3
M:&5L;`!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<W-W
M;W)D`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I
M;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S
M=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M
M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5R9F]R;2!-86EN
M=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE9`!0
M97)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA
M;"!);F9O<FUA=&EO;@!097)U`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0
M:71C86ER;@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!O;&%N9`!0
M;VQL<P!0;W)T=6=A;`!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@
M`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:6]U<R!O<'1I;VYS`%!R:79A=&4@
M2V5Y`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`
M4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,O4')I=F%T
M92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@
M4FEC;P!1871A<@!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE
M8W1I;VX`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@
M)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y
M;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E
M;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE
M>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E
M('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!2
M97%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O
M9&4Z(`!297-E=`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`
M4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I
M9VAT`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#<GEP
M=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`
M4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S
M<V%G:6YG`%-13"!3:&5L;`!34T@`4U5#0T534P!380!386EN="!(96QE;F$`
M4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R
M92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN
M97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O
M;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B
M:6$`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN
M`%-E87)C:`!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!3
M96QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S
M97(@=&\@861D`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@
M=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N
M(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E
M>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H
M92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L
M96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L
M9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F5G86P`
M4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I
M86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T
M(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/P!3:&]W('!I8VME<@!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:')I;FL`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I
M9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N
M86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W(&1E<'1H.B``4V]L;VUO;B!)
M<VQA;F1S`%-O;6%L:6$`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D
M9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS
M*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W)I($QA;FMA`%-T86YD87)D`%-T87)T('EE87(`4W1A
M=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!
M9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W4`4W5B:F5C=`!3
M=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY('=R;W1E("5S
M`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YR:7-E`%-U;G)I
M<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I
M<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@
M36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>7)I86X@07)A
M8B!297!U8FQI8P!44U8@9FEL90!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O
M9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA
M<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@
M061M:6YI<W1R871I;VX`5&5X=`!497AT($]N;'D`5&@`5&AA:2`H5$E3+38R
M,"D`5&AA:6QA;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@36%I;G1E
M;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/
M<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@;&]C871I;VX@;V8@
M=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P
M9W`Z.B!C;&%S<RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O
M<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N
M8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E
M>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D
M96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P
M96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!U<&QO861E9"!D871A
M('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D
M960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B
M;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA
M="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY
M(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E
M<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S
M('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F
M:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU
M;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE
M;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I
M86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@
M=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE
M(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R
M97%U:7)E9"!F:65L9"X`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I
M<R`E<RX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O
M;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN
M9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO
M<G)O=P!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`
M5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE
M;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y
M;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C
M;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T
M;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R
M>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE
M('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA
M8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92X`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@
M9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;FEC;V1E("A55$8M."D`56YI=&5D
M($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5
M;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK
M;F]W;@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;G-U<'!O<G1E
M9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&=R
M861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI
M8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5R=6=U87D`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%N=6%T
M=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H
M:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I
M;VX`5F5R<VEO;B!#;VYT<F]L`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)
M22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@
M)7,`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N
M4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA
M(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@
M1E)/32`E<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R
M($9O<F5C87-T`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E
M<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`
M66%H;V\A(&UA<`!996%R;'D`665M96X`665S+"!)($%G<F5E`%EO=2!A<F4@
M:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@
M8F%C:R!T;R!765-)5UE'+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO
M=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S
M="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T
M:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R
M96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S
M:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O
M=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R
M(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P
M9&%T960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`
M6F%M8FEA`%II;6)A8G=E`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@
M)7-=`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA
M=&4`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!T
M>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`R+C`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T
M<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z
M,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`Q+3`V+3$X(#(R.C`U*S`X
M,#`*3&%S="U4<F%N<VQA=&]R.B!L:6%O8FEN(#QL:6%O8FEN0&II=&4N;F5T
M/@I,86YG=6%G92U496%M.B!#:&EN97-E(#QI,3AN0&QI<W1S+FAO<F1E+F]R
M9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN
M.R!C:&%R<V5T/4=",C,Q,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X
M+6)I=`H`("@E<R#,[,>P*0`@*+_LO=V\_"`E<RD`("B]\<SL*0`@*-?RS.PI
M`-/:`-?NO?P@)60@S.S&^,_SU*2QJ``E<R`M(+&XS?S"O``E<R#6N,[&`"5S
M($M"`"5S(,ZLNZ2RV=?W("T@R+?(SP`E<R#7HK+A`"5S(,VLTN+/[L2_`"5S
M(-+1M.;4V@`E<R#4VB`E<R`E<P"QV-#HTJH@)7,`)7,@M]8`U=*RN[6]("5S
M+@`@)7,@M;T@)7,@N;(@)7,`)7,Z("5S`"P@U?.WYR`E<R`E<P`LL>2[K\&_
MM-,@)7,@M;T@)7,`+2T@T:'4\2`M+0`R-"#0H<JQUL8`M,O'^+_IL=C0Z]*J
MUKBVJ,K]OMV_XK?^SO&VRRX`MZ+)^L'+TKNX]M'/UMBUQ+3MSO,`T_N\T\/<
MT\J\_BR[N=#HTJK3T-*[N/8@4$=0(+FKOZK#W-2_+@#3^]'IUJ32T<>IP_NU
MQ-/*O/XLN[G0Z-*JT]#2N[CV(%!'4""YJ[^JP]S4ORX`T_N]XL/<T\J\_BR[
MN=#HTJK3T-*[N/:YJ[^J(%!'4"##W-2_+,N]P]P@4$=0(,/<U+\LTM2\L+_:
MP>XN`-/[UK30T-/*O/['J</[++NYT.C2JM/0TKNX]KFKOZH@4$=0(,/<U+\L
MR[W#W"!01U`@P]S4ORS2U+RPO]K![BX`T_N]XL/<T\J\_BR[N=#HTJK3T-*[
MN/:YJ[^J(%--24U%(,/<U+\LR[W#W"!334E-12##W-2_+-+4O+"_VL'N+@#3
M^]:TT-#3RKS^QZG#^RR[N=#HTJK3T-*[N/:YJ[^J(%,O34E-12##W-2_+,N]
MP]P@4R]-24U%(,/<U+\LTM2\L+_:P>XN`-/[O-/#W-/*O/XLN[G0Z-*JT]#2
MN[CV(%--24U%(+FKOZK#W-2_+@!!32]030!!4$D@L>"ZQ0"YV-/:U>*X]K'@
MO*W&]P"YV-/:+BXN`,BHS]ZRN]?C+,[>MZB]J,&B(%9&4R#$O\*\+@#(J,_>
MLKO7XRS.WK>HO:C!HB!61E,@SL2\_BX`U<NZQ=+1MK.]X2X`O>'5R@#0PM3V
M`-#"U/;/PKRVU^D`T,+4]L_"O+;(J,_>`-3:M,O0PM3VH[H`T,+4]M/#NZ?7
MZ0#0PM3VR*C/W@#0PM3VTKNX]M/#NZ<Z`-#"U/;2N[CVL\G4L3H`T,+4]K;4
M`-#"U/8@)7,@SJH@36]Z:6QL82!3:61E8F%R(+++M:4`T,+4]M/#NZ<`T,+4
M]M/#NZ>UQ+FFQ-RUL<>PL;NYV+'5+@"UV-:W`,VHT;:RO@"SR<ZJN=S`[=2Q
M("T@SJK&Y,O\T\.[I\7DUL/(J,_>`+G<P.T`N>.XYKG<P.T`L**XN[JY`+"B
MMONPS<3AT<<`L**V^[RPP/O1QP"Q\,/[`,OYT]#2T='IUJ2UQ-/#NZ<`R_G3
MT-/#NZ?7Z0#+^=/0R*C/W@#4RM#MMN"X]K7GU]/3RKS^M=C6MP#2T;3FU-H`
ML>2X_"!)35-0(+7'PKP`L>2X_"!)35-0(,/<PNL`L>2X_"!)35-0(-/#NZ<`
ML>2X_,2CL.8`P\#*],CXQ*;1QP#2N[CVLKNZS[>HM<36M;&[RKG3PRX`L+*U
MP+;[`+"RN.?`K0"PLKGGP*T`Q.3#^[3ZP.T`Q,^\J];>`+"RS.&YS[RPL,VV
M^[*\M.\`TZ;3P[/,T/(`TZ;3P[/,T/+2T;[-T/<`TZ;3P[6]R_G3T,_"O+:Y
MLL_M`,7ZU[P`R\34P@"PHL"MLJ[.Q"`H5VEN9&]W<RTQ,C4V*0#1N<OUSL2\
M_K3ST*$`T;G+]<[$O/[#^[/&`,3ZR+>VJ-*JR;ZS_2`E<R"UQ->BLN'"\"`_
M`+"BN/G-H@#1Q\/`Q.'1QP#1Q\/`Q.'1Q\[$("A!4DU30TE)+3@I`+"BPK.P
MS0"PHLFMR\G(NK6Z`-''UMXOS*O&O='SM=C'^`#6M-#0SJR[I++9U_?'L,_4
MRK[(M\C/MM2[L+_R/P#*U,V\R;ZS_=*[N/:RN[3FU-JUQ-/#NZ?7Z2X`RM3-
MO,F^L_W2N[CVLKNTYM3:M<3(J,_>+@#*U,V\L>"\K=*[N/:RN[3FU-JUQ-/#
MNZ?7Z2X`RM3-O+'@O*W2N[CVLKNTYM3:M<2YLL_M+@#*]-#4`+#+U,(`L,2T
M\\#[T<<`L,*UV,#[`$%U=&A?8W)Y<W%L.B#5TK*[M;W+^=#HTJJUQ"!I;6%P
M(,"IU;G7Z;S^+@!!=71H7V-Y<G5S.B"W_L[QMLNRHLZTS.&YJ;C#S^[6I[/6
M+@!!=71H7V-R>75S.B#5TK*[M;W+^=#HTJJUQ"!I;6%P(,"IU;G7Z;S^+@!!
M=71H7V9T<#H@U=*RN[6]R_G0Z-*JM<0@1E10(,"IU;G7Z;S^+L?KUMC0PK'@
MTNL@4$A0(+*BQ]*\T\CK("TM96YA8FQE+69T<"#1H<_N+,#]R.<@8V]N9FEG
M=7)E("TM96YA8FQE+69T<`!!=71H7VEM87`Z(-72LKNUO<OYT.C2JK7$($E-
M05`@P*G5N=?IO/XN`$%U=&A?:W)B-3H@U=*RN[6]R_G0Z-*JM<0@:W)B-2#`
MJ=6YU^F\_BX`075T:%]L9&%P.B#5TK*[M;W+^=#HTJJUQ"!,1$%0(,"IU;G7
MZ;S^+@!!=71H7VQD87`Z(,[>MZC0PM3VT\.[IR`E<RX@M_[.\<;WN]C3ICH`
M075T:%]L9&%P.B#.WK>HR;ZS_=/#NZ<@)7,`075T:%]L9&%P.B#.WK>HN/S0
MPM/#NZ<@)7,`075T:%]M8V%L.B#5TK*[M;W+^=#HTJJUQ"!-0T%,(,"IU;G7
MZ;S^+@!!=71H7W-M8F%U=&@Z(-72LKNUO<OYT.C2JK7$('-M8F%U=&@@P*G5
MN=?IO/XN`-'IUJ3*I[#<+@#1Z=:DRJ>PW"X@)7,`4D%$2553(-'IUJ2T[<[S
M+@!&5%`@T>G6I+3MSO,N`+_)T\.UQ-?6MLXZ`+"BR/NPW;VN`+&SOK#1U<FK
M`&ME<F)E<F]S(,/<PNNT[<[S+@!K97)B97)O<R#3P[NGP_NT[<[S+@"PS;G^
MPNW(NK6Z`+#-P=8`LJC"WK7$NJ/.Q"`H25-/+3@X-3DM,3,I`,//O-/`K;GZ
M`+#-L,VVX,NY`+#7MNW"WLNY`+'(P/O*L0"RKL#[U\@`L;3$_@"PV<2]M//(
MNK6Z`+*[M:0`R?K(U0#'^+_IQ>36PP#'^+_IP.#0S0"TULSE`+*CP/O.K-''
M`,KIQZD`LJC+N<3AT<>ZS;K:R/NXY\ZLQ,<`LJFTQ,W?Q,D`LJC.K,S8M;H`
ML,W.]P#3HLKTTZ&VR-'SP>RUV`#.Q,"S`+&CO-/`^]''`,_NQ+^W^[K%`+*\
MO*K$R;>HR_<`LKS"H;7/`,3:R-VYW,#MS[7-LP!#4D,`0U),(+?6LKRUXP#(
MU<#Z`,'CO+:WYP"\[<;2U:\`OZ;"\\*A`,[>MZC!JKOZUL$@24U!4""W_L[Q
MQO<Z("5S`+S3Q,.T\P#(H<_[`,BAS_O.RLSBL:BXY@#.WK>HR;ZS_<[$O/X@
M(B5S(BX`SMZWJ,F^L_W$O\*\("(E<R(N`,[>MZC6V-?IH:/+^<SAN:FUQ+S'
MPKS*_<2_T^O/R,>PR_FQH[3FM<3*_;[=LKNW^RX`SMZWJ+2KR\W0Q<^BM;W6
MN+:HM<2ZQ<+K+@"W\+7#O<<`OZK"_,BZM;H`TL:VK[7GN[``R/NV^\S8SL0@
M*$E33RTX.#4Y+3$T*0#6T+?'N;*ZS;GZ`-;0Q;<@*$E33RTX.#4Y+3(I`,:^
MUJ3/N+W:`,:^UJ2RW\+4`-6GM<,`N/RXQ`#6Q\#[`-;0N?H`O/+,Y=;0SL0@
M*$=",C,Q,BD`M[',Y=;0SL0@*$)I9S4I`-&AU/'#W,+K`-&AU/'2N[CVT\.[
MI\/[`,C5QMK/U,J^M[W*O3H`RJ6UKK6Z`-72LKNUO2`E<R"UQ,#@L?"VJ-+E
M+@"PM,KSL>J\_+S,T/@`N=BQU;2PO]H`U,;!OP"_QK_&R[G(NK6Z`+CGPM>Q
MR-''`-'5R:L`M??)J\7,`+^HS:@`P_S![@##_,'NO<6QO@#&P,+;`,VHT\/#
M^P"_QL2FPMX`N:O+O@#,];S^`,7DUL,@)7,`R+?(S\/<PNL`N-6Y^P"XU;G[
MN;*ZS;GZ`,&LO=/*I[#<.B``P:R]T];!N:N_JL/<U+^W_L[QQO?*L=3BOMR^
M^"X@U*W2\CH@)7,@*"5S*0#!K+W3UL$@1E10(,[$O/ZW_L[QQO?*I[#<+@"_
MXK_+R+JUN@"XM-;&T:'4\0"XY\NYM._`Z+S3`+_&S-BUS\W?`,[>MZC2U"!0
M1U`@O-/#W-/*O/XN`,[>MZC.JB!01U`@UK30T-/*O/['J</[+@#.WK>HTM0@
M4R]-24U%(+S3P]S3RKS^+@#.WK>HSJH@4R]-24U%(-/*O/['J</[+@#.WK>H
ML/.VJ"!,1$%0(+?^SO'&]P#.WK>HO>+#W"!01U`@ROV^W2X`SMZWJ+WBP]P@
M4R]-24U%(,K]OMTN`,[>MZB^]K:HRM6\_LC+M<2UY]?3T\J\_K78UK<N`,[>
MMZC7U,/<U+^W_L[QQO?(H;7#N:N_JL/<U+\N`,[>MZBT\K^J("5S+@#.WK>H
MM/*_JLZLNZ2YI-?WQ*._Z2`E<P#.WK>HML'(H2`E<RX`SMZWJ+;!R*&TYLBA
MO]C6QK'M*$%#3"D`SMZWJ+;!R*&W_L[QQO>UQ,_@N=C,V-#4`,[>MZBQH[3F
M("5S(+7$Q>36PRX`SMZWJ++IU=(@3$1!4"`@M_[.\<;W+@#5TK*[M;T@36]Z
M:6QL82!3:61E8F%R+B#'Z\BWR,\@<VED96)A<B#*Q[?QM/*_JBX`N?J\T@"]
MJ,&B`+VHP:+7T\[$O/Z\T`"]J,&BU=^UQ,BHS]X`T,73P[^HNL7"ZP"_R\+>
MM=C1QP"YQ;#-`+6QQ[#*L;SD`+6QQ[#,[,;X`+6QQ[#7M+_V.B``M;''L+?G
MN/$`O/3'T-&AU/$`R/O&UL*WR[D`SO?`[[;[SL0@*$M/23@M4BD`SO?`[[;[
MSL0@*%=I;F1O=W,M,3(U,2D`SO?`[[;[SL0OSMJ_R\"\SL0@*$M/23@M52D`
MO=V_R[FRNLVY^@#(U0##O\C5`,C5QMH`RM6UO<C5QMH`T:'4\<C5QMH`L-?,
M[`#*KK;^U,(`O/7)V<OUQ<4`Q*S(S\GMM]W*MK'P`,F^L_T`R;ZS_=/#NZ?7
MZ0#)OK/]R*C/W@#)OK/]H:+'Y;_5T\J\_@"UW<O-RK&\Y`"UI,+S`,[*S.+#
MZ,KV`,/HRO8`S[B]VB`HQ^NRSK^\($AO<F1E(+S'PKS.Q+S^*3H`S[B]VL?K
MLLZ_O,^US;.YW,#MM<?"O"X`T="WH@#"MK7CSL*VR`#7[KKSTKO0H<JQM<3"
MMK7CSL*VR#H@`,*VM>/.PK;(.B``M-/7\];!T](`M-/3TM;!U_,`Q+_"O`#2
MU"`R-"#0H<JQUL;/U,J^/P#/U,J^T:'/[@#/U,J^N/'*O0"\JK*\S.$`LKO)
MOK/]`+*[TJK6L;W3M.;(H2!M86EN=&5N86YC92YP:'``M=K2N['*O,?"O,K'
MM_&P_+JLU]:VSL/[L\8_(,CGN?O*Q\?KT:'4\2X`MN##U\3AO-,`MN##U\3A
MO-.YLKK-N?H`S\+4V`#/PM38("5S`,_"U-C)^K/)M<3%Y-;#SL2\_LZJ(%!(
M4""SS-#R+@#/PL"MLLNUI0"UY]?3T\J\_@"T[<[S`+;RN<^VX+;[`+'@O*T`
ML>"\K<?XO^D`L>"\K=/#NZ?7Z0"QX+RMR*C/W@"QX+RMR*C/W@"QX+RM("5S
M(+7$R*C/W@"QX+RMT:'/[@"QX+RM("5S(+7$R*C/W@"PH[RP`,CXMOO-W[;@
M`+7GU]/3RKS^`+7GU]/3RKS^M=C6MP"UY]?3T\J\_K78UK>QV-#KSL>ZSRX`
MM>?7T]/*O/[(M\C/`+'MQ^FW^[K%`+_5L-?0Q;S^+@"_U;#7O>&Y^RX`Q.JU
MUP"WQ;3SL>"\K<;W`+/@M<"\N,3:T<<`MO+!HLS8P._1QP"T[<[S`+"NR;/$
MX=''`+"CR/NV[;'(T<<`Q;?6W@##OR`Q-2"WUM;3`,._(#,P(,/KUM,`P[\@
M-2"WUM;3`,._M,ZUQ\*\`,._(#,P(+?6UM,`P[\@,2"WUM;3`+>VP/W6M3H`
MUK30T`#5N;^J`+6]QMK(U0"]XLNUU+$`1E10(,G/M*O%Y-;#+@"VP<BAQJNZ
MP\7DUL/*I[#<`,[>MZC!K+W3($Q$05`@M_[.\<;W+@#.WK>HP:R]TR!334(@
MM_[.\<;W+@"XM-;&RJ>PW-?4("(E<R(N`+BTUL;*I[#<M;T@(B5S(BX`SMZW
MJ+VHP:+2N[CVT,*UQ"!305-,(,&LO=,N`-+&MJ^UO2`B)7,BRJ>PW"X`MZC`
MO+_+N*/(NK6Z("C"[;;[SJS$R<NYR+JUNBD`MZC"WLBZM;H`M*O5Y@"V_M3"
M`+C0OO7/\<K'`+C0OO7/\<K'.B``[+.\PP#.Q+S^ROW$OSH@)7,@N/;.Q+S^
M`,[$O/[*_<2_.B`E<R#.Q+S^`,[$O/ZYW,#MQO<`SL2\_L/[L\8`SL2\_LG/
MM*L`SL2\_LG/M*NYIL3<SK2QN]:GL]8N`+G]PLO&]P"WTL"\`,G/L.O4P@#)
MS\_2U,(`N<RVJ+'(P/T`MZW7J@#$O\*\("5S(+*[M.;4V@#7UM#-T=7)JP#4
MI+&HS.S*_2`HU*2QJ,SLROVP_,"HL-?,[-+4O+#2N;SDM<3*_;[=.\CGN?O4
MI+&HS.S*_;W/LZ2]J]6\T\.QR+W/O^VW^;7$L.;#YBD`M+#,Y0#+X\/\`,OC
MP_S`X-#-`,OCP_P`PMO,LP#7U+:OUZK0Q0#0Q\;:SN4`MZBY^@"WJ,KTN>?1
MQ\3'`+>HRO2RH\#[Q.'.]]''`+S$O/[(RP"TTP#-ZM7[P^C*]@#"^M3"`,BK
MP_L`O-/%[@"XU+'(T<<`LOK)^B`E<R"UQ,^US;/%Y-;#`+CQPK.\JM''`+7"
MN?H`Y<C$R0#6L;*\PM[-TP##^P#7JK6]`$=O;V=L92#+T<OW`+O2ML@`SZ/`
ML`#/H\"PSL0@*$E33RTX.#4Y+3<I`+CQP>K`O`"X\<'6Q,FT[P#3P[NGU^FY
MW,#M`-/#NZ?7Z</[L\:RN[7#O]6PUP#3P[NGU^D`N<^UPL+>QM6UN@"YV+6Z
M`,ZCM=C"[<"M`+CQMO?.][6Z`+?#O\W(J,_>`+?#O\W!]-'4`+RXQ-K1QP"\
MN,3:T<>QR,G<N;*ZS;GZ`+GGT<?$QP!(5$U,`-72LKNUO2!(5%10(-'IUJ0N
M`+JCM=@`U-.TU2W+X[>H`+'MS;<`NM6UPKK-PO2UL<#-R+JUN@#/H[*NP+3.
MQ"`H25-/+3@X-3DM."U)*0"P[];Z`+'@O*W&]\JYT\.P[];Z`+#OUOH`U>+`
M[\K'SL2\_K7$OZK*O#H`Z/.UV;C4`,K7TK,`RM?2L[78UK<`RM?2L[7GN[``
MNNFVO,"MR[D`UM"Y^L_CN-L`2&]R9&4`RZ[&O<_?`-?6ML[*_<2_N;*\QC\`
MRJJVR`#*JK;(.B``T-G1P,#[`$E-05`@T\K/Y+VHP:+*I[#<.B`E<P!)34%0
M(-/*S^3)OK/]RJ>PW#H@)7,`24U!4"#3RL_DM,7%S,7DUL.]J,&BRJ>PW#H@
M)7,`25`@M=C6M\[>MZC*N=/#+@!)4""UV-:WLJ*RN]3:($-)1%(@M<2]T\K<
MQ_B_Z=;0+@"Q^;6Z`-:[T]#-O+'J`,V\L>J\L,[$U]8`R<^TJ\V\QJP`S;S&
MK`"[X\CK+""RO=;H("5D`+OCR.O7UK;..B`E<P"[X\CKU]:VSCH`RN3(Z[*[
MU?W(M[7$U_?3P\+K+@#4]KS3R_7%Q0#3H;;(`+CVL?#3P[NG`-.AMLC$X<[W
MT<<`T,7/H@#0Q<^B`++ER.NQ[;CQ`++ER.O-^,+GP:R]TP"RY<CKO\G,YK3Z
MQ*.PY@"RY<CKT\J\_@"RY<CK+['DN/S-O,:L`++ER.LOL>2X_,WXPN?!K+W3
M`-7[ROT`U?O*_<'0`,[>T*>UQ"!51$@HT\.[I\K]OMVQ[<VW*2X`SM[0I[7$
MTZ;3P[/,T/(N`,[>T*>UQ,7ZM,ZZQ<+K+@#,X;V[M<3*_;[=SM[0IRX`SM[0
MI[7$Q+^QZM>AUK<`LKNZS[>HM<3.Q+S^N/'*O0#.WM"GM<0@;7-G7W1Y<&4N
M`,[>T*>UQ+ORU=*RN[6](&%P:5]I9"X`SM[0I[7$N_+5TK*[M;VRSLK]+@"R
MN[K/MZBUQ+BXR*C/WBX`SM[0I[7$S:C1MM"MTNDN`,[>T*>UQ,"TU+37H=:W
M+@#.WM"GM<3-\M/#PNO*_;[=+@#2P<#*TL'+N<"\N;*ZS;GZ`-+!P*V_RP"P
MKK;[P+P`PORUN@#2U,FKP=``QZFWHM7?`-"QS.4`TN*T\\#[`-'`PO*\TP#2
MN]3"`$IA<&%N("C(U;&^*0#(U<[$("A)4T\M,C`R,BU*4"D`U//.][6Z`-2\
MM:D`QM_4P@#!^=3"`-;#UM``U_/3TK;4QNL`O[_7\[;4QNL`O[_3TK;4QNL`
MN?[(^+_+R[G,N0"QH\'TU*W1^2`_`+_/Q.'1QP!+97)B97)O<R#(S]:DM.W.
M\RX`P]S4O[VHP:(`P]S4O\S8U?<`P]S4O[.DML@`P]S4O\#@T,T`P]S4O]/O
MMZ@`M;''L+7$N:N_JL/<U+^W_L[QQO?6T"S2T;ZMM.;4VL3ZM<3#W-2_+@"[
M^<#OL,W+N;FRNLVY^@"SK\_*`+JKN?H`NJO.Q"`H155#+4M2*0"_QLW^S-@`
MO*JV^[RJR[G,N0#3[]'4`,#/SLX`S\*PZ]3"`,_"S]+4P@#)S[3.N/S0PCH`
MR<_2N[3.M<?"O#H@)7,`R<_2N[3.M<?"O#H@)7,@U]0@)7,`R<_2N[3.M<?"
MO#H@M=K2N[3.M<?"O`#`K<W1SJS1QP"PYL/FQ>36PP#`Z+#-Q-L`P+/+]\W0
M`,#[L<C`[]''`,#[L<C1QP#!T-:GMMC*O[7'`,&LO=,`P:R]TP#!T+/V("T@
MT\.[I[_)TM2_M+6]U>*X]L[$O/Z\T`#!T+/VR[7#]['JS.(`S-;"V]/#NZ?7
MZ2W.Q+S^N?$`S-;"V]/#NZ?7Z2W'\];Z`,S6PMO3P[NGU^DMRK:Q\+K%PNL`
MS-;"V]/#NZ?7Z2W3M=/0U=\`S-;"V]/#NZ?7Z2V\Q+S^R,L`S-;"V]/#NZ?7
MZ2VVJ=3$`,S6PMO3P[NGU^DMR*'/^[:IU,0`P="S]M/#NZ>UQ+FFQ-RQN[G8
ML=4`SL31IP#!HLS5S?``M;&UV,JQO.0Z(`"UV,?XT^O*L;SD`+78Q_@`M<?"
MO`#7HL_Z`+7'PKP`M<?"O,JGL-PL(,?KO.RRZ<3ZM<33P[NGP_NZS</<PNLL
M(,B[NO/6V,K4+@"UQ\*\RJ>PW"X`PJS)K;&D`-3"`,._R-70Q<^B`$U3+51.
M148@N+V\T\[$O/[6T,.[T]#*_;[=+@!-4T<`UM"Y^K#$P\4`PNW&Y+;9N;*Z
MS;GZ`,+MM.^\T\NYO-.UN@#3RKS^`-/*O/ZYW,#M`,+MP*W-_@#"[<"TSO?1
MQP#"[;;[M/JW\@#"[<#[`,+MMOK+^P#(_=3"`+'JO,>SR2"_M+G]+\ZTO[2Y
M_0"QZKS'L\G&Y,O\M<3*MK'P("C`_<CG+B#6V-*J+]+1N]BXM"D`PNW)W+;[
MR+JUN@#"[<SAQ.&_R[6Z`-7]U-K&I<7DU]:VS@##J\#OR_[$X=''`,.KP._'
M\\NY`+B]O/[*_<2_TM&SK+/VO=/*W,G/S]XN`-?NO?P@,C0@T*'*L;7$U^ZX
MW\["ML@Z(`#7[KW\(#8@T*'*L;7$U^ZXW\["ML@Z(`"]T\K<U^ZT\[.DML@`
MSN74P@#"[=2\S-C(NK6Z`+/)U+$`T:&UI<2CRKTZ`-/*O/X`T\J\_M'IUJ32
MT<WJL\DLM:O*Q]/#NZ>UQ,>IP_O(M,[>MZC-J+G]T>G6I"X`T,7/HM+1N?W&
MVBX`T,7/HL#@T,T`365T87(@Q_B_Z<[>MZC*N=/#+@!-971A<B#'^+_ISMZW
MJ,JYT\,N(,^XO=K'Z[+.O[S/M<VSN=S`[;7'PKPN`+>]MZ@`N:O6Q@#$J\[W
MN.<`P]R_R\+>Q.'.]]''P:JP[KGZ`$UI;64@P.#0S0#7[KW\(#(T(-"ARK&U
MQ-?NM<W.PK;(.B``U^Z]_"`V(-"ARK&UQ-?NN-_.PK;(.B``T[/)Y`#%Y-;#
MSL2\_M+%RJ<N(,CGN?O2JLJYT\/5XKCVTZ;3P[/,T/+$^K'8T.O/UM3:OLVR
M^LGZR_LN`-72LKNUO=#%SZ*UQ"!)1"X`U=*RN[6]N^'&VK7$($E$+@#0Q\;:
MTKL`T-"VK]/*O/X`N/S0PLC5QMH`Q*._Z0#$IK;[MN#-WP#$IL3)N.<`P\FY
MQ0#4PKK-Q.H`P[_4P@##R<S8R/O`K<S8`-3"P<'3K[_W`,2FPN6XYP#/PM+&
M`-?STL8`T]+2Q@#)S]+&`,_"TL8`R<_2Q@#$JLFCL<B_RP"XM-&A`,[2M<35
MR[K%`,[2M<3#Q;NG`,[2M<3#Q;NGTK/#YL7DUL,`P^6UZ0"RNRS.TK*[S:S2
MX@##^[/&`,3)P]>QR-''`.BGPK,`Q.&RM+;[`+K)P+P`NLG*]+"RM=C!T,NY
M`+OYT]I.971S8V%P92"UQ,WXUK<`3F5T<V-A<&4@4U-,(+?^SO'&]\/[L\8`
M3F5T<V-A<&4@R,_6I+7$Q?K7H@!.971S8V%P92#(S]:DP.#0S0#-^,+G`+33
MSK0`T,*_IL#OMN#$X=''`-#"U,(`T,+3P[NGP_L@*+?'L=C2JBD`T,+.]\"\
M`-#"M+"_VB`H7V)L86YK*0#0PL[%`,_"TKNRO0#/PM*[N/;1H<_N`,3AO-/`
MK;G/`,3AR-6V^P#$X<C5P/O1QP#-[<G/`,6FL*.UN@#+^=:XMJBUQ,Z[UL/)
MS\.[T]#'^+_IM.;4V@##N]/0S.&YJ<C5P/K#^[/&TM2YJ2!-0T%,(-'IUJ0N
M`,.[T]#6N+:HM<0@)7,@Q>36P]#%SZ(N`,.[T]#6N+:HM<0@1E10(%9&4R#%
MY-;#T,7/HBX`P[O3T-:XMJBUQ"!344P@5D93Q>36P]#%SZ(N`,.[T]#6N+:H
MM<0@4U%,+49I;&4@5D93Q>36P]#%SZ(N`,[$O/[.M,G/M*L`SKO6P]#%SZ+)
MT,ZTQ>36PP##N]/0UKBVJ,/<PNO2U+FI($A45%`@T>G6I"X`P[O3T-:XMJC#
MW,+KTM2YJ2!)34%0(-'IUJ0N`,.[T]#6N+:HP]S"Z]+4N:D@2V5R8F5R;W,@
MT>G6I"X`P[O3T-:XMJC#W,+KTM2YJ2!,;V=I;B#1Z=:D+@##N]/0UKBVJ,/<
MPNO2U+FI(%!!4U-71"#1Z=:D+@##N]/0UKBVJ,/<PNO2U+FI(%--0B#1Z=:D
M+@##N]/0M/W)\[7$UZ*RX<GJQ^LN`,[>U-VTYL2_PKR_R;FIO^S(H2X`P[O3
MT+K/MZBUQ"!834P@ROV^W;&[M*N[V`"_U;#7UK4`U*W*O,7DUL/.Q+S^UM#5
MTK*[M;VPYK&^T,7/HBX@UMC0PK+ZR?K%Y-;#SL2\_BX`U-K$^K7$Q>36P\[$
MO/[6T-72LKNUO;#FL;[0Q<^B+B#6V-#"LOK)^L7DUL/.Q+S^+@#.W@#(U;;Z
MPOS.Q"`H25-/+3@X-3DM,3`I`,6UN*._R[6Z`+&QL.O'\@"QL<+MP._1Q\3)
MR+JUN@#%LLW^`+?'UJZZ\P"WQ]:NQ[``LKO*Q]*[N/;$O\*\`,ZTL;O6I[/6
M`+&XS?S"O`#*KM*[U,(`ROW7U@#7UK?[ROT`U]:VSLK]Q+\`L<K*_0!/2P"V
MU,_SO:C!HM7?`+#+O?C.NP#*KM3"`+#LN:O*T@"PHL+\`-:[T]`@24U!4""W
M_L[QQO?6I[/6SL2\_KS0N;+/[;FFQ-PN`-:[O=/*W-*[N/;3RKS^M=C6MRX`
MUKO3T-.UT]#5W]/KS[7-L[G<P.W4L;_)TM2QY+C\N;+/[<BHS]X`U-K0PK2P
MO]K6T+3ROZH`T:'/[@`E<R"UQ-&AS^X`S^[$O['@NL4`U^G6KP#7Z=:OM:7.
MNP#4K<J\TZ;3P[/,T/+$H[#F`-3:("5S.B#6T+7$U*W*O,2CL.8N`,;DR_P`
MQN3+_-#%SZ(`T[73T-7?R*C/W@!004T@T>G6I,[>T*<N`%!'4"#*_=?6QZG#
M^P!01U`@O-/#W-?*P<\`4$=0(+FKOZK#W-2_`%!'4"#2T<>IP_LOTM&\T\/<
M(-?*P<\`4$A0(+/,T/*T^L+K`%!(4""]Q;&^`+#-N_G+N<RY`,7!P,T`L,W`
MU<NYS+FQN]6\P>S'^`"PS<3#PNT`L,VRO-''T,*\N,3:T<<`L,W`K;GG`,/<
MPNL`P[O3T-:XMJC#W,+KTM2YJ2!2041)55,@T>G6I"X`P]S"Z\BWR,\`P]S"
MZSH`P]S"ZSH@`,/<PNNQV-#KSL>ZSRX`S/G)SP#,^<G/`,*WOK8`M/W)\[7'
MPKRCN@#6M-#0SJR[I++9U_<`M<?"O+KSUK30T,ZLNZ2RV=?W/P#(J,_>`+3F
MR*'4XK[<`,BHS]X`R*C/WKG<P.T`SM*UQ`##V,*S`+?&PLFQ]@"UY[NP`-75
MQJP`QJ3,V+^UM;H`Q^O*Y,CKTKNX]M3"M]V\L,3JM]TN`,?KRN3(Z]*[N/:Z
MS[>HM<3(U<;:.]&AU/&TR]3"M]VUQ,C5QMHN`,?KRN3(Z[K/MZBUQ,JQO.0N
M`,?KS.&YJ<[*S.*UQ-6JTJHN`,?KRN3(Z\3ZM<33P[NGP_N\L,/<PNL`LJC`
MO`#-ML:Q`,;/S-'1P`"UW<O-T\J\_K6]U>*X]L[$O/Z\T"`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I`-?NO?P@)7,@T*'*L;7$O;73ZL&_.B``4')E9G-?;&1A
M<#H@U=*RN[6]R_G0Z-*JM<0@3$1!4"#`J=6YU^F\_BX`4')E9G-?<V5S<VEO
M;CH@U=*RN[6]R_G0Z-*JM<0@<V5S<VEO;B#`J=6YU^F\_BX`QOC1N0"ZH\:]
MP^;&^-&Y.B``QOC1N3H@`-2DP,``R<_2N[CVT:'/[@#+O</<P]S4OP#.RLSB
MP^C*]@#7J+"X`,SARK[$VLC=`+FKOZK#W-2_`+FKOZK#W-2_T=W+XP"YJ[^J
M+\N]P]S#W-2_MM2RHLZTL;NR^LGZ+@"RJ+;@P.BX]P"_J,O^MOL`4E-!(+FK
MOZK#W-2_("@E9"#.NRD`M:71H0"QR,+*`+;!R*$`ML'(H=/*O/X`U>:UQ-*J
MR;ZS_2`E<R#"\#\@U>+/[K+9U_>]J\[>MZB[UKBT+@#(H<_[N+34K0#+HM#"
MP\6[I\K3S;PZ`+GFU/*Q[;3ORKT`QL#"VP#4MK/,M_[.\<;W`-2VL\S-^-:W
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`R;ZS_0#)OK/]Q_B_
MZ0#)OK/]MM0`U]2W_L[QQO?4W;3FQ+_"O-;0R;ZS_=+1L:.TYK7$Q>36P[/,
MT/(N`,F^L_W3P[NG`,F^L_W3P[NG.B`E<P#0Z,?SSK2QN\_LTZ8Z(+3MSO.Z
MQ<+K.@#6V,GH`+WAN?L`M[6[V-&AS^X`4F5U;FEO;B`HP?3$X<WZM;HI`+W'
MR:L`4F]M86YI82`HPM["[<3AT<<I`-#]UZH@,3@P(+;(`,_RU_/0_=>J`,_R
MT]+0_=>J`-:TT-``4G5S<VEA;B!&961E<F%T:6]N("BV[<+>R[DI`%)W86YD
M82`HPJRPLK3O*0!3+TU)344@O-/#W,>IP_L`T\J\_M+1RKG3PR!3+TU)344@
MO-/#W`!305-,(-'IUJ3.WM"G+@#0Q<^B`,K]OMV_XKW%L;X`O-/#W-;5MLN[
M^@"SR;FF`-#'QMK!^0#*I;K5P-7$P[6Z`,JEN_FUPKK-P=#.K,NY`,JEPJS.
M]]''M;H`RJ7&I+"CMONZS<+SO\O"U\BZM;H`RJ7.Q,FMS-BZS;CQP=;$R;3O
M`,VLTKNX]K2PO]H@*%]S96QF*0#(^,2FT<<`RJ7"[<&FQ;4`RJ6VX,/`NLW&
MU<'6SO>QR`#.P-#'S.&YJ=7?`,FSS-BPHL"MLJX`L:.TY@"QH[3F("5S`+&C
MM.;1H<_N`+VKLOK)^K7$Q>36P\[$O/[2U"!02%`@T^_1U+CQRKVQH[3FM;W$
M^K7$M_[.\<;WU-VTYL2_PKS6T"X`Q>36PR`E<R#2T;&CM.8N`,O1T;``T:'4
M\=*[N/;(U<;:`-&AU/'2N[CVT\.[I]?IT\/2U-#"U/8`T:'4\=*[SKO0PK7$
MT[73T-7?`-&AU/'2N[*_M_[.\<;W`-&AU/'2N\Z[T\.[I]/#TM30PM3V`-&A
MU/'+^=/0R-7&VM?IO/XN`-/:TM3/PK7$M+"_VM;0T:'(H<3ZTJJUQ-?6M_LN
MTM3*\['JN+36QLOYT:'.Q-?6+,B[NO/,^<G/SL2\_K'@O*W'^"X`T:'4\<C5
MQMJWUKCT.@#1H=3QR-7&VLC5QMJX\<J].@#1H=3QRK&\Y+?6N/0Z`-&AU/'(
MU<;:RK&\Y+CQRKTZ`-&AU/'/X+NEQJ7%Y+7$MOZX]M?6MLXN`-&AU/'$^K7$
MT=7)J\7DUL,`T:'4\<:KNL/3[]'4.@"TJ\O-SLK,XK>TTZ8`4V5N96=A;"`H
MR/O$VKS3MOLI`+2KN-#&]SH@`+[%U,(`4V5R8FEA(&%N9"!-;VYT96YE9W)O
M("C(^[;[SJS1Q]/KP\G,V,3AN.?"WBD`T/*ZQ0"[X<;:($E$(-+1N?W&VBX`
MQ>36PP#%Y-;#U+:SS+?^SO'&]\G/RO33VL3ZM<2X]LC+U;[,J"X`Q>36P\3Z
MM<3&J[K#T^_1U"P@RK''^-+4O+#(U<;:N/'*O2X`Q>36P\3ZM<3&],J\TZ;3
MP[/,T/(LT=7)J\7DUL,LTK/#YKC\T,+&M<+*++RPQN3+_,_4RK[1H<_N+@#3
MT+K#O+BX]K78M>.ZS=7BN/:RSLK]T]"YV#H@`%-E>6-H96QL97,@*,C[SO2V
M^RD`N;K.[P"\\K;,U:K2J@#*Q[?QSJJT\[*_M]VUQ,&LO=.VJ-+EO^R]W;FF
MQ-R\_#\`S]3*O@##O[3.M<?"O+KSS]3*OLG/TKNTSK7$M<?"O,JQO.0@/P#/
MU,J^M>/1H<;W`-/:U_.QW\_4RKX@)7,@LLNUI3\`RM7+]0!3:65R<F$@3&5O
M;F4@*,JHU]/)O;GZ*0#7HK+A`,>IP_L`QZG#^]'=R^,`4VEN9V%P;W)E("C0
MPKS3QL(I`+3ST*$`PM2Y_<ZLNZ0`4VQO=F%K:6$@*,NYPN6WI;_+*0!3;&]V
M96YI82`HR[G"Y;>EQ.'1QRD`N_W1J<GNML@Z(`!3;VQO;6]N($ES;&%N9',@
M*,OWPM[#Q<BZM;HI`%-O;6%L:6$@*,OWPNW`^]''*0#%Q<'0M[W/\M&AU/$`
MP+34M+78UK<`4V]U=&@@069R:6-A("C$S[?'*0#$S\6W("A)4T\M.#@U.2TS
M*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD
M<P#$S[#KQ_(`4W!A:6X@*,[WL.#1P"D`P*R[^-/*O/X`S-C*XM?6M_O*Y,CK
M`%-R:2!,86YK82`HR[G`[\"\OZ@I`+'JU[P`QO3*O,3JM]T`RJ$`U[3,K`"Q
MH[3FN/'*O0"]UK7``,F^L_W/WP#7UK?[M*[!T`#0Q\;:S.P`UO?6O`#,X;V[
M`,_"L>H`L\FYI@#2T;/)N::XLKC'("5S`%-U9&%N("C+U;6D*0#5JM*J`,C5
ML_8`R-7"Y`#(U;/V`,C5L_8OR-7"Y`#(U;/V.B``R-7"Y`#(U<+D.B``R<^Q
MZ@#6I[/6`%-U<FEN86UE("C+U<#[Q,\I`+3"NL4`4W9A;&)A<F0@86YD($IA
M;B!-87EE;@!3=V%Z:6QA;F0@*,JWS=^\P\"\*0!3=V5D96X@*,CPM>0I`%-W
M:71Z97)L86YD("C(\,J_*0!3>7)I86X@07)A8B!297!U8FQI8R`HT/#`^]''
M*0!404(@M]:X]+CQRKW.Q+S^`,RHS>4`S*C-Y0!486II:VES=&%N("C+_KRJ
MR[G,N2D`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B`HS+G)T,3AT<<I
M`,2_L>HZ`+3]L.S*PL_N`+7GN["ZQ<+K`-?NO?S2N]"ARK&UQ,["ML@Z(`#.
MPK;(`,["ML@Z(`#$H[#FN=S`[0#$VLC=`+2_SL37U@#0Q\;:R\0`S*G.Q"`H
M5$E3+38R,"D`5&AA:6QA;F0@*,RIN?HI`-"[T+O$^LJYT\.QOL^US;,N`$94
M4"#1T\GL*&5X=&5N<VEO;BG.WM"G+@!-86EN=&5N86YC92#`X+'PLJ+.M+/)
MN:;4V,CK`-&AS^ZTL+_:TM2YV+'5+L#KOZK6T"X`T>G6I-/*O/['J</[T.C2
MJM/0TKNX]M+1O>*_JK7$(%!'4"#'^+_I+@#0Z-*JTKNX]KZMN?V\T\/<M<3-
M^,+GP:R]TRX`SL2\_B`E<R#3IKC#L/RZK-*[N/8@)7,@Q>36PRX`SL2\_B`E
M<R#3IKC#L/RZK-*[T*D@)7,@Q>36PRX`M,O.Q+S^UM##N]/0ROV^W2X`TM3/
MPLK'(')F8S@R,B#3RKS^M<2Q[<VW+@!';G501R"V_M2JSL2\_K7$PK>^MK'8
MT.NVJ-+EU-H@0W)Y<'1?<&=P.CH@P."Q\-;0+@!(;W)D95]#<GEP=%]S;6EM
M93HZ(,#@L?`LL=C0Z-*JT]`@;W!E;G-S;"#$H[_I+@"TR\:KNL,@(B5S(B#*
M_;[=TO+.JK.LN?W7[K3SO=/*W-:U+,OYTM3.WK>HL;NQH[3F`-/#TM2\[,K3
MM,O*_;[=P.#0S2`H)7,I(+7$L\S0\K*BLKNTYM3:T]K/M<VSR<\N`+3+M_[.
M\<;W("(E<R(@TM&QN\F^L_TN`+3+M_[.\<;W("(E<R(@TM&QN[&CM.8N`"5S
M(+7$UZ*RX=#HQ_/2T;&[R;ZS_2X`UKBVJ+7$O,?"O+*BLKNTYM3:+@"TT\G/
MTKNX]K*]UNC6KKKSR<^TJ[7$ROV^W=+%RJ<N`,G/M*O.Q+S^LJ+.M+&[L:.T
MYBX`=V5A=&AE<BYC;VT@Q_B_Z<[>MZC*N=/#+@#.WKB]O/Z_R=:QO=.T\K^J
M+@"TR]?6ML[6T+#\NJS,J[;@M<37ULK]+L3ZTM'*Y,CK("5S(+CVU];*_3O$
M^LKDR.NUQ-?6ROVQV-#KT*'3VB`E<RX`R<^TJ\[$O/[*L;>BR?K2N[CVSLK,
MXCH@)7,@SK2QN\G/M*LN`,G/M*O.Q+S^RK&WHLGZTKNX]L[*S.(Z("5S(+3S
MT*&SK+G]O=/*W-?NM//6M2`H)60@8GET97,I+@#)S[2KSL2\_LJQMZ+)^M*[
MN/;.RLSB.B"]]K*_M]:UQ"`E<R#.Q+S^L;O)S[2K+@"\[,K3T\J\_LJQMZ+)
M^M*[N/:T[<[S+@"[X\CKM,O-J-&VLK[*_;[=RK&WHLGZM.W.\RX`U-K%Y-;#
MM+#,Y=;0MZ+)^L'+TKNX]K3MSO,NT]"_R<3<Q/K2Q<*IP<NQV-#KS.[0M+7$
MU]:VSBX`M,L@24U!4""W_L[QQO>RHLZTUJ>SUL[$O/Z\T+?6S^VYIL3<+@#5
MXLO&NO6RN\K'U?W(M[7$(')A<B#1N<OUSL2\_BX`U>++QKKULKO*Q]7]R+>U
MQ"!Z:7`@T;G+]<[$O/XN`-7BR\:Z];*[RL?5_<BWM<30Q=/#OZBZQ<+K+@"T
MR]?6ML[*Q['8T.C2JK7$+@"TR]?6ML[$VLC=UKN]T\K<U?O*_<K]U]8N`+3+
MU]:VSL3:R-W6N[W3RMS*_=?6O+##L+K%+@"TR]?6ML[$VLC=UKN]T\K<L,N]
M^-;&ROW6M2X`M,O7UK;.Q-K(W;'8T.O.JK:ZNL6[\K_5L->WUKCTM<3*_=?6
M`+'8T.O*Q]*[N/;*_=?6+@"TR]?6ML[$VLC=L=C0Z[#\NJS2N]?IRJ[!^;WX
MUL:UQ"!21T(@T=7)J[3ZPNLLP/W(YR`G(S$R,S1A9B<N`-7BN/:TL,SETM&Q
MN[2FP.VY_2X`U>+*QR`E<RX`M,O*_=:UU^[)V;'8T.O*QR`Q+@"TR[?^SO'&
M]\[>MZBVU"!Z:7`@O+`@9WII<""X\<J]SL2\_KWXT-"]XM&YR_4`M,O/M<VS
MM;''L,K'S:/3P[7$U[3,K"X`L=C0Z\K'TKNX]LK]U]8N`+3+M+"_VK'8T.O2
MJM/)T:'/[K2PO]HH3W!T:6]N*<OYNO2]T`#*L;SD`,JQO.37M]?9`,JQO.2X
M\<J]`,JQQ_C1H=3Q`%1I;6]R+4QE<W1E`+'JS.(`RM6\_LC+`,CGN?O2JKBT
MT:$LQ^O4VK7CT:'*\['JM<3-K,JQL+0@0V]N=')O;+S\*+CVR,N\QLOCN_HI
M(+OR($-O;6UA;F2\_"C&N[G[O,;+X[OZ*2X`O?',[`!(5$U,(-2MRKS.Q+S^
M`+;@N.<`S="_R\#-R+JUN@##]\SL`,S`O-,`S-C!HL3AM.^ZS;;@L,VXYP#5
MYKORO-D`T,?&VK;^`,V[Q.'+N0#-P;;ZQN0`S<&V^L;DSL0@*$E33RTX.#4Y
M+3DI`,W!O^+"_,NYS+D`S-B_R\NYNLV_K;_&R[G(NK6Z`,V\S=_"K`#*Y,CK
MQ/JUQ-&AU/$Z(`#7S\WBS]_6N,K].B``S?C6MP#-^-:W.@#.VKC)M.\`SMJ_
MR\"\`,[>MZBTYLBA(%9&4R#$O\*\+@#7HK+ARK'.WK>HU/:\T[;NS>*UQ-/#
MNZ?0Q<^B+@#.WK>HN,2QY"!61E,@SL2\_B`B)7,B(+7$R*C/WBX`SMZWJ+'D
MN/P@5D93(,[$O/X@)7,O)7,@M<3(J,_>+@#.WK>HL>2X_,ZJ("5S+@#.WK>H
MP:R]T];!(%-13""W_L[QQO<N`,[>MZC*N=/#(%-33"#!K+W3+@#.WK>HN+36
MQB!61E,@SL2\_BX`SMZWJ+VHP:(@5D93(,2_PKP@(B5S(BX`SMZWJ+VHP:(@
M5D93(,2_PKPN`,[>MZB]J,&B(%9&4R#.Q+S^+@#.WK>HO:O*_;[=O>+1N<OU
M+@#.WK>HR;ZS_2`E<RRTR\2_PKRRHK?'O]6PUP#.WK>HM=VYZ<F^L_W$O\*\
M+@#.WK>HR;ZS_2!61E,@Q+_"O"X`SMZWJ,F^L_T@5D93(,2_PKPZ("5S+@#.
MWK>HR;ZS_2!61E,@SL2\_B`B)7,B+@#.WK>HR;ZS_2!61E,@SL2\_BX`SMZW
MJ+7=N>G)OK/](%9&4SH@)7,N`,[>MZC%T+;/M;''L+7$Q+_"O"X`SMZWJ+WB
MOZK&OM:DS[B]V@#.WK>HO-/4V"`E<R"UQ+:HTN7*_;[=+@#.WK>HTL:VKR!6
M1E,@SL2\_BX`SMZWJ+3ROZH@5D93(,[$O/X@(B5S(BX`SMZWJ-"TR.L@5D93
M(,[$O/XN`,[>MZBT\K^J(%9&4R#.Q+S^+@#.WK>HM/*_JM&YR_7.Q+S^+@#.
MWK>HML'(H2!V9G-R;V]T(,2_PKPN`,[>MZBQY+C\(%9&4R#$O\*\M<3#^[/&
M+@#.WK>HR;ZS_2!61E,@Q+_"O#H@)7,N`,[>MZBQY+C\(%9&4R#.Q+S^("(E
M<R(@M<3#^[/&+@#.WK>HL>2X_"!61E,@SL2\_B`E<R\E<R"UQ,/[L\8N`,[>
MMZBQY+C\(%9&4R#.Q+S^M<3#^[/&+@#.WK>HUZJ[NR!7;W)D(,[$O/X`SMZW
MJ-"TR.L@5D93("(E<R(@SL2\_BX`SMZWJ-"TR.L@5D93(,[$O/[*_;[=+@#/
MPKNNS]\`R*'/^[C\N,0`N+34K0"W_L[QQO?!K+W3RK&WHLGZSK34I,;:M<2[
MV-.F.B``MZ+)^LZTU*3&VK7$N]C3IBS3R;?^SO'&]SH@`,WRT\/"ZR`H551&
M+3@I`+"BP*VRKL&JNL_'];.DN?H`TZ*Y^@##P+GZ`%5N:71E9"!3=&%T97,@
M36EN;W(@3W5T;'EI;F<@27-L86YD<P"UI=2J`,ZTUJJUQ`#.M-:JM<33P[NG
MP_N[\L/<PNLN`,ZTUJ>SUK7$P*G5N</[`+'DN/P`N/S0PB`E<P"X_-#"T\.[
MIP"X_-#"L\S0\M+1R;ZS_2X`R<^TJP#2T<G/M*O+^=/0TZ;3P[/,T/*UQ,7D
MUL/.Q+S^M;VW_L[QQO<N`,[:P*VYYP#3P[NG("5S(,ZTS:BY_2`E<R"UQ,K:
MR*C1Z=:D+@#3P[NGN=S`[0#3P[NGT:'/[@#3P[NGUZ*RX0"TR]6^S*BUQ-/#
MNZ?7HK+AS[7-L]+1S:/3PRX`T\.[I\/[`-/#NZ?#^SH`T\.[ISH@`,^US;/6
MT+7$T\.[ISH`SMK7R+'PO\O+N<RY`%9&4R#$O\*\LJ*RN[3FU-HN`+S9QMH`
MTM'5TK6]T]#0I[7$M=BUXSH@`-/0T*?0U`#2U+?6UM/.JK6ESKLHM-//UM3:
MQO#+XRD`UK4`S=_"L["BS;P`L>2[KP#.K\3:R/#`K0#1Z=:DRJ>PW"`M(+3+
MT\J\_K_)Q-S2T=3BR,O)P]?4M-NXQ"X`L.:QO@"PYK&^O]C6Q@#4O<3/`-2]
MQ,_.Q"`H5DE30TE)*0"\[,K3("5S`-3:T,*TL+_:M/*_J@#2U"`E<R"RZ;^T
M`-.BRO3.K+;[OJG(NK6Z`,/`RO3.K+ZIR+JUN@#$W+S[ML@`Q-R\^[;(.B``
MTN*T\\#[M_RUPK?GM>?0Q;FKR[[-N+G](%--5%``OJ^XY@"^K[CF(2$A(+33
M("5S(,K6MJ_)OK/]L\S0\BX`S=_`^\NYNLVXN\V\R+JUN@"^K[CF`-#'QMK(
M_0#,[,;XU*2RX@#-^-6^`,WXU;X`P[_6W`"[MM.M`+NVTZVUO2`E<P"[MM.M
M+"`E<P#.]\6W("A)4T\M.#@U.2TQ*0#.]\6W("A)4T\M.#@U.2TQ-2D`SO?(
M]KG^P*T`M<?"O+KSTZ:XP\_(S]3*OB`E<R#$Q-*[N/;3IM/#L\S0\C\`U]:V
MSK7$M]:X]-?6M_L_`-+]RO:UQ,>PM;RW^S\`M^?+V2B]VBD`M^?+V3H`M^?+
MV3H@`+#LN:O*TK78UK<`L.RYJ\K2M>>[L`!8-3`Y=C,@P*G5N</[`,3J`,3J
M`%EA:&]O("$@M=C-O`##O\3J`-*RP\4`RL>UQ"S.TLVLTN(`Q/JUL<>PRKG3
MP[2_SL37UK'@T+3$H\J]+B#*N=/#(%L\/ET@L+3%I;_)Q]"[N\ZJS?C2L['@
MT+3$H\J]+@#$^K*BSK3*Y,CKTKNX]KK/MZBUQ+7GU]/3RKS^M=C6MRX`Q/JR
MHLZTT\FUO,CKM<3.Q+S^UM"VU-.SR,ZZSM?6MLZUO2`E<P#$^M+1OJW7HL_Z
M+@#$^K'8T.O*Y,CKTKNX]KK/MZBUQ-:U+@#$^K'8T.O/R+GFNZZZP\K]OMW*
M]RA$871A5')E92FW_L[QMLNRQ<3<O,S0^,JYT\/0PM/#NZ?7HK+AM_[.\2X`
MQ^O#Z,KVSLK,XJ.LU-K$^K2KR\W.RLSBL:BXYM:NQ[`N`,3ZL=C0Z\KDR.NT
MR\&LO=/+^=:XS_*UQ,WXUK<`Q^O6N+:HTJK)OK/]M<2W_L[QQO<N`,?KUKBV
MJ-*JR;ZS_;7$T\.[IRX`Q^O6N+:HTJK0PM3VM<33P[NG+@#'Z]:XMJC2JKC\
MT,*UQ-/#NZ<N`,?KUKBVJ-*JUK30T+7$U_?3PRX`Q/JUQ"`E<R"[X<;:TM&Y
M_<JQ+L?KUMC0PK7'PKPN`,3ZM<2UY]?3T\J\_K78UK<`Q/JUQ-#%SZ(`U]2T
MT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ-+RS-C-^+78UK?2T;'DN/PN(,ZJ
ML:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PK7'PKPN`,3ZM<30U</[`,3Z
MM<31Z=:DMLNRHLZTUJ>SUL'0L_;3P[NGN_*XP[FFQ-S2T;&[N=BQU2X`U]2T
MT\3ZM<0@)7,@N^'&VK^JRKS2U,"TQ/JUQ.2OP,#&]\O&NO72T;'DN/PN(,ZJ
ML:.[I,3ZM<2PLLBKQO"\^Z.LQ/JQV-#KUMC0PK7'PKPN`,3ZM<3DK\#`QO>R
MHLZTUJ>SUM7BN/:YIL3<+@#$^K6QQ[#+^<7DUL.UQ,JQQ_@Z`,3ZM<31H<_N
MTM&X_-#"+@#$^K7$U+:SS+?^SO'&]SH`Q,_+N<"MM_(`U/K2P;;[`-3>L<C1
MQP"]\K#-LKS.I`!;SLK,XK&HN.9=`%O.N]/:T-`@)7,@N;(@)7,@T-!=`,[$
MO/X`M-,@)7,@*"5S*2#3VB`E<R`E<P#*L3H`P:*\M`##^[/&`,G0SK3*M<_6
M+@#)T,ZTRK7/UBX`U-FTSLKDR.O$^K7$P]S"Z]+4R+?(S\[>SO,`SK3#_,/[
M`-/#NZ?1H=3Q`'9#87)D`-#'QMHZ`'=E871H97(N8V]M(,WXU;X`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O=6M?54$O3$-?34534T%'15,`````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-3`R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]U:U]502]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S,R,"`Q
M,#4Q-30S-#$T,2`P,C$T-#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!H;W)D92]L;V-A;&4O=6M?54$O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P
M-2\R-R`R,#HR,CHQ,B!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A
M9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E
M<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF
M;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY
M(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8
M+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@
M>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE
M=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM
M87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@
M9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S
M<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@
M971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@
M<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B
M=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET
M96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@
M87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET
M;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP
M87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@
M:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N
M('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@
M86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P
M;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@
M8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E
M(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I
M;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@
M=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O=6M?54$O3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$Q,3`@,3`U,34T
M,S0Q-#$@,#(S,C$Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````4````!P```"<`@``:P```!P%````````R`8`
M`"@```#)!@``"````/(&```/````^P8```@````+!P``"````!0'```9````
M'0<```<````W!P``#@```#\'```%````3@<``!$```!4!P``"````&8'```5
M````;P<```H```"%!P``#````)`'```'````G0<``!````"E!P```@```+8'
M```%````N0<``!````"_!P``!@```-`'```4````UP<```4```#L!P``#0``
M`/('```%``````@```L````&"```#P```!((```#````(@@```0````F"```
M#````"L(```*````.`@```4```!#"```$@```$D(```0````7`@``!````!M
M"```&@```'X(```&````F0@```<```"@"````@```*@(```$````JP@```\`
M``"P"```!P```,`(```'````R`@```0```#0"```!0```-4(```(````VP@`
M`!4```#D"```'@```/H(```%````&0D``"@````?"0``*0```$@)```3````
M<@D```L```"&"0``!0```)()```1````F`D```0```"J"0``#````*\)```:
M````O`D``!<```#7"0``%P```.\)```3````!PH``!`````;"@``%P```"P*
M```'````1`H```4```!,"@```P```%(*```,````5@H```@```!C"@``%```
M`&P*```'````@0H```8```")"@``"P```)`*```,````G`H```H```"I"@``
M`@```+0*```&````MPH``$4```"^"@``)@````0+```E````*PL``!````!1
M"P``9P$``&(+```Z````R@P```D````%#0``&@````\-```+````*@T``!(`
M```V#0``(@```$D-```&````;`T```\```!S#0``"0```(,-```.````C0T`
M``\```"<#0``'P```*P-```4````S`T```T```#A#0``"````.\-```4````
M^`T```(````-#@``!P```!`.```0````&`X```<````I#@``$````#$.```'
M````0@X``!,```!*#@``!P```%X.```-````9@X``!(```!T#@``!````(<.
M```(````C`X```X```"5#@``$````*0.```%````M0X``!0```"[#@``$0``
M`-`.```9````X@X``"D```#\#@``!@```"8/```%````+0\```(````S#P``
M"@```#8/```/````00\```0```!1#P``"````%8/```$````7P\```<```!D
M#P``!@```&P/```8````<P\``!\```",#P``!P```*P/```I````M`\``"X`
M``#>#P``#0````T0```,````&Q````@````H$```%````#$0```$````1A``
M``X```!+$```&0```%H0```5````=!```!4```"*$```(P```*`0```7````
MQ!```!D```#<$```!P```/80```%````_A````,````$$0``#P````@1```1
M````&!$``!8````J$0``!0```$$1```'````1Q$```T```!/$0``#0```%T1
M```/````:Q$```(```![$0``!P```'X1``!%````AA$``#$```#,$0``,0``
M`/X1```7````,!(```$`````````30```!T```!%````%0````@````B````
M.0``````````````'````$<`````````%````"X`````````.P```#8```!)
M````)@```#$````````````````````G````'@```"T````-`````````"D`
M`````````@````````!/````)0```$(```!,```````````````H````/@``
M`!@````?````%@```!L````C````"0```#`````U````!`````L````%````
M#`````\````O````0````!H```!&````2P```$X````R````0P```#T````&
M````*P``````````````/P```$@````X````"@```````````````````#P`
M````````#@`````````3````$0```"`````0````(0```$H``````````P``
M`%`````2````-``````````````````````````7````00```#,````9````
M*@`````````D``````````<````W````1````#H````L`````"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`061D
M(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&UI;FES=')A=&EO;@!!;&EA<P!!=F%I
M;&%B;&4@9FEE;&1S.@!":7)T:&1A>0!#86YC96P@4')O8FQE;2!297!O<G0`
M0V5L;"!0:&]N90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF:7)M(%!A<W-W
M;W)D`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E<V-R:6)E
M('1H92!0<F]B;&5M`$5M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@
M3&]G:6X`17AA;7!L92!V86QU97,Z`$9A>`!(96QP`$AO;64@061D<F5S<P!(
M;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$QI<W0@2&5L<"!4;W!I8W,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L9',`
M365S<V%G90!-;VYT:&QY`$YA;64`3F]T97,`4&%S<W=O<F0`4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0
M:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN
M`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5S970`4F5T=7)N('1O
M($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T
M:6UE(&9O<FUA=#H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA
M;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&ET;&4`55),
M`%5N9&\@0VAA;F=E<P!5<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!7
M87)N:6YG`%=E96ML>0!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0
M:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@
M8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M
M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P
M96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`6U!R;V)L96T@4F5P;W)T70!0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E('8R+C$*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R
M+3`Q+3`U(#$V.C$U*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!;F1R:7D@2V]P
M>7-T>6%N<VMY(#QA;G)I0'!O;'EN970N;'9I=BYU83X*3&%N9W5A9V4M5&5A
M;3H@56MR86EN:6%N(#QW96)M87-T97)`<&]L>6YE="YL=FEV+G5A/@I-24U%
M+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S
M970]2T])."U5"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@#O
MT,72P<.FT2#0TL_&ILS!R]3)WL[/Q\\@S\+3S-7'S]?5U\'.SM$@)7,@+2#P
MIL34U\72Q-;%SL[1`#(T(,?/Q,G.R0#DS\3!U,D@SL_7S\?/(,O/TLG3U-77
MP=[!.@#DS\3!U,D@T,'2U0#DS\3!U,D@R\_2R=/4U=?!WL$`Y,_$P=?!SL[1
M(,O/TLG3U-77P=ZFUR#:P<+/TL_.Q<[%+@#AQ-+%T\$`X<3-ILZFT]32U=?!
MSL[1`/#3Q=?$S\ZFS0#DS]/4U=#.IB#0S\S1.@#DQ<[8(,[!TL_$UL7.SM$`
M]Z;$S:;.R=3)(-#/UZ;$S\W,Q<[.T2#0TL_"S,7-R0#SU*;,V,[)R\_7R<H@
MU,7,Q<;/S@#ZP<O2R=3)(->FR\[/`.O/S=#!SJ;1`/"FQ-37Q=+$UL7.SM$@
MT,'2S\S``.3D`/W/Q,7.SL\`[]/.S]?.P2"FT,_3U,'3V`#WR=3%TM3)`._0
MR=NFU-@@T-+/PLS%S=4`Y2W0S]O4P0#PS]+/ULZFRB#2Q=K5S-C4P=0N`/#/
MS<G,R\$`Z\_6SL_'SR#7R,_$U0#DP<ZF(,3,T2#0TLG+S,'$U3H`YL'+TP#D
MS]#/S<_'P0#DS\W!V\[1(,'$TL73P0#DS\W!V\ZFRB#4Q<S%QL_.`$AO<F1E
M`+;-T,_2U,_7P<[%(-#/S,4Z("5S`+;-T,_2U,_7P<ZF(-#/S-$Z`/#%TL7,
MILL@TL_:Q*;,IM<@Y,_0S\W/Q\D`\,72Q<?,T<0@T]#)T\O5(,O/TLG3U-77
MP=ZFUR#:P<+/TL_.Q<[)RBX`]]>FRM3)`/?)RM3)`.WM`$E-4"W0S]+4P<P`
M]Z;$T,_7IL3.IB#0S\S1`.S)T]0`_<_-IM/1P]$`MLU@T0#NS]3!U,O)`/#!
MTL_,V`#PP=+/S-@@S=73R=38(-/0IM?0P=/4R2X`]\G+S\[!U,D@T-+/QJ;,
MP<O4R=[.IB#/T,72P<.FIP#TQ<S%QL_.`.+5Q-@MS,'3R\$L(,3!RM3%(,O/
MTL_4R\G*(,_0R=,@T-+/PLS%S<DN`.+5Q-@MS,'3R\$L(-?+P=:FU-@@SL':
MU]4@R\_2R=/4U=?!WL$@IB#0P=+/S-@`[]#)TR#0TL_"S,7-R0#WR=3%TM3)
M(-#!TM4`[][)T]3)U,D`\,_7Q=+.U=3)T]$@Q,\@[]##ILH`\L_,V`#ZPL72
MQ<?4R2#/T,.FIP#WR<+%TJ;4V"#2S]K$ILS`U\'>(,3!U,DZ`/?)PL72IM38
M(,;/TLW!U"#$P=3).@#WR<+%TJ;4V"#&S]+-P=0@WL'3U3H`]Z;$IM/,P=3)
M(-#/UZ;$S\W,Q<[.T2#0TL\@T-+/PLS%S=4`\-+/T-73U,G4R2#0TL_&ILS!
MR]3)R]4`]]>FQ"#ST,7#IL',V,[)R"#3R<W7S\RFUP#UT]"FV\[/`/3)U-7,
M`%523`#SR\'3U=?!U,D@VLVFSLD`[L':U\$@R\_2R=/4U=?!WL$`Z\_2R=/4
MU=?!WJ8@UR#3R=/4Q<VF.@#UU\''P0#]S]3)UL[1`/>FU,'`(/?!TRP@)7,`
M\L_"S][!(,'$TL73P0#RS\+/WLG*(-3%S,7&S\X`\O(`_<_2IM[.SP#WR2#0
MS]?)SLZF(,_0R=/!U,D@T-+/PLS%S=4L(-#%TML@SJ;6(->FQ-/)S,'4R2#0
MS]>FQ,_-S,7.SM$@T-+/(,[%IRX`]\'-(-/,IL0@U\O!VL'4R2#.P=K7U2#+
MS]+)T]35U\'>P2#$S-$@U\G$P<S%SL[1+@#WP<T@T\RFQ"#7R\':P=3)(,[!
MVM?5(,O/TLG3U-77P=[!(,3,T2#$S\3!U\'.SM$N`%OPS]>FQ,_-S,7.SM$@
M\-+/PLS%S<E=````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W1R7U12+TQ#7TU%4U-!
M1T53````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,30Q(#`R,34S,``@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O=')?5%(O:&5L<"YX;6P`````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#8V,C`@,3`U,34T,S0Q-#$@,#(Q-3`P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_>&UL('9E<G-I
M;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3DB/SX*/"$M+2`D2&]R9&4Z
M(&AO<F1E+VQO8V%L92]T<E]44B]H96QP+GAM;"QV(#$N,2XR+C$@,C`P-2\Q
M,"\Q."`Q,3HS,SHT-B!J86X@17AP("0@+2T^"CQH96QP/@H*/"$M+2!%;F=L
M:7-H(&5N=')Y.@H\96YT<GD@:60](G-U;6UA<GDB/@H\=&ET;&4^5&AE(%!O
M<G1A;"!086=E/"]T:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@
M<')O=FED97,@82!Q=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N
M=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H
M;W<@;6%N>2!N97<@92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U
M<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A
M<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE
M8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E
M"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@
M8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M
M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R
M('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O
M9B!T:&ES('!O<G1A;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,
M87EO=70@8G5T=&]N+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W
M:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*
M("!W96QL(&%S(&EN('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P
M87)A/@H\+V5N=')Y/@HM+3X*/&5N=')Y(&ED/2)S=6UM87)Y(B!M9#4](C8X
M8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U(B!S=&%T93TB=7!T;V1A
M=&4B/@H\=&ET;&4^1VER:?X@4V%Y9F%S_3PO=&ET;&4^"CQP87)A/@I':7)I
M_B!S87EF87/]('-I>F4@]FYE;6QI(&)I;&=I;&5R:6YI>FEN(&O]<V$@]GIE
M=&EN:2!V97)I<BX@UG)N9?!I;BP@9V5L96X@:W5T=6YU>F1A(&MAYR!T86YE
M('EE;FD@96QE:W1R;VYI:R!P;W-T82!O;&1U\'5N=2P@=&%K=FEM:6YI>F1E
M:VD@>6%K;&'^86X@;VQA>6QA<OTL('EA</UL86-A:VQA<B!L:7-T97-I;F1E
M:VD@:?YL97)I;FEZ:2P@<V7G:6QI(&AA8F5R('-E<G9I<VEN9&5K:2!B8?YL
M_6ML87+]('9S+B!G]G-T97)I<BX@0G4@]GIE=&QE<FEN(.=O\'4@9V5N96P@
M9F]N:W-I>6]N;&%R(&GG:6X@:_US87EO;&QA<B!IYV5R96-E:W1I<BP@('EE
M;FD@<&]S=&$@;VQU_G1U<FUA:RP@>65N:2!T86MV:6T@;VQA>?T@>6$@9&$@
M:?YI(&]L=?YT=7)M86L@9VEB:2X*/"]P87)A/@H\<&%R83X*1VER:?X@<V%Y
M9F%S_6[];B!IYV5R:?!I(&3\>F5N;&5M92!T=?YU(&EL92!I<W1E\&4@=7EA
M<FQA;F%B:6QI<BX@(M9R;F7P:6XL(&=I<FG^('-A>69A<_UN_6X@:&%N9VD@
M]O!E;&5R:2!IYV5R96-E\&EN:6X@>6%N_6YD82!B=2#V\&5L97)I;B!G]G-T
M97)I;&UE('/]<F%L87+](&1A('-EYVEL96)I;&ER+@H\+W!A<F$^"CPO96YT
M<GD^"@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\96YT<GD@:60](FYA=F)A<B(^
M"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE
M/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@
M<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI
M8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I
M8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L
M92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y
M(&ED/2)N879B87(B(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W
M.#)F-#<B('-T871E/2)U<'1O9&%T92(^"CQT:71L93Y5>6=U;&%M82!$;VQA
M_OUM(,=U8G7P=3PO=&ET;&4^"CQP87)A/@I5>6=U;&%M82!D;VQA_OUM(.=U
M8G7P=2!W96(@<V%Y9F%S_6[];B!S;VP@:V5N87+]9/UR+B!-979C=70@=7EG
M=6QA;6%L87(@87)A<_UN9&$@(&C]>FS]('9E(&MO;&%Y8V$@9V5Z:6YE8FEL
M;65K(&GG:6X@=6QA_OUM(.=U8G7P=6YD86MI('-I;6=E;&5R:2!T_6ML87G]
M;OUZ+@H\+W!A<F$^"CPO96YT<GD^"@H*/"$M+2!%;F=L:7-H(&5N=')Y.@H\
M96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L
M93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R
M;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES
M(&)O>"X*("`@(#PO<&%R83X*/"]E;G1R>3X*+2T^"@H\96YT<GD@:60](G!R
M969S+61O7VUA:6YT96YA;F-E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E
M83DQ.3(X.&(R9#`P(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^5&5R8VEH
M;&5R.B!"86O];3H@0F%K_6T@66%P;6$\+W1I=&QE/@H\<&%R83X*4VES=&5M
M92!G:7)E<FME;B!B86O];2!I_FQE;6QE<FD@>6%P;6%K(&ES=&5R<V5N:7H@
M8G4@:W5T=7EU(&G^87)E=&QE>6EN:7HN"CPO<&%R83X*/"]E;G1R>3X*"CPA
M+2T@16YG;&ES:"!E;G1R>3H*/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA
M:6YT96YA;F-E(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N
M8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@
M("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC
M92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@
M268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS
M('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA
M=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@
M("`\+W!A<F$^"CPO96YT<GD^"BTM/@H*/&5N=')Y(&ED/2)P<F5F<RUC;VYF
M:7)M7VUA:6YT96YA;F-E(B!M9#4](F$R,3$V,F-D9F8S8C%D.&9A96%D8C<R
M.38R-#`P,S9E(B!S=&%T93TB=7!T;V1A=&4B/@H\=&ET;&4^5&5R8VEH;&5R
M.B!"86O];3H@0F%K_6T@1&_P<G5L86UA/"]T:71L93X*/'!A<F$^"D)A:_UM
M(&?V<F5V;&5R:6YI(.=A;/W^;6%Y82!B8?YL86UA9&%N(/9N8V4@9&_P<G5L
M86UA:R!I<W1I>6]R<V%N_7H@8G4@:W5T=7EU(&G^87)E=&QE>6EN:7HN($7P
M97(@:W5T=2!I_F%R971L96YM96UI_B!I<V4@YV%L_?YM87/](&=E<F5K96X@
M8OQT_&X@8F%K_6T@:?YL96UL97)I;FEZ('-I<W1E;64@9VER97)K96X@+&EP
M=&%L(&5T;64@_F%N<_UN_7H@;VQM861A;B!O=&]M871I:R!O;&%R86L@9V5R
MYV5K;&7^96-E:W1I<BX*/"]P87)A/@H\+V5N=')Y/@H*/"]H96QP/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W1R7U12+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,S,V,3`P(#$P-3$U-#,T,30Q(#`R,S(U,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````#>$@25`````)H&
M```<````[#0``-L(``"\:0```````"B-```.````*8T```\````XC0``#0``
M`$B-```(````5HT```L```!?C0``#````&N-```$````>(T```P```!]C0``
M#P```(J-```+````FHT```X```"FC0``!0```+6-```H````NXT```@```#D
MC0``"@```.V-```5````^(T``!(````.C@``"P```"&.```.````+8X```H`
M```\C@``#0```$>.```.````58X``!$```!DC@``#0```':.```,````A(X`
M``T```"1C@``!@```)^.```/````IHX``!@```"VC@``#````,^.```.````
MW(X```X```#KC@``"````/J.```N`````X\``!H````RCP``,@```$V/```X
M````@(\``%0```"YCP``40````Z0``!:````8)```%<```"[D```-````!.1
M```'````2)$```H```!0D0``#P```%N1```%````:Y$```8```!QD0``$0``
M`'B1```(````BI$```D```"3D0``"0```)V1```E````IY$``"````#-D0``
M$````.Z1```/````_Y$```H````/D@```P```!J2```/````'I(``!0````N
MD@``"0```$.2```-````39(``!(```!;D@``#P```&Z2```*````?I(```\`
M``")D@``"````)F2```D````HI(``!0```#'D@``%@```-R2```(````\Y(`
M`!D```#\D@``!P```!:3```,````'I,``"P````KDP``#@```%B3```#````
M9Y,```L```!KDP``!P```'>3```'````?Y,```4```"'DP``!0```(V3```*
M````DY,```,```">DP``%P```**3```*````NI,```\```#%DP``#@```-63
M```8````Y),``",```#]DP``#@```"&4```4````,)0``!<```!%E```%P``
M`%V4```7````=90``!,```"-E```#P```*&4```.````L90``!\```#`E```
M!P```."4```&````Z)0```@```#OE```#P```/B4```&````")4```H````/
ME0``$P```!J5```+````+I4``!`````ZE0``%0```$N5```5````894```<`
M``!WE0``$````'^5```%````D)4``!4```"6E0``$0```*R5```,````OI4`
M`#L```#+E0``"0````>6```'````$98``!0````9E@```P```"Z6```%````
M,I8``!`````XE@``"0```$F6```3````4Y8``#D```!GE@``$@```*&6```G
M````M)8``"P```#<E@``*@````F7```E````-)<```H```!:EP``!@```&67
M```)````;)<```<```!VEP``+P```'Z7```W````KI<``"X```#FEP``50``
M`!68```M````:Y@``"T```"9F```+0```,>8``!`````]9@``",````VF0``
M(P```%J9```M````?ID``#,```"LF0``%0```."9```9````]ID``"D````0
MF@``)````#J:```1````7YH```H```!QF@``#````'R:```*````B9H``!``
M``"4F@``%@```*6:```6````O)H```<```#3F@``!P```-N:```4````XYH`
M``H```#XF@``"`````.;```(````#)L```<````5FP``!P```!V;```&````
M)9L```4````LFP``!P```#*;```&````.IL```@```!!FP``*0```$J;```.
M````=)L```H```"#FP``!````(Z;```'````DYL```D```";FP``!@```*6;
M```1````K)L```<```"^FP``%@```,:;```$````W9L```@```#BFP``!@``
M`.N;```-````\IL```8`````G```'@````><```1````)IP```@````XG```
M#0```$&<```,````3YP```<```!<G````P```&2<```#````:)P``!<```!L
MG```$P```(2<```(````F)P```0```"AG```"````*:<```(````KYP``$$`
M``"XG```(````/J<```&````&YT```8````BG0``%0```"F=```8````/YT`
M`"(```!8G0``+@```'N=```=````JIT``"$```#(G0``5````.J=```I````
M/YX```H```!IG@``!P```'2>```5````?)X```X```"2G@``"@```*&>```/
M````K)X```T```"\G@``#P```,J>```-````VIX```D```#HG@``%````/*>
M```&````!Y\``!@````.GP``'0```">?```3````19\``!0```!9GP``!```
M`&Z?```&````<Y\``%0```!ZGP``!````,^?```.````U)\```4```#CGP``
M!0```.F?```;````[Y\``!H````+H```$0```":@```1````.*```!P```!*
MH```*@```&>@```0````DJ```"$```"CH```!0```,6@```3````RZ```!(`
M``#?H```"@```/*@```/````_:```!$````-H0``$P```!^A```,````,Z$`
M``8```!`H0``!@```$>A```7````3J$``!````!FH0``$0```'>A```(````
MB:$```4```"2H0``#````)BA```0````I:$```4```"VH0``#0```+RA```&
M````RJ$```<```#1H0``#0```-FA```'````YZ$```L```#OH0``!P```/NA
M```'`````Z(```D````+H@``"@```!6B```9````(*(```P````ZH@``$```
M`$>B```%````6*(``"4```!>H@``$@```(2B```3````EZ(``"L```"KH@``
M.P```->B```@````$Z,``#8````THP``"````&NC```,````=*,```8```"!
MHP``!````(BC```.````C:,```H```"<HP``#0```*>C```>````M:,``!L`
M``#4HP``(0```/"C```>````$J0``!D````QI```'@```$ND```;````:J0`
M`"8```"&I```&P```*VD```>````R:0``!P```#HI```)@````6E```S````
M+*4``"8```!@I0``*P```(>E```X````LZ4``"\```#LI0``$@```!RF```I
M````+Z8``!(```!9I@``H@```&RF```6````#Z<``",````FIP``*````$JG
M```I````<Z<``"@```"=IP``'P```,:G```@````YJ<``"4````'J```*```
M`"VH```P````5J@``)(```"'J```(0```!JI```<````/*D``"8```!9J0``
M00```("I```,````PJD```<```#/J0``!P```->I```&````WZD```T```#F
MJ0``$````/2I```2````!:H``!,````8J@``$@```"RJ```'````/ZH```0`
M``!'J@``#````$RJ```.````6:H```\```!HJ@``$P```'BJ```-````C*H`
M`"@```":J@```P```,.J```-````QZH```8```#5J@``$0```-RJ```7````
M[JH``!L````&JP``#@```"*K```"````,:L```4````TJP``$````#JK```$
M````2ZL```T```!0JP``#@```%ZK```#````;:L```X```!QJP``"````("K
M```/````B:L```\```"9JP``!P```*FK```-````L:L``!````"_JP``"P``
M`-"K```&````W*L```P```#CJP``$0```/"K```9`````JP```L````<K```
M#0```"BL```B````-JP```H```!9K```&````&2L```9````?:P``!8```"7
MK```#0```*ZL```'````O*P``!0```#$K```"P```-FL```B````Y:P``"\`
M```(K0``"P```#BM```)````1*T``!D```!.K0``"P```&BM```7````=*T`
M`!<```",K0``"0```*2M```6````KJT```\```#%K0``%@```-6M```.````
M[*T``!@```#[K0``"````!2N```-````':X``"8````KK@``0P```%*N```(
M````EJX``!(```"?K@``"````+*N```+````NZX``"\```#'K@``#@```/>N
M```%````!J\```8````,KP```P```!.O```'````%Z\```0````?KP``"@``
M`"2O```*````+Z\```\````ZKP``$````$JO```7````6Z\``!$```!SKP``
M%P```(6O```)````G:\```4```"GKP``"P```*VO```*````N:\```(```#$
MKP``!0```,>O```-````S:\``!L```#;KP``%P```/>O```)````#[````X`
M```9L```#0```"BP```2````-K```#@```!)L```(````(*P```(````H[``
M``X```"LL```>P```+NP```8````-[$``!$```!0L0``!P```&*Q```%````
M:K$``!D```!PL0``!P```(JQ```(````DK$```8```";L0``!@```**Q```0
M````J;$```\```"ZL0``$````,JQ```/````V[$```L```#KL0``#P```/>Q
M```,````![(```\````4L@``!P```"2R```&````++(```X````SL@``#```
M`$*R```H````3[(```\```!XL@``"````(BR```(````D;(``!,```":L@``
M'@```*ZR```A````S;(``"````#OL@``&0```!"S```7````*K,``"4```!"
MLP``%P```&BS```$````@+,``!L```"%LP``#0```*&S```,````K[,```,`
M``"\LP``"````,"S```*````R;,```P```#4LP``"P```.&S```0````[;,`
M``P```#^LP``!`````NT```3````$+0``!0````DM```#````#FT```)````
M1K0```X```!0M```"P```%^T```;````:[0```<```"'M```!P```(^T```*
M````E[0```T```"BM```"0```+"T```$````NK0```4```"_M````P```,6T
M```8````R;0```H```#BM```!````.VT```F````\K0```X````9M0``?```
M`"BU```5````I;4```4```"[M0``!P```,&U```,````R;4```@```#6M0``
M"@```-^U```&````ZK4```@```#QM0```@```/JU```&````_;4```8````$
MM@``%`````NV```-````(+8``!`````NM@``&P```#^V```$````6[8```D`
M``!@M@``$````&JV```)````>[8```D```"%M@``!0```(^V```:````E;8`
M``@```"PM@``!@```+FV```9````P+8```X```#:M@``!P```.FV```'````
M\;8```4```#YM@``"0```/^V```*````";<```(````4MP``!@```!>W```-
M````'K<```D````LMP``!@```#:W```2````/;<```D```!0MP``!P```%JW
M```4````8K<``!T```!WMP``!@```)6W```*````G+<```0```"GMP``"0``
M`*RW```(````MK<``!$```"_MP``"0```-&W```&````V[<```T```#BMP``
M!@```/"W```$````][<``#D```#\MP``/0```#:X```Z````=+@``!X```"O
MN```!0```,ZX```.````U+@```0```#CN```!@```.BX```A````[[@``!4`
M```1N0``!@```">Y```$````+KD``!$````SN0``!@```$6Y```*````3+D`
M`"(```!7N0``!````'JY```%````?[D``!T```"%N0``!````*.Y```,````
MJ+D```H```"UN0``"````,"Y```)````R;D```4```#3N0``.@```-FY```P
M````%+H``#4```!%N@``*0```'NZ``!'````I;H``#@```#MN@``*0```":[
M```_````4+L``"X```"0NP``+0```+^[```?````[;L```\````-O```$@``
M`!V\```+````,+P``"8````\O```*0```&.\```D````C;P``"8```"RO```
M"````-F\```*````XKP```D```#MO```!P```/>\```@````_[P``"`````@
MO0``)@```$&]```*````:+T``!D```!SO0``*0```(V]```6````M[T``!(`
M``#.O0``!P```.&]```*````Z;T```P```#TO0``#P````&^```0````$;X`
M`$`````BO@``<````&.^``!F````U+X```X````[OP``"0```$J_```*````
M5+\``!(```!?OP``$P```'*_```,````AK\```8```"3OP``#P```)J_```2
M````JK\``!````"]OP``$0```,Z_```<````X+\``",```#]OP``:@```"'`
M```/````C,````4```"<P```$````*+````)````L\````0```"]P```"P``
M`,+````4````SL````P```#CP```#````/#````/````_<```!4````-P0``
M*0```"/!```J````3<$``"8```!XP0``)P```)_!```I````Q\$``"H```#Q
MP0``&0```!S"``!"````-L(``!$```!YP@``$@```(O"```3````GL(``!0`
M``"RP@``#P```,?"```6````U\(``!<```#NP@``$`````;#```1````%\,`
M`#0````IPP``$P```%[#```2````<L,``#4```"%PP``%````+O#```'````
MT,,```P```#8PP``(````.7#```4````!L0``!$````;Q```%P```"W$```<
M````1<0``!,```!BQ```$0```';$```:````B,0``!X```"CQ```&@```,+$
M```1````W<0``!0```#OQ```%P````3%```5````',4```D````RQ0``&0``
M`#S%```$````5L4```<```!;Q0``"P```&/%```1````;\4```8```"!Q0``
M!@```(C%```&````C\4```4```"6Q0``!P```)S%```'````I,4```4```"L
MQ0``%@```++%```&````R<4```8```#0Q0``!````-?%```$````W,4```<`
M``#AQ0``#@```.G%```,````^,4```P````%Q@``#0```!+&```*````(,8`
M``X````KQ@``!0```#K&```H````0,8```X```!IQ@``#````'C&```/````
MA<8```H```"5Q@``"````*#&```)````J<8``"L```"SQ@``!````-_&```(
M````Y,8``"8```#MQ@``$@```!3'```/````)\<```8````WQP``"@```#['
M```'````2<<```@```!1QP``(````%K'```)````>\<```P```"%QP``#0``
M`)+'```.````H,<``!8```"OQP``$0```,;'```&````V,<```,```#?QP``
M!@```./'```9````ZL<```<````$R```!`````S(```+````$<@```L````=
MR```!P```"G(```'````,<@``!8````YR```#0```%#(```-````7L@```H`
M``!LR```$````'?(```/````B,@``!$```"8R```%P```*K(```*````PL@`
M`!$```#-R```"````-_(```$````Z,@```\```#MR```.@```/W(```%````
M.,D```P````^R0``'@```$O)```.````:LD``!````!YR0``"P```(K)```,
M````ELD```D```"CR0``!P```*W)```*````M<D```D```#`R0``#@```,K)
M```0````V<D``!H```#JR0``"@````7*```)````$,H```H````:R@``#```
M`"7*```/````,LH```@```!"R@``!@```$O*```'````4LH```L```!:R@``
M1P```&;*```-````KLH```D```"\R@``!````,;*```#````R\H``!,```#/
MR@``$P```./*```3````]\H```H````+RP```@```!;+```$````&<L``"4`
M```>RP```P```$3+```%````2,L``"H```!.RP``"@```'G+```%````A,L`
M``0```"*RP``"@```(_+```-````FLL```8```"HRP``"````*_+```(````
MN,L```0```#!RP``!0```,;+``!H````S,L```D````US```#````#_,```%
M````3,P```8```!2S```&P```%G,```O````=<P``!````"ES```"@```+;,
M```/````P<P```H```#1S```"0```-S,```3````YLP``!L```#ZS```&```
M`!;-```7````+\T```X```!'S0```P```%;-```'````6LT```@```!BS0``
M!P```&O-```*````<\T```L```!^S0``!P```(K-``!1````DLT``!````#D
MS0``#````/7-```-`````LX``!H````0S@``2@```"O.```&````=LX```8`
M``!]S@``!@```(3.```?````B\X```8```"KS@``"0```++.```8````O,X`
M`!<```#5S@``!@```.W.```-````],X``"(````"SP``5P```"7/```3````
M?<\``",```"1SP``$P```+7/```"````R<\```L```#,SP``"````-C/```-
M````X<\```H```#OSP``!P```/K/```4`````M````8````7T```"````![0
M```.````)]````<````VT```"@```#[0```+````2=````<```!5T```#```
M`%W0```-````:M````P```!XT```"0```(70```)````C]````H```"9T```
M!P```*30```)````K-````<```"VT```"@```+[0```;````R=```!(```#E
MT```"@```/C0```)`````]$``!`````-T0``!P```![1```2````)M$```0`
M```YT0``!P```#[1```%````1M$```4```!,T0``"P```%+1```4````7M$`
M`!$```!ST0``&@```(71```6````H-$``!0```"WT0``%P```,S1```8````
MY-$``!P```#]T0``&0```!K2```'````--(```4````\T@``#0```$+2```,
M````4-(```@```!=T@``%P```&;2```+````?M(``!,```"*T@``!````)[2
M```*````H](```0```"NT@``#````+/2```)````P-(```4```#*T@``!P``
M`-#2```%````V-(```0```#>T@```@```./2```X````YM(``"P````?TP``
M$@```$S3```I````7],``#(```")TP``"@```+S3```L````Q],``"X```#T
MTP``,P```"/4```S````5]0``#@```"+U```#P```,34```8````U-0``!``
M``#MU```#P```/[4```3````#M4``!0````BU0``$@```#?5```4````2M4`
M`!4```!?U0``+0```'75```M````H]4``#$```#1U0``+@````/6```O````
M,M8``"P```!BU@``8@```(_6```3````\M8```@````&UP``"`````_7```K
M````&-<``"$```!$UP``&@```&;7```)````@=<``$4```"+UP``00```-'7
M```$````$]@``!,````8V```%````"S8```.````0=@``!,```!0V```&```
M`&38```&````?=@```D```"$V```"@```([8```/````F=@``!````"IV```
M!P```+K8```.````PM@```4```#1V```&P```-?8```(````\]@```8```#\
MV```%`````/9```1````&-D```X````JV0``.````#G9```"````<MD```8`
M``!UV0``#@```'S9```%````B]D```<```"1V0``#@```)G9```&````J-D`
M``0```"OV0``*0```+39```7````WMD``!\```#VV0``7````!;:```4````
M<]H``#X```"(V@``'P```,?:```0````Y]H```<```#XV@``#@````#;```,
M````#]L```P````<VP``$P```"G;```*````/=L``!T```!(VP``&0```&;;
M```%````@-L``!$```"&VP``$0```)C;```D````JML``!4```#/VP``$@``
M`.7;```.````^-L``!D````'W```"````"'<```)````*MP```T````TW```
M"@```$+<```'````3=P```\```!5W```"P```&7<```*````<=P```<```!\
MW```"````(3<```%````C=P``!\```"3W```!@```+/<```0````NMP```@`
M``#+W```#0```-3<```(````XMP``!(```#KW```+````/[<```:````*]T`
M``D```!&W0``"@```%#=```5````6]T```4```!QW0``%````'?=```$````
MC-T``!````"1W0``!@```*+=```'````J=T``!X```"QW0``*````-#=```*
M````^=T``!H````$W@``%````!_>```$````--X```0````YW@``"P```#[>
M```%````2MX```8```!0W@``"````%?>```&````8-X```H```!GW@``&P``
M`'+>```T````CMX``#0```##W@``(````/C>```I````&=\``"````!#WP``
M00```&3?```:````IM\``"@```#!WP``*0```.K?```B````%.````8````W
MX```"````#[@```%````1^````@```!-X```&0```%;@```9````<.```"H`
M``"*X```(P```+7@```N````V>```#0````(X0``"````#WA```7````1N$`
M``H```!>X0``!P```&GA```A````<>$``!````"3X0``#@```*3A```+````
ML^$```<```"_X0``$P```,?A```(````V^$```L```#DX0``"@```/#A```4
M````^^$``#(````0X@``"P```$/B```%````3^(```4```!5X@``%P```%OB
M```/````<^(```0```"#X@``"@```(CB```)````D^(```L```"=X@``#0``
M`*GB```,````M^(```X```#$X@``!0```-/B```$````V>(```T```#>X@``
M,@```.SB``!%````'^,``!<```!EXP``'@```'WC```4````G.,```4```"Q
MXP``%````+?C```'````S.,```X```#4XP``*@```./C```&````#N0```P`
M```5Y```#0```"+D```1````,.0```L```!"Y```-@```$[D```*````A>0`
M`"(```"0Y```"P```+/D```/````O^0``#(```#/Y```#@````+E```%````
M$>4```X````7Y0``$P```";E```'````.N4``!$```!"Y0``!P```%3E```4
M````7.4``!@```!QY0``!P```(KE```%````DN4```P```"8Y0``#````*7E
M```2````LN4```0```#%Y0``!P```,KE```*````TN4```L```#=Y0``#```
M`.GE```.````]N4```X````%Y@``!0```!3F```%````&N8``"X````@Y@``
M)@```$_F```C````=N8```,```":Y@``$@```)[F```&````L>8``!X```"X
MY@``&````-?F```E````\.8```T````6YP``"0```"3G```#````+N<```<`
M```RYP``"@```#KG```"````1><```P```!(YP``%0```%7G```+````:^<`
M`!D```!WYP``(````)'G```2````LN<```4```#%YP``"@```,OG```5````
MUN<``!(```#LYP``#````/_G```$````#.@```<````1Z```#````!GH``!2
M````)N@``!<```!YZ```!P```)'H```&````F>@```X```"@Z```#````*_H
M```-````O.@``!4```#*Z```$@```.#H```/````\^@``!0````#Z0``&P``
M`!CI```0````-.D``&D```!%Z0``&@```*_I```7````RND``"<```#BZ0``
M&@````KJ```7````)>H``!L````]Z@``&0```%GJ```?````<^H``!,```"3
MZ@``"````*?J```'````L.H```@```"XZ@``"0```,'J```5````R^H```T`
M``#AZ@``$P```._J```#`````^L``$8````'ZP``/P```$[K```W````CNL`
M`%<```#&ZP``!0```![L```?````).P``"\```!$[```"@```'3L```(````
M?^P```T```"([```+0```);L```$````Q.P``$\```#)[```)0```!GM```<
M````/^T```L```!<[0``'P```&CM```=````B.T``"4```"F[0``(````,SM
M```D````[>T``"`````2[@``"P```#/N```'````/^X```T```!'[@``#```
M`%7N```7````8NX```8```!Z[@``.0```('N```,````N^X```<```#([@``
M"0```-#N```3````VNX```D```#N[@``!````/CN```0````_>X```@````.
M[P``"````!?O```$````(.\```L````E[P``#````#'O```2````/N\``!$`
M``!1[P``#````&/O```:````<.\```\```"+[P``!P```)OO```-````H^\`
M`!0```"Q[P``#@```,;O```,````U>\``!L```#B[P``+````/[O```3````
M*_```!P````_\```*````%SP```&````A?````<```",\```$P```)3P```%
M````J/````0```"N\```%P```+/P```*````R_````P```#6\```"0```./P
M```&````[?````D```#T\```"````/[P```)````!_$```H````1\0``$0``
M`!SQ```&````+O$```X````U\0``#@```$3Q```-````4_$```L```!A\0``
M'0```&WQ```+````B_$```(```"7\0``!P```)KQ```&````HO$```D```"I
M\0``!P```+/Q```[````N_$``"@```#W\0``-````"#R```5````5?(```4`
M``!K\@``!P```''R```(````>?(```<```""\@``!0```(KR```'````D/(`
M``X```"8\@``"0```*?R```&````L?(```@```"X\@``"P```,'R```'````
MS?(```@```#5\@``!P```-[R```6````YO(```D```#]\@``!@````?S```+
M````#O,``!P````:\P``%````#?S```'````3/,```@```!4\P``"````%WS
M```%````9O,``!````!L\P``$````'WS```&````CO,``!D```"5\P``"@``
M`*_S```<````NO,```<```#7\P``!0```-_S```0````Y?,``!0```#V\P``
M"P````OT```-````%_0``!<````E]```!````#WT```)````0O0```H```!,
M]```!P```%?T```"````7_0```X```!B]```"````''T```?````>O0``",`
M``":]```.````+[T```Q````]_0``"<````I]0``9````%'U```4````MO4`
M`%4```#+]0``.````"'V``!*````6O8``%L```"E]@``*`````'W```X````
M*O<``"@```!C]P``+````(SW```G````N?<``!L```#A]P``/@```/WW``"I
M`0``//@``",```#F^0``%P````KZ``!(````(OH``(4```!K^@``,````/'Z
M``!!````(OL``%L```!D^P``20```,#[```=````"OP``!@````H_```(0``
M`$'\```?````8_P``"L```"#_```(0```*_\```G````T?P``!T```#Y_```
M$0```!?]```S````*?T``"4```!=_0``)P```(/]```?````J_T``#````#+
M_0``:0```/S]```]````9OX``&4```"D_@``30````K_```O````6/\``"X`
M``"(_P``,````+?_``!4````Z/\``%H````]``$`2````)@``0!*````X0`!
M`#(````L`0$`+P```%\!`0`L````CP$!`"T```"\`0$`<0```.H!`0!O````
M7`(!`+,```#,`@$`%P```(`#`0`E````F`,!`#(```"^`P$`*0```/$#`0`^
M````&P0!`"(```!:!`$`4@```'T$`0`E````T`0!``L```#V!`$`L0````(%
M`0!%````M`4!`"$```#Z!0$`,````!P&`0`E````308!`!P```!S!@$`,0``
M`)`&`0`'````P@8!``<```#*!@$`!````-(&`0`-````UP8!``L```#E!@$`
M#@```/$&`0`+``````<!``4````,!P$`$````!('`0`"````(P<!`%D````F
M!P$`!0```(`'`0`2````A@<!``0```"9!P$`!P```)X'`0`(````I@<!``4`
M``"O!P$``P```+4'`0`0````N0<!``P```#*!P$`$P```-<'`0`-````ZP<!
M``(```#Y!P$`!P```/P'`0`&````!`@!`!0````+"`$`#````"`(`0`8````
M+0@!``8```!&"`$`$@```$T(`0`,````8`@!``,```!M"`$`*@```'$(`0`$
M````G`@!``8```"A"`$`!P```*@(`0`?````L`@!`#4```#0"`$`+@````8)
M`0`O````-0D!`!<```!E"0$`(````'T)`0`;````G@D!`!@```"Z"0$`)```
M`-,)`0`?````^`D!`!H````8"@$`(````#,*`0`:````5`H!`#(```!O"@$`
M+P```*(*`0`K````T@H!`!\```#^"@$`(P```!X+`0`?````0@L!`!H```!B
M"P$`)0```'T+`0`F````HPL!`"4```#*"P$`)````/`+`0`8````%0P!`!T`
M```N#`$`)````$P,`0`8````<0P!`"(```"*#`$`)0```*T,`0`\````TPP!
M`!\````0#0$`(P```#`-`0`?````5`T!`"````!T#0$`&@```)4-`0`8````
ML`T!`"8```#)#0$`'@```/`-`0`I````#PX!`!X````Y#@$`"0```%@.`0`,
M````8@X!`!<```!O#@$`+P```(<.`0`D````MPX!``<```#<#@$`#P```.0.
M`0`4````]`X!``X````)#P$`#0```!@/`0`D````)@\!``4```!+#P$`!P``
M`%$/`0`B````60\!`"4```!\#P$`'0```*(/`0`:````P`\!``<```#;#P$`
MQP```.,/`0`+````JQ`!`!4```"W$`$`!@```,T0`0`)````U!`!``L```#>
M$`$`%P```.H0`0`&`````A$!`#,````)$0$`$P```#T1`0`3````41$!``<`
M``!E$0$`#P```&T1`0`'````?1$!`#(```"%$0$`(0```+@1`0`3````VA$!
M``P```#N$0$`$0```/L1`0`R````#1(!``@```!`$@$`"0```$D2`0`*````
M4Q(!`!0```!>$@$`"@```',2`0`=````?A(!``@```"<$@$`'P```*42`0`(
M````Q1(!`!H```#.$@$`!@```.D2`0`5````\!(!``<````&$P$`"`````X3
M`0`)````%Q,!`#\````A$P$`!P```&$3`0`/````:1,!``X```!Y$P$`$```
M`(@3`0`)````F1,!``D```"C$P$`"````*T3`0`3````MA,!``<```#*$P$`
M&0```-(3`0`*````[!,!`!<```#W$P$`%`````\4`0`*````)!0!``P````O
M%`$`%P```#P4`0`$````5!0!`"H```!9%`$`$0```(04`0`'````EA0!``(`
M``">%`$`$````*$4`0`8````LA0!``L```#+%`$``P```-<4`0`(````VQ0!
M``8```#D%`$`!P```.L4`0`-````\Q0!``L````!%0$`%`````T5`0`5````
M(A4!``X````X%0$`+P```$<5`0`@````=Q4!`!P```"8%0$`#````+45`0`Q
M````PA4!``4```#T%0$`$@```/H5`0`_````#18!`!(```!-%@$`"@```&`6
M`0`&````:Q8!``0```!R%@$`!````'<6`0`*````?!8!`!,```"'%@$`!0``
M`)L6`0`&````H18!``8```"H%@$`!````*\6`0`,````M!8!``H```#!%@$`
M!0```,P6`0`8````TA8!`!D```#K%@$`'P````47`0`=````)1<!`!$```!#
M%P$``@```%47`0`$````6!<!``H```!=%P$`!@```&@7`0`%````;Q<!``,`
M``!U%P$`#````'D7`0!%````AA<!`!H```#,%P$`-0```.<7`0`H````'1@!
M`%,```!&&`$`&0```)H8`0!R````M!@!`"`````G&0$`-0```$@9`0`A````
M?AD!`$4```"@&0$`,````.89`0`H````%QH!`"D```!`&@$`)@```&H:`0`E
M````D1H!`"@```"W&@$`*````.`:`0`B````"1L!`#`````L&P$`$@```%T;
M`0`3````<!L!`!````"$&P$`>0```)4;`0`)````#QP!`',````9'`$`?```
M`(T<`0`K````"AT!`!<````V'0$`%@```$X=`0`/````91T!`!\```!U'0$`
M0````)4=`0`?````UAT!`!P```#V'0$`40```!,>`0`4````91X!``H```!Z
M'@$`!0```(4>`0`&````BQX!``@```"2'@$`!0```)L>`0`2````H1X!`!``
M``"T'@$`$P```,4>`0`=````V1X!``\```#W'@$`#P````<?`0`$````%Q\!
M``D````<'P$`"P```"8?`0`'````,A\!``4````Z'P$`%````$`?`0`'````
M51\!``@```!='P$`#P```&8?`0`(````=A\!``P```!_'P$`#P```(P?`0`&
M````G!\!`!0```"C'P$`!@```+@?`0`,````OQ\!``@```#,'P$`!````-4?
M`0`*````VA\!``<```#E'P$`!````.T?`0`9````\A\!``(````,(`$`"0``
M``\@`0`&````&2`!``8````@(`$`)P```"<@`0`$````3R`!``\```!4(`$`
M$P```&0@`0`'````>"`!``<```"`(`$`!@```(@@`0`&````CR`!`!````"6
M(`$`$@```*<@`0`&````NB`!``D```#!(`$`(@```,L@`0`'````[B`!``<`
M``#V(`$`"P```/X@`0`%````"B$!``(````0(0$`"P```!,A`0!K`0``'R$!
M``X```"+(@$`%````)HB`0`+````KR(!``@```"[(@$`"````,0B`0`&````
MS2(!``@```#4(@$`"P```-TB`0`6````Z2(!``T`````(P$`#0````XC`0`%
M````'",!`!T````B(P$`"@```$`C`0`(````2R,!`!0```!4(P$`#0```&DC
M`0`+````=R,!`!$```"#(P$`"0```)4C`0`.````GR,!``T```"N(P$`$```
M`+PC`0`)````S2,!``X```#7(P$`$````.8C`0`&````]R,!`!$```#^(P$`
M$@```!`D`0`)````(R0!`!<````M)`$`%P```$4D`0`'````720!`#,```!E
M)`$`%P```)DD`0`]````L20!`$T```#O)`$`9````#TE`0!<````HB4!`&L`
M``#_)0$`8P```&LF`0`_````SR8!``D````/)P$`"0```!DG`0`,````(R<!
M``4````P)P$`!@```#8G`0`4````/2<!``P```!2)P$`!0```%\G`0`&````
M92<!`"@```!L)P$`*@```)4G`0`.````P"<!`!$```#/)P$`#````.$G`0`$
M````[B<!``T```#S)P$`#0````$H`0`,````#R@!``X````<*`$`#@```"LH
M`0`4````.B@!``H```!/*`$`#0```%HH`0`*````:"@!`"P```!S*`$`%0``
M`*`H`0`4````MB@!``X```#+*`$`(P```-HH`0`%````_B@!``T````$*0$`
M,@```!(I`0`'````12D!``,```!-*0$`"@```%$I`0`*````7"D!``<```!G
M*0$`"````&\I`0`&````>"D!``H```!_*0$`!````(HI`0`<````CRD!``L`
M``"L*0$`"P```+@I`0`,````Q"D!`!@```#1*0$`-````.HI`0`)````'RH!
M`!$````I*@$`$P```#LJ`0`8````3RH!`!T```!H*@$`#P```(8J`0`,````
MEBH!``X```"C*@$`&@```+(J`0`&````S2H!``8```#4*@$`"````-LJ`0`,
M````Y"H!``4```#Q*@$`"0```/<J`0`2`````2L!``@````4*P$`$````!TK
M`0`.````+BL!`!<````]*P$`!@```%4K`0`.````7"L!``4```!K*P$`%0``
M`'$K`0`5````ARL!``P```"=*P$`.@```*HK`0`(````Y2L!``H```#N*P$`
M%````/DK`0`%````#BP!``4````4+`$`$0```!HL`0`,````+"P!`!0````Y
M+`$`+P```$XL`0`/````?BP!`"4```".+`$`)````+0L`0`I````V2P!`"T`
M```#+0$`#````#$M`0`'````/BT!``L```!&+0$`"0```%(M`0`O````7"T!
M`"P```",+0$`+0```+DM`0!?````YRT!`"P```!'+@$`+````'0N`0`L````
MH2X!`"X```#.+@$`)````/TN`0`H````(B\!`"P```!++P$`,@```'@O`0`9
M````JR\!`!P```#%+P$`,P```.(O`0`H````%C`!`!,````_,`$`"@```%,P
M`0`1````7C`!``<```!P,`$`#0```'@P`0`7````AC`!`!P```">,`$`"0``
M`+LP`0`'````Q3`!`!0```#-,`$`"0```.(P`0`(````[#`!``T```#U,`$`
M"P````,Q`0`'````#S$!``8````7,0$`!0```!XQ`0`'````)#$!``8````L
M,0$`"0```#,Q`0`Q````/3$!``T```!O,0$`"0```'TQ`0`$````AS$!``<`
M``",,0$`"@```)0Q`0`%````GS$!`!````"E,0$`"````+8Q`0`,````OS$!
M``D```#,,0$`"````-8Q`0`#````WS$!``X```#C,0$`"````/(Q`0`>````
M^S$!``8````:,@$`"P```"$R`0`0````+3(!``P````^,@$`!P```$LR`0`#
M````4S(!``,```!7,@$`%0```%LR`0`5````<3(!``8```"',@$`!@```(XR
M`0`(````E3(!``<```">,@$`3````*8R`0`?````\S(!``8````3,P$`!0``
M`!HS`0`7````(#,!`!@````X,P$`&````%$S`0`Q````:C,!`!H```"<,P$`
M'P```+<S`0!W````US,!`"P```!/-`$`"@```'PT`0`&````AS0!`!@```".
M-`$`#@```*<T`0`,````MC0!`!$```##-`$`$P```-4T`0`1````Z30!`!$`
M``#[-`$`#`````TU`0`4````&C4!``0````O-0$`%P```#0U`0`8````3#4!
M`!@```!E-0$`%@```'XU`0`#````E34!``@```"9-0$`:P```*(U`0`(````
M#C8!`!8````7-@$`!````"XV`0`#````,S8!`!\````W-@$`%P```%<V`0`,
M````;S8!`!,```!\-@$`)P```)`V`0`S````N#8!`!$```#L-@$`&@```/XV
M`0`'````&3<!`!\````A-P$`%P```$$W`0`1````63<!`!@```!K-P$`&0``
M`(0W`0`7````GC<!``\```"V-P$`"````,8W`0`'````SS<!``T```#7-P$`
M%0```.4W`0`4````^S<!``D````0.`$`!````!HX`0`+````'S@!``L````K
M.`$`"0```#<X`0`0````03@!``4```!2.`$`!0```%@X`0`,````7C@!``@`
M``!K.`$`"0```'0X`0`'````?C@!``8```"&.`$`#0```(TX`0`(````FS@!
M`!4```"D.`$`#0```+HX`0`0````R#@!``4```#9.`$`'````-\X`0`8````
M_#@!`!@````5.0$`+````"XY`0`[````6SD!`"4```"7.0$`-P```+TY`0`%
M````]3D!``P```#[.0$`!0````@Z`0`'````#CH!``X````6.@$`"@```"4Z
M`0`-````,#H!`!P````^.@$`&P```%LZ`0`?````=SH!`!X```"7.@$`'P``
M`+8Z`0`>````UCH!`!@```#U.@$`(`````X[`0`A````+SL!`"0```!1.P$`
M'P```'8[`0`>````ECL!`"\```"U.P$`(P```.4[`0`E````"3P!`#$````O
M/`$`+@```&$\`0`-````D#P!`"4```">/`$`#0```,0\`0"9````TCP!`!``
M``!L/0$`'P```'T]`0`A````G3T!`",```"_/0$`)````.,]`0`A````"#X!
M`!X````J/@$`)0```$D^`0`H````;SX!`"P```"8/@$`HP```,4^`0`8````
M:3\!`",```""/P$`(@```*8_`0!+````R3\!``X````50`$`!````"1``0`'
M````*4`!``4````Q0`$`#@```#=``0`*````1D`!``\```!10`$`$0```&%`
M`0`3````<T`!``L```"'0`$`!````)-``0`/````F$`!``T```"H0`$`%0``
M`+9``0`2````S$`!`!(```#?0`$`,````/)``0`#````(T$!`!,````G00$`
M!@```#M!`0`.````0D$!`!0```!100$`%@```&9!`0`/````?4$!``(```"-
M00$`!@```)!!`0`5````ET$!``4```"M00$`#````+-!`0`,````P$$!``,`
M``#-00$`"P```-%!`0`&````W4$!``\```#D00$`#P```/1!`0`*````!$(!
M``\````/0@$`$0```!]"`0`(````,4(!``,````Z0@$`"````#Y"`0`(````
M1T(!`!@```!00@$`"0```&E"`0`)````<T(!`!D```!]0@$`"@```)="`0`4
M````HD(!`!0```"W0@$`%````,Q"`0`-````X4(!``D```#O0@$`$0```/E"
M`0`(````"T,!`#P````40P$`,@```%%#`0`'````A$,!``L```",0P$`&@``
M`)A#`0`-````LT,!`!$```#!0P$`$0```--#`0`%````Y4,!`"````#K0P$`
M%P````Q$`0`>````)$0!`!(```!#1`$`#P```%9$`0`&````9D0!``@```!M
M1`$`+0```'9$`0`^````I$0!``<```#C1`$`$P```.M$`0`%````_T0!``@`
M```%10$`,P````Y%`0`2````0D4!``<```!510$`!P```%U%`0`#````944!
M``<```!I10$`!P```'%%`0`,````>44!``P```"&10$`#````)-%`0`0````
MH$4!`!@```"Q10$`%````,I%`0`8````WT4!``8```#X10$`!0```/]%`0`+
M````!48!``8````11@$``@```!A&`0`0````&T8!`!<````L1@$`)0```$1&
M`0`7````:D8!`!````""1@$`"@```)-&`0`*````GD8!`!,```"I1@$`3@``
M`+U&`0`J````#$<!``H````W1P$`%@```$)'`0!R````64<!`!T```#,1P$`
M#@```.I'`0`&````^4<!``0`````2`$`(`````5(`0`'````)D@!``@````N
M2`$`!0```#=(`0`&````/4@!``T```!$2`$`#````%)(`0`-````7T@!``P`
M``!M2`$`"P```'I(`0`.````AD@!``H```"52`$`#P```*!(`0`(````L$@!
M``@```"Y2`$`%P```,)(`0`.````VD@!`"\```#I2`$`%0```!E)`0`#````
M+TD!``T````S20$`&@```$%)`0`@````7$D!`",```!]20$`(@```*%)`0`D
M````Q$D!`"(```#I20$`)`````Q*`0`?````,4H!``H```!12@$`&@```%Q*
M`0`-````=TH!``T```"%2@$`!````)-*`0`%````F$H!``P```">2@$`#@``
M`*M*`0`-````NDH!`!(```#(2@$`#````-M*`0`$````Z$H!`!8```#M2@$`
M%@````1+`0`0````&TL!``D````L2P$`#````#9+`0`-````0TL!`!T```!1
M2P$`"0```&]+`0`*````>4L!``@```"$2P$`"@```(U+`0`-````F$L!``4`
M``"F2P$`!0```*Q+`0`#````LDL!``T```"V2P$`"@```,1+`0`%````STL!
M`"H```#52P$`#`````!,`0![````#4P!`!<```")3`$`!P```*%,`0`%````
MJ4P!``H```"O3`$`"````+I,`0`*````PTP!``@```#.3`$`#@```-=,`0`"
M````YDP!``H```#I3`$`!@```/1,`0`4````^TP!`!`````030$`$P```"%-
M`0`5````-4T!``8```!+30$`!@```%)-`0`-````64T!``<```!G30$`!P``
M`&]-`0`%````=TT!`!T```!]30$`!P```)M-`0`'````HTT!`!L```"K30$`
M#P```,=-`0`)````UTT!``<```#A30$`!````.E-`0`+````[DT!``H```#Z
M30$``P````5.`0`&````"4X!``P````03@$`"P```!U.`0`*````*4X!`!0`
M```T3@$`"````$E.`0`'````4DX!``T```!:3@$`'````&A.`0`'````A4X!
M``@```"-3@$`!````)9.`0`)````FTX!``@```"E3@$`#@```*Y.`0`-````
MO4X!``0```#+3@$`#````-!.`0`&````W4X!``0```#D3@$`,@```.E.`0`S
M````'$\!`#,```!03P$`(````(1/`0`%````I4\!`!````"K3P$`"0```+Q/
M`0`&````QD\!`!\```#-3P$`%P```.U/`0`)````!5`!``8````/4`$`&P``
M`!90`0`(````,E`!``@````[4`$`%0```$10`0`&````6E`!``D```!A4`$`
M!P```&M0`0`(````<U`!``D```!\4`$`"P```(90`0`(````DE`!``D```";
M4`$`!0```*50`0!(````JU`!`#<```#T4`$`.P```"Q1`0`G````:%$!`$D`
M``"040$`.P```-I1`0`C````%E(!`#<````Z4@$`(P```')2`0`:````EE(!
M`!@```"Q4@$`"P```,I2`0`0````UE(!``8```#G4@$`*P```.Y2`0`J````
M&E,!`!4```!%4P$`*@```%M3`0`#````AE,!``4```"*4P$`"@```)!3`0`*
M````FU,!`"0```"F4P$`(````,M3`0`K````[%,!``D````85`$`&````")4
M`0`O````.U0!`!0```!K5`$`%P```(!4`0`'````F%0!``\```"@5`$`$```
M`+!4`0`;````P50!``T```#=5`$`10```.M4`0!J````,54!`($```"<50$`
M$````!Y6`0`+````+U8!``P````[5@$`$````$A6`0`1````658!`!````!K
M5@$`"@```'Q6`0`4````AU8!`!@```"<5@$`&````+56`0`3````SE8!`!H`
M``#B5@$`)````/U6`0!H````(E<!`!````"+5P$`"0```)Q7`0`5````IE<!
M``D```"\5P$`!0```,97`0`%````S%<!`!,```#25P$`$0```.97`0`1````
M^%<!`!@````*6`$`$@```"-8`0`N````-E@!`"\```!E6`$`,````)58`0`O
M````QE@!`#,```#V6`$`,@```"I9`0`6````75D!`$,```!T60$`&P```+A9
M`0`:````U%D!`!H```#O60$`&0````I:`0`)````)%H!`!T````N6@$`'```
M`$Q:`0`:````:5H!`!D```"$6@$`&@```)Y:`0`<````N5H!`!L```#66@$`
M+@```/):`0`.````(5L!``<````P6P$`#P```#A;`0`M````2%L!`!(```!V
M6P$`%P```(E;`0`9````H5L!`!8```"[6P$`%0```-);`0`1````Z%L!`!T`
M``#Z6P$`)````!A<`0`2````/5P!`!L```!07`$`&0```&Q<`0`7````AEP!
M`!@```">7`$`!````+=<`0`6````O%P!``0```#37`$`!P```-A<`0`/````
MX%P!`"````#P7`$`!@```!%=`0`'````&%T!``8````@70$`!@```"==`0`'
M````+ET!``0````V70$`!P```#M=`0`5````0UT!``8```!970$`!0```&!=
M`0`&````9ET!``<```!M70$`!0```'5=`0`,````>UT!``T```"(70$`"@``
M`)9=`0`*````H5T!``H```"L70$`&````+==`0`%````T%T!`"4```#670$`
M$@```/Q=`0`-````#UX!`!$````=7@$`$````"]>`0`,````0%X!`!$```!-
M7@$`*P```%]>`0`(````BUX!``@```"47@$`"@```)U>`0`*````J%X!``\`
M``"S7@$`!@```,->`0`+````REX!``T```#67@$``P```.1>`0`?````Z%X!
M``H````(7P$`"0```!-?`0`/````'5\!``T````M7P$`&@```#M?`0`/````
M5E\!``<```!F7P$`!````&Y?`0`%````<U\!`!T```!Y7P$`!@```)=?`0`#
M````GE\!`!(```"B7P$`$````+5?`0`'````QE\!``<```#.7P$`!0```-9?
M`0`-````W%\!``D```#J7P$`#````/1?`0`<`````6`!`!H````>8`$`%0``
M`#E@`0`:````3V`!``D```!J8`$`$@```'1@`0`,````AV`!``@```"48`$`
M$0```)U@`0!!````KV`!``L```#Q8`$`#````/U@`0`D````"F$!`!@````O
M80$`&0```$AA`0`3````8F$!``T```!V80$`#@```(1A`0`*````DV$!``T`
M``">80$`&@```*QA`0`5````QV$!`!T```#=80$`)@```/MA`0`(````(F(!
M``@````K8@$`#0```#1B`0`,````0F(!``P```!/8@$``P```%QB`0`%````
M8&(!``4```!F8@$`#P```&QB`0!#````?&(!`!4```#`8@$`"@```-9B`0`#
M````X6(!``4```#E8@$`%````.MB`0`4`````&,!`!0````58P$`"@```"IC
M`0`"````-6,!``0````X8P$`(````#UC`0`#````7F,!``4```!B8P$`"0``
M`&AC`0`*````<F,!``0```!]8P$`!0```()C`0`0````B&,!`!(```"98P$`
M!@```*QC`0`'````LV,!``D```"[8P$`!````,5C`0`%````RF,!`&,```#0
M8P$`#@```#1D`0`1````0V0!``0```!59`$`#0```%ID`0`A````:&0!`#\`
M``"*9`$`$````,ID`0`(````VV0!``\```#D9`$`"0```/1D`0`(````_F0!
M`!T````'90$`)@```"5E`0`D````3&4!`",```!Q90$`$0```)5E`0`%````
MIV4!``<```"M90$``P```+5E`0`&````N64!``H```#`90$`$P```,ME`0`%
M````WV4!`$@```#E90$`%0```"YF`0`*````1&8!``L```!/9@$`)P```%MF
M`0!,````@V8!``8```#09@$`!@```-=F`0`'````WF8!``H```#F9@$`!```
M`/%F`0`)````]F8!`",`````9P$`(@```"1G`0`%````1V<!``@```!-9P$`
M)@```%9G`0!@````?6<!`!(```#>9P$`)P```/%G`0`8````&6@!``,````R
M:`$`#````#9H`0`%````0V@!``X```!):`$`#````%AH`0`*````96@!``@`
M``!P:`$`!@```'EH`0`*````@&@!``D```"+:`$`!0```)5H`0`*````FV@!
M``L```"F:`$``P```+)H`0`/````MF@!`!(```#&:`$`$@```-EH`0`*````
M[&@!``D```#W:`$`"0````%I`0`+````"VD!``H````7:0$`"P```")I`0`(
M````+FD!`"$````W:0$`"P```%EI`0`'````96D!``@```!M:0$`#@```'9I
M`0`'````A6D!``\```"-:0$``@```)UI`0`'````H&D!``4```"H:0$`!0``
M`*YI`0`(````M&D!`!(```"]:0$`$@```-!I`0`5````XVD!`!4```#Y:0$`
M%`````]J`0`2````)&H!`!<````W:@$`(````$]J`0`:````<&H!``(```"+
M:@$`!````(YJ`0`.````DVH!``T```"B:@$`!P```+!J`0`<````N&H!``T`
M``#5:@$`$P```.-J`0`(````]VH!``X`````:P$`!P````]K`0`2````%VL!
M``D````J:P$`!P```#1K`0`'````/&L!``0```!$:P$`!````$EK`0`%````
M3FL!`$,```!4:P$`.@```)AK`0`2````TVL!`"L```#F:P$`.````!)L`0`.
M````2VP!`"D```!:;`$`,0```(1L`0`V````MFP!`#8```#M;`$`.P```"1M
M`0`*````8&T!`"<```!K;0$`&````)-M`0`8````K&T!`!@```#%;0$`&```
M`-YM`0`0````]VT!`!0````(;@$`&````!UN`0`G````-FX!`"<```!>;@$`
M*P```(9N`0`H````LFX!`"D```#;;@$`)@````5O`0!@````+&\!`!P```"-
M;P$`"0```*IO`0`'````M&\!`"8```"\;P$`*@```.-O`0`@````#G`!``D`
M```O<`$`0P```#EP`0!&````?7`!``<```#$<`$`&0```,QP`0`<````YG`!
M``T````#<0$`#P```!%Q`0`5````(7$!``8````W<0$`$````#YQ`0`/````
M3W$!``L```!?<0$`$P```&MQ`0`-````?W$!``\```"-<0$`!@```)UQ`0`D
M````I'$!``4```#)<0$`!````,]Q`0`/````U'$!``P```#D<0$`#````/%Q
M`0!`````_G$!``0````_<@$`!0```$1R`0`0````2G(!``\```!;<@$`!```
M`&MR`0`4````<'(!``0```"%<@$`!0```(IR`0`]````D'(!`!D```#.<@$`
M.````.AR`0!=````(7,!`!$```!_<P$`10```)%S`0`?````UW,!``\```#W
M<P$`"@````=T`0`2````$G0!`!`````E=`$`!P```#9T`0`.````/G0!``D`
M``!-=`$`%@```%=T`0`<````;G0!``4```"+=`$`#@```)%T`0`.````H'0!
M`!T```"O=`$`$````,UT`0`4````WG0!`!$```#S=`$`(P````5U`0`(````
M*74!``H````R=0$`#P```#UU`0`.````374!``8```!<=0$`$@```&-U`0`8
M````=G4!``L```"/=0$`"@```)MU`0`(````IG4!``4```"O=0$`'@```+5U
M`0`&````U'4!``\```#;=0$`"````.MU`0`.````]'4!``8````#=@$`#0``
M``IV`0`M````&'8!``T```!&=@$`!P```%1V`0`'````7'8!`!X```!D=@$`
M"````(-V`0`0````C'8!``,```"==@$`$P```*%V`0`(````M78!``4```"^
M=@$`'@```,1V`0`M````XW8!``0````1=P$`#0```!9W`0`0````)'<!``0`
M```U=P$`#P```#IW`0`*````2G<!``<```!5=P$`"P```%UW`0`(````:7<!
M``P```!R=P$`#0```']W`0`>````C7<!`#$```"L=P$`-@```-YW`0`?````
M%7@!`"0````U>`$`(P```%IX`0`_````?G@!`!\```"^>`$`(0```-YX`0`H
M`````'D!`"$````I>0$`!P```$MY`0`(````4WD!``D```!<>0$`"````&9Y
M`0`9````;WD!`!D```")>0$`,P```*-Y`0`J````UWD!`"T````">@$`,@``
M`#!Z`0`&````8WH!`!L```!J>@$`!P```(9Z`0`(````CGH!`!\```"7>@$`
M$0```+=Z`0`.````R7H!``P```#8>@$`!0```.5Z`0`1````ZWH!``@```#]
M>@$`$@````9[`0`,````&7L!`!@````F>P$`,0```#][`0`*````<7L!``4`
M``!\>P$`!0```()[`0`:````B'L!``P```"C>P$`!@```+![`0`6````MWL!
M`!0```#.>P$`#0```.-[`0`-````\7L!`!4```#_>P$`#@```!5\`0`$````
M)'P!``4````I?`$`#0```"]\`0!(````/7P!`&,```"&?`$`$P```.I\`0`?
M````_GP!`!D````>?0$`#0```#A]`0`/````1GT!``L```!6?0$`$@```&)]
M`0`L````=7T!``,```"B?0$`"0```*9]`0`*````L'T!``\```"[?0$`"P``
M`,M]`0`R````UWT!``,````*?@$`&@````Y^`0`-````*7X!`!,````W?@$`
M)P```$M^`0`,````<WX!``<```"`?@$`$````(A^`0`5````F7X!``@```"O
M?@$`$0```+A^`0`'````RGX!`!H```#2?@$`)@```.U^`0`*````%'\!``,`
M```??P$`$@```"-_`0`.````-G\!`!4```!%?P$`!0```%M_`0`'````87\!
M`!$```!I?P$`"P```'M_`0`+````AW\!`!$```"3?P$`$0```*5_`0`)````
MMW\!``@```#!?P$`-````,I_`0`N````_W\!`"X````N@`$`"````%V``0`1
M````9H`!``8```!X@`$`%P```'^``0`<````EX`!`!X```"T@`$`#@```-.`
M`0`*````XH`!``,```#M@`$`"````/&``0`+````^H`!``,````&@0$`#```
M``J!`0`4````%X$!``L````L@0$`&````#B!`0`;````48$!`!<```!M@0$`
M!0```(6!`0`*````BX$!`!0```"6@0$`#@```*N!`0`/````NH$!``8```#*
M@0$`"0```-&!`0`2````VX$!`$X```#N@0$`'0```#V"`0`%````6X(!``4`
M``!A@@$`#P```&>"`0`-````=X(!``\```"%@@$`&P```)6"`0`1````L8(!
M`!````##@@$`(````-2"`0`?````]8(!``\````5@P$`;@```"6#`0`<````
ME(,!`!4```"Q@P$`)@```,>#`0`;````[H,!`!0````*A`$`&````!^$`0`6
M````.(0!`!P```!/A`$`$P```&R$`0`*````@(0!``<```"+A`$`"P```).$
M`0`%````GX0!`!<```"EA`$`#0```+V$`0`?````RX0!``8```#KA`$`2@``
M`/*$`0`Q````/84!`$0```!OA0$`8P```+2%`0`'````&(8!`#0````@A@$`
M*````%6&`0`&````?H8!``H```"%A@$`"0```)"&`0`R````FH8!``8```#-
MA@$`6P```-2&`0`K````,(<!`"4```!<AP$`#P```(*'`0`P````DH<!`!\`
M``##AP$`)P```..'`0`A````"X@!`"<````MB`$`(P```%6(`0`0````>8@!
M``<```"*B`$`%P```)*(`0`5````JH@!``\```#`B`$`!@```-"(`0`O````
MUX@!``P````'B0$`!@```!2)`0`$````&XD!`!`````@B0$`"````#&)`0`%
M````.HD!``L```!`B0$`"````$R)`0`(````58D!``,```!>B0$`#````&*)
M`0`/````;XD!`!\```!_B0$`'0```)^)`0`/````O8D!`!8```#-B0$`#P``
M`.2)`0`&````](D!`!(```#[B0$`%@````Z*`0`-````)8H!``P````SB@$`
M&0```$"*`0`G````6HH!``\```""B@$`(@```)**`0`K````M8H!`!$```#A
MB@$`#@```/.*`0`<`````HL!``<````?BP$`$````">+`0`4````.(L!``L`
M``!-BP$`"@```%F+`0`*````9(L!``<```!OBP$`"0```'>+`0`(````@8L!
M``D```"*BP$`#@```)2+`0`.````HXL!``4```"RBP$`#P```+B+`0`,````
MR(L!``P```#5BP$`#0```.*+`0`:````\(L!``L````+C`$``P```!>,`0`$
M````&XP!``8````@C`$`"````">,`0`&````,(P!`%0````WC`$`*````(R,
M`0`S````M8P!`!4```#IC`$`!0```/^,`0`$````!8T!``H````*C0$`"@``
M`!6-`0`'````((T!``H````HC0$`%0```#.-`0`,````28T!``H```!6C0$`
M#````&&-`0`(````;HT!``8```!WC0$`!P```'Z-`0`&````AHT!`!4```"-
MC0$`"0```*.-`0`%````K8T!``<```"SC0$`(@```+N-`0`&````WHT!`!4`
M``#EC0$`&````/N-`0`+````%(X!``<````@C@$`$P```"B.`0`3````/(X!
M``8```!0C@$`$P```%>.`0`*````:XX!``@```!VC@$`!@```'^.`0`(````
MAHX!`!````"/C@$`&````*".`0`(````N8X!``H```#"C@$`#P```,V.`0`%
M````W8X!``P```#CC@$`$````/".`0`+`````8\!``,````-CP$`#0```!&/
M`0`'````'X\!`"P````GCP$`*@```%2/`0`Y````?X\!`"0```"YCP$`+0``
M`-Z/`0!?````#)`!`!````!LD`$`5P```'V0`0`U````U9`!`%H````+D0$`
M4P```&:1`0`>````NI$!`$(```#9D0$`(````!R2`0`C````/9(!`"$```!A
MD@$`%0```(.2`0`_````F9(!`-(!``#9D@$`%````*R4`0`0````P90!`$$`
M``#2E`$`>0```!25`0`Q````CI4!`#P```#`E0$`4P```/V5`0!/````498!
M`!H```"AE@$`$````+R6`0`6````S98!`!D```#DE@$`(P```/Z6`0`A````
M(I<!`"(```!$EP$`&@```&>7`0`0````@I<!`#,```"3EP$`'0```,>7`0`A
M````Y9<!`!P````'F`$`+@```"28`0!=````4Y@!`#D```"QF`$`6P```.N8
M`0!$````1YD!`#(```",F0$`/@```+^9`0`R````_ID!`%`````QF@$`;P``
M`(*:`0!=````\IH!`%$```!0FP$`-````**;`0`@````UYL!`"$```#XFP$`
M(P```!J<`0!O````/IP!`&D```"NG`$`OP```!B=`0`7````V)T!`"````#P
MG0$`/````!&>`0`\````3IX!`#L```"+G@$`)0```,>>`0!%````[9X!`!8`
M```SGP$`!@```$J?`0#%````49\!`$$````7H`$`(P```%F@`0`P````?:`!
M`"(```"NH`$`'````-&@`0`R````[J`!``T````AH0$`"````"^A`0`%````
M.*$!``P````^H0$`#````$NA`0`,````6*$!``L```!EH0$`!@```'&A`0`2
M````>*$!``0```"+H0$`3@```)"A`0`%````WZ$!`!0```#EH0$`!````/JA
M`0`'````_Z$!``4````'H@$`!0````VB`0`#````$Z(!`!(````7H@$`"0``
M`"JB`0`2````-*(!`!$```!'H@$``@```%FB`0`%````7*(!``<```!BH@$`
M$P```&JB`0`,````?J(!`!<```"+H@$`!@```*.B`0`1````JJ(!``T```"\
MH@$``P```,JB`0`R````SJ(!``0````!HP$`!@````:C`0`'````#:,!`!P`
M```5HP$`+0```#*C`0`N````8*,!`"\```"/HP$`$P```+^C`0`>````TZ,!
M`!<```#RHP$`&P````JD`0`>````)J0!`!D```!%I`$`&@```%^D`0`>````
M>J0!`!8```"9I`$`*0```+"D`0`?````VJ0!`"<```#ZI`$`%P```"*E`0`;
M````.J4!`!T```!6I0$`&````'2E`0`D````C:4!`"8```"RI0$`)P```-FE
M`0`7`````:8!`!@````9I@$`'````#*F`0`B````3Z8!`!<```!RI@$`'@``
M`(JF`0`:````J:8!`#X```#$I@$`)`````.G`0`G````**<!`"H```!0IP$`
M*P```'NG`0`E````IZ<!`!L```#-IP$`(````.FG`0`=````"J@!`#`````H
MJ`$`'0```%FH`0`*````=Z@!`!8```""J`$`$@```)FH`0`H````K*@!`!T`
M``#5J`$`#0```/.H`0`/`````:D!`!D````1J0$`$````"NI`0`;````/*D!
M`#$```!8J0$`"````(JI`0`*````DZD!`"(```">J0$`)@```,&I`0`E````
MZ*D!`!D````.J@$`!P```"BJ`0#"````,*H!`!H```#SJ@$`%0````ZK`0`(
M````)*L!``P````MJP$`%````#JK`0`:````3ZL!``4```!JJP$`-0```'"K
M`0`4````IJL!`!0```"[JP$`!P```-"K`0`*````V*L!``H```#CJP$`0```
M`.ZK`0`E````+ZP!`!(```!5K`$`%0```&BL`0`/````?JP!`#(```".K`$`
M#0```,&L`0`.````SZP!``\```#>K`$`&````.ZL`0`*````!ZT!``\````2
MK0$`!0```"*M`0`?````**T!``H```!(K0$`'P```%.M`0`(````<ZT!`!4`
M``!\K0$`!P```)*M`0`(````FJT!``H```"CK0$`.P```*ZM`0`%````ZJT!
M``T```#PK0$`"@```/ZM`0`0````":X!``8````:K@$`"@```"&N`0`'````
M+*X!`!(````TK@$`#````$>N`0`=````5*X!`!,```!RK@$`'@```(:N`0`R
M````I:X!``4```#8K@$`!@```-ZN`0`<````Y:X!``0````"KP$`*@````>O
M`0`0````,J\!``4```!#KP$``P```$FO`0`,````3:\!`!<```!:KP$`"P``
M`'*O`0`#````?J\!``H```""KP$`"````(VO`0`+````EJ\!``X```"BKP$`
M#P```+&O`0`1````P:\!`!(```#3KP$`"@```.:O`0`P````\:\!`!L````B
ML`$`&````#ZP`0`*````5[`!`$@```!BL`$`"````*NP`0`6````M+`!`$(`
M``#+L`$`%`````ZQ`0`/````([$!``D````SL0$`!````#VQ`0`&````0K$!
M`!8```!)L0$`&@```&"Q`0`'````>[$!``@```"#L0$`"````(RQ`0`"````
ME;$!``D```"8L0$`"P```**Q`0`%````KK$!`!H```"TL0$`)@```,^Q`0`5
M````]K$!`!X````,L@$`$0```"NR`0`"````/;(!``0```!`L@$`#P```$6R
M`0`&````5;(!``4```!<L@$`!````&*R`0`4````9[(!`$D```!\L@$`$0``
M`,:R`0`E````V+(!`"\```#^L@$`6````"ZS`0`1````A[,!`&D```"9LP$`
M'P````.T`0`\````([0!`"8```!@M`$`.0```(>T`0`N````P;0!`"<```#P
MM`$`-0```!BU`0`Q````3K4!`#$```"`M0$`-0```+*U`0`M````Z+4!`!\`
M```6M@$`-@```#:V`0`:````;;8!``X```"(M@$`#````)>V`0!S````I+8!
M``8````8MP$`=0```!^W`0!J````E;<!`"L`````N`$`$````"RX`0`6````
M/;@!``L```!4N`$`&@```&"X`0`U````>[@!`!L```"QN`$`%0```,VX`0!7
M````X[@!`!<````[N0$`"@```%.Y`0`%````7KD!``8```!DN0$`"````&NY
M`0`%````=+D!`!0```!ZN0$`$````(^Y`0`6````H+D!`"````"WN0$`"P``
M`-BY`0`(````Y+D!``0```#MN0$`"@```/*Y`0`+````_;D!``@````)N@$`
M!P```!*Z`0`7````&KH!``8````RN@$`!@```#FZ`0`7````0+H!``L```!8
MN@$`!P```&2Z`0`2````;+H!``@```!_N@$`%P```(BZ`0`-````H+H!``T`
M``"NN@$`!@```+RZ`0`&````P[H!``\```#*N@$`!P```-JZ`0`%````XKH!
M`!0```#HN@$``@```/VZ`0`$`````+L!``P````%NP$`"0```!*[`0`B````
M'+L!``(````_NP$`$@```$*[`0`8````5;L!``L```!NNP$`!0```'J[`0`,
M````@+L!``H```"-NP$`#P```)B[`0`6````J+L!``4```"_NP$`#0```,6[
M`0`G````T[L!``X```#[NP$`#P````J\`0`0````&KP!``4````KO`$``@``
M`#&\`0`+````-+P!``$```#C````J0$``%L```!0`0``N`(``"$%```W!@``
M#0,``%`#``#U!0```````#X&``#O!0``7```````````````:0,``"`$``!6
M!0``NP4``$D!```J`0````````````"<`@``I@4```````#W````U@4``'<$
M````````W`0``,(%``"P````%P$``#D$``#;!```-0```!H&``"0````10$`
M`!@!``"*`0``4`4``)4$``"C```````````````R`0```````"X"````````
M`````',!`````````````&,&`````````````````````````````#(```!Z
M!0``4@0`````````````:@$``#P$```G!````````%L!``!Q!0```````"X&
M``#L!0``808``/<!``!Q`0``````````````````#P$``'<"``#``0``:P,`
M`````````````````"X%````````:P0``"X```#V!```4P,``(\```!K!0``
M```````````D`P``%@(```````"1````0P$``%4!``#Z`0``````````````
M````40(``(T%``"E`P```````/$```!M`@``608``'\"````````6@,``(@#
M```V!@``S`$`````````````BP(````````G````B`$``!H#``"@`@``2P$`
M`'````!R!```;P$```````"V`P```````"@!``#Z!0``&0$``*P!````````
M6`,``%D#``!:!0``U@0``#4%```.````<`0``$P"````````*P$```4%``##
M`@``2@8``#,#``!'````VP$``%H!``#[!```3@```.8```!F!@````$`````
M``#7`@``P@,``"8%``!C`@``:00``(@%`````````````/4"``#\!```PP,`
M`!H"````````>@0``!8%```;````7P0``"P```"%!0``R00``,\!```R!@``
MF`8``-`"````````OP``````````````*0(```````!Y`@``HP0```````!Q
M`````````+\"``"7`````````#H```!Z!@``9````)<%````````F`4`````
M```$!```FP4``"\````&`P```````(H```#@!0``R````$T`````````````
M`"$"``"^!`````````````""`0``GP$```````"^````#P(``,0"````````
M#@(``)8&```!!````@8```````!<`@``1`8```````!4`P``!0```"4!```[
M`0```````&@#``#7!0```````#X`````````30$``&4#````````R`4`````
M``"H`P```````+<$```+!```````````````````3P0``(0"``!+`P``````
M`#X!````````700``'`!``"Q!````````'P!```U`P```````/L"``#P`@``
M]P0``,@"``"=`````08````````H`P``N0```,0%``#/`@``[@$``-X!```M
M`P``P`4``&\`````````JP0``%(&``#$!```&0```#@%````````P`,``"`"
M```U`@```````$<"``!Q!````````)T#```-!0``1@0``%H$``"I!```````
M``4#``"B`@``8P,``'T"``!E!```=P,```````!X`P``%`,``,H"``"R!```
M?`8``"8!``#:`@``*`4``+H%``!<!`````````````#!````G@```&4!````
M````Z@(``$$&``"[`@```````+L!``!4`````P0``,X!````````)P(``$<%
M``#I!````````-P!``````````````````!.`@```````/0```!`!```````
M`#8!``!V`@``?08```````#&`0`````````````8!```6P4``)<!``#2`0``
M>``````````<````.P,``.$!``"=!```,`4``````````````````.@"``!#
M!@````````4$````````9`8``-@!````````C@,````````5`P``````````
M``!U!```?0```&L"``"A!```P@```!`&``"%!```B@0```````"(!@``/P$`
M``````!9`0```````(`"``#@`0``A0$``/8!```#`@``=`,``*X%``"L`P``
MYP$``-8````,`@``V00``$,`````````B0,``$T#``#,`@``@`,```($```5
M!0``)04``)$$`````````````)8"``#7`P``JP(``-P%``"4!@``8````*0"
M``#`!```0P,``*H$````````%P,````````0`0``JP,``'D````)````F@4`
M````````````@``````````G!0``/04``%L"``"A!0``L`$``$0````K````
M.@(``%<"``!E!0``\00``+\%``!J!0``Q0```&X#```+`@``1@8````````.
M!```.@0``.<`````````]0,``(P#````````!`$````````!`@``-P4`````
M``"I````6`8``!(%````````+08``&(%````````:@```-0```#[!0``````
M`(4#```9!@``"`,```````````````````````")!@``TP$``!0```#0!```
M``````````!_!0``:@0``/<#``#[`P```````(<$``#,!0``$0$``#X%````
M````?P$````````L`@``(08``!,```#N!```4@4``*X$``":`@``M`$``"\&
M````````W04``"(````L`P``7`,``$X$````````Q`,``!P$````````)@``
M`-<$````````C`8```````"]````D@0``$L"```N`P```````/8#``!_`P``
MA`4``*`%``!K!@``X`,``'X#```9`P```````/0"``#F!0``RP(```````!3
M`@````````<%``""!```(0,``!<%```I!@``5`8```````"G`````````.D"
M``"W`0``D0(``)$%````````V@```&$````4!@````8``&H"```.`0``TP(`
M`.(```#]!```3````.$````P`@```````)T"````````X0(``'`&```E`@``
MVP```#4$``".!@``$0,``+<%``![````L`0```````#[`0``Y`0``,4"``!4
M`@```````)L!``!\`@``ZP(```````#H`P`````````````,!@``````````
M`````````````+0%```A!`````````````!+`````````/@$```.`P``````
M```````Y!0``H@,``!<$``#.!0``[`0``-T```#(`0```````-4$```R!0``
MC0```%8$``"``0``R`0``($!``!.`0``;@$``/@!``"?!0``'P,```````"$
M````7P```'0!``!-!```,08``.H$````````(@4``/,$````````!P,``'T#
M``#*`P``LP0```````!8`@``LP```,T!``!F!```-@(```<"``!S!@``]@4`
M`-`#``!2`P````````````"$!````````%D```!?!@```````&`%````````
M``````````#[````.`$``!\&```[!@``104``,<%``"A`0``"P8``*(!```S
M`@``&P4```````"J````.08``/`#```F`P``XP(`````````````G`4``,8#
M``#4`P``@@4``!,#``#Q`0``0`4``,H%``"7!````````"P!``!-`@``-0$`
M`$L&```Q`@````````````"F!```\0(``&H#``#9`@``?`4``*X```";!```
ML@4````````>!```?`,``*($``"-!````````)P!````````<P(``.T#``!`
M`````````#`#``#9!0``F0,```````!/````A@(```P````]!@``,P$`````
M``!,!```G04``,H```!N!```<@$``-0"``![`0``!`,``&`"``!(!```U@,`
M`,P$```O`0```````.P`````````1`4``&@&``"5!@``P@0``/`$```M`0``
MWP4```````!L!````````#P#````````,P4``.8$``#>````WP(``%$%``!"
M!```F`````````#J`P``*@(``/0!````````?04``&8"``">!0``*`(``*0%
M````````1`(``(P!``"$`0``7@(``+P$```4`@``!`8``'T$``!P`@``[@4`
M`)8$``"'`@```````/(%`````````````"P$````````*@8``#T$``!@!```
M<@4``!H```#^`P``Y@$`````````````````````````````500````````2
M!```;`$``(8&```:!0```````-4%``"^!0````````````!$!```-@0``(L`
M``"?````Q`$````````)!@``%P````H%````````W@,``%`"```W`@``JP$`
M`-$$``#]`@``PP0```H&``!G!@``/0$``!L&````````.P0`````````````
M`````+4!```0`@````````(```!A!````````/\$``#)!0```````(\"``!M
M!@``0@8``*4$``")``````,``(X!`````````````/,```"3!```D@4``&("
M`````````````&8%```C!@``_P````````"T`@``-@```#D!``".!```````
M`$<$`````````````````````````````+H$``#>`@``C@````````#5`0``
M10,```<``````````````(T#```=`0``(`,``"T```"0`P```````,L#``!_
M````/P8``+8$``!@`0``F@,``'H#``"&!0``AP```(@`````````M0,``)`$
M``!@!@```````#H!`````````````)`"``!)`P``DP8``!$%````````````
M`'8```">`@``E````&0!``#Z````U`0```L#```#````P@(``)`%``"X`0``
M#`,``$H`````````?@(`````````````:`0``'0`````````>P(``"4$````
M````6P8``.$#```=!@```````%T&```5!@``=`0``-($``#!`0``%@8``&X%
M``#L`P``GP,``-D!````````9`(``&4````Q`P``'@$``)D!``#N`@``\@(`
M```````[!0```````*D#``!^!@``.P(``$L%``#H!````````%,&````````
M9P0```@!``!/`P``?@0``*\"````````5P$``#X#```-`@```````,\%``!F
M`0``,04```````#^`@``8@0``&4&````````50````````#?!```-````$$`
M``!1`P````````````!T`@``1P,``.H```"-`0``^`,````````0!0``````
M````````````T0```#<!```D!0``D`$``-4```!Q`P``:08``-,$```5!```
M`````*\%``!"!0```````.L!```8!0``OP$``)D&````````?P8``)4%``#K
M``````````(!```?!```YP0``'4!``"H!`````````````!D!```!0$``!T"
M````````=0,``+(`````````@0(```````!3````[P$``$0!``"#`@``=08`
M`$@"``"O!```S@,``"`!`````````````+T$``#Y!````````"0"``#X!0``
M`````.,%``!C`0``BP4``.X```#J`0``OP0``"D%```2`@``!08``+<#````
M````C08``&P&``"9!0``B@(```P%````````_0,```````"Q````:`4`````
M``"\````R`,`````````````N04```````#=`@``L04``,L$````````*P0`
M`&<%``#!!```(P4```````!N````%P(`````````````6@```.D`````````
M\@```+(!``!``0``'00`````````````A@,``.`````[````J`(``,````#$
M`````````#D`````````$P4``*`#```>!0``^```````````````H`0`````
M``!>`0``+@0``,D#```Q`0``8@```#\%```2````8@8```````#6`@``3`8`
M`.`$``!=`P```````!$````\````2@0``-,#````````IP4`````````````
M=P4``.$%````````>08``#D"````````70```&T%````````;0```-8!````
M````U`$``.4$```````````````````'`0```````.4```!7!0``A0``````
M```J`P``5P````````#^!0``E0(``/D#`````````````%$&```@!0``Z```
M`+P"``"D`0``M04```H```">!```T`$```````"L`@```````+L#``#T`P``
M-P,`````````````6P,``.<"``#;`P``9`,``"D#```T!0``X@(``+4$``#\
M`0``(````#($``"X!0``]@```*P```"/`0``<`4````````/!0``````````
M```9!0``$P(```````!0````IP(```````!=!0````````````#!`@``>P0`
M`.\"````````HP$``!D$``#S`0````4``'4```"3````O`$```````"2`P``
M-`0``(0&````````&P$``,H$``##`0``(P````````"I!0``4@$```````!*
M!0``$00``)0%``!U!0````````````!0!```*P8``"4&``"#`P``OP,```T$
M``"C!0```````)(&````````Y`(``*8!``"M!````````'@&``"T!```E`(`
M``,%```-````00(``#0&`````````````"0```!E`@``F@8```````!I!0``
MC@4``(("```?`@``$P8```````#*`0``````````````````@`8``'4"``!7
M!@``KP,``,T%``!Z`0``=@4```````!I`@``@@,``(,`````````H0,`````
M``"O`````````+P%``#%`P```````/\%``"7!@``"@(```````!%`@``````
M`+X#``!N!@``Y0(```8%````````D@$``.H%```P!```"P```)@"````````
M\````(L#``!&`P``B@4```````"]!0``7`8``(0#```#`P``V0,``$`"```(
M`````````)@#````````K0(```0"``"\`P``````````````````9P``````
M```I`0``:`$``,P#````````,0```-T!``!,!0``'@````````!M`P``D@``
M`%4&```X````&`(``%<$```)`@``<@(````````````````````````O!```
MJ@4``.L%``",`@````````````!-!0``400``#<````;`P``208````````K
M`P``3P4``!L"``"M`P``0P(``&\$``!=`0``=@8``+H"``!V`P```0$``'P$
M``````````````````#>!`````````````!R!@``%0``````````````L0,`
M`!,!````````"`4``````````````````)8%``"1!@``FP(``,<"``#.`@``
M*@4``-,%````````Z`4``$8!``!X`@``M````,L!``#7`0``QP```+,#``!?
M`@``9P(``/\"``!J!@``CP0``"H$``")!0``8`,```````"V`````````*0#
M``#S`P``*@```+4````@!@``)0````L!```D!@``7@4``%X&````````N@,`
M```````K`@``_0$``!L$``#%`0```````*<$``!X!0``B@,````````Z!0``
M#P8``(\&``"T`P`````````````_!````````$4$````````%@$``'X`````
M````P`(``.0%``"?!```<P4``.\```"`!0``9P$``"(!``",!0``20``````
M``"!!```=@$``+T!``#&!````````*@````#`0``H0`````````5`0``````
M`#,&````````"`(````````\`0``````````````````H0(``)\"```M!0``
MP@$``&$!````````DP$``+X"``!Y!0``````````````````!@```',$```:
M`0```````.,#````````(@,``'L#``"Q`0``$@8`````````````<@```&$%
M``",````_`(``*8````?!0``V`4`````````````$0(`````````````E0``
M`!P#``#)`0``#P```$D$``!/!@``.`,``&(!``"%`@``0@,``&P#``"+`0``
M,P```'0%``!>`P``/P```#H&````````^@(``+@#``!+!```5@,``,T```!1
M`0``0`,```````!\````=@0``-P#``````````````D$``"P`P``Z04``,L`
M`````````````*(`````````+P4``*4!`````````````)@$``#0!0``<P,`
M`,<!```4!0``L`4``+D!``#B!````````&X"``!"`@````````````#2````
M,@(``.T%```X`@``204``$@!``!!`0``2````)H```!7`P``%0(``%\!``#&
M!0``K@,``),#````````LP$``'D!`````````@,``-P"``"M````Y0$``&(#
M```*`P``#@4``*````#\!0```````+8"``#?````-@4`````````````80,`
M`!`#``#M`0``(0$```````#0````@P$``+<"```=!0```````)$!``"9!```
M)`$``%P%``!(`P``4@(``-4#````````T@(`````````````-08``*D"````
M````5`0``&\#````````)`0``.T$````````S@```$4&``!"````_@$``*8#
M````````D0,``.<#``!6!@``E`,``-$!```8`````````%P!```7!@``)P,`
M``D#``"8`0``WP,```P$````````E`$``$(!````````1P$````````W!```
MV@$``!\!``!#!```(P$``+4"````````8P0``.,!``!/`@```@4``,T#````
M````_P,```````#4!0``B0$``!T#``#F`@``V`,``%@%``"9````000``*L%
M````````N0(``$X#``!!!0``O0,``$\!``":`0``2`8``*P%``!G`P``````
M``````#Y`@``IP$````````(!```E0,``!\`````````B00``/P`````````
M`````)8```!A`@``\0,``/T```!#!0``>0,``&L!```<!@``P04``-$%````
M````!P8``)D"``",!```CP,```````"3`@``=P```(,&``!Z`@``60(``#``
M```Z`P``@0```+L```![!@``_@0``#\#````````40```/(!``#:!```/0``
M`#,$``!P`P``^`(`````````````B`0``&D```!?!0``MP```%@$````````
MFP,```````"2`@``5@```'L%``!;!````````+@$```A````Y`$`````````
M````<08```@&``!=`@``6````/,"```'!```I04``,\```!(!0``V`(`````
M```4`0``I`````````">`P``<0(```D%``#K!```9@```*4````"`@``K0$`
M``````!O!@```````#P&``"(`@``4`8``(,$````````'`4``,T"``#\`P``
MTP````````#?`0```````,8```"Y`P````````````"6`0``,`$``$H"``!C
M!0``!@$``(8```!4`0``E`0```````!'!@``JP```"P&```<`0```````&P`
M```-!@``T@4``"(&````````Z0$``.L#```$!0``;P4``%(```#B`0``X@,`
M`````````````````'\$````````;0$```````!^`0``9`4``*8"````````
M`````/`!````````Q@(``.(%```&!````````$8"````````0`8``+,"``!T
M!@``SP0````````]`@``5`4``"P%``!3!```EP,````````C`P``(@0``"8&
M``#+!0``FP````````"H`0``\`4``"<&``#N`P``504``)T!````````G```
M`.0#```>!@``+@$``$T&``"'!@``N@$``+8!````````]0$````"```6`P``
M````````````````J@,``+$"```G`0``AP$`````````````]0``````````
M`````````*H"````````$@$``#0"`````````````!@#``#8`````````&T$
M``!*`P``=P$``+8%```H!@``[0```#@&```>`@``#0$``.4%``#<````3@4`
M``$#````````-@,``,,``````````````),%```B`@``+0(```````!X!```
M`````)H$````````B@8```X&```$````!@(``,D`````````"P4``'@!``!8
M`0``7P,``+("``"6`P````````````#H`0``"0$``-D```#R`P``[P,``#`&
M``!3`0```````/\!``#Z!``````````````M!```Y0,`````````````````
M`+T"```3!```;`4``!8`````````_@```,<$````````&@0``#D#````````
M`````)P$````````^0$``-(#``#%!```"@$``.<%``">`0```````"@$``"'
M!0``I0(``+X!```O`@`````````````>`P``]P4``(8$````````[`(`````
M```T`0``?@4```````"D!``````````$````````C0(``&@"``!>````<@,`
M`-L%```0!```50(``!$&```/`P``W00``(,%``!:`@``Y@,``&P"```R`P``
M)@0``*,"`````````````*\!````````XP0``","``#:!0`````````````%
M`@``A08``/D%``##!0```````#X$``#5`@``BP8``+L$``#)`@```````($%
M``#Q!0```````#$$```K!0``6@8``+`"````````````````````````````
M`/<"``#]!0````````````!>!```5@$``"D`````````@@```$X&```&!@``
M]00``&L```#1`@``1@4```,&``".`@``&0(``#\"````````:0$``)P#```6
M!````````#@$``"G`P``J`4````````8!@````````````"!`P``S````$H!
M``!$`P````````````"`!```'`(``$P!``!S`````````)4!``")`@``````
M``````#1`P```````*H!``!W!@``604``,X$``#@`@``V@,``*P$````````
MH`$``((&```*!```V`0```\$````````\@0``!T```"X`````````'T!````
M`````````$$#``#T!0```````(L$```T`P``9@,``.\$```2`P``N00`````
M``!6`@``EP(``*T%``````````````````!5`P```````(\%``"&`0``600`
M`($&```E`P``P0,``"D$``!%````\P4`````````````]@(``/0$``!H````
MSP,``-T#``#7````4P4```````#I`P```````,<#``#;`@```````#P%````
M````;P(``/H#```]`P``/`(``"8"``"S!0```````.$$``!Y!```AP,``'H`
M```4!```/@(``*(%```,`0```````-X%``!)`@``L@,````````H````S00`
M`!````"Z````D`8````````C!```^0```&,```#%!0``+P,``.P!````````
M`````*X!``#M`@``K@(``.0```!,`P``1@```*,#```!!0```"`H)7,@9&%Y
M<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI
M`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"5D("5S(&%N9"`E<P`E
M9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@
M2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E
M<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@
M;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D
M<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S
M:VQI<W0`)7,Z("5S`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@
M)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@
M1F]R;6%T`#(T(&AO=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E
M9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!0
M1U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R
M<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S
M8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D
M:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C
M8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D
M`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R
M93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W
M('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D
M<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`
M061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I
M80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E
M9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S
M:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E
M($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E
M($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N
M871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`
M06YT:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,
M:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R
M97,`07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN
M9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E
M('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E
M<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#
M24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S
M:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L
M=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E
M<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I
M;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!
M=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F
M86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S
M97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!
M=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K
M9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT
M:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L:6YE
M`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`
M0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F
M;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`
M0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O
M<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U
M=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET
M;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;&T`0V%M
M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!2
M97!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E
M`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R
M`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@
M82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I
M<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E
M<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@
M;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L
M96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#
M;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I
M;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O
M;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L
M;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN
M('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`
M0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)E("5S`$-O
M;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O
M:VEE`$-O<'D`0V]P>2!S96QE8W1I;VX`0V]S=&$@4FEC80!#;W1E(&0G279O
M:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N
M;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-R
M96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R>0!#
M;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``
M0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G
M;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H
M2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A
M:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R
M964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`
M1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$
M96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@
M261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET
M>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R96-A
M<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C
M8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A
M:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$
M;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO860@
M)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%8W5A9&]R
M`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%
M9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@
M;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO
M;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL
M($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I
M=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T
M>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N
M(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B
M;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E
M($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W
M:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O
M<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT
M97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA`$5T
M:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T
M960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E
M<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO
M860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A
M:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N
M;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N
M`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W
M(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I
M<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&
M871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK
M93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX
M`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE
M<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@
M=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I
M;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP
M`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO
M<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S
M`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@
M<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[
M(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B
M;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R
M='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S
M`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H
M($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R
M:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@
M36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R
M;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`
M1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A
M<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N
M<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A
M+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S
M('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A
M8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@
M;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O
M=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R9"!)
M<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U.2TX
M+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI
M<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG
M:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO
M;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E
M9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E
M<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F
M('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C
M8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN
M=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X
M=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,
M('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I
M979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O
M2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R
M:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H
M97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@
M>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@
M87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D
M96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO
M;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA
M8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)
M8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X
M=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R
M<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@
M;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@
M8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`
M26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E
M(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T
M97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?
M<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!)
M;F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@
M=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S
M`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@
M;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T
M97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R
M97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES
M;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA
M;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE
M<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`
M2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K
M:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E
M:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E
M871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y
M(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G
M<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M
M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E
M;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@475A
M<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,87EO
M=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`3&5F
M="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!
M<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI
M9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG
M:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@
M4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I
M;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E
M('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T
M("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES
M="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(
M96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I
M8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z
M(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G
M:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O
M<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I
M;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,
M;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB
M;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@
M9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA
M=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI
M;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI
M`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``
M36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`
M36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L
M;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@
M=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE
M9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE
M<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA
M+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E
M;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI
M<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC
M871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I
M;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D
M=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N
M=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO
M<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U;FYY
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N
M(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O<G1A
M;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L
M86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2
M979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E
M(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E
M(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@
M0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@
M*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI`$YE
M=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`3FEG
M97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U
M<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL
M86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H
M('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P
M;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U
M=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A
M9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C
M;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I
M;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI
M960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T
M:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C
M:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T
M=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R
M>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T
M;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N
M`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A
M:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.
M;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E
M9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y
M;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.
M;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S
M=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.
M;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F
M(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D
M(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T
M`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`
M3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E
M9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A
M=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R
M<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H
M96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET
M;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A
M>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0
M971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`
M4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E
M(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT
M.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES
M(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L
M96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S
M92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A
M;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N
M=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E
M(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U
M<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C
M871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`
M4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES
M('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)
M34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F
M<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R
M969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F
M;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U
M<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O
M=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y
M`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@
M=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I
M`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A
M:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&
M;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E
M("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@
M<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F
M<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I
M97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO
M=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T
M(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H
M90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U
M<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"!&:65L9`!297-E
M=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`
M4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H
M="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE
M`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F
M<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R
M:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3
M879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`
M4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D
M871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G
M86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!3
M97)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A
M;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y
M8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@
M:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF
M9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L
M>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I
M;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I
M;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A
M<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B
M;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U
M<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W
M97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I
M9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R
M82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM
M`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO
M=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W
M97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W
M(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI
M80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A
M9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM
M,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N
M9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3
M<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@
M8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T
M87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3
M=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T
M<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE
M(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S`%-U
M8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@
M<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG
M=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`
M4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES
M92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP
M=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-
M87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O
M<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R
M;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN
M:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4
M:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG
M('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N
M;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE
M(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H
M92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H
M92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US
M('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@
M=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H
M="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@
M9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@
M>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H
M870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N
M9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0
M;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F
M=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO
M;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R
M>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S
M('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I
M<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D
M(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@
M=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q
M=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@
M<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET
M<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H
M92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T
M('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S
M(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E
M96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N
M`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@
M=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4
M:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@
M<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4
M:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@
M87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@
M=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M
M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E
M9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO
M("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X
M:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A
M<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI
M;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@
M;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F
M;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB
M=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0
M('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%0
M20!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@
M4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY
M('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C
M8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I
M;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O
M;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@
M9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T
M(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@
M9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@
M8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'
M<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL
M(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO
M;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I
M;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R
M:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R
M(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4
M:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L
M=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL
M960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM
M90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I
M;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T
M(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O
M<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G
M9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4
M;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD
M(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI
M<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S
M($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X
M.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E
M<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T
M:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O
M("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@
M=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N
M`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93
M(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@
M=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(')E
M8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL
M<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE
M('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E
M<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E
M9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O
M;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N
M86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`
M56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@
M=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C
M=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C
M86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F
M;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN
M:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@
M=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N
M<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E
M("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A
M9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE
M('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB
M97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L=65S
M('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E
M<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E
M;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T
M:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI
M9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@
M86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD
M<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I
M<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)
M3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E
M<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@M4F5F`%@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E9
M60!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO
M=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S
M=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT:6-A
M=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I
M;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE
M(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U
M<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9
M;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L
M:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S
M('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E
M9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S
M=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O
M<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K
M('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`
M7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA
M9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN
M:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3
M971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K
M`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!F86QL:6YG`&9I;&4`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E
M;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A<W-W
M;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L
M96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@
M2&]R9&5V,RXP+C0*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH
M;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K
M,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3`V+3(X(#$T.C0X*S`S,#`*
M3&%S="U4<F%N<VQA=&]R.B!!=71O;6%T:6-A;&QY(&=E;F5R871E9`I,86YG
M=6%G92U496%M.B!I,3AN0&QI<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ
M(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X
M-3DM.0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&
M;W)M<SH@;G!L=7)A;',],3L@<&QU<F%L/3`["@`@*"5S(&?\;B#V;F-E*0`H
M17)I_FEM($%N86AT87+]("5S*0`@*"5S(&?\;F1E*0`@*&)U9_QN*0`@*'EA
M<OUN*0`@*&3\;BD`(&1E*&1A*2``)60@)7,@=F4@)7,`)60M9_QN;/QK(&AA
M=F$@=&%H;6EN:0`E<R`M($)I;&1I<FEM`"5S(%!A<FUA:R#=>FD`)7,@2T(`
M)7,@0F%K_6T@W?YL96UL97)I("T@3VYA>6QA;6$`)7,@07EA<FQA<@`E<R!'
M:7)I_@`E<R!!;FQA_FUA($MO_G5L;&%R_0`E<R!Z871E;B!V87(N`"5S(&1E
M("5S("5S`"5S(&ES=&5N;65K=&5D:7(N`"5S(&1A:VEK80`E<R!B=6QU;F%M
M863]+@`E<R`M("5S("\@)7,@`"5S($%D<F5S($1E9G1E<FD`)7,@5&%K=FEM
M`"5S($YO="!$969T97)I`"5S($?V<F5V($QI<W1E<VD`)7,Z("5S`"P@9OUR
M=/UN86S]("5S("5S`"P@9&7P:?YI;2`E<R`M/B`E<P`M+2!39><@+2T`,3(@
M4V%A=&QI:R!:86UA;B!":>=I;6D`,C0@4V%A=&QI:R!:86UA;B!":>=I;6D`
M,C0@<V%A=`!"=2#V8F5K(&GG:6X@=F5R:71A8F%N_2!S;VX@=7IA;G3]<_T@
M9V5R96MM96MT961I<BX`3VYU;&UA>B!B:7(@:&%T82!O;'7^='4`W6QE=&EY
M:2#^:69R96QE>65B:6QM96L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E
M:VUE:W1E9&ER+@#=;7IA;&%N;?W^(&EL971I>6D@9&_P<G5L=?!U;G4@<V'P
M;&%M86L@:>=I;B!01U`@8>?]:R!A;F%H=&%R_2!G97)E:VUE:W1E9&ER+@#=
M;&5T:6YI;B#^:69R97-I;FD@Y_9Z;65K(&GG:6X@8>?]:R!01U`@86YA:'1A
M<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E<F5K
M;65K=&5D:7(N`-UL971I>6D@:6UZ86QA;6%K(&GG:6X@8>?]:R!01U`@86YA
M:'1A<OTL]GIE;"!01U`@86YA:'1A<OT@=F4@9V7G:?X@=/QM8V5C:?!I(&=E
M<F5K;65K=&5D:7(N`-UL971I;FEN(/YI9G)E<VEN:2#G]GIM96L@:>=I;B!A
MY_UK(%,O34E-12!A;F%H=&%R_2P@]GIE;"!3+TU)344@86YA:'1A<OT@=F4@
M9V7G:?X@=/QM8V5C:?!I(&=E<F5K;65K=&5D:7(N`-UL971I>6D@:6UZ86QA
M;6%K(&GG:6X@8>?]:R!3+TU)344@86YA:'1A<OTL(/9Z96P@4R]-24U%(&%N
M86AT87+]('9E(&=EYVG^('3\;6-E8VGP:2!G97)E:VUE:W1E9&ER+@#=;&5T
M:7EI(/YI9G)E;&5Y96)I;&UE:R!IYVEN(&'G_6L@4TU)344@86YA:'1A<OT@
M9V5R96MM96MT961I<BX`UM8@66'P;75R`-;6(%-A\&YA:P#6UB!(869I9B!+
M87(`UM8OUE,`05!)($E$`$3\>F5N;&5Y:6-I(&AA:VO];F1A`$AA:VO];F1A
M+BXN+@!%;F%L=`!/<G1A>6$`5D93(&1I>FEN:2!Y87)A=/UR:V5N(&5R:?YI
M;2!E;F=E;&QE;F1I+@!61E,@9&EZ:6YI('EA<F%T_6S]<FME;B!E<FG^:6T@
M96YG96QL96YD:2X`2&5S87`@4&%R86QO<_T`2&5S87`@1&]N9'5R=6QD=2X`
M2&5S87!L86[]>6]R`$5K;&4`06QT($=R=7`@14ML90!!;'0@W7II;B!%2VQE
M`$)U<F%Y82!%:VQE.@!996YI($=R=7`@16ML90!996YI(-UZ:6X@16ML90!9
M96YI(&MU;&QA;OUC_2!E:VQE.@!+;VQO;B!%:VQE`%EE;FD@_'EE(&5K;&4`
MW6MI;&D@16ML90`E<R!-96[\<_QN_"!-;WII;&QA($ME;F%R(,=U8G7P=2!/
M;&%R86L@16ML90!!9')E<R!D969T97)I;F4@96ML93H`061R97,@9&5F=&5R
M:6UE(&5K;&4`2W5L;&%N_6/]($5K;&4`2W5L;&%N_6/](&5K;&5M92!S9>=I
M;&5M97H@:_UL_6YD_2X`061R97,`061R97,@1&5F=&5R:0!9]FYE=&EM+2U$
M:?!E<B!K=6QL86[];&%R(&GG:6X@:7II;FQE<FD@8F5L:7)L97EI;@!9]FYE
M=&EM`$%D<P!!9F=A;FES=&%N`$%R;F%V=71L=6L`0V5Z87EI<@#6=&5K:2!A
M9`!(:7IA;&$`2&EZ86QA;6%K.@!4_&W\`%3\;2!$;_!R=6QA;FW]_B!+=6QL
M86[]8_UL87(`5/QM($=R=7!L87(`5/QM(-UZ:6YL97(`5/QM(&3V<G0@>?QZ
M`,=O:VQU(&%D<F5S;&5R92!I>FEN('9E<@!3_7)A;&%N;?W^(&QI<W1E('3\
M<OQN_"!A>6%R;&%M87EA(&EZ:6X@=F5R:6QS:6X@;6D_`%IA=&5N('9A<@#6
M=&5K:2!)35-0($=I<FG^:0#6=&5K:2!)35-0(%!A<F]L87/]`-9T96MI($E-
M4U`@2W5L;&%N_6/]($%D_0#6=&5K:2!E;&5K=')O;FEK('!O<W1A(&%D<F5S
M:0#6=&5K:2!T87-L86ML87(`UG1E:VD@;65T:6XZ`$%M97)I:V%N(%-A;6]A
M`$=EYV5R<VEZ(&1E\&5R(&)E;&ER=&EL9&DN`$%N9&]R80!!;F=O;&$`06YG
M=6EL;&$`06YO;FEM(%!R;WAY`$-E=F%P`$%N=&%R=&EK80!!;G1I9W5A('9E
M($)A<F)U9&$`57EG=6QA;6$`57EG=6QA;6$@3&ES=&5S:0!5>6=U;&%M82!(
M87K]<@!!;'0@<&%Y;&'^_6UL87)A('5Y9W5L80!/;F%Y;&$`66%K;&'^_6L@
M0F]Y=70`3FES86X`07)A<.=A("A7:6YD;W=S+3$R-38I`$)E;&=E;&EK($1O
M<WEA($)U>75T=0!"96QG96QI:R!!9/T`)7,@:>=I;B!G:7)I_B!I<W1E\&EN
M:2!K86QD_7)M86L@:7-T961I\&EN>F4@96UI;B!M:7-I;FEZ/P!!<FIA;G1I
M;@!%<FUE;FES=&%N`$5R;65N:6-E("A!4DU30TE)+3@I`%-A;F%T`$%R=6)A
M`$%S8V5N<VEO;B!!9&%L87+]`$%S8VEI(%-A;F%T_0!!<WEA+U!A<VEF:6L@
M0O9L9V5S:0!"86O];2!I_FQE;6QE<FEN9&5N(/9N8V4@9&_P<G5L86UA('-O
M<G5L<W5N(&UU/P!!=&%M82!+;VQO;FQA<OT`5F%R(&]L;6%Y86X@8FER(&=R
M=6)U('-I;&UE(&=I<FG^:6UI+@!687(@;VQM87EA;B!B:7(@:7IN:2!S:6QM
M92!G:7)I_FEM:2X`5F%R(&]L;6%Y86X@8FER(&=R=6)U(&3\>F5N;&5M92!G
M:7)I_FEM:2X`5F%R(&]L;6%Y86X@8FER('!A>6QA_OUM_2!D_'IE;FQE;64@
M9VER:?YI;6DN`-9Z;FET96QI:VQE<@!!\'5S=&]S`$%V=7-T=7)A;'EA`$%V
M=7-T=7)Y80!!=71H7V-Y<G-Q;#H@W7-T96YE;B!I;6%P('5Z871A=/US_2!B
M=6QU;F%M863]+@!!=71H7V-Y<G5S.B#=<W1E;F5N('EE=&5N96ML97)E('-A
M:&EP(&1E\&EL+@!!=71H7V-Y<G5S.B#=<W1E;F5N(&EM87`@=7IA;G3]<_T@
M8G5L=6YA;6%D_2X`075T:%]F='`Z(-US=&5N96X@1E10('5Z86YT_7/](&)U
M;'5N86UA9/TN(%!(4"=Y:2`M+65N86)L92UF='`@<W=I=&-H(&1E\&G^=&ER
M9V5S:7EL92!D97)L97EI;BX`075T:%]I;6%P.B#=<W1E;F5N($E-05`@=7IA
M;G3]<_T@8G5L=6YA;6%D_2X`075T:%]K<F(U.B#=<W1E;F5N(&MR8C4@=7IA
M;G3]<_T@8G5L=6YA;6%D_2X`075T:%]L9&%P.B#=<W1E;F5N($Q$05`@=7IA
M;G3]<_T@8G5L=6YA;6%D_2X`075T:%]I;6%P.B`E<R!K=6QL86[]8_US_2!E
M:VQE;F5M961I+B!3=6YU8W4Z(`!!=71H7VQD87`Z("5S(&MU;&QA;OUC_7/]
M('-I;&EN96UE9&D`075T:%]L9&%P.B`E<R!K=6QL86[]8_US_2!G_&YC96QL
M96YE;65D:0!!=71H7VUC86PZ(-US=&5N96X@34-!3"!U>F%N=/US_2!B=6QU
M;F%M863]+@!!=71H7W-M8F%U=&@Z(-US=&5N96X@<VUB875T:"!U>F%N=/US
M_2!B=6QU;F%M863]+@!$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4N`$1O\')U
M;&%M82!B8?YA<OUS_7H@;VQD=2X@)7,`1&_P<G5L86UA(%)!1$E54R!S=6YU
M8W5S=2!T87)A9OUN9&%N(&=E<FD@YV5V<FEL9&DN`$944"!S=6YU8W5S=6YA
M(&1O\')U;&%M82!B8?YA<OUS_7H@;VQD=2X`2W5L;&%N_6S]<B!A;&%N;&%R
M.@!!>F5R8F%Y8V%N`$)/1D@@0>?]:VQA;6%L87+]`$%R=&%L86X`07)T86QA
M;B!296YG:0!+]G3\(&ME<F)E<F]S('!A<F]L87/]+@!+]G3\(&ME<F)E<F]S
M(&MU;&QA;OUC_2!A9/TN`$)A:&%M86QA<@!"86AR97EN`$)A;'3]:R`H25-/
M+3@X-3DM,3,I`$)A;F=L861E_@!"87)B861O<P!486)A;B#G:7IG:7-I`$)E
M>6%Z(%)U<WEA`$)E;.=I:V$`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N
M`$1O\'5M9_QN_`!5>6=U;&%M82`B)7,B('-A:&EP(&]L9'7P=2`B)7,B(/9B
M9?!I(&)U;'5N86UA9/TN`-9B96L@07EA<FQA<OT`UF)E:R!4_'+\`$MO>74`
M0F]L:79Y80!997(@W6UL97)I`%/];OUR`%/];OUR($MA;/UN;/WP_3H`4_UN
M_7)L87(`0F]S;F$@2&5R<V5K`$AE<B!):VES:0!";W1S=F%N80!!;'0`0F]U
M=F5T($%D86QA<OT`0G)E>FEL>6$`0G)I=&%N>6$@2&EN="!/:WEA;G5S=2!"
M]FQG97-I`$)R=6YE:0!"=6QG87)I<W1A;@!-861D92#=;6QI($QI<W1E`$)U
M<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4E,`0U),($1A\/UT_6T@3F]K=&%L
M87+]`%](_&-R92#6>F5L;&EK;&5R:2XN+@!486MV:6T`1'5R9W5N`$MA;6)O
MYWEA`$MA;65R=6X`4&%R;VQA(/9Z9&5V:6YI;6QI(&]L87)A:R!S_6;]<FQA
M;F%M86UA:W1A9/UR+"!L_'1F96X@>?9N971I8VEN:7IL92!G]G+\_OQN+@!)
M34%0('-U;G5C=7-U;F$@8F'P;&%N_6QA9/TZ("5S`$MA;F%D80#=<'1A;`!3
M;W)U;B!287!O<G5N=2#=<'1A;"!%=``B)7,B(&1O<WEA<_T@<VEL:6YE;65D
M:2X`1V7G:6-I(&1I>FEN(&)U;'5N86UA9/TN`"=T87)G971&:6QE)R!D9?!I
M_G1I<F=E<VD@;VQM861A;B!D979A;2!E9&EL96UE>BX`(B5S(B!D:7II;FD@
M:V%L9/UR_6QA;6%D_2X`2V%L9/UR_6QA;6%D_2`L)60@86QT('EA</T@=F%R
M+@!996YI9&5N(&3\>F5N;&5M961I+"!Y96YI9&5N(&3\>F5N;&5M92!IYVEN
M('-A\&QA;F%N(&MA>?UT;&%R_6X@<V%Y_7/](&EL92!D97!O;&%N;?W^(&]L
M86YL87+];B!S87G]<_T@9?YL9?YM96UE:W1E9&ER+@!"96QI<G1I;&UI_B!N
M=6UA<F%Y82!I;&5T:2!Y]FYL96YD:7)I;&5M961I+@!#87!E(%9E<F1E`$)A
M_FS]:P!+871E9V]R:6QE<B!V92!%=&EK971L97(`0V%Y;6%N($%D86QA<OT`
M0V5P(%1E;&5F;VYU`$C\8W)E(-9Z96QL:6ML97)I`$C\8W)E('EA<W3]:VQA
M;6%S_3H`2/QC<F4@UGIE;&QI:VQE<FD`2/QC<F4@0F_^;'5K;&%R_3H`0V5P
M(%1E;&5F;VYU`$ME;'1I:R`H25-/+3@X-3DM,30I`$]R=&$`3W)T82!!9G)I
M:V$@0W5M:'5R:7EE=&D`3W)T82!!=G)U<&$@*$E33RTX.#4Y+3(I`$]N87D@
M0F5L9V5S:2!!>7+];G3];&%R_0!/;F%Y($)E;&=E<VD@2W5R86QL87+]`,=A
M9`!$9?!I_G1I<@#=;G-A;FQA<OUN('-I>F1E;B!G96QE;B!E;&5K=')O;FEK
M('!O<W1A;&%R_2!O:W5R:V5N('9E(&-E=F%P;&%R:V5N(&?V<F3\:VQE<FD@
M860@=F4@861R97-I;FEZ:2!D9?!I_G1I<FEN+@!+87)A:W1E<@!"8?!L86YT
M_7G]($1E7VYE=&QE+BXN`-YI;&D`QVEN`$)A<VET;&7^=&ER:6QM:?X@QVEN
M8V4@*$=",C,Q,BD`1V5L96YE:W-E;"#':6YC92`H0FEG-2D`4&%R;VQA('-E
MYVEN`$MU;&QA;OUC_2!A9/T@<V7G:6X`5&%R:6AL97)I;B!N87/];"!G]G-T
M97)I;&5C9?!I;FD@<V7G:6XZ`$QI<W1E($)IYV5M(%3\<OQN_"!39>=I;B`H
M<_UR86QA;FW]_B!L:7-T96QE<B!IYVEN*0!#:')I<W1M87,@061A;&%S_0!3
M_6[]9B!T86[];?T@8G5L=6YA;6%D_3HE<P!496UI>FQE`$U33V9F:6-E(&)I
MYVEM(&EM;&5R:6YI('1E;6EZ;&4`2W5L;&%N_6/]>?T@=&5M:7IL93H@)7,`
M2W5L;&%N_6/]('1E;6EZ;&4`2W5L;&%N_6/]('9E<FES:2!T96UI>FQE`$1E
M=F%M(&5T;65K(&GG:6X@=/UK;&%Y_6X`2%144"!Y;VQU>6QA($-L:6-K871E
M;&P`4&5N8V5R97EI($MA<&%T`$)U;'5T;&%R`$)U;'5T;'4`0V]C;W,@061A
M;&%R_0!+96YA<B#'=6)U\'5N=2!$87)A;'0`1&%R86QT_6QM_?X@4_UN_7)L
M87(`2V]L;VUB:7EA`%)E;FL`4F5N:R!39>=I8VD`4F5N:R!39>=I;6D`2V]L
M;VYL87(Z`$MO;&]N($)A_FS]:VQA<OT`2V]M:6L`2V]M=70`2V]M=70@2V%B
M=?!U`$'G_6ML86UA`$]R=&%K($%D_0!#;VUO<F]S`-YI<FME=`!":6QG:7-A
M>6%R;&%R`$MO_G5L;&%R`%EA</UL86YD_7)M82!&87)K;&%R_0!987#];&%N
M9/UR.B5S`%!A<F%L;WG]($1O\')U;&$`2V]N9V\`1&5M;VMR871I:R!+;VYG
M;R!#=6UH=7)I>65T:0!"8?!L86YT_2!B8?YA<OUS_7H@;VQD=2X`0F'P;&%N
M=/T@8F'^87+]<_UZ(&]L9'4Z`$'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A
M\&QA;G3](')E9&1E9&EL9&DN`$'G_6L@86YA:'1A<B!S=6YU8W5S=6YA(&)A
M\&QA;G3](')E9&1E9&EL9&DN(%-E8F5B.B`E<R`H)7,I`$944"!S=6YU8W5N
M82!B8?!L86YT_2!B8?YA<OUS_7H@;VQD=2X`W6QE=&G^:6T@;F]K=&%L87+]
M(&)A_F%R_7EL82!A9')E<R!D969T97)I;FEZ92!E:VQE;F1I+@!$979A;0!#
M;V]K($%D86QA<OT`QV5R97H`2V]P>6%L80!39>=I;6D@2V]P>6%L80!+;W-T
M82!2:6MA`$-O=&4@9"=)=F]I<F4`W6QE=&D@4$=0(&EL92#^:69R96QE;F5M
M961I+@#=;&5T:2!01U`@:6QE(&EM>F%L86YA;6%D_2X`W6QE=&D@4R]-24U%
M(&EL92!S:69R96QE;F5M961I+@#=;&5T:2!3+TU)344@:6QE(&EM>F%L86YA
M;6%D_2X`W6QE=&G^:6T@;F]K=&%S_2!E:VQE;F5M961I+B`E<P!,1$%0('-U
M;G5C=7-U;F$@8F'P;&%N_6QA;6%D_2X`0F%K:7EE(&1E;F5T;&5N96UE9&DN
M("5S`$1A\/UT_6T@;&ES=&5S:2!Y87)A=/UL86UA9/TN("5S`%!'4"!V97)I
M<VEN:6X@_FEF<F5S:2#G]GK\;&5M961I+@!3+TU)344@=F5R:7-I;FEN(/YI
M9G)E<VD@Y_9Z_&QE;65D:2X`W6QE=&G^:6T@;F]K=&%S_2!S:6QI;F5M961I
M+B`E<P!$8?#]=/UM(&QI<W1E<VD@<VEL:6YE;65D:2X@)7,`06S]8_UN_6X@
M96QE:W1R;VYI:R!P;W-T82!A9')E<VD@8F5L:7)L96YE;65D:2X`061R97,@
M9&5F=&5R:2!T86UA;65N(&=E=&ER:6QE;65D:2X`1&'P_73];2!L:7-T97-I
M('1A;6%M96X@9V5T:7)I;&5M961I+@!$8?#]=/UM(&QI<W1E;&5R:6YI;B!L
M:7-T97-I('1A;6%M96X@9V5T:7)L96UE9&DN`$%N86AT87(@<W5N=6-U<W5N
M9&%N(&'G_6L@86YA:'1A<B!E9&EN:6QE;65D:2X`)7,@8>?];&%M863]+@!-
M86EN=&5N86YC95]487-K(&)I<FEM:2`E<R!AY_UL86UA9/TN`"5S(&]K=6YA
M;6%D_2X`W7-T96YE;B!K=6QL86YC_2!IYVEN('!A<F]L82!S_6;]<FQA;F%M
M863]+B!"87K]('EA9&$@=/QM(&%Y<OUN=/UL87(@9&_P<G4@9&7P:6PN(%EE
M;FED96X@9&5N97EI;B!Y861A(&1A:&$@9F%Z;&$@>6%R9/UM(&GG:6X@<VES
M=&5M('GV;F5T:6YI>FQE(&?V<OS^_&XN`$%#3"!E<FG^:6QE;65D:2X`061R
M97,@9&5F=&5R:6YE(&5R:?YI;&5M961I+B`E<P!$8?#]=/UM(&QI<W1E<VEN
M92!E<FG^:6QE;65D:2X@)7,`1&'P_73];2!L:7-T96QE<FEN92!E<FG^:6QE
M;65D:2X@)7,`4W5N=6-U;G5N('EE=&5N96ML97)I;F4@97)I_FEL96UE9&DN
M`%EA</UL86YD_7)M82!G97)I(&3V;F3\<OQL96UE9&DN+@`E<R!Y87#];&%N
M9/UR;6$@:V%Y9&5D:6QE;65D:2X`665D96L@8FER('EA</UL86YD_7)M82!K
M87ED961I;&5M961I+@!9961E:R!B:7(@>6%P_6QA;F3]<FUA(&MA>61E9&EL
M96UE9&DZ("5S`%EE9&5K('EA</UL86YD_7)M82!D;W-Y87/]("5S(&MA>61E
M9&EL96UE9&DN`%EA</UL86YD_7)M82!D;W-Y87/]("5S(&MA>61E9&EL96UE
M9&DN($)U(&1U<G5M9&$L(&MO9'4@=&5K<F%R("5S(&GG:6YE(&MA>61E=&UE
M:R!Y861A('1A:VEP(&5D96X@:V]D=2!E;"!I;&4@)7,@:>=I;F4@:V]P>6%L
M86UA:RP@<V7G96YE:VQE<FEN:2!K=6QL86YA8FEL:7)S:6YI>BX`3$1!4"!S
M=6YU8W5S=2!A<F%N86UA9/TN`-UL971I_FEM(&YO:W1A<_T@9_QN8V5L;&5N
M96UE9&DN("5S`$1A\/UT_6T@;&ES=&5S:2!G_&YC96QL96YE;65D:2X@)7,`
M36]Z:6QL82!K96YA<B#G=6)U\'4@8G5L=6YA;6%D_2X@2V5N87(@YW5B=?!U
M;G5N(&'G_6L@;VQD=?!U;F1A;B!E;6EN(&]L=6XN`%-A>?UL;?W^(&UE=&EN
M`-QL:V4`1&5R<VQE<@!987)A=`!"8?!L86YT_2!Y87)A=`!996YI(%EA<F%T
M`$%L="!D:7II;B!Y87)A=`!987)A=/UC_2#=>FEN;&5R:0!+<F5D:2!K87)T
M(&YU;6%R87/]`$C]<G9A=&ES=&%N`$O\8F$`WG4@06YD86MI(%IA;6%N`-YU
M(&%N9&%K:2!54DP`WG4@06YD86MI($AA=F$@1'5R=6UU`-YU($%N9&%K:2#>
M87)T;&%R.@!9_'+\<FS\:W1E:VD@<VET:6P`)7,@92!G:7)I_G1E(.=A;/W^
M86-A:R!G]G)E=FQE<FD@:VG^:7-E;&QE_G1I<FEN`$ME<P#>9>=I;&D@;VQA
M;FQA<OT@:V5S`$O]8G+]<P!+:7)I;"`H2T])."U2*0!+:7)I;"`H5VEN9&]W
M<RTQ,C4Q*0!+:7)I;"]5:W)A>6YA("A+3TDX+54I`,=E:R!#=6UH=7)I>65T
M:0!'1P!'_&YL_&L`5F5R:2!!\&%C_2!487)A>?UC_7/]`%1A<FEH`$=E;&G^
M(%1A<FEH:0!487)I:"!39>=I;6D`1_QN`$M?;VQO;G4@4VEL`$%R86S]:P!/
M;F1A;/UK('-A>?UL87(`1VER:6YT:7EI($%Z86QT`-9N('1A;OUM;/T`UFX@
M5&%N_6UL_2!296YK`-9N(%1A;OUM;/T@2VEM;&EK`%1A;OUM;&%R`%-I;`!'
M<G5P(%-I;`#=>FEN(%-I;`#=;&5T:6QE<FD@<VEL('9E('1E;6EZ;&4`2/QC
M<F4@4VEL`$MO;&]N(%-I;`!687)O;&%N(/9T96MI('1A<VQA\/T@<VEL`%-A
M=/UR_2!S:6P`4V7G:6QM:?X@:VEM;&GP:2!S:6P`WG4@86YD86MI(&MO;&]N
M=2!S:6P`WG4@86YD86MI('-A=/UR_2!S:6P`5&5S;&EM('IA;6%N_0!$86YI
M;6%R:V$`4V]R=6YU(%1A;OUM;&%Y_6X`0>?]:VQA;6$`07ER_6YT_6QA<B`H
M07EN_2!Z86UA;F1A($AO<F1E)W5N(&?\;FS\:R!D;W-Y87/];OUN(&GG:6YD
M92DZ`$%Y<OUN=/UL87(@>?9N971I8VD@:>=I;B!G_&YL_&L@;VQA<F%K(&MA
M>61E9&EL9&DN`$=E;&G^:6T`3F5M($UI:W1A<OT`4V]N('-A871T96MI(&YE
M;2!M:6MT87+].B``3F5M(&UI:W1A<OTZ(`!3;VQD86X@<V'P82!Y]FYL_`!3
M8?!D86X@<V]L82!Y]FYL_`!$:7II;@`R-"!S86%T;&EK('IA;6%N(&W](&?V
M<W1E<FEL<VEN/P!']G+\;G3\;&5M92!39>=E;F5K;&5R:0!(879A('1A:&UI
M;FEN:2!G]G+\;G3\;&4@*%1!1BD`1_9R_&YT_&QE;64@0FGG:6UI`$3\>F5N
M($)I;&1I<FEM:0!#:6)U=&D`4VEL;65Y:6X`;6%I;G1E;F%N8V4N<&AP(&1O
M<WEA<_UN82!D;_!R=61A;B!E<FG^;65Y:6XN`-UL:R!S873]<B!A;&%N(&%D
M;&%R_6[](&GG97)I>6]R(&UU/R!%=F5T(&ES92!B=2!K=71U>74@<V7G:6XZ
M`$1O;6EN:6L`1&]M:6YI:R!#=6UH=7)I>65T:0#=;F1I<@`E<R#=;F1I<@!/
M;'7^='5R=6QA;B!Y87#];&%N9/UR;6%Y_2!02%`@8F5T:?!I(&]L87)A:R!I
M;F1I<BX`0?YA\/T@8>?];/UR(&QI<W1E`-UL8>=L87(`12U0;W-T80!%4E(`
M16MV871O<@!$_'IE;FQE`$)L;VL@1/QZ96YL90!'<G5P($3\>F5N;&4`W7II
M;B!$_'IE;FQE`-UZ:6YL97)I($3\>F5N;&4`)7,@W>=I;B#=>FEN;&5R:2!$
M_'IE;FQE`%-EYV5N96ML97)I(&3\>F5N;&4Z`"5S(&GG:6X@:7II;FQE<FD@
M9/QZ96YL90!%\&ET:6T`3?US_7(`16P@4V%L=F%D;W(`UO!E+BXN`$5M`$5L
M96MT<F]N:6L@4&]S=&$`16QE:W1R;VYI:R!0;W-T82!!9')E<VD`16QE:W1R
M;VYI:R!P;W-T82!A<W)E<VQE<FD@9?YL9?YM96QI+@!/;F%Y;/T@96QE:W1R
M;VYI:R!P;W-T80!$=7EG=2!S:6UG97)L97)I`$)O_B!I;&5T:2X`0F_^('-O
M;G7G+@!";_X@87)A;6$@=&5R:6UL97)I`$9O=&_P<F%F($=A;&5R:7-I;F1E
M;B!M971I;FQE<FEN(&GG97)I<VEN92!G]G+\;G3\(&5K;&5M92!E=&MI;FQE
M_G1I<FEL<VEN(&UI/P!38?`@=/UK(&GG97)I:R!M96[\<_P@971K:6YL9?YT
M:7)I;'-I;B!M:3\`0FET:?X@>?UL_0!$_'IE;FQE>6EC:7EI($=E;FG^;&5T
M`%!A<F]L86[]>OT@<_UF_7)L86UA:R!I<W1E9&GP:6YI>F1E('-O<G5L;6%K
M(/QZ97)E(&)I<B!G_'9E;FQI:R!S;W)U<W4@9VER:6XL(-9R+B`G179C:6P@
M:&%Y=F%N_6[]>OUN(&%D_2!N961I<C\G.@!']G+\;G3\(&%D<F5S:6YI(&)U
M<F%Y82!G:7)I;@!%:W9A=&]R($=I;F5S:0!%<FET<F4`2&%T80!%;&5T<F]N
M:6L@<&]S=&$@9/9N9&5R;65D92!H871A+@!%<W1O;GEA`$5T:7EO<'EA`$5T
M;FEK`$%V<G5P80!(97(@,34@9&%K:6MA`$AE<B`R(&1A:VEK80!(97(@,S`@
M<V%N:7EE`$AE<B`U(&1A:VEK80!(97(@1VER:?YT90!(97(@>6%R_6T@<V%A
M=`!(97(@9&%K:6MA`-9R;F5K(&1E\&5R;&5R.@#'86S]_G3]<@!'96YI_FQE
M=`!+96YA<B#'=6)U\'5N=2!'96YI_FQE=``G*2<@0F5K;&5N:7EO<@!3861E
M(&ME;&EM92!V97EA(&%L_6YT_2!A<F%M82!T97)I;6D@8F5K;&5N:7EO<@!'
M9>=E<FQI;&EK(%-O;B!487)I:&D`W'-T`-9N($%L86X@4F5N9VD`07EA<FQA
M<B!IYVEN($944"!Y_&ML96UE<VD`5&5R8VEH;&5R:6X@9V5T:6QM97-I(&)A
M_F%R_7/]>BX`3$1!4"!S=6YU8W5S=6YA(&)A\&QA;G3](&)A_F%R_7/]>BX`
M4TU"('-U;G5C=7-U;F$@8F'P;&%N=/T@8F'^87+]<_UZ+@`B)7,B(&MO;G5M
M=6YD86X@:V]P>6%L86UA(&)A_F%R_7/]>BX`(B5S(B!K;VYU;75N82!K;W!Y
M86QA;6$@8F'^87+]<_UZ+@!996YI(%-!4TP@8F'P;&%N=/US_2!O;'7^='5R
M=6QA;6%D_2X`(B5S(B!K;VYU;75N82!T8?[];6$@8F'^87+]<_UZ+@!5>6=U
M;B!(879A`$9A;&ML86YD($%D86QA<OT@*$UA;'9I;F$I`$9A<F]E($%D86QA
M<OT`3VYU;&UA>B!(871A.@!&86MS`-YU8F%T`$AI<W-E9&EL:7EO<@!(:7-S
M961I;&EY;W(Z(`!(869I9B!38?!A;F%K`$AA9FEF($MA<B!38?!A;F'P_0!!
M;&%N(&UA=')I<VD`1FEJ:0!$;W-Y82!387G]<_TZ("5S(&1O<WEA`$1O<WEA
M(%-A>?US_3H@)7,@9&]S>6$`1&]S>6$@6?9N971I8VES:0!$;W-Y82!!9/T`
M1&]S>6$@<V7G:6UI`$1O<WEA('G\:VQE;64`1&]S>6$@>?QK;&5M92!D97-T
M96ML96YM:7EO<BX`4_QZ9V7G;&5R`$9I;FQA;F1I>6$`W6QK(%EA<OT`W6QK
M(,=E>7)E:P!/<F%N_2!S86)I=&QE`,=E=FER`$MA>6%N`%-I<P`E<R!D:7II
M;FD@>6]K`%EA>OT@4F5N9VD`665M96L`1_9R_&YT_&QE<FD@9&5S=&5K;&5M
M97EE;B!T87)A>?UC_6QA<B!IYVEN`%1A:&UI;B`H5$%&*0!486AM:6X@1_QN
M;&5R:2`H3F]T.B!'97)I(&3V;OQL96-E:VQE<B!H96T@9_QN(&AE;2!G96-E
M(&]L87)A:R!D]F[\;&5C96L[("EB_'G\:R!B:7(@<V%Y_2!G96YI_B!B:7(@
M]F)E:VQE('-O;G7G;&%N86-A:W3]<BD`4&%R;VQA;OUZ_2!M_2!U;G1T=6YU
M>C\`1F]R;6QA<@!$97EI_@!$97EI_B!T_'+\`$1E>6G^;&5R`$1E>6G^;&5R
M(#(`1F]R=6UL87(`6?9N;&5N9&ER;65L97(`0W4`QV5RYV5V96QE<@!&<F%N
M<V$`1G)A;G-A+"!-97)T;W!O;&ET86X`1G)A;G/]>B!'=7EA;F%S_0!&<F%N
M<_UZ(%!O;&EN97IY87/]`$9R86YS_7H@1_QN97D@0O9L9V5S:0!+:6UD96X`
M2VEM9&5N`%1A;2!"971I;6QE;64`1&]L=6YA>0!!Y_UK($%D`$=A8F]N`$?V
M<OQN=/QL97)I;B!A;/UN86-A\/T@9V%L97)I`$=A;&5R:3H`1V%M8FEY80`E
M<R!987#];&%N9/UR;6%S_6[]($]L=?YT=7(`3VQU_G1U<G5L86X@2V]D`$?\
M<F-I<W1A;@!!;&UA;GEA`$=A;F$`0V5B96QI=&%R_6L`5F5R:6QE;B!!9`!'
M:70`1V]E9&5L`$=O;V=L92!!<F%M80!3:7EA:"!"97EA>@!9=6YA;FES=&%N
M`%EU;F%N8V$@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R96YA9&$`1W)U<"!9
M]FYE=&EM:0!'<G5P(&ES:6UL97)I(&1O;'4@;VQM86S]9/UR`$=R=7!L87(`
M1W5A9&%L=7``1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`2V]N=6L@W7II;FQE
M<FD`2V]N=6L@1&5F=&5R:0!':6YE`$=U:6YE($)I<W-A=0!'=7EA;F$`2%1-
M3`!(5$U,07)E82!S873]<F1A:VD@<V]N(&C\8W)E>6D@<VEL;65Y:2!R961D
M961I>6]R+@!(5$U,07)E82#G:7IE;&=E9&5K:2!S;VX@:V]L;VYU('-I;&UE
M>6D@<F5D9&5D:7EO<BX`2%1-3$%R96$@YVEZ96QG961E:VD@<V]N('-A=/UR
M_2!S:6QM97EI(')E9&1E9&EY;W(N`$A45%`@2VEM;&EK($1E;F5T:6UI(&)U
M;&%N86UA9/TN`$AA:71I`$AA<V@@06QG;W)I=&UA<_T`2&%F:68@4VES`$)A
M_FS]:P!(96%R9"!!9&%S_2!V92!-8T1O;F%L9"!!9&%L87+]`-UB<F%N:6-E
M("A)4T\M.#@U.2TX+4DI`%G\:W-E:VQI:P!987)D_6T`1/QZ96YL97EI8VD@
M:W5L;&%R86L@>6%R9/UM`%EA<F3];6/]`%EA<OUK_')E`$1O<WEA;OUN(&)A
M_FQA;F?]8_TZ(`!9_&MS96L`7T%N87-A>69A`%9A=&EK86X`06YA<V%Y9F$`
M178@061R97-I`$5V(%1E;&5F;VYU`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D
M90!(;W)D92]+;VQA8CH@0G4@;65S86H@:>=I;F1E(&=EYV5R<VEZ("5S(%A-
M3"!V97)I<VD@:6QE(&MA<O[];&'^_6QD_3H@)7,`2&]R9&4O2V]L86(Z("5S
M(&YE<VYE<VD@:6QE(&EL9VEL:2!B:7(@:6QE=&D@8G5L=6YA;6%D_0!(;W)D
M92]+;VQA8CH@)7,@=/QR_&YD92!H:><@8FER(&YE<VYE("5S(&UE<V%J_2!I
MYVEN9&4@>6]K+@!(;W)D92]+;VQA8CH@)7,@(B5S(B!B8?YA<OT@:6QE('-I
M;&EN9&D`2&]R9&4O2V]L86(Z($+\=/QN;&5M92!M;W1O<G4@)V1O;7AM;"<@
M4$A0('5Z86YT_7/];F$@:6AT:7EAYR!D=7EM86MT863]<@!(;W)D92]+;VQA
M8CH@)7,@;F5S;F5S:2!IYVEN('EE;FD@6$U,(&'P86/](&]L=?YT=7)U;&%M
M_7EO<@!(;W)D92]+;VQA8CH@4VEL:6YE;65D:2`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@)7,@=/QR_&YD96MI(&O]<_UM(&GG:6X@34E-12!)1"!B=6QU
M;F%M863]`$AO<F1E+TMO;&%B.B!%_FQE;F5M961I("5S("(E<R(Z("5S`%!A
M>6QA_OUM;&%R(&7^;&5N96UE9&DZ("5S`$)I;&EN;65Y96X@<&%Y;&'^_6T@
M(B5S(@!9871A>2#':7IG:0!9871A>2!Y87-T_6ML86UA`%EA=&%Y.@!"=7)A
M>6$@;F%S_6P@9V5L9&EN:7H_("A,_'1F96X@<F%P;W(@961I;B$I`$MAYR!A
M9&5T(&MO;&]N=2!B:7)L9?YT:7)M96L@:7-T:7EO<G-U;G5Z/P!+8><@86QA
M;B`H:V]L;VXI('9A<C\`2V'G(&%D970@<V%T_7+](&)I<FQE_G1I<FUE:R!I
M<W1I>6]R<W5N=7H_`$YE;0!.96TZ(`!-:7IA:.?];&%R`$UA8V%R:7-T86X`
M24U!4"!P;W-T82!K=71U<W4@;VQU_G1U<G5L86UA9/TZ("5S`$E-05`@<&]S
M=&$@:W5T=7-U('-I;&EN96UE9&DZ("5S`$E-05`@<&]S=&$@:W5T=7-U(&MO
M=&%S_2!O;'7^='5R=6QA;6%D_3H@)7,`25`@061R97-I`$E0(&%D<F5S:2!M
M979C=70@9&7P:6PN(`!)4"!!9')E<VD@:7II;B!V97)I;&5N($-)1%(@8FQO
M\'4@:>=I;F1E(&1E\&EL+@!)4"!K:6QI=&QE;64@:6AL86QI+@#6;E]C97EE
M(%-A=/UR(%EE<FQE_G1I<@#=>FQA;F1A`%-A9&5C92!3:6UG96QE<@`E<R!I
MYVEN('-I;6=E;&5R`$UE=&EN(&EL92!B:7)L:6MT92!S:6UG96QE<@!+:6UL
M:?!I;B!A9/TZ`$7P97(@9&_P<G4@9_9R_&YT_&QE;F5M:7EO<G-A+"!Y96YI
M('!E;F-E<F5D92!AYVUA:R!IYVEN('3]:VQA>?UN("5S+@!%\&5R($EN=&5R
M;F5T($5X<&QO<F5R(&EL92!S:6UG96QE<FD@9_9R96UI>6]R<V%N_7H@8G4@
M:W5T=7EU('-EYV5R96L@4$Y'('-A>61A;6S]\/UN_2!K87!A=&UA;OUZ(&=E
M<F5K:7(N`$?V<OQN=/QL97)I(&?V<F5M:7EO<B!F86MA="!B=2!M97-A:OT@
M9_9R96)I;&ER>6]R<V%N_7HL('G\:VQE;65K(&ES=&5D:?!I;FEZ(&?V<OQN
M=/P@=&%R87G]8_UN_7H@=&%R86;];F1A;B!G]G-T97)I;&5M96UE:W1E9&ER
M+@!']G+\;G3\(-9N:7IL96UE`$?V<OQN=/P@55),`$?V<OQN=/P@55),.@!3
M97)G:61E;B!G]G+\;G3\`%-E<F=I9&5N(&?V<OQN=/PZ`$?V<OQN=/P@>?QK
M;&5M96L`1_9R_&YT_&QE<@#=YV5R:2!!:W1A<BP@063];2`E9`#=YV5R:2!A
M:W1A<OUL86X@86QA;CH@)7,`W>=E<FD@86MT87+];&%N(&%L86YL87(Z`%-O
M;E]R87EA(%-A=/UR($5K;&4`66%N;/W^(&5Y;&5M(&MO9'4@9VER:6QD:2X`
M66%N;/W^(&MU;&QA;OUC_2!A9/T@=F4O=F5Y82!P87)O;&$N`%EA;FS]_B!K
M=6QL86[]8_T@863]('9E>6$@]G1E:VD@861R97,N665N:61E;B!D96YE>6EN
M('9E>6$@9&%H82!F87IL82!Y87)D_6T@:>=I;B!Y]FYE=&EC:6YI>FQE(&?V
M<OS^_&XN`$=I<FEN=&EY:2!!<G1T_7(`2&EN9&ES=&%N`$)I<F5Y<V5L($MU
M;&QA;OUC_6QA<@!%;F1O;F5Z>6$`0FEL9VD`0FEL9VD`4V]N<F%Y82!+;U]L
M;VX@16ML90!']G+\;G3\(%EE<FQE_G1I<@#':7IE;&=E(%EE<FQE_G1I<@!7
M96(@0F'P;&%N=/US_2!997)L9?YT:7(`UFYC97EE($MO;&]?;B!%:VQE`%EE
M;FD@:V]L;VYU(/YU(&%N9&%K:2!K;VQO;F1A;B!S;VYR82!Y97)L9?YT:7(`
M665N:2!K;VQO;G4@_G4@86YD86MI(&MO;&]N9&%N(/9N8V5Y92!Y97)L9?YT
M:7(`665N:2!S873]<OT@_G4@86YD86MI('-A=/UR9&%N('-O;G)A>6$@>65R
M;&7^=&ER`%EE;FD@<V%T_7+](/YU(&%N9&%K:2!S873]<F1A;B#V;F-E>64@
M>65R;&7^=&ER`%EE;FD@<&%R86=R86;](/YU(&%N9&%K:2!D_/#\;61E;B!S
M;VYR87EA('EE<FQE_G1I<@!996YI('!A<F%G<F%F_2#^=2!A;F1A:VD@9/SP
M_&UD96X@]FYC97EE('EE<FQE_G1I<@#6=&5K:2!T87-L86L@>65R;&7^=&ER
M`%EE;FD@8FER('!A<F%L;WG](&%L86)I;&5C9?!I;FEZ(&)I<B!E;&5K=')O
M;FEK('!O<W1A(&%D<F5S:2!G:7)I;CH`2/QC<F5Y:2!S;VYR87/];F$@>65R
M;&7^=&ER`$C\8W)E>6D@]FYC97-I;F4@>65R;&7^=&ER`$MO;&]N=2!S;VYR
M87/];F$@>65R;&7^=&ER`$MO;&]N=2#V;F-E<VEN92!Y97)L9?YT:7(`365S
M86H@9VER`%!A<F%G<F%F_2!S;VYR87/];F$@>65R;&7^=&ER`%!A<F%G<F%F
M_2#V;F-E<VEN92!Y97)L9?YT:7(`4V%T_7+]('-O;G)A<_UN82!Y97)L9?YT
M:7(`4V%T_7+](/9N8V5S:6YE('EE<FQE_G1I<@!'_'9E;FQI:R!S;W)U<W5N
M=6X@8V5V86+].@!']G+\;G3\>?P@665R;&7^=&ER+T1E\&G^=&ER`$)A\&QA
M;G3](%EE<FQE_G1I<B]$9?!I_G1I<@!$8?#]=/UM(&QI<W1E<VD@9_9N9&5R
M;65K(&GG:6X@>65T97)S:7H@:W)E9&DN`%EE=&5R<VEZ(&MR961I`%1A;7-A
M>?T`5&%M<V%Y_2!L:7-T97-I`$=EYV5R<VEZ(%5$2"X@*$MU;&QA;OUC_2!6
M97)I($)A_FS]:R!":6QG:7-I*0!'9>=E<G-I>B!U>6=U;&%M82X`1V7G97)S
M:7H@>?WP_6X@:VEM;&GP:2X`1V7G97)S:7H@=F5R:2!G]FYD97)I;&1I+@!'
M9>=E<G-I>B!T97-L:6T@861R97-I`$=EYV5R<VEZ(&1O<WEA(&)IYVEM:0!'
M9>=E<G-I>B!M<V=?='EP90!'9>=E<G-I>B!Y861A(&%T;&%N;?W^(&%P:5]I
M9`!'9>=E<G-I>B!Y861A(&%T;&%N;?W^(&1E\&G^=&ER9V5L97(`1V7G97)S
M:7H@_'-T(&EZ:6XN`$=EYV5R<VEZ(&EL971I_FEM(&MU<F%L;&%R_0!'9>=E
M<G-I>B!P87EL8?[];&%N(&YE<VYE`$=EYV5R<VEZ(&MA>6YA:R!A9')E<VDN
M`$=EYV5R<VEZ('5N:6-O9&4@=F5R:7-I+@!3=&]K`-UR86X@W7-L86T@0W5M
M:'5R:7EE=&D`27)A:P#=<FQA;F1A`$UA;B!!9&$@1&5V;&5T:0!986S]=/UL
M;?W^(&?V:R!G_'+\;'3\;/P@9OUR=/UN80#=<W)A:6P`Q_UK87)A;@#==&%L
M:6L`W71A;'EA`$IA;6%I:V$`3V-A:P!*87!O;GEA`$IA<&]N8V$@*$E33RTR
M,#(R+4I0*0!*97)S97D`W')D_&X`5&5M;75Z`$AA>FER86X`66%S;&$`3W)T
M87EA(%EA<VQA`%1A;6%M96X@66%S;&$`4V]L82!987-L80!38?!A(%EA<VQA
M`$MA>F%K:7-T86X`UGIG_&X@;VQA;B!S86ML86YS_6X@;?T_`$ME;GEA`$ME
M<F)E<F]S('-U;G5C=2!D;_!R=6QA;6%Y_2!R961D971T:2X`QV5K:7)D96L@
M06-E;6EL97)I`$%N86AT87(@66%R870`06YA:'1A<B!087)M86MI>FD`06YA
M:'1A<B!5>G5N;'7P=0!!;F%H=&%R(%1I<&D`06YA:'1A<B!+=6QL86[];?T`
M0>?]:R!A;F%H=&%R('-U;G5C=7-U;F1A(&%N86AT87(@>F%T96X@=F%R+@#'
M;V-U:VQA<@!+:7)I8F%T:0!+=7IE>2!+;W)E`$?\;F5Y($MO<F4`2V]R96-E
M("AE=6,M2U(I`$MU=F5Y=`!+_7)G_7II<W1A;@!387EF82!?1/QZ96YI`$1I
M;`!,86\@1&5M;VMR871I8R!(86QK($-U;6AU<FEY971I`%-O;B!$]G)D_&X`
MWFG^:VEN($%Y`%-O;B!'_&YC96QL96UE.@!3;VX@1VER:?XZ("5S`%-O;B!'
M:7)I_CH@)7,@_'IE<FEN9&5N("5S`%-O;B!':7)I_CH@07-L80!,971O;GEA
M`%EA<V$`1/QZ96X`2&GG8FER('/];OUR(&GG:6X@8F_^(&+]<F%K;6$`3/QB
M;F%N`%-O;`!3;VP@8F'^;/UK(&)I;&=I<VD`4V]L9&%K:2!D9?!E<FQE<@!,
M97-O=&AO`$QI8F5R>6$`3&EB>6$`3&EE8VAT96YS=&5I;@#':7-E;&EY;W(`
M2&%F:68@66'P;75R`$5R:V5N(%-A871L97)D92!(869I9B!98?!M=7(`1V7G
M(%-A871L97)D92!(869I9B!98?!M=7(`2&%F:68@66'P;75R(%-A\&%N8?#]
M`$?V:R!G_'+\;'3\;/P@:&%F:68@>6'P;75R`$AA9FEF($MA<@!(869I9B!+
M87(@4V'P86YA\/T`3OQK=&5L:2#>:6ER`$)A\&QA;G3]`$)A\&QA;G3](&YO
M:W1A<_TZ`$?V<OQN=/QL97)K96X@96QE:W1R;VYI:R!P;W-T82!A9')E<VEN
M:2!O;'7^='5R;6$@<V%Y9F%S_6YA(&)A\&QA`$)A\&QA;G3];&%R`$QI;G5X
M(,=E<F5Z:0!,:7-T96QE("T@:W5L;&%N_6/](&1I>FEN:2!G]G)E8FEL:7(`
M5F5R:2!486)A;FQA<OUN_2!,:7-T96QE`%EA<F3];2!+;VYU;&%R_6[]($QI
M<W1E;&4`QVEZ96QG96QE<FD@3&ES=&5L90!,:7-T96QE+4%R_FEV`$QI<W1E
M;&4M66%R9/UM`$QI<W1E;&4M260`3&ES=&5L92U386AI<`!,:7-T96QE+4?V
M;F1E<FEL;6G^(-;P96QE<@!,:7-T96QE+5/\<F3\<OQM8_QL97(`3&ES=&5L
M92U3_')D_'+\;6/\($]L;6%Y86YL87(`2W5L;&%N_6/](&QI<W1E;&5M92!S
M9>=I;&5M97H@:_UL_6YD_2X`161E8FEY870`3&ET=F%N>6$`6?QK;&5N:7EO
M<BXN+@!997)E;"!Z86UA;CH`665R('9E(%IA;6%N`%EE<@!':7)I_@#'_6O]
M_@!':7)I_B!']G)E=FQE<FD`2W5L;&%N_6/](&%D_2!V97EA('!O<F]L82!D
M;_!R=2!O;&UA9/WP_2!IYVEN(&=I<FG^(&)A_F%R_7/]>B!O;&1U+@!':7)I
M_B!B8?YA<OUS_7H@;VQD=2X`57IU;B!M971I;@!!_FL`1/S^_&L`2_SG_&L@
M>75N86X@:&%R9FQE<FD`2_SG_&L@;&%T:6X@:&%R9FQE<FD`2_SG_&L@<F]M
M82!R86MA;6QA<OT`3/QK<V5M8G5R9P!!00!-3U1$`$U3+51.148@16MI('9E
M<FD@:>=E<FUE;65K=&5D:7(N`$U31P!-86-A;P!-86ME9&]N>6$`36%D86=A
M<VMA<@!"_'G\`%!O<W1A`%!O<W1A(%GV;F5T:6-I<VD`0F'P;&%?;G3](%EA
M<F%T+BXN`$UA;&%V:0!-86QE>GEA`$UA;&1I=FQE<@!-86QI`$UA;'1A`-;P
M96QE<FD@971I:V5T;&5Y96-E\&EN:7H@:V%T96=O<FD@;&ES=&5S:6YI('9E
M(&MA=&5G;W)I;&5R:2!I;&G^:VEL96YD:7)E8V7P:6YI>B!R96YK;&5R:2!Y
M]FYE=&EN+@!-87`R-"!H87)I=&%S_0!-87!1=65S="!H87)I=&%S_0!-87)T
M`$ME;F%R(&)O_FQU\'4`3VMU;FUU_B]/:W5N;6%M_?X@;VQA<F%K(&G^87)E
M=&QE`$1I\&5R(&EL971I(&G^87)E=&QE<FEY;&4@:?YA<F5T;&4@*/9R;F5K
M.B#6;F5M;&DO0V5V87!L86YM_?XI(`!-87)S:&%L;"!!9&%L87+]`$UA<G1I
M;FEK`$7^;&5L96X@86QA;FQA<@!-;W)I=&%N>6$`36%U<FET=7,`W7II;B!V
M97)I;&5N(&5N('G\:W-E:R!K<F5D:2X`16X@>?QK<V5K(&UE<V%J('!A<N=A
M<_T@<V%Y_7/](&'^_6QD_2X`4V]N(#(T('-A871T96MI(&5N('G\:W-E:R!S
M_6-A:VS]:SH@`%-O;B`V('-A871T96MI(&5N('G\:W-E:R!S_6-A:VS]:SH@
M`$5N('G\:W-E:R!U>G5N;'5K`$UA>?US`$UA>6]T=&4`5/UP`-QY96QE<@!-
M96[\($MI<&DZ`$C\8W)E;&5R:2!B:7)L9?YT:7(`W6QE=&D`W6QE<FD@8F'^
M87+]>6QA(&1O\')U;&%N9/T@86UA(&EM>F%L87G]8_UN_6X@;VYA>2!B96QG
M97-I(&1O\')U;&%N86UA9/TN`$UE<V%J_6X@<_QR97-I(&)I='1I+@!-97-A
M:B!T:7!I`$AA=F$@4F%P;W)U`$AA=F$@<F%P;W)U(/9B9?!I(&MU;&QA;OUL
M86)I;&ER(&1E\&EL+@!(879A(')A<&]R=2#V8F7P:2!K=6QL86[];&%B:6QI
M<B!D9?!I;"X@07ER_6YT_6QA<B!Y]FYE=&EC:2!IYVEN(&?\;FS\:VQE;F1I
M`%GV;G1E;0!-971R:6L`365K<VEK80!-:6MR;VYE<WEA`$]R=&$`36EM92!4
M_'+\`%-O;B`R-"!S86%T=&5K:2!E;B!D_/[\:R!S_6-A:VS]:SH@`%-O;B`V
M('-A871T96MI(&5N(&3\_OQK('/]8V%K;/UK.B``66%N<_T`375H=&5L:68`
M0G5L=6YA;6%Y86X@4$5!4B!P86ME=&DZ($A45%!?4F5Q=65S="X`071L86YM
M_?X@>6%P_6QA;F3]<FUA+B!"=2!U>6=U;&%M87G](&MU;&QA;FUA:R!I<W1I
M>6]R<V%N_7H@>6%P_6QA;F3]<FUA>?T@_')E=&UE:R!Z;W)U;F1A<_UN_7HN
M`$%T;&%N;?W^(&UE<V%J($E$+@!!=&QA;FW]_B!O;&%N(&=E<F5K;&D@4$5!
M4B!P86ME=&D@36%I;"X`071L86YM_?X@;W1U<G5M82!A:70@240N`%!Z=`!'
M97II8VD@4&]S=&$`4V%K:6X`1&7P:?YI;2!487)I:&D`1&7P:?YT:7(Z55),
M`$UO9"!486)A;OT`36]L9&]V>6$`36]N86-O`$UO\&]L:7-T86X`07D@=F4@
M>?UL`$%Y;/UK`$UO;G1S97)R870`07D@179R96QE<FD`1F%S`$=E;F5L;&EK
M;&4@0>?]:P!'96YE;&QI:VQE($)U;'5T;'4`1V5N96QL:6ML92!'_&YE_FQI
M`$'^8?#](%1A_OT`4V]L82!48?[]`%-A\&$@5&'^_0!9=6MA<OT@5&'^_0!!
M_F'P_2!T8?[]`%EU:V%R_2!T8?[]`$UO>F%M8FEK`,=O:VQU(&3\>F5Y(&'^
M8?#](&'G_6S]<B!L:7-T96QE<@#';VML=2!39>=I;0!(97-A8OUM`%!O<G1A
M;/UM`%!O<G1A;"!$_'IE;FEM`$UY86YM87(`2V%B=6P@151-25E/4E5-`$%D
M`$YA;6EB>6$`3F%U<G4`3F5P86P`2&]L;&%N9&$`2&]L;&%N9&$@06YT:6QL
M97)I`$YE='-C87!E(%1A8F%N(%523`!.971S8V%P92!#02#=<'1A;"!54DP`
M3F5T<V-A<&4@0T$@:W5R86P@55),`$YE='-C87!E(%EE;FEL96UE(%),`$YE
M='-C87!E(-UP=&%L(%523`!.971S8V%P92!34TP@<W5N=6-U(&%D_0!.971S
M8V%P92!O;F%Y(&)E;&=E<VD@8>?]:VQA;6%S_0!.971S8V%P92!O;F%Y(&)E
M;&=E<VD@=/QR_`!!\`!!<VQA`%EE;FD@2V%L961O;GEA`%EE;FD@2V%T96=O
M<FD`665N:2!!>0!996YI($MU;&QA;OUC_2!!9/T@*%-EYVEM;&DI`%EE;FD@
M6F5L;&%N9&$`665N:2!096YC97)E("A?8F_^*0!(86)E<FQE<@!(86)E<B!'
M<G5P;&%R_0!3;VYR86MI`%-O;G)A:VD@4V7G96YE:VQE<@!.:6MA<F%G=6$`
M3FEJ97)Y80!.:6IE<GEA`$=E8V4`3FEU90!(87G]<@!&87)K;&%R_6X@9_9S
M=&5R:6QE8FEL96-E\&D@:W5L;&%N_6QA8FEL:7(@>6%P_6QA;F3]<FUA('9E
M<FES:2!Y;VLN`$E33R!I;6%J;&%R_2!O=?YT=7)M86L@:>=I;B!K=6QL86[]
M;&%B:6QI<B!B:7(@>?9N=&5M('EO:RX`6?WP_6X@=&%S;&'P_2!Y;VLN`-US
M=&5N96X@:V]N=6UD82!H:>=B:7(@]F)E:R!B=6QU;FUA;6%K=&%D_7(`34-!
M3"!D;_!R=6QA;6%S_2!IYVEN(&AIYV)I<B!T86MV:6T@863]('-A\&QA;FUA
M;?W^=/UR+B``1&7P:?YI:VQI:R!9;VL`0G4@:7IN92!H:>=B:7(@86QT(&EZ
M:6X@96ML96YE;65Y96-E:W1I<BX`)7,@:>=I;B!H:>=B:7(@>6%P_6QA;F3]
M<FUA(&)I;&=I<VD@8F5L:7)T:6QM961I+@!&5%`@5D93(&GG:6X@:&GG8FER
M('EA</UL86YD_7)M82!B:6QG:7-I(&)E;&ER=&EL;65D:2X`4U%,(%9&4R!I
MYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES:2!B96QI<G1I;&UE9&DN
M`%-13"U&:6QE(%9&4R!IYVEN(&AIYV)I<B!Y87#];&%N9/UR;6$@8FEL9VES
M:2!B96QI<G1I;&UE9&DN`$MR961I('EO:RX`2&GG8FER('1E<VQI;2!N;VMT
M87/](&)E;&ER=&EL;65M:?YT:7(N`$AIYV)I<B!D;W-Y82!Y_&ML96YE;65D
M:0!(:>=B:7(@<VEM9V4@8G5L=6YA;6%D_2X`2&GG8FER('EE<B!B96QI<G1I
M;&UE9&DN`$AIYV)I<B!M97-A:B!S8?!L86YM863]+@!!9"!B96QI<G1I;&UE
M9&DN`$YU;6%R82!B96QI<G1I;&UE9&DN`%-A;&3]<F=A;B!D97EI_B!K=6QL
M86YM80!(5%10(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2X`
M24U!4"!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G:7)I;&UE9&DN`$ME<F)E
M<F]S(&1O\')U;&%M87/](&GG:6X@<&%R;VQA(&=I<FEL;65D:2X`3&]G:6X@
M9&_P<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!005-35T0@9&_P
M<G5L86UA<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!334(@9&_P<G5L86UA
M<_T@:>=I;B!P87)O;&$@9VER:6QM961I+@!/<&5N4U-,(&EK:6QI<VEN92!H
M:>=B:7(@>6]L(&)U;'5N86UA9/TN3W!E;E-33"!I:VEL:7-I(%!+0U,@,3(@
M=F5R:7-I>6QE(&-A;/W^;6%K(&GG:6X@9V5R96ML:2X`W'EE(&]L;6%K(&GG
M:6X@8F5K;&5Y96X@>6]K+@!+=7)A;"!Y;VL`66%N('EO:P#6;F)E;&QE:R!I
MYVEN(&=EYVEC:2!D:7II;B!B=6QU;F%M863]+@!+=6QL86[]8_T@863]('9E
M+W9E>6$@<&%R;VQA(&?V;F1E<FEL;65D:2X`1V7G97)L:2!834P@=F5R:7-I
M(&=E<FD@9/9N;65D:2X`1&7P97(@>6]K`-9Z9_QN('EA</UL86YD_7)M861A
M('/\<OQM(&)U;'5N86UA9/TN66%P_6QA;F3]<FUA>?T@=&5K<F%R(/QR971I
M;BX`UGIG_&X@>6%P_6QA;F3]<FUA;OUZ9&$@<_QR_&T@8G5L=6YA;6%D_2Y9
M87#];&%N9/UR;6%Y_2!T96MR87(@_')E=&EN+@!(:>=B:7)I`$AIYV)I<FD@
M*-9R=/QL_"!K=6QL86[];BD`2W5Z97D@079R=7!A;/T@*$E33RTX.#4Y+3$P
M*0!.;W)F;VQK($%D87/]`$MU>F5Y(%EA<OUM:_QR90!+=7IE>2!-87)I86YA
M($%D86QA<OT`3F]R=F7G`%-O;G)A<_UN9&$@1&7P:6P`UFYC97-I;F1E($1E
M\&EL`$1I>FEN(&1E\&EL`$=E<N=E:VQE_G1I<FEL;65M:?X`0F5L:7)T:6QM
M96UI_@!$97-T96ML96YM:7EO<BX`3F]T;&%R`$?V>B!A=/UL86-A:R!B:7+^
M97D@>6]K+"!G97)I(&3V;OQN+@!+87/];0!387G]`$MA<F%K=&5R('-A>?US
M_0!+;VQO;B!S87G]<_T`4V%T_7(@<V%Y_7/]`$1A\/UT_6T@;&ES=&5L97)I
M;FEN(&?\;F-E;&QE;FUE<VD@:>=I;B!N=6UA<F%L87(@8F5L:7)T:6QM96UI
M_BX`179E=`!.97-N90!.97-N92!987)A=/UC_7/]`%-E:VEZ;&EK(%-I<W1E
M;0!%:VEM`%-A;&3]<F=A;FS]:R!S_'IG96-I`$]F:7,`56UM86X`4V%D96-E
M($E-05`@<W5N=6-U;&%R_2!P87EL8?[];&%N(&1I>FEN;&5R:2!D97-T96ML
M96UE:W1E9&ER+@!3861E8V4@<V%L9/UR9V%N(&1E>6G^;&5R`%-A9&5C92!B
M:7(@96QE:W1R;VYI:R!P;W-T82!A9')E<VEN92!I>FEN('9E<FEL;65K=&5D
M:7(N`$)I<B!P87EL8?[];?UN('-A:&EP;&GP:6YI('9E>6$@<V%H:6)I;FD@
M<V%D96-E('-I<WEE;2!Y]FYE=&EC:7-I('9E>6$@<V%H:6)I(&1E\&G^=&ER
M96)I;&ER+@!996YI('!E;F-E<F5D92!AYP!/<&5N4U-,(&AA=&%S_3K=;7IA
M;&%N;?W^(%,O34E-12!P87+G87/];F1A;B!V97)I('-EYVEP(.?]:V%T_6QA
M;6%D_2X`0G4@8F'P;&%N=/UY_2!Y96YI('!E;F-E<F5D92!AYP#=_FQE=&EM
M(%-I<W1E;6D`4V7G96YE:VQE<@`E<R!IYVEN('-EYV5N96ML97(`4_UR86QA
M;FW]_B!,:7-T90!+=7)U;'7^`$MU<G5M<V%L($)I<FEM`$3\>F5N;&5M90#6
M>F?\;B!U>6=U;&%M82!T87-L8?#]`"5S(&GG:6YD96MI(/9Z9_QN('1A<VQA
M:VQA<CH`1&GP97(`1&GP97(@0FEL9VEL97(`4V%H:7`@:7II;FQE<FD`4$%-
M(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"X`4$=0(%-A>?US86P@W6UZ80!0
M1U`@WFEF<F5L96YM:?X@5F5R:0!01U`@0>?]:R!!;F%H=&%R_0!01U`@:6QE
M(-UM>F%L86YM_?XOWFEF<F5L96YM:?X@5F5R:0!02%`@2V]D=0!02%`@2V%B
M=?!U`-93($AA9FEF(%EA\&UU<@#64R!38?!A;F%K;&%R_0#64R!+87(`UE,@
M2V%R(%-A\&%N86ML87+]`-93($?V:R!G_'+\;'3\;/P@9OUR=/UN80!07TA0
M($MA8G7P=0!987-T_6ML86UA`%!A:VES=&%N`%!A;&%U`-W^9V%L($5D:6QM
M:?X@1FEL:7-T:6X@0O9L9V5S:0!086YA;6$`4&%P=6$@665N:2!':6YE`%!A
M<F%G=6%Y`$O]<VUE;B!"=6QU=&QU`%!A<F]L80!986YL_?X@<&%R;VQA`%)!
M1$E54R!D;_!R=6QA;6%S_2!IYVEN('!A<F]L82!G97)E:VUE:W1E9&ER+@!/
M;F%Y;/T@4&%R;VQA`%!A<F]L83H`4&%R;VQA.@!087)O;&%L87(@9?YL9?YM
M96L@>F]R=6YD863]<BX`66%P_?YT_7(`4&%N;V1A;B!Y87#]_G3]<@!9;VP`
M0F5K;&5Y96X@W'EE;&EK;&5R.@#=;G-A;FQA<@!9_'ID90!"86O];2#=_FQE
M;6QE<FEN:2!'97+G96ML9?YT:7(`0F%K_6T@:?YL96UL97)I(&=I<FG^=&4@
M9V5RYV5K;&7^=&ER:6QS:6X@;6D_`-UZ:6X`W7II;B!9]FYE=&EM:0!+:?YI
M<V5L($)I;&=I;&5R`%!E<G4`179C:6P@2&%Y=F%N;&%R`$9I;&EP:6YL97(`
M5&5L969O;@!&;W1O\')A9FQA<@!0:71C86ER;@!297-I;2!":7)I;6D`0F5Y
M;&EK(%/V>FQE<@!,_'1F96X@8FER:V'G(&C\8W)E>64@=/UK;&%Y_6X`3/QT
M9F5N(&)U(/;P97EI(.?]:V%R;6%K(&ES=&5D:?!I;FEZ:2!D;_!R=6QA>?UN
M.@!,_'1F96X@8G4@]O!E;FEN(&)A\/UN_2#G]GIM96L@:7-T961I\&EN:7H@
M9&_P<G5L87G];BX`3/QT9F5N(&)I<B!A>2!V92!B:7(@>?UL(&=I<FEN+@!,
M_'1F96X@>65N:2!K871E9V]R:6YI;B!A9/UN_2!G:7)I;CH`3/QT9F5N(&=E
MYV5R;&D@8FER($E0(&%D<F5S:2!G:7)I;BX`3/QT9F5N(&=EYV5R;&D@8FER
M(&?\;B!G:7)I;BP@87ED86MI(&?\;B!S87G]<_UN_2!K;VYT<F]L(&5D:6XN
M`$S\=&9E;B!G9>=E<FQI(&)I<B!Z86UA;B!G:7)I;BX`3/QT9F5N('-O<G5N
M=6X@8FER(/9Z971I;FD@>6%P_6XN`$S\=&9E;B!K=6QL86[]8_T@863]('9E
M('!A<F]L86[]>OT@9VER:6X`3/QT9F5N('EE;FD@:V%T96=O<FEN:2!A9/T@
M9VER:6XZ`%!O;&]N>6$`4&]L:71I:V$`3WEL86UA;&%R`%!O<G1E:VEZ`$?V
M<OQN=/P@:V]N=6UL86YD_7+];/UY;W(`QVEZ96QG92!K;VYU;6QA;F3]<OUL
M_7EO<@!"=2!D:7II;F4@9_9N9&5R("A)34%0('1A<F%F_6YD86X@>F]R;&%N
M;6%M86MT863]<BD`4V]N("5S('-A871T92!D_/YE;B!Y8?!M=7(@=F4@:V%R
M(&UI:W1A<OTZ`%!R969S7VQD87`Z(-US=&5N96X@3$1!4"!U>F%N=/US_2!B
M=6QU;F%M863]+@!0<F5F<U]S97-S:6]N.B#=<W1E;F5N(&]T=7)U;2!U>F%N
M=/US_2!B=6QU;F%M863]+@!"87/];N<`1&5N:7H@<V5V:7EE<VEN9&5K:2!B
M87/];N<Z`$)A<_UNYSH`UFYI>FQE;64`1_9R_&YT_'G\('EE;FD@<&5N8V5R
M961E(/9N:7IL90#6;F-E:VD@<V7G96YE:VQE<@!"96QG97EI('EA>F3]<@#6
M>F5L($%N86AT87(`4V]R=6X`4V]R=6X@5&%N_6UL86UA<_T`4')O:F5L97(`
M365T:6X@8FEL9VD@:7-T96UI`$'G_6L@06YA:'1A<@!!Y_UK($%N86AT87(@
M86QG;W)I=&UA<_T`0>?]:R_6>F5L(&%N86AT87(@:6MI;&ES:2!B8?YA<OUY
M;&$@>6%R873];&%M863]+@!0;W)T;R!2:6MO`$MA=&%R`%-O<F=U`%)302!!
MY_UK($%N86AT87+]("@E9"!B:70I`%)A9'EO(%-EYVEM:0!98?!M=7(`17)K
M96X@4V%A=&QE<F1E(%EA\&UU<@!'9><@4V%A=&QE<F1E(%EA\&UU<@!38?!A
M;F%K(%EA\/W^`%EA\&UU<B!V92!+87(`2V%R82!D]F[\_F5C96L@>6'P;75R
M`%)A<W1G96QE($1E>6G^`$]R86X`3VMU;6$`W6QE=&EL97)I($]K=0!3:6QM
M96L@:7-T961I\&EN:7IE(&=E<N=E:W1E;B!E;6EN(&UI<VEN:7H_*$)U(&G^
M;&5M(&=E<FD@YV5V<FEL96UE>BDZ)7,`2W5L;&%N_6/]("5S(&4@86ET(&MU
M;&QA;OUC_2!V97)I;&5R:6YI('-I;&UE:R!I<W1E9&GP:6YI>F4@96UI;B!M
M:7-I;FEZ+B!"=2!I_FQE;2!G97)I(.=E=G)I;&5M97HN`%-O;B!E>6QE;6D@
M=&5K<F%R;&$`1&5V:6YG96X@365N_"#6\&5L97)I;FD@5&%Z96QE.@!0;W)T
M86P@1_9R_&[\;?QN_"!487IE;&4Z`$3\>F5N;&D@W69A9&4`W6QI_FMI(%1A
M<F%Y_6/]`$'G_6ML86UA;&%R`%5Z86MT86MI(%-U;G5C=6QA<@!5>F%K=&%K
M:2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!3:6P`UF)E
M\&D@4VEL`$MO;&]N=2!3:6P`0FGG:6UL96UE>6D@4VEL`$EK:6QI>6D@4VEL
M`$MA>61E9&EL;6G^(&)E=&GP:2!S=6YU8W5N=2!G9>=I8VD@9&EZ:6YI;F1E
M;B!S:6PN`%-I;`!"=2!P87+G87G](&)E;&=E9&5N(.?]:V%R=`!+=6QL86[]
M8_T@4VEL`$MU;&QA;OUC_7G]('-I;#H@)7,`W7-T96L@8V5V87!L86YA;6%D
M_2Y$]F[\;&5N(&AA=&$@:V]D=3H@`$=E<F5K96X@06QA;@!496UI>FQE`%!A
M<F]L87G]('/]9OUR;&$`4&%R;VQA;OUZ_2!S_6;]<FQA>?UN`%-O;G7G;&%R
M`%-EYV5N96ML97)E($3V;OQN`%)E=6YI;VX`66%P_6QA;F3]<FUA>?T@1V5R
M:2!$]FYD_'(`6F5N9VEN($UE=&EN($3\>F5N;&5Y:6-I<VD@4V7G96YE:VQE
M<FD`0FEL;65C96QE<@!38?``4V'P(&)A_FS]:R!B:6QG:7-I`$1O\')U(&1E
M\&5R;&5R`%-A7W3]<B#6>F5L;&EK;&5R:2XN+@!']G)E=@!2;VUA;GEA`#$X
M,"!D97)E8V4@9/9N9/QR`%-O;&$@1/9N9/QR`%-A\&$@1/9N9/QR`%-A=/UR
M(-9Z96QL:6ML97)I`%-A=/UR(/9Z96QL:6ML97)I`%-A=/UR;&%R.@#':7IG
M:6QE<@#':7IG:6QE<B!T_&T@<V%T_7(@=F4@:V]L;VYL87(@87)A<_UN9&$@
M8F5L:7)E8V5K=&ER`,=I>F=I;&5R('-A9&5C92!K;VQO;FQA<B!A<F%S_6YD
M82!B96QI<F5C96MT:7(`QVEZ9VEL97(@<V%D96-E('-A=/UR;&%R(&%R87/]
M;F1A(&)E;&ER96-E:W1I<@#'86S]_G3]<@!2=7-Y82!&961E<F%S>6]N=0!2
M=6%N9&$`4R]-24U%(-YI9G)E;&5M92#=;7IA<_T`4R]-24U%(&EL92#>:69R
M96QE;FUI_B#=;&5T:0!305-,(&1O\')U;&%M87/](&UE=F-U="!D9?!I;"X`
M4TU3($UE<V%J;&'^;6$`4U%,($MA8G7P=0!34T@`0D'>05))3$D`4U]13"!+
M86)U\'4`0W1S`%-A:6YT($AE;&5N80!386EN="!+:71T<R!V92!.979I<P!3
M86EN="!,=6-I80!386EN="!0:65R<F4@=F4@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!V92!'<F5N861I;F5S`$%Y;OT@YV5RYV5V92`H:V5N7V1I<VDI`%-A
M;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@=F4@4')I;F-I<&4`57ED=2!38?!L
M87G]8_T`4W5U9&D@07)A8FES=&%N`$MA>61E=`!+87ED970@)7,`4V7G96YE
M:VQE<FD@2V%Y9&5T`$]L=?YT=7)U;&%N('EA</UL86YD_7)M87G](%!(4"!B
M971I\&D@;VQA<F%K('-U;G5C=6YU;B!G9>=I8VD@9&EZ:6YI;F4@:V%Y9&5T
M+@`E<R!Y87#];&%N9/UR;6%S_2!K87ED961I;&1I+@!":6QI;0!!<F%M80!!
M<F%M82!-;W1O<FQA<OT`1&]S>6%L87+](%-EYP!":7(@=&%R:6@@<V7G:6X`
M16ML96UE:R!IYVEN(&)I<B!G<G5P('-EYVEN`%EE;FD@<V%H:6)I('-EYVEN
M`$)I<B!S=6YU8W4@<V7G:6X`16ML96UE:R!IYVEN(&)I<B!K=6QL86[]8_T@
M<V7G:6X`0OQT_&X@=&%R:6@@8FEL9?YE;FQE<FEN:2!S9>=I;@!":7(@;F5S
M;F4@<V7G:6X`W7-T961I\&YI>B!K87)A:W1E<FQE<FD@8?YA\/UD86MI(&MU
M='5L87)D86X@<V7G:6XN($1A:&$@<V]N<F$@;65T:6X@86QA;OUN9&%N(&MO
M<'EA;&%Y_7`@>6%P_?YT_7)A8FEL:7)S:6YI>BX`5&%R:6@@<_UN_7)L87G]
M8_US_6[]('-EY_UN.@!487)I:"!B:>=I;6EN:2!S9>=I;CH`1&7P:?YT:7)M
M96L@:7-T961I\&EN:7H@:VEM;&GP:2!S9>=I;CH`4V%A="!S_6[]<FQA>?UC
M_7/];OT@<V7G:6XZ`%-A870@8FGG:6UI;FD@<V7G:6XZ`$7^;&7^96X@:6MI
M(&%L86[]('-EYVEN+@!296YK(&3\>F5N:6YI>FD@<V7G:6XN`%1E<F-I:"!E
M='1I\&EN:7H@9&EL:2!S9>=I;CH`4V]R=6X@4F%P;W)U($?V;F1E<@!335,@
M1_9N9&5R`%-E;F5G86P`06QG_6QA>?UC_3H`17EL_&P`4_UR8FES=&%N('9E
M($UO;G1E;F5G<F\`4V5R:2!.=6UA<F%S_0!/='5R=6T@:VEM;&GP:6YI;B!S
M_')E<VD@9&]L9'4N`$)E;&ER=`!087)O;&%N_7K];OT@=6YU='5R<V%N_7H@
M<_UF_7)L86UA;OUZ82!I>FEN('9E<F5C96L@<V7G96YE:VQE<FD@8F5L:7)T
M:6XN(`!5;&'^;6%K(&ES=&7P:6YI>B!U>F%K=&%K:2!S=6YU8W5L87+](&)E
M;&ER;&5Y:6XN`%1E<F-I:"!E='1I\&EN:7H@9&EL+"!S86%T(&1I;&EM:2!V
M92!T87)I:"!S9>=E;F5K;&5R:6YI(&)E;&ER;&5Y:6XN`$)A_FQA;F?]YR!U
M>6=U;&%M86[]>OTL(')E;FL@9/QZ96YI;FEZ:2P@<V%Y9F$@=&%Z96QE;64L
M('9E(&1I\&5R(&?V<OQN=/P@<V7G96YE:VQE<FEN:2!B96QI<FQE>6EN+@!!
M>6%R;&%R`$MU<G5L=6T@9_QN8V5L;&5M92!B971I:VQE<FD@:W5L;&%N_6QA
M8FEL:7(@9'5R=6UD82X`1&7P:?YT:7)G92!I;&4@8FER9&5N(&9A>FQA('EE
M<B!M_&UK_&XZ(`!397G^96P`06S]_B!V97)I_@!+_7-A(-9Z970`QV_P=2!B
M8?!L86YT_2!IYVEN(&5R:?YI;2!A;F%H=&%R_2!T86[];6QA;G/];B!M_3\`
M1_9S=&5R`$AA;&5N(&MA>?UT;/T@;VQA;B!Y87#];&%N9/UR;6$@:6QE('EE
M;FD@>6%R873];&%N('EA</UL86YD_7)M82!A<F%S_6YD86MI(&9A<FML87+]
M(&?V<W1E<BX`1VER:?YT92!E;B!S;VX@9VER:?X@=&%R:6AI(&?V<W1E<FEL
M<VEN(&UI/P#6>F?\;B!O;&%N_2!S86ML86UA('-EYV5N9?!I;FD@9_9S=&5R
M`%-EYVEC:7EI(&?V<W1E<@#':7IE;&=E(&G^;&5M;&5R:2!M96[\(.=U8G7P
M=6YD82!G]G-T97)I;'-I;B!M:3\`)7,@365N_'/\('-O;&1A(&?V<W1E<FEL
M<VEN(&UI/P!486)L;R!(_&-R92#6>F5L;&EK;&5R:2!+=71U<W5N=2!G]G-T
M97(`5&%B;&\@UGIE;&QI:VQE<FD@2W5T=7-U;G4@9_9S=&5R`%1A8FQO(%-A
M=/UR(-9Z96QL:6ML97)I($MU='5S=6YU(&?V<W1E<@!']G+\;G3\(/9Z96QL
M:6ML97)I(&MU='5S=6YU(&?V<W1E<@!9_&ML96UE>6D@9_9S=&5R`%-A\&%N
M86L`17)K96X@4V%A=&QE<F1E(%-A\&%N86L`1V7G(%-A871L97)D92!38?!A
M;F%K`,=E=G)E9&4@4V'P86YA:P!+_.?\;'0`W6QK(&]L87)A:R!K;VW^=2#V
M\&5L97(@:_SG_&QT<_QN('EA9&$@=&'^_6YS_6X`4VEE<G)A($QE;VYE`-QY
M92!O;`#=;7IA`-UM>F$@06QG;W)I=&UA<_T`4VEN9V%P=7(`0F]Y=70`0F%K
M_6W]($%T;&$`4VQO=F%K>6$`4VQO=F5N>6$`2V%R`$MA<B!38?!A;F'P_0!+
M87(@4V'P86YA:VQA<OT`17)K96X@4V%A=&QE<F1E($MA<B!38?!A;F%K;&%R
M_0!'9><@4V%A=&QE<F1E($MA<B!38?!A;F%K;&%R_0!+87(@1&5R:6YL:?!I
M.B``66'P86X@:V%R_6X@<W4@9?YI=&DZ(`!3;VQO;6]N($%D86QA<OT`4V]M
M86QI`-YA<FO];&%R("8@WFEI<FQE<@!3_7)A;&%M82!D_'IE;FD@<V7G:6UI
M`$MA>6YA:R!A9')E<VD`1_QN97D@069R:6MA`$?\;F5Y($%V<G5P82`H25-/
M+3@X-3DM,RD`1_QN97D@1V5O<F=I82!V92!'_&YE>2!386YD=VEC:"!!9&%L
M87+]`$?\;F5Y(%EA<OUM:_QR90!":71I_FEK(&C\8W)E;&5R(&%R87/];F1A
M:VD@8F_^;'5K`$C\8W)E9&5K:2!S_6[]<B!V92!IYV5R:6L@87)A<_UN9&%K
M:2!B;_YL=6L`0F_^;'5K($%Y87)L87G]8_T`07)A;/UK(&+]<F%K;6$`07)A
M;/UK(&+]<F%K;6$@=F4@>6%S=/UK;&%M80#=<W!A;GEA`-US=&5N;65Y96X@
MW6QE=&D`UGIE;"!+87)A:W1E<B!':7)I_FD`2/QC<F5Y:2!B]FP`2V]L;VYU
M(&+V;`!3873]<OT@8O9L`%-P;W)L87(`4W)I($QA;FMA`%-T86YD87)T`%5Z
M87D@66]L=0!"8?YL86YG_><@>?UL_0!%>6%L970@=F5Y82#=;`!$=7)U;0!$
M97!O;&%M82!B:>=I;6D`4V]K86L@061R97-I`-QS=/P@YVEZ9VEL:0!$:7IG
M:2!L:7-T97-I`$%D<F5S=&5N(&%L86X@863];OT@Y_UK87)T`%-I=&EL(%M#
M4U-=`%!Z<@!+;VYU`$?V;F1E<@!!;'1S:6UG90!"8?YA<OT`66%P_6QA;F3]
M<FUA(&)A_F%R_7EL82!G97)I(&3V;F3\<OQL9/PN($1E\&G^:6ML:6ML97)I
M(&?V<FUE:R!IYVEN('EE;FED96X@>?QK;&5Y:6XN`%EE9&5K('EA</UL86YD
M_7)M82!B8?YA<OUY;&$@:V%Y9&5D:6QD:2X`665D96L@>6%P_6QA;F3]<FUA
M(&1O<WEA<_T@)7,@8F'^87+]>6QA(&MA>61E9&EL9&DN`"5S(&)A_F%R_7EL
M82!Y87K];&3]+@!3=61A;@#6>F5T`$?\;B!$;_!U;74`1_QN(&)A=/UM_0!'
M_&YE_FQI`$?\;B!D;_!U;74`1_QN(&1O\'5M=2]'_&X@8F%T_6W]`$?\;B!D
M;_!U;74Z(`!'_&X@8F%T_6W]`$?\;B!B873];?TZ(`#<<W1S:6UG90!$97-T
M96L`4W5R:6YA;0!3;WEA9/T`4W9A;&)A<F0@=F4@2F%N($UA>65N`%-V87II
M;&%N9`#=<W9EYP#=<W9IYW)E`$%R86UA('1E<FEM;&5R:6YD92!S]GID:7II
M;2!H871A<_T`4W5R:7EE`$?V:R!G_'+\;'3\;/P@9OUR=/UN80!']FL@9_QR
M_&QT_&S\(&;]<G3];F%L87(`5%-6(&1O<WEA<_T`QVEZ96QG90#'27IE;&=E
M(-9Z96QL:6ML97)I`,=I>F5L9V4@]GIE;&QI:VQE<FD`5&%Y=F%N`%1A>79A
M;BP@QVEN(&5Y86QE=&D`5&%C:6MI<W1A;@!486YZ86YY80!(961E9CH`1_9R
M979L97(`5&5L969O;B!.=6UA<F%S_0!3;VX@<V%A="!IYVEN('/]8V%K;/UK
M.B``4_UC86ML_6L`4_UC86ML_6LZ(`!487-L86L@6?9N971I;6D`365T:6X`
M4V%D96-E($UE=&EN`$UE=&EN(&AI>F%L86UA<_T`365T;FEN(-QS=/P`4'+^
M`%1A:2`H5$E3+38R,"D`5&%Y;&%N9`!3:7-T96UI(&MU;&QA;OUD_?#];OUZ
M(&GG:6X@=&7^96MK_'(@961E<FEZ+@!&5%`@=7IA;G3]<_T@:W5L;&%N_6QA
M8FEL:7(@9'5R=6UD82!D9?!I;"X`2&]R9&4O2V]L86(@8OQT_&YL9?YT:7)M
M92!M;W1O<G4@9&5S=&5K;&5M96UE:W1E9&ER.B`B)7,B`$)A:_UM.CH@<_UN
M_68@8F'^87+]>6QA('G\:VQE;F5M961I+@#>9>=E;F5K;&5R('!E;F-E<F5S
M:2!K87!A;F3]+L?]:_W^('EA</UL_7EO<BX`1?!E<B!I>FEN;&5R:2!K=6QL
M86YM86L@:7-T:7EO<G-A;OUZ('GV;F5T:6-I;FEZ:6X@W7II;B!S:7-T96UI
M;FD@>6%P_6QA;F3]<FUA<_T@9V5R96MM96MT961I<BX`4V%D96-E(&%L="!T
M87)A9@#=;&5T:?YI;2!N;VMT87/];OUN($E$)W-I(&)E;&ER;&5N96UE9&DL
M(&)O_B!B_7)A:_UL;?W^('9E>6$@=F5R:2!T86)A;OUN9&$@8G5L=6YA;6%D
M_2X`W6QE=&G^:6T@;F]K=&%S_2!B8?YA<OUY;&$@861R97,@9&5F=&5R:6YI
M>F4@96ML96YD:2X`Q_UK87)T_6QM_?X@4$=0(&EM>F$@]F)E\&D@:6UZ86QA
M;FW]_B!I;&5T:6YI;B!D;_!R=6QU\'5N=6X@<V'P;&%N;6%S_2!IYVEN(&=E
M<F5K;65K=&5D:7(N`$1A\/UT_6T@;&ES=&5S:2!)1"=S:2!B96QI<FQE;F5M
M961I+"!B;_X@8OUR86O];&W]_B!V97EA('9E<FD@=&%B86[];F1A(&)U;'5N
M86UA9/TN`$1A\/UT_6T@;&ES=&5S:2!B96QI<FQE;F5M961I+@#>:69R96QE
M;64@]GIE;&QI:VQE<FD@9_QV96YL:2!B:7(@=V5B(&)A\&QA;G3]<_T@9V5R
M96MT:7)M96MT961I<BX`)7,@9&]S>6%S_2`E<R!A>6%R_2!IYV5R;65L:61I
M<BX`)7,@9&]S>6%S_2`E<R!A>6%R;&%R_2!IYV5R;65L:61I<BX`1&]S>6$@
M:V5N9&D@_'IE<FEN92!K;W!Y86QA;F%M87HN`$1O<WEA('9E<FD@:>=E<FUI
M>6]R+@!486MI<"!E9&5N;&5R(&)U(&EL971I+W)F8S@R,B!I;&5T:7-I(&GG
M:6X@8F'^;/UK(&)I;&=I;&5R:61I<BX`0?YA;6%D_?#];?UZ('1A<F%Y_6/]
M(&AA=&%L87+]('-E8F5B:7EL92!T86T@96MR86X@:VEP:6YI;B!);G1E<FYE
M="!%>'!L;W)E<B=L82!B:7)L:6MT92!S;W)U;B#G_6MA<F3]\/T@8FEL:6YM
M96MT961I<BX@06YL86US_7H@9_9R_&YT_&QE<FQE+"#G86S]_FUA>6%N(&UE
M=&EN(&3\>F5N;&5Y:6-I(&G^;&5R:7EL92!V92]V97EA('1A<F%Y_6/];OUN
M(')A<W1G96QE(.?V:VUE<VEY;&4@:V%R_OUL8?YA8FEL:7)S:6YI>BX@1?!E
M<B!S:7-T96UI;FEZ(%=I;F1O=W,@.7@@:7-E('G\:W-E:R!I:'1I;6%L("='
M96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&AA=&%S_2!A;/UP('-I<W1E;6D@
M>65N:61E;B!B8?YL871M86[]>B!G97)E:V5C96LN7&Y<;D)U(&)I<B!U>6%R
M_7ED_2X@1?!E<B!H86QA('1A;2!E:W)A;B!M971I;B!D_'IE;FQE>6EC:7-I
M;FD@9&5N96UE:R!I<W1I>6]R<V%N_7H@179E="=I('3]:VQA>?UN+@!+:6UL
M:6L@(B5S(B!S:6QI;F1I+@!3861E8V4@<V]L('1A<F%F`$-R>7!T7W!G<#HZ
M('/];OUF_6YA($=N=5!'(&EK:6QI<VEN:6X@:V]N=6UU('9E<FEL;65K('IO
M<G5N9&%D_7(N`"5S('1A<FEH:6YD92`E<R!E(&?V;F1E<FEL96X@(B5S(B!K
M;VYU;'4@:6QE=&D@9_9R_&YT_&QE;F1I+@I"=2!I;&5T:6YI;B!O:W5N9'7P
M=2!V97EA(&%N;&'^_6QD_?#];OT@9V%R86YT:6QE;65M96MT961I<BX`3VQU
M_G1U<B!P96YC97)E<VEN92!B8?!L86[]<FME;B!K=6QL86[];&%C86L@:7-I
M;0!(;W)D95]#<GEP=%]S:6UE.CH@<_UN_6;](&]P96YS<VP@8FER:6UI(&GG
M:6X@9V5R96MM96MT961I<BX`(B5S(B!T97)C:6AI('9E<FES:2!I>FEN('9E
M<FEL96X@96X@>?QK<V5K(&)O>75T=2!G9>=T:?!I(&GG:6X@:V%Y9&5D:6QE
M;65M96MT961I<BX`0G4@=F5R:2!Y87!S_6[]*"5S*2!G]G-T97)M96L@:>=I
M;B!K=6QL86[];&%N('!R;V=R86T@<VES=&5M9&4@8G5L=6YM86UA:W1A9/UR
M+@!3861E8V4@<V]L('9E('-A\"!T87)A9FQA<@!3861E8V4@<V'P('1A<F%F
M`"(E<R(@<W5N=6-U<W4@<VEL:6YD:2X`(B5S(B!S=6YU8W5S=2!K87ED961I
M;&1I+@`E<R!IYVEN(&]L86X@_'EE;&EK(&ES=&7P:2!S:6QI;F1I+@!"96QI
M<G1I;&5N('-A=/UR(&)U;'5N;6%M86MT863]<BX`1V7G:6-I(&1O<WEA("(E
M<R(@8G5L=6YM86UA:W1A9/UR+@!3861E8V4@_'-T('9E(&%L="!T87)A9FQA
M<@!3861E8V4@_'-T('1A<F%F`$)I<B#V;F-E:VD@863];2!S_7)A<_UN9&$@
M>?QK;&5N96X@=F5R:2!K87EB961I;&1I+@!9_&ML96YE;B!D;W-Y82!K87ED
M961I;&5M961I+@!W96%T:&5R+F-O;2!K=6QL86[];&%B:6QI<B!D9?!I;"X`
M2&GG8FER('-EYV5N96L@;65V8W5T(&1E\&EL+@!-971N92!G]FW\;/P@;VQA
M<F%K(&?V<W1E<FEL96)I;&5C96L@:_US_6T@>6]K`$)U(&%L86YD82#G;VL@
M9F%Z;&$@:V%R86MT97(@=F%R+B5S('1A;F4@:V%R86MT97(@9VER9&EN:7H[
M("5S('1A;F5D96X@87H@9VER;65N:7H@9V5R96MI<F1I+@!$;W-Y82`H:V%R
M_OUD86XI('G\:VQE;FUE<VEN9&4@<V]R=6X@=F%R.B`E<R!Y_&ML96YE;65D
M:2X`1&]S>6$@>?QK;&5N:7)K96X@8FER('-O<G5N(&]L=?YT=3H@)7,@96X@
M8OQY_&L@:7II;B!V97)I;&5N(&)O>75T=&%N("@E9"!B>71E*2!D86AA(&+\
M>?QK+@!$;W-Y82!Y_&ML96YI<FME;B!B:7(@<V]R=6X@;VQU_G1U.B`E<R!S
M861E8V4@:_US;6D@;VQA<F%K('G\:VQE;F1I+@!);&5T:6YI;B!B=2!K_7-M
M_6[](&?V<OQN=/QL96YM97-I;F1E(&AA=&$@;VQU_G1U+@#=;&5T:?YI;2!N
M;VMT87/];OUN('9E<FEL97)I("AIYV5R:2D@86MT87+];/UR:V5N(&AA=&$@
M;VQU_G1U+@!I0V%L96YD87(@=F5R:7-I("AIYV5R:2D@86MT87+];/UR:V5N
M(&AA=&$@;VQU_G1U+@!987#];&%N9/UR;6$@9F]R;75N9&$@8FER(&AA=&$@
M=F%R+B!'97)E:VQI(&)I<B!A;&%N_2!D;VQD=7)M86W]_B!O;&%B:6QI<G-I
M;FEZ+@!"96QI<G1I;&5N(&%D<F5S(&1E9G1E<FD@:?YL979I;FEN(&=E<N=E
M:VQE_G1I<FEL;65S:2!S_7)A<_UN9&$@<V]R=6X@;VQU_G1U+B!,_'1F96X@
M9&%H82!S;VYR82!T96MR87(@9&5N97EI;BX`W6QE=&G^:6T@;F]K=&%S_6[]
M;B!A>7+];G3];&%R_6[](&?\;F-E;&QE<FME;B!H871A(&]L=?YT=2X@3/QT
M9F5N(&1A:&$@<V]N<F$@=&5K<F%R(&1E;F5Y:6XN`$1A\/UT_6T@;&ES=&5S
M:6YI(&?\;F-E;&QE<FME;B!B:7(@:&%T82!O;'7^='4N($S\=&9E;B!D86AA
M('-O;G)A('1E:W)A<B!D96YE>6EN+@!"=2!)34%0('-U;G5C=7-U('!A>6QA
M_OUL86X@9&EZ:6YL97)I(&1E<W1E:VQE;6EY;W(N`$)U(&=EYV5R;&D@8FER
M(')A<B!A<OYI=FD@9&7P:6PN`$)U(&=EYV5R;&D@8FER('II<"!D;W-Y87/]
M(&1E\&EL+@!"=2!G9>=E<FQI(&)I<B!K87)T(&YU;6%R87/](&1E\&EL+@!"
M=2!S_'+\8_P@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!A
M\"!G9>=I9&D@_'IE<FEN9&5N($A45%`@05!)(&MU;&QA;F%R86L@;65S86H@
M871M86[]>F$@:7II;B!V97)I<BX`0G4@<_QR_&/\('-M<S)E;6%I;"`H:'1T
M<#HO+W-M<S)E;6%I;"D@8?`@9V7G:61I(/QZ97)I;F1E;B!(5%10($%022!K
M=6QL86YA<F%K(&UE<V%J(&%T;6%N_7IA(&EZ:6X@=F5R:7(N`$)U('/\<OQC
M_"!33510('EO;'5Y;&$@5F]D869O;F4@271A;'D@8?`@9V7G:61I(/QZ97)I
M;F1E;BP@<V%D96-E(%9O9&5F;VYE(&YU;6%R86QA<OUN82!M97-A:B!A=&UA
M;OUZ82!I>FEN('9E<FER+B!6;V1E9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ
M.3`N:70I(&5L96MT<F]N:6L@<&]S=&$@861R97-I(&=E<F5K=&ER;65K=&5D
M:7(N`$)U(&=E<F5K;&D@8FER(&%L86YD_7(N`$)U(&%L86X@<V%D96-E('-A
M>?T@:>=E<FUE;&ED:7(N`$)U(&%L86X@<V%D96-E('-A>?T@=F4@:6MI(&YO
M:W1A(/QS=/QS=&4@:?YA<F5T:2!IYV5R96)I;&ER+@!"=2!A;&%N('-A9&5C
M92!S96MI>FQI:R!S87G]('-I<W1E;6EN9&5N(&1E\&5R;&4@:>=E<F5B:6QI
M<BX`0G4@86QA;B!V:7)G_&P@=F5Y82!B;_YL=6ML82!A>7+];&W]_B!S87G]
M(&QI<W1E(&]L;6%L_63]<BX`0G4@86QA;B!G9>=E<FQI(&)I<B!N=6UA<F$@
M;VQM86S]9/UR+@!"=2!A;&%N(%)'0B!(97@@8FGG:6UI;F1E(&)I<B!R96YK
M(&MO9'4@:>=E<FUE;&ED:7(L(/9R;F5K.B`G(S$R,S1A9B<`0G4@9F]R;2!Z
M871E;B!I_FQE;F1I+@!"=2`E<RX`0G4@8FER($MO;&%B($=R;W5P=V%R92!N
M97-N97-I9&ER+B!"=2!N97-N97EI(&?V<F5B:6QM96L@:>=I;B!+;VQA8B!'
M<F]U<'=A<F4@8FGG:6UI;FD@86YL87EA8FEL96X@8FER(&5L96MT<F]N:6L@
M<&]S=&$@:7-T96UC:7-I;F4@9V5R96L@=F%R+D)U(&5L96MT<F]N:6L@:7-T
M96UC:2!L:7-T97-I(&GG:6X@)7,@861R97-I;F4@=?!R87G];BX`0G4@:6QE
M=&D@<VEZ:6X@:V%R86MT97(@:_QM96YI>F1E;B!F87)K;/T@;VQA<F%K*"5S
M*2!Y87K];&W]_G3]<BX`0G4@;G5M87)A(&5N(&%Z_6YD86X@8FER(&]L;6%L
M_63]<BX`0G4@<W5N=6-U('II<"!V92!G>FEP(&1O<WEA;&%R_6[](&'G86UA
M;6%K=&%D_7(N`%-I<W1E;6EN(&5T:VEN;&GP:2!K86QD_7+];&W]_G3]<BX`
M0G4@9&7P97(@8FER('-A>?T@;VQM86S]9/UR+@!"=2!P96YC97)E(%-EYV5N
M96ML97(@<&5N8V5R97-I;F1E;B#G8?!R_6QM86S]9/UR+@!']FL@9_QR_&QT
M_'/\`$)I;&5T;&5R`%IA;6%N`%IA;6%N(-UZ;&5M90!:86UA;B!":>=I;6D`
M6F%M86X@4V7G:6UI`%1I;6]R+4QE<W1E`$)A_FS]:P!"8?YL_6L@*&'G_6ML
M86UA*3H`2VEM90#';VML=2#V\&4@<V7G:6UI(&GG:6XL('3]:VQA<FME;B!#
M;VYT<F]L("A00RD@=F5Y82!#;VUM86YD("A-86,I('1U_G5N82!B87/];BX`
M0G5G_&X`2%1-3"!+87EN8?#];F$@1V7G:6X`5&]G;P!4;VME;&%U`%EA<OUN
M`%1O;F=A`-QS=`#<<W0@QV5RYV5V92`HW%]S="D`QV5V:7)I;&5R`%1R:6YI
M9&%D('9E(%1O8F%G;P!$;_!R=2!V97EA(%EA;FS]_@!380!4=6YU<P!4_')K
M:7EE`%3\<FOG92`H25-/+3@X-3DM.2D`5/QR:VUE;FES=&%N`%1U<FMS('9E
M($-A:6-O<R!!9&%L87+]`%1U=F%L=0!39>=I;6EN:7II(&=I<FEN.@!5+E8N
M(&5N9&5K<SH@`%523`!"971I:VQE<FEN(&1U<G5M(')A<&]R;&%R_6[];B!T
M97-L:6T@961I;&5C9?!I(%523`!54DPZ`%5G86YD80!5:W)A>6YA`%9&4R!D
M:7II;FEN92!E<FG^:6QE;65M:7EO<BX`W'EE(&]L=7)K96X@96L@:W5L;&%N
M_6/](&)I;&=I<VD@96ML96YE;6EY;W(N`"(E<R(@5D93(&1O<WEA<_UN_6X@
M:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO<BX`)7,O)7,@5D93(&1O<WEA<_UN
M_6X@:7II;FQE<FD@9&7P:?YT:7)I;&5M:7EO<BX`)7,@9&7P:?YT:7)I;&5M
M961I+@!344P@<W5N=6-U<W5N82!B8?!L86[];&%M_7EO<BX`4U-,(&EL92!B
M8?!L86[];&%M_7EO<BX`5D93(&1O<WEA<_T@:V]P>6%L86YA;?UY;W(N`"(E
M<R(@5D93(&1I>FEN:2!Y87)A=/UL86W]>6]R+@!61E,@9&EZ:6YI('EA<F%T
M_6QA;?UY;W(N`%9&4R!D;W-Y87/]('EA<F%T_6QA;?UY;W(N`$)O_B!61E,@
M9&]S>6%S_2!Y87)A=/UL86W]>6]R+@!697)I('/]:_W^=/UR_6QA;?UY;W(N
M`"(E<R(@9&EZ:6YI('-I;&EN96UI>6]R+"!D:7II;B!B;_X@9&7P:6PN`"5S
M('-I;&EN96UI>6]R+"!D:7II;B!B;_X@9&7P:6P`5D93(&1I>FEN:2#V>GEI
M;F5L:2!O;&%R86L@<VEL:6YE;6EY;W(N`%9&4R!D:7II;FD@<VEL:6YE;6EY
M;W(N`%9&4R!D:7II;FD@<VEL:6YE;6EY;W(Z("5S+@!61E,@9&]S>6%S_2`B
M)7,B('-I;&EN96UI>6]R+@!61E,@9&]S>6%S_2!S:6QI;F5M:7EO<BX`5D93
M(/9Z>6EN96QI(&]L87)A:R!S:6QI;F5M:7EO<CH@)7,N`%G\<OQR;/QK=&5K
M:2!D:7II;F4@:V%R87(@=F5R:6QE;6EY;W(N`$]N87D@8F5L9V5S:2!A>7+]
M;G3];&%R_2#G_6MA<G3];&%M_7EO<@!486[];?T@>?QK;&5N96UI>6]R.B`E
M<P!61E,@9&]S>6%S_2!T8?[];F%M_7EO<BX`5D93(&1O<WEA<_T@(B5S(B!A
MY_UL86W]>6]R+@!61E,@9&]S>6%S_2!Y86UA:R!IYVEN(&'G_6QA;?UY;W(N
M`%9&4R!D;W-Y87/](&'G_6QA;?UY;W(N`%/]:_W^=/UL_6W]_B!A<OYI=B!A
MY_UL86W]>6]R+@!69G-R;V]T(&1I>FEN:2!O:W5N86W]>6]R+@`E<RT^)7,@
M;VQA<F%K('EE;FED96X@861L86YD_7+];&%M_7EO<CH@:&5D968@9&EZ:6X@
M>F%T96X@=F%R+@!61E,@9&EZ:6YI('EE;FED96X@861L86YD_7+];&%M_7EO
M<BX`5D93(&1I>FEN:2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(Z("5S`%9&
M4R!D;W-Y87/]("(E<R(@>65N:61E;B!A9&QA;F3]<OUL86W]>6]R+@`E<R\E
M<R!61E,@9&]S>6%S_2!Y96YI9&5N(&%D;&%N9/UR_6QA;?UY;W(N`%9&4R!D
M;W-Y87/]('EE;FED96X@861L86YD_7+];&%M_7EO<BX`)VUK:7-O9G,G(.=A
M;/W^=/UR_6QA;?UY;W(N`$)U(%=O<F0@8F5L9V5S:2#G979I<FEL:6QE;6EY
M;W(N`%9&4R!D;W-Y87/]("(E<R(@>6%Z_6QA;?UY;W(N`%9&4R!D;W-Y87/]
M('EA>OUL86W]>6]R("AC;W!Y*"D@8F'^87+]<_UZ(&]L9'4I+@!61E,@9&]S
M>6$@=F5R:7-I('EA>OUL86W]>6]R+@!!;'3];OT@YVEZ`$1E\&G^:6ML:6ML
M97)I($=E<FD@06P`4V]N(&5Y;&5M:2!G97)I(&%L`$)A\&QA;G3]9&$@<W5N
M=6-U9&%N(&)E:VQE;FUE>65N('EA;OUT.B``4W5N=6-U9&%N(&)E:VQE;FUE
M>65N('EA;OUT.B``1&]L9'5R=6QM86W]_@!5;FEC;V1E("A55$8M."D`0FER
M;&7^:6L@07)A<"!%;6ER;&EK;&5R:0!":7)L9?YI:R!+<F%L;/UK`$%M97)I
M:V$@0FER;&7^:6L@1&5V;&5T;&5R:0!!;65R:6MA($)I<FQE_FEK($1E=FQE
M=&QE<FEN:6X@2_SG_&L@57IA:R!!9&%L87+]`$)I<FEM;&5R`$)I;&EN;65Y
M96X`0FEL:6YM97EE;B!A<&EM<V=I9"`H05!)($UE<V%J($E$*0!":6QI;FUE
M>65N(&-L:6US9VED("C=<W1E;6-I(&UE<V%J($E$*0!":6QI;FUE>65N(&MU
M;&QA;OUC_2!A9/T@=F5Y82!P87)O;&$N`-YU(&%N:VD@]O!E;FEN(&)A\/UN
M_2#G]GH`W7-I;7-I>@!!>7+]8V%L_6MS_7H@8F5T:6ML97(@<')O9W)A;7-A
M;"!O;&%R86L@2V5S+TMO<'EA;&$O66%P_?YT_7(G82!G_'9E;FQI:R!N961E
M;FEY;&4@97)I_F5M97IL97(N($)E=&EK;&5R:6X@<&%N;WEA(&YA<_UL('5L
M8?YA8V'P_6[](&?V<W1E<F5N(&UO>FEL;&$N;W)G('1E:VYI:R!N;W1U;G4@
M9_9R;65K(&GG:6X@159%5"!I('3]:VQA>?UN+@!"96QI<G1I;&UI_B!R96YK
M=&5N('9A>F=EYP!$97-T96ML96YM97EE;B!5>F%N=/T`1_QN8V5L;&4`1_QN
M8V5L;&4Z("5S`$MU;&QA;OUC_7G](&?\;F-E;&QE`%G\:W-E;'1M92!B971I
M\&D@<VEL:6QN9&DN`%G\:VQE`$+\=/QN('5Y9W5L86UA;&%R_6X@87EA<B!D
M;W-Y86QA<OT@<W5N=6-U>6$@>?QK;&5N9&DN`$+\>?QK(&QA=&EN(&AA<F9L
M97)I`$+\>?QK(')O;6$@<F%K86UL87+]`%5R=6=U87D`2W5L;&%N.B`E<P!3
M4TP@:W5L;&%N`$MU;&QA;OUC_2!A9/UN_7HO<&%R;VQA;OUZ($E-4U`@<W5N
M=6-U(&GG:6X@9F%R:VS](&ES92!K=6QL86[];BX`)7,@:W5L;&%N_6/]<_T@
M)7,@:>=I;B!D;_!R=6QA;F%M863]+@!+=6QL86[]8_T@6?9N971I;6D`2W5L
M;&%N_6/](%-EYV5N96ML97)I`$MU;&QA;OUC_2!+87G]=`!"=2!S:71E(&GG
M:6X@:W5L;&%N_6/](&MA>63]('-EYVEL;65Z(&O];/UN;?W^=/UR+@!+=6QL
M86[]8_T@063]`$MU;&QA;OUC_2!!9/TZ`$MU;&QA;OUC_2!A9/TZ(`!3:7-T
M96UD96MI(&MU;&QA;OUC_6QA<CH`UGIB96MI<W1A;@!61E,@9&EZ:6YI('EO
M:RX`5&%T:6P`1V7G97)L:2!K;VYU;6QA<OUN(&GG97)D:6ML97)I.@!'9>=E
M<FQI;&EK`-YU(&%N9&%N(&ET:6)A<F5N(&1A:VEK82!D9?!E<FD`1&7P97)L
M97(`1&7P97)L97)I;B!S9>=I;&5C9?!I`%9A;G5A='4`1&7P:?YK96X`5F5N
M97IU96QL80!$;_!R=6QA;6$@8F'^87+]<_UZ(&]L9'4@+2!B=2!I;&5T:2!K
M=7)C86QA;FW]_B!O;&%B:6QI<BX@(`!3_'+\;0!3_'+\;2!+;VYT;VS\`$3\
M_F5Y($AI>F$`1/S^97D@>6%S=/UK;&%M80!$_/YE>3H`QV]K(%G\:W-E:P!6
M:65T;F%M`%9I971N86UC82`H5DE30TE)*0!']G+\;G3\;&4@)7,`0FER(&3]
M_B!W96(@<V%Y9F%S_2!G]G+\;G3\;&4`)7,@;VQA<F%K(&?V<OQN=/QL90!"
M<FET86YY82=Y82!A:70@5FER9VEN($%D86QA<OT`06UE<FEK82!":7)L97+^
M:6L@1&5V;&5T;&5R:2=N92!A:70@5FER9VEN($%D86QA<OT`1_9R_/X`1_9R
M_/XZ`%--5%`@>6]L=7EL82!6;V1A9F]N92#==&%L>6$`5T%23@!564%222$A
M(25S(-W'W4Y$14X@0D54W=#=($5,(-U,12#'24M!4E1)3BX`5V%L;&ES('9E
M($9U='5N80!5>6%R_0#'<OX`2&%V82!486AM:6YI`$AA=F$@=F5R:7-I('-A
M\&QA>?UC_7/]`%=E871H97(N8V]M`%=E8@!796(@4VET97-I`$AA9G1A;/UK
M`$AO_F=E;&1I;FEZ`"5S($AO_F=E;&1I;FEZ`$AO_F=E;&1I;FEZ+"`E<P!"
M873]("A)4T\M.#@U.2TQ*0!"873]("A)4T\M.#@U.2TQ-2D`0F%T_2!386AR
M80`E<R!G:7)I_G1E;B!S;VYR82!H86YG:2!U>6=U;&%M87G](&?V<OQN=/QL
M97-I;C\`4_UN_7)L87G]8_T@:V%R86MT97(@;F5D:7(_`$%K=&%R_6T@:V%R
M86MT97)I(&YE9&ER/P!(86YG:2!%=G)E`%IE;F=I;B!-971I;B!D_'IE;FQE
M>6EC:7-I(&GG:6X@:&%N9VD@=7EU;6QU(&5K;&5R('-EYVEL96)I;&ER(&O]
M;/UN<_UN+@!'96YI_FQI:P!#4U,@8FER:6UI>6QE(&=E;FG^;&EK`%-O;&1A
M:VD@)7,@;65N_'/\;OQN(&=E;FG^;&GP:2`H8FER('-O;G)A:VD@9VER:?YT
M92!E=&MI;B!O;&%C86LI.@#':7IE;&=E;FEN(&=E;FG^;&GP:0!'96YI_FQI
M:R!B:7)I;6D`1V5N:?YL:6LZ`%=I:VD`4OQZ9V%R`$5R:V5N(%-A871L97)D
M92!2_'IG87(`2VYO="!B:7)I;6EN9&4@<OQZ9V%R(&C]>OT`4OQZ9V%R.@!2
M_'IG87(Z(`!":6QG96QI:P#=_@#=_B!!9')E<VD`W?X@5&5L969O;G4`6"U2
M968`6#4P.78S(%1E;65L($O]<_UT;&%M86QA<OT`6#4P.78S($=E;FG^;&5T
M:6QM:?X@06YA:'1A<B!+=6QL86[];?T`6#4P.78S(-9T96MI($MO;G4@063]
M`%@U,#EV,R!+;VYU($%N86AT87(@5&%N_73]8_US_0!8-3`Y=C,@=7IA;G3]
M;&%R_0!960!965E9`%EA:&]O(2!H87)I=&%S_0!9_6QL_6L`665M96X`179E
M=`!%=F5T+"!+86)U;"!%9&EY;W)U;0!-153=3B!-3T153D1!4TE.25HN(%L\
M/ET@9/SP;65L97)I;FD@:W5L;&%N87)A:R!765-)5UE'(&?V<OQN_&W\;F4@
M9/9N_&XN`$1O\')U;&%N86UA9/UN_7HN`"=<)R!K87)A:W1E<FD@=&%M(&%D
M_6[]>F1A(&)U;'5N86UA>BX`1V7G97)L:2!B:7(@96QE:W1R;VYI:R!P;W-T
M82!A9')E<VD@9VER;65D:6YI>BX`)7,@:>=I;F1E(&MA<O[];/UK(&=E;&5N
M(&%L86YL87)L82`H:>=E<FDI(&%K=&%R_6QA;B!D;W-Y861A:VD@86QA;FQA
M<OT@9?YL9?YT:7)M961I;FEZ+@#'_6O]_B!Y87!M863];OUZ+@!'9>=E<FQI
M(&)I<B!C97`@=&5L969O;G4@;G5M87)A<_T@9VER;65L:7-I;FEZ+"!S87G]
M;&%R('9E('-EYV5N96ML:2!O;&%R86L@=6QU<VQA<F%R87/](&%R86UA(/9N
M96MI("<K)R``1V7G97)L:2!B:7(@9&7P97(@9VER;65L:7-I;FEZ+@#<>64@
M:V%Y9/T@>6%P86)I;&UE:R!IYVEN(&)I<B!697)I0?!A8_T@>6%P_6QA;F3]
M<FUA;/US_6[]>BX`5D93('-O;B!A_F%M87/];OT@>6%P_6QA;F3]<FUA;/US
M_6[]>BX`4')O8FQE;2!R87!O<G4@9_9N9&5R;65D96X@]FYC92!S;W)U;G4@
M=&%R9FD@971M96QI<VEN:7HN`$)U(&)A\&QA;G3];OUN(&?V<W1E<F1I\&D@
M8FER(%523"!G:7)M96QI<VEN:7H`4VEL:6YM97-I(&GG:6X@8FER('-U;G5C
M=2!S9>=M96QI<VEN:7HN`%1E;6EZ;&5N;65S:6X@:>=I;B!B:7(@:W5L;&%N
M_6/](&%D_2!B96QI<G1M96QI<VEN:7HN`%-I;&EN;65S:2!IYVEN(&)I<B!K
M=6QL86[]8_T@863](&)E;&ER=&UE;&ES:6YI>BX`16ML96YM97-I(&GG:6X@
M8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!'_&YC96QL96YM
M97-I(&GG:6X@8FER(&MU;&QA;OUC_2!A9/T@8F5L:7)T;65L:7-I;FEZ+@!'
M97+G96ML9?YT:7)I;&5C96L@8FER(&5Y;&5M(&)E;&ER=&UE;&ES:6YI>BX`
M665N:2!K871E9V]R>2!A9/T@9VER;65L:7-I;FEZ+@`E<R!O='5R=6UU;G5N
M('/\<F5S:2!D;VQD=2X@3/QT9F5N('1E:W)A<B!G:7)I_B!Y87#];BX`16QE
M:W1R;VYI:R!0;W-T82!!9')E<VEN:7H`2VEM9&5N.B!A9')E<SH`0FEL9VEL
M97)I;FEZ`"5S(&]T=7)U;75N=7IU;B!B8?YL86YG_6/];F1A(-UN=&5R;F5T
M($%D<F5S:6YI;FEZ(&1E\&G^=&DN($?\=F5N;&GP:6YI>FD@:V]R=6UA:R!I
MYVEN+"!Y96YI9&5N(&=I<FG^('EA<&UA;/US_6[]>BX`063];OUZ`$MI;6QI
M:R!D96YE=&EM:6YI>B!K=6QL86[]8_T@;&ES=&5L96UE>6D@9&5S=&5K;&5M
M96UE:W1E9&ER('9E>6$@8G4@]GIE;&QI:R!B:7(@;F5D96X@>?QZ_&YD96X@
M<V7G:6QE;65Z(&O];/UN;?W^=/UR+@`E<R!O='5R=6UU;G5Z=6X@8F'^;&%N
M9_UC_6YD82!T87)A>?UC_6[]>B!D9?!I_G1I+B!'_'9E;FQI\&EN:7II(&MO
M<G5M86L@:>=I;BP@>65N:61E;B!G:7)I_B!Y87!M86S]<_UN_7HN`%1A<F%Y
M_6/];OUZ(&)U(/9Z96QL:?!I(&1E<W1E:VQE;65M96MT961I<BX`6F%M86X@
M1&EL:6UI;FEZ.@#6;B!T86[];6S](&MI;6QI\&EN:7HZ`%1A;2!!9/UN_7HZ
M`"5S(&GG:6X@>65N:2!P87)O;&%N_7HZ("5S`%-EYV5N96ML97)I;FEZ(&)U
M(&]T=7)U;75N('/\<F5S:2!IYVEN9&4@9_QN8V5L;&5N9&DN`%-EYV5N96ML
M97)I;FEZ(&?\;F-E;&QE;F1I+@!087)O;&%N_7H@<_UF_7)L86YD_2X`4&%R
M;VQA;OUZ('/]9OUR;&%N9/TL(&5L96MT<F]N:6L@<&]S=&%N_7K](&MO;G1O
M;"!E9&EN('9E('EE;FD@<&%R;VQA;OUZ;&$@9VER:?X@>6%P_6XN`%5Z86MT
M86MI('-U;G5C=6QA<OUN_7HZ`%EU9V]S;&%V>6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G9E`$C]>FS]`%M!;/UN=/T@365T;FD@4V%K;&%=`%M0<F]B;&5M(%)A
M<&]R=5T`6T%L_6YT_2!-971N:2!']G-T97(@+0!;06S];G3]($UE=&YI($?V
M<W1E<B`M("5S('-A=/UR70`E<R\E<R!S873]<@!?6?9N971I;0!?0TQ)`%]6
M97)I0?!A8_T`4V%T_7+](%]3:6P`7T=R=7!L87(`66%R7V3];0!']G+\;G3\
M(-9?>F5L;&EK;&5R:2XN+@!':5]R:?X`Q_U?:_W^`%]"8?!L86YT_7G]($1E
M\&G^=&ER+BXN`%]39>=E;F5K;&5R`%](86ML87(`0F'P;&%?;G3]>?T@4VEL
M+BXN`%]!>6%R;&%R`,=I>F5?;&=E(-9Z96QL:6ML97)I+BXN`$M?=6QL86[]
M8_UL87(`861R97,@9&5F=&5R:0!T86MV:6T`_6S];6S]`&)U<F%Y82!T_6ML
M87G];@!D_/[\>6]R`&1O<WEA`"5S("@E<RD@9&5N("5S("5S(&1E`&@Z`$%C
M:6P`365T;F4@9_9M_&S\`'-A=/UR;&%R70!M:VES;V9S($E33R!Y87!A<FME
M;B!H871A(&MO9'4Z)60N`&%D`&=E<N=E:VQE_G1I<FEL;65D:0!H96[\>B!G
M97+G96ML9?YT:7)I;&UE9&D`;F]T(&1E9G1E<FD`>?QZ9&4`<F5S:6T@8FER
M:6UI`'G\:W-E;&EY;W(`9F%R:VQA<OT@9_9S=&5R`$A45%`@>6]L=7EL82!S
M;7,R96UA:6P`<V%B:70`9_9R978@;&ES=&5S:0!P87)O;&%Y_2!D;_!R=6QA
M;6%K(&GG:6X@:6MI(&1E9F$@9VER:6X`8FER;&7^=&ER:6QM:?X`861L86YD
M_7+];&UA;?W^`&MU;&QA;OUC_2!S9>=I;6D`=D-A<F0`=SH`=V5A=&AE<BYC
M;VT`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S=E]312],0U]-15-3
M04=%4P``````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$T,2`P,C$U,34`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W-V7U-%+VAE;'`N>&UL````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`S,S(P(#$P-3$U-#,T,30Q(#`R,30U-P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/WAM;"!V97)S
M:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]S=E]312]H
M96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$R(&IA;B!%>'`@)"`M
M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*
M/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES
M('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@
M>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET
M(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*
M("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R
M(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI
M;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@
M36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@
M<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP
M;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE
M;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4
M:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA
M8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U
M(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O
M<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R
M92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A
M<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A
M=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S
M:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A
M=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A
M=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E
M96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4]
M(FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$
M;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W
M;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O
M;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T
M93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z
M($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)
M9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T
M87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@
M;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H
M870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC
M86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\
M+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S
M=E]312],0U]-15-304=%4R]H;W)D92YM;P``````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#0Q,S4T-B`Q,#4Q-30S-#$T,2`P,C,R-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````WA($E0````#D!P``'```
M`#P_``"%"@``7'X```````!PJ```2````'&H```.````NJ@```\```#)J```
M#````-FH```-````YJ@```@```#TJ```"P```/VH```,````":D```0````6
MJ0``&````!NI```;````-*D``"T```!0J0``'0```'ZI```D````G*D``"D`
M``#!J0``&0```.NI```F````!:H```P````LJ@``)````#FJ```/````7JH`
M``L```!NJ@``#@```'JJ```%````B:H``"@```"/J@``"````+BJ```*````
MP:H``!4```#,J@``$@```.*J```+````]:H``!0````!JP``)@```!:K```G
M````/:L``"8```!EJP``A0```(RK```.````$JP```H````AK```#0```"RL
M```G````.JP``"````!BK```#@```(.L```7````DJP``"(```"JK```-0``
M`,VL```1`````ZT```T````5K0``#````".M```-````,*T```8````^K0``
ME````$6M```*````VJT```\```#EK0``&````/6M```,````#JX```X````;
MK@``#@```"JN```(````.:X```D```!"K@``+@```$RN```:````>ZX``#(`
M``"6K@``.````,FN``!4`````J\``%$```!7KP``6@```*FO``!7````!+``
M`#0```!<L```"0```)&P```-````F[````<```"IL```"@```+&P```/````
MO+````4```#,L```!@```-*P```1````V;````@```#KL```"0```/2P```)
M````_K````X````(L0``"````!>Q```E````(+$``"````!&L0``$P```&>Q
M```0````>[$```\```",L0``"@```)RQ```'````I[$```,```"OL0``!@``
M`+.Q```/````NK$``!0```#*L0``"0```-^Q```-````Z;$``!(```#WL0``
M&0````JR```>````)+(```\```!#L@``"@```%.R```/````7K(```@```!N
ML@``)````'>R```7````G+(``!0```"TL@``%@```,FR```(````X+(``$X`
M``#IL@``+0```#BS```9````9K,```<```"`LP``#````(BS```L````E;,`
M``X```#"LP```P```-&S```+````U;,```<```#ALP``!P```.FS```%````
M\;,```4```#WLP``"@```/VS```#````"+0``!<````,M```"@```"2T```/
M````+[0```X````_M```&````$ZT```C````9[0```X```"+M```%````)JT
M```7````K[0``!<```#'M```%P```-^T```3````][0```\````+M0``#@``
M`!NU```I````*K4``!\```!4M0``'0```'2U```'````DK4```8```":M0``
M"````*&U```/````JK4```8```"ZM0``"@```,&U```3````S+4```L```#@
MM0``$````.RU```5````_;4``!4````3M@``!P```"FV```0````,;8```4`
M``!"M@``%0```$BV```1````7K8```P```!PM@``.P```'VV```X````N;8`
M``D```#RM@``!P```/RV```4````!+<```,````9MP``!0```!VW```0````
M([<```D````TMP``$P```#ZW```Y````4K<``!(```",MP``.0```)^W```G
M````V;<``"P````!N```*@```"ZX```E````6;@```D```!_N```"@```(FX
M```&````E+@```D```";N```!P```*6X```O````K;@``#<```#=N```+@``
M`!6Y``!5````1+D``"T```":N0``+0```,BY```]````]KD``#\````TN@``
M+0```'2Z``!`````HKH``",```#CN@``(P````>[``!`````*[L``"T```!L
MNP``,P```)J[```E````SKL``!4```#TNP``&0````J\```I````)+P``"0`
M``!.O```*````'.\```1````G+P``!$```"NO```"@```,"\```$````R[P`
M``P```#0O```"@```-V\```0````Z+P``!8```#YO```%@```!"]```'````
M)[T```<````OO0``%````#>]```*````3+T```@```!7O0``"````&"]```(
M````:;T```8```!RO0``)P```'F]```(````H;T```<```"JO0``!P```+*]
M```&````NKT```4```#!O0``!P```,>]```&````S[T```@```#6O0``*0``
M`-^]```.````";X```H````8O@``"0```".^```.````+;X```0````\O@``
M!P```$&^```)````2;X```8```!3O@``$0```%J^```'````;+X``!8```!T
MO@``!````(N^```(````D+X```8```"9O@``#0```*"^```&````KKX``!X`
M``"UO@``!0```-2^```1````VKX```@```#LO@``#0```/6^```,`````[\`
M``P````0OP``!P```!V_```#````);\```,````IOP``%P```"V_```3````
M1;\``!T```!9OP``"````'>_```$````@+\```@```"%OP``"````(Z_```*
M````E[\``$$```"BOP``&@```.2_```K````_[\``"`````KP```%0```$S`
M```&````8L````8```!IP```%0```'#````8````AL```"(```"?P```+@``
M`,+````=````\<```"$````/P0``*0```#'!```*````6\$```<```!FP0``
M!P```&[!```5````=L$```X```",P0``"@```)O!```/````IL$```T```"V
MP0``#P```,3!```-````U,$```D```#BP0``%````.S!```&`````<(``!@`
M```(P@``'0```"'"```3````/\(``!$```!3P@``%````&7"```$````>L(`
M``P```!_P@``!@```(S"```4````D\(``!<```"HP@``5````,#"``!D````
M%<,```0```!ZPP``#@```'_#``!$````CL,```4```#3PP``!0```-G#```;
M````W\,``!H```#[PP``$P```!;$```1````*L0``!$````\Q```$0```$[$
M```<````8,0``"H```!]Q```$````*C$```A````N<0```4```#;Q```$P``
M`.'$```+````]<0``!(````!Q0``"@```!3%```/````'\4```T````OQ0``
M$0```#W%```3````3\4```P```!CQ0``!@```'#%```,````=\4```8```"$
MQ0``%P```(O%```0````H\4``!$```"TQ0``"````,;%```%````S\4```P`
M``#5Q0``$````.+%```%````\\4```T```#YQ0``!@````?&```'````#L8`
M``T````6Q@``!P```"3&```+````+,8```<````XQ@``!P```$#&```)````
M2,8``!0```!2Q@``"0```&?&```)````<<8```H```![Q@``&0```(;&```]
M````H,8``!T```#>Q@``#````/S&```0````"<<```4````:QP``)0```"#'
M```2````1L<``!,```!9QP``*P```&W'```[````F<<``"````#5QP``"```
M`/;'```V````_\<``"$````VR```$````%C(```(````:<@```P```!RR```
M!@```'_(```$````AL@```\```"+R```#@```)O(```*````JL@```<```"U
MR```"@```+W(```-````R,@``!X```#6R```'P```/7(```;````%<D``!P`
M```QR0``(0```$[)```>````<,D``!D```"/R0``'@```*G)```;````R,D`
M`"$```#DR0``+@````;*```F````-<H``!L```!<R@``'````'C*```>````
ME<H``!P```"TR@``)@```-'*```K````^,H``#,````DRP``)@```%C+```K
M````?\L``#@```"KRP``'0```.3+```=`````LP``!4````@S```%0```#;,
M```O````3,P``"````!\S```$@```)W,```@````L,P``"D```#1S```'@``
M`/O,```>````&LT``"`````YS0``$@```%K-``"B````;<T``!8````0S@``
M(P```"?.```H````2\X``"D```!TS@``*````)[.```?````Q\X``!4```#G
MS@``%0```/W.```@````$\\``"4````TSP``*````%K/```M````@\\``#``
M``"QSP``D@```.+/```A````==```!8```"7T```%@```*[0```<````Q=``
M`"8```#BT```*@````G1``!!````--$``$0```!VT0``#````+O1```'````
MR-$```<```#0T0``!@```-C1```-````W]$``!````#MT0``$@```/[1```3
M````$=(``!(````ET@``!P```#C2```$````0-(``!````!%T@``$````%;2
M```,````9](```X```!TT@``#0```(/2```/````D=(``!,```"AT@``#0``
M`+72```H````P](```,```#LT@``#0```/#2```&````_M(``!$````%TP``
M%P```!?3```;````+],```X```!+TP```@```%K3```%````7=,``!````!C
MTP``#P```'33```$````A-,```T```")TP``#@```)?3```#````IM,```X`
M``"JTP``"````+G3```/````PM,```@```#2TP``#P```-O3```'````Z],`
M``T```#STP``$`````'4```-````$M0```L````@U```$0```"S4```)````
M/M0```8```!(U```"P```$_4```,````6]0```H```!HU```$0```'/4```9
M````A=0```L```"?U```#0```*O4```B````N=0```\```#<U```&P```.S4
M```T````"-4```H````]U0``&````$C5```2````8=4``!D```!TU0``%@``
M`([5```0````I=4``"(```"VU0``#0```-G5```'````Y]4```P```#OU0``
M)@```/S5```4````(]8```L````XU@``(@```$36```O````9]8```L```"7
MU@``"0```*/6```9````K=8```L```#'U@``%P```-/6```7````Z]8```D`
M```#UP``%@````W7```/````)-<``!D````TUP``%@```$[7```.````9=<`
M``<```!TUP``"````'S7```-````A=<``"8```"3UP``0P```+K7```2````
M_M<``!\````1V```"````#'8```+````.M@``"\```!&V```#@```';8```%
M````A=@```8```"+V```10```)+8```#````V-@```<```#<V```!````.38
M```*````Z=@```H```#TV```#P```/_8```0````#]D``!<````@V0``$0``
M`#C9```9````2MD``!<```!DV0``"0```'S9```%````AMD```L```",V0``
M"@```)C9```"````H]D```4```"FV0``#0```*S9```;````NMD``!<```#6
MV0``%````.[9```)`````]H```X````-V@``#0```!S:```2````*MH```,`
M```]V@``"````$':```.````2MH``!@```!9V@``&````'+:```%````B]H`
M`!@```"1V@``'@```*K:```;````R=H``!D```#EV@``&````/_:```;````
M&-L``!,````TVP``$P```$C;```'````7-L```@```!DVP``!@```&W;```&
M````=-L``!````![VP``#P```(S;```0````G-L```\```"MVP``"P```+W;
M```/````R=L```P```#9VP``#P```.;;```'````]ML```8```#^VP``#@``
M``7<```,````%-P``"@````AW```#P```$K<```(````6MP```@```!CW```
M$P```&S<```>````@-P``"$```"?W```(````,'<```9````XMP``!<```#\
MW```)0```!3=```7````.MT``!8```!2W0``!````&G=```;````;MT```T`
M``"*W0``#````)C=```#````I=T```4```"IW0``"````*_=```*````N-T`
M``P```##W0``"P```-#=```0````W-T```P```#MW0``#@```/K=```+````
M"=X```0````5W@``!````!K>```3````']X``!0````SW@``#````$C>```)
M````5=X```X```!?W@``"P```&[>```;````>MX```<```"6W@``!P```)[>
M```*````IMX```T```"QW@``&````+_>```*````V-X```0```#CW@``)@``
M`.C>```.````#]\``'P````>WP``%0```)O?```%````L=\```<```"WWP``
M#````+_?```(````S-\```H```#5WP``!@```.#?```(````Y]\```(```#P
MWP``!@```//?```&````^M\``!0````!X```%0```!;@```/````+.```!$`
M```\X```&@```$[@```-````:>```!````!WX```&P```(C@```$````I.``
M``D```"IX```$````+/@```)````Q.````D```#.X```!0```-C@```:````
MWN````@```#YX```!@````+A```9````">$```X````CX0``!P```#+A```'
M````.N$```4```!"X0``"0```$CA```*````4N$```X```!=X0```@```&SA
M```&````;^$```L```!VX0``#0```(+A```)````D.$```8```":X0``!0``
M`*'A```)````I^$```<```"QX0``!````+GA```4````ON$``$(```#3X0``
M)0```!;B```E````/.(```8```!BX@``!````&GB```)````;N(```@```!X
MX@``$0```('B```.````D^(```D```"BX@``!@```*SB```-````L^(```8`
M``#!X@``!````,CB```Y````S>(``#T````'XP``.@```$7C```>````@.,`
M``4```"?XP``#@```*7C```$````M.,```8```"YXP``!P```,#C```A````
MR.,```T```#JXP``%0```/CC```&````#N0``!(````5Y```!````"CD```1
M````+>0```8````_Y```"@```$;D```B````4>0```0```!TY```!0```'GD
M```$````?^0```P```"$Y```#@```)'D```*````H.0```@```"KY```"0``
M`+3D```%````ON0``#H```#$Y```,````/_D```U````,.4``"D```!FY0``
M1P```)#E```X````V.4``"D````1Y@``/P```#OF```N````>^8``"T```"J
MY@``'P```-CF```/````^.8``!(````(YP``"P```!OG```F````)^<``"D`
M``!.YP``)````'CG```F````G><```@```#$YP``"@```,WG```)````V.<`
M``<```#BYP``(````.KG```@````"^@``"8````LZ```"@```%/H```9````
M7N@``"D```!XZ```%@```*+H```2````N>@```<```#,Z```"@```-3H```,
M````W^@```\```#LZ```$````/SH``!`````#>D``'````!.Z0``9@```+_I
M```.````)NH```D````UZ@``"@```#_J```2````2NH``!,```!=Z@``#```
M`''J```&````?NH```\```"%Z@``$@```)7J```0````J.H```H```"YZ@``
M$0```,3J```<````UNH``",```#SZ@``:@```!?K```/````@NL```4```"2
MZP``$````)CK```)````J>L```0```"SZP``"P```+CK```@````Q.L``!0`
M``#EZP``#````/KK```,````!^P```\````4[```%0```"3L```I````.NP`
M`"H```!D[```)@```(_L```G````MNP``"D```#>[```*@````CM```9````
M,^T``!$```!-[0``$@```%_M```3````<NT``!0```"&[0``#P```)OM```6
M````J^T``!<```#"[0``$````-KM```1````Z^T``#0```#][0``$P```#+N
M```2````1NX``#4```!9[@``%````(_N```'````I.X```P```"L[@``*P``
M`+GN```@````Y>X``!`````&[P``%````!?O```1````+.\``!<````^[P``
M'````%;O```3````<^\``!0```"'[P``&@```)SO```1````M^\``!H```#)
M[P``'@```.3O```:`````_```!,````>\```%0```#+P```1````2/```!<`
M``!:\```%````'+P```7````A_```!4```"?\```"0```+7P```0````O_``
M`!D```#0\```!````.KP```'````[_````L```#W\```$0````/Q```&````
M%?$```8````<\0``!@```"/Q```%````*O$```<````P\0``!P```#CQ```%
M````0/$``!8```!&\0``!@```%WQ```&````9/$```0```!K\0``!````'#Q
M```'````=?$```X```!]\0``#````(SQ```,````F?$```T```"F\0``!0``
M`+3Q```H````NO$```P```#C\0``#P```/#Q```*`````/(```@````+\@``
M"0```!3R```K````'O(```0```!*\@``"````$_R```%````6/(``"8```!>
M\@``$@```(7R```/````F/(```8```"H\@``"@```*_R```'````NO(```@`
M``#"\@``(````,OR```)````[/(``!0```#V\@``#`````OS```-````&/,`
M``X````F\P``%@```#7S```1````3/,```8```!>\P``"````&7S```#````
M;O,```8```!R\P``&0```'GS```'````D_,```0```";\P``"P```*#S```+
M````K/,```<```"X\P``!0```,#S```'````QO,``!8```#.\P``#0```.7S
M```*````\_,```T```#^\P``"@````ST```0````%_0```\````H]```$0``
M`#CT```7````2O0```H```!B]```$0```&WT```(````?_0```0```"(]```
M#P```(WT```Z````G?0```4```#8]```#````-[T```>````Z_0```X````*
M]0``$````!GU```+````*O4```P````V]0``"0```$/U```'````3?4```H`
M``!5]0``"0```&#U```.````:O4``!````!Y]0``&P```(KU```8````IO4`
M`!H```"_]0``"@```-KU```)````Y?4```H```#O]0``#````/KU```/````
M!_8```@````7]@``!@```"#V```'````)_8```4````O]@``"P```#7V``!'
M````0?8```T```")]@``"0```)?V```$````H?8```,```"F]@``$P```*KV
M```3````OO8``!,```#2]@``!@```.;V```+````[?8```H```#Y]@```@``
M``3W```$````!_<``"4````,]P```P```#+W```%````-O<``"H````\]P``
M"@```&?W```%````<O<```0```!X]P``"@```'WW```-````B/<```8```"6
M]P``"````)WW```(````IO<```0```"O]P``!0```+3W``!H````NO<```D`
M```C^```#````"WX```0````.O@```4```!+^```!@```%'X```;````6/@`
M`"\```!T^```$````*3X```*````M?@```\```#`^```"@```-#X```)````
MV_@``!,```#E^```&P```/GX```8````%?D``!<````N^0``'P```$;Y```.
M````9OD```,```!U^0``!P```'GY```(````@?D``!0```"*^0``$P```)_Y
M```0````L_D```T```#$^0``#@```-+Y```6````X?D```<```#X^0``"@``
M``#Z```+````"_H```<````7^@``40```!_Z```0````<?H```P```""^@``
M#0```(_Z```:````G?H``$H```"X^@``&0````/[```&````'?L``!H````D
M^P``)0```#_[```&````9?L```8```!L^P``'P```'/[```&````D_L```D`
M``":^P``&````*3[```7````O?L``"@```#5^P``!@```/[[```-````!?P`
M`"(````3_```5P```#;\```3````COP``",```"B_```$P```,;\```"````
MVOP```L```#=_```"````.G\```-````\OP```H`````_0``!P````O]```4
M````$_T```8````H_0``"````"_]```.````./T```<```!'_0``"@```$_]
M```+````6OT``#(```!F_0``!P```)G]```,````H?T```T```"N_0``#```
M`+S]```)````R?T```D```#3_0``"@```-W]```'````Z/T```D```#P_0``
M!P```/K]```*`````OX```<````-_@``&P```!7^```/````,?X``!(```!!
M_@``"@```%3^```6````7_X```D```!V_@``$````(#^```'````D?X``!(`
M``"9_@``!````*S^```'````L?X```4```"Y_@``!````+_^```,````Q/X`
M``4```#1_@``"P```-?^```4````X_X``!$```#X_@``%`````K_```7````
M'_\``!@````W_P``'````%#_```9````;?\```<```"'_P``!0```(__```-
M````E?\```P```"C_P``$0```+#_```(````PO\``!<```#+_P``"P```./_
M```,````[_\``!\```#\_P``&@```!P``0`3````-P`!``0```!+``$`"@``
M`%```0`$````6P`!``T```!@``$`#````&X``0`%````>P`!``D```"!``$`
M!0```(L``0`'````D0`!``4```"9``$`!````)\``0`"````I``!`#@```"G
M``$`+````.```0`2````#0$!`"D````@`0$`,@```$H!`0`*````?0$!`"P`
M``"(`0$`+@```+4!`0`S````Y`$!`#,````8`@$`.````$P"`0`/````A0(!
M`!0```"5`@$`&````*H"`0`0````PP(!``\```#4`@$`$P```.0"`0`5````
M^`(!`!0````.`P$`$@```",#`0`4````-@,!`!4```!+`P$`+0```&$#`0`M
M````CP,!`#$```"]`P$`+@```.\#`0`O````'@0!`"P```!.!`$`$P```'L$
M`0`,````CP0!``T```"<!`$`"````*H$`0`7````LP0!``@```#+!`$`#```
M`-0$`0`K````X00!`"$````-!0$`&@```"\%`0`)````2@4!`$4```!4!0$`
M00```)H%`0`/````W`4!``0```#L!0$`$P```/$%`0`.````!08!`!,````4
M!@$`&````"@&`0`&````008!``D```!(!@$`"@```%(&`0`/````708!`!``
M``!M!@$`!P```'X&`0`.````A@8!``4```"5!@$`&P```)L&`0`&````MP8!
M``@```"^!@$`!@```,<&`0`4````S@8!`!$```#C!@$`#@```/4&`0`X````
M!`<!``(````]!P$`!@```$`'`0`.````1P<!``4```!6!P$`!P```%P'`0`.
M````9`<!``8```!S!P$`*````'H'`0`,````HP<!`!P```"P!P$`!````,T'
M`0`I````T@<!`!<```#\!P$`'P```!0(`0!<````-`@!`!0```"1"`$`/@``
M`*8(`0`?````Y0@!`!`````%"0$`%````!8)`0`'````*PD!``X````S"0$`
M#````$()`0`,````3PD!`!,```!<"0$`"@```'`)`0`=````>PD!`!D```"9
M"0$`!0```+,)`0`1````N0D!`!$```#+"0$`)````-T)`0`2`````@H!`!4`
M```5"@$`$@```"L*`0`.````/@H!`!D```!-"@$`"````&<*`0`)````<`H!
M``T```!Z"@$`!P```(@*`0`*````D`H!``<```";"@$`#P```*,*`0`&````
MLPH!``L```"Z"@$`&@```,8*`0`*````X0H!``<```#L"@$`"````/0*`0`%
M````_0H!`!\````#"P$`!@```",+`0`0````*@L!``@````["P$`#0```$0+
M`0`(````4@L!`!X```!;"P$`$@```'H+`0`L````C0L!`!H```"Z"P$`"0``
M`-4+`0`*````WPL!`!4```#J"P$`!0`````,`0`4````!@P!``0````;#`$`
M$````"`,`0`&````,0P!``<````X#`$`'@```$`,`0`H````7PP!``H```"(
M#`$`'````),,`0`1````L`P!``L```#"#`$`&@```,X,`0`4````Z0P!``0`
M``#^#`$`!`````,-`0`+````"`T!``4````4#0$`!@```!H-`0`(````(0T!
M``8````J#0$`"@```#$-`0`;````/`T!`#0```!8#0$`-````(T-`0`@````
MP@T!`"D```#C#0$`(`````T.`0!!````+@X!`!H```!P#@$`*````(L.`0`I
M````M`X!`%$```#>#@$`4````#`/`0!7````@0\!`"P```#9#P$`(@````80
M`0`&````*1`!``@````P$`$`!0```#D0`0`(````/Q`!`!D```!($`$`&0``
M`&(0`0`J````?!`!``@```"G$`$`(P```+`0`0`9````U!`!`"X```#N$`$`
M-````!T1`0`(````4A$!`!<```!;$0$`"@```',1`0`'````?A$!`"$```"&
M$0$`$````*@1`0`.````N1$!``L```#($0$`!P```-01`0`3````W!$!``@`
M``#P$0$`"P```/D1`0`*````!1(!`!0````0$@$`#P```"42`0`R````-1(!
M``L```!H$@$`#@```'02`0`%````@Q(!``4```")$@$`!0```(\2`0`7````
ME1(!``\```"M$@$`!````+T2`0`*````PA(!``D```#-$@$`"P```-<2`0`-
M````XQ(!``P```#Q$@$`#@```/X2`0`%````#1,!``0````3$P$`#0```!@3
M`0`R````)A,!`$4```!9$P$`%P```)\3`0`'````MQ,!`!X```"_$P$`%```
M`-X3`0`%````\Q,!`!0```#Y$P$`!@````X4`0`'````%10!`",````=%`$`
M#@```$$4`0`J````4!0!``8```![%`$`#````((4`0`-````CQ0!`!$```"=
M%`$`%P```*\4`0`+````QQ0!`#8```#3%`$`"@````H5`0`B````%14!``L`
M```X%0$`#P```$05`0`+````5!4!`"````!@%0$`)P```($5`0`K````J14!
M``D```#5%0$`,@```-\5`0`E````$A8!`#`````X%@$`,0```&D6`0`M````
MFQ8!``X```#)%@$`%````-@6`0`%````[18!``X```#S%@$`$P````(7`0`2
M````%A<!``<````I%P$`$0```#$7`0`3````0Q<!``<```!7%P$`%````%\7
M`0`8````=!<!``<```"-%P$`!0```)47`0`,````FQ<!``P```"H%P$`$@``
M`+47`0`$````R!<!``<```#-%P$`"@```-47`0`+````X!<!``P```#L%P$`
M#@```/D7`0`.````"!@!``4````7&`$`!0```!T8`0`N````(Q@!`"8```!2
M&`$`(P```'D8`0`#````G1@!`!(```"A&`$`!@```+08`0`>````NQ@!`!@`
M``#:&`$`)0```/,8`0`-````&1D!``D````G&0$`'P```#$9`0`#````41D!
M``<```!5&0$`"@```%T9`0`"````:!D!``P```!K&0$`%0```'@9`0`+````
MCAD!`!D```":&0$`(````+09`0`2````U1D!``4```#H&0$`"@```.X9`0`5
M````^1D!`!(````/&@$`#````"(:`0`$````+QH!``D````T&@$`!P```#X:
M`0`,````1AH!`%(```!3&@$`%P```*8:`0`D````OAH!`!(```#C&@$`!P``
M`/8:`0`&````_AH!``X````%&P$`#````!0;`0`-````(1L!`!4````O&P$`
M$@```$4;`0`/````6!L!`!0```!H&P$`"@```'T;`0`;````B!L!`!````"D
M&P$`"P```+4;`0!I````P1L!`!H````K'`$`%P```$8<`0`G````7AP!`!H`
M``"&'`$`%P```*$<`0`;````N1P!`!D```#5'`$`'P```.\<`0`7````#QT!
M`!,````G'0$`"````#L=`0`'````1!T!``@```!,'0$`"0```%4=`0`5````
M7QT!``T```!U'0$`(P```(,=`0`-````IQT!`!,```"U'0$`"````,D=`0`#
M````TAT!`$8```#6'0$`/P```!T>`0`W````71X!`%<```"5'@$`!0```.T>
M`0`?````\QX!`"\````3'P$`"@```$,?`0`(````3A\!``T```!7'P$`+0``
M`&4?`0`$````DQ\!`$\```"8'P$`)0```.@?`0`<````#B`!``L````K(`$`
M'P```#<@`0`=````5R`!`"4```!U(`$`(````)L@`0`D````O"`!`"````#A
M(`$`"P````(A`0`'````#B$!``T````6(0$`#````"0A`0`7````,2$!``8`
M``!)(0$`.0```%`A`0`,````BB$!``<```"7(0$`"0```)\A`0`3````J2$!
M``<```"](0$`"0```,4A`0`$````SR$!`!````#4(0$`"````.4A`0`(````
M[B$!``0```#W(0$`"P```/PA`0`,````""(!`!(````5(@$`$0```"@B`0`,
M````.B(!`!H```!'(@$`#P```&(B`0`'````<B(!``T```!Z(@$`%````(@B
M`0`.````G2(!``P```"L(@$`+````+DB`0`3````YB(!`!P```#Z(@$`*```
M`!<C`0`&````0",!``<```!'(P$`$P```$\C`0`%````8R,!``0```!I(P$`
M%P```&XC`0`*````AB,!``P```"1(P$`"0```)XC`0`&````J",!``D```"O
M(P$`"````+DC`0`)````PB,!``4```#,(P$`"@```-(C`0`1````W2,!``8`
M``#O(P$`#@```/8C`0`.````!20!``T````4)`$`"P```"(D`0`=````+B0!
M``L```!,)`$``@```%@D`0`<````6R0!``<```!X)`$`!@```(`D`0!D````
MAR0!``D```#L)`$`!P```/8D`0`F````_B0!`#@````E)0$`&@```%XE`0`J
M````>24!`#L```"D)0$`*````.`E`0`T````"28!`!D````^)@$`%0```%@F
M`0`%````;B8!``<```!T)@$`"````'PF`0`'````A28!``4```"-)@$`!P``
M`),F`0`.````FR8!``D```"J)@$`!@```+0F`0`(````NR8!``L```#$)@$`
M!P```-`F`0`(````V"8!``<```#A)@$`%@```.DF`0`)`````"<!``8````*
M)P$`"P```!$G`0`0````'2<!``8````N)P$`'````#4G`0`4````4B<!``<`
M``!G)P$`$0```&\G`0`(````@2<!``X```"*)P$`"````)DG`0`%````HB<!
M`!````"H)P$`"0```+DG`0`0````PR<!``8```#4)P$`&0```-LG`0`*````
M]2<!`!P`````*`$`!P```!TH`0`%````)2@!``0````K*`$`$````#`H`0`4
M````02@!``L```!6*`$`#0```&(H`0`H````<"@!`!@```"9*`$`%P```+(H
M`0`:````RB@!`!0```#E*`$`!````/HH`0`)````_R@!``H````)*0$`!P``
M`!0I`0`"````'"D!``X````?*0$`"````"XI`0`?````-RD!`",```!7*0$`
M(P```'LI`0`?````GRD!`#@```"_*0$`)@```/@I`0`Q````'RH!`"<```!1
M*@$`9````'DJ`0`4````WBH!`!P```#S*@$`50```!`K`0`X````9BL!`$H`
M``"?*P$`6P```.HK`0`H````1BP!`#@```!O+`$`*@```*@L`0`H````TRP!
M`"P```#\+`$`)P```"DM`0`F````42T!`!L```!X+0$`/@```)0M`0`C````
MTRT!`!<```#W+0$`&0````\N`0!(````*2X!`(4```!R+@$`,````/@N`0`E
M````*2\!`$$```!/+P$`6P```)$O`0!)````[2\!`#$````W,`$`'0```&DP
M`0`8````AS`!`"L```"@,`$`(0```,PP`0`?````[C`!`"L````.,0$`)@``
M`#HQ`0`A````83$!`"D```"#,0$`)P```*TQ`0`Z````U3$!`!T````0,@$`
M$0```"XR`0`S````0#(!`"4```!T,@$`.````)HR`0`G````TS(!`"````#[
M,@$`'P```!PS`0`P````/#,!`&D```!M,P$`,0```-<S`0!!````"30!`#,`
M``!+-`$`)0```'\T`0`]````I30!`&4```#C-`$`30```$DU`0`O````ES4!
M`"X```#'-0$`*P```/8U`0`P````(C8!`"H```!3-@$`/@```'XV`0!4````
MO38!`%H````2-P$`2````&TW`0!*````MC<!`#(````!.`$`'0```#0X`0`C
M````4C@!`"\```!V.`$`+````*8X`0`M````TS@!`'$````!.0$`9@```',Y
M`0!O````VCD!`+,```!*.@$`%P```/XZ`0`E````%CL!`#(````\.P$`*0``
M`&\[`0`^````F3L!`"(```#8.P$`4@```/L[`0`E````3CP!``L```!T/`$`
M10```(`\`0`A````QCP!`#````#H/`$`)0```!D]`0`<````/ST!`#$```!<
M/0$`!P```(X]`0`'````ECT!``0```">/0$`#0```*,]`0`+````L3T!``X`
M``"]/0$`"P```,P]`0`%````V#T!`!````#>/0$``@```.\]`0!9````\CT!
M``4```!,/@$`$@```%(^`0`$````93X!``<```!J/@$`"````'(^`0`%````
M>SX!``,```"!/@$`$````(4^`0`,````ECX!`!,```"C/@$`#0```+<^`0`"
M````Q3X!``<```#(/@$`!@```-`^`0`4````USX!``P```#L/@$`&````/D^
M`0`&````$C\!`!(````9/P$`#````"P_`0`#````.3\!`"H````]/P$`!```
M`&@_`0`&````;3\!``<```!T/P$`'P```'P_`0`U````G#\!`"X```#2/P$`
M+P````%``0`7````,4`!`!\```!)0`$`(@```&E``0`E````C$`!`"````"R
M0`$`&P```--``0`8````[T`!`"0````(00$`'P```"U!`0`:````34$!`"$`
M``!H00$`(````(I!`0`:````JT$!`#(```#&00$`&@```/E!`0`O````%$(!
M`"L```!$0@$`'P```'!"`0`C````D$(!`!\```"T0@$`&@```-1"`0`A````
M[T(!`"4````10P$`)@```#=#`0`E````7D,!`"0```"$0P$`&````*E#`0`=
M````PD,!`"0```#@0P$`&`````5$`0`B````'D0!`"P```!!1`$`+P```&Y$
M`0`5````GD0!`"4```"T1`$`/````-I$`0`?````%T4!`",````W10$`'P``
M`%M%`0`@````>T4!`!H```"<10$`&````+=%`0`F````T$4!`!X```#W10$`
M*0```!9&`0`>````0$8!`#$```!?1@$`"0```)%&`0`,````FT8!`!<```"H
M1@$`+P```,!&`0`D````\$8!``<````51P$`'P```!U'`0`/````/4<!`!0`
M``!-1P$`#@```&)'`0`-````<4<!`"0```!_1P$`!0```*1'`0`'````JD<!
M`"(```"R1P$`)0```-5'`0`:````^T<!`!T````62`$`&@```#1(`0`'````
M3T@!`,<```!72`$`"P```!])`0`5````*TD!``8```!!20$`"0```$A)`0`8
M````4DD!``L```!K20$`#0```'=)`0`7````A4D!``8```"=20$`,P```*1)
M`0`3````V$D!`!,```#L20$`!P````!*`0`/````"$H!``<````82@$`,@``
M`"!*`0`$````4TH!`"$```!82@$`$P```'I*`0`,````CDH!`!$```";2@$`
M,@```*U*`0`6````X$H!``@```#W2@$`'0````!+`0`)````'DL!``H````H
M2P$`%````#-+`0`*````2$L!`!T```!32P$`"````'%+`0`?````>DL!``@`
M``":2P$`&@```*-+`0`G````ODL!``8```#F2P$`%0```.U+`0`'`````TP!
M``@````+3`$`"0```!1,`0`_````'DP!``<```!>3`$`#P```&9,`0`.````
M=DP!`!````"%3`$`"0```)9,`0`)````H$P!``@```"J3`$`$P```+-,`0`'
M````QTP!`!D```#/3`$`"@```.E,`0`*````]$P!``D```#_3`$`%P````E-
M`0`4````(4T!``H````V30$`#````$%-`0`7````3DT!``0```!F30$`*@``
M`&M-`0`,````EDT!`!$```"C30$`!P```+5-`0`"````O4T!`!````#`30$`
M&````-%-`0`+````ZDT!``,```#V30$`"````/I-`0`3`````TX!`!<````7
M3@$`!@```"].`0`'````-DX!``T````^3@$`"P```$Q.`0`4````6$X!`!4`
M``!M3@$`#@```(-.`0`O````DDX!`"````#"3@$`'````.-.`0`5`````$\!
M``P````63P$`,0```"-/`0`%````54\!`!(```!;3P$`/P```&Y/`0`2````
MKD\!``H```#!3P$`!@```,Q/`0`$````TT\!``0```#83P$`"@```-U/`0`3
M````Z$\!``4```#\3P$`!@````)0`0`&````"5`!``@````04`$`!````!E0
M`0`,````'E`!``H````K4`$`.0```#90`0`N````<%`!`"D```"?4`$`!0``
M`,E0`0`9````SU`!`!$```#I4`$``@```/M0`0`$````_E`!``H````#40$`
M!@````Y1`0`%````%5$!``,````;40$`#````!]1`0!%````+%$!`#(```!R
M40$`&@```*51`0`U````P%$!`#0```#V40$`*````"M2`0`9````5%(!`'(`
M``!N4@$`(````.%2`0`U`````E,!`"$````X4P$`10```%I3`0`P````H%,!
M`"@```#14P$`*0```/I3`0`F````)%0!`"4```!+5`$`*````'%4`0`H````
MFE0!`"(```##5`$`*P```.94`0`P````$E4!`!(```!#50$`$P```%95`0`0
M````:E4!`'D```![50$`"0```/55`0"A````_U4!`',```"A5@$`?````!57
M`0`K````DE<!`%0```"^5P$`%P```!-8`0`G````*U@!`!8```!36`$`#P``
M`&I8`0`7````>E@!`!\```"26`$`0````+)8`0`?````\U@!`!P````360$`
M40```#!9`0`:````@ED!`!0```"=60$`"@```+)9`0`%````O5D!``8```##
M60$`"````,I9`0`%````TUD!`!(```#960$`$````.Q9`0`3````_5D!`!T`
M```16@$`#P```"]:`0`/````/UH!``0```!/6@$`"0```%1:`0`+````7EH!
M``<```!J6@$`!0```'):`0`4````>%H!``<```"-6@$`"````)5:`0`/````
MGEH!``@```"N6@$`#````+=:`0`/````Q%H!``8```#46@$`%````-M:`0`&
M````\%H!``P```#W6@$`$0````1;`0`(````%EL!``0````?6P$`&0```"1;
M`0`1````/EL!``H```!06P$`!0```%M;`0`8````85L!`!,```!Z6P$`'```
M`(Y;`0`1````JUL!``0```"]6P$`#P```,);`0`'````TEL!``0```#:6P$`
M&0```-];`0`'````^5L!``(````!7`$``@````1<`0`1````!UP!``D````9
M7`$`!@```"-<`0`2````*EP!`!<````]7`$`!@```%5<`0`G````7%P!``(`
M``"$7`$`!````(=<`0`/````C%P!`!,```"<7`$`!P```+!<`0`'````N%P!
M`!$```#`7`$`!@```-)<`0`8````V5P!``8```#R7`$`$P```/E<`0`0````
M#5T!`!(````>70$``@```#%=`0`&````-%T!``P````[70$`"0```$A=`0`1
M````4ET!`"(```!D70$`!P```(==`0`'````CUT!``L```"770$`!0```*-=
M`0`"````J5T!``L```"L70$`8@$``+A=`0!,````&U\!`!$```!H7P$`$@``
M`'I?`0`/````C5\!``X```"=7P$`!P```*Q?`0`*````M%\!``<```"_7P$`
M!````,=?`0`8````S%\!`!T```#E7P$`+`````-@`0`=````,&`!`"````!.
M8`$`)@```&]@`0`7````EF`!`"@```"N8`$`#````-=@`0`K````Y&`!``X`
M```080$`$0```!]A`0`2````,6$!``4```!$80$`(P```$IA`0`(````;F$!
M``H```!W80$`$P```()A`0`/````EF$!``L```"F80$`%0```+)A`0!#````
MR&$!`"(````,8@$`,0```"]B`0!O````86(!``@```#18@$`"@```-IB`0`*
M````Y6(!`#<```#P8@$`(@```"AC`0`0````2V,!`!L```!<8P$`(````'AC
M`0`P````F6,!`!````#*8P$`#P```-MC`0`3````ZV,!`!````#_8P$`!@``
M`!!D`0")````%V0!``L```"A9`$`$0```*UD`0`=````OV0!``H```#=9`$`
M$````.AD`0`0````^60!``D````*90$`"P```!1E`0`L````(&4!`!P```!-
M90$`.P```&IE`0!%````IF4!`%8```#L90$`4P```$-F`0!9````EV8!`%8`
M``#Q9@$`/@```$AG`0`.````AV<!`!,```"69P$`#@```*IG`0`0````N6<!
M`!@```#*9P$`!0```.-G`0`&````Z6<!``H```#P9P$`!0```/MG`0`&````
M`6@!``8````(:`$`$0````]H`0`*````(6@!`"4````L:`$`)````%)H`0`0
M````=V@!`!(```"(:`$`#````)MH`0`&````J&@!``@```"O:`$`"0```+AH
M`0`,````PF@!`!0```#/:`$`&0```.1H`0`.````_F@!`!(````-:0$`%P``
M`"!I`0`>````.&D!`",```!7:0$`&@```'MI`0`0````EFD!`!<```"G:0$`
M#0```+]I`0`J````S6D!`!@```#X:0$`%@```!%J`0`9````*&H!`!,```!"
M:@$`3P```%9J`0`Q````IFH!`"0```#8:@$`!@```/UJ`0`)````!&L!`#0`
M```.:P$`#@```$-K`0`&````4FL!``H```!9:P$`"````&1K`0`(````;6L!
M``4```!V:P$`!P```'QK`0`*````A&L!``0```"/:P$`'````)1K`0`,````
ML6L!`!$```"^:P$`#P```-!K`0`5````X&L!`"8```#V:P$`"P```!UL`0`:
M````*6P!`!T```!$;`$`(0```&)L`0`8````A&P!``\```"=;`$`$````*UL
M`0`1````OFP!`"\```#0;`$`&P````!M`0`;````'&T!``<````X;0$`!@``
M`$!M`0`(````1VT!``P```!0;0$`!````%UM`0`)````8FT!`!,```!L;0$`
M"P```(!M`0`1````C&T!`!8```">;0$`'P```+5M`0`'````U6T!`!(```#=
M;0$`!0```/!M`0`6````]FT!``\````-;@$`#````!UN`0`Q````*FX!`$(`
M``!<;@$`"0```)]N`0`(````J6X!`!0```"R;@$`!0```,=N`0`%````S6X!
M`!````#3;@$`"P```.1N`0`9````\&X!`#L````*;P$`$@```$9O`0!&````
M66\!`"\```"@;P$`-````-!O`0`N````!7`!`"T````T<`$`"0```&)P`0`(
M````;'`!``<```!U<`$`"@```'UP`0`)````B'`!`",```"2<`$`-````+9P
M`0`B````ZW`!`$8````.<0$`(0```%5Q`0`A````=W$!`$,```"9<0$`0@``
M`-UQ`0`?````('(!`$````!`<@$`)P```(%R`0`J````J7(!`$,```#4<@$`
M(0```!AS`0`G````.G,!`"P```!B<P$`&@```(]S`0`>````JG,!`"H```#)
M<P$`*P```/1S`0`K````('0!`!(```!,=`$`#@```%]T`0`*````;G0!``<`
M``!Y=`$`#0```(%T`0`(````CW0!``T```"8=`$`'P```*9T`0`C````QG0!
M``<```#J=`$`!P```/)T`0`5````^G0!``H````0=0$`!@```!MU`0`&````
M(G4!``@````I=0$`!@```#)U`0`I````.74!``@```!C=0$`"P```&QU`0`'
M````>'4!``8```"`=0$`!0```(=U`0`'````C74!``8```"5=0$`"@```)QU
M`0`G````IW4!`!(```#/=0$`"````.)U`0`(````ZW4!``X```#T=0$``P``
M``-V`0`'````!W8!``D````/=@$``P```!EV`0`)````'78!``4````G=@$`
M%P```"UV`0`$````178!``@```!*=@$`!@```%-V`0`-````6G8!``D```!H
M=@$`)P```')V`0`$````FG8!``8```"?=@$`"0```*9V`0`*````L'8!``P`
M``"[=@$`#````,AV`0`'````U78!``,```#==@$``P```.%V`0`7````Y78!
M`!8```#]=@$`)````!1W`0`(````.7<!``4```!"=P$`"````$AW`0`'````
M47<!``H```!9=P$`10```&1W`0`=````JG<!`#@```#(=P$`(@````%X`0`7
M````)'@!``8````\>`$`!@```$-X`0`5````2G@!`!4```!@>`$`'P```'9X
M`0`K````EG@!`!H```#">`$`(P```-UX`0`Q`````7D!``D````S>0$`!@``
M`#UY`0`(````1'D!`!<```!->0$`#@```&5Y`0`,````='D!`!$```"!>0$`
M#@```)-Y`0`1````HGD!``X```"T>0$`#````,-Y`0`5````T'D!``D```#F
M>0$`'````/!Y`0`=````#7H!`!(````K>@$`#P```#YZ`0`2````3GH!``4`
M``!A>@$`"@```&=Z`0`%````<GH!`!,```!X>@$`%P```(QZ`0!5````I'H!
M`&(```#Z>@$``P```%U[`0`3````87L!`"D```!U>P$`!0```)][`0`$````
MI7L!`!P```"J>P$`'@```,=[`0`1````YGL!``T```#X>P$`$0````9\`0`,
M````&'P!`!L````E?`$`)````$%\`0`%````9GP!`!X```!L?`$`!0```(M\
M`0`5````D7P!``L```"G?`$`$P```+-\`0`/````QWP!`!(```#7?`$`$P``
M`.I\`0`8````_GP!`!,````7?0$`#0```"M]`0`$````.7T!``L````^?0$`
M"````$I]`0`7````4WT!`!4```!K?0$`$@```(%]`0`(````E'T!``0```"=
M?0$`#0```*)]`0`'````L'T!``D```"X?0$`#P```,)]`0`+````TGT!``@`
M``#>?0$`#P```.=]`0`)````]WT!``0````!?@$`!P````9^`0`'````#GX!
M``@````6?@$`%0```!]^`0`'````-7X!``4````]?@$`!0```$-^`0`8````
M27X!`%````!B?@$`(0```+-^`0`.````U7X!`!$```#D?@$`!0```/9^`0`%
M````_'X!`!D````"?P$`&@```!Q_`0`L````-W\!`#0```!D?P$`*````)E_
M`0`)````PG\!`"4```#,?P$`(@```/)_`0`/````%8`!``@````E@`$`#```
M`"Z``0`&````.X`!``<```!"@`$`&@```$J``0`1````98`!``H```!W@`$`
M"P```(*``0`*````CH`!``\```"9@`$`(0```*F``0`B````RX`!`"````#N
M@`$`(0````^!`0`D````,8$!`",```!6@0$`'P```'J!`0`F````FH$!`"$`
M``#!@0$`)````..!`0`I````"((!`"4````R@@$`'0```%B"`0`>````=H(!
M`"````"5@@$`&P```+:"`0`F````TH(!`"T```#Y@@$`*P```">#`0`B````
M4X,!`"L```!V@P$`-P```**#`0`=````VH,!`!T```#X@P$`&0```!:$`0`9
M````,(0!`#````!*A`$`(0```'N$`0`2````G80!`"$```"PA`$`*````-*$
M`0`:````^X0!`!@````6A0$`'@```"^%`0`1````3H4!`+8```!@A0$`$@``
M`!>&`0`<````*H8!`"4```!'A@$`)@```&V&`0`@````E(8!`"0```"UA@$`
M&@```-J&`0`:````]88!`"0````0AP$`)````#6'`0`K````6H<!`"P```"&
MAP$`)P```+.'`0",````VX<!`!\```!HB`$`%0```(B(`0`5````GH@!`!X`
M``"TB`$`*0```-.(`0`I````_8@!`$0````GB0$`1````&R)`0`+````L8D!
M``0```"]B0$`!@```,*)`0`%````R8D!``H```#/B0$`"````-J)`0`/````
MXXD!`!8```#SB0$`$0````J*`0`(````'(H!``0````EB@$`$````"J*`0`/
M````.XH!``L```!+B@$`#@```%>*`0`0````9HH!``X```!WB@$`$@```(:*
M`0`,````F8H!`#8```"FB@$`"````-V*`0`+````YHH!``8```#RB@$`$@``
M`/F*`0`8````#(L!`!L````EBP$`"````$&+`0`"````2HL!``8```!-BP$`
M$@```%2+`0`.````9XL!``4```!VBP$`#@```'R+`0`(````BXL!``,```"4
MBP$`#@```)B+`0`(````IXL!``D```"PBP$`!@```+J+`0`-````P8L!``<`
M``#/BP$`#````->+`0`1````Y(L!``P```#VBP$`#`````.,`0`1````$(P!
M``D````BC`$`!@```"R,`0`+````,XP!``P````_C`$`"P```$R,`0`1````
M6(P!`!P```!JC`$`"P```(>,`0`-````DXP!`!\```"AC`$`%````,&,`0`:
M````UHP!`#$```#QC`$`"@```".-`0`5````+HT!`!(```!$C0$`%0```%>-
M`0`2````;8T!`!4```"`C0$`)````):-`0`+````NXT!``<```#'C0$`#0``
M`,^-`0`K````W8T!`!$````)C@$`"P```!N.`0`B````)XX!`"\```!*C@$`
M"@```'J.`0`)````A8X!`!X```"/C@$`"P```*Z.`0`;````NHX!`!L```#6
MC@$`!P```/*.`0`7````^HX!`!4````2CP$`'````"B/`0`7````18\!``X`
M``!=CP$`"@```&R/`0`(````=X\!``L```"`CP$`(@```(R/`0`Y````KX\!
M`!<```#ICP$`(P````&0`0`%````)9`!``@````KD`$`+0```#20`0`*````
M8I`!``8```!MD`$`!@```'20`0!6````>Y`!``,```#2D`$`!P```-:0`0`%
M````WI`!``L```#DD`$`"P```/"0`0`0````_)`!`!(````-D0$`&0```""1
M`0`8````.I$!`!L```!3D0$`&P```&^1`0`*````BY$!``<```"6D0$`"P``
M`)Z1`0`*````JI$!``(```"UD0$`!@```+B1`0`,````OY$!`"4```#,D0$`
M(````/*1`0`6````$Y(!``P````JD@$`$````#>2`0`.````2)(!`!````!7
MD@$`!````&B2`0`'````;9(!``\```!UD@$`(0```(62`0`8````IY(!``,`
M``#`D@$`'0```,22`0`L````XI(!`"L````/DP$`'````#N3`0`I````6),!
M`",```""DP$`%P```*:3`0`:````OI,!``<```#9DP$`"````.&3`0`&````
MZI,!``8```#QDP$`#@```/B3`0`.````!Y0!``\````6E`$`#0```":4`0`0
M````-)0!``\```!%E`$`"P```%64`0`2````890!``,```!TE`$`"0```'B4
M`0`2````@I0!``X```"5E`$`+P```*24`0`-````U)0!``@```#BE`$`#0``
M`.N4`0`@````^90!`"4````:E0$`)@```$"5`0`E````9Y4!`",```"-E0$`
M(P```+&5`0`K````U94!`"(````!E@$`&@```"26`0`#````/Y8!``X```!#
ME@$`"````%*6`0`+````6Y8!``,```!GE@$`!0```&N6`0`(````<98!``D`
M``!ZE@$`"P```(26`0`/````D)8!`!(```"@E@$`"@```+.6`0`.````OI8!
M``X```#-E@$`!````-R6`0`#````X98!`!,```#EE@$`%0```/F6`0`,````
M#Y<!``<````<EP$`!@```"27`0`.````*Y<!`!H````ZEP$`!@```%67`0`'
M````7)<!``T```!DEP$`#@```'*7`0`7````@9<!``@```"9EP$``P```**7
M`0`E````II<!``T```#,EP$`3@```-J7`0`4````*9@!``@````^F`$`"@``
M`$>8`0`1````4I@!``H```!DF`$`#````&^8`0`%````?)@!``X```""F`$`
M`@```)&8`0`%````E)@!``D```":F`$`$P```*28`0`:````N)@!`!,```#3
MF`$`&````.>8`0`@`````)D!``X````AF0$`$@```#"9`0`9````0YD!``0`
M``!=F0$`"0```&*9`0`7````;)D!``@```"$F0$`$0```(V9`0`%````GYD!
M`!@```"EF0$`"````+Z9`0`&````QYD!`!T```#.F0$`#0```.R9`0`(````
M^ID!``@````#F@$`!0````R:`0`)````$IH!``<````<F@$`%0```"2:`0`"
M````.IH!``8````]F@$`#````$2:`0`-````49H!``@```!?F@$`%````&B:
M`0`$````?9H!``@```""F@$`!P```(N:`0`#````DYH!`!,```"7F@$`/0``
M`*N:`0`F````Z9H!`"D````0FP$`!P```#J;`0`$````0IL!``D```!'FP$`
M"````%&;`0`0````6IL!`!,```!KFP$`!P```'^;`0`&````AYL!``T```".
MFP$`!@```)R;`0`$````HYL!`#$```"HFP$`-@```-J;`0`S````$9P!`!H`
M``!%G`$`!0```&"<`0`,````9IP!``4```!SG`$`!@```'F<`0`(````@)P!
M`!@```")G`$`$@```**<`0`7````M9P!``0```#-G`$`#0```-*<`0`%````
MX)P!`!$```#FG`$`#0```/B<`0`(````!IT!`!<````/G0$``P```">=`0`$
M````*YT!``,````PG0$`"P```#2=`0`*````0)T!``P```!+G0$`"````%B=
M`0`)````89T!``4```!KG0$`/0```'&=`0`Q````KYT!`#\```#AG0$`'0``
M`"&>`0!!````/YX!`#<```"!G@$`*````+F>`0`Y````XIX!`"X````<GP$`
M,@```$N?`0`A````?I\!`!$```"@GP$`%0```+*?`0`,````R)\!`"\```#5
MGP$`)`````6@`0`D````*J`!`",```!/H`$`"0```'.@`0`*````?:`!``H`
M``"(H`$`!@```).@`0`E````FJ`!`"8```#`H`$`,````.>@`0`)````&*$!
M`!X````BH0$`*@```$&A`0`:````;*$!`!````"'H0$`!@```)BA`0`-````
MGZ$!``T```"MH0$`#P```+NA`0`2````RZ$!`#L```#>H0$`D0```!JB`0!D
M````K*(!`!4````1HP$`"@```">C`0`+````,J,!`!$````^HP$`$@```%"C
M`0`.````8Z,!``8```!RHP$`$@```'FC`0`4````C*,!`!$```"AHP$`"```
M`+.C`0`1````O*,!`"0```#.HP$`*@```/.C`0!N````'J0!``H```"-I`$`
M!@```)BD`0`6````GZ0!``H```"VI`$`!````,&D`0`+````QJ0!`"<```#2
MI`$`%````/JD`0`+````#Z4!``T````;I0$`#P```"FE`0`3````.:4!`"4`
M``!-I0$`)````'.E`0`<````F*4!`!X```"UI0$`(0```-2E`0`@````]J4!
M`!8````7I@$`$0```"ZF`0`0````0*8!`!,```!1I@$`$@```&6F`0`2````
M>*8!`!4```"+I@$`%````*&F`0`0````MJ8!``\```#'I@$`*0```->F`0`1
M`````:<!`!$````3IP$`.P```"6G`0`4````8:<!``8```!VIP$`#````'VG
M`0`G````BJ<!`"$```"RIP$`%@```-2G`0`5````ZZ<!`!(````!J`$`%@``
M`!2H`0`<````*Z@!`!,```!(J`$`%0```%RH`0`:````<J@!`!@```"-J`$`
M'0```*:H`0`A````Q*@!`"$```#FJ`$`%0````BI`0`4````'JD!`!0````S
MJ0$`&````$BI`0`:````8:D!`!@```!\J0$`%@```)6I`0`+````K*D!``\`
M``"XJ0$`!````,BI`0`$````S:D!``8```#2J0$`"P```-FI`0`1````Y:D!
M``8```#WJ0$`"P```/ZI`0`&````"JH!``<````1J@$`!P```!FJ`0`'````
M(:H!``4````IJ@$`%0```"^J`0`&````1:H!``D```!,J@$`!````%:J`0`$
M````6ZH!``<```!@J@$`#0```&BJ`0`,````=JH!``X```"#J@$`#````)*J
M`0`%````GZH!`"D```"EJ@$`#0```,^J`0`+````W:H!``L```#IJ@$`"0``
M`/6J`0`0````_ZH!`#`````0JP$`!````$&K`0`(````1JL!``4```!/JP$`
M"0```%6K`0`(````7ZL!`!$```!HJP$`!@```'JK`0`)````@:L!``<```"+
MJP$`!0```).K`0`$````F:L!``P```">JP$`$0```*NK`0`/````O:L!`!(`
M``#-JP$`%@```."K`0`>````]ZL!`!H````6K`$`"````#&L`0`(````.JP!
M``,```!#K`$`!@```$>L`0`E````3JP!``<```!TK`$`!P```'RL`0`-````
MA*P!``T```"2K`$`!P```*"L`0`$````J*P!``<```"MK`$`!@```+6L`0`-
M````O*P!``<```#*K`$`"````-*L`0`)````VZP!`!,```#EK`$`%0```/FL
M`0`-````#ZT!`!(````=K0$`"````#"M`0`,````.:T!``@```!&K0$`!```
M`$^M`0`0````5*T!`$(```!EK0$`!@```*BM`0`$````KZT!`!\```"TK0$`
M#@```-2M`0`/````XZT!``X```#SK0$`#`````*N`0`)````#ZX!``<````9
MK@$`"@```"&N`0`)````+*X!``X````VK@$`$````$6N`0`E````5JX!`"4`
M``!\K@$`(@```**N`0`*````Q:X!``<```#0K@$`"0```-BN`0`+````XJX!
M``D```#NK@$`!0```/BN`0`(````_JX!``@````'KP$`!0```!"O`0`0````
M%J\!`$X````GKP$`&````':O`0`)````CZ\!``8```"9KP$``P```*"O`0`0
M````I*\!`!````"UKP$`%````,:O`0`&````VZ\!``H```#BKP$`"0```.VO
M`0`"````]Z\!``0```#ZKP$`(P```/^O`0`#````([`!``4````GL`$`"@``
M`"VP`0`*````.+`!``8```!#L`$`!@```$JP`0`+````4;`!``T```!=L`$`
M!@```&NP`0`(````<K`!``H```![L`$`!````(:P`0`%````B[`!`'8```"1
ML`$`"P````BQ`0`.````%+$!`!<````CL0$`!````#NQ`0`(````0+$!`!4`
M``!)L0$`+P```%^Q`0`-````C[$!``H```"=L0$`#@```*BQ`0`+````M[$!
M``D```##L0$`%````,VQ`0`S````XK$!`"@````6L@$`)P```#^R`0`:````
M9[(!``T```""L@$``P```)"R`0`'````E+(!``<```"<L@$`"P```*2R`0`0
M````L+(!``X```#!L@$`"0```-"R`0`0````VK(!`!L```#KL@$`"0````>S
M`0`)````$;,!``\````;LP$`"@```"NS`0!-````-K,!`!X```"$LP$`#0``
M`*.S`0`*````L;,!`"$```"\LP$`3````-ZS`0`9````*[0!``4```!%M`$`
M'P```$NT`0`N````:[0!``<```":M`$`!@```**T`0`+````J;0!``8```"U
MM`$`!P```+RT`0`G````Q+0!`"8```#LM`$`*@```!.U`0`&````/K4!``<`
M``!%M0$`+P```$VU`0!5````?;4!`!4```#3M0$`)P```.FU`0`3````$;8!
M``(````EM@$`#````"BV`0`(````-;8!``P````^M@$`"@```$NV`0`'````
M5K8!``D```!>M@$`!@```&BV`0`)````;[8!``P```!YM@$`"````(:V`0`)
M````C[8!``@```"9M@$`,@```**V`0`'````U;8!``\```#=M@$`$0```.VV
M`0`0````_[8!``H````0MP$`#@```!NW`0`,````*K<!``H````WMP$`"@``
M`$*W`0`*````3;<!``H```!8MP$`!P```&.W`0`.````:[<!`!P```!ZMP$`
M!P```)>W`0`*````G[<!`!0```"JMP$`"@```+^W`0`0````RK<!``<```#;
MMP$`&````..W`0`$````_+<!``<````!N`$`!0````FX`0`$````#[@!``X`
M```4N`$`!0```".X`0`-````*;@!`!<````WN`$`#P```$^X`0`6````7[@!
M`!D```!VN`$`%P```)"X`0`<````J+@!`!8```#%N`$`!P```-RX`0`&````
MY+@!``X```#KN`$`"P```/JX`0`7````!KD!``8````>N0$`'````"6Y`0`+
M````0KD!``T```!.N0$`(@```%RY`0`:````?[D!`!4```":N0$`!P```+"Y
M`0`-````N+D!``4```#&N0$`$````,RY`0`3````W;D!``8```#QN0$`"0``
M`/BY`0`%`````KH!``<````(N@$`!````!"Z`0`$````%;H!``,````:N@$`
M.P```!ZZ`0`S````6KH!`!(```".N@$`+P```*&Z`0`R````T;H!``X````$
MNP$`/````!.[`0`O````4+L!`#0```"`NP$`-````+6[`0`X````ZKL!`!(`
M```CO`$`$P```#:\`0`8````2KP!`!,```!CO`$`%0```'>\`0`2````C;P!
M`!(```"@O`$`&P```+.\`0`3````S[P!`!4```#CO`$`&@```/F\`0`N````
M%+T!`"X```!#O0$`,@```'*]`0`O````I;T!`#````#5O0$`+0````:^`0`=
M````-+X!`!,```!2O@$`%````&:^`0`+````>[X!`!D```"'O@$`"@```*&^
M`0`/````K+X!`"P```"\O@$`+@```.F^`0`B````&+\!``L````[OP$`50``
M`$>_`0!&````G;\!``X```#DOP$`!0```/._`0`<````^;\!``P````6P`$`
M$````"/``0`2````-,`!``4```!'P`$`"@```$W``0`)````6,`!``\```!B
MP`$`$0```'+``0`*````A,`!``L```"/P`$`#````)O``0`@````J,`!``,`
M``#)P`$`"````,W``0`&````UL`!``P```#=P`$`#@```.K``0`+````^<`!
M`$(````%P0$``@```$C!`0`&````2\$!``T```!2P0$`!0```&#!`0`'````
M9L$!`!D```!NP0$`!@```(C!`0`N````C\$!`!````"^P0$`'0```,_!`0`$
M````[<$!`"H```#RP0$`'````!W"`0`@````.L(!`%D```!;P@$`%````+7"
M`0!'````RL(!`!D````2PP$`#@```"S#`0`<````.\,!``T```!8PP$`%```
M`&;#`0`.````>\,!``P```"*PP$`$@```)?#`0`*````JL,!`!P```"UPP$`
M&0```-+#`0`%````[,,!`!,```#RPP$`$`````;$`0`F````%\0!`!,````^
MQ`$`%0```%+$`0`2````:,0!`!$```![Q`$`&0```(W$`0`'````I\0!``@`
M``"OQ`$`$P```+C$`0`.````S,0!`!(```#;Q`$`#P```.[$`0`:````_L0!
M``\````9Q0$`&@```"G%`0`4````1,4!``D```!9Q0$`"@```&/%`0`(````
M;L4!``4```!WQ0$`"0```'W%`0`&````A\4!`!````".Q0$`"````)_%`0`.
M````J,4!``@```"WQ0$`$@```,#%`0`2````T\4!`"@```#FQ0$`&`````_&
M`0`)````*,8!``H````RQ@$`&0```#W&`0`*````5\8!`"(```!BQ@$`!@``
M`(7&`0`8````C,8!``D```"EQ@$`!P```*_&`0`:````M\8!`"L```#2Q@$`
M"@```/[&`0`?````"<<!``T````IQP$`#````#?'`0`9````1,<!`!4```!>
MQP$`!````'3'`0`'````><<!``P```"!QP$`!P```(['`0`%````EL<!``@`
M``"<QP$`!@```*7'`0`(````K,<!`!@```"UQP$`)@```,['`0`M````]<<!
M`!H````CR`$`(````#[(`0`?````7\@!`$0```!_R`$`'````,3(`0`=````
MX<@!`"0```#_R`$`6P```"3)`0!;````@,D!`$H```#<R0$`(@```"?*`0`7
M````2LH!``4```!BR@$`!P```&C*`0`.````<,H!``@```!_R@$`%P```(C*
M`0`9````H,H!`"X```"ZR@$`"````.G*`0`B````\LH!`!@````5RP$`'P``
M`"[+`0`[````3LL!``4```"*RP$`%0```)#+`0`+````ILL!``\```"RRP$`
M(P```,++`0`8````YLL!`!$```#_RP$`#@```!',`0`'````(,P!`!(````H
MS`$`!P```#O,`0`$````0\P!``T```!(S`$`%0```%;,`0`8````;,P!`"\`
M``"%S`$`"P```+7,`0`1````P<P!``4```#3S`$`!0```-G,`0`%````W\P!
M`!P```#ES`$`"P````+-`0`$````#LT!``L````3S0$`"0```!_-`0`*````
M*<T!``P````TS0$`#0```$'-`0`7````3\T!``L```!GS0$``P```'/-`0`/
M````=\T!`#D```"'S0$`2@```,'-`0`<````#,X!``D````IS@$`(````#/.
M`0`3````5,X!``4```!HS@$`$0```&[.`0`(````@,X!``L```")S@$`)P``
M`)7.`0`,````O<X!`",```#*S@$`!P```.[.`0`-````]LX!``X````$SP$`
M$P```!//`0`9````)\\!``L```!!SP$`,P```$W/`0`'````@<\!`"````")
MSP$`$0```*K/`0`5````O,\!``T```#2SP$`'````.#/`0!!````_<\!`#,`
M```_T`$`"````'/0`0`P````?-`!`"P```"MT`$`-@```-K0`0`W````$=$!
M`#````!)T0$`$P```'K1`0`6````CM$!``D```"ET0$`$@```*_1`0`2````
MPM$!`!@```#5T0$`"````.[1`0`;````]]$!`!(````3T@$`!P```";2`0`7
M````+M(!`"(```!&T@$`!0```&G2`0`%````;](!``L```!UT@$`"P```('2
M`0`4````C=(!``0```"BT@$`"````*?2`0`*````L-(!``X```"[T@$`#```
M`,K2`0`0````U](!`!````#HT@$`!@```/G2`0`&`````-,!`"L````'TP$`
M(P```#/3`0`@````5],!``,```!XTP$`"````'S3`0`&````A=,!``\```",
MTP$`&P```)S3`0`G````N-,!``\```#@TP$`"````/#3`0`A````^=,!``,`
M```;U`$`!@```!_4`0`)````)M0!``(````PU`$`#````#/4`0`5````0-0!
M``L```!6U`$`&0```&+4`0`>````?-0!`!$```";U`$`!0```*W4`0`*````
ML]0!`!4```"^U`$`$@```-34`0`,````Y]0!``4```#TU`$`"@```/K4`0`(
M````!=4!`!,````.U0$`3````"+5`0`=````;]4!`"4```"-U0$`$0```+/5
M`0`)````Q=4!``,```#/U0$`"@```-/5`0`*````WM4!``X```#IU0$`&0``
M`/C5`0`-````$M8!``L````@U@$`'0```"S6`0`)````2M8!`!8```!4U@$`
M#P```&O6`0`*````>]8!`&````"&U@$`&@```.?6`0`1`````M<!`!T````4
MUP$`&````#+7`0`0````2]<!`!@```!<UP$`%0```'77`0`9````B]<!`!P`
M``"EUP$`%0```,+7`0`*````V-<!``<```#CUP$`"````.O7`0`)````]-<!
M`!8```#^UP$`"P```!78`0`S````(=@!`!8```!5V`$`&````&S8`0`)````
MA=@!``0```"/V`$`20```)38`0`^````WM@!`#D````=V0$`6P```%?9`0`%
M````L]D!`#0```"YV0$`)0```.[9`0`,````%-H!``8````AV@$`#@```"C:
M`0`V````-]H!``0```!NV@$`3````'/:`0`K````P-H!`"D```#LV@$`"P``
M`!;;`0`A````(ML!`!X```!$VP$`%P```&/;`0`3````>]L!`!,```"/VP$`
M(@```*/;`0`0````QML!``8```#7VP$`#0```-[;`0`+````[-L!`!$```#X
MVP$`"0````K<`0`O````%-P!``P```!$W`$`"@```%'<`0`(````7-P!`!``
M``!EW`$`!P```';<`0`)````?MP!``<```"(W`$`$````)#<`0`)````H=P!
M``D```"KW`$``P```+7<`0`'````N=P!``D```#!W`$`$````,O<`0`.````
MW-P!``D```#KW`$`&@```/7<`0`,````$-T!``<````=W0$`$0```"7=`0`6
M````-]T!``H```!.W0$`"0```%G=`0`B````8]T!`!````"&W0$`(P```)?=
M`0`K````N]T!``D```#GW0$`"0```/'=`0`7````^]T!``<````3W@$`!```
M`!O>`0`=````(-X!``D````^W@$`"P```$C>`0`(````5-X!``<```!=W@$`
M"0```&7>`0`(````;]X!``D```!XW@$`!0```(+>`0`'````B-X!`!$```"0
MW@$`!@```*+>`0`.````J=X!``H```"XW@$`#````,/>`0`+````T-X!`!L`
M``#<W@$`"@```/C>`0`"`````]\!`"$````&WP$`!@```"C?`0`&````+]\!
M`',````VWP$`"````*K?`0`&````L]\!`!L```"ZWP$`)P```-;?`0`/````
M_M\!`!T````.X`$`2````"S@`0`<````=>`!`!\```"2X`$`$@```++@`0`(
M````Q>`!``4```#.X`$`#P```-3@`0`*````Y.`!``H```#OX`$`!@```/K@
M`0`*`````>$!`!(````,X0$`#````!_A`0`*````+.$!``P````WX0$`!P``
M`$3A`0`'````3.$!``@```!4X0$`"0```%WA`0`6````9^$!``D```!^X0$`
M!P```(CA`0`'````D.$!`!H```"8X0$`!@```+/A`0`7````NN$!``8```#2
MX0$`!P```-GA`0`5````X>$!``D```#WX0$`$`````'B`0`'````$N(!``8`
M```:X@$`$P```"'B`0`1````->(!`!,```!'X@$`!@```%OB`0`&````8N(!
M``H```!IX@$`"````'3B`0`$````?>(!``D```""X@$`!````(SB`0`-````
MD>(!`"(```"?X@$`"@```,+B`0`,````S>(!`"D```#:X@$`%P````3C`0`6
M````'.,!`!L````SXP$`%@```$_C`0`$````9N,!``L```!KXP$`#0```'?C
M`0`'````A>,!``(```"-XP$`#@```)#C`0`(````G^,!`"(```"HXP$`'P``
M`,OC`0`C````Z^,!`"`````/Y`$`-0```##D`0`A````9N0!`"<```"(Y`$`
M*P```+#D`0!D````W.0!`!(```!!Y0$`(0```%3E`0`^````=N4!`",```"U
MY0$`3P```-GE`0!(````*>8!`"8```!RY@$`/P```)GF`0`A````V>8!`"\`
M``#[Y@$`+@```"OG`0`G````6N<!`"<```""YP$`(0```*KG`0`V````S.<!
M`!L````#Z`$`$0```!_H`0`6````,>@!`$L```!(Z`$`<````)3H`0`X````
M!>D!`"H````^Z0$`-0```&GI`0!B````G^D!`%0````"Z@$`*P```%?J`0`<
M````@^H!``\```"@Z@$`(0```+#J`0`6````TNH!`!4```#IZ@$`+0```/_J
M`0`<````+>L!`!L```!*ZP$`+0```&;K`0`=````E.L!`#T```"RZP$`&0``
M`/#K`0`-````"NP!`"X````8[`$`)P```$?L`0`V````;^P!`"D```"F[`$`
M'````-#L`0`@````[>P!`#8````.[0$`4````$7M`0`Q````ENT!`$,```#(
M[0$`+`````SN`0`C````.>X!`#<```!=[@$`8P```)7N`0!,````^>X!`#,`
M``!&[P$`'@```'KO`0`@````F>\!`"$```"Z[P$`(````-SO`0`T````_>\!
M`%\````R\`$`40```)+P`0`\````Y/`!`#\````A\0$`*@```&'Q`0`:````
MC/$!`"@```"G\0$`+0```-#Q`0`M````_O$!`!4````L\@$`@P```$+R`0!W
M````QO(!`(`````^\P$`R````+_S`0`9````B/0!`",```"B]`$`+@```,;T
M`0`G````]?0!`$<````=]0$`(@```&7U`0!0````B/4!`"0```#9]0$`#@``
M`/[U`0!!````#?8!`"0```!/]@$`+@```'3V`0`G````H_8!`"0```#+]@$`
M.@```/#V`0`$````*_<!``<````P]P$``P```#CW`0`/````//<!``H```!,
M]P$`!P```%?W`0`(````7_<!``8```!H]P$`$0```&_W`0`$````@?<!`%L`
M``"&]P$`!````.+W`0`/````Y_<!``0```#W]P$`!P```/SW`0`'````!/@!
M``4````,^`$``P```!+X`0`0````%O@!``X````G^`$`$P```#;X`0`1````
M2O@!``(```!<^`$`"````%_X`0`'````:/@!`!0```!P^`$`#````(7X`0`6
M````DO@!``8```"I^`$`#P```+#X`0`*````P/@!``,```#+^`$`*````,_X
M`0`$````^/@!``8```#]^`$`!P````3Y`0`7````#/D!`$@````D^0$`*0``
M`&WY`0`L````E_D!`!<```#$^0$`)0```-SY`0`F`````OH!`"D````I^@$`
M'0```%/Z`0`:````<?H!`!D```",^@$`&P```*;Z`0`8````POH!`!<```#;
M^@$`'0```//Z`0`;````$?L!`!@````M^P$`)P```$;[`0`8````;OL!`"<`
M``"'^P$`(P```*_[`0`9````T_L!`!T```#M^P$`&P````O\`0`8````)_P!
M`!X```!`_`$`(@```%_\`0`=````@OP!`"8```"@_`$`(@```,?\`0`8````
MZOP!`!H````#_0$`)0```![]`0`7````1/T!`"$```!<_0$`,````'[]`0`S
M````K_T!`!,```#C_0$`)@```/?]`0`^````'OX!`!\```!=_@$`(P```'W^
M`0`A````H?X!`"0```##_@$`'@```.C^`0`8````!_\!`"$````@_P$`(```
M`$+_`0`S````8_\!`"(```"7_P$`-P```+K_`0`,````\O\!``\```#__P$`
M&0````\``@`I````*0`"`!\```!3``(`$````',``@`B````A``"``\```"G
M``(`%0```+<``@`.````S0`"`!````#<``(`&P```.T``@`'````"0$"``4`
M```1`0(`*0```!<!`@`D````00$"`!<```!F`0(`(@```'X!`@`D````H0$"
M``<```#&`0(`U````,X!`@`,````HP("`!0```"P`@(`"0```,4"`@`,````
MSP("`!P```#<`@(`$P```/D"`@`1````#0,"`!L````?`P(`"0```#L#`@`R
M````10,"``@```!X`P(`$````($#`@`'````D@,"`!(```":`P(`"@```*T#
M`@`V````N`,"``D```#O`P(`)````/D#`@`6````'@0"`!4````U!`(`%```
M`$L$`@`F````8`0"`!P```"'!`(`#````*0$`@`<````L00"``T```#.!`(`
M#@```-P$`@`5````ZP0"``H````!!0(`&`````P%`@`(````)04"`"D````N
M!0(`"0```%@%`@`/````8@4"`"H```!R!0(`!@```)T%`@`5````I`4"``<`
M``"Z!0(`"````,(%`@`)````RP4"`#L```#5!0(`!P```!$&`@`0````&08"
M`!(````J!@(`$@```#T&`@`)````4`8"``L```!:!@(`!P```&8&`@`5````
M;@8"``<```"$!@(`%P```(P&`@`+````I`8"``T```"P!@(`#````+X&`@`7
M````RP8"`!D```#C!@(`!````/T&`@`%`````@<"`!D````(!P(`!````"('
M`@`L````)P<"``P```!4!P(`$0```&$'`@`'````<P<"``(```![!P(`#```
M`'X'`@`.````BP<"``L```":!P(`!````*8'`@`)````JP<"`!,```"U!P(`
M%@```,D'`@`(````X`<"``D```#I!P(`$0```/,'`@`-````!0@"`!D````3
M"`(`&@```"T(`@`-````2`@"`#(```!6"`(`'@```(D(`@`C````J`@"`!<`
M``#,"`(`"P```.0(`@`S````\`@"``4````D"0(`$0```"H)`@!"````/`D"
M``L```!_"0(`"@```(L)`@`&````E@D"``0```"="0(`!````*()`@`*````
MIPD"`!0```"R"0(`!0```,<)`@`&````S0D"``8```#4"0(`"@```-L)`@`&
M````Y@D"``X```#M"0(`#P```/P)`@`T````#`H"`"H```!!"@(`)P```&P*
M`@`%````E`H"`!X```":"@(`#@```+D*`@`"````R`H"``0```#+"@(`"@``
M`-`*`@`%````VPH"``4```#A"@(``@```.<*`@`1````Z@H"`$,```#\"@(`
M+@```$`+`@`8````;PL"`",```"("P(`(P```*P+`@`F````T`L"``\```#W
M"P(`7@````<,`@`@````9@P"`$<```"'#`(`)````,\,`@!!````]`P"`"@`
M```V#0(`*@```%\-`@`P````B@T"`#$```"[#0(`-0```.T-`@`T````(PX"
M`"H```!8#@(`)````(,.`@`J````J`X"`#(```#3#@(`$`````8/`@`1````
M%P\"``\````I#P(`;````#D/`@`)````I@\"`*D```"P#P(`7P```%H0`@!W
M````NA`"`"X````R$0(`6````&$1`@`5````NA$"`",```#0$0(`%P```/01
M`@`7````#!("`!L````D$@(`'P```$`2`@`Y````8!("`",```":$@(`(P``
M`+X2`@!8````XA("`!H````[$P(`$@```%83`@`+````:1,"``4```!U$P(`
M!@```'L3`@`(````@A,"``4```"+$P(`$@```)$3`@`,````I!,"`!0```"Q
M$P(`'@```,83`@`.````Y1,"``\```#T$P(`!`````04`@`)````"10"``L`
M```3%`(`"````!\4`@`&````*!0"`!4````O%`(`"0```$44`@`)````3Q0"
M``X```!9%`(`#@```&@4`@`-````=Q0"`!````"%%`(`!@```)84`@`7````
MG10"``H```"U%`(`"0```,`4`@`/````RA0"``@```#:%`(`!0```.,4`@`4
M````Z10"`!4```#^%`(`"@```!05`@`&````'Q4"``\````F%0(`$0```#85
M`@`8````2!4"``T```!A%0(`!0```&\5`@`8````=14"``@```".%0(``P``
M`)<5`@`9````FQ4"``D```"U%0(``@```+\5`@`"````PA4"``\```#%%0(`
M!@```-45`@`&````W!4"``\```#C%0(`%P```/,5`@`&````"Q8"`!8````2
M%@(``@```"D6`@`$````+!8"`!(````Q%@(`$@```$06`@`0````5Q8"``<`
M``!H%@(`#0```'`6`@`&````?A8"``P```"%%@(`"````)(6`@`:````FQ8"
M``\```"V%@(`$@```,86`@`"````V18"``<```#<%@(`"0```.06`@`-````
M[A8"``\```#\%@(`*P````P7`@`$````.!<"``<````]%P(`"P```$47`@`%
M````41<"``(```!7%P(`"P```%H7`@`!````;0,````````2!````````&@&
M``!<`P``K0(``&T'``"[`0``8P,``+T```#$!0````````````"+`@``_`8`
M````````````!P```+T!```<!0``Q@,``-P"``#C````;@```/8````J!0``
M`08```````#0`P``T`0``"8"``"%````_@(``*4#``#5`0```````+0$``!'
M`0``,P8``,\%``!A!P``1`0``-0!````````V@$``!X```#\`0``4@(`````
M``#0````4`(````````=!0``-@,```D```"-!@```````,(#````````*`,`
M`!0```"!`0``/0,`````````````J`4``*X!```4`0``U@0``(D'``#@!P``
M``````````#_`0````````````"$!```KP0``,L!``#"!@```````.4%````
M````]`(```````"#!@```````#`&``!X!P``4`<``!\"``!E!````````(P&
M``!G`0```````&\````'!P``W00``*X&````````C@<``*L!``"M!P``G04`
M``````#.`P``6P```&L&``!M!0``@P$``#4`````````5@<```````#[!```
MB`8`````````````5@4````````B!```Z0$````````^!@``*@,``.,$````
M````-P$``,$$````````$P$`````````````=0,``*P!```(`@```````&X%
M``!\!P``G0$``,,&````````<@````````"]`@``&@<``.X"``#6!@``````
M`-D$``!&!0``\`(``"X%``#N````%@(``(H!``!S`P``F@```'P%``"K!P``
M``````````#'!@```````-D"```U!P``6@(``-,```!(`0```````&,`````
M````+0<``'`#```A!``````````````\!0````````8#``#>!@```````(H$
M``"'!0``,`<``/\&`````````````&P!``#P!@```````+D'````````-0,`
M`*8!``#D!0```````&@!```+!P``````````````````X@8````````3`@``
MM`4```````"`!@``<0<````````I`@``!P$```P%`````````````-\"``!%
M!P``$@$``),'``#M`@``[00``%P"``!9````ZP8``-,$``!M`0````4``-$!
M````````TP8```````#V!0``P`,```````"2!0``/`0``"`&````````,P0`
M`-T%``"R`````````$`#````````F@0``*<$``#M!@``,0(````````9!P``
M/P,``&$```"-!P``E@(``%<!``````````````H$````````T`4``'L#``"9
M`0``\P0```````!H````W@0``'($``!?!P``=P```+\&``!3!```/@(``!$&
M````````50(``!$```"A!0```````&(&``!<!0````````````#8````6`4`
M`"<"``#+````PP$`````````````$`4```````#>````P08```````!$!0``
M`````(,"``"D````^P8``)`%````````'08``-H%``!%!0``DP8``*$'``!P
M!0``^00``.8$``"W!P``````````````````5@(``$\'`````````````&4"
M``!)`P``(P8``$,%``#Q!@``O````.$#``````````````<"``!-`@``V@,`
M`#L#````````9`<``(`%````````9P0``"\$``"C!P```````&T"``!Z!@``
M)@$``$<#````````N`(``+X#``!F`@``?`8``,0$``"%`0``0@0```4"``"5
M`@``A````%P$````````@@```"$```"G!P``J@4``(`#``#6`0``M@8```H#
M````````S`(``/L"``"6`0``N`````$#``"<`0``,P$```X&```9`P``R`$`
M`$<"``!*!0```````,`%``!-!P``D@<``"D%``#(`@``````````````````
M8@,``!D!``#Q`@``<`````````#E`0``K@,``$L```"I`@``.P$``"X#``!#
M`P``OP$````````T`0``L0,``$D%``#]````"`,``(D&``!(`P``]@$``-P!
M````````T@$```````"9!````````*('``#.!P`````````````[!0``200`
M`),$````````4P<```````"'`0``&@$``",$```\`0``'0<``/X$``#*!P``
ML08``(\````>!0``\04``!H#````````S0```*L%```E`P``@````/P%````
M````X08````````O!0``Q04``(,%````````+0,``&X!``#2!P``Q0(``-T`
M``#+!`````````````"G````'@(``"L!``````````````````"O````H`8`
M`#@$``!6!@``;@,``/0$```8!P``R````*0'``#"``````````4'```]!```
ML`8```('``"-`P``.08``.8````T`@``1P```!`#``"P!0```````*@"```G
M!0``-P0```````!A`P``W@<``&D%````````L`<```````"7!0```````(D"
M``#<!```9P8``"<'````!P``M0(``#T!``"Y!0```````#D$```)`@``G0<`
M``````"X`P``!@```,X&```\````7@$``%T%``"``0``UP,``-`!``!.````
M`````&D&``!3!@``&P4``$$"``")````KP8``!\``````````````,\$``"$
M`0``R0```!L#``#Y!@```````,0`````````L0$```````#O`@``50,`````
M``!(!P```````$('``"8!@``Q`,````````0!```5`<``````````````P<`
M``````##`````````,T$````````D@8``,P#````````FP8``.X!``"(`@``
M8`4``&H"``"7!@``(P,`````````````N00``"\'```+!0``J`<``.<$``"4
M`0```````.H!``"F`@``"P(``-$````$`0``RP,```````#G`P``.`<``,``
M``#M`0``:`0`````````````$@```'(!``!3`@```````)(`````````````
M``````#.`@``H`(```````"O!0``!0````````#A`0```````#P&``!.`P``
M5`0``+4'````````4P4``"0'```````````````````_!P``#00```````!:
M!0```````"<#``"8`P``.0(``",'```3!P``D````%L!``!&!@``V@<`````
M`````````````'H$````````DP```$P$``#N!0````````````"4`@``````
M`.D%``#$`@``.````#T&``!Q`0``E0,```````#!``````````H&``">`0``
M208``)D%``"^!P````````8!````````>`(```````!0`0``N0(``%4%``"+
M!@``G`4``%D$``#7!P``+`(``,P%````````#`<``*$!``#6!P```````#L"
M``!,`P``C`(``,`$`````````````/L#````````3@$``*<"``!6`0``=0$`
M`#\&`````````````%H#``#@!0```````$<%``"D!0``VP<``*(!``!J!P``
M3`8``)@"`````````````&L!```L!P``&`4```X#``"I!P``J@0```````";
M`0``J@(``/0&````````0@8```````!-!@``G`0``,D!```S!P```````,P!
M``#*!@``2`4`````````````3@<``-T#```0!P``@@8``-(#``!$`P``````
M`$,'```P!`````````````#!`0``R`4```````"S!````````'D$``#U!```
M(0<``*,$```Z!P``S0$``,,'``#2!````````.T```")!``````````````Q
M!0``50<`````````````V`0``'X$``!Y!P``C00``.@````2`P```````*(`
M``"T!@``*P<```````"V`P``_P(``$H!``#I````8@<``'@&````````A0<`
M```````_`@``30$``(,'``"P`@```````"(#``!O`0``U0```'T%``!M!@``
M-00```8'```2`@``(@8``(4%````````,`(``+P"```L!0``6`(```(%````
M````M08``!8'```*!0``@@$`````````````K@4``$P"``"@`0``8@````P`
M```V`@``90````````"Z!````````,\````C`````````&P%````````````
M`(@$````````_08``'4$````````HP$```````"_!```WP,``!8%``![!P``
M`````+P&``#P`0```````-T'``"$!@``Z`4``.X#````````404``&L#``"J
M`````````"('``#E!@``-P,``-0#```Q!@```````$T%``"K`````````&<"
M````````,0$```,$``!8`0``;`8`````````````'P4``$`"``"'`P``````
M`&D'``!-`P````````````"+!0``!`4``)L'``#1!0``0@$``!4"```O!@``
M``````````!@!```=P0``-\```#+!@``````````````````````````````
M``````````````#A!```+0$``/<"```_````HP8``&P'```^`P``GP4``&<'
M````````L@,``#(%```_!0`````````````_!```L`$```````#D````````
M`%<'``#'`````````%D&``#]!0```````&T````8!@```````"X!```2!0``
M60<``/L```!P!```?P```(@!``#E!```T@```.@&``!]`P``B@8````````U
M!@```````.D$``!S!0``BP,``$`$``#,!@``'00```````##!```?0$``-X%
M`````````````.$```"[!@``$P8``%\%``!_!@``5P(``,($```Z!0``#`(`
M`%\$````````$`(``$L"``"Y!@``[P4``.L$``"%!@``Z`(``,X$``!A!@``
M1@,```````!>!P``6@```!<&``!R`@``Z`$``.D#```W````G0(``(X!```#
M`0``4`,```````"!!P```````,`!``"4!```]`,`````````````(@4``#H&
M````````BP0``/(&````````L@(``)H&``#@`P````````\!```-!P``````
M``````#.`0``OP,``/X%``#J!0```````&@%``#P!```H@4``!````"2!```
M?@4``#4%``!L`````````"T$``!!!0````````````![````4@8```````"V
M!````````&@"``"G!@``@`0``&,"``";`@```````!@!```@!```6`<``%H&
M``!O!@``K`<``&0&``"2`P``X`$`````````````N`8``"H"``!V`@``3@4`
M``````!J!@``Y@,``&L`````````'P<``"D`````````-P<```````!(`@``
M%@0`````````````)@,``-,!```4`@``Q0$``-L````N!@```````!,$````
M````=P4``.H#``">!P``(`4```T"```P`0``LP4``+P%```7`P``M00```X`
M``"<````)P$``/$$````````.P<``%P````C`0``'0```.@#``"C`P``)0$`
M`$$````'!0``;P,```````"Z!P``D@$``"`'```'`P``,`4``"H!```F!@``
MM`,``*D%````````6P8``-0&``#(!P``=08```@```#0!P````````````#%
M`P``G0````X"``!T!````````$D'````````XP4``%\&```R!@``2@8``&\$
M`````````````(@'```F````R@```/H$```&!0``FP4``/<%``!Q!@``````
M`````````````````#0#``"$`@```````)D"``!#!```````````````````
MXP,```````".!@``R@$``&`!``!&`0``40,``,4$``#G`0``=@0```\$``"?
M!P``?@(``````````````````/<!```/!0```````'H!``!`!P``````````
M````````I`0``%H'``````````````$%``#F`@```````+4```#_!```````
M``````#L`P``+`$``!0&````````9@,``)@'``#B!0```````'X'``#B````
M_`(``)4!````````O04``.L#````````/@0```````#%`````````&8'``"8
M`0``)00``&H$```W`@``(@(``'<!````````8@(``/<$``"A`@``70,``"H&
M``"*`P``%00``#X```"^````QP<````````U`0``X`8``#L```#N!@``````
M``T`````````@`(``+P#``"P`P``V@8``'\!````````.`$``*4```"_!0``
M``````````#C!@``<@<``)P"``"(!0``_`0``/H"``!F!0```````%8#``!5
M````+@<``(,#``#0`@``)@4``*("```)`P``U`0```4%``"\!P```````.P&
M``"7`P```````)4%````````I0(```,"````````U`4``!<!```.!0``R@,`
M`!,#````````J@,``&`'``",!```)@0```````"&!`````````````!D````
M90,``+8%```9`````````&0!``"T!P`````````````&`@``G00``%T```#S
M`P``VP4``&D`````````)0<```````"S!P``]`$`````````````Q`$``/$#
M``!!`P``'`$``(P!``#B`@``7@0``/D%``````````````````!4`P``````
M``````#Q````.@$``-(&``"Z`P``FP```/D"``#5!@``NP(``*P$``!&!```
M&P<``&0$````````F0````````#X!```@00``#D`````````&@8``/D#````
M````Z0(``$H```"1!`````````````!^`P``0`$``%H!```$!@``%0,``#8!
M``!>`````P,``)<'``!!!```)P``````````````TP(``/P```!'!```C04`
M`',$````````CP4``"T&``"_`````````'@!``#:`@```````.,"``"&!@``
M7P,``*T&``````````````````!,`0`````````````H`0``!P8``/`%``"R
M!P```````*8%```````````````````]`@``J@8```P#````````M@$`````
M``!"`@``]`4``-D#``!Q!```:P<``%8$``#?!```"00``,\!``"W!0``MP0`
M`',```"W`P``800````````'!````````)X`````````5P```&4%``"4`P``
MD0```!X!``!>!0``V`$``-$#``"&````\P(``%(%````````.`(``(H'```/
M`P```````)0%``!C!````````$T$````````VP,``)8$`````````````*0!
M```V!P``R0,``"<&```;!@``=`8``(<$``"[````S0(``,\&``"5!@``@08`
M`&(!``!!!P``(0$``/D!```<!````````+X"``"T`0``]0,``/\#``"H`0``
M```````````,`0``1@(``'(#``!"`````````"4"``#P````(P4``!X'```/
M!@``G@,``%\"``!I`0```````)H%```I!@``TP4``#T'```)!P```````#@&
M```D`@``A@(``.\&```\`P``N`$``#H#``!;`@```````'$#``":`P``3P$`
M``````"%`P```````$$!```L````'`(``.,'````````C`,````````+````
MQP0``+8"``"S`@```````%T&``"^!```2P4``$````#B`P````````$"```?
M!````````*8#``!K!0``I`,``%D"````````HP(``%$'````````,@(``/8#
M`````````````'P!``">`@``$P4```````#5!P``'`,``+4!``#+!0``H`0`
M`#(````(`0``,@,``/T#````````````````````````I04```````"Z`0``
ML@8``$X&```K`@```0$``'8!``#&!```:0(``!D%``!*!```Y`8``"T"```R
M!P``MP$``.,!```E````V04``'0#``!+!@```````'\#```D`P``````````
M``!P!P``+`8````````````````````!``"-````R`,``)$!``#E`@``````
M`&0"```P````C`4```8&````````EP$```H`````````6P<``+,```#%!P``
M%`0``*L&``!N`@``Q08``.L```!3`0``3`4``,0'````````R0<``-$'``#*
M!```?@$``!@"``#2`@``3P8```````#^!@```````(L'````````K0$``/<&
M```9!```+`,`````````````T@4``($#```)!0``\@(``!0%``!]`@``G`<`
M``````"Q`@``*`(`````````````^````-T!``"F````L00``)$#``"`!P``
MA@$``#0```#:!```6`8``````````````P8`````````````Y0````````"L
M!@``<@4``!`&```*`0```````%$````O`0``````````````````A`4`````
M``"E!```@@<``-L$``":`@``````````````````'@,``((#```-!0``8@4`
M`)X&``!Y````UP0``%\!``#O`0````8``'@%``#D`@``E`8``"(````E!0``
MT08``&,!``#5!0``````````````````+P(``-D'``#D!```*0<``(@#```H
M!```+P```%(!``!D!0```````*P#```A!@``-@4``#@#``#E`P``YP(``$X$
M```A`P``,P,```````"Z!0``*P8``/T"```,!```2P,``%$$``!!!@``=`$`
M`+<"``":`0``X0(``&\"``#$!@``````````````````I`8``)$%``"H!```
M;@8``-@#``"Y`0``L@4```````"J!P``!08``$`&``!K`@``WP8``,('``#L
M`0``<`8```````#`!@``DP4``!4&``#\`P``VP$``!X$```!!```7`<`````
M```D`0```````*8'```/`@``UP(```````!$!P``7`$``$4$``#D`P``804`
M`*($``"&!0```````!L```""!````````!H`````````:@,``!8&````````
M*P0``),"```R!````````.L"``#1`@``[````'<'`````````````'H"````
M`````````'0`````````````````````````R@4``&X'````````Y`$``)<`
M````````S0<```````"S`0``]08```$'``#7!@```````)<$``#)!@``````
M`/X```#T````L`0``,@&````````<P8``*,`````````#P<``-D```!G`P``
MPP(``#$$``"*`@``4@0``*\#``#<!P```````$(%``#Z!@``,P(``"D!``#<
M!0``X04```````!5!```?0```(\&``"?!@``$0,``'4```"=!@``4@,`````
M````````Q@$``,P'``",````4`8``+(!``"^!0``JP0```````"E!@``JP,`
M`'<#``!>`P``9P````````!F!`````````````!I`P``Z@8```````"@!P``
MD0<``"````!#`0``/@$``/X!````````$@<```````!%`0``%P0``'@#``#!
M!P``X`0```@$```K`P``[`4``$<'``#3!P``604``!$"``"/`P```````$4`
M``!N!```=@4``!,`````````90$``"X```"*!0```````$\"````````````
M``````"Y````,@$``%D!````````:`,``+8'``#X`@``?0<``*\'``!^````
M+04``(H`````````Z@0``%<#``#)`@````````````![`@``;P4``($%``#M
M!0```````'0"```Y!0```````',!```6````X@0``-P#``!V````_0$``#<%
M````````U0(``/4!``#X`P``K0,``(\'````````W@$``*8$``#`!P``````
M````````````IP,```(#`````````````-4$``!H!P``.`4```````"K`@``
ME@4``"`"````````]P,``(8'`````````````'0%``"[!0``U0,``'8&```\
M!P``T00``(\$``">!0``U````"<$``#8!@```````!T!``"E!P``R04``,X`
M`````````````)4```!W`@``^@4```````"Q````"`4```````".`P``3P0`
M`!<```")`P``\`,``'D%``!4!@``D`$````````D!@``*0,``(P'``"T````
M````````````````T`8```````#*`@````````````"'`@``D`<```@&``"]
M!```W`8```0"``#6`@``<@8``#8```"E`0``$`$``+T&``"I!@``(`$``&,'
M``!;`P``#0,``-@'```9`@``=P8``.8&````````S```````````````QP,`
M`/($``#J````P0,``$L$``!#````ZP4```L$````````!0,``.L!``!0!```
M5````)`#````````,0,````"``"@!0``D@(``+@$``#O!```_00``!$!````
M````*@<```````#/`P``4@<```````#!`@```````/H!``"L````60,``/8"
M``#S!0``P04``-T"``"4!P``"P$``)8&````````;`(``+H&``!?````````
M``D!```H!@``D`0```````!/````OP<```T!```6`0```````,8'````````
MA`,``"L```!'!@```````*$$```Z`@``;`0```````##!0``C@0``'8#``".
M!0````````````#6!0````````("```.!```>P0`````````````,`,`````
M``">!```[`0`````````````W08```````"Q!P``:@$````````<!@``BP$`
M``0```"]!P```````,L'``"U!0``'0(``&L$```_`0``O@8``)@````E!@``
MN@```,X%```Y`P``4P,``-\%``#B!P```````&8&`````````````'X&``"B
M!@``_P4``/,&```````````````````O`P``?`,``/(#````````508`````
M``#9!@``*00```````!J!0``A0(``/$!``##`P``[P```'4"``"I````````
M`)@$``#_`````````-\!````````6```````````````O@$``$X"``#>`@``
MV`(``&$!````````#@$``($```#7`0``=04``$\#``!=!```<0```*`#````
M``````````````"H!@``50$``-8`````````AP8``/<````(!P``70(``)8`
M``!Y!@``MP8``*$#``"M!```O`$`````````````1@````````!L`P``C@(`
M```````W!@```````%L%``!Y`P``Z08``$H'``!/!0``YP```$(#````````
M`````'L%``#7````%0$``*\!``#S`0``!`0``)@%```T!0``-0(``.8%````
M````Z@(``","``"I`0``VP(``#P"``!O!P``4``````````?`0```````'P`
M````````U`(``,8"``!S!P``LP,`````````````[`(```````!_!0``3```
M`*T%``#O`P``2@,```8$```T!P``'@8``!<"``#'`@``7@(``!@```!Q!0``
MN0,``"$"``#R`````````#H$`````P```````+````#&!0````````\```#H
M!```$@8``#$```"0!@````````0'````````2P$``(("``!&!P```P```'D"
M````````&`,```````"1!@``1````#0$````````,0<``/D```!3````UP4`
M``P&````````5P8``$@$````````?00``'@`````````O`0```````"I`P``
M^@,``"X$``"]`P```````'H'````````@P```'\$``![`0``^`$````````F
M!P```````#,%``````````````````"C!0``+0````````"H````8P4``%$!
M```J!```9P4``+($``"L`@``B````"(!```<````L04`````````````<0(`
M`,8````+!@``S0,`````````````N`<``'\'```Y!P``/@<``)L#````````
MCP(``)4'``"#!```_@,```H"``#Z````M0,``%@$``"I!```\@$``#X%``"[
M`P````````````!@`P``J`,``$0"``#+`@``W@,``&4'```-!@``Q@8`````
M``#9`0``[0,``*T```!V!P``LP8``$4&````````OP(``!L$``!I!```````
M`+L'````````0`4``)8#```S````K@<````````]````?08```````#<````
M3`<````````V!@``K@````````#G!@```````-8#````````H```````````
M```````````````L!````````*X$``!\`@``K@(``&8!``#B`0``^`8``-0'
M```1!P``8@0``(X```#)!```=0<```````!)````+@(``*$&`````````@8`
M``````!0!0``>`0``$@&``":!P```````%P&``#[!0``C0(```````";!```
M)`0``%T!``"9!P``%`<``!$$``"J`0``908``,(%````````#@<``$0&``!4
M`0``VP8```````#@````GP(``)\#```T!@````````````!(````8`8``$0!
M``#F`0``)`4``#L$```;`@``&@(```````!6````AP<``*0"``!@`@``````
M`#L&``")`0```@$``,P$``"V````;00```````"[!```BP```)P#``")!0``
M````````````````5P4```````"1`@``"P,```````"O`@``MP``````````
M````>P8``,`"````````$04`````````````R`0``)8'``!%`P```````)\$
M````````%0````4$``"G!0```````!H%```"!````````-,#````````40(`
M`!0#```D`````````/L!``#U!0``20$``(0'``#/`@``4@```,<!````````
M&`0``#H```!4`@``AP````0#``#8!0````````H'```;`0```````/8$``!>
M!@``E````&H```!_`@``H0```!4%``"5!```]0```'`!```H!0```````*(#
M``!@````5P0``'P$``!:!```````````````````D`(``.<%````````9@``
M``````"9`P``&@0``/8&```<!P```````"`#`````````````!<'``!A`@``
MGP$``,("``#A!P``10(````````6`P``SP<``)<"``"3`P```````"$%```%
M`0``F08```````!#!@``6`,`````````````6P0``)P&``"F!@``*@```!4'
M``"-`0``^`4```````"Z`@``G0,``/4"``#D!P```````%0%````````S04`
M`,T&``#'!0```````#D!``!*`@``@@4``!<%``!Z````<P(``,(!``"G`0``
M8P8``!D&```H!P```````!\#``"T`@``9`,``.X$``!+!P``K`4````$``!Y
M`0``0P(```D&``#S````N`4```````#R!0``*`````````"!`@``-@0```(`
M````````>@,```,%``!Z!0``/04``'0'``"%!`````````````"?````'P8`
M`(8#``#@`@``30````````#:`````````-\'```K!0``DP$```````!)`@``
M70<`````````````<`(``!T#``!1!@```````(\!```````````````@)B,Q
M-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P
M97)A=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`("A!8V-E
M<W-K97D@)7,I`"`H4F5A9"!O;FQY*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI
M`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T(&$@
M9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I
M<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@
M=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E<R(@=V%S(&%D9&5D('1O('1H
M92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@<&5R;6ES
M<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E9#H@)7,N`"4N,F9-
M0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E+C)F)24I`"5D("5S(&%N9"`E
M<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O<F0@97AP:7)E<RX`)60M9&%Y
M(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S
M($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T
M=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D
M>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&AA<R!C86YC96QL960@)7,N`"5S
M(&AA<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R
M97!L:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y
M;W4@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI
M;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!R97%U97-T<R!Y;W5R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;BX`)7,@<F5Q=65S=',@>6]U<B!P<F5S96YC92!A="`E
M<RX`)7,@=&\@)7,@;V8@)7,`)7,@=VES:&5S('1O(&%D9"!T;R`E<RX`)7,@
M=VES:&5S('1O(&UA:V4@>6]U(&%W87)E(&]F("5S+@`E<R!W:7-H97,@=&\@
M<F5C96EV92!T:&4@;&%T97-T(&EN9F]R;6%T:6]N(&%B;W5T("5S+@`E<R=S
M($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S
M(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@
M9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN
M9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@
M=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G
M=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE
M8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`
M/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@
M=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N
M960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!
M('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P
M87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`
M02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@
M<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S
M<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<'0@<F5Q
M=65S=`!!8V-E<'1E9`!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E
M8W1O<GDN`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U
M;G0@26YF;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE
M;BX`06-C;W5N=&EN9P!!8W1I;VYS`$%D9`!!9&0@)7,`061D($-H:6QD($=R
M;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R
M;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B
M)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@
M=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`061D('!A:7(`061D
M('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R`$%D9"!T:&ES('1O
M(&UY(&-A;&5N9&%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A
M9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI
M<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M
M97)I8V%N(%-A;6]A`$%N(&5R<F]R(&]C8W5R<F5D(&9O;&QO=VEN9R!T:&ES
M(&QI;FLZ("5S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG
M=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!
M<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P
M<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M
M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A
M;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N
M("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI
M($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N
M(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM
M96YT(&-O;'5M;G,`071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P
M;'D@=&\@82!R97%U97-T('EO=2!S96YT`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+@!!='1E;F1E97,`071T<FEB=71E<P!!=6=U<W0`075S=')A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U
M<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U
M=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S
M97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD
M87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L
M92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S
M(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?
M;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H
M96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!
M=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H
M96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I
M;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S
M.@!!=V%I=&EN9R!297-P;VYS90!!>F5R8F%I:F%N`$%Z=7(`0D]&2"!%>&-U
M<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@
M<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR
M86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R(%1I;64`
M0F%R('1I;64`0F%R8F%D;W,`0F%R8FEE`$)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E
M<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0FQU92!-;V]N`$)L=64@86YD(%=H:71E`$)O;&0`
M0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O
M='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)O=VX`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`
M0G5L;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R;G0@3W)A;F=E`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N
M9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%M;W5F;&%G90!#86X@;F]T
M(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S(@!#86XG
M="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N`$-A;B=T
M(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@9FEL92`B
M)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN
M;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE
M)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A
M;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E`$-A<'1I
M;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N
M9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#
M96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC
M("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI
M8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$
M971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S
M`$-H860`0VAA:7(@4&5R<V]N`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R
M9`!#:&%N9V4@9&5F875L="!I9&5N=&ET>0!#:&%N9V4@=&AE(&YA;64@86YD
M(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D(&%N9"!R
M97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P87-S=V]R9"!I
M<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO
M;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R`$-H96-?:R!,
M:6YK+BXN`$-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U
M('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H
M:6YE<V4@4VEM<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L
M("A":6<U*0!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!A;B!A8W1I;VXZ`$-H;V]S92!H
M;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H
M9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F
M:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E
M('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S
M97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N
M=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S
M`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`
M0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO;6)I80!#
M;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU
M;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N
M=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O
M<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N
M<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O
M;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@
M<V5L96-T:6]N`$-O<FYF;&]W97(`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@
M9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD
M(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N
M(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($944#H@)7,`
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E8W)Y<'0@4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D
M871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO
M="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E
M('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE
M;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E
M(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R
M:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI
M<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A
M=&5G>2`B)7,B+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L
M9"!N;W0@;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD
M(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O
M=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N
M("5S+@!#;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+@!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@
M;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y
M("<E<R<N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD
M(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O
M<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A
M:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U
M<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U
M;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S
M<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N
M("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`
M0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD
M:7(@(B5S(BX`0V]U;&0@;F]T(')M9&ER("<E<R<N`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T
M:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T
M;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T
M:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N
M(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO
M;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L
M;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE
M($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK("(E<R(N`$-O=6QD(&YO
M="!U;FQI;FL@)R5S)RX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@
M9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B
M87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO
M=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T
M97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A
M=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI
M<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N
M="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R
M96YT(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R
M96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS
M('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#
M>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U
M,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC
M`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A
M=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#
M;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI;F5D`$1E8W)E
M87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N
M=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5G871E('!O<VET
M:6]N`$1E;&5G871E9`!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P
M`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G
M92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E
M>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E
M;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@
M9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$
M96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R
M;W<`1&5L971E('1H:7,@;&EN:P!$96QE=&5D('-E='5P('5P9W)A9&4@<V-R
M:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$96YY(')E<75E<W0`
M1&5N>2!R97%U97-T(&9O<B!F<F5E+V)U<WD@:6YF;W)M871I;VX`1&5S8W)I
M8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(
M;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R
M('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W
M(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@
M;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O
M<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES
M<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I
M`$1I<W!L87D@9F]R;6%T`$1I=FED97(`1&II8F]U=&D`1&\@;F]T(&1E;&5T
M90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S
M('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE
M<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H
M879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S
M`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I
M<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@
M9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H
M:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@
M1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!0
M97)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M
M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C
M871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%
M;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I
M;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T
M:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R
M8V@@=&5R;7,`16YD`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17)R
M;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y
M;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R
M;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!S96YD:6YG(')E<&QY.B`E
M<RX`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=R:71I;F<@
M(B5S(BX`17)R;W(@=W)I=&EN9R`G)7,G+@!%<W1O;FEA`$5T:&EO<&EA`$5T
M:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`
M179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`
M179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`
M17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A
M=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T
M=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T
M;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E
M=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&
M87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`
M1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@
M4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O
M;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@
M)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO
M;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL
M=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&;VQD97(@
M)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R
M<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O
M<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@
M<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE
M<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@
M<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S
M`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`
M1G)A;F-E+"!-971R;W!O;&ET86X`1G)E92]"=7-Y($EN9F]R;6%T:6]N`$9R
M964O0G5S>2!297!L>0!&<F5E+T)U<WD@4F5Q=65S=`!&<F5E+T)U<WD@4F5Q
M=65S="!297-P;VYS90!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`
M1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U
M;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL
M97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A
M=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E
M<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO
M;G,`1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C
M86QE`$=R965C90!'<F5E;@!'<F5E;FQA;F0`1W)E;F%D80!'<F5Y`$=R;W5P
M($%D;6EN:7-T<F%T:6]N`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O
M=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U86T`1W5A=&5M86QA
M`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T(%-E<G9I8V5S`$=U
M97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)
M*0!(96EG:'0`2&5I9VAT("AI;B!P:7AE;',I`$AE;'``2&5L<"!U<VEN9R!E
M9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG
M(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;64`2&]M92!!9&1R97-S`$AO
M;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E
M<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R
M<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@
M;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3
M=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@
M:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@
M97AT96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!8
M34P@=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<F5M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T
M<FEE=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E
M+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D
M92]+;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(
M;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T
M(&AE<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L
M9"!Y;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS
M*2!A<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@
M;65R9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`
M24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X
M(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T
M:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I
M;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO
M8VLN`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E
M`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T
M97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C
M;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y
M;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E
M<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F
M(%!.1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U
M="!N;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG
M="!B92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W
M.@!);6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA
M9V4@9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@
M4W1E<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!)
M;B!0<F]C97-S`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G
M<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W
M(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF
M>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I
M96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!!8W1I
M;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+@!);G9A;&ED(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@
M87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S
M=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI
M9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO
M8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R
M(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R
M<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R
M(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`
M26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`
M26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N
M`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA=&5D(%0M
M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N
M=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)D
M86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S=&EF>2!&
M=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N
M`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G
M90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M`$MI9',`2VER:6)A=&D`2V]L86(`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE
M)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#
M+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!0
M96]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A
M<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T
M(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ
M($YE=F5R`$QA='9I80!,879E;F1E<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y
M(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@
M=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA
M:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@0FQU90!,:6=H="!$<FEZ>FQE
M`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`
M3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG
M:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@
M<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`
M3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S
M8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE
M9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@
M:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`
M3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`
M3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E
M<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M
M86X@;G5M8F5R<P!,;WEO;&$`3&]Y;VQA($)L=64`3'5X96UB;W5R9P!-30!-
M3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'
M`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI
M8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI
M;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA
M;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L
M(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E
M(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@
M<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L
M86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS
M=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F
M:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M
M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T
M=&4`365D:6-I;F4`365E=&EN9R!#86YC96QL871I;VX`365E=&EN9R!);F9O
M<FUA=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P;'D`365E=&EN
M9R!5<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96UB97)S`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C
M;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`
M36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO
M9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`
M36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO
M;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#
M;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2
M:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`36]Z
M:6QL80!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@54L@
M;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U;G0@
M26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA;FUA
M<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE6%0`
M3F5E9',@06-T:6]N`$YE<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N
M=&EL;&5S`$YE='-C87!E($)A<V4@55),`$YE='-C87!E(%)E;F5W86P@55),
M`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@
M;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E
M<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE
M=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@57-E
M<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W
M('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O
M;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P
M<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R
M86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE
M(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`
M3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`
M3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q
M=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R
M($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@
M8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-C<FEP=&EO
M;B!F;W5N9`!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO
M861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L
M;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M
M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV
M92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T
M:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O
M<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO
M9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P96YD:6YG('-I9VYU<',N`$YO
M('%U;W1A('-E=`!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O
M<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A
M<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U
M<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C
M;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E
M<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E
M(&-O;F9I9W5R871I;VXN`$YO;B!087)T:6-I<&%N=`!.;VYE`$YO;F4@*'5S
M92!I;7!L:6-I="D`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@2&5M:7-P:&5R
M90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R=V%Y`$YO="!!9G1E<@!.
M;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M96YT960N`$YO
M="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L
M(&=O(&)A8VLN`$YO=&EC90!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H
M87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M
M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I
M;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B
M97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D
M<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R
M9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P
M;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYA;"!087)T
M:6-I<&%N=`!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/
M<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R
M:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E
M<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES
M<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%
M05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N
M8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP
M=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`
M4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@
M9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B`@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92!S>7-T96TN`%!L96%S92!R979I97<@=&AE(&9O;&QO=VEN9R!I;F9O<FUA
M=&EO;BP@86YD('1H96X@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU
M(&)E;&]W+@!0;&5A<V4@<V5L96-T(&%N(&%C=&EO;B!F<F]M('1H92!M96YU
M(&)E;&]W+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O
M;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!O<W1N=6ME`%!R
M96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I
M;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S
M:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T
M('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I
M;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D
M;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I
M;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y
M($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`
M4'5R9V4@;65S<V%G97,`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!2
M86EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N
M;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O
M=W-E<@!296QO860`4F5M87)K<P!296UE;6)E<B!T:&4@9G)E92]B=7-Y(&EN
M9F]R;6%T:6]N+@!296UO=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O
M=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!2
M96UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V92!F<F]M(&UY
M(&-A;&5N9&%R`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O
M;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E
M;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`
M4F5M;W9E('5S97(Z("5S`%)E<&QY(%-E;G0N`%)E<&QY('=I=&@@3F]T(%-U
M<'!O<G1E9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N97AT
M(#(@;6]N=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@:6YF
M;W)M871I;VXN`%)E<&QY.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E
M<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C
M;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!2
M97%U:7)E9"!087)T:6-I<&%N=`!297-E=`!297-E="!087-S=V]R9`!297-E
M="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E
M='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2
M979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`
M4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@
M4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A
M9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P
M<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3
M86UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A
M;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3
M879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R
M871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!3
M8V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN
M97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@
M=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L
M96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@
M8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE
M8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L
M;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE
M('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N
M="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO
M860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S
M(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,
M96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I
M;7!L97@`4VEN9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI
M80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W
M(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@
M`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3
M;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U
M<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($=E;W)G:6$@86YD('1H
M92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`
M4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O
M;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I
M;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0`4W1A<G0@>65A
M<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R
M965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E
M8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E
M9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN
M;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E
M9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@
M=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T
M960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S
M>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!2
M96QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K
M=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K
M=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E
M9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U
M;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3
M=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`
M4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II
M;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC
M34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!2
M97!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M
M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`
M5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O
M=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E
M<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5A;`!496QE<&AO;F4@3G5M8F5R
M`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E
M.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!4
M96UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I
M;VX`5&5N=&%T:79E;'D@06-C97!T(')E<75E<W0`5&5N=&%T:79E;'D@06-C
M97!T960`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H
M86D@*%1)4RTV,C`I`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE
M('-Y<W1E;2X`5&AE("5S(&QI;FL@=&\@)7,@:&%S(&)E96X@<F5M;W9E9"X`
M5&AE($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O
M<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R
M871I;VX@96YG:6YE(&1O97,@;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L
M;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z
M.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS
M('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O
M<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@
M8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B
M;W1T;VT@<VED92!O;FQY`%1H92!C86QE;F1A<B!D871A(&ES(&EN=F%L:60`
M5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&5V96YT(&AA<R!B965N(&%D9&5D('1O('EO=7(@8V%L96YD87(N
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE
M(&-A;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@:61E;G1I='D@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@;VYL
M>0!4:&4@;&EN:R!H87,@8F5E;B!R96UO=F5D`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T87-K(&AA<R!B
M965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!U
M<V5R)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S
M=&]R960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE
M+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@
M;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E
M<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@
M(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E
M;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O
M8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I
M=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B
M>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E
M('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H
M97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@979E;G0Z("5S+@!4
M:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@)7,N
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O8G5S
M>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E
M<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T
M:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H
M92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI
M<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@
M9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N
M(&ES(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP
M;&5M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O
M9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A
M9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI
M<R!I<R`E<RX`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C
M=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R
M(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O
M;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB
M97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N
M<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4
M:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4
M:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@
M:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K
M97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4
M;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O
M<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F
M86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4
M=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4
M>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`
M56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L
M92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@
M=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H
M96-K(&9I;&4@<VEZ92`E<R\E<P!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S
M(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O
M(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E
M<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FAA;F1L960@8V]M<&]N96YT
M(&]F('1Y<&4Z("5S`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T
M97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO
M=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I
M9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E(')E<W!O;F1E;G0@<W1A='5S`%5P9&%T92!U<V5R`%5P
M9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`
M57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S
M97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T
M<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@
M86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN
M('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L
M80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`
M5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R
M>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6
M:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FEE=R!E=F5N
M=`!6:65W('1A<VL`5FER9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES
M;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@
M271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@
M34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T
M=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@
M<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E8F)P;&%T
M<V5N("T@4V]B97(`5V5B8G!L871S96X@+2!3;V)E<B!.15<`5V5E:VQY`%=E
M;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M
M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`
M5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I
M;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T
M:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI
M8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC
M:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H
M(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@
M;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7
M:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T
M<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE
M("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F
M:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D
M('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O
M(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U
M<B!F=6QL(&YA;64N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E
M<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI
M9"!E;6%I;"!A9&1R97-S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K
M96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O
M('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(
M;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S
M92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN
M="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3
M:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A
M5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T
M:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I
M;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L
M92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E
M('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F
M:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8VQO8VL`8V]M;6%N
M9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC
M86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET
M`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S
M*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM
M;65D:6%T90!I;FQI;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O
M9G1W87)E(&5R<F]R`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI
M;&4@;6%K:6YG($E33RX`;6T`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE
M="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI
M960`<&EX96QS`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R
M=FEC92!U;F%V86EL86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V
M:6$@2%144`!S<P!S=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP
M;W)A<GD@9F%I;'5R90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF
M:7)M`'5N:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T
M:&5R+F-O;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,0I297!O<G0M
M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I
M;VXM1&%T93H@,C`P-BTP,BTQ-2`Q,3HR,2LP,3`P"E!/+5)E=FES:6]N+41A
M=&4Z(#(P,#8M,#(M,38@,#`Z,C8K,#$P,`I,87-T+51R86YS;&%T;W(Z($IO
M87%U:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/@I,86YG
M=6%G92U496%M.B!3=V5D:7-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-
M12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R
M<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I
M=`H`("8C,34Q.R`E<R!K;VUM97(@871T('5T9O9R82!D92!U;F1E<FCE;&QS
M86MT:79I=&5T97)N82!S;VT@;6%R:V5R871S(&YE9&%N+@`@*"5S(&1A9V%R
M('-E9&%N*0`@*'-N86)B=&%N9V5N="`E<RD`("A3:W)I=G-K>61D860I`"`H
M;VT@)7,@9&%G87(I`"`H:61A9RD`("AI;6]R9V]N*0`@*&EGY7(I`"!K;"``
M)R5S)R#D<B!I;G1E(&5N(&MA=&%L;V<N`"<E<R<@Y'(@:6YT92!E='0@9V]D
M:^1N="!V86PN`"<E<R<@Y'(@:6YT92!K;VYF:6=U<F5R870@:2!(;W)D97)E
M9VES=')E<G0N`%1RY&1H86YT97)A<F5N(&;V<B`E<R!S86MN87,N`"<E<R<@
M;&%D97,@=&EL;"!I(&=R=7!P<WES=&5M970N`"<E<R<@;&%D97,@=&EL;"!I
M(&)E:/9R:6=H971S<WES=&5M970N`"<E<R<@<VMA<&%D97,@:6YT93H@)7,N
M`"4N,F9-0B!A;G;D;G0@878@)2XR9DU"('1I;&SE=&5T("@E,F8E)2D`)60@
M)7,@;V-H("5S`$1I='0@;/9S96YO<F0@=7!P:/9R(&%T="!GY&QL82!O;2`E
M9"!D86=A<BX`)60M9&%G<W!R;V=N;W,`)7,@+2!&]G(@:^1N;F5D;VT`1FEN
M9V5R<')I;G0@9O9R("5S`"5S($M"`"5S(%5N9&5R:.5L;'-F=6YK=&EO;B`M
M($)E:W+D9G1E;'-E`"5S(%-E='5P`"5S(&%N;>1L86X`5&KD;G-T96%V=&%L
M(&;V<B`E<P`E<R!F:6YN<R!R961A;BX`)7,@:VP@)7,@)7,`)7,@:&%R(&%N
M;G5L;&5R870@)7,N`"5S(&AA<B!S=F%R870@<.4@96X@8F5GY')A;B!O;2!I
M;F9O<FUA=&EO;B!A;F?E96YD92!L961I9R]U<'!T86=E;BX`)7,@:&%R('-V
M87)A="!PY2!I;F)J=61A;B!T:6QL("5S+@`E<R!H87(@<VMI8VMA="!D:6<@
M:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P=&%G96XN`"5S(&MO;6UE<B!A='0@
M=71F]G)A(&1E('5N9&5R:.5L;'-A:W1I=FET971E<FYA('-O;2!M87)K97)A
M=',@;F5D86XN($UA<FME<F$@9&4@86MT:79I=&5T97(@<V]M(&1U('9I;&P@
M=71F]G)A+@`E<R!K<N1V<P`E<R!M:6YU=&5R`"5S('-A:VYA<RX`)7,@969T
M97)F<N5G87(@:6YF;W)M871I;VX@;VT@;N1R(&1U(.1R(&QE9&EG+W5P<'1A
M9V5N+@`E<R!E9G1E<F9RY6=A<B!D:6X@;N1R=F%R;R!V:60@)7,N`"5S('1I
M;&P@)7,@878@)7,`)7,@=FEL;"!LY&=G82!T:6QL('1I;&P@)7,N`"5S('9I
M;&P@9_9R82!D:6<@;65D=F5T96X@;VT@)7,N`"5S('9I;&P@97)HY6QL82!D
M96X@<V5N87-T92!I;F9O<FUA=&EO;F5N(&]M("5S+@!!9')E<W-B;VL@9O9R
M("5S`$MA;&5N9&5R(&;V<B`E<P!!;G1E8VMN:6YG87(@9O9R("5S`%5P<&=I
M9G1E<B!F]G(@)7,`)7,Z("5S`"5S.B!-961D96QA;F1E="!K86YS:V4@:6YT
M92#D<B!F<N5N(&1E;B!S;VT@9&5T('9E<FMA<BX@5F%R(&;V<G-I:W1I9R!M
M960@871T(&;V;&IA(&SD;FMA<B!E;&QE<B!S:VEC:V$@879SY&YD87)E;B!P
M97)S;VYL:6<@:6YF;W)M871I;VXN`"P@<W1O<FUB>6%R`"P@<W1O<FUB>6%R
M("5S("5S`"P@=F%R:65R86YD92!M96QL86X@)7,@;V-H("5S`"TM(';D;&H@
M+2T`,3(M=&EM;6%R<V9O<FUA=``R-"UT:6UM87)S9F]R;6%T`#(T('1I;6UA
M<@`\1O9R96?E96YD90!%;B!D871A8F%S:V]P<&QI;F<@:W+D=G,@9O9R(&%K
M='5E;&QT(&)L;V-K+@!%='0@9F%T86QT(&9E;"!H87(@:6YT<N1F9F%T`$5N
M('!U8FQI:R!01U`M;GEC:V5L(&MRY'9S(&;V<B!A='0@:W)Y<'1E<F$@971T
M(&UE9&1E;&%N9&4N`$5N('!U8FQI:R!01U`M;GEC:V5L(&MRY'9S(&;V<B!A
M='0@=F5R:69I97)A(&5T="!S:6=N97)A="!M961D96QA;F1E+@!%;B!P=6)L
M:6L@;V-H('!R:79A="!01U`M;GEC:V5L('-A;70@;/9S96YO<F0@:W+D=G,@
M9O9R(&%T="!D96MR>7!T97)A(&5T="!M961D96QA;F1E+@!%;B!P=6)L:6L@
M;V-H('!R:79A="!01U`M;GEC:V5L('-A;70@;/9S96YO<F0@:W+D=G,@9O9R
M(&%T="!S:6=N97)A(&5T="!M961D96QA;F1E+@!%;B!P=6)L:6L@;V-H('!R
M:79A="!3+TU)344M;GEC:V5L('-A;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T
M="!D96MR>7!T97)A(&5T="!M961D96QA;F1E+@!%;B!P=6)L:6L@;V-H('!R
M:79A="!3+TU)344M;GEC:V5L('-A;70@;/9S96YO<F0@:W+D=G,@9O9R(&%T
M="!S:6=N97)A(&5T="!M961D96QA;F1E+@!%;B!P=6)L:6L@4R]-24U%+6YY
M8VME;"!K<N1V<R!F]G(@871T(&MR>7!T97)A(&5T="!M961D96QA;F1E+@!&
M]G)M:61D86=S;6]L;@!,Y'1T(&;V<FUI9&1A9W-R96=N`$;V<FUI9&1A9W-R
M96=N`$;V<FUI9&1A9W-S:W5R87(`1O9R;6ED9&%G<W-K=7)A<B!M960@<V[V
M`$%-+U!-`$%022!)1`!/;2!E9&ET;W)N`$]M+BXN`$)O='1E;@!-:71T96X`
M06-C97!T97)A(&)E9^1R86X`06-C97!T97)A9`!"96CV<FEG:&5T('-A:VYA
M<R!A='0@<VMA<&$@5D93+6UA<'`N`$)E:/9R:6=H970@<V%K;F%S(&%T="!S
M:V%P82!61E,M9FEL+@!+;VYT;VEN9F]R;6%T:6]N`$SV<V5N;W)D(&;V<B!K
M;VYT;P!+;VYT;W0@9G)Y<W0`0G5D9V5T`,5T9^1R9&5R`$SD9V<@=&EL;`!,
MY&=G('1I;&P@)7,`3.1G9R!T:6QL('5N9&5R9W)U<'``;.1G9R!T:6QL('5N
M9&5R8F5H]G)I9VAE=`!,Y&=G('1I;&P@:.1R.@!,Y&=G('1I;&P@;GD@9W)U
M<'``3.1G9R!T:6QL(&YY(&)E:/9R:6=H970`3.1G9R!T:6QL('5N9&5R9W)U
M<'`@=&EL;"`G)7,G`$SD9V<@=&EL;"!U;F1E<F)E:/9R:6=H970@=&EL;"`G
M)7,G`$SD9V<@=&EL;"!E;B!N>2!A;G;D;F1A<F4Z`$SD9V<@=&EL;"!K;VQU
M;6X`3.1G9R!T:6QL(&YY82!M961L96UM87(`3.1G9R!T:6QL('!A<@!,Y&=G
M('1I;&P@;65N>6X@9O9R("5S('-O;2!-;WII;&QA(%-I9&5B87(`3.1G9R!T
M:6QL(&D@;6EN(&MA;&5N9&5R`$SD9V<@=&EL;"!I(&%D<F5S<V)O:SH`3.1G
M9R!T:6QL(&D@;6EN(&%D<F5S<V)O:P!,Y&=G('1I;&P@86YVY&YD87)E`$QA
M9&4@=&EL;"`G)7,G('1I;&P@<WES=&5M970L(&UE;B!K=6YD92!I;G1E(&SD
M9V=A('1I;&P@97AT<F$@(&EN9F]R;6%T:6]N.B`E<RX`3&%D92!T:6QL("<E
M<R<@=&EL;"!S>7-T96UE="X@1'4@:V%N(&QO9V=A(&EN(&YU+@!5<'!LY&=G
M(&%V(&%N=N1N9&%R92#D<B!I;F%K=&EV97)A="X`061R97-S`$%D<F5S<V)O
M:P!!9&UI;FES=')A=&EO;B`M(&%N9V4@8F5H]G)I9VAE="!F]G(@86YD<F$@
M86YVY&YD87)E`$%D;6EN:7-T<F%T:6]N`%)E:VQA;0!!9F=A;FES=&%N`$%L
M8F%N:65N`$%L9V5R:65T`$%L:6%S`$IU<W1E<F$`2G5S=&5R:6YG.@!!;&QA
M`$%L;&$@875T96YT:7-E<F%D92!A;G;D;F1A<F4`06QL82!G<G5P<&5R`$%L
M;&$@8F5H]G)I9VAE=&5R`$%L;&$@9GER82!S:61O<@!4:6QLY70@9FQE<F$@
M861R97-S97(`5&EL;.5T(&EN<W3D;&QN:6YG(&;V<B!S;W)T97)A9"!L:7-T
M83\`1FEN;G,@<F5D86X`06QT97)N871I=B!)35-0+6EN;&]G9VYI;F<`06QT
M97)N871I=G0@;/9S96YO<F0@9O9R($E-4U``06QT97)N871I=G0@86YVY&YD
M87)N86UN(&;V<B!)35-0`$%L=&5R;F%T:78@92UP;W-T(&%D<F5S<P!!;'1E
M<FYA=&EV(&UA;&P`06QT97)N871I=B!T97AT.@!!;65R:6MA;G-K82!386UO
M80!%='0@9F5L('5P<'-T;V0@;N1R(&SD;FME;B`H)7,I('-K=6QL92!A;G;D
M;F1A<P!%='0@9F5L86MT:6=T(';D<F1E(&%N9V%V<RX`171T(&]KY&YT(&9E
M;"!H87(@:6YT<N1F9F%T`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY
M;2!P<F]X>0!3=F%R`$%N=&%R:W1I<P!!;G1I9W5A(&]C:"!"87)B=61A`$%P
M<&QI:V%T:6]N`$%P<&QI:V%T:6]N<VQI<W1A`$%P<&QI:V%T:6]N96X@Y'(@
M:VQA<BX`5F5R:W-TY&QL('1I;&P@=6YD97)U=&1E;&YI;F=A<@!';V1KY&YN
M`%5N9V5FY')L:6<@<W1O<FQE:P!A<')I;`!!<F%B:7-K("A7:6YD;W=S+3$R
M-38I`$%R:VEV9FEL<W1O<FQE:P!!<FMI=F9I;&YA;6X`Q'(@9&5T('/D:V5R
M="!A='0@9'4@=FEL;"!T82!B;W)T(&)E9^1R86X@9O9R("5S/P#$<B!D970@
M<^1K97)T(&%T="!D=2!V:6QL(')A9&5R82`G)7,G(&]C:"!E=F5N='5E;&QA
M('5N9&5R9W)U<'!E<C\`07)G96YT:6YA`$%R;6%N:65N`$%R;65N:7-K("A!
M4DU30TE)+3@I`$MO;G-T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@
M:V]N<W0`07-I96XO4W1I;&QA(&AA=G-R96=I;VYE;@!&<N5G82!E9G1E<B!B
M96MRY&9T96QS92!I;FYA;B!U;F1E<FCE;&QS86MT:79I=&5T97(@=71F]G)S
M/P!4:6QL9&5L;FEN9W-K;VQU;6X`0FEF;V=A9"#D<B!E;B!I0V%L96YD97(@
M9FEL(&UE9"!E='0@<W9A<B!PY2!E;B!B96?D<F%N('-O;2!D=2!S:VEC:V%T
M+`!&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N(&=R=7!P('-O;2!I;G1E(&9I
M;FYS+@!&]G)S]FL@=&EL;"!A='0@<F%D97)A(&5N(&)E:/9R:6=H970@<V]M
M(&EN=&4@9FEN;G,N`$;V<G/V:R!A='0@Y&YD<F$@96X@8F5H]G)I9VAE="!S
M;VT@:6YT92!F:6YN<RX`1O9R<_9K(&%T="#D;F1R82!E;B!U=&1E;&YI;F<@
M<V]M(&EN=&4@9FEN;G,N`$1E;'1A9V%R90!!='1R:6)U=`!A=6=U<W1I`$%U
M<W1R86QI96X`UG-T97)R:6ME`$%U=&A?8WER<W%L.B!)34%0+65X=&5N<VEO
M;B!S86MN87,N`$%U=&A?8WER<W%L.B!+;W!P;&EN9V5N('-A:VYA<B!F=6YK
M=&EO;F5R('-O;2!K<N1V<RX`075T:%]C>7)U<SH@24U!4"UE>'1E;G-I;VX@
M<V%K;F%S+@!!=71H7V9T<#H@1E10+71I;&SD9V<@<V%K;F%S+B!+;VUP:6QE
M<F$@4$A0(&UE9"!S=VET8VAE;B`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@
M24U!4"UE>'1E;G-I;VX@<V%K;F%S+@!!=71H7VMR8C4Z(&MR8C4M97AT96YS
M:6]N('-A:VYA<RX`075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T(&SD9V=A
M('1I;&P@86YVY&YD87)E(&D@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z
M($1E="!GY7(@:6YT92!A='0@<F%D97)A(&%N=N1N9&%R92!F<N5N($%C=&EV
M92!$:7)E8W1O<GD`075T:%]L9&%P.B!,1$%0+71I;&SD9V<@<V%K;F%S+@!!
M=71H7VQD87`Z($MA;B!I;G1E(&SD9V=A('1I;&P@86YVY&YD87)E("<E<R<N
M(%-E<G9E<FX@<W9A<F%D93H@`$%U=&A?;&1A<#H@2V%N(&EN=&4@<F%D97)A
M(&%N=N1N9&%R92`E<P!!=71H7VQD87`Z($MA;B!I;G1E('5P<&1A=&5R82!A
M;G;D;F1A<F4@)7,`075T:%]L9&%P.B!$970@9^5R(&EN=&4@871T('5P<&1A
M=&5R82!A;G;D;F1A<F4@:2!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ
M($U#04PM97AT96YS:6]N('-A:VYA<RX`075T:%]S;6)A=71H.B!S;6)A=71H
M+65X=&5N<VEO;B!S86MN87,N`$%U=&5N=&ES97)I;F<@=&EL;"!)34%0+7-E
M<G9E<B!M:7-S;'EC:V%D97,N`$%U=&5N=&ES97)I;F<@;6ES<VQY8VMA9&5S
M`$%U=&5N=&ES97)I;F<@;6ES<VQY8VMA9&5S+B`E<P!!=71E;G1I<V5R:6YG
M(&%V=FES861E<R!A=B!2041)55,M<V5R=F5R;BX`075T96YT:7-E<FEN9R!T
M:6QL($944"US97)V97(@;6ES<VQY8VMA9&5S+@!!=71E;G1I<V5R:6YG('1I
M;&P@4TU"+7-E<G9E<B!M:7-S;'EC:V%D97,N`%1I;&QGY&YG;&EG82!FY&QT
M.@!6Y&YT87(@<.4@<W9A<@!!>F5R8F%I:F%N`$%Z=7)B;.4`0D]&2"UU<G/D
M:W1E<@!"86MG<G5N9`!"86MG<G5N9'-FY')G`$9E;&%K=&EG="!L]G-E;F]R
M9"!F]G(@2V5R8F5R;W,`1F5L86MT:6=T(&%N=N1N9&%R;F%M;B!F]G(@2V5R
M8F5R;W,`0F%H86UA<P!"86AR86EN`$)A;'1I<VL@*$E33RTX.#4Y+3$S*0!"
M86YG;&%D97-H`$)A<G1I9`!2861T:60`0F%R8F%D;W,`0F%R8FEE`$)A<VMA
M=&%L;V<@)R5S)R!F]G(@8FEL9&5R(&AI='1A9&5S(&EN=&4N`$)A<VQI;FIE
M`%9I=')Y<W-L86YD`$)E;&=I96X`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$;V9&5L<V5D86<`0FQO8VL@)R5S)R!F]G(@87!P;&EK871I;VX@)R5S
M)R!S86MN87,N`$)L;V-K:6YS=.1L;&YI;F=A<@!";&]C:W1Y<`!";.4@;>5N
M90!";.5T="!O8V@@=FET=`!&970`0F]L:79I80!";VMMY')K96X`4F%M`%)A
M;6)R961D.@!286UA<@!";W-N:65N(&]C:"!(97)Z96=O=FEN80!"Y61A`$)O
M='-W86YA`$)O='1E;@!";W5V970@27-L86YD`$)R87-I;&EE;@!"<FET=&ES
M:V$@=&5R<FET;W)I970@:2!);F1I<VMA(&]C96%N96X`0G)U;@!"<G5N96D`
M0G5L9V%R:65N`%!U;FMT;&ES=&$`0G5R:VEN82!&87-O`$)RY&YD($]R86YG
M90!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E
M;&P@:6YS=.1L;&YI;F=A<BXN+@!#86-H96EN:71I97)I;F<@Y'(@:6YT92!F
M=6QL<W3D;F1I9RX`2V%L96YD97(`3'5G;G0`2V%M8F]D:F$`2V%M97)U;@!+
M86UO=69L86=E`$MA;B!I;G1E(&YO;&QS=.1L;&$@;/9S96YO<F0@875T;VUA
M=&ES:W0L(&MO;G1A:W1A(&1I;B!A9&UI;FES=')A=/9R+@!+86X@:6YT92!S
M:W)I=F$@=&EL;"!F:6P@)R5S)P!$970@9^5R(&EN=&4@871T(&%D;6EN:7-T
M<F5R82!E>'1E<FYA('-E<W-I;VYS:&%N=&5R87)E+@!+86X@:6YT92!K;VYT
M86MT82!)34%0+7-E<G9E<FXZ("5S`$MA;B!I;G1E(/9P<&YA(&9I;"`G)7,G
M`$MA;F%D80!!=F)R>70`079B<GET('!R;V)L96UR87!P;W)T`$MA;B!I;G1E
M(')A9&5R82`G)7,G+@!+86X@:6YT92!H:71T82!E;B!T96UP<N1R(&UA<'`N
M`$MA;B!I;G1E(&9O<G1SY'1T82!U=&%N("=MY6QF:6PG+7!A<F%M971E<BX`
M2V%N(&EN=&4@<F%D97)A(&UA<'`@)R5S)RX`2V%N(&EN=&4@<F%D97)A.R`E
M9"!B87)N(&5X:7-T97)A<BX`2V%N(&EN=&4@9&ER:6=E<F$@;65D9&5L86YD
M92!T:6QL(&%N9VEV970@;G5M;65R+@!+87`@5F5R9&4`4G5B<FEK`$]P97)A
M=/9R`$MA=&5G;W)I97(@;V-H(')U8G)I:V5R`$-A>6UA;B!)<VQA;F1S`$UO
M8FEL=&5L969O;@!#96QL:6YS=.1L;&YI;F=A<@!#96QL=71F>6QL;F%D.@!#
M96QL:6YS=.1L;&YI;F=A<@!#96QL;65L;&%N<G5M.@!-;V)I;'1E;&5F;VX`
M0V5L=&ES:R`H25-/+3@X-3DM,30I`$-E;G1R97)A9`!#96YT<F%L869R:6MA
M;G-K82!R97!U8FQI:V5N`$-E;G1R86QE=7)O<&5I<VL@*$E33RTX.#4Y+3(I
M`$-E<G1I9FEK871D971A;&IE<@!#97)T:69I:V%TY&=A<F4`0V5R=&EF:6MA
M='!O;&EC:65S`%1C:&%D`$]R9&;V<F%N9&4`Q&YD<F$`Q&YD<F$@9&ET="!L
M]G-E;F]R9`#$;F1R82!F]G)V86QD(&ED96YT:71E=`#$;F1R82!N86UN(&]C
M:"!A9')E<W,@<V]M(&UO='1A9V%R;F$@<V5R(&[D<B!D92!LY'-E<B!O8V@@
M<W9A<F%R('#E(&1I;F$@;65D9&5L86YD96XN`$%T="!B>71A(&SV<V5N;W)D
M('-T]F1S(&EN=&4@;65D(&1E;B!N=79A<F%N9&4@:V]N9FEG=7)A=&EO;F5N
M+B`@5F%R(&=O9"!K;VYT86MT82!A9&UI;FES=')A=/9R96XN`%1K;@!+;VYT
M<F]L;&5R82!LY&YK+BXN`$UA<FME<F$@9&4@86MT:79I=&5T97(@9'4@=FEL
M;"!U=&;V<F$@;G4N`$-H:6QE`$MI;F$`2VEN97-I<VMT(&;V<F5N:VQA="`H
M1T(R,S$R*0!+:6YE<VES:W0@=')A9&ET:6]N96QL="`H0FEG-2D`5N1L:B!A
M<'!L:6MA=&EO;CH`5N1L:B!L]G-E;F]R9`!6Y&QJ(&%N=N1N9&%R;F%M;@!6
MY&QJ(.5T9^1R9#H`5N1L:B!H=7(@9&%T=6T@<VMA;&P@=FES87,Z`%;D;&H@
M;&ES='-T:6P@*&;V<B!S;W)T97)A9&4@;&ES=&]R*0!*=6SV;@!+;&%S<V1E
M9FEN:71I;VX@9O9R("5S('-A:VYA<RX`4F5N<V$`4F5N<V$@35-/9F9I8V4M
M=&%G9V%R`%)E;G-A(&9RY6=A`%)E;G-A(&%N=N1N9&%R93H@)7,`4F5N<V$@
M86YVY&1N87)E`%)E;G-A(&%N=N1N9&%R9&%T80!396YA<F4@=7!P:VQA<FYA
M;F1E`$ML:6-K82!F]G(@871T(&9O<G1SY'1T80!#;&EC:V%T96QL('9I82!(
M5%10`%-TY&YG(&;V;G-T97(`36]L;@!4:61I9V$@;6]L;@!-;VQN:6YG=`!#
M;V-O<R`H2V5E;&EN9RD@27-L86YD<P!+;VUP<FEM97)A('-I9&]FY&QT970`
M2V]M<')I;65R861E(')A;6%R`$MO;&]M8FEA`$;D<F<`1N1R9VAA;G1E<F%R
M90!&Y')G=F%L`$MO;'5M;F5R.@!+;VQU;6X@<G5B<FEK97(`3'5S=&EG:&5T
M97(`2V]M;6%N9&\`2V]M;6%N9&]F]FYS=&5R`$MO;6UE;G1A<@!.86UN`$-O
M;6]R;W,`1O9R971A9P!3;'5T9O9R9`!3:W)I=B!M961D96QA;F1E("@E<RD`
M1&%T;W)E<@!6Y&1E<@!6Y&1E<@!+;VYF:6=U<F%T:6]N<W-K:6QL;F%D97(`
M26YS=.1L;&YI;F=A<B!F]G(@871T('-Y;FMR;VYI<V5R82!M960@:&%N9&1A
M=&]R97(L('-M87)T82!T96QE9F]N97(@;V-H($]U=&QO;VL`2V]N9FEG=7)A
M=&EO;B!B96CV=F5R('5P<&1A=&5R87,N`$MO;F9I9W5R97)A("5S`$)E:W+D
M9G1A(&SV<V5N;W)D`$MO;F=O`$MO;F=O`$;V<F)I;F1E;'-E(&UI<W-L>6-K
M861E<RX`1O9R8FEN9&5L<V4@;6ES<VQY8VMA9&5S.B``1O9R8FEN9&5L<V4@
M;65D('!U8FQI:R!N>6-K96QS97)V97(@;F5K861E<RX`1O9R8FEN9&5L<V4@
M;65D('!U8FQI:R!N>6-K96QS97)V97(@;F5K861E<SH@)7,@*"5S*0!&]G)B
M:6YD96QS92!M960@1E10+7-E<G9E<B!M:7-S;'EC:V%D97,N`$MO;G1A:W1E
M<@!+;VYT86MT97(@;&%D97,@=&EL;"!I(&1I;B!A9')E<W-B;VLN`$EN;F5H
MY6QL<W1Y<"!F]G(@:V]M<')I;65R860@9FEL.B``26YN96CE;&P@:2`G)7,G
M`$9O<G1SY'1T`$-O;VL@27-L86YD<P!#;V]K:64`2V]P:65R80!+;W!I97)I
M;F<@;6ES<VQY8VMA9&5S.B`E<P!+;W!I97)A(&UA<FME<FEN9P!-86IS8FQO
M;6UA`$MO<W1N861S+4E$`$-O<W1A(%)I8V$`16QF96YB96YS:W5S=&5N`$MA
M;B!I;G1E(%!'4"UK<GEP=&5R82!M961D96QA;F1E+@!+86X@:6YT92!01U`M
M:W)Y<'1E<F$@;65D9&5L86YD93H@`$MA;B!I;G1E(%!'4"US:6=N97)A(&UE
M9&1E;&%N9&4N`$MA;B!I;G1E(%!'4"US:6=N97)A(&UE9&1E;&%N9&4Z(`!+
M86X@:6YT92!3+TU)344M:W)Y<'1E<F$@;65D9&5L86YD92X`2V%N(&EN=&4@
M4R]-24U%+7-I9VYE<F$@;65D9&5L86YD92X`2V%N(&EN=&4@;.1G9V$@=&EL
M;"!K;VYT86MT+B`E<P!-:7-S;'EC:V%D97,@871T(&MO;G1A:W1A($Q$05`@
M<V5R=F5R+@!+86X@:6YT92!V97)I9FEE<F$@:V]N=&]S86QD;RX@)7,`2W5N
M9&4@:6YT92!A;G-L=71A('1I;&P@3$1!4"US97)V97(N`$MA;B!I;G1E(&MO
M;G1A:W1A('-E<G9E<B`G)7,G('9I82!&5%`Z("5S`$MA;B!I;G1E('-K87!A
M(&1I<W1R:6)U=&EO;G-L:7-T82X@)7,`2V%N(&EN=&4@9&5K<GEP=&5R82!0
M1U`M9&%T82X`2V%N(&EN=&4@9&5K<GEP=&5R82!01U`M9&%T83H@`$MA;B!I
M;G1E(&1E:W)Y<'1E<F$@4R]-24U%+61A=&$N`$MA;B!I;G1E(')A9&5R82!K
M;VYT86MT+B`E<P!+86X@:6YT92!R861E<F$@9&ES=')I8G5T:6]N<VQI<W1A
M+B`E<P!+86X@:6YT92!R861E<F$@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL
M.B`E<RX`2V%N(&EN=&4@8F5S=.1M;6$@;6]T=&%G87)E;G,@95!O<W0M861R
M97-S+@!+86X@:6YT92!HY&UT82!K;VUP;&5T="!A9')E<W-B;VLN`$MA;B!I
M;G1E(&CD;71A(&MO;7!L971T(&1I<W1R:6)U=&EO;G-L:7-T82X`2V%N(&EN
M=&4@:.1M=&$@:V]M<&QE='0@;&ES=&$@]G9E<B!D:7-T<FEB=71I;VYS;&ES
M=&]R+@!+86X@:6YT92!L861D82!S=')A=&5G:2`G)7,G+@!+86X@:6YT92!L
M861D82!S=')A=&5G:2`G)7,G+@!+86X@:6YT92!S:V%P82!M87!P("<E<R<N
M`$MA;B!I;G1E('-K87!A(&UA<'`@)R5S)RX`2V%N(&EN=&4@:.1M=&$@<'5B
M;&EK(&YY8VME;"!F<N5N(&YY8VME;'-E<G9E<FXN`$MA;B!I;G1E(/9P<&YA
M("<E<R<@9O9R('-K<FEV:6YG+@!+86X@:6YT92#V<'!N82`E<RX`2V%N(&EN
M=&4@]G!P;F$@)R5S)R!F]G(@<VMR:79I;F<N`$MA;B!I;G1E(/9P<&YA($UA
M:6YT96YA;F-E7U1A<VL@;6]D=6P@)7,`2V%N(&EN=&4@]G!P;F$@;6%P<&5N
M("<E<R<`2V%N(&EN=&4@]G!P;F$@;6%P<"`G)7,G`$MA;B!I;G1E(&MO;G1A
M:W1A($Q$05`@<V5R=F5R+@!+86X@:6YT92!LY'-A("5S+@!$970@9VEC:R!I
M;G1E(&%T="#E=&5R<W3D;&QA(&SV<V5N;W)D970@9O9R(&1E;B!A;F=I=FYA
M(&%N=N1N9&%R96XN($[E9V]N(&5L;&5R(&[E9W)A(&%V('5P<&=I9G1E<FYA
M(.1R(&EN=&4@:V]R<F5K=&$N($;V<G/V:R!I9V5N(&5L;&5R(&MO;G1A:W1A
M(&%D;6EN:7-T<F%T]G)E;B!O;2!D=2!B96CV=F5R(&AJY&QP+@!+86X@:6YT
M92!HY&UT82!!0TP`2V%N(&EN=&4@:.1M=&$@861R97-S8F]K+B`E<P!+86X@
M:6YT92!HY&UT82!D:7-T<FEB=71I;VYS;&ES=&$N("5S`$MA;B!I;G1E(&CD
M;71A(&1I<W1R:6)U=&EO;G-L:7-T;W(N("5S`$MA;B!I;G1E(&CD;71A(&1S
M97)V97)F=6YK=&EO;F5R`$MA;B!I;G1E(.5T97)S=.1L;&$@:V]N9FEG=7)A
M=&EO;F5N+@!+86X@:6YT92!R861E<F$@;6%P<"`G)7,G+@!+86X@:6YT92!R
M861E<F$@;6%P<"`G)7,G+@!+86X@:6YT92!S<&%R82!K;VYF:6=U<F%T:6]N
M(&;V<B`E<RX`2V%N(&EN=&4@<W!A<F$@8F%C:W5P+6MO;F9I9W5R871I;VXN
M`$MA;B!I;G1E('-P87)A(&5N(&)A8VMU<"UK;VYF:6=U<F%T:6]N.B`E<RX`
M2V%N(&EN=&4@<W!A<F$@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`
M2V%N(&EN=&4@<W!A<F$@8F%C:W5P+6MO;F9I9W5R871I;VX@)7,N`$MA;B!I
M;G1E('-P87)A(&MO;F9I9W5R871I;VYS9FEL96X@)7,N($1U(&MA;B!A;G1I
M;F=E;B!A;G;D;F1A(&5N(&%V(&%L=&5R;F%T:79E;B!A='0@<W!A<F$@:V]D
M96X@=&EL;"`E<R!E;&QE<B!K;W!I97)A(&MO9&5N(&YE9&%N('1I;&P@)7,N
M`$MA;B!I;G1E('/V:V$@:2!,1$%0+6MA=&%L;V=E;BX`2V%N(&EN=&4@<F%D
M97)A("<E<R<N`$MA;B!I;G1E(')A9&5R82`G)7,G+@!+86X@:6YT92!U<'!D
M871E<F$@:V]N=&%K="X@)7,`2V%N(&EN=&4@=7!P9&%T97)A(&1I<W1R:6)U
M=&EO;G-L:7-T82X@)7,`2V%N(&EN=&$@<W!A<F$@:V]N9FEG=7)A=&EO;B!F
M]G(@)R5S)SH@)7,`2V%N(&EN=&4@:&ET=&$@36]Z:6QL87,@<VED;V;D;'0N
M(%9E<FEF:65R82!A='0@<VED;V;D;'1E="#D<B#V<'!E="X`2V%N(&EN=&4@
M9V4@86YVY&YD87)E;B`G)7,G(&%N9VEV;F$@<N1T=&EG:&5T97(@=&EL;"!M
M87!P96X@)R5S)SH@)7,`4N1K;F%D('1E>'0`3&%N9`!+=7)S97(`4VMA<&$`
M4VMA<&$@;.1N:P!3:V%P82!N>0!3:V%P82!U;F1E<FUA<'``0F5H]G)I9VAE
M=&5R(&;V<B#D9V%R80!+<F5D:71K;W)T<VYU;6UE<@!+<F]A=&EE;@!+=6)A
M`$%K='5E;&QA(#0@9F%S97(`06MT=65L;"!S97-S:6]N`$%K='5E;&P@=&ED
M`$%K='5E;&P@55),(.1R`$%K=&EV82!A;G;D;F1A<F4`06MT=65L;'0@=N1D
M97(`06MT=65L;&$@=FEL;&MO<CH@`$%K='5E;&P@<W1I;`!3:W+D9&1A<G-Y
M(&%K=&EV:71E=&5R('-O;2!K]G)S('9I9"!I;FQO9VYI;F<@=&EL;"`E<RX`
M2VQI<'`@=70`2VQI<'`@=7)V86P`0WEP97)N`$MY<FEL;&ES:R`H2T])."U2
M*0!+>7)I;&QI<VL@*%=I;F1O=W,M,3(U,2D`2WER:6QL:7-K+U5K<F%I;G-K
M("A+3TDX+54I`%1J96-K:65N`$1$`$1A9VQI9P!$871A5')E92!B;.1D9')A
M<F4`1&%T86)A<W5P<'-L86<`1&%T=6T`1&%T=6T@;6]T=&%G970`1&%T=6UV
M86P`1&%G`%]2861E<F$@:V]L=6UN`&1E8V5M8F5R`$1E8VEM86QE<@!!=F+V
M:G0`36EN<VMA(&EN9')A9P!&]G)V86QT`$;V<G9A;&0@9N1R9P!&]G)V86QD
M(&ED96YT:71E=`!&]G)V86QT('-K86P`1&5F:6YI=&EO;F5R`$1E;&5G97)A
M('!O<VET:6]N`$1E;&5G97)A9`!2861E<F$`4F%D97)A(&-E;&P`4F%D97)A
M(&=R=7!P`%)A9&5R82!L;V=G`%)A9&5R82!B96CV<FEG:&5T`%)A9&5R82!O
M8V@@<F5N<V$@;65D9&5L86YD96X`4F%D97)A(&-E;&P`4F%D97)A(&MO;'5M
M;@!2861E<F$@8F5F:6YT;&EG(&%L=&5R;F%T:79M86QL`%)A9&5R861E(&UE
M9&1E;&%N9&5N`%)A9&5R82!B96CV<FEG:&5T(&;V<B`G)7,G`%)A9&5R82!B
M96CV<FEG:&5T(&;V<B`G)7,G(&]C:"!U;F1E<F)E:/9R:6=H971E<C\`4F%D
M97)A(')A9`!2861E<F$@=F%L9"!I9&5N=&ET970`4F%D97)A('5N9&5R;6%P
M<&%R`%)A9&5R82!A:W1U96QL(&MO;'5M;@!2861E<F$@86MT=65L;"!R860`
M4F%D97)A(&1E;B!HY'(@;.1N:V5N`%)A9&5R861E('5P<&=R861E<FEN9W-S
M8W)I<'1E="`G)7,G+@!,979E<F%N<W1I9`!$86YM87)K`$%V<VSE(&)E9^1R
M86X`079S;.4@8F5GY')A;B!O;2!L961I9R]U<'!T86=E;BUI;F9O<FUA=&EO
M;@!"97-K<FEV('!R;V)L96UE=`!"97-K<FEV;FEN9P!$971A;&IE<B`H;V-K
M<^4@:2!(;W)D97,@;&]G9V9I;"DZ`$1E=&%L:F5R(&AA<B!L;V=G871S(&;V
M<B!S>7-T96UA9&UI;FES=')A=/9R96XN`%5T=F5C:VQI;F<`1&%G9W!U;FMT
M`$1A9V=P=6YK="!F]G(@<V5N87-T92!T:6UM96XZ(`!$86=G<'5N:W0Z(`!2
M:6MT;FEN9R!VY&YS=&5R('1I;&P@:/9G97(`4FEK=&YI;F<@:/9G97(@=&EL
M;"!VY&YS=&5R`$MA=&%L;V<`5FES82`R-"UT:6UM87)S(&ML;V-K83\`5FES
M;FEN9W-I;G-TY&QL;FEN9V%R`%9I<V$@9&5T86QJ97)A9"!F]G)U='/D9V5L
M<V4`5FES82!F]G)U='/D9V5L<V4@*%1!1BD`5FES;FEN9W-F;W)M870`079S
M:VEL:F%R90!$:FEB;W5T:0!2861E<F$@:6YT90!!;G;D;F0@:6YT92!M86EN
M=&5N86YC92YP:'`@9&ER96MT`$EN;F5HY6QL97(@9O9R<W1A(')A9&5N(&;D
M;'1N86UN96X_($]M("=J82<L(&UA<FME<F$@:.1R.@!$;VUI;FEK86YS:V$@
M<F5P=6)L:6ME;@!(87(@9'4@:6YG970@:V]N=&\_(%)E9VES=')E<F$@9&EG
M+@!(Y&UT80!(Y&UT82`E<P!(Y&UT82!G96YE<F5R860@:V]N9FEG=7)A=&EO
M;B!S;VT@4$A0+7-K<FEP="X`1')O<'!L:7-T80!$<F]G97(`12UP;W-T`$1R
M:79R=71I;B!F]G(@12UP;W-T('1I;&P@4TU3+6)R>6=G83L@9O9R(&]P97)A
M=/9R97(@<V]M('1I;&QH86YD86CE;&QE<B!D96YN82!T:N1N<W0N`$9%3`!%
M:W5A9&]R`,1N9')A`,1N9')A(&)L;V-K`,1N9')A(&=R=7!P`,1N9')A(&)E
M:/9R:6=H970`Q&YD<F$@8F5H]G)I9VAE=&5R`,1N9')A(&)E:/9R:6=H971E
M<B!F]G(@)7,`Q&YD<F$@:6YS=.1L;&YI;F=A<B!F]G(Z`,1N9')A(&)E:/9R
M:6=H971E<B!F]G(@)R5S)P#$;F1R82!B96CV<FEG:&5T97(@9O9R("<E<R<`
M571B:6QD;FEN9P!%9WEP=&5N`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`
M12UP;W-T`$4M<&]S=&%D<F5S<P!%+7!O<W1A9')E<W-E<B!MY7-T92!S=.1M
M;6$@]G9E<G)E;G,N`$4M<&]S=&UE9&1E;&%N9&4@;65D(&)E:W+D9G1E;'-E
M`$4M<&]S="!T:6QL(%--4RUB<GEG9V$`2^1N<VQO:6MO;F5R`%1O;70@;65D
M9&5L86YD92X`5&]M="!R97-U;'1A="X`5&]M="!S]FMK<FET97)I80!3;'5T
M`%-L=70@Y7(`1O9R<W1O<F$@961I=&]R`$%N9V4@<_9K=N1G("A54DPI('1I
M;&P@8FEL9&5N(&CD<@!32W)I=B!B;VMS=.1V97)N82!N961A;CH`1F5L`$9E
M;"!V:60@<VMA<&%N9&4@878@8FQO8VLZ("5S`$9E;"!V:60@<F%D97)I;F<@
M878@<WEN:W)O;FES97)I;F=S;>1R:V4Z("5S`$9E;"!V:60@<F%D97)I;F<@
M878@<WEN:W)O;FES97)I;F=S;&]G9SH@)7,`1F5L(&[D<B!I;FYE:.5L(&CD
M;71A9&5S.B`E<P!&96P@=6YD97(@<^1N9&YI;F<@878@<W9A<G-M961D96QA
M;F1E.B`E<P!&96P@=FED('5P<&1A=&5R:6YG(&%V(&SV<V5N;W)D.B`E<P!&
M96P@=FED('-K<FEV;FEN9R`G)7,G+@!&96P@=FED('-K<FEV;FEN9R!A=B`G
M)7,G+@!%<W1L86YD`$5T:6]P:65N`$5T;FES:P!%=7)O<&$`5F%R(#$U.F4@
M;6EN=70`5F%R86YN86X@;6EN=70`5F%R(#,P.F4@<V5K=6YD`%9A<B`U.F4@
M;6EN=70`5F%R:F4@:6YL;V=G;FEN9P!687)J92!H86QV=&EM;64`5F%R:F4@
M;6EN=70`17AE;7!E;"!PY2!VY')D96XZ`$OV<@!%>'!A;F1E<F$`17AP86YD
M97)A('-I9&]FY&QT`$;V<G;D;G1A9&4@)RDG`$;V<G;D;G1A9&4@96YS:VEL
M="!O<F0@96QL97(@8VET97)A="!S]FMB96=R97!P`$;V<F9A;&QO9&%T=6T`
M17AP;VYE;G0`1O9R9W)U;F1S9N1R9P!,861D82!U<'`@:V]N9FEG=7)A=&EO
M;B!V:6$@1E10+@!-:7-S;'EC:V%D97,@871T(&CD;71A(&EN<W3D;&QN:6YG
M87(N`$UI<W-L>6-K861E<R!A='0@:V]N=&%K=&$@3$1!4"!S97)V97(N`$UI
M<W-L>6-K861E<R!A='0@:V]N=&%K=&$@4TU"('-E<G9E<BX`36ES<VQY8VMA
M9&5S(&%T="!K;W!I97)A(&9RY6X@)R5S)RX`36ES<VQY8VMA9&5S(&%T="!K
M;W!I97)A('1I;&P@)R5S)RX`36ES<VQY8VMA9&5S(&%T="!S:V%P82!N>2!3
M05-,+6;V<F)I;F1E;'-E+@!-:7-S;'EC:V%D97,@871T(&9L>71T82!T:6QL
M("<E<R<N`$UI<W-L>6-K861E<R!A='0@:.1M=&$Z("5S`$)R80!&86QK;&%N
M9'/V87)N80!&Y'+V87)N80!&871A;'0@9F5L.@!&87@`1F%X87(`9F5B<G5A
M<FD`2^1N;G,@<V]M`$OD;FYS('-O;3H@`$;E=&%L:6=A('-K=7)A<@!&Y71A
M;&EG82!S;O9S:W5R87(`1N1L=&UA=')I<P!&:6=L970@0T%05$-(00!&:6=L
M971T>7!S;FET=`!&:6II`$9I;`!!;G1A;"!F:6QE<CH@)7,@9FEL`$%N=&%L
M(&9I;&5R.B`E<R!F:6QE<@!&:6QH86YT97)A<F4`1FEL;F%M;@!&:6QV86P`
M1FEL=7!P;&%D9&YI;F<`1FEL=7!P;&%D9&YI;F<@<W3V9',@:6YT92X`1FEL
M=&5R`$9I;FQA;F0`1O9R<W1A(&AA;'9A;@!&]G)S=&$@:W9A<G1E;@!-87!P
M("5S(&5X:7-T97)A<B!I;G1E+@!&;VYT9N1R9P!-870`1O9R('=E8F)LY'-A
M<F4@<V]M(&EN=&4@<W3V9&5R(&)I;&1E<@!0<F]G;F]S("A4048I`$%N=&%L
M(&1A9V%R(&;V<B!P<F]G;F]S("AV87)J92!D86<@8F5T>61E<B!E;B!P<F]G
M;F]S(&;V<B!D86<@;V-H(&5N(&;V<B!N871T*0!';/9M="!D:71T(&SV<V5N
M;W)D/P!&;W)M=6SD<@!6:7-H971S;W)D`%1Y<"!A=B!V:7-H971S;W)D`%9I
M<VAE='-O<F0`5FES:&5T<V]R9"`R`$9O<G5M`%9I9&%R8F5F;W)D<F%R`$9R
M`%)A;6%R`$9R86YK<FEK90!&<F%N:W)I:V4L($UE=')O<&]L`$QE9&EG+U5P
M<'1A9V5N(&EN9F]R;6%T:6]N`$QE9&EG+U5P<'1A9V5N('-V87(`3&5D:6<O
M=7!P=&%G96XM9O9R9G+E9V%N`%-V87(@<.4@;&5D:6<O=7!P=&%G96XM9O9R
M9G+E9V%N`$9R86YS:V$@1W5I86YA`$9R86YS:V$@4&]L>6YE<VEE;@!&<F%N
M<VMA('/V9')A('1E<G)I=&]R:65R`$9RY6X`1G+E;B!D96X@`$9U;&QS=.1N
M9&EG(&)E<VMR:79N:6YG`$9U;&QMY6YE`$9U;&QS=.1N9&EG="!N86UN`$=A
M8F]N`$=A;&QE<FD@871T('1A(&)I;&0@9G+E;@!'86QL97)I.@!'86UB:6$`
M1V5N97)E<F$@:V]N9FEG=7)A=&EO;B!F]G(@)7,`1V5N97)E<F%D(&MO9`!'
M96]R9VEE;@!4>7-K;&%N9`!':&%N80!':6)R86QT87(`1O9R;F%M;@!';&]B
M86QA(&EN<W3D;&QN:6YG87(`3TL`1V]E9&5L`$=O;V=L96MA<G1O<@!';V]G
M;&5S]FMN:6YG`$=RY7-K86QA`$=R96MI<VL@*$E33RTX.#4Y+3<I`$=R]FX`
M1W+V;FQA;F0`1W)A;F%D80!'<N4`1W)U<'!A9&UI;FES=')A=&EO;@!'<F]U
M<%]L9&%P.B!+86X@:6YT92!LY&=G82!T:6QL(&=R=7!P("<E<R<N(%-E<G9E
M<FX@<W9A<F%D93H@`$=R;W5P7VQD87`Z($MA;B!I;G1E(')A9&5R82!G<G5P
M<"`G)7,G`$=R;W5P7VQD87`Z($MA;B!I;G1E('5P<&1A=&5R82!G<G5P<"`G
M)7,G`$=R=7!P97(`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1^1S=&)E:/9R
M:6=H971E<@!4:N1N<W1E<B!F]G(@9^1S=&5R`$?D<W1B;VL`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5I;F5A`$A434P`2%1-3$%R96$@=N1G<F%R(&%T="!R
M861E<F$@<VES=&$@8V5L;&5N(&D@96X@<F%D+@!(5$U,07)E82!VY&=R87(@
M871T(')A9&5R82!S:7-T82!K;VQU;6YE;B!I(&5N('1A8F5L;"X`2%1-3$%R
M96$@=N1G<F%R(&%T="!R861E<F$@<VES=&$@<F%D96X@:2!E;B!T86)E;&PN
M`$A45%`@075T96YT:7-E<FEN9R!S86MN87,N`$AA:71I`$AA<VAA;&=O<FET
M;0!$:6UM80!2=6)R:6L`4G5B<FEK97(`2&5A<F0M(&]C:"!-8T1O;F%L9/9A
M<FYA`$MR869T:6=A(.5S:W-K=7)A<@!(96)R96ES:R`H25-/+3@X-3DM."U)
M*0!(]FID`$CV:F0@*'!I>&QA<BD`2&KD;'``2&KD;'`@;65D(&5D:71O<FX`
M2&KD;'!F=6YK=&EO;@!(96UI<V;D<@!(Y'(@Y'(@8O9R:F%N(&%V(&9I;&5N
M.@!(]F<`2&5?;0!(96T`061R97-S+"!H96T`2&5M:V%T86QO9P!496QE9F]N
M+"!H96T`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!/
M9VEL=&EG="`E<R!834PM9&%T82!PY71RY&9F861E<R!I(&UE9&1E;&%N9&4@
M)7,`2&]R9&4O2V]L86(Z($EN9V5T(&UE9&1E;&%N9&4@;6%T8VAA<B!O8FIE
M:W1E="`E<P!(;W)D92]+;VQA;CH@26YG970@;V)J96MT(&%V('1Y<&5N("5S
M(&AI='1A9&5S(&D@;65D9&5L86YD970@)7,`2&]R9&4O2V]L86(Z(%)A9&5R
M861E("5S("<E<R<`2&]R9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUO=&]R;B!K
M<N1V97(@)V1O;7AM;"<M=&EL;.1G9V5T(&;V<B!02%``2&]R9&4O2V]L86(Z
M($MA;B!I;G1E('-K87!A(&YY='0@6$U,+71RY&0@9O9R(&]B:F5K="`E<P!(
M;W)D92]+;VQA8CH@2V%N(&EN=&4@<F%D97)A("5S("<E<R<Z("5S`$AO<F1E
M+TMO;&%B.B!+86X@:6YT92!HY&UT82!-24U$12U)1"!F]G(@9&5L96X@;65D
M('1Y<"`E<P!(;W)D92]+;VQA8CH@2V%N(&EN=&4@<WEN:W)O;FES97)A("5S
M("<E<R<Z("5S`$AO<F1E+TMO;&%B.B!+86X@:6YT92!S>6YK<F]N:7-E<F$@
M=71D96QN:6YG87(Z("5S`$AO<F1E+TMO;&%B.B!/:^1N9"!U=&1E;&YI;F<@
M)R5S)P!(;W)I<V]N=&5L;"!L:6YJ90!(;W)I<V]N=&5L;"!U=&9Y;&QN860`
M2&]R:7-O;G1E;&PZ`$AU<B!H86UN861E(&1U(&CD<C\@*%9A<B!G;V0@<F%P
M<&]R=&5R82!D971T82$I`$AU<B!MY6YG82!K;VQU;6YE<B!V:6QL(&1U('-L
MY2!I:&]P/P!(=7(@;>5N9V$@9N1L="`H:V]L=6UN97(I(&9I;FYS(&1E=#\`
M2'5R(&WE;F=A(')A9&5R('9I;&P@9'4@<VSE('-A;6UA;C\`1G5K=&EG:&5T
M`$9U:W1I9VAE=#H`2'5M;W)I<W1E<@!5;F=E<FX`4VMA<&%N9&4@878@24U!
M4"UM87!P(&UI<W-L>6-K861E.B`E<P!2861E<FEN9R!A=B!)34%0+6UA<'`@
M;6ES<VQY8VMA9&5S.B`E<P!3:V%P86YD92!A=B!Q=6]T82!F]G(@24U!4"UM
M87!P(&UI<W-L>6-K861E<SH@)7,`25`M861R97-S`$E0+6%D<F5S<R#D<B!I
M;G1E('1I;&QGY&YG;&EG+@!)4"UA9')E<W,@Y'(@:6YT92!I;F]M(&=O9&OD
M;G0@0TE$4BUB;&]C:RX`1O9R<_9K(&%T="!K<FEN9V?E($E0+6SE<RX`25]N
M9F]G82!R860@9O9R90!)<VQA;F0`16YB87)T(&EK;VYE<@!):V]N97(@9O9R
M("5S`$EK;VYE<B!M960@=&5X=`!)9&5N=&ET971E;G,@;F%M;CH`3VT@9&5T
M(&EN=&4@=FES87,@:V]R<F5K="P@)7,@9O9R(&%T="#V<'!N82!I(&YY='0@
M9O9N<W1E<BX`3VT@9'4@:6YT92!S97(@;N5G<F$@:6MO;F5R(&[D<B!D=2!A
M;G;D;F1E<B!);G1E<FYE="!%>'!L;W)E<BP@<^4@:V%N(&1U(&)E:/9V82!M
M87)K97)A(&1E;FYA(')U=&$@9O9R(&%T="!S=.1N9V$@878@9V5N;VUS:VEN
M;&EG82!03D<M8FEL9&9I;&5R+@!/;2!D=2!S97(@9&5N;F$@=&5X="!M96X@
M:6YG96X@8FEL9"P@<^4@:V%N(&EN=&4@9&EN('=E8F)LY'-A<F4@=FES82!D
M96X@8FEL9"!D=2!F]G)S]FME<B!L861D82!U<'`N`$;V<FAA;F1S9W)A;G-K
M82!B:6QD.@!":6QD861R97-S`$)I;&1A9')E<W,Z`$)I;&0@9G+E;B!G86QL
M97)I`$)I;&0@9G+E;B!G86QL97)I.@!,861D82!U<'`@8FEL9`!":6QD97(`
M26UP;W)T97)A+"!S=&5G("5D`$EM<&]R=&5R861E(&;D;'0Z("5S`$EM<&]R
M=&5R861E(&;D;'0Z`%#E9^5E;F1E`$EN7V9O9V$@<F%D(&5F=&5R`$9E;&%K
M=&EV(&%K=&EV:71E='-K;V0@<W!E8VEF:6-E<F%D+@!&96QA:W1I9W0@86YV
MY&YD87)N86UN(&]C:"]E;&QE<B!L]G-E;F]R9"X`3V=I;'1I9W0@86YVY&YD
M87)N86UN(&5L;&5R(&%L=&5R;F%T:78@861R97-S+B!&]G)S]FL@:6=E;B!E
M;&QE<B!K;VYT86MT82!A9&UI;FES=')A=/9R96X@;VT@9'4@8F5H]G9E<B!H
M:N1L<"X`UFMA(&EN9')A9P!);F1I96X`26YD:79I9'5E;&QA(&%N=N1N9&%R
M90!);F1O;F5S:65N`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@Y'(@
M:6YT92!T:6QL9^1N9VQI9R!LY&YG<F4N`$EN9F]G82!K7V]L=6UN(&5F=&5R
M`$EN9F]G82!B:6QD`$EN9F]G82!T86)E;&P`26YF;V=A('=E8F)LY&YK`$EN
M9F]G82!?:V]L=6UN(&;V<F4`26YF;V=A(&YY(&MO;'5M;B!E9G1E<B!A:W1U
M96QL(&MO;'5M;@!);F9O9V$@;GD@:V]L=6UN(&;V<F4@86MT=65L;"!K;VQU
M;6X`26YF;V=A(')A9"!E9G1E<B!A:W1U96QL(')A9`!);F9O9V$@;GD@<F%D
M(&;V<F4@96MT=65L;"!R860`26YF;V=A('!A<F%G<F%F(&5F=&5R(&%K='5E
M;&P@;F]D`$EN9F]G82!P87)A9W)A9B!F]G)E(&%K='5E;&P@;F]D`$EN9F]G
M82!A;'1E<FYA=&EV(&UA;&P`26YF;V=A(&-E;&P@969T97(`26YF;V=A(&-E
M;&P@9O9R90!);F9O9V$@:V]L=6UN(&5F=&5R`$EN9F]G82!K;VQU;6X@9O9R
M90!);F9O9V$@;65D9&5L86YD96X`26YF;V=A('!A<F%G<F%F(&5F=&5R`$EN
M9F]G82!P87)A9W)A9B!F]G)E`$EN9F]G82!R860@969T97(`26YF;V=A(')A
M9"!F]G)E`$%N9V4@97)F;W)D<F%T('-V87(@=&EL;"!SY&ME<FAE='-F<N5G
M86XZ`$EN9F]G82_$;F1R82!B:6QD`$EN9F]G82_$;F1R82!LY&YK`$]T:6QL
M<N1C:VQI9R!K<F5D:70@9O9R(&%T="!S:VEC:V$@=&EL;"!D:7-T<FEB=71I
M;VYS;&ES=&$N`$]T:6QL<N1C:VQI9R!K<F5D:70N`$AE;'1A;`!(96QT86QS
M;&ES=&$`3V=I;'1I9R#E=&?D<F0@9O9R(&1E;B!HY'(@:V]M<&]N96YT96XN
M`$]G:6QT:6<@541(("@G=7-E<B!D871A(&AE861E<B<I+@!/9VEL=&EG="!:
M25`M87)K:79D871A`$9E;&%K=&EG(&%P<&QI:V%T:6]N+@!&96QA:W1I9W0@
M8F%T8V@M240`1F5L86MT:6<@9&%T82!S:VEC:V%D+@!&96QA:W1I9R!D97-T
M:6YA=&EO;G-A9')E<W,N`$9E;&%K=&EG="!F:6QF;W)M870`3V=I;'1I9R!L
M:6-E;G-N>6-K96PN`$9E;&%K=&EG(&]R="!S<&5C:69I8V5R860N`$9E;&%K
M=&EG(&UE9&1E;&%N9&5?='EP+@!&96QA:W1I9R!E;&QE<B!S86MN860@87!I
M7VED+@!&96QA:W1I9W0@96QL97(@<V%K;F%D('!A<F%M971E<BX`1F5L86MT
M:6<@]G9E<FQI9V=A;F1E(&)E:/9R:6=H970N`$9E;&%K=&EG="!P87)T;F5R
M+6ED+@!&96QA:W1I9R!P<F]D=6MT:V]D+@!&96QA:W1I9W0@<')O=&]K;VQL
M+@!&96QA:W1I9R!M;W1T86=A<F4Z("<E<R<`1F5L86MT:6=T('5T9&5L;FEN
M9W-O8FIE:W0`1F5L86MT:6<@879SY&YD87)A9')E<W,N`$9E;&%K=&EG="!U
M;FEC;V1E+61A=&$`26YV96YT87)I97(`26YV97)T97)A('5R=F%L`$ER86X`
M27)A:P!)<FQA;F0`27-L92!O9B!-86X`16YS=&%K82#E<VMS:W5R87(`27-R
M865L`%5T9N1R9&%T(&%V`$MU<G-I=@!)=&%L:65N`$IA;6%I8V$`:F%N=6%R
M:0!*87!A;@!*87!A;G-K("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE
M;@!J=6QI`&IU;FD`2G5S=&5R80!#96YT97)J=7-T97)A`$IU<W1E<F$@:N1M
M=`!6Y&YS=&5R:G5S=&5R80!(]F=E<FIU<W1E<F$`2V5N>6$`2V5R8F5R;W-S
M97)V97)N(&%V=FES861E(&%U=&5N=&ES97)I;F=E;BX`3GEC:V5L('-K87!A
M9`!&:6YG97)P<FEN=`!.>6-K96QLY&YG9`!.>6-K96QT>7``3GEC:V5L86YV
MY&YD86YD90!.>6-K96P@9FEN;G,@<F5D86X@<.4@9&5N('!U8FQI:V$@;GEC
M:V5L<V5R=F5R;BX`0F%R;@!+:7)I8F%T:0!+;VQA8@!.;W)D:V]R96$`4WED
M:V]R96$`2V]R96%N<VL@*$550RU+4BD`2W5W86ET`$MI<F=I<W1A;@!,85]Y
M;W5T`%-P<N5K`$QA;W,`4VES=&$@:&%L=F%N`$SV<V5N;W)D(.1N9')A9&5S
M`%-I<W1A(&MV87)T86QE=`!396YA<W0@=7!P9&%T97)A9#H`4V5N87-T92!I
M;FQO9V=N:6YG.B`E<P!396YA<W1E(&EN;&]G9VYI;F<Z("5S(&9RY6X@)7,`
M4V5N87-T92!I;FQO9V=N:6YG.B!!;&1R:6<`3&5T=&QA;F0`3&%V96YD97(`
M3&%G`$QA>6]U=`!,Y&UN82!T;VT@9O9R(&%T="!S=.1N9V$@878@:V%N=&QI
M;FIE`$QI8F%N;VX`5N1N<W1E<@!6Y&YS=&5R<G5B<FEK`%;D;G-T97)VY')D
M96X`3&5S;W1H;P!.:7;E`$QI8F5R:6$`3&EB>65N`$QI96-H=&5N<W1E:6X`
M3&IU<V)LY0!$=6=G<F5G;@!,Y'1T(')E9VX`3.1T="!F]G)M:61D86=S<F5G
M;@!,Y'1T(&5F=&5R;6ED9&%G<W)E9VX`3.1T="!R96=N<VMU<@!,Y'1T(')E
M9VX@;65D(.5S:V$`3.1T="!S;O8`3.1T="!S;O9S:W5R`$QI;65R:6-K`$SD
M;FL`3.1N:V5N('!E:V%R('#E.@!,Y&YK82!E+7!O<W1A9')E<W-E;B!T:6QL
M(&9U;FMT:6]N96X@9O9R(&%T="!S:V%P82!N>71T(&UE9&1E;&%N9&4`3.1N
M:V%R`$MA:V$`3&ES=&$@+2!A;G;D;F1A<F4@:V%N('-E(&UA<'!E;@!6:7-A
M(&1A=&%B87-E<@!6:7-A(&AJY&QPY&UN96X`3&ES=&$@=&%B96QL97(`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`1&5T(&=I8VL@
M:6YT92!A='0@;&ES=&$@<V5S<VEO;F5R.B`E<P!$970@9VEC:R!I;G1E(&%T
M="!L:7-T82!A;G;D;F1A<F4Z("5S`$QI<W1N:6YG(&%V(&%N=N1N9&%R92!A
M=F%K=&EV97)A9"X`3&ET=&5R871U<@!,:71A=65N`$QA9&1A<BXN+@!,;VMA
M;"!T:60Z(`!296=I;VYA;'0`4&QA=',`3&]G9V$@:6X`3&]G9V$@=70`3&]G
M:6X`3&]G:6YA:W1I=FET971E<@!);FQO9V=N:6YG(&UI<W-L>6-K861E<RX@
M5')O;&EG='9I<R!V87(@86YVY&YD87)N86UN(&5L;&5R(&SV<V5N;W)D(&9E
M;&%K=&EG="X`26YL;V=G;FEN9R!M:7-S;'EC:V%D97,N`$SE;F<@=&5X=`!+
MY')L96L`3.5G`$=R96MI<VMA(&=E;65N97(`3&%T:6YS:V$@9V5M96YE<@!3
M;>4@<F]M97)S:V$@<VEF9G)O<@!,;WEO;&$`3&]Y;VQA($)LY0!,=7AE;6)U
M<F<`34T`34]41`!-4RU43D5&(&)I;&%G82!I;FYE:/9L;"!I;F=E;B!D871A
M+@!-4T<`36%C86\`36%C961O;FEE;@!-86=A9V%S:V%R`$UA9VES:P!%+7!O
M<W0`12UP;W-T861M:6X`4VMA<&$@;.1N:RXN+@!-86QA=VD`36%L87ES:6$`
M36%L9&EV97)N80!-86QI`$UA;'1A`%5N9&5R:.5L;"!L:7-T86X@;65D(&MA
M=&5G;W)I97(@9'4@86YVY&YD97(@9O9R(&%T="!K871E9V]R:7-E<F$@<&]S
M=&5R(&UE9"!O8V@@9N1R9V5R;F$@<V]M('1I;&QH]G(@9&5S<V$@:V%T96=O
M<FEE<BX`36%P,C0M:V%R=&$`36%P475E<W0M:V%R=&$`UG9E<G/D='1N:6YG
M87(@<W!A<F%D92X`;6%R<P!-87)G:6YA;`!&;&%G9V$@<V]M(&SD<W0O;VSD
M<W0`1FQA9V=A(&UE9"!A;FYA;B!S=&%T=7,@*'0@97@@=FEK=&EG="]B97-V
M87)A="D`36%R<VAA;&SV87)N80!-87)T:6YI<75E`$UA=&-H86YD92!FY&QT
M`$UA=7)I=&%N:65N`$UA=7)I=&EU<P!-87@@=&EL;.5T96X@:W)E9&ET+@!'
M<N1N<R!F]G(@;6%X(&%N=&%L(&1E;&%R(&D@;65D9&5L86YD92#V=F5R<VMR
M:61E;BX`2/9G<W1A('1E;7!E<F%T=7)E('-E;F%S=&4@,C0@=&EM;6%R;F$Z
M(`!(]F=S=&$@=&5M<&5R871U<F4@<V5N87-T92`V('1I;6UA<FYA.B``36%X
M:6UA;'0@86YT86P@<&]R=&%L8FQO8VL`36%X:6UA;"!LY&YG9`!M86H`36%Y
M;W1T90!-961I8VEN`$%V8F]K82!M]G1E`$WV=&5S:6YF;W)M871I;VX`3?9T
M97-F]G)F<N5G86X`3?9T97-S=F%R`$WV=&5S=7!P9&%T97)I;F<`57!P9&%T
M97)I;F=S8F5GY')A;B!O;2!M]G1E`$UE9&QE;6UA<@!-96YY;.1G93H`4VSE
M(&EH;W`@8V5L;&5R`$UE9&1E;&%N9&4`365D9&5L86YD970@=F5R:69I97)A
M9&5S(&UE;B!D96X@<VEG;F5R861E<R!C97)T:69I:V%T(&MU;F1E(&EN=&4@
M=F5R:69I97)A<RX`365D9&5L86YD92!GY&QL97(@:6YT92!LY&YG<F4N`$UE
M9&1E;&%N9&5T>7``365T87)VY&1E<@!-971A<F)L;V-K970@Y'(@:6YT92!T
M:6QL9^1N9VQI="X`365T87(M8FQO8VL@96H@=&EL;&?D;F=L:6=T+B!$971A
M;&IE<B!H87(@;&]G9V%T<R!F]G(@<WES=&5M861M:6YI<W1R873V<F5N+@!-
M971A<D1"(.1R(&EN=&4@86YS;'5T96XN`$UE=&]D`$UE=&]D96X@)R5S)R#D
M<B!I;G1E(&1E9FEN:65R860`365T;V1E;B!H87(@:6YT92!D969I;F5R871S
M+B!!;G)O<&%D(&UE=&]D.B`E<P!-971R:7-K`$UE>&EK;P!-:6MR;VYE<VEE
M;@!-:71T96X`36EM971Y<`!,Y&=S=&$@=&5M<&5R871U<B!S96YA<W1E(#(T
M('1I;6UA<FYA.B``3.1G<W1A('1E;7!E<F%T=7(@<V5N87-T92`V('1I;6UA
M<FYA.B``36EN<W1A(&SV<V5N;W)D<^5L9&5R(&AA<B!I;G1E('5P<&[E='1S
M(.1N`%-P96=L80!$:79E<G-E`$]B;&EG871O<FES:W0@<&%K970@<V%K;F%S
M("A014%2($A45%!?4F5Q=65S="DN`$MO;F9I9W5R871I;VX@<V%K;F%S+B!$
M=2!MY7-T92!S:V%P82!D96X@;G4@;VT@9'4@=FEL;"!A;G;D;F1A(&1E;B!H
MY'(@87!P;&EK871I;VYE;BX`4V%K;F%R(&UE9&1E;&%N9&4M240N`$]B;&EG
M871O<FES:W0@<&%K970@<V%K;F%S("A014%2($UA:6PI+@!386MN87(@<V5S
M<VEO;G,M240N`$WE`$UO8FEL(&4M<&]S=`!-;V1E<F5R80#$;F1R860@9&%T
M=6T`Q&YD<F$@;.1N:P!-;V1U;'5S`$UO;&1A=FEE;@!-;VYA8V\`36]N9V]L
M:65T`$WE;F%D(&]C:"#E<@!-Y6YA=&QI9P!-;W1S97)R870`3>5N9F%S97(`
M1FQE<B!FY&QT(&AI='1A9&5S('#E(')A9"`E9"#D;B!D970@9O9R=N1N=&%D
M92`E9"X`36%R;V-K;P!-97-T861E;',@:VQA<G0`365S=&%D96QS(&UO;&YI
M9W0`365S=&%D96QS('-O;&EG=`!&;'ET=&$@;F5D`$9L>71T82!VY&YS=&5R
M`$9L>71T82!H]F=E<@!&;'ET=&$@=7!P`$9L>71T82!N960`1FQY='1A('5P
M<`!-;^=A;6)I<75E`$UO>FEL;&$`1FQE<FYI=N5S;&ES=&$`375L=&EM87`@
M4W1O<F)R:71A;FYI96YK87)T80!&;&5R=F%L`$UI='0@:V]N=&\`36EN(&MO
M;G1O:6YF;W)M871I;VX`36EN('!O<G1A;`!-:6X@<&]R=&%L;&%Y;W5T`$UY
M86YM87(`3D5*+"!*86<@86-C97!T97)A<B!I;G1E`$YA;6X`3F%M:6)I80!.
M875R=0!.95A4`$)E:/9V97(@Y71GY')D`$YE<&%L`$YE9&5R;.1N9&5R;F$`
M3F5D97)LY&YD<VMA($%N=&EL;&5R;F$`3F5S8V%P92!B87,M55),`$YE='-C
M87!E(&;V<FYY96QS92U54DP`3F5T<V-A<&4@Y71E<FMA;&QE;'-E+5523`!.
M971S8V%P92!34TPM<V5R=F5R;F%M;@!.971S87!E(&-E<G1I9FEK871S:V]M
M;65N=&%R`$YE='-A<&4@8V5R=&EF:6MA='-T>7``3N1T=F5R:P!!;&1R:6<`
M3GEA($MA;&5D;VYI96X`3GD@:V%T96=O<FD`3GET="!M961D96QA;F1E('1I
M;&P@)7,`3GEMY6YE`$YY='0@86YVY&YD87)N86UN("AV86QF<FET="D`3GEA
M(%IE96QA;F0`3GET="!L]G-E;F]R9`!.>71T(&SV<V5N;W)D(&MO;6UE<B!A
M='0@9^4@=70@)7@N`$SV<V5N;W)D(&WE<W1E('9A<F$@<V%M;6$N`$YY='0@
M9O9N<W1E<B`H7V)L86YK*0!.>6AE=&5R`$YY:&5T<V=R=7!P97(`3N1S=&$`
M2V]M;6%N9&4@-"!F87-E<@!.Y'-T82!I;G-TY&QL;FEN9V%R`$[D<W1A/@!.
M:6-A<F%G=6$`3FEG97(`3FEG97)I80!.871T`$YI=64`3F5J`$1E="!F:6YN
M<R!I;F=E="!K;VYF:6=U<F%T:6]N<V1A=&$@871T('9I<V$@<VMI;&QN861E
M<B!F]G(N`$EN9V5N('1I;&QGY&YG;&EG('-T<F%T96=I(&;V<B!A='0@<VMA
M<&$@25-/+6EM86=E+@!);G1E(&5N(&)A=&-H;6%L;"X`1&5T(&9I;FYS(&EN
M9V5T(&)L;V-K('#E(&1E;B!B96?D<F1A('!O<VET:6]N96X`26YG970@:V%L
M96YD97)N86UN(&;V<B!-0T%,(&%U=&5N=&ES97)I;F<@86YG:79E="X`26YG
M96X@Y&YD<FEN9RX`26YG82!U;F1E<F)E:/9R:6=H971E<B!K86X@;.1G9V%S
M('1I;&P@9&5N(&CD<B!B96CV<FEG:&5T96XN`$EN9V5N(&MO;F9I9W5R97)I
M;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@)7,N`$EN9V5N(&MO;F9I9W5R
M97)I;F=S:6YF;W)M871I;VX@86YG:79E;B!F]G(@1E10(%9&4RX`26YG96X@
M:V]N9FEG=7)E<FEN9W-I;F9O<FUA=&EO;B!A;F=I=F5N(&;V<B!344P@5D93
M+@!);F=E;B!K;VYF:6=U<F5R:6YG<VEN9F]R;6%T:6]N(&%N9VEV96X@9O9R
M(%-13"UF:6P@5D93+@!);F=E;B!K<F5D:70@:W9A<BX`0F5S:W)I=FYI;F<@
M<V%K;F%S+@!);F=E;B!M;W1T86=A<F4@86YG:79E;BX`26YG96X@9FEL('5P
M<&QA9&1A9`!);F=A(&EK;VYE<B!H:71T861E<RX`26YG96X@;W)T(&%N9VEV
M96XN`$EN9V5N(&]R="!A;F=I=F5N+@!);F=E="!M961D96QA;F1E(&)I9F]G
M861E<RX`26YG970@;F%M;B!A;F=I=F5T+@!);F=E;B!N=6UM97(@86YG:79E
M="X`26YG82!O9O9R<VOD;61A('9I<VAE='-O<F0`26YG970@;/9S96YO<F0@
M9O9R($A45%`M875T96YT:7-E<FEN9R!A;F=I=F5T+@!);F=E="!L]G-E;F]R
M9"!F]G(@24U!4"UA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T(&SV<V5N
M;W)D(&;V<B!+97)B97)O<RUA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN9V5T
M(&SV<V5N;W)D(&;V<B!,;V=I;BUA=71E;G1I<V5R:6YG(&%N9VEV970N`$EN
M9V5T(&SV<V5N;W)D(&;V<B!005-35T0M875T96YT:7-E<FEN9R!A;F=I=F5T
M+@!);F=E="!L]G-E;F]R9"!F]G(@4TU"+6%U=&5N=&ES97)I;F<@86YG:79E
M="X`26YG82!VY&YT86YD92!R96=I<W1R97)I;F=A<BX`26YG96X@:W9O=&$@
M86YG:79E;@!);F=E;B!K=F]T82!A;F=I=F5N+@!);F=A(')E9VQE<@!);F=E
M;B!A=F=RY&YS87)E(&%N9VEV96XN`$EN9V$@<VED;W(`26YG96X@<^5D86X@
M9FEL`$EN9V5N('1E;7!O<N1R:V%T86QO9R!T:6QL9^1N9VQI9R!F]G(@8V%C
M:&4N`$EN9V5T(&%N=N1N9&%R;F%M;B!O8V@O96QL97(@;/9S96YO<F0@<VMI
M8VMA="X`26YG970@9VEL=&EG(%A-3"UD871A(')E='5R;F5R861E<P!);F=A
M(';D<F1E;@!);F=E;B!V97)S:6]N(&AI='1A9&5S(&D@9&5N('5R<W!R=6YG
M;&EG82!K;VYF:6=U<F%T:6]N96XN(,5T97)S:V%P82!K;VYF:6=U<F%T:6]N
M96XN`$EN9V5N('9E<G-I;VX@:&ET=&%D97,@:2!D:6X@:V]N9FEG=7)A=&EO
M;BX@Q71E<G-K87!A(&MO;F9I9W5R871I;VYE;BX`26-K92UD96QT86=A<F4`
M26YG96X`26YG96X@*&%N=N1N9"!U;F1E<F;V<G-TY61D*0!.;W)F;VQK]F%R
M;F$`3F]R<F$@:&5M:7-FY')E;@!.;W)R82!-87)I86YA]F%R;F$`3F]R9V4`
M26YT92!E9G1E<@!);G1E(&;V<F4`26YT92!E;B!K871A;&]G`$5J(&EM<&QE
M;65N=&5R860N`$5J(&%N9VEV96X`4W3V9',@:6YT92X`06YT96-K;FEN9V%R
M`$EN9V5N=&EN9R!A='0@=FES82P@9^4@=&EL;&)A:V$N`$]"4P!N;W9E;6)E
M<@!.=6UM97(`06YT86P@=&5C:V5N`$%N=&%L(&MO;'5M;F5R`$%N=&%L(')A
M9&5R`$YU;6UE<B!I;G1E('-P96-I9FEC97)A9&4@9O9R(&%T="!U<'!D871E
M<F$@:2!D:7-T<FEB=71I;VYS;&ES=&%N+@!/2P!/8FIE:W0`3V)J96MT<VMA
M<&%R90!/:W1A;`!O:W1O8F5R`$9I;'1E<B!F]G(@;V;V<G-KY&UD:&5T97(`
M2V]N=&]R`$=A;6UA;'0@;V-H(&YY='0@;/9S96YO<F0@9N5R(&EN=&4@=F%R
M82!S86UM82X`1V%M;6%L="!L]G-E;F]R9`!'86UM86QT(&SV<V5N;W)D(.1R
M(&9E;&%K=&EG=`!/;6%N`$1E;&%D92!M87!P87(@<W3V9',@96YB87)T(&%V
M($E-05`M<V5R=G)A<@!%;F)A<G0@;V;V<G-KY&UD82!V:7-H971S;W)D`$5N
M9&%S="!E;B!E+7!O<W1A9')E<W,@=&EL;.5T96XN`$5N9&%S="#D9V%R92!E
M;&QE<B!S>7-T96UA9&UI;FES=')A=/9R(&MA;B#D;F1R82#D9V%R92!E;&QE
M<B!B96CV<FEG:&5T97(@<.4@96X@=71D96QN:6YG`-9P<&YA(&D@;GET="!F
M]FYS=&5R`$]P96Y34TPM9F5L.B!$970@9VEC:R!I;G1E(&%T="!E>'1R86AE
M<F$@9&%T82!F<N5N('-I9VYE<F%D(%,O34E-12UD96PN`-9P<&YA(&SD;FL@
M:2!N>71T(&;V;G-T97(`3W!E<F%T:79S>7-T96T`26-K92!O8FQI9V%T;W)I
M<VMA(&1E;'1A9V%R90!);G-TY&QL;FEN9V%R`$EN<W3D;&QN:6YG87(@9O9R
M("5S`%-O<G1E<F%D(&QI<W1A`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYS
M96YH970`3W)G86YI<V5R80!5<G-P<G5N9VQI9R!A<'!L:6MA=&EO;G-M86QL
M`%5R<W!R=6YG;&EG82!M86QL87(@:2`E<SH`06YN86X`06YD<F$@:6YS=.1L
M;&YI;F=A<@#$9V%R8F5H]G)I9VAE=&5R`%!!32U!=71E;G1I<V5R:6YG(.1R
M(&EN=&4@=&EL;&?D;F=L:6<N`%!%05(Z.DUA:6PM:V]P<&QI;F<`4$=0($1I
M9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!0=6)L:6L@4$=0
M+6YY8VME;`!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"UK;V0`4$A0
M+7-K86P`3.1T="!F]G)M:61D86=S<F5G;@!&]G)M:61D86=S<F5G;@!%9G1E
M<FUI9&1A9W-S:W5R87(`169T97)M:61D86=S<V[V`$5F=&5R;6ED9&%G<W-K
M=7)A<B!M960@<V[V`$5F=&5R;6ED9&%G<W-O;`#%<VMS:W5R87(@<.4@969T
M97)M:61D86=E;@!03U-)6"UT:6QLY&=G('-A:VYA<P!07TA0+7-K86P`571F
M>6QL;F%D.@!086MI<W1A;@!086QA=0!086QE<W1I;F$`4&%N86UA`%!A<'5A
M+4YY82!'=6EN96$`4&%R86=U87D`1&5L=FES(&UO;&YI9W0`3/9S96YO<F0`
M3/9S96YO<F0@Y&YD<F%D97,N`$SV<V5N;W)D(&9E;&%K=&EG=`!,]G-E;F]R
M9"!K<N1V<R!F]G(@4D%$2553(&%U=&5N=&ES97)I;F<N`$SV<V5N;W)D(&UE
M9"!B96MRY&9T96QS90!,]G-E;F]R9#H`3/9S96YO<F0Z(`!,]G-E;F]R9"!M
MY7-T92!V87)A(&QI:V$N`$ML:7-T<F$@:6X`2VQI<W1R82!I;B!F<N5N('5R
M:VQI<'!S:&%N=&5R87)E;@!3]FMVY&<`5N1N=&%N9&4@<F5G:7-T<F5R:6YG
M87(Z`$WD;FYI<VMO<@!0<F]C96YT`%5T9O9R('5N9&5R:.5L;'-F=6YK=&EO
M;F5R`%5T9O9R('5N9&5R:.5L;'-A:W1I=FET971E<B!V:60@:6YL;V=G;FEN
M9S\`0F5H]G)I9VAE=`!"96CV<FEG:&5T("<E<R<@<F%D97)A9&5S(&EN=&4N
M`,5T:V]M<W0@;F5K860`8F5H]G)I9VAE=&5R`$)E:/9R:6=H971S861M:6YI
M<W1R871I;VX`4&5R<V]N;&EG(&EN9F]R;6%T:6]N`%!E<G4`2'5S9&IU<@!&
M:6QI<'!I;F5R;F$`5&5L969O;@!&;W1O;@!0:71C86ER;@!0:7AL87(`2VQI
M8VCI97(`5F%R(&=O9"!K;&EC:V$@:2!E;B!C96QL`$)E:W+D9G1A(&%T="!D
M=2!V:6QL(')A9&5R82!V86QD('!O<W0_`$)E:W+D9G1A(&%T="!D=2!V:6QL
M(')A9&5R82!A:W1U96QL="!E;&5M96YT+@!687(@9V]D(&%N9V4@;>5N860@
M;V-H(.5R+@!687(@9V]D(&%N9V4@;F%M;B!F]G(@:V%T96=O<FEN.@!687(@
M9V]D(&%N9V4@9V]D:^1N9"!)4"UA9')E<W,N`%9A<B!G;V0@86YG92!E='0@
M9VEL=&EG="!D871U;3L@:V]N=')O;&QE<F$@86YT86QE="!D86=A<B!I(&WE
M;F%D96XN`%9A<B!G;V0@86YG92!E;B!G;V1KY&YD('1I9"X`5F%R(&=O9"!S
M=6UM97)A(&1I='0@<')O8FQE;2X`06YG92!D:71T(&%N=N1N9&%R;F%M;B!O
M8V@@;/9S96YO<F0N`%9A<B!G;V0@;.1S(&EG96YO;2!F]FQJ86YD92!T97AT
M+B!$=2!-Q5-412!S86UT>6-K82!M960@=FEL;&MO<F5N(&;V<B!A='0@86YV
MY&YD82!S>7-T96UE="X`5F%R(&=O9"!LY',@:6=E;F]M(&;V;&IA;F1E('1E
M>'0N($1U($W%4U1%('-A;71Y8VMA(&UE9"!V:6QL:V]R96X@9O9R(&%T="!A
M;G;D;F1A('-Y<W1E;65T+@!+;VYT<F]L;&5R82!F]FQJ86YD92!I;F9O<FUA
M=&EO;B!O8V@@=N1L:B!S961A;B!E;B!H86YD;&EN9R!I(&UE;GEN"FYE9&%N
M+@!6Y&QJ(&5N(&AA;F1L:6YG(&9RY6X@;65N>6X@;F5D86XN`$%N9V4@;GET
M="!K871E9V]R:6YA;6XZ`%!O;&5N`%!O;&ET:6L`56YD97)S]FMN:6YG87(`
M4&]R='5G86P`4&]S:71I;VYE<FEN9R!A=B!B:6QD96X`4&]S:71I;VYE<FEN
M9R!A=B!T86)E;&QE;@!3:W)I=B!T:6QL(&1E;B!HY'(@;6%P<&5N("AE:B!T
M=FEN9V%T(&%V($E-05`I`%!O<W1N=6ME`$YE9&5R8O9R9"!D92!S96YA<W1E
M("5S('1I;6UA<FYA.B``0VAA;G,@=&EL;#QB<B\^;F5D97)B]G)D`$%U=&A?
M;&1A<#H@3$1!4"UT:6QLY&=G('-A:VYA<RX`4')E9G-?<V5S<VEO;CH@3V)L
M:6=A=&]R:7-K="!S97-S:6]N<W1I;&SD9V<@:&ET=&%D97,@:6YT92X`5')Y
M8VL`3'5F='1R>6-K('9I9"!H879E=#H@`$QU9G1T<GEC:SH@`$;V<FAA;F1S
M=FES;FEN9P!&]G)H86YD<V=R86YS:V$@8FEL9"!I(&YY='0@9O9N<W1E<@!&
M]G)E9^5E;F1E(&EN<W3D;&QN:6YG87(`4VMR:78@=70@9&]K=6UE;G0`4')I
M=F%T82!N>6-K96P`4')O8FQE;0!0<F]B;&5M8F5S:W)I=FYI;F<`4')O:F5K
M=`!497AT`%!U8FQI:R!N>6-K96P`4'5B;&EK(&YY8VME;&%L9V]R:71M`%!U
M8FQI:R!N>6-K96QI;F9O<FUA=&EO;@!&96P@=FED(&=E;F5R97)I;F<@878@
M<'5B;&EK="]P<FEV870@;GEC:V5L<&%R+@!0=65R=&\@4FEC;P!296YS82!M
M961D96QA;F1E;@!1871A<@!&<N5G80!+=F]T80!0=6)L:6L@4E-!+6YY8VME
M;"`H)60@8FET87(I`$5N<VMI;'0@=F%L`%)E9VX`5&ED:6=T(')E9VX`4V5N
M="!R96=N`%)E9VYS:W5R87(`4F5G;B!O8V@@<V[V`%)E9VX@=&EL;"!S;O8`
M4VQU;7!MY'-S:6=T('9I<VAE='-O<F0`1O9R:.5L;&%N9&4`3.1S`$SD<R!M
M961D96QA;F1E;@!3Y&ME<G0@871T(&1U('9I;&P@<F%D97)A("5S/R!2861E
M<FEN9V5N(&MA;B!I;G1E(.5N9W)A<RX`4^1K97)T(&%T="!D=2!V:6QL(')A
M9&5R82!A;G;D;F1A<F1A=&$@9O9R("5S/R!2861E<FEN9V5N(&MA;B!I;G1E
M(.5N9W)A<RX`1_9R(&]M(&1I;B!S96YA<W1E(&EN;6%T;FEN9P!5<'!D871E
M<F$`57!P9&%T97)A(&1Y;F%M:7-K82!M96YY96QE;65N=#H`57!P9&%T97)A
M('!O<G1A;'9Y.@!296=E>`!6:7-A(&;V<FCE;&QA;F1E;@!,861D82!O;0!+
M;VUM96YT87)E<@!+;VT@:6CE9R!I;F9O<FUA=&EO;B!O;2!L961I9R]U<'!T
M86=E;BX`1FKD<G)S97)V<F%R`%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%1A(&)O<G0`5&$@8F]R="!B;&]C:P!482!B;W)T(&MO;'5M
M;@!482!B;W)T(&9O<FUA=&5R:6YG`%1A(&)O<G0@9G+E;B!M:6X@:V%L96YD
M97(`5&$@8F]R="!P87(`4F%D97)A('-P87)A="!S:W)I<'0@9G+E;B!S97)V
M97)N<R!T96UP;W+D<FMA=&%L;V<N`%1A(&)O<G0`4F%D97)A(&1E;FYA(&YO
M9"!F<N5N(&1O:W5M96YT970`5&$@8F]R="!A;G;D;F1A<F4`5&$@8F]R="!A
M;G;D;F1A<F4Z("5S`%-V87(@<VMI8VMA="X`4W9A<F$@871T(&)E9^1R86X@
M:6YT92!S=/9D<P!3=F%R82!M960@:6YF;W)M871I;VX@;VT@;&5D:6<O=7!P
M=&%G96X@9O9R(&MO;6UA;F1E('1VY2!MY6YA9&5R+@!3=F%R82!M960@9&5N
M(&)E9^1R9&$@;&5D:6<O=7!P=&%G96XM:6YF;W)M871I;VYE;BX`4W9A<CH@
M)7,`0F5GY')A;B!K=6YD92!I;G1E(&)E<W9A<F%S+B!2971U<FYE<F%D(&9E
M;&MO9#H@`$1E;B!E9G1E<F9RY6=A9&4@=&KD;G-T96X@:W5N9&4@:6YT92!H
M:71T87,N`$5R9F]D<F%D("<E<R<@Y'(@:6YT92!A;F=I=F5N(&D@:V]N9FEG
M=7)A=&EO;F5N(&%V("5S+@!%<F9O9')A9"`G)7,G(.1R(&EN=&4@86YG:79E
M;B!I(&MO;F9I9W5R97)I;F=E;B!A=B!61E,N`$5R9F]D<F%D("<E<R<@Y'(@
M:6YT92!A;F=I=F5N(&D@:V]N9FEG=7)E<FEN9V5N+@!/8FQI9V%T;W)I<VMT
M="!FY&QT`$]B;&EG871O<FES:R!D96QT86=A<F4`Q71E<G-TY&QL`,5T97)S
M=.1L;"!L]G-E;F]R9`#%=&5R<W3D;&P@;/9S96YO<F0`Q7-T97)TY&QL('-E
M;F%S=&4@9G+E9V%N`%)E<W5L=&%T`,5T97)VY&YD('1I;&P@:6YS=.1L;&YI
M;F=A<@!!;F=E(&YY='0@;/9S96YO<F0`4NEU;FEO;@#%=&5R<W3D;&P@:V]N
M9FEG=7)A=&EO;@!);G-TY&QL;FEN9V%R(&;V<B!2:6-H(%1E>'0@161I=&]R
M`$?E=&]R`$CV9V5R`$CV9V5R<G5B<FEK`$CV9V5R=N1R9&5N`%)A7V1I;G-T
MY&QL;FEN9V%R+BXN`%)O;&P`4G5MY&YI96X`4F]T97)A(#$X,`!2;W1E<F$@
M=N1N<W1E<@!2;W1E<F$@:/9G97(`4F%D:6YS=.1L;&YI;F=A<@!2861I;G-T
MY&QL;FEN9V%R`%)A9&5R.@!,:6YJ97(`3&EN:F5R('9I<V%S(&UE;&QA;B!A
M;&QA(')A9&5R(&]C:"!K;VQU;6YE<@!,:6YJ97(@=FES87,@96YB87)T(&UE
M;&QA;B!K;VQU;6YE<@!,:6YJ97(@=FES87,@96YB87)T(&UE;&QA;B!R861E
M<@!+]G(`4GES<VQA;F0`4G=A;F1A`%,O34E-12!S:6=N871U<@!3+TU)344M
M:W)Y<'1E<F%T(&UE9&1E;&%N9&4`4T%33"UA=71E;G1I<V5R:6YG(.1R(&EN
M=&4@=&EL;&?D;F=L:6<N`%--4R!M961D96QA;F1E;@!344PM<VMA;`!344PM
M<V5K=F5N<R!F]G(@=7!P<VQA9R!A=B!VY')D96X`4U-(`$Q90TM!5`!37U%,
M+7-K86P`3/8`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&]C:"!.979I<P!3
M86EN="!,=6-I80!386EN="U0:65R<F4@;V-H($UI<75E;&]N`%-A:6YT(%9I
M;F-E;G0@;V-H($=R96YA9&EN97)N80!386UM82!R86T@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-A;R!4;VUE(&]C:"!0<FEN8VEP90!3871T96QI=&QE
M=F5R86YT]G(`4V%U9&EA<F%B:65N`%-P87)A`%-P87)A("<E<R<`4W!A<F$@
M)7,`4W!A<F$@:6YS=.1L;&YI;F=A<@!3<&%R82!G96YE<F5R860@:V]N9FEG
M=7)A=&EO;B!S;VT@4$A0+7-K<FEP="!T:6QL(&1I;B!S97)V97)S("!T96UP
M+6MA=&%L;V<N`%-P87)A9&4@:V]N9FEG=7)A=&EO;B!F]G(@)7,N`%-P87)A
M9&4@=7!P9W)A9&5R:6YG<W-C<FEP="!T:6QL.B`E<RX`4W!R:61D82#E<VMS
M:W5R87(`5F5T96YS:V%P`%/V:P!3]FMM;W1O<F5R`%;D;&H@9FEL97(`5N1L
M:B!E='0@9&%T=6T`5N1L:B!G<G5P<"!A='0@;.1G9V$@=&EL;`!6Y&QJ(&YY
M(.1G87)E`%;D;&H@<V5R=F5R`%;D;&H@86YVY&YD87)E(&%T="!LY&=G82!T
M:6QL`%;D;&H@86QL80!6Y&QJ(&1A='5M:V]M<&]N96YT97(N`%;D;&H@971T
M(&]B:F5K=`!6Y&QJ(&EN9V5N`$%N9V4@9&4@=&5C:V5N(&1U(&)E:/9V97(@
M:2!R=71O<FYA(&YE9&%N+B!$=2!K86X@<V5D86X@:V]P:65R82!O8V@@:VQI
M<W1R82!I;B!D96T@:2!T97AT87)U=&%N+@!6Y&QJ(&%V9W+D;G-A<F4@9O9R
M(&1A='5M.@!6Y&QJ(&1A='5M9F]R;6%T.@!6Y&QJ(&ED96YT:71E="!D=2!V
M:6QL(.1N9')A.@!6Y&QJ(&%V9W+D;G-A<F4@9O9R('1I9#H`5N1L:B!T:61S
M9F]R;6%T.@!6Y&QJ('1VY2!M871C:&%N9&4@9N1L=#H`5N1L:B!D:71T(&;D
M<F=S8VAE;6$N`$%N9V4@9&ET="!F]G)V86QD82!S<'+E:SH`4VMI8VMA('-E
M;F%S=&4@:6YF;W)M871I;VYE;@!3:VEC:V$@<')O8FQE;7)A<'!O<G0`4VMI
M8VMA(%--4P!396YE9V%L`%-E;G-O<CH@`'-E<'1E;6)E<@!397)B:65N(&]C
M:"!-;VYT96YE9W)O`%-E<FEE;G5M;65R`%-E<G9E<FEN<W3D;&QN:6YG87(@
M9F5L86MT:6=A(&5L;&5R(&EN86MT:78@<V5R=F5R+@!397-S:6]N<V%D;6EN
M:7-T<F%T:6]N`%-E<W-I;VYS+4E$(&AA<B!GY71T('5T+@!397-S:6]N97(`
M4^1T=`!+;VYF:6=U<F5R82!A;'1E<FYA=&EV('-O;2!M]FIL:6=G]G(@Y71E
M<G-TY&QL;FEN9R!A=B!B;W)T9VSV;70@;/9S96YO<F0N`$MO;F9I9W5R97)A
M(&9JY')R<V5R=G)A<B!S;VT@9'4@=FEL;"!K;VUM82#E="!F<N5N(&1I;B!P
M;W)T86PN`$%N9V4@9&ET="!F]G)V86QD82!S<'+E:RP@=&ED<WIO;B!C;V@@
M9&%T=6UI;G-TY&QL;FEN9V%R+@!3Y'1T(&1I='0@:6YI=&EA;&$@87!P;&EK
M871I;VXL(&;D<F=S8VAE;6$L('-I9'5P<&1A=&5R:6YG(&]C:"!A;F1R82!V
M:7-N:6YG<VEN<W3D;&QN:6YG87(N`%-E='5P`$MO;F9I9W5R871I;VYS=7!P
M9W)A9&5R:6YG<W-K<FEP="!F:6YN<R!T:6QL9^1N9VQI9V$`1&5T(&9I;FYS
M(&9L97)A(&]R=&5R(&UE9"!P87)A;65T97)N.@!397EC:&5L;&5R;F$`2&%N
M9&5L`$MO<G0@<W5M;65R:6YG`%-K86QL(&=E;G;D9W-T86YG96YT97(@9&5F
M:6YE<F%S(&;V<B!D92!F;&5S=&$@;.1N:V%R/P!6:7-A`%9I<V$@<VMI;&QN
M861E<B!M96QL86X@9&5N(&%K='5E;&QA(&]C:"!D96X@;GEL:6=E;B!S:V%P
M861E(&MO;F9I9W5R871I;VYE;BX`5FES82!S96YA<W1E(&EN;&]G9VYI;F=S
M=&ED('9I9"!I;FQO9V=N:6YG/P!6:7-A(&EN<W3D;&QN:6YG(&;V<B!A='0@
M8F5HY6QL82!O<FEG:6YA;`!6:7-A('!A;&5T=`!6:7-A("=T86)E;&QA:W1I
M=FET971E<B<@:2!M96YY;C\`5FES82!M96YY(&;V<B`E<R!T:6QL(';D;G-T
M97(_`%1A8F5L;&-E;&QI;G-TY&QL;FEN9V%R`%1A8F5L;&EN<W3D;&QN:6YG
M87(`5&%B96QL:6YS=.1L;&YI;F=A<@!6:7-A(&1I86QO9W)U=&$@9O9R(&)I
M;&1E9V5N<VMA<&5R`%9I<V$@=7!P;&%D9&YI;F<`4VMU<F%R`%1I9&EG82!S
M:W5R87(`4V5N82!S:W5R87(`4VMU<F%R(&D@;N1R:&5T96X`1O9R;6EN<VMA
M`$MR>6UP(&5L;&5R(&9L>71T82!B;W)T(&[D<FQI9V=A;F1E(&)L;V-K(&;V
M<G-T`%-I97)R82!,96]N90!296=I<W1R97)A`%-I9VYA='5R`%-I9VYA='5R
M86QG;W)I=&T`4VEM<&QE>`!3:6YG87!O<F4`4W1O<FQE:P!!=F)R>70@=6YD
M97)HY6QL`%-L;W9A:VEE;@!3;&]V96YI96X`4V[V`%-N]G-K=7(`4V[V<VMU
M<F%R`%1I9&EG82!S;O9S:W5R87(`4V5N82!S;O9S:W5R87(`4V[V9&IU<#H@
M`$UO='-V87)A;F1E('-N]B!I('9A='1E;CH@`%-A;&]M;V[V87)N80!3;VUA
M;&EA`%/E;F=E<B!O8V@@9&EK=&5R`%-O<G1E<FEN9W-I;W)D;FEN9W-V86P`
M:^1L;&%D<F5S<P!3>61A9G)I:V$`4_9D<F$@1V5O<F=I82!O8V@@4WES<V%N
M9'=I8VCV87)N80!3Y&1R82!H96UI<V;D<F5N`%5T<GEM;64@;65L;&%N(&EN
M=&EL;&EG9V%N9&4@8V5L;&5R`%5T<GEM;64@;65L;&%N(&EN;F5HY6QL(&]C
M:"!K86YT96X@:2!C96QL96X`365L;&%N<G5M`$UE;&QA;G)U;0!-96QL86YR
M=6T@;V-H('5T:N1M;FEN9P!3<&%N:65N`%-P86T`26YM871N:6YG(&%V('-P
M96-I96QL82!T96-K96X`1&5L82!C96QL`$1E;&$@:V]L=6UN`$1E;&$@<F%D
M`%-P;W)T97(`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R=`!3
M=&%R=.5R`%-T870@96QL97(@<F5G:6]N`%-T871U<P!,86=R:6YG<V9O<FUA
M=`!'871U861R97-S`$=E;F]M<W1R=6ME;@!3='+D;F=L:7-T80!482!B;W)T
M(&1O;>1N(&9RY6X@861R97-S96X`4W1I;"!;0U-370!3]@!+86X@:6YT92!H
M:71T82!U;F1E<FMA=&%L;V<@)R5S)RX`Q')E;F1E`%-K:6-K80!$:6X@8F5G
MY')A;B!A='0@;.1G9V$@=&EL;"`B)7,B('1I;&P@<WES=&5M970@:&%R('-K
M:6-K871S+B!$=2!K86X@:6YT92!L;V=G82!I;B!I;FYA;B!D:6X@8F5GY')A
M;B!H87(@86-C97!T97)A=',N`$YE9'/D;FMT`$QY8VMA=``G)7,G(&QA9&5S
M('1I;&P@:2!S>7-T96UE="X`4F%D97)A9&4@:6YF;W)M871I;VX@;VT@86YV
MY&YD87)E("<E<R<N`"<E<R<@<F%D97)A9&5S+@`G)7,G('1O9W,@8F]R="!F
M<N5N('-Y<W1E;65T+@!+;VYF:6=U<F%T:6]N96X@:&%R(.5T97)S=.1L;'1S
M+B!,861D82!O;2!S:61A;B!F]G(@871T('-E(&;V<N1N9')I;F=A<BX`4W!A
M<F%D92!B86-K=7!K;VYF:6=U<F%T:6]N+@!3<&%R861E(&)A8VMU<&MO;F9I
M9W5R871I;VX@)7,N`"<E<R<@=7!P9&%T97)A9&5S+@!3:W)E=B`E<P!3=61A
M;@!386UM86YS=.1L;&YI;F<`4V]L=7!P9^5N9P!3;VQN961GY6YG`%-O;&EG
M=`!3;VQU<'!GY6YG`%-O;'5P<&?E;F<O;F5D9^5N9P!3;VQU<'!GY6YG.B``
M4V]L;F5D9^5N9P!3;VQN961GY6YG.B``57!P:/9J9`!3=7!P;W)T`%-U<FEN
M86UE`$5F=&5R;F%M;@!3=F%L8F%R9"!O8V@@2F%N($UA>65N`%-W87II;&%N
M9`!3=F5R:6=E`%-C:'=E:7H`4WEK<F]N:7-E<FEN9W-L;V=G(')A9&5R860`
M4WEN8TU,`%-Y;G1A>&9E;"!I('/V:VMR:71E<FEA`%-Y<FEE;@#%<VMS:W5R
M`,5S:W-K=7)A<B!O8V@@8FSE<VEG=`#%<VMS:W5R87(`5&ED:6=A(.5S:W-K
M=7)A<@!44U8M9FEL`%1A8F5L;`!486)E;&QI;G-TY&QL;FEN9V%R`%1A8F5L
M;'5P<'/D='1N:6YG`%1A8F5L;&EN<W3D;&QN:6YG87(`5&%I=V%N`%1A:7=A
M;@!486II:VES=&%N`%1A;GIA;FEA`$WE;#H`57!P9VEF=&5R`%1E86P`5&5L
M969O;FYU;6UE<@!(]F=S=&$@=&5M<&5R871U<B!S96YA<W1E('1I;6UE;CH@
M`%1E;7!E<F%T=7(`5&5M<&5R871U<CH@`%1E;7!E<F%T=7(\8G(@+SXH)7--
M87@E<R\E<TUI;B5S*2`F9&5G.R5S`$MA;B!I;G1E(&AI='1A(&UA;&P@)7,N
M`$%N=N1N9&%R861M:6YI<W1R871I;VX`1V]D:^1N;B!B96?D<F%N('!R96QI
M;6ENY')T`%!R96QI;6ENY')T(&%C8V5P=&5R870`5&5X=`!%;F)A<G0@=&5X
M=`!497AT:G5S=&5R:6YG`%1E>'1T;W``5&\`5&AA:2`H5$E3+38R,"D`5&AA
M:6QA;F0`5&%C:R!F]G(@871T(&1U(&%N=N1N9&5R('-Y<W1E;65T+@!,Y&YK
M96X@)7,@=&EL;"`E<R!H87(@<F%D97)A=',N`$944"UT:6QLY&=G970@Y'(@
M:6YT92!T:6QL9^1N9VQI9W0N`$AI<W1O<FEK<WES=&5M970@Y'(@879A:W1I
M=F5R870N`$AO<F1E+TMO;&%B+6EN=&5G<F%T:6]N<V=RY&YS<VYI='1E="!S
M=/9D97(@:6YT92`B)7,B`$E-4U`M;&]G9V5N(&MU;F1E(&EN=&4@:6YI=&EE
M<F%S+@!+;&%S<V5N($UA:6YT96YA;F-E.CH@:W5N9&4@:6YT92!L861D87,`
M26YS=.1L;&YI;F=S9O9N<W1R970@:&%R('-TY&YG=',N($%V<VQU=&%R+@!!
M9&UI;FES=')A=/9R96X@;>5S=&4@:V]N9FEG=7)E<F$@96X@<&5R;6%N96YT
M($)E:/9R:6=H971S+6MO<'!L:6YG(&]M(&1U('9I;&P@86YVY&YD82!"96CV
M<FEG:&5T97(N`$5N8F%R="!N961R92!S:61A;@!+86QE;F1E<FEN9F]R;6%T
M:6]N96X@Y'(@9F5L86MT:6<`2V]N=&%K=&5N<R!)1"!A;F=A=G,@:6YT92!E
M;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B87-E;BX`2V]N=&%K=&5N
M(&QA9&5S('1I;&P@:2!A9')E<W-B;VME;BX`1&5N(&SV<V=J;W)D82!01U`M
M<VEG;F%T=7)E;B!K<N1V<R!F]G(@871T('9E<FEF:65R82!D970@<VEG;F5R
M861E(&UE9&1E;&%N9&5T+@!$:7-T<FEB=71I;VYS;&ES=&%N<R!)1"!A;F=A
M=G,@:6YT92!E;&QE<B!K=6YD92!I;G1E(&AI='1A<R!I(&1A=&%B87-E;BX`
M1&ES=')I8G5T:6]N<VQI<W1A;B!H87(@:6YT92!A;F=I=FET<RX`2W)Y<'1E
M<FEN9W-F=6YK=&EO;F5R;F$@:W+D=F5R(&5N('/D:V5R('=E8F;V<F)I;F1E
M;'-E("A(5%104RDN`$CD;F1E;'-E;B!L861E<R!T:6QL(&D@:V%L96YD97)N
M+@!&:6QE;B`E<R!S:V%L;"!I;FYE:.5L;&$@96X@:6YS=.1L;&YI;F<@9O9R
M("5S+@!&:6QE;B`E<R!S:V%L;"!I;FYE:.5L;&$@:6YS=.1L;&YI;F=A<B!F
M]G(@)7,N`$9I;&5N(&MA;B!I;G1E(&MO<&EE<F%S('1I;&P@<VEG('-JY&QV
M+@!&:6QE;B!K86X@:6YT92!K;W!I97)A<R!T:6QL('-I9R!S:N1L=BX`1FEL
M96X@:6YN96CV;&P@:6YG96X@:6YF;W)M871I;VXN`$AU=G5D9N1L="!F]G(@
M9&5T=&$@;65D9&5L86YD92]R9F,X,C)M961D96QA;F1E(&;V;&IE<@!)9&5N
M=&ET971E;B`G)7,G(')A9&5R861E<RX`0F%R82!VY&YS=&5R('-I9&$`3.1N
M:V5N(&AA<B!T86=I=',@8F]R=`!3]FMVY&=E;B!T:6QL($=N=5!'+7!R;V=R
M86UM970@;>5S=&4@=F%R82!A;F=I=F5N('1I;&P@:VQA<W-E;B!#<GEP=%]P
M9W`Z.BX`365D9&5L86YD970@<VMI8VMA="`E<R!T:6QL("5S(&UE9"#D<F5N
M9&4@(B5S(B!H87(@=FES871S+@I$971T82#D<B!I;F=E;B!G87)A;G1I(&;V
M<B!A='0@;65D9&5L86YD970@:&%R(&SD<W1S+@!.86UN970@<V]M('-K86QL
M(&%N=N1N9&%S(&;V<B!A='0@;.1N:V$@=&EL;"!S:V%P82US:61A;@!!;G1A
M;"!FY&QT(&WE<W1E('9A<F$@971T(&YU;65R:7-K="!VY')D92X`36]D=6QE
M;B!O<&5N<W-L(&MRY'9S(&%V(&ML87-S96X@2&]R9&5?0W)Y<'1?<VUI;64Z
M.BX`26YS=.1L;&YI;F=E;B`B)7,B(&MU;F1E(&EN=&4@<W!A<F%S('#E(&=R
M=6YD(&%V(&%T="!D871A;>1N9V1E;B#V=F5R<VMR:79E<B!D96X@;6%X:6UA
M;'0@=&EL;.5T;F$`4')O9W)A;6UE="!S;VT@86YVY&YD<R!F]G(@871T('9I
M<V$@9&5N(&CD<B!M961D96QA;F1E='EP96X@*"5S*2!S86MN87,@<.4@<WES
M=&5M970N`%1E8VMN970@9O9R(&-I=&5R:6YG(&WE<W1E('9A<F$@971T('1E
M8VME;BX`0F%R82!H]F=E<B!O8V@@=N1N<W1E<B!S:61O<@!"87)A(&CV9V5R
M('-I9&$`4V5P87)A=&]R;B!MY7-T92!V87)A(&5T="!T96-K96XN`%-E<G9E
M<B`G)7,G(')A9&5R861E<RX`4V5R=F5R("<E<R<@<W!A<F%D97,N`%!R96YU
M;65R871I;VYS8F5GY')A;B!F]G(@)7,@:&%R('1A9VET<R!B;W)T+@!!;F=I
M=F5N(')A9"`H)60I(&9I;FYS(&EN=&4N`$%N9VEV96X@<F%D(&5X:7-T97)A
M<B!I;G1E+@!5<'!G:69T96X@:&%R(&QA9W1S('1I;&P@:2!D:6X@=7!P9VEF
M='-L:7-T82X`5&5M<&]RY'(@9FEL("<E<R<@9FEN;G,@:6YT92X`5&5X=&5N
M(&1U(&UA=&%T(&EN('-TY&UM97(@:6YT92#V=F5R96YS(&UE9"!T97AT96X@
M<.4@<VOD<FUE;@!"87)A('1O<'`@;V-H(&)O='1E;B!S:61A`$)A<F$@=&]P
M<'-I9&$`57!P;&%D9&%T(&1A=&$@9O9R<W9A;FX@<V5D86X@9O9R96?E96YD
M92!S=&5G+@!$96X@=7!P;&%D9&%D92!F:6QE;B!K=6YD92!I;G1E('-P87)A
M<RX`3&5D:6<O=7!P=&%G96XM:6YF;W)M871I;VX@9O9R(&%N=N1N9&%R96X@
M:&%R('-P87)A=',N`%=E871H97(N8V]M+6)L;V-K970@Y'(@:6YT92!T:6QL
M9^1N9VQI9W0N`%1E;6%K871A;&]G("<E<R<@9FEN;G,@:6YT92X`26YG82!I
M;G-TY&QL;FEN9V%R('1I;&QGY&YG;&EG82X`1&5T(&9I;FYS(&EN9V$@86QT
M97)N871I=F$@9&5L87(@<V]M(&MA;B!V:7-A<R!I;FQI;F4N`$;V<B!MY6YG
M82!T96-K96X@:2!FY&QT970N($1U(&AA<B!A;F=E='0@)7,@=&5C:V5N.R!M
M87AI;6%L="!A;G1A;"!T96-K96X@Y'(@)7,N`%!R;V)L96T@;65D(&%T="!L
MY&=G82!T:6QL("<E<R<@=&EL;"!S>7-T96UE=#H@)7,`4')O8FQE;2!M960@
M871T(')E;G-A(&EN9F]R;6%T:6]N(&]M(&%N=N1N9&%R92`G)7,G(&9RY6X@
M<WES=&5M970Z(`!0<F]B;&5M(&UE9"!A='0@=&$@8F]R="`G)7,G(&9RY6X@
M<WES=&5M970Z(`!0<F]B;&5M('9I9"!U<'!D871E<FEN9R!A=B`G)7,G.B`E
M<P!0<F]B;&5M('9I9"!U<'!L861D;FEN9R!A=B!F:6QE;BX@26YG82`E<R!L
M861D861E<R!U<'`N`$1E="!U<'!S=&]D('!R;V)L96T@=FED('5P<&QA9&1N
M:6YG(&%V(&9I;&5N.B`E<R#D<B!S=/9R<F4@Y&X@;6%X:6UA;'0@=&EL;.5T
M96X@<W1O<FQE:R`H)60@8GET97,I+@!$970@=7!P<W1O9"!P<F]B;&5M('9I
M9"!U<'!L861D;FEN9R!A=B!F:6QE;CH@)7,@;&%D9&%D97,@96YB87)T('5P
M<"!D96QV:7,N`$1E="!U<'!S=&]D(&5T="!F96P@=FED('9I<VYI;F<@878@
M;65D9&5L86YD961E;&5N+@!&96P@=FED(&EM<&]R="!A=B!K;VYT86MT9&%T
M82X`1F5L('9I9"!I;7!O<G0@878@:.1N9&5L<V5N.B`E<RX`1F5L('9I9"!I
M;7!O<G0@878@:4-A;&5N9&%R(&1A=&$N`$9E;"!V:60@:6UP;W)T(&%V('5P
M<&=I9G1E;CH@)7,N`$9E;"!V:60@:6UP;W)T(&%V(&EN9F]R;6%T:6]N(&]M
M(&QE9&EG+W5P<'1A9V5N.B`E<RX`171T(&9E;"!PY71RY&9F861E<R!I(&9O
M<FUU;.1R970N($MO;G1R;VQL97)A(&%T="!D=2!I;G1E(&=L]FUT(&9Y;&QA
M(&D@971T(&]B;&EG871O<FES:W0@9N1L="X`1&5T(&=I8VL@:6YT92!A='0@
M=71F]G)A(&1E;B!B96?D<F1A(&%D<F5S<V)O:W-F=6YK=&EO;F5N+B!687(@
M9V]D(&;V<G/V:R!S96YA<F4N`$9E;"!V:60@=7!P9&%T97)I;F<@878@:V]N
M=&%K='5P<&=I9G1E<BX@1O9R<_9K(&EG96X@<V5N87)E+@!&96P@=FED('5P
M<&1A=&5R:6YG(&%V(&1I<W1R:6)U=&EO;G-L:7-T86XN($;V<G/V:R!I9V5N
M('-E;F%R92X`1&EN($E-05`M<V5R=F5R('-T]F1E<B!I;G1E(&1E;&%D92!M
M87!P87(N`$1E;FYA(&AA;F1L:6YG('-T]F1S(&EN=&4N`$1E;FYA(&9U;FMT
M:6]N(.1R(&EN=&4@:6UP;&5M96YT97)A9"#D;BX`1FEL96X@=F5R:V%R(&EN
M=&4@=F%R82!E='0@9VEL=&EG="!205(M87)K:78N`$9I;&5N('9E<FMA<B!I
M;G1E('9A<F$@971T(&=I;'1I9W0@6DE0+6%R:VEV+@!&96QA:W1I9W0@:V]R
M=&YU;6UE<BX`1&5N;F$@9')I=G)U=&EN(&?V<B!D970@;?9J;&EG="!A='0@
M<VMI8VMA(&UE9&1E;&%N9&5N('9I82!#;&EC:V%T96QL+6)R>6=G86X@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@9V5N;VT@871T(&%N=N1N9&$@2%144"!!
M4$DZ="X`1&5N;F$@9')I=G)U=&EN(&?V<B!D970@;?9J;&EG="!A='0@<VMI
M8VMA(&UE9&1E;&%N9&5N('9I82!724XM8G)Y9V=A;B`H:'1T<#HO+W=I;G!L
M8RYC;VTI(&=E;F]M(&%T="!A;G;D;F1A($A45%`@05!).G0`1&5N;F$@9')I
M=G)U=&EN(&?V<B!D970@;?9J;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N
M('9I82!S;7,R96UA:6PM8G)Y9V=A;B`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI
M(&=E;F]M(&%T="!A;G;D;F1A($A45%`@05!).G0`1&5N;F$@9')I=G)U=&EN
M(&?V<B!D970@;?9J;&EG="!A='0@<VMI8VMA(&UE9&1E;&%N9&5N('9I82!3
M3510(&=E;F]M(%9O9&%F;VYE($ET86QI96XM8G)Y9V=A;B`H96YB87)T('1I
M;&P@5F]D869O;FYU;6UE<BDN($1R:79R=71I;F5N(&MRY'9E<B!E='0@92UP
M;W-T:V]N=&\@:&]S(%9O9&%F;VYE($ET86QI96X@*&AT='`Z+R]W=W<N,3DP
M+FET*2X`1N1L=&5T(&WE<W1E('9A<F$@:69Y;&QT+@!&Y&QT970@9N5R(&5N
M8F%R="!I;FYE:.5L;&$@:&5L=&%L+@!&Y&QT970@9N5R(&5N8F%R="!I;FYE
M:.5L;&$@<VEF9G)O<B!O8V@@:V]L;VXN`$;D;'1E="!FY7(@96YB87)T(&EN
M;F5HY6QL82!O:W1A;&$@=&%L+@!&Y&QT970@<VMA;&P@=F%R82!E;B!K;VUM
M82T@96QL97(@;65L;&%N<VQA9W-S97!A<F%R860@;&ES=&$@;65D(&AE;'1A
M;`!&Y&QT970@;>5S=&4@=F%R82!E='0@9V]D:^1N="!T86PN`$1E='1A(&;D
M;'0@;>5S=&4@:6YN96CE;&QA(&5N(%)'0BUFY')G:V]D(&D@:&5X861E8VEM
M86QT(&9O<FUA="P@="!E>"`G(S$R,S1A9B<N`$1E='1A(&9O<FUU;.1R(&AA
M<B!R961A;B!B96%R8F5T871S+@!$970@:.1R(.1R("5S+@!-961D96QA;F1E
M="!S:W)E=G,@:2!E;B!A;FYA;B!T96-K96YU<'!SY'1T;FEN9R`H)7,I(.1N
M(&1I;B!E9V5N+@!$970@:.1R(&YU;7)E="!MY7-T92!V87)A(&UI;G-T(&5T
M="X`4V5R=F5R;B!K86X@:6YT92!P86-K82!U<'`@>FEP(&]C:"!G>FEP(&9I
M;&5R+@!3>7-T96UE="#D<B!F]G(@=&EL;&;D;&QE="!A=F%K=&EV97)A="X`
M1&5T(&CD<B!VY')D970@;>5S=&4@=F%R82!N=6UE<FES:W0N`$1E='1A(&;V
M;G-T97(@;>5S=&4@86YR;W!A<R!F<N5N(&5T="!K;VYF:6=U<F%T:6]N<V;V
M;G-T97(`Q7-K80#$<F5N9&5N`%1I9`!4:61S<F5D;W9I<VYI;F<`5&ED<V9O
M<FUA=`!4:61S=F%L`-9S='1I;6]R`%)U8G)I:P!2=6)R:6L@*'1O;VQT:7`I
M.@!4:6QL`$;V<B!A='0@;6%R:V5R82!F;&5R82!V86PL(&CE;&P@;F5D($-T
M<FP@*%!#*2!E;&QE<B!#;VUM86YD("A-86,I('1A;F=E;G1E;B!NY'(@9'4@
M:VQI8VMA<BX`261A9P!6:7-A($A434PM:^1L;&$`5&]G;P!4;VME;&%U`$EM
M;W)G;VX`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`UG9E<G/D='1N:6YG
M87(`5')I;FED860@;V-H(%1O8F%G;P!386YT(&5L;&5R(&9A;'-K=`!4:0!4
M=6YI<VEE;@!4=7)K:65T`%1U<FMI<VL@*$E33RTX.#4Y+3DI`%1U<FMM96YI
M<W1A;@!4=7)K<RT@;V-H($-A:6-O<_9A<FYA`%1U=F%L=0!!;F=E(&1I='0@
M=F%L.B``558M:6YD97@Z(`!54DP`55),(&;V<B!D:71T(&QE=F5R86YS<F%P
M<&]R=&5R:6YG<W-K<FEP=`!54DPZ`%5G86YD80!5:W)A:6YA`$MA;B!I;G1E
M(&SD<V$@5D93+6UA<'`N`$1E="!G:6-K(&EN=&4@871T(&SD9V=A('1I;&P@
M=73V:V%D(&%N=N1N9&%R:6YF;W)M871I;VX@=FED(')E9VES=&5R:6YG+@!+
M86X@:6YT92#D;F1R82!B96CV<FEG:&5T(&;V<B!61E,M9FEL("5S+@!+86X@
M:6YT92#D;F1R82!B96CV<FEG:&5T(&;V<B!61E,M9FEL("5S+R5S+@!+86X@
M:6YT92#D;F1R82!T:6QL("5S+@!+86X@:6YT92!K;VYT<F]L;&5R82!F:6QS
M=&]R;&5K("5S+R5S`$MA;B!I;G1E(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@
M<.4@)7,N`$MA;B!I;G1E(&MO;G1R;VQL97)A(&9I;'-T;W)L96L@<.4@)7,O
M)7,N`$MA;B!I;G1E(&MO;G1A:W1A(%-13"US97)V97(N`$MA;B!I;G1E(&MO
M;G1A:W1A('9I82!34TPN`$MA;B!I;G1E(&MO<&EE<F$@5D93+69I;"X`2V%N
M(&EN=&4@<VMA<&$@5D93+6UA<'`@)7,N`$MA;B!I;G1E('-K87!A(%9&4RUM
M87!P+@!+86X@:6YT92!S:V%P82!61E,M9FEL+@!+86X@:6YT92!S:V%P82!6
M1E,M;6%P<"`G)7,G+@!+86X@:6YT92!S:V%P82!T;VT@5D93+69I;"X`2V%N
M(&EN=&4@<&%C:V$@=7!P(&1A=&$N`$MA;B!I;G1E(')A9&5R82`E<RP@;6%P
M<&5N(.1R(&EN=&4@=&]M+@!+86X@:6YT92!R861E<F$@)R5S)SH@)7,`2V%N
M(&EN=&4@<F%D97)A("5S+"!M87!P96X@Y'(@:6YT92!T;VTN`$MA;B!I;G1E
M(')A9&5R82!61E,M;6%P<"!R96MU<G-I=G0N`$MA;B!I;G1E(')A9&5R82!6
M1E,M;6%P<"X`2V%N(&EN=&4@<F%D97)A(%9&4RUM87!P.B`E<RX`2V%N(&EN
M=&4@<F%D97)A(%9&4RUF:6P@)7,N`$MA;B!I;G1E(')A9&5R82!61E,M9FEL
M+@!+86X@:6YT92!R861E<F$@5D93+6UA<'`@)R5S)RX`2V%N(&EN=&4@<F%D
M97)A(%9&4R!R96MU<G-I=G0Z("5S+@!+86X@:6YT92!A=F?V<F$@86MT=65L
M;"!M87!P+@!+86X@:6YT92!E>'1R86AE<F$@0V5R=&EF:6MA='-D971A;&IE
M<@!+86X@:6YT92!L861D82!D969I;FET:6]N96X@878@)7,N`$MA;B!I;G1E
M(&9L>71T82!61E,M9FEL+@!+86X@:6YT92#V<'!N82!61E,M9FEL("5S+@!+
M86X@:6YT92#V<'!N82!61E,M9FEL(&;V<B!S:W)I=FYI;F<N`$MA;B!I;G1E
M(/9P<&YA(%9&4RUF:6PN`$MA;B!I;G1E(/9P<&YA(&MO;7!R:6UE<F%T(&%R
M:VEV+@!+86X@:6YT92!LY'-A(%9&4RUF:6P@*&9I;&5S:7IE*"D@;6ES<VQY
M8VMA9&5S*2X`2V%N(&EN=&4@;.1S82!61E,M9FEL("AG971&:6QE4VEZ92@I
M(&UI<W-L>6-K861E<RDN`$MA;B!I;G1E(&SD<V$@9FEL.B``2V%N(&EN=&4@
M;.1S82!K871A;&]G96X@9O9R("=V9G-R;V]T)RX`2V%N(&EN=&4@8GET82!N
M86UN('#E("5S('1I;&P@)7,Z(&1E<W1I;F%T:6]N<VUA<'`@9FEN;G,@<F5D
M86X`2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUM87!P+@!+86X@:6YT92!B
M>71A(&YA;6X@<.4@5D93+6UA<'`Z("5S+@!+86X@:6YT92!B>71A(&YA;6X@
M<.4@5D93+69I;"`E<RX`2V%N(&EN=&4@8GET82!N86UN('#E(%9&4RUF:6P@
M)7,O)7,N`$MA;B!I;G1E(&)Y=&$@;F%M;B!PY2!61E,M9FEL+@!+86X@:6YT
M92!K]G)A("=M:VES;V9S)RX`2V%N(&EN=&4@]G9E<G/D='1A(%=O<F1D;VMU
M;65N=&5T`$MA;B!I;G1E('-K<FEV82!T:6QL(%9&4RUF:6P@)7,N`$MA;B!I
M;G1E('-K<FEV82!T:6QL(%9&4RUF:6P@*&-O<'DH*2!M:7-S;'EC:V%D97,I
M+@!+86X@:6YT92!S:W)I=F$@9&%T82!T:6QL(%9&4RUF:6PN`$MA;B!I;G1E
M('-K<FEV82!T:6QL(%9&4RUF:6PL(&MV;W1A('-K=6QL92#V=F5R<VMR:61A
M<RX`56YD97)S=')U:V5N`,5N9W)A(.1N9')I;F=A<@#%;F=R87(@9&EN('-E
M;F%S=&4@Y71GY')D`$]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!PY2!F]G)B
M:6YD96QS93H@`$]VY&YT870@<W9A<B!F<N5N('-E<G9E<B!T:6QL.B``16H@
M:V%T96=O<FES97)A9`!)8VME(&AA;G1E<F%D(&MO;7!O;F5N="!A=B!T>7`Z
M("5S`%5N:6-O9&4@*%541BTX*0!&]G)E;F%D92!!<F%B96UI<F%T96X`4W1O
M<F)R:71A;FYI96X`1O9R96YT82!3=&%T97)N80!!;65R:6MA;G-K82!3=&EL
M;&%H879S]F%R;F$`16YH971E<@!/:^1N9`!/:^1N="!G<N1N<W-N:71T<VUE
M9&1E;&%N9&5I9"`H87!I;7-G:60I+@!/:^1N="!K;&EE;G1M961D96QA;F1E
M:60@*&-L:6US9VED*2X`3VOD;F0@;W)T('-P96-I9FEC97)A9"X`3VOD;G0@
M86YVY&YD87)N86UN(&5L;&5R(&SV<V5N;W)D+@!482!B;W)T(&SD;FME;B!F
M<N5N(&YU=G)A;F1E(&5L96UE;G0`3F%M;FSV<P!)8VME+7!R:79I;&EG97)A
M9&4@<VMR:7!T(&MA;B!I;G1E(&MO;6UA(.5T($ML:7!P('5T+TMO<&EE<F$O
M2VQI<W1R82UF=6YK=&EO;F5R;F$@878@<^1K97)H971S<VOD;"X@2VQI8VMA
M($]+(&;V<B!A='0@<V4@96X@=&5K;FES:R!B97-K<FEV;FEN9R!F<N5N(&UO
M>FEL;&$N;W)G(&]M(&AU<B!D=2!K86X@=&EL;.5T82!A='0@<VMR:7!T(&MO
M;6UE<B#E="!U<FML:7!P+@!482!B;W)T(&;D<F<`5&EL;.1G9V5T('-T]F1S
M(&EN=&4`57!P9&%T97)A`%5P<&1A=&5R82`E<P!5<'!D871E<F$@<W1A='5S
M('#E('-V87)A;F1E`%5P<&1A=&5R82!A;G;D;F1A<F4`57!P9&%T97)A9&4@
M)R5S)RX`57!P9&%T97)I;F=S<V-R:7!T(')A9&5R870N`$QA9&1A('5P<`!,
M861D861E('5P<"!A;&QA(&MO;F9I9W5R871I;VYS9FEL97(@=&EL;"!S97)V
M97)N+@!697)S86QE<@!2;VUE<G-K82!S:69F<F]R`%5R=6=U87D`06YVY&YD
M(&%K='5E;&PZ("5S`$%N=N1N9"!34TP`06YVY&YD(&]M(&YA;6XO;/9S96YO
M<F0@Y'(@86YN;W)L=6YD82!F]G(@24U34"US97)V97(N`$%N=N1N9&%R90!!
M;G;D;F1A<F4@)7,@Y'(@:6YT92!B96CV<FEG(&;V<B`E<RX`06YVY&YD87)A
M9&UI;FES=')A=&EO;@!!;G;D;F1A<FEN<W3D;&QN:6YG87(`06YVY&YD87)R
M96=I<W1R97)I;F<`06YVY&YD87)R96=I<W1R97)I;F<@:&%R(&%V86MT:79E
M<F%T<RX`06YVY&YD87)K;VYT;W0@:&ET=&%D97,@:6YT90!!;G;D;F1A<FYA
M;6X`06YVY&YD87)N86UN("5S(&9I;FYS(')E9&%N+@!!;G;D;F1A<FYA;6XZ
M`$%N=N1N9&%R;F%M;CH@`$%N=N1N9&%R92!I('-Y<W1E;65T.@!5>F)E:VES
M=&%N`%9&4RUM87!P(&5X:7-T97)A<B!I;G1E+@!396UE<W1E<@!':6QT:6=A
M('!L871S97(@<V]M(&AI='1A9&5S(&EN:VQU9&5R87(Z(`!':6QT:6=H970`
M36EN=71E<B!F<N5N(&YU`%;D<F1E="#V=F5R<W1I9V5R(&1E="!H]F=S=&$@
M=&EL;.5T;F$@*"5S*0!6Y')D96X`5N1R9&5N(&%T="!VY&QJ82!F<N5N`%9A
M;G5T874`5F%R:6%B96P`5F5N97IU96QA`%9E<FEF:65R:6YG(&UI<W-L>6-K
M861E<R`M(&UE9&1E;&%N9&5T(&MA;B!H82!M86YI<'5L97)A=',N`%9E<G-I
M;VX`5F5R<VEO;FAA;G1E<FEN9P!697)T:6MA;"!J=7-T97)I;F<`5F5R=&EK
M86P@=71F>6QL;F%D`%9E<G1I:V%L.@!6Y&QD:6=T(&CV9P!6:65T;F%M`%9I
M971N86UE<VES:R`H5DE30TE)*0!6:7-A("5S`%9I<V$@96X@97AT97)N('=E
M8F)S:61A`%9I<V$@<V]M("5S`%9I<V$@:.1N9&5L<V4`5FES82!U<'!G:69T
M`$IU;F=F<G7V87)N82P@0G)I='1I<VMA`$IU;F=F<G7V87)N82P@06UE<FEK
M86YS:V$`4VEK=`!3:6MT.@!6;V1A9F]N92!)=&%L:65N('9I82!33510`%9!
M4DX`5D%23DE.1R$A(2!2041%4D$@4TM225!4150@34%.545,3%0@1E+%3B`E
M<RX`5TE.('9I82!(5%10`%=A;&QI<R!O8V@@1G5T=6YA`%9A<FYI;F<`3VX`
M5N1D97)P<F]G;F]S`%;D9&5R9&%T82!F<N5N`'=E871H97(N8V]M`%=E8F(`
M5V5B8G!L871S`%=E8F)P;&%T<V5N("T@4V]B97(`5V5B8G!L871S96X@+2!3
M;V)E<B!.60!696-K;W9I<P!6Y&QK;VUM96X`5N1L:V]M;65N('1I;&P@)7,`
M5N1L:V]M;65N+"`E<P!6Y'-T97)LY&YD<VL@*$E33RTX.#4Y+3$I`%;D<W1E
M<FSD;F1S:R`H25-/+3@X-3DM,34I`%;D<W1R82!386AA<F$`5FEL:V5N(&%P
M<&QI:V%T:6]N('-K86QL("5S('9I<V$@969T97(@:6YL;V=G;FEN9S\`5FEL
M:V5N(.1R(&%V9W+D;G-N:6YG<W1E8VMN970_`%9I;&ME="#D<B!T96-K;F5T
M(&;V<B!C:71E<F%D('1E>'0_`%=H97)E:7,@075S=')A;&EE;FMA<G1A`%9I
M;&MA(&9A<V5R`%9I;&MA('!L=6=I;B!S:V%L;"!A:W1I=F5R87,@9O9R(%)I
M8V@@5&5X="!E9&ET;W)N+@!"<F5D9`!"<F5D9"!I($-34RUU;FET<P!"<F5D
M9"!PY2!M96YY;B!F]G(@)R5S)R!T:6QL(';D;G-T97(@*&?D;&QE<B!F<N5N
M(&[D<W1A(&EN;&]G9VYI;F<`5&%B96QL8G)E9&0`0G)E9&1E;FAE=`!"<F5D
M9#H`5VEK:0!6:6YD`%1I9&EG('9I;F0`5FEN9&AA<W1I9VAE="!I(&MN;W``
M5FEN9#H`5FEN9#H@`%9I<V1O;0#6;G-K96QI<W1A`$%R8F5T90!!9')E<W,L
M(&%R8F5T90!496QE9F]N+"!A<F)E=&4`1F5L(&%N=&%L(&;D;'0@<.4@<F%D
M("5D+B!&]G)VY&YT861E("5D+"!H:71T861E("5D+@!&96P@86YT86P@9N1L
M="X@1O9R=N1N=&%D92`E9"P@:&ET=&%D92`E9"X`1F5L('!O<VET:6]N("5D
M('9I9"!LY'-N:6YG(&%V(%9&4RUF:6PN`%@M4F5F`%@U,#E6,R!5=/9K860@
M;GEC:V5L86YVY&YD;FEN9P!8-3`Y5C,M=&EL;.1G9P!960!965E9`%EA:&]O
M(2!M87``Q7)L:6<`665M96X`2F$`2F$L(&IA9R!S86UT>6-K97(`1'4@:&%R
M(&%K=&EV97)A="!T97AT;.1G92X@06YVY&YD(%L\/ET@9O9R(&%T="#E=&5R
M9^4@=&EL;"!765-)5UE'+@!$=2!H87(@:6YT92!B96CV<FEG:&5T('-K87!A
M(&9L97(@Y&X@)60@8FQO8VLN`$1U(.1R(&EN=&4@875T96YT:7-E<F%D+@!$
M=2!K86X@:6YT92!A;G;D;F1A("=<)R!I(&1I='0@;F%M;@!$=2!K86X@:6YT
M92!A;G;D;F1A("=<)R!I(&1I='0@;F%M;@!$=2!A;F=A=B!I;G1E(&5N(&=O
M9&OD;F0@92UP;W-T861R97-S+@!$=2#D<B!U=&QO9V=A9"X`1'4@;>5S=&4@
M86YG92!E='0@9VEL=&EG="!M;V)I;&YU;6UE<CL@96YB87)T('-I9F9R;W(@
M;V-H(&5T="`G*R<@9O9R92!I;G1E<FYA=&EO;F5L;'0@<')E9FEX+@!$=2!A
M;F=A=B!I;G1E(&5T="!G;V1KY&YT(';D<F1E+@!$=2!MY7-T92!K;VYF:6=U
M<F5R82!E;B!$871A5'+D9',M:V]P<&QI;F<@9O9R(&%T="!A;G;D;F1A(')E
M9VES=')E<FEN9P!$=2!MY7-T92!K;VYF:6=U<F5R82!E;B!61E,M:V]P<&QI
M;F<`1'4@;>5S=&4@8F5S:W)I=F$@<')O8FQE;65N+"!I;FYA;B!D=2!K86X@
M<F%P<&]R=&5R82!E='0@<')O8FQE;2X`1'4@;>5S=&4@86YG92!E;B!54DP@
M<V]M(&SD;FME;B!P96MA<B!PY0!$=2!MY7-T92!A;F=E(&5N('-E<G9E<B!S
M;VT@<VMA;&P@<F%D97)A<RX`1'4@;>5S=&4@86YG92!E='0@86YVY&YD87)N
M86UN('-O;2!S:V%L;"!R96YS87,N`$1U(&WE<W1E(&%N9V4@971T(&%N=N1N
M9&%R;F%M;B!S;VT@<VMA;&P@<F%D97)A<RX`1'4@;>5S=&4@86YG92!E='0@
M86YVY&YD87)N86UN('-O;2!S:V%L;"!LY&=G87,@=&EL;"X`1'4@;>5S=&4@
M86YG92!E='0@86YVY&YD87)N86UN('-O;2!S:V%L;"!U<'!D871E<F%S+@!$
M=2!MY7-T92!A;F=E(&5N(.5T9^1R9"!S;VT@<VMA;&P@=71F]G)A<RX`1'4@
M;>5S=&4@86YG92!E='0@;GET="!K871E9V]R:6YA;6XN`$1U(&WE<W1E(&%N
M9V4@971T(&ET86QI96YS:W0@=&5L969O;FYU;6UE<@!$:6X@)7,@<V5S<VEO
M;B!H87(@=7!P:/9R="X@5F%R(&=O9"!L;V=G82!I;B!I9V5N+@!$:6X@92UP
M;W-T861R97-S`$1I;B!&<N5N.B!A9')E<W,Z`$1I;B!I;F9O<FUA=&EO;@!$
M:6X@:6YT97)N971A9')E<W,@:&%R(.1N9')A=',@969T97(@871T(&1U(&QO
M9V=A="!I;B!T:6QL("<E<R<N($;V<B!A='0@<VMY9&1A(&1I9RP@;>5S=&4@
M9'4@;&]G9V$@:6X@:6=E;BX`1&ET="!N86UN`$1I;B!A=71E;G1I<V5R:6YG
M<VMO<'!L:6YG('-T]F1E<B!I;G1E('5P<&SD9V<@878@86YVY&YD87)E+B!/
M;2!D=2!V:6QL(&%N=N1N9&$@2&]R9&4@9O9R(&%T="!A9&UI;FES=')E<F$@
M86YVY&YD87)E('/E(&WE<W1E(&1U(&%N=N1N9&$@96X@86YN86X@875T96YT
M:7-E<FEN9W-K;W!P;&EN9RX`1&ET="!A=71E;G1I<V5R:6YG<VMO<'!L:6YG
M('-T]F1E<B!I;G1E(&QI<W1N:6YG(&%V(&%N=N1N9&%R92P@96QL97(@<^4@
MY'(@9G5N:W1I;VYE;B!A=G-TY&YG9"X`1&EN('=E8F)LY'-A<F4O:6YT97)N
M971A9')E<W,@:&%R(.1N9')A=',@969T97(@871T(&1U(&QO9V=A="!I;B!T
M:6QL("<E<R<N($;V<B!A='0@<VMY9&1A(&1I9RP@;>5S=&4@9'4@;&]G9V$@
M:6X@:6=E;BX`1&EN('=E8F)LY'-A<F4@<W3V9&5R(&EN=&4@9&5N(&CD<B!F
M=6YK=&EO;F5N+@!$:6X@=V5B8FSD<V%R92!S=/9D97(@:6YT92!U='-K<FEF
M='-F=6YK=&EO;F5N+B!4<GEC:R!#=')L+T]P=&EO;B`K(%`@9O9R(&%T="!S
M:W)I=F$@=70N`$1I;B!A:W1U96QL82!T:61S>F]N.@!$:6X@9O9R=F%L9&$@
M:61E;G1I=&5T(&AA<B#D;F1R871S+@!$:6X@9O9R=F%L9&$@:61E;G1I=&5T
M.@!$:71T(&9U;&QS=.1N9&EG82!N86UN.@!$:6X@:6YL;V=G;FEN9R!H87(@
M9^5T="!U="X`1&ET="!N>6$@;/9S96YO<F0@9O9R("5S(.1R.B`E<P!$:6YA
M(&EN<W3D;&QN:6YG87(@:&%R('5P<&1A=&5R871S(&;V<B!D96X@:.1R('-E
M<W-I;VYE;BX`1&EN82!I;G-TY&QL;FEN9V%R(&AA<B!U<'!D871E<F%T<RX`
M1&ET="!L]G-E;F]R9"!H87(@8FQI=FET(.5T97)S=.1L;'0`1&ET="!L]G-N
M;W)D(&AA<B#E=&5R<W3D;&QT<RP@:V]N=')O;&QE<F$@9&EN(&4M<&]S="!O
M8V@@;&]G9V$@:6X@;65D(&1I='0@;GEA(&SV<V5N;W)D+@!$:71T(&SV<V5N
M;W)D(&AA<B!GY71T('5T+@!$:6YA(&9JY')R<V5R=G)A<CH`2G5G;W-L879I
M96X`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M']FT@8VET97)A9"!T
M97AT70!;1F5L<F%P<&]R=%T`6U9I<V$@8VET97)A9"!T97AT("T`6U9I<V$@
M8VET97)A9"!T97AT("T@)7,@<F%D97)=`%MR860@)7,@878@)7-=`%]!9&UI
M;FES=')A=&EO;@!?0TQ)`%]$871A5'+D9`!?4F%D97)A(')A9`!?1W)U<'!E
M<@!?2&KD;'``7T)I;&1I;G-TY&QL;FEN9V%R+BXN`%],;V=G82!I;@!?3&]G
M9V$@=70`Q%]N9')A(&SD;FLN+BX`7TEN<W3D;&QN:6YG87(`7T)E:/9R:6=H
M971E<@!?5&$@8F]R="!LY&YK+BXN`%]3971U<`!?5&%B96QL:6YS=.1L;&YI
M;F=A<BXN+@!?06YVY&YD87)E`&%D<F5S<V)O:P!O:^1N9"!M;W1T86=A<F4`
M:V%L96YD97(`;'5G;G0`:V%N(&EN=&4@<VMA<&$@=71F:6P`:V%N(&EN=&4@
M]G!P;F$@:6YD871A`&ML:6-K82!HY'(`:VQO8VMA`&MO;6UA;F1O<F%D<V9E
M;`!K;VYF:6=U<F%T:6]N<V9E;`!K<FET:7-K('-Y<W1E;69I;"!S86MN87,`
M9&%T869O<FUA=&9E;`#D;F1R80!P;W-T96X@:W5N9&4@:6YT92!H:71T87,`
M9F%L;&%N9&4`9FEL`&9RY6X@9&5N("5S("@E<RD@:VP@)7,@)7,`<W1O<FUB
M>6%R`&@Z`&AH`&]KY&YD(';D<F1D871O<@!G96YA<W0`:6YL:6YE`&)E87)B
M971N:6YG<V9E;`!);G1E<FYT(&%P<&QI:V%T:6]N<V9E;`!R861E<ET`9F5L
M:V]D("5D(&9RY6X@;6MI<V]F<P!M;0!N86UN`&EN=&4@:6UP;&5M96YT97)A
M9`!I;G1E(&EM<&QE;65N=&5R860`86YT96-K;FEN9W-B;&]C:P!P<F]C96YT
M`.5T:V]M<W0@;F5K860`<&EX;&%R`'!R;W1O:V]L;&9E;`!S=&EG86YD90!4
M:N1N<W1E;B#D<B!E:B!T:6QL9^1N9VQI9P!V:7-A('-K:6QL;F%D97(`<VUS
M,F5M86EL('9I82!(5%10`'-S`'-T861I9W0`<WES=&5M9F5L`'5P<&=I9G1S
M;&ES=&$`=&EL;&;D;&QI9W0@9F5L`&%N9V4@;/9S96YO<F1E="!T=N4@9^5N
M9V5R(&;V<B!A='0@8F5K<N1F=&$`96YA9`!N86UN;/9S`&%N=N1N9&%R=F%L
M`'9#87)D`'<Z`'=E871H97(N8V]M````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO3$-?34534T%'15,`
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q-#$@,#(Q-3`W`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S
M;%]322]H96QP+GAM;```````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S,R,"`Q,#4Q-30S-#$T,2`P,C$T-3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]X;6P@=F5R<VEO;CTB
M,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<VQ?4TDO:&5L<"YX
M;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH
M96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T
M86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@
M:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H
M="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V
M92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE
M;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F
M<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@
M;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T
M8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG
M(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@
M979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O
M;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V
M:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@
M8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@
M<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO
M=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T
M871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@
M0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O
M9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@
M8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@
M8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H
M92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@
M;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF
M:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@
M8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@
M=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE
M960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@
M=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VQ?4TDO
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`S-3`P,S,@,3`U,34T,S0Q-#$@,#(S,C,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````G`8``!P```#\-```
MVP@``-QI````````2(T```X```!)C0``#P```%B-```-````:(T```@```!V
MC0``"P```'^-```,````BXT```0```"8C0``&````)V-```;````MHT``"T`
M``#2C0``'0````".```D````'HX``"D```!#C@``&0```&V.```F````AXX`
M``P```"NC@``)````+N.```/````X(X```L```#PC@``#@```/R.```%````
M"X\``"@````1CP``"````#J/```*````0X\``!4```!.CP``$@```&2/```+
M````=X\``(4```"#CP``#@````F0```*````&)````T````CD```#@```#&0
M```1````0)````T```!2D```#````&"0```-````;9````8```![D```E```
M`(*0```*````%Y$```\````BD0``&````#*1```,````2Y$```X```!8D0``
M#@```&>1```(````=I$```D```!_D0``+@```(F1```:````N)$``#(```#3
MD0``.`````:2``!4````/Y(``%$```"4D@``6@```.:2``!7````09,``#0`
M``"9DP``"0```,Z3```-````V),```<```#FDP``"@```.Z3```/````^9,`
M``4````)E```!@````^4```(````%I0``"4````?E```(````$64```3````
M9I0``!````!ZE```#P```(N4```*````FY0```,```"FE```#P```*J4```4
M````NI0```D```#/E```#0```-F4```2````YY0``!D```#ZE```'@```!25
M```/````,Y4```H```!#E0``#P```$Z5```(````7I4``"0```!GE0``%```
M`(R5```6````H94```@```"XE0``3@```,&5```M````$)8``!D````^E@``
M!P```%B6```,````8)8``"P```!ME@``#@```)J6```#````J98```L```"M
ME@``!P```+F6```'````P98```4```#)E@```P```,^6```7````TY8```H`
M``#KE@``#P```/:6```8````!I<``",````?EP``#@```$.7```4````4I<`
M`!<```!GEP``%P```'^7```7````EY<``!,```"OEP``#@```,.7```?````
MTI<``!T```#REP``!P```!"8```&````&)@```@````?F```#P```"B8```&
M````.)@```H````_F```$P```$J8```+````7I@``!````!JF```%0```'N8
M```5````D9@```<```"GF```!0```*^8```5````M9@``!$```#+F```#```
M`-V8```[````ZI@``#@````FF0``"0```%^9```'````:9D``!0```!QF0``
M`P```(:9```%````BID```D```"0F0``$P```)J9```Y````KID``!(```#H
MF0``)P```/N9```L````(YH``"H```!0F@``)0```'N:```*````H9H```8`
M``"LF@``"0```+.:```'````O9H``"\```#%F@``-P```/6:```N````+9L`
M`%4```!<FP``+0```+*;```M````X)L``#T````.G```/P```$R<```M````
MC)P``$````"ZG```(P```/N<```C````'YT``$````!#G0``+0```(2=```S
M````LIT``"4```#FG0``%0````R>```9````(IX``"D````\G@``)````&:>
M```H````BYX``!$```"TG@``"@```,:>```,````T9X``!8```#>G@``%@``
M`/6>```'````#)\```<````4GP``%````!R?```*````,9\```@````\GP``
M)P```$6?```'````;9\```<```!UGP``!@```'V?```%````A)\```<```"*
MGP``!@```)*?```(````F9\``"D```"BGP``#@```,R?```*````VY\```<`
M``#FGP``"0```.Z?```6````^)\```0````/H```"````!2@```-````':``
M``8````KH```'@```#*@```1````4:````@```!CH```#````&R@```'````
M>:````,```"!H````P```(6@```7````B:```!T```"AH```"````+^@```$
M````R*````@```#-H```"````-:@```K````WZ```"`````+H0``%0```"RA
M```&````0J$```8```!)H0``%0```%"A```Z````9J$``!@```"AH0``(@``
M`+JA```S````W:$``"X````1H@``'0```$"B```A````7J(``%0```"`H@``
M0````-6B```I````%J,``!D```!`HP``"@```%JC```'````9:,``!4```!M
MHP``#@```(.C```*````DJ,```D```"=HP``%````*>C```8````O*,``!T`
M``#5HP``$P```/.C```1````!Z0``!0````9I```!````"ZD```&````,Z0`
M`!0````ZI```5````$^D``!D````I*0```4````)I0``!0````^E```;````
M%:4``!H````QI0``$P```$RE```1````8*4``!$```!RI0``'````(2E```0
M````H:4``"$```"RI0``!0```-2E```+````VJ4``!(```#FI0``"@```/FE
M```/````!*8```T````4I@``$0```"*F```3````-*8```P```!(I@``!@``
M`%6F```,````7*8```8```!II@``%P```'"F```0````B*8```@```"9I@``
M!0```**F```,````J*8``!````"UI@``#0```,:F```&````U*8```<```#;
MI@``#0```..F```'````\:8```L```#YI@``!P````6G```'````#:<```D`
M```5IP``"0```!^G```*````*:<``!D````TIP``/0```$ZG```=````C*<`
M``P```"JIP``$````+>G```%````R*<``"4```#.IP``$@```/2G```3````
M!Z@``"L````;J```.P```$>H```@````@Z@```@```"DJ```-@```*VH```A
M````Y*@``!`````&J0``"````!>I```,````(*D```8````MJ0``#P```#2I
M```'````1*D```H```!,J0``#0```%>I```?````9:D``!P```"%J0``(0``
M`**I```>````Q*D``!D```#CJ0``'@```/VI```;````'*H``"$````XJ@``
M+@```%JJ```F````B:H``!P```"PJ@``'@```,VJ```<````[*H``"8````)
MJP``*P```#"K```S````7*L``"8```"0JP``*P```+>K```X````XZL``!T`
M```<K```%0```#JL```O````4*P``"````"`K```$@```*&L```I````M*P`
M`!X```#>K```(````/VL```2````'JT``*(````QK0``%@```-2M```C````
MZZT``"@````/K@``*0```#BN```H````8JX``!\```"+K@``%0```*NN```@
M````P:X``"4```#BK@``*`````BO```M````,:\``#````!?KP``D@```)"O
M```A````([```!8```!%L```'````%RP```F````>;```"H```"@L```00``
M`,NP``!$````#;$```P```!2L0``!P```%^Q```'````9[$```8```!OL0``
M$````':Q```2````A[$``!,```":L0``$@```*ZQ```'````P;$```0```#)
ML0``$````,ZQ```0````W[$```P```#PL0``#0```/VQ```/````"[(``!,`
M```;L@``*````"^R```&````6+(``!$```!?L@``%P```'&R```;````B;(`
M``X```"EL@```@```+2R``!)````M[(```4````!LP``$`````>S```/````
M&+,```0````HLP``#0```"VS```.````.[,```,```!*LP``"````$ZS```'
M````5[,```T```!?LP``$````&VS```-````?K,```L```",LP``!@```)BS
M```,````G[,```H```"LLP``$0```+>S```9````R;,``"(```#CLP``#P``
M``:T```;````%K0``#0````RM```&````&>T```2````@+0``"(```"3M```
M#0```+:T```'````Q+0``!0```#,M```"P```.&T```B````[;0``"\````0
MM0``"P```$"U```)````3+4``!D```!6M0``"P```'"U```)````?+4``!8`
M``"&M0``#P```)VU```9````K;4``!8```#'M0``#@```-ZU```8````[;4`
M``@````&M@``#0````^V```F````';8``$,```!$M@``"````(BV```2````
MD;8``!\```"DM@``"P```,2V```O````T+8```X`````MP``!0````^W```&
M````%;<``$4````<MP```P```&*W```'````9K<```0```!NMP``"@```'.W
M```*````?K<```\```")MP``$````)FW```7````JK<``!$```#"MP``&0``
M`-2W```7````[K<```D````&N```!0```!"X```+````%K@```4````BN```
M#0```"BX```;````-K@``!<```!2N```%````&JX```)````?[@```X```")
MN```#0```)BX```2````IK@``#@```"YN```(````/*X```(````$[D``'L`
M```<N0``&````)BY```1````L;D```<```##N0``!0```,NY```8````T;D`
M`!X```#JN0``&P````FZ```9````);H``!L````_N@``&0```%NZ```3````
M=;H```<```")N@``"````)&Z```&````FKH```8```"AN@``$````*BZ```/
M````N;H``!````#)N@``#P```-JZ```+````ZKH```\```#VN@``#`````:[
M```/````$[L```<````CNP``!@```"N[```,````,KL``"@````_NP``#P``
M`&B[```(````>+L``!,```"!NP``'@```)6[```A````M+L``"````#6NP``
M&0```/>[```7````$;P``"4````IO```%P```$^\```6````9[P```0```!^
MO```&P```(.\```-````G[P```P```"MO````P```+J\```%````OKP```@`
M``#$O```"@```,V\```,````V+P```L```#EO```$````/&\```,`````KT`
M``X````/O0``"P```!Z]```$````*KT```0````OO0``$P```#2]```4````
M2+T```P```!=O0``"0```&J]```.````=+T```L```"#O0``&P```(^]```'
M````J[T```<```"SO0``"@```+N]```-````QKT```D```#4O0``!````-Z]
M```#````X[T``!@```#GO0``!`````"^```.````!;X``'P````4O@``%0``
M`)&^```%````I[X```<```"MO@``#````+6^```(````PKX```H```#+O@``
M!@```-:^```(````W;X```(```#FO@``!@```.F^```4````\+X```T````%
MOP``$````!._```;````)+\```0```!`OP``"0```$6_```0````3[\```D`
M``!@OP``"0```&J_```%````=+\```8```!ZOP``&0```(&_```.````F[\`
M``<```"JOP``!P```+*_```%````NK\```D```#`OP``"@```,J_```.````
MU;\```(```#DOP``"P```.>_```-````\[\```D````!P```!@````O````2
M````$L````D````EP```!P```"_````4````-\```!T```!,P```0@```&K`
M```E````K<```"4```#3P```!@```/G````*`````,$```0````+P0``"0``
M`!#!```(````&L$``!$````CP0``"0```#7!```&````/\$```T```!&P0``
M!@```%3!```$````6\$``!X```!@P0``!0```'_!```.````A<$```0```"4
MP0``!@```)G!```'````H,$``"$```"HP0``#0```,K!```5````V,$```8`
M``#NP0``!````/7!```&````^L$```H````!P@``(@````S"```$````+\(`
M``4````TP@``'0```#K"```,````6,(```X```!EP@``"@```'3"```(````
M?\(```D```"(P@``!0```)+"```Z````F,(``#````#3P@``-0````3#```I
M````.L,``$<```!DPP``.````*S#```I````Y<,``#\````/Q```+@```$_$
M```M````?L0``!\```"LQ```)````,S$```(````\<0```H```#ZQ```"0``
M``7%```'````#\4``"`````7Q0``(````#C%```F````6<4```H```"`Q0``
M&0```(O%```I````I<4``!8```#/Q0``!P```.;%```*````[L4```P```#Y
MQ0``#P````;&```0````%L8``$`````GQ@``9@```&C&```,````S\8```8`
M``#<Q@``#P```./&```2````\\8``!`````&QP``'````!?'```C````-,<`
M`&H```!8QP``!0```,/'```0````R<<```D```#:QP``"P```.3'```@````
M\,<``!D````1R```0@```"O(```/````;L@``#0```!^R```-0```+/(```4
M````Z<@```<```#^R```#`````;)```@````$\D``!`````TR0``%````$7)
M```1````6LD``!<```!LR0``'````(3)```3````H<D``!0```"UR0``&@``
M`,K)```1````Y<D``!H```#WR0``'@```!+*```:````,<H``!,```!,R@``
M%0```&#*```1````=LH``!<```"(R@``%````*#*```7````M<H``!4```#-
MR@``"0```./*```0````[<H``!D```#^R@``!````!C+```'````'<L``!$`
M```ERP``!@```#?+```&````/LL```4```!%RP``!P```$O+```'````4\L`
M``4```!;RP``%@```&'+```&````>,L```8```!_RP``!````(;+```$````
MB\L```H```"0RP``#@```)O+```%````JLL``"@```"PRP``#@```-G+```,
M````Z,L```\```#URP``"@````7,```(````$,P```D````9S```*P```"/,
M```$````3\P```@```!4S```)@```%W,```2````A,P```\```"7S```!@``
M`*?,```*````KLP```@```"YS```(````,+,```)````X\P``!0```#MS```
M#`````+-```-````#\T```X````=S0``%@```"S-```1````0\T```8```!5
MS0```P```%S-```'````8,T```L```!HS0``"P```'3-```'````@,T```4`
M``"(S0``!P```([-```6````ELT```T```"MS0``#0```+O-```*````R<T`
M`!````#4S0``#P```.7-```1````]<T``!<````'S@``"@```!_.```1````
M*LX```0````\S@``.@```$'.```%````?,X```P```""S@``'@```(_.```.
M````KLX``!````"]S@``"P```,[.```,````VLX```D```#GS@``!P```/'.
M```*````^<X```D````$SP``#@````[/```0````'<\``!L````NSP``&```
M`$K/```:````8\\```H```!^SP``"0```(G/```*````D\\```P```">SP``
M#P```*O/```(````N\\```8```#$SP``'````,O/```'````Z,\```4```#P
MSP``"P```/;/``!'`````M````T```!*T```"0```%C0```$````8M````,`
M``!GT```"@```&O0```"````=M````0```!YT```)0```'[0```#````I-``
M``4```"HT```*@```*[0```*````V=````4```#DT```!````.K0```*````
M[]````8```#ZT```"`````'1```(````"M$```0````3T0``!0```!C1``!H
M````'M$```D```"'T0``#````)'1```0````GM$```4```"OT0``&P```+71
M```O````T=$``!`````!T@``"@```!+2```/````'=(```H````MT@``"0``
M`#C2```3````0M(``!L```!6T@``&````'+2```7````B](``!\```"CT@``
M#@```,/2```#````TM(```<```#6T@``"````-[2```'````Y](```H```#O
MT@``!P```/K2``!1`````M,``!````!4TP``#````&73```-````<M,``!H`
M``"`TP``2@```)O3```9````YM,```8`````U```&@````?4```E````(M0`
M``8```!(U```!@```$_4```?````5M0```D```!VU```&````(#4```7````
MF=0``"@```"QU```!@```-K4```-````X=0``"(```#OU```$P```!+5```C
M````)M4``!,```!*U0```@```%[5```+````8=4```@```!MU0``#0```';5
M```'````A-4``!0```",U0``!@```*'5```(````J-4```X```"QU0``!P``
M`,#5```*````R-4```L```#3U0``,@```-_5```'````$M8```P````:U@``
M#0```"?6```7````-=8```P```!-U@``"0```%K6```)````9-8```H```!N
MU@``!P```'G6```)````@=8```<```"+U@``"@```)/6```;````GM8```\`
M``"ZU@``$@```,K6```*````W=8``!8```#HU@``"0```/_6```0````"=<`
M``<````:UP``$@```"+7```$````-=<```<````ZUP``!0```$+7```%````
M2-<```L```!.UP``%````%K7```1````;]<``!H```"!UP``%@```)S7```4
M````L]<``!<```#(UP``&````.#7```<````^=<``!D````6V```!P```##8
M```%````.-@```T````^V```#````$S8```(````6=@``!<```!BV```"P``
M`'K8```,````AM@``!\```"3V```&@```+/8```$````SM@```H```#3V```
M!````-[8```-````X]@```P```#QV```!0```/[8```)````!-D```4````.
MV0``!P```!39```%````'-D```0````BV0```@```"?9```X````*MD``"P`
M``!CV0``$@```)#9```I````H]D``#(```#-V0``"@````#:```L````"]H`
M`"X````XV@``,P```&?:```S````F]H``#@```#/V@``#P````C;```8````
M&-L``!`````QVP``#P```$+;```3````4ML``!4```!FVP``%````'S;```2
M````D=L``!0```"DVP``%0```+G;``!B````S]L``!,````RW```#0```$;<
M```7````5-P```P```!LW```*P```'G<```A````I=P``!H```#'W```"0``
M`.+<``!%````[-P``$$````RW0``!````'3=```4````>=T```X```".W0``
M$P```)W=```8````L=T```8```#*W0``"0```-'=```*````V]T```\```#F
MW0``$````/;=```.````!]X```4````6W@``&P```!S>```(````.-X```8`
M``!!W@``%````$C>```1````7=X```X```!OW@``.````'[>```&````M]X`
M``X```"^W@``!0```,W>```'````T]X```8```#;W@``*````.+>```,````
M"]\``!P````8WP``!````#7?```I````.M\``!<```!DWP``'P```'S?``!<
M````G-\``!0```#YWP``/@````[@```0````3>````<```!>X```#@```&;@
M```,````=>```!,```""X```"@```);@```=````H>```!D```"_X```!0``
M`-G@```1````W^```!$```#QX```)`````/A```2````*.$``!4````[X0``
M$@```%'A```.````9.$``!D```!SX0``"````(WA```)````EN$```T```"@
MX0``!P```*[A```*````MN$```<```#!X0``#P```,GA```&````V>$```L`
M``#@X0``&@```.SA```*````!^(```@````2X@``!0```!OB```?````(>(`
M``8```!!X@``$````$CB```(````6>(```T```!BX@``"````'#B```>````
M>>(``!(```"8X@``+````*OB```:````V.(```D```#SX@``"@```/WB```5
M````".,```4````>XP``$````"3C```&````->,``!X````\XP``*````%OC
M```*````A.,``!P```"/XP``$0```*SC```+````ON,``!H```#*XP``%```
M`.7C```$````^N,```0```#_XP``"P````3D```%````$.0```8````6Y```
M"````!WD```@````)N0``"D```!'Y```(````''D``!!````DN0``!H```#4
MY```*````._D```I````&.4``%````!"Y0``(@```)/E```&````MN4```@`
M``"]Y0``!0```,;E```(````S.4``"H```#5Y0``(P````#F```9````).8`
M`"X````^Y@``"````&WF```7````=N8```H```".Y@``!P```)GF```0````
MH>8```L```"RY@``!P```+[F```3````QN8```@```#:Y@``"P```./F```*
M````[^8``!0```#ZY@``#P````_G```R````'^<```L```!2YP``#@```%[G
M```%````;><```4```!SYP``!0```'GG```7````?^<```\```"7YP``!```
M`*?G```*````K.<```D```"WYP``"P```,'G```-````S><```P```#;YP``
M#@```.CG```%````]^<```0```#]YP``#0````+H```R````$.@``$4```!#
MZ```!P```(GH```>````D>@``!0```"PZ```!0```,7H```4````R^@```8`
M``#@Z```!P```.?H```.````[^@``"H```#^Z```!@```"GI```-````,.D`
M``L````^Z0``-@```$KI```+````@>D```\```"-Z0``,@```)WI```E````
MT.D``#````#VZ0``,0```"?J```M````6>H```X```"'Z@``!0```);J```.
M````G.H``!,```"KZ@``$@```+_J```'````TNH``!$```#:Z@``$P```.SJ
M```'`````.L``!0````(ZP``&````!WK```'````-NL```P````^ZP``#```
M`$OK```$````6.L```<```!=ZP``"@```&7K```+````<.L```P```!\ZP``
M`P```(GK```2````C>L```8```"@ZP``'@```*?K```8````QNL``"4```#?
MZP``#0````7L```)````$^P``!\````=[````P```#WL```'````0>P```H`
M``!)[````@```%3L```,````5^P``!4```!D[```"P```'KL```9````ANP`
M`"````"@[```!0```,'L```*````Q^P``!4```#2[```$@```.CL```,````
M^^P```0````([0``"0````WM```'````%^T```P````?[0``4@```"SM```7
M````?^T``"0```"7[0``$@```+SM```'````S^T```8```#7[0``#@```-[M
M```,````[>T```T```#Z[0``%0````CN```2````'NX```\````Q[@``%```
M`$'N```*````5NX``!L```!A[@``$````'WN```+````CNX``&D```":[@``
M&@````3O```7````'^\``"<````W[P``&@```%_O```7````>N\``!L```"2
M[P``&0```*[O```?````R.\``!,```#H[P``"````/SO```'````!?````@`
M```-\```"0```!;P```5````(/````T````V\```(P```$3P```-````:/``
M`!,```!V\```"````(KP```#````D_```$8```"7\```/P```-[P```W````
M'O$``%<```!6\0``!0```*[Q```?````M/$``"\```#4\0``"@````3R```(
M````#_(```T````8\@``+0```";R```$````5/(``$\```!9\@``)0```*GR
M```<````S_(```L```#L\@``'P```/CR```=````&/,```L````V\P``!P``
M`$+S```-````2O,```P```!8\P``%P```&7S```&````??,``#D```"$\P``
M#````+[S```'````R_,```D```#3\P``$P```-WS```)````\?,```0```#[
M\P``$`````#T```(````$?0```@````:]```!````"/T```+````*/0```P`
M```T]```$@```$'T```1````5/0```P```!F]```&@```'/T```/````CO0`
M``<```">]```#0```*;T```4````M/0```X```#)]```#````-CT```;````
MY?0``"P````!]0``$P```"[U```&````0O4```4```!)]0``!````$_U```7
M````5/4```8```!L]0``"0```'/U```(````??4```D```"&]0``"@```)#U
M```1````F_4```8```"M]0``#@```+3U```.````P_4```L```#2]0``'0``
M`-[U```"````_/4``!P```#_]0``!P```!SV```&````)/8``&0````K]@``
M!P```)#V```F````F/8``#@```"_]@``&@```/CV```J````$_<``#L````^
M]P``*````'KW```T````H_<``!D```#8]P``%0```/+W```%````"/@```@`
M```.^```!P```!?X```%````'_@```<````E^```#@```"WX```)````//@`
M``8```!&^```"````$WX```'````5O@```@```!>^```!P```&?X```6````
M;_@```D```"&^```!@```)#X```+````E_@``!````"C^```!@```+3X```<
M````N_@``!0```#8^```!P```.WX```1````]?@```@````'^0``"````!#Y
M```)````&?D```8````C^0``&0```"KY```*````1/D``!P```!/^0``!0``
M`&SY```0````<OD``!0```"#^0``"P```)CY```-````I/D``"@```"R^0``
M&````-OY```7````]/D```0````,^@``"0```!'Z```"````&_H```@````>
M^@``(P```"?Z```?````2_H``#@```!K^@``)@```*3Z```Q````R_H``"<`
M``#]^@``9````"7[``!5````BOL``#@```#@^P``2@```!G\``!;````9/P`
M`"@```#`_```.````.G\```H````(OT``"P```!+_0``&P```'C]```C````
ME/T``$@```"X_0``A0````'^```P````A_X``"4```"X_@``00```-[^``!;
M````(/\``$D```!\_P``,0```,;_```K````^/\``"$````D``$`'P```$8`
M`0`F````9@`!`#H```"-``$`,P```,@``0`E````_``!`"<````B`0$`(```
M`$H!`0`?````:P$!`#````"+`0$`:0```+P!`0`Q````)@(!`$$```!8`@$`
M,P```)H"`0`E````S@(!`#T```#T`@$`90```#(#`0!-````F`,!`"\```#F
M`P$`+@```!8$`0`P````100!`%0```!V!`$`6@```,L$`0!(````)@4!`$H`
M``!O!0$`,@```+H%`0`O````[04!`"P````=!@$`+0```$H&`0!Q````>`8!
M`&8```#J!@$`;P```%$'`0"S````P0<!`!<```!U"`$`)0```(T(`0`R````
MLP@!`"D```#F"`$`/@```!`)`0`B````3PD!`%(```!R"0$`)0```,4)`0`+
M````ZPD!`+$```#W"0$`10```*D*`0`A````[PH!`#`````1"P$`)0```$(+
M`0`<````:`L!`#$```"%"P$`!P```+<+`0`'````OPL!``0```#'"P$`#0``
M`,P+`0`+````V@L!``X```#F"P$`!0```/4+`0`"````^PL!`%D```#^"P$`
M!0```%@,`0`$````7@P!``<```!C#`$`"````&L,`0`%````=`P!`#````!Z
M#`$`#````*L,`0`3````N`P!``T```#,#`$``@```-H,`0`'````W0P!``8`
M``#E#`$`%````.P,`0`,`````0T!`!@````.#0$`!@```"<-`0`2````+@T!
M``P```!!#0$``P```$X-`0`J````4@T!``8```!]#0$`!P```(0-`0`?````
MC`T!`"X```"L#0$`+P```-L-`0`7````"PX!`"(````C#@$`)0```$8.`0`;
M````;`X!`!@```"(#@$`)````*$.`0`?````Q@X!`!H```#F#@$`(0````$/
M`0`@````(P\!`!H```!$#P$`,@```%\/`0`:````D@\!`"\```"M#P$`*P``
M`-T/`0`?````"1`!`",````I$`$`'P```$T0`0`:````;1`!`"$```"($`$`
M)0```*H0`0`F````T!`!`"4```#W$`$`)````!T1`0`8````0A$!`!T```!;
M$0$`)````'D1`0`8````GA$!`"(```"W$0$`+````-H1`0`5````!Q(!`"4`
M```=$@$`/````$,2`0`?````@!(!`",```"@$@$`'P```,02`0`@````Y!(!
M`!H````%$P$`&````"`3`0`F````.1,!`"D```!@$P$`'@```(H3`0`I````
MJ1,!`!X```#3$P$`,0```/(3`0`,````)!0!`"\````Q%`$`)````&$4`0`'
M````AA0!``\```".%`$`%````)X4`0`.````LQ0!``T```#"%`$`)````-`4
M`0`%````]10!``<```#[%`$`(@````,5`0`E````)A4!`!H```!,%0$`'0``
M`&<5`0`'````A14!`!4```"-%0$`!@```*,5`0`)````JA4!``L```"T%0$`
M#0```,`5`0`7````SA4!``8```#F%0$`,P```.T5`0`'````(18!``\````I
M%@$`!P```#D6`0`R````018!``0```!T%@$`(0```'D6`0`3````FQ8!``P`
M``"O%@$`$0```+P6`0`R````SA8!`!8````!%P$`"````!@7`0`=````(1<!
M``D````_%P$`"@```$D7`0`4````5!<!``H```!I%P$`'0```'07`0`(````
MDA<!`!\```";%P$`"````+L7`0`:````Q!<!`"<```#?%P$`!@````<8`0`5
M````#A@!``<````D&`$`"````"P8`0`)````-1@!`#\````_&`$`!P```'\8
M`0`/````AQ@!``D```"7&`$`"````*$8`0`3````JA@!``<```"^&`$`&0``
M`,88`0`7````X!@!`!0```#X&`$`"@````T9`0`,````&!D!`!<````E&0$`
M!````#T9`0`J````0AD!``P```!M&0$`$0```'H9`0`'````C!D!``(```"4
M&0$`$````)<9`0`8````J!D!``L```#!&0$``P```,T9`0`(````T1D!``8`
M``#:&0$`!P```.$9`0`-````Z1D!``L```#W&0$`%`````,:`0`5````&!H!
M``X````N&@$`+P```#T:`0`@````;1H!`!P```".&@$`%0```*L:`0`,````
MP1H!`#$```#.&@$`$@`````;`0`_````$QL!``0```!3&P$`!````%@;`0`*
M````71L!`!,```!H&P$`!0```'P;`0`&````@AL!``8```")&P$`"````)`;
M`0`$````F1L!``P```">&P$`"@```*L;`0`Y````MAL!`"X```#P&P$`*0``
M`!\<`0`%````21P!`!@```!/'`$`&0```&@<`0`?````@AP!`!T```"B'`$`
M$0```,`<`0`"````TAP!``0```#5'`$`"@```-H<`0`&````Y1P!``4```#L
M'`$``P```/(<`0`,````]AP!`#(````#'0$`&@```#8=`0`T````41T!`"@`
M``"&'0$`4P```*\=`0`9`````QX!`'(````='@$`(````)`>`0`U````L1X!
M`"$```#G'@$`10````D?`0`H````3Q\!`"D```!X'P$`)@```*(?`0`E````
MR1\!`"@```#O'P$`*````!@@`0`B````02`!`"L```!D(`$`,````)`@`0`2
M````P2`!`!,```#4(`$`$````.@@`0!Y````^2`!``D```!S(0$`H0```'TA
M`0!S````'R(!`'P```"3(@$`*P```!`C`0!4````/",!`!<```"1(P$`)P``
M`*DC`0`6````T2,!``\```#H(P$`%P```/@C`0`?````$"0!`$`````P)`$`
M'P```'$D`0`<````D20!`%$```"N)`$`&@`````E`0`4````&R4!``H````P
M)0$`!0```#LE`0`&````024!``@```!()0$`$@```%$E`0`0````9"4!`!,`
M``!U)0$`'0```(DE`0`/````IR4!``0```"W)0$`"0```+PE`0`'````QB4!
M``4```#.)0$`!P```-0E`0`(````W"4!``@```#E)0$`#````.XE`0`&````
M^R4!``8````")@$`#`````DF`0`1````%B8!``@````H)@$`!````#$F`0`9
M````-B8!`!$```!0)@$`"@```&(F`0`8````;28!`!,```"&)@$`'````)HF
M`0`1````MR8!``0```#))@$`#P```,XF`0`'````WB8!``0```#F)@$`&0``
M`.LF`0`'````!2<!``(````-)P$``@```!`G`0`1````$R<!``D````E)P$`
M!@```"\G`0`2````-B<!`!<```!))P$`!@```&$G`0`G````:"<!``(```"0
M)P$`!````),G`0`/````F"<!`!,```"H)P$`!P```+PG`0`1````Q"<!`!@`
M``#6)P$`!@```.\G`0`3````]B<!`!`````**`$`$@```!LH`0`"````+B@!
M``8````Q*`$`#````#@H`0`)````12@!`!$```!/*`$`(@```&$H`0`'````
MA"@!``<```",*`$`"P```)0H`0`%````H"@!``(```"F*`$`"P```*DH`0`Q
M`0``M2@!`!````#G*0$`%````/@I`0`,````#2H!``<````:*@$`!@```"(J
M`0`)````*2H!``0````S*@$`#@```#@J`0`9````1RH!`",```!A*@$`(```
M`(4J`0`E````IBH!`"<```#,*@$`%@```/0J`0`Q````"RL!``L````]*P$`
M&@```$DK`0`1````9"L!`!4```!V*P$`"````(PK`0`%````E2L!`"````";
M*P$`"````+PK`0`*````Q2L!``D```#0*P$`#P```-HK`0`+````ZBL!`(<`
M``#V*P$`#@```'XL`0`(````C2P!``P```"6+`$`#@```*,L`0`)````LBP!
M``H```"\+`$`"P```,<L`0`+````TRP!``8```#?+`$`J0```.8L`0`)````
MD"T!``X```":+0$`&P```*DM`0`,````Q2T!``P```#2+0$`#````-\M`0`%
M````["T!`!(```#R+0$`-P````4N`0`;````/2X!`#,```!9+@$`-@```(TN
M`0!3````Q"X!`$\````8+P$`50```&@O`0!5````OB\!`#@````4,`$`"```
M`$TP`0`3````5C`!``T```!J,`$`#@```'@P`0`7````AS`!``4```"?,`$`
M!@```*4P`0`'````K#`!`"L```"T,`$`+@```.`P`0`-````#S$!``P````=
M,0$`!P```"HQ`0`'````,C$!``4````Z,0$`$P```$`Q`0`7````5#$!``H`
M``!L,0$`$@```'<Q`0`5````BC$!`!@```"@,0$`'````+DQ`0`8````UC$!
M``T```#O,0$`$0```/TQ`0`)````#S(!`!\````9,@$`#P```#DR`0`3````
M23(!`!````!=,@$`4P```&XR`0`M````PC(!`"8```#P,@$`!@```!<S`0`&
M````'C,!`"4````E,P$`"P```$LS`0`'````5S,!``H```!?,P$`"````&HS
M`0`)````<S,!``<```!],P$``P```(4S`0`7````B3,!``L```"A,P$`#@``
M`*TS`0`:````O#,!`!,```#7,P$`#0```.LS`0`@````^3,!`!4````:-`$`
M(````#`T`0`=````430!`!$```!O-`$`$0```($T`0`E````DS0!`!4```"Y
M-`$`!@```,\T`0`&````UC0!``@```#=-`$`#@```.8T`0`'````]30!``H`
M``#]-`$`$@````@U`0`*````&S4!`!`````F-0$`&@```#<U`0`9````4C4!
M``8```!L-0$`!0```',U`0`6````>34!`!@```"0-0$`"@```*DU`0!"````
MM#4!`$````#W-0$`"0```#@V`0`(````0C8!`!0```!+-@$`"````&`V`0`%
M````:38!``X```!O-@$`%@```'XV`0`R````E38!`!````#(-@$`)````-DV
M`0`I````_C8!`"H````H-P$`)0```%,W`0`)````>3<!``8```"#-P$`"@``
M`(HW`0`(````E3<!`#(```">-P$`+P```-$W`0`Q`````3@!`%L````S.`$`
M)P```(\X`0`P````MS@!`#T```#H.`$`0@```"8Y`0`P````:3D!`$$```":
M.0$`+````-PY`0`M````"3H!`$`````W.@$`,````'@Z`0`[````J3H!`"4`
M``#E.@$`%`````L[`0`7````(#L!`"8````X.P$`)0```%\[`0`E````A3L!
M`!,```"K.P$`#0```+\[`0`/````S3L!`!@```#=.P$`(P```/8[`0`&````
M&CP!``<````A/`$`%````"D\`0`*````/CP!``@```!)/`$`,````%(\`0`*
M````@SP!``<```"./`$`!@```)8\`0`%````G3P!``\```"C/`$`!0```+,\
M`0`+````N3P!`"H```#%/`$`$P```/`\`0`,````!#T!``@````1/0$`#```
M`!H]`0`4````)ST!``4````\/0$`!P```$(]`0`1````2CT!``D```!</0$`
M)0```&8]`0`&````C#T!``D```"3/0$`#````)T]`0`'````JCT!``,```"R
M/0$``P```+8]`0`9````NCT!`"H```#4/0$`!P```/\]`0`'````!SX!``D`
M```//@$`!P```!D^`0`H````(3X!`#4```!*/@$`(0```(`^`0`&````HCX!
M``<```"I/@$`(````+$^`0`V````TCX!`"$````)/P$`&P```"L_`0`W````
M1S\!`#<```!_/P$`'P```+<_`0`G````US\!`%4```#_/P$`/0```%5``0`T
M````DT`!`!D```#(0`$`$````.)``0`+````\T`!`!0```#_0`$`#P```!1!
M`0`/````)$$!``\````T00$`%0```$1!`0`<````6D$!`!P```!W00$`%```
M`)1!`0`0````J4$!`!````"Z00$``P```,M!`0`(````ST$!`!8```#800$`
M>0```.]!`0!4````:4(!``4```"^0@$`"````,1"`0`C````S4(!`"$```#Q
M0@$`$@```!-#`0`,````)D,!`!<````S0P$`%@```$M#`0`/````8D,!`"0`
M``!R0P$`!0```)=#`0`3````G4,!`"(```"Q0P$`$P```-1#`0`;````Z$,!
M``X````$1`$`%P```!-$`0`6````*T0!``H```!"1`$`!@```$U$`0`0````
M5$0!``@```!E1`$`#@```&Y$`0`5````?40!``D```"31`$`!0```)U$`0`.
M````HT0!``X```"R1`$`#P```,%$`0`&````T40!``0```#81`$`#0```-U$
M`0`(````ZT0!``H```#T1`$`!P```/]$`0`'````!T4!``P````/10$`"@``
M`!Q%`0`*````)T4!`!(````R10$`*0```$5%`0`B````;T4!``H```"210$`
M#````)U%`0`%````JD4!`!X```"P10$`$P```,]%`0`3````XT4!`#(```#W
M10$`0@```"I&`0`E````;48!``4```"31@$`+0```)E&`0`=````QT8!``X`
M``#E1@$`"````/1&`0`-````_48!``D````+1P$`%P```!5'`0`+````+4<!
M``D````Y1P$`%@```$-'`0`B````6D<!`!X```!]1P$`*````)Q'`0`D````
MQ4<!`!T```#J1P$`)P````A(`0`B````,$@!`"<```!32`$`0@```'M(`0`N
M````OD@!`"4```#M2`$`)P```!-)`0`=````.TD!`"\```!920$`.0```(E)
M`0`V````PTD!`"<```#Z20$`.````")*`0`_````6TH!`"4```";2@$`&P``
M`,%*`0`[````W4H!`",````92P$`%@```#U+`0`U````5$L!`"````"*2P$`
M(P```*M+`0`7````STL!`+D```#G2P$`&@```*%,`0`B````O$P!`#,```#?
M3`$`,P```!--`0`:````1TT!`#$```!B30$`'0```)1-`0`E````LDT!`#,`
M``#830$`-@````Q.`0`]````0TX!`$````"!3@$`E0```,).`0`C````6$\!
M`"8```!\3P$`'P```*-/`0`O````PT\!`"T```#S3P$`,````"%0`0!#````
M4E`!`!,```"64`$`!P```*I0`0`'````LE`!``<```"Z4`$`#````,)0`0`/
M````SU`!``\```#?4`$`&P```.]0`0`(````"U$!``0````440$`&@```!E1
M`0`,````-%$!``P```!!40$`$@```$Y1`0`-````85$!``\```!O40$`/```
M`']1`0`%````O%$!`!````#"40$`%P```--1`0`<````ZU$!`!$````(4@$`
M`@```!I2`0!,````'5(!``8```!J4@$`(0```'%2`0`7````DU(!``4```"K
M4@$`#0```+%2`0`-````OU(!``,```#-4@$`"````-%2`0`(````VE(!``X`
M``#C4@$`$P```/)2`0`/````!E,!``L````64P$`!P```")3`0`/````*E,!
M``\````Z4P$`$@```$I3`0`@````75,!`"<```!^4P$`$P```*93`0`;````
MNE,!`#(```#64P$`&P````E4`0`1````)50!`#H````W5`$`#````')4`0`&
M````?U0!`!````"&5`$`!````)=4`0`J````G%0!`"\```#'5`$`!@```/=4
M`0`)````_E0!`!L````(50$`"@```"15`0`&````+U4!`",````V50$`%P``
M`%I5`0`9````<E4!`!8```",50$`$0```*-5`0`>````M54!``@```#450$`
M"@```-U5`0`I````Z%4!`#\````25@$`"````%)6`0`6````6U8!`"8```!R
M5@$`"@```)E6`0`S````I%8!``X```#85@$`"````.=6`0`2````\%8!`$<`
M```#5P$``P```$M7`0`'````3U<!``4```!75P$`#0```%U7`0`-````:U<!
M`!````!Y5P$`$````(I7`0`7````FU<!`!,```"S5P$`&````,=7`0`6````
MX%<!``X```#W5P$`!0````98`0`(````#%@!`!(````56`$`$@```"A8`0`C
M````.U@!`"````!?6`$`$````(!8`0`'````D5@!`!,```"96`$`$````*U8
M`0`/````OE@!`#,```#.6`$`'@````)9`0`*````(5D!`(8````L60$`%@``
M`+-9`0`4````RED!``@```#?60$`!@```.A9`0`B````[UD!`#`````26@$`
M,````$-:`0`;````=%H!`"$```"06@$`(@```+):`0`8````U5H!``@```#N
M6@$`"````/=:`0`(`````%L!``8````)6P$`#P```!!;`0`.````(%L!`!``
M```O6P$`#@```$!;`0`-````3UL!``T```!=6P$`#````&M;`0`1````>%L!
M``8```"*6P$`"````)%;`0`/````FEL!`#H```"J6P$`$````.5;`0`)````
M]EL!`!H`````7`$`(0```!M<`0`F````/5P!`"4```!D7`$`'0```(I<`0`=
M````J%P!`"D```#&7`$`&P```/!<`0`7````#%T!``@````D70$`$0```"U=
M`0`-````/UT!``P```!-70$``P```%I=`0`$````7ET!``<```!C70$`$```
M`&M=`0`1````?%T!``T```".70$`%P```)Q=`0`-````M%T!``X```#"70$`
M#0```-%=`0`&````WUT!``@```#F70$`&P```.]=`0`;````"UX!`!(````G
M7@$`#````#I>`0`0````1UX!`!````!87@$`&P```&E>`0`&````A5X!``8`
M``",7@$`#0```)->`0`.````H5X!`!````"P7@$`!0```,%>`0`%````QUX!
M`!,```#-7@$`!0```.%>`0`-````YUX!`"X```#U7@$`&0```"1?`0`&````
M/E\!``8```!%7P$`!@```$Q?`0`&````4U\!``@```!:7P$`#P```&-?`0`-
M````<U\!``(```"!7P$`"````(1?`0`>````C5\!`!(```"L7P$`%0```+]?
M`0`;````U5\!``(```#Q7P$``P```/1?`0`*````^%\!``H````#8`$`"0``
M``Y@`0`%````&&`!``<````>8`$`%0```"9@`0`.````/&`!``<```!+8`$`
M"````%-@`0`$````7&`!``D```!A8`$`"````&M@`0`2````=&`!``4```"'
M8`$`#0```(U@`0`0````FV`!`!````"L8`$`!P```+U@`0`3````Q6`!``L`
M``#98`$`!P```.5@`0`8````[6`!`"$````&80$`/@```"AA`0`H````9V$!
M`"D```"080$`!P```+IA`0`*````PF$!``0```#-80$`"0```-)A`0`(````
MW&$!`!,```#E80$`#0```/EA`0`'````!V(!``X````/8@$`!P```!YB`0`$
M````)F(!`!T````K8@$`!0```$EB`0`.````3V(!``<```!>8@$`!0```&9B
M`0`%````;&(!`"$```!R8@$`#@```)1B`0`8````HV(!``<```"\8@$`!@``
M`,1B`0`*````RV(!``<```#68@$`&P```-YB`0`&````^F(!``4````!8P$`
M!P````=C`0`.````#V,!``8````>8P$`#P```"5C`0`(````-6,!``D````^
M8P$`!0```$AC`0`]````3F,!`#D```",8P$`/````,9C`0`H`````V0!`$(`
M```L9`$`,P```&]D`0`L````HV0!`#X```#09`$`,`````]E`0`M````0&4!
M`"$```!N90$`'0```)!E`0`)````KF4!``L```"X90$`"0```,1E`0`*````
MSF4!`"H```#990$`)P````1F`0`Q````+&8!``D```!>9@$`&@```&AF`0`F
M````@V8!``T```"J9@$`"0```+AF`0`*````PF8!``L```#-9@$`$0```-EF
M`0`5````ZV8!`#8````!9P$`=0```#AG`0`+````KF<!``4```"Z9P$`#@``
M`,!G`0`2````SV<!``\```#B9P$`&P```/)G`0`I````#F@!`(H````X:`$`
M!@```,-H`0`5````RF@!``H```#@:`$`%@```.MH`0`A`````FD!`!H````D
M:0$`0@```#]I`0`3````@FD!`#(```"6:0$`0````,EI`0`?````"FH!``T`
M```J:@$`%````#AJ`0`C````36H!`!@```!Q:@$`%@```(IJ`0`4````H6H!
M`"4```"V:@$`'0```-QJ`0`<````^FH!`!P````7:P$`&````#1K`0`3````
M36L!`"$```!A:P$`)0```(-K`0`?````J6L!`!D```#):P$`&````.-K`0`4
M````_&L!`!H````1;`$`'````"QL`0`:````26P!`!H```!D;`$`#P```']L
M`0`+````CVP!`!@```";;`$`!````+1L`0`%````N6P!`!$```"_;`$`!@``
M`-%L`0`*````V&P!``<```#C;`$`!P```.ML`0`&````\VP!``@```#Z;`$`
M%@````-M`0`&````&FT!``D````A;0$`!0```"MM`0`%````,6T!``D````W
M;0$`$@```$%M`0`&````5&T!`"0```!;;0$`#@```(!M`0`/````CVT!``T`
M``"?;0$`$````*UM`0`,````OFT!`!````#+;0$`,@```-QM`0`&````#VX!
M``D````6;@$`*````"!N`0`2````26X!`!$```!<;@$`!P```&YN`0`*````
M=FX!``4```"!;@$`)````(=N`0`/````K&X!`!@```"\;@$`$````-5N`0`3
M````YFX!`!,```#Z;@$`&`````YO`0`6````)V\!``@````^;P$`!0```$=O
M`0`'````36\!``T```!5;P$`$0```&-O`0`&````=6\!``4```!\;P$`"```
M`()O`0`'````BV\!``X```"3;P$`#````*)O`0`*````KV\!`!$```"Z;P$`
M$````,QO`0`%````W6\!`!````#C;P$`"@```/1O`0`.````_V\!``@````.
M<`$`0P```!=P`0`(````6W`!``\```!D<`$`(@```'1P`0`6````EW`!`!,`
M``"N<`$`#````,)P`0`/````SW`!``\```#?<`$`$0```.]P`0`1`````7$!
M``X````3<0$`#@```")Q`0`-````,7$!`"`````_<0$`(0```&!Q`0`=````
M@G$!``H```"@<0$`!@```*MQ`0`*````LG$!``T```"]<0$`#````,MQ`0`%
M````V'$!``<```#><0$`'0```.9Q`0`&````!'(!``<````+<@$`$P```!-R
M`0!!````)W(!`!$```!I<@$`#@```'MR`0`(````BG(!``4```"3<@$`"@``
M`)ER`0`"````I'(!`!````"G<@$`)P```+AR`0`#````X'(!``4```#D<@$`
M+````.IR`0`*````%W,!``@````B<P$`$@```"MS`0`4````/G,!``8```!3
M<P$`"````%IS`0`'````8W,!``0```!K<P$`!0```'!S`0!D````=G,!``\`
M``#;<P$`$@```.MS`0`2````_G,!``4````1=`$`)0```!=T`0`Y````/70!
M`!,```!W=`$`"@```(MT`0`-````EG0!``L```"D=`$`"0```+!T`0`8````
MNG0!`"@```#3=`$`)0```/QT`0`D````(G4!`"(```!'=0$`$P```&IU`0`#
M````?G4!``<```""=0$`$P```(IU`0`&````GG4!``L```"E=0$`"@```+%U
M`0!?````O'4!`!8````<=@$`#@```#-V`0`+````0G8!`!L```!.=@$`+P``
M`&IV`0`3````FG8!``@```"N=@$`&@```+=V`0`I````TG8!``D```#\=@$`
M!@````9W`0`@````#7<!``P````N=P$`)````#MW`0`C````8'<!`"8```"$
M=P$`"````*MW`0`-````M'<!`"0```#"=P$`&0```.=W`0`O`````7@!`!,`
M```Q>`$``@```$5X`0`.````2'@!``8```!7>`$`#P```%YX`0`&````;G@!
M`!0```!U>`$`!@```(IX`0`)````D7@!``T```";>`$`"````*EX`0`*````
MLG@!``L```"]>`$`,P```,EX`0`&````_7@!``\````$>0$`$@```!1Y`0`>
M````)WD!`!$```!&>0$`#@```%AY`0`1````9WD!`!(```!Y>0$`#@```(QY
M`0`.````FWD!``X```"J>0$`"````+EY`0`=````PGD!`!8```#@>0$`$0``
M`/=Y`0`*````"7H!`!8````4>@$`"@```"MZ`0`7````-GH!``<```!.>@$`
M$@```%9Z`0`#````:7H!``@```!M>@$`!0```'9Z`0`%````?'H!``H```""
M>@$`$0```(UZ`0`4````GWH!`!L```"T>@$`&P```-!Z`0`9````['H!`!@`
M```&>P$`&P```!][`0`8````.WL!`!@```!4>P$`"````&U[`0`&````=GL!
M``\```!]>P$`#P```(U[`0`)````G7L!`!4```"G>P$`#@```+U[`0`*````
MS'L!`!D```#7>P$`%P```/%[`0`&````"7P!`!,````0?`$`"0```"1\`0`3
M````+GP!`!(```!"?`$`"@```%5\`0`)````8'P!``4```!J?`$`"````'!\
M`0`%````>7P!``0```!_?`$`!P```(1\`0`\````C'P!`"T```#)?`$`$P``
M`/=\`0`E````"WT!`"8````Q?0$`#@```%A]`0`O````9WT!`#0```"7?0$`
M(@```,Q]`0`C````[WT!`"P````3?@$`%0```$!^`0`.````5GX!`!8```!E
M?@$`#P```'Q^`0`5````C'X!`!4```"B?@$`'@```+A^`0`<````UWX!`"$`
M``#T?@$`&0```!9_`0!T````,'\!`!X```"E?P$`'P```,1_`0`9````Y'\!
M`!````#^?P$`*0````^``0`U````.8`!`",```!O@`$`#@```).``0!/````
MHH`!`$H```#R@`$`!P```#V!`0`6````18$!`!````!<@0$`#P```&V!`0`7
M````?8$!``D```"5@0$`"@```)^!`0`'````JH$!``D```"R@0$`#````+R!
M`0`+````R8$!``<```#5@0$`+@```-V!`0`(````#((!``@````5@@$`#P``
M`!Z"`0`1````+H(!``\```!`@@$`0P```%""`0`&````E((!`!4```";@@$`
M"````+&"`0`'````NH(!``<```#"@@$`*@```,J"`0`+````]8(!`!@````!
M@P$`!````!J#`0`R````'X,!`!0```!2@P$`)0```&>#`0!>````C8,!`!(`
M``#L@P$`1````/^#`0`1````1(0!``D```!6A`$`#P```&"$`0`,````<(0!
M`!0```!]A`$`#````)*$`0`:````GX0!`!8```"ZA`$`!0```-&$`0`2````
MUX0!`!,```#JA`$`$P```/Z$`0`6````$H4!`!0````IA0$`%````#Z%`0`/
M````4X4!`!X```!CA0$`"````(*%`0`*````BX4!`!,```"6A0$`#0```*J%
M`0`/````N(4!``X```#(A0$`&````->%`0`.````\(4!`!````#_A0$`&P``
M`!"&`0`*````+(8!``@````WA@$`!0```$"&`0`>````1H8!``8```!EA@$`
M$@```&R&`0`(````?X8!``X```"(A@$`!0```)>&`0`:````G88!`!````"X
MA@$`)@```,F&`0`2````\(8!``8````#AP$`!P````J'`0`6````$H<!``<`
M```IAP$`$@```#&'`0`&````1(<!`!D```!+AP$`)@```&6'`0`*````C(<!
M`!T```"7AP$`&````+6'`0`*````SH<!`!8```#9AP$`$@```/"'`0`$````
M`X@!``P````(B`$`"````!6(`0`'````'H@!``L````FB`$`"````#*(`0`B
M````.X@!`"@```!>B`$`)P```(>(`0!$````KX@!`"(```#TB`$`)P```!>)
M`0`R````/XD!`&8```!RB0$`)````-F)`0`'````_HD!``@````&B@$`!@``
M``^*`0`+````%HH!`"8````BB@$`&P```$F*`0`4````98H!`#````!ZB@$`
M!````*N*`0`7````L(H!``8```#(B@$`"0```,^*`0`3````V8H!``X```#M
MB@$`!P```/R*`0`5````!(L!``@````:BP$`$P```".+`0`,````-XL!`!D`
M``!$BP$`&P```%Z+`0`U````>HL!``D```"PBP$`%````+J+`0`%````SXL!
M``D```#5BP$`!0```-^+`0`;````Y8L!``X````!C`$`!````!",`0`,````
M%8P!``T````BC`$`!0```#",`0`,````-HP!``L```!#C`$`!@```$^,`0`(
M````5HP!``0```!?C`$`#P```&2,`0!'````=(P!`&D```"\C`$`!P```":-
M`0`B````+HT!``\```!1C0$`!0```&&-`0`1````9XT!``\```!YC0$`"```
M`(F-`0`4````DHT!`"P```"GC0$`"````-2-`0`0````W8T!``P```#NC0$`
M.````/N-`0`3````-(X!`!@```!(C@$`-````&&.`0`>````EHX!`#@```"U
MC@$`.0```.Z.`0`E````*(\!`!(```!.CP$`"0```&&/`0`/````:X\!`!<`
M``![CP$`&0```)./`0`'````K8\!`!0```"UCP$`&P```,J/`0`/````YH\!
M`!0```#VCP$`*@````N0`0`&````-I`!``T````]D`$`#P```$N0`0`(````
M6Y`!``@```!DD`$`#````&V0`0`-````>I`!``X```"(D`$`!P```)>0`0`&
M````GY`!``8```"FD`$`'````*V0`0`:````RI`!`!@```#ED`$`#@```/Z0
M`0`*````#9$!`"$````8D0$``P```#J1`0`%````/I$!``H```!$D0$``@``
M`$^1`0`,````4I$!`!8```!?D0$`"P```':1`0`:````@I$!`!H```"=D0$`
M!0```+B1`0`*````OI$!`!0```#)D0$`%@```-Z1`0`/````]9$!``8````%
MD@$`"P````R2`0`*````&)(!`!`````CD@$`7@```#22`0`:````DY(!`#,`
M``"ND@$`'0```.*2`0`'`````),!``8````(DP$`"0````^3`0`/````&9,!
M``P````IDP$`)0```#:3`0`6````7),!`!````!SDP$`)P```(23`0`*````
MK),!`!,```"WDP$`#@```,N3`0`-````VI,!`&H```#HDP$`%@```%.4`0`5
M````:I0!`"\```"`E`$`%````+"4`0`2````Q90!`!\```#8E`$`(0```/B4
M`0`/````&I4!`!L````JE0$`"P```$:5`0`'````4I4!``<```!:E0$`"0``
M`&*5`0`4````;)4!`!(```"!E0$`,@```)25`0`3````QY4!`!,```#;E0$`
M!````.^5`0`'````])4!`$\```#\E0$`2@```$R6`0`L````EY8!`#T```#$
ME@$`!P````*7`0`Q````"I<!`"4````\EP$`"````&*7`0`+````:Y<!``\`
M``!WEP$`*````(>7`0`'````L)<!`$P```"XEP$`*`````68`0`E````+I@!
M`!P```!4F`$`*@```'&8`0`A````G)@!``\```"^F`$`!0```,Z8`0`-````
MU)@!``X```#BF`$`$````/&8`0`&`````ID!`"X````)F0$`#````#B9`0`*
M````19D!``8```!0F0$`%````%>9`0`(````;)D!``@```!UF0$`%@```'Z9
M`0`)````E9D!``D```"?F0$`!````*F9`0`-````KID!``T```"\F0$`%0``
M`,J9`0`6````X)D!``X```#WF0$`(@````::`0`0````*9H!``@````ZF@$`
M$````$.:`0`6````5)H!``L```!KF@$`#0```'>:`0`<````A9H!`"<```"B
MF@$`#@```,J:`0`+````V9H!``@```#EF@$`$@```.Z:`0`5`````9L!``<`
M```7FP$`"@```!^;`0`*````*IL!``T````UFP$`#0```$.;`0`4````49L!
M``8```!FFP$`$0```&V;`0`,````?YL!`!0```",FP$`&P```*&;`0`"````
MO9L!`!8```#`FP$`!@```->;`0`)````WIL!`%\```#HFP$`!0```$B<`0`B
M````3IP!`"<```!QG`$`&P```)F<`0`G````M9P!`$\```#=G`$`,@```"V=
M`0`]````8)T!`"$```">G0$`&````,"=`0`%````V9T!``T```#?G0$`#0``
M`.V=`0`'````^YT!``T````#G@$`$P```!&>`0`-````)9X!``T````SG@$`
M#@```$&>`0`'````4)X!``<```!8G@$`!P```&">`0`5````:)X!``4```!^
MG@$`"````(2>`0`&````C9X!`"$```"4G@$`#@```+:>`0`B````Q9X!`!H`
M``#HG@$`!P````.?`0`<````"Y\!`!(````HGP$`#````#N?`0`1````2)\!
M``8```!:GP$`&````&&?`0`,````>I\!`!X```"'GP$`"````*:?`0`4````
MKY\!`!D```#$GP$`"P```-Z?`0`-````ZI\!`"@```#XGP$`%@```"&@`0`3
M````.*`!``@```!,H`$`#0```%6@`0`"````8Z`!``8```!FH`$`$P```&V@
M`0`9````@:`!`"<```";H`$`)P```,.@`0`N````ZZ`!`"L````:H0$`-P``
M`$:A`0!!````?J$!`$<```#`H0$`3@````BB`0`^````5Z(!`!@```"6H@$`
M,P```*^B`0`N````XZ(!`"\````2HP$`)0```$*C`0`?````:*,!`#T```"(
MHP$`>@```,:C`0`T````0:0!`"````!VI`$`-P```)>D`0!?````SZ0!`#X`
M```OI0$`,P```&ZE`0`Q````HJ4!`!\```#4I0$`&P```/2E`0`@````$*8!
M`#`````QI@$`/@```&*F`0`G````H:8!`!@```#)I@$`&@```.*F`0`:````
M_:8!`!X````8IP$`5@```#>G`0`U````CJ<!`#8```#$IP$`-@```/NG`0`P
M````,J@!`$@```!CJ`$`<````*RH`0!&````':D!`"H```!DJ0$`+@```(^I
M`0`N````OJD!`%@```#MJ0$`8````$:J`0!/````IZH!`$D```#WJ@$`)```
M`$&K`0`9````9JL!`!P```"`JP$`(P```)VK`0!$````P:L!`#T````&K`$`
M0P```$2L`0"-````B*P!`!0````6K0$`*````"NM`0`N````5*T!`",```"#
MK0$`1@```*>M`0`@````[JT!`$L````/K@$`'P```%NN`0`)````>ZX!`+H`
M``"%K@$`0P```$"O`0`?````A*\!`#$```"DKP$`'@```-:O`0`@````]:\!
M`"@````6L`$`!0```#^P`0`'````1;`!``0```!-L`$`#0```%*P`0`,````
M8+`!``P```!ML`$`!@```'JP`0`"````@;`!`&T```"$L`$``P```/*P`0`$
M````]K`!``<```#[L`$`!P````.Q`0`%````"[$!`"P````1L0$`#````#ZQ
M`0`2````2[$!``D```!>L0$``P```&BQ`0`(````;+$!``<```!UL0$`%```
M`'VQ`0`,````DK$!`!<```"?L0$`!@```+>Q`0`8````OK$!``P```#7L0$`
M`P```.2Q`0`O````Z+$!``8````8L@$`"````!^R`0`=````*+(!`#$```!&
ML@$`+````'BR`0`:````I;(!`!P```#`L@$`*0```-VR`0`;````![,!`!\`
M```CLP$`(````$.S`0`?````9+,!`"````"$LP$`(````*6S`0`@````QK,!
M`!P```#GLP$`*`````2T`0`<````+;0!`"@```!*M`$`&P```'.T`0`;````
MC[0!`",```"KM`$`(0```,^T`0`@````\;0!`"$````2M0$`&P```#2U`0`E
M````4+4!`"@```!VM0$`&@```)^U`0`A````NK4!`!X```#<M0$`,````/NU
M`0`>````++8!`"4```!+M@$`*0```'&V`0`C````F[8!`"@```"_M@$`+@``
M`.BV`0`B````%[<!`"8````ZMP$`*````&&W`0`I````BK<!`",```"TMP$`
M&@```-BW`0`K````\[<!`#,````?N`$`)````%.X`0`J````>+@!`"H```"C
MN`$`-````,ZX`0`4`````[D!`#$````8N0$`,@```$JY`0`,````?;D!``X`
M``"*N0$`&0```)FY`0`4````L[D!`!$```#(N0$`)@```-JY`0`%`````;H!
M``D````'N@$`)P```!&Z`0`Q````.;H!`!4```!KN@$`(P```(&Z`0`*````
MI;H!`!4```"PN@$`"````,:Z`0`+````S[H!`!4```#;N@$`$0```/&Z`0`@
M`````[L!``<````DNP$`.0```"R[`0`'````9KL!`!,```!NNP$`"P```(*[
M`0!#````CKL!``D```#2NP$`'P```-R[`0`4````_+L!`!<````1O`$`%P``
M`"F\`0`X````0;P!`!T```!ZO`$`$````)B\`0`G````J;P!`!(```#1O`$`
M$@```.2\`0`<````][P!``H````4O0$`%@```!^]`0`)````-KT!`"$```!`
MO0$`"@```&*]`0`B````;;T!`"@```"0O0$`"0```+F]`0`;````P[T!``<`
M``#?O0$`"@```.>]`0`)````\KT!`$````#\O0$`"@```#V^`0`*````2+X!
M``L```!3O@$`!P```%^^`0`3````9[X!``D```![O@$`'P```(6^`0`:````
MI;X!`!0```#`O@$`"@```-6^`0`+````X+X!`!H```#LO@$`"0````>_`0`L
M````$;\!``X````^OP$`$````$V_`0`)````7K\!``(```!HOP$`$0```&N_
M`0`:````?;\!``L```"8OP$`!0```*2_`0`-````JK\!``@```"XOP$`"P``
M`,&_`0`K````S;\!``\```#YOP$`%`````G``0`4````'L`!``X````SP`$`
M+@```$+``0`9````<<`!`!D```"+P`$`'````*7``0`0````PL`!`#(```#3
MP`$`%`````;!`0!`````&\$!``0```!<P0$`!P```&'!`0`0````:<$!`!8`
M``!ZP0$`!@```)'!`0`'````F,$!``<```"@P0$`#````*C!`0`'````M<$!
M`!````"]P0$`$0```,[!`0!!````X,$!`#8````BP@$`*P```%G"`0`%````
MA<(!`!<```"+P@$`(@```*/"`0`>````QL(!`!X```#EP@$`$@````3#`0`"
M````%\,!``0````:PP$`$````!_#`0`%````,,,!``4````VPP$``P```#S#
M`0`0````0,,!`"\```!1PP$`$0```('#`0`B````D\,!`#````"VPP$`4@``
M`.?#`0`4````.L0!`&\```!/Q`$`(@```+_$`0!"````XL0!`!X````EQ0$`
M2@```$3%`0`I````C\4!`#X```"YQ0$`0````/C%`0`\````.<8!`$````!V
MQ@$`*@```+?&`0`>````XL8!`"X````!QP$`2````##'`0`8````><<!``P`
M``"2QP$`#0```)_'`0!M````K<<!``H````;R`$`JP```";(`0!S````TL@!
M`'$```!&R0$`)@```+C)`0!L````W\D!`!L```!,R@$`+@```&C*`0`3````
ME\H!``H```"KR@$`&0```+;*`0`=````T,H!`#8```#NR@$`)@```"7+`0`B
M````3,L!`&4```!ORP$`%P```-7+`0`:````[<L!``L````(S`$`!````!3,
M`0`'````&<P!``@````AS`$`&0```"K,`0`4````1,P!`!P```!9S`$`)P``
M`';,`0`2````GLP!``0```"QS`$`"0```+;,`0`(````P,P!``8```#)S`$`
M!P```-#,`0`&````V,P!``D```#?S`$`"@```.G,`0`(````],P!``L```#]
MS`$`!@````G-`0`0````$,T!``<````AS0$`!0```"G-`0`C````+\T!`!8`
M``!3S0$`"0```&K-`0`@````=,T!`!8```"5S0$`)@```*S-`0`6````T\T!
M``4```#JS0$`&P```/#-`0`(````#,X!``@````5S@$`$@```![.`0`&````
M,<X!``(````XS@$``@```#O.`0`6````/LX!``4```!5S@$`#0```%O.`0`5
M````:<X!`!D```!_S@$`!P```)G.`0`O````H<X!``(```#1S@$``P```-3.
M`0`-````V,X!``X```#FS@$`"````/7.`0`8````_LX!`!P````7SP$`"P``
M`#3/`0`3````0,\!``\```!4SP$`%````&3/`0`"````><\!``@```!\SP$`
M$0```(7/`0`/````E\\!`!````"GSP$`)````+C/`0`&````W<\!``H```#D
MSP$`$@```._/`0`)`````M`!``(````,T`$`"P````_0`0`!````[0```-<#
M``!I````;0$```````#W!0``*`8``$<!``!+`P``Z`4```````#;`P``X04`
M`&H```"A!````````&<#```9!```0P4``*T%``!G`0``(08`````````````
MD0$``),%`````````@$``,@%``!K!````````-0$``"U!0``OP```"4!```S
M!```TP0``$$````*!@``GP```&(!```F`0``I@$```````",!```LP``````
M````````2`$```````!.`@````````````".`0````````````!9!@``````
M``````````````````````!`````;`4``/D%`````````````(4!```V!```
M(`0```````!W`0``8P4```````"*!@``W@4``%8&```9`@````````(#````
M`````````!L!``")`@``X@$``&D#````````J@(````````?!0``Q@4``+L$
M```]````Y@0``$T#``">````704`````````````*````#8"````````H```
M`%\!```_!@``'`(``````````````````&T"``![!0```````%0#``#:`@``
M@0(``$L&````````*`$``%4#``"*`P``)P8``.P!``````````````````!W
M!@``-````*0!````!0``H`(``&@!````````9@0``(P!````````LP,`````
M```Y`0``[04``"<!``#)`0``-P4``%(#``!3`P``NP,``*\$```G!0``%P``
M`+,$``!1!@```````#X!``#Y!```;@$``#H&```M`P``5@```/T!``!V`0``
M`@0``%\```#Q````7`8``/$!````````U`(``+X#```;!0``?0(``&0$``!W
M!0````````````#N`@``[`0``+\#```Z`@```````&\$```,!0``)0```%P$
M```[````=`4``,$$``#O`0``(P8``#D%``#,`@``-@8``,D`````````````
M`.@"`````````````)P$``#T!```?@````````"\`@``J`````````!'````
M:@8``'(```"%!0```````(8%``!<!0``V0```(@%```^````[P0``"D$``"7
M`````````-(```!>````'@0```````!$`@```````)\%````````00(``+T!
M````````Q@$``"X"``#!`@``:P8``"T"`````````````/(%````````=P(`
M`+@#````````3@,```4````V`0``5`$``(D$``!F`P``J04```````!+````
ME08``&H!``!A`P```````%$$```%!@``````````````````"@0```````"U
M!```C`(```````"I`P``1@,``#H```!8`0```````(<&``"-`0``K00``'T&
M``"9`0``+P,```````#T`@``E@(```````#%`@``K0```$D&````````(0,`
M`,0`````````E`8``/<$```"`@``)@,``+(%``!]`````````*<$``!#!@``
MO`0``",````J!0```````+P#``!#`@``5@(```````!H`@``900```````"@
M`P``104``$`$``!5!```I00```T````!`P``I`(``%\#``"T!0```P(``'4#
M````````=@,```X#``#'`@``9P0```,%```W`0``F08``(X%``"L!0``6`0`
M`'\&````````RP```*X```#'`0```````.4"``````````````````#=`0``
M8P```/X#``#``P```````$H"```V!0````````````#^`0```````)0%````
M````.@4```````#_````Z`,``'@&``!/`0``B`(``&P&``"5`P``YP$`````
M````````$@0``',%``"T`0``\@$``!(`````````)@```#0#```&`@``E@0`
M`",%``````````````````#C`@``-`8``,,#```$!````````%H&``#Z`0``
M`````!P#````````#P,``*0$````````:00``(H```#A`@``J0```,P`````
M````>00``'\$````````XP```)P`````````-`$````````O!@``!0(``*`!
M```8`@``)`(``'(#``"=!0``^0$```P"````````*P(``-$$``!2````````
M`(L#````````R0(``'X#```R`@``"@4``'T$``"(!`````````````"3`@``
M300``*X"``#,!0``E@8``&X```"G`@```````#X#``"F!```S@4``!8#````
M````'`$``-$#``"'````$0```(<%```3!````````(T`````````'`4``&T$
M``!V`@``H@$```````!3````.````%L"``!R`@``5@4```````"Q!0``TP``
M`,\```!L`P``*@(`````````````3`4``#0$``#S`````````"<```".`P``
M`````!`!````````(@(``"D%````````N0`````````%!0```````!H&``!3
M!0```````'@```#B````[@4```````!-``````````4#````````````````
M``#\`P``1P4``/0!```>````R`0``(X&````````@P```%4&``#V`P``^@,`
M`-X$``![!```O@4``!\!`````````````)P!````````3`(``$H&```<````
MWP0``#X%``"J!```F`(``-`!``#W`@``>P$``'X%```N````)0,``%<#``!(
M!````````+,!```7!````````#,```#/!```D`$``(\%````````R````#T"
M``!L`@``)P,```````#U`P``?0,```````!+!0``8`8``.D"``!\`P``$P,`
M`)<%``#M`@``U@4``,@"````````;@(```````#[!```"0$``!H#```-!0``
M`````$4&````````MP````````#D`@``V0$``)`"``!_!0``60(```````!2
M!@``!`8``/`%```0````&0$``-`"``#L````\00``%T```#K````40(`````
M``";`@```````-P"````````S@$``-($```N!`````````````"G!0``K```
M`*P$````````'0(``!8&``#"`@``;P(```````"X`0```````.8"``#X!0``
MY0,``/(```#%`0``^P4``(8&````````UP0```````!^`0``.@,`````````
M````7````*8#``#G!````````-4%````````4`(````````^`@``P`4``#T%
M````````T@$```````#-!```)04``)H```!2`@``G0$``,`$``">`0``:P$`
M`(H!```:`@``BP4``!@#``"=`@``D0```&T`````````@`0``#D#````````
M`````!4%``#D!```(`8```0#``![`P``Z@4``/@!````````<P(```````#M
M`0``800``%<"```H`@``I0,``*4%``#-`P``3`,`````````````>`0`````
M``!G````5`8``((&``!1!0```````#L!````````!P$``%$!````````+`8`
M`#0%````````OP$``!P&``#``0``50(```\%````````#@```"H&``#N`P``
M'P,``-X"````````_0,``(D%``#!`P``T`,``"`%```-`P``6@0``.@$``"\
M!0``CP0````````_`0``"0```$X!```[!@``4P(```````#E````GP0``.H"
M``!H`P``U@(``&X%``"^````E`0``*(%`````````````'H#``"-!@``5@0`
M``````"Y`0```````(8"```$`0``3P```$P&```J`P``R04``)L#````````
M8````(T"```5````+@8``$H!````````1P0```````#4````-P8``'`"``#1
M`@``F`$``/\"``!Z`@``0@0``-(#``!&!0``0P$```````#W`````````#(%
M``#_!```EP8``+H$``#A!```0`$``-`%````````L@,````````U`P``C`8`
M``````#:!```Z0```-D"``!R!@``/`0``*H`````````YP,``%T$```6`@``
M=`8``&\%``!_`@``B@4```````"1!0``SP(``&4"``"H`0``GP$````````!
M!```<`,``!$$``!R!```A`(``.`%``".!```C@(`````````````"P``````
M```C!````````!<&```W!````````&0%```D````ZP0```L"````````````
M```````3!@```````$P$````````#`0``(@!``"!!@```````*4"````````
ML`4``$$&````````Y@4``(<!``"8````KP```.8!````````.P4``"$```#^
M!````````-D#````````6`(``,@!``!#!```^`(``+8%```R!@``VP(``%<!
M```+!@```````#4$``````````````````#1`0``+P(````````"````X@0`
M``````#S!```9@4```````#L`@```````#,&``">!```E@```/L"``"3`0``
M``````````#^````B@0``(`%``!\`@````````````!8!0``_`4```P!````
M````M@(``$(`````````+P0``',&``!!!``````````````C`P```````(L&
M``"V!```V`(``)T`````````]@$``$`#```'``````````````"/`P``+@$`
M`!D#```\````D@,`````````````C`````````"R!```?0$``)P#``!X`P``
M=04``)0```"5````<08``#T!``"'!```JP0```````!3`0``````````````
M!```U@,````````$!0````````````"$````G@(``*4```""`0``!@$``,P$
M```(`P```P```+\"```#!```V@$``*H#``!;````8`0```,#``"(!@``G@,`
M`&,$``"!`````````$\#``"Z``````````````#=`P``-P,``!\&````````
M&@$``&@$```T`@``XP$```8&``!@!0``ZP,``*(#``#[`0```````'X"``!S
M````*P,``/\!``"V`0``^@4``.L"````````+04```````"[!0``;@8``,H$
M``"W!0````````````!$!@```````&($```3`0``2@,``',$``"Q`@``````
M`-P#```X`P``+`(```````#!!0``@P$``"0%````````^0(``%X$``!;!@``
M`08``&0`````````Y`,``(T$``!0````6`8```````"0!@``AP(``$,#``#U
M````J0$``/<#````````H0```)4%``"%`P``5P```-X```!0`0```````-0%
M``#D````;P,``%X&``"C!0``#P0``(L!``">!0``W04````````0`@``3P8`
M`.$!``";!@```````(4&``"#!0``]@```.T$```.`0```````$L$``"2`0``
MHP0``#$&````````"@````````!``@``Z@,``',#``!+`0``^0````````"W
M`P``D0,``-<"``!@`0```````&<&``!I`@``P`(``,L#```Q`0``````````
M````````Z00```X%``!'`@``ZP4``#H!``#2!0``@0$``.D!``#Z````#P(`
M````````````,0(```````"T`P````````````!A!@```````,L$``"!`P``
M@P,`````````````P````%H%````````QP`````"````````(0(``*L%````
M````N`4``*$%```L!```XP4``"($``!9!0``N00``!8%``!P!0``?````#<"
M`````````````&@```#*`@```````/T```"<`@``6P$``!@$```I`P``````
M`(@#```2`@``2````*P"``#*``````````````!&````1`4```@%````````
M``````,!```P!````````)D$````````>@$``"4$``#$`P``10$``&\`````
M````&P`````````\!0``TP(```````![!@``FP```/0%```:````20```$4$
M````````(@8``,X``````````````"X%``#Q!0````````````!:`@``````
M`&L```!?!0```````'L```#W`0```````/4!``#9!```J`0`````````````
M$@$```````#P````2`4``)(`````````<0```&8```":!````````)("``!-
M!@````````````````````````````"&!```UP4``"\%```3````EP0``/0`
M````````KP(``(0$``!9!```\@,``#`#``````````````X$``#B`@``Y`4`
M`&`#```B`P```````-T"``"Q!```'@(``"P````J!```J`4```$!``"\````
MJP$``&(%`````````@4``````````````````#,"````````80```*L"``"%
M!```3@4```8%`````````````'`$``#]!```W````)L$```4!```%0(``/4$
M``""````HP```-X!````````E`,``"T$``"G`P``?@8``"P!``#"!```Y0$`
M`#````!X!0``@`,``$(&```_`@``Y00```<%``""!0``9P4`````````````
M200``!@&````````5@$``-,!```/!@``D`4```````"2!@``PP0``-\"``#"
M`0``J00````#``!I!@``L`0``)$"``!U!@``%@```&("```E!@``````````
M```Q````"@,``)P&````````6P4``'P%````````0@(```,&````````]`,`
M``````#'`P`````````````V`P```````*T#``#*!0``EP$``.4%````````
M`````((#``"0`````````.X$````````.@0```````"N!0``C04``+0`````
M````2`8``$@#````````9@(```````"Z`P``8@8``.`"``#Z!````````*X!
M``#:!0``)P0``!0```"5`@```````/P```"-`P``0@,``(\&````````KP4`
M`$P!``"$`P``_@(``-0#``!A`@``"`````````":`P```````+`"```E`@``
M1@$````````U!@```````'4`````````/`$``&,#``#)`P```````(8`````
M````Z04``"H`````````:P,``*(```"D!0``10```#@"``"L`0``4@0``(4"
M``!=`@`````````````;!@``)@0``)D%``#<!0``CP(`````````````A@,`
M`$H$``!$````%`,`````````````)`,```````!>`0``JP,``*H!````````
M>0$`````````````=`,```T!``!Q!````````!L$````````U@0`````````
M````908``!\````````````````````A`0``F@8``/P$``!R!0``````````
M``!O!@``/@0``)D"``#$`@``RP(``!T%``#%!0````````````!D`0``B@(`
M`&@%``#K`0``L@$``-$```"P`P``>0(``!$#``#Z`@``7P8`````````````
M*@$``%P#````````P@````````#=!```\0,``#<```#!````$08``#(````6
M`0```````$\%``!3!@```````*,"````````2P(``%D#```6!````````"(%
M``"@!```:@4``(P#````````+`4``/8"````````L0,`````````````.00`
M```````_!```I````"0!``"+`````````+T"``#3!0``F`0``&4%``#[````
M`````%@#```+`P``>@4``%H```````````````````#?`0``O@0```````"X
M````#P$``+$`````````(P$````````S`0```````"D"``"0!```50$`````
M`````````````*$"``"?`@``9`(``.0!``!_`0```````*\!``"[`@``:P4`
M``````!I!0````````8```!#````*0$``,X$``#?`P``0`4``!L#``!Y`P``
MS0$``(<#````````3@8``'\```!2!0``F0```/4"``"V````````````````
M`````````#`"`````````````*8````5`P``Z@$``!@```!$!```````````
M``"``0``%`4``.`#``!J`P``IP$``!T&```+!0``6@,``$P````K!@``````
M`/,"``"U`P``1@0``%`#``#8````<`$``#P#````````B0```&H$````````
M```````````(!```K@,``-D%``#6``````````````"R`````````"$%``#!
M`0````````````"1!```P@4``'$#``#H`0``"04``,@#``#;`0``V`0``&8&
M``""`@``8P(```````"3!@``WP```%0"``#?!0``20$```````!F`0``7`$`
M`%D```!2`0``40,``#4"``!\`0``N04``*P#``!B`P```````,\!``"6`0``
M`````/T"``#$!```O0```-@!``!>`P``!P,```$%``"P````[P4```````"X
M`@``Z@```"@%``````````````````"4`0``$0(``#(!``!!`0``W0```/@#
M``"Y`@``$04```````"M`0``D@0``#4!``!-!0``1`,`````````````````
M`,X"```X!0```````"8&``"M`@```````+H"``!M`P```````!T$``!!`P``
M`````-H```#C!```40```!\"``#4`0``!@0``),#``#C`P``1P8``)8#````
M````(@````````!X`0``!P8``"`#```&`P``M0$``-H#``":`@``<0$``+`!
M``!=`0```````&4!``!.````,00``/P!````````/00```````"W`@``````
M`%\$```(`@``?P,``#,%``#*`P```````*,#````````QP4``*4!``!3!```
M$P4``-,#``!)!0``JP```#L$````````6`````````!)`P```````+D#``!L
M`0``MP$``#D&``";!0``9`,``%`%````````\@(``,,!````````!P0``)<#
M```K`````````'X$```(`0````````````"G````>P(``.\#```*`0``,04`
M`'<#``"&`0``#`8```L$``##!0````````````"7`@``@00``,4#````````
M"08``(4```"Z!0``BP(``'0"```_````,P,``(X```#&`````````/($```[
M`P``LP4``&(````4`@```````$H````K!```;@,``/$"``#P!````````'P$
M``!W````&04``,,`````````3@0``)T#``!E`P``OP4``&4```!M!0``.0(`
M``````"T!```+0````D"`````````````&0&``!7!0``>`(``#\#``#_`P``
M;P$``)(%``#;````"@(``-4"````````(@$`````````````H0,`````````
M!@``W`0``'0```"U````(P(``,H!``#5`0``8P8```````"!!0``O@(```(&
M``!W!````````!`%``!6`P``^P,``.``````````!`(```````#0````M@,`
M``````"B!```6@$``$0!``!K`@``#````!$!``"3````<P$``(L$````````
M.`8``+L````9!@``+0$```````!Z````_04``,0%```2!@````````X"``#I
M`P``^`0``&$%``":!0``!P(``-X#``````````````````!T!````````(D!
M````````FP$``%4%``"I`@`````````````3`@```````,,"```Y````!00`
M`%<&``!G`@````````````"U`@``YP4``,<$````````7@(``$$%```>!0``
MN`0``)D#````````'0,``!P$````````O04``&$!```/````Q`$``.(%```4
M!@``[`,```````"Z`0```````'T%```7!0``#@8``$(!```]!@``A`8``-P!
M``#7`0```````!<"``!-`0``$`,````````8!0```````*@#``"S`@``.`$`
M`*,!``"\`0``)`8``#`&````````$@,``)$&``!V!````````"`!``"$!0``
M``````````"B`@``YP```+<$````````10,``'`&``"F!0``%08``/@````I
M!@``$`8``!@!````````60$``#P&``#\`@``\P$``"8%``#-````````````
M```!`@``10(``$T"````````;`0```````"3!````````&T&``#^!0``!```
M`"<"`````````````-L%``"5`0``V`,``%L#``"T`@``F`,``'8&````````
M#0(``!0!``#H````\`,``.T#```>!@``<@$````````@`@``Z@0```````!&
M!@``)`0``.$#``````````````````#6`0``#00``%X%```@````'@$```L!
M``"_!```4`8``!4$```R`P``?`8``-L$``"5!```708``!L"``#/`P``O00`
M`!4!``#A````NP$```````!`!@``=@4``*@"``#@`0``3P(`````````````
M%P,```````!Z!````````/,#````````[@$`````````````G00``-4````[
M`@```````!(%````````;`````````#+!0``@P0``%T#```=`0``"0,``-4$
M```:!0``=0(``.(#``#N````+`,``!\$``"F`@````$``,D$``#,`0``````
M``````!&`@``F`4``"\```",!0``)@(``(`&``#L!0```````(,&```X!```
MT@(``(D&```P`0``Q@(``!T```!Q!0``5P0````````H!````````*H%``"R
M`@``+08```````````````````````#P`@``````````````````6P0``'0!
M```V````2`(``(\````^!@``]04``,L!``!Y````S0(``#4%``#S!0``]@4`
M`/`!``!@`@```````(0!``"?`P``$`0````````R!```I`,``)8%````````
M"`8`````````````K@0``-<````:!```````````````````=00``#P"``!I
M`0``@`````````"Q`0``````````````````S@,```T&````````:`8``$H%
M``#&!```CP$``-4#``!0!````````+X!``!Z!@``"00``-`$```P!0``````
M`$\$```I````<0(``)`#``":`0`````````````]`P`````````````K!0``
M+@,```````#@!```#`,``(($``"``@```````)0"``"<!0``````````````
M``````````````!C`0``H0$``%0$``!Y!@``'@,``+T#```A!```5```````
M`````````````.\"``#1!0``=@```,P#``#_!0``Y@```#\%````````Y@,`
M``````#"`P````````````!"!0```````(,"``#Y`P```````%P"``!)`@``
MV`4```````"8!@```````(D#``"(````;@0``%\"```K`0``%P$``,8#``#/
M!0``:@(``*\#````````-0```,4$```9````Q0```%0%``"@!0````````4!
M``!P`````````"@#``!Y!0``S04````````O`0``YP(``#$#``#O````1P,`
M`%4```!U`0``]@0````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E
M<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@
M9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70N+BX`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN
M9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES
M<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I
M;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M
M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D
M(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@
M861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S
M`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`
M06QB86YI80!!;&=E<FEA`$%L:6%S`$%L;`!!;&P@075T:&5N=&EC871E9"!5
M<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO=R!M=6QT:7!L
M92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP
M93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N
M871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I
M9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`
M07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!
M<'!R;W9E`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I
M;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O
M(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S
M=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P
M<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T
M`$%R=6)A`$%S8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@
M8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I
M;VYS/P!!<W-I9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES
M=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E
M;G0@<VAA<F4N`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA
M`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E
M9"!C87!A8FEL:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE
M+69T<"!S=VET8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I
M;VX@;F]T(&9O=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E
M;6]V:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E
M8W1O<GD`075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES
M(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@
M=&\@<F5M;W9E('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M('5S97(@)7,`075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P
M<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I
M<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!2
M97%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I
M8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@
M9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!3
M34(@<V5R=F5R(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA
M;@!"3T9(($5X8W5S97,`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R
M8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX
M.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER
M96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"96QA<G5S`$)E;&=I=6T`0F5L:7IE
M`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@
M87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L
M;V-K(%1Y<&4`0F]L:79I80!";V]K;6%R:W,`0F]S;FEA(&%N9"!(97)Z96=O
M=FEN80!";W1H`$)O='-W86YA`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I
M<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"
M=6QG87)I80!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N
M`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N)W0@861M:6YI
M<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T
M('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N
M861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&-O<'D@
M9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE
M+@!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@;6]V92!F:6QE*',I("T@9&5S=&EN
M871I;VX@:7,@=VET:&EN('-O=7)C92X`0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF
M:65D(&YU;6)E<BX`0V%N;F]T('=R:71E('1O(&9I;&4@(B5S(@!#87!E(%9E
M<F1E`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA
M;F1S`$-E;&P@4&AO;F4`0V5L;'!H;VYE`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)
M4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W
M;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9
M;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T
M('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@
M96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T
M960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(N`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAR:7-T;6%S
M($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE
M87(`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`
M0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`0VQI8VL@=&\@0V]N=&EN
M=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7:6YD;W<`0VQO=61S`$-L
M;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI;F<I($ES;&%N9',`0V]L
M;&%P<V4@4VED96)A<@!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L
M;W5R('-E;&5C=&EO;@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O
M;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A
M;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R
M9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N
M=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I
M;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#
M;V]K:64`0V]P>2!F86EL960Z("5S`$-O<W0@240`0V]S=&$@4FEC80!#;W1E
M(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD
M(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S
M+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO
M="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@
M4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V
M92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I
M;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A
M;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N
M;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N
M(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B
M87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G
M:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R
M96%T90!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A
M=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U
M8F$`0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@
M5&EM90!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT(&-O
M;F1I=&EO;CH@`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T
M;R`E<RX`0WEP<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD
M;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!2
M97!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A
M;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY
M`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!2
M96-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5C96UB97(`1&5F875L=`!$
M969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$
M969I;FET:6]N<P!$96QE=&4`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@97AI<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E
M<P!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`B)7,B(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@
M<V5L96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I
M;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S
M="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I
M;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C
M97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I
M;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O
M;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U
M;G0_(%-I9VX@=7`N`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R
M=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C
M87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D
M;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N
M`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I
M="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D
M;W(`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A
M=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`
M16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S
M(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C
M;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B
M87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T
M90!%>'!O;F5N=`!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A
M;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T
M<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE
M($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N
M86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL
M92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S
M="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``1F]G`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;V]D`$9O<F5C87-T("A4048I`$9O<F5C
M87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T
M=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@
M8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S
M<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O
M<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86YC90!&<F%N8V4L($UE
M=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86UB:6$`
M1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R
M9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L
M($]P=&EO;G,`1V\`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A
M;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D
M80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4
M:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA
M8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@
M=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M
M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN
M96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5%10($%U=&AE;G1I8V%T
M:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D
M97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`
M2&5A=GD@5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE
M;'``2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F
M('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@
M4W1A=&4I`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE
M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI
M9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E
M+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S
M<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@
M(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U
M:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(
M;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P
M87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O
M;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@
M(B5S(@!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2'5M
M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@
M061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C
M:V1O=VX@=FEO;&%T:6]N+@!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE
M(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y
M;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!)
M;F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O<FUA=&EO;@!)
M;F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@86QT97)N
M871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H
M('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@;65S
M<V%G97,`26YS97)T('1H92!R97%U:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R
M:71Y('%U97-T:6]N.@!);G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@
M=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I8VEE;G0@8W)E9&ET+@!)
M;G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(
M96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN=F%L:60@87!P;&EC871I;VXN
M`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN
M=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA
M=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A;&ED(&QO8V%T:6]N('!R;W9I
M9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I
M7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R86UE=&5R<RX`26YV86QI9"!P
M87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P87)T;F5R(&ED+@!);G9A;&ED
M('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T;V-O;"X`26YV86QI9"!R96-I
M<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S;W5R
M8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R>0!)
M;G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A
M<0!)<F5L86YD`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A
M;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*
M4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN
M9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI
M<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY
M<F=Y>G-T86X`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O<F0@0VAA;F=E`$QA<W0@475A
M<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ
M("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,96)A
M;F]N`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB
M97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG
M:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@
M4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4
M:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EN:P!,:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U
M<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI
M=&5R871U<F4`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO
M8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S
M('-Y;F,@<V5S<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN
M(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S
M(&5N=&5R960@:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT
M`$QO=F4`3&]W`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE
M;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H
M92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I
M8P!-86EL`$UA:6P@061M:6X`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA
M;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA
M=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D
M('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA
M<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI
M;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R
M961I="X`36%X(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA
M<W0@,C0@:&]U<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M
M($YU;6)E<B!O9B!0;W)T86P@0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-
M87EO='1E`$UE9&EC:6YE`$UE;6)E<G,`365N=2!M;V1E.@!-97-S86=E`$UE
M<W-A9V4@5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@
M8V5R=&EF:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X
M<&ER960N`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K
M(&YO="!A=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E
M=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N
M`$UE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B
M(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE
M=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@
M4W1A=&5S(&]F`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@;65S<V%G
M92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES
M<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I
M9FEE9"!$871E`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C
M8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA
M;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT
M:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L
M(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R
M=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P
M92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W
M<P!.97=S9W)O=7!S`$YE>'0`3F5X="`T(%!H87-E<P!.97AT(&]P=&EO;G,`
M3F5X=#X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.
M;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R
M96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)
M4T\@:6UA9V5S+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S
M(&%T('1H92!R97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P
M<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&
M5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO
M(&1E<W1I;F%T:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC
M;VYS(&9O=6YD+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R
M;W9I9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE
M9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S
M`$YO('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@
M3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3
M(#$R(&1A=&$N`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.
M;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S=6-H(&9I;&4`3F\@=&5M<&]R
M87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.;R!U<V5R;F%M
M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,(&1A=&$@<F5T
M=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@;W)I9VEN86P@
M8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R
M:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@
M82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<W5P<&]R=&5D+@!.
M;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M
M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU
M;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I
M;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@
M;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@
M:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R
M="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL
M>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O
M<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O
M<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W
M('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A
M(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5R871I;F<@4WES=&5M`$]P
M=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO
M;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP
M;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN
M9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO
M;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I
M9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC
M($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3
M:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W
M`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT
M96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!086MI<W1A;@!086QA=0!0
M86QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.
M97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S
M<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C
M=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N
M+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&5N9&EN9R!3:6=N
M=7!S.@!096]P;&4`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@
M1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0
M:&]N90!0:&]T;W,`4&ET8V%I<FX`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A
M9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE
M('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W
M(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A
M;`!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A
M=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L
M979E;#H@`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:6]U<R!O<'1I;VYS`%!R
M:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T
M<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM
M`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G
M96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S
M86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET
M*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!2
M86EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@
M1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T
M92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY
M(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N
M(&-A;FYO="!B92!U;F1O;F4N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E(&-O;'5M;@!296UO=F4@<&%I<@!296UO=F4@<V%V960@
M<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M
M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@
M86YS=V5R960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V
M:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E
M8VEF:65D(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I
M96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`
M4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`
M4F5T>7!E(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T
M:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT(&AE
M861E<@!2:6=H="!V86QU97,`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T
M871E($QE9G0`4F]T871E(%)I9VAT`%)U;@!2=7-S:6%N($9E9&5R871I;VX`
M4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@
M16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M
M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`
M4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,
M=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@
M86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`
M4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U
M<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`
M4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I
M;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P
M('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E
M;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L
M96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E
M;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H
M92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C
M="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A
M;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE
M8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD
M<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F
M97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`
M4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE
M9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V
M86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E
M<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R
M96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO
M=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z
M;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC
M871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H
M97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP
M=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@
M=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M
M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L
M:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY
M('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN
M`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O
M<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W
M97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T
M=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E
M`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W
M97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W
M(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)
M<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C
M=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E
M86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!3
M86YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V5R`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!O<G1S`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W4`
M4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U8FUI=`!3
M=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES=&5M+B!9
M;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@
M87!P<F]V960N`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@
M(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO
M860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@
M8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B
M)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6X@4FES90!3=6X@
M4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U
M;G-E=`!3=6YS970Z(`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A
M<F0@86YD($IA;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD
M`%-Y;F,@;&]G(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R
M8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M
M(&%N9"!7:6YD>0!4+5-T;W)M<P!44U8@9FEL90!486)L92!3970`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`
M5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z
M(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E
M;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO
M;@!497AT`%1E>'0@3VYL>0!4:`!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO
M;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES
M86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E
M<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@
M:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W
M86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&-O;G1A8W0@240@;G5M8F5R
M('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U
M;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U
M;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@
M4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE
M('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S
M(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N
M9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@
M;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER
M92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD
M(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N
M=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T
M;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@
M)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D
M+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B
M965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@
M;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE
M;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E
M<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE
M('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I
M=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T
M97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<&%R871O
M<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E
M<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M('-A=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T
M+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT
M(&]N('1H92!S8W)E96XN`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I
M;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L
M9"!N;W0@8F4@<V%V960N`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@
M879A:6QA8FQE+@!4:&5M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4
M:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P
M87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@
M=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E
M;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA
M;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@
M<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@
M9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@
M=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D
M960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S
M:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D
M960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A
M8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A
M;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG
M=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D
M(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E
M8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT
M86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A
M<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N
M;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P
M96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@
M87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@
M<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T
M96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H
M92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E
M=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E
M;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P
M.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!3
M3510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@
M=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN
M`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@
M8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C
M;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M
M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F
M:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@
M8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F
M;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@
M;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I
M='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@
M;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S
M97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H
M:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE
M9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE
M`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&ET
M;&4`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE
M($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC
M:VEN9RX`5&]D87D`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M
M86YY(&EN=F%L:60@;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4
M<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E
M`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM
M96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S
M8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!59V%N9&$`56MR86EN90!5
M;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C:&%N
M9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H
M86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B
M)7,B+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N
M86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@
M9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N
M86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T
M92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N
M`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D
M96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I
M<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@
M)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T
M(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@
M8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC
M871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@
M)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I
M=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N
M(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@
M*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N
M86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O
M(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@
M97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M
M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S
M+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N
M("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C
M=6UE;G0`56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T92!F;W(@
M)7,`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET
M92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U
M;W1A('=I;&P@8F4@97AC965D960N`%5N9&\@0VAA;F=E<P!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"X`56YN86UE9`!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57)U9W5A>0!5
M<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R9"!I
M<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S
M97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO
M;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U
M;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D>2!E
M>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T
M96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES="X`
M5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!686QI
M9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O=F5R
M('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T;R!S
M96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R>2!(:6=H
M`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I
M<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O
M9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E
M<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA
M(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:"!I;B!#4U,@=6YI=',`5VED
M=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O
M;B!N97AT(&QO9RUI;BDZ`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E
M960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K
M`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L
M9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N
M=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG
M(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U
M,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S
M86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U
M8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E9
M60!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO
M=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C
M:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V
M92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I
M9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T
M(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE
M(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE
M(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R
M('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T
M;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$
M871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R
M;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N
M`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U
M(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU
M<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E
M8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H
M92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R
M>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@
M;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO
M9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R
M97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H
M87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N
M9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@
M=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U
M(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B
M;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A
M<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U
M<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M
M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R
M="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0
M('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED
M96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E
M9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES
M('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U
M<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B
M965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y
M;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`
M66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB:6$`
M6FEM8F%B=V4`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`
M6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI
M;F5S70!;;&EN92`E<R!O9B`E<UT`7T-,20!?1&%T851R964`7T=R;W5P<P!?
M2&5L<`!?3&]G(&EN`%],;V<@;W5T`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?
M4V5T=7``7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C
M86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T
M(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M
M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD
M`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I
M;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I
M;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN
M97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M
M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO
M=&5P860`<&5R;6ES<VEO;B!D96YI960`<F5M;W1E(&5R<F]R(&EN('!R;W1O
M8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC
M97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`
M=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D
M('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T
M`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@+@I2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-BTP-RTR-2`Q,3HS,"LP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#8M,#0M,S`@,3`Z,S(K,#$P,`I,87-T+51R86YS;&%T
M;W(Z(&1U8VM`;V)A;&$N;F5T"DQA;F=U86=E+51E86TZ('-L7U-)(#QD=6-K
M0&]B86QA+FYE=#X*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/75T9BTX"D-O;G1E;G0M5')A;G-F97(M16YC
M;V1I;F<Z(#AB:70*`"`H<')E9"`E<R!D;F5V:2D`("A$;W-T;W!N82!T:7!K
M82`E<RD`("AV("5S(&1N96@I`"AD86YE<RD`2G5T<FD@`"AVQ(UE<F%J*0`@
M;V(@`"(E<R(@;FD@:6UE;FEK`"(E<R(@:F4@;F5V96QJ879N82!I>F)I<F$`
M(B5S(B!N92!Z87IN86T@=B!(;W)D;W9E;2!R96=I<W1R=2``)R5S)R!N92!N
M86ID96T@9')E=F5S82!Z82!I>G)I<RX`)R5S)R!J92!B:6P@9&]D86X@<VMU
M<&EN<VME;74@<VES=&5M=0`G)7,G(&IE(&)I;"!D;V1A;B!K(&1O<'5S=&YE
M;74@<VES=&5M=2X`)R5S)R!N:2!U<W1V87)J96XZ("5S(`!5<&]R86)L:F5N
M:6@@)2XR9DU"(&]D("4N,F9-0B!D;W9O;&IE;FEH("@E+C)F)24I`"5D("5S
M(&EN("5S`,6@92`E9"!D;FD@9&\@<&]T96MA(&=E<VQA`"5D+61N979N82!N
M87!O=F5D`"5S(.*`DR!";V1I=&4@<&]Z;W)N:0`E<R!/9'1I<P`E<R!+0@`E
M<R!6>F1RQ;YE=F%L;F$@9&5L82`M(%!O=')D:71E=@`E<R`@("`@(``E<R!P
M<FEJ879A`"5S(%!O9V]J:0`E<R#%OF4@;V)S=&%J82X`)7,@;V(@)7,@)7,`
M)7,@:F4@<')I<')A=FQJ96X@;F$@:7IV86IA;FIE('9Z9'+%OF5V86QN:6@@
M;W!E<F%C:6HL('!R979E<FD@<W!O9&%J+E!R979E<FD@;F%B:7)A;&YI:R!Z
M82!V<V4@;W!E<F%C:6IE+"!K:2!B:2!J:6@@<F%D(&]P<F%V:6P@<V5D86HN
M`%!O=')E8G5J96T@)7,@`"5S(&UI;G5T`"5S(&YE(&YA:F1E;0`E<R!O8B`E
M<R!O9"`E<P!);65N:6L@)7,`2V]L961A<B`E<P!"96QEQ;YK82`E<P`E<R!/
M<')A=FEL80`E<SH@)7,`)7,Z('1O('-P;W)OQ(UI;&\@;6]G;\2-92!N:2!O
M9"!P;\6A:6QJ871E;&IA+"!K871E<FD@<')A=FD@9&$@:F4N(%!A>FET92!S
M92!K871E<FEH:V]L:2!P;W9E>F%V('8@<W!O<F_$C6EL=2!A;&D@<&]D86IA
M;FIU(&MA=&5R:6@@:V]L:2!O<V5B;FEH(&EN9F]R;6%C:6H@;F$@=&$@;F%S
M;&]V+@`L(&=O<W1I;2``+"!G;W-T:6T@)7,@)7,`+"!S<')E;65N;&II=FMA
M(&]D("5S(&1O("5S`"TM(&EZ8F5R:2`M+0`Q,B!U<B!F;W)M870`,C0@=7(@
M9F]R;6%T`#(T('5R`%!R96K%H6YJ82!M;\6^;F]S=`!:82!T82!B;&]K(&IE
M('!O=')E8FYA('!O=F5Z879A(&YA('!O9&%T:V]V;FD@<W1R9<6^;FEK`%!O
M:F%V:6QA('-E(&IE(&AU9&$@;F%P86MA+@!:82!K;V1I<F%T:2!S<&]R;\2-
M:6QO('!O=')E8G5J96T@:F%V;FD@4$=0(&ML:G7$C2X`2F%V;FD@4$=0(&ML
M:G7$C2!J92!P;W1R96)E;B!Z82!O9&ML97!A;FIE('-P;W)OQ(UI;&$N`$IA
M=FYI(%!'4"!K;&IUQ(TL('IA<V5B;FD@4$=0(&ML:G7$C2!I;B!G97-L;R!S
M;R!P;W1R96)N:2!Z82!O9&ML97!A;FIE('-P;W)OQ(UI;&$N`$IA=FYI(%!'
M4"!K;&IUQ(TL('IA<V5B;FD@4$=0(&ML:G7$C2!I;B!G97-L;R!S;R!P;W1R
M96)N:2!Z82!P;V1P:7,@<W!O<F_$C6EL82X`2F%V;FD@4R]-24U%(&ML:G7$
MC2P@>F%S96)N:2!3+TU)344@:VQJ=<2-(&EN(&=E<VQO('-O('!O=')E8FYI
M('IA('!O9'!I<R!S<&]R;\2-:6QA+@!*879N:2!3+TU)344@:VQJ=<2-+"!Z
M87-E8FYI(%,O34E-12!K;&IUQ(T@:6X@9V5S;&\@<V\@<&]T<F5B;FD@>F$@
M<&]D<&ES('-P;W)OQ(UI;&$N`"!*879N:2!334E-12!K;&IU92!J92!P;W1R
M96)E;B!Z82!O9&ML97!A;FIE('-P;W)OQ(UI;&$@`$]B;&'$C6YO`$IU=')A
M;FII(%)A:&5L(&1EQ;X`2G5T<F%N:FD@9&7%O@!*=71R86YJ:2!N86QI=@!*
M=71R86YJ:2!S;F7%OFYI(&UE=&7%O@!!32]030!!4$D@240`3W!I<RXN+@!0
M<F5P;W9E9&%N(&1O<W1O<"!Z82!U<W1V87)J86YJ92!M87!E(%9&4RX@`%!R
M97!O=F5D86X@9&]S=&]P('IA('5S='9A<FIA;FIE(&1A=&]T96ME(%9&4RX`
M5F'%H6D@<&]D871K:0!0;W1R9&D@9V5S;&\`27IV86IA;0!)>G9A:F%M`$1O
M9&%J`$1O9&%J('-K=7!I;F\@;W1R;VL`1&]D86H@9&]V;VQJ96YJ82!O=')O
M:V$`1&5D86H@<V5M.@!$;V1A:B!N;W9O('-K=7!I;F\`1&]D86H@;F]V82!D
M;W9O;&IE;FIA`$1O9&%J('-K=7!I;F\@;W1R;VL@(B5S(@!$;V1A:B!D;W9O
M;&IE;FIE(&]T<F]K82`B)7,B`$1O9&%J(&YO=F5G82!U<&]R86)N:6MA.@!$
M;V1A:B!S=&]L<&5C`$1O9&%J(&YO=F4@Q(UL86YE`$1O9&%J('!A<@!$;V1A
M:B`E<R!-96YU('8@36]Z:6QL82!3:61E8F%R`$1O9&%J('8@:6UE;FEK.@!$
M;V1A:B!V(&UO:B!I;65N:6LZ`$1O9&%J('5P;W)A8FYI:V$`($1O9&%L("<E
M<R<@<VES=&5M=2P@=F5N9&%R(&)O(&YE;6]G;\2-92!D;V1A:F%N:F4@9&]D
M871N:6@@=G!I<VYI:"!I;F9O<FUA8VEJ.B`E<RX`1&]D86X@)R5S)R!S:7-T
M96UU+B!3961A:B!S92!L86AK;R!P<FEJ879I=&4N`$1O9&%J86YJ92!U<&]R
M86)N:6MO=B!J92!O;F5M;V=OQ(UE;F\N`$YA<VQO=@!);65N:6L`57)E9&D@
M9&]V;VQJ96YJ82!Z82!O<W1A;&4@=7!O<F%B;FEK90!5<')A=FQJ86YJ90!2
M96ML86UE`$%F:&%N:7-T86X`06QB86YI:F$`06S%OFER:6IA`$]Z:7)O;6$`
M5G-E`%9S:2!O=F5R:F5N:2!U<&]R86)N:6MI`%9S92!S:W5P:6YE`%9S82!$
M;W9O;&IE;FIA`$1O=F]L:2!M;F]G;VMR871N92!N87-L;W9E`$1O=F]L:2!N
M87-T879I='9E("``PX+%O64@;V)S=&%J80!.861O;65S=&YO($E-4U`@=7!O
M<F%B;FG%H6MO(&EM90!.861O;65S=&YO($E-4U`@9V5S;&\`3F%D;VUE<W1N
M;R!)35-0('5P;W)A8FYIQ:%K;R!I;64`3F%D;VUE<W1N:2!E;&5K=')O;G-K
M:2!N87-L;W8`3F%D;VUE<W1N:2!V>F]R8VD`($%M97)IQ:%K82!386UO82``
M3F%V961E;F$@:F4@8FEL82!N97IA:V]N:71A('9R961N;W-T+@!P;VIA=FEL
M82!S92!J92!N87!A:V$`06YD;W)A`$%N9V]L80!!;F=U:6QL80!!;F]N:6UE
M;B!0<F]X>0!/9&=O=F]R`$%N=&%R:W1I8V$`06YT:6=U82!I;B!"87)B=61A
M`$%P;&EK86-I:F$`4V5Z;F%M(&%P;&EK86-I:@!!<&QI:V%C:6IA(&IE('!R
M:7!R879L:F5N80!0<FEJ879I(&]T<F]K;W9E(&1E;&YI8V4@`%!O=')D:0!!
M<')I;`!!<F%B<VMI("A7:6YD;W=S+3$R-38I`%9E;&EK;W-T(&1A=&]T96ME
M($%R:&EV(`!);64@07)H:79A`%-T92!P<F5P<FG$C6%N:2P@9&$@Q;YE;&ET
M92!P<F5K;&EC871I('IA:'1E=F\@>F$@<')I:F%V;R!Z82`E<R`_(`!3=&4@
M<')E<')IQ(UA;FDL(&1A(,6^96QI=&4@:7IB<FES871I("<E<R<@:6X@;W-T
M86QE('!O9'-K=7!I;F4_`$%R9V5N=&EN80!!<FUE;FEJ80!!<FUE;G-K:2`H
M05)-4T-)22TX*0!5;65T;F]S=`!!<G5B80!5;65T;F]S=&D@Q(UR:P!!>FEA
M+U!A8VEF:<6A:V4@<F5G:6IE`%9P<F'%H6%J('IA('!O=')D:71E=B!P<F5D
M(&EZ=F%J86YJ96T@=GID<L6^979A;FIA`$1O9&5L:F5N92!K;VQO;F4`4&]S
M:W5S(&EZ8G)I<V$@;F5O8G-T;VIEQ(UE('-K=7!I;F4N`%!O<VMU<R!I>F)R
M:7-A(&YE;V)S=&]J9<2-96=A(&1O=F]L:F5N:F$N`%!O<VMU<R!U<F5D:71V
M92!N96]B<W1O:F7$C65G82!D;W9O;&IE;FIA+@!0;W-K=7,@=7)E9&ET=F4@
M;F5O8G-T;VIEQ(UE(&1E;&YI8V4N`$QA<W1N;W-T:0!!=F=U<W0`079S=')A
M;&EJ80!!=G-T<FEJ80`@075T:%]C>7)U<SH@6F%H=&5V86YO(&EM87`@Q:%I
M<FET978@;FES96T@;F'%H65L+@!!=71H7V-Y<G5S.B!"86-K96YD(&YI;6$@
M>F%H=&5V86YI:"!Z;6_%OFYO<W1I+@!!=71H7V-Y<G5S.B!:86AT979A;F\@
M:6UA<"#%H6ER:71E=B!N:7-E;2!N8<6A96PN`$%U=&A?9G1P.B!:86AT979A
M;F\@1E10(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X@27IP;VQN:2!02%`@>B`M
M;VYE;6]G;\2-96YO+2!F='`@>F%M96YJ879O+B``075T:%]I;6%P:'1E=F%N
M;R!)34%0:71E=B!N:7-E;2!N8<6A96PN`$%U=&A?:W)B-3H@6F%H=&5V86YO
M(&MR8C4@Q:%I<FET978@;FES96T@;F'%H65L+@!!=71H7VQD87`Z($YI(&UO
MQ;YN;R!D;V1A:F%N:F4@=7!O<F%B;FEK;W8@=B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@3FD@;6_%OFYO(&]D<W1R86YJ979A;FIE('5P;W)A8FYI
M:V]V('8@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%IA:'1E=F%N;R!,
M1$%0(,6A:7)I=&5V(&YI<V5M(&YAQ:%E;"X`075T:%]L9&%P.B!.92!M;W)E
M;2!D;V1A=&D@=7!O<F%B;FEK82`E<RX@4W!O<F_$C6EL;R!S=')EQ;YN:6MA
M.B``075T:%]L9&%P.B!.92!M;W)E;2!O9'-T<F%N:71I('5P;W)A8FYI:V$@
M)7,`075T:%]L9&%P.B!.92!M;W)E;2!N861G<F%D:71I('5P;W)A8FYI:V$@
M)7,@`$%U=&A?;&1A<#H@;F4@;6]R96T@;F%D9W)A:F5V871I('5P;W)A8FYI
M:V]V('8@06-T:79E($1I<F5S=&]R>2X`075T:%]M8V%L.B!:86AT979A;F\@
M34-!3"#%H6ER:71E=B!N:7-E;2!N8<6A96PN`$%U=&A?<VUB875T:#H@6F%H
M=&5V86YE9V$@<VUB875T:"!Z82#%H6ER:71E=B!N:7-E;2!N8<6A96PN`$]V
M97)J86YJ92!Z82!&5%`@<W1R9<6^;FEK(&YI('5S<&5L;RX`3W9E<FIA;FIE
M(&YI('5S<&5L;RX`3W9E<FIA;FIE(&YI('5S<&5L;RX@)7,`3W9E<FIA;FIE
M(&IE('IA=G)N:6P@4D%$2553('-T<F7%OFYI:RX`3W9E<FIA;FIE('IA($94
M4"!S=')EQ;YN:6L@;FD@=7-P96QO+@!/=F5R:F%N:F4@>F$@4TU"('-T<F7%
MOFYI:R!N:2!U<W!E;&\N`%!O;&IA(&YA(')A>G!O;&%G;SH`07IE<F)A:F3%
MOF%N(`!.975M;FD@:7IG;W9O<FD`3F%P8<2-;F\@:V5R8F5R;W,@9V5S;&\N
M`$YA<&'$C6YO(&ME<F)E<F]S('5P;W)A8FYIQ:%K;R!I;64N`$)A:&%M:0!"
M86AR86EN`$)A;'1I:R`H25-/+3@X-3DM,3,I`$)A;F=L861EQ:$`0F%R8F%D
M;W,`3FES96T@;F'%H65L(&]S;F]V;F5G82!G<F%F:<2-;F5G82!I;65N:6MA
M("(E<R(N`$)E;&]R=7-I:F$`0F5L9VEJ80!"96QI>F4`0F5N:6X`0F5R;75D
M<VMI(&]T;VMI`$)U=&%N`%)O:G-T;FD@9&%N`$YI<V5M(&YAQ:%E;"!B;&]K
M82`B)7,B+"!A<&QI:V%C:6IE("(E<R(@+@!:875S=&%V:2!.87-T879I='9E
M`%IA=7-T879I(%1I<`!";VQI=FEJ80!0<FEL:G5B;&IE;F4`0F]S;F$@:6X@
M2&5R8V5G;W9I;F$`3V)O:FD`0F]C=F%N80!";W5V971O=F\@;W1OQ(UJ90!"
M<F%Z:6QI:F$`($)R:71A;G-K;R!O>F5M;&IE($EN9&EJ<VME9V$@;V-E86YA
M(`!"<G5N96D`0F]L9V%R:6IA`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$U31P!#
M4D,`($-23"!R87ID96QI='9E;F4@=&_$C6ME(`!.87-T879L:F%N:F4@<')E
M9'!O;6YI;&YI:V$@;FD@9&]K;V[$C6%N;RX`2V]L961A<@!:8G)IQ:%I`$MA
M;6)O9,6^80!+86UE<G5N`$YE(&UO<F5J;R!U<')A=FQJ871I('IU;F%N:FD@
M=7!R879L:F%L8VD`3F4@;6]R96T@=GIP;W-T879I=&D@<&]V97IA=F4@>B!)
M34%0('-T<F7%OFYI:V]M.B`E<R``3FD@;6]G;\2-92!O9'!R971I("(E<R(@
M9&%T;W1E:V4N`$MA;F%D80!:8G)IQ:%I`'!O<F_$C6EL;R!O('1EQ;YA=F%H
M('H@8G)I<V%N:F5M`$YE(&UO<F5M(&MO<&ER871I(&1A=&]T96L@*&4I("T@
M=FER(&EN(&-I;&IA('-T82!I<W1A+@!.92!M;W)E;2!I>F)R:7-A=&D@9&%T
M;W1E:V4@(B5S(BX`3F4@;F%J9&5M('IAQ(UA<VYE(&1A=&]T96LN`$YE(&UO
M<F5M('!R96UA:VYI=&D@9&%T;W1E:R`H92D@+2!C:6QJ(&IE('IN;W1R86H@
M=FER82X`3F4@;6]R96T@;F%D86QJ979A=&D@8G)E>B!P87)A;65T<F]V("=C
M:6QJ;F4@9&%T;W1E:V4G+@`B)7,B($EM96YI:V$@;F4@;6]R96T@>F)R:7-A
M=&DN`$YE(&UO<F5M(&]D<W1R86YI=&D[(&]B<W1A:F$@)60@<&]D=F5L:@!.
M92!M;W)E;2!P;VYO=FYO('5R961I=&DL(,6A=&5V:6QO(&1A;FEH('9N;W-O
M=B!S92!N92!S:VQA9&$@<R#%H71E=FEL;VT@('-H<F%N:F5N:6@N`$YE(&UO
M<F5M(&%V=&]M871S:V\@<&]N87-T879I=&D@9V5S;&$L(&]B<FYI=&4@<V4@
M;F$@<VMR8FYI:V$`3F4@;6]R96T@<')E=7-M97)I=&D@<W!O<F_$C6EL82!N
M879E9&5N96UU(,6A=&5V:6QU+@!#86YN;W0@=W)I=&4@=&\@9FEL92`B)7,B
M`$MA<'9E<F1S:VD@;W1O:VD`4')I;F'%H6%L96,`2V%T96=O<FEJ92!I;B!Z
M;F%M:V4`2V%Y;6%N<VMI(&]T;VMI`$UO8FEL;FD@=&5L969O;@!-;V)I;&YI
M('1E;&5F;VX`2V5L='-K:2`H25-/+3@X-3DM,30I`$-E;G1R86QN;R!!9G)I
MQ:%K82!297!U8FQI:V$`4W)E9&YJ965V<F]P<VMI("A)4T\M.#@U.2TR*0!0
M;V1R;V)N;W-T:2!P;W1R9&EL80!,87-T;FEK('!O=')D:6QA`%!R879I;&$@
M<&]T<F1I;&$`16%D`%-P<F5M96YI`'-P<F5M96YI=&4@=F'%H64@9V5S;&\`
M4W!R96UE;FET92!I;64@:6X@;F%S;&]V('9AQ:%E9V$@96QE:W1R;VYS:V5G
M82!N87-L;W9A+"!K:2!G82!V:61I:F]P<F5J96UN:6MI(&]B(&)R86YJ=2!I
M;B!O9&=O=F%R:F%N:G4@;F$@=F'%H6\@<&_%H71O+@!6('1R96YU=&YI(&MO
M;F9I9W5R86-I:F4@;F4@;6]R971E('-P<F5M96YI=&D@9V5S;&$N($MO;G1A
M:W1I<F%J=&4@=F'%H65G82!S:W)B;FEK82X`Q(UI;&4`2VET86IS:V$`4&]E
M;F]S=&%V;&IE;F$@:VET86K%H<2-:6YA*$=",C,Q,BD`5')A9&EC:6]N86QN
M82!K:71A:L6AQ(UI;F$@*$)I9S4I`$EZ8F5R:2!A<&QI:V%C:6IO.@!)>F)E
M<FD@9V5S;&\`27IB97)I('5P;W)A8FYIQ:%K;R!I;64`2V%K;R!P<FEK87IA
M=&D@9&%T=6UE.@!";\6^:<2-;FD@;W1O:VD`3FES96T@;F'%H65L(&1E9FEN
M:6-I:F4@=G)S=&4@>F$@)7,N`$IA<VYO`%!R9<2-:7-T:2!P;VEZ=F5D8F4`
M3V1S=')A;FD@>G5N86YJ96=A('5P;W)A8FYI:V$Z("5S(`!/9'-T<F%N:2!U
M<&]R86)N:6MA`$EZ8G)IQ:%I('!O9&%T96L@=7!O<F%B;FEK80!I>F)R:<6A
M:2!P;W1E;0!+;&EK;FD@>F$@;F%D86QJ979A;FIE(`!#;&EC:V%T96QL('!R
M;W1O;2!(5%10`%IA<')I(&]K;F\`3V)L86MI`%IJ=71R86H@3V)L8<2-;F\`
M3V)L8<2-;F\`2V]K;W-O=FD@;W1O:VD`6F1R=<6^:2!S=')A;G-K;R!O:VYO
M`$MO;'5M8FEJ80!"87)V80!)>F)I<F%L96,@8F%R=@`@27IB:7)A($)A<G9E
M(`!.87-L;W8@<W1O;'!I8V$`4W1R:7!I`%5K87H`56MA>FYA(&QU<&EN80!+
M;VUE;G1A<@!3:W5P;F\@:6UE`$MO;6]R:2``1')UQ;YB80!28<2-=6YA;&YI
M:VD`3F%S=&%V:71E=@!.87-T879I='9E`%)A>FQI:V4@;F%S=&%V:71V90!.
M87-T879I='9E('IA('-I;FMR;VYI>F%C:6IA;R!D;&%NQ(UN:6MO=@!.87-T
M879I='9E('!O=')E8G5J96IO(&'%OG5R:7)A;FIE`$YA<W1A=FD@)7,`4&]T
M<F1I(&=E<VQO`$MO;F=O`$MO;F=O+"!$96UO:W)A=&G$C6YA(')E<'5B;&EK
M80!0;W9E>F%V82!N:2!U<W!E;&$N`%!O=F5Z879A(&YI('5S<&5L83H`6F%V
M<FYJ96YA('!O=F5Z879A('H@:F%V;FEM(&ML:G7$C6YI;2!S=')EQ;YN:6MO
M;2X`6F%V<FYJ96YA('!O=F5Z879A('H@:F%V;FEM(&ML:G7$C6YI;2!S=')E
MQ;YN:6MO;2X@4F%Z;&]G.B`E<R`H)7,I`%!O=F5Z879A(',@1E10('-T<F7%
MOFYI:V]M(&YI('5S<&5L82X`4W1I:VD`4W1I:R!J92!B:6P@=7-P9<6A;F\@
M9&]D86X@:R!V8<6A:6T@;F%S;&]V;VTN`%1I<"!S=&EK82!S=&ES;FIE;F4@
M9&%T;W1E:V4Z`%9S96)I;F4@;V0B)7,B`$YA9&%L:G5J`$-O;VMO=FD@;W1O
M:VD`4&G%H6MO=&5K`$MO<&ER86YJ92!N:2!U<W!E;&\Z("5S`$E$('-T<F_%
MH65K`$MO<W1A<FEK80`@4VQO;F]K;\6AQ(UE;F$@;V)A;&$@`%!'4"!N92!M
M;W)E(,6A:69R:7)A=&D@<W!O<F_$C6EL83H`3FD@;6]G;V4@4$=0('!O9'!I
M<R!S<&]R;V5I;&$N`$YI(&UO9V_$C64@4R]-24U%(,6A:69R:7)A=&D@<W!O
M<F_$C6EL82X`3FD@;6]G;\2-92!3+TU)344@<&]D<&ES('-P;W)OQ(UI;&$N
M`$YI(&UO9V_$C64@9&]D871I('-T:6MO=BX@)7,N`%!O=F5Z879A('H@3$1!
M4"!S=')EQ;YN:6MO;2!N:2!M;V=OQ(UA+@!.:2!M;V=OQ(UE(&MO;G1R;VQI
M<F%T:2`_/S\_/S\@)7,N`%!O=F5Z879A('H@3$1!4"!S=')EQ;YN:6MO;2!N
M:2!M;V=OQ(UA+@!.92!M;W)E;2!V>G!O<W1A=FET:2!P;W9E>F%V92!S('-T
M<F7%OFYI:V]M("(E<R(@>B!U<&]R86)O($944#H@)7,`3F4@;6]R96T@=7-T
M=F%R:71I('-E>FYA;6$@>F$@9&ES=')I8G5C:6IO+B`E<P!.:2!M;V=OQ(UE
M(&1EQ:%I9G)I<F%T:2!01U`@<&]D871K;W8Z`$YI(&UO9V_$C64@9&7%H6EF
M<FER871I(%,O34E-12!P;V1A=&ME+@!.92!M;W)E;2!I>F)R:7-A=&D@<W1I
M:V]V+B`E<P!.92!M;W)E;2!I>F)R:7-A=&D@9&ES=')I8G5C:6IS:V5G82!S
M97IN86UA+B`E<P!.92!M;W)E;2!I>F)R:7-A=&D@;F%S=&%V:71V96YE(&'%
MOG5R86-I:G-K92!S:W)I<'1E("(E<R(`3FD@;6]G;\2-92!D;VQOQ(UI=&D@
M96QE:W1R;VYS:V5G82!N87-L;W9A('!R96IE;6YI:V$N`$YI(&UO9V_$C64@
M9&]L;\2-:71I(&-E;&]T;F5G82!I;65N:6MA+@!.:2!M;V=OQ(UE(&1O;&_$
MC6ET:2!C96QO=&YE9V$@9&ES=')I8G5C:6IS:V5G82!S97IN86UA+@!.:2!M
M;V=OQ(UE(&1O;&_$C6ET:2!C96QO=&YE9V$@<V5Z;F%M82!D:7-T<FEB=6-I
M:G-K:6@@<V5Z;F%M;W8`3FD@;6]G;\2-92!N86QOQ;YI=&D@<W1R871E9VEJ
M92`B)7,B+@!.92!M;W)E;2!T=F]R:71I(&UA<&4@(B5S(BX`3FD@;6]G;\2-
M92!D;V)I=&D@:F%V;F5G82!K;&IUQ(UA(&]D(&ML:G7$C6YE9V$@<W1R9<6^
M;FEK82X`3FD@;6]G;\2-92!O9'!R971I("(E<R(@>F$@<&ES86YJ92X`3FD@
M;6]G;\2-92!O9'!R971I("5S+@!.:2!M;V=OQ(UE(&]D<')E=&D@;6]D=6QA
M(&\@;W!R879I;'5?=GID<L6^979A;FIA("5S(`!.:2!M;V=OQ(UE('!R96)R
M871I(&EM96YI:R`B)7,B+@!.:2!M;V=OQ(UE(&1O<V7$C6D@3$1!4"!S=')E
MQ;YN:6MA+@!.:2!M;V=OQ(UE('!R96)R871I("5S+@!.:2!M;\6^;F\@<&]N
M87-T879I=&D@9V5S;&$@>F$@>F%H=&5V86YE9V$@=7!O<F%B;FEK82X@3F5K
M871E<F4@86QI('9S97!O9')O8FYO<W1I(&YI<V\@<')A=FEL;F4N(%!O<VMU
M<VET92!Z;F]V82!A;&D@:V]N=&%K=&ER86IT92!V8<6A96=A=7!R879I=&5L
M:F$L(,2-92!P;W1R96)U:F5T92!N861A;&IN:F\@<&]M;\2-+@!.:2!U<W!E
M;&\@=GIP;W-T879I=&DZ("5S(`!.:2!U<W!E;&\@=GIP;W-T879I=&D@:6UE
M;FEK83H@)7,@`$YI('5S<&5L;R!V>G!O<W1A=FET:2!D:7-T<FEB=6-I:G-K
M96=A('-E>FYA;6$Z("5S(`!.:2!U<W!E;&\@=GIP;W-T879I=&D@9&ES=')I
M8G5C:6IS:V5G82!S97IN86UA.B`E<R``3FD@=7-P96QO('9Z<&]S=&%V:71I
M.B`E<R``6F%H=&5V86YI("<E<R<@;FD@<&]D<F]B;F\@;V)L:6MO=F%N('8@
M)7,@<&]D;V)I+@!.92!M;W)E;2!I>F)R:7-A=&D@;6%P92`B)7,B+@`E<R!K
M;VYF:6=U<F%C:6IE(&YI(&UO9V_$C64@<VAR86YI=&DN`$MO;F9I9W5R86-I
M:F4@=F%R;F]S=&YE(&MO<&EJ92!N:2!M;V=OQ(UE('-H<F%N:71I+@!+;VYF
M:6=U<F%C:6IE('9A<FYO<W1N92!K;W!I:F4@;FD@;6]G;\2-92!S:')A;FET
M:3H@)7,`3F4@;6]R96T@<VAR86YI=&D@;F%S=&%V:71V96YE(&'%OG5R86-I
M:G-K92!S:W)I<'1E(&YA.B`B)7,B+@!.92!M;W)E;2!S:')A;FET:2!K;VYF
M:6=U<F%C:6IS:V\@9&%T;W1E:V\@)7,L('9A<FYO<W1N92!K;W!I:F4N`$YE
M(&UO<F5M('-H<F%N:71I("!K;VYF:6=U<F%C:6IS:V4@9&%T;W1E:V4@)7,N
M($QA:&MO('5P;W)A8FET92!A;&D@96YO(&]D(&]P8VEJ('IA('-H<F%N:71I
M(&MO9&\@>F%D86H@;F$@)7,@86QI(')OQ(UN;R!K;W!I<F%T92!S<&]D;FIO
M(&MO9&\@;F$@)7,N`$YI(&UO9V_$C64@:7-K86YJ92!,1$%0('-T<F7%OFYI
M:V$N`$YI(&UO9V_$C64@;V1S=')A;FET:2!P;W9E>F%V92!Z("(E<R(N`$YI
M(&UO9V_$C64@8<6^=7)I<F%T:2!S=&EK+B`E<RX`3FD@;6]G;\2-92!AQ;YU
M<FER871I(&1I<W1R:6)U8VEJ<VMI('-E>FYA;2X@)7,`3FD@;6]G;\2-92!N
M87!I<V%T:2!K;VYF:6=U<F%C:6IE('IA("(E<R(Z("5S`$YE(&YA:F1E;2!-
M;WII;&QA(%-I9&5B87(N(%!R979E<FD@86QI(&IE(&]D<')T+@`B)7,B('5P
M;W)A8FYI:W4@;F4@;6]R96T@9&]D96QI=&D@<VQE9&7$C6EH('!R879I8R!Z
M82!M87!O("(E<R(Z("5S`%!R9<6A=&5T;R!B97-E9&EL;R``1'+%OF%V80!4
M9<2-86II`%5S='9A<FD`57-T=F%R:2!N;W9O`%5S='9A<FD@<&]D;6%P90!!
M=G1O<B!D;W9O;&IE;FH`Q:!T979I;&MA(&MR961I=&YE(&MA<G1I8V4@`$AR
M=F'%H6MA`$MU8F$`4V5D86YJ92`T(')A>G9O:FYE('-T;W!N:F4`4V5D86YJ
M92!S96IE`%-E9&%N:FD@Q(UA<P!3961A;FII('5P;W)A8FYI:VD`4V5D86YJ
M92!V<F5M90!3961A;FIE('-T86YJ93H`3F%S=&%V:71E(&%K=&EV;F]S=&DL
M(&MI('-E(&)O9&\@:7IV<L6A:6QE(&]B('!R:6IA=FD@;F$@)7,N`$-I<&5R
M`$-I<FEL:6-A*$M/23@M4BD`0VER:6QI8V$@*%=I;F1O=W,M,3(U,2D`0VER
M:6QI8V$O56MR86II;G-K:2`H2T])."U5*0#$C67%H6MA(')E<'5B;&EK80!$
M1`!$3E,@*'!O9VQE:B!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P
M86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1N979N;P!0<F5G
M;&5D;W9A;&YI:R!D<F5V97-N92!S=')U:W1U<F4`4&]I>G9E9&)A(&)A>F4@
M<&]D871K;W8`1&%T=6T`1&%T=6T@<')E:F5M80!)>F)I<F$@9&%T=6UA`$1A
M;@!$96-E;6)E<@!0<FEV>F5T;P!0<FEV>F5T82!"87)V80!0<FEV>F5T82!I
M9&5N=&ET971A`%!R:79Z971A(&QU<&EN80!/<')E9&5L:71V90!:8G)IQ:%I
M`%IB<FG%H6D@<VMU<&EN;P!:8G)IQ:%I(&1N979N:6L`6F)R:<6A:2!D;W9O
M;&IE;FIE`$EZ8G)IQ:%I(&EN('!R9<2-:7-T:2!S<&]R;\2-:6QA`$EZ8G)I
MQ:%I(&]B<W1O:F7$C6D@86QT97)N871I=FYI('9Z;W)E8P!)>F)R:<6A:2!S
M<&]R;\2-:6QA`$EZ8G)IQ:%I(&1O=F]L:F5N:F$@>F$@(B5S(@!)>F)R:<6A
M96T@9&]V;VQJ96YJ92!Z82`B)7,B(&EN('9S82!P;V1D;W9O;&IE;FIA/P!)
M>F)R:<6A:2!I>F)R86YO(&ED96YT:71E=&\`27IB<FG%H6D@<&]D(&UA<&4`
M3F4@;6]R96T@:7IB<FES871I(&YA<W1A=FET=F5N92!AQ;YU<F%C:6IS:V4@
M<VMR:7!T92`B)7,B+@#$C&%S(&1O<W1A=F4`1&%N<VMA`$]P:<6A:71E('1E
MQ;YA=F\`3W!I<P!0;V1R;V)N;W-T:2`H='5D:2!V($AO<F1O=FD@;&]G(&1A
M=&]T96MI*3H`4&]D<F]B;F]S=&D@<V\@8FEL92!P<FEJ879L:F5N92!Z82!U
M<')A=FQJ86QC82X`4F%Z=F]J`%)O<VG%H<2-90!2;W-IQ:'$C64@>F$@<')E
M:L6A;FIO('5R;SH`4F]S:<6AQ(UE.@!);65N:6L`4')I:V'%OF5M(,2-87,@
M<&\@,C0@=7)N96T@<VES=&5M=3\`3F%S=&%V:71V92!P<FEK87IO=F%N:F$`
M4')I:V'%OFD@<&]D<F]B;F\@;F%P;W9E9`!0<FEK8<6^:2!N87!O=F5D("A4
M048I`%!R:6MAQ;YI('9E;&EK;W-T`$]B=F5S=&EL;R!O(&1O<W1A=FQJ96YI
M('!OQ:%T:0!$Q;YI8G5T:0!.92!Z8G)IQ:%I`$YE(&1O<W1O<&%J(&YE<&]S
M<F5D;F\@9&\@;VAR86YJ86YJ82YP:'`@`$%L:2!P<G9A('9R<W1A('9S96)U
M:F4@:6UE;F$@<&]L:C\@Q(UE(&II:"P@<')E=F5R:2!N86)I<F%L;FEK.@!$
M;VUI;FEC80!$;VUI;FEK86YS:V$@4F5P=6)L:6MA`$YI<W1E(')E9VES=')I
M<F%N:3\@4F5G:7-T<FER86IT92!S92X@`%!R96YE<VD@)7,`4')E;F5S:71E
M(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;R!K;W0@4$A0('-K<FEP=&\N`%!A
M9&%J;\2-:2!M96YI`%ID<F%V:6QA`$5L96MT<F]N<VMI(&YA<VQO=@!0<F5N
M;W,@96QE:W1R;VYS:VEH('-P;W)OQ(UI;"!V(%--4RUJ92!Z82!O<&5R871E
M<FIE+"!K:2!T;R!O;6]G;\2-86IO+@!%4E(`16MV861O<@!5<F5D:0!5<F5D
M:2!S=&]L<&5C`%5R961I('-K=7!I;F\`57)E9&D@9&]V;VQJ96YJ90!5<F5D
M:2!D;W9O;&IE;FIA`%5R961I(&1O=F]L:F5N:F$@>F$@)7,@`%5R961I(&UO
MQ;YN;W-T:2!Z83H`57)E9&D@9&]V;VQJ96YJ82!Z82`B)7,B`%5R961I(&1O
M=F]L:F5N:F$@>F$@)7,`27IO8G)AQ;YE=F%N:F4`16=I<'0`4V%L=F%D;W(`
M16QE:W1R;VYS:V$@<&_%H71A`$5L96MT<F]N<VMI(&YA<VQO=@!%;&5K=')O
M;G-K:2!N87-L;W8@<V4@;6]R82!U:F5M871I+@!%;&5K=')O;G-K82!P;\6A
M=&$@<R!P;W1R9&ET=FEJ;P!%;6%I;"U335,@4')E:&]D`%-M9<6A:VD`4')A
M>F5N;R!S<&]R;\2-:6QO+@!0<F%Z96X@<F5Z=6QT870N`%!R87IE;B!I<VMA
M;&YI:P!)>FML;W!I;2!V<W1A=FQJ86YJ92!S;&EK(&EZ($9O=&\@1V%L97)I
M:F4@=B!T96MS=#\`27IK;&]P:6T@;65N:2!Z(&1E<VYI;2!K;&EK;VT_`$MO
M;F5C(&QE=&$`5FYE<VET92!V87)N;W-T;F\@=G!R8<6A86YJ92P@:VD@8F\@
M<&]S=&%V;&IE;F\L(,2-92!B;W-T92!P;W1R96)O=F%L:7!O;F%S=&%V:71I
M('9AQ:%E(&=E<VQO+"!N<'(N(,."XH">:6UE('9AQ:%E9V$@;&IU8FQJ96[$
MC6MA(&IE/SH`5FYE<VET92!S<&]D;FIE(,2-<FME.@!%:W9A=&]R:6%L;F$@
M1W9I;F5J80!%<FET<F5J80!.87!A:V$`3F%P86MA('!R:2!U<W1V87)J86YJ
M=2!S=&]L<&$Z("5S+@!.87!A:V$@<')I(&)R:7-A;FIU('!O=F5Z879E('-I
M;FAR;VX@:7IA8VEJ93H@)7,`3F%P86MA('!R:2!B<FES86YJ=2!D;F5V;FEK
M82!S:6YH<F]N:7IA8VEJ93H@)7,N`$YA<&%K82!P<FD@<&]V97IO=F%N:G4Z
M("5S+@!.87!A:V$@<')I(&'%OG5R:7)A;FIU(&=E<VQA.B`E<RX`3F%P86MA
M('H@96QE:W1R;VYS:VEM('-P;W)OQ(UI;&]M+@!.87!A:V$@<')I('!I<V%N
M:G4@(B5S(BX`17-T;VYI:F$`171I;W!I:F$`17-T;VYI:F$`179R;W!A`%9S
M86MI:"`Q-2!M:6YU=`!6<V%K:2`R(&UI;G5T:0!6<V%K:6@@,S`@<V5K=6YD
M`%9S86MI:"`U(&UI;G5T`%9S86MA('!R:6IA=F$`5G-A:V4@<&]L('5R90!6
M<V%K;R!M:6YU=&\`4')I;65R('9R961N;W-T:3H`27IV961I`%!O=F7$C6%J
M`%!R:<2-86MO=F%N("<I)P!0<FG$C6%K;W9A;F$@:F4@8FEL82!B97-E9&$@
M86QI(&)E<V5D;F$@>G9E>F$@=B!N879E9&YI8V%H`$1A='5M('IA<&%D;&]S
M=&D`6F%S=&]P;FEK`$944"!N86QOQ;YI=&5V(&YA;65S=&ET=F4N`$YI('5S
M<&5L;R!V>G!O<W1A=FET:2!P<F5F97)E;F-E+@!0;W9E>F%V82!Z($Q$05`@
M<W1R9<6^;FEK;VT@;FD@=7-P96QA+@!0;W9E>F%V82!S(%--0B!S=')EQ;YN
M:6MO;2!N:2!U<W!E;&$@`$MO<&ER86YJ92!I>B`B)7,B+"!N:2!U<W!E;&\N
M`$MO<&ER86YJ92!N82`B)7,B+"!N:2!U<W!E;&\N`$YI('5S<&5L;R!V>G!O
M<W1A=FET:2!N;W9O(%-!4TP@<&]V97IA=F\N`$YI('5S<&5L;R!P<F5M86MN
M:71I(&LZ("5S(`!.96UO9V_$C64@<')E8G)A=&DZ("5S(`!/9&1A;&IN;P!&
M86QK;&%N9'-K:2!O=&]K:0!&97)S:VD@;W1O:VD@`$AU9&$@;F%P86MA(0!&
M87@`1F%X:0!&96)R=6%R`%!OQ(UU=&ET:2!S92!K;W0`4&_$C75T:71I('-E
M(&MO=#H`3F5K86H@;F%L:79O=@!.96MA:B!S;F7%OFYI:"!M971EQ;YE=@!-
M871R:6-A('!O;&IA`$9I9VQE="!#05!40TA!`$9I9VQE="!P:7-A=F$`1FED
MQ;YI`$1A=&]T96MA`,6@=&5T:F4@1&%T;W1E:SH@)7,@9&%T;W1E:P#%H'1E
M=&IE($1A=&]T96LZ("5S(&1A=&]T96L`57!R879I=&5L:B!D871O=&5K`$EM
M92!D871O=&5K90!)>F)I<F$@9&%T;W1E:V4N`$YA;&_%OFD@9&%T;W1E:V\`
M1&]D86YA(&1A=&]T96MA(&YI('!O9'!R=&$N`$9I;'1R:0!&:6YS:V$`4')V
M82!P;VQO=FEC80!0<G9A(,2-971R=&EN80!3=&%L;F4@=F5L:6MO<W1I`$]B
M<FYI`$UE9VQA`"5S(&UA<&$@;F4@;V)S=&%J82``2')A;F$`3F%P;W9E9"`H
M5$%&*0!$;F5V:2!N87!O=F5D:2X@*$YA<&]V961A(&QE(&QA:&MO('IE;&\@
M9&]L9V$I`%-T92!P;WIA8FEL:2!V8<6A92!G97-L;S\`;V)L:6ME`%-R9<2-
M80!3<F7$C64`4W)EQ(UE`%-R9<2-92`R`%1A8FQA('!O9V]V;W)O=@!0<F5U
M<VUE<FET979E`$9R`$9R86YC:6IA`$9R86YC:6IA+"!+;VQO;FEA;&YA(&UE
M=')O<&]L80!&<F%N8V]S:V$@1W9A:F%N82``1G)A;F-O<VMA(%!O;&EN97II
M:F$@`$9R86YC;W-K:2!J=<6^;FD@=&5R:71O<FEJ(`!/9`!/9"``4&]L;B!/
M<&ES.@!0;VQN82!L=6YA`%!O;&YO(&EM90!'86)O;@!'86UB:6IA`%5S='9A
M<FD@)7,@3F%S=&%V:71V90!'96YE<FER86H@:V]D;P!'<G5Z:6IA`$YE;<2-
M:6IA`$=A;F$`1VEB<F%L=&%R`$1A;F\@:6UE`%-P;&_%H6YE($UOQ;YN;W-T
M:0!0;VID:0!';V]G;&]V92!M87!E`$G%H<2-:2!Z($=O;V=L;VT`3&5S='9I
M8V$@<VEV:6YE(`!'<L2-:6IA`$=RQ:%K:2`H25-/+3@X-3DM-RD`1W)E;FQA
M;F1I:F$`1W)E;F%D80!3:W5P:6YS:V$@861M:6YI<W1R86-I:F$`26UE;F$@
M4VMU<&EN(&YE('-M96IO(&)I=&D@<')A>FYA`$%U=&A?;&1A<#H@3F4@;6]R
M96T@9&]D871I('-K=7!I;F4@)7,N(%-P;W)OQ(UI;&\@<W1R9<6^;FEK83H@
M`%-K=7!?;&1A<#H@3F4@;6]R96T@:7IB<FES871I('-K=7!I;F4@)7,`4VMU
M<%]L9&%P.B!.92!M;W)E;2!N861G<F%D:71I('-K=7!I;F4@)7,`4VMU<&EN
M90!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$1O=F]L:F5N
M:F$@>F$@9V]S=&4`2VYJ:6=A(&=O<W1O=@!'=FEN96IA`$=V:6YE:F$M0FES
M<V%O`$=V86IA;F$`2%1-3`!/=F5R:F5N96=A($A45%`@3FES96T@;F'%H65L
M+@!(86ET:0!(87-H($%L9V]R:71E;0!-96=L:6-A`$=L879A`$=L879E`$AE
M87)D(&]T;VL@:6X@36-$;VYA;&1O=F\@;W1OQ(UJ90!-;\2-;F$@;F5V:6AT
M80!(96)R96IS:VD@*$E33RTX.#4Y+3@M22D`5FG%H6EN80!0;VUOQ(T`4&]M
M;\2-;&YI:P!0;VQO8FQA`%1U:V%J(&IE('IAQ(UE=&5K(&1A=&]T96ME.@!6
M:7-O:V\`1&]M;W8`5F%T:6MA;@!$;VUAQ(UI(&YA<VQO=@!);65N:6L`1&]M
M8<2-:2!T96QE9F]N`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+
M;VQA8CH@3F5V96QJ879E;B`E<R!834P@<&]D871E:R!N86ID96X@=B!S<&]R
M;\2-:6QU("5S`$AO<F1E+TMO;&%B.B!.;V)E;F\@<W!O<F_$C6EL;R!S92!N
M92!U:F5M82!S('!R961M971O;2`E<P!(;W)D92]+;VQA8CH@5B!S<&]R;\2-
M:6QU("5S(&YI(&YA:F1E;B!N;V)E;B!P<F5D;65T('1I<&$@)7,`2&]R9&4O
M2V]L86(Z(%5S<&7%H6YO(&]D<W1R86YJ96X@)7,@(B5S(@!(;W)D92]+;VQA
M8CH@26YT96=R86-I:G-K82!N87!R879A('IA:'1E=F$@)V1O;7AM;"<@4$A0
M(&5K<W1E;GII:F\`2&]R9&4O2V]L86(Z($YE(&UO<F4@=7-T=F%R:71I(&YO
M=F\@6$U,(&1R979O('IA("5S`$AO<F1E+TMO;&%B.B!.92!M;W)E;2!O9'-T
M<F%N:71I("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.92!M;W)E;2!P;VEZ
M=F5D971I('IA($U)344@240@>F$@9&5L(&]D('9R<W1E("5S`$AO<F1E+TMO
M;&%B.B!.92!M;W)E;2!S:6YH<F]N:7II<F%T:2`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@3F4@;6]R96T@<VEN:')O;FEZ:7)A=&D@9&5L93H@)7,`2&]R
M9&4O2V]L86(Z($YE>FYA;F$@9&5L:71E=B`B)7,B`$MO;&EK;R!P;VQJ("AS
M=&]L<&-E=BEJ92!T86T_`%9L8<6^;F]S=`!6;&'%OFYO<W0Z(`!(=6UO<FES
M=&D`36%DQ;YA<G-K80!5<W1V87)J86YJ92!)34%0(&YA8FER86QN:6MA(&YI
M('5S<&5L;SH@)7,`0G)I<V%N:F4@24U!4"!N86)I<F%L;FEK82!N:2!U<W!E
M;&\Z("5S`%5S='9A<FIA;FIE(&MV;W1E($E-05`@;F%B:7)A;&YI:V$L(&YI
M('5S<&5L;SH@)7,`25`@3F%S;&]V`$E0($YA<VQO=B!N:2!N82!R87IP;VQA
M9V\N`$E0($YA<VQO=B!N:2!V(&1O=F]L:F5N:2!#2412('-K=7!I;FDN`%IA
M:VQE;FIE;B!)4"X`27-L86YD:6IA`%-A;6\@:6MO;F4`26MO;F4@>F$@)7,`
M26MO;F4@>B!B97-E9&EL;VT`261E;G1I9FEK86-I:G-K;R!I;64Z`"5S('IA
M(&]D<')E=&D@=B!N;W9E;2!O:VYU+"#$C64@;FD@<')A=FEL;F\@<')I:V%Z
M86YO+@#$C64@=FED:71E('1O('-P;W)OQ(UI;&\@:6X@<VQIQ(UI8V4@;F4L
M('!O;65N:2P@9&$@=F'%H2!B<G-K86QN:6L@;F4@;6]R92!O9'!R971I('-L
M:<2-:6-E+"!K:2!J;R#%OF5L:71E(&YA;&_%OFET:2X`1&]D86H@<VQI:V\`
M4VQI:V4`5FYO<RP@2V]R86L@)60`5FYEQ:%E;F\@<&]L:F4Z("5S`%9N9<6A
M96YA('!O;&IA.@!0;W-R961O=F%N(&YE<')A=FEL96X@=6MA>BX`3F5P<F%V
M:6QN;R!U<&]R86)N:<6A:V\@:6UE(&EN+V%L:2!G97-L;RX`3F5P<F%V:6QN
M;R!U<&]R86)N:<6A:V\@:6UE(&%L:2!A;'1E<FYA=&EV96X@;F%S;&]V+B!0
M;W-K=7-I=&4@>FYO=F$@86QI(&MO;G1A:W1I<F%J=&4@=F'%H65G82!S:W)B
M;FEK82P@Q(UE('!O=')E8G5J971E(&YA9&%L:FYJ;R!P;VUOQ(TN`$EN9&EJ
M80!0;W-A;65Z;FD@57!O<F%B;FEK:2``26YD;VYE>FEJ80!);F9O<FUA8VEJ
M92!O('-E<W1A;FMU`$EN9F]R;6%C:6IE(&YI<V\@=F7$C2!D;W-E9VQJ:79E
M+@!6<W1A=FD@86QT97)N871I=F5N('9Z;W)E8P!6<W1A=FET92!E;&5K=')O
M;G-K:2!N87-L;W8@;F$@:V%T97)E9V$@;&%H:V\@<')E:FUE=&4@;F]V;R!G
M97-L;SH`5G-T879I=&4@<W!O<F_$C6EL;P!6<&G%H6ET92!Z86AT979A;B!O
M9&=O=F]R(&YA('9A<FYO<W1N;R!V<')AQ:%A;FIE.@!3=&%N:F4@;F$@<F'$
MC75N=2!N92!Z861O<W1U:F4@>F$@<&_%H6EL:F%N:F4@;F$@Q;YE;&IE;B!S
M<&ES96LN`%-T86YJ92!N82!R8<2-=6YU(&YE('IA9&]S='5J92X`0V5L;R#%
MH71E=FEL;P!397IN86T@8V5L:6@@Q:%T979I;`!.979E;&IA=F5N(%5$2"X@
M*%5S97(@1&%T82!(96%D97(I+@!.979E;&IA=F5N(%I)4"!P;V1A=&5K+B``
M3F5V96QJ879N82!A<&QI:V%C:6IA+@!.979E;&IA=FYI($E$('!A:V5T+@!.
M979E;&IA=FYI('!O9&%T:VD@<V\@8FEL:2!O9'!O<VQA;FDN`$YE=F5L:F%V
M96X@;F%S;&]V(&YA<VQO=FYI:V$N`"!.979E;&IA=FYA(&]B;&EK82!D871O
M=&5K92``3F5V96QJ879E;B!L:6-E;L2-;FD@:VQJ=<2-+@!/9')E:F5N(&YE
M=F5L:F%V96X@:W)A:BX`3F5V96QJ879E;B!T:7!?;7-G+@!.979E;&IA=F5N
M(&%L:2!M86YJ:V%J;\2-(&%P:5]I9"X`3F5V96QJ879N:2!A;&D@;6%N:FMA
M:F_$C6D@<&%R86UE=')I+@!.979E;&IA=FYO(&1O=F]L:F5N:F4@<W1A<L6A
M978N`$YE=F5L:F%V96X@<&%R=&YE<FIE=B!I9"X`3F5V96QJ879N82!K;V1A
M(&%R=&EK;&$N`$YE=F5L:F%V96X@<')O=&]K;VPN`$YE=F5L:F%V96X@;F%S
M;&]V;FEK.B`B)7,B`"!.979E;&IA=F5N(&]B:F5K="!D96QJ96YJ82``3F5V
M96QJ879E;B!I>G9O<FYI(&YA<VQO=BX`($YE=F5L:F%V96X@=6YI:V]D('!O
M9&%T96L`26YV96YT=7)A+W!O<&ES`$]B<FYI(&EZ8F]R`$ER86XL($ES;&%M
M<VMA(%)E<'5B;&EK80!)<F%K`$ER<VMA`%!O<V%M97IN92!N979I:'1E`$EZ
M<F%E;`!)>F1A:F%T96QJ`$ET86QI:F$`2F%M86IK80!*86YU87(`2F%P;VYS
M:V$`2F%P;VYS:VD@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:6IA`$IU
M;&EJ`$IU;FEJ`$MA>F%H<W1A;@!/8F1RQ;YI;2!I>G9I<FYI:S\`2V5N:6IA
M`$ME<F)E<F]S('-T<F7%OFYI:R!Z879R;FEL(&]V97)I=&5V+@!+97)N96P@
M;F]V:6YC:0!5<W1V87)I($ML:G7$C2``3V1T:7,@2VQJ=<2-80!$;VS%OFEN
M82!+;&IUQ(UA`%1I<"!+;&IUQ(UA(`!5<&]R86)A($ML:G7$C6$@`$ML:G7$
MC2#%OF4@;V)S=&%J82!N82!J879N96T@:VQJ=<2-;F5M('-T<F7%OFYI:W4N
M`$]T<F]C:0!+:7)I8F%T:2``2V]R96IA+"!$96UO:W)A=&G$C6YA(&QJ=61S
M:V$@<F5P=6)L:6MA(`!+;W)E:F$L(%)E<'5B;&EK82``2V]R96IS:VD@*$55
M0RU+4BD`2W5V86IT(`!+:7)G:7II:F$@`$IE>FEK`$QA;W,@;&IU9'-K82!D
M96UO:W)A=&G$C6YA(')E<'5B;&EK80!:861N:F$@<&]L;W9I8V$`6F%D;FIA
M('-P<F5M96UB82!G97-L83H@`%IA9&YJ82#$C65T<G1I;F$`6F%D;FIE(&'%
MOG5R:7)A;FIE.@!:861N:F$@<')I:F%V83H@)7,@`%IA9&YJ82!P<FEJ879A
M.B`E<R!I>B`E<P!:861N:F$@<')I:F%V83H@3FEK;VQI`$QA='9I:F$@`%!R
M879O`$QI8F%N;VX`3&5V;R!O9VQA=FQJ90!6<F5D;F]S=&D@;F$@;&5V:0!,
M97-O=&\`4F%V96X`3&EB97)I:F$`3&EB:6IA(`!,:65C:'1E;G-T96EN(`!2
M86AE;"!P<L6A96,`4F%H96P@9&7%O@!:9V]D86H@<F%H96P@9&7%O@!0;WIN
M;R!R86AE;"!D9<6^`%!L;VAA`%!L;VAA('H@9W)M96YJ96T`4F%H96P@<VYE
M9P!3;F7%OFYI(&UE=&7%O@!0;W9E>F%V80!0;W9EQ;YI(&4M;F%S;&]V(',@
M;V)R87IC96T@>F$@<V5S=&%V;R!N;W9E('!OQ:%T;R!M92!P<FEK87IO=F%N
M:F5M`%!O=F5Z879E`$QI;G5X('!IQ:%K;W1E:P!397IN86T@+2!U<&]R86)N
M:6L@;&%H:V\@=FED:2!M87!O`%-E>FYA;2!P;V1A=&MO=FYI:"!B87H`4V5Z
M;F%M(%1E;2!0;VUOQ(UI(`!397IN86T@=&%B96P`(%-E>FYA;2!!<FAI=F$@
M`%-E>FYA;2!0;VUOQ(UI(`!397IN86T@261E;G1I=&5T(`!397IN86T@3&%S
M=&YI:V]V(`!397IN86T@4&_%H71E(`!397IN86T@4')I:F%V(`!397IN86T@
M3V1J878@`%-P:7-E:R!S97IN86UA('-E:B!N:2!U<W!E;#H@)7,N`%-E>FYA
M;2!U<&]R86)N:6MO=B!N:2!M;V=OQ(UE.B`E<P!397IN86T@=7!O<F%B;FEK
M;W8@;FD@;6]G;\2-+@!,:71E<F%T=7)A`$QI='9A(`!.86QA9V%M+BXN`$QO
M:V%L;FD@Q(UA<SH`3&]K86QI>F%C:6IA`$UE<W1O`%!R:6IA=F$`3V1J879A
M(',@<')E9&AO9&YE('-Y;F,@<V5J92``3V1J879A`%!R:6IA=F$`4')I:F%V
M82!N82!O<')A=FEL80!0<FEJ879A(&YI('5S<&5L82X@57!O<F%B;FG%H6MO
M(&EM92!A;&D@9V5S;&\@;F5P<F%V:6QN;R!V;F7%H65N;P!0<FEJ879A(&YI
M('5S<&5L80!$;VQG;R!"97-E9&EL;P!,:G5B97IE;@!.:7IE:P!,=6MS96UB
M=7)G`$U-`%-P;W)OQ(UI;&\@9&YE=F$`35,M5$Y%1B!0<FEP;VYK82!N:2!V
M<V5B;W9A;&$@<&]D871K;W8N`$U31P!-86-A=0!-86ME9&]N:6IA+"!F;W)M
M86QN82!*=6=O<VQO=F%N<VMA(')E<'5B;&EK80!-861A9V%S:V%R`,2-87)O
M8F5N`$5L96MT<F]N<VMI(&YA<VQO=@!!9&UI;FES=')A=&]R('!OQ:%T90!-
M86QA=FD`36%L97II:F$`36%L9&EV:0!-86QI`$UA;'1A`%5R961I=&4@<V5Z
M;F%M(&MA=&5G;W)I:B!S(&MA=&5R:6UI(&)O<W1E(&]Z;F'$C6EL:2!P;W-T
M879K92!I;B!P<FEP861A:F_$C64@8F%R=F4@>F$@=&4@:V%T96=O<FEJ92X`
M6F5M;&IE=FED($UA<#(T`%IE;6QJ979I9"!-87!1<F5S=`!3:')A;FIE;F4@
M<&]V97IA=F4`36%R96,`3WIN8<2-:2!Z('IA<W1A=FEC86UI(%9I9&5N;R].
M979I9&5N;P!/>FYAQ(UI('H@;W-T86QI;6D@>F%S=&%V:6-A;6DH;G!R+B!0
M;VUE;6)N;R]/9&=O=F]R:F5N;RD`36%R<VAA;&QO=F\@;W1OQ(UJ90!-87)T
M:6YI<75E`%5J96UA;FIE('!O;&H`36%V<F5T86YI:F$`36%V<FEC:75S`$YE
M:G9EQ(T@9&]V;VQJ96YI('IN97-E:P!-86MS:6UA;&YI(&1E;&D@<W!O<F_$
MC6EL82!P<F5K;W)AQ(UE;FDN`$UA:W-I;6%L;F$@=&5M<&5R871U<F$@>F%D
M;FII:"`R-"!U<CH`36%K<VEM86QN82!T96UP97)A='5R82!Z861N:FEH(#8@
M=7(Z`$UA:W-I;6%L;F\@Q:%T979I;&\@8FQO:V]V('!O<G1A;&$`36%K<VEM
M86QN82!D;VS%OFEN80!-86H`36%Y;W1T90!:9')A=FEL;R`H365D:6-I;F$I
M`,2-;&%N:0!4:7`@;65N:6IA.@!3<&]R;\2-:6QO`%-P;W)OQ(UI;&\@:F4@
M8FEL;R!U<W!EQ:%N;R!P<F5V97)J96YO+"!T;V1A('!O9'!I<VYI:V]V96=A
M('!O=')D:6QA(&YI(&)I;&\@;6]G;\2-92!P<F5V97)I=&DN`%-P;W)OQ(UI
M;&\@:F4@<&]T96ML;RX`5&EP(%-P;W)OQ(UI;&$`365T87(@=G)E;64`365T
M87(@8FQO:R!N:2!N82!R87IP;VQA9V\N`%!O9')O8FYO<W1I('-O(&)I;&4@
M<')I:F%V;&IE;F4@>F$@=7!R879L:F%L8V$N`$UE=&%R1$(@;FD@<&]V97IA
M;BX`4&]S=&]P96L`)R5S)R!P;W-T;W!E:R!N:2!D;VQOQ(UE;BX`4&]S=&]P
M96L@;FD@9&]L;\2-96XN(%!O<W1O<&5K(&-E;&EC93H@)7,`365T<FG$C6YI
M`$UE:&EK80!-:6MR;VYE>FEJ82P@1F5D97)A=&EV;F$@9'+%OF%V80!4:7`@
M9&%T;W1E:V4`36EN:6UA;&YA('1E;7!E<F%T=7)A('IA9&YJ:6@@,C0@=7(Z
M`$UI;FEM86QN82!T96UP97)A='5R82!Z861N:FEH(#8@=7(Z`$UI;FEM86QN
M82!S=&%R;W-T(&=E<VQA(,6A92!N:2!P;W1E:VQA`$]G;&5D86QO`$UN;V=O
M<W1R86YS:V$`4&]G<F7%H6%N(%!%05(@<&%K970L($A45%`@>F%H=&5V86XN
M`%!O9W)EQ:%A;F\@240@<W!O<F_$C6EL;RX`4&]G<F7%H6%N;R!S<&]R;\2-
M:6QO(&\@>F%H=&5V86YE;2!014%2('!A:V5T=2X`4&]G<F7%H6%N82!)1"!S
M96IA+@!0;P!-;V)I;&YA('!OQ:%T80!:;65R;F\`1&%T=6T@<W!R96UE;6)E
M`$UO9'5L:0!-;VQD879I:F$L(')E<'5B;&EK80!-;VYA:V\`36]N9V]L:6IA
M`$UE<V5C(&EN(&QE=&\`365S9<2-;F\`36]N='-E<G)A=`!,=6YI;F4@;65N
M90!6('9R<W1I("5D(&IE(&YA:F1E;FEH('9EQ(T@<&]L:B!O9"!P<F5D=FED
M96YI:"`E9"X`36%R;VMO`%!R971EQ;YN;R!J87-N;P!0<F5T9<6^;F\@;V)L
M8<2-;F\`4')E=&7%OFYO(&]B;&'$C6YO(&EN('9E=')O=FYO`%!R971EQ;YN
M;R!S;V[$C6YO`%!O;6%K;FD@<V4@9&]L`%!O;6%K;FD@<V4@=B!L979O`%!O
M;6%K;FD@<V4@=B!D97-N;P!0;VUA:VYI('-E(&=O<@!0;VUA:VYI('-E(&1O
M;`!0;VUA:VYI('-E(&=O<@!-;WIA;6)I:P!69<2-(&YI=F]J;FD@<&%D86IO
MQ(UI('-P:7-K:0!-=6QT:6UA<"!52R!Z96UL:F5V:60N`$UN;V=O:W)A=&5N
M(&EZ8F]R`$UO:B!R8<2-=6X`4&]D871K:2!M;VIE9V$@<F'$C75N80!-;VH@
M<&]R=&%L`$]B;&EK82!M;VIE('!R=F4@<W1R86YI`$UJ86YM87(`3F4L('-E
M(&YE('-T<FEN:F%M`$EM90!.86UI8FEJ80!.875R=0!.97!A;`!.:7IO>F5M
M<VMA`$YI>F]Z96US:VD@06YT:6QI`$YE='-C87!E(&]S;F]V;FD@55),`"!.
M971S8V%P92!#02!54DP@>F$@<')E:VQI8P!.87-L;W8@3F5T<V-A<&4@8V5R
M=&EF:6MA=&$`($YE='-C87!E(&]B;F]V:71V96YI(%523``@3F5T<V-A<&4@
M55),('IA('!R96ML:6,`3F5T<V-A<&4@4U-,(&EM92!S=')EQ;YN:6MA`$YE
M='-C87!E('5R861N:2!K;VUE;G1A<@!4:7`@3F5T<V-A<&4@8V5R=&EF:6MA
M=&$`3VUR9<6^:F4`3FEK;VQI`$YO=F$@2V%L961O;FEJ80!.;W9A(&MA=&5G
M;W)I:F$`3F]V82!,=6YA`$YO=F\@=7!O<F%B;FG%H6MO(&EM90!.;W9A(%IE
M;&%N9&EJ80!.;W9O(&=E<VQO`$YO=F\@9V5S;&\@8F\@<&]T96ML;R`E>"X`
M3F]V;R!G97-L;R!S92!N92!U:F5M82X`3F]V:6-E`$YO=FG$C6%R<VMA('-K
M=7!I;F$`3F%S;&5D;FII`$YA<VQE9&YJ92`T('-T;W!N:F4`3F%S;&5D;FIA
M(&UOQ;YN;W-T`$YA<VQE9&YJ:3X`3FEK87)A9W9A`$YI9V5R`$YI9V5R:6IA
M`$YI9V5R`$YI=64`3F]B961E;@!.:2!D;W-T;W!N:6@@<&]D871K;W8@;R!K
M;VYF:6=U<F%C:6II(&1A(&)I('!O:V%Z86P@<F%Z;&EK92X`4W1R871E9VEJ
M82!Z82!I>F1E;&%V;R!)4T\@<VQI:RP@;FD@9&]S=&]P;F$N`$YI('!A:V5T
M;F4@<')E9&QO9V4`3F$@Q;YE;&5N96T@;65S="!B96QEQ;YK82!N92!O8G-T
M86IA+@!:82!-0T%,(&]V97)I=&5V(&YI(&MO;&5D87)S:V5G82!I;65N80!N
M:2!S<')E;65N:F5N;P!.82!T96H@<W1O<&YJ:2!N92!D;V1A:F%M;R!O=')O
MQ:%K:6@@9&]V;VQJ96YJ+@!:82`E<R!N:2!S<&5C:69I8VER86YI:"!K;VYF
M:6=U<F%C:6IS:VEH(&EN9F]R;6%C:6HN`%IA($944"!61E,@;FD@<&]S96)N
M:6@@:6YF;W)M86-I:BX`(%IA(%-13"!61E,@;FD@<&]S96)N:6@@:6YF;W)M
M86-I:BX`(%IA(&1A=&]T96MO+5-13"!61E,@;FD@<&]S96)N:6@@:6YF;W)M
M86-I:BX`3FD@<W1A;FIA(&YA(')AQ(UU;G4N`$YI(&1E<W1I;F%C:6IE`$YI
M(&YA;&_%OF5N:6@@9&%T;W1E:RX`3F4@;F%J9&5M(&EK;VXN`$UE<W1O(&YI
M(&YA<W1A=FQJ96YO+@!-97-T;R!N:2!N87-T879L:F5N;RX`3F]B96YO('-P
M;W)OQ(UI;&\@9&]S=&%V;&IE;F\N`$YI('-P96-I9FEC:7)A;F\@;F]B96YO
M(&EM92X`3FD@<W!E8VEF:6-I<F%N;R!N;V)E;F\@Q:%T979I;&\N`$YO8F5N
M:6@@;V9E;GII=FYI:"!S<F7$C2X`4&]T(&1O(&)I;F%R;F4@9&%T;W1E:V4@
M3W!E;E-33"!N:2!B:6QA(&YA<W1A=FQJ96YA+B!/<&5N4U-,(&)I;F%R;F$@
M9&%T;W1E:V$@:F4@<&]T<F5B;F$@>F$@9&5L;R!S(%!+0U,@,3(@<&]D871K
M:2X`3F4@<W!R96IE;6%M;R!Z8<2-87-N:6@@<')I:F%V`$MV;W1A(&YI(&YA
M<W1A=FQJ96YA+V1O;&_$C65N82X`3FD@<W!E8VEF:6-I<F%N;R!L;\2-:6QO
M+@!.:2!T86ME(&1A=&]T96ME`$YE(&YA:F1E;2!Z8<2-87-N92!M87!E('IA
M('!R961P;VUN:6QN:6LN`$YO8F5N;R!U<&]R86)N:<6A:V\@:6UE(&EN+V%L
M:2!G97-L;R!N:2!B:6QO('!O<VQA;F\N`%!O=G)A=&YI:"!V96QJ879N:6@@
M6$U,('!O9&%T:V]V(&YI`$)R97H@=G)E9&YO<W1I`%8@;W)I9VEN86QN:2!K
M;VYF:6=U<F%C:6II(&YE(&YA:F1E;2!N;V)E;F4@<F%Z;&G$C6EC92X@3V)N
M;W9I=&D@:V]N9FEG=7)A8VEJ;RX`5B!V8<6A:2!K;VYF:6=U<F%C:6II(&YE
M(&YA:F1E;2!N;V)E;F4@<F%Z;&G$C6EC92X@3V)N;W9I=&4@:V]N9FEG=7)A
M8VEJ;RX`3F]B961E;@!.;W)D:6IS:VD@*$E33RTX.#4Y+3$P`$YO<F9O;,6A
M:VD@;W1O:VD`4V5V97)N82!P;VQO8FQA`%-E=F5R;FD@36%R:6%N<VMI(&]T
M;VMI`$YO<G9EQ:%K80!.92!K87-N96IE`$YE('!R96H`3FD@:6UE;FEK`$YI
M(&EZ=F5D96YO+@!.92!P;V1P:7)A;0!:87!I<VMI`$YI('9P:7-A;FEH(&)E
M<V5D('IA(&ES:V%N:F4L('9R;FET92!S92!N87IA:BX`3F]V96UB97(`Q:!T
M979I;&\`Q:!T979I;&\@>FYA:V]V`,6@=&5V:6QO('-T;VQP8V5V`,6@=&5V
M:6QO('9R<W1I8P!.:2!S<&5C:69I8VER86YI:"#%H71E=FEL:R!Z82!AQ;YU
M<FER86YJ92!I;B!D:7-T<FEB=6-I:G-K:2!S97IN86TN`%IA9&5V80!5<W1V
M87)J86QE8R!P<F5D;65T;W8`3W-M:<6A:VD`3VMT;V)E<@!0:7-A<FYA`%-T
M87)O(&EN(&YO=F\@9V5S;&\@;6]R871A(&)I=&D@<F%Z;&G$C6YA+@!3=&%R
M;R!'97-L;P!3=&%R;R!G97-L;R!N:2!P<F%V:6QN;RX`3VUA;@!-87!E('8@
M<VMU<&YI('5P;W)A8FD@<&]D<&ER82!S86UO($E-05`@<W1R9<6^;FEK+@!3
M86UO(&YE<W)A;6YE(&EZ:F%V90!$;W9O;&IE;B!J92!L92!E;B!E;&5K=')O
M;G-K:2!N87-L;W8N`$QE(&QA<W1N:6L@86QI('5P<F%V;FEK('-I<W1E;6$@
M;&%H:V\@>F%M96YJ82!L87-T;FG%H71V;R!A;&D@;&%S=&YI:V]V;R!D;W9O
M;&IE;FIE('IA(&1E;&7%OBX`3V1P<FD@=B!N;W9E;2!O:VYU`$]D<')T85-3
M3"!N87!A:V$Z($YE(&UO<F5M('!O=GIE=&D@9&%T=6UA(&EZ(&]Z;F'$C65N
M96=A(%,O34E-(&1E;&$N`$]P97)A=&EV;FD@<VES=&5M`$UOQ;YN;W-T:0!-
M;\6^;F]S=&D@>F$@)7,`3W)G86YI>F%C:6IA`$]R9V%N:7IA8VEJ<VMA(&5N
M;W1A`$]R9V%N:7IA8VEJ80!)>G9I<FYE(,6A86)L;VYE(&%P;&EK86-I:@!)
M>G9I<FYI(,6A86)L;VYE('8@)7,Z`$1R=6=O`$]S=&%L92!I;F9O<FUA8VEJ
M90!$;W9O;&IE;FIA(&QA<W1N:6MA`$]V97)J96YJ92!N:2!U<W!E;&\`4$5!
M4CHZ(&=O;FEL;FEK(%!OQ:%T90!$:6=I=&%L96X@<&]D<&ES(%!'4`!+;V1I
M<F%N:2!01U`@<&]D871K:0!*879N:2!K;&IU92!01U``4&]D<&ES86YI+VMO
M9&ER86YI(%!'4"!P;V1A=&MI`%!(4"!K;V1A`%!(4"!L=7!I;F$`4&]P;VQD
M;F4@<F%H96P@9&7%O@!0;W!O;&1N92!D9<6^`%!O<&]L9&YE(&YA;&EV:0!0
M;W!O;&1N92!S;F5G+@!0;W!O;&1N92!S;F7%OFYI(&UE=&7%OFD`4&]P;VQD
M;F4@<V]N8V4`4&]P;VQD;F4@;F5V:6AT90!0;V=R9<6A86YA(%!/4TE8(&5K
M<W1E;GII:F$`4$A0(&QU<&EN80!086MI<W1A;@!086QA=0!086QE<W1I;FMI
M(&]K=7!I<F%N:2!T97)I=&]R:6H`4&%N86UA`%!A<'5A($YO=F$@1W9I;F5J
M80!087)A9W9A:@!$96QN;R!O8FQAQ(UN;P!'97-L;P!'97-L;R!U<W!EQ:%N
M;R!S<')E;65N:F5N;P!.97!R879I;&YO(&=E<VQO`%IA(%)!1$E54R!O=F5R
M:71E=B!J92!Z86AT979A;F\@9V5S;&\N`$=E<VQO(&EN('!O=')D:71E=@!'
M97-L;SH`1V5S;&\Z(`!'97-L;R!S92!M;W)A('5J96UA=&DN`%!R:6QE<&D`
M3F5P;W1R:F5N92!P<FEJ879E`$QJ=61J90!)>G9RQ:%I('9Z9'+%OF5V86QN
M82!D96QA`$EZ=G+%H6EM('9Z9'+%OF5V86QN82!D96QA(&]B('!R:6IA=FD_
M`$1O=F]L:F5N:F4`(B5S(B!D;W9O;&IE;FIE(&YI(&EZ8G)I<V%N;RX`1&]V
M;VQJ96YJ92!J92!Z879R;FIE;F\N`$1O=F]L:F5N:F$`57!R879N:<6A:V$@
M9&]V;VQJ96YJ80!/<V5B;F4@:6YF;W)M86-I:F4`4&5R=0!,:G5B;&IE;L2-
M:VD`1FEL:7!I;FD`5&5L969O;@!&;W1O9W)A9FEJ90!0:71C86ER;@!0<F]S
M:6UO+"!D82!V;F5S971E(&UE<V5C(&EN(&QE=&\N`%!R;W-I;6\L(&1A('9N
M97-E=&4@:6UE(&YO=F4@:V%T96=O<FEJ93H`4')O<VEM;RP@9&$@=FYE<V5T
M92!V96QJ879E;B!)4"!N87-L;W8N`%!R;W-I;6\L(&1A('9N97-E=&4@=F5L
M:F%V96X@9&%T=6TZ('!R979E<FET92#%H71E=FEL;R!D;FD@=B!M97-E8W4N
M`%!R;W-I;6\L(&1A('9N97-E=&4@<')A=FEL96X@Q(UA<RX`4')O<VEM;RP@
M9&$@<')I<')A=FET92!P;W9Z971E:R!T9<6^878N`%!R;W-I;6\L(&1A('-I
M(&EZ8F5R971E('5P;W)A8FYIQ:%K;R!I;64@:6X@9V5S;&\N`%!R;W-I;6\L
M('!R96)E<FET92!S;&5D9<2-92!B97-E9&EL;RX@Q(UE(,6^96QI=&4@=7!O
M<F%B;&IA=&D@=&$@<VES=&5M+"!S92!M;W)A=&4@<W1R:6YJ871I(',@<&]G
M;VII+@!0<F]S:6TL('9N97-I=&4@:6UE(&YO=F4@:V%T96=O<FEJ93H`4&]L
M:G-K80!0;VQI=&EK80!!;FME=&4`4&]R='5G86QS:V$`3V1D86H@=B!T;R!M
M87!O("AN:2!Z86AT979A;F\@;V0@24U!4"D`4&%D879I;F4@=B!Z861N:FEH
M("5S('5R86@Z`%!A9&%V:6YE/&)R("\^8VAA;F-E`"!0<F5F<U]L9&%P.B!Z
M86AT979A;F5G82!,1$%0(')A>G1E9V$@;F4@;F%J9&5M+@!4;&%K`%1L86L@
M;F$@;6]R<VMI('9IQ:%I;FDZ`%1L86LZ(`!0<F5D;V=L960`4')E:L6A;FIE
M(&UOQ;YN;W-T:0!:87-E8F5N(&ML:G7$C0!0<F]B;&5M`%H@;W!I<V]M('-O
M('1EQ;YA=F4N+@!0<F]J96MT:0!486MO:L6A;FIE(&)E<V5D:6QO`$IA=FYI
M(&ML:G7$C0!!;&=O<FET96T@:F%V;F5G82!K;&IUQ(UA`$EN9F]R;6%C:6IE
M(&IA=FYE9V$@:VQJ=<2-80!*879N:2]Z87-E8FYI('!A<B!K;&IUQ(UE=B!N
M:2!B:6P@=7-P9<6A;F\@9V5N97)I<F%N+@!0;W)T;W)I:V\`4')EQ(UI<W1I
M('-P;W)OQ(UI;&$`2V%T87(`4&]I>G9E9&)A`$MV;W1A`%)302!J879N:2!K
M;&IUQ(T@*"5D(&)I=&]V*0!)>F)E<FET92!R861I;P!$9<6^`$1EQ;X@>FIU
M=')A:@!$9<6^('!O<&]L9&YE`$YA;&EV`$1EQ;X@:6X@<VYE9P!$9<6^('8@
M<VYE9P!3<F7$C6$`4F%Z;65R:F4`0F5R:0!"97)I('-P;W)OQ(UI;&\`4W1E
M('!R97!R:<2-86YI+"!D82#%OF5L:71E('IB<FES871I("5S/R!)>F)R:7-A
M(&YI(&UO9V_$C64@<')E:VQI8V%T:2X`4W1E('!R97!R:<2-86YI+"!D82#%
MOF5L:71E('IB<FES871I('5P;W)A8FYI:V]V92!P;V1A=&ME('IA('5P;W)A
M8FYI:V$E<S\@27IB<FES82!N:2!M;V=OQ(UE('!R96ML:6-A=&DN`$]S=F7%
MOFD`3W-V9<6^:2!D:6YA;6G$C6YI(&UE;FD@96QE;65N=&]V.@!/<W9EQ;YI
M('!O<G1A;#H`4F5G97@`27-K86QN:6L@<F%Z;65R:6H`4&]N;W9N;R!N86QO
MQ;YI`%!R:7!O;6)E`$]D9&%L:F5N:2!S=')EQ;YN:6MI`$]D9&%L:F5N(%52
M3"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1R86YI`$]D
M<W1R86YI('-T;VQP96,`3V1S=')A;FD@<&%R`$]D<W1R86YI('-H<F%N:F5N
M;R!S:W)I<'1O(&EZ('-T<F7%OFYI:V]V92!Z8<2-87-N92!M87!E`$]D<W1R
M86YI('5P;W)A8FYI:V$`3V1S=')A;FD@=7!O<F%B;FEK83H@)7,@`%IA:'1E
M=FD@;F4@;6]R96T@=6=O9&ET:2X@5G)N:F5N82!J92!N87!AQ(UN82!K;V1A
M.B``3F4@;F%J9&5M('IA:'1E=F%N96=A('-E<G9I<V$N`%IA:'1E=F%N:2`B
M)7,B(&YI('!O9')O8FYO(&]B;&EK;W9A;B!V("5S(&MO;F9I9W5R86-I:FDN
M`%IA:'1E=F%N:2`B)7,B(&YI('!O9')O8FYO(&]B;&EK;W9A;B!V(%9(4R!K
M;VYF:6=U<F%C:6II+@!:86AT979A;FD@)R5S)R!N:2!P;V1R;V)N;R!O8FQI
M:V]V86XN`%IA:'1E=F%N82!D871O=&5K80!0;VYA<W1A=FD`4&]N87-T879I
M(&=E<VQO`%!O;F%S=&%V:71E('9AQ:%E(&=E<VQO`$]B;F]V:71E('IA9&YJ
M;R!P;VEZ=F5D8F\`6F%D971K:0!6<FYI('-E(&YA($UOQ;YN;W-T:0!0;VYO
M=FYO('9P:<6A:71E(&YO=F\@9V5S;&\`4&]N;W9N;R!Z9')UQ;YI`%!O=G)N
M:2!K;VYF:6=U<F%C:6IO`%9R;FD@<V4@;F$@;6_%OFYO<W1I('5R96IE=F%L
M;FEK82!B97-E9&EL80!%;FEG;64`1&5S;F\@;V=L879J90!$97-N92!V<F5D
M;F]S=&D`1G5N:V-I:F$`4F]M=6YI:F$`3V)R;FD@>F$@,3@P`$]B<FYI(&YA
M(&QE=F\`3V)R;FD@;F$@9&5S;F\`6F'%OF5N:0!2=7-I:F$`4G5A;F1A`"!3
M+TU)344@:W)I<'1O9W)A9G-K:2!P;V1P:7,`4R]-24U%(&MO9&ER86YO('-P
M;W)OQ(UI;&\`4T%33"!/=F5R:F%N:F4@;FD@=7-P96QO`%--4R!S<&]R;\2-
M:6QO`%-13"!L=7!I;F$`4U%,('-T879E:R!Z82!P;VEZ=F5D8F\@=G)E9&YO
M<W1I`%-32`!54U!%2`!344P@;'5P:6YA`%-A`%-V971A($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,@`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A
M;F0@36EQ=65L;VX@`%-A:6YT(%9I;F-E;G0@:6X@1W)E;F%D:6YE`%-A;6]A
M`%-A;B!-87)I;F\`4V%O(%1O;64@:6X@4')I;F-I<&4`4V%T96QI='-K:2!O
M<VMR8F]V86QE8P!3875D<VMA($%R86)I:F$`4VAR86YI`%-H<F%N:2`B)7,B
M`%-H<F%N:2`E<R``4VAR86YI($UOQ;YN;W-T:0!3:')A;FET92!G96YE<FER
M86YO(&MO;F9I9W5R86-I:F\@:V]T(%!(4"!S:W)I<'1O(&YA('IAQ(UA<VYI
M(&UA<&D@=F'%H65G87-T<F7%OFYI:V%D:7)E8W1O<GDN`%-H<F%N:F5N82`E
M<R!K;VYF:6=U<F%C:6IA`%-H<F%N:F5N82!N87-T879I='9E;F4@<VMR:7!T
M82!N861G<F%D;FIE(&YA.B`B)7,B+@!287ID:79J86YA(&YE=FEH=&$@>B!G
M<FUE;FIE;0!:;F%N;W-T`$G%H<2-:0!)<VMA;&YI:VD`27IB97)I(&1A=&]T
M96MO`$EZ8F5R:2!D871U;0!)>F)E<FD@<VMU<&EN;RP@:VD@:F\@Q;YE;&G%
MH2!D;V1A=&DN`$EZ8F5R:2!N;W9E9V$@;&%S=&YI:V$`27IB97)I('-T<F7%
MOFYI:P!)>F)E<FD@=7!O<F%B;FEK82P@:VD@9V$@Q;YE;&G%H2!D;V1A=&D`
M27IB97)I('9S90!)>F)E<FD@<&]P;VQN(&1A='5M`$EZ8F5R:2!P<F5D;65T
M`$]D:VQJ=6MA:B!V<V4`6FYA:V4L(&MI(&II:"!P;W1R96)U:F5T92!I>F)E
M<FET92!I>B!O:W9I<FIE=B!S<&]D86HN($YA=&\@:FEH(&QA:&MO(&MO<&ER
M871E(&EN('!R:6QE<&ET92!V+VEZ(&)E<V5D:6QA+@!$;VQOQ(UI(&MO;L2-
M;FD@9&%T=6TZ`$EZ8F5R:2!O8FQI:V\@9&%T=6UA.@!)>F)E<FET92!I9&5N
M=&ET971O+"!K871E<F\@Q;YE;&ET92!S<')E;65N:71I.@!$;VQOQ(UI(&MO
M;L2-;F\@=7)O.@!)>F)E<FD@;V)L:6MO('5R93H`27IB97)I(&1V92!U:F5M
M86IOQ(UI('-E('!O;&II.@!)>F)E<FET92!V8<6A92!B87)V;F\@:V]M8FEN
M86-I:F\`27IB97)I=&4@:F5Z:6LZ`%!OQ:%L:FD@<&]R;\2-:6QO(&\@;F%P
M86MA:`!0;\6A;&II(%--4P!396YE9V%L`%-E;GIO<CH`4V5P<F5M8F5R`%-R
M8FEJ82!I;B#$C7)N82!G;W)A`%-E<FEJ<VMA(,6A=&5V:6QK80!3=')EQ;YN
M:6MO=B!D871U;2!J92!N87!AQ(UE;B!A;&D@;FD@;F$@<F%Z<&]L86=O+@!!
M9&UI;FES=')A8VEJ82!S96IE`$E$('-E:F4@:F4@<&]T96ML82X`4V5J90!.
M86UE<W1I`$YA<W1A=FD@;W!C:6IO+"!D82!V('!R:6UE<G4L(&1A('!O>F%B
M:71E('9AQ:%E(&=E<VQO+"!L86AK;R!P;VYA<W1A=FET92!L92UT;RX`57)E
M9&ET92!O9&1A;&IE;F4@<W1R9<6^;FEK92!N82!K871E<F4@Q;YE;&ET92!D
M;W-T;W!A=&D@>B!V8<6A96=A('!O<G1A;&$`3F%S=&%V:71E('!R:79Z970@
M:F5Z:6L@:6X@;F%S=&%V:71V92!D871U;6$`57)E9&D@>F'$C65T;F4@8F%R
M=FYE('-H96UE+"!A<&QI:V%C:6IE+"!O<W9EQ;YI='9E('-T<F%N:2XN+@!.
M86UE<W1I`$YA<W1A=FD@<VMR:7!T;R!Z82!O<W9EQ;YI=&5V(&MO="!R87IP
M;VQOQ;YL:FEV;RX`36_%OFYI:"!J92!V9<2-(&QO:V%C:6H@<R!P87)A;65T
M<F]M.@!396K%H65L:0!.86MU<&]V86YJ90!+<F%T96L@<&]V>F5T96L`3F%T
M879I;2!T:7!K87)S:V4@8FQIQ;YN:6-E(&YA('!O=F5Z879E/P!0;VMAQ;YI
M`%!O:V'%OFD@<F%Z;&EK92!M960@<V5D86H@<VAR86YJ96YO(&EN(&YA:FYO
M=F5JQ:%O(&=E;F5R:7)A;F\@:V]N9FEG=7)A8VEJ;RX`4')I:V'%OFD@9&%T
M=6T@>F%D;FIE('!R:6IA=F4@<&\@=G-T;W!U/P!0<FEK8<6^:2!O<&-I:F4@
M>F$@;V)D<L6^871I(&]R:6=I;F%L`%!O:V'%OFD@=&ES=&5G82P@:VD@<W!R
M96IE;6$`4')I:V'%OFD@;65N:6IS:V\@=G)S=&EC;R!D96QO=F%N:F$@=&%B
M96QE`%!R:6MAQ;YE;2`E<R!M96YI(&YA(&QE=FD@<W1R86YI/P!$;V1A:B!N
M86QA9V%N:F4`4&QO:&4`6FIU=')A:B!P;&]H90!0;W!O;&1N92!P;&]H90!6
M(&)L:<6^:6YI('!L;VAE`%-K<L2-:0!.86IP<F5J('-K<L2-:2!A;&D@<')E
M;6%K;FD@<V]S961N:F4@8F5L9<6^:V4N`%-I97)R82!,96]N90!0<FEJ879I
M('-E`%!O9'!I<P!!;&=O<FET;6G$C65N('!O9'!I<P!3:6YG87!U<@!696QI
M:V]S=`!0<F5S:V_$C6D@=GID<L6^979A;FIE`%-L;W9AQ:%K80!3;&]V96YI
M:F$`4VYE9P!3;F7%OFYA('!L;VAA`%-N9<6^;F4@<&QO:&4`6FIU=')A:B!S
M;F7%OFYE('!L;VAE`%!O<&]L9&YE('-N9<6^;F4@<&QO:&4`5FG%H6EN82!S
M;F5G83H`4VYE9W4@96MV:79A;&5N=&YA(&MO;&G$C6EN82!V;V1E.@!386QO
M;6]N;W9I(&]T;VMI`%-O;6%L:6IA`%!E<VUI(&EN('!O97II:F4`5G)S=&$@
M=7)E:F5N96=A(&EZ8F]R80!.87-L;W8@=FER80!*=<6^;F$@069R:6MA`$IU
MQ;YN;RUE=G)O<'-K:2`H25-/+3@X-3DM,RD`2G7%OFYA($=E;W)G:6$@:6X@
M;W1O:VD@2G7%OFYI(%-A;F1W:6-H`$IUQ;YN82!P;VQO8FQA`%!R97-L961N
M:6-A`,6@<&%N:6IA`$YE>F'%OF5L96YA('!OQ:%T80!6:&]D('IA('!O<V5B
M;F4@>FYA:V4`Q:!P;W)T:0#%H')I($QA;FMA`%-T86YD87)D96X`6G9E>F1N
M92!S=&5Z90!:8<2-971N;R!L971O`$1RQ;YA=F$@86QI('!R;W9I;F-A`%-T
M871U<P!/8FQI:V$@<&]M;FEL;FEK80!.87-L;W8@=6QI8V4`4W!I<V5K(&)E
M<V5D;FEH('IV97H`/S\_/S\_/S\_/V1O;65N82!I>B!N87-L;W9A`$YE`$YE
M(&YA:F1E;2!P;V1M87!E("(E<R(`6F%D979A`%!R961L;\6^:0!3<')E:F5L
M:2!S;6\@>F%H=&5V96L@>F$@=G!I<R`B)7,B+B!.92!M;W)E=&4@<V4@<')I
M:F%V:71I(&1O:VQE<B!V8<6A82!Z86AT979E:R!N92!P;R!P;W1R:F5N+@!5
M<W!E:``B)7,B('-E;2!U<W!EQ:%N;R!D;V1A;"!K('-I<W1E;74N`"<E<R<@
M<V5M('5S<&7%H6YO(&]D<W1R86YI;"!I>B!S:7-T96UA+@`B)7,B('-E;2!U
M<W!EQ:%N;R!I>F)R:7-A;"X`(B5S(B!S96T@=7-P9<6A;F\@;V1S=')A;FEL
M(&EZ('-I<W1E;6$N`%5S<&7%H6YO(&]B<FYJ96YA(&MO;F9I9W5R86-I:F$N
M(,2-92#%OF5L:<6A('9I9&5T:2!S<')E;65M8F4L('!O;F]V;F\@;F%L;\6^
M:2X`57-P9<6A;F\@<VAR86YJ96YA('9A<FYO<W1N82!K;W!I:F$@:V]N9FEG
M=7)A8VEJ92X`57-P9<6A;F\@<VAR86YJ96YA('9A<FYO<W1N82!K;W!I:F$@
M:V]F:6=U<F%C:6IE(&1A=&]T96ME("5S+@`B)7,B(&IE(&)I;"!U<W!EQ:%N
M;R!P;W-O9&]B;&IE;BX`)7,@<V5M('5S<&7%H6YO('IA<&ES86PN`%-U9&%N
M`%-O;L2-;FD@=GIH;V0`4V]NQ(UN:2!Z86AO9`!3;V[$C6YO`%-O;L2-;FD@
M=GIH;V0`4V]NQ(UN:2!V>FAO9"]Z86AO9`!3;V[$C6YI('9Z:&]D`%-O;L2-
M;FD@>F%H;V0`4V]NQ(UN:2!Z86AO9#H`4&]D<&]R80!3=7)I;F%M`%!R:6EM
M96L`4W9A;&)A<F0@:6X@2F%N($UA>65N`%-V87II`,6@=F5D<VMA`,6@=FEC
M80!)>F)R:7-A;B!S:6YK<F]N:7IA8VEJ<VMI(&1N979N:6L`4VEN:W)O;FEZ
M86-I:F$`3F%P86MA('8@<VEN=&%K<VD@:7-K86QN:6@@<&]G;VIE=@!3:7)I
M:G-K82!A<F%B<VMA(')E<'5B;&EK80!'<FUE;FIE`$YE=FEH=&$@>B!G<FUE
M;FIE;2!I;B!V971R;VT`3F5V:6AT82!Z(&=R;65N:F5M`%135B!D871O=&5K
M80!.87-T879I=&5V('1A8F5L90!486IV86X`5&%I=V%N+"!D9<6^96QA($MI
M=&%J<VME`%1A9,6^:6MI<W1A;@!486YZ86YI:F$L(%ID<G7%OF5N82!R97!U
M8FQI:V$`3W!R879I;&$`5&5L969O;G-K82#%H71E=FEL:V$`5&5M<&5R871U
M<F$@=B!Z861N:FD@=7)I.@!496UP97)A='5R80!496UP97)A='5R83H@`%1E
M;7!E<F%T=7)A/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`(B5S(B!V
M>F]R8V$@;F4@;F%J9&5M+@!5<F5J979A;&YI:R#%H6%B;&]N`$)E<V5D:6QO
M`%-A;6\@0F5S961I;&\`5&\`5&%J<VMA`$]V97)J96YJ92!N:2!U<W!E;&\`
M6F=O9&]V:6YA(&IE(&EZ:VQO<&QJ96YA+@!(;W)D92]+;VQA8B!I;G1E9W)A
M8VEJ82!N92!P;V1P:7)A("(E<R(`4&]S;V1O8FQJ96X@9&%T;W1E:V4@;F4@
M;6]R96T@<VAR86YI=&DN`%9Z9'+%OF5V86YJ93H@<F%Z<F5D(&YI(&)I;"!U
M<W!EQ:%N;R!N86QOQ;YE;BX`3VMN;R!-;\6^;F]S=&D@:F4@8FEL;R!Z87!R
M=&\N(%IA:VQJ=65U:F5M+@!!9&UI;FES=')A=&]R(&UO<F$@;F%J<')E:B!N
M87-T879I=&D@<VES=&5M('IA('!R879I8V4N`$MO;G1A:W1N:2!)1"!N:2!B
M:6P@<&]S<F5D;W9A;B!A;&D@;FD@8FEL(&YA:F1E=B!V(&)A>FD@<&]D871K
M;W8N`%-T:6L@:F4@8FEL('5S<&7%H6YO(&1O9&%N(&L@=F'%H6EM(&YA<VQO
M=F]M+B!+;&EK;FET92!S<&]D86H@>F$@;V=L960Z`%!O=')E8G5J96T@;&_$
MC65N;R!01U`@<&]D<&ES86YO(&)E;&7%OFYI8V\L(&1A('!R979I<FEM('!O
M9'!I<V%N;R!S<&]R;\2-:6QO+@!)1"!S97IN86UA(&YI(&)I;"!P;W-R961O
M=F$@86QI(&YI(&)I;"!N86ID96X@=B!B87II('!O9&%T:V]V+@!4;R!D96IA
M;FIE(&YI;6$@<&]D<&]R92X`2V]D:7)A;F$@=G-E8FEN82!Z86AT979A('9A
M<FYO(&EN=&5R;F5T;F\@<&]V97IA=F\N`"5S(&1A=&]T96MA(&)I(&UO<F%L
M82!V<V5B;W9A=&D@)7,@;F%S=&%V:71V<BX`)7,@9&%T;W1E:V$@8FD@;6]R
M86QA('9S96)O=F%T:2`E<R!N87-T879I='9E+B``1&%T;W1E:V$@;F4@=G-E
M8G5J92!N;V)E;FEH('!O9&%T:V]V+@!3=')EQ;YN:6L@(B5S(B!J92!B:6P@
M:7IB<FES86XN`$UE<W1O($=N=5!'('!R;V=R86UA(&UO<F$@8FET:2!P;W-R
M961O=F%N;R!R87IR961U($-R>7!T7W!G<"X`4W!O<F_$C6EL;R!P;W-L86YO
M(&1N92`E<R!Z82`E<R!Z(&YA<VQO=F]M("(E<R(@:F4@8FEL('!R96)R86XN
M"DYI('IA9V]T;W9I;&$@9&$@:F4@8FEL;R!D96IA;G-K;R!P<F5B<F%N;R!A
M;&D@<F%Z=6UL:F5N;RX`26UE('IA('!O=F5Z879O(&YA('-T<F%N('IA('-E
M<W1A=FQJ86YJ92!S<&]R;\2-:6QA+@!482!V<F5D;F]S="!M;W)A(&)I=&D@
MQ:%T979I;&MA+@!0;W1R96)U:F5M(&]P96YS<VP@;6]D=6P@>F$@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!R87IR960N`$YA<W1A=FEE;F4@9&%T;W1E:V4@(B5S
M(B!N92!M;W)E('-H<F%N:71I+"!K97(@;FIE;FD@<&]D871K:2!P<F5S96=A
M:F]N86IV9<2-:FD@9&]V;VQJ96X@;V)S96<N`%!R;V=R86UA+"!K:2!O9'!I
M<F$@<&]D871K92!T92!V<G-T92`H)7,I(&YE(&YA:F1E;2!V('-I<W1E;74N
M`%)A>FUE:FET978@;6]R82!B:71I('-E<W1A=FQJ96YA(&QE(&EZ(&5N96=A
M('IN86MA+@!,;\2-:71E=B!M;W)A(&)I=&D@<V5S=&%V;&IE;F$@;&4@:7H@
M96YE9V$@>FYA:V$N`%-T<F7%OFYI:R`B)7,B(&IE(&)I;"!I>F)R:7-A;BX`
M4W1R9<6^;FEK("(E<R(@:F4@<VAR86YJ96XN`$EZ8G)A;F$@=G)S=&EC82`H
M)60I(&YE(&]B<W1A:F$N`%9N9<6A96YO(&)E<V5D:6QO(&YE('5S=')E>F$@
M8F5S961I;&\@;F$@96MR86YU+@!0;W-O9&]B;&IE;FD@<&]D871K:2!S;R!B
M:6QI(&EZ9W5B;&IE;FD@<')I('!R96K%H6YJ96T@:V]R86MU+@!0;W-O9&]B
M;&IE;B!D871O=&5K92!N92!M;W)E;2!S:')A;FET:2X`=V5A=&AE<BYC;VT@
M;FD@;F$@=F]L:F\N`$YE(&YA:F1E;2!M87!E(&]B;&EK("(E<R(N`$YI(&UO
MQ;YN;W-T:2!N82!R87IP;VQA9V\N`$1E;&D@;F4@;6]R96IO(&)I=&D@<')I
M:V%Z86YI+@!6('!O;&IU(&IE('!R979EQ(T@>FYA:V]V+B!6=&EP:V%L:2!S
M=&4@)7,@>FYA:V]V+B!6=&EP:V%T:2!M;W)A=&4@;6%N:B!K;W0@)7,@>FYA
M:V]V+@!0<FG%H6QO(&IE(&1O(&YA<&%K92!P<FD@9&]D86IA;FIU("<E<R<@
M:R!S:7-T96UU.B`E<P!0<FG%H6QO(&IE(&1O(&YA<&%K92!P<FD@;V1S=')A
M;FIA;FIU("<E<R<@:7H@<VES=&5M82X`4')IQ:%L;R!J92!D;R!N87!A:V4@
M<')I(&]D<W1R86YJ86YJ=2`G)7,G(&EZ('-I<W1E;6$N`%!R:<6A;&\@:F4@
M9&\@;F%P86ME('!R:2!P;W-O9&%B;&IA;FIU("<E<R<Z("5S(`!0<FD@;F%L
M86=A;FIU(&1A=&]T96ME(&IE('!R:<6A;&\@9&\@;F%P86ME+B!.;V)E9&5N
M("5S(&YI(&)I;"!N86QOQ;YE;BX`4')I(&YA;&%G86YJ=2!D871O=&5K92!J
M92!P<FG%H6QO(&1O(&YA<&%K92X@)7,@>F%S961A('9EQ(T@<')O<W1O<F$L
M(&MO="!J92!D;W9O;&IE;F\N($1O=F]L:F5N;R!J92`H)60@8GET;W8I+@!0
M<FD@;F%L86=A;FIU(&1A=&]T96ME(&IE('!R:<6A;&\@9&\@;F%P86ME+B`E
M<R!J92!L92!D96QN;R!N86QOQ;YE;F$N`%8@<W!O<F]E:6QU('-E(&IE('!O
M:F%V:6QA(&YE>FYA;F$@;F%P86MA+@!0<FD@<W!R96IE;6%N:G4@:V]N=&%K
M=&$@:F4@<')IQ:%L;R!D;R!N87!A:V4N`%!R:2!S<')E:F5M86YJ=2!K;VYT
M86MT82!J92!P<FG%H6QO(&1O(&YA<&%K92X`2V]N9FEG=7)A8VEJ<VMI(&]B
M<F%Z96,@=G-E8G5J92!N87!A:V\N(%9E<FIE=&YO('-T92!P;WIA8FEL:2!N
M87-T879I=&D@>F%H=&5V86YO('!O;&IE+@!0<FG%H6QO(&IE(&1O(&YA<&%K
M92!P<FD@<')O8V5S:7)A;FIU(&EZ8G)A;F5G82!I;65N:6MA+B!0<F]S:6UO
M('!O<VMU<VET92!Z;F]V86YE:V]L:6MO(&MA<VYE:F4`4')I('-P<F5J96UA
M;FIU(&MO;G1A:W1A(&IE('!R:<6A;&\@9&\@;F%P86ME+B!0<F]S:6UO('!O
M<VMU<VET92!Z;F]V82!K87-N96IE+@!0<FD@<W!R96IE;6%N:G4@:V]N=&%K
M=&$@:F4@<')IQ:%L;R!D;R!N87!A:V4N(%!R;W-I;6\@<&]S:W5S:71E(&MA
M<VYE:F4N`%9AQ:$@8G)S:V%L;FEK(&YE('!O9'!I<F$@=&4@<&]T97IE+@!4
M;R!N:2!V96QJ879E;B!205(@87)H:78N`%1O(&YI('9E;&IA=FYA('II<"!D
M871O=&5K82X`Q(+B@)K%H'1E=FEL:V$@:V%R=&EC92!N:2!V96QJ879N82X`
M1V]N:6QN:6L@;VUO9V_$C64@<&_%H6EL:F%N:F4@<W!O<F_$C6EL('!R96MO
M(&]P97)A=&5R:F$@0VQI8VMA=&5L;"X`1V]N:6QN:6L@;VUO9V_$C64@<&_%
MH6EL:F%N:F4@<W!O<F_$C6EL('!R96MO(&]P97)A=&5R:F$@5TE.+@!';VYI
M;&YI:R!O;6]G;\2-92!P;\6A:6QJ86YJ92!S<&]R;\2-:6P@<')E:V\@;W!E
M<F%T97)J82!S;7,R96UA:6PN`$=O;FEL;FEK(&]M;V=OQ(UE('!OQ:%I;&IA
M;FIE('-P;W)OQ(UI;"!P<F5K;R!I=&%L:F%N<VME9V$@;W!E<F%T97)J82!6
M;V1O869O;F4N6F$@<&_%H6EL:F%N:F4@;6]R971E(&EM971I(')E9VES=')I
M<F%N:2!N82!H='1P.B\O=W=W+C$Y,"YI=`!0;W1R96)U:F5M('1O('!O;&IE
M+@!4;R!P;VQJ92!L86AK;R!V<V5B=6IE(&QE(&-E;&$@Q:%T979I;&$N`%1O
M('!O;&IE(&QA:&MO('9S96)U:F4@;&4@Q:%T979I;&$@:6X@<W1O;'!E8RX`
M5&\@<&]L:F4@;&%H:V\@=G-E8G5J92!L92#%H71E=FEL82X`4&]L:F4@;6]R
M82!V<V5B;W9A=&D@<V5Z;F%M(,6A=&5V:6PL(&QOQ(UE;FEH('H@=F5J:6-O
M(&%L:2!P<F5S;&5D:V]M+@!482!V<F5D;F]S="!M;W)A(&)I=&D@Q:%T979I
M;&MA+@!4;R!P;VQJ92!M;W)A('9S96)O=F%T:2!B87)V;F\@:V]D;R!V(%)'
M0B!(97@@9F]R;6%T=2P@;F$@<')I;65R("<C,3(S-&%F)RX`5&$@;V)L:6MA
M(&IE(&)I;&$@Q;YE(&]B9&5L86YA+@!4;R!J92`E<RX`5&\@:F4@<&]D871E
M:R!S:W5P:6YS:V$@=7!R879L:F%N:F4@2V]L86(N(%IA('!R96=L960@=&5G
M82!P;V1A=&MA('!O=')E8G5J971E<')E9VQE9&QO=F%L;FEK+"!K:2!P;V1P
M:7)A(&YAQ(UI;B!Z87!I<V$@2V]L86(@1W)O=7!W87)E+B!:82!S97IN86T@
M;V1J96UA;&-E=FMI('1O('!O9'!I<F%J;R!O8FG%H<2-:71E("5S`%-P;W)O
MQ(UI;&\@:F4@8FEL;R!N87!I<V%N;R!V(&MO9&YI('1A8F5L:2!D<G5G8<2-
M;F4@;V0@=F'%H64@*"5S*2X`5&\@Q:%T979I;&\@;6]R82!B:71I('9S86H@
M96YA+@!482!S=')EQ;YN:6L@;F4@;6]R92!O9'!R971I('II<"!I;B!G>FEP
M(&1A=&]T96LN`%-I<W1E;2!J92!T<F5N=71N;R!N96%K:71I=F5N+@!482!V
M<F5D;F]S="!M;W)A(&)I=&D@Q:%T979I;&MA+@!4;R!O:VYO(&UO<F%T92!P
M;V=N871I('H@;VMN82!-;\6^;F]S=&DN`$)L:7-K`%!R:6IA=F4`Q(UA<P!3
M;&5D;FIE(,2-87-A`$]B;&EK82#$C6%S80!)>F)I<F$@96%S82X`3F%S;&]V
M`%IA`&7$C2#%OF5L:71E(&EZ8G)A=&D@=F7$C2!P<F5D;65T;W8L('!R:71I
M<VYI=&4@0V]N=')O;"`H4$,I(&%L:2!#;VUM86YD("A-86,I('1I<&MO+"!M
M961T96T@:V\@;F%N:F4@:VQI:V%T92X`9&%N`%1O9V\`5&]K96QA=0!+;VUO
M<FD@`%1O;F=A`%!R979EQ(T@;F5U<W!E;&EH('!O=F5Z878@=B!Z861N:FEH
M(&UI;G5T86@N`$]R9V%N:7IA8VEJ80!4<FEN:61A9"!I;B!4;V)A9V\`1&$@
M86QI(&YE`,2,90!4=6YI>FEJ80!4=7)E:6IA`%1U<L6A:VD@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7+%H6MI(&EN($-A:6-O<R!O=&]K:0!4=79A
M;'4`5G1I<&MA:G1E('9AQ:%O(&EZ8FER;SH@`%4N5BX@:6YD96MS.@!54DP`
M55),('9AQ:%E('-K<FEP=&4@>F$@<&]R;\2-86YJ92!S=&%T=7-A(&1O<W1A
M=F4`56=A;F1A`%5K<F%J:6YA`$YI;6%M(&1O<W1O<&$@9&\@5D93(&EM96YI
M:V$N`$YE(&UO<F5M('-P<F5M96YI=&D@<')A=FEC92!Z82!61E,@9&%T;W1E
M:V\@(B5S(BX`1&]V;VQJ96YJ82!Z82!61E,@)7,O)7,@;F4@;6]R96T@<W!R
M96UE;FET:2X`3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RX`3F4@;6]R96T@
M<W!R96UE;FET:2!N82`B)7,B+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93
M(&1A=&]T96ME("5S+R5S+@!.92!M;W)E;2!S92!P;W9E>F%T:2!S(%-33"X`
M5D93(&1A=&]T96ME(&YE(&UO<F5M(&MO<&ER871I+@!.92!M;W)E;2!U<W1A
M=G)I=&D@:6UE;FEK82`B)7,B+@!61E,@:6UE;FEK82!N92!M;W)E;2!U<W1A
M=G)I=&DN`%9&4R!D871O=&5K92!N92!M;W)E;2!U<W1V87)I=&DN`$YE(&UR
M;V5M('5S='9A<FET:2!I;65N:6MA("(E<R(N`%9&4R!D871O=&5K92!N92!M
M;W)E;2!U<W1V87)I=&DN`%!O9&%T:V]V(&YE(&UO<F5M('-P<F]S=&ET:2X`
M3F4@;6]R96T@:7IB<FES871I("5S+"!I;65N:6L@;FD@<')A>F5N+@!.92!M
M;W)E;2!I>F)R:7-A=&D@)R5S)SH@)7,N`$YE(&UO<F5M(&EZ8G)I<V%T:2`E
M<RP@:6UE;FEK(&YI('!R87IE;BX`3F4@;6]R96T@:7IB<FES871I(&EM96YI
M:V$N`$YE(&UO<F5M(&EZ8G)I<V%T:2!I;65N:6MA+@!.92!M;W)E;2!I>F)R
M:7-A=&D@5D93(&EM96YI:V$Z("5S(`!.92!M;W)E;2!I>F)R:7-A=&D@9&%T
M;W1E:V4N(B5S(BX`3F4@;6]R96T@:7IB<FES871I(%9&4R!D871O=&5K92X`
M3F4@;6]R96T@:7IB<FES871I(&1A=&]T96ME("(E<R(N`$YE(&UO<F5M(&EZ
M8G)I<V%T:2!61E,Z("5S(`!.92!M;W)E;2!D;VQOQ(UI=&D@<V5D86YJ96=A
M(&EM96YI:V$N`$YE(&UO<F5M(&EZ<&ES871I('!O=')J96YI:"!P;V1R;V)N
M;W-T:2X`3F4@;6]R96T@<W!R96UE;FET:2!N82`E<RX`3F4@;6]R96T@<')E
M;6%K;FET:2!61E,@9&%T;W1E:V4N`$YE(&UO<F5M(&]D<')E=&D@9&%T;W1E
M:V4B)7,B+@!.92!M;W)E;2!O9'!R971I(%9&4R!D871O=&5K92!N86UE;FIE
M;F4@<&ES86YJ=2X`3F4@;6]R96T@;V1P<F5T:2!61E,@9&%T;W1E:V4N`$YE
M(&UO<F5M(&]D<')E=&D@>F=OQ:'$C65N96=A(&%R:&EV82X`3F4@;6]R96T@
M<')E:6UE;F]V871I(%9&4R!D871O=&5K92`E<R\E<RX`3F4@;6]R96T@<')E
M:6UE;F]V871I(%9&4R!D871O=&5K92X`3F4@;6]R96T@<')E8G)A=&D@5D93
M(&]S;F]V;F5G82!I;65N:6MA+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@)7,@
M=B`E<SH@;6%P82#%OF4@;W-T86IA`$YE(&UO<F5M('!R96EM96YO=F%T:2!6
M1E,@:6UE;FEK82X`3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!I;65N:6MA
M.B`E<RX`3F4@;6]R96T@<')E:6UE;F]V871I(%9&4R!D871O=&5K92`B)7,B
M+@!.92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME("5S+R5S+@!.
M92!M;W)E;2!P<F5I;65N;W9A=&D@5D93(&1A=&]T96ME+@!.92!M;W)E;2!S
M<')E;65N:71I(&YA("5S+@!.92!M;W)E;2!P<F5V97-T:2!T96=A(%=O<F1O
M=F5G82!D;VMU;65N=&$N`$YE(&UO<F5M('-P<F_%OFET:2!P<F]S=&\O>F%S
M961E;F\@<&]S;V1O8FET92!Z82`E<P!.92!M;W)E;2!N87!I<V%T:2!61E,@
M9&%T;W1E:V4@(B5S(BX`3F4@;6]R96T@;F%P:7-A=&D@5D93('!O9&%T:V]V
M;FEH(&1A=&]T96LN`$YE(&UO<F5M(&YA<&ES871I(%9&4R!P;V1A=&MO=FYI
M:"!D871O=&5K+@!.92!M;W)E;2!N87!I<V%T:2!61E,@9&%T;W1E:V4L(&MV
M;W1A(&)O('!R97-EQ;YE;F$N`%)A>G9E;&IA=FD@<W!R96UE;6)E`$YE<')I
MQ(UA:V]V86X@;V1G;W9O<B!S('-T<F7%OFYI:V$@=B!P;W9E>F]V86YJ=3H`
M3F5P<FG$C6%K;W9A;B!N97!R:<2-86MO=F%N(&]D9V]V;W(@<W1R9<6^;FEK
M82!Z83H`3F5I>G!O;&YJ96YO`%5N:6MO9"`H551&+3@I`%ID<G7%OF5N:2!A
M<F%B<VMI(&5M:7)A=&D`6F1R=<6^96YO(&MR86QJ97-T=F\`6F1R=<6^96YE
M(&1RQ;YA=F4`6F1R=<6^96YE(&1RQ;YA=F4@3W1O:VD@36EN;W(@3W5T;'EI
M;F<`16YO=&4`3F5P;WIN86YO`$YE<&]Z;F%N82!A<&EM<V=I9"`H240@05!)
M('-P;W)OQ(UI;&$I+@!.97!O>FYA;F$@8VQI;7-G:60@*$E$('5P;W)A8FYI
MQ:%K96=A('-P;W)OQ(UI;&$I`$UE<W1O(&YI(&YA<W1A=FQJ96YO+@!.97IN
M86YO('5P;W)A8FYIQ:%K;R!I;64@86QI(&=E<VQO+@!"<F5Z(&EM96YA`$YE
M<&]D<')T82!R87K%H6ER:71E=@!0;W-O9&]B:0!0;W-O9&]B:2`E<P!0;W-O
M9&]B;&IE;B!U<&]R86)N:6L`4&]S;V1O8FQJ96X@)R5S)RX`27IB<FES86YA
M('-K<FEP=&$@>F$@;F%D9W)A9&YJ;RX`3F%L86=A;0!.86QOQ;YI(&YA('-T
M<F7%OFYI:R!V<V4@;F%M97-T:71V96YE(&1A=&]T96ME(&%P;&EK86-I:BX`
M57)U9W9A:@!5<&]R86)I('-E9&%N:FDZ("5S`%5P;W)A8FD@4U-,`%5P;W)A
M8FDL(,2-92!J92!U<&]R86)N:<6A:V\@:6UE+V=E<VQO(&1R=6=AQ(UN;R!O
M9"!)35-0('-T<F7%OFYI:V$`57!O<F%B;FEK`%5P;W)A8FYI:R`E<R!N:6UA
M(&1O<W1O<&$@9&\@)7,`57!R879A('IA('5P;W)A8FYI:V4`57!O<F%B;FG%
MH6ME(&YA<W1A=FET=F4`4F5G:7-T<F%C:6IA('5P;W)A8FYI:V$`4F5G:7-T
M<FER86YJ92!U<&]R86)N:6MO=B!J92!N82!T96H@<W1R86YI(&]N96UO9V_$
MC65N;RX`3F4@;F%J9&5M('5P;W)A8FYI:V]V(')AQ(UU;BX`57!O<F%B;FG%
MH6MO(&EM90!5<&]R86)N:<6A:V\@:6UE("(E<R(@:F4@Q;YE('8@=7!O<F%B
M:2X`57!O<F%B;FG%H6MO(&EM93H@`%5P;W)A8FYIQ:%K;R!I;64Z(`!5<&]R
M86)N:6MI+"!K:2!S;R!V('-I<W1E;74Z`%5Z8F5K:7-T86X`5D93(&EM96YI
M:R!N92!O8G-T86IA+@!/9'-O=&YO<W0`3F%J9&5N82!V96QJ879N82!L;VMA
M8VEJ82!Z86IE;6$Z`%9E;&IA=FYO<W0`5G)E9&YO<W0@=B!M:6YU=&%H(&]D
M('-E9&%J(&1A;&IE+@!6<F5D;F]S="!P<F5S96=A(&UA:W-I;6%L;F\@9&]L
MQ;YI;F\@)7,N`%9R961N;W-T:0!6<F5D;F]S=&D@;V0@:V]D97(@:7IB:7)A
M=&D`5F%N=6%T=0!687)I86)I;&YO`%9E;F5Z=65L80!0<F5V97)J86YJ92!N
M975S<&7%H6YO("T@;6]G;\2-92!J92!B:6QO('-P;W)OQ(UI;&\@<W!R96UE
M;FIE;F\N`%)A>FQIQ(UI8V$`4F%Z;&G$C6EC80!:96QO('9I<V]K;P!6:65T
M;F%M`%9I971N86US:VD@*%9)4T-)22D`4&]G;&5J("5S`%!O9VQE9"!N82!Z
M=6YA;FIO('-P;&5T;F\@<W1R86X`1&5V:<6A:VD@;W1O:VD@*&)R:71A;G-K
M:2D`1&5V:<6A:VD@;W1O:VD@*%I$02D`5FED;&II=F]S=`!6:61L:FEV;W-T
M.@!6;V1A9F]N($ET86QI:F$@<')E:V\@4TU44`!/4$]:3U))3$\`3U!/6D]2
M24Q/(2$A(%)/Q(U.3R!/1%-44D%.24T@4TM225!43R!)6B`E<RX`5TE.('!R
M96MO($A45%``5V%L;&ES(&EN($9U='5N80!/<&]Z;W)I;&\`36D`5G)E;65N
M<VMA(&YA<&]V960`5G)E;65N<VMI('!O9&%T:VD@<R!S<&QE=&$`=V5A=&AE
M<BYC;VT`4W!L970`4W!L971N82!S=')A;@!4961E;G-K;P!$;V)R;V1OQ:%L
M:0!$;V)R;V1OQ:%L:2!N82!S<&QE=&YI:"!S=')A;F5H('!R;V=R86UA("5S
M`$1O8G)O9&_%H6QI+"`E<P!:86AO9&YI("A)4T\M.#@U.2TQ*0!:86AO9&YI
M("A)4T\M.#@U.2TQ-0!:86AO9&YA(%-A:&%R80!+871E<F\@87!L:6MA8VEJ
M;R!N86H@<')I:V'%OF4@)7,L('!O('!R:6IA=FD_`$MA:\6A96X@:F4@;&_$
MC6EL;FD@>FYA:S\`2V%KQ:%E;B!J92!N879E9&5N:2!Z;F%K/P!:96UL:F5V
M:60@(%=H97)E:7,@075S=')A;&EA`%)A>G9O:FYA('-T;W!N:F$`2V%T97)E
M(&1O9&%T:V4@;F%J(&]M;V=OQ(UI;2!P<FD@=7)E:F%N:G4@8F5S961I;"X`
MQ:!I<FEN82!V(&5N;W1A:"!#4U,`Q:!I<FEN82`E<R!M96YI:F$@;F$@;&5V
M:2`H;V1R87II;&$@<V4@8F\@;V(@;F%S;&5D;FII('!R:6IA=FDI.@!7:6MI
M`%9E=&5R.B``2G5T<F%N:FD@=F5T97(Z(`!(:71R;W-T('9E=')A('8@=F]Z
M;&EH`%9E=&5R.@!6971E<CH@`$UO9')O<W0`3&ES=&$@Q;YE;&IA`%-L=<6^
M8F$`4VQUQ;YB96YI(&YA<VQO=@!3;'7%OF)E;FD@=&5L969O;@!.87!AQ(UN
M;R#%H71E=FEL;R!P;VQJ('8@)60@=G)S=&DN(%!R:<2-86MO=F%N:6@@)60L
M(&YA:F1E;FEH("5D+@!.87!AQ(UN;R#%H71E=FEL;R!P;VQJ+B!0<FG$C6%K
M;W9A;FEH("5D+"!N86ID96YI:"`E9"X`3F%P8<2-96X@;V1M:6L@)60@;65D
M(&)R86YJ96T@9&%T;W1E:V4@5D93+@!8+5)E9@!8-3`Y=C,@;W-N;W9N82!O
M;65J:71E=@!8-3`Y=C,@4F%ZQ:%I<FIE;F$@=7!O<F%B82!K;&IUQ(UA`%@U
M,#EV,R!:861E=F$@86QT97)N871I=FYO(&EM90!8-3`Y=C,@2VIU92!Z82!D
M;VQO96ET:2!Z861E=F\`6#4P.78S(')A>L6A:7)I=&5V`$Q,`$Q,3$P`66%H
M;V\A('IE;6QJ979I9`!,971N;P!*96UE;@!$82X`1&$L('-E('-T<FEN:F%M
M+@!.:6UA=&4@9&]V;VQJ96YJ82!U<W1V87)I=&D@=F7$C2!K;W0@)60@8FQO
M:V]V+@!.:7-T92!P<FEJ879L:F5N:0!6(&EM96YU(&YE(&UO<F5T92!I;65T
M:2!Z;F%K;W8@)UPG`$YI<W1E('9S=&%V:6QI('9E;&IA=FYE9V$@96QE:W1R
M;VYS:V5G82!N87-L;W9A+@!-960@<W!R96IE=&EM:2!D871O=&5K86UI(&YI
M<W1E(&]Z;F'$C6EL:2!N;V)E;F5G82!P;VQJ82P@:VD@<V4@=6IE;6$@<R!P
M;VQJ:2!V)7,N`$)I;&D@<W1E(&]D:F%V;&IE;FDN`%9N97-T:2!M;W)A=&4@
M=F5L:F%V;F\@9W-M(,6A=&5V:6QK;RY$=F]L:F5N:2!Z;F%K:2!S;R!L92#%
MH71E=FEL:V4@:6X@)RLG(&MO="!P<F5D<&]N82!M961N87)O9&YI;2#%H71E
M:79L:V%M+@!6<W1A=FET:2!M;W)A=&4@=F5L:F%V;F\@=G)E9&YO<W0N`$]B
M;&EK;W9A=&D@;6]R871E(%-I9VYU<"!B86-K96YD+"#%H65L92!N871O('-E
M(&QA:&MO('!R:6IA=FQJ871E+@!/8FQI:V]V871I(&UO<F%T92!61E,@8F%C
M:V5N9"X`3F%J<')E:B!O<&G%H6ET92!T9<6^879E+"#%H65L92!N871O(&QA
M:&MO('!OQ:%L:F5T92!P;W)OQ(UI;&\@;R!T9<6^879A:"X`27IB<F%T:2!M
M;W)A=&4@<W1R9<6^;FEK+"!K:2!B;R!I>F)R:7-A;BX`3F%T86[$C6YE:F4@
M;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE;&ET92!I>F)R
M:6%T:2X`3F%T86[$C6YE:F4@;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@
M:VD@9V$@Q;YE;&ET92!O9'-T<F%N:71I+@!.871A;L2-;F5J92!N879E9&ET
M92!U<&]R86)N:<6A:V\@:6UE+"!K:2!G82#%OF5L:71E(&1O9&%T:2X`3F%T
M86[$C6YE:F4@;F%V961I=&4@=7!O<F%B;FG%H6MO(&EM92P@:VD@9V$@Q;YE
M;&ET92!P;W-O9&]B:71I+@!.871A;L2-;F5J92!N879E9&ET92!K86H@Q;YE
M;&ET92!N87)E9&ET:2X`5G1I<&MA:G1E(&EM92!N;W9E(&MA=&5G;W)I:F4N
M`%9N97-T:2!M;W)A=&4@:71A;&EJ86YS:V\@=&5L969O;G-K;R#%H71E=FEL
M:V\`5F'%H6$@<')I:F%V:71V96YA('-E:F$@)7,@:F4@<&]T96ML82X@4')O
M<VEM;RP@9&$@<V4@<&]N;W9N;R!P<FEJ879I=&4N`%9AQ:$@96QE:W1R;VYS
M:VD@;F%S;&]V.@!68<6A(&YA<VQO=CH`5F'%H6D@<&]D871K:0!/9"!Z8<2-
M971K82`E<R!S96IE+"!S92!J92!V8<6A('-P;&5T;FD@;F%S;&]V('-P<F5M
M96YI;"X@27H@=F%R;F]S=&YI:')A>FQO9V]V+"!S92!M;W)A=&4@<&]N;W9N
M;R!P<FEJ879I=&DN`%9AQ:%E(&EM93H`5F'%H64@;WIA9&IE('IA(&]V97)J
M96YE(&YE('!O9'!I<F$@9&]D86IA;FIA('5P;W)A8FYI:V]V+B#$C64@Q;YE
M;&ET92!U<&]R86)I=&E(;W)D92!Z82!A9&UI;FES=')I<F%N:F4@=7!O<F%B
M;FG%H6MI:"!R8<2-=6YO=BP@;6]R871E('5P;W)A8FET:2!D<G5G;R!O>F%D
M:F4@>F%O=F5R:F%N:F4N`%9AQ:%E(&]Z861J92!Z82!O=F5R:F%N:F4@;F4@
M<&]D<&ER82!N879A:F%N:F$@=7!O<F%B;FEK;W8@86QI('!A(&IE(&)I;&$@
M;6_%OFYO<W0@;VYE;6]G;\2-96YA(&EZ(&1R=6=I:"!R87IL;V=O=BX`2V'%
MOF4L(&1A('-E(&IE(&]D('IAQ(UE=&MA("4@<V5J92P@=F'%H2!B<G-K86QN
M:6L@<W!R96UE;FEL+B!)>G9A<FYO<W1N:6@@<F%Z;&]G;W8L('-E(&UO<F%T
M92!P;VYO=FYO('!R:6IA=FET:2X`5F'%H2!B<G-K86QN:6L@;F4@<&]D<&ER
M82!T92!F=6YK8VEJ92X`5F'%H2!B<G-K86QN:6L@;F4@<&]D<&ER82!D;VQO
MQ(UE;FEH(&UOQ;YN;W-T:2!P<FD@<')I;G1A;FIU+B!:82!P<FEN=&%N:F4@
M<')I=&ES;FET92!#;VYT<F]L+TUOQ;YN;W-T:2`K(%`N`%9AQ:$@=')E;G5T
M;FD@Q(UA<V]V;FD@<&%S.@!68<6A82!P<FEV>F5T82!I9&5N=&ET971A(&IE
M(&)I;&$@<W!R96UE;FIE;F$N`%!R:79Z971A(&ED96YT:71E=&$`5F'%H64@
M:6UE.@!68<6A82!P<FEJ879A(&IE('!O=&5K;&$N`%9AQ:%E(&YO=F4@9V5S
M;&\@>F$@)7,@:F4Z("5S`%9AQ:%E(&YA<W1A=FET=F4@<V\@8FEL92!P;W-O
M9&]B;&IE;F4@>F$@Q(UA<R!T92!S96IE+@!68<6A92!N87-T879I='9E('-O
M(&)I;&4@<&]S;V1O8FQJ96YE+@!68<6A92!G97-L;R!J92!B:6QO('!O;F%S
M=&%V;&IE;F\N`%9AQ:%E(&=E<VQO(&IE(&)I;&\@<&]N87-T879L:F5N;RX@
M3F$@=F'%H2!E+6YA<VQO=B!S;6\@=F%M('!O<VQA;&D@;F]V;V=E<VQO(',@
M:V%T97)I;2!S92!P<FEJ879I=&4N`%9AQ:%E(&=E<VQO(&IE('!O=&5K;&\N
M`%9AQ:%I('!O<W)E9&YI('-T<F7%OFYI:VDZ`$IU9V]S;&%V:6IA`%IA:7(`
M6F%M8FEJ80!::6UB86)V90!;4VMR:6H@8VET:7)A;F\@8F5S961I;&]=`%MP
M;W)OQ(UI;&\@;R!N87!A:VE=`%M0;VMAQ;YI(&-I=&ER86YO(&)E<V5D:6QO
M("T`6U!O:V'%OFD@8VET:7)A;F\@8F5S961I;&\@+2`E<R!V<G-T:6-=`%LE
M<R!V<G-T:6-A(&]D("5S70!?0TQ)`$1R979E<VYA(`!?4VMU<&EN90!0;VUO
MQ(T`4')I:F%V80!/9&IA=F$`36_%OFYO<W1I`$1O=F]L:F5N:F$`7TYA;65S
M=&D`7U5P;W)A8FYI:VD`26UE;FEK`$YA<VQO=FYI:R!N97IN86X`2V]L961A
M<@!-:7)N;P!.92!M;W)E;2!U<W1V87)I=&D@:7IH;V1N92!D871O=&5K90!.
M92!M;W)E;2!O9'!R971I('9H;V1A`&ML:6MN:2!T=0!N87!A:V$@=B!U<&]R
M86)N:2!U:V%Z;F4@=G)S=&EC90!.87!A:V$@=B!K;VYF:6=U<F%C:6II`$YE
M(&YA:F1E;2!Z86AT979A;F4@<VES=&5M<VME(&1A=&]T96ME`$YA<&'$C6YA
M(&]B;&EK82!D871U;6$`57)E9&D`3F4@;F%J9&5M('9N97-E;FEH('!O9&%T
M:V]V`%!A9&%V:6YE`&1A=&]T96MA`&EZ("5S("@E<RD@:R`E<R`E<P!G;W-T
M:6T`:#H`:&@`3F5Z;F%N;R!I;64@9V]S=&ET96QJ80!T86MO:@!-960@=G)S
M=&EC86UI`%9H;V1N82]I>FAO9&YA(&YA<&%K80!);G1E<FYA(&YA<&%K82!V
M('!R;V=R86UU`'9R<W1I8V4`;6MI<V]F<R!N87!A:V$@:V]D92`E9"P@;65D
M('!R:7!R879L:F%N:F5M($E33RX`;6T`:6UE`&YI(&1O:V]NQ(UA;F\`Q:%E
M(&YI('!O9'!R=&$`0F5L9<6^:V$`1&]V;VQJ96YJ92!J92!Z879R;FIE;F\N
M`&YA<&%K82!V(&]D9&QJ96YE;2!P<F]T;VMO;'4`=GIH86IA:F_$C64`4V5R
M=FES(&YI(&YA('9O;&IO+@!0;VMAQ;YI(')A>FQI:V4`<VUS,F5M86EL('!R
M96MO($A45%``<W,`4W1A8FEL;F\`4VES=&5M<VMA(&YA<&%K82X`4V5Z;F%M
M(&]P<F%V:6PN`'IAQ(UA<VYA(&]D<&]V960`>F$@<&]T<F1I=&5V('9T:7!K
M86IT92!G97-L;R!D=F%K<F%T`&5N;W1E;@!B<F5Z(&EM96YA`$EZ8FER82!U
M<&]R86)N:6MA(`!V($MA<G1I8V$`=SH`=V5A=&AE<BYC;VT`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O<VM?4TLO3$-?34534T%'15,`````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-3$P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]S:U]32R]H96QP+GAM;```
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S,R,"`Q
M,#4Q-30S-#$T,2`P,C$T-3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO
M<F1E.B!H;W)D92]L;V-A;&4O<VM?4TLO:&5L<"YX;6PL=B`Q+C(@,C`P-"\P
M-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A
M9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E
M<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF
M;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY
M(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8
M+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@
M>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE
M=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM
M87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@
M9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S
M<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@
M971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@
M<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B
M=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET
M96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@
M87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO
M96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET
M;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP
M87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@
M:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N
M('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@
M86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P
M;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E
M9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^
M4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E
M/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@
M8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E
M(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I
M;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@
M=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE
M;'`^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<VM?4TLO3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,#0Q-S,@,3`U,34T
M,S0Q-#$@,#(S,C,V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````8P<``!P````T.P``V0D``$QV````````L)T`
M``X```"QG0``#P```,"=```-````T)T```@```#>G0``"P```.>=```,````
M\YT```0`````G@``&`````6>```;````'IX``"T````ZG@``'0```&B>```D
M````AIX``"D```"KG@``&0```-6>```F````[YX```P````6GP``)````".?
M```/````2)\```L```!8GP``#@```&2?```%````<Y\``"@```!YGP``"```
M`**?```*````JY\``!4```"VGP``$@```,R?```+````WY\``(4```#KGP``
M#@```'&@```*````@*````T```"+H```#@```)F@```1````J*````T```"Z
MH```#````,B@```-````U:````8```#CH```E````.J@```*````?Z$```\`
M``"*H0``&````)JA```,````LZ$```X```#`H0``#@```,^A```(````WJ$`
M``D```#GH0``+@```/&A```:````(*(``#(````[H@``.````&ZB``!4````
MIZ(``%$```#\H@``6@```$ZC``!7````J:,``#0````!I```"0```#:D```-
M````0*0```<```!.I```"@```%:D```/````8:0```4```!QI```!@```'>D
M```1````?J0```@```"0I```"0```)FD```)````HZ0``"4```"MI```(```
M`-.D```3````]*0``!`````(I0``#P```!FE```*````*:4```,````TI0``
M#P```#BE```4````2*4```D```!=I0``#0```&>E```2````=:4``!D```"(
MI0``'@```**E```/````P:4```H```#1I0``#P```-RE```(````[*4``"0`
M``#UI0``%````!JF```6````+Z8```@```!&I@``3@```$^F```M````GJ8`
M`!D```#,I@``!P```.:F```,````[J8``"P```#[I@``#@```"BG```#````
M-Z<```L````[IP``!P```$>G```'````3Z<```4```!7IP``!0```%VG```*
M````8Z<```,```!NIP``%P```'*G```*````BJ<```\```"5IP``#@```*6G
M```8````M*<``",```#-IP``#@```/&G```4`````*@``!<````5J```%P``
M`"VH```7````1:@``!,```!=J```#P```'&H```.````@:@``!\```"0J```
M'0```+"H```'````SJ@```8```#6J```"````-VH```/````YJ@```8```#V
MJ```"@```/VH```3````"*D```L````<J0``$````"BI```5````.:D``!4`
M``!/J0``!P```&6I```0````;:D```4```!^J0``$0```(2I```,````EJD`
M`#L```"CJ0``.````-^I```)````&*H```<````BJ@```P```"JJ```%````
M+JH``!`````TJ@``"0```$6J```3````3ZH``#D```!CJ@``)P```)VJ```L
M````Q:H``"H```#RJ@``)0```!VK```*````0ZL```8```!.JP``"0```%6K
M```'````7ZL``"\```!GJP``-P```)>K```N````SZL``%4```#^JP``+0``
M`%2L```M````@JP``#T```"PK```/P```.ZL```M````+JT``$````!<K0``
M(P```)VM```C````P:T``$````#EK0``+0```":N```S````5*X``"4```"(
MK@``%0```*ZN```9````Q*X``"D```#>K@``)`````BO```H````+:\``!$`
M``!6KP``"@```&BO```,````<Z\```H```"`KP``$````(NO```6````G*\`
M`!8```"SKP``!P```,JO```'````TJ\```H```#:KP``"````.6O```G````
M[J\```@````6L```!P```!^P```'````)[````8````OL```!0```#:P```'
M````/+````8```!$L```"````$NP```I````5+````X```!^L```"@```(VP
M```$````F+````<```"=L```"0```*6P```&````K[```!$```"VL```!P``
M`,BP```6````T+````0```#GL```"````.RP```&````];````T```#\L```
M!@````JQ```>````$;$``!$````PL0``"````$*Q```-````2[$```P```!9
ML0``!P```&:Q```#````;K$```,```!RL0``%P```':Q```3````CK$``!T`
M``"BL0``"````,"Q```$````R;$```@```#.L0``"````->Q``!!````X+$`
M`!H````BL@``*P```#VR```@````:;(``!4```"*L@``!@```*"R```&````
MI[(``!4```"NL@``&````,2R```B````W;(``"X`````LP``'0```"^S```A
M````3;,``%0```!OLP``*0```,2S```*````[K,```<```#YLP``%0````&T
M```.````%[0```H````FM```#P```#&T```-````0;0```\```!/M```#0``
M`%^T```)````;;0```8```!WM```&````'ZT```3````E[0``!$```"KM```
M%````+VT```$````TK0```8```#7M```%````-ZT``!4````\[0``&0```!(
MM0``!````*VU```.````LK4```4```#!M0``!0```,>U```3````S;4``!$`
M``#AM0``$0```/.U```<````!;8``"H````BM@``$````$VV```A````7K8`
M``4```"`M@``$P```(:V```+````FK8``!(```"FM@``"@```+FV```/````
MQ+8```T```#4M@``$0```.*V```3````]+8```P````(MP``!@```!6W```,
M````'+<```8````IMP``%P```#"W```0````2+<``!$```!9MP``"````&NW
M```%````=+<```P```!ZMP``$````(>W```%````F+<```T```">MP``!@``
M`*RW```'````L[<```T```"[MP``!P```,FW```+````T;<```<```#=MP``
M!P```.6W```)````[;<```D```#WMP``"@````&X```9````#+@``#T````F
MN```'0```&2X```,````@K@``!````"/N```!0```*"X```E````IK@``!(`
M``#,N```$P```-^X```K````\[@``#L````?N0``(````%NY```(````?+D`
M`#8```"%N0``(0```+RY```0````WKD```@```#ON0``#````/BY```&````
M!;H```0````,N@``#P```!&Z```.````(;H```H````PN@``#0```#NZ```?
M````2;H``!P```!IN@``(0```(:Z```>````J+H``!D```#'N@``'@```.&Z
M```=`````+L``!L````>NP``(````#J[```N````6[L``"8```"*NP``'```
M`+&[```>````SKL``!P```#MNP``)@````J\```K````,;P``#,```!=O```
M)@```)&\```K````N+P``#@```#DO```'0```!V]```5````.[T``"\```!1
MO0``(````(&]```2````HKT``"D```"UO0``'@```-^]```@````_KT``!(`
M```?O@``H@```#*^```6````U;X``",```#LO@``*````!"_```I````.;\`
M`"@```!COP``'P```(R_```5````K+\``"````#"OP``)0```.._```H````
M"<```"T````RP```,````&#```"2````D<```"$````DP0``%@```$;!```<
M````7<$``"8```!ZP0``*@```*'!``!!````S,$``$0````.P@``#````%/"
M```'````8,(```<```!HP@``!@```'#"```-````=\(``!````"%P@``$@``
M`);"```3````J<(``!(```"]P@``!P```-#"```$````V,(``!````#=P@``
M$````.["```,````_\(```X````,PP``#0```!O#```/````*<,``!,````Y
MPP``#0```$W#```H````6\,```,```"$PP``#0```(C#```&````EL,```X`
M``"=PP```@```*S#``!)````K\,```4```#YPP``$````/_#```/````$,0`
M``0````@Q```#0```"7$```.````,\0```,```!"Q```#@```$;$```(````
M5<0```\```!>Q```#P```&[$```'````?L0```T```"&Q```$````)3$```-
M````I<0```L```"SQ```!@```+_$```+````QL0```P```#2Q```"@```-_$
M```1````ZL0``!D```#\Q```"P```!;%```-````(L4``"(````PQ0``&P``
M`%/%```T````;\4```H```"DQ0``&````*_%```9````R,4``!8```#BQ0``
M(@```/G%```-````',8```<````JQ@``%````#+&```+````1\8``"(```!3
MQ@``+P```';&```+````IL8```D```"RQ@``&0```+S&```+````UL8``!<`
M``#BQ@``%P```/K&```)````$L<``!8````<QP``#P```#/'```9````0\<`
M`!8```!=QP``#@```'3'```8````@\<```@```"<QP``#0```*7'```F````
ML\<``$,```#:QP``"````![(```2````)\@``!\````ZR```"````%K(```+
M````8\@``"\```!OR```#@```)_(```%````KL@```8```"TR````P```+O(
M```'````O\@```0```#'R```"@```,S(```*````U\@```\```#BR```$```
M`/+(```7`````\D``!$````;R0``&0```"W)```7````1\D```D```!?R0``
M!0```&G)```+````;\D```H```![R0```@```(;)```%````B<D```T```"/
MR0``&P```)W)```7````N<D``!0```#1R0``"0```.;)```.````\,D```T`
M``#_R0``$@````W*```X````(,H``"````!9R@``"````'K*```.````@\H`
M`'L```"2R@``&`````[+```8````)\L``!$```!`RP``!P```%++```%````
M6LL``!@```!@RP``'@```'G+```;````F,L``!D```"TRP``&P```,[+```9
M````ZLL``!,````$S```!P```!C,```(````(,P```8````IS```!@```##,
M```0````-\P```\```!(S```$````%C,```/````:<P```L```!YS```#P``
M`(7,```,````E<P```\```"BS```!P```++,```&````NLP```X```#!S```
M#````-#,```H````W<P```\````&S0``"````!;-```(````'\T``!,````H
MS0``'@```#S-```A````6\T``"````!]S0``&0```)[-```7````N,T``"4`
M``#0S0``%P```/;-```6````#LX```0````ES@``&P```"K.```-````1LX`
M``P```!4S@```P```&'.```%````9<X```@```!KS@``"@```'3.```,````
M?\X```L```",S@``$````)C.```,````J<X```0```"VS@``!````+O.```3
M````P,X``!0```#4S@``#````.G.```)````]LX```X`````SP``"P````_/
M```;````&\\```<````WSP``!P```#_/```*````1\\```T```!2SP``"0``
M`&#/```$````:L\```4```!OSP```P```'7/```8````><\```H```"2SP``
M!````)W/```F````HL\```X```#)SP``?````-C/```5````5=````4```!K
MT```!P```''0```,````>=````@```"&T```"@```(_0```&````FM````@`
M``"AT````@```*K0```&````K=````8```"TT```%````+O0```-````T-``
M`!````#>T```&P```._0```$````"]$```D````0T0``$````!K1```)````
M*]$```D````UT0``!0```#_1```:````1=$```@```!@T0``!@```&G1```9
M````<-$```X```"*T0``!P```)G1```'````H=$```4```"IT0``"0```*_1
M```*````N=$```(```#$T0``!@```,?1```+````SM$```T```#:T0``"0``
M`.C1```&````\M$```D```#YT0``!P````/2```4````"](``!T````@T@``
M0@```#[2```E````@=(``"4```"GT@``!@```,W2```*````U-(```0```#?
MT@``"0```.32```(````[M(``!$```#WT@``"0````G3```&````$],```T`
M```:TP``!@```"C3```$````+],``#D````TTP``/0```&[3```Z````K-,`
M`!X```#GTP``!0````;4```.````#-0```0````;U```!@```"#4```'````
M)]0``"$````OU```#0```%'4```&````7]0```0```!FU```$0```&O4```&
M````?=0```H```"$U```(@```(_4```$````LM0```4```"WU```'0```+W4
M```$````V]0```P```#@U```#@```.W4```*````_-0```@````'U0``"0``
M`!#5```%````&M4``#H````@U0``,````%O5```U````C-4``"D```#"U0``
M1P```.S5```X````--8``"D```!MU@``/P```)?6```N````U]8``"T````&
MUP``'P```#37```/````5-<``!(```!DUP``"P```'?7```F````@]<``"D`
M``"JUP``)````-37```F````^=<```@````@V```"@```"G8```)````--@`
M``<````^V```(````$;8```@````9]@``"8```"(V```"@```*_8```9````
MNM@``"D```#4V```%@```/[8```2````%=D```<````HV0``"@```##9```,
M````.]D```\```!(V0``$````%C9``!`````:=D``'````"JV0``9@```!O:
M```.````@MH```D```"1V@``"@```)O:```2````IMH``!,```"YV@``#```
M`,W:```&````VMH```\```#AV@``$@```/':```0````!-L``!$````5VP``
M'````"?;```C````1-L``&H```!HVP``#P```-/;```%````X]L``!````#I
MVP``"0```/K;```$````!-P```L````)W```(````!7<```4````-MP```P`
M``!+W```#````%C<```/````9=P``!4```!UW```*0```(O<```J````M=P`
M`"8```#@W```)P````?=```I````+]T``"H```!9W0``&0```(3=``!"````
MGMT``!$```#AW0``$@```//=```3````!MX``!0````:W@``#P```"_>```6
M````/]X``!<```!6W@``$````&[>```1````?]X``#0```"1W@``$P```,;>
M```2````VMX``#4```#MW@``%````"/?```'````.-\```P```!`WP``(```
M`$W?```0````;M\``!0```!_WP``$0```)3?```7````IM\``!P```"^WP``
M$P```-O?```4````[]\``!H````$X```$0```!_@```:````,>```!X```!,
MX```&@```&O@```3````AN```!4```":X```$0```+#@```7````PN```!0`
M``#:X```%P```._@```5````!^$```D````=X0``$````"?A```9````..$`
M``0```!2X0``!P```%?A```+````7^$``!$```!KX0``!@```'WA```&````
MA.$```8```"+X0``!0```)+A```'````F.$```<```"@X0``!0```*CA```&
M````KN$```8```"UX0``!````+SA```$````P>$```<```#&X0``#@```,[A
M```,````W>$```P```#JX0``#0```/?A```*````!>(```X````0X@``!0``
M`!_B```H````)>(```X```!.X@``#````%WB```/````:N(```H```!ZX@``
M"````(7B```)````CN(``"L```"8X@``!````,3B```(````R>(``"8```#2
MX@``$@```/GB```&````#.,```H````3XP``!P```![C```(````)N,``"``
M```OXP``"0```%#C```4````6N,```P```!OXP``#0```'SC```.````BN,`
M`!8```"9XP``$0```+#C```&````PN,```,```#)XP``!@```,WC```9````
MU.,```<```#NXP``!````/;C```+````^^,```L````'Y```!P```!/D```%
M````&^0```<````AY```%@```"GD```-````0.0```T```!.Y```"@```%SD
M```0````9^0```\```!XY```$0```(CD```7````FN0```H```"RY```$0``
M`+WD```(````S^0```0```#8Y```#P```-WD```Z````[>0```4````HY0``
M#````"[E```>````.^4```X```!:Y0``$````&GE```+````>N4```P```"&
MY0``"0```)/E```'````G>4```H```"EY0``"0```+#E```.````NN4``!``
M``#)Y0``&P```-KE```8````]N4``!H````/Y@``"@```"KF```)````->8`
M``H````_Y@``#````$KF```/````5^8```@```!GY@``!@```'#F```<````
M=^8```<```"4Y@``!0```)SF```+````HN8``$<```"NY@``#0```/;F```)
M````!.<```0````.YP```P```!/G```3````%^<``!,````KYP``$P```#_G
M```*````4^<```(```!>YP``!````&'G```E````9N<```,```",YP``!0``
M`)#G```J````EN<```H```#!YP``!0```,SG```$````TN<```H```#7YP``
M#0```.+G```&````\.<```@```#WYP``"`````#H```$````">@```4````.
MZ```:````!3H```)````?>@```P```"'Z```$````)3H```%````I>@```8`
M``"KZ```&P```++H```O````SN@``!````#^Z```"@````_I```/````&ND`
M``H````JZ0``"0```#7I```3````/^D``!L```!3Z0``&````&_I```7````
MB.D``!\```"@Z0``#@```,#I```#````S^D```<```#3Z0``"````-OI```'
M````Y.D```H```#LZ0``"P```/?I```'`````^H``%$````+Z@``$````%WJ
M```,````;NH```T```![Z@``&@```(GJ``!*````I.H``!D```#OZ@``!@``
M``GK```:````$.L``"4````KZP``!@```%'K```&````6.L``!\```!?ZP``
M!@```'_K```)````ANL``!@```"0ZP``%P```*GK```H````P>L```8```#J
MZP``#0```/'K```B````_^L``%<````B[```$P```'KL```C````CNP``!,`
M``"R[````@```,;L```+````R>P```@```#5[```#0```-[L```*````[.P`
M``<```#W[```%````/_L```&````%.T```@````;[0``#@```"3M```'````
M,^T```H````[[0``"P```$;M```R````4NT```<```"%[0``#````(WM```-
M````FNT```P```"H[0``"0```+7M```)````O^T```H```#)[0``!P```-3M
M```)````W.T```<```#F[0``"@```.[M```;````^>T``!(````5[@``"@``
M`"CN```6````,^X```D```!*[@``$````%3N```'````9>X``!(```!M[@``
M!````(#N```'````A>X```4```"-[@``!0```)/N```+````F>X``!0```"E
M[@``$0```+KN```:````S.X``!8```#G[@``%````/[N```7````$^\``!@`
M```K[P``'````$3O```9````8>\```<```![[P``!0```(/O```-````B>\`
M``P```"7[P``$0```*3O```(````MN\``!<```"_[P``"P```-?O```,````
MX^\``!\```#P[P``&@```!#P```3````*_````0````_\```"@```$3P```$
M````3_````T```!4\```#````&+P```%````;_````D```!U\```!0```'_P
M```'````A?````4```"-\```!````)/P```"````F/```#@```";\```+```
M`-3P```2`````?$``"D````4\0``,@```#[Q```*````<?$``"P```!\\0``
M+@```*GQ```S````V/$``#,````,\@``.````$#R```/````>?(``!@```")
M\@``$````*+R```/````L_(``!,```##\@``%0```-?R```4````[?(``!(`
M```"\P``%````!7S```5````*O,``"T```!`\P``+0```&[S```Q````G/,`
M`"X```#.\P``+P```/WS```L````+?0``&(```!:]```$P```+WT```-````
MT?0```@```#?]```%P```.CT```(`````/4```P````)]0``*P```!;U```A
M````0O4``!H```!D]0``"0```'_U``!%````B?4``$$```#/]0``!````!'V
M```3````%O8```X````J]@``$P```#GV```8````3?8```8```!F]@``"0``
M`&WV```*````=_8```\```""]@``$````)+V```'````H_8```X```"K]@``
M!0```+KV```;````P/8```@```#<]@``!@```.7V```4````[/8``!$````!
M]P``#@```!/W```X````(O<```(```!;]P``!@```%[W```.````9?<```4`
M``!T]P``!P```'KW```.````@O<```8```"1]P``*````)CW```,````P?<`
M`!P```#.]P``!````.OW```I````\/<``!<````:^```'P```#+X``!<````
M4O@``!0```"O^```/@```,3X```?`````_D``!`````C^0``!P```#3Y```.
M````//D```P```!+^0``#````%CY```3````9?D```H```!Y^0``'0```(3Y
M```9````HOD```4```"\^0``$0```,+Y```1````U/D``"0```#F^0``$@``
M``OZ```5````'OH``!(````T^@``#@```$?Z```9````5OH```@```!P^@``
M"0```'GZ```-````@_H```H```"1^@``!P```)SZ```/````I/H```8```"T
M^@``"P```+OZ```:````Q_H```H```#B^@``!P```.WZ```(````]?H```4`
M``#^^@``'P````3[```&````)/L``!`````K^P``"````#S[```-````1?L`
M``@```!3^P``'@```%S[```2````>_L``"P```".^P``&@```+O[```)````
MUOL```H```#@^P``%0```.O[```%`````?P``!0````'_```!````!S\```0
M````(?P```8````R_```!P```#G\```>````0?P``"@```!@_```"@```(G\
M```<````E/P``!$```"Q_```"P```,/\```:````S_P``!0```#J_```!```
M`/_\```$````!/T```L````)_0``!0```!7]```&````&_T```@````B_0``
M!@```"O]```;````,OT``#0```!._0``-````(/]```@````N/T``"D```#9
M_0``(`````/^``!!````)/X``!H```!F_@``*````('^```I````JOX``%``
M``#4_@``(@```"7_```&````2/\```@```!/_P``!0```%C_```(````7O\`
M`!D```!G_P``&0```('_```J````F_\``",```#&_P``&0```.K_```N````
M!``!`#0````S``$`"````&@``0`7````<0`!``H```")``$`!P```)0``0`A
M````G``!`!````"^``$`#@```,\``0`+````W@`!``<```#J``$`$P```/(`
M`0`(````!@$!``L````/`0$`"@```!L!`0`4````)@$!``\````[`0$`,@``
M`$L!`0`+````?@$!``4```"*`0$`!0```)`!`0`%````E@$!`!<```"<`0$`
M#P```+0!`0`$````Q`$!``H```#)`0$`"0```-0!`0`+````W@$!``T```#J
M`0$`#````/@!`0`.````!0(!``4````4`@$`!````!H"`0`-````'P(!`#(`
M```M`@$`10```&`"`0`7````I@(!``<```"^`@$`'@```,8"`0`4````Y0(!
M``4```#Z`@$`%``````#`0`&````%0,!``<````<`P$`#@```"0#`0`J````
M,P,!``8```!>`P$`#````&4#`0`-````<@,!`!$```"``P$`"P```)(#`0`V
M````G@,!``H```#5`P$`(@```.`#`0`+`````P0!``\````/!`$`,@```!\$
M`0`E````4@0!`#````!X!`$`,0```*D$`0`M````VP0!``X````)!0$`!0``
M`!@%`0`.````'@4!`!,````M!0$`$@```$$%`0`'````5`4!`!$```!<!0$`
M$P```&X%`0`'````@@4!`!0```"*!0$`&````)\%`0`'````N`4!``4```#`
M!0$`#````,8%`0`,````TP4!`!(```#@!0$`!````/,%`0`'````^`4!``H`
M````!@$`"P````L&`0`,````%P8!``X````D!@$`#@```#,&`0`%````0@8!
M``4```!(!@$`+@```$X&`0`F````?08!`",```"D!@$``P```,@&`0`2````
MS`8!``8```#?!@$`'@```.8&`0`8````!0<!`"4````>!P$`#0```$0'`0`)
M````4@<!`!\```!<!P$``P```'P'`0`'````@`<!``H```"(!P$``@```),'
M`0`,````E@<!`!4```"C!P$`"P```+D'`0`9````Q0<!`"````#?!P$`$@``
M```(`0`%````$P@!``H````9"`$`%0```"0(`0`2````.@@!``P```!-"`$`
M!````%H(`0`)````7P@!``<```!I"`$`#````'$(`0!2````?@@!`!<```#1
M"`$`)````.D(`0`2````#@D!``<````A"0$`!@```"D)`0`.````,`D!``P`
M```_"0$`#0```$P)`0`5````6@D!`!(```!P"0$`#P```(,)`0`4````DPD!
M``H```"H"0$`&P```+,)`0`0````SPD!``L```#@"0$`:0```.P)`0`:````
M5@H!`!<```!Q"@$`)P```(D*`0`:````L0H!`!<```#,"@$`&P```.0*`0`9
M``````L!`!\````:"P$`$P```#H+`0`(````3@L!``<```!7"P$`"````%\+
M`0`)````:`L!`!4```!R"P$`#0```(@+`0`C````E@L!``T```"Z"P$`$P``
M`,@+`0`(````W`L!``,```#E"P$`1@```.D+`0`_````,`P!`#<```!P#`$`
M5P```*@,`0`%``````T!`!\````&#0$`+P```"8-`0`*````5@T!``@```!A
M#0$`#0```&H-`0`M````>`T!``0```"F#0$`3P```*L-`0`E````^PT!`!P`
M```A#@$`"P```#X.`0`?````2@X!`!T```!J#@$`)0```(@.`0`@````K@X!
M`"0```#/#@$`(````/0.`0`+````%0\!``<````A#P$`#0```"D/`0`,````
M-P\!`!<```!$#P$`!@```%P/`0`Y````8P\!``P```"=#P$`!P```*H/`0`)
M````L@\!`!,```"\#P$`"0```-`/`0`$````V@\!`!````#?#P$`"````/`/
M`0`(````^0\!``0````"$`$`"P````<0`0`,````$Q`!`!(````@$`$`$0``
M`#,0`0`,````11`!`!H```!2$`$`#P```&T0`0`'````?1`!``T```"%$`$`
M%````),0`0`.````J!`!``P```"W$`$`+````,00`0`3````\1`!`!P````%
M$0$`*````"(1`0`&````2Q$!``<```!2$0$`$P```%H1`0`%````;A$!``0`
M``!T$0$`%P```'D1`0`*````D1$!``P```"<$0$`"0```*D1`0`&````LQ$!
M``D```"Z$0$`"````,01`0`)````S1$!``H```#7$0$`$0```.(1`0`&````
M]!$!``X```#[$0$`#@````H2`0`-````&1(!``L````G$@$`'0```#,2`0`+
M````41(!``(```!=$@$`'````&`2`0`'````?1(!``8```"%$@$`9````(P2
M`0`)````\1(!``<```#[$@$`)@````,3`0`X````*A,!`!H```!C$P$`*@``
M`'X3`0`[````J1,!`"@```#E$P$`-`````X4`0`9````0Q0!`!4```!=%`$`
M!0```',4`0`'````>10!``@```"!%`$`!P```(H4`0`%````DA0!``<```"8
M%`$`#@```*`4`0`)````KQ0!``8```"Y%`$`"````,`4`0`+````R10!``<`
M``#5%`$`"````-T4`0`'````YA0!`!8```#N%`$`"0````45`0`&````#Q4!
M``L````6%0$`$````"(5`0`&````,Q4!`!P````Z%0$`%````%<5`0`'````
M;!4!`!$```!T%0$`"````(85`0`.````CQ4!``@```">%0$`!0```*<5`0`0
M````K14!`!````"^%0$`!@```,\5`0`9````UA4!``H```#P%0$`'````/L5
M`0`'````&!8!``4````@%@$`$````"86`0`4````-Q8!``L```!,%@$`#0``
M`%@6`0`H````9A8!`!@```"/%@$`%P```*@6`0`$````P!8!``D```#%%@$`
M"@```,\6`0`'````VA8!``(```#B%@$`"````.46`0`C````[A8!`#@````2
M%P$`)@```$L7`0`Q````<A<!`"<```"D%P$`9````,P7`0`4````,1@!`%4`
M``!&&`$`.````)P8`0!*````U1@!`%L````@&0$`*````'P9`0`X````I1D!
M`"@```#>&0$`+`````<:`0`F````-!H!`!L```!;&@$`/@```'<:`0"I`0``
MMAH!`",```!@'`$`%P```(0<`0!(````G!P!`(4```#E'`$`,````&L=`0`E
M````G!T!`$$```#"'0$`6P````0>`0!)````8!X!`#$```"J'@$`'0```-P>
M`0`8````^AX!`"L````3'P$`(0```#\?`0`?````81\!`"L```"!'P$`(0``
M`*T?`0`G````SQ\!`#H```#W'P$`'0```#(@`0`1````4"`!`#,```!B(`$`
M)0```)8@`0`G````O"`!`"````#D(`$`'P````4A`0`P````)2$!`&D```!6
M(0$`,0```,`A`0!!````\B$!`#,````T(@$`)0```&@B`0`]````CB(!`&4`
M``#,(@$`30```#(C`0`O````@",!`"X```"P(P$`,````-\C`0!4````$"0!
M`%H```!E)`$`2````,`D`0!*````"24!`#(```!4)0$`+P```(<E`0`L````
MMR4!`"T```#D)0$`<0```!(F`0!F````A"8!`&\```#K)@$`LP```%LG`0`7
M````#R@!`"4````G*`$`,@```$TH`0`I````@"@!`#X```"J*`$`(@```.DH
M`0!2````#"D!`"4```!?*0$`"P```(4I`0"Q````D2D!`$4```!#*@$`(0``
M`(DJ`0`P````JRH!`"4```#<*@$`'`````(K`0`Q````'RL!``<```!1*P$`
M!P```%DK`0`$````82L!``T```!F*P$`"P```'0K`0`.````@"L!``L```"/
M*P$`!0```)LK`0`0````H2L!``(```"R*P$`60```+4K`0`%````#RP!`!(`
M```5+`$`!````"@L`0`'````+2P!``@````U+`$`!0```#XL`0`#````1"P!
M`!````!(+`$`#````%DL`0`3````9BP!``T```!Z+`$``@```(@L`0`'````
MBRP!``8```"3+`$`#````)HL`0`8````IRP!``8```#`+`$`$@```,<L`0`,
M````VBP!``,```#G+`$`*@```.LL`0`$````%BT!``8````;+0$`!P```"(M
M`0`?````*BT!`#4```!*+0$`+@```(`M`0`O````KRT!`!<```#?+0$`(@``
M`/<M`0`E````&BX!`"````!`+@$`&P```&$N`0`8````?2X!`"0```"6+@$`
M'P```+LN`0`:````VRX!`"$```#V+@$`(````!@O`0`:````.2\!`#(```!4
M+P$`&@```(<O`0`O````HB\!`"L```#2+P$`'P```/XO`0`C````'C`!`!\`
M``!",`$`&@```&(P`0`A````?3`!`"4```"?,`$`)@```,4P`0`E````[#`!
M`"0````2,0$`&````#<Q`0`=````4#$!`"0```!N,0$`&````),Q`0`B````
MK#$!`"P```#/,0$`+P```/PQ`0`5````+#(!`"4```!",@$`/````&@R`0`?
M````I3(!`",```#%,@$`'P```.DR`0`@````"3,!`!H````J,P$`&````$4S
M`0`F````7C,!`!X```"%,P$`*0```*0S`0`>````SC,!`#$```#M,P$`"0``
M`!\T`0`,````*30!`!<````V-`$`+P```$XT`0`D````?C0!``<```"C-`$`
M%````*LT`0`.````P#0!``T```#/-`$`!0```-TT`0`'````XS0!`"(```#K
M-`$`)0````XU`0`:````-#4!`!T```!/-0$`&@```&TU`0`'````B#4!`,<`
M``"0-0$`"P```%@V`0`5````9#8!``8```!Z-@$`"0```($V`0`+````BS8!
M``T```"7-@$`%P```*4V`0`&````O38!`#,```#$-@$`$P```/@V`0`3````
M##<!``<````@-P$`#P```"@W`0`'````.#<!`#(```!`-P$`!````',W`0`A
M````>#<!`!,```":-P$`#````*XW`0`1````NS<!`#(```#--P$`%@`````X
M`0`(````%S@!`!T````@.`$`"0```#XX`0`*````2#@!`!0```!3.`$`"@``
M`&@X`0`=````<S@!``@```"1.`$`'P```)HX`0`(````NC@!`!H```##.`$`
M)P```-XX`0`&````!CD!`!4````-.0$`!P```",Y`0`(````*SD!``D````T
M.0$`/P```#XY`0`'````?CD!``\```"&.0$`#@```)8Y`0`0````I3D!``D`
M``"V.0$`"0```,`Y`0`(````RCD!``<```#3.0$`&0```-LY`0`*````]3D!
M`!<`````.@$`%````!@Z`0`*````+3H!``P````X.@$`%P```$4Z`0`$````
M73H!`"H```!B.@$`#````(TZ`0`1````FCH!``<```"L.@$``@```+0Z`0`0
M````MSH!`!@```#(.@$`"P```.$Z`0`#````[3H!``@```#Q.@$`!@```/HZ
M`0`'`````3L!``T````).P$`"P```!<[`0`.````(SL!`"\````R.P$`(```
M`&([`0`<````@SL!`!4```"@.P$`#````+8[`0`Q````PSL!``4```#U.P$`
M$@```/L[`0`_````#CP!`!(```!./`$`"@```&$\`0`&````;#P!``0```!S
M/`$`!````'@\`0`*````?3P!`!,```"(/`$`!0```)P\`0`&````HCP!``8`
M``"I/`$`"````+`\`0`$````N3P!``P```"^/`$`"@```,L\`0`Y````UCP!
M`"X````0/0$`*0```#\]`0`%````:3T!`!@```!O/0$`&0```(@]`0`?````
MHCT!`!T```#"/0$`$0```.`]`0`"````\CT!``0```#U/0$`"@```/H]`0`&
M````!3X!``4````,/@$``P```!(^`0`,````%CX!`$4````C/@$`,@```&D^
M`0`:````G#X!`#0```"W/@$`*````.P^`0!3````%3\!`!D```!I/P$`<@``
M`(,_`0`@````]C\!`#4````70`$`(0```$U``0!%````;T`!`#````"U0`$`
M*````.9``0`I````#T$!`"8````Y00$`)0```&!!`0`H````AD$!`"@```"O
M00$`(@```-A!`0`K````^T$!`#`````G0@$`$@```%A"`0`3````:T(!`!``
M``!_0@$`>0```)!"`0`)````"D,!`*$````40P$`<P```+9#`0!\````*D0!
M`"L```"G1`$`5````--$`0`7````*$4!`"<```!`10$`%@```&A%`0`/````
M?T4!`!<```"/10$`'P```*=%`0!`````QT4!`!\````(1@$`'````"A&`0!1
M````148!`!H```"71@$`%````+)&`0`*````QT8!``4```#21@$`!@```-A&
M`0`(````WT8!``4```#H1@$`$@```.Y&`0`0`````4<!`!,````21P$`'0``
M`"9'`0`/````1$<!``\```!41P$`!````&1'`0`)````:4<!``L```!S1P$`
M!P```']'`0`%````AT<!`!0```"-1P$`!P```*)'`0`(````JD<!``\```"S
M1P$`"````,-'`0`,````S$<!``\```#91P$`!@```.E'`0`4````\$<!``8`
M```%2`$`#`````Q(`0`1````&4@!``@````K2`$`!````#1(`0`9````.4@!
M`!$```!32`$`"@```&5(`0`8````<$@!`!,```")2`$`'````)U(`0`1````
MND@!``\```#,2`$`!P```-Q(`0`$````Y$@!`!D```#I2`$`!P````-)`0`"
M````"TD!``(````.20$`$0```!%)`0`)````(TD!``8````M20$`$@```#1)
M`0`7````1TD!``8```!?20$`)P```&9)`0`"````CDD!``0```"120$`#P``
M`)9)`0`3````IDD!``<```"Z20$`!P```,))`0`1````RDD!``8```#<20$`
M&````.-)`0`&````_$D!`!,````#2@$`$````!=*`0`2````*$H!``(````[
M2@$`!@```#Y*`0`,````14H!``D```!22@$`$0```%Q*`0`B````;DH!``<`
M``"12@$`!P```)E*`0`+````H4H!``4```"M2@$``@```+-*`0`+````MDH!
M`$D!``#"2@$`$`````Q,`0`7````'4P!``L````U3`$`!@```$%,`0`)````
M2$P!``@```!23`$`"@```%M,`0`4````9DP!`!D```![3`$`+0```)5,`0`E
M````PTP!`"4```#I3`$`(P````]-`0`?````,TT!`"T```!330$`"@```(%-
M`0`J````C$T!`!,```"W30$`#0```,M-`0`+````V4T!``4```#E30$`+0``
M`.M-`0`-````&4X!`!T````G3@$`%0```$5.`0`/````6TX!`!$```!K3@$`
M=````'U.`0`.````\DX!``@````!3P$`$0````I/`0`-````'$\!`!8````J
M3P$`%P```$%/`0`7````64\!`!H```!Q3P$`!@```(Q/`0"_````DT\!``L`
M``!34`$`$@```%]0`0`=````<E`!`!````"04`$`$@```*%0`0`2````M%`!
M``@```#'4`$`#P```-!0`0`P````X%`!`!D````140$`-@```"M1`0`]````
M8E$!`%````"@40$`3P```/%1`0!8````05(!`%8```":4@$`.````/%2`0`4
M````*E,!`!<````_4P$`$0```%=3`0`5````:5,!`!T```!_4P$`"````)U3
M`0`&````IE,!``\```"M4P$`!````+U3`0`0````PE,!``\```#34P$`,@``
M`.-3`0`P````%E0!`!$```!'5`$`#@```%E4`0`1````:%0!``D```!Z5`$`
M!@```(14`0`9````BU0!`!<```"E5`$`!P```+U4`0`.````Q50!`!$```#4
M5`$`'@```.94`0`<````!54!`!,````B50$`#0```#95`0`-````1%4!``H`
M``!250$`)@```%U5`0`3````A%4!`!@```"850$`$@```+%5`0!4````Q%4!
M`#<````95@$`)````%%6`0`&````=E8!``<```!]5@$`-@```(56`0`-````
MO%8!``<```#*5@$`"@```-)6`0`(````W58!``@```#F5@$`!0```.]6`0`(
M````]58!``L```#^5@$`!@````I7`0`C````$5<!``X````U5P$`#````$17
M`0`3````45<!`!8```!E5P$`*P```'Q7`0`+````J%<!`"0```"T5P$`%P``
M`-E7`0`D````\5<!`!T````66`$`%````#18`0`2````25@!``X```!<6`$`
M'````&M8`0`6````B%@!``<```"?6`$`!@```*=8`0`(````KE@!``X```"W
M6`$`!P```,98`0`*````SE@!`!$```#96`$`"0```.M8`0`0````]5@!`!@`
M```&60$`*@```!]9`0`(````2ED!`!$```!360$`!0```&59`0`/````:UD!
M``P```![60$`,0```(A9`0`O````NED!``D```#J60$`"````/19`0`&````
M_5D!``4````$6@$`$`````I:`0`,````&UH!`!4````H6@$`-````#Y:`0`H
M````<UH!`"<```"<6@$`)````,1:`0`Q````Z5H!``@````;6P$`!@```"1;
M`0`)````*UL!``<````U6P$`-P```#U;`0`O````=5L!`#8```"E6P$`7@``
M`-Q;`0`U````.UP!`#4```!Q7`$`2@```*=<`0!+````\EP!`#4````^70$`
M0@```'1=`0`Q````MUT!`#0```#I70$`3````!Y>`0`U````:UX!`#L```"A
M7@$`+````-U>`0`6````"E\!`!H````A7P$`)@```#Q?`0`K````8U\!`"L`
M``"/7P$`$0```+M?`0`+````S5\!``P```#97P$`!P```.9?`0`-````[E\!
M`!<```#\7P$`)````!1@`0`&````.6`!``<```!`8`$`"0```$A@`0`(````
M4F`!`"@```!;8`$`#P```(1@`0`*````E&`!``@```"?8`$`!@```*A@`0`%
M````KV`!``<```"U8`$`!0```+U@`0`*````PV`!`"<```#.8`$`$````/9@
M`0`)````!V$!``4````180$`!P```!=A`0`'````'V$!``4````G80$`#0``
M`"UA`0`&````.V$!`!,```!"80$``P```%9A`0`(````6F$!``8```!C80$`
M#0```&IA`0`(````>&$!`"````"!80$`$0```*)A`0`)````M&$!`!(```"^
M80$`#````-%A`0`'````WF$!``,```#F80$``P```.IA`0`4````[F$!`!0`
M```#8@$`,@```!AB`0`(````2V(!``D```!48@$`"````%YB`0`'````9V(!
M`$L```!O8@$`)````+MB`0`M````X&(!`"@````.8P$`(0```#=C`0`&````
M66,!``8```!@8P$`&````&=C`0`A````@&,!`"0```"B8P$`+@```,=C`0`E
M````]F,!`"T````<9`$`8````$ID`0`N````JV0!`!(```#:9`$`!P```.UD
M`0`3````]60!`!$````)90$`#P```!ME`0`0````*V4!`!`````\90$`$```
M`$UE`0`0````7F4!``\```!O90$`"0```']E`0`7````B64!`"$```"A90$`
M%````,-E`0`8````V&4!``,```#Q90$`!@```/5E`0`1````_&4!`%4````.
M9@$`7````&1F`0`$````P68!`!8```#&9@$`!0```-UF`0`$````XV8!`!(`
M``#H9@$`#P```/MF`0`<````"V<!`"0````H9P$`,````$UG`0`/````?F<!
M`",```".9P$`!0```+)G`0`:````N&<!``T```#39P$`&0```.%G`0`5````
M^V<!`!L````1:`$`$0```"UH`0`9````/V@!`!,```!9:`$`#0```&UH`0`&
M````>V@!``P```"":`$`!P```(]H`0`7````EV@!`!(```"O:`$`#@```,)H
M`0`(````T6@!``4```#::`$`"P```.!H`0`+````[&@!``<```#X:`$`#P``
M``!I`0`&````$&D!``8````7:0$`%0```!YI`0`(````-&D!``H````]:0$`
M!@```$AI`0`*````3VD!``@```!::0$`!````&-I`0`$````:&D!`!<```!M
M:0$`3````(5I`0`D````TFD!``\```#W:0$`#@````=J`0`%````%FH!`!P`
M```<:@$`$0```#EJ`0`2````2VH!`"X```!>:@$`/0```(UJ`0`@````RVH!
M``@```#L:@$`,````/5J`0`:````)FL!``H```!!:P$`"@```$QK`0`/````
M5VL!``8```!G:P$`"0```&YK`0`7````>&L!``\```"0:P$`"0```*!K`0`2
M````JFL!`"T```"]:P$`*P```.MK`0`O````%VP!`"T```!';`$`(0```'5L
M`0`F````EVP!`"4```"^;`$`*0```.1L`0`I````#FT!`#4````X;0$`*P``
M`&YM`0`D````FFT!`"8```"_;0$`(0```.9M`0`J````"&X!`#H````S;@$`
M+@```&YN`0`D````G6X!`#````#";@$`.0```/-N`0`E````+6\!`"$```!3
M;P$`-````'5O`0`E````JF\!`!D```#0;P$`+P```.IO`0`C````&G`!`"8`
M```^<`$`&@```&5P`0"Q````@'`!`!(````R<0$`(````$5Q`0`I````9G$!
M`"D```"0<0$`,0```+IQ`0`B````['$!`"$````/<@$`)0```#%R`0`I````
M5W(!`"P```"!<@$`.@```*YR`0`L````Z7(!`),````6<P$`)0```*IS`0`;
M````T',!`"8```#L<P$`+P```!-T`0`O````0W0!`$8```!S=`$`1````+IT
M`0`-````_W0!``<````-=0$`!0```!5U`0`(````&W4!``X````D=0$`#0``
M`#-U`0`5````074!``P```!7=0$`%0```&1U`0`*````>G4!``0```"%=0$`
M#P```(IU`0`0````FG4!``P```"K=0$`#P```+AU`0`5````R'4!`!````#>
M=0$`%````.]U`0`-````!'8!`$(````2=@$`"@```%5V`0`0````8'8!``8`
M``!Q=@$`#P```'AV`0`"````B'8!`$L```"+=@$`!0```-=V`0`C````W78!
M`!<````!=P$`!0```!EW`0`.````'W<!``P````N=P$``P```#MW`0`1````
M/W<!``@```!1=P$`$````%IW`0`1````:W<!``T```!]=P$`$P```(MW`0`;
M````GW<!`",```"[=P$`"0```-]W`0`'````Z7<!``T```#Q=P$`#P```/]W
M`0`.````#W@!``T````>>`$`&@```"QX`0`-````1W@!``X```!5>`$`)P``
M`&1X`0`6````C'@!`"L```"C>`$`#@```,]X`0`8````WG@!`!<```#W>`$`
M%P````]Y`0`Q````)WD!``T```!9>0$`!@```&=Y`0`/````;GD!``4```!^
M>0$`*P```(1Y`0`L````L'D!``4```#=>0$`"0```.-Y`0`>````[7D!``L`
M```,>@$`$@```!AZ`0`2````*WH!``<````^>@$`)@```$9Z`0`5````;7H!
M`!L```"#>@$`&````)]Z`0`1````N'H!`!4```#*>@$`"0```.!Z`0`)````
MZGH!`",```#T>@$`/0```!A[`0`(````5GL!`!8```!?>P$`'@```'9[`0`(
M````E7L!``L```">>P$`,@```*I[`0`0````W7L!``4```#N>P$`!@```/1[
M`0`#````^WL!``<```#_>P$`!P````=\`0`,````#WP!``\````<?`$`#0``
M`"Q\`0`-````.GP!`!0```!(?`$`%P```%U\`0`6````=7P!`!0```",?`$`
M"P```*%\`0`%````K7P!``@```"S?`$`"@```+Q\`0`"````QWP!``4```#*
M?`$`$````-!\`0`C````X7P!`!,````%?0$`$@```!E]`0`)````+'T!``\`
M```V?0$`$0```$9]`0`:````6'T!`"T```!S?0$`*P```*%]`0`+````S7T!
M``X```#9?0$`=@```.A]`0`3````7WX!`!\```!S?@$`$````)-^`0`'````
MI'X!``4```"L?@$`'0```+)^`0`Q````T'X!`"\````"?P$`'@```#)_`0`@
M````47\!`!H```!R?P$`&@```(U_`0`(````J'\!``<```"Q?P$`!P```+E_
M`0`&````P7\!`!````#(?P$`#@```-E_`0`1````Z'\!``\```#Z?P$`%0``
M``J``0`/````((`!``P````P@`$`"@```#V``0`'````2(`!``@```!0@`$`
M%````%F``0`.````;H`!`#<```!]@`$`#P```+6``0`(````Q8`!``L```#.
M@`$`&@```-J``0`@````]8`!`"H````6@0$`*0```$&!`0`?````:X$!`"``
M``"+@0$`*@```*R!`0`?````UX$!`!@```#W@0$`!0```!""`0`=````%H(!
M``\````T@@$`#@```$2"`0`#````4X(!``0```!7@@$`!P```%R"`0`-````
M9((!``\```!R@@$`"P```(*"`0`5````CH(!``L```"D@@$`!0```+""`0`%
M````MH(!`!<```"\@@$`&0```-2"`0`/````[H(!``L```#^@@$`#`````J#
M`0`/````%X,!`"8````G@P$`!@```$Z#`0`&````58,!``T```!<@P$`"@``
M`&J#`0`+````=8,!``8```"!@P$`#@```(B#`0`$````EX,!`!<```"<@P$`
M"P```+2#`0`'````P(,!`"H```#(@P$`#P```/.#`0"#`````X0!`!(```"'
MA`$`"0```)J$`0`'````I(0!``L```"LA`$`!P```+B$`0`)````P(0!``0`
M``#*A`$`#0```,^$`0`#````W80!``4```#AA`$`"@```.>$`0`3````\H0!
M`!(````&A0$`%````!F%`0`:````+H4!``(```!)A0$`"0```$R%`0`+````
M5H4!``0```!BA0$`"@```&>%`0`%````<H4!`"8```!XA0$`"````)^%`0`&
M````J(4!`"<```"OA0$`#@```->%`0`'````YH4!``<```#NA0$`!0```/:%
M`0`)````_(4!``L````&A@$`!P```!*&`0`&````&H8!``L````AA@$`$```
M`"V&`0`-````/H8!``8```!,A@$`!P```%.&`0`'````6X8!`!0```!CA@$`
M'0```'B&`0`_````EH8!`"P```#6A@$`,0````.'`0`'````-8<!``H````]
MAP$`!````$B'`0`)````38<!``@```!7AP$`'0```&"'`0`)````?H<!``8`
M``"(AP$`#0```(^'`0`&````G8<!``0```"DAP$`,@```*F'`0`T````W(<!
M`#0````1B`$`(P```$:(`0`%````:H@!`!T```!PB`$`!````(Z(`0`(````
MDX@!``@```"<B`$`)````*6(`0`+````RH@!``4```#6B`$`"````-R(`0`?
M````Y8@!``@````%B0$`"`````Z)`0`6````%XD!``8````NB0$`!@```#6)
M`0`'````/(D!``4```!$B0$`#0```$J)`0`0````6(D!``T```!IB0$`"```
M`'>)`0`)````@(D!``4```"*B0$`.P```)")`0`X````S(D!`#P````%B@$`
M)P```$**`0`X````:HH!`$````"CB@$`,````.2*`0`Z````%8L!`#4```!0
MBP$`/@```(:+`0`I````Q8L!`!(```#OBP$`%@````*,`0`-````&8P!`"H`
M```GC`$`'````%*,`0`=````;XP!`!P```"-C`$`!P```*J,`0`)````LHP!
M``D```"\C`$`"````,:,`0`H````SXP!`"<```#XC`$`)0```""-`0`)````
M1HT!`!H```!0C0$`+P```&N-`0`F````FXT!`!$```#"C0$`!@```-2-`0`)
M````VXT!``P```#EC0$`#````/*-`0`/````_XT!`#8````/C@$`@@```$:.
M`0!V````R8X!``\```!`CP$`"P```%"/`0`,````7(\!`!$```!ICP$`$@``
M`'N/`0`0````CH\!``<```"?CP$`#P```*>/`0`4````MX\!`!(```#,CP$`
M#P```-^/`0`?````[X\!`"H````/D`$`A@```#J0`0`1````P9`!``4```#3
MD`$`%P```-F0`0`)````\9`!``0```#[D`$`"@````"1`0`>````"Y$!`!$`
M```JD0$`#@```#R1`0`.````2Y$!``P```!:D0$`$P```&>1`0`>````>Y$!
M`"````":D0$`'@```+N1`0`@````VI$!`!\```#[D0$`(0```!N2`0`;````
M/9(!`#@```!9D@$`#P```)*2`0`1````HI(!`!````"TD@$`$@```,62`0`-
M````V)(!`!(```#FD@$`%````/F2`0`0````#I,!`!(````?DP$`,@```#*3
M`0`6````99,!`!0```!\DP$`/0```)&3`0`4````SY,!``H```#DDP$`$P``
M`.^3`0!!`````Y0!`!L```!%E`$`$P```&&4`0`2````=90!`!T```"(E`$`
M&````*:4`0`6````OY0!`!<```#6E`$`'@```.Z4`0`:````#94!`"@````H
ME0$`(P```%&5`0`:````=94!`!4```"0E0$`%@```*:5`0`1````O94!`!<`
M``#/E0$`&0```.>5`0`9`````98!`!<````;E@$`"````#.6`0`0````/)8!
M``0```!-E@$`!````%*6`0`%````5Y8!``L```!=E@$`#P```&F6`0`&````
M>98!``D```"`E@$`!P```(J6`0`)````DI8!``<```"<E@$`!@```*26`0`(
M````JY8!``8```"TE@$`!@```+N6`0`#````PI8!``,```#&E@$`"````,J6
M`0`2````TY8!`!$```#FE@$`#@```/B6`0`/````!Y<!``H````7EP$`$@``
M`"*7`0`$````-9<!`"@````ZEP$`$@```&.7`0`0````=I<!`!@```"'EP$`
M"P```*"7`0`)````K)<!``X```"VEP$`+0```,67`0`$````\Y<!``@```#X
MEP$`(@````&8`0`2````))@!``8````WF`$`"0```#Z8`0`'````2)@!``4`
M``!0F`$`!````%:8`0`1````6Y@!`!0```!MF`$`#@```(*8`0`6````D9@!
M`!@```"HF`$`'0```,&8`0`;````WY@!``@```#[F`$`!0````29`0`&````
M"ID!`"$````1F0$`!P```#.9`0`%````.YD!``X```!!F0$`#0```%"9`0`'
M````7ID!``8```!FF0$`!P```&V9`0`%````=9D!``\```![F0$`#P```(N9
M`0`*````FYD!``\```"FF0$`$0```+:9`0`6````R)D!`!0```#?F0$`#@``
M`/29`0`6`````YH!``@````:F@$`!0```".:`0`1````*9H!`#8````[F@$`
M!0```'*:`0`,````>)H!`",```"%F@$`%@```*F:`0`4````P)H!`!<```#5
MF@$`#````.V:`0`)````^IH!``<````$FP$`"@````R;`0`)````%YL!``X`
M```AFP$`$````#";`0`=````09L!`",```!?FP$`+@```(.;`0`*````LIL!
M``4```"]FP$`#@```,.;`0`-````TIL!`!$```#@FP$`"````/*;`0`+````
M^YL!`"8````'G`$`"````"Z<`0`+````-YP!`!0```!#G`$`40```%B<`0`4
M````JIP!``D```"_G`$`!0```,F<`0`%````SYP!`!,```#5G`$`%0```.F<
M`0`3````_YP!``L````3G0$``@```!^=`0`*````(IT!`"H````MG0$``P``
M`%B=`0`%````7)T!``H```!BG0$`"@```&V=`0`%````>)T!``4```!^G0$`
M'@```(2=`0`2````HYT!``8```"VG0$`"````+V=`0`(````QIT!``0```#/
MG0$`!0```-2=`0!A````VIT!``H````\G@$`#0```$>>`0`2````59X!``4`
M``!HG@$`!0```&Z>`0`G````=)X!`#0```"<G@$`$P```-&>`0`(````Y9X!
M``P```#NG@$`"@```/N>`0`)````!I\!`!H````0GP$`+````"N?`0`J````
M6)\!`"D```"#GP$`'@```*V?`0`/````S)\!``,```#<GP$`!P```."?`0`(
M````Z)\!``@```#QGP$`$````/J?`0`,````"Z`!``8````8H`$`20```!^@
M`0`9````::`!``H```"#H`$`#0```(Z@`0`<````G*`!`$T```"YH`$`(```
M``>A`0`&````**$!`!T````OH0$`*````$VA`0`(````=J$!``8```!_H0$`
M'0```(:A`0`%````I*$!``@```"JH0$`*@```+.A`0`I````WJ$!`"X````(
MH@$`$0```#>B`0`%````2:(!`!X```!/H@$`70```&ZB`0`0````S*(!`"$`
M``#=H@$`$0```/^B`0`#````$:,!``P````5HP$`!@```"*C`0`5````*:,!
M``L````_HP$`!P```$NC`0`)````4Z,!``8```!=HP$`"0```&2C`0`,````
M;J,!``<```![HP$`"@```(.C`0`,````CJ,!`#D```";HP$`!@```-6C`0`.
M````W*,!`!````#KHP$`$````/RC`0`-````#:0!``X````;I`$`#P```"JD
M`0`-````.J0!``T```!(I`$`#0```%:D`0`(````9*0!`!X```!MI`$`$0``
M`(RD`0`*````GJ0!`!<```"II`$`"@```,&D`0`4````S*0!``<```#AI`$`
M$````.FD`0`$````^J0!``<```#_I`$`!0````>E`0`%````#:4!``D````3
MI0$`$````!VE`0`5````+J4!`"T```!$I0$`'````'*E`0`Q````CZ4!`"H`
M``#!I0$`&0```.RE`0`=````!J8!`!@````DI@$`!````#VF`0`%````0J8!
M``X```!(I@$`#@```%>F`0`2````9J8!``,```!YI@$`(P```'VF`0`+````
MH:8!``H```"MI@$`(````+BF`0`:````V:8!`!(```#TI@$`!`````>G`0`0
M````#*<!``4````=IP$`$@```".G`0`1````-J<!``P```!(IP$`"0```%6G
M`0`%````7Z<!``<```!EIP$``P```&VG`0`$````<:<!``,```!VIP$`4@``
M`'JG`0!`````S:<!`!T````.J`$`+@```"RH`0`U````6Z@!``T```"1J`$`
M-@```)^H`0`B````UJ@!`"<```#YJ`$`)P```"&I`0`L````2:D!``X```!V
MJ0$`)````(6I`0`4````JJD!`!P```"_J0$`&@```-RI`0`7````]ZD!`!P`
M```/J@$`(0```"RJ`0`;````3JH!`!<```!JJ@$`+````(*J`0`L````KZH!
M`#````#<J@$`+0````VK`0`N````.ZL!`"L```!JJP$`7@```):K`0`@````
M]:L!`!<````6K`$`"````"ZL`0`>````-ZP!``D```!6K`$`#P```&"L`0!`
M````<*P!`#$```"QK`$`'P```..L`0`.`````ZT!`%4````2K0$`3````&BM
M`0`&````M:T!`"(```"\K0$`#@```-^M`0`0````[JT!`!D```#_K0$`!@``
M`!FN`0`*````(*X!``P````KK@$`#@```#BN`0`6````1ZX!``L```!>K@$`
M$P```&JN`0`(````?JX!`"(```"'K@$`"````*JN`0`%````LZX!``P```"Y
MK@$`#0```,:N`0`-````U*X!`#X```#BK@$``@```"&O`0`&````)*\!``T`
M```KKP$`"0```#FO`0`'````0Z\!`!$```!+KP$`"@```%VO`0`E````:*\!
M``L```".KP$`(@```)JO`0`$````O:\!`"X```#"KP$`%````/&O`0`H````
M!K`!`&H````OL`$`%````)JP`0!$````K[`!`!\```#TL`$`#P```!2Q`0`*
M````)+$!``T````OL0$`#P```#VQ`0`+````3;$!`!0```!9L0$`#0```&ZQ
M`0`9````?+$!`!4```"6L0$``P```*RQ`0`1````L+$!``\```#"L0$`(P``
M`-*Q`0`1````]K$!`!0````(L@$`'0```!VR`0`0````.[(!`"<```!,L@$`
M!P```'2R`0`)````?+(!`!0```"&L@$`$@```)NR`0`2````KK(!`!H```#!
ML@$`$@```-RR`0`/````[[(!`!8```#_L@$`"@```!:S`0`)````(;,!``@`
M```KLP$`$````#2S`0`2````1;,!``8```!8LP$`$0```%^S`0`(````<;,!
M`!$```!ZLP$`!0```(RS`0`;````DK,!``\```"NLP$`+@```+ZS`0`2````
M[;,!``8`````M`$`!P````>T`0`8````#[0!``8````HM`$`$@```"^T`0`%
M````0K0!`!D```!(M`$`!0```&*T`0`'````:+0!`!<```!PM`$`)P```(BT
M`0`%````L+0!`!L```"VM`$`$@```-*T`0`%````Y;0!`!(```#KM`$`$0``
M`/ZT`0`$````$+4!``\````5M0$`"````"6U`0`'````+K4!``H````VM0$`
M"````$&U`0`%````2K4!`"````!0M0$`,P```'&U`0`\````I;4!`!P```#B
MM0$`)P```/^U`0`@````)[8!`#X```!(M@$`&@```(>V`0`@````HK8!`"\`
M``##M@$`6````/.V`0`G````3+<!``8```!TMP$`"````'NW`0`&````A+<!
M``L```"+MP$`&0```)>W`0`9````L;<!`"P```#+MP$`'P```/BW`0`;````
M&+@!`#8````TN`$`/````&NX`0`$````J+@!`!4```"MN`$`!@```,.X`0`&
M````RK@!`"0```#1N`$`&0```/:X`0`1````$+D!``T````BN0$`!P```#"Y
M`0`.````.+D!``@```!'N0$`%@```%"Y`0`,````9[D!`!H```!TN0$`&P``
M`(^Y`0`X````J[D!``D```#DN0$`!0```.ZY`0`%````]+D!``4```#ZN0$`
M&P````"Z`0`2````'+H!``0````ON@$`"0```#2Z`0`+````/KH!`!````!*
MN@$`#@```%NZ`0`=````:KH!``\```"(N@$`!0```)BZ`0`%````GKH!``P`
M``"DN@$`-0```+&Z`0!9````Y[H!`!X```!!NP$`!P```&"[`0`B````:+L!
M`!L```"+NP$`#P```*>[`0`2````M[L!``T```#*NP$`"````-B[`0`1````
MX;L!`"T```#SNP$`"0```"&\`0`.````*[P!`!`````ZO`$`%@```$N\`0`-
M````8KP!`#H```!PO`$`"0```*N\`0`?````M;P!`!4```#5O`$`&0```.N\
M`0`[````!;T!`"8```!!O0$`/@```&B]`0`_````I[T!`#L```#GO0$`#```
M`".^`0`0````,+X!``T```!!O@$`$@```$^^`0`6````8KX!``@```!YO@$`
M%````(*^`0`2````E[X!``<```"JO@$`$P```+*^`0`H````QKX!``<```#O
MO@$`!@```/>^`0`/````_KX!``X````.OP$`%0```!V_`0`$````,[\!``@`
M```XOP$`#````$&_`0`,````3K\!``T```!;OP$`$0```&F_`0`1````>[\!
M``<```"-OP$`!0```)6_`0`T````F[\!`"0```#0OP$`)````/6_`0`'````
M&L`!``\````BP`$`!@```#+``0`<````.<`!`"$```!6P`$`)````'C``0`.
M````G<`!``D```"LP`$`'@```+;``0`#````U<`!``8```#9P`$`"@```.#`
M`0`"````Z\`!``P```#NP`$`$P```/O``0`+````#\$!`!4````;P0$`&0``
M`#'!`0`6````2\$!``4```!BP0$`"@```&C!`0`3````<\$!`!8```"'P0$`
M#@```)[!`0`&````K<$!``L```"TP0$`"0```,#!`0`1````RL$!`%4```#<
MP0$`'0```#+"`0`Q````4,(!``\```""P@$`!````)+"`0`&````E\(!``L`
M``">P@$`#@```*K"`0`-````N<(!`!L```#'P@$`&````./"`0`.````_,(!
M`!\````+PP$`#@```"O#`0`@````.L,!``X```!;PP$`#````&K#`0!J````
M=\,!`"0```#BPP$`%@````?$`0`F````'L0!`"(```!%Q`$`%````&C$`0`9
M````?<0!`!D```"7Q`$`#@```+'$`0`8````P,0!``H```#9Q`$`!P```.3$
M`0`(````[,0!``D```#UQ`$`%````/_$`0`-````%,4!`#0````BQ0$`%```
M`%?%`0`=````;,4!``<```"*Q0$`#@```)+%`0`[````H<4!`$X```#=Q0$`
M+P```"S&`0!X````7,8!``H```#5Q@$`*````.#&`0`W````"<<!``@```!!
MQP$`"````$K'`0`,````4\<!`#8```!@QP$`"````)?'`0!)````H,<!`#D`
M``#JQP$`*````"3(`0`@````3<@!`"<```!NR`$`(0```);(`0`L````N,@!
M`"8```#ER`$`+0````S)`0`F````.LD!`!````!AR0$`"````'+)`0`-````
M>\D!``\```")R0$`#@```)G)`0`'````J,D!`#0```"PR0$`#````.7)`0`0
M````\LD!``8````#R@$`$@````K*`0`(````'<H!``<````FR@$`$````"[*
M`0`)````/\H!``D```!)R@$`"````%/*`0`0````7,H!`!````!MR@$`%0``
M`'[*`0`7````E,H!``T```"LR@$`(@```+K*`0`2````W<H!``@```#PR@$`
M#@```/G*`0`5````",L!``\````>RP$`#````"[+`0`F````.\L!``X```!B
MRP$`'P```''+`0`E````D<L!``D```"WRP$`!@```,'+`0`2````R,L!``H`
M``#;RP$`!````.;+`0`;````Z\L!``X````'S`$`#P```!;,`0`/````)LP!
M``8````VS`$`"0```#W,`0`*````1\P!``D```!2S`$`#@```%S,`0`4````
M:\P!``0```"`S`$`#P```(7,`0`(````E<P!``L```">S`$`#P```*K,`0`9
M````NLP!``H```#4S`$``@```-_,`0`@````XLP!``<````#S0$`!P````O-
M`0!R````$\T!``L```"&S0$`!@```)+-`0`F````F<T!`#X```#`S0$`'```
M`/_-`0`G````',X!`%$```!$S@$`(0```);.`0`R````N,X!`!\```#KS@$`
M%`````O/`0`%````(,\!``4````FSP$`#````"S/`0`+````.<\!``<```!%
MSP$`#````$W/`0`2````6L\!``X```!MSP$`"P```'S/`0`-````B,\!``L`
M``"6SP$`!P```*+/`0`'````JL\!``H```"RSP$`%````+W/`0`)````TL\!
M``<```#<SP$`"P```.3/`0`A````\,\!``8````2T`$`*````!G0`0`%````
M0M`!``4```!(T`$`#P```$[0`0`%````7M`!``H```!DT`$`"0```&_0`0`'
M````>=`!`!(```"!T`$`$@```)30`0`&````I]`!`!8```"NT`$`"P```,70
M`0`(````T=`!``4```#:T`$`!0```.#0`0`/````YM`!`!P```#VT`$`!P``
M`!/1`0`)````&]$!`"8````ET0$`'````$S1`0`-````:=$!``0```!WT0$`
M"````'S1`0`0````A=$!``D```"6T0$``@```*#1`0`'````H]$!`!\```"K
MT0$`)P```,O1`0`A````\]$!`"H````5T@$`*0```$#2`0!:````:M(!`!$`
M``#%T@$`7P```-?2`0`N````-],!`$D```!FTP$`;````+#3`0`>````'=0!
M`#`````\U`$`*````&W4`0`Q````EM0!`"L```#(U`$`'P```/34`0`Z````
M%-4!`,L!``!/U0$`'````!O7`0`/````.-<!`#\```!(UP$`?````(C7`0!#
M````!=@!`!H```!)V`$`,@```&38`0!>````E]@!`$@```#VV`$`(0```#_9
M`0`7````8=D!`!````!YV0$`'@```(K9`0`9````J=D!`!@```##V0$`)P``
M`-S9`0`@````!-H!`!X````EV@$`,0```$3:`0`9````=MH!`!````"0V@$`
M-````*':`0`C````UMH!`"$```#ZV@$`(0```!S;`0`B````/ML!`#D```!A
MVP$`5````)O;`0`O````\-L!`$<````@W`$`,````&C<`0`G````F=P!`$$`
M``#!W`$`7@````/=`0!%````8MT!`#````"HW0$`+````-G=`0`K````!MX!
M`%8````RW@$`3P```(G>`0!*````V=X!`$D````DWP$`,P```&[?`0`L````
MHM\!`"P```#/WP$`+0```/S?`0!E````*N`!`%H```"0X`$`8P```.O@`0"=
M````3^$!`!4```#MX0$`(P````/B`0`O````)^(!`"\```!7X@$`00```(?B
M`0`@````R>(!`%0```#JX@$`(0```#_C`0`+````8>,!`+4```!MXP$`2```
M`"/D`0`?````;.0!`#8```",Y`$`(@```,/D`0`>````YN0!`"P````%Y0$`
M!P```#+E`0`'````.N4!``,```!"Y0$`#0```$;E`0`+````5.4!``H```!@
MY0$`"P```&OE`0`'````=^4!`!D```!_Y0$``P```)GE`0!;````G>4!``0`
M``#YY0$`)P```/[E`0`$````)N8!``<````KY@$`!@```#/F`0`%````.N8!
M``0```!`Y@$`$P```$7F`0`(````6>8!`!$```!BY@$`%0```'3F`0`"````
MBN8!``<```"-Y@$`!P```)7F`0`,````G>8!``X```"JY@$`!@```+GF`0`4
M````P.8!``P```#5Y@$``P```.+F`0`G````YN8!``0````.YP$`!@```!/G
M`0`(````&N<!`#`````CYP$`1P```%3G`0`N````G.<!`"\```#+YP$`&P``
M`/OG`0`O````%^@!`#(```!'Z`$`)````'KH`0`A````G^@!`",```#!Z`$`
M*````.7H`0`C````#ND!`"$````RZ0$`*@```%3I`0`I````?^D!`"(```"I
MZ0$`,P```,SI`0`?`````.H!`#`````@Z@$`+0```%'J`0`B````?^H!`"8`
M``"BZ@$`)0```,GJ`0`@````[^H!`"D````0ZP$`*0```#KK`0`E````9.L!
M`"\```"*ZP$`'````+KK`0`A````U^L!`"4```#YZP$`*0```!_L`0`@````
M2>P!`"H```!J[`$`/@```)7L`0!!````U.P!`!T````6[0$`)````#3M`0!`
M````6>T!`"4```":[0$`*0```,#M`0`H````ZNT!`"D````3[@$`(P```#WN
M`0`@````8>X!`"H```""[@$`)0```*WN`0`Y````T^X!`"<````-[P$`-0``
M`#7O`0`,````:^\!``P```!X[P$`%````(7O`0`O````FN\!`",```#*[P$`
M"P```.[O`0`7````^N\!``X````2\`$`%@```"'P`0`(````./`!``<```!!
M\`$`(@```$GP`0`E````;/`!`!X```"2\`$`)P```+'P`0`E````V?`!``P`
M``#_\`$`ZP````SQ`0`/````^/$!`!@````(\@$`#````"'R`0`/````+O(!
M`!@````^\@$`'P```%?R`0`?````=_(!``8```"7\@$`-0```)[R`0`6````
MU/(!`!0```#K\@$`!P````#S`0`3````"/,!``H````<\P$`/````"?S`0`*
M````9/,!`"@```!O\P$`$P```)CS`0`8````K/,!`!<```#%\P$`.````-WS
M`0`@````%O0!`!(````W]`$`)````$KT`0`3````;_0!`!0```"#]`$`%0``
M`)CT`0`*````KO0!`!<```"Y]`$`"0```-'T`0`=````V_0!``@```#Y]`$`
M'`````+U`0`F````'_4!``<```!&]0$`(P```$[U`0`'````<O4!``@```!Z
M]0$`"0```(/U`0`T````C?4!``8```#"]0$`$````,GU`0`5````VO4!`!0`
M``#P]0$`"P````7V`0`,````$?8!``<````>]@$`"P```";V`0`<````,O8!
M``\```!/]@$`&````%_V`0`9````>/8!``L```"2]@$`#0```)[V`0`7````
MK/8!``D```#$]@$`*P```,[V`0`,````^O8!``\````']P$`"0```!?W`0`"
M````(?<!`!$````D]P$`&````#;W`0`+````3_<!``,```!;]P$`"P```%_W
M`0`(````:_<!``<```!T]P$`"P```'SW`0`+````B/<!``X```"4]P$`+0``
M`*/W`0`:````T?<!`!H```#L]P$`(0````?X`0`*````*?@!`#H````T^`$`
M!0```&_X`0`6````=?@!`#<```",^`$`#0```,3X`0`.````TO@!``8```#A
M^`$`!````.CX`0`&````[?@!``L```#T^`$`%P````#Y`0`'````&/D!``@`
M```@^0$`!P```"GY`0`(````,?D!``4````Z^0$`#P```$#Y`0`0````4/D!
M`#X```!A^0$`,0```*#Y`0`D````TOD!``4```#W^0$`&@```/WY`0`A````
M&/H!`"$````Z^@$`(P```%SZ`0`1````@/H!``(```"2^@$`!````)7Z`0`*
M````FOH!``4```"E^@$`!0```*OZ`0`#````L?H!``D```"U^@$`3````+_Z
M`0`E````#/L!`!@````R^P$`+0```$O[`0`E````>?L!`%\```"?^P$`$P``
M`/_[`0!Y````$_P!`!P```"-_`$`4P```*K\`0`B````_OP!`#\````A_0$`
M-````&']`0`L````EOT!`#8```##_0$`-@```/K]`0`U````,?X!`#,```!G
M_@$`*````)O^`0`B````Q/X!`"8```#G_@$`3`````[_`0`4````6_\!`#0`
M``!P_P$`#P```*7_`0!O````M?\!``D````E``(`H@```"\``@![````T@`"
M`'````!.`0(`*````+\!`@!4````Z`$"`!H````]`@(`*0```%@"`@`7````
M@@("``H```":`@(`'0```*4"`@`=````PP("`#0```#A`@(`(P```!8#`@`8
M````.@,"`%0```!3`P(`'@```*@#`@`7````QP,"``H```#?`P(`!````.H#
M`@`&````[P,"``@```#V`P(`!0```/\#`@`5````!00"`!,````;!`(`&0``
M`"\$`@`E````200"`!````!O!`(`#@```(`$`@`$````CP0"``D```"4!`(`
M#P```)X$`@`(````K@0"``D```"W!`(`%@```,$$`@`-````V`0"``P```#F
M!`(`$0```/,$`@`+````!04"``8````1!0(`$P```!@%`@`+````+`4"`!8`
M```X!0(`#0```$\%`@`'````704"``\```!E!0(`"````'4%`@`)````?@4"
M`"4```"(!0(`&P```*X%`@`,````R@4"`"0```#7!0(`$@```/P%`@`>````
M#P8"`!0````N!@(`$0```$,&`@`%````508"``4```!;!@(`(0```&$&`@`(
M````@P8"``(```",!@(``@```(\&`@`6````D@8"``@```"I!@(`"````+(&
M`@`4````NP8"`!8```#0!@(`"````.<&`@`M````\`8"``(````>!P(`!```
M`"$'`@`0````)@<"`!<````W!P(`#P```$\'`@`'````7P<"`!(```!G!P(`
M!0```'H'`@`;````@`<"``4```"<!P(`%@```*('`@`1````N0<"`!(```#+
M!P(``@```-X'`@`(````X0<"``\```#J!P(`"P```/H'`@`-````!@@"`"0`
M```4"`(`"P```#D(`@`,````10@"`!,```!2"`(`!0```&8(`@`"````;`@"
M``L```!O"`(``0```'\$``";`@```````$8#``!I`@``+P0``!\&````````
M4P$``%,`````!````P$```````!\`0``V`0``'T$``!!!P``204``#8#```E
M`P``#@,``'<#```S!```IP$`````````````+0```````````````````,\$
M````````NP```,T!```%!0``U0,```T"``````````````````#=!@``>0$`
M`*T&``"Z`0```````.H!``"D!```4@(``"P!``"^!0``7P4````````U!0``
MT04``'T!``!<!```(P<```````#U`0``:04``!8#``"V`P```````!D%``#G
M`0``+@8``&H"``"-!0```````&$"``"Y!0``@```````````````OP(``#L"
M``"K!0``=`(``#4#```=!0``G`$``+\%``#9`0``/@4``+$"``"1!0``````
M`.<%```L`````````&,#```5````FP$``'H#``#3`0``30$``$P&``#C````
M[0,``&8!``#'`@``R`(``#H'```9`P````````````!'!0``108``(8!```+
M!```C00````````+````%P$``!X"````````=@8```````#T!@```````,P"
M```W!P```````#,`````````M`(``/,%````````-@4``)@%``!J`0``S@$`
M```````3!P``7````+$#``![!@```````'T```"-!@```````%D!``!-`@``
M^P$```8```#2``````````````#8````$08```````#O````````````````
M````0P(``*(&````````XP,``&H$```G!0``$`4``*P%``!$`````````$D`
M``!B`@``VP4``#L'````````6`4``*D%```4`@``@0$`````````````'@8`
M`+T`````````80<``)P&````````'0(``$@%``#0!@``-@```"8%`````0``
MN`$``+$!````````Y`8``%,'````````9```````````````]`,``%4#``#J
M!0````````4!``#"`@``0P8```````!Z!@``Z`4```````!.`@``.P0``-("
M```1`````````#T!``![!```8@,``(X&````````````````````````8`4`
M`/@&```8!```JP$``(8%````````J0```+<"```````````````````8`P``
MEP8``-\#``#Z!````````.0```#Q!```KP0``%P%``#Y`@``!P$```$'``!0
M!0```````$<#````````Y`4``+0$``"!````!@0``*4&```?!0``````````
M``#9!```90$``%`$``#U`P``$0(```<$``#H`@```````'P$``#.!0``G04`
M``````#P`0``:@4```@!``!H!0``KP,````````?`P``1P$``&,&``"4`P``
M``````````!\`P``O00``%8$``#;````\@0```````"U!@``"P<``-$$``!I
M!```H`$``)H%``"R`P``2@,``/(%``!>!@``<0```!P$````````2`8``,\!
M``#@`0```````"@"``!F`@``Q`$```````#I````V`(``)H#````````'@4`
M```````0`0``*P$``.L```#7!0```````%$#``#5!@``,0$``!P'``!L`0``
M10,``#8"``"4`````````#$```";!@``M00``&P&``"T`P```````)0%``#U
M!0``2`0`````````````+`<``/4&```Y!P``30```"D'```M!0``)P$`````
M``!:`P```````-<&```F`P```````-<$``!"`````````/P"``"Y!```<P8`
M`&8%``![`P``#P0``!(&```4`P```````&T#````````H08`````````````
MU0(``($%``!-!@``&P,```\"````````?@0```@"``!M`0```````/X%```Z
M`P```````````````````````.(```"/`0``&0$``)X`````````\`0`````
M````````200``!$!``"X````"00``(@%```````````````````^````+08`
M`$($``#"!```````````````````1P0```````#<`P``A@,```````#D`@``
M`````+@"```D`P``=@$``(L!```"`@``>`0``#\%```/`P```````)8"``#_
M!@``,P8``&@"```@`P``%`````````"O`@``O`0``)4```!$!0``/08``-8`
M```5`0``U@0``.$&`````````````$$#``#S`P``W`(```````#2!0``U`4`
M```````&`0``DP``````````````\04```0````%`P``,````#0&```I!@``
M-08``&D#```\`P``MP8``,T$``">!0``X04``!0$````````=P$``,L&```8
M!P```````&4"````````G`4````````(!P``E`0`````````````C@$``.P%
M```I````>P4``&,```":`@``S0,``%$```"D`P```````+\$``!O!@``GP4`
M`"`"````````W@0``((#```'`@``RP4``*`&``#-````5@8``!X#``"2`@``
M/00```````!Z!0``*@4``+,```!U````3@,``$`#``!N!0````````H```#L
M`P``````````````````(@<```````"9`0````````````"D!@``5P4``$4'
M````````\@```*L#```2`0```````",$``!S`@```````.`&``"N`@``20$`
M`&D&```M!P``?````(0"``#1`0``8`,`````````````10```/0"````````
M[@$``'$#```J````M`$```````#\`0``Z0(``*,$``"_`0```````*H````\
M!P``S08````````R`@``#`<``+8$``!J````9P(``#D%````````"`,`````
M``!"`0``A`8````````:`0``+P4``+(&```5`@``]0(```````#'````808`
M`+8&``#&````B`0``!X$````````A0$``/$&``#@````,P<``(<&``#C`@``
M``````````"H`@``_0(``%\"```K!0```````#4$```\!```60(``+($``"9
M!```*@(``.8&``!(`P````````````#(!0````````````"Z!0``6`8``*<#
M``````````````T%````````F`$``.P`````!@``&@4```````!_!0``_`,`
M`)8#```[!@```````/D%````````]`````````"`!0``"@<``&T$``""!@``
M`````.8$`````````````#<&``"#!0```````.X"``"Y`0``E00``/@#``"W
M!0``;@$``/X`````````D08``)<%````````9`8``"$&````````#0```"`$
M``"`!@```````"$'````````J`,``!T#``"?`````````$X$````````C```
M`"$$``#/!0``IP8``-8&``",`@``````````````````+`4``,T%``!&!```
M&P$`````````````4@$``*T!``"N`0``^P8``/8!``"N!@``2@```!(%``!%
M!````````&P#```V!```?@4``#H!```^`@``9P$``"@&``!:`@````````\`
M``#*!0``/````````````````````,L!``#.`````````/H%``"3!@``(`<`
M`.<#````````,@$`````````````H0,``.@#```%`@``!`,``*`%````````
M%08``+,$````````]P0``+8!````````0@,``)L#``!D`P``Q0(``*P!````
M`````````!L"```Q!P``'`4``#<%``!/````Y`$``*$````8!0``)`0`````
M``"3`@```````+$&``!4````S`0````````3`@``D0$``%$%``!$!```<@4`
M`$L%```2!```L@4``%P&``!;!@``7P0```$&```\!@``L`$``(0$``"=````
M8@```/("``#Q`P``;0````````#(`P``%@$``!H"``#_!```5@<````````L
M`P```````+@&``#/`P``CP(``$\&``#'`0``````````````````EP$`````
M``"9`P``=`8```````"8`@``>0```,$#```G`@``,@4``!`&``!D`@``_04`
M`,L$````````+`0``,,!```8`@``>04``)<#``!K````#`0```````!9````
M/04``-D`````````6P$```T!``!Q!``````````````(!@```````&@```"*
M````5`(```````"^`@``HP8``!,```";!0``9`$``-<!```D`@``JP8``)L$
M```$!@``````````````````8@<``,(%````````,`(``#@%```C!@``@P$`
M``$#``!*`0``J`4``,4````<````-0```.\&```C`@```````*4"```)`P``
MDP$```````"'````&P0`````````````CP,````````O````1@8`````````
M````6@<``*D$`````````````"$"``!-!P``N`,``"L$``#:`````````!X!
M``"=`P``&@0``#P!```.!@``6@0````````````````````````E!0``F04`
M``````#4!````````%D#```@!0```````#@#````````6P<```````#4````
MOP```*@````S!0```````)\!```'!@``A@8``$$`````````&`$``#\"````
M````>`8``!<$```_!P``N@0``+@%```=`````````"H$``!7!````````-``
M```$`0``C0```*0```"-`@``@@0`````````````KP8``#D&``"^`0``!0``
M`&X#``"R````*P(``!8$``"1!```4`(``.,$``#G`@``V@(``#H````"!```
M*0,``%,#````````Y`,``-X"``#Z`0``_@(```````#)!```%@(```````#Z
M`@``MP$``-$```!V!0```````#8&``#8`P``TP0``+D````4!@``Z00``($$
M`````````````+D&````````Y@```'T&````````;````(`!```B!0``S`$`
M`,P&````````&P8``$X%````````LP8``%P'````````2P```*D&```I!0``
M;@```#,"````````!`4``'$&````````2@4``%D&```9````A`$``-4%```[
M`P```0(````````>````<@(``&@#``#`!```<@0``.4%``"A`0```````$P$
M``#E````C`$```H!````````+0(``#\$``#)!0``X00``!("```1`P``````
M`#$#````````M``````````&!@````````X!```C`````````%T!``#=`P``
M`````````````````````*H#``#S````G@0``)@```!9!0```````$$"````
M````G@,```````!O`@``5@$``*$"````````+@0``,<$````````O@0`````
M``!_!@``^`0```````#N!````````+8```"L`@```P4``#0'```6!P``Q`0`
M`",#```T`P``%P```$X&```I`@``UP(``/L#``#7`P``-0(``.4$``"H!@``
M`````!P&``#N`````````,H``````````````%4$```F`@``%P(``-T`````
M`````````-\``````````````*\!``!2````"@(```````#V!0```````$8`
M``"-`0``?@8``#H%`````````````-L!```A`P```````-8#````````3@<`
M`*8"```M!```R`0``.(!```P`P``5`4``,,#```R!P``)`8```````!H!```
M`````.\!``!;`@``,04``!8`````````<`8``%T%```,!@``N@(``$\#``#+
M`P``3`,``'8```"O````&P```.H&``!E!@``Z`$``!4$``"I`@```````)(!
M``!2!0``W@,``#0!``"E!0``<@,``#0$``#<`````````+L%````````````
M``````"#!```J@4```0'``#T`0``-P```)\#``#S`0````````````",!0``
M`````/P```"5`0```````&8#```'!P```````&\#``"&!```GP0``'P"``"E
M`P```````"L#```J!P``>0,``)$#``"N!```40$``$`"````````W`$``/,"
M``"G````1@4``*`$````````^`$``.T&``!$`@``'@<``,H$``!O`0``YP0`
M`.,!``#]`````````!`"``".`P``$P8``%@!```B`@```````(4%``!G!```
MX0(``(<%``!7`P``)@0``%P!````````'0<``)H$``"<`P``@@$``%`!```N
M!0```````,@!``!`!0``"@,````````K````;@(``*,#``!Z`@``F08`````
M``!=`@``R0```#@```"&````$`<``#`!``!^`P``\@8``&X$``##`@``````
M``````"*!@``!P```.D&````````S`,```````"Y`@``$@<``&L"``#2!@``
MH@$````````I!```'P```(4"``".````,P,``"X'``!)`P```````#(&```#
M````P`8```````#8`0``400``,0&````````A`4``#\&``#0!0``]0``````
M`````````````(D$``!J!@``4@8``&D!````````8`<```````"C!0``-0<`
M``````#P`````````.<&``#O`P``EP```(<"````````70`````````.!0``
M%`$`````````````IP(```````!'`````````,D"``!`!@```````"L'````
M````]@,``$(%``!+!@``1P(``-T%``!-!```T0(``(X$````````]P4`````
M``!8`P``?04``#$$````````8`0``-(!``"N`P``*`<``(H#````````````
M`&P$````````^P```-<````)!P``]P8``&$!``!5!P``*`4```````"7`@``
M90````````#E`@``10(````````:`P``[`(``&4#``#)`0``W0$``+P%``"0
M!````````'@%``!(`@````````````#A````G00``$$!``"D!0``````````
M``!+`@``^08``',!```I`0``K`8``$\!```_`P``BP(``%@'````````Q00`
M``````#T!0```````$L#````````8`$`````````````]P,```````"2!0``
M=`0``.L&```P!P``B0```&L#``#I!0```````-0!``![````:`8```````"%
M!@``VP8```````"#`@``4@,```(`````````[00```````#.!```K@```"\&
M````````'08``*<$``##````80````````!0!@``F@$``%`#```E````L`8`
M`(<#```^!P``208``)`"```X!P````````T'```:````<`(``*0"``"+!```
MM04``&8```#?`0``5@,``.\$``"4`@``(`8``#`$``!O````C`,``"($``"B
M!0``'`,``$(&``#C!0``#@````````!V`@`````````````(!0``7@``````
M``!.`0``B`8``$P`````````)P``````````````<@$````%``!Q`0``\`(`
M`+\#``"$`P````````````#"!@``D`,````````(````)P<``%@"``!>`0``
M<`$``',$``!(`0```````-$&```X!```4`<``&L%````````5`<`````````
M````?@```/$!``#:`P``5@```%X'```E!@````````D"``#?!0```00``&4$
M``!)!P``#`,``+X&``#E!@``!`0``%$'``!K!```D`$```X"````````]@(`
M``````!?!@```````'T"``#O`@```````$H$``#G````A00``/D```!/!P``
MWP0``)T&````````;@8``.H#``#Z!@``V`4`````````````O04`````````
M`````````%T#``!>!`````````````#%!@``I@,````````%!@``````````
M``"F!@```````"X!``#$`P``]P$```````#&`0``NP,```,'````````2@<`
M`(<$````````\`,``````````````````*\%````````7@4``'`$``#)`P``
M<P```,`#```0````W@```%($``!3`@```````,\"``#*`P``[@8```4'````
M`````````%0#```]`@``_@8``"@$``"6!@``(@`````````&!P``50```#<$
M``#=!```VP(``*T"````````$@,``.T"```9!P``;0(``,X&```X!@``O`,`
M`%\#````````60<``"P"````````S`4``,H"``#C!@``*````!<'````````
M_P```'L"```)!0```````#8!``"C`@``M@(``$4!``"9````JP(``!P"````
M`````P(`````````````L`4``'0```"+````````````````````G`0``%<&
M``#5`0``I@```$`!``#F!0``-@<```````#=`@``````````````````6@``
M`%0&````````)P0``*T%``",!````````'\"``"F!```LP4``#$&```P!@``
MB@(``%8"``"*!0``<P,``%````#0`P```P,``(`$``````````````````#^
M`P``#````)4"``!,!P``D`4``+0%````````C0,```````!W````[0$``$<&
M``"8`P``5@4```````````````````````".`@``Q04``,4#``!+!P``W`8`
M`!$%``!H`0``HP```"8&``#>!0``3P(`````````````R@8````"``!U`0``
M`````$0'``#Y`0``[0```,D&```C`0```````.D#``"%````50$``&0$``"P
M`@``#P8``!8%``"\`0```````#0"```"!0``A`````````#!`0``A0,``.@$
M``"7!````````)0&``"5!@``904``/8$``!L!0``LP$``!<%```Y!```````
M`/`&``!)`@```````+`$``````````````L!``!Z`0``V@0``$,%```+!@``
ME@$``-\&````````%`4``$,'```M`P``#P4```````!G````T`(`````````
M````<`4```L"``"<`@```````-,```!K!@``8`8`````````````````````
M````````@P8`````````````S@,``'0#```*!0``H`,```````#3!0``(@,`
M`)P`````````GP(``#P%``"Z`P``X@0``!D"``!X`P```````/T!````````
M8@4``*@!``#```````````````!?````K`0``&,'```A``````````(!```,
M`@``NP0``!8&``#F`@``!@(``,`%``#&`P``<````#,!``#?`@``304`````
M````````E`$```````!<`P``D@0``&L!`````````````/`%````````````
M```````X`@``=0(```````!@`@``:@,``$('`````````````+H````)````
M(04```````!\!0``G0$``.X#````````^````#X!``!(````]00``*,!``!:
M`0``MP,``!T$`````````````"8!``#0!```@@(```P!``!9!```>P$``#X&
M``#Q````V@$``%\!``#V````NP(``-L#`````````````.$!```Y`@``.@(`
M``T$````````_`0````````R`P``2P$``.@&```R!````````!L'``"K!```
M<`,``$$$``"(`0``504``"8'````````>0(``'4#``"W````R````)H&``"!
M!@``^00``#0%``!C`0``Q`4``*D!``!`!````````.H"``!A!0``;08``*H&
M````````9@8```````#>!@``9@0```````"6!0``!@,``#X$```D````````
M`(\$``"/!0``+P,``/0$``!/!````````*T`````````=08````````3!```
M`````!\"```````````````````3`0``1@<``.$#``!W`@``!00```````#&
M`@``H@0``%H%```T`````````+H&```;!0``GP8``$$%```5`P``2P0``+4`
M``#/`````````(8"``""````PP8```D&````````^0,``'H````^`P``P0``
M`````````````````&\$``#&!0```````!@&``!Y!@``Q````(,```"]`P``
M!P,``*0!``"Q!```MP0``"4"``!;````T`$``',%``#F`P``?P``````````
M````U`(``(`"``#K`P``3`4``,,$``#K!0``E04```````!"`@``>`$`````
M````````(0$````````@````8@8```$!```2`````````*`"```D`0``Q@8`
M`*T$``#N!0``104``+P``````````````.H```"Q`````@8``*T#``"6!```
MQP4``'\#`````````````+L!``!7!P``J`0````````0!```'P0``!4%````
M````VP0``/\%````````<04``#<#``"A!0```````.("```J`P``>@0``/H#
M```N`````````.H$``!5!@```````"`!``!C!0``CP8```````#&!```6P4`
M``````!D!0``700``!,#```B`0``T@,``.@`````````Y@$``%L$```D!P``
M9P4``(`#``"6````&08``(L%````````L04``-0&``#^!```=@0``,<&````
M````G0(``)H```".!0``2@8``+4!`````````````*4!```B!@``008``-8"
M``!&`0``9P,``%$&``#\!@``0P```.(#`````````````*(#``"V!0``D@8`
M`$X`````````=P4``%0!``"*`0``J@$```````!C!```.@0``"\'````````
M,0(``/\#``!#`P``_P(``%,%``"*!```40(``!\'``"T!@``[`$``#L!``")
M!0``O08``*P#``#E`P``=@,``%T'``!7````\@$```````#3`@``#0,``"0%
M```[!0``Y0$``"P&``!@````ZP$``#<"````````O`(``'\!``#:!@``X@8`
M`-P%`````````````````````````````*``````````3`(````````Z!@``
M_00``*8%```5!P``=`4``/,$``"+`P```````(@"``!5`@``D@,``/\!``#+
M`@```````%X#``#5!```"`0``)`````4!P``BP8````````7`P``6`0``'T#
M``!X`@``#@0```````#L!`````````````"B`@``+P(````'```K!@``$`,`
M`/(#``!\!@``0````*H$``!G!@``J0,````````]````$0<``-,#````````
M"@0``.L$``#9!0```````!D$``"3!```DP4``+("``#:!0``%P8``/<"````
M````NP8````````"!P``1`,```<%``"\!@``L``````````/`0``;P4`````
M``#*`0````````````#X!0``0P$``"H&````````8P(``,`!``#5````U@4`
M``````#"`0````````````!T`0``X`0`````````````X`(```````!B!```
M/0<```T&``#D!```;`(`````````````+0$```L#``#]!@``(P4``(D!```:
M!P``>00```````!#!`````````````#-`@``708``+,#```_````^P(`````
M`````````````-X!``!$!@``Q0$```````#8!@``,`4``%@```!3!@``L`,`
M``````"8!@```````%\'``"1`@``2@(``-D"``!A`P``800``*H"``">!@``
M```````````*!@``\0(``.`%``"2````5`0```L%````````*`$``+4#``"^
M`P``O0$``)@$`````````````,$%```Y`0``I0```.`#`````P``B08``,$$
M```N`@``"0$``(@#``#/!@``@0,```````!I````O0(``,$&``!'!P``^`(`
M``$%```G!@``*@$````````=`0``B````-D&``"R`0``````````````````
M=00`````````````4@<``,(```#$`@````````````",!@``^P4```````"U
M`@``+P$```````">`0``TP8``)X"````````_`4``((%````````#`4``'<$
M````````0`<`````````````T0,```````"_!@``D0```"4'``!/!0``ZP(`
M`*(````.!P``W`0``*<%``"0!@``````````````````````````````````
M-0$````````N`P``)00```\'``"X!```/0,``.P&``#]`P``!`(``+X```#2
M!````````/8&`````````````.T%````````S@(``#L```"L````,@```(,#
M````````P0(``'4%``"N!0``/P$````````F````>`````````"S`@``U`,`
M`%H&``!Q`@```````'(```!M!0``3`$```````#O!0``?@$``!$$````````
M7`(```````"!`@``P`(``!P!``"E!```2`<``/X!``#(!@``AP$``)D"````
M````CP``````````````V0,``#<!``!^`@``.`$``-8!````````5P$`````
M``"K````E0,``,<#``!R!@``!@4````````\`@``1@(``/<```!$`0``&```
M`%<"````````8@$``,L```#I`0``I@$``"@#``#[!```30,``/H```#B!0``
M`````(D"```3!0```````,(#`````````````)L``````````````#D````:
M!@```P8``%,$````````DP,```````!>`@````````````"A!````@,``#D#
M```?`0````````,$``!W!@``)P,``"4!````````\P8```````#,````PP4`
M`(D#``"Y`P``6P,````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E
M<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@
M9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I
M;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN
M9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D
M9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE
M;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S
M<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE
M;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL
M(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L
M=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L
M=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N
M(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L
M:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O
M=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F-H:79E($9I;&4@4VEZ90!!
M<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T
M:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W
M:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT
M:6YA`$%R;65N:6$`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@
M07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@
M8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T
M<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S
M`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L
M9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R
M;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;F=L861E<V@`0F%R8F%D
M;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A
M<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!"
M:'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B
M(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O
M;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T
M;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D
M($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@
M=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M
M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F
M:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG
M="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R
M9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N
M9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#
M96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5N=&5R
M`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#97)T:69I8V%T92!$971A:6QS
M`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`
M0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A
M;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD
M(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y;W5R('!A<W-W;W)D
M(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N="!C;VYF:6=U<F%T
M:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-H87(`0VAE8U]K
M($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O
M<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S
M`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L
M96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E
M`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U
M9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA
M<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`
M0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I
M=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M
M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`
M0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R
M871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@
M3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG
M=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#
M;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z
M("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@
M<VEG;B!M97-S86=E.B``0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@
M861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R
M+@!#;W5L9"!N;W0@8FEN9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V
M97(`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10
M.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T
M(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O
M=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO
M="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T
M(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T
M(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T
M<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK
M9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H
M92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N
M`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC
M95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S
M(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H
M92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@
M87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N
M;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O
M;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`
M0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L
M9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B
M)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E
M(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T
M=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V
M92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U
M<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O
M;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#
M;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N
M;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W
M<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD
M('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I
M<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG
M(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`
M0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A
M(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO
M;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@
M4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@
M55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@
M8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@
M<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U
M<P!#>F5C:"!297!U8FQI8P!$1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP
M:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A
M=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#
M;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N
M=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A
M=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE
M=&4@1W)O=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E
M;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C
M<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE
M(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S
M(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT
M(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D
M971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L
M87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI
M8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`
M1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`
M12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P
M`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES
M<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N
M`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@
M061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET
M:"!C;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS
M`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E
M<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L
M;&5R:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE
M;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@
M<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M
M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT
M97(@=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R
M96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T
M:6YG('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@
M)7,`17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P
M87-S=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W
M<FET:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%
M=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O
M;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO
M=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N
M9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W
M;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP
M;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T
M<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A
M:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S
M(BX`1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL
M960@=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A
M:7(`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`
M1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E
M96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD
M(&UA=')I>`!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O
M=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L
M96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D
M+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I
M>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U
M<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO
M=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A
M>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT
M(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS
M`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R
M=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O
M;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3
M;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R
M:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T
M86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O
M;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H
M86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@36%P
M<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96YL86YD`$=R
M96YA9&$`1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B
M92!N;VXM96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E
M<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE
M('1O('5P9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U
M871E;6%L80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`
M1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(
M96%D97(`2&5A9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',`2&5A=GD@5"U3=&]R;0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O
M<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@
M=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3
M=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0
M:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(
M;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D
M("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@
M<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L
M86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T
M:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S
M>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H
M87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(
M;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O
M<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E
M/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA
M;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M
M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E
M<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!
M9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N
M;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO
M;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY
M`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE
M.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E
M;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC
M;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@
M8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y
M;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!5
M4DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM
M86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN
M8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE
M(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R
M;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!)
M;F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!)
M;F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!)
M;G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE
M`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T
M97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!)
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T
M(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M
M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D
M:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$
M871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A
M=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E
M9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@
M9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@
M<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN
M9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A
M;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN
M=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED
M(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED
M('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT
M;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`
M27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA
M<&%N`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#
M96YT97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$MA>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R
M=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+
M97D@0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y
M<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!0
M96]P;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2W5W86ET
M`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M
M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N
M9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`
M3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V
M:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N
M;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L
M`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN
M`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI
M9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I
M=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R
M:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E
M<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`
M3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,
M:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI
M<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M
M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@
M<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`
M3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO
M8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO
M9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@
M>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E
M8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@
M9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N
M(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE
M($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC
M`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I
M80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E
M9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO
M<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA
M<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`
M36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F
M;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N
M9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R
M:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E
M>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA
M<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`
M36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-
M96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G
M92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN
M960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R
M:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED
M9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E
M;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO
M="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%
M05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI
M<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S
M<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T
M90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N
M86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A
M=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H
M86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T
M;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO
M=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E
M`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I
M;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A
M;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E
M`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L
M86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2
M979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E
M(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E
M(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT
M`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@
M0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G92!T;R`E<P!.97<@
M36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@
M<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE
M=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS
M`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@
M25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@
M<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P
M<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE
M<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P
M<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO
M('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`
M3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E
M<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F9O;&L@27-L86YD`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO
M<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T
M(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO
M=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M
M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F
M(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D
M:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C
M=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W
M('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L
M9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R
M=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F
M;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@
M=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@
M;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P
M96X@:6X@82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E
M>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H
M:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I
M;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`
M3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI
M8V%T:6]N('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H
M97(`3W1H97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U
M=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C
M:V5N9`!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A
M`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0
M($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!3
M;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@
M97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES
M=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N
M86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!0
M87-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O
M<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T
M:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W
M;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!0
M87-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O
M<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@
M1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0
M:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L96%S92!C;&EC:R!I;G1O
M('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E
M;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A
M;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N
M=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE
M=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM
M92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I
M=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES=&5M+@!0;&5A<V4@='EP92!T
M:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL<P!0
M;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U<BAS
M*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N8V4`4')E9G-?;&1A<#H@4F5Q
M=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N
M.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R97-S
M=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@`%!R97-S=7)E.B``4')E=FEE
M=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')E=FEO=7,@
M;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV871E($ME>0!0<F]B;&5M`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`4')O;7!T('1E>'0`4'5B;&EC
M($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0=6)L:6,@2V5Y($EN9F\`4'5B
M;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL
M>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`475O=&$`4E-!(%!U8FQI8R!+
M97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A:6X`4F%I;B!%87)L>0!2
M86EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A;F0@4VYO=P!286EN('1O(%-N
M;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A9`!296%D(&UE<W-A9V5S`%)E
M86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O
M;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A(&9O<B!U<V5R("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!2961O97,@>6]U<B!L87-T
M(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN86UI8R!-96YU($5L96UE;G1S
M.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O
M=W-E<@!296QO860`4F5M87)K<P!296UO=&4@4V5R=F5R<P!296UO=&4@55),
M("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H`4F5M;W9E`%)E;6]V
M92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`
M4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!61E,@8V]N9FEG
M=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(&-O;F9I
M9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E<V5T`%)E<V5T(%!A<W-W;W)D
M`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R92!,87-T(%%U97)Y`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2975N
M:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`
M4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M86YI80!2;W1A=&4@,3@P`%)O
M=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@4')O<&5R=&EE<P!2;W<@<')O
M<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N
M(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S('=I;&P@87!P96%R(&)E='=E
M96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@<F]W
M<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%,O34E-12!#
M<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A
M9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@
M365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A=&5M96YT(&9O<B!V86QU92!L
M;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I;G0@2&5L96YA
M`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I
M;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4
M;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`4V%U9&D@07)A
M8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-A=F4@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@82!02%`@<V-R:7!T('1O('EO
M=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4V%V960@)7,@8V]N
M9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E
M<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE;F-E`%-E87)C:`!396%R8V@@
M16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE8W0@82!G
M<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A('-E<G9E
M<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C="!A;&P@
M9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!N;VYE
M`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE
M<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O
M;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!3
M96QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO
M=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`
M4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F
M:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@
M4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N
M=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E<B!D871A('=R;VYG(&]R(&YO
M="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`4V5S<VEO;B!)1"!E>'!I<F5D
M+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E
M<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@
M=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O
M;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T
M:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P
M<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD
M(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S
M8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W
M:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T
M(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO
M<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E
M;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H
M;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T
M86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N
M('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA
M;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE
M(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P
M<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@
M16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H
M<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T
M(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;F%T
M=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`4VMI<"!-
M86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@4VAO=V5R
M`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3:&]W97)S
M($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@
M`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O
M<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O
M=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O
M=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL
M<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P
M86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3
M<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M
M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R
M96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G
M92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@
M;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-3
M70!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B
M;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@
M8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY
M(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R
M960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S
M(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF
M:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL
M>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A
M=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S
M9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A
M;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR
M:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R
M:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N
M($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@
M9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3
M>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y
M`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE
M(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0
M<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E
M;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``
M5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP
M;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`
M5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86EL86YD
M`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D
M92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B
M)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H
M92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L
M;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H
M92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N
M="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M
M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@
M;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N
M;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T
M86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I
M9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@
M240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO
M="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES
M="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@
M<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@
M8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@
M9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@
M;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@
M:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L
M;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L
M92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G
M92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A
M;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD
M;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E
M;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN
M7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y
M;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`
M5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M
M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA
M<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H
M92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@
M:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T
M('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE
M(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E
M`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P
M96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@
M8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU
M;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI
M<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN
M`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A
M8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT
M+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN
M9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF
M:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E
M<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N
M;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@
M8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A
M9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H
M92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H
M97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O
M<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M
M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R
M;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M
M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E
M<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO
M860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W
M:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T
M:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O
M;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I
M<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U
M(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O
M<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T
M:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R
M;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A
M9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D
M:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI
M<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R
M<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C
M:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@
M9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N
M=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S
M('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T
M<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4
M:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H
M('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y
M+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@
M271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R
M97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@
M*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I
M96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES
M(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES
M="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB
M97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T
M:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI
M<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S
M+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T
M:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T
M('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@
M82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O
M;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N
M('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@
M8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L
M874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L
M871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4
M=6YI<VEA`%1U<FME>0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)
M<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@
M`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O
M<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO
M;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO
M;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S
M:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E
M<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN
M96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,
M+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R
M96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@
M5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T
M;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N
M86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@
M5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ
M("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N
M`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO
M860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93
M(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA
M8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R
M;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S
M=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T
M;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O
M('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P
M>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D
M960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A
M8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN
M96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@
M`%5N9FEL960`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE
M<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N
M('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE
M;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E
M<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET
M>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@
M870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A
M('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`
M56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E
M('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5
M<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O
M('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@
M;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I
M9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N
M`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@
M061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N
M`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES
M('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA
M;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``
M57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y
M(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U
M;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N
M;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!6
M86QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@
M0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I
M8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=R`E<P!6:65W(&%N(&5X=&5R
M;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L($)R:71I
M<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I8FEL:71Y
M.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'(2$A(%)%
M34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(5%10`%=A
M;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!7
M96%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3
M:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`
M5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES
M<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A
M8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U
M<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA
M8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@
M0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT
M86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B
M;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN
M9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T
M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F
M(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R
M;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`
M5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2
M968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+
M97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y
M=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!9
M60!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R
M964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N
M('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W
M960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A
M8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V
M86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S
M(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S
M(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO
M;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED
M('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD
M('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C
M:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO
M=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R
M('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S
M96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@
M82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S
M97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E
M<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U
M(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R
M("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`
M66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!)
M;F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO
M=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D
M92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A
M(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE
M;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S
M97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M
M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@
M8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO
M;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A
M9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T
M=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT
M(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`
M66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y
M(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U
M<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W
M('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E
M;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@
M8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S
M<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E
M('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II
M<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W
M(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`
M6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E
M90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S
M+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS
M`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0
M<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N
M:VYO=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE
M`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S
M86=E(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M
M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E;G1R>2!N;W0@9F]U
M;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`9W5S
M=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I;6UE9&EA=&4`:6YL:6YE
M`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L
M:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N
M`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`
M;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO
M=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E<G9I8V4@=6YA=F%I;&%B
M;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W,`<W1E
M861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N
M;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C
M="U)9"U697)S:6]N.B!(;W)D92`S+C$*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#8M
M,#$M,#8@,30Z,3`K,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`V+3`Q+3,P
M(#(Q.C(V*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!)=F%N($YO<FES(#QV:7A`
M=F%Z:V$N<VL^"DQA;F=U86=E+51E86TZ(%-L;W9A:R`\=FEX0'9A>FMA+G-K
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X+6)I=`H`("AP<F5D("5S(&3R86UI*0`@*$MLX79E<V]VX2!S:W)A=&MA
M("5S*0`@*&\@)7,@9&[M*0`H9&YE<RD`("AZ86IT<F$I`"`H=NAE<F$I`"!R
M_6-H;&]SNR``(B5S(B!N:64@:F4@861R97/A<BX`(B5S(B!N:64@:F4@<&QA
M=&[A('9OM6)A+@`B)7,B(&YI92!J92!N86MO;F9I9W5R;W9A;ND@=B!R96=I
M<W1R:2!(;W)D92X`>F]B<F%Z;W9AZ"!S=')O;74@(B5S(B!N96)O;"!NX6ID
M96[]+@!3:W5P:6YA("(E<R(@8F]L82!P<FED86[A(&1O('-Y<W3I;74N`%!R
MX79O("(E<R(@8F]L;R!P<FED86[I(&1O('-Y<W3I;74N`"(E<R(@;F5B;VQO
M(&UOOF[I('9Y='9O<FF[.B`E<RX`4&]UOFET_6-H("4N,F9-0B!Z(&1O=F]L
M96[]8V@@)2XR9DU"("@E+C)F)24I`"5D("5S(&$@)7,`)60@9&[M(&1O('9Y
M<'*Y86YI82!P;&%T;F]S=&D@5N&Y:&\@:&5S;&$N`'!R961P;W9E[R!N82`E
M9"!D;NT`)7,@+2!0;WINX6UK80!/9'1L8>AO:R`E<P`E<R!+0@!/<&5RX6-I
M92#Z9'*^8GD@<')E(&%P;&EKX6-I=2`E<R`M(%!O='9R9&5N:64`3F%S=&%V
M96YI92`E<P!296=I<W1R;W9A;FEE(&1O(&%P;&EKX6-I92`E<P!0;V1M:65N
M:WD@<&]UOFET:6$@)7,`)7,@=;X@97AI<W1U:F4N`"5S('9O(';]N6ME("5S
M("5S`$%P;&EKX6-I82`E<R!J92!P<FEP<F%V96[A(&YA('9Y:V]N86YI92!O
M<&5RX6-I[2#Z9'*^8GDN3WIN8>AT92"Y='9O<NAE:R!P<FD@;W!E<N%C:>%C
M:"P@:W1O<ND@8VAC971E('9Y:V]N8;L@=&5R87HN`%!OOF%D=6IE('-A("5S
M`"5S(&UI;OIT`"5S(&YE8F]L(&[A:F1E;OTN`"5S(&&^("5S('H@)7,`061R
M97/A<B!P;W6^[79A=&6U82`E<P!+86QE;F3A<B!P;W6^[79A=&6U82`E<P!0
M;WINX6UK>2!P;W6^[79A=&6U82`E<P!:;WIN86T@^FQO:"!P;W6^[79A=&6U
M82`E<P`E<SH@)7,`)7,Z(%3A=&\@<W!RX79A(&YE;75S[2!B>;L@;V0@;V1O
M<VEE;&%T9;5A+"!K=&]R_2!S82!Z;V)R87IU:F4@86MO(&]D;W-I96QA=&6U
M('-P<N%V>2X@6F%C:&]V86IT92!O<&%T<FYO<[L@<')I(&ML:6MA;NT@;F$@
M;&EN:WD@=B!S<'+A=F4@86QE8F\@<&]S:WET;W9A;NT@;W-O8F[]8V@@:6YF
M;W)MX6-I[2!O9&]S:65L871EM6]V:2X`+"!NX7)A>F]V_2``+"!V(&[A<F%Z
M;V-H("5S("5S`"P@<')E;65N;N$@=B!R;WIS86AU("5S(&&^("5S`"TM('9Y
M8F5R=&4@<VD@+2T`,3(M:&]D:6YO=OT@9F]R;>%T`#(T+6AO9&EN;W;](&9O
M<FWA=``R-"!H;V3M;@`\4')E9&-HX61Z86KZ8V$`4')E('1E;G1O(&)L;VL@
M:F4@<&^^861O=F%N_2!D871A8N%Z;W;](&)A8VME;F0N`%9Y<VMY=&QA('-A
M('KA=F&^;N$@8VAY8F$`3F$@>F&Y:69R;W9A;FEE('-P<N%V>2!J92!P;[YA
M9&]V86[]('9E<F5J;OT@4$A0(&NU^N@N`$YA(&]V97)E;FEE('!O9'#M<V%N
M96H@<W!RX79Y(&IE('!OOF%D;W9A;OT@=F5R96IN_2!01U`@:[7ZZ"X`3F$@
M9&6Y:69R;W9A;FEE('-P<N%V>2!S^B!P;W1R96)NZ3H@=F5R96IN_2!01U`@
M:[7ZZ"P@<')I=N%T;GD@4$=0(&NU^N@@82!H97-L;RX`3F$@<&]D<.US86YI
M92!S<'+A=GD@<_H@<&^^861O=F%NZ3H@=G)E:F[](%!'4"!KM?KH+"!P<FEV
MX71N>2!01U`@:[7ZZ"!A(&AE<VQO+@!.82!D9;EI9G)O=F%N:64@<W!RX79Y
M('/Z('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A=&YY
M(%,O34E-12!KM?KH(&$@:&5S;&\N`$YA('!O9'#M<V%N:64@<W!RX79Y('/Z
M('!OOF%D;W9A;NDZ('9E<F5J;OT@4R]-24U%(&NU^N@L('!R:7;A=&YY(%,O
M34E-12!KM?KH(&$@:&5S;&\N`$YA('IAN6EF<F]V86YI92!S<'+A=GD@:F4@
M<&^^861O=F%N_2!V97)E:F[](%--24U%(&NU^N@N`%!R961P;VQU9&[M;2!O
M8FQAZ&YO`%!R961P;VQU9&[M;2"U86AK_2!DX;[O`%!R961P;VQU9&[M;2!D
MX;[O`%!R961P;VQU9&[M;2!P<F5HX6YK>0!0<F5D<&]L=61N[6T@<VYE:&]V
MZ2!P<F5HX6YK>0`Q,B!H;V3M;@!!4$D@240`3R!T;VUT;R!E9&ET;W)E`$\N
M+BX`06)S;VSZ=&YY('-P;V1O:P!!8G-O;/IT;GD@<W1R960`4')I('9Y=';A
M<F%N[2!61E,@861R97/A<F$@8F]L('IA;6EE=&YU=/T@<'+M<W1U<"X`4')I
M('9Y=';A<F%N[2!61E,@<_IB;W)U(&)O;"!Z86UI971N=73]('!R[7-T=7`N
M`$EN9F]R;>%C:64@;R#ZZ'1E`$AE<VQO('!R92#ZZ&5T`-KH970@>F%B;&]K
M;W9A;OTN`-KH=&]V86YI90!0<FED8;L`4')I9&&[('!O9')I861E;OH@<VMU
M<&EN=0!0<FED8;L@<&]D<FEA9&5NZ2!P<N%V;P!0<FED8;LZ`%!R:61ANR!S
M:W5P:6YU`%!R:61ANR!N;W;I('!RX79O`%!R:61ANR!D8^ER<VMU('-K=7!I
M;G4@9&\@(B5S(@!0<FED8;L@9&/I<G-K92!P<N%V;R!D;R`B)7,B`%!R:61A
MNR!P;W6^[79A=&6U83H`4')I9&&[('-TY7!E8P!0<FED8;L@Z&QE;F]V`%!R
M:61ANR!PX7(`4')I9&&[(&UE;G4@)7,@86MO($)OZ&[]('!A;F5L($UO>FEL
M;'D`4')I9&&[(&1O(&%D<F5SX7)A.@!0<FED8;L@9&\@;?1J:&\@861R97/A
M<F$`4')I9&&[('!O=;[M=F%T9;5A`"(E<R(@8F]L('!R:61A;OT@9&\@<WES
M=.EM=2P@86QE(&YE;6^^;F\@<')I9&&[(.]A;+EI92!P<FEH;&%S;W9A8VEE
M(&EN9F]R;>%C:64Z("5S+@`B)7,B(&)O;"!P<FED86[](&1O('-Y<W3I;74N
M(%1E<F%Z('-A(&WTOF5T92!P<FEH;.%S:;LN`%!R:63A=F%N:64@<&]UONUV
M871EM6]V(&IE('IA:^%Z86[I+@!!9')E<V$`061R97/A<@!!9&UI;FES='+A
M8VEA("T@;F%S=&%V96YI92!P<N%V('!R92!I;OUC:"!P;W6^[79A=&6U;W8`
M061M:6YI<W1RX6-I80!296ML86UY`$%F9V%N:7-T86X`06QBX6YS:V\`06R^
M[7)S:V\`06QI87,`6F%R;W9N8;L`6F%R;W9N86YI93H`5KEE=&MY`%:Y971C
M:2!A=71E;G1I9FEK;W9A;NT@<&]UONUV871E;&EA`%:Y971K>2!S:W5P:6YY
M`%:Y971K>2!P<N%V80!6N65T:WD@N71Y<FD@<W1R86YY`%!O=F]L:;L@=FEA
M8V5RZ2!A9')E<WD`4&]V;VQINR!N87-T879E;FEE('1Y<'4@>F]R861E;NEH
M;R!Z;WIN86UU/P!5OB!E>&ES='5J90!!;'1E<FYA=.UV;F4@<')I:&QA<V]V
M86-I92!M96YO($E-4U``06QT97)N873M=FYE(&AE<VQO($E-4U``06QT97)N
M873M=FYE('!O=;[M=F%T9;5S:^D@;65N;R!)35-0`$%L=&5R;F%T[79N82!E
M+6UA:6QO=N$@861R97-A`$%L=&5R;F%T[79N92"Y86)L\VYY`$%L=&5R;F%T
M[79N>2!T97AT.@!!;65R:6-KX2!386UO80!";VQA('IA9&%NX2!N97!L871N
MX2!H;V1N;W1A`$YA<W1A;&$@;F5Z;N%M82!C:'EB82X`06YD;W)R80!!;F=O
M;&$`06YG=6EL;&$`06YO;GEM;ND@<')O>'D`3V1P;W9E[P!!;G1A<FMT:6MA
M`$%N=&EG=6$@82!"87)B=61A`$%P;&EKX6-I80!:;WIN86T@87!L:6OA8VGM
M`$%P;&EKX6-I82!J92!P<FEP<F%V96[A+@!!<&QI:V]V8;L@;F$@<&]D<FEA
M9&5NZ2!Z9&EEM6%NZ2!P<FEEZ&EN:WD`4V-H=N%L:;L`4')I8FQIOF[A('9E
MM6MO<[L`07!R[6P`5F6U:V]SNR!A<F-H[79U`$UE;F\@87)C:.UV=0!.86]Z
M86H@8VAC971E('9Y;6%Z8;L@OFEA9&]SNR!O('!R:6ALX7-E;FEE("<E<R<_
M`$YA;WIA:B!C:&-E=&4@=GEM87IANR`B)7,B(&$@=KEE=&MY('!O9'-K=7!I
M;GD_`$%R9V5N=.UN80!!<FWI;G-K;P!5;65N:64`07)U8F$`3W-T<F]V($%S
M8V5N<VEO;@!!<V-I:2!U;65N:64`P7II82]086-I9FEC:_T@<F5G:?-N`%9Y
MOF%D;W9ANR!P;W1V<F1E;FEE('!R960@=GEK;VYA;NUM(&]P97+A8VGM(/ID
M<KYB>3\`4&]K=7,@;R!V>6UA>F%N:64@;F5E>&ES='5J^F-E:B!S:W5P:6YY
M+@!0;VMU<R!O('9Y;6%Z86YI92!N965X:7-T=6KZ8V5H;R!P<N%V82X`4&]K
M=7,@;R#Z<')A=G4@;F5E>&ES='5J^F-E:&\@<'+A=F$N`%!O:W5S(&\@^G!R
M879U(&YE97AI<W1U:OIC96AO('ID:66U86[I:&\@;V)J96MT=2X`071R:6+Z
M='D`075G=7-T`$%U<W1RX6QI80!286OZ<VMO`$%U=&A?8WER<W%L.B!0;[YA
M9&]V86[I(')O>KGM<F5N:64@:6UA<"!N96)O;&\@;N%J9&5NZ2X`075T:%]C
M>7)U<SH@8F%C:V5N9"!N96WA('!OOF%D;W9A;ND@<V-H;W!N;W-T:2X`075T
M:%]C>7)U<SH@<&^^861O=F%NZ2!R;WJY[7)E;FEE(&EM87`@;F5B;VQO(&[A
M:F1E;NDN`$%U=&A?9G1P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@1E10(&YE
M8F]L;R!NX6ID96[I+B!3:V]M<&EL=6IT92!02%`@<R!P<F5P[6YAZ&]M("TM
M96YA8FQE+69T<"X`075T:%]I;6%P.B!P;[YA9&]V86[I(')O>KGM<F5N:64@
M24U!4"!N96)O;&\@;N%J9&5NZ2X`075T:%]K<F(U.B!P;[YA9&]V86[I(')O
M>KGM<F5N:64@:W)B-2!N96)O;&\@;N%J9&5NZ2X`075T:%]L9&%P.B!P<FED
MX79A;FEE('!O=;[M=F%T9;5O=B!N:64@:F4@<&]D<&]R;W9A;ND@<')E($%C
M=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!V>6UA>N%V86YI92!P;W6^[79A
M=&6U;W8@;FEE(&IE('!O9'!O<F]V86[I('!R92!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@<&^^861O=F%NZ2!R;WJY[7)E;FEE($Q$05`@;F5B;VQO
M(&[A:F1E;NDN`$%U=&A?;&1A<#H@3F5P;V1A<FEL;R!S82!P<FED8;L@<&]U
MONUV871EM6$@)7,N(%-E<G9E<B!O9'!O=F5D86PZ(`!!=71H7VQD87`Z(&YE
M<&]D87)I;&\@<V$@;V1S='+A;FF[('!O=;[M=F%T9;5A("5S`$%U=&A?;&1A
M<#H@;F5P;V1A<FEL;R!S82!A:W1U86QI>F]V8;L@<&]UONUV871EM6$@)7,`
M075T:%]L9&%P.B!A:W1U86QI>N%C:6$@<&]UONUV871EM6]V(&YI92!J92!P
M;V1P;W)O=F%NX2!P<F4@06-T:79E($1I<F5C=&]R>0!!=71H7VUC86PZ('!O
MOF%D;W9A;ND@<F]ZN>UR96YI92!-0T%,(&YE8F]L;R!NX6ID96[I+@!!=71H
M7W-M8F%U=&@Z('!OOF%D;W9A;ND@<F]ZN>UR96YI92!S;6)A=71H(&YE8F]L
M;R!NX6ID96[I+@!!=71E;G1I9FEKX6-I82!P;VUO8V]U($E-05`@<V5R=F5R
M82!Z;'EH86QA+@!!=71E;G1I9FEKX6-I82!Z;'EH86QA`$%U=&5N=&EF:6OA
M8VEA('IL>6AA;&$N("5S`%-E<G9E<B!2041)55,@>F%M:65T;VP@875T96YT
M:69I:^%C:74N`$%U=&5N=&EF:6OA8VEA('!O;6]C;W4@1E10('-E<G9E<F$@
M>FQY:&%L82X`075T96YT:69I:^%C:6$@<&]M;V-O=2!334(@<V5R=F5R82!Z
M;'EH86QA+@!$;W-T=7!NZ2!P;VQOOFMY.@!!>F5R8F%J9+YA;@!"3T9(($5X
M8W5S97,`4&]Z861I90!&87)B82!P;WIA9&EA`%ILZ2!H97-L;R!P<F4@:V5R
M8F5R;W,N`%ILZ2!P;W6^[79A=&6U<VOI(&UE;F\@<')E(&ME<F)E<F]S+@!"
M86AA;7D`0F%H<F%J;@!"86YG;&%DZ;D`0F%R8F%D;W,`4')I9>AI;F]K(',@
M9W)A9FEK;W4@(B5S(B!N96)O;"!NX6ID96[]+@!:X6ML861N_2!R:6%D;VL`
M0FEE;&]R=7-K;P!"96QG:6-K;P!"96QI>F4`0F5N:6X`0F5R;75D>0!"=73A
M;@!.87)O9&5N:6YY`$)L;VL@(B5S(B!A<&QI:^%C:64@(B5S(B!N96)O;"!N
MX6ID96[]+@!.87-T879E;FEA(&)L;VMU`%1Y<"!B;&]K=0!4=>ANZ0!";VSM
M=FEA`%KA;&^^:WD`3VMR86H`J>UR:V$@;VMR86IA.@!/:W)A:F4`0F]S;F$@
M82!(97)C96=O=FEN80!/8F4`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA
M;F0`0G)A>NUL:6$`0G)I='-KZ2#Z>F5M:64@=B!);F1I8VMO;2!O8V7A;F4`
M0G)U;F5I($1A<G5S<V%L86T`0G5L:&%R<VMO`%IO>FYA;2!S(&]D<N&^:V%M
M:0!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$1I<W1R:6)UZ&[I(&)O
M9'D@0U),`%9L87-T;F]S=&D@7V)U;FMY+BXN`$EN8VEA;&EZX6-I82!V>7)O
M=F[A=F%C96H@<&%MY'1I(&YE8F]L82!D;VMO;NAE;N$N`$MA;&5N9.%R`$)E
M>G9E=')I90!+86UB;V2^80!+86UE<G5N`$YE<&]D87)I;&\@<V$@875T;VUA
M=&EC:WD@;V)N;W9INR!H97-L;RP@:V]N=&%K='5J=&4@<W9O:FAO(&%D;6EN
M:7-T<N%T;W)A+@!.97!O9&%R:6QO('-A('IA<.US8;L@9&\@<_IB;W)U("(E
M<R(`3F5M;[YN;R!A9&UI:7-T<F]V8;L@97AT97)NZ2!O=FSA9&'H92!S961E
M;NTN`$YE<&]D87)I;&\@<V$@<W!O:FF[(',@24U!4"!S97)V97)O;3H@)7,`
M3F5P;V1A<FEL;R!S82!O='9O<FF[('/Z8F]R("(E<R(N`$MA;F%D80!:<G6Y
M:;L`6G)UN6F[('-P<N%V=2!O('!R;V)LZ6UE`$YE<&]D87)I;&\@<V$@=GEM
M87IANR!S^F)O<B`B)7,B+@!.97!O9&%R:6QO('-A(&[A:G.[(&1OZ&%S;OT@
M861R97/A<BX`3F5M;[YN;R!P;VMR8>AO=F&[(&)E>B!P87)A;65T<F$@)W1A
M<F=E=$9I;&4G+@!.97!O9&%R:6QO('-A(&]D<W1RX6YINR!A9')E<^%R("(E
M<R(N`$YE;6^^;F\@;V1S='+A;FF[+"!E>&ES='5J92`E9"!N87-L961O=F[M
M:V]V+@!.96UOOFYO('!R975S<&]R:6%D8;LL('!OZ&5T('!O;&^^:65K('!R
M92!P<F5U<W!O<FEA9&%N:64@;F5S^FAL87/M(',@<&_H=&]M('5L;[YE;OUC
M:"!P;VQOOFEE:RX`3F5P;V1A<FEL;R!S82!S;65R;W9ANR!S<'+A=G4@;F$@
M=7+H96[I(.CM<VQO+@!+87!V97)D<VOI(&]S=')O=GD`5&ET=6QO:P!+871E
M9_-R:64@82!P;W!I<VMY`$MA:FUA;G-KZ2!O<W1R;W9Y`$UO8FEL;OT@=&5L
M96;S;@!6;&%S=&YO<W1I(&)U;FMY`%9Y<&QN96YI92!B=6YK>3H`5FQA<W1N
M;W-T:2!B=6YK>0!2;WIO<W1U<"!B=6YI96LZ`$UO8FEL;OT@=&5L96;S;@!$
M;R!S=')E9'4`4W1R961O869R:6-KX2!R97!U8FQI:V$`4&]D<F]B;ND@:6YF
M;W)MX6-I92!O(&-E<G1I9FEKX71E`%9L87-T;NUK(&-E<G1I9FEKX71U`%!O
M;&ET:6MY('!R92!C97)T:69I:^%T>0#(860`6FUE;FF[`%IM96YINR!68;EE
M(&AE<VQO`$YA<W1A=F5N:64@;65N82!A(&%D<FEE<RP@:W1O<ND@=FED:6$@
MM75D:6$L(&ME[R#H[71A:OH@82!O9'!O=F5D86KZ(&YA(%9AN64@92UM86EL
M>2X`6FUE;F$@:&5S;&$@;FEE(&IE('8@86MT=>%L;F5J(&MO;F9I9W5RX6-I
M:2!P;V1P;W)O=F%NX2X@($MO;G1A:W1U:G1E('-V;VIH;R!A9&UI;FES='+A
M=&]R82X`6FYA:P!37VMO;G1R;VQO=F&[(&QI;FMU+BXN`$-H:6QE`,CM;F$`
M5GEB97)T92!A<&QI:^%C:74Z`%IV;[5T92!S:2!H97-L;P!:=F^U=&4@<VD@
M<&]UONUV871EM7-KZ2!M96YO`%9Y8F5R=&4@<W#T<V]B('IO8G)A>F]V86YI
M82!DX71U;6]V.@!6>6)E<G1E('1Y<""Y=/UL=2!Z;WIN86UU("AP<F4@>F]R
M861E;ND@>F]Z;F%M>2D`5FEA;F_H;OT@;W-T<F]V`$1E9FEN[6-I82!T<FEE
M9'D@)7,@;F5B;VQA(&[A:F1E;N$N`$IA<VYO`$]D<W1RX6YINR!P<NUK87IY
M($U33V9F:6-E`%9Y;6%Z8;L@9&]T87H`3V1S='+A;FF[('!O=;[M=F%T9;5A
M.B`E<P!/9'-T<N%N:;L@<&]UONUV871EM6$`5GEM87IANR!P;W6^[79A=&6U
M<VOI(/ID86IE`$YE<VOT<B!V>6IA<VYE;FEE`$ML:6MN:71E('!R92!P;VMR
M8>AO=F%N:64`0VQI8VMA=&5L;"!C97H@2%144`!:871V;W)INR!O:VYO`$]B
M;&%K>0!2X6YO(&]B;&'H;F\`3V)L8>AN;P!#;V-O<R`H2V5E;&EN9RD@27-L
M86YD<P!:8F%L:;L@0F_H;OT@<&%N96P`6F)A;&5NZ2!O:W)A:F4`2V]L=6UB
M:6$`1F%R8F$`5OUB97(@9F%R8GD`5OUB97(@9F%R8GD`4W3E<&-E.@!.861P
M:7-Y('-TY7!C;W8`2V]M:6MS`%!R[6MA>@!0<NUK87IO=OT@:6YT97)P<F5T
M97(`2V]M96YTX7(`0F6^;ND@;65N;P!+;VUO<GD`4W!O;&_H;F]SNP!0;^CM
M=&'H90!3=&%V`%-T878`4F]Z9&EE;'D@=B!K;VYF:6=U<N%C:6D`2V]N9FEG
M=7+A8VEA('!R92!S>6YC:')O;FEZX6-I=2!S(%!$02P@:6YT96QI9V5N=&[]
M;6D@=&5L96;S;FUI(&$@3W5T;&]O:V]M+@!+;VYF:6=U<N%C:6$@<&]T<F5B
M=6IE(&%K='5A;&EZX6-I=2X`2V]N9FEG=7)O=F&[("5S`%!O='9R[W1E(&AE
M<VQO`$MO;F=O`$1E;6]K<F%T:6-KX2!R97!U8FQI:V$@2V]N9V\`4W!O:F5N
M:64@>FQY:&%L;RX`4W!O:F5N:64@>FQY:&%L;SH@`$NU^N@@8F]L('IA;6EE
M=&YU=/T@<V5R=F5R;VT@=F5R96IN_6-H(&NU^NAO=BX`2[7ZZ"!B;VP@>F%M
M:65T;G5T_2!S97)V97)O;2!V97)E:F[]8V@@:[7ZZ&]V+B!$]'9O9#H@)7,@
M*"5S*0!3<&]J96YI92!S($944"!S97)V97)O;2!Z;'EH86QO+@!+;VYT86MT
M>0!+;VYT86MT>2!B;VQI(/IS<&6Y;F4@=FQOOF5NX2!D;R!6X;EH;R!A9')E
M<^%R82X`5'EP(&MO;7!R:6UO=F%NZ6AO('/Z8F]R=3H`3V)S86@@(B5S(@!0
M;VMR8>AO=F&[`$-O;VMO=F4@;W-T<F]V>0!#;V]K:64`2V]P[7)O=F&[`$MO
M<.UR;W9A;FEE('IL>6AA;&\Z("5S`$MO<.UR;W9ANR!V_6)E<@!+;W-T87)I
M:V$`4&]B<F6^:64@<VQO;F]V:6YY`$YE<&]D87)I;&\@<V$@>F&Y:69R;W9A
MNR!S<'+A=G4@<&]M;V-O=2!01U`Z(`!.97!O9&%R:6QO('-A('!O9'#M<V&[
M('-P<N%V=2!P;VUO8V]U(%!'4#H@`$YE<&]D87)I;&\@<V$@>F&Y:69R;W9A
MNR!S<'+A=G4@<&]M;V-O=2!3+TU)344N`$YE<&]D87)I;&\@<V$@<&]D<.US
M8;L@<W!RX79U('!O;6]C;W4@4R]-24U%+@!.97!O9&%R:6QO('-A('!R:61A
MNR!K;VYT86MT+B`E<RX`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@
M<V5R=F5R=2X`3F5P;V1A<FEL;R!S82!P<FEP;VIINR!K($Q$05`@<V5R=F5R
M=0!.97!O9&%R:6QO('-A(&]V97)INR!Z;W-T871O:R!N82#ZZ'1E+B`E<P!.
M87-T86QA(&-H>6)A('!R:2!P<NUS='5P92!K($Q$05`@<V5R=F5R=0!.97!O
M9&%R:6QO('-A('!R:7!O:FF[(&L@<V5R=F5R=2`B)7,B('!O;6]C;W4@1E10
M.B`E<P!.97!O9&%R:6QO('-A('9Y='9O<FF[('IO>FYA;2!P<NUJ96UC;W8N
M("5S`$YE<&]D87)I;&\@<V$@9&6Y:69R;W9ANR!01U`@^F1A:F4Z(`!.97!O
M9&%R:6QO('-A(&1EN6EF<F]V8;L@4R]-24U%(/ID86IE+@!.97!O9&%R:6QO
M('-A('9Y;6%Z8;L@:V]N=&%K="X@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[
M('IO>FYA;2!P<NUJ96UC;W8N("5S`$YE<&]D87)I;&\@<V$@=GEM87IANR!S
M:W)I<'0@;F$@=7!G<F%D92!K;VYF:6=U<N%C:64@(B5S(BX`3F5P;V1A<FEL
M;R!S82!U<NAINR!E+6UA:6QO=OH@861R97-U('!R[6IE;6-U+@!.97!O9&%R
M:6QO('-A('-T:6%H;G6[(&-E;/T@861R97/A<BX`3F5P;V1A<FEL;R!S82!Z
M[7-K8;L@:V]M<&QE=&[]('IO>FYA;2!P<NUJ96UC;W8N`$YE<&]D87)I;&\@
M<V$@>NUS:V&[(&MO;7!L971N_2!Z;WIN86T@>F]Z;F%M;W8@<'+M:F5M8V]V
M+@!.97!O9&%R:6QO('-A(&YAZ.UT8;L@<W1R873I9VEU("(E<R(N`$YE<&]D
M87)I;&\@<V$@<W!U<W1INR!M:V1I<B`B)7,B+@!.97!O9&%R:6QO('-A('KM
M<VMANR!V97)E:F[](&NU^N@@>F\@<V5R=F5R82!KM?KH;W8N`$YE<&]D87)I
M;&\@<V$@;W1V;W)INR`B)7,B('!R92!ZX7!I<RX`3F5P;V1A<FEL;R!S82!O
M='9O<FF[("5S+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@;6]D=6P@36%I;G1E
M;F%N8V5?5&%S:R`E<P!.97!O9&%R:6QO('-A(&]T=F]R:;L@861R97/A<B`B
M)7,B+@!.97!O9&%R:6QO('-A('!R:7!O:FF[(&YA($Q$05`@<V5R=F5R+@!.
M97!O9&%R:6QO('-A('!R9>CM=&&[("5S+@!.97!O9&%R:6QO('-A(&]B;F]V
M:;L@:&5S;&\@>F%D86[I:&\@<&]UONUV871EM6$N($YI96MT;W+I(&%L96)O
M(':Y971K>2!P;V1R;V)N;W-T:2!N:64@<_H@<W!RX79N92X@4VOZ<W1E('1O
M('IN;W9U(&%L96)O(&MO;G1A:W1U:G1E(%;AN6AO(&%D;6EN:7-T<N%T;W)A
M+"!A:R!P;W1R96)U:F5T92!P;VUO8RX`3F5M;[YN;R!Z[7-K8;L@04-,`$YE
M<&]D87)I;&\@<V$@>NUS:V&[(&%D<F5SX7(N("5S`$YE<&]D87)I;&\@<V$@
M>NUS:V&[('IO>FYA;2!P<NUJ96UC;W8N("5S`$YE<&]D87)I;&\@<V$@>NUS
M:V&[('IO>FYA;7D@<'+M:F5M8V]V("5S`$YE;6^^;F\@>NUS:V&[(&EN9F]R
M;>%C:64@;R!V;&%S=&YO<W1I86-H('-E<G9E<F$`3F5P;V1A<FEL;R!S82!V
M<N%T:;L@:V]N9FEG=7+A8VEU+@!.97!O9&%R:6QO('-A('-P=7-T:;L@<FUD
M:7(@(B5S(BX`3F5P;V1A<FEL;R!S82!U;&^^:;L@:V]N9FEG=7+A8VEU("5S
M+@!.97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE+@!.
M97!O9&%R:6QO('-A('5L;[YINR!ZX6QO:'4@:V]N9FEG=7+A8VEE.B`E<P!.
M97!O9&%R:6QO('-A('5L;[YINR!S:W)I<'0@;F$@=7!G<F%D92!N87-T879E
M;NT@9&\Z("(E<R(N`$YE<&]D87)I;&\@<V$@=6QOOFF[('KA;&]H=2!K;VYF
M:6=U<N%C:64@)7,N`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!K;VYF:6=U<F'H
M;OT@<_IB;W(@)7,N($WTOF5T92!P;W6^:;L@;FEE:W1O<OH@>B!M;[YN;W-T
M[2!N82!ZX7!I<R!K\V1U(&YA("5S(&%L96)O('-K;W#M<F]V8;L@<G7H;F4@
M:_-D('5V961E;OT@;FF^N6EE(&1O("5S+@!.97!O9&%R:6QO('-A(&BU861A
MNR!N82!,1$%0('-E<G9E<FDN`$YE<&]D87)I;&\@<V$@=GEM87IANR`B)7,B
M+@!.97!O9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!K;VYT86MT+B`E<P!.97!O
M9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!Z;WIN86T@<'+M:F5M8V]V+B`E<P!.
M97!O9&%R:6QO('-A('IA<.US8;L@:V]N9FEG=7+A8VEU('!R92`B)7,B.B`E
M<P!.96UOOFYO(&[A:G.[($)OZ&[]('!A;F5L($UO>FEL;'DN(%-K;VYT<F]L
M=6IT92P@OF4@:F4@<&%N96P@;W1V;W)E;OTN`%!O=;[M=F%T9;5O=FD@(B5S
M(B!S82!N97!O9&%R:6QO('!R:61ANR!P<N%V82!P<F4@<')I9>AI;F]K("(E
M<R(Z("5S`%!OZ.UT86[]('1E>'0`2W)A:FEN80!+=7)Z>0!6>71V;W)INP!6
M>71V;W)INR!L:6YK=0!6>71V;W)INR!N;W;]`%9Y='9O<FF[('!O9'!R:67H
M:6YO:P!0<N%V82!T=F]R8W4`R.US;&\@:W)E9&ET;F5J(&MA<G1Y`$-H;W)V
MX71S:V\`2W5B80!!:W1UX6QN92`T(&;A>GD`06MT=>%L;F4@<V5D96YI80!!
M:W1UX6QN>2#H87,`06MT=>%L;F$@55),(&IE`$%K='7A;&YI('!O=;[M=F%T
M96QI80!!:W1UX6QN92!P;^AA<VEE`$%K='7A;&YE('!O9&UI96YK>3H@`$%K
M='7A;&YY(+ET_6P`3F%S=&%V96YI92#Z;&]H+"!K=&]RZ2!S82!S</JYNV%J
M^B!P<FD@<')I:&SA<V5N[2!D;R!A<&QI:^%C:64@)7,N`%9Y<W1R:6AN^KL`
M5GES=')I:&[ZNR!V_6)E<@!#>7!R=7,`R&5S:^$@<F5P=6)L:6MA`$1$`$13
M3B`H<&]Z<FD@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G
M92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$96YN90!0<F5Z97)AZ"!D
MX71O=NEH;R!S=')O;74@*$1A=&%4<F5E*0!6>6BU863A=F%N:64@=B!D871A
M8N%Z90!$X71U;0!$X71U;2!P<FEJ871I80!6_6)E<B!DX71U;74`1&7R`$]?
M9'-T<N%N:;L@<W3E<&5C`$1E8V5M8F5R`$1E<VEA=&MO=ND@Z.US;&$`6FUE
M;KEINR!O9'-A9&5N:64`4')E9&YA<W1A=F5NZ0!0<F5D;F%S=&%V96[A(&9A
M<F)A`%9AN6$@<')E9&YA<W1A=F5NX2!I9&5N=&ET80!0<F5D;F%S=&%V96[]
M('!R[6MA>F]V_2!I;G1E<G!R971E<@!$969I;NUC:64`5GEM87IANP!6>6UA
M>F&[(&)U;FMU`%9Y;6%Z8;L@<VMU<&EN=0!6>6UA>F&[('KA>FYA;0!6>6UA
M>F&[('!RX79O`%9Y;6%Z8;L@82!O9'-T<N%N:;L@<W!RX79Y`%9Y;6%Z8;L@
M8G5N:W4`5GEM87IANR!S=.5P96,`5GEM87IANR!E>&ES='5J^F-U(&%L=&5R
M;F%T[79N=2"Y86)L\VYU`%9Y;6%Z8;L@<'+A=F$@<')E("(E<R(`0VAC971E
M('9Y;6%Z8;L@(B5S(B!A(':Y971K>2!J96AO('!O9'!RX79A/P!6>6UA>F&[
M(')I861O:P!6>6UA>F&[('9Y8G)A;OH@:61E;G1I='4`5GEM87IANR!A:W1U
MX6QN>2!S=.5P96,`5GEM87IANR!A:W1UX6QN>2!R:6%D;VL`4VMR:7!T(&YA
M('5P9W)A9&4@:V]N9FEG=7+A8VEE("(E<R(@8F]L('9Y;6%Z86[]+@#(87,@
M9&]R=>AE;FEA`$3A;G-K;P!0;W#MN71E('!R;V)LZ6T`4&]P:7,`4&]D<F]B
M;F]S=&D@*'1I9;X@=B!L;V=O=F%C;VT@<_IB;W)E($AO<F1E*0!$971A:6QY
M(&)O;&D@>F%Z;F%M96YA;ND@<')E(&%D;6EN:7-T<N%T;W)A+@!6_79O:@!2
M;W-N_2!B;V0`4F]S;OT@8F]D('IA('!O<VQE9&[Z(&AO9&EN=3H@`%)O<V[]
M(&)O9#H@`%-M97(@>K5A=F$@9&]P<F%V80!3;65R('-P<F%V82!D;[5A=F$`
M061R97/A<@!:;V)R87IO=F&[(.AA<R!V(#(T+6AO9&EN;W9O;2!F;W)MX71E
M/P!.87-T879E;FEE('IO8G)A>F5N:6$`6F]B<F%Z:;L@<&]D<F]B;OH@<')E
M9'!O=F7O`%IO8G)A>FF[('!R961P;W9E[R`H5$%&*0!&;W)MX70@>F]B<F%Z
M96YI80!0;W1V<F1E;FEE(&\@9&]R=>AE;NT`1+YI8G5T<VMO`$YE=GEM87IA
MNP!.97!O=;[M=F%J=&4@<')I86UO(&UA:6YT96YA;F-E+G!H<`!/8G-A:'5J
M92!P<G;](')I861O:R!NX7IV>2!P;VSM/R!!:R#A;F\L('IAN6MR=&YI=&4@
M<&]L[>AK;SH@`$1O;6EN:6-A`$1O;6EN:6OA;G-K82!R97!U8FQI:V$`3F5M
MX71E(/KH970_(%IA<F5G:7-T<G5J=&4@<V$N`%-T:6%H;G6[`%-T:6%H;G6[
M("5S`%-T:6%H;G6[('9Y9V5N97)O=F%N^B!K;VYF:6=U<N%C:74@86MO(%!(
M4"!S:W)I<'0N`%IO>FYA;2!S(';]8F5R;VT`1')O9WD`12UM86EL`$524@!%
M:W;A9&]R`%5P<F%V:;L`57!R879INR!B;&]K`%5P<F%V:;L@<VMU<&EN=0!5
M<')A=FF[('!RX79O`%5P<F%V:;L@<'+A=F$`57!R879INR!P<N%V82!P<F4@
M)7,`57!R879INR!N87-T879E;FEA('!R93H`57!R879INR!P<N%V82!P<F4@
M(B5S(@!5<')A=FF[('!RX79A('!R92`E<P!6>F1E;.%V86YI90!%9WEP=`!3
M86QVX61O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL;W;A(&%D<F5S83H`
M12UM86EL;W;I(&%D<F5S>2!M=7-I82!B>;L@<F]V;F%KZ2X`12UM86EL(',@
M<&]T=G)D96[M;0!"<N%N82!%;6%I;"UN82U335,`16UO=&EK;VYY`%!RX7ID
M;F$@<W!RX79A+@!0<N%Z9&YY(';]<VQE9&]K+@!0<N%Z9&YE('!O9&UI96YK
M>2!HM6%D86YI80!0;W9O;&F[('9L;[YE;FEE(&]B<N%Z:V]V('H@1V%LZ7)I
M[2!D;R!T97AT=3\`4&]V;VQINR!K;VYT97AT;W;I(&UE;G4@<')E('!R87;I
M('1L8>AI9&QO/P!+;VYI96,@<F]K80!:=N3HN6F[(&5D:71O<@!:861A:G1E
M(&)E>G!EZ&YO<W1N^B!O=.%Z:W4L(&YA(&MT;W+Z(&)U9&5T92!M=7-I9;L@
M;V1P;W9E9&&[(&%K('IA8G5D;F5T92!H97-L;RP@;F%P<BX@)V%K;R!S82!V
M;VSA(&UO:F4@>G9I97)A=&MO/R<Z`%IA9&%J=&4@55),(&]B<N%Z:V$`6F%D
M86IT92!P[7-M96[A('5V961E;ND@;FF^N6EE.@!2;W9N[6MO=N$@1W5I;F5A
M`$5R:71R96$`0VAY8F$`0VAY8F$@<')I('9Y=';A<F%N[2!B;&]K=3H@)7,`
M0VAY8F$@<')I('9Y;6%ZX79A;NT@=6MO='9E;FEA('-Y;F-H<F]N:7KA8VEE
M.B`E<P!#:'EB82!P<FD@=GEM87KA=F%N[2!ZX7IN86UU('-Y;F-H<F]N:7KA
M8VEE.B`E<P!#:'EB82!P<FD@>NUS:V%V86[M(&]B<V%H=3H@)7,`0VAY8F$@
M<')I(&%K='5A;&EZX6-I:2!H97-L83H@)7,`0VAY8F$@=B!E+6UA:6QO=F5J
M('-P<N%V92X`0VAY8F$@<')I('IA<&ES;W9A;NT@(B5S(BX`17-T\VYS:V\`
M171I\W!I80!%=&YI8VOI`$5U<O-P80!+8;YD_6-H(#$U(&UI;OIT`$MAOF3I
M(#(@;6EN^G1Y`$MAOF3]8V@@,S`@<V5K^FYD`$MAOF3]8V@@-2!M:6[Z=`!0
M<FD@:V&^9&]M('!R:6ALX7-E;NT`2V&^9/H@<&]L:&]D:6YU`$MAOF3Z(&UI
M;OIT=0!.87!R[6ML860Z`%-P=7-T:;L`4F]Z8F%L:;L`4F]Z8F%L:;L@0F_H
M;OT@<&%N96P`3^AA:^%V82!S82`G*2<`3^AA:^%V82!S82!S;&]V;R!A;&5B
M;R!P;V1M:65N:V$@:+5A9&%N:6$@=B#Z=F]D>F]V:^%C:`!$X71U;2!E>'!I
M<N%C:64`17AP;VYE;G0`1F%R8F$@=&5X='4`3F%H<F&[(&MO;F9I9W5RX6-I
M=2!N82!&5%``3F5P;V1A<FEL;R!S82!Z[7-K8;L@;F%S=&%V96YI82X`3F%S
M=&%L82!C:'EB82!P<FD@<W!O:F5N[2!S($Q$05`@<V5R=F5R;VTN`$YA<W1A
M;&$@8VAY8F$@<')I('!R[7-T=7!E(&L@4TU"('-E<G9E<G4N`$YE<&]D87)I
M;&\@<V$@:V]P[7)O=F&[('H@(B5S(BX`3F5P;V1A<FEL;R!S82!K;W#M<F]V
M8;L@9&\@(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!N;W;I(%-!4TP@
M<W!O:F5N:64N`$YE<&]D87)I;&\@<V$@<')E<W5N^KL@9&\@(B5S(BX`3F5P
M;V1A<FEL;R!S82!Z[7-K8;LZ("5S`$1O8G+I`$9A;&ML86YD<VOI(&]S=')O
M=GD@*$UA;';M;GDI`$9A97)S:^D@;W-T<F]V>0!:X79AOF[A(&-H>6)A.@!&
M87@`1F%X>0!&96)R=>%R`%!O8VET('1E<&QO='D`4&]C:70@=&5P;&]T>3H@
M`$UA;.D@>G+AOFMY`$UA;.D@<VYE:&]VZ2!P<F5HX6YK>0!-871I8V$@<&]L
M[0!&:62^:0!3^F)O<@!0;^AE="!S^F)O<F]V.B`E<R!S^F)O<@!0;^AE="!S
M^F)O<F]V.B`E<R!S^F)O<F]V`%-P<N%V8V$@<_IB;W)O=@!-96YO('/Z8F]R
M=0!6_6)E<B!S^F)O<G4`3F%H<F%T:64@<_IB;W)U`$YA:'+A=F%N:64@<_IB
M;W)O=B!N:64@:F4@<&]D<&]R;W9A;NDN`$9I;'1R90!&[6YS:V\`4')VX2!P
M;VQO=FEC80!0<G;A(+ET=G*[`%!E=F[]('!O;65R`$]T;^AINP!0;.%V86KZ
M8VD@=&5X=`!(;6QA`%!R:67H:6YO:R`E<R!N965X:7-T=6IE`$9A<F)A('#M
M<VUA`%!O=')A=F$`4')E('!R96AL:6%D8>AE+"!K=&]RZ2!N97!O9'!O<G5J
M^B!O8G+A>FMY`%!R961P;W9E[R`H5$%&*0!0<F5D<&]V9>\@;F$@=79E9&5N
M_2!P;^AE="!D;NT@*'!A;>1T86IT92!N82!T;RP@OF4@<')E9'!O=F7O(&IE
M('!R92!D;FD@86H@;F]C:2!A('1A:R!M]+YE('9EM6OI(.CM<VQO('9Y='9O
M<FF[('9EM6UI(+EI<F]K_2!B;&]K*0!:86)U9&QI('-T92!H97-L;S\`1F]R
M;75LX7)E`$9O<G1U;F$`5'EP(&9O<G1U;GD`1F]R='5N>0!&;W)T=6YY(#(`
M1O-R80!0<F5S;65R;W9A;FEA`%!I80!2X6UC90!&<F%N8_IZ<VMO`$9R86YC
M^GIS:V\@*$5U<O-P82D`1G)A;F/Z>G-K82!'=6%Y86YA`$9R86YC^GIS:V$@
M4&]L>6[I>FEA`$9R86YC^GIS:V4@:G6^;ND@=&5R:73S<FGA`$]D`%IO('-M
M97)U(`#:<&QN_2!P;W!I<P!3<&QN`$-E;.D@;65N;SH`1V%B=6X`1V%LZ7)I
M82P@>B!K=&]R96H@8VAC971E('9Z:6&[(&]B<N%Z;VL`1V%LZ7)I83H`1V%M
M8FEA`$=E;F5R;W9ANR!K;VYF:6=U<N%C:74@<')E(&%P;&EKX6-I=2`E<P!'
M96YE<F]V86[](&OS9`!'96]R9VEA`$YE;65C:V\`1VAA;F$`1VEB<F%L=.%R
M`$MR<W1NZ2!M96YO`$]D;W-L8;L`1V]E9&5L`$=O;V=L92!-87!S`$BU861A
MNR!N82!';V]G;&4`3V1T:65N92"Y961E:@!'<NEC:V\`1W+S;G-K;P!'<F5N
M861A`$%D;6EN:7-T<N%C:6$@<VMU<.UN`$UE;N$@<VMU<.UN(&YE<VWZ(&)Y
MNR!P<N%Z9&YE`$=R;W5P7VQD87`Z($YE<&]D87)I;&\@<V$@<')I9&&[('-K
M=7!I;G4@)7,N(%-E<G9E<B!O9'!O=F5D86PZ(`!'<F]U<%]L9&%P.B!N97!O
M9&%R:6QO('-A('9Y;6%Z8;L@<VMU<&EN=2`E<P!'<F]U<%]L9&%P.B!N97!O
M9&%R:6QO('-A(&%K='5A;&EZ;W9ANR!S:W5P:6YU("5S`%-K=7!I;GD`1W5A
M9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!0<N%V82!A;F]N>6UN
M_6-H('!O=;[M=F%T9;5O=@!'=65S=&)O;VL`1W5I;F5A`$=U:6YE82U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IANR!P;W-L
M961N^B!B=6YK=2!V(')I861K=2X`2%1-3$%R96$@;F5D;W9O;.T@=GEM87IA
MNR!P;W-L961N_2!S=.5P96,@=B!T86)UM6ME+@!(5$U,07)E82!N961O=F]L
M[2!V>6UA>F&[('!O<VQE9&[](')I861O:R!V('1A8G6U:V4N`$A45%`@875T
M96YT:69I:^%C:6$@;F5B;VQA(&[A:F1E;N$N`$AA:71I`$%L9V]R:71M=7,@
M:&%S:&]V86-E:B!F=6YK8VEE`$]P87(`2&QA=FGH:V$`2&QA=FGH:WD`2&5A
M<F1O=B!O<W1R;W8@82!-8T1O;F%L9&]V92!O<W1R;W9Y`%-I;&[A(&+Z<FMA
M`%;]N6MA`%!O;6]C;NUK`%!O;6]C;NUK('!R92!P;W6^[79A;FEE(&5D:71O
M<F$`4&]M;V-N[6L`4&]L;V=UM6$`5'4@:F4@>F'H:6%T;VL@<_IB;W)U.@!6
M>7-O:^$`1&]?;6]V`%9A=&EKX6X`1&]M;W8`1&]MX6-A(&%D<F5S80!$;VWA
M8VD@<')I9>AI;F]K`%1E;&5F\VX@9&]M;W8`2&]N9'5R87,`2&]N9R!+;VYG
M`$AO<F1E`$AO<F1E+TMO;&%B.B!V('-P<N%V92`E<R!B;VQI(&[A:F1E;ND@
M;F5P;&%T;ND@)7,@6$U,(/ID86IE`$AO<F1E+TMO;&%B.B!S(&]B:F5K=&]M
M("5S(&YE:V]R9;EP;VYD=6IE(+YI861N82!S<'+A=F$N`$AO<F1E+TMO;&%B
M.B!V('-P<N%V92`E<R!N96)O;"!NX6ID96[](+YI861E;B!O8FIE:W0@='EP
M=2`E<P!(;W)D92]+;VQA8CH@^G-P9;EN92!O9'-T<N%N96[I("5S("(E<R(`
M2&]R9&4O2V]L86(Z(&EN=&5G<N%C:6$@=GF^861U:F4@4$A0(')O>KGM<F5N
M:64@)V1O;7AM;"<`2&]R9&4O2V]L86(Z(&YE<&]D87)I;&\@<V$@=GET=F]R
M:;L@;F]V_2!834P@<W1R;VT@<')E(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@
M;F5P;V1A<FEL;R!S82!O9'-T<N%N:;L@)7,@(B5S(CH@)7,`2&]R9&4O2V]L
M86(Z(&YE<&]D87)I;&\@<V$@>NUS:V&[($U)344@240@<')E(.AA<[L@='EP
M=2`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC:')O;FEZ;W9A
MNR`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P;V1A<FEL;R!S82!S>6YC
M:')O;FEZ;W9ANR!Z9&EEM6%NZ2!O8FIE:W1Y.B`E<P!(;W)D92]+;VQA8CH@
M;F5Z;N%M>2!Z9&EEM6%N_2!O8FIE:W0@(B5S(@!(;W)I>F]N=.%L;F$@Z&EA
M<F$`2&]R:7IO;G3A;&YE('9Y<&QN96YI90!(;W)I>F]N=.%L;F4Z`$%K;R!S
M=&4@<V$@<V5M(&1O<W1A;&D_("A0<F]S[6T@;F%H;.%S=&4A*0!+;[5K;R!S
M=.5P8V]V(&-H8V5T92!Z;/KH:;L_`%IA9&%J=&4@<&_H970@<&]L[2`H<W3E
M<&-O=BD_`$MOM6MO(')I861K;W8@8VAC971E('IL^NAINS\`5FQH:V]SNP!6
M;&AK;W.[.B``2'5M;W)I<W1I`$UA[V%R<VMO`$YE<&]D87)I;&\@<V$@=GET
M=F]R:;L@24U!4"!S8VARX6YK=3H@)7,`3F5P;V1A<FEL;R!S82!V>6UA>F&[
M($E-05`@<V-H<N%N:W4Z("5S`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@24U!
M4"!K=O-T=3H@)7,`25`@861R97-A`$E0(&%D<F5S82!N:64@:F4@9&]S='5P
M;N$N`$E0(&%D<F5S82!N:64@:F4@=B!RX6UC:2!D;W9O;&5NZ6AO($-)1%(@
M8FQO:W4N`%!O<G6Y96YI92!P<F%V:61L82!O('!E=FYE:B!)4"!A9')E<V4N
M`%9L;[YINR!KM?KH(%]P<F5D`$ES;&%N9`!)8F$@:6MO;GD`26MO;GD@<')E
M("5S`$EK;VYY(&$@=&5X=`!.X7IO=B!I9&5N=&ET>3H`06L@<V$@;F5Z;V)R
M87KM(&MO<F5K=&YE+"`E<R!A(&]T=F]R[2!S82!V(&YO=F]M(&]K;F4N`$%K
M(&YE=FED[71E('!R:2!P;W6^:73M($EN=&5R;F5T($5X<&QO<F5R82"^:6%D
M;F4@:6MO;GDL('!O=')E8G5J971E('IAN6MR=&[ZNR!T^G1O('9OM6)U('!R
M92!V>7!N=71I92!P<FEE<W9I=&YO<W1I(%!.1R!O8G+A>FMO=BX`06L@=FED
M[71E('3Z=&\@<W!RX79U(&$@;F5V:63M=&4@;V)RX7IO:RP@;V)RX7IO:RP@
M:W1O<OT@<W1E(&-H8V5L:2!N86AR8;LL(&YE;?2^92!B>;L@>F]B<F%Z96[]
M('9O(%9AN6]M('!R96AL:6%D8>AI+@!5:^&^:V$@;V)RX7IK83H`55),(&]B
M<N%Z:V$`55),(&]B<N%Z:V$Z`$]B<N%Z;VL@>B!G86SI<FEE`$]B<N%Z;VL@
M>B!G86SI<FEE.@!.86AR871I92!O8G+A>FMU`$]B<N%Z:WD`26UP;W)T+"!K
M<F]K("5D`$EM<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[I('!O;&EA
M.@!6;&^^:;L@:[7ZZ"!?>F$`0F]L('IA9&%N_2!N97-P<N%V;GD@:_-D(&%K
M8VEE+@!.97-P<N%V;F4@<&]UONUV871EM7-KZ2!M96YO(&$O86QE8F\@:&5S
M;&\`3F5S<'+A=FYE('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!A;'1E<FYA
M=.UV;F$@861R97-A+B!3:_IS=&4@=&\@>FYO=G4@86QE8F\@:V]N=&%K='5J
M=&4@<W!RX79C=2!6X;EH;R!S>7-TZ6UU+"!A:R!P;W1R96)U:F5T92!P;VUO
M8RX`6G;DZ+EINR!O9'-A9&5N:64`26YD:6$`2F5D;F]T;&EV[2!P;W6^[79A
M=&5L:6$`26YD;V[I>FEA`$EN9F\`26YF;W)MX6-I90!);F9O<FWA8VEE('6^
M(&YI92!S^B!D;W-T=7!NZ2X`5FQOOFF[(%]S=.5P96,@>F$`5FQOOFF[(&]B
M<N%Z;VL`5FQOOFF[('1A8G6U:W4`5FQOOFF[(&QI;FMU`%9L;[YINR!?<W3E
M<&5C('!R960`5FQOOFF[(&YO=OT@<W3E<&5C('IA(&%K='7A;&YY`%9L;[YI
MNR!N;W;]('-TY7!E8R!P<F5D(&%K='7A;&YY`%9L;[YINR!N;W;](')I861O
M:R!Z82!A:W1UX6QN>0!6;&^^:;L@;F]V_2!R:6%D;VL@<')E9"!A:W1UX6QN
M>0!6;&^^:;L@;V1S=&%V96,@>F$@86MT=>%L;GD@8F]D`%9L;[YINR!O9'-T
M879E8R!P<F5D(&%K='7A;&YY(&)O9`!6;&^^:;L@86QT97)N873M=FYU(+EA
M8FSS;G4`6F%D86IT92!E+6UA:6QO=OH@861R97-U+"!N82!K=&]R^B!D;W-T
M86YE=&4@;F]VZ2!H97-L;SH`5FQOOFF[(&)U;FMU('IA`%9L;[YINR!B=6YK
M=2!P<F5D`%9L;[YINR!S=.5P96,@>F$`5FQOOFF[('-TY7!E8R!P<F5D`%9L
M;[YT92!S<'+A=GD`5FQOOFF[(&]D<W1A=F5C('IA`%9L;[YINR!O9'-T879E
M8R!P<F5D`%9L;[YINR!R:6%D;VL@>F$`5FQOOFF[(')I861O:R!P<F5D`%IA
M9&%J=&4@<&^^861O=F%N^B!O9'!O=F7O(&YA(&)E>G!EZ&YO<W1N^B!O=.%Z
M:W4Z`%9L;[YINR]U<')A=FF[(&]B<N%Z;VL`5FQOOFF[+W5P<F%V:;L@;&EN
M:W4`3F$@;V1O<VEE;&%N:64@<')E('IO>FYA;2!P<NUJ96UC;W8@;F5MX71E
M(&1O<W1A=&_H;OT@:W)E9&ET+@!.961O<W1A=&_H;OT@:W)E9&ET+@!#96SI
M(.CM<VQO`%IO>FYA;2!C96S]8V@@Z&ES96P`3F5P;&%D;ND@541(("A5<V5R
M($1A=&$@2&5A9&5R+"!(;&%V:>AK82!P;W6^[79A=&6U<VO]8V@@^F1A:F]V
M*2X`3F5P;&%T;ND@^F1A:F4@9F]R;>%T=2!:25`N`$YE<&QA=&[A(&%P;&EK
MX6-I82X`3F5P;&%T;ND@240@9.%V:WDN`$)O;&D@;V1O<VQA;ND@;F5P;&%T
M;ND@^F1A:F4N`$YE<&QA=&[A(&-I9;5O=N$@861R97-A+@!.97!L871N_2!F
M;W)MX70@<_IB;W)U`$YE<&QA=&[](&QI8V5NZ&[](&NU^N@N`$)O;&$@>F%D
M86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.97!L871NX2!H;V1N;W1A(&US9U]T
M>7!E+@!.97!L871NX2!A;&5B;R!C:/UB86KZ8V$@:&]D;F]T82!A<&E?:60N
M`$YE<&QA=&[I(&%L96)O(&-H_6)A:OIC92!P87)A;65T<F4N`$YE<&QA=&[I
M(')O9&GH;W9S:^D@<'+A=F\N`$YE<&QA=&[I(&ED('!A<G1N97)A+@!.97!L
M871N_2!K\V0@<')O9'5K='4N`$YE<&QA=&[]('!R;W1O:V]L`$YE<&QA=&[]
M('!R[6IE;6-A.B`B)7,B`$YE<&QA=&[](&]B:F5K="!Z9&EEM6%N:6$`3F5P
M;&%T;N$@>F1R;VIO=N$@861R97-A+@!.97!L871NZ2#Z9&%J92!U;FEC;V1E
M+@!);G9E;G3A<@!);G9E<G1O=F&[(';]8F5R`$ERX6X`27)A:P#-<G-K;P!)
M<VQE(&]F($UA;@!/:F5D:6YE;.D@8OIR:WD`27IR865L`%9Y9&%V871EM0!+
M=7)Z[79A`%1A;&EA;G-K;P!*86UA:FMA`$IA;G7A<@!*87!O;G-K;P!*97)S
M97D`2F]R9.%N`$KZ;`!*^FX`6F%R;W9N8;L`6F%R;W9N8;L@9&\@<W1R961U
M`%IA<F]V;F&[(&1O(&)L;VMU`%IA<F]V;F&[(':U879O`%IA<F]V;F&[('9P
M<F%V;P!+87IA8VAS=&%N`%!O;F5C:&&[(&]R:6=I;N%L/P!+9?)A`$ME<F)E
M<F]S('-E<G9E<B!Z86UI971O;"!A=71E;G1I9FEKX6-I=2X`2V5R;F5L+6YO
M=N'H:6MO=FEA`%9Y='9O<F5N:64@:[7ZZ&$`1&EG:73A;&YY(&]D=&QAZ&]K
M(&NU^NAA`$3EOFMA(&NU^NAA`%1Y<"!KM?KH80!0;W6^:71I92!KM?KH80!+
MM?KH('6^(&5X:7-T=6IE(&YA('-E<G9E<FD@=F5R96IN_6-H(&NU^NAO=BX`
M1&5T:0!+:7)I8F%T:0"E=61O=F]D96UO:W)A=&EC:^$@<F5P=6)L:6MA($OS
M<F5A`$OS<F5J<VOA(')E<'5B;&EK80!+=79A:G0`2VER9VFY<VMO`%9Z7VBU
M860`2F%Z>6L`3&%O<P!0;W-L961NX2!P;VQO=FEC80!0;W-L961NX2!Z;65N
M82!H97-L80!0;W-L961NX2"Y='9RNP!0;W-L961NX2!A:W1U86QI>N%C:6$Z
M`%!O<VQE9&[I('!R:6ALX7-E;FEE.B`E<P!0;W-L961NZ2!P<FEH;.%S96YI
M93H@)7,@>B`E<P!0;W-L961NZ2!P<FEH;.%S96YI93H@;FEK9'D`3&]T>;ES
M:V\`4'+A=F\`5GIHM6%D`$YE8VAA:G1E('!RX7ID;F4@<')E(+YI861E;B!O
M:W)A:@!,:6)A;F]N`%:U879O`$AL879IZ&MA(':U879O`$AO9&YO='D@=K5A
M=F\`3&5S;W1H;P#:<F]V9?(`3&EBZ7)I80!,[6)Y80!,:6-H=&5NN71A:FYS
M:V\`I6%H:^D@;7)H;VQE;FEE`*5A:&O](&3AON\`4N%N;R"U86AK_2!DX;[O
M`$YE<VOT<B"U86AK_2!DX;[O`*5A:&OI(&1AON]O=ND@<')E:.%N:WD`I6%H
M:_T@9.&^[R!S(&AR;65N[6T`I6%H:^D@<VYEOF5N:64`I6%H:^D@<VYE:&]V
MZ2!P<F5HX6YK>0!,:6UE<FEC:P!,:6YK80!,:6YK82!U:V%Z=6IE(&YA.@!0
M<F5P;VIINR!E+6UA:6QO=OH@861R97-U('-O('-T<N%N:V]U(&YA('#M<V%N
M:64@<&^Y='D`3&EN:WD`3&EN=7@@0V]O:VEE`%IO>FYA;2`M('!O=;[M=F%T
M9;4@=79I9.T@<')I9>AI;F]K`%9Y<.US8;L@>F]Z;F%M(&1A=&%BX7H`6F]Z
M;F%M('3I;2!0;VUO8V[M:V$`5GEP[7-ANR!Z;WIN86T@=&%B=6QI96L`3&ES
M="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0
M;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`6F]B<F%Z96YI
M92!S961E;NT@>FQY:&%L;SH@)7,`6F]B<F%Z96YI92!P;W6^[79A=&6U;W8@
M>FQY:&%L;SH@)7,`6F]B<F%Z;W9A;FEE('IO>FYA;74@<&]UONUV871EM6]V
M(&IE('IA:^%Z86[I+@!,:71E<F%T^G)A`$QI='9A`$YAZ.UT879A('-A+BXN
M`$UI97-T;GD@Z&%S.B``3&]K86QI>N%C:6$@82#H87,`3&]K86QI=&$`4')I
M:&SA<V5N:64`6N%Z;F%M>2!P<F5D8VCA9'IA:OIC96H@<WEN8VAR;VYI>N%C
M:64`3V1H;.%S:;L`4')I:&SA<V5N:64`VFQO:'D@<')I('!R:6ALX7-E;NT`
M4')I:&SA<V5N:64@>FQY:&%L;RP@<')E=&^^92!S=&4@>F%D86QI(&YE<W!R
MX79N92!P;W6^[79A=&6U<VOI(&UE;F\@86QE8F\@:&5S;&\N`%!R:6ALX7-E
M;FEE('IL>6AA;&\N`$1L:/T@=&5X=`!,X7-K80!.[7IK80!-86SI(&=RZ6-K
M92!P[7-M96[A`$UA;.D@;&%T:6YS:^D@<.US;65NX0!-86SI('+M;7-K92#H
M[7-L:6-E`$QU>&5M8G5R<VMO`$U-`%-P<N%V82!D\F$`4'+M;&]H82!-4RU4
M3D5&(&YE;V)S86AO=F%L82"^:6%D;F4@^F1A:F4N`$U31P!-86-A;P!-86-E
M9/-N<VMO`$UA9&%G87-K87(`3>%G:6$`4&^Y=&$`4&]S;&&[(&4M;6%I;"!A
M9&UI;FES='+A=&]R;W9I`%9Y='9O<FF[(&QI;E]K=2XN+@!-86QA=VD`36%L
M86IZ:6$`36%L961I=GD`36%L:0!-86QT80!3<')A=F]V8;L@>F]Z;F%M(&MA
M=&5G\W)I[2P@<R!K=&]R_6UI(&]Z;F'H=6IE=&4@<&]L;[YK>2!A(&9A<F)Y
M(&%S;V-I;W9A;ND@<R!T_6UI=&\@:V%T96?S<FEA;6DN`$UA<&$@36%P,C0`
M36%P82!-87!1=65S=`!-87!O=F%N:6$@=6QOOF5NZ2X`36%R96,`3VMR86H`
M3WIN8>AINR!P<NUZ;F%K;6D@4')EZ.UT86[I+TYE<')EZ.UT86[I`$]Z;F'H
M:;L@:6[];6D@<'+M>FYA:VUI("AN87!R+B!$]&QEOFETZ2]:;V1P;W9E9&%N
MZ2D`36%R<VAA;&QO=F4@;W-T<F]V>0!-87)T:6YI:P!::&]D;ND@<&]L:6$`
M36%U<F5TX6YI80!-875R[71I=7,`36%X:6WA;&YY('!O=F]L96[](&MR961I
M="X`0F]L('!R96MR;^AE;OT@;6%X:6WA;&YY('!OZ&5T(.AA<W3M('-P<N%V
M>2X`3F%J=GFYN6EA('1E<&QO=&$@>F$@<&]S;&5D;OUC:"`R-"!H;V3M;CH@
M`$YA:G9YN;EI82!T97!L;W1A('IA('!O<VQE9&[]8V@@-B!H;V3M;CH@`$UA
M>&EMX6QN>2!P;^AE="!B;&]K;W8@<&]R=.%L=0!-87AI;>%L;F$@9.6^:V$`
M3>%J`$UA>6]T=&4`365D:6/M;F$`R&QE;F]V:6$`6F]B<F%Z96YI92!M96YU
M.@!:;/KH:;L@8G5N:WD`4W!RX79A`%-P<N%V82!B;VQA(/IS<&6Y;F4@;W9E
M<F5NX2P@86QE(&-E<G1I9FEKX70@<&]D<&ES=2!S82!N97!O9&%R:6QO(&]V
M97)INRX`4&QA=&YO<[L@<W!RX79Y('9Y<'*Y86QA+@!4>7`@<W!RX79Y`%!O
MZ&%S:64@365T87(`VF1A:F4@365T87(@;FEE('/Z(&1O<W1U<&[I+@#:9&%J
M92!-971A<B!N:64@<_H@:R!D:7-P;WKM8VEI+B!$971A:6QY(&)O;&D@>F%Z
M;F%M96YA;ND@<')E(&%D;6EN:7-T<N%T;W)A+@!3>7-TZ6T@365T87)$0B!N
M:64@:F4@<')I<&]J96[]+@!-973S9&$`365T\V1A("(E<R(@;FEE(&IE(&1E
M9FEN;W9A;N$`3F5D969I;F]V86[A(&UE=/-D82X@5F]L86[I('H@;65T\V1Y
M.B`E<P!-971R:6-KZ0!-97AI8V\`36EK<F]NZ7IS:V4@9F5D97)A=.UV;F4@
MN73A='D`4W1R960`5'EP($UI;64`3F%J;FF^N6EA('1E<&QO=&$@>F$@<&]S
M;&5D;OUC:"`R-"!H;V3M;CH@`$YA:FYIOKEI82!T97!L;W1A('IA('!O<VQE
M9&[]8V@@-B!H;V3M;CH@`$UI;FEMX6QN82!D;V)A('!L871N;W-T:2!H97-L
M82!EN71E(&YE=GEP<KEA;&$`6G)K861L;W9O(&]B<N%T:;L`4O1Z;F4`0VC]
M8F$@8F%L[6L@4$5!4B!(5%107U)E<75E<W0N`$-H_6)A(&MO;F9I9W5RX6-I
M82X@06L@8VAC971E('!O=;[M=F&[('3Z=&\@87!L:6OA8VEU+"!M=7/M=&4@
M=&5R87H@=GEG96YE<F]V8;L@:V]N9FEG=7+A8VEU+@!#:/UB82!)1"!S<'+A
M=GDN`$-H_6)A('!OOF%D;W9A;OT@4$5!4B!B86SM:R!-86EL+@!#:/UB82!)
M1"!R96SA8VEE+@!0;VX`36]B:6QN_2!M86EL`$UI97)N>0!$X71U;2!P;W-L
M961N96H@>FUE;GD`57!R879INR!54DP`36]D=6QU<P!-;VQD879S:V\`36]N
M86MO`$UO;F=O;'-K;P!-97-I86,@82!R;VL`365S8>AN90!-;VYT<V5R<F%T
M`$UE<V'H;ND@9N%Z>0!.82!R:6%D:W4@)60@8F]L;R!NX6ID96[]8V@@=FEA
M8R!P;VSM(&%K;R!OZ&%KX79A;OUC:"`E9"X`36%R;VMO`%!R979AOFYE(&IA
M<VYO`%!R979AOFYE(&]B;&'H;F\`4')E=F&^;F4@<VQN9>AN;P!0<F5S=6[Z
MNR!D;VQU`%!R97-U;OJ[(':U879O`%!R97-U;OJ[('9P<F%V;P!0<F5S=6[Z
MNR!H;W)E`%!R97-U;OJ[(&1O;'4`4')E<W5N^KL@:&]R90!-;WIA8FUI:P!6
M:6%C^G)O=O)O=ND@=GEB97)A8VEE('IO>FYA;7D`5FEA8V[A<V]B;OT@=OUB
M97(`36]J92!K;VYT;P!);F9O<FWA8VEE(&\@;6]J;VT@^NAT90!-]&H@<&]R
M=.%L`%9Z:+5A9"!M]&IH;R!P;W)TX6QU`$UY86YM87(`3FEE+"!.15/:2$Q!
M4\U-+@!-96YO`$YA;>UB:6$`3F%U<G4`3F5PX6P`2&]L86YD<VMO`$AO;&%N
M9'-KZ2!!;G1I;'D`6N%K;&%D;N$@55),($YE='-C87!E`%523"!P<F4@>FYE
M<&QA=&YE;FEE(&-E<G1I9FEKX71O=B!#02!.971S8V%P90!54DP@<')E('!O
M;&ET:6MU($-!($YE='-C87!E`%523"!P<F4@;V)N;W9E;FEE('!L871N;W-T
M:2!C97)T:69I:^%T;W8@3F5T<V-A<&4`55),('!R92!Z;F5P;&%T;F5N:64@
M8V5R=&EF:6OA=&]V($YE='-C87!E`$UE;F\@4U-,('-E<G9E<F$@3F5T<V-A
M<&4`2V]M96YTX7(@8V5R=&EF:6OA='4@3F5T<V-A<&4`5'EP(&-E<G1I9FEK
MX71U($YE='-C87!E`%-I9;L`3FEK9'D`3F]VX2!+86QE9/-N:6$`3F]VX2!K
M871E9_-R:6$`3F]VX2!S<'+A=F$@<')E("5S`$YO=@!.;W;I('!O=;[M=F%T
M9;5S:^D@;65N;R`H;F5P;W9I;F[I*0!.;W;](%KI;&%N9`!.;W;I(&AE<VQO
M`%!L871N;W.[(&YO=NEH;R!H97-L82!V>7!RN>T@)7@N`$YO=ND@:&5S;.$@
M;FEE('/Z(')O=FYA:^DN`$YO=ND@;VMN;R`H7V)L86YK*0!.97=S`$1I<VMU
M<V[I('-K=7!I;GD`SV%L96H`3F%S;&5D=6KZ8V4@-"!FX7IY`,]A;+EI92!N
M87-T879E;FEA`$YA<VQE9'5J^F-A/@!.:6MA<F%G=6$`3FEG97(`3FEGZ7)I
M80!.;V,`3FEU90!.:64`3FEE('/Z(&1O<W1U<&[I(+YI861N92!K;VYF:6=U
M<F'H;ND@^F1A:F4L('!R92!K=&]RZ2!B>2!S82!D86QI('IO8G)A>FF[(')O
M>F1I96QY+@!0<F4@=GET=N%R86YI92!)4T\@;V)R87IO=B!N:64@:F4@:R!D
M:7-P;WKM8VEI(+YI861N82!S=')A=.EG:6$N`$YE97AI<W1U:F4@N6%B;/-N
M82!P<F4@9.%V:W4N`$YA('!OOF%D;W9A;F5J('!O>NUC:6D@;F5E>&ES='5J
M92"^:6%D96X@8FQO:RX`4')E($U#04P@875T96YT:69I:^%C:74@;F5B;VQO
M('IA9&%NZ2!M96YO(&MA;&5N9.%R82X`KFEA9&YA('IM96YA+@!+('1O;75T
M;R!P<N%V=2!N96UOOFYO('!R:61ANR"^:6%D;F4@<&]D<FEA9&5NZ2!P<N%V
M82X`4')E("5S(&YE8F]L82!U<NAE;N$@:V]N9FEG=7+A8VEA+@!0<F4@1E10
M(%9&4R!N96)O;&$@=7+H96[A(&MO;F9I9W5RX6-I82X`4')E(%-13"!61E,@
M;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`%!R92!344PM1FEL92!61E,@
M;F5B;VQA('5RZ&5NX2!K;VYF:6=U<N%C:6$N`*YI861E;B!K<F5D:70N`$YE
M8F]L;R"Y<&5C:69I:V]V86[I(&UI97-T;R!U<NAE;FEA+@!3^F)O<B!N96)O
M;"!N86AR86[]+@!.96)O;&D@;N%J9&5NZ2"^:6%D;F4@:6MO;GDN`$YI92!J
M92!N87-T879E;N$@;&]K86QI=&$N`$YE8F]L82!Z861A;N$@;&]K86QI=&$N
M`$YE8F]L82!Z861A;N$@OFEA9&YA('-P<N%V82X`3F5B;VQO(+EP96-I9FEK
M;W9A;ND@OFEA9&YE(&UE;F\N`$YE8F]L;R"Y<&5C:69I:V]V86[I(.CM<VQO
M+@"N:6%D;F4@=7+AOFQI=ND@9F]R='5N>0!0<F4@2%144"!A=71E;G1I9FEK
MX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@24U!4"!A=71E;G1I9FEK
MX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!0<F4@2V5R8F5R;W,@875T96YT
M:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E($QO9VEN(&%U=&5N
M=&EF:6OA8VEU(&YE8F]L;R!Z861A;ND@:&5S;&\N`%!R92!005-35T0@875T
M96YT:69I:^%C:74@;F5B;VQO('IA9&%NZ2!H97-L;RX`4')E(%--0B!A=71E
M;G1I9FEKX6-I=2!N96)O;&\@>F%D86[I(&AE<VQO+@!.96)O;&$@>F%D86[A
M(&-E<W1A(&L@<')O9W)A;74@3W!E;E-33"X@4')O9W)A;2!/<&5N4U-,(&IE
M('!O=')E8F[](&YA('!RX6-U(',@^F1A:FUI(%!+0U,@,3(N`*YI861N92!P
M<F5B:65H86KZ8V4@<')I:&SA<V5N:6$N`$MV\W1A(&YI92!J92!N87-T879E
M;N$N`$)E>B#H:6%R`$YE8F]L(+EP96-I9FEK;W9A;OT@;V1D9;5O=F'H+@!"
M97H@<W1RX6X`4_IB;W(@;F5NX6ID96[]`%!R92!V>7)O=F[A=F%C:74@<&%M
MY+L@;FEE(&IE(&1O<W1U<&[](+YI861E;B!D;^AA<V[]('!R:67H:6YO:RX`
M3F5B;VQO(&]D;W-L86[I('!O=;[M=F%T9;5S:^D@;65N;R!A+V%L96)O(&AE
M<VQO+@!.96)O;&D@=G+A=&5NZ2!P;&%T;ND@6$U,(/ID86IE`*YI861N92!H
M;V1N;W1Y`%8@</1V;V1N96H@:V]N9FEG=7+A8VEI(&YE8F]L82!NX6ID96[A
M(+YI861N82!V97)Z:6$N(%9Y9V5N97)U:G1E('IN;W9U(&MO;F9I9W5RX6-I
M=2X`5B!K;VYF:6=U<N%C:6D@;F5B;VQA(&[A:F1E;N$@OFEA9&YA('9E<GII
M82X@5GEG96YE<G5J=&4@>FYO=G4@:V]N9FEG=7+A8VEU+@"N:6%D96X`KFEA
M9&YE("AP;W6^:;L@:6UP;&EC:71N^B!H;V1N;W1U*0!/<W1R;W8@3F]R9F]L
M:P!3979E<F[A('!O;&]G=;5A`%-E=F5R;ND@36%R:>%N<VME(&]S=')O=GD`
M3O-R<VMO`$YE<&QA=.T@<&\`3F5P;&%T[2!P<F5D`$YI92!J92!A9')E<^%R
M`$YI92!J92!I;7!L96UE;G1O=F%NZ2X`3F5N87-T879E;ND`3FEE(&IE('!O
M9'!O<F]V86[I+@!0;WINX6UK>0!.:>@@;F$@<')E>F5R86YI92P@=G+ANW1E
M('-A('-PY+LN`$YO=F5M8F5R`,CM<VQO`%!OZ&5T('IN86MO=@!0;^AE="!S
M=.5P8V]V`%!OZ&5T(')I861K;W8`4')E(&%K='5A;&EZX6-I=2!Z;WIN86UU
M('!R[6IE;6-O=B!N96)O;&D@N7!E8VEF:6MO=F%NZ2#H[7-L82X`3TL`3V)J
M96MT`$%U=&]R(&]B:F5K='4`3W-M:>AK;W;]`$]K=/-B97(`1FEL=&5R(&YA
M(&YA9.%V:WD`4')A8V]V:7-K;P!3=&%RZ2!A(&YO=ND@:&5S;&\@;75S:6$@
M8GF[(&]D;&FY;NDN`%-T87+I(&AE<VQO`%-T87+I(&AE<VQO(&YE8F]L;R!Z
M861A;ND@<W!RX79N92X`3VWA;@!)8F$@24U!4"!S97)V97)Y('!O9'!O<G5J
M^B!Z9&EEM6%NZ2!P<FEEZ&EN:WDN`$EB82!U<N&^;&EVZ2!F;W)T=6YY`$IE
M('!R[7!U<W1NX2!I8F$@:F5D;F$@92UM86EL;W;A(&%D<F5S82X`5FQA<W1N
M[6MA(&%L96)O('!RX79A('9L87-T;NUK82!P<F4@>F1I9;5A;OT@;V)J96MT
M(&WTOF4@>FUE;FF[(&EB82!V;&%S=&[M:R!A;&5B;R!S>7-TZ6UO=OT@861M
M:6YI<W1RX71O<@!/='9O<FF[('8@;F]V;VT@;VMN90!#:'EB82!/<&5N4U-,
M.B!N97!O9&%R:6QO('-A('KM<VMANR#Z9&%J92!Z('!O9'#M<V%N96H@Z&%S
M=&D@4R]-24U%+@!/='9O<FF[('3Z=&\@;&EN:W4@=B!N;W9O;2!O:VYE`$]P
M97)AZ&[]('-Y<W3I;0!.87-T879E;FEA`$YA<W1A=F5N:6$@)7,`6F]R861E
M;OT@>F]Z;F%M`$]R9V%N:7KA8VEA`$]R9V%N:7IAZ&[A(&IE9&YO=&MA`$]R
M9V%N:7IO=F%N:64`4/1V;V1NX2"Y86)L\VYA(&%P;&EKX6-I90!0]'9O9&[I
M(+EA8FSS;GD@=B`E<SH`26[I`,]A;+EI92!I;F9O<FWA8VEE`%!RX79A('9L
M87-T;NUK80!004T@875T96YT:69I:^%C:6$@;FEE(&IE(&1O<W1U<&[A+@!0
M14%2.DUA:6P@8F%C:V5N9`!$:6=I=.%L;GD@<&]D<&ES(%!'4`#:9&%J92!Z
M8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!01U`@=F5R96IN_2!KM?KH`-ID86IE
M('!O9'#M<V%NZ2]Z8;EI9G)O=F%NZ2!P;VUO8V]U(%!'4`!02%`@:_-D`%!(
M4"!3:&5L;`!0;W!O;'5D;NT@M6%H:_T@9.&^[P!0;W!O;'5D;NT@<')E:.%N
M:WD`4&]P;VQU9&[M('-N9;YE;FEE`%!O<&]L=61N[2!S;F5H;W;I('!R96CA
M;FMY`%!O<&]L=61N[2!S;F6^96YI90!0;W!O;'5D;NT@8OIR:WD`0VC]8F$@
M<F]ZN>UR96YI92!03U-)6`!07TA0(%-H96QL`%9Y<&QN96YI90!086MI<W1A
M;@!086QA=7-KZ2!O<W1R;W9Y`%!A;&5S=.UN<VME(/IZ96UI90!086YA;6$`
M4&%P=6$@3F]VX2!'=6EN96$`4&%R86=U87D`R&EA<W1OZ&YE(&]B;&'H;F\`
M2&5S;&\`2&5S;&\@8F]L;R#Z<W!EN6YE('IM96YE;NDN`$YE<W!RX79N92!H
M97-L;P!0<F4@875T96YT:69I:^%C:74@4D%$2553(&IE('9YOF%D;W9A;ND@
M:&5S;&\N`$AE<VQO(',@<&]T=G)D96[M;0!(97-L;SH`2&5S;&\Z(`!(97-L
MX2!M=7-I82!B>;L@<F]V;F%KZ2X`5FQOOFF[`%9L;[YINR!Z;R!S8VARX6YK
M>0!#97-T80!0<F5B:65H86KZ8V4@<F5G:7-T<N%C:64Z`*5U9&EA`%!E<F-E
M;G0`5GEK;VYANR!O<&5RX6-I92#Z9'*^8GD`5GEK;VYANR!O<&5RX6-I92#Z
M9'*^8GD@<')I('!R:6ALX7-E;NT_`%!RX79O`%!RX79O("(E<R(@;F5B;VQO
M('9Y;6%Z86[I+@!0<NUS='5P('IA;6EE=&YU=/T`4'+A=F$`061M:6YI<W1R
MX6-I82!P<N%V`$]S;V)NZ2!I;F9O<FWA8VEE`%!E<G4`1&]MX6-E('IV:65R
M873A`$9I;&EP[6YY`%1E;&5F\VX`1F]T;V=R869I90!0:71C86ER;@!";V1O
M=@!+;&EK;FET92!P<F]S[6T@9&\@;F5J86ME:B!B=6YK>0!0;W1V<N]T92!P
M<F]S[6TL(+YE(&-H8V5T92!O9'-T<N%N:;L@=&5N=&\@96QE;65N=#H`4&]T
M=G+O=&4@<')O<^UM+""^92!C:&-E=&4@;V1S='+A;FF[(&QI;FMU('H@=&]H
M=&\@96QE;65N='4N`%IA9&%J=&4@<')O<^UM(&UE<VEA8R!A(')O:RX`6F%D
M86IT92!P<F]S[6T@;65N;R!P<F4@;F]V^B!K871E9_-R:74Z`%IA9&%J=&4@
M<')O<^UM('!L871N^B!)4"!A9')E<W4N`%IA9&%J=&4@<')O<^UM('!L871N
M_2!DX71U;2P@<VMO;G1R;VQU:G1E('!OZ&5T(&1N[2!V(&UE<VEA8VDN`%IA
M9&%J=&4@<')O<^UM('!L871N_2#H87,N`%!R;W/M;2!U=F7O=&4@>FAR;G5T
M:64@<')O8FSI;74N`%!R;W/M;2!Z861A:G1E('-V;VIE('!O=;[M=F%T9;5S
M:^D@;65N;R!A(&AE<VQO`%!R9>CM=&%J=&4@<VD@<')O<^UM(&YA<VQE9'5J
M^F-I('1E>'0N($U54\U412!S^FAL87-INR!S('!O9&UI96YK86UI('!O=;[M
M=F%N:6$@<WES=.EM=2X`6F%D86IT92!P<F]S[6T@;65N;R!P<F4@;F]V^B!K
M871E9_-R:74Z`%!OM7-K;P!0;VQI=&EK80!!;FME='D`4&]R='5G86QS:V\`
M56UI97-T;F5N:64@=&]H=&\@;V)RX7IK=0!5;6EE<W1N96YI92!T96IT;R!T
M86)UM6MY`$]D;W-L8;L@9&\@=&]H=&\@<')I9>AI;FMA("AN979Y;G5C=6IE
M($E-05`I`%IRX;YK>2!Z82!P;W-L961N_6-H("5S(&AO9.UN.B``4')A=F1E
M<&]D;V)N;W.[/&)R("\^>G+AOF]K`%!R969S7VQD87`Z('!OOF%D;W9A;ND@
M<F]ZN>UR96YI92!,1$%0(&YE8F]L;R!NX6ID96[I+@!0<F5F<U]S97-S:6]N
M.B!P;[YA9&]V86[I(')O>KGM<F5N:64@<V5S<VEO;B!N96)O;&\@;N%J9&5N
MZ2X`5&QA:P!4;&%K(&YA(/IR;W9N:2!M;W)A.B``5&QA:SH@`%5KX;YK80!:
M;V)R87IINR!U:^&^:W4@;V)RX7IK=2!V(&YO=F]M(&]K;F4`4')E9&-HX61Z
M86KZ8V4@;F%S=&%V96YI80!6>71L8>AINR!D;VMU;65N=`!0<FEVX71N>2!K
MM?KH`%!R;V)LZ6T`4&]P:7,@<')O8FSI;74`4')O:F5K='D`5OUZ=F$@;F$@
M>F%D86YI92!T97AT=0!697)E:F[](&NU^N@`06QG;W)I=&UU<R!V97)E:F[I
M:&\@:[7ZZ&$`26YF;W)MX6-I92!O('9E<F5J;F]M(&NU^NAI`%9E<F5J;OTO
M<')I=N%T;GD@:[7ZZ&]V_2!PX7(@;F5B;VP@^G-P9;EN92!V>6=E;F5R;W9A
M;OTN`%!O<G1O<FEK;P!+871A<@!$;W1A>@!+=O-T80!24T$@=F5R96IN_2!K
MM?KH("@E9"!B:71O=BD`4')E<.UN8>@@<R!V_6)E<F]M`$3AON\`4N%N;R!D
MX;[O`$YE<VOT<B!DX;[O`$1AON]O=ND@<')E:.%N:WD`1.&^[R!S;R!S;F5H
M;VT`1.&^[R!P<F5C:.%D>F%J^F-I('8@<VYEOF5N:64`3N%H;V1NX2!F;W)T
M=6YA`%!O;65R`,CM=&&[`,CM=&&[('-P<N%V>0!.86]Z86H@=GEM87IANR`E
M<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO('9RX71INR!S<.2[+@!.86]Z86H@
M=GEM87IANR!P;W6^[79A=&6U<VOI(/ID86IE('!R92!P;W6^[79A=&6U82`E
M<S\@5/IT;R!O<&5RX6-I=2!N96UOOFYO('9RX71INR!S<.2[+@!6<N%T:2!S
M<.2[(%9AN74@<&]S;&5D;OH@86MC:74`3V)N;W9INP!/8FYO=FF[(&5L96UE
M;G1Y(&1Y;F%M:6-KZ6AO(&UE;G4Z`$]B;F]V:;L@>F]B<F%Z96YI92!P;W)T
MX6QU.@!296=U;.%R;GD@=OUR87H`4')E:&QI861AZ"!V>KMA:&]V`%IN;W9U
M(&YAZ.UT8;L`4&]S=')E:'D`5GID:6%L96[I('-E<G9E<GD`5GID:6%L96[A
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1RX6YI
MNP!/9'-T<N%N:;L@8FQO:P!/9'-T<N%N:;L@<W3E<&5C`$]D<W1RX6YINR!F
M;W)MX71O=F%N:64`3V1S='+A;FF[('#A<@!/9'-T<N%N:;L@=6QOOF5N_2!S
M:W)I<'0@>B!D;^AA<V[I:&\@<')I9>AI;FMA(&YA('-E<G9E<FDN`$]D<W1R
MX6YINP!/9'-T<N%N:;L@=&5N=&\@8F]D('H@9&]K=6UE;G1U`$]D<W1RX6YI
MNR!P;W6^[79A=&6U80!/9'-T<N%N:;L@<&]UONUV871EM6$Z("5S`$YA('!O
MOFEA9&%V:W4@;F5B;VQO(&UOOF[I(&]D<&]V961ANRX@3N%V<F%T;W;](&OS
M9"!C:'EB>3H@`%!OOF%D;W9A;OH@<VQUOF)U('-A(&YE<&]D87)I;&\@;N%J
M<[LN`%8@:V]N9FEG=7+A8VEI("5S(&YI92!J92"Y<&5C:69I:V]V86[A('!O
MOF%D;W9A;N$@<&]L;[YK82`B)7,B`%8@:V]N9FEG=7+A8VEI(%9&4R!N:64@
M:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V86[A('!O;&^^:V$@(B5S(@!6(&MO
M;F9I9W5RX6-I:2!N:64@:F4@N7!E8VEF:6MO=F%NX2!P;[YA9&]V86[A('!O
M;&^^:V$@(B5S(@!0;W9I;F[I('!O;&4`5GEM87IANR!F;W)M=6SA<@!/8FYO
M=FF[(&AE<VQO`$]B;F]V:;L@5F&Y92!H97-L;P!/8FYO=FF[('!O<VQE9&[]
M(&1O=&%Z`%;]<VQE9&MY`$[A=G)A="!N82!N87-T879E;FEA`%IA9&%J=&4@
M;F]VZ2!H97-L;P!2975N:6]N`%9RX71INR!K;VYF:6=U<N%C:74`3F%S=&%V
M96YI82!R;WJY[7)E;NEH;R!T97AT;W;I:&\@961I=&]R=0!(X61A;FMY`%9P
M<F%V;P!(;&%V:>AK82!V<')A=F\`2&]D;F]T>2!V<')A=F\`5FQA<W1N;W-T
M:2!?<FEA9&MA+BXN`%)O;&$`4G5M=6YS:V\`3W1OZ&F[(&\@,3@P`$]T;^AI
MNR!VM6%V;P!/=&_H:;L@=G!R879O`%9L87-T;F]S=&D@<FEA9&MA`%9L87-T
M;F]S=&D@<FEA9&MA`%)I861K>3H`R&EA<GD`R&EA<GD@<V$@>F]B<F%Z:6$@
M;65D>FD@=KEE=&O];6D@<FEA9&MA;6D@82!S=.5P8V%M:0#(:6%R>2!S82!Z
M;V)R87II82!I8F$@;65D>FD@<W3E<&-A;6D`R&EA<GD@<V$@>F]B<F%Z:6$@
M:6)A(&UE9'II(')I861K86UI`%-P=7-T:;L`4G5S:^$@9F5D97+A8VEA`%)W
M86YD80!3+TU)344@:W)Y<'1O9W)A9FEC:_T@<&]D<&ES`%-P<N%V82!Z8;EI
M9G)O=F%NX2!P;VUO8V]U(%,O34E-10!305-,(&%U=&5N=&EF:6OA8VEA(&YI
M92!J92!D;W-T=7!NX2X`4&]S:65L86YI92!335,`4U%,(%-H96QL`%-13"!P
M<NUK87H@<')E(&BU861A;FEE(&AO9&[T=`!34T@`VE-014-(`%-?44P@4VAE
M;&P`4V\`4W;D=.$@2&5L96YA`%-VY'3]($MI='1S(&$@3F5V:7,`4W;D=.$@
M3'5C:6$`4W8N(%!I97)R92!A($UI<75E;&]N`%-VY'3](%9I;F-E;G0@82!'
M<F5N861I;GD`5&5N(&ES=/T@<N%M96,@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&$@4')I;F-I<&4`4V%T96QI=&[]('!O<VMY=&]V871E
MM0!3875D<VOA($%RX6)I80!5;&^^:;L`56QOOFF[("(E<R(`56QOOFF[("5S
M`%5L;[YINR!N87-T879E;FEA`%5L;[YINR!V>6=E;F5R;W9A;OH@:V]N9FEG
M=7+A8VEU(&%K;R!02%`@<VMR:7!T(&1O(&1OZ&%S;NEH;R!P<FEEZ&EN:V$@
M5N&Y:&\@<V5R=F5R82X`2V]N9FEG=7+A8VEA("5S(&)O;&$@=6QOOF5NX2X`
M4VMR:7!T(&YA('5P9W)A9&4@;F%S=&%V96[M(&)O;"!U;&^^96[](&1O.B`B
M)7,B+@!/:F5D:6YE;.D@8OIR:WD`5F5D80!(M6%D8;L`5GEHM6%DX79AZ&4`
M5GEB97)T92!S^F)O<GD`5GEB97)T92!DX71U;0!6>6)E<G1E('-K=7!I;G4@
M;F$@<')I9&%N:64`5GEB97)T92!N;W;I:&\@=FQA<W1N[6MA`%9Y8F5R=&4@
M<V5R=F5R`%9Y8F5R=&4@<&]UONUV871EM6$@;F$@<')I9&%N:64`5GEB97)T
M92!VN65T:WD`5GEB97)T92!VN65T:WD@:V]M<&]N96YT>2!DX71U;74`5GEB
M97)T92!O8FIE:W0`6G)UN6F[(';]8F5R`%9Y8F5R=&4@>FYA:WDL(&MT;W+I
M('!O=')E8G5J971E+"!Z(&]K:65N;VL@;FF^N6EE+B!0;W1O;2!I8V@@;?2^
M971E('-K;W#M<F]V8;L@82!V;&^^:;L@>B!T97AT;W;I:&\@<&^U82X`5GEB
M97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T92!DX71U;74Z`%9Y8F5R=&4@9F]R
M;>%T(&3A='5M=3H`5GEB97)T92!I9&5N=&ET=2P@:W1O<OH@8VAC971E('IM
M96YINSH`5GEB97)T92!O9&1EM6]V8>@@=F\@9F]R;>%T92#H87-U.@!6>6)E
M<G1E(&9O<FWA="#H87-U.@!6>6)E<G1E(&1V92!Z:&]D;ND@<&]L:6$N`%9Y
M8F5R=&4@<VD@9F%R96)N^B!S8VCI;74`5GEB97)T92!J87IY:SH`4&]S;&&[
M('-P<N%V=2!O('!R;V)LZ6UE`%!O<VQANR!335,`4V5N96=A;`!396YZ;W(Z
M(`!397!T96UB97(`4W)B<VMO(&$@R&EE<FYA(&AO<F$`4^ER:6]VZ2#H[7-L
M;P#:9&%J92!Z;R!S97)V97)A('/Z(&YE<W!RX79N92!A;&5B;R!N:64@<_H@
M9&]S='5P;NDN`$%D;6EN:7-T<N%C:6$@<V5D96[M`%!L871N;W.[($E$('-E
M9&5N:6$@=GEP<KEA;&$N`%-E9&5N:6$`36YOOFEN82!H;V1N]'0`3F%S=&%V
M=&4@;6^^;F]S=&D@;F$@;V)N;W9E;FEE(%;AN6AO(&AE<VQA(&%K(&AO('IA
M8G5D;F5T92X`3F%S=&%V96YI92!V>F1I86QE;OUC:"!S97)V97)O=BP@:W4@
M:W1O<OUM(&-H8V5T92!P<FES='5P;W9ANR!Z(%;AN6AO('!O<G3A;'4N`%9Y
M8F5R=&4@:F%Z>6LL(.AA<V]V^B!Z\VYU(&$@;F%S=&%V96YI82!DX71U;74N
M`$YA<W1A=F5N:64@87!L:6OA8VEE('-P^KF[86YE:B!P<FD@N71A<G1E+"!F
M87)E8FYE:B!S8VCI;7DL(&EN=&5R=F%L=2!O8FYO=F]V86YI82!S='+A;FMY
M(&$@:6[]8V@@=FQA<W1N;W-T[2!Z;V)R87IE;FEA+@!.87-T879E;FEE`%/Z
M(&1O<W1U<&[I('-K<FEP='D@;F$@=7!G<F%D92!N87-T879E;NT`1&\@^G9A
M:'D@<')I8VCA9'IA(&YI96MOM6MO(&QO:V%L[70@<&]M;V-O=2!P87)A;65T
M<F$Z(`!397EC:&5L>0!3:&]P<&EN9P!+<N%T:WD@<_IH<FX`36%J^B!S82!P
M<F4@=N3HN6EN=2!L:6YI96L@=GET=F]R:;L@<VMR871K;W;I(&MLX79E<WD_
M`%IO8G)A>FF[`%IO8G)A>FF[(')O>F1I96QY(&UE9'II('!RX79E('5L;[YE
M;F]U(&$@;F]V;W9Y9V5N97)O=F%N;W4@:V]N9FEG=7+A8VEO=2X`3>$@<V$@
M<')I('!R:6ALX7-E;NT@>F]B<F%Z:;L@Z&%S('!O<VQE9&[I:&\@<')I:&SA
M<V5N:6$_`%IO8G)A>FF[(&UOOFYO<[L@;F$@<&]N96-H86YI92!O<FEG:6[A
M;'4`6F]B<F%Z:;L@;N%S=')O:B!N82!V_6)E<B!F87)I96(`6F]B<F%Z:;L@
M;65N=2!P<F4@;W!E<N%C:64@<R!T86)UM6MA;6D_`%IO8G)A>FF[(&UE;G4@
M)7,@;F$@M6%V96H@<W1R86YE/P!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO
M<[MA;6D@8G5N:WD@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO
M<[MA;6D@=&%B=;5K>0!:;V)R87IINR!D:6%L\V<@<R!V;&%S=&YO<[MA;6D@
M<FEA9&MU('1A8G6U:WD`6F]B<F%Z:;L@9&EA;/-G(',@=FQA<W1N;W.[86UI
M(&]B<N%Z:W4`6F]B<F%Z:;L@;F%H<F%NZ0!0<F5HX6YK>0!2X6YO('!R96CA
M;FMY`$YE<VOT<B!P<F5HX6YK>0!:<N&^:WD@=B!O:V]L[0!:;65NN6F[`$YA
M:G!R=B!M=7/M=&4@>FUE;KEINR!A;&5B;R!P<F5S=6[ZNR!S=7-E9&[](&)L
M;VLH>2D`4VEE<G)A($QE;VYE`%IA<F5G:7-T<F]V8;L@<V$`4&]D<&ES`$%L
M9V]R:71M=7,@<&]D<&ES=0!3:6YG87!U<@!69;5K;W.[`%!R97-K;^AINR#Z
M9'*^8G4`4VQO=F5N<VMO`%-L;W9I;G-K;P!3;F6^96YI90!3;F5H;W;A('!R
M96CA;FMA`%-N96AO=ND@<')E:.%N:WD`4N%N;R!S;F5H;W;I('!R96CA;FMY
M`$YE<VOT<B!S;F5H;W;I('!R96CA;FMY`$CE8FMA('-N96AU.B``36YOOG-T
M=F\@=F]D>2!E:W9I=F%L96YT;ND@<VYE:'4Z(`"I86QA;?IN;W9E(&]S=')O
M=GD`4V]MX6QS:V\`4&EE<VYE(&$@8N%S;F4`5OUB97(@<VUE<G4@=')I961E
M;FEA`%ID<F]J;W;A(&%D<F5S80!*=;YNX2!!9G)I:V$`2G6^;N$@1V5O<F=I
M82!A(%-O=71H(%-A;F1W:6-H($ES;&%N9',`2G6^;N$@<&]L;V=UM6$`365D
M>F5R82!M961Z:2!S=7-E9&[];6D@8G5N:V%M:0!-961Z97)A(&UE9'II(&]B
M<V%H;VT@82!O:W)A:F]M(&)U;FMY`$]D9&6U;W9AZ`!/9'-T=7``3V1S='5P
M(&$@=GEP;&YE;FEE`*EP86YI96QS:V\`4W!A;0!6;&^^96YI92"Y<&5C:>%L
M;GEC:"!Z;F%K;W8`4F]Z9&5L:;L@8G5N:W4`4F]Z9&5L:;L@<W3E<&5C`%)O
M>F1E;&F[(')I861O:P"I<&]R='D`4W+M($QA;FMA`*ET86YD87)D;ND`4W1A
M<B!4<F5K`%!OZ&EA=&_H;OT@<F]K`*ETX70@86QE8F\@<')O=FEN8VEA`%-T
M878`1F]R;>%T('5L;[YE;FEA`$)Y9&QI<VMO`%!R9;EK<G1N=73I`%IO>FYA
M;2!R9;MA>F-O=@!/9'-T<N%N:;L@9&]MZ6YU('H@861R97-Y`*ET_6P@6T-3
M4UT`3F4`4&]D<')I9>AI;F]K("(E<R(@;F5B;VP@;N%J9&5N_2X`4')E9&UE
M=`!/9&]S;&&[`%!OOFEA9&%V:V$@;F$@<')I9&%N:64@(B5S(B!D;R!S>7-T
MZ6UU(&)O;&$@;V1O<VQA;N$N($YE;?2^971E('-A('!R:6ALX7-INRP@:_UM
M(&YE8G5D92!68;EA('!OOFEA9&%V:V$@<V-H=N%L96[A+@!$;VQN_2!I;F1E
M>`#:<W!E8V@`4')I9&%N:64@(B5S(B!D;R!S>7-TZ6UU(&)O;&\@^G-P9;EN
MZ2X`5GEM87IA;FEE(/ID86IO=B!Z;R!S>7-TZ6UU('!R92!P;W6^[79A=&6U
M82`B)7,B(&)O;&\@^G-P9;ENZ2X`5GEM87IA;FEE("(E<R(@8F]L;R#Z<W!E
MN6[I+@!6>6UA>F%N:64@(B5S(B!Z;R!S>7-TZ6UU(&)O;&\@^G-P9;ENZ2X`
M3N%V<F%T(&MU(&MO;F9I9W5RX6-I:2!B;VP@^G-P9;EN_2X@4')E('IO8G)A
M>F5N:64@>FUI96X@>FYO=G4@;F'H[71A:G1E('-T<N%N:W4N`%KA;&]H82!K
M;VYF:6=U<N%C:64@8F]L82!U;&^^96[A+@!:X6QOOF[](&MO;F9I9W5R8>AN
M_2!S^F)O<B`E<R!B;VP@^G-P9;EN92!U;&^^96[]+@!!:W1U86QI>N%C:6$@
M(B5S(B!B;VQA(/IS<&6Y;N$N`%KA<&ES("5S(&)O;"#Z<W!EN6[]`%-U9.%N
M`%/Z:')N`%;]8VAO9"!S;&YK80!:X7!A9"!S;&YK80!3;&YEZ&YO`%;]8VAO
M9"!S;&YK80!6_6-H;V0O>N%P860@<VQN:V$`5OUC:&]D('-L;FMA.B``6N%P
M860@<VQN:V$`6N%P860@<VQN:V$Z(`!(;W)N_2!I;F1E>`!0;V1P;W)A`%-U
M<FEN86T`4')I97IV:7-K;P!3=F%L8F%R9"!A($IA;B!-87EE;@!3=F%Z:6IS
M:V\`J7;I9'-K;P"I=F%JZ&EA<G-K;P!:X7IN86UY(&\@<WEN8VAR;VYI>N%C
M:6D@=GEM87IA;ND`4WEN8TU,`%-Y;G1A:W1I8VOA(&-H>6)A('8@<&]D;6EE
M;FMA8V@@:+5A9&%N:6$`4_UR:6$`0OIR:V$`0OIR:V$@82!V971E<FYO`$+Z
M<FMY`%+A;F\@8OIR:WD`5%-6('/Z8F]R`%1A8G6U:V$`5FQA<W1N;W-T:2!T
M86)UM6MY`%9L87-T;F]S=&D@=&%B=;5K>0!486EW86X`5&%I=V%N+"!P<F]V
M:6YC:6$@R.UN>0!4862^:6MI<W1A;@!486YZX6YI80!#:66U.@#:;&]H>0!4
M96QE9O-N;F4@Z.US;&\`5&5P;&]T82!Z82!P;W-L961N^B!H;V1I;G4Z(`!4
M97!L;W1A`%1E<&QO=&$Z(`!497!L;W1A/&)R("\^*"5S36%X)7,O)7--:6XE
M<RD@)F1E9SLE<P"I86)L\VYA("(E<R(@;F5B;VQA(&[A:F1E;N$N`%-P<N%V
M82"Y86)L\VX`5&5X=`!)8F$@=&5X=`!:87)O=FYA;FEE('1E>'1U`%1E>'0@
M:&]R90"I=`!4:&%J<VMO`%)O>KGM<F5N:64@1E10(&YI92!J92!D;W-T=7!N
MZ2X`26YT96=RX6-I82!(;W)D92]+;VQA8B!N97!O9'!O<G5J92`B)7,B`$E-
M4U`@>N%Z;F%M('-A(&YE<&]D87)I;&\@=6QOOFF[+@!4<FEE9&$@36%I;G1E
M;F%N8V4Z.B!S82!N96YAZ.UT86QA(/IS<&6Y;F4`3VMN;R!S(&YA<W1A=F5N
M:6%M:2!S82!Z871V;W)I;&\N($MO;FEE8RX`061M:6YI<W1RX71O<B!M=7/M
M(&YA:V]N9FEG=7)O=F&[('!E<FUA;F5N=&[](&)A8VME;F0@<')E(%!RX79A
M+"!A:R!C:&-E=&4@<&]UONUV8;L@4'+A=F$N`$EB82!S<&]D;N$@<W1R86YA
M`$E$(.CM<VQO(&MO;G1A:W1U(&YE8F]L;R"Y<&5C:69I:V]V86[I+"!B;VQO
M('!O;F5C:&%NZ2!P<N%Z9&YE(&%L96)O(&YE8F]L;R!NX6ID96[I('8@9&%T
M86+A>F4N`$MO;G1A:W0@8F]L(/IS<&6Y;F4@=FQOOF5N_2!D;R!6X;EH;R!A
M9')E<^%R82X`3F$@;W9E<F5N:64@<&]D<.US86YE:B!S<'+A=GD@:F4@<&^^
M861O=F%N_2!O9&1E;&5N_2!B;&]K(',@4$=0('!O9'!I<V]M+@!)1"!Z;WIN
M86UU('!R[6IE;6-O=B!B=>\@;F5B;VQO(+EP96-I9FEK;W9A;NDL(&%L96)O
M(&)O;&\@<&]N96-H86[I('!RX7ID;F4@86QE8F\@;F5B;VQO(&[A:F1E;ND@
M=B!D871A8N%Z92X`3F5B;VP@=7+H96[]('IO>FYA;2!P<NUJ96UC;W8N`*EI
M9G)O=F%N:64@=GF^861U:F4@8F5Z<&7H;ND@<')I<&]J96YI92`H:'1T<',I
M+@!3^F)O<B`E<R!B>2!M86P@;V)S86AO=F&[(&YA<W1A=F5N:64@)7,N`%/Z
M8F]R("5S(&)Y(&UA;"!O8G-A:&]V8;L@;FEE:W1O<ND@;F%S=&%V96YI82`E
M<RX`6F1R;VIO=OT@82!C:66U;W;]('/Z8F]R(&UU<VEA(&)YNR!O9&QIN6[I
M+@!3^F)O<B!N96]B<V%H;W9A;""^:6%D;F4@^F1A:F4N`$YA<VQE9'5J^B!H
M;&%V:>AK>2!T96IT;R!S<'+A=GD@=F\@9F]R;>%T92!M97-S86=E+W)F8S@R
M,BX`0V5L;V]B<F%Z;W9K;W;](')EOFEM('-P]'-O8G5J92!P<F]B;.EM>2!V
M($EN=&5R;F5T($5X<&QO<F5R:2!K=O1L:2!C:'EBX6T@<')E:&QI861AZ&$L
M(&MT;W+I('-A(&[A;2!N97!O9&%R:6QO(&]B[7.[+B!-]+YU('-A('!R96IA
M=FF[(&YE<W!RX79N>6T@>F]B<F%Z96[M;2P@8VC]8F%J^F-I;6D@9G5N:V-I
M86UI(&5D:71O<F$@82]A;&5B;R!NX6AO9&[];6D@<.%D;6D@<')E:&QI861A
MZ&$N($%K(&IE(%;AN2!S>7-TZ6T@5VEN9&]W<R`Y>"P@:F4@=F6U;6D@<')A
M=F1E<&]D;V)NZ2P@OF4@<V$@>F]B<F%Z[2!C:'EB82`G1V5N97)A;"!0<F]T
M96-T:6]N($9A=6QT)R!A(&)U9&5T92!M=7-I9;L@<F6Y=&%R=&]V8;L@<&_H
M[71AZ"Y<;EQN5F%R;W9A;&D@<VUE(%;A<RX@4W1L8>AT92!P<F]S[6T@3TL@
M86L@;F%O>F%J(&-H8V5T92!P;W6^:;L@961I=&]R('8@8V5L;V]B<F%Z;W9K
M;W9O;2!R9;YI;64N`$ED96YT:71A("(E<R(@8F]L82!V>6UA>F%NX2X`26)A
M(+5A=N$@<W1R86YA`%1R:65D82!#<GEP=%]P9W`Z.B!P;W1R96)U:F4@<&]Z
M;F&[('5M:65S=&YE;FEE('!R;V=R86UU($=N=5!'+@!3<'+A=F$@;V1O<VQA
M;N$@)7,@<')E("5S(',@<')E9&UE=&]M("(E<R(@8F]L82!Z;V)R87IE;N$N
M"DYE97AI<W1U:F4@=KEA:R!ZX7)U:V$L(+YE('-P<N%V82!B;VQA('!R9>CM
M=&%NX2!A;&5B;R!P;V-H;W!E;N$N`$UE;F\L(&MT;W+I('-A(&WA('!O=;YI
MNR!P<FD@;&EN:V]V86[M(&YA('-T<N%N:W4@;F$@<.US86YI92!S<'+A=B``
M4&_H970@<&]L[2!M=7/M(&)YNR#H[7-L;RX`5')I961A($AO<F1E7T-R>7!T
M7W-M:6UE.CH@=GF^861U:F4@;6]D=6P@;W!E;G-S;"X`3F%S=&%V96YI92`B
M)7,B('-A(&YE<&]D87)I;&\@=6QOOFF[+"!P<F5T;[YE(&IE:&\@^F1A:F4@
M<')E:W)AZ'5J^B!M87AI;>%L;G4@<&]V;VQE;OH@=F6U:V]SNP!0<F]G<F%M
M('!O=;[M=F%N_2!N82!Z;V)R87IE;FEE('1O:'1O(/ID86IO=NEH;R!T>7!U
M("@E<RD@;F5B;VP@;N%J9&5N_2X`6FYA:R!C:73A8VEE(&UU<^T@8GF[(&IE
M9&5N('IN86LN`$EB82!P<F%VX2!A(+5A=N$@<W1R86YA`$EB82!P<F%VX2!S
M=')A;F$`3V1D9;5O=F'H(&UU<^T@8GF[(&IE9&5N('IN86LN`%-E<G9E<B`B
M)7,B(&)O;"!V>6UA>F%N_2X`4V5R=F5R("(E<R(@8F]L('5L;[YE;OTN`*YI
M861O<[L@;R!P<FEH;.%S96YI92`E<R!B;VQA('9Y;6%Z86[A+@"I<&5C:69I
M:V]V86[](')I861O:R!N965X:7-T=6IE+@!$;^AA<V[]('/Z8F]R("(E<R(@
M;F5E>&ES='5J92X`6F%D86[]('1E>'0@;FEE(&IE(')O=FYA:_T@86MO('1E
M>'0@;F$@;V)R87IO=FME+@!)8F$@:&]R;N$@82!S<&]D;N$@<W1R86YA`$EB
M82!H;W)NX2!S=')A;F$`3F%H<F%NZ2#Z9&%J92!S82!O9"!P<F5D8VCA9'IA
M:OIC96AO(&MR;VMU('-T<F%T:6QI+@!.86AR86[]('/Z8F]R('-A(&YE<&]D
M87)I;&\@=6QOOFF[+@!";&]K('=E871H97(N8V]M(&YI92!J92!D;W-T=7!N
M_2X`4')I9>AI;F]K('3I;2`B)7,B(&YE8F]L(&[A:F1E;OTN`*YI861N92!N
M87-T879E;FEA(&YI92!S^B!D;W-T=7!NZ2X`KFEA9&YE(&%L=&5R;F%T[79N
M92#H87-T:2!N96UOOFYO('IO8G)A>FF[('8@=&5L92!S<'+A=GDN`%8@=&]M
M=&\@<&]L:2!J92!P<NUL:;D@=F6U82!Z;F%K;W8N(%IA9&%L:2!S=&4@)7,@
M>FYA:V]V.R!M=7/M=&4@>F%D8;L@;65N96H@86MO("5S+@!.87-T86QA(&-H
M>6)A('!R:2!P<FEDX79A;NT@(B5S(B!D;R!S>7-TZ6UU.B`E<P!.87-T86QA
M(&-H>6)A('!R:2!O9'-T<F'R;W9A;NT@<&]UONUV871EM7-K_6-H(/ID86IO
M=B`B)7,B('IO('-Y<W3I;74Z(`!.87-T86QA(&-H>6)A('!R:2!O9'-T<F'R
M;W9A;NT@(B5S(B!Z;R!S>7-TZ6UU.B``3F%S=&%L82!C:'EB82!P<FD@86MT
M=6%L:7KA8VEI("(E<R(Z("5S`%9Y<VMY=&]L('-A('!R;V)LZ6T@<R!N86AR
MX79A;NUM('/Z8F]R=3H@KFEA9&5N("5S(&YE8F]L(&YA:')A;OTN`%9Y<VMY
M=&]L('-A('!R;V)LZ6T@<R!N86ARX79A;NUM('/Z8F]R=3H@)7,@8F]L(';D
MZ+GM(&%K;R!N86IVY.BY[2!P;W9O;&5N_2!L:6UI="`H)60@8F%J=&]V*2X`
M5GES:WET;VP@<V$@<')O8FSI;2!S('5K;&%D86[M;2!S^F)O<G4Z("5S(&)O
M;"!N86AR86[](&QE;B#H:6%S=&_H;F4N`$YA<W1A;&$@8VAY8F$@<')I('IO
M8G)A>F]V86[M('1E:G1O(.AA<W1I('-P<N%V>0!.87-T86QA(&-H>6)A('!R
M:2!I;7!O<G1E(/ID86IO=B!O(&MO;G1A:W1E+@!.87-T86QA(&-H>6)A('!R
M:2!I;7!O<G1E(/ID86IO=B!I0V%L96YD87(N`$YA<W1A;&$@8VAY8F$@=B!K
M;VYF:6=U<F'H;F]M(&9O<FUU;.%R:2X@4')A=F1E<&]D;V)N92!S=&4@;F5V
M>7!L;FEL:2!P;[YA9&]V86[I('!O;&4N`$YA<W1A;&$@8VAY8F$@<')I('9Y
M:V]NX79A;NT@=7+H96YE:B!F=6YK8VEE(&%D<F5SX7)A+B!0<F]S[6T@<VOZ
M<W1E('1O(&YE<VOT<BX`3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI
M(&1E=&%I;&]V(&MO;G1A:W1U+B!0<F]S[6T@<VOZ<W1E('1O(&YE<VOT<BX`
M3F%S=&%L82!C:'EB82!P<FD@86MT=6%L:7KA8VEI('IO>FYA;74@<'+M:F5M
M8V]V+B!0<F]S[6T@<VOZ<W1E('1O('IN;W9U+@!496YT;R!)34%0('-E<G9E
M<B!N97!O9'!O<G5J92!Z9&EEM6%N:64@<')I9>AI;FMO=BX`5&]T;R!P<F%V
M9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV(')A<BX`5&]T;R!P<F%V
M9&5P;V1O8FYE(&YI92!J92!P;&%T;OT@87)C:.UV('II<"X`5&]T;R!P<F%V
M9&5P;V1O8FYE(&YI92!J92!P;&%T;ND@Z.US;&\@:V%R='DN`%1E;G1O(&]V
M;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI92!S<'+A=B!C97H@8G+A;G4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P;VUO8V]U($A45%`@
M05!)`%1E;G1O(&]V;.%D8>@@=6UOOO)U:F4@<&]S:65L86YI92!S<'+A=B!C
M97H@8G+A;G4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@<&]M;V-O=2!(5%10
M($%020!496YT;R!O=FSA9&'H('5M;[[R=6IE('!O<VEE;&%N:64@<W!RX78@
M8V5Z(&)RX6YU('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI('!O
M;6]C;W4@2%144"!!4$D`5&5N=&\@;W9LX61AZ"!U;6^^\G5J92!P;W-I96QA
MNR!S<'+A=GD@8V5Z(%--5%`@8V5Z(&)RX6YU(%9O9&%F;VYE($ET86QY("AI
M8F$@;F$@Z.US;&$@5F]D869O;F4I+B!6>;YA9'5J92!E+6UA:6QO=OT@^NAE
M="!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4;W1O('!O
M;&4@:F4@<&]V:6YNZ2X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[(&EB82#H
M[7-L82X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[(&EB82#H[7-L82!A(&1V
M;VIB;V1K=2X`5&]T;R!P;VQE(&WTOF4@;V)S86AO=F&[(&EB82!O<VUIZ&MO
M=ND@:&]D;F]T>2X`5&]T;R!P;VQE(&UU<^T@8GF[('IO>FYA;2#H[7-E;"!O
M9&1E;&5N_6-H(.AI87)K;W4@86QE8F\@;65D>F5R;W4`5&]T;R!P;VQE(&UU
M<^T@8GF[('!L871NZ2#H[7-L;RX`5&]T;R!P;VQE(&UU<^T@;V)S86AO=F&[
M(&OS9"!F87)B>2!V(+EE<W1NX7-T:V]V;VT@9F]R;>%T92!21T(L(&YA<'+M
M:VQA9"`G(S$R,S1A9B<N`%1E;G1O(&9O<FUU;.%R('6^(&)O;"!S<')A8V]V
M86[]+@!4;W1O(&IE("5S+@!4;W1O(&IE(&]B:F5K="!+;VQA8B!'<F]U<'=A
M<F4N(%!R92!Z;V)R87IE;FEE('1O:'1O(&]B:F5K='4@<&]T<F5B=6IE=&4@
M92UM86EL;W;I:&\@:VQI96YT82P@:W1O<OT@<F]Z=6UI92!F;W)MX71U($MO
M;&%B($=R;W5P=V%R92X@4')E('IO>FYA;2!T86O]8VAT;R!K;&EE;G1O=B!N
M87:Y=.UV=&4@<')O<^UM("5S`%3A=&\@<W!RX79A(&)O;&$@;F%P[7-A;N$@
M=B!I;F5J(&%K;R!686UI('!O=;[M=F%N96H@>FYA:V]V96H@<V%D92`H)7,I
M+@!4;W1O(.CM<VQO(&UU<^T@8GF[(&YA:FUE;F5J(#$N`%1E;G1O('-E<G9E
M<B!N961O:^&^92!D96MO;7!R:6UO=F&[('/Z8F]R>2!Z:7`@82!G>FEP+@!3
M>7-TZ6T@:F4@;6]M96YTX6QN92!D96%K=&EV;W9A;OTN`%3A=&\@:&]D;F]T
M82!M=7/M(&)YNR#H[7-E;&[A+@!4;W1O(&]K;F\@;75S[2!B>;L@>F%V;VQA
M;ND@>B!O:VYA($YA<W1A=F5N[0!(<FUE;FEE`%1I8VME=',`R&%S`%1I;64@
M5')A8VMI;F<`1F]R;>%T(.AA<W4`5OUB97(@Z&%S=0!4:6UO<BU,97-T90!4
M:71U;&]K`$YA9'!I<R`H8G5B;&EN;W;](';]<&ES*3H`4')E`%!R92!V_6)E
M<B!V:6%C97+]8V@@<&]L;[YI96L@9'*^=&4@<&_H87,@:VQI:V%N:6$@:VSA
M=F5S=2!#;VYT<F]L("A00RD@86QE8F\@0V]M;6%N9"`H36%C*2X`1&YE<P!0
M<F5P;OJ[('IO8G)A>F5N:64@>F1R;VIO=NEH;R!K\V1U($A434P`5&]G;P!4
M;VME;&%U`%IA:G1R80!4;VYG80!6<F-H`%9R8VAN_2!RX6UE8R`H7W1O<"D`
M4')E:VQA9'D`5')I;FED860@82!4;V)A9V\`4')A=F1A(&%L96)O(&YE<')A
M=F1A`%5T`%1U;FES:V\`5'5R96-K;P!4=7)K;65N:7-T86X`5'5R:W,@82!#
M86EC;W,`5'5V86QU`%IA9&%J=&4@5F&Y=2!V;[5B=3H@`%4N5BX@:6YD97@Z
M(`!54DP`55),(%;AN6AO('-K<FEP='4@<')E('-P<N%V=2!O(&1O<G7H96[M
M`%523#H`56=A;F1A`%5K<F%J:6YA`$YE<&]D87)I;&\@<V$@=7-K=71OZ&YI
MNR!P<NUS='5P(&L@5D93(&%D<F5SX7)U+@!.97!O9&%R:6QO('-A('!R:61A
MNR#O86RY:64@:6YF;W)MX6-I92!O('!O=;[M=F%T9;5O=FD@<')I(')E9VES
M='+A8VEI+@!.97!O9&%R:6QO('-A('IM96YINR!P<N%V;R!P<F4@5D93('/Z
M8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@>FUE;FF[('!RX79O('!R92!61E,@
M<_IB;W(@)7,O)7,N`$YE<&]D87)I;&\@<V$@>FUE;FF[(&YA("5S+@!.97!O
M9&%R:6QO('-A('-K;VYT<F]L;W9ANR!V9;5K;W.[('/Z8F]R=2`B)7,B+@!.
M97!O9&%R:6QO('-A('-K;VYT<F]L;W9ANR!V9;5K;W.[('/Z8F]R=2`B)7,O
M)7,B+@!.97!O9&%R:6QO('-A('-P;VIINR!S(%-13"!S97)V97)O;2X`3F5P
M;V1A<FEL;R!S82!S<&]J:;L@<&]M;V-O=2!34TPN`$YE<&]D87)I;&\@<V$@
M<VMO<.UR;W9ANR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@=GET=F]R:;L@
M5D93(&%D<F5SX7(@(B5S(BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@
M861R97/A<BX`3F5P;V1A<FEL;R!S82!V>71V;W)INR!61E,@<_IB;W(N`$YE
M<&]D87)I;&\@<V$@=GET=F]R:;L@5D93('!R:67H:6YO:R`B)7,B+@!.97!O
M9&%R:6QO('-A('9Y='9O<FF[('!RX7ID;GD@5D93('/Z8F]R+@!.97!O9&%R
M:6QO('-A(&1E:V]M<')I;6]V8;L@^F1A:F4N`$YE<&]D87)I;&\@<V$@=GEM
M87IANR`B)7,B+"!A9')E<^%R(&YI92!J92!P<N%Z9&YY+@!.97!O9&%R:6QO
M('-A('9Y;6%Z8;L@(B5S(CH@)7,N`$YE<&]D87)I;&\@<V$@=GEM87IANR`E
M<RP@861R97/A<B!N:64@:F4@<'+A>F1N>0!.97!O9&%R:6QO('-A(')E:W5R
M>NUV;F4@=GEM87IANR!61E,@861R97/A<BX`3F5P;V1A<FEL;R!S82!V>6UA
M>F&[(%9&4R!A9')E<^%R+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93(&%D
M<F5SX7(Z("5S+@!.97!O9&%R:6QO('-A('9Y;6%Z8;L@5D93('/Z8F]R("(E
M<R(N`$YE<&]D87)I;&\@<V$@=GEM87IANR!61E,@<_IB;W(N`$YE<&]D87)I
M;&\@<V$@=GEM87IANR!61E,@<')I9>AI;F]K("(E<R(N`$YE<&]D87)I;&\@
M<V$@<F5K=7)Z[79N92!V>6UA>F&[(%9&4SH@)7,N`$YE<&]D87)I;&\@<V$@
M=7+H:;L@86MT=>%L;GD@861R97/A<BX`3F5P;V1A<FEL;R!S82!Z:7-T:;L@
M<&]D<F]B;F]S=&D@;R!C97)T:69I:^%T92X`3F5M;[YNZ2!N86AR8;L@9&5F
M:6[M8VEU("5S+@!.97!O9&%R:6QO('-A('!R97-U;OJ[(%9&4R!S^F)O<BX`
M3F5P;V1A<FEL;R!S82!O='9O<FF[(%9&4R!S^F)O<B`B)7,B+@!.97!O9&%R
M:6QO('-A(&]T=F]R:;L@5D93('/Z8F]R(&YA('KA<&ES+@!.97!O9&%R:6QO
M('-A(&]T=F]R:;L@5D93('/Z8F]R+@!.97!O9&%R:6QO('-A(&]T=F]R:;L@
M:V]M<')I;6]V86[](&%R8VCM=BX`3F5P;V1A<FEL;R!S82!P<F7H[71ANR!6
M1E,@<_IB;W(@*&9U;FMC:6$@9FEL97-I>F4H*2!Z;'EH86QA*2X`3F5P;V1A
M<FEL;R!S82!P<F7H[71ANR!61E,@<_IB;W(@*&9U;FMC:6$@9V5T1FEL95-I
M>F4H*2!Z;'EH86QA*2X`3F5P;V1A<FEL;R!S82!P<F7H[71ANR!S^F)O<CH`
M3F5P;V1A<FEL;R!S82#H[71ANR!A9')E<^%R('9F<W)O;W0N`$YE<&]D87)I
M;&\@<V$@<')E;65N;W9ANR`E<R!N82`E<SH@8VEEM6]V_2!P<FEEZ&EN;VL@
M=;X@97AI<W1U:F4`3F5P;V1A<FEL;R!S82!P<F5M96YO=F&[(%9&4R!A9')E
M<^%R+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93(&%D<F5SX7(Z("5S
M+@!.97!O9&%R:6QO('-A('!R96UE;F]V8;L@5D93('/Z8F]R("(E<R(N`$YE
M<&]D87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(@)7,O)7,N`$YE<&]D
M87)I;&\@<V$@<')E;65N;W9ANR!61E,@<_IB;W(N`$YE<&]D87)I;&\@<V$@
M<W!U<W1INR`G;6MI<V]F<R<N`$YE<&]D87)I;&\@<V$@<')E;&^^:;L@=&5N
M=&\@9&]K=6UE;G0@5V]R9`!.97!O9&%R:6QO('-A('IA<.US8;L@5D93('/Z
M8F]R("(E<R(N`$YE<&]D87)I;&\@<V$@>F%P[7-ANR!61E,@<_IB;W(@*&9U
M;FMC:6$@8V]P>2@I('IL>6AA;&$I+@!.97!O9&%R:6QO('-A('IA<.US8;L@
M^F1A:F4@5D93('/Z8F]R=2X`3F5P;V1A<FEL;R!S82!Z87#M<V&[(%9&4R!S
M^F)O<BP@:W;S=&$@:F4@<')E:W)OZ&5NX2X`4&]DZ&EA<FMN=73I`%IR=;EI
MNR!Z;65N>0!:<G6Y[2!P;W-L961N^B!A:V-I=0!.96_H86OA=F%NX2!O9'!O
M=F7O(&]D('-E<G9E<F$@<&_H87,@<W!O:F5N:6$Z(`!.96_H86OA=F%NX2!O
M9'!O=F7O(&]D('-E<G9E<F$@;F$Z(`!.96YA<W1A=F5NX0!3<&]J96[I(&%R
M86)S:^D@96UI<N%T>0!69;5KX2!"<FETX6YI80!3<&]J96[I(+ETX71Y($%M
M97)I8VOI`$IE9&YO=&MY`$YE>F[A;64`3F5Z;N%M92!A<&EM<V=I9"`H05!)
M($UE<W-A9V4@240I+@!.97INX6UE(&-L:6US9VED("A#;&EE;G0@365S<V%G
M92!)1"DN`$)O;&$@>F%D86[A(&YE<&QA=&[A(&QO:V%L:71A+@!.97INX6UE
M('!O=;[M=F%T9;5S:^D@;65N;R!A;&5B;R!H97-L;RX`3V1S='+A;FF[(&QI
M;FMU('H@86MT=>%L;F5H;R!E;&5M96YT=0!.97!O;65N;W9A;N$`3F5P<FEV
M:6QE9V]V86[I('-K<FEP='D@;F5M86KZ('H@8F5Z<&7H;F]S=&[]8V@@9/1V
M;V1O=B!P<NUS='5P(&L@=F^U8N%M(%9Y<W1R:6AN^KLO2V]P[7)O=F&[+U9L
M;[YINRX@2VQI:VYI=&4@;F$@3TL@82!Z;V)R87KM('-A('1E8VAN:6-KX2!I
M;F9O<FWA8VEA(&YA('-T<N%N:V4@;6]Z:6QL82YO<F<L(&MT;W+A(%;A<R!I
M;F9O<FUU:F4L(&%K;R!U;6^^;FF[('-K<FEP='4@<'+M<W1U<"!K('-C:'+A
M;FME+@!/9'-T<N%N:;L@9F%R8G4`3F5P;V1P;W)O=F%NZ2!R;WJY[7)E;FEE
M`$%K='5A;&EZX6-I80!!:W1U86QI>F]V8;L@)7,`06MT=6%L:7IO=F&[('!O
M=;[M=F%T9;5A`$%K='5A;&EZX6-I82`B)7,B(&)O;&$@^G-P9;ENX2X`4VMR
M:7!T(&YA('5P9W)A9&4@8F]L('9Y;6%Z86[]+@!.86AR8;L`5KEE=&MY('/Z
M8F]R>2!S(&MO;F9I9W5RX6-I;W4@8F]L:2!N86AR86[I(&YA('-E<G9E<BX`
M5F6U:^D@;&%T:6YS:^D@<.US;65NX0!69;5KZ2!R[6US:V4@Z.US;&EC90!5
M<G5G=6%Y`%!O=;YINR!A:W1UX6QN93H@)7,`4&]UOFF[(%-33`!0;W6^:71E
M('8@<'+M<&%D92P@OF4@:F4@;65N;R]H97-L;R!O9&QIN6[I('!R92!)35-0
M('-E<G9E<BX`4&]UONUV871EM0!0;W6^[79A=&6U("5S(&YI92!J92!A=71O
M<FEZ;W9A;OT@;F$@)7,N`%-P<N%V82!P;W6^[79A=&6U;W8`4&]UONUV871E
MM7-KZ2!N87-T879E;FEA`%)E9VES='+A8VEA('!O=;[M=F%T9;5A`%)E9VES
M='+A8VEA('!O=;[M=F%T9;5O=B!B;VQA('!R92!T96YT;R!S>7-TZ6T@>F%K
MX7IA;N$N`%!O=;[M=F%T9;5S:_T@^NAE="!N96)O;"!NX6ID96[]`%!O=;[M
M=F%T9;5S:^D@;65N;P!0;W6^[79A=&6U<VOI(&UE;F\@(B5S(B!UOB!E>&ES
M='5J92X`4&]UONUV871EM7-KZ2!M96YO.@!0;W6^[79A=&6U<VOI(&UE;F\Z
M(`!0;W6^[79A=&5L:6$@<WES=.EM=3H`57IB96MI<W1A;@!61E,@861R97/A
M<B!N965X:7-T=6IE+@!$;W9O;&5N:V$`4&QA=&[I('5M:65S=&YE;FEA('IA
M:.#R86KZ.B``4&QA=&YO<[L`4&QA=&YO<[L@=B!M:6[Z=&%C:"!O9'1E<F%Z
M+@!(;V1N;W1A('!R96MR;^AI;&$@;6%X:6WA;&YU(&3EOFMU("5S+@!(;V1N
M;W1Y`$AO9&YO='DL('H@:W1O<OUC:"!S:2!M]+YE=&4@=GEB<F&[`%9A;G5A
M='4`4')E;65N;N$`5F5N97IU96QA`$]V97)E;FEE('IL>6AA;&\@+2!TX71O
M('-P<N%V82!M;VAL82!B>;L@<V9A;+EO=F%NX2X`5F5R>FEA`$UA;F&^;65N
M="!V97)Z:>T`5F5R=&EKX6QN92!Z87)O=FYA;FEE`%9E<G1I:^%L;F4@=GEP
M;&YE;FEE`%9E<G1I:^%L;F4Z`%9EM6UI('9Y<V]KX0!6:65T;F%M`%IO8G)A
M>FF[("5S`%IO8G)A>FF[(&5X=&5R;OH@=W=W('-T<N%N:W4`6F]B<F%Z:;L@
M86MO("5S`$)R:71S:^D@4&%N96YS:^D@;W-T<F]V>0!!;65R:6-KZ2!086YE
M;G-KZ2!O<W1R;W9Y`%9I9&ET9;5N;W.[`%9I9&ET9;5N;W.[.B``5F]D869O
M;F4@271A;'D@8V5Z(%--5%``5D%23U9!3DE%`%503UI/4DY%3DE%(2$A($]$
M4U12P=)412!32U))4%0@6B`E<R!25<A.12X`5TE.(&-E>B!(5%10`%=A;&QI
M<R!A($9U='5N80!687)O=F%N:64`4W0`4')E9'!O=F7O('!OZ&%S:6$`VF1A
M:F4@;R!P;^AA<^T@<&]S:WET=6IE`%=E871H97(N8V]M`%=E8@!75U<@<W1R
MX6YK80!4_;YD96YN90!6:71A:G1E`%;M=&$@5N%S("5S`%9I=&%J=&4L("5S
M`%KA<&%D;N$@4V%H87)A`$MT;W+Z(&%P;&EKX6-I=2!MX2`E<R!Z;V)R87II
MNR!P;R!P<FEH;.%S96[M/P!!:_T@:F4@>FYA:R!P<F4@;V1D9;5O=F'H/P!!
M:_T@:F4@>FYA:R!P<F4@^G9O9'IO=FMU/P!-87!A($%U<W1RX6QI92!P<F4@
M<VQUOF)U(%=H97)E:7,`2W1O<ND@9N%Z>0!+=&]RZ2!ZX7-U=F[I(&UO9'5L
M>2!P;W9O;&F[('!R92!R;WJY[7)E;OT@=&5X=&]V_2!E9&ET;W(N`*GM<FMA
M`*GM<FMA('8@:F5D;F]T:^%C:"!#4U,`J>UR:V$@;65N=2`E<R!VM6%V;R`H
M<')E:F%V[2!S82!P<FD@[V%LN6]M('!R:6ALX7-E;NTI.@"I[7)K82!T86)U
MM6MY`$IE9&YO=&MA(+GM<FMY`*GM<FMA.@!7:6MI`%9I971O<@!2X6YO('9I
M971O<@!2_6-H;&]SNR!V971R82!V('5Z;&]C:`!6:65T;W(Z`%9I971O<CH@
M`$WZ9')O<[L`5VES:&QI<W0`4'+A8V$`061R97-A(&1O('!RX6-E`%1E;&5F
M\VX@9&\@<'+A8V4`3F5S<'+A=FYY('!OZ&5T('!O;.T@;F$@<FEA9&MU("5D
M+B!/Z&%KX79A('-A("5D+"!N8;EL;R!S82`E9"X`3F5S<'+A=FYY('!OZ&5T
M('!O;.TN($_H86OA=F$@<V$@)60L(&YAN6QO('-A("5D+@!:;/T@;V9F<V5T
M("5D('!R:2#H[71A;NT@5D93('/Z8F]R=2X`6"U2968`6N%K;&%D;ND@;V)M
M961Z96YI82!8-3`Y=C,`4&]UOFET:64@<F]ZN>UR96[I:&\@:[7ZZ&$@6#4P
M.78S`$%L=&5R;F%T[79N92!M96YO('-U8FIE:W1U(%@U,#EV,P!)9&5N=&EF
M:6OA=&]R(&NU^NAA('-U8FIE:W1U(%@U,#EV,P!8-3`Y=C,@<F]ZN>UR96YI
M80!960!965E9`%EA:&]O(2!M87``4F_H;F4`2F5M96X`06YO`%/Z:&QA<^UM
M+@!3=&4@=B!415A43U9/32!21:Y)344N(%!O=;YI=&4@=&QAZ&ED;&\@6SP^
M72!N82!P<F5P;G5T:64@;F%S<.2[(&1O(%=94TE764<N`$YE;?2^971E('9Y
M='9O<FF[('9I86,@86MO("5D(&)L;VMO=BX`3FEE('-T92!A=71E;G1I9FEK
M;W9A;OTN`%9O(%9AN6]M('!L;F]M(&UE;F4@;F5M]+YE=&4@<&]UOFF[('IN
M86L@)UPG+@!.97IA9&%L:2!S=&4@<&QA=&[Z(&4M;6%I;&]V^B!A9')E<W4N
M`$YE=7+H:6QI('-T92!V>KMA:"!M961Z:2"^:6%D;GEM:2!P;VQI86UI('H@
M:6UP;W)T;W9A;NEH;R!S^F)O<G4@82!Z;V1P;W9E9&%J^F-I;6D@<&^U86UI
M('8@)7,N`$)O;&D@<W1E(&]D:&SA<V5N_2X`375S[71E('IA9&&[('!L871N
MZ2#H[7-L;R!M;V)I;&[I:&\@=&5L96;S;G4L(&MT;W+I(&]B<V%H=6IE(&EB
M82#H[7-L82!S('9O;&ET9;5N_6T@<')E9FEX;VT@)RLG('!R92!M961Z:6[A
M<F]D;OT@9F]R;>%T+@!-=7/M=&4@>F%D8;L@<&QA=&[Z(&AO9&YO='4N`$%B
M>2!S=&4@;6]H;&D@<&]UONUV8;L@4F5G:7-T<N%C:64L(&UU<^UT92!N86IS
M:_1R(&YA:V]N9FEG=7)O=F&[($1A=&%4<F5E(&)A8VME;F0N`$UU<^UT92!N
M86MO;F9I9W5R;W9ANR!61E,@8F%C:V5N9"X`375S[71E('!O<.US8;L@<')O
M8FSI;2!P<F5D=/UM+"!A:V\@;V1ON6QE=&4@<W!RX79U(&\@<')O8FSI;64N
M`$UU<^UT92!Z861ANR!54DP@861R97-U+"!N82!K=&]R^B!TX71O(&QI;FMA
M('5K87IU:F4`375S[71E('9Y8G)ANR!S97)V97(L(&MT;W+](&WA(&)YNR!V
M>6UA>F%N_2X`375S[71E('5RZ&F[(&UE;F\@<&]UONUV871EM6$L(&MT;W+I
M:&\@8VAC971E('9Y;6%Z8;LN`$UU<^UT92!U<NAINR!M96YO('!O=;[M=F%T
M9;5A+"!K=&]RZ6AO(&-H8V5T92!V>6UA>F&[+@!-=7/M=&4@=7+H:;L@;65N
M;R!P;W6^[79A=&6U82P@:W1O<NEH;R!C:&-E=&4@<')I9&&[+@!-=7/M=&4@
M=7+H:;L@<&]UONUV871EM6$L(&MT;W+]('-A(&WA(&%K='5A;&EZ;W9ANRX`
M375S[71E('5RZ&F[(&%K8VEU+"!K=&]RX2!S82!MX2!V>6MO;F&[+@!-=7/M
M=&4@>F%D8;L@;65N;R!N;W9E:B!K871E9_-R:64N`$UU<^UT92!Z861ANR!T
M86QI86YS:V4@=&5L96;S;FYE(.CM<VQO`%!L871N;W.[(%9AN65J(')E;.%C
M:64@<')E(&%P;&EKX6-I=2`E<R!V>7!RN6%L82X@4')O<^UM('!R:6ALX7-T
M92!S82!Z;F]V=2X`5F&Y82!%;6%I;&]VX2!A9')E<V$`5F&Y82!%;6%I;&]V
MX2!A9')E<V$@<&]UOFETX2!P<F4@;V1C:.%D>F%J^F-U('!ON71U.@!68;EE
M(&EN9F]R;>%C:64`5F&Y82!I;G1E<FYE=&]VX2!A9')E<V$@<V$@>FUE;FEL
M82!O9"!Z8>AI871K=2!68;EE:B!R96SA8VEE("5S+B!0<F4@5F&Y=2!B97IP
M9>AN;W.[('-A(&UU<^UT92!Z;F]V=2!P<FEH;.%S:;LN`%9AN64@;65N;P!6
MX;D@875T96YT:69I:V'H;OT@;6]D=6P@;F5P;V1P;W)U:F4@<')I9.%V86YI
M92!P;W6^[79A=&6U;W8N($%K('-I(+YE;.%T92!P;W6^:;L@2&]R9&4@;F$@
M<W!RX79U('!O=;[M=F%T9;5S:_UC:"#ZZ'1O=BP@;75S[71E('!O=;YINR!I
M;OT@875T96YT:69I:V'H;OT@8F%C:V5N9"X`5N&Y(&%U=&5N=&EF:6MAZ&[]
M(&UO9'5L(&YE<&]D<&]R=6IE('IO8G)A>F]V86YI92!Z;WIN86UU('!O=;[M
M=F%T9;5O=BP@86QE8F\@8F]L82!TX71O(&UOOFYO<[L@>B!N96IA:^EH;R!D
M]'9O9'4@>F%KX7IA;N$N`%IDX2!S82P@OF4@5N&Y('!R96AL:6%D8>@@<V$@
M>FUE;FEL(&]D('IAZ&EA=&MU(%9AN65J(')E;.%C:64@)7,N(%!R92!68;EU
M(&)E>G!EZ&YO<[L@<V$@;75S[71E('IN;W9U('!R:6ALX7-INRX`5N&Y('!R
M96AL:6%D8>@@;F5P;V1P;W)U:F4@=/IT;R!F=6YK8VEU+@!6X;D@<')E:&QI
M861AZ"!N97!O9'!O<G5J92!T^G1O(&9U;FMC:74@=&QAZ&4N(%-T;&'H=&4@
M0V]N=')O;"]#;VUM86YD("L@4"!P<F4@=&QAZ"X`5F&Y82!A:W1UX6QN82#H
M87-O=N$@>O-N83H`5F&Y82!P<F5D;F%S=&%V96[A(&ED96YT:71A(&)O;&$@
M>FUE;F5NX2X`4')E9&YA<W1A=F5NX2!I9&5N=&ET83H`5F&Y92!M96YO.@!0
M;&%T;F]SNR!6X;EH;R#ZZ'1U('9Y<'*Y86QA+@!68;EE(&YO=ND@:&5S;&\@
M<')E("5S(&IE.B`E<P!68;EE(&YA<W1A=F5N:6$@8F]L:2!A:W1U86QI>F]V
M86[I('!R92!T;W1O('-E9&5N:64N`%9AN64@;F%S=&%V96YI82!B;VQI(&%K
M='5A;&EZ;W9A;NDN`%9AN64@:&5S;&\@8F]L;R!O8FYO=F5NZ0!68;EE(&AE
M<VQO(&)O;&\@;V)N;W9E;NDL('-K;VYT<F]L=6IT92!S:2!P;[ET=2!A('!R
M:6ALX7-T92!S82!S(%9AN>UM(&YO=OUM(&AE<VQO;2X`4&QA=&YO<[L@5N&Y
M:&\@:&5S;&$@=GEP<KEA;&$N`%9AN64@=GID:6%L96[I('-E<G9E<GDZ`$IU
M:&]S;.%V:6$`6F%I<@!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6U-K<GF[(&-I
M=&]V86[]('1E>'1=`%M3<'+A=F$@;R!P<F]B;.EM95T`6UIO8G)A>FF[(&-I
M=&]V86[]('1E>'0@+0!;6F]B<F%Z:;L@8VET;W9A;OT@=&5X="`M("5S(')I
M861K;W9=`%MR:6%D;VL@)7,@>B`E<UT`7T%D;6EN:7-T<N%C:6$`7T-,20!?
M1&%T851R964`7U9Y;6%Z8;L@<FEA9&]K`%]3:W5P:6YY`%]0;VUO8V[M:P!6
M;&%S=&YO<W1I(%]O8G+A>FMU+BXN`%]0<FEH;.%S:;L@<V$`7T]D:&SA<VF[
M('-A`%]5<')A=FF[(&QI;FMU+BXN`%].87-T879E;FEA`%]0<N%V80!/9'-T
M7W+A;FF[(&QI;FMU+BXN`$YA7W-T879E;FEE`%9L87-T;F]S=&D@7W1A8G6U
M:WDN+BX`4&]?=;[M=F%T96QI80!A9')E<^%R`&%D<F5SX70@;F5Z;N%M>0!K
M86QE;F3A<@!B97IV971R:64`;F5P;V1A<FEL;R!S82!V>71V;W)INR!V_7-T
M=7!N_2!S^F)O<@!N97!O9&%R:6QO('-A(&]T=F]R:;L@=G-T=7``:VQI:VYI
M=&4@<V5M`&-H>6)A('!R:2!P;W6^:73M('!R[6MA>F]VZ6AO(')I861K=0!C
M:'EB82!K;VYF:6=U<N%C:64`8VC]8F$@9/1L9;YI=/T@<WES=.EM;W;]('/Z
M8F]R`&-H>6)A(&9O<FWA='4@^F1A:F]V`'!O;&^^:V$@;F5NX6ID96[A`&ML
M97/A`'/Z8F]R`'IO('-M97)U("5S("@E<RD@<OUC:&QO<[MO=2`E<R`E<P!N
MX7)A>F]V_0!V.@!H:`!N97INX6UE(&UE;F\@:&]S=&ET9;5A`&]K86V^:71E
M`'8@<W!RX79E`&-H>6)A('9S='5P=2]V_7-T=7!U`&EN=&5R;N$@8VAY8F$@
M<V]F=';I<G4`<FEA9&MO=ET`<&_H87,@=GET=N%R86YI82!)4T\@;F%S=&%L
M82!C:'EB82!M:VES;V9S("5D`&UM`&UE;F\`;F5I;7!L96UE;G1O=F%NZ0!Z
M871I8;4@;F5I;7!L96UE;G1O=F%NZ0!P;WINX6UK;W;](&)L;VL`<&5R8V5N
M=`!P<NUS='5P('IA;6EE=&YU=/T`8F]D;W8`=GID:6%L96[A(&-H>6)A('8@
M<')O=&]K;VQE`'-T^G!A`'-L=;YB82!N:64@:F4@9&]S='5P;N$`>F]B<F%Z
M:;L@<F]Z9&EE;'D`<VUS,F5M86EL(&-E>B!(5%10`'-S`'5S=.%L96[]`'-Y
M<W3I;6]VX2!C:'EB80!Z;WIN86T@^FQO:`!D;^AA<V[A(&-H>6)A`'!R92!P
M;W1V<F1E;FEE('IA9&%J=&4@:&5S;&\@9'9A:W+A=`!U;FEF:6MO=F%NZ0!N
M97!O;65N;W9A;N$`9&5F:6YU:F4@<&]UONUV871EM0!V0V%R9`"Y.@!W96%T
M:&5R+F-O;0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R=5]252],0U]-15-304=%4P``````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T,2`P,C$U,S(`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W)U7U)5
M+VAE;'`N>&UL````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S,S(P(#$P-3$U-#,T,30Q(#`R,30W-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B
M/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]R=5]252]H96QP+GAM;"QV
M(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$S(&IA;B!%>'`@)"`M+3X*/&AE;'`^
M"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P
M86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O
M<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H
M;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN
M('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R
M+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@
M<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T
M:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S
M('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N
M97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N
M="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N
M=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T
M:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O
M<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E
M(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\
M+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H
M92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N
M"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@
M=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V
M86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@
M8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@
M36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U
M;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O
M<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H
M96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T
M;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H
M(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"CPO:&5L<#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]R=5]252],0U]-
M15-304=%4R]H;W)D92YM;P``````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M,C,W-2`Q,#4Q-30S-#$T,2`P,C,R-C(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````WA($E0`````C`0``'````#0)``"%`0``
M3!(```````!@&```*````&$8```.````BA@```X```"9&```"````*@8```%
M````L1@``!,```"W&````P```,L8```)````SQ@```@```#9&```)````.(8
M```'````!QD```P````/&0``+````!P9```.````21D```4```!8&0``%P``
M`%X9```*````=AD```\```"!&0``(P```)$9```4````M1D``!<```#*&0``
M%P```.(9```?````^AD```L````:&@``%0```"8:```Y````/!H``"P```!V
M&@``*@```*,:```1````SAH```@```#@&@``#@```.D:```*````^!H```@`
M```#&P``!@````P;```5````$QL``!4````I&P``"@```#\;``!4````2AL`
M`$0```"?&P``$P```.0;```<````^!L```P````5'```$````"(<```'````
M,QP``!T````['```*0```%D<```&````@QP``!````"*'```$P```)L<```,
M````KQP``"@```"\'````@```.4<```%````Z!P```0```#N'```#0```/,<
M```0`````1T```8````2'0``&````!D=```4````,AT``"\```!''0``"0``
M`'<=```6````@1T```\```"8'0``)@```*@=``!#````SQT```@````3'@``
M"P```!P>```$````*!X```H````M'@``%P```#@>```1````4!X```4```!B
M'@``#0```&@>```@````=AX```4```"7'@``$````)T>```/````KAX``!``
M``"^'@``#P```,\>```+````WQX```\```#K'@``#````/L>```/````"!\`
M``8````8'P``'@```!\?```A````/A\```,```!@'P``!````&0?```,````
M:1\```<```!V'P``$````'X?```.````CQ\```(```">'P``#0```*$?```&
M````KQ\``!$```"V'P``!P```,@?```$````T!\```H```#5'P``(@```.`?
M```%`````R````0````)(```#`````X@```*````&R````4````F(```"@``
M`"P@```/````-R```!````!'(```!@```%@@```/````7R```!(```!O(```
M$````((@```0````DR````<```"D(```"````*P@```.````M2```!8```#$
M(```$0```-L@```&````[2```!````#T(```#P````4A```(````%2$```8`
M```>(0``!P```"4A```%````+2$```L````S(0```@```#\A```$````0B$`
M`&@```!'(0``#P```+`A```*````P"$```<```#+(0``!P```-,A```+````
MVR$```D```#G(0``"0```/$A```*````^R$```<````&(@``"0````XB```'
M````&"(```H````@(@``%@```"LB```$````0B(```4```!'(@``#````$TB
M```$````6B(```0```!?(@``#````&0B```"````<2(```D```!T(@``!```
M`'XB```3````@R(```4```"7(@```@```)TB```'````H"(```X```"H(@``
M"@```+<B```1````PB(```@```#4(@``"0```-TB```*````YR(``!X```#R
M(@``*````!$C```*````.B,```L```!%(P``%````%$C```%````9B,``"D`
M``!L(P``*````)8C```I````OR,``!````#I(P``!P```/HC```3`````B0`
M``0````6)```!P```!LD```>````(R0``!0```!")```#@```%<D```J````
M9B0```8```"1)```#````)@D```+````I20```4```"Q)```$0```+<D```8
M````R20```0```#B)```!````.<D```,````["0```8```#Y)```#P`````E
M```*````$"4```L````;)0``&@```"<E```7````0B4``"<```!:)0``%P``
M`((E```;````FB4``!D```"V)0``'P```-`E```3````\"4``#\````$)@``
M-P```$0F``!7````?"8```4```#4)@``#0```-HF```M````Z"8```0````6
M)P``)0```!LG```?````02<``!T```!A)P``!@```'\G```$````AB<``!``
M``"+)P``$P```)PG```7````L"<```8```#()P``!P```,\G```&````UR<`
M``<```#>)P``-````.8G```5````&R@```X````Q*```!0```$`H```)````
M1B@``"$```!0*```'P```'(H```?````DB@``#````"R*```+P```.,H```A
M````$RD``!P````U*0``!P```%(I```+````6BD```4```!F*0```@```&PI
M``!9````;RD```,```#)*0``(````,TI```D````[BD``"8````3*@``#```
M`#HJ```'````1RH```8```!/*@``,@```%8J```$````B2H```P```".*@``
M"````)LJ```)````I"H```H```"N*@``!P```+DJ```9````P2H```<```#;
M*@```P```.,J```&````YRH```T```#N*@``"P```/PJ```O````""L```P`
M```X*P``,0```$4K```_````=RL```P```"W*P``"@```,0K```"````SRL`
M``8```#2*P```P```-DK```9````W2L``$4```#W*P``,````#TL```2````
M;BP``!,```"!+```$````)4L```)````IBP``!<```"P+```%@```,@L```/
M````WRP``!\```#O+```%`````\M```0````)"T```\````U+0``#P```$4M
M```'````52T```4```!=+0``"````&,M```(````;"T```P```!U+0``!@``
M`((M```&````B2T```0```"0+0``!P```)4M```%````G2T``%H!``"C+0``
M)0```/XN```*````)"\```H````O+P``!P```#HO```%````0B\```X```!(
M+P``"````%<O```)````8"\```T```!J+P``&````'@O```%````D2\```X`
M``"7+P``,P```*8O```*````VB\```D```#E+P``#````.\O```*````_"\`
M``D````',```'@```!$P```3````,#````<```!$,```%@```$PP```C````
M8S````H```"',```"0```)(P``!"````G#```"0```#?,```*@````0Q```/
M````+S$```T````_,0``"@```$TQ```*````6#$```D```!C,0``!@```&TQ
M```8````=#$``!$```"-,0``%````)\Q```A````M#$``#X```#6,0``%```
M`!4R```8````*C(```P```!#,@``"P```%`R```(````7#(``!4```!E,@``
M*@```'LR```'````IC(``!4```"N,@``"0```,0R```-````SC(``"(```#<
M,@```@```/\R```)`````C,```0````,,P``$0```!$S```4````(S,```<`
M```X,P``&0```$`S```0````6C,``#8```!K,P``!P```*(S```F````JC,`
M`!````#1,P``+````.(S``!!````#S0```D```!1-```#````%LT```.````
M:#0```T```!W-```%0```(4T```)````FS0```4```"E-```$@```*LT```N
M````OC0```8```#M-```#P```/0T```/````!#4``!`````4-0``#@```"4U
M```4````-#4```X```!)-0``#0```%@U```0````9C4```D```!W-0``(P``
M`($U```E````I34```0```#+-0``!````-`U```)````U34```<```#?-0``
M&0```.<U```&`````38```<````(-@``#@```!`V```&````'S8```4````F
M-@``"0```"PV```)````-C8```D```!`-@``-````$HV```&````?S8```8`
M``"&-@``#@```(TV```0````G#8```8```"M-@``#0```+0V```0````PC8`
M``P```#3-@``"````.`V```.````Z38``!8```#X-@``$P````\W```,````
M(S<```D````P-P``!````#HW```7````/S<``"<```!7-P``'P```'\W```%
M````GS<``!D```"E-P``"P```+\W```,````RS<```0```#8-P``!0```-TW
M```.````XS<```0```#R-P```@```/<W```%````^C<``#(`````.```$```
M`#,X```+````1#@```D```!0.```"@```%HX```)````93@``!````!O.```
M$0```(`X```2````DC@``!$```"E.```$````+<X```1````R#@```X```#:
M.```#P```.DX```#````^3@```<```#].```#P````4Y```'````%3D```4`
M```=.0``$@```",Y```#````-CD```T````Z.0``"P```$@Y```2````5#D`
M``<```!G.0```@```&\Y```)````<CD``!$```!\.0``"@```(XY```1````
MF3D```8```"K.0``!@```+(Y```&````N3D``"````#`.0``-````.$Y```%
M````%CH```T````<.@``!@```"HZ```'````,3H``"$````Y.@``(P```%LZ
M```R````?SH``!,```"R.@``"0```,8Z```1````T#H```8```#B.@``"```
M`.DZ```C````\CH``!4````6.P``$````"P[```G````/3L```<```!E.P``
M#````&T[```,````>CL```@```"'.P``%@```)`[```?````ISL```@```#'
M.P``"0```-`[```3````VCL```4```#N.P``#P```/0[```+````!#P```X`
M```0/```(````!\\```5````0#P``!\```!6/```)````'8\```>````FSP`
M`!,```"Z/```$````,X\```<````WSP``$T```#\/```10```$H]``!,````
MD#T```H```#=/0``$@```.@]```F````^ST```@````B/@``*0```"L^```B
M````53X``!D```!X/@``!@```)(^```&````F3X``!0```"@/@``#P```+4^
M```3````Q3X```8```#9/@``!````.`^```&````Y3X```<```#L/@``*```
M`/0^```B````'3\``!0```!`/P``!@```%4_```,````7#\``!0```!I/P``
M%````'X_```7````DS\``#<```"K/P``*P```.,_```G````#T```"`````W
M0```!P```%A````2````8$````D```!S0```!````'U```!#````@D````,`
M``#&0```)@```,I````D````\4```"L````600``$@```$)!```&````54$`
M``D```!<00``2````&9!```,````KT$``!8```"\00``$````--!```0````
MY$$``!````#U00``"P````9"```5````$D(```@````H0@```P```#%"```+
M````-4(``!4```!!0@``%````%="```E````;$(```0```"20@``,0```)="
M```Z````R4(```T````$0P``#P```!)#```"````(D,```@````E0P```@``
M`"Y#```4````,4,``$@```!&0P``00```(]#```*````T4,``!8```#<0P``
M#P```/-#```)`````T0```P````-1```&0```!I$```)````-$0``!X````^
M1```$0```%U$```6````;T0``!$```"&1```"@```)A$```&````HT0```8`
M``"J1```!0```+%$```)````MT0```4```#!1```"@```,=$```,````TD0`
M``<```#?1```#P```.=$```%````]T0```$```!:`````````)0`````````
M7``````````-`0``"@$``.L```##````&P````````#5````=0``````````
M````/P````````#7`````````$4```"C````"P```)<```"5````KP```!4`
M````````!P$``",!``#3````2P```+$`````````2@```/0````R````.@``
M`&8```"'````/````!H!````````T0```'X`````````A0```"8```"@````
MC0```(````!D`````````)@```#V``````````@`````````V0````````!/
M`````````&<```![``````````````",````7P````,!``"^````I````"``
M````````T@```((``````````````&\```!V````7@```($````X````````
M`+L```!7````#P$```````!'````G@````P```!J````IP`````````=`0``
MM0```,8```#I````````````````````!`$``!L!````````T````+T```#:
M````'@$``+8````7``````$``.\````9`0``,0```!X```!X````30```.T`
M```3`0``5@```!0```!A````_`````````#N`````````!````!C````````
M`"@```#"`````````#`````8`0````````````"2````/0``````````````
M40```)D```!8````(0````(!``#D````&@```*P````S````%0$``#8`````
M````W0````````"Y````#@$``&P```!]````N`````X```!;````'`$`````
M````````70```$X```#8`````````'0```#U``````````````";````````
M`.4````0`0```````!<!``!R````*0```(D```":````$@```/````"=````
MQ````,H````)`0``D0`````````=````MP```)8```!P````4@```"<```#W
M````J0```.,````&`0```````````````````````.@```#B````(`$``(,`
M```?````SP```-0```"3````1@`````````#````S0```&(````E````I0``
M`&D```!_`````````(8```#,`````````"H``````````````,<```"?````
M/@````4`````````=P```#D```"$````^````$,````N````R0```,4`````
M````+P````````#Z`````````&X```"T````_@`````````?`0``%`$``!@`
M```)````LP````````!4````C@``````````````JP```&````"H````<0``
M`/T```"J````^0```/$```!K````WP```-P`````````$P````<````(`0``
M+0``````````````X0``````````````"@```!$!``!0````OP`````````6
M`0``^P```.P```#;``````````T```#6```````````````D`````````.<`
M``"P````_P````0```"(`````@```"(!```C`````````.````!$````20``
M`%,```!S````K0```)P```"B````#P````````"+`````````(H`````````
M$0```&T``````````````,$```#>````%@````L!``!"````2````!P```#.
M````CP```+(````````````````````9````.P```%D`````````-P``````
M```%`0``D````'P```!,````>0```.8`````````H0```+P```!E````:```
M`"(````A`0```````/,```!5````>@````````"N`````````/(`````````
M0`````8````,`0``$@$``#0```````````````````"F````P````"P````K
M````RP```#4`````````00```,@```#J`````````````````````0$`````
M``"Z`````"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I
M;VX`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`04TO
M4$T`06-C;W5N="!);F9O<FUA=&EO;@!!9&0`061D($AE<F4Z`$%D9"!P86ER
M`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&1R97-S
M`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;&P@075T:&5N
M=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P
M<&QI8V%T:6]N`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<VL@9F]R(&-O;F9I
M<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%V
M86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$)L;V-K(%-E='1I;F=S`$)L;V-K
M(%1Y<&4`0V%L96YD87(`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M871E9V]R:65S(&%N9"!,86)E;',`0V5L;"!0:&]N90!#:&%N9V4@=&AE(&YA
M;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R96%D
M(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAE8VL@=&AE(&)O>"!F;W(@
M86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@
M=&EM92X`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-L;W-E(%=I;F1O=P!#;VQL87!S92!3:61E8F%R`$-O;7!A
M;GD`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0W)E871E`$-R96%T92!A
M(&YE=R!O;F4`0W)E871O<B!097)M:7-S:6]N<P!#=7)R96YT(%1I;64`0W5S
M=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!$1`!$86EL
M>0!$871E`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET>0!$96QE=&4`
M1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T
M;W(N`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@
M3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O=VYL;V%D`$1O=VYL;V%D("5S
M`$5D:70`161I="!";&]C:P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%;6%I;`!%;7!T>2!R97-U;'0N`$5N86)L92!R:6=H
M="!C;&EC:R!C;VYT97AT(&UE;G4_`$5R<F]R`$5V97)Y(#$U(&UI;G5T97,`
M179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU
M=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`
M17AA;7!L92!V86QU97,Z`$5X<&%N9`!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M>`!&:6QE`$9I;&4@36%N86=E<@!&:6QT97)S`$9U;&P@1&5S8W)I<'1I;VX`
M1VQO8F%L($]P=&EO;G,`1V\`1V]O9VQE(%-E87)C:`!'<F]U<',`1W5E<W0@
M4&5R;6ES<VEO;G,`2&5A9&5R<P!(96QP`$AE;6ES<&AE<F4`2&5R92!I<R!T
M:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(;U]M90!(;VUE`$AO;64@061D
M<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T
M97AT`$ED96YT:71Y)W,@;F%M93H`26UA9V5S`$EM<&]R="P@4W1E<"`E9`!)
M;7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F1I=FED=6%L
M(%5S97)S`$QA7WEO=70`3&%N9W5A9V4`3&%S="!L;V=I;CH@)7,`3&%S="!L
M;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,87EO=70`3&ES
M="!(96QP(%1O<&EC<P!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN
M`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`34T`36%I;`!-86YA9V4@=&AE
M(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W
M:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R
M:65S+@!-871C:&EN9R!F:65L9',`365N=2!M;V1E.@!-97-S86=E`$UO;G1H
M;'D`36]O;B!0:&%S97,`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT
M`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``37D@06-C;W5N=`!->2!!8V-O
M=6YT($EN9F]R;6%T:6]N`$YA;64`3F5V97(`3F5W($-A=&5G;W)Y`$YE=W,`
M3F5X=`!.97AT(&]P=&EO;G,`3F\`3F\@=F%L=65S`$YO;F4`3F]R=&AE<FX@
M2&5M:7-P:&5R90!.;W1E<P!/2P!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R
M9V%N:7II;F<`3W1H97(@26YF;W)M871I;VX`4&%S<W=O<F0`4&%S<W=O<F0Z
M`%!A<W-W;W)D.B``4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E
M<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES
M<VEO;@!097)M:7-S:6]N<P!097)S;VYA;"!);F9O<FUA=&EO;@!0:&]N90!0
M;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A
M<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P
M<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R979I;W5S(&]P
M=&EO;G,`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%)E860`4F5F<F5S
M:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T
M86P@5FEE=SH`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M
M;W9E('!A:7(`4F5S970`4F5T=7)N('1O($]P=&EO;G,`4FEC:"!497AT($5D
M:71O<B!/<'1I;VYS`%)O;&4`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E
M;&5C="!A('-E<G9E<@!396QE8W0@86QL`%-E;&5C="!N;VYE`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5T('5P(')E;6]T
M92!S97)V97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P
M;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@
M86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C
M8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO
M=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE
M(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE
M(&QE9G0_`%-H<FEN:P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4V]U=&AE<FX@
M2&5M:7-P:&5R90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%T=7,`4W5B
M:F5C=`!3=6)M:70`4W5C8V5S<P!3=6-C97-S9G5L;'D@<V%V960@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!W<F]T
M92`E<P!3=6YR:7-E+U-U;G-E=`!487-K<P!497AT($]N;'D`5&AE('-E<G9E
M<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@
M8F5E;B!S879E9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4
M:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN
M92X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E
M('!A<G0`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&EC:V5T<P!4:6UE(&9O<FUA=`!4
M:71L90!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T
M:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L
M:6-K:6YG+@!54DP`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`
M56YA8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T
M;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5
M;F9I;&5D`%5P9&%T90!5<V4@:68@;F%M92]P87-S=V]R9"!I<R!D:69F97)E
M;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@3W!T:6]N<P!5<V5R;F%M
M90!5<V5R;F%M93H`57-E<FYA;64Z(`!6:65W("5S`%9I97<@86X@97AT97)N
M86P@=V5B('!A9V4`5V%R;FEN9P!796(`5V5E:VQY`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA
M>2!A9G1E<B!L;V=I;C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@@;V8@=&AE
M("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO
M9RUI;BDZ`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!.86UE`%EO=7(@8W5R<F5N="!T
M:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA
M;64Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!R96UO
M=&4@<V5R=F5R<SH`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`
M7T%D;6EN:7-T<F%T:6]N`%]'<F]U<',`7TAE;'``7TQO9R!O=70`7T]P=&EO
M;G,`7U!E<FUI<W-I;VYS`%]3971U<`!?57-E<G,`961I=`!U;FYA;65D`'9#
M87)D`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@=C,N,2U20S,*4F5P;W)T
M+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T
M:6]N+41A=&4Z(#(P,#8M,#(M,#<@,3$Z,3`K,#(P,`I03RU2979I<VEO;BU$
M871E.B`R,#`V+3`R+3$W(#$W.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!!
M;&5X97D@6F%K:&%R;W8@/&)A8F5R0&UO<V=A+FYE=#X*3&%N9W5A9V4M5&5A
M;3H@4G5S<VEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO
M;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R
M-3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`SN_E\.#VZ/\@
M[^[DY.7PYNKH("5S("T@S^[D\N+E\.;DY>WHY0`Q,BWWX/'NXN[I`#(T+??@
M\>[B[ND`,C0@]^#QX`!!32]030#3]^7R[>#_(.?@[^CQ_`#$[N'@XNCR_`#$
M[N'@XNCR_#H`Q.[AX.+H\OP@[^#P\P#$[N'@XNCR_"!-;WII;&QA(%-I9&5B
M87(`P.3PY?$`P.3PY?'MX/\@ZNWHX^``S>#Q\O#NZ>KH("T@\_'RX.WNXNK@
M(._PX.(@Y.O_(.3P\^/H]2#O[NO\Y^[BX/+EZ^7I`-/O\.#BZ^7MZ.4`S_'E
MXN3N[>CL`,+QY2#B[OCEY/CHY0#"\>4@X_#S[^_[`,+QY2#O\.#BX`#0X.?P
MY?CH\OP@[N_E\.#VZ.@@\>X@\>_H\>K@[.@`P.O\\N7P[>#RZ.+M^^D@25--
M4`#/X/#NZ_PZ`,CL_R#O[NO\Y^[BX/+EZ_\@25--4#H`P?OK[B#SZN#GX.WN
M(.WEZN[P\.7J\NWNY2#G[>#WY>WHY2X`S_#HZ^[FY>WHY0#-X/'R\.[E[>X`
MQ^#O\.#XZ.+@\OP@[^[D\N+E\.;DY>WHY2#OY?#EY"#B^^_NZ^WE[>CE["#N
M[^7PX/;HZ2#NX?'K\^;HXN#MZ/\_`,_N[_ORZN`@\^3@Z^CR_"#MY?'S^>7Q
M\N+S_OGHY2#O\.#BX`#/[N_[\NK@(/#EY.#J\NCP[N+@\OP@[>7Q\_GE\?+B
M\_[YZ.4@[_#@XN``Q.[Q\O/O[?OE(._NZ_\Z`,3E[?P@\.[FY.7MZ/\`S>#Q
M\O#NZ>K@.@#0X/'XZ/#E[>CE`,K@Z^7MY.#P_`#.\NSE[>``SO+LY>W@(.[R
M]^7RX"#N(._P[N'KY>SE`,K@\N7C[O#HZ"#H(.SE\NKH`,KKY?+N]^W@_R#P
MX.3H[O'B_^?\`,W@\?+P[NGJZ"#H[.7MZ"P@X.3PY?'@+"#O[N3OZ/'H+@#.
M\NSE\OSRY2#TZ^#FZN#LZ"#N[^7PX/;H_BCHZ"DL(.KN\N[P^^4@POL@]>[R
MZ/+E(.[Q\_GE\?+BZ/+\+@#"^^'E\.CRY2#O\.CK[N;E[>CE.@#4[O#LX/(@
M[O+NX?#@YN7MZ/\@Y.#R^SH`Q^#J\/OR_"#NZNWN`-/A\.#R_"#LY>W^`,KN
M[._@[>C_`,KN[?3HX_/PX/;H_R#S\?+@\.7KX`#-Y2#L[N/S(.[RZO#[\OP@
M[.[D\^O\($UA:6YT96YA;F-E7U1A<VL@)7,`T>[GY.#R_`#1[N?DX/+\(.WN
MXOOI(._P[O3HZ_P`T>[GY.#RY>O\`-+EZO/YY>4@XO#E[/\`Q^#DX/?H+"#G
MX._S\>K@Y>S[Y2#O\.@@XO7NY.4@XB`E<P#$Q`#%YN7D[>7B[>X`Q.#RX`#6
MXN7R(._N(//L[NOWX.WH_@#/\.[TZ.O\(._N(//L[NOWX.WH_@#3Y.#KZ/+\
M`-/DX.OH\OP@XOOA\.#M[?OI(._P[O3HZ_P`SN_H^.CRY2#O\.[AZ^7L\P#/
M[N3P[N'M[O'RZ"#A^^OH(.?@[^CQX.W[(.(@YO/P[>#K(.3K_R#@Y.SH[>CQ
M\O#@\N[PX"X`RN#RX.ONXP#.\N[A\.#FX/+\(.+PY>S_(.(@,C0M]^#Q[N+N
M["#T[O#LX/+E/P#$\//CZ.4@[>#Q\O#NZ>KH`,WE(.+[Y_OBX.GRY2!M86EN
M=&5N86YC92YP:'`@[>7O[O'PY>3Q\N+E[>WN`,(@[^7PXN[I(/'R\.[JY2#S
MZN#GX.W[(.CLY>W@(._NZ^7I/R#%\>OH(.3@+"#O[O'RX.+\\N4@X^#K[O?J
M\SH@`,?@X_#SY^CR_`#'X./P\^?H\OP@)7,`T.7DX.KRZ/#NXN#MZ.4`T.7D
MX.KRZ/#NXN#R_`#3\?+@[>[BZN`@[_#@XB#DZ_\@)7,`S>#Q\O#NZ>KH`$5M
M86EL`,WSZ^7B[ND@\.7G\^O\\N#R+@#*[NWRY>KQ\NWNY2#LY>W^(._N(.W@
MYN#RZ.@@[_#@XN[I(.KM[N_JZ"#L^_CH`,[XZ.'JX`#*X.;D^^4@,34@[.CM
M\_(`RN#FY/OE(#(@[.CM\_+[`,K@YN3[Y2`S,"#QY>KS[>0`RN#FY/OE(#4@
M[.CM\_(`RN#FY/OI(/#@YR#O\.@@XO7NY.4`RN#FY/OE(._NZ_?@\>``RN#F
MY//^(.SH[?/R\P#/\.CLY?`@Y^W@]^7MZ.DZ`-#@\?CH\.CR_`#"[O'Q\N#M
M[N+KY>WHY2#MX/'R\.[EZB#MY2#SY.#K[O'\+@#-Y?/DX/?M[N4@\>[EY.CM
MY>WHY2#Q(/'E\.+E\.[L($Q$05`N`-3@ZO$`U.#IZP#5\.#MZ.OH^>``U.CK
M_/+P^P#/[NOM[N4@[N_H\>#MZ.4@[_#NX>OE[/LZ`,_N\/+@ZP#/Y?#EZ?+H
M`,_NZ/'J(.(@1V]O9VQE`,/P\^_O^P##[O'R_`#'X./NZ^[BZN@`S^[D\>K@
MY^K@`,_NZ_/XX/#HY0#-Z.;E(._PY>3Q\N#BZ^7MX"#H[?3N\.S@]NC_(.CG
M(/'@[.[C[B#MX/?@Z^`@].#IZ^`Z`,_N\/+@ZP#/[O#RX.L`Q.[LX/CMZ.D@
MX.3PY?$`Q.[LX/CMZ.D@\N7KY?3N[0#/[O#RX.L`TN[K_.KN(.CJ[NWJZ`#(
MZN[MZN@@\2#RY>KQ\N[L`,CL_R#O\.[TZ.O_.@#*X/#RZ.WJZ`#([._N\/(L
M(/C@XR`E9`#([._N\/+H\.[BX.WN(._NZ^4Z("5S`,CL[^[P\NCP[N+@[?L@
M[^[K_SH`S^[K_.?NXN#RY>OH`-#@\>KKX.3JX`#?Y_OJ`,_PY>3[Y//YZ.D@
MXO7NY"#A^^LZ("5S`,_PY>3[Y//YZ.D@XO7NY"#A^^LZ("5S(/$@ZN[L[_S^
M\N7PX"`E<P#/\.7D^^3S^>CI(.+U[N0@[>4@Y^#TZ.KQZ/#NXN#M`,+[]>[D
M`-'OZ/'NZB#PX.?DY>ONXB#O[N3QZN#GZN@`R^[JX.OHY^#VZ/\`T.#Q[^[K
M[N;E[>CE`,+U[N0`POOU[N0`T_?E\NW@_R#GX._H\?P`PO7NY`#,S`#/[O?R
MX`#-X/'R\.[IZN`@\>_H\>K@(.K@\N7C[O#HZ2#H(/;BY?+NXB#H]2#N\N[A
M\.#FY>WH_P#1[N+OX.3@_OGHY2#O[NO_`-#EYNCL(.SE[?XZ`-'N[N'YY>WH
MY0#%YN7LY?'_]^WN`-3@Y_L@R_/M^P#OY?#E[.7Q\NCR_"#B[>CG`._E\.7L
MY?'RZ/+\(.+KY>+N`._E\.7LY?'RZ/+\(.+O\.#B[@#OY?#E[.7Q\NCR_"#B
MXN7P]0#OY?#E[.7Q\NCR_"#B[>CG`._E\.7LY?'RZ/+\(.+BY?#U`-/WY?+M
MX/\@Y^#OZ/'\`,+@^.`@Z.WT[O#LX/;H_P#([/\`S>CJ[N/DX`#-[N+@_R#J
MX/+EX^[PZ/\`S>[B[O'RZ`#$X.OEY0#1Z^7D\_[YX/\@\?+PX.WH]N``S>7R
M`,WE(.[O\.7DY>OE[>X`+>WE(.+[X?#@[2T`T>7BY?#M[N4@[^[K\_C@\.CE
M`,?@[.7RZN@`3TL`S>#Q\O#NZ>KH`,W@\?+P[NGJZ"#DZ_\Z("5S`,[PX^#M
MX.GGY?``S_#N]^#_(.CM].[P[.#VZ/\`S^#P[NO\`,_@\.[K_`#/X/#NZ_P`
MSO'S^>7Q\N+KY>WHY2#N[^7PX/;HZ2#O[N3DY?#FZN@`POOO[NOMZ/+\(.[O
MY?#@]NCH(.[A\>OSYNCBX.WH_R#O\.@@XO7NY.4@XB#QZ/'RY>SS/P#/\.#B
MX`#/\.#BX"#D[O'R\^_@`,OH]^W[Y0#2Y>OE].[M`,+BY>3H\N4@[>#GXN#M
MZ.4@[>[B[ND@ZN#RY>/N\.CH.@#/[N;@Z_/I\?+@+"#Q[N[A^>CRY2#Q\_+\
M(._P[N'KY>S[+@#/[N;@Z_/I\?+@+"#BXN7DZ/+E(,+@^.@@Z.S_(._NZ_SG
M[N+@\N7K_R#H(._@\.[K_`#/\.7D^^3S^>#_(/'R\.#MZ/;@`,_P[N'KY>S@
M/P#.[^CQX.WHY2#O\.[AZ^7L^P#7Z/+@\OP`SN'M[N+H\OP`SN'M[N+K__+\
M(.3H[>#LZ/?E\>KHY2#O\^WJ\OL@[.7M_CH`SN'M[N+K__+\(.CM].[P[.#V
MZ/XZ`,_N]_+NXOOE(/'E\.+E\.``P.3PY?$@\>7PXN7PX"`H[>#O\.CLY?`@
M:'1T<#HO+VUA:6PN<G4I`-/DX.OH\OP`T^3@Z^CR_"#AZ^[J`-/DX.OH\OP@
M[^#P\P#1X?#N\>CR_`#"Y?#M\_+\\?\@ZB#MX/'R\.[IZN#L`,W@\?+P[NGJ
MZ"#BZ.?SX.O\[>[C[B#PY>3@ZO+N\.``T?;E[>#PZ.D`T>[U\.#MZ/+\`-'N
M]?#@[>CR_"#MX/'R\.[IZN@`S^[H\>H`POOAY?#H\N4@\>7PXN7P`,+[X?#@
M\OP@XO'E`,[R[.7MZ/+\(.+[X>[P`,+[X>7PZ/+E(/#@Y^3EZ^CRY>O\(._N
MZ^7I(.3@\OLZ`,+[X>7PZ/+E(/3N\.S@\B#DX/+[.@#"^^'E\.CRY2#O\.[T
MZ.O\(.3K_R#MX/'R\.[IZN@Z`,+[X>7PZ/+E(.[R[N'PX.;E[>C_(/3N\.S@
M\B#B\.7LY>WH.@#"^^'E\.CRY2#DXN`@\>[B[^#DX/[YZ/4@[^[K_RX`PN#X
MX"#VXN7R[N+@_R#Q]>7LX`#?Y_OJ(.[R[N'PX.;E[>C_`,_N\>O@\OP@\>[N
MX?GE[>CE(.X@[_#NX>OE[.4`Q.[O[NOMZ/+EZ_SM^^4@[^[W\N[B^^4@\>7P
MXN7PX"P@ZB#J[O+N\/OL(.+[(/7N\NCRY2#H[.7R_"#D[O'R\^\@Z.<@S^[P
M\N#KX"X`T_'RX.WNXNK@(/_G^^K@(.+[XN[DX"P@XO#E[.7M[>[I(.?N[?L@
MZ"#T[O#LX/+@(.[R[N'PX.;E[>C_(.+PY>SE[>@N`-/Q\N#M[N+JX"#O\.CK
M[N;E[>C_(._N(//L[NOWX.WH_BP@]N+E\N[B[ND@\?7E[/L@Z"#O\.[WZ/4@
M[N_VZ.D@[O+NX?#@YN7MZ/\`S_#HZ^[FY>WH_P#*\.#RZN[E(.[A[N'YY>WH
MY3H`SN_PY>3EZ^CR_"#A^_'R\/OE(.KKX.+H^.@@Y.O_(/'Q^^ONZC\`S^[J
MX.?@\OP`S^[JX.?[XN#R_"#H[?3N\.S@]NC^(.X@[_#EY/OD\_GE["#B]>[D
MY3\`S^[JX.?@\OP@[.7M_B#N[^7PX/;HZ2#Q(/+@X>OH]N#LZ`#.\N[A\.#F
MX/+\(.SE[?X@)7,@\>OEXN`_`-'SY^CR_`#0X.?LY?``S_#N[_/Q\NCR_"#O
M[N3DY?#FZO,`WN;M[N4@[^[K\_C@\.CE`-'OY?;HX.O\[?OE(/'H[.+NZ_L`
MT?+@\O/Q`-+E[.``R/'JX/+\`-/Q[^7X[>X`T?+@\.#_(.KN[?3HX_/PX/;H
M_R#Q[O7PX.WE[>`@XB#TX.GK.B`E<P#-[N+@_R#J[NWTZ./S\.#VZ/\@\>[U
M\.#MY>W@(.(Z("5S`,+PY>S_(.+N\?7NY.`OY^#JX/+@`,?@Y.#WZ`#2[NO\
MZNX@\N7J\?(`T>7PXN7P("5S(.'[ZR#SY.#KY>T`T>7PXN7P("5S(.'[ZR#Q
M[N?DX.T`S>7R(.3N\?+S[^W[]2#MX/'R\.[EZBX`T>[NX?GE[>CE(.(@[>7B
MY?#M[NP@].[P[.#RY2#H(.WE(.SNYN7R(.'[\OP@[O+NX?#@YN7M[@#.^.CA
MZN`@[_#H(.[R[N'PX.;E[>CH(/WR[ND@]^#Q\N@@\>[NX?GE[>C_`-WR[B#W
MZ/'K[B#MY2#L[N;E\B#A^_+\(.SE[?SXY2#EY.CMZ/;[+@#=\NX@Y^W@]^7M
MZ.4@Y.[KYNWN(.'[\OP@]^CQZ^[L+@#'X._P[O'[`-3N\.S@\B#N\N[A\.#F
MY>WH_P#'X./NZ^[B[NH`RN[L\P#7\N[A^R#B^^'PX/+\(.WE\>KNZ_SJ[B#]
MZ^7LY>WR[N(L(//DY?#FZ.+@Z?+E(.W@YN#R[ND@ZNO@XNCF\R!#=')L`%52
M3`#-Y>+NY^SNYNWN(/'NY>3H[>CR_/'_(/$@4U%,(/'E\.+E\.[L+@#-Y>+N
MY^SNYNWN(.?@X_#SY^CR_"#N[_#EY.7KY>WHY2`E<RX`W?+N\B#D[NKS[.7M
M\B!7;W)D(.WE(.SNYN7R(.'[\OP@[^7PY>+EY.7M+@#.\NSE[>CR_"#HY^SE
M[>7MZ/\`S_/Q\N[I`,_PZ.SE[>CR_`#(\>_NZ_SG\^7R\?\@Y?'KZ"#BX/CH
M(.CL_R_OX/#NZ_P@Y.O_($E-4U`@\>7PXN7PX"#N\NOH]^#^\O'_(.[R(/+E
MZO/YZ/4`S^[K_.?NXN#RY>O\`,W@\?+P[NGJZ"#O[NO\Y^[BX/+EZ_\`R.S_
M(._NZ_SG[N+@\N7K_P#([/\@[^[K_.?NXN#RY>O_`,CL_R#O[NO\Y^[BX/+E
MZ_\`S_#N\>SN\O`@)7,`S^[JX.?@\OP@XN7A+?'R\.#MZ/;S`,+MZ.S@[>CE
M`,+EX0#%YN7MY>3EZ_SM[@#$[N'P[B#O[N;@Z^[BX/+\(.(@)7,`Q.[A\.X@
M[^[FX.ONXN#R_"P@)7,`U_+N(.[R[N'PX.;@\OP@[^[QZ^4@XO7NY.`@XB#Q
MZ/'RY>SS.@#4X.?@`,K@ZNCE(.[O]NCH(.'SY//R(.3N\?+S[^W[(.(@XNCG
M\^#K_.WN["#PY>3@ZO+N\.4`V.CPZ.W@(.SE[?X@)7,@\>OEXN`@*.'SY.7R
M(._PZ.SE[>7MX"#O\.@@\>OEY//^^>7L(.+U[N3E*0#0X.'N]^CI(.#D\.7Q
M`-#@X>[WZ.D@\N7KY?3N[0##PP#%YN7C[N3M[@#$X`#"^R#B^_CKZ"#HYR#Q
MZ/'RY>S[+@#"^R#D[NOF[?L@[N_H\>#R_"#O\.[AZ^7L^RP@[_#EYN3E(/?E
M["#Q[.[FY?+E(.[R[O'KX/+\(/'N[N'YY>WHY2#N(.WEZ2X`PN#XX"`E<R#Q
MY?'QZ/\@Y^#J[NWWZ.O@\?PN(,_NYN#K\^GQ\N`L(.+NZ>3H\N4@XB#QZ/'R
MY>SS(.?@[>[B[BX`PN#X($5M86EL.@#"X/@@X.3PY?$@[O+O\.#BZ/+EZ_\Z
M`,+@^.`@Z.WT[O#LX/;H_P#"X/CE(.CL_SH`U^#Q[N+NZ2#O[O_Q`,+@^"#O
M\.[TZ.O\(._N(//L[NOWX.WH_CH`PN#XY2#H[/\Z`,+@^.@@[>#Q\O#NZ>KH
M(.'[Z^@@[N'M[N+KY>W[+@#1\N[P[NWMZ.D@\>7PXN7P.@!;T>[NX?GE[>CE
M(.X@[_#NX>OE[.5=`%OQ\O#NZN`@)7,@Z.<@)7-=`-/O\.#BZ^7MZ.4`P_#S
M[^_[`,_N[.[Y_`#"^_7NY`#-X/'R\.[IZN@`S_#@XN``S_#HZ^[FY>WH_P#/
M[NO\Y^[BX/+EZ^@`S_#@XNCR_`#RY>KQ\B#Q[N[A^>7MZ/\`=D-A<F0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQO8V%L92]R;U]23R],0U]-15-304=%4P``````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P
M,C$U,38`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+W)O7U)/+TQ#7TU%
M4U-!1T53+VAO<F1E+FUO````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S
M-S$U(#$P-3$U-#,T,30Q(#`R,S(T,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````#>$@25`````&0````<````/`,``(D```!<
M!@```````(`(```H````@0@```@```"J"```!0```+,(```(````N0@```<`
M``#""```!0```,H(```?````T`@``!$```#P"```"`````()```(````"PD`
M`!4````4"0``"@```"H)```,````-0D```<```!""0``*0```$H)```"````
M=`D```4```!W"0``$````'T)```4````C@D``"\```"C"0``#P```-,)```F
M````XPD```4````*"@``#0```!`*```%````'@H``!`````D"@``$````#4*
M```/````1@H```L```!6"@``#P```&(*```,````<@H```\```!_"@``'@``
M`(\*```A````K@H```,```#0"@``!````-0*```,````V0H```H```#F"@``
M!0```/$*```2````]PH``!`````*"P``"````!L+```0````)`L```8````U
M"P``!P```#P+```"````1`L```0```!'"P``#P```$P+```'````7`L```<`
M``!D"P``!````&P+```%````<0L```4```!W"P``!P```'T+```1````A0L`
M``@```"7"P``'@```*`+```%````OPL``"@```#%"P``*0```.X+```3````
M&`P```L````L#```$0```#@,```$````2@P```P```!/#```&@```%P,```7
M````=PP``!<```"/#```&P```*<,```?````PPP``!,```#C#```$````/<,
M```7````"`T```<````@#0``!0```"@-```A````+@T``!P```!0#0``!0``
M`&T-```#````<PT``"````!W#0``)@```)@-```,````OPT```P```#,#0``
M"````-D-```'````X@T```8```#J#0``#0```/$-```+````_PT```P````+
M#@``"@```!@.```"````(PX```8````F#@``10```"T.```P````<PX``!``
M``"D#@``'P```+4.```0````U0X```\```#F#@``!0```/8.``!;`0``_`X`
M`"@```!8$```"0```($0```%````BQ````\```"1$```!@```*$0```%````
MJ!```",```"N$```%````-(0```/````YQ````@```#W$```$0`````1```-
M````$A$``!$````@$0``"````#(1```H````.Q$```(```!D$0``!@```&<1
M```4````;A$``!````"#$0``,0```)01```2````QA$``"<```#9$0``!0``
M``$2```9````!Q(```8````A$@``$P```"@2```4````/!(``!,```!1$@``
M%````&42```3````>A(``!````".$@``$@```)\2```9````LA(``"8```#,
M$@```P```/,2```$````]Q(```\```#\$@``$@````P3```%````'Q,``!$`
M```E$P``$@```#<3```%````2A,``!H```!0$P``"0```&L3```+````=1,`
M``(```"!$P``#0```(03```=````DA,```4```"P$P``!0```+83```$````
MO!,```D```#!$P``!````,L3```'````T!,```\```#8$P``!@```.@3```B
M````[Q,```<````2%```)P```!H4```P````0A0``!0```!S%```#P```(@4
M```1````F!0``!````"J%```#P```+L4```4````RQ0``!P```#@%```&P``
M`/T4```B````&14``!L````\%0``&````%@5```5````<14``!8```"'%0``
M!@```)X5```'````I14``!8```"M%0``*````,05```%````[14```,```#S
M%0``(@```/<5```N````&A8``!0```!)%@``$@```%X6```*````<18```<`
M``!\%@``"@```(06```<````CQ8``!$```"L%@``$@```+X6```3````T18`
M``(```#E%@``!0```.@6```Z````[A8``#L````I%P``%@```&47```:````
M?!<``!$```"7%P``$0```*D7```1````NQ<```$````D`````````$X````=
M````3P```!<```!%````!P```"(`````````30```"$`````````2P```&(`
M```*````$0`````````,````,@```%,````Q`````````"4```!&````70``
M``````!2````0@```%4`````````1P```"P````O````5@```%$````U````
M$`````@````^````00```%\````K````#P```#D```!*````(P```!@````S
M````0````"@```!@````"P``````````````5```````````````/0````D`
M````````+@```$@```!<````.@`````````.`````````%D`````````-@``
M```````;````/P```!P````:````#0```#L`````````!`````4`````````
M$@`````````3`````````%<````M`````````"8``````````````!4````&
M`````````%L````W````&0````````!>`````````#@````T`````````$D`
M```?````6@```$0`````````'@``````````````8P````````!8````*0``
M```````P```````````````\````9````%``````````%@```"``````````
M`P```&$```!#````*@```"<```!,`````@`````````4`````"5S($UA:6YT
M96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`,C0@:&]U<G,`04TO
M4$T`061D('!A:7(`061D<F5S<P!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A;&5N
M9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H;VYE`$-L;W-E(%=I
M;F1O=P!#;VUP86YY`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@
M;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`1&ES<&QA>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L
M>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$5M86EL`$5M<'1Y(')E<W5L="X`
M17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F
M97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A
M>`!(96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QA;F=U86=E`$QI<W0@2&5L
M<"!4;W!I8W,`3&]G(&EN`$QO9R!O=70`34T`36%I;`!-871C:&EN9R!F:65L
M9',`365S<V%G90!-;VYT:&QY`$YA;64`3F5V97(`3F]T97,`3W!T:6]N<P!/
M=&AE<B!);F9O<FUA=&EO;@!087-S=V]R9`!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&AO;F4`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y(&]F
M('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N
M9"!P87-S=V]R9`!0<F]B;&5M($1E<V-R:7!T:6]N`%)E;6]V92!P86ER`%)E
M='5R;B!T;R!/<'1I;VYS`%)O;&4`4V%V92!/<'1I;VYS`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6-C97-S`%1A<VMS`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A
M<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I=&QE`%52
M3`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E
M<B!/<'1I;VYS`%5S97)N86UE`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@=&\@
M)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A
M<FQY`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@
M8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA
M=&EO;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M
M(%)E<&]R=%T`6VQI;F4@)7,@;V8@)7-=`'9#87)D`%!R;VIE8W0M260M5F5R
M<VEO;CH@2$]21$4@,BXQ"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U
M.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P,BTP."TP,2`P.3HS-"LP
M,CHP,`I,87-T+51R86YS;&%T;W(Z($-O<FYE;&EU($U54T%4(#QC;75S871`
M:V5Y<WES+G)O/@I,86YG=6%G92U496%M.B!23TU!3DE!3B`\:3$X;D!L:7-T
M<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@
M=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`"5S($]P97)A=&EU;FD@9&4@;65N=&5N86YT
M82`M($-O;F9I<FUA<F4`,C0@9&4@;W)E`$%-+U!-`$%D875G82!P97)E8VAE
M80!!9')E<V$`06QI87,`4RUA('-P96-I9FEC870@;R!V86QO87)E(&EN8V]R
M96-T82X`0VEM<'5R:2!D:7-P;VYI8FEL93H`6FEU82!D92!N87-T97)E`$-A
M;&5N9&%R`%)E;G5N=&$@;&$@4F%P;W)T`%1E;&5F;VX@36]B:6P`26YC:&ED
M92!F97)E87-T<F$`0V]M<&%N:6$`3G4@<&]T(&1E<V-H:61E(&UO9'5L=6P@
M9&4@365N=&5N86YT82`E<P!:6@!::6QN:6,`261E;G1I=&%T92!);7!L:6-I
M=&$`1&5S8W)I92!P<F]B;&5M80!$971A;&EI(&EN<F5G:7-T<F%T92!I;B!,
M3T<@<&5N=')U(&%D;6EN:7-T<F%T;W(N`$]P=&EU;FD@9&4@069I<V%R90!4
M92!R;V<@;G4@86-C97-A(&1I<F5C="!M86EN=&5N86YC92YP:'``16UA:6P`
M16UP='D@<F5S=6QT+B`M(&1E('1R861U<P!%<F]A<F4`3R!D871A(&QA(#$U
M(&UI;G5T90!/(&1A=&$@;&$@,S`@<V5C=6YD90!,82!F:65C87)E(#4@;6EN
M=71E`$QA(&9I96-A<F4@0V]N96-T87)E`$\@9&%T82!L82`S,"!M:6YU=&4`
M26X@9FEE8V%R92!M:6YU=`!%>&5M<&QE(&1E('9A;&]R:3H`3G4@<&]T(&-I
M=&D@<')E9F5R:6YT96QE+@!.=2!M82!P;W0@8V]N96-T82!L82!S97)V97)U
M;"!D92!,1$%0+@!&87@`2&5L<`!!9')E<V$@9&4@86-A<V$`5&5L969O;G5L
M(&1E(&%C87-A`$AO<F1E`$-I;7`@:6UP;W)T870Z("5S`$-I;7!U<FD@:6UP
M;W)T871E.@!,:6UB80!,:7-T82!S=6)I96-T96QO<B!D:6X@2&5L<`!#;VYE
M8W1A<F4`1&5C;VYE8W1A<F4`3$P`0V]R97-P;VYD96YT80!#:6UP=7)I('!O
M=')I=FET92`M(&1E('1R861U<P!-97-A:@!,=6YA<@!.=6UE`$YI8VEO9&%T
M80!.;W1E`$]P=&EU;FD`06QT92!I;F9O<FUA=&EI`%!A<F]L80!%>&5C=71A
M($]P97)A=&EU;FEL92!D92!-96YT96YA;G1A`%1E;&5F;VX`5&4@<F]G('-P
M96-I9FEC82!U;B!S=6UA<B!A;"!P<F]B;&5M96DN`%1E(')O9R!I;G1R;V1U
M('5N(&YU;64@9&4@=71I;&EZ871O<B!S:2!O('!A<F]L80!$97-C<FEE<F5A
M('!R;V)L96UE:0!3=&5R9V4@<&5R96-H96$`26YA<&]I(&QA(&]P=&EU;FD`
M4F]L92`M(&1E('1R861U<P!386QV87IA($]P=&EU;FD`1&5L:6UI=&%T;W(@
M9&4@9&%T83H`1F]R;6%T=6P@9&4@869I<V%R92!A(&1A=&5I.@!&;W)M871U
M;"!D92!A9FES87)E(&$@;W)E:3H`4V5L96-T96%Z82!D;W5A(&-I;7!U<FD@
M<&]T<FEV:71E+@!396QE8W1E87IA(&QI;6)A('!R969E<F%T83H`5')I;6ET
M92!287!O<G0@9&4@17)O87)E`%-A<FD@<&5S=&4@365N=&5N86YT80!#87)A
M8W1E<F4@4W!E8VEA;&4@+BXN`%-U8V-E<P!387)C:6YI`%9A;&]A<F5A(&UI
M;FEM82!E<W1E(#$`06-E87-T82!V86QO87)E('1R96)U:64@<V$@9FEE(&YU
M;65R:6-A+@!4:71L=0!54DP`3G4@;6$@<&]T(&-O;F5C=&$@;&$@<V5R=F5R
M=6P@4U%,+@!.=2!P;W0@=')A9'5C92!A8V5S="!D;V-U;65N="!7;W)D("T@
M9&4@=')A9'5S`$%N=6QE87IA(%-C:&EM8F%R:6QE`$]P=&EU;FD@571I;&EZ
M871O<@!5=&EL:7IA=&]R`$%T96YT:64`4V%P=&%M:6YA;`!":6YE(&%I('9E
M;FET(&EN('-I<W1E;75L("5S`$)I;F4@86D@=F5N:70L("5S`$%D<F5S82!L
M82!397)V:6-I=0!496QE9F]N(&QA(%-E<G9I8VEU`$%!`$%N=6%L`%1R96)U
M:64@<V$@9&5S8W)I:2!P<F]B;&5M82!I;F%I;G1E(&1E(&$@=')I;6ET92!R
M87!O<G1U;"X`4V5S:75N96$@=&$@9&4@)7,@82!E>'!I<F%T+B!492!R;V<@
M<V$@9F%C:2!,;V<@26X@9&EN(&YO=2X`26YF;W)M871I:2!D97-P<F4@=&EN
M90!/<'1I=6YI;&4@874@9F]S="!S86QV871E+@!;4F%P;W)T(%!R;V)L96UA
M70!;;&EN:6$@)7,@9&EN("5S70!V0V%R9"`M(&1E('1R861U<P``````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?4%0O3$-?34534T%'
M15,`````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q-#$@,#(Q-3(T`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]P=%]05"]H96QP+GAM;```````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S8T-B`Q,#4Q-30S-#$T,2`P,C$U,#$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]X;6P@=F5R<VEO
M;CTB,2XP(B!E;F-O9&EN9STB:7-O+3@X-3DM,2(_/@H\(2TM("1(;W)D93H@
M:&]R9&4O;&]C86QE+W!T7U!4+VAE;'`N>&UL+'8@,2XR+C$P+C$@,C`P-B\P
M-R\R-R`Q,SHU,3HP,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I
M9#TB<W5M;6%R>2(@<W1A=&4](G5P=&]D871E(B!M9#4](C8X8V$S,V8W9C!C
M.6%A931C,3`S96(T-S0Y,F-D8S$U(CX*/'1I=&QE/D$@4.%G:6YA(&1O(%!O
M<G1A;#PO=&ET;&4^"B`\<&%R83X*17-T82!PX6=I;F$@9F]R;F5C92!U;2!B
M<F5V92!S=6WA<FEO(&1E('1O9&$@82!S=6$@:6YF;W)M8>?C;R!I;7!O<G1A
M;G1E+@I0;W(@97AE;7!L;RP@<&]D92!M;W-T<F%R('%U86YT87,@;65N<V%G
M96YS(&YO=F%S(&1E(&4M;6%I;"!E>&ES=&5M(&YA('-U82!)3D)/6"P@"F]S
M(&5V96YT;W,@86=E;F1A9&]S(&YO('-E=2!C86QE;F3A<FEO+"!T87)E9F%S
M(&YA('-U82!L:7-T82!D92!A9F%Z97)E<RQO<R!C86)EYV%L:&]S(&1O<R`*
M<V5R=FGG;W,@9&4@;F]T[6-I87,@<V5L96-C:6]N861O<RP@92!M=6ET;R!M
M86ES+@I-=6ET;W,@9&5S=&5S('-U;>%R:6]S(&-O;G3J;2!A=&%L:&]S('+A
M<&ED;W,@<&%R82!A<R!F=6[G]65S(&UA:7,@8V]M=6YS+"!C;VUO(&-O;7!O
M<VGGXV\*9&4@=6UA(&YO=F$@;65N<V%G96T@9&4@92UM86EL+"!C<FEAY^-O
M(&1E('5M(&YO=F\@8V%L96YDX7)I;R!D92!E=F5N=&]S(&]U('1A<F5F87,L
M(&5T8RX*("`@/"]P87)A/@H@/'!A<F$^"D]S(&-O;G1E^F1O<R!D97-T92!P
M;W)T86P@<^-O('!E<G-O;F%L:7KA=F5I<R!A=')A=NES(&1E('5M(&)O=.-O
M(&1E($QA>6]U="X*4&]R(&5X96UP;&\L('!O9&4@97-C;VQH97(@<75A:7,@
M;W,@:71E;7,@82!I;F-L=6ER(&YE<W1E('!O<G1A;"!E(&$@<W5A(&]R9&5M
M(&1E(&%P<F5S96YT8>?C;PH@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB8CAC9C!A93$Y934W
M9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N
M($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@I.;R!L861O(&5S<75E
M<F1O(&1A('#A9VEN82!W96(@97-TX2!A(&)A<G)A(&1E(&YA=F5G8>?C;RX*
M0VQI<75E(&YO<R#M8V]N97,@9&5S=&$@8F%R<F$@9&4@;F%V96=AY^-O('!A
M<F$@<N%P:61A(&4@9N%C:6QM96YT92!E<V-O;&AE<B`*87,@87!L:6-AY_5E
M<R!D:7-P;V[M=F5I<RX@"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED
M/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](G5P=&]D871E(B!M9#4]
M(F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ.3(X.&(R9#`P(CX*("`@(#QT:71L
M93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T
M:71L93X*("`@(#QP87)A/@I392!P<F5T96YD97(@<F5A;&EZ87(@;W!E<F'G
M]65S(&1E(&UA;G5T96[GXV\@;F\@;&]G:6XL('-E;&5C8VEO;F4@97-T82!C
M86EX82X*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q
M-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^4')E
M9F5RZFYC:6%S.B!-86YU=&5NY^-O.B!#;VYF:7)M87(@36%N=71E;N?C;SPO
M=&ET;&4^"B`@("`\<&%R83X*4V4@<')E=&5N9&5R(&-O;F9I<FUA<B!T;V1A
M<R!A<R!T87)E9F%S(&1E(&UA;G5T96[GXV\@86YT97,@9&4@<V5R96T@87!L
M:6-A9&%S+"!S96QE8V-I;VYE(&5S=&$@8V%I>&$N"E-E(&[C;R!S96QE8V-I
M;VYA<B!E<W1A(&-A:7AA+"!T;V1A<R!A<R!O<&5R8>?U97,@9&4@;6%N=71E
M;N?C;R!S97+C;R!R96%L:7IA9&%S(&%U=&]MX71I8V%M96YT92!S96T@82!O
M<.?C;R!D90IC86YC96QA<B!N;R!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R
M>3X*/"]H96QP/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?
M4%0O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`T,C<S,C<@,3`U,34T,S0Q-#$@,#(S,C8P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````-X2!)4`````<P<``!P```"T
M.P``[PD``$QW````````")\``$T````)GP``OP```%>?``!D````%Z```+X`
M``!\H```D````#NA``!#````S*$``#P````0H@``*P```$VB```N````>:(`
M`"D```"HH@``*````-*B``!%````^Z(``$<```!!HP``2@```(FC``!'````
MU*,``$4````<I```2````&*D```Y````JZ0``$8```#EI```2````"RE```P
M````=:4``$4```"FI0``1@```.RE``!,````,Z8``#0```"`I@``,@```+6F
M``!I````Z*8``#````!2IP``)0```(.G``"(````J:<``$`````RJ```]@``
M`'.H``!*````:JD``"P```"UJ0``A0```.*I``!(````:*H```X```"QJ@``
M#P```,"J```-````T*H```@```#>J@``"P```.>J```,````\ZH```0`````
MJP``&P````6K```M````(:L``!T```!/JP``)````&VK```I````DJL``!D`
M``"\JP``#````-:K```1````XZL``"4```#UJP``#P```!NL```+````*ZP`
M`!$````WK```#@```$FL```%````6*P``"@```!>K```"````(>L```*````
MD*P``!4```";K```$@```+&L```+````Q*P``!,```#0K```#@```.2L```*
M````\ZP```T```#^K```+@````RM```.````.ZT``!$```!*K0``#0```%RM
M```,````:JT```T```!WK0``!@```(6M```*````C*T```\```"7K0``&```
M`*>M```,````P*T``!L```#-K0``#@```.FM```.````^*T```@````'K@``
M"0```!"N``!"````&JX``"X```!=K@``&@```(RN```R````IZX``#@```#:
MK@``5````!.O``!1````:*\``%H```"ZKP``5P```!6P```T````;;````D`
M``"BL```#0```*RP```'````NK````H```#"L```#P```,VP```%````W;``
M``8```#CL```$0```.JP```(````_+````D````%L0``"0````^Q```E````
M&;$``"`````_L0``$````&"Q```/````<;$```H```"!L0```P```(RQ```/
M````D+$``!0```"@L0``"0```+6Q```-````O[$``!(```#-L0``&0```."Q
M```>````^K$```\````9L@``"@```"FR```/````-+(```@```!$L@``)```
M`$VR```4````<K(``!8```"'L@``"````)ZR``!.````I[(``"T```#VL@``
M'P```"2S```9````1+,```<```!>LP``#````&:S```L````<[,```X```"@
MLP```P```*^S```+````L[,```<```"_LP``!P```,>S```%````S[,```4`
M``#5LP``"@```-NS```#````YK,``!<```#JLP``"@````*T```/````#;0`
M``X````=M```&````"RT```C````1;0```X```!IM```%````'BT```7````
MC;0``!<```"EM```%P```+VT```3````U;0```\```#IM```#@```/FT```?
M````"+4``!T````HM0``!P```$:U```&````3K4```@```!5M0``#P```%ZU
M```&````;K4```H```!UM0``$P```("U```+````E+4``!4```"@M0``%0``
M`+:U```'````S+4``!````#4M0``!0```.6U```5````Z[4``!$````!M@``
M#````!.V```[````(+8``#@```!<M@``"0```)6V```'````G[8``!0```"G
MM@```P```+RV```%````P+8``!````#&M@``"0```->V```3````X;8``#D`
M``#UM@``$@```"^W```G````0K<``"P```!JMP``*@```)>W```E````PK<`
M``H```#HMP``!@```/.W```)````^K<```<````$N```+P````RX```W````
M/+@``"X```!TN```50```*.X```M````^;@``"T````GN0``+0```%6Y``!`
M````@[D``",```#$N0``(P```.BY```M````#+H``#,````ZN@``%0```&ZZ
M```9````A+H``"D```">N@``)````,BZ```1````[;H```H```#_N@``#```
M``J[```*````%[L``!`````BNP``%@```#.[```6````2KL```<```!ANP``
M!P```&F[```4````<;L```H```"&NP``"````)&[```(````FKL```<```"C
MNP``!P```*N[```&````L[L```4```"ZNP``!P```,"[```&````R+L```@`
M``#/NP``*0```-B[```.`````KP```H````1O```!````!R\```'````(;P`
M``D````IO```!@```#.\```1````.KP```<```!,O```%@```%2\```$````
M:[P```@```!PO```!@```'F\```-````@+P```8```".O```'@```)6\```1
M````M+P``"(```#&O```%@```.F\```(`````+T```T````)O0``#````!>]
M```'````)+T```,````LO0```P```#"]```7````-+T``!,```!,O0``'0``
M`&"]```(````?KT```0```"'O0``"````(R]```(````E;T``$$```">O0``
M(````."]```&`````;X```8````(O@``%0````^^```8````);X``"(````^
MO@``+@```&&^```=````D+X``"$```"NO@``5````-"^```I````);\```H`
M``!/OP``!P```%J_```5````8K\```X```!XOP``"@```(>_```/````DK\`
M``T```"BOP``#P```+"_```-````P+\```D```#.OP``%````-B_```&````
M[;\``!@```#TOP``'0````W````3````*\```!$````_P```%````%'````$
M````9L````8```!KP```5````'+````$````Q\````X```#,P```1````-O`
M```%````(,$```4````FP0``&P```"S!```:````2,$``!$```!CP0``$0``
M`'7!```<````A\$``"H```"DP0``$````,_!```A````X,$``"4````"P@``
M&0```"C"```%````0L(``!,```!(P@``$@```%S"```*````;\(```\```!Z
MP@``#0```(K"```1````F,(``!,```"JP@``#````+["```&````R\(```P`
M``#2P@``!@```-_"```7````YL(``!````#^P@``$0````_#```(````(<,`
M``4````JPP``#````###```0````/<,```4```!.PP``#0```%3#```&````
M8L,```<```!IPP``#0```''#```0````?\,```D```"0PP``!P```)K#```+
M````HL,```L```"NPP``!P```+K#```'````PL,``!0```#*PP``"0```-_#
M```)````Z<,```H```#SPP``&0```/[#```=````&,0```P````VQ```$```
M`$/$```%````5,0``"4```!:Q```$@```(#$```3````D\0``"L```"GQ```
M.P```-/$```@````#\4``#8````PQ0``(0```&?%```0````B<4```@```":
MQ0``#````*/%```&````L,4```0```"WQ0``#@```+S%```0````R\4```H`
M``#<Q0``#0```.?%```>````]<4``!L````4Q@``(0```##&```>````4L8`
M`!D```!QQ@``'@```(O&```;````JL8``"X```#&Q@``%P```/7&```F````
M#<<``#`````TQP``&P```&7'```>````@<<``!P```"@QP``)@```+W'```K
M````Y,<``#,````0R```)@```$3(```K````:\@``#@```"7R```'0```-#(
M```5````[L@``"\````$R0``(````#3)```2````5<D``"D```!HR0``'@``
M`)+)```2````L<D``*(```#$R0``%@```&?*```C````?LH``"@```"BR@``
M*0```,O*```H````]<H``!\````>RP``%0```#[+```@````5,L``"4```!U
MRP``*````)O+```M````Q,L``#````#RRP``D@```"/,```A````MLP``!8`
M``#8S```'````._,```F````#,T``"H````SS0``00```%[-``!$````H,T`
M``P```#ES0``!P```/+-```'````^LT```8````"S@``#0````G.```0````
M%\X``!(````HS@``$P```#O.```2````3\X```<```!BS@``!````&K.```0
M````;\X```P```"`S@``#@```(W.```/````G,X``!,```"LS@``#0```,#.
M```H````SLX```,```#WS@``#0```/O.```&````"<\``!$````0SP``%P``
M`"+/```;````.L\```X```!6SP```@```&7/```%````:,\``!````!NSP``
M!````'_/```-````A,\```X```"2SP```P```*'/```.````I<\```@```"T
MSP``#P```+W/```/````S<\```<```#=SP``#0```.7/```0````\\\``!,`
M```$T```$P```!C0```+````+-````8````XT```#````#_0```1````3-``
M`!D```!>T```"P```'C0```-````A-```"(```"2T```&P```+70```T````
MT=````H````&T0``&````!'1```9````*M$``!8```!$T0``+P```%O1```B
M````B]$```T```"NT0``!P```+S1```4````Q-$```L```#9T0``(@```.71
M```O````"-(```L````XT@``"0```$32```9````3M(```L```!HT@``%P``
M`'32```7````C-(```D```"DT@``%@```*[2```/````Q=(``!D```#5T@``
M%@```._2```.````!M,``!@````5TP``"````"[3```-````-],``"8```!%
MTP``0P```&S3```(````L-,``!(```"YTP``"````,S3```+````U=,``"\`
M``#ATP``#@```!'4```%````(-0```8````FU````P```"W4```'````,=0`
M``0````YU```"@```#[4```*````2=0```\```!4U```$````&34```7````
M==0``!$```"-U```&0```)_4```7````N=0```D```#1U```!0```-O4```+
M````X=0```H```#MU````@```/C4```%````^]0```T````!U0``&P````_5
M```7````*]4```D```!#U0``#@```$W5```-````7-4``!(```!JU0``.```
M`'W5```@````MM4```@```#7U0``#@```.#5``![````[]4``!@```!KU@``
M0````(36```1````Q=8```<```#7U@``!0```-_6```9````Y=8``!,```#_
MU@``!P```!/7```'````&]<```@````CUP``!@```"S7```&````,]<``!``
M```ZUP``#P```$O7```0````6]<```\```!LUP``"P```'S7```/````B-<`
M``P```"8UP``#P```*77```'````M=<```H```"]UP``!@```,C7```.````
MS]<```P```#>UP``*````.O7```/````%-@```@````DV```%@```"W8```(
M````1-@``!,```!-V```'@```&'8```A````@-@``"````"BV```&0```,/8
M```7````W=@``"4```#UV```%P```!O9```$````,]D``!L````XV0``#0``
M`%39```,````8MD```,```!OV0``"````'/9```*````?-D```P```"'V0``
M"P```)39```0````H-D```P```"QV0``!````+[9```3````P]D``!0```#7
MV0``#````.S9```)````^=D```X````#V@``"P```!+:```;````'MH```<`
M```ZV@``!P```$+:```*````2MH```T```!5V@``"0```&/:```$````;=H`
M``4```!RV@```P```'C:```8````?-H```H```"5V@``!````*#:```F````
MI=H```X```#,V@``?````-O:```5````6-L```4```!NVP``!P```'3;```,
M````?-L```@```")VP``"@```)+;```&````G=L```@```"DVP``%@```*W;
M```2````Q-L```(```#7VP``!@```-K;```&````X=L``!0```#HVP``#0``
M`/W;```0````"]P``!L````<W```!````#C<```)````/=P``!````!'W```
M"0```%C<```)````8MP```4```!LW```!0```'+<```:````>-P```@```"3
MW```!@```)S<```9````H]P```X```"]W```(@```,S<```'````[]P```<`
M``#WW```#@```/_<```%````#MT```D````4W0``"@```![=```"````*=T`
M``8````LW0``#0```#/=```)````0=T```8```!+W0``$@```%+=```)````
M9=T```<```!OW0``%````'?=```=````C-T``!$```"JW0``!@```+S=```*
M````P]T```0```#.W0``"0```-/=```(````W=T``!$```#FW0``$0```/C=
M```)````"MX```8````4W@``#0```!O>```&````*=X```0````PW@``.0``
M`#7>```]````;]X``#H```"MW@``'@```.C>```%````!]\```X````-WP``
M!````!S?```&````(=\``"$````HWP``#0```$K?```5````6-\```8```!N
MWP``!````'7?```1````>M\```8```",WP``H````)/?```*````-.```"(`
M```_X```!````&+@```E````9^````4```"-X```'0```)/@```$````L>``
M``P```"VX```"@```,/@```(````SN````D```#7X```!0```.'@```;````
MY^```#H````#X0``,````#[A```U````;^$``"D```"EX0``+@```,_A``!'
M````_N$``#@```!&X@``*0```'_B```_````J>(``"X```#IX@``+0```!CC
M```?````1N,```\```!FXP``$@```';C```+````B>,``"8```"5XP``*0``
M`+SC```D````YN,``"8````+Y```"````#+D```*````.^0```D```!&Y```
M!P```%#D```@````6.0``"````!YY```)@```)KD```*````P>0``!D```#,
MY```*0```.;D```6````$.4``!(````GY0``!P```#KE```*````0N4```\`
M``!-Y0``$````%WE``!`````;N4``'````"OY0``9@```"#F```.````A^8`
M``D```"6Y@``"@```*#F```2````J^8``!,```"^Y@``#````-+F```&````
MW^8```\```#FY@``$@```/;F```0````"><``!$````:YP``'````"SG```C
M````2><``&H```!MYP``#P```-CG```%````Z.<``!````#NYP``"0```/_G
M```$````">@```L````.Z```(````!KH```:````.^@``!0```!6Z```#```
M`&OH```,````>.@```\```"%Z```%0```)7H```I````J^@``"H```#5Z```
M)@````#I```G````)^D``"D```!/Z0``*@```'GI```9````I.D``$(```"^
MZ0``$0````'J```2````$^H``!,````FZ@``%````#KJ```/````3^H``!8`
M``!?Z@``%P```';J```0````CNH``!$```"?Z@``-````+'J```3````YNH`
M`!(```#ZZ@``-0````WK```4````0^L```<```!8ZP``#````&#K```@````
M;>L``!````".ZP``%````)_K```1````M.L``!<```#&ZP``'````-[K```3
M````^^L``!0````/[```&@```"3L```1````/^P``!H```!1[```'@```&SL
M```:````B^P``!,```"F[```%0```+KL```1````T.P``!<```#B[```%```
M`/KL```7````#^T``!4````G[0``"0```#WM```9````1^T```0```!A[0``
M!P```&;M```+````;NT``!$```!Z[0``!@```(SM```&````D^T```8```":
M[0``!0```*'M```'````I^T```<```"O[0``!0```+?M```6````O>T```8`
M``#4[0``!@```-OM```$````XNT```0```#G[0``!P```.SM```.````].T`
M``P````#[@``#````!#N```-````'>X```H````K[@``#@```#;N```%````
M1>X``"@```!+[@``#@```'3N```,````@^X```\```"0[@``"@```*#N```(
M````J^X```D```"T[@``*P```+[N```$````ZNX```@```#O[@``)@```/CN
M```2````'^\```\````R[P``!@```$+O```*````2>\```<```!4[P``"```
M`%SO```@````9>\```D```"&[P``#````)#O```-````G>\```X```"K[P``
M%@```+KO```1````T>\```8```#C[P```P```.KO```&````[N\``!D```#U
M[P``!P````_P```$````%_````L````<\```"P```"CP```'````-/````<`
M```\\```%@```$3P```-````6_````T```!I\```"@```'?P```0````@O``
M``\```"3\```$0```*/P```7````M?````H```#-\```$0```-CP```(````
MZO````0```#S\```#P```/CP```Z````"/$```4```!#\0``#````$GQ```>
M````5O$```X```!U\0``$````(3Q```+````E?$```P```"A\0``"0```*[Q
M```'````N/$```H```#`\0``"0```,OQ```.````U?$``!````#D\0``&@``
M`/7Q```*````$/(```D````;\@``%````"7R```*````.O(```P```!%\@``
M#P```%+R```(````8O(```8```!K\@``!P```'+R```+````>O(``$<```"&
M\@``#0```,[R```)````W/(```0```#F\@```P```.OR```3````[_(``!,`
M```#\P``$P```!?S```*````*_,```(````V\P``!````#GS```E````/O,`
M``,```!D\P``!0```&CS```J````;O,```H```"9\P``!0```*3S```$````
MJO,```H```"O\P``#0```+KS``!`````R/,``!,````)]```!@```!WT```(
M````)/0```@````M]```!````#;T```%````._0``&@```!!]```"0```*KT
M```,````M/0```4```#!]```!@```,?T```;````SO0``"\```#J]```$```
M`!KU```*````*_4```\````V]0``"@```$;U```)````4?4``!,```!;]0``
M&P```&_U```8````B_4``!<```"D]0``#@```+SU```#````R_4```<```#/
M]0``"````-?U```'````X/4```H```#H]0``"P```//U```M````__4``!4`
M```M]@``,````$/V```D````=/8```<```"9]@``40```*'V```0````\_8`
M``P````$]P``#0```!'W```:````'_<``$H````Z]P``&0```(7W```&````
MG_<``!H```"F]P``!@```,'W```&````R/<``!\```#/]P``!@```._W```)
M````]O<``!@`````^```%P```!GX```&````,?@```T````X^```(@```$;X
M``!7````:?@``!,```#!^```(P```-7X```3````^?@```(````-^0``"P``
M`!#Y```(````'/D```T````E^0``"@```#/Y```&````/OD```<```!%^0``
M%````$WY```&````8OD```@```!I^0``#@```'+Y```'````@?D```H```")
M^0``"P```)3Y```'````H/D```P```"H^0``#0```+7Y```,````P_D```D`
M``#0^0``"0```-KY```*````Y/D```<```#O^0``"0```/?Y```'`````?H`
M``H````)^@``&P```!3Z```2````,/H```H```!#^@``"0```$[Z```0````
M6/H```<```!I^@``$@```''Z```$````A/H```<```")^@``!0```)'Z```%
M````E_H```L```"=^@``%````*GZ```1````OOH``!H```#0^@``%@```.OZ
M```4`````OL``!<````7^P``&````"_[```<````2/L``!D```!E^P``!P``
M`'_[```%````A_L```T```"-^P``#````)O[```(````J/L``!<```"Q^P``
M"P```,G[```3````U?L```0```#I^P``"@```.[[```$````^?L```T```#^
M^P``#`````S\```%````&?P```D````?_```!0```"G\```'````+_P```4`
M```W_```!````#W\```"````0OP``#@```!%_```+````'[\```2````J_P`
M`"D```"^_```,@```.C\```*````&_T``#8````F_0``+````%W]```5````
MBOT``"X```"@_0``,P```,_]```S`````_X``#@````W_@``#P```'#^```8
M````@/X``#L```"9_@``$````-7^```4````YOX``!,```#[_@``%0````__
M```4````)?\``!(````Z_P``%````$W_```5````8O\``"T```!X_P``+0``
M`*;_```Q````U/\``"T````&``$`+@```#0``0`O````8P`!`"P```"3``$`
M8@```,```0`3````(P$!``@````W`0$`"````$`!`0`K````20$!`"$```!U
M`0$`&@```)<!`0`)````L@$!`$4```"\`0$`00````("`0`$````1`(!`!,`
M``!)`@$`%````%T"`0`.````<@(!`!,```"!`@$`&````)4"`0`&````K@(!
M``D```"U`@$`"@```+\"`0`/````R@(!`!````#:`@$`!P```.L"`0`.````
M\P(!``4````"`P$`&P````@#`0`&````)`,!``@````K`P$`!@```#0#`0`4
M````.P,!`!$```!0`P$`#@```&(#`0`X````<0,!``(```"J`P$`!@```*T#
M`0`.````M`,!`!H```##`P$`!0```-X#`0`'````Y`,!``X```#L`P$`!@``
M`/L#`0`$`````@0!`"D````'!`$`%P```#$$`0`?````200!`%P```!I!`$`
M%````,8$`0`^````VP0!`!\````:!0$`$````#H%`0`'````2P4!``X```!3
M!0$`"````&(%`0`,````:P4!``P```!X!0$`$P```(4%`0`*````F04!`!T`
M``"D!0$`&0```,(%`0`%````W`4!`!$```#B!0$`$0```/0%`0`D````!@8!
M`!4````K!@$`$@```$$&`0`.````5`8!`!D```!C!@$`"````'T&`0`)````
MA@8!``T```"0!@$`"@```)X&`0`'````J08!``\```"Q!@$`!@```,$&`0`+
M````R`8!``H```#4!@$`!P```-\&`0`(````YP8!``4```#P!@$`'P```/8&
M`0`&````%@<!`!`````=!P$`"````"X'`0`-````-P<!``@```!%!P$`$@``
M`$X'`0`L````80<!`!H```".!P$`"0```*D'`0`*````LP<!`!4```"^!P$`
M!0```-0'`0`4````V@<!``0```#O!P$`$````/0'`0`&````!0@!``<````,
M"`$`'@```!0(`0`H````,P@!``H```!<"`$`'````&<(`0`:````A`@!``\`
M``"?"`$`%````*\(`0`$````Q`@!``0```#)"`$`"P```,X(`0`%````V@@!
M``8```#@"`$`"````.<(`0`&````\`@!``H```#W"`$`&P````()`0`T````
M'@D!`#0```!3"0$`(````(@)`0`I````J0D!`"````#3"0$`00```/0)`0`:
M````-@H!`"@```!1"@$`*0```'H*`0!1````I`H!`"\```#V"@$`(@```"8+
M`0`&````20L!``@```!0"P$`!0```%D+`0`(````7PL!`!D```!H"P$`&0``
M`((+`0`J````G`L!`",```#'"P$`&0```.L+`0`N````!0P!`#0````T#`$`
M"````&D,`0`7````<@P!``H```"*#`$`!P```)4,`0`A````G0P!`!````"_
M#`$`#@```-`,`0`+````WPP!``<```#K#`$`$P```/,,`0`(````!PT!``L`
M```0#0$`"@```!P-`0`4````)PT!``\````\#0$`,@```$P-`0`+````?PT!
M``4```"+#0$`!0```)$-`0`7````EPT!``\```"O#0$`!````+\-`0`*````
MQ`T!``D```#/#0$`"P```-D-`0`-````Y0T!``P```#S#0$`#@`````.`0`%
M````#PX!``0````5#@$`#0```!H.`0`R````*`X!`$4```!;#@$`%P```*$.
M`0`>````N0X!`!0```#8#@$`!0```.T.`0`4````\PX!``<````(#P$`#@``
M`!`/`0`J````'P\!``8```!*#P$`#````%$/`0`-````7@\!`!$```!L#P$`
M"P```'X/`0`V````B@\!``H```#!#P$`(@```,P/`0`+````[P\!``\```#[
M#P$`,@````L0`0`E````/A`!`#````!D$`$`,0```)40`0`M````QQ`!``X`
M``#U$`$`!0````01`0`.````"A$!`!,````9$0$`!P```"T1`0`:````-1$!
M``@```!0$0$`$0```%D1`0`'````:Q$!`!0```!S$0$`&````(@1`0`'````
MH1$!``4```"I$0$`#````*\1`0`,````O!$!`!(```#)$0$`!````-P1`0`'
M````X1$!``H```#I$0$`"P```/01`0`,`````!(!``X````-$@$`#@```!P2
M`0`%````*Q(!``4````Q$@$`+@```#<2`0`F````9A(!`",```"-$@$``P``
M`+$2`0`2````M1(!``8```#($@$`'@```,\2`0`8````[A(!`"4````'$P$`
M#0```"T3`0`)````.Q,!``,```!%$P$`!P```$D3`0`*````41,!``(```!<
M$P$`#````%\3`0`5````;!,!``L```""$P$`&0```(X3`0`@````J!,!`!(`
M``#)$P$`!0```-P3`0`*````XA,!`!4```#M$P$`$@````,4`0`,````%A0!
M``0````C%`$`!P```"@4`0`)````,!0!``P````Z%`$`4@```$<4`0`7````
MFA0!`"0```"R%`$`$@```-<4`0`'````ZA0!``8```#R%`$`#@```/D4`0`B
M````"!4!`!T````K%0$`#````$D5`0`-````5A4!`!4```!D%0$`$@```'H5
M`0`/````C14!`!0```"=%0$`&P```+(5`0`0````SA4!`&D```#?%0$`&@``
M`$D6`0`7````9!8!`"<```!\%@$`&@```*06`0`7````OQ8!`!L```#7%@$`
M&0```/,6`0`?````#1<!`!,````M%P$`"````$$7`0`'````2A<!``@```!2
M%P$`"0```%L7`0`5````91<!``T```![%P$`(P```(D7`0`3````K1<!``,`
M``#!%P$`1@```,47`0`_````#!@!`#<```!,&`$`5P```(08`0`%````W!@!
M`!\```#B&`$`+P````(9`0`*````,AD!``@````]&0$`#0```$89`0`M````
M5!D!``0```""&0$`3P```(<9`0`E````UQD!`!P```#]&0$`"P```!H:`0`?
M````)AH!`!T```!&&@$`)0```&0:`0`@````BAH!`"0```"K&@$`(````-`:
M`0`+````\1H!``<```#]&@$`#0````4;`0`,````$QL!`!<````@&P$`!@``
M`#@;`0`Y````/QL!``P```!Y&P$`!P```(8;`0`9````CAL!``D```"H&P$`
M$P```+(;`0`)````QAL!``0```#0&P$`$````-4;`0`*````YAL!``@```#Q
M&P$`"````/H;`0`$`````QP!``L````('`$`#````!0<`0`2````(1P!`!$`
M```T'`$`#````$8<`0`:````4QP!``\```!N'`$`!P```'X<`0`-````AAP!
M`!0```"4'`$`#@```*D<`0`,````N!P!`!L```#%'`$`+````.$<`0`3````
M#AT!`!P````B'0$`*````#\=`0`&````:!T!``<```!O'0$`$P```'<=`0`%
M````BQT!``0```"1'0$`%P```)8=`0`*````KAT!``P```"Y'0$`"0```,8=
M`0`&````T!T!``D```#7'0$`"````.$=`0`)````ZAT!``H```#T'0$`$0``
M`/\=`0`&````$1X!`!@````8'@$`#@```#$>`0`.````0!X!``T```!/'@$`
M"P```%T>`0`=````:1X!``L```"''@$``@```),>`0`'````EAX!``8```">
M'@$`90```*4>`0`)````"Q\!``<````5'P$`)@```!T?`0`X````1!\!`!H`
M``!]'P$`*@```)@?`0`[````PQ\!`"@```#_'P$`-````"@@`0`9````72`!
M`!4```!W(`$`!0```(T@`0`'````DR`!``@```";(`$`!P```*0@`0`%````
MK"`!``<```"R(`$`#@```+H@`0`)````R2`!``8```#3(`$`"````-H@`0`+
M````XR`!``<```#O(`$`"````/<@`0`'`````"$!`!8````((0$`"0```!\A
M`0`&````*2$!``L````P(0$`'````#PA`0`4````62$!``<```!N(0$`$0``
M`'8A`0`(````B"$!``X```"1(0$`"````*`A`0`%````J2$!`!````"O(0$`
M$````,`A`0`&````T2$!`!D```#8(0$`"@```/(A`0`<````_2$!``<````:
M(@$`!0```"(B`0`0````*"(!`!0````Y(@$`"P```$XB`0`-````6B(!`"@`
M``!H(@$`&````)$B`0`7````JB(!``0```#"(@$`"0```,<B`0`*````T2(!
M``<```#<(@$``@```.0B`0`.````YR(!``@```#V(@$`'P```/\B`0`^````
M'R,!`",```!>(P$`.````((C`0`F````NR,!`#$```#B(P$`)P```!0D`0!D
M````/"0!`!0```"A)`$`50```+8D`0`X````#"4!`$H```!%)0$`6P```)`E
M`0`H````["4!`#@````5)@$`*````$XF`0`L````=R8!`"<```"D)@$`&P``
M`,PF`0`^````Z"8!`*D!```G)P$`*````-$H`0`C````^B@!`!<````>*0$`
M2````#8I`0"%````?RD!`#`````%*@$`00```#8J`0!;````>"H!`$D```#4
M*@$`'0```!XK`0`8````/"L!`"$```!5*P$`'P```'<K`0`K````ERL!`"$`
M``##*P$`)P```.4K`0`=````#2P!`!$````K+`$`,P```#TL`0`E````<2P!
M`"<```"7+`$`'P```+\L`0`P````WRP!`&D````0+0$`*P```'HM`0`Q````
MIBT!`$$```#8+0$`,P```!HN`0`E````3BX!`#T```!T+@$`90```+(N`0!-
M````&"\!`"\```!F+P$`+@```)8O`0`P````Q2\!`%0```#V+P$`@P```$LP
M`0!:````SS`!`$@````J,0$`2@```',Q`0`R````OC$!`"\```#Q,0$`+```
M`"$R`0`M````3C(!`'$```!\,@$`;P```.XR`0"S````7C,!`!<````2-`$`
M)0```"HT`0`R````4#0!`"D```"#-`$`/@```*TT`0`B````[#0!`%(````/
M-0$`)0```&(U`0`+````B#4!`+$```"4-0$`10```$8V`0`A````C#8!`"X`
M``"N-@$`,````-TV`0`E````#C<!`!P````T-P$`,0```%$W`0`'````@S<!
M``<```"+-P$`!````),W`0`-````F#<!``L```"F-P$`#@```+(W`0`+````
MP3<!``4```#--P$`$````-,W`0`"````Y#<!`%D```#G-P$`!0```$$X`0`2
M````1S@!``0```!:.`$`!P```%\X`0`(````9S@!``4```!P.`$``P```'8X
M`0`0````>C@!``H```"+.`$`#````)8X`0`3````HS@!``T```"W.`$``@``
M`,4X`0`'````R#@!``8```#0.`$`%````-<X`0`,````[#@!`!@```#Y.`$`
M!@```!(Y`0`2````&3D!``P````L.0$``P```#DY`0`J````/3D!``0```!H
M.0$`!@```&TY`0`'````=#D!`!\```!\.0$`-0```)PY`0`N````TCD!`"\`
M```!.@$`%P```#$Z`0`@````23H!`!L```!J.@$`&````(8Z`0`D````GSH!
M`!\```#$.@$`&@```.0Z`0`@````_SH!`!H````@.P$`,@```#L[`0`:````
M;CL!`"\```").P$`*P```+D[`0`?````Y3L!`",````%/`$`'P```"D\`0`:
M````23P!`"4```!D/`$`)@```(H\`0`E````L3P!`"0```#7/`$`&````/P\
M`0`=````%3T!`"0````S/0$`&````%@]`0`B````<3T!`!4```"4/0$`)0``
M`*H]`0`\````T#T!`!\````-/@$`(P```"T^`0`?````43X!`"````!Q/@$`
M&@```)(^`0`8````K3X!`"8```#&/@$`'@```.T^`0`I````##\!`!X````V
M/P$`"0```%4_`0`,````7S\!`!<```!L/P$`+P```(0_`0`D````M#\!``<`
M``#9/P$`#P```.$_`0`4````\3\!``X````&0`$`#0```!5``0`D````(T`!
M``4```!(0`$`!P```$Y``0`B````5D`!`"4```!Y0`$`$P```)]``0`:````
MLT`!`!T```#.0`$`&@```.Q``0`'````!T$!`,<````/00$`"P```-=!`0`5
M````XT$!``P```#Y00$`!@````9"`0`)````#4(!``L````70@$`#0```"-"
M`0`=````,4(!`!<```!/0@$`!@```&="`0`S````;D(!`!,```"B0@$`$P``
M`+9"`0`'````RD(!``8```#20@$`#P```-E"`0`'````Z4(!`#(```#Q0@$`
M(0```"1#`0`3````1D,!``P```!:0P$`$0```&=#`0`R````>4,!`!````"L
M0P$`"````+U#`0`=````QD,!``D```#D0P$`"@```.Y#`0`%````^4,!`!0`
M``#_0P$`"@```!1$`0`=````'T0!``@````]1`$`'P```$9$`0`(````9D0!
M`!H```!O1`$`)P```(I$`0`&````LD0!`!4```"Y1`$`!P```,]$`0`(````
MUT0!``D```#@1`$`/P```.I$`0`'````*D4!``\````R10$`#@```$)%`0`0
M````444!``D```!B10$`"0```&Q%`0`(````=D4!`!,```!_10$`!P```)-%
M`0`9````FT4!``H```"U10$`%P```,!%`0`4````V$4!``H```#M10$`#```
M`/A%`0`7````!48!``0````=1@$`*@```")&`0`1````348!``<```!?1@$`
M"0```&=&`0`"````<48!`!````!T1@$`&````(5&`0`+````GD8!``,```"J
M1@$`"````*Y&`0`&````MT8!``<```"^1@$`#0```,9&`0`+````U$8!`!0`
M``#@1@$`%0```/5&`0`.````"T<!`"\````:1P$`(````$I'`0`<````:T<!
M``P```"(1P$`,0```)5'`0`%````QT<!`!(```#-1P$`/P```.!'`0`2````
M($@!``H````S2`$`!@```#Y(`0`$````14@!``0```!*2`$`"@```$](`0`3
M````6D@!``4```!N2`$`!@```'1(`0`&````>T@!``D```""2`$`!````(Q(
M`0`,````D4@!``H```">2`$`(````*E(`0`%````RD@!`!@```#02`$`&0``
M`.E(`0`?`````TD!`!T````C20$`$0```$%)`0`"````4TD!``0```!620$`
M"@```%M)`0`&````9DD!``4```!M20$``P```'-)`0`,````=TD!`$4```"$
M20$`&@```,I)`0`U````Y4D!`"@````;2@$`4P```$1*`0`9````F$H!`'(`
M``"R2@$`(````"5+`0`U````1DL!`"$```!\2P$`10```)Y+`0`P````Y$L!
M`"@````53`$`*0```#Y,`0`F````:$P!`"4```"/3`$`*````+5,`0`H````
MWDP!`"(````'30$`*P```"I-`0`P````5DT!`!(```"'30$`$P```)I-`0`0
M````KDT!`'D```"_30$`"0```#E.`0!R````0TX!`',```"V3@$`?````"I/
M`0`K````IT\!`%0```#33P$`%P```"A0`0`6````0%`!``\```!74`$`90``
M`&=0`0`?````S5`!`$````#M4`$`'P```"Y1`0`<````3E$!`%$```!K40$`
M%````+U1`0`*````TE$!``4```#=40$`!@```.-1`0`(````ZE$!``4```#S
M40$`$@```/E1`0`0````#%(!`!,````=4@$`'0```#%2`0`/````3U(!``\`
M``!?4@$`!````&]2`0`)````=%(!``L```!^4@$`!P```(I2`0`%````DE(!
M`!0```"84@$`!P```*U2`0`(````M5(!``\```"^4@$`"````,Y2`0`,````
MUU(!``\```#D4@$`!@```/12`0`4````^U(!``8````04P$`#````!=3`0`5
M````)%,!``@````Z4P$`!````$-3`0`*````2%,!``0```!34P$`!@```%A3
M`0`'````7U,!``0```!G4P$`!P```&Q3`0`9````=%,!``<```".4P$``@``
M`)93`0`"````F5,!``D```"<4P$`!@```*93`0`&````K5,!`"<```"T4P$`
M`@```-Q3`0`$````WU,!``L```#D4P$`"0```/!3`0`/````^E,!`!,````*
M5`$`!P```!Y4`0`'````)E0!``8````N5`$`!@```#54`0`0````/%0!`!(`
M``!-5`$``@```&!4`0`&````8U0!``D```!J5`$`,P```'14`0`B````J%0!
M``<```#+5`$`!P```--4`0`'````VU0!``L```#C5`$`!0```.]4`0`"````
M]50!``L```#X5`$`8@$```15`0!S````9U8!`+@```#;5@$`0@```)17`0#`
M````UU<!`)````"86`$`1@```"E9`0`W````<%D!`#,```"H60$`-@```-Q9
M`0`O````$UH!`"X```!#6@$`:````'):`0!E````VUH!`&<```!!6P$`90``
M`*E;`0!G````#UP!`&\```!W7`$`/P```.=<`0!D````)UT!`$,```",70$`
M+P```-!=`0!-`````%X!`$0```!.7@$`2@```)->`0`S````WEX!`#@````2
M7P$`;@```$M?`0`N````NE\!`"T```#I7P$`B````!=@`0!B````H&`!``\!
M```#80$`3@```!-B`0`T````8F(!`(L```"78@$`4````"-C`0`0````=&,!
M`!4```"%8P$`%````)MC`0`'````L&,!``D```"X8P$`"````,)C`0`%````
MRV,!`!X```#18P$`+@```/!C`0`L````'V0!`"D```!,9`$`+@```'9D`0`8
M````I60!``H```"^9`$`$0```,ED`0`K````VV0!`!,````'90$`$````!ME
M`0`0````+&4!`!0````]90$`!0```%)E`0`H````6&4!``T```"!90$`#0``
M`(]E`0`3````G64!``T```"Q90$`"P```+]E`0`;````RV4!`!````#G90$`
M"@```/AE`0`6`````V8!`#\````:9@$`#0```%IF`0`/````:&8!`!````!X
M9@$`"P```(EF`0`-````E68!``8```"C9@$`#0```*IF`0`3````N&8!`!4`
M``#,9@$`#0```.)F`0`;````\&8!`!L````,9P$`$P```"AG`0`(````/&<!
M``D```!%9P$`6````$]G`0`T````J&<!`!4```#=9P$`/0```/-G`0!.````
M,6@!`&H```"`:`$`:0```.MH`0!P````56D!`&\```#&:0$`0@```#9J`0`/
M````>6H!`!(```"):@$`#@```)QJ`0`3````JVH!``\```"_:@$`!0```,]J
M`0`&````U6H!`!,```#<:@$`"0```/!J`0`/````^FH!`!$````*:P$`(0``
M`!QK`0`C````/FL!`!8```!B:P$`$````'EK`0`-````BFL!``D```"8:P$`
M%0```*)K`0`9````N&L!`!$```#2:P$`%0```.1K`0`8````^FL!`!\````3
M;`$`)````#-L`0`:````6&P!`!````!S;`$`%P```(1L`0`2````G&P!`"X`
M``"O;`$`&````-YL`0`<````]VP!`!0````4;0$`60```"EM`0`J````@VT!
M`"H```"N;0$`*@```-EM`0`(````!&X!``D````-;@$`-P```!=N`0`-````
M3VX!``@```!=;@$`"P```&9N`0`'````<FX!``<```!Z;@$`!P```()N`0`'
M````BFX!``P```"2;@$`!````)]N`0`B````I&X!``\```#';@$`$P```-=N
M`0`7````ZVX!`!P````#;P$`,````"!O`0`)````46\!`!@```!;;P$`'@``
M`'1O`0`C````DV\!`!$```"W;P$`%````,EO`0`2````WF\!``\```#Q;P$`
M(P````%P`0`=````)7`!``<```!#<`$`!@```$MP`0`'````4G`!`!H```!:
M<`$`"````'5P`0`*````?G`!`!$```")<`$`"0```)MP`0`1````I7`!`!H`
M``"W<`$`!P```-)P`0`2````VG`!``4```#M<`$`%@```/-P`0`>````"G$!
M``\````I<0$`/P```#EQ`0`[````>7$!``D```"U<0$`!P```+]Q`0`3````
MQW$!``0```#;<0$`!0```.!Q`0`0````YG$!``H```#W<0$`%`````)R`0`\
M````%W(!`!4```!4<@$`+0```&IR`0`R````F'(!`#$```#+<@$`,````/UR
M`0`)````+G,!``8````X<P$`"0```#]S`0`'````27,!`#L```!1<P$`.P``
M`(US`0`Z````R7,!`%\````$=`$`.0```&1T`0`Y````GG0!`#D```#8=`$`
M2P```!)U`0`M````7G4!`#````",=0$`.0```+UU`0`_````]W4!`!4````W
M=@$`&0```$UV`0`R````9W8!`"8```":=@$`$P```,%V`0`*````U78!`!``
M``#@=@$`!0```/%V`0`,````]W8!`!X````$=P$`(P```"-W`0`&````1W<!
M``4```!.=P$`%0```%1W`0`+````:G<!``@```!V=P$`"@```']W`0`,````
MBG<!``<```"7=P$`!@```)]W`0`%````IG<!``<```"L=P$`!0```+1W`0`+
M````NG<!`#(```#&=P$`%P```/EW`0`-````$7@!``<````?>`$`!P```"=X
M`0`*````+W@!``4````Z>`$`$P```$!X`0`&````5'@!`!(```!;>`$`!0``
M`&YX`0`(````='@!``0```!]>`$`"P```()X`0`&````CG@!`"4```"5>`$`
M$0```+MX`0`K````S7@!`!X```#Y>`$`"````!AY`0`.````(7D!``T````P
M>0$`!P```#YY`0`#````1GD!``,```!*>0$`&@```$YY`0`@````:7D!`"L`
M``"*>0$`"@```+9Y`0`%````P7D!``@```#'>0$`"````-!Y`0!>````V7D!
M`"@````X>@$`!@```&%Z`0`(````:'H!`!\```!Q>@$`)````)%Z`0`O````
MMGH!`#(```#F>@$`)@```!E[`0`F````0'L!`%T```!G>P$`/@```,5[`0`7
M````!'P!``<````<?`$`$@```"1\`0`,````-WP!`!````!$?`$`&````%5\
M`0`7````;GP!`!@```"&?`$`&````)]\`0`)````N'P!`!4```#"?`$`!P``
M`-A\`0`9````X'P!`!L```#Z?`$`&0```!9]`0`3````,'T!`!@```!$?0$`
M$@```%U]`0`'````<'T!`%L```!X?0$`"0```-1]`0`5````WGT!`#8```#T
M?0$`$@```"M^`0`:````/GX!`!T```!9?@$`&0```'=^`0`7````D7X!`!T`
M``"I?@$`'@```,=^`0`R````YGX!``T````9?P$`+````"=_`0`G````5'\!
M`!T```!\?P$`!@```)I_`0`<````H7\!`!X```"^?P$`&@```-U_`0`:````
M^'\!``L````3@`$`%0```!^``0`3````-8`!``T```!)@`$`!@```%>``0`/
M````7H`!``@```!N@`$`%0```'>``0`6````C8`!`!$```"D@`$`%0```+:`
M`0`%````S(`!``8```#2@`$`$0```-F``0`(````ZX`!`!,```#T@`$``@``
M``B!`0`'````"X$!`!,````3@0$`$@```">!`0`)````.H$!``H```!$@0$`
M"0```$^!`0`*````68$!``<```!D@0$`!P```&R!`0`-````=($!``P```""
M@0$`"````(^!`0`)````F($!`!H```"B@0$`(@```+V!`0`-````X($!`!@`
M``#N@0$`'@````>"`0`>````)H(!``\```!%@@$`$````%6"`0`P````9H(!
M`#\```"7@@$`(0```->"`0`\````^8(!`"@````V@P$`#@```%^#`0`)````
M;H,!``H```!X@P$`#@```(.#`0`&````DH,!``\```"9@P$`%@```*F#`0`7
M````P(,!`!P```#8@P$`+@```/6#`0`L````)(0!`#````!1A`$`+P```(*$
M`0`I````LH0!`"D```#<A`$`)@````:%`0`Y````+84!`"(```!GA0$`,```
M`(J%`0!"````NX4!`#$```#^A0$`,@```#"&`0`E````8X8!`#(```")A@$`
M.0```+R&`0!.````]H8!`#4```!%AP$`.````'N'`0!#````M(<!`"0```#X
MAP$`%@```!V(`0!/````-(@!`"D```"$B`$`&@```*Z(`0`[````R8@!`"(`
M```%B0$`&````"B)`0#5````08D!`!H````7B@$`+0```#**`0`P````8(H!
M`#$```"1B@$`,@```,.*`0`I````]HH!`!8````@BP$`+@```#>+`0`W````
M9HL!`#H```">BP$`/0```-F+`0`Z````%XP!`)H```!2C`$`*P```.V,`0`?
M````&8T!`"@````YC0$`-P```&*-`0`V````FHT!`%8```#1C0$`60```"B.
M`0`-````@HX!``0```"0C@$`!@```)6.`0`%````G(X!`!$```"BC@$`#@``
M`+2.`0`0````PXX!`!4```#4C@$`&P```.J.`0`4````!H\!`!$````;CP$`
M%@```"V/`0`)````1(\!``X```!.CP$`#P```%V/`0`1````;8\!``T```!_
MCP$`0P```(V/`0`&````T8\!`!$```#8CP$`$P```.J/`0`1````_H\!`!<`
M```0D`$`&P```"B0`0`/````1)`!``(```!4D`$`"P```%>0`0`<````8Y`!
M``0```"`D`$`$````(60`0`0````EI`!``,```"GD`$`#P```*N0`0`(````
MNY`!`!````#$D`$`$@```-60`0`+````Z)`!``\```#TD`$`$0````21`0`6
M````%I$!`!8````MD0$`"@```$21`0`'````3Y$!``T```!7D0$`$0```&61
M`0`:````=Y$!``X```"2D0$`#@```*&1`0`D````L)$!`!H```#5D0$`.```
M`/"1`0`-````*9(!`!\````WD@$`&0```%>2`0`8````<9(!`#8```"*D@$`
M)P```,&2`0`2````Z9(!``D```#\D@$`$P````:3`0`)````&I,!`#`````D
MDP$`.P```%63`0`/````D9,!`!````"ADP$`(0```+*3`0`2````U),!`",`
M``#GDP$`(P````N4`0`*````+Y0!`!P````ZE`$`%@```%>4`0`>````;I0!
M`!8```"-E`$`%P```*24`0`9````O)0!``<```#6E`$`"P```-Z4`0`J````
MZI0!`$H````5E0$`"````&"5`0`4````:94!``<```!^E0$`"@```(:5`0`W
M````D94!`!,```#)E0$`!@```-V5`0`3````Y)4!``,```#XE0$`%````/R5
M`0`&````$98!``P````8E@$`#````"66`0`1````,I8!`!$```!$E@$`%P``
M`%:6`0`1````;I8!`!D```"`E@$`%P```)J6`0`(````LI8!``8```"[E@$`
M&````,*6`0`+````VY8!``(```#GE@$`$P```.J6`0`?````_I8!`!\````>
MEP$`&````#Z7`0`2````5Y<!``\```!JEP$`#P```'J7`0`5````BI<!`#X`
M``"@EP$`,@```-^7`0`*````$I@!``\````=F`$`H@```"V8`0`>````T)@!
M`$T```#OF`$`$````#V9`0`2````3ID!``0```!AF0$`*````&:9`0`6````
MCYD!``8```"FF0$`%````*V9`0`H````PID!``4```#KF0$`!@```/&9`0`/
M````^)D!``X````(F@$`$````!>:`0`.````*)H!``P````WF@$`#@```$2:
M`0`+````4YH!`!````!?F@$`"````'":`0`+````>9H!``@```"%F@$`%0``
M`(Z:`0`,````I)H!`#\```"QF@$`$0```/&:`0`(`````YL!`!,````,FP$`
M%0```"";`0`K````-IL!`"<```!BFP$`(@```(J;`0`A````K9L!`!@```#/
MFP$`&@```.B;`0`E`````YP!`!D````IG`$``P```$.<`0`9````1YP!``L`
M``!AG`$`"P```&V<`0`#````>9P!``D```!]G`$`"````(><`0`*````D)P!
M`!$```";G`$`#0```*V<`0`0````NYP!``0```#,G`$`(````-&<`0`A````
M\IP!`!,````4G0$`#P```"B=`0`3````.)T!`!<```!,G0$`+@```&2=`0`'
M````DYT!``D```";G0$`$````*6=`0`0````MIT!``L```#'G0$`"````-.=
M`0`)````W)T!``@```#FG0$`%@```.^=`0`,````!IX!``8````3G@$`*0``
M`!J>`0`.````1)X!`(D```!3G@$`'0```-V>`0`'````^YX!``4````#GP$`
M#0````F?`0`%````%Y\!``<````=GP$`!@```"6?`0`(````+)\!`"0````U
MGP$`$P```%J?`0`"````;I\!``@```!QGP$`$@```'J?`0`5````C9\!``\`
M``"CGP$`$@```+.?`0`G````QI\!``(```#NGP$``P```/&?`0`2````]9\!
M``D````(H`$`#0```!*@`0`'````(*`!`!(````HH`$`(````#N@`0`(````
M7*`!`!,```!EH`$`%0```'F@`0`-````CZ`!`"````"=H`$`!P```+Z@`0`=
M````QJ`!``\```#DH`$`$0```/2@`0`)````!J$!``P````0H0$``@```!VA
M`0`%````(*$!``\````FH0$`$@```#:A`0`&````2:$!`!(```!0H0$`"P``
M`&.A`0`'````;Z$!`!<```!WH0$`)@```(^A`0`3````MJ$!``8```#*H0$`
M"0```-&A`0`$````VZ$!`!8```#@H0$`"````/>A`0`6`````*(!`!8````7
MH@$`$````"ZB`0`%````/Z(!``P```!%H@$`(````%*B`0`$````<Z(!`$4`
M``!XH@$`1@```+ZB`0!%````!:,!`"4```!+HP$`$@```'&C`0`3````A*,!
M``<```"8HP$`"0```*"C`0`6````JJ,!`!````#!HP$`%0```-*C`0`&````
MZ*,!``4```#OHP$`%````/6C`0`%````"J0!`)P````0I`$`"@```*VD`0`>
M````N*0!``0```#7I`$`,P```-RD`0`%````$*4!`!P````6I0$`!````#.E
M`0`0````.*4!`!````!)I0$`%@```%JE`0`,````<:4!``4```!^I0$`&@``
M`(2E`0`R````GZ4!`#<```#2I0$`0`````JF`0`L````2Z8!`#(```!XI@$`
M00```*NF`0!*````[:8!`#$````XIP$`10```&JG`0`U````L*<!`#<```#F
MIP$`)P```!ZH`0`0````1J@!`!4```!7J`$`"P```&VH`0`H````>:@!`"``
M``"BJ`$`(0```,.H`0`?````Y:@!``@````%J0$`"@````ZI`0`*````&:D!
M`!0````DJ0$`*0```#FI`0`G````8ZD!`#````"+J0$`"P```+RI`0`9````
MR*D!`"D```#BJ0$`&@````RJ`0`4````)ZH!`!0````\J@$`#0```%&J`0`0
M````7ZH!`!,```!PJ@$`1````(2J`0!]````R:H!`((```!'JP$`$P```,JK
M`0`-````WJL!``X```#LJP$`$0```/NK`0`2````#:P!`!8````@K`$`!P``
M`#>L`0`2````/ZP!`!,```!2K`$`$@```&:L`0`5````>:P!`"P```"/K`$`
M+````+RL`0!M````Z:P!`!4```!7K0$`$@```&VM`0`8````@*T!`!8```"9
MK0$`"@```+"M`0`*````NZT!`"$```#&K0$`'0```.BM`0`6````!JX!``X`
M```=K@$`#@```"RN`0`5````.ZX!`!4```!1K@$`*@```&>N`0`I````DJX!
M`"D```"\K@$`*````.:N`0`G````#Z\!`"D````WKP$`&@```&&O`0!5````
M?*\!`!,```#2KP$`%0```.:O`0`5````_*\!`!0````2L`$`$0```">P`0`7
M````.;`!`!<```!1L`$`%````&FP`0`3````?K`!`#H```"2L`$`&````,VP
M`0`9````YK`!`#X`````L0$`%0```#^Q`0`'````5;$!`!$```!=L0$`(```
M`&^Q`0`3````D+$!`!,```"DL0$`'@```+BQ`0`B````U[$!`!T```#ZL0$`
M&P```!BR`0`:````-+(!`"(```!/L@$`$@```'*R`0`<````A;(!`"$```"B
ML@$`'````,2R`0`8````X;(!`!L```#ZL@$`$P```!:S`0`;````*K,!`!P`
M``!&LP$`'````&.S`0`8````@+,!``H```"9LP$`&@```*2S`0`3````O[,!
M`!0```#3LP$`"P```.BS`0`4````]+,!`!`````)M`$`!P```!JT`0`'````
M(K0!`!(````JM`$`!P```#VT`0`'````1;0!``4```!-M`$`%0```%.T`0`&
M````:;0!`!L```!PM`$`!0```(RT`0`%````DK0!``H```"8M`$`!P```*.T
M`0`*````J[0!`!4```"VM`$`%````,RT`0`8````X;0!`!4```#ZM`$`$P``
M`!"U`0`L````)+4!`!,```!1M0$`$````&6U`0`:````=K4!`!0```"1M0$`
M#0```*:U`0`3````M+4!`#$```#(M0$`!@```/JU`0`)`````;8!`"<````+
MM@$`$P```#.V`0`0````1[8!``8```!8M@$`$P```%^V`0`+````<[8!``8`
M``!_M@$`(0```(:V`0`2````J+8!`!(```"[M@$`%````,ZV`0`2````X[8!
M`!@```#VM@$`%0````^W`0`4````);<!``,````ZMP$`"@```#ZW`0`A````
M2;<!``8```!KMP$`"````'*W`0`5````>[<!`!(```"1MP$`!@```*2W`0`'
M````J[<!`#,```"SMP$`#````.>W`0`3````]+<!``D````(N`$`$@```!*X
M`0`5````);@!`!$````[N`$`%0```$VX`0`-````8[@!``0```!QN`$`"@``
M`':X`0`'````@;@!`!0```")N`$`20```)ZX`0`(````Z+@!``\```#QN`$`
M)0````&Y`0`5````)[D!`!@````]N0$`#@```%:Y`0`0````9;D!``X```!V
MN0$`"P```(6Y`0`-````D;D!`!,```"?N0$`$P```+.Y`0`7````Q[D!`"P`
M``#?N0$`"P````RZ`0`5````&+H!`!D````NN@$`#0```$BZ`0`,````5KH!
M`!H```!CN@$`"P```'ZZ`0`&````BKH!``0```"1N@$`$@```):Z`0!6````
MJ;H!`!8`````NP$`"P```!>[`0`$````([L!``4````HNP$`&````"Z[`0`9
M````1[L!`!H```!ANP$`"@```'R[`0`"````A[L!``0```"*NP$`(P```(^[
M`0`#````L[L!``4```"WNP$`*````+V[`0`*````YKL!``4```#QNP$`!P``
M`/>[`0`8````_[L!`!$````8O`$`40```"J\`0`2````?+P!``8```"/O`$`
M!P```):\`0`(````GKP!``0```"GO`$`!0```*R\`0!D````LKP!``H````7
MO0$`#0```"*]`0`%````,+T!``8````VO0$`&0```#V]`0`X````5[T!``X`
M``"0O0$`"0```)^]`0`7````J;T!``H```#!O0$`"````,R]`0`9````U;T!
M`"\```#OO0$`*0```!^^`0`H````2;X!`!(```!RO@$`!````(6^`0`'````
MBKX!``@```"2O@$`!P```)N^`0`-````H[X!``P```"QO@$`-@```+Z^`0`?
M````];X!`#$````5OP$`)0```$>_`0`(````;;\!`%D```!VOP$`$0```-"_
M`0`0````XK\!`!(```#SOP$`&0````;``0!.````(,`!`!T```!OP`$`!@``
M`(W``0`?````E,`!``<```"TP`$`!@```+S``0`@````P\`!``8```#DP`$`
M"0```.O``0`G````]<`!`"8````=P0$`!P```$3!`0`*````3,$!`"4```!7
MP0$`2P```'W!`0`8````R<$!`!T```#BP0$`%@````#"`0`"````%\(!``T`
M```:P@$`"````"C"`0`3````,<(!``T```!%P@$`!@```%/"`0`&````6L(!
M`!0```!AP@$`%````';"`0`(````B\(!``D```"4P@$`"P```)["`0`*````
MJL(!``L```"UP@$`$0```,'"`0`/````T\(!`!(```#CP@$`$P```/;"`0`&
M````"L,!`!4````1PP$`%````"?#`0`%````/,,!``8```!"PP$`!0```$G#
M`0`7````3\,!`"````!GPP$`$0```(C#`0`-````FL,!``P```"HPP$`%```
M`+7#`0`0````RL,!`!$```#;PP$`!````.W#`0`4````\L,!``4````'Q`$`
M!0````W$`0`7````$\0!`!,````KQ`$`%````#_$`0`<````5,0!`"$```!Q
MQ`$`&0```)/$`0`9````K<0!`!T```#'Q`$`(@```.7$`0`<````",4!``0`
M```EQ0$`!0```"K%`0`.````,,4!``X````_Q0$`"````$[%`0`B````5\4!
M``T```!ZQ0$`%````(C%`0`(````G<4!`!(```"FQ0$`!P```+G%`0`0````
MP<4!``\```#2Q0$`"````.+%`0`6````Z\4!`!(````"Q@$`'````!7&`0`%
M````,L8!``0````XQ@$``P```#W&`0!1````0<8!`#\```"3Q@$`'@```-/&
M`0`D````\L8!`$$````7QP$`$0```%G'`0`^````:\<!`"X```"JQP$`'```
M`-G'`0`Z````]L<!`$H````QR`$`5P```'S(`0!<````U,@!`!`````QR0$`
M(@```$+)`0!'````9<D!`!4```"MR0$`(0```,/)`0`>````Y<D!`",````$
MR@$`'P```"C*`0`9````2,H!`!L```!BR@$`$P```'[*`0`Y````DLH!`#D`
M``#,R@$`/0````;+`0`Y````1,L!`#H```!^RP$`.P```+G+`0`X````]<L!
M`'$````NS`$`'0```*#,`0`*````OLP!``D```#)S`$`,````-/,`0`[````
M!,T!`"D```!`S0$`"P```&K-`0!+````=LT!`$8```#"S0$`!P````G.`0`7
M````$<X!`!4````IS@$`#P```#_.`0`0````3\X!`!<```!@S@$`$````'C.
M`0`/````B<X!``X```"9S@$`$P```*C.`0`1````O,X!``P```#.S@$`#@``
M`-O.`0`%````ZLX!`",```#PS@$`!````!3/`0`(````&<\!``8````BSP$`
M%````"G/`0`1````/L\!`!````!0SP$`4@```&'/`0`"````M,\!``<```"W
MSP$`$@```+_/`0`@````TL\!``4```#SSP$`!P```/G/`0`;`````=`!``@`
M```=T`$`$````";0`0`R````-]`!`!8```!JT`$`,@```('0`0!V````M-`!
M`!4````KT0$`3@```$'1`0`B````D-$!`!$```"ST0$`!@```,71`0`,````
MS-$!``<```#9T0$`#@```.'1`0`+````\-$!`!8```#\T0$`"P```!/2`0`<
M````'](!`!@````\T@$`!0```%72`0`2````6](!`!(```!NT@$`)0```('2
M`0`6````I](!`!4```"^T@$`$0```-32`0`C````YM(!``H````*TP$`#```
M`!73`0`4````(M,!`!,````WTP$`#````$O3`0`.````6-,!``L```!GTP$`
M$P```'/3`0`-````A],!``H```"5TP$`'P```*#3`0`2````P-,!`!<```#3
MTP$`!@```.O3`0`0````\M,!`!4````#U`$`%@```!G4`0`-````,-0!`!@`
M```^U`$`,0```%?4`0`=````B=0!``X```"GU`$`#P```+;4`0`D````QM0!
M``4```#KU`$`$0```/'4`0`'`````]4!`!8````+U0$`!P```"+5`0`+````
M*M4!`"`````VU0$`-````%?5`0`)````C-4!`"(```"6U0$`&P```+G5`0`-
M````U=4!`!0```#CU0$`!````/C5`0`4````_=4!``D````2U@$`"````!S6
M`0`+````)=8!``X````QU@$`!@```$#6`0`*````1]8!`"$```!2U@$`/P``
M`'36`0!`````M-8!`"0```#UU@$`+0```!K7`0`J````2-<!`$<```!SUP$`
M)````+O7`0`S````X-<!`$,````4V`$`80```%C8`0`T````NM@!`"T```#O
MV`$`!P```!W9`0`(````)=D!``D````NV0$`%````#C9`0`;````3=D!`!L`
M``!IV0$`,````(79`0`E````MMD!`"(```#<V0$`.@```/_9`0!"````.MH!
M``<```!]V@$`&0```(7:`0`)````G]H!``@```"IV@$`(````++:`0`1````
MT]H!`!0```#EV@$`#0```/K:`0`(````"-L!`!4````1VP$`"0```"?;`0`/
M````,=L!``T```!!VP$`&@```$_;`0`8````:ML!`#L```"#VP$`"@```+_;
M`0`/````RML!``8```#:VP$`&@```.';`0`0````_-L!``4````-W`$`#0``
M`!/<`0`0````(=P!``D````RW`$`#````#S<`0`,````2=P!``X```!6W`$`
M!P```&7<`0`#````;=P!``T```!QW`$`-@```'_<`0!(````MMP!`!@```#_
MW`$`)0```!C=`0`A````/MT!`!$```!@W0$`%0```'+=`0`+````B-T!`!(`
M``"4W0$`*0```*?=`0`'````T=T!``T```#9W0$`#@```.?=`0`2````]MT!
M``L````)W@$`/````!7>`0`)````4MX!`!P```!<W@$`$@```'G>`0`6````
MC-X!`$````"CW@$`)````.3>`0`\````"=\!`#H```!&WP$`-@```('?`0`1
M````N-\!``8```#*WP$`%P```-'?`0`<````Z=\!``H````&X`$`'0```!'@
M`0`+````+^`!`!`````[X`$`!P```$S@`0`5````5.`!`!4```!JX`$`"0``
M`(#@`0`'````BN`!`!0```"2X`$`$0```*?@`0`9````N>`!``4```#3X`$`
M!P```-G@`0`)````X>`!`!````#KX`$`#P```/S@`0`5````#.$!`!4````B
MX0$`!P```#CA`0`&````0.$!`#$```!'X0$`*0```'GA`0`E````H^$!``@`
M``#)X0$`#P```-+A`0`3````XN$!`!\```#VX0$`'@```!;B`0`?````->(!
M``T```!5X@$`#````&/B`0`#````<.(!``<```!TX@$`#0```'SB`0`"````
MBN(!``P```"-X@$`$0```)KB`0`+````K.(!`!0```"XX@$`&````,WB`0`5
M````YN(!`!P```#\X@$`(P```!GC`0`3````/>,!`!8```!1XP$`#@```&CC
M`0`'````=^,!``H```!_XP$`#````(KC`0`.````E^,!`%H```"FXP$`&```
M``'D`0`L````&N0!`!4```!'Y`$`!P```%WD`0`(````9>0!`!(```!NY`$`
M*P```('D`0`D````K>0!`!0```#2Y`$`$P```.?D`0`A````^^0!`!@````=
MY0$`%@```#;E`0`D````3>4!`"@```!RY0$`%0```)OE`0!?````L>4!`"$`
M```1Y@$`'0```#/F`0`M````4>8!`",```!_Y@$`'0```*/F`0`D````P>8!
M`"````#FY@$`(@````?G`0`=````*N<!``H```!(YP$`%````%/G`0`)````
M:.<!``@```!RYP$`$P```'OG`0`/````C^<!`"L```"?YP$`%0```,OG`0`(
M````X><!`&````#JYP$`/P```$OH`0!0````B^@!`'````#<Z`$`"@```$WI
M`0`E````6.D!`"\```!^Z0$`"0```*[I`0`'````N.D!``T```#`Z0$`/@``
M`,[I`0`'````#>H!`$D````5Z@$`+0```%_J`0`G````C>H!``X```"UZ@$`
M-P```,3J`0`=````_.H!`$$````:ZP$`-@```%SK`0`_````D^L!`#4```#3
MZP$`%`````GL`0`*````'NP!`!,````I[`$`%@```#WL`0`8````5.P!``@`
M``!M[`$`,0```';L`0`*````J.P!``H```"S[`$`)@```+[L`0`*````Y>P!
M`!<```#P[`$`%@````CM`0`'````'^T!`!$````G[0$`$0```#GM`0`*````
M2^T!`!8```!6[0$`!````&WM`0`%````<NT!``8```!X[0$`#P```'_M`0`2
M````C^T!`!````"B[0$`'0```+/M`0`-````T>T!``<```#?[0$`$````.?M
M`0`@````^.T!`!(````9[@$`#0```"SN`0`:````.NX!`"8```!5[@$`#@``
M`'SN`0`?````B^X!`"\```"K[@$`"0```-ON`0`+````Y>X!`!@```#Q[@$`
M$`````KO`0`6````&^\!`!D````R[P$`#@```$SO`0`0````6^\!``T```!L
M[P$`"0```'KO`0`M````A.\!``8```"R[P$`"0```+GO`0`-````P^\!`!,`
M``#1[P$`!@```.7O`0`<````[.\!`!@````)\`$`#P```"+P`0`(````,O`!
M`!X````[\`$`&P```%KP`0`,````=O`!``(```"#\`$`!P```(;P`0`(````
MCO`!`&X```"7\`$`$`````;Q`0`'````%_$!`"<````?\0$`1@```$?Q`0`<
M````CO$!`"<```"K\0$`1````-/Q`0`Q````&/(!`$````!*\@$`'````(OR
M`0`6````J/(!`!(```"_\@$`!@```-+R`0`-````V?(!``H```#G\@$`"0``
M`/+R`0`-````_/(!`!$````*\P$`#P```!SS`0`*````+/,!``P````W\P$`
M$````$3S`0`'````5?,!``@```!=\P$`!P```&;S`0`4````;O,!`!0```"#
M\P$`#P```)CS`0`%````J/,!`"4```"N\P$`%0```-3S`0`*````ZO,!`!0`
M``#U\P$`"P````KT`0`4````%O0!``L````K]`$`!@```#?T`0`6````/O0!
M`!8```!5]`$`!P```&ST`0`'````=/0!`!D```!\]`$`"````);T`0`%````
MG_0!``<```"E]`$`$@```*WT`0`;````P/0!``L```#<]`$`#0```.CT`0`M
M````]O0!`"$````D]0$`&````$;U`0`%````7_4!``P```!E]0$`%````'+U
M`0`-````A_4!``(```"5]0$`$P```)CU`0`2````K/4!`!\```"_]0$`0```
M`-_U`0`C````(/8!`#0```!$]@$`,0```'GV`0`T````J_8!`"(```#@]@$`
M8@````/W`0`6````9O<!`&X```!]]P$`.P```.SW`0!6````*/@!`'$```!_
M^`$`+0```/'X`0`\````'_D!`"L```!<^0$`,````(CY`0`P````N?D!`!P`
M``#J^0$`.@````?Z`0"_`0``0OH!`"L````"_`$`'P```"[\`0`6````3OP!
M`%8```!E_`$`C````+S\`0`S````2?T!`$````!]_0$`6@```+[]`0!0````
M&?X!`"(```!J_@$`%0```(W^`0`=````H_X!`!T```#!_@$`*@```-_^`0`<
M````"O\!`"4````G_P$`(P```$W_`0`6````<?\!`#<```"(_P$`*@```,#_
M`0`H````Z_\!`!H````4``(`,````"\``@!B````8``"`"T```##``(`-```
M`/$``@!%````)@$"`#(```!L`0(`*P```)\!`@!'````RP$"`&4````3`@(`
M6@```'D"`@`Q````U`("`"X````&`P(`+````#4#`@!9````8@,"`)4```"\
M`P(`;````%($`@!<````OP0"`%H````<!0(`,@```'<%`@`E````J@4"`"4`
M``#0!0(`*P```/8%`@!N````(@8"`&L```"1!@(`P````/T&`@`9````O@<"
M`"<```#8!P(`/@`````(`@`M````/P@"`%$```!M"`(`)P```+\(`@!<````
MYP@"`!X```!$"0(`"@```&,)`@#>````;@D"`#L```!-"@(`*0```(D*`@!"
M````LPH"`#T```#V"@(`)0```#0+`@`@````6@L"`#\```!["P(`"````+L+
M`@`(````Q`L"``D```#-"P(`$P```-<+`@`0````ZPL"`!(```#\"P(`"P``
M``\,`@`&````&PP"``X````B#`(`!````#$,`@!<````-@P"``0```"3#`(`
M$0```)@,`@`2````J@P"``@```"]#`(`!@```,8,`@`.````S0P"``0```#<
M#`(`%@```.$,`@`*````^`P"``D````##0(`$0````T-`@`3````'PT"``(`
M```S#0(`%````#8-`@`4````2PT"`!(```!@#0(`#@```',-`@`5````@@T"
M``8```"8#0(`%@```)\-`@`-````M@T"``,```#$#0(`-````,@-`@`$````
M_0T"`!,````"#@(`!P```!8.`@`D````'@X"`%````!##@(`.0```)0.`@`Z
M````S@X"`!\````)#P(`)P```"D/`@`B````40\"`"8```!T#P(`*````)L/
M`@`C````Q`\"`"4```#H#P(`+`````X0`@`G````.Q`"`#L```!C$`(`(@``
M`)\0`@`X````PA`"`#0```#[$`(`)0```#`1`@`I````5A$"`"P```"`$0(`
M)P```*T1`@`L````U1$"`"T````"$@(`-0```#`2`@`A````9A("`"4```"(
M$@(`*@```*X2`@`R````V1("`"4````,$P(`+````#(3`@`;````7Q,"`"4`
M``![$P(`0@```*$3`@`F````Y!,"`"H````+%`(`+0```#84`@`N````9!0"
M`"8```"3%`(`)````+H4`@`N````WQ0"`"L````.%0(`.````#H5`@`=````
M<Q4"``H```"1%0(`$P```)P5`@`9````L!4"`"P```#*%0(`(P```/<5`@`-
M````&Q8"``\````I%@(`%@```#D6`@`+````4!8"`!D```!<%@(`*@```'86
M`@`(````H18"``P```"J%@(`(0```+<6`@`R````V18"`!@````,%P(`*P``
M`"47`@`K````41<"`"0```!]%P(`"````*(7`@#F````JQ<"`!$```"2&`(`
M%@```*08`@`,````NQ@"``D```#(&`(`#0```-(8`@`5````X!@"`!$```#V
M&`(`*0````@9`@`B````,AD"``8```!5&0(`10```%P9`@`<````HAD"`!T`
M``"_&0(`'0```-T9`@`+````^QD"`!,````'&@(`"0```!L:`@!2````)1H"
M`"H```!X&@(`'0```*,:`@`4````P1H"`!<```#6&@(`*````.X:`@`8````
M%QL"`!(````P&P(`)````$,;`@`3````:!L"`!0```!\&P(`#````)$;`@`8
M````GAL"`!@```"W&P(`%P```-`;`@`(````Z!L"`"P```#Q&P(`"0```!X<
M`@`I````*!P"`"@```!2'`(`!P```'L<`@`;````@QP"``<```"?'`(`"```
M`*<<`@`)````L!P"`#P```"Z'`(`!@```/<<`@`3````_AP"`!0````2'0(`
M#@```"<=`@`)````-AT"``H```!`'0(`(````$L=`@`3````;!T"``T```"`
M'0(`%@```(X=`@`2````I1T"`!@```"X'0(`&````-$=`@`,````ZAT"``X`
M``#W'0(`&`````8>`@`$````'QX"`"\````D'@(`#P```%0>`@`%````9!X"
M``<```!J'@(``@```'(>`@`1````=1X"`",```"''@(`"P```*L>`@`#````
MMQX"``8```"['@(`#````,(>`@`,````SQX"`!$```#<'@(`$````.X>`@`6
M````_QX"`!<````6'P(`!0```"X?`@`O````-!\"`!\```!D'P(`'@```(0?
M`@`)````HQ\"`"D```"M'P(`!P```-<?`@`7````WQ\"`#X```#W'P(`$0``
M`#8@`@`2````2"`"``@```!;(`(`!````&0@`@`%````:2`"``T```!O(`(`
M&@```'T@`@`&````F"`"``<```"?(`(`"0```*<@`@`1````L2`"``@```##
M(`(`$@```,P@`@`2````WR`"`#````#R(`(`%````",A`@`9````."$"`"0`
M``!2(0(`(@```'<A`@`E````FB$"`!````#`(0(``@```-$A`@`$````U"$"
M``L```#9(0(`"@```.4A`@`%````\"$"``,```#V(0(`#0```/HA`@!'````
M""("`!4```!0(@(`,@```&8B`@`Y````F2("`%(```#3(@(`#P```"8C`@!V
M````-B,"`"(```"M(P(`3@```-`C`@`O````'R0"`#8```!/)`(`/0```(8D
M`@`I````Q"0"`"<```#N)`(`,````!8E`@`T````1R4"`"T```!\)0(`*0``
M`*HE`@`L````U"4"`"X````!)@(`,0```#`F`@`F````8B8"`!0```"))@(`
M$````)XF`@![````KR8"``H````K)P(`>````#8G`@!Z````KR<"`'D````J
M*`(`,````*0H`@!A````U2@"`!0````W*0(`$@```$PI`@`-````7RD"`(,`
M``!M*0(`)@```/$I`@`Y````&"H"`"(```!2*@(`(````'4J`@!K````EBH"
M`!L````"*P(`"@```!XK`@`%````*2L"``8````O*P(`"````#8K`@`%````
M/RL"`!<```!%*P(`&0```%TK`@`7````=RL"`"(```"/*P(`$````+(K`@`.
M````PRL"``@```#2*P(`!P```-LK`@`.````XRL"``<```#R*P(`!@```/HK
M`@`7`````2P"``<````9+`(`!0```"$L`@`2````)RP"``<````Z+`(`"P``
M`$(L`@`3````3BP"``T```!B+`(`%P```'`L`@`-````B"P"``D```"6+`(`
M$````*`L`@`*````L2P"``4```"\+`(`"P```,(L`@`%````SBP"``8```#4
M+`(`"@```-LL`@`(````YBP"``P```#O+`(`$P```/PL`@`'````$"T"``(`
M```8+0(``@```!LM`@`(````'BT"``@````G+0(`!P```#`M`@`L````."T"
M``(```!E+0(`!````&@M`@`.````;2T"``X```!\+0(`$````(LM`@`5````
MG"T"`!````"R+0(`"P```,,M`@`&````SRT"``<```#6+0(`$@```-XM`@`2
M````\2T"``(````$+@(`!P````<N`@`0````#RX"`"H````@+@(`-@```$LN
M`@`)````@BX"``@```",+@(`"P```)4N`@`<````H2X"``4```"^+@(`!@``
M`,0N`@`+````RRX"``$```#.!0``UP(``.$%``"G`@``!P0``&H&````````
M4P8``.0%```R!```Q@```&X#``"Y!@```````+L!``![!0```````#,#```Z
M!@``;0$``+P%````````A@$```D"``#D`P``$P8````````V`@``[```````
M``!B!0``@04``#,&````````60(``,`$``!T`P````$``.4$```)````!P``
M`+<%````````WP8`````````````S`$```@```!H````#0(```````#^!```
MZ0```/,%``#Q!0```````-$!```0!@```````````````````````&P!``#8
M`````````)(&```3`````````$8"``"?`0```````.`"``#3````*@4``&X`
M````````U04``'@"``"_!```'P(``,,$``"!`@``_P$```````##!@``:P(`
M`%T```"0!0```````%$#```D`0``I````$L%``"9`0``8P$``"<#````````
M+`,``$T"``"B!@``F0```-`%``#8`P```````"<!``#.````P08```````#'
M!@``?````(T`````````I00`````````````<P$``'T&``#I`0``0P,``!D"
M````````2P0``.8"```S`0``P`8``"P`````````U`8``*$%````````'P$`
M```````,````1P```/<#``!.`@``^P0````````@`0``F`8``%(!```Z`@``
M.0,``"@#``#>`0``E@,```````"<!0``2P$````````"`0``CP$``.`!``"*
M!```RP,```````"\`0``&@0``'T%``#U`P``G@8```````!=`P```````.T%
M``!O!0``\@$```H%````````'@(```D!``#^`P``R0$``-0$``!&`0``X0(`
M````````````W@,``'@```!;!```R@```$D!`````````````-,&``#.`P``
M`````*D#```H!0``LP`````````-!0``B@4``'D```!O`0``'@$``!D%````
M````L0$``$P&``````````````````!P`P````````````!O`@``@@0``!0&
M``"]!0``GP4```````#N````8`<``.($``"(!```7P,``.\&````````A`4`
M`'('``!/!P``.@<``,<#``#+`@````````````#$`P``\P$```````"0`P``
MWP````````#^!0```````((!```6!0``H@4``.D&`````````````"`"````
M````OP,``-,!``#@!@``6@```/<"````````Z0(```````!^`0``/`4``+0%
M``";`@``-0<```````#\!```L0```*(```#:`@``;P<``!,%``#7````````
M`.<&``!*`@``ZP(``'8$``"_!@``_P(``%($```6!P``00```&````!S!P``
M>@0``*4````1`@``T@```"X#``"O!@```0,```,$`````````````$L```#=
M`P````````````"*`P``'04``/($``!C`````````!4#```2!0``+`4``+4#
M``#6````L0,``#\'``"$!@```````,4"````````\P(```````#I`P``.0(`
M`*L$````````8`,``#$%```1!@``\0,``(4```#/!```@@(``,L```"%`0``
M504``%P!``#G!```#P<```L!````````<`$``+4%```>!```X0,```````!B
M`0``BP8`````````````'`(``.T&````````<0``````````````S00``+X%
M````````W0$``$@'``#+!```,`4``&4!``"$````$P(``)P!````````$P0`
M``````#!`P``_@8``!$'````````4`4``#$!``"L`0``P@0``(T%``"E`@``
M)0```-`$`````````````.P!````````6`4``/\$``"0!@``YP$``'($``#K
M!@``2P(````````-!```@`4``'0"``"/`P``B0$``/D```!)!0``5@(``)D"
M`````````````)(`````````*`<``%8$``"D`@````````````!?`@``?0``
M``0%``````````````L`````````H`,```D&```K!P```````'@$```;!@``
MK`8```(```"_`@```````&8```";!0``]`4``.(&`````````````+D$````
M````I@(``/4%``"'!```````````````````*0<````````M!@``E0$``+@$
M``#Q`0``NP4``!H&````````:0$``-H%````````W````"\$``#U!@``````
M`#4```"U````_0,``*8!````````:@<``-4&````````10$``",````X`@``
M`````/,````_`0```````(T&``"&`@``@P0``$X&``!!`0``D0,``)@"````
M`````````*\%``````````````````#<`P``D08``.X"```!`0``[P$``"@$
M````````?P$``!\$``!-`P``=P$``#0#```E!0``B@````T&``!'!P``^P,`
M`*4&`````````````'\```#D!````````#(```#>!@```````$X!``!*!@``
M```````````G!```Z@```.H%``"?!```K``````````.!0````````````#!
M!0```````(@%``#6`P``S@0``)T#````````104``*D`````````]````*0!
M```9`P```````#("``#@`P`````````````Z!```-0(``*P%````````/0$`
M`%0$``#Y`@``;P````\#``"#!0``9P0```````!M!0``J`4```X'````````
M`````,,#````````3P4``/8````\`P``AP```/L```!=`0``.P(``(4"``"Y
M`@``L`$``-$&```[!```R@(```````#$`0``60,```$%``#P`0``P`$`````
M````````]`8````````L`@``3P(``%D!``#4`0``C@,``&<#```X`0``````
M`&4%``"I`@``?0$``"T#`````````````$($``"Y````\`8``%(```!?`0``
M=@4``$0"```2`0```````"0%``#%````LP0``(L"````````O08``&P````)
M!0```````#,'````````7@(``&,&``"[!@``:0,``%@&``!E!@```````-`"
M```(`@``Y@$```````!^````-0$``-D#```J!````````"D$```@!```````
M`$8`````````.@4``#L#``#E`0```````*8&``!*`P``;0``````````````
MK@````````!;!P``6`<``"T$```@`P``HP8```````"8````7@$```4"``"W
M````N0,``#X%``#T`@``\P0``+4&``"2!0```````+P#````````\````-T$
M``"M!@``.00``%4!```R!0``C@(``/X`````````"P8``/T%````````D@$`
M`*0#``!E!```)````(X```!P`@``30```(L%``!-!P``U@4``%@#````````
MX0$``+`%```?!@``,`(``)@$````````4`$```````!1`0``#0$`````````
M````K@,``````````````````.P#```8!@``%P(``*<&``!0`P``D04`````
M``!&!0````````````#-`0``"@$`````````````D`(``+0"``#5`P``T@(`
M``````!O!@``[0````````````````````````"O````+`8``$X$````````
MA04```````#_````/`8``"L$```N`0```````-4```"3!```I`4``*H&``#E
M!0``>@(``"("```T````S08``$4&```'`0```````'X&``!)!```[P``````
M```X!@``<@4``'H#``!I!P````````4#``":!0``V`4``!P%``">`0``(0,`
M``````!T!````````.4```!D`@``,0(``````````````````(P"```6````
M9`,``",%``"+`````````(P$``";````M````.<```"2`@``>08``%0#``#-
M!0``;`8``/8%```/`@```````````````````````%X```#2`0``)0,``%,`
M``"7`@``EP```%P`````````?`8```````!E`@``DP8``(X!``!W!0``T04`
M``````#"`@``0`<``#$``````````````*8%```5````0P(``'H`````````
M50<``(4$``"!````@`$```````!5`````````)X#```F!````````"D!````
M``````````````#7`0``8`(``#P"```0`P``C@8``+P```!-`0``:0(``%\%
M``!D!0``9P8``"T%``"6`0```````*P#```7`P``K00````````&`0``(P8`
M`,L%```;`@``(`````````!#!0```````%L#``````````````````"P!@``
M5P,``.P"```(!P``C````!`%``"%!@```````$0$``#``P```````+8"````
M````S`0``*,$``!.```````````````C`@``_`8``%L````*!@``0@4`````
M``#C!````````,0&``"J`0```````)D#```\!P``````````````````50,`
M`.,`````````#`<``+$$``!(!```[@,```\!``"5!@``HP,```````#\`0``
M0@<``(0$``"+`0````````8&```5!@``-@4```````"(!@``S@8``)H```!#
M!P``%P8````````C!P``20````````#W!0``L08``&8#````````SP4``+8&
M```.!```&P```#('```>!0```````.X$```'!P```````(8#````````M`0`
M````````````^`(``+\%`````````````%,'```5`@``EP4``$P"``#"!@``
M*08``-$$``!9!@````````````"&!```E0,``/<`````````>`$``*8$``#%
M!````````!0"``"*`@``-@,```P&``#K````008```````#D`@```````-X`
M``"!`P``<P,``$`#``#;!@``.P8``"T```!K!````````-`&``![!```-P0`
M```$```Z`P``O00``#H!````````?@0``%@!``!7!P``T`````````".!0``
MF@$``/H&``!E!P```````"4&``````````````````#'!```AP,``%$%````
M`````````&("```G`@``^@0``)$$````````(@```*$```#:!```:P```#4#
M``"W`P``*````"(#``!@!@``B`,``$D&```$`0``40```*$$````````00,`
M`,@````X`P``(00``(@"``#I!0``I`0``````````````````'<"``!=!0``
M!`0````````&!P``*@,``+X"``!M!```9````````````````````/@$```_
M!````````.X&```E!````````&H"````````F04``!@!````````V04`````
M``"@`0``$`<``)````#[`0``[0$``!<'``#&`@``C00``,(%```V!P``*@(`
M`$`%```#!P``\`(``),%``#]!````````*("```=`P``WP$``#X$```M!P``
M<00``$`$````````%@(``)P"```-!P``]0(``%P&``"$`@`````````````#
M````U`,``',```````````````,#``!B!@``SP$``$`&````````/@$`````
M``!D!```Y0(``.4#````````(@<``!P#``!'`P``9@8```````!W`P``````
M`-L%``!?!```T@,``````````````````%L"```V`0``XP(``#X&``"R````
MU@(``-4!````````.````%0%````````FP,``)<$``#,`````````%H'```1
M`0````8``!`"````````2P,``-T````G`````````+<"````````#0,``+("
M``"(````I@```'P!``#O`P```````'8```!_!```QP$``&4#```A!@``)@(`
M`+`"``#7!````````(D&````````<P0``)T$````````L0(``,D&```0`0``
M`````,4%``#&!@``-08``$`"``!N`@```````*,%```S!0``.0<``,$```!^
M!0``*@$``$$%```:`P```````'X#````````"P(``+T"````````````````
M``````````````````!G`@``JP,``&`!``"I!```.`4``#\`````````H`0`
M`#@'```'`@``@`,``````````````````"L!````````SP8```````!$!P``
MS0(``#H``````````````-(&``!"````3@,`````````````=@8``+8%``!F
M`@``W`8``(H!````````V00``)`$``!V`0``3P8``+,!`````````````-,"
M````````@`(``(D`````````=0(``+T````S````E00``&,$``#F`P``````
M`#T```#X`0```````(@!``!%`P``^P(``$0```";`0````````````"X````
MT@4``#0%```9!P``A@8``!0#``#(`P``N`,```````!0!P``G````%X#```V
M!```OP$```````#8`@````````````#7`P``F@(```````#6`0``````````
M``!,!P``"`0``"L"``",!0``G`,``&T&``#?!`````````````#T`0``````
M``````#%!@``UP8``)<&```N````5@$``.\%``",`P``S`(```````"T!@``
M,`8``.H&```8!P```````+T!``"K!0```````,H&``#]````1P4``($$```K
M`P```````&L#``!Y`0``)0<``````````````00``!L#````````/@```'\#
M``#P!```Y`$```,%``"R`0``@`0``/<!``#K`0``]@$````````9`0``LP,`
M`%L%``#_!0``S@$````````4`0``C0,``.X!``"B`P``%````*D%```>````
M(@8``!($```?````$`0```````!G!P``@P$```````#A````X@```&$$``!A
M!0``@P,``-P"`````````````*`"```K!0``(`4``/H%``!7`0``G0(``+8`
M```=`0```08````````<!@``W`$``(0!```D!```H@0``*@#```'!0``Z@0`
M`.,#``#"`P``LP8``/4!````````<@8``-D``````````````%@$````````
M<`<``%X$``#,!@``=P8``"D"````````S0````````!A`@``R00``%L!``!H
M`@``-P(``.<"```O````F08``+L$``#+!@``0`$``#0!``#(`@```````!@%
M````````DP$``$<&```"`P``/P,```````!I!```VP0``-L"````````````
M`*X$``"=`0``$0````````#!!```5`<`````````````G04```$"``!1!P``
M[00```H'````````^`,``+X#``"G`P````<``%8#```N`@``.`0`````````
M````AP$``$@&``"O`@``,`<``(D%`````````````!@$````````8@```#X"
M```<!```;`0``/@&````````=0,``-`#``!-!@``W0(```````")`P``````
M`&<%``!0!@``BP0``.`%``!Q!0``^@,``-$#``#5`@``%0<```````"8!0``
M-@```*`%````````\@``````````````+`<``&H#``!\`@``8`4````````(
M!@``2@0````````8`@`````````````T!P```P$``'<$``#Q````<P(``-$"
M````````Q````+$%``!^`@``M00``*L"```Q!```.P4``.L$``#P`P````4`
M`*``````````K`0```H$``!\!0``"00```````!K!P``,@8``%H#``#)`@``
M`````-X$````````>00``"0&````````]P0``%H"``"4`@``1@8``(H&```9
M!````````$4````H!@``0@8``%T&``!8`````````*T!``!(`0``````````
M``````````````````#R`@``)@$``'$"```)`P````````````#X!0``````
M`+H`````````:`0`````````````F`,`````````````M`$``&,%``!#````
M8@,```0"```\`0``80<``````````````````!0%```:````"@,```````")
M!```+@4```````"S!0``(0```*H"``#X``````````````![`P``!````"\"
M```9````%P4```````!*!0``(0$``%<"``!<!```<@(``%(%````````````
M`&0'```:`0``Z``````````S!```>P8``*$!``!9!```\P8``),```#C!0``
M!0<```````#\`P``Z`$``.@"```W````K`(``#<%````````Z@,````````=
M!```7`<```````!<`P``'@<``'`&````````CP4``,H$``!A````80,``-L#
M``"#`@``P@```+L"````````$@,``*`&``"&````3P0``"\%``",!@``&```
M`!T"``#`````ZP,``!L%```6`0``2`(``-0```#3!0```````'P$````````
M`````/D$`````````````/(%`````````````%@"```Y!0```````,<"````
M````?`,````````,!```#`4``"<&```2!P``)@,```````"G!```_`4``)X`
M``!=!P``J@0`````````````40(``*4%```?`P````````````!5!@``````
M`%X%`````````````.P$``#`!0``-@8``/P````3!P```````````````@``
M-00``"\&``!!!P``KP0``(\`````````@`8``+H#````````)P4``,P#````
M````7`4``'D"```/!@````````````"Z`@``F00``+````"3`P``I0,``%D'
M``"T`P```@4``-D!``!C`@``E`,``/$$``"G````>@8``#T&``!,!0``20,`
M`-@!```B!`````````````"=````I`8``&P'``#R`P``3P,`````````````
M"`,``"X$``"N`0```````+X&``!T!@``+`0```P#``#&!0``HP```(,&``#%
M`0``AP4``((#```H`0``_`(``$,&```W!P````````````"K````,@,``%X&
M``!4`0``5````)L&``#3!```R`$``#\"``"^````'0<``!X#````````F@0`
M`+(&``#B`P````````````!#`0```````'<`````````+@<```````""````
M?P(````````C`P``9`$``&\#``!-!````````"T"````````T0```-H`````
M`````````&@&``#?!0``)@8``&@#``!_!@``9@$``!P`````````G08`````
M````````X08``,L!``!I````/@,```````#0`0``Y@0``'D#````````Y@``
M`+<!````````.0```'L```#^`0``]P8``*@$```]`P``X`0```````"<!```
M$@```+8!``!:`0``;@0```````!(`P``X````!4%``#Y`P``\0(``*\!```"
M!```O`0```D'````````:@```!@#````````4@<``&D&``"2!```<P4`````
M````````8@<``!````#$!0``,0<`````````````V@$``+<&```$`P``#P4`
M`'H%``"X`0````````4!``````````````````"X`@``.08``+L#``!*!P``
M"`4``$4'```.`@``)@```&<!``"$`P```````%,"````````;@$``#<!``":
M`P```````&$&``"H`0``````````````````7P<```````!0`@```````*$#
M````````_P,``+P"``#T`P``)@4``",$``!3!0``?0(`````````````,```
M`"(!``#[!@``L@0``&H%``#O`@```````-8&``#B`@``O@$``%$&``!K`0``
M^@```$@%``!4`@``<````'4&```]`@``;0<``),"```2`@```P8`````````
M````GP````X&``#U````.0$``-<%````````*@````0&```>!@```````.T"
M``!R`0``R@$``'D%``#H!0``L@,``%8'`````````````&8'``#U!```JP$`
M`(\$``"M`P``=`````````!2`@``U`(``*<!``#Y`0```````.(%``!*````
M/04``%4$``"C`0``Z`8``%X'````````S0,``%D```"[````FP0``%4"````
M````5P````````"!!@``-P8``)\&```````````````````O`P```````,(!
M``"-`@``````````````````2P8``+H&``"?`@``/P4`````````````:@0`
M`%H%````````[`4``+`#`````````````#,"``#<!```/00``$D"````````
MN`8```````#V!@``Q`0``.,!``!,`P``N04```````!R````4@,``"$%````
M````E`0``-L!``````````````````"Z!0``9@4``%,!``"N!0``4`0``%T$
M``#=!0``9P```#0$```%!@````````````">!```0P0``&L%````````?P4`
M``L#``#>!0```````(4#``"X!0``]@,``((&```I!0```````.(!````````
M`````````````````````,8$``#'!0``E````&@%````````C0$``"H&```4
M!```E@4``&($``#%`P``*`(``%8%````````]`0``)4"```:!0``KP,``.L%
M````````EP$``)$```"2`P``\`4````````(`0``80$``"P!````````````
M`/T&``!0````R@4``$$"``````````````8"`````````````$D'````````
M%P```%<$``"+`P``!@,```````!1!```/`0``$L'``"/!@``1@<````````<
M!P``!0```*T"``!:!@``604``&,#```'`P`````````````D`@``:@$``+<$
M```[!P``<0,``*T%````````:`<``*(!````````=@,```````"`````````
M`$0!``!U````Q@$```````"4!0``5@8````````7!```10(``%H$``#:`P``
MU00```````#(!@``&@<``"(%```"`@``E`$``"4!``#F!@``000``+(%````
M`````````%,$``"5!0``V0(`````````````R04``/X"``#V`@``W`4``*,"
M`````P``3`$``+,"``"N`@``]@0``"$'``"5````=0$``&\$``#&`P``````
M`)`!``!N!@``[0,````````3`0``>P$``!T&``#]`@``SP(``)P&``",`0``
M`````&,'``!@!```Q`(``-H&```/````,@$``'H!```J!P```````*D&``!P
M!0``5@```/T!````````\08``+X$``#/````-`(``)$!```*`@``````````
M``!2!@```P(```````!U!````````.P&``"\!@```````*T```!'`0``````
M`.H!``#.`@```````$0%````````$0,``"L`````````VP```!D&```C`0``
M'P<``$0&``#N!0```````)8$```6!```<@,``"\!```&!0```````"4"``".
M!`````````4$``"N!@``IP4``-8$``!``````````.@$``#[!0``P0$``"X&
M``"/`@```````#$#```5!````````'`$``#(!````````-($``#E!@``````
M``L$``#?`P``1@0``%<%```6`P````````X#``````````````````!L`P``
M,`0``!H"```!!P```````,,"````````1@,``&@!``#/`P``I@,``+D!````
M````=`$``/D%``#Z`0``P0(``'$!``!N!0```````$X%```I`````````#T'
M````````1P(``!$%``##`0``^@(```````"!`0``<P8````````7`0``AP8`
M`!L!``#``@``-`8``#P```!3`P``J@,```````#I!````````+`$```G!P``
M`````(,```#O!```Y````$<$``!L!0```````$("```+!0``"@````````#S
M`P```````)H&```4!P``R0`````````[````0@,````````A`@``%0$``$\!
M``!7!@``>`4``+4!``#Y!@``/P8``'T$``">!0````````````#>`@``````
M````````````\@8``.8%```/!```!04``.<%```+!P``0@$``'4%``"6`@``
M$@8``'8"````````_P8``#$&``"K!@```````'$'``"6```````````````K
M!@``!P8``"`'````````U`4``"0'````````AP(``"D#``!,`````````'@#
M``"V!```3P```%L&```?!0```````$4$````````'`$``$0#``"H!@``R0,`
M`'$&````````````````````````V`8``!L$``!?!@``M@,``#L!``")`@``
M+0$``*H```!<`@``#0```.,&``!D!@``90```#`#``"Z!````````.@#```$
M!P``X00``,@%``"E`0``J`(``$@````O!P``V`0``&T"````````O0,``&8$
M````````;@<``&D%``"J!0``V08``&L&````````J0$``,H#```&````H0(`
M`+H!``#G`P``D0(``*$&``"_````70(``-,#```=`````@8``$P$``##````
M!@0``)@!``!X!@``?0,``-\"```,`@``#@$```````#J`@```````!$$````
M````@@4``(8%````````2@$``"`&````````$P,``)0&```"!P``G@(```X`
M```F!P``5`8````````6!@``304```````![`@``;`(``#X'``#=!@``E@8`
M`,,%``!T!0``-04``,<```#D!@``````````````````3@<``)\#```D`P``
M`````#`!``!M`P``#`$``#<#``!?````M0(```````"7`P````````````#,
M!0``J``````````;!P```"`@+4TL("TM;65S<V%G93U-15-304=%("!5<V4@
M=&AI<R!C;VUM:70@;65S<V%G92!I;G-T96%D(&]F('1H92!D969A=6QT(&]N
M97,N`"`@+6$L("TM861D/49)3$4@("`@("`@($%D9"!T:&ES(%!/(&9I;&4@
M=&\@=&AE(&-O;7!E;F1I=6TN(%5S969U;"!T;PH@("`@("`@("`@("`@("`@
M("`@("`@("!I;F-L=61E(&$@8V]M<&5N9&EU;2!F<F]M(&$@9&EF9F5R96YT
M(&)R86YC:"!T;PH@("`@("`@("`@("`@("`@("`@("`@("!T:&4@9V5N97)A
M=&5D(&-O;7!E;F1I=6TN`"`@+6(L("TM8F%S93TO4$%42"`@1G5L;"!P871H
M('1O('1H92`H2&]R9&4I(&)A<V4@9&ER96-T;W)Y('1H870@<VAO=6QD(&)E
M"B`@("`@("`@("`@("`@("`@("`@=7-E9"X`("`M8RP@+2UC;VUP96YD:75M
M/49)3$4@($UE<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AI<R!C;VUP96YD
M:75M(&9I;&4*("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1E860@;V8@
M=&AE(&1E9F%U;'0@;VYE("AC;VUP96YD:75M+G!O(&EN('1H90H@("`@("`@
M("`@("`@("`@("`@("`@("`@:&]R9&4O<&\@9&ER96-T;W)Y+@`@("UC+"`M
M+6-O;7!E;F1I=6T]1DE,12`@57-E('1H:7,@8V]M<&5N9&EU;2!F:6QE(&EN
M<W1E860@;V8@=&AE(&1E9F%U;'0*("`@("`@("`@("`@("`@("`@("`@("`@
M(&]N92`H8V]M<&5N9&EU;2YP;R!I;B!T:&4@:&]R9&4O<&\@9&ER96-T;W)Y
M*2X`("`M9"P@+2UD96)U9R`@("`@("!3:&]W(&5R<F]R(&UE<W-A9V5S(&9R
M;VT@=&AE(&5X96-U=&5D(&)I;F%R:65S+@`@("UD+"`M+61I<F5C=&]R>3U$
M25(@("!#<F5A=&4@8V]M<&5N9&EU;2!I;B!T:&ES(&1I<F5C=&]R>2X`("`M
M:"P@+2UH96QP("`@("`@("!3:&]W('1H:7,@:&5L<"!M97-S86=E+@`@("UL
M+"`M+6QO8V%L93UL;%]#0R`@("`@57-E(&]N;'D@=&AI<R!L;V-A;&4N`"`@
M+6PL("TM;&]C86QE/6QL7T-#("`@("!5<V4@=&AI<R!L;V-A;&4N`"`@+6PL
M("TM;&]C86QE/6QL7T-#("`@(%5S92!T:&ES(&QO8V%L92X`("`M;2P@+2UM
M;V1U;&4]34]$54Q%("`@($)U:6QD($U/(&9I;&5S(&]N;'D@9F]R('1H:7,@
M*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;&5A
M;G5P(%!/(&9I;&5S(&]N;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@
M+6TL("TM;6]D=6QE/4U/1%5,12`@("!#;VUM:70@=')A;G-L871I;VYS(&]N
M;'D@9F]R('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/
M1%5,12`@("!#<F5A=&4@82!03R!F:6QE(&]N;'D@9F]R('1H:7,@*$AO<F1E
M*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@("!-97)G92!03R!F
M:6QE<R!O;FQY(&9O<B!T:&ES("A(;W)D92D@;6]D=6QE+@`@("UM+"`M+6UO
M9'5L93U-3T153$4@("`@57!D871E(&AE;'`@9FEL97,@;VYL>2!F;W(@=&AI
M<R`H2&]R9&4I(&UO9'5L92X`("`M;2P@+2UM;V1U;&4]34]$54Q%("`@(%5P
M9&%T92!O;FQY('1H:7,@*$AO<F1E*2!M;V1U;&4N`"`@+6TL("TM;6]D=6QE
M/4U/1%5,12`@1V5N97)A=&4@4$]4(&9I;&4@;VYL>2!F;W(@=&AI<R`H2&]R
M9&4I(&UO9'5L92X`("`M;BP@+2UN;RUC;VUP96YD:75M("`@($1O;B=T(&UE
M<F=E(&YE=R!T<F%N<VQA=&EO;G,@=&\@=&AE(&-O;7!E;F1I=6TN`"`@+6XL
M("TM;F\M8V]M<&5N9&EU;2`@("!$;VXG="!U<V4@82!C;VUP96YD:75M+@`@
M("US+"`M+7-T871I<W1I8W,@("`@("`@4V%V92!T<F%N<VQA=&EO;B!S=&%T
M:7-T:6-S(&EN(&$@;&]C86P@9FEL92X`("`M="P@+2UT97-T("`@("`@("!3
M:&]W('1H92!E>&5C=71E9"!C;VUM86YD<R!B=70@9&]N)W0@<G5N(&%N>71H
M:6YG+@`@(&-L96%N=7`@("`@($-L96%N<R!T:&4@4$\@9FEL97,@=7`@9G)O
M;2!U;G1R86YS;&%T960@86YD(&]B<V]L971E(&5N=')I97,N`"`@8V]M;6ET
M("`@("`@0V]M;6ET('1R86YS;&%T:6]N<R!T;R!T:&4@0U93('-E<G9E<BX`
M("!C;VUM:70M:&5L<"!#;VUM:70@:&5L<"!F:6QE<R!T;R!T:&4@0U93('-E
M<G9E<BX`("!C;VUP96YD:75M("!296)U:6QD('1H92!C;VUP96YD:75M(&9I
M;&4N(%=A<FYI;F<Z(%1H:7,@;W9E<G=R:71E<R!T:&4*("`@("`@("`@("`@
M("!C=7)R96YT(&-O;7!E;F1I=6TN`"`@97AT<F%C="`@("`@1V5N97)A=&4@
M4$\@=&5M<&QA=&4@*"YP;W0I(&9I;&5S+@`@(&AE;'`@("`@("`@(%-H;W<@
M=&AI<R!H96QP(&UE<W-A9V4N`"`@:6YI="`@("`@("`@0W)E871E(&]N92!O
M<B!M;W)E(%!/(&9I;&5S(&9O<B!A(&YE=R!L;V-A;&4N(%=A<FYI;F<Z(%1H
M:7,*("`@("`@("`@("`@("!O=F5R=W)I=&5S('1H92!E>&ES=&EN9R!03R!F
M:6QE<R!O9B!T:&ES(&QO8V%L92X`("!M86ME("`@("`@("!"=6EL9"!B:6YA
M<GD@34\@9FEL97,@9G)O;2!T:&4@<W!E8VEF:65D(%!/(&9I;&5S+@`@(&UA
M:V4M:&5L<"`@($UA<FL@86QL(&5N=')I97,@:6X@=&AE(%A-3"!H96QP(&9I
M;&4@8F5I;F<@=7`M=&\M9&%T92!A;F0*("`@("`@("`@("`@("!P<F5P87)E
M('1H92!F:6QE(&9O<B!T:&4@;F5X="!E>&5C=71I;VX@;V8@=7!D871E+6AE
M;'`N(%EO=0H@("`@("`@("`@("`@('-H;W5L9"!O;FQY(')U;B!M86ME+6AE
M;'`@049415(@=7!D871E+6AE;'`@86YD(')E=FES:6YG('1H90H@("`@("`@
M("`@("`@(&AE;'`@9FEL92X`("!M97)G92`@("`@("!-97)G92!T:&4@8W5R
M<F5N="!03R!F:6QE('=I=&@@=&AE(&-U<G)E;G0@4$\@=&5M<&QA=&4@9FEL
M92X`("!U<&1A=&4@("`@("!2=6X@97AT<F%C="!A;F0@;65R9V4@<V5Q=65N
M="X`("!U<&1A=&4M:&5L<"!%>'1R86-T(&%L;"!N97<@86YD(&-H86YG960@
M96YT<FEE<R!F<F]M('1H92!%;F=L:7-H(%A-3"!H96QP"B`@("`@("`@("`@
M("`@9FEL92!A;F0@;65R9V4@=&AE;2!W:71H('1H92!E>&ES=&EN9R!O;F5S
M+@`@)B,Q-3$[("5S(&ES(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO=RX`("@E<R!D87ES(&%G;RD`
M("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO
M<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!V86QI9"!C
M:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A
M<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@
M=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T
M960Z("5S+@`E9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`)60@;V8@
M)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T90`E9"UD87D@9F]R96-A
M<W0`)7,@+2!.;W1I8V4`)7,@061M:6YI<W1R871I;VX`)7,@1FEN9V5R<')I
M;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA
M=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N
M=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@;F]T('=R
M:71A8FQE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N
M9"X`)7,@;F]T(&9O=6YD+B!2=6X@)W1R86YS;&%T:6]N(&5X=')A8W0G(&9I
M<G-T+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A
M;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U
M<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@
M)7,`+2T@<V5L96-T("TM`"TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0`Q
M,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\4')E=FEO
M=7,`/&=E='1E>'0^('1A9R!N;W0@8VQO<V5D(&EN(&9I;&4@)7,N"D]P96YI
M;F<@=&%G(&9O=6YD(&EN(&QI;F4@)60N`$$@9&%T86)A<V4@8F%C:V5N9"!I
M<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@
M;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@
M<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A
M=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I
M9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3
M+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG
M;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T
M;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`
M04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@
M240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI
M9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'
M<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'
M<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@
M(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W
M('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D
M<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG(&YE=R!F
M:6QE<R!T;R!R97!O<VET;W)Y.@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES
M<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H
M86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT
M.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@
M4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D
M<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L
M<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)
M35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T
M92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E
M('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P
M96-I9FEE9"X`06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R
M80!!;F=O;&$`06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A
M<F-T:6-A`$%N=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC
M871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E
M`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I
M`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@
M/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N
M>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-
M4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`
M07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C
M;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P
M+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U
M=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q
M=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"
M86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U
M=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#
M;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H
M7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T
M('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V
M92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S
M`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N
M(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@4D%$2553
M('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A
M8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O
M<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A
M;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S96QI
M;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A
M;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T
M(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I
M80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`
M0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!"
M;W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R
M:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5I;&1I;F<@34\@9FEL97,@9F]R
M(&UO9'5L92`E<RXN+@!"=6EL9&EN9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA
M`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#
M4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A
M8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M
M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T
M:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N)W0@8V]N
M;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#86YC96P@
M4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO
M="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@
M=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E
M(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E
M>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L
M:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N
M`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A
M<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!2
M97!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S
M<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O
M('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K('1H92!B
M;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A
M="!T:&ES('1I;64N`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A;FEN9R!U<"!03R!F:6QE<R!F;W(@;6]D=6QE
M("5S+BXN`$-L96%N:6YG('5P(&QO8V%L92`E<RXN+B``0VQE87(`0VQE87(@
M35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#
M;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU
M90!#;&EC:V%T96QL('9I82!(5%10`$-L;W-E(%=I;F1O=P!#;&]U9',`0VQO
M=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL
M87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R
M`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T
M:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM86YD(&]P
M=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O;6UI='1I;F<Z`$-O;6UO;B!.
M86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;VUP
M=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F
M97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#;VYF:6=U
M<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C
M<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN
M96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&
M5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@
M861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C
M;VUP<F5S<V5D(&9I;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O
M;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W!Y:6YG
M("5S('1O("5S`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@
M4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N
M;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T
M(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E
M<B`B)7,B('5S:6YG($944#H@)7,`0V]U;&0@;F]T(&-O<'D@)7,@=&\@)7,`
M0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&-R96%T92!L;V-A;&4@9&ER96-T;W)Y(&9O<B!L;V-A;&4@)7,Z`$-O
M=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L9"!N;W0@9&5C<GEP="!3
M+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO="!D
M971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L
M9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@
M9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F
M971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N
M`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M:V1I
M<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@
M:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG+@!#
M;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?
M5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E<R(N
M`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W
M;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H
M92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@
M861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@
M;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL
M:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N
M;W0@<FUD:7(@(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO
M="!S879E('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N
M;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U
M;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A
M;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C
M;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO
M=R!T;R`E<RX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T
M+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U
M;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE
M('-I9&5B87(@:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE
M(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U
M;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN
M:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R
M(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`
M0W5R<F5N="`T(%!H87-E<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`
M0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S
M='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E
M<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!097)M:7-S:6]N<P!$969A=6QT('!E<FUI<W-I;VYS`$1E9FEN
M:71I;VYS`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F
M;W(@)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$
M96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O
M;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI
M<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T960@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E
M<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@
M:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT
M`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T
M:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER
M96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS
M`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H
M5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`
M1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S
M(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T
M:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN
M:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5C=6%D;W(`161I
M=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@
M4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I
M;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE
M;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E
M<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6]T:6-O
M;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@
M=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'
M86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@
M;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET
M>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E
M9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N
M86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%
M;G1R:65S.B`E9"!T;W1A;"P@)60@=7`M=&\M9&%T92P@)60@;F5W+"`E9"!C
M:&%N9V5D+"`E9"!U;FMN;W=N`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`
M17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG
M("(E<R(N`$5R<F]R.B``17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E
M`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E
M8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@
M:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AE
M8W5T:6YG.@!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X
M<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A
M=&EO;B!$871E`$5X<&]N96YT`$5X=')A8W1I;F<@9G)O;2`E<RXN+B``1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&
M87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E;',@
M3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R
M<P!&:65L9"!M871R:7@`1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@
M0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S
M96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T
M960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`
M1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H
M;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@
M9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R
M;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&
M;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P;&EC871I;VYS.B`E<P!&;W5N9"!D
M:7)E8W1O<FEE<SH`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L
M:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O
M=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I
M<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!&=7IZ>0!'86)O;@!'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96YE<F%T:6YG('-T
M871U<R!F;W(@;6]D=6QE("5S+BXN`$=E;W)G:6$`1V5R;6%N>0!'971O<'0@
M17)R;W(Z(`!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';P!';V5D96P`
M1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U
M.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<"!P97)M:7-S:6]N
M<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R;G-E>0!'
M=65S="!097)M:7-S:6]N<P!'=65S="!P97)M:7-S:6]N<P!'=65S=&)O;VL`
M1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W
M87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T
M;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I
M8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(
M96%D97(`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y
M(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE
M;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96QP97(@87!P;&EC871I;VX@=&\@
M8W)E871E(&%N9"!M86EN=&%I;B!T<F%N<VQA=&EO;G,@9F]R('1H92!(;W)D
M90IF<F%M97=O<FL@86YD(&ET<R!A<'!L:6-A=&EO;G,N"D9O<B!A;B!I;G1R
M;V1U8W1I;VX@<F5A9"!T:&4@9FEL92!214%$344@:6X@=&AI<R!D:7)E8W1O
M<GDN`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE.@!(:6=H`$AI<W1O<GD@96YT<GD@;F%M97,@;75S="!B92!N;VXM96UP
M='D`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R
M9&4`2&]R9&4@=')A;G-L871I;VX@9V5N97)A=&]R`$AO<F1E+TMO;&%B.B!)
M;G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I
M;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN8VAR;VYI
M<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/
M;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I
M80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N
M`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN:71I86QI>FEN
M9R!M;V1U;&4@)7,N+BX@`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!)
M;6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L
M=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A
M('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT
M97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H
M:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@
M8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A
M9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS
M97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!)
M;G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@
M<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS
M97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I
M96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`
M26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV
M86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T
M80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A
M;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E
M<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`
M26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`
M26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG
M('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L
M:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@
M<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA
M<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI
M8V]D92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`
M27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA
M<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY
M`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S
M=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I
M;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC
M871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R
M<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A
M9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB
M871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO
M<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y
M>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I
M8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E
M9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T
M(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F
M;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A
M;'5E<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,
M:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!2
M86EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,
M:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@
M4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE
M(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L
M87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@
M=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI
M<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T
M+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R
M:6)E`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET
M:'5A;FEA`$QO861I;F<@;&EB<F%R:65S+BXN`$QO861I;F<N+BX`3&]C86P@
M=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U
M=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N
M86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I
M;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T
M97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,
M=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE
M9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU
M9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL
M($%D;6EN`$UA:V4@;&EN7VLN+BX`36%K92!S=7)E('1H870@>6]U(&AA=F4@
M4$5!4B!I;G-T86QL960@86YD(&EN('EO=7(@:6YC;'5D92!P871H+@!-86MI
M;F<@9&ER96-T;W)Y("5S`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI
M`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E
M('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W
M:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``
M36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE
M<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-87D`
M36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L
M;',`365R9VEN9R!A;&P@)7,N<&\@9FEL97,@=&\@=&AE(&-O;7!E;F1I=6TN
M+BX@`$UE<F=I;F<@;&]C86QE("5S+BXN(`!-97)G:6YG('1H92!03R!F:6QE
M(&9O<B`E<R!T;R!T:&4@8V]M<&5N9&EU;2XN+B``365R9VEN9R!T<F%N<VQA
M=&EO;B!F;W(@;6]D=6QE("5S+BXN`$UE<W-A9V4`365S<V%G92!697)I9FEE
M9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C
M;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G
M92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L
M92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N
M;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN
M960`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S
M`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C
M;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@
M>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S
M<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`
M36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-
M;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QE`$UO9'5L=7,`36]L9&]V
M82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R
M`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)O8V-O`$UO<W1L
M>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`
M36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U
M<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT
M:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L
M($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB
M:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL
M97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%52
M3`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R
M(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C
M97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.
M97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`
M3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U
M<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A
M<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L
M92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N
M`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N
M`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E
M<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O
M<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD('!E
M<FUI<W-I;VYS(&%R92!T;R!B92!A9&1E9"!B96QO=R!T:&ES(&QE=F5L+@!.
M;R!C:&EL9')E;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.
M;R!C;VUM86YD('-P96-I9FEE9"X`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!6
M1E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`
M3F\@96YT<GD@=VET:"!T:&4@:60@(B5S(B!E>&ES=',@:6X@=&AE(&]R:6=I
M;F%L(&AE;'`@9FEL92X`3F\@9FEL92!U<&QO861E9`!.;R!L;V-A;&4@<W!E
M8VEF:65D+@!.;R!L;V-A=&EO;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I
M9&5D+@!.;R!M97-S86=E('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`
M3F\@;G5M8F5R('-P96-I9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO
M('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3$1!4"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U
M;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.
M;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D
M:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T
M960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W1I8V4`
M3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O
M9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE
M9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C
M=`!/8FIE8W0@0W)E871O<@!/8FIE8W0@8W)E871O<B!P97)M:7-S:6]N<P!/
M8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N;'D@
M24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F
M96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E
M9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y
M(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@
M<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U
M;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`
M3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES
M=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W!T:6]N<SH`3W)D97)E9"!,
M:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II
M;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M
M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!0
M97)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!0
M1U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#
M;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO
M=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!?2%`@4VAE
M;&P`4&%D9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O
M<GDL($]C8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y
M`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B
M;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N
M`%!E<FUI<W-I;VYS(&9O<@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E
M=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0
M;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@
M8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z
M`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@
M96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE
M87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E
M(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L
M:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT
M:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@
M82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R
M('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W
M:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U
M<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E<&]R="!A;GD@8G5G<R!T;R!I,3AN
M0&QI<W1S+FAO<F1E+F]R9RX`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E
M;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R
M`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A
M=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES
M(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S
M97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA
M;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X
M`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T
M=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V
M92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E
M="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`4F5S=6QT
M<R`H:6YC;'5D:6YG($AO<F1E*3H`4F5S=6QT<SH`4F5T=7)N('1O($]P=&EO
M;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I
M=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@
M=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E
M(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`
M4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(`%-50T-%4U,`4U]13"!3
M:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A
M:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN
M8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A
M;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET
M92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("5S`%-A=F4@)R5S
M)P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A
M<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER
M96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C
M:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E87)C:&EN9R!(;W)D92!A
M<'!L:6-A=&EO;G,@:6X@)7,`4V5A<F-H:6YG(&=E='1E>'0@8FEN87)I97,N
M+BX`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@
M=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L
M96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N
M965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A
M;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@
M9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C
M="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE
M('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE
M8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H
M96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O
M8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB
M97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R
M(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!)1"!E>'!I
M<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M
M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R
M('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N
M92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T
M:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R
M(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S
M(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H
M92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA
M<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN
M:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N(&-U<G)E;G1L>2!S
M879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3
M:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T
M:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`4VAO=R!T86)L92!O
M<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L
M969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`
M4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3
M:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H
M92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``4VEG;B!U<"!I9B!N
M;W0@<F5G:7-T97)E9`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3
M:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-K:7!P960N+BX`4VQO
M=F%K:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`
M4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P
M=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N
M9',`4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N
M`%-O=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N
M(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R
M9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN
M9P!3<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E
M;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T
M86YD87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E
M`%-T871U<P!3=&%T=7,@9F]R(&QO8V%L92`E<RXN+B``4W1O<F%G92!F;W)M
M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3
M=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3
M=6)J96-T`%-U8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&YO="!L;V<@:6X@=6YT:6P@>6]U<B!R
M97%U97-T(&AA<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3
M=6-C97-S9G5L;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@8VQE87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES
M=&5M+@!3=6-C97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E
M=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`
M4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C
M97-S9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`%-U8V-E<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R
M;W1E("5S`%-U9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3
M=6YR:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T
M.B``4W5P97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB
M87)D(&%N9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N
M9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B(%)E
M<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`5"U3
M=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4`5&%B;&4@4')O<&5R=&EE<P!4
M86)L92!P<F]P97)T:65S`%1A:7=A;@!486EW86XL(%!R;W9I;F-E(&]F($-H
M:6YA`%1A:FEK:7-T86X`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!4
M87)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F;W(@;&%S="!H
M;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP97)A='5R93QB
M<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S`%1E;7!L871E("(E<R(@;F]T
M(&9O=6YD+@!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL
M>0!497AT(&%L:6=N`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA
M;F0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4:&4@)7,@:&5L
M<"!F:6QE(&9O<B`E<R!D;V5S;B=T('EE="!E>&ES="X@0W)E871I;F<@82!N
M97<@;VYE+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4
M:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@;F]T('-U
M<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN:71I86QI
M>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@
M8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F
M;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E
M96X@;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R
M;F5T($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R
M96XG="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC
M92!G87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A
M;F0O;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M
M(&ES(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G
M970@82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R
M96)O;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S
M($]+(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@
M961I=&]R+@!4:&4@:&5L<"!F:6QE("5S(&1I9&XG="!S=&%R="!W:71H(#P_
M>&UL`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L
M969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@
M8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S
M+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C="`B
M)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT964@
M=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O;V0N
M`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@
M<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(
M;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B
M(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D
M('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@
M=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@
M=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@(B5S(B!H87,@8F5E
M;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V960N`%1H
M92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE
M('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@
M9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&]P(&%N9"!B;W1T;VT@
M<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T
M82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A
M9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@
M8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE<F4@87)E(&YO(&]P=&EO;G,@
M879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES
M<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@
M:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S
M.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E(&1O97-N)W0@
M>65T(&5X:7-T(&$@:&5L<"!F:6QE(&9O<B`E<RX`5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@;W!E;FEN9R!T:&4@9FEL92`E<RX@5')Y(')U;FYI;F<@=')A;G-L
M871I;VXN<&AP('=I=&@@=&AE(&9L86<@+60@=&\@<V5E(&%N>2!E<G)O<B!M
M97-S86=E<R!F<F]M('1H92!X;6P@<&%R<V5R+@!4:&5R92!W87,@86X@97)R
M;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC
M=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H
M:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E
M<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R
M8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP
M(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@
M;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E
M<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA
M:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A
M>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E
M;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N
M,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M
M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA
M>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@
M8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R
M<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE
M;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F
M;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A
M;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@
M2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y
M;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S
M('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U
M8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E
M('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H
M86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE
M+@!4:&ES('-C<FEP="!M=7-T(&)E(')U;B!F<F]M('1H92!C;VUM86YD(&QI
M;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP
M(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N
M`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S
M="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I
M8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L
M96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`
M5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R
M;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`
M5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O
M=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&5D`%1R86YS
M;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`
M5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R
M(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP
M="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`
M56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D
M(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B
M;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E
M;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA
M8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T
M>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@
M<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@
M)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F
M<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@
M5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@9&%T82X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U
M<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R
M(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@
M16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5
M;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI
M;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!C;VUM86YD.B`E
M<P!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE
M(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA
M;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O
M<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS
M+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL
M82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T
M;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T
M960@17AT96YS:6]N`%5N=')A;G-L871E9`!5<&1A=&4`57!D871E("5S`%5P
M9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!D871I;F<@)7,@:&5L<"!F:6QE
M(&9O<B`E<RX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A
M9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R
M+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U
M9W5A>0!5<V%G93H`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF(&YA
M;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`57-E
M<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R
M871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G
M:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S
M97(@<&5R;6ES<VEO;G,`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y
M(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,`57-E<G,@:6X@
M=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T
M(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D
M93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E
M(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L
M=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y
M($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=A<FYI;F<Z(`!790!796%T:&5R($9O
M<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!7
M96(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U
M.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@
M)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R
M(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC
M:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@
M;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N
M97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I
M9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S
M`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W1S`%=O<FL`5V]R:R!!9&1R
M97-S`%=O<FL@4&AO;F4`5W)I=&EN9R!U<&1A=&5D(&AE;'`@9FEL92!T;R`E
M<RX`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E
M;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M
M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS
M:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L
M($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@
M8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T
M(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R
M86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD
M<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG
M(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET
M<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I
M;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI
M9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A
M8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y
M;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E
M<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@
M<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C
M:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y
M(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U
M<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE
M('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P
M97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO
M=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U
M<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN
M`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@
M26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T
M('-U<'!O<G0@861D:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@875T:&5N
M=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E
M<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE
M(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C
M:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N
M+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G
M86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U
M<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@
M;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9
M;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ
M`%EO=7(@9G5L;"!N86UE.@!9;W5R(&=E='1E>'0@=F5R<VEO;B!I<R!T;V\@
M;VQD(&%N9"!D;V5S(&YO="!S=7!P;W)T(%!(4"!N871I=F5L>2X*3F]T(&%L
M;"!S=')I;F=S('=I;&P@8F4@97AT<F%C=&5D+@!9;W5R(&YE=R!P87-S=V]R
M9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO
M=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,
M20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@
M4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN
M+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%N
M(&5R<F]R(&AA<R!O8V-U<F5D.@!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`
M9&]N90!F86EL960`9F%L;&EN9P!F:6QE`&9O=6YD.B``9G)O;2!T:&4@)7,@
M*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`
M;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/
M+@!M;0!N86UE`&YO="!C:&%N9V5D`&YO="!F;W5N9`!N;W0@:6UP;&5M96YT
M960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D`'!E<F-E;G0`<&EX96QS
M`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S
M<P!S=&5A9'D`=&%S:R!L:7-T`'1H92!(;W)D92!03R!F:6QE(&9O<B!T:&4@
M;&]C86QE("5S(&1O97,@;F]T(&5X:7-T.@!T>7!E('1H92!P87-S=V]R9"!T
M=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U<&1A=&5D`'5S97(@
M<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-2TQ,2TR-"`P
M,3HQ."LP,#`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#(M,#$M,C$@,3@Z,C(M
M,#`P,`I,87-T+51R86YS;&%T;W(Z($YU;F\@3&]U<F5I<F\@/&YU;F]`971H
M+G!T/@I,86YG=6%G92U496%M.B!0;W)T=6=A;"!0;W)T=6=U97-E(#QD979`
M;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y
M<&4Z('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R
M86YS9F5R+45N8V]D:6YG.B`X8FET"@`@("U-+"`M+6UE<W-A9V4]345.4T%'
M14T@57-A<B!E<W1A(&UE;G-A9V5M(&1E(&-O;65T:6UE;G1O(&5M('9E>B!D
M80H@("`@("`@("`@("`@("`@("`@("`@("`@;65N<V%G96T@<&]R(&]M:7-S
MXV\N`"`@+6$L("TM861D/4%2455)5D\@("`@($%D:6-I;VYA<B!E<W1E(&%R
M<75I=F\@4$\@86\@8V]M<.IN9&EO+B!5=&EL('!A<F$*("`@("`@("`@("`@
M("`@("`@("`@("`@:6YC;'5I<B!U;2!C;VUPZFYD:6\@9&4@=6T@<F%M;R!D
M:69E<F5N=&4@;F\*("`@("`@("`@("`@("`@("`@("`@("`@8V]M<.IN9&EO
M(&=E<F%D;RX`("`M8BP@+2UB87-E/2]#04U)("!#86UI;FAO('!A<F$@;R!D
M:7)E8W3S<FEO(&)A<V4@*$AO<F1E*2!A('5S87(N`"`@+6,L("TM8V]M<&5N
M9&EU;3U!4E%5("!);G1E9W)A<B!N;W9A<R!T<F%D=>?U97,@82!E<W1E(&%R
M<75I=F\@9&4@8V]M<.IN9&EO"B`@("`@("`@("`@("`@("`@("`@("`@("!E
M(&[C;R!A;R!C;VUPZFYD:6\@<&]R(&]M:7-SXV\@*&-O;7!E;F1I=6TN<&\@
M;F$*("`@("`@("`@("`@("`@("`@("`@("`@('!A<W1A(&AO<F1E+W!O+@`@
M("UC+"`M+6-O;7!E;F1I=6T]05)152`@57-A<B!E<W1E(&%R<75I=F\@9&4@
M8V]M<.IN9&EO(&5M('9E>B!D;R!A<G%U:79O"B`@("`@("`@("`@("`@("`@
M("`@("`@("!P;W(@;VUI<W/C;R`H8V]M<&5N9&EU;2YP;R!N82!P87-T82!H
M;W)D92]P;RX`("`M9"P@+2UD96)U9R`@("`@("!-;W-T<F%R(&UE;G-A9V5N
M<R!D92!E<G)O(&1O<R!B:6[A<FEO<R!E>&5C=71A9&]S+@`@("UD+"`M+61I
M<F5C=&]R>3U005-402!#<FEA<B!U;2!C;VUPZFYD:6\@;F5S=&$@<&%S=&$N
M`"`@+6@L("TM:&5L<"`@("`@("`@36]S=')A<B!E<W1A(&UE;G-A9V5M(&1E
M(&%J=61A+@`@("UL+"`M+6QO8V%L93UL;%]#0R`@("`@57-A<B!A<&5N87,@
M97-T82!L;V-A;&EZ8>?C;RX`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@(%5S
M87(@97-T82!L;V-A;&EZ8>?C;RX`("`M;"P@+2UL;V-A;&4];&Q?0T,@("`@
M57-A<B!E<W1A(&QO8V%L:7IAY^-O+@`@("UM+"`M+6UO9'5L93U-TT153$\@
M("`@0V]N<W1R=6ER(&%R<75I=F]S($U/(&%P96YA<R!P87)A(&5S=&4@;?-D
M=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R9&4I+@`@("UM+"`M
M+6UO9'5L93U-TT153$\@("`@3&EM<&%R(&%R<75I=F]S(%!/(&%P96YA<R!P
M87)A(&5S=&4@;?-D=6QO"B`@("`@("`@("`@("`@("`@("`@("`@("`H2&]R
M9&4I+@`@("UM+"`M+6UO9'5L93U-TT153$\@("`@0V]M971E<B!A<R!T<F%D
M=>?U97,@87!E;F%S('!A<F$@97-T92!M\V1U;&\*("`@("`@("`@("`@("`@
M("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4W31%5,3R`@("!#
M<FEA<B!O(&%R<75I=F\@4$\@87!E;F%S('!A<F$@97-T92!M\V1U;&\*("`@
M("`@("`@("`@("`@("`@("`@("`@("A(;W)D92DN`"`@+6TL("TM;6]D=6QE
M/4W31%5,3R`@("!);G1E9W)A<B!A<G%U:79O<R!03R!A<&5N87,@<&%R82!E
M<W1E(&WS9'5L;PH@("`@("`@("`@("`@("`@("`@("`@("`@*$AO<F1E*2X`
M("`M;2P@+2UM;V1U;&4]3=-$54Q/("`@($%C='5A;&EZ87(@87)Q=6EV;W,@
M9&4@86IU9&$@87!E;F%S('!A<F$@97-T90H@("`@("`@("`@("`@("`@("`@
M("`@("`@;?-D=6QO("A(;W)D92DN`"`@+6TL("TM;6]D=6QE/4U/1%5,12`@
M("!!8W1U86QI>F%R(&%P96YA<R!E<W1E(&WS9'5L;R`H2&]R9&4I+@`@("UM
M+"`M+6UO9'5L93U-3T153$4@("`@1V5R87(@87)C:&EV;R!03U0@87!E;F%S
M('!A<F$@97-T92!M\V1U;&\*("`@("`@("`@("`@("`@("`@("`@("`@("A(
M;W)D92DN`"`@+6XL("TM;F\M8V]M<&5N9&EU;2`@("!.XV\@:6YT96=R87(@
M;F]V87,@=')A9'7G]65S(&YO(&-O;7#J;F1I;RX`("`M;BP@+2UN;RUC;VUP
M96YD:75M("`@($[C;R!U<V%R('5M(&-O;7#J;F1I;RX`("`M<RP@+2US=&%T
M:7-T:6-S("`@("`@($=U87)D87(@97-T873M<W1I8V%S(&1E('1R861UY^-O
M(&YU;2!F:6-H96ER;R!L;V-A;"X`("`M="P@+2UT97-T("`@("`@("!-;W-T
M<F%R(&]S('!R;V=R86UA<R!A(&5X96-U=&%R(&UA<R!NXV\@;R!F87IE<BX`
M("!C;&5A;G5P("`@("!,:6UP87(@;V8@87)Q=6EV;W,@4$\@9&4@96YT<F%D
M87,@<&]R('1R861U>FER(&]U(&]B<V]L971A<RX`("!C;VUM:70@("`@("!#
M;VUE=&5R(&%S('1R861UY_5E<R!N;R!S97)V:61O<B!#5E,N`"`@8V]M;6ET
M+6AE;'`@0V]M971E<B!A<G%U:79O<R!D92!A:G5D82!N;R!S97)V:61O<B!#
M5E,N`"`@8V]M<&5N9&EU;2`@4F5C;VYS=')U:7(@;R!A<G%U:79O(&1E(&-O
M;7#J;F1I;RX@071E;N?C;SH@3R!N;W9O(&%R<75I=F\*("`@("`@("`@("`@
M("!S;V)R97#U92US92!A;R!A;G1I9V\N`"`@97AT<F%C="`@("`@1V5R87(@
M87)Q=6EV;W,@;6]D96QO(%!/("@N<&]T*2X`("!H96QP("`@("`@("!-;W-T
M<F%R(&5S=&$@;65N<V%G96T@9&4@86IU9&$N`"`@:6YI="`@("`@("`@0W)I
M87(@=6T@;W4@;6%I<R!A<G%U:79O<R!03R!P87)A('5M82!N;W9A(&QO8V%L
M:7IAY^-O+@H@("`@("`@("`@("`@($%T96[GXV\Z($]S(&YO=F]S(&%R<75I
M=F]S('-O<')E</5E;2US92!A;W,@86YT:6=O<RX`("!M86ME("`@("`@("!#
M;VYS=')U:7(@87)Q=6EV;W,@8FENX7)I;W,@34\@82!P87)T:7(@9&]S(&%R
M<75I=F]S"B`@("`@("`@("`@("`@4$\@97-P96-I9FEC861O<RX`("!M86ME
M+6AE;'`@("!-87)C87(@=&]D87,@87,@96YT<F%D87,@;F\@87)Q=6EV;R!8
M34P@9&4@86IU9&$@8V]M;R!E<W1A;F1O"B`@("`@("`@("`@("`@86-T=6%L
M:7IA9&%S(&4@<')E<&%R87(@;R!A<G%U:79O('!A<F$@82!P<O-X:6UA(&5X
M96-UY^-O"B`@("`@("`@("`@("`@9&4@=7!D871E+6AE;'`N($1E=F4M<V4@
M97AE8W5T87(@;6%K92UH96QP($1%4$])4R!D90H@("`@("`@("`@("`@('5P
M9&%T92UH96QP(&4@9&4@<F5V97(@;R!A<G%U:79O(&1E(&%J=61A+@`@(&UE
M<F=E("`@("`@($EN=&5G<F%R(&\@87)Q=6EV;R!03R!C;W)R96YT92!C;VT@
M;R!A<G%U:79O(&UO9&5L;R!03R!C;W)R96YT92X`("!U<&1A=&4@("`@("!%
M>&5C=71A<B!E>'1R86-T(&4@;65R9V4@96T@<V5Q=>IN8VEA+@`@('5P9&%T
M92UH96QP($5X=')A:7(@=&]D87,@87,@96YT<F%D87,@;F]V87,@92!M;V1I
M9FEC861A<R!D;R!A<G%U:79O(&1E"B`@("`@("`@("`@("`@86IU9&$@6$U,
M(&5M(&EN9VSJ<R!E(&EN=&5G<N$M;&%S(&-O;2!A<R!E>&ES=&5N=&4N`"`F
M(S$U,3L@)7,@97-TX2!P<F]N=&\@<&%R82!E9F5C='5A<B!A<R!O<&5R8>?U
M97,@9&4@;6%N=71E;N?C;R!M87)C861A<R!A8F%I>&\N`"`H)7,@9&EA<R!A
M='+A<RD`("A#:&%V92!D92!A8V5S<V\@)7,I`"`H9&5N=')O(&1E("5S(&1I
M87,I`"`H:&]J92D`("AA;6%N:.,I`"`H;VYT96TI`"!C;VT@`"(E<R(@;N-O
M(.D@=6UA(&5S8V]L:&$@=N%L:61A+@`B)7,B(&[C;R!E<W3A(&-O;F9I9W5R
M861O(&YO(%)E9VES=&\@9&\@2&]R9&4N`"(E<R(@<F5P<F5S96YT861O<B!D
M92#A<G9O<F4@;N-O(&5N8V]N=')A9&\N`"(E<R(@9F]I(&%D:6-I;VYA9&\@
M86\@<VES=&5M82!D92!G<G5P;W,N`"(E<R(G(&9O:2!A9&EC:6]N861O(&%O
M('-I<W1E;6$@9&4@<&5R;6ES<_5E<RX`(B5S(B!NXV\@9F]I(&-R:6%D;SH@
M)7,N`"5D("5S(&4@)7,`)60@8GET97,@97-C<FET;W,`)60@9&4@)60@96YT
M<F%D82!M87)C861A<R!C;VUO(&%C='5A;&EZ861A<P!P<F5V:7/C;R!D92`E
M9"!D:6%S`"5S("T@3F]T:69I8V'GXV\`)7,@061M:6YI<W1R8>?C;P`E<R!)
M;7!R97-SXV\@1&EG:71A;``E<R!+0@`E<R!/<&5R8>?U97,@9&4@36%N=71E
M;N?C;R`M($-O;F9I<FUAY^-O`$-O;F9I9W5R87(@)7,`)7,@4W5B<V-R979E
M<@`E<R!497)M;W,@9&\@06-O<F1O`"5S(&KA(&5X:7-T92X`)7,@96T@)7,@
M)7,`;N-O('-E('!O9&4@97-C<F5V97(@96T@)7,N`"5S(.D@;V)R:6=A=/-R
M:6\`)7,@;6EN=71O<P`E<R!NXV\@9F]I(&5N8V]N=')A9&\N`"5S(&[C;R!F
M;VD@96YC;VYT<F%D;RX@17AE8W5T87(@)W1R86YS;&%T:6]N(&5X=')A8W0G
M('!R:6UE:7)O+@`E<R!A("5S(&1E("5S`$-O;G1A8W1O<R!D92`E<P!#86QE
M;F3A<FEO(&1E("5S`$YO=&%S(&1E("5S`%1A<F5F87,@9&4@)7,`)7,Z("5S
M`"P@8V]M(')A:F%D87,`+"!C;VT@<F%J861A<R`E<R`E<P`L('9A<FGA=F5L
M(&1E("5S(&$@)7,`+2T@97-C;VQH82`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T`1F]R;6%T;R!D92`Q,B!H;W)A<R`H04TO4$TI`$9O<FUA=&\@
M9&4@,C0@:&]R87,`,C0@:&]R87,`/$%N=&5R:6]R`&5T:7%U971A(#QG971T
M97AT/B!P;W(@9F5C:&%R(&YO(&9I8VAE:7)O("5S+@I!8G)I;F1O(&$@971I
M<75E=&$@96YC;VYT<F%D82!N82!L:6YH82`E9"X`17-T92!B;&]C;R!E>&EG
M92!U;2!M96-A;FES;6\@=7-A;F1O(&)A<V5S(&1E(&1A9&]S+@!/8V]R<F5U
M('5M(&5R<F\@9F%T86P`R2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A
M(%!'4"!P87)A(&5N8W)I<'1A<B!A(&UE;G-A9V5M+@#)(&YE8V5S<^%R:6$@
M=6UA(&-H879E('#Z8FQI8V$@4$=0('!A<F$@=F5R:69I8V%R(&$@87-S:6YA
M='5R82!D92!U;6$@;65N<V%G96T`4&%R82!D96-I9G)A<B!U;6$@;65N<V%G
M96T@<^-O(&YE8V5S<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%!'4"P@=6UA
M(&-H879E('!R:79A9&$@4$=0(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&%S
M<VEN87(@=6UA(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@
M</IB;&EC82!01U`L('5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!F<F%S
M92UP87-S92X`4&%R82!D96-I9G)A<B!U;6$@;65N<V%G96T@<^-O(&YE8V5S
M<^%R:6%S('5M82!C:&%V92!P^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R
M:79A9&$@4R]-24U%(&4@=6UA(&9R87-E+7!A<W-E+@!087)A(&%S<VEN87(@
M=6UA(&UE;G-A9V5M('/C;R!N96-E<W/A<FEA<R!U;6$@8VAA=F4@</IB;&EC
M82!3+TU)344L('5M82!C:&%V92!P<FEV861A(%,O34E-12!E('5M82!F<F%S
M92UP87-S92X`R2!N96-E<W/A<FEA('5M82!C:&%V92!P^F)L:6-A(%,O34E-
M12!P87)A(&5N8W)I<'1A<B!U;6$@;65N<V%G96TN`$[Z=F5N<R!D92!M86YH
MXP!#:'5V:7-C;W,@9&4@36%N:.,`0VAU=F$@9&4@;6%N:.,`06=U86-E:7)O
M<R!D92!M86YHXP!.97;U97,@9&4@;6%N:.,`04TO4$T`05!)($E$`$%C97)C
M82!D97-T92!E9&ET;W(`06-E<F-A+BXN`$)A<V5S(&%L:6YH861A<P!#96YT
M<F]S(&%L:6YH861O<P!!8V5S<V\@;F5G861O(&%O(&-R:6%R('!A<W1A(%9&
M4RX`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A<G%U:79O(%9&4RX`4&%L879R
M82U087-S92!D82!#;VYT80!#;VYT82!C;VYG96QA9&$N`$-O;G1A8FEL:61A
M9&4`061I8VEO;F%R`$%D:6-I;VYA<B!'<G5P;R!&:6QH;P!!9&EC:6]N87(@
M4&5R;6ES<^-O($9I;&AA`$%C<F5S8V5N=&%R($%Q=6DZ`$%D9&EC:6]N87(@
M3F]V;R!'<G5P;P!!9&EC:6]N87(@3F]V82!097)M:7-SXV\`061I8VEO;F%R
M('5M(&=R=7!O(&9I;&AO(&$@(B5S(@!!9&EC:6]N87(@=6UA('!E<FUI<W/C
M;R!F:6QH82!A("(E<R(`061I8VEO;F%R(&YO=F\@=71I;&EZ861O<CH`061I
M8VEO;F%R(&-O;'5N80!!9&EC:6]N87(@;F]V;W,@;65M8G)O<P!!9&EC:6]N
M87(@<&%R8V5I<F\`061I8VEO;F%R(&\@365N=2`E<R!C;VUO($)A<G)A($QA
M=&5R86P@36]Z:6QL80!!9&EC:6]N87(@86]S($-O;G1A8W1O<SH`061I8VEO
M;F%R(&%O<R!M975S(&-O;G1A8W1O<P!!9&EC:6]N87(@=71I;&EZ861O<@!!
M9&EC:6]N96D@(B5S(B!A;R!S:7-T96UA+"!M87,@;N-O('!U9&4@861I8VEO
M;F%R(&EN9F]R;6'GXV\@9&4@<W5B<V-R:>?C;R!A9&EC:6]N86PZ("5S+@!!
M9&EC:6]N96D@(B5S(B!A;R!S:7-T96UA+B!*X2!P;V1E(&5N=')A<BX`061I
M8VEO;F%N9&\@;F]V;W,@87)Q=6EV;W,@86\@<F5P;W-I=/-R:6\Z`$$@861I
MY^-O(&1E('5T:6QI>F%D;W)E<R!E<W3A(&1E<V%C=&EV861A+@!%;F1E<F7G
M;P!#;VYT86-T;W,`061M:6YI<W1R87(@+2!A=')I8G5I<B!P97)M:7-S]65S
M(&$@;W5T<F]S('5T:6QI>F%D;W)E<P!!9&UI;FES=')AY^-O`$%N^FYC:6]S
M`$%F96=A;FES=.-O`$%L8N)N:6$`07)GZ6QI80!!;&-U;FAA`$%L:6YH87(`
M06QI;FAA;65N=&\Z`%1U9&\`5&]D;W,@;W,@571I;&EZ861O<F5S($%U=&5N
M=&EC861O<P!4;V1O<R!O<R!'<G5P;W,`5&]D87,@87,@4&5R;6ES<_5E<P!4
M;V1O<R!O<R`H<75A=')O*2!L861O<P!097)M:71I<B!M^FQT:7!L;W,@96YD
M97)EYV]S`%!E<FUI=&ER(&%T<FEB=6GGXV\@9&\@=&EP;R!D92!L:7-T87,@
M;W)D96YA9&%S/P!*X2!E>&ES=&4`16YT<F%D82!)35-0($%L=&5R;F%T:79A
M`%!A;&%V<F$M4&%S<V4@24U34"!!;'1E<FYA=&EV80!.;VUE(&1E(%5T:6QI
M>F%D;W(@24U34"!!;'1E<FYA=&EV;P!%;F1E<F7G;R!I;G;A;&ED;P!-;V1E
M;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E<FYA=&EV;SH`4V%M;V$@06UE
M<FEC86YA`$9O:2!E<W!E8VEF:6-A9&\@=6T@=F%L;W(@:6YVX6QI9&\N`$]C
M;W)R974@=6T@97)R;R!D97-C;VYH96-I9&\N`$%N9&]R<F$`06YG;VQA`$%N
M9W5I;&$`16YT<F5P;W-T;R`H<')O>'DI($%N\VYI;6\`4F5S<&]S=&$`06YT
MX7)C=&EC;P!!;G3M9W5A(&4@0F%R8G5D80!!<&QI8V'GXV\`07!L:6-AY^-O
M('!R;VYT82X`07!L:6-A<B!A(%!A<G1I;&AA<R!&:6QH87,`07!R;W9A<@!4
M86UA;FAO($%P<F]X:6UA9&\`06)R:6P`07+A8FEC;R`H5VEN9&]W<RTQ,C4V
M*0!486UA;FAO(&1O($9I8VAE:7)O(&1E($%R<75I=F\`3F]M92!D;R!!<G%U
M:79O`%1E;2!A(&-E<G1E>F$@<75E('%U97(@<F5M;W9E<B!O('!E9&ED;R!D
M92!S=6)S8W)IY^-O('!A<F$@)7,@/P!496T@82!C97)T97IA('%U92!Q=65R
M(')E;6]V97(@(B5S(B!E('%U86ES<75E<B!S=6(M9W)U<&]S/P!!<F=E;G1I
M;F$`07)MZ6YI80!!<FWI;FEO("A!4DU30TE)+3@I`$%R=&4`07)U8F$`26QH
M82!D92!!<V-E;G/C;P!!<G1E($%30TE)`%)E9VGC;R#!<VEA+U!A8^UF:6-O
M`%!E9&ER(&-O;F9I<FUAY^-O(&%N=&5S(&1E(')E86QI>F%R(&]P97)AY_5E
M<R!D92!M86YU=&5NY^-O/P!#;VQU;F%S(&1E(&%T<FEB=6GGXV\`5&5N=&%T
M:79A(&1E(')E;6_GXV\@9&4@=6T@9W)U<&\@:6YE>&ES=&5N=&4N`%1E;G1A
M=&EV82!D92!R96UOY^-O(&1E('5M82!P97)M:7-SXV\@:6YE>&ES=&5N=&4N
M`%1E;G1A=&EV82!D92!E9&GGXV\@9&4@=6UA('!E<FUI<W/C;R!I;F5X:7-T
M96YT92X`5&5N=&%T:79A(&1E(&5D:>?C;R!D92!U;6$@<&%R=&EL:&$@:6YE
M>&ES=&5N=&4N`$%T<FEB=71O<P!!9V]S=&\`075S='+A;&EA`,%U<W1R:6$`
M075T:%]C>7)S<6PZ($$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA(&[C;R!F
M;VD@96YC;VYT<F%D82X`075T:%]C>7)U<SH@3R!M96-A;FES;6\@;N-O('1E
M;2!A<R!C87!A8VED861E<R!N96-E<W/A<FEA<RX`075T:%]C>7)U<SH@02!E
M>'1E;G/C;R!I;6%P(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!
M=71H7V9T<#H@02!E>'1E;G/C;R!&5%`@;F5C97-SX7)I82!NXV\@9F]I(&5N
M8V]N=')A9&$N($-O;7!I;&4@;R!02%`@8V]M(&$@;W#GXV\@+2UE;F%B;&4M
M9G1P+@!!=71H7VEM87`Z($$@97AT96YSXV\@24U!4"!N96-E<W/A<FEA(&[C
M;R!F;VD@96YC;VYT<F%D82X`075T:%]K<F(U.B!!(&5X=&5N<^-O(&MR8C4@
M;F5C97-SX7)I82!NXV\@9F]I(&5N8V]N=')A9&$N`$%U=&A?;&1A<#H@02!E
M>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$@;N-O(&9O:2!E;F-O;G1R861A+@!!
M=71H7VQD87`Z($EM<&]S<^UV96P@861I8VEO;F%R('5T:6QI>F%D;W(@)7,N
M($5I<R!O('%U92!O('-E<G9I9&]R(&1I<W-E.B``075T:%]L9&%P.B!);7!O
M<W/M=F5L(')E;6]V97(@;R!U=&EL:7IA9&]R("5S`$%U=&A?;&1A<#H@26UP
M;W-S[79E;"!A8W1U86QI>F%R(&\@=71I;&EZ861O<B`E<P!!=71H7VUC86PZ
M($$@97AT96YSXV\@34-!3"!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D
M82X`075T:%]S;6)A=71H.B!!(&5X=&5N<^-O('-M8F%U=&@@;F5C97-SX7)I
M82!NXV\@9F]I(&5N8V]N=')A9&$N`$$@875T96YT:6-AY^-O(&9A;&AO=0!!
M(&%U=&5N=&EC8>?C;R!F86QH;W4N("5S`$$@875T96YT:6-AY^-O(&9O:2!R
M96IE:71A9&$@<&5L;R!S97)V:61O<B!2041)55,N`$$@875T96YT:6-AY^-O
M(&YO('-E<G9I9&]R($944"!F86QH;W4N`$-A;7!O<R!D:7-P;V[M=F5I<SH`
M07IE<F)A:6KC;P!$97-C=6QP87,@(D)/1D@B`$9U;F1O`$-O<B!D;R!&=6YD
M;P!086QA=G)A+5!A<W-E(&ME<F)E<F]S(&5R<F%D82X`3F]M92!D92!5=&EL
M:7IA9&]R(&ME<F)E<F]S(&5R<F%D;RX`0F%A;6%S`$)A<NEM`$+A;'1I8V\@
M*$E33RTX.#4Y+3$S*0!"86YG;&%D96-H90!"87)B861O<P!,:6YH82!B87-E
M`$)I96QO<G+Z<W-I80!"Z6QG:6-A`$)E;&EZ90!"96YI;0!"97)M=61A`$)U
M=.-O`$%N:79E<G/A<FEO`$\@8FQO8V\@(B5S(B!D82!A<&QI8V'GXV\@(B5S
M(B!NXV\@9F]I(&5N8V]N=')A9&\N`$-O;F9I9W5R8>?U97,@9&4@0FQO8V]S
M`%1I<&\@9&4@0FQO8V\`3F5G<FET;P!";VSM=FEA`$UA<F-A9&]R97,`0F]R
M9&$`17-P97-S=7)A(&1A(&)O<F1A.@!";W)D87,`0O-S;FEA+4AE<GIE9V]V
M:6YA`$%M8F%S`$)O='-U86YA`$)A<V4`26QH82!";W5V970`0G)A<VEL`%1E
M<G)I=/-R:6\@0G)I=.)N:6-O(&1O($]C96%N;R#-;F1I8V\`0G)U;F5I($1A
M<G5S<V%L86T`0V]N<W1R=6EN9&\@87)Q=6EV;W,@34\@<&%R82!O(&WS9'5L
M;R`E<RXN+@!#;VYS=')U:6YD;R!L;V-A;&EZ8>?C;R`E<RXN+B``0G5L9^%R
M:6$`3&ES="!)=&5M:7IA9&$`0G5R<75I;F$@1F%S;P!"=7+Z;F1I`$--4P!#
M4D,`4&]N=&]S(&1E($1I<W1R:6)U:>?C;R!#4DP`4')O<')I961A9&5S(&1A
M*',I($/I7VQU;&$H<RDN+BX`26YI8VEA;&EZ8>?C;R!D82`B8V%C:&4B(&[C
M;R!F;VD@8V]N8VQU[61A+@!#86QE;F3A<FEO`$-A;&UO`$-A;6)O9&IA`$-A
M;6%R]65S`$[C;R!P;W-S;R!R96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&%U
M=&]M871I8V%M96YT92P@8V]N=&%C=&4@;R!S974@861M:6YI<W1R861O<B!D
M92!S:7-T96UA<RX`26UP;W-S[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!)
M34%0.B`E<P!#86YA9.$`0V%N8V5L87(`0V%N8V5L87(@4F5L873S<FEO(&1E
M(%!R;V)L96UA<P!.XV\@8V]N<VEG;R!R96UO=F5R(&\@9FEC:&5I<F\@(B5S
M(BX`3N-O(&-O;G-I9V\@96YC;VYT<F%R('5M(&1I<F5C=/-R:6\@=&5M<&]R
MX7)I;RX`26UP;W-S[79E;"!C;VYT:6YU87(@<V5M(&\@<&%RXFUE=')O("=T
M87)G971&:6QE)RX`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@
M(B5S(BX`26UP;W-S[79E;"!R96UO=F5R+"!E>&ES=&5M("5D(&9I;&AO<RX`
M3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R.B!O(&[Z;65R;R!D92!E;G1R861A
M<R!F;W)N96-I9&%S(&[C;R!C;W)R97-P;VYD92!A;R!N^FUE<F\@9W5A<F1A
M9&\N`$[C;R!F;VD@<&]S<^UV96P@96YC86UI;FAA<B!A(&UE;G-A9V5M('!A
M<F$@;R!N^FUE<F\@:6YD:6-A9&\N`%)E</IB;&EC82!D92!#86)O(%9E<F1E
M`$QE9V5N9&$`0V%T96=O<FEA<R!E($-O<F5S`$EL:&%S($-A:6WC;P!496QE
M9F]N92!#96QU;&%R`%!R;W!R:65D861E<R!D87,@0^EL=6QA<P!%;F-H:6UE
M;G1O(&1A<R!#Z6QU;&%S.@!0<F]P<FEE9&%D97,@9&%S(&/I;'5L87,`17-P
M8>=A;65N=&\@9&%S(&/I;'5L87,Z`%1E;&5M\W9E;`!#Z6QT:6-O("A)4T\M
M.#@U.2TQ-"D`0V5N=')A<@!297#Z8FQI8V$@0V5N=')O($%F<FEC86YA`$5U
M<F]P82!#96YT<F%L("A)4T\M.#@U.2TR*0!0;W)M96YO<F5S(&1O($-E<G1I
M9FEC861O`$1O;F\@9&\@0V5R=&EF:6-A9&\`4&]L[71I8V%S(&1E($-E<G1I
M9FEC861O`%)E</IB;&EC82!D;R!#:&%D90!!;'1E<F%R`$%L=&5R92!O(&YO
M;64@92!E;F1E<F7G;R!Q=64@87,@<&5S<V]A<R!V97+C;R!Q=6%N9&\@;&5R
M96T@92!R97-P;VYD97)E;2#@<R!S=6%S(&UE;G-A9V5N<RX`0V%R86-T97)E
M`%9E<FE?9FEC87(@3&EG8>?C;RXN+@!-87)Q=64@87,@;W!E<F'G]65S('%U
M92!D97-E:F$@97AE8W5T87(@;F5S=&4@;6]M96YT;RX`4F5P^F)L:6-A(&1O
M($-H:6QE`%)E</IB;&EC82!0;W!U;&%R(&1A($-H:6YA`$-H:6[J<R!3:6UP
M;&EF:6-A9&]S("A'0C(S,3(I`$-H:6[J<R!4<F%D:6-I;VYA;"`H0FEG-2D`
M17-C;VQH82!A('!A;&%V<F$M<&%S<V4`17-C;VQH82!U;2!.;VUE(&1E(%5T
M:6QI>F%D;W(`17-C;VQH82!C;VUO(&UO<W1R87(@87,@9&%T87,Z`$5S8V]L
M:&$@;R!E<W1I;&\@9&%S(&QI<W1A("AP87)A(&QI<W1A<R!O<F1E;F%D87,I
M`$EL:&$@9&\@3F%T86P`3N-O(&9O:2!E;F-O;G1R861A(&$@9&5F:6YIY^-O
M(&1A(&-L87-S92`E<RX`3&EM<&%N9&\@;W,@87)Q=6EV;W,@4$\@9&\@;?-D
M=6QO("5S+BXN`$QI;7!A;F1O(&$@;&]C86QI>F'GXV\@)7,N+BX@`$QI;7!A
M<@!,:6UP87(@971I<75E=&%S(&1O($U33V9F:6-E`$QI;7!A<B!D861O<R!D
M;R!U=&EL:7IA9&]R.B`E<P!,:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<@!,
M:6UP87(@9&%D;W,@9&\@=71I;&EZ861O<@!,:6UP82!487)D90!#;&EQ=64@
M<&%R82!#;VYT:6YU87(`0VQI8VMA=&5L;"!V:6$@2%144`!&96-H87(@:F%N
M96QA`$[Z=F5N<P!.^G9E;G,@36%T:6YA:7,`16YE=F]A9&\`26QH87,@0V]C
M;W,@*$ME96QI;F<I`$-O;&%P<V%R($)A<G)A($QA=&5R86P`0F]R9&%S($-O
M;&%P<V%D87,`4F5P^F)L:6-A(&1A($-O;/1M8FEA`$-O<F5S`%!A;&5T90!3
M96QE8^?C;R!D92!C;W)E<@!#;VQU;F%S.@!4[71U;&]S(&1A<R!C;VQU;F%S
M`$)$`$-O;6%N9&\`0V]N<V]L82!D92!#;VUA;F1O<P!/<.?U97,@9&\@8V]M
M86YD;SH`0V]M86YD;W,Z`$-O;65N=.%R:6\`0V]M971E;F1O`$YO;64@0V]M
M=6T`0V]M;W)O<P!%;7!R97-A`$5S8W)E=F5R("@E<RD`0V]M<'5T861O<F5S
M`$-O;F1IY^-O`$-O;F1IY_5E<P!$:69E<F5NYV%S(&1E($-O;F9I9W5R8>?C
M;P!!(&-O;F9I9W5R8>?C;R!E<W3A(&1E<V%C='5A;&EZ861A`$-O;F9I9W5R
M87(@)7,`0V]N9FER;64@82!086QA=G)A+5!A<W-E`%)E</IB;&EC82!$96UO
M8W+A=&EC82!D;R!#;VYG;P!297#Z8FQI8V$@1&5M;V-RX71I8V$@9&\@0V]N
M9V\`0V]N97CC;R!F86QH;W4N`$-O;F5XXV\@9F%L:&]U.B``0V]N97CC;R!A
M;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,@<F5C=7-A9&$N`$-O;F5X
MXV\@86\@<V5R=FED;W(@9&4@8VAA=F5S('#Z8FQI8V%S(')E8W5S861A+B!2
M87KC;SH@)7,@*"5S*0!#;VYE>.-O(&%O('-E<G9I9&]R($944"!R96-U<V%D
M82X`0V]N=&%C=&]S(&%D:6-I;VYA9&]S(&-O;2!S=6-E<W-O(&%O('-E=2!L
M:79R;R!D92!E;F1E<F7G;W,N`%1I<&\@9&4@8V]N=&7Z9&\@9&\@87)Q=6EV
M;R!C;VUP<FEM:61O.B``0V]N=&7Z9&\@9&4@)7,`0V]N=&EN=6%R`$EL:&%S
M($-O;VL`0F]L:6YH;R!C:&ENZG,`0V]P:6%R`$-O<&EA<B!S96QE8^?C;P!#
M;W!I86YD;R!D92`E<R!P87)A("5S`%)E</IB;&EC82!D82!#;W-T82!2:6-A
M`%)E</IB;&EC82!D82!#;W-T82!D;R!-87)F:6T`3N-O(&9O:2!P;W-S[79E
M;"!E;F-R:7!T87(@82!M96YS86=E;2!C;VT@4$=0+@!.XV\@9F]I('!O<W/M
M=F5L(&%S<VEN87(@82!M96YS86=E;2!C;VT@4$=0+@!.XV\@9F]I('!O<W/M
M=F5L(&5N8W)I<&%R(&$@;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O:2!P
M;W-S[79E;"!A<W-I;F%R(&$@;65N<V%G96T@8V]M(%,O34E-12X`3N-O(&9O
M:2!P;W-S[79E;"!A9&EC:6]N87(@;R!C;VYT86-T;RX@)7,`1F%L:&$@;F$@
M;&EG8>?C;R`H8FEN9"D@86\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S
M[79E;"!V97)I9FEC87(@;R!S86QD;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!C
M;VYE8W1A<B!A;R!S97)V:61O<B`B)7,B('5S86YD;R!&5%`Z("5S`$[C;R!F
M;VD@<&]S<^UV96P@8V]P:6%R("5S('!A<F$@)7,`3N-O(&9O:2!P;W-S[79E
M;"!C<FEA<B!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S
M<^UV96P@8W)I87(@<&%S=&$@9&4@;&]C86QI>F'GXV\@<&%R82!A(&QO8V%L
M:7IAY^-O("5S.@!.XV\@9F]I('!O<W/M=F5L(&1E<V5N8W)I<'1A<B!O<R!D
M861O<R!C;VT@;R!01U`N`$[C;R!F;VD@<&]S<^UV96P@9&5S96YC<FEP=&%R
M(&]S(&1A9&]S(&-O;2!3+TU)344N`$[C;R!F;VD@<&]S<^UV96P@<F5M;W9E
M<B!C;VYT86-T;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R(&QI<W1A
M(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!R96UO=F5R
M(&\@(G-C<FEP="(@9&4@86-T=6%L:7IAY^-O("(E<R(N`$[C;R!F;VD@<&]S
M<^UV96P@9&5T97)M:6YA<B!O(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\@9&\@9&5S=&EN873A<FEO+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&\@;&EV<F\@9&4@96YD97)EYV]S(&-O;7!L971O+@!.XV\@9F]I('!O<W/M
M=F5L(&]B=&5R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O(&-O;7!L971A+@!.
MXV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES=&$@8V]M<&QE=&$@9&%S(&QI
M<W1A<R!D92!D:7-T<FEB=6GGXV\N`$EM<&]S<^UV96P@8V%R<F5G87(@97-T
M<F%TZ6=I82`B)7,B+@!);7!O<W/M=F5L(&UK9&ER("(E<R(N`$[C;R!F;VD@
M<&]S<^UV96P@;V)T97(@82!C:&%V92!P^F)L:6-A(&$@<&%R=&ER(&1O('-E
M<G9I9&]R(&1E(&-H879E<R!P^F)L:6-A<RX`3N-O(&9O:2!P;W-S[79E;"!A
M8G)I<B`B)7,B('!A<F$@97-C<FET82X`3N-O(&9O:2!P;W-S[79E;"!A8G)I
M<B`E<RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!O(&WS9'5L;R!D92!-86YU
M=&5NY^-O(&1E(%1A<F5F87,@)7,`3N-O(&9O:2!P;W-S[79E;"!A8G)I<B!P
M87-T82`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&QE<B`E<RX`3N-O(&9O:2!P
M;W-S[79E;"!R96EN:6-I87(@82!P86QA=G)A+7!A<W-E(&1O('5T:6QI>F%D
M;W(@:6YD:6-A9&\N($%L9W5M(&]U('1O9&]S(&]S('!O<FUE;F]R97,@;N-O
M(&5S=&%V86T@8V]R<F5C=&]S+B!0;W(@9F%V;W(@=&5N=&4@9&4@;F]V;R!O
M=2!C;VYT86-T92!O('-E=2!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('-E
M('!R96-I<V%R(&1E(&UA:7,@86IU9&$N`$[C;R!F;VD@<&]S<^UV96P@;V)T
M97(@04-,`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@;&EV<F\@9&4@96YD97)E
MYV]S+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&QI<W1A(&1E(&1I<W1R
M:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!O8G1E<B!L:7-T87,@9&4@
M9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&%S(&-O
M;7!E=.IN8VEA<R!D;R!S97)V:61O<@!.XV\@9F]I('!O<W/M=F5L(')E=F5R
M=&5R(&$@8V]N9FEG=7)AY^-O+@!);7!O<W/M=F5L(')M9&ER("(E<R(N`$[C
M;R!F;VD@<&]S<^UV96P@9W5A<F1A<B!A(&-O;F9I9W5R8>?C;R!D92`E<RX`
M3N-O(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A
M;'9A9W5A<F1A+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@82!C;VYF:6=U
M<F'GXV\@9&4@<V%L=F%G=6%R9&$Z("5S`$[C;R!F;VD@<&]S<^UV96P@9W5A
M<F1A<B!O(")S8W)I<'0B(&1E(&%C='5A;&EZ8>?C;R!E;3H@(B5S(BX`3N-O
M(&9O:2!P;W-S[79E;"!G=6%R9&%R(&$@8V]N9FEG=7)AY^-O(&1E('-A;'9A
M9W5A<F1A("5S+@!.XV\@9F]I('!O<W/M=F5L(&=U87)D87(@;R!A<G%U:79O
M(&1E(&-O;F9I9W5R8>?C;R`E<RX@4&]D92!U<V%R('5M82!D87,@;W#G]65S
M('!A<F$@9W5A<F1A<B!O(&/S9&EG;R!E;2`E<R!O=2!C;W!I87(@;6%N=6%L
M;65N=&4@;R!C\V1I9V\@86)A:7AO('!A<F$@)7,N`$[C;R!F;VD@<&]S<^UV
M96P@<')O8W5R87(@;F\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S[79E
M;"!D97-L:6=A<B`B)7,B+@!.XV\@9F]I('!O<W/M=F5L(&%C='5A;&EZ87(@
M8V]N=&%C=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@86-T=6%L:7IA<B!A(&QI
M<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`3N-O(&9O:2!P;W-S[79E;"!E<V-R
M979E<B!A(&-O;F9I9W5R8>?C;R!P87)A("(E<R(Z("5S`$[C;R!E;F-O;G1R
M96D@82!"87)R82!,871E<F%L(&1O($UO>FEL;&$N($%S<V5G=7)E+7-E('%U
M92!A(&)A<G)A(&QA=&5R86P@97-TX2!A8F5R=&$N`$[C;R!F;VD@<&]S<^UV
M96P@871R:6)U:7(@86\@=71I;&EZ861O<B`B)7,B(&]S('-E9W5I;G1E<R!D
M:7)E:71O<R!S;V)R92!A('!A<W1A("(E<R(Z("5S`%1E>'1O($-O;G1A9&\`
M4&'M<P!#=7)S;W,`0W)I87(`0W)I87(@=6UA(&QI9V'GXV\`0W)I87(@=6UA
M(&YO=F$`0W)I87(@<W5B+7!A<W1A<P!097)M:7-S]65S(&1O($-R:6%D;W(`
M3OIM97)O(&1O(&-A<G3C;R!D92!C<NED:71O`%)E</IB;&EC82!D82!#<F_A
M8VEA`%)E</IB;&EC82!D92!#=6)A`%%U871R;R!F87-E<R!C;W)R96YT97,`
M1&%T82](;W)A`%523"!C;W)R96YT92#I`$5S=&%D;R!D;R!496UP;P!3:71U
M8>?C;R!A8W1U86PZ(`!%<W1I;&\@86-T=6%L`%!E<G-O;F%L:7IA<B!A<R!T
M87)E9F%S('%U92!S97+C;R!E>&5C=71A9&%S(&%Q=6%N9&\@;R!L;V=I;B!N
M;R`E<RX`0V]R=&%R`$-O<G1A<B!A('-E;&5CY^-O`%)E</IB;&EC82!D92!#
M:&EP<F4`0VER[6QI8V\@*$M/23@M4BD`0VER[6QI8V\@*%=I;F1O=W,M,3(U
M-BD`0VER[6QI8V\O56-R86YI86YO("A+3TDX+54I`%)E</IB;&EC82!#:&5C
M80!$1`!$:6%R:6%M96YT90!.879E9V%D;W(@9&4@P7)V;W)E(&1E($1A9&]S
M`$1A=&$`1&%T82!D92!296-E<.?C;P!396QE8^?C;R!D92!D871A`$1I80!2
M96UO=F5R($-O7VQU;F$`1&5Z96UB<F\`3OIM97)O<R!D96-I;6%I<P!2961U
M>FER(&EN9&5N=&'GXV\`4&]R($]M:7-SXV\`0V]R(%!O<B!/;6ES<^-O`$ED
M96YT:61A9&4@4&%D<N-O`%!E<FUI<W/U97,@4&]R($]M:7-SXV\`4&5R;6ES
M<_5E<R!P;W(@;VUI<W/C;P!$969I;FGG]65S`%)E;6]V97(`4F5M;W9E<B!'
M<G5P;P!296UO=F5R(%!E<FUI<W/C;P!296UO=F5R(&4@<'5R9V%R(&UE;G-A
M9V5N<P!296UO=F5R(&/I;'5L80!296UO=F5R(&-O;'5N80!296UO=F5R(&UO
M9&5L;R!A;'1E<FYA=&EV;R!E>&ES=&5N=&4`4F5M;W9E<B!P97)M:7-S]65S
M(&1E("(E<R(`4F5M;W9E<B!P97)M:7-S]65S('!A<F$@)R5S)R!E('%U86ES
M<75E<B!S=6(M<&5R;6ES<_5E<S\`4F5M;W9E<B!L:6YH80!296UO=F5R(&ED
M96YT:61A9&4@<V5L96-C:6]N861A`%)E;6]V97(@82!C;VQU;F$@8V]R<F5N
M=&4`4F5M;W9E<B!A(&QI;FAA(&-O<G)E;G1E`%)E;6]V97(@97-T82!P97)M
M:7-SXV\@92!T;V1A<R!A<R!S=6%S('-U8BUP97)M:7-S]65S/P`B4V-R:7!T
M(B!D92!A8W1U86QI>F'GXV\@(B5S(B!R96UO=FED;RX`36]M96YT;R!D92!E
M;G1R96=A`$1I;F%M87)C80!$97-C<F5V82!O(%!R;V)L96UA`$1E<V-R:>?C
M;P!0;W)M96YO<F5S("AT86UBZ6T@;F\@<F5G:7-T;RP@(FQO9R(L(&1O($AO
M<F1E*3H`3W,@9&5T86QH97,@9F]R86T@96YV:6%D;W,@<&%R82!O(&%D;6EN
M:7-T<F%D;W(@9&\@<VES=&5M82X`1&5S96YV;VQV:6UE;G1O`%!O;G1O(&1E
M($]R=F%L:&\`4&]N=&\@9&4@3W)V86QH;R!N82#Z;'1I;6$@:&]R83H@`%!O
M;G1O(&1E(&]R=F%L:&\Z(`!$:7)E8^?C;R!D82!E<W%U97)D82!P87)A(&$@
M9&ER96ET80!$:7)E8^?C;R!D82!D:7)E:71A('!A<F$@82!E<W%U97)D80!$
M:7)E8W3S<FEO`$UO<W1R87(@=&5M<&]S(&-O;2`R-"!H;W)A<S\`3W#G]65S
M(&1E(%9I<W5A;&EZ8>?C;P!-;W-T<F%R('!R979I<^-O('!O<FUE;F]R:7IA
M9&$`36]S=')A<B!P<F5V:7/C;R`H5$%&*0!&;W)M871O(&1E('9I<W5A;&EZ
M8>?C;P!.;W1I9FEC8>?C;R!D92!$:7-P;W-IY^-O`$1J:6)U=&D`3N-O(')E
M;6]V97(`3N-O('5T:6QI>F4@;R!M86EN=&5N86YC92YP:'`@9&ER96-T86UE
M;G1E`$$@<')I;65I<F$@;&EN:&$@8V]N=.EM(&]S(&YO;65S(&1O<R!C86UP
M;W,_(%-E('-I;2P@87-S:6YA;&%R(&5S=&$@8V%I>&$Z`$1O;6EN:6-A`%)E
M</IB;&EC82!$;VUI;FEC86YA`%)E8V5B97(`4F5C96)E<B`E<P!$97-C87)R
M96=A<B!A(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2`B<V-R:7!T(B!0
M2%`N`$QI<W1A(&1E(&1E<V5N<F]L87(`1')O9V%S`$-O<G)E:6\@96QE8W1R
M\VYI8V\`15)2`%)E</IB;&EC82!D;R!%<75A9&]R`$5D:71A<@!%9&ET87(@
M0FQO8V\`161I=&%R($=R=7!O`$5D:71A<B!097)M:7-S]65S`$5D:71A<B!0
M97)M:7-S]65S`$5D:71A<B!P97)M:7-S]65S(&1E("5S`$5D:71A<B!O<.?U
M97,@9&4Z`$5D:71A<B!P97)M:7-S]65S(&1E("(E<R(`161I=&%R('!E<FUI
M<W/U97,@9&4@)7,`161U8V'GXV\`16=I<'1O`%)E</IB;&EC82!D92!%;"!3
M86QV861O<@!%;&5M96YT;RXN+@!%;0!#;W)R96EO($5L96-T<O-N:6-O`$5N
M9&5R9>=O(&1E($-O<G)E:6\@16QE8W1R\VYI8V\`3W,@96YD97)EYV]S('3J
M;2!Q=64@8V]I;F-I9&ER+@!-96YS86=E;2!C;VT@8V]N9FER;6'GXV\`4^UM
M8F]L;W,@9&4@16UOY^-O`$UE;G-A9V5M('9A>FEA+@!396T@<F5S=6QT861O
M<RX`4V5M('1E<FUO<R!D92!P<F]C=7)A`$%C=&EV87(@:6YS97+GXV\@9&4@
M:6UA9V5N<R!D92!'86QE<FEA<R!&;W1O9W+A9FEC87,@;F\@=&5X=&\_`$%C
M=&EV87(@;65N=2!D92!C;VYT97AT;R!N;R!B;W3C;R!D:7)E:71O(&1O(')A
M=&\_`$%N;R!D92!F:6T`075M96YT87(@161I=&]R`$EN=')O9'5Z82!U;6$@
M<&5R9W5N=&$@9&4@<V5G=7)A;N=A('%U92!S97+A(&-O;G9I9&%D;R!A(')E
M<W!O;F1E<B!S92!P<F5C:7-A<B!D92!R96EN:6-I87(@82!S=6$@<&%L879R
M82UP87-S92P@92YG+BP@)V-O;6\@<V4@8VAA;6$@;R!S974@86YI;6%L(&1E
M(&5S=&EM8>?C;S\G.@!);G1R;V1U>F$@;R!54DP@9&$@:6UA9V5M(&%Q=6D`
M16YT<F%D87,Z("5D('1O=&%L+"`E9"!A8W1U86QI>F%D87,L("5D(&YO=F%S
M+"`E9"!A;'1E<F%D87,L("5D(&1E<V-O;FAE8VED87,`1W5I;ND@17%U871O
M<FEA;`!%<W1A9&\@9&$@17)I=')E:6$`17)R;P!%<G)O(&YA(&UE;G-A9V5M
M(&1E(&-O<G)E:6\@96QE8W1R\VYI8V\N`$5R<F\@86\@97-C<F5V97(@(B5S
M(BX`17)R;SH@`%)E</IB;&EC82!D82!%<W3S;FEA`%)E</IB;&EC82!$96UO
M8W+A=&EC82!&961E<F%L(&1A($5T:?-P:6$`R71I8V\`175R;W!A`$-A9&$@
M,34@;6EN=71O<P!#861A(#(@;6EN=71O<P!#861A(#,P('-E9W5N9&]S`$-A
M9&$@-2!M:6YU=&]S`$-A9&$@16YT<F%D80!#861A(&UE:6$@:&]R80!#861A
M(&UI;G5T;P!686QO<F5S(&5X96UP;&\Z`$5X96-U=&%R`$5X96-U=&%N9&\Z
M`$5X<&%N9&ER`$UO<W1R87(@0F%R<F$@3&%T97)A;``G*2<@97-P97)A9&\`
M17-P97)A=F$@=6UA('-I;7!L97,@<&%L879R82!O=2!U;2!T97)M;R!D92!P
M<F]C=7)A(&5N=')E(&%S<&%S`$1A=&$@9&4@17AP:7)AY^-O`$5X<&]E;G1E
M`$5X=')A:6YD;R!D92`E<RXN+B``0V]R(&1O(%!R:6UE:7)O(%!L86YO`$-A
M<G)E9V%R(&-O;F9I9W5R8>?C;R!D92!I;G-T86QAY^-O('!O<B!&5%``3N-O
M(&9O:2!P;W-S[79E;"!P=7AA<B!A<R!P<F5F97+J;F-I87,N`$9A;&AA(&YA
M(&QI9V'GXV\@86\@<V5R=FED;W(@3$1!4"X`1F%L:&$@;F$@;&EG8>?C;R!A
M;R!S97)V:61O<B!334(N`$9A;&AA(&%O(&-O<&EA<B!D92`B)7,B+@!&86QH
M82!A;R!C;W!I87(@<&%R82`B)7,B+@!&86QH82!A;R!C<FEA<B!U;6$@;F]V
M82!C;VYE>.-O(%-!4TPN`$9A;&AA(&%O(&UO=F5R('!A<F$@(B5S(BX`0F]M
M`$EL:&%S($9A;&ML86YD("A-86QV:6YA<RD`26QH87,@1F%R;V4`17)R;R!&
M871A;#H`1F%X`$9E=F5R96ER;P!!<&%R96YT80!!<&%R96YT83H@`$%L9W5N
M<R!!9W5A8V5I<F]S`$%L9W5N<R!.97;U97,`36%T<FEZ(&1E(&-A;7!O<P!&
M:6II`$-O;G1A9V5M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O`$-O;G1A9V5M
M(&1E($%R<75I=F]S.B`E<R!A<G%U:79O<P!'97-TXV\@9&4@1FEC:&5I<F]S
M`$YO;64@9&\@07)Q=6EV;P!396QE8^?C;R!D;R!A<G%U:79O`$-A<G)E9V%M
M96YT;R!D92!A<G%U:79O`$-A<G)E9V%M96YT;W,@9&4@9FEC:&5I<F]S(&[C
M;R!SXV\@<W5P;W)T861O<RX`1FEL=')O<P!&:6YLXFYD:6$`475A<G1O($-R
M97-C96YT90!1=6%R=&\@0W)E<V-E;G1E`$9I>&%R('+A8VEO`$EN=F5R=&5R
M`$9L=71U86YT90!.979O96ER;P!!('!A<W1A("5S(&[C;R!E>&ES=&4N`$-O
M<B!D;R!497AT;P!#;VUI9&$`4&%R82!N879E9V%D;W)E<R!Q=64@;N-O('-U
M<&]R=&%M(&EM86=E;G,`4')E=FESXV\@*%1!1BD`1&EA<R!D92!0<F5V:7/C
M;R`H;F]T92US92!Q=64@87,@<')E=FES]65S(&EN8VQU96T@=&%N=&\@9&EA
M<R!C;VUO(&YO:71E<SL@=6T@=F%L;W(@9&5M87-I861O(&=R86YD92!P;V1E
M(')E<W5L=&%R(&YU;2!B;&]C;R!M=6ET;R!L87)G;RD`17-Q=65C974M<V4@
M9&$@<&%L879R82UP87-S93\`36]D96QO<P!$:71O<P!4:7!O(&1E(&1I=&]S
M`$1I=&]S`$1I=&]S(#(`1O-R=6YS`%)E96YV:6]S`$%P;&EC8>?U97,@*&WS
M9'5L;W,I(&5N8V]N=')A9&%S.B`E<P!087-T87,@96YC;VYT<F%D87,Z`#:J
M`$UO;&1U<F%S`%)E</IB;&EC82!&<F%N8V5S80!&<F%NYV$L($UE=')O<&]L
M:71A;F$`1W5I86YA($9R86YC97-A`%!O;&ENZ7-I82!&<F%N8V5S80!497)R
M87,@075S=')A:7,@92!!;G3A<F-T:6-A<R!&<F%N8V5S87,`1&4`1&4@`$1E
M<V-R:>?C;R!#;VUP;&5T80!,=6$@0VAE:6$`3F]M92!#;VUP;&5T;P!$:69U
M<V%S`%)E</IB;&EC82!'86)O;F5S80!'86QE<FEA(&1E(&]N9&4@<F5T:7)A
M<B!A(&EM86=E;0!'86QE<FEA.@!297#Z8FQI8V$@9&$@1^)M8FEA`$=E<F%R
M($-O;F9I9W5R8>?C;R`E<P!#\V1I9V\@1V5R861O`$=E<F%N9&\@;R!E<W1A
M9&\@9&\@;?-D=6QO("5S+BXN`$=E\W)G:6$`4F5P^F)L:6-A($9E9&5R86P@
M9&$@06QE;6%N:&$`17)R;R!E;2!G971O<'0Z`%)E</IB;&EC82!D;R!'86YA
M`$=I8G)A;'1A<@!.;VUE(%!R\W!R:6\`27(`1_9D96P`4&5S<75I<V$@1V]O
M9VQE`$[M=F5I<R!D92!C:6YZ96YT;P!'<NEC:6$`1W)E9V\@*$E33RTX.#4Y
M+3<I`$=R;VYE;.)N9&EA`$=R86YA9&$`061M:6YI<W1R8>?C;R!D92!'<G5P
M;W,`3F]M97,@9&4@9W)U<&]S(&[C;R!P;V1E;2!E<W1A<B!V87II;W,`4&5R
M;6ES<_5E<R!D92!G<G5P;P!'<G5P;W,`1W5A9&%L=7!E`$=U86T`4F5P^F)L
M:6-A(&1A($=U871E;6%L80!'=65R;G-E>0!097)M:7-S]65S(&1A<R!6:7-I
M=&%S`%!E<FUI<W/U97,@9&%S(%9I<VET87,`3&EV<F\@9&4@5FES:71A<P!'
M=6ENZ0!'=6ENZ2U":7-S874`4F5P^F)L:6-A($-O+6]P97)A=&EV82!D82!'
M=6EA;F$`2%1-3`!/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E;65N=&4@
M82!R96UO=F5R(&$@^FQT:6UA(&/I;'5L82!D82!L:6YH82X`3R!(5$U,07)E
M82!R96-U<V$M<V4@8V]B87)D96UE;G1E(&$@<F5M;W9E<B!A(/IL=&EM82!C
M;VQU;F$@9&$@=&%B96QA+@!/($A434Q!<F5A(')E8W5S82US92!C;V)A<F1E
M;65N=&4@82!R96UO=F5R(&$@^FQT:6UA(&QI;FAA(&1A('1A8F5L82X`075T
M96YT:6-AY^-O($A44%`@;N-O(&9O:2!E;F-O;G1R861A+@!297#Z8FQI8V$@
M9&\@2&%I=&D`06QG;W)I=&UO(&1E(")(87-H(@!.96)L:6YA`$-A8F7G86QH
M;P!);&AA<R!(96%R9"!E($UC1&]N86QD`%1E;7!O<F%L+50@1F]R=&4`2&5B
M<F5U("A)4T\M.#@U.2TX+4DI`$%L='5R80!!:G5D80!!:G5D82!S;V)R92!O
M(&5D:71O<@!!:G5D80!!<&QI8V'GXV\@875X:6QI87(@<&%R82!C<FEA<B!E
M(&UA;G1E<B!T<F%D=>?U97,@9&$@<&QA=&%F;W)M80I(;W)D92!E(&1A<R!S
M=6%S(&%P;&EC8>?U97,@*&WS9'5L;W,I+@I087)A('5M82!I;G1R;V1UY^-O
M(&QE<B!O(&9I8VAE:7)O(%)%041-12!N97-T82!P87-T82X`2&5M:7-FZ7)I
M;P!!<75I(&5S=.$@;R!I;NUC:6\@9&\@87)Q=6EV;SH`06QT80!.;VUE<R!D
M87,@96YT<F%D87,@:&ES=/-R:6%S(&[C;R!P;V1E;2!E<W1A<B!V87II;W,`
M0V%?<V$`17-T861O(&1A($-I9&%D92!D;R!6871I8V%N;P!#87-A`$5N9&5R
M9>=O(&1E($-A<V$`5&5L969O;F4@9&4@0V%S80!297#Z8FQI8V$@9&%S($AO
M;F1U<F%S`$AO;F=U96-O;F=U90!(;W)D90!'97)A9&]R(&1E('1R861UY_5E
M<R!(;W)D90!(;W)D92]+;VQA8CH@1&%D;W,@6$U,("5S(&EN=N%L:61O<R!N
M82!M96YS86=E;2`E<P!(;W)D92]+;VQA8CH@3F5N:'5M82!M96YS86=E;2!C
M;W)R97-P;VYD92!A;R!O8FIE8W1O("5S`$AO<F1E+TMO;&%B.B!.96YH=6T@
M;V)J96-T;R!D;R!T:7!O("5S(&5N8V]N=')A9&\@;F$@;65N<V%G96T@)7,`
M2&]R9&4O2V]L86(Z(%)E;6_GXV\@9&4@)7,@(B5S(B!T979E('-U8V5S<V\`
M2&]R9&4O2V]L86(Z(%-I;F-R;VYI>F'GXV\@9&4@)7,@(B5S(B!T979E('-U
M8V5S<V\`2&]R9&4O2V]L86(Z($\@;6]T;W(@9&4@:6YT96=R8>?C;R!R97%U
M97(@82!E>'1E;G/C;R!02%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($[C;R!F
M;VD@<&]S<^UV96P@8W)I87(@=6UA(&YO=F$@X7)V;W)E<R!834P@<&%R82!O
M(&]B:F5C=&\@)7,`2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@<F5M
M;W9E<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@3N-O(&9O:2!P;W-S[79E
M;"!O8G1E<B!O($E$($U)344@<&%R82!A('!A<G1E(&1E('1I<&\@)7,`2&]R
M9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@<VEN8W)O;FEZ87(@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z($[C;R!F;VD@<&]S<^UV96P@<VEN8W)O;FEZ
M87(@<&%R=&EL:&%S.B`E<P!(;W)D92]+;VQA8CH@4&%R=&EL:&$@(B5S(B!D
M97-C;VYH96-I9&$`5')AYV\@2&]R:7IO;G1A;`!%;F-H:6UE;G1O(&AO<FEZ
M;VYT86P`2&]R:7IO;G1A;#H`0V]M;R!C:&5G;W4@87%U:3\@*%!O<B!F879O
M<B!R97!O<G1E+6\A*0!1=6%N=&%S(&-O;'5N87,@<')E=&5N9&4@:G5N=&%R
M/P!1=6%N=&]S(&-A;7!O<R`H8V]L=6YA<RD@97AI<W1E;3\`475A;G1A<R!L
M:6YH87,@<')E=&5N9&4@:G5N=&%R/P!(=6UI9&%D90!(=6UI9&%D93H@`$AU
M;6]R:7-T87,`4F5P^F)L:6-A(&1A($AU;F=R:6$`02!C<FEAY^-O(&1A(&-A
M:7AA('!O<W1A;"!)34%0(&9A;&AO=3H@)7,`4F5M;^?C;R!D82!C86EX82!P
M;W-T86P@24U!4"!F86QH;W4Z("5S`$-R:6'GXV\@9&4@<75O=&$@9&4@8V%I
M>&$@<&]S=&%L($E-05`@9F%L:&]U.B`E<P!%;F1E<F7G;R!)4`!%;F1E<F7G
M;R!)4"!I;F1I<W!O;NUV96PN`$5N9&5R9>=O($E0(&9O<F$@9&\@8FQO8V\@
M0TE$4B!P97)M:71I9&\N`%9I;VQAY^-O(&1E(&)L;W%U96EO(&1E($E0`$E?
M;G-E<FER($QI;FAA($%N=&5S`%)E</IB;&EC82!D82!)<VSB;F1I`$%P96YA
M<R#-8V]N97,`S6-O;F5S(&-O;2!497AT;P!.;VUE(&1A(&ED96YT:61A9&4Z
M`%-E(&[C;R!F;W(@;6]S=')A9&\@8V]R<F5C=&%M96YT92P@)7,@<&%R82!O
M(&%B<FER(&YU;6$@;F]V82!J86YE;&$N`%-E(&[C;R!V:7(@<75A;'%U97(@
M[6-O;F4@86\@=7-A<B!O($EN=&5R;F5T($5X<&QO<F5R+"!P;V1E('!R96-I
M<V%R(&1E('-E;&5C8VEO;F%R(&5S=&$@8V%I>&$@<&%R82!D97-L:6=A<B!A
M('1R86YS<&%RZFYC:6$N`%-E('9I<B!E<W1A(&UE;G-A9V5M(&YM87,@;N-O
M(&$@:6UA9V5M('!R;W!R:6%M96YT92!D:71A+"!A(&EM86=E;2!Q=64@<')E
M=&5N9&4@8V%R<F5G87(@;N-O('!O9&4@<V5R(&UO<W1R861A('!E;&\@<V5U
M(&YA=F5G861O<BX`4')E=FESXV\@9&$@26UA9V5M.@!54DP@9&$@:6UA9V5M
M`%523"!D82!I;6%G96TZ`$EM86=E;2!D92!G86QE<FEA`$EM86=E;2!D92!G
M86QE<FEA.@!#87)R96=A;65N=&\@9&$@:6UA9V5M`$EM86=E;G,`26UP;W)T
M87(L(%!A<W-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R
M=&%D;W,Z`$EN7W-E<FER($QI;FAA($1E<&]I<P!#\V1I9V\@9&4@86/GXV\@
M:6YT<F]D=7II9&\@97-TX2!I;F-O<G)E8W1O+@!.;VUE(&1E('5T:6QI>F%D
M;W(@;W4@<&%L879R82UP87-S92!E<G)A9&]S+@!.;VUE(&1E('5T:6QI>F%D
M;W(@;W4@96YD97)EYV\@86QT97)N871I=F\@97)R861O<RX@0V]N=&%C=&4@
M;R!S974@861M:6YI<W1R861O<B!D92!S:7-T96UA('!A<F$@;V)T97(@86IU
M9&$N`$%U;65N=&%R(&$@26YD96YT8>?C;P!297#Z8FQI8V$@9&$@S6YD:6$`
M571I;&EZ861O<F5S($EN9&EV:61U86ES`%)E</IB;&EC82!D82!);F1O;NES
M:6$`26YF;W)M8>?C;P!);F9O<FUAY^-O`$EN9F]R;6'GXV\@:N$@;N-O(&5S
M=.$@9&ES<&]N[79E;`!);FEC:6%L:7IA;F1O(&\@;?-D=6QO("5S+BXN(`!)
M;G-E<FER($-?;VQU;F$@1&5P;VES`$EN<V5R:7(@26UA9V5M`$EN<V5R:7(@
M5&%B96QA`$EN<V5R:7(@3&EG8>?C;R#@(%=E8@!);G-E<FER(%]#;VQU;F$@
M06YT97,`26YS:7)I<B!U;6$@;F]V82!C;VQU;F$@9&5P;VES(&1A(&-O<G)E
M;G1E`$EN<VER:7(@=6UA(&YO=F$@8V]L=6YA(&%N=&5S(&1A(&-O<G)E;G1E
M`$EN<VER:7(@=6UA(&YO=F$@;&EN:&$@9&5P;VES(&1A(&-O<G)E;G1E`$EN
M<VER:7(@=6UA(&YO=F$@;&EN:&$@86YT97,@9&$@8V]R<F5N=&4`26YS97)I
M<B!U;2!P87+A9W)A9F\@87#S<R!O(&[S(&-O<G)E;G1E`$EN<V5R:7(@=6T@
M<&%RX6=R869O(&%N=&5S(&1O(&[S(&-O<G)E;G1E`$EN<VER:7(@;6]D96QO
M(&%L=&5R;F%T:79O`$EN=')O9'5Z82!U;2!E;F1E<F7G;R!D92!C;W)R96EO
M(&5L96-T<O-N:6-O(&]N9&4@<&]S<V$@<F5C96)E<B!A(&YO=F$@<&%L879R
M82UP87-S93H`26YS:7)I<B!CZ6QU;&$@87#S<P!);G-E<FER(&/I;'5L87,@
M86YT97,`26YS97)I<B!CZ6QU;&$@9&5P;VES`$EN<V5R:7(@8V]L=6YA(&%N
M=&5S`$EN<V5R:7(@;65N<V%G96YS`$EN<V5R:7(@<&%RX6=R869O(&%N=&5S
M`$EN<V5R:7(@<&%RX6=R869O(&%N=&5S`$EN<V5R:7(@;&EN:&$@9&5P;VES
M`$EN<V5R:7(@;&EN:&$@86YT97,`26YT<F]D=7IA(&$@<F5S<&]S=&$@97AI
M9VED82!P87)A(&$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A.@!);G-E<FER+TUO
M9&EF:6-A<B!);6%G96T`26YS97)I<B]-;V1I9FEC87(@3&EG8>?C;P!#<NED
M:71O(&EN<W5F:6-I96YT92!P87)A(&5N=FEA<B!P87)A(&$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O+@!#<NED:71O(&EN<W5F:6-I96YT92X`26YT96ER;P!,
M:7-T82!D92!I;G1E:7)O<P!51$@@*%5S97(@1&%T82!(96%D97(I(&EN=N%L
M:61O+@!$861O<R!:25`@:6YVX6QI9&]S`$%P;&EC8>?C;R!I;G;A;&ED82X`
M240@9&4@;&]T92`H(F)A=&-H(BD@:6YVX6QI9&\N`$]S(&1A9&]S('-U8FUE
M=&ED;W,@<^-O(&EN=N%L:61O<RX`16YD97)EYV\@9&4@9&5S=&EN;R!I;G;A
M;&ED;RX`1F]R;6%T;R!D;R!A<G%U:79O(&EN=N%L:61O`$-H879E(&1A(&QI
M8V5NYV$@:6YVX6QI9&$N`$QO8V%L:7IAY^-O(&EN=N%L:61A(&5S<&5C:69I
M8V%D82X`;7-G7W1Y<&4@:6YVX6QI9&\N`&%P:5]I9"!I;G;A;&ED;R!O=2!E
M;2!F86QT82X`4&%RXFUE=')O<R!I;G;A;&ED;W,@;W4@96T@9F%L=&$N`%!E
M<FUI<W/C;R!P87)E;G1A;"!I;G;A;&ED82X`240@9&4@<&%R8V5I<F\@:6YV
MX6QI9&\N`$/S9&EG;R!D92!P<F]D=71O(&EN=N%L:61O+@!0<F]T;V-O;&\@
M:6YVX6QI9&\N`$1E<W1I;F%TX7)I;R!I;G;A;&ED;SH@(B5S(@!/8FIE8W1O
M(&1E('!A<G1I;&AA(&EN=N%L:61O`$5N9&5R9>=O(&1A(&]R:6=E;2!I;G;A
M;&ED;RX`1&%D;W,@=6YI8V]D92!I;G;A;&ED;W,N`$EN=F5N=.%R:6\`4F5P
M^F)L:6-A($ES;.)M:6-A(&1O($ERXV\`4F5P^F)L:6-A(&1O($ER87%U90!2
M97#Z8FQI8V$@9&$@27)L86YD80!);&AA(&1E($UA;@!496UP;W)A:7,M5"!)
M<V]L861O<P!%<W1A9&\@9&4@27-R865L`$5M:7-S;W(`273A;&EC;P!297#Z
M8FQI8V$@271A;&EA;F$`2F%M86EC80!*86YE:7)O`$IA<.-O`$IA<&]NZG,@
M*$E33RTR,#(R+4I0*0!*97)S97D`4F5I;F\@2&%S:&5M:71A(&1A($IO<F3B
M;FEA`$IU;&AO`$IU;FAO`$IU<W1I9FEC87(`0V5N=')A<@!*=7-T:69I8V%R
M`$IU<W1I9FEC87(@X"!%<W%U97)D80!*=7-T:69I8V%R(.`@1&ER96ET80!2
M97#Z8FQI8V$@9&\@0V%Z87%U:7-TXV\`4')E<V5R=F%R(&\@;W)I9VEN86P_
M`%)E</IB;&EC82!D;R!1=>EN:6$`3R!S97)V:61O<B!+97)B97)O<R!R96IE
M:71O=2!A(&%U=&5N=&EC8>?C;RX`3F]V871O<R!N;R`B2V5R;F5L(@!#<FEA
MY^-O(&1A($-H879E`$EM<')E<W/C;R!D:6=I=&%L(&1A(&-H879E`$-O;7!R
M:6UE;G1O(&1A(&-H879E`%1I<&\@9&$@0VAA=F4`571I;&EZ8>?C;R!D82!#
M:&%V90!!(&-H879E(&KA(&5X:7-T92!N;R!S97)V:61O<B!D92!C:&%V97,@
M</IB;&EC87,N`$UI^F1O<P!1=6ER:6)A=&D`4F5P^F)L:6-A(%!O<'5L87(@
M1&5M;V-RX71I8V$@9&$@0V]R96EA`%)E</IB;&EC82!D82!#;W)E:6$`0V]R
M96%N;R`H155#+4M2*0!+=7=A:70`4F5P^F)L:6-A(%%U:7)G=6EZ90!?1&ES
M<&]S:>?C;P!)9&EO;6$`4F5P^F)L:6-A(%!O<'5L87(@1&5M;V-RX71I8V$@
M3&%O`%%U87)T;R!$96-R97-C96YT90!1=6%R=&\@1&5C<F5S8V5N=&4`VFQT
M:6UA($%C='5A;&EZ8>?C;SH`VFQT:6UA(&5N=')A9&$Z("5S`-IL=&EM82!E
M;G1R861A.B`E<R!D92`E<P#:;'1I;6$@96YT<F%D83H@3G5N8V$`4F5P^F)L
M:6-A(&1A($QE=/-N:6$`3&5I`$1I<W!O<VGGXV\`1&5I>&%R('9A>FEO('!A
M<F$@9FEC87(@<V5M(&)O<F1A`$SM8F%N;P!%<W%U97)D80!#86)EYV%L:&\@
M9&$@97-Q=65R9&$`5F%L;W)E<R#@(&5S<75E<F1A`$QE<V]T;P!,:6+I<FEA
M`$=R86YD92!*86UA:&ER:7EA(%-O8VEA;&ES=&$@4&]P=6QA<B#!<F%B92!D
M82!,[6)I80!,:7-T96YS=&%I;F4`0VAU=F$@(DUO;&AA+51O;&]S(@!#:'5V
M:7-C;W,`0VAU=FES8V]S($UA=&EN86ES`$-H=79I<V-O<R!697-P97)T:6YO
M<P!097%U96YO($%G=6%C96ER;P!#:'5V:7-C;R!C;VT@5')O=F]A9&$`475E
M9&$@9&4@3F5V90!.979E`"),:6UE<FEC:R(`3&EG8>?C;P!,:6=AY^-O(&%P
M;VYT82!P87)A.@!,:6=A<B!O(&5N9&5R9>=O(&1E(&-O<G)E:6\@96QE8W1R
M\VYI8V\@X"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A;R!M;W-T<F%R`$QI9V'G
M]65S`$)O;&EN:&\@;&EN=7CJ<P!,:7-T82`M(&\@=71I;&EZ861O<B!P;V1E
M('9E<B!A('!A<W1A`$QI<W1A<B!"87-E<R!D92!$861O<P!-;W-T<F%R(%3S
M<&EC;W,@9&4@06IU9&$`3&ES=&%R(%1A8F5L87,`3&ES=&%G96TM07)Q=6EV
M;P!,:7-T86=E;2U!:G5D80!)1"!D82!,:7-T80!,:7-T86=E;2U$;VYO`$QI
M<W1A9V5M+5-U8FUI<W/U97,`3&ES=&%G96TM4W5B<V-R:71A<P!,:7-T86=E
M;2U.XV\@<W5B<V-R:71A<P!!(&QI<W1A9V5M(&1E('5T:6QI>F%D;W)E<R!E
M<W3A(&1E<V%C=&EV861A+@!,:71E<F%T=7)A.@!297#Z8FQI8V$@9&$@3&ET
M=>)N:6$`0V%R<F5G86YD;R!B:6)L:6]T96-A<RXN+@!#87)R96=A;F1O+BXN
M`%1E;7!O(&QO8V%L.@!,;V-A;&EZ8>?C;R!E($9U<V\@2&]RX7)I;P!,;V-A
M;&EZ8>?C;P!%;G1R87(`4V%I<@!487)E9F%S(&1E($5N=')A9&$`02!A=71E
M;G1I8V'GXV\@9F%L:&]U('!O<B!O($YO;64@9&4@571I;&EZ861O<B!O=2!A
M(%!A;&%V<F$M4&%S<V4@97-T87)E;2!I;F-O<G)E8W1O<RX`02!A=71E;G1I
M8V'GXV\@9F%L:&]U+@!497AT;R!L;VYG;P!!;6]R`$)A:7AO`$QE=')A<R!G
M<F5G87,@;6EN^G-C=6QA<P!,971R87,@;&%T:6YA<R!M:6[Z<V-U;&%S`$[Z
M;65R;W,@<F]M86YO<R!M:6[Z<V-U;&]S`$QU>&5M8G5R9V\`34T`34]41`!/
M(&%N97AO($U3+51.148@;N-O(&-O;G1I;FAA(&1A9&]S+@!-4T<`36%C874`
M36%C963S;FEA+"!!;G1I9V$@4F5P^F)L:6-A($IU9V]S;&%V82!D80!-861A
M9^%S8V%R`$UA9VEA`$-O<G)E:6\`061M:6YI<W1R8>?C;R!D92!#;W)R96EO
M`$9A>F5R(&QI7V=AY^-O+BXN`$%S<V5G=7)E+7-E(&1E('%U92!T96T@;R!0
M14%2(&EN<W1A;&%D;R!E(&YO(&-A;6EN:&\@9&4@:6YC;'5S]65S("AI;F-L
M=61E('!A=&@I+@!#<FEA;F1O(&$@<&%S=&$@)7,`36%L875I`$UA;.%S:6$`
M36%L9&EV87,`36%L:0!-86QT80!':7)A(&$@;&ES=&$@9&4@8V%T96=O<FEA
M<R!Q=64@<&]D92!A=')I8G5I<B!A;W,@:71E;G,L(&)E;2!C;VUO(&%S(&-O
M<F5S('%U92!L:&5S(&5S=.-O(&%S<V]C:6%D87,N`$UA<&$@36%P,C0`36%P
M82!-87!1=65S=`!-87+G;P!-87)G96T`36%R8V%R(&-O;6\@3&ED82].XV\@
M;&ED80!-87)C87(@9&4@;W5T<F%S(&9O<FUA<R`H92YG+BP@26UP;W)T86YT
M92]0;W(@<F5S<&]N9&5R*0!);&AA<R!-87)S:&%L;`!-87)T:6YI8V$`0V%M
M<&]S('%U92!C;W)R97-P;VYD96T`36%U<FETXFYI80!-875R[6-I;P!-X7AI
M;6\@8W+I9&ET;R!P97)M:71I9&\N`$WA>&EM;R!N^FUE<F\@9&4@<&%R=&5S
M(&YU;6$@;65N<V%G96T@97AC961I9&\N`%1E;7!E<F%T=7)A(&WA>&EM82!N
M87,@^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A(&WA>&EM82!N87,@
M^FQT:6UA<R`V(&AO<F%S.B``0V]M<')I;65N=&\@;>%X:6UO`$UA:6\`36%Y
M;W1T90!-961I8VEN80!-96UB<F]S`$UO9&\@9&\@;65N=3H`56YI<B!CZ6QU
M;&%S`$EN=&5G<F%N9&\@=&]D;W,@;W,@9FEC:&5I<F]S("5S+G!O(&-O;2!O
M(&-O;7#J;F1I;RXN+@!);G1E9W)A;F1O(&$@;&]C86QI>F'GXV\@)7,N+BX@
M`$EN=&5G<F%N9&\@;R!A<G%U:79O(%!/(&1E("5S(&-O;2!O(&-O;7#J;F1I
M;RXN+B``26YT96=R86YD;R!A('1R861UY^-O(&1O(&WS9'5L;R`E<RXN+@!-
M96YS86=E;0!-96YS86=E;B!697)I9FEC861A(&-O;2!3=6-E<W-O+"!M87,@
M;R!C97)T:69I8V%D;R!D;R!S=6)S8W)I=&]R(&[C;R!P]&1E('-E<B!V97)I
M9FEC861O+@!-96YS86=E;2!E>'!I<F]U+@!4:7!O(&1E(&UE;G-A9V5M`$UE
M=&5O<F]L;V=I82!-151!4@!";&]C;R!-151!4B!I;F1I<W!O;NUV96PN`$)L
M;V-O($U%5$%2(&EN9&ES<&]N[79E;"X@3W,@<&]R;65N;W)E<R!F;W)A;2!R
M96=I<W1A9&]S('!A<F$@;R!A9&UI;FES=')A9&]R+@!!($UE=&%R1$(@;N-O
M(&5S=.$@8V]N96-T861A+@!-Z71O9&\`3R!MZ71O9&\@(B5S(B!NXV\@97-T
MX2!D969I;FED;P!-Z71R:6-O`$WI>&EC;P!-:6-R;V[I<VEA+"!%<W1A9&]S
M($9E9&5R861O<R!D80!#96YT<F\`5&EP;R!-24U%`%1E;7!E<F%T=7)A(&WM
M;FEM82!N87,@^FQT:6UA<R`R-"!H;W)A<P!496UP97)A='5R82!M[6YI;6$@
M;F%S(/IL=&EM87,@-B!H;W)A<P!%<W!E;&AO`$UI<V-E;.)N96$`4&%C;W1E
M($A45%!?4F5Q=65S="!D;R!014%2(&5M(&9A;'1A+@!#;VYF:6=U<F'GXV\@
M96T@9F%L=&$N(%1E<N$@9&4@82!G97)A<B!A9V]R82!S92!Q=6ES97(@=7-A
M<B!E<W1A(&%P;&EC8>?C;RX`240@9&$@;65N<V%G96T@96T@9F%L=&$N`%!A
M8V]T92!-86EL(&1O(%!%05(@96T@9F%L=&$N`$E$(&1A('-E<W/C;R!E;2!F
M86QT82X`,JH`0V]R<F5I;R!-\W9E;`!-;V1E<F%D;P!$871A(&1E($UO9&EF
M:6-AY^-O`$UO9&EF:6-A<B!54DP`3?-D=6QO`$WS9'5L;P!297#Z8FQI8V$@
M9&$@36]L9&]V80!0<FEN8VEP861O(&1O($WS;F%C;P!-;VYG\VQI80!-ZG,@
M92!A;F\`365N<V%L;65N=&4`36]N='-E<G)A=`!&87-E(&1A($QU80!296EN
M;R!D92!-87)R;V-O<P!3;V)R971U9&\@3&EM<&\`4V]B<F5T=61O($5N979O
M861O`%-O8G)E='5D;R!3;VQA<F5N9V\`1&5S8V5R`$UO=F5R('!A<F$@82!%
M<W%U97)D80!-;W9E<B!P87)A(&$@1&ER96ET80!3=6)I<@!$97-C97(`4W5B
M:7(`4F5P^F)L:6-A(&1E($UOYV%M8FEQ=64`3&ES=&%S(&1E(&1E<V5N<F]L
M87(@;75L=&DM;NUV96P`4V5L96/GXV\@;?IL=&EP;&$`02!-:6YH82!#;VYT
M80!/($UE=2!0;W)T86P`1&ES<&]S:>?C;R!D;R!0;W)T86P`56YIXV\@9&4@
M37EA;FUA<@!.XV\L(&[C;R!C;VYC;W)D;P!.;VUE`%)E</IB;&EC82!D82!.
M86WM8FEA`$YA=7)U`$YE<&%L`%)E:6YO(&1O<R!08>US97,@0F%I>&]S`$%N
M=&EL:&%S($AO;&%N9&5S87,`55),(&1E($)A<V4@3F5T<V-A<&4`55),(&1E
M(%)E=F]G8>?C;R!#02!.971S8V%P90!54DP@8V]M(&$@<&]L[71I8V$@9&4@
M0T$@3F5T<V-A<&4`55),(&1E(%)E;F]V8>?C;R!.971S8V%P90!54DP@9&4@
M4F5V;V=AY^-O($YE='-C87!E`$YO;64@9&\@<V5R=FED;W(@4U-,($YE='-C
M87!E`$-O;65N=.%R:6\@9&4@8V5R=&EF:6-A9&\@3F5T<V-A<&4`5&EP;R!D
M92!C97)T:69I8V%D;R!.971S8V%P90!2961E`$YU;F-A`$YO=F$@0V%L963S
M;FEA`$YO=F$@0V%T96=O<FEA`$QU82!.;W9A`$YO=F\@3F]M92!D92!5=&EL
M:7IA9&]R("AO<&-I;VYA;"D`3F]V82!:96SB;F1I80!.;W9A(&IA;F5L82`H
M7V)L86YK*0!.;W3M8VEA<P!'<G5P;W,@9&4@3F]T[6-I87,`4'+S>&EM80!0
M<O-X:6UA<R`T($9A<V5S`%!R\WAI;6%S(&]PY_5E<P!0<O-X:6UA/@!297#Z
M8FQI8V$@9&$@3FEC87+A9W5A`%)E</IB;&EC82!D;R!.[6=E<@!297#Z8FQI
M8V$@1F5D97)A;"!D82!.:6=E<FEA`$YO:71E`$YI=64`3N-O`$[C;R!HX2!D
M861O<R!D92!C;VYF:6=U<F'GXV\@9&ES<&]N[79E:7,@96T@<F5L8>?C;R!A
M;W,@<75A:7,@;6]S=')A<B!D:69E<F5NYV%S+@!.XV\@:.$@;F5N:'5M82!E
M<W1R873I9VEA(&1I<W!O;NUV96P@<&%R82!R96%L:7IA<B!I;6%G96YS($E3
M3RX`3N-O(&CA(&UO9&5L;R!D92!L;W1E(")B871C:"(N`$[C;R!E>&ES=&4@
M8FQO8V\@;F$@<&]S:>?C;R!I;F1I8V%D80!.XV\@9F]I(&9O<FYE8VED;R!U
M;2!N;VUE(&1E(&-A;&5N9.%R:6\@<&%R82!A(&%U=&5N=&EC8>?C;R!-0T%,
M+@!396T@;6]D:69I8V'G]65S+@!.XV\@<V4@<&]D92!A9&EC:6]N87(@<&5R
M;6ES<_5E<R!D92!F:6QH;W,@86)A:7AO(&1E<W1E(&[M=F5L+@!.XV\@<V4@
M<&]D92!A9&EC:6]N87(@9FEL:&]S(&$@97-T82!P97)M:7-SXV\N`$YE;FAU
M;2!C;VUA;F1O(&5S<&5C:69I8V%D;RX`3N-O(&9O:2!E<W!E8VEF:6-A9&$@
M82!I;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!P87)A("5S+@!.XV\@9F]I
M(&5S<&5C:69I8V%D82!A(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O('!A
M<F$@5D93(&)A<V5A9&\@96T@1E10+@!.XV\@9F]I(&5S<&5C:69I8V%D82!A
M(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&YE8V5S<^%R:6$@<&%R82!O
M(%9&4R!B87-E861O(&5M(%-13"X`3N-O(&9O:2!E<W!E8VEF:6-A9&$@82!I
M;F9O<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!N96-E<W/A<FEA('!A<F$@;R!6
M1E,@8F%S96%D;R!E;2!344PM1FEL92X`0W+I9&ET;R!E<V=O=&]U+@!.96YH
M=6T@9&5S=&EN873A<FEO(&9O:2!F;W)N96-I9&\N`$[C;R!E>&ES=&4@<75A
M;'%U97(@96YT<F%D82!C;VT@;R!I9"`B)7,B(&YO(&%R<75I=F\@9&4@86IU
M9&$@;W)I9VEN86PN`$[C;R!S92!C87)R96=O=2!N861A+@!.96YH=6UA(&QO
M8V%L:7IAY^-O(&5S<&5C:69I8V%D82X`1F%L=&$@:6YD:6-A<B!U;6$@;&]C
M86QI>F'GXV\N`$$@;&]C86QI>F'GXV\@;N-O(&9O:2!E<W!E8VEF:6-A9&$N
M`$YE;FAU;6$@;65N<V%G96T@9F]I(&9O<FYE8VED82X`3F5N:'5M(&YO;64@
M97-P96-I9FEC861O+@!.96YH=6T@;OIM97)O(&5S<&5C:69I8V%D;RX`4V5M
M(&1I=&]S(&]F96YS:79O<P!.XV\@9F]I(&9O<FYE8VED82!P86QA=G)A+7!A
M<W-E('!A<F$@82!A=71E;G1I8V'GXV\@2%144"X`3N-O(&9O:2!F;W)N96-I
M9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-AY^-O($E-05`N`$[C
M;R!F;VD@9F]R;F5C:61A('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC
M8>?C;R!+97)B97)O<RX`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S
M92!P87)A(&$@875T96YT:6-AY^-O($Q$05`N`$[C;R!F;VD@9F]R;F5C:61A
M('!A;&%V<F$M<&%S<V4@<&%R82!A(&%U=&5N=&EC8>?C;R!,;V=I;BX`3N-O
M(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P87)A(&$@875T96YT:6-A
MY^-O(%!!4U-71"X`3N-O(&9O:2!F;W)N96-I9&$@<&%L879R82UP87-S92!P
M87)A(&$@875T96YT:6-AY^-O(%--0BX`3N-O(&9O:2!I;F1I8V%D;R!C86UI
M;FAO('!A<F$@;R!B:6[A<FEO($]P96Y34TPN($\@8FENX7)I;R!/<&5N4U-,
M(.D@;F5C97-SX7)I;R!P87)A('1R86)A;&AA<B!C;VT@9&%D;W,@4$M#4R`Q
M,BX`3N-O(&CA('-U8G-C<FGG]65S('!E;F1E;G1E<RX`4V5M('1R8>=O<P!3
M96T@;&%D;W,`3N-O(&CA('!A<W1A('1E;7!O<N%R:6$@9&ES<&]N[79E;"!P
M87)A(")C86-H92(N`$[C;R!F;W)A;2!E;G9I861O<R!O(&YO;64@9&\@=71I
M;&EZ861O<B!O=2!A('!A;&%V<F$M<&%S<V4N`$[C;R!F;W)A;2!R971O<FYA
M9&]S(&1A9&]S(&5M(%A-3"!VX6QI9&]S`%-E;2!V86QO<F5S`$[C;R!F;VD@
M96YC;VYT<F%D82!V97)SXV\@;F$@8V]N9FEG=7)AY^-O(&]R:6=I;F%L+B!2
M96=E;F5R87(@8V]N9FEG=7)AY^-O+@!.XV\@9F]I(&5N8V]N=')A9&$@=F5R
M<^-O(&YA('-U82!C;VYF:6=U<F'GXV\N(%)E9V5N97)A<B!C;VYF:6=U<F'G
MXV\N`$YE;FAU;6$`3F5N:'5M("AU<V%R(&EM<&SM8VET;RD`3O-R9&EC;R`H
M25-/+3@X-3DM,3`I`$EL:&$@9&4@3F]R9F]L:P!(96UI<V;I<FEO($YO<G1E
M`$EL:&%S($UA<FEA;F%S(&1O($YO<G1E`%)E:6YO(&1A($YO<G5E9V$`3G5N
M8V$@1&5P;VES(&1E`$YU;F-A($%N=&5S(&1E`$[C;R#I('5M(&1I<F5C=/-R
M:6\`3N-O(&EM<&QE;65N=&%D82X`4&]R(&%T<FEB=6ER`$[C;R!S=7!O<G1A
M9&\N`$YO=&%S`$YA9&$@<&%R82!N879E9V%R+"!V;VQT92!P87)A('1RX7,N
M`$YO=&$`3F]V96UB<F\`3OIM97)O`$[Z;65R;R!D92!C87)A8W1E<F5S`$[Z
M;65R;R!D92!C;VQU;F%S`$[Z;65R;R!D92!L:6YH87,`3F$@;&ES=&$@9&4@
M9&ES=')I8G5IY^-O(&CA(&[Z;65R;W,@<75E(&[C;R!F;W)A;2!E<W!E8VEF
M:6-A9&]S('!A<F$@86-T=6%L:7IAY^-O+@!/2P!/8FIE8W1O`$-R:6%D;W(@
M9&\@3V)J96-T;P!097)M:7-S]65S(&1O(&-R:6%D;W(@9&\@;V)J96-T;P!/
M8W1A;`!/=71U8G)O`$9I;'1R;R!D92!M871E<FEA;"!O9F5N<VEV;P!'86)I
M;F5T90!3=6QT86YA=&\@9&\@3VWC`%/S(&]S('-E<G9I9&]R97,@24U!4"!S
M=7!O<G1A;2!P87-T87,@<&%R=&EL:&%D87,N`$%P96YA<R!D:71O<R!O9F5N
M<VEV;W,`4_,@Z2!P97)M:71I9&\@=6T@96YD97)EYV\@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;RX`07!E;F%S(&\@9&]N;R!O=2!U;2!A9&UI;FES=')A9&]R
M(&1E('-I<W1E;6%S('!O9&4@86QT97)A<B!A('1I='5L87)I9&%D92!D92!U
M;6$@<&%R=&EL:&$@;W4@87,@<&5R;6ES<_5E<R!D;R!S974@9&]N;P!!8G)E
M(&YU;6$@;F]V82!J86YE;&$`17)R;R!/<&5N4U-,.B!.XV\@9F]I('!O<W/M
M=F5L(&5X=')A:7(@9&%D;W,@9&4@=6UA('!A<G1E(&%S<VEN861A(&-O;2!3
M+TU)344N`$%B<F4@97-T82!L:6=AY^-O(&YU;6$@;F]V82!J86YE;&$`4VES
M=&5M82!/<&5R871I=F\`3W#G]65S`$]PY_5E<R!D;R`E<P!/<.?U97,Z`$QI
M<W1A($]R9&5N861A`$]R9V%N:7IAY^-O`%5N:61A9&4@3W)G86YI>F%C:6]N
M86P`3W)G86YI>F'GXV\`36]D96QO(&]R:6=I;F%L(&1A(&%P;&EC8>?C;P!-
M;V1E;&]S(&]R:6=I;F%I<R!E;2`E<SH`3W5T<F\`3W5T<F%S($EN9F]R;6'G
M]65S`%!E<FUI<W/U97,@9&\@1&]N;P!!=71E;G1I8V'GXV\@4$%-(&[C;R!E
M<W3A(&1I<W!O;NUV96PN`$%S<VEN871U<F$@1&EG:71A;"!01U``1&%D;W,@
M96YC<FEP=&%D;W,@4$=0`$-H879E(%#Z8FQI8V$@4$=0`$1A9&]S($%S<VEN
M861O<R]%;F-R:7!T861O<R!C;VT@4$=0`$/S9&EG;R!02%``0V]M86YD;W,@
M4$A0`$-H=79I<V-O<R!P96QA(%1A<F1E`$%G=6%C96ER;W,@9&4@5&%R9&4`
M3F5V92#@(%1A<F1E`$YE=O5E<R#@(%1A<F1E`%-O;"#@(%1A<F1E`%1E;7!O
M<F%I<RU4(.`@5&%R9&4`0V]M86YD;W,@4%](4`!%;F-H:6UE;G1O`%)E</IB
M;&EC82!)<VSB;6EC82!D;R!087%U:7-TXV\`4F5P^F)L:6-A(&1E(%!A;&%U
M`%1E<G)I=/-R:6\@4&%L97-T:6YI86YO`%!A;F%MX0!087!U82!.;W9A($=U
M:6[I`%)E</IB;&EC82!D;R!087)A9W5A:0!087)C:6%L;65N=&4@16YC;V)E
M<G1O`%!A;&%V<F$M4&%S<V4`4&%L879R82U087-S92!I;F-O<G)E8W1A`%!A
M;&%V<F$M4&%S<V4@;F5C97-SX7)I82!P87)A(&%U=&5N=&EC8>?C;R!2041)
M55,`4&%L879R82U087-S92!C;VT@8V]N9FER;6'GXV\`4&%L879R82U087-S
M93H`4&%L879R82U087-S93H@`$%S('!A;&%V<F%S+7!A<W-E('3J;2!D92!S
M97(@:6=U86ES+@!#;VQA<@!#;VQA<B!D92!R96-O<G1E<P!#86UI;FAO`%-U
M8G-C<FGG]65S(%!E;F1E;G1E<SH`4&5S<V]A<P!097)C96YT86=E;0!%>&5C
M=71A<B!/<&5R8>?U97,@9&4@36%N=71E;N?C;P!%>&5C=71A<B!O<&5R8>?U
M97,@9&4@;6%N=71E;N?C;R!A<75A;F1O(&1A(&5N=')A9&$_`%!E<FUI<W/C
M;P!!('!E<FUI<W/C;R`B)7,B(&[C;R!F;VD@<F5M;W9I9&$N`$%D;6EN:7-T
M<F'GXV\@9&4@4&5R;6ES<_5E<P!097)M:7-S]65S(&1E`$EN9F]R;6'G]65S
M(%!E<W-O86ES`%!E<OH`06YI;6%I<R!D92!%<W1I;6'GXV\`1FEL:7!I;F%S
M`%1E;&5F;VYE`$9O=&]G<F%F:6%S`$EL:&%S(%!I=&-A:7)N`%#M>&5I<P!0
M;&%T:71U9&5S`%!O<B!F879O<B!C;&EQ=64@<V]B<F4@=6UA(&/I;'5L80!0
M;W(@9F%V;W(@8V]N9FER;64@<V4@<F5A;&UE;G1E('!R971E;F1E(')E;6]V
M97(@97-T92!E;&5M96YT;SH`4&]R(&9A=F]R(&-O;F9I<FUE('-E(')E86QM
M96YT92!P<F5T96YD92!D97-L:6=A<B!E<W1E(&5L96UE;G1O+@!0;W(@9F%V
M;W(@:6YT<F]D=7IA('5M(&WJ<R!E('5M(&%N;RX`4&]R(&9A=F]R(&EN=')O
M9'5Z82!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z`%!O<B!F879O<B!I;G1R
M;V1U>F$@=6T@96YD97)EYV\@25`@=N%L:61O+@!0;W(@9F%V;W(@:6YT<F]D
M=7IA('5M82!D871A(';A;&ED83L@=F5R:69I<75E(&\@;OIM97)O(&1E(&1I
M87,@9&\@;>IS+@!0;W(@9F%V;W(@:6YT<F]D=7IA('5M82!H;W)A(';A;&ED
M82X`4&]R(&9A=F]R+"!F;W)N9>=A('5M82!B<F5V92!D97-C<FGGXV\@9&\@
M<')O8FQE;6$N`%!O<B!F879O<BP@:6YT<F]D=7IA(&\@<V5U($YO;64@9&4@
M571I;&EZ861O<B!E(&$@<W5A(%!A;&%V<F$M4&%S<V4`4&]R(&9A=F]R(&QE
M:6$@;R!T97AT;R!S96=U:6YT92X@5&5M(&1E($-/3D-/4D1!4B!C;VT@;W,@
M=&5R;6]S(&1E<W1E(&%C;W)D;R!P87)A('5S87(@;R!S:7-T96UA+@!0;W(@
M9F%V;W(@<F5P;W)T92!O<R!E<G)O<R!P87)A(&DQ.&Y`;&ES=',N:&]R9&4N
M;W)G`%!O<B!F879O<B!I;G1R;V1U>F$@;R!N;VUE(&1A(&YO=F$@8V%T96=O
M<FEA.@!0;VSS;FEA`%!O;.UT:6-A`%-O;F1A9V5N<P!297#Z8FQI8V$@4&]R
M='5G=65S80!0;W-I8VEO;F%M96YT;R!D97-T82!I;6%G96T`4&]S:6-I;VYA
M;65N=&\@9&5S=&$@=&%B96QA`")0;W-T(B!P87)A(&5S=&$@<&%S=&$@*&[C
M;R#I(')E<75I<VET;R!D;R!)34%0*0!0<F5C:7!I=&'GXV\@;F%S(/IL=&EM
M87,@)7,@:&]R82AS*3H@`%!R;V)A8FEL:61A9&4@9&4\8G(@+SY0<F5C:7!I
M=&'GXV\`4')E9G-?;&1A<#H@02!E>'1E;G/C;R!,1$%0(&YE8V5S<^%R:6$@
M;N-O(&9O:2!E;F-O;G1R861A+@!0<F5F<U]S97-S:6]N.B!!(&5X=&5N<^-O
M(&1E('-E<W/C;R!N96-E<W/A<FEA(&[C;R!F;VD@96YC;VYT<F%D82X`4')E
M<W/C;P!0<F5S<^-O(&%O(&[M=F5L(&1O(&UA<CH@`%!R97-SXV\Z(`!0<F5V
M:7/C;P!0<F5V97(@82!I;6%G96T@;G5M82!N;W9A(&IA;F5L80!/<.?U97,@
M86YT97)I;W)E<P!);7!R:6UI<B!O(&1O8W5M96YT;P!#:&%V92!0<FEV861A
M`%!R;V)L96UA`$1E<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J96-T;W,`365N
M<V%G96TM<')O;G1O`$-H879E(%#Z8FQI8V$`06QG;W)I=&UO(&1E($-H879E
M(%#Z8FQI8V$`26YF;W)M8>?C;R!3;V)R92!A($-H879E`$\@<&%R(&1E(&-H
M879E<R!0=6)L:6-A+U!R:79A9&$@;N-O(&9O:2!G97)A9&$@8V]M('-U8V5S
M<V\N`%!O<G1O(%)I8V\`17-T861O(&1O(%%A=&%R`%!E9&ED;P!#:&%V92!0
M^F)L:6-A(%)302`H)60@8FET*0!396QE8^?C;R`B<N%D:6\B`$-H=79A`$-H
M=79A($UA=&EN86P`0VAU=F$@5F5S<&5R=&EN80!!9W5A8V5I<F\`0VAU=F$@
M92!.979E`$-H=79A(&$@3F5V90!$:71O($%L96%T\W)I;P!296QAY^-O`$QE
M<@!,97(@;65N<V%G96YS`%%U97(@;65S;6\@<F5M;W9E<B`E<S\@17-T82!O
M<&5R8>?C;R!NXV\@=&5M(')E9W)E<W-O+@!296UO=F5R(&UE<VUO(&]S(&1A
M9&]S(&1O('5T:6QI>F%D;W(@)7,_($5S=&$@;W!E<F'GXV\@;N-O('1E;2!R
M96=R97-S;RX`4F5F87H@82!S=6$@^FQT:6UA(&%CY^-O`%)E9G)E<V-A<B!%
M;&5M96YT;W,@9&4@365N=2!$:6[B;6EC;SH`4F5F<F5S8V%R(%9I<W5A;&EZ
M8>?C;R!D;R!0;W)T86PZ`$5X<')E<W/C;R!296=U;&%R`$YA=F5G861O<B!D
M92!296QAY_5E<P!/8G-E<G9AY_5E<P!397)V:61O<F5S(%)E;6]T;W,`55),
M(%)E;6]T;R`H:'1T<#HO+W=W=RYE>&5M<&QO+G!T+VAO<F1E*3H`4F5M;W9E
M<@!296UO=F5R($)L;V-O`%)E;6]V97(@8V]L=6YA`%)E;6]V97(@9F]R;6%T
M8>?C;P!296UO=F5R('!A<@!296UO=F5R(&\@(G-C<FEP="(@9W5A<F1A9&\@
M9&$@<&%S=&$@=&5M<&]RX7)I82!D;R!S97)V:61O<BX`4F5M;W9E<B!O`%)E
M;6]V97(@97-T92!N\R!D;R!D;V-U;65N=&\`4F5M;W9E<B!5=&EL:7IA9&]R
M`%)E;6]V97(@=71I;&EZ861O<CH@)7,`3N-O(&9O:2!P;W-S[79E;"!R97-P
M;VYD97(@86\@<&5D:61O+B!#\V1I9V\@9&4@97)R;R!D979O;'9I9&\Z(`!/
M('-E<G9IYV\@<&5D:61O(&[C;R!F;VD@96YC;VYT<F%D82X`(B5S(B!O8G)I
M9V%T\W)I;R!NXV\@9F]I(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\@
M9&4@)7,N`"(E<R(@;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@
M;F$@8V]N9FEG=7)AY^-O(%9&4RX`(B5S(B!O8G)I9V%T\W)I;R!NXV\@9F]I
M(&5S<&5C:69I8V%D;R!N82!C;VYF:6=U<F'GXV\N`$-A;7!O($]B<FEG873S
M<FEO`$QI;7!A<@!296EN:6-I87(@4&%L879R82U087-S90!296EN:6-I92!A
M(%-U82!086QA=G)A+5!A<W-E`%)E<W5L=&%D;W,`4F5S=6QT861O<R`H:6YC
M;'5I;F1O($AO<F1E*3H`4F5S=6QT861O<SH`5F]L=&%R(.!S($]PY_5E<P!2
M975N:>-O`%)%=F5R=&5R($-O;F9I9W5R8>?C;P!/<.?U97,@9&4@161IY^-O
M(%)I8V$`061I=FEN:&%S`$1I<F5I=&$`0V%B9>=A;&AO(&1A(&1I<F5I=&$`
M5F%L;W)E<R#@(&1I<F5I=&$`4')O<')I961A9&5S(&1A($QI;E]H82XN+@!2
M96=R80!2;VWI;FEA`%)O9&%R(#$X,`!2;V1A<B#@($5S<75E<F1A`%)O9&%R
M(.`@9&ER96ET80!0<F]P<FEE9&%D97,@9&$@3&EN:&$`4')O<')I961A9&5S
M(&1A(&QI;FAA`$QI;FAA<SH`5')AYV]S`%1R8>=O<R!A<&%R96-E<N-O(&5N
M=')E('1O9&%S(&%S(&QI;FAA<R!E(&-O;'5N87,`5')AYV]S(&%P87)E8V5R
MXV\@87!E;F%S(&5N=')E(&%S(&-O;'5N87,`5')AYV]S(&%P87)E8V5RXV\@
M87!E;F%S(&5N=')E(&QI;FAA<P!%>&5C=71A<@!&961E<F'GXV\@4G5S<V$`
M4F5P^F)L:6-A(&1O(%)U86YD80!!<W-I;F%T=7)A($-R:7!T;V=RX69I8V$@
M4R]-24U%`$UE;G-A9V5M($5N8W)I<'1A9&$@8V]M(%,O34E-10!!=71E;G1I
M8V'GXV\@4T%33"!I;F1I<W!O;NUV96PN`$UE;G-A9V5N<R!335,`0V]M86YD
M;W,@4U%,`%-32`!354-%4U-/`$-O;6%N9&]S(%-?44P`<^$`4V%N=&$@2&5L
M96YA`%/C;R!+:71T<R!E($YE=FES`%-A;G1A($SZ8VEA`%/C;R!0961R;R!E
M($UI<75E;&]N`%/C;R!6:6-E;G1E(&4@1W)E;F%D:6YE<P!-97-M82!M;VQD
M=7)A("A?<V5L9BD`17-T861O($EN9&5P96YD96YT92!D82!386UO80!297#Z
M8FQI8V$@4V5R96[M<W-I;6$@9&4@4^-O($UA<FEN;P!3XV\@5&]MZ2!E(%!R
M[6YC:7!E`$9O<FYE8V5D;W(@9&\@4V%TZ6QI=&4`07+A8FEA(%-A=61I=&$`
M1W5A<F1A<@!'=6%R9&%R("5S`$=U87)D87(@)R5S)P!'=6%R9&%R($]PY_5E
M<P!'=6%R9&%R(&-O;F9I9W5R8>?C;R!G97)A9&$@8V]M;R!U;2`B<V-R:7!T
M(B!02%`@;F\@9&ER96-T\W)I;R!T96UP;W+A<FEO(&1O('-E=2!S97)V:61O
M<BX`1W5A<F1E:2!C;VYF:6=U<F'GXV\@)7,N`$=U87)D96D@;R`B<V-R:7!T
M(B!D92!A8W1U86QI>F'GXV\@96TZ("(E<R(N`%1E;7!O<F%I<RU4($1I<W!E
M<G-O<P!#:>IN8VEA`%!R;V-U<F%R`$UO=&]R97,@9&4@4')O8W5R80!0<F]C
M=7)A;F1O(&%P;&EC8>?U97,@*&WS9'5L;W,I($AO<F1E(&5M("5S`%!R;V-U
M<F%N9&\@;W,@8FENX7)I;W,@9&4@9V5T=&5X="XN+@!396QE8V-I;VYA<B!!
M<G%U:79O<P!396QE8V-I;VYE('5M82!D871A`%-E;&5C8VEO;F4@=6T@9W)U
M<&\@82!A8W)E<V-E;G1A<@!396QE8V-I;VYA<B!U;2!N;W9O(&1O;F\`4V5L
M96-C:6]N92!U;2!S97)V:61O<@!396QE8V-I;VYE('5M('5T:6QI>F%D;W(@
M82!A9&EC:6]N87(`4V5L96-C:6]N92!T;V1O<R!O<R!C;VUP;VYE;G1E<R!D
M82!D871A+@!396QE8V-I;VYE('5M(&]B:F5C=&\`4V5L96-C:6]N92!O<R!C
M87)A8W1E<F5S(&YA<R!C86EX87,@86)A:7AO+B!0;V1E<N$@96YTXV\@8V]P
M:>$M;&]S(&4@8V]LX2UL;W,@;F$@X7)E82!D92!T97AT;RX`4V5L96-C:6]N
M92!O(&1E;&EM:71A9&]R(&1A(&1A=&$Z`%-E;&5C8VEO;F4@;R!F;W)M871O
M(&1A(&1A=&$Z`%-E;&5C8VEO;F4@82!I9&5N=&ED861E('%U92!P<F5T96YD
M92!A;'1E<F%R.@!396QE8V-I;VYE(&\@9&5L:6UI=&%D;W(@9&%S(&AO<F%S
M.@!396QE8V-I;VYE(&\@9F]R;6%T;R!D82!H;W)A.@!396QE8V-I;VYE(&1O
M:7,@8V%M<&]S(')E;&%C:6]N861O<RX`17-C;VQH82!O('-E=2!C;VYJ=6YT
M;R!D92!C;W)E<RX`4V5L96-C:6]N92!O('-E=2!I9&EO;6$@<')E9F5R:61O
M.@!%;G9I87(@4F5L873S<FEO(&1E(%!R;V)L96UA<P!%;G9I87(@4TU3`%)E
M</IB;&EC82!D;R!396YE9V%L`"!396YS;W(Z(`!3971E;6)R;P!3Z7)V:6$@
M92!-;VYT96YE9W)O`$[Z;65R;R!D92!3Z7)I90!$861O<R!D;R!S97)V:61O
M<B!E<G)A9&]S(&]U(&EN9&ES<&]N[79E:7,N`$E$(&1E('-E<W/C;R!E>'!I
M<F]U+@!!=')I8G5I<@!%<W1A8F5L9>=A(&]PY_5E<R!Q=64@;&AE('!E<FUI
M=&%M(')E:6YI8VEA<B!A('-U82!P86QA=G)A+7!A<W-E('-E(&%L9W5M82!V
M97H@9&5L82!S92!E<W%U96-E<BX`17-P96-I9FEC87(@<V5R=FED;W)E<R!R
M96UO=&]S('%U92!D97-E:F$@86-E9&5R(&YO('-E=2!P;W)T86PN`%-E;&5C
M8VEO;F4@;R!S974@:61I;VUA('!R969E<FED;RP@;R!S974@9G5S;R!H;W+A
M<FEO(&4@87,@<W5A<R!O<.?U97,@9&4@9&%T87,N`$5S8V]L:&$@82!S=6$@
M87!L:6-AY^-O(&EN:6-I86PL(&\@97-Q=65M82!D92!C;W)E<RP@;R!R969R
M97-C86UE;G1O(&1E('#A9VEN87,@92!O=71R87,@;W#G]65S(&1E('9I<W5A
M;&EZ8>?C;RX`0V]N9FEG=7)A<@`B4V-R:7!T<R(@9&4@86-T=6%L:7IAY^-O
M(&1I<W!O;NUV96ES`%;A<FEA<R!L;V-A;&EZ8>?U97,@<&]S<^UV96ES(&-O
M;2!O('!A<N)M971R;SH@`%-E:6-H96QE<P!#;VUP<F%S`$)R979E(%-U;>%R
M:6\`1&5V96TM<V4@9&5F:6YI<B!T96-L87,@9&4@86-E<W-O('!A<F$@82!M
M86EO<FEA(&1A<R!L:6=AY_5E<S\`36]S=')A<@!-;W-T<F%R(&1I9F5R96[G
M87,@96YT<F4@82!C;VYF:6=U<F'GXV\@9W5A<F1A9&$@92!A<75E(&9O:2!A
M9V]R82!G97)A9&$N`$UO<W1R87(@;6]M96YT;R!D82#Z;'1I;6$@96YT<F%D
M82!N;R!S:7-T96UA/P!-;W-T<F%R(&]PY^-O('!A<F$@<')E<V5R=F%R(&\@
M;W)I9VEN86P`36]S=')A<B!P86QE=&4`36]S=')A<B!A(&)A<G)A(&1E(&UE
M;G4@8V]M(&%S(&]P97)AY_5E<R!S;V)R92!T86)E;&%S/P!-;W-T<F%R(&\@
M365N=2`E<R#@(&5S<75E<F1A/P!-;W-T<F%R(&$@8V%I>&$@9&4@9&GA;&]G
M;R!D87,@4')O<')I961A9&5S(&1E($/I;'5L87,@9&4@5&%B96QA/P!-;W-T
M<F%R(&$@8V%I>&$@9&4@9&GA;&]G;R!D87,@4')O<')I961A9&5S(&1E(%1A
M8F5L87,`36]S=')A<B!A(&-A:7AA(&1E(&1IX6QO9V\@9&%S(%!R;W!R:65D
M861E<R!D92!,:6YH87,@9&4@5&%B96QA`$UO<W1R87(@82!C86EX82!D92!D
M:>%L;V=O(&1A<R!0<F]P<FEE9&%D97,@9&4@26UA9V5M`$UO<W1R87(@8V%R
M<F5G86UE;G1O`$%G=6%C96ER;W,`06=U86-E:7)O<R!-871I;F%I<P!!9W5A
M8V5I<F]S(%9E<W!E<G1I;F]S`$%G=6%C96ER;W,@;F$@5FEZ:6YH86[G80!%
M;F-O;&AE<@!%;F-O;&AA(&]U(&UO=F$@;RAS*2!B;&]C;RAS*2!V:7II;FAO
M*',I('!R:6UE:7)O`%-E<G)A($QEXV\`4W5B<V-R979E<@!3=6)S8W)E=F$L
M('-E(&%I;F1A(&[C;R!E<W3A(')E9VES=&%D;P!!<W-I;F%T=7)A`$%L9V]R
M:71M;R!D92!!<W-I;F%T=7)A`%)E</IB;&EC82!D92!3:6YG87!U<F$`5&%M
M86YH;P!386QT87(@36%N=71E;N?C;P!.XV\@<')O8V5S<V%D;RXN+@!%<VQO
M=N%Q=6EA`%)E</IB;&EC82!D82!%<VQO=NEN:6$`3F5V90!.97;C;P!.97;U
M97,`3F5V]65S($UA=&EN86ES`$YE=O5E<R!697-P97)T:6YO<P!!;'1U<F$@
M9&4@;F5V93H@`$UO<W1R87(@97%U:79A;&5N=&4@;F$@X6=U83H@`$EL:&%S
M(%-A;&]MXV\`4V]MX6QI80!#86[G]65S(&4@4&]E;6%S`%-E;&5CY^-O(&1O
M('-E;G1I9&\@9&$@;W)D96YAY^-O`$5N9&5R9>=O(&1E(&]R:6=E;0#!9G)I
M8V$@9&\@4W5L`$5U<F]P82!D;R!3=6P@*$E33RTX.#4Y+3,I`$=E\W)G:6$@
M9&\@4W5L(&4@26QH87,@4V%N9'=I8V@@9&\@4W5L`$AE;6ES9NER:6\@4W5L
M`$5S<&'G;R!E;G1R92!CZ6QU;&%S(&%D:F%C96YT97,`17-P8>=O(&5N=')E
M(&\@8V]N=&7Z9&\@92!A(&)O<F1A(&1E('5M82!CZ6QU;&$`17-P8>=A9&]R
M`$5S<&'G86UE;G1O`$5S<&'G86UE;G1O(&4@96YC:&EM96YT;P!296EN;R!D
M92!%<W!A;FAA`$-O<G)E:6\@;N-O('-O;&EC:71A9&\`26YS97)I<B!#87)A
M8W1E<B!%<W!E8VEA;`!$:79I9&ER(&/I;'5L80!!9&EC:6]N87(@8V]L=6YA
M`$1I=FED:7(@;&EN:&$`1&5S<&]R=&]S`%)E</IB;&EC82!$96UO8W+A=&EC
M82!3;V-I86QI<W1A(&1O(%-R:2!,86YK80!0861RXV\`4W1A<B!4<F5K`$%N
M;R!D92!I;NUC:6\`17-T861O(&]U(%!R;W;M;F-I80!3=&%T=7,`17-T861O
M(&1A(&QO8V%L:7IAY^-O("5S+BXN(`!&;W)M871O(&1E(&%R;6%Z96YA;65N
M=&\`16YD97)EYV\@9&4@4G5A`%)A<W5R861O`$QI<W1A(&1E(&-A9&5I87,@
M9&4@8V%R86-T97)E<P!2971I<F%R(&1O;>UN:6\@9&\@96YD97)EYV\`17-T
M:6QO(%M#4U-=`&1O`$%S<W5N=&\`4W5B;65T97(`1F]I('-U8FUE=&ED;R!P
M961I9&\@<&%R82!A9&EC:6]N87(@(B5S(B!A;R!S:7-T96UA+B!.XV\@<&]D
M97+A(&5N=')A<B!E;G%U86YT;R!O('-E=2!P961I9&\@;N-O(&9O<B!A<')O
M=F%D;RX`26YF97)I;W(@X"!L:6YH80!3=6-E<W-O`"(E<R(@861I8VEO;F%D
M;R!C;VT@<W5C97-S;R!A;R!S:7-T96UA+@!,:6UP97IA(&1O('-I<W1E;6$@
M9&]S(&1A9&]S(&1O('5T:6QI>F%D;W(@(B5S(B!R96%L:7IA9&$@8V]M('-U
M8V5S<V\N`%)E;6_GXV\@9&4@(B5S(B!C;VT@<W5C97-S;RX`4F5M;^?C;R!D
M92`B)7,B(&1O('-I<W1E;6$@8V]M('-U8V5S<V\N`$-O;F9I9W5R8>?C;R!R
M979E<G1I9&$@8V]M('-U8V5S<V\N(%)E8V%R<F5G=64@<&%R82!V97(@87,@
M;75D86[G87,N`$-O;F9I9W5R8>?C;R!D92!S86QV86=U87)D82!G=6%R9&%D
M82!C;VT@<W5C97-S;RX`1FEC:&5I<F\@9&4@8V]N9FEG=7)AY^-O(&1E('-A
M;'9A9W5A<F1A("5S(&=U87)D861O(&-O;2!S=6-E<W-O+@`B)7,B(&%C='5A
M;&EZ861O(&-O;2!S=6-E<W-O`"5S(&5S8W)I=&\@8V]M('-U8V5S<V\`4F5P
M^F)L:6-A(&1O(%-U9.-O`%)E<W5M;P!.87-C97(@9&\@4V]L`%#T<B!D;R!3
M;VP`4V]L87)E;F=O`$YA<V-E<B!D;R!3;VP`3F%S8V5R+U#T<B!D;R!3;VP`
M3F%S8V5R(&1O(%-O;#H@`%#T<B!D;R!3;VP`4/1R(&1O(%-O;#H@`%-U<&5R
M:6]R(.`@;&EN:&$`4W5P;W)T90!3=7)I;F%M90!!<&5L:61O`%-V86QB87)D
M(&4@2F%N($UA>65N`%)E:6YO(&1A(%-U87II;.)N9&EA`%)E:6YO(&1A(%-U
MZ6-I80!3=>WG80!%<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO<R!D92!P<F]C
M=7)A`%)E</IB;&EC82#!<F%B92!3[7)I80!496UP;W)A;"U4`%1E;7!O<F%L
M+50@92!696YT;W-O`%1E;7!O<F%I<RU4`%1E;7!O<F%I<RU4($UA=&EN86ES
M`$%R<75I=F\@5%-6`%1A8F5L80!0<F]P<FEE9&%D97,@9&$@5&%B96QA`%!R
M;W!R:65D861E<R!D82!T86)E;&$`1F]R;6]S80!&;W)M;W-A`%)E</IB;&EC
M82!D;R!4861J:7%U:7-TXV\`5&%N>N)N:6$`06QV;SH`5&%R969A<P!.^FUE
M<F\@9&4@5&5L969O;F4`5&5M<&5R871U<F$@9&$@^FQT:6UA(&AO<F$Z`%1E
M;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7-!
M;'1A)7,O)7-"86EX825S*2`F9&5G.R5S`$\@;6]D96QO("(E<R(@;N-O(&9O
M:2!E;F-O;G1R861O+@!!9&UI;FES=')AY^-O(&1E($UO9&5L;W,`5&5X=&\`
M07!E;F%S(%1E>'1O`$%L:6YH86UE;G1O(&1O('1E>'1O`%1O<&\@9&\@=&5X
M=&\`-:H`5&%I;&%N9.IS("A425,M-C(P*0!296EN;R!D82!486ELXFYD:6$`
M3V)R:6=A9&\@<&]R('5S87(@97-T92!S:7-T96UA+@!/(&%R<75I=F\@9&4@
M86IU9&$@)7,@<&%R82`E<R!NXV\@97AI<W1E(&%I;F1A+B!#<FEA;F1O('5M
M(&YO=F\N`$$@97AT96YSXV\@1E10(&[C;R!E<W3A(&1I<W!O;NUV96PN`$\@
M96YG96YH;R!D92!I;G1E9W)AY^-O($AO<F1E+TMO;&%B(&[C;R!S=7!O<G1A
M("(E<R(`3R!R96=I<W1O("@B;&]G(BD@24U34"!NXV\@</1D92!S97(@:6YI
M8VEA;&EZ861O+@!!(&-L87-S92!-86EN=&5N86YC93HZ(&[C;R!F;VD@8V%R
M<F5G861A(&-O;2!S=6-E<W-O`$$@:F%N96QA(&1E($]PY_5E<R!F96-H;W4N
M(%-A[6YD;RX`3R!A9&UI;FES=')A9&]R('1E;2!D92!C;VYF:6=U<F%R('5M
M(&UE8V%N:7-M;R!D92!P97)M:7-S]65S('!E<FUA;F5N=&4@<V4@<75I<V5R
M('5S87(@4&5R;6ES<_5E<RX`07!E;F%S(&\@;&%D;R!I;F9E<FEO<@!/(&[Z
M;65R;R!D92!)1"!D;R!C;VYT86-T;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@
M9F]I(&1E:7AA9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N
M82!B87-E(&1E(&1A9&]S+@!/(&-O;G1A8W1O(&9O:2!A9&EC:6]N861O(.`@
M;&ES=&$@9&4@8V]N=&%C=&]S(&-O;2!S=6-E<W-O+@!/(&)L;V-O(&1E(&%S
M<VEN871U<F$@4$=0(&1E<W1A8V%D;R#I(&YE8V5S<^%R:6\@<&%R82!V97)I
M9FEC87(@=6UA(&UE;G-A9V5M(&%S<VEN861A+@!/($E$(&1A(&QI<W1A(&1E
M(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D;RP@9F]I(&1E:7AA
M9&\@96T@8G)A;F-O(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N82!B87-E(&1E
M(&1A9&]S+@!!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C
M:69I8V%D82X`07,@9G5N8VEO;F%L:61A9&5S(&1E(&5N8W)I<'1AY^-O(&5X
M:6=E;2!U;6$@;&EG8>?C;R!S96=U<F$N`$\@87)Q=6EV;R`E<R!D979E<FEA
M(&-O;G1E<B!U;2!A=')I8G5T;R`E<RX`3R!A<G%U:79O("5S(&1E=F5R:6$@
M8V]N=&5R(&%L9W5N<R!A=')I8G5T;W,@)7,N`$\@9FEC:&5I<F\@;N-O('!O
M9&4@<V5R(&-O<&EA9&\@<&%R82!S:2!P<O-P<FEO+@!/(&9I8VAE:7)O(&[C
M;R!C;VYTZ6T@9&%D;W,N`$%B86EX;R!E<W3C;R!O<R!C86)EYV%L:&]S(&1E
M<W1A(&UE;G-A9V5M+VUE;G-A9V5M(')F8S@R,BX`3R!M;V1O(&1E(&5C<N,@
M:6YT96ER;R!C875S82!P<F]B;&5M87,@;F\@26YT97)N970@17AP;&]R97(L
M(&1E=FED;R!A(&5R<F]S(&YO(&YA=F5G861O<B!Q=64@;N-O(&-O;G-E9W5I
M;6]S('5L=')A<&%S<V%R+B`@4&]D92!S=7)G:7(@;&EX;RP@<&]D96T@9&5S
M87!A<F5C97(@9G5N8VEO;F%L:61A9&5S(&1O(&5D:71O<B!E+V]U(&\@<V5U
M(&YA=F5G861O<B!P;V1E(&%B;W)T87(N(%-E(&\@<V5U('-I<W1E;6$@Z2!U
M;2!7:6YD;W=S(#EX+"#I(&UU:71O('!R;W;A=F5L('%U92!O8G1E;FAA('5M
M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&4@<')E8VES92!D92!R96EN
M:6-I87(@;R!S:7-T96UA+EQN7&Y&;VD@879I<V%D;RX@(%!O<B!F879O<B!P
M<F5S<VEO;F4@3TL@<V4@86EN9&$@87-S:6T@<75I<V5R(&5X<&5R:6UE;G1A
M<B!O(&5D:71O<B!D92!E8W+C(&EN=&5I<F\N`$\@9FEC:&5I<F\@9&4@86IU
M9&$@)7,@;N-O(&-O;67G82!C;VT@/#]X;6P`02!I9&5N=&ED861E("(E<R(@
M9F]I(')E;6]V:61A+@!!<&5N87,@;R!L861O(&5S<75E<F1O`$$@;&]C86QI
M>F'GXV\@9&\@87)Q=6EV;R!E>&5C=73A=F5L(&1E($=N=5!'('1E;2!D92!S
M97(@:6YD:6-A9&$@X"!C;&%S<V4@0W)Y<'1?<&=P.CHN`$$@;65N<V%G96T@
M96YV:6%D82!E;2`E<R!P87)A("5S(&-O;2!A<W-U;G1O("(E<R(@9F]I(&UO
M<W1R861A+@I.XV\@:.$@9V%R86YT:6$@9&4@<75E(&$@;65N<V%G96T@=&5N
M:&$@<VED;R!R96%L;65N=&4@;&ED82!O=2!C;VUP<F5E;F1I9&$N`$\@;F]M
M92!A('5S87(@<75A;F1O(&QI9V%N9&\@X"!PX6=I;F$@9&4@8V]M<&]S:>?C
M;P!/(&WS9'5L;R!O<&5N<W-L(.D@;F5C97-SX7)I;R!P87)A(&$@8VQA<W-E
M($AO<F1E7T-R>7!T7W-M:6UE.CHN`$$@;W#GXV\@(B5S(B!NXV\@</1D92!S
M97(@9W5A<F1A9&$L('!O:7,@;W,@<V5U<R!D861O<R!E>&-E9&5M(&$@9&EM
M96YSXV\@;>%X:6UA('!E<FUI=&ED80!/('!R;V=R86UA('5S861O('!A<F$@
M=F5R(&5S=&4@=&EP;R!D92!D861O<R`H)7,I(&[C;R!F;VD@96YC;VYT<F%D
M;R!N;R!S:7-T96UA+@!!<&5N87,@;W,@;&%D;W,@97-Q=65R9&\@92!D:7)E
M:71O`$%P96YA<R!O(&QA9&\@9&ER96ET;P!/('-E<G9I9&]R("(E<R(@9F]I
M(')E;6]V:61O+@!/('-E<G9I9&]R("(E<R(@9F]I(&=U87)D861O+@!/('!E
M9&ED;R!D92!S=6)S8W)IY^-O(&1E("5S(&9O:2!R96UO=FED;RX`02!L:6YH
M82!I;F1I8V%D82!NXV\@97AI<W1E+@!/(&%R<75I=F\@=&5M<&]RX7)I;R`B
M)7,B(&[C;R!E>&ES=&4N`$%P96YA<R!O<R!L861O<R!S=7!E<FEO<B!E(&EN
M9F5R:6]R`$%P96YA<R!O(&QA9&\@<W5P97)I;W(`3W,@9&%D;W,@8V%R<F5G
M861O<R!P97)D97)A;2US92!D97-D92!O('!A<W-O(&%N=&5R:6]R+@!/(&%R
M<75I=F\@8V%R<F5G861O(&[C;R!P]&1E('-E<B!G=6%R9&%D;RX`3R!B;&]C
M;R!W96%T:&5R+F-O;2!NXV\@97-TX2!D:7-P;V[M=F5L+@!.XV\@:.$@;W#G
M]65S(&1I<W!O;NUV96ES+@!.XV\@:.$@<&%R=&5S('%U92!P;W-S86T@<V5R
M(&UO<W1R861A<R!E;2!L:6YH82X`2.$@9&5M87-I861O<R!C87)A8W1E<F5S
M(&YE<W1E(&-A;7!O+B!);G1R;V1U>FEU("5S(&-A<F%C=&5R97,[('1E;2!D
M92!I;G1R;V1U>FER(&UE;F]S(&1O('%U92`E<RX`3N-O(&5X:7-T92!A:6YD
M82!U;2!A<G%U:79O(&1E(&%J=61A('!A<F$@)7,N`$]C;W)R974@=6T@<')O
M8FQE;6$@;F$@861IY^-O(&1E("(E<R(@86\@<VES=&5M83H@)7,`3V-O<G)E
M=2!U;2!P<F]B;&5M82!A;R!L:6UP87(@;W,@9&%D;W,@9&\@=71I;&EZ861O
M<B`B)7,B(&1O('-I<W1E;6$N`$]C;W)R974@=6T@<')O8FQE;6$@;F$@<F5M
M;^?C;R!D92`B)7,B(&1O('-I<W1E;6$N`$]C;W)R974@=6T@<')O8FQE;6$@
M86\@86-T=6%L:7IA<B`B)7,B.B`E<RX`2&]U=F4@=6T@<')O8FQE;6$@8V]M
M(&\@8V%R<F5G86UE;G1O(&1O(&9I8VAE:7)O.B`E<R!NXV\@9F]I(&-A<G)E
M9V%D;RX`3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C87)R96=A;65N=&\@
M9&\@87)Q=6EV;SH@3R`E<R!E>&-E9&4@;R!T86UA;FAO(&WA>&EM;R!P97)M
M:71I9&\@*"5D(&)Y=&5S*2X`3V-O<G)E=2!U;2!P<F]B;&5M82!C;VT@;R!C
M87)R96=A;65N=&\@9&\@87)Q=6EV;SH@3R`E<R!F;VD@87!E;F%S('!A<F-I
M86QM96YT92!C87)R96=A9&\N`$]C;W)R974@=6T@97)R;R!A;R!M;W-T<F%R
M(&5S=&$@<&%R=&4@9&$@;65N<V%G96T`3V-O<G)E=2!U;2!E<G)O(&%O(&EM
M<&]R=&%R(&1A9&]S(&1E(&-O;G1A8W1O+@!/8V]R<F5U('5M(&5R<F\@86\@
M:6UP;W)T87(@9&%D;W,@:4-A;&5N9&%R+@!/8V]R<F5U('5M(&5R<F\@;F\@
M9F]R;75LX7)I;R!D92!C;VYF:6=U<F'GXV\N(%1A;'9E>B!T96YH82!O;6ET
M:61O('5M(&-A;7!O(&]B<FEG873S<FEO+@!/8V]R<F5U('5M(&5R<F\@86\@
M86)R:7(@;R!A<G%U:79O("5S+B!%>'!E<FEM96YT92!E>&5C=71A<B!T<F%N
M<VQA=&EO;BYP:'`@8V]M(&$@;W#GXV\@+60@<&%R82!C;VYS96=U:7(@=F5R
M(&%S(&UE;G-A9V5N<R!D92!E<G)O(&1O(&%N86QI<V%D;W(@6$U,+@!/8V]R
M<F5U('5M(&5R<F\@86\@<F5A;&EZ87(@82!F=6[GXV\@9&4@;&EV<F\@9&4@
M96YD97)EYV]S(&5S<&5C:69I8V%D82X@4&]R(&9A=F]R('1E;G1E(&1E(&YO
M=F\@;6%I<R!T87)D92X`3V-O<G)E=2!U;2!E<G)O(&%O(&%C='5A;&EZ87(@
M;W,@<&]R;65N;W)E<R!D;R!C;VYT86-T;RX@4&]R(&9A=F]R('1E;G1E(&1E
M(&YO=F\@;6%I<R!T87)D92X`3V-O<G)E=2!U;2!E<G)O(&%O(&%C='5A;&EZ
M87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N(%!O<B!F879O<B!T96YT92!D
M92!N;W9O(&UA:7,@=&%R9&4N`$5S=&4@<V5R=FED;W(@24U!4"!NXV\@<W5P
M;W)T82!P87)T:6QH82!D92!P87-T87,N`$[C;R!P87)E8V4@<V5R('5M(&%R
M<75I=F\@<F%R(';A;&ED;RX`3N-O('!A<F5C92!S97(@=6T@87)Q=6EV;R!Z
M:7`@=N%L:61O+@!.XV\@<&%R96-E('-E<B!U;6$@;OIM97)O(&1E(&-A<G3C
M;R!VX6QI9&\N`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO(&1E
M(&UE;G-A9V5N<R!A=')A=NES(&1O($-L:6-K871E;&P@*&AT='`Z+R]C;&EC
M:V%T96QL+F-O;2DL('5S86YD;R!A($%022!(5%10`$5S=&4@8V]N=')O;&%D
M;W(@<&5R;6ET92!O(&5N=FEO(&1E(&UE;G-A9V5N<R!A=')A=NES(&1O('-M
M<S)M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2DL('5S86YD;R!A($%022!(
M5%10`$5S=&4@8V]N=')O;&%D;W(@<&5R;6ET92!O(&5N=FEO(&1E(&UE;G-A
M9V5N<R!V:6$@4TU44"!A=')A=NES(&1A(%9O9&%F;VYE($ETX6QI82!E(&%P
M96YA<R!P87)A(&[Z;65R;W,@5F]D869O;F4N($5X:6=E('5M82!C;VYT82!D
M92!C;W)R96EO(&5L96-T<O-N:6-O(&YA(%9O9&%F;VYE($ETX6QI82`H:'1T
M<#HO+W=W=RXQ.3`N:70I+@!%<W1E(&-A;7!O(.D@;V)R:6=A=/-R:6\N`$5S
M=&4@8V%M<&\@<&]D92!C;VYT97(@87!E;F%S(&EN=&5I<F]S+@!%<W1E(&-A
M;7!O('!O9&4@87!E;F%S(&-O;G1E<B!N^FUE<F]S(&4@;R!S[6UB;VQO(&1O
M:7,M<&]N=&]S+@!%<W1E(&-A;7!O('!O9&4@8V]N=&5R(&%P96YA<R!V86QO
M<F5S(&]C=&%I<RX`17-T92!C86UP;R!T96T@9&4@8V]N=&5R('5M82!L:7-T
M82!D92!I;G1E:7)O<R!S97!A<F%D;W,@<&]R(&5S<&'G;W,@;W4@=NUR9W5L
M87,N`$5S=&4@8V%M<&\@=&5M(&1E('-E<B!U;2!N^FUE<F\@=N%L:61O+@!%
M<W1E(&-A;7!O('1E;2!D92!C;VYT97(@=6T@8_-D:6=O(&1E(&-O<B!N;R!F
M;W)M871O(%)'0B!H97AA9&5C:6UA;"P@<&]R(&5X96UP;&\@)R,Q,C,T868G
M+@!%<W1E(&UO9&5L;R!JX2!F;VD@<')O8V5S<V%D;RX`27-T;R#I("5S+@!%
M<W1E(.D@=6T@;V)J96-T;R!+;VQA8B!'<F]U<'=A<F4N(%!A<F$@=F5R(&5S
M=&4@;V)J96-T;R!P<F5C:7-A(&1E('5M(&-L:65N=&4@9&4@8V]R<F5I;R!E
M;&5C='+S;FEC;R!Q=64@8V]N:&7G82!O(&9O<FUA=&\@2V]L86(@1W)O=7!W
M87)E+B!087)A('5M82!L:7-T82!D92!C;&EE;G1E<R!D92!C;W)R96EO(&5L
M96-T<O-N:6-O(&YE<W-A<R!C:7)C=6YS=.)N8VEA<R!V:7-I=&4@)7,`17-T
M82!M96YS86=E;2!F;VD@97-C<FET82!N=6T@8_-D:6=O("@E<RD@9&EF97)E
M;G1E(&1O('-E=2X`17-T92!N^FUE<F\@<')E8VES82!D92!S97(@<&5L;R!M
M96YO<R!U;2X`17-T92`B<V-R:7!T(B!T96T@<V5R(&5X96-U=&%D;R!A('!A
M<G1I<B!D92!U;6$@;&EN:&$@9&4@8V]M86YD;W,N`$5S=&4@<V5R=FED;W(@
M;N-O(&-O;G-E9W5E(&1E<V-O;7!R:6UI<B!A<G%U:79O<R!Z:7`@;W4@9WII
M<"X`17-T92!S:7-T96UA(&5N8V]N=')A+7-E(&1E<V%C=&EV861O+@!%<W1A
M('9A;&]R('1E;2!D92!S97(@=6T@;OIM97)O+@!%<W1A(&IA;F5L82!T96T@
M9&4@<V5R(&-H86UA9&$@82!P87)T:7(@9&4@=6UA(&IA;F5L82!D92!/<.?U
M97,`5')O=F]A9&$`0FEL:&5T97,`1&%T82](;W)A`%-E9W5I;65N=&\@5&5M
M<&]R86P`1F]R;6%T;R!D;R!T96UP;P!396QE8^?C;R!D871A+VAO<F$`5&EM
M;W(M3&5S=&4`5.UT=6QO`%3M='5L;R`H9&EC82DZ`%!A<F$`4&%R82!S96QE
M8V-I;VYA<B!M^FQT:7!L;W,@:71E;G,L(&-A<G)E9W5E(&5M($-O;G1R;VP@
M*%!#*2!O=2!#;VUM86YD("A-86,I(&5N<75A;G1O(&-L:6-A<BX`2&]J90!4
M<F]C87(@1F]N=&4@2%1-3`!297#Z8FQI8V$@5&]G;VQE<V$`5&]Q=65L874`
M06UA;FCC`%)E:6YO(&1O(%1O;F=A`%1O<&\`36]L9'5R82!D92!T;W!O("A?
M=&]P*0!4<F%D=7II9&%S`%1R861UY_5E<P!4<FEN9&%D92!E(%1O8F%G;P!6
M97)D861E:7)O(&]U(&9A;'-O`#.J`%)E</IB;&EC82!D82!4=6[M<VEA`%)E
M</IB;&EC82!D82!4=7)Q=6EA`%1U<F-O("A)4T\M.#@U.2TY*0!4=7)Q=65M
M96YI<W3C;P!);&AA<R!4=7)C87,@92!#86EC;W,`5'5V86QU`$5S8W)E=F$@
M82!S=6$@97-C;VQH83H`S6YD:6-E(%4N5BXZ(`!54DP`55),(&1O('-E=2!R
M96QA=/-R:6\@9&4@97-T861O(&1O(&5N=FEO(&1E(")S8W)I<'1S(@!54DPZ
M`%)E</IB;&EC82!D;R!59V%N9&$`56-RXFYI80!.XV\@9F]I('!O<W/M=F5L
M(&%C961E<B#@('!A<W1A(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!A9&EC:6]N
M87(@:6YF;W)M8>?C;R!D92!U=&EL:7IA9&]R(&5X=')A(&%Q=6%N9&\@9&$@
M<W5B<V-R:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!M=61A<B!A<R!P97)M:7-S
M]65S(&1O(&%R<75I=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@;75D
M87(@87,@<&5R;6ES<_5E<R!D;R!A<G%U:79O(%9&4R`E<R\E<RX`3N-O(&9O
M:2!P;W-S[79E;"!M=61A<B!P87)A("5S+@!.XV\@9F]I('!O<W/M=F5L(&QI
M9V%R(&%O('-E<G9I9&]R(%-13"X`3N-O(&9O:2!P;W-S[79E;"!L:6=A<B!U
M<V%N9&\@4U-,+@!.XV\@9F]I('!O<W/M=F5L(&-O<&EA<B!O(&%R<75I=F\@
M5D93+@!.XV\@9F]I('!O<W/M=F5L(&-R:6%R(&$@<&%S=&$@5D93("(E<R(N
M`$[C;R!F;VD@<&]S<^UV96P@8W)I87(@82!P87-T82!61E,N`$[C;R!F;VD@
M<&]S<^UV96P@8W)I87(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E
M;"!C<FEA<B!U;2!A<G%U:79O(%9&4R!V87II;RX`3N-O(&9O:2!P;W-S[79E
M;"!D97-C;VUP<FEM:7(@;W,@9&%D;W,N`$[C;R!F;VD@<&]S<^UV96P@<F5M
M;W9E<B`B)7,B+"!P;VES(&$@<&%S=&$@;N-O(&5S=.$@=F%Z:6$N`$[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B`B)7,B.B`E<RX`3N-O(&9O:2!P;W-S[79E
M;"!R96UO=F5R("5S+"!P;VES(&$@<&%S=&$@;N-O(&5S=.$@=F%Z:6$`3N-O
M(&9O:2!P;W-S[79E;"!R96UO=F5R(&$@<&%S=&$@5D93(')E8W5R<VEV86UE
M;G1E+@!.XV\@9F]I('!O<W/M=F5L(')E;6]V97(@82!P87-T82!61E,N`$[C
M;R!F;VD@<&]S<^UV96P@<F5M;W9E<B!A('!A<W1A(%9&4SH@)7,N`$[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B!O(&%R<75I=F\@5D93("(E<R(N`$[C;R!F
M;VD@<&]S<^UV96P@<F5M;W9E<B!O(&%R<75I=F\@5D93+@!.XV\@9F]I('!O
M<W/M=F5L(')E;6]V97(@<F5C=7)S:79A;65N=&4Z("5S+@!.XV\@9F]I('!O
M<W/M=F5L(&1E=&5R;6EN87(@82!P87-T82!C;W)R96YT92X`3N-O(&9O:2!P
M;W-S[79E;"!E>'1R86ER(&]S('!O<FUE;F]R97,@9&\@8V5R=&EF:6-A9&\`
M26UP;W-S[79E;"!L97(@82!D969I;FGGXV\@9&4@)7,N`$[C;R!F;VD@<&]S
M<^UV96P@;6]V97(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!A
M8G)I<B!O(&%R<75I=F\@5D93("(E<R(N`$[C;R!F;VD@<&]S<^UV96P@86)R
M:7(@;R!A<G%U:79O(%9&4R!P87)A(&5S8W)I=&$N`$[C;R!F;VD@<&]S<^UV
M96P@86)R:7(@;R!A<G%U:79O(%9&4RX`3N-O(&9O:2!P;W-S[79E;"!A8G)I
M<B!O(&%R<75I=F\@8V]M<')I;6ED;RX`3N-O(&-O;G-I9V\@;&5R(&\@87)Q
M=6EV;SH@`$[C;R!F;VD@<&]S<^UV96P@;&5R(&$@<&%S=&$@=F9S<F]O="X`
M3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B`E<R!C;VUO("5S.B!A('!A<W1A
M(&1E(&1E<W1I;F\@:N$@97AI<W1E`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE
M87(@82!P87-T82!61E,N`$[C;R!F;VD@<&]S<^UV96P@<F5N;VUE87(@82!P
M87-T82!61E,Z("5S+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&\@87)Q
M=6EV;R!61E,@(B5S(BX`3N-O(&9O:2!P;W-S[79E;"!R96YO;65A<B!O(&%R
M<75I=F\@5D93("5S+R5S+@!.XV\@9F]I('!O<W/M=F5L(')E;F]M96%R(&%R
M<75I=F\@5D93+@!.XV\@9F]I('!O<W/M=F5L(&5X96-U=&%R("=M:VES;V9S
M)RX`3N-O(&9O:2!P;W-S[79E;"!C;VYV97)T97(@97-T92!D;V-U;65N=&\@
M5V]R9`!.XV\@9F]I('!O<W/M=F5L(&5S8W)E=F5R(&%R<75I=F\@5D93("(E
M<R(N`$[C;R!F;VD@<&]S<^UV96P@97-C<F5V97(@;R!A<G%U:79O(%9&4R`H
M8V]P>2@I(&9A;&AO=2DN`$[C;R!C;VYS:6=O(')E;6]V97(@)R5S)SH@)7,N
M`%-U8FQI;FAA9&\`1&5S9F%Z97(@06QT97)AY_5E<P!$97-F87H@82!S=6$@
M^FQT:6UA(&%CY^-O`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@
M;F$@8V]N97CC;SH@`%)E<W!O<W1A(&EN97-P97)A9&$@9&\@<V5R=FED;W(@
M83H@`%-E;2!C871E9V]R:6$`56YI8V]D92`H551&+3@I`$5M:7)A9&]S(,%R
M86)E<R!5;FED;W,`4F5I;F\@56YI9&\`17-T861O<R!5;FED;W,@9&$@06WI
M<FEC80!);&AA<R!-96YO<F5S($1I<W1A;G1E<R!D;W,@17-T861O<R!5;FED
M;W,`56YI9&%D97,`1&5S8V]N:&5C:61O`&%P:6US9VED("A)1"!D92!-96YS
M86=E;2!D92!!4$DI+@!C;&EM<V=I9"!D97-C;VYH96-I9&\@*$E$(&1E($UE
M;G-A9V5M(&1E($-L:65N=&4I+@!#;VUA;F1O(&1E<V-O;FAE8VED;SH@)7,`
M1F]I(&9O<FYE8VED82!U;6$@;&]C86QI>F'GXV\@9&5S8V]N:&5C:61A+@!.
M;VUE(&1E('5T:6QI>F%D;W(@;W4@<&%L879R82UP87-S92!E<G)A9&]S`%)E
M;6]V97(@;&EG8>?C;R!D;R!E;&5M96YT;R!C;W)R96YT90!396T@;F]M90!0
M;W(@<F%Z]65S(&1E('-E9W5R86[G82P@(G-C<FEP=',B('-E;2!P<FEV:6SI
M9VEO(&[C;R!P;V1E;2!A8V5D97(@82!#;W)T87(O0V]P:6%R+T-O;&%R('!R
M;V=R86UA=&EC86UE;G1E+B!#87)R96=U92!E;2!/2R!P87)A('9E<B!U;6$@
M;F]T82!TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G('%U92!L:&4@;6]S=')A<N$@
M8V]M;R!A=71O<FEZ87(@=6T@(G-C<FEP="(@82!A8V5D97(@86]S(')E8V]R
M=&5S+@!296UO=F5R(&-O;&]R8>?C;P!%>'1E;G/C;R!NXV\@4W5P;W)T861A
M`%!O<B!T<F%D=7II<@!-;V1I9FEC87(`06-T=6%L:7IA<B`E<P!!8W1U86QI
M>F%R('5T:6QI>F%D;W(`(B5S(B!A8W1U86QI>F%D;RX`06-T=6%L:7IA;F1O
M(&%R<75I=F\@9&4@86IU9&$@)7,@<&%R82`E<RX`(E-C<FEP="(@9&4@86-T
M=6%L:7IAY^-O(')E;6]V:61O+@!5<&QO860`0V%R<F5G861O<R!N;R!S97)V
M:61O<B!T;V1O<R!O<R!A<G%U:79O<R!D92!I;G-T86QAY^-O(&1E(&%P;&EC
M8>?U97,N`$QE=')A<R!L871I;F%S(&5M(&UA:?IS8W5L87,`3OIM97)O<R!R
M;VUA;F]S(&5M(&UA:?IS8W5L87,`4F5P^F)L:6-A($]R:65N=&%L(&1O(%5R
M=6=U86D`571I;&EZ8>?C;SH`57-A<B!O($-O<G)E;G1E.B`E<P!5<V%R(%-3
M3"X`57-A<B!S92!O(&YO;64@9&4@=71I;&EZ861O<B!O=2!A('!A;&%V<F$M
M<&%S<V4@9F]R96T@9&EF97)E;G1E<R!N;R!S97)V:61O<B!)35-0+@!5=&EL
M:7IA9&]R("5S(&[C;R!E<W3A(&%U=&]R:7-A9&\@<&%R82`E<RX`061M:6YI
M<W1R8>?C;R!D92!5=&EL:7IA9&]R97,`3W#G]65S(&1O(%5T:6QI>F%D;W(`
M4F5G:7-T;R!D92!5=&EL:7IA9&]R97,`3R!296=I<W1O(&1E(%5T:6QI>F%D
M;W)E<R!E<W3A(&EN86-T:79O+@!097)M:7-S]65S(&1O('5T:6QI>F%D;W(`
M3F]M92!D92!5=&EL:7IA9&]R`$\@3F]M92!D92!5=&EL:7IA9&]R("(E<R(@
M:N$@97AI<W1E+@!.;VUE(&1E(%5T:6QI>F%D;W(Z`$YO;64@9&4@571I;&EZ
M861O<CH@`%5T:6QI>F%D;W)E<P!5=&EL:7IA9&]R97,@9&\@<VES=&5M83H`
M4F5P^F)L:6-A(&1O(%5Z8F5Q=6ES=.-O`$$@<&%S=&$@5D93(&[C;R!E>&ES
M=&4N`$%U<^IN8VEA`$%S(&QO8V%L:7IAY_5E<R!VX6QI9&%S(&5N8V]N=')A
M9&%S(&EN8VQU96TZ`%9A;&ED861E+@!686QO<B!E;2!M:6YU=&]S(&$@<&%R
M=&ER(&1E<W1E(&EN<W1A;G1E+@!686QO<B!E>&-E9&4@;R!C;VUP<FEM96YT
M;R!MX7AI;6\@9&4@)7,N`%9A;&]R97,`4&]S<^UV96P@=F%L;W)E<R!A(&5S
M8V]L:&5R`%9A;G5A='4`5F%R:>%V96P`5F5N97IU96QA`%9E<FEF:6-AY^-O
M(&9A;&AO=2`M(&5S=&$@;65N<V%G96T@<&]D92!T97(@<VED;R!A9'5L=&5R
M861A+@!697)SXV\`0V]N=')O;&\@9&4@5F5R<_5E<P!!;&EN:&%M96YT;R!6
M97)T:6-A;`!#86SG;R!697)T:6-A;`!697)T:6-A;#H`375I=&\@06QT;P!2
M97#Z8FQI8V$@4V]C:6%L:7-T82!D;R!6:65T;F%M90!6:65T;F%M:71A("A6
M25-#24DI`%9I<W5A;&EZ87(@)7,`5F5R('5M82!PX6=I;F$@97AT97)N80!6
M:7-U86QI>F%R(&-O;6\@)7,`26QH87,@5FER9V5N<R!"<FETXFYI8V%S`$EL
M:&%S(%9I<F=E;G,@06UE<FEC86YA<P!6:7-I8FEL:61A9&4`5FES:6)I;&ED
M861E.B``5F]D869O;F4@273A;&EA('9I82!33510`$%625,`051%3L?#3R$A
M(2!214U/5D$@3R`B4T-225!4(B!-04Y504Q-14Y412!$12`E<RX`5V%L;&ES
M(&4@1G5T=6YA`$%V:7-O`$%V:7-O.B``-*H`4')E=FESXV\@9&\@5&5M<&\`
M1&%D;W,@;65T96]R;VSS9VEC;W,@9F]R;F5C:61O<R!P;W(`5V5A=&AE<BYC
M;VT`5V5B`%#A9VEN80!396UA;F%L;65N=&4`0F5M+79I;F1A*&\I`$)E;2UV
M:6YD82AO*2!A("5S`$)E;2UV:6YD82AO*2P@)7,`3V-I9&5N=&%L("A)4T\M
M.#@U.2TQ*0!/8VED96YT86P@*$E33RTX.#4Y+3$U*0!386%R80!1=64@87!L
M:6-AY^-O(&1E=F4@;R`E<R!M;W-T<F%R(&%P\W,@82!E;G1R861A/P!1=6%L
M(.D@;R!C87)A8W1E<F4@9&5L:6UI=&%D;W(_`%%U86P@Z2!O(&-A<F%C=&5R
M92!D92!C:71AY^-O/P!1=64@9F%S97,`475E(")P;'5G:6YS(B!A8W1I=F%R
M('!A<F$@82!%9&GGXV\@4FEC82X`3&%R9W5R80!,87)G=7)A(&5M('5N:61A
M9&5S($-34P!,87)G=7)A(&1O($UE;G4@)7,@X"!E<W%U97)D82`H=&5M(&5F
M96ET;R!N82!P<O-X:6UA(&5N=')A9&$I.@!,87)G=7)A(&1A('1A8F5L80!5
M;FED861E(&1E(&QA<F=U<F$`3&%R9W5R83H`5VEK:0!696YT;P!696YT;R!-
M871I;F%L`%9E;&]C:61A9&4@9&\@=F5N=&\@96T@;O-S`%9E;G1O.@!696YT
M;SH@`%-A8F5D;W)I80!,:7-T87,@9&4@1&5S96IO<P!4<F%B86QH;P!%;F1E
M<F7G;R`H16UP<F5G;RD`5&5L969O;F4@*$5M<')E9V\I`$5S8W)E=F5N9&\@
M87)Q=6EV;R!D92!A:G5D82!A8W1U86QI>F%D;R!P87)A("5S+@!2969E<NIN
M8VEA<R!C<G5Z861A<P!297-T<FGG]65S($+A<VEC87,@6#4P.78S`%5T:6QI
M>F'GXV\@9&4@0VAA=F4@17AT96YD:61A(%@U,#EV,P!.;VUE($%L=&5R;F%T
M:79O(&1E(%-U:F5I=&\@6#4P.78S`$ED96YT:69I8V%D;W(@0VAA=F4@9&4@
M4W5J96ET;R!8-3`Y=C,`17AT96YS]65S(%@U,#EV,P!!00!!04%!`$UA<&$@
M66%H;V\A`$%N=6%L;65N=&4`2>EM96X`4VEM`%-I;2P@0V]N8V]R9&\`17-T
MX2!E;2!-3T1/(&1E(%1%6%0N("!5<V4@;R!B;W3C;R!;/#Y=('!A<F$@=')O
M8V%R('!A<F$@;R!M;V1O(%9)4U5!3"X`3N-O(&5S=.$@875T96YT:6-A9&\N
M`$[C;R!P;V1E('1E<B!O(&-A<F%C=&5R92`G7"<@;F\@<V5U(&YO;64@8V]M
M<&QE=&\N`$[C;R!I;G1R;V1U>FEU('5M(&5N9&5R9>=O(&1E(&-O<G)E:6\@
M96QE8W1R\VYI8V\@=N%L:61O+@!.XV\@;6%P96]U(&YE;FAU;2!C86UP;R!D
M;R!A<G%U:79O(&EM<&]R=&%D;R!P87)A(&]S(&-A;7!O<R!C;W)R97-P;VYD
M96YT97,@96T@)7,N`$%C86)O=2!D92!S86ER+@!496T@9&4@:6YT<F]D=7II
M<B!U;2!N^FUE<F\@9&4@=&5L96WS=F5L(';A;&ED;RP@<_,@8V]M(&3M9VET
M;W,L(&UA<R!C;VT@=6T@)RLG(&]P8VEO;F%L('!A<F$@;R!P<F5F:7AO(&EN
M=&5R;F%C:6]N86PN`%1E;2!D92!I;G1R;V1U>FER('5M('9A;&]R(';A;&ED
M;RX`5&5M(&1E(&-O;F9I9W5R87(@=6T@;65C86YI<VUO(&+A<VEC;R!P87)A
M($1A=&%4<F5E('-E('%U:7-E<B!U<V%R(%-U8G-C<FGG]65S`%1E;2!D92!C
M;VYF:6=U<F%R('5M(&UE8V%N:7-M;R!B87-E('!A<F$@;R!61E,N`$1E=F4@
M9&5S8W)E=F5R(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@<F5L873S
M<FEO+@!496T@9&4@:6YT<F]D=7II<B!O(%523"!D;R!R96-U<G-O('%U92!E
M<W1A(&QI9V'GXV\@<V4@<F5F97)E`%1E;2!D92!S96QE8V-I;VYA<B!U;2!S
M97)V:61O<B!A(')E;6]V97(N`$1E=F4@97-P96-I9FEC87(@;R!U=&EL:7IA
M9&]R(&$@;&EM<&%R+@!$979E(&5S<&5C:69I8V%R(&\@;F]M92!D;R!U=&EL
M:7IA9&]R(&$@<F5M;W9E<BX`5&5M(&1E(&5S<&5C:69I8V%R(&\@;F]M92!D
M;R!U=&EL:7IA9&]R(&$@861I8VEO;F%R+@!496T@9&4@97-P96-I9FEC87(@
M;R!U=&EL:7IA9&]R(&$@86-T=6%L:7IA<BX`5&5M(&1E(&5S<&5C:69I8V%R
M(&$@86/GXV\@82!D97-E;7!E;FAA<BX`5&5M(&1E(&EN=')O9'5Z:7(@=6T@
M;F]V;R!N;VUE(&1E(&-A=&5G;W)I82X`5&5M(&1E(&9O<FYE8V5R('5M(&[Z
M;65R;R!D92!T96QE9F]N92!I=&%L:6%N;P!!('-U82!S97-SXV\@)7,@97AP
M:7)O=2X@4&]R(&9A=F]R(&5N=')E(&1E(&YO=F\N`$\@<V5U($5N9&5R9>=O
M(&1E($-O<G)E:6\@16QE8W1R\VYI8V\Z`$\@<V5U(&5N9&5R9>=O(")$93HB
M`$$@<W5A($EN9F]R;6'GXV\`3R!S974@96YD97)EYV\@25`@<&%R96-E('1E
M<B!M=61A9&\@9&5S9&4@;R!I;NUC:6\@9&$@<V5S<^-O("5S+B!087)A(&=A
M<F%N=&ER(&$@<W5A('-E9W5R86[G82P@9&5V92!A=71E;G1I8V%R+7-E(&1E
M(&YO=F\N`$\@4V5U($YO;64`3R!S974@;65C86YI<VUO(&1E(&%U=&5N=&EC
M8>?C;R!NXV\@<W5P;W)T82!A9&GGXV\@9&4@=71I;&EZ861O<F5S(&]U(&5S
M=&$@;W#GXV\@9F]I(&1E<V%C=&EV861A('!O<B!A;&=U;2!O=71R;R!M;W1I
M=F\N`$\@<V5U(&UE8V%N:7-M;R!D92!A=71E;G1I8V'GXV\@;N-O('-U<&]R
M=&$@;&ES=&%G96T@9&4@=71I;&EZ861O<F5S(&]U(&5S=&$@;W#GXV\@9F]I
M(&1E<V%C=&EV861A('!O<B!A;&=U;2!O=71R;R!M;W1I=F\N`$\@<V5U(&YA
M=F5G861O<B!P87)E8V4@=&5R(&UU9&%D;R!D97-D92!O(&EN[6-I;R!D82!S
M97-SXV\@)7,N(%!A<F$@9V%R86YT:7(@82!S=6$@<V5G=7)A;N=A+"!D979E
M(&%U=&5N=&EC87(M<V4@9&4@;F]V;RX`3R!S974@;F%V96=A9&]R(&[C;R!S
M=7!O<G1A(&5S=&$@9G5N8VEO;F%L:61A9&4N`$\@<V5U(&YA=F5G861O<B!N
MXV\@<W5P;W)T82!E<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@4')E<W-I;VYE
M($-O;G1R;VPO0V]M;6%N9"`K(%`@<&%R82!I;7!R:6UI<BX`1G5S;R!H;W+A
M<FEO(&%C='5A;#H`261E;G1I9&%D92!P861RXV\Z`$YO;64@8V]M<&QE=&\`
M02!S=6$@=F5R<^-O(&1O(&=E='1E>'0@Z2!D96UA<VEA9&\@86YT:6=A+"!N
MXV\@<W5P;W)T86YD;R!02%`@9&4@9F]R;6$@;F%T:79A+B!.96T@=&]D87,@
M87,@8V%D96EA<R!D92!C87)A8W1E<F5S('-E<N-O(&5X=')A[61A<RX`02!S
M=6$@;F]V82!P86QA=G)A+7!A<W-E('!A<F$@)7,@Z3H@)7,`07,@<W5A<R!O
M<.?U97,@9F]R86T@86QT97)A9&%S(&%TZ2!A;R!F:6YA;"!D97-T82!S97-S
MXV\N`$%S('-U87,@;W#G]65S(&9O<F%M(&%C='5A;&EZ861A<RX`02!S=6$@
M<&%L879R82UP87-S92!F;VD@<F5C<FEA9&$`02!S=6$@<&%L879R82UP87-S
M92!F;VD@<F5C<FEA9&$L('9E<FEF:7%U92!O('-E=2!C;W)R96EO(&5L96-T
M<O-N:6-O(&4@96YT<F4@8V]M(&$@<W5A(&YO=F$@<&%L879R82UP87-S92X`
M3W,@<V5U<R!S97)V:61O<F5S(')E;6]T;W,Z`$IU9V]S;.%V:6$`6F%I<F4`
M6N)M8FEA`%II;6)A8G7I`%II<'!Y`%M%<V-O;F1E<B!497AT;R!#:71A9&]=
M`%M296QA=/-R:6\@9&4@4')O8FQE;6%S72``6TUO<W1R87(@5&5X=&\@0VET
M861O("T`6TUO<W1R87(@5&5X=&\@0VET861O("T@)7,@;&EN:&%S70!;;&EN
M:&$@)7,@9&4@)7-=`%]!9&UI;FES=')AY^-O`%]#;VYS;VQA`,%R7W9O<F4`
M7U)E;6]V97(@3&EN:&$`7T=R=7!O<P!!7VIU9&$`4')O<')I961A9&5S(&1A
M(%]);6%G96T`7T5N=')A<@!?4V%I<@!?36]D:69I8V%R($QI9V'GXV\`7T]P
MY_5E<P!?4&5R;6ES<_5E<P!?4F5M;W9E<B!,:6=AY^-O+BXN`%]#;VYF:6=U
M<F'GXV\`4')O<')I961A9&5S(&1A(%]486)E;&$`7U5T:6QI>F%D;W)E<P!C
M;VYT86-T;W,`;V-O<G)E=2!U;2!E<G)O.@!C86QE;F3A<FEO`&-A;&UO`&-L
M:7%U92!A<75I`&9E:71O`&9A;&AO=0!D:6UI;G5I;F1O`&9I8VAE:7)O`&5N
M8V]N=')A9&\Z(`!D;R`E<R`H)7,I(.!S("5S("5S`')A:F%D87,`:#H`:&@`
M:6UE9&EA=&\`96T@;&EN:&$`;&EN:&%S70!%<G)O(&UK:7-O9G,@8V]M(&/S
M9&EG;R`E9"!A;R!C;VYS=')U:7(@25-/+@!M;0!N;VUE`'-E;2!A;'1E<F'G
M]65S`&[C;R!E;F-O;G1R861O`&[C;R!I;7!L96UE;G1A9&$`86EN9&$@<&]R
M(&EM<&QE;65N=&%R`&-A9&5R;F\@9&4@;F]T87,`<&5R8V5N=&%G96T`<.UX
M96ES`'-U8FEN9&\`;6]S=')A<B!D:69E<F5NYV%S`'-M<S)E;6%I;"!V:6$@
M2%144`!S<P!E<W3A=F5L`&QI<W1A(&1E('1A<F5F87,`3R!F:6-H96ER;R!0
M3R!P87)A(&\@;&]C86QE("5S(&[C;R!E>&ES=&4N`&EN=')O9'5Z82!A('!A
M;&%V<F$M<&%S<V4@9'5A<R!V97IE<RP@<&%R82!C;VYF:7)M8>?C;P!U;FEF
M:6-A9&\`<V5M(&YO;64`86-T=6%L:7IA9&\`<V5L96-C:6]N861A('!E;&\@
M=71I;&EZ861O<@!V0V%R9`!2965N8SH`=V5A=&AE<BYC;VT`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+W!T7T)2+TQ#7TU%4U-!1T53````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,34P-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O<'1?0E(O:&5L<"YX;6P`````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T,S0Q
M-#$@,#(Q-#0V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R
M9&4O;&]C86QE+W!T7T)2+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z
M,C(Z,3,@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA
M<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L
M93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC
M:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N
M+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM
M86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI
M;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M
M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I
M8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I
M;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N
M<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R
M96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO
M<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P
M86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@
M($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I
M;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H
M:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!
M<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!
M="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A
M<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O
M;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I
M;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N
M<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA
M:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP
M87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N
M86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?
M;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N
M8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^
M"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@
M86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H
M96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E
M<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E
M;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+W!T7T)2+TQ#7TU%4U-!1T53+VAO<F1E+FUO````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-#$U,34Q(#$P-3$U-#,T,30Q(#`R
M,S(S,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#>$@25`````(8'```<````3#P``!,*``!\>````````,B@```.````R:``
M``\```#8H```#0```.B@```(````]J````L```#_H```#`````NA```$````
M&*$``!@````=H0``&P```#:A```M````4J$``!T```"`H0``)````)ZA```I
M````PZ$``!D```#MH0``)@````>B```,````+J(``"0````[H@``#P```&"B
M```+````<*(```X```!\H@``!0```(NB```H````D:(```@```"ZH@``"@``
M`,.B```5````SJ(``!(```#DH@``"P```/>B``"%`````Z,```X```")HP``
M"@```)BC```-````HZ,```X```"QHP``$0```,"C```-````TJ,```P```#@
MHP``#0```.VC```&````^Z,``)0````"I```"@```)>D```/````HJ0``!@`
M``"RI```#````,ND```.````V*0```X```#GI```"````/:D```)````_Z0`
M`"X````)I0``&@```#BE```R````4Z4``#@```"&I0``5````+^E``!1````
M%*8``%H```!FI@``5P```,&F```T````&:<```D```!.IP``#0```%BG```'
M````9J<```H```!NIP``#P```'FG```%````B:<```8```"/IP``$0```):G
M```(````J*<```D```"QIP``"0```+NG```E````Q:<``"````#KIP``$P``
M``RH```0````(*@```\````QJ```"@```$&H```#````3*@```\```!0J```
M%````&"H```)````=:@```T```!_J```$@```(VH```9````H*@``!X```"Z
MJ```#P```-FH```*````Z:@```\```#TJ```"`````2I```D````#:D``!0`
M```RJ0``%@```$>I```(````7JD``$X```!GJ0``+0```+:I```9````Y*D`
M``<```#^J0``#`````:J```L````$ZH```X```!`J@```P```$^J```+````
M4ZH```<```!?J@``!P```&>J```%````;ZH```4```!UJ@``"@```'NJ```#
M````AJH``!<```"*J@``"@```**J```/````K:H```X```"]J@``&````,RJ
M```C````Y:H```X````)JP``%````!BK```7````+:L``!<```!%JP``%P``
M`%VK```3````=:L```\```")JP``#@```)FK```?````J*L``!T```#(JP``
M!P```.:K```&````[JL```@```#UJP``#P```/ZK```&````#JP```H````5
MK```$P```""L```+````-*P``!````!`K```%0```%&L```5````9ZP```<`
M``!]K```$````(6L```%````EJP``!4```"<K```$0```+*L```,````Q*P`
M`#L```#1K```.`````VM```)````1JT```<```!0K0``%````%BM```#````
M;:T```4```!QK0``$````'>M```)````B*T``!,```"2K0``.0```*:M```2
M````X*T``"<```#SK0``+````!NN```J````2*X``"4```!SK@``"@```)FN
M```&````I*X```D```"KK@``!P```+6N```O````O:X``#<```#MK@``+@``
M`"6O``!5````5*\``"T```"JKP``+0```-BO```]````!K```#\```!$L```
M+0```(2P``!`````LK```",```#SL```(P```!>Q``!`````.[$``"T```!\
ML0``,P```*JQ```E````WK$``!4````$L@``&0```!JR```I````-+(``"0`
M``!>L@``*````(.R```1````K+(```H```"^L@``#````,FR```*````UK(`
M`!````#AL@``%@```/*R```6````";,```<````@LP``!P```"BS```4````
M,+,```H```!%LP``"````%"S```G````6;,```@```"!LP``!P```(JS```'
M````DK,```8```":LP``!0```*&S```'````I[,```8```"OLP``"````+:S
M```I````O[,```X```#ILP``"@```/BS```$`````[0```<````(M```"0``
M`!"T```&````&K0``!$````AM```!P```#.T```6````.[0```0```!2M```
M"````%>T```&````8+0```T```!GM```!@```'6T```>````?+0``!$```";
MM```"````*VT```-````MK0```P```#$M```!P```-&T```#````V;0```,`
M``#=M```%P```.&T```3````^;0``!T````-M0``"````"NU```$````-+4`
M``@````YM0``"````$*U``!!````2[4``!H```"-M0``*P```*BU```@````
MU+4``!4```#UM0``!@````NV```&````$K8``!4````9M@``&````"^V```B
M````2+8``"X```!KM@``'0```)JV```A````N+8``%0```#:M@``*0```"^W
M```*````6;<```<```!DMP``!P```&RW```5````=+<```X```"*MP``"@``
M`)FW```/````I+<```T```"TMP``#P```,*W```-````TK<```D```#@MP``
M%````.JW```&````_[<``!@````&N```'0```!^X```3````/;@``!$```!1
MN```%````&.X```$````>+@```8```!]N```%````(2X``!4````F;@``&0`
M``#NN```!````%.Y```.````6+D```4```!GN0``!0```&VY```;````<[D`
M`!H```"/N0``$P```*JY```1````OKD``!$```#0N0``'````.*Y```J````
M_[D``!`````JN@``(0```#NZ```%````7;H``!,```!CN@``"P```'>Z```2
M````@[H```H```"6N@``#P```*&Z```-````L;H``!$```"_N@``$P```-&Z
M```,````Y;H```8```#RN@``#````/FZ```&````!KL``!<````-NP``$```
M`"6[```1````-KL```@```!(NP``!0```%&[```,````5[L``!````!DNP``
M!0```'6[```-````>[L```8```")NP``!P```)"[```-````F+L```<```"F
MNP``"P```*Z[```'````NKL```<```#"NP``"0```,J[```)````U+L```H`
M``#>NP``&0```.F[```]`````[P``!T```!!O```#````%^\```0````;+P`
M``4```!]O```)0```(.\```2````J;P``!,```"\O```*P```-"\```[````
M_+P``"`````XO0``"````%F]```V````8KT``"$```"9O0``$````+N]```(
M````S+T```P```#5O0``!@```.*]```$````Z;T```\```#NO0``#@```/Z]
M```'````#;X```H````5O@``#0```""^```?````+KX``!P```!.O@``(0``
M`&N^```>````C;X``!D```"LO@``'@```,:^```;````Y;X``"$````!OP``
M+@```"._```F````4K\``!P```!YOP``'@```):_```<````M;\``"8```#2
MOP``*P```/F_```S````)<```"8```!9P```*P```(#````X````K,```!T`
M``#EP```%0````/!```O````&<$``"````!)P0``$@```&K!```I````?<$`
M`!X```"GP0``(````,;!```2````Y\$``*(```#ZP0``%@```)W"```C````
MM,(``"@```#8P@``*0````'#```H````*\,``!\```!4PP``%0```'3#```@
M````BL,``"4```"KPP``*````-'#```M````^L,``#`````HQ```D@```%G$
M```A````[,0``!8````.Q0``'````"7%```F````0L4``"H```!IQ0``00``
M`)3%``!$````UL4```P````;Q@``!P```"C&```'````,,8```8````XQ@``
M#0```#_&```0````3<8``!(```!>Q@``$P```''&```2````A<8```<```"8
MQ@``!````*#&```0````I<8``!````"VQ@``#````,?&```.````U,8```T`
M``#CQ@``#P```/'&```3`````<<```T````5QP``*````"/'```#````3,<`
M``T```!0QP``!@```%['```1````9<<``!<```!WQP``&P```(_'```.````
MJ\<```(```"ZQP``20```+W'```%````!\@``!`````-R```#P```![(```$
M````+L@```T````SR```#@```$'(```#````4,@```X```!4R```"````&/(
M```/````;,@```\```!\R```!P```(S(```-````E,@``!````"BR```#0``
M`+/(```+````P<@```8```#-R```"P```-3(```,````X,@```H```#MR```
M$0```/C(```9````"LD```L````DR0``#0```##)```B````/LD``!L```!A
MR0``-````'W)```*````LLD``!@```"]R0``&0```-;)```6````\,D``"(`
M```'R@``#0```"K*```'````.,H``!0```!`R@``"P```%7*```B````8<H`
M`"\```"$R@``"P```+3*```)````P,H``!D```#*R@``"P```.3*```7````
M\,H``!<````(RP``"0```"#+```6````*LL```\```!!RP``&0```%'+```6
M````:\L```X```""RP``&````)'+```(````JLL```T```"SRP``)@```,'+
M``!#````Z,L```@````LS```$@```#7,```?````2,P```@```!HS```"P``
M`'',```O````?<P```X```"MS```!0```+S,```&````PLP``$4```#)S```
M`P````_-```'````$\T```0````;S0``"@```"#-```*````*\T```\````V
MS0``$````$;-```7````5\T``!$```!OS0``&0```('-```7````F\T```D`
M``"SS0``!0```+W-```+````P\T```H```#/S0```@```-K-```%````W<T`
M``T```#CS0``&P```/'-```7````#<X``!0````ES@``"0```#K.```.````
M1,X```T```!3S@``$@```&'.```X````=,X``"````"MS@``"````,[.```.
M````U\X``'L```#FS@``&````&+/```8````>\\``!$```"4SP``!P```*;/
M```%````KL\``!@```"TSP``'@```,W/```;````[,\``!D````(T```&P``
M`"+0```9````/M```!,```!8T```!P```&S0```(````=-````8```!]T```
M!@```(30```0````B]````\```"<T```$````*S0```/````O=````L```#-
MT```#P```-G0```,````Z=````\```#VT```!P````;1```&````#M$```X`
M```5T0``#````"31```H````,=$```\```!:T0``"````&K1```(````<]$`
M`!,```!\T0``'@```)#1```A````K]$``"````#1T0``&0```/+1```7````
M#-(``"4````DT@``%P```$K2```6````8M(```0```!YT@``&P```'[2```-
M````FM(```P```"HT@```P```+72```%````N=(```@```"_T@``"@```,C2
M```,````T](```L```#@T@``$````.S2```,````_=(```X````*TP``"P``
M`!G3```$````)=,```0````JTP``$P```"_3```4````0],```P```!8TP``
M"0```&73```.````;],```L```!^TP``&P```(K3```'````IM,```<```"N
MTP``"@```+;3```-````P=,```D```#/TP``!````-G3```%````WM,```,`
M``#DTP``&````.C3```*`````=0```0````,U```)@```!'4```.````.-0`
M`'P```!'U```%0```,34```%````VM0```<```#@U```#````.C4```(````
M]=0```H```#^U```!@````G5```(````$-4```(````9U0``!@```!S5```&
M````(]4``!0````JU0``#0```#_5```0````3=4``!L```!>U0``!````'K5
M```)````?]4``!````")U0``"0```)K5```)````I-4```4```"NU0``&@``
M`+35```(````S]4```8```#8U0``&0```-_5```.````^=4```<````(U@``
M!P```!#6```%````&-8```D````>U@``"@```"C6```.````,]8```(```!"
MU@``!@```$76```+````3-8```T```!8U@``"0```&;6```&````<-8``!(`
M``!WU@``"0```(K6```'````E-8``!0```"<U@``'0```+'6``!"````S]8`
M`"4````2UP``)0```#C7```&````7M<```H```!EUP``!````'#7```)````
M==<```@```!_UP``$0```(C7```)````FM<```8```"DUP``#0```*O7```&
M````N=<```0```#`UP``.0```,77```]````_]<``#H````]V```'@```'C8
M```%````E]@```X```"=V```!````*S8```&````L=@```<```"XV```(0``
M`,#8```-````XM@``!4```#PV```!@````;9```$````#=D``!$````2V0``
M!@```"39```*````*]D``"(````VV0``!````%G9```%````7MD``!T```!D
MV0``!````(+9```,````A]D```X```"4V0``"@```*/9```(````KMD```D`
M``"WV0``!0```,'9```Z````Q]D``#`````"V@``-0```#/:```I````:=H`
M`$<```"3V@``.````-O:```I````%-L``#\````^VP``+@```'[;```M````
MK=L``!\```#;VP``#P```/O;```2````"]P```L````>W```)@```"K<```I
M````4=P``"0```![W```)@```*#<```(````Q]P```H```#0W```"0```-O<
M```'````Y=P``"````#MW```(`````[=```F````+]T```H```!6W0``&0``
M`&'=```I````>]T``!8```"EW0``$@```+S=```'````S]T```H```#7W0``
M#````.+=```/````[]T``!````#_W0``0````!#>``!P````4=X``&8```#"
MW@``#@```"G?```)````.-\```H```!"WP``$@```$W?```3````8-\```P`
M``!TWP``!@```('?```/````B-\``!(```"8WP``$````*O?```1````O-\`
M`!P```#.WP``(P```.O?``!J````#^````\```!ZX```!0```(K@```0````
MD.````D```"AX```!````*O@```+````L.```"````"\X```%````-W@```,
M````\N````P```#_X```#P````SA```5````'.$``"D````RX0``*@```%SA
M```F````A^$``"<```"NX0``*0```-;A```J`````.(``!D````KX@``0@``
M`$7B```1````B.(``!(```":X@``$P```*WB```4````P>(```\```#6X@``
M%@```.;B```7````_>(``!`````5XP``$0```";C```T````..,``!,```!M
MXP``$@```('C```U````E.,``!0```#*XP``!P```-_C```,````Y^,``"``
M``#TXP``$````!7D```4````)N0``!$````[Y```%P```$WD```<````9>0`
M`!,```""Y```%````);D```:````J^0``!$```#&Y```&@```-CD```>````
M\^0``!H````2Y0``$P```"WE```5````0>4``!$```!7Y0``%P```&GE```4
M````@>4``!<```"6Y0``%0```*[E```)````Q.4``!````#.Y0``&0```-_E
M```$````^>4```<```#^Y0``"P````;F```1````$N8```8````DY@``!@``
M`"OF```&````,N8```4````YY@``!P```#_F```'````1^8```4```!/Y@``
M%@```%7F```&````;.8```8```!SY@``!````'KF```$````?^8```<```"$
MY@``#@```(SF```,````F^8```P```"HY@``#0```+7F```*````P^8```X`
M``#.Y@``!0```-WF```H````X^8```X````,YP``#````!OG```/````*.<`
M``H````XYP``"````$/G```)````3.<``"L```!6YP``!````(+G```(````
MA^<``"8```"0YP``$@```+?G```/````RN<```8```#:YP``"@```.'G```'
M````[.<```@```#TYP``(````/WG```)````'N@``!0````HZ```#````#WH
M```-````2N@```X```!8Z```%@```&?H```1````?N@```8```"0Z````P``
M`)?H```&````F^@``!D```"BZ```!P```+SH```$````Q.@```L```#)Z```
M"P```-7H```'````X>@```4```#IZ```!P```._H```6````]^@```T````.
MZ0``#0```!SI```*````*ND``!`````UZ0``#P```$;I```1````5ND``!<`
M``!HZ0``"@```(#I```1````B^D```@```"=Z0``!````*;I```/````J^D`
M`#H```"[Z0``!0```/;I```,````_.D``!X````)Z@``#@```"CJ```0````
M-^H```L```!(Z@``#````%3J```)````8>H```<```!KZ@``"@```'/J```)
M````?NH```X```"(Z@``$````)?J```;````J.H``!@```#$Z@``&@```-WJ
M```*````^.H```D````#ZP``"@````WK```,````&.L```\````EZP``"```
M`#7K```&````/NL``!P```!%ZP``!P```&+K```%````:NL```L```!PZP``
M1P```'SK```-````Q.L```D```#2ZP``!````-SK```#````X>L``!,```#E
MZP``$P```/GK```3````#>P```H````A[````@```"SL```$````+^P``"4`
M```T[````P```%KL```%````7NP``"H```!D[```"@```(_L```%````FNP`
M``0```"@[```"@```*7L```-````L.P```8```"^[```"````,7L```(````
MSNP```0```#7[```!0```-SL``!H````XNP```D```!+[0``#````%7M```0
M````8NT```4```!S[0``!@```'GM```;````@.T``"\```"<[0``$````,SM
M```*````W>T```\```#H[0``"@```/CM```)`````^X``!,````-[@``&P``
M`"'N```8````/>X``!<```!6[@``'P```&[N```.````CNX```,```"=[@``
M!P```*'N```(````J>X```<```"R[@``"@```+KN```+````Q>X```<```#1
M[@``40```-GN```0````*^\```P````\[P``#0```$GO```:````5^\``$H`
M``!R[P``&0```+WO```&````U^\``!H```#>[P``)0```/GO```&````'_``
M``8````F\```'P```"WP```&````3?````D```!4\```&````%[P```7````
M=_```"@```"/\```!@```+CP```-````O_```"(```#-\```5P```/#P```3
M````2/$``",```!<\0``$P```(#Q```"````E/$```L```"7\0``"````*/Q
M```-````K/$```H```"Z\0``!P```,7Q```4````S?$```8```#B\0``"```
M`.GQ```.````\O$```<````!\@``"@````GR```+````%/(``#(````@\@``
M!P```%/R```,````6_(```T```!H\@``#````';R```)````@_(```D```"-
M\@``"@```)?R```'````HO(```D```"J\@``!P```+3R```*````O/(``!L`
M``#'\@``#P```./R```2````\_(```H````&\P``%@```!'S```)````*/,`
M`!`````R\P``!P```$/S```2````2_,```0```!>\P``!P```&/S```%````
M:_,```4```!Q\P``"P```'?S```4````@_,``!$```"8\P``&@```*KS```6
M````Q?,``!0```#<\P``%P```/'S```8````"?0``!P````B]```&0```#_T
M```'````6?0```4```!A]```#0```&?T```,````=?0``!$```""]```"```
M`)3T```7````G?0```L```"U]```#````,'T```?````SO0``!H```#N]```
M$P````GU```$````'?4```H````B]0``!````"WU```-````,O4```P```!`
M]0``!0```$WU```)````4_4```4```!=]0``!P```&/U```%````:_4```0`
M``!Q]0```@```';U```X````>?4``"P```"R]0``$@```-_U```I````\O4`
M`#(````<]@``"@```$_V```L````6O8``"X```"']@``,P```+;V```S````
MZO8``#@````>]P``#P```%?W```8````9_<``!````"`]P``#P```)'W```3
M````H?<``!4```"U]P``%````,OW```2````X/<``!0```#S]P``%0````CX
M```M````'O@``"T```!,^```,0```'KX```N````K/@``"\```#;^```+```
M``OY``!B````./D``!,```";^0``#0```*_Y```(````O?D``!<```#&^0``
M"````-[Y```,````Y_D``"L```#T^0``(0```"#Z```:````0OH```D```!=
M^@``10```&?Z``!!````K?H```0```#O^@``$P```/3Z```4````"/L```X`
M```=^P``$P```"S[```8````0/L```8```!9^P``"0```&#[```*````:OL`
M``\```!U^P``$````(7[```'````EOL```X```">^P``!0```*W[```;````
ML_L```@```#/^P``!@```-C[```4````W_L``!$```#T^P``#@````;\```X
M````%?P```(```!._```!@```%'\```.````6/P```4```!G_```!P```&W\
M```.````=?P```8```"$_```*````(O\```,````M/P``!P```#!_```!```
M`-[\```I````X_P``!<````-_0``'P```"7]``!<````1?T``!0```"B_0``
M/@```+?]```?````]OT``!`````6_@``!P```"?^```.````+_X```P````^
M_@``#````$O^```3````6/X```H```!L_@``'0```'?^```9````E?X```4`
M``"O_@``$0```+7^```1````Q_X``"0```#9_@``$@```/[^```5````$?\`
M`!(````G_P``#@```#K_```9````2?\```@```!C_P``"0```&S_```-````
M=O\```<```"$_P``"@```(S_```'````E_\```\```"?_P``!@```*__```+
M````MO\``!H```#"_P``"@```-W_```'````Z/\```@```#P_P``!0```/G_
M```?````__\```8````?``$`$````"8``0`(````-P`!``T```!```$`"```
M`$X``0`>````5P`!`!(```!V``$`+````(D``0`:````M@`!``D```#1``$`
M"@```-L``0`5````Y@`!``4```#\``$`%`````(!`0`$````%P$!`!`````<
M`0$`!@```"T!`0`'````-`$!`!X````\`0$`*````%L!`0`*````A`$!`!P`
M``"/`0$`$0```*P!`0`+````O@$!`!H```#*`0$`%````.4!`0`$````^@$!
M``0```#_`0$`"P````0"`0`%````$`(!``8````6`@$`"````!T"`0`&````
M)@(!``H````M`@$`&P```#@"`0`T````5`(!`#0```")`@$`(````+X"`0`I
M````WP(!`"`````)`P$`00```"H#`0`:````;`,!`"@```"'`P$`*0```+`#
M`0!0````V@,!`"(````K!`$`!@```$X$`0`(````500!``4```!>!`$`"```
M`&0$`0`9````;00!`!D```"'!`$`*@```*$$`0`C````S`0!`!D```#P!`$`
M+@````H%`0`T````.04!``@```!N!0$`%P```'<%`0`*````CP4!``<```":
M!0$`(0```*(%`0`0````Q`4!``X```#5!0$`"P```.0%`0`'````\`4!`!,`
M``#X!0$`"`````P&`0`+````%08!``H````A!@$`%````"P&`0`/````008!
M`#(```!1!@$`"P```(0&`0`%````D`8!``4```"6!@$`!0```)P&`0`7````
MH@8!``\```"Z!@$`!````,H&`0`*````SP8!``D```#:!@$`"P```.0&`0`-
M````\`8!``P```#^!@$`#@````L'`0`%````&@<!``0````@!P$`#0```"4'
M`0`R````,P<!`$4```!F!P$`%P```*P'`0`'````Q`<!`!X```#,!P$`%```
M`.L'`0`%``````@!`!0````&"`$`!@```!L(`0`'````(@@!``X````J"`$`
M*@```#D(`0`&````9`@!``P```!K"`$`#0```'@(`0`1````A@@!``L```"8
M"`$`-@```*0(`0`*````VP@!`"(```#F"`$`"P````D)`0`/````%0D!`#(`
M```E"0$`)0```%@)`0`P````?@D!`#$```"O"0$`+0```.$)`0`.````#PH!
M``4````>"@$`#@```"0*`0`3````,PH!`!(```!'"@$`!P```%H*`0`1````
M8@H!`!,```!T"@$`!P```(@*`0`4````D`H!`!@```"E"@$`!P```+X*`0`%
M````Q@H!``P```#,"@$`#````-D*`0`2````Y@H!``0```#Y"@$`!P```/X*
M`0`*````!@L!``L````1"P$`#````!T+`0`.````*@L!``X````Y"P$`!0``
M`$@+`0`%````3@L!`"X```!4"P$`)@```(,+`0`C````J@L!``,```#."P$`
M$@```-(+`0`&````Y0L!`!X```#L"P$`&`````L,`0`E````)`P!``T```!*
M#`$`"0```%@,`0`?````8@P!``,```""#`$`!P```(8,`0`*````C@P!``(`
M``"9#`$`#````)P,`0`5````J0P!``L```"_#`$`&0```,L,`0`@````Y0P!
M`!(````&#0$`!0```!D-`0`*````'PT!`!4````J#0$`$@```$`-`0`,````
M4PT!``0```!@#0$`"0```&4-`0`'````;PT!``P```!W#0$`4@```(0-`0`7
M````UPT!`"0```#O#0$`$@```!0.`0`'````)PX!``8````O#@$`#@```#8.
M`0`,````10X!``T```!2#@$`%0```&`.`0`2````=@X!``\```")#@$`%```
M`)D.`0`*````K@X!`!L```"Y#@$`$````-4.`0`+````Y@X!`&D```#R#@$`
M&@```%P/`0`7````=P\!`"<```"/#P$`&@```+</`0`7````T@\!`!L```#J
M#P$`&0````80`0`?````(!`!`!,```!`$`$`"````%00`0`'````71`!``@`
M``!E$`$`"0```&X0`0`5````>!`!``T```".$`$`(P```)P0`0`-````P!`!
M`!,```#.$`$`"````.(0`0`#````ZQ`!`$8```#O$`$`/P```#81`0`W````
M=A$!`%<```"N$0$`!0````82`0`?````#!(!`"\````L$@$`"@```%P2`0`(
M````9Q(!``T```!P$@$`+0```'X2`0`$````K!(!`$\```"Q$@$`)0````$3
M`0`<````)Q,!``L```!$$P$`'P```%`3`0`=````<!,!`"4```".$P$`(```
M`+03`0`D````U1,!`"````#Z$P$`"P```!L4`0`'````)Q0!``T````O%`$`
M#````#T4`0`7````2A0!``8```!B%`$`.0```&D4`0`,````HQ0!``<```"P
M%`$`"0```+@4`0`3````PA0!``D```#6%`$`!````.`4`0`0````Y10!``@`
M``#V%`$`"````/\4`0`$````"!4!``L````-%0$`#````!D5`0`2````)A4!
M`!$````Y%0$`#````$L5`0`:````6!4!``\```!S%0$`!P```(,5`0`-````
MBQ4!`!0```"9%0$`#@```*X5`0`,````O14!`!L```#*%0$`+````.85`0`3
M````$Q8!`!P````G%@$`*````$06`0`&````;18!``<```!T%@$`$P```'P6
M`0`%````D!8!``0```"6%@$`%P```)L6`0`*````LQ8!``P```"^%@$`"0``
M`,L6`0`&````U18!``D```#<%@$`"````.86`0`)````[Q8!``H```#Y%@$`
M$0````07`0`&````%A<!``X````=%P$`#@```"P7`0`-````.Q<!``L```!)
M%P$`'0```%47`0`+````<Q<!``(```!_%P$`'````((7`0`'````GQ<!``8`
M``"G%P$`9````*X7`0`)````$Q@!``<````=&`$`)@```"48`0`X````3!@!
M`!H```"%&`$`*@```*`8`0`[````RQ@!`"@````'&0$`-````#`9`0`9````
M91D!`!4```!_&0$`!0```)49`0`'````FQD!``@```"C&0$`!P```*P9`0`%
M````M!D!``<```"Z&0$`#@```,(9`0`)````T1D!``8```#;&0$`"````.(9
M`0`+````ZQD!``<```#W&0$`"````/\9`0`'````"!H!`!8````0&@$`"0``
M`"<:`0`&````,1H!``L````X&@$`$````$0:`0`&````51H!`!P```!<&@$`
M%````'D:`0`'````CAH!`!$```"6&@$`"````*@:`0`.````L1H!``@```#`
M&@$`!0```,D:`0`0````SQH!``D```#@&@$`$````.H:`0`&````^QH!`!D`
M```"&P$`"@```!P;`0`<````)QL!``<```!$&P$`!0```$P;`0`0````4AL!
M`!0```!C&P$`"P```'@;`0`-````A!L!`"@```"2&P$`&````+L;`0`7````
MU!L!``0```#L&P$`"0```/$;`0`*````^QL!``<````&'`$``@````X<`0`.
M````$1P!``@````@'`$`(P```"D<`0`?````31P!`#@```!M'`$`)@```*8<
M`0`Q````S1P!`"<```#_'`$`9````"<=`0`4````C!T!`%4```"A'0$`.```
M`/<=`0!*````,!X!`%L```!['@$`*````-<>`0`X`````!\!`"@````Y'P$`
M+````&(?`0`F````CQ\!`!L```"V'P$`/@```-(?`0"I`0``$2`!`",```"[
M(0$`%P```-\A`0!(````]R$!`(4```!`(@$`,````,8B`0`E````]R(!`$$`
M```=(P$`6P```%\C`0!)````NR,!`#$````%)`$`'0```#<D`0`8````520!
M`"L```!N)`$`(0```)HD`0`?````O"0!`"L```#<)`$`)@````@E`0`G````
M+R4!`#H```!7)0$`'0```)(E`0`1````L"4!`#,```#")0$`)0```/8E`0`G
M````'"8!`"````!$)@$`'P```&4F`0`P````A28!`&D```"V)@$`,0```"`G
M`0!!````4B<!`#,```"4)P$`)0```,@G`0`]````[B<!`&4````L*`$`30``
M`)(H`0`O````X"@!`"X````0*0$`,````#\I`0!4````<"D!`%H```#%*0$`
M2````"`J`0!*````:2H!`#(```"T*@$`+P```.<J`0`L````%RL!`"T```!$
M*P$`<0```'(K`0!F````Y"L!`&\```!++`$`LP```+LL`0`7````;RT!`"4`
M``"'+0$`,@```*TM`0`I````X"T!`#X````*+@$`(@```$DN`0!2````;"X!
M`"4```"_+@$`"P```.4N`0"Q````\2X!`$4```"C+P$`(0```.DO`0`P````
M"S`!`"4````\,`$`'````&(P`0`Q````?S`!``<```"Q,`$`!P```+DP`0`$
M````P3`!``T```#&,`$`"P```-0P`0`.````X#`!``L```#O,`$`!0```/LP
M`0`0`````3$!``(````2,0$`60```!4Q`0`%````;S$!`!(```!U,0$`!```
M`(@Q`0`'````C3$!``@```"5,0$`!0```)XQ`0`#````I#$!`!````"H,0$`
M#````+DQ`0`3````QC$!``T```#:,0$``@```.@Q`0`'````ZS$!``8```#S
M,0$`%````/HQ`0`,````#S(!`!@````<,@$`!@```#4R`0`2````/#(!``P`
M``!/,@$``P```%PR`0`J````8#(!``0```"+,@$`!@```)`R`0`'````ES(!
M`!\```"?,@$`-0```+\R`0`N````]3(!`"\````D,P$`%P```%0S`0`B````
M;#,!`"4```"/,P$`(````+4S`0`;````UC,!`!@```#R,P$`)`````LT`0`?
M````,#0!`!H```!0-`$`(0```&LT`0`@````C30!`!H```"N-`$`,@```,DT
M`0`:````_#0!`"\````7-0$`*P```$<U`0`?````<S4!`",```"3-0$`'P``
M`+<U`0`:````US4!`"$```#R-0$`)0```!0V`0`F````.C8!`"4```!A-@$`
M)````(<V`0`8````K#8!`!T```#%-@$`)````.,V`0`8````"#<!`"(````A
M-P$`+````$0W`0`O````<3<!`!4```"A-P$`)0```+<W`0`\````W3<!`!\`
M```:.`$`(P```#HX`0`?````7C@!`"````!^.`$`&@```)\X`0`8````NC@!
M`"8```#3.`$`'@```/HX`0`I````&3D!`!X```!#.0$`,0```&(Y`0`)````
ME#D!``P```">.0$`%P```*LY`0`O````PSD!`"0```#S.0$`!P```!@Z`0`/
M````(#H!`!0````P.@$`#@```$4Z`0`-````5#H!`"0```!B.@$`!0```(<Z
M`0`'````C3H!`"(```"5.@$`)0```+@Z`0`:````WCH!`!T```#Y.@$`&@``
M`!<[`0`'````,CL!`,<````Z.P$`"P````(\`0`5````#CP!``8````D/`$`
M"0```"L\`0`+````-3P!``T```!!/`$`%P```$\\`0`&````9SP!`#,```!N
M/`$`$P```*(\`0`3````MCP!``<```#*/`$`#P```-(\`0`'````XCP!`#(`
M``#J/`$`!````!T]`0`A````(CT!`!,```!$/0$`#````%@]`0`1````93T!
M`#(```!W/0$`%@```*H]`0`(````P3T!`!T```#*/0$`"0```.@]`0`*````
M\CT!`!0```#]/0$`"@```!(^`0`=````'3X!``@````[/@$`'P```$0^`0`(
M````9#X!`!H```!M/@$`)P```(@^`0`&````L#X!`!4```"W/@$`!P```,T^
M`0`(````U3X!``D```#>/@$`/P```.@^`0`'````*#\!``\````P/P$`#@``
M`$`_`0`0````3S\!``D```!@/P$`"0```&H_`0`(````=#\!`!,```!]/P$`
M!P```)$_`0`9````F3\!``H```"S/P$`%P```+X_`0`4````UC\!``H```#K
M/P$`#````/8_`0`7`````T`!``0````;0`$`*@```"!``0`,````2T`!`!$`
M``!80`$`!P```&I``0`"````<D`!`!````!U0`$`&````(9``0`+````GT`!
M``,```"K0`$`"````*]``0`&````N$`!``<```"_0`$`#0```,=``0`+````
MU4`!`!0```#A0`$`%0```/9``0`.````#$$!`"\````;00$`(````$M!`0`<
M````;$$!`!4```")00$`#````)]!`0`Q````K$$!``4```#>00$`$@```.1!
M`0`_````]T$!`!(````W0@$`"@```$I"`0`&````54(!``0```!<0@$`!```
M`&%"`0`*````9D(!`!,```!Q0@$`!0```(5"`0`&````BT(!``8```"20@$`
M"````)E"`0`$````HD(!``P```"G0@$`"@```+1"`0`Y````OT(!`"X```#Y
M0@$`*0```"A#`0`%````4D,!`!@```!80P$`&0```'%#`0`?````BT,!`!T`
M``"K0P$`$0```,E#`0`"````VT,!``0```#>0P$`"@```.-#`0`&````[D,!
M``4```#U0P$``P```/M#`0`,````_T,!`$4````,1`$`,@```%)$`0`:````
MA40!`#0```"@1`$`*````-5$`0!3````_D0!`!D```!210$`<@```&Q%`0`@
M````WT4!`#4`````1@$`(0```#9&`0!%````6$8!`#````">1@$`*````,]&
M`0`I````^$8!`"8````B1P$`)0```$E'`0`H````;T<!`"@```"81P$`(@``
M`,%'`0`K````Y$<!`#`````02`$`$@```$%(`0`3````5$@!`!````!H2`$`
M>0```'E(`0`)````\T@!`*$```#]2`$`<P```)])`0!\````$TH!`"L```"0
M2@$`5````+Q*`0`7````$4L!`"<````I2P$`%@```%%+`0`/````:$L!`!<`
M``!X2P$`'P```)!+`0!`````L$L!`!\```#Q2P$`'````!%,`0!1````+DP!
M`!H```"`3`$`%````)M,`0`*````L$P!``4```"[3`$`!@```,%,`0`(````
MR$P!``4```#13`$`$@```-=,`0`0````ZDP!`!,```#[3`$`'0````]-`0`/
M````+4T!``\````]30$`!````$U-`0`)````4DT!``L```!<30$`!P```&A-
M`0`%````<$T!`!0```!V30$`!P```(M-`0`(````DTT!``\```"<30$`"```
M`*Q-`0`,````M4T!``\```#"30$`!@```-)-`0`4````V4T!``8```#N30$`
M#````/5-`0`1`````DX!``@````43@$`!````!U.`0`9````(DX!`!$````\
M3@$`"@```$Y.`0`8````64X!`!,```!R3@$`'````(9.`0`1````HTX!``0`
M``"U3@$`#P```+I.`0`'````RDX!``0```#23@$`&0```-=.`0`'````\4X!
M``(```#Y3@$``@```/Q.`0`1````_TX!``D````13P$`!@```!M/`0`2````
M(D\!`!<````U3P$`!@```$U/`0`G````5$\!``(```!\3P$`!````']/`0`/
M````A$\!`!,```"43P$`!P```*A/`0`'````L$\!`!$```"X3P$`!@```,I/
M`0`8````T4\!``8```#J3P$`$P```/%/`0`0````!5`!`!(````64`$``@``
M`"E0`0`&````+%`!``P````S4`$`"0```$!0`0`1````2E`!`"(```!<4`$`
M!P```']0`0`'````AU`!``L```"/4`$`!0```)M0`0`"````H5`!``L```"D
M4`$`I0$``+!0`0`0````5E(!`!4```!G4@$`#0```'U2`0`'````BU(!``D`
M``"34@$`"````)U2`0`#````IE(!`!@```"J4@$`'@```,-2`0`O````XE(!
M`"L````24P$`*0```#Y3`0`M````:%,!`!D```"64P$`*@```+!3`0`*````
MVU,!`!X```#F4P$`$@````54`0`*````&%0!`!<````C5`$`!0```#M4`0`H
M````050!`!(```!J5`$`#@```'U4`0`3````C%0!``T```"@5`$`"@```*Y4
M`0"2````N50!`!````!,50$`"@```%U5`0`2````:%4!``T```![50$`&P``
M`(E5`0`,````I54!``\```"R50$`%@```,)5`0`&````V54!`)D```#@50$`
M"````'I6`0`-````@U8!`!@```"15@$`#P```*I6`0`0````NE8!`!````#+
M5@$`"````-Q6`0`0````Y58!`#P```#V5@$`%0```#-7`0!#````25<!`$D`
M``"-5P$`50```-=7`0!-````+5@!`'(```![6`$`:@```.Y8`0!&````65D!
M`!````"@60$`%@```+%9`0`.````R%D!`!````#760$`$@```.A9`0`%````
M^UD!``8````!6@$`$0````A:`0`(````&EH!``D````C6@$`"0```"U:`0`E
M````-UH!`",```!=6@$`$````(%:`0`.````DEH!`!$```"A6@$`!@```+-:
M`0`)````NEH!`!L```#$6@$`(0```.!:`0`.`````EL!`!0````16P$`&```
M`"9;`0`E````/UL!`"H```!E6P$`&@```)!;`0`0````JUL!`!<```"\6P$`
M#0```-1;`0`U````XEL!`",````87`$`)@```#Q<`0`1````8UP!`%@```!U
M7`$`-@```,Y<`0`E````!5T!``@````K70$`%0```#1=`0`W````2ET!``T`
M``""70$`"````)!=`0`+````F5T!``<```"E70$`!P```*U=`0`'````M5T!
M``<```"]70$`#````,5=`0`%````TET!`!L```#870$`#````/1=`0`0````
M`5X!`!(````27@$`'````"5>`0`O````0EX!``D```!R7@$`%@```'Q>`0`6
M````DUX!`!@```"J7@$`'@```,->`0`4````XEX!`!(```#W7@$`#P````I?
M`0`A````&E\!`!T````\7P$`!P```%I?`0`&````8E\!``@```!I7P$`#0``
M`')?`0`(````@%\!``D```")7P$`$@```)-?`0`)````IE\!`!,```"P7P$`
M&````,1?`0`J````W5\!``<````(8`$`$@```!!@`0`%````(V`!`!8````I
M8`$`$@```$!@`0`/````4V`!`$(```!C8`$`.@```*9@`0`)````X6`!``<`
M``#K8`$`$P```/-@`0`$````!V$!``4````,80$`#0```!)A`0`*````(&$!
M`!<````K80$`0P```$-A`0`5````AV$!`"0```"=80$`*P```,)A`0`J````
M[F$!`#`````98@$`"0```$IB`0`&````5&(!``D```!;8@$`!P```&5B`0`[
M````;6(!`#T```"I8@$`.@```.=B`0!?````(F,!`#D```""8P$`.0```+QC
M`0!%````]F,!`$4````\9`$`.0```()D`0!2````O&0!`"H````/90$`+```
M`#IE`0!)````9V4!`#D```"Q90$`/P```.ME`0`E````*V8!`!4```!19@$`
M&0```&=F`0`L````@68!`"8```"N9@$`)@```-5F`0`3````_&8!``H````0
M9P$`$0```!MG`0`%````+6<!``P````S9P$`&0```$!G`0`;````6F<!``<`
M``!V9P$`!P```'YG`0`5````AF<!``H```"<9P$`"````*=G`0`T````L&<!
M`!````#E9P$`"@```/9G`0`'`````6@!``8````):`$`!0```!!H`0`(````
M%F@!``4````?:`$`"P```"5H`0`R````,6@!`!8```!D:`$`#0```'MH`0`'
M````B6@!``<```"1:`$`"0```)EH`0`%````HV@!`!$```"I:`$`!@```+MH
M`0`4````PF@!``4```#7:`$`"````-UH`0`&````YF@!``L```#M:`$`!@``
M`/EH`0`B`````&D!``8````C:0$`"````"II`0`4````,VD!``P```!(:0$`
M!P```%5I`0`#````76D!``,```!A:0$`&@```&5I`0`:````@&D!`"T```";
M:0$`!@```,EI`0`%````T&D!``@```#6:0$`"````-]I`0!:````Z&D!`"$`
M``!#:@$`/````&5J`0`L````HFH!`"$```#/:@$`!@```/%J`0`(````^&H!
M`!X````!:P$`)@```"!K`0`Q````1VL!`#8```!Y:P$`*````+!K`0`O````
MV6L!`&T````);`$`.@```'=L`0`*````LFP!``8```"];`$`"0```,1L`0`2
M````SFP!``P```#A;`$`$````.YL`0`6````_VP!`!$````6;0$`%@```"AM
M`0`6````/VT!`!````!6;0$`%0```&=M`0`&````?6T!`!L```"$;0$`&P``
M`*!M`0`7````O&T!`!L```#4;0$`&````/!M`0`&````"6X!``<````0;@$`
M$````!AN`0!<````*6X!`&````"&;@$`!````.=N`0`2````[&X!``4```#_
M;@$`!0````5O`0`<````"V\!`!D````H;P$`%````$)O`0`1````5V\!`!(`
M``!I;P$`&@```'QO`0`Z````EV\!``\```#2;P$`+P```.)O`0`&````$G`!
M`!0````9<`$`#P```"YP`0`3````/G`!``\```!2<`$`&````&)P`0`2````
M>W`!`!4```".<`$`$P```*1P`0`-````N'`!``8```#&<`$`$@```,UP`0`'
M````X'`!``X```#H<`$`%@```/=P`0`/````#G$!``@````><0$``P```"=Q
M`0`0````*W$!``X````\<0$`!0```$MQ`0`3````47$!``H```!E<0$`!P``
M`'!Q`0`0````>'$!``@```")<0$`!````))Q`0`'````EW$!``<```"?<0$`
M#````*=Q`0`(````M'$!``D```"]<0$`&@```,=Q`0`^````XG$!`"8````A
M<@$`#0```$AR`0`0````5G(!``4```!G<@$`'P```&UR`0`1````C7(!`!(`
M``"?<@$`,@```+)R`0!"````Y7(!`"$````H<P$`"````$IS`0!'````4W,!
M`"@```";<P$`$````,1S`0`)````U7,!``H```#?<P$`!@```.IS`0`&````
M\7,!`!(```#X<P$`#@````MT`0`+````&G0!``H````F=`$`#P```#%T`0`L
M````070!`"<```!N=`$`-````)9T`0`O````RW0!`"8```#[=`$`*P```")U
M`0`F````3G4!`"4```!U=0$`/0```)MU`0`R````V74!`"D````,=@$`+P``
M`#9V`0`F````9G8!`#0```"-=@$`1@```,)V`0!!````"7<!`#T```!+=P$`
M/0```(EW`0!'````QW<!`"P````/>`$`*````#QX`0!&````97@!`"H```"L
M>`$`&@```-=X`0`U````\G@!`"@````H>0$`+````%%Y`0`8````?GD!`,D`
M``"7>0$`'````&%Z`0`R````?GH!`#(```"Q>@$`-````.1Z`0`Q````&7L!
M`"D```!+>P$`*@```'5[`0`J````H'L!`#(```#+>P$`-0```/Y[`0!)````
M-'P!`#L```!^?`$`J0```+I\`0`L````9'T!`"4```"1?0$`*````+=]`0`V
M````X'T!`#(````7?@$`60```$I^`0!.````I'X!``T```#S?@$`!`````%_
M`0`&````!G\!``4````-?P$`#0```!-_`0`.````(7\!`!`````P?P$`%0``
M`$%_`0`;````5W\!``<```!S?P$`!````'M_`0`.````@'\!``X```"/?P$`
M"@```)Y_`0`-````J7\!`!,```"W?P$`"P```,M_`0`0````UW\!``P```#H
M?P$`-@```/5_`0`&````+(`!``X````S@`$`!@```$*``0`1````28`!`!<`
M``!;@`$`&P```'.``0`0````CX`!``(```"@@`$`2@```*.``0`+````[H`!
M`!4```#Z@`$`&@```!"!`0`$````*X$!`!,````P@0$`#P```$2!`0`#````
M5($!``\```!8@0$`"````&B!`0`0````<8$!`!````""@0$`!@```).!`0`*
M````FH$!`!$```"E@0$`#````+>!`0`*````Q($!``<```#/@0$`#@```->!
M`0`-````YH$!``L```#T@0$`$0````""`0`:````$H(!``X````M@@$`#@``
M`#R"`0`C````2X(!`!P```!O@@$`/````(R"`0`-````R8(!`!X```#7@@$`
M%@```/:"`0`5````#8,!`#0````C@P$`#P```%B#`0`)````:(,!`!,```!R
M@P$`"0```(:#`0`U````D(,!`#<```#&@P$`#P```/Z#`0`0````#H0!`"4`
M```?A`$`$@```$6$`0`@````6(0!`"````!YA`$`"0```)J$`0`;````I(0!
M`!(```#`A`$`&0```-.$`0`5````[80!``X````#A0$`&0```!*%`0`'````
M+(4!``L````TA0$`)@```$"%`0!(````9X4!``H```"PA0$`%````+N%`0`?
M````T(4!``8```#PA0$`"0```/>%`0`P`````88!`!`````RA@$`!@```$.&
M`0`'````2H8!`%0```!2A@$``P```*>&`0`'````JX8!``8```"SA@$`#```
M`+J&`0`,````QX8!`!````#4A@$`$0```.6&`0`9````]X8!`!$````1AP$`
M&0```".'`0`9````/8<!``@```!7AP$`!0```&"'`0`+````9H<!``L```!R
MAP$``@```'Z'`0`&````@8<!`!(```"(AP$`)P```)N'`0`8````PX<!`!D`
M``#<AP$`"0```/:'`0`3`````(@!`!0````4B`$`'````"F(`0!&````1H@!
M`"\```"-B`$`#````+V(`0`/````RH@!`(H```#:B`$`'````&6)`0`8````
M@HD!`!````";B0$`"````*R)`0`$````M8D!`!<```"ZB0$`*P```-*)`0`H
M````_HD!`!H````GB@$`'0```$**`0`1````8(H!`!,```!RB@$`!P```(:*
M`0`'````CHH!``8```"6B@$`!@```)V*`0`/````I(H!``X```"TB@$`$```
M`,.*`0`.````U(H!``P```#CB@$`#@```/"*`0`+````_XH!`!,````+BP$`
M"````!^+`0`(````*(L!`!8````QBP$`#````$B+`0`U````58L!`!$```"+
MBP$`"````)V+`0`5````IHL!`"4```"\BP$`&P```.*+`0`C````_HL!`"(`
M```BC`$`&````$6,`0`:````7HP!`"4```!YC`$`&0```)^,`0`2````N8P!
M``4```#,C`$`&0```-*,`0`+````[(P!``L```#XC`$``P````2-`0`%````
M"(T!``D````.C0$`$````!B-`0`2````*8T!`!$````\C0$`"@```$Z-`0`/
M````68T!``X```!IC0$`#````'B-`0`$````A8T!``<```"*C0$`(````)*-
M`0`A````LXT!`!<```#5C0$`#P```.V-`0`2````_8T!`!`````0C@$`(@``
M`"&.`0`'````1(X!``D```!,C@$`#P```%:.`0`/````9HX!``D```!VC@$`
M!0```(".`0`*````AHX!``4```"1C@$`$P```)>.`0`,````JXX!``8```"X
MC@$`*0```+^.`0`.````Z8X!`(,```#XC@$`$0```'R/`0`+````CH\!``4`
M``":CP$`#0```*"/`0`&````KH\!``@```"UCP$`!@```+Z/`0`1````Q8\!
M``,```#7CP$`!P```-N/`0`&````XX\!`!0```#JCP$`#P```/^/`0`2````
M#Y`!`!P````BD`$``@```#^0`0`%````0I`!`!(```!(D`$`"0```%N0`0`-
M````99`!``4```!SD`$`(````'F0`0`(````FI`!``8```"CD`$`&@```*J0
M`0`-````Q9`!``<```#3D`$`"````-N0`0`$````Y)`!``D```#ID`$`#0``
M`/.0`0`.`````9$!``(````0D0$`!@```!.1`0`,````&I$!`!,````GD0$`
M$````#N1`0`&````3)$!`!(```!3D0$`"@```&:1`0`'````<9$!`!<```!Y
MD0$`*0```)&1`0!*````NY$!`"<````&D@$`*0```"Z2`0`&````6)(!``D`
M``!?D@$`!````&F2`0`)````;I(!``@```!XD@$`%P```(&2`0`0````F9(!
M``4```"JD@$`#````+"2`0`&````O9(!``0```#$D@$`00```,F2`0!"````
M"Y,!`$$```!.DP$`(0```)"3`0`%````LI,!``X```"XDP$`!P```,>3`0`)
M````SY,!``D```#9DP$`&P```..3`0`0````_Y,!`!4````0E`$`!@```":4
M`0`%````+90!``\````SE`$`"@```$.4`0`*````3I0!`!X```!9E`$`!```
M`'B4`0`'````?90!`"0```"%E`$`!@```*J4`0`4````L90!`!$```#&E`$`
M$````-B4`0`(````Z90!``D```#RE`$`!0```/R4`0`[`````I4!`#8````^
ME0$`0P```'65`0`I````N94!`$(```#CE0$`0@```":6`0`K````:98!`$H`
M``"5E@$`+P```."6`0`Y````$)<!`"\```!*EP$`$````'J7`0`1````BY<!
M``L```"=EP$`+0```*F7`0`I````UY<!`"$````!F`$`*````".8`0`'````
M3)@!``D```!4F`$`"@```%Z8`0`'````:9@!`"0```!QF`$`)@```):8`0`M
M````O9@!``L```#KF`$`&P```/>8`0`M````$YD!`!@```!!F0$`$P```%J9
M`0`(````;ID!``X```!WF0$`#@```(:9`0`.````E9D!`!,```"DF0$`1```
M`+B9`0!^````_9D!`'$```!\F@$`&P```.Z:`0`-````"IL!``X````8FP$`
M$0```">;`0`2````.9L!``\```!,FP$`!P```%R;`0`2````9)L!`!,```!W
MFP$`$@```(N;`0`3````GIL!`"@```"RFP$`'@```-N;`0"$````^IL!`!(`
M``!_G`$`!0```)*<`0`4````F)P!``D```"MG`$`"@```+><`0`*````PIP!
M`!\```#-G`$`%````.V<`0`.`````IT!``X````1G0$`$P```""=`0`5````
M-)T!`"0```!*G0$`)@```&^=`0`C````EIT!`"4```"ZG0$`(0```."=`0`C
M`````IX!`!T````FG@$`10```$2>`0`3````BIX!`!0```">G@$`$P```+.>
M`0`4````QYX!`!$```#<G@$`%@```.Z>`0`7````!9\!`!(````=GP$`$P``
M`#"?`0`\````1)\!`!8```"!GP$`%````)B?`0`^````K9\!`!4```#LGP$`
M#@````*@`0`1````$:`!`"T````CH`$`$P```%&@`0`3````9:`!`"````!Y
MH`$`'0```)J@`0`?````N*`!`!T```#8H`$`&P```/:@`0`A````$J$!`!P`
M```TH0$`(P```%&A`0`A````=:$!`"````"7H0$`(````+BA`0`=````V:$!
M`!,```#WH0$`&P````NB`0`=````)Z(!`!L```!%H@$`&````&&B`0`*````
M>J(!`!````"%H@$`&@```):B`0`&````L:(!``<```"XH@$`#0```,"B`0`4
M````SJ(!``8```#CH@$`!P```.JB`0`'````\J(!``8```#ZH@$`!P````&C
M`0`'````":,!``4````1HP$`%0```!>C`0`&````+:,!``@````THP$`!0``
M`#VC`0`%````0Z,!``H```!)HP$`$0```%2C`0`*````9J,!`!(```!QHP$`
M$0```(2C`0`+````EJ,!`!(```"BHP$`!@```+6C`0`J````O*,!`!$```#G
MHP$`$````/FC`0`:````"J0!`!`````EI`$`#0```#:D`0`,````1*0!`"\`
M``!1I`$`"````(&D`0`(````BJ0!`"@```"3I`$`%````+RD`0`0````T:0!
M``8```#BI`$`"P```.FD`0`'````]:0!``8```#]I`$`(0````2E`0`-````
M)J4!`!`````TI0$`#0```$6E`0`3````4Z4!`!````!GI0$`'P```'BE`0`3
M````F*4!``<```"LI0$``P```+2E`0`&````N*4!`!\```"_I0$`!@```-^E
M`0`(````YJ4!`!(```#OI0$`$P````*F`0`&````%J8!``0````=I@$`!P``
M`"*F`0`6````*J8!``T```!!I@$`#0```$^F`0`+````7:8!`!0```!II@$`
M%@```'ZF`0`7````E:8!`!D```"MI@$`"@```,>F`0`-````TJ8!``8```#@
MI@$`!````.>F`0`1````[*8!`#L```#^I@$`!0```#JG`0`/````0*<!`"$`
M``!0IP$`%@```'*G`0`7````B:<!``X```"AIP$`#````+"G`0`)````O:<!
M``<```#'IP$`"@```,^G`0`)````VJ<!``X```#DIP$`$````/.G`0`@````
M!*@!`"$````EJ`$`)P```$>H`0`*````;Z@!``@```!ZJ`$`#0```(.H`0`,
M````D:@!`!(```">J`$`!@```+&H`0`(````N*@!`"<```#!J`$`"P```.FH
M`0`(````]:@!`!(```#^J`$`/````!&I`0`/````3JD!``L```!>J0$`!```
M`&JI`0`%````;ZD!`!L```!UJ0$`'````)&I`0`<````KJD!``H```#+J0$`
M`@```-:I`0`$````V:D!`"$```#>J0$``P````"J`0`%````!*H!`"D````*
MJ@$`"@```#2J`0`&````/ZH!``<```!&J@$`&````$ZJ`0`.````9ZH!``8`
M``!VJ@$`!P```'VJ`0`(````A:H!``0```".J@$`!0```).J`0`\````F:H!
M`!````#6J@$`$P```.>J`0`5````^ZH!``4````1JP$`!@```!>K`0`>````
M'JL!`#,````]JP$`#@```'&K`0`)````@*L!`!8```"*JP$`"@```*&K`0`(
M````K*L!`!D```"UJP$`+````,^K`0`I````_*L!`"@````FK`$`(0```$^L
M`0`.````<:P!``0```"`K`$`!P```(6L`0`(````C:P!``<```"6K`$`#0``
M`)ZL`0`/````K*P!``@```"\K`$`5P```,6L`0`2````':T!`!`````PK0$`
M"P```$&M`0`;````3:T!`%````!IK0$`'0```+JM`0`&````V*T!`!T```#?
MK0$`)P```/VM`0`'````):X!``8````MK@$`(````#2N`0`$````5:X!``D`
M``!:K@$`*0```&2N`0`H````CJX!`"<```"WK@$`!P```-^N`0`(````YZX!
M`"(```#PK@$`60```!.O`0`8````;:\!`"8```"&KP$`%@```*VO`0`#````
MQ*\!``T```#(KP$`!P```-:O`0`/````WJ\!``L```#NKP$`!@```/JO`0`5
M`````;`!``8````7L`$`"````!ZP`0`)````)[`!``L````QL`$`"@```#VP
M`0`,````2+`!`#T```!5L`$`"````).P`0`2````G+`!`!0```"OL`$`%P``
M`,2P`0`,````W+`!`!````#IL`$`#P```/JP`0`+````"K$!``8````6L0$`
M!0```!VQ`0`*````([$!`"4````NL0$`%P```%2Q`0`0````;+$!``L```!]
ML0$`$````(FQ`0`*````FK$!`!0```"EL0$`"````+JQ`0`4````P[$!``0`
M``#8L0$`!P```-VQ`0`%````Y;$!``4```#KL0$`!P```/&Q`0`3````^;$!
M`!0````-L@$`(@```"*R`0`B````1;(!`!P```!HL@$`'````(6R`0`@````
MHK(!`"4```##L@$`'P```.FR`0`$````";,!``4````.LP$`#@```!2S`0`.
M````([,!`!4````RLP$`"````$BS`0`7````4;,!``T```!ILP$`"@```'>S
M`0`:````@K,!`!\```"=LP$`%````+VS`0`(````TK,!`!(```#;LP$`!P``
M`.ZS`0`0````]K,!``\````'M`$`"````!>T`0`)````(+0!``4````JM`$`
M!P```#"T`0`%````.+0!``0````^M`$``P```$.T`0!!````1[0!`#4```")
MM`$`%P```+^T`0`I````U[0!`#D````!M0$`$@```#NU`0`X````3K4!`#@`
M``"'M0$`/0```,"U`0`]````_K4!`$(````\M@$`&````'^V`0`9````F+8!
M`!8```"RM@$`&````,FV`0`@````XK8!`"`````#MP$`&P```"2W`0`9````
M0+<!`!L```!:MP$`%````':W`0`Q````B[<!`#$```"]MP$`-0```.^W`0`R
M````);@!`#,```!8N`$`,````(RX`0!W````O;@!`!D````UN0$`%@```$^Y
M`0`*````9KD!`"(```!QN0$`"0```)2Y`0`3````GKD!`#0```"RN0$`)0``
M`.>Y`0`@````#;H!``L````NN@$`40```#JZ`0!-````C+H!``<```#:N@$`
M%P```.*Z`0`5````^KH!``P````0NP$`$````!V[`0`6````+KL!``<```!%
MNP$`"````$V[`0`)````5KL!`!(```!@NP$`$0```'.[`0`/````A;L!``X`
M``"5NP$`"0```*2[`0`8````KKL!``@```#'NP$`!@```-"[`0`4````U[L!
M`!$```#LNP$`$````/Z[`0!"````#[P!``(```!2O`$`!@```%6\`0`1````
M7+P!``4```!NO`$`!P```'2\`0`/````?+P!``H```",O`$`*@```)>\`0`,
M````PKP!`!X```#/O`$``P```.Z\`0`W````\KP!`!@````JO0$`*````$.]
M`0"&````;+T!`!@```#SO0$`00````R^`0`A````3KX!`!,```!PO@$`!@``
M`(2^`0`,````B[X!``X```"8O@$`"P```*>^`0`6````L[X!``L```#*O@$`
M'````-:^`0`6````\[X!``4````*OP$`$@```!"_`0`:````([\!`"4````^
MOP$`$P```&2_`0`6````>+\!`!P```"/OP$`$0```*R_`0`F````OK\!``H`
M``#EOP$`%````/"_`0`6````!<`!`!`````<P`$`$@```"W``0`/````0,`!
M`!(```!0P`$`#P```&/``0`5````<\`!`!X```")P`$`%0```*C``0`&````
MOL`!``D```#%P`$`!0```,_``0`=````U<`!``8```#SP`$`$````/K``0`(
M````"\$!`!0````4P0$`!0```"G!`0`;````+\$!``\```!+P0$`+0```%O!
M`0`5````B<$!``8```"?P0$`!P```*;!`0`8````KL$!``4```#'P0$`'@``
M`,W!`0`$````[,$!`!0```#QP0$`!P````;"`0`+````#L(!`"`````:P@$`
M+0```#O"`0`)````:<(!`!P```!SP@$`$````)#"`0`*````H<(!`!L```"L
MP@$`%````,C"`0`$````W<(!`!0```#BP@$`"0```/?"`0`(`````<,!``4`
M```*PP$`"````!##`0`&````&<,!``8````@PP$`(0```"?#`0`W````2<,!
M`#\```"!PP$`(@```,'#`0`P````Y,,!`"@````5Q`$`10```#[$`0`B````
MA,0!`"@```"GQ`$`)0```-#$`0!5````]L0!`"H```!,Q0$`!P```'?%`0`(
M````?\4!``<```"(Q0$`"````)#%`0`4````F<4!`!0```"NQ0$`,````,/%
M`0`M````],4!`!@````BQ@$`-0```#O&`0`]````<<8!``<```"OQ@$`&0``
M`+?&`0`)````T<8!`!````#;Q@$`(@```.S&`0`1````#\<!`!(````AQP$`
M#0```#3'`0`(````0L<!`!4```!+QP$`"````&''`0`+````:L<!``T```!V
MQP$`&@```(3'`0`-````G\<!`#P```"MQP$`"@```.K'`0`%````]<<!``D`
M``#[QP$`!0````7(`0`:````"\@!`!$````FR`$`!0```#C(`0`.````/L@!
M`!````!-R`$`$0```%[(`0`,````<,@!``\```!]R`$`#P```(W(`0`'````
MG<@!``,```"ER`$`#0```*G(`0`Z````M\@!`$X```#RR`$`%0```$')`0`)
M````5\D!`"8```!AR0$`'0```(C)`0`%````ILD!`!4```"LR0$``P```,+)
M`0`+````QLD!`!(```#2R0$`*@```.7)`0`'````$,H!``T````8R@$`#@``
M`";*`0`2````-<H!``L```!(R@$`.P```%3*`0`)````D,H!`!P```":R@$`
M#P```+?*`0`3````Q\H!`#\```#;R@$`+@```!O+`0`Y````2LL!`#H```"$
MRP$`-@```+_+`0`1````]LL!``8````(S`$`$`````_,`0`0````(,P!``T`
M```QS`$`"@```#_,`0`1````2LP!`!T```!<S`$`!P```'K,`0`5````@LP!
M`!H```"8S`$`"````+/,`0`'````O,P!`!$```#$S`$`$@```-;,`0`9````
MZ<P!``8````#S0$`!P````K-`0`/````$LT!`!4````BS0$`%````#C-`0`5
M````3<T!`!4```!CS0$`!P```'G-`0`&````@<T!`#$```"(S0$`)P```+K-
M`0`F````XLT!``@````)S@$`#P```!+.`0`&````(LX!`!\````IS@$`(0``
M`$G.`0`F````:\X!``L```"2S@$`%````)[.`0`F````L\X!``,```#:S@$`
M!P```-[.`0`5````YLX!``,```#\S@$`#`````#/`0`1````#<\!``L````?
MSP$`%````"O/`0`8````0,\!`!0```!9SP$`!0```&[/`0`*````=,\!`!,`
M``!_SP$`%````)//`0`.````J,\!``8```"WSP$`"0```+[/`0`)````R,\!
M``T```#2SP$`6@```.#/`0`6````.]`!`#4```!2T`$`%````(C0`0`'````
MG=`!``D```"ET`$`%````*_0`0`5````Q-`!`!(```#:T`$`(0```.W0`0`8
M````#]$!`!4````HT0$`(P```#[1`0`0````8M$!`"<```!ST0$`$P```)O1
M`0`5````K]$!`'````#%T0$`(0```#;2`0`<````6-(!`"T```!UT@$`(0``
M`*/2`0`<````Q=(!`"8```#BT@$`'P````G3`0`?````*=,!`!P```!)TP$`
M"@```&;3`0`'````<=,!``@```!YTP$`"````(+3`0`3````B],!``\```"?
MTP$`+0```*_3`0`7````W=,!`!4```#UTP$`!P````O4`0`'````$]0!`$\`
M```;U`$`20```&O4`0`^````M=0!`&8```#TU`$`#````%O5`0`R````:-4!
M`#````";U0$`"0```,S5`0`'````UM4!``8```#>U0$`0````.75`0`&````
M)M8!`$`````MU@$`-````&[6`0`C````H]8!``X```#'U@$`+0```-;6`0`<
M````!-<!`#,````AUP$`*````%77`0`R````?M<!`"@```"QUP$`#0```-K7
M`0`&````Z-<!``\```#OUP$`$@```/_7`0`5````$M@!``<````HV`$`0@``
M`##8`0`*````<]@!``D```!^V`$`"@```(C8`0`7````D]@!``D```"KV`$`
M!P```+78`0`2````O=@!``H```#0V`$`"0```-O8`0`$````Y=@!``<```#J
MV`$`"````/+8`0`/````^]@!`!0````+V0$`%@```"#9`0`=````-]D!``T`
M``!5V0$`!P```&/9`0`0````:]D!``\```!\V0$`$@```(S9`0`-````G]D!
M`!@```"MV0$`*````,;9`0`.````[]D!`!\```#^V0$`*0```![:`0`)````
M2-H!``L```!2V@$`%````%[:`0`'````<]H!``0```![V@$`'P```(#:`0`.
M````H-H!``X```"OV@$`#0```+[:`0`(````S-H!``D```#5V@$`!@```-_:
M`0`)````YMH!``L```#PV@$`$P```/S:`0`(````$-L!`!@````9VP$`"P``
M`#+;`0`'````/ML!`!X```!&VP$`)@```&7;`0`,````C-L!``,```"9VP$`
M(0```)W;`0`'````O]L!``8```#'VP$`=````,[;`0`*````0]P!``<```!.
MW`$`)P```%;<`0!`````?MP!`!H```"_W`$`)0```-K<`0!$`````-T!`"D`
M``!%W0$`/0```&_=`0`;````K=T!`!8```#)W0$`!0```.#=`0`&````YMT!
M``D```#MW0$`"@```/?=`0`*`````MX!``D````-W@$`%````!?>`0`+````
M+-X!``H````XW@$`#````$/>`0`,````4-X!``<```!=W@$`"````&7>`0`)
M````;MX!`!0```!XW@$`"P```(W>`0`&````F=X!``4```"@W@$`"P```*;>
M`0`&````LMX!`"8```"YW@$`&````.#>`0`*````^=X!`!8````$WP$`"P``
M`!O?`0`4````)]\!``L````\WP$`!@```$C?`0`6````3]\!``8```!FWP$`
M%@```&W?`0`&````A-\!`!H```"+WP$`"P```*;?`0`6````LM\!``4```#)
MWP$`!P```,_?`0`2````U]\!`"````#JWP$`"P````O@`0`-````%^`!`"T`
M```EX`$`&P```%/@`0`8````;^`!``4```"(X`$`#0```([@`0`4````G.`!
M`!<```"QX`$``P```,G@`0`3````S>`!``D```#AX`$`(P```.O@`0`I````
M#^$!`#,````YX0$`)0```&WA`0`T````D^$!`"<```#(X0$`:0```/#A`0`7
M````6N(!`&<```!RX@$`0@```-KB`0!4````'>,!`&X```!RXP$`+0```.'C
M`0`[````#^0!`#,```!+Y`$`.````'_D`0`N````N.0!`!L```#GY`$`-```
M``/E`0#7`0``..4!`!\````0YP$`%P```##G`0!*````2.<!`'<```"3YP$`
M,P````OH`0`E````/^@!`$$```!EZ`$`7````*?H`0!:````!.D!`"H```!?
MZ0$`(P```(KI`0`6````KND!`"@```#%Z0$`'0```.[I`0`:````#.H!`"T`
M```GZ@$`)0```%7J`0`E````>^H!`#H```"AZ@$`(P```-SJ`0`6`````.L!
M`#@````7ZP$`)0```%#K`0`J````=NL!`"T```"AZP$`'P```,_K`0`X````
M[^L!`&T````H[`$`,0```);L`0!"````R.P!`"X````+[0$`)P```#KM`0!`
M````8NT!`&,```"C[0$`2`````?N`0`N````4.X!`"X```!_[@$`,````*[N
M`0!?````W^X!`&\````_[P$`6````*_O`0!9````"/`!`#4```!B\`$`*@``
M`)CP`0`J````P_`!`"\```#N\`$`:P```![Q`0!Q````BO$!`'$```#\\0$`
MN0```&[R`0`9````*/,!`"\```!"\P$`,````'+S`0`M````H_,!`%(```#1
M\P$`)0```"3T`0!3````2O0!`"(```">]`$`"@```,'T`0#8````S/0!`%@`
M``"E]0$`(P```/[U`0`X````(O8!`"@```!;]@$`'@```(3V`0`Y````H_8!
M``0```#=]@$`"````.+V`0`$````Z_8!`!D```#P]@$`#P````KW`0`/````
M&O<!``L````J]P$`!@```#;W`0`/````/?<!``0```!-]P$`6````%+W`0`$
M````J_<!`!<```"P]P$`!````,CW`0`'````S?<!``8```#5]P$`!0```-SW
M`0`$````XO<!`!4```#G]P$`"0```/WW`0`1````!_@!`!,````9^`$``P``
M`"WX`0`'````,?@!``<````Y^`$`$@```$'X`0`-````5/@!`!0```!B^`$`
M!@```'?X`0`:````?O@!``T```"9^`$``P```*?X`0`K````J_@!``0```#7
M^`$`!@```-SX`0`'````X_@!`"$```#K^`$`0`````WY`0`Q````3OD!`#(`
M``"`^0$`&P```+/Y`0`R````S_D!`#4````"^@$`)````#CZ`0`C````7?H!
M`!X```"!^@$`)````*#Z`0`?````Q?H!`!T```#E^@$`)0````/[`0`C````
M*?L!`!X```!-^P$`-````&S[`0`<````H?L!`#$```"^^P$`,@```/#[`0`A
M````(_P!`"4```!%_`$`)````&O\`0`?````D/P!`"0```"P_`$`*@```-7\
M`0`H`````/T!`"H````I_0$`)@```%3]`0`?````>_T!`"(```";_0$`*P``
M`+[]`0`=````ZOT!`"0````(_@$`+P```"W^`0`R````7?X!`!H```"0_@$`
M)P```*O^`0`\````T_X!`"0````0_P$`)@```#7_`0`E````7/\!`"8```""
M_P$`(````*G_`0`>````RO\!`"<```#I_P$`(P```!$``@`N````-0`"`"<`
M``!D``(`+@```(P``@`*````NP`"`!,```#&``(`%@```-H``@`S````\0`"
M`"8````E`0(`#0```$P!`@`/````6@$"`!8```!J`0(`"P```($!`@`.````
MC0$"`"P```"<`0(`"````,D!`@`,````T@$"`"<```#?`0(`*@````<"`@`@
M````,@("`!\```!3`@(`'````',"`@`(````D`("`-0```"9`@(`#0```&X#
M`@`6````?`,"``D```"3`P(`#0```)T#`@`1````JP,"`!````"]`P(`'P``
M`,X#`@`&````[@,"`$L```#U`P(`'````$$$`@`<````7@0"``<```![!`(`
M$@```(,$`@`,````E@0"`#8```"C!`(`"````-H$`@`G````XP0"`!D````+
M!0(`$@```"4%`@`4````.`4"`#(```!-!0(`'P```(`%`@`'````H`4"`!<`
M``"H!0(`"````,`%`@`)````R04"`!0```#3!0(`"P```.@%`@`;````]`4"
M``8````0!@(`*@```!<&`@`(````0@8"`",```!+!@(`*P```&\&`@`'````
MFP8"`!<```"C!@(`!P```+L&`@`(````PP8"``D```#,!@(`/@```-8&`@`&
M````%0<"`!(````<!P(`%````"\'`@`/````1`<"``D```!4!P(`"@```%X'
M`@`&````:0<"`!,```!P!P(`!@```(0'`@`A````BP<"`!(```"M!P(`&0``
M`,`'`@`5````V@<"``P```#P!P(`#@```/T'`@`:````#`@"``<````G"`(`
M+0```"\(`@`,````70@"``\```!J"`(`!P```'H(`@`#````@@@"`!$```"&
M"`(`'````)@(`@`+````M0@"``,```#!"`(`"````,4(`@`,````S@@"``D`
M``#;"`(`#P```.4(`@`-````]0@"`!8````#"0(`%P```!H)`@`0````,@D"
M`"\```!#"0(`'0```',)`@`<````D0D"`!H```"N"0(`"P```,D)`@`P````
MU0D"``<````&"@(`%P````X*`@!%````)@H"`!$```!L"@(`$@```'X*`@`(
M````D0H"``0```":"@(`!0```)\*`@`1````I0H"`!H```"W"@(`!@```-(*
M`@`'````V0H"``D```#A"@(`$````.L*`@`(````_`H"`!(````%"P(`#@``
M`!@+`@!%````)PL"`#8```!M"P(`*0```*0+`@`%````S@L"`!D```#4"P(`
M)````.X+`@`B````$PP"`"@````V#`(`$````%\,`@`"````<`P"``0```!S
M#`(`"P```'@,`@`*````A`P"``4```"/#`(``P```)4,`@`0````F0P"`$\`
M``"J#`(`,P```/H,`@`:````+@T"`"L```!)#0(`+P```'4-`@!3````I0T"
M`!8```#Y#0(`A0```!`.`@`D````E@X"`$(```"[#@(`)0```/X.`@!'````
M)`\"`"L```!L#P(`,P```)@/`@`N````S`\"`"X```#[#P(`,````"H0`@`P
M````6Q`"`"T```",$`(`,@```+H0`@`T````[1`"`#<````B$0(`%@```%H1
M`@`@````<1$"`!````"2$0(`?````*,1`@`(````(!("`'`````I$@(`<@``
M`)H2`@"`````#1,"`"8```".$P(`7@```+43`@`7````%!0"`",````L%`(`
M%@```%`4`@`2````9Q0"`!0```!Z%`(`'````(\4`@!`````K!0"`!X```#M
M%`(`&0````P5`@!0````)A4"`!(```!W%0(`&````(H5`@`*````HQ4"``4`
M``"N%0(`!@```+05`@`(````NQ4"``4```#$%0(`%@```,H5`@`7````X14"
M`!8```#Y%0(`(0```!`6`@`0````,A8"``X```!#%@(`!````%(6`@`)````
M5Q8"``\```!A%@(`!P```'$6`@`&````>18"`!H```"`%@(`"0```)L6`@`,
M````I18"`!````"R%@(`!P```,,6`@`+````RQ8"`!````#7%@(`"P```.@6
M`@`:````]!8"``D````/%P(`%0```!D7`@`5````+Q<"``8```!%%P(`!0``
M`$P7`@`C````4A<"`!D```!V%P(`"P```)`7`@`C````G!<"`!0```#`%P(`
M*P```-47`@`9`````1@"``8````;&`(`%P```"(8`@`%````.A@"``<```!`
M&`(`&P```$@8`@`%````9!@"``(```!J&`(``@```&T8`@`;````<!@"``@`
M``",&`(`"P```)48`@`5````H1@"`!@```"W&`(`!P```-`8`@`S````V!@"
M``(````,&0(`!`````\9`@`0````%!D"`!8````E&0(`#@```#P9`@`+````
M2QD"``D```!7&0(`!@```&$9`@`8````:!D"``@```"!&0(`%````(H9`@`1
M````GQD"`!(```"Q&0(``@```,09`@`'````QQD"``\```#/&0(`$````-\9
M`@`0````\!D"`"P````!&@(`"0```"X:`@`(````.!H"`!(```!!&@(`!0``
M`%0:`@`"````6AH"``L```!=&@(``0```-`$```:!```+@4``%T#````````
MG`$``&L"``">!````````)(#``#%`0``^`8``'P``````````````(0"```F
M!P``"P$```````!^!P``P0```'0%```3!```[@4``"P```#8`P``O@8``"`'
M```&`@``_P,``+D%``#_!@``+P,```````"D`@``[04``&("``"P`@``#00`
M`'\#````````````````````````TP0``$X%``"#!`````````````#T`0``
M;@(`````````````?0(``"P$````````(P$``*$%````````7P<``.$%``",
M!@``)0$``&T&``#R!```;`(``'`!```P!P``P`$``,\"```M!```;0,``$L'
M``!:````H@$``#,!``"&!P```````'L!``#K````DP8``+T%``!9!P``1P4`
M`,D&````````D@0``&`"``#R````)P(``&0"````````V`0``($&``#;!0``
M``````````"E````````````````````E@,```````!`````X08```````#+
M`0```````,L%``!&`@``O`4```````#[`@``A0<````````)!0```````$T$
M``#)!0``Z@(``",%```7`````````#0```!8````NP$`````````````LP(`
M`%@$``!C`P``:`,``%\!````````````````````````^`$``&(#``!O````
MU`$```````!Z!@````````4'``"0`````````$L#``"9`@```````!H#``!:
M!@``\@$``-\````F`P``V@$``,X!``"T`P``10,````````8!P``#@<``",#
M``#Q````K04``,\$`````````````*D#``"D`````````,@%``!?`P``=P,`
M`),$```(!````````(<&``"^`0```````-X$``!U!P``U@,``.4!````````
M_`4``$<'``"I`0``5@0``.(!````````3P```)L$```````````````````M
M`P``:0<```````"R`````````)4%``!E!```H08``.`!``"N!@```````"H`
M``#Y`0``:`$``%$'``#7`P``)@8``*$$``!1!@``5`0``*P&````````FP(`
M`%L```"/!@``B0,``*D`````````J04``-,```">`P``>@$``&4"``#``P``
M)0<``'D#```K`````````#8``````````````"\"``"#````X00```````#S
M!```=P0``$$'````````]P``````````````D0(``+<%````````%`4``*@#
M```I`@``=P<```````!R!```.0(`````````````C@(``(X!``"(!```W```
M`'D'``!4!0``F`,```$"```X!P``7`,```8!````````0P0````````J!P``
MG0,``*4!`````````````&0%``!Q`0````````````!`!@``VP```#H'``!*
M```````````"````````*0$```````!4`P```````)H$````````R@$``%\$
M```4`P```````"4$``!A```````````````C!```=P```.L#``!C!@``````
M`)D&``#]!0``>P`````````6!@``KP0```,`````!P``V@4``+0&``#'`P``
M>@(``!,'``#L``````````````!C`0```````.P"``":````D@```)P#````
M````FP$``"@%``!O`@``\`,``$0#``"\`@``N0$``-H$``#3!@``L@,``.`$
M``#'!```J`0````````5!P``%0(``+T$```8`0``KP(`````````````WP,`
M`(T"````````?@$``/L%``!I`0``%`8``/8!```H`P``20,``'`#``!%!```
ME@$``$<```#&`0``;P,``$L&```Z````708``%,```#2!@``=`(````````K
M!0``)`(``'`&``#M````"`8```0```#B`@``?`,``(`%``")`0``D00``/P"
M``!A!P``Y`4``!<!````````GP$```H'``!Y`@``?@````,$```&!P``*P8`
M`#(&````````4`(``+\`````````=0,``/T#````````"P```#`%````````
M`````&,'```E!@``W0````````#R`@``/`<```````#5`P``UP0`````````
M````:`````L"``!O!@```````-`&``#"!@``<0```*````#Y!@``0`(`````
M``"9!```MP,``,`````"!```#`8``$P!``"2`@``M@4``*`!``"_`0``````
M``4`````````20<``-0"``!C`````````,0```````````````````#O!```
M`````#T%``!L!P```````,H&````````%0,``'X&`````````````$\%````
M`````````/`$``!U!```H`8``&T$```(````7@```$4'``"X`P``<P4``-X`
M``""`P``(@0``#@%``#T!@``F@,``'4"````````:@$``#P"``"[!@``ZP4`
M`+P$````````;`8```````")````HP(````````Q!@```````!D'````````
M50$``"`$```X`0```````&L$````````A0(``'8%``!]!0``U@`````````?
M`@``3`8``#4$```Q`@````````````"5`P``_`0``/T&```%`P``9@8`````
M``#O`0``Q@```.T#``"/````6`<`````````````Y`8``(,#````````````
M`-L"```L`P``5P$``/$&````````XP$``/X```!-````R@0```T%````````
M-@$``(X#``!]`0``EP```%<$``!]!```<P```*0%``!6`@``@`(````````_
M!@``=@$``/P!````````Y`0````````D`````````/4$``!I!````````%D!
M```?!```!@```)T"``!<`@`````````````!!@``D04```````#>!@``C`,`
M`#X````K`0``$@(``-0#``".!@``/0<```````!J`P```````(P$``"C````
M`````,,#``!1````NP(``"H$```>!```Y@0````````J!@``]`(``"P&``!5
M!0``````````````````IP(``"(#`````````````+,!````````?0```"4#
M````````;P<```````"/!````````,P!``#M!@``"`$`````````````````
M```!``!)!0``-@8```````#&!0``$0$``%T$``#X`P``G````*X#``#"`0``
M`````',$``!O!```U0(``,<%``!\`0``C`$``````````````````/H%```S
M!````````#L'``"B!@``S@,``*4&``#K`0``I@````````#M`@``````````
M````````JP0``.D!``#V!```W`,``"8$````````9`0``)\````-!@``MP0`
M`.<#````````Q@0``%D"``"*!````````,("``"[!0``/P4``'$'``#3!0``
MD`8```````!@!P`````````````9!````````/$#``!4````V0````````!(
M````E@````````!4`@``-P```!T&```Z`@``<0(```````#Q`@````````8$
M``"U`@``HP0``'0'````````UP8``!4`````````U@0```````#\````````
M`!P%``"(!0``]0$``/0%``!Z`P``U08``+$%``"2!0````4`````````````
M``````````"!!```O0(``,P"```)!P``EP,``/T"````````\00``#T"``!3
M`0```````,,$```R`0```````,D"``",``````````````!+`0``````````
M``"W!@``"0$``-P!```D!```H@,``,H%``!S`0``,00```X&``")!```8@``
M```````O````G08``#8"``!7`@``?`<``$0'``"*!0``&0````````"M````
M[`,``,X&``!Y!0``,@```+H%``#(`@```````/,&``"S!@``6`4``$0!````
M`````````!L"```;!P``V`8````````+!0```````&`!```W`@``00(``+H!
M``!^`P```````"H!``!&````S@(``!$&````````?P```$`#```R!P``+0$`
M`"\$``#?`0```````,\%``"R`@``Y@$``%(#``#U`P``>P0```````"@`P``
MT@(``&`#``#H!0````````````!?````'0(``#`#``#Z`@```````'$$````
M````?08``#0%```W!0``%@0```````!V````H0,```````"4!0``7P4``!`"
M``!L`0``(@$```````".`````````&<%````````P@4``!H!``#>`0``````
M`)$#``"8`````````((%```8`````````"D%``"$!````````!P```"6!@``
M908``/D"``"%`0```````$H#``!E!P``>`0```X$``!E````404``,$&``!R
M`@``X```````````````M0,``',#`````````````````````````````%P!
M````````-0<``'P"``!L``````````````"&`@```````,L&```)`@``#`4`
M`&T!```K`@``W04``.4"``!-`P``#0$``&````!G`````````+P&``#7`@``
MM@8``````````````````.H```"P!```*``````````L!P```````/,```"G
M!0``^P$``-($```:````````````````````8`0```````#%!@``7`8``$X`
M````````$0(`````````````2`0``!,&```C````/P```'\%``"F!```M@(`
M`(X%``#D````0`0```````"U!0``/@4``!\!``"X`0```````)@%````````
MM0```/X&```H!P````````````"N!````````&8'``!X!0``9@``````````
M`````````,L$```'`0``5`8`````````````W`8``%T'```[`0``.00``',"
M``#H!@``-P0``!P'``#Z!@``;@8```P!````````1`8``)H&``"Z!```8@8`
M``8%``!"!P``````````````````<0,``(L```!V!P``T`,``/\!``"C`0``
M*@,```````"Q!````````"$'``#_`@``Z0(``'````!J!@``V`````\&``!#
M`P``6@<``/`%``#E!@``S@0``#T#````````^`4``&('``"<!@``T`(`````
M``!K`0``T0```(8&```P````Q@(``)\$``#J`0``X@```&@"``"F`0``6@(`
M```````V`P```````%@&```I!```7@,``-X%````````SP```),%``#4!@``
M0P(`````````````E0$`````````````!`8``$,%``#[!@```````$<#``!I
M!0``4`<``-$!``"``0````````````````````````````#Z!```:@0```0$
M```\`P``'00``-P$````````6@,``'P$```/`@``*08``,@$```9`P``````
M`'L&``!U`````P,``)$!````````K``````````"`@``>0$``"<$```Q!P``
M`````'H```!T``````````````!B`0``5`$```T````_`0``VP,``+$&```T
M!P`````````````F````````````````````A04``(T$````````1`0``/X%
M````````LP```%`!``"-!@``L@$``!0"``!.`@``A0,``&L'``#S`@``M@``
M`.\&``#N`P``40$``-\$``#L!````````,P&````````+0(````````(!P``
M4`````````!2`@```````$@&``!_`@```````!D&````````\`8``(@&``"[
M````608```````#W`0``A````$,&````````=0$`````````````0@(``$@!
M```3`P```````"0!``!7`P``]0```)<%``!0!0``V08``#D!```6!P``````
M`(@!``!9!0``500``#X'``"8`@``.P,```\#``"K!0``20$```````"=!```
M`````#X!``!J````>P4``*4#``"D!@``(`````````"N````2P```!(```"D
M!````0$``'4&````````TP$``+H```#A`P``M@$`````````````9@0`````
M````````O@```+D```!P!````````!$```!<!0``XP0``!X#``"K`0``Y@``
M`"`"``";!@``O`$``/`!```W!@``?P8```````"!````$`0``+D"```[!```
M?P$``!L```"Q`@```````+L#``!R!0``8P(``(4`````````RP(``,`&``!\
M!0```````%4"``"<!0``[@$``*L#````````AP4``'(!``"Q````?P0`````
M``#L!@````````T'``!M`@```````.H#````````#@(``!0!```K`P``0@0`
M``````!_!P``W0(```````!X!@``1@4```````#8!0``A00```````!;!P``
M]0(``*T$```#`@```````"$```#Y!0``=P$``#H#```'!@``\04``.X"``!N
M!0``M@,```````#2`P``Y@(``%4&````````>00``#\#````````*`(``)D%
M``##!0``UP4``%X%`````````````/P&``!W!0``10(``#P```"\````````
M```````-`P`````````````,!P``-`8``!($`````````````%\"```$!P``
M,0,```````!``0``.@4```````"7!@````````````"'`0``R0```.8#``#@
M!@``O0```(L!``"[!````````#0#```S`@``&@4```````"#!@``K`0```4"
M``#H!```O0,``````````````````$<$``!-!@``LP0``'`%``#"`P``````
M`&D#``#8`0``L`$```````"0!0```````,8&``"?!0````````<#``![`P``
M$P````L$``##`0``"00````````_`@``50```.`%````````J@,```$#```7
M!````P8`````````````YP0``.D%```(`P``I04``+4$```6````4@0``#<!
M``!2!0``H@(``/<"````````?@(``"`%``#Y`P``0P$``&@$````````````
M`#P%```3`0```````.\#``#$!```N@8```````!&`P```````,L#``!:!0``
M>@0``#H&``#Y````&P4``$8!````````JP```%8!``#E!```C0````````#,
M`P``-08`````````````RP```(<```#:`P````````````#)!````````$X'
M````````%@4```````#D`P``,0```,H#``"&!0``$`$```X```!G!P``IP``
M`,P$``!>!P``%08``-H````A`0``H`(``)8"``!<!```*P0``!\'``!E`0``
M=@(``!`'```;!```U@4``)H"``!=`````````-T$``!C!0``/`8``.0"````
M````KP4````````"`P``'`0```````````````````$%````````DP$``((&
M``!R`P``K0,``/8&````````D`0``(,"```;!@```````-D#````````6P$`
M`%<'```2`P``[P(``"\'``!Q!0``I@,``%T!```H!@``````````````````
MJP8``-T#``!,`P``^00``#8'``!V!````````"P%``!D!@``U````)X"``#W
M`P```````"4%``""!P``Z@4``'`"````````*0`````````$`@````````<'
M``#B!````````$X&`````````````",'``#_!0```````$0"````````````
M``````#5`0``S0```#4#```$`0```````"<'``!N!P``7P8```````!^!0``
M;@$``*T"``#"!```+`(``%,$``````````````````"!!0``$00``(\"``!3
M!@``T@```*P#``!%!@``,P<``'@'````````S00``!@%````````N`0`````
M````````@@$`````````````(0(``%H!````````%P<``"X'```>`@``I@(`
M`"('````````.`0``(<"``!K````[@8``#8%```\`0``#@4```````#B!0``
MB@```!P!``"I!```AP,```,%````````'P4``%L"````````Z`$```````#W
M!````````-T!``!$!0```````!`&``"(````YP(``#($``#B`P``J`4```H&
M``#%`P```````#T$``````````````````#H`@``GP,``/P#```5!0``,P``
M`/,%``!S!P```````&L&````````R0,``&\!```<`P``5@4```````"&````
M@P$```````"T````C0,``(($```N!```MP$``)<"``"=!0``M`(``.,"````
M````,`0``*$````J`@``Q@,```D#````````B04````````8!@``J@0`````
M`````````````&@%````````U@$````````,!```!08````````E````W@,`
M`)X``````````````&\%```<!@```````!4!```[!0``'0```,H"``";!0``
MA08``(P"```>!0``E`(````````]!@``/@8``*$!``">!0``)0(`````````
M````+0```$8'``"3`@``4`0`````````````,@(``/4%``!T`0``6P,``#4!
M````````3`0``%,%``"@!```"0```,`%``"!`P```````%@!``!G`@``Z0,`
M`!<"````````P`(``%8'``!!`P``.@0``)`!``#D`0``X`,``$\$````````
M`````*H"```,`@``&@(``$X!``!&!```"@````````!)!@``^@$``"X```"-
M`0```````"D'``#K`@``YP$``,T!``!J`@````````````#8`@``P0(``"<`
M``"Q`P``CP4```````!N````$`````````"+!```&P$``&X$``!R!P``_@(`
M`-P%``!/!P``L`,```,'``"+`P```````(L"``!G`0``@`,``+T!``!S!@``
M;`0``*H```!,`@``804```````"*`P``*P<``(`$````````N@,``#P$```6
M`@```````#4"``"0`P``@@```/X#```````````````````-`@``$P(``,(`
M``"Y`P```````,T&```M!0``[@```+X%````````104```\'``!5!P````0`
M`%X!`````````````-<!``!&!@``[@0``&D&```U!0``-P<``)H!``#A````
MN@(``+P#```4!`````````````"6!0``YP4``/(#````````/P<``!<#``#I
M!```DP,````#```&!@``B@8```````!H!@``7`<``"X!```C!@```````&$&
M``!G`P```````%L&``"S`P``"`(``$<"```?````"08``&0!````````````
M`$T"`````````````*,%```N!@``L0$```````#0`0``,@4``(8!``!<````
M`````#@&``#C`P``%P4``+D$``"K`@```````(````!X`P``A`8``,4%``"`
M!@``VP$``#,#``#M`0`````````````,````E`,``&$"``"<`@``[P4`````
M`````````````&($`````````````.D```"S!0``G@8````````>`0``OP,`
M`#D&``!M!0``A`$``&D"````````2P0``.,&````````PP8``(\!````````
MPP```!H'````````800``'`'````````"@4``#T!``!,!P``:P,``!\&``!$
M````$@<`````````````U@(``$D````Y`P``%00```````#O````9P8`````
M```'!0``40,```0%```A!0``L@8``*<$```%!```1P$``$$&````````````
M```````=!0```````+````"O````+08``.L&``#C`````````"`&```0`P``
MOP0``-8&`````````````'T#```*!```%@,``*P!`````````````-\&``#.
M`````````)(!``![!P``PP(``/\$````````-`$```````"H````+`$```P#
M````````C@0``!D!``"B````304```````#F!@``TP(`````````````````
M``<$``"9`0``F0,``*H!```*`@``T@4``/(%``#S`0``"P,```````"=`0``
MQ0````````#$`@``5P```#@````F`@````````````#[`P``I00``+@%````
M````OP4```````!/`0``'0$``.D&``#U!@``E`0``$X$````````K0$`````
M````````I`$``*8%``"N`@``8`8```````#3`P``$P4``*0#````````&`(`
M`/T$````````@P<``'T'``#.!0``X0$``*D&``#A`@``O08``*D"``!N`P``
MC04``*\!````````T`4``)\&````````L@4```````#,!0``:@4```````#V
M`@```````-H&`````````````!T#``!Z!P``L@0``*,&````````P04``*<!
M``!#````FP,``!D"````````2@0````````"`0``E0(``$P%```^`P``=@8`
M`-H"````````0P<``&`%``!\!@``0@,``.4```!*!0``OP8`````````````
M``````````#0````60,``+<```!W`@``0`4```````!/!@``U`4``$@"```]
M````*@4```````!W!@``W@(``%X$```8`P``````````````````P00`````
M``#1`P``X`(``'8#``"4````A`<``!@$````````````````````````/P0`
M`!<&`````````````$T'````````)P,``/T```!5`P`````````````>!P``
M3P,``#@"``"3````\0$``%,"````````]@,```L&````````EP0```````!"
M`0``70(``$D$``!(!P``:P4``*\#````````@@(``$H&````````)@$`````
M``#9`0```````*X%``!M!P``V00``&8%``"P!@``)`4``#D'``!`!P``2`,`
M`&<$``#-`P```````&8"``"L!0``?@0``'0#``#/`P``3@,``)@!``#?`@``
M2@(``,`$````````A@0``&@'``!R````````````````````^`(````````O
M!0``9@,```('```A`P``>08```````#E`P``E00``+4!``#'!@``S0(``"@!
M``"7`0``R0$```````!3!P``40(``%@#``"#!0```````"X"``#X````F0``
M``````#,````K`(``#$%````````UP````````"B!0``````````````````
M(@8``)4&``#L`0``'P,``#L```"4!@``00$``,0#``"*`@```0<``!(%``!B
M!0``````````````````(`,``(@"```>````@`<``%('``"J!0``10```'(&
M```V!```P0$``-(!``!"````8P0``"0'``!L!0``\@8``%8````.`0``]P4`
M`$L"``#[!```6`(``*`%```"!@``Y@4``"(```!"!0```````$<&``"6!```
MF`8``+\"```!!`````````````"Y!@``;`,``!(&``#J!@```````'H%``#H
M````,@,``%<%```/!0``#P$``!P"````````904````````O`0``.P(``$T!
M```P`0``(P(``-4`````````(@4``&0#``#V````>`(``(L&````````````
M`*$"````````K@$``/H#``!A`0``N````)$```````````````````"5````
M)`,```\``````````````(@#````````>P(``,0%``#$`0```````(0#```=
M!P``G@$```````#9`@``QP$```H!``!3`P``>0```-$$``#!`P```````,@!
M```1`P``````````````````:@<``.T$``!T!```!@,````````[!@``U00`
M``````"?`@``;0```(P%```4!P```````%0'```H!````@```%X"```9!0``
M`````/8%``!+!0```````,@````*`P``B0(```````"C`P``!04````````W
M`P``_0$```L'``!;!```!P(```````!,````F`0``,\!```F!0``Y04`````
M``!X`````````&8!``#P````[`4``$D"``"T!0```@4```````!2````Z`,`
M`$@%``#1!@``.0```,4$``":!0``O@(````````#`0``=`8``$$%``#;!@``
M```````````'````,P4``"D#``#Z````Q`8``!$'````!@``R@```'@!```2
M`0``]`,``.,%``"G!@``400``%(!````````!`,``+<"``!*!P``%````(\#
M``"H`@``6@0``-0$```X`P``+@,``/0````^!````````-P"``"M!@``````
M``````#9!0``7@8``+X#``#(`P``Z@0``%D$``"4`0``A@,``&0'``"!!P``
M```````````0!0``B08``*($```M!P``B@$``$$$``";````'@8``/`"``!Q
M!@````````````"T!`````````X#``#G!@``704```````#X!```D08``-\%
M```G!@````````````#T!````````+@"````````M`$``$(&````````J@8`
M`%(&```Y!0```````$$````T!````````#`"````````_@0```````"+!0``
M&P,``*4"`````````````%`#```D!@``T04``/<&````````J`$``&$#```/
M!`````````````!0!@``)P$``+`%````````X@8``-$"````````A`4``($"
M``"U!@``5@,``($!````````ZP0``"("``#/!@```````#4```"X!@``QP(`
M`*<#``!9`````````#$!````````W08``*\&```(!0``10$``%<&``"V!```
M,P8```````!6!@```````&0````A!@``Q0(```````"=````_P````4!```^
M`@``AP0``&D```#5!0``(`$``)P$````````D`(``!$%````````.@$``,T%
M````````%@$```````!U!0``QP```,@&`````````````%L%```A!```\P,`
M`"<%``#G````O@0``*8&```:!@``2@$``"\&``#^`0``90,``-L$```T`@``
M``````````#[````J`8``)(&``!/`@```````#`&````("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E
M<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X
M:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`
M)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@
M)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D
M<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H
M;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN
M`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE
M+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N
M="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@
M3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D
M9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K
M.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@
M=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S
M:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T
M96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E
M<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`
M069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N
M;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`
M06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE
M(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E
M/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA
M=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E
M<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R
M;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A
M<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`
M06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`
M07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS
M:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@
M9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E
M(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM
M97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X
M:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S
M=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q
M=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@
M1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@
M5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA
M8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!2
M97%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T
M:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T
M:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B
M86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO
M<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M
M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L
M861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N
M:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L
M:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@
M5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI
M8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!"
M;W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!)
M;F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-2
M0P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN
M`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`
M0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O
M;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO
M="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA
M;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R
M=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I
M;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`
M0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@
M4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN
M80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U
M97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@
M9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E
M;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`
M0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B
M87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC
M:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI
M8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`
M0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N
M<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O
M;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@
M<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S
M(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E
M<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$
M86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R
M;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E('!E<FUI<W-I
M;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@
M86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T
M960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@
M=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B
M;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F
M:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@
M;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG
M:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@
M,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL
M960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O
M<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T
M(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H
M<`!$;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_
M($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!2
M97!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL
M;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I
M;`!%36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W
M:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%
M9&ET($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R
M;6ES<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS
M(&9O<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I
M;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16P@4V%L=F%D;W(`16QE;65N
M="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL(&%D9')E<W-E<R!M
M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO;@!%;6%I;"UT;RU3
M35,@1V%T97=A>0!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S
M=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I
M;6%G97,@9G)O;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I
M9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET
M;W(`16YT97(@82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B
M92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E
M+F<N("=W:&%T(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H
M92!I;6%G92!54DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17%U
M871O<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!C<F5A=&EN9R!B
M;&]C:SH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!A;F-H;W(Z("5S`$5R<F]R
M(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O;G1E;G0Z
M("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W:71H(&5M
M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI
M;W!I80!%=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M
M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y
M($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V
M86QU97,Z`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D
M("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D('-E87)C:"!T97)M
M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D
M(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL
M960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE
M8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&
M86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE=R!3
M05-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE
M9"!T;R!R971R:65V93H@)7,`1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV
M:6YA<RD`1F%R;V4@27-L86YD<P!&871A;"!%<G)O<CH`1F%X`$9A>&5S`$9E
M8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3:&]W97)S`$9E
M=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I9VQE="!#05!40TA!`$9I
M9VQE="!F;VYT`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@
M0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S
M96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T
M960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`
M1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E
M>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@
M<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H
M;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@
M9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U
M;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R
M;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&
M;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O
M<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H
M(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S
M8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O
M('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@
M0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`
M1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`
M1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R
M965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`1W)O
M=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM96UP
M='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI<R!I
M<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'
M=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U
M:6YE82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F
M=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A
M(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I
M;B!T86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO
M="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A
M9&5R<P!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5A=GD@
M5"U3=&]R;0!(96)R97<@*$E33RTX.#4Y+3@M22D`2&5I9VAT`$AE;'``2&5L
M<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`2&5R92!I<R!T:&4@
M8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE`$AO;'D@4V5E("A6
M871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@1&ER
M96-T;W)Y`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO
M<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN
M(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N
M9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP
M92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S
M9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT96=R
M871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT96YS
M:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E
M92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E
M("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA
M8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N
M=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_
M("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@
M=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!4"!M
M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A
M:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N
M`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0
M(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC96QA
M;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT`$ED
M96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R96-T
M;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@9&]N
M)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@>6]U
M(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.1R!T
M<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N;R!I
M;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B92!D
M:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!);6%G
M92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O
M;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E<"`E
M9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S97)T
M(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R
M<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R
M;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L
M<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`26YD
M;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R
M(&%V86EL86)L92X`26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E
M`$EN<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@
M0F5F;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@
M;VYE`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E
M<G0@82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M<&%R86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R
M86=R87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA
M=&4@=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@
M>6]U(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL
M(&%F=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R
M`$EN<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@
M<&%R86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R
M="!R;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U
M:7)E9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O
M36]D:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@
M8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U
M9F9I8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(%I)4"!D871A`$EN
M=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N`$EN=F%L:60@
M9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RX`
M26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&QI8V5N<V4@:V5Y+@!);G9A
M;&ED(&QO8V%T:6]N('!R;W9I9&5D+@!);G9A;&ED(&US9U]T>7!E+@!);G9A
M;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I;F<@<&%R
M86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV86QI9"!P
M87)T;F5R(&ED+@!);G9A;&ED('!R;V1U8W0@8V]D92X`26YV86QI9"!P<F]T
M;V-O;"X`26YV86QI9"!R96-I<&EE;G0Z("(E<R(`26YV86QI9"!S:&%R92!O
M8FIE8W0`26YV86QI9"!S;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E
M(&1A=&$N`$EN=F5N=&]R>0!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES;VQA
M=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY`$IA;6%I
M8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I`$IE<G-E
M>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT97(`2G5S
M=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA>F%K:'-T
M86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R(')E:F5C
M=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@0W)E871I
M;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S
M86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E
M<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!2
M97!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%54,M2U(I
M`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@4&%S<W=O
M<F0@0VAA;F=E`$QA<W0@475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G
M:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V
M97(`3&%T=FEA`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E
M<@!,96)A;F]N`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H
M;P!,979E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT
M96YS=&5I;@!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%
M87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@
M4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E
M<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I
M;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG
M`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F
M;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A
M8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE
M<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,
M:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!F86EL
M960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`
M3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@
M5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]F('!R979I;W5S('-Y;F,@<V5S
M<VEO;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B
M96-A=7-E('EO=7(@=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@
M:6YC;W)R96-T;'DN`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W
M`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E
M<B!R;VUA;B!N=6UB97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T
M=&%C:&UE;G0@8V]N=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N
M:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A
M<@!-86=I8P!-86EL`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`
M36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@
M;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A
M;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-
M87`R-"!M87``36%P475E<W0@;6%P`$UA<'!I;F=S('-T;W)E9"X`36%R8V@`
M36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@
M;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L
M;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N
M:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X(&UE<W-A9V4@
M<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-87@@
M=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N
M`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=&AO9"`B)7,B(&ES(&YO
M="!D969I;F5D`$UE=&AO9"!N;W0@9&5F:6YE9"X@0V%L;&5D(&UE=&AO9#H@
M)7,`365T<FEC`$UE>&EC;P!-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S
M(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN('1E;7`@;&%S="`R-"!H;W5R<SH@
M`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E
M(&AA<R!N;W0@>65T(&5X<&ER960`36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES
M<VEN9R!014%2('!A8VMA9V4@2%144%]297%U97-T+@!-:7-S:6YG(&-O;F9I
M9W5R871I;VXN(%EO=2!H879E('1O(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@
M=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A=&EO;BX`36ES<VEN9R!M97-S86=E
M($E$+@!-:7-S:6YG(')E<75I<F5D(%!%05(@<&%C:V%G92!-86EL+@!-:7-S
M:6YG('-E<W-I;VX@240N`$UO`$UO8FEL92!-86EL`$UO9&5R871E`$UO9&EF
M:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;&1O=F$L(%)E<'5B;&EC
M(&]F`$UO;F%C;P!-;VYG;VQI80!-;VYT:"!A;F0@>65A<@!-;VYT:&QY`$UO
M;G1S97)R870`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]R;V-C;P!-;W-T;'D@0VQE
M87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N;GD`36]V92!$;W=N`$UO=F4@
M3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@=7``36]Z
M86UB:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&ES=',`375L=&EM87`@
M54L@;6%P`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY($%C8V]U
M;G0@26YF;W)M871I;VX`37D@4&]R=&%L`$UY(%!O<G1A;"!,87EO=70`37EA
M;FUA<@!.3RP@22!$;R!.3U0@06=R964`3F%M90!.86UI8FEA`$YA=7)U`$YE
M<&%L`$YE=&AE<FQA;F1S`$YE=&AE<FQA;F1S($%N=&EL;&5S`$YE='-C87!E
M($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E
M($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE='-C
M87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M='EP90!.971W;W)K`$YE=F5R`$YE=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y
M`$YE=R!-97-S86=E('1O("5S`$YE=R!-;V]N`$YE=R!5<V5R;F%M92`H;W!T
M:6]N86PI`$YE=R!:96%L86YD`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="`T(%!H87-E<P!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A
M=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B
M;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T
M96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S
M:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H
M96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E;B!C86X@8F4@861D
M960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE
M(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T:6]N('-U<'!L:65D
M+@!.;R!F:6QE('5P;&]A9&5D`$YO(&EC;VYS(&9O=6YD+@!.;R!L;V-A=&EO
M;B!I<R!S970N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U
M<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE
M9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!A<W-W;W)D('!R;W9I9&5D
M(&9O<B!(5%10(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@24U!4"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@3&]G:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D
M('!R;W9I9&5D(&9O<B!005-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@
M=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B
M:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N
M`$YO('!E;F1I;F<@<VEG;G5P<RX`3F\@<75O=&$@<V5T+@!.;R!R=6QE<P!.
M;R!S97!A<F%T;W(@<W!E8VEF:65D+@!.;R!S:61E<P!.;R!S=6-H(&9I;&4`
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+@!.
M;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@6$U,
M(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@:6X@
M;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T
M:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@
M4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO;F4@*'5S92!I;7!L
M:6-I="D`3F]R9&EC("A)4T\M.#@U.2TQ,"D`3F]R9F]L:R!)<VQA;F0`3F]R
M=&AE<FX@2&5M:7-P:&5R90!.;W)T:&5R;B!-87)I86YA($ES;&%N9',`3F]R
M=V%Y`$YO="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@
M:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T
M:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB
M97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@
M<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I
M<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T
M86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`3VQD(&%N9"!N97<@
M<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@<&%S<W=O<F0`3VQD
M('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/
M<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC
M871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE
M<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$5!4CHZ36%I;"!B86-K
M96YD`%!'4"!$:6=I=&%L(%-I9VYA='5R90!01U`@16YC<GEP=&5D($1A=&$`
M4$=0(%!U8FQI8R!+97D`4$=0(%-I9VYE9"]%;F-R>7!T960@1&%T80!02%`@
M0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@4F%I;@!032!286EN`%!-(%-H;W=E
M<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS
M`%!/4TE8(&5X=&5N<VEO;B!I<R!M:7-S:6YG`%!?2%`@4VAE;&P`4&%D9&EN
M9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C8W5P
M:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L>2!#
M;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`
M4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU
M<',Z`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M`%!E<FUI<W-I;VX`4&5R;6ES<VEO;B`B)7,B(&YO="!D96QE=&5D+@!097)M
M:7-S:6]N($1E;FEE9`!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES
M=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!E=',`4&AI;&EP
M<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S
M`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T
M:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C
M;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`
M4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N=&5R
M(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R(&$@
M=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@
M8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E
M(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES
M=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N
M9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES
M(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES
M(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@
M9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R96-I<&ET871I;VX\8G(@+SYC:&%N
M8V4`4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-S=7)E`%!R97-S=7)E(&%T('-E82!L979E;#H@
M`%!R97-S=7)E.B``4')E=FEE=P!0<F5V:65W('1H92!I;6%G92!I;B!A(&YE
M=R!W:6YD;W<`4')E=FEO=7,@;W!T:6]N<P!0<FEN="!D;V-U;65N=`!0<FEV
M871E($ME>0!0<F]B;&5M`%!R;V)L96T@1&5S8W)I<'1I;VX`4')O:F5C=',`
M4')O;7!T('1E>'0`4'5B;&EC($ME>0!0=6)L:6,@2V5Y($%L9V]R:71H;0!0
M=6)L:6,@2V5Y($EN9F\`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N;W0@9V5N
M97)A=&5D('-U8V-E<W-F=6QL>2X`4'5E<G1O(%)I8V\`46%T87(`475E<GD`
M475O=&$`4E-!(%!U8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N
M`%)A:6X`4F%I;B!%87)L>0!286EN($QA=&4`4F%I;B!3:&]W97(`4F%I;B!A
M;F0@4VYO=P!286EN('1O(%-N;W<`4F%N9&]M($9O<G1U;F4`4F%T:6\`4F5A
M9`!296%D(&UE<W-A9V5S`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H`%)E9G)E<V@@1'EN
M86UI8R!-96YU($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296=E
M>`!296QA=&EO;G-H:7`@0G)O=W-E<@!296QO860`4F5M87)K<P!296UO=&4@
M4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO
M<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V
M92!F;W)M871T:6YG`%)E;6]V92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@
M9G)O;2!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE
M`%)E;6]V92!T:&ES(&YO9&4@9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S
M97(`4F5M;W9E('5S97(Z("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R
M960N(%)E='5R;F5D(&5R<F]R8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O
M=6QD(&YO="!B92!F;W5N9"X`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN("5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I
M9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@
M<W!E8VEF:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I96QD`%)E
M<V5T`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=&]R
M92!,87-T(%%U97)Y`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E
M(&YE=R!P87-S=V]R9`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I
M8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE
M861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]M
M86YI80!2;W1A=&4@,3@P`%)O=&%T92!,969T`%)O=&%T92!2:6=H=`!2;W<@
M4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2;W=S.@!2=6QE<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&%L;"!R;W=S(&%N9"!C;VQU;6YS`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@8V]L=6UN<R!O;FQY`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@<F]W<R!O;FQY`%)U;@!2=7-S:6%N($9E9&5R871I
M;VX`4G=A;F1A`%,O34E-12!#<GEP=&]G<F%P:&EC(%-I9VYA='5R90!3+TU)
M344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!335,@365S<V%G:6YG`%-13"!3:&5L;`!344P@<W1A
M=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#15-3`%-?44P@4VAE
M;&P`4V$`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN
M="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E
M;G0@86YD('1H92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@
M4')O=FED97(`4V%U9&D@07)A8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`
M4V%V92!/<'1I;VYS`%-A=F4@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@
M82!02%`@<V-R:7!T('1O('EO=7(@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4V%V960@)7,@8V]N9FEG=7)A=&EO;BX`4V%V960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@=&\Z("(E<R(N`%-C871T97)E9"!4+5-T;W)M<P!38VEE
M;F-E`%-E87)C:`!396%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T
M(&$@9&%T90!396QE8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W
M;F5R`%-E;&5C="!A('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE
M8W0@86QL`%-E;&5C="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@
M;V)J96-T`%-E;&5C="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@
M;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@
M86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE
M(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE
M8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H
M92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C
M:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R
M;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G86P`4V5N<V]R.B``4V5P=&5M
M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<G9E
M<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M:6X`
M4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO;G,@
M=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V
M97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@
M=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E
M9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3
M970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A
M9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T
M=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO
M8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L
M;&5S`%-H;W!P:6YG`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES
M(&)E(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E
M;F-E<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W
M:&5N(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`
M4VAO=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3
M:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#
M96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A
M9`!3:&]W97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@
M:6X@=&AE(%9I8VEN:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O
M=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE
M;VYE`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN
M9V%P;W)E`%-I>F4`4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI
M80!3;F]W`%-N;W<@4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@
M16%R;'D`4VYO=R!3:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U
M:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O
M;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E
M<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3
M;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3
M;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L
M;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3
M<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`
M4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU
M;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4
M<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A
M9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG
M(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-3
M4UT`4W4`4W5B9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!3=6)J96-T`%-U
M8FUI=`!3=6)M:71T960@<F5Q=65S="!T;R!A9&0@(B5S(B!T;R!T:&4@<WES
M=&5M+B!9;W4@8V%N;F]T(&QO9R!I;B!U;G1I;"!Y;W5R(')E<75E<W0@:&%S
M(&)E96X@87!P<F]V960N`%-U8G-C<FEP=`!3=6-C97-S`%-U8V-E<W-F=6QL
M>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C;&5A
M<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D("(E
M<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N
M9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S
M879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S
M<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D
M86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N
M<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C
M<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA
M;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;F,@;&]G
M(&1E;&5T960`4WEN8TU,`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`
M4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD
M>0!4+5-T;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L
M92!0<F]P97)T:65S`%1A8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A:7=A
M;@!486EW86XL(%!R;W9I;F-E(&]F($-H:6YA`%1A:FEK:7-T86X`5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9@!487)G970Z`%1A<VMS`%1E;&5P:&]N
M92!.=6UB97(`5&5M<"!F;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M
M<&5R871U<F4Z(`!496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F
M9&5G.R5S`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T92!!9&UI
M;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1E>'1T;W``
M5&@`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@
M:7,@;F]T(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B
M;&5D+@!4:&4@2&]R9&4O2V]L86(@:6YT96=R871I;VX@96YG:6YE(&1O97,@
M;F]T('-U<'!O<G0@(B5S(@!4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E(&EN
M:71I86QI>F5D+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO
M860@<W5C8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D
M+B!%>&ET:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U
M<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N
M="!T;R!U<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H
M92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B
M;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O
M;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@
M8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F
M="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T
M:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN
M`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE
M(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE
M(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I;&4@
M8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H96%D
M97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F=6QL
M('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I=&@@
M26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA="!W
M92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E>'!E
M<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N8W1I
M;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U<B!S
M>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@>6]U
M)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N965D
M('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A<V4@
M<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL('-C
M<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T
M960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O9B!T
M:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G
M<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@
M<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G
M=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N
M9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE
M(&-O;7!O<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE
M('-I;F=L92!C:&%R86-T97(N`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O
M;FQY`%1H92!R:6=H="UH86YD('-I9&4@;VYL>0!4:&4@<V5P87)A=&]R(&UU
M<W0@8F4@;VYE('-I;F=L92!C:&%R86-T97(N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@<V%V
M960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@<F5M;W9E
M9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D*2!D;V5S(&YO="!E>&ES="X`5&AE
M('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT
M('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C
M<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S
M:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE
M('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B
M92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B
M;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R
M92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H
M870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N
M>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@
M)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4
M:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ
M("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E
M<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P
M<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@
M=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D
M(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE
M<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`
M5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A
M+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@
M9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N
M(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N
M`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@
M861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R
M+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T
M86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P
M;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@
M8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@
M=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O
M(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S
M:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D
M<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR
M;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A
M9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I
M=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F
M:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN
M(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R
M<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@
M;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S
M<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU
M<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN
M(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M
M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O
M8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E
M(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N
M(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U
M<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT
M<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4
M<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T
M90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L
M92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N
M9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,
M(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F
M<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`
M5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S
M`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!5
M4DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),
M.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N
M('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA
M8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O
M(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER
M96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!6
M1E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I
M;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE
M=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T
M;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D
M:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I
M<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE
M=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B
M+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L
M92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E
M>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE
M(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!6
M1E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O
M(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE
M('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I
M;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F
M:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A
M:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N
M9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N
M.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL
M960`56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E
M9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/
M=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@
M365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO
M=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E
M;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C
M8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R
M:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T
M92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W
M(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO
M<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A
M=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N
M`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@
M=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA
M;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E
M(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E
M<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E
M<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I
M;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H
M:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R
M;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z
M(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O
M<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F
M;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M
M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N
M`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L
M90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G
M92!M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO
M;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R
M=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI
M`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S
M`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N
M`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!3
M3510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($92
M3TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG
M`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y
M`%=E871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC
M;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E
M<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES
M('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C
M:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`
M5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I
M=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S
M(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI
M;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI
M`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I
M;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0
M:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C
M=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP
M96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A
M9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN
M=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!
M;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R
M`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`
M665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@
M(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=9
M1RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D
M(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO
M="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D
M:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T
M;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E
M96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL
M<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K
M)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H
M879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R
M92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T
M(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T
M:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E
M<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@
M<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L
M971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U
M="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U
M(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I
M9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE
M=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI
M86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@
M4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&
M<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@
M061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@
M>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O
M=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W
M<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI
M;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I
M='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N
M;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO
M="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O
M;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9
M;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D
M969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H
M87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9
M;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO
M;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W
M;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@
M:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@
M97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER
M90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0
M<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T
M960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T
M<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE
M;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D
M:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN
M:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E
M<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO
M="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@
M:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E
M<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T
M(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M
M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE
M('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`
M:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@
M8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE
M;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M
M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L
M`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`
M<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S
M:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W
M:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#
M87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4*
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I
M<VEO;BU$871E.B`R,#`V+3`R+3$U(#$V.C4P+3`R,#`*3&%S="U4<F%N<VQA
M=&]R.B!&86)I;R!';VUE<R`\9FQG;VUS0'5O;"YC;VTN8G(^"DQA;F=U86=E
M+51E86TZ($)R87II;&EA;B!0;W)T=6=U97-E(#QI,3AN0&QI<W1S+FAO<F1E
M+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L
M86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O
M9&EN9SH@.&)I=`I8+4=E;F5R871O<CH@2T)A8F5L(#$N,RXQ"E!L=7)A;"U&
M;W)M<SH@(&YP;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.PH`("@E<R!D:6%S
M(&%T<N%S*0`@*%1E8VQA(&1E($%T86QH;R`E<RD`("AE;2`E<R!D:6%S*0`@
M*&AO:F4I`"`H86UA;FCC*0`@*&]N=&5M*0`@82``(B5S(B!.XV\@Z2!U;2!D
M:7)E=/-R:6\N`"<E<R<@;N-O(.D@=6UA(&5S8V]L:&$@=N%L:61A+@`G)7,G
M(&[C;R!E<W3A(&-O;F9I9W5R861O(&YO(%)E9VES=')O(&1O($AO<F1E+@!R
M96YD97)I>F%D;W(@9&4@X7)V;W)E("(E<R(@;N-O(&5N8V]N=')A9&\N`"(E
M<R(@9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M82!D92!G<G5P;W,N`"(E<R(@
M9F]I(&%D:6-I;VYA9&\@86\@<VES=&5M82!D92!P97)M:7-S]65S+@`B)R5S
M(B!NXV\@9F]I(&-R:6%D;SH@)7,N`"4N,F9-0B!U<V%D;W,@9&4E+C)F34(@
M<&5R;6ET:61O<R`H)2XR9B4E*0`E9"`E<R!E("5S`"5D(&1I87,@873I('-U
M82!S96YH82!E>'!I<F%R+@`E9"!P<F5V:7/C;R!D;R!D:6$`)7,@+2!!=FES
M;P!);7!R97-SXV\@1&EG:71A;"!D92`E<P`E<R!+0@`E<R!/<&5R8>?U97,@
M9&4@36%N=71E;N?C;R`M($-O;F9I<FUAY^-O`$-O;F9I9W5R8>?C;R!D92`E
M<P!#861A<W1R;R!D92`E<P`E<R!497)M;W,@9&\@06-O<F1O`"5S(&KA(&5X
M:7-T92X`)7,@82`E<R`E<P`E<R!E<W3A('!R;VYT;R!P87)A(&5X96-U=&%R
M(&%S(&]P97)AY_5E<R!D92!M86YU=&5NY^-O(&UA<F-A9&%S(&%B86EX;RX@
M36%R<75E(&$@8V%I>&$@<&%R82!Q=6%L<75E<B!O<&5R8>?C;R!Q=64@=F]C
MZB!Q=65I<F$@97AE8W5T87(@9&5S=&$@=F5Z+@`E<R#I(&]B<FEG873S<FEO
M`"5S(&UI;G5T;W,`)7,@;N-O(&5N8V]N=')A9&\N`"5S(&$@)7,@9&4@)7,`
M0V%TX6QO9V\@9&4@16YD97)EYV]S(&1E("5S`$%G96YD82!D92`E<P!!;F]T
M8>?U97,@9&4@)7,`3&ES=&$@9&4@5&%R969A<R!D92`E<P`E<SH@)7,`)7,Z
M($5S=&$@;65N<V%G96T@<&]D92!NXV\@<V5R(&1E('%U96T@96QA(&1I>B!S
M97(N(%1O;64@8W5I9&%D;R!C;VT@<75A;'%U97(@;&EN:R!P<F5S96YT92!N
M96QA(&]U(&5M(&9O<FYE8V5R(&%O(')E;65T96YT92!Q=6%L<75E<B!I;F9O
M<FUAY^-O('!E<W-O86PN`"P@8G)I<V$@`"P@8G)I<V$@)7,@)7,`+"!V87)I
MX79E;"!D92`E<R!P87)A("5S`"TM('-E;&5C:6]N92`M+0!&;W)M871O(#$R
M($AO<F%S`$9O<FUA=&\@,C0@2&]R87,`,C0@:&]R87,`/%#A9VEN82!!;G1E
M<FEO<@!5;2!C;VYE8W1O<B!D92!B86YC;R!D92!D861O<R#I(&]B<FEG873S
M<FEO('!A<F$@97-T92!B;&]C;RX`56T@97)R;R!F871A;"!O8V]R<F5U`%5M
M82!C:&%V92!P^F)L:6-A(%!'4"#I(&]B<FEG873S<FEA('!A<F$@8W)I<'1O
M9W)A9F%R('5M82!M96YS86=E;2X`56UA(&-H879E('#Z8FQI8V$@4$=0(.D@
M;V)R:6=A=/-R:6$@<&%R82!V97)I9FEC87(@=6UA(&UE;G-A9V5M(&%S<VEN
M861A+@!5;6$@8VAA=F4@<')I=F%D82!01U`@92!U;6$@<V5N:&$@<^-O(&]B
M<FEG873S<FEA<R!P87)A(&1E<V-R:7!T;V=R869A<B!U;6$@;65N<V%G96TN
M`%5M82!C:&%V92!P<FEV861A(%!'4"!E('5M82!S96YH82!SXV\@;V)R:6=A
M=/-R:6%S('!A<F$@87-S:6YA<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P
M^F)L:6-A(%,O34E-12P@=6UA(&-H879E('!R:79A9&$@4R]-24U%(&4@=6UA
M('-E;FAA('/C;R!O8G)I9V%T\W)I87,@<&%R82!D97-C<FEP=&]G<F%F87(@
M=6UA(&UE;G-A9V5M+@!5;6$@8VAA=F4@</IB;&EC82!3+TU)344L('5M82!C
M:&%V92!P<FEV861A(%,O34E-12!E('5M82!S96YH82!SXV\@;V)R:6=A=/-R
M:6%S('!A<F$@87-S:6YA<B!U;6$@;65N<V%G96TN`%5M82!C:&%V92!P^F)L
M:6-A(%,O34E-12#I(&]B<FEG873S<FEA('!A<F$@8W)I<'1O9W)A9F%R('5M
M82!M96YS86=E;2X`3G5V96YS(&UA='5T:6YA<P!#:'5V82!&<F%C82!697-P
M97)T:6YA`$-H=79A(&UA='5T:6YA`$-H=79A<R!M871U=&EN87,`3F5V87-C
M87,@36%T=71I;F%S`$%-+U!-`$%022!)1`!3;V)R92!E<W1E(&5D:71O<@!3
M;V)R92XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C97-S;R!N96=A9&\@86\@
M8W)I87(@9&ER973S<FEO(%9&4RX`06-E<W-O(&YE9V%D;R!A;R!C<FEA<B!A
M<G%U:79O(%9&4RX`4W5A<R!);F9O<FUAY_5E<P!396YH82!D82!#;VYT80!#
M;VYT82!D97-A=&EV861A+@!#;VYT87,`061I8VEO;F%R`$%D:6-I;VYA<B!'
M<G5P;R!3=6)O<F1I;F%D;P!!9&EC:6]N87(@4&5R;6ES<_5E<R!3=6)O<F1I
M;F%D87,`061I8VEO;F4@07%U:3H`061I8VEO;F%R($YO=F\@1W)U<&\`061I
M8VEO;F%R($YO=F$@4&5R;6ES<^-O`$%D:6-I;VYA<B!U;2!G<G5P;R!S=6)O
M<F1I;F%D;R!A("<E<R<`061I8VEO;F%R('5M82!P97)M:7-SXV\@<W5B;W)D
M:6YA9&$@82`G)7,G`$%D:6-I;VYA<B!U;2!N;W9O('5S=>%R:6\Z`$%D:6-I
M;VYA<B!C;VQU;F$`061I8VEO;F%R(&YO=F]S(&UE;6)R;W,`061I8VEO;F%R
M('!A<@!!9&EC:6]N87(@;R!-96YU("5S(&-O;6\@=6UA($)A<G)A($QA=&5R
M86P@9&\@36]Z:6QL80!!9&EC:6]N87(@86\@8V%TX6QO9V\@9&4@96YD97)E
MYV]S.@!!9&EC:6]N87(@86\@;65U(&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!!
M9&EC:6]N87(@=7-UX7)I;P`G)7,G(&%D:6-I;VYA9&\@86\@<VES=&5M82P@
M;6%S(&[C;R!P=61E(&EN8VQU:7(@:6YF;W)M8>?U97,@861I8VEO;F%I<R!D
M;R!C861A<W1R;SH@)7,N`"5S(&%D:6-I;VYA9&\@86\@<VES=&5M82X@5F]C
MZB!P;V1E('-E(&-O;F5C=&%R(&%G;W)A+@!!9&GGXV\@9&4@=7-UX7)I;W,@
M97-TX2!D97-A8FEL:71A9&$N`$5N9&5R9>=O`$-A=.%L;V=O(&1E($5N9&5R
M9>=O<P!!9&UI;FES=')A<B`M(&-O;F9I9W5R82!P97)M:7-S]65S('!A<F$@
M;W5T<F]S('5S=>%R:6]S`$%D;6EN:7-T<F'GXV\`06[Z;F-I;W,`069E9V%N
M:7-TXV\`06QBXFYI80!!<F?I<FEA`$%P96QI9&\`06QI;FAA<@!!;&EN:&%M
M96YT;SH`5&]D;W,`5&]D;W,@57-UX7)I;W,@075T96YT:6-A9&]S`%1O9&]S
M($=R=7!O<P!4;V1A<R!097)M:7-S]65S`%1O9&]S('%U871R;R!L861O<P!0
M97)M:71I<B!M^FQT:7!L;W,@96YD97)EYV]S`%!E<FUI=&ER(&-O;F9I9W5R
M87(@;R!T:7!O(&1E(&QI<W1A<R!O<F1E;F%D87,_`$KA(&5X:7-T90!,;V=I
M;B!)35-0($%L=&5R;F%T:79O`%-E;FAA($E-4U`@06QT97)N871I=F$`57-U
MX7)I;R!)35-0($%L=&5R;F%T:79O`$5N9&5R9>=O(&1E(&4M;6%I;"!A;'1E
M<FYA=&EV;P!-;V1E;&]S(&%L=&5R;F%T:79O<P!497AT;R!A;'1E<FYA=&EV
M;SH`4V%M;V$@06UE<FEC86YA`%5M('9A;&]R(&EL96=A;"!F;VD@97-P96-I
M9FEC861O+@!/8V]R<F5U('5M(&5R<F\@9&5S8V]N:&5C:61O+@!!;F1O<G)A
M`$%N9V]L80!!;F=U:6QL80!0<F]X>2!A;O1N:6UO`%)E<W!O<W1A`$%N=.%R
M=&ED80!!;G1I9W5A(&4@0F%R8F%D;W,`07!L:6-AY^-O`$QI<W1A(&1E($%P
M;&EC8>?U97,`02!A<&QI8V'GXV\@97-TX2!P<F]N=&$N`$%P;&EC87(@86]S
M($-O;7!A<G1I;&AA;65N=&]S(%-U8F]R9&EN861O<P!!<')O=F%R`%1A;6%N
M:&\@07!R;WAI;6%D;P!!8G)I;`!!<N%B:6-O("A7:6YD;W=S+3$R-38I`%1A
M;6%N:&\@9&\@07)Q=6EV;P!.;VUE(&1O($%R<75I=F\`5F]CZB!T96T@8V5R
M=&5Z82!Q=64@<75E<B!R96UO=F5R(&$@<V]L:6-I=&'GXV\@9&4@8V%D87-T
M<F\@9&4@)7,_`%9O8^H@=&5M(&-E<G1E>F$@<75E(&1E<V5J82!E>&-L=6ER
M("<E<R<@92!S975S('-U8F=R=7!O<S\`07)G96YT:6YA`$%R;>IN:6$`07)M
MZFYI;R`H05)-4T-)22TX*0!!<G1E`$%R=6)A`$EL:&$@07-C96YSXV\`07)T
M92!!<V-I:0#!<VEA+U)E9VGC;R!D;R!086/M9FEC;P!3;VQI8VET87(@8V]N
M9FER;6'GXV\@86YT97,@9&4@97AE8W5T87(@87,@;W!E<F'G]65S(&1E(&UA
M;G5T96[GXV\_`$-O;'5N87,@9&4@9&5S:6=N8>?C;P!496YT;W4@97AC;'5I
M<B!U;2!G<G5P;R!I;F5X:7-T96YT92X`5&5N=&]U(&5X8VQU:7(@=6UA('!E
M<FUI<W/C;R!NXV\@97AI<W1E;G1E+@!496YT;W4@961I=&%R('5M82!P97)M
M:7-SXV\@;N-O(&5X:7-T96YT92X`5&5N=&]U(&5D:71A<B!U;2!C;VUP87)T
M:6QH86UE;G1O(&[C;R!E>&ES=&5N=&4N`$%T<FEB=71O<P!!9V]S=&\`075S
M='+A;&EA`,%U<W1R:6$`075T:%]C>7)S<6PZ($[C;R!F;VD@96YC;VYT<F%D
M82!A(&5X=&5N<^-O(&EM87`@;F5C97-SX7)I82X`075T:%]C>7)U<SH@3R!C
M;VYE8W1O<B!NXV\@<&]S<W5I(&%S(&-A<&%C:61A9&5S(&YE8V5S<^%R:6%S
M+@!!=71H7V-Y<G5S.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E>'1E;G/C;R!I
M;6%P(&YE8V5S<^%R:6$N`$%U=&A?9G1P.B!.XV\@9F]I(&5N8V]N=')A9&$@
M82!E>'1E;G/C;R!&5%`@;F5C97-SX7)I82X@0V]M<&EL92!O(%!(4"!C;VT@
M82!O<.?C;R`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@3N-O(&9O:2!E;F-O
M;G1R861A(&$@97AT96YSXV\@:6UA<"!N96-E<W/A<FEA+@!!=71H7VMR8C4Z
M($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O(&MR8C4@;F5C97-SX7)I
M82X`075T:%]L9&%P.B!);F-L=7/C;R!D92!U<W7A<FEO<R!NXV\@Z2!S=7!O
M<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@17AC;'5S
MXV\@9&4@=7-UX7)I;W,@;N-O(.D@<W5P;W)T861A('!A<F$@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N
M<^-O($Q$05`@;F5C97-SX7)I82X`075T:%]L9&%P.B!);7!O<W/M=F5L(&%D
M:6-I;VYA<B!O('5S=>%R:6\@)7,N($ES=&\@9F]I(&\@<75E(&\@<V5R=FED
M;W(@<F5P;W)T;W4Z(`!!=71H7VQD87`Z($EM<&]S<^UV96P@<F5M;W9E<B!O
M('5S=>%R:6\@)7,`075T:%]L9&%P.B!);7!O<W/M=F5L(&%T=6%L:7IA<B!O
M('5S=>%R:6\@)7,`075T:%]L9&%P.B!!='5A;&EZ8>?C;R!D92!U<W7A<FEO
M<R!NXV\@Z2!S=7!O<G1A9&$@<&%R82!!8W1I=F4@1&ER96-T;W)Y+@!!=71H
M7VUC86PZ($[C;R!F;VD@96YC;VYT<F%D82!A(&5X=&5N<^-O($U#04P@;F5C
M97-SX7)I82X`075T:%]S;6)A=71H.B!.XV\@9F]I(&5N8V]N=')A9&$@82!E
M>'1E;G/C;R!S;6)A=71H(&YE8V5S<^%R:6$N`$%U=&5N=&EC8>?C;R!N;R!S
M97)V:61O<B!)34%0(&9A;&AO=2X`1F%L:&$@;F$@875T96YT:6-AY^-O`$9A
M;&AA(&YA(&%U=&5N=&EC8>?C;SH@)7,`075T96YT:6-AY^-O(')E:F5I=&%D
M82!P96QO('-E<G9I9&]R(%)!1$E54RX`02!A=71E;G1I8V'GXV\@;F\@<V5R
M=FED;W(@1E10(&9A;&AO=2X`02!A=71E;G1I8V'GXV\@;F\@<V5R=FED;W(@
M4TU"(&9A;&AO=2X`0V%M<&]S(&1I<W!O;NUV96ES.@!!>F5R8F%I:N-O`$1E
M<V-U;'!A<R!D;R!"3T9(`$9U;F1O`$-O<B!D92!&=6YD;P!396YH82!K97)B
M97)O<R!I;F-O<G)E=&$N`%5S=>%R:6\@:V5R8F5R;W,@:6YC;W)R971O+@!"
M86AA;6%S`$)A:')A:6X`0N%L=&EC;R`H25-/+3@X-3DM,3,I`$)A;F=L861E
M<V@`0F%R8F%D;W,`3N-O(&9O:2!E;F-O;G1R861O(&\@9&ER973S<FEO(&)A
M<V4@9&4@:6UA9V5N<R`G)7,G+@!,:6YH82!D92!087)T:61A`$)E;&]R^G-S
M:6$`0NEL9VEC80!"96QI>F4`0F5N:6X`0F5R;75D87,`0G5TXV\`06YI=F5R
M<^%R:6\`3N-O(&9O:2!E;F-O;G1R861O(&\@8FQO8V\@(B5S(B!D82!A<&QI
M8V'GXV\@(B5S(BX`0V]N9FEG=7)AY_5E<R!D;R!";&]C;P!4:7!O(&1E($)L
M;V-O`$YE9W)I=&\`0F]L[79I80!&879O<FET;W,`0F]R9&$`3&%R9W5R82!D
M82!B;W)D83H`0F]R9&%S`$+S<VYI82!E($AE<GIE9V]V:6YA`$%M8F]S`$)O
M='-U86YA`%)O9&%PZ0!);&AA($)O=79E=`!"<F%S:6P`5&5R<FET\W)I;R!D
M;R!/8V5A;F\@S6YD:6-O($EN9VSJ<P!"<G5N96D`0G5L9^%R:6$`3&ES=&$@
M8V]M($UA<F-A9&]R97,`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!0
M;VYT;W,@9&4@1&ES=')I8G5IY^-O($-23`!0<F]P<FEE9&%D97,@9&$@0^E?
M;'5L82XN+@!!(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C
M:69I8V%D82X`06=E;F1A`$-A;&UO`$-A;6)O9&IA`$-A;6%R]65S`$[C;R#I
M('!O<W/M=F5L(&=E<F%R('5M82!N;W9A('-E;FAA(&%U=&]M871I8V%M96YT
M92P@96YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R+@!.XV\@
M8V]N<VEG;R!G<F%V87(@;R!A<G%U:79O("(E<R(`3N-O(.D@<&]S<^UV96P@
M861M:6YI<W1R87(@9V5R96YC:6%D;W)E<R!E>'1E<FYO<R!D92!S97-SXV\N
M`$[C;R#I('!O<W/M=F5L(&-O;F5C=&%R(&%O('-E<G9I9&]R($E-05`Z("5S
M`$[C;R!C;VYS:6=O(&%B<FER(&\@87)Q=6EV;R`B)7,B+@!#86YA9.$`0V%N
M8V5L87(`0V%N8V5L87(@4F5L873S<FEO(&1E(%!R;V)L96UA`$[C;R#I('!O
M<W/M=F5L(&5X8VQU:7(@;R!A<G%U:79O("(E<R(N`$[C;R#I('!O<W/M=F5L
M(&5N8V]N=')A<B!U;2!D:7)E=/-R:6\@=&5M<&]RX7)I;RX`3N-O(.D@<&]S
M<^UV96P@8V]N=&EN=6%R('-E;2!O('!A<N)M971R;R`G=&%R9V5T1FEL92<N
M`$[C;R#I('!O<W/M=F5L(&5X8VQU:7(@;R!D:7)E=/-R:6\@(B5S(BX`3N-O
M(.D@<&]S<^UV96P@97AC;'5I<BP@)60@<&]S<W5I('-U8F]R9&EN861O<RX`
M3N-O(.D@<&]S<^UV96P@<F5O<F1E;F%R+"!N^FUE<F\@9&4@<F5G:7-T<F]S
M(&9O<FYE8VED;W,@<&%R82!R96]R9&5N87(@;N-O(&-O<G)E<W!O;F1E(&%O
M(&[Z;65R;R!A<FUA>F5N861O+@!.XV\@Z2!P;W-S[79E;"!R;W1E87(@;65N
M<V%G96T@<&%R82!O(&[Z;65R;R!E<W!E8VEF:6-A9&\N`$-A8F\@5F5R9&4`
M5.UT=6QO`$]P97)A9&]R80!#871E9V]R:6%S(&4@3F]M97,`26QH87,@0V%Y
M;6%N`%1E;&5F;VYE($-E;'5L87(`4')O<')I961A9&5S(&1A($/I;'5L80!-
M87)G96T@9&$@8^EL=6QA.@!0<F]P<FEE9&%D97,@9&$@0^EL=6QA`$5S<&'G
M86UE;G1O(&1A(&/I;'5L83H`5&5L969O;F4@8V5L=6QA<@!#Z6QT:6-O("A)
M4T\M.#@U.2TQ-"D`0V5N=')O`%)E</IB;&EC82!D82#!9G)I8V$@0V5N=')A
M;`!%=7)O<&$@0V5N=')A;"`H25-/+3@X-3DM,BD`1&5T86QH97,@9&\@0V5R
M=&EF:6-A9&\`4')O<')I973A<FEO(&1O($-E<G1I9FEC861O`%!O;.UT:6-A
M<R!D;R!#97)T:69I8V%D;P!48VAA9&4`06QT97)A<@!!;'1E<F4@4W5A(%-E
M;FAA`$%L=&5R87(@;R!N;VUE(&4@;R!E;F1E<F7G;R!Q=64@87,@<&5S<V]A
M<R!VZF5M('%U86YD;R!E;&%S(&SJ96T@92!R97-P;VYD96T@<W5A<R!M96YS
M86=E;G,N`$%L=&5R8>?C;R!D92!S96YH82!NXV\@Z2!S=7!O<G1A9&$@;F$@
M8V]N9FEG=7)AY^-O(&%T=6%L+B`@16YT<F4@96T@8V]N=&%T;R!C;VT@;R!A
M9&UI;FES=')A9&]R+@!#:&%R`%9E<FEF:6-A<B!,:6Y?:RXN+@!#:&EL90!#
M:&EN80!#:&ENZG,@4VEM<&QI9FEC861O("A'0C(S,3(I`$-H:6[J<R!4<F%D
M:6-I;VYA;"`H0FEG-2D`17-C;VQH82!A($%P;&EC8>?C;SH`17-C;VQH82!U
M;6$@<V5N:&$`17-C;VQH82!U;2!U<W7A<FEO`$5S8V]L:&$@8V]M;R!E>&EB
M:7(@9&%T87,Z`$5S8V]L:&$@;R!T:7!O(&1E(&5S=&EL;R!D92!L:7-T87,@
M*'!A<F$@;&ES=&%S(&]R9&5N861A<RD`26QH87,@0VAR:7-T;6%S`$[C;R!F
M;VD@96YC;VYT<F%D82!A(&1E9FEN:>?C;R!D92!C;&%S<V4@9&4@)7,N`$QI
M;7!A<@!,:6UP87(@=&%G<R!-4T]F9FEC90!%>&-L=6ER('5S=>%R:6\`17AC
M;'5I<B!U<W7A<FEO.B`E<P!%>&-L=6ER('5S=>%R:6\`17AC;'5I<B!D861O
M<R!D;R!U<W7A<FEO`$/I=2!A8F5R=&\@82!487)D90!#;&EQ=64@<&%R82!#
M;VYT:6YU87(`0VQI8VMA=&5L;"!V:6$@2%144`!&96-H87(@2F%N96QA`$YU
M=F5N<P!.=6)L861O('!E;&$@36%N:.,`3G5B;&%D;P!);&AA<R!D92!#;V-O
M<P!#;VYT<F%I<B!"87)R82!,871E<F%L`$-O;G1R86ER(&)O<F1A<P!#;VST
M;6)I80!#;W(`4&%L:&5T82!D92!#;W)E<P!396QEY^-O(&1E($-O<@!#;VQS
M.@!4[71U;&]S(&1A<R!#;VQU;F%S`%%U861R:6YH;W,`0V]M86YD;P!,:6YH
M82!D92!#;VUA;F1O`$-O;65N=&%R`$YO;64`0V]M;W)O<P!%;7!R97-A`$-O
M;7!U=&%D;W)E<P!#;VYD:>?C;P!#;VYD:>?U97,`1&EF97)E;N=A<R!D92!#
M;VYF:6=U<F'GXV\`0V]N9FEG=7)AY^-O(&1E('-I;F-R;VYI>F'GXV\@8V]M
M(%!$07,L(%-M87)T<&AO;F5S(&4@3W5T;&]O:RX`0V]N9FEG=7)AY^-O(&YE
M8V5S<VET82!D92!A='5A;&EZ8>?C;RX`0V]N9FEG=7)A<B`E<P!#;VYF:7)M
M92!A(%-E;FAA`$-O;F=O`$-O;F=O+"!297#Z8FQI8V$@1&5M;V-RX71I8V$@
M9&\`1F%L:&$@;F$@8V]N97CC;RX`1F%L:&$@;F$@8V]N97CC;SH@`$-O;F5X
MXV\@<F5C=7-A9&$@<&5L;R!S97)V:61O<B!D92!C:&%V97,@</IB;&EC87,N
M`$-O;F5XXV\@<F5C=7-A9&$@<&5L;R!S97)V:61O<B!D92!C:&%V97,@</IB
M;&EC87,N($UO=&EV;SH@)7,@*"5S*0!!(&-O;F5XXV\@86\@<V5R=FED;W(@
M1E10(&9A;&AO=2X`0V]N=&%T;W,`3W,@8V]N=&%T;W,@9F]R86T@861I8VEO
M;F%D;W,@8V]M('-U8V5S<V\@86\@<V5U(&-A=.%L;V=O(&1E(&5N9&5R9>=O
M<RX`5&EP92!D92!C;VYT9?ID;R!D;R!A<G%U:79O(&-O;7!R:6UI9&\Z(`!#
M;VYT9?ID;R!D92`G)7,G`$-O;G1I;G5A<@!);&AA<R!#;V]K`$-O;VMI90!#
M;W!I87(`1F%L:&$@;F$@8_-P:6$Z("5S`$-O<&EA<B!S96QEY^-O`$E$(&1E
M($-U<W1O`$-O<W1A(%)I8V$`0V]S=&$@9&\@36%R9FEM`$EM<&]S<^UV96P@
M8W)I<'1O9W)A9F%R(&$@;65N<V%G96T@8V]M(%!'4#H@`$EM<&]S<^UV96P@
M87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!01U`Z(`!.XV\@9F]I('!O<W/M=F5L
M(&-R:7!T;V=R869A<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F;VD@
M<&]S<^UV96P@87-S:6YA<B!A(&UE;G-A9V5M(&-O;2!3+TU)344N`$[C;R!F
M;VD@<&]S<^UV96P@861I8VEO;F%R(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S
M<^UV96P@8V]N96-T87(@86\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S
M[79E;"!V97)I9FEC87(@;R!S86QD;RX@)7,`26UP;W-S[79E;"!C;VYE8W1A
M<B!A;R!S97)V:61O<B!,1$%0+@!.XV\@9F]I('!O<W/M=F5L(&-O;F5C=&%R
M(&%O('-E<G9I9&]R("<E<R<@=71I;&EZ86YD;R!&5%`Z("5S`$[C;R!F;VD@
M<&]S<^UV96P@8W)I87(@82!L:7-T82!D92!D:7-T<FEB=6GGXV\N("5S`$EM
M<&]S<^UV96P@9&5S8W)I<'1O9W)A9F%R(&]S(&1A9&]S(%!'4#H@`$[C;R!F
M;VD@<&]S<^UV96P@9&5S8W)I<'1O9W)A9F%R(&\@9&%D;R!3+TU)344N`$[C
M;R!F;VD@<&]S<^UV96P@97AC;'5I<B!O(&-O;G1A=&\N("5S`$[C;R!F;VD@
M<&]S<^UV96P@97AC;'5I<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX@)7,`
M3N-O(&9O:2!P;W-S[79E;"!E>&-L=6ER(&\@<V-R:7!T(&1E(&%T=6%L:7IA
MY^-O(&1E(&-O;F9I9W5R8>?C;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&1E
M=&5R;6EN87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@9&\@9&5S=&EN873A<FEO
M+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&-O;7!L971A;65N=&4@;R!C873A
M;&]G;R!D92!E;F1E<F7G;W,N`$[C;R!F;VD@<&]S<^UV96P@;V)T97(@8V]M
M<&QE=&%M96YT92!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX`3N-O(&9O:2!P
M;W-S[79E;"!O8G1E<B!C;VUP;&5T86UE;G1E(&$@;&ES=&$@9&4@;&ES=&%S
M(&1E(&1I<W1R:6)U:>?C;RX`3N-O(&9O:2!P;W-S[79E;"!C87)R96=A<B!A
M(&5S=')A=.EG:6$@)R5S)RX`3N-O(&9O:2!P;W-S[79E;"!C<FEA<B!O(&1I
M<F5T\W)I;R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@8VAA=F4@
M</IB;&EC82!A('!A<G1I<B!D;R!S97)V:61O<B!D92!C:&%V97,N`$[C;R!F
M;VD@<&]S<^UV96P@86)R:7(@)R5S)R!P87)A(&=R879AY^-O+@!.XV\@9F]I
M('!O<W/M=F5L(&%B<FER("5S+@!.XV\@9F]I('!O<W/M=F5L(&%B<FER(&\@
M;?-D=6QO("=-86EN=&5N86YC95]487-K)R`E<P!.XV\@9F]I('!O<W/M=F5L
M(&%B<FER(&\@9&ER973S<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV96P@<&5S
M<75I<V%R(&YO('-E<G9I9&]R($Q$05`N`$[C;R!F;VD@<&]S<^UV96P@;&5R
M("5S+@!.XV\@9F]I('!O<W/M=F5L(&=E<F%R('5M82!N;W9A('-E;FAA('!A
M<F$@;R!U<W7A<FEO('-O;&EC:71A9&\N($%L9W5N<R!O=2!T;V1O<R!O<R!D
M971A;&AE<R!NXV\@97-TXV\@8V]R<F5T;W,N(%1E;G1E(&YO=F%M96YT92!O
M=2!E;G1R92!E;2!C;VYT871O(&-O;2!O(&%D;6EN:7-T<F%D;W(@<V4@=F]C
MZB!N96-E<W-I=&$@9&4@;6%I<R!A:G5D82X`3N-O(&9O:2!P;W-S[79E;"!O
M8G1E<B!A($%#3`!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&\@8V%TX6QO9V\@
M9&4@96YD97)EYV]S+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R(&$@;&ES
M=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M=F5L(&]B=&5R
M(&%S(&QI<W1A<R!D92!D:7-T<FEB=6GGXV\N("5S`$[C;R!F;VD@<&]S<^UV
M96P@;V)T97(@87,@8V%P86-I9&%D97,@9&\@<V5R=FED;W(`3N-O(&9O:2!P
M;W-S[79E;"!R979E<G1E<B!A(&-O;F9I9W5R8>?C;RX`3N-O(&9O:2!P;W-S
M[79E;"!R96UO=F5R(&\@9&ER973S<FEO("<E<R<N`$[C;R!F;VD@<&]S<^UV
M96P@<V%L=F%R(&$@8V]N9FEG=7)AY^-O("5S+@!.XV\@9F]I('!O<W/M=F5L
M('-A;'9A<B!U;2!B86-K=7`@9&$@8V]N9FEG=7)AY^-O+@!.XV\@9F]I('!O
M<W/M=F5L('-A;'9A<B!U;2!B86-K=7`@9&$@8V]N9FEG=7)AY^-O.B`E<P!.
MXV\@9F]I('!O<W/M=F5L('-A;'9A<B!O('-C<FEP="!D92!A='5A;&EZ8>?C
M;R!D92!C;VYF:6=U<F'GXV\@96TZ("<E<R<N`$[C;R!C;VYS96=U:2!S86QV
M87(@;R!B86-K=7`@9&\@87)Q=6EV;R!D92!C;VYF:6=U<F'GXV\@)7,N`$[C
M;R!C;VYS96=U:2!S86QV87(@;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E
M<RX@5F]CZB!P;V1E(&]U('5T:6QI>F%R('5M82!D87,@;W#G]65S('!A<F$@
M<V%L=F%R(&\@8_-D:6=O(&1E('9O;'1A(&5M("5S(&]U(&-O<&EA<B!M86YU
M86QM96YT92!O(&/S9&EG;R!A8F%I>&\@<&%R82`E<RX`3N-O(&9O:2!P;W-S
M[79E;"!P97-Q=6ES87(@;F\@<V5R=FED;W(@3$1!4"X`3N-O(&9O:2!P;W-S
M[79E;"!R96UO=F5R(&\@;&EN:R`G)7,G+@!.XV\@9F]I('!O<W/M=F5L(&%T
M=6%L:7IA<B!O(&-O;G1A=&\N("5S`$[C;R!F;VD@<&]S<^UV96P@871U86QI
M>F%R(&$@;&ES=&$@9&4@9&ES=')I8G5IY^-O+B`E<P!.XV\@9F]I('!O<W/M
M=F5L(&=R879A<B!A(&-O;F9I9W5R8>?C;R!D92`G)7,G.B`E<P!.XV\@9F]I
M('!O<W/M=F5L(&5N8V]N=')A<B!A($)A<G)A($QA=&5R86P@9&\@36]Z:6QL
M82X@0V5R=&EF:7%U92US92!Q=64@96QA(&5S=.$@86)E<G1A+@!.XV\@9F]I
M('!O<W/M=F5L(&1A<B!A;R!U<W7A<FEO("5S(&]S('-E9W5I;G1E<R!D:7)E
M:71O<R!P87)A(&$@<&%S=&$@)R5S)SH@)7,`5&5X=&\@8V]N=&%D;P!08>US
M`$-U<G-O<P!#<FEA<@!#<FEA<B!U;2!L:6YK`$-R:6%R('5M82!N;W9A`$-R
M:6%R('-U8B!P87-T87,`4&5R;6ES<_5E<R!D;R!C<FEA9&]R`$[Z;65R;R!D
M;R!C87)TXV\@9&4@8W+I9&ET;P!#<F_A8VEA`$-U8F$`-"!&87-E<R!!='5A
M:7,`4V5S<_5E<R!!='5A:7,`2&]R82!!='5A;`!!(%523"!A='5A;"#I`%5S
M=>%R:6]S(&YO(&UO;65N=&\`0VQI;6$@071U86P`0V]N9&GGXV\@871U86PZ
M(`!%<W1I;&\@871U86P`0W5S=&]M:7IA('1A<F5F87,@82!S97)E;2!E>&5C
M=71A9&%S(&%O(&-O;F5C=&%R(&$@)7,N`$-O<G1A<@!#;W)T87(@<V5L9>?C
M;P!#:&EP<F4`0VER[6QI8V\@*$M/23@M4BD`0VER[6QI8V\@*%=I;F1O=W,M
M,3(U,2D`0VER[6QI8V\O56-R86YI86YO("A+3TDX+54I`%)E</IB;&EC82!4
M8VAE8V$`1$0`1%-.("AV96IA(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L
M+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&EA<FEA
M;65N=&4`3F%V96=A9&]R(&1E($1A=&%4<F5E`%!E<W%U:7-A(&YO($)A;F-O
M(&1E($1A9&]S`$1A=&$`1&%T82!D92!296-E8FEM96YT;P!396QEY^-O(&1E
M(&1A=&$`1&EA`$5?>&-L=6ER($-O;'5N80!$97IE;6)R;P!.^FUE<F]S(&1E
M8VEM86ES`%)E8W5A<B!)9&5N=&'GXV\`4&%D<N-O`$-O<B!0861RXV\`261E
M;G1I9&%D92!0861RXV\`4VAE;&P@4&%D<N-O`$1E9FEN:>?U97,`17AC;'5I
M<@!%>&-L=6ER(&/I;'5L80!%>&-L=6ER($=R=7!O`$5X8VQU:7(@3&]G`$5X
M8VQU:7(@4&5R;6ES<^-O`$5X8VQU:7(@92!P=7)G87(@;65N<V%G96YS`$5X
M8VQU:7(@8^EL=6QA`$5X8VQU:7(@8V]L=6YA`$5X8VQU:7(@;6]D96QO('-U
M8G-T:71U=&\@97AI<W1E;G1E`$5X8VQU:7(@<&5R;6ES<_5E<R!P87)A("<E
M<R<`17AC;'5I<B!P97)M:7-S]65S('!A<F$@)R5S)R!E('%U86QQ=65R(&]U
M=')A('-U8BUP97)M:7-SXV\_`$5X8VQU:7(@;&EN:&$`17AC;'5I<B!I9&5N
M=&ED861E('-E;&5C:6]N861A`$5X8VQU:7(@82!C;VQU;F$@871U86P`17AC
M;'5I<B!A(&QI;FAA(&%T=6%L`%-C<FEP="!D92!A='5A;&EZ8>?C;R!D92!C
M;VYF:6=U<F'GXV\@)R5S)R!E>&-L=>UD;RX`2&]R82!D92!E;G1R96=A`$1I
M;F%M87)C80!$97-C<F5V82!O('!R;V)L96UA`$1E<V-R:>?C;P!$971A;&AE
M<R`H=&%M8NEM(&YO(')E9VES=')O(&1E(&%T:79I9&%D97,@9&\@2&]R9&4I
M.@!/<R!D971A;&AE<R!F;W)A;2!G<F%V861O<R!E;2!L;V<@<&%R82!O(&%D
M;6EN:7-T<F%D;W(N`$1E<V5N=F]L=FEM96YT;P!0;VYT;R!D92!/<G9A;&AO
M`%!O;G1O(&1E($]R=F%L:&\@<&%R82!A(/IL=&EM82!H;W)A.B``4&]N=&\@
M9&4@3W)V86QH;SH@`$1I<F7GXV\@9&$@97-Q=65R9&$@<&%R82!D:7)E:71A
M`$1I<F7GXV\@9&$@9&ER96ET82!P87)A(&5S<75E<F1A`$1I<F5T\W)I;P!%
M>&EB:7(@96T@9F]R;6%T;R`R-"!H;W)A<S\`3W#G]65S(&1E($5X:6)IY^-O
M`$5X:6)I<B!P<F5V:7/C;R!D971A;&AA9&$`17AI8FER('!R979I<^-O("A4
M048I`$5X:6)I<B!F;W)M871O`$YO=&EF:6-AY^-O(&1E($1I<W!O<VGGXV\`
M1&II8G5T:0!.XV\@97AC;'5I<@!.XV\@86-E<W-E(&1I<F5T86UE;G1E(&UA
M:6YT96YA;F-E+G!H<`!!('!R:6UE:7)A(&QI;FAA(&-O;G3I;2!O<R!N;VUE
M<R!D;W,@8V%M<&]S/R!392!S:6TL(&-L:7%U92!N97-T82!C86EX83H`1&]M
M:6YI8V%N80!297#Z8FQI8V$@1&]M:6YI8V%N80!.XV\@=&5M('5M82!C;VYT
M83\@0V%D87-T<F4M<V4N`$)A:7AA<@!"86EX87(@)7,`0F%I>&%R(&$@8V]N
M9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M('-C<FEP="!02%`N`$QI<W1A(&1E
M('-E;&7GXV\`1')O9V%S`$-O<G)E:6\`0V]N96-T;W(@9&\@9V%T97=A>2!%
M36%I;"UP87)A+5--4RP@<&%R82!O<&5R861O<F%S('%U92!D:7-P;VYI8FEL
M:7IA;2!E<W1E('-E<G9IYV\N`$524@!%<75A9&]R`$5D:71A<@!%9&ET87(@
M0FQO8V\`161I=&%R($=R=7!O`$5D:71A<B!097)M:7-SXV\`161I=&%R(%!E
M<FUI<W/U97,`161I=&%R(%!E<FUI<W/U97,@<&%R82`E<P!%9&ET87(@;W#G
M]65S(&1E.@!%9&ET87(@<&5R;6ES<_5E<R!P87)A("5S`$5D:71A<B!P97)M
M:7-S]65S('!A<F$@)7,`161U8V'GXV\`16=I=&\`16P@4V%L=F%D;W(`16QE
M;65N=&\N+BX`16T`12UM86EL`$5N9&5R9>=O(&1E($4M36%I;`!/(&5N9&5R
M9>=O(&1E(&4M;6%I;"!D979E(&-O<G)E<W!O;F1E<BX`365N<V%G96T@8V]M
M(&-O;F9I<FUAY^-O`$=A=&5W87D@9&4@14UA:6PM<&%R82U335,`16UO=&EC
M;VYS`$UE;G-A9V5M(&5M(&)R86YC;RX`4F5S=6QT861O(&5M(&)R86YC;RX`
M5&5R;6]S(&1E('!E<W%U:7-A(&5M(&)R86YC;P!(86)I;&ET87(@:6YS97+G
MXV\@9&4@:6UA9V5N<R!A('!A<G1I<B!D82!'86QE<FEA(&1E($EM86=E;G,@
M;F\@=&5X=&\_`$AA8FEL:71A<B!M96YU(&1E(&-O;G1E>'1O(&-O;2!O(&)O
M=.-O(&1I<F5I=&\_`$9I;F%L(&1O(&%N;P!!=6UE;G1A<B!%9&ET;W(`1F]R
M;F7G82!U;6$@<&5R9W5N=&$@9&4@<V5G=7)A;N=A(&$@<75A;"!V;V/J('-E
M<N$@<&5R9W5N=&%D;R!S92!V;V/J(&YE8V5S<VET87(@9V5R87(@=6UA(&YO
M=F$@<V5N:&$L(&5X+B`G<75A;"!O(&YO;64@9&\@<V5U(&-A8VAO<G)O/R<Z
M`$9O<FYEYV$@82!54DP@9&$@:6UA9V5M(&%Q=6D`1&EG:71E(&%S(&QE=')A
M<R!A8F%I>&\Z`$=U:6[I($5Q=6%T;W)I86P`17)I='+I:6$`17)R;P!%<G)O
M(&%O(&-R:6%R(&)L;V-O.B`E<P!%<G)O(&%O(&5X8VQU:7(@XFYC;W)A(&1E
M('-I;F-R;VYI>F'GXV\Z("5S`$5R<F\@86\@97AC;'5I<B!L;V<@9&4@<VEN
M8W)O;FEZ8>?C;SH@)7,`17)R;R!A;R!O8G1E<B!C;VYT9?ID;SH@)7,`17)R
M;R!A;R!A='5A;&EZ87(@82!S96YH83H@)7,`17)R;R!N82!M96YS86=E;2X`
M17)R;R!G<F%V86YD;R`G)7,G+@!%<W3T;FEA`$5T:?-P:6$`R71N:6-O`$5U
M<F]P80!#861A(#$U(&UI;G5T;W,`0V%D82`R(&UI;G5T;W,`0V%D82`S,"!S
M96=U;F1O<P!#861A(#4@;6EN=71O<P!#861A($-O;F5XXV\`0V%D82!M96EA
M(&AO<F$`0V%D82!M:6YU=&\`5F%L;W)E<R!D92!E>&5M<&QO.@!%>&5C=71A
M<@!%>'!A;F1I<@!%>'!A;F1I<B!"87)R82!,871E<F%L`$5S<&5R861O("<I
M)P!%<W!E<F%D;R!U;6$@<&%L879R82!O=2!T97)M;R!D92!P97-Q=6ES82!E
M;G1R92!A<W!A<P!$871A(&1E($5X<&ER8>?C;P!%>'!O96YT90!#;W(@9&\@
M<')I;65I<F\@<&QA;F\`0V]N9FEG=7)AY^-O(&1E(&5N=FEO(&1E(&%R<75I
M=F]S($944`!&86QH82!O8G1E;F1O('!R969E<NIN8VEA<RX`1F%L:&$@86\@
M8V]N96-T87(@86\@<V5R=FED;W(@3$1!4"X`1F%L:&$@86\@8V]N96-T87(@
M86\@<V5R=FED;W(@4TU"+@!&86QH82!A;R!C;W!I87(@9&4@(B5S(BX`1F%L
M:&$@86\@8V]P:6%R('!A<F$@(B5S(BX`1F%L:&$@86\@8W)I87(@=6UA(&YO
M=F$@8V]N97CC;R!305-,+@!&86QH82!A;R!M;W9E<B!P87)A("(E<R(N`$9A
M;&AA(&%O(&]B=&5R.B`E<P!*=7-T;P!);&AA<R!&86QK;&%N9"`H36%L=FEN
M87,I`$EL:&%S($9A<F]E`$5R<F\@1F%T86PZ`$9A>`!&87AE<P!&979E<F5I
M<F\`4V5N<V'GXV\@5.ER;6EC80!396YS8>?C;R!TZ7)M:6-A.B``4&%N8V%D
M87,@9&4@0VAU=F$`3F5V92!&<F%C80!-871R:7H@9&\@8V%M<&\`1FEG;&5T
M($-!4%1#2$$`1F]N=&4@1FEG;&5T`$9I:FD`87)Q=6EV;P!#;VYT86=E;2!D
M92!!<G%U:79O<SH@)7,@87)Q=6EV;P!#;VYT86=E;2!D92!!<G%U:79O<SH@
M)7,@87)Q=6EV;W,`1V5R96YC:6%D;W(@9&4@07)Q=6EV;W,`3F]M92!D;R!!
M<G%U:79O`%-E;&7GXV\@9&4@87)Q=6EV;P!%;G9I;R!D92!A<G%U:79O`$5N
M=FEO(&1E(&%R<75I=F]S(&[C;R#I('-U<&]R=&%D;RX`1FEL=')O<P!&:6YL
MXFYD:6$`4')I;65I<F$@365T861E`%!R:6UE:7)O(%%U87)T;P!487AA(&9I
M>&$`1VER87(`1&ES<&]S:>?C;P!.Z79O80!087-T82`E<R!NXV\@97AI<W1E
M`$-O<B!D82!&;VYT90!#;VUI9&$`4&%R82!N879E9V%D;W)E<R!Q=64@;N-O
M('-U<&]R=&%M(&EM86=E;G,`4')E=FESXV\@*%1!1BD`1&EA<R!0<F5V:7-T
M;W,@*$YO=&4@<75E(&$@<')E=FESXV\@<F5T;W)N861A(&5X:6)E(&%M8F]S
M(&1I82!E(&YO:71E.R!U;2!N^FUE<F\@;75I=&\@86QT;R!A<75I('!O9&4@
M<F5S=6QT87(@96T@=6T@8FQO8V\@97AT96YS;RD`17-Q=65C974@82!S96YH
M83\`1F]R;75LX7)I;W,`4V]R=&4`5&EP;R!D92!3;W)T90!3;W)T97,`4V]R
M=&5S(#(`1O-R=6YS`%)E9&ER96-I;VYA;65N=&]S`%-E>`!1=6%D<F]S`$9R
M86[G80!&<F%NYV$@365T<F]P;VQI=&%N80!'=6EA;F$@1G)A;F-E<V$`4&]L
M:6[I<VEA($9R86YC97-A`%1E<G)I=/-R:6]S($9R86YC97-E<R!D;R!3=6P`
M1&4`1&\H82D`1&5S8W)IY^-O($-O;7!L971A`$QU82!#:&5I80!.;VUE($-O
M;7!L971O`$=A8N-O`$=A;&5R:6$@9&4@;VYD92!O8G1E<B!A<R!I;6%G96YS
M`$=A;&5R:6$Z`$?B;6)I80!'97)A<B!A($-O;F9I9W5R8>?C;R!D92`E<P!#
M\V1I9V\@1V5R861O`$=E\W)G:6$`06QE;6%N:&$`1V%N80!':6)R86QT87(`
M4')I;65I<F\@3F]M90!/<.?U97,@1VQO8F%I<P!)<@!';V5D96P`1V]O9VQE
M($UA<&%S`%!E<W%U:7-A<B!N;R!';V]G;&4`17-C86QA(&1E($-I;GIA<P!'
M<NEC:6$`1W)E9V\@*$E33RTX.#4Y+3<I`$=R;V5LXFYD:6$`1W)A;F%D80!!
M9&UI;FES=')AY^-O(&1E($=R=7!O<P!.;VUE<R!D92!G<G5P;W,@;N-O(&1E
M=F5M(&5S=&%R(&5M(&)R86YC;P!'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&%D
M:6-I;VYA<B!G<G5P;R`E<RX@27-T;R#I(&\@<75E(&\@<V5R=FED;W(@9&ES
M<V4Z(`!'<F]U<%]L9&%P.B!);7!O<W/M=F5L(&5X8VQU:7(@9W)U<&\@)7,`
M1W)O=7!?;&1A<#H@26UP;W-S[79E;"!A='5A;&EZ87(@9W)U<&\@)7,`1W)U
M<&]S`$=U861A;'5P90!'=6%M`$=U871E;&%M80!'=65R;G-E>0!097)M:7-S
M]65S(&1E($-O;G9I9&%D;P!,:79R;R!D92!6:7-I=&%S`$=U:6[I`$=U:6[I
M+4)I<W-A=0!'=6EA;F$`2%1-3`!(5$U,07)E82!S92!N96=A(&-O=F%R9&5M
M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@8^EL=6QA(&1A(&QI;FAA+@!(5$U,
M07)E82!S92!N96=A(&-O=F%R9&5M96YT92!A(&5X8VQU:7(@82#Z;'1I;6$@
M8V]L=6YA(&1A('1A8F5L82X`2%1-3$%R96$@<V4@;F5G82!C;W9A<F1E;65N
M=&4@82!E>&-L=6ER(&$@^FQT:6UA(&QI;FAA(&1A('1A8F5L82X`075T96YT
M:6-AY^-O($A45%`@;N-O(&5N8V]N=')A9&$N`$AA:71I`$%L9V]R:71M;R!(
M87-H`$YE8FQI;F$`0V%B9>=A;&AO`$-A8F7G86QH;P!);&AA($AE87)D(&4@
M26QH87,@36-$;VYA;&0`5&5M<&5S=&%D92!&;W)T90!(96)R974@*$E33RTX
M.#4Y+3@M22D`06QT=7)A`$%J=61A`$%J=61A(&1O(&5D:71O<@!!<W-I<W1E
M;G1E`$AE;6ES9NER:6\`07%U:2!E<W3A(&\@:6[M8VEO(&1O(&%R<75I=F\Z
M`$%L=&$`25]N[6-I;P!386YT82!3Z2`H0VED861E+45S=&%D;R!D;R!6871I
M8V%N;RD`26[M8VEO`$5N9&5R9>=O(%)E<VED96YC:6%L`$1I<F5T\W)I;R!0
M97-S;V%L`$9O;F4@4F5S:61E;F-I86P`2&]N9'5R87,`2&]N9R!+;VYG`$AO
M<F1E`$AO<F1E+TMO;&%B.B!$861O(%A-3"`E<R!I;G;A;&ED;R!E;F-O;G1R
M861O(&YA(&UE;G-A9V5M("5S`$AO<F1E+TMO;&%B.B!.96YH=6UA(&UE;G-A
M9V5M(&-O<G)E<W!O;F1E(&%O(&]B:F5T;R`E<P!(;W)D92]+;VQA8CH@3F5N
M:'5M(&]B:F5T;R!D;R!T:7!O("5S(&9O:2!E;F-O;G1R861O(&YA(&UE;G-A
M9V5M("5S`$AO<F1E+TMO;&%B.B!296UO=FED;R!C;VT@<W5C97-S;R`E<R`B
M)7,B`$AO<F1E+TMO;&%B.B!!(&5N9VEN92!D92!I;G1E9W)AY^-O(')E<75E
M<B!A(&5X=&5N<^-O(%!(4"`G9&]M>&UL)P!(;W)D92]+;VQA8CH@26UP;W-S
M[79E;"!C<FEA<B!U;6$@;F]V82#A<G9O<F4@6$U,('!A<F$@;R!O8FIE=&\@
M)7,`2&]R9&4O2V]L86(Z($EM<&]S<^UV96P@<F5M;W9E<B`E<R`B)7,B.B`E
M<P!(;W)D92]+;VQA8CH@26UP;W-S[79E;"!O8G1E<B!A(&ED96YT:69I8V'G
MXV\@34E-12!P87)A(&$@<&%R=&4@9&\@=&EP;R`E<P!(;W)D92]+;VQA8CH@
M26UP;W-S[79E;"!S:6YC<F]N:7IA<B`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@26UP;W-S[79E;"!S:6YC<F]N:7IA<B!C;VUP87)T:6QH86UE;G1O<SH@
M)7,`2&]R9&4O2V]L86(Z($-O;7!A<G1I;&AA;65N=&\@9&5S8V]N:&5C:61O
M("(E<R(`3&EN:&$@2&]R:7IO;G1A;`!-87)G96T@:&]R:7IO;G1A;`!(;W)I
M>F]N=&%L.@!#;VUO('9O8^H@8VAE9V]U(&%Q=6D_("A0;W(@9F%V;W(@8V]M
M=6YI<75E(2D`475A;G1A<R!C;VQU;F%S('9O8^H@9V]S=&%R:6$@9&4@;65S
M8VQA<C\`475A;G1O<R!C86UP;W,@*&-O;'5N87,I(&5X:7-T96T_`%%U86YT
M87,@;&EN:&%S('9O8^H@9V]S=&%R:6$@9&4@;65S8VQA<C\`56UI9&%D90!5
M;6ED861E.B``2'5M;W)I<W1A<P!(=6YG<NUA`$9A;&AA(&%O(&-R:6%R(&-A
M:7AA('!O<W1A;"!)34%0.B`E<P!&86QH82!A;R!E>&-L=6ER(&-A:7AA('!O
M<W1A;"!)34%0.B`E<P!&86QH82!A;R!C<FEA<B!Q=6]T82!D82!C86EX82!P
M;W-T86P@24U!4#H@)7,`16YD97)EYV\@25``16YD97)EYV\@25`@;N-O(&1I
M<W!O;NUV96PN`$5N9&5R9>=O($E0(&[C;R!E<W3A(&YO(&)L;V-O('!E<FUI
M=&ED;R!#2412+@!6:6]L8>?C;R!D;R!B;&]Q=65I;R!)4"X`25]N<VER82!,
M:6YH82!!;G1E<P!)<VSB;F1I80!3;VUE;G1E(,UC;VYE<P#-8V]N97,@<&%R
M82`E<P#-8V]N97,@92!T97AT;P!.;VUE(&1A(&ED96YT:61A9&4Z`%-E(&[C
M;R!F;W(@97AI8FED;R!C;W)R971A;65N=&4L("5S('!A<F$@86)R[2UL;R!E
M;2!U;6$@;F]V82!J86YE;&$N`%-E('9O8^H@;N-O(';J(&YE;FAU;2#M8V]N
M92!A;R!U=&EL:7IA<B!O($EN=&5R;F5T($5X<&QO<F5R+"!V;V/J('!O9&4@
M8VAE8V%R(&5S=&$@8V%I>&$@<&%R82!D97-A8FEL:71A<B!A('1R86YS<&%R
MZFYC:6$@4$Y'+@!392!V;V/J(';J(&5S=&$@;65N<V%G96T@;6%S(&[C;R!A
M(&EM86=E;2P@82!I;6%G96T@<75E('9O8^H@<75E<B!E;G9I87(@;N-O('!O
M9&4@<V5R(&5X:6)I9&$@<&5L;R!S974@;F%V96=A9&]R+@!0<NDM=FES=6%L
M:7IAY^-O(&1A($EM86=E;3H`55),(&1A($EM86=E;0!54DP@9&$@26UA9V5M
M.@!);6%G96T@9&$@9V%L97)I80!);6%G96T@9&$@9V%L97)I83H`16YV:6\@
M9&4@26UA9V5M`$EM86=E;G,`26UP;W)T87(L(%!A<W-O("5D`$-A;7!O(&EM
M<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D;W,Z`$EN7W-E<FER($QI;FAA
M($%P\W,`0_-D:6=O(&1E(&'GXV\@9F]R;F5C:61O(&5S=.$@:6YC;W)R971O
M+@!5<W7A<FEO(&4O;W4@<V5N:&$@:6YC;W)R971O<RX`57-UX7)I;R!O=2!E
M;F1E<F7G;R!A;'1E<FYA=&EV;R!I;F-O<G)E=&]S+B!496YT92!N;W9A;65N
M=&4@;W4@96YT<F4@96T@8V]N=&%T;R!C;VT@;R!A9&UI;FES=')A9&]R('-E
M('9O8^H@;F5C97-S:71A(&1E(&UA:7,@86IU9&$N`$%U;65N=&%R($ED96YT
M8>?C;P#-;F1I80!5<W7A<FEO<R!I;F1I=FED=6%I<P!);F1O;NES:6$`26YF
M;W)M8>?C;P!);F9O<FUAY^-O`$[C;R!E>&ES=&5M(&]PY_5E<R!D:7-P;V[M
M=F5I<RX`26YS97)I<B!#7V]L=6YA($%P\W,`26YS97)I<B!);6%G96T`26YS
M97)I<B!486)E;&$`26YS97)I<B!,:6YK(&1A(%=E8@!);G-E<FER(%]#;VQU
M;F$@06YT97,`26YS97)I<B!U;6$@;F]V82!C;VQU;F$@87#S<R!A(&%T=6%L
M`$EN<V5R:7(@=6UA(&YO=F$@8V]L=6YA(&%N=&5S(&1A(&%T=6%L`$EN<V5R
M:7(@=6UA(&YO=F$@;&EN:&$@87#S<R!A(&%T=6%L`$EN<V5R:7(@=6UA(&YO
M=F$@;&EN:&$@86YT97,@9&$@871U86P`26YS97)I<B!U;2!P87+A9W)A9F\@
M87#S<R!O(&%T=6%L`$EN<V5R:7(@=6T@<&%RX6=R869O(&%N=&5S(&1O(&%T
M=6%L`$EN<V5R:7(@=6T@;6]D96QO(&%L=&5R;F%T:79O`$9O<FYEYV$@=6T@
M96YD97)EYV\@9&4@92UM86EL(&YO('%U86P@=F]CZB!P;V1E(')E8V5B97(@
M82!N;W9A('-E;FAA.@!);G-E<FER(&/I;'5L82!A</-S`$EN<V5R:7(@8^EL
M=6QA(&%N=&5S`$EN<V5R:7(@8V]L=6YA(&%P\W,`26YS97)I<B!C;VQU;F$@
M86YT97,`26YS97)I<B!M96YS86=E;G,`26YS97)I<B!P87+A9W)A9F\@87#S
M<P!);G-E<FER('!A<N%G<F%F;R!A;G1E<P!);G-E<FER(&QI;FAA(&%P\W,`
M26YS97)I<B!L:6YH82!A;G1E<P!&;W)N9>=A(&$@<F5S<&]S=&$@;V)R:6=A
M=/-R:6$@<&%R82!A('!E<F=U;G1A(&1E('-E9W5R86[G83H`26YS97)I<B]!
M;'1E<F%R($EM86=E;0!);G-E<FER+T%L=&5R87(@3&EN:P!#<NED:71O(&EN
M<W5F:6-I96YT92!P87)A(&5N=FEA<B!P87)A(&$@;&ES=&$@9&4@9&ES=')I
M8G5IY^-O+@!#<NED:71O(&EN<W5F:6-I96YT92X`3OIM97)O($EN=&5I<F\`
M3&ES=&$@9&4@26YT96ER;W,`0T15("A#86)EYV%L:&\@9&4@1&%D;W,@9&4@
M57-UX7)I;RD@:6YVX6QI9&\N`$1A9&]S(%I)4"!I;G;A;&ED;W,`07!L:6-A
MY^-O(&EN=N%L:61A+@!)9&5N=&EF:6-AY^-O(&1O(&)A=&-H(&EN=N%L:61A
M+@!$861O<R!E;G9I861O<R!SXV\@:6YVX6QI9&]S+@!%;F1E<F7G;R!D92!D
M97-T:6YO(.D@:6YVX6QI9&\N`$9O<FUA=&\@9&\@87)Q=6EV;R#I(&EN=N%L
M:61O`$[Z;65R;R!D92!L:6-E;N=A(&EN=N%L:61O+@!,;V-A;&EZ8>?C;R!F
M;W)N96-I9&$@Z2!I;G;A;&ED82X`5&EP;R!D82!M96YS86=E;2#I(&EN=N%L
M:61O+@!!<&E?:60@Z2!I;G;A;&ED;R!O=2!E<W3A(&9A;'1A;F1O+@!087+B
M;65T<F]S(&EN=N%L:61O<R!O=2!F86QT86YD;RX`4&5R;6ES<_5E<R!D;R!P
M86D@<^-O(&EN=N%L:61A<RX`4&5R;6ES<_5E<R!D;R!P86D@<^-O(&EN=N%L
M:61A<RX`0_-D:6=O(&1O('!R;V1U=&\@Z2!I;G;A;&ED;RX`4')O=&]C;VQO
M(&EN=N%L:61O+@!$97-T:6YA=.%R:6\@:6YVX6QI9&\Z("<E<R<`3V)J971O
M(&-O;7!A<G1I;&AA9&\@:6YVX6QI9&\`1F]N=&4@9&\@96YD97)EYV\@:6YV
MX6QI9&$N`$1A9&]S('5N:6-O9&4@:6YVX6QI9&]S+@!);G9E;G3A<FEO`$EN
M=F5R=&5R('-E;&7GXV\`27+C+"!297#Z8FQI8V$@27-LXFUI8V$@9&\`27)A
M<75E`$ER;&%N9&$`26QH82!D;R!(;VUE;0!496UP97-T861E<R!)<V]L861A
M<P!)<W)A96P`16UI<W-O<@!)=.%L:6-O`$ETX6QI80!*86UA:6-A`$IA;F5I
M<F\`2F%PXV\`2F%P;V[J<R`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)DXFYI
M80!*=6QH;P!*=6YH;P!*=7-T:69I8V%R`$%L:6YH87(@86\@0V5N=')O`$IU
M<W1I9FEC87(`06QI;FAA<B#@($5S<75E<F1A`$%L:6YH87(@X"!$:7)E:71A
M`$-A>F%Q=6ES=.-O`$UA;G1E<B!O(&]R:6=I;F%L/P!1=>IN:6$`4V5R=FED
M;W(@:V5R8F5R;W,@<F5J96ET;W4@82!A=71E;G1I8V'GXV\N`$YO=F%T;W,@
M9&4@2V5R;F5L`$-R:6'GXV\@9&4@0VAA=F4`26UP<F5S<^-O($1I9VET86P@
M9&$@0VAA=F4`5&%M86YH;R!D82!#:&%V90!4:7!O(&1A($-H879E`%5S;R!D
M82!#:&%V90!#:&%V92!JX2!E>&ES=&4@;F\@<V5R=FED;W(@9&4@8VAA=F5S
M('#Z8FQI8V%S+@!#<FEA;N=A<P!+:7)I8F%T:0!#;W+I:6$L(%)E</IB;&EC
M82!0;W!U;&%R($1E;6]C<N%T:6-A(&1A`$-O<NEI82P@4F5P^F)L:6-A(&1A
M`$-O<F5A;F\@*$550RU+4BD`2W5W86ET`%%U:7)G=6ES=.-O`$QA7WEO=70`
M261I;VUA`$QA;R!297#Z8FQI8V$@1&5M;V-RX71I8V$@4&]P=6QA<@#:;'1I
M;6$@365T861E`$=E<F%R($YO=F$@4V5N:&$`VFQT:6UO(%%U87)T;P#:;'1I
M;6$@071U86QI>F'GXV\Z`-IL=&EM;R!L;V=I;CH@)7,`VFQT:6UO(&QO9VEN
M.B`E<R#@('!A<G1I<B!D92`E<P#:;'1I;6\@;&]G:6XZ($YU;F-A`$QE=/1N
M:6$`3&5I`$QA>6]U=`!$96EX82!V87II;R!S92!Q=6ES97(@<V5M(&)O<F1A
M`$SM8F%N;P!%<W%U97)D80!#86)EYV%L:&\@97-Q=65R9&\`5F%L;W)E<R!D
M82!E<W%U97)D80!,97-O=&\`06UO<@!,:6+I<FEA`$SM8FEA(,%R86)E($IA
M;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!#:&EV:7-C;T9R86-O`$-H=79A($9R
M86-A`$-H=79A($9R86-A($UA='5T:6YA`$-H=79A($9R86-A(%9E<W!E<G1I
M;F$`3&5V97,@4&%N8V%D87,@9&4@0VAU=F$`0VAU=F%S($9R86-A<R!C;VT@
M5')O=O5E<P!.979E($9R86-A`$)R979E($YE=F%S8V$`4&_J;6%S`$QI;FL`
M3&EN:R!A<&]N=&$@<&%R83H`3&EG87(@;R!E;F1E<F7G;R!D92!E+6UA:6P@
MX"!PX6=I;F$@9&4@8V]M<&]S:>?C;R!A;R!E>&EB:7(`3&EN:W,`0V]O:VEE
M(&1O($QI;G5X`$QI<W1A<B`M('5S=>%R:6\@<&]D92!V97(@82!P87-T80!,
M:7-T87(@0F%N8V]S(&1E($1A9&]S`$QI<W1A<B!4\W!I8V]S(&1E($%J=61A
M`$QI<W1A<B!486)E;&%S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)
M9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N
M<W5B<V-R:6)E`$$@;&ES=&%G96T@9&4@<V5S<_5E<R!F86QH;W4Z("5S`$$@
M;&ES=&%G96T@9&4@=7-UX7)I;W,@9F%L:&]U.B`E<P!,:7-T86=E;2!D92!U
M<W7A<FEO<R!E<W3A(&1E<V%B:6QI=&%D82X`3&ET97)A='5R80!,:71UXFYI
M80!#87)R96=A;F1O+BXN`$AO<F$@;&]C86PZ(`!,;V-A;&EZ8>?C;R!E($AO
M<F$`4F5G:>-O`$-O;F5C=&%R`$QO9R!D82!S97-SXV\@9&4@<VEN8W)O;FEZ
M8>?C;R!A;G1E<FEO<@!$97-C;VYE8W1A<@!#;VYE8W1A<@!487)E9F%S(&1E
M($-O;F5XXV\`3R!L;V=I;B!F86QH;W4@<&]R<75E('-E=2!U<W7A<FEO(&]U
M('-E;FAA(&5S=&%V82!I;F-O<G)E=&$N`$9A;&AA(&1E($QO9VEN+@!497AT
M;R!L;VYG;P!!;6]R`$)A:7AA`$%L9F%B971O(&=R96=O(&5M(&UI;OIS8W5L
M;P!!;&9A8F5T;R!L871I;F\@96T@;6EN^G-C=6QO`$[Z;65R;W,@<F]M86YO
M<R!E;2!M:6[Z<V-U;&\`3'5X96UB=7)G;P!-30!-3U1$`$\@86YE>&\@35,M
M5$Y%1B!NXV\@8V]N=.EM(&1A9&]S+@!-4T<`36%C86\`36%C961O;FEA+"!!
M;G1I9V$@4F5P^F)L:6-A($EU9V]S;.%V:6$@9&$`36%D86=A<V-A<@!-X6=I
M8V\`0V]R<F5I;P!!9&UI;FES=')A9&]R(&1O($-O<G)E:6\`0W)I87(@;&EN
M7VLN+BX`36%L87=I`$UA;.%S:6$`36%L9&EV87,`36%L:0!-86QT80!'97)E
M;F-I82!A(&QI<W1A(&1E(&-A=&5G;W)I87,@92!A<R!C;W)E<R!A<W-O8VEA
M9&%S(&$@96QA<RX`36%P96%M96YT;R!-87`R-`!-87!E86UE;G1O($UA<%%U
M97-T`$UA<&5A;65N=&]S(&=R879A9&]S+@!-87+G;P!-87)G96T`36%R8V%R
M(&-O;2!F;&%G<R!,:61A+T[C;R!,:61A`$UA<F-A<B!C;VT@;W5T<F]S(&9L
M86=S("AE>"X@26UP;W)T86YT92]297-P;VYD:61A*0!);&AA<R!-87)S:&%L
M;`!-87)T:6YI8V$`0V%M<&]S(&-O<G)E<W!O;F1E;G1E<P!-875R:73B;FEA
M`$UA=7+M8VEO`$-RZ61I=&\@;>%X:6UO('!E<FUI=&ED;RX`3OIM97)O(&WA
M>&EM;R!D92!P87)T97,@9&$@;65N<V%G96T@97AC961E=2X`5&5M<&5R871U
M<F$@;>%X:6UA(&YA<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<&5R871U<F$@
M;>%X:6UA(&YA<R#Z;'1I;6%S(#8@:&]R87,Z(`!.^FUE<F\@3>%X:6UO(&1E
M($)L;V-O<R!D92!0;W)T86P`5&%M86YH;R!MX7AI;6\`36%I;P!-87EO='1E
M`$UE9&EC:6YA`$UE;6)R;W,`36]D;R!D;R!M96YU.@!-97-C;&%R(&/I;'5L
M87,`365N<V%G96T`365N<V%G96T@5F5R:69I8V%D82!C;VT@4W5C97-S;R!M
M87,@;R!C97)T:69I8V%D;R!D;R!A<W-I;F%N=&4@;N-O('#T9&4@<V5R('9E
M<FEF:6-A9&\N`$UE;G-A9V5M(&5X<&ER861A+@!4:7!O(&1E(&UE;G-A9V5M
M`$-L:6UA($UE=&%R`$)L;V-O($UE=&%R(&[C;R!D:7-P;V[M=F5L+@!";&]C
M;R!-971A<B!NXV\@9&ES<&]N[79E;"X@1&5T86QH97,@9F]R86T@9W)A=F%D
M;W,@96T@;&]G('!A<F$@;R!A9&UI;FES=')A9&]R+@!/($UE=&%R1$(@;N-O
M(&5S=.$@8V]N96-T861O+@!-Z71O9&\`3>ET;V1O("<E<R<@;N-O(&5S=.$@
M9&5F:6YI9&\`3>ET;V1O(&[C;R!D969I;FED;RX@3>ET;V1O(&-H86UA9&\Z
M("5S`$WI=')I8V$`3>EX:6-O`$UI8W)O;NES:6$L($5S=&%D;W,@1F5D97)A
M9&]S(&1A`$UE:6\`5&EP;R!-:6UE`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@
M^FQT:6UA<R`R-"!H;W)A<SH@`%1E;7!E<F%T=7)A(&WM;FEM82!N87,@^FQT
M:6UA<R`V(&AO<F%S.B``261A9&4@;>UN:6UA(&1A('-E;FAA(&%I;F1A(&[C
M;R!E>'!I<F]U`$5S<&5L:&\`1&EV97)S;W,`4&%C;W1E(%!%05(@2%144%]2
M97%U97-T(&9A;'1A;F1O+@!#;VYF:6=U<F'GXV\@9F%L=&%N9&\N(%9O8^H@
M=&5M('%U92!G97)A<B!E;&$@86=O<F$@<V4@=F]CZB!Q=65R('5T:6QI>F%R
M(&5S=&$@87!L:6-AY^-O+@!)1"!D82!M96YS86=E;2!F86QT86YD;RX`4&%C
M;W1E(&]B<FEG873S<FEO(%!%05(@36%I;"!F86QT86YD;RX`240@9&$@<V5S
M<^-O(&9A;'1A;F1O+@!396<`0V]R<F5I;R!-\W9E;`!-;V1E<F%R`$1A=&$@
M36]D:69I8V%D80!!;'1E<F%R(%523`!-\V1U;&\`36]L9&]V82P@4F5P^F)L
M:6-A(&1A`$WT;F%C;P!-;VYG\VQI80!-ZG,@92!A;F\`365N<V%L;65N=&4`
M36]N='-E<G)A=`!&87-E<R!D82!,=6$`36%I<R!C86UP;W,@96YC;VYT<F%D
M;W,@;F$@;&EN:&$@)60@<75E(&\@;OIM97)O(&5S<&5R861O("5D+@!-87)R
M;V-O<P!'<F%N9&4@4&%R=&4@3&EM<&$`1W)A;F1E(%!A<G1E($YU8FQA9&\`
M1W)A;F1E(%!A<G1E($5N<V]L87)A9&\`36]V97(@06)A:7AO`$UO=F5R(.`@
M17-Q=65R9&$`36]V97(@X"!$:7)E:71A`$UO=F5R($%C:6UA`$%B86EX;P!!
M8VEM80!-;^=A;6)I<75E`$QI<W1A<R!D92!S96QEY^-O(&1E(&WZ;'1I<&QO
M<R!N[79E:7,`36%P87,@26YG;&5S97,@375L=&EM87``4V5L9>?C;R!M^FQT
M:7!L80!-:6YH82!#;VYT80!3=6%S($EN9F]R;6'G]65S`$UE=2!0;W)T86P`
M365U($QA>6]U="!D92!0;W)T86P`0FER;>)N:6$`3L-/+"!%=2!.PT\@0V]N
M8V]R9&\`3F]M90!.86WM8FEA`$YA=7)U`$YE<&%L`$AO;&%N9&$`06YT:6QH
M87,@2&]L86YD97-A<P!54DP@0F%S92!D;R!.971S8V%P90!54DP@9&4@4F5V
M;V=AY^-O(&1E($-!(&1O($YE='-C87!E`%523"!D92!P;VSM=&EC87,@9&4@
M0T$@9&\@3F5T<V-A<&4`55),(&1E(%)E;F]V8>?C;R!D;R!.971S8V%P90!5
M4DP@9&4@4F5V;V=AY^-O(&1O($YE='-C87!E`$YO;64@9&\@<V5R=FED;W(@
M4U-,(&1O($YE='-C87!E`$-O;65N=.%R:6\@9&\@8V5R=&EF:6-A9&\@9&\@
M3F5T<V-A<&4`5&EP;R!D92!C97)T:69I8V%D;R!D;R!.971S8V%P90!2961E
M`$YU;F-A`$YO=F$@0V%L963T;FEA`$YO=F$@0V%T96=O<FEA`$YO=F$@365N
M<V%G96T@<&%R82`E<P!,=6$@3F]V80!.;W9O(%5S=>%R:6\@*&]P8VEO;F%L
M*0!.;W9A(%IE;.)N9&EA`$YO=F$@<V5N:&$`3F]V82!S96YH82!E>'!I<F%R
MX2!E;2`E>"X`07,@;F]V87,@<V5N:&%S(&[C;R!SXV\@:6=U86ES+@!.;W9A
M(&IA;F5L82`H7V)L86YK*0!.;W3M8VEA<P!'<G5P;W,@9&4@3F]T[6-I87,`
M4'+S>&EM80!0<O-X:6UA<R`T($9A<V5S`%!R\WAI;6%S(&]PY_5E<P!0<O-X
M:6UA/@!.:6-A<N%G=6$`3FEG97(`3FEGZ7)I80!.;VET90!.:75E`$[C;P!.
M96YH=6T@9&%D;R!D92!C;VYF:6=U<F'GXV\@9&ES<&]N[79E;"!P87)A(&5X
M:6)I<B!A<R!D:69E<F5NYV%S+@!.96YH=6UA(&5S=')A=.EG:6$@9&ES<&]N
M[79E;"!P87)A(&-R:6%R(&EM86=E;G,@25-/+@!.96YH=6T@;6]D96QO(&1E
M(&)A=&-H+@!.96YH=6T@8FQO8V\@97AI<W1E(&YA('!O<VGGXV\@<V]L:6-I
M=&%D80!.96YH=6T@;F]M92!D92!A9V5N9&$@9F]R;F5C:61O('!A<F$@82!A
M=71E;G1I8V'GXV\@34-!3"X`3F5N:'5M82!A;'1E<F'GXV\N`$YE;FAU;2!S
M=6)O<F1I;F%D;R!P;V1E('-E<B!A9&EC:6]N861O(&$@97-T82!P97)M:7-S
MXV\N`$YE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U<F'GXV\@97-P96-I
M9FEC861A('!A<F$@)7,N`$YE;FAU;6$@:6YF;W)M8>?C;R!D92!C;VYF:6=U
M<F'GXV\@97-P96-I9FEC861A('!A<F$@1E10(%9&4RX`3F5N:'5M82!I;F9O
M<FUAY^-O(&1E(&-O;F9I9W5R8>?C;R!E<W!E8VEF:6-A9&$@<&%R82!344P@
M5D93+@!.96YH=6UA(&EN9F]R;6'GXV\@9&4@8V]N9FEG=7)AY^-O(&5S<&5C
M:69I8V%D82!P87)A(%-13"U&:6QE(%9&4RX`3F5N:'5M(&-RZ61I=&\@<F5S
M=&%N=&4N`$YE;FAU;2!D97-T:6YO(&9O<FYE8VED;RX`3F5N:'5M(&%R<75I
M=F\@96YV:6%D;P!.96YH=6T@[6-O;F4@96YC;VYT<F%D;RX`3F5N:'5M82!L
M;V-A;&EZ8>?C;R!C;VYF:6=U<F%D82X`3F5N:'5M82!L;V-A;&EZ8>?C;R!C
M;VYF:6=U<F%D82X`3F5N:'5M82!M96YS86=E;2!F;W)N96-I9&$N`$YE;FAU
M;2!N;VUE(&5S<&5C:69I8V%D;RX`3F5N:'5M(&[Z;65R;R!E<W!E8VEF:6-A
M9&\N`%-E;2!S;W)T97,@;V9E;G-I=F%S`$YE;FAU;6$@<V5N:&$@9F]R;F5C
M:61A('!A<F$@82!A=71E;G1I8V'GXV\@2%144"X`3F5N:'5M82!S96YH82!F
M;W)N96-I9&$@<&%R82!A(&%U=&5N=&EC8>?C;R!)34%0+@!.96YH=6UA('-E
M;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($ME<F)E<F]S+@!.
M96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-AY^-O($QO
M9VEN+@!.96YH=6UA('-E;FAA(&9O<FYE8VED82!P87)A(&$@875T96YT:6-A
MY^-O(%!!4U-71"X`3F5N:'5M82!S96YH82!F;W)N96-I9&$@<&%R82!A(&%U
M=&5N=&EC8>?C;R!334(N`$YE;FAU;2!P871H('!A<F$@;R!B:6[A<FEO(&1O
M($]P96Y34TP@9F]I(&9O<FYE8VED;RX@3R!B:6[A<FEO(&1O($]P96Y34TP@
MZ2!N96-E<W/A<FEO('!A<F$@;6%N:7!U;&%R(&]S(&1A9&]S(%!+0U,@,3(N
M`$YE;FAU;2!C861A<W1R;R!P96YD96YT92X`475O=&$@;N-O(&-O;F9I9W5R
M861A+@!396T@;&EN:&%S`$YE;FAU;2!S97!A<F%D;W(@9F]I(&5S<&5C:69I
M8V%D;RX`4V5M(&QA9&]S`$%R<75I=F\@:6YE>&ES=&5N=&4`3F5N:'5M(&1I
M<F5T\W)I;R!T96UP;W+A<FEO(&1I<W!O;NUV96P@<&%R82!O(&-A8VAE+@!.
M96YH=6T@=7-UX7)I;R!E+V]U('-E;FAA(&9O<FYE8VED;W,N`$YE;FAU;2!D
M861O(%A-3"!VX6QI9&\@<F5T;W)N861O`%-E;2!V86QO<F5S`$YE;FAU;2!V
M97)SXV\@96YC;VYT<F%D82!N82!C;VYF:6=U<F'GXV\@;W)I9VEN86PN($=E
M<F4@;F]V86UE;G1E(&$@8V]N9FEG=7)AY^-O+@!.96YH=6UA('9E<G/C;R!E
M;F-O;G1R861A(&YA('-U82!C;VYF:6=U<F'GXV\N($=E<F4@;F]V86UE;G1E
M(&$@8V]N9FEG=7)AY^-O+@!.96YH=6UA`$YE;FAU;6$@*'5S;R!I;7!L[6-I
M=&\I`$[S<F1I8V\@*$E33RTX.#4Y+3$P*0!);&AA($YO<F9O;&L`2&5M:7-F
MZ7)I;R!.;W)T90!);&AA<R!-87)I86YA(&1O($YO<G1E`$YO<G5E9V$`3N-O
M($%P\W,`3N-O($%N=&5S`$[C;R#I('5M(&1I<F5T\W)I;P!.XV\@26UP;&5M
M96YT861O+@!.XV\@8V]N9FEG=7)A9&\`3N-O('-U<&]R=&%D;RX`06YO=&'G
M]65S`$YA9&$@<&%R82!E>&EB:7(L('9O;'1E+@!.;W9E;6)R;P!.^FUE<F\`
M3OIM97)O(&1E(&-A<F%C=&5R97,`3OIM97)O(&1E(&-O;'5N87,`3OIM97)O
M(&1E(&QI;FAA<P!.^FUE<F\@;N-O(&5S<&5C:69I8V%D;R!P87)A(&%T=6%L
M:7IAY^-O(&YA(&QI<W1A(&1E(&1I<W1R:6)U:>?C;RX`3TL`3V)J971O`$-R
M:6%D;W(@9&\@3V)J971O`$]C=&%L`$]U='5B<F\`1FEL=')O(&]F96YS:79O
M`$5S8W)I=/-R:6\`4V5N:&%S(&%N=&EG82!E(&YO=F$@9&5V96T@<V5R(&1I
M9F5R96YT97,N`%-E;FAA(&%N=&EG80!396YH82!A;G1I9V$@;N-O(&5S=.$@
M8V]R<F5T82X`3VWC`%-O;65N=&4@<V5R=FED;W)E<R!)34%0('-U<&]R=&%M
M('!A<W1A<R!C;VUP87)T:6QH861A<RX`4V]M96YT92!S;W)T97,@;V9E;G-I
M=F%S`%-O;65N=&4@=6T@96YD97)EYV\@9&4@92UM86EL('!E<FUI=&ED;RX`
M4V]M96YT92!O('!R;W!R:65TX7)I;R!O=2!O(&%D;6EN:7-T<F%D;W(@9&\@
M<VES=&5M82!P;V1E;2!A;'1E<F%R(&%S('!E<FUI<W/U97,@9&4@<')O<')I
M961A9&4@;W4@<')O<')I973A<FEO(&1E('5M(&-O;7!A<G1I;&AA;65N=&\`
M06)R:7(@96T@=6UA(&YO=F$@:F%N96QA`$5R<F\@9&\@3W!E;E-33#H@3N-O
M('!U9&4@97AT<F%I<B!D861O<R!D82!P87)T92!A<W-I;F%D82!3+TU)344N
M`$%B<F4@97-T92!L:6YK(&5M('5M82!N;W9A(&IA;F5L80!3:7-T96UA($]P
M97)A8VEO;F%L`$]PY_5E<P!/<.?U97,@9&4@)7,`3&ES=&$@3W)D96YA9&$`
M3W)G86YI>F'GXV\`56YI9&%D92!/<F=A;FEZ86-I;VYA;`!/<F=A;FEZ86YD
M;P!-;V1E;&\@;W)I9VEN86P@9&4@87!L:6-AY^-O`$UO9&5L;R!O<FEG:6YA
M;"!E;2`E<SH`3W5T<F\`3W5T<F%S($EN9F]R;6'G]65S`%!E<FUI<W/U97,@
M9&\@4')O<')I973A<FEO`$%U=&5N=&EC8>?C;R!004T@;N-O(&5S=.$@9&ES
M<&]N[79E;"X`0V]N96-T;W(@4$5!4CHZ36%I;`!!<W-I;F%T=7)A($1I9VET
M86P@4$=0`$1A9&]S($-R:7!T;V=R869A9&]S(&-O;2!01U``0VAA=F4@4/IB
M;&EC82!01U``1&%D;W,@07-S:6YA9&]S+T-R:7!T;V=R869A9&]S(&-O;2!0
M1U``0_-D:6=O(%!(4`!,:6YH82!D92!#;VUA;F1O(%!(4`!#:'5V82!&<F%C
M82!697-P97)T:6YA`$-H=79A(%9E<W!E<G1I;F$`0VAU=F%S(%9E<W!E<G1I
M;F%S`$YE=F4@5F5S<&5R=&EN80!.979A<V-A(%9E<W!E<G1I;F$`3F5V92!6
M97-P97)T:6YA`%1R;W9O861A<R!697-P97)T:6YA<P!%<W3A(&9A;'1A;F1O
M(&$@97AT96YSXV\@4$]325@`3&EN:&$@9&4@0V]M86YD;R!07TA0`$UA<F=E
M;0!087%U:7-TXV\`4&%L874`4&%L97-T:6YO+"!497)R:73S<FEO($]C=7!A
M9&\`4&%N86WA`%#A<'5A($YO=F$@1W5I;ND`4&%R86=U86D`4&%R8VEA;&UE
M;G1E($YU8FQA9&\`4V5N:&$`4V5N:&$@86QT97)A9&$@8V]M('-U8V5S<V\N
M`%-E;FAA(&EN8V]R<F5T80!396YH82!O8G)I9V%T\W)I82!P87)A(&$@875T
M96YT:6-AY^-O(%)!1$E54RX`4V5N:&$@8V]M(&-O;F9I<FUAY^-O`%-E;FAA
M.@!396YH83H@`%-E;FAA<R!D979E;2!S97(@:6=U86ES+@!#;VQA<@!#;VQA
M<B!D82#A<F5A(&1E('1R86YS9F5RZFYC:6$`4&%T:`!#861A<W1R;W,@4&5N
M9&5N=&5S.@!097-S;V%S`%!O<F-E;G1A9V5M`$5X96-U=&%R($]P97)AY_5E
M<R!D92!-86YU=&5NY^-O`$5X96-U=&%R(&]P97)AY_5E<R!D92!M86YU=&5N
MY^-O(&%O(&-O;F5C=&%R/P!097)M:7-SXV\`4&5R;6ES<^-O("(E<R(@;N-O
M(&5X8VQU[61A+@!097)M:7-SXV\@3F5G861A`%!E<FUI<W/U97,`061M:6YI
M<W1R8>?C;R!D92!097)M:7-S]65S`$EN9F]R;6'G]65S(%!E<W-O86ES`%!E
M<G4`06YI;6%I<R!D92!%<W1I;6'GXV\`1FEL:7!I;F%S`%1E;&5F;VYE`$9O
M=&]S`%!I=&-A:7)N`%!I>&5L<P!#;&EC:.D`4&]R(&9A=F]R(&-L:7%U92!E
M;2!A;&=U;6$@8^EL=6QA`%!O<B!F879O<B!C;VYF:7)M92!Q=64@=F]CZB!Q
M=65R(')E;6]V97(@97-T92!E;&5M96YT;SH`4&]R(&9A=F]R(&-O;F9I<FUE
M('%U92!V;V/J('%U97(@<F5M;W9E<B!O(&QI;FL@9&5S=&4@96QE;65N=&\N
M`%!O<B!F879O<B!F;W)N9>=A('5M(&WJ<R!E('5M(&%N;RX`4&]R(&9A=F]R
M(&9O<FYEYV$@=6T@;F]M92!P87)A(&$@;F]V82!C871E9V]R:6$Z`%!O<B!F
M879O<B!F;W)N9>=A('5M(&5N9&5R9>=O($E0(';A;&ED;RX`4&]R(&9A=F]R
M(&9O<FYEYV$@=6UA(&1A=&$@=N%L:61A+"!V97)I9FEQ=64@;R!N^FUE<F\@
M9&4@9&EA<R!N;R!MZG,N`%!O<B!F879O<B!F;W)N9>=A('5M82!H;W)A(';A
M;&ED82X`4&]R(&9A=F]R(&9O<FYEYV$@=6T@<F5S=6UO(&1O('!R;V)L96UA
M+@!0;W(@9F%V;W(@9F]R;F7G82!S974@=7-UX7)I;R!E('-E;FAA`%!O<B!F
M879O<B!L96EA(&\@=&5X=&\@82!S96=U:7(N(%9O8^H@1$5612!C;VYC;W)D
M87(@8V]M(&]S('1E<FUO<R!D92!U<V\@9&\@<VES=&5M82X`4&]R(&9A=F]R
M(&1I9VET92!O(&YO;64@9&$@;F]V82!C871E9V]R:6$Z`%!O;/1N:6$`4&]L
M[71I8V$`16YQ=65T90!0;W)T=6=A;`!0;W-IY^-O(&1E<W1A(&EM86=E;0!0
M;W-IY^-O(&1E<W1A('1A8F5L80!%;G9I92!P87)A(&5S=&$@<&%S=&$@*&[C
M;R#I(&]B<FEG861O('!E;&\@24U!4"D`4')E8VEP:71AY^-O('!A<F$@82AS
M*2#Z;'1I;6$H<RD@)7,@:&]R82AS*3H@`%!R96-I<&ET8>?C;SQB<B`O/F-H
M86YC90!0<F5F<U]L9&%P.B!%>'1E;G/C;R!,1$%0(&]B<FEG873S<FEA(&[C
M;R!E;F-O;G1R861A+@!0<F5F<U]S97-S:6]N.B!%>'1E;G/C;R!D92!S97-S
MXV\@;V)R:6=A=/-R:6$@;N-O(&5N8V]N=')A9&$N`%!R97-SXV\`4')E<W/C
M;R!E;2!N[79E;"!D;R!M87(Z(`!0<F5S<^-O.B``4'+I+79I<W5A;&EZ8>?C
M;P!0<F5V97(@82!I;6%G96T@96T@=6UA(&YO=F$@:F%N96QA`$]PY_5E<R!A
M;G1E<FEO<F5S`$EM<')I;6ER(&1O8W5M96YT;P!#:&%V92!0<FEV861A`%!R
M;V)L96UA`$1E<V-R:>?C;R!D;R!0<F]B;&5M80!0<F]J971O<P!497AT;R!B
M<F5V90!#:&%V92!0^F)L:6-A`$%L9V]R:71M;R!D82!#:&%V92!0^F)L:6-A
M`$-H879E(%#Z8FQI8V$`4&%R(&1E(&-H879E<R!0^F)L:6-A+U!R:79A9&$@
M;N-O(&9O<F%M(&=E<F%D;W,@8V]M('-U8V5S<V\N`%!O<G1O(%)I8V\`46%T
M87(`0V]N<W5L=&%R`%%A=&%R`$-H879E(%#Z8FQI8V$@4E-!("@E9"!B:70I
M`$)O=/5E<R!D92!S96QEY^-O`$-H=79A`$-H=79A($UA='5T:6YA`$-H=79A
M(%9E<W!E<G1I;F$`4&%N8V%D87,@9&4@0VAU=F$`0VAU=F$@92!.979E`$-H
M=79A('!A<F$@3F5V90!3;W)T92!!;&5A=/-R:6$`4F5L8>?C;P!,97(`3&5R
M(&UE;G-A9V5N<P!%>&-L=6ER(')E86QM96YT92`E<S\@17-T82!O<&5R8>?C
M;R!NXV\@<&]D92!S97(@9&5S9F5I=&$N`%)E;6]V97(@<F5A;&UE;G1E(&]S
M(&1A9&]S(&1O('5S=>%R:6\@)7,_($5S=&$@;W!E<F'GXV\@;N-O('!O9&4@
M<V5R(&1E<V9E:71A+@!2969A>B!S=6$@^FQT:6UA(&'GXV\`071U86QI>F%R
M`$%T=6%L:7IA<B!-96YU(&1E($5L96UE;G1O<R!$:6[B;6EC;W,Z`$%T=6%L
M:7IA<B!%>&EB:>?C;R!D;R!0;W)T86PZ`%)E9V5X`$YA=F5G861O<B!D92!2
M96QAY_5E<P!,97(`3V)S97)V8>?U97,`4V5R=FED;W)E<R!296UO=&]S`%52
M3"!296UO=&$@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO
M=F5R`%)E;6]V97(@0FQO8V\`4F5M;W9E<B!C;VQU;F$`4F5M;W9E<B!F;W)M
M871AY^-O`%)E;6]V97(@<&%R`%)E;6]V97(@<V-R:7!T(&=R879A9&\@;F\@
M9&ER973S<FEO('1E;7!O<N%R:6\@9&\@<V5R=FED;W(N`%)E;6]V97(@;P!2
M96UO=F5R(&5S=&4@;O,@9&\@9&]C=6UE;G1O`%)E;6]V97(@=7-UX7)I;P!2
M96UO=F5R('5S=>%R:6\Z("5S`%-O;&EC:71AY^-O(&[C;R!P]&1E('-E<B!R
M97-P;VYD:61A+B!#\V1I9V\@9&4@97)R;R!R971O<FYA9&\Z(`!/('-E<G9I
MYV\@<F5Q=6ES:71A9&\@;N-O('!O9&4@<V5R(&5N8V]N=')A9&\N`"<E<R<@
M;V)R:6=A=/-R:6\@;N-O(&9O:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)A
MY^-O("5S+@`G)7,G(&]B<FEG873S<FEO(&[C;R!F;VD@97-P96-I9FEC861O
M(&YA(&-O;F9I9W5R8>?C;R!61E,N`"<E<R<@;V)R:6=A=/-R:6\@;N-O(&9O
M:2!E<W!E8VEF:6-A9&\@;F$@8V]N9FEG=7)AY^-O+@!#86UP;R!/8G)I9V%T
M\W)I;P!,:6UP87(`1V5R87(@3F]V82!396YH80!'97)A<B!.;W9A(%-E;FAA
M`-IL=&EM;R!1=6%R=&\`4F5S=6QT861O<P!2971O<FYA<B#@($]PY_5E<P!$
M:6=I=&4@82!N;W9A('-E;FAA(&YO=F%M96YT90!2975N:>-O`%)E=F5R=&5R
M($-O;F9I9W5R8>?C;P!/<.?U97,@9&\@161I=&]R(%)I8V@@5&5X=`!#:&%R
M861A<P!$:7)E:71A`$-A8F7G86QH;R!D:7)E:71O`%9A;&]R97,@9&$@9&ER
M96ET80!0<F]P<FEE9&%D97,@9&$@7TQI;FAA+BXN`$9U;N?C;P!2;VWJ;FEA
M`$=I<F%R(#$X,"!G<F%U<P!':7)A<B!P87)A(&$@17-Q=65R9&$`1VER87(@
M<&%R82!A($1I<F5I=&$`4')O<')I961A9&5S(&1A($QI;FAA`%!R;W!R:65D
M861E<R!D82!L:6YH80!,:6YH87,Z`$QI;FAA<P!,:6YH87,@87!A<F5C97+C
M;R!E;G1R92!T;V1A<R!A<R!L:6YH87,@92!C;VQU;F%S`$QI;FAA<R!A<&%R
M96-E<N-O('-O;65N=&4@96YT<F4@8V]L=6YA<P!,:6YH87,@87!A<F5C97+C
M;R!S;VUE;G1E(&5N=')E(&QI;FAA<P!%>&5C=71A<@!&961E<F'GXV\@4G5S
M<V$`4G5A;F1A`$%S<VEN871U<F$@0W)I<'1O9W+A9FEC82!3+TU)344`365N
M<V%G96T@0W)I<'1O9W)A9F%D82!C;VT@4R]-24U%`$%U=&5N=&EC8>?C;R!3
M05-,(&[C;R!E<W3A(&1I<W!O;NUV96PN`$-O<G)E:6\@4TU3`$QI;FAA(&1E
M(&-O;6%N9&\@4U%,`%-E;G1E;N=A(%-13"!P87)A('!E<W%U:7-A<R!D92!V
M86QO<F5S`%-32`!354-%4U-/`$QI;FAA(&1E(&-O;6%N9&\@4U]13`!386(`
M4V%N=&$@2&5L96YA`%/C;R!+:71T<R!E($YE=FES`%-A;G1A($QU>FEA`%/C
M;R!0961R;R!E($UI<75E;&]N`%/C;R!6:6-E;G1E(&4@1W)A;F%D:6YA<P!-
M97-M;R!Q=6%D<F\@*%]S96QF*0!386UO80!386X@36%R:6YO`%/C;R!4;VWI
M(&4@4'+M;F-I<&4`4')O=F5D;W(@9&4@4V%TZ6QI=&4`07+A8FEA(%-A=61I
M=&$`4V%L=F%R`%-A;'9A<B`E<P!386QV87(@)7,`4V%L=F%R($]PY_5E<P!3
M86QV87(@8V]N9FEG=7)AY^-O(&=E<F%D82!C;VUO('5M('-C<FEP="!02%`@
M<&%R82!O(&1I<F5T\W)I;R!T96UP;W+A<FEO(&1O('-E=2!S97)V:61O<BX`
M0V]N9FEG=7)AY^-O("5S('-A;'9A+@!38W)I<'0@9&4@871U86QI>F'GXV\@
M9&4@8V]N9FEG=7)AY^-O('-A;'9O(&5M.B`G)7,G+@!496UP97-T861E<R!)
M<V]L861A<P!#:>IN8VEA`%!E<W%U:7-A<@!%;F=I;F5S(&1E(%!E<W%U:7-A
M(`!396QE8VEO;F4@;W,@07)Q=6EV;W,`4V5L96-I;VYE('5M82!D871A`%-E
M;&5C:6]N92!U;2!G<G5P;R!P87)A(&%D:6-I;VYA<@!396QE8VEO;F4@=6T@
M;F]V;R!M96UB<F\`4V5L96-I;VYE('5M('-E<G9I9&]R`%-E;&5C:6]N92!U
M;2!U<W7A<FEO('!A<F$@861I8VEO;F%R`%-E;&5C:6]N87(@=&]D;W,`4V5L
M96-I;VYE('1O9&]S(&]S(&-O;7!O;F5N=&5S(&1E(&1A=&$N`%-E;&5C:6]N
M92!U;2!O8FIE=&\`3N-O('-E;&5C:6]N87(@;F5N:'5M`%-E;&5C:6]N92!O
M<R!C87)A8W1E<F5S('%U92!V;V/J('!R96-I<V$@;F$@8V%I>&$@86)A:7AO
M+B!6;V/J('!O9&4@96YTXV\@8V]P:>$M;&]S(&4@8V]LX2UL;W,@;F$@X7)E
M82!D92!T97AT;RX`4V5L96-I;VYE('5M(&1E;&EM:71A9&]R(&1E(&1A=&$Z
M`%-E;&5C:6]N92!O(&9O<FUA=&\@9&4@9&%T83H`4V5L96-I;VYE(&$@:61E
M;G1I9&%D92!Q=64@=F]CZB!Q=65R(&%L=&5R87(Z`%-E;&5C:6]N92!U;2!D
M96QI;6ET861O<B!D92!H;W)A.@!396QE8VEO;F4@;R!F;W)M871O(&1E(&AO
M<F$Z`%-E;&5C:6]N92!D;VES(&-A;7!O<R!C;W)R97-P;VYD96YT97,N`%-E
M;&5C:6]N92!S974@97-Q=65M82!D92!C;W)E<RX`4V5L96-I;VYE('-E=2!I
M9&EO;6$@<')E9F5R:61O.@!%;G9I87(@4F5L873S<FEO(&1E(%!R;V)L96UA
M`$5N=FEA<B!335,`4V5N96=A;`!396YS;W(Z(`!3971E;6)R;P!397)V:6$@
M92!-;VYT96YE9W)O`$[Z;65R;R!D92!3Z7)I90!$861O<R!D;R!S97)V:61O
M<B!E<G)A9&]S(&]U(&[C;R!D:7-P;V[M=F5I<RX`061M:6YI<W1R861O<B!D
M92!397-SXV\`240@9&$@4V5S<^-O(&5X<&ER;W4N`%-E<W/U97,`06IU<W1A
M<@!#;VYF:6=U<F$@87,@;W#G]65S('!A<F$@<&5R;6ET:7(@=F]CZB!G97)A
M<B!U;6$@;F]V82!S96YH82!S92!V;V/J(&5S<75E8^HM;&$N`$-O;F9I9W5R
M82!O<R!S97)V:61O<F5S(')E;6]T;W,@<75E('9O8^H@<75E<B!A8V5S<V%R
M(.`@<&%R=&ER(&1O('!O<G1A;"X`0V]N9FEG=7)A('-E=2!I9&EO;6$@<')E
M9F5R:61O+"!F=7-O(&AO<N%R:6\@92!O<.?U97,@9&4@9&%T82X`0V]N9FEG
M=7)A('-U82!A<&QI8V'GXV\@:6YI8VEA;"P@97-Q=65M82!D92!C;W)E<RP@
M871U86QI>F'GXV\@9&4@<.%G:6YA<R!E(&]U=')A<R!O<.?U97,@9&4@97AI
M8FGGXV\N`$-O;F9I9W5R8>?C;P!38W)I<'1S(&1E(&%T=6%L:7IAY^-O(&1E
M(&-O;F9I9W5R8>?C;R!D:7-P;V[M=F5I<P!$:79E<G-A<R!L;V-A;&ED861E
M<R!P;W-S[79E:7,@8V]M(&\@<&%RXFUE=')O.B``4V5I8VAE;&5S`$-O;7!R
M87,`4F5S=6UO`%1E8VQA<R!D92!A=&%L:&\@9&5V97+C;R!S97(@9&5F:6YI
M9&%S('!A<F$@82!M86EO<FEA(&1O<R!L:6YK<S\`17AI8FER`$5X:6)I<B!A
M<R!D:69E<F5NYV%S(&5N=')E(&$@8V]N9FEG=7)AY^-O(&%T=6%L(&4@82!N
M;W9A(&=E<F%D82X`17AI8FER(&1A=&$@92!H;W)A(&1A(/IL=&EM82!C;VYE
M>.-O(&%O('-E(&-O;F5C=&%R/P!%>&EB:7(@82!O<.?C;R!D92!M86YT97(@
M;R!O<FEG:6YA;`!%>&EB:7(@<V5L971O<@!%>&EB:7(@8F%R<F$@9&4@;65N
M=2!C;VT@;W!E<F'G]65S(&1E('1A8F5L83\`17AI8FER(&\@365N=2`E<R#@
M(&5S<75E<F1A/P!%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@9&4@
M0^EL=6QA<R!D82!486)E;&$`17AI8FER(&1IX6QO9V\@9&4@4')O<')I961A
M9&5S(&1A(%1A8F5L80!%>&EB:7(@9&GA;&]G;R!D92!0<F]P<FEE9&%D97,@
M9&4@3&EN:&%S(&1A(%1A8F5L80!%>&EB:7(@9&GA;&]G;R!D92!P<F]P<FEE
M9&%D97,@9&4@:6UA9V5M`$5X:6)I<B!U<&QO860`0VAU=F%S`$-H=79A<R!M
M871I;F%I<P!#:'5V87,@5F5S<&5R=&EN87,`0VAU=F%S(&YA<R!R961O;F1E
M>F%S`%)E9'5Z:7(`4')I;65I<F%M96YT92!R961U>F$@;W4@=&ER92!D;R!C
M86UI;FAO(&\H<RD@8FQO8V\H<RD@861J86-E;G1E*',I`%-E<G)A($QE;V$`
M4F5G:7-T<F%R`$%S<VEN871U<F$`06QG;W)I=&UO(&1A($%S<VEN871U<F$`
M0VEN9V%P=7)A`%1A;6%N:&\`26=N;W)A<B!-86YU=&5NY^-O`$5S;&]VX7%U
M:6$`17-L;W9E;FEA`$YE=F4`3F5V87-C80!.979A<V-A<P!#:'5V87,@;6%T
M:6YA:7,`3F5V87-C87,@5F5S<&5R=&EN87,`4')O9G5N9&ED861E(&1A($YE
M=F4Z(`!%<75I=F%L96YT92!D92!N979E(&5M(.%G=6$Z(`!);&AA<R!386QO
M;>-O`%-O;>%L:6$`0V%NY_5E<R`F(%!O96UA<P!/<F1E;F%R('-E;&7GXV\`
M16YD97)EYV\@9&4@;W)I9V5M`,%F<FEC82!D;R!3=6P`4W5L($5U<F]P974@
M*$E33RTX.#4Y+3,I`%-U;"!D82!'96]R9VEA(&4@4W5L(&1A<R!);&AA<R!3
M86YD=>UC:&4`2&5M:7-FZ7)I;R!3=6P`17-P8>=O(&5N=')E(&/I;'5L87,@
M861J86-E;G1E<P!%<W!AYV\@96YT<F4@;R!C;VYT9?ID;R!E(&)O<F1A(&1A
M(&/I;'5L80!%<W!AYV%D;W(`17-P8>=A;65N=&\`17-P8>=A;65N=&\@92!M
M87)G96T`17-P86YH80!3<&%M`$5N=')A9&$@9&4@0V%R86-T97)E<R!%<W!E
M8VEA:7,`1&EV:61I<B!CZ6QU;&$`1&EV:61I<B!C;VQU;F$`1&EV:61I<B!L
M:6YH80!%<W!O<G1E<P!3<FD@3&%N:V$`4&%D<N-O`%-T87(@5')E:P!!;F\@
M:6YI8VEA;`!%<W1A9&\@;W4@4')O=NUN8VEA`%-I='5AY^-O`$9O<FUA=&\@
M9&\@87)M87IE;F%M96YT;P!.;VUE(&1A(%)U80!4<F'G861O`$QI<W1A(&1E
M(&-A9&5I87,@9&4@8V%R86-T97)E<P!2971I<F%R(&$@<&%R=&4@9&\@9&]M
M[6YI;R!D;R!E;F1E<F7G;P!%<W1I;&\@6T-34UT`1&]M`%-U8F1I<F5T\W)I
M;R`G)7,G(&[C;R!E;F-O;G1R861O+@!!<W-U;G1O`$5N=FEA<@!%;G9I861A
M(&$@<V]L:6-I=&'GXV\@9&4@861I8VEO;F%R("(E<R(@86\@<VES=&5M82X@
M5F]CZB!NXV\@<&]D92!C;VYE8W1A<BUS92!A=.D@<75E('-U82!S;VQI8VET
M8>?C;R!S96IA(&%P<F]V861A+@!3=6)S8W)E=F5R`%-U8V5S<V\`)R5S)R!A
M9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-I<W1E;6$N`$]S(&1A9&]S(&1O
M('5S=>%R:6\@)R5S)R!F;W)A;2!R96UO=FED;W,@9&\@<VES=&5M82!C;VT@
M<W5C97-S;RX`)R5S)R!E>&-L=>UD;R!C;VT@<W5C97-S;RX`17AC;'7M9&\@
M)R5S)R!D;R!S:7-T96UA(&-O;2!S=6-E<W-O+@!#;VYF:6=U<F'GXV\@<F5V
M97)T:61A(&-O;2!S=6-E<W-O+B!!='5A;&EZ92!P87)A('9E<B!A<R!A;'1E
M<F'G]65S+@!"86-K=7`@9&$@8V]N9FEG=7)AY^-O('-A;'9A(&-O;2!S=6-E
M<W-O+@!/(&)A8VMU<"!D;R!A<G%U:79O(&1E(&-O;F9I9W5R8>?C;R`E<R!F
M;VD@<V%L=F\@8V]M('-U8V5S<V\N`"<E<R<@871U86QI>F%D;R!C;VT@<W5C
M97-S;P`E<R!G<F%V861O(&-O;2!S=6-E<W-O`%-U9.-O`%)E<W5M;P!!;6%N
M:&5C97(`4/1R+61O+5-O;`!%;G-O;&%R861O`$%M86YH96-E<@!!;6%N:&5C
M97(O4/1R+61O+5-O;`!!;6%N:&5C97(Z(`!0]'(M9&\M4V]L`%#T<BUD;RU3
M;VPZ(`!3;V)R97-C<F5V97(`4W5P;W)T90!3=7)I;F%M90!3;V)R96YO;64`
M4W9A;&)A<F0@92!*86X@36%Y96X`4W5A>FELXFYD:6$`4W7I8VEA`%-U[>=A
M`$[C;R!E>&-L=6ER`%-Y;F--3`!%<G)O(&1E('-I;G1A>&4@;F]S('1E<FUO
M<R!D82!P97-Q=6ES80!297#Z8FQI8V$@P7)A8F4@9&$@4^UR:6$`5&5M<&5S
M=&%D90!496UP97-T861E<R!E(%9E;G1A;FEA`%1E;7!E<W1A9&5S`%1E;7!E
M<W1A9&5S($UA=&EN86ES`$%R<75I=F\@5%-6`%1A8F5L80!0<F]P<FEE9&%D
M97,@9&$@5&%B96QA`%1A8F5L80!0<F]P<FEE9&%D97,@9&$@=&%B96QA`%1A
M:7=A;@!486EW86XL(%!R;W;M;F-I82!D82!#:&EN80!486II<75I<W3C;P!4
M86YZXFYI82P@4F5P^F)L:6-A(&1A`$%L=F\Z`%1A<F5F87,`3OIM97)O(&1E
M(%1E;&5F;VYE`%1E;7!E<F%T=7)A('!A<F$@82#Z;'1I;6$@:&]R83H@`%1E
M;7!E<F%T=7)A`%1E;7!E<F%T=7)A.B``5&5M<&5R871U<F$\8G(@+SXH)7-!
M;'1A)7,O)7-"86EX825S*2`F9&5G.R5S`$UO9&5L;R`G)7,G(&[C;R!E;F-O
M;G1R861O+@!!9&UI;FES=')AY^-O(&1E($UO9&5L;W,`5&5X=&\`4V]M96YT
M92!497AT;P!!;&EN:&%M96YT;R!D92!497AT;P!";W)D82!S=7!E<FEO<B!D
M;R!497AT;P!1=6D`5&%I;&%N9.IS("A425,M-C(P*0!486ELXFYD:6$`02!E
M>'1E;G/C;R!&5%`@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!H:7-T\W)I8V\@
M9&\@<VES=&5M82!E<W3A(&1E<V%B:6QI=&%D;RX`02!E;F=I;F4@9&4@:6YT
M96=R8>?C;R!(;W)D92]+;VQA8B!NXV\@<W5P;W)T82`B)7,B`$\@;&]G($E-
M4U`@;N-O('!O9&4@<V5R(&EN:6-I86QI>F%D;RX`02!C;&%S<V4@(DUA:6YT
M96YA;F-E(B!NXV\@9F]I(&-A<G)E9V%D82!C;VT@<W5C97-S;P!!(&IA;F5L
M82!D92!/<.?U97,@9F]I(&9E8VAA9&$N(%-A:6YD;RX`3R!A9&UI;FES=')A
M9&]R('!R96-I<V$@8V]N9FEG=7)A<B!U;2!C;VYE8W1O<B!P97)M86YE;G1E
M(&1E(%!E<FUI<W/U97,@<V4@=F]CZB!Q=65R('5T:6QI>F%R(%!E<FUI<W/U
M97,N`%-O;65N=&4@;R!L861O(&1E(&)A:7AO`$\@;OIM97)O($E$(&1O(&-O
M;G1A=&\@;N-O(&9O:2!E<W!E8VEF:6-A9&\L(&1E:7AA9&\@96T@8G)A;F-O
M(&]U(&[C;R!F;VD@96YC;VYT<F%D;R!N;R!B86YC;R!D92!D861O<RX`3R!C
M;VYT871O(&9O:2!A9&EC:6]N861O(&-O;2!S=6-E<W-O(&%O('-E=2!C873A
M;&]G;R!D92!E;F1E<F7G;W,N`%!A<F$@=F5R:69I8V%R(&$@;65N<V%G96T@
M87-S:6YA9&$@Z2!N96-E<W/A<FEO('5M(&)L;V-O('-E<&%R861O(&1A(&%S
M<VEN871U<F$@4$=0+@!/($E$(&1A(&QI<W1A(&1E(&1I<W1R:6)U:>?C;R!N
MXV\@9F]I(&5S<&5C:69I8V%D;RP@9&5I>&%D;R!E;2!B<F%N8V\@;W4@;N-O
M(&9O:2!E;F-O;G1R861O(&YO(&)A;F-O(&1E(&1A9&]S+@!!(&QI<W1A(&1E
M(&1I<W1R:6)U:>?C;R!NXV\@9F]I(&5S<&5C:69I8V%D82X`07,@9G5NY_5E
M<R!D92!C<FEP=&]G<F%F:6$@<F5Q=65R96T@=6UA(&-O;F5XXV\@=V5B('-E
M9W5R82X`3R!A<G%U:79O("5S(&1E=F5R:6$@8V]N=&5R('5M82!C;VYF:6=U
M<F'GXV\@9&4@)7,N`$\@87)Q=6EV;R`E<R!D979E<FEA(&-O;G1E<B!A;&=U
M;6%S(&-O;F9I9W5R8>?U97,@9&4@)7,N`$\@87)Q=6EV;R!NXV\@<&]D92!S
M97(@8V]P:6%D;R!P87)A(&5L92!M97-M;RX`3R!A<G%U:79O(&[C;R!C;VYT
MZ6T@9&%D;W,N`%-E9W5E;2!O<R!C86)EYV%L:&]S(&1E<W1A(&UE;G-A9V5M
M+VUE;G-A9V5M(')F8S@R,BX`R2!S86)I9&\@<75E(&\@;6]D;R!T96QA(&-H
M96EA(&-A=7-A('!R;V)L96UA<R!C;VT@;R!);G1E<FYE="!%>'!L;W)E<BP@
M96T@=FER='5D92!D92!B=6=S(&1O(&YA=F5G861O<B!Q=64@;O-S(&[C;R!E
M<W1A;6]S(&%P=&]S(&$@8V]N=&]R;F%R+B!6;V/J('!O9&4@;V)S97)V87(@
M97)R;W,@9&4@97AI8FGGXV\L(&9A;'1A(&1E(&9U;N?U97,@9&\@961I=&]R
M(&4O;W4@=')A=F%M96YT;W,@86QE873S<FEO<R!D;R!N879E9V%D;W(N(%-E
M('-E=2!S:7-T96UA(.D@5VEN9&]W<R`Y>"#I(&UU:71O('!R;W;A=F5L('%U
M92!V;V/J(')E8V5B82!U;2!E<G)O(&1E("=&86QH82!'97)A;"!D92!0<F]T
M9>?C;R<@92!P<F5C:7-A<N$@<F5I;FEC:6%R+B!<;EQN(%9O8^H@9F]I(&%V
M:7-A9&\N(%!O<B!F879O<B!P<F5S<VEO;F4@3TL@<V4@=F]CZB!A:6YD82!Q
M=65R('1E;G1A<B!U<V%R(&\@961I=&]R(&1E('1E;&$@8VAE:6$N`$$@:61E
M;G1I9&%D92`B)7,B(&9O:2!E>&-L=>UD82X`4V]M96YT92!O(&QA9&\@97-Q
M=65R9&\`02!L;V-A;&EZ8>?C;R!D;R!B:6[A<FEO(&1O($=N=5!'(&1E=F4@
M<V5R(&9O<FYE8VED82#@(&-L87-S92`B0W)Y<'1?<&=P(BX`02!M96YS86=E
M;2!E;G9I861A(&5M("5S('!A<F$@)7,@8V]M(&\@87-S=6YT;R`B)7,B(&9O
M:2!E>&EB:61A+@I)<W1O(&[C;R!G87)A;G1E('%U92!A(&UE;G-A9V5M(&9O
M:2!L:61A(&]U(&5N=&5N9&ED82X`3R!N;VUE('5T:6QI>F%D;R!A;R!V:6YC
M=6QA<B!A('#A9VEN82!D92!C;VUP;W-IY^-O`$\@;OIM97)O(&1E(&-A;7!O
M<R!D979E('-E<B!N=6WI<FEC;RX`3R!M\V1U;&\@;W!E;G-S;"#I(&]B<FEG
M873S<FEO('!A<F$@82!C;&%S<V4@(DAO<F1E7T-R>7!T7W-M:6UE(BX`02!P
M<F5F97+J;F-I82`B)7,B(&[C;R!P;V1E('-E<B!S86QV82!P;W)Q=64@<V5U
M<R!D861O<R!E>&-E9&5R86T@;R!T86UA;FAO(&WA>&EM;R!P97)M:71I9&\`
M3R!P<F]G<F%M82!U=&EL:7IA9&\@<&%R82!V:7-U86QI>F%R(&5S=&4@=&EP
M;R!D92!D861O("@E<RD@;N-O(&9O:2!E;F-O;G1R861O(&YO('-I<W1E;6$N
M`$\@8V%R86-T97)E('!A<F$@8VET8>?C;R!D92!S97(@87!E;F%S('5M+@!3
M;VUE;G1E(&]S(&QA9&]S(&1I<F5I=&\@92!E<W%U97)D;P!3;VUE;G1E(&\@
M;&%D;R!D:7)E:71O`$\@<V5P87)A9&]R(&1E=F4@<V5R('5M(/IN:6-O(&-A
M<F%C=&5R92X`3R!S97)V:61O<B`B)7,B(&9O:2!E>&-L=>UD;RX`3R!S97)V
M:61O<B`B)7,B(&9O:2!S86QV;RX`02!S;VQI8VET8>?C;R!D92!C861A<W1R
M;R!D92`E<R!F;VD@97AC;'7M9&$N`$$@;&EN:&$@97-P96-I9FEC861A("@E
M9"D@;N-O(&5X:7-T92X`3R!A<G%U:79O('1E;7!O<N%R:6\@(B5S(B!NXV\@
M97AI<W1E+@!/('1E>'1O('%U92!V;V/J(&1I9VET;W4@;N-O(&-O<G)E<W!O
M;F1E(&%O('1E>'1O(&YA('1E;&$N`%-O;65N=&4@;W,@;&%D;W,@9&4@8VEM
M82!E(&1E(&)A:7AO`%-O;65N=&4@;R!L861O(&1E(&-I;6$`3W,@9&%D;W,@
M96YV:6%D;W,@9F]R86T@<&5R9&ED;W,@9&5S9&4@;R!P87-S;R!A;G1E<FEO
M<BX`3R!A<G%U:79O(&5N=FEA9&\@;N-O('#T9&4@<V5R('-A;'9O+@!/(&)L
M;V-O(")W96%T:&5R+F-O;2(@;N-O(&5S=.$@9&ES<&]N[79E;"X`3R!D:7)E
M=/-R:6\@9&4@=&5M87,@)R5S)R!NXV\@9F]I(&5N8V]N=')A9&\N`$[C;R!E
M>&ES=&5M(&]PY_5E<R!D:7-P;V[M=F5I<RX`3N-O(&5X:7-T96T@<&%R=&5S
M('%U92!P;W-S86T@<V5R(&5X:6)I9&%S(&EN8V]R<&]R861A<RX`17AI<W1E
M;2!M=6ET;W,@8V%R86-T97)E<R!N97-T92!C86UP;RX@5F]CZB!P<F5E;F-H
M974@8V]M("5S(&-A<F%C=&5R97,[('9O8^H@9&5V92!P<F5E;F-H97(@8V]M
M("5S(&]U(&UE;F]S+@!(;W5V92!U;2!P<F]B;&5M82!A9&EC:6]N86YD;R`G
M)7,G(&%O('-I<W1E;6$Z("5S`$AO=79E('5M('!R;V)L96UA(&%O(&5X8VQU
M:7(@9&\@<VES=&5M82!O<R!D861O<R!D;R!U<W7A<FEO("<E<R<Z(`!(;W5V
M92!U;2!P<F]B;&5M82!A;R!E>&-L=6ER("<E<R<@9&\@<VES=&5M83H@`$AO
M=79E('5M('!R;V)L96UA(&%O(&%T=6%L:7IA<B`G)7,G.B`E<P!(;W5V92!U
M;2!P<F]B;&5M82!C;VT@;R!E;G9I;R!D;R!A<G%U:79O.B!.96YH=6T@)7,@
M9F]I(&5N=FEA9&\N`$AO=79E('5M('!R;V)L96UA(&-O;2!O(&5N=FEO(&1O
M(&%R<75I=F\N($\@)7,@97)A(&UA:6]R('%U92!O('1A;6%N:&\@;>%X:6UO
M('!E<FUI=&ED;R`H)60@8GET97,I+@!(;W5V92!U;2!P<F]B;&5M82!C;VT@
M;R!E;G9I;R!D;R!A<G%U:79O+B!/("5S(&9O:2!E;G9I861O('!A<F-I86QM
M96YT92X`2&]U=F4@=6T@97)R;R!A;R!E>&EB:7(@97-T82!P87)T92!D82!M
M96YS86=E;0!(;W5V92!U;2!E<G)O(&%O(&EM<&]R=&%R(&]S(&1A9&]S(&1O
M(&-O;G1A=&\N`$AO=79E('5M(&5R<F\@86\@:6UP;W)T87(@;W,@9&%D;W,@
M9&\@:4-A;&5N9&%R+@!(;W5V92!U;2!E<G)O(&YO(&9O<FUU;.%R:6\@9&4@
M8V]N9FEG=7)AY^-O+B!486QV97H@=F]CZB!D96EX;W4@=6T@8V%M<&\@;V)R
M:6=A=/-R:6\@96T@8G)A;F-O+@!(;W5V92!U;2!E<G)O(&%O(&5X96-U=&%R
M(&$@9G5NY^-O(&1E(&-A=.%L;V=O(&1E(&5N9&5R9>=O<R!E<W!E8VEF:6-A
M9&$N(%!O<B!F879O<B!T96YT92!N;W9A;65N=&4@;6%I<R!T87)D92X`2&]U
M=F4@=6T@97)R;R!A;R!A='5A;&EZ87(@;W,@9&5T86QH97,@9&\@8V]N=&%T
M;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!(;W5V
M92!U;2!E<G)O(&%O(&%T=6%L:7IA<B!A(&QI<W1A(&1E(&1I<W1R:6)U:>?C
M;RX@4&]R(&9A=F]R('1E;G1E(&YO=F%M96YT92!M86ES('1A<F1E+@!%<W1E
M('-E<G9I9&]R($E-05`@;N-O('-U<&]R=&$@<&%S=&%S(&-O;7!A<G1I;&AA
M9&%S+@!%<W1E(&[C;R!P87)E8V4@<V5R('5M(&%R<75I=F\@<F%R(';A;&ED
M;RX`17-T92!NXV\@<&%R96-E('-E<B!U;2!A<G%U:79O('II<"!VX6QI9&\N
M`$5S=&4@;N-O('!A<F5C92!S97(@=6T@;OIM97)O(&1E(&-A<G3C;R!VX6QI
M9&\N`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T
M<F%VZ7,@9&\@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2P@
M=71I;&EZ86YD;R!A($%022!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E
M;G9I87(@;65N<V%G96YS(&%T<F%VZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@
M*&AT='`Z+R]S;7,R96UA:6PN8V]M*2P@=71I;&EZ86YD;R!O($%022!(5%10
M`$5S=&4@8V]N96-T;W(@<&5R;6ET92!E;G9I87(@;65N<V%G96YS(&%T<F%V
MZ7,@9&\@9V%T97=A>2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M
M*2P@=71I;&EZ86YD;R!O($%022!(5%10`$5S=&4@8V]N96-T;W(@<&5R;6ET
M92!E;G9I87(@=6UA(&UE;G-A9V5M('9I82!33510(&%T<F%VZ7,@9&\@5F]D
M869O;F4@271A;&EA;F\L('-O;65N=&4@<&%R82!N^FUE<F]S(%9O9&%F;VYE
M+B#)(&]B<FEG873S<FEO('!O<W-U:7(@=6UA(&-O;G1A(&YO(%9O9&%F;VYE
M($ET86QI86YO("AH='1P.B\O=W=W+C$Y,"YI="DN`$5S=&4@8V%M<&\@Z2!O
M8G)I9V%T\W)I;RX`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@;OIM
M97)O<R!I;G1E:7)O<RX`17-T92!C86UP;R!P;V1E(&-O;G1E<B!A<&5N87,@
M;OIM97)O<R!E(';M<F=U;&$N`$5S=&4@8V%M<&\@<&]D92!C;VYT97(@87!E
M;F%S('9A;&]R97,@;V-T86ES+@!%<W1E(&-A;7!O(&1E=F4@<V5R('5M82!L
M:7-T82!D92!N^FUE<F]S(&EN=&5I<F]S('-E<&%R861A('!O<B!V[7)G=6QA
M<R!O=2!E<W!AYV]S`$5S=&4@8V%M<&\@9&5V92!S97(@=6T@;OIM97)O(';A
M;&ED;RX`17-T92!C86UP;R!D979E(&-O;G1E<B!U;2!C\V1I9V\@9&4@8V]R
M(&5M(&9O<FUA=&\@4D="($AE>&$L('!O<B!E>&5M<&QO("<C,3(S-&%F)RX`
M17-T92!F;W)M=6SA<FEO(&KA(&9O:2!P<F]C97-S861O+@!)<W1O(.D@)7,N
M`$5S=&4@Z2!U;2!O8FIE=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9I<W5A
M;&EZ87(@97-T92!O8FIE=&\@=F]CZB!P<F5C:7-A<N$@9&4@=6T@8VQI96YT
M92!D92!C;W)R96EO('%U92!E;G1E;F1A(&\@9F]R;6%T;R!+;VQA8B!'<F]U
M<'=A<F4N(%!A<F$@=6UA(&QI<W1A(&1E(&-L:65N=&5S(&1E(&-O<G)E:6\@
M8V]M(&5S=&%S(&9U;N?U97,@<&]R(&9A=F]R('9I<VET92`E<P!%<W1A(&UE
M;G-A9V5M(&9O:2!E<V-R:71A(&5M('5M(&-O;FIU;G1O(&1E(&-A<F%C=&5R
M97,@*"5S*2!Q=64@;N-O(.D@;R!M97-M;R!Q=64@;R!S974N`$5S=&4@;OIM
M97)O(&1E=F4@<V5R('!E;&\@;65N;W,@=6TN`$5S=&4@<V5R=FED;W(@;N-O
M('!O9&4@9&5S8V]M<')I;6ER(&%R<75I=F]S('II<"!E(&=Z:7`N`$5S=&4@
M<VES=&5M82!E<W3A(&%T=6%L;65N=&4@9&5S871I=F%D;RX`17-T92!V86QO
M<B!D979E('-E<B!U;2!N^FUE<F\N`$5S=&$@:F%N96QA(&1E=F4@<V5R(&-H
M86UA9&$@82!P87)T:7(@9&$@:F%N96QA(&1E($]PY_5E<P!286EO`$)I;&AE
M=&5S`$AO<F$`06-O;7!A;FAA;65N=&\@9&4@2&]RX7)I;P!&;W)M871O(&1E
M(&AO<F$`4V5L9>?C;R!D92!H;W)A`%1I;6]R($QE<W1E`%3M='5L;P!!<W-U
M;G1O("AD:6-A*3H`4&%R80!087)A('-E;&5C:6]N87(@;?IL=&EP;&]S(.UT
M96YS+"!S96=U<F4@82!T96-L82!#;VYT<F]L("A00RD@;W4@0V]M;6%N9"`H
M36%C*2!A;R!C;&EC87(N`$AO:F4`5')O8V%R('!A<F$@8_-D:6=O($A434P`
M5&]G;P!4;VME;&%U`$%M86YHXP!4;VYG80!4;W!O`%%U861R;R!D;R!4;W!O
M("A?=&]P*0!4<F%D=>?U97,`5')I;F1A9&4@92!4;V)A9V\`5F5R9&%D96ER
M;R!O=2!F86QS;P!497(`5'5N[7-I80!4=7)Q=6EA`%1U<F-O("A)4T\M.#@U
M.2TY*0!4=7)C;VUE;FES=.-O`$EL:&%S(%1U<FMS(&4@0V%I8V]S`%1U=F%L
M=0!0<F5E;F-H82!C;VT@<W5A(&5S8V]L:&$Z(`#-;F1I8V4@52Y6+CH@`%52
M3`!54DP@9&\@<V5U(')E;&%T\W)I;R!D92!S:71U8>?C;R!D92!E;G1R96=A
M`%523#H`56=A;F1A`%5C<N)N:6$`26UP;W-S[79E;"!A8V5S<V%R(&1I<F5T
M\W)I;R!61E,N`$EM<&]S<^UV96P@861I8VEO;F%R(&EN9F]R;6'G]65S(&5X
M=')A<R!D92!U<W7A<FEO(&%O(')E9VES=')A<BX`26UP;W-S[79E;"!A;'1E
M<F%R('!E<FUI<W/C;R!D;R!A<G%U:79O(%9&4R`B)7,B+@!);7!O<W/M=F5L
M(&%L=&5R87(@<&5R;6ES<^-O(&1O(&%R<75I=F\@5D93("5S+R5S+@!);7!O
M<W/M=F5L(&%L=&5R87(@<&%R82`E<RX`26UP;W-S[79E;"!V97)I9FEC87(@
M;R!T86UA;FAO(&1O(&%R<75I=F\@9&4@(B5S(BX`26UP;W-S[79E;"!V97)I
M9FEC87(@;R!T86UA;FAO(&1O(&%R<75I=F\@9&4@(B5S+R5S(BX`26UP;W-S
M[79E;"!C;VYE8W1A<B!A;R!S97)V:61O<B!344PN`$EM<&]S<^UV96P@8V]N
M96-T87(@=71I;&EZ86YD;R!34TPN`$EM<&]S<^UV96P@8V]P:6%R(&%R<75I
M=F\@5D93+@!);7!O<W/M=F5L(&-R:6%R(&1I<F5T\W)I;R!61E,@(B5S(BX`
M26UP;W-S[79E;"!C<FEA<B!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L(&-R
M:6%R(&%R<75I=F\@5D93+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@
M5D93("(E<R(N`$EM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!61E,@=F%Z:6\N
M`$EM<&]S<^UV96P@9&5S8V]M<')I;6ER(&1A9&]S+@!);7!O<W/M=F5L(&5X
M8VQU:7(@(B5S(BP@;R!D:7)E=/-R:6\@;N-O(&5S=.$@=F%Z:6\N`$EM<&]S
M<^UV96P@97AC;'5I<B`B)7,B.B`E<RX`26UP;W-S[79E;"!E>&-L=6ER("5S
M+"!O(&1I<F5T\W)I;R!NXV\@97-TX2!V87II;P!);7!O<W/M=F5L(&5X8VQU
M:7(@<F5C=7)S:79A;65N=&4@;R!D:7)E=/-R:6\@5D93+@!);7!O<W/M=F5L
M(&5X8VQU:7(@9&ER973S<FEO(%9&4RX`26UP;W-S[79E;"!E>&-L=6ER(&1I
M<F5T\W)I;R!61E,Z("5S+@!);7!O<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!6
M1E,@(B5S(BX`26UP;W-S[79E;"!E>&-L=6ER(&%R<75I=F\@5D93+@!);7!O
M<W/M=F5L(&5X8VQU:7(@87)Q=6EV;R!61E,@(B5S(BX`26UP;W-S[79E;"!E
M>&-L=6ER(%9&4R!R96-U<G-I=F%M96YT93H@)7,N`$EM<&]S<^UV96P@9&5T
M97)M:6YA<B!O(&1I<F5T\W)I;R!A='5A;"X`26UP;W-S[79E;"!E>'1R86ER
M(&1E=&%L:&5S(&1O(&-E<G1I9FEC861O`$EM<&]S<^UV96P@8V%R<F5G87(@
M82!D969I;FGGXV\@9&4@)7,N`$EM<&]S<^UV96P@;6]V97(@;R!A<G%U:79O
M(%9&4RX`26UP;W-S[79E;"!A8G)I<B!A<G%U:79O(%9&4R`B)7,B+@!);7!O
M<W/M=F5L(&%B<FER(&%R<75I=F\@5D93('!A<F$@9W)A=F'GXV\N`$EM<&]S
M<^UV96P@86)R:7(@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@86)R:7(@87)Q
M=6EV;R!C;VUP<FEM:61O+@!);7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&4R`H
M9FEL97-I>F4H*2!F86QH;W4I+@!);7!O<W/M=F5L(&QE<B!A<G%U:79O(%9&
M4R`H9V5T1FEL95-I>F4H*2!F86QH;W4I+@!);7!O<W/M=F5L(&QE<B!O(&%R
M<75I=F\Z(`!);7!O<W/M=F5L(&QE<B!A(')A:7H@9&\@9&ER973S<FEO(%9&
M4RX`26UP;W-S[79E;"!R96YO;65A<B`E<R!P87)A("5S.B!A('!A<W1A(&1E
M(&1E<W1I;F\@:N$@97AI<W1E`$EM<&]S<^UV96P@<F5N;VUE87(@;R!D:7)E
M=/-R:6\@5D93+@!);7!O<W/M=F5L(')E;F]M96%R(&1I<F5T\W)I;R!61E,Z
M("5S+@!);7!O<W/M=F5L(')E;F]M96%R(&%R<75I=F\@5D93("(E<R(N`$EM
M<&]S<^UV96P@<F5N;VUE87(@87)Q=6EV;R!61E,@)7,O)7,N`$EM<&]S<^UV
M96P@<F5N;VUE87(@87)Q=6EV;R!61E,N`$EM<&]S<^UV96P@97AE8W5T87(@
M)VUK:7-O9G,G+@!);7!O<W/M=F5L('1R861U>FER(&5S=&4@9&]C=6UE;G1O
M(%=O<F0`26UP;W-S[79E;"!G<F%V87(@87)Q=6EV;R!61E,@(B5S(BX`26UP
M;W-S[79E;"!G<F%V87(@87)Q=6EV;R!61E,@*&-O<'DH*2!F86QH;W4I+@!)
M;7!O<W/M=F5L(&=R879A<B!D861O<R!D;R!A<G%U:79O(%9&4RX`26UP;W-S
M[79E;"!G<F%V87(@87)Q=6EV;R!61E,L('%U;W1A(&5X8V5D97+A+@!3=6)L
M:6YH861O`$1E<V9A>F5R($%L=&5R8>?U97,`1&5S9F%Z('-U82#Z;'1I;6$@
M8>?C;P!297-P;W-T82!I;F5S<&5R861A(&1O('-E<G9I9&]R(&1U<F%N=&4@
M82!C;VYE>.-O.B``4F5S<&]S=&$@:6YE<W!E<F%D82!D;R!S97)V:61O<B!P
M87)A.B``4V5M(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`16UI<F%D;W,@
MP7)A8F5S(%5N:61O<P!296EN;R!5;FED;P!%<W1A9&]S(%5N:61O<P!);&AA
M<R!097)I9NER:6-A<R!-96YO<F5S(&1O<R!%<W1A9&]S(%5N:61O<P!5;FED
M861E<P!$97-C;VYH96-I9&\`87!I;7-G:60@9&5S8V]N:&5C:61O("A!4$D@
M365S<V%G92!)1"DN`&-L:6US9VED(&1E<V-O;FAE8VED;R`H0VQI96YT($UE
M<W-A9V4@240I+@!.96YH=6UA(&QO8V%L:7IAY^-O(&-O;F9I9W5R861A+@!5
M<W7A<FEO(&]U('-E;FAA(&1E<V-O;FAE8VED;W,N`$1E<W9I;F-U;&%R(&\@
M96QE;65N=&\@871U86P`4V5M($YO;64`4V-R:7!T<R!NXV\@<')I=FEL96=I
M861O<R!NXV\@<&]D96T@=71I;&EZ87(@0V]R=&%R+T-O<&EA<B]#;VQA<B!P
M;W(@<F%Z]65S(&1E('-E9W5R86[G82X@0VQI<75E(&5M($]+('!A<F$@=F5R
M(&$@;F]T82!TZ6-N:6-A(&5M(&UO>FEL;&$N;W)G(&$@<75A;"!E;G-I;F$@
M8V]M;R!P97)M:71I<B!S8W)I<'1S(&%C97-S87)E;2!A(.%R96$@9&4@=')A
M;G-F97+J;F-I82X`1&5S;6%R8V%R(&-O<@!%>'1E;G/C;R!.XV\@4W5P;W)T
M861A`$%T=6%L:7IA<@`E<R!A='5A;&EZ861O`$%T=6%L:7IA<B!U<W7A<FEO
M`"<E<R<@871U86QI>F%D;RX`4V-R:7!T(&1E(&%T=6%L:7IAY^-O(')E;6]V
M:61O+@!%;G9I87(`5&]D;W,@87)Q=6EV;W,@9&4@(&-O;F9I9W5R8>?U97,@
M9&%S(&%P;&EC8>?U97,@9F]R86T@96YV:6%D;W,@86\@<V5R=FED;W(N`$%L
M9F%B971O(&QA=&EN;R!E;2!M86GZ<V-U;&\`3OIM97)O<R!R;VUA;F]S(&5M
M(&UA:?IS8W5L;P!5<G5G=6%I`%5T:6QI>F%R($%T=6%L.B`E<P!5=&EL:7IA
M<B!34TP`571I;&EZ87(@<V4@;R!N;VUE+W-E;FAA(.D@9&EF97)E;G1E(&YO
M('-E<G9I9&]R($E-4U`N`%5S=>%R:6]S`%5S=>%R:6\@)7,@;N-O(&5S=.$@
M875T;W)I>F%D;R!P87)A("5S+@!!9&UI;FES=')AY^-O(&1E(%5S=>%R:6]S
M`$]PY_5E<R!D92!5<W7A<FEO<P!296=I<W1R;R!D92!5<W7A<FEO<P!296=I
M<W1R;R!D92!5<W7A<FEO<R!E<W3A(&1E<V%B:6QI=&%D;R!N97-T92!S:71E
M+@!#;VYT82!D92!U<W7A<FEO(&[C;R!E;F-O;G1R861A`%5S=>%R:6\`57-U
MX7)I;R`G)7,G(&KA(&5X:7-T92X`57-UX7)I;SH`57-UX7)I;SH@`%5S=>%R
M:6]S(&YO('-I<W1E;6$Z`%5Z8F5Q=6ES=.-O`$\@9&ER973S<FEO(%9&4R!N
MXV\@97AI<W1E+@!&Z7)I87,`3&]C86QI>F'G]65S(';A;&ED87,@96YC;VYT
M<F%D87,@:6YC;'5E;3H@`%9A;&ED861E`%9A;&]R(&5M(&UI;G5T;W,@82!P
M87)T:7(@9&4@86=O<F$N`$\@=F%L;W(@97-TX2!A8VEM82!D;R!T86UA;FAO
M(&WA>&EM;R!D92`E<RX`5F%L;W)E<P!686QO<F5S('!A<F$@<V5L96-I;VYA
M<@!686YU871U`%9A<FGA=F5L`%9E;F5Z=65L80!&86QH82!N82!V97)I9FEC
M8>?C;R`M(&5S=&$@;65N<V%G96T@<&]D92!T97(@<VED;R!A9'5L=&5R861A
M+@!697)SXV\`0V]N=')O;&4@9&4@5F5R<^-O`$%L:6YH86UE;G1O('9E<G1I
M8V%L`$UA<F=E;2!V97)T:6-A;`!697)T:6-A;#H`375I=&\@06QT80!6:65T
M;N,`5FEE=&YA;6ET82`H5DE30TE)*0!697(@)7,`5FES=6%L:7IA<B!U;6$@
M<.%G:6YA('=E8B!E>'1E<FYA`%9I<W5A;&EZ87(@8V]M;R`E<P!);&AA<R!6
M:7)G96YS+"!"<FETXFYI8V%S`$EL:&%S(%9I<F=E;G,L($4N52Y!+@!6:7-I
M8FEL:61A9&4`5FES:6)I;&ED861E.B``5F]D869O;F4@271A;&EA;F\@=FEA
M(%--5%``051%3L?#3P!!5$5.Q\-/(2$A(%)%34]602!/(%-#4DE05"!-04Y5
M04Q-14Y412!$12`E<RX`5TE.('9I82!(5%10`%=A;&QI<R!E($9U='5N80!!
M=&5NY^-O`%%U80!0<F5V:7/C;R!D;R!496UP;P!$861O<R!D;R!#;&EM82!F
M;W)N96-I9&\@<&]R`%=E871H97(N8V]M`%=E8@!3:71E(%=E8@!396UA;F%L
M;65N=&4`0F5M+79I;F1O`$)E;2UV:6YD;R!A;R`E<P!"96TM=FEN9&\L("5S
M`$]C:61E;G1A;"`H25-/+3@X-3DM,2D`3V-I9&5N=&%L("A)4T\M.#@U.2TQ
M-2D`4V%H87)A($]C:61E;G1A;`!1=64@87!L:6-AY^-O("5S(&1E=F5R:6$@
M97AI8FER(&%P\W,@82!C;VYE>.-O/P!1=6%L(&\@8V%R86-T97)E(&1E;&EM
M:71A9&]R/P!1=6%L(&\@8V%R86-T97)E(&1E(&-I=&'GXV\_`$UA<&%S($%U
M<W1R86QI86YO<R!7:&5R96ES`%%U86ES(&9A<V5S`%%U86ES('!L=6=I;G,@
M:&%B:6QI=&%R('!A<F$@;R!E9&ET;W(@4FEC:"!497AT+@!,87)G=7)A`$QA
M<F=U<F$@96T@=6YI9&%D97,@0U-3`$QA<F=U<F$@9&\@;65N=2`E<R!D;R!L
M861O(&5S<75E<F1O("AT97+A(&5F96ET;R!N82!P<O-X:6UA(&-O;F5XXV\I
M.@!,87)G=7)A(&1A('1A8F5L80!5;FED861E(&1E($QA<F=U<F$`3&%R9W5R
M83H`5VEK:0!696YT;P!696YT;W,@<&5L82!M86YHXP!696QO8VED861E(&1O
M('9E;G1O(&5M(&[S<P!696YT;SH`5F5N=&\Z(`!386)E9&]R:6$`3&ES=&$@
M9&4@<&5D:61O<P!4<F%B86QH;P!%;F1E<F7G;R!#;VUE<F-I86P`1F]N92!#
M;VUE<F-I86P`3OIM97)O(&EN8V]R<F5T;R!D92!C86UP;W,@;F$@;&EN:&$@
M)60N($5S<&5R861O<R`E9"P@96YC;VYT<F%D;W,@)60N`$[Z;65R;R!E<G)A
M9&\@9&4@8V%M<&]S+B!%<W!E<F%D;W,@)60L(&5N8V]N=')A9&]S("5D+@!/
M9F9S970@)60@:6YC;W)R971O(&%O(&QE<B!O(&%R<75I=F\@5D93+@!8+5)E
M9@!297-T<FGG]65S($+A<VEC87,@6#4P.78S`%5T:6QI>F'GXV\@9&4@0VAA
M=F4@17AT96YD:61A(%@U,#EV,P!.;VUE($%L=&5R;F%T:79O(&1E($%S<W5N
M=&\@6#4P.78S`$ED96YT:69I8V%D;W(@9&$@0VAA=F4@9&4@07-S=6YT;R!8
M-3`Y=C,`17AT96YS]65S(%@U,#EV,P!!00!!04%!`$UA<&$@66%H;V\A`$%N
M=6%L;65N=&4`3.IM96X`4VEM`%-I;2P@174@0V]N8V]R9&\`5F]CZB!E<W3A
M(&5M($U/1$\@5$585$\N("!5=&EL:7IA(&\@8F]TXV\@6SP^72!P87)A('9O
M;'1A<B!P87)A(&\@;6]D;R!765-)5UE'+@!6;V/J(&[C;R!E<W3A(&%U=&]R
M:7IA9&\@82!C<FEA<B!M86ES(&1E("5D(&)L;V-O<RX`5F]CZB!NXV\@97-T
MX2!A=71E;G1I8V%D;RX`5F]CZB!NXV\@<&]D92!T97(@;R!C87)A8W1E<B!<
M(&YO('-E=2!N;VUE+@!6;V/J(&[C;R!F;W)N96-E=2!U;2!E;F1E<F7G;R!D
M92!E+6UA:6P@=N%L:61O+@!6;V/J(&[C;R!M87!E;W4@;F5N:'5M(&-A;7!O
M(&1O(&%R<75I=F\@:6UP;W)T861O(&%O<R!C86UP;W,@8V]R<F5S<&]N9&5N
M=&5S(&5M("5S+@!6;V/J(&9O:2!D97-C;VYE8W1A9&\N`%9O8^H@9&5V92!P
M<F5E;F-H97(@=6T@;OIM97)O(&1E('1E;&5F;VYE(&-E;'5L87(@=N%L:61O
M+"!S;VUE;G1E(&3M9VET;W,@8V]M('5M(&]P8VEO;F%L("<K)R!P87)A(&1I
M<V-A9V5M(&1E('!R969I>&\@:6YT97)N86-I;VYA;"X`5F]CZB!D979E('!R
M965N8VAE<B!U;2!V86QO<B!VX6QI9&\N`%9O8^H@9&5V92!C;VYF:6=U<F%R
M('5M(&-O;F5C=&]R($1A=&%4<F5E('!A<F$@=71I;&EZ87(@0V%D87-T<F]S
M+@!6;V/J(&1E=F4@8V]N9FEG=7)A<B!U;2!C;VYE8W1O<B!61E,N`%9O8^H@
M9&5V92!D97-C<F5V97(@;R!P<F]B;&5M82!A;G1E<R!D92!E;G9I87(@;R!R
M96QA=/-R:6\@9&4@<')O8FQE;6$N`%9O8^H@9&5V92!F;W)N96-E<B!A(%52
M3"!O;F1E(&\@;&EN:R!A<&]N=&$`5F]CZB!D979E('-E;&5C:6]N87(@=6T@
M<V5R=FED;W(@<&%R82!S97(@97AC;'7M9&\N`%9O8^H@9&5V92!E<W!E8VEF
M:6-A<B!U;2!U<W7A<FEO('!A<F$@97AC;'5I<BX`5F]CZB!D979E(&5S<&5C
M:69I8V%R('5M('5S=>%R:6\@<&%R82!R96UO=F5R+@!6;V/J(&1E=F4@97-P
M96-I9FEC87(@=6T@=7-UX7)I;R!P87)A(&%D:6-I;VYA<BX`5F]CZB!D979E
M(&5S<&5C:69I8V%R('5M('5S=>%R:6\@<&%R82!A='5A;&EZ87(N`%9O8^H@
M9&5V92!E<W!E8VEF:6-A<B!U;6$@8>?C;R!P87)A(&5X96-U=&%R+@!6;V/J
M(&1E=F4@<')E96YC:&5R('5M(&YO;64@<&%R82!A(&YO=F$@8V%T96=O<FEA
M+@!6;V/J('!R96-I<V$@9F]R;F5C97(@=6T@;OIM97)O(&1E('1E;&5F;VYE
M(&ET86QI86YO`%-U82!S97-SXV\@)7,@97AP:7)O=2X@4&]R(&9A=F]R+"!C
M;VYE8W1E+7-E(&YO=F%M96YT92X`4V5U($5N9&5R9>=O(&1E($4M;6%I;`!3
M974@16YD97)EYV\@9&4@4F5M971E;G1E("A$93HI.@!3=6%S($EN9F]R;6'G
M]65S`%-E=2!%;F1E<F7G;R!D92!);G1E<FYE="!M=61O=2!D97-D92!O(&EN
M[6-I;R!D92!S=6$@<V5S<^-O("5S+B!087)A('!R;W1E9V5R('-U82!S96=U
M<F%NYV$@=F]CZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`4V5U($YO
M;64`4V5U(&)A8VME;F0@9&4@875T96YT:6-AY^-O(&[C;R!S=7!O<G1A(&%D
M:>?C;R!D92!U<W7A<FEO<RP@;W4@82!F=6[GXV\@9F]I(&1E<V%B:6QI=&%D
M82!P;W(@86QG=6UA(&]U=')A(')A>N-O+@!3974@8F%C:V5N9"!D92!A=71E
M;G1I8V'GXV\@;N-O('-U<&]R=&$@;&ES=&%G96T@9&4@=7-UX7)I;W,L(&]U
M(&$@9G5NY^-O(&9O:2!D97-A8FEL:71A9&$@<&]R(&%L9W5M82!O=71R82!R
M87KC;RX`4V5U(&YA=F5G861O<B!P87)E8V4@=&5R(&%L=&5R861O(&1E<V1E
M(&\@:6[M8VEO(&1E('-U82!S97-SXV\@)7,N(%!A<F$@<')O=&5G97(@<W5A
M('-E9W5R86[G82P@=F]CZB!D979E(&-O;F5C=&%R+7-E(&YO=F%M96YT92X`
M4V5U(&YA=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&9U;N?C;RX`4V5U(&YA
M=F5G861O<B!NXV\@<W5P;W)T82!E<W1A(&]PY^-O(&1E(&EM<')E<W/C;RX@
M4')E<W-I;VYE($-O;G1R;VPO3W!T:6]N("L@4"!P87)A(&EM<')I;6ER+@!3
M974@9G5S;R!H;W+A<FEO(&%T=6%L.@!3=6$@:61E;G1I9&%D92!P861RXV\@
M9F]I(&%L=&5R861A+@!3=6$@:61E;G1I9&%D92!P861RXV\Z`%-E=2!N;VUE
M(&-O;7!L971O.@!3=6$@8V]N97CC;R!E>'!I<F]U+@!3=6$@;F]V82!S96YH
M82!P87)A("5S(.DZ("5S`%-U87,@;W#G]65S(&9O<F%M(&%T=6%L:7IA9&%S
M('!O<B!C875S82!D82!D=7)AY^-O(&1E<W1A('-E<W/C;RX`4W5A<R!O<.?U
M97,@9F]R86T@871U86QI>F%D87,N`%-U82!N;W9A('-E;FAA(&9O:2!G97)A
M9&$`4W5A(&YO=F$@<V5N:&$@9F]I(&=E<F%D82P@=F5R:69I<75E('-E=2!E
M+6UA:6P@92!C;VYE8W1E+7-E(&-O;2!S=6$@;F]V82!S96YH82X`4W5A('-E
M;FAA(&5X<&ER;W4N`%-E=7,@<V5R=FED;W)E<R!R96UO=&]S.@!)=6=O<VSA
M=FEA`%IA:7)E`%KB;6)I80!::6UB86)W90!::7!P>0!;3V-U;'1A<B!497AT
M;R!#:71A9&]=`%M296QA=/-R:6\@9&4@4')O8FQE;6%=`%M%>&EB:7(@5&5X
M=&\@0VET861O("T`6T5X:6)I<B!497AT;R!#:71A9&\@+2`E<R!L:6YH87-=
M`%ML:6YH82`E<R!D92`E<UT`7T%D;6EN:7-T<F'GXV\`7T-,20!$871A7U1R
M964`15]X8VQU:7(@0V]L=6YA`%]'<G5P;W,`05]J=61A`%!R;W!R:65D861E
M<R!D82!?26UA9V5M+BXN`%]#;VYE8W1A<@!?1&5S8V]N96-T87(`05]L=&5R
M87(@3&EN:RXN+@!?3W#G]65S`%]097)M:7-S]65S`%]296UO=F5R($QI;FLN
M+BX`0V]N9FEG=7)A7W(`4')O<')I961A9&5S(&1A(%]486)E;&$N+BX`7U5S
M=>%R:6]S`&-A=.%L;V=O(&1E(&5N9&5R9>=O<P!C873A;&]G;R!D92!E;F1E
M<F7G;W,`86=E;F1A`&-A;&UO`&EM<&]S<^UV96P@8W)I87(@87)Q=6EV;R!D
M92!D97-T:6YO`&EM<&]S<^UV96P@86)R:7(@82!O<FEG96T`8VQI<75E(&%Q
M=6D`97)R;R!D92!S:6YT87AE(&1A(&QI;FAA(&1E(&-O;6%N9&\`97)R;R!D
M92!C;VYF:6=U<F'GXV\`=6T@87)Q=6EV;R!C<NUT:6-O(&1O('-I<W1E;6$@
M97-TX2!F86QT86YD;P!E<G)O(&YO(&9O<FUA=&\@9&]S(&1A9&]S`&5D:71A
M<@!R96=I<W1R;R!NXV\@96YC;VYT<F%D;P!Q=65D80!A<G%U:79O`&$@<&%R
M=&ER(&1E("5S("@E<RD@X"`E<R`E<P!B<FES80!H.@!H:`!N;VUE(&1O(&AO
M<W0@Z2!D97-C;VYH96-I9&\`:6UE9&EA=&\`:6YC;W)P;W)A9&\`97)R;R!D
M92!E;G1R861A+W-A[61A`&5R<F\@:6YT97)N;R!D;R!P<F]G<F%M80!L:6YH
M87-=`&/S9&EG;R!D92!E<G)O("5D(&1O(&UK:7-O9G,@96YQ=6%N=&\@9V5R
M879A(&$@25-/+@!M;0!N;VUE`&[C;R!I;7!L96UE;G1A9&\`;N-O(&EM<&QE
M;65N=&%D;R!A:6YD80!B;&]C;R!D92!N;W1A<P!P;W)C96YT86=E;0!097)M
M:7-SXV\`<&EX96QS`&5R<F\@<F5M;W1O(&YO('!R;W1O8V]L;P!N87-C96YT
M90!S97)V:>=O(&EN9&ES<&]N[79E;`!E>&EB:7(@9&EF97)E;N=A<P!S;7,R
M96UA:6P@=FEA($A45%``<W,`97-TX79E;`!E<G)O(&1E('-I<W1E;6$`;&ES
M=&$@9&4@=&%R969A<P!F86QH82!T96UP;W+A<FEA`'!R965N8VAA('-U82!S
M96YH82!D=6%S('9E>F5S('!A<F$@8V]N9FER;6%R`'5N:69I8V%D;P!S96T@
M;F]M90!S96QEY^-O(&1E('5S=>%R:6\`=D-A<F0`=SH`=V5A=&AE<BYC;VT`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O<&Q?4$PO3$-?3453
M4T%'15,`````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q-#$@,#(Q-3`T`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO
M8V%L92]P;%]03"]H96QP+GAM;```````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,S,R,"`Q,#4Q-30S-#$T,2`P,C$T-#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]X;6P@=F5R
M<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O<&Q?4$PO
M:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@
M+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^
M"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI
M<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL
M('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I
M="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U
M"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U
M<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L
M:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@
M($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K
M('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M
M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L
M96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@
M5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ
M86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO
M=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P
M;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A
M<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B
M87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG
M871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@
M<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG
M871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG
M871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W
M965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N
M=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E
M/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@
M1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@
M=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A
M=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E
M.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@
M268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@
M=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF
M(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T
M:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I
M8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M<&Q?4$PO3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`Q-#$P,34@,3`U,34T,S0Q-#$@,#(S,C(S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````00,``!P`
M```D&@``700``"PT````````H$4``$@```"A10``#@```.I%```/````^44`
M``T````)1@``"````!=&```+````($8```P````L1@``&P```#E&```M````
M548``"0```"#1@``*0```*A&```9````TD8```P```#L1@``"P```/E&```1
M````!4<```X````71P``!0```"9'```H````+$<```@```!51P``"@```%Y'
M```2````:4<```X```!\1P``"@```(M'```-````ED<```X```"D1P``$0``
M`+-'```-````Q4<```P```#31P``#0```.!'```&````[D<```P```#U1P``
M#@````)(```.````$4@```@````@2```"0```"E(```:````,T@``#(```!.
M2```.````(%(``!4````ND@``%$````/20``6@```&%)``!7````O$D``#0`
M```42@``!0```$E*```1````3TH```@```!A2@``$````&I*```/````>TH`
M``H```"+2@```P```)9*```)````FDH```T```"D2@``$@```+)*```/````
MQ4H```H```#52@``#P```.!*```(````\$H``"0```#Y2@``%````!Y+```6
M````,TL```@```!*2P``+0```%-+```9````@4L```<```";2P``#````*-+
M```.````L$L```,```"_2P``"P```,-+```'````STL```<```#72P``!0``
M`-]+```#````Y4L``!<```#I2P``"@````%,```/````#$P``!@````<3```
M#@```#5,```4````1$P``!<```!93```%P```'%,```7````B4P```\```"A
M3```'P```+%,```'````T4P```8```#93```"````.!,```/````Z4P```8`
M``#Y3```"@````!-```+````"TT``!4````730``!P```"U-```%````-4T`
M`!$````[30``#````$U-```)````6DT```<```!D30``!0```&Q-```Y````
M<DT```H```"L30``!@```+=-```)````ODT```<```#(30``+P```-!-```N
M`````$X``%4````O3@``+0```(5.```M````LTX``"T```#A3@``(P````]/
M```C````,T\``"T```!73P``,P```(5/```5````N4\``!D```#/3P``*0``
M`.E/```D````$U```!$````X4```"@```$I0```,````55````H```!B4```
M$````&U0```6````?E```!8```"54```!P```*Q0```'````M%```!0```"\
M4```"@```-%0```'````W%````<```#D4```!@```.Q0```%````\U````<`
M``#Y4```!@````%1```(````"%$```X````140``"@```"!1```'````*U$`
M``D````S40``%@```#U1```$````5%$```8```!940``"````&!1```#````
M:5$```,```!M40``$P```'%1```(````A5$```@```".40``"````)=1``!!
M````H%$``"````#B40``!@````-2```&````"E(``!4````14@``&````"=2
M```B````0%(``!T```!C4@``"@```(%2```5````C%(```H```"B4@``#P``
M`*U2```/````O5(```D```#-4@``%````-=2```8````[%(``!T````%4P``
M$P```"-3```1````-U,```0```!)4P``!@```$Y3``!4````55,```X```"J
M4P``1````+E3```%````_E,```4````$5```$0````I4```1````'%0``!P`
M```N5```$````$M4```1````7%0```P```!N5```%P```'M4```0````DU0`
M``@```"D5```!0```*U4```,````LU0``!````#`5```#0```-%4```'````
MWU0```T```#G5```!P```/54```'````_50```<````%50``%`````U5```)
M````(E4```H````L50``#````#=5```0````1%4```4```!550``)0```%M5
M```2````@54``!,```"450``*P```*A5```[````U%4``"`````05@``-@``
M`#%6```0````:%8```@```!Y5@``#````()6```$````CU8```X```"45@``
M'@```*-6```;````PE8``"$```#>5@``'@````!7```>````'U<``"X````^
M5P``&P```&U7```>````B5<``#,```"H5P``+P```-Q7```@````#%@``!(`
M```M6```*0```$!8```>````:E@``!8```")6```00```*!8```'````XE@`
M``8```#J6```#0```/%8```0````_U@``!(````060``!P```"-9```$````
M*UD```P````P60``*````#U9```#````9ED```8```!J60``#@```'%9```"
M````@%D```4```"#60``!````(E9```.````CED```@```"=60``#0```*99
M```0````M%D``!,```#%60``$P```-E9```&````[5D```P```#T60``$0``
M``%:```9````$UH```L````M6@``#0```#E:```;````1UH``#0```!C6@``
M"@```)A:```8````HUH``!D```"\6@``%@```-9:```O````[5H```<````=
M6P``%````"5;```O````.EL```D```!J6P``%@```'1;```/````BUL```@`
M``";6P``#0```*1;```F````LEL```@```#96P``$@```.);```(````]5L`
M``L```#^6P``!0````I<```&````$%P```<````77```!````!]<```*````
M)%P```\````O7```$````#]<```7````4%P``!$```!H7```%P```'I<```%
M````DEP```L```"87```!0```*1<```-````JEP``!L```"X7```"0```-1<
M```.````WEP```T```#M7```(````/M<```1````'%T```<````N70``!0``
M`#9=```3````/%T```<```!070``"````%A=```&````85T``!````!H70``
M#P```'E=```0````B5T```\```":70``"P```*I=```/````MET```P```#&
M70``#P```--=```'````XUT```8```#K70``#@```/)=```A`````5X``!D`
M```C7@``%P```#U>```7````55X``!L```!M7@``#0```(E>```,````EUX`
M``,```"D7@``"````*A>```$````L5X```P```"V7@``"0```,->```.````
MS5X```L```#<7@``&P```.A>```'````!%\```<````,7P``!````!1?```5
M````&5\```8````O7P``#0```#9?```0````1%\``!L```!57P``!````'%?
M```%````=E\```8```!\7P``!P```(-?```%````BU\```D```"17P```@``
M`)M?```-````GE\```8```"L7P``"0```+-?```'````O5\```8```#%7P``
M"@```,Q?```$````UU\```D```#<7P``"````.9?```&````[U\```T```#V
M7P``!@````1@```$````"V````4````08```(0```!9@```$````.&````0`
M```]8```!0```$)@```=````2&````0```!F8```#````&M@```*````>&``
M``@```"#8```"0```(Q@```%````EF```"D```"<8```!P```,9@```'````
MSF````H```#68```#P```.%@```0````\6````8````"80``$@````EA```0
M````'&$```4````M80``"0```#-A```$````/6$```P```!"80``%P```$]A
M```<````9V$``!,```"$80``%````)AA```9````K6$```0```#'80``!P``
M`,QA```&````U&$```8```#;80``!0```.)A```'````Z&$```<```#P80``
M!0```/AA```&````_F$```0````%8@``!`````IB```*````#V(```4````:
M8@``#````"!B```/````+6(```H````]8@``"````$AB```K````46(```0`
M``!]8@``"````()B```F````BV(``!(```"R8@``!@```,5B```*````S&(`
M``<```#78@``"````-]B```@````Z&(```X````)8P``%@```!AC```1````
M+V,```8```!!8P``!P```$AC```'````4&,``!8```!88P``#0```&]C```0
M````?6,``!H```".8P``"0```*EC```*````LV,```P```"^8P``#P```,MC
M```&````VV,```<```#B8P``"P```.IC``!'````]F,```T````^9````P``
M`$QD```*````4&0```(```!;9```!````%YD```#````8V0```4```!G9```
M*@```&UD```*````F&0```0```"C9```!@```*AD```(````KV0```@```"X
M9```!````,%D```%````QF0``&@```#,9```!0```#5E```&````.V4``!``
M``!"90``"@```%-E```/````7F4```H```!N90``"0```'EE```#````@V4`
M``<```"'90``"@```(]E```+````FF4```<```"F90``&@```*YE``!*````
MR64```8````49@``"0```!MF```-````)68```H````S9@``!P```#YF```4
M````1F8```8```!;9@``"````&)F```'````:V8```H```!S9@``"P```'YF
M```'````BF8```D```"29@``"0```)QF```*````IF8```<```"Q9@``"0``
M`+EF```'````PV8```H```#+9@``"@```-9F```)````X68```<```#K9@``
M!````/-F```'````^&8```4`````9P``!0````9G```+````#&<``!0````8
M9P``!P```"UG```%````-6<```T````[9P``#````$EG```+````5F<```0`
M``!B9P``!````&=G```,````;&<```D```!Y9P``!0```(-G```'````B6<`
M``0```"19P``"@```)9G```N````H6<``!````#09P``+0```.%G```M````
M#V@``#$````]:```+0```&]H```N````G6@``"\```#,:```+````/QH```$
M````*6D```X````N:0``!@```#UI```0````1&D```<```!5:0``#@```%UI
M```%````;&D```8```!R:0``"````'EI```1````@FD```X```"4:0```@``
M`*-I```'````IFD```8```"N:0``!````+5I```?````NFD``!0```#::0``
M!P```.]I```.````]VD```P````&:@``$P```!-J```*````)VH```4````R
M:@``$0```#AJ```1````2FH``"0```!<:@``%0```(%J```2````EVH```X`
M``"J:@``&0```+EJ```(````TVH```D```#<:@``"@```.9J```(````\6H`
M``4```#Z:@``!@````!K```0````!VL```@````8:P``"````"%K```2````
M*FL``!H````]:P``"0```%AK```*````8FL``!4```!M:P``!0```(-K```4
M````B6L``!X```">:P``*````+UK```*````YFL```\```#Q:P``%`````%L
M```$````%FP```L````;;```!0```"=L```(````+6P``#0````V;```-```
M`&ML```@````H&P``!H```#!;```*````-QL```I````!6T```8````O;0``
M"````#9M```'````/VT```L```!';0``!P```%-M```3````6VT```H```!O
M;0``%````'IM```/````CVT``#(```"?;0``"P```-)M```%````WFT```4`
M``#D;0``%P```.IM```>`````FX``!0````A;@``#@```#9N```&````16X`
M``P```!,;@``#0```%EN```+````9VX```H```!S;@``"P```'YN```/````
MBFX```4```":;@``#@```*!N```3````KVX```<```##;@``$0```,MN```'
M````W6X``!@```#E;@``!````/YN```'`````V\```H````+;P``"P```!9O
M```,````(F\```X````O;P``$@```#YO```&````46\``!@```!8;P``)0``
M`'%O```)````EV\```,```"A;P``"@```*5O```,````L&\``!4```"];P``
M"P```--O```9````WV\``"````#Y;P``!0```!IP```*````('````P````K
M<```!````#AP```)````/7````<```!'<```#````$]P```&````7'````P`
M``!C<```&@```'!P```7````BW```"<```"C<```&@```,MP```7````YG``
M`!L```#^<```&0```!IQ```?````-'$``!,```!4<0``!P```&AQ```)````
M<'$```T```!Z<0```P```(AQ```_````C'$``#<```#,<0``5P````1R```%
M````7'(```H```!B<@``#0```&UR```$````>W(``"4```"`<@``'0```*9R
M```,````Q'(``!D```#1<@``"0```.MR```3````]7(```D````)<P``!```
M`!-S```0````&',```@````I<P``"````#)S```/````.W,```<```!+<P``
M#````%-S```;````8',``"P```!\<P``!0```*ES```$````KW,``!<```"T
M<P``"@```,QS```,````UW,```D```#D<P``"0```.YS```1````^',```8`
M```*=```#@```!%T```'````('0```8````H=```!P```"]T```F````-W0`
M`#@```!>=```&@```)=T```J````LG0``!D```#==```!0```/=T```.````
M_70```@````,=0``"0```!5U```&````'W4```L````F=0``%````#)U```&
M````1W4``!D```!.=0``"@```&AU```<````<W4```4```"0=0``$````)9U
M```)````IW4```@```"Q=0``'P```+IU```C````VG4``"$```#^=0``'P``
M`"!V```G````0'8``!\```!H=@``,0```(AV``!!````NG8``#,```#\=@``
M)0```#!W```O````5G<``#````"&=P``+P```+=W```L````YW<``!<````4
M>```(@```"QX``!%````3W@``#````"5>```!````,9X```+````RW@```4`
M``#7>````@```-UX``!9````X'@```4````Z>0``!````$!Y```'````17D`
M``@```!->0``!0```%9Y```3````7'D```T```!P>0``!P```'YY```&````
MAGD``!0```"->0``#````*)Y```&````KWD```,```"V>0``!````+IY```&
M````OWD```<```#&>0``%P```,YY```@````YGD``!H````'>@``)@```")Z
M```,````27H``!0```!6>@``#@```&MZ```-````>GH```<```"(>@``!P``
M`)!Z```5````F'H```8```"N>@``!@```+5Z```'````O'H```P```#$>@``
M$0```-%Z```(````XWH``!T```#L>@``"0````I[```*````%'L``!0````?
M>P``"@```#1[```(````/WL```<```!(>P``"0```%![```'````6GL```@`
M``!B>P``!P```&M[```9````<WL```H```"->P``%P```)A[```4````L'L`
M`!$```#%>P``!P```-=[```#````WWL```8```#C>P``!P```.I[```-````
M\GL```L`````?```%`````Q\```5````(7P```X````W?```+P```$9\```Q
M````=GP``#\```"H?```#````.A\```*````]7P```(`````?0``!`````-]
M```&````"'T```4````/?0```P```!5]```,````&7T``!D````F?0``10``
M`$!]```F````AGT``"4```"M?0``$@```--]```3````YGT``!````#Z?0``
M>0````M^```)````A7X``'(```"/?@``<P````)_```7````=G\``!8```".
M?P``#P```*5_```?````M7\``$````#5?P``'P```!:````4````-H````H`
M``!+@```!0```%:````&````7(````@```!C@```$````&R````/````?8``
M``0```"-@```"P```)*````'````GH````4```"F@```!P```*R````(````
MM(````\```"]@```"````,V````,````UH````\```#C@```!@```/.````&
M````^H````P````!@0``"`````Z!```$````%X$```0````<@0``!P```"&!
M```'````*8$```4````Q@0``4P$``#>!``!#````BX(```X```#/@@``$@``
M`-Z"```1````\8(```<````#@P``"`````N#```*````%(,``"(````?@P``
M+P```$*#```=````<H,``"(```"0@P``'@```+.#```*````TH,```H```#=
M@P``$````.B#```/````^8,```4````)A```)P````^$```/````-X0```X`
M``!'A```$````%:$```0````9X0```@```!XA```$0```(&$```-````DX0`
M`!,```"AA```#````+6$```+````PH0```X```#.A```!@```-V$```-````
MY(0``!(```#RA```$@````6%```(````&(4```H````AA0``%P```"R%```_
M````1(4``$@```"$A0``7````,V%``!9````*H8``&(```"$A@``7P```.>&
M``!!````1X<```4```")AP``#@```(^'```.````GH<```X```"MAP``$@``
M`+R'```%````SX<```4```#5AP``#````-N'```0````Z(<``!8```#YAP``
M&0```!"(```-````*H@``!4````XB```"@```$Z(```>````68@``!L```!X
MB```(````)2(```1````M8@``"T```#'B```)@```/6(```%````'(D``!``
M```BB0``#0```#.)```'````08D```H```!)B0``!P```%2)```(````7(D`
M``4```!EB0``"````&N)```C````=(D```\```"8B0``%0```*B)```7````
MOHD```P```#6B0``%P```..)```7````^XD``",````3B@``&````#>*```3
M````4(H``"4```!DB@``!@```(J*```&````D8H```@```"8B@``#P```*&*
M```)````L8H```H```"[B@``"0```,:*```0````T(H```D```#AB@``"```
M`.N*```1````](H```X````&BP``"0```!6+```'````'XL```4````GBP``
M/0```"V+```(````:XL```@```!TBP``"0```'V+```'````AXL``#@```"/
MBP``.````,B+``!;`````8P``#<```!=C```-P```)6,```W````S8P``"X`
M```%C0``,@```#2-```W````9XT``#T```"?C0``(0```-V-```E````_XT`
M`"\````EC@``,0```%6.```.````AXX```L```"6C@``#````**.```#````
MKXX```D```"SC@``%````+V.```?````THX```P```#RC@``!P```/^.```6
M````!X\```H````>CP``"````"F/```&````,H\```8````YCP``!0```$"/
M```'````1H\```8```!.CP``#@```%6/```0````9(\```D```!UCP``!P``
M`'^/```(````AX\``!0```"0CP```P```*6/```(````J8\```@```"RCP``
M`P```+N/```#````OX\``!L```##CP``"0```-^/```(````Z8\```<```#R
MCP``3P```/J/```M````2I````8```!XD```!@```'^0```9````AI```!T`
M``"@D```+````+Z0```@````ZY```!D````,D0``%@```":1```)````/9$`
M`!,```!'D0``$P```%N1```)````;Y$``!8```!YD0``&@```)"1```?````
MJY$``!4```#+D0``%@```.&1```$````^)$```4```#]D0``1@````.2```/
M````2I(``#,```!:D@``!0```(Z2```%````E)(```L```":D@``%P```*:2
M```@````OI(``!<```#?D@``%@```/>2```,````#I,``!D````;DP``#0``
M`#63```(````0Y,```4```!,DP``#0```%*3```,````8),```T```!MDP``
M!P```'N3```'````@Y,```D```"+DP``!@```)63```%````G),``!4```"B
MDP``"0```+B3```'````PI,```X```#*DP``#P```-F3```%````Z9,``!T`
M``#ODP``'`````V4```=````*I0``"P```!(E```.P```'64```I````L90`
M`#X```#;E```#@```!J5```(````*94```L````RE0``!P```#Z5```-````
M1I4``"L```!4E0``*````("5```N````J94``"L```#8E0``*@````26```Y
M````+Y8``"4```!IE@``*````(^6```M````N)8``#,```#FE@``)@```!J7
M```6````09<``"T```!8EP``(````(:7```B````IY<``$4```#*EP``!```
M`!"8```&````%9@```L````<F```"P```"B8```6````-)@```D```!+F```
M!````%68```+````6I@``#<```!FF```!@```)Z8```$````I9@```\```"J
MF````@```+J8```*````O9@```0```#(F```#0```,V8```(````VY@```X`
M``#DF```$@```/.8```4````!ID``!0````;F0``!````#"9```*````-9D`
M`!````!`F0``&0```%&9```,````:YD```P```!XF0``&P```(69```Z````
MH9D```L```#<F0``&````.B9```5`````9H``!0````7F@``-````"R:```%
M````89H```T```!GF@``,````'6:```'````IIH``"8```"NF@``$@```-6:
M```'````Z)H```D```#PF@``+@```/J:```=````*9L``",```!'FP``"```
M`&N;```+````=)L```D```"`FP``!@```(J;```'````D9L```8```"9FP``
M"@```*";```1````JYL``!$```"]FP``&````,^;```5````Z)L``!@```#^
MFP``!0```!><```(````'9P```4````FG```"P```"R<```E````.)P```D`
M``!>G```$````&B<```0````>9P``#8```"*G```$````,&<```'````TIP`
M``0```#:G```%P```-^<```'````]YP```<```#_G```!@````>=```1````
M#IT``!$````@G0``$@```#*=```0````19T``!0```!6G0``%````&N=```/
M````@)T``!4```"0G0``!P```*:=```&````KIT```P```"UG0``*@```,*=
M```?````[9T``"`````-G@``(@```"Z>```3````49X```L```!EG@``$```
M`'&>```$````@IX```0```"'G@``!0```(R>```/````DIX```L```"BG@``
M"P```*Z>```/````NIX``"8```#*G@``!@```/&>```)````^)X```@````"
MGP``$@````N?```'````'I\``!`````FGP``$P```#>?```N````2Y\```(`
M``!ZGP``!0```'V?```&````@Y\```8```"*GP``!0```)&?```)````EY\`
M``,```"AGP``$P```*6?```&````N9\```H```#`GP``!P```,N?```0````
MTY\```D```#DGP``!````.Z?```)````\Y\```@```#]GP``!@````:@```-
M````#:````8````;H```!````"*@```%````)Z```!<````MH```!0```$6@
M```&````2Z````8```!2H```'````%F@```(````=J````P```!_H```"0``
M`(R@```(````EJ````@```"?H```!0```*B@```E````KJ````4```#4H```
M"````-J@```+````XZ````\```#OH```$0```/^@```'````$:$``!0````9
MH0``$0```"ZA```%````0*$```D```!&H0``!````%"A```-````5:$``!L`
M``!CH0``'0```'^A```:````G:$``!T```"XH0``!````-:A```$````VZ$`
M``@```#@H0``!@```.FA```'````\*$```8```#XH0``!P```/^A```'````
M!Z(```<````/H@``!@```!>B```&````'J(```@````EH@``"@```"ZB```%
M````.:(``!`````_H@``#0```%"B```.````7J(```H```!MH@``,0```'BB
M```&````JJ(```@```"QH@``*````+JB```/````XZ(```8```#SH@``"0``
M`/JB```+````!*,```4````0HP``!````!:C```6````&Z,``!L````RHP``
M&0```$ZC```%````:*,```<```!NHP``!P```':C```%````?J,```T```"$
MHP``%@```)*C```G````J:,```4```#1HP``#````->C```.````Y*,``!D`
M``#SHP``!P````VD```'````%:0``!8````=I```5P```#2D```;````C*0`
M``4```"HI```"@```*ZD```"````N:0```0```"\I````P```,&D```%````
MQ:0```D```#+I```"@```-6D```&````X*0```8```#GI```!P```.ZD```(
M````]J0```0```#_I```!0````2E``!;````"J4```8```!FI0``"````&VE
M```/````=J4```D```"&I0``#0```)"E```*````GJ4```D```"II0```P``
M`+.E```'````MZ4```H```"_I0``#@```,JE```)````V:4``!\```#CI0``
M6@````.F```&````7J8```@```!EI@``%````&ZF```*````@Z8```@```".
MI@``$@```)>F```&````JJ8```@```"QI@``"@```+JF```*````Q:8```T`
M``#0I@``!@```-ZF```-````Y:8```X```#SI@``#P````*G```.````$J<`
M``X````AIP``#@```#"G```(````/Z<```4```!(IP``"@```$ZG```%````
M6:<```@```!?IP``!P```&BG```%````<*<```4```!VIP``"````'RG```3
M````A:<```0```"9IP``!0```)ZG```.````I*<```X```"SIP``#0```,*G
M```*````T*<```@```#;IP``#@```.2G```)````\Z<```4```#]IP``!P``
M``.H```$````"Z@```H````0J```&0```!NH```0````-:@``"L```!&J```
M*P```'*H```O````GJ@``"L```#.J```+````/JH```M````)ZD``"H```!5
MJ0``!0```("I```'````AJD```@```".J0``%0```)>I```,````K:D```X`
M``"ZJ0``!0```,FI```%````SZD```@```#5J0``#0```-ZI```.````[*D`
M``(```#[J0``"P```/ZI```%````"JH```0````0J@``)P```!6J```4````
M/:H```4```!2J@``"````%BJ```+````8:H``!<```!MJ@``"P```(6J```$
M````D:H```\```"6J@``$````*:J```G````MZH``!(```#?J@``&@```/*J
M```3````#:L``"P````AJP``!P```$ZK```+````5JL```P```!BJP``"```
M`&^K```%````>*L```8```!^JP``$0```(6K```(````EZL```4```"@JP``
M$P```*:K```6````NJL```8```#1JP``!P```-BK```3````X*L```4```#T
MJP``$````/JK```:````"ZP``"T````FK```"P```%2L```/````8*P``!,`
M``!PK```!````(2L```(````B:P```<```"2K```"````)JL```D````HZP`
M`"````#(K```'P```.FL```;````":T``!8````EK0``)@```#RM```&````
M8ZT```H```!JK0``!P```'6M```.````?:T```<```",K0``#0```)2M```/
M````HJT``!L```"RK0``'@```,ZM```Z````[:T```D````HK@``!0```#*N
M```)````.*X``!X```!"K@``(0```&&N```6````@ZX```X```":K@``!```
M`*FN```)````KJX```P```"XK@``"0```,6N```$````SZX``!````#4K@``
M%@```.6N```%````_*X```T````"KP``$P```!"O```&````)*\```\````K
MKP``!P```#NO```9````0Z\```H```!=KP``!P```&BO```2````<*\```P`
M``"#KP``#0```)"O```<````GJ\```4```"[KP``!@```,&O```=````R*\`
M`"@```#FKP``"P````^P```#````&[````P````?L```#0```"RP```3````
M.K````L```!.L```%P```%JP```9````<K````4```",L```"@```)*P```0
M````G;````8```"NL```"P```+6P```)````P;````P```#+L```!@```-BP
M```-````W[```!L```#ML```%`````FQ```<````'K$``!L````[L0``%0``
M`%>Q```:````;;$``!@```"(L0``'P```*&Q```9````P;$```<```#;L0``
M"````..Q```-````[+$```4```#ZL0``/@````"R```U````/[(``%8```!U
ML@``#````,RR```(````V;(```L```#BL@``!0```.ZR```S````]+(``!<`
M```HLP``#````$"S```P````3;,```8```!^LP``$````(6S```(````EK,`
M``@```"?LP``&````*BS```(````P;,```@```#*LP``#@```-.S```'````
MXK,``!$```#JLP``(0```/RS```2````'K0```D````QM```!````#NT```9
M````0+0```\```!:M```#P```&JT```.````>K0```D```")M```%````).T
M```&````J+0```P```"OM```!0```+RT```&````PK0```H```#)M```(```
M`-2T```@````];0``!8````6M0``(````"VU```9````3K4```4```!HM0``
M%````&ZU```'````@[4```4```"+M0``!P```)&U```*````F;4```4```"D
MM0``!@```*JU```&````L;4```L```"XM0``"````,2U```'````S;4```X`
M``#5M0``"P```.2U```)````\+4``"0```#ZM0``(````!^V```<````0+8`
M`!P```!=M@``(P```'JV```@````GK8``#,```"_M@``1P```/.V```N````
M.[<``"P```!JMP``.````)>W```S````T+<``"H````$N```*@```"^X```6
M````6K@``"$```!QN```0@```).X```X````UK@```0````/N0``#````!2Y
M```%````(;D```(````GN0``7@```"JY```$````B;D```0```".N0``!P``
M`).Y```%````F[D```4```"AN0``$0```*>Y```0````N;D```<```#*N0``
M!@```-*Y```4````V;D```P```#NN0``!@```/NY```#`````KH```0````&
MN@``!@````NZ```'````$KH``!H````:N@``*0```#6Z```C````7[H``"T`
M``"#N@``#0```+&Z```<````O[H```\```#<N@```P```.RZ```(````\+H`
M``D```#YN@``&P````.[```*````'[L```<````JNP``!P```#*[```1````
M.KL``!<```!,NP``$0```&2[```F````=KL``!(```"=NP``$P```+"[```7
M````Q+L```H```#<NP``!P```.>[```'````[[L```D```#WNP``!@````&\
M```'````"+P```@````0O```$````!F\```-````*KP``!H````XO```)```
M`%.\```/````>+P```L```"(O````P```)2\```*````F+P```8```"CO```
M"P```*J\```*````MKP``!4```#!O```%@```->\```0````[KP``#,```#_
MO```-P```#.]``!/````:[T```X```"[O0``#0```,J]```"````V+T```0`
M``#;O0``!@```."]```%````Y[T```,```#MO0``$````/&]```0`````KX`
M`"<````3O@``,P```#N^```R````;[X``!$```"BO@``#@```+2^```0````
MP[X``($```#4O@``"@```%:_``!=````8;\``%X```"_OP``'````![````3
M````.\```!P```!/P```(````&S```!`````C<```"8```#.P```%0```/7`
M```*````"\$```0````6P0``!@```!O!```(````(L$``!0````KP0``#@``
M`$#!```$````3\$```P```!4P0``!@```&'!```&````:,$```@```!OP0``
M"````'C!```-````@<$```8```"/P0``#````);!```,````H\$```T```"P
MP0``#````+[!```0````R\$```D```#<P0``!````.;!```(````Z\$```@`
M``#TP0``"0```/W!```%````!\(```$```"J``````````````!8````````
M`+P!````````V@````H```!H````-`,``)P"```2````/@(``,,!``"5````
ME0$```````!'`0``30$`````````````L@(``,$"```5````0P(``,H!``#&
M````<````&\!``!=`@``"@,``)<"````````F0``````````````7P```/$`
M``!&`@```````#`!``!E`0``TP(```````#+`0```````*4```"6````7```
M`(4"```-`0``M@(`````````````=@````0"````````KP```/P"````````
MD````,T```!R`0``U0````````"[`````@(``+@"````````$0````````#,
M`@``=````'4"``"*````.@```.$!```%`@``7@`````````U````)@(`````
M```G`P``I@(```(````A`P```P,``.0````V`0```````'4`````````#`$`
M`*@!``"K````V@(``+<"``!?`0``M@```&`!```@`P``(P,``*D```#T`0``
M`````!P!```/`@```````/4!```=`P``8`(``(D```"O`0```````$(!```2
M`@``-0,``!`#``#?`0```````-````!``0``4`(``&H!````````Q0```/<`
M``!6`0````````````!1`````````&8`````````*@,``!D#``"0`@``````
M`%H```#[````%`$``/H!``#!``````````````"E`@``.P$```````#N````
M^P(`````````````HP$``'<!`````````````.H"``#8`@```````,8!``!/
M````>@$```````!?`@``3P$`````````````;P(``$4"```H`@``GP(``,(!
M```X`P```````&4````-`@`````````````V````5P(```````!2````.@,`
M`%,"````````0````/X!```Q````K`(``&L!``#_`@```````&$`````````
M60$``"H"````````9`````<!````````^P$``"D!````````Z0```#0"``#^
M`@``@P$``+@!````````(@,``#X````7`@``RP```-T"``!Z`@``````````
M``#'`@``W0$```H"``#'`````````'P````,`P``XP(``,("``#B````````
M`&H`````````I0$``+8!````````W`$``"D#```]`@``C@````````!+`@``
M`````,<!````````O@$``,\!``#U`@``H0``````````````G@$``)X"``#)
M`0``U@````$!````````RP(``#4"``#.`@``2````!L"``!Q````````````
M```F`0``AP$``"4#````````+0(``*`"``"G`0``````````````````2P$`
M`.@!``!,````/@,```````!#`0``!0```+\````:`P``3@$`````````````
M`````&("``"T````F````!8"```_`@``/P$``)H"``"P`0``;0````````!-
M````A`$``&D"```4````R0(`````````````.0$```````!_`0``^@```*(!
M``!\`0``VP```)D"`````````````'8!``!Q`@``X@$``#L"``"9`0``````
M`!P"````````&@(``.L!````````\P(````````!`@``@````+T"``#K`@``
M\P$``-<"```0`@```````!T"```1`0``10```.\"``"D````-@,``((!```R
M`@```````#<```!N`@``2`(``!L#``#N`@``,````/P!```&`0```````/``
M```X`````````*,"``"=`@``6`$``$<````Y````\0(``"P"````````NP(`
M`"L```!!```````````````)`@```````)(!``````````````````#S````
M]`(``-<!``"-`````````&L"```M````]P$``!H!``#Y`@``5`(``"<!``!"
M````BP(``!,!``!2`@``?0```.T"`````````````!$#````````C```````
M`````````````!\``````````````/4````$````W0```$L```!L`@``````
M`.,!````````<`(``"P#``")`@```````%,!```^`0```````/D````(`@``
M3@```)P!````````1@````````"+````%P,`````````````YP$```````!]
M`@````````````"!````R`(``+T``````````````+@````B````YP```&,!
M````````/````+4"``#(`0``@@(``+`"```R````H`$``)("````````N0$`
M``````"=`0``W@```!D"```A`````````$$#``"W````N0`````````Q`@``
MF`$``#,`````````K0$``,\```!V`@``5@(``!8#````````B`(`````````
M``````````8"````````>P(``$0```!9`@````,```\````@`@``+@(`````
M``!G````6@(``#<!```-````3P(``#(#```O````6`(``*X`````````(P(`
M`#P!````````VP(````````'````"@$``"0!``"&`@``Y0````````!I`0``
M2@```'L!``#A````J````(8`````````N@```+H"``!<`0``'@$``'X"````
M````R0````````#4`0```````!X```#>`0```````.L```"3````H0(``",`
M````````T0$``-(`````````(P$```````"*`@```````"4"``!``@``E`(`
M``@```!.`@```````(4```!#````Q`$``-H!``!_````&0```.0!```$`P``
M3`$``!(!`````````````%`!``"\`@```````-<````'`P``,P$``),"```\
M`P``_P$``%T````#`0``&0$``*,```":````Q@(```````!1`0``-````"<`
M```K`@``MP$``*H!```:````)0```(4!```0`0``9@(``#(!``"D`0``#@(`
M```````]`P```````$<"``"1`````````#<#``#R`@```````)X```#]`0``
M#@$``"P!``!)````>@```#L#``#<````A`(`````````````PP```)0````$
M`0```````"D```!Y`@``[`$``(D!``"\````;P```!L``````````````/(!
M````````"P(``"L!``"-`@``C`(``+H!````````Y`(```X```#@`0``90(`
M``L!``"7`0``VP$``"````#5`0```````+4!``#^````:@(``'X!```F````
ME0(``&D```#W`@``Z@$````````2`P``<0$````````)`0``;0(``,`!``!\
M`@``D@```+(`````````%P$``#H!````````#`(``,X`````````````````
M```M`P```````*P!``"K`0``"P````$#```Q`0```````#`"``#0`@``\0$`
M```````X`@``^@(``-D"```H`P``^`(``-0``````0``R@``````````````
MK0```.4!``"'`@``%@````@!``!S`````````"H!````````!@,``.P"````
M````EP```!P#``"@`````````/8`````````[P```&P!```/`0```````"0#
M``#8`0```````.D"``#@```````````````````````````````4`P``>0``
M``````#9````B`$``/`!``"P````9P$``,\"``!=`0``(0(`````````````
MP`(````````S`P``$P,``,X!``"G`@``9P(``#0!````````'@,``*D"``"1
M`@```````!\#``!T`0``?0$``!4!````````Y@```#@!``!W````E@(```4#
M``!9````=0$``-`!``#1`````````#H"``!S`0````````````#,`0``````
M`%X!``!A`@``50$``.T```#G`@``)P(``+(!``!N````40(``#$#``"_`@``
M`````&0"```=`0``Y@$``$0"``"<````O@```(T!``!5``````(```````"M
M`@``00(``.8"```U`0``%0(``($!``#]``````````````!5`@``````````
M``#J````XP```'0"``#>`@``;0$``,T!``"S`0``2@(``$`#````````````
M`!$"``!,`@``P0$``"\"```````````````````7````.P```-4"```I`@``
M"P,``"@!``"=`````````.`"``#$````@P(`````````````7@(`````````
M`````````(X!````````KP(```4!```K`P````````````#I`0```````'@"
M``#A`@``;````.@```".`@``5P```!X"```?`@``8````%L"``!7`0``*@``
M`',"````````@0(```````#%`0``M`(``),!``!R`@``E@$``!T```#2`@``
M&`(```````#-`@``F@$``(8!```#`````````-$"``#V`@`````````````D
M````IP```(0`````````<@```&L````#`@``(0$``'L`````````20(`````
M``"B````CP$``,````"S`@``R`````````!*`0``;@$``!,````/`P``````
M`%````";`0``OP$``"4!``!H`@``%@$``&8!``"1`0``'````/8!``"N`0``
MGP```)L`````````TP$``"("``"+`0``%`(``#T````"`P`````````````_
M`P```````+0!``!&`0``+P$``/T"``",`0``PP(``"8#``#3````&`$``%L`
M``";`@``J@(``(\```"N`@```````*0"``#?`@``+@``````````````80$`
M`)`!``!C`@```````!@```#9`0``U@(``%L!``"S````J`(``&0!```@`0``
M`````(`!``#2`0```````'<"```-`P``V````+$"```]`0``Z`(``%P"```O
M`P``M0```.T!``"A`0```````.("``````````````````"^`@``>`$`````
M```.`P```````#8"``"Q`0````````````""````00$```````#X````>0$`
M`,(```!B````````````````````5````+T!````````H@(``/(```#?````
M`````.P````\`@``<`$``$0!``"L````GP$``"0"````````>`````````!^
M````8@$``,4"````````^`$``+L!`````````````!,"````````F`(``%H!
M```?`0``(@$``!L!````````.0(`````````````5@````@#``!4`0``+```
M`*8!```5`P```````/D!``"#````/P``````````````N0(``$T"``!%`0``
M``````````"``@``CP(```````"4`0``W`(``/P````N`P``]````#,"``!)
M`0``:`$``,0"``!3`````````%(!``"*`0``$````'\"`````````````.4"
M````````0@(```8```#6`0``JP(````````Y`P``+@$```````"(````````
M`,H"``#_````*````-0"``````````````````#N`0``"0```(<````'`@``
M`````&,```#P`@``"0,``$@!```,````J0$````````W`@``L0````````#,
M`````@$``.\!```P`P`````````````8`P``+0$``*8`````("8C,34Q.R`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N`"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y
M("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S
M=&5R9&%Y*0`B)7,B(&ES(&YO="!A('9A;&ED(&-H;VEC92X`(B5S(B!I<R!N
M;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN`"(E<R(@=V%S
M(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@8W)E871E
M9#H@)7,N`"5D("5S(&%N9"`E<P`E<R`M($YO=&EC90`E<R!!9&UI;FES=')A
M=&EO;@`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@
M86QR96%D>2!E>&ES=',N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@
M;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E
M<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E
M<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`
M,C0@:&]U<G,`/%!R979I;W5S`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D
M`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y
M<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y
M+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S
M86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN
M`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`
M061D`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`
M061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO
M9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!
M9&1R97-S($)O;VL`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L
M8F%N:6$`06QG97)I80!!;&EA<P!!;&P`06QL($%U=&AE;G1I8V%T960@57-E
M<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL;W<@;75L=&EP;&4@
M861D<F5S<V5S`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO9VEN
M`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S97)N
M86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T97AT.@!!
M;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N9&]R<F$`06YG;VQA
M`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!
M<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P<F]V90!!<')I
M;`!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)G96YT:6YA`$%R
M;65N:6$`07)U8F$`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=')I8G5T97,`075G=7-T`$%U
M<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N
M86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"
M86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)E;&%R=7,`0F5L9VEU
M;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@
M4V5T=&EN9W,`0FQO8VL@5'EP90!";VQI=FEA`$)O;VMM87)K<P!";W-N:6$@
M86YD($AE<GIE9V]V:6YA`$)O=&@`0G)A>FEL`$)U;&=A<FEA`$--4P!#4D,`
M0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#86UB;V1I80!#86UE<F]O
M;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A
M8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86XG="!C;VYN96-T('1O($E-05`@
M<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B
M+@!#87!E(%9E<F1E`$-A=&5G;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE
M`$-E;&P@4')O<&5R=&EE<P!#96QL('!R;W!E<G1I97,`0V5L;'!H;VYE`$-E
M;'1I8R`H25-/+3@X-3DM,30I`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#
M96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A
M:6QS`$-E<G1I9FEC871E($]W;F5R`$-H860`0VAA;F=E`$-H86YG92!T:&4@
M;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E
M860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&5C7VL@3&EN:RXN+@!#
M:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O
M('!E<F9O<FT@870@=&AI<R!T:6UE+@!#:&EL90!#:&EN80!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H<FES=&UA<R!)<VQA;F0`0VQI8VL@=&\@0V]N=&EN=64`
M0VQO<V4@5VEN9&]W`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E
M(%-I9&5B87(`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S
M96QE8W1I;VX`0V]L=6UN('1I=&QE<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`
M0V]M;65N=`!#;VUO<F]S`$-O;7!A;GD`0V]M<&]S92!-97-S86=E("@E<RD`
M0V]M<'5T97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S
M<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F
M('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#
M;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O
M;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A
M<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L
M86YD<P!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E
M<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E8VEP
M:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI
M8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B
M(&9O<B!W<FET:6YG+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P
M96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@
M9&ER96-T;W)Y("(E<R(N`$-O=6QD(&YO="!U;FQI;FL@(B5S(BX`0V]U;&1N
M)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I
M9&5B87(@:7,@;W!E;BX`0V]U;G1R>0!#<F5A=&4`0W)E871E(&$@;&EN:P!#
M<F5A=&4@82!N97<@;VYE`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U
M8F$`0W5R<F5N="!4:6UE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L
M;V=O;B!T;R`E<RX`0W5T`$-Y<')U<P!#>F5C:"!297!U8FQI8P!$1`!$86EL
M>0!$871E`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@
M<&5R;6ES<VEO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES
M<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E
M;&5T92!C;VQU;6X`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B`$1E;&5T
M92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@:61E;G1I='D`1&5L971E
M('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E
M;&5T92!T:&ES('!E<FUI<W-I;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5T86EL<R!H879E(&)E
M96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&ER96-T;W)Y`$1I
M<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1J:6)O=71I
M`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N
M86YC92YP:'``1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O=VYL;V%D
M`$1O=VYL;V%D("5S`$1R=6=S`$4M36%I;`!%8W5A9&]R`$5D:70`161I="!'
M<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E
M<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI
M<W-I;VYS(&9O<B`E<P!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!
M9&1R97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6]T:6-O;G,`
M16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;F%B;&4@<FEG:'0@8VQI
M8VL@8V]N=&5X="!M96YU/P!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R
M<F]R`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=7)O
M<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@
M<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L
M9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%
M>'!A;F0`17AP86YD(%-I9&5B87(`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!
M4"!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O
M(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R
M;W(Z`$9A>`!&96)R=6%R>0!&:6II`$9I;&4@36%N86=E<@!&:6QE($YA;64`
M1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO="!S
M=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&;V]D`$9O<F=O="!Y;W5R('!A
M<W-W;W)D/P!&<F%N8V4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA
M`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$=A8F]N`$=A;6)I
M80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!';P!';V]G;&4@4V5A<F-H`$=R
M965C90!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<',`1W5A9&5L;W5P90!'=6%M
M`$=U871E;6%L80!'=65R;G-E>0!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA
M;F$`2%1-3`!(86ET:0!(96%R9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N
M9',`2&5L<`!(:6=H`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A
M=&4I`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N
M9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E
M9"`E<R`B)7,B`$AU;F=A<GD`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I
M=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EM86=E<P!);7!O<G1E9"!F:65L
M9#H@)7,`26UP;W)T960@9FEE;&1S.@!);F1I80!);F1O;F5S:6$`26YF;P!)
M;G-E<G0@26UA9V4`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D
M97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L
M:60@;&EC96YS92!K97DN`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A
M<0!)<F5L86YD`$ES<F%E;`!)<W-U97(`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IO<F1A;@!*=6QY`$IU;F4`2V%Z86MH<W1A;@!+96YY80!+97D@
M0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`
M2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+
M:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B
M;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+=7=A:70`2WER9WEZ<W1A;@!,
M85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B
M;&EC`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S
M="!L;V=I;CH@3F5V97(`3&%T=FEA`$QE<V]T:&\`3&EB97)I80!,:6)Y86X@
M07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&ES="!(96QP(%1O<&EC
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71H=6%N:6$`3&]A9&EN
M9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO9R!I;@!,;V<@
M;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@=7-E
M<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN`$QO
M9VEN(&9A:6QE9"X`3&]W`$QU>&5M8F]U<F<`34T`34]41`!-4T<`36%C86\`
M36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA
M9&%G87-C87(`36%I;`!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-
M86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T
M;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET
M:"!T:&]S92!C871E9V]R:65S+@!-87)C:`!-87)G:6X`36%R<VAA;&P@27-L
M86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA
M=7)I=&EU<P!-87D`36%Y;W1T90!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M<W-A9V4`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@
M;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T
M:&4@861M:6YI<W1R871O<BX`365X:6-O`$UI;64@5'EP90!-;V1I9FEE9"!$
M871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-
M;VYA8V\`36]N9V]L:6$`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S
M`$UO<F]C8V\`36]V92!$;W=N`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@
M57``36]V92!D;W=N`$UO=F4@=7``36]Z86UB:7%U90!->2!!8V-O=6YT`$UY
M(%!O<G1A;`!->6%N;6%R`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H
M97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971W;W)K`$YE=F5R`$YE
M=R!#86QE9&]N:6$`3F5W($-A=&5G;W)Y`$YE=R!:96%L86YD`$YE=W,`3F5X
M=`!.97AT(&]P=&EO;G,`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEU90!.
M;R!C:&%N9V4N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B`E<RX`3F\@9FEL92!U<&QO861E9`!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O
M<F0@<')O=FED960@9F]R($Q$05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F]N
M90!.;W)F;VQK($ES;&%N9`!.;W)W87D`3F]T(&EM<&QE;65N=&5D+@!.;W0@
M<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&EC90!.;W9E;6)E<@!.=6UB
M97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!/2P!/8W1O8F5R`$]F9FEC
M90!/;6%N`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3W!E;B!I
M;B!A(&YE=R!W:6YD;W<`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F=A;FES
M871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U
M<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N
M960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!?2%`@4VAE
M;&P`4&%K:7-T86X`4&%L874`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R
M86=U87D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D('=I
M=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D
M<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VYS
M(&9O<@!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!H:6QI<'!I;F5S`%!H
M;VYE`%!I=&-A:7)N`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@
M=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!V
M86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!O;&%N9`!0
M;W)T=6=A;`!0<F5V:65W`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$
M97-C<FEP=&EO;@!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U
M8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE
M<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!1871A<@!1=65R>0!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2969R97-H($1Y;F%M:6,@365N=2!%
M;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M;W1E(%-E<G9E<G,`
M4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!P86ER
M`%)E;6]V92!T:&4`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S`%)E<V5T
M`%)E<V5T(%!A<W-W;W)D`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2
M971U<FX@=&\@3W!T:6]N<P!2975N:6]N`%)I8V@@5&5X="!%9&ET;W(@3W!T
M:6]N<P!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A
M=&4@4FEG:'0`4F]W('!R;W!E<G1I97,`4G5S<VEA;B!&961E<F%T:6]N`%)W
M86YD80!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%33"!A=71H96YT:6-A
M=&EO;B!I<R!N;W0@879A:6QA8FQE+@!344P@4VAE;&P`4U-(`%-?44P@4VAE
M;&P`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,
M=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S`%-A;6]A`%-A;B!-87)I;F\`4V%U9&D@07)A
M8FEA`%-A=F4`4V%V92`B)7,B`%-A=F4@)7,`4V%V92!/<'1I;VYS`%-E87)C
M:`!396QE8W0@1FEL97,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@
M=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YE9V%L
M`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E=`!3970@=7`@<F5M;W1E('-E
M<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A
M;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@
M9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C
M;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L
M87D@;W!T:6]N<RX`4V5T=7``4V5Y8VAE;&QE<P!3:&]R="!3=6UM87)Y`%-H
M;W<`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:65R<F$@3&5O;F4`4VEG;B!U
M<"!I9B!N;W0@<F5G:7-T97)E9`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R
M:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA
M`%-L;W9E;FEA`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O=71H($%F<FEC
M80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4W!A:6X`4W!A;0!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W)I($QA;FMA`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3
M=')E970@061D<F5S<P!3=6)J96-T`%-U8FUI=`!3=6-C97-S`%-U8V-E<W-F
M=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!C
M;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U
M8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL>2!R96UO=F5D
M("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@=7!D871E9"`B
M)7,B`%-U9&%N`%-U;G)I<V4O4W5N<V5T`%-U<FEN86UE`%-W87II;&%N9`!3
M=V5D96X`4W=I='IE<FQA;F0`4WER:6%N($%R86(@4F5P=6)L:6,`5&%I=V%N
M`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI
M82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`
M5&5X="!/;FQY`%1H86EL86YD`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2X`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S
M(B!H87,@8F5E;B!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`
M5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M
M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S
M97(@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M
M(')E;6]V:6YG("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@
M<')O8FQE;2!U<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S
M(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M
M8F5R+@!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@
M<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!S97)V97(@8V%N
M)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1I;64`5&EM92!F
M;W)M870`5&ET;&4`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD
M(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W
M:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O
M;F=A`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=6YI<VEA
M`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5V
M86QU`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5;FET960@07)A8B!%;6ER
M871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:VYO=VX`56YN
M86UE9`!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P;&]A9`!5<G5G
M=6%Y`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R;F%M90!5
M<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA
M;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9A8V%T:6]N
M`%9A;G5A='4`5F5N97IU96QA`%9E<G-I;VX`5FEE="!.86T`5FEE=R`E<P!6
M:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5V%L;&ES(&%N
M9"!&=71U;F$`5V%R;FEN9P!796(`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T
M;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N
M("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO
M;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAI8V@@<&QU9VEN
M<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:"!O
M9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE
M>'0@;&]G+6EN*3H`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`65E960!9
M96%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@:&%V92!B965N(&QO
M9V=E9"!O=70N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R
M92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S
M<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y
M('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=7(@16UA:6P@061D<F5S<P!9;W5R
M($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE
M="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@
M>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO
M=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A
M=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+"!O
M<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE
M<B!R96%S;VXN`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!C=7)R
M96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U
M;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:86UB
M:6$`6FEM8F%B=V4`6U!R;V)L96T@4F5P;W)T70!?061M:6YI<W1R871I;VX`
M7T-,20!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%],;V<@:6X`7TQO9R!O
M=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M
M;W9E($QI;FLN+BX`7U-E='5P`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L96YD
M87(`9FEL90!N86UE`&YO=&5P860`=6YN86UE9`!V0V%R9`!0<F]J96-T+4ED
M+59E<G-I;VXZ($AO<F1E(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z
M(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M
M,3$M,C0@,C`Z-38K,#$P,`I03RU2979I<VEO;BU$871E.B`R,#`U+3$Q+3(T
M(#(Q.C0V*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!+<GIY<WIT;V8@2V]Z;&]W
M<VMI(#QK;WII:S%`;S(N<&P^"DQA;F=U86=E+51E86TZ(%!O;&ES:"`\<&Q`
M;&DN;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O
M<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,@I#;VYT96YT+51R86YS9F5R+45N
M8V]D:6YG.B`X+6)I=`H`)7,@+2!G;W1O=WD@9&\@=WEK;VYA;FEA(&-Y:VQI
M8WIN>6-H(&]P97)A8VII('IA>FYA8WIO;GEC:"!P;VYIOV5J+@`@*"5S(&1N
M:2!T96UU*0`H:VQU8WH@9&]S=.IP=2`E<RD`("AW(&-IL6=U("5S(&1N:2D`
M("AD>FFV*0`@*&IU=')O*0`@*'=C>F]R86HI`"(E<R(@;FEE(&IE<W0@<')A
M=VEDLV]W>6T@=WEB;W)E;2X`(B5S(B!N:64@:F5S="!S:V]N9FEG=7)O=V%N
M>2!W(')E:F5S=')Z92!(;W)D92X`561ALV\@<VGJ(&1O9&'F("(E<R(@9&\@
M9W)U<"X`561ALV\@<VGJ(&1O9&'F("(E<R(@9&\@=7!R87=N:67Q+@`B)7,B
M(&YI92!Z;W-T8;,@=71W;W)Z;VYY.B`E<RX`)60@)7,@:2`E<P`E<R`M(%5W
M86=A`$%D;6EN:7-T<F%C:F$@)7,`)7,@;V1C:7-K('!A;&-A`"5S(&M"`"5S
M("T@;W!E<F%C:F4@8WEK;&EC>FYE("T@<&]T=VEE<F1Z96YI90!+;VYF:6=U
M<F%C:F$@)7,`4F5J97-T<F%C:F$@)7,`)7,@:G6_(&ES=&YI96IE+@`E<R!J
M97-T('=Y;6%G86YY`"5S(&UI;G5T`"5S(&YI97IN86QE>FEO;GDN`"5S(&1O
M("5S('H@)7,`2W-IL;]K82!A9')E<V]W82`E<P!+86QE;F1A<GH@)7,`3F]T
M871N:6L@)7,`3&ES=&$@>F%D8?$@)7,`)7,Z("5S`"TM('=Y8FEE<GH@+2T`
M,3(M9V]D>FEN;GD@9F]R;6%T`#(T+6=O9'II;FYY(&9O<FUA=``R-"!G;V1Z
M+@`\4&]P<GIE9&YI`$YA<W2Q<&FS(&*SL60@:W)Y='EC>FYY`%!O=')Z96)N
M>2!J97-T(&ML=6-Z('!U8FQI8WIN>2!01U`@9&\@>F%S>GEF<F]W86YI82!W
M:6%D;VUOMF-I+@!0;W1R>F5B;GD@:F5S="!K;'5C>B!P=6)L:6-Z;GD@4$=0
M(&1O('-P<F%W9'IE;FEA('!O9'!I<V%N96H@=VEA9&]M;[9C:2X`4&]T<GIE
M8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A=&YY(%!'
M4"!O<F%Z(&AA<[-O(&1O(&]D<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2X`4&]T
M<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!01U`L(&ML=6-Z('!R>7=A=&YY
M(%!'4"!O<F%Z(&AA<[-O(&1O('!O9'!I<V%N:6$@=VEA9&]M;[9C:2X`4&]T
M<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!3+TU)344L(&ML=6-Z('!R>7=A
M=&YY(%,O34E-12!O<F%Z(&AA<[-O(&1O(&]D<WIY9G)O=V%N:6$@=VEA9&]M
M;[9C:2X`4&]T<GIE8FYE('.Q(&ML=6-Z('!U8FQI8WIN>2!3+TU)344L(&ML
M=6-Z('!R>7=A=&YY(%,O34E-12!O<F%Z(&AA<[-O(&1O('!O9'!I<V%N:6$@
M=VEA9&]M;[9C:2X`4&]T<GIE8FYY(&IE<W0@:VQU8WH@<'5B;&EC>FYY(%--
M24U%(&1O('IA<WIY9G)O=V%N:6$@=VEA9&]M;[9C:2X`04TO4$T`3R!T>6T@
M961Y=&]R>F4`3R!P<F]G<F%M:64N+BX`2&%SLV\@9&\@:V]N=&$`2V]N=&\@
M>F%B;&]K;W=A;F4N`$MO;G1A`$1O9&%J`$1O9&%J('1U=&%J.@!$;V1A:B!N
M;W>Q(&=R=7#J`$1O9&%J(&YO=V4@=7!R87=N:65N:64`1&]D86H@;F]W96=O
M('6_>71K;W=N:6MA.@!$;V1A:B!K;VQU;6[J`$1O9&%J(&YO=WEC:"!C>K-O
M;FOS=P!$;V1A:B!P87+J`$1O9&%J(&UE;G4@)7,@9&\@<&%S:V$@36]Z:6QL
M:0!$;V1A:B!D;R!K<VFQOVMI(&%D<F5S;W=E:CH`1&]D86H@9&\@;6]J96H@
M:W-IL7IK:2!A9')E<V]W96H`1&]D86H@=;]Y=&MO=VYI:V$`1&]D86YO("(E
M<R(@9&\@<WES=&5M=2X@36^_97-Z('-IZB!Z86QO9V]W8>8N`$1O9&%W86YI
M92!UOWET:V]W;FEK\W<@:F5S="!W>;-A8WIO;F4N`$%D<F5S`$MS:;&_:V$@
M861R97-O=V$`061M:6YI<W1R86-J80!296ML86UY`$%F9V%N:7-T86X`06QB
M86YI80!!;&=I97)I80!!;&EA<P!7<WIY<W1K;P!7<WIY<V-Y('5W:65R>GET
M96QN:65N:2!UOWET:V]W;FEC>0!7<WIY<W1K:64@9W)U<'D`5W-Z>7-T:VEE
M('5P<F%W;FEE;FEA`%!O>G?S;"!N82!W:65L92!A9')E<_-W`$IUOR!I<W1N
M:65J90!!;'1E<FYA='EW;GD@;&]G:6X@24U34`!!;'1E<FYA='EW;GD@:&%S
MLV\@24U34`!!;'1E<FYA='EW;F$@;F%Z=V$@=;]Y=&MO=VYI:V$@24U34`!!
M;'1E<FYA='EW;GD@861R97,@96UA:6P`06QT97)N871Y=VYY('1E:W-T.@!:
M;W-T8;-A('!O9&%N82!N:65P<F%W:62S;W=A('=A<G1OMN8N`$%N9&]R80!!
M;F=O;&$`06YG=6EL;&$`06YO;FEM;W=E(%!R;WAY`$]D<&]W:65DO`!!;G1A
M<FMT>61A`$%P;&EK86-J80!!<&QI:V%C:F$@9V]T;W=A`%IA='=I97)DO`!+
M=VEE8VEE\0!7:65L:V^VYB!A<F-H:7=U;0!.87IW82!A<F-H:7=U;0!!<F=E
M;G1Y;F$`07)M96YI80!!<G5B80!0;W!R;[8@;R!P;W1W:65R9'IE;FEE('!R
M>F5D('=Y:V]N86YI96T@;W!E<F%C:FD@8WEK;&EC>FYY8V@_`$%T<GEB=71Y
M`%-I97)P:67Q`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER=7,Z($YI92!Z
M;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&EM87`N`$%U=&A?
M8WER=7,Z($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA
M(&EM87`N`$%U=&A?9G1P.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O(')O
M>G-Z97)Z96YI82!&5%`N(%-K;VUP:6QU:B!02%`@>B!P87)A;65T<F5M("TM
M96YA8FQE("X`075T:%]I;6%P.B!.:64@>FYA;&5Z:6]N;R!W>6UA9V%N96=O
M(')O>G-Z97)Z96YI82!)34%0+@!!=71H7VMR8C4Z($YI92!Z;F%L97II;VYO
M('=Y;6%G86YE9V\@<F]Z<WIE<GIE;FEA(&MR8C4N`$%U=&A?;&1A<#H@3FEE
M('IN86QE>FEO;F\@=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@3$1!4"X`075T
M:%]L9&%P.B!.:64@=61ALV\@<VGJ('5S=6ZQYB!UOWET:V]W;FEK82`E<P!!
M=71H7VQD87`Z($YI92!U9&&S;R!S:>H@=6%K='5A;&YIYB!UOWET:V]W;FEK
M82`E<P!!=71H7VUC86PZ($YI92!Z;F%L97II;VYO('=Y;6%G86YE9V\@<F]Z
M<WIE<GIE;FEA($U#04PN`$%U=&A?<VUB875T:#H@3FEE('IN86QE>FEO;F\@
M=WEM86=A;F5G;R!R;WIS>F5R>F5N:6$@<VUB875T:"X`57=I97)Z>71E;&YI
M96YI92!N:64@<&]W:6]DLV\@<VGJ`%5W:65R>GET96QN:65N:64@;FEE('!O
M=VEO9+-O('-IZBX@)7,`57=I97)Z>71E;&YI96YI92!O9')Z=6-O;F4@<')Z
M97H@<V5R=V5R(%)!1$E54RX`57=I97)Z>71E;&YI96YI92!D;R!S97)W97)A
M($944"!N:64@<&]W:6]DLV\@<VGJ+@!$;W-TZG!N92!P;VQA.@!!>F5R8F5J
M9+]A;@!7>6WS=VMI($)/1D@`5+-O`$MO;&]R('2S80!:LV4@:&%SLV\@2V5R
M8F5R;W-A+@!:LV$@;F%Z=V$@=;]Y=&MO=VYI:V$@2V5R8F5R;W-A`%=Y<W!Y
M($)A:&%M80!"86AR86IN`$)ALW1Y8VMI("A)4T\M.#@U.2TQ,RD`0F%N9VQA
M9&5S>@!":6&S;W)UM@!"96QG:6$`0F5L:7IE`$)E;FEN`$)E<FUU9'D`0FAU
M=&%N`$1A=&$@=7)O9'IE;FEA`%5S=&%W:65N:6$@8FQO:W4`5'EP(&)L;VMU
M`$)O;&EW:6$`6F%KLV%D:VD`0F^V;FEA(&D@2&5R8V5G;W=I;F$`3V)A`$)R
M87IY;&EA`$)ULV=A<FEA`$--4P!#4D,`5[-AMF-I=V^V8VD@:V]M\W)K:2XN
M+B`H7V,I`$MA;&5N9&%R>@!+86UB;V2_80!+86UE<G5N`$YI92!U9&&S;R!S
M:>H@>G)E<V5T;W=AYB!H87.S82!A=71O;6%T>6-Z;FEE+"!S:V]N=&%K='5J
M('-IZB!Z(&%D;6EN:7-T<F%T;W)E;2X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA
M('-IZB!Z('-E<G=E<F5M($E-05`Z("5S`$MA;F%D80!!;G5L=6H`06YU;'5J
M(')A<&]R="!O('!R;V)L96UI90!.:64@;6^_;F$@<VMA<V]W8>8@<&QI:W4@
M(B5S(@!.:64@=61ALV\@<VGJ('IN86QEO.8@:V%T86QO9W4@='EM8WIA<V]W
M96=O+@!.:64@;6^_;F$@<VMA<V]W8>8@:V%T86QO9W4@(B5S(@!7>7-P>2!:
M:65L;VYE9V\@4')Z>6RQ9&MA`$MA=&5G;W)I92!I(&]Z;F%C>F5N:6$`5&5L
M+B!K;VTN`%>S8;9C:7=OMF-I(&MO;?-R:VD`5[-AMF-I=V^V8VD@:V]M\W)K
M:0!496PN(&MO;2X`0V5L='EC:VD@*$E33RTX.#4Y+3$T*0!297!U8FQI:V$@
MIG)O9&MO=V5J($%F<GEK:0"F<F]D:V]W;V5U<F]P96IS:VD@*$E33RTX.#4Y
M+3(I`%-Z8WIE9_.S>2!C97)T>69I:V%T=0!7LV&V8VEC:65L(&-E<G1Y9FEK
M871U`$-Z860`6FUI9?$`6FUI9?$@:6UIZBP@;F%Z=VES:V\@:2!A9')E<RP@
M:W3S<GD@:6YN:2!W:61ZL2!W(%1W;VEC:"!L:7-T86-H(&5M86EL+@!3<')A
M=V2\(&QI;FLN+BX`6F%Z;F%C>B!P;WIY8VKJ(&1L82!K=/-R96H@8VAC97-Z
M('=Y:V]N8>8@;W!E<F%C:NHN`$-H:6QE`$-H:6YY`%!O9&%J(&AA<[-O`%!O
M9&%J(&YA>G?J('6_>71K;W=N:6MA`%=Y8FEE<GH@<W!O<_-B('=YMG=I971L
M86YI82!D870Z`%=Y<W!A($)OOV5G;R!.87)O9'IE;FEA`$ML:6MN:6H@8GD@
M:V]N='EN=6]W8>8`6F%M:VYI:B!O:VYO`%=Y<W!Y($MO:V]S;W=E("A+965L
M:6YG82D`4V-H;W=A:B!P87-E:P!+;VQU;6)I80!+;VQO<@!7>6)I97)Z(&MO
M;&]R`%=Y8O-R(&MO;&]R=0!4>71ULWD@:V]L=6UN`$MO;65N9&$`4&]WLV]K
M80!+;VUE;G1A<GH`2V]M;W)Y`$9I<FUA`%-T=_-R>B!W:6%D;VUOMN8@*"5S
M*0!+;VUP=71E<GD`5V%R=6YK:0!3:V]N9FEG=7)U:B`E<P!0;W1W:65R9+P@
M:&%SLV\`2V]N9V\`1&5M;VMR871Y8WIN82!297!U8FQI:V$@2V]N9V\`4&^S
ML6-Z96YI92!N:64@<&]W:6]DLV\@<VGJ+@!0;[.Q8WIE;FEE(&YI92!P;W=I
M;V2S;R!S:>HZ(`!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z;F5G
M;R!S97)W97)A+@!/9&WS=VEO;F\@<&^SL6-Z96YI82!D;R!P=6)L:6-Z;F5G
M;R!S97)W97)A+B!0;W?S9#H@)7,@*"5S*0!"L[%D('!O9&-Z87,@L[%C>F5N
M:6$@<VGJ('H@<V5R=V5R96T@1E10+@!+;VYT86MT>2!Z;W-T8;-Y('!O;7FV
M;&YI92!D;V1A;F4@9&\@5'=O:F5J(&MS:;&_:VD@861R97-O=V5J+@!:87=A
M<G1OMN8@(B5S(@!+;VYY;G5U:@!7>7-P>2!#;V]K80!3:V]P:75J`%-K;W!I
M=6H@=WEB\W(`3FEE('5D8;-O('-IZB!Z87-Z>69R;W=AYB`H4$=0*2!W:6%D
M;VUOMF-I+@!.:64@=61ALV\@<VGJ('!O9'!I<V'F("A01U`I('=I861O;6^V
M8VDN`$YI92!U9&&S;R!S:>H@>F%S>GEF<F]W8>8@*%,O34E-12D@=VEA9&]M
M;[9C:2X`3FEE('5D8;-O('-IZB!P;V1P:7-AYB`H4R]-24U%*2!W:6%D;VUO
MMF-I+@!"L[%D('!O9&-Z87,@L[%C>F5N:6$@<VGJ('H@<V5R=V5R96T@3$1!
M4"X`0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M("(E<R(@
M<&]P<GIE>B!&5%`Z("5S`$YI92!U9&&S;R!S:>H@;V1S>GEF<F]W8>8@9&%N
M>6-H(%!'4"X`3FEE('5D8;-O('-IZB!O9'-Z>69R;W=AYB!D86YY8V@@4R]-
M24U%+@!.:64@=61ALV\@<VGJ('5S=&%L:>8@861R97-U(&4M;6%I;"!O9&)I
M;W)C>2X`3FEE('5D8;-O('-IZB!U>GES:V'F('H@<V5R=V5R82!K;'5C>F$@
M<&)U;&EC>FYE9V\N`$YI92!U9&&S;R!S:>H@;W1W;W)Z>>8@(B5S(B!D;R!Z
M87!I<W4N`$YI92!M;[]N82!O='=O<GIYYB`E<RX`3FEE(&UOOVYA(&]T=V]R
M>GGF(&UO9'6S=2!-86EN=&5N86YC95]487-K("5S`$YI92!M;[]N82!O='=O
M<GIYYB!K871A;&]G=2`B)7,B`$YI92!U9&&S;R!S:>H@<VMA<V]W8>8@<&QI
M:W4@(B5S(BX`3FEE('5D8;-O('-IZB!Z;F%L9;SF('!A<VMA($UO>FEL;&DN
M(%5P97=N:6H@<VGJ+""_92!J97-T(&]N(&]T=V%R='DN`$MR86H`4W1W\W)Z
M`%-T=_-R>B!L:6YK`%-T=_-R>B!N;W>Q`$YU;65R(&MA<G1Y(&MR961Y=&]W
M96H`0VAO<G=A8VIA`$MU8F$`3V)E8VYY(&-Z87,`4W!E<G-O;F%L:7IU:B!Z
M861A;FEA('5R=6-H86UI86YE('!R>GD@;&]G;W=A;FEU(&1O("5S+@!7>71N
M:6H`0WEP<@!297!U8FQI:V$@0WIE8V@`1$0`0V]D>FEE;FYI90!$871A`%]5
M<W7Q(&MO;'5M;NH`1W)U9'II9?$`1&]M>;9L;GD@:V]L;W(`1&]M>;9L;F$@
M=&^_<V%M;[;F`$1O;7FV;&YE('5P<F%W;FEE;FEA`$1O;7FV;&YE('5P<F%W
M;FEE;FEA`%5S=?$`57-U\2!'<G5PZ@!5<W7Q('5P<F%W;FEE;FEA`%5S=?$@
M:2!W>6-Z>;;F('=I861O;6^V8VD`57-U\2!K;VWS<FOJ`%5S=?$@:V]L=6UN
MZ@!3:V%S=6H@=7!R87=N:65N:6$@9&QA("(E<R(`4VMA<V]W8>8@=7!R87=N
M:65N:6$@9&QA("(E<R(@:2!W<WIY<W1K:64@<&]D+75P<F%W;FEE;FEA/P!5
M<W7Q('=I97)S>@!3:V%S=6H@=WEB<F%NL2!T;[]S86UOMN8`57-U\2!A:W1U
M86QNL2!K;VQU;6[J`%5S=?$@86MT=6%L;GD@=VEE<G-Z`%-K87-O=V'F('1O
M('5P<F%W;FEE;FEE(&D@=W-Z>7-T:VEE('!O9"UU<')A=VYI96YI83\`1&%N
M:6$`3W!I<WH@<')O8FQE;0!3>F-Z96?SLWD@>F]S=&&S>2!Z86QO9V]W86YE
M(&1L82!A9&UI;FES=')A=&]R82X`2V%T86QO9P!7>;9W:65T;"!C>F%S('<@
M9F]R;6%C:64@,C0M9V]D>FEN;GEM/P!5<W1A=VEE;FEA('=Y9VRQ9'4`1+]I
M8G5T:0!.:64@:V%S=6H`0G)A:R!B97IP;[9R961N:65G;R!D;W-TZG!U(&1O
M(&UA:6YT96YA;F-E+G!H<`!$;VUI;FEK82`H5W-P\VQN;W1A($1O;6EN:6MI
M*0!$;VUI;FEK86YA("A297!U8FQI:V$@1&]M:6YI:V'Q<VMA*0"F8VFQ9VYI
M:@"F8VFQ9VYI:B`E<P!.87)K;W1Y:VD`12UM86EL`$5K=V%D;W(`161Y8VIA
M`%5S=?$@1W)U<.H`6FUI9?$@=7!R87=N:65N:64`6FUI9?$@=7!R87=N:65N
M:6$`6FUI9?$@=7!R87=N:65N:6$@9&QA("5S`%IM:67Q('5S=&%W:65N:6$@
M9&QA.@!:;6EE\2!U<')A=VYI96YI82!D;&$@)7,`16=I<'0`4V%L=V%D;W(`
M16UA:6P`061R97,@96UA:6P`061R97-Y(&5M86EL(&UU<WJQ(&1O('-I96)I
M92!P87-O=V'F+@!%;6]T:6MO;GD`4'5S=&$@=VEA9&]M;[;F+@!"<F%K(')E
M>G5L=&%T\W<N`%>SL6-Z>>8@;65N=2!K;VYT96MS=&]W92!P;V0@<')A=WEM
M('!R>GEC:7-K:65M(&UY<WIY/P!'=VEN96$@4O-W;FEK;W=A`$5R>71R96$`
M0K.Q9`!"L[%D('!R>GD@>F%P:7-I92`B)7,B+@!%<W1O;FEA`$5T:6]P:6$`
M175R;W!A`$-O(&MAOV1E(#$U(&UI;G5T`$-O(&MAOV1E(#(@;6EN=71Y`$-O
M(&MAOV1E(#,P('-E:W5N9`!#;R!K8;]D92`U(&UI;G5T`$-O(&MAOV1E('IA
M;&]G;W=A;FEE`$-O(&MAOV1E('#SLR!G;V1Z:6YY`$-O(&MAOV2Q(&UI;G5T
MZ@!0<GIY:[-A9&]W92!W87)T;[9C:3H`5WEK;VYA:@!2;WIW:?$`4F]Z=VGQ
M('!A<V5K`$*SL60@<&]D8WIA<R"SL6-Z96YI82!S:>H@>B!S97)W97)E;2!,
M1$%0+@!"L[%D('!O9&-Z87,@:V]P:6]W86YI82!Z("(E<R(N`$*SL60@<&]D
M8WIA<R!K;W!I;W=A;FEA(&1O("(E<R(N`$*SL60@<&]D8WIA<R!P<GIE;F]S
M>F5N:6$@9&\@(B5S(BX`1F%L:VQA;F1Y("A-86QW:6YY*0!7>7-P>2!/=V-Z
M90!"L[%D(&MR>71Y8WIN>3H@`$9A:W,`3'5T>0!&:62_:0!-96YE9+]E<B!P
M;&EK\W<`3F%Z=V$@<&QI:W4`5WEB\W(@<&QI:W4`5V=R>7=A;FEE('!L:6MU
M`%=G<GEW86YI92!P;&EK\W<@;FEE(&IE<W0@;V)SLW5G:7=A;F4N`$9I;'1R
M>0!&:6YL86YD:6$`2F5D>F5N:64`6F%P;VUN:6&S9;8@:&%SLV$_`$9R86YC
M:F$`1W5J86YA($9R86YC=7-K80!0;VQI;F5Z:F$@1G)A;F-U<VMA`$9R86YC
M=7-K:64@5&5R>71O<FEA(%!OLW5D;FEO=V4@:2!!;G1A<FMT>6-Z;F4`3V0`
M1V%B;VX`1V%M8FEA`$YI96UC>0!':&%N80!':6)R86QT87(`262\`%=Y<WIU
M:VEW87)K82!';V]G;&4`1W)E8VIA`$=R96YL86YD:6$`1W)E;F%D80!'<G5P
M>2!D>7-K=7-Y:FYE`$=W861E;'5P80!'=6%M`$=W871E;6%L80!'=65R;G-E
M>0!'=VEN96$`1W=I;F5A($)I<W-A=0!'=6IA;F$`2%1-3`!(86ET:0!7>7-P
M>2!(96%R9"!I($UC1&]N86QD80!0;VUO8P!7>7-O:VD`7U-T87)T`%=A='EK
M86X@*%-T;VQI8V$@07!O<W1O;'-K82D`4&]C>K%T96L`061R97,@9&]M;W=Y
M`%1E;"X@9&]M+@!(;VYD=7)A<P!(;VYG2V]N9P!(;W)D90!(;W)D92]+;VQA
M8CH@561ALV\@<VGJ('5S=6ZQYB`E<R`B)7,B`%?J9W)Y`$ES;&%N9&EA`%1Y
M;&MO(&EK;VYY`$EK;VYY('H@=&5K<W1E;0!.87IW82!T;[]S86UOMF-I.@!'
M<F%F:6MA`$EM<&]R=&]W86YE('!O;&4Z("5S`$EM<&]R=&]W86YE('!O;&$Z
M`$EN9&EE`$EN9&]N97IJ80!);F9O`%=K;&5J(&]B<F%Z96L`5WESLV%N92!N
M:65P<F%W:62S;W=E(&1A;F4N`$YI97!R87=I9+-O=WD@861R97,@9&]C96QO
M=WDN`$YI97!R87=I9+-O=WD@9F]R;6%T('!L:6MU`$YI97!R87=I9+-O=WD@
M:VQU8WH@;&EC96YC:FDN`$ER86X`27)A:P!)<FQA;F1I80!)>G)A96P`5WED
M87=C80!7LV]C:'D`2F%M86IK80!3='EC>F7Q`$IA<&]N:6$`2F]R9&%N`$QI
M<&EE8P!#>F5R=VEE8P!+87IA8VAS=&%N`$ME;FEA`%1W;W)Z96YI92!K;'5C
M>F$`3V1C:7-K(&ML=6-Z80!$LW5G;[;F(&ML=6-Z80!4>7`@:VQU8WIA`$ML
M=6-Z(&IUOR!I<W1N:65J92!N82!P=6)L:6-Z;GEM('-E<G=E<GIE(&ML=6-Z
M>2X`1'II96-I`$MI<FEB871I`$MO<F5A\7-K82!297!U8FQI:V$@3'5D;W=O
M+41E;6]K<F%T>6-Z;F$`4F5P=6)L:6MA($MO<F5I`$MU=V5J=`!+:7)G:7-T
M86X`5WEG;+%D("A?>2D`2NIZ>6L`3&%O<P!/<W1A=&YI92!L;V=O=V%N:64Z
M("5S`$]S=&%T;FEE(&QO9V]W86YI93H@)7,@>B`E<P!/<W1A=&YI92!L;V=O
M=V%N:64Z(&YI9V1Y`*-O='=A`$QE<V]T:&\`3&EB97)I80!,:6)I80!,:65C
M:'1E;G-T96EN`%=YMG=I971L('1E;6%T>2!P;VUO8WD`3&ES=&]W86YI92!U
MOWET:V]W;FEK\W<@:F5S="!W>;.Q8WIO;F4N`$QI='=A`*-A9&]W86YI92XN
M+@!#>F%S(&QO:V%L;GDZ(`!5<W1A=VEE;FEA(&QO:V%L;F4@:2!C>F%S`%IA
M;&]G=6H`5WEL;V=U:@!:861A;FEA('!R>GD@;&]G;W=A;FEU`$QO9V]W86YI
M92!N:64@<&]W:6]DLV\@<VGJ+"!P;VYI97=AOR!P;V1ALV6V(&YI97!R87=I
M9+-O=V4@:&%SLV\@;'5B(&YA>G?J('6_>71K;W=N:6MA+@!,;V=O=V%N:64@
M;FEE('!O=VEO9+-O('-IZBX`3FES:VD`3'5K<V5M8G5R9P!-30!-3U1$`$U3
M1P!-86MA=0!-86-E9&]N:6$`36%D86=A<VMA<@!0;V-Z=&$`36%L87=I`$UA
M;&5Z:F$`36%L961I=WD`36%L:0!-86QT80!:87)ZL61Z86H@;&ES=+$@:V%T
M96=O<FEI+"!K=/-R>6UI(&+J9'II97-Z(&]Z;F%C>F&S('!O>GEC:F4L(&D@
M:V]L;W)A;6D@>B!N:6UI('IW:;%Z86YY;6DN`$UA<GIE8P!-87)G:6YE<P!7
M>7-P>2!-87)S:&%L;&$`36%R='EN:6MA`%!A<W5JL6-E('!O;&$`36%U<F5T
M86YI80!-875R:71I=7,`36%J`$UA:F]T=&$`5')Y8B!M96YU.@!0;[.Q8WH@
M:V]M\W)K:0!7:6%D;VUOMN8`0FQO:R`B365T87(B(&YI92!J97-T(&1O<W3J
M<&YY+@!";&]K(")-971A<B(@;FEE(&IE<W0@9&]S=.IP;GDN(%-Z8WIE9_.S
M>2!Z9&%R>F5N:6$@>F]S=&&S>2!Z86QO9V]W86YE(&1L82!A9&UI;FES=')A
M=&]R82X`365K<WEK`%1Y<"!-:6UE`$]S=&%T;FEA(&UO9'EF:6MA8VIA`%IM
M:67Q(&QI;FL`36^S9&%W:6$`4F5P=6)L:6MA($UOLV1A=VEI`$UO;F%K;P!-
M;VYG;VQI80!#;R!M:65S:;%C`$UO;G1S97)R870`1F%Z>2!K<VGJOWEC80!-
M87)O:V\`4')Z97-U\2!W(&3SLP!0<GIE<W7Q('<@;&5W;P!0<GIE<W7Q('<@
M<')A=V\`4')Z97-U\2!W(&?S<NH`4')Z96YI9;8@=R!D\[,`4')Z97-U\2!W
M(&?S<NH`36]Z86UB:6L`2V]N=&\`3?-J('!O<G1A;`!":7)M80!.87IW:7-K
M;P!.86UI8FEA`$YA=7)U`$YE<&%L`$AO;&%N9&EA`$%N='EL92!(;VQE;F1E
M<G-K:64`4VEEY@!.:6=D>0!.;W=A($MA;&5D;VYI80!.;W=A(&MA=&5G;W)I
M80!.;W=A(%IE;&%N9&EA`%=I861O;6^V8VD`3F%S=.IP;F4`3F%S=.IP;F4@
M;W!C:F4`3FEK87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEU90!"97H@>FUI86XN
M`$)R86L@:V]N9FEG=7)A8VII(&1L82`E<RX`3FEE('=G<F%N;R!P;&EK=0!.
M:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($A45%`N`$YI
M92!P;V1A;F\@:&%SLV$@9&QA('5W:65R>GET96QN:65N:6$@24U!4"X`3FEE
M('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!+97)B97)O<RX`
M3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!,1$%0+@!.
M:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA($Q/1TE.+@!.
M:64@<&]D86YO(&AA<[-A(&1L82!U=VEE<GIY=&5L;FEE;FEA(%!!4U-71"X`
M3FEE('!O9&%N;R!H87.S82!D;&$@=7=I97)Z>71E;&YI96YI82!334(N`*]A
M9&YA`$YO<F9O;&L`3F]R=V5G:6$`3FEE('IA:6UP;&5M96YT;W=A;F\N`$YI
M975S=&%W:6]N90!.:65O8G.S=6=I=V%N90!5=V%G:0!5=V%G80!,:7-T;W!A
M9`!,:6-Z8F$@:V]L=6UN`$QI8WIB82!W:65R<WIY`$]+`%!AO&1Z:65R;FEK
M`$)I=7)O`$]M86X`5'?S:B!J961E;B!A9')E<R!E+6UA:6P@:F5S="!D;WIW
M;VQO;GDN`$]T=_-R>B!W(&YO=WEM(&]K;FEE`$]P8VIE`$]P8VIE("5S`$]R
M9V%N:7IA8VIA`$IE9&YO<W1K82!O<F=A;FEZ86-Y:FYA`$]R9V%N:7IA=&]R
M`$EN;F4`26YN92!I;F9O<FUA8VIE`$EN;F4@=7!R87=N:65N:6$`57=I97)Z
M>71E;&YI96YI92!004T@;FEE(&IE<W0@9&]S=.IP;F4N`$-Y9G)O=WD@<&]D
M<&ES(%!'4`!7:6%D;VUOMN8@>F%S>GEF<F]W86YA(%!'4`!+;'5C>B!P=6)L
M:6-Z;GD@4$=0`%=I861O;6^VYB!Z87-Z>69R;W=A;F$O<&]D<&ES86YA(&ML
M=6-Z96T@4$=0`$MO9"!02%``4&]WLV]K82!02%``4&]WLV]K82!07TA0`%!A
M:VES=&%N`%!A;&%U`%!A;F%M80!087!U82U.;W=A($=W:6YE80!087)A9W=A
M:@!(87.S;P!(87.S;R!N:65P<F%W:62S;W=E`$AA<[-O('H@<&]T=VEE<F1Z
M96YI96T`2&%SLV\Z`$AA<[-O.B``2&%SLV\@;75S:2!P87-O=V'F+@!7:VQE
M:@!7:VQE:B!Z92!S8VAO=VMA`%=Y:V]N86H@8WEK;&EC>FYE(&]P97)A8VIE
M`%=Y:V]N86H@8WEK;&EC>FYE(&]P97)A8VIE('!O9&-Z87,@;&]G;W=A;FEA
M/P!5<')A=VYI96YI90!5<')A=VYI96YI82!D;&$`26YF;W)M86-J92!O<V]B
M:7-T90!097)U`$9I;&EP:6YY`%1E;&5F;VX`4&ET8V%I<FX`3F$@<&5W;F\@
M=7-U;K'F('1E;B!W>6)R86YY(&5L96UE;G0Z`$YA('!E=VYO('5S=6ZQYB!W
M>6)R86YY(&5L96UE;G0Z`%!R;W-ZZB!P;V1AYB!P;W!R87=N>2!A9')E<R!)
M4"X`4')O<WKJ('!O9&'F('!O<')A=VYY(&-Z87,N`%!R;W-ZZB!O<&ES8>8@
M<')O8FQE;2X`4')O<WKJ('!O9&'F(&YA>G?J('6_>71K;W=N:6MA(&D@:&%S
MLV\`4&]L<VMA`%!O<G1U9V%L:6$`4&]D9VRQ9`!+;'5C>B!P<GEW871N>0!0
M<F]B;&5M`$]P:7,@<')O8FQE;74`2VQU8WH@<'5B;&EC>FYY`$%L9V]R>71M
M(&ML=6-Z82!P=6)L:6-Z;F5G;P!);F9O<FUA8VIE(&\@:VQU8WIU('!U8FQI
M8WIN>6T`4&%R82!K;'5C>GD@;W-O8FES='EC:"!N:64@>F]S=&&S82!W>6=E
M;F5R;W=A;F$@<&]M>;9L;FEE+@!0;W)T;W)Y:V\`2V%T87(`6F%P>71A;FEE
M`$ML=6-Z('!U8FQI8WIN>2!24T$@*"5D(&)I=/-W*0!/9+9W:66_(&1Y;F%M
M:6-Z;F4@96QE;65N='D@;65N=3H`3V2V=VEEOR!W:61O:R!S97)W:7-U.@!:
M9&%L;F4@<V5R=V5R>0!5<W7Q`%5S=?$@8FQO:P!5<W7Q(&MO;'5M;NH`57-U
M\2!P87+J`%5S=?$`57-U\2!UOWET:V]W;FEK80!:9&%L;F4@=;]Y=&MO=VYI
M:V$Z("5S`$MA<W5J`%=Y8WIYMN8@:&%SLV\`5WEC>GFVYB!4=V]J92!H87.S
M;P!7>6YI:VD`4&]W<O-T(&1O(&]P8VII`%)E=6YI;VX`4F]Z8G5D;W=A;GD@
M961Y=&]R('1E:W-T=0!3=&%N;W=I<VMO`%)U;75N:6$`3V)R\^8@;R`Q.#`@
M<W1O<&YI`$]B<O/F('<@;&5W;P!/8G+SYB!W('!R87=O`%>S8;9C:7=OMF-I
M(')ZZF1U(%!R;W!E<G1I97,`4F]S:F$`4G5A;F1A`%=I861O;6^VYB!Z87-Z
M>69R;W=A;F$@4R]-24U%`%5W:65R>GET96QN:65N:64@4T%33"!N:64@:F5S
M="!D;W-TZG!N92X`4&]W;&]K82!344P`4U-(`%!O=[-O:V$@4U]13`"F=VGJ
M=&$@2&5L96YA`%-A:6YT($MI='1S(&D@3F5V:7,`4V%I;G0@3'5C:6$`4V%I
M;G0M4&EE<G)E(&D@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!I($=R96YA9'EN
M>0!386UO80!386X@36%R:6YO`$%R86)I82!3875D>6IS:V$`6F%P:7-Z`%IA
M<&ES>B`B)7,B`%IA<&ES>B`E<P!:87!I<WH@;W!C:F4`4WIU:V%J`%=Y8FEE
M<GH@<&QI:VD`5WEB:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ`%=Y8FEE<GH@
M9F]R;6%T(&1A='DZ`%=Y8FEE<GH@=&^_<V%M;[;F(&1O('IM:6%N>3H`5WEB
M:65R>B!Z;F%K('!O9'II8;-U(&1A='DZ`%=Y8FEE<GH@9F]R;6%T(&-Z87-U
M.@!7>6)I97)Z(&1W82!P87-U:K%C92!P;VQA+@!7>6)I97)Z('-C:&5M870@
M:V]L;W+S=RX`5WEB:65R>B!T=_-J('!R969E<F]W86YY(&KJ>GEK.@!7>;9L
M:6H@<F%P;W)T(&\@<')O8FQE;6EE`%-E;F5G86P`5W)Z97-I9?$`3G5M97(@
M<V5R>6IN>0!5<W1A=P!5<W1A=R!Z9&%L;F4@<V5R=V5R>2P@9&\@:W3S<GEC
M:"!C:&-E<WH@;6EEYB!D;W-TZG`@>B!S97)W:7-U+@!5<W1A=R!P<F5F97)O
M=V%N>2!JZGIY:RP@<W1R96;J(&-Z87-O=[$@:2!O<&-J92!D871Y+@!5<W1A
M=R!U<[-U9^H@<&]C>K%T:V]WL2P@<V-H96UA="!K;VQO<O-W+"!O9+9W:66_
M86YI92!S=')O;GD@:2!I;FYE(&]P8VIE('=YMG=I971L86YI80!+;VYF:6=U
M<F%C:F$`4WIE<WIE;&4`2W+S=&MI(&]P:7,`4&]K8;\`4&]K87IY=V'F(&-Z
M87,@;W-T871N:65G;R!Z86QO9V]W86YI82!P;R!L;V=O=V%N:74_`%!O:V&_
M(&UE;G4@)7,@<&\@;&5W96H_`%-I97)R82!,96]N90!:87)E:F5S=')U:B!S
M:>HL(&IEMFQI(&IE<WIC>F4@=&5G;R!N:64@>G)O8FFS9;8`4&]D<&ES`$%L
M9V]R>71M('!O9'!I<W4`4VEN9V%P=7(`5VEE;&MOMN8`4&]M:?$@;W!E<F%C
M:F4@8WEK;&EC>FYE`%.S;W=A8VIA`%.S;W=E;FEA`%=Y<W!Y(%-A;&]M;VYA
M`%-O;6%L:6$`4&^S=61N:6]W82!!9G)Y:V$`4&^S=61N:6]W;V5U<F]P96IS
M:VD@*$E33RTX.#4Y+3,I`$=E;W)G:6$@4&^S=61N:6]W80!(:7-Z<&%N:6$`
M4W!A;0!%9'EC:F$@>FYA:_-W('-P96-J86QN>6-H`%!O9'II96P@:V]M\W)K
MZ@!0;V1Z:65L(&MO;'5M;NH`4&]D>FEE;"!W:65R<WH`4W)I($QA;FMA`%=O
M:F5W\V2\='=O(&QU8B!S=&%N`%-T871U<P!!9')E<R!D;VUO=WD`5&5M870`
M5WFV;&EJ`%!O=V]D>F5N:64`561ALV\@<VGJ(&1O9&'F("(E<R(@9&\@<WES
M=&5M=2X`561ALV\@<VGJ('5S=6ZQYB`B)7,B('H@<WES=&5M=2X`561ALV\@
M<VGJ('5S=6ZQYB`B)7,B+@!59&&S;R!S:>H@=7-U;K'F("(E<R(@>B!S>7-T
M96UU+@!59&&S;R!S:>H@=6%K='5A;&YIYB`B)7,B`%-U9&%N`%=S8VCS9"]Z
M86-H\V0@<[-O\6-A`%-U<FEN86T`4W5A>FD`4WIW96-J80!3>G=A:F-A<FEA
M`%-Y<FEA`%1A:G=A;@!486IW86X`5&%DOWEK:7-T86X`5&%N>F%N:6$`6F%D
M86YI80!.=6UE<B!T96QE9F]N=0!4>6QK;R!T96MS=`!486IL86YD:6$`1'II
MZFMU:F5M>2!Z82!K;W)Z>7-T86YI92!Z('-E<G=I<W4N`%1OOW-A;6^VYB`B
M)7,B('IO<W1ALV$@=7-U;FGJ=&$N`%-E<G=E<B`B)7,B('IO<W1ALR!U<W5N
M:>IT>2X`4V5R=V5R("(E<R(@>F]S=&&S('IA<&ES86YY+@!";&]K('=E871H
M97(N8V]M(&YI92!J97-T(&1O<W3J<&YY+@!.:64@;6$@OV%D;GEC:"!D;W-T
MZG!N>6-H(&]P8VII+@!7>7-TL7!ILR!P<F]B;&5M('!R>GD@9&]D87=A;FEU
M("(E<R(@9&\@<WES=&5M=3H@)7,`5WES=+%P:;,@<')O8FQE;2!P<GIY('5S
M=7=A;FEU(&1A;GEC:"!D;&$@=;]Y=&MO=VYI:V$@(B5S(B!W('-Y<W1E;6EE
M.B``5WES=+%P:;,@<')O8FQE;2!P<GIY('5S=7=A;FEU("(E<R(@>B!S>7-T
M96UU+@!7>7-TL7!ILR!P<F]B;&5M('!R>GD@=6%K='5A;&YI86YI=2`B)7,B
M.B`E<P!7>7-TL7!ILR!BL[%D('!O9&-Z87,@=WFV=VEE=&QA;FEA('1E:B!C
M>NJV8VD@=VEA9&]M;[9C:0!7>7-TL7!ILR!BL[%D('!O8WIA<R!I;7!O<G1O
M=V%N:6$@9&%N>6-H(&E#86QE;F1A<BX`4&QI:R!N:64@=WEG;+%D82!N82!P
M;W!R87=N92!A<F-H:7=U;2!205(N`%!L:6L@;FEE('=Y9VRQ9&$@;F$@<&]P
M<F%W;F4@87)C:&EW=6T@6DE0+@!4;R!P;VQE(&IE<W0@=WEM86=A;F4N`%1O
M('!O;&4@;75S:2!B>>8@<&]P<F%W;K$@;&EC>F*Q+@!7:6%D;VUOMN8@>F]S
M=&&S82!N87!I<V%N82!W(&EN;F5J(&YIOR!T=V]J82!S=')O;FEE(&MO9&]W
M96H@*"5S*2X`5&5N('-E<G=E<B!N:64@<&]T<F%F:2!R;WIP86MO=WEW8>8@
M87)C:&EW\W<@>FEP(&D@9WII<"X`0WIA<P!&;W)M870@8WIA<W4`5'ET=;,`
M1&\`06)Y('=Y8G)AYB!W:65L;VMR;W1N92!P;VQA('!R>GET<GIY;6%J('!R
M>GEC:7-K($-T<FP@*%!#*2!L=6(@0V]M;6%N9"`H36%C*2!P;V1C>F%S(&ML
M:6MA;FEA+@!$>FFV`%1O9V\`5&]K96QA=0!*=71R;P!4;VYG80!4<GEN:61A
M9"!I(%1O8F%G;P!0<F%W9&$@;'5B(&9ALW-Z`%1U;F5Z:F$`5'5R8VIA`%1U
M<F5C:VD@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=79A;'4`55),`%52
M3#H`56=A;F1A`%5K<F%I;F$`0K.Q9"!P;V1C>F%S('IM:6%N>2!D;R`E<RX`
M0K.Q9"!P;V1C>F%S(+.Q8WIE;FEA('-IZB!Z('-E<G=E<F5M(%-13"X`0K.Q
M9"!P;V1C>F%S(')O>G!A:V]W>7=A;FEA(&1A;GEC:"X`3FEE(&UOOVYA('!R
M>F5TLW5M86-Z>>8@=&5G;R!D;VMU;65N='4@5V]R9"UA`$-O9FYI:B!Z;6EA
M;GD`6FIE9&YO8WIO;F4@16UI<F%T>2!!<F%B<VMI90!7:65L:V$@0G)Y=&%N
M:6$`55-!`$YI97IN86YE`$)E>B!N87IW>0!.:65O8G.S=6=I=V%N92!R;WIS
M>F5R>F5N:64`56%K='5A;&YI:@!:8;-A9'5J`%5R=6=W86H`3W!C:F4@=;]Y
M=&MO=VYI:V$`4F5J97-T<F%C:F$@=;]Y=&MO=VYI:V$`3F%Z=V$@=;]Y=&MO
M=VYI:V$`5;]Y=&MO=VYI:R!O(&YA>G=I92`B)7,B(&IUOR!I<W1N:65J92X`
M3F%Z=V$@=;]Y=&MO=VYI:V$Z`$YA>G=A('6_>71K;W=N:6MA.B``5;]Y=&MO
M=VYI8WD@=R!S>7-T96UI93H`57IB96MI<W1A;@!786MA8VIE`%9A;G5A='4`
M5V5N97IU96QA`%=E<G-J80!7:65T;F%M`%=I9&]K("5S`%!O:V&_('-T<F]N
MZB!75U<`4&]K8;\@:F%K;R`E<P!"<GET>6IS:VEE(%=Y<W!Y($1Z:65W:6-Z
M90!7>7-P>2!$>FEE=VEC>F4@4W1A;O-W(%IJ961N;V-Z;VYY8V@`5V%L;&ES
M(&D@1G5T=6YA`$]S=')Z9;]E;FEE`%=75P!#;R!T>61Z:67Q`%=I=&%M>0!7
M:71A;7D@=R`E<P!7:71A;7DL("5S`%IA8VAO9&YI("A)4T\M.#@U.2TQ*0!:
M86-H;V1N:2`H25-/+3@X-3DM,34I`%-A:&%R82!:86-H;V1N:6$`2F%KL2!A
M<&QI:V%C:NH@;6$@)7,@=WFV=VEE=&QAYB!P;R!Z86QO9V]W86YI=2!S:>H_
M`$IA:VEE('=T>6-Z:VD@86MT>7=O=V'F('<@4F]Z8G5D;W=A;GEM(&5D>71O
M<GIE('1E:W-T=2X`4WIE<F]K;[;F(&QE=V5G;R!M96YU("5S("AZ;6EA;F$@
M>F%C>FYI92!O8F]W:;%Z>7=AYB!P<GIY(&YA<W3J<&YY;2!L;V=O=V%N:74I
M.@!!9')E<R!D;R!P<F%C>0!496PN(&1O('!R86-Y`%)2`%)24E(`0V\@<F]K
M`$IE;65N`%1A:P!486LL('IG861Z86T@<VGJ`%=Y;&]G;W=ALV6V('-IZBX`
M375S:7-Z(&]P:7-AYB!P<F]B;&5M('IA;FEM(&=O('=YMFQE<WHN`$UU<VES
M>B!O:W)EMFQIYB!UOWET:V]W;FEK82P@:W3S<F5G;R!C:&-E<WH@=7-U;K'F
M+@!-=7-I<WH@;VMR9;9L:>8@=;]Y=&MO=VYI:V$L(&MT\W)E9V\@8VAC97-Z
M(&1O9&'F+@!4=_-J(&%D<F5S(&4M;6%I;`!4=_-J(&%D<F5S($]D.@!4=V]J
M92!I;F9O<FUA8VIE`%1W\VH@861R97,@:6YT97)N971O=WD@<VGJ('IM:65N
M:;,@;V0@<&]C>K%T:W4@<V5S:FD@)7,N(%<@>G=IL7IK=2!Z(&)E>G!I96-Z
M9?%S='=E;2!4=V]J96=O(&MO;G1A(&UU<VES>B!Z86QO9V]W8>8@<VGJ('!O
M;F]W;FEE+@!4=V]J92!I;6GJ`%1E;B!S>7-T96T@875T96YT>6MA8VII(&YI
M92!O8G.S=6=U:F4@9&]D87=A;FEA('6_>71K;W=N:6OS=RP@;'5B('1A(&]P
M8VIA('IO<W1ALV$@=WFSL6-Z;VYA+@!496X@<WES=&5M(&%U=&5N='EK86-J
M:2!N:64@;V)SLW5G=6IE(&QI<W1O=V%N:6$@=;]Y=&MO=VYI:_-W+"!L=6(@
M=&$@;W!C:F$@>F]S=&&S82!W>;.Q8WIO;F$N`%1W;VIA(&]B96-N82!S=')E
M9F$@8WIA<V]W83H`1&]M>;9L;F$@=&^_<V%M;[;F.@!4=V]J92!P9;-N92!I
M;6GJ(&D@;F%Z=VES:V\Z`%1W;VEM(&YO=WEM(&AA<[-E;2!W("5S(&IE<W0Z
M("5S`%1W;VIE('5S=&%W:65N:6$@>F]S=&&S>2!U86MT=6%L;FEO;F4@;F$@
M8WIA<R!T<G=A;FEA('1E:B!S97-J:2X`5'=O:F4@=7-T87=I96YI82!Z;W-T
M8;-Y('5A:W1U86QN:6]N92X`5'=O:F4@>F1A;&YE('-E<G=E<GDZ`$IU9V]S
MLV%W:6$`6F%I<@!:86UB:6$`6FEM8F%B=V4`6U)A<&]R="!O('!R;V)L96UI
M95T`7T%D;6EN:7-T<F%C:F$`7T-,20!?57-U\2!W:65R<WH`7T=R=7!Y`%]0
M;VUO8P!?6F%L;V=U:@!?5WEL;V=U:@!:;6EE\2!L:6YK+BXN`%]/<&-J90!?
M57!R87=N:65N:6$`57-U\2!L:6YK+BXN`%]+;VYF:6=U<F%C:F$`7U6_>71K
M;W=N:6-Y`&MS:;&_:V$@861R97-O=V$`:V%L96YD87)Z`'!L:6L`3F%Z=VES
M:V\`;F]T871N:6L`8F5Z(&YA>G=Y`'9#87)D````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O;FY?3D\O3$-?34534T%'15,`````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@
M,#(Q-3`U`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N;E].3R]H96QP
M+GAM;```````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,S,R,"`Q,#4Q-30S-#$T,2`P,C$T-#<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA
M+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O;FY?3D\O:&5L<"YX;6PL=B`Q+C(@
M,C`P-"\P-2\R-R`R,#HR,CHQ,R!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE
M;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R
M=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P
M<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT
M"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO
M=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R
M($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S
M:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C
M=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*
M("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C
M;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA
M:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@
M=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F
M('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA
M>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H
M:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@
M('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B
M/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L
M93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B
M('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L
M:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U
M:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B
M;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K
M('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT
M96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI
M:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H
M97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D
M+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@
M<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C
M:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H\+VAE;'`^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FY?3D\O3$-?34534T%'
M15,O:&]R9&4N;6\`````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C,R,#$@
M,3`U,34T,S0Q-#$@,#(S,C(P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````F0```!P```#D!```TP```*P)````
M````^`P```L```#Y#```*`````4-```5````+@T```@```!$#0``!0```$T-
M```#````4PT```\```!7#0``"````&<-```(````<`T``!D```!Y#0``!P``
M`),-```,````FPT```X```"H#0``!0```+<-```?````O0T``#D```#=#0``
M)P```!<.```L````/PX``"H```!L#@``$0```)<.```(````J0X```@```"R
M#@``!@```+L.```5````P@X```H```#8#@``$0```.,.```,````]0X```<`
M```"#P``$`````H/```K````&P\``!X```!'#P``&P```&8/```;````@@\`
M`#,```">#P``+P```-(/```I`````A````(````L$```!0```"\0```0````
M-1````8```!&$```%````$T0```O````8A````\```"2$```)@```*(0```$
M````R1````4```#.$```#0```-00```%````XA```!````#H$```$````/D0
M```/````"A$```L````:$0``#P```"81```,````-A$```\```!#$0``'@``
M`%,1```A````<A$```,```"4$0``#````)@1```4````I1$```8```"Z$0``
M!````,$1```,````QA$```H```#3$0``!0```-X1```2````Y!$``!````#W
M$0``"`````@2```0````$1(``!H````B$@``!@```#T2```'````1!(```(`
M``!,$@``)0```$\2```$````=1(```\```!Z$@``!P```(H2```'````DA(`
M``D```":$@``!P```*02```2````K!(```0```"_$@``!P```,02```%````
MS!(``#,```#2$@``&@````83```%````(1,```<````G$P``$0```"\3```(
M````01,``!4```!*$P``'@```&`3```H````?Q,```L```"H$P``&@```+03
M```%````SQ,``"@```#5$P``*0```/X3```3````*!0``#(````\%```!```
M`&\4```&````=!0```L```![%```!0```(<4```1````C10```0```"?%```
M#````*04```:````L10``!<```#,%```%P```.04```;````_!0``!D````8
M%0``'P```#(5```3````4A4```0```!F%0``$````&L5```7````?!4```<`
M``"4%0``!0```)P5```Q````HA4``#@```#4%0``(0````T6```<````+Q8`
M``4```!,%@```P```%(6```@````5A8``"8```!W%@``#````)X6```&````
MJQ8``!,```"R%@``#````,86```(````TQ8``!0```#<%@``!P```/$6```&
M````^18```T`````%P``"P````X7```,````&A<```H````G%P```@```#(7
M```&````-1<```P````\%P``10```$D7```F````CQ<``"4```"V%P``,```
M`-P7```0````#1@``',````>&```'P```)(8```0````LA@```\```##&```
M!0```-,8``!B`0``V1@```H````\&@``*````$<:```4````<!H```@```"%
M&@``!0```(X:```(````E!H``!,```"=&@``#````+$:```/````OAH``!X`
M``#.&@``!P```.T:```*````]1H```X`````&P``!0````\;```C````%1L`
M`#L````Y&P``+0```'4;```O````HQL``"X```#3&P``$P````(<```'````
M%AP```@````>'```!@```"<<```5````+AP```P```!$'```%@```%$<```.
M````:!P```4```!W'```$````'T<```K````CAP``!T```"Z'```(````-@<
M```<````^1P``#`````6'0``-@```$<=```L````?AT```(```"K'0``!@``
M`*X=```1````M1T```8```#''0``$0```,X=```F````X!T``!$````''@``
M(P```!D>```%````/1X```8```!#'@``#@```$H>```$````61X``!````!>
M'@``$````&\>```/````@!X```\```"0'@``#P```*`>```,````L!X``!``
M``"]'@``'P```,X>```C````[AX```0````2'P``#0```!<?```4````)1\`
M``<````Z'P``!0```$(?```/````2!\```\```!8'P``!0```&@?```3````
M;A\``!````""'P``!0```),?```2````F1\``"````"L'P``"````,T?```'
M````UA\```(```#>'P``)0```.$?```&````!R```!`````.(```"0```!\@
M```'````*2````D````Q(```"````#L@```5````1"````0```!:(```"```
M`%\@```%````:"```#@```!N(```(````*<@```'````R"````H```#0(```
M$0```-L@```'````[2```!4```#U(```'`````LA```L````*"$```<```!5
M(0``%@```%TA```'````="$``"4```!\(0``)````*(A```6````QR$``"\`
M``#>(0```P````XB```%````$B(```D````8(@``"0```"(B```6````+"(`
M``4```!#(@``$````$DB```9````6B(```\```!T(@``#P```(0B```8````
ME"(``!````"M(@``$````+XB```3````SR(```,```#C(@``%0```.<B```:
M````_2(```<````8(P``"````"`C```I````*2,``#4```!3(P``'@```(DC
M```>````J",```8```#'(P```P```,XC```>````TB,``"@```#Q(P``#P``
M`!HD```(````*B0``!0````S)```$````$@D```*````620``!0```!D)```
M"````'DD```)````@B0```\```",)```#````)PD```/````J20```\```"Y
M)````@```,DD```%````S"0```X```#2)```.@```.$D```J````'"4``"T`
M``!')0``,@```'4E```/````J"4``'D```"X)0``)@```#(F```0````628`
M`!````!J)@``!0```'LF```!````;@````````"+````!@``````````````
M`````&,````3````#0``````````````A@```(`````9````3P```!(````:
M````=0````D```!V````!````"@````%`````````&T```!(````.````$(`
M````````80````P``````````````($```"-````0P```&8````L````"```
M```````W````/@```((```!H`````````&H````\````9`````````!$````
M<0```#````!0````>0```%H```"0````5P```!4`````````$0```)D`````
M````'`````,`````````AP```#T```!]``````````````!X````:0```"L`
M``")`````````"D`````````<``````````+````A0``````````````````
M`(,```"*````````````````````>@``````````````)`````````!'````
M6````!````!*````*@```"8````4``````````````!E````70```)<`````
M`````````',```"4````C@```(\``````````````#4```![````,@```'<`
M`````````````"4```!-````50```"T```"$````(@```$8`````````-```
M`%$`````````'P```%(````/``````````(````>``````````````"5````
MDP```$4```!T````C````'\`````````,P```'X`````````&````%8`````
M`````````!T``````````````#8`````````)P``````````````B````&\`
M```Q````7P````H`````````5````%X````@`````````'(```!G````D@``
M`$D````6````3@````X````[````0````$L```!B````&P```&P```"6````
M4P```#H```!\`````````&L```!,````D0````<````A`````````%D````Y
M````F````#\````C````8`````````!<````%P```$$`````````6P```"X`
M```O`````"5S("T@3F]T:6-E`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@
M+2!#;VYF:7)M871I;VX`)7,@5&5R;7,@;V8@06=R965M96YT`#(T(&AO=7)S
M`$%-+U!-`$%D9`!!9&0@82!N97<@=7-E<CH`061D('!A:7(`061D('5S97(`
M061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O
M:P!!9&UI;FES=')A=&EO;@!!;&EA<P!!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M
M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E;7!T('1O(&1E;&5T92!A(&YO
M;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('!E<FUI<W-I;VXN`$%V86EL86)L92!F:65L9',Z`$)I<G1H9&%Y`$-A
M;&5N9&%R`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V5L;"!0:&]N
M90!#;&EC:R!T;R!#;VYT:6YU90!#;&]S92!7:6YD;W<`0V]M<&%N>0!#;VYF
M:7)M(%!A<W-W;W)D`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O
M=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T82X`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@
M92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F
M<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L
M971E`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L87D@3W!T:6]N<P!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!%9&ET`$5M
M86EL`$5M<'1Y(')E<W5L="X`17)R;W(`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!&86EL
M960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@
M=&\@3$1!4"!S97)V97(N`$9A>`!&:6QE($UA;F%G97(`1W)O=7`@061M:6YI
M<W1R871I;VX`1W)O=7!S`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N
M9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,;V<@:6X`3&]G(&]U=`!-30!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$UA:6P`36%T8VAI;F<@9FEE;&1S`$UE;6)E<G,`
M365S<V%G90!-:6UE(%1Y<&4`36]N=&AL>0!.3RP@22!$;R!.3U0@06=R964`
M3F%M90!.971W;W)K`$YE=F5R`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!V86QI9"!834P@9&%T82!R
M971U<FYE9`!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W
M;W)D`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/P!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO
M;@!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L
M96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D
M`%!R;V)L96T@1&5S8W)I<'1I;VX`4'5B;&EC+U!R:79A=&4@:V5Y<&%I<B!N
M;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`4F5A9`!296UO=F4`4F5M;W9E
M('!A:7(`4F5S970`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO
M;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L
M96-T('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P
M;W)T`%-H;W<`4VMI<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6-C97-S`%1A<VMS`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE(&5N8W)Y<'1I;VX@9F5A='5R
M97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A
M(&YU;6)E<BX`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S
M97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT
M`%5N9&\@0VAA;F=E<P!5<&1A=&4`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R
M($]P=&EO;G,`57-E<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN
M9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E
M<W,`5V]R:R!0:&]N90!960!996%R;'D`665S+"!)($%G<F5E`%EO=2!M=7-T
M(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE
M('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@
M=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A
M9&0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN
M(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!;4')O8FQE
M;2!297!O<G1=`%ML:6YE("5S(&]F("5S70!V0V%R9`!0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,"UC=G,*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`R+3`V+3`X(#(R
M.C,P*S`Q,#`*3&%S="U4<F%N<VQA=&]R.B!097(M4W1I86X@5F%T;F4@/'!S
M=D!O<G-T82YO<F<^"DQA;F=U86=E+51E86TZ($YO<G=E9VEA;B!.>6YO<G-K
M(#QN>6YO<G-K0&]R<W1A+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`)7,@+2!.;W1I<P`E<R!V961L
M:6ME:&%L9'-O<&5R87-J;VYA<B`M(%-T861F97-T:6YG`"5S(%9I;&OE<B!F
M;W(@879T86QE`#(T('1I;6%R`$%-+U!-`$QE9V<@=&EL`$QE9V<@=&EL(&YY
M(&)R=6MA<CH`3&5G9R!T:6P@<&%R`$QE9V<@=&EL(&)R=6MA<@!,96=G('1I
M;"!B<G5K87)A<B!E<B!S;.5T="!A=BX`061R97-S90!!9')E<W-E8F]K`$%D
M;6EN:7-T<F5R:6YG`$%L:6%S`$5I;B!U;&]V;&5G('9E<F1I('9A<G0@<W!E
M<VEF:7-E<G0N`%-P^'(@;VT@<W1A9&9E<W1I;F<@9OAR(&OX>7)I;F<@878@
M=F5D;&EK96AA;&1S;W!E<F%S:F]N87(_`%!R^'9D92#E('-L971T92!E:2!I
M:VMJ92UE:W-I<W1E<F%N9&4@9W)U<'!E+@!0<OAV9&4@Y2!S;&5T=&4@96EN
M(&EK:VIE+65K<VES=&5R86YD92!T:6QG86YG+@!0<OAV9&4@Y2!E;F1R92!E
M:6X@:6MK:F4M96MS:7-T97)A;F1E('1I;&=A;F<N`%1I;&=J96YG96QE9V4@
M9F5L=#H`0G5R<V1A9P!+86QE;F1E<@!!=F)R>70`079B<GET('!R;V)L96UR
M87!P;W)T`$UO8FEL=&5L969O;@!+;&EK:R!F;W(@Y2!H86QD92!F<F%M`$QU
M:VL@=FEN9&%U9V5T`$9I<FUA`%-T861F97-T('!A<W-O<F0`3W!P:V]P;&EN
M9R!M;W0@;V9F96YT;&5G(&[X:VME;'1E;F%R(&YE:W1A+@!+=6YN92!I:VMJ
M92!01U`M:V]D92!M96QD:6YG+@!+=6YN92!I:VMJ92!01U`M<VEG;F5R92!M
M96QD:6YG+@!+=6YN92!I:VMJ92!D96MO9&4@4$=0+61A=&$N`$MU;FYE(&EK
M:VIE(&%V9VIE<F4@;6]T=&%K87)E;B!S:2!E+7!O<W1A9')E<W-E+@!+=6YN
M92!I:VMJ92!S:V%F9F4@;V9F96YT;&5G(&[X:VME;"!F<N4@;OAK:V5L=&5N
M87)E;BX`2W5N;F4@:6MK:F4@;W!N92!-86EN=&5N86YC95]487-K+6UO9'5L
M96X@)7,`1$0`1&%G;&5G`%-T86YD87)D:61E;G1I=&5T`%-L971T90!3:VEL
M9')E('!R;V)L96UE=`!$971A;&IA<B!E<B!L;V=G82!F;W(@861M:6YI<W1R
M871O<F5N+@!6:7-I;F=S86QT97)N871I=@!):VMJ92!B<G5K(&UA:6YT96YA
M;F-E+G!H<"!D:7)E:W1E+@!%;F1R90!%+7!O<W0`5&]M="!R97-U;'1A="X`
M1F5I;`!+=F%R="`Q-2X@;6EN=71T`$MV87)T(#,P+B!S96MU;F0`2W9A<G0@
M-2X@;6EN=71T`$MV87(@:6YN;&]G9VEN9P!+=F%R(&AA;'9E('1I;64`2W9A
M<G0@;6EN=71T`$5K<V5M<&5L=F5R9&EA<CH`2W5N;F4@:6MK:F4@:&5N=&4@
M:6YN<W1I;&QI;F=A<@!+=6YN92!I:VMJ92!K;W!L92!T:6P@3$1!4"UT96YA
M<F5N+@!&86MS`$9I;&AA;F1S86UI;F<`1W)U<'!E861M:6YI<W1R97)I;F<`
M1W)U<'!E<@!(:F5L<`!!9')E<W-E+"!P<FEV870`5&5L969O;BP@<')I=F%T
M`$AO<F1E`$EM<&]R=&5R=&4@9F5L=#H@)7,`26UP;W)T97)T92!F96QT.@!3
M<'+E:P!6:7,@96UN92!F<N4@2&IE;'``3&ES=&EN9R!A=B!B<G5K87)A<B!E
M<B!S;.5T="!A=BX`3&]G9R!I;FX`3&]G9R!U=`!-30!-4RU43D5&+79E9&QE
M9V<@:6YN96AE;&1T(&EN9V5N(&1A=&$N`$4M<&]S=`!386US=F%R86YD92!F
M96QT`$UE9&QE;6UA<@!-96QD:6YG`$U)344M='EP90!-Y6YA9&QE9P!.14DL
M(&5G(&5R($E+2TI%('-A;60`3F%M;@!.971T=F5R:P!!;&1R:0!);F=E;B!K
M;VYF:6=U<F%S:F]N<VEN9F]R;6%S:F]N('-P97-I9FES97)T(&9O<B!344P@
M5D93+@!);F=E;B!G>6QD:6=E(%A-3"UD871A(')E='5R;F5R=`!.;W1A=&%R
M`$%L=&5R;F%T:78`06YN86X@:6YF;W)M87-J;VX`4&%S<V]R9`!087-S;W)D
M82!MY2!S86US=F%R92X`2_AY<B!V961L:6ME:&%L9'-O<&5R87-J;VYA<@!+
M^'ER('9E9&QI:V5H86QD<V]P97)A<VIO;F%R('9E9"!I;FYL;V=G:6YG/P!4
M:6QG86YG`%1I;&=A;F=S861M:6YI<W1R97)I;F<`5&5L969O;@!3:W)I=B!I
M;FX@96ET('-A;6%N9')A9R!A=B!P<F]B;&5M970N`%-K<FEV(&EN;B!D:71T
M(&)R=6MA<FYA;6X@;V<@<&%S<V]R9`!3:VEL9')I;F<@878@<')O8FQE;65T
M`$]F9F5N=&QE9R]P<FEV870@;OAK:V5L<&%R('9A<G0@:6MK:F4@9V5N97)E
M<G0N`$QE<P!&:F5R;@!&:F5R;B!P87(`3G5L;'-T:6QL`%1I;&)A:V4@=&EL
M(&%L=&5R;F%T:78`4F]L;&4`3&%G<F4@86QT97)N871I=@!696P@<VMI;&IE
M=&5I:VX@9F]R(&1A=&\Z`%9E;"!D871O9F]R;6%T.@!696P@=&ED<V9O<FUA
M=#H`5F5L('1O('-A;7-V87)A;F1E(&9E;'0N`%9E;"!F87)G97-K:F5M82X`
M5F5L(/AN<VMA('-P<N5K.@!396YD('!R;V)L96UR87!P;W)T`%9I<P!(;W!P
M(&]V97(@=F5D;&EK96AA;&0`26YN=&%S=&EN9R!A=B!S<&5S:6%L=&5I:VX`
M4W5K<V5S<P!/<'!GY79E<@!+;&%S<V$@36%I;G1E;F%N8V4Z.B!V87)T(&EK
M:VIE(&QA<W1A(&EN;@!+<GEP=&5R:6YG<V9U;FMS:F]N86YE(&MR978@96D@
M<VEK:V5R(&YE='1O<'!K;W!L:6YG+@!$971T92!T86QE="!MY2!V97)E(&UI
M;G-T(&5I;BX`1&5N;F4@=F5R9&EE;B!MY2!V97)E(&5I="!T86PN`%1I='1E
M;`!54DP`2V%N(&EK:VIE(&MO<&QE('1I;"!344PM=&5N87(N`$MA;B!I:VMJ
M92!O;7-E=&IE(&1E='1E(%=O<F0M9&]K=6UE;G1E="X`06YG<F4@96YD<FEN
M9V%R`$]P<&1A=&5R`$)R=6MA<F%D;6EN:7-T<F5R:6YG`$)R=6MA<F%L=&5R
M;F%T:78`0G)U:V%R;F%M;@!"<G5K87)A<B!I('-Y<W1E;65T.@#%='9A<FEN
M9P!+=F%R('9E:V4`5F5L:V]M96X@=&EL("5S`%9E;&MO;65N+"`E<P!!9')E
M<W-E+"!A<F)E:60`5&5L969O;BP@87)B96ED`,7%`,5R;&5G`$IA+"!E9R!E
M<B!S86UD`$1U(&WE('-K:6QD<F4@<')O8FQE;65T(&;X<B!D=2!K86X@<V5N
M9&4@<')O8FQE;7)A<'!O<G1E;BX`1'4@;>4@<W!E<VEF:7-E<F4@96ET(&)R
M=6MA<FYA;6X@Y2!F:F5R;F4N`$1U(&WE('-P97-I9FES97)E(&5I="!B<G5K
M87)N86UN(.4@;&5G9V4@=&EL+@#8:W1A(&1I("@E<RD@:&%R(&?E='0@=70@
M<.4@=&ED+B!,;V=G(&EN;B!PY2!N>71T+@!$:6X@:6YF;W)M87-J;VX`3&ES
M=&EN9R!A=B!B<G5K87)A<B!E<B!I:VMJ92!S=/AT=&$@878@8F%K<F4@875T
M96YT:7-E<FEN9RP@96QL97(@9G5N:W-J;VYE;B!H87(@878@96EN(&5L;&5R
M(&%N;F%N(&=R=6YN(&)L:71T('-LY71T(&%V+@!!;'1E<FYA=&EV82!D:6YE
M(&AA<B!B;&ET="!O<'!D871E<G1E+@!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ
M92`E<R!A=B`E<UT`=D-A<F0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FQ?3DPO3$-?34534T%'15,`
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q-#$@,#(Q-3`P`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N
M;%].3"]H96QP+GAM;```````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S,R,"`Q,#4Q-30S-#$T,2`P,C$T-#(`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]X;6P@=F5R<VEO;CTB
M,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O;FQ?3DPO:&5L<"YX
M;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-"!J86X@17AP("0@+2T^"CQH
M96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T
M86P@<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@
M:6UP;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H
M="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V
M92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE
M;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F
M<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@
M;V8@=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T
M8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG
M(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@
M979E;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O
M;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V
M:6$@=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@
M8VAO;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@
M<&%G92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO
M=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T
M871E/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@
M0F%R/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O
M9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@
M8F%R+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@
M8F%R('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H
M92!A=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@
M(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B
M/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I
M;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@
M;&EK92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G
M:6XL(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE
M=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF
M:7)M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U
M('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@
M8F5F;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@
M=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE
M960@=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@
M=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;FQ?3DPO
M3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`T,34P,#<@,3`U,34T,S0Q-#$@,#(S,C(T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-X2!)4`````B0<``!P```!D/```
M$PH``*QX````````^*````X```#YH```#P````BA```-````&*$```@````F
MH0``"P```"^A```,````.Z$```0```!(H0``&````$VA```;````9J$``"T`
M``""H0``'0```+"A```D````SJ$``"D```#SH0``&0```!VB```F````-Z(`
M``P```!>H@``)````&NB```/````D*(```L```"@H@``#@```*RB```%````
MNZ(``"@```#!H@``"````.JB```*````\Z(``!4```#^H@``$@```!2C```+
M````)Z,``(4````SHP``#@```+FC```*````R*,```T```#3HP``#@```.&C
M```1````\*,```T````"I```#````!"D```-````':0```8````KI```E```
M`#*D```*````QZ0```\```#2I```&````.*D```,````^Z0```X````(I0``
M#@```!>E```(````)J4```D````OI0``+@```#FE```:````:*4``#(```"#
MI0``.````+:E``!4````[Z4``%$```!$I@``6@```):F``!7````\:8``#0`
M``!)IP``"0```'ZG```-````B*<```<```"6IP``"@```)ZG```/````J:<`
M``4```"YIP``!@```+^G```1````QJ<```@```#8IP``"0```.&G```)````
MZZ<``"4```#UIP``(````!NH```3````/*@``!````!0J```#P```&&H```*
M````<:@```,```!\J```#P```("H```4````D*@```D```"EJ```#0```*^H
M```2````O:@``!D```#0J```'@```.JH```/````":D```H````9J0``#P``
M`"2I```(````-*D``"0````]J0``%````&*I```6````=ZD```@```".J0``
M3@```)>I```M````YJD``!D````4J@``!P```"ZJ```,````-JH``"P```!#
MJ@``#@```'"J```#````?ZH```L```"#J@``!P```(^J```'````EZH```4`
M``"?J@``!0```*6J```*````JZH```,```"VJ@``%P```+JJ```*````TJH`
M``\```#=J@``#@```.VJ```8````_*H``",````5JP``#@```#FK```4````
M2*L``!<```!=JP``%P```'6K```7````C:L``!,```"EJP``#P```+FK```.
M````R:L``!\```#8JP``'0```/BK```'````%JP```8````>K```"````"6L
M```/````+JP```8````^K```"@```$6L```3````4*P```L```!DK```$```
M`'"L```5````@:P``!4```"7K```!P```*VL```0````M:P```4```#&K```
M%0```,RL```1````XJP```P```#TK```.P````&M```X````/:T```D```!V
MK0``!P```("M```4````B*T```,```"=K0``!0```*&M```0````IZT```D`
M``"XK0``$P```,*M```Y````UJT``!(````0K@``)P```".N```L````2ZX`
M`"H```!XK@``)0```*.N```*````R:X```8```#4K@``"0```-NN```'````
MY:X``"\```#MK@``-P```!VO```N````5:\``%4```"$KP``+0```-JO```M
M````"+```#T````VL```/P```'2P```M````M+```$````#BL```(P```".Q
M```C````1[$``$````!KL0``+0```*RQ```S````VK$``"4````.L@``%0``
M`#2R```9````2K(``"D```!DL@``)````(ZR```H````L[(``!$```#<L@``
M"@```.ZR```,````^;(```H````&LP``$````!&S```6````(K,``!8````Y
MLP``!P```%"S```'````6+,``!0```!@LP``"@```'6S```(````@+,``"<`
M``")LP``"````+&S```'````NK,```<```#"LP``!@```,JS```%````T;,`
M``<```#7LP``!@```-^S```(````YK,``"D```#OLP``#@```!FT```*````
M*+0```0````SM```!P```#BT```)````0+0```8```!*M```$0```%&T```'
M````8[0``!8```!KM```!````(*T```(````A[0```8```"0M```#0```)>T
M```&````I;0``!X```"LM```$0```,NT```(````W;0```T```#FM```#```
M`/2T```'`````;4```,````)M0```P````VU```7````$;4``!,````IM0``
M'0```#VU```(````6[4```0```!DM0``"````&FU```(````<K4``$$```![
MM0``&@```+VU```K````V+4``"`````$M@``%0```"6V```&````.[8```8`
M``!"M@``%0```$FV```8````7[8``"(```!XM@``+@```)NV```=````RK8`
M`"$```#HM@``5`````JW```I````7[<```H```")MP``!P```)2W```'````
MG+<``!4```"DMP``#@```+JW```*````R;<```\```#4MP``#0```.2W```/
M````\K<```T````"N```"0```!"X```4````&K@```8````ON```&````#:X
M```=````3[@``!,```!MN```$0```(&X```4````D[@```0```"HN```!@``
M`*VX```4````M+@``%0```#)N```9````!ZY```$````@[D```X```"(N0``
M!0```)>Y```%````G;D``!L```"CN0``&@```+^Y```3````VKD``!$```#N
MN0``$0````"Z```<````$KH``"H````ON@``$````%JZ```A````:[H```4`
M``"-N@``$P```).Z```+````I[H``!(```"SN@``"@```,:Z```/````T;H`
M``T```#AN@``$0```.^Z```3`````;L```P````5NP``!@```"*[```,````
M*;L```8````VNP``%P```#V[```0````5;L``!$```!FNP``"````'B[```%
M````@;L```P```"'NP``$````)2[```%````I;L```T```"KNP``!@```+F[
M```'````P+L```T```#(NP``!P```-:[```+````WKL```<```#JNP``!P``
M`/*[```)````^KL```D````$O```"@````Z\```9````&;P``#T````SO```
M'0```'&\```,````C[P``!````"<O```!0```*V\```E````L[P``!(```#9
MO```$P```.R\```K`````+T``#L````LO0``(````&B]```(````B;T``#8`
M``"2O0``(0```,F]```0````Z[T```@```#\O0``#`````6^```&````$KX`
M``0````9O@``#P```!Z^```.````+KX```<````]O@``"@```$6^```-````
M4+X``!\```!>O@``'````'Z^```A````F[X``!X```"]O@``&0```-R^```>
M````]KX``!L````5OP``(0```#&_```N````4[\``"8```""OP``'````*F_
M```>````QK\``!P```#EOP``)@````+````K````*<```#,```!5P```)@``
M`(G````K````L,```#@```#<P```'0```!7!```5````,\$``"\```!)P0``
M(````'G!```2````FL$``"D```"MP0``'@```-?!```@````]L$``!(````7
MP@``H@```"K"```6````S<(``",```#DP@``*`````C#```I````,<,``"@`
M``!;PP``'P```(3#```5````I,,``"````"ZPP``)0```-O#```H`````<0`
M`"T````JQ```,````%C$``"2````B<0``"$````<Q0``%@```#[%```<````
M5<4``"8```!RQ0``*@```)G%``!!````Q,4``$0````&Q@``#````$O&```'
M````6,8```<```!@Q@``!@```&C&```-````;\8``!````!]Q@``$@```([&
M```3````H<8``!(```"UQ@``!P```,C&```$````T,8``!````#5Q@``$```
M`.;&```,````]\8```X````$QP``#0```!/'```/````(<<``!,````QQP``
M#0```$7'```H````4\<```,```!\QP``#0```(#'```&````CL<``!$```"5
MQP``%P```*?'```;````O\<```X```#;QP```@```.K'``!)````[<<```4`
M```WR```$````#W(```/````3L@```0```!>R```#0```&/(```.````<<@`
M``,```"`R```#@```(3(```(````D\@```\```"<R```#P```*S(```'````
MO,@```T```#$R```$````-+(```-````X\@```L```#QR```!@```/W(```+
M````!,D```P````0R0``"@```!W)```1````*,D``!D````ZR0``"P```%3)
M```-````8,D``"(```!NR0``#P```)')```;````H<D``#0```"]R0``"@``
M`/+)```8````_<D``!(````6R@``&0```"G*```6````0\H``"(```!:R@``
M#0```'W*```'````B\H``!0```"3R@``"P```*C*```B````M,H``"\```#7
MR@``"P````?+```)````$\L``!D````=RP``"P```#?+```7````0\L``!<`
M``!;RP``"0```'/+```6````?<L```\```"4RP``&0```*3+```6````OLL`
M``X```#5RP``&````.3+```(````_<L```T````&S```)@```!3,``!#````
M.\P```@```!_S```$@```(C,```?````F\P```@```"[S```"P```,3,```O
M````T,P```X`````S0``!0````_-```&````%<T``$4````<S0```P```&+-
M```'````9LT```0```!NS0``"@```'/-```*````?LT```\```")S0``$```
M`)G-```7````JLT``!$```#"S0``&0```-3-```7````[LT```D````&S@``
M!0```!#.```+````%LX```H````BS@```@```"W.```%````,,X```T````V
MS@``&P```$3.```7````8,X``!0```!XS@``"0```(W.```.````E\X```T`
M``"FS@``$@```+3.```X````Q\X``"``````SP``"````"'/```.````*L\`
M`'L````YSP``&````+7/```8````SL\``!$```#GSP``!P```/G/```%````
M`=```!@````'T```'@```"#0```;````/]```!D```!;T```&P```'70```9
M````D=```!,```"KT```!P```+_0```(````Q]````8```#0T```!@```-?0
M```0````WM````\```#OT```$````/_0```/````$-$```L````@T0``#P``
M`"S1```,````/-$```\```!)T0``!P```%G1```&````8=$```X```!HT0``
M#````'?1```H````A-$```\```"MT0``"````+W1```(````QM$``!,```#/
MT0``'@```./1```A`````M(``"`````DT@``&0```$72```7````7](``"4`
M``!WT@``%P```)W2```6````M=(```0```#,T@``&P```-'2```-````[=(`
M``P```#[T@```P````C3```%````#-,```@````2TP``"@```!O3```,````
M)M,```L````STP``$````#_3```,````4-,```X```!=TP``"P```&S3```$
M````>-,```0```!]TP``$P```(+3```4````EM,```P```"KTP``"0```+C3
M```.````PM,```L```#1TP``&P```-W3```'````^=,```<````!U```"@``
M``G4```-````%-0```D````BU```!````"S4```%````,=0```,````WU```
M&````#O4```*````5-0```0```!?U```)@```&34```.````B]0``'P```":
MU```%0```!?5```%````+=4```<````SU0``#````#O5```(````2-4```H`
M``!1U0``!@```%S5```(````8]4```(```!LU0``!@```&_5```&````=M4`
M`!0```!]U0``#0```)+5```0````H-4``!L```"QU0``!````,W5```)````
MTM4``!````#<U0``"0```.W5```)````]]4```4````!U@``&@````?6```(
M````(M8```8````KU@``&0```#+6```.````3-8```<```!;U@``!P```&/6
M```%````:]8```D```!QU@``"@```'O6```.````AM8```(```"5U@``!@``
M`)C6```+````G]8```T```"KU@``"0```+G6```&````P]8``!(```#*U@``
M"0```-W6```'````Y]8``!0```#OU@``'0````37``!"````(M<``"4```!E
MUP``)0```(O7```&````L=<```H```"XUP``!````,/7```)````R-<```@`
M``#2UP``$0```-O7```)````[=<```8```#WUP``#0```/[7```&````#-@`
M``0````3V```.0```!C8```]````4M@``#H```"0V```'@```,O8```%````
MZM@```X```#PV```!````/_8```&````!-D```<````+V0``(0```!/9```-
M````-=D``!4```!#V0``!@```%G9```$````8-D``!$```!EV0``!@```'?9
M```*````?MD``"(```")V0``!````*S9```%````L=D``!T```"WV0``!```
M`-79```,````VMD```X```#GV0``"@```/;9```(`````=H```D````*V@``
M!0```!3:```Z````&MH``#````!5V@``-0```(;:```I````O-H``$<```#F
MV@``.````"[;```I````9]L``#\```"1VP``+@```-';```M`````-P``!\`
M```NW```#P```$[<```2````7MP```L```!QW```)@```'W<```I````I-P`
M`"0```#.W```)@```//<```(````&MT```H````CW0``"0```"[=```'````
M.-T``"````!`W0``(````&'=```F````@MT```H```"IW0``&0```+3=```I
M````SMT``!8```#XW0``$@````_>```'````(MX```H````JW@``#````#7>
M```/````0MX``!````!2W@``0````&/>``!P````I-X``&8````5WP``#@``
M`'S?```)````B]\```H```"5WP``$@```*#?```3````L]\```P```#'WP``
M!@```-3?```/````V]\``!(```#KWP``$````/[?```1````#^```!P````A
MX```(P```#[@``!J````8N````\```#-X```!0```-W@```0````X^````D`
M``#TX```!````/[@```+`````^$``"`````/X0``%````##A```,````1>$`
M``P```!2X0``#P```%_A```5````;^$``"D```"%X0``*@```*_A```F````
MVN$``"<````!X@``*0```"GB```J````4^(``!D```!^X@``0@```)CB```1
M````V^(``!(```#MX@``$P````#C```4````%.,```\````IXP``%@```#GC
M```7````4.,``!````!HXP``$0```'GC```T````B^,``!,```#`XP``$@``
M`-3C```U````Y^,``!0````=Y```!P```#+D```,````.N0``"````!'Y```
M$````&CD```4````>>0``!$```".Y```%P```*#D```<````N.0``!,```#5
MY```%````.GD```:````_N0``!$````9Y0``&@```"OE```>````1N4``!H`
M``!EY0``$P```(#E```5````E.4``!$```"JY0``%P```+SE```4````U.4`
M`!<```#IY0``%0````'F```)````%^8``!`````AY@``&0```#+F```$````
M3.8```<```!1Y@``"P```%GF```1````9>8```8```!WY@``!@```'[F```&
M````A>8```4```",Y@``!P```)+F```'````FN8```4```"BY@``%@```*CF
M```&````O^8```8```#&Y@``!````,WF```$````TN8```<```#7Y@``#@``
M`-_F```,````[N8```P```#[Y@``#0````CG```*````%N<```X````AYP``
M!0```##G```H````-N<```X```!?YP``#````&[G```/````>^<```H```"+
MYP``"````);G```)````G^<``"L```"IYP``!````-7G```(````VN<``"8`
M``#CYP``$@````KH```/````'>@```8````MZ```"@```#3H```'````/^@`
M``@```!'Z```(````%#H```)````<>@``!0```![Z```#````)#H```-````
MG>@```X```"KZ```%@```+KH```1````T>@```8```#CZ````P```.KH```&
M````[N@``!D```#UZ```!P````_I```$````%^D```L````<Z0``"P```"CI
M```'````-.D```4````\Z0``!P```$+I```6````2ND```T```!AZ0``#0``
M`&_I```*````?>D``!````"(Z0``#P```)GI```1````J>D``!<```"[Z0``
M"@```-/I```1````WND```@```#PZ0``!````/GI```/````_ND``#H````.
MZ@``!0```$GJ```,````3^H``!X```!<Z@``#@```'OJ```0````BNH```L`
M``";Z@``#````*?J```)````M.H```<```"^Z@``"@```,;J```)````T>H`
M``X```#;Z@``$````.KJ```;````^^H``!@````7ZP``&@```##K```*````
M2^L```D```!6ZP``"@```&#K```,````:^L```\```!XZP``"````(CK```&
M````D>L``!P```"8ZP``!P```+7K```%````O>L```L```##ZP``1P```,_K
M```-````%^P```D````E[```!````"_L```#````-.P``!,````X[```$P``
M`$SL```3````8.P```H```!T[````@```'_L```$````@NP``"4```"'[```
M`P```*WL```%````L>P``"H```"W[```"@```.+L```%````[>P```0```#S
M[```"@```/CL```-`````^T```8````1[0``"````!CM```(````(>T```0`
M```J[0``!0```"_M``!H````->T```D```">[0``#````*CM```0````M>T`
M``4```#&[0``!@```,SM```;````T^T``"\```#O[0``$````!_N```*````
M,.X```\````[[@``"@```$ON```)````5NX``!,```!@[@``&P```'3N```8
M````D.X``!<```"I[@``'P```,'N```.````X>X```,```#P[@``!P```/3N
M```(````_.X```<````%[P``"@````WO```+````&.\```<````D[P``40``
M`"SO```0````?N\```P```"/[P``#0```)SO```:````JN\``$H```#%[P``
M&0```!#P```&````*O```!H````Q\```)0```$SP```&````<O````8```!Y
M\```'P```(#P```&````H/````D```"G\```&````+'P```7````RO```"@`
M``#B\```!@````OQ```-````$O$``"(````@\0``5P```$/Q```3````F_$`
M`",```"O\0``$P```-/Q```"````Y_$```L```#J\0``"````/;Q```-````
M__$```H````-\@``!P```!CR```4````(/(```8````U\@``"````#SR```.
M````1?(```<```!4\@``"@```%SR```+````9_(``#(```!S\@``!P```*;R
M```,````KO(```T```"[\@``%P```,GR```,````X?(```D```#N\@``"0``
M`/CR```*`````O,```<````-\P``"0```!7S```'````'_,```H````G\P``
M&P```#+S```/````3O,``!(```!>\P``"@```''S```6````?/,```D```"3
M\P``$````)WS```'````KO,``!(```"V\P``!````,GS```'````SO,```4`
M``#6\P``!0```-SS```+````XO,``!0```#N\P``$0````/T```:````%?0`
M`!8````P]```%````$?T```7````7/0``!@```!T]```'````(WT```9````
MJO0```<```#$]```!0```,ST```-````TO0```P```#@]```"````.WT```7
M````]O0```L````.]0``#````!KU```?````)_4``!H```!']0``$P```&+U
M```$````=O4```H```![]0``!````(;U```-````B_4```P```"9]0``!0``
M`*;U```)````K/4```4```"V]0``!P```+SU```%````Q/4```0```#*]0``
M`@```,_U```X````TO4``"P````+]@``$@```#CV```I````2_8``#(```!U
M]@``"@```*CV```L````L_8``"X```#@]@``,P````_W```S````0_<``#@`
M``!W]P``#P```+#W```8````P/<``!````#9]P``#P```.KW```3````^O<`
M`!4````.^```%````"3X```2````.?@``!0```!,^```%0```&'X```M````
M=_@``"T```"E^```,0```-/X```N````!?D``"\````T^0``+````&3Y``!B
M````D?D``!,```#T^0``#0````CZ```(````%OH``!<````?^@``"````#?Z
M```,````0/H``"L```!-^@``(0```'GZ```:````F_H```D```"V^@``10``
M`,#Z``!!````!OL```0```!(^P``$P```$W[```4````8?L```X```!V^P``
M$P```(7[```8````F?L```8```"R^P``"0```+G[```*````P_L```\```#.
M^P``$````-[[```'````[_L```X```#W^P``!0````;\```;````#/P```@`
M```H_```!@```#'\```4````./P``!$```!-_```#@```%_\```X````;OP`
M``(```"G_```!@```*K\```.````L?P```4```#`_```!P```,;\```.````
MSOP```8```#=_```*````.3\```,````#?T``!P````:_0``!````#?]```I
M````//T``!<```!F_0``'P```'[]``!<````GOT``!0```#[_0``/@```!#^
M```?````3_X``!````!O_@``!P```(#^```.````B/X```P```"7_@``#```
M`*3^```3````L?X```H```#%_@``'0```-#^```9````[OX```4````(_P``
M$0````[_```1````(/\``"0````R_P``$@```%?_```5````:O\``!(```"`
M_P``#@```)/_```9````HO\```@```"\_P``"0```,7_```-````S_\```<`
M``#=_P``"@```.7_```'````\/\```\```#X_P``!@````@``0`+````#P`!
M`!H````;``$`"@```#8``0`'````00`!``@```!)``$`!0```%(``0`?````
M6``!``8```!X``$`$````'\``0`(````D``!``T```"9``$`"````*<``0`>
M````L``!`!(```#/``$`+````.(``0`:````#P$!``D````J`0$`"@```#0!
M`0`5````/P$!``4```!5`0$`%````%L!`0`$````<`$!`!````!U`0$`!@``
M`(8!`0`'````C0$!`!X```"5`0$`*````+0!`0`*````W0$!`!P```#H`0$`
M$0````4"`0`+````%P(!`!H````C`@$`%````#X"`0`$````4P(!``0```!8
M`@$`"P```%T"`0`%````:0(!``8```!O`@$`"````'8"`0`&````?P(!``H`
M``"&`@$`&P```)$"`0`T````K0(!`#0```#B`@$`(````!<#`0`I````.`,!
M`"````!B`P$`00```(,#`0`:````Q0,!`"@```#@`P$`*0````D$`0!0````
M,P0!`"(```"$!`$`!@```*<$`0`(````K@0!``4```"W!`$`"````+T$`0`9
M````Q@0!`!D```#@!`$`*@```/H$`0`C````)04!`!D```!)!0$`+@```&,%
M`0`T````D@4!``@```#'!0$`%P```-`%`0`*````Z`4!``<```#S!0$`(0``
M`/L%`0`0````'08!``X````N!@$`"P```#T&`0`'````208!`!,```!1!@$`
M"````&4&`0`+````;@8!``H```!Z!@$`%````(4&`0`/````F@8!`#(```"J
M!@$`"P```-T&`0`.````Z08!``4```#X!@$`!0```/X&`0`%````!`<!`!<`
M```*!P$`#P```"('`0`$````,@<!``H````W!P$`"0```$('`0`+````3`<!
M``T```!8!P$`#````&8'`0`.````<P<!``4```""!P$`!````(@'`0`-````
MC0<!`#(```";!P$`10```,X'`0`7````%`@!``<````L"`$`'@```#0(`0`4
M````4P@!``4```!H"`$`%````&X(`0`&````@P@!``<```"*"`$`#@```)((
M`0`J````H0@!``8```#,"`$`#````-,(`0`-````X`@!`!$```#N"`$`"P``
M```)`0`V````#`D!``H```!#"0$`(@```$X)`0`+````<0D!``\```!]"0$`
M,@```(T)`0`E````P`D!`#````#F"0$`,0```!<*`0`M````20H!``X```!W
M"@$`!0```(8*`0`.````C`H!`!,```";"@$`$@```*\*`0`'````P@H!`!$`
M``#*"@$`$P```-P*`0`'````\`H!`!0```#X"@$`&`````T+`0`'````)@L!
M``4````N"P$`#````#0+`0`,````00L!`!(```!."P$`!````&$+`0`'````
M9@L!``H```!N"P$`"P```'D+`0`,````A0L!``X```"2"P$`#@```*$+`0`%
M````L`L!``4```"V"P$`+@```+P+`0`F````ZPL!`",````2#`$``P```#8,
M`0`2````.@P!``8```!-#`$`'@```%0,`0`8````<PP!`"4```",#`$`#0``
M`+(,`0`)````P`P!`!\```#*#`$``P```.H,`0`'````[@P!``H```#V#`$`
M`@````$-`0`,````!`T!`!4````1#0$`"P```"<-`0`9````,PT!`"````!-
M#0$`$@```&X-`0`%````@0T!``H```"'#0$`%0```)(-`0`2````J`T!``P`
M``"[#0$`!````,@-`0`)````S0T!``<```#7#0$`#````-\-`0!2````[`T!
M`!<````_#@$`)````%<.`0`2````?`X!``<```"/#@$`!@```)<.`0`.````
MG@X!``P```"M#@$`#0```+H.`0`5````R`X!`!(```#>#@$`#P```/$.`0`4
M`````0\!``H````6#P$`&P```"$/`0`0````/0\!``L```!.#P$`:0```%H/
M`0`:````Q`\!`!<```#?#P$`)P```/</`0`:````'Q`!`!<````Z$`$`&P``
M`%(0`0`9````;A`!`!\```"($`$`$P```*@0`0`(````O!`!``<```#%$`$`
M"````,T0`0`)````UA`!`!4```#@$`$`#0```/80`0`C````!!$!``T````H
M$0$`$P```#81`0`(````2A$!``,```!3$0$`1@```%<1`0`_````GA$!`#<`
M``#>$0$`5P```!82`0`%````;A(!`!\```!T$@$`+P```)02`0`*````Q!(!
M``@```#/$@$`#0```-@2`0`M````YA(!``0````4$P$`3P```!D3`0`E````
M:1,!`!P```"/$P$`"P```*P3`0`?````N!,!`!T```#8$P$`)0```/83`0`@
M````'!0!`"0````]%`$`(````&(4`0`+````@Q0!``<```"/%`$`#0```)<4
M`0`,````I10!`!<```"R%`$`!@```,H4`0`Y````T10!``P````+%0$`!P``
M`!@5`0`)````(!4!`!,````J%0$`"0```#X5`0`$````2!4!`!````!-%0$`
M"````%X5`0`(````9Q4!``0```!P%0$`"P```'45`0`,````@14!`!(```".
M%0$`$0```*$5`0`,````LQ4!`!H```#`%0$`#P```-L5`0`'````ZQ4!``T`
M``#S%0$`%`````$6`0`.````%A8!``P````E%@$`&P```#(6`0`L````3A8!
M`!,```![%@$`'````(\6`0`H````K!8!``8```#5%@$`!P```-P6`0`3````
MY!8!``4```#X%@$`!````/X6`0`7`````Q<!``H````;%P$`#````"87`0`)
M````,Q<!``8````]%P$`"0```$07`0`(````3A<!``D```!7%P$`"@```&$7
M`0`1````;!<!``8```!^%P$`#@```(47`0`.````E!<!``T```"C%P$`"P``
M`+$7`0`=````O1<!``L```#;%P$``@```.<7`0`<````ZA<!``<````'&`$`
M!@````\8`0!D````%A@!``D```![&`$`!P```(48`0`F````C1@!`#@```"T
M&`$`&@```.T8`0`J````"!D!`#L````S&0$`*````&\9`0`T````F!D!`!D`
M``#-&0$`%0```.<9`0`%````_1D!``<````#&@$`"`````L:`0`'````%!H!
M``4````<&@$`!P```"(:`0`.````*AH!``D````Y&@$`!@```$,:`0`(````
M2AH!``L```!3&@$`!P```%\:`0`(````9QH!``<```!P&@$`%@```'@:`0`)
M````CQH!``8```"9&@$`"P```*`:`0`0````K!H!``8```"]&@$`'````,0:
M`0`4````X1H!``<```#V&@$`$0```/X:`0`(````$!L!``X````9&P$`"```
M`"@;`0`0````,1L!``D```!"&P$`$````$P;`0`&````71L!`!D```!D&P$`
M"@```'X;`0`<````B1L!``<```"F&P$`!0```*X;`0`0````M!L!`!0```#%
M&P$`"P```-H;`0`-````YAL!`"@```#T&P$`&````!T<`0`7````-AP!``0`
M``!.'`$`"0```%,<`0`*````71P!``<```!H'`$``@```'`<`0`.````<QP!
M``@```""'`$`(P```(L<`0`?````KQP!`#@```#/'`$`)@````@=`0`Q````
M+QT!`"<```!A'0$`9````(D=`0`4````[AT!`%4````#'@$`.````%D>`0!*
M````DAX!`%L```#='@$`*````#D?`0`X````8A\!`"@```";'P$`+````,0?
M`0`F````\1\!`!L````8(`$`/@```#0@`0"I`0``<R`!`",````=(@$`%P``
M`$$B`0!(````62(!`(4```"B(@$`,````"@C`0`E````62,!`$$```!_(P$`
M6P```,$C`0!)````'20!`#$```!G)`$`'0```)DD`0`8````MR0!`"L```#0
M)`$`(0```/PD`0`?````'B4!`"L````^)0$`)@```&HE`0`G````D24!`#H`
M``"Y)0$`'0```/0E`0`1````$B8!`#,````D)@$`)0```%@F`0`G````?B8!
M`"````"F)@$`'P```,<F`0`P````YR8!`&D````8)P$`,0```((G`0!!````
MM"<!`#,```#V)P$`)0```"HH`0`]````4"@!`&4```".*`$`30```/0H`0`O
M````0BD!`"X```!R*0$`,````*$I`0!4````TBD!`%H````G*@$`2````((J
M`0!*````RRH!`#(````6*P$`+P```$DK`0`L````>2L!`"T```"F*P$`<0``
M`-0K`0!F````1BP!`&\```"M+`$`LP```!TM`0`7````T2T!`"4```#I+0$`
M,@````\N`0`I````0BX!`#X```!L+@$`(@```*LN`0!2````SBX!`"4````A
M+P$`"P```$<O`0"Q````4R\!`$4````%,`$`(0```$LP`0`P````;3`!`"4`
M``">,`$`'````,0P`0`Q````X3`!``<````3,0$`!P```!LQ`0`$````(S$!
M``T````H,0$`"P```#8Q`0`.````0C$!``L```!1,0$`!0```%TQ`0`0````
M8S$!``(```!T,0$`60```'<Q`0`%````T3$!`!(```#7,0$`!````.HQ`0`'
M````[S$!``@```#W,0$`!0`````R`0`P````!C(!``,````W,@$`$````#LR
M`0`,````3#(!`!,```!9,@$`#0```&TR`0`"````>S(!``<```!^,@$`!@``
M`(8R`0`4````C3(!``P```"B,@$`&````*\R`0`&````R#(!`!(```#/,@$`
M#````.(R`0`#````[S(!`"H```#S,@$`!````!XS`0`&````(S,!``<````J
M,P$`'P```#(S`0`U````4C,!`"X```"(,P$`+P```+<S`0`7````YS,!`"(`
M``#_,P$`)0```"(T`0`@````2#0!`!L```!I-`$`&````(4T`0`D````GC0!
M`!\```##-`$`&@```.,T`0`A````_C0!`"`````@-0$`&@```$$U`0`R````
M7#4!`!H```"/-0$`+P```*HU`0`K````VC4!`!\````&-@$`(P```"8V`0`?
M````2C8!`!H```!J-@$`(0```(4V`0`E````IS8!`"8```#--@$`)0```/0V
M`0`D````&C<!`!@````_-P$`'0```%@W`0`D````=C<!`!@```";-P$`(@``
M`+0W`0`L````US<!`"\````$.`$`%0```#0X`0`E````2C@!`#P```!P.`$`
M'P```*TX`0`C````S3@!`!\```#Q.`$`(````!$Y`0`:````,CD!`!@```!-
M.0$`)@```&8Y`0`>````C3D!`"D```"L.0$`'@```-8Y`0`Q````]3D!``D`
M```G.@$`#````#$Z`0`7````/CH!`"\```!6.@$`)````(8Z`0`'````JSH!
M``\```"S.@$`%````,,Z`0`.````V#H!``T```#G.@$`)````/4Z`0`%````
M&CL!``<````@.P$`(@```"@[`0`E````2SL!`!H```!Q.P$`'0```(P[`0`:
M````JCL!``<```#%.P$`QP```,T[`0`+````E3P!`!4```"A/`$`!@```+<\
M`0`)````OCP!``L```#(/`$`#0```-0\`0`7````XCP!``8```#Z/`$`,P``
M``$]`0`3````-3T!`!,```!)/0$`!P```%T]`0`/````93T!``<```!U/0$`
M,@```'T]`0`$````L#T!`"$```"U/0$`$P```-<]`0`,````ZST!`!$```#X
M/0$`,@````H^`0`6````/3X!``@```!4/@$`'0```%T^`0`)````>SX!``H`
M``"%/@$`%````)`^`0`*````I3X!`!T```"P/@$`"````,X^`0`?````USX!
M``@```#W/@$`&@`````_`0`G````&S\!``8```!#/P$`%0```$H_`0`'````
M8#\!``@```!H/P$`"0```'$_`0`_````>S\!``<```"[/P$`#P```,,_`0`.
M````TS\!`!````#B/P$`"0```/,_`0`)````_3\!``@````'0`$`$P```!!`
M`0`'````)$`!`!D````L0`$`"@```$9``0`7````44`!`!0```!I0`$`"@``
M`'Y``0`,````B4`!`!<```"60`$`!````*Y``0`J````LT`!``P```#>0`$`
M$0```.M``0`'````_4`!``(````%00$`$`````A!`0`8````&4$!``L````R
M00$``P```#Y!`0`(````0D$!``8```!+00$`!P```%)!`0`-````6D$!``L`
M``!H00$`%````'1!`0`5````B4$!``X```"?00$`+P```*Y!`0`@````WD$!
M`!P```#_00$`%0```!Q"`0`,````,D(!`#$````_0@$`!0```'%"`0`2````
M=T(!`#\```"*0@$`$@```,I"`0`*````W4(!``8```#H0@$`!````.]"`0`$
M````]$(!``H```#Y0@$`$P````1#`0`%````&$,!``8````>0P$`!@```"5#
M`0`(````+$,!``0````U0P$`#````#I#`0`*````1T,!`#D```!20P$`+@``
M`(Q#`0`I````NT,!``4```#E0P$`&````.M#`0`9````!$0!`!\````>1`$`
M'0```#Y$`0`1````7$0!``(```!N1`$`!````'%$`0`*````=D0!``8```"!
M1`$`!0```(A$`0`#````CD0!``P```"21`$`10```)]$`0`R````Y40!`!H`
M```810$`-````#-%`0`H````:$4!`%,```"110$`&0```.5%`0!R````_T4!
M`"````!R1@$`-0```)-&`0`A````R48!`$4```#K1@$`,````#%'`0`H````
M8D<!`"D```"+1P$`)@```+5'`0`E````W$<!`"@````"2`$`*````"M(`0`B
M````5$@!`"L```!W2`$`,````*-(`0`2````U$@!`!,```#G2`$`$````/M(
M`0!Y````#$D!``D```"&20$`H0```)!)`0!S````,DH!`'P```"F2@$`*P``
M`"-+`0!4````3TL!`!<```"D2P$`)P```+Q+`0`6````Y$L!``\```#[2P$`
M%P````M,`0`?````(TP!`$````!#3`$`'P```(1,`0`<````I$P!`%$```#!
M3`$`&@```!--`0`4````+DT!``H```!#30$`!0```$Y-`0`&````5$T!``@`
M``!;30$`!0```&1-`0`2````:DT!`!````!]30$`$P```(Y-`0`=````HDT!
M``\```#`30$`#P```-!-`0`$````X$T!``D```#E30$`"P```.]-`0`'````
M^TT!``4````#3@$`%`````E.`0`'````'DX!``@````F3@$`#P```"].`0`(
M````/TX!``P```!(3@$`#P```%5.`0`&````94X!`!0```!L3@$`!@```(%.
M`0`,````B$X!`!$```"53@$`"````*=.`0`$````L$X!`!D```"U3@$`$0``
M`,].`0`*````X4X!`!@```#L3@$`$P````5/`0`<````&4\!`!$````V3P$`
M!````$A/`0`/````34\!``<```!=3P$`!````&5/`0`9````:D\!``<```"$
M3P$``@```(Q/`0`"````CT\!`!$```"23P$`"0```*1/`0`&````KD\!`!(`
M``"U3P$`%P```,A/`0`&````X$\!`"<```#G3P$``@````]0`0`$````$E`!
M``\````74`$`$P```"=0`0`'````.U`!``<```!#4`$`$0```$M0`0`&````
M75`!`!@```!D4`$`!@```'U0`0`3````A%`!`!````"84`$`$@```*E0`0`"
M````O%`!``8```"_4`$`#````,90`0`)````TU`!`!$```#=4`$`(@```.]0
M`0`'````$E$!``<````:40$`"P```")1`0`%````+E$!``(````T40$`"P``
M`#=1`0!E`0``0U$!`!,```"I4@$`#P```+U2`0`2````S5(!``H```#@4@$`
M"0```.M2`0`+````]5(!``0````!4P$`%P````93`0`;````'E,!`#(````Z
M4P$`(@```&U3`0`G````D%,!`"<```"X4P$`'````.!3`0`N````_5,!``L`
M```L5`$`(P```#A4`0`3````7%0!``X```!P5`$`#P```']4`0`%````CU0!
M`"@```"55`$`#````+Y4`0`.````RU0!`!D```#:5`$`#@```/14`0`+````
M`U4!`(\````/50$`#0```)]5`0`*````K54!`!$```"X50$`$````,I5`0`.
M````VU4!``L```#J50$`$````/95`0`/````!U8!``8````75@$`L@```!Y6
M`0`-````T58!`!(```#?5@$`&````/)6`0`0````"U<!``\````<5P$`#P``
M`"Q7`0`'````/%<!``<```!$5P$`+@```$Q7`0`H````>U<!`#X```"D5P$`
M30```.-7`0!H````,5@!`&L```":6`$`;@````99`0!Q````=5D!`$````#G
M60$`&````"A:`0`;````05H!`!0```!=6@$`%````'):`0`:````AUH!``4`
M``"B6@$`!@```*A:`0`0````KUH!``<```#`6@$`"0```,A:`0`)````TEH!
M`#(```#<6@$`,`````];`0`1````0%L!`!$```!26P$`$0```&1;`0`.````
M=EL!``D```"%6P$`%0```(];`0`5````I5L!``\```"[6P$`%@```,M;`0`5
M````XEL!`",```#X6P$`(P```!Q<`0`;````0%P!``\```!<7`$`%@```&Q<
M`0`.````@UP!`"T```"27`$`%P```,!<`0`;````V%P!`!,```#T7`$`6P``
M``A=`0`U````9%T!`"H```":70$`!0```,5=`0`)````RUT!`#$```#570$`
M!@````=>`0`,````#EX!``H````;7@$`!P```"9>`0`(````+EX!``4````W
M7@$`"0```#U>`0`+````1UX!``0```!37@$`(````%A>`0`,````>5X!``P`
M``"&7@$`$````)->`0`:````I%X!`"P```"_7@$`"@```.Q>`0`<````]UX!
M`!L````47P$`(````#!?`0`7````45\!`!8```!I7P$`$P```(!?`0`0````
ME%\!`!\```"E7P$`*P```,5?`0`'````\5\!``8```#Y7P$`"`````!@`0`.
M````"6`!``@````88`$`"@```"%@`0`2````+&`!``H````_8`$`$0```$I@
M`0`5````7&`!`!@```!R8`$`"@```(M@`0`1````EF`!``4```"H8`$`%P``
M`*Y@`0`6````QF`!``L```#=8`$`0@```.E@`0`\````+&$!``H```!I80$`
M!P```'1A`0`3````?&$!``4```"080$`!0```)9A`0`0````G&$!``L```"M
M80$`%0```+EA`0!%````SV$!`!$````58@$`,@```"=B`0`Q````6F(!`"X`
M``",8@$`+P```+MB`0`*````ZV(!``@```#V8@$`"0```/]B`0`*````"6,!
M`#(````48P$`.````$=C`0`Q````@&,!`%<```"R8P$`,`````ID`0`P````
M.V0!`%````!L9`$`4@```+UD`0`P````$&4!`$8```!!90$`-````(AE`0`S
M````O64!`%$```#Q90$`,````$-F`0`V````=&8!`"4```"K9@$`%0```-%F
M`0`9````YV8!`"X````!9P$`)````#!G`0`G````56<!`!,```!]9P$`#```
M`)%G`0`,````GF<!``L```"K9P$`$````+=G`0`8````R&<!`!T```#A9P$`
M!P```/]G`0`'````!V@!`!8````/:`$`"@```"9H`0`(````,6@!`"\````Z
M:`$`"0```&IH`0`+````=&@!``8```"`:`$`!@```(=H`0`%````CF@!``<`
M``"4:`$`!@```)QH`0`*````HV@!`"P```"N:`$`$````-MH`0`(````[&@!
M``,```#U:`$`!P```/EH`0`)`````6D!``0````+:0$`"@```!!I`0`&````
M&VD!`!4````B:0$`!@```#AI`0`(````/VD!``D```!(:0$`#0```%)I`0`(
M````8&D!`"$```!I:0$`$0```(MI`0`)````G6D!`!$```"G:0$`#````+EI
M`0`'````QFD!``,```#.:0$``P```-)I`0`5````UFD!`!0```#L:0$`)0``
M``%J`0`&````)VH!``0````N:@$`"````#-J`0`(````/&H!`%(```!%:@$`
M)````)AJ`0`G````O6H!`"8```#E:@$`'0````QK`0`&````*FL!``@````Q
M:P$`&````#IK`0`B````4VL!`"4```!V:P$`,````)QK`0`D````S6L!`"H`
M``#R:P$`>@```!UL`0`U````F&P!``H```#.;`$`"0```-EL`0`&````XVP!
M`!4```#J;`$`#P````!M`0`-````$&T!`!`````>;0$`$0```"]M`0`0````
M06T!``X```!2;0$`#0```&%M`0`6````;VT!``8```"&;0$`'0```(UM`0`>
M````JVT!`!(```#*;0$`$P```-UM`0`1````\6T!``8````#;@$`"`````IN
M`0`4````$VX!`&$````H;@$`>````(IN`0`(`````V\!`!,````,;P$`!0``
M`"!O`0`%````)F\!`!X````L;P$`&P```$MO`0`0````9V\!`!,```!X;P$`
M%P```(QO`0`3````I&\!`"P```"X;P$`$````.5O`0`D````]F\!``8````;
M<`$`%````")P`0`)````-W`!`!$```!!<`$`#0```%-P`0`2````87`!`!``
M``!T<`$`%@```(5P`0`3````G'`!``P```"P<`$`!@```+UP`0`0````Q'`!
M``<```#5<`$`&````-UP`0`1````]G`!`!$````(<0$`"````!IQ`0`%````
M(W$!``T````I<0$`#0```#=Q`0`)````17$!``L```!/<0$`!@```%MQ`0`(
M````8G$!``T```!K<0$`"0```'EQ`0`-````@W$!``<```"1<0$`!P```)EQ
M`0`)````H7$!``@```"K<0$`"0```+1Q`0`;````OG$!`$<```#:<0$`&@``
M`")R`0`/````/7(!`!,```!-<@$`!0```&%R`0`H````9W(!`!,```"0<@$`
M%````*1R`0`X````N7(!`$<```#R<@$`(@```#IS`0`(````77,!`#4```!F
M<P$`*````)QS`0`/````Q7,!``@```#5<P$`#0```-YS`0`&````[',!``@`
M``#S<P$`%````/QS`0`0````$70!``D````B=`$`"@```"QT`0`)````-W0!
M`!X```!!=`$`(P```&!T`0`@````A'0!`"4```"E=`$`'````,MT`0`M````
MZ'0!`!\````6=0$`(P```#9U`0`N````6G4!`",```")=0$`'0```*UU`0`?
M````RW4!`!X```#K=0$`*0````IV`0`O````-'8!`#(```!D=@$`)````)=V
M`0`K````O'8!`#<```#H=@$`'@```"!W`0`>````/W<!`#T```!>=P$`)```
M`)QW`0`3````P7<!`"@```#5=P$`'P```/YW`0`A````'G@!`!(```!`>`$`
MQ````%-X`0`4````&'D!`!X````M>0$`)0```$QY`0`G````<GD!`",```":
M>0$`(@```+YY`0`D````X7D!`"$````&>@$`)````"AZ`0`G````37H!`#``
M``!U>@$`,@```*9Z`0"F````V7H!`",```"`>P$`&@```*1[`0`<````OWL!
M`"<```#<>P$`,`````1\`0!'````-7P!`$0```!]?`$`#0```,)\`0`$````
MT'P!``D```#5?`$`!0```-]\`0`-````Y7P!``\```#S?`$`#@````-]`0`/
M````$GT!`!`````B?0$`!P```#-]`0`$````.WT!``\```!`?0$`#P```%!]
M`0`,````8'T!``X```!M?0$`$@```'Q]`0`+````CWT!`!(```";?0$`#0``
M`*Y]`0`N````O'T!``<```#K?0$`$````/-]`0`&````!'X!`!,````+?@$`
M&0```!]^`0`;````.7X!`!4```!5?@$``@```&M^`0!)````;GX!``D```"X
M?@$`$````,)^`0`3````TWX!``4```#G?@$`#P```.U^`0`.````_7X!``,`
M```,?P$`$````!!_`0`(````(7\!`!$````J?P$`%0```#Q_`0`)````4G\!
M``\```!<?P$`%````&Q_`0`/````@7\!``H```"1?P$`"P```)Q_`0`-````
MJ'\!`!$```"V?P$`#0```,A_`0`1````UG\!`!H```#H?P$`#0````.``0`/
M````$8`!`"D````A@`$`$P```$N``0`<````7X`!`#8```!\@`$`#0```+.`
M`0`D````P8`!`!,```#F@`$`&@```/J``0`8````%8$!`"4````N@0$`"P``
M`%2!`0`*````8($!`!8```!K@0$`#````(*!`0`D````CX$!`"T```"T@0$`
M#````.*!`0`(````[X$!`"$```#X@0$`"@```!J"`0`9````)8(!`!H````_
M@@$`"0```%J"`0`5````9((!``X```!Z@@$`)@```(F"`0`=````L((!``\`
M``#.@@$`&0```-Z"`0`(````^((!`!`````!@P$`)@```!*#`0`]````.8,!
M``@```!W@P$`%@```("#`0`;````EX,!``H```"S@P$`#0```+Z#`0`R````
MS(,!``\```#_@P$`!0````^$`0`&````%80!`%,````<A`$``P```'"$`0`'
M````=(0!``@```!\A`$`#0```(6$`0`.````DX0!``X```"BA`$`$````+&$
M`0`9````PH0!`!4```#<A`$`&0```/*$`0`7````#(4!``D````DA0$`!@``
M`"Z%`0`+````-84!``H```!!A0$``@```$R%`0`&````3X4!``L```!6A0$`
M(P```&*%`0`6````AH4!`!<```"=A0$`"0```+6%`0`-````OX4!``\```#-
MA0$`#P```-V%`0`^````[84!`"8````LA@$`"````%.&`0`/````7(8!`(L`
M``!LA@$`'@```/B&`0`=````%X<!`!(````UAP$`!P```$B'`0`$````4(<!
M`!L```!5AP$`)P```'&'`0`E````F8<!`!\```"_AP$`)0```-^'`0`7````
M!8@!`!P````=B`$`!P```#J(`0`(````0H@!``<```!+B`$`!@```%.(`0`/
M````6H@!``X```!JB`$`$````'F(`0`.````BH@!``\```"9B`$`#````*F(
M`0`+````MH@!`!$```#"B`$`"0```-2(`0`*````WH@!`!(```#IB`$`#@``
M`/R(`0`N````"XD!``L````ZB0$`"````$:)`0`.````3XD!`!0```!>B0$`
M)@```'.)`0`I````FHD!`"@```#$B0$`'0```.V)`0`>````"XH!`"P````J
MB@$`(0```%>*`0`9````>8H!``0```"3B@$`'````)B*`0`/````M8H!``P`
M``#%B@$``P```-**`0`%````UHH!``@```#<B@$`"0```.6*`0`+````[XH!
M``P```#[B@$`$0````B+`0`*````&HL!``X````EBP$`"P```#2+`0`$````
M0(L!``<```!%BP$`'````$V+`0`>````:HL!``T```")BP$`#````)>+`0`.
M````I(L!``T```"SBP$`)P```,&+`0`'````Z8L!``<```#QBP$`#````/F+
M`0`/````!HP!`!4````6C`$`!P```"R,`0`'````-(P!``0````\C`$`$P``
M`$&,`0`)````58P!``<```!?C`$`,````&>,`0`7````F(P!`((```"PC`$`
M%P```#.-`0`+````2XT!``<```!7C0$`"P```%^-`0`(````:XT!``H```!T
MC0$`!@```'^-`0`*````AHT!``(```"1C0$`!@```)2-`0`)````FXT!`!D`
M``"EC0$`#````+^-`0`/````S(T!`!P```#<C0$``P```/F-`0`'````_8T!
M`!8````%C@$`"@```!R.`0`.````)XX!``4````VC@$`,P```#R.`0`&````
M<(X!``8```!WC@$`&````'Z.`0`1````EXX!``<```"IC@$`"0```+&.`0`%
M````NXX!``D```#!C@$`"````,N.`0`.````U(X!``(```#CC@$`!@```.:.
M`0`.````[8X!``T```#\C@$`"P````J/`0`+````%H\!`!,````BCP$`"0``
M`#:/`0`'````0(\!``P```!(CP$`'P```%6/`0!#````=8\!`#$```"YCP$`
M,````.N/`0`'````')`!``H````DD`$`!````"^0`0`)````-)`!``@````^
MD`$`#````$>0`0`*````5)`!``8```!?D`$`#0```&:0`0`&````=)`!``0`
M``![D`$`0````("0`0!$````P9`!`$(````&D0$`(0```$F1`0`%````:Y$!
M``\```!QD0$`!0```(&1`0`#````AY$!``8```"+D0$`(0```)*1`0`0````
MM)$!`!@```#%D0$`!@```-Z1`0`$````Y9$!`!L```#JD0$`!@````:2`0`(
M````#9(!`"(````6D@$`!````#F2`0`%````/I(!`!<```!$D@$`!````%R2
M`0`-````89(!``T```!OD@$`#P```'V2`0`(````C9(!``D```"6D@$`!0``
M`*"2`0`]````II(!`#8```#DD@$`.P```!N3`0`J````5Y,!`#@```""DP$`
M.@```+N3`0`M````]I,!`%(````DE`$`,````'>4`0`Y````J)0!`"D```#B
ME`$`$`````R5`0`8````'94!``P````VE0$`)````$.5`0`D````:)4!`"(`
M``"-E0$`(0```+"5`0`+````TI4!``T```#>E0$`"@```.R5`0`)````]Y4!
M`"(````!E@$`*````"26`0`H````398!``@```!VE@$`&@```'^6`0`S````
MFI8!`!@```#.E@$`$@```.>6`0`'````^I8!`!,````"EP$`%````!:7`0`6
M````*Y<!`!````!"EP$`40```%.7`0"1````I9<!`(0````WF`$`%P```+R8
M`0`.````U)@!``\```#CF`$`%````/.8`0`5````")D!`!$````>F0$`#```
M`#"9`0`3````/9D!`!4```!1F0$`%0```&>9`0`/````?9D!`"(```"-F0$`
M*0```+"9`0"-````VID!`!0```!HF@$`!0```'V:`0`6````@YH!``D```":
MF@$`!````*2:`0`*````J9H!`",```"TF@$`$0```-B:`0`3````ZIH!``X`
M``#^F@$`$`````V;`0`4````'IL!`"<````SFP$`*0```%N;`0`E````A9L!
M`"4```"KFP$`,````-&;`0`P`````IP!`!T````SG`$`10```%&<`0`/````
MEYP!`!$```"GG`$`$0```+F<`0`3````RYP!`!(```#?G`$`%0```/*<`0`7
M````")T!``\````@G0$`$0```#"=`0`Y````0IT!`!T```!\G0$`%P```)J=
M`0`Z````LIT!`!,```#MG0$`!P````&>`0`-````"9X!`"(````7G@$`$@``
M`#J>`0`5````39X!`!(```!CG@$`&0```':>`0`9````D)X!`!0```"JG@$`
M&@```+^>`0`<````VIX!`!(```#WG@$`'@````J?`0`D````*9\!`!8```!.
MGP$`%````&6?`0`8````>I\!`!(```"3GP$`&0```*:?`0`7````P)\!`!,`
M``#8GP$`%P```.R?`0`*````!*`!`!`````/H`$`(````""@`0`$````0:`!
M``<```!&H`$`"@```$Z@`0`8````6:`!``8```!RH`$`"````'F@`0`'````
M@J`!``8```"*H`$`!P```)&@`0`'````F:`!``4```"AH`$`%````*>@`0`&
M````O*`!``@```##H`$`!````,R@`0`$````T:`!``D```#6H`$`%0```."@
M`0`2````]J`!``\````)H0$`$````!FA`0`*````*J$!`!,````UH0$`!0``
M`$FA`0`G````3Z$!``X```!WH0$`#0```(:A`0`3````E*$!``T```"HH0$`
M"P```+:A`0`.````PJ$!`#,```#1H0$`"`````6B`0`(````#J(!`"<````7
MH@$`%````#^B`0`1````5*(!``<```!FH@$`"0```&ZB`0`'````>*(!``0`
M``"`H@$`(````(6B`0`-````IJ(!`!L```"TH@$`$````-"B`0`2````X:(!
M`!8```#TH@$`'0````NC`0`9````*:,!``<```!#HP$`!P```$NC`0`&````
M4Z,!`!@```!:HP$`!P```'.C`0`%````>Z,!``H```"!HP$`#@```(RC`0`'
M````FZ,!``8```"CHP$`!P```*JC`0`=````LJ,!``T```#0HP$`#````-ZC
M`0`,````ZZ,!`!(```#XHP$`#`````ND`0`/````&*0!`!<````HI`$`#0``
M`$"D`0`0````3J0!``@```!?I`$`!````&BD`0`0````;:0!`$$```!^I`$`
M!0```,"D`0`,````QJ0!`"$```#3I`$`#0```/6D`0`9`````Z4!``H````=
MI0$`#0```"BE`0`*````-J4!``@```!!I0$`#@```$JE`0`*````6:4!`!$`
M``!DI0$`$@```':E`0`H````B:4!`"P```"RI0$`+P```-^E`0`*````#Z8!
M``@````:I@$`"````".F`0`,````+*8!`!8````YI@$`!P```%"F`0`)````
M6*8!`!X```!BI@$`"````(&F`0`)````BJ8!``P```"4I@$`3@```*&F`0`3
M````\*8!``L````$IP$`!@```!"G`0`$````%Z<!`!8````<IP$`%P```#.G
M`0`8````2Z<!``D```!DIP$``@```&ZG`0`$````<:<!`"(```!VIP$``P``
M`)FG`0`%````G:<!`#,```"CIP$`"@```->G`0`%````XJ<!``8```#HIP$`
M#0```.^G`0`-````_:<!``8````+J`$`"````!*H`0`)````&Z@!``0````E
MJ`$`!0```"JH`0!B````,*@!``L```"3J`$`#0```)^H`0`7````K:@!``4`
M``#%J`$`!0```,NH`0`F````T:@!`#<```#XJ`$`$0```#"I`0`*````0JD!
M`!4```!-J0$`"@```&.I`0`)````;JD!`!P```!XJ0$`)P```)6I`0`M````
MO:D!`"P```#KJ0$`'0```!BJ`0`.````-JH!``,```!%J@$`!P```$FJ`0`+
M````4:H!``4```!=J@$`"@```&.J`0`2````;JH!``<```"!J@$`:0```(FJ
M`0`1````\ZH!``L````%JP$`"@```!&K`0`?````'*L!`$T````\JP$`&@``
M`(JK`0`'````I:L!`"$```"MJP$`-0```,^K`0`(````!:P!``8````.K`$`
M'P```!6L`0`&````-:P!``D````\K`$`+0```$:L`0`L````=*P!`"\```"A
MK`$`!@```-&L`0`*````V*P!`"4```#CK`$`80````FM`0`6````:ZT!`"@`
M``""K0$`%0```*NM`0`"````P:T!``X```#$K0$`"0```-.M`0`/````W:T!
M``H```#MK0$`!P```/BM`0`7`````*X!``8````8K@$`"````!^N`0`-````
M**X!``L````VK@$`"@```$*N`0`)````3:X!`#<```!7K@$`!P```(^N`0`6
M````EZX!`!0```"NK@$`(````,.N`0`3````Y*X!``P```#XK@$`"@````6O
M`0`+````$*\!``H````<KP$`#````">O`0`*````-*\!``H````_KP$`'0``
M`$JO`0`1````:*\!`!0```!ZKP$`#````(^O`0`4````G*\!``P```"QKP$`
M$@```+ZO`0`%````T:\!`"4```#7KP$`!````/VO`0`'`````K`!``4````*
ML`$`!0```!"P`0`)````%K`!`!,````@L`$`$@```#2P`0`:````1[`!`!8`
M``!BL`$`&````'FP`0`7````DK`!`!<```"JL`$`'@```,*P`0`8````X;`!
M``<```#ZL`$`!0````*Q`0`/````"+$!`!`````8L0$`"P```"FQ`0`A````
M-;$!``T```!7L0$`$````&6Q`0`D````=K$!`"<```";L0$`%0```,.Q`0`&
M````V;$!``T```#@L0$`"````.ZQ`0`0````][$!``\````(L@$`"0```!BR
M`0`)````(K(!``4````LL@$`!P```#*R`0`%````.K(!``0```!`L@$``P``
M`$6R`0`_````2;(!`#D```")L@$`$P```,.R`0`L````U[(!`#(````$LP$`
M$0```#>S`0`Z````2;,!`"X```"$LP$`,P```+.S`0`S````Y[,!`#L````;
MM`$`$@```%>T`0`:````:K0!`!4```"%M`$`&P```)NT`0`=````M[0!`!<`
M``#5M`$`%@```.VT`0`4````!+4!`!4````9M0$`&0```"^U`0`R````2;4!
M`#(```!\M0$`-0```*^U`0`S````Y;4!`#0````9M@$`,0```$ZV`0!K````
M@+8!`!T```#LM@$`%0````JW`0`.````(+<!`!\````OMP$`"P```$^W`0`6
M````6[<!`#````!RMP$`+P```*.W`0`C````T[<!``P```#WMP$`20````2X
M`0!"````3K@!``0```"1N`$`$````):X`0`<````I[@!``X```#$N`$`$P``
M`-.X`0`(````Y[@!``D```#PN`$`!P```/JX`0`)`````KD!``X````,N0$`
M%0```!NY`0`.````,;D!`!$```!`N0$`"````%*Y`0`<````6[D!``@```!X
MN0$`!0```(&Y`0`0````A[D!``\```"8N0$`#````*BY`0`_````M;D!``(`
M``#UN0$`!@```/BY`0`.````_[D!``8````.N@$`!P```!6Z`0`0````';H!
M``<````NN@$`.````#:Z`0`/````;[H!`!T```!_N@$`!````)VZ`0`Q````
MHKH!`!L```#4N@$`(@```/"Z`0!8````$[L!`!@```!LNP$`2````(6[`0`C
M````SKL!`!````#RNP$`!@````.\`0`.````"KP!``\````9O`$`#````"F\
M`0`3````-KP!``L```!*O`$`'0```%:\`0`:````=+P!``8```"/O`$`$0``
M`):\`0`/````J+P!`"8```"XO`$`$@```-^\`0`9````\KP!`!,````,O0$`
M%````""]`0`@````-;T!``@```!6O0$`"0```%^]`0`9````:;T!`!(```"#
MO0$`$@```):]`0`3````J;T!`!@```"]O0$`$````-:]`0`9````Y[T!`!@`
M```!O@$`"@```!J^`0`,````);X!``@````RO@$`!0```#N^`0`=````0;X!
M``8```!?O@$`$@```&:^`0`(````>;X!`!0```""O@$`"@```)>^`0`@````
MHKX!`!(```##O@$`,````-:^`0`:````![\!``L````BOP$`#````"Z_`0`A
M````.[\!``<```!=OP$`%@```&6_`0`#````?+\!`!@```"`OP$`!@```)F_
M`0`'````H+\!`"$```"HOP$`,0```,J_`0`%````_+\!`!L````"P`$`#P``
M`![``0`'````+L`!``T````VP`$`%P```$3``0`$````7,`!``H```!AP`$`
M#````&S``0`(````><`!``8```""P`$`"````(G``0`&````DL`!``H```"9
MP`$`%P```*3``0`T````O,`!`#0```#QP`$`(@```";!`0`S````2<$!`"``
M``!]P0$`1P```)[!`0`=````YL$!`"X````$P@$`+````#/"`0!F````8,(!
M`"4```#'P@$`!0```.W"`0`(````\\(!``D```#\P@$`"`````;#`0`A````
M#\,!`!P````QPP$`,````$[#`0`C````?\,!`!(```"CPP$`,0```+;#`0`V
M````Z,,!``D````?Q`$`&````"G$`0`+````0L0!``H```!.Q`$`*P```%G$
M`0`-````A<0!`!(```"3Q`$`#0```*;$`0`(````M,0!`!0```"]Q`$`"0``
M`-+$`0`,````W,0!`!````#IQ`$`&P```/K$`0`:````%L4!`"P````QQ0$`
M"P```%[%`0`-````:L4!``8```!XQ0$`!0```'_%`0`%````A<4!`!T```"+
MQ0$`%````*G%`0`%````OL4!``L```#$Q0$`"@```-#%`0`(````V\4!``\`
M``#DQ0$`$0```/3%`0`.````!L8!``H````5Q@$`!0```"#&`0`.````)L8!
M`$4````UQ@$`8@```'O&`0`<````WL8!``D```#[Q@$`(P````7'`0`9````
M*<<!``4```!#QP$`%````$G'`0`(````7L<!``L```!GQP$`$@```'/'`0`N
M````AL<!``L```"UQP$`$````,''`0`1````TL<!`!(```#DQP$`$````/?'
M`0!)````",@!``P```!2R`$`)````%_(`0`5````A,@!`!<```":R`$`/0``
M`++(`0`N````\,@!`#`````?R0$`,0```%#)`0`M````@LD!``P```"PR0$`
M"@```+W)`0`0````R,D!`!,```#9R0$`&P```.W)`0`*````"<H!`!$````4
MR@$`'````";*`0`'````0\H!`!@```!+R@$`%P```&3*`0`(````?,H!``8`
M``"%R@$`"P```(S*`0`/````F,H!`!0```"HR@$``P```+W*`0`(````P<H!
M``L```#*R@$`$@```-;*`0`3````Z<H!`!$```#]R@$`$0````_+`0`&````
M(<L!``D````HRP$`-P```#++`0`P````:LL!`"T```";RP$`!P```,G+`0`3
M````T<L!``8```#ERP$`(P```.S+`0`8````$,P!`"<````IS`$`#0```%',
M`0`)````7\P!`"<```!IS`$``P```)',`0`&````E<P!``H```"<S`$``@``
M`*?,`0`)````JLP!`!$```"TS`$`"````,;,`0`5````S\P!`!L```#ES`$`
M%`````'-`0`%````%LT!``H````<S0$`%````"?-`0`1````/,T!``P```!.
MS0$`!P```%O-`0`,````8\T!``H```!PS0$`#@```'O-`0!=````BLT!`!H`
M``#HS0$`*P````/.`0`6````+\X!``H```!&S@$`!@```%'.`0`,````6,X!
M``X```!ES@$`$P```'3.`0`D````B,X!`!T```"MS@$`%````,O.`0`H````
MX,X!`!`````)SP$`(````!K/`0`4````.\\!`!````!0SP$`=````&'/`0`C
M````UL\!`!L```#ZSP$`+````!;0`0`B````0]`!`!L```!FT`$`)0```(+0
M`0`9````J-`!`!L```#"T`$`&0```-[0`0`+````^-`!``<````$T0$`"```
M``S1`0`)````%=$!`!0````?T0$`"P```#31`0`D````0-$!``\```!ET0$`
M$P```'71`0`'````B=$!``D```"1T0$`7@```)O1`0!'````^M$!`#@```!"
MT@$`6P```'O2`0`)````U](!`"$```#AT@$`,@````/3`0`*````-M,!``@`
M``!!TP$`$@```$K3`0`_````7=,!``D```"=TP$`:````*?3`0`P````$-0!
M`"<```!!U`$`$````&G4`0`B````>M0!`"0```"=U`$`+@```,+4`0`K````
M\=0!`"X````=U0$`,0```$S5`0`0````?M4!``4```"/U0$`"P```)75`0`*
M````H=4!`!4```"LU0$`"@```,+5`0`L````S=4!``P```#ZU0$`"0````?6
M`0`,````$=8!`!<````>U@$`"0```#;6`0`'````0-8!`!,```!(U@$`"0``
M`%S6`0`(````9M8!``8```!OU@$`"P```';6`0`+````@M8!`!$```".U@$`
M$````*#6`0`.````L=8!`!L```#`U@$`$````-S6`0`'````[=8!`!4```#U
MU@$`&`````O7`0`)````)-<!``L````NUP$`&@```#K7`0`I````5=<!`!(`
M``!_UP$`)0```)+7`0`G````N-<!``\```#@UP$`"@```/#7`0`:````^]<!
M``8````6V`$`!````!W8`0`8````(M@!``X````[V`$`$````$K8`0`.````
M6]@!``4```!JV`$`"0```'#8`0`)````>M@!``D```"$V`$`"0```([8`0`2
M````F-@!``8```"KV`$`#0```++8`0`%````P-@!``D```#&V`$`"P```-#8
M`0`:````W-@!``L```#WV`$``@````/9`0`@````!MD!``D````GV0$`"@``
M`#'9`0!M````/-D!``D```"JV0$`!@```+39`0`K````N]D!`#X```#GV0$`
M&P```";:`0`K````0MH!`$0```!NV@$`*@```+/:`0`T````WMH!`!H````3
MVP$`&````"[;`0`&````1]L!``P```!.VP$`"@```%O;`0`-````9ML!``8`
M``!TVP$`"@```'O;`0`8````AML!``P```"?VP$`#0```*S;`0`/````NML!
M``L```#*VP$`#0```-;;`0`(````Y-L!``H```#MVP$`&````/C;`0`)````
M$=P!``8````;W`$`"P```"+<`0`3````+MP!``8```!"W`$`&````$G<`0`<
M````8MP!``H```!_W`$`&````(K<`0`,````H]P!`!(```"PW`$`"P```,/<
M`0`2````S]P!``@```#BW`$`$@```.O<`0`&````_MP!`!L````%W0$`#```
M`"'=`0`A````+MT!``4```!0W0$`!0```%;=`0`.````7-T!`",```!KW0$`
M"P```(_=`0`-````F]T!`"P```"IW0$`'````-;=`0`.````\]T!``4````"
MW@$`#`````C>`0`/````%=X!``X````EW@$``@```#3>`0`/````-]X!``@`
M``!'W@$`)````%#>`0`I````==X!`"\```"?W@$`+0```,_>`0`H````_=X!
M`"@````FWP$`70```$_?`0`3````K=\!`%D```#!WP$`-````!O@`0!>````
M4.`!`%L```"OX`$`)@````OA`0`]````,N$!`#,```!PX0$`-P```*3A`0`U
M````W.$!`!X````2X@$`.P```#'B`0#D`0``;>(!`"$```!2Y`$`%````'3D
M`0!4````B>0!`((```#>Y`$`0@```&'E`0`I````I.4!`#\```#.Y0$`<@``
M``[F`0!2````@>8!`#(```#4Y@$`(`````?G`0`5````*.<!`#(````^YP$`
M'0```''G`0`=````C^<!`"T```"MYP$`(P```-OG`0`H````_^<!`$$````H
MZ`$`'0```&KH`0`3````B.@!`#H```"<Z`$`*````-?H`0`I`````.D!`"(`
M```JZ0$`&````$WI`0!`````9ND!`&D```"GZ0$`.P```!'J`0!.````3>H!
M`#L```"<Z@$`*P```-CJ`0`Z````!.L!`&,````_ZP$`3````*/K`0`R````
M\.L!`"T````C[`$`,0```%'L`0!4````@^P!`%L```#8[`$`30```#3M`0!1
M````@NT!`#0```#4[0$`+@````GN`0`N````..X!`"X```!G[@$`B````);N
M`0!]````'^\!`(8```"=[P$`T````"3P`0`3````]?`!`"8````)\0$`.0``
M`##Q`0`L````:O$!`$@```"7\0$`*P```.#Q`0!,````#/(!`"````!9\@$`
M"@```'KR`0#!````A?(!`$<```!'\P$`)@```(_S`0`U````MO,!`"<```#L
M\P$`)````!3T`0`^````.?0!``8```!X]`$`!P```'_T`0`$````A_0!``P`
M``",]`$`"P```)GT`0`,````I?0!``L```"R]`$`!0```+[T`0`0````Q/0!
M``,```#5]`$`9P```-GT`0`'````0?4!`!4```!)]0$`!````%_U`0`'````
M9/4!``8```!L]0$`!0```'/U`0`^````>?4!``D```"X]0$`%0```,+U`0`+
M````V/4!`!(```#D]0$`#0```/?U`0`"````!?8!``<````(]@$`!P```!#V
M`0`2````&/8!``P````K]@$`&````#CV`0`&````4?8!``X```!8]@$`#```
M`&?V`0`#````=/8!`"L```!X]@$`!````*3V`0`'````J?8!``@```"Q]@$`
M*P```+KV`0!'````YO8!`#H````N]P$`.P```&GW`0`B````I?<!`#8```#(
M]P$`.0```/_W`0`M````.?@!`",```!G^`$`)@```(OX`0`J````LO@!`"4`
M``#=^`$`(P````/Y`0`D````)_D!`"P```!,^0$`(0```'GY`0`\````F_D!
M`"8```#8^0$`.@```/_Y`0`U````.OH!`"L```!P^@$`+@```)SZ`0`N````
MR_H!`"D```#Z^@$`*@```"3[`0`N````3_L!`"L```!^^P$`,````*K[`0`N
M````V_L!`"D````*_`$`*0```#3\`0`S````7OP!`"0```"2_`$`+@```+?\
M`0`X````YOP!`#L````?_0$`(````%O]`0`J````?/T!`$,```"G_0$`*0``
M`.O]`0`L````%?X!`"P```!"_@$`+0```&_^`0`G````G?X!`!T```#%_@$`
M*P```./^`0`L````#_\!`#<````\_P$`+````'3_`0!!````H?\!``P```#C
M_P$`$P```/#_`0`@````!``"`#$````E``(`)````%<``@`)````?``"``\`
M``"&``(`'````)8``@`4````LP`"`!````#(``(`,0```-D``@`(````"P$"
M``@````4`0(`(P```!T!`@`F````00$"`!P```!H`0(`)P```(4!`@`?````
MK0$"``D```#-`0(`X0```-<!`@`2````N0("`!H```#,`@(`"0```.<"`@`,
M````\0("`!0```#^`@(`$````!,#`@`:````)`,"``8````_`P(`-P```$8#
M`@`5````?@,"`!<```"4`P(`!P```*P#`@`3````M`,"``L```#(`P(`/```
M`-0#`@`)````$00"`"L````;!`(`$````$<$`@`0````6`0"`!4```!I!`(`
M-````'\$`@`@````M`0"``X```#5!`(`'P```.0$`@`/````!`4"`!`````4
M!0(`&@```"4%`@`+````0`4"`!L```!,!0(`"P```&@%`@`D````=`4"``H`
M``"9!0(`&P```*0%`@`K````P`4"``<```#L!0(`)P```/0%`@`'````'`8"
M``D````D!@(`"0```"X&`@`[````.`8"``8```!T!@(`#@```'L&`@`3````
MB@8"`!8```">!@(`"@```+4&`@`(````P`8"``<```#)!@(`$P```-$&`@`+
M````Y08"`!P```#Q!@(`#P````X'`@`8````'@<"`!8````W!P(`!0```$X'
M`@`'````5`<"`!<```!<!P(`!````'0'`@`S````>0<"``P```"M!P(`$```
M`+H'`@`,````RP<"``(```#8!P(`$0```-L'`@`B````[0<"``L````0"`(`
M`P```!P(`@`'````(`@"``D````H"`(`!@```#((`@`-````.0@"``H```!'
M"`(`%````%((`@`5````9P@"`!$```!]"`(`-@```(\(`@`>````Q@@"`!H`
M``#E"`(`%P`````)`@`+````&`D"`#,````D"0(`!P```%@)`@`7````8`D"
M`$L```!X"0(`%````,0)`@`/````V0D"``@```#I"0(`!````/()`@`$````
M]PD"``H```#\"0(`%@````<*`@`%````'@H"``8````D"@(`"````"L*`@`)
M````-`H"``0````^"@(`"0```$,*`@`.````30H"`#T```!<"@(`,0```)H*
M`@`N````S`H"``4```#["@(`%P````$+`@`@````&0L"`"$````Z"P(`)0``
M`%P+`@`0````@@L"``(```"3"P(`!````)8+`@`*````FPL"``D```"F"P(`
M!0```+`+`@`"````M@L"`!\```"Y"P(`3@```-D+`@`Y````*`P"`!X```!B
M#`(`,P```($,`@`J````M0P"`&````#@#`(`$````$$-`@!\````4@T"`"<`
M``#/#0(`4P```/<-`@`H````2PX"`%(```!T#@(`.````,<.`@`S``````\"
M`#0````T#P(`.0```&D/`@`X````HP\"`#\```#<#P(`/P```!P0`@`M````
M7!`"`#````"*$`(`,P```+L0`@`.````[Q`"``X```#^$`(`#0````T1`@"#
M````&Q$"``@```"?$0(`L0```*@1`@"-````6A("`(@```#H$@(`+@```'$3
M`@!:````H!,"`!0```#[$P(`)0```!`4`@`8````-A0"`!(```!/%`(`&@``
M`&(4`@`C````?10"`#<```"A%`(`&@```-D4`@`8````]!0"`%8````-%0(`
M&@```&05`@`6````?Q4"``L```"6%0(`!0```*(5`@`&````J!4"``@```"O
M%0(`!0```+@5`@`;````OA4"`!$```#:%0(`'@```.P5`@`?````"Q8"`!$`
M```K%@(`!P```#T6`@`$````118"``D```!*%@(`#@```%06`@`(````8Q8"
M``4```!L%@(`'````'(6`@`*````CQ8"``D```":%@(`#P```*06`@`'````
MM!8"``@```"\%@(`$@```,46`@`*````V!8"`!8```#C%@(`"P```/H6`@`)
M````!A<"`!8````0%P(`"````"<7`@`$````,!<"`!P````U%P(`%0```%(7
M`@`)````:!<"`!H```!R%P(`$````(T7`@`A````GA<"``\```#`%P(`"```
M`-`7`@`4````V1<"``8```#N%P(`!P```/47`@`7````_1<"``@````5&`(`
M`@```!X8`@`"````(1@"`!$````D&`(`"P```#88`@`&````0A@"`!$```!)
M&`(`%````%L8`@`'````<!@"`"T```!X&`(``@```*88`@`$````J1@"`!,`
M``"N&`(`%P```,(8`@`+````VA@"``<```#F&`(`#P```.X8`@`&````_A@"
M`!<````%&0(`"````!T9`@`8````)AD"`!`````_&0(`$@```%`9`@`"````
M8QD"``<```!F&0(`"P```&X9`@`*````>AD"`!4```"%&0(`,@```)L9`@`'
M````SAD"``D```#6&0(`$0```.`9`@`%````\AD"``(```#X&0(`"P```/L9
M`@`!````TP0``!P$```Q!0``7P,```````"<`0``;0(``*`$````````E`,`
M`,<!``#[!@``?```````````````A@(``"D'```+`0```````($'``#!````
M=P4``!4$``#P!0``+````-L#``#!!@``(P<```@"```!!```O`4```('```Q
M`P```````*8"``#O!0``9`(``+("```/!```@0,`````````````````````
M``#6!```404``(4$`````````````/8!``!P`@````````````!_`@``+@0`
M```````C`0``I`4```````!B!P``XP4``(\&```E`0``<`8``/4$``!N`@``
M<`$``#,'``#"`0``T0(``"\$``!O`P``3@<``%H```"B`0``,P$``(D'````
M````>P$``.L```"6!@``P`4``%P'``!*!0``S`8```````"4!```8@(``/(`
M```I`@``9@(```````#;!```A`8``-T%`````````````*4`````````````
M``````"8`P```````$````#D!@```````,T!````````G00``$@"``"_!0``
M`````/T"``"(!P````````P%````````3P0``,L%``#L`@``)@4``!<`````
M````-````%@```"\`0````````````"U`@``6@0``&4#``!J`P``7P$``(('
M``````````````````#Z`0``9`,``&\```#6`0```````'T&````````"`<`
M`)``````````30,``)L"````````'`,``%T&``#T`0``WP```"@#``#<`0``
MT`$``+8#``!'`P```````!L'```1!P``)0,``/$```"P!0``T@0`````````
M````JP,``*0`````````R@4``&$#``!Y`P``E00```H$````````B@8``,`!
M````````X00``'@'``#9`P``YP$```````#^!0``2@<``*D!``!8!```Y`$`
M``````!/````O@$``````````````````"\#``!L!P```````+(`````````
MF`4``&<$``"D!@``X@$``$8&````````*@```/L!``!H`0``5`<``-H#```H
M!@``HP0``%0&``!6!```KP8```````"=`@``6P```)(&``"+`P``J0``````
M``"L!0``TP```*`#``!Z`0``9P(``,(#```H!P``>P,``"L`````````-@``
M````````````,0(``(,```#D!````````/8$``!Y!```1`<```````#W````
M``````````"3`@``N@4````````7!0``J@,``"L"``!Z!P```````'0$```[
M`@````````````"0`@``C@$``(H$``#<````?`<``%<%``":`P```P(``#L'
M``!>`P``!@$```````!%!````````"T'``"?`P``I0$`````````````9P4`
M`'$!`````````````$(&``#;````/0<``$H``````````@(````````I`0``
M`````%8#````````G`0```````#,`0``800``!8#````````)P0``&$`````
M`````````"4$``!W````[@,``&8&````````G`8``/\%``![`````````!@&
M``"Q!````P````,'``#<!0``MP8``,D#``!\`@``%@<``.P`````````````
M`&,!````````[@(``)H```"2````G@,```````";`0``*P4``'$"``#S`P``
M1@,``+X"``"Z`0``W00``-8&``"T`P``XP0``,H$``"J!````````!@'```7
M`@``OP0``!@!``"Q`@````````````#B`P``CP(```````!^`0``_04``&D!
M```6!@``^`$``"H#``!+`P``<@,``$<$``"6`0``1P```,@!``!Q`P``3@8`
M`#H```!@!@``4P```-4&``!V`@```````"X%```F`@``<P8``.T````*!@``
M!````.0"``!^`P``@P4``(D!``"3!```_@(``&0'``#F!0``%P$```````"?
M`0``#0<``'L"``!^````!00```D'```M!@``-`8```````!2`@``OP``````
M``!W`P``_P,````````+````,P4`````````````9@<``"<&``#=````````
M`/0"```_!P```````-@#``#:!`````````````!H````#0(``'(&````````
MTP8``,4&``!Q````H````/P&``!"`@```````)L$``"Y`P``P`````0$```.
M!@``3`$``)0"``"Y!0``H`$``,$!````````!0````````!,!P``U@(``&,`
M````````Q````````````````````/($````````0`4``&\'````````S08`
M```````7`P``@08`````````````4@4`````````````\P0``'<$``"C!@``
M;P0```@```!>````2`<``+H#``!V!0``W@```(0#```D!```.P4``/<&``"<
M`P``=P(```````!J`0``/@(``+X&``#M!0``O@0```````!O!@```````(D`
M``"E`@```````#,&````````'`<```````!5`0``(@0``#@!````````;00`
M``````"'`@``>04``(`%``#6`````````"$"``!/!@``-P0``#,"````````
M`````)<#``#_!`````<```<#``!I!@```````/$!``#&````\`,``(\```!;
M!P````````````#G!@``A0,`````````````W0(``"X#``!7`0``]`8`````
M``#E`0``_@```$T```#-!```$`4````````V`0``D`,``'T!``"7````600`
M`'\$``!S````IP4``%@"``""`@```````$$&``!V`0``_@$```````#G!```
M`````"0`````````^`0``&L$``#&!```60$``"$$```&````GP(``%X"````
M``````````,&``"4!0```````.$&``".`P``/@```"L!```4`@``UP,``)$&
M``!`!P```````&P#````````C@0``*,`````````Q0,``%$```"]`@``+`0`
M`"`$``#I!````````"P&``#V`@``+@8``%@%``````````````````"I`@``
M)`,`````````````LP$```````!]````)P,```````!R!P```````)$$````
M````S@$``/`&```(`0````````````````````$``$P%```X!@```````,@%
M```1`0``7P0``/H#``"<````L`,``,0!````````=00``'$$``#7`@``R04`
M`'P!``",`0``````````````````_`4``#4$````````/@<``*4&``#0`P``
MJ`8``.T!``"F`````````.\"``````````````````"M!```ZP$``/D$``#?
M`P``*`0```````!F!```GP````\&``"Y!```Z@,```````#)!```6P(``(P$
M````````Q`(``+X%``!"!0``=`<``-4%``"3!@```````&,'````````````
M`!L$````````]`,``%0```#9`````````$@```"6`````````%8"```W````
M'P8``#P"``!S`@```````/,"````````"`0``+<"``"E!```=P<```````#:
M!@``%0````````#9!````````/P`````````'P4``(L%``#W`0``]@4``'P#
M``#8!@``M`4``)4%```#!0```````````````````````(,$``"_`@``S@(`
M``P'``"9`P``_P(```````#T!```/P(``%,!````````Q00``#(!````````
MRP(``(P``````````````$L!`````````````+H&```)`0``W@$``"8$``"D
M`P``S`4``',!```S!```$`8``(L$``!B`````````"\```"@!@``.`(``%D"
M``!_!P``1P<``(T%```9`````````*T```#O`P``T08``'P%```R````O04`
M`,H"````````]@8``+8&``!;!0``1`$`````````````'0(``!X'``#;!@``
M``````X%````````8`$``#D"``!#`@``NP$``(`#````````*@$``$8```#0
M`@``$P8```````!_````0@,``#4'```M`0``,00``.$!````````T04``+0"
M``#H`0``5`,``/@#``!]!````````*(#``#4`@``8@,``.H%````````````
M`%\````?`@``,@,``/P"````````<P0```````"`!@``-P4``#H%```8!```
M`````'8```"C`P```````)<%``!B!0``$@(``&P!```B`0```````(X`````
M````:@4```````#%!0``&@$``.`!````````DP,``)@`````````A04``!@`
M````````+`4``(8$````````'````)D&``!H!@``^P(``(4!````````3`,`
M`&@'``!Z!```$`0``&4```!4!0``Q`8``'0"``#@``````````````"W`P``
M=0,`````````````````````````````7`$````````X!P``?@(``&P`````
M`````````(@"````````S@8```L"```/!0``;0$``"T"``#?!0``YP(``$\#
M```-`0``8````&<`````````OP8``-D"``"Y!@``````````````````Z@``
M`+($```H`````````"\'````````\P```*H%``#]`0``U00``!H`````````
M``````````!B!````````,@&``!?!@``3@`````````3`@````````````!*
M!```%08``",````_````@@4``*@$``"X`@``D04``.0```!"!````````+@%
M``!!!0``'P$``+@!````````FP4```````"U`````0<``"L'````````````
M`+`$````````:0<``'L%``!F````````````````````S@0```<!``!7!@``
M``````````#?!@``8`<``#L!```[!```=0(``.L&```Y!```'P<``/T&``!Q
M!@``#`$```````!'!@``G08``+P$``!E!@``"04``$4'````````````````
M``!S`P``BP```'D'``#2`P```0(``*,!```L`P```````+,$````````)`<`
M``$#``#K`@``<````&T&``#8````$08``$4#``!=!P``\@4``.@&``#1!```
M/P,```````#Z!0``90<``)\&``#2`@```````&L!``#1````B08``#````#(
M`@``H00``.P!``#B````:@(``*8!``!<`@```````#@#````````6P8``"L$
M``!@`P``X`4```````#/````E@4``-<&``!%`@````````````"5`0``````
M```````&!@``1@4``/X&````````20,``&P%``!3!P``TP$``(`!````````
M`````````````````````/T$``!L!```!@0``#X#```?!```WP0```````!<
M`P``?@0``!$"```K!@``RP0``!L#````````?@8``'4````%`P``D0$`````
M``"L``````````0"``!Y`0``*00``#0'````````>@```'0`````````````
M`&(!``!4`0``#0```#\!``#>`P``M`8``#<'`````````````"8`````````
M``````````"(!0``CP0```````!&!`````8```````"S````4`$``)`&``"R
M`0``%@(``%`"``"'`P``;@<``/4"``"V````\@8``/$#``!1`0``X@0``.\$
M````````SP8````````O`@````````L'``!0`````````%0"````````2P8`
M`($"````````&P8```````#S!@``BP8``+L```!<!@```````/D!``"$````
M108```````!U`0````````````!$`@``2`$``!4#````````)`$``%D#``#U
M````F@4``%,%``#<!@``.0$``!D'````````B`$``%P%``!7!```00<``)H"
M```]`P``$0,``*X%``!)`0```````)\$````````/@$``&H```!^!0``IP,`
M`*<&```@`````````*X```!+````$@```*8$```!`0``>`8```````#5`0``
MN@```.0#``"V`0````````````!H!`````````````"^````N0```'($````
M````$0```%\%``#F!```(`,``*L!``#F````(@(``)X&``"]`0``\@$``#D&
M``""!@```````($````2!```NP(``#T$``!_`0``&P```+,"````````O0,`
M`'4%``!E`@``A0````````#-`@``PP8``'\%````````5P(``)\%``#P`0``
MK0,```````"*!0``<@$``+$```"!!````````.\&````````$`<``&\"````
M````[0,````````0`@``%`$``"T#``!$!````````-4#``#?`@```````'L&
M``!)!0```````-H%``"'!````````+$&``#W`@``KP0```4"````````(0``
M`/L%``!W`0``/`,```D&``#S!0``\`(``'$%``"X`P```````-0#``#H`@``
M6`8```````![!```00,````````J`@``G`4``,8%``#9!0``804`````````
M````_P8``'H%``!'`@``/````+P```````````````\#``````````````\'
M```V!@``%`0`````````````80(```<'```S`P```````$`!```]!0``````
M`)H&`````````````(<!``#)````Z0,``.,&``"]````BP$``+T$````````
M-@,``#4"```=!0```````(8&``"N!```!P(``.L$``"_`P``````````````
M````200``%`&``"U!```<P4``,0#````````:P,``-H!``"P`0```````),%
M````````R08``*(%````````"0,``'T#```3````#00``,4!```+!```````
M`$$"``!5````X@4```````"L`P```P,``!D$```%!@````````````#J!```
MZP4```H#``"H!0``MP0``!8```!4!```-P$``%4%``"D`@``^0(```````"`
M`@``(P4``/L#``!#`0``:@0`````````````/P4``!,!````````\@,``,<$
M``"]!@```````$@#````````S0,``%T%``!\!```/`8``/D````>!0``1@$`
M``````"K````5@$``.@$``"-`````````,X#```W!@````````````#+````
MAP```-T#`````````````,P$````````40<````````9!0```````.<#```Q
M````S`,``(D%```0`0``#@```&H'``"G````SP0``&$'```7!@``V@```"$!
M``"B`@``F`(``%X$```M!```(@<``&4!``!X`@``$P<``!T$``#8!0``G`(`
M`%T`````````X`0``&8%```^!@``Y@(```````"R!0````````0#```>!```
M````````````````!`4```````"3`0``A08``'0#``"O`P``^08```````"2
M!```A0(``!T&````````W`,```````!;`0``6@<``!0#``#Q`@``,@<``'0%
M``"H`P``70$``"H&``````````````````"N!@``X`,``$X#``#\!```.0<`
M`'@$````````+P4``&<&``#4````H`(``/D#````````*`4``(4'``#L!0``
M<@(````````I``````````8"````````"@<``.4$````````408`````````
M````)@<```$&````````1@(``````````````````-<!``#-````-P,```0!
M````````*@<``'$'``!B!@```````($%``!N`0``KP(``,0$```N`@``500`
M`````````````````(0%```3!```D0(``%8&``#2````K@,``$@&```V!P``
M>P<```````#0!```&P4```````"Z!`````````````""`0`````````````C
M`@``6@$````````:!P``,0<``"`"``"H`@``)0<````````Z!```B0(``&L`
M``#Q!@``.04``#P!```1!0```````.0%``"*````'`$``*L$``")`P``!@4`
M```````B!0``70(```````#J`0```````/H$````````WP$``$<%````````
M$@8``(@```#I`@``-`0``.4#``"K!0``S04``,<#````````/P0`````````
M`````````.H"``"A`P``_@,``!@%```S````]04``'8'````````;@8`````
M``#+`P``;P$``!X#``!9!0```````(8```"#`0```````+0```"/`P``A`0`
M`#`$``"W`0``F0(``*`%``"V`@``Y0(````````R!```H0```"P"``#(`P``
M"P,```````",!0```````!H&``"L!```````````````````:P4```````#8
M`0````````X$```'!@```````"4```#A`P``G@``````````````<@4``!X&
M````````%0$``#X%```=````S`(``)X%``"(!@``C@(``"$%``"6`@``````
M`#\&``!`!@``H0$``*$%```G`@`````````````M````20<``)4"``!2!```
M```````````T`@``]P4``'0!``!=`P``-0$```````!.!```5@4``*($```)
M````PP4``(,#````````6`$``&D"``#L`P``&0(```````#"`@``60<``$,#
M```\!```D`$``.8!``#C`P``400`````````````K`(```X"```<`@``3@$`
M`$@$```*`````````$P&``#\`0``+@```(T!````````+`<``.T"``#I`0``
MSP$``&P"`````````````-H"``##`@``)P```+,#``"2!0```````&X````0
M`````````(T$```;`0``<`0``'4'`````P``W@4``%('``"R`P``!@<``(T#
M````````C0(``&<!``""`P``OP$``'8&``!N!```J@```$X"``!D!0``````
M`(P#```N!P``@@0```````"\`P``/@0``!@"````````-P(``)(#``""````
M``0```````````````````\"```5`@``P@```+L#````````T`8``#`%``#N
M````P04```````!(!0``$@<``%@'```"!```7@$`````````````V0$``$D&
M``#Q!```;`8``#@%```Z!P``F@$``.$```"\`@``O@,``!8$````````````
M`)D%``#I!0``]0,```````!"!P``&0,``.P$``"5`P```@,```@&``"-!@``
M`````&L&``!?!P``+@$``"4&````````9`8``&D#````````7@8``+4#```*
M`@``20(``!\````+!@``9`$`````````````3P(`````````````I@4``#`&
M``"Q`0``#`8``-(!```U!0``A@$``%P`````````.@8``.8#```:!0``NP0`
M`*T"````````@````'H#``"'!@```````(,&``#=`0``-0,``.\!````````
M``````P```"6`P``8P(``)X"``#Q!0``````````````````9`0`````````
M````Z0```+8%``"A!@```````!X!``#!`P``.P8``'`%``"$`0``:P(`````
M``!-!```Y@8```````#&!@``CP$```````##````'0<```````!C!```<P<`
M```````-!0``/0$``$\'``!M`P``(08``$0````5!P````````````#8`@``
M20```#L#```7!````````.\```!J!@````````H%``!3`P``!P4``"0%``"U
M!@``J00```<$``!'`0``0P8``````````````````"`%````````L````*\`
M```O!@``[@8``.,`````````(@8``!(#``#!!```V08`````````````?P,`
M``P$```8`P``K`$```````"Y`0``X@8``,X`````````D@$``'X'``#%`@``
M`@4````````T`0```````*@````L`0``#@,```````"0!```&0$``*(```!0
M!0```````.D&``#5`@``````````````````"00``)D!``";`P``J@$```P"
M``#4!0``]`4``/4!```-`P```````)T!``#%`````````,8"``!7````.```
M`"@"`````````````/T#``"G!```NP4```````#"!0```````$\!```=`0``
M[`8``/@&``"6!```4`0```````"M`0````````````"D`0``J04``+`"``!C
M!@```````-8#```6!0``I@,````````:`@````4```````"&!P``@`<``-`%
M``#C`0``K`8``.,"``#`!@``JP(``'`#``"0!0``KP$```````#2!0``H@8`
M``````"U!0```````,X%``!M!0```````/@"````````W08`````````````
M'P,``'T'``"T!```I@8```````#$!0``IP$``$,```"=`P``&P(```````!,
M!`````````(!``"7`@``3P4``$`#``!Y!@``W`(```````!&!P``8P4``'\&
M``!$`P``Y0```$T%``#"!@```````````````````````-````!;`P``MP``
M`'D"``!#!0```````%(&``#6!0``2@(``#T````M!0```````'H&``#@`@``
M8`0``!H#``````````````````##!````````-,#``#B`@``>`,``)0```"'
M!P``&@0```````````````````````!!!```&08`````````````4`<`````
M```I`P``_0```%<#`````````````"$'``!1`P``.@(``),```#S`0``50(`
M````````````#08```````"9!````````$(!``!?`@``2P0``$L'``!N!0``
ML0,```````"$`@``308````````F`0```````-L!````````L04``'`'``#<
M!```:04``+,&```G!0``/`<``$,'``!*`P``:00``,\#````````:`(``*\%
M``"`!```=@,``-$#``!0`P``F`$``.$"``!,`@``P@0```````"(!```:P<`
M`'(```````````````````#Z`@```````#(%``!H`P``!0<``",#``!\!@``
M`````.@#``"7!```M0$``,H&``#/`@``*`$``)<!``#+`0```````%8'``!3
M`@``6@,``(8%````````,`(``/@```"9`````````,P```"N`@``-`4`````
M``#7`````````*4%```````````````````D!@``F`8``.X!```A`P``.P``
M`)<&``!!`0``Q@,``(P"```$!P``%04``&4%```````````````````B`P``
MB@(``!X```"#!P``50<``*T%``!%````=08``#@$``##`0``U`$``$(```!E
M!```)P<``&\%``#U!@``5@````X!``#Y!0``30(``/X$``!:`@``HP4```0&
M``#H!0``(@```$4%````````2@8``)@$``";!@``P0(```,$````````````
M`+P&``!N`P``%`8``.T&````````?04``.@````T`P``6@4``!(%```/`0``
M'@(```````!H!0```````"\!```]`@``30$``#`!```E`@``U0`````````E
M!0``9@,``/8```!Z`@``C@8`````````````HP(```````"N`0``_`,``&$!
M``"X````D0```````````````````)4````F`P``#P``````````````B@,`
M``````!]`@``QP4``,8!````````A@,``"`'``">`0```````-L"``#)`0``
M"@$``%4#``!Y````U`0``,,#````````R@$``!,#``````````````````!M
M!P``\`0``'8$```(`P```````#T&``#8!````````*$"``!M````CP4``!<'
M````````5P<``"H$```"````8`(``!P%````````^`4``$X%````````R```
M``P#``"+`@```````*4#```(!0```````#D#``#_`0``#@<``%T$```)`@``
M`````$P```":!```T0$``"D%``#G!0```````'@`````````9@$``/````#N
M!0``2P(``+<%```%!0```````%(```#K`P``2P4``-0&```Y````R`0``)T%
M``#``@``7@<```,!``!W!@``1`4``-X&``````````````<````V!0``*P,`
M`/H```#'!@``%`<```(&``#*````>`$``!(!``#W`P``Y04``*H&``!3!```
M4@$````````&`P``N0(``$T'```4````D0,``*H"``!<!```UP0``#H#```P
M`P``]````$`$````````W@(``+`&`````````````-L%``!A!@``P`,``,H#
M``#M!```6P0``)0!``"(`P``9P<``(0'`````````````!,%``",!@``I`0`
M`#`'``"*`0``0P0``)L````@!@``\@(``'0&`````````````+8$````````
M$`,``.H&``!@!0```````/L$``"4!@``X04``"D&`````````````/<$````
M````N@(```````"T`0``1`8```````"M!@``508``#P%````````00```#8$
M````````,@(````````!!0```````(X%```=`P``IP(`````````````4@,`
M`"8&``#3!0``^@8```````"H`0``8P,``!$$`````````````%,&```G`0``
MLP4```````#E!@``TP(```````"'!0``@P(``+@&``!8`P``@0$```````#N
M!```)`(``-(&````````-0```+L&``#)`@``J0,``%D`````````,0$`````
M``#@!@``L@8```L%``!%`0``6@8``+@$```U!@```````%D&````````9```
M`",&``#'`@```````)T```#_````!0$``$`"``")!```:0```-<%```@`0``
MG@0```````"2`@``%`4````````Z`0``SP4````````6`0```````'@%``#'
M````RP8`````````````7@4``",$``#V`P``*@4``.<```#`!```J08``!P&
M``!*`0``,08````"``!G`P``W@0``#8"`````````````/L```"K!@``E08`
M`%$"````````,@8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E
M<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@
M9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I
M;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN
M9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D
M9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE
M;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S
M<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE
M;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL
M(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L
M=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L
M=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N
M(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L
M:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O
M=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U
M-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R
M=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT
M(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I
M8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T($E-05`@
M<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@8GD@
M4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E<B!F
M86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R(&9A:6QE
M9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X8W5S97,`
M0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S
M=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`
M0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-E
M(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S96QI;F4`
M0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!"
M:7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O
M=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!"
M;V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S
M;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V
M970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O
M<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@3&ES=`!"
M=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@
M4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W87,@;F]T
M(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#
M86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@
M>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I;&4@(B5S
M(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N
M`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T(&]P96X@
M9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R
M=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T87)G
M971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y("(E
M<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E
M(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D90!#87!T
M:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)<VQA
M;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`
M0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;'1I
M8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P=6)L
M:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@
M1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE
M<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@=&AE
M(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE>2!R
M96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U<B!P
M87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@8V]N
M9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#:&%R
M`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE
M9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@
M07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N
M86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@
M<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA
M;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L
M96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S97(Z
M("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA=&4`
M0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S92!7
M:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME96QI
M;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R
M<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO
M;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@
M4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M
M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF
M9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L
M(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U
M="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG
M;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE
M8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R
M969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E
M<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`
M0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R
M97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I;&4Z(`!#
M;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;V]K:64`
M0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S="!)1`!#
M;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK
M("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N
M=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#
M<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S
M97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@
M:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD
M:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E
M;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N
M=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E
M;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS
M(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@
M:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@8W5R<F5N
M="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D('-E='5P
M('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N;6%R:P!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O
M(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E
M9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN
M=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C
M=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I
M<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N
M<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@
M*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N
M`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S
M<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@
M=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;VUI
M;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A8V-O=6YT
M/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@
M;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@9')I=F5R
M+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I8V4N`$52
M4@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R
M;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R
M("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E
M<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L
M(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D<F5S<P!%
M;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C;VYF:7)M
M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M<'1Y(&UE
M<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L
M92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN
M('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y
M96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@
M=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@
M>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R
M('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@=&AE(&QE
M='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`
M17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@
M86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@
M9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@
M)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E
M<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M
M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!A;F0@
M4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U
M;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@
M0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P
M<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N
M`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C
M;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D
M('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V
M92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`1F%L:VQA
M;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R
M;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z
M(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA=')I>`!&
M:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL92!#;W5N
M=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`
M1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER<W0@2&%L
M9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O9P!&;VQD
M97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O<B!B<F]W
M<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T("A4048I
M`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@9F]R96-A
M<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@;G5M8F5R
M(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R9V]T('EO
M=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E`$9O<G1U
M;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE<P!&<F%N
M8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&<F5N8V@@
M4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R
M;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`
M1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M
M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`
M1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L
M;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A
M<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N
M;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S
M(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@
M9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U
M<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`
M1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!
M<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@
M:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!
M=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM
M`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(
M;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@
M061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO
M;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T
M82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M
M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D
M92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+
M;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O
M;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R
M96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA
M8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B
M.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E
M<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N
M=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D
M:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O
M;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD
M<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO
M=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T
M<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q
M=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@
M4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC
M;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D
M:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I
M;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N
M970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T
M;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@
M;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U
M<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA
M9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G
M86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E
M<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C
M;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R
M>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@
M;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I
M=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R
M;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F
M=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK
M`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F
M=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N
M;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A
M9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W
M;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS
M97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@
M;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R
M87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E
M`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q
M=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI
M;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB
M=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E
M9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV
M86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A
M=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I
M;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L
M:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI
M9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI
M9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI
M<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O
M9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B
M`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N
M`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C
M=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)
M<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET
M86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE
M=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H
M`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5
M<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!2
M86EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A
M:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`
M3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI
M<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I
M;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P
M<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K
M<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W
M;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO
M;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA
M=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-
M`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-
M4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@
M;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`
M36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B
M96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG
M<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!
M;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG
M(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D
M:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.
M=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y
M;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`
M365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`
M365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-
M971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI
M;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-
M:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN
M`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I
M;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-
M;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD
M('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO
M<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D
M>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ
M=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA
M<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN
M9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`
M3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.
M971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E
M(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`
M3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@
M36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@
M<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@
M<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE
M=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS
M`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`
M3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W(&1I9F9E
M<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@
M25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T
M<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@
M<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`
M3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`
M3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.
M;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I
M8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P
M<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I
M960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE
M<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U
M=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P
M<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W
M;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO
M('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`
M3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E
M<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM
M,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R
M90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J
M96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT
M97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E
M<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C
M="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E;6%I;"!A
M9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E;2!A9&UI
M;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R('!E<FUI
M<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W`$]P96Y3
M4TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@
M4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`
M3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R
M960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A
M;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R:6=I;F%L
M('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I;VX`3W=N
M97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3:6=N871U
M<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N
M960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT
M(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W
M97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES
M<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T
M:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U
M:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D
M(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S
M<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S
M<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O
M87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@
M(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO
M;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M
M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C
M86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE
M(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@
M=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O
M('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N
M9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T
M96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S
M92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y
M<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L
M96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E
M('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E
M860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H
M92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G
M86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0
M<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q
M=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0
M<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO
M;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M
M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`
M4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0
M<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U
M97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)3
M02!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A
M:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`
M4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M
M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`4F5L871I
M;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`
M4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E
M;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T
M=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R
M=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@
M=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V
M92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U
M<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@
M8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C
M;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE
M9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E
M="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1
M=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S
M<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@
M161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG
M:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T
M871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I
M97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B
M971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD
M80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y
M<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL
M86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E;65N="!F
M;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL`%-A`%-A
M:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`
M4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T
M:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`4V%N($UA
M<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R;W9I9&5R
M`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A=F4@3W!T
M:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C
M<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A
M=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A9&4@<V-R
M:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R
M8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;`!3
M96QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B:F5C=`!3
M96QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE960@9G)O
M;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N9"!P87-T
M92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D871E(&1E
M;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!I
M9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@=&EM92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@
M;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E
M;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)B
M:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@9&%T82!W
M<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E<W-I;VX@
M240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O(&%L;&]W
M('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R(&9O<F=E
M="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A;G0@=&\@
M86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E<G)E9"!L
M86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T('EO=7(@
M<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P`%-E='5P
M('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A=&EO;G,@
M<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE<P!3:&]P
M<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I
M;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T
M=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@
M8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G
M:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC
M:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@
M)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0<F]P
M97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I86QO
M9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T
M:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO=V5R
M<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN('1H92!6
M:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L
M;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N
M('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3
M:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=P!3
M;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N
M;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@
M:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG<R`F(%!O
M96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S`%-O=71H
M($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&@@1V5O
M<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U=&AE<FX@
M2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E
M(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P
M86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P96-I86P@
M0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET
M(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E:P!3=&%R
M="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E(&9O<FUA
M=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L:7-T`%-T
M<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=`%-U`%-U
M8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M:70`4W5B
M;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U
M(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B965N(&%P
M<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@861D960@
M(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E9"!D871A
M(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@
M9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B(&9R;VT@
M=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I
M;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V960@=&AE
M(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F=6QL>2!U
M<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N`%-U;6UA
M<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I<V4O4W5N
M<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I<'0`4W5P
M<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@36%Y96X`
M4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D96QE=&5D
M`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!
M<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R
M;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R=&EE<P!4
M86)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V
M:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@
M9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M
M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T
M92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X
M=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV
M,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B
M;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E
M+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E
M<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE
M($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL
M>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE
M(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT
M(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI
M<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N
M=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO
M="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C
M97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A
M8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF
M>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)
M1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T
M(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T
M('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R
M97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S
M:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L
M9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A;FYO="!B
M92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I
M<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO
M<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE
M('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E
M(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N
M9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O
M=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N
M97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<
M;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO
M=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4
M:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH
M86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R
M>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`5&AE
M(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S(B!H
M87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H870@
M=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4:&4@
M;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A9V4`
M5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@;W!E
M;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S
M;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B
M92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M
M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`
M5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C
M=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M
M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG
M;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I
M960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T;W`@
M86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!U
M<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P
M+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H92!W
M96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@9&ER
M96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A
M=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P
M;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I
M;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[
M('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O
M8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@
M82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M('1H
M92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN
M9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@
M=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H
M86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E
M('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W
M87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O
M<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S
M('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@
M97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F
M=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N
M(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N
M`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O
M;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!724X@
M*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S
M96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O9&%F
M;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@
M270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE($ET
M86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI
M<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C;VQO
M;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`
M5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D
M(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@
M;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@
M:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N
M`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI<R!I
M<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O('9I
M97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@
M=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA="X@
M1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I<VET
M("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S
M970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T
M(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S
M<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L
M>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4
M:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN
M9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM92!F
M;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@
M*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@
M9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H
M:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4
M;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G:6YS
M(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?=&]P
M*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A
M;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U
M<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y
M<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U
M<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5
M:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE
M('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U
M<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I
M>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E
M<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S
M(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE
M('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T
M:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B
M)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I
M<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E
M8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D
M96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL
M92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T
M;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R
M;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R
M=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO
M;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O
M<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@
M9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F
M:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@
M86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L
M92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@
M5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`
M56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N
M9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E
M("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`
M56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES
M;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S
M<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$
M*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M
M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN
M86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#
M;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N
M<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL
M;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@
M=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R
M=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P
M9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P
M;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R
M=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`
M57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P
M87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S
M97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T
M<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E
M9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@
M86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN
M('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO
M="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU
M9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU
M92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A
M;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L
M80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E
M(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`
M5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R
M>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6
M:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES
M;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET
M>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!7
M05).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.
M('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE
M<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC
M;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`
M5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/
M+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO
M=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`
M5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G
M:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H
M`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD
M($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O
M;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG
M(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O
M=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93
M(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@
M17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X
M=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`
M665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;
M/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E
M(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE
M("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@
M86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R
M97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@
M;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB
M97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@
M:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R
M964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E
M(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M
M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@
M;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`
M66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S
M="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C
M=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y
M(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N
M=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E
M<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA
M<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S
M:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN
M(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD
M(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T
M;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@
M;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E
M;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D
M+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@
M<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R
M('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E
M96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO
M=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9
M;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!:
M:6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@4F5P
M;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT("T@
M)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`7T-,
M20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA9V4@
M4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN:RXN
M+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3971U
M<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K`&%D
M9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T92!O
M=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O;6UA
M;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R:71I
M8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`961I
M=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E
M<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W;@!I
M;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA;"!S
M;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D('=H
M:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y
M970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@9&5N
M:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG`'-E
M<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@
M=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M
M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N
M9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`=V5A
M=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$N,2UC=G,*
M4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4
M+4-R96%T:6]N+41A=&4Z(#(P,#8M,#,M,3(@,#`Z,S$K,#$P,`I03RU2979I
M<VEO;BU$871E.B`R,#`V+3`S+3$S(#(R.C0P*S`Q,#`*3&%S="U4<F%N<VQA
M=&]R.B!*86X@2W5I<&5R<R`\:G)K=6EP97)S0&QA=7=E<G-C;VQL96=E+FYL
M/@I,86YG=6%G92U496%M.B!$=71C:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*`"`H)7,@9&%G96X@9V5L961E;BD`("A3;F5L=&]E=',@)7,I`"`H
M8FEN;F5N("5S(&1A9V5N*0`@*'9A;F1A86<I`"`H;6]R9V5N*0`@*&=I<W1E
M<F5N*0`@;W`@`"(E<R(@:7,@9V5E;B!D:7)E8W1O<GDN`"(E<R(@:7,@9V5E
M;B!G96QD:6=E(&ME=7IE+@`B)7,B(&ES(&YI970@9V5C;VYF:6=U<F5E<F0@
M:6X@:&5T($AO<F1E(')E9VES=&5R+@`B)7,B('1R964@=V5E<F=E=F5R(&YI
M970@9V5V;VYD96XN`"(E<R(@86%N(&AE="!G<F]E<&5N<WES=&5E;2!T;V5G
M979O96=D+@`B)7,B(&%A;B!H970@<F5C:'1E;G-Y<W1E96T@=&]E9V5V;V5G
M9"X`(B5S(B!I<R!N:65T(&%A;F=E;6%A:W0Z("5S+@`E+C)F34(@9V5B<G5I
M:W0@=F%N("4N,F9-0B!T;V5G97-T86%N("@E+C)F)24I`"5D("5S(&5N("5S
M`"5D(&1A9V5N('1O="!U=R!W86-H='=O;W)D('9E<G9A;'0N`"5D+61A9R!V
M;V]R=6ET>FEC:'0`)7,@+2!/<&UE<FMI;F<`)7,@=FEN9V5R869D<G5K`"5S
M($M"`"5S($]N9&5R:&]U9'-W97)K>F%A;6AE9&5N("T@0F5V97-T:6=I;F<`
M)7,@26YS=&5L;&5N`"5S(&EN<V-H<FEJ=F5N`"5S(&=E8G)U:6ME<G-O=F5R
M965N:V]M<W0`)7,@8F5S=&%A="!A;"X`)7,@;W`@)7,@)7,`)7,@:7,@9V5R
M965D(&]M(&]N9&5R<W1A86YD92!G97-E;&5C=&5E<F1E(&]N9&5R:&]U9'-W
M97)K>F%A;6AE9&5N('5I="!T92!V;V5R96XN(%9I;FL@9&4@8F5W97)K:6YG
M*&5N*2!A86X@9&EE('4@;W`@9&ET(&UO;65N="!W:6QT('5I='9O97)E;BX`
M)7,@:7,@=F5R96ES=``E<R!M:6YU=&5N`"5S(&YI970@9V5V;VYD96XN`"5S
M('1O="`E<R!V86X@)7,`)7,G<R!A9')E<V)O96L`)7,G<R!A9V5N9&$`)7,G
M<R!N;W1I=&EE8F]E:P`E<R=S('1A:V5N;&EJ<W0`)7,Z("5S`"5S.B!$:70@
M8F5R:6-H="!K;VUT(&UI<W-C:&EE;B!N:65T('9A;B!D96=E;F4@9&EE(&AE
M="!B97=E97)T('1E('II:FXN(%=E97,@=F]O<GII8VAT:6<@8FEJ(&AE="!K
M;&EK:V5N(&]P(&QI;FMS(&EN(&AE="!B97)I8VAT(&]F(&1E(&%F>F5N9&5R
M('!E<G-O;VYL:6IK92!I;F9O<FUA=&EE('1E('-T=7)E;BX`+"!W:6YD=FQA
M9V5N(``L('=I;F1V;&%G96X@)7,@)7,`+"!V87)I86)E;"!V86X@)7,@=&]T
M("5S`"TM('-E;&5C=&5R96X@+2T`,3(@=75R<W=E97)G879E`#(T('5U<G-W
M965R9V%V90`R-"!U=7)S`#Q6;W)I9V4`165N(&1A=&%B87-E(&)A8VME;F0@
M:7,@=F5R96ES="!V;V]R(&1I="!B;&]K+@!%<B!H965F="!Z:6-H(&5E;B!F
M871A;&4@9F]U="!V;V]R9V5D86%N`$5E;B!O<&5N8F%R92!01U`@<VQE=71E
M;"!I<R!V97)E:7-T(&]M(&5E;B!B97)I8VAT('1E(&-O9&5R96XN`$5E;B!O
M<&5N8F%R92!01U`@<VQE=71E;"!I<R!V97)E:7-T(&]M(&5E;B!O;F1E<G1E
M:V5N9"!B97)I8VAT('1E('9E<FEF:>MR96XN`$5E;B!O<&5N8F%R92!01U`@
M<VQE=71E;"P@<')I=ND@4$=0('-L975T96P@96X@=V%C:'1W;V]R9')E9V5L
M('II:FX@=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!D96-O9&5R96XN`$5E
M;B!O<&5N8F%R92!01U`@<VQE=71E;"P@<')I=ND@4$=0('-L975T96P@96X@
M=V%C:'1W;V]R9')E9V5L('II:FX@=F5R96ES="!O;2!E96X@8F5R:6-H="!T
M92!O;F1E<G1E:V5N96XN`$5E;B!O<&5N8F%R92!3+TU)344@<VQE=71E;"P@
M<')I=ND@4R]-24U%('-L975T96P@96X@=V%C:'1W;V]R9')E9V5L('II:FX@
M=F5R96ES="!O;2!E96X@8F5R:6-H="!T92!D96-O9&5R96XN`$5E;B!O<&5N
M8F%R92!3+TU)344@<VQE=71E;"P@<')I=ND@4R]-24U%('-L975T96P@96X@
M=V%C:'1W;V]R9')E9V5L('II:FX@=F5R96ES="!O;2!E96X@8F5R:6-H="!T
M92!O;F1E<G1E:V5N96XN`$5E;B!O<&5N8F%R92!334E-12!S;&5U=&5L(&ES
M('9E<F5I<W0@;VT@965N(&)E<FEC:'0@=&4@8V]D97)E;BX`0F5W;VQK:6YG
M('9O;W(@,3(N,#`@=75R`$QI8VAT92!R96=E;B!V;V]R(#$R+C`P('5U<@!2
M96=E;B!V;V]R(#$R+C`P('5U<@!"=6EE;B!V;V]R(#$R+C`P('5U<@!3;F5E
M=7=B=6EE;B!V;V]R(#$R+C`P('5U<@!!32]030!!4$D@240`3W9E<B!D97IE
M(&5D:71O<@!/=F5R+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`5&]E9V%N9R!G
M97=E:6=E<F0@8FEJ(&AE="!M86ME;B!V86X@5D93(&1I<F5C=&]R>2X`5&]E
M9V%N9R!G97=E:6=E<F0@8FEJ(&AE="!M86ME;B!V86X@5D93(&)E<W1A;F0N
M`$%C8V]U;G1I;F9O<FUA=&EE`$%C8V]U;G1W86-H='=O;W)D`$%C8V]U;G0@
M8F5V<F]R96XN`%9E<F%N='=O;W)D:6YG`%1O979O96=E;@!#:&EL9"!G<F]E
M<"!T;V5V;V5G96X`0VAI;&0@<F5C:'0@=&]E=F]E9V5N`$AI97(@=&]E=F]E
M9V5N.@!.:65U=V4@9W)O97`@=&]E=F]E9V5N`$YI975W(')E8VAT('1O979O
M96=E;@!%96X@(F-H:6QD9W)O97`B(&%A;B`B)7,B('1O979O96=E;@!%96X@
M(F-H:6QD<F5C:'0B(&%A;B`B)7,B('1O979O96=E;@!.:65U=V4@9V5B<G5I
M:V5R('1O979O96=E;CH`2V]L;VT@=&]E=F]E9V5N`$YI975W92!L961E;B!T
M;V5V;V5G96X`4&%A<B!T;V5V;V5G96X`2&5T("5S(&UE;G4@=&]E=F]E9V5N
M(&%L<R!E96X@36]Z:6QL82!3:61E8F%R`%9O96<@=&]E(&%A;B!A9')E<V)O
M96LZ`%9O96<@=&]E(&%A;B!M:6IN(&%D<F5S8F]E:P!'96)R=6EK97(@=&]E
M=F]E9V5N`"(E<R(@86%N(&AE="!S>7-T965M('1O96=E=F]E9V0L(&UA87(@
M:V]N(&=E96X@97AT<F$@:6YS8VAR:6IV:6YG<VEN9F]R;6%T:64@=&]E=F]E
M9V5N.B`E<RX`(B5S(B!A86X@:&5T('-Y<W1E96T@=&]E9V5V;V5G9"X@52!K
M=6YT(&YU(&%A;FUE;&1E;BX`5&]E=F]E9V5N('9A;B!G96)R=6EK97)S(&ES
M('5I=&=E<V-H86ME;&0N`$%D<F5S`$%D<F5S8F]E:P!"96AE97(@+2!R96-H
M=&5N('9O;W(@86YD97)E(&=E8G)U:6ME<G,@:6YS=&5L;&5N`$)E:&5E<@!!
M9'9E<G1E;G1I97,`069G86YI<W1A;@!!;&)A;FGK`$%L9V5R:6IE`$%L:6%S
M`%5I=&QI:FYE;@!5:71L:6IN:6YG.@!!;&QE`$%L;&4@9V5A=71H96YT:6-E
M97)D92!G96)R=6EK97)S`$%L;&4@9W)O97!E;@!!;&QE(')E8VAT96X`06QL
M92!V:65R('II:F1E;@!-965R9&5R92!A9')E<W-E;B!T;V5S=&%A;@!);G-T
M96QL96X@=F%N(&=E;W)D96YD92!L:6IS="!T>7!E('1O97-T86%N/P!"97-T
M86%T(&%L`$%L=&5R;F%T:65V92!)35-0(&%A;FUE;&1I;F<`06QT97)N871I
M968@24U34"!W86-H='=O;W)D`$%L=&5R;F%T:65V92!)35-0(&=E8G)U:6ME
M<G-N86%M`$%L=&5R;F%T:65F(&4M;6%I;&%D<F5S`$%L=&5R;F%T:65V92!S
M:F%B;&]N96X`06QT97)N871I979E('1E:W-T.@!!;65R:6MA86YS(%-A;6]A
M`$5E;B!O;F=E;&1I9V4@=V%A<F1E(&]P9V5G979E;BX`17(@:&5E9G0@>FEC
M:"!E96X@;VYB96ME;F1E9F]U="!V;V]R9V5D86%N+@!!;F1O<G)A`$%N9V]L
M80!!;F=U:6QL80!!;F]N:65M92!P<F]X>0!!;G1W;V]R9`!!;G1A<F-T:6-A
M`$%N=&EG=6$@96X@0F%R8G5D80!4;V5P87-S:6YG`%1O97!A<W-I;F=E;FQI
M:G-T`%1O97!A<W-I;F<@:7,@9V5R965D+@!/<"!C:&EL9'-H87)E<R!T;V5P
M87-S96X`1V]E9&ME=7)E;@!'97-C:&%T=&4@9W)O;W1T90!!<')I;`!!<F%B
M:7-C:"`H5VEN9&]W<RTQ,C4V*0!!<F-H:65F8F5S=&%N9'-G<F]O='1E`$%R
M8VAI969N86%M`%=E970@=2!Z96ME<B!D870@=2!H970@86%N;65L9&EN9W-V
M97)Z;V5K('9A;B`E<R!W:6QT('9E<G=I:F1E<F5N/P!7965T('4@>F5K97(@
M9&%T('4@(B5S(B!E;B!A;&QE('-U8F=R;V5P96X@=VEL="!V97)W:6ID97)E
M;C\`07)G96YT:6YIZP!!<FUE;FGK`$%R;65E;G,@*$%235-#24DM."D`2W5N
M<W0`07)U8F$`07-C96YS:6]N(&5I;&%N9`!!<V-I:2!K=6YS=`!!>FGK+U!A
M8VEF:7-C:&4@4F5G:6\`3VT@8F5V97-T:6=I;F<@=G)A9V5N('9O;W(@:&5T
M('5I='9O97)E;B!V86X@;VYD97)H;W5D<W=E<FMZ86%M:&5D96X_`$]P9')A
M8VAT(&MO;&]M;65N`%!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N9&4@9W)O
M97`@=&4@=F5R=VEJ9&5R96XN`%!O9VEN9R!O;2!E96X@;FEE="!B97-T86%N
M9"!R96-H="!T92!V97)W:6ID97)E;BX`4&]G:6YG(&]M(&5E;B!N:65T(&)E
M<W1A86YD(')E8VAT('1E(&)E=V5R:V5N+@!0;V=I;F<@;VT@965N(&YI970@
M8F5S=&%A;F1E('-H87)E('1E(&)E=V5R:V5N+@!!='1R:6)U=&5N`$%U9W5S
M='5S`$%U<W1R86QIZP!/;W-T96YR:6IK`$%U=&A?8WER<W%L.B!V97)E:7-T
M92!I;6%P(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?8WER=7,Z(&)A
M8VME;F0@:&5E9G0@;FEE="!D92!V97)E:7-T92!B96MW86%M:&5D96XN`$%U
M=&A?8WER=7,Z('9E<F5I<W1E(&EM87`@97AT96YT:64@;FEE="!G979O;F1E
M;BX`075T:%]F='`Z('9E<F5I<W1E($944"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+B!#;VUP:6QE97(@4$A0(&UE="!D92`M+65N86)L92UF='`@;W!T:64N
M`$%U=&A?:6UA<#H@=F5R96ES=&4@24U!4"!E>'1E;G1I92!N:65T(&=E=F]N
M9&5N+@!!=71H7VMR8C4Z('9E<F5I<W1E(&MR8C4@97AT96YT:64@;FEE="!G
M979O;F1E;BX`075T:%]L9&%P.B!T;V5V;V5G96X@=F%N(&=E8G)U:6ME<G,@
M=V]R9'0@;FEE="!O;F1E<G-T975N9"!V;V]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!697)W:6ID97)E;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N
M:65T(&]N9&5R<W1E=6YD('9O;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD
M87`Z('9E<F5I<W1E($Q$05`@97AT96YT:64@;FEE="!G979O;F1E;BX`075T
M:%]L9&%P.B!.:65T(&EN('-T86%T(&=E8G)U:6ME<B`E<R!T;V4@=&4@=F]E
M9V5N+B!$92!S97)V97(@;65L9'0Z(`!!=71H7VQD87`Z($YI970@:6X@<W1A
M870@9V5B<G5I:V5R("5S('1E('9E<G=I:F1E<F5N`$%U=&A?;&1A<#H@3FEE
M="!I;B!S=&%A="!G96)R=6EK97(@)7,@8FEJ('1E('=E<FME;@!!=71H7VQD
M87`Z($)I:G=E<FME;B!V86X@9V5B<G5I:V5R<R!W;W)D="!N:65T(&]N9&5R
M<W1E=6YD('9O;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!V97)E
M:7-T92!-0T%,(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$%U=&A?<VUB875T
M:#H@=F5R96ES=&4@<VUB875T:"!E>'1E;G1I92!N:65T(&=E=F]N9&5N+@!!
M=71H96YT:6-A=&EE(&]P($E-05`@<V5R=F5R(&UI<VQU:W0N`$%U=&AE;G1I
M8V%T:64@;6ES;'5K=`!!=71H96YT:6-A=&EE(&UI<VQU:W0N("5S`$%U=&AE
M;G1I8V%T:64@9V5W96EG97)D(&1O;W(@9&4@4D%$2553('-E<G9E<BX`075T
M:&5N=&EC871I92!O<"!&5%`@<V5R=F5R(&UI<VQU:W0N`$%U=&AE;G1I8V%T
M:64@;W`@9&4@4TU"('-E<G9E<B!M:7-L=6MT+@!"97-C:&EK8F%R92!V96QD
M96XZ`$%Z97)B86ED>FIA;@!"3T9(($5X8W5S97,`06-H=&5R9W)O;F0`06-H
M=&5R9W)O;F1K;&5U<@!&;W5T(&ME<F)E<F]S=V%C:'1W;V]R9"X`1F]U=&4@
M:V5R8F5R;W-G96)R=6EK97)S;F%A;2X`0F%H86UA<P!"86AR96EN`$)A;'1I
M<V-H("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O<P!"87-I<R!A
M9F)E96QD:6YG96YD:7)E8W1O<GD@(B5S(B!N:65T(&=E=F]N9&5N+@!"87-I
M<VQI:FX`5VET(')U<VQA;F0`0F5L9VGK`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!697)J86%R9&%G`$)L;VL@(B5S(B!V86X@=&]E<&%S<VEN9R`B
M)7,B(&YI970@9V5V;VYD96XN`$)L;VMI;G-T96QL:6YG96X`0FQO:W1Y<&4`
M5F5T`$)O;&EV:6$`0F]O:VUA<FMS`%)A;F0`4F%N9&1I:W1E.@!286YD96X`
M0F]S;FGK(&5N($AE<GIE9V]V:6YA`$)E:61E;@!";W1S=V%N80!/;F1E<FMA
M;G0`0F]U=F5T(&5I;&%N9`!"<F%Z:6QIZP!"<FET<R!);F1I<V-H92!/8V5A
M86X@5&5R<FET;W)I=6T`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6IE`$]N
M9V5O<F1E;F1E(&QI:G-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`
M0U),($1I<W1R:6)U=&EE<'5N=&5N`$-?96QE:6=E;G-C:&%P<&5N+BXN`$-A
M8VAE(&EN:71I86QI<V%T:64@:7,@;FEE="!A9F=E<F]N9"X`06=E;F1A`$MA
M;&T`0V%M8F]D:F$`2V%M97)O96X`2V%N('=A8VAT=V]O<F0@;FEE="!A=71O
M;6%T:7-C:"!R97-E='1E;BP@;F5E;2!C;VYT86-T(&]P(&UE="!D92!S>7-T
M965M8F5H965R9&5R+@!+86X@;FEE="!N86%R(&)E<W1A;F0@(B5S(B!S8VAR
M:6IV96X`2V%N(&=E96X@97AT97)N92!S97-S:65H86YD;&5R(&)E:&5R96XN
M`$MA;B!N:65T('9E<F)I;F1E;B!M970@24U!4"!S97)V97(Z("5S`$MA;B!B
M97-T86YD("(E<R(@;FEE="!O<&5N96XN`$-A;F%D80!!9F)R96ME;@!0<F]B
M;&5E;7)A<'!O<G0@869B<F5K96X`2V%N(&)E<W1A;F0@(B5S(B!N:65T('9E
M<G=I:F1E<F5N+@!+86X@9V5E;B!T:6ID96QI:FME(&1I<F5C=&]R>2!V:6YD
M96XN`$MA;B!N:65T(&1O;W)G86%N('IO;F1E<B`G=&%R9V5T1FEL92<@<&%R
M86UE=&5R+@!+86X@9&ER96-T;W)Y("(E<R(@;FEE="!V97)W:6ID97)E;BX`
M2V%N(&YI970@=F5R=VEJ9&5R96X[("5D(&-H:6QD<F5N(&)E<W1A86XN`$MA
M;B!N:65T(&]P;FEE=7<@<F%N9W-C:&EK:V5N+"!H970@86%N=&%L(&EN=F]E
M<F5N(&]M(&]P;FEE=7<@=&4@<F%N9W-C:&EK:V5N(&MO;70@;FEE="!O=F5R
M965N(&UE="!H970@;W!G97-L86=E;B!A86YT86PN`$MA;B!B97)I8VAT(&YI
M970@;F%A<B!H970@;W!G96=E=F5N(&YU;6UE<B!V97)S='5R96XN`$MA87`@
M5F5R9&4`3W!S8VAR:69T`$1R86=E<@!#871E9V]R:67K;B!E;B!L86)E;',`
M0V%Y;6%N(&5I;&%N9&5N`%1E;"YN<BYM;V)I96P`0V5L96EG96YS8VAA<'!E
M;@!#96P@=G)I:F4@<G5I;71E.@!#96QE:6=E;G-C:&%P<&5N`$-E;'-P871I
MZW)I;F<Z`%1E;"YN<BYM;V)I96P`2V5L=&ES8V@@*$E33RTX.#4Y+3$T*0!-
M:61D96X`0V5N=')A86P@069R:6MA86YS92!297!U8FQI96L`0V5N=')A86P@
M175R;W!E97,@*$E33RTX.#4Y+3(I`$-E<G1I9FEC86%T9&5T86EL<P!#97)T
M:69I8V%A=&5I9V5N86%R`$-E<G1I9FEC86%T8F5L96ED`%1S:F%A9`!7:6IZ
M:6=E;@!7:6IZ:6<@=7<@=V%C:'1W;V]R9`!7:6IZ:6<@9&4@;F%A;2P@861R
M97,@96X@;VYD97)T96ME;FEN9R!D:64@;65N('II970@8FEJ(&AE="!L97IE
M;B!E;B!B96%N='=O;W)D96X@=F%N('5W(&4M;6%I;',N`%=I:GII9V5N('9A
M;B!U=R!W86-H='=O;W)D('=O<F1T(&YI970@;VYD97)S=&5U;F0@9&]O<B!D
M92!H=6ED:6=E(&-O;F9I9W5R871I92X@3F5E;2!C;VYT86-T(&]P(&UE="!U
M=R!S>7-T965M8F5H965R9&5R+@!+87)A:W1E<@!#;VYT7W)O;&5E<B!L:6YK
M+BXN`$-H:6QI`$-H:6YA`$-H:6YE97,@=F5R965N=F]U9&EG9"`H1T(R,S$R
M*0!#:&EN965S('1R861I=&EO;F5E;"`H0FEG-2D`2VEE<R!T;V5P87-S:6YG
M.@!+:65S(&5E;B!W86-H='=O;W)D`$MI97,@965N(&=E8G)U:6ME<G-N86%M
M`$MI97,@9&%T=6UW965R9V%V93H`2VEE<R!L:6IS='-T:6IL='EP92`H=F]O
M<B!G96]R9&5N9&4@;&EJ<W1E;BD`0VAR:7-T;6%S(&5I;&%N9`!#;&%S<V1E
M9FEN:71I92!V86X@)7,@;FEE="!G979O;F1E;BX`2&5L9&5R`$U33V9F:6-E
M('1A9W,@=VES<V5N`%=I<R!Q=65R>0!7:7,@9V5B<G5I:V5R.B`E<P!7:7,@
M9V5B<G5I:V5R`%=I<R!G96)R=6EK97)S9&%T80!,871E(&]P:VQA<FEN9V5N
M`$ML:6L@;VT@=F5R9&5R('1E(&=A86X`0VQI8VMA=&5L;"!V:6$@2%144`!3
M;'5I="!S8VAE<FT`5V]L:V5N`%9R;V5G92!B97=O;&MI;F<`0F5W;VQK=`!#
M;V-O<R`H2V5E;&EN9RD@96EL86YD96X`6FEJ8F%L:R!I;FML87!P96X`26YG
M96ML87!T92!R86YD96X`0V]L;VUB:6$`2VQE=7(`2VQE=7)E;FMI97IE<@!+
M;&5U<G-E;&5C=&EE`$MO;&]M;65N.@!+;VQO;71I=&5L<P!3=')I<',`3W!D
M<F%C:'0`3W!D<F%C:'1S:&5L;`!/<&UE<FMI;F<`06QG96UE;F4@;F%A;0!#
M;VUO<F5N`$)E9')I:F8`0V]M<'5T97)S`$-O;F1I=&EE`$-O;F1I=&EE<P!6
M97)S8VAI;&QE;B!I;B!C;VYF:6=U<F%T:64`0V]N9FEG=7)A=&EE('9O;W(@
M:&5T('-Y;F-H<F]N:7-E<F5N(&UE="!01$$G<RP@4VUA<G1P:&]N97,@96X@
M3W5T;&]O:RX`0V]N9FEG=7)A=&EE(&ES('9E<F]U9&5R9"X`)7,@8V]N9FEG
M=7)E<F5N`$)E=F5S=&EG('=A8VAT=V]O<F0`2V]N9V\`2V]N9V\L($1E($1E
M;6]C<F%T:7-C:&4@4F5P=6)L:65K('9A;B!D90!697)B:6YD:6YG(&UI<VQU
M:W0N`%9E<F)I;F1I;F<@;6ES;'5K=#H@`%9E<F)I;F1I;F<L(&UE="!D92!O
M<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E<F0N`%9E<F)I;F1I
M;F<L(&UE="!D92!O<&5N8F%R92!S;&5U=&5L<V5R=F5R+"!I<R!G97=E:6=E
M<F0N(%)E9&5N.B`E<R`H)7,I`%9E<F)I;F1I;F<@;65T($944"!S97)V97(@
M;6ES;'5K="X`061R97-S96X`061R97-S96X@>FEJ;B!M970@<W5C8V5S(&%A
M;B!U=R!A9')E<V)O96L@=&]E9V5V;V5G9"X`0V]N=&5N="!T>7!E('9A;B!G
M96-O;7!R:6UE97)D(&)E<W1A;F0Z(`!);FAO=60@=F%N("(E<R(`1&]O<F=A
M86X`0V]O:R!E:6QA;F1E;@!#;V]K:64`2V]P:>MR96X`2V]P:>MR96X@;6ES
M;'5K=#H@)7,`2V]P:65E<B!S96QE8W1I90!+;W-T96X@240`0V]S=&$@4FEC
M80!)=F]O<FMU<W0`2V]N(%!'4"!B97)I8VAT(&YI970@8V]D97)E;CH@`$MO
M;B!01U`@8F5R:6-H="!N:65T(&]N9&5R=&5K96YE;CH@`$MO;B!B97)I8VAT
M(&YI970@4R]-24U%(&-O9&5R96XN`$MO;B!B97)I8VAT(&YI970@4R]-24U%
M(&]N9&5R=&5K96YE;BX`2V]N(&%D<F5S("5S(&YI970@=&]E=F]E9V5N+@!+
M;VX@9V5E;B!V97)B:6YD:6YG(&UE="!D92!,1$%0+7-E<G9E<B!M86ME;BX`
M2V]N('1E9V]E9"`E<R!N:65T(&-O;G1R;VQE<F5N+@!+;VX@;FEE="!V97)B
M:6YD96X@;65T($Q$05`@<V5R=F5R+@!+;VX@;FEE="!V97)B:6YD96X@;65T
M('-E<G9E<B`B)7,B(&UE="!&5%`Z("5S`$MO;B!G965N(&1I<W1R:6)U=&EE
M;&EJ<W0@)7,@;6%K96XN`$MO;B!01U`@9&%T82!N:65T(&1E8V]D97)E;CH@
M`$MO;B!3+TU)344@9&%T82!N:65T(&1E8V]D97)E;BX`2V]N(&%D<F5S("5S
M(&YI970@=F5R=VEJ9&5R96XN`$MO;B!D:7-T<FEB=71I96QI:G-T("5S(&YI
M970@=F5R=VEJ9&5R96XN`$MO;B!S971U<"!U<&=R861E('-C<FEP="`B)7,B
M(&YI970@=F5R=VEJ9&5R96XN`$MO;B!H970@92UM86EL861R97,@=F%N(&1E
M(&]N='9A;F=E<B!N:65T(&)E<&%L96XN`$MO;B!C;VUP;&5T92!A9')E<V)O
M96L@;FEE="!O<&AA;&5N+@!+;VX@8V]M<&QE=&4@9&ES=')I8G5T:65L:6IS
M="!N:65T(&]P:&%L96XN`$MO;B!C;VUP;&5T92!L:6IS="!V86X@9&ES=')I
M8G5T:65L:6IS=&5N(&YI970@;W!H86QE;BX`2V]N('-T<F%T96=I92`B)7,B
M(&YI970@;&%D96XN`$MO;B!D:7)E8W1O<GD@(B5S(B!N:65T(&UA:V5N+@!+
M;VX@9&4@;W!E;F)A<F4@<VQE=71E;"!N:65T('9E<FMR:6IG96X@=F%N(&1E
M('-L975T96QS97)V97(N`$MO;B`B)7,B(&YI970@;W!E;F5N('9O;W(@<V-H
M<FEJ=F5N+@!+;VX@)7,@;FEE="!O<&5N96XN`$MO;B!O;F1E<FAO=61S=&%K
M96YM;V1U;&4@)7,@;FEE="!O<&5N96X`2V]N(&1I<F5C=&]R>2`B)7,B(&YI
M970@;W!E;F5N+@!+;VX@9&4@3$1!4"US97)V97(@;FEE="!B97)E:6ME;BX`
M2V]N("5S(&YI970@;&5Z96XN`$MO;B!H970@=V%C:'1W;V]R9"!V86X@9&4@
M9V5W96YS=&4@9V5B<G5I:V5R(&YI970@<F5S971T96XN(%-O;6UI9V4@;V8@
M86QL92!D971A:6QS('II:FX@;FEE="!J=6ES="X@4')O8F5E<B!O<&YI975W
M(&]F(&YE96T@8V]N=&%C="!O<"!M970@9&4@<WES=&5E;6)E:&5E<F1E<BP@
M=V%N;F5E<B!U('9E<F1E<F4@:'5L<"!N;V1I9R!H965F="X`2V]N($%#3"!N
M:65T(&]P:&%L96X`2V]N(&%D<F5S8F]E:R`E<R!N:65T(&]P:&%L96XN`$MO
M;B!D:7-T<FEB=71I96QI:G-T("5S(&YI970@;W!H86QE;BX`2V]N(&1I<W1R
M:6)U=&EE;&EJ<W1E;B`E<R!N:65T(&]P:&%L96XN`$MO;B!S97)V97)B96MW
M86%M:&5D96X@;FEE="!O<&AA;&5N`$MO;B!C;VYF:6=U<F%T:64@;FEE="!T
M97)U9WIE='1E;BX`2V]N(&1I<F5C=&]R>2`B)7,B(&YI970@=F5R=VEJ9&5R
M96XN`$MO;B!C;VYF:6=U<F%T:64@)7,@;FEE="!O<'-L86%N+@!+;VX@9V5E
M;B!B86-K=7!C;VYF:6=U<F%T:64@;W!S;&%A;BX`2V]N(&=E96X@8F%C:W5P
M8V]N9FEG=7)A=&EE(&]P<VQA86XZ("5S`$MO;B!S971U<"!U<&=R861E('-C
M<FEP="!N:65T(&]P<VQA86X@86QS.B`B)7,B+@!+;VX@:&5T(&)A8VMU<&-O
M;F9I9W5R871I96)E<W1A;F0@;FEE="!O<'-L86%N("5S+@!+;VX@:&5T(&-O
M;F9I9W5R871I96)E<W1A;F0@)7,@;FEE="!O<'-L86%N+B!5(&MU;G0@;V8@
MZ^MN('9A;B!D92!O<'1I97,@9V5B<G5I:V5N(&]M(&1E(&-O9&4@=&5R=6<@
M;W`@=&4@<VQA86X@;W`@)7,@;V8@;VYD97)S=&%A;F1E(&-O9&4@:&%N9&UA
M=&EG(&YA87(@)7,@:V]P:>MR96XN`$MO;B!D92!,1$%0+7-E<G9E<B!N:65T
M(&1O;W)Z;V5K96XN`$MO;B`B)7,B(&YI970@;&]S:V]P<&5L96XN`$MO;B!A
M9')E<R`E<R!N:65T(&)I:G=E<FME;BX`2V]N(&1I<W1R:6)U=&EE;&EJ<W0@
M)7,@;FEE="!B:6IW97)K96XN`$MO;B!C;VYF:6=U<F%T:64@=F]O<B`B)7,B
M(&YI970@=V5G<V-H<FEJ=F5N.B`E<P!+;VX@9&4@36]Z:6QL82!3:61E8F%R
M(&YI970@=FEN9&5N+B!:;W)G(&5R=F]O<B!D870@9&4@<VED96)A<B!O<&5N
M(&ES+@!+;VX@9V5B<G5I:V5R("(E<R(@9&4@=F]L9V5N9&4@<F5C:'1E;B!O
M<"!D92!M87`@(B5S(B!N:65T(&=E=F5N.B`E<P!'971E;&1E('1E:W-T`$QA
M;F0`0W5R<W5S<V5N`$UA:V5N`$UA86L@965N(&QI;FL`36%A:R!E96X@;FEE
M=7=E`$UA86L@<W5B;6%P<&5N`$5I9V5N86%R<F5C:'1E;@!#<F5D:71C87)D
M;G5M;65R`$MR;V%T:>L`0W5B80!(=6ED:6=E(#0@9F%S96X`2'5I9&EG92!S
M97-S:65S`$AU:61I9V4@=&EJ9`!(=6ED:6=E(%523"!I<P!(=6ED:6=E(&=E
M8G)U:6ME<G,`2'5I9&EG('=E97(`2'5I9&EG92!C;VYD:71I93H@`$AU:61I
M9V4@<W1I:FP`06%N<&%S<V5N('9A;B!T86ME;B!T:6ID96YS(&%A;FUE;&1I
M;F<@8FEJ("5S+@!+;FEP<&5N`%-E;&5C=&EE(&MN:7!P96X`0WEP<G5S`$-Y
M<FEL;&ES8V@@*$M/23@M4BD`0WER:6QL:7-C:"`H5VEN9&]W<RTQ,C4Q*0!#
M>7)I;&QI<V-H+U5K<F%I;G,@*$M/23@M52D`5'-J96-H:7-C:&4@4F5P=6)L
M:65K`$1$`$133B`H>FEE(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N
M+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%G96QI:FMS
M`$1A=&%4<F5E(&)R;W=S97(`1&%T86)A<V4@9&]O<GIO96ME;@!$871U;0!$
M871U;2!/;G1V86YG96X`1&%T=6T@<V5L96-T:64`1&%G`%9E<E]W:6ID97(@
M:V]L;VT`1&5C96UB97(`1&5C:6UA;&4@9V5T86QL96X`26YS<')I;F=E;B!V
M97)K;&5I;F5N`%-T86YD86%R9`!3=&%N9&%A<F0@:VQE=7(`4W1A;F1A87)D
M(&ED96YT:71E:70`4W1A;F1A87)D('-H96QL`$1E9FEN:71I97,`5F5R=VEJ
M9&5R96X`5F5R=VEJ9&5R(&-E;`!'<F]E<"!V97)W:6ID97)E;@!697)W:6ID
M97(@;&]G`%)E8VAT('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!E;B!W:7,@8F5R
M:6-H=&5N`%9E<G=I:F1E<B!C96P`5F5R=VEJ9&5R(&MO;&]M`$)E<W1A86YD
M(&%L=&5R;F%T:65F('-J86)L;V]N('9E<G=I:F1E<F5N`%9E<G=I:F1E<B!B
M97)I8VAT96X`4F5C:'1E;B!V86X@(B5S(B!V97)W:6ID97)E;@!296-H=&5N
M(&5N(&5V96YT=65L92!S=6)R96-H=&5N('9O;W(@(B5S(B!V97)W:6ID97)E
M;C\`5F5R=VEJ9&5R(')I:@!'97-E;&5C=&5E<F1E(&ED96YT:71E:70@=F5R
M=VEJ9&5R96X`5F5R=VEJ9&5R('-U8FUA<'!E;@!697)W:6ID97(@9&4@:'5I
M9&EG92!K;VQO;0!697)W:6ID97(@9&4@:'5I9&EG92!R:6H`4V5T=7`@=7!G
M<F%D92!S8W)I<'0@(B5S(B!V97)W:6ID97)D+@!!9FQE=F5R=&EJ9`!$96YE
M;6%R:V5N`$)E<V-H<FEJ9B!H970@<')O8FQE96T`0F5S8VAR:6IV:6YG`$1E
M=&%I;',@*&]O:R!I;B!(;W)D92=S(&QO9V)E<W1A;F0I.@!$971A:6QS('II
M:FX@9V5L;V=D('9O;W(@9&4@<WES=&5E;6)E:&5E<F1E<BX`3VYT=VEK:V5L
M:6YG`$1A=7=P=6YT`$1A=7=P=6YT('9O;W(@:&5T(&%F9V5L;W!E;B!U=7(Z
M(`!$875W<'5N=#H@`%)I8VAT:6YG(&QI;FMS(&YA87(@<F5C:'0`4FEC:'1I
M;F<@<F5C:'1S(&YA87(@;&EN:W,`1&ER96-T;W)Y`#(T+75U<G,@=&EJ9'=E
M97)G879E/P!7965R9V%V96]P=&EE<P!'961E=&%I;&QE97)D92!W965R<W9O
M;W)S<&5L;&EN9R!T;VYE;@!7965R<W9O;W)S<&5L;&EN9R!T;VYE;B`H5$%&
M*0!7965R9V%V969O<FUA870`5F]O<F)E<F5I9&EN9W-N;W1I9FEC871I90!$
M:FEB;W5T:0!.:65T('9E<G=I:F1E<F5N`&UA:6YT96YA;F-E+G!H<"!N:65T
M(&1I<F5C="!A86YS<')E:V5N`$)E=F%T(&1E(&5E<G-T92!R:6H@9&4@=F5L
M9&YA;65N/R!:;R!J82P@9&ET(&AO:VIE(&%A;G9I;FME;CH`1&]M:6YI8V$`
M1&]M:6YI8V%A;G-E(%)E<'5B;&EE:P!'965N(&%C8V]U;G0_(%-C:')I:F8@
M=2!I;BX`1&]W;FQO861E;@`E<R!D;W=N;&]A9&5N`$1O=VYL;V%D(&=E9V5N
M97)E97)D92!C;VYF:6=U<F%T:64@86QS(%!(4"!S8W)I<'0N`$1R;W`@9&]W
M;B!L:6IS=`!$<G5G<P!%+4UA:6P`12UM86EL(&YA87(@4TU3(&=A=&5W87D@
M<W1U=7)P<F]G<F%M;6$L('9O;W(@9')A9V5R<R!D:64@9&5Z92!S97)V:6-E
M(&]N9&5R<W1E=6YE;BX`15)2`$5C=6%D;W(`0F5W97)K96X`0FQO:R!B97=E
M<FME;@!'<F]E<"!B97=E<FME;@!296-H="!B97=E<FME;@!296-H=&5N(&)E
M=V5R:V5N`%)E8VAT96X@=F%N("<E<R<@8F5W97)K96X`3W!T:65S(&)E=V5R
M:V5N('9O;W(Z`%)E8VAT96X@=F%N("(E<R(@8F5W97)K96X`4F5C:'1E;B!V
M86X@)7,@8F5W97)K96X`3VYD97)W:6IS`$5G>7!T90!%;"!386QV861O<@!%
M;&5M96YT+BXN`$5M`$4M;6%I;`!%+6UA:6QA9')E<P!%+6UA:6QA9')E<W-E
M;B!M;V5T96X@;W9E<F5E;FMO;65N+@!%+6UA:6P@;65T(&)E=F5S=&EG:6YG
M`$4M;6%I;"!N86%R(%--4R!G871E=V%Y`$5M;W1I8V]N<P!,965G(&)E<FEC
M:'0N`$=E96X@<F5S=6QT86%T+@!,96=E('IO96MT97)M96X`26YV;V5G96X@
M=F%N(&%F8F5E;&1I;F=E;B!U:70@9F]T;V%L8G5M<R!I;B!T96MS="!I;G-C
M:&%K96QE;C\`4F5C:'1K;&EK:V5N(&-O;G1E>'0@;65N=2!I;G-C:&%K96QE
M;C\`16EN9&IA87(`5F5R9W)O;W0@961I=&]R`$=E968@965N(&)E=F5I;&EG
M:6YG<W9R86%G(&1I92!U(&=E=G)A86=D('=O<F1T+"!W86YN965R(&AE="!N
M;V1I9R!I<R!O;2!U=R!W86-H='=O;W)D('1E(')E<V5T=&5N+"!B+G8N("=W
M870@:7,@9&4@;F%A;2!V86X@=7<@:'5I<V1I97(_)SH`5F]E<B!D92!A9F)E
M96QD:6YG(%523"!H:65R(&EN`%9O97(@;VYD97)S=&%A;F1E(&QE='1E<G,@
M:6XZ`$5Q=6%T;W)I86%L($=U:6YE90!%<FET<F5A`$9O=70`1F]U="!B:6H@
M;6%K96X@=F%N(&)L;VLZ("5S`$9O=70@8FEJ('9E<G=I:F1E<F5N('9A;B!S
M>6YC(&%N:V5R.B`E<P!&;W5T(&)I:B!V97)W:6ID97)E;B!V86X@<WEN8R!L
M;V<Z("5S`$9O=70@8FEJ(&]P:&%L96X@=F%N(&EN:&]U9#H@)7,`1F]U="!B
M:6H@8FEJ=V5R:V5N('9A;B!W86-H='=O;W)D.B`E<P!&;W5T(&UE="!E+6UA
M:6QB97)I8VAT+@!&;W5T(&)I:B!S8VAR:6IV96X@=F%N("(E<R(N`$5S=&QA
M;F0`171H:6]P:>L`171N:7-C:`!%=7)O<&$`16QK92`Q-2!M:6YU=&5N`$5L
M:V4@,B!M:6YU=&5N`$5L:V4@,S`@<V5C;VYD96X`16QK92`U(&UI;G5T96X`
M16QK92!A86YM96QD:6YG`$5L:R!H86QF('5U<@!%;&ME(&UI;G5U=`!6;V]R
M8F5E;&1W86%R9&5N.@!5:71V;V5R96X`56ET:VQA<'!E;@!::6IB86QK('5I
M=&ML87!P96X`5F5R=V%C:'1T92`G*2<`5F5R=V%C:'1T92!E;FME;"!W;V]R
M9"!O9B!A86YG96AA86QD92!Z;V5K=&5R;0!697)V86QD871U;0!%>'!O;F5N
M=`!6;V]R9W)O;F1K;&5U<@!&5%`@=7!L;V%D('9A;B!S971U<`!/<&AA;&5N
M('9O;W)K975R<VEN<W1E;&QI;F=E;B!M:7-L=6MT+@!697)B:6YD:6YG(&UE
M="!D92!,1$%0+7-E<G9E<B!I<R!M:7-L=6MT+@!697)B:6YD:6YG(&UE="!D
M92!334(M<V5R=F5R(&ES(&UI<VQU:W0N`$MO<&GK<F5N('5I="`B)7,B(&ES
M(&UI<VQU:W0N`$MO<&GK<F5N(&YA87(@(B5S(B!I<R!M:7-L=6MT+@!-86ME
M;B!V86X@;FEE=7=E(%-!4TP@=F5R8FEN9&EN9R!I<R!M:7-L=6MT+@!697)P
M;&%A='-E;B!N86%R("(E<R(@:7,@;6ES;'5K="X`3W!H86QE;B!V86X@)7,@
M:7,@;6ES;'5K=`!-;V]I`$9A;&ML86YD(&5I;&%N9&5N("A-86QV:6YA<RD`
M1F%R;^MR(&5I;&%N9&5N`$9A=&%L92!F;W5T.@!&87@`1F%X96X`1F5B<G5A
M<FD`5F]E;'0@86QS`%9O96QT(&%L<SH@`$5N:V5L92!B=6EE;@!%;FEG92!S
M;F5E=7=B=6EE;@!696QD;6%T<FEX`$9I9VQE="!#05!40TA!`$9I9VQE="!F
M;VYT`$9I:FD`0F5S=&%N9`!!86YT86P@8F5S=&%N9&5N.B`E<R!B97-T86YD
M`$%A;G1A;"!B97-T86YD96XZ("5S(&)E<W1A;F1E;@!"97-T86YD8F5H965R
M`$)E<W1A;F1S;F%A;0!"97-T86YD(&MI97IE;@!"97-T86YD=7!L;V%D`$)E
M<W1A;F1U<&QO861S('=O<F1E;B!N:65T(&]N9&5R<W1E=6YD+@!&:6QT97)S
M`$9I;FQA;F0`165R<W1E(&AE;&9T`$5E<G-T92!K=V%R=&%A;`!697)H;W5D
M:6YG(&AE<G-T96QL96X`3VUK97)E;@!$<FEJ=F5N`$UI<W0`36%P("5S(&)E
M<W1A870@;FEE=`!&;VYT:VQE=7(`5F]E9'-E;`!6;V]R(&)R;W=S97)S(&1I
M92!G965N(&%F8F5E;&1I;F=E;B!O;F1E<G-T975N96X`5V5E<G-V;V]R<W!E
M;&QI;F<@*%1!1BD`5F]O<G5I='II8VAT9&%G96X@*&UE<FL@;W`@9&%T(&AE
M="!G96=E=F5N('9O;W)U:71Z:6-H="!D86=E;B!E;B!N86-H=&5N(&=E969T
M.R!E96X@9W)O;W0@86%N=&%L(&MA;B!R97-U;'1E<F5N(&EN(&5E;B!B<F5E
M9"!B;&]K*0!5=R!W86-H='=O;W)D('9E<F=E=&5N/P!&;W)M=6QI97)E;@!&
M;W)T=6YE`$9O<G1U;F5T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US
M`$1O;W)S='5R96X`5G(`1G)A;65S`$9R86YK<FEJ:P!&<F%N:W)I:FLL($AO
M;V9D<W1E9&5L:6IK`$9R86YS($=U>6%N80!&<F%N<R!0;VQY;F5S:>L`1G)A
M;G-E(%IU:61E;&EJ:V4@5&5R<FET;W)I80!686X`5F%N(&1E(`!6;VQL961I
M9V4@8F5S8VAR:6IV:6YG`%9O;&QE(&UA86X`5F]L;&5D:6=E(&YA86T`1V%B
M;VX`06QB=6T@=V%A<G5I="!D92!A9F)E96QD:6YG(&=E:&%A;&0@9&EE;G0@
M=&4@=V]R9&5N`$%L8G5M.@!'86UB:6$`1V5N97)E97(@)7,@8V]N9FEG=7)A
M=&EE`$=E9V5N97)E97)D92!C;V1E`$=E;W)G:>L`1'5I='-L86YD`$=H86YA
M`$=I8G)A;'1A<@!6;V]R;F%A;0!';&]B86QE(&]P=&EE<P!'80!';V5D96P`
M1V]O9VQE(&MA87)T96X`1V]O9VQE('IO96ME;@!'<FEJ<W-C:&%A;`!'<FEE
M:V5N;&%N9`!'<FEE:W,@*$E33RTX.#4Y+3<I`$=R;V5N;&%N9`!'<F5N861A
M`$=R;V5P<V)E:&5E<@!'<F]E<&YA;65N(&UO9V5N(&YI970@;&5E9R!Z:6IN
M`$=R;W5P7VQD87`Z($YI970@:6X@<W1A870@9W)O97`@)7,@=&]E('1E('9O
M96=E;BX@1&4@<V5R=F5R(&UE;&1T.B``1W)O=7!?;&1A<#H@3FEE="!I;B!S
M=&%A="!G<F]E<"`E<R!T92!V97)W:6ID97)E;@!'<F]U<%]L9&%P.B!.:65T
M(&EN('-T86%T(&=R;V5P("5S(&)I:B!T92!W97)K96X`1W)O97!E;@!'=6%D
M96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=A<W0@<F5C:'1E;@!'
M87-T96YB;V5K`$=U:6YE90!'=6EN964M0FES<V%U`$=U>6%N80!(5$U,`$A4
M34Q!<F5A('=E:6=E<G0@;&%F(&]M(&1E(&QA871S=&4@8V5L(&EN(&1E(')I
M:B!T92!V97)W:6ID97)E;BX`2%1-3$%R96$@=V5I9V5R="!L868@;VT@9&4@
M;&%A='-T92!K;VQO;2!I;B!D92!T86)E;"!T92!V97)W:6ID97)E;BX`2%1-
M3$%R96$@=V5I9V5R="!L868@;VT@9&4@;&%A='-T92!R:6H@:6X@9&4@=&%B
M96P@=&4@=F5R=VEJ9&5R96XN`$A45%`@875T:&5N=&EC871I92!N:65T(&=E
M=F]N9&5N+@!(86ET:0!(87-H+6%L9V]R:71H;64`3F5V96P`2V]P`$MO<'!E
M;@!(96%R9"!E:6QA;F0@96X@36-$;VYA;&0@96EL86YD96X`6G=A<F4@;VYW
M965R<V)U:0!(96)R965U=W,@*$E33RTX.#4Y+3@M22D`2&]O9W1E`$AE;'``
M2&5L<"!B:6H@9V5B<G5I:R!V86X@961I=&]R`$AE;'!E<@!(86QF<F]N9`!(
M:65R(&ES(&AE="!B96=I;B!V86X@:&5T(&)E<W1A;F0Z`$AO;V<`2&]?;64`
M2&]L>2!3964@*%9A=&EC86%N<W1A9"D`2&]M90!!9')E<R`H<')I=NDI`$AO
M;65D:7)E8W1O<GD`5&5L+FYR+B`H<')I=NDI`$AO;F1U<F%S`$AO;F<@2V]N
M9P!(;W)D90!(;W)D92]+;VQA8CH@3VYG96QD:6=E("5S(%A-3"!D871A('1E
M9V5N9V5K;VUE;B!I;B!B97)I8VAT("5S`$AO<F1E+TMO;&%B.B!'965N(&)E
M<FEC:'0@8V]R<F5S<&]N9&5E<G0@;65T(&]B:F5C="`E<P!(;W)D92]+;VQA
M8CH@1V5E;B!O8FIE8W0@=F%N('1Y<&4@)7,@9V5V;VYD96X@:6X@8F5R:6-H
M="`E<P!(;W)D92]+;VQA8CH@)7,@;65T('-U8V-E<R!V97)W:6ID97)D("(E
M<R(`2&]R9&4O2V]L86(Z($1E(&EN=&5R9W)A=&EE('9E<F5I<W0@9&4@)V1O
M;7AM;"<@97AT96YS:64`2&]R9&4O2V]L86(Z($MA;B!G965N(&YI975W92!8
M34P@8F]O;2!M86ME;B!V;V]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@2V%N
M("5S("(E<R(@;FEE="!V97)W:6ID97)E;CH@)7,`2&]R9&4O2V]L86(Z($YI
M970@:6X@<W1A870@:&5T($U)344@240L('9O;W(@:&5T(&=E9&5E;'1E(&UE
M="!T>7!E("5S+"!O<"!T92!H86QE;@!(;W)D92]+;VQA8CH@2V%N("5S("(E
M<R(@;FEE="!S>6YC:')O;FES97)E;CH@)7,`2&]R9&4O2V]L86(Z($MA;B!G
M961E96QD92!B<F]N;F5N(&YI970@<WEN8VAR;VYI<V5R96XZ("5S`$AO<F1E
M+TMO;&%B.B!/;F)E:V5N9&4@9V5D965L9&4@8G)O;B`B)7,B`$AO<FEZ;VYT
M86QE(&QI:FX`2&]R:7IO;G1A;&4@=G)I:F4@<G5I;71E`$AO<FEZ;VYT86%L
M.@!(;V4@:W=A;2!U(&AI97(_("A'<F%A9R!R87!P;W)T86=E(2D`2&]E=F5E
M;"!K;VQO;6UE;B!W:6QT('4@<V%M96YV;V5G96X_`$AO979E96P@=F5L9&5N
M("AK;VQO;6UE;BD@>FEJ;B!E<C\`2&]E=F5E;"!R:6IE;B!W:6QT('4@<V%M
M96YV;V5G96X_`%9O8VAT:6=H96ED`%9O8VAT:6=H96ED.B``2'5M;W)I<W1E
M;@!(;VYG87)I:F4`36%K96X@=F%N($E-05`@;6%I;&)O>"!M:7-L=6MT.B`E
M<P!697)W:6ID97)E;B!V86X@24U!4"!M86EL8F]X(&UI<VQU:W0Z("5S`$UA
M:V5N('9A;B!)34%0(&UA:6QB;W@@<75O=&$@;6ES;'5K=#H@)7,`25`@061R
M97,`25`@861R97,@;FEE="!B97-C:&EK8F%A<BX`25`@861R97,@=F%L="!N
M:65T(&)I;FYE;B!H970@=&]E9V5S=&%N92!#2412(&)L;VLN`$E0(&QO8VMD
M;W=N(&]V97)T<F5D:6YG+@!2:6H@:5]N=F]E9V5N('9O;W(`24IS;&%N9`!!
M;&QE96X@<&EC=&]G<F%M;65N`%!I8W1O9W)A;6UE;B!V;V]R("5S`%!I8W1O
M9W)A;6UE;B!M970@=&5K<W0`261E;G1I=&5I='-N86%M.@!786YN965R(&AE
M="!N:65T(&=O960@=V]R9'0@=V5E<F=E9V5V96XL("5S(&]M(&AE="!I;B!E
M96X@;FEE=7<@<V-H97)M('1E(&]P96YE;BX`06QS('4@9V5E;B!P:6-T;V=R
M86UM96X@>FEE="P@8FEJ(&=E8G)U:6L@=F%N($EN=&5R;F5T($5X<&QO<F5R
M+"!K86X@:&5T(&YO9&EG('II:FX@9&ET('9A:VIE(&%A;B!T92!V:6YK96X@
M;VT@4$Y'('1R86YS<&%R871I92!U:70@=&4@<V-H86ME;&5N+@!786YN965R
M('4@9&ET(&)E<FEC:'0@>FEE="P@;6%A<B!G965N(&%F8F5E;&1I;F<L(&1A
M;B!K86X@9&4@869B965L9&EN9R!D:64@=2!W:6QT('5P;&]A9&5N(&YI970@
M9&]O<B!U=R!B<F]W<V5R('=O<F1E;B!W965R9V5G979E;BX`069B965L9&EN
M9W-B96]O<F1E;&EN9SH`069B965L9&EN9R!54DP`069B965L9&EN9R!54DPZ
M`$%F8F5E;&1I;F<@=6ET(&%L8G5M`$%F8F5E;&1I;F<@=6ET(&%L8G5M.@!!
M9F)E96QD:6YG<W5P;&]A9`!!9F)E96QD:6YG96X`26UP;W)T97)E;BP@<W1A
M<"`E9`!'96EM<&]R=&5E<F0@=F5L9#H@)7,`1V5I;7!O<G1E97)D92!V96QD
M96XZ`%)I:B!I;G9O96=E;B!N80!/;FIU:7-T92!B97=E<FMI;F=S8V]D92!O
M<&=E9V5V96XN`$]N:G5I<W1E(&=E8G)U:6ME<G-N86%M(&5N+V]F('=A8VAT
M=V]O<F0N`$]N:G5I<W1E(&=E8G)U:6ME<G-N86%M(&]F(&%L=&5R;F%T:65F
M(&%D<F5S+B!0<F]B965R(&]P;FEE=7<@;V8@;F5E;2!C;VYT86-T(&]P(&UE
M="!D92!S>7-T965M8F5H965R9&5R+"!W86YN965R('4@=F5R9&5R92!H=6QP
M(&YO9&EG(&AE969T+@!697)G<F]O="!I;G-P<FEN9VEN9P!);F1I80!);F1I
M=FED=65L92!G96)R=6EK97)S`$EN9&]N97-IZP!);F9O`$EN9F]R;6%T:64`
M26YF;W)M871I92!N:65T(&QA;F=E<B!B97-C:&EK8F%A<BX`2V]L;VT@:6YV
M;V5G96X@;F$`069B965L9&EN9R!I;G9O96=E;@!486)E;"!I;G9O96=E;@!7
M96)L:6YK(&EN=F]E9V5N`%]+;VQO;2!I;G9O96=E;B!V;V]R`$5E;B!N:65U
M=V4@:V]L;VT@:6YV;V5G96X@;F$@9&4@:'5I9&EG90!%96X@;FEE=7=E(&MO
M;&]M(&EN=F]E9V5N('9O;W(@9&4@:'5I9&EG90!%96X@;FEE=7=E(')I:B!I
M;G9O96=E;B!N82!D92!H=6ED:6=E`$5E;B!N:65U=V4@<FEJ(&EN=F]E9V5N
M(&YA(&1E(&AU:61I9V4`165N(&YI975W92!P87)A9W)A868@:6YV;V5G96X@
M;F$@9&4@:'5I9&EG92!N;V1E`$5E;B!N:65U=V4@<&%R86=R86%F(&EN=F]E
M9V5N(&YA(&1E(&AU:61I9V4@;F]D90!!;'1E<FYA=&EE9B!S:F%B;&]O;B!I
M;G9O96=E;@!%96X@92UM86EL861R97,@:6YV;V5G96XL('=A87(@=2!H970@
M;FEE=7=E('=A8VAT=V]O<F0@:V%N(&]N='9A;F=E;CH`0V5L(&EN=F]E9V5N
M(&YA`$-E;"!I;G9O96=E;B!V;V]R`$MO;&]M(&EN=F]E9V5N(&YA`$MO;&]M
M(&EN=F]E9V5N('9O;W(`0F5R:6-H=&5N(&EN=F]E9V5N`%!A<F%G<F%A9B!I
M;G9O96=E;B!N80!087)A9W)A868@:6YV;V5G96X@=F]O<@!2:6H@:6YV;V5G
M96X@;F$`4FEJ(&EN=F]E9V5N('9O;W(`2&5T(&=E=V5N<W1E(&%N='=O;W)D
M('9O;W(@9&4@8F5V96EL:6=I;F=S=G)A86<@:6YV;V5G96XZ`$%F8F5E;&1I
M;F<@:6YV;V5G96XO86%N<&%S<V5N`$QI;FL@:6YV;V5G96XO86%N<&%S<V5N
M`$]N=F]L9&]E;F1E(&MR961I970@;VT@;F%A<B!D92!D:7-T<FEB=71I96QI
M:G-T('1E('IE;F1E;BX`3VYV;VQD;V5N9&4@:W)E9&EE=`!);G1E9V5R`$EN
M=&5G97(@;&EJ<W0`3VYG96QD:6=E(%5$2"X@*%5S97(@1&%T82!(96%D97(I
M+@!/;F=E;&1I9V4@6DE0(&1A=&$`3VYG96QD:6=E('1O97!A<W-I;F<N`$]N
M9V5L9&EG(&)A=&-H($E$+@!/;F=E;&1I9V4@9&%T82!O<&=E9V5V96XN`$]N
M9V5L9&EG(&)E<W1E;6UI;F=A9')E<RX`3VYG96QD:6<@=&EJ9&9O<FUA870`
M3VYG96QD:6=E(&QI8V5N=&EE<VQE=71E;"X`3VYG96QD:6=E(&QO8V%T:64@
M;W!G96=E=F5N+@!/;F=E;&1I9R!M<V=?='EP92X`3VYG96QD:6<@;V8@;VYT
M8G)E:V5N9"!A<&E?:60N`$]N9V5L9&EG92!O9B!O;G1B<F5K96YD92!P87)A
M;65T97)S+@!/;F=E;&1I9R!P87)E;G0@<F5C:'0N`$]N9V5L9&EG('!A<G1N
M97(@:60N`$]N9V5L9&EG92!P<F]D=6-T:65C;V1E+@!/;F=E;&1I9R!P<F]T
M;V-O;"X`3VYG96QD:6=E(&]N='9A;F=E<CH@(B5S(@!/;F=E;&1I9V4@9V5D
M965L9&4@8G)O;@!/;F=E;&1I9R!B<F]N861R97,N`$]N9V5L9&EG92!U;FEC
M;V1E(&1A=&$N`$EN=F5N=&%R:7,`4V5L96-T:64@;VUK97)E;@!)<F%N+"!)
M<VQA;6ET:7-C:&4@4F5P=6)L:65K('9A;@!)<F%K`$EE<FQA;F0`16EL86YD
M($UA;@!'96ES;VQE97)D92!O;G=E97)S8G5I96X`27-R8>ML`%5I=&=E=F5R
M`$-U<G-I968`271A;&GK`$IA;6%I8V$`2F%N=6%R:0!*87!A;@!*87!A;G,@
M*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:>L`2G5L:0!*=6YI`'5I=&QI
M:FYE;@!'96-E;G1R965R9"!U:71L:6IN96X`5F]L;&5D:6<@=6ET;&EJ;F5N
M`$QI;FMS('5I=&QI:FYE;@!296-H=',@=6ET;&EJ;F5N`$MA>F%C:'-T86X`
M3W)I9VEN965L(&)E:&]U9&5N/P!+96YI80!+97)B97)O<R!S97)V97(@=V5I
M9V5R9&4@875T:&5N=&EC871I92X`2V5R;F5L($YE=V)I97,`4VQE=71E;"!M
M86ME;@!3;&5U=&5L=FEN9V5R869D<G5K`%-L975T96QL96YG=&4`4VQE=71E
M;'1Y<&4`4VQE=71E;&=E8G)U:6L`1&4@<VQE=71E;"!B97-T86%T(&%L(&]P
M(&1E(&]P96YB87)E('-L975T96QS97)V97(N`$MI;F1E<F5N`$MI<FEB871I
M`$MO<F5A+"!$96UO8W)A=&ES8VAE(%9O;&MS<F5P=6)L:65K('9A;@!+;W)E
M82P@4F5P=6)L:65K('9A;@!+;W)E86%N<R`H155#+4M2*0!+;V5W96ET`$MY
M<F=I97-IZP!/7W!M86%K`%1A86P`1&5M;V-R871I<V-H92!6;VQK<W)E<'5B
M;&EE:R!,86\`3&%A='-T92!H96QF=`!,86%T<W1E('=A8VAT=V]O<F1W:6IZ
M:6=I;F<`3&%A='-T92!K=V%R=&EE<@!,86%T<W0@8FEJ9V5W97)K=#H`3&%A
M='-T92!A86YM96QD:6YG.B`E<P!,86%T<W1E(&%A;FUE;&1I;F<Z("5S('9A
M;B`E<P!,86%T<W1E(&%A;FUE;&1I;F<Z($YO;VET`$QE=&QA;F0`4F5C:'1E
M;@!/<&UA86L`3&%A="!L965G('9O;W(@9V5E;B!R86YD`$QI8F%N;VX`3&EN
M:W,`3&EN:W-E(&MO<`!,:6YK<V4@=V%A<F1E;@!,97-O=&AO`$YI=F5A=0!,
M:6)E<FEA`$QI8FES8VAE($%R86)I<V-H92!*86UA:&ER:7EA`$QI96-H=&5N
M<W1E:6X`6F%C:'0@8G5I=&IE`$QI8VAT92!R96=E;@!6<F]E9R!L:6-H=&4@
M<F5G96X`3&EC:'1E(')E9V5N`$QI8VAT92!R96=E;F)U:0!,:6-H=&4@<F5G
M96X@;65T(&]N=V5E<@!,:6-H=&4@<VYE975W`$QI8VAT92!S;F5E=7=B=6D`
M3&EM97)I8VL`3&EN:P!,:6YK('=I:G-T(&YA87(Z`$QI;FL@:&5T(&4M;6%I
M;&%D<F5S(&%A;B!D92!N:65U=R!B97)I8VAT('!A9VEN82!T:6ID96YS('=E
M97)G879E`$QI;FMS`$QI;G5X($-O;VMI90!,:6IS="`M(&=E8G)U:6ME<B!K
M86X@9&4@;6%P('II96X`1&%T86)A<V5L:6IS=`!,:6IS="!V86X@:&5L<"!O
M;F1E<F1E;&5N`%1A8F5L;&EJ<W0`3&EJ<W0M07)C:&EE9@!,:6IS="U(96QP
M`$QI:G-T+4ED`$QI:G-T+45I9V5N86%R`$QI:G-T+5!O<W0`3&EJ<W0M26YS
M8VAR:6IV96X`3&EJ<W0M56ET<V-H<FEJ=F5N`%=E97)G979E;B!V86X@<V5S
M<VEE;&EJ<W0@:7,@;6ES;'5K=#H@)7,`5V5E<F=E=F5N('9A;B!G96)R=6EK
M97)S;&EJ<W0@:7,@;6ES;'5K=#H@)7,`5V5E<F=E=F5N('9A;B!G96)R=6EK
M97)S;&EJ<W0@:7,@=6ET9V5S8VAA:V5L9"X`3&ET97)A='5U<@!,:71O=7=E
M;@!,861E;BXN+@!,;VMA;&4@=&EJ9#H`3&%N9&EN<W1E;&QI;F<@96X@=&EJ
M9`!,;V-A=&EE`$%A;FUE;&1E;@!,;V<@=F%N('9O;W)G86%N9&4@<WEN8R!S
M97-S:64`069M96QD96X`06%N;65L9&5N`$%A;FUE;&1T86ME;@!!86YM96QD
M:6YG(&UI<VQU:W0@;VUD870@=7<@9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W
M;V]R9"!O;FIU:7-T(&ES(&EN9V5V;V5R9"X`06%N;65L9&EN9R!M:7-L=6MT
M+@!,86YG92!T96MS=`!,:65F9&4`3&%A9P!'<FEE:W-E(&ML96EN92!L971T
M97)S`$QA=&EJ;G-E(&ML96EN92!L971T97)S`$ML96EN92!2;VUE:6YS92!G
M971A;&QE;@!,=7AE;6)U<F<`34T`34]41`!-4RU43D5&(&)I:FQA9V4@8F5V
M871T92!G965N(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:>LL($1E('9R;V5G
M97)E($IO96=O<VQA=FES8VAE(%)E<'5B;&EE:R!V86X`36%D86=A<V-A<@!-
M86=I90!%+6UA:6P`36%I;&)E:&5E<F1E<@!-86%K(&QI;E]K+BXN`$UA;&%W
M:0!-86QE:7-IZP!-86QA9&EV96X`36%L:0!-86QT80!"96AE97(@=7<@;&EJ
M<W0@;65T(&-A=&5G;W)I9>MN(&5N(&1E(&-O<G)E<W!O;F1E<F5N9&4@:VQE
M=7)E;BP@=V%A<FUE92!O;F1E<F1E;&5N('=O<F1E;B!G96QA8F5L9`!-87`R
M-"!K86%R=`!-87!1=65S=&MA87)T`$MO<'!E;&EN9V5N(&]P9V5S;&%G96XN
M`$UA87)T`$UA<F=E`$UA<FME97(@;65T($=E>FEE;B].:65T($=E>FEE;B!V
M;&%G9V5N`$UA<FME97(@;65T(&%N9&5R92!V;&%G9V5N("AB+G8N($)E;&%N
M9W)I:FLO0F5A;G1W;V]R9"D`36%R8VAA;&P@96EL86YD96X`36%R=&EN:7%U
M90!/=F5R965N:V]M96YD92!V96QD96X`36%U<F5T86YIZP!-875R:71I=7,`
M36%X:6UA86P@=&]E9V5S=&%A;B!K<F5D:65T+@!-87AI;75M(&)E<FEC:'1O
M;F1E<F1E;&5N(&]V97)S8VAR961E;BX`36%X:6UU;2!T96UP97)A='5U<B!V
M86X@9&4@869G96QO<&5N(#(T('5U<CH@`$UA>&EM=6T@=&5M<&5R871U=7(@
M=F%N(&1E(&%F9V5L;W!E;B`V('5U<CH@`$UA>&EM=6T@86%N=&%L('!O<G1A
M86QB;&]K:V5N`$UA>&EM=6T@;&5N9W1E`$UE:0!-87EO='1E`$=E;F5E<VMU
M;F1E`$QE9&5N`$UE;G4@;6]D93H`0V5L;&5N('-A;65N=F]E9V5N`$)E<FEC
M:'0`0F5R:6-H="!M970@<W5C8V5S(&=E=F5R:69I965R9"P@;6%A<B!H970@
M8V5R=&EF:6-A870@=F%N(&1E(&]N9&5R9V5T96ME;F1E(&MO;B!N:65T('=O
M<F1E;B!G979E<FEF:65E<F0N`$)E<FEC:'0@=F5R;&]P96XN`$)E<FEC:'1T
M>7!E`$UE=&%R(%=E97(`345405(@8FQO:R!I<R!N:65T(&)E<V-H:6MB86%R
M+@!-151!4B!B;&]K(&ES(&YI970@8F5S8VAI:V)A87(N($1E=&%I;',@>FEJ
M;B!G96QO9V0@=F]O<B!D92!S>7-T965M8F5H965R9&5R+@!-971A<D1"(&ES
M(&YI970@=F5R8F]N9&5N+@!-971H;V1E`$UE=&AO9&4@(B5S(B!I<R!N:65T
M(&=E9&5F:6YI965R9`!-971H;V1E(&ES(&YI970@9V5D969I;FEE97)D+B!!
M86YG97)O97!E;B!M971H;V1E.B`E<P!-971R:7-C:`!-97AI8V\`36EC<F]N
M97-IZRP@1F5D97)A;&4@4W1A=&5N('9A;@!-:61D96X`36EM92!T>7!E`$UI
M;FEM=6T@=&5M<&5R871U=7(@=F%N(&1E(&%F9V5L;W!E;B`R-"!U=7(Z(`!-
M:6YI;75M('1E;7!E<F%T=75R('9A;B!D92!A9F=E;&]P96X@-B!U=7(Z(`!-
M:6YI;75M('=A8VAT=V]O<F1L965F=&EJ9"!I<R!N;V<@;FEE="!V97)L;W!E
M;@!-:7)R;W(`06QL97)H86YD90!/;G1B<F5K96YD92!014%2(&UO9'5L92!(
M5%107U)E<75E<W0N`$]N=&)R96ME;F1E(&-O;F9I9W5R871I92X@52!D:65N
M="!D97IE(&YU('1E(&=E;F5R97)E;BP@=V%N;F5E<B!U(&1E>F4@=&]E<&%S
M<VEN9R!W:6QT(&=E8G)U:6ME;BX`3VYT8G)E:V5N9"!B97)I8VAT($E$+@!/
M;G1B<F5K96YD92P@=F5R96ES=&4L(%!%05(@;6]D=6QE($UA:6PN`$]N=&)R
M96ME;F0@<V5S<VEE($E$+@!-80!-;V)I96QE(&4M;6%I;`!'96UI9&1E;&0`
M5VEJ>FEG:6YG<V1A='5M`%=I:GII9R!54DP`36]D=6QU<P!-;VQD879IZRP@
M4F5P=6)L:65K('9A;@!-;VYA8V\`36]N9V]L:>L`36%A;F0@96X@:F%A<@!-
M86%N9&5L:6IK<P!-;VYT<V5R<F%T`$UA86YF87-E;@!-965R('9E;&1E;B!I
M;B!R96=E;"`E9"!G979O;F1E;BP@9&%N(&1E('9E<G=A8VAT=&4@)60N`$UA
M<F]K:V\`5F]O<FYA;65L:6IK(&]N8F5W;VQK=`!6;V]R;F%M96QI:FL@8F5W
M;VQK=`!6;V]R;F%M96QI:FL@8F5W;VQK="!E;B!W:6YD97)I9P!6;V]R;F%M
M96QI:FL@>F]N;FEG`$YA87(@8F5N961E;@!.86%R(&QI;FMS`$YA87(@<F5C
M:'1S`$YA87(@8F]V96X`3F%A<B!B96YE9&5N`$YA87(@8F]V96X`36]Z86UB
M:7%U90!-=6QT:2UL979E;"!D<F]P(&1O=VX@;&EJ<W1E;@!-=6QT:6UA<"!6
M2R!K86%R=`!-965R=F]U9&EG92!S96QE8W1I90!-:6IN(&%C8V]U;G0`57<@
M86-C;W5N=&EN9F]R;6%T:64`36EJ;B!P;W)T86%L`$UI:FX@<&]R=&%A;&QA
M>6]U=`!":7)M80!.964L(&EK(&%C8V5P=&5E<B!D92!V;V]R=V%A<F1E;B!.
M2454`$YA86T`3F%M:6)IZP!.875R=0!.97!A;`!.961E<FQA;F0`3F5D97)L
M86YD<R!!;G1I;&QE;@!.971S8V%P92!"87-I<R!54DP`3F5T<V-A<&4@0T$@
M:6YT<F5K:VEN9R!54DP`3F5T<V-A<&4@0T$@8F5L96ED(%523`!.971S8V%P
M92!V97)N:65U=VEN9R!54DP`3F5T<V-A<&4@:6YT<F5K:VEN9R!54DP`3F5T
M<V-A<&4@4U-,('-E<G9E<FYA86T`3F5T<V-A<&4@8V5R=&EF:6-A871C;VUM
M96YT86%R`$YE='-C87!E(&-E<G1I9FEC86%T='EP90!.971W97)K`$YO;VET
M`$YI975W($-A;&5D;VYIZP!.:65U=V4@8V%T96=O<FEE`$YI975W92!M86%N
M`$YI975W92!G96)R=6EK97)S;F%A;2`H;W!T:6]N965L*0!.:65U=R!:965L
M86YD`$YI975W('=A8VAT=V]O<F0`3FEE=7<@=V%C:'1W;V]R9"!Z86P@=F5R
M;&]P96X@;W`@)7@N`$YI975W92!786-H='=O;W)D96X@:V]M96X@;FEE="!O
M=F5R965N+@!.:65U=R!S8VAE<FT@*%]B;&%N:RD`3FEE=7=S`$YI975W<V=R
M;V5P96X`5F]L9V5N9&4`5F]L9V5N9&4@-"!F87-E;@!6;VQG96YD92!O<'1I
M97,`5F]L9V5N9&4^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA8VAT`$YI
M=64`3F5E`$=E96X@8F5S8VAI:V)A<F4@8V]N9FEG=7)A=&EE9&%T82!O;2!V
M97)S8VAI;&QE;B!T92!L871E;B!Z:65N+@!'965N(&)E<V-H:6MB87)E('-T
M<F%T96=I92!V;V]R(&AE="!M86ME;B!V86X@25-/(&EM86=E<RX`1V5E;B!B
M871C:'-J86)L;V]N+@!%<B!B97-T86%T(&=E96X@8FQO:R!O<"!D92!G979R
M86%G9&4@<&]S:71I90!'965N(&%G96YD86YA86T@;W!G96=E=F5N('9O;W(@
M34-!3"!A=71H96YT:6-A=&EE+@!'965N('=I:GII9VEN9V5N+@!!86X@9&ET
M(')E8VAT(&MU;FYE;B!G965N(&-H:6QD(')E8VAT96X@=V]R9&5N('1O96=E
M=F]E9V0N`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O<&=E9V5V96X@
M=F]O<B`E<RX`1V5E;B!C;VYF:6=U<F%T:65I;F9O<FUA=&EE(&]P9V5G979E
M;B!V;V]R($944"!61E,N`$=E96X@8V]N9FEG=7)A=&EE:6YF;W)M871I92!O
M<&=E9V5V96X@=F]O<B!344P@5D93+@!'965N(&-O;F9I9W5R871I96EN9F]R
M;6%T:64@;W!G96=E=F5N('9O;W(@4U%,+6)E<W1A;F0@5D93+@!'965N(&MR
M961I970@;65E<BX`1V5E;B!B97-T96UM:6YG(&]P9V5G979E;BX`1V5E;B!B
M97-T86YD('5P;&]A9&5D`$=E96X@<&EC=&]G<F%M;65N(&=E=F]N9&5N+@!%
M<B!I<R!G965N(&QO8V%T:64@:6YG97-T96QD+@!'965N(&QO8V%T:64@;W!G
M96=E=F5N+@!'965N(&)E<FEC:'0@9V5L979E<F0N`$=E96X@;F%A;2!O<&=E
M9V5V96XN`$=E96X@9V5T86P@;W!G96=E=F5N+@!'965N(&)E;&5D:6=E;F1E
M(&9O<G1U;F5S`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!(5%10
M(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O
M<B!)34%0(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V
M96X@=F%N($ME<F)E<F]S(&%U=&AE;G1I8V%T:64N`$=E96X@=V%C:'1W;V]R
M9"!O<&=E9V5V96X@=F]O<B!,;V=I;B!A=71H96YT:6-A=&EE+@!'965N('=A
M8VAT=V]O<F0@;W!G96=E=F5N('9O;W(@4$%34U=$(&%U=&AE;G1I8V%T:64N
M`$=E96X@=V%C:'1W;V]R9"!O<&=E9V5V96X@=F]O<B!334(@875T:&5N=&EC
M871I92X`1V5E;B!P860@;F%A<B!D92!/<&5N4U-,(&)I;F%R>2!O<&=E9V5V
M96XN($1E($]P96Y34TP@8FEN87)Y(&ES(&YO9&EG(&]M('1E(&MU;FYE;B!W
M97)K96X@;65T(%!+0U,@,3(@9&%T82X`1V5E;B!H86YG96YD92!I;G-C:')I
M:G9I;F=E;BX`1V5E;B!Q=6]T82!I;F=E<W1E;&0N`$=E96X@;&EN:>MR:6YG
M`$=E96X@<V-H96ED:6YG<W1E:V5N(&]P9V5G979E;BX`1V5E;B!Z:6ID96X`
M1V5E;B!D97)G96QI:FL@8F5S=&%N9`!'965N('1I:F1E;&EJ:R!D:7)E8W1O
M<GD@8F5S8VAI:V)A87(@=F]O<B!C86-H92X`1V5E;B!G96)R=6EK97)S;F%A
M;2!E;B]O9B!W86-H='=O;W)D('9E<GIO;F1E;BX`1V5E;B!G96QD:6=E(%A-
M3"!D871A('1E<G5G9V5S='5U<F0`1V5E;B!W86%R9&5N`$=E96X@=F5R<VEE
M(&=E=F]N9&5N(&EN(&]R:6=I;F5L92!C;VYF:6=U<F%T:64N($AE<F=E;F5R
M965R(&-O;F9I9W5R871I92X`1V5E;B!V97)S:64@9V5V;VYD96X@:6X@=7<@
M8V]N9FEG=7)A=&EE+B!(97)G96YE<F5E<B!C;VYF:6=U<F%T:64N`$=E96X`
M1V5E;B`H=F5R<&QI8VAT*0!.;V]R9"!%=7)O<&5E<R`H25-/+3@X-3DM,3`I
M`$YO<F9O;&L@96EL86YD`$YO;W)D96QI:FL@:&%L9G)O;F0`36%R:6%N96X`
M3F]O<G=E9V5N`$YI970@;F$`3FEE="!V;V]R`$=E96X@9&ER96-T;W)Y`$YI
M970@9V5I;7!L96UE;G1E97)D+@!.:65T(&EN9V5S=&5L9`!.:65T(&]N9&5R
M<W1E=6YD+@!.;W1I=&EE<P!.:65T<R!T92!B;&%D97)E;BP@9V$@=&5R=6<N
M`$YO=F5M8F5R`$=E=&%L`$%A;G1A;"!K87)A:W1E<G,`06%N=&%L(&MO;&]M
M;65N`$%A;G1A;"!R:6IE;@!'971A;&QE;B!N:65T(&]P9V5G979E;B!V;V]R
M(&)I:G=E<FME;B!I;B!E96X@9&ES=')I8G5T:65L:6IS="X`3TL`3V)J96-T
M`$]B:F5C=&5I9V5N86%R`$]C=&%A;`!/:W1O8F5R`$)E;&5D:6=I;F=F:6QT
M97(`2V%N=&]O<@!/=61E(&5N(&YI975W92!W86-H='=O;W)D96X@9&EE;F5N
M('9E<G-C:&EL;&5N9"!T92!Z:6IN+@!/=61E('=A8VAT=V]O<F0`3W5D92!W
M86-H='=O;W)D(&ES(&YI970@:G5I<W0`3VUA;@!!;&QE96X@24U!4"!S97)V
M97)S(&]N9&5R<W1E=6YE;B!G961E96QD92!M87!P96XN`$%L;&5E;B!B96QE
M9&EG96YD92!F;W)T=6YE<P!3;&5C:'0@Z>EN(&4M;6%I;&%D<F5S('1O96=E
M<W1A86XN`$%L;&5E;B!D92!E:6=E;F%A<B!O9B!E96X@<WES=&5E;6)E:&5E
M<F1E<B!M86<@9&4@96EG96YA87)R96-H=&5N('9A;B!E96X@<VAA<F4@=VEJ
M>FEG96X`3W!E;B!I;B!E96X@;FEE=7<@<V-H97)M`$]P96Y34TP@9F]U=#H@
M:V]N(&=E96X@9&%T82!U:70@:&5T(&]N9&5R=&5K96YD92!3+TU)344@;VYD
M97)D965L(&AA;&5N+@!/<&5N="!D97IE(&QI;FL@:6X@965N(&YI975W('-C
M:&5R;0!"97-T=7)I;F=S<WET965M`$]P=&EE<P!/<'1I97,@=F]O<B`E<P!'
M96]R9&5N9&4@;&EJ<W0`3W)G86YI<W1A=&EE`$]R9V%N:7-A=&EE(&5E;FAE
M:60`3W)G86YI<V5R96X`3W)I9VEN965L('1O97!A<W-I;F=S<VIA8FQO;VX`
M3W)I9VEN96QE('-J86)L;VYE;B!I;B`E<SH`06YD97)E`$%N9&5R92!I;F9O
M<FUA=&EE`$5I9V5N86%R<F5C:'1E;@!004T@875T:&5N=&EC871I92!I<R!N
M:65T(&)E<V-H:6MB86%R+@!014%2.CI-86EL(&)A8VME;F0`1&EG:71A;&4@
M4$=0(&AA;F1T96ME;FEN9P!'96-O9&5E<F1E(%!'4"!D871A`$]P96YB87)E
M(%!'4"!S;&5U=&5L`$]N9&5R=&5K96YD92]G96-O9&5E<F1E(%!'4"!D871A
M`%!(4"!C;V1E`%!(4"!S:&5L;`!,:6-H=&4@<F5G96X@;F$@,3(N,#`@=75R
M`%)E9V5N(&YA(#$R+C`P('5U<@!"=6EE;B!N82`Q,BXP,"!U=7(`4VYE975W
M(&YA(#$R+C`P('5U<@!3;F5E=7=B=6EE;B!N82`Q,BXP,"!U=7(`6F]N(&YA
M(#$R+C`P('5U<@!/;G=E97)S8G5I96X@;F$@,3(N,#`@=75R`%!/4TE8(&5X
M=&5N<VEE(&]N=&)R965K=`!02%`@7U-H96QL`%9R:6IE(')U:6UT90!086MI
M<W1A;@!086QA=0!086QE<W1I:FYS(%1E<G)I=&]R:75M+"!"97IE=`!086YA
M;6$`4&%P=6$@3FEE=7<@1W5I;F5A`%!A<F%G=6%Y`$=E9&5E;'1E;&EJ:R!B
M97=O;&MT`%=A8VAT=V]O<F0`5V%C:'1W;V]R9"!M970@<W5C8V5S(&=E=VEJ
M>FEG9"X`5V%C:'1W;V]R9"!O;FIU:7-T`%=A8VAT=V]O<F0@:7,@=F5R96ES
M="!V;V]R(%)!1$E54R!A=71H96YT:6-A=&EE+@!786-H='=O;W)D(&UE="!B
M979E<W1I9VEN9P!786-H='=O;W)D.@!786-H='=O;W)D.B``5V%C:'1W;V]R
M9&5N(&UO971E;B!O=F5R965N:V]M96XN`%!L86MK96X`4&QA:VME;B!V86YA
M9B!P<FEK8F]R9`!0860`2&%N9V5N9&4@:6YS8VAR:6IV:6YG96XZ`$UE;G-E
M;@!0<F]C96YT`$]N9&5R:&]U9'-W97)K>F%A;6AE9&5N('5I='9O97)E;@!/
M;F1E<FAO=61S=V5R:WIA86UH961E;B!U:71V;V5R96X@8FEJ(&%A;FUE;&1I
M;F<_`%)E8VAT`%)E8VAT("(E<R(@;FEE="!V97)W:6ID97)D+@!296-H="!G
M97=E:6=E<F0`4F5C:'1E;@!296-H=&5N8F5H965R`%!E<G-O;VYL:6IK92!I
M;F9O<FUA=&EE`%!E<G4`2'5I<V1I97)E;@!0:&EL:7!P:6IN96X`5&5L969O
M;VX`1F]T;R=S`%!I=&-A:7)N`%!I>&5L<P!0;&%T:71U9&5S`$ML:6L@:6X@
M965N(&-E;"P@82YU+F(N`$)E=F5S=&EG+"!D870@=2!D:70@96QE;65N="!W
M:6QT('9E<G=I:F1E<F5N+"!A+G4N8CH`0F5V97-T:6<L(&1A="!U(&1I="!E
M;&5M96YT('=I;'0@;&]S:V]P<&5L96XL(&$N=2YB+@!'965F(&5E;B!M86%N
M9"!E;B!E96X@:F%A<BP@82YU+F(N`$5E;B!N86%M('9O;W(@9&4@;FEE=7=E
M(&-A=&5G;W)I92!I;G9O97)E;BP@82YU+F(N.@!'965F(&5E;B!G96QD:6<@
M25`@861R97,L(&$N=2YB+@!'965F(&5E;B!G96QD:6=E(&1A='5M(&$N=2YB
M+BP@8V]N=')O;&5E<B!H970@86%N=&%L(&1A9V5N(&EN(&1E(&UA86YD+@!'
M965F(&5E;B!G96QD:6=E('1I:F0L(&$N=2YB+@!'965F(&5E;B!S86UE;G9A
M='1I;F<@=F%N(&AE="!P<F]B;&5E;2P@82YU+F(N`$=E968@=7<@9V5B<G5I
M:V5R<VYA86T@96X@=V%C:'1W;V]R9"P@82YU+F(N`$QE97,@9&4@=F]L9V5N
M9&4@=&5K<W0L(&$N=2YB+B!5($U/150@9&4@=F]O<G=A87)D96X@=&4@86-C
M97!T97)E;B!O;2!H970@<WES=&5E;2!T92!K=6YN96X@9V5B<G5I:V5N+@!'
M965F(&1E(&YI975W92!C871E9V]R:65N86%M+"!A+G4N8BXZ`%!O;&5N`%!O
M;&ET:65K`%!E:6QI;F=E;@!0;W)T=6=A;`!0;W-I=&EO;F5R:6YG('9A;B!D
M97IE(&%F8F5E;&1I;F<`4&]S:71I;VYE<FEN9R!V86X@9&5Z92!T86)E;`!3
M='5U<B!N86%R(&1E>F4@;6%P("AN:65T(&%F9V5D=V]N9V5N(&1O;W(@24U!
M4"D`3F5E<G-L86<@=F%N(&1E(&%F9V5L;W!E;B`E<R!U<F5N.B``3F5E<G-L
M86<\8G(@+SYK86YS`%!R969S7VQD87`Z('9E<F5I<W1E($Q$05`@97AT96YT
M:64@;FEE="!G979O;F1E;BX`4')E9G-?<V5S<VEO;CH@=F5R96ES=&4@<V5S
M<VEE(&5X=&5N=&EE(&YI970@9V5V;VYD96XN`$QU8VAT9')U:P!,=6-H=&1R
M=6L@;W`@>F5E;FEV96%U.B``3'5C:'1D<G5K.B``0F5O;W)D96QE;@!"96]O
M<F1E96P@9&4@869B965L9&EN9R!I;B!E96X@;FEE=7<@<V-H97)M`%9O<FEG
M92!O<'1I97,`1&]C=6UE;G0@869D<G5K:V5N`%!R:79E('-L975T96P`4')O
M8FQE96T`4')O8FQE96UB97-C:')I:G9I;F<`4')O:F5C=&5N`%!R;VUP="!T
M96MS=`!/<&5N8F%R92!S;&5U=&5L`$]P96YB87)E('-L975T96P@86QG;W)I
M=&AM90!/<&5N8F%R92!S;&5U=&5L:6YF;W)M871I90!/<&5N8F%A<B]0<FEV
M92!S;&5U=&5L<&%A<B!N:65T(&=E9V5N97)E97)D+@!0=65R=&\@4FEC;P!7
M:7,@8F5R:6-H=&5N`%%U871A<@!1=65R>0!1=6]T80!24T$@;W!E;F)A<F4@
M<VQE=71E;"`H)60@8FET*0!+975Z97)O;F1J92!S96QE8W1I90!296=E;@!6
M<F]E9R!R96=E;@!,86%T(')E9V5N`%)E9V5N8G5I`%)E9V5N(&5N('-N965U
M=P!296=E;B!N86%R('-N965U=P!286YD;VT@1F]R='5N90!697)H;W5D:6YG
M`$QE>F5N`$QE97,@8F5R:6-H=&5N`"5S(&5C:'0@=F5R=VEJ9&5R96X_($1E
M>F4@8F5W97)K:6YG(&MA;B!N:65T(&]N9V5D86%N(&=E;6%A:W0@=V]R9&5N
M+@!'96)R=6EK97)S9&%T82!V86X@9V5B<G5I:V5R("5S(&5C:'0@=F5R=VEJ
M9&5R96X_($1E>F4@8F5W97)K:6YG(&MA;B!N:65T(&]N9V5D86%N(&=E;6%A
M:W0@=V]R9&5N+@!(97)H86%L="!U=R!V;W)I9V4@8F5W97)K:6YG`%9E<G9E
M<G-E;@!697)V97)S(&1Y;F%M:7-C:&4@;65N=2!O;F1E<F1E;&5N.@!0;W)T
M86QW965R9V%V92!V97)V97)S96XZ`%)E9V5X`$)E=')E:VMI;F=E;B!B<F]W
M<V5R`$AE<FQA9&5N`$]P;65R:VEN9V5N`%-E<G9E<G,@;W`@869S=&%N9`!5
M4DP@;W`@869S=&%N9"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ
M`%9E<G=I:F1E<F5N`$)L;VL@=F5R=VEJ9&5R96X`2V]L;VT@=F5R=VEJ9&5R
M96X`3W!M86%K('9E<G=I:F1E<F5N`%!A87(@=F5R=VEJ9&5R96X`5F5R=VEJ
M9&5R(&AE="!O<&=E<VQA9V5N('-C<FEP="!U:70@9&4@=&EJ9&5L:6IK92!D
M:7)E8W1O<GD@;W`@9&4@<V5R=F5R+@!697)W:6ID97(@9&4`5F5R=VEJ9&5R
M(&1E>F4@;F]D92!U:70@:&5T(&1O8W5M96YT`$=E8G)U:6ME<B!V97)W:6ID
M97)E;@!697)W:6ID97(@9V5B<G5I:V5R.B`E<P!697)Z;V5K(&MO;B!N:65T
M('=O<F1E;B!B96%N='=O;W)D+B!'97)E=&]U<FYE97)D92!F;W5T8V]D93H@
M`$1E(&=E=G)A86=D92!S97)V:6-E(&MO;B!N:65T('=O<F1E;B!G979O;F1E
M;BX`5F5R96ES=&4@(B5S(B!N:65T(&]P9V5G979E;B!I;B`E<R!C;VYF:6=U
M<F%T:64N`%9E<F5I<W1E("(E<R(@;FEE="!O<&=E9V5V96X@:6X@5D93(&-O
M;F9I9W5R871I92X`5F5R96ES=&4@(B5S(B!N:65T(&]P9V5G979E;B!I;B!C
M;VYF:6=U<F%T:64N`%9E<F5I<W0@=F5L9`!(97)S=&5L;&5N`%)E<V5T('=A
M8VAT=V]O<F0`4F5S970@=7<@=V%C:'1W;V]R9`!6;V]R9V%A;F1E('%U97)Y
M(&AE<G-T96QL96X`4F5S=6QT871E;@!497)U9R!N86%R(&]P=&EE<P!4>7`@
M;FEE=7<@=V%C:'1W;V]R9"!O<&YI975W`%)E=6YI;VX`0V]N9FEG=7)A=&EE
M('1E<G5G>F5T=&5N`%)I8V@@5&5X="!%9&ET;W(@;W!T:65S`%)A861S96QS
M`%)E8VAT<P!296-H='-E(&MO<`!296-H='-E('=A87)D96X`4FE?:F5I9V5N
M<V-H87!P96XN+BX`4F]L`%)O96UE;FGK`#$X,"!D<F%A:65N`$YA87(@;&EN
M:W,@9')A86EE;@!.86%R(')E8VAT<R!D<F%A:65N`%)I:B!E:6=E;G-C:&%P
M<&5N`%)I:B!E:6=E;G-C:&%P<&5N`%)I:F5N.@!,:6YIZW)I;F<`3&EN:>MR
M:6YG('IA;"!V97)S8VAI:FYE;B!T=7-S96X@86QL92!R:6IE;B!E;B!K;VQO
M;6UE;@!,:6YIZW)I;F<@>F%L(&%L;&5E;B!T=7-S96X@:V]L;VUM96X@=F5R
M<V-H:6IN96X`3&EN:>MR:6YG('IA;"!A;&QE96X@='5S<V5N(')I:F5N('9E
M<G-C:&EJ;F5N`%-T87)T96X`4G5S<VES8VAE($9E9&5R871I90!2=V%N9&$`
M0W)Y<'1O9W)A9FES8VAE(%,O34E-12!H86YD=&5K96YI;F<`4R]-24U%(&=E
M8V]D965R9"!B97)I8VAT`%-!4TP@875T:&5N=&EC871I92!I<R!N:65T(&)E
M<V-H:6MB86%R+@!335,@=F5R<W1U<F5N`%-13"!S:&5L;`!344P@<W1A=&5M
M96YT('9O;W(@=V%A<F1E>F]E:V]P9')A8VAT96X`4U-(`%-50T-%4P!37U%,
M('-H96QL`%IA`%-T($AE;&5N80!3="!+:71T<R!E;B!.979I<P!3="!,=6-I
M80!3="!0:65R<F4@96X@36EQ=65L;VX`4W0@5FEN8V5N="!E;B!D92!'<F5N
M861I;F5S`%IE;&9D92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@96X@4')I;F-I<&4`4V%T96QL:65T<')O=FED97(`4V%U9&D@
M07)A8FGK`$]P<VQA86X`(B5S(B!O<'-L86%N`"5S(&]P<VQA86X`3W!T:65S
M(&]P<VQA86X`1V5G96YE<F5E<F1E(&-O;F9I9W5R871I92!A;',@4$A0('-C
M<FEP="!O<&=E<VQA9V5N(&EN(&1E('1I:F1E;&EJ:V4@9&ER96-T;W)Y('9A
M;B!U=R!S97)V97(N`"5S(&-O;F9I9W5R871I92!O<&=E<VQA9V5N`%-E='5P
M('5P9W)A9&4@<V-R:7!T(&]P9V5S;&%G96X@;F%A<CH@(B5S(BX`1V5S<')E
M:61E(&]N=V5E<G-B=6EE;@!7971E;G-C:&%P`%IO96ME;@!:;V5K;6%C:&EN
M97,`2VEE<R!B97-T86YD96X`4V5L96-T965R(&5E;B!D871U;0!396QE8W1E
M97(@965N(&=R;V5P(&]M('1O92!T92!V;V5G96X`4V5L96-T965R(&5E;B!N
M:65U=V4@96EG96YA87(`4V5L96-T965R(&5E;B!S97)V97(`4V5L96-T965R
M(&5E;B!G96)R=6EK97(@;VT@=&]E('1E('9O96=E;@!!;&QE<R!S96QE8W1E
M<F5N`%-E;&5C=&5E<B!A;&QE(&1A='5M8V]M<&]N96YT96XN`%-E;&5C=&5E
M<B!E96X@;V)J96-T`$YI971S('-E;&5C=&5R96X`4V5L96-T965R(&1E(&)E
M;F]D:6=D92!K87)A:W1E<G,@=6ET(&1E(&]N9&5R<W1A86YD92!V86MJ97,N
M(%4@:W5N="!D97IE(&1A;B!K;W!IZW)E;B!E;B!P;&%K:V5N(&EN(&AE="!T
M96MS=&=E8FEE9"X`4V5L96-T965R(&AE="!D871U;7-C:&5I9&EN9W-T96ME
M;CH`4V5L96-T965R(&AE="!D871U;69O<FUA870Z`%-E;&5C=&5E<B!D92!I
M9&5N=&ET96ET(&1I92!U('=I;'0@=VEJ>FEG96XZ`%-E;&5C=&5E<B!H970@
M=&EJ9'-C:&5I9&EN9W-T96ME;CH`4V5L96-T965R(&AE="!T:6ID<V9O<FUA
M870Z`%-E;&5C=&5E<B!T=V5E(&]V97)E96YK;VUE;F1E('9E;&1E;BX`4V5L
M96-T965R('5W(&ML975R<V-H96UA+@!396QE8W1E97(@=7<@9V5W96YS=&4@
M=&%A;#H`4')O8FQE96UR87!P;W)T('9E<GIE;F1E;@!697)Z96YD(%--4P!3
M96YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E<@!397)V:>L@96X@36]N=&5N96=R
M;P!397)I96YU;6UE<@!397)V97)D871A(&9O=70@;V8@;FEE="!B97-C:&EK
M8F%A<BX`4V5S<VEE8F5H965R9&5R`%-E<W-I92!)1"!V97)L;W!E;BX`4V5S
M<VEE<P!);G-T96QL96X`26YS=&5L;&5N('9A;B!O<'1I97,@;VT@=2!T;V4@
M=&4@<W1A86X@=7<@=V%C:'1W;V]R9"!T92!R97-E='1E;BP@=V%N;F5E<B!U
M(&1I="!B96YT('9E<F=E=&5N+@!);G-T96QL96X@=F%N('-E<G9E<G,@;W`@
M869S=&%N9"!D:64@=2!W:6QT(&)E;F%D97)E;B!V86YU:70@=7<@<&]R=&%L
M+@!);G-T96QL96X@=F%N('5W(&=E=V5N<W1E('1A86PL('1I:F1Z;VYE(&5N
M(&1A='5M;W!T:65S+@!);G-T96QL96X@=F%N('5W(&]P<W1A<G1T;V5P87-S
M:6YG+"!K;&5U<G-C:&5M82P@<&%G:6YA=F5R=F5R<VEN9R!E;B!A;F1E<F4@
M=V5E<F=A=F5O<'1I97,N`$EN<W1E;&QE;@!3971U<"!U<&=R861E('-C<FEP
M=',@8F5S8VAI:V)A87(`5F5R<V-H:6QL96YD92!L;V-A=&EE<R!M;V=E;&EJ
M:R!M970@9&4@<&%R86UA=&5R.B``4V5Y8VAE;&QE;@!7:6YK96QE;@!+;W)T
M92!S86UE;G9A='1I;F<`1&EE;F5N('-N96QT;V5T<V5N('9O;W(@9&4@;65E
M<W1E(&QI;FMS(&=E9&5F:6YI965R9"!T92!W;W)D96X_`%=E97)G979E;@!6
M97)S8VAI;&QE;B!L871E;B!Z:65N('1U<W-E;B!D92!H=6ED:6=E(&]P9V5S
M;&%G96X@8V]N9FEG=7)A=&EE(&5N(&1E(&YI975W92!G96=E;F5R965R9&4@
M8V]N9FEG=7)A=&EE+@!,86%T<W1E(&%A;FUE;&1I;F=S=&EJ9"!W965R9V5V
M96X@8FEJ(&%A;FUE;&1E;C\`3W!T:64@=V5E<F=E=F5N(&]M(&]R:6=I;F5E
M;"!T92!B97=A<F5N`$MI97IE<B!W965R9V5V96X`5&%B96QB97=E<FMI;F=S
M=&%A:V)A;&L@=V5E<F=E=F5N/P`E<R!M96YU(&%A;B!D92!L:6YK97)K86YT
M('=E97)G979E;C\`5&%B96QC96QE:6=E;G-C:&%P<&5N(&1I86QO;V=V96YS
M=&5R('=E97)G979E;@!486)E;&5I9V5N<V-H87!P96X@9&EA;&]O9W9E;G-T
M97(@=V5E<F=E=F5N`%1A8F5L<FEJ96EG96YS8VAA<'!E;B!D:6%L;V]G=F5N
M<W1E<B!W965R9V5V96X`069B965L9&EN9W-E:6=E;G-C:&%P<&5N(&1I86QO
M;V=V96YS=&5R('=E97)G979E;@!5<&QO860@=V5E<F=E=F5N`$)U:65N`$)U
M:65N('9R;V5G`$)U:65N(&QA870`0G5I96X@:6X@9&4@;F%B:6IH96ED`%9E
M<FML96EN96X`5F5R:VQE:6X@;V8@=F5R<&QA871S(&YA8G5R:6=E(&)L;VMK
M96X@965R<W0`4VEE<G)A($QE;VYE`$EN=&5K96YE;@!(86YD=&5K96YI;F<`
M2&%N9'1E:V5N:6YG(&%L9V]R:71H;64`4VEN9V%P;W)E`$=R;V]T=&4`3VYD
M97)H;W5D(&]V97)S;&%A;@!3;&]W86MI:F4`4VQO=F5N:>L`4VYE975W`%-N
M965U=W9L86%G`%-N965U=V)U:65N`'-N965U=V)U:65N('9R;V5G`%-N965U
M=V)U:65N(&QA870`4VYE975W9&EE<'1E.B``4VYE975W97%U:79A;&5N="!I
M;B!W871E<CH@`%-O;&]M;VX@96EL86YD96X`4V]M86QIZP!,:65D97)E;B!E
M;B!G961I8VAT96X`4V]R=&5E<G9O;&=O<F1E('-E;&5C=&EE`$)R;VYA9')E
M<P!:=6ED($%F<FEK80!:=6ED($5U<F]P965S("A)4T\M.#@U.2TS*0!:=6ED
M($=E;W)G:>L@96X@9&4@6G5I9"!386YD=VEC:"!E:6QA;F1E;@!:=6ED96QI
M:FL@:&%L9G)O;F0`4W!A=&GK<FEN9R!T=7-S96X@86%N9W)E;GIE;F1E(&-E
M;&QE;@!3<&%T:>MR:6YG('1U<W-E;B!I;FAO=60@96X@<F%N9"!I;B!C96P`
M4V-H96ED:6YG<W1E:V5N`%-P871IZW)I;F<`4W!A=&GK<FEN9R!E;B!V<FEJ
M92!R=6EM=&4`4W!A;FIE`%-P86T`4W!E8VEA86P@:V%R86MT97(@:6YV;V5R
M`$-E;"!O<'-P;&ET<V5N`$MO;&]M(&]P<W!L:71S96X`4FEJ(&]P<W!L:71S
M96X`4W!O<G0`4W)I($QA;FMA`%-T86YD86%R9`!3=&%R(%1R96L`4W1A<G1J
M86%R`%-T86%T(&]F('!R;W9I;F-I90!3=&%T=7,`3W!S;&%G9F]R;6%A=`!!
M9')E<P!$;V]R:&%L96X`4W1R:6YG;&EJ<W0`4W1R:7`@9&]M96EN('9A;B!H
M970@861R97,`4W1I:FP@6T-34UT`6F\`4W5B9&ER96-T;W)Y("(E<R(@;FEE
M="!G979O;F1E;BX`3VYD97)W97)P`$)E=F5S=&EG96X`5F5R>F]E:R!V97)S
M='5U<F0@;VT@(B5S(B!A86X@:&5T('-Y<W1E96T@=&]E('1E('9O96=E;BX@
M52!K=6YT(&YI970@86%N;65L9&5N('1O="!U=R!V97)Z;V5K(&ES(&=O961G
M96ME=7)D+@!3=6)S8W)I<'0`4W5C8V5S`"(E<R(@;65T('-U8V-E<R!A86X@
M:&5T('-Y<W1E96T@=&]E9V5V;V5G9"X`1&%T82!V86X@9V5B<G5I:V5R("(E
M<R(@;65T('-U8V-E<R!U:70@:&5T('-Y<W1E96T@=F5R=VEJ9&5R9"X`(B5S
M(B!M970@<W5C8V5S('9E<G=I:F1E<F0N`"(E<R(@;65T('-U8V-E<R!U:70@
M:&5T('-Y<W1E96T@=F5R=VEJ9&5R9"X`0V]N9FEG=7)A=&EE(&UE="!S=6-C
M97,@=&5R=6=G97IE="X@5F5R;FEE=7<@;VT@=VEJ>FEG:6YG96X@=&4@>FEE
M;BX`0F%C:W5P8V]N9FEG=7)A=&EE(&UE="!S=6-C97-S(&]P9V5S;&%G96XN
M`$)A8VMU<&-O;F9I9W5R871I96)E<W1A;F0@)7,@;65T('-U8V-E<W,@;W!G
M97-L86=E;BX`(B5S(B!M970@<W5C8V5S(&)I:F=E=V5R:W0`)7,@;65T('-U
M8V-E<R!G97-C:')E=F5N`%-O961A;@!386UE;G9A='1I;F<`6F]N<V]P9V%N
M9P!:;VYS;VYD97)G86YG`%IO;FYI9P!:;VYS;W!G86YG`%IO;G-O<&=A;F<O
M6F]N<V]N9&5R9V%N9P!:;VYS;W!G86YG.B``6F]N<V]N9&5R9V%N9P!:;VYS
M;VYD97)G86YG.B``4W5P97)S8W)I<'0`3VYD97)S=&5U;FEN9P!3=7)I;F%M
M90!!8VAT97)N86%M`%-P:71S8F5R9V5N(&5N($IA;B!-87EE;@!3=V%Z:6QA
M;F0`6G=E9&5N`%IW:71S97)L86YD`%-Y;F,@;&]G('9E<G=I:F1E<F0`4WEN
M8TU,`%-Y;G1A>&9O=70@:6X@>F]E:W1E<FUE;@!3>7)I<V-H92!!<F%B:7-C
M:&4@4F5P=6)L:65K`$]N=V5E<G-B=6D`3VYW965R<V)U:65N(&5N('=I;F1E
M<FEG`$]N=V5E<G-B=6EE;@!/;G=E97)S8G5I96X@=G)O96<`5%-6(&)E<W1A
M;F0`5&%B96QE:6=E;G-C:&%P<&5N`%1A8F5L<V5T`%1A8F5L96EG96YS8VAA
M<'!E;@!486EW86X`5&%I=V%N+"!0<F]V:6YC:64@=F%N($-H:6YA`%1A9'IJ
M:6MI<W1A;@!486YZ86YI82P@5F5R96YI9V1E(%)E<'5B;&EE:R!V86X`1&]E
M;#H`5&%K96X`5&5L969O;VYN=6UM97(`5&5M<&5R871U=7(@=F%N(&AE="!A
M9F=E;&]P96X@=75R.B``5&5M<&5R871U=7(`5&5M<&5R871U=7(Z(`!496UP
M97)A='5U<CQB<B`O/B@E<TAO;V<E<R\E<TQA86<E<RD@)F=R9#LE<P!3:F%B
M;&]O;B`B)7,B(&YI970@9V5V;VYD96XN`%-J86)L;V]N8F5H965R`%1E:W-T
M`$%L;&5E;B!T96MS=`!496MS="!U:71L:6IN96X`5&5K<W1B;W9E;FMA;G0`
M1&\`5&AA:7,@*%1)4RTV,C`I`%1H86EL86YD`$1E($944"!E>'1E;G1I92!I
M<R!N:65T(&)E<V-H:6MB86%R+@!(970@9V5S8VAI961E;FES<WES=&5E;2!I
M<R!U:71G97-C:&%K96QD+@!$92!(;W)D92]+;VQA8B!I;G1E9W)A=&EE(&]N
M9&5R<W1E=6YT("(E<R(@;FEE=`!(970@24U34"!L;V<@:V]N(&YI970@=V]R
M9&5N(&=E:6YI=&EA;&ES965R9"X`1&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!W
M97)D(&YI970@9V5L861E;@!(970@3W!T:65S<V-H97)M(&ES(&=E<VQO=&5N
M+B!!9G-L=6ET96XN`$1E(&)E:&5E<F1E<B!D:65N="!E96X@<&5R;6%N96YT
M(')E8VAT96YB86-K96YD('1E(&-O;F9I9W5R97)E;B!A;',@=2!R96-H=&5N
M('=I;'0@9V5B<G5I:V5N+@!!;&QE96X@9&4@;VYD97)K86YT`$AE="!C;VYT
M86-T($E$(&YU;6UE<B!I<R!N:65T(&]P9V5G979E;BP@;&5E9R!G96QA=&5N
M(&]F(&ES(&YI970@9V5V;VYD96X@:6X@9&4@9&%T86)A<V4N`$AE="!A9')E
M<R!I<R!M970@<W5C8V5S(&%A;B!U=R!A9')E<V)O96L@=&]E9V5V;V5G9"X`
M2&5T(&QO<V=E:V]P<&5L9&4@4$=0(&]N9&5R=&5K96YI;F=S8FQO:R!I<R!V
M97)E:7-T(&]M(&AE="!O;F1E<G1E:V5N9&4@8F5R:6-H="!T92!V97)I9FGK
M<F5N+@!(970@9&ES=')U8G5T:65L:6IS="!)1"!I<R!N:65T(&]P9V5G979E
M;BP@;&5E9R!G96QA=&5N(&]F(&ES(&YI970@9V5V;VYD96X@:6X@9&4@9&%T
M86)A<V4N`$1E(&1I<W1R:6)U=&EE;&EJ<W0@:7,@;FEE="!O<&=E9V5V96XN
M`$1E(&-O9&5E<FUO9V5L:6IK:&5D96X@=F5R96ES96X@965N(&)E=F5I;&EG
M9&4@=V5B=F5R8FEN9&EN9RX`2&5T(&)E<W1A;F0@)7,@9&EE;G0@965N("5S
M(&EN<W1E;&QI;F<@=&4@8F5V871T96XN`$AE="!B97-T86YD("5S(&1I96YT
M(&5N:6=E("5S(&EN<W1E;&QI;F=E;B!T92!B979A='1E;BX`2&5T(&)E<W1A
M;F0@:V%N(&YI970@;F%A<B!Z:6-H>F5L9B!G96MO<&EE97)D('=O<F1E;BX`
M2&5T(&)E<W1A;F0@8F5V871T92!G965N(&1A=&$N`$AE="!V;VQG96YD92!Z
M:6IN(&1E(&MO<'!E;B!V86X@9&ET(&UE<W-A9V4O<F9C.#(R(&)E<FEC:'0N
M`%9A;B!D92!V;VQL961I9R!S8VAE<FT@;6]D92!I<R!B96ME;F0L(&1A="!D
M:70@<')O8FQE;65N(&MA;B!V97)O;W)Z86ME;B!M970@26YT97)N970@17AP
M;&]R97(L('9A;G=E9V4@8G)O=W-E<F)U9W,@=V%A<B!W:6H@;FEE="!O;6AE
M96X@:W5N;F5N+B!(970@:7,@;6]G96QI:FL@9&%T('4@<F]M;65L(&EN(&AE
M="!B965L9'-C:&5R;2P@9V5B<F5K(&%A;B!E9&ET;W)F=6YC=&EE<R!E;B]O
M9B!R86YD;VT@8G)O=W-E<BT@8W)A<VAE<R!E<G9A87)T+B!786YN965R('5W
M('-Y<W1E96T@5VEN9&]W<R`Y>"!I<RP@:7,@:&5T('=A87)S8VAI:FYL:6IK
M(&1A="!U(&5E;B`G06QG96UE;F4@0F5V96EL:6=I;F=S($9O=70G(&MR:6IG
M="P@96X@;W!N:65U=R!D:65N="!T92!H97)S=&%R=&5N+EQN7&Y5(&)E;G0@
M9V5W86%R<V-H=7=D+B!$<G5K(&]P($]+('=A;FYE97(@=2!T;V-H(&1E('9O
M;&QE9&EG('-C:&5R;2!E9&ET;W(@=VEL="!P<F]B97)E;BX`1&4@:61E;G1I
M=&5I="`B)7,B(&ES('9E<G=I:F1E<F0N`$%L;&5E;B!D92!L:6YK97)K86YT
M`$1E('!L86%T<R!V86X@:&5T($=N=5!'('!R;V=R86UM82!D:65N="!O<&=E
M9V5V96X@=&4@=V]R9&5N(&EN(&1E($-R>7!T7W!G<#HZ(&-L87-S+@!(970@
M8F5R:6-H="!V97)S='5U<F0@;W`@)7,@86%N("5S(&UE="!O;F1E<G=E<G`@
M(B5S(B!I<R!W965R9V5G979E;BX*1&ET(&ES(&=E96X@9V%R86YT:64@9&%T
M(&AE="!B97)I8VAT(&ES(&=E;&5Z96X@;V8@8F5G<F5P96XN`$1E(&YA86T@
M9&EE(&=E8G)U:6MT('=O<F1T(&)I:B!L:6YK96X@;F%A<B!D92!N:65U=R!B
M97)I8VAT('!A9VEN80!(970@86%N=&%L('9E;&1E;B!D:65N="!N=6UE<FEE
M:R!T92!Z:6IN+@!$92!O<&5N<W-L(&UO9'5L92!I<R!V97)E:7-T('9O;W(@
M9&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`1&4@=F]O<FME=7)S:6YS
M=&5L;&EN9R`B)7,B(&MO;B!N:65T('=O<F1E;B!O<&=E<VQA9V5N+"!O;61A
M="!D92!D871A(&1E(&UA>&EM=6T@=&]E;&%A=&)A<F4@9W)O;W1T92!O=F5R
M<V-H<FEJ9'0N`$AE="!P<F]G<F%M;6$@;VT@9&ET(&1A=&%T>7!E("@E<RD@
M=&4@8F5K:6IK96XL('=E<F0@;FEE="!O<"!H970@<WES=&5E;2!G979O;F1E
M;BX`2&5T(&%A;FAA;&EN9W-T96ME;B!D:65N="#KZVX@96YK96P@=&5K96X@
M=&4@>FEJ;BX`06QL965N(&1E(')E8VAT97(M(&5N(&QI;FME<FMA;G0`06QL
M965N(&1E(')E8VAT97)K86YT`$AE="!S8VAE:61I;F=S=&5K96X@9&EE;G0@
MZ^MN(&5N:V5L('1E:V5N('1E('II:FXN`$1E('-E<G9E<B`B)7,B(&ES('9E
M<G=I:F1E<F0N`$1E('-E<G9E<B`B)7,B(&ES(&]P9V5S;&%G96XN`$AE="!A
M86YM96QD:6YG<W9E<GIO96L@=F]O<B`E<R!I<R!V97)W:6ID97)D+@!$92!O
M<&=E9V5V96X@<FEJ("@E9"D@8F5S=&%A="!N:65T+@!(970@=&EJ9&5L:6IK
M(&)E<W1A;F0@(B5S(B!B97-T86%T(&YI970N`$1E(&EN9V5V;V5R9&4@=&5K
M<W0@:V]M="!N:65T(&]V97)E96X@;65T(&1E('1E:W-T(&]P(&AE="!S8VAE
M<FTN`$%L;&5E;B!D92!B;W9E;BT@96X@;VYD97)K86YT`$%L;&5E;B!D92!B
M;W9E;FMA;G0`1&4@=7!L;V%D960@9&%T82!I<R!N82!D92!V;V]R9V%A;F1E
M('-T87`@=F5R;&]R96X@9V5G86%N+@!(970@=7!L;V%D960@8F5S=&%N9"!I
M<R!N:65T(&]P9V5S;&%G96XN`$AE="!W96%T:&5R+F-O;2!B;&]K(&ES(&YI
M970@8F5S8VAI:V)A87(N`%1H96UA9&ER96-T;W)Y("(E<R(@;FEE="!G979O
M;F1E;BX`1V5E;B!O<'1I97,@8F5S8VAI:V)A87(N`$5R('II:FX@9V5E;B!O
M;F1E<F1E;&5N+"!W96QK92!I;FQI;F4@=V5E<F=E9V5V96X@:W5N;F5N('=O
M<F1E;BX`17(@>FEJ;B!T92!V965L(&MA<F%K=&5R<R!I;B!D:70@=F5L9"X@
M52!H965F="`E<R!K87)A:W1E<G,@;W!G96=E=F5N.R!U(&1I96YT(&UI;F1E
M<B!D86X@)7,@;W`@=&4@9V5V96XN`$5E;B!P<F]B;&5E;2!M970@:&5T('1O
M979O96=E;B!V86X@(B5S(B!A86X@:&5T('-Y<W1E96TZ("5S`$5E;B!P<F]B
M;&5E;2!M970@:&5T('9E<G=I:F1E<F5N('9A;B!D871A('9A;B!G96)R=6EK
M97(@(B5S(B!U:70@:&5T('-Y<W1E96TZ(`!%96X@<')O8FQE96T@;65T(&AE
M="!V97)W:6ID97)E;B!V86X@(B5S(B!U:70@:&5T('-Y<W1E96TZ(`!%96X@
M<')O8FQE96T@;65T(&AE="!B:6IW97)K96X@=F%N("(E<R(Z("5S`$5E;B!P
M<F]B;&5E;2!M970@9&4@8F5S=&%N9'-U<&QO860Z($=E96X@)7,@=V5R9"!G
M975P;&]A9"X`165N('!R;V)L965M(&UE="!D92!B97-T86YD<W5P;&]A9#H@
M2&5T("5S(&ES(&=R;W1E<B!D86X@9&4@;6%X:6UU;2!T;V5L86%T8F%R92!G
M<F]O='1E("@E9"!B>71E<RDN`$5E;B!P<F]B;&5E;2!M970@9&4@8F5S=&%N
M9'-U<&QO860Z($AE="`E<R!I<R!S;&5C:'1S(&=E9&5E;'1E;&EJ:R!G975P
M;&]A9"X`165N(&9O=70@8FEJ(&AE="!B96MI:FME;B!V86X@9&ET(&)E<FEC
M:'1O;F1E<F1E96P`165N(&9O=70@8FEJ(&AE="!I;7!O<G1E<F5N('9A;B!D
M92!A9')E<V1A=&$N`$5E;B!F;W5T(&)I:B!H970@:6UP;W)T97)E;B!V86X@
M9&4@:4-A;&5N9&%R9&%T82X`165N(&9O=70@:6X@:&5T(&-O;F9I9W5R871I
M969O<FUU;&EE<BX@36ES<V-H:65N(&)E;G0@=2!E96X@=F5R<&QI8VAT('9E
M;&0@=F5R9V5T96XN`$5E;B!F;W5T(&)I:B!H970@=6ET=F]E<F5N('9A;B!D
M92!O<&=E9V5V96X@861R97-B;V5K9G5N8W1I92X@4')O8F5E<B!L871E<B!O
M<&YI975W+"!A+G4N8BX`165N(&9O=70@;65T(&AE="!B:6IW97)K96X@=F%N
M(&1E(&%D<F5S9&5T86EL<RX@4')O8F5E<B!L871E<B!O<&YI975W+"!A+G4N
M8BX`165N(&9O=70@;65T(&AE="!B:6IW97)K96X@=F%N(&1E(&1I<W1R:6)U
M=&EE;&EJ<W0N(%!R;V)E97(@;&%T97(@;W!N:65U=RP@82YU+F(N`$1E>F4@
M24U!4"!S97)V97(@;VYD97)S=&5U;G0@9V5E;B!D96QI;F<@=F%N(&UA<'!E
M;BX`1&ET(&QI:FMT(&YI970@965N(&=E;&1I9R!R87(@8F5S=&%N9"!T92!Z
M:6IN+@!$:70@;&EJ:W0@;FEE="!E96X@9V5L9&EG('II<"!B97-T86YD('1E
M('II:FXN`$1I="!L:6IK="!N:65T(&5E;B!G96QD:6<@:V%A<G1N=6UM97(@
M=&4@>FEJ;BX`1&ET('-T=75R<')O9W)A;6UA(&=E969T(&1E(&UO9V5L:6IK
M:&5I9"!O;2!B97)I8VAT96X@=FEA(&1E($-L:6-K871E;&P@*&AT='`Z+R]C
M;&EC:V%T96QL+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D
M92!(5%10($%020!$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI
M:FMH96ED(&]M(&)E<FEC:'1E;B!V:6$@9&4@5TE.("AH='1P.B\O=VEN<&QC
M+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(5%10($%0
M20!$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M
M(&)E<FEC:'1E;B!V:6$@9&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@9V%T97=A>2!T92!V97)Z96YD96XL(&0N;2YV+B!D92!(5%10($%0
M20!$:70@<W1U=7)P<F]G<F%M;6$@9V5E9G0@9&4@;6]G96QI:FMH96ED(&]M
M(&)E<FEC:'1E;B!V:6$@4TU44"!D+FTN=BX@9&4@5F]D869O;F4@271A;'D@
M9V%T97=A>2!T92!V97)Z96YD96X@;F%A<B!6;V1A9F]N92!N=6UM97)S+B!(
M:65R=F]O<B!I<R!E96X@5F]D869O;F4@271A;'D@92UM86EL861R97,@*&AT
M='`Z+R]W=W<N,3DP+FET*2!N;V]D>F%K96QI:FLN`$1I="!V96QD(&ES('9E
M<F5I<W0`1&ET('9E;&0@;6%G(&%L;&5E;B!I;G1E9V5R<R!B979A='1E;BX`
M1&ET('9E;&0@;6%G(&%L;&5E;B!G971A;&QE;B!E;B!D92!D=6)B96QE('!U
M;G0@8F5V871T96XN`$1I="!V96QD(&UA9R!A;&QE96X@;V-T86%L('=A87)D
M96X@8F5V871T96XN`$1I="!V96QD(&1I96YT(&5E;B!K;VUM82!O9B!S<&%T
M:64@9V5S8VAE:61E;B!L:6IS="!M970@:6YT96=E<G,@=&4@>FEJ;@!$97IE
M('=A87)D92!D:65N="!E96X@9V5L9&EG(&=E=&%L('1E('II:FXN`$1I="!V
M96QD(&1I96YT(&5E;B!K;&5U<F-O9&4@:6X@4D="($A%6"UF;W)M86%T('1E
M(&)E=F%T=&5N+"!B+G8N("<C,3(S-&%F)RX`1&ET(&9O<FUU;&EE<B!I<R!R
M965D<R!V97)W97)K="X`1&ET(&ES("5S+@!$:70@:7,@965N($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N($]M(&1I="!O8FIE8W0@=V5E<B!T92!G979E;B!H
M965F="!U(&5E;B!E+6UA:6P@8VQI96YT(&YO9&EG(&1I92!H970@2V]L86(@
M1W)O=7!W87)E(&9O<FUA870@8F5G<FEJ<'0N(%9O;W(@965N(&QI:G-T(&UE
M="!D97IE(&4M;6%I;&-L:65N=',L(&)E>F]E:R`E<RP@82YU+F(N`$1I="!B
M97)I8VAT(&ES(&EN(&5E;B!A;F1E<F4@:V%R86MT97)S970@*"5S*2!G97-C
M:')E=F5N+"!D86X@=7<@96EG96XN`$1I="!G971A;"!D:65N="!T96YM:6YS
M=&4@Z>EN('1E('II:FXN`$1E>F4@<V5R=F5R(&MA;B!G965N('II<"!E;B!G
M>FEP(&)E<W1A;F1E;B!U:71P86MK96XN`$AE="!S>7-T965M(&ES(&UO;65N
M=&5E;"!U:71G97-C:&%K96QD+@!$97IE('=A87)D92!D:65N="!E96X@9V5T
M86P@=&4@>FEJ;BX`1&ET('-C:&5R;2!D:65N="!A86YG97)O97!E;B!T92!W
M;W)D96X@=F%N=6ET(&5E;B!/<'1I97-S8VAE<FT`3VYW965R`%1I8VME=',`
M5&EJ9`!4:6ID<&QA;FYI;F<`5&EJ9&9O<FUA870`5&EJ9'-E;&5C=&EE`%1I
M;6]R+4QE<W1E`%1I=&5L`%1I=&5L("AT;V]L=&EP*3H`06%N`$]M(&UE97)D
M97)E(&]N9&5R9&5L96X@=&4@<V5L96-T97)E;BP@:&]U9"!D92!#;VYT<F]L
M("A00RD@;V8@0V]M;6%N9"`H36%C*2!T;V5T<R!V87-T('1I:F1E;G,@:VQI
M:VME;BX`5F%N9&%A9P!(5$U,(&)R;VX@;VUS8VAA:V5L96X`5&]G;P!4;VME
M;&%U`$UO<F=E;@!4;VYG80!492!V965L(&]N9V5L9&EG92!A86YM96QD:6YG
M96X@9V5D=7)E;F1E(&1E(&%F9V5L;W!E;B!M:6YU=&5N+@!";W9E;FMA;G0`
M0F]V96YS=&4@9G)A;64@*%]T;W`I`%9E<G1A;&EN9V5N`%1R:6YI9&%D(&5N
M(%1O8F%G;P!4<G5E(&]F(&9A;'-E`$1I`%1U;F5S:>L`5'5R:VEJ90!4=7)K
M<R`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&5N($-A:6-O<R!E
M:6QA;F1E;@!4=79A;'4`5'EP('5W(&ME=7IE.B``52Y6+B!I;F1E>#H@`%52
M3`!54DP@=F]O<B!U=R!A9FQE=F5R:6YG<W-T871U<W)A<'!O<G0@<V-R:7!T
M`%523#H`3V5G86YD80!/96MR8>]N90!.:65T(&EN('-T86%T(%9&4R!D:7)E
M8W1O<GD@86%N('1E('-P<F5K96XN`$YI970@:6X@<W1A870@97AT<F$@9V5B
M<G5I:V5R<VEN9F]R;6%T:64@=&]E('1E('9O96=E;B!B:6H@:6YS8VAR:6IV
M96XN`$YI970@:6X@<W1A870@9&4@<F5C:'1E;B!V86X@5D93(&)E<W1A;F0@
M(B5S(B!T92!W:6IZ:6=E;BX`3FEE="!I;B!S=&%A="!D92!R96-H=&5N('9A
M;B!61E,@8F5S=&%N9"`E<R\E<R!T92!W:6IZ:6=E;BX`3FEE="!I;B!S=&%A
M="!T92!W:6IZ:6=E;B!N86%R("5S+@!.:65T(&EN('-T86%T(&)E<W1A;F1S
M9W)O;W1T92!V86X@(B5S(B!T92!C;VYT<F]L97)E;BX`3FEE="!I;B!S=&%A
M="!B97-T86YD<V=R;V]T=&4@=F%N("(E<R\E<R(@=&4@8V]N=')O;&5R96XN
M`$YI970@:6X@<W1A870@;65T(&1E(%-13"!S97)V97(@=&4@=F5R8FEN9&5N
M+@!.:65T(&EN('-T86%T(&UE="!34TP@=&4@=F5R8FEN9&5N+@!.:65T(&EN
M('-T86%T(%9&4R!B97-T86YD('1E(&MO<&GK<F5N+@!.:65T(&EN('-T86%T
M(%9&4R!D:7)E8W1O<GD@(B5S(B!T92!M86ME;BX`3FEE="!I;B!S=&%A="!6
M1E,@9&ER96-T;W)Y('1E(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!B97-T
M86YD('1E(&UA:V5N+@!.:65T(&EN('-T86%T(%9&4R!M87`@(B5S(B!T92!M
M86ME;BX`3FEE="!I;B!S=&%A="!E96X@;&5E9R!61E,@8F5S=&%N9"!T92!M
M86ME;BX`3FEE="!I;B!S=&%A="!D871A('5I="!T92!P86MK96XN`$YI970@
M:6X@<W1A870@(B5S(B!T92!V97)W:6ID97)E;BP@9&4@9&ER96-T;W)Y(&ES
M(&YI970@;&5E9P!.:65T(&EN('-T86%T("(E<R(Z("5S('1E('9E<G=I:F1E
M<F5N+@!.:65T(&EN('-T86%T("5S('1E('9E<G=I:F1E<F5N+"!D92!D:7)E
M8W1O<GD@:7,@;FEE="!L965G`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R
M>2!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@5D93
M(&1I<F5C=&]R>2!T92!V97)W:6ID97)E;BX`3FEE="!I;B!S=&%A="!61E,@
M9&ER96-T;W)Y("5S('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&
M4R!B97-T86YD("(E<R(@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@
M5D93(&)E<W1A;F0@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@5D93
M(&UA<"`B)7,B('1E('9E<G=I:F1E<F5N+@!.:65T(&EN('-T86%T(%9&4R`E
M<R!R96-U<G-I968@=&4@=F5R=VEJ9&5R96XN`$YI970@:6X@<W1A870@:'5I
M9&EG92!D:7)E8W1O<GD@=&4@8F5P86QE;BX`3FEE="!I;B!S=&%A="!C97)T
M:69I8V%A=&1E=&%I;',@=6ET('1E(&9I;'1E<F5N`$YI970@:6X@<W1A870@
M;VT@9&4@9&5F:6YI=&EE('9A;B`E<R!T92!L861E;BX`3FEE="!I;B!S=&%A
M="!61E,@8F5S=&%N9"!T92!V97)P;&%A='-E;BX`3FEE="!I;B!S=&%A="!6
M1E,@8F5S=&%N9"`B)7,B('1E(&]P96YE;BX`3FEE="!I;B!S=&%A="!61E,@
M8F5S=&%N9"!T92!O<&5N96X@=F]O<B!S8VAR:6IV96XN`$YI970@:6X@<W1A
M870@5D93(&)E<W1A;F0@=&4@;W!E;F5N+@!.:65T(&EN('-T86%T(&AE="!I
M;F=E<&%K=&4@8F5S=&%N9"!T92!O<&5N96XN`$YI970@:6X@<W1A870@5D93
M(&)E<W1A;F0@=&4@;&5Z96X@*&9I;&5S:7IE*"D@;6ES;'5K="DN`$YI970@
M:6X@<W1A870@5D93(&)E<W1A;F0@=&4@;&5Z96X@*&=E=$9I;&53:7IE*"D@
M;6ES;'5K="DN`$YI970@:6X@<W1A870@8F5S=&%N9"!T92!L97IE;CH@`$YI
M970@:6X@<W1A870@=F9S<F]O="!D:7)E8W1O<GD@=&4@;W!E;F5N+@!.:65T
M(&EN('-T86%T(&]M("5S('1E(&AE<FYO96UE;B!N86%R("5S.B!B97-T96UM
M:6YG<VUA<"!B97-T86%T(&%L`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R
M>2!T92!H97)N;V5M96XN`$YI970@:6X@<W1A870@5D93(&1I<F5C=&]R>2`E
M<R!T92!H97)N;V5M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@(B5S
M(B!T92!H97)N;V5M96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@)7,O
M)7,@=&4@:&5R;F]E;65N+@!.:65T(&EN('-T86%T(%9&4R!B97-T86YD('1E
M(&AE<FYO96UE;BX`2V%N("=M:VES;V9S)R!N:65T('5I='9O97)E;BX`3FEE
M="!I;B!S=&%A="!D:70@5V]R9"!D;V-U;65N="!T92!V97)T86QE;@!.:65T
M(&EN('-T86%T(%9&4R!B97-T86YD("(E<R(@=&4@<V-H<FEJ=F5N+@!.:65T
M(&EN('-T86%T(%9&4R!B97-T86YD('1E('-C:')I:G9E;B`H8V]P>2@I(&9A
M:6QE9"DN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F1S9&%T82!T92!S8VAR
M:6IV96XN`$YI970@:6X@<W1A870@5D93(&)E<W1A;F0@=&4@<V-H<FEJ=F5N
M+"!Q=6]T82!W;W)D="!O=F5R<V-H<F5D96XN`$]N9&5R<W1R97!E;@!(97)S
M=&5L('=I:GII9VEN9V5N`$1O970@=7<@;&%A='-T92!B97=E<FMI;F<@=&5N
M:65T`$]N=F5R=V%C:'0@86YT=V]O<F0@=F%N(&1E('-E<G9E<B!O<"!V97)B
M:6YD:6YG.B``3VYV97)W86-H="!A;G1W;V]R9"!V86X@<V5R=F5R(&%A;CH@
M`$]N8F5N;V5M9`!5;FEC;V1E("A55$8M."D`5F5R96YI9V1E($%R86)I<V-H
M92!%;6ER871E;@!697)E;FEG9"!+;VYI;F=K<FEJ:P!697)E;FEG9&4@4W1A
M=&5N`%9E<F5N:6=D92!3=&%T96XL(&ML96EN92!B=6ET96X@;&EG9V5N9&4@
M96EL86YD96X`165N:&5D96X`3VYB96ME;F0`3VYB96ME;F0@87!I;7-G:60@
M*$%022!-97-S86=E($E$*2X`3VYB96ME;F0@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`3VYB96ME;F1E(&QO8V%T:64@;W!G96=E=F5N+@!/;F)E
M:V5N9&4@9V5B<G5I:V5R<VYA86T@;V8@=V%C:'1W;V]R9"X`2&5T(&AU:61I
M9V4@96QE;65N="!L;W-K;W!P96QE;@!/;F)E;F]E;60`3FEE="!G97)E8VAT
M:6=D92!S8W)I<'1S(&MU;FYE;B!P<F]G<F%M;6%M871I9R!N:65T($MN:7!P
M96XO2V]P:>MR96XO4&QA:VME;BP@=F%N=V5G92!B979E:6QI9VEN9W-R961E
M;F5N+B!+;&EK(&]P($]+(&]M(&5E;B!T96-H;FES8VAE(&]P;65R:VEN9R!O
M<"!M;WII;&QA+F]R9R!T92!B96MI:FME;B!H;V4@=2!E96X@<V-R:7!T('1O
M97-T86%T(&AE="!P<FEK8F]R9"!T92!B96YA9&5R96XN`$ML975R('1E<G5G
M<W1E;&QE;@!.:65T(&]N9&5R<W1E=6YD92!E>'1E;G1I90!":6IW97)K96X`
M)7,@8FEJ=V5R:V5N`$=E8G)U:6ME<B!B:6IW97)K96XN`"(E<R(@8FEJ9V5W
M97)K="X`57!G<F%D92!S8W)I<'0@=F5R=VEJ9&5R9"X`57!L;V%D`$%L;&4@
M=&]E<&%S<VEN9R!S971U<&)E<W1A;F1E;B!N86%R(&1E('-E<G9E<B!G975P
M;&]A9"X`3&%T:6IN<V4@:&]O9F1L971T97)S`$=R;W1E(%)O;65I;G-E(&=E
M=&%L;&5N`%5R=6=U87D`1V5B<G5I:R!H=6ED:6=E.B`E<P!'96)R=6EK(%-3
M3`!'96)R=6EK96X@=V%N;F5E<B!N86%M+W=A8VAT=V]O<F0@=F5R<V-H:6QT
M(&UE="!)35-0('-E<G9E<BX`1V5B<G5I:V5R`$=E8G)U:6ME<B`E<R!I<R!N
M:65T(&=E875T;W)I<V5E<F0@=F]O<B`E<RX`1V5B<G5I:V5R<V)E:&5E<@!'
M96)R=6EK97)S;W!T:65S`$=E8G)U:6ME<G-R96=I<W1R871I90!'96)R=6EK
M97)S<F5G:7-T<F%T:64@:7,@=6ET9V5S8VAA:V5L9"!O<"!D97IE('-I=&4N
M`$=E8G)U:6ME<G-A8V-O=6YT(&YI970@9V5V;VYD96XN`$=E8G)U:6ME<G-N
M86%M`$=E8G)U:6ME<G-N86%M("(E<R(@8F5S=&%A="!A;"X`1V5B<G5I:V5R
M<VYA86TZ`$=E8G)U:6ME<G-N86%M.B``1V5B<G5I:V5R<R!I;B!H970@<WES
M=&5E;3H`3V5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!B97-T86%T(&YI970N
M`$%F=V5Z:6=H96ED`$=E=F]N9&5N(&=E;&1I9V4@;&]C871I97,@8F5V871T
M96XZ(`!'96QD:6=H96ED`%=A87)D92!I;B!M:6YU=&5N('9A;F%F(&YU+@!7
M86%R9&4@;&EG="!B;W9E;B!D92!M87AI;75M(&QE;F=T92!V86X@)7,N`%=A
M87)D96X`5V%A<F1E;B!W86%R=6ET(&=E<V5L96-T965R9"!K86X@=V]R9&5N
M`%9A;G5A='4`5F%R:6%B96QE`%9E;F5Z=65L80!697)I9FEC871I92!M:7-L
M=6MT("T@97(@:V%N(&UE="!D:70@8F5R:6-H="!G96MN;V5I9"!Z:6IN+@!6
M97)S:64`5F5R<VEE8V]N=')O;&4`5F5R=&EK86%L('5I=&QI:FYE;@!697)T
M:6MA;&4@=G)I:F4@<G5I;71E`%9E<G1I:V%A;#H`17)G(&AO;V<`5FEE=&YA
M;0!6:65T;F%M965S("A625-#24DI`"5S(&)E:VEJ:V5N`$)E:VEJ:R!E96X@
M97AT97)N92!W96)P86=I;F$`0F5K:6IK96X@86QS("5S`$UA86=D96X@96EL
M86YD96XL($)R:71S90!-86%G9&5N(&5I;&%N9&5N+"!6+E,N`%II8VAT`%II
M8VAT.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!704%24T-(55=)
M3D<A(2$@(%9%4E=)2D1%4B!30U))4%0@2$%.1$U!5$E'(%5)5"`E<RX`5TE.
M('9I82!(5%10`%=A;&QI<R!E;B!&=71U;F$`5V%A<G-C:'5W:6YG`%=O`%=E
M97)S=F]O<G5I='II8VAT`%=E97)B97)I8VAT(&=E9V5V96YS(&=E;&5V97)D
M(&1O;W(`5V5A=&AE<BYC;VT`5V5B`%=E8G-I=&4`5V5K96QI:FMS`%=E;&MO
M;0!796QK;VT@8FEJ("5S`%=E;&MO;2P@)7,`5V5S=&5R<R`H25-/+3@X-3DM
M,2D`5V5S=&5R<R`H25-/+3@X-3DM,34I`%=E<W1E;&EJ:V4@4V%H87)A`%=E
M;&ME('1O97!A<W-I;F<@9&EE;G0@)7,@=V5E<B!T92!G979E;B!N82!A86YM
M96QD:6YG/P!7870@:7,@:&5T('-C:&5I9&EN9W-K87)A:W1E<C\`5V%T(&ES
M(&AE="!C:71A871K87)A:W1E<C\`5VAE<F5I<R!!=7-T<F%L:>L@:V%A<G0`
M5V5L:V4@9F%S96X`5V5L:V4@<&QU9VEN<R!V;V]R(&1E(%)I8V@@5&5X="!E
M9&ET;W(@:6YS8VAA:V5L96XN`$)R965D=&4`0G)E961T92!I;B!#4U,@965N
M:&5D96X`0G)E961T92!V86X@:&5T("5S(&UE;G4@86%N(&1E(&QI;FME<FMA
M;G0@*&%K=&EE9B!B:6H@=F]L9V5N9&4@86%N;65L9&EN9RDZ`$)R965D=&4@
M=F%N(&1E('1A8F5L`$)R965D=&4@965N:&5I9`!"<F5E9'1E.@!7:6MI`%=I
M;F0`5VEN9"!V<F]E9P!7:6YD<VYE;&AE:60@:6X@:VYO<&5N`%=I;F0Z`%=I
M;F0Z(`!7:6IS:&5I9`!796YS;&EJ<W0`5V5R:P!797)K861R97,`5&5L+FYR
M+B`H=V5R:RD`5F5R:V5E<F0@86%N=&%L('9E;&1E;B!I;B!R96=E;"`E9"X@
M5F5R=V%C:'0@)60L(&=E=F]N9&5N("5D+@!697)K965R9"!A86YT86P@=F5L
M9&5N+B!697)W86-H="`E9"P@9V5V;VYD96X@)60N`%9E<FME97)D92!O9F9S
M970@)60@8FEJ(&QE>F5N('9A;B!61E,@8F5S=&%N9"X`6"U2968`6#4P.78S
M(&)A<VES8F5P97)K:6YG96X`6#4P.78S('5I=&=E8G)E:60@<VQE=71E;&=E
M8G)U:6L`6#4P.78S(&%L=&5R;F%T:65V92!O;F1E<G=E<G!N86%M`%@U,#EV
M,R!O;F1E<G=E<G`@<VQE=71E;&ED96YT:69I8V%T;W(`6#4P.78S(&5X=&5N
M=&EE<P!*2@!*2DI*`%EA:&]O(2!M87``2F%A<FQI:FMS`$IE;65N`$IA`$IA
M+"!I:R!A8V-E<'1E97(@9&4@=F]O<G=A87)D96X`52!B96YT(&EN(%1%2U-4
M($U/1$4N($=E8G)U:6L@9&4@6SP^72!K;F]P(&]M(&YA87(@5UE325=91R!T
M97)U9R!T92!S8VAA:V5L96XN`$AE="!I<R!U(&YI970@=&]E9V5S=&%A;B!O
M;2!M965R(&1A;B`E9"!B;&]K:V5N('1E(&UA:V5N+@!5(&)E;G0@;FEE="!G
M96%U=&AE;G1I9FEC965R9"X`52!K=6YT(&=E96X@)UPG(&MA<F%K=&5R(&EN
M('5W('9O;&QE9V4@;F%A;2!H96)B96XN`%4@:&5E9G0@9V5E;B!G96QD:6<@
M92UM86EL861R97,@;W!G96=E=F5N+@!5(&AE969T(&=E96X@=F5L9&5N('5I
M="!H970@9V5I;7!O<G1E97)D92!B97-T86YD(&=E:V]P<&5L9"!M970@9&4@
M;W9E<F5E;FMO;7-T:6=E('9E;&1E;B!I;B`E<RX`52!B96YT(&%F9V5M96QD
M+@!5(&1I96YT(&5E;B!G96QD:6<@;6]B:65L(&YU;6UE<B!I;B!T92!V;V5R
M96XL(&%L;&5E;B!C:6IF97)S(&UE="!E96X@;W!T:6]N96QE("<K)R!V;V]R
M(&AE="!I;G1E<FYA=&EO;F%L92!K:65S=F]O<G9O96=S96PN`%4@9&EE;G0@
M965N(&=E;&1I9V4@=V%A<F1E(&]P('1E(&=E=F5N+@!5(&1I96YT(&5E;B!$
M871A5')E92!B86-K96YD('1E(&-O;F9I9W5R97)E;B!O;2!I;G-C:')I:G9I
M;F=E;B!T92!K=6YN96X@9V5B<G5I:V5N+@!5(&1I96YT(&5E;B!61E,@8F%C
M:V5N9"!T92!C;VYF:6=U<F5R96XN`%4@9&EE;G0@:&5T('!R;V)L965M('1E
M(&)E<V-H<FEJ=F5N+"!V;V]R9&%T('4@:&5T('!R;V)L965M<F%P<&]R="!K
M=6YT('9E<GIE;F1E;BX`52!D:65N="!E96X@55),(&EN('1E('9O97)E;B!W
M86%R;F%A<B!D97IE(&QI;FL@=F5R=VEJ<W0`52!D:65N="!E96X@<V5R=F5R
M('1E('-E;&5C=&5R96X@;VT@=&4@=F5R=VEJ9&5R96XN`%4@9&EE;G0@965N
M(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E=F5N(&]M('1E('=I<W-E;BX`52!D
M:65N="!E96X@9V5B<G5I:V5R<VYA86T@;W`@=&4@9V5V96X@;VT@=&4@=F5R
M=VEJ9&5R96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N86%M(&]P('1E(&=E
M=F5N(&]M('1O92!T92!V;V5G96XN`%4@9&EE;G0@965N(&=E8G)U:6ME<G-N
M86%M(&]P('1E(&=E=F5N(&]M(&)I:B!T92!K=6YN96X@=V5R:V5N+@!5(&1I
M96YT(&5E;B!B97=E<FMI;F<@;W`@=&4@9V5V96X@=V5L:V4@=6ET9V5V;V5R
M9"!M;V5T('=O<F1E;BX`52!D:65N="!E96X@;FEE=7=E(&-A=&5G;W)I96YA
M86T@;W`@=&4@9V5V96XN`%4@9&EE;G0@965N($ET86QI86%N<R!T96QE9F]O
M;FYU;6UE<B!O<"!T92!G979E;@!5=R`E<R!S97-S:64@:7,@=F5R;&]P96XN
M($]P;FEE=7<@86%N;65L9&5N+"!A+G4N8BX`57<@92UM86EL861R97,`57<@
M5F%N.B!A9')E<SH`57<@:6YF;W)M871I90!5=R!I;G1E<FYE=&%D<F5S(&ES
M(&=E=VEJ>FEG9"!S:6YD<R!H970@8F5G:6X@=F%N('5W("5S('-E<W-I92X@
M3VT@=7<@=F5I;&EG:&5I9"!T92!B97-C:&5R;65N+"!D:65N="!U('II8V@@
M;W!N:65U=R!A86X@=&4@;65L9&5N+@!5=R!N86%M.@!(970@=&]E=F]E9V5N
M('9A;B!G96)R=6EK97)S('=O<F1T(&YI970@;VYD97)S=&5U;F0@9&]O<B!U
M=R!A=71H96YT:6-A=&EE(&)A8VME;F0N(%=A;FYE97(@=2!(;W)D92!G96)R
M=6EK97)S('=I;'0@8F5H97)E;BP@9&EE;G0@=2!E96X@86YD97(@875T:&5N
M=&EC871I92!B86-K96YD('1E(&=E8G)U:6ME;BX`2&5T('=E97)G979E;B!V
M86X@965N(&=E8G)U:6ME<G-L:6IS="!W;W)D="!N:65T(&]N9&5R<W1E=6YD
M(&1O;W(@=7<@875T:&5N=&EC871I92!B86-K96YD+"!O9B!D97IE(&]P=&EE
M(&ES(&]M(&%N9&5R92!R961E;F5N('5I=&=E<V-H86ME;&0N`%5W(&)R;W=S
M97(@;&EJ:W0@=&4@>FEJ;B!G97=I:GII9V0@<VEN9',@:&5T(&)E9VEN('9A
M;B!U=R`E<R!S97-S:64N($]M('5W('9E:6QI9VAE:60@=&4@8F5S8VAE<FUE
M;BP@9&EE;G0@=2!Z:6-H(&]P;FEE=7<@86%N('1E(&UE;&1E;BX`57<@8G)O
M=W-E<B!O;F1E<G-T975N="!D97IE(&UO9V5L:6IK:&5I9"!N:65T+@!5=R!B
M<F]W<V5R(&]N9&5R<W1E=6YT(&1E>F4@<')I;G1O<'1I92!N:65T+B!$<G5K
M(&]P($-O;G1R;VPO0V]M;6%N9"`K(%`@;VT@868@=&4@9')U:VME;BX`57<@
M:'5I9&EG92!T:6ID>F]N93H`57<@<W1A;F1A87)D(&ED96YT:71E:70@:7,@
M9V5W:6IZ:6=D+@!5=R!S=&%N9&%A<F0@:61E;G1I=&5I=#H`57<@=F]L;&5D
M:6=E(&YA86TZ`%5W(&%A;FUE;&1I;F<@:7,@=F5R;&]P96XN`%5W(&YI975W
M92!W86-H='=O;W)D('9O;W(@)7,@:7,Z("5S`%5W(&]P=&EE<R!Z:6IN(&)I
M:F=E=V5R:W0@=F]O<B!D92!D=75R('9A;B!D97IE('-E<W-I92X`57<@;W!T
M:65S('II:FX@8FEJ9V5W97)K="X`57<@=V%C:'1W;V]R9"!I<R!G97)E<V5T
M`%5W('=A8VAT=V]O<F0@:7,@=F5R;FEE=7=D+"!C;VYT<F]L965R('5W(&4M
M;6%I;"!E;B!M96QD(&%A;B!M970@=7<@;FEE=7=E('=A8VAT=V]O<F0N`%5W
M('=A8VAT=V]O<F0@:7,@=F5R;&]P96XN`%5W('-E<G9E<G,@;W`@869S=&%N
M9#H`2F]E9V]S;&%V:>L`6F'O<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M6
M97)B97)G(&%A;F=E:&%A;&1E('1E:W-T70!;4')O8FQE96UR87!P;W)T70!;
M06%N9V5H86%L9&4@=&5K<W0@=V5E<F=E=F5N("T`6T%A;F=E:&%A;&1E('1E
M:W-T("T@)7,@<F5G96QS70!;<F5G96P@)7,@=F%N("5S70!"7V5H965R`%]#
M3$D`7T1A=&%4<F5E`%9E<E]W:6ID97(@<FEJ`%]'<F]E<&5N`%](96QP`%]!
M9F)E96QD:6YG<V5I9V5N<V-H87!P96XN+BX`7T%A;FUE;&1E;@!?069M96QD
M96X`7U=I:GII9R!L:6YK+BXN`%]/<'1I97,`7U)E8VAT96X`7U9E<G=I:F1E
M<B!L:6YK+BXN`%]);G-T96QL96X`7U1A8F5L96EG96YS8VAA<'!E;BXN+@!'
M95]B<G5I:V5R<P!!9')E<V)O96L`1V5A9')E<W-E97)D92!O;F)E:V5N9`!+
M86QE;F1E<@!+86QM`$MA;B!O=71P=71B97-T86YD(&YI970@;6%K96X`2V%N
M(&EN<'5T(&YI970@;W!E;F5N`$ML:6L@:&EE<@!#;VUM86YD;W)E9V5L(&=E
M8G)U:6MS9F]U=`!#;VYF:6=U<F%T:65F;W5T`$MR:71I<V-H('-Y<W1E96UB
M97-T86YD(&]N=&)R965K=`!$871A9F]R;6%A=&9O=70`8F5W97)K96X`:6YV
M;V5R(&YI970@9V5V;VYD96X`9&%L96YD`&)E<W1A;F0`=F%N(&1E("5S("@E
M<RD@;W`@)7,@)7,`=FQA9V5R:6<`:#H`:&@`:&]S=&YA86T@;VYB96ME;F0`
M;VYM:61D96QI:FL`:6YL:6YE`&EN<'5T+V]U='!U="!F;W5T`&EN=&5R;F4@
M<V]F='=A<F5F;W5T`')E9V5L<UT`;6MI<V]F<R!F;W5T8V]D92`E9"!B:6H@
M:&5T(&%A;FUA:V5N('9A;B!)4T\N`&UM`&YA86T`;FEE="!V86X@=&]E<&%S
M<VEN9P!.;V<@;FEE="!V86X@=&]E<&%S<VEN9P!N;W1I=&EE8F]E:P!P<F]C
M96YT`%)E8VAT(&=E=V5I9V5R9`!P:7AE;',`4F5M;W1E(&9O=70@:6X@<')O
M=&]C;VP`<W1I:F=E;F0`4V5R=FEC92!N:65T(&)E<V-H:6MB86%R`'1O;VX@
M=F5R<V-H:6QL96X`<VUS,F5M86EL('9I82!(5%10`'-S`'-T86)I96P`<WES
M=&5E;69O=70`=&%K96YL:6IS=`!T:6ID96QI:FME(&UI<VQU:VMI;F<`5F]E
M<BP@=&5R(&)E=F5S=&EG:6YG+"!H970@=V%C:'1W;V]R9"!T=V5E(&UA86P@
M:6X`=6YI9FEE9`!O;F)E;F]E;60`1V5B<G5I:V5R<V5L96-T:64`=D-A<F0`
M=SH`=V5A=&AE<BYC;VT`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]N8E].3R],0U]-15-304=%4P``````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,C$T-S$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VYB7TY/+VAE;'`N>&UL````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(P(#$P
M-3$U-#,T,30Q(#`R,30S,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R
M9&4Z(&AO<F1E+VQO8V%L92]N8E].3R]H96QP+GAM;"QV(#$N,B`R,#`T+S`U
M+S(W(#(P.C(R.C$T(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED
M/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G
M93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S
M(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O
M<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@
M;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L
M('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y
M;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W
M<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA
M<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F
M=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S
M86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E
M=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P
M;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U
M='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E
M;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A
M<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L
M93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A
M<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I
M<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@
M=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A
M;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L
M:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F
M<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E
M9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^
M"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B
M;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0
M<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C
M;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@
M<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M
M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL
M;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T
M;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L
M<#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]N8E].3R],0U]-15-304=%4R]H;W)D
M92YM;P``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V,3`T,R`Q,#4Q-30S
M-#$T,2`P,C,R,3,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````!1`P``'````*0:``!_!```+#4````````H1P``
M2````"E'```.````<D<```\```"!1P``#0```)%'```(````GT<```L```"H
M1P``#````+1'```$````P4<```P```#&1P``$0```--'```E````Y4<```\`
M```+2```"P```!M(```1````)T@```X````Y2```!0```$A(```H````3D@`
M``@```!W2```"@```(!(```5````BT@``!(```"A2```"P```+1(```4````
MP$@``"8```#52```)P```/Q(```F````)$D``!,```!+20``#@```%])```*
M````;DD```T```!Y20``)P```(=)```@````KTD```X```#020``%P```-])
M```B````]TD``#4````:2@``$0```%!*```-````8DH```P```!P2@``#0``
M`'U*```&````BTH``!L```"22@``+0```*Y*```D````W$H``"D````!2P``
M&0```"M+```8````14L```P```!>2P``#@```&M+```.````>DL```@```")
M2P``+@```))+```:````P4L``#(```#<2P``.`````],``!4````2$P``%$`
M``"=3```6@```.],``!7````2DT``#0```"B30``!0```-=-```1````W4T`
M``@```#O30``"0```/A-```)`````DX```X````,3@``"````!M.```E````
M)$X``"````!*3@``$````&M.```/````?$X```H```",3@``!P```)=.```#
M````GTX```\```"C3@``%````+-.```)````R$X```T```#23@``$@```.!.
M```9````\TX``!X````-3P``#P```"Q/```*````/$\```\```!'3P``"```
M`%=/```D````8$\``!<```"%3P``%````)U/```6````LD\```@```#)3P``
M3@```-)/```M````(5```!\```!/4```&0```&]0```'````B5````P```"1
M4```+````)Y0```.````RU````,```#:4```!0```-Y0```%````Y%````H`
M``#J4````P```/50```7````^5````H````140``#P```!Q1```.````+%$`
M`!@````[40``(P```%11```.````>%$``!0```"'40``%P```)Q1```7````
MM%$``!<```#,40``$P```.11```/````^%$``!\````(4@``#P```"A2```&
M````.%(```L````_4@``$````$M2```5````7%(``!4```!R4@``!P```(A2
M```0````D%(``!$```"A4@``#````+-2```[````P%(``#@```#\4@```P``
M`#53```)````.5,``#D```!#4P``$@```'U3```Y````D%,``"<```#*4P``
M+````/)3```J````'U0``"4```!*5```"0```'!4```*````>E0```<```"%
M5```+P```(U4```W````O50``"X```#U5```50```"15```M````>E4``"T`
M``"H50``+0```-95``!`````!%8``",```!%5@``(P```&E6```M````C58`
M`#,```"[5@``%0```.]6```9````!5<``"D````?5P``)````$E7```1````
M;E<``!$```"`5P``#````))7```*````GU<``!````"J5P``%@```+M7```6
M````TE<```0```#I5P``)P```.Y7```(````%E@```<````?6```"````"=8
M```I````,%@```X```!:6```"@```&E8```$````=%@```D```!Y6```!@``
M`(-8```1````BE@```<```"<6```!````*18```&````J5@```T```"P6```
M`P```+Y8```#````PE@``!<```#&6```$P```-Y8```(````\E@```0```#[
M6```00````!9```@````0ED```8```!C60``!@```&I9```5````<5D``!@`
M``"'60``(@```*!9```N````PUD``!T```#R60``(0```!!:``!4````,EH`
M`"D```"'6@``!P```+%:```5````N5H```H```#/6@``#P```-I:```-````
MZEH```\```#X6@``#0````A;```)````%EL```8````@6P``$P```"=;```4
M````.UL```P```!06P``!@```%U;``!4````9%L```0```"Y6P``#@```+Y;
M``!$````S5L``!$````27```$0```"1<```1````-EP``!P```!(7```*@``
M`&5<```A````D%P```4```"R7```$P```+A<```2````S%P```H```#?7```
M#P```.I<```1````^EP``!,````,70``#````"!=```&````+5T```8````T
M70``$````#M=```1````3%T```4```!>70``#````&1=```0````<5T```T`
M``""70``!@```)!=```'````EUT```T```"?70``$````*U=```)````OET`
M``<```#(70``"P```-!=```+````W%T```<```#H70``"0```/!=```4````
M^ET```D````/7@``"@```!E>```9````)%X``!T````^7@``#````%Q>```0
M````:5X``!(```!Z7@``$P```(U>```K````H5X``#L```#-7@``(`````E?
M```V````*E\``!````!A7P``"````')?```&````>U\```0```""7P``#@``
M`(=?```0````EE\``!X```"G7P``&P```,9?```A````XE\``!X````$8```
M&0```"-@```>````/6```!L```!<8```+@```'A@```7````IV```"8```"_
M8```,````.9@```;````%V$``!X````S80``'````%)A```F````;V$``"L`
M``"680``,P```,)A```F````]F$``"L````=8@``.````$EB```=````@F(`
M`!4```"@8@``+P```+9B```2````YF(``"````#Y8@``*0```!IC```>````
M1&,``!(```!C8P``H@```'9C```6````&60``",````P9```*````%1D```I
M````?60``"@```"G9```'P```-!D```5````\&0``"`````&90``)0```"=E
M```H````364``"T```!V90``,````*1E``"2````U64``"$```!H9@``%@``
M`(IF```<````H68``"8```"^9@``*@```.5F``!!````$&<``$0```!29P``
M#````)=G```'````I&<```<```"L9P``!@```+1G```-````NV<``!````#)
M9P``$@```-IG```3````[6<``!(````!:```#0```!1H```,````(F@```\`
M```O:```$P```#]H```-````4V@``"@```!A:````P```(IH```-````CF@`
M``8```"<:````@```*-H```%````IF@```0```"L:```$````+%H```$````
MPF@```T```#':```#@```-5H```#````Y&@```X```#H:```"````/=H```/
M`````&D```@````0:0``#P```!EI```'````*6D```T````Q:0``$````#]I
M```3````4&D``!,```!D:0``"P```'AI```1````A&D```D```"6:0``!@``
M`*!I```,````IVD``!$```"T:0``&0```,9I```+````X&D```T```#L:0``
M(@```/II```;````'6H``#0````Y:@``"@```&YJ```8````>6H``!D```"2
M:@``%@```*QJ```O````PVH``"(```#S:@``#0```!9K```'````)&L```P`
M```L:P``)@```#EK```4````8&L```L```!U:P``(@```(%K```O````I&L`
M``L```#4:P``"0```.!K```9````ZFL```L````$;```%P```!!L```7````
M*&P```D```!`;```%@```$IL```/````86P``!8```!Q;```#@```(AL```8
M````EVP```T```"P;```)@```+YL``!#````Y6P```@````I;0``+P```#)M
M```.````8FT```4```!Q;0``!@```'=M```#````?FT```0```"";0``"@``
M`(=M```*````DFT```\```"=;0``$````*UM```7````OFT``!$```#6;0``
M%P```.AM```9`````&X```D````:;@``"@```"1N```"````+VX```4````R
M;@``#0```#AN```;````1FX``!<```!B;@``"0```'IN```.````A&X```T`
M``"3;@``$@```*%N```X````M&X``"````#M;@```P````YO```(````$F\`
M``X````;;P``>P```"IO```8````IF\```4```"_;P``&````,5O```9````
MWF\``!,```#X;P``!P````QP```&````%'```!`````;<```#P```"QP```0
M````/'````\```!-<```"P```%UP```/````:7````P```!Y<```#P```(9P
M```'````EG````H```"><```!@```*EP```.````L'````P```"_<```*```
M`,QP```/````]7````@````%<0``"`````YQ```3````%W$``!X````K<0``
M(0```$IQ```@````;'$``!D```"-<0``%P```*=Q```E````OW$``!<```#E
M<0``!````/UQ```,`````G(```,````/<@``"````!-R```*````''(```P`
M```G<@``"P```#1R```0````0'(```P```!1<@``$P```%YR```4````<G(`
M``P```"'<@``"0```)1R```.````GG(```L```"M<@``&P```+ER```'````
MU7(```H```#=<@``#0```.AR```)````]G(```0`````<P``!0````5S```#
M````"W,``!@````/<P``"@```"AS```$````,W,``"8````X<P``#@```%]S
M``!\````;G,``!4```#K<P``!0````%T```'````!W0```P````/=```"```
M`!QT```*````)70```8````P=```"````#=T```6````0'0``!(```!7=```
M`@```&IT```&````;70``!4```!T=```#P```(IT```1````FG0``!H```"L
M=```!````,=T```)````S'0``!````#6=```"0```.=T```)````\70``!H`
M``#[=```"````!9U```9````'W4```X````Y=0``#@```$AU```*````5W4`
M``(```!B=0``#0```&5U```)````<W4```8```!]=0``"0```(1U```4````
MCG4``!T```"C=0``$0```,%U```&````TW4``!$```#:=0``$0```.QU```)
M````_G4```(````(=@``!`````MV```Y````$'8``#T```!*=@``.@```(AV
M```>````PW8```X```#B=@``!````/%V```&````]G8```8```#]=@``!```
M``1W```1````"7<```8````;=P``"@```")W```B````+7<```0```!0=P``
M)0```%5W```%````>W<```0```"!=P``#````(9W```*````DW<```4```">
M=P``.@```*1W```P````WW<``#4````0>```*0```$9X```N````<'@``$<`
M``"?>```.````.=X```I````('D``#\```!*>0``+@```(IY```M````N7D`
M`!\```#G>0``#P````=Z```2````%WH```L````J>@``)@```#9Z```I````
M77H``"0```"'>@``)@```*QZ```(````TWH```H```#<>@``"0```.=Z```@
M````\7H``"`````2>P``)@```#-[```*````6GL``!D```!E>P``*0```'][
M```6````J7L``!(```#`>P``"@```--[```,````WGL```\```#K>P``$```
M`/M[``!`````#'P``'````!-?```9@```+Y\```.````)7T```D````T?0``
M"@```#Y]```2````27T``!,```!<?0``#````'!]```&````?7T```\```"$
M?0``$@```)1]```0````IWT```H```"X?0``$0```,-]```<````U7T``",`
M``#R?0``:@```!9^```/````@7X``!````"1?@``!````*)^```+````IWX`
M`!0```"S?@``#````,A^```,````U7X```\```#B?@``%0```/)^```I````
M"'\``"H````R?P``)@```%U_```G````A'\``"D```"L?P``*@```-9_```9
M`````8```$(````;@```$0```%Z````2````<(```!,```"#@```%````)>`
M```/````K(```!8```"\@```%P```-.````0````ZX```!$```#\@```-```
M``Z!```3````0X$``!(```!7@0``-0```&J!```4````H($```<```"U@0``
M*P```+V!```@````Z8$``!0````*@@``$0```!^"```7````,8(``!P```!)
M@@``$P```&:"```1````>H(``!H```",@@``'@```*>"```:````QH(``!$`
M``#A@@``%P```/."```4````"X,``!<````@@P``%0```#B#```)````3H,`
M`!$```!8@P``!@```&J#```&````<8,```<```!X@P``!````("#```$````
MA8,```<```"*@P``#@```)*#```.````H8,``"@```"P@P``#@```-F#```,
M````Z(,```\```#U@P``"@````6$```(````$(0```D````9A```*P```".$
M```$````3X0```<```!4A```"````%R$```)````980```P```!OA```#0``
M`'R$```.````BH0``!8```"9A```$0```+"$```#````PH0```8```#&A```
M&0```,V$```$````YX0```L```#LA```"P```/B$```-````!(4```H````2
MA0``$````!V%```/````+H4``!$````^A0``%P```%"%```*````:(4``!$`
M``!SA0``"````(6%```$````CH4```\```"3A0``.@```*.%```%````WH4`
M``P```#DA0``'@```/&%```.````$(8``!`````?A@``"P```#"&```,````
M/(8```D```!)A@``!P```%.&```*````6X8```D```!FA@``#@```'"&```0
M````?X8``!H```"0A@``"@```*N&```4````MH8```H```#+A@``#````-:&
M```/````XX8```@```#SA@``!@```/R&```'`````X<```L````+AP``1P``
M`!>'```-````7X<```D```!MAP``!````'>'```#````?(<``!,```"`AP``
M$P```)2'```"````J(<```0```"KAP``#P```+"'```4````P(<``!,```#5
MAP``$````.F'```-````^H<```X````(B```%@```!>(```*````+H@```<`
M```YB```!P```$&(```)````28@```<```!3B```!````%N(```,````8(@`
M``4```!MB```!````'.(```$````>(@```D```!]B````@```(>(```/````
MBH@```0```":B```!0```)^(```&````I8@```(```"LB```!@```*^(```4
M````MH@```<```#+B```"@```-.(```1````WH@```@```#PB```'@```/F(
M```H````&(D``!0```!!B0``!0```%:)```H````7(D``"D```"%B0``5P``
M`*^)```L````!XH```<````TB@``#0```#R*```3````2HH``",```!>B@``
M"P```(**```+````CHH``"````":B@``)P```+N*```K````XXH``!0````/
MBP``!0```"2+```1````*HL```0````\BP``!````$&+```,````1HL```8`
M``!3BP``#0```%J+```:````:(L``!<```"#BP``%P```)N+```;````LXL`
M`!\```#/BP``%P```.^+```3````!XP``!D````;C```!````#6,```0````
M.HP``!<```!+C```!0```&.,```&````:8P```<```!PC```!@```'B,```'
M````?XP```<```"'C```!0```(^,```:````E8P``!0```"PC```"0```,6,
M```<````SXP``"D```#LC```.````!:-```O````3XT``"L```!_C0``*@``
M`*N-```^````UHT``!T````5C@``(P```#..```A````5XX``!P```!YC@``
M!0```):.```"````G(X```,```"?C@``(````*..```F````Q(X```P```#K
MC@``'P```/B.```'````&(\``!@````@CP``!@```#F/```,````0(\```@`
M``!-CP``"0```%:/```'````8(\```H```!HCP``"0```'./```'````?8\`
M``8```"%CP``#0```(R/```+````FH\```P```"FCP``"@```+./```"````
MOH\```8```#!CP```P```,B/``!%````S(\``#`````2D```$````$.0```)
M````5)```%,```!>D```'P```+*0```0````TI````\```#CD```!0```/.0
M```(````^9````@````"D0``!`````N1```%````$)$``&@!```6D0``3P``
M`'^2```1````SY(``!````#AD@``$0```/*2```(````!),```L````-DP``
M"````!F3```%````(I,```L````HDP``$0```#23```I````1I,``!````!P
MDP``#0```(&3```1````CY,```X```"ADP``!0```+"3```H````MI,```\`
M``#?DP``#P```.^3```/````_Y,``!,````/E```"P```".4```5````+Y0`
M`$0```!%E```)````(J4```N````KY0``!8```#>E```#0```/64```+````
M`Y4```\````/E0``,P```!^5```A````4Y4```T```!UE0``&0```(.5```G
M````G94``#H```#%E0``$@````"6```/````$Y8``!$````CE@``$P```#66
M```&````298``!P```!0E@``+````&V6```?````FI8``"4```"ZE@``&@``
M`."6```:````^Y8```H````6EP``$````"&7```0````,I<```@```!#EP``
M,````$R7```:````?9<``#P```"8EP``1````-67``!@````&I@``%T```![
MF```9P```-F8``!D````09D``$````"FF0``!0```.>9```1````[9D```4`
M``#_F0``$`````6:```-````%IH``!0````DF@``!P```#F:```N````09H`
M`"H```!PF@``#0```)N:```-````J9H``!4```"WF@``"@```,V:```(````
MV)H``!0```#AF@``&0```/::```-````$)L``!(````>FP``%0```#&;```@
M````1YL``"````!HFP``$P```(F;```0````G9L``!8```"NFP``#````,6;
M```F````TIL``!<```#YFP``%P```!&<```:````*9P```\```!$G```3@``
M`%2<```J````HYP``!X```#.G```,P```.V<```'````(9T```L````IG0``
M,````#6=```.````9IT```@```!UG0``!0```'Z=```'````A)T```H```",
MG0``!````)>=```9````G)T```P```"VG0``$````,.=```/````U)T``!8`
M``#DG0``,0```/N=```3````+9X``!4```!!G@``&````%>>```;````<)X`
M`!D```",G@``$0```*:>```1````N)X``!T```#*G@``#````.B>```$````
M]9X```<```#ZG@``#`````*?```4````#Y\``#4````DGP``"````%J?```4
M````8Y\``!<```!XGP``"0```)"?``!#````FI\``#L```#>GP``!0```!J@
M```+````(*```#X````LH```$````&N@``!!````?*```#````"^H```,P``
M`.^@```U````(Z$``#@```!9H0``"0```)*A```(````G*$```D```"EH0``
M.P```*^A```Z````ZZ$``#H````FH@``5@```&&B```Y````N*(``#D```#R
MH@``.0```"RC```X````9J,``"@```"?HP``*0```,BC```Y````\J,``#\`
M```LI```%````&RD```8````@:0``"8```":I```)@```,&D```3````Z*0`
M``X```#\I```#`````NE```(````&*4```X````AI0``%@```#"E```9````
M1Z4```4```!AI0``+0```&>E```*````E:4```8```"@I0``!P```*>E```N
M````KZ4``!,```#>I0``"@```/*E```#````_:4```D````!I@``!0````NF
M```.````$:8```8````@I@``!0```">F```$````+:8```H````RI@```P``
M`#VF```#````0:8``!@```!%I@``&````%ZF```(````=Z8```8```"`I@``
M0@```(>F```D````RJ8```8```#OI@``!@```/:F```5````_:8``!L````3
MIP``'P```"^G```O````3Z<``!\```!_IP``)````)^G``!U````Q*<``#<`
M```ZJ```!@```'*H```7````>:@```P```"1J```%````)ZH```<````LZ@`
M`!0```#0J```$@```.6H```,````^*@```8````%J0``%P````RI```>````
M)*D```D```!#J0``!0```$VI``!-````4ZD```0```"AJ0``#@```*:I```F
M````M:D``!````#<J0``$P```.VI```.`````:H``"`````0J@``+@```#&J
M```H````8*H```4```")J@``$P```(^J```0````HZH```P```"TJ@``$```
M`,&J```5````TJH``!,```#HJ@``"@```/RJ```%````!ZL```4````-JP``
M%0```!.K```1````*:L```4````[JP``"P```$&K```)````3:L```X```!7
MJP``"P```&:K```(````<JL```T```![JP``$@```(FK```+````G*L```D`
M``"HJP``"@```+*K```+````O:L```4```#)JP``!@```,^K```2````UJL`
M``P```#IJP``!@```/:K```<````_:L``"(````:K```#0```#VL```/````
M2ZP``!4```!;K```%@```'&L```S````B*P``$(```"\K```)0```/^L```D
M````):T```X```!*K0``"````%FM```&````8JT```8```!IK0``$P```'"M
M```2````A*T``!\```"7K0``'@```+>M```I````UJT``"@`````K@``(```
M`"FN```B````2JX``"H```!MK@``.0```)BN```<````TJX``"8```#OK@``
M,0```!:O```B````2*\``"4```!KKP``(````)&O```K````LJ\``#$```#>
MKP``*@```!"P```F````.[```"<```!BL```.````(JP```C````P[```",`
M``#GL```.`````NQ```3````1+$``"(```!8L0``*0```'NQ```?````I;$`
M`!(```#%L0``L0```-BQ```7````BK(``"(```"BL@``*@```,6R```J````
M\+(``#T````;LP``)@```%FS```A````@+,``"(```"BLP``*0```,6S```L
M````[[,``#@````<M```+P```%6T``"@````A;0``"<````FM0``%P```$ZU
M```@````9K4``"P```"'M0``+````+2U```W````X;4``#\````9M@``"@``
M`%FV```$````9+8```8```!IM@``!P```'"V```/````>+8```T```"(M@``
M$P```):V```4````JK8``!$```"_M@``#@```-&V```-````X+8```T```#N
MM@``%````/RV```.````$;<``#(````@MP``"````%.W```5````7+<```8`
M``!RMP```@```'FW```&````?+<```0```"#MP``$0```(BW```$````FK<`
M``P```"?MP``"0```*RW```#````MK<```T```"ZMP``"````,BW```+````
MT;<```<```#=MP``#P```.6W```(````];<```X```#^MP``$0````VX```4
M````'[@``!0````TN```#````$FX```0````5K@```@```!GN```!0```'"X
M```,````=K@```\```"#N```&````).X```+````K+@```T```"XN```(0``
M`,:X```;````Z+@``#8````$N0``"0```#NY```5````1;D``!<```!;N0``
M$P```'.Y```S````A[D``"8```"[N0``#````.*Y```'````[[D``!$```#W
MN0``+P````FZ```1````.;H```L```!+N@``(@```%>Z```N````>KH```D`
M``"IN@``"0```+.Z```?````O;H```L```#=N@``'0```.FZ```=````![L`
M``<````ENP``%````"V[```,````0KL``!,```!/NP``#@```&.[```2````
M<KL```H```"%NP``(````)"[```Z````L;L```@```#LNP``+P```/6[```.
M````);P```D````TO```!@```#Z\```#````1;P```<```!)O```#@```%&\
M```.````8+P``!,```!OO```$@```(.\```:````EKP``!$```"QO```&@``
M`,.\```:````WKP```D```#YO```"@````.]```"````#KT```8````1O0``
M#0```!B]```8````)KT``!8````_O0``"````%:]```,````7[T```X```!L
MO0``$0```'N]``!`````C;T``!D```#.O0``!0```.B]```(````[KT``!0`
M``#WO0``D`````R^```A````G;X```0```"_O@``'````,2^```:````X;X`
M`!L```#\O@``!@```!B_```&````'[\``!`````FOP``#P```#>_```0````
M1[\```\```!8OP``#P```&B_```-````>+\```P```"&OP``$````)._```$
M````I+\```<```"IOP``!0```+&_```-````M[\```T```#%OP``+@```-._
M```*`````L````D````-P```#@```!?````;````)L```"$```!"P```(@``
M`&3````A````A\```!X```"IP```'@```,C````J````Y\```!T````2P0``
M"````##!```,````.<$```,```!&P0``!P```$K!```)````4L$```L```!<
MP0``"````&C!```+````<<$```L```!]P0``%@```(G!```6````H,$```P`
M``"WP0``!P```,3!```'````S,$```X```#4P0``(0```./!```&````!<(`
M``\````,P@``$````!S"```,````+<(```,````ZP@``!````#["```$````
M0\(``!D```!(P@``"0```&+"```#````;,(``"8```!PP@``#P```)?"``".
M````I\(``!`````VPP``"````$?#```-````4,,``!(```!>PP``#@```''#
M```0````@,,```<```"1PP``#````)G#```4````IL,``!````"[PP```@``
M`,S#```&````S\,``!D```#6PP``$@```/##```9`````\0``"$````=Q```
M`P```#_$```$````0\0``!````!(Q```"````%G$```*````8L0``",```!M
MQ```"````)'$```8````FL0```T```"SQ```#0```,'$```)````S\0```(`
M``#9Q```#0```-S$```'````ZL0```8```#RQ```"````/G$```5`````L4`
M`!X````8Q0``$0```#?%```'````2<4``!4```!1Q0``%0```&?%```)````
M?<4```(```"'Q0``!````(K%```S````C\4``#<```##Q0``-````/O%```?
M````,,8```X```!0Q@```P```%_&```$````8\8```4```!HQ@``!0```&[&
M```8````=,8```<```"-Q@``"````)7&```<````GL8```,```"[Q@``,```
M`+_&```%````\,8```0```#VQ@``#0```/O&```.````"<<```4````8QP``
M-````!['```Q````4\<``#D```"%QP``'````+_'```B````W,<``#X```#_
MQP``/0```#[(```J````?,@``#H```"GR```,````.+(```X````$\D``"4`
M``!,R0``$````'+)```2````@\D```L```"6R0``*@```*+)```K````S<D`
M`"0```#YR0``*````![*```)````1\H```L```!1R@``"@```%W*```G````
M:,H``"8```"0R@``,````+?*```*````Z,H``!T```#SR@``+````!'+```5
M````/LL``!0```!4RP``"@```&G+```-````=,L``!````""RP``$@```)/+
M```W````ILL``)````#>RP``=0```&_,```9````Y<P```P```#_S```#0``
M``S-```1````&LT``!(````LS0``$P```#_-```&````4\T``!0```!:S0``
M$P```&_-```0````@\T```P```"4S0``$P```*'-```8````M<T``"0```#.
MS0``@0```//-```*````=<X``!0```"`S@``!````)7.```+````FLX``!<`
M``"FS@``#@```+[.```/````S<X``!````#=S@``%0```.[.```J````!,\`
M`"@````OSP``)@```%C/```D````?\\``"T```"DSP``*P```-+/```7````
M_L\``$(````6T```%````%G0```4````;M```!8```"#T```%````)K0```2
M````K]```!D```#"T```%P```-S0```2````]-```!`````'T0``/0```!C1
M```7````5M$``!8```!NT0``.P```(71```1````P=$```<```#3T0``+0``
M`-O1```@````"=(``!`````JT@``$````#O2```3````3-(``!D```!@T@``
M$0```'K2```4````C-(``!\```"AT@``(P```,'2```5````Y=(``!(```#[
MT@``%@````[3```3````)=,``!0````YTP``%0```$[3```'````9-,``!<`
M``!LTP``!P```(33```&````C-,```8```"3TP``!````)K3```$````G],`
M``8```"DTP``"0```*O3```0````M=,``"H```#&TP``$@```/'3```0````
M!-0``!(````5U```#0```"C4```+````-M0```H```!"U```/````$W4```$
M````BM0```D```"/U```!0```)G4```-````G]0```T```"MU```$@```+O4
M```4````SM0``!L```#CU```%P```/_4```#````%]4```@````;U0``*P``
M`"35```'````4-4```P```!8U0``#P```&75```-````==4```D```"#U0``
M$P```(W5```5````H=4```\```"WU0``%````,?5```,````W-4```X```#I
MU0``"````/C5```$`````=8```\````&U@``-````!;6```&````2]8```P`
M``!2U@``'0```%_6```.````?=8```T```",U@``#0```)K6```+````J-8`
M``H```"TU@``"````+_6```-````R-8```H```#6U@``$````.'6```:````
M\M8``"L````-UP``"@```#G7```5````1-<```D```!:UP``"@```&37```,
M````;]<```@```!\UP``"````(77```'````CM<``!,```"6UP``1@```*K7
M```-````\=<```H```#_UP``"@````K8```#````%=@``!0````9V```%@``
M`"[8```"````1=@```<```!(V```$````%#8```-````8=@```\```!OV```
M#P```'_8```(````C]@```\```"8V```'0```*C8```*````QM@```<```#1
MV```"0```-G8```)````X]@```D```#MV```!````/?8```0````_-@```4`
M```-V0``!P```!/9```%````&]D```H````AV0```P```"S9```-````,-D`
M``4````^V0``!P```$39```$````3-D```(```!1V0``!@```%39```0````
M6]D```0```!LV0``#````''9```1````?MD```<```"0V0``'0```)C9```M
M````MMD``!4```#DV0``!P```/K9```H`````MH``"@````KV@``6````%3:
M```Q````K=H```\```#?V@``#````._:```2````_-H``!\````/VP``"0``
M`"_;```+````.=L``!X```!%VP``,````&3;```T````E=L``!4```#*VP``
M"0```.#;```0````ZML```4```#[VP``"0````'<```*````"]P```,````6
MW```#````!K<```4````)]P```\````\W```$````$S<```9````7=P``!(`
M``!WW```%@```(K<```3````H=P``"````"UW```"0```-;<```5````X-P`
M`!4```#VW```!0````S=```&````$MT```0````9W0``!````![=```'````
M(]T```H````KW0``"````#;=```;````/]T```\```!;W0``"0```&O=```7
M````==T``#@```"-W0``+P```,;=```^````]MT``#<````UW@``-0```&W>
M``!.````H]X``"@```#RW@``+0```!O?```=````2=\``!8```!GWP``!@``
M`'[?```#````A=\```,```")WP``'P```(W?```H````K=\```\```#6WP``
M(````.;?```)````!^```!P````1X```"````"[@```*````-^````H```!"
MX```"P```$W@```&````6>````P```!@X```#@```&W@```(````?.````@`
M``"%X```$````([@```-````G^````P```"MX```#````+K@```"````Q^``
M``4```#*X````@```-#@```\````T^```#8````0X0``#P```$?A```*````
M5^$``&(```!BX0``'0```,7A```0````X^$``!````#TX0``!0````7B```'
M````"^(```0````3X@``!````!CB```%````'>(```$```#*`@``S0```*@`
M``!;`@``3P$````````0`P```````-8```";````S@```$X#``!$`@``1`$`
M````````````````````````````,0,``!\```!4````W0$``#8```#,`0``
MM0(``(4!````````HP$```````#/`0``(0,```````"$`0```````.L"````
M`````````/,"``!1`@``"`(````````Z`P``)P$`````````````@@(```\"
M``",`0``%@(``+8```"-`0``D@(``#T!````````]@```/0"````````1@$`
M`&@```!I`@``[@```!<!``"D````N@````,```"(`0``3@$``-@!```$`0``
M```````````.`@``Z`(```````````````````````!%`0``]P````````"^
M`0``5@```#L#````````@0(``!0#````````)0(```````!K`@``0P,`````
M``"<`0``#0````("``!0````_P````<#``!``P``&`$```````#3````$@``
M``D```!=`@````````````!)`@``F0```%,```!F`@``]P$```````"W````
M6`$``!H!```6`P``<P$``````````````````,0````+`0``+@$``(8```"L
M````5`$``-\`````````````````````````#@$``*8````0`@```````-$!
M```````````````````(````,0(``,L```!E````K`$`````````````*`$`
M`)4!```S`P``Y````"8#``#^`````````/(````=`0``90$`````````````
MY0(``+$"````````@P```-0"``````````````````"N````60```"\!````
M````)0,```$!``"H`@``$P$``&0!``"]````?@```#,`````````L0``````
M``"3`0``]0(``!(#``#E````[`(```,!``"P`0``-@(``)L!``"=`0``````
M``T#``#-`@```````#H"````````$P,``$,"````````_P$``(L````;`@``
M$0`````````U`@``$`````````!6`@``````````````````2P$````````;
M```````````"``!P````&@````P!``"*`0``W`````P"``!5`@``TP$`````
M```7``````````````#@`0``2`````(!```L````9@`````````1`P``4@``
M```````+`P``00,``/P!````````#P$``*`"``!\`@``QP$``#X```!"`P``
M`````#H!``"M`0``30(``,(!````````(0```-<```````````````````"R
M`0``'0````````"L`@``_@(``#`!````````7`(`````````````1@(`````
M``#*`0``+0$``)````!+`@``PP$```````#0`0``!0(``/P"``!%`@``8```
M`&T`````````#0(````````4`0``Q0````````"T````<@$``+L!``!:`0``
ME`$``!,```!1`0`````````````T````2@```"D"```M`P``_P(``&\"```Z
M````00(``'@"````````&P$``+("``````````````H#``#Z`@```````'@`
M``!J````,0$``/0`````````YP(``$X```!)`0``50```!\!``"(````C@``
M`"X```!(`0``7P```&$"````````0@````````"G`````````-H!``!!````
M\0$``*D!``"8````KP```#4!```?`@``<`$``(<!``"+`0``OP(`````````
M````4@$```````!9`0``'`(`````````````_0```,8````!`@``:`(````!
M``"G`@``\`$``'L``````````````/D"``!>````-P$```````!@`0``V@``
M````````````/0(```````!Z`@```````)0"```9`P``H0(``#,!``#J`0``
M50$``)$!``!*`@``8@```"D!````````M0````````"&`@``````````````
M````^P$``$`````#`@``D`$`````````````HP````````"G`0``E@(``/8!
M``!D`@``"@````T!``#9`0``YP$``.,"``"9`0``.`$``((!``"A````S@(`
M``````!)````10``````````````2@$``(D```#?`0``@``````````8````
M`````/````#X`@``&0(```````!V`@``G``````````(`0``J@(`````````
M`````@```````````````````.T!``"^`````````&\!``!U`@``Q`(``'$"
M``"0`@``=`$``%$#``"$``````````````">`0``G`(``","``"*````````
M``````"3````V````&("```X`P``S````%<```#K`0``A0(``,@!``"M`@``
M6````/T!```:`P``'`,``"X"``!]`0``/`$``.D!```&`P```````)H```#C
M`0``3`(``$T#````````JP$`````````````````````````````+0(``.(`
M```&`@``(`$`````````````=`(````````,````I@(```````"X````PP(`
M`+````"#`0```````$H#``#/````Q@$``$0````8`P``UP(``.L`````````
MN0```&P```!S````^````(L"``"J````;`(``,0!``"9`@``N0$``)(`````
M`````````&<```".`@``"0(``&P!```X`@```````.H"```!`P``,@$```(#
M``!%`P``!P(````````>`P```````+X"``!'`0``U0$``#<#```H````6P``
M`````````````````%,"``#!````E0```#P"``#^`0``I0$``*X"````````
M]P(``)$```#5`@``)`$```````"``0``Z0````````!7`@``)0```%T!``#\
M````K@$````````$`@``/````+8"```@````3P,``+\!```9````(@(``'`"
M``")`@```````"`"``!=`````````#D!``#+`@``H`$``!H"````````````
M`"H`````````60(``-D"``#F````9P$```````"\`0``.P$``+@"```L`@``
MJP```'P!``!X`0````````````"]`0```````.4!``#,`@``0`$``!4```"=
M`@```````&(!``#)`0````````````"?`0``)`,``*H!````````]0$``-`"
M``#;````^@`````````0`0```````(D!``"B`0``TP(``(\!``"O`@``````
M``````"/`````````&,!````````80```*`````_`0``/P,``.\!````````
M(P,``!X"`````````````+`"``!.`@``$P(``'P`````````5@$``+<"````
M````6P$``!L#```*`@``C````+$!````````*P$```````".`0``0@$```D#
M````````/`,``"\"```J`P``!0```!4#``"D`0``E0(``!$!``"\`@``@0$`
M`+L`````````VP(``!@"````````A`(``$("``!'`@``:`$``$8#````````
M`````%0"``#S````=P(```0#``#!`0``30```````````````````-X"``"-
M````7````.T````K`````````.(!```F`@``[````/`"````````B@(``)8!
M```I````@0````````#4``````````````">``````,``$P```"``@``````
M``\```"O`0``?@$``#````#*````$@(``"L#``!R`@``D0(``/8"````````
M%0(``.,`````````90(``-P!```[`@``SP(```````"A`0``-0,``(<```#[
M`@```````'8!```C`0```````'<```!R```````````````H`@``:P$``-$"
M```>`0````````@#``!Y`````````"\`````````M0$``)@"``"X`0``H@(`
M`"$"```J`0``_0(```````!1````J`$``-X!````````B`(``!T"````````
MA0```/L````]`````````.H`````````U@$`````````````!0,``.D"``"'
M`@``30$``"X#``!N`@``?P```!P```#7`0``EP$``.\"``#``@``S@$``$`"
M``````````````````#:`@``(0$``/D`````````EP```#<"```G`@``5P$`
M`*D"``#6`@``)`(``+T"``#(````;0(``#D#```K`@``:@(````````R````
MLP$``%P!``#"`@``7P$``!$"``">`@``/0,``+8!``#G````8`(``&D`````
M`````````)H!``#H``````````````#Y`0``J0```*,"````````#@,``/$"
M````````S0$``.\``````````````$@#``#A`@``)P,``"P#````````?P(`
M`+0"````````GP(``&H!`````````````%H"``!#`0``6`(``%X!``#@`@``
M`````&X`````````%@$```````#N`@``P`$``-\"```F````W@```#`"``""
M`````````-L!````````T`````D!`````````````)L"```+````,`,```<`
M``#&`@``$@$``"\#```D`````````(\"``#N`0``/@(``.0"````````"P(`
M`,@"``"E````%P,``$8````R`P``I0(`````````````,0```'$````Y`@``
M(@```'T```#9````>0(````````5`0``00$`````````````R0``````````
M````3`,``/(!``#L`0``(@,``!\#```T`@``!@$``!<"``"W`0``M`$`````
M`````````P,``.``````````PP```*T```#"```````````````H`P``````
M`+L"``!C````!````-(!``#D`0``-`,``%\"````````(`,``-$`````````
M```````````_`@```````!P!```E`0``I`(``#X#``#T`0``/@$``(,"``"K
M`@``#`,``'8```!>`@``)@$``+\```#F`0``>@```#8#``!O````E@```.8"
M``!C`@``1P```-T"````````>0$``/("``#B`@``?P$``&L```"Y`@``````
M`#0!``#2`@````````X```#'``````````<!``#'`@``````````````````
M`````&T!``"Z`0``DP(``&X!``!)`P``U`$``$<#```W```````````````R
M`@``G0```!X```",`@``=0$``#\````V`0``#P,``/H!``"R````&0$``!T#
M````````E````,4"``!Z`0``!@```"(!``#2````Q0$```````#S`0``-0``
M`'4`````````%````.$````Y`````````.T"```I`P``,P(``&<"````````
M?@(``,$"``!I`0```````!0"``#A`0``+0```%H```!0`@``3P``````````
M````!0$``#L```!+`````````$\"````````<0$``,D"```G````N@(`````
M````````O````#@```!,`0```````'L!``!D`````````&8!````````W0``
M`",```"B````2`(``%`!``!+`P``*@(``'<!``#`````A@$``-@"```6````
M`````&$!``"F`0```````'0```"8`0`````````````*`0``C0(```````!]
M`@``1`,``/$``````````````'L"```L`0``U0```+,```!0`P``D@$`````
M`````````````````````````````/4```!3`0``0P```)<"``#X`0``LP(`
M`%("````````F@(`````````````W`(``',"``#H`0```````,L!``"?````
M`"`F(S$U,3L@)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@
M*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R
M<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60@8GET97,@
M=W)I='1E;BX`)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T
M90`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@061M:6YI<W1R871I
M;VX`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E
M<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@
M)7,`)7,@:&%S(&-A;F-E;&QE9"`E<RX`)7,@:&%S(')E<&QI960@=&\@82!F
M<F5E+V)U<WD@<F5Q=65S="X`)7,@:&%S(')E<&QI960@=&\@=&AE(&EN=FET
M871I;VX@=&\@)7,N`"5S(&AA<R!S96YT('EO=2!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN`"5S(&ES(&YO="!W<FET86)L92X`)7,@:7,@<F5Q=6ER960`)7,@
M;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S(')E<75E<W1S('EO=7(@9G)E92]B
M=7-Y(&EN9F]R;6%T:6]N+@`E<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T
M("5S+@`E<R!T;R`E<R!O9B`E<P`E<R!W:7-H97,@=&\@861D('1O("5S+@`E
M<R!W:7-H97,@=&\@;6%K92!Y;W4@87=A<F4@;V8@)7,N`"5S('=I<VAE<R!T
M;R!R96-E:79E('1H92!L871E<W0@:6YF;W)M871I;VX@86)O=70@)7,N`"5S
M)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S
M)W,@5&%S:VQI<W0`)7,Z("5S`"<E<R<@:7,@;F]T(&$@=F%L:60@8VAO:6-E
M+@`G)7,G(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R
M>2X`)R5S)R!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"<E<R<@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"<E<R<@=V%S
M(&YO="!C<F5A=&5D.B`E<RX`+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM
M('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H
M;W5R<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!
M8G-M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`06-C97-S(&1E;FEE
M9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T
M:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N
M+@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@
M0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@
M3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@)R5S)P!!9&0@
M82!C:&EL9"!P97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W('5S97(Z`$%D
M9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@
M365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T;R!M>2!C86QE
M;F1A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B
M;V]K`$%D9"!U<V5R`$%D9&5D("<E<R<@=&\@=&AE('-Y<W1E;2P@8G5T(&-O
M=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S
M+@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO
M=RX`061D:6YG(&YE=R!F:6QE<R!T;R!R97!O<VET;W)Y.@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T
M<F%T:6]N`$%D<P!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T
M:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!
M;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@
M<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`
M06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`
M06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E
M<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06X@:6QL
M96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F]N>6UO=7,@4')O>'D`06YS
M=V5R`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@
M:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O
M>&EM871E(%-I>F4`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R
M92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U
M97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@
M)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R=`!!<V-I:2!!<G0`07-K(&9O
M<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1A8VAE9"!I<R!A;B!I0V%L
M96YD87(@9FEL92!R97!L>2!T;R!A(')E<75E<W0@>6]U('-E;G0`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O=7`N`$%T=&5M<'0@=&\@
M9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@
M961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=&5N9&5E<P!!='1R:6)U=&5S
M`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E
M(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I
M;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&
M5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@
M+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B
M-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D($Q$
M05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@
M861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!
M=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I<F5D
M($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U
M:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T
M:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I
M8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!
M=V%I=&EN9R!297-P;VYS90!"3T9(($5X8W5S97,`0F%C:V=R;W5N9`!"86-K
M9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E
M<F]S('5S97)N86UE+@!"87)E`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("<E
M<R<@;F]T(&9O=6YD+@!"87-E;&EN90!"96QG:75M`$)I<G1H9&%Y`$)L;V-K
M("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E
M='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";V]K;6%R:W,`0F]R9&5R`$)O<F1E
M<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES
M=`!#35,`0U)#`$-23"!$:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E
M<G1I97,N+BX`0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D
M(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N8V5L
M`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S
M(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@
M<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO
M="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H
M:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I
M97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R
M('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU
M;6)E<BX`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`0V5L;"!0:&]N
M90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I
M97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5N=&5R`$-E<G1I9FEC871E
M($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA:7(@4&5R<V]N`$-H
M86YG90!#:&%N9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@
M<V5E('=H96X@=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`
M0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@86X@
M86-T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L
M:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#;&%S<R!D969I
M;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE87(`0VQE87(@35-/9F9I8V4@
M=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R
M(&1A=&$`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#
M;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D>0!#;VQL87!S92!3:61E8F%R`$-O
M;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L
M96-T:6]N`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3
M:&5L;`!#;VUM86YD(&]P=&EO;G,Z`$-O;6UA;F1S.@!#;VUM96YT`$-O;6UI
M='1I;F<Z`$-O;6UO;B!.86UE`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@
M365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!N965D<R!U<&1A=&EN9RX`
M0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N;F5C=&EO;B!F86EL
M960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C=&EO;B!R969U<V5D('1O
M('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T:6]N(')E9G5S960@=&\@
M=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@)7,@*"5S*0!#;VYN96-T
M:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT86-T<R!W97)E('-U8V-E
M<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N=',@
M;V8@)R5S)P!#;VYT:6YU90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#
M;W!Y:6YG("5S('1O("5S`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E
M+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-
M12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@<VEG;B!M97-S
M86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD(&YO="!B:6YD
M('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I;F<@1E10.B`E
M<P!#;W5L9"!N;W0@8V]P>2`E<R!T;R`E<P!#;W5L9"!N;W0@8W)E871E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@8W)E871E(&QO8V%L92!D
M:7)E8W1O<GD@9F]R(&QO8V%L92`E<SH`0V]U;&0@;F]T(&1E8W)Y<'0@4$=0
M(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@)R5S)RX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@)R5S)RX`0V]U;&0@;F]T(&UK9&ER("<E<R<N`$-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO
M="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B`G)7,G(&9O<B!W<FET:6YG+@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@)R5S)RX`0V]U;&0@;F]T(')E860@)7,N
M`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T
M960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C
M;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O
M=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T
M(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V
M97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`G)7,G+@!#;W5L
M9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P
M(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@=&\Z("<E<R<N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`G)7,G
M+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A
M=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF
M:6=U<F%T:6]N(&9O<B`G)7,G.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII
M;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#
M;W5L9&XG="!G:79E('5S97(@)R5S)R!T:&4@9F]L;&]W:6YG(')I9VAT<R!F
M;W(@=&AE(&9O;&1E<B`G)7,G.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#
M;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-U<G)E;G0@4&AA<V4`0W5R<F5N="!4:6UE`$-U<G)E
M;G0@5V5A=&AE<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`
M0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`
M0W5T('-E;&5C=&EO;@!#>7!R=7,`1$0`1&%I;'D`1&%T80!$871A5')E92!"
M<F]W<V5R`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO;@!$87D`
M1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8VQI
M;F5D`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F
M875L="!)9&5N=&ET>0!$969A=6QT(%!E<FUI<W-I;VYS`$1E9F%U;'0@<&5R
M;6ES<VEO;G,`1&5F:6YI=&EO;G,`1&5L96=A=&4@<&]S:71I;VX`1&5L96=A
M=&5D`$1E;&5T90!$96QE=&4@1W)O=7``1&5L971E(%!E<FUI<W-I;VX`1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M('!E<FUI<W-I;VYS(&9O<B`G)7,G`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@
M)R5S)R!A;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE
M=&4@<V5L96-T960@:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M
M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T92!T:&ES('!E<FUI<W-I
M;VX@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T960@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@)R5S)RX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E;GD@
M<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S>2!I;F9O<FUA=&EO
M;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA
M;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO
M9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0
M;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I
M<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T
M`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T
M:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I
M<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$;R!N;W0@9&5L971E`$1O(&YO="!D
M:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T
M(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T
M:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$524@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI
M<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E
M<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%
M9&ET('!E<FUI<W-I;VYS(&9O<B`G)7,G`$5D=6-A=&EO;@!%;&5M96YT+BXN
M`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@
M;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T
M>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%
M;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE
M<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%
M;F0`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q
M=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T
M;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE
M(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%<G)O
M<@!%<G)O<B!S96YD:6YG(')E<&QY.B`E<RX`17)R;W(@=VET:"!E;6%I;"!M
M97-S86=E+@!%<G)O<B!W<FET:6YG("<E<R<N`$5R<F]R.B``175R;W!E`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N
M9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AE8W5T
M:6YG.@!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&871A;"!%<G)O
M<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@;&EK93H@`$9E=R!3
M:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T<FEX`$9I;&4@0V]U
M;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R
M`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:7)S="!(86QF`$9I<G-T
M(%%U87)T97(`1FEX(')A=&EO`$9L:7``1FQO870`1F]G`$9O;&1E<B`E<R!D
M;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H
M870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A
M<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U
M<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C
M;W5L9"!R97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S
M=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R
M='5N97,@,@!&;W)U;7,`1F]R=V%R9',`1F]U;F0@87!P;&EC871I;VYS.B`E
M<P!&;W5N9"!D:7)E8W1O<FEE<SH`1G(`1G)A;65S`$9R964O0G5S>2!);F9O
M<FUA=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E
M92]"=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)O;0!&<F]M('1H92``1G5L;"!$
M97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A;&QE<GD@=&\@=&%K
M92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=E;F5R871E("5S($-O;F9I9W5R871I
M;VX`1V5N97)A=&5D($-O9&4`1V5T;W!T($5R<F]R.B``1VEV96X@3F%M90!'
M;P!';V]G;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96YL86YD`$=R
M;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M
M<'1Y`$=R;W5P('!E<FUI<W-I;VYS`$=R;W5P<P!'=65S="!097)M:7-S:6]N
M<P!'=65S="!P97)M:7-S:6]N<P!'=65S=&)O;VL`2$@`2%1-3`!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(87-H+4%L9V]R:71H;0!(87IE`$AE
M861E<@!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9V@`2&ES=&]R>2!E;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!(;U]M
M90!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E+TMO
M;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D(&EN(&UE<W-A
M9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@
M;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@='EP92`E<R!F
M;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@
M<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!3=6-C97-S9G5L;'D@<WEN
M8VAR;VYI<V5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO
M;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`
M2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O
M<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@
M(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%
M($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B
M;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5
M;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@
M<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L
M96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME
M('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R
M93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M
M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`24U!4"!M86EL8F]X(&-R96%T
M:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@
M)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@
M061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B;&4N`$E0($%D9')E<W,@
M;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN`$E0(&QO8VMD;W=N('9I
M;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC;VYS($]N;'D`26-O;G,@
M9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET
M(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN
M(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I
M;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T
M:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@
M<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@
M=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O
M=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA
M9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L
M;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S
M`$EM<&]R=&5D(&9I96QD<SH`26X@4')O8V5S<P!);E]S97)T(%)O=R!!9G1E
M<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN8V]R<F5C="!U<V5R
M;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U<V5R;F%M92!O<B!A
M;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`26YC<F5A
M<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF;P!);F9O<FUA=&EO;@!)
M;G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE
M`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE
M=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T
M97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E
M('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!)
M;G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I
M=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T
M(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M
M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T
M97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!)
M;G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T
M;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`
M26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N
M9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D
M:70N`$EN=&5G97(`26YV86QI9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@
M8V]M<&]N96YT+@!);G9A;&ED(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!)
M;G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED
M(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N
M`$EN=F%L:60@9FEL92!F;W)M870`26YV86QI9"!M<V=?='EP92X`26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<')O
M=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`G)7,G`$EN=F%L:60@<VAA<F4@
M;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D
M92!D871A+@!);G9E;G1O<GD`27-O;&%T960@5"U3=&]R;7,`27-S=65R`$ET
M86QI8P!*86YU87)Y`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R
M`$ME97`@;W)I9VEN86P_`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H
M96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&
M:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@
M86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`
M3&%?>6]U=`!,86YG=6%G90!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O
M<B!N;R!B;W)D97(`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,:6=H
M="!$<FEZ>FQE`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!2
M86EN($QA=&4`3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H
M=6YD97(`3&EG:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,
M:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O
M('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X
M($-O;VMI90!,:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$
M871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R
M8VAI=F4`3&ES="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`
M3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QO861I;F<@;&EB<F%R:65S+BXN
M`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL960@
M8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D
M(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO
M=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`34T`
M36%I;`!-871C:&EN9R!F:65L9',`365E=&EN9R!#86YC96QL871I;VX`365E
M=&EN9R!);F9O<FUA=&EO;@!-965T:6YG(%!R;W!O<V%L`$UE971I;F<@4F5P
M;'D`365E=&EN9R!5<&1A=&4`365E=&EN9R!5<&1A=&4@4F5Q=65S=`!-96YU
M(&UO9&4Z`$UE<W-A9V4`36]N=&AL>0!-;W9E(&1O=VX`36]V92!U<`!.86UE
M`$YE961S($%C=&EO;@!.979E<@!.97=S`$YE>'0`3F5X="!086=E`$YO`$YO
M;B!087)T:6-I<&%N=`!.;VYE`$YO=&5S`$YO=&EC90!/2P!/9F9I8V4`3W!T
M:6]N86P@4&%R=&EC:7!A;G0`3W!T:6]N<P!/<F=A;FEZ:6YG`$]T:&5R($EN
M9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!H;VYE`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E=FEE=R!T:&4@9F]L;&]W
M:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@86X@86-T:6]N(&9R
M;VT@=&AE(&UE;G4@8F5L;W<N`%!R979I97<`4')E=FEO=7,@4&%G90!0<F]B
M;&5M($1E<V-R:7!T:6]N`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M
M871I;VXN`%)E;6]V92!P86ER`%)E<&QY(%-E;G0N`%)E<&QY('=I=&@@3F]T
M(%-U<'!O<G1E9"!-97-S86=E`%)E<&QY('=I=&@@9G)E92]B=7-Y(&9O<B!N
M97AT(#(@;6]N=&AS+@!297!L>2!W:71H(')E<75E<W1E9"!F<F5E+V)U<WD@
M:6YF;W)M871I;VXN`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E='5R
M;B!T;R!/<'1I;VYS`%)O;&4`4V%V90!3879E($]P=&EO;G,`4V5A<F-H`%-E
M;&5C="!A(&1A=&4`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T
M('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L
M96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E
M9"!L86YG=6%G93H`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!3:6=N('5P(&EF(&YO="!R96=I<W1E<F5D`%-I>F4`4VMI
M<"!-86EN=&5N86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=&%R=`!3
M=&%T=7,`4W5B:F5C=`!3=6)M:70`4W5C8V5S<P!3=6UM87)Y`%1A<VMS`%1E
M;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV96QY($%C8V5P=&5D
M`%1E>'0@3VYL>0!4:&4@8V%L96YD87(@9&%T82!I<R!I;G9A;&ED`%1H92!T
M87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S:VQI<W0N`%1H92!U<V5R
M)W,@9G)E92]B=7-Y(&EN9F]R;6%T:6]N('=A<R!S=6-E<W-F=6QL>2!S=&]R
M960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G
M92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&5V96YT
M.B`E<RX`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@=&%S:SH@
M)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=7-E<B=S(&9R964O
M8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H:7,@86-T:6]N(&ES(&YO="!S=7!P
M;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M96YT960N`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU
M<W0@8F4@82!N=6UB97(N`%1I=&QE`%1O`%523`!5;F%B;&4@=&\@8V]N;F5C
M="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R
M9"!D;V-U;65N=`!5;F1O($-H86YG97,`56YH86YD;&5D(&-O;7!O;F5N="!O
M9B!T>7!E.B`E<P!5;FYA;65D`%5P9&%T92!R97-P;VYD96YT('-T871U<P!5
M<&QO860`57-E<B!/<'1I;VYS`%5S97)N86UE`%5S97)N86UE.@!6:65W("5S
M`%9I97<@979E;G0`5FEE=R!T87-K`%=A<FYI;F<`5V5E:VQY`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`
M665A<FQY`%EE<P!9;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O
M<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U<B`E<R!S
M97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@
M26YF;W)M871I;VX`66]U<B!.86UE`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T]P=&EO
M;B`K(%`@=&\@<')I;G0N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`7TAE;'``7TQO
M9R!O=70`7T]P=&EO;G,`;F%M90!V0V%R9`!0<F]J96-T+4ED+59E<G-I;VXZ
M($AO<F1E(#,N,"XT"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3`U+3$X(#$R.C0S
M*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-2TQ."`Q-#HS-RLP,C`P
M"DQA<W0M5')A;G-L871O<CH@1V5I<B!/+B!(;V=B97)G(#QH;W)D94!S:WED
M:79E<BYN;SX*3&%N9W5A9V4M5&5A;3H@3F]R=V5G:6%N("A";VMM86PI(#QI
M,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("8C,34Q.R`E<R!E<B!K;&%R
M(&9O<B#E('5T9OAR92!V961L:6ME:&]L9'-O<&5R87-J;VYE;F4@<V]M(&5R
M('9A;&=T(&YE9&5N9F]R+@`@*"5S(&1A9V5R('-I9&5N*0`@*&AU<G1I9W1A
M<W0@)7,I`"`H:6YN96X@)7,@9&%G97(I`"`H:2!D86<I`"`H:2!M;W)G96XI
M`"`H:2!GY7(I`"!D96X@`"5D("5S(&]G("5S`"5D(&)Y=&5S('-K<F5V970N
M`"5D(&%V("5D(&]P<&;X<FEN9V5R(&UA<FME="!S;VT@;W!P9&%T97)T`"5D
M+61A9V5R<R!V87)S96P`)7,@+2!4:6P@:6YF;P`E<R!A9&UI;FES=')A<VIO
M;@`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!V961L:6ME:&]L9'-O<&5R87-J
M;VYE<B`M($)E:W)E9G1E;'-E`"5S(&EN<W1I;&QI;F=E<@`E<R!R96=I<W1R
M97)I;F<`)7,@879T86QE=FEL:^5R`"5S(&9I;FYE<R!A;&QE<F5D92X`)7,@
M<.4@)7,@)7,`)7,@:&%R(&MA;G-E;&QE<G0@)7,N`"5S(&AA<B!B97-V87)T
M(&5N(&9O<F5S</AR<V5L(&]M(&EN9F]R;6%S:F]N(&%N9^5E;F1E(&QE9&EG
M+V]P<'1A='0N`"5S(&AA<B!S=F%R="!PY2!I;G9I=&%S:F]N96X@=&EL("5S
M+@`E<R!H87(@<V5N9'0@9&5G(&EN9F]R;6%S:F]N(&]M(&QE9&EG+V]P<'1A
M='0N`"5S(&5R('-K<FEV96)E<VMY='1E="X`)7,@97(@<.5K<F5V9``E<R!M
M:6YU='1E<@`E<R!I:VME(&9U;FYE="X`)7,@9F]R97-P^'(@:6YF;W)M87-J
M;VX@;VT@;N5R(&1U(&5R(&QE9&EG+V]P='1A='0N`"5S(&9O<F5S</AR(&1I
M;B!D96QT86=E;'-E('#E("5S+@`E<R`M("5S(&%V("5S`"5S(/AN<VME<B#E
M(&QE9V=E('1I;"`E<RX`)7,@^&YS:V5R(.4@9VKX<F4@9&5G(&]P<&UE<FMS
M;VT@<.4@)7,N`"5S(/AN<VME<B#E(&UO='1A(&1E;B!S:7-T(&]P<&1A=&5R
M=&4@:6YF;W)M87-J;VYE;B!O;2`E<RX`061D<F5S<V5B;VL@9F]R("5S`$MA
M;&5N9&5R(&9O<B`E<P!.;W1A=&)L;VMK(&9O<B`E<P!/<'!G879E;&ES=&4@
M9F]R("5S`"5S.B`E<P`G)7,G(&5R(&EK:V4@970@9WEL9&EG('9A;&<N`"<E
M<R<@97(@:6MK92!C;VYF:6=U<F5R="!I($AO<F1E(%)E9VES=&5R970N`"5S
M(&)L92!L86=T('1I;"!G<G5P<&5S>7-T96UE="X`)R5S)R!B;&4@;&%G="!T
M:6P@<F5T=&EG:&5T<W-Y<W1E;65T+@`E<R!B;&4@:6MK92!O<'!R971T970Z
M("5S+@`L('9A<FEA8F5L(&UE;&QO;2`E<R!O9R`E<P`M+2!V96QG("TM`#$R
M(%1I;65R<R!F;W)M870`,C0@5&EM97)S(&9O<FUA=``R-"!T:6UE<@!%;B!D
M871A8F%S96MO8FQI;F<@97(@<.5K<F5V9"!F;W(@9&5N;F4@8FQO:VME;BX`
M16X@9F%T86P@9F5I;"!H87(@;W!P<W3E='0`16X@;V9F96YT;&EG(%!'4"UN
M^&MK96P@97(@<.5K<F5V9"!F;W(@Y2!K<GEP=&5R92!M96QD:6YG96XN`$5N
M(&]F9F5N=&QI9R!01U`M;OAK:V5L(&5R('#E:W)E=F0@9F]R(.4@=F5R:69I
M<V5R92!S:6=N97)T(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!01U`M;OAK:V5L
M+"!P<FEV870@4$=0+6[X:VME;"!O9R!P87-S<&AR87-E(&5R('#E:W)E=F0@
M9F]R(.4@9&5K<GEP=&5R92!E;B!M96QD:6YG+@!%;B!O9F9E;G1L:6<@4$=0
M+6[X:VME;"P@<')I=F%T(%!'4"UN^&MK96P@;V<@<&%S<W!H<F%S92!E<B!P
MY6MR979D(&9O<B#E('-I9VYE<F4@96X@;65L9&EN9RX`16X@;V9F96YT;&EG
M(%,O34E-12UN^&MK96PL('!R:79A="!3+TU)344M;OAK:V5L+"!O9R!P87-S
M<&AR87-E(&5R('#E:W)E=F0@9F]R(.4@9&5K<GEP=&5R92!E;B!M96QD:6YG
M+@!%;B!O9F9E;G1L:6<@4R]-24U%+6[X:VME;"P@<')I=F%T(%,O34E-12UN
M^&MK96PL(&]G('!A<W-P:')A<V4@97(@<.5K<F5V9"!F;W(@Y2!S:6=N97)E
M(&5N(&UE;&1I;F<N`$5N(&]F9F5N=&QI9R!3+TU)344M;OAK:V5L(&5R('#E
M:W)E=F0@9F]R(.4@:W)Y<'1E<F4@96X@;65L9&EN9RX`04TO4$T`3VT@9&5N
M;F4@961I=&]R96X`3VTN+BX`06)S;VQU='0@;F5D97)S=`!!8G-O;'5T="!M
M:61T`$=O9&MJ96YN(&9O<F5S</AR<V5L`$=O9'1A='0`5&EL9V%N9R!N96MT
M970@=F5D(&]P<')E='1E;'-E(&%V(%9&4R!K871A;&]G+@!4:6QG86YG(&YE
M:W1E="!V960@;W!P<F5T=&5L<V4@878@5D93(&9I;"X`2V]N=&\@4&%S<V]R
M9`!+;VYT;R!F<OAS970N`$)O:VAO;&1I;F<O06-C;W5N=&EN9P!(86YD;&EN
M9V5R`$QE9V<@=&EL`$QE9V<@=&EL('5N9&5R9W)U<'!E`$QE9V<@=&EL('5N
M9&5R<F5T=&EG:&5T97(`3&5G9R!T:6P@:&5R.@!,96=G('1I;"!N>2!G<G5P
M<&4`3&5G9R!T:6P@;GD@<F5T=&EG:&5T`$QE9V<@=&EL(&5N('5N9&5R9W)U
M<'!E('1I;"`G)7,G`$QE9V<@=&EL('5N9&5R<F5T=&EG:&5T('1I;"`G)7,G
M`$QE9V<@=&EL(&YY(&)R=6ME<CH`3&5G9R!T:6P@:V]L;VYN90!,96=G('1I
M;"!N>64@;65D;&5M;65R`$QE9V<@=&EL('!A<@!,96=G('1I;"`E<R!M96YY
M96X@<V]M($UO>FEL;&$@4VED96)A<@!,96=G('1I;"!I(&UI;B!K86QE;F1E
M<@!,96=G('1I;"!I(&%D9')E<W-E8F]K.@!,96=G('1I;"!I(&UI;B!A9&1R
M97-S96)O:P!,96=G('1I;"!B<G5K97(`3&$@=&EL("<E<R<@:2!S>7-T96UE
M="P@;65N(&MU;FYE(&EK:V4@;&5G9V4@=&EL(&5K<W1R82!R96=I<W1R97)I
M;F=S:6YF;SH@)7,N`$QA("<E<R<@=&EL('-Y<W1E;65T+B!$=2!K86X@;&]G
M9V4@:6YN(&[E+@!,82!T:6P@;GEE(&9I;&5R(&D@<F5P;W-I=&]R>3H`375L
M:6=H970@9F]R(.4@;&5G9V4@=&EL(&YY92!B<G5K97)E(&5R(&1E86MT:79E
M<G0N`$%D<F5S<V4`061R97-S92!";VL`061M:6YI<W1R97(@+2!S971T(')E
M='1I9VAE=&5R(&9O<B!A;F1R92!B<G5K97)E`$%D;6EN:7-T<F%S:F]N`%)E
M:VQA;65R`$%L:6%S`$IU<W1E<F4`2G5S=&5R:6YG.@!!;&QE`$%L;&4@875T
M96YT:7-E<G1E(&)R=6ME<F4`06QL92!'<G5P<&5R`$%L;&4@<F5D9&EG:&5T
M97(`06QL92!F:7)E('-I9&5R`%1I;&QA='0@9FQE<F4@861R97-S97(`5&EL
M;&%T="!E;F1R:6YG(&%V(&9O<FUA=&5T('#E(&YU;6UE<F5R=&4@;&ES=&5R
M/P!%:W-I<W1E<F5R(&%L;&5R961E`$%L=&5R;F%T:78@24U34"!,;V=I;@!!
M;'1E<FYA=&EV="!)35-0('!A<W-O<F0`06QT97)N871I=G0@24U34"!B<G5K
M97)N879N`$%L=&5R;F%T:78@92UP;W-T(&%D<F5S<V4`06QT97)N871I=F4@
M;6%L97(`06QT97)N871I=B!T96MS=#H`16X@=6QO=FQI9R!V97)D:2!V87(@
M;W!P9VET="X`06YO;GEM(%!R;WAY`%-V87(`4')O9W)A;0!0<F]G<F%M;&ES
M=&4`4')O9W)A;6UE="!E<B!K;&%R="X`3W!P9&%T97(@;V=SY2!R96MU<G-I
M=G0@;F5D;W9E<B!F;W(@=6YD97)M87!P97(O9FEL97(`1V]D:VIE;FX`3VUT
M<F5N=&QI9R!S=/AR<F5L<V4`1FEL<W3X<G)E;'-E('#E(&%R:VEV970`07)K
M:79N879N`$5R(&1U(%-)2TM%4B!PY2!A="!D=2!V:6P@9FIE<FYE(')E9VES
M=')E<FEN9W-F;W)E<W#X<G-E;&5N(&9O<B`E<S\`17(@9'4@<VEK:V5R('#E
M(&%T(&1U('9I;"!S;&5T=&4@)R5S)R!O9R!D96YS('5N9&5R9W)U<'!E<C\`
M2W5N<W0`07-C:6D@:W5N<W0`0F4@;VT@8F5K<F5F=&5L<V4@9OAR(&=J96YN
M;VUF^')I;F<@878@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(`2V]L;VYN96%N
M=FES;FEN9P!6961L86=T(&D@<W9A<F5T(&5R(&5N(&E#86QE;F1A<B!F:6P@
M9F]R(&5N(&9O<F5S</AR<V5L(&1U('-E;F1T90!&;W)S^&MT92#E('-L971T
M92!E;B!G<G5P<&4@<V]M(&EK:V4@96MS:7-T97)E<BX`1F]R<_AK=&4@Y2!S
M;&5T=&4@96X@<F5T=&EG:&5T('-O;2!I:VME(&5K<VES=&5R97(N`$9O<G/X
M:W1E(.4@<F5D:6=E<F4@96X@<F5T=&EG:&5T('-O;2!I:VME(&5K<VES=&5R
M97(N`$9O<G/X:W1E(.4@<F5D:6=E<F4@96X@9&5L="!R97-S=7)S('-O;2!I
M:VME(&5K<VES=&5R97(N`$1E;'1A9V5R90!!='1R:6)U=`#8<W1E<G)I:V4`
M075T:%]C>7)S<6PZ($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD:6=E($E-
M05`@=71V:61E;'-E;BX`075T:%]C>7)U<SH@0F%C:V5N9"!I;FYE:&%R(&EK
M:V4@;OAD=F5N9&EG(&9U;FMS:F]N86QI=&5T+@!!=71H7V-Y<G5S.B!+86X@
M:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!)34%0('5T=FED96QS96XN`$%U
M=&A?9G1P.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!&5%`@=71V
M:61E;'-E;BX@2V]M<&EL97(@4$A0(&UE9"`M+65N86)L92UF='`N`$%U=&A?
M:6UA<#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E;F1I9V4@24U!4"!U='9I
M9&5L<V5N+@!!=71H7VMR8C4Z($MA;B!I:VME(&9I;FYE(&1E;B!N^&1V96YD
M:6=E(&MR8C4@=71V:61E;'-E;BX`075T:%]L9&%P.B!+86X@:6MK92!F:6YN
M92!D96X@;OAD=F5N9&EG92!,1$%0('5T=FED96QS96XN`$%U=&A?;&1A<#H@
M2W5N;F4@:6MK92!L96=G92!T:6P@8G)U:V5R("5S+B!397)V97)E;B!S83H@
M`$%U=&A?;&1A<#H@2W5N;F4@:6MK92!F:F5R;F4@8G)U:V5R96X@)7,`075T
M:%]L9&%P.B!+=6YN92!I:VME(&]P<&1A=&5R92!B<G5K97(@)7,`075T:%]M
M8V%L.B!+86X@:6MK92!F:6YN92!D96X@;OAD=F5N9&EG92!-0T%,('5T=FED
M96QS96XN`$%U=&A?<VUB875T:#H@2V%N(&EK:V4@9FEN;F4@9&5N(&[X9'9E
M;F1I9V4@<VUB875T:"!U='9I9&5L<V5N+@!!=71E;G1I<V5R:6YG(&9E:6QE
M=`!!=71E;G1I<V5R:6YG(&9E:6QE="X@)7,`075T96YT:7-E<FEN9R!N96MT
M970@878@4D%$2553('1J96YE<BX`075T96YT:7-E<FEN9R!M;W0@1E10('1J
M96YE<F5N(&9E:6QE="X`5&EL9VIE;F=E;&EG92!F96QT.@!696YT97(@<.4@
M<W9A<@!"3T9(($5X8W5S97,`0F%K9W)U;FX`0F%K9W)U;FYS9F%R9V4`1F5I
M;"!K97)B97)O<R!P87-S;W)D+@!&96EL(&ME<F)E<F]S(&)R=6ME<FYA=FXN
M`$)L86YK`$)A<V5K871A;&]G(&9O<B!G<F%F:6MK("<E<R<@8FQE(&EK:V4@
M9G5N;F5T+@!'<G5N;FQI;FIE`$)E;&EG80!"=7)S9&%G`$)L;VMK("(E<R(@
M878@<')O9W)A;6UE="`B)7,B(&)L92!I:VME(&9U;FYE="X`0FQO:VL@:6YN
M<W1I;&QI;F=E<@!";&]K:R!T>7!E`$9E=`!";VMM97)K97(`4F%M;64`4F%M
M;65T>6MK96QS93H`4F%M;65R`$)E9V=E`$)U;FX`4'5N:W1L:7-T90!#35,`
M0U)#`$-23"!$:7-T<FEB=7-J;VYS<'5N:W1E<@!%9V5N<VMA<&5R(&9O<B!C
M7V5L;&4N+BX`2V%L96YD97(`4W1I;&QE`$MA;B!I:VME(&YU;&QS=&EL;&4@
M<&%S<V]R9"!A=71O;6%T:7-K+"!K;VYT86MT(&1I;B!A9&UI;FES=')A=&]R
M+@!+86X@:6MK92!K;V)L92!T:6P@24U!4"!T:F5N97)E;CH@)7,`2V%N861A
M`$%V8G)Y=`!!=F)R>70@<')O8FQE;7)A<'!O<G0`2V%N(&EK:V4@<VQE='1E
M(&9I;&5N("(E<R(N`$MA;B!I:VME(&9I;FYE(&5N('1E;7`M:V%T86QO9RX`
M2V%N(&EK:V4@9F]R='-E='1E('5T96X@)W1A<F=E=$9I;&4G('!A<F%M971E
M<BX`2V%N(&EK:V4@<VQE='1E(&MA=&%L;V=E;B`B)7,B+@!+86X@:6MK92!S
M;&5T=&4L("5D(&)A<FX@96MS:7-T97)E<BX`2V%N(&EK:V4@96YD<F4@<F5K
M:V5F^&QG96XL(&%N=&%L;&5T(&]P<&;X<FEN9V5R('9A;&=T(&9O<B!O;7-O
M<G1E<FEN9R!S=&5M;65R(&EK:V4@;65D(&%N=&%L;&5T(&QA9W)E9&4@;W!P
M9OAR:6YG97(N`$MA;B!I:VME('-E;F1E(&UE;&1I;F=E;B!T:6P@9&5T('-P
M97-I9FES97)T92!N=6UM97)E="X`571D<F%G`$MA=&5G;W)I97(@;V<@971I
M:V5T=&5R`$UO8FEL=&5L969O;@!%9V5N<VMA<&5R(&9O<B!C96QL90!,=69T
M(')U;F1T(&EN;FAO;&0@878@8V5L;&4Z`$5G96YS:V%P97(@9F]R(&-E;&QE
M`$QU9G0@<G5N9'0@8V5L;&5N.@!-;V)I;'1E;&5F;VX`4V5N=&5R`$1E=&%L
M:F5R(&9O<B!S97)T:69I:V%T`%)E='1N:6YG<VQI;FIE<B!F;W(@<V5R=&EF
M:6MA=`!/<F1S='ER97(`16YD<F4`16YD<F4@;F%V;B!O9R!A9')E<W-E('-O
M;2!M;W1T86ME<F4@<V5R(&[E<B!D92!L97-E<B!O9R!S=F%R97(@<.4@<&]S
M=&5N(&1I;BX`5&5G;@!3:F5K7VL@;&EN:RXN+@!696QG(&1E(&]P97)A<VIO
M;F5N92!D=2!V:6P@=71F^')E(&[E+@!696QG(&5T="!P87-S;W)D`%9E;&<@
M971T(&)R=6ME<FYA=FX`5F5L9R!H86YD;&EN9SH`5F5L9R!H=F]R9&%N(&1U
M('9I;"!V:7-E(&1A=&]E<CH`5F5L9R!S=&EL('#E(&QI<W1E='EP92`H9F]R
M(&YU;6UE<F5R=&4@;&ES=&5R*0!+;&%S<V5D969I;FES:F]N(&9O<B`E<R!B
M;&4@:6MK92!F=6YN970N`$ML87)T`$9J97)N($U33V9F:6-E('1A9W,`1FIE
M<FX@8G)U:V5R.B`E<P!&:F5R;B!B<G5K97(`1FIE<FX@8G)U:V5R9&%T80!+
M;&EK:R!F;W(@Y2!F;W)T<V5T=&4`0VQI8VMA=&5L;"!V:6$@2%144`!,=6MK
M('9I;F1U`%-K>65R`%-K>65T`%-LY2!S86UM96X@<VED96QI;FIE;@!386UM
M96YS;.5T="!R86UM90!&87)G90!&87)G979E;&=E<@!&87)G979A;&<`2V]L
M;VYN92UT:71L97(`5&5G;F5S97)I97(`2V]M;6%N9&\`2V]M;6%N9&]V:6YD
M=0!686QG(&9O<B!K;VUM86YD;SH`2V]M;6%N9&]E<CH`2V]M;65N=&%R`%-J
M96MK(&EN;CH`5F%N;&EG(&YA=FX`1FER;6$`1F5R9&EG`%-K<FEV(&UE;&1I
M;F<@*"5S*0!$871A;6%S:VEN97(`5FEL:^5R`$9O<G-K:F5L;&5R(&D@:6YN
M<W1I;&QI;F=E;F4`26YN<W1I;&QI;F=E<B!B96CX=F5R(&]P<&1A=&5R:6YG
M+@!+;VYF:6=U<F5R("5S`$)E:W)E9G0@<&%S<V]R9`!4:6QK;V)L:6YG(&UI
M<VQY:W1E<RX`5&EL:V]B;&EN9R!M:7-L>6MT97,Z(`!+;V)L:6YG96X@=&EL
M(&1E;B!O9F9E;G1L:6=E(&[X:VME;'1J96YE<F5N(&9E:6QE="X`2V]B;&EN
M9V5N('1I;"!D96X@;V9F96YT;&EG92!N^&MK96QT:F5N97)E;B!F96EL970N
M(,5R<V%K.B`E<R`H)7,I`$MO8FQI;F=E;B!T:6P@1E10('1J96YE<F5N(&UI
M<VQY:W1E<RX`2V]N=&%K=&5N92!B;&4@;&%G="!T:6P@861R97-S96)O:V5N
M`$EN;FAO;&0@:2`G)7,G`$9O<G1S971T`$-O;VMI90!+;W!I97(`2V]P:65R
M('9A;&=T(&]M<N5D90!+;W!I97)E<B`E<R!T:6P@)7,`2W5N;F4@:6MK92!0
M1U`M:W)Y<'1E<F4@;65L9&EN9P!+=6YN92!I:VME(%!'4"US:6=N97)E(&UE
M;&1I;F<`2W5N;F4@:6MK92!K<GEP=&5R92!M96QD:6YG96X@;65D(%,O34E-
M12X`2W5N;F4@:6MK92!S:6=N97)E(&UE;&1I;F=E;B!M960@4R]-24U%+@!+
M=6YN92!I:VME(&QE9V=E('1I;"!K;VYT86MT.B`E<P!4:6QK;V)L:6YG('1I
M;"!,1$%0+7-E<G9E<B!F96EL970N`$MU;FYE(&EK:V4@<VIE:VME('1I;&=J
M96YG96QI9R!K<F5D:71T+B`E<P!+;&%R=&4@:6MK92#E(&MO8FQE('1I;"!T
M:F5N97)E;B`G)7,G('9E9"!B<G5K(&%V($944#H@)7,`2W5N;F4@:6MK92!K
M;W!I97)E("5S('1I;"`E<P!+=6YN92!I:VME(&QA9V4@9&ES=')I8G5S:F]N
M<VQI<W1E+B`E<P!+=6YN92!I:VME(&]P<')E='1E(&QO8V%L92!K871A;&]G
M(&9O<B!L;V-A;&4@)7,Z`$MU;FYE(&EK:V4@9&5K<GEP=&5R92!01U`@;65L
M9&EN9RX`2W5N;F4@:6MK92!D96MR>7!T97)E(%,O34E-12!M96QD:6YG+@!+
M;&%R=&4@:6MK92#E('-L971T92!K;VYT86MT+B`E<P!+;&%R=&4@:6MK92#E
M('-L971T92!D:7-T<FEB=7-J;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@<VQE
M='1E('-E='5P(&]P<&=R861E<FEN9W-S8W)I<'0@)R5S)RX`2W5N;F4@:6MK
M92!F:6YN92!M;W1T86ME<G,@92UP;W-T(&%D<F5S<V4N`$MU;FYE(&EK:V4@
M:&5N=&4@=70@:&5L92!A9')E<W-E8F]K96XN`$MU;FYE(&EK:V4@=70@:&5L
M92!D:7-T<FEB=7-J;VYS;&ES=&5N+@!+=6YN92!I:VME(&AE;G1E('5T(&AE
M;&4@;&ES=&5N(&UE9"!D:7-T<FEB=7-J;VYS;&ES=&5R+@!+=6YN92!I:VME
M(&QA<W1E(&EN;B!S=')A=&5G:2`G)7,G+@!+=6YN92!I:VME(&]P<')E='1E
M(&MA=&%L;V=E;B`G)7,G+@!+=6YN92!I:VME(&AE;G1E('5T(&]F9F5N=&QI
M9R!N^&MK96P@9G)A(&[X:VME;'1J96YE<F5N+@!+=6YN92!I:VME(.5P;F4@
M)7,N`$MU;FYE(&EK:V4@Y7!N92`G)7,G(&9O<B!S:W)I=FEN9RX`2V%N(&EK
M:V4@Y7!N92!-86EN=&5N86YC95]487-K+6UO9'5L96X@)7,`2W5N;F4@:6MK
M92#E<&YE(&MA=&%L;V=E;B`G)7,G+@!+=6YN92!I:VME(&QE<V4@)7,`2W5N
M;F4@:6MK92!N=6QL<W1I;&QE('!A<W-O<F1E="!F;W(@9&5N(&9O<F5S<'5R
M=&4@8G)U:V5R96XN($YO96X@96QL97(@86QL92!D971A;&IE;F4@97(@=7)I
M:W1I9V4N($9O<G/X:R!I9VIE;B!E;&QE<B!K;VYT86MT(&%D;6EN:7-T<F%T
M;W)E;B!H=FES(&1U('1R96YG97(@>71T97)L:6=E<F4@:&IE;'`N`$MU;FYE
M(&EK:V4@:&5N=&4@=70@04-,`$MU;FYE(&EK:V4@:&5N=&4@=70@861R97-S
M96)O:RX@)7,`2W5N;F4@:6MK92!H96YT92!U="!D:7-T<FEB=7-J;VYS;&ES
M=&4N("5S`$MU;FYE(&EK:V4@:&5N=&4@=70@9&ES=')I8G5S:F]N<VQI<W1E
M+B`E<P!+=6YN92!I:VME(&AE;G1E('5T(&EN9F]R;6%S:F]N(&]M('1J96YE
M<F5N<R!F=6YK<VIO;F%L:71E=&5R`$MU;FYE(&EK:V4@<F5V97)T97)E(&MO
M;F9I9W5R87-J;VYE;F4N`$MU;FYE(&EK:V4@9FIE<FYE(&MA=&%L;V=E;B`G
M)7,G+@!+=6YN92!I:VME(&QA9W)E("5S(&MO;F9I9W5R87-J;VXN`$MU;FYE
M(&EK:V4@;&%G<F4@96X@8F%C:W5P(&MO;F9I9W5R87-J;VXN`$MU;FYE(&EK
M:V4@;&%G<F4@96X@8F%C:W5P(&-O;F9I9W5R87-J;VXZ("5S`$MU;FYE(&EK
M:V4@;&%G<F4@<V5T=7`@;W!P9W)A9&5R:6YG<RUS8W)I<'1E="!T:6PZ("<E
M<R<N`$MU;FYE(&EK:V4@;&%G<F4@8F%C:W5P(&MO;F9I9W5R87-J;VYS9FEL
M96X@)7,N`$MU;FYE(&EK:V4@;&%G<F4@:V]N9FEG=7)A<VIO;G-F:6QE;B`E
M<RX@1'4@:V%N(&5N=&5N(&)E;GET=&4@9&5G(&%V(&5N(&%V(&UU;&EG:&5T
M96YE(&9O<B#E(&QA9W)E(&1A=&$@=&EL8F%K92!T:6P@)7,@96QL97(@:V]P
M:65R92!K;V1E;B!U;F1E<B!M86YU96QT('1I;"`E<RX`2W5N;F4@:6MK92!U
M=&;X<F4@<_AK('#E($Q$05`@=&IE;F5R96XN`$MU;FYE(&EK:V4@9FIE<FYE
M("<E<R<N`$MU;FYE(&EK:V4@;W!P9&%T97)E(&MO;G1A:W0N("5S`$MU;FYE
M(&EK:V4@;W!P9&%T97)E(&1I<W1R:6)U<VIO;G-L:7-T96XN("5S`$MU;FYE
M(&EK:V4@<VMR:79E(&MO;F9I9W5R87-J;VX@9F]R("<E<R<Z("5S`$MU;FYE
M(&EK:V4@9FEN;F4@36]Z:6QL82!3:61E8F%R+B!3:F5K:R!A="!D96X@97(@
MY7!E;BX`0G)U:V5R96X@)R5S)R!B;&4@9VET="!F^&QG96YD92!R971T:6=H
M971E<B!T:6P@;6%P<&5N("<E<R<Z("5S`%1A;'0@=&5K<W0`3&%N9`!+=7)S
M97(`3W!P<F5T=`!/<'!R971T(&5N(&QI;FL`3W!P<F5T="!E;B!N>0!/<'!R
M971T('5N9&5R;6%P<&5R`%)E='1I9VAE=&5R(&9O<B!E:65R`$MR961I='1K
M;W)T;G5M;65R`$=J96QD96YD92!F87-E`$=J96QD96YD92!T:60`1VIE;&1E
M;F1E(';F<@!':F5L9&5N9&4@=71S:6MT97(Z(`!':F5L9&5N9&4@<W1I;`!4
M:6QP87-S(&]P<&=A=F5R('-O;2!K:OAR97,@=F5D(&EN;FQO9V=I;F<@=&EL
M("5S+@!+;&EP<"!U=`!+;&EP<"!U="!V86QG="!O;7+E9&4`2WEP<F]S`$1$
M`$1A9VQI9P!$871A`$1A=&%4<F4@=71F;W)S:V5R`$1A=&\`1&%T;R!-;W1T
M871T`$1A=&\@=F%L9P!$86<`4VQE='0@:V]L;VYN90!$97-E;6)E<@!$97-I
M;6%L=&%L;`!!=G-LY71T`%)E9'5S97(@:6YN<GEK:P!3=&%N9&%R9`!3=&%N
M9&%R9"!F87)G90!3=&%N9&%R9&ED96YT:71E=`!3=&%N9&%R9"!R971T:6=H
M971E<@!3=&%N9&%R9"!R971T:6=H971E<@!$969I;FES:F]N97(`1&5L96=E
M<B!P;W-I<VIO;@!$96QE9V5R=`!3;&5T=`!3;&5T="!G<G5P<&4`4VQE='0@
M<F5T=&EG:&5T`%-L971T(&]G(&9J97)N(&UE;&1I;F=E<@!3;&5T="!C96QL
M90!3;&5T="!K;VQO;FYE`%-L971T(&5K<VES=&5R96YD92!A;'1E<FYA=&EV
M(&UA;`!&:F5R;B!R971T:6=H971E;F4@=&EL("<E<R<`1FIE<FX@<F5T=&EG
M:&5T96YE('1I;"`G)7,G(&]G(&%L;&4@=6YD97(M<F5T=&EG:&5T97(_`%-L
M971T(')A9`!3;&5T="!V86QG="!I9&5N=&ET970`4VQE='0@9VIE;&1E;F1E
M(&MO;&]N;F4`4VQE='0@9VIE;&1E;F1E(')A9`!3;&5T=&4@9&5N;F4@<F5T
M=&EG:&5T96X@;V<@86QL92!U;F1E<BUR971T:6=H971E<C\`4VQE='0@<V5T
M=7`@;W!P9W)A9&5R:6YG<RUS8W)I<'0@)R5S)RX`3&5V97)I;F=S=&ED`$1A
M;FUA<FL`079S;.4@9F]R97-P^')S96P`079S;.4@9F]R97-P^')S96P@9F]R
M(&QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VX`0F5S:W)I=B!P<F]B;&5M970`
M0F5S:W)I=F5L<V4`1&5T86QJ97(@*&]G<^4@:2!(;W)D92=S(&QO9V=F:6PI
M.@!$971A;&IE<B!H87(@8FQI='0@;&]G9V5T(&9O<B!A9&UI;FES=')A=&]R
M96XN`%5T=FEK;&EN9P!$;V=G<'5N:W0`1&]G9W!U;FMT(&9O<B!D96X@<VES
M=&4@=&EM96XZ(`!$;V=G<'5N:W0Z(`!2971N:6YG(&9R82!V96YS=')E(&UO
M="!H^'ER90!2971N:6YG(&9R82!H^'ER92!M;W0@=F5N<W1R90!+871A;&]G
M`%9I<R`R-"UT:6UE<G,@=&ED97(_`%9I<VYI;F=S=F%L9P!6:7,@9F]R=F%R
M<V5L("A4048I`%9I<VYI;F=S9F]R;6%T`$UE;&1I;F<@;VT@;W)D;FEN9P!)
M:VME('-L971T`$EK:V4@Y7!N92!M86EN96YA;F-E+G!H<"!D:7)E:W1E`$MR
M>7-S(&%V(&AE<B!H=FES(&1E;B!F^')S=&4@<F%D96X@:6YN96AO;&1E<B!F
M96QT+6YA=FYE=#H`3&%S="!N960`3&%S="!N960@9V5N97)E<G0@:V]N9FEG
M=7)A<VIO;B!S;VT@4$A0('-C<FEP="X`3F5D=')E:VMS;&ES=&4`365D:7-I
M;F5R`$4M<&]S=`!%4E(`4F5D:6=E<@!2961I9V5R92!B;&]K:P!2961I9V5R
M($=R=7!P90!2961I9V5R(')E='1I9VAE=&5R`%)E9&EG97(@<F5T=&EG:'1E
M<@!2961I9V5R(')E='1I9VAE=&5R(&9O<B`E<P!2961I9V5R('9A;&<@9F]R
M.@!2961I9V5R(')E='1I9VAE=&5R(&9O<B`E<P!2961I9V5R(')E='1I9VAE
M=&5R(&9O<B`E<P!/<'!LYG)I;F<`16QE;65N="XN+@!%;0!%+7!O<W0`12UP
M;W-T861R97-S90!%+7!O<W1A9')E<W-E(&WE('-T96UM92X`12UP;W-T(&UE
M9"!B96MR969T96QS90!&^&QE;'-E<@!4;VT@;65L9&EN9RX`5&]M="!R97-U
M;'1A="X`5/AM('/X:V5K<FET97)I97(`06MT:79E<B!M=6QI9VAE="!F;W(@
MY2!S971T92!I;FX@8FEL9&5R(&9R82!G86QL97)I97(@:2!T96MS=&5N/P!!
M:W1I=F5R92!H^'ER96ML:6MK(&UE;GD_`%-L=71T`,5R<W-L=71T`$=J^'(@
M961I=&]R96X@<W3X<G)E`%-K<FEV(&EN;B!E='0@<VEK:V5R:&5T<W-P^')S
M;>5L('-O;2!D=2!V:6P@8FQI('-P=7)T(&]M(&AV:7,@9'4@^&YS:V5R(.4@
M;G5L;'-T:6QL92!P87-S;W)D970@9&ET="P@9BYE:W,N("=H=F$@97(@;F%V
M;F5T('#E(&MJYFQE9'ER970@9&ET=#\G.@!3:W)I=B!I;FX@861R97-S96X@
M=&EL(&)I;&1E="!H97(`1F5I;`!&96EL('9E9"!S96YD:6YG(&%V('-V87(Z
M("5S`$9E:6P@;65D(&4M<&]S="!M96QD:6YG96XN`$9E:6P@=F5D('-K<FEV
M:6YG('1I;"`G)7,G+@!&96EL.B``175R;W!A`$AV97)T(#$U+B!M:6YU='0`
M2'9E<G0@,BX@;6EN=71T`$AV97)T(#,P+B!S96MU;F0`2'9E<G0@-2X@;6EN
M=71T`$AV97(@:6YN;&]G9VEN9P!(=F5R(&AA;'9T:6UE`$AV97)T(&UI;G5T
M=`!%:W-E;7!E;'9E<F1I97(Z`$MJ^'(`2VKX<F5R.@!5='9I9`!5='9I9"!3
M:61E8F%R`$9O<G9E;G1E="`G*2<`1F]R=F5N=&5T(&)L86YK="!O<F0@96QL
M97(@<75O=&5T('/X:V5K<FET97)I90!5=&SX<'-D871O`$5K<W!O;F5N=`!&
M;W)G<G5N;G-F87)G90!/<'!L87-T:6YG(&%V('-E='5P('9I82!&5%``571H
M96YT:6YG(&%V(&EN<W1I;&QI;F=E<B!F96EL970N`%1I;&MO8FQI;F<@=&EL
M($Q$05`M=&IE;F5R(&9E:6QE="X`5&EL:V]B;&EN9R!T:6P@4TU"+71J96YE
M<B!F96EL970N`$9E:6QE="!V960@:V]P:65R:6YG(&9R82`B)7,B+@!&96EL
M970@=F5D(&MO<&EE<FEN9R!T:6P@(B5S(BX`1F5I;&5T('9E9"!O<'!R971T
M96QS92!A=B!N>2!305-,(&MO8FQI;F<N`$9E:6QE="!V960@9FQY='1I;F<@
M=&EL("(E<R(N`%!E;G0@=N9R`$9A=&%L($9E:6PZ(`!&87@`1F5B<G5A<@!&
M^&QE<R!S;VT`1OAL97,@<V]M.B``1N4@8GEG97(`1N4@<V[X8GEG97(`1F5L
M=&UA=')I<V4`06YT86QL(&9I;&5R.B`E<R!F:6QE<@!!;G1A;&P@9FEL97(Z
M("5S(&9I;&5R`$9I;&)E:&%N9&QE<@!&:6QN879N`$9I;'9A;&<`3&%S="!O
M<'`@9FEL97(`3W!P;&%S=&EN9R!A=B!F:6QE<B!S=/AT=&5S(&EK:V4N`$9I
M;'1E<@!&^')S=&4@:&%L=FWE;F4`1OAR<W1E(&MV87)T;>5N90!&87-T(&9O
M<FAO;&0`4VYU`$9L>70`5.5K90!-87!P96X@)7,@96MS:7-T97)E<B!I:VME
M`$9O;G1F87)G90!-870`1F]R(&YE='1L97-E<F4@<V]M(&EK:V4@<W3X='1E
M<B!B:6QD97(`1F]R=F%R<V5L("A4048I`$%N=&%L;"!D86=E<G,@9F]R=F%R
M<V5L("AVYG(@;V)S('#E(&%T(&1E="!R971U<FYE<G1E(&9O<G9A<G-L970@
M:6YN96AO;&1E<B!BY61E(&1A9R!O9R!N871T.R!E;B!S=&]R('9E<F1I(&AE
M<B!K86X@<F5S=6QT97)E(&D@96X@<W1O<B!B;&]K:RD`1VQE;70@<&%S<V]R
M9&5T/P!3:VIE;6%E<@!3:VIE8FYE+VQY:VME`%1Y<&4@<VMJ96)N92]L>6MK
M90!3:VIE8FYE<B]L>6MK90!3:VIE8FYE<B]L>6MK92`R`$9O<G5M97(`5FED
M97)E<V5N9'1E`$9A;G0@<')O9W)A;6UE;F4Z("5S`$9A;G0@:V%T86QO9V5N
M93H`1G(`4F%M;65R`$QE9&EG+V]P<'1A='0M:6YF;W)M87-J;VX`3&5D:6<O
M;W!P=&%T="!S=F%R`$QE9&EG+V]P<'1A='0@9F]R97-P^')S96P`4W9A<B!P
MY2!L961I9R]O<'!T871T(&9O<F5S</AR<V5L`$9R80!&<F$@`$9U;&P@8F5S
M:W)I=F5L<V4`1G5L;&WE;F4`1G5L;'0@;F%V;@!'86QL97)I(&1U(/AN<VME
M<B#E(&AE;G1E(&)I;&1E(&9R80!'86QL97)I.@!'96YE<F5R("5S(&MO;F9I
M9W5R87-J;VX`1V5N97)E<G0@:V]D90!'971O<'0@1F5I;#H@`$=I='0@3F%V
M;@!';P!3^&L@<.4@1V]O9VQE`$=RY71O;F4`2&5L;&%S`$=R^&YL86YD`$=R
M=7!P92!A9&UI;FES=')A<VIO;@!'<G5P<&5N879N(&MA;B!I:VME(';F<F4@
M=&]M;64`1W)U<'!E<F5T=&EG:&5T97(`1W)U<'!E<@!2971T:6=H971E<B!F
M;W(@9VIE<W0`4F5T=&EG:&5T97(@9F]R(&=J97-T`$=J97-T96)O:P!(2`!(
M5$U,`$A434Q!<F5A(&YE:W1E<B#E('-L971T92!D96X@<VES=&4@8V5L;&5N
M(&D@96X@<F%D+@!(5$U,07)E82!N96MT97(@Y2!S;&5T=&4@9&5N('-I<W1E
M(&MO;&]N;F5N(&D@=&%B96QL96XN`$A434Q!<F5A(&YE:W1E<B#E('-L971T
M92!D96X@<VES=&4@<F%D96X@:2!T86)E;&QE;BX`2%144"!A=71E;G1I<V5R
M:6YG(&EK:V4@9G5N;F5T+@!(87-H+6%L9V]R:71M90!$:7,`2&]D90!(^'ED
M90!(:F5L<`!(:F5L<"!T:6P@8G)U:R!A=B!E9&ET;W(`2&IE;'!E<@!(86QV
M:W5L90!(97(@97(@8F5G>6YN96QS96X@<.4@9FEL96XZ`$CX>0!(:7-T;W)I
M96]P<&;X<FEN9V5R('#E(&AA(&YA=FX@<V]M(&EK:V4@97(@=&]M;64`2&IE
M7VT`2&IE;0!(:F5M;65A9')E<W-E`%1E;&5F;VX@:&IE;6UE`$AO<F1E`$AO
M<F1E+TMO;&%B.B!59WEL9&EG("5S(%A-3"!D871A(&9U;FYE="!I(&UE;&1I
M;F<@)7,`2&]R9&4O2V]L86(Z($EN9V5N(&UE;&1I;F<@<&%S<V5R(&UE9"!O
M8FIE:W1E="`E<P!(;W)D92]+;VQA8CH@26YT970@;V)J96MT(&%V('1Y<&5N
M("5S(&9U;FYE="!I(&UE;&1I;F<@)7,`2&]R9&4O2V]L86(Z($9J97)N970@
M)7,@(B5S(@!(;W)D92]+;VQA8CH@4WEN:W)O;FES97)T92`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!);G1E9W)A<VIO;G-M;W1O<F5N(&MR979E<B!02%`@)V1O
M;7AM;"<@=71V:61E;'-E`$AO<F1E+TMO;&%B.B!+=6YN92!I:VME(&]P<')E
M='1E(&YY='0@6$U,('1R92!F;W(@;V)J96MT970@)7,`2&]R9&4O2V]L86(Z
M($MU;FYE(&EK:V4@9FIE<FYE("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!+
M=6YN92!I:VME(&AE;G1E($U)344@240@9F]R(&1E;&5N(&%V('1Y<&4@)7,`
M2&]R9&4O2V]L86(Z($MU;FYE(&EK:V4@<WEN:W)O;FES97)E("5S("(E<R(Z
M("5S`$AO<F1E+TMO;&%B.B!+=6YN92!I:VME('-Y;FMR;VYI<V5R92!D96QT
M92!R97-S=7)S97(Z("5S`$AO<F1E+TMO;&%B.B!5:VIE;G0@9&5L="!R97-S
M=7)S("(E<R(`2&]R:7-O;G1A;"!L:6YJ90!(;W)I<V]N=&%L('!A9&1I;F<`
M2&]R:7-O;G1A;#H`2'9O<F1A;B!K;VT@9'4@:&ET/R`H5F5N;FQI9W-T(')A
M<'!O<G1E<B$I`$AV;W(@;6%N9V4@:V]L;VYN97(@^&YS:V5R(&1U(.4@<VSE
M('-A;6UE;C\`2'9O<B!M86YG92!F96QT97(@*&MO;&]N;F5R*2!E<B!D970_
M`$AV;W(@;6%N9V4@<F%D97(@^&YS:V5R(&1U(.4@<VSE('-A;6UE;C\`1G5K
M=&EG:&5T`$9U:W1I9VAE=#H@`$AU;6]R:7-T97(`3W!P<F5T=&5L<V4@878@
M24U!4"!P;W-T8F]K<R!F96EL970Z("5S`%-L971T:6YG(&%V($E-05`@<&]S
M=&)O:W-E;B!F96EL970Z("5S`$]P<')E='1E;'-E(&%V(&MV;W1E('#E($E-
M05`@<&]S=&)O:W,@9F5I;&5T.B`E<P!)4"!!9')E<W-E`$E0($%D<F5S<V4@
M:6MK92!T:6QG:F5N9V5L:6<N`$E0($%D<F5S<V4@:6MK92!I;FYE;F9O<B!T
M:6QA='1E($-)1%(@8FQO:VLN`$)R=61D('#E($E0(&QO8VMD;W=N+@!37V5T
M="!I;FX@;GD@<F%D(&;X<@!+=6X@:6MO;F5R`$EK;VYE<B!F;W(@)7,`26MO
M;F5R(&UE9"!T96MS=`!)9&5N=&ET971E;G,@;F%V;CH`2'9I<R!D96X@:6MK
M92!V:7-E<R!R:6MT:6<L("5S(&9O<B#E(.5P;F4@:2!N>71T('9I;F1U+@!(
M=FES(&1U(&EK:V4@<V5R(&YO96X@:6MO;F5R(&[E<B!D=2!B96YY='1E<B!)
M;G1E<FYE="!%>'!L;W)E<BP@:V%N(&1E="!H96YD92!D=2!T<F5N9V5R(.4@
M:W)Y<W-E(&%V(&1E;FYE(&)O:W-E;B!F;W(@Y2!S:W)U(&%V('1R86YS<&%R
M96YT(%!.1RX`2'9I<R!D=2!S97(@9&5N;F4@;65L9&EN9V5N(&UE;B!I;G1E
M="!B:6QD92P@:V%N(&1E="!H96YD92!A="!B:6QD970@9'4@=FEL(&QA<W1E
M(&]P<"!I:VME(&MA;B!V:7-E<R!I(&1I;B!N971T;&5S97(N`$9O<FCE;F1S
M=FES;FEN9R!A=B!B:6QD93H`0FEL9&5A9')E<W-E`$)I;&1E861R97-S93H`
M0FEL9&4@9G)A(&=A;&QE<FD`0FEL9&4@9G)A(&=A;&QE<FDZ`$]P<&QA<W1I
M;F<@878@8FEL9&4`0FEL9&5R`$EM<&]R=&5R:6YG+"!S=&5G("5D`$EM<&]R
M=&5R=&4@9F5L=#H@)7,`26UP;W)T97)T92!F96QT.@!5;F1E<B!A<F)E:60`
M7U-E='0@:6YN(')A9"!E='1E<@!&96EL(&AA;F1L:6YG<VMO9&4@9VET="X`
M56=Y;&1I9R!B<G5K97)N879N(&]G+V5L;&5R('!A<W-O<F0N`$9E:6P@8G)U
M:V5R;F%V;B!E;&QE<B!A;'1E<FYA=&EV(&%D<F5S<V4N(%9E;FYL:6=S="!F
M;W)S^&L@:6=J96X@96QL97(@:V]N=&%K="!S>7-T96UA9&UI;FES=')A=&]R
M96X@9&EN(&9O<B!Y='1E<FQI9V5R97)E(&AJ96QP+@#8:R!I;FYR>6MK`$EN
M9&EV:61U96QL92!B<G5K97)E`$EN9F\`26YF;W)M87-J;VX`4V5T="!I;FX@
M:U]O;&]N;F4@971T97(`4V5T="!I;FX@8FEL9&4`4V5T="!I;FX@=&%B96QL
M`%-E='0@:6YN('=E8FQI;FL`4V5T="!I;FX@7VMO;&]N;F4@9OAR`%-E='0@
M:6YN(&5N(&YY(&MO;&]N;F4@971T97(@9&5N(&=J96QD96YD90!3971T(&EN
M;B!E;B!N>2!K;VQO;FYE(&;X<B!D96X@9VIE;&1E;F1E`%-E='0@:6YN(&5N
M(&YY(')A9"!E='1E<B!D96X@9VIE;&1E;F1E`%-E='0@:6YN(&5N(&YY(')A
M9"!F^'(@9&5N(&=J96QD96YD90!3971T(&EN;B!L:6YJ97-K:69T(&5T=&5R
M(&1E;B!G:F5L9&5N9&4@;F]D96X`4V5T="!I;FX@;&EN:F5S:VEF="!F^'(@
M9&5N(&=J96QD96YD92!N;V1E;@!3971T(&EN;B!A;'1E<FYA=&EV(&UA;`!3
M971T(&EN;B!E;B!E+7!O<W0@861R97-S92!D=2#X;G-K97(@Y2!M;W1T82!D
M970@;GEE('!A<W-O<F1E="!PY3H`4V5T="!I;FX@8V5L;&4@971T97(`4V5T
M="!I;FX@8V5L;&4@971T97(`4V5T="!I;FX@:V]L;VYN92!E='1E<@!3971T
M(&EN;B!K;VQO;FYE(&;X<@!3971T(&EN;B!M96QD:6YG97(`4V5T="!I;FX@
M;&EN:F5S:VEF="!E='1E<@!3971T(&EN;B!L:6YJ97-K:69T(&;X<@!3971T
M(&EN;B!R860@971T97(`4V5T="!I;FX@<F%D(&;X<@!3971T(&EN;B!D970@
M<.5K<F5V9&4@<W9A<F5T('1I;"!F^&QG96YD92!S:6MK97)H971S<W#X<G-M
MY6PZ`%-E='0@:6YN+W)E9&EG97)E(&)I;&1E`%-E='0@:6YN+W)E9&EG97)E
M(&QI;FL`26MK92!N;VL@:W)E9&ET="!F;W(@Y2!K=6YN92!S96YD92!T:6P@
M9&ES=')I8G5S:F]N<VQI<W1E;BX`26MK92!N;VL@:W)E9&ET="X`26YT96=E
M<@!59WEL9&EG(&AA;F1L:6YG('9A;&=T(&9O<B!D96YN92!K;VUP;VYE;G1E
M;BX`56=Y;&1I9R!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`56=Y;&1I9R!P
M<F]G<F%M+@!59WEL9&EG(&)A=&-H($E$`%5G>6QD:6<@9&%T82!S96YD="X`
M56=Y;&1I9R!M;W1T86ME<B!A9')E<W-E+@!59WEL9&EG(&9I;&9O<FUA=`!5
M9WEL9&EG(&UE;&1I;F=S='EP90!59WEL9&EG(&5L;&5R(&UA;F=L96YD92!A
M<&E?:60N`%5G>6QD:6<@96QL97(@;6%N9VQE;F1E('!A<F%M971E<F4N`%5G
M>6QD:6=E(')E='1I9VAE=&5R+@!59WEL9&EG('!R;W1O:V]L;"X`56=Y;&1I
M9R!M;W1T86ME<CH@)R5S)P!59WEL9&EG(&1E;'0@;V)J96MT`%5G>6QD:6<@
M:VEL9&5A9')E<W-E`%5G>6QD:6<@=6YI8V]D92!D871A+@!);FYH;VQD`$ES
M;VQE<G1E('1O<F1E;BUS=&]R;65R`%5T9VEV97(`2W5R<VEV`$IA;G5A<@!*
M=6QI`$IU;FD`2G5S=&5R`$UI9'1S=&EL;`!"96AO;&1E(&]R9VEN86P_`$ME
M<F)E<F]S('1J96YE<F5N(&%V=FES=&4@875T96YT:7-E<FEN9V5N+@!+97)N
M96P@3GEB96=Y;FYE<F4`3OAK:V5L9V5N97)E<FEN9P!.^&MK96P@9FEN9V5R
M<')I;G0`3OAK:V5L(&QE;F=D90!.^&MK96P@='EP90!.^&MK96QB<G5K`$[X
M:VME;"!E:W-I<W1E<F5R(&%L;&5R961E('#E(&1E;B!O9F9E;G1L:6=E(&[X
M:VME;'1J96YE<F5N+@!"87)N`%5T7W-E96YD90!3<'+E:P!3:7-T92!H86QT
M:6UE`%-I<W1E(&MV87)T97(`4VES=&4@;W!P9&%T97)I;F<Z`%-I<W1E(&EN
M;FQO9V=I;F<Z("5S`%-I<W1E(&EN;FQO9V=I;F<Z("5S(&9R82`E<P!3:7-T
M92!I;FYL;V=G:6YG.B!!;&1R:0!,;W8`571S965N9&4`V&YS:V5S(&EN9V5N
M(')A;6UE<B!L87(@9'4@9F5L=&5T(';F<F4@=&]M=`!696YS=')E`%9E;G-T
M<F4@:&]D90!696YS=')E('9E<F1I97(`3&5T="!D=7-K<F5G;@!,971T(')E
M9VX`3&5T="!F;W)M:61D86=S<F5G;@!,971T(&5T=&5R;6ED9&%G<W)E9VX`
M3&5T=&4@<F5G;F)Y9V5R`$QE='0@<F5G;B!M960@=&]R9&5N`$QE='0@<V[X
M9F%L;`!,971T92!S;OAB>6=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@<&5K97(@
M=&EL.@!,:6YK(&4M<&]S="!A9')E<W-E;B!T:6P@)W-K<FEV(&YY)RUS:61E
M('9E9"!V:7-N:6YG`$QI;FME<@!,:6YU>"!#;V]K:64`3&ES="`M(&)R=6ME
M<F5N(&MA;B!S92!M87!P96X`3&ES="!D871A8F%S97(`16UN97(@:2!(:F5L
M<`!,:7-T('1A8F5L;&5R`$QI<W1E+6%R:VEV`$QI<W1E:&IE;'``3&ES=&4M
M260`16EE<B!A=B!L:7-T90!,:7-T92UP;W-T`$%B8F]N97(@<.4@;&ES=&4`
M4W1O<'`@86)B;VYN96UE;G0@<.4@;&ES=&4`375L:6=H970@9F]R(.4@;&ES
M=&4@8G)U:V5R92!E<B!D96%K=&EV97)T+@!,:71T97)A='5R`$QA<W1E<B!B
M:6)L:6]T96ME<BXN+@!,87-T97(N+BX`3&]K86P@=&ED.@!3<'+E:R!O9R!T
M:60`3&]K87-J;VX`3&]G9R!I;FX`3&]G9R!U=`!);FYL;V=G:6YG<V]P<&=A
M=F5R`$QO9VEN(&9E:6QE="!F;W)D:2!B<G5K97)N879N970@96QL97(@<&%S
M<V]R9&5T(&1U('-K<F5V(&EN;B!V87(@9F5I;"X`3&]G:6X@9F5I;&5T+@!,
M86YG('1E:W-T`$MJYG)L:6=H970`3&%V`%-MY2!G<F5S:V4@8F]K<W1A=F5R
M`%-MY2!L871I;G-K92!B;VMS=&%V97(`34T`26YN8F]K<P!386US=F%R96YD
M92!F96QT`$WX=&5A=FQY<VYI;F<`3?AT96EN9F]R;6%S:F]N`$WX=&5I;FYK
M86QL96QS90!-^'1E<W9A<@!-^'1E;W!P9&%T97)I;F<`1F]R97/X<G-E;"!O
M;2!M^'1E;W!P9&%T97)I;F<`365N>6UO9'5S.@!-96QD:6YG`$WE;F5D=&QI
M9P!F;'ET="!N960`9FQY='0@;W!P`$YA=FX`5')E;F=E<B!H86YD;&EN9P!!
M;&1R:0!.>6AE=&5R`$YE<W1E`$YE<W1E('-I9&4`3F5I`$EK:V4@9&5L=&%G
M97(`26YG96X`3F]T871E<@!/8G,A`$]+`$MO;G1O<@!686QG9G)I(&1E;'1A
M9V5R`%9A;&<`3W)G86YI<V5R:6YG`$%N;F5N(&EN9F]R;6%S:F]N`%!A<W-O
M<F0`571F^'(@=F5D;&EK96AO;&1S;W!E<F%S:F]N97(`571F^'(@=F5D;&EK
M96AO;&1S;W!E<F%S:F]N97(@=F5D(&EN;FQO9V=I;F<_`%!E<G-O;FQI9R!I
M;F9O<FUA<VIO;@!496QE9F]N`%9E;FYL:6=S="!G:2!E="!S86UM96YD<F%G
M(&%V('!R;V)L96UE="X`5F5N;FQI<W0@<VMR:78@:6YN(&)R=6ME<FYA=FX@
M;V<@<&%S<V]R9`!696YN;&EG<W0@<V4@;W9E<B!D96X@9OAL9V5N9&4@:6YF
M;W)M87-J;VYE;BP@=F5L9R!SY2!E;B!H86YD;&EN9R!F<F$@;65N>65N(&YE
M9&5N=6YD97(N`%9E;FYL:6=S="!V96QG(&5N(&AA;F1L:6YG(&9R82!M96YY
M96X@;F5D96YU;F1E<BX`1F]R:.5N9'-V:7-N:6YG`$9O<G)I9V4@<VED90!0
M<F]B;&5M8F5S:W)I=F5L<V4`2'5S:R!L961I9R]O<'!T871T+6EN9F]R;6%S
M:F]N+@!&:F5R;B!P87(`4W9A<B!S96YD="X`4W9A<B!A="!M96QD:6YG96X@
M:6MK92!S=/AT=&5S`%-V87(@;65D(&QE9&EG+V]P<'1A='0@9F]R(&1E(&YE
M<W1E('1O(&WE;F5D96YE+@!3=F%R(&UE9"!D96X@9F]R97-P=7)T92!L961I
M9R]O<'!T871T+6EN9F]R;6%S:F]N96XN`$]B;&EG871O<FES:R!D96QT86=E
M<@!.=6QL<W1I;&P`5&EL8F%K92!T:6P@5F%L9P!2;VQL90!,86=R92!S;VT`
M3&%G<F4@5F%L9P!3^&L`5F5L9R!E;B!D871O`%9E;&<@9&%T;W-K:6QL971E
M9VXZ`%9E;&<@9&%T;V9O<FUA=`!696QG('1I9'-F;W)M870Z`%9E;&<@=&\@
M<V%M<W9A<F5N9&4@9F5L="X`5F5L9R#X;G-K970@<W!RY6LZ`%-E;F0@<VES
M=&4@:6YF;W)M87-J;VX`4V5N9"!P<F]B;&5M<F%P<&]R=`!296=I<W1R97(@
M9&5G(&]M(&EK:V4@<F5G:7-T<F5R=`!3=/AR<F5L<V4`2&]P<"!O=F5R('9E
M9&QI:V5H;VQD`%-P97-I86QT96=N:6YN=&%S=&EN9P!3=&%R=`!3=&%T=7,`
M16UN90!396YD`%-U:W-E<W,`4V%M;65N9')A9P!/<'!G879E<@!';V1T82!F
M;W)E<W#X<G-E;"!F;W)E;/AP:6<`1V]D=&$@9F]R96SX<&EG`$MU;B!T96MS
M=`!+86QE;F1E<F1A=&$@97(@=6=Y;&1I9P!(86YD;&EN9V5N(&AA<B!B;&ET
M="!L86=T('1I;"!D:6X@;&ES=&4@;W9E<B!H86YD;&EN9V5R+@!"<G5K97)E
M;G,@;&5D:6<O;W!P=&%T="!I;F9O<FUA<VIO;B!B;&4@;&%G<F5T+@!$970@
M;W!P<W1O9"!E;B!F96EL('5N9&5R(&9O<G/X:R!PY2#E('9I<V4@9&5N;F4@
M;65L9&EN9W-D96QE;@!$970@;W!P<W1O9"!E;B!F96EL('5N9&5R(&EM<&]R
M=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N`$1E="!O<'!S=&]D(&5N(&9E:6P@
M=F5D(&EM<&]R=&5R:6YG(&%V(&AE;F1E;'-E;CH@)7,N`$1E="!O<'!S=&]D
M(&5N(&9E:6P@=F5D(&EM<&]R=&5R:6YG(&%V(&)R=6ME<F5N<R!L961I9R]O
M<'!T871T+6EN9F]R;6%S:F]N.B`E<P!$96X@9F]R97-P=7)T92!O<'!G879E
M;B!E<B!I:VME('-T;W1T970N`$1E;B!F;W)E<W!U<G1E(&]P<&=A=F5N(&5R
M(&EK:V4@:6UP;&5M96YT97)T+@!$971T92!T86QL970@;>4@=N9R92!M:6YS
M="`Q+@!$971T92!MY2!VYG)E(&5T('1A;&PN`%1I='1E;`!4:6P`55),`$MA
M;B!I:VME(&MO8FQE('1I;"!344QS97)V97)E;BX`2V%N(&EK:V4@;W9E<G-E
M='1E(&1E='1E(%=O<F0M9&]K=6UE;G1E=`!!;F=R92!E;F1R:6YG97(`56CE
M;F1T97)T(&MO;7!O;F5N="!A=B!T>7!E;CH@)7,`571E;B!N879N`$]P<&1A
M=&5R('-T871U<R!PY2!A=G-E;F1E<F4`3&%S="!O<'``3&%G<F4@5F%L9P!"
M<G5K97)N879N`$)R=6ME<FYA=FXZ`%9I<R`E<P!6:7,@:&5N9&5L<V4`5FES
M(&AA;F1L:6YG97(`061V87)S96P`56ME;G1L:6<`5F5L:V]M;65N('1I;"`E
M<P!696QK;VUM96XL("5S`$9I<FUA861R97-S90!&:7)M871E;&5F;VX`Y>4`
MY7)L:6<`2F$`1'4@;>4@8F5S:W)I=F4@<')O8FQE;65T(&;X<B!D=2!K86X@
M<V5N9&4@96X@<')O8FQE;7)A<'!O<G0N`$1I;B`E<R!T:6QK;V)I;F<@:&%R
M(&?E='0@=70N(%9E;FYL:6=S="!L;V<@:6YN(&EG:F5N+@!$:6X@:6YF;W)M
M87-J;VX`1G5L;'0@;F%V;@!.971T;&5S97)E;B!D:6X@<W3X='1E<B!I:VME
M(&1E;FYE('5T<VMI9G1S;W!E<F%S:F]N96XN(%1R>6MK($MO;G1R;VQL+T]P
M<VIO;B`K(%`@9F]R(.4@<VMR:79E('5T+@!$:6YE('9A;&<@:&%R(&)L:71T
M(&]P<&1A=&5R=`!;4')O8FQE;7)A<'!O<G1=`%ML:6YJ92`E<R!A=B`E<UT`
M2&IE;'``3&]G9R!U=`!686QG`&YA=FX`=D-A<F0`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VQV
M7TQ6+TQ#7TU%4U-!1T53````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,34R,``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O;'9?3%8O3$-?34534T%'15,O:&]R9&4N;6\`````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,U-S$@,3`U,34T,S0Q-#$@,#(S
M,C0T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````9````!P````\`P``B0```%P&````````@`@``"@```"!"```
M"````*H(```%````LP@```@```"Y"```!P```,((```%````R@@``!\```#0
M"```$0```/`(```(`````@D```@````+"0``%0```!0)```*````*@D```P`
M```U"0``!P```$()```I````2@D```(```!T"0``!0```'<)```0````?0D`
M`!0```"."0``+P```*,)```/````TPD``"8```#C"0``!0````H*```-````
M$`H```4````>"@``$````"0*```0````-0H```\```!&"@``"P```%8*```/
M````8@H```P```!R"@``#P```'\*```>````CPH``"$```"N"@```P```-`*
M```$````U`H```P```#9"@``"@```.8*```%````\0H``!(```#W"@``$```
M``H+```(````&PL``!`````D"P``!@```#4+```'````/`L```(```!$"P``
M!````$<+```/````3`L```<```!<"P``!P```&0+```$````;`L```4```!Q
M"P``!0```'<+```'````?0L``!$```"%"P``"````)<+```>````H`L```4`
M``"_"P``*````,4+```I````[@L``!,````8#```"P```"P,```1````.`P`
M``0```!*#```#````$\,```:````7`P``!<```!W#```%P```(\,```;````
MIPP``!\```###```$P```.,,```0````]PP``!<````(#0``!P```"`-```%
M````*`T``"$````N#0``'````%`-```%````;0T```,```!S#0``(````'<-
M```F````F`T```P```"_#0``#````,P-```(````V0T```<```#B#0``!@``
M`.H-```-````\0T```L```#_#0``#`````L.```*````&`X```(````C#@``
M!@```"8.``!%````+0X``#````!S#@``$````*0.```?````M0X``!````#5
M#@``#P```.8.```%````]@X``%<!``#\#@``*@```%00```*````?Q````4`
M``"*$```#@```)`0```&````GQ````P```"F$```&0```+,0```0````S1``
M``\```#>$```"0```.X0```;````^!```!$````4$0``#````"81```(````
M,Q$``"L````\$0```@```&@1```(````:Q$``!(```!T$0``$P```(<1```O
M````FQ$``!(```#+$0``(@```-X1```'`````1(``!`````)$@``!0```!H2
M```1````(!(``!(````R$@``$````$42```8````5A(```\```!O$@``#```
M`'\2```.````C!(``!X```";$@``)````+H2```%````WQ(```D```#E$@``
M#````.\2```.````_!(```4````+$P``%````!$3```0````)A,```8````W
M$P``&@```#X3```+````61,```4```!E$P```@```&L3```%````;A,``!``
M``!T$P``!````(43```,````BA,```4```"7$P``!0```)T3```(````HQ,`
M``<```"L$P``$````+03```&````Q1,``!\```#,$P``"````.P3```C````
M]1,``"T````9%```$@```$<4```,````6A0``!<```!G%```!````'\4```0
M````A!0``!X```"5%```&P```+04```:````T!0``",```#K%```$P````\5
M```<````(Q4``!(```!`%0``%````%,5```'````:!4```@```!P%0``'P``
M`'D5```?````F14```H```"Y%0```P```,05```G````R!4``"L```#P%0``
M#P```!P6```1````+!8```\````^%@``"P```$X6```,````6A8``!````!G
M%@``$````'@6```,````B18```X```"6%@```@```*46```*````J!8``"\`
M``"S%@``/````.,6```0````(!<``!L````Q%P``%````$T7```0````8A<`
M``4```!S%P```0```"0`````````3@```!T```!/````%P```$4````'````
M(@````````!-````(0````````!+````8@````H````1``````````P````R
M````4P```#$`````````)0```$8```!=`````````%(```!"````50``````
M``!'````+````"\```!6````40```#4````0````"````#X```!!````7P``
M`"L````/````.0```$H````C````&````#,```!`````*````&`````+````
M``````````!4```````````````]````"0`````````N````2````%P````Z
M``````````X`````````60`````````V`````````!L````_````'````!H`
M```-````.P`````````$````!0`````````2`````````!,`````````5P``
M`"T`````````)@``````````````%0````8`````````6P```#<````9````
M`````%X`````````.````#0`````````20```!\```!:````1``````````>
M``````````````!C`````````%@````I`````````#```````````````#P`
M``!D````4``````````6````(``````````#````80```$,````J````)P``
M`$P````"`````````!0`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M
M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S
M`$%L:6%S`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`079A:6QA
M8FQE(&9I96QD<SH`0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-E;&P@4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]U;&0@
M;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`
M1&5F875L="!)9&5N=&ET>0!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS
M(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7-P
M;&%Y($]P=&EO;G,`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC
M92YP:'``16UA:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU
M=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO
M9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU
M97,Z`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@
M8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S
M`$AO;64@4&AO;F4`2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D
M(&9I96QD<SH`3&%N9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G
M(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO;G1H;'D`
M3F%M90!.979E<@!.;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A
M<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@
M1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L
M90!3879E($]P=&EO;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L
M96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`
M4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT
M96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S:W,`
M5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@
M;75S="!B92!A(&YU;6)E<BX`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T
M('1O(%-13"!S97)V97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P=&EO;G,`57-E<FYA;64`
M5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K
M($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E
M(&QO9VEN(&%G86EN+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H
M879E(&)E96X@=7!D871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O
M9B`E<UT`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C$*4F5P
M;W)T+4US9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R
M96%T:6]N+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO
M;BU$871E.B`R,#`R+3$Q+3(X(#$T.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R
M.B!+87-P87)S($MA<&5N:65K<R`\:V%S<&%R<T!R8V,N;'8^"DQA;F=U86=E
M+51E86TZ($QA='9I86X@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M0U`Q,C4W"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`E<R!5
M>G1U<N?P86YA<R!O<&5RXF-I:F%S("T@87!S=&EP<FENXFIU;7,`,C0@<W1U
M;F1A<P!!32]030!0:65V:65N;W0@<.)R:0!!9')E<V4`06EZ<W3B:G;B<F1S
M`$YO<N)D[G1A(&YE9&5R[F=A(';G<G3N8F$`4&EE96IA;6EE(&QA=6MI.@!$
M>FEM\&%N87,@9&EE;F$`2V%L96YDXG)S`$%T8V5L="!P<F]B;.=M87,@<&EE
M=&5I:W5M=0!-;V)I;&%I<R!TXFQR=6YI<P!!:7IVYW)T(&QO9W4`57KRYVUU
M;7,`3F5I>F1E=N)S(&%T=N=R="!-86EN=&5N86YC95]487-K(&UO9'5L:2`E
M<P!$1`!):V1I96YA<P!087)A<W3B(&ED96YT:73B=&4`07!R86MS=&EE="!P
M<F]B;.=M=0!3[FOB:V$@:6YF;W)MXF-I:F$@:7(@;F]S^W3N=&$@861M:6YI
M<W1R871O<F%M+@!%:W+B;F$@:65S=&%T[FIU;6D`3F%V('1I9?!A<R!P:65E
M:F%S(&UA:6YT96YA;F-E+G!H<`!%+7!A<W1S`%1U:_!S(')E>G5L=.)T<RX`
M2^_[9&$`2V%T<F%S(#$U(&UI;OMT97,`2V%T<F%S(#,P('-E:W5N9&5S`$MA
M=')A<R`U(&UI;OMT97,`2V%T<N(@<&EE<VSG9_!A;N)S(')E:7KG`$MA=')U
M('!U<W-T=6YD=0!+871R=2!M:6[[=&D`4&%R875G=N=R=.YB87,`3F5I>F1E
M=N)S('-A\F5M="!I97-T873N:G5M=7,N`$YE:7ID97;B<R!P:65S;.=G=&EE
M<R!,1$%0('-E<G9E<FEM+@!&86MS<P!086SN9'KN8F$`3>)J87,@861R97-E
M`$WB:F%S('1E;&5F;VYS`$AO<F1E`$EE;.)DYW1A:7,@;&%U:W,Z("5S`$EE
M;.)DYW1I92!L875K:3H`5F%L;V1A`%!A<N)D[G0@<&%L[F1Z[F)A<R!T96UA
M='5S`%!I97-LYV=T:65S`$EZ:65T`$U-`%!A<W1S`%-A<VMA;F_P:64@;&%U
M:VD`6FGR80!+871R=2!MYVYE<VD`5N)R9',`3F5K860`4&EE>NYM97,`3W!C
M:6IA<P!#:71A(&EN9F]R;>)C:6IA`%!A<F]L90!)>G!I;&3N="!U>G1U<N?P
M86YA<R!O<&5RXF-I:F%S`%3B;')U;FES`$S[9'IU(&YO<N)D:65T('!R;V)L
MYVUA<R!A;F]TXF-I:G4N`$S[9'IU(&YO<N)D:65T('-A=G4@;&EE=&]TXFIA
M(';B<F1U('5N('!A<F]L:0!0<F]B;.=M87,@87!R86MS=',`27ID>N=S="!P
MXG)I`$%T9W)I97IT:65S('!I92!O<&-I:N)M`$QO;6$`4V%G;&%BXG0@;W!C
M:6IA<P!)>G;G;&EE=&EE<R!D871U;6$@871D86SN=.)J=3H`27IVYVQI971I
M97,@9&%T=6UA(&9O<FWB='4Z`$EZ=N=L:65T:65S(&QA:6MA(&9O<FWB='4Z
M`$EZ=N=L:65T:65S(&1I=G5S('-A9&5R[F=U<R!L875K=7,N`$EZ=N=L:65T
M:65S('9A;&]D=3H`3F]S^W3N="!P<F]B;.=M87,@<&EE=&5I:W5M=0!)>FQA
M:7-T('5Z='5RY_!A;G4`SG!A\&\@<VEM8F]L=2!I979A9&4`5F5I:W-M90!5
M>F1E=G5M:0#0:6T@<VMA:71L:6T@:7(@:N)B^W0@=FES;6%Z(#$N`-!A:2!V
MYW)T[F)A:2!I<B!JXF+[="!S:V%I=&QI;2X`5FER<W)A:W-T<P!54DP`3F%V
M(&EE<W#G:F%M<R!P:65S;.=G=&EE<R!344P@<V5R=F5R:6TN`$YA=B!I97-P
MYVIA;7,@:6YT97)P<F5TYW0@\&\@5V]R9"!D;VMU;65N='4`071C96QT(&EZ
M;6%I\F%S`$QI971O=.)J82!O<&-I:F%S`$QI971O=.)J82!VXG)D<P!"<NYD
M:6[B:G5M<P!+871R=2!N963G[W4`3&%I<&YI(&S[9'IA;2`E<P!,86EP;FD@
M;/MD>FTL("5S`$1A<F)A(&%D<F5S90!$87)B82!TXFQR=6YI<P!'1P!+871R
M=2!G861U`$%P<F%K<W1I970@<')O8FSG;74@<&ER;7,@<&EE=&5I:W5M82!S
M^W3N\&%N87,N`$K[<W4@)7,@<V5S:6IA(&ER(&)E:6=U<VEE<RX@3/MD>G4@
M<&EE<VSG9'II971I97,@871KXG)T;W1I+@!*^W-U(&EN9F]R;>)C:6IA`$K[
M<W4@;W!C:6IA<R!I<B!S86=L86+B=&%S+@!;4')O8FSG;6%S('II\F]J=6US
M70!;<FEN9&$@)7,@;F\@)7-=`'9#87)D````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]M:U]-2R],0U]-15-304=%4P``````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,C$T-S0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VUK7TU++TQ#7TU%4U-!1T53
M+VAO<F1E+FUO````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-C$P(#$P
M-3$U-#,T,30Q(#`R,S(Q,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#>$@25`````%@````<````W`(``'\```"<!0``````
M`)@'```H````F0<```@```#"!P``!0```,L'```/````T0<```@```#A!P``
M"````.H'```9````\P<```<````-"```#@```!4(```%````)`@``!$````J
M"```"````#P(```5````10@```H```!;"```#````&8(```'````<P@``!``
M``!["```*0```(P(```"````M@@```4```"Y"```$````+\(```&````T`@`
M`!0```#7"```)@```.P(```%````$PD```T````9"0``!0```"<)```+````
M+0D```\````Y"0``(0```$D)```#````:PD```0```!O"0``#````'0)```*
M````@0D```4```","0``$@```)()```0````I0D``!````"V"0``&@```,<)
M```&````X@D```<```#I"0```@```/$)```$````]`D```\```#Y"0``!P``
M``D*```'````$0H```0````9"@``!0```!X*```(````)`H``!4````M"@``
M'@```$,*```%````8@H``"@```!H"@``*0```)$*```3````NPH```L```#/
M"@``!0```-L*```1````X0H```0```#S"@``#````/@*```:````!0L``!<`
M```@"P``%P```#@+```;````4`L``!,```!L"P``$````(`+```7````D0L`
M``<```"I"P``!0```+$+```#````MPL``"````"["P``)@```-P+```,````
M`PP```@````0#```%````!D,```'````+@P```8````V#```"P```#T,```,
M````20P```H```!6#````@```&$,```&````9`P``$4```!K#```)@```+$,
M```E````V`P``',```#^#```$````'(-``!Q`0``@PT``"(```#U#@``!P``
M`!@/```%````(`\``!0````F#P``"@```#L/```/````1@\``"<```!6#P``
M!@```'X/```.````A0\```4```"4#P``$````)H/```(````JP\``!4```"T
M#P``!P```,H/```5````T@\```4```#H#P``#P```.X/```[````_@\```(`
M```Z$```!@```#T0```4````1!````<```!9$```$0```&$0```J````<Q``
M``<```">$```$````*80```&````MQ```!$```"^$```!P```-`0```E````
MV!````0```#^$```!0````,1```/````"1$```\````9$0``!0```"D1```4
M````+Q$``!,```!$$0``%@```%@1```F````;Q$```@```"6$0``!0```)\1
M```"````I1$```4```"H$0``%@```*X1```&````Q1$```<```#,$0```P``
M`-01```)````V!$```<```#B$0``'0```.H1```<````"!(```<````E$@``
M(````"T2```P````3A(``!$```!_$@``#````)$2```%````GA(``!$```"D
M$@``!0```+82```-````O!(``!P```#*$@``&0```.<2```9`````1,``!X`
M```;$P``&P```#H3```3````5A,``!T```!J$P``!P```(@3```&````D!,`
M``,```"7$P``*@```)L3```K````QA,``!,```#R$P``#@````84```6````
M%10```@````L%```!P```#44```.````/10``!````!,%```$0```%T4```"
M````;Q0```<```!R%```,````'H4```K````JQ0``"D```#7%```;@````$5
M```7````<!4```$````L````*@````````!6````"P`````````8````````
M``````!$````*``````````4```````````````U````!0```$H````"````
M`P```#L```!(````$@````````!1````/@```#,````A````,@```$P````:
M`````````"\````@``````````````!7````%@```"L````3`````````$8`
M```?````!@```#D````````````````````*````0@```"<`````````````
M`"0````/````#````$T```!'````-@`````````Z````*0```$L````'````
M(P```````````````````%,```!`````'@```#0````<`````````!T`````
M````(@```!$``````````````#\``````````````!<```!#````5````$\`
M```E````%0```#````!.``````````X````\````$````%@`````````````
M`$4`````````#0`````````;````"0````@`````````4````!D`````````
M)@````0````Q````.````#T```!5````4@```"T``````````````$D```!!
M````-P`````````N````````````````)7,@36%I;G1E;F%N8V4@3W!E<F%T
M:6]N<R`M($-O;F9I<FUA=&EO;@`R-"!H;W5R<P!!32]030!!9&0@82!N97<@
M=7-E<CH`061D('!A:7(`061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!!9&1R97-S`$%D;6EN:7-T<F%T:6]N`$%L:6%S`$%V86EL86)L92!F
M:65L9',Z`$)I<G1H9&%Y`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#96QL(%!H
M;VYE`$-L;W-E(%=I;F1O=P!#;VUP86YY`$-O;F9I<FT@4&%S<W=O<F0`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I
M;'D`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``16UA
M:6P`16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2!,;V=I;@!%>&%M<&QE('9A
M;'5E<SH`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A>`!(
M96QP`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$EM<&]R=&5D(&9I
M96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&]G(&EN`$QO9R!O=70`34T`36%I
M;`!-871C:&EN9R!F:65L9',`365S<V%G90!-;VYT:&QY`$YA;64`3F]T97,`
M4&%S<W=O<F0`4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!E<F9O<FT@36%I;G1E
M;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA
M<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA
M;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A
M:7(`4F5S970`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O
M<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;F0@4')O8FQE;2!297!O<G0`4VMI<"!-86EN=&5N
M86YC90!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3=6-C97-S`%1I=&QE`%52
M3`!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@
M=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F1O($-H86YG97,`57-E
M<FYA;64`57-E<G,@:6X@=&AE('-Y<W1E;3H`5V%R;FEN9P!7965K;'D`5V5L
M8V]M92P@)7,`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`665A<FQY`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M
M92!T;R!A9&0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO
M="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B
M965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`6U!R;V)L96T@
M4F5P;W)T70!0<F]J96-T+4ED+59E<G-I;VXZ(&UK7TU+"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P,RTP-BTR-B`Q-3HQ."LP,C`P"DQA<W0M5')A;G-L871O<CH@4W1O:F%N
M(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SX*3&%N9W5A9V4M5&5A;3H@36%C
M961O;FEA;B`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@
M,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U
M.2TU"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*6"U'96YE<F%T
M;W(Z($M"86)E;"`Q+C`N,0H`)7,@OM_5X-#FV-@@U]`@WM3@UN/2T/K5("T@
MO][BTN#4T``R-"#GT.'0`$%-+U!-`+3>U-#4V"#=WM(@VM[@V.'=V-HZ`+3>
MU-#4V"#?T.``M-[4T-38(-K>X-CAW=C:`+3>U-#2T/K5XMX@W=`@VM[@V.'=
MV.;8(-4@WMW5TM[7W-[6U=W>+@"PU.#5X=``L-3<V-W8X>+@T.;8^-``06QI
M87,`M-[AXM#?W=@@W][;V/K0.@#`WM35W=35W0"^XMK0UM@@O^#>T=O5W"#`
MU=_>X.(`O-[1V-O5W0"WT.+2WN#8(-/>(-_@WM?>X-7FWN(`Q-C@W-``O][B
MTN#4V"#;WM?8W=K0`+S>U./;WN(@W=`@U]#4T.?0XM`@U]`@WM3@UN/2T/K5
M("5S(-W5(-S>UM4@U-`@T=C4U2#>XM+>X-7=`$1$`+3=U=+=W@#!XM#=U-#@
MU-7=(-C4U=WBV.+5X@"XU]'@V.C8`+[?V.$@W=`@W^#>T=O5W-[B`+W5(-_@
MV.'BT-_CTM#X(-38X-7:XMW>(-3>(&UA:6YT96YA;F-E+G!H<`#5+=_>Z.+0
M`+_@T-?5W2#@U=?CV^+0XBX`L^#5Z-K0`,'5VM[5(-_@V/C0TN/2T/K5`+_@
MV-S5X#H`O=7CX=_5Z-W0(-K>W=7:YMCXT"#AWB!,1$%0(.'5X-+5X-[B+@#$
MT-KA`+_>W-[H`+3>W-#HW=`@T-3@U>'0.@"TWMS0Z-7=(.+5V]7DWMT`2&]R
M9&4`N-S?WN#BV.#0W=X@W][;U3H@)7,`N-S?WN#BV.#0W=@@W][;V/K0.@"X
MU]O8X>+0^"#BU=S8(-?0(-_>W-[H`+O8X>+0^M7BWB#=T"#:WN#8X=W8YM@@
MU2#>W=72WM?<WM;5W=XN`+O>T]C@T/K5`+C7V]77`$U-`+_>Z.+0`+K>X-7A
MW][=U-C@T.?:V"#?WMO8^M``O][@T-K0`+S5X=7GW=X`N-S5`+?0T=7;U>C:
MV`"[WM?8W=K0`+O>U]C=VMCBU2#<WN#0(-30(-'8U-#B(-CAXM@N`+C7TN#H
MV"#>W]7@T.;8V"#7T"#>U.#6X]+0^M4`PM7;U>3>W0"RU2#<WMO8W-4@W=#2
MU=35XM4@T]X@W^#>T=O5W-[B+@"RU2#<WMO8W-4@W=#2U=35XM4@TM#HU2#:
MWN#8X=W8Y]K>(-C<U2#8(-O>U]C=VM``OM_8X2#=T"#?X-[1V]7<WN(`OM3A
MXN#0W=@@W]#@`%)E<V5T`+W0U]#4(-K>W2#>W^;8V.+5`,/;WM/0`+?0Y^/2
MT/@@WM_FV-@`N-?1U>#8(.'5W]#@T.+>X"#7T"#4T.+CW-[B.@"XU]'5X-@@
MY-[@W-#B(-?0(-30XN/<WN(Z`+C7T=7@V"#DWN#<T.(@U]`@TN#5W-7BWCH`
MN-?1U>#8(-32U2#>U-/>TM#@T.?:V"#?WMO8^M`N`+_@T.+8(-C7TM7HXM#X
M(-?0(-_@WM';U=S>X@"_X-7AVM[:W=@@WM3@UN/2T/K5`++=U>'CTM#ZU2#=
MT"#AW]7FV/C0V]W8(-?=T.;8`,/AW]7HW=X`O=#AV][2`%523`"]U2#<WM;5
MTB#4T"#AU2#:WMW5VN+8X-#<(.'>(%-13"#AU>#2U>#>XBX`O=4@W-[6U=(@
MU-`@T]X@W^#5TM74T-P@WM+>^"!7;W)D(-3>VN/<U=WB+@"^XMK0UM@@T]@@
MW^#>W-7=V.+5`+K>X-CAW=CGVMX@V-S5`+K>X-CAW=CFV"#2WB#AV.'BU=S>
MXCH`LMW8W-#=V-4`O=74U=O=W@"TWM'@U=3>^-35+"`E<P"PU.#5X=`@W=`@
MX-#1WN+0`,+5V]7DWMT@W=`@X-#1WN+0`+.S`+/>U-CHW=X`OM_8Z-7BU2#3
MWB#?X-[1V]7<WN(@W^#5U"#4T"#8X=_@T.+5XM4@V-?2U>CBT/@N`+W0TM74
MU>+5(-K>U2#:WN#8X=W8Y]K>(-C<U2#4T"#AU2#>XN'BX-#=V"X`O=#2U=35
MXM4@VM[5(-K>X-CAW=CGVMX@V-S5(-30(.'5(-3>U-#4U2X`LM#HV-[B(-#2
MXM[@V-?0YMC>W=7=(-_@WN+>VM[;(-W5(-_>U.#6X]+0(-O8X>+0^M4@VM[@
MV.'=V.;8+"#8V]@@XM#0(-S>UMW>X>(@U2#>W=72WM?<WM;5W=`@WM0@U.#C
MT]@@W^#8Y]C=V"X`6[C7TM7HXM#X(-?0(-_@WM';U=S>XET`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+VQT7TQ4+TQ#7TU%4U-!1T53````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,34Q-``@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O;'1?3%0O:&5L<"YX;6P`````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T
M,S0Q-#$@,#(Q-#4V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@
M:&]R9&4O;&]C86QE+VQT7TQ4+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@
M,C`Z,C(Z,30@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U
M;6UA<GDB('-T871E/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T
M:71L93X*(#QP87)A/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q
M=6EC:R!S=6UM87)Y(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T
M:6]N+B!&;W(@97AA;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@
M92UM86EL(&UE<W-A9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C
M;VUI;F<@979E;G1S(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@
M=&\M9&\*("!L:7-T+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E
M<G9I8V5S+"!A;F0@<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S
M('=I;&P@8V]N=&%I;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T
M:6]N<RP@<W5C:"!A<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L
M(&-R96%T:6YG(&$@;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*
M(#PO<&%R83X*(#QP87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A
M;"!P86=E(&%R92!C=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N
M+@H@($9O<B!E>&%M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T
M;R!I;F-L=61E(&]N('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN
M('=H:6-H(&]R9&5R('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y
M/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*
M("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H
M92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@
M:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E
M87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T
M:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O
M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E
M;F-E<SH@36%I;G1E;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@
M(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*
M("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I
M<FU?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E
M<F5N8V5S.B!-86EN=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET
M;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I
M<FT@86QL(&UA:6YT96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL
M(&-H96-K('1H:7,@8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E
M('!E<F9O<FUE9"!A=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A
M;F-E;"!O;B!L;V=I;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+VQT7TQ4+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,S,R,C0R(#$P-3$U-#,T,30Q
M(#`R,S(S-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````'0&```<````O#,``)L(``!<9P```````,B)```.````
MR8D```\```#8B0``"````.B)```,````\8D```0```#^B0``#`````.*```/
M````$(H```L````@B@``#@```"R*```%````.XH``"@```!!B@``"@```&J*
M```5````=8H``!(```"+B@``"P```)Z*```.````JHH```H```"YB@``#0``
M`,2*```.````THH``!$```#AB@``#0```/.*```,`````8L```T````.BP``
M!@```!R+```/````(XL``!@````SBP``#````$R+```.````68L```X```!H
MBP``"````'>+```N````@(L``!H```"OBP``,@```,J+```X````_8L``%0`
M```VC```40```(N,``!:````W8P``%<````XC0``-````)"-```*````Q8T`
M``4```#0C0``!@```-:-```1````W8T```@```#OC0``"0```/B-```)````
M`HX``"4````,C@``(````#*.```0````4XX```\```!DC@``"@```'2.```#
M````?XX```\```"#C@``%````)..```)````J(X```T```"RC@``$@```,".
M```/````TXX```H```#CC@``#P```.Z.```(````_HX``"0````'CP``%```
M`"R/```6````08\```@```!8CP``&0```&&/```'````>X\```P```"#CP``
M+````)"/```.````O8\```,```#,CP``"P```-"/```'````W(\```<```#D
MCP``!0```.R/```%````\H\```H```#XCP```P````.0```7````!Y````H`
M```?D```#P```"J0```.````.I```!@```!)D```(P```&*0```.````AI``
M`!0```"5D```%P```*J0```7````PI```!<```#:D```$P```/*0```/````
M!I$```X````6D0``'P```"61```'````19$```8```!-D0``"````%21```/
M````79$```8```!MD0``"@```'21```3````?Y$```L```"3D0``%0```)^1
M```5````M9$```<```#+D0``!0```-.1```5````V9$``!$```#OD0``#```
M``&2```[````#I(```D```!*D@``!P```%22```4````7)(```,```!QD@``
M!0```'62```0````>Y(```D```",D@``$P```):2```Y````JI(``!(```#D
MD@``)P```/>2```L````'Y,``"H```!,DP``)0```'>3```*````G9,```8`
M``"HDP``"0```*^3```'````N9,``"\```#!DP``-P```/&3```N````*90`
M`%4```!8E```+0```*Z4```M````W)0``"T````*E0``0````#B5```C````
M>94``",```"=E0``+0```,&5```S````[Y4``!4````CE@``&0```#F6```I
M````4Y8``"0```!]E@``$0```**6```*````M)8```P```"_E@``"@```,R6
M```0````UY8``!8```#HE@``%@```/^6```'````%I<```<````>EP``%```
M`":7```*````.Y<```@```!&EP``"````$^7```'````6)<```<```!@EP``
M!@```&B7```%````;Y<```<```!UEP``!@```'V7```(````A)<```X```"-
MEP``"@```)R7```$````IY<```<```"LEP``"0```+27```&````OI<``!$`
M``#%EP``!P```->7```6````WY<```0```#VEP``"````/N7```&````!)@`
M``T````+F```!@```!F8```>````()@``!$````_F```"````%&8```-````
M6I@```P```!HF```!P```'68```#````?9@```,```"!F```%P```(68```3
M````G9@```@```"QF```!````+J8```(````OY@```@```#(F```00```-&8
M```@````$YD```8````TF0``!@```#N9```5````0ID``!@```!8F0``(@``
M`'&9```N````E)D``!T```##F0``(0```.&9``!4`````YH``"D```!8F@``
M"@```(*:```'````C9H``!4```"5F@``#@```*N:```*````NIH```\```#%
MF@``#0```-6:```/````XYH```T```#SF@``"0````&;```4````"YL```8`
M```@FP``&````">;```=````0)L``!,```!>FP``%````'*;```$````AYL`
M``8```",FP``5````).;```$````Z)L```X```#MFP``!0```/R;```%````
M`IP``!L````(G```&@```"2<```1````/YP``!$```!1G```'````&.<```J
M````@)P``!````"KG```(0```+R<```%````WIP``!,```#DG```$@```/B<
M```*````"YT```\````6G0``$0```":=```3````.)T```P```!,G0``!@``
M`%F=```&````8)T``!<```!GG0``$0```'^=```(````D9T```4```":G0``
M#````*"=```0````K9T```4```"^G0``#0```,2=```&````TIT```<```#9
MG0``#0```.&=```'````[YT```L```#WG0``!P````.>```'````"YX```D`
M```3G@``"@```!V>```9````*)X```P```!"G@``$````$^>```%````8)X`
M`"4```!FG@``$@```(R>```3````GYX``"L```"SG@``.P```-^>```@````
M&Y\``#8````\GP``"````'.?```,````?)\```8```")GP``!````)"?```.
M````E9\```H```"DGP``#0```*^?```>````O9\``!L```#<GP``(0```/B?
M```>````&J```!D````YH```'@```%.@```;````<J```"8```".H```&P``
M`+6@```>````T:```!P```#PH```)@````VA```S````-*$``"8```!HH0``
M*P```(^A```X````NZ$``"\```#TH0``$@```"2B```I````-Z(``!(```!A
MH@``H@```'2B```6````%Z,``",````NHP``*````%*C```I````>Z,``"@`
M``"EHP``'P```,ZC```@````[J,``"4````/I```(0```#6D```<````5Z0`
M`"8```!TI```00```)ND```,````W:0```<```#JI```!P```/*D```&````
M^J0```T````!I0``$`````^E```2````(*4``!,````SI0``$@```$>E```'
M````6J4```0```!BI0``#````&>E```.````=*4```\```"#I0``$P```).E
M```-````IZ4``"@```"UI0```P```-ZE```-````XJ4```8```#PI0``$0``
M`/>E```7````":8``!L````AI@``#@```#VF```"````3*8```4```!/I@``
M$````%6F```$````9J8```T```!KI@``#@```'FF```#````B*8```X```",
MI@``"````)NF```/````I*8```\```"TI@``#0```,2F```0````TJ8```L`
M``#CI@``!@```.^F```,````]J8``!$````#IP``&0```!6G```+````+Z<`
M``T````[IP``(@```$FG```*````;*<``!@```!WIP``&0```)"G```6````
MJJ<```T```#!IP``!P```,^G```4````UZ<```L```#LIP``(@```/BG```O
M````&Z@```L```!+J```"0```%>H```9````8:@```L```![J```%P```(>H
M```7````GZ@```D```"WJ```%@```,&H```/````V*@``!8```#HJ```#@``
M`/^H```8````#JD```@````GJ0``#0```#"I```F````/JD``$,```!EJ0``
M"````*FI```2````LJD```@```#%J0``"P```,ZI```O````VJD```X````*
MJ@``!0```!FJ```&````'ZH```,````FJ@``!P```"JJ```$````,JH```H`
M```WJ@``"@```$*J```/````3:H``!````!=J@``%P```&ZJ```1````AJH`
M`!<```"8J@``"0```+"J```%````NJH```L```#`J@``"@```,RJ```"````
MUZH```4```#:J@``#0```."J```;````[JH``!<````*JP``"0```"*K```.
M````+*L```T````[JP``$@```$FK```X````7*L``"````"5JP``"````+:K
M```.````OZL``'L```#.JP``&````$JL```1````8ZP```<```!UK```!0``
M`'VL```9````@ZP```<```"=K```"````*6L```&````KJP```8```"UK```
M$````+RL```/````S:P``!````#=K```#P```.ZL```+````_JP```\````*
MK0``#````!JM```/````)ZT```<````WK0``!@```#^M```,````1JT``"@`
M``!3K0``#P```'RM```(````C*T```@```"5K0``$P```)ZM```>````LJT`
M`"$```#1K0``(````/.M```9````%*X``!<````NK@``)0```$:N```7````
M;*X```0```"$K@``&P```(FN```-````I:X```,```"SK@``"````+>N```*
M````P*X```P```#+K@``"P```-BN```$````Y*X``!,```#IK@``%````/VN
M```,````$J\```D````?KP``#@```"FO```+````.*\``!L```!$KP``!P``
M`&"O```'````:*\```H```!PKP``#0```'NO```)````B:\```0```"3KP``
M!0```)BO```#````GJ\``!@```"BKP``"@```+NO```$````QJ\``"8```#+
MKP``#@```/*O``!\`````;```!4```!^L```!0```)2P```'````FK````P`
M``"BL```"````*^P```*````N+````8```##L```"````,JP```"````T[``
M``8```#6L```!@```-VP```4````Y+````T```#YL```$`````>Q```;````
M&+$```0````TL0``"0```#FQ```0````0[$```D```!4L0``"0```%ZQ```%
M````:+$``!H```!NL0``"````(FQ```&````DK$``!D```"9L0``#@```+.Q
M```'````PK$```<```#*L0``!0```-*Q```)````V+$```H```#BL0```@``
M`.VQ```&````\+$```T```#WL0``"0````6R```&````#[(``!(````6L@``
M"0```"FR```'````,[(``!0````[L@``'0```%"R```&````;K(```H```!U
ML@``!````("R```)````A;(```@```"/L@``$0```)BR```)````JK(```8`
M``"TL@``#0```+NR```&````R;(```0```#0L@``.0```-6R```]````#[,`
M`#H```!-LP``'@```(BS```%````I[,```X```"MLP``!````+RS```&````
MP;,``"$```#(LP``%0```.JS```&`````+0```0````'M```$0````RT```&
M````'K0```H````EM```(@```#"T```$````4[0```4```!8M```'0```%ZT
M```$````?+0```P```"!M```"@```(ZT```(````F;0```D```"BM```!0``
M`*RT```Z````LK0``#````#MM```-0```!ZU```I````5+4``$<```!^M0``
M.````,:U```I````_[4``#\````IM@``+@```&FV```M````F+8``!\```#&
MM@``#P```.:V```2````]K8```L````)MP``)@```!6W```I````/+<``"0`
M``!FMP``)@```(NW```(````LK<```H```"[MP``"0```,:W```'````T+<`
M`"````#8MP``(````/FW```F````&K@```H```!!N```&0```$RX```I````
M9K@``!8```"0N```$@```*>X```'````NK@```H```#"N```#P```,VX```0
M````W;@``$````#NN```9@```"^Y```.````EKD```D```"EN0``"@```*^Y
M```2````NKD``!,```#-N0``#````.&Y```&````[KD```\```#UN0``$@``
M``6Z```0````&+H``!$````IN@``'````#NZ```C````6+H``&H```!\N@``
M#P```.>Z```%````][H``!````#]N@``"0````Z[```$````&+L```L````=
MNP``%````"F[```,````/KL```P```!+NP``#P```%B[```5````:+L``"D`
M``!^NP``*@```*B[```F````T[L``"<```#ZNP``*0```"*\```J````3+P`
M`!D```!WO```0@```)&\```1````U+P``!(```#FO```$P```/F\```4````
M#;T```\````BO0``%@```#*]```7````2;T``!````!AO0``$0```'*]```T
M````A+T``!,```"YO0``$@```,V]```U````X+T``!0````6O@``!P```"N^
M```,````,[X``"````!`O@``%````&&^```1````=KX``!<```"(O@``'```
M`*"^```3````O;X``!$```#1O@``&@```..^```>````_KX``!H````=OP``
M$0```#B_```4````2K\``!<```!?OP``%0```'>_```)````C;\``!D```"7
MOP``!````+&_```'````MK\```L```"^OP``$0```,J_```&````W+\```8`
M``#COP``!@```.J_```%````\;\```<```#WOP``!P```/^_```%````!\``
M`!8````-P```!@```"3````&````*\````0````RP```!````#?````'````
M/,````X```!$P```#````%/````,````8,````T```!MP```"@```'O````.
M````AL````4```"5P```*````)O````.````Q,````P```#3P```#P```.#`
M```*````\,````@```#[P```"0````3!```K````#L$```0````ZP0``"```
M`#_!```F````2,$``!(```!OP0``#P```(+!```&````DL$```H```"9P0``
M!P```*3!```(````K,$``"````"UP0``"0```-;!```,````X,$```T```#M
MP0``#@```/O!```6````"L(``!$````AP@``!@```#/"```#````.L(```8`
M```^P@``&0```$7"```'````7\(```0```!GP@``"P```&S"```+````>,(`
M``<```"$P@``!P```(S"```6````E,(```T```"KP@``#0```+G"```*````
MQ\(``!````#2P@``#P```./"```1````\\(``!<````%PP``"@```!W#```1
M````*,,```@````ZPP``!````$/#```/````2,,``#H```!8PP``!0```)/#
M```,````F<,``!X```"FPP``#@```,7#```0````U,,```L```#EPP``#```
M`/'#```)````_L,```<````(Q```"@```!#$```)````&\0```X````EQ```
M$````#3$```:````1<0```H```!@Q```"0```&O$```*````=<0```P```"`
MQ```#P```(W$```(````G<0```8```"FQ```!P```*W$```+````M<0``$<`
M``#!Q```#0````G%```)````%\4```0````AQ0```P```";%```3````*L4`
M`!,````^Q0``$P```%+%```*````9L4```(```!QQ0``!````'3%```E````
M><4```,```"?Q0``!0```*/%```J````J<4```H```#4Q0``!0```-_%```$
M````Y<4```H```#JQ0``#0```/7%```&`````\8```@````*Q@``"````!/&
M```$````',8```4````AQ@``:````"?&```)````D,8```P```":Q@``!0``
M`*?&```&````K<8``!L```"TQ@``+P```-#&```0`````,<```H````1QP``
M#P```!S'```*````+,<```D````WQP``$P```$''```;````5<<``!@```!Q
MQP``%P```(K'```.````HL<```,```"QQP``!P```+7'```(````O<<```<`
M``#&QP``"@```,['```+````V<<```<```#EQP``40```.W'```0````/\@`
M``P```!0R```#0```%W(```:````:\@``$H```"&R```!@```-'(```&````
MV,@```8```#?R```'P```.;(```&````!LD```D````-R0``&````!?)```7
M````,,D```8```!(R0``#0```$_)```B````7<D``%<```"`R0``$P```-C)
M```C````[,D``!,````0R@```@```"3*```+````)\H```@````SR@``#0``
M`#S*```*````2LH```<```!5R@``%````%W*```&````<LH```@```!YR@``
M#@```(+*```'````D<H```H```"9R@``"P```*3*```'````L,H```P```"X
MR@``#0```,7*```,````T\H```D```#@R@``"0```.K*```*````],H```<`
M``#_R@``"0````?+```'````$<L```H````9RP``&P```"3+```2````0,L`
M``H```!3RP``"0```%[+```0````:,L```<```!YRP``$@```('+```$````
ME,L```<```"9RP``!0```*'+```%````I\L```L```"MRP``%````+G+```1
M````SLL``!H```#@RP``%@```/O+```4````$LP``!<````GS```&````#_,
M```<````6,P``!D```!US```!P```(_,```%````E\P```T```"=S```#```
M`*O,```(````N,P``!<```#!S```"P```-G,```3````Y<P```0```#YS```
M"@```/[,```$````"<T```P````.S0``"0```!O-```%````)<T```<````K
MS0``!0```#/-```$````.<T```(````^S0``.````$'-```L````>LT``!(`
M``"GS0``*0```+K-```R````Y,T```H````7S@``+````"+.```N````3\X`
M`#,```!^S@``,P```++.```X````YLX```\````?SP``&````"_/```0````
M2,\``!,```!9SP``%````&W/```2````@L\``!0```"5SP``%0```*K/```M
M````P,\``"T```#NSP``,0```!S0```N````3M```"\```!]T```+````*W0
M``!B````VM```!,````]T0``"````%'1```(````6M$``"L```!CT0``(0``
M`(_1```:````L=$```D```#,T0``10```-;1``!!````'-(```0```!>T@``
M$P```&/2```4````=](```X```",T@``$P```)O2```8````K](```8```#(
MT@``"0```,_2```*````V=(```\```#DT@``$````/32```'````!=,```X`
M```-TP``!0```!S3```;````(M,```@````^TP``!@```$?3```4````3M,`
M`!$```!CTP``#@```'73```X````A-,```(```"]TP``!@```,#3```.````
MQ],```4```#6TP``!P```-S3```.````Y-,```8```#STP``!````/K3```I
M````_],``!<````IU```'P```$'4``!<````8=0``!0```"^U```'P```-/4
M```0````\]0```<````$U0``#@````S5```,````&]4```P````HU0``$P``
M`#75```*````2=4``!T```!4U0``&0```'+5```%````C-4``!$```"2U0``
M$0```*35```D````MM4``!4```#;U0``$@```/'5```.````!-8``!D````3
MU@``"````"W6```)````-M8```T```!`U@``"@```$[6```+````6=8```H`
M``!EU@``!P```'#6```(````>-8```4```"!U@``'P```(?6```&````I]8`
M`!````"NU@``"````+_6```-````R-8```@```#6U@``$@```-_6```L````
M\M8``!H````?UP``"0```#K7```*````1-<``!4```!/UP``!0```&77```4
M````:]<```0```"`UP``$````(77```&````EM<```<```"=UP``'@```*77
M```H````Q-<```H```#MUP``&@```/C7```4````$]@```0````HV```!```
M`"W8```+````,M@```4````^V```!@```$38```(````2]@```8```!4V```
M"@```%O8```;````9M@``#0```""V```-````+?8```@````[-@``"D````-
MV0``(````#?9``!!````6-D``!H```":V0``*````+79```I````WMD``"(`
M```(V@``!@```"O:```(````,MH```4````[V@``"````$':```9````2MH`
M`!D```!DV@``*@```'[:```C````J=H``"X```#-V@``-````/S:```(````
M,=L``!<````ZVP``"@```%+;```'````7=L``"$```!EVP``$````(?;```.
M````F-L```L```"GVP``!P```+/;```3````N]L```@```#/VP``"P```-C;
M```*````Y-L``!0```#OVP``,@````3<```+````-]P```4```!#W```!0``
M`$G<```7````3]P```\```!GW```!````'?<```*````?-P```D```"'W```
M"P```)'<```.````G=P```4```"LW```!````++<```-````M]P``#(```#%
MW```10```/C<```7````/MT``!X```!6W0``%````'7=```%````BMT``!0`
M``"0W0``!P```*7=```.````K=T``"H```"\W0``!@```.?=```,````[MT`
M``T```#[W0``$0````G>```+````&]X``#8````GW@``"@```%[>```B````
M:=X```L```",W@``#P```)C>```R````J-X```4```#;W@``#@```.'>```3
M````\-X```<````$WP``$0````S?```'````'M\``!0````FWP``&````#O?
M```'````5-\```4```!<WP``#````&+?```,````;]\``!(```!\WP``!```
M`(_?```'````E-\```H```"<WP``"P```*??```,````L]\```X```#`WP``
M#@```,_?```%````WM\```4```#DWP``+@```.K?```F````&>```",```!`
MX````P```&3@```2````:.````8```![X```'@```(+@```8````H>```"4`
M``"ZX```#0```.#@```)````[N````,```#XX```!P```/S@```*````!.$`
M``(````/X0``#````!+A```5````'^$```L````UX0``&0```$'A```@````
M6^$``!(```!\X0``!0```(_A```*````E>$``!4```"@X0``$@```+;A```,
M````R>$```0```#6X0``!P```-OA```,````X^$``%(```#PX0``%P```$/B
M```'````6^(```8```!CX@``#@```&KB```,````>>(```T```"&X@``%0``
M`)3B```2````JN(```\```"]X@``%````,WB```;````XN(``!````#^X@``
M:0````_C```:````>>,``!<```"4XP``)P```*SC```:````U.,``!<```#O
MXP``&P````?D```9````(^0``!\````]Y```$P```%WD```(````<>0```<`
M``!ZY```"````(+D```)````B^0``!4```"5Y```#0```*OD```3````N>0`
M``,```#-Y```1@```-'D```_````&.4``#<```!8Y0``5P```)#E```?````
MZ.4``"\````(Y@``"@```#CF```(````0^8```T```!,Y@``+0```%KF```$
M````B.8``$\```"-Y@``)0```-WF```<`````^<```L````@YP``'P```"SG
M```=````3.<``"4```!JYP``(````)#G```D````L><``"````#6YP``"P``
M`/?G```'`````^@```T````+Z```#````!GH```&````)N@``#D````MZ```
M#````&?H```'````=.@```D```!\Z```$P```(;H```)````FN@```0```"D
MZ```$````*GH```(````NN@```@```##Z```"P```,SH```,````V.@``!H`
M``#EZ```#P````#I```'````$.D```T````8Z0``%````";I```.````.^D`
M``P```!*Z0``&P```%?I```L````<^D``!,```"@Z0``'````+3I```H````
MT>D```8```#ZZ0``!P````'J```3````">H```4````=Z@``!````"/J```7
M````*.H```H```!`Z@``#````$OJ```)````6.H```8```!BZ@``"0```&GJ
M```(````<^H```D```!\Z@``"@```(;J```1````D>H```8```"CZ@``#@``
M`*KJ```.````N>H```T```#(Z@``"P```-;J```=````XNH```L`````ZP``
M`@````SK```'````#^L```8````7ZP``"0```![K```'````*.L``#L````P
MZP``*````&SK```5````E>L```4```"KZP``!P```+'K```(````N>L```<`
M``#"ZP``!0```,KK```'````T.L```X```#8ZP``"0```.?K```&````\>L`
M``@```#XZP``"P````'L```'````#>P```@````5[```!P```![L```6````
M)NP```D````][```!@```$?L```+````3NP``!P```!:[```%````'?L```'
M````C.P```@```"4[```"````)WL```%````INP``!````"L[```$````+WL
M```&````SNP``!D```#5[```"@```._L```<````^NP```<````7[0``!0``
M`!_M```0````)>T``!0````V[0``"P```$OM```-````5^T``!<```!E[0``
M!````'WM```)````@NT```H```",[0``!P```)?M```"````G^T```X```"B
M[0``"````+'M```?````NNT``",```#:[0``.````/[M```Q````-^X``"<`
M``!I[@``9````)'N```4````]NX``%4````+[P``.````&'O``!*````FN\`
M`%L```#E[P``*````$'P```X````:O```"@```"C\```+````,SP```G````
M^?```!L````A\0``/@```#WQ``"I`0``?/$``",````F\P``%P```$KS``!(
M````8O,``(4```"K\P``,````#'T``!!````8O0``%L```"D]```20````#U
M```=````2O4``!@```!H]0``(0```('U```?````H_4``"L```##]0``(0``
M`._U```=````$?8``!$````O]@``,P```$'V```E````=?8``"<```";]@``
M'P```,/V```P````X_8``&D````4]P``/0```'[W``!E````O/<``$T````B
M^```+P```'#X```N````H/@``#````#/^```5`````#Y``!:````5?D``$@`
M``"P^0``2@```/GY```R````1/H``"\```!W^@``+````*?Z```M````U/H`
M`'$````"^P``;P```'3[``"S````Y/L``!<```"8_```)0```+#\```R````
MUOP``"D````)_0``/@```#/]```B````<OT``%(```"5_0``)0```.C]```+
M````#OX``+$````:_@``10```,S^```A````$O\``#`````T_P``)0```&7_
M```<````B_\``#$```"H_P``!P```-K_```'````XO\```0```#J_P``#0``
M`.__```+````_?\```X````)``$`"P```!@``0`%````)``!`!`````J``$`
M`@```#L``0!9````/@`!``4```"8``$`$@```)X``0`$````L0`!``<```"V
M``$`"````+X``0`%````QP`!``,```#-``$`$````-$``0`,````X@`!`!,`
M``#O``$`#0````,!`0`"````$0$!``<````4`0$`!@```!P!`0`4````(P$!
M``P````X`0$`&````$4!`0`&````7@$!`!(```!E`0$`#````'@!`0`#````
MA0$!`"H```")`0$`!````+0!`0`&````N0$!``<```#``0$`'P```,@!`0`U
M````Z`$!`"X````>`@$`+P```$T"`0`7````?0(!`"````"5`@$`&P```+8"
M`0`8````T@(!`"0```#K`@$`'P```!`#`0`:````,`,!`"````!+`P$`&@``
M`&P#`0`R````AP,!`"\```"Z`P$`*P```.H#`0`?````%@0!`",````V!`$`
M'P```%H$`0`:````>@0!`"4```"5!`$`)@```+L$`0`E````X@0!`"0````(
M!0$`&````"T%`0`=````1@4!`"0```!D!0$`&````(D%`0`B````H@4!`"4`
M``#%!0$`/````.L%`0`?````*`8!`",```!(!@$`'P```&P&`0`@````C`8!
M`!H```"M!@$`&````,@&`0`F````X08!`!X````(!P$`*0```"<'`0`>````
M40<!``D```!P!P$`#````'H'`0`7````AP<!`"\```"?!P$`)````,\'`0`'
M````]`<!``\```#\!P$`%`````P(`0`.````(0@!``T````P"`$`)````#X(
M`0`%````8P@!``<```!I"`$`(@```'$(`0`E````E`@!`!T```"Z"`$`&@``
M`-@(`0`'````\P@!`,<```#["`$`"P```,,)`0`5````SPD!``8```#E"0$`
M"0```.P)`0`+````]@D!`!<````""@$`!@```!H*`0`S````(0H!`!,```!5
M"@$`$P```&D*`0`'````?0H!``\```"%"@$`!P```)4*`0`R````G0H!`"$`
M``#0"@$`$P```/(*`0`,````!@L!`!$````3"P$`,@```"4+`0`(````6`L!
M``D```!A"P$`"@```&L+`0`4````=@L!``H```"+"P$`'0```)8+`0`(````
MM`L!`!\```"]"P$`"````-T+`0`:````Y@L!``8````!#`$`%0````@,`0`'
M````'@P!``@````F#`$`"0```"\,`0`_````.0P!``<```!Y#`$`#P```($,
M`0`.````D0P!`!````"@#`$`"0```+$,`0`)````NPP!``@```#%#`$`$P``
M`,X,`0`'````X@P!`!D```#J#`$`"@````0-`0`7````#PT!`!0````G#0$`
M"@```#P-`0`,````1PT!`!<```!4#0$`!````&P-`0`J````<0T!`!$```"<
M#0$`!P```*X-`0`"````M@T!`!````"Y#0$`&````,H-`0`+````XPT!``,`
M``#O#0$`"````/,-`0`&````_`T!``<````##@$`#0````L.`0`+````&0X!
M`!0````E#@$`%0```#H.`0`.````4`X!`"\```!?#@$`(````(\.`0`<````
ML`X!``P```#-#@$`,0```-H.`0`%````#`\!`!(````2#P$`/P```"4/`0`2
M````90\!``H```!X#P$`!@```(,/`0`$````B@\!`!,```"/#P$`!0```*,/
M`0`&````J0\!``8```"P#P$`!````+</`0`,````O`\!``H```#)#P$`!0``
M`-0/`0`8````V@\!`!D```#S#P$`'P````T0`0`=````+1`!`!$```!+$`$`
M`@```%T0`0`$````8!`!``H```!E$`$`!@```'`0`0`%````=Q`!``,```!]
M$`$`#````($0`0!%````CA`!`!H```#4$`$`-0```.\0`0`H````)1$!`%,`
M``!.$0$`&0```*(1`0!R````O!$!`"`````O$@$`-0```%`2`0!%````AA(!
M`#````#,$@$`*````/T2`0`I````)A,!`"8```!0$P$`)0```'<3`0`H````
MG1,!`"@```#&$P$`(@```.\3`0`P````$A0!`!(```!#%`$`$P```%84`0`0
M````:A0!`'D```![%`$`"0```/44`0!S````_Q0!`'P```!S%0$`*P```/`5
M`0`7````'!8!`!8````T%@$`#P```$L6`0`?````6Q8!`!\```![%@$`'```
M`)L6`0!1````N!8!`!0````*%P$`"@```!\7`0`%````*A<!``8````P%P$`
M"````#<7`0`%````0!<!`!(```!&%P$`$````%D7`0`3````:A<!`!T```!^
M%P$`#P```)P7`0`/````K!<!``0```"\%P$`"0```,$7`0`+````RQ<!``<`
M``#7%P$`!0```-\7`0`4````Y1<!``<```#Z%P$`"`````(8`0`/````"Q@!
M``@````;&`$`#````"08`0`/````,1@!``8```!!&`$`%````$@8`0`&````
M71@!``P```!D&`$`"````'$8`0`$````>A@!``H```!_&`$`!P```(H8`0`$
M````DA@!`!D```"7&`$``@```+$8`0`)````M!@!``8```"^&`$`!@```,48
M`0`G````S!@!``0```#T&`$`#P```/D8`0`3````"1D!``<````=&0$`!P``
M`"49`0`&````+1D!``8````T&0$`$````#L9`0`2````3!D!``8```!?&0$`
M"0```&89`0`B````<!D!``<```"3&0$`!P```)L9`0`+````HQD!``4```"O
M&0$``@```+49`0`+````N!D!`%<!``#$&0$`$@```!P;`0`.````+QL!``L`
M```^&P$`"````$H;`0`!````4QL!``L```!5&P$`$0```&$;`0`,````<QL!
M``T```"`&P$`!0```(X;`0`I````E!L!``\```"^&P$`#````,X;`0`2````
MVQL!``@```#N&P$`$0```/<;`0`*````"1P!``P````4'`$`$P```"$<`0`1
M````-1P!``X```!''`$`$0```%8<`0`0````:!P!``8```!Y'`$`#@```(`<
M`0`5````CQP!`!$```"E'`$`$P```+<<`0`3````RQP!``L```#?'`$`+```
M`.L<`0`2````&!T!`#T````K'0$`20```&D=`0!E````LQT!`&8````9'@$`
M:````(`>`0!I````Z1X!`$````!3'P$`"@```)0?`0`%````GQ\!``8```"E
M'P$`$@```*P?`0`'````OQ\!`!$```#''P$`$P```-D?`0`K````[1\!`"@`
M```9(`$`"P```$(@`0`3````3B`!``@```!B(`$`!P```&L@`0`/````<R`!
M`!````"#(`$`$````)0@`0`3````I2`!`!4```"Y(`$`&@```,\@`0`0````
MZB`!`!8```#[(`$`#````!(A`0`M````'R$!`!H```!-(0$`'P```&@A`0`1
M````B"$!`!P```":(0$`!P```+<A`0`'````OR$!`#D```#'(0$`"`````$B
M`0`(````"B(!``P````3(@$`"````"`B`0`'````*2(!``@````Q(@$`"```
M`#HB`0`+````0R(!``4```!/(@$`&@```%4B`0`,````<"(!``P```!](@$`
M%````(HB`0`4````GR(!`"$```"T(@$`#@```-8B`0`?````Y2(!`!T````%
M(P$`(@```",C`0`>````1B,!`!4```!E(P$`%````'LC`0`.````D",!`!L`
M``"?(P$`!@```+LC`0`&````PB,!``<```#)(P$`&0```-$C`0`)````ZR,!
M``H```#U(P$`$@`````D`0`'````$R0!`!4````;)`$`%P```#$D`0`+````
M220!``@```!5)`$`%P```%XD`0`3````=B0!`!D```"*)`$`,P```*0D`0`)
M````V"0!``@```#B)`$`%0```.LD`0`%`````24!``4````')0$`'0````TE
M`0`+````*R4!`"`````W)0$`+@```%@E`0`5````AR4!`"@```"=)0$`*@``
M`,8E`0`K````\24!`"L````=)@$`"0```$DF`0`)````4R8!``H```!=)@$`
M"````&@F`0`O````<28!`"P```"A)@$`+@```,XF`0!0````_28!`"T```!.
M)P$`+0```'PG`0`M````JB<!`#\```#8)P$`*0```!@H`0`K````0B@!`"T`
M``!N*`$`,P```)PH`0`4````T"@!`!@```#E*`$`*@```/XH`0`G````*2D!
M``X```!1*0$`#0```&`I`0`1````;BD!``4```"`*0$`"P```(8I`0`A````
MDBD!`"8```"T*0$`!P```-LI`0`)````XRD!`!8```#M*0$`"@````0J`0`*
M````#RH!``X````:*@$`"P```"DJ`0`'````-2H!``<````]*@$`!P```$4J
M`0`(````32H!``<```!6*@$`"P```%XJ`0`0````:BH!``L```![*@$`"@``
M`(<J`0`(````DBH!``<```";*@$`!P```*,J`0`0````JRH!``<```"\*@$`
M%@```,0J`0`%````VRH!``@```#A*@$`"````.HJ`0`*````\RH!``D```#^
M*@$`(`````@K`0`5````*2L!``D````_*P$`$0```$DK`0`.````6RL!``D`
M``!J*P$``P```'0K`0`#````>"L!`!<```!\*P$`%````)0K`0`+````J2L!
M``0```"U*P$`"````+HK`0`)````PRL!`$\```#-*P$`*@```!TL`0`&````
M2"P!``@```!/+`$`'````%@L`0`<````=2P!`"$```"2+`$`*````+0L`0`?
M````W2P!`"D```#]+`$`6````"<M`0`L````@"T!``H```"M+0$`"P```+@M
M`0`+````Q"T!``T```#0+0$`$0```-XM`0`0````\"T!``X````!+@$`$```
M`!`N`0`2````(2X!`!,````T+@$`$P```$@N`0`&````7"X!`!P```!C+@$`
M'@```(`N`0`3````GRX!`!(```"S+@$`!0```,8N`0`(````S"X!`&(```#5
M+@$`"````#@O`0`6````02\!``0```!8+P$`!@```%TO`0`<````9"\!`!L`
M``"!+P$`%@```)TO`0`;````M"\!`"$```#0+P$`)````/(O`0`+````%S`!
M``\````C,`$`!@```#,P`0`8````.C`!`!T```!3,`$`&P```'$P`0`;````
MC3`!``4```"I,`$`$P```*\P`0`.````PS`!``D```#2,`$`"0```-PP`0`6
M````YC`!`!L```#],`$`"0```!DQ`0`&````(S$!`!(````J,0$`%````#TQ
M`0`+````4C$!`!4```!>,0$`"````'0Q`0`'````?3$!`!````"%,0$`"@``
M`)8Q`0`.````H3$!``<```"P,0$`"0```+@Q`0`,````PC$!``<```#/,0$`
M%````-<Q`0`/````[#$!`!4```#\,0$`!@```!(R`0`<````&3(!`!4````V
M,@$`%@```$PR`0`Q````8S(!`#X```"5,@$`)P```-0R`0`R````_#(!``4`
M```O,P$`"@```#4S`0`.````0#,!``D```!/,P$`%0```%DS`0`*````;S,!
M`!8```!Z,P$`'@```)$S`0`?````L#,!`"$```#0,P$`(@```/(S`0`=````
M%30!`"@````S-`$`'P```%PT`0`I````?#0!`!\```"F-`$`(@```,8T`0`>
M````Z30!`"H````(-0$`*P```#,U`0`C````7S4!`"D```"#-0$`,````*TU
M`0`O````WC4!`!8````.-@$`+@```"4V`0`5````5#8!`+<```!J-@$`$@``
M`"(W`0`B````-3<!`"<```!8-P$`)P```(`W`0`E````J#<!`!P```#.-P$`
M(````.LW`0`O````##@!`"`````\.`$`(````%TX`0`L````?C@!`$<```"K
M.`$`#P```/,X`0`(`````SD!``8````,.0$`!P```!,Y`0`/````&SD!`!0`
M```K.0$`%````$`Y`0`0````53D!`!L```!F.0$`"````((Y`0`$````BSD!
M`!$```"0.0$`$0```*(Y`0`6````M#D!`!0```#+.0$`$@```.`Y`0`S````
M\SD!``@````G.@$`%````#`Z`0`&````13H!`!$```!,.@$`%P```%XZ`0`?
M````=CH!`!(```"6.@$``@```*DZ`0`'````K#H!`!<```"T.@$`!````,PZ
M`0`%````T3H!`!(```#7.@$`!0```.HZ`0`2````\#H!``<````#.P$`%0``
M``L[`0`5````(3L!`!(````W.P$`%````$H[`0`+````7SL!``@```!K.P$`
M#@```'0[`0`.````@SL!`!D```"2.P$`#0```*P[`0`1````NCL!`"H```#,
M.P$`#P```/<[`0`:````!SP!`!0````B/`$`$P```#<\`0`1````2SP!``8`
M``!=/`$`$P```&0\`0`)````>#P!`"X```""/`$`+0```+$\`0`(````WSP!
M``D```#H/`$`'0```/(\`0`+````$#T!`!H````</0$`&@```#<]`0`)````
M4CT!`!H```!</0$`%0```'<]`0`5````C3T!`!,```"C/0$`'````+<]`0`(
M````U#T!``@```#=/0$`*@```.8]`0`B````$3X!``@````T/@$`%````#T^
M`0`*````4CX!``T```!=/@$`-````&L^`0`9````H#X!``<```"Z/@$`$0``
M`,(^`0`#````U#X!``D```#8/@$`!@```.(^`0`7````Z3X!``\````!/P$`
M$````!$_`0`0````(C\!`!4````S/P$`$@```$D_`0`5````7#\!``<```!R
M/P$`!P```'H_`0`*````@C\!``P```"-/P$``@```)H_`0`*````G3\!`!$`
M``"H/P$`'P```+H_`0`A````VC\!``H```#\/P$`#@````=``0`3````%D`!
M`!L````J0`$`.P```$9``0`F````@D`!``X```"I0`$`$P```+A``0!R````
MS$`!`!D````_00$`$@```%E!`0`(````;$$!``8```!U00$`#@```'Q!`0`&
M````BT$!``@```"200$`!P```)M!`0`&````HT$!``X```"J00$`#0```+E!
M`0`0````QT$!``T```#800$`&P```.9!`0`.`````D(!``H````10@$`"P``
M`!Q"`0`'````*$(!``H````P0@$`#P```#M"`0`\````2T(!``X```"(0@$`
M"@```)="`0`-````HD(!`!P```"P0@$`'0```,U"`0`H````ZT(!`"<````4
M0P$`'0```#Q#`0`<````6D,!`"(```!W0P$`&0```)I#`0`'````M$,!`!H`
M``"\0P$`#````-=#`0`&````Y$,!``<```#K0P$`"@```/-#`0`,````_D,!
M`!,````+1`$`!@```!]$`0`9````)D0!`!P```!`1`$`#P```%U$`0`1````
M;40!`!(```!_1`$`#P```))$`0`B````HD0!``<```#%1`$`!P```,U$`0`,
M````U40!`!(```#B1`$`%P```/5$`0`+````#44!``H````910$`!0```"1%
M`0`9````*D4!``T```!$10$`!P```%)%`0`I````6D4!`!(```"$10$`AP``
M`)=%`0`:````'T8!``8````Z1@$`!0```$%&`0`,````1T8!``8```!41@$`
M"````%M&`0`*````9$8!``P```!O1@$`!0```'Q&`0`)````@D8!``H```",
M1@$`%@```)=&`0`2````KD8!`!8```#!1@$`(````-A&`0`#````^48!``0`
M``#]1@$`$`````)'`0`(````$T<!``T````<1P$`!P```"I'`0`U````,D<!
M``D```!H1P$`!P```')'`0`7````>D<!`!(```"21P$`!P```*5'`0`)````
MK4<!``0```"W1P$`"P```+Q'`0`&````R$<!``8```#/1P$`!P```-9'`0`.
M````WD<!``L```#M1P$`"````/E'`0`6`````D@!``L````92`$`!P```"5(
M`0`6````+4@!`"$```!$2`$`!@```&9(`0`)````;4@!``4```!W2`$`"0``
M`'U(`0`'````AT@!``T```"/2`$`#````)U(`0`'````JD@!``X```"R2`$`
M!@```,%(`0`$````R$@!`#,```#-2`$`-P````%)`0`V````.4D!`"````!P
M20$`!@```)%)`0`/````F$D!``4```"H20$`"````*Y)`0`>````MTD!`!8`
M``#620$`!P```.U)`0`'````]4D!`"````#]20$`#0```!Y*`0`)````+$H!
M`!L````V2@$`!@```%)*`0`)````64H!`"0```!C2@$`"````(A*`0`,````
MD4H!``X```">2@$`"````*U*`0`)````MDH!``@```#`2@$`,P```,E*`0`O
M````_4H!`#(````M2P$`)@```&!+`0!&````ATL!`#H```#.2P$`*@````E,
M`0`R````-$P!`#(```!G3`$`,P```)I,`0`E````SDP!`!(```#T3`$`$P``
M``=-`0`.````&TT!`"`````J30$`'P```$M-`0`?````:TT!`!T```"+30$`
M"0```*E-`0`+````LTT!``H```"_30$`"````,I-`0`G````TTT!`"@```#[
M30$`,````"1.`0`*````54X!`!D```!@3@$`(P```'I.`0`.````GDX!`!<`
M``"M3@$`"0```,5.`0`/````STX!`!4```#?3@$`$P```/5.`0`H````"4\!
M`&D````R3P$`%0```)Q/`0`0````LD\!`!$```##3P$`&0```-5/`0`:````
M[T\!`!4````*4`$`!P```"!0`0`5````*%`!`!(````^4`$`#@```%%0`0`8
M````8%`!`!H```!Y4`$`,0```)10`0"C````QE`!`!4```!J40$`!@```(!1
M`0`7````AU$!``H```"?40$`"P```*I1`0`+````ME$!`!L```#"40$`$P``
M`-Y1`0`/````\E$!``\````"4@$`&0```!)2`0`O````+%(!`"X```!<4@$`
M+````(M2`0`K````N%(!`",```#D4@$`(@````A3`0`;````*U,!`$$```!'
M4P$`$@```(E3`0`6````G%,!`!D```"S4P$`&````,U3`0`/````YE,!`!<`
M``#V4P$`&P````Y4`0`4````*E0!`!@````_5`$`+P```%A4`0`=````B%0!
M`!D```"F5`$`,0```,!4`0`2````\E0!``@````%50$`#P````Y5`0`D````
M'E4!`!0```!#50$`#P```%A5`0`;````:%4!`!0```"$50$`&@```)E5`0`5
M````M%4!`!T```#*50$`(P```.A5`0`>````#%8!`!<````K5@$`%````$-6
M`0`=````6%8!`!P```!V5@$`"P```)-6`0`:````GU8!``8```"Z5@$`!@``
M`,%6`0`)````R%8!`!,```#25@$`"````.96`0`)````[U8!``@```#Y5@$`
M!P````)7`0`'````"E<!``8````25P$`"````!E7`0`7````(E<!``<````Z
M5P$`"0```$)7`0`%````3%<!``@```!25P$`!@```%M7`0`/````8E<!``X`
M``!R5P$`$````(%7`0`1````DE<!``L```"D5P$`%````+!7`0`&````Q5<!
M`"P```#,5P$`$P```/E7`0`-````#5@!``\````;6`$`"P```"M8`0`+````
M-U@!`!(```!#6`$`)P```%98`0`&````?E@!``D```"%6`$`)P```(]8`0`2
M````MU@!`!4```#*6`$`"````.!8`0`)````Z5@!``L```#S6`$`!0```/]8
M`0`E````!5D!``H````K60$`%````#99`0`+````2UD!`!P```!760$`*0``
M`'19`0`8````GED!``<```"W60$`!0```+]9`0`*````Q5D!`#````#060$`
M!P````%:`0`'````"5H!`!$````16@$`$P```"-:`0`'````-UH!``@````_
M6@$`%@```$A:`0`.````7UH!``X```!N6@$`$````'U:`0`5````CEH!`!<`
M``"D6@$`#P```+Q:`0`=````S%H!`!$```#J6@$`$@```/Q:`0`)````#UL!
M``<````96P$`"@```"%;`0`Y````+%L!``@```!F6P$`%````&];`0`O````
MA%L!`!L```"T6P$`%0```-!;`0`6````YEL!`!8```#]6P$`%0```!1<`0`0
M````*EP!`!@````[7`$`%0```%1<`0`>````:EP!`!P```")7`$`'0```*9<
M`0`*````Q%P!``<```#/7`$`"0```-=<`0`1````X5P!`!````#S7`$`!0``
M``1=`0`+````"ET!``H````670$`$P```"%=`0!4````-5T!`!4```"*70$`
M#0```*!=`0`%````KET!``@```"T70$`&@```+U=`0`:````V%T!`!H```#S
M70$`#0````Y>`0`"````'%X!``0````?7@$`*````"1>`0`#````35X!``4`
M``!17@$`"@```%=>`0`,````8EX!``8```!O7@$`!@```'9>`0`.````?5X!
M`!,```",7@$`!P```*!>`0`)````J%X!``@```"R7@$`!0```+M>`0`%````
MP5X!`%<```#'7@$`#P```!]?`0`2````+U\!``4```!"7P$`!P```$A?`0`C
M````4%\!`#$```!T7P$`#0```*9?`0`)````M%\!``\```"^7P$`"P```,Y?
M`0`*````VE\!`!0```#E7P$`*P```/I?`0`:````)F`!`!D```!!8`$`$```
M`%M@`0`&````;&`!``8```!S8`$`"````'I@`0`&````@V`!``X```"*8`$`
M#@```)E@`0`&````J&`!`$P```"O8`$`$@```/Q@`0`-````#V$!``L````=
M80$`%@```"EA`0!$````0&$!``<```"%80$`!0```(UA`0`'````DV$!`"(`
M``";80$`"````+YA`0`*````QV$!`!D```#280$`&@```.QA`0`)````!V(!
M``4````18@$`(P```!=B`0!)````.V(!`!````"%8@$`)P```)9B`0`0````
MOF(!``4```#/8@$`#@```-5B`0`)````Y&(!``\```#N8@$`"@```/YB`0`'
M````"6,!`!,````18P$`!P```"5C`0`)````+6,!`!$````W8P$`"@```$EC
M`0`*````5&,!``T```!?8P$`!P```&UC`0`1````=6,!`!0```"'8P$`$@``
M`)QC`0`/````KV,!`!````"_8P$`$0```-!C`0`1````XF,!`!````#T8P$`
M$@````5D`0`*````&&0!`"8````C9`$`$P```$ID`0`-````7F0!``T```!L
M9`$`%P```'ID`0`)````DF0!``T```"<9`$`!@```*ID`0`(````L60!``8`
M``"Z9`$`!P```,%D`0`+````R60!`!(```#59`$`%0```.AD`0`A````_F0!
M`!\````@90$`&````$!E`0`6````664!`!P```!P90$`'@```(UE`0`:````
MK&4!``<```#'90$`!P```,]E`0`2````UV4!`!````#J90$`#@```/ME`0`C
M````"F8!`!$````N9@$`%@```$!F`0`)````5V8!``\```!A9@$`"````'%F
M`0`3````>F8!``D```".9@$`!P```)AF`0`(````H&8!``8```"I9@$`!0``
M`+!F`0`"````MF8!`"4```"Y9@$`(@```-]F`0`7`````F<!`"`````:9P$`
M-````#MG`0`.````<&<!`",```!_9P$`*````*-G`0`M````S&<!`"T```#Z
M9P$`,@```"AH`0`4````6V@!`!(```!P:`$`$@```(-H`0`4````EF@!`!(`
M``"K:`$`$````+YH`0`2````SV@!`!P```#B:`$`+0```/]H`0`M````+6D!
M`#$```!;:0$`+@```(UI`0`O````O&D!`"P```#L:0$`8````!EJ`0`@````
M>FH!`!(```";:@$`$0```*YJ`0`D````P&H!`#$```#E:@$`&0```!=K`0`-
M````,6L!`$`````_:P$`0````(!K`0`*````P6L!``0```#,:P$`%0```-%K
M`0`.````YVL!`!(```#V:P$`&`````EL`0`)````(FP!``@````L;`$`#```
M`#5L`0`,````0FP!``T```!/;`$`"@```%UL`0`-````:&P!``<```!V;`$`
M(0```'YL`0`)````H&P!``<```"J;`$`$0```+)L`0`2````Q&P!`!````#7
M;`$`,P```.AL`0`"````'&T!``@````?;0$`$@```"AM`0`+````.VT!``8`
M``!';0$`$````$YM`0`&````7VT!``8```!F;0$`+P```&UM`0`8````G6T!
M`"@```"V;0$`5@```-]M`0`7````-FX!`",```!.;@$`$@```')N`0`*````
MA6X!``T```"0;@$`$P```)YN`0`,````LFX!``D```"_;@$`#````,EN`0`?
M````UFX!`!<```#V;@$`!`````YO`0`0````$V\!`!$````D;P$`)0```#9O
M`0`8````7&\!`!D```!U;P$`$P```(]O`0`A````HV\!``D```#%;P$`!P``
M`,]O`0`1````UV\!``D```#I;P$`"@```/-O`0`(````_F\!``T````'<`$`
M"@```!5P`0`%````('`!`!X````F<`$`!@```$5P`0`5````3'`!``H```!B
M<`$`$0```&UP`0`+````?W`!`!<```"+<`$`+````*-P`0`;````T'`!``P`
M``#L<`$`#0```/EP`0`;````!W$!``8````C<0$`*P```"IQ`0`&````5G$!
M`!T```!=<0$`!@```'MQ`0`)````@G$!`!\```",<0$`-0```*QQ`0`&````
MXG$!`!8```#I<0$`%`````!R`0`$````%7(!``<````:<@$`"0```")R`0`)
M````+'(!``H````V<@$`"0```$%R`0`)````2W(!``D```!5<@$`&P```%]R
M`0`U````>W(!`#X```"Q<@$`&0```/!R`0`G````"G,!`!P````R<P$`/```
M`$]S`0`8````C',!`!0```"E<P$`+@```+IS`0`F````Z7,!``<````0=`$`
M"0```!AT`0`*````(G0!``L````M=`$`%0```#ET`0`1````3W0!`"D```!A
M=`$`(````(MT`0`N````K'0!`#,```#;=`$`!@````]U`0`5````%G4!``@`
M```L=0$`"````#5U`0`D````/G4!`!0```!C=0$`%@```'AU`0`0````CW4!
M``@```"@=0$`$P```*EU`0`)````O74!`!````#'=0$`#P```-AU`0`8````
MZ'4!`"H````!=@$`#````"QV`0`'````.78!``<```!!=@$`'@```$EV`0`4
M````:'8!``8```!]=@$`"P```(1V`0`-````D'8!``8```">=@$`$0```*5V
M`0`(````MW8!``@```#`=@$`$P```,EV`0`P````W78!`$,````.=P$`&P``
M`%)W`0`D````;G<!`!H```"3=P$`!0```*YW`0`0````M'<!``@```#%=P$`
M$````,YW`0`L````WW<!``@````,>`$`#P```!5X`0`3````)7@!`!8````Y
M>`$`#0```%!X`0`\````7G@!``D```";>`$`(@```*5X`0`2````R'@!`!8`
M``#;>`$`+````/)X`0`(````'WD!`!,````H>0$`%0```#QY`0`*````4GD!
M`!,```!=>0$`"````'%Y`0`7````>GD!`!P```"2>0$`!@```*]Y`0`(````
MMGD!`!(```"_>0$`%````-)Y`0`6````YWD!``0```#^>0$`"`````-Z`0`+
M````#'H!``X````8>@$`#P```"=Z`0`2````-WH!`!(```!*>@$`"````%UZ
M`0`)````9GH!`"@```!P>@$`'````)EZ`0`:````MGH!``<```#1>@$`$@``
M`-EZ`0`&````['H!``X```#S>@$`&0````)[`0`F````''L!``L```!#>P$`
M!P```$][`0`#````5WL!``8```!;>P$`"````&)[`0`%````:WL!``\```!Q
M>P$`%P```(%[`0`-````F7L!`!T```"G>P$`'0```,5[`0`:````XWL!``4`
M``#^>P$`"P````1\`0`4````$'P!``D````E?`$`#0```"]\`0`)````/7P!
M``P```!'?`$`%````%1\`0!6````:7P!`!@```#`?`$`!P```-E\`0`'````
MX7P!``<```#I?`$`$@```/%\`0`0````!'T!`!$````5?0$`&P```"=]`0`3
M````0WT!`!4```!7?0$`)````&U]`0`3````DGT!`&(```"F?0$`&P````E^
M`0`:````)7X!`"D```!`?@$`&P```&I^`0`:````AGX!`"0```"A?@$`&@``
M`,9^`0`9````X7X!`!H```#[?@$`"@```!9_`0`)````(7\!``L````K?P$`
M"````#=_`0`6````0'\!``\```!7?P$`%0```&=_`0`(````?7\!`%````"&
M?P$`00```-=_`0`H````&8`!`$\```!"@`$`&P```)*``0`K````KH`!``@`
M``#:@`$`"@```..``0`1````[H`!`"D`````@0$`!@```"J!`0!-````,8$!
M`"4```!_@0$`(0```*6!`0`2````QX$!`"````#:@0$`&````/N!`0`<````
M%((!`!\````Q@@$`'@```%&"`0`C````<((!`!0```"4@@$`!@```*F"`0`+
M````L((!``T```"\@@$`"0```,J"`0`J````U((!``L```#_@@$`#`````N#
M`0`'````&(,!`!$````@@P$`"@```#*#`0`%````/8,!`!8```!#@P$`"0``
M`%J#`0`)````9(,!``0```!N@P$`#@```'.#`0`8````@H,!``X```";@P$`
M!P```*J#`0`5````LH,!`!X```#(@P$`$````.>#`0`,````^(,!`!H````%
MA`$`*````""$`0`1````280!`!$```!;A`$`)@```&V$`0`&````E(0!`!$`
M``";A`$`!@```*V$`0`(````M(0!``8```"]A`$`'0```,2$`0`.````XH0!
M`!(```#QA`$`$`````2%`0`'````%84!``D````=A0$`"@```">%`0`,````
M,H4!``\````_A0$`%P```$^%`0`&````9X4!`!(```!NA0$`#@```(&%`0`)
M````D(4!``X```":A0$`&````*F%`0`-````PH4!``4```#0A0$`!````-:%
M`0`&````VX4!``@```#BA0$`"````.N%`0!4````](4!`#0```!)A@$`&0``
M`'Z&`0`'````F(8!``<```"@A@$`"@```*B&`0`*````LX8!``<```"^A@$`
M"@```,:&`0`5````T88!``P```#GA@$`"@```/2&`0`,````_X8!``@````,
MAP$`#````!6'`0`)````(H<!``<````LAP$`&````#2'`0`+````38<!``<`
M``!9AP$`"@```&&'`0`E````;(<!`!@```"2AP$`!P```*N'`0`(````LX<!
M``H```"\AP$`!P```,>'`0`3````SX<!`!,```#CAP$`"````/>'`0`<````
M`(@!``T````=B`$`'@```"N(`0`)````2H@!``8```!4B`$`$````%N(`0`5
M````;(@!``L```""B`$`#0```(Z(`0`7````G(@!``<```"TB`$`"P```+R(
M`0`/````R(@!``X```#8B`$`!0```.>(`0`8````[8@!``D````&B0$`'```
M`!")`0`1````+8D!`#,````_B0$`)@```'.)`0`C````FHD!`'L```"^B0$`
M%````#J*`0`_````3XH!`#0```"/B@$`10```,2*`0!#````"HL!`!\```!.
MBP$`9````&Z+`0`F````TXL!`#,```#ZBP$`*@```"Z,`0`3````68P!`!@`
M``!MC`$`?0$``(:,`0`7````!(X!`!(````<C@$`.````"^.`0"!````:(X!
M`#P```#JC@$`-P```">/`0!)````7X\!`$0```"ICP$`'@```.Z/`0`3````
M#9`!`!@````AD`$`&0```#J0`0`D````5)`!`!T```!YD`$`(P```)>0`0`4
M````NY`!`!L```#0D`$`(0```.R0`0`7````#I$!``\````FD0$`,````#:1
M`0!;````9Y$!`"P```##D0$`4@```/"1`0`Y````0Y(!`",```!]D@$`)@``
M`*&2`0`C````R)(!`$<```#LD@$`1P```#23`0`]````?),!`#P```"ZDP$`
M,````/>3`0`J````*)0!`"H```!3E`$`+0```'Z4`0!G````K)0!`&4````4
ME0$`JP```'J5`0`6````)I8!`"T````]E@$`,0```&N6`0`P````G98!`$D`
M``#.E@$`'@```!B7`0!.````-Y<!`!8```"&EP$`!P```)V7`0"Q````I9<!
M`$4```!7F`$`*````)V8`0`S````QI@!`!H```#ZF`$`'@```!69`0`N````
M-)D!``D```!CF0$`"````&V9`0`&````=ID!``X```!]F0$`#@```(R9`0`2
M````FYD!``H```"NF0$`"````+F9`0`,````PID!``,```#/F0$`;````-.9
M`0`(````0)H!`!````!)F@$`!0```%J:`0`'````8)H!``4```!HF@$`!0``
M`&Z:`0`'````=)H!`!D```!\F@$`"````)::`0`5````GYH!``P```"UF@$`
M!0```,*:`0`'````R)H!``<```#0F@$`%0```-B:`0`*````[IH!`!<```#Y
MF@$`!@```!&;`0`;````&)L!``\````TFP$``P```$2;`0`F````2)L!``0`
M``!OFP$`!@```'2;`0`'````>YL!`"(```"#FP$`00```*:;`0`H````Z)L!
M`"H````1G`$`%@```#R<`0`G````4YP!`"````![G`$`'P```)R<`0`C````
MO)P!`!X```#@G`$`&P```/^<`0`B````&YT!`!X````^G0$`*P```%V=`0`I
M````B9T!`"L```"SG0$`'P```-^=`0`C````_YT!`"$````CG@$`'````$6>
M`0`F````8IX!`"<```")G@$`(P```+&>`0`>````U9X!`!P```#TG@$`(@``
M`!&?`0`E````-)\!`!T```!:GP$`)0```'B?`0`F````GI\!`#H```#%GP$`
M(0````"@`0`E````(J`!`",```!(H`$`)````&R@`0`>````D:`!`!P```"P
MH`$`)````,V@`0`@````\J`!`"L````3H0$`(P```#^A`0`)````8Z$!`!,`
M``!MH0$`&@```(&A`0`:````G*$!`!H```"WH0$`"@```-*A`0`0````W:$!
M`!D```#NH0$`$@````BB`0`3````&Z(!`"(````OH@$`"````%*B`0`)````
M6Z(!`"0```!EH@$`)P```(JB`0`O````LJ(!`"$```#BH@$`#`````2C`0#Z
M````$:,!`!$````,I`$`%0```!ZD`0`*````-*0!``T````_I`$`%````$VD
M`0`?````8J0!``@```""I`$`,0```(ND`0`<````O:0!`!H```#:I`$`"0``
M`/6D`0`5````_Z0!``L````5I0$`10```"&E`0`O````9Z4!`!D```"7I0$`
M%````+&E`0`6````QJ4!`"````#=I0$`$````/ZE`0`1````#Z8!`!(````A
MI@$`&P```#2F`0`,````4*8!`!L```!=I@$`"0```'FF`0`;````@Z8!``H`
M``"?I@$`'````*JF`0`(````QZ8!`",```#0I@$`!P```/2F`0`)````_*8!
M``D````&IP$`,0```!"G`0`'````0J<!`!````!*IP$`%````%NG`0`1````
M<*<!``L```""IP$`#0```(ZG`0`)````G*<!`!<```"FIP$`#0```+ZG`0`6
M````S*<!`!(```#CIP$`%P```/:G`0`5````#J@!``D````DJ`$`"P```"ZH
M`0`9````.J@!``0```!4J`$`*@```%FH`0`/````A*@!``<```"4J`$`!0``
M`)RH`0`,````HJ@!`!(```"OJ`$`"P```,*H`0`#````SJ@!``P```#2J`$`
M"P```-^H`0`&````ZZ@!`!(```#RJ`$`"0````6I`0`3````#ZD!`!0````C
MJ0$`#@```#BI`0`K````1ZD!`!<```!SJ0$`%@```(NI`0`,````HJD!`"0`
M``"OJ0$`!@```-2I`0`1````VZD!`$8```#MJ0$`#P```#2J`0`,````1*H!
M``<```!1J@$`!````%FJ`0`4````7JH!``8```!SJ@$`!P```'JJ`0`(````
M@JH!``8```"+J@$`#0```)*J`0`/````H*H!``4```"PJ@$`'@```+:J`0`B
M````U:H!`!H```#XJ@$`'0```!.K`0`/````,:L!``(```!!JP$`!````$2K
M`0`0````2:L!``8```!:JP$`!P```&&K`0`$````::L!`!````!NJP$`1P``
M`'^K`0`1````QZL!`"D```#9JP$`)`````.L`0!$````**P!`!````!MK`$`
M90```'ZL`0`;````Y*P!`%@`````K0$`+@```%FM`0`6````B*T!`#````"?
MK0$`,P```-"M`0`D````!*X!`",````IK@$`)P```$VN`0`3````=:X!`#``
M``")K@$`,````+JN`0`7````ZZX!`!(````#KP$`%````!:O`0!/````*Z\!
M`!,```![KP$`;0```(^O`0!4````_:\!`"<```!2L`$`$@```'JP`0`:````
MC;`!`!0```"HL`$`(@```+VP`0`;````X+`!`!H```#\L`$`7````!>Q`0`6
M````=+$!``L```"+L0$`!@```)>Q`0`'````GK$!``@```"FL0$`"@```*^Q
M`0`;````NK$!`!8```#6L0$`&@```.VQ`0`F````"+(!`!$````OL@$`"0``
M`$&R`0`$````2[(!``X```!0L@$`$````%^R`0`'````<+(!``@```!XL@$`
M&P```(&R`0`,````G;(!``L```"JL@$`$0```+:R`0`+````R+(!``<```#4
ML@$`%````-RR`0`.````\;(!`!<`````LP$`"P```!BS`0`.````)+,!``L`
M```SLP$`!0```#^S`0`-````1;,!``8```!3LP$`!@```%JS`0`1````8;,!
M``(```!SLP$`"@```':S`0`(````@;,!``@```"*LP$`)@```).S`0`&````
MNK,!``P```#!LP$`$````,ZS`0`.````W[,!``D```#NLP$`"0```/BS`0`$
M`````K0!`!`````'M`$`$@```!BT`0`'````*[0!``T````SM`$`(P```$&T
M`0`*````9;0!``4```!PM`$`%@```':T`0`%````C;0!``(```"3M`$`"P``
M`):T`0`!````$`,``(<"```:`P``JP4````````?`@``3@$``#4$``"H!0``
M2@(`````````````YP,```````"0!```H`$``*H!````````Q0(```````!%
M!0```````)\%````````:`0`````````````*0(``"@#``!'!@``]````"\&
M```Q`@```P,`````````````]0```"\%``!5!@``90,```````!N`P``&@$`
M``````!<`0```````+L````F`@``S`$```````!G!```<00``#P!``"[`0``
M`````-D"``!9`@``(P,``)X"``"*!```80```````````````````#,#````
M`````````*D#``"_!``````````````^!```?@```#X!``#[````````````
M```K`P``X@4```````!@````80,``*8!``"K`@``X`0`````````````.@$`
M`"@$``#2`@``WP4``!(#``!9!````````'(&````````LP0``!L#``"A!0``
M``````````#V`0```````(P$````````300``$T%``"\`0````````````"4
M!0``YP4`````````````"`(```````!'````6P0``#($`````````````"D`
M````````LP$````````!`0``'0,```````!:!@``HP```$D%``"0`@``````
M```````3!@``?P$```````#^`0``GP,``&X&``````````````````"I`0``
MC@````````"3````;P0``-\$```8!``````````````V`0``FP4```````#,
M`@``@0,````````=`@``+@$``(($```S!0``8P8```````#/!0``YP$`````
M````````-P```%H```#Y!```IP(``&0#``"Y`@```````*8#````````````
M`)0!```_`0``B00``,<$``"R`P``O`(```````#A````&0````````!8````
M``````````".`0``,P$```````"\````/P0``*D"``"C`0``"@(``*T````E
M!@```````"L$``"5````!`(```````!2`````````"T`````````0P8``&0"
M``#<!```+08```````"W`P````````````!R!0``[@,``,(#````````````
M``````````````````````!]!````@$```P#```]`@``G0,``(T$````````
ME0$``/<"``#!````3@4````````F`P``?`,``.T```"%`0``_`(``/X"```2
M!0````````H!``"R``````````````"S!0``PP(``&(%```3`0``K@0``$@"
M``!,!```S@```"H$````````"`8``"\````>````6P8``"8%``!W`P``````
M`.\#``"9!0``T@$``/H%``!&!0``T0$``!`"```X!@``4`(``*$#``#A!0``
M,@4``!0!```8!@``:08``#,$``".`P```@0``$\$``!:!```B`(``#8%``!&
M`P```@(``&8%``!9`P``408``$<!```+`@``4P(``"\$````````D@```,\#
M``!!`0``]00`````````````_@```(0```!-!@``MP(``#L"````````SP$`
M``8$````````U0,```4!``#;!````````-$%``#``0``=P4````````1````
M3@````````#-!```N@(```````!$!@``"0,````````H`@``>04``(H!``#_
M!```+00``!H$``!=!0``[P(``$0"````````K`$``&X"```O`P``O`,```T&
M``#S!```_`$``*,%``"]`@``C0$``),$``!B`@``-0,``%8"``"8!```(@0`
M`)$!``#X````5@```-(%``#M`P``Y0```.H````>`0``=@```'L#``!6`P``
M`````#(```!Y````A0,``/@$``"P`@``\@4```````"=`0``9`````0!``"V
M`P``90```-$```!0!```608``#\````R`@``2P4``````````````````-,$
M``"@!0````````8#``"H````=0,``/<%``!A!@``'`0``),"``!2!```$0(`
M`(0#````````)0```/\#```````````````````A`P```````#T&``"]!0``
M-P,``````````````````","``")!0``"P8```````#>````FP```'0`````
M````I`(``#4"```^!@```````&L&```5!@``0P(``(\#``!7!@``G@0`````
M````````908``!\#````````K@(``!T!``#;`@``P`4``#X#``"[!0``D```
M`/L#```>!@```````,H!``#,`````````#,`````````\P4``*X!````````
MW04``%8!`````````````-0````N!@``F@````````!;`P``N`$```````"&
M`@``EP0`````````````'`4``%0````,!```Z````*\"````````D@0``$,#
M``"I!0``M@(``#P$``"%!```>P````````#V`@``I0(``(0$```6`@``;`(`
M`$(```#$`0``"@8`````````````E@$```````!=!```-`(``"`%````````
M$````%(#````````IP4``&T"``"T`@``Z04``'\#```[!```5@0``$D"````
M````8P```'$```!)````Q0$```````!<````FP$``'0"``!L````^0$`````
M``#``P``=P````````#R!```9@$``*X%``"J!0``G@,```````!X````````
M`#P"````````#@4```$#``!0`0``3@0``#H%```Z!```!0,``$X&````````
MH@``````````````4P0``(T#`````````````/(!````````_P4``(<!``"0
M`0``L04``(L#```@`````````,D!``"[!```M`0``,L%````````'P8``)T%
M``!?`@```````&\"``!G`0```````-X"``",`````````-@"``!T`0``C`,`
M`/("````````F@0``&<#``!$!```^`$``-@%`````````@,``(D```"E`0``
M`````&L``````````````!$$```L`P``$`0``.$!```8!0```````*8"```W
M!0``?@4``+X#``````````0`````````````C@4``&`$``!%````JP$``(L$
M``!\````UP,``+8`````````;`$``+<````0!0````````````"_`P``````
M`'0&``!-`@``[P0``(0!```L`0```````#0```#$`P``T0,````````Q`P``
M2`4``%,!````````[@0``&\%``#=`0```P$``"\"```L````1P(```````#K
M`@``'P$``.`#``!*`P``<@(```````"J`@``K04``)X%````````"@0``+\"
M```7!@``9@(``&8`````````%@```(@!``!3!0``)0,``+0```!"!```````
M``````#(`@``M00``#T```#E`P`````````````,!@``L`,``)(#``#6````
M2`0``!D"````````Y`,````````K`@``GP$``.0$```6!@```````&P#```,
M````NP(```````!B`P``````````````````+`0``"$```!2!@``B0,`````
M```*`P``;@$``(@`````````%P(``%$%```.`````````#4```"%`@``````
M`.0"``!L!0``>P0``&@```#Q`````````'@!``#Q`@```````%P%``"4!```
MG`4``$@```#<!0``VP```#T%````````\00```````#W!````````!@"``!8
M`P``6`4``)\```";!```"P0```````!*`````````"\!``"3`0``*@4`````
M`````````````+4%````````HP(``*$$````````C04```````!>!@``<@$`
M`#P#``#:`P``Y@4``'0#``#[`@``@P4``.,$````````)0(``$L"````````
M````````````````10,```````#]!0``N`(``"L````Q`0``[04``)<"``"D
M!0```````,X$``"L!`````````X"``"*`@``*@,``-,"````````^04`````
M````````XP$``,0"````````2P,``!\$``#?````-@8``+T!``!3!@``````
M`````````````````!$&````````J`,```T!``",!0``DP,```````#@`0``
M`````&`#``!>`0``Q`4``*\#```'!0``70,``%4$``":`P```````$0#````
M````.@8``&0&````````30$````````/`0``#P4``$<$``"Z!0``\P```-$"
M``"Y````&`,``-<"``!Z`P``?`$``!D#``"4`P``KP$``%T!``!/````\@,`
M`'@"``!B!@```````#(!``#G```````````````;!````````*$!````!@``
M`````+,```"8`0``]@,``````````````````!D$``"#`@```````%\!```X
M`P``RP0``"0$````````)P4``/8```#Z````=@4``/(```"U`P``QP,`````
M````````!@8``,$"```5!```5`0``#$$``!C`P```````%P#``!?````Z0,`
M`````````````````,L"``#5````,P(``$`!```X!0``N@```%X```!``P``
MRP```.````#L!```T00``"@```#Q`P``AP,``%$"``"E!0````````````!F
M!@``V`,``-4!```K`0``[`4``'P%``!-`P``$`$``"`&```Y`@``PP4``!X#
M``!@`0``;04``(`#``!C`0``B0(```````"U`@``)P8``+T$````````EP4`
M`%<$``````````````````"<`@``9@,``#0#```7````>`4````````1!0``
M`````'(````B`P``R0(```````"T`P``B`4``'$!```-`P``1P4``%H#````
M````$@(``$8"```F`0``(@(``%`%``"G`````````*`#``!E`0``YP0``.8!
M``"1`````````&H$``!9!0``%`,```X#``#L````IP$``#<"``!U`@``````
M``````!S`0````````````"6`@```````,4$``#*`P``@`(``&T#````````
ML`0```````!S!@``^@(``$D$``!-````X`(``%,```!;!0``T@,```@#```6
M`P```````)8$``#>!0``R0```*,$````````Z`(``+8!`````````````+P$
M``"U````@P```&<```!4!@````````````#D!0```````,T!``!5`P``_`4`
M```````X!```6`(````````N`@``W@,``'X$`````````````"`$``#&`0``
MP`0``*P"``#6!```M@0``,8```"D`P``S04``/,!```A`0``QP4```````!]
M`0```````"T%````````X@,``!0"``#L`0``=0```-8!```'!```R00``%0!
M``!"`0```````%L!``"H`@``%``````````,!0`````````````N````````
M`#H"`````````````!P!```Z``````````````!5`@``=@(``*@!``"/!0``
M00,``&X$````````W00``"P&``"J`P``;P,```P"``!#!0``7@,``)(!``!)
M`P``)@8``#T#``"N````9P4``-0#`````````````/0%``#,!0``)`(`````
M```4!@``D0(```````"I````5P$``&$$``"M`@```````.L#````````````
M``````"?`@````````````"E`````````)\$``#:`0``!`0``#8#``#P!0``
MM0$``,($``#U!0``U@,``%8%``"M!```P0,``-@`````````#@$``'H$````
M````20$``-P"`````````````````````````````,8%``"1`P``4@$``#\%
M````````8`(```````#B`0``7@0```````!L!```<`8``!$#```V`@``,```
M`*P````6`0````(``+$```!J`P``X00````````R`P``(P$```````!P`P``
MTP4````````!!0```````",$````````````````````````$0$``&\!``"P
M````7`8``'4%```7`P```````-,!``#A`@``L0(``&D````#!@``O`4``"$$
M````````>`0``-`!````````/`8``.(```"G`P``X@0```````"W`0``EP$`
M``````"^!```*`8``$`$``#M!```$@```.4$`````````````.L$````````
MF@(`````````````"`0``-X!`````````````,,$````````ZP$``*X#``#C
M````<`(``$P&```=!@```````!8%``"1!```2@$``',$``"$`@``50```.H!
M`````````````'($```W!@``F00``.H#```N!````P4``$<#``!?!```````
M`*P#``!^`@``>P$``+$$``!_````.04``,8$``!(`0``0@(````````I!@``
M-@0``(H```#M`0```````````````````````.@%````````Y@,``!`&``#E
M!0``@0```,H%`````P``<P,````````#`@``D`,``/\```!*!````````"<`
M``#[!```00```(8#``"/`0``)````(\````V````Q@(``&,"``!,`@``50$`
M`'D!```X`@``JP```'L%````````_0(```````!.`P``DP4``&T```#W`P``
M;P```,X#``"!`@``F`(`````````````-P$```T```#/````A0`````%``"B
M!```7`0```````#)`P``[`(``)@````J`@``#P,`````````````7P8``/X$
M```;!@``L0,``+@```"M`P``.00``#H#``#;!0``LP,```4&``#,!```OP``
M`,T````'`@``40```/8%```[!0```````+L#``#O`````````.X"``!X`P``
M```````````9`0``"@4```````"'!```$P,``'\"`````````````*,#```T
M!0``504``#4%``"B!0```````&@"``!\!```_P$```8````.!@``904``'(#
M``````````````````#K!0``&@(````````8`````````"T"``!H`P``6@$`
M`',%````````5@8``.0````"!@````````````!+!@``P00```````!G!@``
MN00```````"8`P``G``````````G`0``100```<!``##`0``0`8```0```"`
M````>0(``%<```!(`P```````(L"``""``````````````!B!````````.<"
M``#(````]0$```4$``!1`P``U00```````")`0``!@4``)8#``"!!```KP0`
M``````".!````````&T!``#'`0``"00``+X!```N!0````````D%```>`@``
M:P(``(@$``!=`@``M`4````````%`````````%@!```Y``````````````#3
M`P``U`$`````````````K0$``-D`````````*04``)0```!U!```,0```-@!
M``!W!````````!L%``!J`@``P@````````!1!```UP$``$$&``"B`@``(`,`
M`'<!``#J`@``\P,```````!9`0``V00``"0#``#T`P``BP```+X`````````
M"P,``,\$``#H!```)04``!L!``#(`P``2@8``#D#``"W!0``-`0``)8````Y
M`0```````(L%``!Q`P```````"L&```3`@``CP(``$@&``!9````2P$`````
M``#3````(P4``*\`````````*0,``&$!``#X`@``208``!@!``!"!@``W0,`
M``````!%`0```````)<#`````````````%$!`````````````#T!````````
MP0$``*0!``"&````9`$``$`%`````````````%0"``!0!@``J00``(H#````
M`````````-D%``"-`````````$P!```"!0``/`````````!@!@``PP,``,X"
M````````F@$```````"K!```5P4``&(!````````_`,``+`!``#2````N@$`
M`,@%``"_!0``708``.D`````````'00``&T$`````````````%0#````````
M#P8``)0"``"D!```:P4````````A!@``N@0```````!Z````^0(``&H%``#=
M`@``]0,```````!$````BP$``)4%``!M!@``@P0``+,"````````EP```$$$
M````````G00``)4"``",`@``@@4``/H$`````````````%0%``#0`P``````
M`.@#```+!0```````(,#``#7````.P$```````"9`P``(@8`````````````
M]P$``.\%``!J`0``P@4``+\!``!J!@``804``!<$`````````````.8```!O
M!@``!0(``'$%``!&`0``.`$```````#N!0``L@(``````````````````'4!
M````````-P0```````"`!0``-`8```````!P`0``6`8``+@#````````3@(`
M`#@````)`0``Q04`````````````MP0``'D#````````@`$``$P%```'`P``
M@04``',"``#!!0```````````````````````/T!``#F!````````&$"```N
M`P``3P(``+$!``#[!0```````)P#````````6`0``.T"``#:!0``=@0``-`$
M``!!!0``:`8``,T#````````````````````````XP(``'$"```4!```;@4`
M`*$"``!/!@``QP(``*8$````````?0(``-D#``!H`0```````-8%````````
M:`4``$P````5````D@(```$$``"F!0````$``#`"``#N`0``T`(``*$```#'
M````'@0``%<"```H`0``^@$`````````````"`$``!(&````````F`4``!H`
M``"B`P``>@4``-P#```^!0``V0$``,L!```;`@``[`,``#`&````````XP4`
M````````````Q`0``"(!``#*!```WP(``'X!```K!0```````%T```#]````
MUP0``'T%``"^`@``#@0``#$&``!_!0``%0$``+@%``"&`0``!`,``,H````+
M````D@4``(T"```?````^`,``/`"````````>00````````'````R@(`````
M``"&!0``AP4``.`%``!2!0``'````)L"``#6`@``N04``)D````[!@``7`(`
M`'0$``!&````````````````````.08``'<"``"H!````````'`$``"J!```
M```````````@`@``'04``$8&````````]0(``#\#``"5!```````````````
M`````````+`%```U!@``?P0``.0!``#:````]`$``!H%``!Z`0``M`$``-L#
M``#I`0```````(`$``#$````@@$````````_!@``"08``&L!``#5!0``````
M`*P%````````@@(```$&```/!````````!L`````````!04```L!````````
MI0,````````[`P``_00``.@!```P`P``0P0``-0"```<`P``WP,```H```"K
M`P``\`$``&L#````````:0$``-H"``#4!````0(``!D&``#-`@``*0$`````
M````````(`$````````F!```9P(``/T#``#;`0``B@4``$\!``#.`0``````
M`.X```#:!`````````D"``!V`P``1@0```````"R!```3P,```8"``!F!```
M$@0``)X!````````5P,``+H#```]!```)P(````````B!0``_@4```````#P
M`P``'0```'````!E!```Q@,```````!#`0``#04```0&````````CP0``&(`
M``!+!````````+(!``#I`@``]`(``$0%``!0````T@0````````-`@``"0``
M`%L"```3````L@4```````!I`P``-`$``!P"``"9`@``!P8``&X`````````
M/@(``/D#```3!```)00``*`"``!,`P``&04```````#J!`````````````#Q
M!0```````.4!``#K`````@`````````7!0``>P(``.("```G`P``J@```)4#
M``#(`0```````+X%``#W````3P4``!4%``!0`P``*@```+T#````````A@0`
M`````````````````-````#?`0``)`8````````[`````````)T"```C````
M(0(```````!3`P``*@8``,("``"X!```%P$``(0%```B````=@$``/H#``"Y
M`P``:0(``)H%``!P!0``]@0``/`$````````Q0,````````E`0``0@4``#`$
M```````````````````#`````````)L#``#``@``(04``#(&```F````?0,`
M`&0$``````````````@%``"(`P``````````````````I@```/\"````````
M1`$``%X%``!Z`@``^`4``",&``#4!0``G`$``#,&````````8P0``$$"````
M````@P$``*<$````````#00``%H%`````````````!8$```Q!0``````````
M```4!0``RP,``$`"``!`````D04```@```"9`0``%0,``%\#``#P`````P0`
M`-T```#Y````108``&,%``"D````S@4``(P!```I!```KP4``/P```"Y`0``
MSP(``!,%``#%``````````\```!T!0``M@4``-`%```G!```````````````
M````P````&0%```$!0``G0```,D%``!I!0``-0$``&H```#F`@````````8!
M``#>!```XP,``/P$````````*@$``&4"```P!0``,`$``!X%``!2`@``Z00`
M`'$&``#E`@``G`0``'T``````````````!P&``#T!```P@$``)X```!S````
M6P```%\%``#^`P```````-4"``#<````[P$```\"```\!0``V`0``#\"``".
M`@``'P4```````!\`@``6@(``"P"``#S`@```````.$#```D`0```````,,`
M```L!0``$@$``$H%``!>`@``0@,``((#```,`0````````````"@````````
M`,@$``#,`P``10(`````````````+0$``)`%``#J!0``2P``````````````
M+0,```````"]````E@4```````#<`0``?@,``(4%````````;`8``!4"```H
M!0``)`4``*(!``#Q`0```````*`$``#7!0``AP```#X```!@!0``:00``*4$
M````````&@8``$,``````````````/L!``!K!```@0$``````````````"`H
M)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*'1O9&%Y*0`@*'EE<W1E
M<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($9I;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P
M97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4VEG;B!5<``E<R!497)M<R!O
M9B!!9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@)7,@)7,`
M+"!V87)I86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R
M($9O<FUA=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P!!(&1A=&%B87-E(&)A
M8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R
M;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@
M=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q
M=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E
M<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I
M=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@
M=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R
M:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D
M('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q
M=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-(%-H;W=E<G,`04TO4$T`
M05!)($E$`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!
M8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A
M<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI
M;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.
M97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&YE=R!U<V5R.@!!
M9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S
M($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O
M:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1I;F<@=7-E
M<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T
M97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S`$%D;6EN:7-T
M<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA`$%L9V5R:6$`06QI87,`
M06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE;G1I8V%T960@57-E<G,`
M06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL(&9O=7(@<VED97,`06QL
M;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E='1I;F<@;V8@;W)D97)E
M9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L=&5R;F%T92!)35-0($QO
M9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L=&5R;F%T92!)35-0(%5S
M97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S`$%L=&5R;F%T92!T96UP
M;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N(%-A;6]A`$%N(&EL;&5G
M86P@=F%L=64@=V%S('-P96-I9FEE9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@:7,@<F5A9'DN
M`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<FEL`$%R86)I8R`H
M5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`
M07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E
M<75E<W0@9F]R("5S(#\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%2
M35-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T
M`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F
M;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@
M8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U
M<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN
M`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB
M=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E
M<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@
M0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!
M=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@
M0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T
M:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA
M="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO
M=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E
M<P!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO
M;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E5
M4R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D
M+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W
M;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"
M86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V5L
M:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T
M86X`0FER=&AD87D`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O
M;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T
M;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D
M($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A
M;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A
M=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N
M)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N861A`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E9V]R:65S(&%N9"!,86)E;',`
M0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L
M;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL
M<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R
M:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#
M97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`
M0VAA;F=E`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L
M92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS
M+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#
M:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W
M('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O
M<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN
M:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T
M86=S`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@
M9&%T80!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L
M;W-E(%=I;F1O=P!#;&]U9',`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA
M;F1S`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I
M8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M
M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE
M`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N9&ET:6]N<P!#;VYF:6=U
M<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W
M;W)D`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T
M:&4`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E
M<W,@8F]O:RX`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O;VMI90!#;W!Y`$-O
M<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N
M;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S:6=N(&UE
M<W-A9V4N`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L
M9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@
M;F]T(&-H96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#
M;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T
M92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L
M:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E
M+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E
M<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO
M;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@
M9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K
M97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U
M;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@
M;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R
M('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I
M;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R
M(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L
M9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S
M(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@
M)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#
M;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E
M("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O
M;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T
M92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z
M:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`
M0V]U;G1E9"!T97AT`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@
M;&EN:P!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A
M=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U
M8F$`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@5V5A=&AE
M<@!#=7)R96YT(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE
M('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C
M=&EO;@!#>7!R=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O
M=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E
M<'5B;&EC`$1$`$1A:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E
M8V5I=F5D`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E
M;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969I;FET:6]N<P!$96QE=&4`1&5L
M971E($=R;W5P`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@
M;65S<V%G97,`1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI
M<W1I;F<@86QT97)N871E('1E;7!L871E`$1E;&5T92!R;W<`1&5L971E('-E
M;&5C=&5D(&ED96YT:71Y`$1E;&5T92!T:&4@8W5R<F5N="!C;VQU;6X`1&5L
M971E('1H92!C=7)R96YT(')O=P!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S
M8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I
M;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@
M9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`
M1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I
M;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E
M8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`
M1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I
M=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N
M;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F
M:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE
M8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;W=N
M;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA
M:6P`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I
M="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N
M<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F
M;W(@)7,`161U8V%T:6]N`$5G>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`
M16T`16UA:6P`16UA:6P@061D<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M
M871C:"X`16UA:6P@=VET:"!C;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y
M(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N
M86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S
M(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N
M9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I
M;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S
M970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y
M;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`17%U871O<FEA
M;"!'=6EN96$`17)I=')E80!%<G)O<@!%<G)O<B!W:71H(&5M86EL(&UE<W-A
M9V4N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R>2`Q-2!M
M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y
M(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@
M;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%>'!E8W1E
M9"`G*2<`17AP96-T960@8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R
M;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE;G0`1D<@0V]L;W(`1E10('5P;&]A
M9"!O9B!S971U<`!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C;VYN
M96-T('1O(%--0B!S97)V97(N`$9A:6QE9"!T;R!C;W!Y(&9R;VT@(B5S(BX`
M1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+@!&86EL960@=&\@;6]V92!T;R`B)7,B+@!&86ER
M`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A
M>`!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R
M<P!&:6II`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE
M('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&
M:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI
M<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L
M;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E
M<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O
M<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D
M<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC
M:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R
M<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL
M($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F
M<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N
M`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT
M87(`1VEV96X@3F%M90!';P!';V5D96P`1V]O9VQE(%-E87)C:`!'<F%Y<V-A
M;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D
M80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>0!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=65R
M;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A`$=U:6YE
M82U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E
M<R!T;R!D96QE=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O
M=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T
M86)L92X`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@<F]W(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F
M;W5N9"X`2&%I=&D`2&%S:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M
M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI
M9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(
M;VUE($%D9')E<W,`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R
M9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R
M97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O
M9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-
M3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R
M:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO
M<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@
M:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD
M('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I
M(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M
M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)
M34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I
M;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL
M86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C
M:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`
M26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T
M;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E
M(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L
M;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);G-E<G0@
M0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R
M="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W
M(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O
M;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@
M869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E
M('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE
M(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C
M=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@
M86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE
M(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@
M8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O
M<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS
M97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@
M<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@
M<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T
M+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T
M:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN
M=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE
M861E<BDN`$EN=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@8F%T8V@@240N
M`$EN=F%L:60@9&%T82!S=6)M:71T960N`$EN=F%L:60@9&5S=&EN871I;VX@
M861D<F5S<RX`26YV86QI9"!F:6QE(&9O<FUA=`!);G9A;&ED(&US9U]T>7!E
M+@!);G9A;&ED(&]R(&UI<W-I;F<@87!I7VED+@!);G9A;&ED(&]R(&UI<W-I
M;F<@<&%R86UE=&5R<RX`26YV86QI9"!P87)E;G0@<&5R;6ES<VEO;BX`26YV
M86QI9"!P<F]T;V-O;"X`26YV86QI9"!S:&%R92!O8FIE8W0`26YV86QI9"!S
M;W5R8V4@861D<F5S<RX`26YV86QI9"!U;FEC;V1E(&1A=&$N`$EN=F5N=&]R
M>0!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE
M(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI
M8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR
M,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S
M('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I
M97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME
M>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U
M8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T
M:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO
M<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U
M86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L
M9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,
M87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I
M80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO
M;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&EB97)I
M80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@
M1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I
M;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N
M9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN
M:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T
M:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#
M;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T
M86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,
M;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,
M;V<@;W5T`$QO9VEN(%1A<VMS`$QO9VEN(&9A:6QE9"!B96-A=7-E('EO=7(@
M=7-E<FYA;64@;W(@<&%S<W=O<F0@=V%S(&5N=&5R960@:6YC;W)R96-T;'DN
M`$QO9VEN(&9A:6QE9"X`3&]N9R!T97AT`$QO=F4`3&]W`$QO=V5R(&=R965K
M(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N=6UB
M97)S`$QU>&5M8F]U<F<`34T`34]41`!-4RU43D5&($%T=&%C:&UE;G0@8V]N
M=&%I;F5D(&YO(&1A=&$N`$U31P!-86-A;P!-86-E9&]N:6$L(%1H92!&;W)M
M97(@675G;W-L878@4F5P=6)L:6,@;V8`36%D86=A<V-A<@!-86=I8P!-86EL
M`$UA:6P@061M:6X`36%K92!L:6Y?:RXN+@!-86QA=VD`36%L87ES:6$`36%L
M9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI<W0@;V8@8V%T96=O<FEE
M<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H+"!A;F0@8V]L;W)S(&%S
M<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S+@!-87`R-"!M87``36%P
M475E<W0@;6%P`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!
M;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG
M(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D
M:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!L
M96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z
M`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S
M9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@
M8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE
M=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@
M8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T:&]D`$UE=')I8P!-97AI8V\`
M36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4
M>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@
M:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C
M:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U
M(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T
M:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@
M<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)
M1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I
M9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO
M;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N
M(%!H87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO
M<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V
M92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L
M(&1R;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N
M=`!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O
M($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N
M9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T
M<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%52
M3`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%52
M3`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A
M=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`
M3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H
M7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3FEC
M87)A9W5A`$YI9V5R`$YI9V5R:6$`3FEG:'0`3FEU90!.;P!.;R!A=F%I;&%B
M;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R
M+@!.;R!A=F%I;&%B;&4@<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S
M+@!.;R!B871C:"!T96UP;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R
M97%U97-T960@<&]S:71I;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F
M;W(@34-!3"!A=71H96YT:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9')E
M;B!C86X@8F4@861D960@=&\@=&AI<R!P97)M:7-S:6]N+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@)7,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"U&:6QE(%9&4RX`3F\@8W)E9&ET(&QE9G0N`$YO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+@!.;R!F:6QE('5P;&]A9&5D`$YO(&QO8V%T:6]N(&ES
M('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N
M`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V
M:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K
M('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U
M;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE
M(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N
M`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S
M:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A
M=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.
M;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N
M82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D
M:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T
M960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E
M<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M
M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U
M<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C
M="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E
M`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R
M<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S
M:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N<R!T
M:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L
M:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T
M:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A
M=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3
M:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-
M($QI9VAT(%)A:6X`4$T@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0(%-H96QL
M`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y
M+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!0
M87)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S
M=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!087-S
M=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z(`!0
M87-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP8F]A
M<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S
M`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA
M=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O
M;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0
M;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L
M96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S
M92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E
M;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED
M(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N
M`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@
M<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U
M<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E
M9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S
M:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A
M8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0
M*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L
M9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S
M7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N
M9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z
M(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0
M<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R
M;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X
M=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV
M871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T
M;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A
M9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@
M4VAO=V5R`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E
M<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@
M=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@
M;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E
M9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R
M`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W
M=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M
M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO
M=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C
M=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O
M8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O
M=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297-E
M=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L=',`
M4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO
M;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H
M="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE
M`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`
M4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E
M<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`
M4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U-(
M`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET
M=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ
M=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F
M<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R
M:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3
M879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N8V4`
M4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D
M871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C="!T
M:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO=RX@
M66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@=&5X
M="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@=&AE
M(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT('1O
M(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T('1H
M92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N`%-E
M;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R<F5D
M(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E;F5G
M86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R;P!3
M97)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O<'1I
M;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO
M=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@
M>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R
M('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N
M<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE
M+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N
M`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE
M<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC
M97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H
M;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO
M=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`
M4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:')I;FL`4VAR
M:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@
M=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N
M871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N
M8V4`4VQO=F%K:6$`4VQO=F5N:6$`4VYO=R!3:&]W97(`4VYO=R!D97!T:#H@
M`%-N;W<@97%U:79A;&5N="!I;B!W871E<CH@`%-O;&]M;VX@27-L86YD<P!3
M;VUA;&EA`%-O;F=S("8@4&]E;7,`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U
M<F-E(&%D9')E<W,`4V]U=&@@069R:6-A`%-O=71H($5U<F]P96%N("A)4T\M
M.#@U.2TS*0!3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<P!3;W5T:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J
M86-E;G0@8V5L;',`4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@
M:6X@8V5L;`!3<&%C97(`4W!A8VEN9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P
M86EN`%-P86T`4W!E8VEA;"!#:&%R86-T97(@26YP=70`4W!L:70@8V5L;`!3
M<&QI="!C;VQU;6X`4W!L:70@<F]W`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A
M<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A
M='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEK971H<F]U
M9V@`4W1R:6YG(&QI<W0`4W1R:7`@9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`
M4W1Y;&4@6T-34UT`4W4`4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E
M<W,`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A
M9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C
M;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M
M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3
M=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3
M=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA;B!-87EE
M;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E<G)O<B!I
M;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4
M+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE
M('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`
M5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E
M=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z
M(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D;6EN:7-T
M<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4
M:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H
M92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@
M<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@
M;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S
M960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W
M86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`
M5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T
M(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@
M8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S
M<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R
M97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES
M=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D
M:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y
M<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO
M;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4
M:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`5&AE(&9I
M;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E('1H92!H
M96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N`%1H92!F
M=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L96US('=I
M=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U9W,@=&AA
M="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M:6=H="!E
M>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET;W(@9G5N
M8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@268@>6]U
M<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY('1H870@
M>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&%N9"!N
M965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N("!0;&5A
M<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H92!F=6QL
M('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E
M;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A=&EO;B!O
M9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T
M7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER
M960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E
M9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D
M871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L969T('-I
M9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97)V97(@
M(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E
M96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S(&)E96X@
M<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI<W0N`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R
M92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T
M<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O
M(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E
M<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E
M<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@
M3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M
M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P
M<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@
M<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA
M>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP
M;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R
M;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F
M="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E
M<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN
M(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U
M<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R
M:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-
M05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4
M:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E
M+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE
M+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E
M<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR
M;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH
M='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@
M05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I
M82!33510('1H<F]U9V@@=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N
M;'D@=&\@5F]D869O;F4@;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@
M86-C;W5N="!W:71H(%9O9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI
M="DN`%1H:7,@9FEE;&0@:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!I;G1E9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&YU;6)E<G,@86YD('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&]C=&%L('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M8V]M;6$@;W(@<W!A8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI
M<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU
M<W0@8V]N=&%I;B!A(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T
M+"!F;W(@97AA;7!L92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D
M>2!B965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B
M($=R;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I
M;&P@;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@
M2V]L86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M
M86EL(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI
M<R!S97)V97(@8V%N)W0@=6YC;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N
M`%1H:7,@<WES=&5M(&ES(&-U<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V
M86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A
M;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4
M:6UE`%1I;64@5')A8VMI;F<`5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`
M5&EM;W(M3&5S=&4`5&ET;&4`5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE
M8W0@;75L=&EP;&4@:71E;7,L(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I
M(&]R($-O;6UA;F0@*$UA8RD@:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4
M;V=G;&4@2%1-3"!3;W5R8V4`5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A
M`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A
M;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R
M:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC
M;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD
M97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@
M<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M
M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI
M<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R
M;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@
M=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L
M92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL
M92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!6
M1E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L
M971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@
M<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A
M:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B
M;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O
M9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O
M;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE
M(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S
M(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY
M(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C
M:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO
M=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`
M56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A
M=&4@)7,`57!D871E('5S97(`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L
M;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T
M:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU
M;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES
M=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`57-E<B!2
M96=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@<VET92X`
M57-E<FYA;64`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A
M;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E<P!686QU
M97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`
M5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B
M965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E
M<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@
M2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE
M=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA
M;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`
M5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%2
M3DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A;&QI
M<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E8V%S=`!796%T
M:&5R(&1A=&$@<')O=FED960@8GD`5V5A=&AE<BYC;VT`5V5B`%=E8B!3:71E
M`%=E96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S
M=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E
M<FX@4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@
M869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_
M`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA<V5S`%=H
M:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O
M<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M
M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI
M.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7
M:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N
M<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B
M:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N
M=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!9
M96%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@
M34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@
M5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;B!N
M;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`
M66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@
M9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@
M=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B
M965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L
M;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G
M*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@
M:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U
M<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S
M="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H
M92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R
M92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V
M97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O
M(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO
M=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU
M<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!
M9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T
M:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F
M;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI
M<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P87-S=V]R
M9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`
M675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@
M475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E
M>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O
M9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@
M4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I
M;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I
M;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N
M+BX`7U5S97)S`&%D9')E<W,@8F]O:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE
M<F4`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S("@E<RD@870@)7,@)7,`:#H`
M:6UM961I871E`&EN;&EN90!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO="!Y
M970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!I>&5L<P!R:7-I;F<`
M<VAO=R!D:69F97)E;F-E<P!S;7,R96UA:6P@=FEA($A45%``<W1E861Y`'1A
M<VL@;&ES=`!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N
M:69I960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O
M;0!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,"UC=G,*4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E
M.B`R,#`T+3$Q+3(Y(#$R.C4R*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!6:6QI
M=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#X*3&%N9W5A9V4M5&5A;3H@3&ET
M:'5A;FEA;B`\=FEL:75S0&QN:RYL=#X*34E-12U697)S:6]N.B`Q+C`*0V]N
M=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$S"D-O
M;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H<')I9?`@)7,@9&EE
M;F%S*0`@*&UY9W1U:V%S("5S*0`@*/!I86YD:65N*0`@*'9A:V%R*0`@`"5D
M("5S(&ER("5S`"5D+61I96[X('!R;V=N;WKK`"5S("T@<&%S=&%B80`E<R!A
M;G1S<&%U9&%S`"5S($M"`"5S('!R;V9I;&%K=&EK;W,@=F5I:W-M86D@+2!P
M871V:7)T:6YI;6%S`"5S(')E9VES=')A8VEJ80`E<R!N=6]S=&%T;W,`)7,@
M:F%U(&5G>FES='5O:F$N`"5S("5S("5S`"5S('ER82!P<FEV86QO;6%S`"5S
M(&UI;G5TZW,`)7,@;F5R87-T87,N`&YU;R`E<R!I:VD@)7,@:?`@)7,`)7,@
M861R97/X(&MN>6=E;.L`)7,@:V%L96YD;W)I=7,`)7,@=?YR8?#X(&MN>6=E
M;.L`)7,@9&%R8O@@<^!R8?!A<P`E<SH@)7,`+"!G^W-I86D@)7,@)7,`+"!K
M:6YT82!N=6\@)7,@:6MI("5S`"TM('!A<VER:6YK:71E("TM`#$R('9A;&%N
M9/@@9F]R;6%T87,`,C0@=F%L86YD^"!F;W)M871A<P`R-"!V86QA;F1O<P#0
M:6%M(&)L;VMU:2!R96EK86QI;F=A('9I971A(&1U;VUE;O@@8F%ZZVIE+@#!
M=GEK;R!R:6UT82!K;&%I9&$`3F]RZV1A;6D@=?YK;V1U;W1I(&QA:?!KX"!P
M<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4$=0(')A:W3@+@!.;W+K9&%M:2!P
M871I:W)I;G1I('!A<VER8?!Y=.`@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@
M=FEE\.!JX2!01U`@<F%K=.`N`$YO<NMD86UI(&%T:V]D=6]T:2!L86GP:^`@
M<')I=F%L;W1E('1U<NMT:2!V:67PX&KA(&ER('-L87!TX&KA(%!'4"!R86MT
M=7,L(&)E:2#^:6YO=&D@<VQA<'3@:N`@9G)A>N8N`$YO<NMD86UI('!A<VER
M8?!Y=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE\.!JX2!I<B!S;&%P
M=.!JX2!01U`@<F%K='5S+"!B96D@_FEN;W1I('-L87!TX&K@(&9R87KF+@!.
M;W+K9&%M:2!A=&MO9'5O=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@=FEE
M\.!JX2!I<B!S;&%P=.!JX2!3+TU)344@<F%K='5S+"!B96D@_FEN;W1I('-L
M87!TX&K@(&9R87KF+@!.;W+K9&%M:2!P87-I<F'P>71I(&QA:?!KX"!P<FEV
M86QO=&4@='5RZW1I('9I9?#@:N$@:7(@<VQA<'3@:N$@4R]-24U%(')A:W1U
M<RP@8F5I(/YI;F]T:2!S;&%P=.!JX"!F<F%ZYBX`3F]RZV1A;6D@=?YK;V1U
M;W1I(&QA:?!KX"!P<FEV86QO=&4@='5RZW1I('9I9?#@:N$@4R]-24U%(')A
M:W3@+@!!32!R;V1Y;6%S`$%-+U!-`$%022!)1`!!<&EE(/#A(')E9&%K=&]R
M:?@`07!I92XN+@!6:7-I\&MA:2!A<&'H:6]J90!6:7-I\&MA:2!P97(@=FED
M=7+A`%-I<W1E;6$@;F5T=7)I('1E:7-I^"!S=6MU<G1I(%9&4R!K871A;&]G
MX"X`4VES=&5M82!N971U<FD@=&5I<VGX('-U:W5R=&D@5D93(&9A:6S@+@!3
M;&%P=&'^;V1I<P!3X'-K86ET82!U_O!A;&1Y=&$N`$%P<VMA:71A`%-U:W5R
M=&D`4W5K=7)T:2!P;V=R=7#A`%-U:W5R=&D@<&]T96ES97,`0FQO:V\@X71E
M<G!I;6%S.@!3=6MU<G1I(&YA=6K@(&=R=7#F`%-U:W5R=&D@;F%U:F%S('1E
M:7-E<P!.875J;R!V87)T;W1O:F\@<W5K^W)I;6%S.@!0<FEDZW1I('-T=6QP
M96SA`$YA=6KX(&YA<FGX('!R:63K:FEM87,`4W5K=7)T:2!P;W+@`%!R:63K
M=&D@)7,@;65N:74@<')I92!-;WII;&]S(.%R86YK:?@@:G5O<W1O<P#!=')A
M=6MT:2#A(&%D<F5S^"!K;GEG96SF.@#!=')A=6MT:2#A(&UA;F\@861R97/X
M(&MN>6=E;.8Z`%-U:W5R=&D@=F%R=&]T;VK@`%9A<G1O=&]J^"!K^W)I;6%S
M(&GP:G5N9W1A<RX`061R97-A<P!!9')E<V%I`$%D;6EN:7-T<G5O=&D@+2!G
M86QI(&YU<W1A='ET:2!T96ES97,@:VET:65M<R!V87)T;W1O:F%M<P!686QD
M>6UA<P!"86YE<FEA:0!!9F=A;FES=&%N87,`06QB86YI:F$`06S^>7)A<P!0
M<F%V87)DZP!,>6=I=6]T:0!,>6=I879I;6%S.@!6:7-O<P!6:7-I('!R:7-I
M:G5N9^8@=F%R=&]T;VIA:0!6:7-O<R!G<G5PZW,`5FES;W,@=&5I<^MS`%9I
M<V]S(&ME='5R:6]S('!U<^MS`$QE:7-T:2!K96QE=.`@861R97/X`$QE:7-T
M:2!N875D;W1I('-U<OOP:75O=.`@<^!R8?#@/P!*874@96=Z:7-T=6]J80!!
M;'1E<FYA='EV=7,@24U34"!P<FES:6IU;F=I;6%S`$%L=&5R;F%T>79U<R!)
M35-0('-L87!T8?YO9&ES`$%L=&5R;F%T>79U<R!)35-0('9A<G1O=&]J;R!V
M87)D87,`06QT97)N871Y=G5S(&5L+B!P8?!T;R!A9')E<V%S`$%L=&5R;F%T
M>7;[<R#P86)L;VYA:0!!;'1E<FYA='EV=7,@=&5K<W1A<P!!;65R:6MO<R!3
M86UO80#!=F5DZW1E(&YE;&5I<W1I;N`@<F5I:_!MYBX`06YD;W)A`$%N9V]L
M80!!;F=I;&%I`$%N;VYI;6EN:7,@<')O>'D@<V5R=F5R:7,`071S86MY;6%S
M`$%N=&%R:W1I9&$`06YT:6=U82!I<B!"87)B=61A`$UO9'5L:7,`36]D=6QI
M<R!V96EK:6$@9V5R86DN`%!R:71A:6MY=&D@:7(@<&_P86MI86US`%!A='9I
M<G1I;G1I`$)A;&%N9&ES`$%R86)I\&MA("A7:6YD;W=S+3$R-38I`$%R8VAY
M=F\@9F%I;&\@9'ED:7,`07)C:'EV;R!F86EL;R!P879A9&EN:6UA<P!!<B!T
M:6MR86D@;F]R:71E(&GP=')I;G1I("5S(')E9VES=')A8VEJ;W,@<')A\'EM
MX#\`07)G96YT:6YA`$%R;>MN:6IA`$%R;>MN:?!K82`H05)-4T-)22TX*0!-
M96YA<P!!<G5B80!+<FES=&%U<R#^96YG:6UO(.$@9&%N9_@@<V%L80!!8W-I
M:2!M96YA<P!!>FEJ82]286UI;VIO('9A;F1E;GEN;R!R96=I;VYA<P!!<B!P
M<F'P>71I('!A='9I<G1I;G1I('!R;V9I;&%K=&EK;W,@=F5I:W-M=7,_`%!R
M:7-K>7)I;6\@<W1U;'!E;&EA:0!"86YD;W1E(&GP=')I;G1I(&YE96=Z:7-T
M=6]J86[H:>`@9W)U<.8N`$)A;F1O=&4@:?!T<FEN=&D@;F5E9WII<W1U;VIA
M;NAI87,@=&5I<V5S+@!"86YD;W1E(')E9&%G=6]T:2!N965G>FES='5O:F%N
MZ&EA<R!T96ES97,N`$)A;F1O=&4@<F5D86=U;W1I(&YE96=Z:7-T=6]J86YT
MX2!E;&5M96YTX"X`071R:6)U=&%I`%)U9W!J^W1I<P!!=7-T<F%L:6IA`$%U
M<W1R:6IA`$%U=&A?8WER<W%L.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0
M(&UO9'5L:7,N`$%U=&A?8WER=7,Z(&-Y<G5S(&YE='5R:2!R96EK:6%M^"!G
M86QI;7EB:?@N`$%U=&A?8WER=7,Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($E-
M05`@;6]D=6QI<RX`075T:%]F='`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($94
M4"!M;V1U;&ES+B!3=6MO;7!I;&EU;VMI=&4@4$A0('-U("TM96YA8FQE+69T
M<"X`075T:%]I;6%P.B!N97)A<W1A<R!R96EK86QI;F=A<R!)34%0(&UO9'5L
M:7,N`$%U=&A?:W)B-3H@;F5R87-T87,@<F5I:V%L:6YG87,@:W)B-2!M;V1U
M;&ES+@!!=71H7VQD87`Z(&YE<F%S=&%S(')E:6MA;&EN9V%S($Q$05`@;6]D
M=6QI<RX`075T:%]L9&%P.B!S=6MU<G1I('9A<G1O=&]JX"`E<R!N97!A=GEK
M;RX@4V5R=F5R:6\@<')A;F7P:6UA<SH@`$%U=&A?;&1A<#H@:?!T<FEN=&D@
M=F%R=&]T;VK@("5S(&YE<&%V>6MO`$%U=&A?;&1A<#H@871N875J:6YT:2!V
M87)T;W1O:N`@)7,@;F5P879Y:V\`075T:%]M8V%L.B!N97)A<W1A<R!R96EK
M86QI;F=A<R!-0T%,(&UO9'5L:7,N`$%U=&A?<VUB875T:#H@;F5R87-T87,@
M<F5I:V%L:6YG87,@<VUB875T:"!M;V1U;&ES+@!0<FES:6IU;F=T:2!N97!A
M=GEK;P!0<FES:6IU;F=T:2!N97!A=GEK;RX@)7,`4D%$2553('-E<G9E<FES
M(&YE;&5I9/YI82!A=71E;G1I9FEK=6]T:7,N`%!R:7-I:G5N9W1I('!R:64@
M1E10('-E<G9E<FEO(&YE<&%V>6MO+@!'86QI;6D@;&%U:V%I.@!!>F5R8F%I
M9/YA;F%S`$)/1D@@871S:7!R8?!Y;6%I`$9O;F%S`$9O;F\@<W!A;'9A`$YE
M=&5I<VEN9V%S(&ME<F)E<F]S('-L87!T8?YO9&ES+@!.971E:7-I;F=A<R!K
M97)B97)O<R!V87)T;W1O:F\@=F%R9&%S+@!"86AA;6%I`$)A:')E:6YA<P!"
M86QT:?!K82`H25-/+3@X-3DM,3,I`$)A9VQA9&7P87,`0F%R8F%D;W-A<P!0
M86=R+B!L:6YI:F]J90!"86QT87)U<VEJ80!"96QG:6IA`$)E;&EZ87,`0F5N
M:6YA<P!"97)M=61A:0!"=71A;F%S`$=I;71A9&EE;FES`$)L;VMO('!A<F%M
M971R86D`0FQO:V\@=&EP87,`4&%S=&]R:6YT:0!";VQI=FEJ80!!=/YY;6]S
M`$MR8?!T87,`2W)A\'1O('-T;W)U;6%S.@!+<F'P=&%I`$)O<VYI:F$@:7(@
M2&5R8V5G;W9I;F$`5FES;W,`0F]T<W9A;F$`07!AZ&EO:F4`0G5V970@<V%L
M80!"<F%Z:6QI:F$`0G)I=/@@26YD:6IO<R!V86YD96YY;F\@=&5R:71O:F$`
M0G)U;NMJ875S(&1A<G5S86QE;6%S`$)U;&=A<FEJ80!3=?YY;>MT87,@<^!R
M8?!A<P!"=7)K:6YA<R!&87-A<P!"=7)U;F1I:F$`5%93`$-20P!#4DP@<&%S
M:VER<W1Y;6\@<'5N:W1A:0!?0V5LZW,@;G5S=&%T>6UA:2XN+@!+86QE;F1O
M<FEU<P!286UU`$MA;6)O9/YA`$MA;65R^VYA<P!.979E:6MI82!A=71O;6%T
M:6YI<R!S;&%P=&'^;V3^:6\@<&%K96ET:6UA<RP@<W5S:7-I96MI=&4@<W4@
M861M:6YI<W1R871O<FEU;6DN`$YE9V%L:74@<')I<VEJ=6YG=&D@<')I92!)
M34%0('-E<G9E<FEO.B`E<P!+86YA9&$`073P875K=&D`073P875K=&D@<')O
M8FQE;6]S('!R86YE\&EMX`!.96=A;&EU(&GP=')I;G1I(&9A:6QO("(E<R(N
M`$YE9V%L:74@<F%S=&D@;&%I:VEN;VIO(&MA=&%L;V=O+@!.96=A;&EU(&%P
M9&]R;W1I("=T87)G971&:6QE)R!P87)A;65T<F\N`$YE9V%L:74@:?!T<FEN
M=&D@:V%T86QO9V\@(B5S(BX`3F5G86QI=2!I\'1R:6YT:2X@16=Z:7-T=6]J
M82`E9"!P;_!A:VEA:2X`3F5G86QI=2!P97)R^_!I=6]T:2X@P79E<W1A<R#A
M<F'P^"!S:V%IZ&EU<R!N97-U=&%M<&$@<W4@X7)A\/@@<VMA:>AI=6UI(&1U
M;VUE;O@@8F%ZZVIE+@!.96=A;&EU(&YU:W)E:7!T:2#^:6YU=.MS(.$@;G5R
M;V1Y=.`@;G5M97+A+@!+96EP=F5R9&ES`%!A=F%D:6YI;6%S`$MA=&5G;W)I
M:F]S`$MA:6UA;O@@<V%L;W,`36]B:6QU<R!T96QE9F]N87,`0V5LZW,@;G5S
M=&%T>6UA:0!487)P86D@8V5LZW-E.@!#96SK<R!N=7-T871Y;6%I`%1A<G!A
M:2!T87)P(&-E;&GX.@!-;V)I;'5S:7,@=&5L969O;F%S`$ME;'3X("A)4T\M
M.#@U.2TQ-"D`0V5N=')E`$-E;G1R:6[K<R!!9G)I:V]S(%)E<W!U8FQI:V$`
M0V5N=')I;NMS($5U<F]P;W,@*$E33RTX.#4Y+3(I`%-E<G1I9FEK871O(&1E
M=&%LZW,`4V5R=&EF:6MA=&\@=&5I<^MS`,AA9&%S`%!A:V5I<W1I`$K[<_@@
M=F%R9&\@:7(@861R97-O+"!K=7)I=6]S(&UA='ES(/YM;V[K<RP@<VMA:71A
M;G1Y<R!I<B!A='-A:VENZVIA;G1Y<R#A($K[<_@@;&%I\&MU<RP@:V5I=&EM
M87,N`%-I;6)O;&ES`%!A7W1I:W)I;G1I(&YU;W)O9.`N+BX`R&ELZP!+:6YI
M:F$`2VEN:65T:?!K82!P87!R87-T82`H1T(R,S$R*0!+:6YI971I\&MA('1R
M861I8VENZR`H0FEG-2D`4&%S:7)I;FMI=&4@<VQA<'1A_F]DX0!087-I<FEN
M:VET92!V87)T;W1O:F\@=F%R9.``4&%S:7)I;FMI=&4@:V%I<"!V86EZ9'5O
M=&D@9&%T87,Z`%!A<VER:6YK:71E('-U<OOP:75O=&\@<^!R8?!O('-T:6QI
M^`!+86SK9/@@<V%L80!+;&%SZW,@)7,@;NMR82X`1VEE9')A`$GP=')I;G1I
M($U3($]F9FEC92#^>6UE<P!687)T;W1O:F\@9'5O;65N^"!V86QY;6%S.B`E
M<P!)\'9A;'ET:2!V87)T;W1O:F\@9'5O;65N:7,`2?!V86QY=&D@=F%R=&]T
M;VIO(&1U;VUE;FES`%3F<W1I`$-L:6-K871E;&P@<&5R($A45%``5?YD87)Y
M=&D@;&%N9^``1&5B97-U;W1A`$1E8F5S=6]T80!+;VMO<V\@*$MY;&EN9V\I
M('-A;&]S`%1U\.AI^"!C96QI^"!K<F'P=/@@<F]D>6UA<P!+;VQU;6)I:F$`
M4W!A;'9A`%!A<VER:6YK:71E('-P86QVX`!3<&%L=F]S('!A<VER:6YK:6UA
M<P!3='5L<&5L:6%I.@!3='5L<&5L:?@@<&%V861I;FEM86D`2V]M:6MS86D`
M2V]M86YD80!+;VUA;F1I;NL@96EL=73K`$MO;65N=&%R87,`5F%R9&%S+W!A
M=F%R9.L`2V]M;W)A:0!+;VUP86YI:F$`2V]M<&EU=&5R:6%I`%/@;'EG;W,`
M3G5S=&%T>6WX('!A:V5I=&EM86D`2V]N9FEG^W)U;W1I("5S`%-L87!T8?YO
M9&ES(&1A<B!K87)TX`!+;VYG87,`1&5M;VMR871I;NL@2V]N9V\@4F5S<'5B
M;&EK80!0<FES:6IU;F=T:2!N97!A=GEK;RX`4')I<VEJ=6YG=&D@;F5P879Y
M:V\Z(`!0<FES:6IU;F=T:2!P<FEE('9I9?#X:O@@<F%K=/@@<V5R=F5R:6\@
M;F5P879Y:V\N`%!R:7-I:G5N9W1I('!R:64@=FEE\/AJ^"!R86MT^"!S97)V
M97)I;R!N97!A=GEK;RP@;F5S.B`E<R`H)7,I`%!R:7-I:G5N9W1I('!R:64@
M1E10('-E<G9E<FEO(&YE<&%V>6MO+@!+;VYK86MT86D@<^MK;6EN9V%I(.%T
M<F%U:W1I(.$@2OMS^"!A9')E<_@@:VYY9V5LY@!4YG-T:0!+=6MO('-A;&]S
M`$QA:6WK<R#^:6YU=.MS`$MO<&EJ=6]T:0!+;W!I:G5O=&D@<&%S:7)I;FMI
M;>``2V]S=&$@4FEK80!$<F%M8FQI;R!+875L;R!+<F%N=&%S`$YE<&%V>6MO
M('7^:V]D=6]T:2!01U`@;&%I\&MO+@!.97!A=GEK;R!P87-I<F'P>71I(%!'
M4"!L86GP:V\N`$YE<&%V>6MO('7^:V]D=6]T:2!3+TU)344@;&%I\&MO+@!.
M97!A=GEK;R!P87-I<F'P>71I(%,O34E-12!L86GP:V\N`$YE<&%V>6MO('!R
M:63K=&D@:V]N=&%K=&\N("5S`$YE<&%V>6MO(&%U=&5N=&EF:6MU;W1I<R#A
M($Q$05`@<V5R=F5RX2X`3F5P879Y:V\@<&%T:6MR:6YT:2!B86QA;G-O+B`E
M<P!.97!A=GEK;R!S=6MU<G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<P!.
M97!A=GEK;R!A=&MO9'5O=&D@4$=0(&1U;VUE;O@N`$YE<&%V>6MO(&%T:V]D
M=6]T:2!3+TU)344@9'5O;65N^"X`3F5P879Y:V\@:?!T<FEN=&D@:V]N=&%K
M=&\N("5S`$YE<&%V>6MO(&GP=')I;G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O
M+B`E<P!.97!A=GEK;R!N=7-T871Y=&D@9V%VZVIO(&5L+B!P8?!T;R!A9')E
M<V\N`%!A=GEK;R!G875T:2!V:7-O<R!A9')E<_@@:VYY9V5LZW,N`$YE<&%V
M>6MO(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!SX')A\&\N`$YE<&%V>6MO
M(&=A=71I('9I<V\@9&ES=')I8G5C:6IO<R!SX')A\/@@<^!R8?!O+@!.97!A
M=GEK;R!G875T:2!V:67P;VIO(')A:W1O(&GP(')A:W3X('-E<G9E<FEO+@!.
M97!A=GEK;R!A=&ED87)Y=&D@)7,N`$YE<&%V>6MO(&%T:61A<GET:2!-86EN
M=&5N86YC95]487-K(&UO9'5L:6\@)7,`3F5P879Y:V\@<VMA:71Y=&D@)7,N
M`$YE<&%V>6MO('!A:V5I<W1I('-L87!T8?YO9/YI;R#P:6%M('9A<G1O=&]J
M=6DN($MA:2!K=7)I(&%R8F$@=FES82!I;F9O<FUA8VEJ82!Y<F$@;F5T:6MS
M;&DN(%!A8F%N9'EK:71E(&1A<B!K87)TX"!A<F)A('-U<VES:65K:71E('-U
M('-A=F\@861M:6YI<W1R871O<FEU;6D@:F5I9W4@<F5I:V%L:6YG82!P86=A
M;&)A+@!.97!A=GEK;R!G875T:2!!0TP`3F5P879Y:V\@9V%U=&D@861R97/X
M(&MN>6=E;.MS+B`E<P!.97!A=GEK;R!G875T:2!D:7-T<FEB=6-I:F]S('/@
M<F'P;RX@)7,`3F5P879Y:V\@9V%U=&D@9&ES=')I8G5C:6IO<R!SX')A\/@N
M("5S`$YE<&%V>6MO(&YU<W1A='ET:2!S97)V97)I;R!G86QI;7EB:?@`3F5P
M879Y:V\@871K96ES=&D@;G5S=&%T>6WX+@!.97!A=GEK;R!I\'-A=6=O=&D@
M)7,@;G5S=&%T>6WX+@!.97!A=GEK;R!P861A<GET:2!A='-A<F=I;NMS(&YU
M<W1A='EM^"!K;W!I:F]S+@!.97!A=GEK;R!P86EE\&MA($Q$05`@<V5R=F5R
M>6IE+@!.97!A=GEK;R!A=&YA=6II;G1I(&MO;G1A:W1O+B`E<P!.97!A=GEK
M;R!A=&YA=6II;G1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O+B`E<P!.97!A=GEK
M;R!R87-T:2!-;WII;&]S(.%R86YK:?@@:G5O<W1O<RX@P7-I=&EK:6YK:71E
M+"!K860@:FD@871I9&%R>71A+@!2:6)O=&%S('1E:W-T87,`5F%L<W1Y8NL`
M2W5R<V%I`%-U:W5R=&D`4W5K=7)T:2!N=6]R;V3@`%-U:W5R=&D@;F%U:N`@
M87!R8?#@`%-U:W5R=&D@<&%K871A;&]G:75S`%-A=FEN:6YK;R!T96ESZW,`
M2W)E9&ET:6[K<R!K;W)T96SK<R!N=6UE<FES`$MR;V%T:6IA`$MU8F$`1&%B
M87)T:6YI<R!L86EK87,`T&EU;R!M971U(%523"!Y<F$`1&%B87)T:6[K<R!O
M<F\@<^!L>6=O<P!$86)A<G1I;NMS('/@;'EG;W,Z(`!$86)A<G1I;FES('-T
M:6QI=7,`5F5I:W-M^"P@871L:65K86WX('!R:7-I:G5N9W5S('!R:64@)7,L
M(&YU<W1A='EM87,N`%!E<FME;'1I`%!E<FME;'1I('!A<VER:6YK:6W@`$MI
M<')A<P!+:7)I;&EC82`H2T])."U2*0!+:7)I;&EC82`H5VEN9&]W<RTQ,C4Q
M*0!+:7)I;&EC82]5:W)A:6YI971I\&MA("A+3TDX+54I`,AE:VEJ;W,@4F5S
M<'5B;&EK80!$1`!+87-D:65N`$1U;VUE;O@@;65D_FEO(&YA<O!Y:VSK`$1A
M=&$`1V%U=&$`1&%T;W,@<&%S:7)I;FMI;6%S`$1I96YA`$GP=')I;G1I(%]S
M='5L<&5LX0!'<G5O9&ES`$1E\&EM=&%I;FEA:2!S:V%IZ&EA:0!3=6UA_FEN
M=&D@871I=')A=6MI;>``4W1A;F1A<G1I;NL@<W!A;'9A`%-T86YD87)T:6YI
M<R!A<')A\&%S`$%P:6)RZ_YI;6%I`$GP=')I;G1I`$GP=')I;G1I(&=R=7#F
M`$GP=')I;G1I('1E:7/F`%9I<VGP:V%I(&GP=')I;G1I(&QA:?!K=7,`2?!T
M<FEN=&D@8V5LY@!)\'1R:6YT:2!S='5L<&5LX0!)\'1R:6YT:2!E9WII<W1U
M;VIA;G3A(&%L=&5R;F%T>7;X(/!A8FQO;N``2?!T<FEN=&D@96EL=73F`$GP
M=')I;G1I('!A<VER:6YK=.`@87!R8?#@`$GP=')I;G1I(/#A('-T=6QP96SA
M`$GP=')I;G1I(/!IX"!E:6QU=.8`4')I<W1A='EM;R!L86EK87,`1&%N:6IA
M`%!R;V)L96UO<R!A<')A\'EM87,`07!R8?!Y;6%S`$1E=&%L:6%U("AT86EP
M('!A="#^:?MRZVMI=&4@2&]R9&4@;&]G(&9A:6QE*3H`061M:6YI<W1R871O
M<FEU:2!I\'-I^'-T87,@9&5T86QU<R!A<')A\'EM87,N`%9Y<W1Y;6%S`$1R
MZV=N=6UA<P!$<NMG;G5M87,@<&%S:W5T:6[F('9A;&%N9.`Z(`!$<NMG;G5M
M87,Z(`!+<GEP=&ES(&GP(&MA:7+K<R#A(&1E\&ENY@!+<GEP=&ES(&GP(&1E
M\&ENZW,@X2!K86ERY@!+871A;&]G87,`4F]D>71I(#(T+6GX('9A;"X@9F]R
M;6%TX#\`5F%I>F1A=FEM;R!N=7-T871Y;6%I`%)O9'ET:2!P<F]G<F]NYB`H
M5$%&*0!686EZ9&%V:6UO(&9O<FUA=&%S`$QA:?!K;R!P<FES=&%T>6UO('!R
M86YE\&EM86D`1/YI8G5T:7,`3F5T<FEN=&D`3F5S:6MR96EP:VET92!T:65S
M:6]G:6%I(.$@;6%I;G1E;F%N8V4N<&AP`$%R('!I<FUA<R#A<F'P87,@>7)A
M(&QA=6MO('9A<F1A:3\`1&]M:6YI:V$`1&]M:6YI:V]S(%)E<W!U8FQI:V$`
M071S:7-I^'-T:0!!='-I<VGX<W1I("5S`$%T<VES:?AS=&D@<W5G96YE<G5O
M='5S(&YU<W1A='EM=7,@:V%I<"!02%`@<VMR:7!TX"X`2?!S:7-K;&5I9/YI
M86YT:7,@<^!R8?!A<P!686ES=&%I`$5L+B!P8?!T;R!A9')E<V%S`$524@!%
M:W9A9&]R87,`2V5I<W1I`$ME:7-T:2!B;&]K;R!P87)A;65T<G5S`%)E9&%G
M=6]T:2!G<G5PY@!2961A9W5O=&D@=&5I<V5S`%)E9&%G=6]T:2!T96ES97,`
M)7,@=&5I<VGX(')E9&%G879I;6%S`$ME:7-T:2!N=7-T871Y;75S.@`E<R!T
M96ES:?@@<F5D86=A=FEM87,`56=D>6UA<P!%9VEP=&%S`%-A;'9A9&]R87,`
M16QE;65N=&%S+BXN`$5M`$5L+B!P8?!T87,`16PN('!A\'1O(&%D<F5S87,`
M16PN('!A\'1O(&%D<F5S86D@='5R:2!S=71A<'1I+@!%;"X@<&'P=&\@861R
M97-A<R!S=2!P871V:7)T:6YI;74`T'EP<V5NZVSK<P#>:6YU=.L@='7PZ&EA
M+@!297IU;'1A=&%S('1U\.AI87,N`$YE;G5R;V3K=&4@<&%I9?!K;W,@=&5R
M;6EN^`!,96ES=&D@=&5K<W1E(.%T97)P=&D@<&%V96EK<VSK;&EU<R!I\"!.
M=6]T<F%U:_@@9V%L97)I:F]S/P#!:G5N9W1I(&1E\&EN:6]J;R!P96SK<R!M
M>6=T=6MO(&UE;FEU/P!'86QI;FEA:2!M971A:0!)\'!LZW-T:2!R961A:W1O
M<FGX`,%R8?!Y:VET92!K;&%U<VEMX"P@:W5R:7,@:G5M<R!B=7,@=?YD=6]T
M87,@:F5I9W4@<&%M:7+P:71E('-A=F\@<VQA<'1A_F]DX2P@<'9Z+CH@)VMO
M:W,@>7)A($K[<_@@9WEV^VYO('9A<F1A<S\G.@#!=F5S:VET92!P879E:6MS
M;.ML:6\@55),`$5K=F%T;W)I;NL@1W9I;NMJ80!%<FET<NMJ80!+;&%I9&$`
M2VQA:61A(&QA:?!K92X`17-T:6IA`$5T:6]P:6IA`$5T;FENZW,`175R;W!A
M`$MA<R`Q-2!M:6YUZ&GX`$MA<R`R(&UI;G5T97,`2V%S(#,P('-E:W5N9/YI
M^`!+87,@-2!M:6YU=&5S`$MI96MV:65N;R!P<FES:6IU;F=I;6\@;65T=0!+
M87,@<'5S=F%L86YDX0!+87,@;6EN=73F`%!A=GEZ9/YI=6DZ`%9Y:V1Y=&D`
M2?!S:VQE:7-T:0!296EK86QI;F=A<R`G*2<`4F5I:V%L:6YG87,@_F]D:7,@
M87)B82!K86)U=.MS92#A<F'P>71A<R!P86EE\&MO<R!K<FET97)I:G5S`$=A
M;&EO:FEM;R!D871A`$5K<W!O;F5N=.L`5&5K<W1O('-P86QV80!.=7-T871Y
M;?@@<VEU;G1I;6%S('!E<B!&5%`N`$ML86ED82!N=7-K86ET86YT(&YU<W1A
M='EM=7,N`$YE<&%V>6MO('!R:7-I:G5N9W1I('!R:64@3$1!4"!S97)V97)I
M;RX`3F5P879Y:V\@<')I<VEJ=6YG=&D@<')I92!334(@<V5R=F5R:6\N`$YE
M<&%V>6MO(&YU:V]P:6IU;W1I(&GP("(E<R(N`$YE<&%V>6MO(&YU:V]P:6IU
M;W1I(.$@(B5S(BX`3F5P879Y:V\@<W5K=7)T:2!N875J;R!305-,(')Y\&EO
M+@!.97!A=GEK;R!P97)K96QT:2#A("(E<R(N`-!V96QN=7,`1F]L:VQA;F3X
M('-A;&]S("A-86QV:6YA:2D`1F%R97+X('-A;&]S`$9A:W-A<P!687-A<FES
M`$%T<F]D;R!L>6<`071R;V1O(&QY9SH@`%1R=6UP86QA:6MI<R!L:65T=7,`
M1FED_FES`$9A:6SX('-K86GH:75S.B`E<R!F86EL87,`1F%I;/@@<VMA:>AI
M=7,Z("5S(&9A:6QA:2CX*0!&86EL^"!T=F%R:WEM87,`1F%I;&\@<&%V861I
M;FEM87,`1F%I;&\@<&%S:7)I;FMI;6%S`$9A:6QO('-I=6YT:6UA<P!.87+P
M>6MLZR!N97!A;&%I:V\@9F%I;/@@<VEU;G1I;6\N`$9I;'1R86D`4W5O;6EJ
M80!0:7)M;VII('!U<^L`4&ER;6%S:7,@:V5T=FER=&ES`$YU<W1A='ET87,@
M:V]E9FEC:65N=&%S`$%T=FER:_#H:6%S`$GP9.MS='EM87,`4OMK87,`2V%T
M86QO9V%S("5S(&YE96=Z:7-T=6]J80!496MS=&\@<W!A;'9A`$UA:7-T87,`
M3F%R\'EK;.MM<RP@:W5R:6]S(&YE<&%L86EK;R!P879E:6MS;.ML:?@`3W+X
M('!R;V=N;WKK("A4048I`$]R^"!P<F]G;F]ZZW,@87!I;71I<R`HX7-I9.MM
MZVMI=&4L(&MA9"#P:2!F=6YK8VEJ82!G<F'^:6YA(&ER(&1I96YO<R!I<B!N
M86MT:65S('!R;V=N;WKF.R!P97(@9&ED96QI<R!S:V%IZ&EU<R!G86QI('-U
M9&%R:WET:2!D:7IA:6[@*0!086UI<O!O=&4@<V%V;R!S;&%P=&'^;V3A/P!&
M;W)M;W,`1G)A>NL`1G)A>FGX('1I<&%S`$9R87KK<P!&<F%ZZW,@,@!$:7-K
M=7-I:F]S`%!E<G-I=6YT:6UA:0!096YK+@!+<F'P=&ENZW,`4')A;F/[>FEJ
M80!0<F%N8_MZ:6IA+"!-971R;W!O;&ES`%!R86YC^WII:F]S($=V:6%N80!0
M<F%N8_MZ:6IO<R!0;VQI;F5Z:6IA`%!R86YC^WII:F]S('!I971I;NMS('1E
M<FET;W)I:F]S`$YU;P!.=6\@`%!I;&YA<R!A<')A\'EM87,`4&EL;F%T:7,`
M4&EL;F%S('9A<F1A<P!'86)O;F%S`$=A;&5R:6IA(&GP(&MU<FEO<R!I\"!K
M=7)I;W,@8G5S(')O9&]M87,@<&%V96EK<VSK;&ES`$=A;&5R:6IA.@!'86UB
M:6IA`$=E;F5R=6]T:2`E<R!N=7-T871Y;75S`%-U9V5N97)U;W1A<R!K;V1A
M<P!'<G5Z:6IA`%9O:VEE=&EJ80!'86YA`$=I8G)A;'1A<F%S`%9A<F1A<P!2
M;V1Y=&D`1V%D96QI<P!';V]G;&4@<&%I9?!K80!.97-P86QV;W1A<P!'<F%I
M:VEJ80!'<F%I:VGP:V$@*$E33RTX.#4Y+3<I`$=R96YL86YD:6IA`$=R96YA
M9&$`1W)U<&GX(&%D;6EN:7-T<F%V:6UA<P!'<G5PZW,@=F%R9&%S('1U<FD@
M8OMT:2!N971U\.AI87,`1W)U<.MS`$=V861E;'5PZP!'=6%M80!'=F%T96UA
M;&$`1V5R;G-I<P!3=F7H:?@@=&5I<^MS`%-V9>AI^"!K;GEG80!'=FENZVIA
M`$)I<W-A=2U'=FENZVIA`$=A:F%N80!(5$U,`$A434Q!<F5A(&YE9V%L:2!I
M\'1R:6YT:2!P87-K=71I;NMS(&-E;.MS(&5I;'5TZVIE+@!(5$U,07)E82!N
M96=A;&D@:?!R:6YT:2!P87-K=71I;FEO('-T=6QP96QI;R!L96YT96SK:F4N
M`$A434Q!<F5A(&YE9V%L:2!I\'1R:6YT:2!P87-K=71I;NMS(&5I;'5TZW,@
M;&5N=&5LZVIE+@!296EK86QI;F=A($A45%`@875T96YT:69I:V%C:6IA+@!(
M86ET:7,`2&%S:"U!;&=O<FET;6%S`$UI9VQA`$%N=')A\'3K`$AE<F1O('-A
M;&$@:7(@36%K9&]N86QD;R!S86QO<P!(96)R86KX("A)4T\M.#@U.2TX+4DI
M`$%U:_!T:7,`4&%G86QB80!2961A:W1O<FEA=7,@;F%U9&]J:6UO<VD@<&%G
M86QB80!086=A;&)I;FEN:V%S`$AE;6ES9F5R80#0=&%I(.AI82!Y<F$@9F%I
M;&\@<')A9/YI83H`4W9A<F)U`%]0;W)T86QA<P#0=F5N=&%S:7,@4V]S=&%S
M("A6871I:V%N;R!V86QS=&EJ82D`4&]R=&%L87,`3F%M^"!A9')E<V%S`$YA
M;?@@=&5L969O;F%S`$AO;F3[<F%S`$AO;FMO;F=A<P!0;W)T86QA<P!(;W)D
M92]+;VQA8CH@;F5T96ES:6YG:2`E<R!834P@9'5O;65N>7,@_FEN=73K:F4@
M)7,`2&]R9&4O2V]L86(Z(&]B:F5K=&\@)7,@;F5A=&ET:6YK82!J;VMI82#^
M:6YU=.L`2&]R9&4O2V]L86(Z(&]B:F5K=&\@=&EP87,@)7,@;F5R87-T87,@
M_FEN=73K:F4@)7,`2&]R9&4O2V]L86(Z("5S("(E<R(@<^MK;6EN86D@:?!T
M<FEN=&$`2&]R9&4O2V]L86(Z(&EN=&5G<F%C:6IO<R!V87)I:VQI=6MU:2!R
M96EK86QI;F=A<R`G9&]M>&UL)R!02%`@;6]D=6QI<P!(;W)D92]+;VQA8CH@
M;F5P879Y:V\@<W5K=7)T:2!N875J;R!834P@;65D_FEO(&]B:F5K='5I("5S
M`$AO<F1E+TMO;&%B.B!N97!A=GEK;R!I\'1R:6YT:2`E<R`B)7,B.B`E<P!(
M;W)D92]+;VQA8CH@;F5P879Y:V\@9V%U=&D@34E-12!)1"!D86QI86D@)7,@
M=&EP;P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O;FEZ=6]T:2`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@;F5P879Y:V\@<W5S:6YC:')O;FEZ
M=6]T:2!E;&5M96YT^#H@)7,`2&]R9&4O2V]L86(Z(&YE_FEN;VUA<R!E;&5M
M96YT87,@(B5S(@!(;W)I>F]N=&%L:2!L:6YI:F$`2&]R:7IO;G1A;'5S('1A
M<G!A<P!(;W)I>F]N=&%L:6%I.@!+86EP(.AI82!P871E:V]T93\@*%!R86YE
M\&MI=&4A*0!+:65K('-T=6QP96QI^"!N;W)I=&4@<W5J=6YG=&D_`$MI96L@
M;&%U:_@@*'-T=6QP96QI^"D@=&5N('ER83\`2VEE:R!E:6QUZ&GX(&YO<FET
M92!S=6IU;F=T:3\`1'+K9VYU;6%S`$1RZV=N=6UA<SH@`$IU;6]R97-K;W,`
M5F5N9W)I:F$`3F5P879Y:V\@<W5K=7)T:2!)34%0('!A\'1O(&3K_G5TZW,Z
M("5S`$YE<&%V>6MO(&GP=')I;G1I($E-05`@<&'P=&\@9.O^=73K<SH@)7,`
M3F5P879Y:V\@;G5S=&%T>71I($E-05`@<&'P=&\@9.O^=73K<R!D>63^:6\Z
M("5S`$E0(&%D<F5S87,`3F5P879Y:V\@9V%U=&D@25`@861R97-O+@!)4"!A
M9')E<V%S(&YE=&5I<VEN9V%M92!#2412(&)L;VME+@!)4"!U_G)A:VEN=&%S
M+@!?P71E<G!T:2!E:6QU=.8@=FER\'5J90!)<VQA;F1I:F$`5&EK('!I:W1O
M9W)A;6]S`%!I:W1O9W)A;6]S('-U('1E:W-T=0!!<')A\&\@<&%V861I;FEM
M87,Z`$IE:2!N96=A;&ET92!P97)S:V%I='ET:2#P:6\@;&%I\&MO+"`E<RX`
M2F5I9W4@;6%T;W1E(/!IX"#^:6YU=.8@=FEE=&]J('!A=F5I:W-LZVQI;RP@
M:W5RX2!N;W)I=&4@X6ME;'1I+"!T86D@2OMS^"!N87+P>6MLZR!N96=A;&D@
M:F\@871V86EZ9'5O=&DN`%!A=F5I:W-LZVQI;R!P97+^:?MR80!0879E:6MS
M;.ML:6\@55),`%!A=F5I:W-LZVQI;R!54DPZ`%!A=F5I:W-LZVQI<R!I\"!G
M86QE<FEJ;W,`4&%V96EK<VSK;&ES(&GP(&=A;&5R:6IO<SH`4&%V96EK<VSK
M;&EO(.%KZVQI;6%S`%9A:7ID86D`P6OK;&EM87,L("5D(/YI;F=S;FES`$QA
M=6MA<R#A:V5L=&%S.B`E<P#!:V5L=&D@;&%U:V%I.@#!7W1E<G!T:2!E:6QU
M=.8@87!AZ&EO:F4`3F5T96ES:6YG87,@=F5I:W-M;R!K;V1A<RX`3F5T96ES
M:6YG87,@=F%R=&]T;VIO('9A<F1A<R!I<B]A<F)A('-L87!T8?YO9&ES+@!.
M96ET96ES:6YG87,@=F%R=&]T;VIO('9A<F1A<R!A<F)A(&%L=&5R;F%T>79U
M<R!E;"X@<&'P=&\@861R97-A<RX@0F%N9'EK:71E(&1A<B!K87)TX"!A<F)A
M('-U<VES:65K:71E('-U('-A=F\@861M:6YI<W1R871O<FEU;6D@:F5I9W4@
M<F5I:V%L:6YG82!T;VQE<V[K('!A9V%L8F$N`%!A9&ED:6YT:2!A=&ET<F%U
M:VEMX`!);F1I:F$`26YD:79I9'5A;/MS('9A<G1O=&]J86D`26YD;VYE>FEJ
M80!);F9O<FUA8VEJ80!);F9O<FUA8VEJ80#!=')A=6MT:2!S='5L<&5LX2!?
M9&7P:6[K:F4`P71E<G!T:2!P879E:6MS;.MLX0#!=&5R<'1I(&QE;G1E;.8`
MP71E<G!T:2!N=6]R;V3@`,%T97)P=&D@<W1U;'!E;.$@7VMA:7+K:F4`P71E
M<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@9&7P:6[K:F4`
MP71E<G!T:2!N875JX"!S='5L<&5LX2!E<V%M;R!S='5L<&5L:6\@:V%I<NMJ
M90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!A<&'H:6]J
M90#!=&5R<'1I(&YA=6K@(&5I;'5TYB!E<V%M;W,@96EL=73K<R!V:7+P=6IE
M`,%T97)P=&D@<&%R86=R86;@(&5L96UE;G1O(&%P8>AI;VIE`,%T97)P=&D@
M<&%R86=R86?@(&5L96UE;G1O('9I<O!U:F4`P71E<G!T:2!A;'1E<FYA='EV
M^"#P86)L;V[@`,%R8?!Y:VET92!E;"X@<&'P=&\@861R97/@+"#A(&MU<N$@
M;F]R:71E(&=A=71I(&YA=6K@('-L87!T8?YO9.$Z`,%T97)P=&D@8V5LYB!P
M;R!T;P#!=&5R<'1I(&-E;.8@<')I9?`@=&%I`,%T97)P=&D@<W1U;'!E;.$@
M9&7P:6[K:F4`P71E<G!T:2!S='5L<&5LX2!K86ERZVIE`,%T97)P=&D@;&%I
M\&MU<P#!=&5R<'1I('!A<F%G<F%FX"!P;R!T;P#!=&5R<'1I('!A<F%G<F%F
MX"!P<FEE\"!T86D`P71E<G!T:2!E:6QU=.8@<&\@=&\`P71E<G!T:2!E:6QU
M=.8@<')I9?`@=&%I`,%R8?!Y:VET92!R96EK:6%MX"!A='-A:WEMX"#A(&ML
M875S:6W@('9I<O!U:F4Z`,%T97)P=&DO<F5D86=U;W1I('!A=F5I:W-LZVSA
M`,%T97)P=&DO4F5D86=U;W1I(&YU;W)O9.``1&ES=')I8G5C:6IO<R!SX')A
M\'5I(&YU<VGX<W1I(&YE=?YT96YK82!K<F5D:71O+@!.977^=&5N:V$@:W)E
M9&ET;RX`4VMA:>AI=7,`4VMA:>AI^"!SX')A\&%S`$YE=&5I<VEN9V%S(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+@!.971E:7-I;F=A<R!M;V1U;&ES+@!.
M971E:7-I;F=A<R!)1"X`P79E<W1I(&YE=&5I<VEN9VD@9'5O;65N>7,N`$YE
M=&5I<VEN9V%S(&%D<F5S87,N`$YE=&5I<VEN9V%S(&9A:6QO(&9O<FUA=&%S
M`$YE=&5I<VEN9V%S(&US9U]T>7!E+@!.971E:7-I;F=A<R!A<F)A(&[K<F$@
M87!I7VED+@!087)A;65T<F%I(&YE=&5I<VEN9VD@87)B82!J^"!NZW)A+@!.
M971E:7-I;F=O<R!P879E;&1I;6]S('1E:7/K<RX`3F5T96ES:6YG87,@<')O
M=&]K;VQA<RX`3F5T96ES:6YG87,@;V)J96MT87,`3F5T96ES:6YG87,@<VEU
M;G3K:F\@861R97-A<RX`3F5T96ES:6YG:2!U;FEK;V1O(&1U;VUE;GES+@!)
M;G9E;G1O<FEU<P!)<VQA;6GP:V$@27)A;F\@4F5S<'5B;&EK80!)<F%K87,`
M06ER:6IA`$UE;F\@<V%L80!)>F]L:75O=&]S(%0M875D<F]S`$EZ<F%E;&ES
M`$GP9&%VZVIA<P!+=7)S>79A<P!)=&%L:6IA`$IA;6%I:V$`4V%U<VES`$IA
M<&]N:6IA`$IA<&]N:?!K82`H25-/+3(P,C(M2E`I`$3^97)S:7,`2F]R9&%N
M:6IA`$QI97!A`$)I<OYE;&ES`%!I;&YA:0!,>6=I=6]T:2!C96YT<F4`3'EG
M=6]T:2!P:6QN86D`3'EG:75O=&D@:V%I<NMJ90!,>6=I=6]T:2!D9?!I;NMJ
M90!+87IA:W-T86YA<P!)\'-A=6=O=&D@;W)I9VEN86S@/P!+96YI:F$`3F5P
M879Y:V\@<')I<VEJ=6YG=&D@<')I92!+97)B97)O<R!S97)V97)I;RX`0G)A
M;F1U;VQI;R!N875J;VMA:0!286MT;R!K^W)I;6%S`%)A:W1O(&%T<W!A=61A
M<P!286MT;R!I;&=I<P!286MT;R!T:7!A<P!286MT;R!P86YA=61O:FEM87,`
M4F%K=&%S(&IA=2!Y<F$@=FEE\/AJ^"!R86MT^"!S97)V97)Y:F4N`%9A:6MA
M:0!+:7)I8F%T:7,`1&5M;VMR871I;NL@2V]RZVIO<R!,:6%U9&EE<R!297-P
M=6)L:6MA`$MO<NMJ;W,@4F5S<'5B;&EK80!+;W+K:FEE=&GP:V$@*$550RU+
M4BD`2W5V96ET87,`2VER9VEZ:6IA`%])\&3K<W1Y;6%S`$MA;&)A`$QA;W-O
M($1E;6]K<F%T:6[K($QI875D:65S(%)E<W!U8FQI:V$`06YT<F$@<'5SZP!0
M87-K=71I;FES(&ME='9I<G1I<P!!=&YA=6II;G1A.@!087-K=71I;FES('!R
M:7-I:G5N9VEM87,Z("5S`%!A<VMU=&EN:7,@<')I<VEJ=6YG:6UA<SH@)7,@
M:?`@861R97-O("5S`%!R:7-I:G5N9^MT92!P:7)MX"!K87)TX`!,871V:6IA
M`%1E:7/K`$GP9.MS='EM87,`2F5I9W4@;F5N;W)I=&4@;F5N875D;W1I(&MR
M8?!T^"P@<&%L:6MI=&4@='7PZ&G@`$QI8F%N87,`2V%I<NMJ90!+86ER:6]J
M:2!A;G1R8?!TZP!+86ER:6]S:6]S(')E:6OP;>MS`$QE<V]T87,`3&EB97)I
M:F$`3&EB:6IO<R!!<F%B^"!%;7ER871A:0!,:6-H=&5N\'1E:6YA<P!3;75L
M:W5S(&QI971U<P!.961I9&5L:7,@;&EE='5S`$YE9&ED96QI<R!L:65T=7,@
M<GET90!.961I9&5L:7,@;&EE='5S('9A:V%R90!.961I9&5LZR!L:?MT:7,`
M3F5D:61E;&ES(&QI971U<R!S=2!P97)K^VYI:F$`3F5D:61E;&ES('-N:65G
M87,`3F5D:61E;.L@\&QA<&1R:6)A`$QI;65R:6MA<P!.=6]R;V1A`$YU;W)O
M9&$@X3H`4&%D87)Y=&D@96PN('!A\'1O(&%D<F5SX"!N=6]R;V1A(.$@;&%I
M\&MO(')A\'EM;R!P=7-L87#A`$YU;W)O9&]S`$QI;G5X(&QA:6WK<R#^:6YU
M=.MS`%)O9'ET:2`M('9A<G1O=&]J87,@9V%L:2!M871Y=&D@:V%T86QO9V\@
M='5R:6[A`%)O9'ET:2!D=6]M96[X(&)A>FGX('/@<F'PX`!2;V1Y=&D@<&%G
M86QB;W,@=&5M87,`4F]D>71I(&QE;G1E;&GX('/@<F'PX`!+;VYF97)E;F-I
M:F]S(&%R8VAY=F%S`$MO;F9E<F5N8VEJ;W,@<&%G86QB80!+;VYF97)E;F-I
M:F]S($E$`$MO;F9E<F5N8VEJ;W,@<V%V:6YI;FMA<P!28?!Y=&D@X2!K;VYF
M97)E;F-I:N``4')I<VEJ=6YG=&D@<')I92!K;VYF97)E;F-I:F]S`$%T<VEJ
M=6YG=&D@;G5O(&MO;F9E<F5N8VEJ;W,`5F%R=&]T;VKX('/@<F'P87,@=?YD
M<F%U<W1A<RX`3&ET97)A=/MR80!,:65T=79A`$MR875N82XN+@!6:65T:6YI
M<R!L86EK87,Z(`!,;VMA;.L@:7(@;&%I:V%S`%9I971A`%!R:7-I:G5N9W1I
M`$%T<VEJ=6YG=&D`4')I<VEJ=6YG:6UO(&1A<F)A:0!0<FES:6IU;F=T:2!N
M97!A=GEK;RX@3F5T96ES:6YG87,@2OMS^"!N=7)O9'ET87,@=F%R=&]T;VIO
M('9A<F1A<R!I<B]A<B!S;&%P=&'^;V1I<RX`4')I<VEJ=6YG=&D@;F5P879Y
M:V\N`$EL9V%S('1E:W-T87,`365I;.L`3F5S=F%R8G4`36'^;W-I;W,@9W)A
M:6MI\&MO<R!R86EDZW,`36'^;W-I;W,@;&]T>6YI\&MO<R!R86EDZW,`36'^
M:65J:2!R;VWK;FGP:VD@<VMA:>AI86D`3&EU:W-E;6)U<F=A<P!-30!-3U1$
M`%!R:6MA8FEN=&%M92!-4RU43D5&(&9A:6QE(&[K<F$@9'5O;>MN^"X`35-'
M`$UA:V%O`$UA:V5D;VYI:F$`36%D86=A<VMA<F%S`$UA9VEJ80!08?!T87,`
M4&'P=&\@=F%L9'EM87,`4W5K=7)T:2!?;G5O<F]DX"XN+@!-86QA=FES`$UA
M;&%I>FEJ80!-86QD>79A:0!-86QI<P!-86QT80!+871E9V]R:6KX('/@<F'P
M;RP@:W5R:6]M<R!P<FES:VER:6%M:2!O8FIE:W1A:2P@:7(@<W4@:F]M:7,@
M<W5S:6IU<VGX('-P86QV^"!K96ET:6UA<RX`36%P,C0@_F5MZVQA<&ES`$UA
M<%%U97-T(/YE;>ML87!I<P!+;W9A<P!087)A\'3K`%!A_GEMZW1I(&MA:7`@
M<VMA:71Y='5S+VYE<VMA:71Y='5S`%!A_GEMZW1I(&MI=&%I<R!A=')I8G5T
M86ES("AP=GHN('-V87)B=2]A='-A:WET82D`36%R\&%L;R!S86QO<P!-87)T
M:6YI:V$`4W5J=6YG=&D@;&%U:V%I`$UA=7)I=&%N:6IA`$UA=7)I8VEJ=7,`
M36%K<VEM86QU<R!K<F5D:71A<RX`36%K<VEM86QU<R#^:6YUZ&GX(&1A;&GX
M(&MI96MI<R!I\&5I:W9O=&%S+@!-86MS+B!T96UP+B!P87-K+B`R-"!V86PZ
M(`!-86MS+B!T96UP+B!P87-K+B`V('9A;#H@`$UA:W-I;6%L=7,@:6QG:7,`
M1V5G=?[K`$UO:F]TZP!-961I8VEN80!.87)I86D`365N:74@<F7^:6UA<SH`
M4W5J=6YG=&D@8V5L97,`WFEN=73K`$QA:?!K87,@<&%V:7)T:6YT87,L('1A
MZ&EA=2!N97!A='9I<G1I;G1A<R!P87-I<F'P:75S:6\@87-M96YS('-E<G1I
M9FEK871A<RX`WFEN=73K(&YE:?!S:?AS=&$N`-YI;G5TZW,@=&EP87,`3W)O
M('-A;'EG;W,`3W)O('/@;'EG^"!B;&]K;R!NZW)A+@!/<F\@<^!L>6?X(&)L
M;VMO(&[K<F$N($%D;6EN:7-T<F%T;W)I=6D@:?!S:?AS=&%S(&1E=&%L=7,@
M87!R8?!Y;6%S+@!-971O9&%S`$UA=&%I`$UE:W-I:V$`36EK<F]N97II:F]S
M($9E9&5R86-I;NMS(%9A;'-T:6IO<P!6:61U<GEJ90!-24U%('1I<&%S`$UI
M;BX@=&5M<"X@<&%S:RX@,C0@=F%L.B``36EN+B!T96UP+B!P87-K+B`V(&AO
M=7)S.B``071S<&EN9'ES`$MI=&]S`$YE<F%S=&%S(%!%05(@2%144%]297%U
M97-T('!A:V5T87,N`$YU<W1A='EM^"!NZW)A+B!*96EG=2!N;W)I=&4@;F%U
M9&]T:2#PX2!M;V1U;.$L('1U<FET92!JX2!S=6MO;F9I9_MR=6]T:2X`3NMR
M82#^:6YU=.MS($E$+@!.97)A<W1A<R!R96EK86QI;F=A<R!014%2($UA:6P@
M<&%K971A<RX`3NMR82!S97-I:F]S($E$+@!0:7)M+@!-;V)I;'5S('!A\'1A
M<P!6:61U=&EN:7,`4F5D86=A=FEM;R!D871A`$ME:7-T:2!54DP`36]D=6QI
M<P!-;VQD;W9O<R!297-P=6)L:6MA`$UO;F%K87,`36]N9V]L:6IA`$WK;F5S
M:6%I(&ER(&UE=&%I`$MA<R!MZVYE<^$`36]N<V5R871A<P!-ZVYU;&EO(&9A
M>NMS`$UA<F]K87,`1&%U9VEA=7-I82!G:65D<F$`1&%U9VEA=7-I82!A<'-I
M;F%U:^8`1&%U9VEA=7-I82!S875LZW1A`%!E<FME;'1I(/YE;6EA=0!097)K
M96QT:2!K86ER:6%U`%!E<FME;'1I(&1E\&EN:6%U`%!E<FME;'1I(&%U:_#H
M:6%U`%!E<FOK;&EM87,@_F5M>6X`4&5R:^ML:6UA<R!A=6OP='EN`$UO>F%M
M8FEK87,`2V5L971O(&QY9VGX(&GP<VES:VQE:63^:6%N=&ES('/@<F'P87,`
M2V5L971A<R!P87-I<FEN:VEM^`!-86YO('/@<VMA:71A`$UA;F\@<&]R=&%L
M87,`36%N;R!P;W)T86QO(&GP9.MS='EM87,`36%I;FUA<F%S`$Y%+"!.15-5
M5$E.2U4`5F%R9&%S`$YA;6EB:6IA`$YA=7)A<P!.97!A;&%S`$YY9&5R;&%N
M9&%I`$YY9&5R;&%N9/@@06YT:6QA:0!.971S8W!A<&4@8F%Z:6YI<R!54DP`
M3F5T<V-P864@<V5R:69I:V%T;R!A=/!A=6MI;6\@55),`$YE='-C<&%E('-E
M<G1I9FEK871O('1E:7-I^"!54DP`3F5T<V-A<&4@871N875J:6YO;6\@55),
M`$YE='-C87!E(&%T\&%U:VEM;R!54DP`3F5T<V-A<&4@4U-,('-E<G9E<FEO
M('9A<F1A<P!.971S8V%P92!S97)T:69I:V%T;R!A<')A\'EM87,`3F5T<V-A
M<&4@<V5R=&EF:6MA=&\@=&EP87,`5&EN:VQA<P!.:65K861A`$YA=6IO:FD@
M2V%L961O;FEJ80!.875J82!K871E9V]R:6IA`$YA=6IA<R!MZVYU;&ES`$YA
M=6IA<R!V87)T;W1O:F\@=F%R9&%S("AN96+[=&EN87,I`$YA=6IO:FD@6F5L
M86YD:6IA`$YA=6IA;64@;&%N9V4@*%]B;&%N:RD`3F%U:FEE;F]S`$YA=6II
M96[X(&=R=7#K<P!396MA;G1I<P!396MA;G1Y<R!N=7-T871Y;6%I`$YI:V%R
M86=V80!.:6=E<FES`$YI9V5R:6IA`$YA:W1I<P!.:75JZP!.90!.977^=&5N
M:V$@9'5O;65N^"!S:VER='5M^"!P87)O9'EM=6DN`$YE;G5R;V1Y=&$@<W1R
M871E9VEJ82!)4T\@<F'P>6UU:2X`3NMR82!S=63K=&EN:6\@\&%B;&]N;RX`
M3G5R;V1Y=&]J92!P;WII8VEJ;VIE(&)L;VMO(&[K<F$`3F7A=F5DZW1E(&MA
M;&5N9&]R:6%U<R!V87)D;R!-0T%,(&%U=&5N=&EF:6MA8VEJ;VIE+@!3:VER
M='5M^"!NZW)A+@#0:6]S('1E:7/K<R!N96=A;&D@='5RZW1I('!O=&5I<VGX
M+@!.ZW)A(&EN9F]R;6%C:6IO<R!A<&EE("5S(&MO;F9I9_MR86-I:N`N`$[K
M<F$@:6YF;W)M86-I:F]S(&%P:64@1E10(%9&4R!K;VYF:6?[<F%C:6K@+@!.
MZW)A(&EN9F]R;6%C:6IO<R!A<&EE(%-13"!61E,@:V]N9FEG^W)A8VEJX"X`
M3NMR82!I;F9O<FUA8VEJ;W,@87!I92!344PM1FEL92!61E,@:V]N9FEG^W)A
M8VEJX"X`2W)E9&ET87,@:?!E:6MV;W1A<RX`3F7A=F5S=&%S(&=A=NMJ87,N
M`$9A:6QA<R!N96YU<VGX<W1A<P!.96YU<W1A='ET82!V:65T;W;K+@!.9>%R
M8?#K=&4@_FEN=73K<RX`3F7A<F'PZW1E('9A<F1O+@!.9>%R8?#K=&4@;G5M
M97)I;RX`3F5R;V1Y=&D@X?YE:63^:6%NZ&GX(&9R87II^`!.9>%V963K=&4@
M<VQA<'1A_F]D_FEO($A45%`@875T96YT:69I:V%C:6IA:2X`3F7A=F5DZW1E
M('-L87!T8?YO9/YI;R!)34%0(&%U=&5N=&EF:6MA8VEJ86DN`$YEX79E9.MT
M92!S;&%P=&'^;V3^:6\@2V5R8F5R;W,@875T96YT:69I:V%C:6IA:2X`3F7A
M=F5DZW1E('-L87!T8?YO9/YI;R!,;V=I;B!A=71E;G1I9FEK86-I:F%I+@!.
M9>%V963K=&4@<VQA<'1A_F]D_FEO(%!!4U-71"!A=71E;G1I9FEK86-I:F%I
M+@!.9>%V963K=&4@<VQA<'1A_F]D_FEO(%--0B!A=71E;G1I9FEK86-I:F%I
M+@!.9>%V97-T87,@:V5L:6%S(&EK:2!/<&5N4U-,('!A9W)I;F1I;FGX(&9A
M:6SX+B!/<&5N4U-,(')E:6MA;&EN9V$@9&%R8G5I('-U(%!+0U,@,3(@9'5O
M;65N:6UI<RX`3F5P871V:7)T:6YT^"!R96=I<W1R86-I:O@@;NMR82X`3F5N
M875D;W1I('-K:7)T=6OX`$[K('9I96YO:F4@<'5SZVIE`%-P87)T:6YI;75I
M(&[K<F$@;&%I:VEN;VIO(&MA=&%L;V=O+@!687)T;W1O:F\@=F%R9&%S(&ER
M+V%R8F$@<VQA<'1A_F]D:7,@;F5N=7-I^'-T87,N`%1E:7-I;F?X(%A-3"!D
M=6]M96[X(&[K<F$`3NMR82!R96EK\&UI^`!+;VYF:6?[<F%C:6YI86UE(&9A
M:6QE(&[K<F$@=F5R<VEJ;W,N(%!E<F=E;F5R=6]K:71E(&YU<W1A='EM=7,N
M`$MO;F9I9_MR86-I;FEA;64@9F%I;&4@;NMR82!V97)S:6IO<RX@4&5R9V5N
M97)U;VMI=&4@;G5S=&%T>6UU<RX`3F5N=7)O9'ET80!.ZW)A`-!I875RZW,@
M*$E33RTX.#4Y+3$P*0!.;W)F;VQK;R!S86QO<P#0:6%U<FENZR!H96UI<V9E
M<F$`T&EA=7)I;NMS($UA<FEJ86[X('-A;&]S`$YO<G9E9VEJ80!.92!P;R!T
M;P!.92!P<FEE\"!T86D`3F4@:V%T86QO9V%S`$YE<F5A;&EZ=6]T82X`3F5N
M=7)O9'ET80!.97!A;&%I:V]M87,N`%7^<F'P86D`3NMR82!KX"!P97+^:?MR
MZW1I+"!E:6MI=&4@871G86PN`$QA<&MR:71I<P!.=6UE<FES`%-I;6)O;&GX
M('-K86GH:75S`%-T=6QP96QI^"!S:V%IZ&EU<P!%:6QUZ&GX('-K86GH:75S
M`$YEX79E<W1I(&1I<W1R:6)U8VEJ;W,@<^!R8?!O(&%T;F%U:FEN:6UO('-K
M86GH:6%I+@!/2P!/8FIE:W1A<P!/8FIE:W1O('-A=FEN:6YK87,`0?!T=6YT
M86EN:7,`4W!A;&ES`-YI875R=6UO(&9I;'1R87,`3V9I<V%S`$]M86YA<P!+
M871A;&]G^"!D86QI:FEMX'-I('!A;&%I:V\@=&EK($E-05`@<V5R=F5R:6%I
M+@!4:6L@X?YE:63^:6%NZ&EO<R!F<F%ZZW,`3&5I9/YI86UA<R!T:6L@=FEE
M;F%S(&5L+B!P8?!T;R!A9')E<V%S+@!%;&5M96YT;R!S879I;FEN:V\@=&5I
M<V5S(&=A;&D@:V5I<W1I('1I:R!J;R!S879I;FEN:V%S(&%R8F$@<VES=&5M
M;W,@861M:6YI<W1R871O<FEU<P!!=&ED87)Y=&D@;F%U:F%M92!L86YG90!!
M=&ED87)Y=&D@\&G@(&YU;W)O9.`@;F%U:F%M92!L86YG90!/<')A8VENZW,@
M<VES=&5M;W,`3G5S=&%T>6UA:0`E<R!N=7-T871Y;6%I`%-U<OOP:75O=&%S
M('/@<F'P87,`3W)G86YI>F%C:6IA`%!A9&%L:6YY<P!3:7-T96UI;FEM87,`
M3W)I9VEN86QU<R!A<&QI:V%C:6IO<R#P86)L;VYA<P!/<FEG:6YA;/AS(/!A
M8FQO;F%I("5S.@!+:71A`$MI=&$@:6YF;W)M86-I:F$`4V%V:6YI;FEK;R!T
M96ESZW,`3NMR82!004T@875T96YT:69I:V%C:6IO<R!M96-H86YI>FUO+@!0
M1U`@<VMA:71M96YI;FES('!A<F'P87,`4$=0('7^:V]D=6]T82!I;F9O<FUA
M8VEJ80!01U`@=FEE\&%S:7,@<F%K=&%S`%!'4"!P87-I<F'P>71I+W7^:V]D
M=6]T:2!D=6]M96YY<P!02%`@:V]D87,`4$A0($-,20!032!L96YG=F%S(&QI
M971U<P!032!L:?MT:7,`4$T@5"UA=61R80!07TA0($-,20!487)P86D@8V5L
MZW-E`%!A:VES=&%N87,`4&%L874`5?YI;71O:FD@4&%L97-T:6YO<R!T97)I
M=&]R:6IA`%!A;F%M80!087!U82!.875J;VII($=V:6[K:F$`4&%R86=V86IU
M<P!$86QI;F%I(&1E8F5S=6]T80!3;&%P=&'^;V1I<P!3;&%P=&'^;V1I<R!N
M971E:7-I;F=A<P!2041)55,@875T96YT:69I:V%C:6IA:2!R96EK:6$@<VQA
M<'1A_F]D_FEO+@!3;&%P=&'^;V1I<R!S=2!P871V:7)T:6YI;74`4VQA<'1A
M_F]D:7,Z`%-L87!T8?YO9&ES.B``4VQA<'1A_F]D_FEA:2!T=7)I('-U=&%P
M=&DN`,%K96QT:0#!:V5L=&D@:?`@;&%I:VEN;W-I;W,@<V%U9WEK;&]S("AC
M;&EP8F]A<F0I`$ME;&EA<P!.97!A='9I<G1I;G1O<R!R96=I<W1R86-I:F]S
M.@#>;6]NZW,`4')O8V5N=&%I`$%T;&EK=&D@<')O9FEL86MT:6YI=7,@=F5I
M:W-M=7,`07(@871L:6MT:2!P<F]F:6QA:W1I;FEU<R!V96EK<VUU<R!P<FES
M:6IU;F=I;6\@;65T=3\`5&5I<^MS`%1E:7-I^"!A9&UI;FES=')A=FEM87,`
M07-M96YI;NL@:6YF;W)M86-I:F$`4&5R=0!'>7;[;F%I`$9I;&EP:6YA:0!4
M96QE9F]N87,`3G5O=')A=6MO<P!0:71K<F%N87,`4&EK<V5L:6%I`$)A;F%L
M>6+K<P!)\'-I<FEN:VET92!K=7)IX"!N;W)S(&-E;.8`4&%T=FER=&EN:VET
M92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#PX2!E;&5M96YTX#H`4&%T
M=FER=&EN:VET92P@87(@=&EK<F%I(&YO<FET92!I\'1R:6YT:2#P:6\@96QE
M;65N=&\@;G5O<F]DX"X`P79E<VMI=&4@;>MN97/A(&ER(&UE='5S+@#!=F5S
M:VET92!N875J;W,@:V%T96=O<FEJ;W,@<&%V861I;FEMX#H`P79E<VMI=&4@
M=&5I<VEN9^`@25`@861R97/@+@#!=F5S:VET92!T96ES:6YGX"!D873@+"!P
M871I:W)I;FMI=&4@9&EE;O@@<VMA:>AI^"!MZVYE<WEJ92X`P79E<VMI=&4@
M=&5I<VEN9^`@;&%I:^`N`$%P<F'P>6MI=&4@<')O8FQE;>`N`$YU<F]D>6MI
M=&4@<V%V;R!V87)T;W1O:F\@=F%R9.`@8F5I('-L87!T8?YO9.$`P79E<VMI
M=&4@;F%U:N`@:V%T96=O<FEJ;W,@<&%V861I;FEMX#H`3&5N:VEJ80!0;VQI
M=&EK86D`0F%L<V%V:6UA:0!0;W)T=6=A;&EJ80!0879E:6MS;.ML:6\@<&]Z
M:6-I:F$`3&5N=&5LZW,@<&]Z:6-I:F$`2?!S875G;W1I(/!I86UE(&MA=&%L
M;V=E("AN96=A;&EO:F$@24U!4"D`2W)I='5L:6%I('!A<VLN("5S('9A;&%N
M9.`H87,I.B``4')E9G-?;&1A<#H@;F5R87-T87,@<F5I:V%L:6YG87,@3$1!
M4"!M;V1U;&ES+@!0<F5F<U]S97-S:6]N.B!N97)A<W1A<R!R96EK86QI;F=A
M<R!S97-I:O@@;6]D=6QI<RX`4VSK9VES`%-LZV=I<R!J^W)O<R!L>6=Y:F4Z
M(`!3;.MG:7,Z(`!097+^:?MR80!097+^:?MRZW1I('!A=F5I:W-LZVSA(&YA
M=6IA;64@;&%N9V4`06YK<W1E<VYI(&YU<W1A='EM86D`071S<&%U<V1I;G1I
M(&1O:W5M96YTX`!3;&%P=&%S:7,@<F%K=&%S`%!R;V)L96UA`%!R;V)L96UO
M<R!A<')A\'EM87,`4')O:F5K=&%I`%!R8?!Y;6%S('1E:W-T=6D`5FEE\&%S
M:7,@<F%K=&%S`%9I9?!O:F\@<F%K=&\@86QG;W)I=&UA<P!6:67P;VIO+W-L
M87!T;VIO(')A:W3X('!O<F$@;F5S=6=E;F5R=6]T82X`4'5E<G1O(%)I:V%S
M`$MA=&%R87,`4V%K:6YY<P!24T$@=FEE\&%S:7,@<F%K=&%S("@E9"!B:71A
M:2D`)U)A9&EO)R!P87-I<FEN:VEM87,`3&EE='5S`$QI971U<R!R>71E`$QI
M971U<R!V86MA<F4`3&G[=&ES`$%T<VET:6MT:6[K(&9R87KK`%-A;G1Y:VES
M`%-K86ET>71I`%!E<G-K86ET>71I(&QA:?!K86D`5&EK<F%I(&GP=')I;G1I
M("5S/R!'<F'^:6YT:2!A=&=A;"!N96)E9V%LZW-I=&4N`%1I:W)A:2!I\'1R
M:6YT:2!V87)T;W1O:F\@)7,@9'5O;65N:7,_($=R8?YI;G1I(&%T9V%L(&YE
M8F5G86SK<VET92X`4&%K87)T;W1I(&%N:W-T97-NX2!V96EK<VW@`$%T;F%U
M:FEN=&D@:V%I<FEO:F\@;65N:74@96QE;65N='5S.@!!=&YA=6II;G1I('!O
M<G1A;&\@=F%I>F3@.@!296=E>`!3X')Y\&GX(&YA<O!Y:VSK`%!A<W1A8F]S
M`$YU=&]LYB!S97)V97)I86D`3G5T;VSF<R!54DP@*&AT='`Z+R]W=W<N<&%V
M>7ID>7,N8V]M+VAO<F1E*3H`2?!T<FEN=&D`4&'P86QI;G1I(&)L;VO@`%!A
M;F%I:VEN=&D@<W1U;'!E;.$`4&%N86EK:6YT:2!F;W)M871A=FEMX`!)\'1R
M:6YT:2!P;W+@`$GP=')I;G1I(&%T;F%U:FEN:6UO('-K<FEP=.`@:?`@<V5R
M=F5R:6\@;&%I:VEN;VIO(&MA=&%L;V=O+@!08?!A;&EN=&D`4&'P86QI;G1I
M(/#A(&5L96UE;G3@(&GP(&1O:W5M96YT;P!)\'1R:6YT:2!V87)T;W1O:N``
M5F%R=&]T;VIO('1R>6YI;6%S.B`E<P!.96=A;&EU(&%T<V%K>71I(.$@=?YK
M;&%U<^`N($ML86ED;W,@:V]D87,Z(`!)\"!N875J;P!086ME:7-T:2!S;&%P
M=&'^;V3A`%-L87!T8?YO9/YI;R!K96ET:6UA<P!297IU;'1A=&%I`$=RX?YT
M:2#A(&YU<W1A='EM=7,`4F5J^VYI:F$`071S=&%T>71I(&MO;F9I9_MR86-I
M:N``2%1-3"!R961A:W1O<FEA=7,@;G5S=&%T>6UA:0!-X7-LZW,`1&7P:6[K
M:F4`1&7P:6YI;VII(&%N=')A\'3K`$1E\&EN:6]S:6]S(')E:6OP;>MS`%]%
M:6QU=.MS(&YU<W1A='EM86DN+BX`4F]LZP!2=6UU;FEJ80!087-U:W1I(#$X
M,`!087-U:W1I(&MA:7+K;@!087-U:W1I(&1E\&ENZVX`16EL=73K<R!N=7-T
M871Y;6%I`$5I;'5TZW,@;G5S=&%T>6UA:0!%:6QU=.MS.@!3:VER='5K86D`
M4VMI<G1U:V%I('1A<G`@=FES^"!E:6QUZ&GX(&ER('-T=6QP96QI^`!3:VER
M='5K86D@=&EK('1A<G`@<W1U;'!E;&GX`%-K:7)T=6MA:2!T:6L@=&%R<"!E
M:6QUZ&GX`%9Y:V1Y=&D`4G5S:6IO<R!&961E<F%C:6IA`%)U86YD80!3+TU)
M344@<&%R8?!A<P!3+TU)344@=?YK;V1U;W1A<R!L86GP:V%S`$[K<F$@4T%3
M3"!A=71E;G1I9FEK86-I:F]S(&UE8VAA;FEZ;6\N`%--4R#^:6YU=.MS`%-1
M3"!#3$D`4U-(`%!!5EE+3P!37U%,($-,20#09?!T+@#0=F5N=&]J:2!(96QE
M;F$`4V%I;G0@2VET<V%S(&ER($YE=FES87,`4V%I;G0@3&EU8VEJ80#0=F5N
M=&%S:7,@4&5T<F%S(&ER($UI9V5L;VYA<P!386EN="!6:6YC96YT87,@:7(@
M1W)E;F%D:6YA:0!486UE('!AZ&EA;64@;&%N9V4@*%]S96QF*0!386UO80!3
M86X@36%R:6YA<P!386\@5&]M92!I<B!0<FEN8VEPZP!086QY9&]V87,`4V%U
M9&\@07)A8FEJ80!)\'-A=6=O=&D`2?!S875G;W1I("5S`$GP<V%U9V]T:2!N
M=7-T871Y;75S`$GP<V%U9V]T:2!S=6=E;F5R=6]T=7,@;G5S=&%T>6UU<R!K
M86EP(%!(4"!S:W)I<'3@(&K[<_@@<V5R=F5R:6\@;&%I:VEN86IA;64@:V%T
M86QO9V4N`"5S(&YU<W1A='EM86D@:?!S875G;W1I+@!-;VMS;&%S`$EE\&MO
M=&D`4&%I9?!K80!087-I<FEN:VET92!F86EL=7,`4&%S:7)I;FMI=&4@9&%T
MX`!087-I<FEN:VET92!G<G5PY@!087-I<FEN:VET92!N875JX"!S879I;FEN
M:^``4&%S:7)I;FMI=&4@<V5R=F5RX0!087-I<FEN:VET92!V87)T;W1O:N``
M4&%S:7)I;FMI=&4@=FES=7,@9&%T;W,@:V]M<&]N96YT=7,N`%!A<VER:6YK
M:71E(&]B:F5K=.``2?`@_F5M:6%U(&5S86[H:?@@<^!R8?#X('!A<VER:6YK
M:71E(')E:6MI86UU<R!S:6UB;VQI=7,N(%;K;&EA=2!G86QI=&4@:G5O<R!N
M=6MO<&EJ=6]T:2#A(&QA:?!KX"X`4&%S:7)I;FMI=&4@9&%T;W,@<VMI<G1U
M:^`Z`%!A<VER:6YK:71E(&1A=&]S(&9O<FUA=.`Z`%!A<VER:6YK:71E(&%P
M<F'PX"!K=7+A(&YO<FET92!R961A9W5O=&DZ`%!A<VER:6YK:71E(&QA:6MO
M('-K:7)T=6O@.@!087-I<FEN:VET92!L86EK;R!F;W)M873@.@!087-I<FEN
M:VET92!D=2!A=&ET:6YK86[H:75S(&QA=6MU<RX`4&%S:7)I;FMI=&4@<W!A
M;';X(&1E<FENX2X`4&%S:7)I;FMI=&4@;F]R:6W@(&MA;&+@.@!3:?AS=&D@
M<')O8FQE;6]S('!R86YE\&EMX`!3:?AS=&D@4TU3`%-E;F5G86QA<P!396YS
M;W)I=7,Z(`!2=6=SZVII<P!397)B:6IA(&ER($UO;G1E;F5G<F%S`%-E<FEJ
M;W,@;G5M97)I<P!397-I:F]S($E$('!A<VEB86EGZRX`4FEN:VEN>7,`3G5S
M=&%T>6UA:2!L96ED_FEA;G1Y<R!*=6US('!A<VEK96ES=&D@<VQA<'1A_F]D
MX2P@:F5I9W4@:N$@:V%D82!N;W)S('!A;6ER\&ET92X`3G5T;VQU<VGX('-E
M<G9E<FGX+"!K=7)I=6]S(&YO<FET92!M871Y=&D@:?`@<&]R=&%L;RP@;G5S
M=&%T>6UA:2X`2V%L8F]S+"!L86EK;R!Z;VYO<R!I<B!D871O<R!N=7-T871Y
M;6%I+@!0=7-L87!I;R!S<&%L=O@L(&%T<VEN875J:6YI;6\@9&'^;G5M;R!I
M<B!K:73X('9A:7ID879I;6\@<&%R86UE='+X(&YU<W1A='EM86DN`%)A<W1A
M<R!A=&YA=6II;FEM;R!S:W)I<'1A<P!3=2#P:75O('!A<F%M971R=2!G86QI
M;6]S(&ME;&EO<R!V:65T;W;K<SH@`%-E:?!E;&%I`%!A<F1U;W1U=NL`5')U
M;7!A<R!A<')A\'EM87,`07(@;F%U9&]T:2!K;&%V:6%T^W)O<R!M>6=T=6MU
M<R!V86QD>6UU:3\`4F]D>71I`%!A<F]D>71I('-K:7)T=6UU<R!T87)P(&GP
M<V%U9V]T;R!I<B!KX"!T:6L@<W5G96YE<G5O=&\@:V]N9FEG^W)A8VEN:6\@
M9F%I;&\N`%)O9'ET:2!P87-K=71I;FEO('!R:7-I:G5N9VEM;R!L86EKX#\`
M4F]D>71I(&=A;&EM>6+F('!A;&EK=&D@;W)I9VEN86S@`%)O9'ET:2!P87)I
M<VEN:VEMX`!2;V1Y=&D@;&5N=&5LZW,@;W!E<F%C:6KX(&UE;FEU/P!2;V1Y
M=&D@)7,@;65N:74@:V%I<NMJ93\`4F]D>71I(&-E;.MS(&YU<W1A='EM^"!L
M86YGX`!2;V1Y=&D@;&5N=&5LZW,@;G5S=&%T>6WX(&QA;F?@`%)O9'ET:2!E
M:6QU=.MS(&YU<W1A='EM^"!L86YGX`!2;V1Y=&D@<&%V96EK<VSK;&EO(&YU
M<W1A='EM^"!L86YGX`!2;V1Y=&D@9F%I;/@@X6OK;&EMX`!,:?MT:7,`3&G[
M=&ES(')Y=&4`3&G[=&ES('9A:V%R90!3=6UA_FEN=&D`4W5M8?YI;G1I(&%R
M8F$@<&%S='5M=&D@:V%I;7EN:6YI=7,@8FQO:W5S`%-I97)A($QE;V[K`%)E
M9VES=')A8VEJ80!087)A\&%S`%!A<F'P;R!A;&=O<FET;6%S`%-I;F=A</MR
M87,`1'ED:7,`4')A;&5I<W1I('!R;V9I;&%K=&EKX`!3;&]V86MI:F$`4VQO
M=NMN:6IA`%#[9V$`4VYI96=O(&=Y;&ES.B``4VYI96=O(&MI96MI<R!V86YD
M96YI=3H@`%-O;&]M;VYO('-A;&]S`%-O;6%L:6$`1&%I;F]S(&ER($5I;.MR
M8?#H:6%I`%+[\&EA=FEM;R!T=F%R:V]S('!A<VER:6YK:6UA<P!3:75N=.MJ
M;R!A9')E<V%S`%!I973X($%F<FEK80!0:65T^"!%=7)O<&]S("A)4T\M.#@U
M.2TS*0!0:65T^"!$_F]R9/YI:F]S(&ER(%!I973X(%-A;F1V:>AO('-A;&]S
M`%!I971I;NL@:&5M:7-F97)A`%1A<G!A<R!T87)P(&-E;&GX`%1A<G!A<R!T
M87)P(&-E;.MS('1U<FEN:6\@:7(@:W)A\'1I;NMS`%1A<G!A<P!487)P86D@
M=&%R<"!C96QI^`!487)P86D`27-P86YI:F$`4W!A;6%S`%-P96-I9FEN:?@@
M<VEM8F]L:?@@X71E<G!I;6%S`%!E<G-K96QT:2!C96SF`%!E<G-K96QT:2!S
M='5L<&5LX0!097)S:V5L=&D@96EL=73F`%-P;W)T87,`T')I($QA;FMA`%-T
M86YD87)T87,`4W1A<B!4<F5K)V%S`%!R861I;FEA:2!M971A:0!286IO;F%S
M(&%R8F$@<')O=FEN8VEJ80!"^W-E;F$`4V%U9V]J:6UO(&9O<FUA=&%S`$=A
M=';K<R!A9')E<V%S`%7^8G)A=6MT:0#>;V3^:?@@<^!R8?!A<P!.=6EM=&D@
M9&]M96[@(&YU;R!A9')E<V\`4W1I;&EU<R!;0U-370!396MM+@!496UA`,%V
M97-T:0!);F1E:W-A<P!3ZVMM:6YG80!+;VYF:6?[<F%C:6IA(&%T<W1A='ET
M82!SZVMM:6YG86DN(%!E<FMR875K:71E('!U<VQA<.$L(&MA9"!P86UA='ET
M=6WK=&4@<&%K96ET=6UU<RX`071S87)G:6[K(&MO;F9I9_MR86-I:F]S(&MO
M<&EJ82!SZVMM:6YG86D@:?!S875G;W1A+@`G)7,G('/K:VUI;F=A:2!U_G)A
M\'ET87,N`%-U9&%N87,`5'5R:6YY<P!3875LZW1E:VES`%-A=6SK;'EG:7,`
M4V%U;.MT80!3875LZW1E:VES`%-A=6SK=&5K:7,O4V%U;.ML>61I<P!3875L
MZW1E:VES.B``4V%U;.ML>6=I<P!3875LZVQY9VES.B``3&%I<'-N:7,`07!T
M87)N879I;6%S`%-U<FEN86UA<P!0879A<F3K`%-V86QB87)D87,@:7(@1/YA
M;FUA:6YA<P!3=F%Z:6QA;F1A<P#0=F5D:6IA`-!V96EC87)I:F$`4VEN=&%K
M<^MS(&ML86ED82!P86EE\&MO<R!K<FET97)I:G5J90!3:7)I:F]S($%R86+X
M(%)E<W!U8FQI:V$`5"UA=61R80!4+6%U9')O<P!44U8@9F%I;&%S`$QE;G1E
M;.L`3&5N=&5LZW,@;G5S=&%T>6UA:0!,96YT96SK<R!N=7-T871Y;6%I`%1A
M:79A;F%S`%1A:79A;F%S+"!+:6YI:F]S('!R;W9I;F-I:F$`5&%D_FEK:7-T
M86YA<P!*=6YG=&ENZR!486YZ86YI:F]S(%)E<W!U8FQI:V$`5&%I:VEN>7,Z
M`$1A<F)A:0!496QE9F]N;R!N=6UE<FES`%1E;7`N('!A<VLN('9A;&%N9.`Z
M(`!496UP97)A=/MR80!496UP97)A=/MR83H@`-!A8FQO;O@@861M:6YI<W1R
M879I;6%S`%1E:W-T87,`5&EK('1E:W-T87,`3'EG:75O=&D@=&5K<W3@`%1E
M:W-T;R!V:7+P=6IE`$ME='8N`%1A:6QA;F1I971I\&MA("A425,M-C(P*0!4
M86EL86YD87,`0>AI^R!K860@;F%U9&]J873K<R!S:7-T96UA+@!.ZW)A($94
M4"!M;V1U;&EO+@!(;W)D92]+;VQA8B!I;G1E9W)A8VEJ;W,@=F%R:6ML:75K
M87,@;F5P86QA:6MO("(E<R(`3F5P879Y:V\@=?YK<F%U=&D@36%I;G1E;F%N
M8V4Z.B!K;&%SZW,`3G5S=&%T>6WX(&QA;F=A<R!U_F1A<GET87,N($GP96EN
M=2X`2F5I9W4@;F]R:71E(&YA=61O=&D@;G5S=&%T>6UU<RP@<&%P<F'P>6MI
M=&4@:V%D(&%D;6EN:7-T<F%T;W)I=7,@<W5K;VYF:6?[<G5O=/@@<&%S=&]V
M:>`@9'5O;65N^"!B87KF(&YU<W1A='EM86US('-A=6=O=&DN`%1I:R!A<&%T
M:6[K:F4@<'5SZVIE`$YEX7)A\.MT92!C;VYT86MT;R!)1"!N=6UE<FEO(&%R
M8F$@:FES(&YE<F%S=&%S(&1U;VUE;O@@8F%ZZVIE+@!+;VYT86MT87,@<^MK
M;6EN9V%I(.%T<F%U:W1A<R#A($K[<_@@861R97/X(&MN>6=E;.8N`$YO<NMD
M86UI('!A=&EK<FEN=&D@;&%I\&O@('!R:79A;&]T92!T=7+K=&D@871S:VER
MX"!01U`@<&%R8?!O(&)L;VO@+@!.9>%R8?#K=&4@9&ES=')I8G5C:6IO<R!S
MX')A\&\@240@87)B82!J:7,@;F5R87-T87,@9'5O;65N^"!B87KK:F4N`$YE
MX7)A\.MT92!D:7-T<FEB=6-I:F]S('/@<F'P;RX`4$=0('7^:V]D879I;6\@
M9V%L:6UY8NL@<F5I:V%L875J82!S875G875S('!R:7-I:G5N9VEM;RX@0F%N
M9'EK:71E(')A\'ET:2!H='1P<SHO+R!A9')E<V\@<')A9/YI;VIE+@!&86EL
M87,@)7,@<')I=F%L;R!T=7+K=&D@)7,@<&%R86UE='+@+@!&86EL87,@)7,@
M<')I=F%L;R!T=7+K=&D@:V%I(&MU<FEU;W,@)7,@<&%R86UE=')U<RX`1F%I
M;&%S(&YE9V%L:2!B^W1I(&YU:V]P:6IU;W1A<R!A;G0@<V%VYG,N`$9A:6QE
M(&[K<F$@9'5O;65N^"X`4D9#.#@R(&QA:?!K;R!A;G1R8?!TZW,N`$IE:6=U
M(&1I<F)A=&4@26YT97)N970@17AP;&]R97(@;F%R\'EK;&4L('!I;&YA96MR
M86YI<R!R961A:W1O<FEA=7,@<F7^:6UA<R!G86QI('-U:V5L=&D@<')O8FQE
M;?@L(&3K;"#P:6]S(&YA<O!Y:VSK<R!K;&%I9/@N($=A;&ET92!N96UA='ET
M:2!K86D@:W5R:?@@<F5D86MT;W)I875S(&5L96UE;G3X+B!*96EG=2!N875D
M;VIA=&4@5VEN9&]W<R`Y>"!/4R!G<F5IZ&EA=7-I86D@:OMS^"!K;VUP:75T
M97)I<R!P87!R8?#H:6%U<VEA:2!N=6QU\"!P87-K96QB9&%M87,@87!I92!P
M86=R:6YD:6[F(&ML86EDX"Y<;EQN2OMS(&)U=F]T92!P97)S<.MT87,N($IE
M:6=U('9I<W1I96L@;F]R:71E(&GP8F%N9'ET:2!P:6QN865K<F%NX2!R9?YI
M;>`@<W!A=7-K:71E($]++@!!<')A\&%S("(E<R(@:?!T<FEN=&%S+@!4:6L@
M:V%I<NMJ92!P=7/K:F4`0W)Y<'1?<'%P.CH@:VQA<V5I(')E:6MI82!N=7)O
M9'ET:2!K=7(@>7)A($=N=5!'(&9A:6QA:2X`3&%I\&MA<R!I\'-I^'-T87,@
M)7,@861R97-A='5I("5S('1E;6$@(B5S(B!B=79O('!A<F]D>71A<RX*5&'H
M:6%U('1A:2!N96=A<F%N='5O:F$@:V%D(&QA:?!K87,@8G5V;R!P97)S:V%I
M='ET87,@87)B82!S=7!R87-T87,N`%!A=F%D:6YI;6%S(&MU<N$@;F%U9&]S
M:71E(&YU;W)O9&]J92#A(&QA:?!K;R!R8?!Y;6\@<'5S;&%PX0!(;W)D95]#
M<GEP=%]S;6EM93HZ(&ML87-E:2!R96EK86QI;F=A<R!/<&5N4U-,(&UO9'5L
M:7,N`$YE9V%L:74@:?!S875G;W1I(&YU<W1A='EM;R`B)7,B+"!N97,@9'5O
M;65N^"!D>61I<R!V:7+P>6IA(&QE:7-T:6[@(')I8N``4')O9W)A;6$L('-K
M:7)T82!P97+^:?MRZW1I(/#A(&1U;VUE;O@@=&EPX"`H)7,I+"!N97)A<W1A
M('-I<W1E;6]J92X`5&EK(&MA:7+K:F4@:7(@9&7P:6[K:F4@<'5SZW-E`%1I
M:R!D9?!I;NMJ92!P=7/K:F4`4V5R=F5R:7,@(B5S(B!I\'1R:6YT87,N`%-E
M<G9E<FES("(E<R(@:?!S875G;W1A<RX`)7,@<F5G:7-T<F%C:6IO<R!P<F'P
M>6UA<R!I\'1R:6YT87,N`$YU<F]D>71A(&5I;'5TZR!N965G>FES='5O:F$N
M`%1I:R!V:7+P=71I;NMJ92!I<B!A<&%T:6[K:F4@<'5SZW-E`%1I:R!A<&%T
M:6[K:F4@<'5SZVIE`$YU<VGX<W1I(&1U;VUE;GES('!R87)A<W1I+@!.96=A
M;&EU(&GP<V%U9V]T:2!N=7-I^'-T;R!F86EL;RX`5V5A=&AE<BYC;VT@8FQO
M:V\@;NMR82X`3G5S=&%T>6WX(&[K<F$N`$1A;&GX+"!K=7)I87,@9V%L:6UA
M(')O9'ET:2!L86GP:V\@=&5K<W1E+"!NZW)A+@#0:6%M92!L875K92#A=F5S
M=&$@<&5R(&1A=6<@<VEM8F]L:?@N($K[<R#A=F5DZW1E("5S+"!O(&UA:W-I
M;6%L=7,@<VMA:>AI=7,@+2`E<R!S:6UB;VQI86DN`%!R;V)L96UO<R!S=2!F
M86EL^"!S:75N=&EM=3H@)7,@;F5N=7-I^'-T87,N`$YU<VGX<W1I(&9A:6QO
M(&YE<&%V>6MO+B!&86EL87,@)7,@>7)A(&1I9&5S;FES(&YE9W4@;&5I9/YI
M86UA<R!D>61I<R`H)60@8F%I=&%I*2X`3G5S:?AS=&D@9F%I;&\@;F5P879Y
M:V\N($9A:6QA<R`E<R!T:6L@9&%L:6YA:2!N=7-I^'-T87,N`$YE9V%L:74@
M<&%R;V1Y=&D@\&EO<R!L86GP:V\@9&%L:65S`$ML86ED82#A:V5L:6%N="!K
M;VYT86MT:6YI=7,@9'5O;65N:7,N`$ML86ED82#A:V5L:6%N="!I0V%L96YD
M87(@9'5O;65N:7,N`$ML86ED82!K;VYF:6?[<F%C:6IO<R!F;W)M;VIE+B!'
M<F5IZ&EA=7-I86D@;F5U_G!I;&3K=&4@<F5I:VEA;?@@;&%U:_@N`$ML86ED
M82!A=&QI96MA;G0@;G5R;V1Y=.`@861R97/X(&MN>6=E;.MS(&9U;FMC:6K@
M+B!086)A;F1Y:VET92!VZVQI874N`$ML86ED82!A=&YA=6II;F%N="!K;VYT
M86MT:6YI=7,@9'5O;65N:7,N(%!A8F%N9'EK:71E(';K;&EA=2X`2VQA:61A
M(&%T;F%U:FEN86YT(&1I<W1R:6)U8VEJ;W,@<^!R8?#@+B!086)A;F1Y:VET
M92!VZVQI874N`-!I<R!)34%0('-E<G9E<FES(&YE<&%L86EK;R!K871A;&]G
M^"!D86QI:FEM;W-I+@!!=')O9&\L(&MA9"!T86D@;F5T=F%R:VEN9V%S(%)!
M4B!A<F-H>79A<RX`071R;V1O+"!K860@=&%I(&YE='9A<FMI;F=A<R!:25`@
M87)C:'EV87,N`$%T<F]D;RP@:V%D('1A:2!N971E:7-I;F=A<R!K;W)T96SK
M<R!N=6UE<FES+@#0:2!T=F%R:WEK;.L@;&5I9/YI82!S:?AS=&D@_FEN=71E
M<R!P97(@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!P87-I
M;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I('1V87)K>6MLZR!L96ED_FEA
M('-I^'-T:2#^:6YU=&5S('!E<B!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2!P87-I;F%U9&]J86YT($A45%`@<')O=&]K;VQU`-!I('1V87)K
M>6MLZR!L96ED_FEA('-I^'-T:2#^:6YU=&5S(%--5%`@<')O=&]K;VQU('!E
M<B!6;V1A9F]N92!)=&%L:6IO<R!V87)T=7,L('1I:R!6;V1A9F]N92!N=6UE
M<FEA;7,N($II(')E:6MA;&%U:F$@96PN('!A\'1O(&%D<F5S;R!6;V1A9F]N
M92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@#0:7,@;&%U:V%S('!R:79A
M;&]M87,N`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@<W9E:6MI96II('-K
M86GH:6%I+@#0:6%M92!L875K92!G86QI(&+[=&D@=&EK('-K86GH:6%I(&ER
M(&1V:71A\&MI86DN`-!I86UE(&QA=6ME(&=A;&D@8OMT:2!T:6L@8?!T=6YT
M86EN:6%I('-K86GH:6%I+@#0:6%M92!L875K92!T=7)I(&+[=&D@:V%B;&5L
M:6%I<R!A<F)A('1A<G!A:7,@871S:VER=&D@<W9E:6MI96II('-K86GH:6%I
M`-!I(')E:6OP;>L@='5R:2!B^W1I('-K86GH:75S+@#0:6%M92!L875K92!G
M86QI(&+[=&D@=&EK('-P86QV;W,@:V]D87,@4D="($AE>"!F;W)M871E+"!P
M879Y>F3^:75I("<C,3(S-$%&)RX`T&D@9F]R;6$@:F%U(&%P9&]R;W1A+@!4
M86D@)7,N`%1A:2!+;VQA8B!'<F]U<'=A<F4@;V)J96MT87,N($YO<NMD86UI
M('!E<OYI^W+K=&D@;V)J96MTX"!P<FEV86QO=&4@='5RZW1I(&5L+B!P8?!T
M;R!K;&EE;G3@+"!K=7)I<R!S=7!R86YTX"#PX2!F;W)M873@+B!4;VMI^"!E
M;"X@<&'P=&\@:VQI96YT^"!SX')A\.`@9V%L:71E(')A<W1I(&%P<VEL86YK
MYB`E<P#0:7,@;&%I\&MA<R!B=79O('!A<F'P>71A<R`E<R!K;V1U;W1E+B!*
M^W,@;F%U9&]J871E(&MI=&]K:>`@:V]D=6]TYBX`T&ES('-K86GH:75S('1U
M<FD@8OMT:2!D:61E<VYI<R!U_B!N=6SA+@#0:7,@<V5R=F5R:7,@;F5G86QI
M(&GP87)C:'EV=6]T:2!Z:7`@:7(@9WII<"!F86EL^"X`T&D@<VES=&5M82!D
M86)A<B!I\&IU;F=T82X`T&D@<F5I:_!MZR!T=7)I(&+[=&D@<VMA:>AI=7,N
M`-#A(&QA;F?@(')E:6MI82!A=&ED87)I;NMT:2!I\"!N=7-T871Y;?@@;&%N
M9V\`4&5R:_MN:6IA`$)I;&EE=&%I`$QA:6MA<P!,86EK;R!A<'-K86ET80!,
M86EK;R!F;W)M871A<P!,86EK;R!P87-I<FEN:VEM87,`5&EM;W)L97-TZP!0
M87)E:6=O<P!0879A9&EN:6UA<SH`2V%M`$YO<NMD86UI('!A<VER:6YK=&D@
M:V5L973@(&5L96UE;G3X+"!L86EK>6MI=&4@0V]N=')O;"`H4$,I(&%R8F$@
M0V]M;6YA9"`H36%C*2!K;&%V:?#@+"!I<B!P87-I<FEN:VET92!P96QE+@#0
M:6%N9&EE;@!2;V1Y=&D@2%1-3"!K;V3@`%1O9V%S`%1O:V5L874`4GET;VH`
M5&]N9V$`5FER\'5J90!6:7+P=71I;FEA;64@;&%N9V4@*%]T;W`I`%9E<G1I
M;6%I`%1R:6YI9&%D87,@:7(@5&]B86=A<P!486EP(&%R8F$@;F4`06YT<BX`
M5'5N:7-A<P!4=7)K:6IA`%1U<FMI\&MA("A)4T\M.#@U.2TY*0!4=7)K;>MN
M:6IA`%1U<FMS;R!I<B!+86EK;W-O('-A;&]S`%1U=F%L=0#!=F5S:VET92!S
M879O('!A<VER:6YK:6W@.B``52Y6+B!I;F1E:W-A<SH@`%523`!3:W)I<'1O
M('!R:7-T871Y;6\@<W1A='5S;R!R87!O<G1O(%523`!54DPZ`%5G86YD80!5
M:W)A:6YA`$YE<&%V>6MO('!E<G-K86ET>71I(%9&4R!K871A;&]G;RX`3F5P
M879Y:V\@<')I9.MT:2!P87!I;&1O;6]S('9A<G1O=&]J;R!R96=I<W1R86-I
M:F]S(&EN9F]R;6%C:6IO<RX`3F5P879Y:V\@<&%K96ES=&D@5D93(&9A:6QO
M("(E<R(@=&5I<VGX+@!.97!A=GEK;R!P86ME:7-T:2!T96ES:?@@5D93(&9A
M:6QU:2`E<R\E<RX`3F5P879Y:V\@<&5R96ET:2#A("5S+@!.97!A=GEK;R!P
M<FES:6IU;F=T:2!P<FEE(%-13"!S97)V97)I;RX`3F5P879Y:V\@<')I<VEJ
M=6YG=&D@4U-,(')E_FEM=2X`3F5P879Y:V\@;G5K;W!I:G5O=&D@5D93(&9A
M:6QO+@!.97!A=GEK;R!S=6MU<G1I(%9&4R!K871A;&]G;R`B)7,B+@!.97!A
M=GEK;R!S=6MU<G1I(%9&4R!K871A;&]G;RX`3F5P879Y:V\@<W5K=7)T:2!6
M1E,@9F%I;&\N`$YE<&%V>6MO('-U:W5R=&D@='7PZ&EO(%9&4R!F86EL;RX`
M3F5P879Y:V\@:?!A<F-H>79U;W1I(&1U;VUE;O@N`$YE<&%V>6MO(&GP=')I
M;G1I("(E<R(L(&MA=&%L;V=A<R!N971U\.AI87,`3F5P879Y:V\@:?!T<FEN
M=&D@)7,L(&MA=&%L;V=A<R!N971U\.AI87,`3F5P879Y:V\@<F5K=7)S:?!K
M86D@:?!T<FEN=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!I\'1R:6YT:2!6
M1E,@:V%T86QO9V\N`$YE<&%V>6MO(&GP=')I;G1I(%9&4R!K871A;&]G;SH@
M)7,N`$YE<&%V>6MO(&GP=')I;G1I(%9&4R!F86EL;R`B)7,B+@!.97!A=GEK
M;R!I\'1R:6YT:2!61E,@9F%I;&\N`$YE<&%V>6MO(')E:W5R<VGP:V%I(&GP
M=')I;G1I(%9&4SH@)7,N`$YE<&%V>6MO(&YU<W1A='ET:2!D86)A<G1I;FEO
M(&MA=&%L;V=O+@!.97!A=GEK;R!G875T:2!S97)T:69I:V%T;R!A<')A\'EM
M;P!.97!A=GEK;R!U_FMR875T:2`E<R!A<')A\'EM;RX`3F5P879Y:V\@<&5R
M:V5L=&D@5D93(&9A:6QO+@!.97!A=GEK;R!A=&ED87)Y=&D@5D93(&9A:6QO
M("(E<R(N`$YE<&%V>6MO(&%T:61A<GET:2!61E,@9F%I;&\@<F'P>6UU:2X`
M3F5P879Y:V\@871I9&%R>71I(%9&4R!F86EL;RX`3F5P879Y:V\@871I9&%R
M>71I('-U<W!A=7-T;R!A<F-H>79O+@!.97!A=GEK;R!P97)S:V%I='ET:2!V
M9G-R;V]T(&MA=&%L;V=O+@!.97!A=GEK;R!P97)V861I;G1I("5S(.$@)7,Z
M('1O:W,@:V%T86QO9V%S(&IA=2!E9WII<W1U;VIA`$YE<&%V>6MO('!E<G9A
M9&EN=&D@5D93(&MA=&%L;V=O+@!.97!A=GEK;R!P97)V861I;G1I(%9&4R!K
M871A;&]G;SH@)7,N`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO("(E
M<R(N`$YE<&%V>6MO('!E<G9A9&EN=&D@5D93(&9A:6QO("5S+R5S+@!.97!A
M=GEK;R!P97)V861I;G1I(%9&4R!F86EL;RX`3F5P879Y:V\@<&%L96ES=&D@
M)VUK:7-O9G,G+@!.97!A=GEK;R!I\'9E<G-T:2#P:6\@5V]R9"!D;VMU;65N
M=&\`3F5P879Y:V\@X7)A\'ET:2!61E,@9F%I;&\@(B5S(BX`3F5P879Y:V\@
MX7)A\'ET:2!61E,@9F%I;&\@*&-O<'DH*2!K;&%I9&$I+@!.97!A=GEK;R#A
M<F'P>71I(%9&4R!F86EL;R!D=6]M96[X+@!086)R875K=&D`073P875K=&D@
M<&%K96ET:6UU<P!!=/!A=6MT:2!A;FMS=&5S;N$@=F5I:W-MX`!.971I:^MT
M82!S97)V97)I;R!K;&%I9&$Z(`!.971I:^MT82!S97)V97)I;R!K;&%I9&$Z
M(`!.96YU<F]D>71A`%5N:6MO9&%S("A55$8M."D`2G5N9W1I;FEA:2!!<F%B
M^"!%;7ER871A:0!*=6YG=&ENZR!+87)A;'ES=.L`2G5N9W1I;NMS(%9A;'-T
M:6IO<P!*=6YG=&EN:?@@5F%L<W1Y:O@@071O:V5S;NMS('-A;&]S`%9I96YE
M=&%I`$YE_FEN;VUA<P!.9?YI;F]M87,@87!I;7-G:60@*$%022!-97-S86=E
M($E$*2X`3F7^:6YO;6%S(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN
M`$YE_FEN;VUA<R!V87)T;W1O:F\@=F%R9&%S(&ER+V%R8F$@<VQA<'1A_F]D
M:7,N`%!A;F%I:VEN=&D@;G5O<F]DX"#P:6%M(&5L96UE;G1U:0!.9>%V87)D
M:6YT87,`4V%U9W5M;R!S=6UE=&EM86ES(&YE<')I=FEL96=I:G5O=&D@<VMR
M:7!T86D@;F5G86QI(&%T;&EK=&D@4&5R:^ML:6UO+TMO<&EJ879I;6\OP6OK
M;&EM;R!P<F]G<F%M:?!K86DN($YO<NMD86UI('!E<OYI^W+K=&D@=&5C:&YI
M;F5S(&1E=&%L97,@;6]Z:6QL82YO<F<@=&EN:VQA<'EJ92P@:7(@<W7^:6YO
M=&D@:V%I<"!S:W)I<'1A;7,@;&5I<W1I('!R:65I=&D@<')I92!L86EK:6YO
M<VEO<R!S875G>6ML;W,L('!A<W!A=7-K:71E($]++@!.96YA=61O=&D@<W!A
M;'9O<P!0;.MT:6YY<R!N97!A;&%I:V]M87,`071N875J:6YT:0!!=&YA=6II
M;G1I("5S`$%T;F%U:FEN=&D@=F%R=&]T;VK@`$%T;F%U:FEN:6UO('-K<FEP
M=&%S(&GP=')I;G1A<RX`3G5S:?AS=&D`5FES:2!M;V1U;&GX(&%T;F%U:FEN
M:6UO(&9A:6QA:2#A:V5L=&D@X2!S97)V97+A+@!$:63^:6]S:6]S(&QO=&EN
M:?!K;W,@<F%I9.MS`$1I9&EE:FD@<F]MZVYI\&MI('-K86GH:6%I`%5R=6=V
M86IU<P!.875D;W1I(&1A8F%R=&ENYCH@)7,`3F%U9&]T:2!34TP`3F%U9&]T
M:2!J96EG=2!V87)T;W1O:F\@=F%R9&%S+W-L87!T8?YO9&ES($E-4U`@<V5R
M=F5R:75I('ER82!K:71O:W,N`%9A<G1O=&]J87,@)7,@;F5A=71O<FEZ=6]T
M87,@<')IZVII;75I('!R:64@)7,N`%9A<G1O=&]J^"!A9&UI;FES=')A=FEM
M87,`5F%R=&]T;VIO(&YU<W1A='EM86D`5F%R=&]T;VKX(')E9VES=')A8VEJ
M80!687)T;W1O:O@@<F5G:7-T<F%C:6IA(&GP:G5N9W1A+@!687)T;W1O:F\@
M=F%R9&%S`%9A<G1O=&]J;R!V87)D87,Z`%9A<G1O=&]J;R!V87)D87,Z(`!6
M87)T;W1O:F%I(/!I;VIE('-I<W1E;6]J93H`57IB96MI<W1A;F%S`%9&4R!K
M871A;&]G87,@;F5E9WII<W1U;VIA+@!!=&]S=&]G;W,`4F%S=&]S('1E:7-I
M;F=O<R!V:65T;W;K<SH@`$=A;&EO:FEM87,`4F5I:_!MZR!M:6YU=.MM:7,@
M;G5O(&1A8F%R+@!296EK\&WK<P!296EK\&WK<R!I\"!K=7)I^"!G86QI;6$@
M<&%S:7)I;FMT:0!686YU871U`$MI;G1A;G1I<P!696YE<W5E;&$`4&%T=FER
M=&EN:6UA<R!N96)A:6=T87,@+2#P:7,@;&%I\&MA<R!S=6=A9&EN=&%S+@!6
M97)S:6IA`%9E<G-I:O@@:V]N=')O;.L`3'EG:75O=&D@=F5R=&EK86QI86D`
M5F5R=&EK86QU<R!T87)P87,`5F5R=&EK86QU<SH`3&%B86D@9&ED96QI<P!6
M:65T;F%M87,`5FEE=&YA;6EE=&GP:V$@*%9)4T-)22D`4&5R_FG[<NMT:2`E
M<P!2;V1Y=&D@:?!O<FENX2!P=7-L87#A`%!E<OYI^W+K=&D@:V%I<"`E<P!"
M<FET^"!6:7)D_FEN:6IO<R!S86QO<P!*058@5FER9/YI;FEJ;W,@<V%L;W,`
M36%T;VUU;6%S`$UA=&]M=6UA<SH@`%9O9&%F;VYE($ET86QI:F$@<&5R(%--
M5%``5T%23@!$RTU%4TE/(2$A(%!!5%E3($G05%))3DM)5$4@4TM225!4P"!)
MT"`E<RX`5F%L:7,@:7(@1G5T=6YA`$3K;65S:6\`5')EZ"X`3W+X('!R;V=N
M;WKK`$]R^"!P<F]G;F]ZZR!P86=A;`!796%T:&5R+F-O;0!75U<`5U=7('!U
M<VQA<&ES`$MA<R!S879A:73F`%-V96EK:0!3=F5I:VD@871V>6OF(.$@)7,`
M3&%B87,L("5S`%9A:V%R^"`H25-/+3@X-3DM,2D`5F%K87+X("A)4T\M.#@U
M.2TQ-2D`5F%K87+X(%-A8VAA<F$`2V]KX2!M;V1U;.$@)7,@='5R:2!R;V1Y
M=&D@<&\@<')I<VEJ=6YG:6UO/P!+;VMS('-K:7)T=6MO('-I;6)O;&ES/P!+
M;VMS(&MA8G7H:?@@<VEM8F]L:7,_`$MU<FEO<R!F87KK<P!(5$U,(')E9&%K
M=&]R:6%U<R!M;V1U;&GX(.%J=6YG:6UA<RX`4&QO=&ES`%!L;W1I<R!#4U,@
M;6%T86ES`"5S(&MA:7)I;VIO(&UE;FEU('!L;W1I<R`H<&%K96ET:6UA:2!B
M=7,@;6%T>71I('!O(&MI=&\@<')I<VEJ=6YG:6UO*3H`3&5N=&5LZW,@<&QO
M=&ES`%!L;^AI;R!M871A<P!0;&]T:7,Z`%=I:VD`5NMJ;R!G<F5I=&ES(&UA
M>F=A:7,`5NMJ87,Z`%;K:F%S.B``2?!M:6YT:7,`1&%R8F%S`$1A<F)O(&%D
M<F5S87,`1&%R8F\@=&5L969O;F%S`%@M4F5F`%@U,#EV,R!P86=R:6YD:6YI
M86D@;G5S=&%T>6UA:0!8-3`Y=C,@:?!P;.MS=&\@<F%K=&\@<&%N875D;VII
M;6%S`%@U,#EV,R!A;'1E<FYA='EV=7,@=F%R9&%S`%@U,#EV,R!R86MT;R!I
M9&5N=&EF:6MA=&]R:75S`%@U,#EV,R!M;V1U;&EA:0!960!965E9`%EA:&]O
M(2#^96WK;&%P:7,`2V%S;65T`$IE;65N87,`5&%I<`!486EP+"!A\"!S=71I
M;FMU`$K[<R!E<V%T92!414M35$E.24%-12!21=Y)344N($YO<NMD86UI(&=R
MX?YT:2#A(%=94TE764<@<W!A=7-K:71E(%L\/ETN`$K[<R!N97!R:7-I:G5N
M9^8N`%-A=F\@=F%R9&4@;F5G86QI=&4@;F%U9&]T:2!S:6UB;VQI;R`G7"<N
M`,%V963K=&4@;F5T96ES:6YGX"!E;"X@<&'P=&\@861R97/@+@!.97!R:6IU
M;F?K=&4@:F]K:?@@;&%U:_@@:?`@X6ME;&EA;6\@9F%I;&\@<')I92`E<R!A
M=&ET:6YK86WX(&QA=6OX+@!*^W,@871S:6IU;F?K=&4N`%1U<FET92#A=F5S
M=&D@=&5I<VEN9^`@=&5L969O;F\@;G5M97+A("AT:6L@<VMA:>AI=7,@:7(@
M)RLG+"!J96EG=2!N;W)I=&4@;G5R;V1Y=&D@=&%R<'1A=71I;N$@:V]DX"DN
M`,%V963K=&4@;F5T96ES:6YGX"!R96EK\&WF+@!.;W+K9&%M:2!N875G;W1I
M<R!R96=I<W1R86-I:F]S('-I<W1E;6$L('1U<FET92!S=6MO;F9I9_MR=6]T
M:2!D=6]M96[X(&UE9/YI;R!P;W-I<W1E;>8N`%!R:67P('-I^'-D86UI('!R
M86YE\&EMX"P@87!R8?!Y:VET92!P<F]B;&5MX"X`P7)A\'EK:71E(&YU;W)O
M9&]S(%523`!4=7)I=&4@<&%S:7)I;FMT:2!S97)V97+A+"!K=7+A(&YO<FET
M92!I\'1R:6YT:2X`3G5R;V1Y:VET92!V87)T;W1O:F\@=F%R9.`L(&MU<FEO
M(&1U;VUE;FES('1R:6YA=&4N`$YU<F]D>6MI=&4@=F%R=&]T;VIO('9A<F3@
M('1R>6YI;75I+@!.=7)O9'EK:71E(&MU<FEA;6\@=F%R=&]T;VIO('9A<F3@
M+@!.=7)O9'EK:71E(&%T;F%U:FEN86UO('9A<G1O=&]J;R!V87)DX"X`3G5R
M;V1Y:VET92!V96EK<VW@+@!*^W,@='5R:71E(.%V97-T:2!N875J;W,@:V%T
M96=O<FEJ;W,@<&%V861I;FEMX"X`)7,@<V5S:6IA(&)A:6?K<VDN(%!R8?!O
M;64@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@96PN('!A\'1O(&%D<F5S
M87,Z`$5L+B!P8?!T;R!A9')E<V%S.@!);F9O<FUA8VEJ82!A<&EE($IU<P!.
M=6\@)7,@<V5S:6IO<R!P<F%D_FEO<R!J^W/X($E0(&%D<F5S87,@<&%S:6ME
M:73K+B!4=7)I=&4@<')I<VEJ=6YG=&D@:?`@;F%U:F\N`$K[<_@@=F%R9&%S
M+W!A=F%R9.L`2OMS^"!A=71E;G1I9FEK879I;6\@<VES=&5M82!N97!A;&%I
M:V\@=F%R=&]T;VKX('/@<F'P;RP@87)B82#P:2!F=6YK8VEJ82!U_F1R875S
M=&$@9.ML('1A;2!T:6MR^"!P<FEE_F%SZ&GX+@!.=6\@)7,@<V5S:6IO<R!P
M<F%D_FEO<R!J^W/X(&YA<O!Y:VSK<R!T:7!A<R!P87-I:V5I=.LN(%1U<FET
M92!P<FES:6IU;F=T:2!I\"!N875J;RX`2OMS^"!N87+P>6MLZR!N97!A;&%I
M:V\@\&EO<R!G86QI;7EBZW,N`$K[<_@@;&%I:V\@:G5O<W1A.@!*^W/X('-T
M86YD87)T:6YI<R!A<')A\&%S.@!*^W/X('9A<F1A<R]P879A<F3K.@!*^W/X
M(&YA=6IA<R`E<R!S;&%P=&'^;V1I<R!Y<F$Z("5S`$K[<_@@;G5S=&%T>6UA
M:2!A=&YA=6II;G1I+@!*^W/X('-L87!T8?YO9&ES('!A:V5I<W1A<P!*^W/X
M('-L87!T8?YO9&ES('!A:V5I<W1A<RX@4&%S:71I:W)I;FMI=&4@<V%V;R!P
M8?!TX"!I<B!P<FES:6IU;FMI=&4@<W4@;F%U:G4@<VQA<'1A_F]D_FEU+@!*
M^W/X(&YU=&]LYB!S97)V97)I86DZ`$IU9V]S;&%V:6IA`%IA:7)A<P!:86UB
M:6IA`%II;6)A8G;K`$5N97)G:6YG;W,`6U!A<VSK<'1I(&-I='5O:F%MX"!T
M96MS=.!=`%M0<F]B;&5M;W,@<')A;F7P:6UA<UT`6U)O9'ET:2!C:71U;VIA
M;>`@=&5K<W3@("T`6U)O9'ET:2!C:71U;VIA;>`@=&5K<W3@("T@)7,@96EL
M=71E<UT`6V5I;'5TZR`E<R!I\"`E<UT`7U9A;&1Y;6%S`%]#3$D`7T1U;VUE
M;O@@;65D:7,`7TGP=')I;G1I(&5I;'5TY@!'7W)U<.MS`%!A7V=A;&)A`%]0
M879E:6MS;.ML:6\@;G5S=&%T>6UA:2XN+@!0<FES:5]J=6YG=&D`071S:5]J
M=6YG=&D`7TME:7-T:2!N=6]R;V3@+BX`7TYU<W1A='EM86D`7U1E:7/K<P!?
M2?!T<FEN=&D@;G5O<F]DX"XN+@!?2V]N9FEG^W)A8VEJ80!?3&5N=&5LZW,@
M;G5S=&%T>6UA:2XN+@!67V%R=&]T;VIA:0!A9')E<_@@:VYY9V5LZP!+86QE
M;F1O<FEU<P!R86UU<P!S<&%U<VMI=&4@Z&EA`&MR96YT80!F86EL87,`;G5O
M("5S("@E<RD@)7,@)7,`83H`='5O:F%U('!A=`!P87!R87-T:0!E:6QU=&5S
M70!M:VES;V9S(&ML86ED;W,@:V]D87,@)60@8F5D87)A;G0@25-/+@!V87)D
M87,`;F5R96%L:7IU;W1A`&1A<B!N97)E86QI>G5O=&$`=?YR8?#X(&MN>6=E
M;.L`<')O8V5N=&%I`'!I:W-E;&EA:0!K>6QA`')O9'ET:2!S:VER='5M=7,`
M<VUS,F5M86EL('!E<B!(5%10`'-T86)I;&D`9&%R8O@@<^!R8?!A<P!S;&%P
M=&'^;V3A('1U<FET92#A<F'P>71I(&1U(&MA<G1U<P!U;FEF:6MU;W1I`&1A
M;&ES`'9A<G1O=&]J;R!P87-I<FEN:VEM87,`=D-A<F0`<#H`=V5A=&AE<BYC
M;VT`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:V]?2U(O3$-?34534T%'15,`````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q-#$@,#(Q-3`S`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]K;U]+
M4B]H96QP+GAM;```````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,S,R,"`Q,#4Q-30S-#$T,2`P,C$T-#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP
M(C\^"CPA+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O:V]?2U(O:&5L<"YX;6PL
M=B`Q+C(@,C`P-"\P-2\R-R`R,#HR,CHQ-"!J86X@17AP("0@+2T^"CQH96QP
M/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4
M:&4@4&]R=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@
M<&%G92!P<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP
M;W)T86YT"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S
M:&]W(&AO=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I
M;B!Y;W5R($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A
M<BP@=&%S:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M
M('-E;&5C=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@
M=&AE<V4*("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T
M<R!T;R!C;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@
M;F5W(&UA:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E
M;G0@;W(@=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E
M;G1S(&]F('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@
M=&AE($QA>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO
M;W-E('=H:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G
M92!A<PH@('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E
M/2)N97<B/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R
M/"]T:71L93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T
M:&4@=V5B('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R
M+@H@($-L:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R
M('1O('%U:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A
M=F%I;&%B;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE
M;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@
M("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E
M;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK
M92!T;R!P97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL
M(&-H96-K('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R
M>2!I9#TB<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^
M"B`@("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M
M($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O
M=6QD(&QI:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F
M;W)E('1H97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC
M:&5C:V5D+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@
M=&\@8F4@<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET
M:"!N;R!C:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:V]?2U(O3$-?
M34534T%'15,O:&]R9&4N;6\`````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-3$P-34@,3`U,34T,S0Q-#$@,#(S,C(V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````-X2!)4`````BP$``!P```!T#```'0(`
M`,P8````````0"$```\```!!(0``"````%$A```+````6B$```P```!F(0``
M*````',A```2````G"$```@```"O(0``!0```+@A```1````OB$```,```#0
M(0``#P```-0A```(````Y"$```@```#M(0``&0```/8A```'````$"(```P`
M```8(@``#@```"4B```%````-"(```4````Z(@``"@```$`B```#````2R(`
M``X```!/(@``#P```%XB```?````;B(```4```".(@``.0```)0B```&````
MSB(``!$```#5(@``"@```.<B```0````\B(```@````#(P``!`````PC```&
M````$2,``!$````8(P``!P```"HC```$````,B,```8````W(P``#0```#XC
M```3````3",```@```!@(P``!@```&DC```5````<",```<```"&(P``"@``
M`(XC```/````F2,```T```"I(P``#P```+<C```-````QR,```D```#5(P``
M!@```-\C```&````YB,```X```#M(P``!0```/PC```J`````B0``!,````M
M)```#````$$D```0````3B0``!$```!?)```!0```'$D```%````=R0```8`
M``!])```!P```(0D```0````C"0```0```"=)```#@```*(D```I````L20`
M``8```#;)```#0```.(D```.````\"0```T```#_)````P````TE```-````
M$24```(````?)0``!0```"(E```$````*"4```X````M)0``"````#PE```/
M````124```\```!5)0``!P```&4E```0````;24```8```!^)0``"P```(4E
M```-````D24```H```"?)0``&0```*HE```6````Q"4``!0```#;)0``"P``
M`/`E```O````_"4```D````L)@``#P```#8F```F````1B8``$,```!M)@``
M"````+$F```+````NB8```0```#&)@``%P```,LF```1````XR8```H```#U
M)@```@`````G```%`````R<```D````))P``#0```!,G```.````(2<``!@`
M```P)P``!0```$DG```0````3R<``!````!@)P``#P```'$G```+````@2<`
M``\```"-)P``#````)TG```/````JB<```X```"Z)P``"````,DG```>````
MTB<``"$```#Q)P```P```!,H```(````%R@```P````@*```!P```"TH```*
M````-2@```8```!`*```!````$<H```'````3"@```(```!4*```!@```%<H
M```$````7B@``!$```!C*```(@```'4H```,````F"@```H```"E*```!0``
M`+`H```/````MB@``!(```#&*```"P```-DH```I````Y2@``"0````/*0``
M)@```#0I```2````6RD```H```!N*0``#P```'DI```0````B2D```X```":
M*0``"0```*DI```*````LRD``!(```"^*0``$````-$I```1````XBD```\`
M``#T*0``%`````0J```,````&2H```P````F*@``#P```#,J```5````0RH`
M`"D```!9*@``*@```(,J```F````KBH``"<```#5*@``*0```/TJ```J````
M)RL``!$```!2*P``$@```&0K```3````=RL``!0```"+*P``%@```*`K```7
M````MRL``!````#/*P``$0```.`K```3````\BL``!(````&+```!@```!DL
M```'````("P```4````H+```%@```"XL```$````12P```0```!*+```!P``
M`$\L```.````5RP```P```!F+```#````',L```-````@"P``!(```".+```
M#P```*$L```(````L2P```X```"Z+```%@```,DL```1````X"P```8```#R
M+```!````/DL```0````_BP``!H````/+0``!@```"HM```'````,2T```L`
M```Y+0``$P```$4M```3````62T``!,```!M+0```@```($M```$````A"T`
M``T```")+0``!0```)<M```&````G2T```\```"D+0```P```+0M```*````
MN"T```L```##+0``!P```,\M```&````URT```H```#>+0``!P```.DM```)
M````\2T```<```#[+0``!`````,N```'````""X```4````0+@``$P```!8N
M```$````*BX```(````O+@``,P```#(N```S````9BX``#@```":+@``!```
M`-,N```%````V"X```@```#>+@``$0```.<N```.````^2X```<````(+P``
M'P```!`O```'````,"\```X````X+P``#````$<O```,````5"\```4```!A
M+P``$0```&<O```'````>2\```@```"!+P``%0```(HO```%````H"\``!0`
M``"F+P``!````+LO```'````P"\``!X```#(+P``%````.<O```%````_"\`
M``8````",```*`````DP```I````,C````<```!<,```(0```&0P```.````
MAC```!,```"5,```%P```*DP```+````P3````4```#-,```$0```-,P```%
M````Y3```!(```#K,```!````/XP```.`````S$```X````2,0``!0```"$Q
M```2````)S$```0````Z,0``#````#\Q```&````3#$``&D```!3,0``&@``
M`+TQ```7````V#$``!<```#P,0``&P````@R```?````)#(``!,```!$,@``
M"0```%@R```E````8C(``"````"(,@``)````*DR```@````SC(```0```#O
M,@``$````/0R```<````!3,``"@````B,P``!P```$LS```3````4S,``!<`
M``!G,P``"@```'\S```,````BC,```D```"7,P``#0```*$S```+````KS,`
M``<```"[,P``!@```,,S```)````RC,```<```#4,P``!P```-PS```+````
MY#,``!````#P,P``$`````$T```%````$C0```0````8-```"0```!TT```*
M````)S0``!\````R-```&P```%(T```^````;C0``",```"M-```'P```-$T
M```]````\30``"$````O-0``'````%$U```%````;C4``!````!T-0```@``
M`(4U```2````B#4```,```";-0``$````)\U```#````L#4``"\```"T-0``
M(````.0U```D````!38``"4````J-@``(````%`V```F````<38```D```"8
M-@``#````*(V```7````KS8```X```#'-@``#0```-8V```:````Y#8```<`
M``#_-@``"P````<W```3````$S<``!,````G-P``#````#LW```(````2#<`
M`!0```!1-P``#@```&8W```0````=3<```<```"&-P``!P```(XW```&````
MEC<```<```"=-P``#0```*4W```+````LS<``"````"_-P``'````.`W```%
M````_3<``!(````#.```"@```!8X```&````(3@```P````H.```"@```#4X
M```"````0#@```8```!#.````P```$HX``!%````3C@``!D```"4.```10``
M`*XX```P````]#@``"8````E.0``)0```$PY```P````<CD``!(```"C.0``
M$P```+8Y```0````RCD```D```#;.0``<P```.4Y```K````63H``!<```"%
M.@``%@```)TZ```/````M#H``$````#$.@``'P````4[```2````)3L``!``
M```X.P``$P```$D[```=````73L```\```![.P``#P```(L[```+````FSL`
M``4```"G.P``%````*T[```(````PCL```\```#+.P``"````-L[```/````
MY#L``!0```#T.P``!@````D\```$````$#P```<````5/```!@```!T\```'
M````)#P```4````L/```4@$``#(\```,````A3T```<```"2/0``!P```)H]
M```'````HCT``!<```"J/0``%0```,(]```'````V#T```D```#@/0``"P``
M`.H]```$````]CT``!,```#[/0``#P````\^```+````'SX``!0````K/@``
M!````$`^```&````13X```0```!,/@``"@```%$^```$````7#X```4```!A
M/@``"0```&<^```(````<3X```<```!Z/@``%P```((^```#````FCX``!<`
M``">/@```P```+8^```,````NCX```0```#'/@``"0```,P^```$````UCX`
M``0```#;/@``!````.`^```)````Y3X```0```#O/@``!````/0^```$````
M^3X```L```#^/@``#`````H_```$````%S\```0````</P``$@```"$_```$
M````-#\```8````Y/P``!P```$`_```'````2#\```<```!0/P``!P```%@_
M```&````8#\```8```!G/P``!````&X_```.````<S\```0```""/P``%0``
M`(<_```4````G3\```<```"R/P``#0```+H_```+````R#\```0```#4/P``
M`P```-D_```&````W3\```0```#D/P``"0```.D_```$````\S\```0```#X
M/P``*P```/T_```&````*4````L````P0```"@```#Q````+````1T````8`
M``!30```!@```%I````"````84````0```!D0```!````&E````)````;D``
M``0```!X0```!````'U````(````@D````0```"+0```"P```)!````$````
MG$````<```"A0```!P```*E````'````L4````P```"Y0```#````,9````)
M````TT````4```#=0```*@```.-````(````#D$```D````700``)P```"%!
M``!#````24$```@```"-00``"P```)9!```$````HD$```P```"G00``#@``
M`+1!```'````PT$```(```#+00``!@```,Y!```(````U4$```D```#>00``
M"P```.A!```-````]$$```0````"0@``"0````="```)````$4(```@````;
M0@``"P```"1"```)````,$(```0````Z0@```P```#]"```-````0T(```8`
M``!10@``$P```%A"```3````;$(```0```"`0@```P```(5"```+````B4(`
M``0```"50@``"0```)I"```&````I$(```0```"K0@``!````+!"```$````
MM4(```0```"Z0@``!@```+]"```&````QD(``!X```#-0@``!P```.Q"```+
M````]$(```4`````0P``!@````9#```)````#4,```4````70P``$P```!U#
M```.````,4,``!,```!`0P``#@```%1#```&````8T,```T```!J0P``#```
M`'A#```.````A4,```@```"40P``"0```)U#```/````IT,```P```"W0P``
M$````,1#```(````U4,``!````#>0P``"0```.]#```'````^4,```P````!
M1```#@````Y$```7````'40``!<````U1```%P```$U$```7````940``!@`
M``!]1```&````)9$```,````KT0```P```"\1```#````,E$```,````UD0`
M``X```#C1```#@```/)$```,`````44```P````.10``#@```!M%```.````
M*D4```@````Y10```P```$)%```$````1D4``!0```!+10```P```&!%```#
M````9$4```0```!H10``"P```&U%```)````>44```D```"#10``"P```(U%
M```(````F44```\```"B10``!````+)%```1````MT4``"````#)10``$P``
M`.I%```(````_D4```0````'1@``"P````Q&```;````&$8```8````T1@``
M"````#M&```/````1$8```T```!41@``"P```&)&```0````;D8```(```!_
M1@``!````()&```0````AT8```,```"81@``"````)Q&```-````I48```,`
M``"S1@``"0```+=&```)````P48```8```#+1@``!@```-)&```(````V48`
M``0```#B1@``"P```.=&```)````\T8```0```#]1@``"`````)'```(````
M"T<```T````41P``!````")'```&````)T<``",````N1P``'````%)'```A
M````;T<```T```"11P``!````)]'```$````I$<```<```"I1P``!P```+%'
M```$````N4<``!$```"^1P``"````-!'```+````V4<```D```#E1P``!```
M`.]'```$````]$<```D```#Y1P``!`````-(```$````"$@``!D````-2```
M!@```"=(```3````+D@```0```!"2```!@```$=(```3````3D@```D```!B
M2```"````&Q(```$````=4@``"$```!Z2```'@```)Q(```(````NT@``!``
M``#$2```"0```-5(```)````WT@``!````#I2```#P```/I(```)````"DD`
M`!$````420``!@```"9)```,````+4D```0````Z20``!P```#])```'````
M1TD```,```!/20``$@```%-)```$````9DD```T```!K20``!````'E)```[
M````?DD``!,```"Z20``#@```,Y)```.````W4D``!D```#L20``'P````9*
M```8````)DH```,````_2@``#@```$-*```.````4DH```X```!A2@``$```
M`'!*```$````@4H```T```"&2@``!@```)1*```:````FTH```0```"V2@``
M#0```+M*```.````R4H```<```#82@``!P```.!*```'````Z$H```@```#P
M2@``"P```/E*```$````!4L```0````*2P``"`````]+```$````&$L```0`
M```=2P``!@```")+```'````*4L```<````Q2P``!````#E+```&````/DL`
M``0```!%2P``"0```$I+```8````5$L``!X```!M2P``+0```(Q+```>````
MNDL``!\```#92P``/P```/E+```I````.4P``!@```!C3```!````'Q,```-
M````@4P```D```"/3```#@```)E,```"````J$P``!$```"K3````P```+U,
M```M````P4P``!X```#O3```&P````Y-```D````*DT``"@```!/30``(0``
M`'A-```$````FDT``!$```"?30``$````+%-```$````PDT```0```#'30``
M%0```,Q-```)````XDT```D```#L30``#0```/9-```0````!$X```\````5
M3@``"````"5.```0````+DX```D````_3@``"0```$E.```'````4TX```0`
M``!;3@``!````&!.```$````94X``!8```!J3@``#@```(%.```7````D$X`
M`!<```"H3@``!````,!.```)````Q4X```D```#/3@``!0```-E.```*````
MWTX```T```#J3@```@```/A.```$````^TX```(`````3P``/0````-/```4
M````04\``#X```!63P``*0```)5/```E````OT\``"4```#E3P``+`````M0
M```,````.%````H```!%4```!````%!0```%````55```',```!;4```)P``
M`,]0```,````]U````P````$40``"@```!%1```?````'%$``!8````\40``
M#0```%-1```/````85$```P```!Q40``$P```'Y1```.````DE$```8```"A
M40``"0```*A1```&````LE$```X```"Y40``"@```,A1```.````TU$```H`
M``#B40``#0```.U1```,````^U$```,````(4@``!`````Q2```&````$5(`
M``0````84@``"0```!U2```%````)U(```$```#W````;P$```````!3`0``
M`````%H```"L````%P$``"``````````/P````H```#+````C0```&<```#D
M````+`$``-T`````````:0```+$```!Z````I`````````#Y````A@```&(`
M``!8`0``$P$``#@````````````````````?`0``,P$``.8```#[````LP``
M``````"\`````````*,```#>`````````#4````^`````````!(!``""`0``
M+P```%L!``!$`0``7P```'P!``".``````````````#<````````````````
M````?@$``%T```````````````````````````````````"F````R````%H!
M``"I````2@```/4`````````S``````````;````'0$``)X````6````"`$`
M`+@```#7`````@````````"9````\@````,```#3````U````-(```!T`0``
M5P```.X``````0``;0$``$<!``#*````````````````````$`$``.H```"+
M````[````'$````E`0``SP`````````'````)@$````````(````*P```*L`
M``````````````````"*````3P$``)0```!X`0``&@`````````2````;0``
M`#T!``!4````9@````````!/````-P$``%L````R`0``?0``````````````
M_`````````"J`````````%4!```7````A0```$````"+`0``^@````````"@
M````5@```!@!``"8````/````$L!``!V````1@```,0`````````/@$`````
M```]````X@```(````!J`0``90`````````A`0``90$```````""````7`$`
M``````#O`````````(8!``!!````2@$``!0!``"_````B````&L`````````
MV0````````#.````9``````````&````Y0```.,```!,````0`$``+D````:
M`0```````%\!``#G`````P$```````!K`0``AP$```````!(`````````(,`
M``!H`0```````#L!```<`0``Z````+(```#6````1P``````````````S0``
M`(`!``#_````.@```'X`````````(@````````!"`0``R0````````!1````
M60$``),`````````$0```,``````````=P$``'````#^````O0````````!(
M`0```````'P`````````:0$``%X!``")```````````````L````$P``````
M````````AP```,(``````````````'T!```O`0``!`$```H!``!V`0``#@$`
M`'\!````````]`````````!1`0````````````!&`0``4@``````````````
MVP```/,````.````=````.$`````````.@$``%`!``#%````E@````````!C
M````ZP```#,````N````V@````0```!F`0````````````!A````(P````(!
M``"A````>0$``(,!``"T````4@$``+8````,````>``````````8````````
M`+X````,`0``#0$``)(````\`0````````\!````````<P```$X````>`0``
M'`````````#0`````````)$````A`````````.D````D````=0```-$````6
M`0````````````"5`````````"X!``!$````(P$``#`!```1`0``*0$``!0`
M````````,@``````````````4````+H````G````B0$```````"<````QP``
M```````V`0```````#0!````````;``````````'`0``60```%X```"$`0``
M`0$``(4!```9````;@$```````!G`0````````````"U`````````$T!````
M````>P```(@!``!,`0``8@$``'H!``!<````#0```$X!````````+0```%<!
M````````-``````````/````>0```!L!`````````````+`````5`0``````
M``4````)````!0$``"L!``#X````!@$```````!D`0``.P```'<`````````
M`````&$!`````````````!T```"[````;`$``!4```!)````*@$``($```!_
M`````````'$!``!O````H@```#\!`````````````$(`````````8P$``',!
M``"N````$`````````"M````-@`````````P````*`$```````!8````:@``
M`)```````````````,8`````````<`$````````H````50```/T`````````
M<@```"T!```E````"0$``"<!``"E`````````,$```#@``````````````#8
M````)@````````"/````\`````````![`0``G0````````"O`````````+<`
M``!U`0```````!D!```Y`0``(`$``"0!````````.0`````````+````````
M```````B`0``IP```(0```":````8````!X````Q`0``C````&`!```J````
M0P$``$T```!)`0``4P```,,```!+````"P$`````````````0P```%8!``"H
M````-0$```````"?````.`$```````!N````\0```%0!```I````:````-4`
M````````'P```#$````W````EP```%T!``"!`0``<@$```````#V````00$`
M`.T```";````10$```````#?````10```(H!````("A!8V-E<W-K97D@)7,I
M`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`E<R!-86EN=&5N
M86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(&%L<F5A9'D@97AI
M<W1S+@`R-"!H;W5R<P!!32]030!!8F]U="!T:&ES(&5D:71O<@!!9&0`061D
M(&$@;F5W('5S97(Z`$%D9"!P86ER`$%D9"!U<V5R`$%D9&EN9R!U<V5R<R!I
M<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1R871I
M;VX`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL(&9O=7(@<VED97,`
M06QT97)N871E('1E>'0Z`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE
M9"X`07!R:6P`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA
M:6YT96YA;F-E(&]P97)A=&EO;G,_`$%U9W5S=`!!=F%I;&%B;&4@9FEE;&1S
M.@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0FER=&AD87D`0F]L9`!"
M;W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W1H`$)O='1O;0!"
M=6QL971E9"!,:7-T`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD87(`0V%N
M8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#87!T:6]N`$-E;&P@4&AO;F4`
M0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T:65S
M`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#:&%N9V4`0VAE8U]K
M($QI;FLN+BX`0VAI;F$`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R
M9&5R960@;&ES=',I`$-L96%R($U33V9F:6-E('1A9W,`0VQO<V4@5VEN9&]W
M`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;W(`0V]L
M<SH`0V]M:6-S`$-O;7!A;GD`0V]N9FER;2!087-S=V]R9`!#;W!Y`$-O<'D@
M<V5L96-T:6]N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A<VL@;6]D
M=6QE("5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-U<G)E;G0@55),(&ES`$-U
M<G)E;G0@<W1Y;&4`0W5T`$-U="!S96QE8W1I;VX`1$0`1&%I;'D`1&%T90!$
M95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L(&YU;6)E<G,`1&5C<F5A
M<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&5L
M971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@<F]W`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$97-C<FEB
M92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7)E8W1O<GD`1&ES<&QA
M>2!/<'1I;VYS`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@
M)7,`161I=`!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%;&5M96YT+BXN`$5M`$5M86EL`$5M;W1I8V]N<P!%;7!T>2!R97-U
M;'0N`$5N;&%R9V4@161I=&]R`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%
M<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@
M-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M
M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X<&%N9"!3:61E8F%R`$9'($-O;&]R
M`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N
M;F5C="!T;R!,1$%0('-E<G9E<BX`1F%X`$9E8G)U87)Y`$9I;&4@36%N86=E
M<@!&:6QT97)S`$9O;G0@0V]L;W(`1G)A;65S`$9R;VT`1V5R;6%N>0!';P!(
M96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(97)E(&ES('1H92!B96=I
M;FYI;F<@;V8@=&AE(&9I;&4Z`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO
M<F1E`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R:7IO
M;G1A;#H`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G
M93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M
M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$E?;G-E<G0@4F]W
M($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S
M(&YA;64Z`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W
M($%F=&5R`$EN8W)E87-E($EN9&5N=`!);G-E<G0@0U]O;'5M;B!!9G1E<@!)
M;G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E
M<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E
M;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!)
M;G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS
M97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU
M;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T('!A<F%G<F%P
M:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F
M=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="]-;V1I9GD@26UA9V4`26YS
M97)T+TUO9&EF>2!,:6YK`$ET86QI8P!*86YU87)Y`$IA<&%N`$IA<&%N97-E
M("A)4T\M,C`R,BU*4"D`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT
M97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MO
M<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`3&%N9W5A9V4`3&%S
M="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN
M.B!.979E<@!,87EO=70`3&5F=`!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@
M=7-E<G,@:7,@9&ES86)L960N`$QO9R!I;@!,;V<@;W5T`$QO9VEN(%1A<VMS
M`$QO=V5R(&=R965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E
M<B!R;VUA;B!N=6UB97)S`$U-`$UA:6P`36%K92!L:6Y?:RXN+@!-87)C:`!-
M87)G:6X`36%T8VAI;F<@9FEE;&1S`$UA>0!-96YU(&UO9&4Z`$UE<F=E(&-E
M;&QS`$UE<W-A9V4`36ED9&QE`$UO9&EF>2!54DP`36]N=&AL>0!-;W9E($1O
M=VX`36]V92!5<`!.86UE`$YE='=O<FL`3F5V97(`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97AT`$YO`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E
M8VEF:65D(&9O<B!&5%`@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RX`3F]N90!.
M;W1E<P!.;W9E;6)E<@!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W
M<P!/8W1O8F5R`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W:6YD;W<`3W!T
M:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`%!A9&1I;F<`4&%S<W=O<F0`4&%S
M<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D
M`%!A=&@`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R<V]N86P@26YF;W)M871I;VX`4&AO;F4`4&EX96QS`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4')E=FEE=P!0<F5V:65W('1H
M92!I;6%G92!I;B!A(&YE=R!W:6YD;W<`4')I;G0@9&]C=6UE;G0`4')O8FQE
M;2!$97-C<FEP=&EO;@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!296UO=F4@
M<&%I<@!297-E=`!2971U<FX@=&\@3W!T:6]N<P!2:6=H=`!2;U]W(%!R;W!E
M<G1I97,N+BX`4F]L90!2;W<@4')O<&5R=&EE<P!2;W<@<')O<&5R=&EE<P!2
M;W=S.@!386UE(&9R86UE("A?<V5L9BD`4V%V90!3879E($]P=&EO;G,`4V5A
M<F-H`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B
M;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@
M9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R
M.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE('1I;64@9F]R
M;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E<'1E
M;6)E<@!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE
M(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T
M:65S(&1I86QO9P!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4W!A8V4@8F5T=V5E
M;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O
M<F1E<B!I;B!C96QL`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W1R:6ME=&AR;W5G:`!3='EL92!;0U-370!3=6)J96-T`%-U
M8FUI=`!3=6)S8W)I<'0`4W5C8V5S<P!3=6UM87)Y`%-U<&5R<V-R:7!T`%1A
M8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!487-K<P!497AT`%1E
M>'0@3VYL>0!497AT(&%L:6=N`%1H86YK('EO=2!F;W(@=7-I;F<@=&AE('-Y
M<W1E;2X`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I
M;F<@87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE
M<W-A9V4N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D
M+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!V86QU
M92!M=7-T(&)E(&$@;G5M8F5R+@!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O
M`%1O9V=L92!(5$U,(%-O=7)C90!4;W``5&]P(&9R86UE("A?=&]P*0!54DP`
M56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E
M<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!R96%D('1H
M92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE
M;G0`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C
M=&EO;@!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N;&EN:R!T:&4@
M8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YS970@8V]L;W(`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S97(@3W!T:6]N<P!5
M<V5R;F%M90!5<V5R<R!I;B!T:&4@<WES=&5M.@!697)T:6-A;"!A;&EG;@!6
M97)T:6-A;"!P861D:6YG`%9I97<@)7,`5V%R;FEN9P!7965K;'D`5V5L8V]M
M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@:7,@=&AE(&1E;&EM
M:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`
M5VED=&@`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=O
M<FL@061D<F5S<P!7;W)K(%!H;VYE`%E9`%EE87)L>0!997,`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S<&5C:69Y(&$@
M=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@3F%M90!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI
M<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M(
M:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E
M9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@
M)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?1&5L971E(%)O=P!?2&5L<`!?
M26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`
M7T]P=&EO;G,`7U)E;6]V92!,:6YK+BXN`%]486)L92!0<F]P97)T:65S+BXN
M`&QI;F5S70!N86UE`'!E<F-E;G0`<&EX96QS`'5N;F%M960`=D-A<F0`4')O
M:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I9"U"
M=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E
M.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P
M,2TQ,2TP.2`Q-CHR.2LP.3`P"DQA<W0M5')A;G-L871O<CH@2FEN:'EO:R!(
M96\@/&YO=F5M8G)E0&]U<FYA='5R92YO<F<^"DQA;F=U86=E+51E86TZ(&DQ
M.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U%54,M2U(*0V]N=&5N="U4<F%N
M<V9E<BU%;F-O9&EN9SH@.&)I=`H`("BTW,/@Q;`@)7,I`"`HO\"TPRD`("BS
MN\#/*0`@*+[NP:8I`"5S(,"OP?:P_+BN(,#;OO<@+2#(KL#.`"(E<R*TPB#`
MS+G,(,#6O<"TS[39+@`R-""]P["C`+_`P/POO\#(Q`#`S""_H;7PQ<VTP@##
MW["A`+OUM\Z_[B"[Y[_KP-H@P]^PH3H`QN2^[BAP86ER*2##W["A`+OGO^O`
MVB##W["A`+OGO^O`VB##W["A(+OGO^N^R,?4`,'6O-(`P=:\TK?/`+#\N*X`
MOO.V\\#,ONZ]N@#!I+?$`,&DM\0Z`+CPM<X@O+'%PP"X\+7G(#2XZ0"TZ\.\
M(+';`,#?N/BUR""YKL#:L*$@P-:]P+3/M-DN`#2_^0#`K\'VL/RXKKW'Q^#`
M_"#(KL#.Q\^QX@`XO_D`L*&TR<?1(,?*M>4Z`+GHL.8`N>BPYB"[]K'R`+O]
MP,\`L;VPU`"PYK#H`+#FL.@@M<ZRL@"PYK#H`+CPM<X`OL:WH0"QXLBC(+BN
MO;K&K@!?9;R_(+S3O+HN+BX`M-ZWP@##Z[S2`+_`M_D@NKBP[<?/L>(@P^N\
MT@#$N+S'`,C>M.O&^0"\OR"\T[RZ`+R_(,;DM?D`O+\@O-.\N@"\OR"PH[#=
M`,C>M.O&^0"PH;_NM:4`NJ^PY@!?:[BUQ:D@L,N[YRXN+@#!W[&Y`+SXO*T@
MN*Z]NL:N(,&^M_D@O+'%PP!-4[_`Q\>]NB#%U['7(,'VO^RQX@##HB"TW;'B
M`+_>PLJXM[3K(+3=L>(`Q]7#Q,'X(+#FL.@`N_:Q\@"_K3H`0V]M:6-S`,BX
MN^<`OL_(HR#(KL#.`+JYN^<`NKF[YP!-86EN=&5N86YC95]487-K(+CPM>(@
M)7,@N*8@OZT@O/8@OOB]P+3/M-DN`+BXM>FQX@"XM<6I(+BXM>FQX@#']L#G
M(%523,"Z`,?VP.<@O;K%N,#/`,#:N*.QX@#`VKBCL>(`1$0`P,^ZL`"SK\*E
M`%]LOZT@N^C!I@`Q,K_Y`+S]P-H`L[N^[KZRL>(`L>*ZNP"QXKJ[(+W$NK#`
MV@"[Z,&F`+R_(+OHP:8`OZT@N^C!I@#'X""[Z,&F`,?VP.<@OZT@P?:_\@#'
M]L#G(,?@(,'VO_(`O\"W^2"\L[CM`+RSN.TZ`+R\NL[!I+JXL*$@L/RXKL#:
MN*8@P*?'V""QXK?/M<>^[L&SO<"TS[39+@"U\+>ZQ>2XK@#(K;CI(+RSP:0`
M;6%I;G1E;F%N8V4N<&APOZ$@P??!HB#!HK'9Q\_!]B"XMKR\O^0N`,.YN?C"
ML"#'X,"Z(,?7N/$@P,RXI\"[(+"NL.T@P-:]P+3/L>X_(+'7M[BTV;CI+""_
MJ;'BN*8@P[S%J<?/O+R_Y#H`L[NWP;G>L>(`)7,@L[NWP;G>L>(`O/;!I``E
M<R"QQ\?1(+SVP:0`O+'%P[OGQ]<@O/;!I#H`O^2\TBXN+@!E;0#`S+C>P,\`
MP,RX\,:\Q-P`L.&P^B"^^,"]`,;MP?VQXB#(KK3K`+'7N+(@55),(,#4M\(`
MO\"W^0`Q-;K0(+BVM-D`,S##RB"XMK39`#6ZT""XMK39`+CPM><@M\ZQU\#.
M`#,PNM`@N+:TV0"XQ;K0`+^Y.@"_WL+*N+>TZR#(KL#E`,#\L.:[]@#(K[#F
MO+/!I"#`T+'B(+_`M_DN`$Q$05`@O*VY]B#!HKS3(+W'QM``QM&]N@`RO_D`
MQL3`SR"P_+BNP-H`Q\K%S0"QV\#:(+OVL?(`Q\&WN<#3`,"GQ*$`M;;`SP"P
MH;'B`+/TP,P`M;6_\KB[`+6UO_*XNP#&Q,#/P,<@O</`V\#,(+39P+VP^B"P
ML+W`M,^TV3H`P?T@P=:\T@#!_2#`_,BMN?C(HP!(;W)D90"\]L;RO+$`L*&W
MSB##I+_R`+"AM\XZ`,?5Q*&P[2"]S<"Z(+^MP,<@O/8`Q]>X\2B_K2G`QR"\
M]C\`Q]7$H;#M(+W-P+H@Q^#`QR"\]@!?;K[5OZ$@Q^`@P]^PH0"^QL#,Q-P`
MOL;`S,3<L/H@N:[`V@"]Q+JPP-H@P,RXISH`L=>XLB"YS+BNNKBQXCH`L=>X
MLB!54DP`L=>XLB!54DPZ`+"AP:Z_PB#'U[CQ.B`E<P"PH<&NO\(@Q]>X\3H`
M7W.TV<"]OZ$@Q^`@P]^PH0"UZ;^IOK*QX@!?;[39P+V_H2"_K2##W["A`+'7
MN+(@P]^PH0#'I2##W["A`,"E(+BUQ:D@P]^PH0!?8[[5OZ$@OZT@P]^PH0#'
M]L#G(+^M(+7:OZ$@N_4@OZT@P]^PH0#']L#G(+^M(+[5OZ$@N_4@OZT@P]^P
MH0#']L#G(,?@(+7:OZ$@N_4@Q^`@P]^PH0#']L#G(,?@(+[5OZ$@N_4@Q^`@
MP]^PH0#']L#G(,'VP:$@M=J_H2"TW+;T(,/?L*$`Q_;`YR#!]L&A(+[5OZ$@
MM-RV]"##W["A`+7:OZ$@O+\@P]^PH0"^U;^A(+R_(,/?L*$`M=J_H2"_K2##
MW["A`+[5OZ$@OZT@P]^PH0"UVK^A(+3<MO0@P]^PH0"^U;^A(+3<MO0@P]^P
MH0"UVK^A(,?@(,/?L*$`OM6_H2#'X"##W["A`+'7N+(@P]^PH2^\]L&D`+BU
MQ:D@P]^PH2^\]L&D`+'BO^_`S+'B`#&_^0#`S[J[`,#/NKN^[B`H25-/+3(P
M,C(M2E`I`#>_^0`VO_D`P:2WQ`"PH;_NM:4@P:2WQ`"^Y\+*(,&DM\0`O]["
MRB#!I+?$`+_`N*7"RB#!I+?$`+3KQ]&YSK&Y`,?1L;F^[B`H155#+4M2*0"^
M\+[N`+BVP?:XMR"WSK'7P,XZ("5S`+BVP?:XMR"WSK'7P,XZ("5S+"#!HKS3
M(,"GQ*$Z("5S`+BVP?:XMR"WSK'7P,XZ(+[XP+T`M[G`S+[&O_0`O]["R@"U
MM;_ROLL@N/'"]P"[Y[_KQ](@O/8@OOBTPB"[Y[_KP-H@N/&WSRX`M\ZQU\#.
M`+?.L=>^QK_T`+?.L=?`SB"]P\#;P-N^]P"QU[BNO;H@O-*YKL#:`+;SQKX@
MO-*YKL#:`+?.N+8@O-*YKL#:(+S]P-H`34T`N-[`SP!?:[BUQ:D@N+BUZ;'B
M+BXN`#._^0"PH<#EP-JXK@#`S\2AQ\^TPB#'U[CQ`#6_^0"XWK2Z(+CPM>4`
MO+\@Q]7$H;'B`+C>O</!]@"PH;_NM:4`55),(+SVP:0`N,6_^0"^QK>AM\X@
MP,RUOP#`I[?.(,#,M;\`P,RXIP"SU\:NO_;%J0"[Y[_KOLC'U`"[]2##HBA?
M8FQA;FLI`+39P+T`OL:TS[_``$944"!61E.XIB#`I\?1(+RSP:3!I+JXL*$@
MOOB]P+3/M-DN`%-13"!61E,@O+/!I,&DNKBPH2"^^+W`M,^TV2X`4U%,+49I
M;&4@5D93(+RSP:3!I+JXL*$@OOB]P+3/M-DN`+RQQ</'S\'V(+[*P+T`POS!
MM@`Q,;_Y`+^MP,<@O/8`Q^#`QR"\]@`Q,+_Y`+OU(,.BOZ$@N+7%J2"_K;'B
M`+RQQ<.[Y\?7`"5S(+RQQ<.[Y\?7`+S]P-H@N/&WSP"TW,.\`+'BQ;@`L>+%
MN"#!I+JX`,;DM?D`OL_(HP"^S\BCL*$@P,_$H<?/P?8@OLJ]P+3/M-DN`+K9
MP,RQX@#%K+BSNKBUY;^AO*T@NMG`S+'B`+#FM\X`QMN\OL:N`,"OP?8@L/RX
MKB#`V[[W(+W'Q^``L+/`SB#!I+JX`,#\R*VY^,BC`,?(O+\`N:[!IK^A(+3K
MQ]$@O^2^X,"[(,#4M\+'V"#!UKR\O^0N`+OGO^O`VL#,N*>P^B"^S\BCN*8@
MP-2WPL?/O+R_Y`"YS+BNNKBQX@"[]2##HK^A(+G,N*ZZN+'B`+FNO*T@P,Z\
MX@"YKL&F(+RSN.T`N+;!]KBW(+CMM\D@N=VZN0#&Y+[N*'!A:7(I(+OHP:8`
MP-2WPB##Z[S2`+_)O,?`N+?.(+6YOL:PH;'B`+_`N*7"R@!?=\?@(+S3O+HN
M+BX`OZK'T@#'X""\T[RZ`,?@(+S3O+H`Q^`Z`+"PP+H@Q\&WN<#3*%]S96QF
M*0#`^L#E`+RQQ<.[Y\?7(,#ZP.4`L,N[]@"^QK>A(+OSP-J_H;RM(,?*O^3'
MT2"YKL#:N*8@O+'%P\?/L.T@NKF[Y\?/OZD@NMF_J;/6P+B\O+_D+@"SK\#:
M(+&XNM#'I;W#(+RQQ<,Z`+.OP-H@Q_R]Q""\L<7#`+W#L*,@Q_R]Q""\L<7#
M`+7.L+/`QR#`S\2AQ\^TPB#'U[CQ(+RQQ<,`P-K!UKOGO^O'S[3"(+[PONZX
MIB"\L<7#Q\^\O+_D+@"YKL&FN=^[_2"ZN+#MO*T@P/R\V\?/L>(`.;_Y`+R_
M(+S3O+K#HB"ZN+'B`,>E(+S3O+K#HB"ZN+'B`+^M(+S3O+K#HB"ZN+'B`+'7
MN+(@O-.\NL.B(+JXL>(`Q:FQX@#`K\'VL/RXKB"[_;>K`+R_L*.PW0"\OR"P
MYK#HO\T@L[N_ZR"[Y\#,P,<@L*.PW0"PQ;BN`+#%N*Z_S2##I+_LL>(`QJ^\
M]B"YKL#:(,#4M\(`O+\@NM#'T@"_K2"ZT,?2`,?@(+K0Q](`L*&_[K6EP=D`
MO;K%N,#/6T-34UT`P::X\0#!IL/B`+[&MZ'#M\#:`+RZL/@`O^2^X`#`K<.W
MP-H`QZ4@O-.\N@#'I2"\T[RZ`,#;OO<`N:[`VK^M`+FNP-H`N:[`VB#!I+?$
M`+OGO^O'V,'6O,6\K2"PJ+OGQ]6TS[39+@#&Q,#/OZ$@OL:YJ[>Q(,#:M^&P
MH2"^^+W`M,^TV2X`OL:WH;3"(,#,(&UE<W-A9V4O<F9C.#(R(,;MP?;`QR"X
MT[BTN+O`U+3/M-DN`+W$NK#`VB`B)7,B(+"A(+OHP::UQ[[ZO<"TS[39+@#`
MS+_KL*&TR<?1(+RQQ<.[Y\?7P,P@OOB]P+3/M-DN`,;$P,\@O\.XKK'BOZ$@
MN:[!IK"A(,#6O<"TS[39+B`E<R#&Q,#/P,P@OO>WSK7EM<?!]B"^RK[2O<"T
MS[39+@#`S""\_<#:M,(@P]:\TL?1(#'`VKBN(,#,N_/`S+[NOM\@Q]6TS[39
M+@#`S""PJL"Z(+S]P-J_J;[?(,?5M,^TV2X`P::X\0#%N,#,QK(HQ?C&P2DZ
M`+G>M,(@N^>V]P!(5$U,(+S2O;H@NKBQX@#`IP"[\\"G(,?!M[G`TRA?=&]P
M*0!54DP`5D93(,;$P,\@)7,O)7/`QR#&V[G,O,?`NR"ZK[#FQ](@O/8@OOB]
MP+3/M-DN`%-13""\K;GVOZ$@P:*\T\?2(+SV(+[XO<"TS[39+@`E<R#!I,#'
MN*8@P-#`NR"\]B"^^+W`M,^TV2X`=F9S<F]O=""U\+>ZQ>2XKKBF(,#0P+L@
MO/8@OOB]P+3/M-DN`%9&4R#&Q,#/("5S+R5SP+LHN*8I(+JOL.;'TB"\]B"^
M^+W`M,^TV2X`P,P@O_:UY;FNO*VXIB"ZK[#FQ](@O/8@OOB]P+3/M-DN`+G8
MP=D`NJ^PYKOGQ]<@M<>UN;BNL>(`N+;!]KBW(+CMM\D@P^N\T@"_M;&Y`+G,
ML;D`Q_;`YR"_Y+S2OZ$@N+7%J2#!IK#%`,#,N*<@OOC`O0"[]K'R(,&FL,4`
MMO/&OK[N(+3KN:[`V@"WSKBV(+3KN:[`VB"\_<#:`+OGO^O`VB"\L<7#N^?'
MUP"[Y[_KP-JX[0"]P[VZQ=O`QR"[Y[_KP-HZ`+SVP?<@P:2WQ`"\]L'W(,.D
MO_(`)7,@NKBQX@"PYK#M`+C%P=8`R*^_M0#(K[^UQ]6TS[39(2`E<R#`U+3/
MM-DN`,BOO[7'U;3/M-DL("5S`+&XNM`@N:[`VK3"(+FKOOG`U+3/L>X_`,#.
MO^L@NL[(H[3"(+FKOOG`U+3/L>X_`+/*NO$`QZ7`QR"SRKKQ`+/*NO$@M-S`
MIP"SRKKQ.@#!]\#E(,'6O-(Z`,'WP.4@P/S(K;GXR*,`65D`N,6SX@"_N0!4
M15A4N/"UY<#4M,^TV2X@6SP^72"Y]L:PP+L@M*FXH[CI(%=94TE764<@N/"U
MY;?.(+6YOL:PJ;3/M-DN`+?.L=>^QK_T(,?/O[2]P+3/M-DN`+FNP:8@NKBP
M[;RMN*8@NKBSN['BP/R_H2#`S+FNP::_H2"TZ\?1(+RSN.W`NR#`U+?"Q]B^
MWR#'U;3/M-DN`,#,(+BUQ:FPH2"PH;BNQ*&TPB!54DS`NR#`U+?"Q]B^WR#'
MU;3/M-DN`+OHP:;'TB"[Y[_KP-H@P,RXI\"[(,#4M\+'V+[?(,?5M,^TV2X`
MP]^PH<?2(+OGO^O`VB#`S+BGP+L@P-2WPL?8OM\@Q]6TS[39+@`E<R"\O+S'
MP,P@N+BWX;7'OOJ]P+3/M-DN(+39O<,@M\ZQU\#.Q\^\O+_D+@#`S+C>P,\@
MP=:\TCH`N-[`SR#!UKS2.@#!I+JX`,#,N*<Z`+3GO<7`QR#`SL'UQ:RV\\#,
MOO#&KK"A(+OGO^O`VB"X\;?/NKBQXKBF(,'VO_C'S\'V(+[*O<"TS[39+B"V
MQ[3"(+39N*4@P,S`K[?.(+OGO^O`VB"X\;?/NKBQXKBF(+OGO^O'TB"\]B"^
M^+W`M,^TV2X`NNJV\[_LP/JPH2#`S""QXK3)P+L@P?:_^,?/P?8@OLJ]P+3/
MM-DN`,?VP.<@O<.PH[3K.@"QXKJ[(+W$NK#`VCH`P/S#O"#`S+BG.@#`S""\
MO+S'(+6_OL@@O\F\Q\#,(,#ZP.6UR[3/M-DN`+_)O,?`S"#`^L#EM<>^^KW`
MM,^TV2X`6\#.O^L@O/NQXK'B70!;O\"W^2"ZN+#MQ\^QXET`6\#.O^L@NKBQ
MXB`M`%O`SK_K(+JXL>(@+2`E<R#!V5T`6[;SP,X@)7,@+R`E<UT`7T&P_+BN
M`%]$Q^`@P?:_\@"UM;_RN+L`7TFQU[BR(+S3O+HN+BX`7TRWSK'7OL:_]`!?
M;;BUQ:D@O/;!I"XN+@!?3[RQQ<.[Y\?7`%]RN+7%J2"[Z,&F+BX`7W3'I2"\
MT[RZ+BXN`,'970#`S+BG`,;;O+[&K@#'R+R_`,#,N*<@OOC`O0!V0V%R9```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L
M92]B9U]"1R],0U]-15-304=%4P``````````````````````````````````
M```````````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,C$T,S8`(#4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+V)G7T)'+VAE;'`N>&UL````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(P(#$P-3$U-#,T,30Q
M(#`R,30P,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E
M+VQO8V%L92]B9U]"1R]H96QP+GAM;"QV(#$N,B`R,#`T+S`U+S(W(#(P.C(R
M.C$V(&IA;B!%>'`@)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y
M(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^
M"B`\<&%R83X*("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@
M<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@
M1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I
M;"!M97-S86=E<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG
M(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O
M"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E
M<RP@86YD('-O(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL
M(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L
M('-U8V@@87,*("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A
M=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A
M<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G
M92!A<F4@8W5S=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&
M;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC
M;'5D92!O;B!T:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC
M:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](FYA=F)A<B(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@07!P
M;&EC871I;VX@3F%V:6=A=&EO;B!"87(\+W1I=&QE/@H@/'!A<F$^"B`@070@
M=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H92!W96(@<&%G92!I<R!T:&4@87!P
M;&EC871I;VX@;F%V:6=A=&EO;B!B87(N"B`@0VQI8VL@;VX@=&AE(&EC;VYS
M(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@=&\@<75I8VML>2!A;F0@96%S:6QY
M('-W:71C:`H@(&)E='=E96X@=&AE(&%V86EL86)L92!A<'!L:6-A=&EO;G,N
M"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN
M=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC97,Z
M($UA:6YT96YA;F-E.B!$;R!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O('!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@8VAE8VL@=&AI<R!B;W@N"B`@("`\
M+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC;VYF:7)M7VUA
M:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E
M<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@
M("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L
M;"!M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C
M:R!T:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC
M92!O<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F
M;W)M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@
M;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]B9U]"1R],0U]-15-304=%4R]H;W)D92YM;P``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,C8Q,2`Q,#4Q-30S-#$T,2`P,C,Q
M-3<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0````#Z````'````.P'``!1`0``O`\`````````%0``#@````$5```(
M````$!4```P````9%0``"P```"85```H````,A4``!4```!;%0``#@```'$5
M```(````@!4``#(```")%0``.````+P5``!4````]14``%$```!*%@``-```
M`)P6```%````T18```T```#7%@``$@```.46```/````^!8``!D````(%P``
M!P```"(7```,````*A<```X````W%P```P```$87```%````2A<```H```!0
M%P``#P```%L7```?````:Q<``!$```"+%P``#````)T7```Y````JA<``"<`
M``#D%P``+`````P8```J````.1@```H```!D&```%0```&\8```I````A1@`
M`!$```"O&```%@```,$8```6````V!@```@```#O&```!````/@8```)````
M_1@```,````'&0```P````L9```(````#QD``"`````8&0``!@```#D9```*
M````0!D```P```!+&0``!@```%@9```'````7QD``!````!G&0``*P```'@9
M```$````I!D``!X```"I&0``&P```,@9```;````Y!D``#,`````&@``+P``
M`#0:```I````9!H```,```".&@```@```)(:```%````E1H``!````";&@``
M!@```*P:```O````LQH```\```#C&@``!````/,:```%````^!H```T```#^
M&@``&P````P;```-````*!L```4````V&P``$````#P;```0````31L```\`
M``!>&P``"P```&X;```/````>AL```P```"*&P``#P```)<;```>````IQL`
M`"$```#&&P``(````.@;```#````"1P``!,````-'```%````"$<```,````
M-AP```D```!#'```&P```$T<```'````:1P```8```!Q'```"0```'@<```4
M````@AP```8```"7'```$0```)X<```>````L!P```0```#/'```!````-0<
M```,````V1P```H```#F'```!0```/$<```@````]QP``"`````8'0``)@``
M`#D=```I````8!T```H```"*'0``#P```)4=```2````I1T``!````"X'0``
M%P```,D=```&````X1T```P```#H'0``#````/4=```-`````AX``"@````0
M'@``*P```#D>```(````91X``!````!N'@``&@```'\>```&````FAX```<`
M``"A'@```@```*D>```E````K!X```0```#2'@``#P```-<>```'````YQX`
M``H```#O'@``!P```/H>```&`````A\```D````)'P``#0```!,?```'````
M(1\```H````I'P``!````#0?```'````.1\```4```!!'P``%P```$<?```"
M````7Q\``#,```!B'P``,P```)8?```X````RA\``"T````#(```,0```#$@
M```L````8R```!H```"0(```"0```*L@```%````M2````(```"[(```!P``
M`+X@```,````QB```!$```#3(```$0```.4@```)````]R````@````!(0``
M"0````HA```*````%"$``!4````?(0``!0```#4A```H````.R$```L```!D
M(0``&@```'`A```%````BR$``"````"1(0``,@```+(A```%````Y2$```0`
M``#K(0``,@```/`A```J````(R(```8```!.(@``#P```%4B```$````92(`
M``D```!J(@```P```'0B```5````>"(``!(```".(@``#P```*$B```4````
ML2(``!H```#&(@``%P```.$B```7````^2(``!L````1(P``&0```"TC```?
M````1R,``%<```!G(P``!````+\C```$````Q",``!<```#)(P``!@```.$C
M```'````Z",```4```#P(P``"0```/8C``!*`````"0``#@```!+)```2```
M`(0D``!)````S20``#`````7)0``:0```$@E```]````LB4``&4```#P)0``
M30```%8F```N````I"8``"\```#3)@``+`````,G```7````,"<``"4```!(
M)P``,@```&XG```^````H2<``"4```#@)P``(0````8H```P````*"@``!P`
M``!9*```#0```'8H```%````A"@```,```"**```(````(XH```B````KR@`
M`"4```#2*```)@```/@H```)````'RD```8````I*0``"0```#`I```3````
M.BD```@```!.*0``"0```%<I```*````82D``!0```!L*0``"````($I```_
M````BBD```<```#**0``!@```-(I```-````V2D```L```#G*0``+P```/,I
M```,````(RH```H````P*@```@```#LJ```&````/BH```,```!%*@``*```
M`$DJ```F````<BH``"4```"9*@``*````+\J```0````Z"H``',```#Y*@``
M'P```&TK```4````C2L```\```"B*P``!````+(K```'````MRL```4```"_
M*P``4@$``,4K```/````&"T```<````H+0``"````#`M```.````.2T``"4`
M``!(+0``'````&XM```,````BRT```<```"8+0``-0```*`M```U````UBT`
M`%(````,+@``3P```%\N```W````KRX```4```#G+@``%@```.TN```6````
M!"\``!8````;+P``)@```#(O```%````62\``!````!?+P``#@```'`O```'
M````?R\```D```"'+P``#````)$O```,````GB\``",```"K+P``%P```,\O
M```-````YR\``#<```#U+P``+0```"TP```M````6S```"\```"),```"```
M`+DP```8````PC```#(```#;,```#P````XQ```;````'C$``"4````Z,0``
M"@```&`Q```)````:S$```<```!U,0```P```'TQ```#````@3$```@```"%
M,0``)@```(XQ```&````M3$```\```"\,0``$````,PQ```'````W3$```@`
M``#E,0``$P```.XQ```I`````C(```<````L,@``)0```#0R```E````6C(`
M`"<```"`,@``)0```*@R```Z````SC(``#4````),P``!@```#\S```"````
M1C,```D```!),P``&P```%,S```&````;S,``"X```!V,P``#0```*4S```(
M````LS,```4```"\,P``"P```,(S```B````SC,``!````#Q,P``!@````(T
M```/````"30``!`````9-```#@```"HT```-````.30``!0```!'-```#```
M`%PT```3````:30``"D```!]-```,@```*<T```D````VC0```0```#_-```
M%0````0U```6````&C4```P````Q-0``"P```#XU```F````2C4```8```!Q
M-0``!@```'@U```+````?S4``!<```"+-0``!0```*,U```.````J34``"$`
M``"X-0``!0```-HU```&````X#4```T```#G-0``#P```/4U```%````!38`
M`"\````+-@``+P```#LV```\````:S8``"8```"H-@``"@```,\V```-````
MVC8``!0```#H-@``$P```/TV```?````$3<```D````Q-P``$@```#LW```1
M````3C<``!(```!@-P``*@```',W```M````GC<```0```#,-P``"@```-$W
M```A````W#<```0```#^-P``!0````,X```"````"3@``"T````,.```!```
M`#HX```0````/S@```<```!0.```#@```%@X```%````9S@```4```!M.```
M"````',X```1````?#@```<```"..```"@```)8X```#````H3@```4```"E
M.```!@```*LX```C````LC@```(```#6.```)@```-DX```F`````#D``"L`
M```G.0``*P```%,Y```O````?SD``#4```"O.0``&0```.4Y```.````_SD`
M``<````..@```@```!8Z```%````&3H```\````?.@``$````"\Z```4````
M0#H```D```!5.@``!@```%\Z```'````9CH```@```!N.@``$@```'<Z```&
M````BCH``#(```"1.@``!0```,0Z```9````RCH```<```#D.@``'@```.PZ
M```W````"SL```H```!#.P``!@```$X[``!"````53L``"D```"8.P``"```
M`,([```7````RSL```0```#C.P``"0```.@[```#````\CL``!H```#V.P``
M(````!$\```/````,CP``!T```!"/```&0```&`\```:````>CP``!@```"5
M/```'@```*X\```C````S3P``"0```#Q/```:````!8]```)````?ST```8`
M``")/0``'@```)`]```'````KST```4```"W/0``!@```+T]```*````Q#T`
M`$<```#//0``*P```!<^``!)````0SX``%<```"-/@``+P```.4^``!?````
M%3\``#4```!U/P``80```*L_```_````#4```"<```!-0```'````'5````;
M````DD```!<```"N0```*@```,9````Q````\4```$4````C00``(````&E!
M```D````BD$``#<```"O00``(````.=!```5````"$(```@````>0@```P``
M`"="```D````*T(``"L```!00@``)0```'Q"```H````HD(```H```#+0@``
M!P```-9"```*````WD(``!\```#I0@```P````E#```$````#4,```4````2
M0P``&````!A#```(````,4,``#T````Z0P``"````'A#```(````@4,``!``
M``"*0P``#P```)M#```T````JT,```P```#@0P``#@```.U#```"````_$,`
M``<```#_0P```@````=$```A````"D0``"L````L1```*@```%A$```M````
M@T0``!$```"Q1```90```,-$```K````*44```\```!510``$````&5%```$
M````=D4```<```![10``!0```(-%```!`````````+<```":````/````.4`
M``"G````=````````````````````(H`````````E@```%````!W````````
M`%$```".````9P```!(```!S```````````````H````KP```)`````=````
M"0````\```!_```````````````_````;@```!L```!+````9@````````#V
M`````````"H````M`````````%L`````````5````/4`````````B0```$D`
M``!]`````````*H```!%````K````'L```#S`````````,X```!M````-0``
M`.\`````````K@```.<```"&````,P```),```"M````6@````````#R````
M8````$,```!V`````````$P``````````````$<`````````(````#H````Y
M````V@`````````X````&@```#(```"+````30``````````````8P```&\`
M``"K````[@```.````!A````````````````````9`````````#,````7@``
M`-`````N````<@```.@``````````````#8```#=````HP```-L```",````
M``````````#3````5P```!0```#)````U`````(```"9````!````!`````>
M````W@```+4``````````````*(```!*````SP```"$```"5`````````%@`
M```F````"@```"\````E````/@```+D```"!`````````!D```!H````^@``
M`&H```#5````M`````````"Q````%P```.8`````````D@````````!3````
M1@```-\```"E`````````%P`````````60```)P```#+``````````````"I
M````R````.P````B`````````&4```"R````[0```'X```!L`````````.(`
M``#$````$P``````````````````````````````M@````````""````Z@``
M`/$```#K````D0```'$```"=``````````````#<````L````!4```"@````
MT@```!8```#-`````````+X```"X````]````(<```">````Q0````````!!
M`````````)<`````````,0```(T```!X````OP````````#C``````````X`
M``!=````T0```$(`````````.P```.$```!U``````````````!(````4@``
M`$\```"/``````````````!P````"`````T````T````5@```",`````````
M``````````!5````V0```/D```#X````V`````````"?````$0```-<```"\
M````QP```-8```"A````/0```"L```"H````'`````4````#````"P```,8`
M``"S`````````+T`````````P0````````#*`````````/````"`````&```
M`)@```"Z`````````&L```````````````````!\````>0```$``````````
M>@```"0```#D````@P```.D`````````A0```&(````P````'P```/<`````
M``````````P```"(````*0```+L```";`````````$0`````````PP```(0`
M```W````I````,`````G`````````)0```!I````!@````<```!.````````
M```````L````P@```*8```!?`````"`H)7,@9&%Y<R!A9V\I`"`H=&]D87DI
M`"`H>65S=&5R9&%Y*0`E<R`M($YO=&EC90`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%1E<FUS(&]F($%G<F5E;65N=``E
M<R!I<R!R97%U:7)E9``R-"!H;W5R<P!!('!U8FQI8R!01U`@:V5Y(&ES(')E
M<75I<F5D('1O(&5N8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M(&ES(')E<75I<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@
M4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04TO4$T`061D
M($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@;F5W('5S97(Z
M`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O
M;VL`061M:6YI<W1R871I;VX`061S`$%L:6%S`$%L;"!'<F]U<',`06QL(%!E
M<FUI<W-I;VYS`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`07)C
M:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!='1E
M;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T
M;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T
M;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=')I8G5T97,`
M075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D
M(&)Y(%)!1$E54R!S97)V97(N`$%V86EL86)L92!F:65L9',Z`$)A9"!K97)B
M97)O<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!":7)T:&1A
M>0!";VQD`$)O;VMM87)K<P!#35,`0U)#`$-A;&5N9&%R`$-A;B=T(&-O;FYE
M8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F-E;`!#96QL(%!H;VYE`$-O;&]R
M(%!I8VME<@!#;VUI8W,`0V]M<&%N>0!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]P>0!#
M;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A+@!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E
M<G9E<BX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M;V1U;&4@
M)7,`0W5T`$1$`$1A:6QY`$1E9F%U;'0@261E;G1I='D`1&5L971E`$1E=&%I
M;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I
M<W!L87D@3W!T:6]N<P!%9&ET`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@
M861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M<'1Y(')E<W5L="X`17)R;W(`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E
M<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X
M86UP;&4@=F%L=65S.@!&86EL960@<F5T<FEE=FEN9R!P<F5F97)E;F-E<RX`
M1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V97(N`$9A:6QE9"!T;R!C
M;VYN96-T('1O(%--0B!S97)V97(N`$9A>`!&:6QE($-O=6YT.B`E<R!F:6QE
M`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA;64`
M1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1F]R=6US`$9U
M;&P@3F%M90!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<',`1W5E<W0@4&5R
M;6ES<VEO;G,`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AE;'``
M2&]M90!(;VUE($%D9')E<W,`2&]M92!0:&]N90!(;W)D90!)34%0(&UA:6QB
M;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@
M9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D
M.B`E<P!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K
M+@!)8V]N<R!/;FQY`$EC;VYS('=I=&@@=&5X=`!);7!O<G1E9"!F:65L9#H@
M)7,`26UP;W)T960@9FEE;&1S.@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!)
M=&%L:6,`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y
M(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!,86YG
M=6%G90!,:7-T($AE;'`@5&]P:6-S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L
M960N`$QO9R!I;@!,;V<@;W5T`$U-`$U3+51.148@071T86-H;65N="!C;VYT
M86EN960@;F\@9&%T82X`36%I;`!-871C:&EN9R!F:65L9',`365M8F5R<P!-
M96YU(&UO9&4Z`$UE<W-A9V4`365T:&]D`$UI;64@5'EP90!-;V1I9FEE9"!$
M871E`$UO;G1H;'D`37D@06-C;W5N=`!.86UE`$YE='=O<FL`3F5V97(`3F5W
M(%5S97)N86UE("AO<'1I;VYA;"D`3F\`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I
M;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF
M:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@
M5D93+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F]T97,`3TL`3W!T:6]N<P!/<F1E<F5D($QI<W0`3W1H97(@26YF;W)M
M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$A0(%-H96QL`%!A<W-W;W)D`%!A
M<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T
M90!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E
M<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!H;VYE`%!L
M96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%)A=&EO`%)E
M860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E
M('5N9&]N92X`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@=7-E<CH@)7,`4F]L90!344P@4VAE;&P`
M4U-(`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!T
M:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E
M;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE
M;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G93H`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO
M;BP@8V]L;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D
M:7-P;&%Y(&]P=&EO;G,N`%-H;W<`4VEZ90!3<&5C:6%L($-H87)A8W1E<B!)
M;G!U=`!3=6)M:70`4W5C8V5S<P!487-K<P!497AT($]N;'D`5&AE(&1E=&%C
M:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y
M('1H92!S:6=N960@;65S<V%G92X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@
M<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&QO8V%T:6]N
M(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y
M<'1?<&=P.CH@8VQA<W,N`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES
M(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`
M5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI
M;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE
M;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@
M96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A
M<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@
M;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E
M<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AI<R!D
M;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI
M<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI
M<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT
M86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M
M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM
M82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9O
M<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!V86QU92!M=7-T(&)E(&$@
M;G5M8F5R+@!4:6UE(%1R86-K:6YG`%1I=&QE`%523`!5;F%B;&4@=&\@8V]N
M;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D
M(&%R8VAI=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R
M>2X`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0`56YD
M97)L:6YE`%5P9&%T90!5<&1A=&4@)7,`57-E<B!!9&UI;FES=')A=&EO;@!5
M<V5R;F%M90!5<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES
M=&5M.@!686-A=&EO;@!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S
M86=E(&UA>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5V%R;FEN9P!7965K
M;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T:6]N
M('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!960!996%R;'D`665S`%EO=2!D:60@;F]T(&5N=&5R(&$@
M=F%L:60@96UA:6P@861D<F5S<RX`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=7(@26YF;W)M871I;VX`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E
M871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<F5M;W1E
M('-E<G9E<G,Z`%ML:6YE("5S(&]F("5S70!F:6QE`'5N;F%M960`=D-A<F0`
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C`M8W9S"E)E<&]R="U-<V=I
M9"U"=6=S+51O.B!D979`;&ES=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$
M871E.B`R,#`U+3$P+3$X(#$U.C$R*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@
M,C`P,BTQ,2TQ.2`R,#HT-"TP-3`P"DQA<W0M5')A;G-L871O<CH@36ER;W-L
M878@4&5N9&5V(#QM:7)O0&-Y8F5R<VAA9&4N=7,^"DQA;F=U86=E+51E86TZ
M(&DQ.&Y`;&ES=',N:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E
M;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U#4#$R-3$*0V]N=&5N="U4
M<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R#D[>@@[>#GX.0I`"`HY.WE
M\2D`("CB]^7PX"D`)7,@+2#'X.'EZ^7FZN``)7,@SN'QZ_/FXN#YZ"#N[^7P
MX/;HZ"`M(,_N\N+Z\.;DY>WHY0`E<R#3\>ONXNC_(._N(-'O[O#@Y_/LY>WH
MY?+N`"5S(.WE[N'U[N3H[``R-"#WX/'@`,?@(.3@(.KPZ._RZ/#@\N4@[^CQ
M[.X@Y2#MY>[A]>[DZ.P@[_/AZ^CWY>T@4$=0(.KK_O<N`,?@(.3@(._P[N+E
M\.CRY2#O[N3OZ/'@[>X@[^CQ[.X@Y2#MY>[A]>[DZ.P@4$=0(.KK_O<N`,?@
M(.3@(.3EZO#H[_+H\.#RY2#OZ/'L[B#QX"#MY>[A]>[DZ.SH.B#O\^'KZ/?E
M[2#JZ_[W+"#KZ/?E[2#JZ_[W(.@@ZNO^]^[BX"#T\.#GX"X`Q^`@Y.`@[^[D
M[^CXY?+E(._H\>SN(/'@(.WE[N'U[N3H[.@Z(._SX>OH]^7M(.KK_O<L(.OH
M]^7M(.KK_O<@Z"#JZ_[W[N+@(/3PX.?@+@#'X"#DX"#J\.CO\NCPX/+E(._H
M\>SN(.4@[>7NX?7NY.CL(._SX>OH]^7M(%--24U%(.KK_O<N`$%-+U!-`,3N
MX>#B_^WE(.W@(.WNXN`@X_#S[^``Q.[AX.+_[>4@[>`@[>[BZ"#O\.#BX`#$
M[N'@XN@@[>[B(._N\O#EX>CRY>LZ`,3NX>#B_^WE\NX@[>`@[^[R\.7AZ/+E
MZ^@@Y2#GX.'PX.WE[>XN`,#D\.7Q`,#D\.7QY>T@X>7KY>;MZ.H`P.3LZ.WH
M\?+PZ/#@[>4`Q.[AX.+JZ`#/\>7BY.[MZ.P`PO'H]^KH(./P\^_H`,+QZ/?J
MZ"#O\.#BX`#"^N+EY.7MX/+@(/'R[NGM[O'R(.WE(.4@Y.[O\_'RZ.S@+@#0
MX.?LY?`@[>`@X/#UZ.+MZ/\@].#IZP#([.4@[>`@X/#UZ.+@`,3@(/'E(.CQ
MZN`@Z^@@[^[RXOKPYN3E[>CE(._PY>3H(.[A\>OSYN+@^>CRY2#N[^7PX/;H
MZ#\`P_#E^.K@(._PZ"#HY_+PZ.+@[>4@[>`@[>7Q^OGE\?+B\^+@^>`@X_#S
M[^`N`,/PY?CJX"#O\.@@Z.?R\.CBX.WE(.WE(.WE\?KYY?'RXO/BX/GH(._P
MX.+@+@##\.7XZN`@[_#H(/#EY.#J\NCPX.WE(.W@(.WE\?KYY?'RXO/BX/GH
M(._PX.+@+@#`\O#HX?/RZ`##\.7XZN`@[_#H(.CDY>WRZ/3HZN#VZ/\`R.3E
M[?+H].CJX/;H__+@(.'E^.4@[O+UXOKPZ^7MX"#N\B!2041)55,@\?KPXOKP
MX"X`S>#KZ/?MZ"#O[NOE\N`Z`,WEXN#KZ.3MX"!K97)B97)O<R`@[^#P[NO@
M+@#-Y>+@Z^CD[>X@:V5R8F5R;W,@[^[R\.7AZ/+EZ_'J[B#H[.4N`-#NYN3E
M[2#DY>T`T^3EX>7KY>WH`,[R[.7RZN@`0TU3`$-20P#*X.OE[>3@\`##\.7X
MZN`@[_#H(/'B^O#GXN#MY2#Q(.SEZ>L@\?KPXOKP.B`E<P#.\NK@YN@`S.[A
MZ.OE[2#RY>OE].[M`,CGX>CPX.WE(.W@(/;B__(`RN[LZ.KQZ`#*[NSOX.WH
M_P#/[O+B^O#DY?+E(._@\.[KX/+@`,3N\?+Z[^`@Y.X@[_/AZ^CW[>C_(/'Z
M\.+Z\"#AY?CE(.[RZN#GX.TN`,KN[^CPX.D`P_#E^.K@(._PZ"!01U`@ZO#H
M[_+H\.#MY?+N(.W@(._H\>SN+@##\.7XZN`@[_#H(%!'4"#O[N3OZ/'BX.WE
M\NX@[>`@[^CQ[.XN`,/PY?CJX"#O\.@@Y.7J\.CO\NCPX.WE\NX@[>`@4$=0
M(.3@[>WH+@#-Y>KN\.7J\N7M(&5M86EL(.#D\.7Q(.W@(._NZ_/WX/+EZ_\N
M`,/PY?CJX"#O\.@@[^[K\_?@XN#MY?+N(.W@(._SX>OH]^WH_R#JZ_[W(.[R
M(.KK_O<M\?KPXOKPX"X`S>7B^N?L[N;M[O'R(.3@(/'E(.[RXN[PZ"#.X?'K
M\^;BX/GH7^?@Y.#WZ"#L[N3SZR`E<R``Z.?PY>;H`,3$`,7FY>3MY>+M[@#(
MY.7M\NCW[>[Q\B#O[B#O[N3PX.?AZ/#@[>4`R.?R\.CI`,3E\N#IZ^CRY2#A
M__7@(/#EX^CQ\O#H\.#MZ"#GX"#@Y.SH[>CQ\O#@\N[PX"X`Q.CQ[^OEZ2#.
M[_;HZ`#0Y>3@ZO;H_P#/Z/'L[@#%;6%I;"#@Y/#E\0!%;6%I;"#@Y/#E\>CR
MY2#R\/_AXN`@Y.`@\?KB[^#DX/(N`,_PX.?E[2#PY>?SZ_+@\BX`P_#E^.K@
M`,+QY>KH(#$U(.SH[?/RZ`#"\>7JZ"`S,"#QY>KS[>3H`,+QY>KH(#4@[.CM
M\_+H`,+Q_^KN(.ONX^+@[>4`S>`@XO'EZN@@[^[K[N+H[2#WX/$`PO'_ZN`@
M[.CM\_+@`,_PZ.SE\.WH(/'R[NGM[O'RZ#H`S>7B^N?L[N;M[O'R(.3@(/'E
M(.?@\.7D__(@[_#E].7PY>WVZ.CRY2X`S>7B^N?L[N;M[O'R(.3@(/'E(.[Q
M^OGE\?+BZ"#B\/KGZN`@\2!,1$%0(/'Z\.+Z\"X`P_#E^.K@(._PZ"#QXOKP
MY^+@[>4@\?KQ(%--0B#Q^O#B^O`N`-3@ZO$`P?#NZ2#TX.GK[N+E.B`E<R#T
MX.GK`,'P[ND@].#IZ^[BY3H@)7,@].#IZ^``U.#IZR#LY>W@YN7P`,CLY2#M
MX"#TX.GK`,CG[_#@^>#MY?+N(.W@(/3@Z>ONXN4@[>4@\>4@[^[DY/KPYN`N
M`-3HZ_+Z\`#4[O#S[.@`R.SE(.W@(/3@Z>L`P.3LZ.WH\?+PZ/#@[>4@[>`@
MX_#S[^@`P_#S[^@`S_#@XN`@Y^`@X^[Q\N@`2%144"#HY.7M\NCTZ.K@]NC_
M(.WE(.4@[>#LY?#E[>`N`,_N[.[Y`,W@]^#K[@#$[NS@^.7M(.#D\.7Q`,3N
M[.#XY>T@\N7KY?3N[0!(;W)D90##\.7XZN`@[_#H(/'ZY^3@XN#MY2#MX"!)
M34%0(._N^>7M\>K@(.KS\NC_.B`E<P##\.7XZN`@[_#H(.CG\O#HXN#MY2#M
MX"!)34%0(._N^>7M\>K@(.KS\NC_.B`E<P##\.7XZN`@[^[PX.3H(.KB[O+@
M(._PZ"#Q^N?DX.+@[>4@[>`@24U!4"#O[OGE[?'JX"#J\_+H_SH@)7,`25`@
MX.3PY?'@(.WE(.4@XB#O[N?B[NOE[>C_($-)1%(@X>ONZBX`T>#L[B#HZN[M
MZ`#(ZN[MZ"#Q(/+EZO'R`,CL[^[P\NCPX.WN(._NZ^4Z("5S`,CL[^[P\NCP
MX.WH(._NZ^7RX#H`R.?O\.#RY>WH\N4@Y.#M[>@@\>`@[>7BX.OHY.WH+@#-
MX.KK[NWE[>@`[_KK[>X@[^[D\.#B[?_BX.WE`.O_XNX@[^[D\.#B[?_BX.WE
M`.3_\>WN(._NY/#@XNW_XN#MY0!+97)B97)O<R#Q^O#B^O#@(.[R]>+Z\.OH
M(.CDY>WRZ/3HZN#VZ/_RX"X`RNO^]^`@XN7WY2#Q^OGE\?+B\^+@(.(@[_/A
MZ^CW[>C_(.KK_O?Q^O#B^O`N`,7GZ.H`S^[L[OD@\N7LZ`#1[^CQ^NK@(/$@
M[^[R\.7AZ/+EZ^@@Y2#GX.'PX.WE[2X`PO7NY`#(Y_7NY`#,S`!-4RU43D5&
M(._PZ.KPY>_E[>C_\B#TX.GK(.WE(/'ZY/KPYN#XY2#DX.WMZ"X`S^[YX`#1
M^N+OX.3@^>@@[^[KY?+@`-?KY>WNXN4`PNCD(.W@(.SE[?[R[CH`S^CQ[.X`
MS.7R[N0`36EM92#RZ.\`Q.#RX"#MX"#O\.[LY>W_[>4`S.7QY??M[@#,[O_R
MX"#/[OG@`,CLY0#,\.7FX`#-Z.KNX^``S>[B[B#O[O+PY>'H\N7K\>KN(.CL
MY2`H[N_VZ.[MX.OM[BD`S>4`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@
MY^`@1E10(%9&4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,
M(%9&4RX`S?_LX"#GX.3@Y.7MX"#J[NWTZ./S\.#VZ/\@Y^`@4U%,+49I;&4@
M5D93+@#-_^S@(.?@Y.#DY>W@(._@\.[KX"#GX"!)34%0(.CDY>WRZ/3HZN#V
MZ/\N`,W_[.`@Y^#DX.3E[>`@[^#P[NO@(.?@($ME<F)E<F]S(.CDY>WRZ/3H
MZN#VZ/\N`,W_[.`@ZN[M].CC\_#@]NCN[>W@(.CM].[P[.#VZ/\@Y^`@4TU"
M(.CDY>WRZ/3HZN#VZ/\N`,+Z\.W@\NCRY2#DX.WMZ"#MY2#QX"!834P`S?_L
MX"#Q\N[I[>[Q\N@`P>7KY>;JZ`#.R@#.[_;HZ`#/[N3PY>3E[2#Q[^CQ^NH`
MQ/#SX^`@Z.WT[O#LX/;H_P#/\.#BX"#MX"#O\.CRY>;@\N7K_P!01U`@4VAE
M;&P`S^#P[NO@`,_@\.[KX#H`S^#P[NO@.B``S>7J[O#EZO+MX"#OX/#NZ^`N
M`,+L^NKMZ`#$X"#QY2#HY^+Z\/CBX/(@Z^@@[N'QZ_/FXN#YZ/+E(.[OY?#@
M]NCH(._PZ"#"]>[D/P#/\.#BX`#`Y.SH[>CQ\O#H\.#MY2#MX"#O\.#BX/+@
M`-+EZ^7T[NT`S.[K_RP@XOKBY>3E\N4@[.7QY?8@Z"#C[N3H[>`N`,KK_O?N
MXN`@Y.+NZ>K@(._SX>OH]^7M+_?@\?+E[2#JZ_[W(.WE(.'E^.4@X^7MY?#H
M\.#MX"X`RN[E].CVZ.7M\@#7Y?+E[>4`R/'JX/+E(.3@(.CG\O#HY?+E("5S
M(.OH/R#2X.?H(.[OY?#@]NC_(.WE(.SNYN4@Y.`@\>4@XOKP[>4@[>#GX.0N
M`,#D\.7Q(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`,_P
MY>S@]>WH`,_PY>S@]>WH(._N\O#EX>CRY>LZ("5S`-#NZ_\`4U%,(%-H96QL
M`%-32`#(Y^'E\.7RY2#C\//OX"#GX"#D[N'@XO_MY0#(Y^'E\.7RY2#M[N(@
M[_#H\N7FX/+EZR#MX"#C\//OX`#(Y^'E\.7RY2#Q^O#B^O``R.?AY?#H(._N
M\O#EX>CRY>L@Y^`@Y.[AX.+_[>4`R.?AY?#E\N4@Q.#RX"#PX.?DY>OH\N7K
M.@#(Y^'E\.7RY2#T[O#LX/(@Y^`@Q.#RX/+@.@#(Y^'E\.7RY2#T[O#LX/(@
MY^`@U^#QX#H`R.?AY?#E\N4@Y.+E(/'ZXN_@Y.#YZ"#O[NOE\N`Z`,CGX>7P
MY?+E(.+@^.#RX"#Q]>7LX"#GX"#VXN7R[N+E\N4N`,CGX>7PY?+E(._PY>3O
M[O?H\N#MZ/_R(.[R(,+@\2#EY^CJ.@#'X.3@Z?+E(,+@^.7R[B#MX/?@Z^WN
M(._PZ.ONYN7MZ.4L(/'UY>S@(.?@(/;BY?+NXN4L(.[O\.7Q[?_BX.WE(.W@
M(/'R\.#MZ/;@\N`@Z"#D\//CZ"#N[_;HZ"#GX"#DZ/'OZ^7_+@#/[NK@Y^+@
M[>4`T.#G[.7P`,+ZXN7FY.#MY2#MX"#Q[^7VZ.#K[>@@\>CLXN[KZ`#(Y^_P
MX/+H`-/Q[^7U`,?@Y.#WZ`#1X.SN(/+EZO'R`,_PZ.KPY>_E[>C_\B!01U`@
M[^[D[^CQ(.4@[>7NX?7NY.CL(.?@(.3@(/'E(._P[N+E\.@@[^[D[^CQX.WN
M\NX@[^CQ[.XN`,KPZ._RZ/#@[>7R[B#HY^CQZN+@(.KPZ._RZ/#@[>`@=V5B
M(.+P^N?JX"X`S.7Q\N[O[NONYN7MZ.7R[B#MX"!';G501R#TX.GKX"#R\/_A
MXN`@Y.`@X?KDY2#DX.3E[6\@[>`@0W)Y<'1?<&=P.CH@8VQA<P#/\.[C\.#L
MX/+@+"#J[O_R[B#QZ_/FZ"#GX"#O[NK@Y^+@[>4@[>`@\N[GZ"#RZ.\@Y.#M
M[>@@*"5S*2#MY2#AY?CE(.[RZO#H\N`@XB#QZ/'RY>S@\N``S?_LX"#DXN[I
MZN@L(.KNZ/+N(.3@(.'ZY.#R(._NZN#GX.WH(.(@Z^CMZ/_RX"X`R.S@(/+B
M^O#DY2#L[>[C[B#QZ.SB[NOH(.(@\N[BX"#O[NOE+B#"^N+EZ^@@\?+E("5S
M(/'H[.+NZ^`[(/+P_^'BX"#DX"#B^N+EY.7RY2#O[BWLX.OJ[B#N\B`E<RX`
MP_#E^.K@(._PZ"#HY^_PX/G@[>7R[B#MX"#TX.GKX#H@)7,@[>4@X>7XY2#H
MY^_PX/+E[2X`R.S@^.4@[_#NX>OE["#O\.@@Z.?O\.#YX.WE\NX@[>`@].#I
MZ^`N("5S(.4@[^XMX^[K_^P@[O(@[.#J\>CLX.OM[B#D[N_S\?+H[.C_(/#@
MY^SE\"`H)60@X>#I\N`I+@##\.7XZN`@[_#H(.CG[_#@^>#MY?+N(.W@(/3@
MZ>O@+B`E<R#AY?CE(/'@[.X@[O+WX/'RZ"#HY^_PX/+E[2X`P_#E^.K@(._P
MZ"#H[._N\/(@[>`@Y.#M[>@@Y^`@ZN[M\N#J\N@N`-+NXN`@[>4@Y2#BX.OH
MY.7M(')A<B#@\/7HXBX`TN[BX"#MY2#E(.+@Z^CDY>T@>FEP(/3@Z>LN`-+N
MXN`@[^[KY2#E(.WE[N'U[N3H[.XN`-+NXN`@[^[KY2#L[N;E(.3@(/'ZY/KP
MYN`@\>#L[B#VY>OH(/?H\>O@+@#2[N+@(._NZ^4@[.[FY2#DX"#Q^N3Z\.;@
M(/'@[.X@]^CQZ^`@Z"#DXN[E\N[WZ.4N`-+NXN`@[^[KY2#R\/_AXN`@Y.`@
MY2#GX._E\N#_(.CKZ"#H[?+E\.+@ZR#PX.?DY>OE[2#Q[^CQ^NH@[_#N[.7M
MZ^CBZ`#2X.?H(/3N\.S@(.+E]^4@X>7XY2#NX?#@X>[RY>W@+@#2[N+@(/?H
M\>ON(/+P_^'BX"#DX"#E(._N[>4@Y>3H[>CVX"X`TN[GZ"#Q^O#B^O`@[>4@
M[.[FY2#DX"#DY>KN[._PY?'H\.`@>FEP(.@@9WII<"#TX.GK[N+E+@#2X.?H
M(/'R[NGM[O'R(/+P_^'BX"#DX"#E(/?H\>ON+@#/\.[QZ^7D_^+@[>4@[>4@
MXO#E[.4`Q.OZYNWN\?(`55),`,WEXOKG[.[F[>[Q\B#GX"#B\/KGZN`@\2!3
M44P@\?KPXOKP+@##\.7XZN`@[_#H(.[RXN#P_^WE\NX@[>`@ZN[L[_#E\>CP
MX.T@X/#UZ.(N`,/PY?CJX"#O\.@@]^7RY>WE\NX@[>`@=F9S<F]O="#OX._J
MX"X`P_#E^.K@(._PZ"#O\.7B[N3@(.W@(/+NY^@@5V]R9"#D[NKS[.7M\@#/
M[N3WY?#RX.WH`,[O\.7Q[>@`SN_PY?'MZ"`E<P#`Y.SH[>CQ\O#H\.#MY2#M
MX"#O[O+PY>'H\N7KZ/+E`,CLY0#([.4Z`,CLY3H@`,_N\O#EX>CRY>OH(.(@
M\>CQ\N7LX/+@.@#"X.K@[?;H_P##\.7XZN`@[_#H(._P[N+E\.K@\N`@+2#R
M[N+@(._H\>SN(.SNYN4@Y.`@Y2#AZ.ON(._NY._PX.+E[>XN`,+MZ.S@[>CE
M`-'EY.SH]^WN`,3NX?#E(,3N^.OH(.(@)7,`Q.[A\.4@Y.[XZ^@L("5S`,CG
MX>7PY?+E(._PZ.ONYN7MZ.7R[BP@ZN[E\NX@)7,@Y.`@[^[JX.;E(/'KY>0@
MXO7NY"X`P>CG[>7Q(.#D\.7Q`,'HY^WE\2#RY>OE].[M`,/#`,/NY.CX[>X`
MQ.``S>4@XOKBY>3N]?+E(.+@Z^CDY>T@96UA:6P@X.3PY?$N`-+P_^'BX"#D
MX"#GX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.CG\O#HXN#MY2X`TO#_X>+@(.3@
M(.?@Y.#DY?+E(._N\O#EX>CRY>L@Y^`@Y.[AX.+_[>4N`-+P_^'BX"#DX"#G
MX.3@Y.7RY2#O[O+PY>'H\N7K(.?@(.[O\.7Q[?_BX.WE+@#([?3N\.S@]NC_
M(.?@(,+@\0#"X/CH__(@Z.3E[?+H].CJX/;H[NWE[2#D\.#IXN7P(.WE(._N
MY.3Z\.;@(/'OZ/'ZZB#MX"#O[O+PY>'H\N7KZ/+E+"#HZ^@@\N#GZ"#B^N?L
M[N;M[O'R(.4@Y^#A\.#MY>W@+@#"X/CH\N4@ZN[M].CC\_#@]NCN[>WH(.[O
M]NCH(.'_]>`@[N'M[N+E[>@N`,+@^.CRY2#Q^O#B^O#H.@!;Z^CMZ/\@)7,@
M[O(@)7-=`/3@Z>L`X>7G(.CLY0!V0V%R9```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]I=%])
M5"],0U]-15-304=%4P``````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,C$U,#8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VET7TE4+VAE;'`N>&UL````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-#(W(#$P-3$U-#,T,30Q(#`R,30V
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TQ(C\^"CPA
M+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O:71?250O:&5L<"YX;6PL=B`Q+C(N
M,3`N,B`R,#`U+S$P+S$X(#$Q.C,S.C0S(&IA;B!%>'`@)"`M+3X*/&AE;'`^
M"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB
M-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B/@H\=&ET;&4^4&%G
M:6YA(&1I(&EN9W)E<W-O(&1E;"!P;W)T86QE/"]T:71L93X*(#QP87)A/@H@
M(%%U97-T82!P86=I;F$@9&D@:6YG<F5S<V\@9&5L('!O<G1A;&4@9F]R;FES
M8V4@=6X@8G)E=F4@<V]M;6%R:6\@9&D@='5T=&4@;&4@='5E"B`@:6YF;W)M
M87II;VYI(&EM<&]R=&%N=&DN($%D(&5S96UP:6\L('1I('!U\B!M;W-T<F%R
M92!Q=6%N=&D@;G5O=FD@;65S<V%G9VD@8VD*("!S;VYO(&YE;&QA('1U82!)
M3D)/6"P@:2!P<F]S<VEM:2!E=F5N=&D@;F5L('1U;R!C86QE;F1A<FEO+"!L
M92!A='1I=FETX"!N96QL80H@('1U82!L:7-T82P@;&4@=6QT:6UE(&YO=&EZ
M:64@9&$@<V5R=FEZ:2!S96QE>FEO;F%T:2!E(&-O<^P@=FEA+B!-;VQT:2!D
M:2!Q=65S=&D*("!S;VUM87)I(&-O;G1E<G)A;FYO(&1E:2!C;VQL96=A;65N
M=&D@82!F=6YZ:6]N:2!C;VUU;FDL('%U86QI(&%D(&5S96UP:6\@;&$@8V]M
M<&]S:7II;VYE"B`@9&D@=6YA(&YU;W9O(&UE<W-A9V=I;RP@;&$@8W)E87II
M;VYE(&1I('5N;R!N=6]V;R!E=F5N=&\@9&$@:6YS97)I<F4@;F5L(&-A;&5N
M9&%R:6\*("!O(&QA(&-R96%Z:6]N92!D:2!U;F$@;G5O=F$@871T:79I=.`@
M9&$@:6YS97)I<F4@;F5L;&$@;&ES=&$L(&5C8RX*(#PO<&%R83X*(#QP87)A
M/@H@($D@8V]N=&5N=71I(&1I('%U97-T82!P86=I;F$@9&5L('!O<G1A;&4@
M<V]N;R!P97)S;VYA;&EZ>F%B:6QI('1R86UI=&4@:6P@8F]T=&]N92!&;W)M
M871O+@H@($%D(&5S96UP:6\L('!U;VD@<V-E9VQI97)E('%U86QI(&EN9F]R
M;6%Z:6]N:2!I;G-E<FER92!N96QL82!P86=I;F$@8V]M92!A;F-H92!I;@H@
M('%U86QE(&]R9&EN92!V97)R86YN;R!M;W-T<F%T92X*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4](G5P=&]D871E(B!M
M9#4](F(X8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE
M/DQA(&)A<G)A(&1I(&YA=FEG87II;VYE(&1E;&QE(&%P<&QI8V%Z:6]N:3PO
M=&ET;&4^"B`\<&%R83X*("!3=6QL82!S:6YI<W1R82!D96QL82!P86=I;F$@
M=V5B(.@@<')E<V5N=&4@;&$@8F%R<F$@9&D@;F%V:6=A>FEO;F4@9&5L;&4@
M87!P;&EC87II;VYI+@H@($-L:6-C82!S=6QL)VEC;VYA('!R97-E;G1E(&YE
M;&QA(&)A<G)A(&1I(&YA=FEG87II;VYE('!E<B!P87-S87)E(')A<&ED86UE
M;G1E(&4*("!V96QO8V5M96YT92!T<F$@;&4@=F%R:64@87!P;&EC87II;VYI
M(&1I<W!O;FEB:6QI+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D
M9#DU9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^
M4')E9F5R96YZ93H@36%N=71E;GII;VYE.B!%<V5G=6D@;&$@;6%N=71E;GII
M;VYE/"]T:71L93X*("`@(#QP87)A/@H@("`@4V4@=G5O:2!E<V5G=6ER92!L
M92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N92!A<'!E;F$@96YT<F%T;R!N
M96P@<&]R=&%L92P*("`@('-E;&5Z:6]N92!Q=65S=&$@8V%S96QL82X*("`@
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?
M;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F
M,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^4')E9F5R96YZ
M93H@36%N=71E;GII;VYE.B!#;VYF97)M82!L82!M86YU=&5N>FEO;F4\+W1I
M=&QE/@H@("`@/'!A<F$^"B`@("!392!D97-I9&5R:2!C:&4@=F5N9V$@8VAI
M97-T82!L82!C;VYF97)M82!P<FEM82!C:&4@='5T=&4@;&4@;W!E<F%Z:6]N
M:2!D:2!M86YU=&5N>FEO;F4@"B`@("!V96YG86YO(&5S96=U:71E+"!S96QE
M>FEO;F$@<75E<W1A(&-A<V5L;&$N"B`@("!392!L82!C87-E;&QA(&YO;B!V
M:65N92!S96QE>FEO;F%T82P@='5T=&4@;&4@;W!E<F%Z:6]N:2!D:2!M86YU
M=&5N>FEO;F4@8VAE('-O;F\*("`@('!R;V=R86UM871E('9E<G)A;FYO(&5S
M96=U:71E(&%U=&]M871I8V%M96YT92!S96YZ82!L82!P;W-S:6)I;&ETX"!D
M:2!C86YC96QL87)L90H@("`@<75A;F1O('-I(&5N=')A(&YE;"!P;W)T86QE
M+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VET7TE4+TQ#7TU%4U-!1T53+VAO
M<F1E+FUO````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,S(U,3(W(#$P-3$U
M-#,T,30Q(#`R,S(S-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#>$@25`````(<%```<````5"P``&$'``",6````````!!V
M```.````$78```\````@=@``#0```#!V```(````/G8```L```!'=@``#```
M`%-V```$````8'8``!@```!E=@``&P```'YV```M````FG8``!T```#(=@``
M)````.9V```I````"W<``!D````U=P``)@```$]W```,````=G<``"0```"#
M=P``#P```*AW```+````N'<```X```#$=P``!0```--W```H````V7<```@`
M```">```"@````MX```5````%G@``!(````L>```"P```#]X``"%````2W@`
M``X```#1>```"@```.!X```-````ZW@```X```#Y>```$0````AY```-````
M&GD```P````H>0``#0```#5Y```&````0WD``)0```!*>0``"@```-]Y```/
M````ZGD``!@```#Z>0``#````!-Z```.````('H```X````O>@``"````#YZ
M```)````1WH``"X```!1>@``&@```(!Z```R````FWH``#@```#.>@``5```
M``=[``!1````7'L``%H```"N>P``5P````E\```T````87P```D```"6?```
M#0```*!\```'````KGP```H```"V?```#P```,%\```%````T7P```8```#7
M?```$0```-Y\```(````\'P``"4```#Y?```(````!]]```3````0'T``!``
M``!4?0``#P```&5]```*````=7T```,```"`?0``#P```(1]```4````E'T`
M``D```"I?0``#0```+-]```2````P7T``!D```#4?0``'@```.Y]```/````
M#7X```H````=?@``#P```"A^```(````.'X``"0```!!?@``%````&9^```6
M````>WX```@```"2?@``3@```)M^```M````ZGX``!D````8?P``!P```#)_
M```,````.G\``"P```!'?P``#@```'1_```%````@W\```H```")?P```P``
M`)1_```7````F'\```H```"P?P``#P```+M_```.````RW\``!@```#:?P``
M(P```/-_```.````%X```!0````F@```%P```#N````7````4X```!<```!K
M@```$P```(.````/````EX```!\```"G@```'0```,>````&````Y8````L`
M``#L@```$````/B````5````"8$``!4````?@0``!P```#6!```0````/8$`
M``4```!.@0``$0```%2!```,````9H$``#L```!S@0``.````*^!```Y````
MZ($``!(````B@@``)P```#6"```L````78(``"H```"*@@``)0```+6"```*
M````VX(```8```#F@@``+P```.V"```W````'8,``"X```!5@P``50```(2#
M```M````VH,``"T````(A```/0```#:$```_````=(0``"T```"TA```0```
M`.*$```C````(X4``",```!'A0``0````&N%```M````K(4``#,```#:A0``
M)0````Z&```5````-(8``!D```!*A@``*0```&2&```D````CH8``"@```"S
MA@``$0```-R&```*````[H8``!````#YA@``%@````J'```6````(8<``"<`
M```XAP``"````&"'```I````:8<```X```"3AP``"@```**'```$````K8<`
M``D```"RAP``!@```+R'```1````PX<```<```#5AP``%@```-V'```$````
M](<```8```#YAP``!@````"(```-````!X@```,````5B````P```!F(```7
M````'8@``!,````UB```'0```$F(```(````9X@```0```!PB```"````'6(
M```[````?H@``#0```"ZB```00```.^(```:````,8D``"L```!,B0``(```
M`'B)```5````F8D```8```"OB0``%0```+:)```8````S(D``"(```#EB0``
M+@````B*```=````-XH``"$```!5B@``5````'>*```I````S(H```<```#V
MB@``%0```/Z*```.````%(L```H````CBP``#P```"Z+```-````/HL```\`
M``!,BP``#0```%R+```)````:HL```8```!TBP``'0```'N+```3````F8L`
M`!$```"MBP``%````+^+```&````U(L``!0```#;BP``5````/"+``!D````
M18P```0```"JC```#@```*^,```%````OHP```4```#$C```$P```,J,```1
M````WHP``!$```#PC```'`````*-```J````'XT``"$```!*C0``!0```&R-
M```+````<HT``!(```!^C0``"@```)&-```/````G(T```T```"LC0``$0``
M`+J-```,````S(T```8```#9C0``#````."-```&````[8T``!````#TC0``
M$0````6.```%````%XX```P````=C@``$````"J.```%````.XX```T```!!
MC@``!@```$^.```'````5HX```T```!>C@``!P```&R.```+````=(X```<`
M``"`C@``"0```(B.```)````DHX```H```"<C@``&0```*>.```]````P8X`
M`!T```#_C@``#````!V/```0````*H\``!(````[CP``$P```$Z/```K````
M8H\``#L```".CP``(````,J/```(````ZX\``#8```#TCP``(0```"N0```0
M````39````@```!>D```!````&>0```/````;)````X```!\D```'P```(N0
M```<````JY```"$```#(D```'@```.J0```9````"9$``!X````CD0``&P``
M`$*1```A````7I$``"X```"`D0``)@```*^1```<````UI$``!X```#SD0``
M'````!*2```F````+Y(``"L```!6D@``,P```(*2```F````MI(``"L```#=
MD@``.`````F3```=````0I,``!4```!@DP``+P```':3```@````II,``!(`
M``#'DP``*0```-J3```>````!)0``"`````CE```$@```$24``"B````5Y0`
M`!8```#ZE```(P```!&5```H````-94``"D```!>E0``*````(B5```?````
ML94``!4```#1E0``(````.>5```E````")8``"@````NE@``+0```%>6```P
M````A98``)(```"VE@``(0```$F7```<````:Y<``"8```"(EP``*@```*^7
M``!!````VI<``$0````<F```#````&&8```'````;I@```<```!VF```!@``
M`'Z8```-````A9@``!````"3F```$@```*28```3````MY@``!(```#+F```
M$````-Z8```0````[Y@```P`````F0``#@````V9```-````')D```\````J
MF0``$P```#J9```-````3ID``"@```!<F0```P```(69```-````B9D```8`
M``"7F0``!0```)Z9```$````I)D```T```"IF0``#@```+>9```#````QID`
M``X```#*F0``"````-F9```/````XID```\```#RF0``#0````*:```0````
M$)H```T````AF@``"P```"^:```&````.YH```L```!"F@``#````$Z:```*
M````6YH``!$```!FF@``&0```'B:```+````DIH```T```">F@``(@```*R:
M```/````SYH``!L```#?F@``-````/N:```*````,)L``!@````[FP``$@``
M`%2;```9````9YL``!8```"!FP``(@```)B;```-````NYL```<```#)FP``
M%````-&;```+````YIL``"(```#RFP``+P```!6<```+````19P```D```!1
MG```&0```%N<```+````=9P``!<```"!G```%P```)F<```6````L9P```\`
M``#(G```&0```-B<```.````\IP``!@````!G0``#0```!J=```F````*)T`
M`$,```!/G0``'P```).=```(````LYT```L```"\G0``+P```,B=```%````
M^)T```0```#^G0``"@````.>```*````#IX```\````9G@``$````"F>```7
M````.IX``!$```!2G@``&0```&2>```7````?IX```4```"6G@``"@```)R>
M```-````IYX``!L```"UG@``%P```-&>```.````Z9X```T```#XG@``$@``
M``:?```X````&9\``"````!2GP``"````'.?```.````?)\``'L```"+GP``
M&`````>@```8````(*````4````YH```&````#^@```>````6*```!L```!W
MH```&0```).@```;````K:```!D```#)H```$P```..@```0````]Z````\`
M```(H0``$````!BA```/````*:$```L````YH0``#P```$6A```,````5:$`
M``\```!BH0``!P```'*A```&````>J$```X```"!H0``#````)"A```H````
MG:$```\```#&H0``"````-:A```(````WZ$``!,```#HH0``'@```/RA```A
M````&Z(``"`````]H@``&0```%ZB```7````>*(``"4```"0H@``%P```+:B
M```6````SJ(```0```#EH@``#````.JB```(````]Z(```H`````HP``#```
M``NC```3````&*,``!0````LHP``#````$&C```)````3J,```X```!8HP``
M"P```&>C```;````<Z,```<```"/HP``!P```)>C```*````GZ,```T```"J
MHP``"0```+BC```#````PJ,``!@```#&HP``"@```-^C```$````ZJ,``"8`
M``#OHP``#@```!:D```5````):0```@````[I````@```$2D```&````1Z0`
M``0```!.I```"0```%.D```0````7:0```D```!NI```"0```'BD```:````
M@J0```@```"=I```&0```*:D```.````P*0```<```#/I```"0```->D```*
M````X:0```X```#LI````@```/ND```+````_J0```D````*I0``!@```!2E
M```4````&Z4``!T````PI0``0@```$ZE```E````D:4``"4```"WI0``!@``
M`-VE```1````Y*4```D```#VI0``!@````"F```'````!Z8```8````/I@``
M!````!:F```1````&Z8```8````MI@``"@```#2F```B````/Z8```0```!B
MI@``!0```&>F```=````;:8```0```"+I@``#````)"F```.````G:8```H`
M``"LI@``#P```+>F```2````QZ8```L```#:I@``)@```.:F```I````#:<`
M`"0````WIP``)@```%RG```(````@Z<```H```",IP``!P```)>G```@````
MGZ<``"````#`IP``)@```.&G```*````"*@``!D````3J```*0```"VH```2
M````5Z@```<```!JJ```"@```'*H```,````?:@```\```"*J```$````)JH
M``!`````JZ@``'````#LJ```9@```%VI```.````Q*D```D```#3J0``"@``
M`-VI```2````Z*D``!,```#[J0``#`````^J```&````'*H```\````CJ@``
M$@```#.J```0````1JH``!$```!7J@``'````&FJ```C````AJH``&H```"J
MJ@``#P```!6K```0````):L```L````VJP``(````$*K```4````8ZL```P`
M``!XJP``#````(6K```/````DJL``!4```"BJP``*0```+BK```J````XJL`
M`"8````-K```)P```#2L```I````7*P``"H```"&K```&0```+&L``!"````
MRZP``!$````.K0``$@```""M```3````,ZT``!0```!'K0``#P```%RM```6
M````;*T``!<```"#K0``$````)NM```1````K*T``#0```"^K0``$P```/.M
M```2````!ZX``#4````:K@``%````%"N```'````9:X```P```!MK@``(```
M`'JN```0````FZX``!0```"LK@``$0```,&N```7````TZX``!P```#KK@``
M$P````BO```4````'*\``!H````QKP``$0```$RO```:````7J\``!X```!Y
MKP``&@```)BO```3````LZ\``!4```#'KP``$0```-VO```7````[Z\``!0`
M```'L```%P```!RP```)````-+```!`````^L```!@```$^P```%````5K``
M``<```!<L```!0```&2P```$````:K````0```!OL```!P```'2P```.````
M?+````P```"+L```#````)BP```-````I;````X```"SL```*````,*P```,
M````Z[````\```#XL```"@````BQ```(````$[$```D````<L0``*P```":Q
M```$````4K$```<```!7L0``"````%^Q```)````:+$``!0```!RL0``#```
M`(>Q```-````E+$```X```"BL0``%@```+&Q```1````R+$```,```#:L0``
M!@```-ZQ```9````Y;$```<```#_L0``!`````>R```+````#+(```L````8
ML@``!0```"2R```*````*K(```0````UL@``#P```#JR```Z````2K(```4`
M``"%L@``'@```(NR```.````JK(``!````"YL@``"P```,JR```,````UK(`
M``D```#CL@``!P```.VR```*````];(```X`````LP``$`````^S```;````
M(+,``!@````\LP``&@```%6S```*````<+,```H```![LP``#````(:S```/
M````D[,```@```"CLP``!@```*RS```'````L[,```4```"[LP``"P```,&S
M``!'````S;,```T````5M```"0```".T```$````+;0```,````RM```$P``
M`#:T```3````2K0``!,```!>M```"@```'*T```E````?;0```4```"CM```
M!````*FT```*````KK0```T```"YM```:````,>T```%````,+4```8````V
MM0``&P```#VU```O````6;4```\```")M0``$P```)FU```;````K;4``!@`
M``#)M0``%P```.*U```?````^K4```X````:M@```P```"FV```(````+;8`
M``<````VM@``"P```#ZV```'````2K8``%$```!2M@``$````*2V```,````
MM;8```8```#"M@``&@```,FV```E````Y+8```8````*MP``!@```!&W```&
M````&+<``!@````?MP``%P```#BW```H````4+<```8```!YMP``#0```("W
M```B````CK<``%<```"QMP``$P````FX```C````';@``!,```!!N````@``
M`%6X```(````6+@```T```!AN```"@```&^X```'````>K@```X```""N```
M!P```)&X```+````F;@``#(```"EN```"0```-BX```)````XK@```H```#L
MN```!P```/>X```)````_[@```<````)N0``$@```!&Y```*````)+D``!8`
M```ON0``"0```$:Y```0````4+D``!(```!AN0``!````'2Y```'````>;D`
M``4```"!N0``#````(>Y```(````E+D``!<```"=N0``#````+6Y```?````
MPKD``!H```#BN0``$P```/VY```$````$;H```H````6N@``!````"&Z```-
M````)KH```P````TN@``!0```$&Z```%````1[H``#@```!-N@``+````(:Z
M```I````L[H``#(```#=N@``"@```!"[```L````&[L``"X```!(NP``,P``
M`'>[```S````J[L``#@```#?NP``#P```!B\```8````*+P``!````!!O```
M#P```%*\```3````8KP``!4```!VO```%````(R\```2````H;P``!0```"T
MO```+0```,F\```M````][P``#$````EO0``+@```%>]```O````AKT``"P`
M``"VO0``8@```..]```-````1KX```@```!4O@``%P```%V^```(````=;X`
M``P```!^O@``*P```(N^```A````M[X``!H```#9O@``"0```/2^``!%````
M_KX``$$```!$OP``!````(:_```3````B[\``!,```"?OP``!@```+._```)
M````NK\```H```#$OP``#P```,^_```0````W[\```<```#POP``#@```/B_
M```%````!\```!L````-P```"````"G````&````,L```!0````YP```$0``
M`$[````.````8,```#@```!OP```!@```*C````.````K\````4```"^P```
M!P```,3````&````S,```"@```#3P```#````/S````<````"<$``"D````F
MP0``'P```%#!``!<````<,$``!0```#-P0``/@```.+!```?````(<(``!``
M``!!P@``!P```%+"```.````6L(```P```!IP@``#````';"```3````@\(`
M``H```"7P@``'0```*+"```9````P,(```4```#:P@``$0```.#"```1````
M\L(``"0````$PP``$@```"G#```.````/,,``!D```!+PP``"````&7#```)
M````;L,``!H```!XPP``!P```)/#```-````F\,``!X```"IPP``$@```,C#
M```L````V\,``!H````(Q```%0```"/$```%````.<0``!0````_Q```!```
M`%3$```&````6<0```<```!@Q```'@```&C$```H````A\0```H```"PQ```
M'````+O$```1````V,0```L```#JQ```&@```/;$```4````$<4```4````F
MQ0``!@```"S%```;````,\4``#0```!/Q0``-````(3%```@````N<4``"D`
M``#:Q0``(`````3&``!!````)<8``!H```!GQ@``*````(+&```I````J\8`
M`%````#5Q@``(@```";'```&````2<<```@```!0QP``!0```%G'```(````
M7\<``!D```!HQP``&0```(+'```J````G,<``",```#'QP``+@```.O'```T
M````&L@```@```!/R```%P```%C(```*````<,@```<```![R```(0```(/(
M```0````I<@```X```"VR```"P```,7(```'````T<@``!,```#9R```"```
M`.W(```*````]L@``!0````!R0``#P```!;)```R````)LD```X```!9R0``
M!0```&C)```/````;LD```0```!^R0``!0```(/)```$````B<D```T```".
MR0``,@```)S)``!%````S\D``!<````5R@``!P```"W*```>````-<H``!0`
M``!4R@``!@```&G*```'````<,H```X```!XR@``*@```(?*```&````LLH`
M``P```"YR@``#0```,;*```1````U,H```L```#FR@``-@```/+*```*````
M*<L``"(````TRP``"P```%?+```/````8\L``#(```!SRP``)0```*;+```P
M````S,L``#$```#]RP``+0```"_,```.````7<P```4```!LS```#@```'+,
M```3````@<P``!(```"5S```!P```*C,```1````L,P``!,```#"S```!P``
M`-;,```4````WLP``!@```#SS```!P````S-```%````%,T```P````:S0``
M#````"?-```2````-,T```0```!'S0``"@```$S-```+````5\T```P```!C
MS0``#@```'#-```.````?\T```4```".S0``!0```)3-```N````FLT``"8`
M``#)S0``(P```/#-```#````%,X``!X````8S@``&````#?.```E````4,X`
M``T```!VS@``'P```(3.```2````I,X``!(```"WS@``!````,K.```)````
MS\X```<```#9S@``#````.'.``!2````[LX``!<```!!SP``)````%G/```'
M````?L\```8```"&SP``#@```(W/```,````G,\```T```"ISP``%0```+?/
M```2````S<\```\```#@SP``%````/#/```*````!=```!L````0T```$```
M`"S0```+````/=```&D```!)T```&@```+/0```7````SM```"<```#FT```
M&@````[1```7````*=$``!L```!!T0``&0```%W1```?````=]$``!,```"7
MT0``"````*O1```(````M-$```D```"]T0``#0```,?1```C````U=$```T`
M``#YT0``$P````?2```(````&](```,````DT@``1@```"C2```_````;](`
M`#<```"OT@``5P```.?2```%````/],``!\```!%TP``+P```&73```-````
ME=,``"T```"CTP``!````-'3``!/````UM,``"4````FU```'````$S4```+
M````:=0``!\```!UU```'0```)74```+````L]0```<```"_U```"0```,?4
M```3````T=0```0```#EU```$````.K4```$````^]0``!0`````U0``#@``
M`!75```,````)-4``!,````QU0``'````$75```H````8M4```8```"+U0``
M!P```)+5```3````FM4```4```"NU0``%P```+35```*````S-4```P```#7
MU0``"0```.35```*````[M4``!$```#YU0``#@````O6```.````&M8``!T`
M```IU@``"P```$?6```"````4]8``!P```!6U@``!P```'/6```&````>]8`
M`&0```""U@``)@```.?6```X````#M<``!H```!'UP``*@```&+7```[````
MC=<``"@```#)UP``-````/+7```9````)]@``!4```!!V```!P```%?8```'
M````7]@```<```!GV```!@```&_8```+````=M@``!P```""V```$````)_8
M```)````L-@``!````"ZV```!P```,O8```%````T]@``!````#9V```%```
M`.K8```+````_]@```T````+V0``&````!G9```7````,MD```0```!*V0``
M"0```$_9```*````6=D```(```!DV0``(P```&?9```?````B]D``#@```"K
MV0``)@```.39```Q````"]H``"<````]V@``%````&7:```X````>MH``"@`
M``"SV@``.````-S:```H````%=L``"P````^VP``&P```&O;```^````A]L`
M`",```#&VP``)0```.K;``!!````$-P``%L```!2W```20```*[<```A````
M^-P``!\````:W0``*P```#K=```F````9MT``"<```"-W0``.@```+7=```S
M````\-T``"4````DW@``(````$K>```?````:]X``#````"+W@``:0```+S>
M```Q````)M\``$$```!8WP``,P```)K?```E````SM\``#T```#TWP``90``
M`#+@``!-````F.```"\```#FX```+@```!;A```P````1>$``%0```!VX0``
M6@```,OA``!(````)N(``$H```!OX@``,@```+KB```O````[>(``"P````=
MXP``+0```$KC```E````>.,``#(```">XP``/@```-'C```B````$.0``%(`
M```SY```)0```(;D```+````K.0``$4```"XY```(0```/[D```P````(.4`
M`"4```!1Y0``'````'?E```Q````E.4```<```#&Y0``!P```,[E```$````
MUN4```L```#;Y0``#@```.?E```%````]N4```(```#\Y0``60```/_E```%
M````6>8```@```!?Y@``,````&CF```#````F>8```P```"=Y@``#0```*KF
M```"````N.8```8```"[Y@``$@```,+F```?````U>8``#4```#UY@``+@``
M`"OG```O````6N<``!<```"*YP``(@```*+G```E````Q><``"````#KYP``
M&P````SH```8````*.@``"0```!!Z```'P```&;H```:````AN@``"$```"A
MZ```(````,/H```:````Y.@``#(```#_Z```&@```#+I```O````3>D``"L`
M``!]Z0``'P```*GI```C````R>D``!\```#MZ0``&@````WJ```A````*.H`
M`"4```!*Z@``)@```'#J```E````E^H``"0```"]Z@``&````.+J```=````
M^^H``"0````9ZP``&````#[K```B````5^L``"P```!ZZP``+P```*?K```5
M````U^L``"4```#MZP``/````!/L```?````4.P``",```!P[```'P```)3L
M```@````M.P``!H```#5[```&````/#L```F````">T``"D````P[0``'@``
M`%KM```I````>>T``!X```"C[0``,0```,+M```)````].T```P```#^[0``
M%P````ON```O````(^X``"0```!3[@``!P```'CN```=````@.X``!H```">
M[@``!P```+GN```5````P>X```8```#7[@``"0```-[N```+````Z.X```T`
M``#T[@``%P````+O```&````&N\``#,````A[P``$P```%7O```3````:>\`
M``\```!][P``!P```(WO```R````E>\```0```#([P``(0```,WO```3````
M[^\```P````#\```$0```!#P```R````(O```!8```!5\```"````&SP```=
M````=?````D```"3\```"@```)WP```4````J/```!T```"]\```"````-OP
M```?````Y/````@````$\0``&@````WQ```G````*/$```8```!0\0``%0``
M`%?Q```(````;?$``#\```!V\0``!P```+;Q```/````OO$```X```#.\0``
M$````-WQ```)````[O$```D```#X\0``!P````+R```9````"O(```H````D
M\@``"@```"_R```,````.O(```0```!'\@``*@```$SR```'````=_(```(`
M``!_\@``$````(+R```8````D_(```8```"L\@``!P```+/R```-````N_(`
M``L```#)\@``+P```-7R```@````!?,``#$````F\P``!0```%CS```2````
M7O,``#\```!Q\P``$@```+'S```*````Q/,```8```#/\P``!````-;S```3
M````V_,```4```#O\P``!@```/7S```&````_/,```0````#]```#`````CT
M```*````%?0``#D````@]```+@```%KT```I````B?0```8```"S]````P``
M`+KT```,````OO0``$4```#+]```,@```!'U```:````1/4``#0```!?]0``
M*````)3U``!3````O?4``!D````1]@``<@```"OV```@````GO8``#4```"_
M]@``(0```/7V``!%````%_<``#````!=]P``*````([W```I````M_<``"8`
M``#A]P``)0````CX```H````+O@``"@```!7^```(@```(#X```K````H_@`
M`#````#/^```$@````#Y```3````$_D``!`````G^0``>0```#CY```)````
MLOD``*$```"\^0``<P```%[Z``!\````TOH``"L```!/^P``5````'O[```7
M````T/L``"<```#H^P``%@```!#\```/````)_P``!<````W_```'P```$_\
M``!`````;_P``!\```"P_```'````-#\``!1````[?P``!H````__0``%```
M`%K]```2````;_T``!````""_0``$P```)/]```=````I_T```\```#%_0``
M#P```-7]```+````Y?T```<```#Q_0``!0```/G]```4````__T```<````4
M_@``"````!S^```/````)?X```@````U_@``#````#[^```/````2_X```8`
M``!;_@``%````&+^```&````=_X```P```!^_@``$0```(O^```(````G?X`
M``0```"F_@``&0```*O^```1````Q?X```H```#7_@``&````.+^```3````
M^_X``!$````/_P``%@```"'_```$````./\```\````]_P``&0```$W_```1
M````9_\```D```!Y_P``$@```(/_```7````EO\```8```"N_P``)P```+7_
M```$````W?\```\```#B_P``$P```/+_```'````!@`!``<````.``$`$0``
M`!8``0`8````*``!`!,```!!``$`$````%4``0`&````9@`!``P```!M``$`
M"0```'H``0`1````A``!`"(```"6``$`!P```+D``0`'````P0`!``L```#)
M``$``@```-4``0`+````V``!`(@!``#D``$`$P```&T"`0`7````@0(!``\`
M``"9`@$`!P```*D"`0`)````L0(!``<```"[`@$`!````,,"`0`9````R`(!
M`!T```#B`@$`+0`````#`0`A````+@,!`"L```!0`P$`+0```'P#`0`<````
MJ@,!`"L```#'`P$`"@```/,#`0`J````_@,!`!,````I!`$`#````#T$`0`1
M````2@0!``4```!<!`$`*````&($`0`/````BP0!``@```";!`$`%0```*0$
M`0`1````N@0!``H```#,!`$`C````-<$`0`.````9`4!``D```!S!0$`#P``
M`'T%`0`-````C04!``T```";!0$`$````*D%`0`*````N@4!`!0```#%!0$`
M!@```-H%`0"1````X04!``P```!S!@$`$0```(`&`0`6````D@8!``\```"I
M!@$`#@```+D&`0`.````R`8!``8```#7!@$`"P```-X&`0`U````Z@8!`!P`
M```@!P$`/0```#T'`0!(````>P<!`&D```#$!P$`9P```"X(`0!P````E@@!
M`&T````'"0$`0````'4)`0`'````M@D!`!(```"^"0$`"@```-$)`0`-````
MW`D!``L```#J"0$`!0```/8)`0`&````_`D!`!8````#"@$`"P```!H*`0`H
M````)@H!`"````!/"@$`%````'`*`0`0````A0H!`!(```"6"@$`"@```*D*
M`0`(````M`H!`!8```"]"@$`&````-0*`0`-````[0H!`!4```#["@$`%P``
M`!$+`0`@````*0L!`"(```!*"P$`&0```&T+`0`0````APL!`!4```"8"P$`
M$@```*X+`0`L````P0L!`!8```#N"P$`'@````4,`0`/````)`P!`%(````T
M#`$`+````(<,`0`D````M`P!``D```#9#`$`!P```.,,`0`T````ZPP!``\`
M```@#0$`!P```#`-`0`-````.`T!``4```!&#0$`'````$P-`0`.````:0T!
M`!````!X#0$`%@```(D-`0`<````H`T!`#8```"]#0$`"@```/0-`0`6````
M_PT!`!D````6#@$`%P```#`.`0`;````2`X!`!0```!D#@$`$@```'D.`0`J
M````C`X!`!,```"W#@$`"````,L.`0`,````U`X!`!(```#A#@$`&````/0.
M`0`:````#0\!``<````H#P$`&0```#`/`0`&````2@\!`!L```!1#P$`#0``
M`&T/`0`[````>P\!`#@```"W#P$`1P```/`/`0`4````.!`!`#(```!-$`$`
M-````(`0`0`U````M1`!`#H```#K$`$`"0```"81`0`&````,!$!`#,````W
M$0$`-````&L1`0`R````H!$!`%<```#3$0$`,@```"L2`0`Q````7A(!`$4`
M``"0$@$`2P```-82`0`Q````(A,!`$\```!4$P$`+0```*03`0`M````TA,!
M`$X`````%`$`,0```$\4`0`W````@10!`"H```"Y%`$`%@```.04`0`:````
M^Q0!`"L````6%0$`)0```$(5`0`E````:!4!`!(```".%0$`!@```*$5`0`-
M````J!4!`!T```"V%0$`&P```-05`0`K````\!4!``H````<%@$`+P```"<6
M`0`3````5Q8!``L```!K%@$`"0```'<6`0`*````@18!``4```",%@$`$P``
M`)(6`0`%````IA8!`!0```"L%@$`"````,$6`0`%````RA8!``<```#0%@$`
M#@```-@6`0`#````YQ8!``,```#K%@$`%P```.\6`0`3````!Q<!`"D````;
M%P$`"@```$47`0`%````4!<!``@```!6%P$`2````%\7`0!/````J!<!`$\`
M``#X%P$`(0```$@8`0`E````:A@!`"D```"0&`$`(````+H8`0`(````VQ@!
M`!L```#D&`$`(P`````9`0`M````)!D!`#8```!2&0$`*0```(D9`0`I````
MLQD!`%(```#=&0$`.@```#`:`0`(````:QH!`!4```!T&@$`#````(H:`0`)
M````EQH!``\```"A&@$`$@```+$:`0`/````Q!H!``T```#4&@$`"0```.(:
M`0`&````[!H!`!L```#S&@$`&`````\;`0`<````*!L!`!D```!%&P$`!@``
M`%\;`0`6````9AL!`%X```!]&P$`:0```-P;`0`'````1AP!``X```!.'`$`
M!````%T<`0`$````8AP!`!8```!G'`$`$P```'X<`0`5````DAP!`"$```"H
M'`$`.````,H<`0`S`````QT!``8````W'0$`#P```#X=`0`4````3AT!``X`
M``!C'0$`&P```'(=`0`/````CAT!`!0```">'0$`#P```+,=`0`$````PQT!
M``L```#('0$`"````-0=`0`.````W1T!``X```#L'0$`!@```/L=`0`,````
M`AX!`!`````/'@$`"````"`>`0`.````*1X!``<````X'@$`!P```$`>`0`0
M````2!X!``@```!9'@$`"P```&(>`0`'````;AX!``D```!V'@$`"@```(`>
M`0`*````BQX!`!\```"6'@$`1P```+8>`0`<````_AX!``P````;'P$`%```
M`"@?`0`5````/1\!`!8```!3'P$`+````&H?`0`\````EQ\!`"(```#4'P$`
M"````/<?`0`]`````"`!`"8````^(`$`$0```&4@`0`(````=R`!``4```"`
M(`$`$0```(8@`0`/````F"`!`"8```"H(`$`)@```,\@`0`J````]B`!`"D`
M```A(0$`)0```$LA`0`F````<2$!`"8```"8(0$`)@```+\A`0`T````YB$!
M`#$````;(@$`+@```$TB`0`P````?"(!`"4```"M(@$`,P```-,B`0!'````
M!R,!`#P```!/(P$`,P```(PC`0!!````P",!`$T````")`$`)P```%`D`0`E
M````>"0!`#,```">)`$`*P```-(D`0`6````_B0!`#`````5)0$`)0```$8E
M`0`F````;"4!`!<```"3)0$`L0```*LE`0`:````728!`"4```!X)@$`-```
M`)XF`0`T````TR8!`#`````()P$`*````#DG`0`I````8B<!`"P```",)P$`
M,P```+DG`0`V````[2<!`$L````D*`$`1@```'`H`0"9````MR@!`"T```!1
M*0$`)@```'\I`0`T````IBD!`#,```#;*0$`10````\J`0!,````52H!``T`
M``"B*@$`!P```+`J`0`%````N"H!``0```"^*@$`#````,,J`0`.````T"H!
M`!4```#?*@$`%````/4J`0`7````"BL!``\````B*P$`$0```#(K`0`-````
M1"L!`!````!2*P$`#@```&,K`0`-````<BL!`!4```"`*P$`#@```)8K`0`V
M````I2L!``8```#<*P$`$P```.,K`0`%````]RL!``P```#]*P$`!`````HL
M`0`-````#RP!`!$````=+`$`!@```"\L`0`0````-BP!``@```!'+`$`#P``
M`%`L`0`8````8"P!``\```!Y+`$`$P```(DL`0`0````G2P!``L```"N+`$`
M!P```+HL`0`-````PBP!``X```#0+`$`"P```-\L`0`0````ZRP!`!X```#\
M+`$`#0```!LM`0`/````*2T!`"D````Y+0$`$@```&,M`0`;````=BT!`#(`
M``"2+0$`#````,4M`0`>````TBT!`!D```#Q+0$`&P````LN`0`8````)RX!
M`#X```!`+@$`#0```'\N`0`)````C2X!`!0```"7+@$`"P```*PN`0`J````
MN"X!`$,```#C+@$`"````"<O`0`0````,"\!`",```!!+P$`$@```&4O`0`>
M````>"\!`!X```"7+P$`)P```+8O`0`:````WB\!`"$```#Y+P$`&@```!LP
M`0`8````-C`!``T```!/,`$`*0```%TP`0!)````AS`!`!T```#1,`$`!P``
M`.\P`0`*````]S`!`#T````",0$`!@```$`Q`0`(````1S$!`!$```!0,0$`
M$0```&(Q`0`3````=#$!`!,```"(,0$`&@```)PQ`0`:````MS$!`!T```#2
M,0$`'````/`Q`0`&````#3(!``L````4,@$`#P```"`R`0`E````,#(!`!(`
M``!6,@$`$````&DR`0`0````>C(!`!D```"+,@$`3````*4R`0!"````\C(!
M``D````U,P$`$P```#\S`0"(````4S,!`"$```#<,P$`)0```/XS`0`&````
M)#0!`!P````K-`$`*P```$@T`0`I````=#0!`"$```">-`$`(@```,`T`0`>
M````XS0!`!8````"-0$`#@```!DU`0`-````*#4!``\````V-0$`#0```$8U
M`0`/````5#4!``T```!D-0$`"P```'(U`0`1````?C4!``8```"0-0$`!P``
M`)<U`0`/````GS4!``P```"O-0$`+````+PU`0`0````Z34!``D```#Z-0$`
M"0````0V`0`D````#C8!`#`````S-@$`)````&0V`0`C````B38!`"$```"M
M-@$`(````,\V`0`S````\#8!`"$````D-P$`'P```$8W`0`&````9C<!``X`
M``!M-P$`"````'PW`0`(````A3<!``D```".-P$`%P```)@W`0`8````L#<!
M``T```#)-P$`"0```-<W`0`.````X3<!``L```#P-P$`'P```/PW`0`&````
M'#@!``D````C.`$`"P```"TX`0`,````.3@!``X```!&.`$`!@```%4X`0`9
M````7#@!`!(```!V.`$`!````(DX`0`J````CC@!`!````"Y.`$`'````,HX
M`0`'````YS@!``(```#O.`$`!P```/(X`0`"````^C@!``8```#].`$`%```
M``0Y`0`)````&3D!``T````C.0$`*0```#$Y`0`)````6SD!`!@```!E.0$`
M#P```'XY`0`(````CCD!``H```"7.0$`"0```*(Y`0`/````K#D!``,```"\
M.0$`#````,`Y`0`.````S3D!``8```#<.0$`%@```.,Y`0`J````^CD!`%(`
M```E.@$`+@```'@Z`0`O````ISH!``8```#7.@$`%0```-XZ`0`2````]#H!
M``P````'.P$`#````!0[`0`'````(3L!``4````I.P$`%0```"\[`0`(````
M13L!``@```!..P$`&P```%<[`0`$````<SL!``8```!X.P$`(````'\[`0`%
M````H#L!`!$```"F.P$`$0```+@[`0`0````RCL!`!(```#;.P$`%P```.X[
M`0`,````!CP!`#D````3/`$`&@```$T\`0`@````:#P!`!@```")/`$`!P``
M`*(\`0`)````JCP!``@```"T/`$`*````+T\`0`L````YCP!`#0````3/0$`
M#````$@]`0`=````53T!`#P```!S/0$`&````+`]`0`'````R3T!``H```#1
M/0$`#````-P]`0`/````Z3T!`!(```#Y/0$`2P````P^`0".````6#X!`'0`
M``#G/@$`(@```%P_`0`,````?S\!``T```",/P$`%P```)H_`0`8````LC\!
M`!0```#+/P$`"````.`_`0`1````Z3\!`!,```#[/P$`$`````]``0`4````
M($`!`!T````U0`$`)@```%-``0![````>D`!`!4```#V0`$`$@````Q!`0`,
M````'T$!`"$````L00$`%P```$Y!`0`2````9D$!`!$```!Y00$`$@```(M!
M`0`8````GD$!`#````"W00$`-````.A!`0`M````'4(!`#$```!+0@$`+```
M`'U"`0`N````JD(!`"(```#90@$`2````/Q"`0`8````14,!`!D```!>0P$`
M&@```'A#`0`;````DT,!`!$```"O0P$`&P```,%#`0`<````W4,!`!<```#Z
M0P$`&````!)$`0`Z````*T0!`!T```!F1`$`&@```(1$`0`^````GT0!`!8`
M``#>1`$`!@```/5$`0`,````_$0!`"(````)10$`$P```"Q%`0`8````0$4!
M`!,```!910$`*````&U%`0`J````ED4!`"````#!10$`)0```.)%`0`=````
M"$8!`!0````F1@$`'0```#M&`0`@````648!`"$```!Z1@$`&@```)Q&`0`;
M````MT8!`!8```#31@$`'0```.I&`0`<````"$<!`!X````E1P$`"@```$1'
M`0`4````3T<!``D```!D1P$`!@```&Y'`0`'````=4<!``@```!]1P$`!@``
M`(9'`0`&````C4<!``H```"41P$`%````)]'`0`0````M$<!`!4```#%1P$`
M$P```-M'`0`6````[T<!`#$````&2`$`$````#A(`0`>````24@!`!8```!H
M2`$`$0```'](`0`0````D4@!`#````"B2`$`"````--(`0`-````W$@!``H`
M``#J2`$`#````/5(`0`O`````DD!``T````R20$`%0```$!)`0`6````5DD!
M`!T```!M20$`%P```(M)`0`%````HTD!``P```"I20$`)0```+9)`0`&````
MW$D!``@```#C20$`&````.Q)`0`2````!4H!``<````82@$`#P```"!*`0`,
M````,$H!`!@````]2@$`3P```%9*`0`,````IDH!`"@```"S2@$`$P```-Q*
M`0`>````\$H!``X````/2P$`%````!Y+`0`1````,TL!`!H```!%2P$`&```
M`&!+`0`5````>4L!`!\```"/2P$`)0```*]+`0`C````U4L!`"4```#Y2P$`
M"P```!],`0`.````*TP!``P````Z3`$`#````$=,`0`%````5$P!``4```!:
M3`$`!````&!,`0`%````94P!`!4```!K3`$`4P```(%,`0`0````U4P!``L`
M``#F3`$`!0```/),`0`%````^$P!`!@```#^3`$`&````!=-`0`7````,$T!
M``L```!(30$`+0```%1-`0`&````@DT!``4```")30$`&````(]-`0`5````
MJ$T!`&4```"^30$`!0```"1.`0`'````*DX!`"D````R3@$`.````%Q.`0`4
M````E4X!`!D```"J3@$`*````,1.`0`=````[4X!`!P````+3P$`'P```"A/
M`0`1````2$\!``8```!:3P$`"````&%/`0`&````:D\!``\```!Q3P$`"0``
M`(%/`0!I````BT\!`!(```#U3P$`#@````A0`0`&````%U`!`!X````>4`$`
M*````#U0`0`'````9E`!``<```!N4`$`!0```'90`0`<````?%`!`!L```"9
M4`$`-0```+50`0`(````ZU`!``4```#T4`$`*@```/I0`0!4````)5$!`!H`
M``!Z40$`+````)51`0`;````PE$!``(```#>40$`"````.%1`0`3````ZE$!
M``P```#^40$`!@````M2`0`+````$E(!``L````>4@$`"P```"I2`0!+````
M-E(!``P```""4@$`$0```(]2`0`/````H5(!``P```"Q4@$`#````+Y2`0`,
M````RU(!`!(```#84@$`"P```.M2`0`<````]U(!``L````44P$`'````"!3
M`0`6````/5,!``0```!44P$`!````%E3`0`#````7E,!``\```!B4P$`"@``
M`')3`0`=````?5,!``X```";4P$`'P```*I3`0`B````RE,!`!<```#M4P$`
M!P````54`0`1````#50!``@````?5`$`#P```"A4`0`0````.%0!``D```!)
M5`$`!0```%-4`0!8````650!`#@```"R5`$`+0```.M4`0!%````&54!`!$`
M``!?50$`-````'%5`0!(````IE4!`$T```#O50$`30```#U6`0!2````BU8!
M`!T```#>5@$`)````/Q6`0`<````(5<!`"`````^5P$`(P```%]7`0`B````
M@U<!`"$```"F5P$`(````,A7`0`B````Z5<!`#H````,6`$`.@```$=8`0`^
M````@E@!`#L```#!6`$`/````/U8`0`Y````.ED!`)4```!T60$`'P````I:
M`0`.````*EH!`"8````Y6@$`#````&!:`0`3````;5H!`#@```"!6@$`,```
M`+I:`0`J````ZUH!``T````66P$`6P```"1;`0!5````@%L!``<```#66P$`
M%P```-Y;`0`7````]EL!``@````.7`$`"````!=<`0`)````(%P!`!$````J
M7`$`$````#Q<`0`-````35P!``\```!;7`$`!P```&M<`0`F````<UP!``@`
M``":7`$`!@```*-<`0`3````JEP!`!$```"^7`$`#P```-!<`0!5````X%P!
M``<````V70$`%0```#Y=`0`&````5%T!``<```!;70$`!P```&-=`0`T````
M:UT!`!````"@70$`(P```+%=`0`T````U5T!`"0````*7@$`?P```"]>`0`:
M````KUX!`%,```#*7@$`+@```!Y?`0`1````35\!``<```!?7P$`#@```&=?
M`0`/````=E\!``X```"&7P$`$P```)5?`0`&````J5\!`",```"P7P$`&0``
M`-1?`0`%````[E\!`!(```#T7P$`&0````=@`0`G````(6`!`!@```!)8`$`
M$P```&)@`0`@````=F`!``H```"78`$`"0```*)@`0`9````K&`!``L```#&
M8`$`%0```-)@`0`?````Z&`!`!4````(80$`-0```!YA`0`5````5&$!`"$`
M``!J80$`!P```(QA`0`7````E&$!``@```"L80$`!P```+5A`0`+````O6$!
M`"0```#)80$`-````.YA`0`(````(V(!`!T````L8@$`#P```$IB`0`(````
M6F(!`!$```!C8@$`%@```'5B`0`(````C&(!``H```"58@$`)````*!B`0`^
M````Q6(!`#\````$8P$`)P```$1C`0`T````;&,!`"P```"A8P$`30```,YC
M`0`C````'&0!`"X```!`9`$`-0```&]D`0!=````I60!`#(````#90$`!P``
M`#9E`0`(````/F4!``D```!'90$`"@```%%E`0`A````7&4!`"````!^90$`
M,0```)]E`0`E````T64!`#(```#W90$`/P```"IF`0`)````:F8!`!\```!T
M9@$`"P```)1F`0`)````H&8!`"T```"J9@$`$0```-AF`0`0````ZF8!``X`
M``#[9@$`"`````IG`0`8````$V<!``@````L9P$`#P```#5G`0`?````16<!
M`"(```!E9P$`1````(AG`0`2````S6<!``<```#@9P$`#P```.AG`0`'````
M^&<!``@`````:`$`!0````EH`0`2````#V@!`#\````B:`$`8P```&)H`0`=
M````QF@!``@```#D:`$`*````.UH`0`@````%FD!``@````W:0$`#````$!I
M`0`-````36D!`"H```!;:0$`!P```(9I`0`1````CFD!`!(```"@:0$`&```
M`+-I`0`1````S&D!`$````#>:0$`"@```!]J`0`A````*FH!`!````!,:@$`
M%````%UJ`0!`````<FH!`"P```"S:@$`/````.!J`0`]````'6L!`#8```!;
M:P$`#P```))K`0`&````HFL!`!(```"I:P$`%@```+QK`0`;````TVL!``D`
M``#O:P$`%````/EK`0`:````#FP!``@````I;`$`&0```#)L`0`?````3&P!
M``L```!L;`$`!@```'AL`0`6````?VP!`!````"6;`$`&````*=L`0`&````
MP&P!``P```#';`$`$````-1L`0`.````Y6P!`!0```#T;`$`%`````EM`0`&
M````'FT!``8````E;0$`-0```"QM`0`I````8FT!`"<```",;0$`"````+1M
M`0`4````O6T!`!@```#2;0$`*````.MM`0`-````%&X!`"H````B;@$`&```
M`$UN`0`4````9FX!``4```![;@$`"@```(%N`0`(````C&X!`!````"5;@$`
M90```*9N`0`:````#&\!`#\````G;P$`!P```&=O`0`'````;V\!`!$```!W
M;P$`$````(EO`0`2````FF\!`"$```"M;P$`'P```,]O`0`3````[V\!`"$`
M```#<`$`#P```"5P`0`H````-7`!`!0```!><`$`$0```'-P`0!V````A7`!
M`"````#\<`$`(````!UQ`0`I````/G$!`!T```!H<0$`'@```(9Q`0`F````
MI7$!`!\```#,<0$`'@```.QQ`0`<````"W(!``D````H<@$`"0```#)R`0`)
M````/'(!``\```!&<@$`-````%9R`0`:````BW(!`!@```"F<@$`"````+]R
M`0`'````R'(!`%L```#0<@$`0````"QS`0`]````;7,!`((```"K<P$`#```
M`"YT`0`V````.W0!`#````!R=`$`#@```*-T`0`_````LG0!``8```#R=`$`
M4P```/ET`0`N````374!`"\```!\=0$`%@```*QU`0`R````PW4!`"0```#V
M=0$`%0```!MV`0`,````,78!``4````^=@$`$@```$1V`0`*````5W8!`",`
M``!B=@$`!````(9V`0`A````BW8!`!(```"M=@$`"@```,!V`0`4````RW8!
M`!H```#@=@$`+P```/MV`0`-````*W<!``H````Y=P$`&````$1W`0`&````
M77<!`!X```!D=P$`#P```(-W`0`1````DW<!``\```"E=P$`$````+5W`0`1
M````QG<!`!D```#8=P$`"0```/)W`0`?````_'<!``L````<>`$``@```"AX
M`0`@````*W@!``<```!,>`$`"@```%1X`0!_````7W@!`"X```#?>`$`6```
M``YY`0`<````9WD!`"8```"$>0$`20```*MY`0`P````]7D!`#P````F>@$`
M'````&-Z`0`7````@'H!``@```"8>@$`"````*%Z`0`*````JGH!``8```"U
M>@$`"````+QZ`0`I````Q7H!`!<```#O>@$`&@````=[`0`7````(GL!``H`
M```Z>P$`"````$5[`0`2````3GL!`!X```!A>P$`"P```(![`0`-````C'L!
M`!H```":>P$`$0```+5[`0`%````QWL!``H```#->P$`$@```-A[`0`"````
MZWL!`",```#N>P$`*@```!)\`0`W````/7P!`"P```!U?`$`.0```*)\`0`N
M````W'P!`!L````+?0$`.P```"=]`0`R````8WT!`#T```"6?0$`,@```-1]
M`0`U````!WX!`"(````]?@$`1P```&!^`0`C````J'X!`#$```#,?@$`0```
M`/Y^`0!R````/W\!`&4```"R?P$`(0```!B``0`?````.H`!`#(```!:@`$`
M)````(V``0`C````LH`!`#D```#6@`$`/````!"!`0`H````38$!`"\```!V
M@0$`(````*:!`0`Y````QX$!`'<````!@@$`.P```'F"`0!4````M8(!`#8`
M```*@P$`-````$&#`0!.````=H,!`'0```#%@P$`7````#J$`0!'````EX0!
M`$````#?A`$`0````""%`0!B````884!`&<```#$A0$`8````"R&`0!C````
MC88!`#P```#QA@$`.````"Z'`0`T````9X<!`#,```"<AP$`*````-"'`0`T
M````^8<!`$T````NB`$`*@```'R(`0!7````IX@!`",```#_B`$`#````".)
M`0!-````,(D!`"````!^B0$`/@```)^)`0`G````WHD!`"0````&B@$`0@``
M`"N*`0`%````;HH!``D```!TB@$``P```'Z*`0`0````@HH!`!(```"3B@$`
M!@```*:*`0`!````K8H!`&0```"OB@$`!````!2+`0`&````&8L!`#0````@
MBP$`!````%6+`0`*````6HL!``P```!EBP$``@```'*+`0`'````=8L!`!8`
M``!]BP$`*````)2+`0!8````O8L!`#4````6C`$`-@```$R,`0`:````@XP!
M`"T```">C`$`,````,R,`0`F````_8P!`"`````DC0$`(````$6-`0`I````
M9HT!`"0```"0C0$`'P```+6-`0`H````U8T!`"4```#^C0$`*0```"2.`0`U
M````3HX!`!\```"$C@$`,@```*2.`0`Y````UXX!`"<````1CP$`*P```#F/
M`0`G````98\!`"(```"-CP$`*P```+"/`0`P````W(\!`"T````-D`$`+@``
M`#N0`0`J````:I`!`"$```"5D`$`)````+>0`0`P````W)`!`!\````-D0$`
M)P```"V1`0`X````59$!`#<```".D0$`'0```,:1`0`I````Y)$!`$L````.
MD@$`*````%J2`0`L````@Y(!`"@```"PD@$`*0```-F2`0`C`````Y,!`!\`
M```GDP$`*@```$>3`0`[````<I,!`"8```"NDP$`,0```-63`0`R````!Y0!
M`$4````ZE`$`#````("4`0`1````C90!`!T```"?E`$`-0```+V4`0`@````
M\Y0!``L````4E0$`(@```""5`0`A````0Y4!``H```!EE0$`&0```'"5`0`(
M````BI4!``L```"3E0$`#P```)^5`0`.````KY4!`"````"^E0$`!@```-^5
M`0!$````YI4!`!H````KE@$`%P```$:6`0`3````7I8!``<```!RE@$`1@``
M`'J6`0`&````P98!`"0```#(E@$`#P```.V6`0`.````_98!`!0````,EP$`
M0@```"&7`0`7````9)<!``L```!\EP$`(````(B7`0`,````J9<!``T```"V
MEP$`$P```,27`0`<````V)<!``<```#UEP$`)````/V7`0`(````(I@!`!@`
M```KF`$`,@```$28`0`&````=Y@!`!P```!^F`$`"0```)N8`0!"````I9@!
M``@```#HF`$`%0```/&8`0`6````!YD!`!4````>F0$`"@```#29`0`*````
M/YD!``T```!*F0$`(0```%B9`0`2````>ID!``H```"-F0$`#````)B9`0`*
M````I9D!`#(```"PF0$`"@```..9`0`"````[ID!`!@```#QF0$`(P````J:
M`0`/````+IH!``D````^F@$`#@```$B:`0`-````5YH!`#@```!EF@$`)0``
M`)Z:`0`P````Q)H!``D```#UF@$`%@```/^:`0!,````%IL!`!<```!CFP$`
M$@```'N;`0`*````CIL!``4```"9FP$`&@```)^;`0`&````NIL!``<```#!
MFP$`"````,F;`0`&````TIL!`!0```#9FP$`$P```.Z;`0`]`````IP!`"X`
M``!`G`$`/0```&^<`0`+````K9P!``(```"YG`$`$@```+R<`0!)````SYP!
M`#`````9G0$`%P```$J=`0`V````8IT!`"L```"9G0$`5P```,6=`0`6````
M'9X!`'@````TG@$`'P```*V>`0`^````S9X!`"`````,GP$`0````"V?`0`X
M````;I\!`"@```"GGP$`)P```-"?`0`H````^)\!`"D````AH`$`*0```$N@
M`0`G````=:`!`"\```"=H`$`+````,V@`0!`````^J`!`!8````[H0$`'P``
M`%*A`0`3````<J$!`(4```"&H0$`"P````RB`0"H````&*(!`'H```#!H@$`
MA0```#RC`0`L````PJ,!`%T```#OHP$`$P```$VD`0`N````8:0!`!L```"0
MI`$`%0```*RD`0`7````PJ0!`"(```#:I`$`1@```/VD`0`E````1*4!`"``
M``!JI0$`7````(NE`0`:````Z*4!`!4````#I@$`&@```!FF`0`5````-*8!
M`!D```!*I@$`(P```&2F`0`0````B*8!`!````"9I@$`#@```*JF`0`'````
MN:8!``8```#!I@$`&P```,BF`0`&````Y*8!``4```#KI@$`&0```/&F`0`(
M````"Z<!``D````4IP$`&````!ZG`0`-````-Z<!`!L```!%IP$`!@```&&G
M`0`'````:*<!`!4```!PIP$`"@```(:G`0`%````D:<!`"$```"7IP$`&```
M`+FG`0`)````TJ<!`"8```#<IP$`&`````.H`0`=````'*@!`!L````ZJ`$`
M"````%:H`0`1````7Z@!`!0```!QJ`$`%0```(:H`0`)````G*@!`!8```"F
MJ`$`&P```+VH`0`&````V:@!`#@```#@J`$`!````!FI`0`0````'JD!`!<`
M```OJ0$`"P```$>I`0`(````4ZD!``\```!<J0$`'````&RI`0`8````B:D!
M`!0```"BJ0$`"````+>I`0`1````P*D!``\```#2J0$`$0```.*I`0`K````
M]*D!``D````@J@$`"@```"JJ`0`2````-:H!``(```!(J@$`"P```$NJ`0`!
M`````````'\```#W`@``%@(``,@#````````60$```\#````````!0$`````
M``!=!0````````,%```T`0````````````!0`0```````-4#```Q`@``A0(`
M`(L"``#U!````````&\#``!,````"0$``(,"``"&!```7````)$!````````
M800````````Z````+@,``/,!``"]`0```````%8$``!/`@``S`,``*D```"2
M`0`````````````6````]P,```````!D!0``1P4``/($````````````````
M```!`P``/P0``*X$``!!`0````````\$``#"`0``)P,``,0"```C`@``QP(`
M`$("````````*P,``!L%``"N`P``A@4``#T!``!@`P``>`4``+H"``!\`P``
M``````````!P`@`````````!``!U!````````"(!``#^`@``.P$```````#L
M`0``)`0`````````````4P4``/$$```7`````````!P#``!;`P``E0(``(X!
M```1`@``L`(````````.`0``+@(``&0!``#W!```^@,``!,#``!P!0``]`0`
M`#$```"0`0``(P,````````]!```P@```(P#```7`@```0$``*````!>!0``
M`````'4!``"L`0````````````"%!```004````````#!```=`0``+`!``!*
M`@``4@````P$``"6````]0,``````````````````/0!``#Y!````````.`"
M``!D`P``3`,``$@#``#X`@``@````'P%```:`P`````````````^!0``DP(`
M`%L$``!U!0``R0```/`$```&`0````````4#``!C!0``````````````````
M`````)H$```4!0````````````#C````Z@,``/H````,!0```````&\$```N
M!0``P````!D#```B!0``,`$``)@"`````````````!8!````````M`,``%@!
M``#=`0```````)H#````````5P$```````!.`@```````)(```#_!```````
M`````````````````.,!````````Z0```(0%``"L!```0P4```````".!```
MI0$``#\!```?````QP,``%$%````````T@0``#<$```-`0``-0,``(P!````
M````%0(```P`````````I````'(%``">`P``E@(```H#````````<```````
M``##`@```````/T!```^````+@0``,H#``!'`@``FP``````````````,@,`
M``````"K`0``40$``````````````````!L"``!H`````````*@"``"-`P``
M<P,``(L!``````````````````#\`P``Z`$``-P!``````````````````!;
M`0``4P,```````"9`@``CP```'8!``#P`P``F`,````````.`````````!0"
M``#;!```&0(``.X```"\`@``EP0``#\#````````<`,``'H```!@`0``GP$`
M````````````H0$``&H$``#T`P``6P4``'<"```B`P````````````#"!```
M\0````````!@`@``V`,```````#)`0``@`(```````![`0``&`$````````P
M!```````````````````&`(``-H`````````L0(``-,#``"<`@``X00``"H"
M``!&!````````.@`````````V`(```D%``#/`@``$04``+L!````````-P4`
M`+8$``"0`@``````````````````)P```"P"``![!0```````,T#``#;````
M`````)("```"`P``K0,``,@```!K`````````'8```!A`P``:04````````!
M!0``J@```+8"``!!!````````.8$``!.`P``$@,``)@`````````:@,``.T"
M``"/`0``0P```*H"```<!0``B`,````````A!0```````#X#````````HP$`
M`(\#``!=`P`````````````>`@``KP0``)T$``"$!```K`(``+$`````````
M=P0``&L#``"&`````````+,#```U`0```````&H```!L`P``[00``$L"``#B
M````OP```+\$````````FP$``'X%``!V!0``W0```)T#``!&`P``30(`````
M``#1`P``'0```)$"``#Q`@``````````````````.@,`````````````&`4`
M````````````H@(``+<$``!,!0``^`$```T"``![````0P0``%H!````````
MY0(```````"<`P``20(``$@%``#1````(@(```````#C!```AP,``(D"``#9
M`P``&P0``"<!``#D`0``^````$\```!0````&00``-@$````````[@(``$L%
M````````/0,```````!%``````````````#-!```8@4``*4#``"R`@``-@4`
M`.8#``"-!````````#8#````````[`(```````#&````*`$``-@```".`@``
M``````````#\`@```````!\"````````&@$``/\```!)!0``;@,```8"``!G
M`0``L@$``.\#````````_P,`````````````)@0``#L%````````)P4``*0#
M``#8`0````(``/@#```O`@``'04``/4````C!0``J@,``'D`````````,`(`
M`$D#```H!0``"0,``,\!``!G`@``9@(````````!`@``600``'4```"H`0``
M(0$``/$!```.!```Q`,``&X$``!-!0``5P,``-`#``#Q`P``9@,``$X```#3
M`@```````!,"````````Q@0``'4#``"=`@``'@```)X"``#6!```````````
M``!I`@``Z`0``$L$```@`@``!`$```````#]`@``)00``*`"````````*@``
M``````!J`@``6`4``.H!`````````````$<```"!!0``)0$``*D"````````
M%`,```@$````````>@$``+$!```2!```W@$```H````V`@``4@$`````````
M````0`(``($````H!```'0$``$,#``"J!```5@(``+,"````!0```````$H#
M```\`P``@`,``/,```".````2P$````````R`````````#@"```C````````
M`"X````L`0``?00``&@!``!U`@``N@0``"P````C`0```````*\"``!X````
M50,```````!8`@````````````!3`@``804```````"W`0``EP(``/X#``!\
M`@``W`,```P!``#C`P``GP````````!M`@``AP$``+8!```:!````````&T!
M``!2`@``Y`0`````````````J````,4"``")````^0,```H!```"````EP``
M`#H$``#J!```_````(@$````````-@0``%\!``!I`0``YP````<$```)````
M\@$``/H$``#5!```-`(``,4$```I`@``[0,``$0"``!G!0``S`0``+0"````
M````6`0``+,```!-`P``W@```$T!``!?`@```````'\!``#,`````````(H!
M```0!0```````'@$``!S`0``Y0```)4#``!8`P``D0```#<#```)`@``+00`
M`*D!``#]````L0,```````!%!```!`4``%,````J!```?P4```````#E!```
MT@(``!T"````````<@,```````#6`P``<@$``-D"````````3`(``(("```@
M`P``Q0```.<"````````C0```&`%```&````=`(````````#`0``G0$``*,"
M```K!0``9````#($``#[````G@``````````````T`(``&<$````````F0$`
M`',%``!B````70$``+T#````````4@0``'\"``"T````W`(``.P#```^`@``
MA0```"T```#!`0``````````````````RP```*T```"7`P``````````````
M`````````!<#``!K`@``A@(````````5`P``0@```-0"````````.@(`````
M``!;````U`,``/8!```$````$0```)`#``"<````+`,`````````````.`0`
M```````Y!```7P```#D%````````Z0,``"@#``#[!````````%0`````````
MF`$``+8```"O`0``>P0``'`$``!5`@``20```*D#```9````.P(``%`#```H
M`@``7`,``&@#```T!```B`(``,H$``#1`0``+0$``(`!`````P``````````
M``!_!```I00```````!"`P```````.<#```P`````````/T#````````.0``
M`-0$````````M@,```````#P`0``1`4``)D$```0`P``6@,``&<#``#T`@``
MF0```&8```!X`P``'P,``+L"``#_`0``!04```````#D`P``I0(``*8"```+
M`0```````/8````\!0``Z`(````````8!```UP0```````!*````DP0```H%
M```&!````````*\#``!]````S0````````#M````80$```0"````````O00`
M````````````F`0``#D!``!M`P``EP$``$T$```"`@``;@```)8#````````
M,0,``&X"````````IP0``!X#```F`@``T`$``"T%````````5@$``*`!````
M````50```/4"``"+!```/````&4#``!(!```504``+D"``#6`0``.````#P$
M``!Y`@``500``%D"```\`@```````*<"``#_`@```````)0```!E!```-@$`
M`,,#`````````````$<#``#2`P``[P(``&``````````QP$```````!Y`0``
M`````(D$``"N`0``````````````````7P0``%@````S`@``3P,````````?
M`0```````'<%``"X`@``PP```+($``!>`0```````(,$````````H00``.($
M````````!00``&D$````````/0```!P"``"P```````````````S`0``*0$`
M`,L#``#*`0``N`0``&,#``"#!0```````!X$``#;`@``B@```"4```#G!```
M^P$````````/`@``A04``#(%``!;`@``1@(``"T"``#I`@``'`0```````"!
M`P``%`0``&\```#9!````````$(%``!`!```;`4``*(#``":`@``%@0`````
M``#R`@``$P4```P"```(````I`(``#4$``!'!```6@```#\%``"]````````
M``(!``!=!```V@0``%$````'`@``Q0,`````````````7P,``'D$``!(`@``
M*P```"D````F!0```````#`%``"`!```B@,``+D!``!7!```+P$``*L````[
M!```AP(``,P"``#!!```:0```!8%``!`````\`(``)($``"+`P``D`0`````
M``#+`0``Y`(``+4#``!R!```!0(``/P$```"!```R`0```$$``"S`0``QP``
M`(@`````````5`4``$8%``"N````;00``,X!````````XP(``+X!``!%`P``
M`````#8```"S!````````%$#```-`P```````"\$```H`````````!T#````
M````:`4``,$#````````"@0```T%`````````````!(%``#`!````@4``!P!
M``"4`0``(P0``,,!````````.`$```````!%`0``,P,```````"X`0``RP0`
M`+4```"F!```Z00``&,!``"1`P``6@4``(,```![`P```````!````#``@``
M`````"H#``!&````TP$``&<```!R`@``````````````````?0,``+H#````
M````X@(```````"$````R0(``)4!````````OP$```````"*`@``1@$``&`$
M``"R`P```````($"``"$`0```````*L$``#)`P``'@4```````!/`0``4`4`
M``,#````````$0,``'H"````````/@0``#4"```4````&@(``'0`````````
M:`0``.`#````````CP0``"<$``#/`````````$$```"'!````````+X"``!.
M`0``B@0``.L#``#E`P````````@"````````H0,``)T````Y`P``$`(`````
M```8````[@0``$D$``!C`@``WP,``&P!``!5`0``,04``+T"``",````````
M`'H#````````5`0``!<!``"U`@``"P4`````````````3@4``%<`````````
M!0`````````9!0``VP$```````"K`@``G`$``.`!``!P`0````````````!*
M`0``$@$``#L#``!T`0```````*P`````````5`(``!(`````````?@,``&(!
M```Y`@``MP(``%X#````````W@0```````#J`@``U0$``+\"``#$`0``)0,`
M`-0!````````N0,```,```#]!```JP,``/8#`````````````.T!```D`0``
M`````$(!``#7`0```````.X!``!:`@``G@$```````"Z`````````/X$``!:
M!```VP,``!,```"H`P``&@````P#``#O`0``````````````````T`0``-\`
M````````GP(```L#``!``0```````+X#``"C```````````````B````5@4`
M`"0%``!]`@```````$$#````````-P(```<#````````HP0``,8#````````
MK@(``&P$```E!0```````*P#``!3`0``4@4``'P$````````Y@``````````
M````?@0``,X$``!+````40(``(<%``"&`0``#0```%0!``"2`P``=@0`````
M``"D!```@@$```<!`````````````"$"``!2`P``"@(``$H$````````>P(`
M````````````/0(``-P$``#4````:`(``&8!````````````````````````
M2````#$$````````H0```-<"````````60```(\"``")`0``?`$``+L```!0
M!```O`$````````5````<@````````#[`P``/04``&\!````````-04``-<`
M``"B````0P$``.\$``!<!0``S0$``,<$````````!@4``/<!``#>`P``+P4`
M``@#```4`0```````(($``#:`P``SP,``$H%``"X````10(``,X`````````
M1P$````````)!```20$``.8!``!=`@````````````!Z!0``3@0``!\$```;
M`0``'00``$0#````````TP0```8#``#?!`````````````#$````D````(<`
M``!-````_`$``/8$``!"!````````((#``"Z`0``RP(``,`!``!K!0``````
M`/,"``!Q!0``B`$``'X"````````Y0$```````!O`@``V@$``&4%````````
MX0,```````"U!```Q@(``&P````7!```7@(````````F`0``!`0````````S
M!0``604``'@"``!K!```)0(``.L`````````P0```.H```!B`P``%0$`````
M``!!`@```````.P```",!```R`(``"8`````````_@$``*($``"4!```TP``
M`"\#``!A`@``%P4``!P````2`@``>0,``&T%``!F!```;P4````````Q`0``
M`````&$``````````````'X!``!N`0```````!,$``"3````1``````````P
M`P``[P```/D`````````^@(``+L$```G`@``(0```+$$``#R`````````)0"
M````````^@$``/````!M````3`0``.L$```.`P``>04``,X#``"E````M`$`
M`)4$```R`0```````"\```"D`0```````'$#```@!```BP```"``````````
M2`$``)8$````````T@````````#7`P``N00``)D#````````F@```"($``"O
M````3P0``/D"``"5``````````0#````````&P````````"U`0``P`,``#H!
M``#B`0````````````#@`````````&H!````````V0$``-(!``!C````]P``
M`',"````````-`4```````"J`0```````.8"``!V`P``````````````````
M#00``%T`````````$`$``'$"````````K0(``````````````````#@#``#,
M`0``2P,``$4%``!7`@```````+`$``"B`0``NP,``)H!``#K`@``X0$`````
M`````````````/D!``#A`@``````````````````4`(```````"_`P``_@``
M`,X"```````````````````M`P``<P0````````K`@```````)\$````````
M```````````T````60,````````D````=P$``!D!```(!0``C0$``#@%```'
M`````````+X$```J`0``\P0``*D$```'!0``J`0`````````````3P4``/(#
M``#[`@```````"P$```+`@``:0,``````````````````'<```!Q!```90$`
M`-T#```5!0```````-P```"%`P``?0$```````"\`P```````!4$```8`P``
M]````-$"``"F`0``90(``'X```#6`@``1`$``,4!``#@!```0P(``+D```""
M!0``#P4```````"A`@``5P4``)L"````````9`(``&("``!6`````````/8"
M``#9````V@(``(0"```D`@``DP$```````#U`0```````"`!```D`P``````
M`*<!````````5`,``.(#``"?`P``#P$``,,$``"3`P```````(`%``#0````
M5@,``.P$````````?````#,```#5`@``@@````,"``"@`P``:P$```````"M
M!```P0(``$0$``#-`@``HP,````$``".`P``Q@$``$`#``"\````-P```-\!
M``#"`@``.@4``'$!```L!0``FP,``'$````J!0``)@,`````````````*P$`
M````````````YP$``,@!``",`@```````,0$````````(00``(,!``#"`P``
M"`$``.D!``!>````Y`````````!Z!````````)P$````````X0```/@$````
M`````````($!````````<P```&,$``"#`P``#@4`````````````&P,``+X`
M````````O`0````````I`P``7`(````````U`````````/,#```W`0``0`4`
M``````!<`0````````````#=!````````%,$```^`0``;`(``#("``#=`@``
M``````````#6````T00``&0$``#N`P``,P0``&X%```K!```?04```````"$
M`P``90```'<#``!<!```'@$``+<#``#)!````````'\#``"&`P``#@(`````
M``!?!0``+@$``*8```"R````/`$``-4```!B!```G@0``#0#``#?`@``3`$`
M`+`#```_`@``.P`````````1`0`````````````+!```D00``+0$``!X`0``
MIP,``!\%```3`0```````(D#````````$`0``&H%``#*````7@0```L```"%
M`0``=@(``"`%``#*`@``K0$``*8#``!T!0``````````````````IP``````
M``"6`0``$00``)0#``"-`@``@00``&8%``!T`P```````#\```#K`0``````
M`*`$``````````````````"X`P`````````````6`P``SP0``"$#````````
M&@4``-X"```I!```Z`,``)L$``!1!```MP```"D%```/```````````@*"5S
M(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O
M9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO
M="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E
M<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B
M)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T
M;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E
M<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E
M+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A
M;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D
M+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!+
M0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S
M(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L
M<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F
M;W)M('1H92!M86EN=&5N86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N
M($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@
M=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI
M;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E
M<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML
M:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W
M:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@
M;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A
M;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG
M("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`
M,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`/%!R979I
M;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@4F%I;@!!32!3:&]W97)S`$%-
M(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E9&ET;W(`
M06)O=70N+BX`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y
M+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN
M9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C
M8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES
M<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I
M;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M
M:7-S:6]N('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D
M(&YE=R!M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO
M>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@
M861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S
M`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!;&EG;@!!;&EG;FUE;G0Z
M`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!0
M97)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R
M97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR
M96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-
M4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E
M(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@
M=&5X=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN
M;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;G-W97(`07!P;&EC871I;VX`07!P
M;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@
M0VAI;&0@4VAA<F5S`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@
M<W5B+6=R;W5P<S\`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!
M='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP
M="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP
M="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@
M=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U
M<W0`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I
M<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT
M96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B
M;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N
M;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I
M<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L
M92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A
M=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S
M=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q
M=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z
M(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N
M=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO
M;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO
M;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE
M(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!"86-K9W)O
M=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"
M860@:V5R8F5R;W,@=7-E<FYA;64N`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y
M("(E<R(@;F]T(&9O=6YD+@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI
M8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4
M>7!E`$)O;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!"
M;W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1T;VT`0G)A
M>FEL`$)U;&QE=&5D($QI<W0`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O
M:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C
M;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%N(&YO="!C;W!Y
M(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M
M92X`0V%N(&YO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H
M:6X@<V]U<F-E+@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L
M;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E
M('1O(&9I;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I
M;VX@:&%N9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S
M`$-A;B=T(&]P96X@9FEL92`B)7,B+@!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87)R:65R`$-A
M=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE
M`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE
M<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96YT97(`0V5N=')A;"!%=7)O
M<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T86EL<P!#97)T:69I
M8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%N9V4`0VAA;F=E
M(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H
M870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U
M<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O
M<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL
M90!#:&EN80!#:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D
M`$-H;V]S92!A('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E
M<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I
M`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A
M<B!1=65R>0!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U
M<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&]S
M92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]L;&%P<V4@
M4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`
M0V]L;W5R('-E;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#
M;VUM86YD`$-O;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUP
M86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET
M:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O
M<F0`0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N
M;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O
M;CH@)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#
M;VYT86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@
M9FEL93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]P>0!#;W!Y(&9A
M:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]U;&0@;F]T(%!'4"!E;F-R>7!T
M(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@`$-O=6QD
M(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H96-K(&)A
M;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&5%`Z("5S
M`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD
M(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=7!D871E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B
M.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@
M(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B
M.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A
M=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S
M`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-U<G)E
M;G0@-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R
M<F5N="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WEP<G5S`$1A:6QY`$1A=&4`1&%T92!296-E:79E9`!$871E('-E;&5C=&EO
M;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S
M`$1E8W)E87-E($EN9&5N=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E
M;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7-P;&%Y(#(T+6AO=7(@
M=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C
M87-T`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$
M;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N
M8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N
M86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<G5G
M<P!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`
M161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET
M(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@
M<&5R;6ES<VEO;G,@9F]R("5S`$5G>7!T`$5L96UE;G0N+BX`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C
M;VYF:7)M871I;VX`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T
M>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\`16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@
M82!S96-U<FET>2!Q=65S=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I
M9B!Y;W4@;F5E9"!T;R!R97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T
M(&ES('1H92!N86UE(&]F('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!5
M4DP@:&5R90!%;G1E<B!T:&4@;&5T=&5R<R!B96QO=SH`17)R;W(`17)R;W(@
M8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@86YC:&]R
M.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`17)R;W(@9V5T=&EN
M9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S=V]R9#H@)7,`17)R
M;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET:6YG("(E<R(N`$5V
M97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N
M9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U
M<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD
M`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O
M<F0@;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O
M;F5N=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R
M:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0
M('-E<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I
M;&5D('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B
M+@!&86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE
M9"!T;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I
M<@!&871A;"!%<G)O<CH`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&
M:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L
M;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA
M;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;V<`1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&
M*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R=V%R9',`1G(`1G)A;F-E`$9R
M;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@
M3F%M90!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'96YE
M<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E<FUA;GD`
M1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`1V\`1V]O9VQE
M($UA<',`1W)A>7-C86QE`$=R965C90!'<F]U<"!!9&UI;FES=')A=&EO;@!'
M<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S
M86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'
M<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'
M=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`2&5A9&5R`$AE861E<G,`2&5I
M9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES<&AE<F4`
M2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H`$AO7VUE
M`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M92!!9&1R
M97-S`$AO;64@1&ER96-T;W)Y`$AO;64@4&AO;F4`2&]R:7IO;G1A;"!2=6QE
M`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G
M970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M
M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T
M;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6YG87)Y`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)7VYS
M97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E
M<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N
M;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE
M=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN
M=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B
M;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T
M:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@
M=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N
M`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R
M;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!)
M;6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O
M<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I
M;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:79I
M9'5A;"!5<V5R<P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`
M26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"
M969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T
M92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@
M869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`
M26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P
M87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T
M(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-
M;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F
M9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L
M:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A
M<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B
M:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9E;G1O<GD`26YV97)T
M('-E;&5C=&EO;@!)<W-U97(`271A;'D`2F%N=6%R>0!*87!A;@!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V5E<"!O<FEG:6YA;#\`2V5R8F5R;W,@
M<V5R=F5R(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97D@0W)E871I;VX`
M2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E
M`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`
M2VED<P!,85]Y;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D
M($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N
M`$QE9G0`3&5F="!H96%D97(`3&5F="!V86QU97,`3&5V96P`3&EG:'0@4F%I
M;@!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S
M('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI
M<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,
M:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T
M+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4W5B<V-R:6)E`$QI<W0M
M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I
M;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D
M+@!,:71E<F%T=7)E`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A
M;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!4
M87-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A
M<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N
M`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R
M(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G
M`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`36%G:6,`
M36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%N86=E('1H92!L:7-T
M(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@
M86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`
M36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K
M('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-
M871C:&EN9R!F:65L9',`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G
M92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA
M>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A
M;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UE9&EC:6YE`$UE;6)E<G,`
M365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F
M=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B
M92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T
M:&]D`$UE=&AO9"`B)7,B(&ES(&YO="!D969I;F5D`$UE=&AO9"!N;W0@9&5F
M:6YE9"X@0V%L;&5D(&UE=&AO9#H@)7,`365T<FEC`$UE>&EC;P!-:61D;&4`
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UI;FEM=6T@<&%S<W=O<F0@86=E(&AA<R!N;W0@>65T(&5X<&ER960`
M36ER<F]R`$UI<V-E;&QA;F5O=7,`36ES<VEN9R!014%2('!A8VMA9V4@2%14
M4%]297%U97-T+@!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O
M(&=E;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L
M:6-A=&EO;BX`36ES<VEN9R!M97-S86=E($E$+@!-:7-S:6YG(')E<75I<F5D
M(%!%05(@<&%C:V%G92!-86EL+@!-:7-S:6YG('-E<W-I;VX@240N`$UO`$UO
M9&5R871E`$UO9&EF:65D($1A=&4`36]D:69Y(%523`!-;V1U;'5S`$UO;G1H
M(&%N9"!Y96%R`$UO;G1H;'D`36]O;B!0:&%S97,`36]R92!F:65L9',@9F]U
M;F0@:6X@;&EN92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"X`36]V92!$;W=N
M`$UO=F4@3&5F=`!-;W9E(%)I9VAT`$UO=F4@57``36]V92!D;W=N`$UO=F4@
M=7``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!)
M;F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!.3RP@22!$
M;R!.3U0@06=R964`3F%M90!.971W;W)K`$YE=F5R`$YE=R!#871E9V]R>0!.
M97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@<&%S<W=O<F0`
M3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S
M(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R
M;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI
M9VAT`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D
M:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K
M:6YG($E33R!I;6%G97,N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S
M=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#
M04P@875T:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44PM1FEL92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S
M=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@
M;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S
M<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S
M<&5C:69I960N`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!(5%10(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@24U!4"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($ME<F)E<F]S
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@3&]G
M:6X@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!0
M05-35T0@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!334(@875T:&5N=&EC871I;VXN`$YO('!A=&@@=&\@=&AE($]P96Y34TP@
M8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E;E-33"!B:6YA<GD@:7,@;F5C97-S
M87)Y('1O('=O<FL@=VET:"!02T-3(#$R(&1A=&$N`$YO('%U;W1A('-E="X`
M3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@
M<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O
M<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO
M('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N
M(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I
M9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE
M("AU<V4@:6UP;&EC:70I`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=V%Y`$YO
M="!!9G1E<@!.;W0@0F5F;W)E`$YO="!A(&1I<F5C=&]R>0!.;W0@:6UP;&5M
M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E9"X`3F]T97,`3F]T:&EN9R!T
M;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R`$YU;6)E<@!.=6UB97(@;V8@
M8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN<P!.=6UB97(@;V8@<F]W<P!.
M=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG(&EN(&1I<W1R:6)U
M=&EO;B!L:7-T+@!/8FIE8W0`3V)J96-T($-R96%T;W(`3V-T86P`3V-T;V)E
M<@!/9F9I8V4`3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R
M96YT+@!/;&0@<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T
M+@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD97)S+@!/
M;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R
M(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP
M(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N
M97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A
M=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I
M;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO
M;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T
M:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E
M;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@
M26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T
M:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!'4"!%;F-R>7!T960@1&%T80!01U`@
M4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E
M`%!(4"!3:&5L;`!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!0861D:6YG
M`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN
M`%!A<W-W;W)D(&EN8V]R<F5C=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$
M2553(&%U=&AE;G1I8V%T:6]N+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO
M;@!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E
M($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N
M(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E
M9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&AO;F4`4&AO
M=&]S`%!L96%S92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S
M92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N
M="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BX`4&QE87-E(&5N
M=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E(&5N=&5R
M(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T
M92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES(&EN('1H92!M;VYT:"X`4&QE
M87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N
M86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E
M>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@
M<WES=&5M+@!0;&5A<V4@='EP92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O
M;&%N9`!0;VQI=&EC<P!0;VQL<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T
M:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T
M:&ES(&9O;&1E<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I
M;VX@9F]R(&QA<W0@)7,@:&]U<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q
M=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0
M<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E
M=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO
M;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M
M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!
M;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A
M:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U<F=E(&UE<W-A9V5S
M`%%U97)Y`%)A9&EO('-E;&5C=&EO;@!286EN`%)A=&EO`%)E860`4F5A9"!M
M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN
M;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E
M<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S
M('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5L;V%D`%)E;6%R
M:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W
M;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG
M=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H
M=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN
M+@!2;VQE`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O
M=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S
M('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L
M97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%,O34E-12!#<GEP=&]G
M<F%P:&EC(%-I9VYA='5R90!3+TU)344@16YC<GEP=&5D($UE<W-A9V4`4T%3
M3"!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!335,@365S<V%G
M:6YG`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4V%M92!F<F%M
M92`H7W-E;&8I`%-A=&5L;&ET92!0<F]V:61E<@!3879E`%-A=F4@(B5S(@!3
M879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T
M:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R
M>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38VEE;F-E`%-E87)C:`!3
M96%R8V@@16YG:6YE<P!396QE8W0@1FEL97,`4V5L96-T(&$@9&%T90!396QE
M8W0@82!G<F]U<"!T;R!A9&0`4V5L96-T(&$@;F5W(&]W;F5R`%-E;&5C="!A
M('-E<G9E<@!396QE8W0@82!U<V5R('1O(&%D9`!396QE8W0@86QL`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!N;VYE`%-E;&5C="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H
M92!B;WAE<R!B96QO=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H
M96T@9G)O;2!T:&4@=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI
M=&5R.@!396QE8W0@=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT
M:71Y('EO=2!W86YT('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM
M:71E<CH`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C
M:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T
M('EO=7(@<')E9F5R<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T
M`%-E;F0@4TU3`%-E;G-O<CH@`%-E<'1E;6)E<@!397)I86P@3G5M8F5R`%-E
M<G9E<B!D871A('=R;VYG(&]R(&YO="!A=F%I;&%B;&4N`%-E<W-I;VX@061M
M:6X`4V5S<VEO;B!)1"!E>'!I<F5D+@!397-S:6]N<P!3970`4V5T(&]P=&EO
M;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U
M(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y
M;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@
M<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS
M+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L
M('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`
M4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L
M(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!3:&]R
M="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M
M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R
M96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A
M=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3
M:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@
M=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O
M;B!T:&4@;&5F=#\`4VAO=R!U<&QO860`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VYO=P!3
M;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I
M8V$`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT
M(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E
M;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3
M<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M
M;@!3<&QI="!R;W<`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&]R
M86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N
M=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5C8V5S<V9U
M;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L
M96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C
M8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@
M(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C
M;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F
M=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY
M('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C
M97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3
M=6UM87)Y`%-U<'!O<G0`4W5R;F%M90!3=V5D96X`4W=I='IE<FQA;F0`4WEN
M=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!486)L92!0<F]P97)T:65S`%1A
M8FQE(%-E=`!486)L92!P<F]P97)T:65S`%1A<F=E=#H`5&%S:W,`5&5L97!H
M;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!4
M96UP97)A='5R93H@`%1E;7!L871E("(E<R(@;F]T(&9O=6YD+@!496UP;&%T
M92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N`%1H
M`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T
M;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G
M<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`5&AE($E-4U`@
M;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E
M.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N
M<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&)O='1O;2!S:61E
M(&]N;'D`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N
M;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E
M(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C;VYT
M86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE9"!N;R!D
M871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI<R!M
M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@:61E;G1I='D@(B5S(B!H87,@
M8F5E;B!D96QE=&5D+@!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU
M;65R:6,N`%1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE
M($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E
M<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D
M960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E
M9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O
M;B!T:&4@<WES=&5M+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C:69I
M960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@9FEL
M92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E9"!D
M:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!U<&QO
M861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S=&5P+@!4
M:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H96UE<R!D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A
M8V4@<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T
M(&)E(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A
M(&-O;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L
M92`G(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E
M<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN
M(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H
M:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C
M86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T
M96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@
M8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@
M86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!F
M;W)M870`5&EM92!S96QE8W1I;VX`5&ET;&4`5&\`5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]M;W)R;W<`
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N`%1O<`!4<F%N<VQA=&EO;G,`5')U92!O<B!F86QS90!4=0!4=7)K97D`
M5'EP92!Y;W5R(&-H;VEC93H@`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C
M=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H
M96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O
M<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@
M9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5
M;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@
M=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N
M86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D
M:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E
M;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE
M('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E
M<R(N`%5N86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA
M8FQE('1O(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T
M:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N
M`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N
M(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92X`56YA8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@
M=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B
M;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@
M9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA
M=&EO;B!F;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ
M("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T
M;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93
M(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A
M;G-L871E('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=')I9V=E<B!F
M<F5E+V)U<WD@=7!D871E(&9O<B`E<P!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I
M;&5D*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD
M97)L:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ
M(`!5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YK;F]W
M;@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U
M<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5
M<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G
M<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I
M;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57-E($-U<G)E;G0Z("5S
M`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O
M<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D
M(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E
M<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES
M86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5
M<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M
M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!61E,@9&ER96-T
M;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@
M9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O
M;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S
M+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A<FEA8FQE`%9E<FEF
M:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T
M86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A
M;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`
M5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`
M5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5T%23@!705).24Y'(2$A(%)%34]6
M12!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5V%R;FEN9P!790!796%T:&5R
M($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!7965K;'D`5V5L
M8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE
M(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3
M('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME
M<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`
M5VED=&@@=6YI=`!7:61T:#H`5VEN9`!7:6YD('-P965D(&EN(&MN;W1S`%=I
M;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+@!996%R;'D`665S`%EE<RP@22!!9W)E90!9;W4@87)E
M(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H
M(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A
M=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC
M871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO
M=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL
M(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@
M:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@
M)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT
M97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H
M(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN
M9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO
M=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I
M9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@
M;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD
M('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W
M:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S
M97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE
M('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@
M861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N
M`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U
M(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P
M<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO
M;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL
M($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N
M`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO
M=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D
M9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN
M:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H
M92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E
M87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I
M;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T
M96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R
M(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E
M;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@
M8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M
M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@
M9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@
M9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N
M<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R
M(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U
M<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`
M6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O
M=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN
M92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]$96QE=&4@4F]W`%]'<F]U
M<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U
M=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO
M=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S
M`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM
M`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`
M8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A
M=&EO;B!E<G)O<@!D871A(&9O<FUA="!E<G)O<@!D:7-P;&%Y(&9O<F5C87-T
M("AT868I`&5D:70`96YT<GD@;F]T(&9O=6YD`&9R;VT@=&AE("5S("@E<RD@
M870@)7,@)7,`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN<'5T+V]U
M='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI
M<V]F<R!E<G)O<B!C;V1E("5D('=H:6QE(&UA:VEN9R!)4T\N`&YA;64`;F]T
M(&EM<&QE;65N=&5D`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C
M96YT`'!E<FUI<W-I;VX@9&5N:65D`')E;6]T92!E<G)O<B!I;B!P<F]T;V-O
M;`!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<W1E861Y
M`'-Y<W1E;2!E<G)O<@!T87-K(&QI<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP
M92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M
M960`=7-E<B!S96QE8W0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!H;W)D92`S+C$N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP-"TQ,R`Q
M-#HQ-BLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#0M,3,@,30Z,38K
M,#(P,`I,87-T+51R86YS;&%T;W(Z($UA<F-O(%!I<F]V86YO(#QM87)C;RYP
M:7)O=F%N;T!U;FEB;V-C;VYI+FET/@I,86YG=6%G92U496%M.B!I,3AN0&QI
M<W1S+FAO<F1E+F]R9PI-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"E!L=7)A;"U&;W)M<SH@;G!L=7)A;',],CL@
M<&QU<F%L/2AN("$](#$I.PH`("@E<R!G:6]R;FD@<V-O<G-I*0`@*$-H:6%V
M92!D:2!A8V-E<W-O("5S*0`@*&EN("5S(&=I;W)N:2D`("AO9V=I*0`@*&1O
M;6%N:2D`("AI97)I*0`@82!A`"(E<R(@;F]N(.@@=6YA(&1I<F5C=&]R>2X`
M(B5S(B!N;VX@Z"!U;F$@<V-E;'1A('9A;&ED82X`(B5S(B!N;VX@Z"!C;VYF
M:6=U<F%T;R!N96D@4F5G:7-T<FD@9&D@2&]R9&4N`"(E<R(@86QB97)O(')E
M;F1E<F5R(&YO;B!T<F]V871O+@`B)7,B(.@@<W1A=&\@86=G:75N=&\@86D@
M9W)U<'!I(&1I('-I<W1E;6$N`"(E<R(@Z"!S=&%T;R!A9V=I=6YT;R!A:2!P
M97)M97-S:2!D:2!S:7-T96UA+@`B)7,B(&YO;B#H('-T871O(&-R96%T;SH@
M)7,N`"4N,F9-0B!U<V%T:2!D:2`E+C)F34(@9&ES<&]N:6)I;&D@*"4N,F8E
M)2D`)60@)7,@92`E<P`E9"!G:6]R;FD@86QL;R!S8V%D97)E(&1E;&QA('1U
M82!P87-S=V]R9"X`)60M9VEO;F\@<')E=FES:6]N90`E<R`M($YO=&EZ:6$`
M)7,@1FER;6$@1&EG:71A;&4`)7,@2T(`)7,@3W!E<F%Z:6]N:2!D:2!-86YU
M=&5N>FEO;F4@+2!#;VYF97)M80`E<R!);7!O<W1A>FEO;F4`)7,@1FER;6$`
M)7,@5&5R;6EN:2!D:2!!8V-O<F1O`"5S(&=IX"!E<VES=&5N=&4N`"5S(&$@
M)7,@)7,`)7,@Z"!P<F]N=&\@<&5R(&5S96=U:7)E(&QE(&]P97)A>FEO;FD@
M9&D@;6%N=71E;GII;VYE('-O='1O('-E;&5Z:6]N871E+B!396QE>FEO;F$@
M;&$@8V%S96QL82!P97(@;V=N:2!O<&5R87II;VYE*&DI(&-H92!V=6]I(&5S
M96=U:7)E(&]R82X`)7,@Z"!R:6-H:65S=&\`)7,@;6EN=71I`"5S(&YO;B!T
M<F]V871O+@`E<R!A("5S(&1I("5S`%)U8G)I8V$@9&D@)7,`0V%L96YD87)I
M;R!D:2`E<P!.;W1E(&1I("5S`$QI<W1A($%T=&EV:73@(&1I("5S`"5S.B`E
M<P`E<SH@475E<W1O(&UE<W-A9V=I;R!P;W1R96)B92!N;VX@87)R:79E(&1A
M(&-H:2!D:6-H:6%R82!D:2!E<W-E<F4N($%T=&5N>FEO;F4@86D@;&EN:R!P
M<F5S96YT:2!I;B!E<W-O(&\@9F]R;FES8VD@;V=N:2!I;F9O<FUA>FEO;F4@
M86P@;6ET=&5N=&4N`"P@<V]F9FEA;F1O(``L('-O9F9I86YD;R`E<R`E<P`L
M('9A<FEA8FEL92!D82`E<R!A("5S`"TM('-E;&5Z:6]N82`M+0!&;W)M871O
M(#$R(&]R90!&;W)M871O(#(T(&]R90`R-"!O<F4`/%!R96-E9&5N=&4`56X@
M9&%T86)A<V4@9&D@8F%C:V5N9"#H(')I8VAI97-T;R!P97(@<75E<W1O(&)L
M;V-C;RX`12<@86-C861U=&\@=6X@97)R;W)E(&9A=&%L90!5;F$@8VAI879E
M('!U8F)L:6-A(%!'4"#H(')I8VAI97-T82!P97(@8VEF<F%R92!I;"!M97-S
M86=G:6\N`%5N82!C:&EA=F$@<'5B8FQI8V$@4$=0(.@@<FEC:&EE<W1A('!E
M<B!V97)I9FEC87)E(&EL(&UE<W-A9V=I;R!F:7)M871O+@!5;F$@8VAI879E
M('!U8F)L:6-A(%!'4"P@=6YA(&-H:6%V92!P<FEV871A(%!'4"P@92!U;F$@
M<&%S<W=O<F0@<V]N;R!R:6-H:65S=&4@<&5R(&1E8VEF<F%R92!U;B!M97-S
M86=G:6\`56YA(&-H:6%V92!P=6)B;&EC82!01U`L('5N82!C:&EA=F4@<')I
M=F%T82!01U`L(&4@=6YA('!A<W-W;W)D('-O;F\@<FEC:&EE<W1E('!E<B!F
M:7)M87)E('5N(&UE<W-A9V=I;P!5;F$@8VAI879E('!U8F)L:6-A(%,O34E-
M12P@=6YA(&-H:6%V92!P<FEV871A(%,O34E-12!E('5N82!P87-S=V]R9"!S
M;VYO(')I8VAI97-T92!P97(@9&5C:69R87)E('5N82!M97-S86=G:6\N`%5N
M82!C:&EA=F4@<'5B8FQI8V$@4R]-24U%+"!U;F$@8VAI879E('!R:79A=&$@
M4R]-24U%(&4@=6YA('!A<W-W;W)D('-O;F\@<FEC:&EE<W1E('!E<B!F:7)M
M87)E('5N(&UE<W-A9V=I;RX`56YA(&-H:6%V92!P=6)B;&EC82!3+TU)344@
MZ"!R:6-H:65S=&$@<&5R(&-I9G)A<F4@=6X@;65S<V%G9VEO+@!!32!.=6)I
M`$%-(%!I;V=G:6$@3&5G9V5R80!!32!0:6]G9VEA`$%-($%C<75A>GIO;FD`
M04T@3F5V:6-A=&4`04TO4$T`05!)($E$`%)I9W5A<F1O('%U97-T;R!E9&ET
M;W(`4FEG=6%R9&\N+BX`06-C97-S;R!N96=A=&\@8W)E86YD;R!L82!D:7)E
M8W1O<GD@5D93+@!!8V-E<W-O(&YE9V%T;R!C<F5A;F1O(%9&4R!F:6QE+@!)
M;F9O<FUA>FEO;FD@06-C;W5N=`!087-S;W=R9"!!8V-O=6YT`$%C8V]U;G0@
M8V]N9V5L871O+@!!8V-O=6YT:6YG`$%G9VEU;F=I`$%G9VEU;F=I($=R=7!P
M;R!&:6=L:6\`06=G:75N9VD@4&5R;65S<VD@1FEG;&EO`$%G9VEU;F=I('%U
M:3H`06=G:75N9VD@3G5O=F\@1W)U<'!O`$%G9VEU;F=I($YU;W9O(%!E<FUE
M<W-O`$%G9VEU;F=I('5N(&=R=7!P;R!F:6=L:6\@82`B)7,B`$%G9VEU;F=I
M('5N('!E<FUE<W-O(&9I9VQI;R!A("(E<R(`06=G:75N9VD@=6X@;G5O=F\@
M=71E;G1E.@!!9V=I=6YG:2!C;VQO;FYA`$%G9VEU;F=I(&YU;W9I(&UE;6)R
M:0!!9V=I=6YG:2!L82!C;W!P:6$`06=G:75N9VD@:6P@)7,@365N=2!C;VUE
M('5N82!-;WII;&QA(%-I9&5B87(`06=G:75N9VD@86QL82!R=6)R:6-A.@!!
M9VEU;F=I(&%L;&$@<G5B<FEC82!P97)S;VYA;&4`06=G:75N9VD@=71E;G1E
M`$%G9VEU;G1I("(E<R(@86P@<VES=&5M82P@;6$@;F]N('-I('!O<W-O;F\@
M86=G:75N9V5R92!U;'1E<FEO<FD@:6YF;W)M87II;VYI.B`E<RX`06=G:75N
M=&\@(B5S(B!A;"!S:7-T96UA+B!/<F$@<'5O:2!A8V-E9&5R92X`3"=A9V=I
M=6YT82!D:2!U=&5N=&D@Z"!D:7-A8FEL:71A=&$N`$EN9&ER:7IZ;P!2=6)R
M:6-A`$%M;6EN:7-T<F%T;W)E("T@:6UP;W-T82!I('!E<FUE<W-I('!E<B!A
M;'1R:2!U=&5N=&D`06UM:6YI<W1R87II;VYE`$%L;&EN96$`06QL:6YE86UE
M;G1O.@!4=71T:0!4=71T:2!G;&D@=71E;G1I(&%U=&5N=&EC871I`%1U='1I
M(&D@9W)U<'!I`%1U='1I(&D@<&5R;65S<VD`5'5T=&D@92!Q=6%T=')O(&D@
M;&%T:0!4=71T:2!G;&D@:6YD:7)I>GII(&UU;'1I<&QI`%!E<FUE='1E<F4@
M;&4@:6UP;W-T87II;VYI(&1I(&QI<W1E(&]R9&EN871E('!E<B!T:7!O/P!%
M<VES=&4@9VG@`$QO9VEN($E-4U`@86QT97)N871I=F$`4&%S<W=O<F0@24U3
M4"!A;'1E<FYA=&EV80!5=&5N=&4@24U04R!A;'1E<FYA=&EV;P!);F1I<FEZ
M>F\@96UA:6P@86QT97)N871I=F\`36%S8VAE<F4@86QT97)N871I=F4`5&5S
M=&\@86QT97)N871I=F\Z`$4G('-T871O('-P96-I9FEC871O('5N('9A;&]R
M92!N;VX@=F%L:61O+@!%<G)O<F4@<V-O;F]S8VEU=&\N`%)I<W!O<W1A`$%P
M<&QI8V%Z:6]N90!,:7-T82!!<'!L:6-A>FEO;FD`3"=A<'!L:6-A>FEO;F4@
MZ"!P<F]N=&$N`$%P<&QI8V$@86D@9FEG;&D@8V]N9&EV:7-I`$%P<')O=F$`
M1&EM96YS:6]N92!!<'!R;W-S:6UA=&EV80!!<')I;&4`1&EM96YS:6]N92!F
M:6QE(&EN(&%R8VAI=FEO`$YO;64@07)C:&EV:6\`4V5I('-I8W5R;R!D:2!V
M;VQE<B!R:6UU;W9E<F4@;&4@<FEC:&EE<W1E(&9I<FUA=&4@<&5R("5S(#\`
M07-E:2!S:6-U<F\@9&D@=F]L97(@96QI;6EN87)E("(E<R(@92!O9VYI('-O
M='1O+6=R=7!P;S\`4FEC:&EE9&5R92!L82!C;VYF97)M82!P<FEM82!D:2!E
M<V5G=6ER92!L92!O<&5R87II;VYI(&1I(&UA;G5T96YZ:6]N93\`07-S96=N
M86UE;G1O(&-O;&]N;F4`4VD@Z"!C97)C871O(&1I(&5L:6UI;F%R92!U;B!G
M<G5P<&\@;F]N(&5S:7-T96YT92X`4VD@Z"!C97)C871O(&1I(&5L:6UI;F%R
M92!U;B!P97)M97-S;R!N;VX@97-I<W1E;G1E+@!3:2#H(&-E<F-A=&\@9&D@
M<'5B8FQI8V%R92!U;B!P97)M97-S;R!N;VX@97-I<W1E;G1E+@!3:2#H(&-E
M<F-A=&\@9&D@<'5B8FQI8V%R92!U;F$@8V]N9&EV:7-I;VYE(&YO;B!E<VES
M=&5N=&4N`$%T=')I8G5T:0!!9V]S=&\`075T:%]C>7)S<6PZ(&5S=&5N<VEO
M;F4@:6UA<"!R:6-H:65S=&$@;F]N('1R;W9A=&$N`$%U=&A?8WER=7,Z(&EL
M(&)A8VME;F0@;F]N(&AA(&QE(&-A<&%C:73@(')I8VAI97-T92X`075T:%]C
M>7)U<SH@97-T96YS:6]N92!I;6%P(')I8VAI97-T82!N;VX@=')O=F%T82X`
M075T:%]F='`Z($5S=&5N<VEO;F4@1E10(')I8VAI97-T82!N;VX@=')O=F%T
M82X@0V]M<&EL82!02%`@8V]N(&PG;W!Z:6]N92`M+65N86)L92UF='`N`$%U
M=&A?:6UA<#H@($5S=&5N<VEO;F4@24U!4"!R:6-H:65S=&$@;F]N('1R;W9A
M=&$N`$%U=&A?:W)B-3H@17-T96YS:6]N92!K<F(U(')I8VAI97-T82!N;VX@
M=')O=F%T82X`075T:%]L9&%P.B!L)V%G9VEU;G1A(&1I('5T96YT:2!N;VX@
MZ"!S=7!P;W)T871A('!E<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@
M;&$@8V%N8V5L;&%Z:6]N92!D:2!U=&5N=&D@;F]N(.@@<W5P<&]R=&%T82!P
M97(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($5S=&5N<VEO;F4@3$1!
M4"!R:6-H:65S=&$@;F]N('1R;W9A=&$N`$%U=&A?;&1A<#H@26UP;W-S:6)I
M;&4@86=G:75N9V5R92!L)W5T96YT92`E<RX@475E<W1A(.@@;&$@<FES<&]S
M=&$@9&5L('-E<G9E<CH`075T:%]L9&%P.B!);7!O<W-I8FEL92!C86YC96QL
M87)E(&PG=71E;G1E("5S`$%U=&A?;&1A<#H@26UP;W-S:6)I;&4@86=G:6]R
M;F%R92!L)W5T96YT92`E<P!!=71H7VQD87`Z(&PG86=G:6]R;F%M96YT;R!D
M96=L:2!U=&5N=&D@;F]N(.@@<W5P<&]R=&%T;R!P97(@06-T:79E($1I<F5C
M=&]R>2X`075T:%]M8V%L.B!E<W1E;G-I;VYE($U#04P@<FEC:&EE<W1A(&YO
M;B!T<F]V871A+@!!=71H7W-M8F%U=&@Z(&5S=&5N<VEO;F4@<VUB875T:"!R
M:6-H:65S=&$@;F]N('1R;W9A=&$N`$PG875T96YT:6-A>FEO;F4@86P@<V5R
M=F5R($E-05`@Z"!F86QL:71A+@!!=71E;G1I8V%Z:6]N92!F86QL:71A`$%U
M=&5N=&EC87II;VYE(&9A;&QI=&$N("5S`$%U=&5N=&EC87II;VYE(')I9FEU
M=&%T82!D86P@<V5R=F5R(%)!1$E54RX`075T96YT:6-A>FEO;F4@86P@<V5R
M=F5R($944"!F86QL:71A+@!!=71E;G1I8V%Z:6]N92!A;"!S97)V97(@4TU"
M(&9A;&QI=&$N`$-A;7!I(&1I<W!O;FEB:6QI.@!39F]N9&\`0V]L;W)E('-F
M;VYD;P!087-S=V]R9"!K97)B97)O<R!N;VX@=F%L:61A+@!5=&5N=&4@:V5R
M8F5R;W,@;F]N('9A;&ED;RX`1&ER96-T;W)Y(&=R869I8V$@9&D@8F%S92`B
M)7,B(&YO;B!T<F]V871A+@!#;VUP;&5A;FYO`$)L;V-C;R`B)7,B(&1E;&PG
M87!P;&EC87II;VYE("(E<R(@;F]N('1R;W9A=&\N`$EM<&]S=&%Z:6]N:2!"
M;&]C8V\`5&EP;R!";&]C8V\`1W)A<W-E='1O`%-E9VYA;&EB<FD`0F]R9&\`
M4W!E<W-O<F4@9&5L(&)O<F1O.@!";W)D:0!";W-N:6$@92!(97)Z96=O=FEN
M80!%;G1R86UB90!"87-S;P!"<F%S:6QE`$5L96YC;R!P=6YT871O`$--4P!#
M4D,`4'5N=&D@1&ES=')I8G5Z:6]N92!#4DP`4')O<')I973@($-?96QL92XN
M+@!,82!C86-H92!I;FEZ:6%L92!N;VX@Z"!S=&%T82!C;VUP;&5T871A+@!#
M86QE;F1A<FEO`$-A;&UO`$-A;6)O9VEA`$EM<&]S<VEB:6QE(&-O<&EA<F4@
M9FEL92AS*2`M(&QA('-O<F=E;G1E(&4@;&$@9&5S=&EN87II;VYE('-O;F\@
M=6=U86QI+@!);7!O<W-I8FEL92!S<&]S=&%R92!I;"!F:6QE*',I("T@;&$@
M9&5S=&EN87II;VYE(.@@86QL)VEN=&5R;F\@9&5L;&$@<V]R9V5N=&4N`$EM
M<&]S<VEB:6QE(')E:6UP;W-T87)E(&QA('!A<W-W;W)D(&%U=&]M871I8V%M
M96YT92P@8V]N=&%T=&$@;"=A;6UI;FES=')A=&]R92X`26UP;W-S:6)I;&4@
M<V-I=F5R92!N96P@9FEL92`B)7,B`$EM<&]S<VEB:6QE(&=E<W1I<F4@<V5S
M<VEO;FD@97-T97)N92X`26UP;W-S:6)I;&4@8V]L;&5G87)S:2!A;"!S97)V
M97(@24U!4#H@)7,`26UP;W-S:6)I;&4@87!R:7)E(&EL(&9I;&4@(B5S(BX`
M0V%N8V5L;&$`0V%N8V5L;&$@:6P@4F5P;W)T('!R;V)L96UA`$EM<&]S<VEB
M:6QE(&5L:6UI;F%R92!I;"!F:6QE("(E<R(N`$EM<&]S<VEB:6QE('1R;W9A
M<F4@=6YA(&1I<F5C=&]R>2!T96UP;W)A;F5A+@!);7!O<W-I8FEL92!P<F]C
M961E<F4@<V5N>F$@:6P@<&%R86UE=')O("=T87)G971&:6QE)RX`26UP;W-S
M:6)I;&4@<FEM=6]V97)E(&QA(&1I<F5C=&]R>2`@(B5S(BX`26UP;W-S:6)I
M;&4@<FEM=6]V97)E+"!E<VES=&]N;R`E9"!F:6=L:2X`26UP;W-S:6)I;&4@
M<FEO<F1I;F%R92P@;"=E;&5N8V\@9F]R;FET;R!N;VX@8V]R<FES<&]N9&4@
M8V]N(&PG96QE;F-O(&UE;6]R:7IZ871O+@!);7!O<W-I8FEL92!I;G-T<F%D
M87)E(&EL(&UE<W-A9V=I;R!A;"!N=6UE<F\@<W!E8VEF:6-A=&\N`$-A<G)I
M97)A`$-A=&5G;W)I92!E($5T:6-H971T90!)<V]L92!#87EM86X`0V5L;'5L
M87)E`%!R;W!R:65TX"!#96QL90!2:65M<&EM96YT;R!C96QL93H`4')O<')I
M973@(&-E;&QE`%-P87II;R!C96QL93H`0V5L;'5L87)E`$-E;G1R;P!%=7)O
M<&$@0V5T<F%L92`H25-/+3@X-3DM,BD`1&5T=&%G;&D@9&5L($-E<G1I9FEC
M871O`%!R;W!R:65T87)I;R!D96P@0V5R=&EF:6-A=&\`4&]L:71I8VAE(&1E
M;"!#97)T:69I8V%T;P!#86UB:6$`0V%M8FEA(&QA('1U82!087-S=V]R9`!#
M86UB:6$@:6P@;F]M92!E(&PG:6YD:7)I>GIO(&-H92!L92!P97)S;VYE('9E
M9&]N;R!Q=6%N9&\@;&5G9V]N;R!E(')I<W!O;F1O;F\@86QL92!T=64@96UA
M:6PN`$EL(&-A;6)I;R!D96QL82!T=6$@<&%S<W=O<F0@;F]N(.@@<W5P<&]R
M=&%T;R!C;VX@;&$@8V]N9FEG=7)A>FEO;F4@8V]R<F5N=&4N("!#;VYT871T
M82!L)V%M;6EN:7-T<F%T;W)E+@!#87)B;VYE`$-H96-?:R!,:6YK+BXN`$-I
M;&4`0VEN80!38V5G;&D@;"=A<'!L:6-A>FEO;F4Z`%-C96=L:2!U;F$@<&%S
M<W=O<F0`4V-E9VQI('5N(&YO;64@=71E;G1E`%-C96=L:2!C;VUE('9I<W5A
M;&EZ>F%R92!L82!D871A.@!38V5G;&D@:6P@=&EP;R!D:2!S=&EL92!D96QL
M82!L:7-T82`H<&5R(&QI<W1E(&]R9&EN871E*0!,82!D969I;FEZ:6]N92!D
M:2!C;&%S<V4@9&D@)7,@;F]N(.@@<W1A=&$@=')O=F%T82X`0VAI87)O`$%N
M;G5L;&$@1&]M86YD80!%;&EM:6YA(&PG=71E;G1E.B`E<P!%;&EM:6YA('5T
M96YT90!%;&EM:6YA(&EN9F]R;6%Z:6]N:2!U=&5N=&4`16QI;6EN87)E($1O
M<&\@`$-L:6-K('!E<B!#;VYT:6YU87)E`$-H:75D:2!&:6YE<W1R80!.=6)I
M`$YU8FD@<')E<W1O`$YU=F]L;W-O`$-H:75D:2!3:61E8F%R`$-H:75D:2!I
M(&)O<F1I`$-O;&]R90!-87!P82!#;VQO<FD`4V5L97II;VYE(&-O;&]R:0!#
M;VQO;FYE.@!4:71O;&\@8V]L;VYN90!#;VUI8VAE`$-O;6%N9&\`3&EN96$@
M9&D@8V]M86YD;P!#;VUM96YT;P!.;VUE($-O;75N90!!>FEE;F1A`$-O;7!U
M=&5R<P!#;VYD:7II;VYE`$-O;F1I>FEO;FD`1&EF9F5R96YZ92!N96QL82!C
M;VYF:6=U<F%Z:6]N90!#;VYF:6=U<F%Z:6]N92!P97(@;&$@<VEN8W)O;FEZ
M>F%Z:6]N92!C;VX@4$1!<RP@4VUA<G1P:&]N97,@92!/=71L;V]K+@!,82!C
M;VYF:6=U<F%Z:6]N92#H('9E8V-H:6$N`$-O;F9I9W5R82`E<P!#;VYF97)M
M82!L82!087-S=V]R9`!#;VQL96=A;65N=&\@9F%L;&ET;RX`0V]L;&5G86UE
M;G1O(&9A;&QI=&\Z(`!#;VYN97-S:6]N92!A;"!K97ES97)V97(@;W5B8FQI
M8V\@<FEF:75T871A+@!#;VYN97-S:6]N92!A;"!K97ES97)V97(@<'5B8FQI
M8V\@<FEF:75T871A+B!-;W1I=F\Z("5S("@E<RD`0V]N;F5S<VEO;F4@86P@
M<V5R=F5R($944"!F86QL:71A+@!#;VYT871T:0!)(&-O;G1A='1I('-O;F\@
M<W1A=&D@86=G:75N=&D@8V]N('-U8V-E<W-O(&%L;&$@='5A(')U8G)I8V$N
M`%1I<&\@9&D@8V]N=&5N=71O(&1E;"!F:6QE(&-O;7!R97-S;SH@`$-O;G1E
M;G5T:2!D:2`B)7,B`$-O;G1I;G5A`$-O<&EA`$-O<&EA(&9A;&QI=&$Z("5S
M`$-O<&EA('-E;&5Z:6]N90!.;VX@<VD@<'7R(&-I9G)A<F4@:6X@4$=0(&EL
M(&UE<W-A9V=I;P!.;VX@<VD@<'7R(&9I<FUA<F4@:6X@4$=0(&EL(&UE<W-A
M9V=I;P!.;VX@<VD@<'7R(&-R:69R87)E(&EN(%,O34E-12!I;"!M97-S86=G
M:6\`3F]N('-I('!U\B!F:7)M87)E(&EN(%,O34E-12!I;"!M97-S86=G:6\`
M3F]N('-I('!U\B!A9V=I=6YG97)E(&EL(&-O;G1A='1O+B`E<P!.;VX@<VD@
M<'7R(&EN=&5R<F]G87)E(&EL('-E<G9E<B!,1$%0+@!.;VX@<VD@<'7R('9E
M<FEF:6-A<F4@;"=E<75I;&EB<FEO+B`E<P!);7!O<W-I8FEL92!C;VQL96=A
M<G-I(&%L('-E<G9E<B!,1$%0+@!);7!O<W-I8FEL92!C;VQL96=A<G-I(&%L
M('-E<G9E<B`B)7,B('5S86YD;R!&5%`Z("5S`$EM<&]S<VEB:6QE(&-R96%R
M92!U;F$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,`26UP;W-S:6)I;&4@
M9&5C:69R87)E(&EL(&1A=&\@:6X@9F]R;6%T;R!01U`Z(`!);7!O<W-I8FEL
M92!D96-I9G)A<F4@:6P@9&%T;R!I;B!F;W)M871O(%,O34E-12X`26UP;W-S
M:6)I;&4@96QI;6EN87)E(&EL(&-O;G1A='1O+B`E<P!);7!O<W-I8FEL92!E
M;&EM:6YA<F4@;&4@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X@)7,`26UP;W-I
M8FEL92!E;&EM:6YA<F4@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@9&5L
M;"=I;7!O<W1A>FEO;F4@(B5S(BX`26UP;W-S:6)I;&4@9&5T97)M:6YA<F4@
M9VQI(&EN9&ER:7IZ:2!E;6%I;"!D96D@9&5S=&EN871A<FDN`&E);7!O<W-I
M8FEL92!S8V%R:6-A<F4@:6X@;6]D;R!C;VUP;&5T;R!L82!R=6)R:6-A+@!)
M;7!O<W-I8FEL92!S8V%R:6-A<F4@:6X@;6]D;R!C;VUP;&5T;R!L82!L:7-T
M82!D:2!D:7-T<FEB=7II;VYE+@!);7!O<W-I8FEL92!S8V%R:6-A<F4@:6X@
M;6]D;R!C;VUP;&5T;R!L82!L:7-T82!D96QL92!L:7-T92!D:2!D:7-T<FEB
M=7II;VYE+@!);7!O<W-I8FEL92!C87)I8V%R92!L82!S=')A=&5G:6$@(B5S
M(BX`26UP;W-S:6)I;&4@8W)E87)E(&QA(&1I<F5C=&]R>2`B)7,B+@!);7!O
M<W-I8FEL92!O='1E;F5R92!L82!C:&EA=F4@<'5B8FQI8V$@9&%L('-E<G9E
M<BX`26UP;W-S:6)I;&4@87!R:7)E("(E<R(@<&5R(&QA(')I<V-R:71T=7)A
M+@!);7!O<W-I8FEL92!A<')I<F4@)7,N`$EM<&]S<VEB:6QE(&%P<FER92!I
M;"!M;V1U;&\@36%I;G1E;F%N8V5?5&%S:R`E<P!);7!O<W-I8FEL92!A<')I
M<F4@;&$@9&ER96-T;W)Y("(E<R(N`$EM<&]S<VEB:6QE(&-O;G1A='1A<F4@
M:6P@<V5R=F5R($Q$05`N`$EM<&]S<VEB:6QE(&QE9V=E<F4@)7,N`$EM<&]S
M<VEB:6QE(&%Z>F5R87)E(&QA('!A<W-W;W)D('!E<B!L)W5T96YT92!R:6-H
M:65S=&\N($%L8W5N:2!O('1U='1I(&D@9&5T=&%G;&D@;F]N('-O;F\@8V]R
M<F5T=&DN(%)I<')O=F$@86YC;W)A(&\@8V]N=&%T=&$@;"=A;6UI;FES=')A
M=&]R92!S92!N96-E<W-I=&D@9&D@=6QT97)I;W)E(&%I=71O+@!);7!O<W-I
M8FEL92!R96-U<&5R87)E($%#3`!);7!O<W-I8FEL92!R96-U<&5R87)E(&QA
M(')U8G)I8V$N("5S`$EM<&]S<VEB:6QE(')E8W5P97)A<F4@;&$@;&ES=&$@
M9&D@9&ES=')I8G5Z:6]N92X@)7,`26UP;W-S:6)I;&4@<F5C=7!E<F%R92!L
M92!L:7-T92!D:2!D:7-T<FEB=7II;VYE+B`E<P!);7!O<W-I8FEL92!R96-U
M<&5R87)E(&QE('!O<W-I8FEL:73@(&1E;"!S97)V97(`26UP;W-S:6)I;&4@
M:6YV97)T:7)E(&QA(&-O;F9I9W5R87II;VYE+@!);7!O<W-I8FEL92!C86YC
M96QL87)E(&QA(&1I<F5C=&]R>2`B)7,B+@!);7!O<W-I8FEL92!S86QV87)E
M(&QA(&-O;F9I9W5R87II;VYE(&1I("5S+@!);7!O<W-I8FEL92!S86QV87)E
M('5N82!C;W!I82!D96QL82!C;VYF:6=U<F%Z:6]N92X`26UP;W-S:6)I;&4@
M<V%L=F%R92!U;F$@8V]P:6$@9&5L;&$@8V]N9FEG=7)A>FEO;F4Z("5S`$EM
M<&]S<VEB:6QE('-A;'9A<F4@;&\@<V-R:7!T(&1I(&%G9VEO<FYA;65N=&\@
M9&5L;&4@:6UP;W-T87II;VYI('-U.B`B)7,B+@!);7!O<W-I8FEL92!S86QV
M87)E(&EL(&9I;&4@9&D@<V%L=F%T86=G:6\@9&5L;&$@8V]N9FEG=7)A>FEO
M;F4@9&D@)7,N`$EM<&]S<VEB:6QE('-A;'9A<F4@:6P@9FEL92!D:2!C;VYF
M:6=U<F%Z:6]N92!D:2`E<RX@4'5O:2!U<V%R92!N82!D96QL92!O<'II;VYI
M('!E<B!S86QV87)E(&EL(&-O9&EC92!S=2`E<R!O(&-O<&EA<F4@;6%N=6%L
M;65N=&4@:6P@8V]D:6-E('-O='1O('-U("5S+@!);7!O<W-I8FEL92!F87)E
M('5N82!R=6-E<F-A(&YE;"!S97)V97(@3$1!4"X`26UP;W-S:6)I;&4@86=G
M:6]R;F%R92!I;"!C;VYT871T;RX@)7,`26UP;W-S:6)I;&4@86=G:6]R;F%R
M92!L82!L:7-T82!D:2!D:7-T<FEB=7II;VYE+B`E<P!);7!O<W-I8FEL92!S
M8W)I=F5R92!L82!C;VYF:6=U<F%Z:6]N92!P97(@(B5S(CH@)7,`26UP;W-S
M:6)I;&4@=')O=F%R92!L82!3:61E8F%R(&1I($UO>FEL;&$N($%S<VEC=7)A
M=&D@8VAE('-I82!A<&5R=&$N`$EM<&]S<VEB:6QE(&1A<F4@86QL)W5T96YT
M92`B)7,B(&D@<V5G=65N=&D@9&ER:71T:2!P97(@;&$@8V%R=&5L;&$@(B5S
M(CH@)7,`5&5S=&\@8V]N=&%T;P!.87II;VYE`$-O<G-I`$-R96$`0W)E82!U
M;B!L:6YK`$-R96$@=6YO(&YU;W9O`$-R96%R92!S;W1T;R!C87)T96QL90!#
M<F5A=&]R92!D:2!P97)M97-S:0!.=6UE<F\@8V%R=&$@9&D@8W)E9&ET;P!#
M;W)R96YT92`T($9A<VD`4V5S<VEO;FD@8V]R<F5N=&D`5&5M<&\@071T=6%L
M90!,82!54DP@871T=6%L92#H`%5T96YT:2!!='1U86QI`%1E;7!O($%T='5A
M;&4`0V]N9&EZ:6]N92!C;W)R96YT93H@`%-T:6QE(&-O<G)E;G1E`%!E<G-O
M;F%L:7IZ82!L92!O<&5R87II;VYI(&1A(&5S96=U:7)E(&%L;"=A=G9I;R!D
M:2`E<P!486=L:6$`5&%G;&EA(&QA('-E;&5Z:6]N90!#:7!R;P!':6]R;F%L
M;65N=&4`1&%T80!$871A(%)I8V5V=71A`%-E;&5Z:6]N82!L82!D871A`$=I
M;W)N;P!%7VQI;6EN82!#;VQO;FYA`$1I8V5M8G)E`$YU;65R:2!D96-I;6%L
M:0!$:6UI;G5I<V-I(&QA(')I96YT<F%N>F$`0V]L;W)E('-T86YD87)D`$ED
M96YT:73@(&1I(&1E9F%U;'0`4VAE;&P@9&D@9&5F875L=`!$969I;FEZ:6]N
M:0!%;&EM:6YA`$5L:6UI;F$@0V5L;&$`16QI;6EN82!'<G5P<&\`16QI;6EN
M82!,;V<`16QI;6EN82!097)M97-S;P!%;&EM:6YA<F4@92!S=G5O=&%R92!I
M(&UE<V%G9VD`16QI;6EN82!C96QL80!%;&EM:6YA(&-O;&]N;F$`16QI;6EN
M82!L82!M87-C:&5R82!A;'1E<FYA=&EV82!E<VES=&5N=&4`16QI;6EN82!I
M(&UE<W-A9V=I`$5L:6UI;F$@:2!P97)M97-S:2!P97(@(B5S(@!%;&EM:6YA
M(&D@<&5R;65S<VD@<&5R("(E<R(@92!O9VYI('-O='1O+7!E<FUE<W-O/P!%
M;&EM:6YA(')I9V$`16QI;6EN82!L)VED96YT:73@('-E;&5Z:6]N871A`$5L
M:6UI;F$@;&4@<V]T=&\@8V%R=&5L;&4`16QI;6EN82!L82!C;VQO;FYA(&-O
M<G)E;G1E`$5L:6UI;F$@;&$@<FEG82!C;W)R96YT90!%;&EM:6YA(&QO('-C
M<FEP="!D:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N:2!D:2`B
M)7,B+@!496UP;R!D)VEN=FEO`$1A;FEM87)C80!$97-C<FEV:2!I;"!P<F]B
M;&5M80!$97-C<FEZ:6]N90!$971T86=L:2`H86YC:&4@;F5L(&9I;&4@9&D@
M;&]G(&1I($AO<F1E*3H`22!D971T86=L:2!S;VYO('-T871I('-C<FET=&D@
M;F5L(&9I;&4@9&D@;&]G('!E<B!L)V%M;6EN:7-T<F%T;W)E+@!3=FEL=7!P
M;P!0=6YT;R!D:2!R=6=I861A`%!U;G1O(&1I(')U9VEA9&$@<&5R(&PG=6QT
M:6UA(&]R83H@`%!U;G1O(&1I(')U9VEA9&$Z(`!$:7)E>FEO;F4@9&$@<VEN
M:7-T<F$@82!D97-T<F$`1&ER97II;VYE(&1A(&1E<W1R82!A('-I;FES=')A
M`%9I<W5A;&EZ>F$@:6P@=&5M<&\@;F5L(&9O<FUA=&\@,C0@;W)E/P!/<'II
M;VYI(&1I('9I<W5A;&EZ>F%Z:6]N90!6:7-U86QI>GIA('!R979I<VEO;F4@
M9&5T=&%G;&EA=&$`1F]R;6%T;R!D:2!V:7-U86QI>GIA>FEO;F4`3F]T:69I
M8V$@9&D@9&ES<&]S:7II;VYE`$YO;B!E;&EM:6YA<F4`3F]N(&%C8V5D97)E
M(&1I<F5T=&%M96YT92!M86EN=&5N86YC92YP:'``3&%P<FEM82!R:6=A(&-O
M;G1I96YE(&EL(&-A;7!O(&1E:2!N;VUI/R!392!S:2P@<V5L97II;VYA('%U
M97-T82!C87-E;&QA.@!.;VX@:&%I('5N)W5T96YZ83\@:7-C<FEV:71I+@!3
M8V%R:6-A`%-C87)I8V$@)7,`3&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A=&$@
MZ"!S=&%T82!S8V%R:6-A=&$@8V]M92!S8W)I<'0@4$A0+@!$<F]G:&4`4'5B
M8FQI8V$`5FES=6%L:7IZ82!B;&]C8V\`5FES=6%L:7IZ82!'<G5P<&\`5FES
M=6%L:7IZ82!097)M97-S;P!6:7-U86QI>GIA(%!E<FUE<W-I`%9I<W5A;&EZ
M>F$@4&5R;65S<VD@<&5R("5S`%9I<W5A;&EZ>F$@;&4@;W!Z:6]N:2!P97(Z
M`%9I<W5A;&EZ>F$@:2!P97)M97-I('!E<B`B)7,B`%9I<W5A;&EZ>F$@:2!P
M97)M97-S:2!P97(@)7,`16=I='1O`$5L96UE;G1O+BXN`$EN9&ER:7IZ;R!%
M;6%I;`!,)VEN9&ER:7IZ;R!%;6%I;"!D979E(&-O<G)I<W!O;F1E<F4N`$5M
M86EL(&-O;B!C;VYF97)M80!-97-S86=G:6\@=G5O=&\N`%)I<W5L=&%T;R!V
M=6]T;RX`4FEC97)C82!D96D@=&5R;6EN:2!V=6]T80!!8FEL:71A(&PG:6YS
M97)I;65N=&\@9&D@:6UM86=I;FD@;F5L('1E<W1O(&1A;&QA($=A;&QE<FEA
M(&1E;&QE($9O=&]G<F%F:64_`$%B:6QI=&%R92!I;"!M96YU(&1I(&-O;G1E
M<W1O(&-L:6-C86YD;R!I;"!T87-T;R!D97-T<F\@9&5L(&UO=7-E/P!&:6YE
M(&%N;F\`26YG<F%D:7-C:2!L)V5D:71O<@!);G-E<FES8VD@=6YA(&1O;6%N
M9&$@<VEC=7)A(&-H92!T:2!V97)RX"!C:&EE<W1A('-E(&%V<F%I(&YE8V5S
M<VETX"!D:2!A>GIE<F%R92!L82!T=6$@<&%S<W=O<F0L(&5S("=Q=6%L)^@@
M:6P@;F]M92!D96P@='5O(&-U8V-I;VQO/R<Z`$EN<V5R:7-C:2!L)U523"!D
M96QL)VEM;6%G:6YE('%U:0!);G-E<FES8VD@;&4@;&5T=&5R92!S;W1T;R!R
M:7!O<G1A=&4Z`$5R<F]R90!%<G)O<F4@8W)E86YD;R!I;"!B;&]C8V\Z("5S
M`$5R<F]R92!E;&EM:6YA;F1O(&PG86YC;W)A(&1I('-I;F-R;VYI83H@)7,`
M17)R;W)E(&5L:6UI;F%N9&\@:6P@;&]G(&1I('-I;F-R;VYI83H@)7,`17)R
M;W)E(&]T=&5N96YD;R!I;"!C;VYT96YU=&\Z("5S`$5R<F]R92!A9V=I;W)N
M86YD;R!L82!P87-S=V]R9#H@)7,`17)R;W)E(&-O;B!I;"!M97-S86=G:6\@
M96UA:6PN`$5R<F]R92!S8W)I=F5N9&\@(B5S(BX`3V=N:2`Q-2!M:6YU=&D`
M3V=N:2`R(&UI;G5T:0!/9VYI(#,P('-E8V]N9&D`3V=N:2`U(&UI;G5T:0!!
M9"!O9VYI(&%C8V5S<V\`3V=N:2!M97IZ)V]R80!/9VYI(&UI;G5T;P!686QO
M<FD@9"=E<V5M<&EO.@!%<V5G=6D`17-P86YD:0!%<W!A;F1I(%-I9&5B87(`
M4')E=FES=&\@)RDG`&E087)O;&$@<')E=FES=&$@;R!T97)M:6YE(&-I=&%T
M;R!D:2!R:6-E<F-A`$1A=&$@9&D@<V-A9&5N>F$`17-P;VYE;G1E`$-O;&]R
M92!&1P!!9V=I;W)N86UE;G1O($944"!D96QL92!I;7!O<W1A>FEO;FD`5&5N
M=&%T:79O(&9A;&QI=&\@;F5L(')E8W5P97)O(&1E;&QE('!R969E<F5N>F4N
M`$-O;&QE9V%M96YT;R!A;"!S97)V97(@3$1!4"!F86QL:71O+@!#;VQL96=A
M;65N=&\@86P@<V5R=F5R(%--0B!F86QL:71O+@!.;VX@Z"!R:75S8VET;R!A
M(&-O<&EA<F4@9&$@(B5S(BX`3F]N(.@@<FEU<V-I=&\@82!C;W!I87)E(&$@
M(B5S(BX`3F]N(.@@<FEU<V-I=&\@82!C<F5A<F4@=6YA(&YU;W9A(&-O;FYE
M<W-I;VYE(%-!4TPN`$YO;B#H(')I=7-C:71O(&$@<W!O<W1A<F4@82`B)7,B
M+@!.;VX@Z"!R:75S8VET;R!A(')E8W5P97)A<F4Z("5S`$=I=7-T;P!%<G)O
M<F4@1F%T86QE.@!&96)B<F%I;P!3:6UI;&4@80!3:6UI;&4@83H`0V]N=&5G
M9VEO(&9I;&4Z("5S(&9I;&4`0V]N=&5G9VEO(&9I;&4Z("5S(&9I;&5S`$=E
M<W1I;VYE($9I;&4`3F]M92!&:6QE`%-E;&5Z:6]N92!F:6QE`$-A<FEC82!&
M:6QE`$-A<FEC86UE;G1O(&9I;&4@;F]N('-U<'!O<G1A=&\`1FEL=')I`$9I
M;FQA;F1I80!0<FEM;R!-97IZ;P!0<FEM;R!1=6%R=&\`4F%P<&]R=&\@9FES
M<V\`3F5B8FEA`$QA($-A<G1E;&QA("5S(&YO;B!E<VES=&4`0V]L;W)E(&1E
M;&QA(&9O;G1E`$-I8F\`4&5R(&)R;W=S97(@8VAE(&YO;B!S=7!P;W)T86YO
M(&QE(&EM;6%G:6YI`%!R979I<VEO;F4@*%1!1BD`2&%I(&1I;65N=&EC871O
M(&QA('!A<W-W;W)D/P!);F]L=')I`%9E`$9R86YC:6$`1&$`1&$@:6P@`$1E
M<V-R:7II;VYE($-O;7!L971A`$QN82!0:65N80!.;VUE($-O;7!L971O`$=A
M;&QE<FEA(&1A;&QA('%U86QE('!R96YD97)E(&QE(&EM;6%G:6YI`$=A;&QE
M<FEA.@!'96YE<F$@)7,@0V]N9FEG=7)A>FEO;F4`0V]D:6-E($=E;F5R871O
M`$=E<FUA;FEA`$=I8FEL=&5R<F$`3F]M92!$871O`$]P>FEO;FD@1VQO8F%L
M:0!686D`36%P<&4@1V]O9VQE`%-C86QE(&1I(&=R:6=I`$=R96-I80!!;6UI
M;FES=')A>FEO;F4@1W)U<'!I`$D@;F]M:2!D96P@9W)U<'!O(&YO;B!D979O
M;F\@97-S97)R92!V=6]T:0!'<F]U<%]L9&%P.B!);7!O<W-I8FEL92!A9V=I
M=6YG97)E(&EL(&=R=7!P;R`E<RX@475E<W1A(.@@;&$@<FES<&]S=&$@9&5L
M('-E<G9E<CH@`$=R;W5P7VQD87`Z($EM<&]S<VED:6QE(&5L:6UI;F%R92!I
M;"!G<G5P<&\@)7,`1W)O=7!?;&1A<#H@26UP;W-S:6)I;&4@86=G:6]R;F%R
M92!I;"!G<G5P<&\@)7,`1W)U<'!I`%!E<FUE<W-I(&1E9VQI(&]S<&ET:0!,
M:6)R;R!D96=L:2!O<W!I=&D`26YT97-T87II;VYE`$EN=&5S=&%Z:6]N:0!!
M;'1E>GIA`$%I=71O`$%I=71O('5S86YD;R!L)V5D:71O<@!!:75T86YT90!%
M;6ES9F5R;P!1=65S=&\@Z"!L)VEN:7II;R!D96P@9FEL93H`06QT;P!(;U]R
M9&4`4V%N=&$@4V5D92`H0VET=&$G(&1E;"!6871I8V%N;RD`2&]R9&4`26YD
M:7)I>GIO(&1I(&-A<V$`1&ER96-T;W)Y(&1I(&-A<V$`5&5L969O;F\@9&D@
M8V%S80!296=O;&$@;W)I>GIO;G1A;&4`4FEE;7!I;65N=&\@;W)I>GIO;G1A
M;&4`3W)I>GIO;G1A;&4Z`$-O;64@<V5I(&%R<FEV871O('%U:3\@*%-E:2!P
M<F5G871O(&1I(&9A<F4@=6X@<F%P<&]R=&\A*0!1=6%N=&4@8V]L;VYN92!V
M=6]I('5N:7)E/P!1=6%N=&D@8V%M<&D@*&-O;&]N;F4I(&-I('-O;F\@/P!1
M=6%N=&4@<FEG:&4@=G5O:2!U;FER93\`56UI9&ETX`!5;6ED:73@.B``56YG
M:&5R:6$`0W)E87II;VYE(&1E;&QA(&-A<V5L;&$@24U!4"!F86QL:71A.B`E
M<P!#86YC96QL87II;VYE(&1E;&QA(&-A<V5L;&$@24U!4"!F86QL:71A.B`E
M<P!#<F5A>FEO;F4@9&5L;&$@<75O=&$@9&5L;&$@8V%S96QL82!)34%0(&9A
M;&QI=&$Z("5S`$EN9&ER:7IZ;R!)4`!);F1I<FEZ>F\@25`@;F]N(&1I<W!O
M;FEB:6QE+@!,)VEN9&ER:7IZ;R!)4"!N;VX@Z"!A;&PG:6YT97)N;R!D96P@
M8FQO8V-O($-)1%(@8V]N<V5N=&ET;RX`25]N<V5R:7-C:2!L82!226=A('!R
M:6UA`$ES;&%N9&$`4V]L;R!)8V]N90!)8V]N92!P97(@)7,`26-O;F4@8V]N
M('1E<W1O`$YO;64@9&5L;"=)9&5N=&ETX`!392!N;VX@Z"!S=&%T;R!V:7-U
M86QI>GIA=&\@8V]R<F5T=&%M96YT92P@)7,@87!R:7)E(&EN('5N82!N=6]V
M82!F:6YE<W1R82X`4V4@;F]N('9E9&D@;F5S<W5N82!I8V]N82!U<V%N9&\@
M26YT97)N970@17AP;&]R97(L('!O=')E<W1I(&1O=F5R('-E;&5Z:6]N87)E
M('%U97-T82!C87-E;&QA('!E<B!A;FYU;&QA<F4@;&$@=')A<W!A<F5N>F$@
M9&5L;&4@:6UM86=I;FD@4$Y'+@!392!V961I('%U97-T;R!M97-S86=G:6\@
M;6$@;F]N(&PG:6UM86=I;F4L(&PG:6UA9VEN92!C:&4@=G5O:2!C87)I8V%R
M92!N;VX@<'7R(&5S<V5R92!V:7-U86QI>GIA=&$@9&%L('1U;R!B<F]W<V5R
M+@!0<F4M5FES=6%L:7IZ87II;VYE(&1E;&PG26UM86=I;F4Z`%523"!);6UA
M9VEN90!54DP@26UM86=I;F4Z`$EM;6%G:6YE(&1A;&QA(&=A;&QE<FEA`$EM
M;6%G:6YE(&1A;&QA(&=A;&QE<FEA.@!#87)I8V%M96YT;R!);6UA9VEN90!)
M;6UA9VEN:0!);7!O<G1A+"!087-S;R`E9`!#86UP:2!I;7!O<G1A=&DZ("5S
M`$-A;7!I(&EM<&]R=&%T:3H`26Y?<V5R:7-C:2!R:6=A(&1O<&\`0V]D:6-E
M(&1I(&%Z:6]N92!E<G)A=&\@9&%T;RX`3F]M92!U=&5N=&4@92]O('!A<W-W
M;W)D(&YO;B!C;W)R971T;RX`3F]M92!U=&5N=&4@;R!I;F1I<FEZ>F\@86QT
M97)N871I=F\@;F]N('9A;&ED;RX@4FEP<F]V82!A;F-O<F$@;R!C;VYT871T
M82!L)V%M;6EN:7-T<F%T;W)E('-E(&YE8V5S<VET:2!D:2!U;'1E<FEO<F4@
M86EU=&\N`$%U;65N=&$@;&$@<FEE;G1R86YZ80!5=&5N=&D@26YD:79I9'5A
M;&D`26YF;W)M87II;VYE`$EN9F]R;6%Z:6]N92!N;VX@<&GY(&1I<W!O;FEB
M:6QE+@!);G-E<FES8VD@0U]O;&]N;F$@1&]P;P!);G-E<FES8VD@26UM86=I
M;F4`26YS97)I<V-I(%1A8F5L;&$`26YS97)I<V-I(&QI;FL@=V5B`$EN<V5R
M:7-C:2!?0V]L;VYN82!0<FEM80!);G-E<FES8VD@=6YA(&YU;W9A(&-O;&]N
M;F$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I('5N82!N=6]V82!C
M;VQO;FYA('!R:6UA(&1I('%U96QL82!C;W)R96YT90!);G-E<FES8VD@=6YA
M(&YU;W9A(')I9V$@9&]P;R!Q=65L;&$@8V]R<F5N=&4`26YS97)I<V-I('5N
M82!N=6]V82!R:6=A('!R:6UA(&1I('%U96QL82!C;W)R96YT90!);G-E<FES
M8VD@=6X@<&%R86=R869O(&1O<&\@:6P@;F]D;R!C;W)R96YT90!);G-E<FES
M8VD@=6X@<&%R86=R869O('!R:6UA(&1E;"!N;V1O(&-O<G)E;G1E`$EN<V5R
M:7-C:2!U;F$@;6%S8VAE<F$@86QT97)N871I=F$`26YS97)I<V-I('5N(&EN
M9&ER:7IZ;R!E;6%I;"!A;"!Q=6%L92!P;W1R86D@<FEC979E<F4@;&$@;G5O
M=F$@<&%S<W=O<F0Z`$EN<V5R:7-C:2!U;F$@8V5L;&$@9&]P;P!);G-E<FES
M8VD@=6YA(&-E;&QA('!R:6UA`$EN<V5R:7-C:2!U;F$@8V]L;VYN82!D;W!O
M`$EN<V5R:7-C:2!U;F$@8V]L;VYN82!P<FEM80!);G-E<FER92!M97-S86=G
M:0!);G-E<FES8VD@=6X@<&%R86=R869O(&1O<&\`26YS97)I<V-I('5N('!A
M<F%G<F%F;R!P<FEM80!);G-E<FES8VD@=6YA(')I9V$@9&]P;P!);G-E<FES
M8VD@=6YA(')I9V$@<')I;6$`26YS97)I<V-I(&QA(')I<W!O<W1A(')I8VAI
M97-T82!A;&QA(&1O;6%N9&$@9&D@<VEC=7)E>GIA.@!);G-E<FES8VDO34]D
M:69I8V$@;"=I;6UA9VEN90!);G-E<FES8VDO34]D:69I8V$@:6P@;&EN:P!#
M<F5D:71I(&EN<W5F9FEC:65N=&D@<&5R('-P961I<F4@86QL82!L:7-T82!D
M:2!D:7-T<FEB=7II;VYE+@!#<F5D:71I(&EN<W5F9FEC:65N=&DN`$EN=&5R
M;P!,:7-T82!I;G1E<F$`541((&YO;B!V86QI9&$@*%5S97(@1&%T82!(96%D
M97(I+@!$871A(%I)4"!N;VX@=F%L:61A`$%P<&QI8V%Z:6]N92!N;VX@=F%L
M:61A+@!"871C:"!)1"!N;VX@=F%L:61O`&E,)VEN9F]R;6%Z:6]N92!S;W1T
M;VUE<W-A(&YO;B#H('9A;&ED82X`3"=I;F1I<FEZ>F\@9&D@9&1E<W1I;F%Z
M:6]N92!N;VX@Z"!V86QI9&\N`$EL(&9O<FUA=&\@9&5L(&9I;&4@;F]N(.@@
M=F%L:61O`$QA(&-H:6%V92!D96QL82!L:6-E;GIA(&YO;B#H('9A;&ED82X`
M26P@;&]G;R!F;W)N:71O(&YO;B#H('9A;&ED;RX`;7-G7W1Y<&4@;F]N('9A
M;&ED;RX`87!I7VED(&YO;B!V86QI9&\@;R!M86YC86YT92X`4&%R86UE=')O
M(&YO;B!V86QI9&\@;R!M86YC86YT92X`4&5R;65S<V\@9&5L(&=E;FET;W)E
M(&YO;B!V86QI9&\N`&ED(&1E;"!P87)T;F5R(&YO;B!V86QI9&\N`$-O9&EC
M92!P<F]D;W1T;R!N;VX@=F%L:61O+@!0<F]T;V-O;&QO(&YO;B!V86QI9&\N
M`$1E<W1I;F%T87)I;R!N;VX@=F%L:61O.B`B)7,B`$]G9V5T=&\@8V]N9&EV
M:7-O(&YO;B!V86QI9&\`26YD:7)I>GIO('-O<F=E;G1E(&YO;B!V86QI9&\N
M`$EN=F5N=&%R:6\`26YV97)T:2!L82!S96QE>FEO;F4`16UI='1E;G1E`$ET
M86QI80!'96YN86EO`$=I87!P;VYE`$QU9VQI;P!':75G;F\`1VEU<W1I9FEC
M80!':75S=&EF:6-A(&%L(&-E;G1R;P!':75S=&EF:6-A('1U='1O`$=I=7-T
M:69I8V$@82!S:6YI<W1R80!':75S=&EF:6-A(&$@9&5S=')A`$UA;G1E;F5R
M92!L)V]R:6=I;F%L93\`26P@<V5R=F5R($ME<F)E<F]S(&AA(')I9FEU=&%T
M;R!L)V%U=&5N=&EC87II;VYE+@!#<F5A>FEO;F4@8VAI879E`$EM<')O;G1A
M(&1I9VET86QE(&1E;&QA(&-H:6%V90!,=6YG:&5Z>F$@9&5L;&$@8VAI879E
M`%1I<&\@9&5L;&$@8VAI879E`%5S;R!D96QL82!C:&EA=F4`3&$@8VAI879E
M(.@@9VG@('!R97-E;G1E('-U;"!K97ES97)V97(@<'5B8FQI8V\N`$)A;6EB
M:6YI`$1I7W-P;W-I>FEO;F4`3&EN9W5A9V=I;P!5;'1I;6\@;65Z>F\`56QT
M:6UA('!O<W-I8FEL:73@('!E<B!I;"!C86UB:6\@9&5L;&$@<&%S<W=O<F0`
M56QT:6UO('%U87)T;P!5;'1I;6\@86=G:6]R;F%M96YT;SH`56QT:6UA(&-O
M;FYE<W-I;VYE.B`E<P!5;'1I;6$@8V]N;FYE<W-I;VYE.B`E<R!D82`E<P!5
M;'1I;6$@8V]N;F5S<VEO;F4Z($UA:0!,96=G90!$:7-P;W-I>FEO;F4`3&%S
M8VEA;&\@=G5O=&\@<&5R(&%V97)L;R!S96YZ82!B;W)D:0!,:6)A;F\`4VEN
M:7-T<F$`26YT97-T87II;VYE(&1I('-I;FES=')A`%9A;&]R:2!D:2!S:6YI
M<W1R80!,:79E;&QO`%!I;V=G:6$@;&5G9V5R80!#;VQL96=A;65N=&\`26P@
M8V]L;&5G86UE;G1O('!U;G1A(&$Z`$-O;&QE9V$@;"=I;F1I<FEZ>F\@96UA
M:6P@86QL82!P86=I;F$@9&D@8V]M<&]S:7II;VYE('%U86YD;R!V:65N92!V
M:7-U86QI>GIA=&\`0V]L;&5G86UE;G1I`$5L96YC;R`M(&PG=71E;G1E('!U
M\B!V961E<F4@;&4@8V%R=&5L;&4`16QE;F-O(&1E:2!D871A8F%S90!%;&5N
M8V\@9&5I('-O9V=E='1I(&1E;&PG86EU=&\`16QE;F-O(%1A8F5L;&4`07)C
M:&EV:6\@9&5L;&$@3&ES=&$`06EU=&\@9&5L;&$@3&ES=&$`261E;G1I9FEC
M871I=F\@9&5L;&$@3&ES=&$`4')O<')I971A<FEO(&1E;&QA(&QI<W1A`$ES
M8W)I>FEO;F4@86QL82!,:7-T80!!;FYU;&QA(&PG:7-C<FEZ:6]N92!A;&QA
M($QI<W1A`$PG96QE;F-O(&1E;&QE('-E<W-I;VYE(.@@9F%L;&ET;SH@)7,`
M3"=E;&5N8V\@9&5G;&D@=71E;G1I(.@@9F%L;&ET;SH@)7,`3"=E;&5N8V\@
M9&5G;&D@=71E;G1I(.@@9&ES86)I;&ET871O+@!,971T97)A='5R80!#87)I
M8V%M96YT;RXN+@!/<F$@;&]C86QE.B``3&EN9W5A(&4@3W)A`$QU;V=O`$5N
M=')A`$5S8VD`16YT<F$`3W!E<F%Z:6]N:2!D:2!!8V-E<W-O`$PG86-C97-S
M;R#H(&9A;&QI=&\@<&5R8VCH(&EL(&YO;64@=71E;G1E(&\@;&$@<&%S<W=O
M<F0@:6YS97)I=&D@;F]N('-O;F\@8V]R<F5T=&DN`$%C8V5S<V\@9F%L;&ET
M;RX`5&5S=&\@;'5N9V\`06UO<F4`0F%S<V\`3&5T=&5R92!G<F5C:&4@;6EN
M=7-C;VQE`$QE='1E<F4@;&%T:6YE(&UI;G5S8V]L90!.=6UE<FD@<F]M86YI
M(&UI;G5S8V]L:0!,=7-S96UB=7)G;P!-4RU43D5&(&PG86QL96=A=&\@;F]N
M(&-O;G1I96YE(&EN9F]R;6%Z:6]N:2X`36%G:6-O`%!O<W1A`$EN9&ER:7IZ
M;R!A;6UI;FES=')A=&]R90!#<F5A(&-O;&QE9V%M96Y?=&\N+BX`1V5S=&ES
M8VD@;"=E;&5N8V\@9&5L;&4@8V%T96=O<FEE(&5T:6-H971T86YD;R!G;&D@
M87)T:6-O;&DL(&4@8V]N(&D@8V]L;W)I(&%S<V]C:6%T:2!A;&QE(&-A=&5G
M;W)I92X`36%R>F\`36%R9VEN90!#;VYT<F%S<V5G;F%R92!C;VX@:2!F;&%G
M<R!6:7-T;R].;VY6:7-T;P!#;VYT<F%S<V5G;F%R92!C;VX@86QT<FD@9FQA
M9W,@*&5S.B!);7!O<G1A;G1E+U)I<W!O<W1O*0!#86UP:2!C;W)R:7-P;VYD
M96YT:0!#<F5D:71O(&UA<W-I;6\@<&5R;65S<V\N`$5C8V5D=71E(&QA('!A
M<G1I(&UA<W-I;64@9&5L(&UE<W-A9V=I;RX`5&5M<&\@;6%S<VEM;R!U;'1I
M;64@,C0@;W)E.B``5&5M<&\@;6%S<VEM;R!U;'1I;64@-B!O<F4Z(`!.=6UE
M<F\@;6%S<VEM;R!D96P@4&]R=&$@0FQO8VMS`$QU;F=H97IZ82!M87-S:6UA
M`$UA9V=I;P!-961I8VEN80!-96UB<FD`56YI<V-I(&QE(&-E;&QE`$UE<W-A
M9V=I;P!);"!M97-S86=I;R#H('-T871O('9E<FEF:6-A=&\@8V]R<F5T=&%M
M96YT92P@;6$@:6P@9FER;6%T87)I;R!D96P@8V5R=&EF:6-A=&\@;F]N('!U
M\B!E<W-E<F4@=F5R:69I8V%T;RX`365S<V%G9VEO('-C861U=&\N`%1I<&\@
M;65S<V%G9VEO`$UE=&]D;P!);"!M971O9&\@("(E<R(@;F]N(.@@9&5F:6YI
M=&\`365T;V1O(&YO;B!D969I;FET;RX@365T;V1O(&-H:6%M871A.B`E<P!-
M971R:6-A`$UE<W-I8V\`365Z>F\`5&5M<&\@;6EN:6UO('5L=&EM92`R-"!O
M<F4Z(`!496UP;R!M:6YI;6\@=6QT:6UE(#8@;W)E.B``26P@=&5M<&\@9&D@
M9'5R871A(&UI;FEM;R!D96QL82!P87-W;W)D(&YO;B#H('-C861U=&\`4W!E
M8V-H:6\`5F%R:6\`26P@<&%C8VAE='1O(%!%05(@2%144%]297%U97-T(.@@
M;6%N8V%N=&4N`$-O;F9I9W5R87II;VYE(&UA;F-A;G1E+B!$979I(&=E;F5R
M87)N92!U;F$@;G5O=F$@<V4@=G5O:2!U<V%R92!Q=65S=&$@87!P;&EC87II
M;VYE+@!)1"!D96P@;65S<V%G9VEO(&UA;F-A;G1E+@!);"!P86-C:&5T=&\@
M4$5!4B!-86EL(')I8VAI97-T;R#H(&UA;F-A;G1E+@!)1"!D96QL82!S97-S
M:6]N92!M86YC86YT92X`3'4`36]D97)A=&\`1&%T82!D96QL82!M;V1I9FEC
M80!-;V1I9FEC82!54DP`36]D=6QO`$UE<V4@92!A;FYO`$UE;G-I;&UE;G1E
M`$9A<VD@;'5N87)I`%-O;F\@<W1A=&D@=')O=F%T:2!P:?D@8V%M<&D@;F5L
M;&$@;&EN96$@)60@<FES<&5T=&\@82!Q=65L;&D@:7!R979I<W1I("5D+@!3
M<&]S=&$@4V]T=&\`4W!O<W1A(&$@4VEN:7-T<F$`4W!O<W1A(&$@1&5S=')A
M`%-P;W-T82!3;W!R80!3<&]S=&$@<V]T=&\`4W!O<W1A('-O<')A`%-E;&5Z
M:6]N92!M=6QT:7!L80!-:6\@06-C;W5N=`!);F9O<FUA>FEO;FD@9&5L($UI
M;R!!8V-O=6YT`$UI;R!0;W)T86QE`$1I<W!O<VEZ:6]N92!D96P@36EO(%!O
M<G1A;&4`3D\L(&YO;B!S;VYO(&0G86-C;W)D;P!.;VUE`%)E=&4`36%I`$YU
M;W9A($-A=&5G;W)I80!,=6YA($YU;W9A`$YU;W9O($YO;64@571E;G1E("AO
M<'II;VYA;&4I`$YU;W9A('!A<W-W;W)D`$QA(&YU;W9A('!A<W-W;W)D('-C
M861RX"!I;B`E>"X`3&$@;G5O=F$@<&%S<W=O<F0@;F]N(&-O<G)I<W!O;F1E
M+@!.=6]V82!F:6YI<W1R82`H7W9U;W1A*0!.;W1I>FEE`$=R=7!P:2!D:2!.
M;W1I>FEE`%!R;W-S:6UO`%!R;W-S:6UE(#0@1F%S:0!0<F]S<VEM92!O<'II
M;VYI`%!R;W-S:6UO/@!.;W1T90!.;VX@<V]N;R!D:7-P;VYI8FEL:2!I;F9O
M<FUA>FEO;FD@<FEG=6%R9&\@;&$@8V]N9FEG=7)A>FEO;F4@<&5R(&UO<W1R
M87)E(&QE(&1I9F9E<F5N>F4N`$YO;B#H(&1I<W!O;FEB:6QE('5N82!S=')A
M=&5G:6$@<&5R(&-R96%R92!I;6UA9VEN:2!)4T\N`$YO;B!E<VES=&4@=6X@
M8FQO8V-O(&%L;&$@<&]S:7II;VYE(')I8VAI97-T80!.;VX@Z"!S=&%T;R!F
M;W)N:71O(&EL(&YO;64@9&5L(&-A;&5N9&%R:6\@<&5R(&PG875T96YT:6-A
M>FEO;F4@34-!3"X`3F5S<W5N82!M;V1I9FEC82X`3F5S<W5N(&9I9VQI;R!P
M=?(@97-S97)E(&%G9VEU;G1O(&$@<75E<W1O('!E<FUE<W-O+@!.;VX@Z"!S
M=&%T82!S<&5C:69I8V%T82!A;&-U;F$@:6YF;W)M87II;VYE('-U;&QA(&-O
M;F9I9W5R87II;VYE('!E<B`E<RX`3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@
M86QC=6YA(&EN9F]R;6%Z:6]N92!S=6QL82!C;VYF:6=U<F%Z:6]N92!P97(@
M1E10(%9&4RX`3F]N(.@@<W1A=&$@<W!E8VEF:6-A=&$@86QC=6YA(&EN9F]R
M;6%Z:6]N92!S=6QL82!C;VYF:6=U<F%Z:6]N92!P97(@4U%,(%9&4RX`3F]N
M(.@@<W1A=&$@<W!E8VEF:6-A=&$@86QC=6YA(&EN9F]R;6%Z:6]N92!S=6QL
M82!C;VYF:6=U<F%Z:6]N92!P97(@4U%,+49I;&4@5D93+@!.;VX@Z"!R:6UA
M<W1O(&YE<W-U;B!C<F5D:71O+@!.;VX@Z"!S=&%T82!F;W)N:71A(&QA(&1E
M<W1I;F%Z:6]N92X`26P@9FEL92!N;VX@Z"!S=&%T;R!C87)I8V%T;P!.;VX@
M<V]N;R!S=&%T92!T<F]V871E(&QE(&EC;VYE+@!.;VX@Z"!S=&%T;R!I;7!O
M<W1A=&\@;&$@<&]S:7II;VYE+@!.;VX@Z"!S=&%T;R!I;F1I8V%T;R!L82!P
M;W-I>FEO;F4N`$YO;B#H('-T871O(&9O<FYI=&\@:6P@;65S<V%G9VEO+@!.
M;VX@Z"!S=&%T;R!S<&5C:69I8V%T;R!I;"!N;VUE+@!.;VX@Z"!S=&%T;R!S
M<&5C:69I8V%T;R!I;"!N=6UE<F\N`$YO;B#H('-T871A(&9O<FYI=&$@;&$@
M<&%S<W=O<F0@<&5R(&PG875T96YT:6-A>FEO;F4@2%144"X`3F]N(.@@<W1A
M=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z:6]N92!)
M34%0+@!.;VX@Z"!S=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E<B!L)V%U
M=&5N=&EC87II;VYE($ME<F)E<F]S+@!.;VX@Z"!S=&%T82!F;W)N:71A(&QA
M('!A<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE($QO9VEN+@!.;VX@Z"!S
M=&%T82!F;W)N:71A(&QA('!A<W-W;W)D('!E<B!L)V%U=&5N=&EC87II;VYE
M(%!!4U-71"X`3F]N(.@@<W1A=&$@9F]R;FET82!L82!P87-S=V]R9"!P97(@
M;"=A=71E;G1I8V%Z:6]N92!334(N`$YO;B#H(&1I<W!O;FEB:6QE(&%L8W5N
M82!P871C:"!P97(@;&$@=F5R<VEO;F4@8FEN87)I82!D:2!/<&5N4U-,+B!,
M82!V97)S:6]N92!B:6YA<FEA(&1I($]P96Y34TP@Z"!N96-E<W-A<FEO(&-H
M92!O<&5R:2!C;VX@;&4@:6YF;W)M87II;VYI(%!+0U,@,3(N`$YO;B#H('-T
M871A(&EM<&]S=&%T82!L82!Q=6]T82X`3F5S<W5N82!R96=O;&$`3F]N(.@@
M<W1A=&\@<W!E8VEF:6-A=&\@:6P@<V5P87)A=&]R92X`3F5S<W5N82!L871O
M`$YE<W-U;B!T:7!O(&1I(&9I;&4`3F]N(.@@9&ES<&]N:6)I;&4@=6YA(&1I
M<F5C=&]R>2!T96UP;W)A;F5A('!E<B!L82!C86-H92X`3F]N(.@@<W1A=&$@
M:6YV:6%T;R!I;"!N;VUE('5T96YT92!E+V\@<&%S<W=O<F0N`$YO;B!S;VYO
M(')I=&]R;F%T92!I;F9O<FUA>FEO;FD@6$U,('9A;&ED90!.97-S=6X@=F%L
M;W)E`$YO;B#H('-T871A('1R;W9A=&$@;&$@=F5R<VEO;F4@;F5L;&$@8V]N
M9FEG=7)A>FEO;F4@;W)I9VEN86QE+B!2:6=E;F5R82!L82!C;VYF:6=U<F%Z
M:6]N92X`3F]N(.@@<W1A=&$@=')O=F%T82!L82!V97)S:6]N92!N96QL82!T
M=6$@8V]N9FEG=7)A>FEO;F4N(%)I9V5N97)A(&QA(&-O;F9I9W5R87II;VYE
M+@!.97-S=6YO`$YE<W-U;F\@+W5S;R!I;7!L:6-I=&\I`$5M:7-F97)O(%-E
M='1E;G1R:6]N86QE`$YO<G9E9VEA`$YO;B!$;W!O`$YO;B!0<FEM80!.;VX@
M=6YA(&1I<F5C=&]R>0!.;VX@:6UP;&5M96YT871O`$YO;B!I;7!O<W1A=&\`
M3F]N('-U<'!O<G1A=&\N`$%P<'5N=&D`3G5L;&$@9&$@=FES=6%L:7IZ87)E
M+"!T;W)N82!I;F1I971R;RX`3F]V96UB<F4`3G5M97)O`$YU;65R;R!D:2!C
M87)A='1E<FD`3G5M97)O(&1I(&-O;&]N;F4`3G5M97)O(&1I(')I9VAE`$D@
M;G5M97)I(&YO;B!S;VYO('-T871I('-P96-I9FEC871I('!E<B!L)V%G9VEO
M<FYA;65N=&\@;F5L;&$@;&ES=&$@9&D@9&ES=')I8G5Z:6]N92X`3V=G971T
M;P!#<F5A=&]R92!D96QL)T]G9V5T=&\`3W1T86QE`$]T=&]B<F4`569F:6-I
M;P!,92!P87-S=V]R9"!V96-C:&EE(&4@;G5O=F4@9&5V;VYO(&5S<V5R92!D
M:69F97)E;G1I`%9E8V-H:6$@<&%S<W=O<F0`3&$@=F5C8VAI82!P87-S=V]R
M9"!N;VX@Z"!C;W)R971T82X`4V]L;R!I('-E<G9E<B!)34%0('-U<'!O<G1A
M;F\@;&4@8V%R=&5L;&4@8V]N9&EV:7-E+@!%)R!P97)M97-S;R!S;VQO('5N
M(&EN9&ER:7IZ;R!E;6%I;"X`4V]L;R!I;"!P<F]P<FEE=&%R:6\@;R!L)V%M
M;6EN:7-T<F%T;W)E(&1I('-I<W1E;6$@<'7R(&-A;6)I87)E(&QA('!R;W!R
M:65TX"!O(&D@<&5R;65S<VD@9&5L('!R;W!R:65T87)I;R!P97(@=6YA(&-O
M;F1I=FES:6]N90!!<')E(&EN('5N82!N=6]V82!F:6YI<W1R80!%<G)O<F4@
M3W!E;E-33#H@;F]N('-I('!O<W-O;F\@97-T<F%R<F4@;&4@:6YF;W)M87II
M;VYI(&1A;&QA('!A<G1E(&9I<FUA=&$@4R]-24U%+@!!<')E('%U97-T;R!C
M;VQL96=A;65N=&\@:6X@=6YA(&YU;W9A(&9I;F5S=')A`%-I<W1E;6$@3W!E
M<F%T:79O`$]P>FEO;FD`3W!Z:6]N:2!P97(@)7,`16QE;F-O(&]R9&EN871O
M`$]R9V%N:7IZ87II;VYE`%5N:73@($]R9V%N:7IZ871I=F$`06=E;F1A`$UA
M<V-H97)A(&]R:6=I;F%L92!D96QL)V%P;&EC87II;VYE`$UA<V-H97)A(&]R
M:6=I;F%L92!I;B`E<SH`06QT<F\`06QT<F4@26YF;W)M87II;VYE`%!E<FUE
M<W-I(&1E;"!P<F]P<FEE=&%R:6\`3"=A=71E;G1I8V%Z:6]N92!004T@;F]N
M(.@@9&ES<&]N:6)I;&4N`$EN9F]R;6%Z:6]N92!#:69R871A(%!'4`!#:&EA
M=F4@4'5B8FQI8V$@4$=0`$EN9F]R;6%Z:6]N92!&:7)M871A+T-I9G)A=&$@
M4$=0`$-O9&EC92!02%``4VAE;&P@4$A0`$5S=&5N<VEO;F4@4$]325@@;6%N
M8V%N=&4`4FEE;7!I;65N=&\`4&%R>FEA;&UE;G1E($YU=F]L;W-O`%!A<W-W
M;W)D(&-A;6)I871A(&-O;B!S=6-C97-S;RX`4&%S<V]W<F0@;F]N(&-O<G)E
M='1A`$4G(')I8VAI97-T82!L82!P87-S=V]R9"!P97(@;"=A=71E;G1I8V%Z
M:6]N92!2041)55,N`%!A<W-W;W)D(&-O;B!C;VYF97)M80!,92!P87-S=V]R
M9"!D979O;F\@8V]R<FES<&]N9&5R92X`26YC;VQL80!);F-O;&QA(&1A;&QA
M(&-L:7!B;V%R9`!097)C;W)S;P!097)S;VYE`%!E<F-E;G1U86QE`$5S96=U
M:2!L92!/<&5R87II;VYI(&1I($UA;G5T96YZ:6]N90!%<V5G=6ER92!L92!O
M<&5R87II;VYI(&1I(&UA;G1U=&5N>FEO;F4@86QL)V%C8V5S<V\_`%!E<FUE
M<W-O`%!E<FUE<W-O("(E<R(@;F]N(&-A;F-E;&QA=&\N`%!E<FUE<W-O($YE
M9V%T;P!097)M97-S:0!'97-T:6]N92!097)M97-S:0!);F9O<FUA>FEO;FD@
M4&5R<V]N86QI`%1E;&5F;VYO`$9O=&]G<F%F:64`4VD@<')E9V$@9&D@8VQI
M8V-A<F4@:6X@86QC=6YE(&-E;&QE`%-I('!R96=A(&1I(&-O;F9E<FUA<F4@
M8VAE('-I('9U;VQE(')I;75O=F5R92!Q=65S=&\@96QE;65N=&\Z`%-I('!R
M96=A(&1I(&-O;F9E<FUA<F4@8VAE('-I('9U;VQE('-C;VQL96=A<F4@<75E
M<W1O(&5L96UE;G1O.@!3:2!P<F5G82!D:2!I;G-E<FER92!U;B!M97-E(&4@
M=6X@86YN;RX`4VD@<')E9V$@9&D@:6YS97)I<F4@=6X@;F]M92!P97(@;&$@
M;G5O=F$@9V%T96=O<FEA.@!3:2!P<F5G82!D:2!I;G-E<FER92!U;B!I;F1I
M<FEZ>F\@25`@=F%L:61O+@!3:2!P<F5G82!D:2!I;G-E<FER92!U;F$@9&%T
M82!V86QI9&$L(&-O;G1R;VQL82!I;"!N=6UE<F\@9&D@9VEO<FYI(&YE;"!M
M97-E+@!3:2!P<F5G82!D:2!I;G-E<FER92!U;B=O<F$@=F%L:61A+@!3:2!P
M<F5G82!D:2!F;W)N:7)E('5N(')I87-S=6YT;R!D96P@<')O8FQE;6$N`%-I
M('!R96=A(&1I(&9O<FYI<F4@:6P@<')O<')I;R!N;VUE('5T96YT92!E('!A
M<W-W;W)D`%-I('!R96=A(&1I(&QE9V=E<F4@:6P@<V5G=65N=&4@=&5S=&\N
M($1%5DD@97-S97)E(&0G86-C;W)D;R!C;VX@:2!T97)M:6YI(&0G=7-O(&1E
M;"!S:7-T96UA+@!3:2!P<F5G82!D:2!S8W)I=F5R92!I;&YO;64@9&5L;&$@
M;G5O=F$@8V%T96=O<FEA.@!0;VQO;FEA`%!O;&ET:6-A`%-C<G5T:6YI;P!0
M;W)T;V=A;&QO`%!O<VEZ:6]N86UE;G1O(&1I('%U97-T82!I;6UA9VEN90!0
M;W-I>FEO;F%M96YT;R!D:2!Q=65S=&$@=&%B96QL80!0;W-T87)E(&$@<75E
M<W1A(&-A<G1E;&QA("AN;VX@87!P;&EC871O(&1A($E-05`I`%!R96-I<&ET
M87II;VYE('!E<B!L)W5L=&EM82`E<R!O<F$H92D`4')E9G-?;&1A<#H@17-T
M96YS:6]N92!,1$%0(')I8VAI97-T82!N;VX@=')O=F%T82X`4')E9G-?<V5S
M<VEO;CH@97-T96YS:6]N92!D96QL82!S97-S:6]N92!R:6-H:65S=&$@;F]N
M('1R;W9A=&$N`%!R97-S:6]N90!0<F5S<VEO;F4@86P@;&EV96QL;R!D96P@
M;6%R93H@`%!R97-S:6]N93H@`$%N=&5P<FEM80!!;G1E<')I;6$@9&5L;"=I
M;6UA9VEN92!I;B!U;F$@;G5O=F$@9FEN97-T<F$`3W!Z:6]N:2!P<F5C9&5N
M=&D`4W1A;7!A(&1O8W5M96YT;P!#:&EA=F4@4')I=F%T80!0<F]B;&5M80!$
M97-C<FEZ:6]N92!D96P@<')O8FQE;6$`4')O9V5T=&D`0VAI879E(%!U8F)L
M:6-A`$%L9V]R:71M;R!D96QL82!#:&EA=F4@4'5B8FQI8V$`26YF;W)M87II
M;VYI('-U;&QA($-H:6%V92!0=6)B;&EC80!,82!C;W!P:6$@8VAI879E(%!U
M8F)L:6-A+U!R:79A=&$@;F]N(.@@<W1A=&$@9V5N97)A=&$@8V]N('-U8V-E
M<W-O+@!%;&EM:6YA(&D@;65S<V%G9VD`1&]M86YD80!396QE>FEO;F4@<F%D
M:6\`4&EO9V=I80!287!P;W)T;P!,96=G:0!,96=G97)E(&D@;65S<V%G9VD`
M16QI;6EN87)E(')E86QM96YT92`E<S\@3"=O<&5R87II;VYE(&YO;B!P=?(@
M97-S97)E(')E8W5P97)A=&$N`$5L:6UI;F%R92!R96%L;65N=&4@;&4@:6YF
M;W)M87II;VYI(')E;&%T:79E(&%L;"=U=&5N=&4@)7,_($PG;W!E<F%Z:6]N
M92!N;VX@<'7R(&5S<V5R92!R96-U<&5R871A+@!2:65S96=U92!L82!T=6$@
M=6QT:6UA(&%Z:6]N90!!9V=I;W)N80!!9V=I;W)N82!G;&D@96QE;65N=&D@
M9&EN86UI8VD@9&5L(&UE;G4Z`$%G9VEO<FYA<F4@;&$@=FES=&$@9&5L('!O
M<G1A;&4Z`%)I8V%R:6-A`$]S<V5R=F%Z:6]N:0!397)V97(@<F5M;W1I`%52
M3"!R96UO=&$@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2:6UU
M;W9I`%)I;75O=FD@:6P@8FQO8V-O`%)I;75O=FD@;&$@8V]L;VYN80!2:6UU
M;W9I(&QA(&9O<FUA='1A>FEO;F4`4FEM=6]V:2!L82!C;W!P:6$`4FEM=6]V
M:2!L;R!S8W)I<'0@<V%L=F%T;R!D86QL82!D:7)E8W1O<GD@=&5M<&]R86YE
M82!D96P@<V5R=F5R+@!2:6UU;W9I(&EL`%)I;75O=FD@<75E<W1O(&YO9&\@
M9&%L(&1O8W5M96YT;P!2:6UU;W9I(&PG=71E;G1E`%)I;75O=FD@;"=U=&5N
M=&4Z("5S`$QA(')I8VAI97-T82!N;VX@<'7R(&5S<V5R92!E=F%S82X@0V]D
M:6-E(&1I(&5R<F]R92!D:2!R:71O<FYO.B``26P@<V5R=FEZ:6\@<FEC:&EE
M<W1O(&]N('!U\B!E<W-E<F4@=')O=F%T;RX`(B5S(B!R:6-H:65S=&\@;F]N
M(.@@<W!E8VEF:6-A=&\@;F5L;&$@8V]N9FEG=7)A>FEO;F4@9&D@)7,N`"(E
M<R(@<FEC:&EE<W1O(&YO;B#H('-P96-I9FEC871O(&YE;&QA(&-O;F9I9W5R
M87II;VYE(&1I(%9&4RX`(B5S(B!R:6-H:65S=&\@;F]N(.@@<W!E8VEF:6-A
M=&\@;F5L;&$@8V]N9FEG=7)A>FEO;F4N`$-A;7!O(%)I8VAI97-T;P!!>GIE
M<F$`07IZ97)A(&QA('!A<W-W;W)D`$%Z>F5R82!L82!T=6$@<&%S<W=O<F0`
M4FEP<FES=&EN82!L)W5L=&EM82!D;VUA;F1A`%)I<W5L=&%T:0!2:71O<FYA
M(&%L;&4@3W!Z:6]N:0!2:7-C<FEV:2!L82!N=6]V82!P87-S=V]R9`!2:75N
M:6]N90!);G9E<G1I(&QA($-O;F9I9W5R87II;VYE`$]P>FEO;FD@<&5R(&EL
M(%)I8V@@5&5X="!%9&ET;W(`26YD;W9I;F5L;&D`1&5S=')A`$EN=&5S=&%Z
M:6]N:2!D:2!D97-T<F$`5F%L;W)I(&1I(&1E<W1R80!0<F]P<FEE=.`@9&5L
M;&$@4FE?9V$N+BX`4F5G;VQA`%)O=71A(&1I(#$X,`!2;W5T82!A('-I;FES
M=')A`%)O=71A(&$@1&5S=')A`%!R;W!R:65TX"!D96QL82!2:6=A`%!R;W!R
M:65TX"!D96QL82!R:6=A`%)I9VAE.@!296=O;&4`3&4@<F5G;VQE(&%P<&%R
M:7)A;FYO('1R82!T=71T92!L92!R:6=H92!E(&QE(&-O;&]N;F4`3&4@<F5G
M;VQE(&%P<&%R:7)A;FYO('-O;&\@=')A(&QE(&-O;&]N;F4`3&4@<F5G;VQE
M(&%P<&%R:7)A;FYO('-O;&\@=')A(&QE(')I9VAE`$5S96=U:7)E`$9I<FUA
M(&-I9G)A=&$@4R]-24U%`$UE<W-A9V=I;R!C:69R871O(%,O34E-10!,)V%U
M=&5N=&EC87II;VYE(%-!4TP@;F]N(.@@9&ES<&]N:6)I;&4N`$UE<W-A9V=I
M;R!335,`1&EC:&EA<F%Z:6]N92!344P@<&5R(&EL('9A;&]R92!D:2!L;V]K
M<W5P`%-T97-S82!S=')U='1U<F$@*%]A=71O*0!P<F]V:61E<B!S871E;&QI
M=&%R90!386QV80!386QV82`B)7,B`%-A;'9A("5S`%-A;'9A(&QE($]P>FEO
M;FD`3&$@8V]N9FEG=7)A>FEO;F4@9V5N97)A=&$@Z"!S=&%T82!S86QV871A
M(&-O;64@<V-R:7!T(%!(4"!N96QL82!D:7)E8W1O<GD@=&5M<&]R86YE82!D
M96P@='5O('-E<G9E<BX`<V%L=F%T92`E<R!C;VYF:6=U<F%Z:6]N:2X`4V%L
M=F%T;R!L;R!S8W)I<'0@9&D@86=G:6]R;F%M96YT;R!D96QL92!I;7!O<W1A
M>FEO;FD@:6XZ("(E<R(N`%-C:65N>F$`4FEC97)C80!-;W1O<FD@9&D@4FEC
M97)C80!&:6QE('-E;&5Z:6]N871I`%-E;&5Z:6]N82!U;F$@9&%T80!396QE
M>FEO;F$@=6X@9W)U<'!O(&1A(&%G9VEU;F=E<F4`4V5L97II;VYA('5N(&YU
M;W9O('!R;W!R:65T87)I;P!396QE>FEO;F$@=6X@<V5R=F5R`%-E;&5Z:6]N
M82!U;B!U=&5N=&4@9&$@86=G:75N9V5R90!396QE>FEO;F$@='5T=&\`4V5L
M97II;VYA('1U='1I(&D@8V]M<&]N96YT:2!D96QL82!D871A+@!S96QE>FEO
M;F$@=6X@;V=G971T;P!.97-S=6YA('-E;&5Z:6]N90!396QE>FEO;F$@:2!C
M87)A='1E<FD@9&D@8W5I(&AA:2!B:7-O9VYO(&1A;&QE(&-A<V5L;&4@<V]T
M=&\@<FEP;W)T871E+B!0=6]I(&-O<&EA<FQI(&4@:6YC;VQL87)L:2!D86QL
M)V%R96$@9&D@=&5S=&\N`%-E;&5Z:6]N82!I;"!T97)M:6YE(&1E;&QA(&1A
M=&$Z`%-E;&5Z:6]N82!I;"!F;W)M871O(&1E;&QA(&1A=&$Z`%-E;&5Z:6]N
M82!L)VED96YT:73@(&-H92!V=6]I(&UO9&EF:6-A<F4Z`%-E;&5Z:6]N82!I
M;"!L:6UI=&4@9&5L;"=O<F$Z`%-E;&5Z:6]N82!I;"!F;W)M871O(&1E;&PG
M;W)A.@!396QE>FEO;F$@9'5E(&-A;7!I(&-H92!C;W)R:7-P;VYD;VYO+@!3
M96QE>FEO;F$@;&\@<V-H96UA(&1E:2!C;VQO<FDN`%-E;&5Z:6]N82!L82!L
M:6YG=6$@<')E9F5R:71A.@!);G9I82!I;"!297!O<G0@9&5L('!R;V)L96UA
M`$EN=FEA(%--4P!396YS;W)E.B``4V5T=&5M8G)E`$YU;65R;R!D:2!397)I
M90!);F9O<FUA>FEO;F4@9&5L('-E<G9E<B!S8F%G;&EA=&$@;R!N;VX@9&ES
M<&]N:6)I;&4N`$%M;6EN:7-T<F%T;W)E(&1I('-E<W-I;VYE`$QA('-E<W-I
M;VYE($E$(.@@<V-A9'5T80!397-S:6]N:0!);7!O<W1A`$EM<&]S=&$@;&4@
M;W!Z:6]N:2!P97(@<&5R;65T=&5R=&D@9&D@87IZ97)A<F4@;&$@<&%S<W=O
M<F0@;F5L(&-A<V\@9&]V97-S:2!D:6UE;G1I8V%R=&5L82X`26UP;W-T82!I
M;"!S97)V97(@<F5M;W1O(&%L('%U86QE('9U;VD@86-C961E<F4@9&%L('1U
M;R!P;W)T86QE+@!);7!O<W1A(&QA(&QI;F=U82!P<F5F97)I=&$@92!L92!O
M<'II;VYI('!E<B!L)V]R82!E(&QA(&1A=&$N`$EM<&]S=&$@;&4@87!P;&EC
M87II;VYI(&1I(&%V=FEO+"!L;R!S8VAE;6$@9&5I(&-O;&]R:2P@:6P@=&5M
M<&\@9&D@86=G:6]R;F%M96YT;R!D96QL82!P86=I;F$@92!A;'1R92!O<'II
M;VYI(&1I('9I<W5A;&EZ>F%Z:6]N92X`26UP;W-T87II;VYE`%-C<FEP="!D
M:2!A9V=I;W)N86UE;G1O(&1E;&QE(&EM<&]S=&%Z:6]N:2!D:7-P;VYI8FEL
M:0!$:79E<G-E('!O<VEZ:6]N:2!D:7-P;VYI8FEL:2!C;VX@:6P@<&%R86UE
M=')O.B``0G)E=F4@4V]M;6%R:6\`3&$@8VAI879E(&0G86-C97-S;R!D;W9R
MX"!E<W-E<F4@9&5F:6YI=&$@<&5R('!I^2!C;VQL96=A;65N=&D_`$UO<W1R
M80!-;W-T<F$@;&4@9&EF9F5R96YZ92!T<F$@;&$@8V]N9FEG=7)A>FEO;F4@
M871T=6%L;65N=&4@<V%L=F%T82!E(&QA(&YU;W9A(&=E;F5R871A+@!-;W-T
M<F$@;"=O<F$@9&5L;"=U;'1I;6\@86-C97-S;R!Q=6%N9&\@96YT<FD_`$UO
M<W1R82!L)V]P>FEO;F4@<&5R(&UA;G1E;F5R92!Q=65L;&$@;W)I9VEN86QE
M`$UO<W1R82!I;"!R86-C;V=L:71O<F4`36]S=')A<F4@;&$@=&%B96QL82!D
M96QL92!O<&5R87II;VYI(&1E;"!M96YU(&)A<C\`36]S=')A(&EL(&UE;G4@
M9&D@)7,@<W5L;&$@<VEN:7-T<F$_`$UO<W1R82!I;"!C87)I8V%M96YT;P!#
M;VYT<F%S<V5G;F$`1FER;6$`06QG;W)I=&UO(&1I(&9I<FUA`$1I;65N<VEO
M;F4`4V%L=&$@;&4@;W!E<F%Z:6]N:2!D:2!M86YU=&5N>FEO;F4`3F5V90!/
M<F1I;F$@;"=O<F1I;F%M96YT;R!D:2!S96QE>FEO;F4`26YD:7)I>GIO('-O
M<F=E;G1E`%-U9"!!9G)I8V$`96UI<V9E<F\@365R:61I;VYA;&4`4W!A>FEO
M('1R82!C96QL92!A:61A8V5N=&D`4W!A>FEO('1R82!I;"!C;VYT96YU=&\@
M92!I;"!B;W)D;R!I;B!U;F$@8V5L;&$`1&ES=&%N>FEA=&]R90!3<&%Z:6%T
M=7)A`%-P87II871U<F$@92!R:65M<&EM96YT;P!3<&%G;F$`26YS97)I;65N
M=&\@0V%R871T97)I(%-P96-I86QI`%-E<&%R82!L82!C96QL80!397!A<F$@
M;&$@8V]L;VYN80!397!A<F$@;&$@<FEG:&$`06YN;R!D:2!P87)T96YZ80!3
M=&%T;R!O(%!R;W9I;F-I80!&;W)M871O(&1I(&UE;6]R:7IZ87II;VYE`$EN
M9&ER:7IZ;P!4;V=L:2!I;"!D;VUI;FEO(&1A;&PG:6YD:7)I>GIO`%-T:6QE
M(%M#4U-=`$1O`%-O='1O9&ER96-T;W)Y("(E<R(@;F]N('1R;W9A=&$N`$]G
M9V5T=&\`4V]T=&]M971T:0!%)R!S=&%T82!I;G9I871A(&QA(')I8VAI97-T
M82!P97(@86=G:75N9V5R92`B)7,B(&%L('-I<W1E;6$N($YO;B!P=6]I(&%C
M8V5D97)E(&9I;G1A;G1O("!C:&4@;&$@<FEC:&EE<W1A(&YO;B!V:65N92!A
M<'!R;W9A=&$N`"(E<R(@Z"!S=&%T;R!A9V=I=6YT;R!C;VX@<W5C8V5S<V\@
M86P@<VES=&5M82X`3&4@:6YF;W)M87II;VYI(')E;&%T:79E(&%L;"=U=&5N
M=&4@(B5S(B!S;VYO('-T871E(&-A;F-E;&QA=&4@8V]N('-U<W-E<W-O(&1A
M;"!S:7-T96UA+@`B)7,B(&5L:6UI;F%T82!C;VX@<W5C8V5S<V\N`"(E<R(@
M<FEM;W-S;R!C;VX@<W5C8V5S<V\@9&%L('-I<W1E;6$N`$-O;F9I9W5R87II
M;VYE(&EN=F5R=&ET82!C;VX@<W5C8V5S<V\N(%)I8V%R:6-A('!E<B!V961E
M<F4@:2!C86UB:6%M96YT:2X`0V]P:6$@9&5L;&$@8V]N9FEG=7)A>FEO;F4@
M<V%L=F%T82!C;VX@<W5C8V5S<V\N`$-O<&EA(&1E;"!F:6QE(&1I(&-O;F9I
M9W5R87II;VYE(&1I("5S('-A;'9A=&$@8V]N('-U8V-E<W-O+@!!9V=I;W)N
M871O(&-O;B!S=6-C97-S;R`B)7,B`%-C<FET=&\@8V]N('-U8V-E<W-O("5S
M`%-O;6UA<FEO`%-U<'!O<G1O`%-O<')A;FYO;64`4W9E>FEA`%-V:7IZ97)A
M`$5R<F]R92!D:2!S:6YT87-S:2!N96D@=&5R;6EN:2!D:2!R:6-E<F-A`%!R
M;W!R:65TX"!D96QL82!486)E;&QA`$EM<&]S=&%Z:6]N92!D96QL82!486)E
M;&QA`%!R;W!R:65TX"!D96QL82!T86)E;&QA`$]B:65T=&EV;SH`071T:79I
M=.``3G5M97)O(&1I('1E;&5F;VYO`%1E;7!E<F%T=7)A('!E<B!L)W5L=&EM
M82!O<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@`$UA<V-H97)A("(E
M<R(@;F]N('1R;W9A=&$N`$=E<W1I;VYE($UA<V-H97)A`%1E<W1O`%-O;&\@
M5&5S=&\`06QL:6YE86UE;G1O('1E<W1O`$=I`$PG97-T96YS:6]N92!&5%`@
M;F]N(.@@9&ES<&]N:6)I;&4N`$QA(&-R;VYI<W1O<FEA(&1E;"!S:7-T96UA
M(.@@9&ES86)I;&ET871A+@!);"!M;W1O<F4@9&D@:6YT96=R87II;VYE($AO
M<F1E+TMO;&%B(&YO;B!S=7!P;W)T82`B)7,B`$EL(&QO9R!D:2!)35-0(&YO
M;B!P=?(@97-S97)E(&EN:7II86QI>GIA=&\N`$QA(&-L87-S92!-86EN=&5N
M86YC93HZ(&YO;B#H('-T871A(&-A<FEC871A(&-O;B!S=6-C97-S;P!,82!F
M:6YI<W1R82!D96QL92!/<'II;VYI('-I(.@@8VAI=7-A+B!5<V-I<F4N`%-O
M;&%M96YT92!I;"!L871O(&EN9F5R:6]R90!);"!C;VYT871T;R#H('-T871O
M(&%G9VEU;G1O(&-O;B!S=6-C97-S;R!A;&QA('1U82!R=6)R:6-A+@!.;VX@
MZ"!S=&%T82!S<&5C:69I8V%T82!L82!L:7-T82!D:2!D:7-T<FEB=7II;VYE
M+@!,82!F=6YZ:6]N92!D:2!C:69R871U<F$@<FEC:&EE9&4@=6YA(&-O;FYE
M<W-I;VYE('=E8B!S:6-U<F$N`$EL(&9I;&4@)7,@9&]V<F5B8F4@8V]N=&5N
M97)E('5N82`E<R!I;7!O<W1A>FEO;F4N`$EL(&9I;&4@)7,@9&]V<F5B8F4@
M8V]N=&5N97)E(&%L8W5N92`E<R!I;7!O<W1A>FEO;FDN`$EL(&9I;&4@;F]N
M(&-O;G1I96YE(&EN9F]R;6%Z:6]N:2X`3&4@<V5G=65N=&D@<V]N;R!L92!I
M;G1E<W1A>FEO;FD@<&5R('%U97-T;R!M97-S86=G:6\O<F9C.#(R(&UE<W-A
M9V=I;RX`3"=I9&5N=&ETX"`B)7,B(.@@<W1A=&$@8V%M8V5L;&%T82X`26P@
M;G5M97)O(&1E:2!C86UP:2!D979E(&5S<V5R92!D:2!T:7!O(&YU;65R:6-O
M+@!);"!M;V1U;&\@;W!E;G-S;"#H(')I8VAI97-T;R!P97(@;&$@8VQA<W-E
M($AO<F1E7T-R>7!T7W-M:6UE.CHN`$QA('!R969E<F5N>F$@(B5S(B!N;VX@
M<'7R(&5S<V5R92!S86QV871A('!E<F-HZ"!L)VEN9F]R;6%Z:6]N92!C;VYT
M96YU=&$@96-C961E(&QA(&UA<W-I;6$@9&EM96YS:6]N92!D:7-P;VYI8FEL
M90!);"!P<F]G<F%M;6$@=7-A=&\@<&5R('9I<W5A;&EZ>F%R92!Q=65S=&\@
M=&EP;R!D:2!I;F9O<FUA>FEO;F4@*"5S*2!N;VX@Z"!S=&%T;R!T<F]V871O
M(&YE;"!S:7-T96UA+@!);"!S97)V97(@(B5S(B#H('-T871O(&5L:6UI;F%T
M;RX`26P@<V5R=F5R("(E<R(@Z"!S=&%T;R!S86QV871O+@!,82!R:6-H:65S
M=&$@9&D@:7-C<FEZ:6]N92!P97(@)7,@Z"!S=&%T82!R:6UO<W-A+@!,82!R
M:6=A('-P96-I9FEC871A("@E9"D@;F]N(&5S:7-T92X`26P@9FEL92!T96UP
M;W)A;F5O("(E<R(@;F]N(&5S:7-T92X`26P@=&5S=&\@9&EG:71A=&\@;F]N
M(&-O<G)I<W!O;F1E(&%L('1E<W1O('-U;&QO('-C:&5R;6\N`$PG:6YF;W)M
M87II;VYE(&-A<FEC871A(.@@<W1A=&$@<&5R<V$@<VEN(&1A;&PG=6QT:6UO
M('!A<W-O+@!);"!F:6QE(&-A<FEC871O(&YO;B!P=?(@97-S97)E('-A;'9A
M=&\N`$QA(&1I<F5C=&]R>2!D96D@=&5M:2`B)7,B(&YO;B#H('-T871A('1R
M;W9A=&$N`$YO;B!C:2!S;VYO(&]P>FEO;FD@9&ES<&]N:6)I;&DN`$YO;B!C
M:2!S;VYO('!A<G1I(&-H92!P;W-S;VYO(&5S<V5R92!V:7-U86QI>GIA=&4@
M:6YL:6YE+@!#:2!S;VYO('1R;W!P:2!C87)A='1E<FD@:6X@<75E<W1O(&-A
M;7!O+B!(86D@9&EG:71A=&\@)7,@8V%R871T97)I.R!D979I(&1I9VET87)E
M('5N(&YU;65R;R!D:2!C87)A='1E<FD@;6EN;W)E(&1I("5S+@!#:2!S;VYO
M(&%L8W5N:2!P<F]B;&5M:2!N96QL)V%G9VEU;F=E<F4@(B5S(B!A;"!S:7-T
M96UA.B`E<P!#)^@@<W1A=&\@=6X@<')O8FQE;6$@;F5L(&-A;F-E;&QA<F4@
M;&4@:6YF;W)M87II;VYI('!E<B!L)W5T96YT92`B)7,B(&1A;"!S:7-T96UA
M.B``0R?H('-T871O('5N('!R;V)L96UA(&YE;"!R:6UU;W9E<F4@(B5S(B!D
M86P@<VES=&5M83H@`$,GZ"!S=&%T;R!U;B!P<F]B;&5M82!N96QL)V%G9VEO
M<FYA;65N=&\@9&D@(B5S(CH@)7,`0R?H('-T871O('5N('!R;V)L96UA(&-O
M;B!I;"!C87)I8V%M96YT;R!D96P@9FEL93H@3F5S<W5N("5S(.@@<W1A=&\@
M8V%R:6-A=&\N`$,GZ"!S=&%T;R!U;B!P<F]B;&5M82!C;VX@:6P@8V%R:6-A
M;65N=&\@9&5L(&9I;&4Z($EL("5S(&5R82!P:?D@;'5N9V\@9&5L;&$@;6%S
M<VEM82!D:6UE;G-I;VYE('!E<FUE<W-A("@E9"!B>71E<RDN`$,GZ"!S=&%T
M;R!U;B!P<F]B;&5M82!C;VX@:6P@8V%R:6-A;65N=&\@9&5L(&9I;&4Z($EL
M("5S(.@@<W1A=&\@8V%R:6-A=&\@<V]L;R!P87)Z:6%L;65N=&4N`$,GZ"!S
M=&%T;R!U;B!E<G)O<F4@;F5L;&$@=FES=6%L:7IZ87II;VYE(&1I('%U97-T
M82!P87)T92!D96P@;65S<V%G9VEO`$,GZ"!S=&%T;R!U;B!E<G)O<F4@;F5L
M;"=I;7!O<G1A<F4@;&4@:6YF;W)M87II;VYI(&1E;"!C;VYT871T;RX`0R?H
M('-T871O('5N(&5R<F]R92!N96QL)VEM<&]R=&%R92!L92!I;F9O<FUA>FEO
M;FD@9&D@:4-A;&5N9&%R+@!#)^@@<W1A=&\@=6X@97)O<F4@;F5L;&$@9F]R
M;2!D:2!C;VYF:6=U<F%Z:6]N92X@4')O8F%B:6QM96YT92!H86D@9&EM96YT
M:6-A=&\@=6X@8V%M<&\@<FEC:&EE<W1O+@!#)^@@<W1A=&\@=6X@97)R;W)E
M(&YE;&PG97-E9W5I<F4@;&$@<W!E8VEF:6-A(&9U;GII;VYE(&1E;&QA(')U
M8G)I8V$N(%-I('!R96=A(&1I(')I<')O=F%R92!P:?D@=&%R9&DN`$,GZ"!S
M=&%T;R!U;B!E<G)O<F4@;F5L;"=A9V=I;W)N86UE;G1O(&1E:2!D971T86=L
M:2!D96P@8V]N=&%T=&\N(%-I('!R96=A(&1I('!R;W9A<F4@<&GY('1A<F1I
M+@!#)^@@<W1A=&\@=6X@97)R;W)E(&YE;&PG86=G:6]R;F%M96YT;R!D96QL
M82!L:7-T82!D:2!D:7-T<FEB=7II;VYE+B!3:2!P<F5G82!D:2!P<F]V87)E
M('!I^2!T87)D:2X`475E<W1O('-E<G9E<B!)34%0(&YO;B!S=7!P;W)T82!L
M82!C;VYD:79I<VEO;F4@9&D@8V%R=&5L;&4N`%%U97-T;R!S96UB<F$@;F]N
M(&5S<V5R92!U;B!A<F-H:79I;R!D:2!T:7!O(')A<B!V86QI9&\N`%%U97-T
M;R!S96UB<F$@;F]N(&5S<V5R92!U;B!F:6QE(&1I('1I<&\@>FEP('9A;&ED
M;RX`475E<W1O(&YO;B!S96UB<F$@97-S97)E('5N(&YU;65R;R!D:2!C87)T
M82!V86QI9&\N`"!1=65S=&\@8V%M<&\@<'7R(&-O;G1E;F5R92!S;VQO(&EN
M=&5R:2X`(%%U97-T;R!C86UP;R!P=?(@8V]N=&5N97)E('-O;&\@;G5M97)I
M(&4@9'5E('!U;G1I+@!1=65S=&\@8V%M<&\@<'7R(&5S<V5R92!S;VQO('5N
M82!L:7-T82!D:2!I;G1E<FD@<V%P87)A=&D@9&$@=FER9V]L82!O('-P87II
M;P!1=65S=&\@8V%M<&\@9&5V92!E<W-E<F4@=6X@;G5M97)O('9A;&ED;RX`
M475E<W1O(&-A;7!O(&1E=F4@8V]N=&5N97)E('5N(&-O;&]R;R!I;B!F;W)M
M871O(%)'0B!E<V%D96-I;6%L92P@860@97-E;7!I;R`G(S$R,S1A9B<N`%%U
M97-T82!F;W)M(.@@9VEA('-T871A('!R;V-E<W-A=&$N`%%U97-T;R#H("5S
M+@!1=65S=&\@;65S<V%G9VEO(.@@<W1A=&\@<V-R:71T;R!I;B!U;B!S970@
M9&D@8V%R871T97)I("@E<RD@9&EV97)S;R!D86P@='5O+@!1=65S=&\@;G5M
M97)O(&1E=F4@97-S97)E('5N:6-O+@!1=65S=&\@<V5R=F5R(&YO;B!P=?(@
M9&5C;VUP<FEM97)E(&9I;&4@:6X@9F]R;6%T;R!Z:7`@92!G>FEP+@!!;"!M
M;VUE;G1O('%U97-T;R!S:7-T96UA(&YO;B#H(&%T=&EV;RX`475E<W1O('9A
M;&]R92!D979E(&5S<V5R92!U;B!N=6UE<F\N`%%U97-T82!F:6YE<W1R82!D
M979E(&5S<V5R92!C:&EA;6%T82!D82!U;F$@9FEN97-T<F$@9&5L;&4@3W!Z
M:6]N:0!4=6]N;P!":6=L:65T=&D`3W)A`$9O<FUA=&\@9&5L;"=O<F$`4V5L
M97II;VYE(&1E;&PG;W)A`%1I=&]L;P!!`%!E<B!S96QE>FEO;F5R92!P:?D@
M=F]C:2P@=&EE;FD@<')E;75T;R!I;"!T87-T;R!#;VYT<F]L("A00RD@;R!#
M;VUM86YD("A-86,I(&UE;G1R:2!S=&%I(&-L:6-C86YD;RX`3V=G:0!$;VUA
M;FD`5')O<'!E(&%C8V5S<VD@;F]N('9A;&ED:2!D=7)E;G1E(&=L:2!U;'1I
M;6D@;6EN=71I+@!!;'1O`%1R861U>FEO;FD`5F5R;R!O(&9A;'-O`$UA`%1U
M<F-H:6$`1&EG:71A(&QA('1U82!S8V5L=&$Z(`!);7!O<W-I8FEL92!A8V-E
M9&5R92!A;&QA(&1I<F5C=&]R>2!61E,N`$EM<&]S<VEB:6QE(&%G9VEU;F=E
M<F4@86QT<F4@:6YF;W)M87II;VYI('-U9VQI('5T96YT:2!M96YT<F4@9'5R
M86YT92!L82!S;W1T;W-C<FEZ:6]N92X`26UP;W-S:6)I;&4@8V%M8FEA<F4@
M:2!P97)M97-S:2!P97(@:6P@9FEL92!61E,@(B5S(BX`26UP;W-S:6)I;&4@
M8V%M8FEA<F4@:2!P97)M97-S:2!P97(@:6P@9FEL92!61E,@)7,O)7,N`$EM
M<&]S<VEB:6QE(&-A;6)I87)E(&$@)7,N`$EM<&]S<VEB:6QE('9E<FEF:6-A
M<F4@;&$@9&EM96YS:6]N92!D:2`B)7,B+@!);7!O<W-I8FEL92!V97)I9FEC
M87)E(&QA(&1I;65N<VEO;F4@9&D@(B5S+R5S(BX`26UP;W-S:6)I;&4@8V]N
M;F5T=&5R<VD@86P@<V5R=F5R(%-13"X`26UP;W-S:6)I;&4@8V]N;F5T=&5R
M<VD@8V]N(%-33"X`26UP;W-S:6)I;&4@8V]P:6%R92!I;"!F:6QE(%9&4RX`
M26UP;W-S:6)I;&4@8W)E87)E(&QA(&1I<F5C=&]R>2!61E,@(B5S(BX`26UP
M;W-S:6)I;&4@8W)E87)E(&QA(&1I<F5C=&]R>2!61E,N`$EM<&]S<VEB:6QE
M(&-R96%R92!I;"!F:6QE(%9&4RX`26UP;W-S:6)I;&4@8W)E87)E(&QA(&-A
M<G1E;&QA(%9&4R`B)7,B+@!);7!O<W-I8FEL92!C<F5A<F4@:6P@9FEL92!6
M1E,@=G5O=&\N`$EM<&]S<VEB:6QE(&1E8V]M<')I;65R92!L92!I;F9O<FUA
M>FEO;FDN`$EM<&]S<VEB:6QE(&5L:6UI;F%R92`B)7,B+"!L82!D:7)E8W1O
M<GD@;F]N(.@@=G5O=&$N`$EM<&]S<VEB:6QE(&5L:6UI;F%R92`B)7,B.B`E
M<RX`26UP;W-S:6)I;&4@96QI;6EN87)E("5S+"!L82!D:7)E8W1O<GD@;F]N
M(.@@=G5O=&$`26UP;W-S:6)I;&4@96QI;6EN87)E(&QA(&1I<F5C=&]R>2!6
M1E,@:6X@;6]D;R!R:6-O<G-I=F\N`$EM<&]S<VEB:6QE(&5L:6UI;F%R92!L
M82!D:7)E8W1O<GD@5D93+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@;&$@9&ER
M96-T;W)Y(%9&4SH@)7,N`$E-<&]S<VEB:6QE(&5L:6UI;F%R92!I;"!F:6QE
M(%9&4R`B)7,B+@!);7!O<W-I8FEL92!E;&EM:6YA<F4@:6P@9FEL92!61E,N
M`$EM<&]S<VEB:6QE(&5L:6UI;F%R92!L82!C87)T96QL82!61E,@(B5S(BX`
M26UP;W-S:6)I;&4@96QI;6EN87)E(%9&4R!I;B!M;V1O(')I8V]R<VEV;SH@
M)7,N`$EM<&]S<VEB:6QE(&1E=&5R;6EN87)E(&QA(&1I<F5C=&]R>2!A='1U
M86QE+@!);7!O<W-I8FEL92!E<W1A<G)E(&D@9&5T=&%G;&D@9&5L(&-E<G1I
M9FEC871O`$EM<&]S<VEB:6QE(&-A<FEC87)E(&QA(&1E9FEN:7II;VYE(&1I
M("5S+@!);7!O<W-I8FEL92!S<&]S=&%R92!I;"!F:6QE(%9&4RX`26UP;W-S
M:6)I;&4@87!R:7)E(&EL(&9I;&4@5D93("(E<R(N`$EM<&]S<VEB:6QE(&%P
M<FER92!I;"!F:6QE(%9&4R!P97(@;&$@<V-R:71T=7)A+@!);7!O<W-I8FEL
M92!A<')I<F4@:6P@9FEL92!61E,N`$EM<&]S<VEB:6QE(&%P<FEE(&PG87)C
M:&EV:6\@8V]M<')E<W-O+@!);7!O<VEB:6QE(&QE9V=E<F4@:6P@9FEL92!6
M1E,@*&9I;&5S:7IE(&9I;&4H*2!F86EL960I+@!);7!O<W-I8FEL92!L96=G
M97)E(&EL(&9I;&4@5D93("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`$EM<&]S
M<VEB:6QE(&QE9V=E<F4@:6P@9FEL93H@`$EM<&]S<VEB:6QE(&QE9V=E<F4@
M;&$@9&ER96-T;W)Y('9F<W)O;W0N`$EM<&]S<VEB:6QE(')I;F]M:6YA<F4@
M)7,@:6X@)7,Z(&QA(&-A<G1E;&QA(&1I(&1E<W1I;F%Z:6]N92#H(&=I82!P
M<F5S96YT90!);7!O<W-I8FEL92!R:6YO;6EN87)E(&QA(&1I<F5C=&]R>2!6
M1E,N`$EM<&]S<VEB:6QE(')I;F]M:6YA<F4@;&$@9&ER96-T;W)Y(%9&4SH@
M)7,N`$EM<&]S<VEB:6QE(')I;F]M:6YA<F4@:6P@9FEL92!61E,@(B5S(BX`
M26UP;W-S:6)I;&4@<FEN;VUI;F%R92!I;"!F:6QE(%9&4R`E<R\E<RX`26UP
M;W-S:6)I;&4@<FEN;VUI;F%R92!I;"!F:6QE(%9&4RX`26UP;W-S:6)I;&4@
M97-E9W5I<F4@)VUK:7-O9G,G+@!);7!O<W-I8FEL92!T<F%D=7)R92!Q=65S
M=&\@9&]C=6UE;G1O(%=O<F0`26UP;W-S:6)I;&4@9&%R92!L)V%V=FEO(&%L
M;"=A9V=I;W)N86UE;G1O(&9R964O8G5S>2!P97(@)7,`26UP;W-S:6)I;&4@
M<V-R:79E<F4@:6P@9FEL92!61E,@(B5S(BX`26UP;W-S:6)I;&4@<V-R:79E
M<F4@:6P@9FEL92!61E,@*&-O<'DH*2!F86EL960I+@!);7!O<W-I8FEL92!S
M8W)I=F5R92!L92!I;F9O<FUA>FEO;FD@;F5L(&9I;&4@5D93+@!);7!O<W-I
M8FEL92!S8W)I=F5R92!I;"!F:6QE(%9&4RP@;&$@<75O=&$@8V]N<V5N=&ET
M82!V97)RX"!E8V-E9'5T82X`4V]T=&]L:6YE871O`$%N;G5L;&$@36]D:69I
M8VAE`$YO;B!F87)E(&QA('1U82!U;'1I;6$@87II;VYE`%)I<W!O<W1A(&EN
M871T97-A(&1A;"!S97)V97(@9'5R86YT92!L82!C;VYN97-S:6]N93H@`%)I
M<W!O<W1A(&EN871T97-A(&1A;"!S97)V97(@83H@`%-C;VYO<V-I=71O`$YO
M;64@=71E;G1E(&4@<&%S<W=O<F0@<V-O;F]S8VEU=&D`3F]N(&-O;&QE9V%R
M92!L)V5L96UE;G1O(&-O<G)E;G1E`%-E;GIA(&YO;64`17-T96YS:6]N92!N
M;VX@<W5P<&]R=&%T80!!9V=I;W)N80!!9V=I;W)N82`E<P!!9V=I;W)N82!U
M=&5N=&4`06=G:6]R;F$@(B5S(BX`4V-R:7!T(&1I(&-A<FEC86UE;G1E(&5L
M:6UI;F%T82X`0V%R:6-A`&-A<FEC871I('1U='1I(&D@9FEL92!D:2!I;7!O
M<W1A>FEO;F4@9&5L;&4@87!P;&EC87II;VYI('-U;"!S97)V97(N`&-A<F%T
M=&5R:2!L871I;FD@;6%I=7-C;VQI`$YU;65R:2!R;VUA;FD@;6%I=7-C;VQI
M`'5S82!I;"!C;W)R96YT93H@)7,`57-A(%-33`!5<V$@<V4@:6P@;F]M92!U
M=&5N=&4O<&%S<W=O<F0@Z"!D:69F97)E;G1E(&1A('%U96QL82!D96P@<V5R
M=F5R($E-4U`N`%5T96YT90!,=71E;G1E("5S(&YO;B#H(&%U=&]R:7IZ871O
M('!E<B`E<RX`1V5S=&EO;F4@571E;G1I`$]P>FEO;FD@571E;G1I`%)E9VES
M=')A>FEO;F4@571E;G1I`$QA<F5G:7-T<F%Z:6]N92!D96=L:2!U=&5N=&D@
MZ"!S=&%T82!D:7-A8FEL:71A=&$@<&5R('%U97-T;R!S:71O+@!.;VUE('5T
M96YT92!N;VX@=')O=F%T;P!.;VUE(%5T96YT90!.;VUE(%5T96YT92`B)7,B
M(.@@9VEA('!R97-E;G1E+@!.;VUE(%5T96YT93H`3F]M92!5=&5N=&4Z(`!5
M=&5N=&D@;F5L('-I<W1E;6$Z`$QA(&1I<F5C=&]R>2!61E,@;F]N(&5S:7-T
M92X`07-S96YZ80!0;W-I>FEO;FD@=F%L:61E('1R;W9A=&4@:6YC;'5D;VYO
M.B``5F%L:61I=.``5F%L;W)E(&EN(&UI;G5T:2!D82!O<F$N`$EL('9A;&]R
M92#H(&UA9V=I;W)E(&1L;&$@;6%S<VEM82!L=6YG:&5Z>F$@9&D@)7,N`%9A
M;&]R:0!686QO<FD@9&%I('%U86QI('-E;&5Z:6]N87)E`%9A<FEA8FEL90!6
M97)I9FEC82!F86QL:71A("T@<75E<W1O(&UE<W-A9V=I;R!P=?(@97-S97)E
M('-T871O(&%L=&5R871O(&-O;BX`5F5R<VEO;F4`5F5R<VEO;F4@9&D@0V]N
M=')O;&QO`$%L;&EN96%M96YT;R!V97)T:6-A;&4`4FEE;7!I;65N=&\@=F5R
M=&EC86QE`%9E<G1I8V%L93H`36]L=&\@06QT;P!6:7-U86QI>GIA("5S`%9I
M<W5A;&EZ>F$@=6YA('!A9VEN82!W96(@97-T97)N80!6:7-U86QI>GIA(&-O
M;64@)7,`5FES:6)I;&ETX`!6:7-I8FEL:73@.B``051414Y:24].10!!5%1%
M3EI)3TY%(2$A(%))355/5DD@3$\@4T-225!4($U!3E5!3$U%3E1%($1!("5S
M+@!!='1E;GII;VYE`$UE`$)O;&QE='1I;F\@;65T96]R;VQO9VEC;P!";VQL
M971T:6YO(&UE=&5O<F]L;V=I8V\@9F]R;FET;R!D80!3971T:6UA;F%L;65N
M=&4`0F5N=F5N=71O`$)E;G9E;G5T;R!A("5S`$)E;G9E;G5T;RP@)7,`475A
M;&4@87!P;&EC87II;VYE(&1O=G+@('9I<W5A;&EZ>F%R92`E<R!D;W!O(&PG
M86-C97-S;S\`475A;"?H(&EL(&-A<F%T=&5R92!D:2!D96QI;6ET87II;VYE
M/P!1=6%L92!P;'5G:6YS(&%B:6QI=&%R92!P97(@:6P@4FEC:"!497AT(&5D
M:71O<BX`3&%R9VAE>GIA`$QA<F=H97IZ82!I;B!U;FETX"!#4U,`3&%R9VAE
M>GIA(&1E;"!M96YU(&1I("5S('-U;&QA('-I;FES=')A("AA=G+@(&5F9F5T
M=&\@8V]L('!R;W-S:6UO(&%C8V5S<V\I.@!,87)G:&5Z>F$@9&5L;&$@=&%B
M96QL80!5;FETX"!D:2!L87)G:&5Z>F$`3&%R9VAE>GIA.@!696YT;P!696QO
M8VETX"!D96P@=F5N=&\@:6X@;F]D:0!696YT;SH`5F5N=&\Z(`!386=G97IZ
M80!,879O<F\`26YD:7)I>GIO(&1E;"!L879O<F\`5&5L969O;F\@9&5L(&QA
M=F]R;P!.=6UE<F\@9&D@8V%M<&D@97)R871O(&YE;&QA(&QI;F5A("5D+B!!
M='1E<VD@)60L('1R;W9A=&D@)60N`$YU;65R;R!D:2!C86UP:2!E<G)A=&\N
M($%T=&5S:2`E9"P@=')O=F%T:2`E9"X`0V]M<&5N<V%Z:6]N92!S8F%G;&EA
M=&$@)60@9'5R86YT92!L82!L971T=7)A(&1I('5N(&9I;&4@5D93+@!!;FYU
M86QM96YT90!3:0!3:2P@<V]N;R!D)V%C8V]R9&\`4V5I(&EN(&9O<FUA=&\@
M=&5S=&\N(%5S82!I;"!B;W1T;VYE(%L\/ET@<&5R('1O<FYA<F4@86P@9F]R
M;6%T;R!765-)5UE'+@!.;VX@:&%I(&EL('!E<FUE<W-O(&1I(&-R96%R92!P
M:?D@9&D@)60@8FQO8V-H:2X`3F]N('1I('-E:2!A=71E;G1I8V%T;RX`3F]N
M('!U;VD@879E<F4@:6P@8V%R871T97)E("=<)R!N96P@='5O(&YO;64@8V]M
M<&QE=&\N`$YO;B!H86D@:6YS97)I=&\@=6X@:6YD:7)I>GIO(&5M86EL('9A
M;&ED;RX`3F]N(&AA:2!A<W-O8VEA=&\@;F5S<W5N(&1E:2!C86UP:2!D86P@
M9FEL92!I;7!O<G1A=&\@8V]N(&D@8V%M<&D@8V]R<FES<&]N9&5N=&D@:6X@
M)7,N`%-E:2!S=&%T;R!D:7-C;VYN97-S;RX`1&5V:2!I;G-E<FER92!U;B!N
M=6UE<F\@9&D@8V5L;'5L87)E('9A;&ED;RP@8V]N=&5N96YT92!S;VQO(&YU
M;65R:2!C;VX@;"=O<'II;VYE(&1E;"`G*R<@<&5R(&D@<')E9FES<VD@:6YT
M97)N87II;VYA;&DN`$1E=FD@:6YS97)I<F4@=6X@=F%L;W)E('9A;&ED;RX`
M1&5V:2!C;VYF:6=U<F%R92!U;B!B86-K96YD('!E<B!I;"!$871A5')E92!P
M97(@=7-A<F4@4VEG;G5P<RX`1&5V:2!C;VYF:6=U<F%R92!U;B!B86-K96YD
M(%9&4RX`1&5V:2!P<FEM82!D97-C<FEV97)E(&EL('!R;V)L96UA('!R:6UA
M(&1I(&UA;F1A<FQO(&-O;64@<F5P;W)T+@!$979I(&EN<V5R:7)E(&PG55),
M(&%L;&$@<75A;&4@<'5N=&$@<75E<W1O(&-O;&QE9V%M96YT;P!$979I('-E
M;&5Z:6]N87)E('5N('-E<G9E<B!D82!E;&EM:6YA<F4N`$1E=FD@<W!E8VEF
M:6-A<F4@=6X@=71E;G1E(&1A(&%Z>F5R87)E+@!$979I('-P96-I9FEC87)E
M('5N('5T96YT92!D82!R:6UU;W9E<F4N`$1E=FD@<W!E8VEF:6-A<F4@=6X@
M=71E;G1E(&1A(&%G9VEU;F=E<F4N`$1E=FD@<W!E8VEF:6-A<F4@=6X@=71E
M;G1E(&1A(&%G9VEO<FYA<F4N`$1E=FD@<W!E8VEF:6-A<F4@=6XG87II;VYE
M(&1A(&5S96=U:7)E+@!$979I('-P96-I9FEC87)E(&EL(&YO;64@9&5L;&$@
M;G5O=F$@8V%T96=O<FEA+@!$979I(&EN<V5R:7)E('5N(&YU;65R;R!D:2!T
M96QE9F]N;R!I=&%L:6%N;P!,82!T=6$@<V5S<VEO;F4@)7,@Z"!S8V%D=71A
M+B!3:2!P<F5G82!D:2!C;VQL96=A<G-I(&YU;W9A;65N=&4N`$EL('1U;R!I
M;F1I<FEZ>F\@16UA:6P`26P@8V%M<&\@1&$Z(&1E;"!T=6\@:6YD:7)I>GIO
M.@!,92!T=64@:6YF;W)M87II;VYI`$EL('1U;R!I;F1I<FEZ>F\@26YT97)N
M970@Z"!C86UB:6%T;R!D86QL)VEN:7II;R!D96QL82!T=6$@<V5S<VEO;F4@
M)7,N(%!E<B!P<F]T96=G97)E(&QA('1U82!S:6-U<F5Z>F$L(&1E=FD@<FEC
M;VQE9V%R=&D@;G5O=F%M96YT92X`26P@='5O($YO;64`26P@='5O(&)A8VME
M;F0@9&D@875T96YT:6-A>FEO;F4@;F]N('-U<'!O<G1A(&PG86=G:75N=&$@
M9&D@;G5O=FD@=71E;G1I+B!392!V=6]I('5S87)E($AO<F1E('!E<B!G97-T
M:7)E(&=L:2!U=&5N=&DL(&1E=FD@=7-A<F4@=6X@8F%C:V5N9"!D:2!A=71E
M;G1I8V%Z:6]N92!D:69F97)E;G1E`$EL('1U;R!B86-K96YD(&1I(&%U=&5N
M=&EC87II;VYE(&YO;B!S=7!P;W)T82!L)V5L96YC;R!D96=L:2!U=&5N=&DL
M(&\@;&$@9G5N>FEO;F4@Z"!S=&%T82!D:7-A8FEL:71A=&$@<&5R(&%L=')E
M(')A9VEO;FDN`%-E;6)F<F$@8VAE(&EL('1U;R!B<F]W<V5R('-I82!C86UB
M:6%T82!D86QL)VEN:7II;R!D96QL82!T=6$@<V5S<VEO;F4@)7,N(%!E<B!P
M<F]T96=G97)E(&QA('1U82!S:6-U<F5Z>F$L(&1E=FD@86-C961E<F4@;G5O
M=F%M96YT92X`26P@='5O(&)R;W=S97(@;F]N('-U<'!O<G1A('%U97-T82!F
M=6YZ:6]N92X`26P@='5O(&)R;W=S97(@;F]N('-U<'!O<G1A('%U97-T82!O
M<'II;VYE(&1I('-T86UP82X@4')E;6D@0V]N=')O;"]#;VUM86YD("L@4"!P
M97(@<W1A;7!A<F4N`$EL('1U;R!F=7-O(&]R87)I;SH`3&$@='5A(&ED96YT
M:73@(&1I(&1E9F%U;'0@Z"!S=&%T82!M;V1I9FEC871A+@!,82!T=6$@:61E
M;G1I=.`@9&D@9&5F875L=#H`26P@='5O(&YO;64@8V]M<&QE=&\Z`$QA('1U
M82!L;V=I;B#H('-C861U=&$N`$QA('1U82!N=6]V82!P87-S=V]R9"!P97(@
M)7,@Z#H@)7,`3&4@='5E(&]P>FEO;FD@<V]N;R!S=&%T92!A9V=I;W)N871E
M('!E<B!L82!D=7)A=&$@9&D@<75E<W1A('-E<W-I;VYE+@!,92!T=64@;W!Z
M:6]N:2!S;VYO('-T871E(&%G9VEO<FYA=&4N`$QA('1U82!P87-S=V]R9"#H
M('-T871A(&%Z>F5R871A`$QA('1U82!P87-S=V]R9"#H('-T871A(&%Z>F5R
M871A+"!C;VYT<F]L;&$@;&$@='5A(&5M86EL(&4@86-C961I(&-O;B!L82!T
M=6$@;G5O=F$@<&%S<W=O<F0N`$QA('1U82!P87-S=V]R9"#H('-C861U=&$N
M`$D@='5O:2!S97)V97(@<F5M;W1I.@!;3F%S8V]N9&D@:6P@=&5S=&\@8VET
M871O70!;4F5P;W)T(&1E;"!P<F]B;&5M85T`6TUO<W1R82!I;"!T97-T;R!C
M:71A=&\@+0!;36]S=')A(&EL('1E<W1O(&-I=&%T;R`M("5S(&QI;F5E70!;
M;&EN96$@)7,@9&D@)7-=`%]!;6UI;FES=')A>FEO;F4`7T-A;F-E;&QA(%)I
M9V$`7T=R=7!P:0!?06EU=&\`<')O<')I973@(&1E;&PG7TEM;6%G:6YE+BXN
M`%]%;G1R80!?17-C:0!?36]D:69I8V$@0V]L;&5G86UE;G1O+BXN`%]/<'II
M;VYI`%]097)M97-S:0!?16QI;6EN82!#;VQL96=A;65N=&\N+BX`7TEM<&]S
M=&%Z:6]N90!0<F]P<FEE=.`@9&5L;&$@7U1A8F5L;&$N+BX`571E;G1I`')U
M8G)I8V$`:6YD:7)I>GII('-C;VYO<V-I=71I`&-A;&5N9&%R:6\`8V%L;6\`
M;F]N('!O<W-O(&-R96%R92!I;"!F:6QE(&1I(&]U<'5T`&YO;B!P;W-S;R!A
M<')I<F4@;"=I;G!U=`!P<F5M:2!Q=6D`97)R;W)E(&YE;&PG=7-O(&1E;&QA
M(&QI;F5A(&1I(&-O;6%N9&\`97)R;W)E(&1I(&-O;F9I9W5R87II;VYE`&5R
M<F]R92!N96P@9F]R;6%T;R!D96QL82!D871A`'9I<W5A;&EZ>F$@<')E=FES
M:6]N92`H=&%F*0!P=6)B;&EC80!E;G1R>2!N;VX@=')O=F%T80!D86P@)7,@
M*"5S*2!A;"`E<R`E<P!N;VUE(&AO<W0@<V-O;F]S8VEU=&\`:6UM961I871O
M`&5R<F]R92!D:2!I;G!U="]O=71P=70`97)R;W)E(&EN=&5R;F\@9&5L('-O
M9G1W87)E`&QI;F5E70!E<G)O<F4@9&D@8V]D:6-E("5D(&1I(&UK:7-O9G,@
M9'5R86YT92!L82!S8W)I='1O<F$@25-/+@!N;VUE`&YO;B!I;7!L96UE;G1A
M=&\`;F]N(&%N8V]R82!I;7!L96UE;G1A9&\`8FQO8V-O(&YO=&4`<&5R8V5N
M=&\`<&5R;65S<V\@;F5G871O`&5R<F]R92!R96UO=&\@;F5L('!R;W1O8V]L
M;&\`<V5R=FEZ:6\@;F]N(&1I<W!O;FEB:6QE`&UO<W1R82!L92!D:69F97)E
M;GIE`&-O<W1A;G1E`&5R<F]R92!D:2!S:7-T96UA`&5L96YC;R!A='1I=FET
MX`!G=6%S=&\@=&5M<&]R86YE;P!S8W)I=FD@;&$@<&%S<W=O<F0@9'5E('9O
M;'1E('!E<B!C;VYF97)M87)E`'5N:69I8V%T;P!S96YZ82!N;VUE`'5T96YT
M92!S96QE>FEO;F%T;P!W.@!W96%T:&5R+F-O;0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]I<U])4R],0U]-
M15-304=%4P``````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$T,2`P,C$U,#0`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+VES7TE3+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$S-S4Q(#$P-3$U-#,T,30Q(#`R,S(S,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M`'<````<````U`,``*,```",!P```````!@*```,````&0H```,````F"@``
M'P```"H*```%````2@H```8```!0"@``!````%<*```6````7`H```8```!S
M"@``!@```'H*```9````@0H``!0```";"@``!````+`*```&````M0H``"@`
M``"\"@``!````.4*```(````Z@H``!````#S"@``!@````0+```/````"PL`
M``@````;"P``"P```"0+```$````,`L```T````U"P``!0```$,+```0````
M20L``!````!:"P``#P```&L+```/````>PL```P```"+"P``"````)@+```'
M````H0L```0```"I"P``!````*X+```0````LPL```<```#$"P``!````,P+
M```$````T0L```@```#6"P``#0```-\+```.````[0L``!8```#\"P``$0``
M`!,,```&````)0P```8````L#```!P```#,,```$````.PP```<```!`#```
M"0```$@,```&````4@P```<```!9#```"P```&$,```$````;0P```8```!R
M#```"````'D,```(````@@P```0```"+#```!0```)`,```&````E@P``!``
M``"=#```"@```*X,```#````N0P``"0```"]#```!P```.(,```&````Z@P`
M`!\```#Q#```!@```!$-```-````&`T```(````F#0``"@```"D-```&````
M-`T```8````[#0``"0```$(-```'````3`T```0```!4#0``!0```%D-```$
M````7PT```(```!D#0``!````&<-```(````;`T```(```!U#0``!P```'@-
M```'````@`T```@```"(#0``%````)$-```I````I@T```4```#0#0``!@``
M`-8-```?````W0T```D```#]#0``!`````<.```'````#`X```<````4#@``
M!````!P.```C````(0X``"\```!%#@``(0```'4.```<````EPX```(```"T
M#@``!P```+<.```,````OPX```@```#,#@``!P```-4.```'````W0X```T`
M``#E#@```P```/,.```P````]PX``!,````H#P``$````#P/``!3````30\`
M`!<```"A#P``%@```+D/```/````T`\``!\```#@#P``!0`````0```(````
M!A````@````/$```!````!@0```&````'1```%L!```D$```"P```(`1```*
M````C!$``!8```"7$0``!0```*X1```%````M!$```0```"Z$0``%@```+\1
M```)````UA$```8```#@$0``&P```.<1```1`````Q(```4````5$@``!P``
M`!L2```X````(Q(```0```!<$@``"````&$2```4````:A(```0```!_$@``
M$````(02```6````E1(``!D```"L$@``!@```,82```'````S1(```4```#5
M$@``$````-L2```0````[!(``!4```#]$@``$0```!,3```/````)1,```<`
M```U$P``!````#T3```#````0A,```4```!&$P``"@```$P3```&````5Q,`
M``0```!>$P``!````&,3```(````:!,```\```!Q$P``$0```($3```8````
MDQ,``!4```"L$P``"````,(3```+````RQ,```<```#7$P``!P```-\3```'
M````YQ,```<```#O$P``"````/<3```&`````!0``!4````'%```"0```!T4
M```&````)Q0```@````N%```#@```#<4```$````1A0```0```!+%```!P``
M`%`4```-````6!0```D```!F%````P```'`4```F````=!0```8```";%```
M!@```*(4```*````J10```8```"T%```"````+L4```"````Q!0```L```#'
M%```!@```-,4```&````VA0```P```#A%```"@```.X4```$````^10```8`
M``#^%```!0````45```#````"Q4```4````/%0``"````!45```&````'A4`
M``<````E%0``#0```"T5```(````.Q4``!8```!$%0``(0```%L5```*````
M?14```4```"(%0``&@```(X5```)````J14```4```"S%0``!````+D5```)
M````OA4```4```#(%0``'@```,X5```Q````[14``",````?%@``(````$,6
M```#````9!8```8```!H%@``$0```&\6```+````@18```<```"-%@``!P``
M`)46```0````G18```(```"N%@``+P```+$6```;````X18```L```#]%@``
M50````D7```4````7Q<``!8```!T%P``$````(L7```F````G!<```4```##
M%P``!@```,D7```)````T!<```4```#:%P``"````.`7```!````!@``````
M``!7````80```"@`````````9```````````````/0```"D`````````30``
M`$H```!N`````````"\````0````-@````X```!G````"@```"X````_````
M`@`````````1````40```%P````T````(@```#X```!+````:@```$(````P
M````'@````@```!%`````````#<``````````````'8`````````"P```'0`
M```,`````````$@````Q`````````&P`````````3@`````````#````8```
M`&@`````````&````&T```!$`````````$,`````````9@```%D`````````
M!0`````````5````4`````````!E````(0````````!`````(P```!,`````
M````=0```#D```!>````4P```%4````U`````````$$`````````&0```%@`
M``!S````20```!8```````````````````!K`````````#H````=````)```
M```````````````````````K````+0```%8`````````$@```%(````-````
M&P```!P`````````+`````````!,`````````'<````J````6P```$8```!B
M````:0```"`````E````3P````0````S````/````$<```!P`````````%\`
M``!:````#P````<``````````````!H```!O````)P````````!=````.```
M`!0````R````8P`````````F````<@````D````?````%P```#L`````````
M<0```%0``````````$%D9')E<W,@0F]O:P!!;&P`06X@:6QL96=A;"!V86QU
M92!W87,@<W!E8VEF:65D+@!!<')I;`!!=6=U<W0`0F]T:`!"=6EL9&EN9R!L
M;V-A;&4@)7,N+BX@`$-A;F-E;`!#:&%N9V4`0VQE86YI;F<@=7`@;&]C86QE
M("5S+BXN(`!#;VUP;W-E($UE<W-A9V4@*"5S*0!#;W!Y`$-R96%T90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$1A=&4`1&5C
M96UB97(`1&5F875L="!)9&5N=&ET>0!$96QE=&4`1&ES<&QA>2!/<'1I;VYS
M`$1O=VYL;V%D`$1O=VYL;V%D("5S`$5D:70`16UA:6P@061D<F5S<P!%<G)O
M<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M
M:6YU=&5S`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`1F5B<G5A<GD`
M1FEL=&5R<P!&<F]M`$AE;'``261E;G1I='DG<R!N86UE.@!*86YU87)Y`$IU
M;'D`2G5N90!,86YG=6%G90!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S
M`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T
M=FEA`$QA>6]U=`!,96)A;F]N`$QE9G0`3&EB97)I80!,:71H=6%N:6$`3&]G
M(&EN`$QO9R!O=70`3&]G:6X@5&%S:W,`36%I;`!-86QA=VD`36%L87ES:6$`
M36%L9&EV97,`36%L:0!-87)C:`!-87)G:6X`36%R<VAA;&P@27-L86YD<P!-
M875R:71A;FEA`$UA>0!-97)G:6YG('1R86YS;&%T:6]N(&9O<B!M;V1U;&4@
M)7,N+BX`365S<V%G90!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T
M871E<R!O9@!-:7)R;W(`36ES8V5L;&%N96]U<P!-;P!-;V1I9GD@55),`$UO
M9'5L90!-;VYA8V\`36]V92!$;W=N`$UO=F4@57``3F%M90!.979E<@!.97AT
M`$YO`$YO;F4`3F]V96UB97(`3TL`3V-T;V)E<@!/<'1I;VYS`%!A<W-W;W)D
M`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%)E<V5T`%-E87)C:`!396QE8W0@>6]U<B!P
M<F5F97)R960@;&%N9W5A9V4Z`%-E<'1E;6)E<@!3:7IE`%-U8FIE8W0`4W5C
M8V5S<P!497AT`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P
M87)T`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1O`%5N;F%M960`57-E<B!/<'1I;VYS
M`%5S97)N86UE`%9I97<@)7,`5V%R;FEN9P!796QC;VUE('1O("5S`%EE<P!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@
M8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0
M<F5S<R!#;VYT<F]L+T]P=&EO;B`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N
M="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL
M(&YA;64Z`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`7TAE;'``
M7TQO9R!O=70`7T]P=&EO;G,`9&]N90!F86EL960`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C`N-0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI
M<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P,BTP,2TQ,"`Q
M.3HP,"LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#4M,3$M,3D@,C`Z,S,K
M,#`P,`I,87-T+51R86YS;&%T;W(Z($)J;W)N($1A=FED<W-O;B`\8FIO<W-I
M0'-N97)P82YI<SX*3&%N9W5A9V4M5&5A;3H@26-E;&%N9&EC(#QS=7!P;W)T
M0'-N97)P82YI<SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T
M97AT+W!L86EN.R!C:&%R<V5T/6ES;RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E
M<BU%;F-O9&EN9SH@.&)I=`H`3F5T9F%N9V%B\VL`UFQL('-K97ET:0#3=.9K
M="!G:6QD:2!T:6QG<F5I;G0N`&%P<NUL`.%G^G-T`$+F\&D`0GEG9VD@;OH@
M;&]C86QE("5S("XN+@!(YG1T82!V:?``0G)E>71A`$AR96EN<V$@=&EL(.T@
M;&]C86QE("5S("XN+@!396UJ82!S:V5Y=&D@*"5S*0!!9G)I=`!"^F$@=&EL
M`%-T:6QL82!A\&=E<O!I<B!S96T@97)U(&9R86UK=N9M9&%R(/YE9V%R(/[Z
M('1E;F=I<W0@)7,N`$1A9W,`9&5S96UB97(`4VKA;&9G969I\"!K96YN:6UA
M<FL`17GP80#:=&QI='-S=&EL;&EN9V%R`%/F:VIA('EF:7(@X2!V:6YN=7-T
M]O``4^9K:F$@)7,@>69I<B#A('9I;FYU<W3V\`!"<F5Y=&$`3F5T9F%N9P!6
M:6QL80#!(&MO<G1E<G,@9G)E<W1I`,$@,S`@<V5K+B!F<F5S=&D`P2!F:6UM
M(&WM;OIT;F$@9G)E<W1I`,$@:.%L9G3M;6$@9G)E<W1I`,$@;>UN^G1U(&9R
M97-T:0!F96)R^F%R`%/M=7(`1G+A`$AJX6QP`$ME;FYI;F%F;CH`:F%N^F%R
M`&KZ;.T`:OIN[0!4=6YG=6WA;`!S[?!A<W0@=7!P9N9R=#H`4^WP87-T('1E
M;F=S=#H@)7,`4^WP87-T('1E;F=S=#H@)7,@9G+A("5S`%/M\&%S="!T96YG
M<W0Z($%L9')E:0!,971T;&%N9`!&<F%M<V5T;FEN9P!,[6)A;F]N`%9I;G-T
M<FD`3.UB97+M80!,:71HX65N`%1E;F=J87-T`-IT<VMRX0!697)K969N:2!V
M:?`@=&5N9VEN9W4`5F5F</-S='5R`$UA;&%V[0!-86QA[7/M80!'<N9N:/9F
M\&%E>6IA<@!-86SM`&UA<G,`4W#A<W/M80!-87)S:&%L;&5Y:F%R`$WA<NUT
M86[M80!M8>T`4V%M96EN82#^_?!I;F=A<B!F>7)I<B`E<R!E:6YI;F=U;F$N
M+BX`4VME>71I`$UE>.UK\P!-[6MR\VYE<^UA`%-P96=L80#=;6ES;&5G=`!-
MX0!"<F5Y=&$@<VSS\`!%:6YI;F<`3?-N86OS`$9L>71J82!N:?!U<@!&;'ET
M:F$@=7!P`$YA9FX`06QD<F5I`$[F<W1A`$YE:0!%;F=I;@!N\W9E;6)E<@#-
M(&QA9VD`;VMT\V)E<@!686QS=&EL;&EN9V%R`$QY:VEL;W+P`%5P<&S]<VEN
M9V%R('5M(&YO=&%N9&$`4VSA\'4@:6YN(&YO=&%N9&%N869N(&]G(&QY:VQI
M;W+P`$5N9'5R<V5T:F$`3&5I=&$`5F5L9'4@<VKA;&9G969I\"!T=6YG=6WA
M;#H`<V5P=&5M8F5R`%-TYG+P`$5F;FD`1G)A;6MVYFUT`%1E>'1I`$ME;FYI
M;G4@(B5S(B!H969U<B!V97)I\"!E>71T+@!6:6QL82!K;VT@=7!P('9I\"!B
M:7)T:6YG=2#^97-S82!H;'5T82!S:V5Y=&ES:6YS`%1A;&%N('9E<O!U<B!A
M\"!V97)A(&'P(&SA9VUA<FMI(#$N`-YE='1A(&=I;&1I('9E<O!U<B!A\"!V
M97)A('1A;&$N`%1I;`#3;F5F;G0`5F%L:V]S=&ER(&YO=&%N9&$`3F]T86YD
M86YA9FX`4_UN82`E<P!!\';V<G5N`%9E;&MO;6EN*&XI(.T@)7,`2N$`3&]T
M86X@)7,@97(@<G5N;FEN(/IT(.$@=.UM82X@5&5N9V1U(/YI9R!A9G1U<BX`
M1G5L;'0@;F5T9F%N9R#^:71T("A&<N$Z*2`Z`%5P<&S]<VEN9V%R`%9E9G-K
M;_!A<FD@_FEN;B!S='GP=7(@96MK:2#^97-S82!P<F5N=&'P9V5R\"X@3F]T
M8?!U($-44DPO3W!T:6]N(&]G(%`@=&EL(&'P('!R96YT82X`3OIV97)A;F1I
M('3M;6%B96QT:3H`4VKA;&9G969I\"!K96YN:2#^:71T.@!&=6QL="!N869N
M(/YI='0Z`%-T:6QL:6YG87(@_NUN87(@:&%F82!V97)I\"!U<'!FYG+P87(N
M`$AJX6QP`-IT<VMRX0!686QK;W-T:7(`;&]K:?``:VQI:VMA\&D`````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O:F%?2E`O3$-?34534T%'15,`````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#8Q`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]J85]*4"]H96QP+GAM;```````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S,R,"`Q,#4Q-30S-#$T
M,2`P,C$T,C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA+2T@)$AO<F1E.B!H;W)D
M92]L;V-A;&4O:F%?2E`O:&5L<"YX;6PL=B`Q+C(@,C`P-"\P-2\R-R`R,#HR
M,CHQ-"!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R
M>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R=&%L(%!A9V4\+W1I=&QE
M/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P<F]V:61E<R!A('%U:6-K
M('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT"B`@:6YF;W)M871I;VXN
M($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO=R!M86YY(&YE=R!E+6UA
M:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R($E.0D]8+"!U<&-O;6EN
M9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S:W,@;VX@>6]U<B!T;RUD
M;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C=&5D(&YE=W,@<V5R=FEC
M97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*("!S=6UM87)I97,@=VEL
M;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C;VUM;VX@9G5N8W1I;VYS
M+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA:6P@;65S<V%G92P@8W)E
M871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@=&%S:RP@971C+@H@/"]P
M87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F('1H:7,@<&]R=&%L('!A
M9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA>6]U="!B=71T;VXN"B`@
M1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H:6-H(&ET96US('1O(&EN
M8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@('=E;&P@87,@:6X@=VAI
M8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A<F$^"CPO96YT<GD^"B`@
M/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B/@H\=&ET;&4^5&AE($%P
M<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L93X*(#QP87)A/@H@($%T
M('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B('!A9V4@:7,@=&AE(&%P
M<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L:6-K(&]N('1H92!I8V]N
M<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U:6-K;'D@86YD(&5A<VEL
M>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B;&4@87!P;&EC871I;VYS
M+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M9&]?;6%I
M;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S
M.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A
M<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@8F]X+@H@("`@
M/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M8V]N9FER;5]M
M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\=&ET;&4^4')E9F5R96YC
M97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT96YA;F-E/"]T:71L93X*
M("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI:V4@=&\@8V]N9FER;2!A
M;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H97D@87)E(')U;BP@8VAE
M8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D+"!A;&P@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@<G5N('=I;&P@8F4@<&5R
M9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C:&%N8V4@=&\@8V%N8V5L
M(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L;V-A;&4O:F%?2E`O3$-?34534T%'15,O:&]R9&4N;6\`````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`S,3`Q-S<@,3`U,34T,S0Q-#$@,#(S
M,C`W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-X2!)4`````J04``!P```!D+0``C0<``*Q:````````X'@```X```#A>```
M#P```/!X```-`````'D```@````.>0``"P```!=Y```,````(WD``!@````P
M>0``&P```$EY```M````97D``!T```"3>0``)````+%Y```I````UGD``!D`
M````>@``)@```!IZ```,````07H``"0```!.>@``"P```'-Z```.````?WH`
M``4```".>@``*````)1Z```(````O7H```H```#&>@``%0```-%Z```2````
MYWH``(4```#Z>@``#@```(![```*````CWL```T```":>P``#@```*A[```1
M````MWL```T```#)>P``#````-=[```-````Y'L```8```#R>P``E````/E[
M```,````CGP```X```";?```#@```*I\```(````N7P```D```#"?```+@``
M`,Q\```:````^WP``#(````6?0``.````$E]``!4````@GT``%$```#7?0``
M6@```"E^``!7````A'X``#0```#<?@``!0```!%_```1````%W\``"4````I
M?P``(````$]_```3````<'\``!````"$?P``#P```)5_```*````I7\```,`
M``"P?P``#P```+1_```4````Q'\```D```#9?P``#0```.-_```2````\7\`
M`!D````$@```'@```!Z````/````/8````H```!-@```#P```%B````(````
M:(```"0```!Q@```%````):````6````JX````@```#"@```3@```,N````M
M````&H$``!D```!(@0``!P```&*!```,````:H$``"P```!W@0``#@```*2!
M```#````LX$```L```"W@0``!P```,.!```'````RX$```4```#3@0``"@``
M`-F!```#````Y($``!<```#H@0``"@````""```/````"X(``!@````;@@``
M(P```#2"```.````6((``!0```!G@@``%P```'R"```7````E((``!<```"L
M@@``$P```,2"```/````V((```X```#H@@``'P```/>"```=````%X,```<`
M```U@P``!@```#V#```(````1(,```\```!-@P``!@```%V#```*````9(,`
M`!,```!O@P``"P```(.#```0````CX,``!4```"@@P``%0```+:#```'````
MS(,``!````#4@P``!0```.6#```1````ZX,```P```#]@P``.P````J$```X
M````1H0```D```!_A```!P```(F$```%````D80``!````"7A```$P```*B$
M```Y````O(0``"<```#VA```+````!Z%```J````2X4``"4```!VA0``"@``
M`)R%```&````IX4```D```"NA0``!P```+B%```O````P(4``#<```#PA0``
M+@```"B&``!5````5X8``"T```"MA@``+0```-N&```]````"8<``#\```!'
MAP``+0```(>'``!`````M8<``",```#VAP``(P```!J(``!`````/H@``"T`
M``!_B```,P```*V(```E````X8@``!4````'B0``&0```!V)```I````-XD`
M`"0```!AB0``*````(:)```1````KXD```H```#!B0``"@```,R)```0````
MUXD``!8```#HB0``%@```/^)```'````%HH```<````>B@``"@```":*```(
M````,8H``"<````ZB@``"````&**```'````:XH```<```!SB@``!@```'N*
M```%````@HH```<```"(B@``!@```)"*```(````EXH``"D```"@B@``#@``
M`,J*```*````V8H```0```#DB@``!P```.F*```)````\8H```8```#[B@``
M$0````*+```'````%(L``!8````<BP``"````#.+```-````/(L```8```!*
MBP``'@```%&+```1````<(L```@```""BP``#0```(N+```,````F8L```<`
M``"FBP```P```*Z+```#````LHL``!<```"VBP``$P```,Z+```=````XHL`
M``@`````C```"`````F,```(````$HP``$$````;C```&@```%V,```K````
M>(P``"````"DC```%0```,6,```&````VXP```8```#BC```%0```.F,```8
M````_XP``"(````8C0``+@```#N-```=````:HT``"$```"(C0``5````*J-
M```I````_XT```H````IC@``!P```#2.```'````/(X``!4```!$C@``#@``
M`%J.```*````:8X```\```!TC@``#0```(2.```/````DHX```T```"BC@``
M"0```+".```&````NHX``!@```#!C@``$P```-J.```1````[HX``!0`````
MCP``!````!6/```&````&H\``!0````ACP``5````#:/``!D````BX\```X`
M``#PCP``!0```/^/```%````!9```!,````+D```$0```!^0```1````,9``
M`!P```!#D```$````&"0```A````<9```!,```"3D```"P```*>0```2````
MLY````H```#&D```#P```-&0```1````X9````P```#SD```%P````"1```0
M````&)$```@````ID0``!0```#*1```,````.)$``!````!%D0``!0```%:1
M```-````7)$```8```!JD0``!P```'&1```-````>9$```<```"'D0``"P``
M`(^1```'````FY$```<```"CD0``&0```*N1```]````Q9$``!T````#D@``
M#````"&2```0````+I(```4````_D@``)0```$62```2````:Y(``!,```!^
MD@``*P```)*2```[````OI(``"````#ZD@``"````!N3```V````)),``"$`
M``!;DP``$````'V3```(````CI,```P```"7DP``!````*23```/````J9,`
M``X```"YDP``"@```,B3```-````TY,``!\```#ADP``'`````&4```A````
M'I0``!X```!`E```&0```%^4```>````>90``!L```"8E```(0```+24```N
M````UI0``"8````%E0``'````"R5```>````294``!P```!HE0``)@```(65
M```K````K)4``#,```#8E0``)@````R6```K````,Y8``#@```!?E@``'0``
M`)B6```5````MI8``"\```#,E@``(````/R6```2````'9<``"D````PEP``
M'@```%J7```@````>9<``!(```":EP``H@```*V7```6````4)@``",```!G
MF```*````(N8```I````M)@``"@```#>F```'P````>9```5````)YD``"``
M```]F0``)0```%Z9```H````A)D``"T```"MF0``,````-N9``"2````#)H`
M`"$```"?F@``%@```,&:```<````V)H``"8```#UF@``*@```!R;``!!````
M1YL```<```")FP``!@```)&;```0````F)L``!(```"IFP``$P```+R;```2
M````T)L```<```#CFP``!````.N;```0````\)L```P````!G```#@````Z<
M```-````'9P``"@````KG````P```%2<```-````6)P```8```!FG```#@``
M`&V<```"````?)P```4```!_G```$````(6<```/````EIP```0```"FG```
M#0```*N<```.````N9P```X```#(G```"````-><```/````X)P```\```#P
MG```!P````"=```-````")T``!`````6G0``#0```">=```&````-9T```L`
M```\G0``#````$B=```*````59T``!$```!@G0``"P```'*=```-````?IT`
M`"(```",G0``#P```*^=```;````OYT``#0```#;G0``"@```!">```8````
M&YX``!(````TG@``&0```$>>```6````89X``"(```!XG@``#0```)N>```'
M````J9X``!0```"QG@``"P```,:>```B````TIX``"\```#UG@``"P```"6?
M```7````,9\``!<```!)GP``%@```&&?```/````>)\```@```"(GP``#0``
M`)&?```F````GY\``$,```#&GP``"`````J@```2````$Z```!\````FH```
M"````$:@```+````3Z```"\```!;H```!@```(N@```'````DJ````0```":
MH```"@```)^@```*````JJ````\```"UH```$````,6@```7````UJ```!$`
M``#NH```&0````"A```7````&J$```4````RH0``"P```#BA```%````1*$`
M``T```!*H0``&P```%BA```7````=*$```X```",H0``#0```)NA```2````
MJ:$``#@```"\H0``(````/6A```.````%J(``'L````EH@``&````*&B```1
M````NJ(```<```#,H@``!0```-2B```8````VJ(``!L```#SH@``&0````^C
M```;````*:,``!D```!%HP``$P```%^C```'````<Z,```@```![HP``!@``
M`(2C```0````BZ,```\```"<HP``$````*RC```/````O:,```L```#-HP``
M#P```-FC```,````Z:,```\```#VHP``!P````:D```&````#J0```X````5
MI```#````"2D```/````,:0```@```!!I```"````$JD```3````4Z0``!X`
M``!GI```(0```(:D```@````J*0``!D```#)I```%P```..D```E````^Z0`
M`!<````AI0``%@```#FE```;````4*4```T```!LI0``#````'JE```#````
MAZ4```4```"+I0``"````)&E```$````FJ4```0```"?I0``$P```*2E```4
M````N*4```P```#-I0``"0```-JE```.````Y*4```L```#SI0``&P```/^E
M```'````&Z8```<````CI@``#0```"NF```8````.:8```H```!2I@``)@``
M`%VF```5````A*8```4```":I@``!@```*"F```"````IZ8```8```"JI@``
M!@```+&F```4````N*8```T```#-I@``$````-NF```;````[*8``!`````(
MIP``"0```!FG```)````(Z<```4````MIP``&@```#.G```(````3J<```8`
M``!7IP``&0```%ZG```.````>*<```<```"'IP``!P```(^G```%````EZ<`
M``D```"=IP``"@```*>G```.````LJ<```L```#!IP``#0```,VG```&````
MVZ<```D```#BIP``!P```.RG```4````]*<``!T````)J```0@```">H```E
M````:J@``"4```"0J```!@```+:H```*````O:@```0```#(J```"0```,VH
M```(````UZ@``!$```#@J```"0```/*H```&````_*@```T````#J0``!@``
M`!&I```>````&*D```4````WJ0``#@```#VI```&````3*D```<```!3J0``
M(0```%NI```&````?:D```0```"$J0``"@```(FI```%````E*D``!T```":
MJ0``!````+BI```,````O:D```X```#*J0``"@```-FI```(````Y*D```D`
M``#MJ0``!0```/>I```Z````_:D``#`````XJ@``-0```&FJ```I````GZH`
M`$<```#)J@``.````!&K```I````2JL``#\```!TJP``+@```+2K```M````
MXZL``!\````1K```#P```#&L```I````0:P``"0```!KK```)@```)"L```'
M````MZP``"````"_K```(````."L```F`````:T```H````HK0``&0```#.M
M```I````3:T``!8```!WK0``!P```(ZM```*````EJT```P```"AK0``#P``
M`*ZM```0````OJT``$````#/K0``<````!"N```.````@:X```D```"0K@``
M"@```)JN```&````I:X```\```"LK@``$@```+RN```0````SZX``!P```#@
MK@``(P```/VN``!J````(:\```\```",KP``!0```)RO```0````HJ\```D`
M``"SKP``!````+VO```+````PJ\``!0```#.KP``#````..O```,````\*\`
M``\```#]KP``%0````VP```I````([```"H```!-L```)@```'BP```G````
MG[```"D```#'L```*@```/&P```9````'+$``$(````VL0``$0```'FQ```2
M````B[$``!,```">L0``%````+*Q```/````Q[$``!8```#7L0``%P```.ZQ
M```0````!K(``!$````7L@``-````"FR```3````7K(``!(```!RL@``-0``
M`(6R```4````N[(``!````#0L@``%````.&R```7````]K(``!P````.LP``
M%````"NS```:````0+,``!H```!;LP``$P```':S```5````BK,``!$```"@
MLP``%P```+*S```4````RK,``!<```#?LP``%0```/>S```0````#;0``!D`
M```>M```!````#BT```'````/;0```L```!%M```!@```%&T```&````6+0`
M``8```!?M```!0```&:T```'````;+0```<```!TM```!0```'RT```&````
M@K0```8```")M```!````)"T```$````E;0```<```":M```#@```**T```,
M````L;0```P```"^M```#0```,NT```*````V;0```X```#DM```!0```/.T
M```H````^;0```P````BM0``#P```"^U```*````/[4```@```!*M0``*P``
M`%.U```(````?[4``"8```"(M0``$@```*^U```&````PK4```H```#)M0``
M!P```-2U```(````W+4``"````#EM0``#`````:V```.````$[8``!8````B
MM@``$0```#FV```&````2[8```8```!2M@``!P```%FV```$````8;8```<`
M``!FM@``!P```&ZV```6````=K8```T```"-M@``!````)NV```Z````H+8`
M``X```#;M@``$````.JV```+````^[8``!L````'MP``&````".W```:````
M/+<```D```!7MP``"@```&&W```,````;+<```\```!YMP``"````(FW```&
M````DK<```<```"9MP``!0```*&W```+````I[<``$<```"SMP``#0```/NW
M```3````";@``!,````=N```$P```#&X```*````1;@```(```!0N```)0``
M`%.X```%````>;@``"H```!_N```"@```*JX```$````M;@```8```"ZN```
M"````,&X```(````RK@```0```#3N```!0```-BX``!H````WK@```4```!'
MN0``$````$VY```*````7KD```\```!IN0``"@```'FY```)````A+D```,`
M``".N0``!P```)*Y```'````FKD```H```"BN0``"P```*VY```'````N;D`
M`%$```#!N0``!@```!.Z```:````&KH```8````UN@``'P```#RZ```)````
M7+H``"(```!FN@``5P```(FZ```3````X;H``",```#UN@``$P```!F[```"
M````+;L```L````PNP``#0```#R[```4````2KL```8```!?NP``"````&:[
M```'````;[L```H```!WNP``"P```(*[```'````CKL```D```"6NP``"0``
M`*"[```*````JKL```<```"UNP``"0```+V[```'````Q[L```H```#/NP``
M"@```-J[```6````Y;L```<```#\NP``$@````2\```$````%[P```<````<
MO```!0```"2\```%````*KP```L````PO```%````#R\```'````4;P```4`
M``!9O```#0```%^\```,````;;P```@```!ZO```%P```(.\```+````F[P`
M``P```"GO```'P```+2\```:````U+P```0```#OO```"@```/2\```$````
M_[P```P````$O0``!0```!&]```)````%[T```4````AO0``!P```">]```$
M````+[T``#@````TO0``"@```&V]```L````>+T``"X```"EO0``,P```-2]
M```S````"+X``#@````\O@``#P```'6^```8````A;X``!````">O@``#P``
M`*^^```5````O[X``!0```#5O@``$@```.J^```4````_;X``"T````2OP``
M+0```$"_```Q````;K\``"X```"@OP``+P```,^_```L````_[\``&(````L
MP```$P```(_````-````H\```!<```"QP```#````,G````A````UL```!H`
M``#XP```"0```!/!``!%````'<$``$$```!CP0``!````*7!```.````JL$`
M`!,```"YP0``&````,W!```&````YL$```D```#MP0``"@```/?!```/````
M`L(``!`````2P@``#@```"/"```%````,L(```@````XP@``!@```$'"```4
M````2,(``!$```!=P@``#@```&_"```X````?L(```(```"WP@``!@```+K"
M```.````P<(```<```#0P@``!@```-C"```,````W\(``!P```#LP@``!```
M``G#```I````#L,``!\````XPP``7````%C#```4````M<,``#X```#*PP``
M!P````G$```.````$<0```P````@Q```#````"W$```3````.L0```H```!.
MQ```'0```%G$```1````=\0``!$```")Q```)````)O$```5````P,0``!(`
M``#6Q```#@```.G$```9````^,0```@````2Q0``"0```!O%```:````)<4`
M``<```!`Q0``"````$C%```%````4<4``!\```!7Q0``!@```'?%```0````
M?L4```@```"/Q0``"````)C%```>````H<4``!(```#`Q0``+````-/%```:
M`````,8```D````;Q@``"@```"7&```5````,,8```4```!&Q@``%````$S&
M```$````8<8``!````!FQ@``!P```'?&```>````?\8``"@```">Q@``"@``
M`,?&```<````TL8``!$```#OQ@``"P````''```:````#<<``!0````HQP``
M!````#W'```+````0L<```4```!.QP``"````%3'```&````7<<``"````!D
MQP``*0```(7'``!!````K\<``"@```#QQP``*0```!K(``!0````1,@```8`
M``"5R```!0```)S(```(````HL@``"X```"KR```-````-K(```'````#\D`
M`"$````7R0``$````#G)```.````2LD```L```!9R0``!P```&7)```3````
M;<D```H```"!R0``%````(S)```/````H<D``#(```"QR0``"P```.3)```.
M````\,D```4```#_R0``!0````7*```%````"\H``!<````1R@``!0```"G*
M```$````+\H``#(````TR@``10```&?*```7````K<H``!X```#%R@``%```
M`.3*```&````^<H```X`````RP``*@````_+```&````.LL```P```!!RP``
M$0```$[+```+````8,L``#8```!LRP``"@```*/+```B````KLL```L```#1
MRP``#P```-W+```R````[<L``#`````@S```,0```%',```M````@\P```4`
M``"QS```#@```+?,```3````QLP```<```#:S```$0```.+,```3````],P`
M`!0````(S0``&````!W-```%````-LT```0````\S0``!P```$'-```*````
M2<T```L```!4S0``#````&#-```.````;<T```X```!\S0``!0```(O-```%
M````D<T``"X```"7S0``)@```,;-```C````[<T```,````1S@``$@```!7.
M```&````*,X``!X````OS@``&````$[.```E````9\X```D```"-S@```P``
M`)?.```'````F\X```(```"CS@``#````*;.```5````L\X```L```#)S@``
M&0```-7.```@````[\X```4````0SP``"@```!;/```5````(<\```P````W
MSP``!````$3/```)````2<\```<```!3SP``#````%O/``!2````:,\``!<`
M``"[SP``)````-//```&````^,\```X```#_SP``#`````[0```-````&]``
M`!4````IT```$@```#_0```/````4M```!0```!BT```"@```'?0``!I````
M@M```!H```#LT```%P````?1```G````']$``!H```!'T0``%P```&+1```;
M````>M$``!D```"6T0``'P```+#1```3````T-$```@```#DT0``!P```.W1
M```)````]=$``!4```#_T0``#0```!72```-````(](```@````QT@``1@``
M`#K2```_````@=(``#<```#!T@``5P```/G2```%````4=,``!\```!7TP``
M"@```'?3```-````@M,``"T```"0TP``!````+[3``!/````P],``"4````3
MU```'P```#G4```=````6=0``"4```!WU```(````)W4```D````OM0``"``
M``#CU```!@````35```Y````"]4```P```!%U0``!P```%+5```)````6M4`
M`!,```!DU0``"0```'C5```$````@M4``!````"'U0``"````)C5```(````
MH=4```\```"JU0``!P```+K5```4````PM4```X```#7U0``#````.;5```L
M````\]4``!,````@U@``'````#36```H````4=8```<```!ZU@``$P```(+6
M```%````EM8``!<```"<U@``"@```+36```,````O]8```D```#,U@``"0``
M`-;6```1````X-8```8```#RU@``#@```/G6```-````"-<```L````6UP``
M`@```"+7```<````)=<```8```!"UP``"0```$G7```'````4]<``"8```!;
MUP``.````(+7```:````N]<``"H```#6UP``.P````'8```H````/=@``#0`
M``!FV```&0```)O8```5````M=@```4```#+V```!P```-'8```(````V=@`
M``<```#BV```#@```.K8```)````^=@```8````#V0``"`````K9```+````
M$]D```<````?V0``"````"?9```'````,-D``!8````XV0``"0```$_9```&
M````6=D```L```!@V0``%````&S9```(````@=D``!````"*V0``$````)O9
M```&````K-D``!D```"SV0``"@```,W9```<````V-D```4```#UV0``$```
M`/O9```8````#-H``!<````EV@``"0```#W:```*````1]H```<```!2V@``
M`@```%K:```(````7=H``",```!FV@``'P```(K:```Q````JMH``"<```#<
MV@``9`````3;``!5````:=L``#@```"_VP``2@```/C;``!;````0]P``"@`
M``"?W```.````,C<```H`````=T``"P````JW0``)@```%?=```;````?MT`
M`#X```":W0``J0$``-G=```C````@]\``$@```"GWP``)0```/#?``!!````
M%N```%L```!8X```20```+3@```Q````_N```"L````PX0``(0```%SA```?
M````?N$``"8```">X0``)P```,7A```S````[>$``"4````AX@``(````$?B
M```?````:.(``#````"(X@``:0```+GB```Q````(^,``$$```!5XP``,P``
M`)?C```E````R^,``#T```#QXP``90```"_D``!-````E>0``"\```#CY```
M+@```!/E```P````0N4``%0```!SY0``6@```,CE``!(````(^8``$H```!L
MY@``,@```+?F```O````ZN8``"P````:YP``+0```$?G```7````=><``"4`
M``"-YP``,@```+/G```I````YN<``#X````0Z```(@```$_H``!2````<N@`
M`"4```#%Z```10```.OH```A````,>D``#````!3Z0``)0```(3I```<````
MJND``#$```#'Z0``!````/GI```-````_ND```L````,Z@``"P```!CJ```%
M````).H``%D````JZ@``$@```(3J```$````E^H```<```"<Z@``!0```*3J
M```P````JNH``!,```#;Z@```@```._J```'````\NH```8```#ZZ@``#```
M``'K```8````#NL```8````GZP``$@```"[K```#````0>L```8```!%ZP``
M!P```$SK```?````5.L``"X```!TZP``+P```*/K```7````T^L``"(```#K
MZP``)0````[L```@````-.P``!L```!5[```&````''L```D````BNP``!\`
M``"O[```&@```,_L```A````ZNP``"`````,[0``&@```"WM```R````2.T`
M`!H```![[0``+P```);M```K````QNT``!\```#R[0``(P```!+N```?````
M-NX``!H```!6[@``(0```''N```E````D^X``"8```"Y[@``)0```.#N```D
M````!N\``!@````K[P``'0```$3O```D````8N\``!@```"'[P``(@```*#O
M```L````P^\``"\```#P[P``%0```"#P```E````-O```#P```!<\```'P``
M`)GP```C````N?```!\```#=\```(````/WP```:````'O$``"8````Y\0``
M'@```&#Q```I````?_$``!X```"I\0``,0```,CQ```)````^O$```P````$
M\@``%P```!'R```O````*?(``"0```!9\@``!P```'[R```4````AO(```X`
M``";\@``#0```*KR```D````N/(```<```#=\@``'0```.7R```'`````_,`
M`,<````+\P``%0```-/S```&````Z?,```D```#P\P``"P```/KS```-````
M!O0``!<````4]```!@```"ST```S````,_0``!,```!G]```$P```'OT```'
M````C_0```\```"7]```!P```*?T```R````K_0```0```#B]```(0```.?T
M```3````"?4```P````=]0``$0```"KU```R````//4``!8```!O]0``"```
M`(;U```=````C_4```D```"M]0``"@```+?U```4````PO4```H```#7]0``
M"````.+U```(````Z_4```<```#T]0``"0```/SU```_````!O8```<```!&
M]@``#P```$[V```.````7O8```@```!M]@``!P```';V```9````?O8``!<`
M``"8]@``%````+#V```1````Q?8```<```#7]@```@```-_V```&````XO8`
M``<```#I]@``#0```/'V```+````__8```X````+]P``+P```!KW```@````
M2O<``!P```!K]P``,0```(CW```%````NO<``#\```#`]P``$@````#X```*
M````$_@```8````>^```"````"7X```,````+O@```H````[^```.0```$;X
M```N````@/@``"D```"O^```&````-GX```9````\O@``!\````,^0``'0``
M`"SY```1````2OD```(```!<^0``!````%_Y```&````9/D```4```!K^0``
M`P```''Y```,````=?D``$4```""^0``,@```,CY```:````^_D``#0````6
M^@``*````$OZ``!3````=/H``!D```#(^@``<@```.+Z```@````5?L``#4`
M``!V^P``(0```*S[``!%````SOL``#`````4_```*````$7\```I````;OP`
M`"8```"8_```)0```+_\```H````Y?P``"@````._0``(@```#?]```P````
M6OT``!(```"+_0``$P```)[]```0````LOT``'D```##_0``"0```#W^``"A
M````1_X``',```#I_@``?````%W_```K````VO\``%0````&``$`%P```%L`
M`0`G````<P`!`!8```";``$`#P```+(``0`7````P@`!`!\```#:``$`0```
M`/H``0`?````.P$!`!P```!;`0$`40```'@!`0`:````R@$!`!0```#E`0$`
M"@```/H!`0`%````!0(!``8````+`@$`"````!("`0`0````&P(!``\````L
M`@$`#P```#P"`0`+````3`(!``<```!8`@$`!0```&`"`0`4````9@(!``<`
M``![`@$`"````(,"`0`/````C`(!``@```"<`@$`#````*4"`0`/````L@(!
M``8```#"`@$`%````,D"`0`&````W@(!``P```#E`@$`$0```/("`0`(````
M!`,!`!D````-`P$`$0```"<#`0`*````.0,!`!@```!$`P$`$P```%T#`0`<
M````<0,!`!$```".`P$`!````*`#`0`/````I0,!``0```"U`P$`$0```+H#
M`0`2````S`,!`!<```#?`P$`!````/<#`0`/````_`,!`!,````,!`$`!P``
M`"`$`0`'````*`0!`!$````P!`$`!@```$($`0`8````200!`!,```!B!`$`
M$````'8$`0`,````AP0!``D```"4!`$`$0```)X$`0`B````L`0!``<```#3
M!`$`!0```-L$`0`Z`0``X00!``H````<!@$`#P```"<&`0`/````-P8!``<`
M``!'!@$`"````$\&`0`'````6`8!`"4```!@!@$`(0```(8&`0`M````J`8!
M`"4```#6!@$`*0```/P&`0`J````)@<!`"````!1!P$`*@```'('`0`+````
MG0<!`"````"I!P$`"0```,H'`0`+````U`<!``4```#@!P$`$0```.8'`0`)
M````^`<!``\````""`$`"P```!((`0`5````'@@!`&L````T"`$`#0```*`(
M`0`%````K@@!`!$```"T"`$`$P```,8(`0`/````V@@!``L```#J"`$`"P``
M`/8(`0`1`````@D!``8````4"0$`D@```!L)`0`*````K@D!``H```"Y"0$`
M"@```,0)`0`'````SPD!``L```#7"0$`*````.,)`0`<````#`H!`"D````I
M"@$`,0```%,*`0!*````A0H!`$0```#0"@$`4````!4+`0!*````9@L!`"P`
M``"Q"P$`!0```-X+`0`6````Y`L!`"\```#["P$`*P```"L,`0`.````5PP!
M`!8```!F#`$`'@```'T,`0`*````G`P!``0```"G#`$`$@```*P,`0`4````
MOPP!``L```#4#`$`%````.`,`0`8````]0P!`!H````.#0$`'````"D-`0`2
M````1@T!``@```!9#0$`$@```&(-`0`*````=0T!`"P```"`#0$`$0```*T-
M`0`6````OPT!``P```#6#0$`3@```.,-`0`V````,@X!`"8```!I#@$`!```
M`)`.`0`*````E0X!`!T```"@#@$`!````+X.`0`#````PPX!``X```#'#@$`
M"@```-8.`0`,````X0X!``0```#N#@$`"@```/,.`0`$````_@X!``P````#
M#P$`#@```!`/`0`0````'P\!`!0````P#P$`*@```$4/`0`.````<`\!`!0`
M``!_#P$`%@```)0/`0`4````JP\!`!0```#`#P$`$@```-4/`0`.````Z`\!
M`!````#W#P$`&@````@0`0`>````(Q`!``@```!"$`$`#@```$L0`0`*````
M6A`!``X```!E$`$`!````'00`0`,````>1`!`!@```"&$`$`$````)\0`0`4
M````L!`!`!8```#%$`$`$````-P0`0`$````[1`!`!````#R$`$`!`````,1
M`0`8````"!$!``P````A$0$`,0```"X1`0`S````8!$!`!(```"4$0$`$```
M`*<1`0`&````N!$!``X```"_$0$`$@```,X1`0`N````X1$!`"H````0$@$`
M+````#L2`0`L````:!(!`"8```"5$@$`!````+P2`0`$````P1(!``X```#&
M$@$`$@```-42`0`Q````Z!(!`#8````:$P$`+@```%$3`0!J````@!,!`"D`
M``#K$P$`*0```!44`0!"````/Q0!`$(```""%`$`*0```,44`0`U````[Q0!
M`"4````E%0$`)0```$L5`0!"````<14!`"D```"T%0$`+P```-X5`0`B````
M#A8!`!(````Q%@$`%@```$06`0`H````6Q8!`!\```"$%@$`'P```*06`0`6
M````Q!8!`!8```#;%@$`!````/(6`0`&````]Q8!`"````#^%@$`'@```!\7
M`0`&````/A<!``H```!%%P$`&````%`7`0`*````:1<!`#0```!T%P$`!@``
M`*D7`0`0````L!<!``@```#!%P$`"````,H7`0`,````TQ<!`!(```#@%P$`
M#````/,7`0`&`````!@!`#0````'&`$`#````#P8`0`.````21@!``0```!8
M&`$`#@```%T8`0`,````;!@!``(```!Y&`$`"@```'P8`0`"````AQ@!`!@`
M``"*&`$`#@```*,8`0`(````LA@!``@```"[&`$`#@```,08`0`6````TQ@!
M``H```#J&`$`"````/48`0`.````_A@!``X````-&0$``P```!P9`0`#````
M(!D!`!`````D&0$`#0```#49`0`H````0QD!``8```!L&0$`"@```',9`0`0
M````?AD!`$````"/&0$`'````-`9`0`L````[1D!`"4````:&@$`'````$`:
M`0`&````71H!``H```!D&@$`&````&\:`0`@````B!H!`"(```"I&@$`+P``
M`,P:`0`F````_!H!`"8````C&P$`2````$H;`0`R````DQL!`!(```#&&P$`
M!````-D;`0`(````WAL!``P```#G&P$`#````/0;`0`(`````1P!``@````*
M'`$`"@```!,<`0`(````'AP!``H````G'`$`"````#(<`0`$````.QP!`!(`
M``!`'`$`#````%,<`0`.````8!P!``X```!O'`$`#````'X<`0`$````BQP!
M`!````"0'`$`,````*$<`0!.````TAP!`!4````A'0$`"@```#<=`0`.````
M0AT!`!8```!1'0$`$````&@=`0`.````>1T!``X```"('0$`#````)<=`0`@
M````I!T!`!D```#%'0$`"````-\=`0`0````Z!T!``H```#Y'0$`$`````0>
M`0`2````%1X!`!(````H'@$`"@```#L>`0`0````1AX!`!````!7'@$``@``
M`&@>`0`&````:QX!``8```!R'@$`!````'D>`0`*````?AX!``H```")'@$`
M"````)0>`0`.````G1X!``@```"L'@$`!@```+4>`0`*````O!X!``0```#'
M'@$`"@```,P>`0`R````UQX!`!@````*'P$`#0```",?`0`0````,1\!``P`
M``!"'P$`$````$\?`0`*````8!\!``H```!K'P$`)@```'8?`0`S````G1\!
M`"$```#1'P$`!@```/,?`0`D````^A\!`"`````?(`$`"P```$`@`0`$````
M3"`!``H```!1(`$`!@```%P@`0`.````8R`!`!````!R(`$`$````(,@`0`6
M````E"`!`"L```"K(`$`*0```-<@`0`N`````2$!`"P````P(0$`(````%TA
M`0`G````?B$!`!X```"F(0$`(P```,4A`0`L````Z2$!`"8````6(@$`)0``
M`#TB`0`I````8R(!`"````"-(@$`)@```*XB`0`R````U2(!`#(````((P$`
M*@```#LC`0`L````9B,!`"P```"3(P$`+````,`C`0`;````[2,!`"H````)
M)`$`+0```#0D`0`?````8B0!`"H```"")`$`*````*TD`0`=````UB0!`!4`
M``#T)`$`C`````HE`0`:````ER4!`"0```"R)0$`)@```-<E`0`F````_B4!
M`"8````E)@$`'````$PF`0`E````:28!`!\```"/)@$`*@```*\F`0`L````
MVB8!`#0````')P$`-@```#PG`0!]````<R<!`!T```#Q)P$`)0````\H`0`@
M````-2@!`"8```!6*`$`'P```'TH`0!`````G2@!``(```#>*`$`!````.$H
M`0`(````YB@!`!(```#O*`$`$@````(I`0`4````%2D!`!`````J*0$`#@``
M`#LI`0`0````2BD!``H```!;*0$`#0```&8I`0`.````="D!`"\```"#*0$`
M"````+,I`0`2````O"D!``X```#/*0$`#````-XI`0`"````ZRD!``0```#N
M*0$`#0```/,I`0`0`````2H!``0````2*@$`"@```!<J`0`(````(BH!``H`
M```K*@$`!````#8J`0`&````.RH!``P```!"*@$`"@```$\J`0`,````6BH!
M``T```!G*@$`$````'4J`0`$````ABH!``@```"+*@$`#@```)0J`0`*````
MHRH!`!````"N*@$`"````+\J`0`(````R"H!`!8```#1*@$`$````.@J`0`7
M````^2H!`#D````1*P$`"````$LK`0`0````5"L!`!(```!E*P$`$@```'@K
M`0`2````BRL!`"H```">*P$`"````,DK`0`*````TBL!``X```#=*P$`!```
M`.PK`0`C````\2L!`"0````5+`$`!````#HL`0`*````/RP!``H```!*+`$`
M"@```%4L`0`.````8"P!``P```!O+`$`"@```'PL`0`N````ARP!`$8```"V
M+`$`"````/TL`0`.````!BT!`"(````5+0$`#````#@M`0`1````12T!`#D`
M``!7+0$`"@```)$M`0`0````G"T!``0```"M+0$`#@```+(M`0`.````P2T!
M`!````#0+0$`$````.$M`0`5````\BT!`!(````(+@$`%P```!LN`0`5````
M,RX!`!8```!)+@$`%````&`N`0`*````=2X!``\```"`+@$`*P```)`N`0`3
M````O"X!`!(```#0+@$`%````.,N`0`*````^"X!`"X````#+P$`)````#(O
M`0`6````5R\!`%H```!N+P$`#P```,DO`0`0````V2\!``H```#J+P$`!@``
M`/4O`0`7````_"\!`!D````4,`$`$P```"XP`0`9````0C`!`!P```!<,`$`
M&P```'DP`0`0````E3`!``H```"F,`$`"@```+$P`0`&````O#`!``4```##
M,`$`!@```,DP`0`%````T#`!``H```#6,`$`!@```.$P`0`%````Z#`!``H`
M``#N,`$`!````/DP`0`$````_C`!`!`````#,0$`"@```!0Q`0`(````'S$!
M``0````H,0$`!@```"TQ`0`=````-#$!`"0```!2,0$`(P```'<Q`0`B````
MFS$!`"$```"^,0$`'P```.`Q`0`@`````#(!`!T````A,@$`%@```#\R`0`D
M````5C(!``P```![,@$`#@```(@R`0`#````ES(!``,```";,@$`!````)\R
M`0`2````I#(!``@```"W,@$`%P```,`R`0`7````V#(!`!(```#P,@$`"@``
M``,S`0`,````#C,!`!0````;,P$`+@```#`S`0`(````7S,!`!(```!H,P$`
M"````'LS`0`:````A#,!``8```"?,P$`'@```*8S`0`B````Q3,!``@```#H
M,P$`"@```/$S`0`"````_#,!``(```#_,P$`#@````(T`0`0````$30!`!``
M```B-`$`%````#,T`0`2````2#0!``H```!;-`$`!````&8T`0`$````:S0!
M``P```!P-`$`&````'TT`0`,````EC0!``X```"C-`$`%0```+(T`0`0````
MR#0!``X```#9-`$`$````.@T`0`,````^30!``P````&-0$``@```!,U`0`.
M````%C4!``T````E-0$`"P```#,U`0`.````/S4!``X```!.-0$`"````%TU
M`0`,````9C4!`!P```!S-0$`.````)`U`0`H````R34!`"@```#R-0$`"```
M`!LV`0`.````)#8!``@````S-@$`$````#PV`0`,````338!`!````!:-@$`
M#````&LV`0`,````>#8!`!(```"%-@$`$@```)@V`0`;````JS8!``P```#'
M-@$`%````-0V`0`&````Z38!``8```#P-@$`&````/<V`0`$````$#<!``8`
M```5-P$`!````!PW`0`&````(3<!`!P````H-P$`!@```$4W`0`*````3#<!
M`!0```!7-P$`#@```&PW`0`2````>S<!``0```".-P$`!0```),W`0!"````
MF3<!`#T```#<-P$`/0```!HX`0`E````6#@!`"D```!^.`$`.@```*@X`0`I
M````XS@!`"L````-.0$`*0```#DY`0`?````8SD!`"(```"#.0$`!@```*8Y
M`0`:````K3D!`"(```#(.0$`&@```.LY`0`0````!CH!`"L````7.@$`*P``
M`$,Z`0`S````;SH!``L```"C.@$`&0```*\Z`0`R````R3H!`!````#\.@$`
M$@````T[`0`,````(#L!``T````M.P$`$@```#L[`0`(````3CL!`$4```!7
M.P$`60```)T[`0`.````]SL!``@````&/`$`"0````\\`0`$````&3P!`!<`
M```>/`$`'P```#8\`0`<````5CP!`"P```!S/`$`*````*`\`0!4````R3P!
M``P````>/0$`!@```"L]`0`*````,CT!`!(````]/0$`!````%`]`0`2````
M53T!`!````!H/0$`"@```'D]`0`(````A#T!``P```"-/0$`#@```)H]`0`8
M````J3T!`!8```#"/0$`&````-D]`0`6````\CT!`!H````)/@$`&````"0^
M`0`6````/3X!`#````!4/@$`$````(4^`0`.````ECX!``X```"E/@$`#@``
M`+0^`0`0````PSX!`!````#4/@$`#@```.4^`0`.````]#X!``P````#/P$`
M'@```!`_`0`0````+S\!`!(```!`/P$`*````%,_`0`0````?#\!`!<```"-
M/P$`'````*4_`0`=````PC\!`!P```#@/P$`&@```/T_`0`<````&$`!`!P`
M```U0`$`&````%)``0`6````:T`!`!8```""0`$`%@```)E``0`6````L$`!
M`!H```#'0`$`&0```.)``0`*````_$`!`!8````'00$`#````!Y!`0`,````
M*T$!``8````X00$`"@```#]!`0`&````2D$!``0```!100$`#@```%9!`0`*
M````94$!``0```!P00$`!````'5!`0`,````>D$!``@```"'00$`!````)!!
M`0`$````E4$!``8```":00$`"````*%!`0`(````JD$!``8```"S00$`!@``
M`+I!`0`2````P4$!`!(```#400$`#````.=!`0`C````]$$!``@````80@$`
M!@```"%"`0`$````*$(!``8````M0@$`*````#1"`0`.````74(!`!8```!L
M0@$`"````(-"`0`*````C$(!``X```"70@$`#````*9"`0`$````LT(!`!0`
M``"X0@$`"````,U"`0`2````UD(!`!X```#I0@$`%`````A#`0`.````'4,!
M``0````L0P$`#@```#%#`0`"````0$,!``H```!#0P$`#@```$Y#`0`L````
M74,!`!8```"*0P$`!@```*%#`0`H````J$,!`!````#10P$`%````.)#`0`(
M````]T,!`!X`````1`$`&@```!]$`0`D````.D0!`!````!?1`$`"P```'!$
M`0`*````?$0!``H```"'1`$`!````))$`0`(````ET0!``H```"@1`$`"```
M`*M$`0`/````M$0!`#X```#$1`$`&`````-%`0`6````'$4!`!0````S10$`
M%````$A%`0`4````744!``(```!R10$`+0```'5%`0`&````HT4!`"````"J
M10$`$@```,M%`0`*````WD4!``X```#I10$`"@```/A%`0`0`````T8!``H`
M```41@$`#````!]&`0`P````+$8!``0```!=1@$`%````&)&`0`.````=T8!
M`!P```"&1@$`'````*-&`0`2````P$8!``0```#31@$`#````-A&`0`&````
MY48!``X```#L1@$`"````/M&`0`$````!$<!`$(````)1P$`"````$Q'`0`@
M````54<!``X```!V1P$`$````(5'`0`)````ED<!`#$```"@1P$`6````-)'
M`0`@````*T@!`"D```!,2`$`(````'9(`0`"````ET@!``H```":2`$`!@``
M`*5(`0`.````K$@!``H```"[2`$`"````,9(`0`$````ST@!``X```#42`$`
M!````.-(`0`,````Z$@!``0```#U2`$`!````/I(`0`$````_T@!``0````$
M20$`!`````E)`0`$````#DD!`!(````320$`"@```"9)`0`.````,4D!``X`
M``!`20$`#````$])`0`$````7$D!``X```!A20$`#````'!)`0`,````?4D!
M``P```"*20$`&````)=)`0`,````L$D!``0```"]20$`&@```,))`0`(````
MW4D!``0```#F20$`%````.M)`0`0`````$H!`!`````12@$`+````")*`0`@
M````3TH!``@```!P2@$`$````'E*`0`"````BDH!``X```"-2@$`"P```)Q*
M`0`0````J$H!`!````"Y2@$`%@```,I*`0`(````X4H!`"8```#J2@$`"@``
M`!%+`0`R````'$L!`",```!/2P$`*````'-+`0`H````G$L!`"P```#%2P$`
M$@```/)+`0`<````!4P!`"0````B3`$`%@```$=,`0`:````7DP!`"````!Y
M3`$`&@```)I,`0`:````M4P!`",```#03`$`(P```/1,`0`G````&$T!`"<`
M``!`30$`)0```&A-`0`H````CDT!`%T```"W30$`&````!5.`0`>````+DX!
M`"````!-3@$`$````&Y.`0`J````?TX!`!L```"J3@$`!@```,9.`0!&````
MS4X!`$8````43P$`!````%M/`0`.````8$\!``8```!O3P$`#@```'9/`0`.
M````A4\!``H```"43P$`"@```)]/`0`:````JD\!`!0```#%3P$`&````-I/
M`0`$````\T\!``0```#X3P$``@```/U/`0`&`````%`!``0````'4`$`!```
M``Q0`0`T````$5`!``(```!&4`$`#````$E0`0`2````5E`!``0```!I4`$`
M"````&Y0`0`.````=U`!`"````"&4`$`"````*=0`0`R````L%`!`"D```#C
M4`$`0@````U1`0`4````4%$!`$D```!E40$`"@```*]1`0`-````NE$!``X`
M``#(40$`!````-=1`0`$````W%$!``0```#A40$`(````.91`0`6````!U(!
M`!(````>4@$`&@```#%2`0`,````3%(!``H```!94@$`"@```&12`0`7````
M;U(!``D```"'4@$`"0```)%2`0`:````FU(!``0```"V4@$`&@```+M2`0`,
M````UE(!`!````#C4@$`#````/12`0`8`````5,!`!`````:4P$`"@```"M3
M`0`B````-E,!`!P```!94P$`(P```'93`0`0````FE,!``L```"K4P$`#```
M`+=3`0`:````Q%,!``@```#?4P$`&@```.A3`0`$`````U0!`!8````(5`$`
M"@```!]4`0`2````*E0!`"0````]5`$`"@```&)4`0`H````;50!`!@```"6
M5`$`"@```*]4`0`0````NE0!``@```#+5`$`#````-14`0`0````X50!``0`
M``#R5`$`#````/=4`0`(````!%4!`!H````-50$`(0```"A5`0`^````2E4!
M`"(```")50$`*````*Q5`0!8````U54!`!`````N5@$`!@```#]6`0`0````
M1E8!`#````!75@$`,P```(A6`0`*````O%8!`!P```#'5@$`#@```.16`0`$
M````\U8!``8```#X5@$`!````/]6`0`.````!%<!``8````35P$`$@```!I7
M`0`*````+5<!`"4````X5P$`#````%Y7`0`2````:U<!``@```!^5P$`"```
M`(=7`0`(````D%<!`!,```"95P$``@```*U7`0`$````L%<!`#0```"U5P$`
M0P```.I7`0`4````+E@!`!D```!#6`$`$````%U8`0`(````;E@!`!````!W
M6`$`+````(A8`0`$````M5@!``X```"Z6`$`"@```,E8`0`*````U%@!`#(`
M``#?6`$`!@```!)9`0`@````&5D!``P````Z60$`$````$=9`0`6````6%D!
M`#(```!O60$`,0```*)9`0`L````U%D!``@````!6@$`%`````I:`0`<````
M'UH!``0````\6@$`$````$%:`0`2````4EH!``X```!E6@$`'@```'1:`0`"
M````DUH!``0```"66@$`"@```)M:`0`)````IEH!``@```"P6@$`"````+E:
M`0`&````PEH!``8```#)6@$`!````-!:`0`$````U5H!`!P```#:6@$`$@``
M`/=:`0`2````"EL!``0````=6P$`"@```");`0`(````+5L!``\````V6P$`
M#0```$9;`0`;````5%L!``H```!P6P$``P```'M;`0`$````?UL!``(```"$
M6P$`#@```(=;`0`8````EEL!``P```"O6P$`&````+Q;`0`H````U5L!``P`
M``#^6P$`$`````M<`0`>````'%P!`!(````[7`$`!````$Y<`0`+````4UP!
M``D```!?7`$`$````&E<`0!)````>EP!`!<```#$7`$`*@```-Q<`0`$````
M!UT!``P````,70$`#@```!E=`0`8````*%T!`"(```!!70$`'@```&1=`0`8
M````@UT!`"````"<70$`"````+U=`0!2````QET!`"0````97@$`'@```#Y>
M`0`3````75X!`"0```!Q7@$`'@```)9>`0`J````M5X!`!<```#@7@$`%P``
M`/A>`0`6````$%\!``@````G7P$`#@```#!?`0`$````/U\!`!8```!$7P$`
M!````%M?`0`.````8%\!``H```!O7P$`-@```'I?`0`R````L5\!`"````#D
M7P$`5P````5@`0`$````76`!`!(```!B8`$`$````'5@`0`,````AF`!`#P`
M``"38`$`!````-!@`0`T````U6`!`"X````*80$`'@```#EA`0`D````6&$!
M`!P```!]80$`%@```)IA`0`:````L6$!`!H```#,80$`!````.=A`0`R````
M[&$!`!(````?8@$`#````#)B`0`(````/V(!`!0```!(8@$`$@```%UB`0`&
M````<&(!`!(```!W8@$`$````(IB`0`0````FV(!``P```"L8@$`$@```+EB
M`0`,````S&(!``X```#98@$`$````.AB`0`B````^6(!``8````<8P$`$```
M`"-C`0`2````-&,!``0```!'8P$`"@```$QC`0`(````5V,!``X```!@8P$`
M"````&]C`0`&````>&,!``8```!_8P$`'````(9C`0`*````HV,!``0```"N
M8P$`"````+-C`0`(````O&,!``X```#%8P$``@```-1C`0`D````UV,!``0`
M``#\8P$`!@````%D`0`$````"&0!`"$````-9`$`(P```"]D`0`7````4V0!
M`",```!K9`$`-````(]D`0`J````Q&0!`#8```#O9`$`&P```"9E`0`;````
M0F4!``X```!>90$`!````&UE`0`&````<F4!``@```!Y90$`#P```()E`0`(
M````DF4!``0```";90$`!@```*!E`0`&````IV4!``@```"N90$`#@```+=E
M`0`"````QF4!`"````#)90$`$````.IE`0`0````^V4!``H````,9@$`%```
M`!=F`0`+````+&8!``8````X9@$`!@```#]F`0`$````1F8!`!(```!+9@$`
M$@```%YF`0`4````<68!``8```"&9@$`"````(UF`0`@````EF8!`!(```"W
M9@$`#````,IF`0`(````UV8!``@```#@9@$``@```.EF`0`(````[&8!`!8`
M``#U9@$`(@````QG`0`R````+V<!`"X```!B9P$`3````)%G`0!<````WF<!
M`"P````[:`$`/````&AH`0!<````I6@!`"0````":0$`)@```"=I`0`F````
M3FD!`"8```!U:0$`)@```)QI`0`B````PVD!`"P```#F:0$`XP```!-J`0`:
M````]VH!`$<````2:P$`*@```%IK`0`X````A6L!`$<```"^:P$`2@````9L
M`0`D````46P!`"8```!V;`$`'@```)UL`0`>````O&P!`!X```#;;`$`(```
M`/IL`0`R````&VT!`"H```!.;0$`*````'EM`0`B````HFT!`"8```#%;0$`
M7@```.QM`0`O````2VX!`#T```![;@$`+@```+EN`0`E````Z&X!`$L````.
M;P$`7P```%IO`0!/````NF\!`"@````*<`$`,@```#-P`0`O````9G`!`$P`
M``"6<`$`3@```.-P`0!&````,G$!`$8```!Y<0$`-@```,!Q`0`M````]W$!
M`"L````E<@$`*````%%R`0`:````>G(!`"H```"5<@$`,@```,!R`0`K````
M\W(!`$X````?<P$`*@```&YS`0!&````F7,!`"0```#@<P$`3`````5T`0`I
M````4G0!`#$```!\=`$`*@```*YT`0`B````V70!`$(```#\=`$`!````#]U
M`0`,````1'4!``@```!1=0$`%@```%IU`0`(````<74!`%L```!Z=0$`$@``
M`-9U`0`,````Z74!``P```#V=0$`"@````-V`0`L````#G8!`!H````[=@$`
M`@```%9V`0`0````678!``P```!J=@$`$````'=V`0`6````B'8!``8```"?
M=@$`!@```*9V`0`#````K78!``X```"Q=@$`"@```,!V`0`F````RW8!`#``
M``#R=@$`,0```"-W`0`5````57<!`"H```!K=P$`+P```)9W`0`<````QG<!
M`!8```#C=P$`(````/IW`0`H````&W@!`"(```!$>`$`'@```&=X`0`H````
MAG@!`",```"O>`$`&````--X`0`V````['@!`!D````C>0$`-````#UY`0`J
M````<GD!`"(```"=>0$`)````,!Y`0`D````Y7D!`!X````*>@$`*````"EZ
M`0`@````4GH!`"8```!S>@$`'````)IZ`0`=````MWH!`!X```#5>@$`(```
M`/1Z`0`F````%7L!`!H````\>P$`'@```%=[`0`O````=GL!`#(```"F>P$`
M&@```-E[`0`B````]'L!`#H````7?`$`*@```%)\`0`L````?7P!`"H```"J
M?`$`*P```-5\`0`D`````7T!`"`````F?0$`(````$=]`0`H````:'T!`!H`
M``"1?0$`-````*Q]`0`$````X7T!``X```#F?0$`%````/5]`0`F````"GX!
M`!X````Q?@$`!@```%!^`0`0````5WX!``0```!H?@$`!````&U^`0`.````
M<GX!``0```"!?@$`(````(9^`0`$````IWX!`+P```"L?@$`'````&E_`0`$
M````AG\!``\```"+?P$`$````)M_`0`5````K'\!`!X```#"?P$`#````.%_
M`0!$````[G\!`!0````S@`$`%````$B``0`4````78`!`!(```!R@`$`"@``
M`(6``0`[````D(`!``8```#,@`$`)@```-.``0`*````^H`!`!`````%@0$`
M"@```!:!`0`N````(8$!`"(```!0@0$`"````'.!`0`>````?($!``D```";
M@0$`"@```*6!`0`4````L($!`!0```#%@0$`!````-J!`0`&````WX$!``X`
M``#F@0$`&@```/6!`0`S````$((!``(```!$@@$`#@```$>"`0`&````5H(!
M`!8```!=@@$`"0```'2"`0`7````?H(!`!````"6@@$`$````*>"`0`8````
MN((!``0```#1@@$``@```-:"`0`$````V8(!``@```#>@@$`#0```.>"`0`1
M````]8(!``@````'@P$`,````!"#`0`6````08,!`!0```!8@P$`+````&V#
M`0`"````FH,!`#$```"=@P$`!@```,^#`0`(````UH,!``0```#?@P$`#@``
M`.2#`0`,````\X,!`!``````A`$`.0```!&$`0`P````2X0!`#\```!\A`$`
M#P```+R$`0`/````S(0!`!,```#<A`$`%P```/"$`0`/````"(4!``(````8
MA0$``@```!N%`0`$````'H4!``X````CA0$`!````#*%`0`*````-X4!`#T`
M``!"A0$`-0```("%`0`<````MH4!`"<```#3A0$`*````/N%`0!1````)(8!
M`!,```!VA@$`:````(J&`0`:````\X8!`$X````.AP$`*@```%V'`0`Z````
MB(<!`",```##AP$`(@```.>'`0`D````"H@!`"0````OB`$`)````%2(`0`D
M````>8@!`"8```">B`$`'@```,6(`0!!````Y(@!`!(````FB0$`%P```#F)
M`0`:````48D!`&@```!LB0$`#````-6)`0"5````XHD!`'8```!XB@$`;@``
M`.^*`0`R````7HL!`&(```"1BP$`#@```/2+`0`F`````XP!`!4````JC`$`
M#````$",`0`8````38P!`!P```!FC`$`.````(.,`0`8````O(P!`"````#5
MC`$`3@```/:,`0`:````18T!``\```!@C0$`#@```'"-`0`B````?XT!``X`
M``"BC0$`$````+&-`0`,````PHT!``H```#/C0$`!@```-J-`0`*````X8T!
M``H```#LC0$`"````/>-`0`3`````(X!``H````4C@$`#````!^.`0`,````
M+(X!``P````YC@$`#````$:.`0`,````4XX!``X```!@C@$`"````&^.`0`(
M````>(X!``H```"!C@$`#@```(R.`0`&````FXX!`!P```"BC@$`&````+^.
M`0`.````V(X!`!8```#GC@$`"@```/Z.`0`<````"8\!`!`````FCP$`!```
M`#>/`0`0````/(\!``@```!-CP$`#@```%:/`0`,````98\!`!@```!RCP$`
M!````(N/`0`2````D(\!`!8```"CCP$`!@```+J/`0`*````P8\!`!@```#,
MCP$`"````.6/`0`<````[H\!``P````+D`$`"@```!B0`0`.````(Y`!``P`
M```RD`$`#@```#^0`0`E````3I`!``0```!TD`$`!0```'F0`0`!````M@$`
M`%(`````````"@$``#4!``#(`P``Y````"4!``````````````````#W`@``
MV`0``.\$``"\`0```````.,!``#N`P```````!X```#!`0``+P0``)$````/
M`@```````$`"``"G`P``.04``.X$``"<!0``%```````````````*@,`````
M```U````CP0```````!1!```%`$``,T"``!W`@``6@0```````"%`0``````
M`*0!``"Y!```?04``````````````````'H$````````@`,``-D"````````
M`````.P$``#N`0``%`(``+4!```:`P``_@0```,"``"<!```]0```/L#```G
M`@``L````'<!``!5!```=`4``,(```!_!```,0(``,@```#[`@``:P````(!
M````````O````)4$``````````````````"-`@``!0$``"````"V`P``;`,`
M``L#``!/!0``PP$``/H!````````5@,``,$#``"[!````````'X"```&````
MR@(`````````````A`(```L"``#Z`@``3`0``#(`````````SP0``&$!``#&
M````1@`````````I`@``]P````````#6`P```````-X"``"J````A@4``+8`
M``"D`P``.@,``#P$````````GP```)D"````````1P0```````"B````````
M`&\"``"9`0``H`4``$X$``!(!0``````````````````!04````````U`@``
M^`,``.`````_`0``@@4``/<#``!-`P``9`````````!,!0````````0#```<
M`0``K`$``(T```#&`@``@P(``*X#``#,`P```````/0!````````;@0``,L$
M`````````````"4#````````V00``.4#``#<`@```````/0```"?!0``S@``
M``````!U``````````````#[`0``U0(`````````````*`$``+,!``">!0``
MX@0``)D%``!N`@``J`$``&<"``#9`0``#00``-@"``"E`@```````',$``!;
M`P```````(\!``"G````;0,`````````````M0(``%`#````````9P```'T!
M``!"`P``,````*8$```Q!0``C@(``-0"``!E``````````````!1`@``4P$`
M```````L`P``_@```$D`````````````````````````E0```"X!```Y````
M``````\%``#<````1P$```````#F````6`4```\!``")`P```````(L!````
M````IP(```T"```X!````````!X"``#!`@``,`,``/$!```S!```9`4``+($
M``#/````VP$```````!H!0``<@0``'4$```U!0``*`(```````#.`@``)`,`
M`/4!``!\`@```````(X$```W`@``/@,``!D$``!T````"@(```P```"W`0``
MO0,``/4$````````00```"<!```T`P``Q`,``)@$``""`@``<`,```0%``!1
M`P``3P,``/\"````````J@$``!(!````````6`(```````!Y`0``````````
M``"%!````````+X"``!B````!@$``*P```!:`P``*0,``(\%``"H!```````
M`&T!````````2`$``!`%````````K0$````````]`````````'\"``"!!```
M!@4``!<`````````]`,``)8```#X`@```````-L#````````F`,```````"6
M!```+@(```````"3`@``:@$```````"]!```<0$````````K`P``!````-\!
M``#C````N````/D$``!5````1P```$(``````````````%`$````````H`,`
M`'0!`````````````-`!```?!```_P```(($``!V!````P4````````J!0``
M``````````!4!0```````-`$`````````````$(!``!V`````````+<#````
M````\@`````````H!```30(```````!2`P```````%$`````````F`(``%0"
M``!P`@``TP0``*D!``"E!```TP$``"8!``"B!0``30$``$H"````````W@0`
M`"\#``##!````````"8#``#=`P``[`(```P#```!`@``X`,```````".````
M1@(``*<$``!"`@``Z`$``%0!``"L`@``N`(``.X"````````X`$``-<````E
M`@``%@0``#H```#F!```_0$``%8%```/`P``JP`````````\`@``50(``$($
M```(!0``Z@,```````#0`P``RP(``+L#````````;@```,,#````````AP$`
M`$@#``!!!```(@,``(4#`````````````&H$```:`0``5P```!,!``#.!```
MC`$```````##`@``D00``/(!``#B`0``X@,``&D````O!0``=`,``,L!```>
M`P````````````!2!0```````&<%``#K`P``8`0``!T`````````8P,``&`!
M``#4````B@$``!\%``!#!0``OP,```D"```C!````````$,$````````W0$`
M`"L"``"$````6@```/\!````````>P,``)X```!A!```<0(``'4%``"`!0``
M\P```"8%````````:0$```````!W`P``U00``!8!```N````;@,``-<!``!8
M`P``.0$```````#C`P``R@$```````!;`````````$D"``#/`0``````````
M``!'`@``4`(``#\#```Q`0``8P(````````"!0```````"T```"=`@``````
M`.4"``"<`@```````/D!``!``0``@P````````!$!```````````````````
M_`$``"\```">!```60```/T#``"D!0``7`````````"/`P``:P(``&\```">
M`P``6@(``.<$````````O`0``/`#``!0`0```````)D#```K````4P4```,`
M````````L`$``,D#```P!0``)`(````````6`@```````#@"``"@`0``%0``
M`)(%``!M!```H````"4$``#S`0```````)@%``"B!```=@4``!@%``"$`0``
MD``````````D!```?@4``,````#$`0````````````!<`0``C`(``'X$````
M``````````````"O!````````+D#```K!0``;`(`````````````"@0``!$!
M```H````U0$`````````````L`(``)L$````````10,``)H%````````P@0`
M``````#0````^`0``!D!```#`0``)@(``.$$````````#@4``$4!````````
M`````$0#```]`@``W00`````````````O0```(P#`````````````'H#``"+
M`P````````````"#`0``>`4```````"A!```$0(``-L$````````N0$``"\"
M``"(`@``S`0````````R`@```````#L%```C`P```````*\!```1`P```@(`
M``````"=`P```````!T#````````O`(``-P$``"Z!```FP(``,P"``"Y````
M$0```(T!``"I!```<`$`````````````;@4``*,"``"C!0``DP``````````
M````S@$``#H"````````T`(``%8`````````&P0``,8!``!9`@``/@$```4$
M``#G`0``6`$```````!)`P``N`,`````````````3`,```````";`0``!@0`
M``````"&`P```````.`$``"B`P```````-@!``"?`0``204`````````````
M4P(``!<"``!_`P``7`(``$0"````````(0```)T!````!```;P,````````'
M`P``$@0``-4```"^`P``C00``#<#````````]0,``.P!``!6`@``[P(`````
M``!!`P``*`,``'(!``!C`0``1P,``*T"```M`0````````````"M`P``4@0`
M`!@#````````!P0``-H"````````,`0``+8$``````````````````!$````
M``````````!9`0```````!H"```-`P`````````````3!0``E@,````````C
M`0``L`0``%(!```0`@``'P```!\#``!R`````````&X!````````_P0``#\"
M``#2`0``8@4``*0$``#]`@``````````````````<P````L```"7`0``:00`
M`#@!``":`@``;P4```````#%`0````````````#W`0``5`0`````````````
MWP0````````5!0``"P$``/0"``#\````900```````!W!```"04```````!R
M`P``A0```$,#```\`0``L0(``'@```````````````L%````````````````
M``!`````)`4``'L"``"!`@``50$````````S`@``C0,``*\#``":`P``100`
M``````!3`````````($#``!%````U@(```D`````````Q@,``)H$````````
M!@(```````"0`@``2@4``'L!```=`@```````/T$`````````````.L!``!O
M`0``QP,``+0````1!```6@4``"D$``"]`0``JP$```````#2!```6@$``.0#
M````````Q`(``"<``````````````%0#```(`0``````````````````````
M`((```"F`@``U@0``&\$``!>`P``504``+\"````````2@,``$`%``"2!```
M`````+H```!@`P``V@,````````C````RP```.4````[`@``J@,``-(```"N
M`@``J0``````````````,0,``&<#`````@```````(\"``#M`P``]`0``(H#
M``#Q`P``^@````````!(`@``G````/($```@`@``.P````````!Q!0``V@$`
M``````!'!0``7@(``/T````I!0``-@0``$L````X`P``UP0```($``!S!0``
M&P```)X!```A`0``3@$``'T"```5`@``:`0``+,````@!0``$@4`````````
M!0``-@4``-X!```0`P``8@,``)8!```:!0``YP```.$!``"$!```R`(``)4#
M```*`P````````````!Z!0``I0,``-H$``!Z`@``SP(``*4!```9````X@(`
M`*,$```B`@````````````!/!```J04``)L%``"(`P``QP```%<#````````
MO`,``*D"```=!0```````-8```!Y!```K@0```T````7`0``<`4```(```"N
M````5@0```````!(````9@0``,<!```V````30```.D"```]`0``*0$```0$
M``!D!```0P$``,0$```\!0``>04````````;`@``^0,````````&`P``````
M`"$#``"Z`0``E`$``&T%````````EP(``-D```!G!```&`$``!P%``#?`@``
M=P`````````3`P```````&P!````````P`,``"(`````````[0$```````!Q
M````+@,```T%``"_`0``>`$`````````````UP,``+$$```!`P``H0,``,,`
M```7!0````````````"<`P````````````!S`@``7@0``%@`````````YP(`
M`*$!``"U```````````````G!0```````%P#``"9!````````)T```![!```
MO0(``%L"``!$!0``,@0``%<%````````\@(``%X!````````[P$````````7
M`P``Z@(``$L!``#8`P``WP```'X````^!```XP0``#@%````````K`,``,D$
M``"4````B@4``+X!```W`0``1@$``(@`````````BP(``&($``"S!```5P$`
M`'D#``#S`@``3P(``'$#``#F`@``=0(``(X#``#$````HP$``!X!``"W`@``
MEP,``&4!````````'P$``'0$``#3`P````````````#G`P```````-P!``#D
M`0``9@```.$"``!F`P``Y`0``+("````````9@$``%$!``#(!```I@4``.H`
M``"+!0```````!P#`````````````,H`````````'@0```````!.`@``/04`
M`-$`````````S`$``/\#``!R!0``#`4``````````````````%@$````````
M#@0``&@#``#O`P```````"(%````````^``````````3`@``+00``)0%``",
M````?@,``(D"``#5`P``-P4``!0%``!+!0``'`0``$8$````````]@0``%T`
M``"!!0``?00`````````````T@,``.0"``"[````?P$``*8!``"4`@``D`0`
M`#`"````````/P4```D!````````7P```+0$````````304``#,#``#-`0``
MVP```!,````9`@``704``'H`````````\`$``*<%```*````70,``)$%``"[
M`@``?`0```````"M`````````'T#```:!```_`(``(4"```=`0```````*4`
M``!D`@```````"P!``"J`@``M0,``*\"``#.`P``S0````````````````$`
M`'X!```2````Z`(````````@`P``/@```&$"````````-`(``&0!``#/`P``
M5````````````````````)0#``!>````10(``"`!``"9````\0(```````")
M`0``"P0``-8!``!9!```$`````````#;`@````````````"0`P``TP```.P#
M``"$`P``W`,``$H$``!=!```/0,``)8%````````%P0``,`!````````````
M`,D"``"P`P``N0(```````#3`@``!0```(,#``!@!0``@@$```@```!L````
M(04``$L#```*!0``$P0``&4"``"'`@``Z0,``.8#``![!0``R`$```````"@
M!```#@,``#H!```)`P``````````````````I````!X%``#S!```D0(``!L#
M```0!```8`(``(\```"T`@```````&@"```2`P``3@,``-0!``!;`0``104`
M`)L#``"*!```70$````````4`P``*`4``',#```\```````````````"`P``
MD@(``+(!``"(!0``>`(``-<"```(!````P0````````^!0```````!8#``!(
M!```.@0``$D$```T````.P,```\````5`P``KP```'P!``!A````LP(``/8!
M``!/````[00``/L````<`@``!P(``&L!```F````D@,````````J`0``)`$`
M`*L#``!H``````````````"1`P``0P```.$#``"+````"00``$0!``!I`P``
MDP0``#<`````````XP(``/8#``#"`@```````#0!````````+0(``%\!``!)
M`0```````+(#``#R`P``;`4``",%```8`@```````*X!````````Q@0`````
M``#9`P``L0,``/L$``!!`@``"`,```````!V`0``S00```````"*`@``.```
M`/D``````````````#L$``")!```9@4``!`!``".!0``^@,``%T"``"!````
MA@$``"D`````````Z````'\%``",!```.@4``%8!``#>````F`$```````!J
M`P``Q00``,4"``!1!0``+0,``'@$`````````````%\$``",!0``````````
M``"&!`````````<%``#4!````````),#``!7`@````````````!*`0``:@``
M`*@%``"?`P``&P4``'`$``"V`@``3@```!\"``````````````````!;!```
M/P```)8"````````````````````````H@$``+<````L!0``\`````````!Q
M!```?P````````!K`P``&`0``'<%```_!````````*8````J!```GP0``,(!
M``"X`0``EP0``+4$``"&``````````4#``")````0P(``',!``"5`@``B@``
M`"<#``"4!```L0$``/$`````````FP```+$```#8````V@````````#I````
M`````*<!``"_````!`$``&H%````````]P0``/H$```2`@``J`(```````#K
M`@```````+<$``#\`P``$04``````````````````)(!````````R@,``"T%
M``!,````&0,```````!,`0``[0```,<$``#Q!```004``&4#```V`P``(P(`
M``````#1!```(`0```````!T`@``\`0``$$!``#"`P``*P0````````5`0``
MAP0``+0!````````]@(```````"+!````````&0#``!A`P```````)$!``!F
M`@``300``&$%````````=0$``*L$`````````````(,$```-`0```````+@$
M``!``P``,P```.$```!R`@``4@(``,$```"&`@``>0(``$8%``"F`P``>P``
M`%L%```Y!````````,P``````P``:0(``-\#```Y`@```````.(````'````
M``````$$````````*@(``(T%````````Y0$```````"'!0``*@``````````
M````(@0``%<$````````J````,T#``"8````F@$``%P%``#2`@``ZP```-$#
M``"2````H0````````!M````0`0``!L!````````J@0``&<!````````'00`
M`#(!````````,@,```````!U`P``)````(`"``"3`0```````#0%``!/`0``
M>0````\$``!?!0``!0(```````#^`P```````.X`````````'````"4%````
M``````````````")!0``````````````````G00```````!]````HP````X`
M````````C@$``-T"````````8P0``'P```!E!0``4P,```$%```Q````U`,`
M`/,#``#I`0``&````(@$``"<`0``B`$``#$$``!0!0``%@```%\"``"B`@``
M`````'8#```S!0``%@4``,L#``!9!0```````"$"``#P`@``%`0``$(%```:
M````&04``+L!```U!```AP,``#X"`````````````&H"``!B`0``#`(``&,%
M````````Q0````````"$!0``(@$`````````````-P0```````"K`@``!`(`
M``````#^`@```````*T$``!9`P``N@(``(4%`````````````*P$````````
M3`(``.T"``"`````#@(``"P$``#V````50,``)`%``"C`P``````````````
M````GP(``.D$```'`0````````````#1`0``^`$``#8!```R!0```````&L%
M``"7!0``)P0``"$$````````Z`,```````""`P```````.P```!3!```````
M``````!+!```T0(``"L!```F!````````.8!``!Z`0``````````````````
M`````+X$``"D`@````````````"H`P``8P`````````T!`````````````"3
M!0``/`,``.L$````````Z@$`````````````-@(``$X%``!\`P``R0``````
M``":````I04``)<```!I!0``P`(```````!\!0``>`,```````"`!```H04`
M``````#)`0``=@(``(<```!<!```+`(``"X$```[`0``+P$``$8#``"@`@``
M_@$``.@$``!B`@``@`$```````"^````.0,```````!0````@0$```````!L
M!```_`0``"4```#%`P````````P!``"=!0```````.\```!?`P``L@```)`!
M``"T`P``QP(```X!```#`P``P`0``-T```">`@````````````"5!0``:`$`
M`.`"``#U`@``Z@0``$L"```U`P``+``````````]!````````#`!``!P````
MH0(``,H$```5!```"`(````````S`0``J0,``&T"``"S`P``Y00```````#!
M!`````````````!K!```E0$```$!```,!```W@,```````"Z`P``+@4``/D"
M`````````````+\$``!@````2@```(,%``!>!0```"`H)7,@9&%Y<R!A9V\I
M`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M
M;W)R;W<I`"`H>65S=&5R9&%Y*0`B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`
M(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I
M9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R
M97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y
M<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E
M+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U
M;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5S("T@3F]T:6-E`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!
M9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&ES(')E861Y('1O('!E
M<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@8VAE8VME9"!B96QO
M=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO;BAS*2!Y;W4@=V%N
M="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@<F5Q=6ER960`)7,@
M;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F("5S`"5S)W,@061D
M<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S
M:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y(&YO="!B92!F<F]M
M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@9F]L;&]W:6YG(&%N
M>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE('-E;F1E<B!W:71H
M(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+2T@<V5L96-T("TM`#$R($AO
M=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!
M(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN
M`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@
M:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U
M8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E
M(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-
M24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A
M<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O
M34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@
M87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-
M12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-+U!-
M`$%B;W5T('1H:7,@961I=&]R`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93
M(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`
M06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@
M9G)O>F5N+@!!8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H
M:6QD(%!E<FUI<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE
M=R!097)M:7-S:6]N`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@
M8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@
M8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE
M;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`
M061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG
M;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE
M9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M
M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M
M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!
M;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@
M0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T
M:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!
M<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@
M=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`
M07)M96YI80!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X
M:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H
M87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H
M7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P
M86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N
M(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@
M<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P
M;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W
M:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E
M;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R
M("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-
M0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER
M960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO
M;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE
M9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E
M:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($94
M4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E
M<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0F%C
M:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O<R!P87-S=V]R
M9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A:')A:6X`0F%N
M9VQA9&5S:`!"87)B861O<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B
M(&YO="!F;W5N9"X`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"
M96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P
M<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C
M:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T
M:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1S
M=V%N80!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A
M;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T
M960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T
M<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI
M="!W87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%M8F]D:6$`0V%M97)O
M;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE
M("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L
M97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O
M<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!2
M97!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G
M=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R
M>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N
M;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R
M96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R
M;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`
M0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@
M27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I
M;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E<G1I9FEC871E($1E
M=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`
M0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N
M86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A
M9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S
M<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I
M9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAE8U]K
M($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O
M<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@9&5F:6YI
M=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R($U33V9F:6-E('1A9W,`0VQE
M87(@475E<GD`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@
M=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L;W-E(%=I;F1O=P!#;V-O
M<R`H2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&]M8FEA
M`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O
M;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM
M96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VYF:6=U<F%T:6]N
M($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!0
M1$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A
M8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE
M.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]P
M>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S=&$@4FEC80!#
M;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``
M0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#
M;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@
M8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP
M="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#
M;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@
M<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C
M;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP
M;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO
M860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD
M(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O
M=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N
M("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E
M<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E
M86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD
M(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E
M<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T
M+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@
M>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,
M`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO
M="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E
M=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I
M979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O
M;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@
M<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I
M9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I
M<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG
M=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O
M<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA
M;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H
M('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L
M9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T
M:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I
M9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=')Y
M`$-R96%T90!#<F5A=&4@82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#
M<F5A=&]R(%!E<FUI<W-I;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA
M`$-U8F$`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!5
M4DP@:7,`0W5R<F5N="!5<V5R<P!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P
M;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>F5C
M:"!297!U8FQI8P!$1`!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E
M($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&5?
M;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N=6UB97)S`$1E8W)E87-E
M($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`1&5F875L="!)9&5N=&ET
M>0!$969A=6QT(%-H96QL`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O
M=7``1&5L971E($QO9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@8V5L;`!$
M96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA
M=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S
M(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R
M;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y
M`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN
M`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E
M('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@
M=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D
M92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$:7)E8W1I;VX@;&5F="!T
M;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7-P;&%Y(#(T+6AO
M=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:FEB;W5T:0!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B
M;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`
M1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@
M87,@4$A0('-C<FEP="X`12U-86EL`$5C=6%D;W(`161I=`!%9&ET($)L;V-K
M`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`
M161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I
M="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E
M<P!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;@!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@
M1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S
M`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%<G)O<B!G971T:6YG(&-O
M;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W;W)D.B`E<P!%<G)O<B!W
M:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I;F<@(B5S(BX`17-T;VYI
M80!%=&AI;W!I80!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@
M)RDG`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO<@!&5%`@=7!L
M;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E<F5N8V5S+@!&
M86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I;&5D('1O(&-O
M;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@9G)O;2`B)7,B
M+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@8W)E871E(&YE
M=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O("(E<R(N`$9A
M:6QE9"!T;R!R971R:65V93H@)7,`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN
M87,I`$9A<F]E($ES;&%N9',`1F%T86P@17)R;W(Z`$9A>`!&87AE<P!&96)R
M=6%R>0!&:6II`$9I;&4`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT
M.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T
M:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&
M:6QT97)S`$9I;FQA;F0`1FER<W0@475A<G1E<@!&;VQD97(@)7,@9&]E<R!N
M;W0@97AI<W0`1F]N="!#;VQO<@!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R
M=6US`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E
M;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<P!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA
M;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`
M1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O
M9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE
M`$=L;V)A;"!/<'1I;VYS`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)E
M96-E`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R
M;W5P(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A
M:60Z(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R
M;W5P7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U
M861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%I=&D`2&%S:"U!;&=O
M<FET:&T`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L
M9"!)<VQA;F1S`$AE:6=H=`!(96QP`$AE;6ES<&AE<F4`2&]?;64`2&]L>2!3
M964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M
M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R
M9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R
M960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R
M97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O
M9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U
M8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I
M;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E
M>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-
M3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R
M96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R
M:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E
M+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO
M=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M
M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S
M('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6YG87)Y`$E-05`@;6%I;&)O
M>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F
M86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z
M("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!
M9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K
M9&]W;B!V:6]L871I;VXN`$EC96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@
M)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@
M;F]T(&1I<W!L87EE9"!C;W)R96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N
M97<@=VEN9&]W+@!)9B!Y;W4@9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!)
M;G1E<FYE="!%>'!L;W)E<BP@>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@
M8F]X('1O('1U<FX@;V9F(%!.1R!T<F%N<W!A<F5N8WDN`$EM86=E(%!R979I
M97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E<P!);7!O<G0L(%-T97`@
M)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26YC;W)R
M96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD
M+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E
M(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R
M871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N
M=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R
M;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E
M<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R
M90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@
M;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G
M<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P
M:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E('1E
M;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C
M86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E
M<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E
M<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G
M<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W
M(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@
M86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF
M>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I
M="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I
M96YT(&-R961I="X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T
M:6]N+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T
M:6]N(&%D9')E<W,N`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C
M871I;VX@<')O=FED960N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN
M=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L
M:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@
M<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@
M=6YI8V]D92!D871A+@!);G9E<G0@<V5L96-T:6]N`$ER86XL($ES;&%M:6,@
M4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*97)S
M97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU
M<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS
M=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE
M8W1E9"!A=71H96YT:6-A=&EO;BX`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P
M<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!A;')E861Y(&5X:7-T<R!O
M;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L
M92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!1=6%R=&5R`$QA<W0@;&]G
M:6XZ("5S`$QA<W0@;&]G:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V
M97(`3&%T=FEA`$QA>6]U=`!,96)A;F]N`$QE9G0`3&5S;W1H;P!,:6)E<FEA
M`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6YK`$QI
M;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N
M(&1I<W!L87EI;F<`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC<P!,
M:7-T(%1A8FQE<P!,:7-T:6YG('-E<W-I;VYS(&9A:6QE9#H@)7,`3&ES=&EN
M9R!U<V5R<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N
M`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD
M(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@
M<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U3+51.148@071T86-H;65N
M="!C;VYT86EN960@;F\@9&%T82X`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%I;`!-86QA
M=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT80!-86YA9V4@=&AE(&QI
M<W0@;V8@8V%T96=O<FEE<R!Y;W4@:&%V92!T;R!L86)E;"!I=&5M<R!W:71H
M+"!A;F0@8V]L;W)S(&%S<V]C:6%T960@=VET:"!T:&]S92!C871E9V]R:65S
M+@!-87)C:`!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@
M9FEE;&1S`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>0!-87EO='1E`$UE;6)E
M<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@5F5R
M:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF:6-A
M=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-971H;V0`365T:&]D("(E<R(@
M:7,@;F]T(&1E9FEN960`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3
M=&%T97,@;V8`36EM92!4>7!E`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC
M871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I
M;&4@36%I;`!-;V1I9FEE9"!$871E`$UO;&1O=F$L(%)E<'5B;&EC(&]F`$UO
M;F%C;P!-;VYG;VQI80!-;VYT:&QY`$UO;G1S97)R870`36]O;B!0:&%S97,`
M36]R;V-C;P!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UY($%C8V]U;G0`37D@
M06-C;W5N="!);F9O<FUA=&EO;@!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E
M90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R
M;&%N9',@06YT:6QL97,`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE
M=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.
M97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP
M:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97=S`$YE
M=W-G<F]U<',`3F5X=`!.97AT(&]P=&EO;G,`3F5X=#X`3FEC87)A9W5A`$YI
M9V5R`$YI9V5R:6$`3FEU90!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D
M871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!C:&%N9V4N`$YO(&-H
M:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@
M8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!6
M1E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O
M<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I
M9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S
M=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@
M9F]U;F0N`$YO(&QO8V%T:6]N('!R;W9I9&5D+@!.;R!M97-S86=E('-U<'!L
M:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I9FEE9"X`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N
M+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC
M871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O
M=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R
M:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q
M=6]T82!S970N`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-U8V@@9FEL
M90!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L:60@
M6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U;F0@
M:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U
M<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO
M;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VYE`$YO<F9O;&L@27-L
M86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA
M;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O
M<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W9E
M;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O
M;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O
M<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J96-T`$]B
M:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F:6-E`$]L9"!P87-S=V]R9`!/;&0@
M<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E
M<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O;F4@96UA:6P@861D
M<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI
M<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S
M:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,
M(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O
M34E-12!P87)T+@!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]R9&5R960@3&ES
M=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG
M`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]T:&5R($EN9F]R;6%T
M:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y
M<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`
M4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)
M55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N
M`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!0
M87-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P
M<SH`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R
M9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S
M:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$
M96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`
M4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0:&EL:7!P:6YE<P!0:&]N90!0
M:71C86ER;@!0:7AE;',`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A
M<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`
M4&QE87-E(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O
M9B!D87ES(&EN('1H92!M;VYT:"X`4&QE87-E('!R;W9I9&4@82!S=6UM87)Y
M(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE
M(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N
M(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS('1O('5S92!T:&4@<WES
M=&5M+@!0;VQA;F0`4&]L;',`4&]R='5G86P`4')E9G-?;&1A<#H@4F5Q=6ER
M960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5F<U]S97-S:6]N.B!2
M97%U:7)E9"!S97-S:6]N(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R979I97<`
M4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P
M=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B
M;&5M($1E<V-R:7!T:6]N`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE
M<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A=&EO`%)E860`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@
M9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N
M`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@@1'EN86UI8R!-96YU
M($5L96UE;G1S.@!2969R97-H(%!O<G1A;"!6:65W.@!296QO860`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&9O<FUA='1I;F<`
M4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@
M;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E
M<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@
M97)R;W)C;V1E.B``4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN("5S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I
M;B!61E,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF
M:65D(&EN(&-O;F9I9W5R871I;VXN`%)E<V5T`%)E<V5T(%!A<W-W;W)D`%)E
M<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2
M971Y<&4@;F5W('!A<W-W;W)D`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@
M5&5X="!%9&ET;W(@3W!T:6]N<P!2:6=H=`!2;VQE`%)O;6%N:6$`4F]T871E
M(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`
M4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A
M<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W
M965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3
M+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E
M9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L
M92X`4U%,(%-H96QL`%-32`!354-#15-3`%-A`%-A:6YT($AE;&5N80!386EN
M="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N
M9"!-:7%U96QO;@!386EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!3
M86UO80!386X@36%R:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3875D:2!!
M<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M(B5S(BX`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE
M8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@
M;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E
M;&5C="!A;&P`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@
M=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@
M=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI
M;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L
M:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA
M=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE
M8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O
M<G0`4V5N9"!335,`4V5N96=A;`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT
M96YE9W)O`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!!9&UI;@!397-S:6]N<P!3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O
M<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M`%-E>6-H96QL97,`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@
M8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N
M8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H
M96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R
M/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L
M92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:')I;FL`
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3
M:6=N871U<F4@06QG;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E
M;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`4V]L;VUO;B!)<VQA;F1S`%-O;6%L
M:6$`4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@
M069R:6-A`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)
M<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA
M8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I
M;B!C96QL`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W)I($QA;FMA`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3
M=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T>6QE(%M#4U-=`%-U`%-U
M8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B;6ET`%-U8G-C<FEP=`!3
M=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`B)7,B('1O('1H92!S>7-T96TN
M`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E
M<W-F=6QL>2!R96UO=F5D("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E92!C
M:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I
M;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R871I
M;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@(B5S(@!3=6-C97-S
M9G5L;'D@=W)O=&4@)7,`4W5D86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T
M`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P
M97)S8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N
M9"!*86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>7)I
M86X@07)A8B!297!U8FQI8P!44U8@9FEL90!486)L92!0<F]P97)T:65S`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N
M`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:6QA;F0`5&AE($944"!E>'1E;G-I;VX@:7,@;F]T
M(&%V86EL86)L92X`5&AE($AI<W1O<GD@<WES=&5M(&ES(&1I<V%B;&5D+@!4
M:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C8V5S<V9U
M;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET:6YG+@!4
M:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P97)M86YE
M;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U<V4@4&5R
M;6ES<VEO;G,N`%1H92!C;VYT86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&-O;G1A8W0@=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y
M;W5R(&%D9')E<W,@8F]O:RX`5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@
M8FQO8VL@:7,@<F5Q=6ER960@=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G
M92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P
M96-I9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B
M87-E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N
M`%1H92!E;F-R>7!T:6]N(&9E871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B
M(&-O;FYE8W1I;VXN`%1H92!F:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@
M<V5T=&EN9RX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S
M971T:6YG<RX`5&AE(&9I;&4@8V%N;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!L;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN
M87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4
M:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N`%1H92!O<&5N
M<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M
M:6UE.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E
M('-A=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@
M86QL;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@
M9&%T82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4
M:&4@<75O=&4@8VAA<F%C=&5R(&UU<W0@8F4@;VYE('-I;F=L92!C:&%R86-T
M97(N`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-P96-I9FEE9"!R;W<@*"5D
M*2!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E
M<R!N;W0@97AI<W0N`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E
M('1H92!P<F5V:6]U<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N
M;W0@8F4@<V%V960N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER
M960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9FEE;&0@
M:7,@<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E
M9V5R<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD
M('1H92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L
M('9A;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@
M<V5P87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E
M(&$@=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O
M;&]R(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G
M(S$R,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E
M9"X`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E
M="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S
M('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY
M(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H
M:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD
M;W<`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;6]R+4QE<W1E
M`%1I=&QE`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H
M92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI
M8VMI;F<N`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]N9V$`
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N`%1R:6YI9&%D(&%N9"!4;V)A9V\`5'4`5'5N:7-I80!4=7)K97D`5'5R
M:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`5'EP
M92!Y;W5R(&-H;VEC93H@`%523`!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@
M86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES
M<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T
M;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B
M;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C
M;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@
M4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP
M='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L
M92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN
M`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@
M)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T
M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O
M;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@
M)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N
M86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O
M(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@
M5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`
M56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D
M*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V
M9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@
M9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R
M96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA
M;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FET960@07)A8B!%
M;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FMN;W=N`%5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;F%M960`56YP<FEV:6QE9V5D('-C
M<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I
M8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@
M82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y
M;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O
M87)D+@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5
M<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T
M960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL
M97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R
M;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`
M57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E
M<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`
M57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R
M871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R
M('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5
M<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA
M;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9A8V%T:6]N
M`%9A;&ED:71Y`%9A;G5A='4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL
M960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H
M+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!6:65T
M($YA;0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FER9VEN
M($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5V%L;&ES
M(&%N9"!&=71U;F$`5V%R;FEN9P!790!7965K;'D`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC
M871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@
M=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H
M87)A8W1E<C\`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H
M(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T
M:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@
M;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I<VAL:7-T`%=O<FL@
M061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@
M;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@
M;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E
M="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@U,#EV,R!"87-I8R!#
M;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3
M=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED
M96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!996%R;'D`665M
M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H
M879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L
M96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O
M;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D
M9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N
M(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO
M=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N
M=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B
M86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@
M<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E
M;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E
M<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG
M(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y
M+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T
M('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM
M86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U
M<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F
M875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S
M(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X
M<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`
M6F%M8FEA`%II;6)A8G=E`%M0<F]B;&5M(%)E<&]R=%T`6VQI;F4@)7,@;V8@
M)7-=`%]!9&UI;FES=')A=&EO;@!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP
M`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF
M>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN
M+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S
M(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`
M961I=`!E;G1R>2!N;W0@9F]U;F0`9FEL90!H;W-T(&YA;64@=6YK;F]W;@!I
M;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;`!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R
M96YC97,`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R
M90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N;F%M960`
M=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S+C$N,`I03U0M0W)E
M871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#,M,C(@,3(Z,#`K,#DP,`I,87-T+51R86YS;&%T;W(Z
M($AI<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B82YA8RYJ<#X*3&%N
M9W5A9V4M5&5A;3H@2F%P86YE<V4@/'5N:VYO=VY`=6YK;F]W;BYD;VUA:6X^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U32$E&5%]*25,*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@
M.&)I=`H`("@E<R"3^I%/*0"#08-.@UJ#6(-,@T,@)7,`@6DE<R"3^H+,D^""
MR8%J`"`HC:&3^BD`@6F6OI/Z@6H`("B-\)/Z*0`G)7,G((+-@V:#0H.,@TZ#
M9X.*@5N"Q8+-@J""Z(+<@KF"\8%"`"(E<R(@@LV0LX*U@J*129'P@L6"S8*@
M@NB"W(*Y@O&!0@`B)7,B((+-($AO<F1E((.,@U>#6(-G@XJ"R9#=DNB"LX+J
M@L2"HH+<@KF"\2X`(B5S(B"#8X.*@5N57(ZFBT"47(*JC*F5=(*I@NB"W(*Y
M@O&!0@`B)7,B((*J@T^#BX%;@W:#5H-8@V6#@(+)DL>)P8*S@NJ"W(*U@KV!
M0@`B)7,B((*J@T&#3H-:@UB,H(-6@UB#98.`@LF2QXG!@K."ZH+<@K6"O2X`
M(B5S(B""S8WLD*R"LX+J@MR"N8+Q@L6"M8*].B`E<RX`EV67RB`E,B0N,F9-
M0B"2AH+,("4Q)"XR9DU"((YGEW`H)3,D+C)F)24I`"5D("5S((+&("5S`(-P
M@UB#CX%;@VB"S8*@@L8@)60@D_J73(SX@L6"MX%"`)+*DFT@+2`E<P`E<R"3
M9(YQCG>6Y``E<R!+0@`E<R"5VX[GD8"-[(+,BFV41@`E<R""S)#=DN@`)7,@
M@U2#0X.3@T&#8H-V`"5S().OB-./\(V``"5S((+-BOF"R9&VC=V"M8+<@K>!
M0@`E<R""S8Z?@LF.=Y+H@K."ZH+$@J*"Z97;CN>1@(WL@O".P(US@K>"Z8^`
ME/6"JI"N@J*"W(*U@KV!0H[`C7."M8*]@J*1@(WL@LR#>X-B@TZ#6(+P@V"#
M1H-B@TZ"M8+$@JV"OH*S@J*!0@`E<R""JI5+EW:"Q8*W`"5S()6J`"5S((*J
M@J""Z(+<@KF"\8%"`"5S((*I@N<@)7.!08V'C'8@)7,`)7,@@LR#08-H@XR#
M6)*@`"5S((+,EUR2Z)5<`"5S((+,@X&#@I*@`"5S((+,@UZ#6(-.@XJ#6(-G
M`"5S.B`E<P`E<SH@@K&"S(.!@V*#6H%;@U>"S8ZF@K."ZH+$@J*"Z9&7D$V.
MTH*I@N>"S(+@@LR"Q8+-@LB"HH+&CG:"[8+J@MR"MX%"@KN"S)*&@LR#BH.3
M@TZ"\(-.@XJ#8H-.@K6"O8+H@4&,PI!LC^Z5\8+PD9>038*W@NF"S(+-CUR5
MJH+)DHV(TX*U@L2)NH*S@J*!0@`M+2"129'P("TM`#$RCIZ*U(Q@CJX`,C2.
MGHK4C&".K@`R-"".GHK4`#R13X+,@WF!6X-7`(*Q@LR#=8.-@V*#3H+)@LV#
M9H%;@UZ#>(%;@UB"JI5+EW:"Q8*W@4(`DG:6O9-)@LB#1X.)@5N"JI2MD+:"
MM8+<@K6"O0!01U",]HI*C*Z"JH.!@V*#6H%;@U>"S(C#C8:)NX+)E4N7=H+%
M@K>!0@!01U",]HI*C*Z"JH^0EKR"LX+J@KV#@8-B@UJ!6X-7@LR,GX_8@LF5
M2Y=V@L6"MX%"`%!'4(SVBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!
M6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF52Y=V@L6"MX%"`%!'4(SV
MBDJ,KH%!4$=0E.F6IXRN@JB"YH+1@W"#6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7
M@LR/D):\@LF52Y=V@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN
M@JB"YH+1@W"#6(-T@XR!6X-9@JJ(PXV&B;N#@8-B@UJ!6X-7@LR5G(V&@LF5
M2Y=V@L6"MX%"`%,O34E-18SVBDJ,KH%!4R]-24U%E.F6IXRN@JB"YH+1@W"#
M6(-T@XR!6X-9@JJ#@8-B@UJ!6X-7@LR/D):\@LF52Y=V@L6"MX%"`%,O34E-
M18SVBDJ,KH*J@X&#8H-:@5N#5X+,B,.-AHF[@LF52Y=V@L6"MX%"`$%-+U!-
M`(*Q@LR#1X-F@T*#7H%;@LF"PH*B@L0`5D93@V:#0H.,@TZ#9X.*@LR-[)"L
M@LV#08-.@UJ#6(N1E-N"LX+J@MR"M8*]@4(`5D93@W2#0(-#@XN"S(WLD*R"
MS8-!@TZ#6H-8BY&4VX*S@NJ"W(*U@KV!0@"#08-*@T6#DX-GC^Z5\0"#08-*
M@T6#DX-G@LR#<(-8@X^!6X-H`(-!@TJ#18.3@V>"S9.`C(N"LX+J@L2"HH+<
M@K>!0@"#08-*@T6#DX-G`)+'B<$`@U2#=8-/@XN!6X-V@O"2QXG!`(-4@W6#
M08-.@UJ#6(R@@O"2QXG!`(*Q@K&"R9+'B<$Z`)!6@K6"HH-/@XN!6X-V@O"2
MQXG!`)!6@K6"HH+P@T&#3H-:@UB,H(+PDL>)P0"#5(-U@T^#BX%;@W:"\"`B
M)7,B((+)DL>)P0"#5(-U@T&#3H-:@UB,H(+P("(E<R(@@LF2QXG!`)!6BTN#
MAH%;@U6"\)+'B<&!1@"7\8+PDL>)P0"05HM+@X&#DX-O@O"2QXG!@48`@WF#
M08+PDL>)P0`E<R"#@8-J@X6!6X+P($UO>FEL;&$@@LR#5(-#@VB#;X%;@LF2
MQXG!@K>"Z0"#08-H@XR#6)*@@LF2QXG!.@".A(+,@LR#08-H@XR#6)*@@LF2
MQXG!`(.&@5N#58+PDL>)P0"#5H-8@V6#@(+)("(E<R(@@O"2QXG!@K6"W(*U
M@KV"JH%!@U2#0X.3@T&#8H-V@LR/[I7Q@JJ2QXG!@L6"JX+<@KF"\8+%@K6"
MO8%&)7,`@U:#6(-E@X""R2`B)7,B((+PDL>)P8*U@MR"M8*]@LR"Q8%!@XV#
M3X-#@Y."Q8*K@MR"MX%"`(.&@5N#58+,DL>)P8^(EYV"S9:SC/B"R8+(@L&"
MQ(*B@MR"MX%"`(]:CXH`@T&#:(.,@UB2H`"*QY>=("T@D;R"S(.&@5N#58+,
M@T&#3H-:@UB,H`"*QY>=`$%D<P"#08-T@TN#:H-8@UZ#DP"#08.+@V^#:H-!
M`(-!@XN#5X-&@XJ#00"5RI:\`(C*DG61M8*F@48`D5.5E`"14Y1&C]B#AH%;
M@U4`D5."Q(+,@T^#BX%;@W8`D5."Q(+,@T&#3H-:@UB,H`"5H9"4@LR#08-H
M@XR#6(+PBY:)P@"4U(V&E72"JX.*@UB#9X+PD-V2Z(+%@JN"Z8+F@J2"R8*U
M@MR"MX*I@4@`BOF"R9&VC=V"M8+<@K<`D>.1UH+,($E-4U`@@XV#3X-#@Y,`
MD>.1UH+,($E-4U`@@W"#6(./@5N#:`"1XY'6@LP@24U34""#AH%;@U66O`"1
MXY'6@LR#@8%;@XN#08-H@XR#6`"1XY'6@LR#98.3@W:#C(%;@V<`D>.1UH-E
M@TR#6(-G@48`@T&#@8.*@TJ7S(-4@X*#00"5<Y"S@LB2;(*JCG>2Z(*S@NJ"
MQ(*B@MR"MP"77(KZ@K6"R(*B@T>#B8%;@JJ4K9"V@K6"W(*U@KT`@T&#DX-H
M@XD`@T&#DX-3@XF+I)AAC9$`@T&#DX-/@T*#B0"3O9:\@W:#C8-,@U:!6P"3
MFH*F`)/LB\F!:9'EEZ2!:@"#08.3@V6#0H-/@T&!18-O@5N#=8%;@U\`@T&#
M=H.*@U"!6X-6@X>#DP"#08-V@XJ#4(%;@U:#AX.3B.J7EP"#08-V@XJ#4(%;
M@U:#AX.3CF>7<(G"`(FZB,J"S(NDETR"R9-+EW``C[.41@""J(*H@N:"NX+,
M@U2#0X-9`()3C(X`@T&!6X-*@T.#=8-T@T"#0X.+@U2#0X-9`(-!@5N#2H-#
M@W66O``E<R""S(-4@T.#DX-!@V*#=I=VBX&"\)9[DY:"R8WMCYR"M8+$@J*"
MHH+%@K>"J8%(`)9[DY:"R2`B)7,B((+&@U2#=8-/@XN!6X-VD5."Q(+PC>V/
MG(*U@L2"HH*B@L6"MX*I/P"#08.+@UN#DX-@@Y.+I)AAC9$`@T&#BX.!@VJ#
M08NDF&&-D0"#08.+@V\`@T&#6H.3@U:#AX.3DX<`@T&#5X-!@5Z1OI6]EVV2
M;HCF`)7;CN>-[(O&@LR.P(USD4^"R8IME$:"\(N!@M^"Z8+F@J2"R8*U@MR"
MMX*I@4@`D;:-W8*U@LB"HH-/@XN!6X-V@O"-[8^<@K6"YH*D@L:"M8+<@K6"
MO8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"-[8^<@K6"YH*D@L:"M8+<@K6"
MO8%"`)&VC=V"M8+(@J*#08-.@UJ#6(R@@O"5TH]7@K6"YH*D@L:"M8+<@K6"
MO8%"`)&VC=V"M8+(@J*+I)=,@O"5TH]7@K6"YH*D@L:"M8+<@K6"O8%"`)&N
MD*L`@E>,C@"#28%;@UB#9X.)@XJ#00"#28%;@UB#9X.*@T&+I)AAC9$`075T
M:%]C>7)S<6PZ()5+EW:"R$E-05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!
M0@!!=71H7V-Y<G5S.B"#;X-B@TZ#1X.3@VB"S95+EW:"R)1<E\V"\)=,@K6"
MQ(*B@MR"N8+Q@4(`075T:%]C>7)U<SH@EW:+@8*W@NEI;6%PBF>2HX*JC*F"
MPH*I@NB"W(*Y@O&!0@!!=71H7V9T<#H@1E10BF>2HXM`E%R"JH+=@L*"J8+H
M@MR"N8+Q+B!02%""\"`M+65N86)L92UF='`@@TF#=H-6@X>#DX+P@L*"KX+$
M@U*#DX-P@T.#BX*U@LB"J(*U@L2"K8*^@K."HH%"`$%U=&A?:6UA<#H@24U!
M4(IGDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?:W)B-3H@:W)B-8IG
MDJ.+0)1<@JJ,J8+"@JF"Z(+<@KF"\8%"`$%U=&A?;&1A<#H@06-T:79E($1I
M<F5C=&]R>2""Q8+,@X:!6X-5DL>)P8+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"
M\0!!=71H7VQD87`Z($%C=&EV92!$:7)E8W1O<GD@@L6"S(.&@5N#58WMCYR"
MS8-4@WR!6X-G@K."ZH+$@J*"W(*Y@O$`075T:%]L9&%P.B!,1$%0BF>2HXM`
ME%R"JHRI@L*"J8+H@MR"N8+Q@4(`075T:%]L9&%P.B"#AH%;@U4@)7,@@O"2
MQXG!@L6"JX+<@KF"\8%"@U2!6X-O@LR)GI.:.B``075T:%]L9&%P.B"#AH%;
M@U4@)7,@@O"-[8^<@L6"JX+<@KF"\0!!=71H7VQD87`Z((.&@5N#52`E<R""
M\(U8D%:"Q8*K@MR"N8+Q`$%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2""
MQ8+,@X:!6X-5C5B05H+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\0!!=71H7VUC
M86PZ($U#05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!!=71H7W-M8F%U
M=&@Z('-M8F%U=&B*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!)34%0@U2!
M6X-O@L6"S)1&C]B"R8ZXE'."M8+<@K6"O8%"`)1&C]B"R8ZXE'."M8+<@K6"
MO0"41H_8@LF.N)1S@K6"W(*U@KV!0B5S`%)!1$E54X-4@5N#;X+)@N:"Z)1&
MC]B"JHN1E-N"LX+J@MR"M8*]@4(`1E10@U2!6X-O@LR41H_8@LF.N)1S@K6"
MW(*U@KV!0@!334*#5(%;@V^"S)1&C]B"R8ZXE'."M8+<@K6"O8%"`(YGEW")
MPI1<@LB#=(-"@5N#BX-H@48`@T&#6X.+@V^#0X-7@X.#DXNDF&&-D0"4=XQI
M`)1WC&F01@!+97)O8F5R;W,@@W"#6(./@5N#:(*JEK.,^(+%@K>!0@!+97)O
M8F5R;W,@@X:!6X-5EKR"JI:SC/B"Q8*W@4(`@V^#;H-]`(-O@5N#C(%;@Y,`
M@V^#DX-/@XF#9H-6@X60;):OBZ2888V1`(-O@XN#;X-H@U@`BNZ6>X-/@XF#
M=(-"@TZ#6(+,@V:#0H.,@TZ#9X.*@5L@(B5S(B""JH*@@NB"W(*Y@O&!0@"*
M[H^`D/P`@WB#B8.+@5N#5HNDF&&-D0"#>(.+@TV!6P"#>(.*@5N#60"#>(-I
M@Y.+I)AAC9$`@V^#?H.%@5N#7X%ICY23AX%J`(-U@5N#7H.3B:2-D0"289"V
MD_H`@W6#C8-B@TX@(B5S(B""S(-!@W:#BH-0@5N#5H.'@Y,@(B5S(B""JH*@
M@NB"W(*Y@O&!0@"#=8.-@V*#3I#=DN@`@W6#C8-B@TZ#7H-#@W8`D;Z.F@"#
M>X.*@W*#08NDF&&-D0"#=8-B@TZ#?8%;@TX`B8\`B8^"S)&^@K.!1@")CP"#
M>X-8@VJ#08%%@W>#BX-C@T:#4X-R@VD`@WN#8X./@VF+I)AAC9$`@W6!6X-X
MDX<`@W6#B8-7@XL`B7"7S(-#@Y.#:(^4DX<`@W6#BX-L@T.!18-?@XN#5(.)
M@5N#@`"#=8.+@TN#BH-!`(G3C_"/D8*K`(-U@XN#3(-I@W2#0(-<`(-U@XN#
MDX-7BZ2888V1`$--4P!#4D,`0U),()1ZE7J#?(-#@Y.#9P!?18-:@XN1KI"K
M+BXN`(-,@X.#8H-6@X6"S(^)BOJ)NX*JBJZ7N8*U@MR"N8+Q@L6"M8*]@4(`
MEUR2Z)5<`(-*@Y.#>X-7@T$`@TJ#@8.+@5N#DXNDF&&-D0"#<(-8@X^!6X-H
M@LV.J9.N@L6"S8.*@UJ#8H-G@L6"JX+<@KF"\8%"BL>7G8[2@LF809>-@K6"
MQ(FZ@K."HH%"`(-T@T"#0X.+("(E<R(@@LF/D8*O@MR"N8+Q@4(`BD^5E(+,
M@UJ#8H-6@X>#DX-N@Y.#:(.)@5N"S8K'EYV"Q8*K@MR"N8+Q@4(`24U!4""#
M5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@L6"M8*].B`E<P"#=(-`@T.#BR`B)7,B
M((*JBDJ"KX+<@KF"\8%"`(-*@VF#7P"#3(.#@Y.#6H.+`(_ABE&5\8V0@O"#
M3(.#@Y.#6H.+@K>"Z0"#=(-`@T.#BR`B)7,B((+PC>V/G(+%@JN"W(*Y@O&!
M0@"-[(O&@V:#0H.,@TZ#9X.*@JJ,J95T@JF"Z(+<@KF"\8%"`"=T87)G971&
M:6QE)R"#<(.)@X&!6X->@LB"M8+%@LV1L8US@L6"JX+<@KF"\8%"`(-F@T*#
MC(-.@V>#BH%;("(E<R(@@O"-[8^<@L6"JX+<@KF"\8%"`(WMCYR"Q8*K@MR"
MN8+Q@4*.<9&W@JH@)60@D;:-W8*U@MR"MX%"`)7`@M>1UH*F@LR1SH_;@LR0
ME(*JE=N1MH*S@NJ"Q(*B@NF0E(+&C8>"[8+(@J*"S(+%E<""UY'6@J:"JH+%
M@JN"W(*Y@O&!0@".=Y+H@K."ZH*]E-2-AH+)@X&#8H-:@5N#5X+PE'J1EX+%
M@JN"W(*Y@O&"Q8*U@KV!0@"#2H%;@WR#>(.+@V:+I)AAC9$`E5R1Z`"#3(.#
M@XJ#00"5JI?>@L:#B8-X@XL`@U"#0X-]@Y./E).'`(QGD=&39)AB`(-:@XN1
MKI"K`(-:@XN6A)&0@48`@UJ#BY&ND*L`@UJ#BY==E)*!1@",9Y'1DV288@"2
MAHF;`)*&B9N#08-T@XJ#2HNDF&&-D0"/V):^CY&"S(_:C=<`C]B6OH^1@LR/
MBI=,CM(`C]B6OH^1@WR#BH-6@5L`@V"#@X-HBZ2888V1`)7/C5@`@W"#6(./
M@5N#:(+PE<^-6`"39(YQ@X&#0X.+@LF.9Y=P@K>"Z9:\D4^"QH-!@VB#C(-8
M@O"5SXU8@K6"W(*W@4(`C+N-W8+,D-V2Z(+%@LV#<(-8@X^!6X-H@LR5SXU8
M@O"#5(-\@5N#9X*U@L2"HH+<@KF"\8%"BL>7G8[2@LF809>-@K6"Q(FZ@K."
MHH%"`%]+@XJ#DX-.@O"#8(-&@V*#3BXN+@"#8(.*BZ2888V1`)*&B=B0;):O
MBZ2888V1`(-!@W:#BH-0@5N#5H.'@Y.129'P@48`@W"#6(./@5N#:(+PD4F1
M\`"#AH%;@U66O(+PD4F1\`"3^I5TE5R.IHQ@CJZ!1@"#3H.*@UB#?8-8DX<`
M@TZ#B8-8DNB+8"`E<R""JHRIE72"J8+H@MR"N8+Q@4(`35,M3V9F:6-E@LR#
M7H-/@O".YH+HCYR"K0",GXWUC\&+C@"#AH%;@U6"S)'>BXZ!1B5S`(.&@5N#
M58_!BXX`@X:!6X-5@V:!6X->C\&+C@"#3H.*@V*#3H*W@NF"QHZ?@M8`@T6#
M0H.3@VB#18+PE<*"MH+I`(-2@U*#6(^4DX<`@U2#0X-H@V^!6X+PC_2"W@"#
M4H.-@Y.#<H-!BZ2888V1`)!&`)!&D4F1\`"01I%)D?``E_&!1@"7\8->@T.#
M9X.+`(-2@WZ#8H-.@U@`@U*#?8.3@V@`@U*#?8.3@VB#5H-&@XL`@U*#@8.3
M@V<`BZ22RI:\`(-2@X*#C9A!C8<`B>^.T`"0W9+H@LR-MY6J`%!$08%!@UB#
M?8%;@V>#=(-(@Y.!04]U=&QO;VN"QH+,DZ^*^H+PD-V2Z(*U@MR"MX%"`)#=
MDNB"S8_<EJ&*^HS`D-B"ZH+%@K>!0@`E<R""\)#=DNB"MX+I`(-P@UB#CX%;
M@VB"\(IME$8`@U*#DX-3BZ2888V1`(-2@Y.#4Y:OCN6+I)AAC9$`D-J1L8ZX
ME'.!0@"0VI&QCKB4<X%&`(SVCT^,KH-4@5N#;X+6@LR0VI&Q@JJ+D93;@K."
MZH+<@K6"O8%"`(SVBDJ,KH-4@5N#;X+6@LR0VI&Q@JJ+D93;@K."ZH+<@K6"
MO8%"EYV74H%&)7,@*"5S*0!&5%"#5(%;@V^"UH+,D-J1L8+)CKB4<X*U@MR"
MM8*]@4(`F$&7C9#F`)A!EXV0YH+-@T&#:(.,@UB2H(+)DL>)P8*S@NJ"W(*U
M@KV!0@"(LX]K@W2#0(-#@XN"S(-2@Y.#98.3@V.#7H-#@W:!1@`B)7,B((+,
MD^"790"1L8*M`(-.@V*#3H^4DX<`@U*#<X%;`(-2@W.!6XZXE'.!1B5S`)%)
MD?"4S8C-@O"#4H-S@5L`@U*#6(->@XJ#2HNDF&&-D0"#4H%;@V>#5X-[@X^!
M6X.+BZ2888V1`(.!@V*#6H%;@U>"S"!01U`@B,.-AHF[@JJ"Q8*K@MR"N8+Q
M@L6"M8*]@4(`@X&#8H-:@5N#5X+,(%!'4""/D):\@JJ"Q8*K@MR"N8+Q@L6"
MM8*]@4(`@X&#8H-:@5N#5X+,(%,O34E-12"(PXV&B;N"JH+%@JN"W(*Y@O&"
MQ8*U@KV!0@"#@8-B@UJ!6X-7@LP@4R]-24U%((^0EKR"JH+%@JN"W(*Y@O&"
MQ8*U@KV!0@"809>-D.:"\)+'B<&"Q8*K@MR"N8+Q@L6"M8*]@4(E<P!,1$%0
M((-4@5N#;X+)@V^#0X.3@VB"Q8*K@MR"N8+Q@L6"M8*]@4(`CF.-@H*JBFV4
M1H+%@JN"W(*Y@O&"Q8*U@KV!0B5S`$Q$05`@@U2!6X-O@LF0VI&Q@L6"JX+<
M@KF"\8+%@K6"O8%"`$944"""Q8-4@5N#;R`B)7,B((+)D-J1L8+%@JN"W(*Y
M@O&"Q8*U@KTZ("5S`)&7D$V0YH.*@UB#9X*JC>R0K(+%@JN"W(*Y@O&"Q8*U
M@KV!0B5S`%!'4""#9H%;@UZ"S)6<C8:)NX*J@L6"JX+<@KF"\8+%@K6"O3H`
M4R]-24U%((-F@5N#7H+,E9R-AHF[@JJ"Q8*K@MR"N8+Q@L6"M8*]@4(`F$&7
MC9#F@JJ-[8^<@L6"JX+<@KF"\8+%@K6"O8%")7,`D9>039#F@XJ#6(-G@JJ-
M[8^<@L6"JX+<@KF"\8+%@K6"O8%")7,`D-V2Z(U8D%:7<(-8@TZ#BH-V@V<@
M(B5S(B""\(WMCYR"Q8*K@MR"N8+Q@L6"M8*]@4(`CO.038[2@LR39(YQ@X&!
M6X.+@T&#:(.,@UB"JHIMDNB"Q8*K@MR"N8+Q@L6"M8*]@4(`@T&#:(.,@UB2
MH(*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"`)&7D$V0YH.*@UB#
M9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"`)&7D$V0YH.*@UB#
M9X*JBJZ14X+)@LV.YI.^@L6"JX+<@KF"\8+%@K6"O8%"`(-8@V>#B8-E@U>!
M6R`B)7,B((+P@XV!6X-H@L6"JX+<@KF"\8+%@K6"O8%"`$UK9&ER("(E<R(@
M@LF.N)1S@K6"W(*U@KV!0@",]HI*C*Z"\(RN@U2!6X-O@JF"YX[FD[Z"Q8*K
M@MR"N8+Q@L6"M8*]@4(`(B5S(B""\(^1@JN-GH+=EW""R8-)@5N#=H.3@L6"
MJX+<@KF"\8+%@K6"O8%"`"5S((+P@TF!6X-V@Y."Q8*K@MR"N8+Q@L6"M8*]
M@4(`E=N.YXWLB\:#@H-7@X6!6X.+("5S((+PBDJ"KX+<@KF"\8+%@K6"O8%"
M`(-F@T*#C(-.@V>#BH%;("(E<R(@@JJ*2H*O@MR"N8+Q@L6"M8*]@4(`3$1!
M4""#5(%;@V^"R9#:D;&"Q8*K@MR"N8+Q@4(`)7,@@JJ3QX+=CV^"N8+<@KF"
M\8%"`)=VBX&"LX+J@KV#AH%;@U6"S(-P@UB#CX%;@VB"\(.*@UJ#8H-G@L6"
MJX+<@KF"\8+%@K6"O8%"@J*"K8+"@JF"H(+I@J*"S9%3@L2"S(_NE?&"S8K4
MB.&"P8+$@J*"W(*W@4*-Q)-XCHZ"M8+$@MV"Z8*IBL>7G8[2@LF809>-@K6"
MQ(FZ@K."HH%"`$%#3"""\([FD[Z"Q8*K@MR"N8+Q@L6"M8*]`(-!@VB#C(-8
MDJ""\([FD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"1EY!-D.:#BH-8@V>"\([F
MD[Z"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"1EY!-D.:#BH-8@V>"\([FD[Z"Q8*K
M@MR"N8+Q@L6"M8*]@4(E<P"#5(%;@V^"S(M`E%R(ZI>7@O".YI.^@L6"JX+<
M@KF"\8+%@K6"O0"0W9+H@O",LX+)EM^"N8+<@KF"\8+%@K6"O8%"`"(E<R(@
M@V:#0H.,@TZ#9X.*@5N"JHWMCYR"Q8*K@MR"N8+Q@4(`)7,@D-V2Z(+PE=N1
MMH+%@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:"\)7;D;:"
MQ8*K@MR"N8+Q@L6"M8*]@4(`D-V2Z(+,@V^#8H-.@T&#8H-V@O"5VY&V@L6"
MJX+<@KF"\8+%@K6"O8%&)7,`D-V2Z(U8D%:7<(-8@TZ#BH-V@V>"\"`B)7,B
M((+)E=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0@"0W9+H@LR#;X-B@TZ#08-B@W:#
M=(-`@T.#BR`E<R""\)7;D;:"Q8*K@MR"N8+Q@L6"M8*]@4(`D-V2Z(-T@T"#
M0X.+("5S((+)E=N1MH+%@JN"W(*Y@O&"Q8*U@KV!0B5S((+)EM^"P8+$E=N1
MMH-)@W:#5H.'@Y."\([`C7."MX+I@JF!08[H@L6"L8+,B>:6RH+,@U*!6X-H
M@O`@)7,@@LF#4H-S@5N"M8+$B;J"LX*B@4(`3$1!4""#5(%;@V^"JHR?C?6"
MQ8*K@MR"N8+Q@4(`(B5S(B""\(WMCYPH=6YL:6YK*8+%@JN"W(*Y@O&"Q8*U
M@KV!0@"809>-D.:"\(U8D%:"Q8*K@MR"N8+Q@L6"M8*]@4(E<P"1EY!-D.:#
MBH-8@V>"\(U8D%:"Q8*K@MR"N8+Q@L6"M8*]@4(E<P`B)7,B((+,D-V2Z(*J
MCY&"JXV>@M^"W(*Y@O&!1B5S`$UO>FEL;&$@@LR#5(-#@VB#;X%;@JJ,J95T
M@JF"Z(+<@KF"\8%"@U2#0X-H@V^!6X+PBDJ"HH+$B;J"LX*B@4(`C9$`C>R0
MK`"05HM+C>R0K`"#5(-U@W2#2(.+@U^"\(WLD*P`C>R0K([2@LR#08-.@UJ#
M6(R@`(-.@XR#5X-B@V>#2H%;@VB4U(V&`(-.@XV#08-@@T&+I)AAC9$`@TR#
MA8%;@V^+I)AAC9$`C+N-W8+,@UJ#8H-6@X>#DP",NXW=@LR.GHK4`(R[C=V"
MS"!54DP@@LT`C+N-W8+,@X:!6X-5@5L`)7,@@M:"S(.-@T^#28.3CIZ"R8[`
MC7."MX+I@UZ#6(-.@O"0W9+H@K6"W(*W@4(`D-B"Z([F@N@`D4F1\)3-B,V"
M\)#8@NB.YH+H`(-,@W:#C8-8BZ2888V1`(-@@T:#4HNDF&&-D0"3^@"6B)/Z
M`$1A=&%4<F5E((E[EY<`@V:!6X->@WB!6X-8CE&/Q@"3^I5T`(-F@5N#7H[S
MD$T`D_J5=)%)D?``7TR7\8+,C>V/G``Q,HR.`(]<D&F0E`"2:8FZ@K""\)#S
M@JT`@V:#=(-(@XN#9P"#9H-T@TB#BX-GD$8`@V:#=(-(@XN#9R!)1`"#9H-T
M@TB#BX-G('-H96QL`(WMCYP`@UJ#BXWMCYP`@T^#BX%;@W:"\(WMCYP`@XV#
M3X+,C>V/G`"#08-.@UJ#6(R@@O"-[8^<`(-:@XN-[8^<`)?Q@LR-[8^<`)'C
MD=:#98.3@W:#C(%;@V>"S(WMCYP`@X&#8H-:@5N#5X+PC>V/G``B)7,B((+,
M@T&#3H-:@UB,H(+PC>V/G``B)7,B((+,@T&#3H-:@UB,H(+&@KN"S(-4@W6#
M08-.@UJ#6(R@@O"14X+$C>V/G(*U@MR"MX*I@4@`C7."S(WMCYP`D4F1\(*U
M@KU)1(+PC>V/G`"#5(-U@W2#2(.+@U^"\(WMCYP`C+N-W8C*DG6"S)?Q@O"-
M[8^<`(R[C=V(RI)U@LR-<X+PC>V/G`"0W9+HC5B05I=P@UB#3H.*@W:#9R`B
M)7,B((+PC>V/G(*U@MR"M8*]@4(`E'J1EXZ>BM0`@V:#DX-]@5N#3@"/X8I1
MD^"798+,D."6O@"0X):^`(_:C=>!:4AO<F1E@LR#C8-/@W2#0(-#@XN"X(Y1
MC\:!:H%&`(_:C=>"S8K'EYV.TH+,@KV"WX+)BTR87H*S@NJ"W(*U@KV!0@"*
M2I2M`(VV@JF"YXE%@M8`B46"J8+GC;:"U@`R-(Z>BM257(ZF`)5<CJ:#28-V
M@U:#AX.3`(-7@W6#8(NDF&&-D0"-[8^<@K6"R(*B`&UA:6YT96YA;F-E+G!H
M<"""R9*\D-J#08-.@UJ#6(*U@LB"HH+%@JV"OH*S@J(`C<6/B8+,E_&"JH-T
M@T*!6X.+@VB6O(+PBMR"\8+%@J*"W(*W@JD_((*[@J2"R(+G@V"#1H-B@TZ"
MM8+$@JV"OH*S@J*!1@"#:(-^@VJ#2@"#:(-^@VJ#2HNDF&&-D0"#08-*@T6#
MDX-G@JJ52Y=V@LB"YX-4@T.#DX-!@V*#=H%"`(-?@T6#DX.-@5N#:``E<R""
MS(-?@T6#DX.-@5N#:`"0MI"L@K."ZH*]D-V2Z(+P(%!(4""#6(-.@XJ#=H-G
M@O""QH*U@L2#7X-%@Y.#C8%;@VB"MX+I@4(`DV2.<8.!@5N#BP"#1X-.@T&#
M:(.+BZ2888V1`)72CU<`@W6#C8-B@TZ"S)72CU<`@T^#BX%;@W:"S)72CU<`
M@T&#3H-:@UB,H(+,E=*/5P"#08-.@UJ#6(R@@LR5TH]7`"5S((+,@T&#3H-:
M@UB,H(+,E=*/5P"#28-V@U:#AX.3@LR5TH]7@48`(B5S(B""S(-!@TZ#6H-8
MC*""S)72CU<`)7,@@LR#08-.@UJ#6(R@@LR5TH]7`(-'@U>#=H-G@46#08.)
M@W6+I)AAC9$`@T>#BX-4@XN#;X-H@XN+I)AAC9$`DV2.<8.!@5N#BP!%@X&!
M6X.+@T&#:(.,@U@`18.!@5N#BX-!@VB#C(-8@JJ(ZI)V@K6"R(*O@NJ"SH*B
M@J^"W(*Y@O&!0@!%@X&!6X.+@T&#:(.,@UB*;91&`(OS@X&#8H-:@5N#5X+%
M@K>!0@")O8+@C*F"PH*I@NB"W(*Y@O&!0@"+\X+,C)^-]8SJ`(--@X.#B8.*
M@5N"J8+GB>:1G(+PD7V3_(+%@JN"Z8+F@J2"R8*U@MR"MX*I@4@`B46#3H.*
M@V*#3H+%@X&#:H.%@5N"\)5<CJ:"M8+<@K>"J8%(`(-'@V:#0H->@5N)YI;*
M@O"1Y8*K@JT`@J""R(*]@LR#<(-8@X^!6X-H@O"#BH-:@V*#9X*W@NF.GH+,
MEW"04X+,@KV"WX+,CK^6XH+PD_R7S8%"E^&"IH+.@4&!=8-Y@V*#9X+,EKR1
M3X+-@4B!=H%&`(GFD9R"S%523(+PD_R7S0"0U).Y@TV#:H-!BZ2888V1`(-'
M@XJ#9X.*@T$`@T>#B8%;`(-U@XV#8H-.C>R0K(-'@XF!6SH@)7,N`).OBOJ#
MC8-/@LR-[8^<@T>#B8%;.B`E<RX`D^"798[FD[Z#1X.)@5LZ("5S+@"#<(-8
M@X^!6X-HC5B05H-'@XF!6SH@)7,N`(.!@5N#BX-!@VB#C(-8@LR#1X.)@5N"
MQ8*W@4(`(B5S(B""S(^1@JN-GH+=@T>#B8%;@L6"MX%"`(-'@UB#9X-J@T&+
MI)AAC9$`@T>#8(-)@W.#00"#B(%;@XV#8H-P`#$UE:J6B``RE:J6B``S,)6J
MEH@`-96JEH@`@XV#3X-#@Y.6B``S,)6JEH@`,96JEH@`CG>2Z))L@LR7X0".
MP(US`)-7BDH`@U2#0X-H@V^!6X+PDU>*2@`G*2<@@O"35XI*`)=,C/B*^HS`
M`(YWD)0`D4^,:9!&`)#=DNB"\"!&5%`@@L6#08-B@W:#C8%;@VB"MX+I`(-V
M@XR#=(-`@XR#DX-8D-V2Z(+PCN:3OH+%@JN"W(*Y@O&!0@!,1$%0((-4@5N#
M;X+)D-J1L8+%@JN"W(*Y@O&"Q8*U@KV!0@!334(@@U2!6X-O@LF0VI&Q@L6"
MJX+<@KF"\8+%@K6"O8%"`"(E<R(@@JF"YX+,@U*#<X%;@LF.N)1S@K6"W(*U
M@KV!0@`B)7,B((+6@LR#4H-S@5N"R8ZXE'."M8+<@K6"O8%"`)!6BTN"S"!3
M05-,()#:D;&"R8ZXE'."M8+<@K6"O8%"`"(E<R(@@M:"S(C:DZZ"R8ZXE'."
MM8+<@K6"O8%"`([FD[Z"R8ZXE'."M8+<@K6"O8%&)7,`@W2#2(%;@TZ#B8.3
M@VB/E).'@6F#?8.+@W*#:8-8CY23AX%J`(-T@T:#C8%;CY23AP"2=I:]DTF#
M1X.)@5N!1@!&05@`1D%8`()1C(X`@W2#0H-7@5N/E).'BZ2888V1`(-T@T"#
M0X.+`(-T@T"#0X.+D)0Z("5S((-T@T"#0X.+`(-T@T"#0X.+D)0Z("5S((-T
M@T"#0X.+`(-T@T"#0X.+@WV#;(%;@U>#@P"#=(-`@T.#BY:\`(-T@T"#0X.+
MD4F1\`"#=(-`@T.#BX-!@V*#=H.-@5N#:`"#=(-`@T.#BX-!@V*#=H.-@5N#
M:(+-@U2#?(%;@V>"LX+J@L2"HH+<@KF"\8%"`(-T@T*#BX->`(-T@T*#DX.)
M@Y.#:(NDF&&-D0"/XXRW@LR,C@"#=(-(@XN#7X%;("5S((*J@J""Z(+<@KF"
M\0"5MHZ:D$8`B>:1G(+P@U2#?(%;@V>"M8+(@J*#=8.)@T6#59=P`(-P@UB#
MCX%;@VB"\)99@NJ"Q(*U@MR"HH+<@K6"O8*I@4@`@W2#2(%;@X``@W2#2(%;
M@XF#@`"+X`"89P"#=(.)@Y.#6(NDF&&-D0"#=(.)@Y.#6(%IEGN-D8%J`(-T
M@XF#DX-8E\R#38-!@VD`@W2#B8.3@UB7S(-\@XJ#;(-6@T$`@W2#B8.3@UB7
MS(O)D^R/E).'`(_:@K6"HI#@EKX`EIZ,C@".@9:\`(-+@WN#DXNDF&&-D0")
MYI&<@O".YH+HCV^"MX--@X.#B8.*@5L`@TV#@X.)@XJ!6X%&`(-+@Y.#<H-!
MBZ2888V1`"5S((U<D*R/[I7Q@O"0MI"L@K>"Z0"0MI"L@K."ZH*]@U*!6X-H
M`(-/@XN#5X-!BZ2888V1`(-H@T.#8YA!EDV+I)AAC9$`@TN!6X-IBZ2888V1
M`(-7@W6#B8.+@UZ#BP"0J0"+I)+*@TF#=H-6@X>#DP!';V]G;&4@@WV#8H-V
M`$=O;V=L92",GXWU`(--@XJ#5H.#BZ2888V1`(-/@XJ!6X.3@XF#DX-H`(-/
M@XR#:8-?`(-/@XN!6X-VBL>7G0"#3X.+@5N#=I:\@LV+\Y22@L6"S8+(@J*"
ML8+&`$=R;W5P7VQD87`Z((-/@XN!6X-V("5S((+PDL>)P8+%@JN"W(*Y@O&!
M0H-4@5N#;X+,B9Z3FCH@`$=R;W5P7VQD87`Z((-/@XN!6X-V("5S((+PC>V/
MG(+%@JN"W(*Y@O$`1W)O=7!?;&1A<#H@@T^#BX%;@W8@)7,@@O"-6)!6@L6"
MJX+<@KF"\0"#3X.+@5N#=@"#3X-!@VB#BX%;@W:3AP"#3X-!@X"3AP"#3X-!
M@V6#?8.)BZ2888V1`(-+@5N#DX-7@5N3AP"#48-8@V>#08-.@UJ#6(R@`(-1
M@UB#9X-U@V*#3@"#38-J@T&+I)AAC9$`@TV#:H-!@W*#5(-%BZ2888V1`(-+
M@T.#08-IBZ23KXNDF&&-D0!(5%10()1&C]B"JH+=@L*"J8+H@MR"N8+Q@4(`
M@VZ#0X-@BZ2888V1`(-N@V*#5H.%@T&#BX-3@XJ#68.``(-W@V*#7P"#=X-B
M@U\`@VZ!6X-H@46#?8-.@VB#:8.+@VB/E).'`(V"@K,`@W>#BX-V`)2\BX4`
M@WJ!6X.``(.-@5N#?99`B:22H8%I@V^#8(-*@Y..<XV1@6H`@WJ!6X.``(ZI
MD>Z"S(]:CXH`@WJ!6X.`@V:#0H.,@TZ#9X.*@5L`CJF1[H+,DV288I34C88`
M@WJ#DX-7@X6#B8-8BZ2888V1`(V!C6``2&]R9&4`2&]R9&4O2V]L86(Z()5S
MD+."R"!834P@@V:!6X->("5S((*J@X&#8H-:@5N#5R`E<R""Q8R?CV^"LX+J
M@MR"M8*]`$AO<F1E+TMO;&%B.B"#28-U@U>#1H-.@V<@)7,@@LF1SHF>@K>"
MZ8.!@V*#6H%;@U>"S8*@@NB"W(*Y@O$`2&]R9&4O2V]L86(Z((-)@W6#5X-&
M@TZ#9XQ>("5S((+-@X&#8H-:@5N#5R`E<R""R8+-@J""Z(+<@KF"\0!(;W)D
M92]+;VQA8CH@)7,@@LV-[8^<@K."ZH+<@K6"O2`B)7,B`$AO<F1E+TMO;&%B
M.B!02%`@BF>2HR`G9&]M>&UL)R""JI5+EW:"Q8*W`$AO<F1E+TMO;&%B.B"#
M28-U@U>#1H-.@V<@)7,@@LP@6$U,((-C@XJ!6X*JC>R0K(+%@JN"W(*Y@O$`
M2&]R9&4O2V]L86(Z("5S((*JC>V/G(+%@JN"W(*Y@O$@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z("5S((+,($U)344@240@@JJ.YI.^@L6"JX+<@KF"\0!(;W)D
M92]+;VQA8CH@)7,@@L:3KXKZ@L6"JX+<@KF"\2`B)7,B.B`E<P!(;W)D92]+
M;VQA8CH@DZ^*^H+%@JN"W(*Y@O&!1B5S`$AO<F1E+TMO;&%B.B`B)7,B((+-
ME7.6OH+(BZ273(+%@K<`D(65O9#\`(*B@JV"PH+,E_&"\(R+C8>"M8+<@K>"
MJ8%(`(-T@T*!6X.+@V@HC7,I@LR0E(+-@J*"K8+"@L6"MX*I@4@`@J*"K8+"
M@LR-<X+PC(N-AX*U@MR"MX*I@4@`@VZ#DX-+@XJ!6XNDF&&-D0!)34%0((.!
M@5N#BX-[@V*#3H-8@LR-[)"L@LF.N)1S@K6"W(*U@KTZ("5S`$E-05`@@X&!
M6X.+@WN#8H-.@UB"S(WMCYR"R8ZXE'."M8+<@K6"O3H@)7,`24U!4""#@8%;
M@XN#>X-B@TZ#6(-.@TB!6X->@LR-[)"L@LF.N)1S@K6"W(*U@KTZ("5S`$E0
M((-!@VB#C(-8`$E0((-!@VB#C(-8@JJ"H(+H@MR"N8+Q@4(`25"#08-H@XR#
M6(*JBY:)PH*S@NJ"O4-)1%*#=8.-@V*#3I/@@LF"H(+H@MR"N8+Q@4(`25"5
ME8V]B.&4O8+%@K>!0@"#08-#@UB#B8.3@VB+I)AAC9$`@T&#0X-2@Y."S(+=
M`"5S((+,@T&#0X-2@Y,`@T&#0X-2@Y."QH-E@TR#6(-G`$E$@LR6O)%/`(+@
M@K6"X)"S@K6"K95<CJ:"LX+J@LB"HH+(@N>!025S((*U@L205H*U@J*#18-#
M@Y.#:(%;@O"*2H*B@L2)NH*S@J*!0@""X(*U@N`@26YT97)N970@17AP;&]R
M97(@@O".9X+!@L2"HH+$@4&#08-#@U*#DX*JE5R.IH*S@NJ"R(*B@LB"YX%!
M@K&"L8+PD4F1\(*U@L2)NH*S@J*!0@")YI&<@W:#C(-R@X6!6P")YI&<(%52
M3`")YI&<(%523#H`B>:1G`"#0X.3@WR!6X-G@4&#6(-E@V*#=B`E9`"#0X.3
M@WR!6X-G@K."ZH*]@W2#0H%;@XN#:(%&("5S`(-#@Y.#?(%;@V>"LX+J@KV#
M=(-"@5N#BX-H@48`BM2(X8+!@KV#08-.@U:#AX.3@U*!6X-H@JJ77H*F@N>"
MZH+$@J*"W(*W@4(`@X:!6X-5EKR"J8-P@UB#CX%;@VB"JI"S@K6"K8*@@NB"
MW(*Y@O&!0@"#AH%;@U66O(*ID>.1UH-!@VB#C(-8@JJ0LX*U@JV"H(+H@MR"
MN8+Q@4*-Q)-XCHZ"M8+$@MV"Z8*I@4&*QY>=CM*"R9A!EXV"M8+$B;J"LX*B
M@4(`DFF)NH*P@O"06X*M`(-#@Y.#:`",PI7*@X:!6X-5`(-#@Y.#:(-L@U:#
M08NDF&&-D0"/[I7Q`(-#@Y.#=(-(@X&!6X-6@X>#DP!?3XSC@NN"R9?Q@O"1
M?9/\`(GFD9R"\)%]D_P`E5R"\)%]D_P`@XJ#DX-.@O"1?9/\`%]#D4^"R9?Q
M@O"1?9/\`(R[C=V(RI)U@LR,XX+K@LF7\8+PD7V3_`",NXW=B,J2=8+,D4^"
MR9?Q@O"1?9/\`(R[C=V(RI)U@LR,XX+K@LF-<X+PD7V3_`",NXW=B,J2=8+,
MD4^"R8US@O"1?9/\`(R[C=V(RI)U@LR,XX+K@LF2:9>.@O"1?9/\`(R[C=V(
MRI)U@LR13X+)DFF7CH+PD7V3_`"1XY'6@V6#DX-V@XR!6X-G@LR1?9/\`)!6
M@K6"HH-P@UB#CX%;@VB"\([S@J^.YH+I@X&!6X.+@T&#:(.,@UB"\)/\E\V!
M1@",XX+K@LF#6H.+@O"1?9/\`)%/@LF#6H.+@O"1?9/\`(SC@NN"R9?Q@O"1
M?9/\`)%/@LF#6H.+@O"1?9/\`(.!@V*#6H%;@U>"\)%]D_P`C.."ZX+)DFF7
MCH+PD7V3_`"13X+)DFF7CH+PD7V3_`",XX+K@LF-<X+PD7V3_`"13X+)C7."
M\)%]D_P`EW"04X+,@KV"WX+,CK^6XH+,DYJ"IH+PD_R7S8%&`(GFD9R"S)%]
MD_R!7I7/C5@`@XJ#DX-.@LR1?9/\@5Z5SXU8`)&7D$V0YH+)D9>"Z8*]@M^"
MS(YCC8*"JI5SD:N"M8+$@J*"W(*W@4(`CF.-@H*JE7.1JX+%@K>!0@"5<Y"S
M@L@@6FEP((-F@5N#7H+%@K>!0@"5<Y"S@LB#08-V@XJ#4(%;@U:#AX.3@L6"
MMX%"`):SC/B"R(-F@5N#7H*JDO&/;X*S@NJ"W(*U@KTN`)&7@NB0YH+,@T&#
M:(.,@UB"JI5SD+."Q8*W@4(`E7.0LX+(@XF#0X-:@Y.#6(-,@T."Q8*W@4(`
ME7.0LX+(C^J/BH*JCG>2Z(*S@NJ"W(*U@KV!0@"/XXC*@LR#08-.@UJ#6(R@
M@JJ5<Y"S@L6"MX%"`)5SD+."R(-P@5N#9X-I@5M)1(+%@K>!0@"5<Y"S@LB0
MNY5I@U*!6X-H@L6"MX%"`)5SD+."R(-V@XV#9X-2@XN"Q8*W@4(`E7.0LX+(
MCO.038[2@L6"MX%&(B5S(@"5<Y"S@LB+I)=,@TF#=8-7@T:#3H-G`)5SD+."
MR)2MD$V,LX-!@VB#C(-8@L6"MX%"`)5SD+."R'5N:6-O9&6#9H%;@UZ"Q8*W
M@4(`D4F1\(+PE+V370"#0X.)@Y.!18-#@UB#B8.`BZ2888V1`(-#@XF#3HND
MF&&-D0"#08-#@XN#B8.3@V@`@WV#DY.'`(-#@UB#B8-'@XL`E*V-<X[2`([.
MD<P`@T.#7H.*@T&+I)AAC9$`@U>#@X-]@T.#2@""4(R.`)/ZEGL`@U>#@X%;
M@U>!6Y.'`(.(@XN#7X.3`()6C(X`@E6,C@"1M8*F@ND`DH:)FY&U@J8`E[R2
M6Y&U@J8`C;:1M8*F`(E%D;6"I@"#2H-5@W2#6(->@Y.+I)AAC9$`@TF#BH-7
M@VF#BX+PE=N1MH%(`(-0@VJ#08NDF&&-D0!+97)B97)O<R"#5(%;@V^"JI1&
MC]B+D93;@K6"W(*U@KV!0@",KHWLD*R3^@",KHYWEN0`C*Z2MP",KH[ME]X`
MDV2.<8RN@JJ"MX+%@LF,]H]/C*Z#5(%;@V^"R9&VC=V"M8+<@K>!0@"#3(.*
M@V^#6(NDF&&-D0"2J9%.EJ^.Y8[EBV"0;):OBZ2888V1`)'EBMB6KXV1`(-.
M@T6#1H%;@V<`@TR#BX--@UB+I)AAC9$`7UF#C(-#@T&#18-G`(R^C.H`@XF#
M28-8D&R6KY:OCN6+I)AAC9$`B;J,MX+,C(X`D4^)\8+,@XV#3X-#@Y,Z("5S
M`)%/B?&"S(.-@T^#0X.3.B`E,B1S((*I@N<@)3$D<P"13XGQ@LR#C8-/@T.#
MDSH@@LB"M0"#B8-G@W*#08NDF&&-D0"4>I)U`(.,@V^#;8.3BZ2888V1`(VV
M`(.,@UR#9XFDC9$`@XJ#>(.*@T&+I)AAC9$`D>6#BH-R@T&!18-!@XF#=8[0
MB>^.Y8M@D&R6KX-7@X.#?8%;@W&#BH%;@X0`@XJ#<8-E@Y.#5H.%@UZ#0X.3
MC/:-D0"#BH.3@TX`@X&!6X.+C>R0K)=P@LF#@8%;@XN#08-H@XR#6(+)@XJ#
MDX-.@K>"Z0"#9H%;@UZ#>(%;@UB(ZI>7`(-W@XN#=HV`EMJ"\)5<CJ:"MX+I
M`)5<@LR(ZI>7`(-:@V*#5H.'@Y."S(CJEY>-[)"L@LF.N)1S@48E<P"#AH%;
M@U6"S(CJEY>-[)"L@LF.N)1S@48E<P"#AH%;@U6"S(.*@UB#9X+-EK.,^(+)
M@LB"P8+$@J*"W(*W@4(`@XJ#9X-!@VJ#08NDF&&-D0"#C8%;@VB2ABXN+@",
MNY)NCIZ*U(%&`))NB.:"QHZ>BM0`C^J/B@"#C8-/@T.#DP"#C8-/@T&#18-G
M`(.-@T^#0X.3`(.-@T^#0X.3((->@UB#3@"#AH%;@U66O(*I@W"#6(./@5N#
M:(*JD+."M8*M@LB"HH*]@M^"R8.-@T^#0X.3@LF.N)1S@K6"W(*U@KV!0@"#
MC8-/@T.#DX+)CKB4<X*U@MR"M8*]@4(`@TV#BH-6@X.5MHZ:@6F/K)6VCIJ!
M:@"#B8-E@Y.5MHZ:@6F/K)6VCIJ!:@"#C8%;@WV0E(Z:@6F/K)6VCIJ!:@"#
MBX-.@UJ#DX-U@XN#3I'EC/:-D0",C@"3695T@K."ZH*]($U3+51.148@@LV#
M9H%;@UZ"\(K<@O&"Q8*B@MR"N8+Q@4(`@WV#2H-)`(-]@U"#:(-J@T&+C(.&
M@5N#4X-8@XF#<H-!BZ2888V1`(-]@U^#2X-8@TJ#BXNDF&&-D0"39(YQ@X&!
M6X.+`(-]@XF#18-#BZ2888V1`(-]@XR!6X-6@T$`@X*#BX-F@T*#=8NDF&&-
MD0"39(YQ@X&!6X.+`(-]@XN#7HNDF&&-D0"01I5T@J^"LX+J@KV#B8-X@XN"
M\)'.B9Z"LX*Y@L25JI?>@O"*QY>=@K6"W(*W@4(`@E*,C@"#?8%;@U:#@X.+
MCY23AXNDF&&-D0"#?8.+@V6#0H-J@TZ3AP"#=(-"@5N#BX-H@O"(ZI)V@K."
MN8+$@J*"W(*W`(."@5N#BH->@VJ#08%%@T.#6(.)@X"+I)AAC9$`@X*!6X.*
M@U:#@X-8BZ2888V1`()4C(X`@WV#0X.(@V*#9Y.'`(.!@Y.#;P"#@8-J@X6!
M6X."@5N#:`"#6H.+C(N-AP"6>Y6V`(.!@V*#6H%;@U>"S8R?C]B"Q8*K@MR"
MM8*]@JJ!08^0EKR.TH+,D&>,LX+-C)^/V(+%@JN"W(*Y@O&"Q8*U@KV!0@"#
M@8-<@V*#:`"#@8-<@V*#:"`B)7,B((+-DNB+8(*S@NJ"Q(+<@KF"\0"#@8-,
M@U:#4HV'CT^-D0"#?H-.@XV#;(-6@T&8099-`$UI;64@5'EP90!014%2((-P
M@V*#4(%;@U>"S"!(5%107U)E<75E<W0@@JJ,J9.6@KV"Z(+<@KF"\8%"`):B
MD-V2Z(+%@K>!0H*Q@LR#08-V@XJ#4(%;@U:#AX.3@O".9Y=P@K>"Z8*]@M^"
MR8+-D-V2Z(-T@T"#0X.+@O"-[)"L@K>"Z95+EW:"JH*@@NB"W(*W@4(`@X&#
M8H-:@5N#5R!)1"""JHRIDY:"O8+H@MR"N8+Q@4(`4$5!4B"#<(-B@U"!6X-7
M@LP@36%I;"""JHRIDY:"O8+H@MR"N8+Q@4(`@UJ#8H-6@X>#DR!)1"""JHRI
MDY:"O8+H@MR"N8+Q@4(`C(X`C&>1T8.!@5N#BP"/0Y"SD_H`@X*#BX-H@V^+
MI)AAC9$`@X*#:8-2C/:-D0"#@H.3@U.#BP"6B(R.`(."@Y.#9X-:@XF#9Y.'
M`(R.E^X`@X*#C8-B@U*)I(V1`(FZ@M8`C;:"U@")18+6`(_C@M8`B;J"U@"/
MXX+6`(."@U6#DX-R@5N#3HNDF&&-D0"#08-*@T6#DX-G`(-!@TJ#18.3@V>/
M[I7Q`(-^@X.#DX-]@5N8099-`).OB-."M8+<@KF"\0"6O)%/`(-I@WZ#<H-!
MBZ2888V1`(-I@T6#BXNDF&&-D0"#;(-P@5N#BXFDC9$`@TF#B8.3@U^)I(V1
M`(-)@XF#DX-?E\R#08.3@V6#0H.+CY23AP"#;(-B@V>#CX%;@TX`@LB"M0"#
M=(.)@Y.#6)?,@VJ#A8%;@TJ#C(-H@VJ#00"05HM+E:J7W@"05HR.`)!6@K6"
MHH.&@5N#59:\*)1#B-,I`(-J@X6!6X-7@5N#B8.3@V@`D%:"M8*B@W"#6(./
M@5N#:`"05H*U@J*#<(-8@X^!6X-H@LT@)7@@@LF*^HS`D-B"ZH+)@LB"Z(+<
M@K>!0@"05H*U@J*#<(-8@X^!6X-H@JJ(ZI)V@K6"W(*Y@O&!0@"#:H.%@5N#
M6`"#:H.%@5N#6(-/@XN!6X-V`(Z?`(Z?@LR#28-V@U:#AX.3`(Z?@LR#>8%;
M@U<^`(-J@TJ#B8-/@T&+I)AAC9$`@VJ#5X-&@5N#BXNDF&&-D0"#:8-#@U>#
M1H.*@T&8099-BZ2888V1`(-J@T6#1Y.'`(VWE:J"\)5<CJ:"MX+I@KV"WX+,
MD-V2Z(*J@J""Z(+<@KF"\8%"`)7/C5B"R(*U@4(`@K&"S(-!@TZ#6H-8C*""
MR8+-@U2#=8-!@TZ#6H-8C*""S9+'B<&"Q8*K@MR"N8+Q@4(`)7,@@LR0W9+H
MC^Z5\8*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4(`1E10(%9&4R""S(U<D*R/[I7Q
M@JJ.=Y+H@K."ZH+$@J*"W(*Y@O&!0@!344P@5D93((+,C5R0K(_NE?&"JHYW
MDNB"LX+J@L2"HH+<@KF"\8%"`%-13""#2H-E@U.#BH+,C5R0K(_NE?&"JHYW
MDNB"LX+J@L2"HH+<@KF"\8%"`(YCC8*"JH*@@NB"W(*Y@O&!0@"1EY!-D.:"
MJHYWDNB"LX+J@L2"HH+<@KF"\8%"`(-T@T"#0X.+@JJ#08-B@W:#C8%;@VB"
MLX+J@L2"HH+<@KF"\0"#08-#@U*#DX*J@J""Z(+<@KF"\8%"`(_JCXJ"JHYW
MDNB"LX+J@L2"HH+<@KF"\8%"`(.!@V*#6H%;@U>"JHYWDNB"LX+J@L2"HH+<
M@KF"\8%"`):\D4^"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`)34C8:"JHYWDNB"
MLX+J@L2"HH+<@KF"\8%"`$A45%`@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<
M@KF"\8%"`$E-05`@E$:/V(+,@W"#6(./@5N#:(*J@J""Z(+<@KF"\8%"`$ME
M<F)E<F]S()1&C]B"S(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@"#C8-/@T.#
MDR"41H_8@LR#<(-8@X^!6X-H@JJ"H(+H@MR"N8+Q@4(`4$%34U=$()1&C]B"
MS(-P@UB#CX%;@VB"JH*@@NB"W(*Y@O&!0@!334(@E$:/V(+,C5R0K(_NE?&"
MJHYWDNB"LX+J@L2"HH+<@KF"\8%"`$]P96Y34TP@@W:#C8-/@XF#@(+,@W"#
M6(*JCG>2Z(*S@NJ"Q(*B@MR"N8+Q@4)/<&5N4U-,((+-(%!+0U,@,3(@@LR#
M9H%;@UZ"\(BU@J2"S(+)E4N7=H+%@K>!0@"5VY>O@LR#5(-#@Y.#08-B@W:"
MR(*U@4(`@TZ#2(%;@UZ"JI#=DNB"LX+J@L2"HH+<@KF"\8%"`(-:@W"#C(%;
M@UZ"JHYWDNB"LX+J@L2"HH+<@KF"\8%"`(I9DY:#=(-`@T.#BX+(@K4`@X:!
M6X-5EKR"J8-P@UB#CX%;@VB"JI&7@N>"ZH+<@KF"\8+%@K6"O8%"`):SC/B"
MS%A-3(-F@5N#7H*JE=2"Z(+<@K6"O0"2;(+(@K4`@TF#BH-7@VF#BX+,D-V2
MZ(-T@T"#0X.+@LF#;X%;@U>#AX.3@JJ"H(+H@MR"N8+Q@4*0W9+H@O"-Q)"V
MD*R"M8+<@K>!0@"0W9+H@W2#0(-#@XN"R8-O@5N#5X.'@Y."JH*@@NB"W(*Y
M@O&!0I#=DNB#=(-`@T.#BX+PC>R"Z)*\@K6"Q(FZ@K."HH%"`(+(@K4`@VV!
M6X-T@TB!6X-.DX<`EFN4O(N%`)9K@WV#BH-!@VF/E).'`(-M@XN#18-&@5N)
MI(V1`(*Q@NJ"YH+HD4\`@K&"ZH+F@NB,XP"#9H-"@XR#3H-G@XJ"Q8+-@J""
MZ(+<@KF"\0".P)&5@K."ZH+$@J*"W(*Y@O&!0@"#5(-\@5N#9X*S@NJ"Q(*B
M@MR"N8+Q@4(`@X&#@@`Q,8R.`)"4`)6VCIJ0E`"7\9"4`(USD)0`D9>039#F
M@XJ#6(-G@O"-6)!6@KV"WX+,E-2-AH*JCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!
M0@!/2P"#28-U@U>#1H-.@V<`@TF#=8-7@T:#3H-GC>R0K([2`#$PC(X`@TF#
M=(-"@U@`C,."HH-P@UB#CX%;@V@`C,."HH-P@UB#CX%;@VB"JI"S@K6"K8*@
M@NB"W(*Y@O$`@TF#?8%;@Y,`BZ273(-T@TB#BX-?@LT@24U!4""#5(%;@V^"
MOH*O@JJ#5(-\@5N#9X+%@JN"W(*W@4(`DV2.<8.!@5N#BX-!@VB#C(-8@LTQ
M@L*"OH*OCG>2Z(+%@JN"W(*W@4(`CXJ73([2@JF#5H-8@V6#@(K'EYV.TH*^
M@J^"JHNDETR"S(^*ETR,H(+&@T&#3H-:@UB,H(+PE<^-6(+%@JN"W(*W`)!6
MBTN#18-#@Y.#:(%;@LF57(ZF`$]P96Y34TP@@T>#B8%;@493+TU)344@CY"6
MO(*S@NJ"O8-P@5N#9X*I@N>#9H%;@UZ"\([F@NB/;X*Y@MR"N8+Q@L6"M8*]
M@4(`@TF#=H-6@X>#DP`E<R"#28-V@U:#AX.3`)34C8:5=(G3C_"/D8*K`)%G
MD$0`E92/D`"0KI>=`(RS@LR#08-V@XJ#4(%;@U:#AX.3@V6#DX-V@XR!6X-G
M`)&\@LR#0X.3@W2#2(.!@5N#5H.'@Y,`CXJ73([2@LR#08-.@UJ#6(R@`%!!
M32"41H_8@LV.9Y=P@L6"JX+<@KF"\8%"`%!'4""39(YQCY"6O`!01U`@B,.-
MAI6V`%!'4"",]HI*C*X`4$=0((^0EKR-SR^(PXV&B;N#9H%;@UX`4$A0@U*!
M6X-H`%!(4(-6@T:#BP!03U-)6""*9Y*C@JJ,J9.6@KV"Z(+<@KF"\0"6A)&0
M`(-P@TR#6(->@Y.!18-#@UB#B8.`BZ2888V1`(-P@XF#28NDF&&-D0"#<(.,
M@UB#8(-ICJF.H8OF`(-P@VF#?8NDF&&-D0"#<(-V@T&#:H.%@5N#38-J@T&3
MQI>GC9$`@W"#B8-/@T&#0XNDF&&-D0"#<(-8@X^!6X-H`(-P@UB#CX%;@VB"
MS9"SC^V"R97/C5B"LX+J@MR"M8*]@4(`@W"#6(./@5N#:(*JD+."M8*M@J""
MZ(+<@KF"\0!2041)55,@E$:/V(+,@W"#6(./@5N#:(*JE4N7=H+%@K>!0@"#
M<(-8@X^!6X-H@LR*;91&`(-P@UB#CX%;@V@Z`(-P@UB#CX%;@V@Z(`"#<(-8
M@X^!6X-H@JJ(ZI)V@K6"W(*Y@O&!0@"37(+HE72"KP"#3H.*@V*#=H-[@5N#
M:(*I@N>37(+HE72"KP"#<(-8`)7;EZ^2AH+,@U2#0X.3@T&#8H-V@48`@W"!
M6X-:@Y.#9P"5VX[GD8"-[(+PCL"-<X*W@ND`@XV#3X-#@Y..GH+)E=N.YY&`
MC>R"\([`C7."M8+<@K>"J8%(`(-!@TZ#6H-8C*``@T&#3H-:@UB,H"`B)7,B
M((+-C>V/G(*S@NJ"W(*Y@O&"Q8*U@KV!0@"#08-.@UJ#6(+-BY&4VX*S@NJ"
MW(*U@KT`@T&#3H-:@UB,H`"#08-.@UJ#6(R@@LR*QY>=`(S"D&R/[I7Q`(-Y
M@XN!6XNDF&&-D0"#=(-"@XJ#<X.3BZ2888V1`)-DF&(`@W.#9X-0@T&#DY.'
M`(-S@TZ#6H.+`(R.@L:43H+PD_R7S8*U@L2"K8*^@K."HH%"`)!6@K6"HI6J
ME]Z"S):\D4^"\)/\E\V"M8+$B;J"LX*B.@"0LX*U@J*3^I5T@O"3_)?-@K6"
MQ(*M@KZ"LX*B+B",CH+,D_J0E(+P@V"#1H-B@TZ"M8+$@JV"OH*S@J*!0@"/
MX8I1D^"798+PEW:6\8*U@L2"LHM,D_R"K8*^@K."HH%"`(.&@5N#59:\@L:#
M<(-8@X^!6X-H@O"3_)?-@K6"Q(*M@KZ"LX*B@4(`CI^"S)6VCY&"\)/'@O&"
MQ8*M@KZ"LX*B+B""L8+,@U:#6(-E@X""\(YGEW""MX+I@KV"WX+,BTN2Z(Z6
MC8""R9.OB-."MX+IE4N7=H*J@J""Z(+<@K>!0@"#?(%;@XF#DX-HBZ2888V1
M`).*E5N0E`"#?(.+@V>#2X.+BZ2888V1`%!R969S7VQD87`Z()5+EW:"R$Q$
M05"*9Y*CBT"47(*JC*F"PH*I@NB"W(*Y@O&!0@!0<F5F<U]L9&%P.B"52Y=V
M@LAS97-S:6]NBF>2HXM`E%R"JHRI@L*"J8+H@MR"N8+Q@4(`@W:#C(-R@X6!
M6P"05H*U@J*#18-#@Y.#:(%;@LF)YI&<@O"57(ZF`)%/@LR#28-V@U:#AX.3
M`(CSC?P`E.F6IXRN`(_ABE$`C^&*49/@EV6"S)#@EKX`C/:*2HRN`(SVCT^,
MKH-!@XN#4X.*@UF#@`",]HI*C*Z/[I7Q`(SVCT^,KB^4Z9:GC*Z"JI"VD*R"
MQ8*K@MR"N8+Q@L6"M8*]@4(`@W:#1X.+@V>#BH-2`(.!@V*#6H%;@U>"\(-P
M@5N#5P"#2H->@5N#BP"#3H-'@XJ!6P"#2H->@5N#BP!24T&,]H]/C*XH)62#
M<H-B@V<I`)3D`)/'@MX`EGN3EH+)("5S((+PC>V/G(*U@MR"MX*I/R""L8+,
MD8"-[(+-C+."R9;?@KF"W(*Y@O&!0@"6>Y.6@LF#AH%;@U4@)7,@@LR#9H%;
M@UZ"\(WMCYR"M8+<@K>"J8%(((*Q@LR1@(WL@LV.YH+HC\&"N8+<@KF"\8%"
M`(W%C.."S)&`C>R"\(+B@NB2O(*W`).NDTF#@8-J@X6!6X+,C<257(ZFBM2*
M=3H`@WR!6X->@XN"S(W$E5R.I@"#BH.-@5N#:`"#BH."@5N#9X-4@5N#<H-8
M`(.*@X*!6X-G55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M+VAO<F1E*3H@
M`(WMCYP`@W6#C8-B@TZ"\(WMCYP`CY&.KH+PC>V/G`"#>8-!@O"-[8^<`)7;
MD;:"M8*]@UB#3H.*@W:#9X+PC>R+QH-F@T*#C(-.@V>#BH*I@N>-[8^<@K>"
MZ8%"`(WMCYR!1@""L8+,@VV!6X-H@O"#:(-,@X6#@8.3@V>"J8+GC>V/G`"#
MAH%;@U6"\(WMCYP`@X:!6X-5@O"-[8^<.B`E<P"7=HN!@LF5U).:@L6"JX+<
M@KF"\3H@`)=VBX&"LX+J@KT@(B5S(B""S2`E<R""S)#=DNB"R8YWDNB"LX+J
M@L2"HH+<@KF"\8%"`)=VBX&"LX+J@KT@(B5S(B""S2!61E,@D-V2Z(+)CG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`EW:+@8*S@NJ"O2`B)7,B((+-D-V2Z(+)CG>2
MZ(*S@NJ"Q(*B@MR"N8+Q@4(`@XJ#6H-B@V<`@W"#6(./@5N#:(+P@XJ#6H-B
M@V<`@J""R(*]@LR#<(-8@X^!6X-H@O"#BH-:@V*#9P",BXG*`(-)@W:#5H.'
M@Y."R9;?@ND`@W"#6(./@5N#:(+PC<23_)?-`(RS@LR-7)"L@LF6WX*W`(-E
M@TR#6(-G@T>#9H-"@UZ!6X+,@TF#=H-6@X>#DP")10"6\(J$`(.+@5N#?8-J
M@T$`,3@PDWB)\9-=`(VV@LF)\9-=`(E%@LF)\9-=`(USD:Z0JP"-<Y&ND*L`
MC7.!1@",<I#\`)%3@L2"S(US@L:7\8+,BM2"R8QRD/R"\(CX@JT`C7."S(K4
M@LF,<I#\@O"(^(*M`)?Q@LR*U(+)C'*0_(+PB/B"K0".P(US`(.-@U:#09A!
MEDT`@XN#CX.3@U\`4R]-24U%((C#C8:/D):\`%,O34E-12"(PXV&E;8`4T%3
M3""41H_8@LV.9Y=P@L6"JX+<@KF"\8%"`%-13""#5H-&@XL`4U-(`)"LC/<`
MDWD`@UJ#DX-G@W>#C(-IDX<`@UJ#DX-G@TR#8H-C@96#;(%;@Y2#0H-8`(-:
M@Y.#9X.+@U:#00"#5(.3@W.#1X%;@XN!18-^@TZ#C8.3DX<`@UJ#DX-G@W.#
MDX-:@Y.#9X*H@N:"T8-/@XR#:8-F@T*!6X.3CY23AP"#5(."@T&3QI>GC9$`
M@U2#DX-]@XJ#;8NDF&&-D0"#5(.3@V>#@8%%@W:#BH.3@U:#>9:OCN6+I)AA
MC9$`@U2#18-7@T&#B8-R@T&)I(V1`)7;D;8`(B5S(B""\)7;D;8`)7,@@O"5
MVY&V`(-)@W:#5H.'@Y."\)7;D;8`D+:0K(*S@NJ"O9#=DNB"\"!02%`@@UB#
M3H.*@W:#9X+&@K6"Q(-4@5N#;X+,C>R+QH-F@T*#C(-.@V>#BH+)E=N1MH*W
M@NF!0@`E<R"0W9+H@O"5VY&V@K6"W(*U@KV!0@"0W9+HC5B05I=P@UB#3H.*
M@W:#9R`B)7,B((+PE=N1MH*U@MR"M8*]@4(`C)^-]0",GXWU@T>#DX-7@Y,`
M@W2#0(-#@XN"\)%)D?``D_J5=(+PCG>2Z(*U@L2"K8*^@K."HH%&`)+'B<&"
MMX+I@T^#BX%;@W:"\)%)D?""M8+$@JV"OH*S@J(`D%:"M8*BCXJ.G8[2@O"1
M29'P@K6"Q(*M@KZ"LX*B`(-4@5N#;X+PD4F1\(*U@L2"K8*^@K."H@"2QXG!
M@K>"Z8.&@5N#58+PD4F1\(*U@L2"K8*^@K."H@"14X+$D4F1\`"52Y=V@LB5
MMHZ:@O")NH+,@WN#8H-.@UB"J8+GD4F"\8+%@U*#<X%;@K>"Z8+&@4&#98-,
M@UB#9X-'@XJ#08+6@WF!6X-8@V>"Q8*K@MR"MX%"`)/ZE72"S(OFD-B"Z)6V
MCIJ"\(YWDNB"M8+$@JV"OH*S@J*!1@"3^I5T@LR,8(ZN@O".=Y+H@K6"Q(*M
M@KZ"LX*B@48`E<^-6(*U@KV"HDE$@O"129'P.@".GHV/@LR+YI#8@NB5MHZ:
M@O".=Y+H@K6"Q(*M@KZ"LX*B@48`CIZ-CX+,C&".KH+PCG>2Z(*U@L2"K8*^
M@K."HH%&`(CJDG:"MX+I@E&"PH+,@W2#0H%;@XN#:(+PD4F"\8+%@JV"OH*S
M@J*!0@"01I*R@O"129'P@K6"Q(*M@KZ"LX*B+@",OHSJ@O"129'P@K6"Q(*M
M@KZ"LX*B.@"/X8I1@XR#?(%;@V>"\)&7D$V"MX+I`%--4R"1EY!-`(-:@VR#
M2X.+BZ2888V1`()8C(X`@UJ#BX-R@T&!18."@Y.#98-L@T^#C0"2RI34`(-:
M@V*#5H.'@Y.*QY>=`(-:@V*#5H.'@Y,`EEF"ZH+$@K6"W(+!@KV#<(-8@X^!
M6X-H@O"#BH-:@V*#9X+%@JN"Z8+F@J2"R8*U@MR"MX%"`(-\@5N#7H.+@L6#
M08-.@UJ#6(*W@NF#BH."@5N#9X-4@5N#;X+PD-V2Z(*U@MR"MX%"`(R^C.J!
M08Z>BM21T8%!D_J5=(+PD-V2Z(*U@MR"MX%"`(I*CFZ.GH+,@T&#=H.*@U"!
M6X-6@X>#DX%!D$:2LH%!@WF!6X-7C<257(ZF@4&"NX+,D;R"S)5<CJ:#28-V
M@U:#AX.3@O"129'P@K6"Q(*M@KZ"LX*B+@"0W9+H`)#=DNB-6)!6@UB#3H.*
M@W:#9P"#6H%;@U:#1H.+BZ2888V1`(K(DE""R)=VEO&!1@"!:8.!@VJ#A8%;
M@LB"QX+%@6J#5H.'@5N#9X-*@V*#9X-,@5N"JHYG@J:"Z8+F@J2"R8*U@MR"
MMX*I@4@`E5R.I@",NXW=@LR0W9+H@L:05H*U@JV0MI"L@K."ZH*]D-V2Z(+&
M@LR-MY6J@O"57(ZF@K>"Z8%"`(.-@T^#0X.3CIZ"R9%/B?&"S(.-@T^#0X.3
MCIZ*U(+PE5R.IH*U@MR"MX*I@4@`E5R1@(WL@X&#:H.%@5N"\)5<CJ:"M8+<
M@K>"J8%(`(GFELJ-MH+)("5S((.!@VJ#A8%;@O"57(ZF@K6"W(*W@JF!2`"5
M7(+,@UJ#BY&ND*N#7X-#@T&#C8-/@O"57(ZF`)5<D:Z0JX-?@T.#08.-@T^"
M\)5<CJ8`E5R"S)?QD:Z0JX-?@T.#08.-@T^"\)5<CJ8`E5R"S(USD:Z0JX-?
M@T.#08.-@T^"\)5<CJ8`CVN/K`""W(*XE]>"Z(+,@W6#C8-B@TZ"\(]KCZR"
MW(*]@LV(VI.N@K."N8+$@JV"OH*S@J*!0@"#5H-'@XF#C(-)@VR+I)AAC9$`
M@U2#0X.3@T&#8H-V`)-DCG&/D):\`)-DCG&/D):\@T&#BX-3@XJ#68.``(-6
M@Y.#2X-\@5N#BXNDF&&-D0"#5(-#@UD`E=N.YX+P@UB#3(-B@W:"MX+I`(-8
M@XV#;X-,@T&+I)AAC9$`@UB#C8-X@VJ#08NDF&&-D0"#7(.-@X*#DX^4DX<`
M@UR#?8.*@T&6KX[EBZ2888V1`)7`@M&/AX+,D4F1\`"1EY!-C+.#08-H@XR#
M6`"3[(-!@W2#BH-*BZ2888V1`)/L@U>#AX%;@U>#09.'@463[(-4@Y.#:(-#
M@V*#8(^4DX<`D^R4O(N%`)?7@LR#6H.+@L:"S)==E)(`@UJ#BX+&BZN*18+&
M@LR77922`)==E)(`EUV4DH+&EH21D`"#6(-Y@T.#DP"3P8[JE;:.FH+,D_R7
MS0"#6H.+E:J*A`"7\96JBH0`C7.5JHJ$`(-8@XJ#B8.3@TJ6KX[ECM")[X[E
MBV"+I)AAC9$`CT*"W(*]@LV,IP"/\Y'4`(]:CXJ4U))N`([FC\&"M9#\`(-8
M@UZ#0X.+(%M#4U-=`)/Z`(-4@W6#9H-"@XR#3H-G@XH@(B5S(B""JH*@@NB"
MW(*Y@O&!0@".P(US`(FZE72"JP"0K(SW`"(E<R(@@LV#5H-8@V6#@(+)DL>)
MP8*S@NJ"W(*U@KV!0@`B)7,B((*J@U:#6(-E@X""J8+GC>V/G(*S@NJ"W(*U
M@KV!0@`B)7,B((*JC>V/G(*S@NJ"W(*U@KV!0@`B)7,B((*J@U:#6(-E@X""
MJ8+GC>V/G(*S@NJ"W(*U@KV!0@"0W9+H@LV0LX_M@LF6WX*S@NJ"W(*U@KV!
M0H.*@XV!6X-H@K6"Q(IME$:"Q8*K@MR"MX%"`)#=DNB"S(-O@V*#3H-!@V*#
M=H+-D+./[8+)E=N1MH*S@NJ"W(*U@KV!0@"0W9+H@W2#0(-#@XN"S(-O@V*#
M3H-!@V*#=B`E<R""S9"SC^V"R97;D;:"LX+J@MR"M8*]@4(`(B5S(B""S9"S
MC^V"R8U8D%:"LX+J@MR"M8*]`"5S((+-D+./[8+)CY&"JXV>@MR"ZH+<@K6"
MO0"#6(%;@U^#DXNDF&&-D0"*5)=V`)/Z@LR/;P"3^H+,D_R"Z`"3^H+,CV\O
MD_J"S)/\@N@`D_J"S(]O@48`D_J6=@"3^I9V@48`C^.5=(*K`(-4@WR!6X-G
M`(-8@XJ#:8.`BZ2888V1`)"I`(-8@Y2#0(%;@XN#;X.+@4&#A(.3@WV#0X-'
M@Y./E).'`(-8@X^#5X.)@Y.#:(FDC9$`@UB#18-&@5N#9H.3B:2-D0"#6(-#
M@UB8099-`(-6@XJ#08%%@T&#B8-UBZ2888V1`%135H-T@T"#0X.+`)5<D:Z0
MJP"57)&ND*L`D>28<`"1Y)AP@6F2AHV1@LR(ZI64@6H`@UZ#5X-,@UB#7H.3
MBZ2888V1`(->@Y.#58-J@T&8099-BZ2888V1`(->@UB#3@"39)ABE-2-A@"#
M98.3@W:#C(%;@V<@(B5S(B""JH*@@NB"W(*Y@O&!0@"#98.3@W:#C(%;@V>"
MS(K'EYT`@V6#3(-8@V>"S(+=`)6VCIJ4>I)U`)6VCIJ"S(_C`);8`(->@T.)
MI(V1`$944""*9Y*C@JJ"H(+H@MR"N8+Q@4(`EYJ7\(-6@UB#98.`@LV6LXSX
M@LF"R(+!@L2"HH+<@K>!0@!-86EN=&5N86YC92"#3H.)@UB"S)/'C9Z"W8*J
MD+./[8+)C7."IH+<@KF"\8+%@K6"O0"#28-V@U:#AX.3@T6#0H.3@VB#18+P
ME<*"MH+<@K6"O8%"CTF7N8*U@MR"MX%"`(-!@TZ#6H-8C*""\)=,C/B"R8*W
M@NF"R8+-BL>7G8[2@JJ"NX+,@V^#8H-.@T>#DX-H@O"0W9+H@K>"Z8*Q@L:"
MJI5+EW:"Q8*W@4(`F$&7C9#F2424U(V&@JJ.=Y+H@K."ZH+(@JF"P8*]@JF!
M08OS@KZ"P8*]@JF!08*@@NF"HH+-@V:!6X->@WB!6X-8DH:"R8RIE72"J8+H
M@MR"N8+Q@L6"M8*]@4(`F$&7C9#F@LV"H(+(@KV"S(-!@VB#C(-8DJ""R9+'
MB<&"LX+J@MR"M8*]@4(`DV2.<8^0EKR"LX+J@KV#@8-B@UJ!6X-7@O",GX_8
M@K>"Z8+)@LV!05!'4""/D):\@JJ52Y=V@L6"MX%"`)&7D$V0YDE$E-2-AH*J
MCG>2Z(*S@NJ"R(*I@L&"O8*I@4&+\X*^@L&"O8*I@4&"H(+I@J*"S8-F@5N#
M7H-X@5N#6)*&@LF,J95T@JF"Z(+<@KF"\8+%@K6"O8%"`)&7D$V0YDE$E-2-
MAH*JCG>2Z(*S@NJ"W(*Y@O&"Q8*U@KV!0@"(PXV&B;N"R8+-B,"14X+(@T6#
M1H-UD-J1L8*JE4N7=H+%@K>!0@"#=(-`@T.#BR`E<R""R8+-("5S((+,D-V2
MZ(*JE4N0>X+%@K>!0@"#=(-`@T.#BR`E<R""R8+-("5S((+,D-V2Z(*JE4N0
M>X+%@K>!0@"#=(-`@T.#BX+-CJF5JHZID&>"R8-2@W.!6X+%@JN"W(*Y@O&!
M0@"#=(-`@T.#BX*J@V:!6X->@O"*W(+Q@L6"HH+<@KF"\8%"`(C(B;J"S8*Q
M@LR#@8-B@UJ!6X-7@6E21D,X,C*!:H+,@W>#8H-?@L6"MX%"`)*-B-.!22"#
M=(.+@UB#3H.*@5N#DX."@5N#:(+-($EN=&5R;F5T($5X<&QO<F5R((+%@LV6
MXI'H@JJ4K9"V@K>"Z8*Q@L:"JH*@@NB"W(*W@6F#=8.)@T6#58+,@V^#3X+%
M@K>!:H%"B>:6RH+)@U.#?H*JE5R.IH*S@NJ"O8+H@4%7:6YD;W=S((*J@TZ#
MB8-B@U:#A8*U@KV"Z(*W@NF"J8+@@K6"ZH+<@KF"\8%""H-T@XN#6(-.@XJ!
M6X.3@X*!6X-H@LF"MX+I@LB"YR!/2R""\(F?@K6"Q(FZ@K."HH%"`$E$("(E
M<R(@@LV-[8^<@K."ZH+<@K6"O8%"`$=N=5!'((-O@T.#:8.*@LR#<(-8@JH@
M0W)Y<'1?<&=P((-.@XF#6(+)D-V2Z(*S@NJ"Q(*B@NF52Y=V@JJ"H(+H@MR"
MMX%"`(*Q@LR#=(-"@5N#BX-H@LV0E(Z:@L6"R(*O@NJ"SH+(@NB"W(*Y@O&!
M0@!(;W)D95]#<GEP=%]S;6EM98-.@XF#6(+)@LUO<&5N<W-L@X*#5X.%@5N#
MBX*JE4N7=H+%@K>!0@"#=H.,@W2#0(.,@Y.#6"(E<R*"S8-F@5N#7H*J@U2#
M0X-9D*>,P(+PB7J"IH*]@KV"WY7;D;:"Q8*K@MR"N8+Q@L6"M8*]+@""L8+,
M@V:!6X->C%XH)7,I@O"57(ZF@K>"Z8*]@M^"S(-V@XV#3X.)@X""JH*Q@LR#
M5H-8@V6#@(+)@MV"PH*I@NB"W(*Y@O&!0@"(^)=PE82"S8)0E;:.FH+%@LB"
MKX+J@LZ"R(+H@MR"N8+Q@4(`B^:0V(+HE82"S8)0E;:.FH+%@LB"KX+J@LZ"
MR(+H@MR"N8+Q@4(`@U2!6X-O("(E<R(@@LV-[8^<@K."ZH+<@K6"O8%"`(-4
M@5N#;R`B)7,B((+-E=N1MH*S@NJ"W(*U@KV!0@".=Y+H@K6"O9?Q@6DE9(%J
M@JJ"H(+H@MR"N8+Q@4(`B.J.GH-T@T"#0X.+("(E<R(@@JJ"H(+H@MR"N8+Q
M@4(`@T&#8H-V@XV!6X-H@V:!6X->@JJ2O)%/@LR#6(-E@V*#=H+%C\&.N(*U
M@MR"M8*]@4(`@T&#8H-V@XV!6X-H@V:!6X->@O"5VY&V@L6"JX+<@KF"\8+%
M@K6"O8%"`(-E@5N#?8-F@T*#C(-.@V>#BH%;("(E<R(@@JJ"H(+H@MR"N8+Q
M@4(`CG>2Z(+%@JN"Z8-)@W:#5H.'@Y."S8*@@NB"W(*Y@O&!0@"#0X.3@XF#
M0X.3E5R.IH+%@JN"Z964E:J"S8*@@NB"W(*Y@O&!0@"5MHZ:D)2"JH*Q@LR#
M=(-"@5N#BX-H@LF1O8G?@JR"W(*W+B`E<R""S)6VCIJ"JI/\E\V"LX+J@L2"
MHH+<@K<N("5S((C(B;J"Q8+(@JV"Q(+-@J*"KX+<@KF"\8%"`"(E<R(@@O"#
M5H-8@V6#@(+6DL>)P9*&@LF6XI'H@JJ4K9"V@K6"W(*U@KTZ("5S`(.&@5N#
M52`B)7,B((+,@V:!6X->@O"#5H-8@V6#@(*I@N>/P8N.DH:"R9;BD>B"JI2M
MD+:"M8+<@K6"O3H`(B5S(B""\(-6@UB#98.`@JF"YXWMCYR2AH+)EN*1Z(*J
ME*V0MH*U@MR"M8*].@`B)7,B((+PC5B05I*&@LF6XI'H@JJ4K9"V@K6"W(*U
M@KTZ("5S`(-T@T"#0X.+@T&#8H-V@XV!6X-H@LF6XI'H@JJ4K9"V@K6"W(*U
M@KTZ("5S((+-@T&#8H-V@XV!6X-H@K."ZH+$@J*"W(*Y@O&!0@"#=(-`@T.#
MBX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""S8-T@T"#
M0X.+@LR#5(-#@UF0IXS`DFPH)62#;X-#@V<I@O")>H*F@L2"HH+<@K>!0@"#
M=(-`@T.#BX-!@V*#=H.-@5N#:(+)EN*1Z(*JE*V0MH*U@MR"M8*].B`E<R""
MS8CJE92"S(+=@T&#8H-V@XV!6X-H@K."ZH+<@K6"O8%"`(*Q@LR#<(%;@V>"
M\)5<CJ:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KT`F$&7C9#F@V:!6X->@LR#
M0X.3@WR!6X-GDH:"R8-'@XF!6X*JE*V0MH*U@MR"M8*]@4(`:4-A;&5N9&%R
M((+,@T.#DX-\@5N#9Y*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O2X`D-V2Z(-T
M@TB!6X.`DH:"R8-'@XF!6X*J@J""Z(+<@K6"O8%"@KV"U(+Q@4&52Y![C8"6
MVH*JB_.4DH*^@L&"O8+,@L6"M8+E@J2!0@".=Y+H@K."ZH*]@T&#:(.,@UB2
MH(+,D8"-[)*&@LF#1X.)@5N"JI2MD+:"M8+<@K6"O8%"C.."Q8W$DWB.P(US
M@K6"Q(*M@KZ"LX*B@4(`F$&7C9#F@LR/VHW7@O"-6)!6DH:"R8-'@XF!6X*J
ME*V0MH*U@MR"M8*]@4*,XX+%C<23>([`C7."M8+$@JV"OH*S@J*!0@"1EY!-
MD.:#BH-8@V>"S(U8D%:2AH+)@T>#B8%;@JJ4K9"V@K6"W(*U@KV!0HSC@L6-
MQ)-XCL"-<X*U@L2"K8*^@K."HH%"`(*Q@LP@24U!4""#5(%;@V^"S8NDETR#
M=(-(@XN#7X+P@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0@""L8+J@LV73(SX@L@@
M<F%R((-!@5N#2H-#@W6"Q8+-@LB"HH+F@J2"Q8*W@4(`@K&"ZH+-ETR,^(+(
M('II<""#=(-`@T.#BX+%@LV"R(*B@N:"I(+%@K>!0@""L8+J@LV73(SX@LB#
M2H%;@VB4U(V&@L6"S8+(@J*"YH*D@L6"MX%"`(*Q@LR#=(-"@5N#BX-H@LV5
M2Y![@L6"MX%"`(*Q@LR#=(-"@5N#BX-H@LV0KI"4@L6"R(*M@L2"S8*B@J^"
MW(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-D)2.FH+&@U*#C8.3@L6"R(*M@L2"
MS8*B@J^"W(*Y@O&!0@""L8+,@W2#0H%;@XN#:(+-.)!ID)2"Q8+(@JV"Q(+-
M@J*"KX+<@KF"\8%"`(*Q@LR#=(-"@5N#BX-H@LV#4H.3@WV"W(*]@LV+\Y22
M@L6+YI#8@N>"ZH*]D*Z0E(+,@XJ#6(-G@L6"R(*M@L2"S8*B@J^"W(*Y@O&!
M0@""L8+,@W2#0H%;@XN#:(+-D)2.FH+%@LB"KX+J@LZ"R(+H@MR"N8+Q@4(`
M@K&"S(-T@T*!6X.+@VB"S3$VD&E21T*57(M,@LR01H-2@5N#:(+(@JV"Q(+-
M@J*"KX+<@KF"\8%"E^$Z)R,Q,C,T868G+@""L8+,@W2#2(%;@X""S8KY@LF/
MB)>=@K."ZH+$@J*"W(*W@4(`@K&"S(.!@V*#6H%;@U>"S8*@@LB"O8*JCF>7
M<(*W@NF"S(+&B-F"R(+IE;:.FH-:@V*#9X%I)7.!:H+%CY&"J8+J@L2"HH+<
M@K>!0@""L8+,E-2-AH+-C<6/K(+%@N`Q@L6"R(*M@L2"S8*B@J^"W(*Y@O&!
M0@""L8+,@U2!6X-O@L6"S7II<(+&9WII<(-T@T"#0X.+@O"35XI*@L6"JX+<
M@KF"\8%"`(*Q@LR#5H-8@V6#@(+-B.J.GI-)@LF6LXSX@LF"R(+!@L2"HH+<
M@K>!0@""L8+,DFR"S9"4CIJ"Q8+(@J^"ZH+.@LB"Z(+<@KF"\8%"`(*Q@LR#
M18-"@Y.#:(-%@LV#28-V@U:#AX.3@T6#0H.3@VB#18*I@N>,Q(]O@K."ZH+I
ME4N7=H*J@J""Z(+<@K>!0@".GHK4`(->@T.#@(-6@5N#9P".GHK4CY&.K@"3
MC(-E@T*#@H%;@XN6KX[EBZ2888V1`(->@T.#9X.+`)6AD)2"S(V`EMJ"\)%)
MD?""MX+I@LF"S8%!4$."Q8+-0V]N=')O;(-,@T.!04UA8X+(@N=#;VUM86YD
M@TR#0X+PB9^"M8+(@JJ"YX-.@XJ#8H-.@K6"W(*W@4(`2%1-3(-<@5N#6)5<
MCJ:0V)'6`(-G@5N#4XNDF&&-D0"#9X-0@XF#18^4DX<`@V>#DX-+B:2-D0""
ML8+,D)25JHK4@LF)O9-X@N"#C8-/@T.#DX*JCHZ-<X*S@NJ"W(*U@KV!0@"#
M9X.*@VJ#7X%;@VB!18-G@V^#4XNDF&&-D0")S@"#8(.%@VJ#5X-!BZ2888V1
M`(-G@XN#4HNDF&&-D0"#9X.+@TZ#@8-J@UB#7H.3`(->@5N#3H-8@46#2H-#
M@U*#6(^4DX<`@V.#;X.+`)%)D?"!1@!54DP`@T6#2X.3@U^+I)AAC9$`@T6#
M3H.)@T.#:0!61E,@@V:#0H.,@TZ#9X.*@LF#08-.@UJ#6(+%@JN"W(*Y@O&!
M0@!61E,@@W2#0(-#@XL@(B5S(B""S(-!@TZ#6H-8C*""S97/C5B"Q8*K@MR"
MN8+Q@4(`5D93((-T@T"#0X.+("5S+R5S((+,@T&#3H-:@UB,H(+-E<^-6(+%
M@JN"W(*Y@O&!0@`E<R""R97/C5B"Q8*K@MR"N8+Q@4(`@W2#0(-#@XL@(B5S
M(B""S(-4@T.#68*J@V"#1H-B@TZ"JX+<@KF"\8%"`(-T@T"#0X.+("(E<R\E
M<R(@@LR#5(-#@UF"JH-@@T:#8H-.@L6"JX+<@KF"\8%"`%-13""#5(%;@V^"
MR9#:D;&"Q8*K@MR"N8+Q@4(`4U-,((+%D-J1L8+%@JN"W(*Y@O&!0@!61E,@
M@W2#0(-#@XN"\(-2@W.!6X+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*
M("(E<R(@@O"-[)"L@L6"JX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ"\(WL
MD*R"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+@O"-[)"L@L6"JX+<@KF"\8%"
M`%9&4R"#9H-"@XR#3H-G@XH@(B5S(B""\(WLD*R"Q8*K@MR"N8+Q@4(`B_."
MS"!61E,@@W2#0(-#@XN"\(WLD*R"Q8*K@MR"N8+Q@4(`@V:!6X->@O"(LX]K
M@L6"JX+<@KF"\8%"`"(E<R*"\(WMCYR"Q8*K@MR"N8+Q+B"#9H-"@XR#3H-G
M@XJ"JHOS@L6"S8*@@NB"W(*Y@O&!0@`B)7,B@O"-[8^<@L6"JX+<@KF"\3H@
M)7,N`"5S@O"-[8^<@L6"JX+<@KF"\2X@@V:#0H.,@TZ#9X.*@JJ+\X+%@LV"
MH(+H@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BH+PC<2+09-)@LF-[8^<@L6"
MJX+<@KF"\8%"`%9&4R"#9H-"@XR#3H-G@XJ"\(WMCYR"Q8*K@MR"N8+Q@4(`
M5D93((-F@T*#C(-.@V>#BH+PC>V/G(+%@JN"W(*Y@O&!1B5S`%9&4R"#=(-`
M@T.#BR`B)7,B((+PC>V/G(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"\(WM
MCYR"Q8*K@MR"N8+Q@4(`5D93((-F@T*#C(-.@V>#BB`B)7,B((+PC>V/G(+%
M@JN"W(*Y@O&!0@!61E,@@O"-Q(M!DTF"R8WMCYR"Q8*K@MR"N8+Q@48E<P",
MNXW=@LR#9H-"@XR#3H-G@XJ!6X*JD\&2Z(+%@JN"W(*Y@O&!0@"/V):^CY&"
MS(_:C=>"JH[F@NB/;X*Y@MR"N8+Q`"5S((+,DNB+8(*J@XV!6X-H@L6"JX+<
M@KF"\8%"`%9&4R"#=(-`@T.#BX*JB-J3KH+%@JN"W(*Y@O&!0@!61E,@@W2#
M0(-#@XL@(B5S(B""JHI*@J^"W(*Y@O&!0@!61E,@@W2#0(-#@XN"\(^1@JN-
MGH+=EW""R8I*@J^"W(*Y@O&!0@!61E,@@W2#0(-#@XN"JHI*@J^"W(*Y@O&!
M0@"(LX]KCY&,R8-T@T"#0X.+@O"*2H*O@MR"N8+Q@4(`5D93((-T@T"#0X.+
M@JJ3QX+?@MR"N8+Q@6EF:6QE<VEZ92@I((-'@XF!6X%J@4(`5D93((-T@T"#
M0X.+@JJ3QX+?@MR"N8+Q@6EG971&:6QE4VEZ92@I((-'@XF!6X%J@4(`5D93
M((-T@T"#0X.+@JJ3QX+?@MR"N8+Q@4(`=F9S<F]O=""#9H-"@XR#3H-G@XJ"
M\)/'@M^"W(*Y@O&!0@"6O)%/("5S((+P("5S((+)E<^-6(+%@JN"W(*Y@O&!
M1H-T@TB#BX-?@5N"S8KY@LF1MHW=@K6"W(*W`%9&4R"#9H-"@XR#3H-G@XJ!
M6X+,EKR13X+PE<^-6(+%@JN"W(*Y@O&!0@!61E,@@V:#0H.,@TZ#9X.*@5N"
MS):\D4^"\)7/C5B"Q8*K@MR"N8+Q@48E<P!61E,@@W2#0(-#@XL@(B5S(B""
MS):\D4^"\)7/C5B"Q8*K@MR"N8+Q@4(`5D93((-T@T"#0X.+("5S+R5S((+,
MEKR13X+PE<^-6(+%@JN"W(*Y@O&!0@!61E,@@W2#0(-#@XN"S):\D4^"\)7/
MC5B"Q8*K@MR"N8+Q@4(`@K&"S"!7;W)D()6VCY&"\)9\EO."Q8*K@MR"N8+Q
M@4(`5D93((-T@T"#0X.+("(E<R(@@LF/D8*O@MR"N8+Q@4(`5D93((-T@T"#
M0X.+@LF/D8*O@MR"N8+Q@6EC;W!Y*"F.N)1S@6J!0@!61E,@@W2#0(-#@XN"
MR8^1@J^"W(*Y@O&!0@!61E,@@W2#0(-#@XN"R8^1@J^"W(*Y@O&!0G%U;W1A
M((+PDK2)WX*U@KV"YH*D@L6"MX%"`(FZD/P`E<^-6(+PCN:"Z(_!@K<`C<6,
MXX+,D8"-[(+PC+."R9;?@K<`D-J1L8Z>@LR#5(%;@V^!6X*I@N>"S)=<BOJ"
MM8+(@J*)GI.:@48`@U2!6X-O@5N"J8+G@LR77(KZ@K6"R(*BB9Z3FH%&`):B
MD*Z7G0"#08.)@W6.\9*WC9&8099-`(EPC9$`E<2-D0"5Q)?,D;Z5O9=MCY23
MAP"5<Y:^`(.&@5N#59:\@JF#<(-8@X^!6X-H@JJ5<Y:^@L6"MX%"`):SEKP`
M@UJ#3(.%@XJ#98-"@5N/XX+,EYV74H*I@N>3P8R@@LR6LX*B@UB#3H.*@W:#
M9X+-($-U="]#;W!Y+U!A<W1E((+%@JN"W(*Y@O&!0D]+((+P@TZ#BH-B@TZ"
MMX+I@L:!08+'@J2"XH+!@L2#3H.*@V*#=H-[@5N#:(+)@T&#3H-:@UB"MX+I
M@JF"QH*B@J0@;6]Z:6QL82YO<F<@@LR+6H]PE;:/D8+PC*F"Z8*Q@L:"JH+%
M@JN"W(*W@4(`@U2#?(%;@V>"M8+$@J*"R(*BBF>2HXYQ@L6"MP"-6)!6`"5S
M((+PC5B05H*W@NF!0@"#AH%;@U6"\(U8D%:"MX+I`"(E<R(@@O"-6)!6@K6"
MW(*U@KV!0@"-6)!6@UB#3H.*@W:#9X+PC>V/G(*U@MR"M8*]@4(`@T&#8H-V
M@XV!6X-H`)%3@L2"S(-!@W:#BH-0@5N#5H.'@Y."S)#=DNB#=(-`@T.#BX+P
M@U2!6X-O@LF#08-B@W:#C8%;@VB"M8+<@K6"O8%"`(.)@V6#DY6VCIJ!:9'E
ME;:.FH%J`(.-@5N#?9"4CIJ!:9'EE;:.FH%J`(-%@XN#3X-!@T.3C)7[BZ28
M88V1`(R[C=V"S))L@O".9Y=P@48E<P!34TP@@O".9Y=P`$E-4U`@@U2!6X-O
M@LR#AH%;@U66O(%>@W"#6(./@5N#:(*JB-F"R(+IC^J-AX+)CF>7<(*U@MR"
MMX%"`(.&@5N#50"#AH%;@U4@)7,@@LT@)7,@@L641H_8@K."ZH+$@J*"W(*Y
M@O&!0@"#AH%;@U6*QY>=`(.&@5N#58-)@W:#5H.'@Y,`@X:!6X-5DV^87@"#
MAH%;@U6"S)-OF%Z"S8*Q@LR#5(-#@V>"Q8+-B]:.?H*S@NJ"Q(*B@MR"MX%"
M`(.&@5N#58%;@T&#2H-%@Y.#9X*J@J""Z(+<@KF"\8%"@4(`@X:!6X-5EKP`
M@X:!6X-5EKP@(B5S(B""S8KY@LF"H(+H@MR"MX%"`(.&@5N#59:\.@"#AH%;
M@U66O#H@`(-6@UB#98.`DH:"S(.&@5N#58%&`(-%@UF#>(-,@UB#7H.3BZ28
M88V1`(MXB<D`ETR,^)"K`(-O@VN#08-CBZ2888V1`(-X@VR#68-'@XF!18-[
M@XJ#;X.+BZ2888V1`(R?C]B.N)1S("T@@K&"S(.!@V*#6H%;@U>"S8G\XH*"
MLX+J@L2"HH+I@N:"I(+%@K>!0@"4Q0"#;X%;@U>#AX.3BL>7G0"/8XC*DG4`
M@WB#9X-I@X".T(GOCN6+8(NDF&&-D0`E<R""\(RI@ND`BD^5E(+,('=E8B"#
M>8%;@U>"\)5<CJ8`B7"7S(-O@5N#5X.3CY23AP"5Q)?,@V^!6X-7@Y./E).'
M`(-%@TB#BH-8@46#=(-G@T2!6X-ICY23AP",>(V0`)"%`):(CU0`@N:"I(*Q
M@KL`)7,@@LF"YH*D@K&"NP`E<R""LX+Q@4&"YH*D@K&"NP"0O(-4@VZ#B0`E
M<X.-@T^#0X.3C.."QX+,@T&#=H.*@U"!6X-6@X>#DX+PE5R.IH*U@MR"MX*I
M@4@`B^:0V(+HE;:.FH+-B;V"Q8*W@JF!2`"(^)=PE;:.FH+-B;V"Q8*W@JF!
M2`"#98-,@UB#9X-'@V:#0H->@5N"S(-V@XF#3X-#@Y."\)%)D?""M8+<@K>!
M0@"5G0"-MH+)DG6"K25S@X&#:H.%@5N"S)6=@6F.GXGQ@LR#C8-/@T.#DX*I
M@N>73(SX@6HZ`)5<@LR5G0"5G8+,DE"(R@"5G8%&`)=^@K6"HH+@@LR(ZI>7
M`(O.EK&0YH+,CUJ/B@"+SI:QD.:"S)-DF&*4U(V&`"5D((USEMJ"Q8K4B.&"
MP8*]C8"6VI"4@4*0LX*U@JV"S2`E9(%!CG>2Z(*S@NJ"O8+,@LT@)62!0@"*
MU(CA@L&"O8V`EMJ0E(%"D+."M8*M@LT@)62!08YWDNB"LX+J@KV"S(+-("5D
M@4(`5D93@W2#0(-#@XN"S)/'@MV/;X*UDH:"R95SD+."R(-)@W2#6H-B@V<@
M)60@@JJ.=Y+H@K."ZH+<@K6"O8%"`%@U,#EV,R"*[I9[D*>,P`!8-3`Y=C,@
MC*Z.9Y=PED``6#4P.78S(([ED<R.TH+,E<J6O`!8-3`Y=C,@CN61S([2@LR,
MKHZOE<J.<0!8-3`Y=C,@BF>2HXM`E%P`E$X`E$X`EHB43@"#0X-'@X&#DXND
MF&&-D0""S8*B`).OB-."M8+<@K<`C:&"S8-E@TR#6(-G@X*!6X-H@L6"MX%"
M6SP^78-[@UZ#DX+%5UE325=91X."@5N#:(+)EM^"Z(+<@K>!0@`E9""(R(_C
M@LR#=8.-@V*#3H+PC>R0K(*W@NF"L8+&@LV+EHG"@K."ZH+$@J*"W(*Y@O&!
M0@""H(+(@KV"S91&C]B"LX+J@L2"HH+<@KF"\8%"`):\D4^"S)*&@LD@)UPG
M((+&@J*"I)6VCIJ"S8YG@J:"W(*Y@O&!0@"73(SX@LB39(YQ@X&!6X.+@T&#
M:(.,@UB"Q8+-@J""Z(+<@KF"\8%"`(-#@Y.#?(%;@V>"LX+J@KV#=(-`@T.#
MBX+,@W2#0H%;@XN#:(+P)7.3X(+,D<Z)GH*W@NF#=(-"@5N#BX-H@LF#?8-B
M@W:"M8+$@MR"N8+Q+@"#C8-/@T&#18-G@K6"W(*U@KTN`)"S@K6"HI-DF&*4
MU(V&@O"3_)?-@K>"Z8+F@J2"R9*-B-."M8+$B;J"LX*B@4*0E(Z:@KZ"KX*J
MCF>7<(+%@JN"W(*W@JJ!08V1C=N39)AB@LB"YY#FDZJ"R8%[@O"5=(*O@MR"
MMX%"`)"S@K6"HI)L@O"3_)?-@K6"Q(FZ@K."HH%"`(-4@T.#DX-!@V*#=H+P
MEYB7<(*W@NF"O8+?@LF"S2!$871A5')E92"#;X-B@TZ#1X.3@VB"\)#=DNB"
MMX+IE4N7=H*J@J""Z(+<@K>!0@!61E,@@V^#8H-.@T>#DX-H@O"0W9+H@K>"
MZ95+EW:"JH*@@NB"W(*W@4(`C^&*48+,D^"798+PBTR/<8*U@L2"J8+G@4&/
MX8I1@XR#?(%;@V>"\)&7D$V"M8+$@JV"OH*S@J*!0@""L8*Q@LF#BH.3@TZ"
MMX+I55),@O"3_)?-@K6"Q(FZ@K."H@"-[8^<@K>"Z8-4@5N#;X+PCG>2Z(*U
M@L2"K8*^@K."HH%"`(_!BXZ"MX+I@X:!6X-5EKR"\(YWDNB"M8+$@JV"OH*S
M@J*!0@"-[8^<@K>"Z8.&@5N#59:\@O".=Y+H@K6"Q(*M@KZ"LX*B@4(`DL>)
MP8*W@NF#AH%;@U66O(+PCG>2Z(*U@L2"K8*^@K."HH%"`(U8D%:"MX+I@X:!
M6X-5EKR"\(YWDNB"M8+$@JV"OH*S@J*!0@".P(US@K>"Z8-!@TZ#5H.'@Y."
M\(YWDNB"M8+$@JV"OH*S@J*!0@"05H*U@J*5JI?>EKR"\)/\E\V"M8+$B;J"
MLX*B@4(`)7,@@UJ#8H-6@X>#DX+,ETR,^(KZC,""JI#8@NJ"Q(*B@MR"MX%"
M@XV#3X-#@Y."M9*\@K6"Q(*M@KZ"LX*B@4(`DV2.<8.!@5N#BX-!@VB#C(-8
M`(*@@LB"O8+,($9R;VTZ((-!@VB#C(-8`(*@@LB"O8+,@T.#DX-T@TB#@8%;
M@U:#AX.3`(-:@V*#5H.'@Y,@)7,@@LR*U(+)@J""R(*]@LR#08-H@XR#6(*J
ME<^-6(*S@NJ"W(*U@KV!0H-:@TR#A8.*@V6#0H%;E=N,[(+,@KV"WX+)@XV#
M3X-#@Y."M9*\@K>"UX*K@L6"MX%"`(*@@LB"O8+,EKR13P""L8+,E$:/V(-O
M@V*#3H-'@Y.#:(+%@LV!08.&@5N#58+,DL>)P8*J@U2#?(%;@V>"LX+J@L2"
MHH+<@KF"\8%"@N""M2!(;W)D92""Q8.&@5N#58-!@TJ#18.3@V>"\(K'EYV"
MM8*]@J*"S(+(@N>!09&\@LR41H_8@V^#8H-.@T>#DX-H@O".9X*D@M>"JX+%
M@K>!0@""L8+,E$:/V(-O@V*#3H-'@Y.#:(+%@LV!08.&@5N#58+,@XJ#6(-G
M@JJ#5(-\@5N#9X*S@NJ"Q(*B@LB"HH*I@4&"H(+I@J*"S8F]@N>"J8+,EYV7
M4H+%@K&"S(M`E%R"JI:SC/B"R8+(@L&"Q(*B@MR"MX%"`(-:@V*#5H.'@Y,@
M)7,@@LR*U(+)@J""R(*]@LR#=8.)@T6#58*JE<^-6(*S@NJ"O8+F@J2"R(+,
M@L6!08-:@TR#A8.*@V6#0H%;E=N,[(+,@KV"WX+)@XV#3X-#@Y."M9*\@K>"
MUX*K@L6"MX%"`(*HCF>"HH+,@W6#B8-%@U6"S8*Q@LR+0)1<@O"#5(-\@5N#
M9X*U@L2"HH+<@KF"\8%"`(*HCF>"HH+,@W6#B8-%@U6"S8*Q@LR(\XW\@TF#
M=H-6@X>#DX+P@U2#?(%;@V>"M8+$@J*"W(*Y@O&!0D-O;G1R;VPO0V]M;6%N
M9"`K(%`@@L6(\XW\@K6"Q(FZ@K."HH%"`(->@T.#@(-=@5N#DX%&`(*@@LB"
MO8+,@V:#=(-(@XN#9TE$@LV5SXU8@K."ZH+<@K6"O8%"`(*@@LB"O8+,@V:#
M=(-(@XN#9TE$.@""H(+(@KV"S(Z!EKP`@XV#3X-#@Y."S8KZC,"0V(+J@L6"
MMX%"`)!6@K6"HB`E<R"7<(+,@W"#6(./@5N#:(%&)7,`@J""R(*]@LR#28-V
M@U:#AX.3@LV,NXW=@LR#6H-B@U:#AX.3DH:"R97/C5B"LX+J@MR"M8*]@4(`
M@TF#=H-6@X>#DX+PC5B05H*U@MR"M8*]`(-P@UB#CX%;@VB"S8.*@UJ#8H-G
M@K."ZH+<@K6"O8%"`(-P@UB#CX%;@VB"S8.*@UJ#8H-G@K."ZH+<@K6"O8+,
M@L6!09!6@K6"HH-P@UB#CX%;@VB"Q8.-@T^#0X.3@K6"Q(+=@L2)NH*S@J*!
M0@"#<(-8@X^!6X-H@JJ*^HS`D-B"ZH+%@K>!0@"#BH."@5N#9X-4@5N#;SH`
M@X:!6X-3@UB#B8-R@T$`@U6#0X%;@XN+I)AAC9&!:8-2@Y.#4Y:OCN6+I)AA
MC9&!:@"#58.3@W*#08NDF&&-D0"#5X.3@V^#=8-'BZ2888V1`(%MC^&*497Q
MC9"!;@!;C7,Z)7,O)7-=`%]!BL>7G0!?1(US@O"-[8^<`%]'@T^#BX%;@W8`
M7TB#=X.+@W8`7TF)YI&<@W:#C8-P@V6#0BXN+@!?3(.-@T^#0X.3`%],@XV#
M3X-!@T6#9P!?38.*@Y.#3I7/C5@`7T^#28-V@U:#AX.3`%]0@T&#3H-:@UB,
MH`!?4H.*@Y.#3HWMCYP`7U.#6H-B@V>#08-B@W8`7U257)&ND*L`7U6#AH%;
M@U4`@T&#:(.,@UB2H`"5<Y:^@LB#08-H@XR#6`"77)+HE5P`CV^7S8-T@T"#
M0X.+@JJ-[)"L@L6"JX+<@KF"\0"3_)?-@W2#0(-#@XN"JHI*@J^"W(*Y@O$`
M@K&"L8+P@TZ#BH-B@TX`@U*#?8.3@VB-<XYGEW""S(-'@XF!6P"0W9+H@T>#
MB8%;`(]DEW:"R(-6@UB#98.`@W2#0(-#@XN"S(R'EXX`@V:!6X->C&".KH-'
M@XF!6P"5TH]7`(V`EMJ"JH*@@NB"W(*Y@O$`@W2#0(-#@XL`@WJ#6(-GEKR"
MJI5SEKX`D_R/;Y?-@T>#B8%;`(-<@W2#9X-%@T:#09/@E92"S(-'@XF!6P"6
MO)%/`([`D96"LX+J@L2"HH+<@KF"\0""W(*^CL"1E8*S@NJ"Q(*B@MR"N8+Q
M`(.!@X*2H`"#<(%;@UJ#DX-G`(-!@TZ#6H-8@LV+D93;@K."ZH+<@K6"O0"#
M<X-.@UJ#BP"#BH."@5N#9X+%@LR#=H.-@V>#4H.+@T>#B8%;`(-4@5N#<H-8
ME7.47`"-MY6J@O"57(ZF`(-6@UB#98.`@T>#B8%;`(->@UB#3H.*@UB#9P"(
MZHZ>DTF"R(-'@XF!6P"*;91&@LR"O8+?@W"#6(./@5N#:#*3>)/\E\V"M8+$
MB;J"LX*B`):SEKP`=D-A<F0`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]H=5](52],0U]-15-304=%
M4P``````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T,2`P,C$U,#8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE
M+VAU7TA5+VAE;'`N>&UL````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`T,#<V(#$P-3$U-#,T,30Q(#`R,30V,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2)I<V\M.#@U.2TR(C\^"CPA+2T@2&]R9&4@,RXQ
M(&AE;'`Z(&AU7TA5("1(;W)D93H@:&]R9&4O;&]C86QE+VAU7TA5+VAE;'`N
M>&UL+'8@,2XR+C$P+C,@,C`P-B\P,R\P,R`Q,SHT-#HQ,"!J86X@17AP("0@
M+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](G5P=&]D
M871E(B!M9#4](C8X8V$S,V8W9C!C.6%A931C,3`S96(T-S0Y,F-D8S$U(CX*
M/'1I=&QE/D$@<WIE;>EL>65S(/9S<WIE9WKU("AP;W)TX6PI(&]L9&%L/"]T
M:71L93X*(#QP87)A/@H@($5Z(&%Z(&]L9&%L(&=Y;W)S(/9S<WIE9WKI<W0@
M860@87H@UFX@<WKA;>%R82!F;VYT;W,@:6YF;W)MX6-I\VMR\VPN"B`@4&PN
M(&IE;&5Z:&5T:2P@:&]G>2!HX6YY(/IJ(&QE=F5L92!V86X@87H@24Y"3U@@
M;6%P<.%B86XL(&UI;'EE;B`*("!E;&9O9VQA;'1SX6=A:2!V86YN86L@8F7M
M<G9A(&$@:_9Z96QJ]G;U8F5N(&$@;F%P=.%R8F%N+"!M:6QY96X*("!E;&EN
M=.EZ96YD]2!D;VQG;VL@=F%N;F%K(&$@9F5L861A=&QI<W3A:N%B86XL(&1E
M(&UE9VIE;&5N[71H973U"B`@96=YZ6(@:_QL<_4@<WIO;&?A;'1A=.%S;VL@
M=&%R=&%L;6$@:7,L('-T8BX@17IE:V+U;"!A>B#V<W-Z96=ZZ7-E:V+U;`H@
M('-O:W-Z;W(@:_9Z=F5T;&5N_&P@:6YD[71H873S:R!A(&=Y86MR86X@:&%S
M>F[A;'0@9G5N:V-I\VLL('!L+@H@(/IJ(&QE=NEL(.URX7-A+"#Z:B!B96IE
M9WEZZ7,@:^ES>NUTZ7-E(&$@;F%P=.%R8F$@=F%G>2!A(&9E;&%D871L:7-T
MX6)A+"`*("!S=&(N"B`@/"]P87)A/@H@/'!A<F$^"B`@12!S>F5MZ6QY97,@
M]G-S>F5G>O4@;VQD86P@=&%R=&%L;>%T(&$@5&5R=F5ZZ7,@9V]M8F)A;"!M
M\V1O<^UT:&%T:F$N"B`@365G861H871J82!P;"XL(&AO9WD@;6EL>65N(&EN
M9F]R;>%C:?-K870@:^UVX6X@;65G:F5L96[M=&5N:2P@Z7,*("!M:6QY96X@
M96QR96YD97KI<V)E;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60]
M(FYA=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4](F(X8V8P864Q.64U-V1F
M83!C,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/D%Z(&%L:V%L;6%ZX7-VX6QA
M<WIT\R!M96[\/"]T:71L93X*(#QP87)A/@H@($$@=V5B;VQD86P@8F%L(&]L
M9&%LX6X@96=Y(&%L:V%L;6%ZX7-VX6QA<WIT\R!M96[\('1A;.%L:&%T\RX*
M("!!(&UE9V9E;&5L]2!F96QI<F%T;VMR82!K871T:6YT=F$@9WEO<G-A;B#I
M<R!K]FYN>65N(.%T=6=O<FAA="!E9WEI:PH@(&%L:V%L;6%ZX7-B\VP@82!M
MX7-I:V)A+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB<')E9G,M
M9&]?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)D9#DU9&8P
M-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(^"B`@("`\=&ET;&4^3W!C:?-K
M.B!"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S(&9E;&%D871O:SH@=NEG
M<F5H86ITX7,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!(82!A>G0@<WIE<F5T
M;NDL(&AO9WD@8F5J96QE;G1K97KI<VMO<B!F=7-S86YA:PH@("`@;&4@82!K
M87)B86YT87)TX7-I(&9E;&%D871O:RP@:F5L]FQJ92!B92!A(&[I9WEZ971E
M="X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O
M;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U/2)A,C$Q
M-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET;&4^3W!C
M:?-K.B!"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA=&]S(&9E;&%D871O:SH@
M;65G97+U<^UTZ7,\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!(82!A>G0@<WIE
M<F5T;NDL(&AO9WD@82!R96YD<WIE<B!M96=E<O5S[73I<W0@:^ER:F5N(-9N
M=/5L(&UI96SU='0*("`@(';I9W)E:&%J=&%NX2!A(&MA<F)A;G1A<G3A<VD@
M9F5L861A=&]K870L(&IE;/9L:F4@8F4@97IT(&$@;NEG>7IE=&5T+@H@("`@
M2&$@;F5M(&IE;/9L:2!B92P@82!K87)B86YT87)TX7-I(&9E;&%D871O:R!B
M96IE;&5N=&ME>NES:V]R(&%U=&]M871I:W5S86X@"B`@("!L92!F;V=N86L@
M9G5T;FDL(&%NZ6QK_&PL(&AO9WD@8F5F;VQYX7-O;&AA=&[A(/5K970N"B`@
M("`\+W!A<F$^"CPO96YT<GD^"CPO:&5L<#X*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&]C86QE+VAU7TA5+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P-#(S,3`U(#$P-3$U-#,T,30Q(#`R,S(S
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````#>
M$@25`````','```<````M#L``.\)``!,=P````````B?```.````"9\```\`
M```8GP``#0```"B?```(````-I\```L````_GP``#````$N?```$````6)\`
M`!@```!=GP``&P```':?```M````DI\``!T```#`GP``)````-Z?```I````
M`Z```!D````MH```)@```$>@```,````;J```"0```![H```#P```*"@```+
M````L*````X```"\H```*````,N@```(````]*````H```#]H```%0````BA
M```2````'J$```L````QH0``A0```#VA```.````PZ$```H```#2H0``#0``
M`-VA```.````ZZ$``!$```#ZH0``#0````RB```,````&J(```T````GH@``
ME````#6B```*````RJ(```\```#5H@``&````.6B```,````_J(```X````+
MHP``#@```!JC```(````*:,```D````RHP``+@```#RC```:````:Z,``#(`
M``"&HP``.````+FC``!4````\J,``%$```!'I```6@```)FD``!7````]*0`
M`#0```!,I0``"0```(&E```-````BZ4```<```"9I0``"@```*&E```/````
MK*4```4```"\I0``!@```,*E```1````R:4```@```#;I0``"0```.2E```)
M````[J4``"4```#XI0``(````!ZF```3````/Z8``!````!3I@``#P```&2F
M```*````=*8```,```!_I@``#P```(.F```4````DZ8```D```"HI@``#0``
M`+*F```2````P*8``!D```#3I@``'@```.VF```/````#*<```H````<IP``
M#P```">G```(````-Z<``"0```!`IP``%````&6G```6````>J<```@```"1
MIP``3@```)JG```M````Z:<``!D````7J```!P```#&H```,````.:@``"P`
M``!&J```#@```'.H```#````@J@```L```"&J```!P```)*H```'````FJ@`
M``4```"BJ```!0```*BH```*````KJ@```,```"YJ```%P```+VH```*````
MU:@```\```#@J```#@```/"H```8````_Z@``",````8J0``#@```#RI```4
M````2ZD``!<```!@J0``%P```'BI```7````D*D``!,```"HJ0``#P```+RI
M```.````S*D``!\```#;J0``'0```/NI```'````&:H```8````AJ@``"```
M`"BJ```/````,:H```8```!!J@``"@```$BJ```3````4ZH```L```!GJ@``
M$````'.J```5````A*H``!4```":J@``!P```+"J```0````N*H```4```#)
MJ@``%0```,^J```1````Y:H```P```#WJ@``.P````2K```X````0*L```D`
M``!YJP``!P```(.K```4````BZL```,```"@JP``!0```*2K```0````JJL`
M``D```"[JP``$P```,6K```Y````V:L``!(````3K```)P```":L```L````
M3JP``"H```![K```)0```*:L```*````S*P```8```#7K```"0```-ZL```'
M````Z*P``"\```#PK```-P```""M```N````6*T``%4```"'K0``+0```-VM
M```M````"ZX``#T````YK@``/P```'>N```M````MZX``$````#EK@``(P``
M`":O```C````2J\``$````!NKP``+0```*^O```S````W:\``"4````1L```
M%0```#>P```9````3;```"D```!GL```)````)&P```H````MK```!$```#?
ML```"@```/&P```,````_+````H````)L0``$````!2Q```6````);$``!8`
M```\L0``!P```%.Q```'````6[$``!0```!CL0``"@```'BQ```(````@[$`
M`"<```",L0``"````+2Q```'````O;$```<```#%L0``!@```,VQ```%````
MU+$```<```#:L0``!@```.*Q```(````Z;$``"D```#RL0``#@```!RR```*
M````*[(```0````VL@``!P```#NR```)````0[(```8```!-L@``$0```%2R
M```'````9K(``!8```!NL@``!````(6R```(````BK(```8```"3L@``#0``
M`)JR```&````J+(``!X```"OL@``$0```,ZR```(````X+(```T```#IL@``
M#````/>R```'````!+,```,````,LP```P```!"S```7````%+,``!,````L
MLP``'0```$"S```(````7K,```0```!GLP``"````&RS```(````=;,``$$`
M``!^LP``&@```,"S```K````V[,``"`````'M```%0```"BT```&````/K0`
M``8```!%M```%0```$RT```8````8K0``"(```![M```+@```)ZT```=````
MS;0``"$```#KM```5`````VU```I````8K4```H```",M0``!P```)>U```'
M````G[4``!4```"GM0``#@```+VU```*````S+4```\```#7M0``#0```.>U
M```/````];4```T````%M@``"0```!.V```4````';8```8````RM@``&```
M`#FV```=````4K8``!,```!PM@``$0```(2V```4````EK8```0```"KM@``
M!@```+"V```4````M[8``%0```#,M@``9````"&W```$````AK<```X```"+
MMP``!0```)JW```%````H+<``!L```"FMP``&@```,*W```3````W;<``!$`
M``#QMP``$0````.X```<````%;@``"H````RN```$````%VX```A````;K@`
M``4```"0N```$P```):X```+````JK@``!(```"VN```"@```,FX```/````
MU+@```T```#DN```$0```/*X```3````!+D```P````8N0``!@```"6Y```,
M````++D```8````YN0``%P```$"Y```0````6+D``!$```!IN0``"````'NY
M```%````A+D```P```"*N0``$````)>Y```%````J+D```T```"NN0``!@``
M`+RY```'````P[D```T```#+N0``!P```-FY```+````X;D```<```#MN0``
M!P```/6Y```)````_;D```D````'N@``"@```!&Z```9````'+H``#T````V
MN@``'0```'2Z```,````DKH``!````"?N@``!0```+"Z```E````MKH``!(`
M``#<N@``$P```.^Z```K`````[L``#L````ONP``(````&N[```(````C+L`
M`#8```"5NP``(0```,R[```0````[KL```@```#_NP``#`````B\```&````
M%;P```0````<O```#P```"&\```.````,;P```<```!`O```"@```$B\```-
M````4[P``!\```!AO```'````(&\```A````GKP``!X```#`O```&0```-^\
M```>````^;P``!L````8O0``(0```#2]```N````5KT``"8```"%O0``'```
M`*R]```>````R;T``!P```#HO0``)@````6^```K````++X``#,```!8O@``
M)@```(R^```K````L[X``#@```#?O@``'0```!B_```5````-K\``"\```!,
MOP``(````'R_```2````G;\``"D```"POP``'@```-J_```@````^;\``!(`
M```:P```H@```"W````6````T,```",```#GP```*`````O!```I````-,$`
M`"@```!>P0``'P```(?!```5````I\$``"````"]P0``)0```-[!```H````
M!,(``"T````MP@``,````%O"``"2````C,(``"$````?PP``%@```$'#```<
M````6,,``"8```!UPP``*@```)S#``!!````Q\,``$0````)Q```#````$[$
M```'````6\0```<```!CQ```!@```&O$```-````<L0``!````"`Q```$@``
M`)'$```3````I,0``!(```"XQ```!P```,O$```$````T\0``!````#8Q```
M$````.G$```,````^L0```X````'Q0``#0```!;%```/````),4``!,````T
MQ0``#0```$C%```H````5L4```,```!_Q0``#0```(/%```&````D<4``!$`
M``"8Q0``%P```*K%```;````PL4```X```#>Q0```@```.W%``!)````\,4`
M``4````ZQ@``$````$#&```/````4<8```0```!AQ@``#0```&;&```.````
M=,8```,```"#Q@``#@```(?&```(````EL8```\```"?Q@``#P```*_&```'
M````O\8```T```#'Q@``$````-7&```-````YL8```L```#TQ@``!@````#'
M```+````!\<```P````3QP``"@```"#'```1````*\<``!D````]QP``"P``
M`%?'```-````8\<``"(```!QQP``#P```)3'```;````I,<``#0```#`QP``
M"@```/7'```8`````,@``!(````9R```&0```"S(```6````1L@``"(```!=
MR```#0```(#(```'````CL@``!0```"6R```"P```*O(```B````M\@``"\`
M``#:R```"P````K)```)````%LD``!D````@R0``"P```#K)```7````1LD`
M`!<```!>R0``"0```';)```6````@,D```\```"7R0``&0```*?)```6````
MP<D```X```#8R0``&````.?)```(`````,H```T````)R@``)@```!?*``!#
M````/LH```@```""R@``$@```(O*```?````GLH```@```"^R@``"P```,?*
M```O````T\H```X````#RP``!0```!++```&````&,L``$4````?RP```P``
M`&7+```'````:<L```0```!QRP``"@```';+```*````@<L```\```",RP``
M$````)S+```7````K<L``!$```#%RP``&0```-?+```7````\<L```D````)
MS```!0```!/,```+````&<P```H````ES````@```##,```%````,\P```T`
M```YS```&P```$?,```7````8\P``!0```![S```"0```)#,```.````FLP`
M``T```"IS```$@```+?,```X````RLP``"`````#S0``"````"3-```.````
M+<T``'L````\S0``&````+C-```8````T<T``!$```#JS0``!P```/S-```%
M````!,X``!@````*S@``'@```"/.```;````0LX``!D```!>S@``&P```'C.
M```9````E,X``!,```"NS@``!P```,+.```(````RLX```8```#3S@``!@``
M`-K.```0````X<X```\```#RS@``$`````+/```/````$\\```L````CSP``
M#P```"_/```,````/\\```\```!,SP``!P```%S/```&````9,\```X```!K
MSP``#````'K/```H````A\\```\```"PSP``"````,#/```(````R<\``!,`
M``#2SP``'@```.;/```A````!=```"`````GT```&0```$C0```7````8M``
M`"4```!ZT```%P```*#0```6````N-````0```#/T```&P```-30```-````
M\-````P```#^T````P````O1```%````#]$```@````5T0``"@```![1```,
M````*=$```L````VT0``$````$+1```,````4]$```X```!@T0``!````&_1
M```$````=-$``!,```!YT0``%````(W1```,````HM$```D```"OT0``#@``
M`+G1```+````R-$``!L```#4T0``!P```/#1```'````^-$```H`````T@``
M#0````O2```)````&=(```0````CT@```P```"C2```8````+-(```H```!%
MT@``!````%#2```F````5=(```X```!\T@``?````(O2```5````"-,```4`
M```>TP``!P```"33```,````+-,```@````YTP``"@```$+3```&````3=,`
M``@```!4TP```@```%W3```&````8-,```8```!GTP``%````&[3```-````
M@],``!````"1TP``&P```*+3```$````OM,```D```##TP``$````,W3```)
M````WM,```D```#HTP``!0```/+3```:````^-,```@````3U```!@```!S4
M```9````(]0```X````]U```!P```$S4```'````5-0```4```!<U```"0``
M`&+4```*````;-0```X```!WU````@```(;4```&````B=0```L```"0U```
M#0```)S4```)````JM0```8```"TU```$@```+O4```)````SM0```<```#8
MU```%````.#4```=````]=0``$(````3U0``)0```%;5```E````?-4```8`
M``"BU0``"@```*G5```$````M-4```D```"YU0``"````,/5```1````S-4`
M``D```#>U0``!@```.C5```-````[]4```8```#]U0``.0````36```]````
M/M8``#H```!\U@``'@```+?6```%````UM8```X```#<U@``!````.O6```&
M````\-8```<```#WU@``(0```/_6```-````(=<``!4````OUP``!@```$77
M```$````3-<``!$```!1UP``!@```&/7```*````:M<``"(```!UUP``!```
M`)C7```%````G=<``!T```"CUP``!````,'7```,````QM<```X```#3UP``
M"@```.+7```(````[=<```D```#VUP``!0````#8```Z````!M@``#````!!
MV```-0```'+8```I````J-@``$<```#2V```.````!K9```I````4]D``#\`
M``!]V0``+@```+W9```M````[-D``!\````:V@``#P```#K:```2````2MH`
M``L```!=V@``)@```&G:```I````D-H``"0```"ZV@``)@```-_:```(````
M!ML```H````/VP``"0```!K;```'````)-L``"`````LVP``(````$W;```F
M````;ML```H```"5VP``&0```*#;```I````NML``!8```#DVP``$@```/O;
M```'````#MP```H````6W```#````"'<```/````+MP``!`````^W```0```
M`$_<``!P````D-P``&8````!W0``#@```&C=```)````=]T```H```"!W0``
M$@```(S=```3````G]T```P```"SW0``!@```,#=```/````Q]T``!(```#7
MW0``$````.K=```1````^]T``!P````-W@``(P```"K>``!J````3MX```\`
M``"YW@``!0```,G>```0````S]X```D```#@W@``!````.K>```+````[]X`
M`"````#[W@``%````!S?```,````,=\```P````^WP``#P```$O?```5````
M6]\``"D```!QWP``*@```)O?```F````QM\``"<```#MWP``*0```!7@```J
M````/^```!D```!JX```0@```(3@```1````Q^```!(```#9X```$P```.S@
M```4`````.$```\````5X0``%@```"7A```7````/.$``!````!4X0``$0``
M`&7A```T````=^$``!,```"LX0``$@```,#A```U````T^$``!0````)X@``
M!P```![B```,````)N(``"`````SX@``$````%3B```4````9>(``!$```!Z
MX@``%P```(SB```<````I.(``!,```#!X@``%````-7B```:````ZN(``!$`
M```%XP``&@```!?C```>````,N,``!H```!1XP``$P```&SC```5````@.,`
M`!$```"6XP``%P```*CC```4````P.,``!<```#5XP``%0```.WC```)````
M`^0``!`````-Y```&0```![D```$````..0```<````]Y```"P```$7D```1
M````4>0```8```!CY```!@```&KD```&````<>0```4```!XY```!P```'[D
M```'````AN0```4```".Y```%@```)3D```&````J^0```8```"RY```!```
M`+GD```$````ON0```<```##Y```#@```,OD```,````VN0```P```#GY```
M#0```/3D```*`````N4```X````-Y0``!0```!SE```H````(N4```X```!+
MY0``#````%KE```/````9^4```H```!WY0``"````(+E```)````B^4``"L`
M``"5Y0``!````,'E```(````QN4``"8```#/Y0``$@```/;E```/````">8`
M``8````9Y@``"@```"#F```'````*^8```@````SY@``(````#SF```)````
M7>8``!0```!GY@``#````'SF```-````B>8```X```"7Y@``%@```*;F```1
M````O>8```8```#/Y@```P```-;F```&````VN8``!D```#AY@``!P```/OF
M```$`````^<```L````(YP``"P```!3G```'````(.<```4````HYP``!P``
M`"[G```6````-N<```T```!-YP``#0```%OG```*````:><``!````!TYP``
M#P```(7G```1````E><``!<```"GYP``"@```+_G```1````RN<```0```#<
MYP``#P```.'G```Z````\><```4````LZ```#````#+H```>````/^@```X`
M``!>Z```$````&WH```+````?N@```P```"*Z```"0```)?H```'````H>@`
M``H```"IZ```"0```+3H```.````ON@``!````#-Z```&P```-[H```8````
M^N@``!H````3Z0``"@```"[I```)````.>D```H```!#Z0``#````$[I```/
M````6^D```@```!KZ0``!@```'3I```<````>^D```<```"8Z0``!0```*#I
M```+````IND``$<```"RZ0``#0```/KI```)````".H```0````2Z@```P``
M`!?J```3````&^H``!,````OZ@``$P```$/J```*````5^H```(```!BZ@``
M!````&7J```E````:NH```,```"0Z@``!0```)3J```J````FNH```H```#%
MZ@``!0```-#J```$````UNH```H```#;Z@``#0```.;J```&````].H```@`
M``#[Z@``"`````3K```$````#>L```4````2ZP``:````!CK```)````@>L`
M``P```"+ZP``$````)CK```%````J>L```8```"OZP``&P```+;K```O````
MTNL``!`````"[```"@```!/L```/````'NP```H````N[```"0```#GL```3
M````0^P``!L```!7[```&````'/L```7````C.P``!\```"D[```#@```,3L
M```#````T^P```<```#7[```"````-_L```'````Z.P```H```#P[```"P``
M`/OL```'````!^T``%$````/[0``$````&'M```,````<NT```T```!_[0``
M&@```(WM``!*````J.T``!D```#S[0``!@````WN```:````%.X``"4````O
M[@``!@```%7N```&````7.X``!\```!C[@``!@```(/N```)````BNX``!@`
M``"4[@``%P```*WN```H````Q>X```8```#N[@``#0```/7N```B`````^\`
M`%<````F[P``$P```'[O```C````DN\``!,```"V[P```@```,KO```+````
MS>\```@```#9[P``#0```.+O```*````\.\```<```#[[P``%`````/P```&
M````&/````@````?\```#@```"CP```'````-_````H````_\```"P```$KP
M```R````5O````<```")\```#````)'P```-````GO````P```"L\```"0``
M`+GP```)````P_````H```#-\```!P```-CP```)````X/````<```#J\```
M"@```/+P```;````_?````\````9\0``$@```"GQ```*````//$``!8```!'
M\0``"0```%[Q```0````:/$```<```!Y\0``$@```('Q```$````E/$```<`
M``"9\0``!0```*'Q```%````I_$```L```"M\0``%````+GQ```1````SO$`
M`!H```#@\0``%@```/OQ```4````$O(``!<````G\@``&````#_R```<````
M6/(``!D```!U\@``!P```(_R```%````E_(```T```"=\@``#````*OR```1
M````N/(```@```#*\@``%P```-/R```+````Z_(```P```#W\@``'P````3S
M```:````)/,``!,````_\P``!````%/S```*````6/,```0```!C\P``#0``
M`&CS```,````=O,```4```"#\P``"0```(GS```%````D_,```<```"9\P``
M!0```*'S```$````I_,```(```"L\P``.````*_S```L````Z/,``!(````5
M]```*0```"CT```R````4O0```H```"%]```+````)#T```N````O?0``#,`
M``#L]```,P```"#U```X````5/4```\```"-]0``&````)WU```0````MO4`
M``\```#']0``$P```-?U```5````Z_4``!0````!]@``$@```!;V```4````
M*?8``!4````^]@``+0```%3V```M````@O8``#$```"P]@``+@```.+V```O
M````$?<``"P```!!]P``8@```&[W```3````T?<```T```#E]P``"````//W
M```7````_/<```@````4^```#````!WX```K````*O@``"$```!6^```&@``
M`'CX```)````D_@``$4```"=^```00```./X```$````)?D``!,````J^0``
M%````#[Y```.````4_D``!,```!B^0``&````';Y```&````C_D```D```"6
M^0``"@```*#Y```/````J_D``!````"[^0``!P```,SY```.````U/D```4`
M``#C^0``&P```.GY```(````!?H```8````.^@``%````!7Z```1````*OH`
M``X````\^@``.````$OZ```"````A/H```8```"'^@``#@```([Z```%````
MG?H```<```"C^@``#@```*OZ```&````NOH``"@```#!^@``#````.KZ```<
M````]_H```0````4^P``*0```!G[```7````0_L``!\```!;^P``7````'O[
M```4````V/L``#X```#M^P``'P```"S\```0````3/P```<```!=_```#@``
M`&7\```,````=/P```P```"!_```$P```([\```*````HOP``!T```"M_```
M&0```,O\```%````Y?P``!$```#K_```$0```/W\```D````#_T``!(````T
M_0``%0```$?]```2````7?T```X```!P_0``&0```'_]```(````F?T```T`
M``"B_0``!P```+#]```*````N/T```<```##_0``#P```,O]```&````V_T`
M``L```#B_0``&@```.[]```'````"?X```@````1_@``!0```!K^```?````
M(/X```8```!`_@``$````$?^```(````6/X```T```!A_@``"````&_^```>
M````>/X``!(```"7_@``+````*K^```:````U_X```D```#R_@``"@```/S^
M```5````!_\```4````=_P``%````"/_```$````./\``!`````]_P``!@``
M`$[_```'````5?\``!X```!=_P``*````'S_```*````I?\``!P```"P_P``
M$0```,W_```+````W_\``!H```#K_P``%`````8``0`$````&P`!``0````@
M``$`"P```"4``0`%````,0`!``8````W``$`"````#X``0`&````1P`!``H`
M``!.``$`&P```%D``0`T````=0`!`#0```"J``$`(````-\``0`I``````$!
M`"`````J`0$`00```$L!`0`:````C0$!`"@```"H`0$`*0```-$!`0!0````
M^P$!`"(```!,`@$`!@```&\"`0`(````=@(!``4```!_`@$`"````(4"`0`9
M````C@(!`!D```"H`@$`*@```,("`0`C````[0(!`!D````1`P$`+@```"L#
M`0`T````6@,!``@```"/`P$`%P```)@#`0`*````L`,!``<```"[`P$`(0``
M`,,#`0`0````Y0,!``X```#V`P$`"P````4$`0`'````$00!`!,````9!`$`
M"````"T$`0`+````-@0!``H```!"!`$`%````$T$`0`/````8@0!`#(```!R
M!`$`"P```*4$`0`.````L00!``4```#`!`$`!0```,8$`0`%````S`0!`!<`
M``#2!`$`#P```.H$`0`$````^@0!``H```#_!`$`"0````H%`0`+````%`4!
M``T````@!0$`#````"X%`0`.````.P4!``4```!*!0$`!````%`%`0`-````
M504!`#(```!C!0$`10```)8%`0`7````W`4!``<```#T!0$`'@```/P%`0`4
M````&P8!`!0````P!@$`!@```$4&`0`'````3`8!``X```!4!@$`*@```&,&
M`0`&````C@8!``P```"5!@$`#0```*(&`0`1````L`8!``L```#"!@$`-@``
M`,X&`0`*````!0<!`"(````0!P$`"P```#,'`0`/````/P<!`#(```!/!P$`
M)0```(('`0`P````J`<!`#$```#9!P$`+0````L(`0`.````.0@!``4```!(
M"`$`#@```$X(`0`3````70@!`!(```!Q"`$`!P```(0(`0`1````C`@!`!,`
M``">"`$`!P```+((`0`4````N@@!`!@```#/"`$`!P```.@(`0`%````\`@!
M``P```#V"`$`#`````,)`0`2````$`D!``0````C"0$`!P```"@)`0`*````
M,`D!``L````["0$`#````$<)`0`.````5`D!``X```!C"0$`!0```'()`0`%
M````>`D!`"X```!^"0$`)@```*T)`0`C````U`D!``,```#X"0$`$@```/P)
M`0`&````#PH!`!X````6"@$`&````#4*`0`E````3@H!``T```!T"@$`'P``
M`((*`0`#````H@H!``<```"F"@$``@```*X*`0`,````L0H!`!4```"^"@$`
M"P```-0*`0`9````X`H!`"````#Z"@$`$@```!L+`0`%````+@L!``H````T
M"P$`%0```#\+`0`2````50L!``P```!H"P$`!````'4+`0`)````>@L!``<`
M``"$"P$`#````(P+`0!2````F0L!`!<```#L"P$`)`````0,`0`2````*0P!
M``<````\#`$`!@```$0,`0`.````2PP!``P```!:#`$`#0```&<,`0`5````
M=0P!`!(```"+#`$`#P```)X,`0`4````K@P!``H```###`$`&P```,X,`0`0
M````Z@P!``L```#[#`$`:0````<-`0`:````<0T!`!<```",#0$`)P```*0-
M`0`:````S`T!`!<```#G#0$`&P```/\-`0`9````&PX!`!\````U#@$`$P``
M`%4.`0`(````:0X!``<```!R#@$`"````'H.`0`)````@PX!`!4```"-#@$`
M#0```*,.`0`C````L0X!``T```#5#@$`$P```.,.`0`(````]PX!``,`````
M#P$`1@````0/`0`_````2P\!`#<```"+#P$`5P```,,/`0`%````&Q`!`!\`
M```A$`$`+P```$$0`0`*````<1`!``@```!\$`$`#0```(40`0`M````DQ`!
M``0```#!$`$`3P```,80`0`E````%A$!`!P````\$0$`"P```%D1`0`?````
M91$!`!T```"%$0$`)0```*,1`0`@````R1$!`"0```#J$0$`(`````\2`0`+
M````,!(!``<````\$@$`#0```$02`0`,````4A(!`!<```!?$@$`!@```'<2
M`0`Y````?A(!``P```"X$@$`!P```,42`0`)````S1(!`!,```#7$@$`"0``
M`.L2`0`$````]1(!`!````#Z$@$`"`````L3`0`(````%!,!``0````=$P$`
M"P```"(3`0`,````+A,!`!(````[$P$`$0```$X3`0`,````8!,!`!H```!M
M$P$`#P```(@3`0`'````F!,!``T```"@$P$`%````*X3`0`.````PQ,!``P`
M``#2$P$`&P```-\3`0`L````^Q,!`!,````H%`$`'````#P4`0`H````610!
M``8```""%`$`!P```(D4`0`3````D10!``4```"E%`$`!````*L4`0`7````
ML!0!``H```#(%`$`#````-,4`0`)````X!0!``8```#J%`$`"0```/$4`0`(
M````^Q0!``D````$%0$`"@````X5`0`1````&14!``8````K%0$`#@```#(5
M`0`.````014!``T```!0%0$`"P```%X5`0`=````:A4!``L```"(%0$``@``
M`)05`0`<````EQ4!``<```"T%0$`!@```+P5`0!D````PQ4!``D````H%@$`
M!P```#(6`0`F````.A8!`#@```!A%@$`&@```)H6`0`J````M18!`#L```#@
M%@$`*````!P7`0`T````11<!`!D```!Z%P$`%0```)07`0`%````JA<!``<`
M``"P%P$`"````+@7`0`'````P1<!``4```#)%P$`!P```,\7`0`.````UQ<!
M``D```#F%P$`!@```/`7`0`(````]Q<!``L`````&`$`!P````P8`0`(````
M%!@!``<````=&`$`%@```"48`0`)````/!@!``8```!&&`$`"P```$T8`0`0
M````61@!`!P```!J&`$`%````(<8`0`'````G!@!`!$```"D&`$`"````+88
M`0`.````OQ@!``@```#.&`$`!0```-<8`0`0````W1@!`!````#N&`$`!@``
M`/\8`0`9````!AD!``H````@&0$`'````"L9`0`'````2!D!``4```!0&0$`
M$````%89`0`4````9QD!``L```!\&0$`#0```(@9`0`H````EAD!`!@```"_
M&0$`%P```-@9`0`$````\!D!``D```#U&0$`"@```/\9`0`'````"AH!``(`
M```2&@$`#@```!4:`0`(````)!H!`",````M&@$`'P```%$:`0`X````<1H!
M`"8```"J&@$`,0```-$:`0`G`````QL!`&0````K&P$`%````)`;`0!5````
MI1L!`#@```#[&P$`2@```#0<`0!;````?QP!`"@```#;'`$`.`````0=`0`H
M````/1T!`"P```!F'0$`)@```),=`0`;````NAT!`#X```#6'0$`J0$``!4>
M`0`C````OQ\!`!<```#C'P$`2````/L?`0"%````1"`!`#````#*(`$`)0``
M`/L@`0!!````(2$!`%L```!C(0$`20```+\A`0`Q````"2(!`!T````[(@$`
M&````%DB`0`K````<B(!`"$```">(@$`'P```,`B`0`K````X"(!`"8````,
M(P$`)P```#,C`0`Z````6R,!`!T```"6(P$`$0```+0C`0`S````QB,!`"4`
M``#Z(P$`)P```"`D`0`@````2"0!`!\```!I)`$`,````(DD`0!I````NB0!
M`#$````D)0$`00```%8E`0`S````F"4!`"4```#,)0$`/0```/(E`0!E````
M,"8!`$T```"6)@$`+P```.0F`0`N````%"<!`#````!#)P$`5````'0G`0!:
M````R2<!`$@````D*`$`2@```&TH`0`R````N"@!`"\```#K*`$`+````!LI
M`0`M````2"D!`'$```!V*0$`9@```.@I`0!O````3RH!`+,```"_*@$`%P``
M`',K`0`E````BRL!`#(```"Q*P$`*0```.0K`0`^````#BP!`"(```!-+`$`
M4@```'`L`0`E````PRP!``L```#I+`$`L0```/4L`0!%````IRT!`"$```#M
M+0$`,`````\N`0`E````0"X!`!P```!F+@$`,0```(,N`0`'````M2X!``<`
M``"]+@$`!````,4N`0`-````RBX!``L```#8+@$`#@```.0N`0`+````\RX!
M``4```#_+@$`$`````4O`0`"````%B\!`%D````9+P$`!0```',O`0`2````
M>2\!``0```",+P$`!P```)$O`0`(````F2\!``4```"B+P$``P```*@O`0`0
M````K"\!``P```"]+P$`$P```,HO`0`-````WB\!``(```#L+P$`!P```.\O
M`0`&````]R\!`!0```#^+P$`#````!,P`0`8````(#`!``8````Y,`$`$@``
M`$`P`0`,````4S`!``,```!@,`$`*@```&0P`0`$````CS`!``8```"4,`$`
M!P```)LP`0`?````HS`!`#4```##,`$`+@```/DP`0`O````*#$!`!<```!8
M,0$`(@```'`Q`0`E````DS$!`"````"Y,0$`&P```-HQ`0`8````]C$!`"0`
M```/,@$`'P```#0R`0`:````5#(!`"$```!O,@$`(````)$R`0`:````LC(!
M`#(```#-,@$`&@`````S`0`O````&S,!`"L```!+,P$`'P```'<S`0`C````
MES,!`!\```"[,P$`&@```-LS`0`A````]C,!`"4````8-`$`)@```#XT`0`E
M````930!`"0```"+-`$`&````+`T`0`=````R30!`"0```#G-`$`&`````PU
M`0`B````)34!`"P```!(-0$`+P```'4U`0`5````I34!`"4```"[-0$`/```
M`.$U`0`?````'C8!`",````^-@$`'P```&(V`0`@````@C8!`!H```"C-@$`
M&````+XV`0`F````US8!`!X```#^-@$`*0```!TW`0`>````1S<!`#$```!F
M-P$`"0```)@W`0`,````HC<!`!<```"O-P$`+P```,<W`0`D````]S<!``<`
M```<.`$`#P```"0X`0`4````-#@!``X```!).`$`#0```%@X`0`D````9C@!
M``4```"+.`$`!P```)$X`0`B````F3@!`"4```"\.`$`&@```.(X`0`=````
M_3@!`!H````;.0$`!P```#8Y`0#'````/CD!``L````&.@$`%0```!(Z`0`&
M````*#H!``D````O.@$`"P```#DZ`0`-````13H!`!<```!3.@$`!@```&LZ
M`0`S````<CH!`!,```"F.@$`$P```+HZ`0`'````SCH!``\```#6.@$`!P``
M`.8Z`0`R````[CH!``0````A.P$`(0```"8[`0`3````2#L!``P```!<.P$`
M$0```&D[`0`R````>SL!`!8```"N.P$`"````,4[`0`=````SCL!``D```#L
M.P$`"@```/8[`0`4`````3P!``H````6/`$`'0```"$\`0`(````/SP!`!\`
M``!(/`$`"````&@\`0`:````<3P!`"<```",/`$`!@```+0\`0`5````NSP!
M``<```#1/`$`"````-D\`0`)````XCP!`#\```#L/`$`!P```"P]`0`/````
M-#T!``X```!$/0$`$````%,]`0`)````9#T!``D```!N/0$`"````'@]`0`3
M````@3T!``<```"5/0$`&0```)T]`0`*````MST!`!<```#"/0$`%````-H]
M`0`*````[ST!``P```#Z/0$`%P````<^`0`$````'SX!`"H````D/@$`#```
M`$\^`0`1````7#X!``<```!N/@$``@```'8^`0`0````>3X!`!@```"*/@$`
M`P```*,^`0`(````ISX!``8```"P/@$`!P```+<^`0`-````OSX!``L```#-
M/@$`%````-D^`0`5````[CX!``X````$/P$`+P```!,_`0`@````0S\!`!P`
M``!D/P$`%0```($_`0`,````ES\!`#$```"D/P$`!0```-8_`0`2````W#\!
M`#\```#O/P$`$@```"]``0`*````0D`!``8```!-0`$`!````%1``0`$````
M64`!``H```!>0`$`$P```&E``0`%````?4`!``8```"#0`$`!@```(I``0`(
M````D4`!``0```":0`$`#````)]``0`*````K$`!`#D```"W0`$`+@```/%`
M`0`I````($$!``4```!*00$`&````%!!`0`9````:4$!`!\```"#00$`'0``
M`*-!`0`1````P4$!``(```#300$`!````-9!`0`*````VT$!``8```#F00$`
M!0```.U!`0`#````\T$!``P```#W00$`10````1"`0`R````2D(!`!H```!]
M0@$`-````)A"`0`H````S4(!`%,```#V0@$`&0```$I#`0!R````9$,!`"``
M``#70P$`-0```/A#`0`A````+D0!`$4```!01`$`,````)9$`0`H````QT0!
M`"D```#P1`$`)@```!I%`0`E````044!`"@```!G10$`*````)!%`0`B````
MN44!`"L```#<10$`,`````A&`0`2````.48!`!,```!,1@$`$````&!&`0!Y
M````<48!``D```#K1@$`H0```/5&`0!S````ET<!`'P````+2`$`*P```(A(
M`0!4````M$@!`!<````)20$`)P```"%)`0`6````24D!``\```!@20$`%P``
M`'!)`0`?````B$D!`$````"H20$`'P```.E)`0`<````"4H!`%$````F2@$`
M&@```'A*`0`4````DTH!``H```"H2@$`!0```+-*`0`&````N4H!``@```#`
M2@$`$@```,E*`0`0````W$H!`!,```#M2@$`'0````%+`0`/````'TL!``\`
M```O2P$`!````#]+`0`+````1$L!``<```!02P$`!0```%A+`0`4````7DL!
M``<```!S2P$`"````'M+`0`/````A$L!``@```"42P$`#````)U+`0`/````
MJDL!``8```"Z2P$`%````,%+`0`&````UDL!``P```#=2P$`$0```.I+`0`(
M````_$L!``0````%3`$`&0````I,`0`1````)$P!``H````V3`$`&````$%,
M`0`3````6DP!`!P```!N3`$`$0```(M,`0`$````G4P!``\```"B3`$`!P``
M`+),`0`$````NDP!`!D```"_3`$`!P```-E,`0`"````X4P!`!$```#D3`$`
M"0```/9,`0`2`````$T!`!<````330$`!@```"M-`0`G````,DT!``0```!:
M30$`#P```%]-`0`3````;TT!``<```"#30$`!P```(M-`0`1````DTT!``8`
M``"E30$`&````*Q-`0`&````Q4T!`!,```#,30$`$````.!-`0`2````\4T!
M``8````$3@$`#`````M.`0`)````&$X!`!$````B3@$`(@```#1.`0`'````
M5TX!``L```!?3@$`!0```&M.`0`"````<4X!`&,!``!T3@$`%````-A/`0`3
M````[4\!``\````!4`$`!0```!%0`0`)````%U`!``D````A4`$``P```"M0
M`0`4````+U`!`!P```!$4`$`+````&%0`0`K````CE`!`"$```"Z4`$`+0``
M`-Q0`0`<````"E$!`#,````G40$`"P```%M1`0`L````9U$!`!0```"440$`
M$P```*E1`0`+````O5$!`"@```#)40$`#````/)1`0`5````_U$!`!L````5
M4@$`(0```#%2`0`*````4U(!`(,```!>4@$`%@```.)2`0`'````^5(!`!$`
M```!4P$`%0```!-3`0`.````*5,!``H````X4P$`#P```$-3`0`1````4U,!
M`)H```!E4P$`#0````!4`0`5````#E0!`!D````D5`$`#P```#Y4`0`0````
M3E0!`!````!?5`$`!@```'!4`0`&````=U0!`#P```!^5`$`'@```+M4`0`Y
M````VE0!`$P````450$`:P```&%5`0!G````S54!`'$````U5@$`;0```*=6
M`0`\````%5<!`!(```!25P$`$P```&57`0`,````>5<!`!$```"&5P$`$@``
M`)A7`0`%````JU<!`"L```"Q5P$`$@```-U7`0`*````\%<!``D```#[5P$`
M"@````58`0`S````$%@!`"T```!$6`$`&0```')8`0`&````C%@!`"$```"3
M6`$`"0```+58`0`'````OU@!`!4```#'6`$`(@```-U8`0`1`````%D!`!8`
M```260$`&@```"E9`0`=````1%D!`"H```!B60$`&P```(U9`0`4````J5D!
M`!(```"^60$`$0```-%9`0`N````XUD!`!P````26@$`'0```"]:`0`9````
M35H!`&4```!G6@$`0@```,U:`0`P````$%L!``,```!!6P$`"@```$5;`0`\
M````4%L!``X```"-6P$`"@```)Q;`0`+````IUL!``<```"S6P$`!P```+M;
M`0`%````PUL!``H```#)6P$`"0```-1;`0`+````WEL!`!T```#J6P$`#@``
M``A<`0`2````%UP!`"`````J7`$`&P```$M<`0`S````9UP!``L```";7`$`
M'P```*=<`0`2````QUP!`!X```#:7`$`#P```/E<`0`3````"5T!`!(````=
M70$`#P```#!=`0`B````0%T!`!@```!C70$`!P```'Q=`0`&````A%T!``@`
M``"+70$`*````)1=`0`&````O5T!``H```#$70$`$@```,]=`0`*````XET!
M`!0```#M70$`$P````)>`0`M````%EX!``H```!$7@$`$0```$]>`0`'````
M85X!`!,```!I7@$`'````'U>`0`:````FEX!`#T```"U7@$`.@```/->`0`)
M````+E\!``P````X7P$`$@```$5?`0`(````6%\!``4```!A7P$`!P```&=?
M`0`,````;U\!`!H```!\7P$`20```)=?`0`7````X5\!`"D```#Y7P$`+0``
M`"-@`0`T````46`!`#D```"&8`$`#0```,!@`0`)````SF`!``H```#88`$`
M"````.-@`0`T````[&`!`$@````A80$`,P```&IA`0!>````GF$!`#(```#]
M80$`,@```#!B`0!%````8V(!`#X```"I8@$`,@```.AB`0!&````&V,!`"X`
M``!B8P$`.P```)%C`0!"````S6,!`#(````09`$`.````$-D`0`Z````?&0!
M`"4```"W9`$`*````-UD`0`Y````!F4!`#H```!`90$`.0```'ME`0`;````
MM64!``P```#190$`(````-YE`0`&````_V4!``L````&9@$`'@```!)F`0`F
M````,68!``<```!89@$`!P```&!F`0`3````:&8!``D```!\9@$`"````(9F
M`0`U````CV8!``L```#%9@$`$````-%F`0`'````XF8!``8```#J9@$`!0``
M`/%F`0`'````]V8!``8```#_9@$`"P````9G`0`M````$F<!`!8```!`9P$`
M$@```%=G`0`(````:F<!``<```!S9P$`$````'MG`0`%````C&<!``\```"2
M9P$`!P```*)G`0`3````JF<!``D```"^9P$`"````,AG`0`$````T6<!``T`
M``#69P$`"````.1G`0`:````[6<!`!$````(:`$`"````!IH`0`*````(V@!
M``P````N:`$`!P```#MH`0`5````0V@!``,```!9:`$`+````%UH`0`3````
MBF@!`"D```">:`$`!@```,AH`0`'````SV@!``D```#7:`$`!P```.%H`0!`
M````Z6@!`!X````J:0$`.P```$EI`0`J````A6D!`"0```"P:0$`!@```-5I
M`0`%````W&D!`!H```#B:0$`(0```/UI`0`_````'VH!`#L```!?:@$`(P``
M`)MJ`0`B````OVH!`%<```#B:@$`+````#IK`0`2````9VL!``H```!Z:P$`
M"P```(5K`0`7````D6L!``\```"I:P$`#0```+EK`0`2````QVL!`!(```#:
M:P$`$@```.UK`0`3`````&P!``T````4;`$`$P```")L`0`%````-FP!`!D`
M```\;`$`&@```%9L`0`7````<6P!`!D```");`$`)````*-L`0`$````R&P!
M``L```#-;`$`$P```-EL`0!$````[6P!`%P````R;0$`"````(]M`0`2````
MF&T!``4```"K;0$`!````+%M`0`>````MFT!`!D```#5;0$`'0```.]M`0`1
M````#6X!`!X````?;@$`+0```#YN`0`V````;&X!`!(```"C;@$`*````+9N
M`0`&````WVX!`!D```#F;@$`%`````!O`0`6````%6\!`!4````L;P$`'P``
M`$)O`0`0````8F\!`"0```!S;P$`*````)AO`0`1````P6\!``D```#3;P$`
M$0```-UO`0`*````[V\!``\```#Z;P$`'0````IP`0`1````*'`!``@````Z
M<`$`!````$-P`0`,````2'`!``T```!5<`$`"0```&-P`0`1````;7`!``8`
M``!_<`$`!P```(9P`0`0````CG`!``H```"?<`$`#@```*IP`0`/````N7`!
M``,```#)<`$`#````,UP`0`1````VG`!`!$```#L<`$`'0```/YP`0!8````
M''$!`"````!U<0$`$0```)9Q`0`5````J'$!``4```"^<0$`'P```,1Q`0`7
M````Y'$!`!@```#\<0$`-@```!5R`0!#````3'(!`"P```"0<@$`"0```+UR
M`0`T````QW(!`!X```#\<@$`#0```!MS`0`)````*7,!``T````S<P$`!```
M`$%S`0`+````1G,!`!H```!2<P$`&````&US`0`4````AG,!``H```";<P$`
M$````*9S`0`L````MW,!`"\```#D<P$`/@```!1T`0`Q````4W0!`"P```"%
M=`$`'@```+)T`0!$````T70!`"P````6=0$`/@```$-U`0`L````@G4!`#T`
M``"O=0$`/P```.UU`0`B````+78!`"@```!0=@$`-P```'EV`0`Q````L78!
M`"T```#C=@$`+P```!%W`0`\````07<!`"(```!^=P$`)P```*%W`0`_````
MR7<!`"L````)>`$`'````#5X`0`I````4G@!`"8```!\>`$`'@```*-X`0`1
M````PG@!`,0```#4>`$`.@```)EY`0`I````U'D!`"L```#^>0$`+0```"IZ
M`0`O````6'H!`#4```"(>@$`(P```+YZ`0`H````XGH!`"X````+>P$`,0``
M`#I[`0`Y````;'L!`#0```"F>P$`D````-M[`0`T````;'P!`!@```"A?`$`
M+0```+I\`0`K````Z'P!`"\````4?0$`1````$1]`0!*````B7T!``\```#4
M?0$`!@```.1]`0`*````ZWT!``H```#V?0$`$`````%^`0`.````$GX!`!0`
M```A?@$`*````#9^`0`/````7WX!``P```!O?@$`!````'Q^`0`1````@7X!
M`"(```"3?@$`"@```+9^`0`/````P7X!`!8```#1?@$`$@```.A^`0`>````
M^WX!`!`````:?P$`2P```"M_`0`'````=W\!`!@```!_?P$`!@```)A_`0`/
M````GW\!`!4```"O?P$`%0```,5_`0`0````VW\!``(```#L?P$`70```.]_
M`0`'````38`!`!$```!5@`$`&0```&>``0`%````@8`!`!$```"'@`$`$@``
M`)F``0`&````K(`!``X```"S@`$`"````,*``0`&````RX`!`!````#2@`$`
M#P```..``0`?````\X`!`"$````3@0$`%0```#6!`0`*````2X$!``8```!6
M@0$`#P```%V!`0`1````;8$!`!<```!_@0$`%0```)>!`0`/````K8$!``\`
M``"]@0$`$0```,V!`0`H````WX$!`!$````(@@$`'0```!J"`0`^````.((!
M``T```!W@@$`(````(6"`0`3````IH(!`!H```"Z@@$`%P```-6"`0`K````
M[8(!`!(````9@P$`!0```"R#`0`;````,H,!``8```!.@P$`+P```%6#`0!!
M````A8,!``H```#'@P$`"@```-*#`0`5````W8,!``P```#S@P$`$@````"$
M`0`2````$X0!``8````FA`$`,@```"V$`0`9````8(0!`"4```!ZA`$`)@``
M`*"$`0`6````QX0!`"8```#>A`$`"`````6%`0`+````#H4!`"P````:A0$`
M0````$>%`0`(````B(4!`!4```"1A0$`)P```*>%`0`(````SX4!``\```#8
MA0$`/0```.B%`0`/````)H8!``P````VA@$`!0```$.&`0!1````288!``0`
M``";A@$`!P```*"&`0`)````J(8!``\```"RA@$`$0```,*&`0`5````U(8!
M`!@```#JA@$`'@````.'`0`=````(H<!`"````!`AP$`'@```&&'`0`'````
M@(<!``@```"(AP$`"````)&'`0`'````FH<!`!8```"BAP$`!0```+F'`0`)
M````OX<!`"$```#)AP$`%P```.N'`0`0`````X@!``X````4B`$`#````".(
M`0`,````,(@!`!D````]B`$`0P```%>(`0`V````FX@!``P```#2B`$`%@``
M`-^(`0!Z````]H@!`!H```!QB0$`&@```(R)`0`1````IXD!``<```"YB0$`
M!````,&)`0`G````QHD!`#8```#NB0$`/0```"6*`0`B````8XH!`"P```"&
MB@$`&````+.*`0`G````S(H!``H```#TB@$`!P```/^*`0`,````!XL!``8`
M```4BP$`#0```!N+`0`,````*8L!`!(````VBP$`#````$F+`0`7````5HL!
M``L```!NBP$`"@```'J+`0`.````A8L!``L```"4BP$`#````*"+`0`?````
MK8L!`!L```#-BP$`30```.F+`0`7````-XP!``8```!/C`$`!````%:,`0`G
M````6XP!`#$```"#C`$`'@```+6,`0`=````U(P!`"L```#RC`$`*@```!Z-
M`0`L````28T!`"T```!VC0$`'````*2-`0`&````P8T!`!P```#(C0$`#@``
M`.6-`0`7````](T!``,````,C@$``P```!".`0`'````%(X!`!`````<C@$`
M$@```"V.`0`-````0(X!`!8```!.C@$`"P```&6.`0`F````<8X!``8```"8
MC@$`!````)^.`0`2````I(X!`!(```"WC@$`#@```,J.`0`'````V8X!``X`
M``#AC@$`#P```/".`0`A`````(\!``8````BCP$`"@```"F/`0`(````-(\!
M``L````]CP$`%@```$F/`0`1````8(\!``,```!RCP$`%````':/`0`(````
MBX\!``8```"4CP$`.0```)N/`0`8````U8\!`(P```#NCP$`&0```'N0`0`,
M````E9`!``8```"BD`$`#@```*F0`0`(````N)`!``H```#!D`$`!P```,R0
M`0`,````U)`!``(```#AD`$`"````.20`0`-````[9`!``T```#[D`$`#@``
M``F1`0`1````&)$!`!8````JD0$`!@```$&1`0`'````2)$!`!````!0D0$`
M"````&&1`0`*````:I$!``4```!UD0$`(````'N1`0`+````G)$!``8```"H
MD0$`)````*^1`0`1````U)$!``8```#FD0$`"P```.V1`0`%````^9$!``D`
M``#_D0$`"@````F2`0`4````%)(!``4````ID@$`!0```"^2`0`-````-9(!
M``X```!#D@$`#````%*2`0`+````7Y(!`!(```!KD@$`"````'Z2`0`'````
MAY(!`!8```"/D@$`'````*:2`0!#````PY(!`"L````'DP$`.````#.3`0`)
M````;),!``H```!VDP$`!````(&3`0`)````AI,!``@```"0DP$`%````)F3
M`0`+````KI,!``8```"ZDP$`#0```,&3`0`&````SY,!`$````#6DP$`10``
M`!>4`0!"````790!`"L```"@E`$`!0```,R4`0`/````TI0!``,```#BE`$`
M!@```.:4`0`&````[90!`!L```#TE`$`#````!"5`0`4````'94!``@````R
ME0$`"````#N5`0`C````1)4!``@```!HE0$`!P```'&5`0`0````>94!``0`
M``"*E0$`"````(^5`0`,````F)4!``@```"EE0$`"P```*Z5`0`4````NI4!
M``\```#/E0$`"````-^5`0`(````Z)4!``4```#QE0$`-````/>5`0`W````
M+)8!`#<```!DE@$`+````)R6`0!%````R98!`$,````/EP$`+P```%.7`0!8
M````@Y<!`#0```#<EP$`2@```!&8`0`M````7)@!`!````"*F`$`$````)N8
M`0`+````K)@!`",```"XF`$`)````-R8`0`7`````9D!`"`````9F0$`#```
M`#J9`0`.````1YD!``H```!6F0$`#````&&9`0`N````;ID!`"H```"=F0$`
M/P```,B9`0`&````")H!`!X````/F@$`,````"Z:`0`<````7YH!`!8```!\
MF@$`!@```).:`0`+````FIH!``H```"FF@$`$````+&:`0`E````PIH!`$8`
M``#HF@$`D0```"^;`0!T````P9L!``\````VG`$`#````$:<`0`-````4YP!
M`!L```!AG`$`%P```'V<`0`.````E9P!``4```"DG`$`%0```*J<`0`5````
MP)P!`!,```#6G`$`%@```.J<`0`7`````9T!`#0````9G0$`C0```$Z=`0`0
M````W)T!``4```#MG0$`$@```/.=`0`)````!IX!``H````0G@$`"@```!N>
M`0`H````)IX!`!<```!/G@$`$````&>>`0`5````>)X!`!````".G@$`%@``
M`)^>`0`7````MIX!`!8```#.G@$`$P```.6>`0`3````^9X!`!P````-GP$`
M&P```"J?`0`@````1I\!`#\```!GGP$`&0```*>?`0`8````P9\!`!<```#:
MGP$`%@```/*?`0`2````":`!`!P````<H`$`&P```#F@`0`3````5:`!`!,`
M``!IH`$`,````'V@`0`;````KJ`!`!P```#*H`$`0@```.>@`0`?````*J$!
M``4```!*H0$`%````%"A`0`M````9:$!`",```"3H0$`(0```+>A`0`F````
MV:$!`"4`````H@$`'0```":B`0`C````1*(!`",```!HH@$`'````(RB`0`B
M````J:(!`$$```#,H@$`(@````ZC`0`G````,:,!`"<```!9HP$`(````(&C
M`0`@````HJ,!`",```##HP$`*0```.>C`0`B````$:0!`",````TI`$`#0``
M`%BD`0`7````9J0!`!@```!^I`$`!````)>D`0`(````G*0!``H```"EI`$`
M%````+"D`0`&````Q:0!`!4```#,I`$`!````.*D`0`+````YZ0!``<```#S
MI`$`!@```/ND`0`%`````J4!`!,````(I0$`!@```!RE`0`(````(Z4!``8`
M```LI0$`!@```#.E`0`*````.J4!`!````!%I0$`&@```%:E`0`0````<:4!
M`!$```""I0$`"@```)2E`0`8````GZ4!``4```"XI0$`.0```+ZE`0`6````
M^*4!`!$````/I@$`$0```"&F`0`.````,Z8!``L```!"I@$`$@```$ZF`0`O
M````8:8!``@```"1I@$`"````)JF`0`D````HZ8!`!(```#(I@$`#P```-NF
M`0`&````ZZ8!``P```#RI@$`"0```/^F`0`%````":<!`"0````/IP$`"@``
M`#2G`0`6````/Z<!``T```!6IP$`$P```&2G`0`8````>*<!`",```"1IP$`
M)P```+6G`0`*````W:<!``,```#HIP$`"@```.RG`0`B````]Z<!``<````:
MJ`$``P```"*H`0`1````)J@!`!(````XJ`$`!P```$NH`0`%````4Z@!``<`
M``!9J`$`*@```&&H`0`-````C*@!`!(```":J`$`"@```*VH`0`3````N*@!
M`!<```#,J`$`#````.2H`0`.````\:@!``X`````J0$`#@````^I`0`$````
M'JD!`!$````CJ0$`0P```#6I`0`&````>:D!``4```"`J0$`)P```(:I`0`6
M````KJD!`#0```#%J0$`%0```/JI`0`.````$*H!`!,````?J@$`#P```#.J
M`0`0````0ZH!``\```!4J@$`'@```&2J`0`?````@ZH!`#4```"CJ@$`*P``
M`-FJ`0`F````!:L!``@````LJP$`"````#6K`0`+````/JL!``L```!*JP$`
M$0```%:K`0`$````:*L!``T```!MJP$`*@```'NK`0`-````IJL!``T```"T
MJP$`)@```,*K`0!1````Z:L!`!T````[K`$`#0```%FL`0`(````9ZP!``@`
M``!PK`$`#@```'FL`0`.````B*P!`!4```"7K`$`"0```*VL`0`"````MZP!
M``T```"ZK`$`(P```,BL`0`&````[*P!``4```#SK`$`"0```/FL`0`+````
M`ZT!``D````/K0$`"0```!FM`0`4````(ZT!``X````XK0$`!@```$>M`0`(
M````3JT!``\```!7K0$`!````&>M`0`%````;*T!`&L```!RK0$`#````-ZM
M`0`/````ZZT!`"````#[K0$`!P```!RN`0`%````)*X!`"H````JK@$`,0``
M`%6N`0`1````AZX!``H```"9K@$`&0```*2N`0`*````OJX!``D```#)K@$`
M*@```-.N`0`>````_JX!`"D````=KP$`*````$>O`0`K````<*\!``\```"<
MKP$`!0```*RO`0`'````LJ\!``T```"ZKP$`!0```,BO`0`3````SJ\!`!8`
M``#BKP$`!@```/FO`0!9`````+`!`!X```!:L`$`$````'FP`0`6````BK`!
M`"0```"AL`$`9@```,:P`0`8````+;$!``<```!&L0$`'P```$ZQ`0`P````
M;K$!``@```"?L0$`!@```*BQ`0`>````K[$!``4```#.L0$`"@```-2Q`0`N
M````W[$!`"T````.L@$`.P```#RR`0`3````>+(!``8```",L@$`)````).R
M`0!6````N+(!`!\````/LP$`'````"^S`0`Y````3+,!``(```"&LP$`&0``
M`(FS`0`'````H[,!`!(```"KLP$`$0```+ZS`0`'````T+,!`!0```#8LP$`
M!@```.VS`0`(````]+,!``L```#]LP$`!P````FT`0`*````$;0!``L````<
MM`$`+````"BT`0`'````5;0!`!````!=M`$`$````&ZT`0`/````?[0!``D`
M``"/M`$`#````)FT`0`-````IK0!``H```"TM`$`"0```+^T`0`*````R;0!
M``@```#4M`$`&P```-VT`0`>````^;0!`!0````8M0$`&@```"VU`0`6````
M2+4!`!8```!?M0$`(````':U`0`'````E[4!`!8```"?M0$``P```+:U`0`'
M````NK4!``4```#"M0$`!0```,BU`0`)````SK4!`!````#8M0$`$@```.FU
M`0`S````_+4!`"X````PM@$`(@```%^V`0`D````@K8!`!<```"GM@$`'P``
M`+^V`0`9````W[8!``<```#YM@$`!`````&W`0`,````!K<!``P````3MP$`
M$0```""W`0`&````,K<!`!X````YMP$`"0```%BW`0`)````8K<!`"L```!L
MMP$`)0```)BW`0`/````OK<!``4```#.MP$`#````-2W`0`)````X;<!`!$`
M``#KMP$`$````/VW`0`*````#K@!``D````9N`$`!0```".X`0`'````*;@!
M``<````QN`$`!````#FX`0`#````/K@!`%D```!"N`$`+0```)RX`0!$````
MRK@!`!L````/N0$`/0```"NY`0`/````:;D!`$````!YN0$`*0```+JY`0`>
M````Y+D!`!X````#N@$`(P```"*Z`0`V````1KH!``T```!]N@$`,````(NZ
M`0`9````O+H!`!4```#6N@$`%0```.RZ`0`/`````KL!`!0````2NP$`%0``
M`">[`0`A````/;L!`#T```!?NP$`/@```)V[`0!!````W+L!`#X````>O`$`
M/P```%V\`0`]````G;P!`&T```#;O`$`'@```$F]`0`6````:+T!`!H```!_
MO0$`)0```)J]`0`/````P+T!`!````#0O0$`.P```.&]`0`K````';X!`"T`
M``!)O@$`"@```'>^`0`I````@KX!`"L```"LO@$`!0```-B^`0`F````WKX!
M`!8````%OP$`#@```!R_`0`.````*[\!`!<````ZOP$`"````%*_`0`*````
M6[\!``P```!FOP$`#@```'._`0`O````@K\!``\```"ROP$`#P```,*_`0`,
M````TK\!`"8```#?OP$`"`````;``0`$````#\`!`!`````4P`$`#@```"7`
M`0`+````-,`!`#4```!`P`$``@```';``0`(````><`!`!<```""P`$`#```
M`)K``0`'````I\`!``8```"OP`$`$0```+;``0`K````R,`!``T```#TP`$`
M'`````+!`0`$````'\$!`#<````DP0$`(P```%S!`0`>````@,$!`'<```"?
MP0$`%P```!?"`0!(````+\(!`"<```!XP@$`$@```*#"`0`&````L\(!``X`
M``"ZP@$`%````,G"`0`)````WL(!`!$```#HP@$`#@```/K"`0`>````"<,!
M`!4````HPP$`!0```#[#`0`0````1,,!`!H```!5PP$`,@```'##`0`5````
MH\,!`!4```"YPP$`&````,_#`0`3````Z,,!`!\```#\PP$`!P```!S$`0`7
M````),0!``L````\Q`$`%````$C$`0`4````7<0!`!8```!RQ`$`$````(G$
M`0`6````FL0!`!@```"QQ`$`"P```,K$`0`)````UL0!``4```#@Q`$`'0``
M`.;$`0`&````!,4!``\````+Q0$`"````!O%`0`2````),4!``8````WQ0$`
M)````#[%`0`4````8\4!`#,```!XQ0$`%0```*S%`0`'````PL4!``@```#*
MQ0$`'@```-/%`0`+````\L4!`!L```#^Q0$`!P```!K&`0`C````(L8!``<`
M``!&Q@$`"````$[&`0`D````5\8!`#L```!\Q@$`"P```+C&`0`E````Q,8!
M`"<```#JQ@$`#0```!+'`0`:````(,<!`!`````[QP$`!````$S'`0`.````
M4<<!``X```!@QP$`!P```&_'`0`.````=\<!``@```"&QP$`!0```(_'`0`)
M````E<<!`!T```"?QP$`)@```+W'`0`_````Y,<!`"@````DR`$`)0```$W(
M`0`?````<\@!`#L```"3R`$`'@```,_(`0`J````[L@!`#(````9R0$`70``
M`$S)`0`E````JLD!``T```#0R0$`"````-[)`0`*````Y\D!``H```#RR0$`
M$0```/W)`0`6````#\H!`$<````FR@$`)0```&[*`0`:````E,H!`#@```"O
MR@$`0````.C*`0`)````*<L!`"8````SRP$`"P```%K+`0`4````9LL!`"<`
M``![RP$`#````*/+`0`9````L,L!``P```#*RP$`#@```-?+`0`.````YLL!
M``\```#URP$`$`````7,`0`/````%LP!`!L````FS`$`&@```$+,`0`U````
M7<P!``L```"3S`$`&@```)_,`0`%````NLP!`!4```#`S`$`!0```-;,`0`>
M````W,P!`!<```#[S`$``P```!/-`0`,````%\T!`!`````DS0$`!0```#7-
M`0`.````.\T!``@```!*S0$`#P```%/-`0`%````8\T!``<```!IS0$`$```
M`''-`0!)````@LT!`%````#,S0$`)P```!W.`0`)````1<X!`#(```!/S@$`
M*P```(+.`0`1````KLX!``D```#`S@$`#````,K.`0`0````U\X!`#(```#H
MS@$`!@```!O/`0`-````(L\!``X````PSP$`%0```#_/`0`-````5<\!`%P`
M``!CSP$`"@```,#/`0`E````R\\!`!4```#QSP$`%@````?0`0`L````'M`!
M`"8```!+T`$`/@```'+0`0!!````L=`!`#L```#ST`$`#@```"_1`0`%````
M/M$!`!,```!$T0$`'````%C1`0`@````==$!``@```"6T0$`$P```)_1`0`;
M````L]$!``<```#/T0$`'P```-?1`0`7````]]$!`!`````/T@$`!````"#2
M`0`2````)=(!`!,````XT@$`%````$S2`0`&````8=(!``<```!HT@$`$P``
M`'#2`0`.````A-(!``\```"3T@$`$0```*/2`0`1````M=(!``8```#'T@$`
M!P```,[2`0`H````UM(!`"0```#_T@$`(````"33`0`(````1=,!``\```!.
MTP$`!@```%[3`0`8````9=,!`"D```!^TP$`*0```*C3`0`*````TM,!`!@`
M``#=TP$``P```/;3`0`(````^M,!``,````#U`$`$@````?4`0`4````&M0!
M``L````OU`$`&````#O4`0`C````5-0!`!<```!XU`$`!@```)#4`0`*````
ME]0!`!0```"BU`$`%P```+?4`0`,````S]0!``8```#<U`$`#````./4`0`*
M````\-0!`!4```#[U`$`>0```!'5`0`?````B]4!`"\```"KU0$`%````-O5
M`0`(````\-4!``<```#YU0$`%P````'6`0`7````&=8!`!@````QU@$`(@``
M`$K6`0`=````;=8!`!(```"+U@$`)0```)[6`0`1````Q-8!`"8```#6U@$`
M&````/W6`0`7````%M<!`(,````NUP$`*````++7`0`?````V]<!`#@```#[
MUP$`)P```#38`0`>````7-@!`"L```![V`$`(P```*?8`0`G````R]@!`!0`
M``#SV`$`"P````C9`0`(````%-D!``D````=V0$`"@```"?9`0`5````,MD!
M``L```!(V0$`.P```%39`0`I````D-D!`#<```"ZV0$`%@```/+9`0`&````
M"=H!`$4````0V@$`50```%;:`0`T````K-H!`)P```#AV@$`"P```'[;`0`W
M````BML!`"\```#"VP$`$@```/+;`0`(````!=P!`!,````.W`$`1````"+<
M`0`,````9]P!`%@```!TW`$`2````,W<`0`H````%MT!`!0````_W0$`(@``
M`%3=`0`B````=]T!`"P```":W0$`(@```,?=`0`K````ZMT!`!\````6W@$`
M%0```#;>`0`'````3-X!`!````!4W@$`%````&7>`0`-````>MX!``L```"(
MW@$`40```)3>`0`,````YMX!`!X```#SW@$`$0```!+?`0`?````)-\!``D`
M``!$WP$`!0```$[?`0`8````5-\!``D```!MWP$`"0```'??`0`'````@=\!
M``<```")WP$`"0```)'?`0`2````F]\!`!P```"NWP$`#P```,O?`0`?````
MV]\!`!````#[WP$`"`````S@`0`-````%>`!`"8````CX`$`"P```$K@`0`*
M````5N`!`!@```!AX`$`)@```'K@`0`,````H>`!`"(```"NX`$`*P```-'@
M`0`+````_>`!``@````)X0$`(0```!+A`0`-````-.$!`!D```!"X0$`&P``
M`%SA`0`4````>.$!`!8```"-X0$`$@```*3A`0`%````M^$!``D```"]X0$`
M"````,?A`0`)````T.$!``H```#:X0$`%````.7A`0`'````^N$!`!`````"
MX@$`"@```!/B`0`(````'N(!``P````GX@$`(0```#3B`0`,````5N(!``(`
M``!CX@$`(P```&;B`0`%````BN(!``H```"0X@$`>@```)OB`0`*````%N,!
M``@````AXP$`*@```"KC`0`Z````5>,!`!H```"0XP$`+@```*OC`0!=````
MVN,!`",````XY`$`,P```%SD`0`O````D.0!`"4```#`Y`$`!@```.;D`0`-
M````[>0!``@```#[Y`$`"0````3E`0`%````#N4!``@````4Y0$`$@```!WE
M`0`*````,.4!``D````[Y0$`"P```$7E`0`+````4>4!`!H```!=Y0$`"```
M`'CE`0`)````@>4!`!4```"+Y0$`"@```*'E`0`*````K.4!``4```"WY0$`
M+@```+WE`0`F````[.4!`!@````3Y@$`!P```"SF`0`2````-.8!``D```!'
MY@$`#P```%'F`0`S````8>8!``@```"5Y@$`&````)[F`0`8````M^8!``8`
M``#0Y@$`!@```-?F`0`-````WN8!`!P```#LY@$`!@````GG`0`)````$.<!
M``L````:YP$`'````";G`0`+````0^<!``T```!/YP$`*@```%WG`0`?````
MB.<!`!@```"HYP$`!@```,'G`0`+````R.<!`!````#4YP$`#0```.7G`0`#
M````\^<!``X```#WYP$`"`````;H`0`=````#^@!`"\````MZ`$`,````%WH
M`0`J````CN@!`"X```"YZ`$`+@```.CH`0".````%^D!`!8```"FZ0$`8P``
M`+WI`0`X````(>H!`&$```!:Z@$`:0```+SJ`0`A````)NL!`$T```!(ZP$`
M/````);K`0!'````T^L!`!X````;[`$`&````#KL`0`C````4^P!`/T!``!W
M[`$`'0```'7N`0`=````D^X!`$D```"Q[@$`H````/ON`0`T````G.\!`"D`
M``#1[P$`1P```/OO`0!:````0_`!`&0```">\`$`,@````/Q`0`@````-O$!
M`!X```!7\0$`-````';Q`0`<````J_$!`!\```#(\0$`)````.CQ`0`@````
M#?(!`"8````N\@$`+P```%7R`0`:````A?(!`!8```"@\@$`,0```+?R`0`J
M````Z?(!`"0````4\P$`/````#GS`0`:````=O,!`#(```"1\P$`<0```,3S
M`0`[````-O0!`#H```!R]`$`,@```*WT`0`I````X/0!`$<````*]0$`;0``
M`%+U`0!?````P/4!`#`````@]@$`,````%'V`0`S````@O8!`$X```"V]@$`
M9@````7W`0!-````;/<!`%,```"Z]P$`20````[X`0`G````6/@!`"<```"`
M^`$`)````*CX`0!X````S?@!`&T```!&^0$`=P```+3Y`0#.````+/H!`!P`
M``#[^@$`+````!C[`0`V````1?L!`"X```!\^P$`4````*O[`0`<````_/L!
M`$`````9_`$`/P```%K\`0`%````FOP!`,@```"@_`$`1@```&G]`0`B````
ML/T!`#X```#3_0$`)P```!+^`0`<````.OX!`"P```!7_@$`"0```(3^`0`6
M````COX!``,```"E_@$`%@```*G^`0`,````P/X!``T```#-_@$`"P```-O^
M`0`'````Y_X!``T```#O_@$`!P```/W^`0!U````!?\!``(```![_P$`%@``
M`'[_`0`$````E?\!``<```":_P$`!@```*+_`0`%````J?\!``4```"O_P$`
M%0```+7_`0`*````R_\!`!(```#6_P$`#P```.G_`0`"````^?\!``<```#\
M_P$`"P````0``@`2````$``"``T````C``(`&0```#$``@`&````2P`"`!D`
M``!2``(`"@```&P``@`#````=P`"`%L```![``(`!````-<``@`&````W``"
M``<```#C``(`)P```.L``@!,````$P$"`$8```!@`0(`1P```*<!`@`J````
M[P$"`"X````:`@(`,0```$D"`@`=````>P("`"(```"9`@(`'````+P"`@`R
M````V0("`"H````,`P(`)````#<#`@`F````7`,"`"<```"#`P(`+@```*L#
M`@`K````V@,"`!X````&!`(`*0```"4$`@`J````3P0"`!\```!Z!`(`(P``
M`)H$`@`A````O@0"`!D```#@!`(`(@```/H$`@`L````'04"`#(```!*!0(`
M,P```'T%`@`G````L04"`!T```#9!0(`)````/<%`@`I````'`8"`!T```!&
M!@(`)P```&0&`@`X````C`8"`#L```#%!@(`&0````$'`@`C````&P<"`#H`
M```_!P(`(@```'H'`@`F````G0<"`"0```#$!P(`)0```.D'`@`<````#P@"
M`"0````L"`(`,````%$(`@`>````@@@"`#$```"A"`(`(0```-,(`@`V````
M]0@"``D````L"0(`$````#8)`@`B````1PD"`$<```!J"0(`+````+()`@`,
M````WPD"``\```#L"0(`%P```/P)`@`2````%`H"`!`````G"@(`)P```#@*
M`@`&````8`H"``H```!G"@(`)0```'(*`@`H````F`H"`!L```#!"@(`*```
M`-T*`@`<````!@L"``\````C"P(`]````#,+`@`5````*`P"`!<````^#`(`
M"0```%8,`@`7````8`P"`"(```!X#`(`'0```)L,`@`>````N0P"``D```#8
M#`(`/@```.(,`@`/````(0T"`!8````Q#0(`!P```$@-`@`;````4`T"`!$`
M``!L#0(`3@```'X-`@`0````S0T"`"(```#>#0(`'`````$.`@`8````'@X"
M`",````W#@(`80```%L.`@`G````O0X"`!````#E#@(`)P```/8.`@`1````
M'@\"`!(````P#P(`&````$,/`@`+````7`\"`!T```!H#P(`*0```(8/`@`?
M````L`\"``L```#0#P(`,P```-P/`@`]````$!`"``<```!.$`(`$P```%80
M`@`'````:A`"``<```!R$`(`"0```'H0`@!)````A!`"``8```#.$`(`#0``
M`-40`@`0````XQ`"`!8```#T$`(`"P````L1`@`,````%Q$"``<````D$0(`
M$0```"P1`@`/````/A$"`!P```!.$0(`%P```&L1`@`4````@Q$"`!@```"8
M$0(`#````+$1`@`.````OA$"`"P```#-$0(`#@```/H1`@`V````"1("`!H`
M``!`$@(`$````%L2`@`.````;!("``,```![$@(`%````'\2`@`;````E!("
M``,```"P$@(`"0```+02`@`'````OA("``H```#&$@(`#@```-$2`@`.````
MX!("`!L```#O$@(`'`````L3`@`.````*!,"`#0````W$P(`&@```&P3`@`5
M````AQ,"`!D```"=$P(`#0```+<3`@`R````Q1,"``D```#X$P(`%P````(4
M`@!6````&A0"`!4```!Q%`(`&0```(<4`@`*````H10"``0```"L%`(`!```
M`+$4`@`6````MA0"`!4```#-%`(`!0```.,4`@`&````Z10"``H```#P%`(`
M#0```/L4`@`%````"14"``X````/%0(`$@```!X5`@`_````,14"`#(```!Q
M%0(`*0```*05`@`@````SA4"`!P```#O%0(`(P````P6`@`H````,!8"`"``
M``!9%@(`%0```'H6`@`"````D!8"``0```"3%@(`#0```)@6`@`&````IA8"
M``4```"M%@(`!````+,6`@`1````N!8"`'@```#*%@(`)````$,7`@`M````
M:!<"`"\```"6%P(`(P```,87`@!(````ZA<"`!D````S&`(`C@```$T8`@`B
M````W!@"`%0```#_&`(`(0```%09`@!7````=AD"`"X```#.&0(`*0```/T9
M`@!`````)QH"`#,```!H&@(`+P```)P:`@`_````S!H"`!T````,&P(`)0``
M`"H;`@`H````4!L"`$T```!Y&P(`$````,<;`@`;````V!L"`!0```#T&P(`
M=0````D<`@`*````?QP"`-8```"*'`(`A0```&$=`@!^````YQT"`#@```!F
M'@(`>@```)\>`@`<````&A\"`#<````W'P(`*@```&\?`@`2````FA\"`"4`
M``"M'P(`)````-,?`@!&````^!\"`"(````_(`(`'````&(@`@!9````?R`"
M`"\```#9(`(`)@````DA`@`+````,"$"``4````\(0(`!@```$(A`@`(````
M22$"`"(```!2(0(`#@```'4A`@`@````A"$"`"@```"E(0(`"P```,XA`@`/
M````VB$"``L```#J(0(`"0```/8A`@`*`````"("``D````+(@(`%@```!4B
M`@`-````+"("``X````Z(@(`%````$DB`@`'````7B("``X```!F(@(`$0``
M`'4B`@`,````AR("`!8```"4(@(`#0```*LB`@`*````N2("`!0```#$(@(`
M!@```-DB`@`'````X"("`"4```#H(@(`(@````XC`@`.````,2,"`!````!`
M(P(`$@```%$C`@`D````9","`!$```")(P(`"0```)LC`@`5````I2,"``<`
M``"[(P(`!````,,C`@`C````R","``L```#L(P(``@```/@C`@`5````^R,"
M``@````1)`(`$0```!HD`@`1````+"0"``0````^)`(`20```$,D`@`#````
MC20"`"\```"1)`(`+P```,$D`@`+````\20"``@```#])`(`'`````8E`@`%
M````(R4"`!T````I)0(`"0```$<E`@`D````424"`!H```!V)0(`(````)$E
M`@`+````LB4"``P```"^)0(`#````,LE`@`-````V"4"`"D```#F)0(`"@``
M`!`F`@`?````&R8"``4````[)@(``P```$$F`@`!````Q04``,("``#7!0``
MDP(``/H#``!D!@```````$H&``#:!0``(00``)\```!:`P``X@8```````"?
M`0``<04````````>`P```````$X!``!O!```]P4``&8!``#R`0``T0,```P&
M````````(@(``,L`````````6@4``'<%```K!@```````$@"``"T!```8`,`
M`-T```#<!`````````````"M!0```````-@&````````H@8``+(!``"@!0``
M0````/<!````````]00``,@```#H!0``90<```````"X`0``"08`````````
M``````````````"$!@``M@````````!?!```2P````````"L`0``@`$``-\&
M``#+`@``L0```"`%``!'````2@,``,P%``!D`@``LP0```T"``"W!```;`(`
M`.@!````````O08``%@"```U````A@4````````]`P``!0$``'P```!#!0``
M>@$``$(!```2`P``-@(``"@'```]`@``G08``'$```#'!0``Q`,````````*
M`0``J@```+L&````````P08``%4```!E`````````````````````````%0!
M``!Z!@``T`$``"X#```#`@````````````#1`@``%@$``+H&```(````````
M`.P$``"7!0``#P<````!`````````````"$```#F`P``1````/($````````
M`0$``'D$```Q`0``)@(``"0#```3`P``Q0$``(4#````````D04``"T!``!:
M!P``WP```'`!``#'`0``?@0``+@#````````H0$```P$``!S!0``Y`,`````
M````````I`(`````````````9@4``-H!```!!0````````P"``#I````[0,`
M``````#*!```*`$``,P"````````H`0``,H#``!1````3@0``*4````'`0``
M`````*\!``#.!@``NP,``+8#``"7`P``'@4``(P`````````!`4``(`%``!2
M````9@<``/\``````````````)0!``!#!@```````%T'````````7`,`````
M````````7`(```8"```-!@``LP4``)4%````````S0```&`'``"6!```?`0`
M`$P#`````````````'H%``!S!P```````$L$``"S`P``M0(`````````````
ML`,``-L!````````?P,``+X`````````]@4```````!B`0``#04```````#C
M!@`````````````.`@```````*H#``"Z`0``908``#(```#A`@```````-0"
M````````7@$``#(%``"J!0``AP(``#,'```A!0``\P0``(H```!Z````Q0(`
M`!X'```*!0``M0````````#A!@``.@(``-8"``!H!```N08``.D"``!#!```
M``````8%```X`````````&T$``!]````^P$``*\````9`P``J@8``.L"``#S
M`P```````-4&````````R0,`````````````>0,``!,%``#I!```.P``````
M``#_`@``"04``"(%````````M````*`#```\!P``@@8```````"O`@``````
M`-T"````````U@,``"4"```+!@```````$T#```E!0``B0,``.`#``!=````
MQ00``&X"``"F````90$``$T%```[`0``W@0``.,%``#K````&P<``,(&``"K
M!0``#P0``,X#````````00$``(D&``````````````8#``#G!@```````$H`
M````````]P,``,,$``"U!0```````,0!``!%!P``P`0```````!%`0``7```
M`/T!``!]`0````````8$`````````````/H&``!K`P```````$@%```4`0``
MC@$``+8$``"#!0``D@(```P#``#&!`````````````#3`0```````%`%``#V
M!```"`<``,X!``!E!```Y08``#L"``````````0``'8%``!@`@```````&D!
M```U`@``/P4``$4"``"%`@``60<``&P'``!J````+@4``"8'``!&!```D0(`
M```````E!```3@(``%8```#[!````````.P&``!P!0```````(T#```'!0``
MC@,```````!K!```#`<``*<&``#O`0``%P,````````^````D`4``.D%``#;
M!@```````%H&``"M!```@`8```````#J!0``>P0``.8`````````````````
M````````Y0```'8!``"L!```V`$``+$%```2!@``50<``$D!``#1!0``````
M`+H````>!````````!8&``#2````C@```.P#``"'`0``L`8``&T'````````
M`````"<!```4!@````````````#O````(0$`````````````<@(``'8$``!%
M!@``(P$``(`#``"$`@````````````"E!0``````````````````R`,``(X&
M````````W@```-8!```8!````````%\!```0!```.`,``!("```?`P``'`4`
M`&(````&!@``AP```.H#``"?!@````````````!8````VP0````````/````
M4P8`````````````008`````````````%P0``,D```#@!0``E`0``(4`````
M````!04```````!"!0``N`4```````!^!0```````,0$``"*`P``T00``#L%
M``""`````````-,```"%`0```P,````````>`@``S0,``/D%````````+`0`
M`"$"``"B!0```````!\!``!%!```XP(``$@```#Y`@``>04``%D$````````
M9`4``)X%``#T!@```````*`!``"O`P```````$<%``#5````)P,``%\```#8
M````/`$``"@"``!Q`@``HP(``),!``!O!@``+00``+0"````````J0$``$4#
M``#7`@``UP$``*4!`````````````.X&````````&0(``#\"```W`0``NP$`
M`'T#``#E!```&@$```````!=!0``E0(``%T!```8`P``RP8``&D$```T!```
MD@```.H&```K````?P```&P%```R`@``\@`````````:!0``G@```*<$``!Y
M`@```````+<&``!%``````4````````R!P```````$T"````````M08``%4#
M``!/!@``7P8```````"Z`@``\0$``,T!````````5P```/0#``#%`P``\@,`
M```````9!```$00````````@`````````#`%```F`P``S`$```````"@!@``
M-0,``$8````^`0```````"4`````````7@<``+(%```=!```"@,``)X&````
M````<`````````#N`0``D````*0#```T!0``W@(``.H$``"O!@``B`4``/D&
M``"G`P``HP```,\```"S!@``ZP8``"L$``!)`P``)@4``'P"``#;````````
M``0&``#U!0``!`(``',!``"2`P````````````!F````70(``"<```"!!0``
M2@<``,T%``!$`P```````,@!``"+`@``&`8``!T"``"-!````````#`!````
M````L`$``.T``````````````)T#```+!P````````````#:`P``$`8```$"
M``"A!@``/`,``(<%````````/`4`````````````LP$``.H`````````````
M`'X"``"?`@```````+P"````````:@8``,P```!1`0``````````````````
MB````'L&```_!````````'L%````````W````#0&```;!```$0$```````"S
M````AP0``)H%``"E!@``VP4``&4"```0`@```````,<&```\!@``Y```````
M````````.P0``,X`````````,`8``)D&``!H`P``5P8```````#O`@``CP4`
M`,\%```2!0``?P$```L#````````L`````````#$````;0,``'X#````````
M``````````!Z`@``*@4``%$#```9!0``8P````````"`!```<P```(T```#&
M````?P(``/`%``!``P``Q`4``&<&````````^0$```````````````````L%
M```V````3`<``!`#```L````@P(``&\````T`````````'D&```<````X`8`
M`)`&``!O`0``;04``,@%````````)P8``#T'```.``````````````"<!0``
M`````#$"``!3`````````%<'``!X!```H@```&`!````````W@,````````)
M````%@0``-@#``!#`@``````````````````P@,``$\"```I`@``^@(``(P&
M``"5````+P$``%8"``!7!0``7`4``&$&```C!0``=P$```````":`P```0,`
M`*$$````````XP```!P&``#"!0``"@(``+L%````````.04```H&``!'`P``
M````````````````JP8``$,#``"K````!0<``&0```"]````@P8```````";
M`P``JP,```````"A`@``L0$``,($``"8!```*```````````````$0(``/@&
M```S`````P8``#@%``!<!P``V@0``#8$``"^!@``BP$```````"&`P``&@0`
M`````````````````$$#``#"``````````D'``"E!````````-T#````````
MD@8``)$#````````Y0$``#\'``!W!```;`$``$@'````!@``````````````
M````A@8```````!R````0`<```\&````````-`(``",`````````[04``*P&
M``!3`P``9`,``,8%``!*!```R@(``%D````Q!P``%`4`````````````_P4`
M``````!U`P```````*@$`````````````.("````````.0,`````````````
M_P$``(P%```\`@``O`8``"(&``#'!```4`8`````````````>@0``(0#``#6
M````[P8``%D!``";!```N00``*8%``#^`0``+`4````````%!@``R@```#D&
M````````SP(```````"\````;P,``%\#```K`P``U`8``#,&```*````700`
M``````#*!@``;@0``"D$``#O`P``)0,``+$$```<`0```````'$$```V`0``
M`````*T`````````A`4``'L!``#V!@``9P<````````>!@```````-4$````
M````NP0``'8#``!)!0````````````!1`@``%0(``/$$``"%!````````*T!
M``!Y````T`0``$,````@`P``3`0```0````-`P``608``'<#``!`!@``X0``
M`"H```#9`0```````"P#``"A````(P,``!($``!T`@``[P0``)D$````````
M`````/4&``!C`@``504``````````````@<```$$``"H`@``OP(``#P`````
M`````````!(```#N!```,00```````#H!@``%00```````!7`@``OP$``(X%
M``#Y`````````-`%````````@0$```T'``!H````Y`$``-0!```4!P``L`(`
M`($$``"Y!0``-`<````````V!0``_P8``-H"``")!0``]`0```````"/`@``
M!P,``,8!```P!```*P<``&0$```R!````````/("``"(`@``"@<``-\"``!5
M!@``<`(`````````````TP8``,$#``!,``````````````#M`@``7`8``+4!
M```X!@``B@0``"`!``!+!P``5P0``-`"``#2`P```````!\'```Z!```,@,`
M`&`&````````8P,```````#2!0``4@0``+\#``````````````````!*`@``
M%P$``,X"```V!@``BP```,$"``"]`0```````"8$``!,!0```````(@#````
M````IP```%L'```D!P``\0```/@%``#Z`0```````#8#``"[`````P``````
M``"B`@``4@<``/<"``">`@``8````'X```!<`0````````````!/````<@0`
M``````!2`P``&@8``!0"``"<`@``S00```````"'!@```````&8$``"2!```
M`````)T"``##!@``\`````````"\!0``P`8``.`!```N`@``6P(```````"9
M!0``<`,``$`%``":````=`4```P!```W!0``!`,```````!J`@```````/0!
M``"G`@``````````````````````````````````5`(``)D#```_`0``G@0`
M`"T%```:`````````)4$```V!P``\`$`````````````U`4````````-`0``
M`````,D&````````00<``+<"``````````````````#,!@``'0```#H#````
M`````````(L#``"L!0``4P(``"X$``!K`0```````,\$```L!P``6`$``",$
M``"6`0````````````"]`@``#@<``&L"``!A`````````&$"``"6````$0``
M`)`!``!6!``````````````8````X0$```````!H`0``,`,``.4"```?````
M?`$```````#S!0``)0<``,D%```H!0``%@<```````#^`@``M`,``.0$````
M````9`<``#T!``!+`P``*`0``*0!````````PP(````````0````PP,``(8"
M````````O@$`````````````20<``/L#```8`@``@@4``&4#``!H!@``U@0`
M````````````W`$`````````````OP8``-$&``"4!@``"P```#0!``#E!0``
M>P,``+8"````````K@8``"@&``#D!@``%0<```````"B`0````````````#$
M!@``V@````@"``!T!```%@,```````!7`P``)08``"('`````````````/`#
M```%`P```````!D```!L`P``YP0``,L!``#Z!```E0$``',$``#?`0``T@$`
M`-X!````````^@```*(#``!3!0```````+0!````````]````'P#``#5`0``
MD`,```````"?!0```````!L&```%!```Z08```,$````````:@<``&,!``"H
M!@``P````,$```!4!```604``'(#``#'`@````````````"-`@``G`,``!8%
M``#Q!0``-0$``(D"``"/````_@```/H%`````````````,,!``!D`0``````
M`)<$``"6`P``_@0``.$$``#0`P``K0,``,L%``#=`0```````&T&``"W````
M``````````!(!````````$\'``!1!```Q@8````````7`@```````*D`````
M````4`(``+T$```Z`0``50(``","``#2`@``#````)4&``"O!```MP$``"(!
M````````0P$``'('```.!0```````'0!```^!@``[`(``"H#````````6P0`
M`-($``#&`@````````````"B!```?@$``(D$````````M00``%8'````````
M004``)(%``#J`0``5`<``)@%```'!P```````.<#``"I`P``E0,``/P&``!"
M`P``&P(``"H$````````:P<``&<!```_!@``FP(``"\'``!_!0``O`$`````
M```+!````````#H````K`@``#00``%X$``#R!@```````&$#``"]`P``1`8`
M`,@"````````>`,```````!?!0``1P8``'\$``#6!0``C08``.D#``"^`P``
MP`(``!('````````C04``!,````P!P```````-$````K!0```````"H'``!6
M`P```````%@%``":`@```@8``#P$`````````@(``&@'`````````````.``
M``!J!```T````%\"``"[`@```````)T```"G!0``:`(``*D$``"6`@``(`0`
M`#$%``#B!```WP,``/<$``!X`````````!,'``#]`P``<@4``/P#````````
M`````,L#``!&`P``LP(```````#4!```"00``&P$```=!@````````\%``!)
M`@``@0(``#T&``"(!@`````````````A`P``(08``#H&``!6!@``,```````
M``"/`0``*@$```````"R`@`````````````J!@``W`(```@!``!>`@``\P(`
M`-D&````````[@4```````"3`````````%H$`````````````,@&````````
M`````)<!``!;!0``'@```$\#``#M`0``'@$``&$'``````````````````#%
M!@``%0,``(T!````````?00``"0%````````J04``*P"```G!P````````8'
M`````````````+8%```<`@``V0(```````"=`0``5P$```(!``!&`@``3P0`
M`.L%``!*!0```````&X'````````"@0``,<`````````(@0``'@&``""`0``
M200``.T&``!K`````````'8&````````ZP,``,\!``#3`@``%````)<"````
M`````````-<#````````#@0``),%````````-P<``"<"``!K!@```````(4%
M``"_!```.0```$X#``#'`P``;P(``)L```"E`@```````/P"``";!@``7@``
M`$`$``!]!0``*P$``*D"````````F0```-D#```1!0``]P```#@"``"R````
MR@4```````#9!0````````````#P!`````````````#G!0````````````!'
M`@``+P4```````"Q`@```````&D#````````_P,```,%```@!@``1@8``!$#
M````````G`0``/0%``!V````7P<``)\$````````K@,``$$"``";!0``"0,`
M````````````3`8```````!6!0````````````#C!```MP4``"X&``#9````
M$`<``',&````````Z0$``#4$``!L!@``/@<``*,$``!G`````````'T&``"E
M`P````<``!T%``"Y`P```````%0%``!H!0``>P(`````````````>`(``(X$
M``")````@@,``),#``!J`0``;@,``/D$``#``0``4@(``(,#``#H!```@```
M`#X"```U!@``1`4``#0#```)`0``J`4`````````````F@0```````!O!P``
MX0,``#L#`````````````-8&````````D0$```````"X!@``<08``!P$``#V
M`@``O04``'L```"!!@``J@$```````!Q`P``"P$``.8"```[!@``-0<`````
M````````A````!T#```;!0``,P$``"T```"7!@``R00````````L`@``EP``
M`!H'```(`P```````(\$````````SP,```````"+!```)0$```````!0````
M`````%@'``!3!P``6@```&D"````````#@,``$0!``!;`P``/@0````````:
M`@```````*X```"X``````````````!B!@``U04``!\&``!4`P``?`8``$8!
M``"^!```.`<``````````````````-H&``"$!```00```"D#``!1!P``M@$`
M`-T$``!G`P```````,4```":`0```````!4```!4````YP$``/$&``"=!```
M*`,``-<$``#X!```D00```````"9`0``.0$``&`$````````,P,``+\````,
M!0``Z`,``-L"``"2`0``\0,``+`$``#/!@``?@8``$(````9`0```````(\&
M``!C!@``A@0``&D%````````ZP$``&('``"+!@``;0(```(#````````````
M`,$!``"Q!@``[@(````````M!@``FP$```````#B`````````%`'````````
M%`0``#$&``"F`P``1P<``/\$``!"!P``^`$```(```!'`0``<P,``"<%````
M````%P4``$\!```8`0``AP,```````!;!@``B0$`````````````````````
M````````=`8```````"/`P```````.X#``"F`@``XP,```@&```3!```2P4`
M`&<"```$!P````````T````#`0``]P8``*8$``!B!0``TP,```````#0!@``
MS0(``*,!``!(!@``3`$``-<````^!0```````$D```!R!@``*@(```````"`
M`@``_`$``/P%`````````````'<````'!@``U````!L!``#.!0````````8`
M``#]!0``%P8``*T&``#8`@``4P$``*X!``!O!0``W@4``*$#``#\!```````
M``````!I!P``[00``(P!``"#!`````(``$T`````````0@(``+X"``"(`0``
MX@$```````#8!0``)````#,%```X`0``A`$``````````````````+H#```Q
M````E````)`$``!$`@```````"\`````````?P8``"\&``":!@``````````
M````````&@,``-<&``"G`0``]0``````````````J````$(&``"T!@``C`(`
M`#4%`````````````%P$``!2!0```````.(%``"?`P```P<````````?`@``
MTP0``"\$```Y`@```````+(&````````\`8``+@$``#*`0``-P,``*\%````
M````=0```#X#``!W`@```````(@$``#"`0``````````````````L`4``%X%
M```R`0``I`4``$$$``!0!````````#\````D!```_@4`````````````DP0`
M````````````JP0``'4%``#U`@``TP4```````!T`P``K@4``.4#``"Y`0``
M'P4```````#)`0````````````!+`0```````"D'``"Z!```O@4``&P```!@
M!0```````&X!```C!@``!P0```````!5!```L0,``!8"``!.!0```````.L$
M``""`@``$`4``)X#``#A!0```````'@!``!I````@0,``.8%````````YP``
M`$`!```.`0````````````!V`@``B@8``,$%```O`@``````````````````
M``````````!&!P```````'4$``!'!```>@,``/`"````````0@0``/0"````
M`````````$,'``#?!0``&0<``"0"``"8`@``408``%$%``!0`P``\0(`````
M`````````````$H!``!(`P``.0<``%T#``"C!0````````````"#`0``(0<`
M`&(#````````0`(````````F`0``3@```*L!````````B@4``$T&``!P!@``
M708``#,"``!-!```Q@,``,L$````````M`4``!<'```8!0``6@$``'4!```&
M`0``P00``#,$`````````````,T&``!$!```BP4``,0"`````````````,`%
M``#H`@``X`(``!,&``"0`@``Z@(``"X!```R!@``F0(`````````````;0``
M`%8!``!A!```L@,```````!Q`0``:08``-P#````````\P```%L!```5!@``
MYP(``+D"``"8!@``;0$```````!C!P``4P0``*X"````````D0```!4!````
M````HP8```````#;`P``9P4``"X```#F`0````````````"R!```K````"`"
M``!R`0``\P$`````````````208``.P!````````E@4```````#F!@``M@8`
M``````"&````*0$```````#1`0``N`(``$0'```Z!0```````/L"```'````
M`````+D````1!@``!`$``!P'````````Y`4```````",!```!0(``%X#```2
M`0``_00````````3`@``@@0```````#U`P``J08``)T%``#,!```&P```&($
M``#?!```\@4``*8!```F!@``?0(````````<`P``"`0```````!C!```O`0`
M`$X'``#(!```W@8```````#^`P``S`,``#@$```G!`````,```````#X`@``
M````````````````6`,``!\$```)`@``HP,```````"M`@```````#$#``!(
M`0``O`,``)0#``"<`0```````%4!``#O!0``XP$``*L"``!2`0``904`````
M``!&!0``!0```'$'```Z!P```````#<"```(!0``J`$``.0"````````80$`
M`&X&````````^````(4&``#\````J@(``/@#```7````/P,``)@#```]!0``
MX`0```````"D!`````````````!;````Y@0``,,````Y!```8P4``-D$```P
M`@```@4``*$%````````X@,```<"``"6!@``$0<``*0````L!@``%@```"T#
M````````#P(``/8````+`@``3@8``&X%``"8`0``_08``#<&``!P!```E`4`
M```````!!P``R0(``$\%`````````````%(&``#<!0```@0``%`!``#=!0``
M`````"0!``!K!0````````````!B`@```````/L&```I!@``I@8```````#S
M!@``;@``````````````)`8```$&```=!P```````&<$``#V`P```````',"
M```4`P``)@````````!F`P``J@0``"D```!4!@``%04``/4!```W!```+0<`
M`/T````O`P``Z````+4#`````````````!`!`````````````-(&````````
M6`8````````=`0``=0(```\!``"#````2P(``/L```#<!@``7@8``#T````;
M`P``K@0```````#5`P``=P8``-@$``"_!0``A@$``)0"```B````+@<``,X$
M``!:`@```````*@#``!8!`````````````!A!0```````*0&``!F!@``````
M`(H!``"W`P``<`<``(X"``">`0``U`,``*P#``"<!@``F````$P"``#``P``
M30$``/L%```]!```G````/D#``!Y`0``=08``&H#```M`@``]@$``.X`````
M````U0(````````$!````````'@%``!\!0```````"P!```9!@```````/T"
M``"1!@``_@8``(H"``!T````(P<``$L&````````#@8``$4%````````9@(`
M`%D"```[!P```````),&``"Z!0``:@4``"D%``"@````W08`````````````
M`````$T'``",`P``#P,``"`'```3`0``60,``.P````B`P``-P```*`"````
M````````````````````PP4``($```#L!0``&`<````@*"5S(&1A>7,@86=O
M*0`@*$%C8V5S<VME>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O
M;6]R<F]W*0`@*'EE<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C
M=&]R>2X`(B5S(B!I<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T
M(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@
M<F5N9&5R97(@;F]T(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O
M=7!S('-Y<W1E;2X`(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS
M('-Y<W1E;2X`(B5S(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E
M9"!O9B`E+C)F34(@86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@
M9&%Y<R!U;G1I;"!Y;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E
M8V%S=``E<R`M($YO=&EC90`E<R!&:6YG97)P<FEN=``E<R!-86EN=&5N86YC
M92!/<&5R871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@
M57``)7,@5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E
M<R!A="`E<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N
M86YC92!O<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@
M9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T
M:&ES('1I;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O
M=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A
M;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B!4:&ES(&UE
M<W-A9V4@;6%Y(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"
M97=A<F4@;V8@9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V
M:61I;F<@=&AE('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO
M;BX`+"!G=7-T:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M
M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R
M($9O<FUA=``R-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I
M;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%0
M22!)1`!!8F]U="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S
M;6ED9&QE`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`
M06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O
M<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O
M=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I
M;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N
M`$%D9"!A(&-H:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES
M<VEO;B!T;R`B)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N
M97<@;65M8F5R<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII
M;&QA(%-I9&5B87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D
M9')E<W,@8F]O:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL
M(&)U="!C;W5L9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T
M:6]N.B`E<RX`061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO
M9R!I;B!N;W<N`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!
M9&1R97-S($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@
M;W1H97(@=7-E<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L
M8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@
M075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N
M<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL
M;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES
M=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O
M<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D
M9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE
M<FEC86X@4V%M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!
M;B!U;FMN;W=N(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!
M;F=U:6QL80!!;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT
M:6=U82!A;F0@0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T
M`$%P<&QI8V%T:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`
M07!P<F]V90!!<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W
M<RTQ,C4V*0!!<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO
M=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@
M9F]R("5S(#\`07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B
M(&%N9"!A;GD@<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI
M86X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C
M:6D@07)T`$%S:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I
M;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG
M;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N
M="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI
M<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`
M071T<FEB=71E<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S
M<6PZ(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C
M>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI
M=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F
M;W5N9"X@0V]M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C
M:"X`075T:%]I;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U
M;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D
M(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H
M7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T
M:%]L9&%P.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T
M:&4@<V5R=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@
M=7-E<B`E<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!
M=71H7VQD87`Z(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M
M8F%U=&@@97AT96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@
M24U!4"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T
M:&5N=&EC871I;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E
M9"!B>2!2041)55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R
M=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+@!!=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC
M=7-E<P!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S
M('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H
M<F%I;@!"86QT:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S
M`$)A<V4@9W)A<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E
M;&EN90!"96QA<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU
M=&%N`$)I<G1H9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N
M;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI
M=FEA`$)O;VMM87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R
M<P!";W-N:6$@86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M
M`$)O=79E="!)<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>0!"<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,
M:7-T`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U
M=&EO;B!0;VEN=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A
M<R!N;W0@8V]M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R
M;V]N`$-A;B!N;W0@<F5S970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N
M=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N`$-A;B!N;W0@=W)I=&4@=&\@9FEL
M92`B)7,B`$-A;B=T(&%D;6EN:7-T97(@97AT97)N86P@<V5S<VEO;B!H86YD
M;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@)7,`0V%N)W0@
M;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#86YC96P`0V%N8V5L(%!R;V)L96T@
M4F5P;W)T`$-A;FYO="!D96QE=&4@9FEL92`B)7,B+@!#86YN;W0@9FEN9"!A
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`$-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O
M<GD@(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A
M;FYO="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@
M<F5O<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@
M<F]U=&4@;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+@!#87!E(%9E<F1E
M`$-A<'1I;VX`0V%R<FEE<@!#871E9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N
M($ES;&%N9',`0V5L;"!0:&]N90!#96QL(%!R;W!E<G1I97,`0V5L;"!P861D
M:6YG.@!#96QL('!R;W!E<G1I97,`0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`
M0V5L=&EC("A)4T\M.#@U.2TQ-"D`0V5N=&5R`$-E;G1R86P@069R:6-A;B!2
M97!U8FQI8P!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#97)T:69I
M8V%T92!$971A:6QS`$-E<G1I9FEC871E($]W;F5R`$-E<G1I9FEC871E(%!O
M;&EC:65S`$-H860`0VAA;F=E`$-H86YG92!9;W5R(%!A<W-W;W)D`$-H86YG
M92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T
M:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%N9VEN9R!Y
M;W5R('!A<W-W;W)D(&ES(&YO="!S=7!P;W)T960@=VET:"!T:&4@8W5R<F5N
M="!C;VYF:6=U<F%T:6]N+B`@0V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(N
M`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S92!3:6UP
M;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I9S4I`$-H
M;V]S92!!<'!L:6-A=&EO;CH`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S
M($ES;&%N9`!#;&%S<R!D969I;FET:6]N(&]F("5S(&YO="!F;W5N9"X`0VQE
M87(`0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!1=65R>0!#;&5A<B!O=70@
M=7-E<CH@)7,`0VQE87(@=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@
M3&%T90!#;&EC:R!T;R!#;VYT:6YU90!#;&EC:V%T96QL('9I82!(5%10`$-L
M;W-E(%=I;F1O=P!#;&]U9',`0VQO=61S($5A<FQY`$-L;W5D>0!#;V-O<R`H
M2V5E;&EN9RD@27-L86YD<P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B
M;W)D97)S`$-O;&]M8FEA`$-O;&]R`$-O;&]R(%!I8VME<@!#;VQO=7(@<V5L
M96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L97,`0V]M:6-S`$-O;6UA;F0`0V]M
M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N
M>0!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&9O<B!S>6YC:6YG('=I=&@@
M4$1!<RP@4VUA<G1P:&]N97,@86YD($]U=&QO;VLN`$-O;F9I9W5R871I;VX@
M:7,@;W5T(&]F(&1A=&4N`$-O;F9I9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D
M`$-O;F=O`$-O;F=O+"!4:&4@1&5M;V-R871I8R!297!U8FQI8R!O9B!T:&4`
M0V]N;F5C=&EO;B!F86EL960N`$-O;FYE8W1I;VX@9F%I;&5D.B``0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(%)E87-O;CH@
M)7,@*"5S*0!#;VYN96-T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!#;VYT
M86-T<P!#;VYT86-T<R!W97)E('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R
M(&%D9')E<W,@8F]O:RX`0V]N=&5N="!T>7!E(&]F(&-O;7!R97-S960@9FEL
M93H@`$-O;G1E;G1S(&]F("(E<R(`0V]N=&EN=64`0V]O:R!)<VQA;F1S`$-O
M;VMI90!#;W!Y`$-O<'D@9F%I;&5D.B`E<P!#;W!Y('-E;&5C=&EO;@!#;W-T
M($E$`$-O<W1A(%)I8V$`0V]T92!D)TEV;VER90!#;W5L9"!N;W0@4$=0(&5N
M8W)Y<'0@;65S<V%G93H@`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E.B``
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE
M8VL@8F%L86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N`$-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B`B)7,B('5S:6YG($94
M4#H@)7,`0V]U;&0@;F]T(&-R96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z(`!#;W5L9"!N;W0@9&5C<GEP
M="!3+TU)344@9&%T82X`0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#
M;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$-O=6QD(&YO
M="!D971E<FUI;F4@=&AE(')E8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#
M;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N
M;W0@9F5T8V@@8V]M<&QE=&4@9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO
M="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES
M=',N`$-O=6QD(&YO="!L;V%D('-T<F%T96=Y("(E<R(N`$-O=6QD(&YO="!M
M:V1I<B`B)7,B+@!#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T
M:&4@:V5Y<V5R=F5R+@!#;W5L9"!N;W0@;W!E;B`B)7,B(&9O<B!W<FET:6YG
M+@!#;W5L9"!N;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N
M8V5?5&%S:R!M;V1U;&4@)7,`0V]U;&0@;F]T(&]P96X@9&ER96-T;W)Y("(E
M<R(N`$-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!R96%D("5S+@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T
M:&4@<F5Q=65S=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS
M(&%R92!N;W0@8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A
M9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@
M;F]T(')E=')I979E($%#3`!#;W5L9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B
M;V]K+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES=',N("5S
M`$-O=6QD(&YO="!R971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,`0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<FUD:7(@
M(B5S(BX`0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@
M;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V
M92!A(&)A8VMU<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('-E
M='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A
M=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@
M=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@
M;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`
M0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U
M;FQI;FL@(B5S(BX`0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<P!#;W5L
M9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@
M=W)I=&4@8V]N9FEG=7)A=&EO;B!F;W(@(B5S(CH@)7,`0V]U;&1N)W0@9FEN
M9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@
M:7,@;W!E;BX`0V]U;&1N)W0@9VEV92!U<V5R("(E<R(@=&AE(&9O;&QO=VEN
M9R!R:6=H=',@9F]R('1H92!F;VQD97(@(B5S(CH@)7,`0V]U;G1E9"!T97AT
M`$-O=6YT<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@
M82!N97<@;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I
M;VYS`$-R961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T
M(%!H87-E<P!#=7)R96YT(%-E<W-I;VYS`$-U<G)E;G0@5&EM90!#=7)R96YT
M(%523"!I<P!#=7)R96YT(%5S97)S`$-U<G)E;G0@5V5A=&AE<@!#=7)R96YT
M(&-O;F1I=&EO;CH@`$-U<G)E;G0@<W1Y;&4`0W5S=&]M:7IE('1A<VMS('1O
M(')U;B!U<&]N(&QO9V]N('1O("5S+@!#=70`0W5T('-E;&5C=&EO;@!#>7!R
M=7,`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`
M0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$-Z96-H(%)E<'5B;&EC`$1$
M`$133B`H<V5E(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA
M9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&%I;'D`1&%T851R964@
M0G)O=W-E<@!$871A8F%S92!,;V]K=7``1&%T90!$871E(%)E8V5I=F5D`$1A
M=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I
M;6%L(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#
M;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO
M;G,`1&5L971E`$1E;&5T92!#96QL`$1E;&5T92!'<F]U<`!$96QE=&4@3&]G
M`$1E;&5T92!097)M:7-S:6]N`$1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,`
M1&5L971E(&-E;&P`1&5L971E(&-O;'5M;@!$96QE=&4@97AI<W1I;F<@86QT
M97)N871E('1E;7!L871E`$1E;&5T92!M97-S86=E<P!$96QE=&4@<&5R;6ES
M<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B(&%N
M9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE
M8W1E9"!I9&5N=&ET>0!$96QE=&4@<W5B(&9O;&1E<G,`1&5L971E('1H92!C
M=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE(&-U<G)E;G0@<F]W`$1E;&5T960@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E
M8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA=`!$:7-P;W-I=&EO;B!.;W1I9FEC
M871I;VX`1&II8F]U=&D`1&\@;F]T(&1E;&5T90!$;R!N;W0@9&ER96-T;'D@
M86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H92!F:7)S="!R;W<@8V]N
M=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@8VAE8VL@=&AI<R!B;W@Z
M`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C
M8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D`$1O=VYL;V%D("5S`$1O=VYL;V%D
M(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(%!(4"!S8W)I<'0N`$1R;W`@
M9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%36%I;"UT;RU335,@9V%T97=A>2!D
M<FEV97(L(&9O<B!C87)R:65R<R!W:&EC:"!P<F]V:61E('1H:7,@<V5R=FEC
M92X`15)2`$5C=6%D;W(`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I
M="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M:7-S:6]N
M<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S:6]N<R!F
M;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16=Y
M<'0`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%;6%I;`!%;6%I;"!!9&1R
M97-S`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O
M;F9I<FUA=&EO;@!%;6%I;"UT;RU335,@1V%T97=A>0!%;6]T:6-O;G,`16UP
M='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T>2!S96%R8V@@=&5R;7,`
M16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O;2!0:&]T;R!'86QL97)I
M97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K(&-O;G1E>'0@;65N=3\`
M16YD('EE87(`16YL87)G92!%9&ET;W(`16YT97(@82!S96-U<FET>2!Q=65S
M=&EO;B!W:&EC:"!Y;W4@=VEL;"!B92!A<VME9"!I9B!Y;W4@;F5E9"!T;R!R
M97-E="!Y;W5R('!A<W-W;W)D+"!E+F<N("=W:&%T(&ES('1H92!N86UE(&]F
M('EO=7(@<&5T/R<Z`$5N=&5R('1H92!I;6%G92!54DP@:&5R90!%;G1E<B!T
M:&4@;&5T=&5R<R!B96QO=SH`17%U871O<FEA;"!'=6EN96$`17)I=')E80!%
M<G)O<@!%<G)O<B!C<F5A=&EN9R!B;&]C:SH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!A;F-H;W(Z("5S`$5R<F]R(&1E;&5T:6YG('-Y;F,@;&]G.B`E<P!%
M<G)O<B!G971T:6YG(&-O;G1E;G0Z("5S`$5R<F]R('5P9&%T:6YG('!A<W-W
M;W)D.B`E<P!%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N`$5R<F]R('=R:71I
M;F<@(B5S(BX`17-T;VYI80!%=&AI;W!I80!%=&AN:6,`175R;W!E`$5V97)Y
M(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`
M179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA;&8@:&]U<@!%
M=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$5X96-U=&4`17AP86YD`$5X
M<&%N9"!3:61E8F%R`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@
M;W(@<75O=&5D('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N
M=`!&1R!#;VQO<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V
M:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E
M<G9E<BX`1F%I;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D
M('1O(&-O<'D@9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&
M86EL960@=&\@8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T
M;R!M;W9E('1O("(E<R(N`$9A:6QE9"!T;R!R971R:65V93H@)7,`1F%I<@!&
M86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD<P!&871A
M;"!%<G)O<CH`1F%X`$9A>&5S`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T
M<FEX`$9I9VQE="!#05!40TA!`$9I:FD`1FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S`$9I;&4@36%N86=E<@!&:6QE($YA
M;64`1FEL92!S96QE8W1I;VX`1FEL92!U<&QO860`1FEL92!U<&QO861S(&YO
M="!S=7!P;W)T960N`$9I;'1E<G,`1FEN;&%N9`!&:7)S="!(86QF`$9I<G-T
M(%%U87)T97(`1FEX(')A=&EO`$9L:7``1F]G`$9O;&1E<B`E<R!D;V5S(&YO
M="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N
M)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y
M<R`H;F]T92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O
M=&@@9&%Y(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R
M97-U;'0@:6X@82!W:61E(&)L;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`
M1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@
M,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE
M=')O<&]L:71A;@!&<F5N8V@@1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E
M;F-H(%-O=71H97)N(%1E<G)I=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@
M1&5S8W)I<'1I;VX`1G5L;"!-;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y
M('1O('1A:V4@:6UA9V4@9G)O;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@
M)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA
M;GD`1VAA;F$`1VEB<F%L=&%R`$=I=F5N($YA;64`1VQO8F%L($]P=&EO;G,`
M1V\`1V]E9&5L`$=O;V=L92!-87!S`$=O;V=L92!396%R8V@`1W)A>7-C86QE
M`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`
M1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='D`1W)O=7!?;&1A<#H@56YA8FQE('1O(&%D9"!G<F]U<"`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$=R;W5P7VQD87`Z(%5N86)L
M92!T;R!D96QE=&4@9W)O=7`@)7,`1W)O=7!?;&1A<#H@56YA8FQE('1O('5P
M9&%T92!G<F]U<"`E<P!'<F]U<',`1W5A9&5L;W5P90!'=6%M`$=U871E;6%L
M80!'=65R;G-E>0!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`1W5I;F5A
M`$=U:6YE82U":7-S874`1W5Y86YA`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S
M97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C
M;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@
M=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H
M92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@
M9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E
M<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M
M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@
M=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E
M9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T
M:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C
M=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D
M92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT97)E9"!I;B!M
M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S
M('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@
M)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U
M;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T
M:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO
M;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@6$U,('1R964@
M9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E;6]V92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E=')I979E($U)
M344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@
M56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z
M(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A
M;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H
M4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI
M:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H
M97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(
M=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I
M;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!D96QE=&EO
M;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL
M960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A:6QA8FQE+@!)
M4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L;V-K+@!)4"!L
M;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R90!)8V5L86YD
M`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N
M=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY
M+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T
M('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M
M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A
M;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA
M9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES
M<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@
M55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@
M9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L(%-T97`@)60`
M26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2
M;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E
M8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA
M;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N
M`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S97)S`$EN9&]N
M97-I80!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A
M=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G90!)
M;G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E
M9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT(&]N
M90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`
M26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A
M<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A<F%G
M<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N871E
M('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H('EO
M=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A
M9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E<@!)
M;G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T('!A
M<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E<G0@
M<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER
M960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T+TUO
M9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT(&-R
M961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS=69F
M:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI9"!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!:25`@9&%T80!);G9A
M;&ED(&%P<&QI8V%T:6]N+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A
M=&$@<W5B;6ET=&5D+@!);G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN
M=F%L:60@9FEL92!F;W)M870`26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI
M9"!L;V-A=&EO;B!P<F]V:61E9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI
M9"!O<B!M:7-S:6YG(&%P:5]I9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M
M971E<G,N`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R
M=&YE<B!I9"X`26YV86QI9"!P<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C
M;VPN`$EN=F%L:60@<F5C:7!I96YT.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J
M96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D
M871A+@!);G9E;G1O<GD`26YV97)T('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F`$ER87$`27)E;&%N9`!)<VQE(&]F($UA;@!)<V]L871E
M9"!4+5-T;W)M<P!)<W)A96P`27-S=65R`$ET86QI8P!)=&%L>0!*86UA:6-A
M`$IA;G5A<GD`2F%P86X`2F%P86YE<V4@*$E33RTR,#(R+4I0*0!*97)S97D`
M2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I
M9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N
M`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E
M9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE=V)I97,`2V5Y($-R96%T:6]N
M`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G
M90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE('!U8FQI8R!K97ES97)V97(N
M`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P
M=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+
M=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA;F=U86=E`$QA;R!096]P;&4G
M<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D
M($-H86YG90!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`
M3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`
M3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*86UA:&ER:7EA`$QI96-H=&5N
M<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!286EN`$QI9VAT(%)A:6X@16%R
M;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A
M:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`
M3&EN:P!,:6YK('!O:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T
M;R!T:&4@8V]M<&]S92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU
M>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@
M1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S
M:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T
M:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,
M;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I
M;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U
M=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R
M('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY
M+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E
M:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M
M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O
M;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R
M;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I
M;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA
M;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I
M97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A
M<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA
M<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K
M('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S
M("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-
M87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU
M<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E
M9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V
M(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI
M;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@
M;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U
M8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD
M(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y
M<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C
M;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-
M971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-
M97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`
M36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L
M87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE
M="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P
M86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9
M;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E
M('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN
M9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N
M($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO
M9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`
M36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO
M;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T
M:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#
M;&]U9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2
M:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L
M=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT
M:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T
M:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@
M1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L
M86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.
M971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@
M55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@
M55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I
M8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R
M:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@365S<V%G
M92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@
M6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E
M(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W
M("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`
M3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI
M9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T
M;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y
M(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO
M(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A
M;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN
M`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@
M<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C
M:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P
M96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R
M961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U
M<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.
M;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@
M;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N
M<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B
M97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE
M8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG
M('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R
M('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@
M86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R
M;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O
M;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R
M<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@
M8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I
M8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES
M<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T
M97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D
M+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O
M=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A
M8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R
M<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@
M;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`
M3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M
M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I
M<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T
M('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY
M(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R
M('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R
M(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@
M=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@
M9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A
M(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@
M9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N
M86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L
M871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF
M;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N
M(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG
M:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@
M2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$T@3&EG
M:'0@4F%I;@!032!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H
M;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!/4TE8(&5X=&5N<VEO;B!I<R!M
M:7-S:6YG`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@
M<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q
M=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET
M:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S
M(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`
M4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT
M96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I
M;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@
M9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O
M;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W:71H('1H92!T97)M<R!T
M;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R
M>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I
M;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE
M`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0
M<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T
M:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S
M<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A
M="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@
M:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@
M9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T
M:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME
M>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME
M>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O
M`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@
M2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`
M4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT
M<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5L871I;VYS:&EP($)R;W=S97(`
M4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T
M<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO
M8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I
M<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@
M=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U
M97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z
M(`!297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I
M<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T
M:6]N+@!297%U:7)E9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E
M="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E
M='5R;B!T;R!/<'1I;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2
M979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`
M4FED9&QE<P!2:6=H=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@
M4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O
M9W)A<&AI8R!3:6=N871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!
M4TP@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A
M9VEN9P!344P@<W1A=&5M96YT(&9O<B!V86QU92!L;V]K=7!S`%-32`!354-#
M15-3`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I
M;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC
M96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M
M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E
M(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S
M`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S
M(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E
M8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P
M9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I
M96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C
M="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O
M=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L
M96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N
M(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U
M(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y
M(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H
M92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L
M96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T
M:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E
M;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V
M97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN
M`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS
M('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E
M=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U
M('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R
M969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`
M4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P
M86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E
M='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L
M;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE
M;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y
M<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R
M96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@
M=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L
M`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`
M4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@
M0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T
M:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO
M860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S
M(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB
M;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,
M96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I
M;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N
M:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S
M($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q
M=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3
M;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R
M97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`
M4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`
M4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E
M;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`
M4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M
M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L
M=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@
M5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R
M86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN
M9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#
M4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3
M=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y
M<W1E;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA
M<R!B965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L
M;'D@861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE
M87)E9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B
M)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O
M;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U
M;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@
M<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E
M<W-F=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U
M9&%N`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U
M;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S
M8W)I<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO
M9R!D96QE=&5D`%-Y;G1A>"!E<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N
M($%R86(@4F5P=6)L:6,`5"U3=&]R;0!4+5-T;W)M(&%N9"!7:6YD>0!4+5-T
M;W)M<P!4+5-T;W)M<R!%87)L>0!44U8@9FEL90!486)L90!486)L92!0<F]P
M97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN
M8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O
M<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E
M<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@
M(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`
M5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P
M*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE
M+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+
M;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B
M`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M
M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@
M9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H
M960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@
M=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@
M=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W
M87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q
M=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO
M=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@
M8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@
M8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T
M82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S
M<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@
M:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E
M<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T
M;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D
M:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O
M;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S
M(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R
M86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9
M;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@
M<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE
M(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N
M9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@
M;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M
M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S
M(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H
M92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA
M;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H
M92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS
M<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI
M;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@
M<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A
M;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D
M871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H
M92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA
M;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R
M97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D
M(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@
M(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED
M(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N
M9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L
M;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`
M5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A
M=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C
M=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A
M:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA
M>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@
M=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y
M;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L
M96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@
M<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@
M<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R
M;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@
M(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P
M;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N
M('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W
M87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S
M(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@
M9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R
M;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y
M;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N
M8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y
M(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE
M(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4
M:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD
M97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A
M<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II
M<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D
M(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN
M8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@
M86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH
M='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)
M`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U
M9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W
M87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N
M9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N
M92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET
M(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L
M>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D
M+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@
M9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN
M`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H
M:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L
M:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU
M;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4
M:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@
M)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W
M('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H
M870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O
M<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E
M<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T
M("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B
M92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@
M>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@
M9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI
M<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O
M=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R
M;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT
M;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O
M=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL
M92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K
M96QA=0!4;VUO<G)O=P!4;VYG80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N
M<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U
M`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI
M<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U
M<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I
M<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE
M`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D
M9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA
M8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S
M+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@8VAE8VL@9FEL
M92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@
M(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BX`56YA
M8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C;W!Y(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@(B5S(BX`56YA
M8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@8W)E871E
M(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD97(@(B5S(BX`
M56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA8FQE('1O(&1E
M8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B+"!T:&4@9&ER
M96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T92`B)7,B.B`E
M<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV
M96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA
M8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE
M=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C
M=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A
M=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E
M<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET
M:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@
M8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H
M9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``
M56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D
M>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@
M)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R
M=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D
M;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE
M('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O
M('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA
M;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O
M;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E
M<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M
M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D
M(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`
M56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)
M1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK
M;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P
M87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5
M;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A
M<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L
M:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G
M('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C
M97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X
M=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9&%T960@
M(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L;V%D`%5P;&]A9&5D
M(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+@!5
M<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU;6)E<G,`57)U9W5A
M>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@;F%M92]P87-S=V]R
M9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5<V5R`%5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C
M8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE("(E<R(@86QR96%D
M>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!6
M86QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU92!I<R!O
M=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L=65S`%9A;'5E<R!T
M;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E;F5Z=65L80!697)I
M9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@
M=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC
M86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H
M`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N
M(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER9VEN($ES;&%N9',L
M($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES:6)I;&ET>0!6:7-I
M8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``5T%23@!705).24Y'
M(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E<RX`5TE.('9I82!(
M5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`5V5A=&AE<B!&;W)E
M8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5B`%=E8B!3:71E`%=E
M96ML>0!796QC;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R
M;B`H25-/+3@X-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@
M4V%H87)A`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T
M97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R86-T97(_`%=H
M870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@
M;6%P`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@
M=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET
M<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F
M96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H
M('5N:70`5VED=&@Z`%=I:VD`5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@
M:6X@:VYO=',`5VEN9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O
M<FL@061D<F5S<P!7;W)K(%!H;VYE`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@
M:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB
M97(@;V8@9FEE;&1S+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F
M9G-E="`E9"!W:&EL92!R96%D:6YG(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y(%5S86=E
M`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S(%-U8FIE
M8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`65E960!9
M86AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E`%EO=2!A
M<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T;R!S=VET
M8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A;&QO=V5D('1O(&-R
M96%T92!M;W)E('1H86X@)60@8FQO8VMS+@!9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+@!9;W4@8V%N;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@
M>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I
M;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!T;R!E
M;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N=6UB97(L(&1I9VET<R!O;FQY('=I
M=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T:&4@:6YT97)N871I;VYA;"!D:6%L
M:6YG('!R969I>"X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!V86QU92X`
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO
M=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E
M;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),
M('=H97)E('1H:7,@;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N
M('-E<G9E<B!T;R!B92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E
M<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA
M;64@=&\@<F5M;W9E+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T
M;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T
M92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9
M;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G;W)Y(&YA;64N`%EO=2!N965D('1O
M('!R;W9I9&4@86X@271A;&EA;B!P:&]N92!N=6UB97(`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M861D:6YG('5S97)S+B!)9B!Y;W4@=VES:"!T;R!U<V4@2&]R9&4@=&\@861M
M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y;W4@;75S="!U<V4@82!D:69F97)E
M;G0@875T:&5N=&EC871I;VX@8F%C:V5N9"X`66]U<B!A=71H96YT:6-A=&EO
M;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@
M=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@
M<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H86YG960@
M<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R
M;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92X`66]U
M<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN
M(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E
M;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N
M86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R
M9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I
M;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H96-K('EO
M=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W;W)D+@!9
M;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D+@!9;W5R(')E;6]T92!S97)V97)S
M.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I80!::6UB86)W90!;2&ED92!1=6]T
M960@5&5X=%T`6U!R;V)L96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M
M`%M3:&]W(%%U;W1E9"!497AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S
M70!?061M:6YI<W1R871I;VX`7T-,20!?1&5L971E(%)O=P!?1W)O=7!S`%](
M96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI
M;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R
M97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD87(`8V%L;0!C86YN
M;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-L:6-K
M(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O;F9I9W5R871I;VX@
M97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN9P!D871A(&9O<FUA
M="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL:6YG`&9I;&4`9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z`&AO<W0@;F%M92!U
M;FMN;W=N`&EM;65D:6%T90!I;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@
M<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W
M:&EL92!M86MI;F<@25-/+@!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T
M(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE
M9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V
M:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I
M82!(5%10`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R
M>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`
M=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!0<F]J96-T+4ED+59E<G-I
M;VXZ($AO<F1E(#,N,0I297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S
M+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTQ-R`Q,#HP
M,"LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,3<@,3`Z,S@K,#$P
M,`I,87-T+51R86YS;&%T;W(Z($QA<WIL;R!,+B!4;W)N;V-I(#QT;W)L87-Z
M0'AE;FEA+G-O=&4N:'4^"DQA;F=U86=E+51E86TZ($AU;F=A<FEA;B`\:3$X
M;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TR"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@;F%P<&%L(&5Z96SU='0I
M`"`H06QT+6)I;&QE;G1Y^R`E<RD`("@E<R!N87`@;?IL=F$I`"`H;6$I`"`H
M:&]L;F%P*0`@*'1E9VYA<"D`(#H@`"(E<R(@;F5M(&%L:_9N>79TX7(N`"(E
M<R(@;F5M(.ER=NEN>65S(';A;&%S>G3A<RX`(B5S(B!N:6YC<R!K;VYF:6=U
M<N%L=F$@82!(;W)D92!296=I<W1R>6)E;BX`(B5S(B!F87-T<G5K=/IR82UM
M96=J96QE;NUT]2!N96T@=&%LX6QH873S+@`B)7,B+70@:&]Z>N%A9'1U:R!A
M(&-S;W!O<G1O:VAO>BX`(B5S(BUT(&AO>GKA861T=6L@82!J;V=O<W5L='/A
M9VD@<F5N9'-Z97)H97HN`"(E<R(M="!N96T@:&]Z='5K(&SI=')E.B`E<RX`
M)2XR9DU"(&9E;&AA<WINX6QT(&$@)2XR9DU"(&UE9V5N9V5D971T8O5L("@E
M+C)F)24I`"5D("5S(.ES("5S`"5D(&YA<"!M^FQV82!L96KA<B!J96QS>F%V
MX6YA:R#I<G;I;GEE<W/I9V4N`"5D(&YA<&]S(&5L]7)E:F5L>NES`"5S("T@
M1FEG>65L;65Z=&5TZ7,`)7,@;&5N>6]M870`)7,@:V%R8F%N=&%R=.%S:2!F
M96QA9&%T;VL@+2!M96=E<O5S[73I<P`E<R!B9>%L;.UTX7,`)7,@;&]G:6X@
M;NEV(&EGZ6YY;.ES`"5S('-Z;VQGX6QT873A<VD@9F5L=.ET96QE:P!!("(E
M<R(@;F5V^R#A;&QO;>%N>2!MX7(@;.ET97II:RX`)7,@.B`E<R`E<P!!*'HI
M("5S(&OI<WIE;B#A;&P@87H@86SA8F)I(&MA<F)A;G1A<G3A<VD@9F5L861A
M=&]K(&5L=NEG>NESZ7)E+DIE;/9L:F4@:VD@87IO:V%T(&$@9F5L861A=&\H
M:V$I="P@86UI*&ME*70@;6]S="!E;"!K[7;A;B!VZ6=E>FYI+@`E<R!K:73V
M;'3I<V4@<WK\:W/I9V5S`"5S('!E<F,`)7,@;F5M('1A;.%L:&%T\RX`)7,@
M+2`E<R`H]G-S>F5S96X@)7,I`"5S(&/M;6IE9WEZZ6ME`"5S(&YA<'3A<F$`
M)7,@9F5L:F5G>7KI<V5I`"5S(&9E;&%D871L:7-TX6IA`"5S.B!,96AE='/I
M9V5S+"!H;V=Y(&5Z(&$@;&5VZ6P@=F%L\VKA8F%N(&YE;2!A(&UE9V%D;W1T
M(&9E;&%D\W3S;"!S>N%R;6%Z:6LN($=O;F1O;&IA(&UE9RP@;6EE;/5T="!R
MX6MA='1I;G0@=F%L86UI<F4L('9A9WD@<WIE;>EL>65S(&EN9F]R;>%C:?-T
M(&%D(&UE9RX`+"!S>NEL;/9KZ7-E:P`L("5S("5S+7,@<WKI;&SV:^ES96L`
M+"!VX6QT;WKS("5S(.ES("5S(&OV>O9T=``M+2!VX6QA<W-Z;VX@+2T`,3(@
M\W+A<R!F;W)MX71U;0`R-"#S<N%S(&9O<FWA='5M`#(T(/-R80`\16SU>O4`
M17IE;B!B;&]K:R!H87-Z;N%L873A:&]Z(&5G>2!A9&%T8N%Z:7,@86QR96YD
M<WIE<B!S>OQK<^EG97,N`$AE;'ER96AO>FAA=&%T;&%N(&AI8F$@=/9R=.EN
M=`!!(&QE=NEL('1I=&MO<^UTX7/A:&]Z(&5G>2!N>6EL=N%N;W,@4$=0(&MU
M;&-S('-Z_&MSZ6=E<RX`02!D:6=I=.%L:7-A;B!A;.'M<G0@;&5VZ6P@96QL
M96[U<GKI<^EH97H@96=Y(&YY:6QVX6YO<R!01U`@:W5L8W,@<WK\:W/I9V5S
M+@!!('1I=&MO<^UT;W1T(&QE=NEL(&1E:_-D;VSA<^%H;WH@96=Y(&YY:6QV
MX6YO<R!01U`@:W5L8W,L(&5G>2!T:71K;W,@4$=0(&MU;&-S(.ES(&5G>2!J
M96QM;VYD870@<WK\:W/I9V5S+@!!(&QE=NEL(&1I9VETX6QI<R!A;.'M<N%S
MX6AO>B!E9WD@;GEI;';A;F]S(%!'4"!K=6QC<RP@96=Y('1I=&MO<R!01U`@
M:W5L8W,@Z7,@96=Y(&IE;&UO;F1A="!S>OQK<^EG97,N`$$@=&ET:V]S[71O
M='0@;&5VZ6P@9&5K\V1O;.%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K
M=6QC<RP@96=Y('1I=&MO<R!3+TU)344@:W5L8W,@Z7,@96=Y(&IE;&UO;F1A
M="!S>OQK<^EG97,N`$$@;&5VZ6P@9&EG:73A;&ES(&%LX>URX7/A:&]Z(&5G
M>2!N>6EL=N%N;W,@4R]-24U%(&MU;&-S+"!E9WD@=&ET:V]S(%,O34E-12!K
M=6QC<R#I<R!E9WD@:F5L;6]N9&%T('-Z_&MSZ6=E<RX`02!L97;I;"!T:71K
M;W/M=.%SX6AO>B!E9WD@;GEI;';A;F]S(%,O34E-12!K=6QC<R!S>OQK<^EG
M97,N`$3I;&5L]71T(&)O<G5L="#I9P!$Z6QE;/5T="!G>65N9V4@97/U`$3I
M;&5L]71T(&5S]0!$Z6QE;/5T=&D@>N%P;W)O:P!$Z6QE;/5T="!H\WKA<&]R
M;VL`9&4O9'4`05!)($E$("AA('!R;V=R86UO>N%S:2!F96S\;&5T(&%Z;VYO
M<^UT\VIA*0!%<G+U;"!A>B!E9&ET;W)R\VP`3NEV:F5G>2XN+@!A8G-Z(&%L
M=6P`86)S>B!K]GKI<`!.:6YC<R!J;V=O<W5L='/A9V$@82!61E,@86QK]FYY
M=G3A<B!LZ71R96AO>N%SX6AO>BX`3FEN8W,@:F]G;W-U;'1SX6=A(&$@5D93
M(&;A:FP@;.ET<F5H;WKA<^%H;WHN`$)E:F5L96YT:V5ZZ7-I(&EN9F]R;>%C
M:?,`2F5L<WKS`$$@:F]G;W-U;'1SX6<@9F5L('9A;B!F_&=G97-Z='9E+@!0
MZ6YZ_&=Y96L`0F5V:71E;`!!;&-S;W!O<G0@;.ET<F5H;WKA<V$`2F]G;W-U
M;'1SX6=I(&%L8W-O<&]R="!LZ71R96AO>N%S80!!9&1J=6L@:&]Z>N$@:71T
M.@#::B!C<V]P;W)T(&SI=')E:&]ZX7-A`-IJ(&IO9V]S=6QT<^%G(&SI=')E
M:&]ZX7-A`$%L8W-O<&]R="!H;WIZX6%DX7-A("(E<R(M:&5Z`$IO9V]S=6QT
M<^%G:2!A;&-S;W!O<G0@:&]Z>N%A9.%S82`B)7,B+6AE>@#::B!F96QH87-Z
M;N%L\R!LZ71R96AO>N%S83H`VFH@;W-Z;&]P(&AO>GKA863A<V$`VFH@=&%G
M;VL@9F5L=NET96QE`-IJ('#A<B!H;WIZX6%DX7-A`$$H>BD@)7,@;65N_'0@
M861J=6L@:&]Z>N$@82!-;WII;&QA(&UE;OQS;W)H;WH`061J=6L@:&]Z>N$@
M82!C[6UJ96=Y>NEK:&5Z.@!!9&IU:R!H;WIZX2!A(&/M;6IE9WEZZ6ME;6AE
M>@#::B!F96QH87-Z;N%L\R!H;WIZX6%DX7-A`"(E<R(@9F5L:&%S>F[A;/-T
M(&AO>GKA861T=6L@82!R96YD<WIE<FAE>BP@9&4@;F5M('-I:V5R_&QT(&$@
M=/9B8FD@8F5J96QE;G1K97KI<VD@861A="!TX7)O;.%S83H@)7,N`"(E<R(@
M9F5L:&%S>F[A;/-T(&9E;'9E='3I:R!A(')E;F1S>F5R8F4N($UO<W0@;>%R
M(&)E:F5L96YT:V5Z:&5T+@!!(')E;F1S>F5R:&5Z(&YE;2!A9&AA=/-K(&AO
M>GKA(/IJ(&9E;&AA<WINX6SS:RX`0^UM`$/M;6IE9WEZZ6L`061M:6YI<WIT
M<N%C:?,@+2!J;V=O<W5L='/A9V]K(&%DX7-A('1O=N%B8FD@9F5L:&%S>F[A
M;/-K;F%K`$%D;6EN:7-Z='+A8VGS`$AI<F1E=.ES96L`069G86YI<WITX6X`
M06QBX6YI80!!;&?I<FEA`$%L:6%S`$5L:&5L>65ZZ7,`4F5N9&5ZZ7,Z`&%Z
M(/9S<WIE<V5T`$UI;F1E;B!N96T@=F5N9.EG(&9E;&AA<WINX6SS`$UI;F1E
M;B!C<V]P;W)T`$UI;F1E;B!J;V=O<W5L='/A9P!-:6YD(&$@;NEG>2!O;&1A
M;&]N(&QE9WEE;B!K97)E=`!%;F=E9&K\;FL@;65G('3V8F(@8^UM970@:7,`
M02!S;W)S>N%M;W,@9F5L<V]R;VSA<R!T[7!U<V$@=N%L=&]Z=&%T:&%T\R!L
M96=Y96X_`$WA<B!LZ71E>FEK`$E-4U`@8F5J96QE;G1K97KI<VD@<&%R86WI
M=&5R96L`3>%S:6LL($E-4U`@:F5L<WKS`$WA<VEK+"!)35-0(&)E:F5L96YT
M:V5ZZ7-I(&[I=@!-X7-I:R!E;6%I;"!C[6T`06QT97)N873M=B!S86)L;VYO
M:P!!;'1E<FYA=.UV('-Z]G9E9SH`06UE<FEK86D@4WIA;6]A`$$@;65G861O
M='0@Z7)TZ6L@;F5M(&9O9V%D:&%T\R!E;"X`27-M97)E=&QE;B!H:6)A('3V
M<G3I;G0N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYI;2!P<F]X>6X@
M:V5R97-Z=/QL:2!I;G1E<FYE="!E;.ERZ7,`5N%L87-Z`$%N=&%R:W1I<WH`
M06YT:6=U82#I<R!"87)B=61A`$%L:V%L;6%ZX7,`06QK86QM87KA<V]K(&QI
M<W3A:F$`07H@86QK86QM87KA<R!KZ7-Z+@!!(&OV>O9S('3A<G1E<OQL970@
M86QC<V]P;W)T:F%I<F$@:7,@Z7)VZ6YY97,`2O-VX6AA9WGA<P!+]G+\;&)E
M;/QL:2!MZ7)E=`#A<')I;&ES`&%R86(@*%=I;F1O=W,M,3(U-BD`02!T]FWV
M<NUT971T(.%L;&]MX6YY(&WI<F5T90!!('3V;?9R[71E='0@X6QL;VWA;GD@
M;F5V90!":7IT;W,@8F5N;F4L(&AO9WD@=/9R]FQN:2!K[7;A;FIA("5S(&)E
M:F5L96YT:V5ZZ7-I(&EGZ6YYZ70_`$)I>G1O<RP@:&]G>2!T]G+V;&YI(&%K
M87)J82`B)7,B+70@86QC<V]P;W)T:F%I=F%L(&5G>?QT=#\`07)G96YT[6YA
M`-9R;>EN>6]R<WKA9P#V<FWI;GD@*$%235-#24DM."D`3?MVZ7-Z970`07)U
M8F$`4&]H;G!E:0!!<V-I:2!R86IZ;VL`P7IS:6$O0W-E;F1E<RWS8V7A;FD@
M<NEG:?,`2^ER:F5N(&$@<F5N9'-Z97(@;65G97+U<^UTZ7-T(&$@:V%R8F%N
M=&%R=.%S:2!F96QA9&%T;VL@96QVZ6=ZZ7-E(&5L]71T/P!(;WIZX7)E;F1E
M;.ES:2!O<WIL;W!O:P!.96ULZ71E>O4@8W-O<&]R=&]T(&OM<^ER96QT(&UE
M9R!T]G+V;&YI+@!.96ULZ71E>O4@:F]G;W-U;'1SX6=O="!K[7/I<F5L="!M
M96<@=/9R]FQN:2X`3F5M;.ET97KU(&IO9V]S=6QT<^%G;W0@:^USZ7)E;'0@
M;65G(&UE9W;A;'1O>G1A=&YI+@!.96ULZ71E>O4@:_9Z]G,@=.%R=&5R_&QE
M=&5T(&OM<^ER96QT(&UE9R!M96=VX6QT;WIT871N:2X`5'5L86ID;VYSX6=O
M:P!A=6=U<WIT=7,`075S>G1RX6QI80!!=7-Z=')I80!!=71H7V-Y<G-Q;#H@
M82!S>OQK<^EG97,@:6UA<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N`$%U=&A?
M8WER=7,Z(&$@:.%T=.ER<WIO;&?A;'1A=.%S(&YE;2!R96YD96QK97II:R!A
M(&OM=N%N="!KZ7!E<W/I9V5K:V5L+@!!=71H7V-Y<G5S.B!A('-Z_&MSZ6=E
M<R!I;6%P(&+U=NUTZ7,@;F5M('1A;.%L:&%T\RX`075T:%]F='`Z(&$@<WK\
M:W/I9V5S(&9T<"!B]7;M=.ES(&YE;2!T86SA;&AA=/,N($9O<F3M='-A(&QE
M(&$@4$A0+70@87H@+2UE;F%B;&4M9G1P(&]P8VGS=F%L+@!!=71H7VEM87`Z
M(&$@<WK\:W/I9V5S(&EM87`@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H
M7VMR8C4Z(&$@<WK\:W/I9V5S(&MR8C4@8O5V[73I<R!N96T@=&%LX6QH873S
M+@!!=71H7VQD87`Z(&YE;2!H;WIH873S:R!LZ71R92#Z:B!F96QH87-Z;N%L
M\VL@06-T:79E($1I<F5C=&]R>2!E<V5TZ6X`075T:%]L9&%P.B!F96QH87-Z
M;N%L\VL@;F5M('3V<O9L:&5T]6L@06-T:79E($1I<F5C=&]R>2!E<V5TZ6X`
M075T:%]L9&%P.B!A('-Z_&MSZ6=E<R!,1$%0(&+U=NUTZ7,@;F5M('1A;.%L
M:&%T\RX`075T:%]L9&%P.B`E<R!F96QH87-Z;N%L\R!H;WIZX6%DX7-A(&YE
M;2!S:6ME<OQL="X@02!S>F5R=F5R(';A;&%S>F$Z(`!!=71H7VQD87`Z("5S
M(&9E;&AA<WINX6SS('3V<FSI<V4@;F5M('-I:V5R_&QT`$%U=&A?;&1A<#H@
M)7,@9F5L:&%S>F[A;/,@861A=&%I;F%K(&UE9_IJ[73A<V$@;F5M('-I:V5R
M_&QT`$%U=&A?;&1A<#H@82!F96QH87-Z;N%L\VL@;F5M(&WS9&]S[71H873S
M:R!!8W1I=F4@1&ER96-T;W)Y(&5S973I;@!!=71H7VUC86PZ(&$@<WK\:W/I
M9V5S($U#04P@8O5V[73I<R!N96T@=&%LX6QH873S+@!!=71H7W-M8F%U=&@Z
M(&$@<WK\:W/I9V5S('-M8F%U=&@@8O5V[73I<R!N96T@=&%LX6QH873S+@!.
M96T@<VEK97+\;'0@87H@24U!4"!S>F5R=F5R96X@=F%L\R!F96QH87-Z;N%L
M\V%Z;VYO<^UTX7,N`$$@9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!S:6ME
M<OQL="X`02!F96QH87-Z;N%L\V%Z;VYO<^UTX7,@;F5M('-I:V5R_&QT+B`E
M<P!!(&9E;&AA<WINX6SS(&%Z;VYO<^UTX7/A="!A(%)!1$E54R!S>F5R=F5R
M(&5L=71A<^UT;W1T82X`3F5M('-I:V5R_&QT(&%Z($944"!S>F5R=F5R:&5Z
M('9A;/,@9F5L:&%S>F[A;/-A>F]N;W/M=.%S+@!.96T@<VEK97+\;'0@87H@
M4TU"('-Z97)V97)E;B!V86SS(&9E;&AA<WINX6SS87IO;F]S[73A<RX`02!R
M96YD96QK97KI<W)E(.%L;/,@;65Z]6LZ`$%Z97)B86ID>G/A;@!!(&=O;F]S
M>B!R96YD<WIE<F=A>F1A(&UE;G1SZ6=E:0!(X71TZ7(`2.%T=.ER('-Z[6X`
M3F5M(&UE9V9E;&5L]2!K97)B97)O<R!J96QS>O,N`$YE;2!M96=F96QE;/4@
M:V5R8F5R;W,@9F5L:&%S>F[A;/-NZ78N`$)A:&%MX6L`0F%H<F5I;@!B86QT
M:2`H25-/+3@X-3DM,3,I`$)A;F=L861E<P!"87)B861O<P!!(&=R869I:W5S
M(.%L;&]MX6YY;VL@(B5S(B!A;&OV;GEV=.%R82!N96T@=&%LX6QH873S+@!A
M;&%P=F]N86QO;@!&96CI<F]R;W-Z;W)S>N%G`$)E;&=I=6T`0F5L:7IE`$)E
M;FEN`$)E<FUU9&$`0FAU=.%N`%-Z_&QE=.ES;F%P`$$@(B5S(B!B;&]K:R!A
M("(E<R(@<')O9W)A;6UA;"!N96T@=&%LX6QH873S+@!+Z7!E<FYY]7+I<WH@
M8F7A;&SM=.%S`$OI<&5R;GGU<NES>B!T[7!U<P!FZ6QK]G;I<@!";VSM=FEA
M`$ME9'9E;F,@=V5B8^UM96L`2V5R970`2V5R971V87-T86=SX6<Z`$ME<F5T
M96L`0F]S>FYI82U(97)C96=O=FEN80!-:6YD:V5T=/4`0F]T<W=A;F$`86QU
M;`!";W5V970M<WII9V5T`$)R87KM;&EA`$)R:70@26YD:6%I+?-C9>%N:2!4
M97+\;&5T`$)R=6YE:2!$87)U<W-A;&%M`$)U;&?A<FEA`$9E;'-O<F]LX7,`
M0G5R:VEN82!&87-O`$)U<G5N9&D`5V5B;VQD86P@:V%R8F%N=&%R=.%S`$-2
M0P!!('1A;OIS[71VX6YY=FES<WIA=F]NX7-I(&QI<W3A:R`H0U),*2!C[6UE
M:0!#96QL82!T=6QA:F1O;G/A9V]K`$$@8V%C:&4@:6YI8VEA;&EZX6SA<V$@
M;F5M(&9E:F5Z]63V='0@8F4N`$YA<'3A<@!.>75G;V1T`$MA;6)O9'IS80!+
M86UE<G5N`$YE;2!S:6ME<OQL="!A(&IE;'-Z\W0@X73A;&SM=&%N:2P@9F]R
M9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BX`02AZ*2`B)7,B(.%L;&]MX6YY
M(&YE;2#M<FAA=/,N`$$@:_QL<_4@9F5L:&%S>F[A;/-K87!C<V]L870M:V5Z
M96SU:R!N96T@861M:6YI<WIT<N%L:&%T\VLN`$$@:_9V971K97KU($E-05`@
M<WIE<G9E<B!N96T@Z7)H973U(&5L.B`E<P!!*'HI("(E<R(@X6QL;VWA;GD@
M;F5M(&YY:71H873S(&UE9RX`2V%N861A`$WI9W-E`$WI9W-E(&O\;&3V:R!H
M:6)A:F5L96YTZ7-T`$$H>BD@(B5S(B#A;&QO;>%N>2!N96T@=/9R]FQH973U
M+@!.96T@=&%LX6QH873S(&%Z(&ED96EG;&5N97,@X6QL;VWA;GEO:V%T('1A
M<G1A;&UA>O,@86QK]FYY=G3A<BX`02`G=&%R9V5T1FEL92<@<&%R86WI=&5R
M(&UE9V%DX7-A(&[I;&O\;"!N96T@9F]L>71A=&AA=&IU:RX`02AZ*2`B)7,B
M(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2X`3F5M('3V<O9L:&5T]2P@)60@
M86QC<V]P;W)T:F$@=F%N+@!!>B#Z:B!S;W)B87)E;F1E>NES(&YE;2!L96AE
M='/I9V5S+"!A(&UE9V%D;W1T(&%D871O:R!S>N%M82!N96T@96=Y97II:R!A
M('3A<F]L=&%KZ79A;"X`02!M96=A9&]T="!S>N%M<F$@;F5M(&O\;&1H973U
M(&5L(&%Z(/QZ96YE="X`6O9L9"UF;VMI+7-Z:6=E=&5K`,%B<F%S>O9V96<`
M4WIO;&?A;'1A=/,`2V%T96?S<FGA:R#I<R!J96SV;.ES_&L`2V%J;>%N+7-Z
M:6=E=&5K`$UO8FEL('1E;&5F;VX`0V5L;&%T=6QA:F1O;G/A9V]K`$-E;&QA
M(&)E;'/U(&UA<F?S.@!#96QL871U;&%J9&]N<^%G;VL`0V5L;.%K(&OV>O9T
M=&D@<NES.@!-;V)I;"!T96QE9F]N`&ME;'1A("A)4T\M.#@U.2TQ-"D`:_9Z
MZ7``2_9ZZ7`M869R:6MA:2!+]GITX7)S87/A9P!K96QE="UE=7+S<&%I("A)
M4T\M.#@U.2TR*0!!('1A;OIS[71VX6YY('+I<WIL971E:0!!('1A;OIS[71V
MX6YY('1U;&%J9&]N;W-A`%1A;OIS[71VX6YY(&9E;&AA<WINX6SA<VD@:7+A
M;GEE;'9E:P!#<^%D`%;A;'1O>G1A=.%S`$$@:F5L<WKS(.%TX6QL[73A<V$`
M07H@UFX@X6QT86P@96QK_&QD]G1T(&QE=F5L96ME;B!S>F5R97!L]2!NZ78@
MZ7,@8^UM(&UE9W;A;'1O>G1A=.%S82X`02!J96QE;B!K;VYF:6=U<N%C:?-B
M86X@;F5M(&QE:&5T<^EG97,@82!J96QS>F%V86L@;?-D;W/M=.%S82X@1F]R
M9'5L:F]N(&$@<F5N9'-Z97)G87IDX6AO>BX`2V%R86MT97(`3&EN7VME;&QE
M;O5R>NES+BXN`$-H:6QE`$OM;F$`:^UN86DL(&5G>7-Z97+[<^UT971T("A'
M0C(S,3(I`&OM;F%I+"!H86=Y;VWA;GEO<R`H0FEG-2D`5N%L87-S>F]N(&MI
M(&5G>2!A;&MA;&UA>N%S=#H`5N%L87-S>F]N(&IE;'-Z\W0`5N%L87-S>F]N
M(&5G>2!F96QH87-Z;N%L\VYE=F5T`%;A;&%S<WIA(&MI(&$@9.%T=6UO:R!M
M96=J96QE;NUTZ7-I(&9O<FWA:N%T.@!6X6QA<W-Z82!K:2!A(&9E;'-O<F]L
MX7,@=.UP=7/A="`H<WKA;6]Z;W1T(&QI<W3A:V[A;"D`2V%RX6-S;VYY+7-Z
M:6=E=&5K`$$H>BD@)7,@8VQA<W,@9&5F:6[M8VGS:F$@;F5M('1A;.%L:&%T
M\RX`1&5R_&QT`%3V<FQI(&%Z($U33V9F:6-E('1A9V5K970`02!L96OI<F1E
M>NES('3V<FSI<V4`)7,@9F5L:&%S>F[A;/,@=/9R;.ES90!!(&9E;&AA<WIN
MX6SS('3V<FSI<V4`02!F96QH87-Z;N%L\R!A9&%T86EN86L@=/9R;.ES90!%
M<W3I<F4@9&5R_&QT(.EG`$$@9F]L>71A=.%S:&]Z(&MA='1I;G1S;VX@87H@
M96?I<G)E;`!#;&EC:V%T96QL('-Z;VQGX6QT873A<R!(5%10+6X@:V5R97-Z
M=/QL`$%Z(&%B;&%K(&)E>N%RX7-A`$)O<G5L="#I9P!296=G96P@9F5L:/5S
M(&ED]0!&96QH]7,@:63U`$OS:W5S>BUS>FEG971E:P!4_&YT97-S_&L@96P@
M87H@;VQD86QS\R!M96[\=`#6<W-Z97KA<G0@:V5R971E:P!+;VQU;6)I80!3
M>NUN`%-Z[6YVX6QA<WIT\P!3>NUN=N%L87-Z=.%S`$]S>FQO<&]K.@!!>B!O
M<WIL;W!O:R!C[6UE:0!6:6-C96L`4&%R86YC<P!087)A;F-SZ7)T96QM97KU
M`$UE9VIE9WEZZ7,`3NEV+"!E;&YE=F5ZZ7,`0V]M;W)E+7-Z:6=E=&5K`$/I
M9P!3>N%M[73S9^EP96L`263U:N%RX7-I(&AE;'EZ970`263U:N%RX7-I(&AE
M;'EZ970`2_QL]FYB<^EG96L@82!K;VYF:6=U<N%C:?-B86X`2^EZ:7-ZX6WM
M=/-GZ7!E:VME;"P@;VMO<W1E;&5F;VYO:VMA;"P@3W5T;&]O:VMA;"!V86SS
M(&%D871S>FEN:W)O;FEZX6SA<R!K;VYF:6=U<N%C:?-J80!!(&MO;F9I9W5R
MX6-I\R!MX7(@;F5M(.ER=NEN>65S+@`E<R!K;VYF:6=U<N%C:?-J80!!(&IE
M;'-Z\R!M96=E<O5S[73I<V4`2V]N9_,`2V]N9_-I($1E;6]K<F%T:6MU<R!+
M]GITX7)S87/A9P!3:6ME<G1E;&5N(&$@:V%P8W-O;&%T+@!3:6ME<G1E;&5N
M(&$@:V%P8W-O;&%T.B``02!N>6EL=N%N;W,@:W5L8W-O:R!S>F5R=F5R92!E
M;'5T87/M=&IA(&$@:V%P8W-O;&%T;W0N`$$@;GEI;';A;F]S(&MU;&-S;VL@
M<WIE<G9E<F4@96QU=&%S[71J82!A(&MA<&-S;VQA=&]T+B!/:V$Z("5S("@E
M<RD`4VEK97)T96QE;B!A>B!&5%`@<WIE<G9E<G)E;"!V86SS(&MA<&-S;VQA
M="X`4&%R=&YE<F5K`$$@<&%R=&YE<F5K970@<VEK97)E<V5N(&AO>GKA861T
M=6L@82!C[6UJ96=Y>NEKZ6AE>BX`02!T]FWV<NUT971T(.%L;&]MX6YY('3M
M<'5S83H@`"(E<R(@=&%R=&%L;6$`1F]L>71A=.%S`$-O;VLM<WII9V5T96L`
M4_QT:0!-X7-O;&IU:R#A=`!!(&WA<V]LX7,@;F5M('-I:V5R_&QT.B`E<P!!
M(&MI:F5L]FQT('+I<WH@;>%S;VSA<V$`4WKA;6SA>N%S:2!A>F]N;W/M=/,`
M0V]S=&$@4FEC80!%;&5FX6YT8W-O;G1P87)T`$YE;2!S:6ME<OQL="!01U`M
M=F5L('1I=&MO<^UT86YI(&$@;&5V96QE=#H@`$$@;&5V96QE="!N96T@<VEK
M97+\;'0@4$=0(&%LX>URX7-S86P@96QLX71N:3H@`$$@;&5V96QE="!N96T@
M<VEK97+\;'0@87H@4R]-24U%('-Z86)VX6YY('-Z97)I;G0@=&ET:V]S[71A
M;FDN`$$@;&5V96QE="!N96T@<VEK97+\;'0@4R]-24U%(&%LX>URX7-S86P@
M96QLX71N:2X`02!P87)T;F5R(&%D871A:70@;F5M('-I:V5R_&QT(&5L=.%R
M;VQN:2X@)7,`07H@3$1!4"!S>F5R=F5R(&YE;2#I<FAE=/4@96PN`$YE;2!S
M:6ME<OQL="!E;&QE;O5R:7IN:2!A('-ZX6ULX6KA;B!R96YD96QK97KI<W)E
M(.%L;/,@]G-S>F5G970N("5S`$YE;2!S:6ME<OQL="!A>B!,1$%0('-Z97)V
M97)H97H@:V%P8W-O;/-D;FDN`$YE;2!S:6ME<OQL="!A*'HI("(E<R(@<WIE
M<G9E<G)E;"!&5%`@:V%P8W-O;&%T;W0@9F5L=F5N;FDZ("5S`$YE;2!S:6ME
M<OQL="!LZ71R96AO>FYI(&$@:_9R;&5VZ6QL:7-TX70N("5S`$%Z(&%D871O
M:R!01U`@=&ET:V]S[73A<V+S;"!T]G)TZ6[U(&1E:_-D;VSA<V$@;F5M('-I
M:V5R_&QT.B``07H@861A=&]K(%,O34E-12!T:71K;W/M=.%S8O-L('3V<G3I
M;O4@9&5K\V1O;.%S82!N96T@<VEK97+\;'0N`$$@<&%R=&YE<B!T]G)LZ7-E
M(&YE;2!S:6ME<OQL="X@)7,`02!K]G)L97;I;&QI<W1A('3V<FSI<V4@;F5M
M('-I:V5R_&QT+B`E<P!.96T@<VEK97+\;'0@=/9R]FQN:2!A*'HI("(E<R(@
M<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$YE;2!S:6ME<OQL="!M96?A;&QA
M<.UT86YI(&$@8^UM>F5T="!E;6%I;"!C[6WI="X`3F5M('-I:V5R_&QT(&)E
M;VQV87-N:2!A('1E;&IE<R!C[6UJ96=Y>NEK970N`$YE;2!S:6ME<OQL="!B
M96]L=F%S;FD@82!T96QJ97,@:_9R;&5VZ6QL:7-TX70N`$YE;2!S:6ME<OQL
M="!B96]L=F%S;FD@82!K]G)L97;I;&QI<W3A:R!T96QJ97,@9F5L<V]R;VSA
M<^%T+@!!*'HI("(E<R(@<W1R873I9VEA(&YE;2!T86SA;&AA=/,N`$$H>BD@
M(B5S(B!A;&OV;GEV=.%R(&YE;2!H;WIH873S(&SI=')E+@!!(&YY:6QVX6YO
M<R!K=6QC<V]T(&YE;2!S:6ME<OQL="!M96=S>F5R97IN:2!A(&MU;&-S<WIE
M<G9E<G+U;"X`3F5M('-I:V5R_&QT("(E<R(M="#M<N%S:2!CZ6QL86P@;65G
M;GEI=&YI+@!.96T@<VEK97+\;'0@)7,M="!M96=N>6ET;FDN`$$@)7,@:V%R
M8F%N=&%R=.%S:2!M;V1U;"!N96T@;GEI=&AA=/,@;65G`$$H>BD@(B5S(B!A
M;&OV;GEV=.%R(&YE;2!N>6ET:&%T\R!M96<N`$%Z($Q$05`@<WIE<G9E<B!N
M96T@Z7)H973U(&5L+@`E<R!N96T@;VQV87-H873S+@!.96T@<VEK97+\;'0@
M82!K[7;A;G0@9F5L:&%S>F[A;/,@:F5L<WIA=N%T(.%TX6QL[71A;FDN($%Z
M(&UE9V%D;W1T(&%D871O:R!N96T@=F%G>2!N96T@=&5L:F5S96X@9F5L96QN
M96L@;65G+B!0<O-BX6QJ82#Z:G)A+"!V86=Y(&AA('1O=N%B8FD@<V5G[71S
MZ6=R92!V86X@<WK\:W/I9V4L(&9O<F1U;&IO;B!A(')E;F1S>F5R9V%Z9.%H
M;WHN`$YE;2!S:6ME<OQL="!M96=H873A<F]Z;FD@87H@96SI<NES:2!J;V=O
M<W5L='/A9V]K870@*$%#3"D`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&/M
M;6IE9WEZZ6ME="X@)7,`3F5M('-I:V5R_&QT(&)E;VQV87-N:2!A(&OV<FQE
M=NEL;&ES=.%T+B`E<P!.96T@<VEK97+\;'0@8F5O;'9A<VYI(&$@:_9R;&5V
MZ6QL:7-TX6MA="X@)7,`3F5M('-I:V5R_&QT(&UE9VAA=.%R;WIN:2!A('-Z
M97)V97(@:^EP97-SZ6=E:70`3F5M('-I:V5R_&QT('9I<W-Z8>%L;.UT86YI
M(&5Z(&5R961E=&D@:V]N9FEG=7+A8VGS="X`02AZ*2`B)7,B(&%L:_9N>79T
MX7(@;F5M('3V<O9L:&5T]2X`3F5M('-I:V5R_&QT(&5L;65N=&5N:2`E<R!K
M;VYF:6=U<N%C:?-T+@!.96T@<VEK97+\;'0@96QM96YT96YI(&$@8F%C:W5P
M(&MO;F9I9W5RX6-I\W0N`$YE;2!S:6ME<OQL="!E;&UE;G1E;FD@82!B86-K
M=7`@:V]N9FEG=7+A8VGS=#H@)7,`3F5M('-I:V5R_&QT(&5L;65N=&5N:2!A
M*'HI("(E<R(@<V5T=7`@=7!G<F%D92!P<F]G<F%M;W0N`$YE;2!S:6ME<OQL
M="!E;&UE;G1E;FD@82AZ*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`02AZ
M*2`E<R!K;VYF:6=U<N%C:?-S(.%L;&]MX6YY="!N96T@<VEK97+\;'0@96QM
M96YT96YI+B!686=Y(&AA<WINX6QJ82!A("5S(&]L9&%L;VX@;&5V]2!L96AE
M=/5SZ6=E:V5T+"!V86=Y(&WA<V]L:F$@X70@87H@86SA8F)I(&OS9&]T(&ED
M93H@)7,N`$%Z($Q$05`@<WIE<G9E<F5N(&YE;2!S:6ME<OQL="!E;';I9V5Z
M;FD@82!K97)E<^ES="X`(B5S(B!N96T@=F]L="!T]G+V;&AE=/4N`$$@<&%R
M=&YE<B!A9&%T86ET(&YE;2!S:6ME<OQL="!M\V1O<^UT86YI+B`E<P!.96T@
M<VEK97+\;'0@82!K]G)L97;I;&QI<W1A(&WS9&]S[73A<V$N("5S`$YE;2!S
M:6ME<OQL="!E;&UE;G1E;FD@(B5S(B!K;VYF:6=U<N%C:?-JX70Z("5S`$$@
M36]Z:6QL82!M96[\<V]R(&YE;2!T86SA;&AA=/,N($5L;&5N]7)I>GIE+"!H
M;V=Y(&UE9R!V86XM92!N>6ET=F$N`$YE;2!S:6ME<OQL="`B)7,B(&9E;&AA
M<WINX6SS;F%K(&IO9V]S=6QT<^%G;W0@861N:2!A*'HI("(E<R(@;6%P<.%H
M;WHZ("5S`$MO<FSA=&]S('-Z]G9E9P!/<G-ZX6<`5.%V;VMT873A<P!,Z71R
M96AO>N%S`$QI;FL@;.ET<F5H;WKA<V$`VFH@;.ET<F5H;WKA<V$`06QM87!P
MX6L@;.ET<F5H;WKA<V$`07H@;V)J96MT=6T@;.ET<F5H;WKS:N%N86L@:F]G
M;W-U;'1SX6=A:0!(:71E;&OA<G1Y87-ZX6T`2&]R=N%T;W)S>N%G`$MU8F$`
M2F5L96YL96=I(#0@9N%Z:7,`02!J96QE;FQE9VD@9F5L:&%S>F[A;/-K87!C
M<V]L871O:P!0;VYT;W,@:63U`$$@:F5L96YL96=I(%523`!*96QE;FQE9VD@
M9F5L:&%S>F[A;/-K`$IE;&5N;&5G:2!I9/5JX7+A<P!!(&IE;&5N;&5G:2!I
M9/5JX7+A<VD@:&5L>7IE=#H`2F5L96YL96=I('-T[6QU<P!-:6QY96X@<&%R
M86YC<V]K(&9U<W-A;F%K(&QE(&%U=&]M871I:W5S86X@82`E<V)E('3V<G3I
M;O4@8F5J96QE;G1K97KI<VMO<BX`2VEVX6?A<P!!(&MI:F5L]FQT('+I<WH@
M:VEVX6?A<V$`0VEP<G5S`&-I<FEL;"`H2T])."U2*0!C:7)I;&P@*%=I;F1O
M=W,M,3(U,2D`8VER:6QL+75K<N%N("A+3TDX+54I`$-S96@@2_9Z=.%R<V%S
MX6<`1$0`1%-.("AA9&%T9F]R<N%S;&7M<O,@+2!LX7-D.B!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A=&%B87-E+F1B+FEN=')O
M+61S;BYP:'`I`&YA<&]N=&$`1&%T851R964@8O9N9^ES>O4`061A=&+A>FES
M8F%N('9A;/,@:V5R97/I<P!$X71U;0!!(&)EZ7)K97KI<R!N87!J80!$X71U
M;2!K:7;A;&%S>G3A<V$`;F%P<&%L`$]S>FQO<"!T]G)LZ7-E`&1E8V5M8F5R
M`'-ZX6UO:P!"96ME>F3I<R!K:6IJ96)B`$%L87#I<G1E;&UE>F5T=`!!>B!A
M;&%PZ7)T96QM97KI<R!S>F5R:6YT:2!S>NUN`$%L87#I<G1E;&UE>NES('-Z
M97)I;G1I(&%Z;VYO<^UT\P!!;&%PZ7)T96QM97IE='0@<VAE;&P`1&5F:6[M
M8VGS:P!4]G)LZ7,`02!C96QL82!T]G)LZ7-E`$$@8W-O<&]R="!T]G)LZ7-E
M`$$@;F%P;//A;&QO;>%N>2!T]G)LZ7-E`$$@:F]G;W-U;'1SX6<@=/9R;.ES
M90!,979E;&5K('3V<FSI<V4`02!C96QL82!T]G)LZ7-E`$%Z(&]S>FQO<"!T
M]G)LZ7-E`%3V<O9L:OQK(&MI(&$@;65G;.EV]2!A;'1E<FYA=.UV('-A8FQO
M;G0`02!L979E;&5K('3V<FSI<V4`(B5S(B!J;V=O<W5L='/A9V%I;F%K('3V
M<FSI<V4`5/9R]FQJ_&L@(B5S(B!J;V=O<W5L='/A9V%I="#I<R!E;FYE:R!E
M<V5T;&5G97,@86QC<V]P;W)T:F%I=#\`02!S;W(@=/9R;.ES90!!(&MI=N%L
M87-Z=&]T="!A>F]N;W/M=/,@=/9R;.ES90!!>B!A;&UA<'#A:R!T]G)LZ7-E
M`$$@:F5L96YL96=I(&]S>FQO<"!T]G)LZ7-E`$$@:F5L96YL96=I('-O<B!T
M]G)LZ7-E`%3V<O9L=/QK(&$H>BD@(B5S(B!S971U<"!U<&=R861E('!R;V=R
M86UO="X`02!KZ7IB97/M=.ES(&ED96IE`$3A;FEA`$%D:F]N(&QE[7+A<W0@
M82!P<F]B;.EMX7+S;`!,9>URX7,`4NES>FQE=&5K("AA($AO<F1E(&QO9V;A
M:FQB86X@:7,@;65G=&%LX6QH873S*3H`02!RZ7-Z;&5T96L@82!R96YD<WIE
M<F=A>F1A('-ZX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB82!K97+\;'1E:RX`
M1F5J;&5S>G3I<P!(87)M871P;VYT`$AA<FUA='!O;G0@:F5L96YL96<Z(`!(
M87)M871P;VYT.B``8F%L<O-L(&IO8F)R82#M<N%S`&IO8F)R\VP@8F%L<F$@
M[7+A<P!#[6UTX7(`07H@:63U<&]N=&]K870@,C0@\W+A<R!F;W)MX71U;6)A
M;B!J96QE;NUT<_QK(&UE9S\`365G:F5L96[M=.ES:2!B9>%L;.UTX7-O:P!!
M('+I<WIL971E<R!E;/5R96IE;'KI<R!M96=J96QE;NUTZ7-E`$5L]7)E:F5L
M>NES(&UE9VIE;&5N[73I<V4@*')E</QL]73I<FDI`$UE9VIE;&5N[73I<VD@
M9F]R;>%T=6T`R7)T97/M=.ES(&$@:^EZ8F5S[71E='0@;&5VZ6P@<V]R<^%R
M\VP`1'IS:6)U=&D`3F4@=/9R]FQJ_&L`02!M86EN=&5N86YC92YP:'`@;F5M
M(.ER:&5T]2!E;"!K]GIV971L96[\;"X`07H@96QS]2!S;W(@82!M97KU:R!N
M979E:70@=&%R=&%L;6%Z>F$_($AA(&EG96XL(&IE;/9L:F4@:VD@97IT.@!$
M;VUI;FEK80!$;VUI;FEK86D@2_9Z=.%R<V%SX6<`3FEN8W,@;>EG(&QO9VEN
M(&YE=F4_($EGZ6YY96QJ96X@96=Y970N`$QE=/9L=.ES`%3V;'1S_&L@;&4@
M)7,M=`!4]FQT<_QK(&QE(%!(4"!P<F]G<F%M(&9O<FWA:N%B86X@87H@96QK
MZ7-Z_&QT(&MO;F9I9W5RX6-I\W0N`$QE9_9R9/QL]2!L:7-T80!+X6+M=/-S
M>F5R96L`96UA:6P`16UA:6QB]6P@4TU3+6O\;&3U(&UE9VAA:G3S+"!H82!A
M('1E;&5F;VYTX7)S87/A9R!B:7IT;W/M=&IA(&5Z="!A('-Z;VQGX6QT873A
M<W0N`$A)0D$`16-U861O<@!-\V1O<^UTX7,`0FQO:VL@;?-D;W/M=.%S`$-S
M;W!O<G0@;?-D;W/M=.%S`$IO9V]S=6QT<^%G(&WS9&]S[73A<P!*;V=O<W5L
M='/A9V]K(&WS9&]S[73A<V$`)7,@:F]G;W-U;'1SX6=A:6YA:R!M\V1O<^UT
MX7-A`$UE;'EI:R!O<&-I\VMA="!VX6QT;WIT87-S=6LZ`"(E<R(@:F]G;W-U
M;'1SX6=A:6YA:R!M\V1O<^UTX7-A`"5S(&IO9V]S=6QT<^%G86EN86L@;?-D
M;W/M=.%S80!/:W1A=.%S`$5G>6EP=&]M`%-A;'9A9&]R`$5L96TN+BX`87H@
M)VTG(&)E=/L@<WKI;&5S<^EG90!%;6%I;`!%;6%I;"!C[6T`07H@96UA:6P@
M8^UM96MN96L@96=Y97IN:?QK(&ME;&PN`$5M86EL('9I<W-Z86EG87IO;.%S
M<V%L`$5M86EL+5--4R#A=&KA<O,`2&%N9W5L871I:V]N;VL`W')E<R#\>F5N
M970N`$YI;F-S(&EL>65N+@!4]G+V;&K\:R!K:2!A(&ME<F5SZ7-E:V5T`$5N
M9V5D:OQK(&UE9RP@:&]G>2!KZ7!E:V5T(&EL;&5S<WK\;FL@82!S>O9V96=B
M92!A($9O=/-G86SI<FGA:V+S;#\`3&5G>65N(&IO8F(@96?I<F=O;6)B86P@
M96SI<FAE=/4L(&MO;G1E>'1U<V;\9V?U(&UE;OP_`$%Z('5T;VQS\R#I=@#!
M=';A;'3A<R!K_&SV;B!A8FQA:W)A`$%D:F$@;65G(&%Z="!A(&)I>G1O;G/A
M9VD@:^ER9.ES="P@86UE;'ER92!M86ID(';A;&%S>F]L;FEA(&ME;&P@:F5L
M<WIA=N%N86L@X73A;&SM=.%SX6AO>BP@<&PN("=H;V=Y(&CM=FKA:R!A(&MU
M='GA:N%T/R<Z`$%D:F$@;65G(&$@:^EP(%523"UJZ70@:71T`,UR:F$@8F4@
M87H@86SA8F)I(&)E=/MK970Z`$5G>65N;.UT]6DM1W5I;F5A`$5R:71R96$`
M2&EB80!(:6)A('3V<G3I;G0@82!B;&]K:R!LZ71R96AO>N%S86MO<CH@)7,`
M2&EB82!T]G)TZ6YT(&%Z(&%D871S>FEN:W)O;FEZX6-I\W,@:F5L('3V<FSI
M<V5K;W(Z("5S`$%Z(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO;>%N
M>2!T]G)LZ7-E(&YE;2!S:6ME<OQL=#H@)7,`2&EB82!T]G)TZ6YT(&%Z(&%D
M871L96OI<NES8F5N.B`E<P!(:6)A('3V<G3I;G0@82!J96QS>O,@;65G=N%L
M=&]Z=&%TX7-A:V]R.B`E<P!(:6)A(&%Z(&5M86EL(/QZ96YE=&)E;BX`02AZ
M*2`B)7,B(.%L;&]MX6YY<F$@;F5M('-I:V5R_&QT(.UR;FDN`,ES>G1O<G-Z
MX6<`171I\W!I80!.96UZ971I<^EG96L`175R\W!A`#$U('!E<F-E;FOI;G0`
M,B!P97)C96YKZ6YT`#,P(&WA<V]D<&5R8V5N:^EN=``U('!E<F-E;FOI;G0`
M;6EN9&5N(&)E:F5L96YT:V5ZZ7-K;W(`9NEL\W+A;FOI;G0`<&5R8V5N:^EN
M=`!0Z6QD82#I<G3I:V5K.@!6Z6=R96AA:G3A<P!.>6ES<W5K('-ZZ70`2F5L
M96[M='/\:R!M96<@87H@;VQD86QS\R!M96[\=`!)='0@)RDG(&ME;&QE;F4@
M:_9V971K97IZ96X`271T(&-S=7!A<WH@<WKS;F%K('9A9WD@:63I>O5J96QB
M96X@;&5V]2!K97)E<^ES:2!K:69E:F5ZZ7-N96L@:V5L;&5N92!L96YN:64`
M07H@Z7)VZ6YY97-SZ6<@;&5JX7)A=&$`2VET97;U`%-Z[6X`02!K;VYF:6=U
M<N%C:?,@1E10+6X@X70@=F%L\R!F96QT]FQTZ7-E`$$@<WIE;>EL>65S(&)E
MX6QL[73A<V]K870@;F5M('-I:V5R_&QT(&)E;VQV87-N:2X`07H@3$1!4"!S
M>F5R=F5R(&YE;2#I<FAE=/4@96PN`$%Z(%--0B!S>F5R=F5R(&YE;2#I<FAE
M=/4@96PN`$YE;2!S:6ME<OQL="!A*'HI("(E<R(M8O5L('3V<G3I;O4@;>%S
M;VSA<RX`3F5M('-I:V5R_&QT(&$H>BD@(B5S(BUB92!T]G)TZ6[U(&WA<V]L
MX7,N`$YE;2!S:6ME<OQL="#Z:B!305-,(&MA<&-S;VQA=&]T(&SI=')E:&]Z
M;FDN`$YE;2!S:6ME<OQL="!A*'HI("(E<R(M8F4@=/9R=.EN]2#A=&AE;'EE
M>NES+@#!;&QO;>%N>6AO>GKA9NERZ7-I(&AI8F$Z("5S`%1I<WIT80!&86QK
M;&%N9"US>FEG971E:R`H36%L=FEN87,I`$9A<F]E+7-Z:6=E=&5K`$AE;'ER
M96AO>FAA=&%T;&%N(&AI8F$Z`$9A>`!&87@`9F5B<G7A<@!(]6WI<G/I:VQE
M=.ER>F5T`$CU;>ER<^EK;&5TZ7)Z970Z(`!%9WDM96=Y('KA<&]R`%-Z\W)V
MX6YY;W-A;B!H\WKA<&]R;VL`365Z]2!MX71R:7@`1FEG;&5T($-!4%1#2$$@
M*&)E=/MK:7)A:_,@:'5MX6YT97-Z="D`1FED>G-I`$;A:FP`02!FX6IL;VL@
M<WKA;6$Z("5S`$$@9N%J;&]K('-ZX6UA.B`E<P!&X6IL(&UE;F5D>G-E<@!&
MX6IL;NEV`$;A:FP@:VEJ96SV;.ES`$;A:FP@9F5L=/9L=.ES90!&X6IL;VL@
M9F5L=/9L=.ES92!N96T@;&5H971SZ6=E<RX`4WK[<O5K`$9I;FYO<G-ZX6<`
M96QS]2!FZ6P`96QS]2!N96=Y960`5N%L=&]Z871L86X@;>ER971A<N%N>0!4
M_&MR]GKI<R`H9O9L+VQE*0!+]F0`)7,@;6%P<&$@;F5M(&SI=&5Z:6L`0F5T
M^W-Z[6X`R71E;&5K`$]L>6%N(&+V;F?I<WKU:R!S>N%MX7)A+"!A;6EK(&YE
M;2!J96QE;NUT:6L@;65G(&$@:^EP96ME=`!%;/5R96IE;'KI<R`H<F5P_&SU
M=.ER:2D`07H@96SU<F5J96QZZ7,@:63U=&%R=&%M82!N87!O:V)A;B`H87H@
M96SU<F5J96QZZ7,@;F%P<&%L:2#I<R#I:G-Z86MA:2!A9&%T;VMA="!T87)T
M86QM87HL(&5ZZ7)T(&$@;F%G>2!S>N%M;VL@<WKI;&5S(&)L;VMK;W0@97)E
M9&WI;GEE>FYE:RD`16QF96QE:G1E='1E(&$@:F5L<WIA=N%T/P#;<FQA<&ME
M>F5LZ7,`263I>F5T`$EDZ7IE="!F86ITX6IA`$EDZ7IE=&5K`$EDZ7IE=&5K
M(#(`1O-R=6UO:P!4;W;A8F+M=.%S;VL`4.D`1G)A;64M96L`1G)A;F-I86]R
M<WKA9P!&<F%N8VEA;W)S>N%G`$9R86YC:6$@1W5Y86YA`$9R86YC:6$@4&]L
M:6[I>FEA`$9R86YC:6$@1.EL:2!497+\;&5T96L`1F5L863S`$ERX6YY.B``
M4NES>FQE=&5S(&QE[7+A<P!T96QI:&]L9`!496QJ97,@;NEV`$=A8F]N`$UE
M;'EI:R!G86SI<FGA8O-L('9E9WG\:R!A(&OI<&5T`$OI<&=A;.ER:6$Z`$=A
M;6)I80!(;WIZ=6L@;.ET<F4@82AZ*2`E<R!K;VYF:6=U<N%C:?-JX70`02!K
M96QE=&ME>F5T="!K\V0`1W+Z>FEA`$[I;65T;W)S>N%G`$=HX6YA`$=I8G)A
M;'3A<@!+97)E<WIT;NEV`$=L;V+A;&ES(&)EX6QL[73A<V]K`$UE:&5T`$?V
M9&5L`$=O;V=L92!TZ7)KZ7``1V]O9VQE(&ME<F5SZ7,`1F5K971E+V9E:.ER
M`$?V<O9G;W)S>N%G`&?V<O9G("A)4T\M.#@U.2TW*0!'<O9N;&%N9`!'<F5N
M861A`$-S;W!O<G0@861M:6YI<WIT<N%C:?,`02!C<V]P;W)T;NEV(&UA<F%D
M:&%T(/QR97-E;@!'<F]U<%]L9&%P.B`E<R!C<V]P;W)T(&AO>GKA863A<V$@
M;F5M('-I:V5R_&QT+B!!('-Z97)V97(@=N%L87-Z83H@`$=R;W5P7VQD87`Z
M("5S(&-S;W!O<G0@=/9R;.ES92!N96T@<VEK97+\;'0`1W)O=7!?;&1A<#H@
M)7,@8W-O<&]R="!A9&%T86EN86L@;65G^FKM=.%S82!N96T@<VEK97+\;'0`
M0W-O<&]R=&]K`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`
M5F5N9.EG(&IO9V]S=6QT<^%G;VL`5F5N9.EG:_9N>78`1W5I;F5A`$)I<W-A
M=2U'=6EN96$`1W5Y86YA`$A434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL
M86YD\R!A('-O<B!U=&]L<_,@8V5L;.%JX70@=/9R]FQN:2X`2%1-3$%R96$@
M9WGA=F%SX6=B\VP@;F5M(&AA:FQA;F3S(&$@=.%B;.%Z870@=71O;'/S(&]S
M>FQO<.%T('3V<O9L;FDN`$A434Q!<F5A(&=YX79A<^%G8O-L(&YE;2!H86IL
M86YD\R!A('3A8FSA>F%T('5T;VQS\R!S;W+A="!T]G+V;&YI+@!!($A45%`@
M9F5L:&%S>F[A;/-A>F]N;W/M=.%S(&YE;2!T86SA;&AA=/,N`$AA:71I`$AA
M<V@@86QG;W)I=&UU<P!+]F0`1F5J;.EC`$9E:FSI8P!(96%R9"T@Z7,@36-$
M;VYA;&0M<WII9V5T96L`17+U<R!Z:79A=&%R`&CI8F5R("A)4T\M.#@U.2TX
M+4DI`$UA9V%S<^%G`%-E9^UT<^EG`%-E9^UT<^EG(&$@<WIE<FME<WIT]2!H
M87-Z;N%L873A:&]Z`%-E9^UT<^EG`$;I;'1E:V4`17H@82!FX6IL(&5L96IE
M.@!N86=Y`$ME>F3U;&%P`%9A=&EKX6YVX7)O<P!+97ID]6QA<`!/='1H;VYI
M(&/M;0!3>F5MZ6QY97,@86QK]FYY=G3A<@!/='1H;VYI('1E;&5F;VX`2&]N
M9'5R87,`2&]N9VMO;F<`2&]R9&4`2&]R9&4O2V]L86(Z(&AI8N%S("5S(%A-
M3"!A9&%T('9A;B!A*'HI("5S(/QZ96YE=&)E;@!(;W)D92]+;VQA8CH@;FEN
M8W,@82AZ*2`E<R!O8FIE:W1U;6YA:R!M96=F96QE;/4@_'IE;F5T`$AO<F1E
M+TMO;&%B.B!N:6YC<R`E<R!T[7!U<_H@;V)J96MT=6T@82AZ*2`E<R#\>F5N
M971B96X`2&]R9&4O2V]L86(Z(%-I:V5R97-E;B!T]G+V;'3\:R!E>G0Z("5S
M("(E<R(`2&]R9&4O2V]L86(Z(&%Z(&EN=&5G<N%L\R!P<F]G<F%M:&]Z('-Z
M_&MSZ6=E<R!A("=D;VUX;6PG(%!(4"!B]7;M=.ES`$AO<F1E+TMO;&%B.B!N
M96T@<VEK97+\;'0@^FH@6$U,(&;A="!LZ71R96AO>FYI(&$H>BD@)7,@;V)J
M96MT=6UH;WH`2&]R9&4O2V]L86(Z($YE;2!S:6ME<OQL="!T]G+V;&YI("5S
M+70@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(&YE;2!S:6ME<OQL="!M96=H873A
M<F]Z;FD@82!-24U%($E$+6KA="!A(&OV=F5T:V5Z]2!T[7!U<_H@;65L;.EK
M;&5T;F5K.B`E<P!(;W)D92]+;VQA8CH@3F5M('-I:V5R_&QT('-Z:6YK<F]N
M:7KA;&YI("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!.96T@<VEK97+\;'0@
M82!K]G9E=&ME>O4@:_9Z]G,@=.%R=&5R_&QE="!S>FEN:W)O;FEZX6SA<V$Z
M("5S`$AO<F1E+TMO;&%B.B!I<VUE<F5T;&5N(&OV>O9S('3A<G1E<OQL970@
M(B5S(@!6[7IS>FEN=&5S('9O;F%L`%;M>G-Z:6YT97,@;6%R9_,`5NUZ<WII
M;G1E<SH`2&]G>2!J=71O='0@:61E/R`H2^ER:OQK(.UR:F$@;65G(2D`2.%N
M>2!O<WIL;W!O="!K[7;A;B#V<W-Z96]L=F%S>G1A;FD_`$CA;GD@;65Z]2`H
M;W-Z;&]P*2!V86X_`$CA;GD@<V]R="!K[7;A;B#V<W-Z96]L=F%S>G1A;FD_
M`%#A<F%T87)T86QO;0!0X7)A=&%R=&%L;VTZ(`!(=6UO<FES=.%K`$UA9WEA
M<F]R<WKA9P!!>B!)34%0(&QE=NEL;.%D82!LZ71R96AO>N%S82!N96T@<VEK
M97+\;'0Z("5S`$%Z($E-05`@;&5VZ6QLX61A('3V<FSI<V4@;F5M('-I:V5R
M_&QT.B`E<P!!>B!)34%0(&QE=NEL;.%DX6AO>B!T87)T;WKS(&MV\W1A(&SI
M=')E:&]ZX7-A(&YE;2!S:6ME<OQL=#H@)7,`25`@8^UM`$%Z($E0(&/M;2!N
M96T@:&%TX7)O>FAA=/,@;65G+@!!>B!)4"!C[6T@;FEN8W,@82!M96=E;F=E
M9&5T="!#2412('1A<G1O;>%N>6)A;BX`5&EL=&]T="]M96=VX6QT;WIO='0@
M25`@8^UM+@!3;W(@8F5I;&QE<WITZ7-E(&5F]FSI`$EZ;&%N9`!C<V%K(&EK
M;VYO:P`E<R!I:V]N:F%I`&EK;VYO:R#I<R!S>O9V96<`07H@87IO;F]S[73S
M:&]Z(';A;&%S>G1O='0@96QN979E>NES.@!(82!A(&UE9VIE;&5N[73I<R!N
M96T@;65G9F5L96SU+"`E<R!E9WD@^FH@86)L86MB86X@=F%L\R!M96=N>6ET
MX7-H;WHN`$AA(-9N($EN=&5R;F5T($5X<&QO<F5R="!H87-Z;N%L+"#I<R!N
M96T@:F5L96YN96L@;65G(&%Z(&EK;VYO:RP@86MK;W(@=N%L87-S>F$@97IT
M(&%Z(&]P8VGS="P@;65L;'EE;"!K:6MA<&-S;VQJ82!A(%!.1R!KZ7!E:R!T
M<F%N<WIP87)E;F-IX6KA="X`2&$@;.%T:F$@97IT(&$@<WKV=F5G970L(&1E
M(&$@:^EP970@;F5M+"!A:VMO<B!B]FYGZ7-Z]7!R;V=R86UJ82!N96T@:^EP
M97,@;65G:F5L96[M=&5N:2!A('-Z97)V97)R92!K_&QD96YD]2!KZ7!E="X`
M16SU>F5T97,@;NEZ970Z`$$@:^EP(%523"UJ90!!(&OI<"!54DPM:F4Z`$UE
M;'EI:R!G86SI<FGA8O-L('9A;B!A(&OI<`!+Z7`@96)B]6P@82!G86SI<FGA
M8O-L.@!+Z7`@9F5L=/9L=.ES90!+Z7!E:P!);7!O<G3A;.%S+"`E9"X@;.EP
MZ7,`07H@:6UP;W)TX6QT(&UE>O4Z("5S`$%Z(&EM<&]R=.%L="!M97KU:SH`
M4V]R(&)E:6QL97-Z=.ES92!E>F%LX0!(:6+A<R!P87)A;F-S<&%R86WI=&5R
M+@!.96T@;65G9F5L96SU(&$@8F5J96QE;G1K97KI<VD@;NEV(.ES+W9A9WD@
M82!J96QS>O,N`$YE;2!M96=F96QE;/4@82!F96QH87-Z;N%L\VD@;NEV('9A
M9WD@87H@86QT97)N873M=B!C[6TN(%!R\V+A;&IA(/IJ<F$@=F%G>2!F;W)D
M=6QJ;VX@82!R96YD<WIE<F=A>F3A:&]Z+"!H82!T;W;A8F)I('-E9^UT<^EG
M<F4@=F%N('-Z_&MSZ6=E+@!"96ME>F3I<R!B96QJ96)B`$EN9&EA`$5G>65S
M(&9E;&AA<WINX6SS:P!);F1O;NEZ:6$`26YF;W)MX6-I\P!);F9O<FWA8VGS
M`$%Z(&EN9F]R;>%C:?,@;>%R(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X`3W-Z
M;&]P(&)E<WKZ<N%S82!E>G5TX6X`2^EP(&)E:6QL97-Z=.ES90!4X6)LX7IA
M="!B96EL;&5S>G3I<V4`3&EN:R!LZ71R96AO>N%S80!/<WIL;W`@8F5S>OIR
MX7-A(&5Z96SI`$]S>FQO<"!B97-Z^G+A<V$@97IU=.%N`$]S>FQO<"!B97-Z
M^G+A<V$@97IE;.D`4V]R(&)E<WKZ<N%S82!E>F%LX0!3;W(@8F5S>OIRX7-A
M(&5F]FSI`$)E:V5Z9.ES(&)E:6QL97-Z=.ES92!E>G5TX6X`0F5K97IDZ7,@
M8F5I;&QE<WITZ7-E(&5Z96SI`$AO>GIU;FL@;.ET<F4@86QT97)N873M=B!S
M86)L;VYT`$%D:F]N(&UE9R!E9WD@96UA:6P@8^UM970L(&UE;'ER92!E;&O\
M;&1H973U(&%Z(-9N(/IJ(&IE;'-Z879A.@!#96QL82!B96EL;&5S>G3I<V4@
M97IU=.%N`$-E;&QA(&)E:6QL97-Z=.ES92!E>F5LZ0!/<WIL;W`@8F5S>OIR
MX7-A(&5Z=73A;@!/<WIL;W`@8F5S>OIRX7-A(&5Z96SI`$QE=F5L96L@8F5M
MX7-O;.%S80!"96ME>F3I<R!B96EL;&5S>G3I<V4@97IU=.%N`$)E:V5Z9.ES
M(&)E:6QL97-Z=.ES92!E>F5LZ0!3;W(@8F5S>OIRX7-A(&5Z86SA`%-O<B!B
M97-Z^G+A<V$@96;V;.D`061J82!M96<@82!K[7;A;G0@=N%L87-Z="!A(&)I
M>G1O;G/A9VD@:^ER9.ES<F4Z`$OI<"!B96EL;&5S>G3I<V4O;?-D;W/M=.%S
M80!,:6YK(&)E:6QL97-Z=.ES92]M\V1O<^UTX7-A`$$@<WKA;6SA:N%N(&YI
M;F-S(&5LZ6<@9F5D97IE="#\>F5N971E="!K_&QD96YI(&$@:_9R;&5VZ6QL
M:7-TX7)A+@!!('-ZX6ULX6KA;B!N:6YC<R!E;.EG(&9E9&5Z970N`$5GZ7-Z
M`$5GZ7-Z('-ZX6UO:R!L:7-TX6IA`$AI8N%S+V5L9F]G861H871A=&QA;B!5
M1$@@*%5S97(@1&%T82!(96%D97(I+@!(:6+A<R]E;&9O9V%D:&%T871L86X@
M6DE0('3V;?9R[73I<P!(:6+A<R]E;&9O9V%D:&%T871L86X@86QK86QM87KA
M<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N(&)A=&-H(&%Z;VYO<^UT\RX`02!K
M_&QD]G1T(&%D870@:&EBX7,O96QF;V=A9&AA=&%T;&%N+@!(:6+A<R]E;&9O
M9V%D:&%T871L86X@8^UM>NES+@!(:6+A<R]E;&9O9V%D:&%T871L86X@9N%J
M;"!F;W)MX71U;0!(:6+A<R]E;&9O9V%D:&%T871L86X@;&EC96YS>FMU;&-S
M+@!(:6+A<R]E;&9O9V%D:&%T871L86X@=N%R;W,N`$AI8N%S+V5L9F]G861H
M871A=&QA;B#\>F5N971T[7!U<RX`2&EBX7,O96QF;V=A9&AA=&%T;&%N('9A
M9WD@:&GA;GEZ\R!P<F]G<F%M;WKA<VEF96S\;&5T+6%Z;VYO<^UT\RX`2&EB
MX7,O96QF;V=A9&AA=&%T;&%N('!A<F%MZ71E<F5K+@!(:6+A<R!A>B!O8FIE
M:W1U;2!E;.ERZ7-I(&IO9V]S=6QT<^%G82X`2&EBX7,O96QF;V=A9&AA=&%T
M;&%N('!A<G1N97)A>F]N;W/M=/,N`$AI8N%S+V5L9F]G861H871A=&QA;B!T
M97)MZ6MK\V0N`$AI8N%S+V5L9F]G861H871A=&QA;B!P<F]T;VMO;&PN`$AI
M8N%S+V5L9F]G861H871A=&QA;B!C[6UZ971T.B`B)7,B`$AI8N%S+V5L9F]G
M861H871A=&QA;B!M96=O<WIT;W1T(&]B:F5K='5M`$AI8N%S+V5L9F]G861H
M871A=&QA;B!F96QA9/-I(&/M;2X`2&EBX7,O96QF;V=A9&AA=&%T;&%N('5N
M:6-O9&4@861A="X`3GEI;';A;G1A<G3A<P!!(&MI:F5L]FSI<R!I;G9E<G3A
M;.%S80!)<N%N:2!)<WILX6T@2_9Z=.%R<V%SX6<`27)A:P#-<F]R<WKA9P!-
M86XM<WII9V5T`%-Z\W)VX6YY;W,@>FEV871A<F]K`$EZ<F%E;`!!('1A;OIS
M[71VX6YY(&MI863S:F$`9/5L=`!/;&%S>F]R<WKA9P!*86UA:6-A`&IA;G7A
M<@!*87#A;@!J87#A;B`H25-/+3(P,C(M2E`I`$IE<G-E>0!*;W)DX6YI80!J
M^FQI=7,`:OIN:75S`%-O<FMI>N%RX7,`:_9ZZ7!R92!R96YD97KI<P!S;W)K
M:7KA<N%S(&UI;F1KZ70@;VQD86QR80!S;W)K:7KA<N%S(&)A;')A`'-O<FMI
M>N%RX7,@:F]B8G)A`$MA>F%H<WITX6X`5&%R='-U:R!M96<@87H@97)E9&5T
M:70_`$ME;GEA`$$@:V5R8F5R;W,@<WIE<G9E<B!E;'5T87/M=&]T=&$@82!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7-T+@!+97ID]2!K97)N96QF96IL97-Z=/5K
M`$MU;&-S(&SI=')E:&]ZX7-A`$$@:W5L8W,@;&5N>6]M871A`$MU;&-S:&]S
M<WKZ<^%G`$MU;&-S('3M<'5S`$$@:W5L8W,@:&%S>F[A;&%T80!!(&MU;&-S
M(&WA<B!LZ71E>FEK(&$@;GEI;';A;F]S(&MU;&-S<WIE<G9E<F5N+@!'>65R
M96ME:P!+:7)I8F%T:0!+;W)E86D@3NEP:2!$96UO:W)A=&EK=7,@2_9Z=.%R
M<V%SX6<`2V]R96%I($OV>G3A<G-A<^%G`&MO<F5A:2`H155#+4M2*0!+=79A
M:70`2VER9VEZ:7-Z=.%N`%]497)V97KI<P!.>65L=@!,86]S>FD@3NEP:2!$
M96UO:W)A=&EK=7,@2_9Z=.%R<V%SX6<`=71O;'/S(&;I;`!!>B!U=&]L<_,@
M:F5L<WKS=N%L=.%S`'5T;VQS\R!N96=Y960`571O;'/S(';A;'1O>G1A=.%S
M.@!5=&]L<_,@8F5J96QE;G1K97KI<SH@)7,`571O;'/S(&)E:F5L96YT:V5Z
MZ7,Z("5S+"`E<R!C[6UR]6P`571O;'/S(&)E:F5L96YT:V5ZZ7,Z(&WI9R!S
M;VAA(&YE;2!V;VQT`$QE='1O<G-ZX6<`2F]G`$5L:&5L>65ZZ7,`2&%G>6IA
M(/QR97-E;BP@:&$@;F5M(&%K87(@:V5R971E=`!,:6)A;F]N`&)A;`!"86P@
M;VQD86QI(&9E:FSI8P!"86P@;VQD86QI(.ER=.EK96L`3&5S;W1H;P!3>FEN
M=`!,:6+I<FEA`$SM8FEA:2!!<F%B(%-Z;V-I86QI<W1A($YA9WD@3NEP:2!+
M]GKV<W/I9P!,:65C:'1E;G-T96EN`$=Y96YG92!S>FETX6SS(&5S]0!'>65N
M9V4@97/U`$3I;&5L]71T(&=Y96YG92!E<_4`1.EL=73A;B]E<W1E(&=Y96YG
M92!E<_4`1WEE;F=E('KA<&]R`$=Y96YG92!Z:79A=&%R`$=Y96YG92!H879A
M>N%S`$=Y96YG92!H\WKA<&]R`$QI;FL`02!L:6YK(&ED92!M=71A=#H`365G
M:F5L96[M=.ES:V]R(&UU=&%S<V]N(&5G>2!L:6YK(&$@;&5VZ6QC[6UR]6P@
M82!L97;I;.UR\R!A8FQA:VAO>@!,:6YK96L`3&EN=7@`3&ES=.%ZX7,@+2!A
M(&9E;&AA<WINX6SS(&SA=&IA(&$@;6%P<.%T`$%Z(&%D871BX7II<V]K(&QI
M<W3A:F$`07IO:VYA:R!A('3I;>%K;F%K(&$@;&ES=.%J82!A;6ER]6P@<V5G
M[71SZ6<@:V%P:&%T\P!!>B!A9&%T=.%B;.%K(&QI<W3A:F$`3&ES=&$@87)C
M:.UV=6T`3&ES=&$@<V5G[71SZ6=KZ7+I<P!,:7-T82!A>F]N;W/M=/,`3&ES
M=&$@='5L86ID;VYO<P!,:7-T82!L97;I;.URX7,`3&ES=&$@9F5L:7)A=&MO
M>N%S("AS=6)S8W)I8F4I`$QI<W1A(&QE:7)A=&MO>N%S("AU;G-U8G-C<FEB
M92D`02!F96QH87-Z;N%L\VMA<&-S;VQA=&]K(&MI;&ES=.%ZX7-A(&YE;2!S
M:6ME<OQL=#H@)7,`02!F96QH87-Z;N%L\VL@:VEL:7-TX7KA<V$@;F5M('-I
M:V5R_&QT.B`E<P!!(&9E;&AA<WINX6SS:R!K:6QI<W3A>N%S82!T:6QT=F$@
M=F%N+@!)<F]D86QO;0!,:71VX6YI80!,973V;'3I<RXN+@!(96QY:2!I9/4Z
M(`!.>65L=BP@9.%T=6TL(&ED]0!(96QY`$)E:F5L96YT:V5ZZ7,`07H@96SU
M>O4@861A='-Z:6YK<F]N:7KA8VGS(&YA<&SSX6QL;VWA;GEA`$MI:F5L96YT
M:V5ZZ7,`0F5J96QE;G1K97KI<P!"96IE;&5N=&ME>NES<V5L(&MA<&-S;VQA
M=&]S(&9E;&%D871O:P!!(&)E:F5L96YT:V5ZZ7,@;F5M('-I:V5R_&QT+"!M
M97)T(')O<W-Z(&9E;&AA<WINX6SS;F5V970@=F%G>2!J96QS>O-T(&%D;W1T
M(&UE9RX`02!B96IE;&5N=&ME>NES(&YE;2!S:6ME<OQL="X`2&]S<WKZ('-Z
M]G9E9P!3>F5R96QE;0!A;&%C<V]N>0!G]G+V9R!K:7-B973[:P!L871I;B!K
M:7-B973[:P!K:7-B973[<R!R\VUA:2!S>N%M;VL`3'5X96UB=7)G`$U-`$YA
M<&D@_'IE;F5T96L`07H@35,M5$Y%1B!M96QLZ6ML971B96X@;FEN8W,@861A
M="X`W%I%3D54`$UA:V'S`$UA:V5D\VYI80!-861A9V%S>FOA<@!687+A>G-L
M870`3&5V96QE>NES`$5M86EL(&1O;6%I;B!K97IE;.ES`$QI;FL@:^ES>NUT
MZ7-E`$UA;&%W:0!-86QA:GII80!-86QD[78M<WII9V5T96L`36%L:0!-X6QT
M80!!9&%T86ET(&MA=&5G\W)IX6MB82!S;W)O;&AA=&IA+B!%>F5K(&ET="!D
M969I;FGA;&AA=/-K+"!M\V1O<^UT:&%T\VLL('1O=N%B8N$@<WKM;F5K(')E
M;F1E;&AE=/5K(&AO>GKA:G5K+@!-87`R-"!TZ7)KZ7``36%P475E<W0@=.ER
M:^EP`$$@:&]Z>N%R96YD96SI<V5K970@96QM96YT971T_&LN`&WA<F-I=7,`
M36%R9_,`07H@3VQV87-O='0O3VQV87-A=&QA;B!J96QZ971E:R!H87-Z;N%L
M871A`$WA<R!J96QZ971E:R`H<&PN($9O;G1O<R]-96=VX6QA<WIO;'0I(&AA
M<WINX6QA=&$`36%R<VAA;&PM<WII9V5T96L`36%R=&EN:7%U90!%9WEMX7-N
M86L@;65G9F5L96SU(&UE>O5K`$UA=7)I=.%N:6$`36%U<FET:75S`$UA>&EM
MX6QI<R!R96YD96QK97KI<W)E(.%L;/,@<WKA;6QA]G-S>F5G+@!!>B#\>F5N
M970@=/IL('-O:R!RZ7-Z8O5L(.%L;"X`07H@96QM^FQT(#(T(/-R82!M87AI
M;>%L:7,@:/5MZ7)SZ6ML971E.B``07H@96QM^FQT(#8@\W)A(&UA>&EMX6QI
M<R!H]6WI<G/I:VQE=&4Z(`!!>B#V<W-Z96?U;VQD86P@8FQO:VMJ86EN86L@
M;6%X:6WA;&ES('-ZX6UA`$UA>&EMX6QI<R!H;W-S>@!MX6IU<P!-87EO='1E
M`$]R=F]S='5D;VWA;GD`5&%G;VL`02!M96[\(&UE9VIE;&5NZ7-E.@!#96QL
MX6L@96=Y8F5O;'9A<WITX7-A`-QZ96YE=`!!(&1I9VETX6QI<V%N(&%LX>UR
M="#\>F5N970@:&ET96QE<RP@9&4@87H@86SA[7+S('1A;OIS[71VX6YYX70@
M;F5M('-I:V5R_&QT(&5L;&5N]7)I>FYI+@!,96KA<G0@87H@_'IE;F5T(.ER
M=NEN>65S<^EG92X`07H@_'IE;F5T('3M<'5S80!-971A<B!I9/5JX7+A<VIE
M;&5N=.ES`$$@365T87(@8FQO:VL@;F5M(.%L;"!R96YD96QK97KI<W)E+@!!
M($UE=&%R(&)L;VMK(&YE;2#A;&P@<F5N9&5L:V5ZZ7-R92X@02!RZ7-Z;&5T
M96L@82!R96YD<WIE<F=A>F1A('-ZX6WA<F$@:^ES>OQL]2!N87!L\V;A:FQB
M82!K97+\;'1E:RX`02!-971A<D1"(&YE;2#I<FAE=/4@96PN`$WS9'-Z97(`
M02AZ*2`B)7,B(&WS9'-Z97(@9&5F:6YIX6QA=&QA;@!!(&WS9'-Z97(@9&5F
M:6YIX6QA=&QA;BX@02!M96=H[79O='0@;?-D<WIE<CH@)7,`365T<FEK=7,`
M365X:6OS`$UI:W)O;NEZ:6%I(%-Z]G9E='/I9VD@P6QL86UO:P!K]GKI<`!-
M24U%('3M<'5S`$%Z(&5L;?IL="`R-"#S<F$@;&5G86QA8W-O;GEA8F(@:/5M
MZ7)SZ6ML971E.B``07H@96QM^FQT(#8@\W)A(&QE9V%L86-S;VYY86)B(&CU
M;>ER<^EK;&5T93H@`$WI9R!N96T@=&5L="!E;"!A(&UI;FEMX6QI<R!I9/4@
M82!J96QS>O,@;65G=N%L=&]Z=&%TX7/A:&]Z`%3\:W+V>NES("AJ;V)B+V)A
M;"D`5F5G>65S`$AIX6YY>FEK(&$@2%144%]297%U97-T(%!%05(@8W-O;6%G
M+@!+;VYF:6=U<N%C:?,@<WK\:W/I9V5S+B!%>G0@;6]S="!K96QL(&SI=')E
M:&]Z;FEA+"!H82!H87-Z;N%L;FD@86MA<FIA(&%Z(&%L:V%L;6%ZX7-T+@!(
M:>%N>7II:R!A>B#\>F5N970@87IO;F]S[73S:F$N`$AIX6YY>FEK(&$@36%I
M;"!014%2(&-S;VUA9RX`2&GA;GEZ:6L@82!F96QH87-Z;N%L\VMA<&-S;VQA
M="!A>F]N;W/M=/-J82`H<V5S<VEO;B!)1"DN`$CI`$QE=F5L97KI<R!M;V)I
M;'1E;&5F;VYR\VP`2_9Z97!E<P!!(&WS9&]S[73A<R!DX71U;6$`07H@55),
M(&WS9&]S[73A<V$`36]D=6QU<P!-;VQD;W9A:2!+]GITX7)S87/A9P!-;VYA
M8V\`36]N9_-L:6$`2/-N87`@Z7,@Z78`:&%V;VYT80!-;VYT<V5R<F%T`$AO
M;&1FX7II<V]K`$$@)60N('-O<F)A;B!T]F)B(&UE>O4@=F]L="P@;6EN="!A
M(';A<G0@)60N`$UA<F]K:_,`5/9B8FYY:7)E(&1E<OQL=`!4]F)B;GEI<F4@
M8F]R=6QT`%3V8F)N>6ER92!N87!O<P!V:6=Y_&L@;&4`=FEG>?QK(&)A;')A
M`'9I9WG\:R!J;V)B<F$`=FEG>?QK(&;V;`!V:6=Y_&L@;&4`=FEG>?QK(&;V
M;`!-;WIA;6)I:P!4]F)B<WII;G3[(&QE9_9R9/QL]2!L:7-TX6L`375L=&EM
M87`@3F%G>2U"<FET86YN:6$@=.ER:^EP`%3V8F)S>O9R]G,@=N%L87-Z=.%S
M`$)E:F5L96YT:V5ZZ7-I(&)EX6QL[73A<V]K`$)E:F5L96YT:V5ZZ7-I(&%D
M871A:6T`4V%JX70@]G-S>F5G>O4@;VQD86QA;0!386KA="#V<W-Z96=Z]2!O
M;&1A;&%M('1E<G9E>NES90!-:6%N;6%R`$Y%32P@;F5M(&5G>65Z96T@8F5L
M92X`3NEV`$YA;>UB:6$`3F%U<G4`3F5PX6P`2&]L;&%N9&EA`$AO;&QA;F0@
M06YT:6QLX6L`3F5T<V-A<&4@8N%Z:7,M55),`$YE='-C87!E('1A;OIS[71V
MX6YY:VEA9.%S:6IO9RA#02DM=FES<WIA=F]NX7-I(%523`!.971S8V%P92!T
M86[Z<^UT=N%N>69E;&AA<WINX6SA<VD@:7+A;GEE;'8@55),`$YE='-C87!E
M('1A;OIS[71VX6YY;65G^FKM=.%S:2!54DP`3F5T<V-A<&4@=&%N^G/M=';A
M;GEV:7-S>F%V;V[A<VD@55),`$YE='-C87!E(%-33"!S>F5R=F5R;NEV`$YE
M='-C87!E('1A;OIS[71VX6YY(&UE9VIE9WEZZ7,`3F5T<V-A<&4@=&%N^G/M
M=';A;GET[7!U<P!(X6SS>F%T`'-O:&$`VFHM2V%L963S;FEA`-IJ(&MA=&5G
M\W)I80#::B!L97;I;"`E<R!C[6UR90#Z:FAO;&0`VFH@9F5L:&%S>F[A;/-N
MZ78@*&]P8VEO;N%L:7,I`-IJ+5KI;&%N9`#::B!J96QS>O,`07H@^FH@:F5L
M<WKS(.ER=NEN>65S<^EG92!E:VMO<B!JX7(@;&4Z("5X+@!!(&UE9V%D;W1T
M(/IJ(&IE;'-Z879A:R!N96T@96=Y97IN96LN`-IJ(&%B;&%K("C\<F5S*0!(
M[7)E:P!([7)C<V]P;W)T;VL`2_9V971K97KU`$OV=F5T:V5Z]2`T(&;A>FES
M`$OV=F5T:V5Z]2!O<&-I\VL`2_9V971K97KU/@!.:6-A<F%G=6$`3FEG97(`
M3FEGZ7)I80#I:G-Z86MA`$YI=64`3F5M`$YI;F-S(')E;F1E;&ME>NES<F4@
MX6QL\R!K;VYF:6=U<N%C:?,L(&%M:6AE>B!KZ7!E<W0@82!K_&SV;F)SZ6=E
M:V5T(&UE9R!L96AE=&YE(&UU=&%T;FDN`$YI;F-S(&QE:&5T]7/I9R!)4T\@
MX6QL;VWA;GEO:R!LZ71R96AO>N%SX7)A+@!(:>%N>7II:R!A(&OV=&5G96QT
M(&9E;&1O;&=O>N%S:&]Z('-Z_&MSZ6=E<R!M:6YT82`H8F%T8V@@=&5M<&QA
M=&4I+@!!(&OM=N%N="!H96QY96X@;FEN8W,@8FQO:VL`07H@34-!3"!F96QH
M87-Z;N%L\V%Z;VYO<^UTX7-H;WH@;FEN8W,@;65G861V82!A(&YA<'3A<B!N
M979E+@!.:6YC<R!VX6QT;WKA<RX`16AH97H@82!J;V=O<W5L='/A9VAO>B!N
M96T@:&]Z:&%T\R!LZ71R92!J;V=O<W5L='/A9VD@86QC<V]P;W)T+@!(:>%N
M>6]Z;F%K(&$@:V]N9FEG=7+A8VGS<R!A9&%T;VL@)7,M:&5Z+@!!>B!&5%`@
M5D93(&YI;F-S(&MO;F9I9W5RX6QV82X`07H@4U%,(%9&4R!N:6YC<R!K;VYF
M:6=U<N%L=F$N`$%Z(%-13"U&:6QE(%9&4R!N:6YC<R!K;VYF:6=U<N%L=F$N
M`$%Z(-9N('-ZX6ULX6KA;B!E;&9O9WEO='0@82!R96YD96QK97KI<W)E(.%L
M;/,@]G-S>F5G+@!.:6YC<R!C[6UZZ7,N`$$@<WIE<G9E<G)E(&YE;2!T]FQT
M]63V='0@9F5L('-E;6UI;'EE;B#A;&QO;>%N>0!!>B!I:V]N;VL@;F5M('1A
M;.%L:&%T\VLN`$YI;F-S(&UE9V%D=F$@82!H96QY+@!.:6YC<R!M96=A9'9A
M(&$@:&5L>2X`07H@_'IE;F5T(/QR97,N`$YI;F-S(&UE9V%D=F$@82!NZ78N
M`$YI;F-S(&UE9V%D=F$@82!S>N%M+@!.92!L96=Y96X@;65G8F]T<N%N:V]Z
M=&%T\R!I9.EZ970`3FEN8W,@:F5L<WKS(&UE9V%D=F$@82!(5%10(&%L87#Z
M(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G
M861V82!A>B!)34%0(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z
M+@!.:6YC<R!J96QS>O,@;65G861V82!A($ME<F)E<F]S(&%L87#Z(&9E;&AA
M<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!J96QS>O,@;65G861V82!A
M($QO9VEN(&%L87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC
M<R!J96QS>O,@;65G861V82!A(%!!4U-71"!A;&%P^B!F96QH87-Z;N%L\VD@
M87IO;F]S[73A<VAO>BX`3FEN8W,@:F5L<WKS(&UE9V%D=F$@87H@4TU"(&%L
M87#Z(&9E;&AA<WINX6SS:2!A>F]N;W/M=.%S:&]Z+@!.:6YC<R!M96=A9'9A
M(&%Z($]P96Y34TP@<')O9W)A;2!E;.ERZ7-I(/IT=F]N86QA+B!!>B!/<&5N
M4U-,('!R;V=R86T@<WK\:W/I9V5S(&$@4$M#4R`Q,B!A9&%T;VL@:V5Z96SI
M<^EH97HN`$YI;F-S(/IJ(&)E:F5L96YT:V5ZZ7-I(&EGZ6YY+@!.:6YC<R!K
M=O-T82!B9>%L;.UT=F$N`$YE(&QE9WEE;F5K('9O;F%L86L@<V5H;VPN`$YI
M;F-S(&1E9FEN:>%L=F$@96QVX6QA<WIT\R!K87)A:W1E<BX`3F4@;&5G>65N
M(&ME<F5T`$YI;F-S(&EL>65N(&;A:FP`3FEN8W,@:61E:6=L96YE<R#A;&QO
M;>%N>6]K('3A<F]LX7/A<F$@<WIO;&?A;/,@86QK]FYY=G3A<BX`2&GA;GEZ
M:6L@82!F96QH87-Z;N%L\V[I=B#I<R]V86=Y(&$@:F5L<WKS+@!!('9I<W-Z
M86MA<&]T="!A9&%T;VL@;F5M(.ER=NEN>65S(%A-3"!A9&%T;VL`3FEN8W,@
M861A=`!.:6YC<R!MZ6<@:V]N9FEG=7+A8VGS+"!G96YE<N%L:F]N(&5G>65T
M+@!.:6YC<R!MZ6<@:V]N9FEG=7+A8VGS:F$L(&=E;F5RX6QJ;VX@96=Y970N
M`&YI;F-S`&YI;F-S(&UE9V%D=F$@*&QE9WEE;B!A;&%PZ7)T96QM97IE='0I
M`&YO<F1I:W5S("A)4T\M.#@U.2TQ,"D`3F]R9F]L:RUS>FEG970`R7-Z86MI
M(&;I;'1E:V4`R7-Z86MI+4UA<FEA;F$M<WII9V5T96L`3F]R=NEG:6$`3F5M
M(&OI<_5B8@!.96T@:V]RX6)B86X`3F5M(&%L:_9N>79TX7(`02!P<F]G<F%M
M;F%K(&5Z(&$@<NES>F4@;>EG(&YI;F-S(&UE9W9A;/-S[71V82X`3FEN8W,@
M8F7A;&SM='9A`$YE;2!TX6UO9V%T;W1T+@!&96QJ96=Y>NES96L`3FEN8W,@
M8O9N9^ES>FAE=/4@861A="P@=.ER:F5N('9I<W-Z82X`;F]V96UB97(`4WKA
M;0!+87)A:W1E<F5K('-ZX6UA`$]S>FQO<&]K('-ZX6UA`%-O<F]K('-ZX6UA
M`$$@:_9R;&5VZ6QL:7-T82!M\V1O<^UTX7/A:&]Z(&YE;2!A9&]T="!M96<@
M<WKA;6]K870N`$]+`$]B:F5K='5M`$%Z(&]B:F5K='5M(&SI=')E:&]Z\VIA
M`$]K=.%L:7,@<WKA;0!O:W3S8F5R`%-Z^W+I<P!(:79A=&%L+VUU;FMA:&5L
M>0!!('+I9VD@Z7,@87H@^FH@:F5L<WKS;F%K(&O\;/9N8O9Z;FEE(&ME;&PN
M`$$@<NEG:2!J96QS>O,`02!RZ6=I(&IE;'-Z\R!N96T@;65G9F5L96SU+@!/
M;>%N`$-S86L@87H@24U!4"!S>F5R=F5R96L@=.%M;V=A=&KA:R!A(&UA<'#A
M:R!M96=O<WITX7/A="X`0W-A:R!M96=B;W1RX6YK;WIT873S(&EDZ7IE="!L
M96=Y96X`0W-A:R!E9WD@96UA:6P@8^UM(&%D:&%T\R!M96<N`$-S86L@82!T
M=6QA:F1O;F]S('9A9WD@82!R96YD<WIE<F=A>F1A(';A;'1O>G1A=&AA=&IA
M(&UE9R!E9WD@:_9Z]G,@=.%R=&5R_&QE="!T=6QA:F1O;F]SX70@=F%G>2!E
M;.ERZ7-I(&IO9V]S=6QT<^%G86ET`$YY:7-S=6L@;65G(/IJ(&%B;&%K8F%N
M`$]P96Y34TP@:&EB83H@3F5M('-I:V5R_&QT(&MI;GEE<FYI(&%Z(&%D871O
M:V%T(&%Z(&%LX>UR="!3+TU)344@<NES>F+U;`!.>6ES<W5K(&UE9R!E>G0@
M82!C[6UE="!E9WD@^FH@86)L86MB86X`3W!E<N%C:?-S(')E;F1S>F5R`$]P
M8VGS:P`E<R!B9>%L;.UTX7-A:0!3;W)S>N%M;W,@9F5L<V]R;VSA<P!3>F5R
M=F5Z970`4WIE<G9E>F5T:2!E9WESZ6<`375N:V%S>F5R=F5ZZ7,`07H@86QK
M86QM87KA<R!E<F5D971I('-A8FQO;FIA`"5S(&5R961E=&D@<V%B;&]N:F%I
M.@!%9WGI8@!%9WGI8B!I;F9O<FWA8VGS`$$@='5L86ID;VYO<R!J;V=O<W5L
M='/A9V%I`$$@4$%-(&9E;&AA<WINX6SS87IO;F]S[73A<R!N96T@X6QL(')E
M;F1E;&ME>NES<F4N`%!%05(Z.DUA:6P@86QR96YD<WIE<@!01U`@9&EG:73A
M;&ES(&%LX>URX7,`4$=0+79E;"!T:71K;W/M=&]T="!A9&%T`%!'4"!N>6EL
M=N%N;W,@:W5L8W,`4$=0+79E;"!A;.'M<G0O=&ET:V]S[71O='0@861A=`!0
M2%`@:_-D`$3I;'5TX6XO97-T92!G>65N9V4@97/U`$3I;'5TX6X@97/U`$3I
M;'5TX6XO97-T92!ZX7!O<F]K`$3I;'5TX6XO97-T92!H879A>N%S`$3I;'5T
MX6XO97-T92!H\WKA<&]R;VL`1.EL=73A;B!N87!S_'3I<P!$Z6QU=.%N+V5S
M=&4@>FEV871A<F]K`$AIX6YY>FEK(&$@4$]325@@8O5V[73I<P!B96QS]2!M
M87)G\P!086MI<WITX6X`4&%L874`4&%L97-Z=&EN(%1E<OQL970@*&UE9W-Z
MX6QL="D`4&%N86UA`%#A<'5A(-IJ+4=U:6YE80!087)A9W5A>0!-Z7)SZ6ME
M;'1E;B!B;W)U;'0`2F5L<WKS`$$@:F5L<WKS="!S:6ME<F5S96X@;65G=N%L
M=&]Z=&%T='5K+@!.96T@;65G9F5L96SU(&IE;'-Z\P!!(%)!1$E54R!F96QH
M87-Z;N%L\V%Z;VYO<^UTX7-H;WH@:F5L<WKS('-Z_&MSZ6=E<RX`2F5L<WKS
M(&UE9V5R]7/M=.ES<V5L`$IE;'-Z\SH`2F5L<WKS.B``02!J96QS>F%V86MN
M86L@96=Y97IN:?QK(&ME;&PN`$)E:6QL97-Z=.ES`$)E:6QL97-Z=.%S(&$@
M=N%G\V%S>G1A;'+S;`#:='9O;F%L`-IJ(&9E;&AA<WINX6SS;F%K(&)E:F5L
M96YT:V5Z971T96LZ`$5M8F5R96L`<WKA>F%LZ6L`2V%R8F%N=&%R=.%S:2!F
M96QA9&%T;VL@=NEG<F5H86ITX7-A`$)E:F5L96YT:V5ZZ7-K;W(@:&%J='-U
M:R!VZ6=R92!A(&MA<F)A;G1A<G3A<VD@9F5L861A=&]K870_`$IO9V]S=6QT
M<^%G`$$H>BD@(B5S(B!J;V=O<W5L='/A9V]T(&YE;2!T]G+V;'3\:RX`UFYN
M96L@;FEN8W,@96AH97H@96QE9V5N9/4@:F]G;W-U;'1SX6=A`$IO9V]S=6QT
M<^%G;VL`2F]G;W-U;'1SX6<@861M:6YI<WIT<N%C:?,`4WIE;>EL>65S(&%D
M871O:P!097)U`,%L;&%T:V5D=F5N8V5K`$;\;/9P+7-Z:6=E=&5K`%1E;&5F
M;VX`1NEN>6OI<&=A;.ER:6$`4&ET8V%I<FX`<&EX96P`2_9Z:&5L>65K`$MA
M='1I;G1S;VX@=F%L86UE;'EI:R!C96QLX7)A`$)I>G1O<V%N('3V<O9L;FD@
M86MA<FIA(&5Z="!A>B!E;&5M970Z`$OI<F5M(&5R]7/M='-E(&UE9RP@:&]G
M>2!V86SS8F%N('3V<O9L;FD@:^UVX6YJ82!E>G0@87H@96QE;65T+@!+Z7)E
M;2!A9&IO;B!M96<@96=Y(&CS;F%P;W0@Z7,@96=Y(.EV970N`$OI<F5M(&%D
M:F$@;65G(&%Z(/IJ(&MA=&5G\W)I82!N97;I=#H`2^ER96T@=F%L\W,@25`@
M8^UM970@861J;VX@;65G+@!+Z7)E;2!V86SS<R!DX71U;6]T(&%D:F]N(&UE
M9RP@96QL96[U<FEZ>F4@82!H\VYA<"!N87!J86ET+@!+Z7)E;2!V86SS<R!D
MX71U;6]T(&%D:F]N(&UE9RX`2^ER96T@<O9V:61E;B#M<FIA(&QE(&$@<')O
M8FSI;6$@;.EN>65GZ70N`$OI<F5M(&%D:F$@;65G(&$@8F5J96QE;G1K97KI
M<VD@;F5VZ70@Z7,@:F5L<WIA=N%T`$OI<F5M(&]L=F%S<V$@96P@82!K]G9E
M=&ME>O4@<WKV=F5G970N($$@<F5N9'-Z97(@:&%S>F[A;&%TX6YA:R!F96QT
MZ71E;&5I="!E;"!+14Q,(&9O9V%D;FEA+@!+Z7)E;2!A9&IA(&UE9R!A>B#Z
M:B!K871E9_-R:6$@;F5VZ70Z`$QE;F=Y96QO<G-ZX6<`4&]L:71I:V$`4WIA
M=F%ZX7-O:P!0;W)T=6?A;&EA`$$@:^EP(&5L:&5L>65ZZ7-E`$$@=.%B;.%Z
M870@96QH96QY97KI<V4`2_9Z=F5T;&5N(&QE=NEL:_QL9.ES(&5B8F4@82!M
M87!PX6)A("A)34%0(&YE;2!M:6YD:6<@=F5S>FD@9FEG>65L96UB92D`07H@
M96QM^FQT("5S(/-R82!C<V%P863I:VUE;FYY:7/I9V4Z(`!#<V%P863I:SQB
M<B`O/G9A;/-S>NUN^W/I9P!0<F5F<U]L9&%P.B!N96T@=&%LX6QH873S(&$@
M<WK\:W/I9V5S($Q$05`@:VET97)J97-Z=.ES+@!0<F5F<U]S97-S:6]N.B!N
M96T@=&%LX6QH873S(&$@<WK\:W/I9V5S("AS97-S:6]N*2!K:71E<FIE<WIT
MZ7,N`$SI9VYY;VWA<P!!('1E;F=E<G-Z:6YT;F5K(&UE9V9E;&5L]2!LZ6=N
M>6]MX7,Z(`!,Z6=N>6]MX7,Z(`!%;/5Z971E<R!M96=T96MI;G3I<P!!(&OI
M<"!E;/5Z971E<R!M96=T96MI;G3I<V4@^FH@86)L86MB86X`16SU>O4@;W!C
M:?-K`$$@9&]K=6UE;G1U;2!K:6YY;VUT873A<V$`5&ET:V]S(&MU;&-S`$AI
M8F%B96IE;&5N=.ES`$$@:&EB82!L9>URX7-A`%!R;VIE:W0@:V5Z96SI<P!!
M('!R;VUP="!S>O9V96=E`$YY:6QVX6YO<R!K=6QC<P!.>6EL=N%N;W,@:W5L
M8W/Z(&%L9V]R:71M=7,`3GEI;';A;F]S(&MU;&-S(&EN9F]R;>%C:?,`02!N
M>6EL=N%N;W,O=&ET:V]S(&MU;&-S<.%R="!N96T@<VEK97+\;'0@;.ET<F5H
M;WIN:2X`4'5E<G1O(%)I8V\`02!L979E;&5K(';I9VQE9V5S('3V<FSI<V4`
M2V%T87(`2V5R97/U+W!A<F%N8W,@<W1R:6YG`$MV\W1A`%)302!N>6EL=N%N
M;W,@:W5L8W,@*"5D(&)I=&5S*0!2X61I\V=O;6)O<R!K:7;A;&%S>G3A<P!%
M<_4`17/U(&3I;&5L]71T`$5S]2!DZ6QU=.%N+V5S=&4`6N%P;W(`17/U(.ES
M(&AA=F%ZX7,`2&%V87-E<_4`5NEL971L96X@:63I>F5T`$%RX6YY`$]L=F%S
MX7,`3&5V96QE:R!O;'9A<^%S80!4Z6YY;&5G('3V<O9L:OQK("5S(&9E;&AA
M<WINX6SS=#\@17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R!V:7-S
M>F$N`%3I;GEL96<@=/9R]FQJ_&L@)7,@9F5L:&%S>F[A;/,@861A=&%I=#\@
M17H@82!VX6QT;WIT873A<R!N96T@9F]R9.UT:&%T\R!V:7-S>F$N`-IJ<F$@
M=NEG<F5H86IT:F$@87H@=71O;'/S(';A;'1O>G1A=.%S=`!&<FES<^UTZ7,`
M02!M96[\(&1I;F%M:6MU<R!E;&5M96EN96L@9G)I<W/M=.ES:2!G>6%K;W)I
M<^%G83H`07H@]G-S>F5G>O5O;&1A;"!F<FES<^UTZ7/I;F5K(&=Y86MO<FES
MX6=A.@!/8FIE:W1U;2!B]FYGZ7-Z]0!&<FES<^UTZ7,`365G:F5G>7KI<V5K
M`%3A=F]L:2!S>F5R=F5R96L`02!TX79O;&D@55),("AP;"X@:'1T<#HO+W=W
M=RYV86QA;6DN:'4O;65G=F%L86UI*3H`5/9R;.ES`$)L;VMK('3V<FSI<V4`
M3W-Z;&]P('3V<FSI<V4`02!F;W)M871TX6SA<R!T]G)LZ7-E`$$@<.%R('3V
M<FSI<V4`5/9R]FQJ_&L@87H@96QM96YT971T('!R;V=R86UO="!A('-Z97)V
M97(@:61E:6=L96YE<R#A;&QO;>%N>6]K870@=&%R=&%L;6%Z\R!A;&OV;GEV
M=.%RX6+S;"X`5F5G>?QK(&MI(`!696=Y_&L@:VD@97IT(&$@<NES>G0@82!D
M;VMU;65N='5M8O-L`$$@9F5L:&%S>F[A;/,@=/9R;.ES90`E<R!F96QH87-Z
M;N%L\R!T]G)LZ7-E`$$@:^ERZ7,@;F5M('1E;&IE<^UT:&5T]2X@02!K87!O
M='0@:&EB86OS9#H@`$$@:V5R97-E='0@<WIO;&?A;'1A=.%S(&YE;2!T86SA
M;&AA=/,N`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P
M96P@)7,@:V]N9FEG=7+A8VGS:N%B86XN`$$@:_9T96QE>O5E;B!M96=A9&%N
M9/,@(B5S(B!N96T@<WIE<F5P96P@82!61E,@:V]N9FEG=7+A8VGS:N%B86XN
M`$$@:_9T96QE>O5E;B!M96=A9&%N9/,@(B5S(B!N96T@<WIE<F5P96P@82!K
M;VYF:6=U<N%C:?-B86XN`%-Z_&MSZ6=E<R!M97KU`%)E<V5T`$$@:F5L<WKS
M(.%TX6QL[73A<V$`07H@UFX@:F5L<WIA=N%N86L@X73A;&SM=.%S80!!>B!U
M=&]L<_,@:V5R97/I<R!V:7-S>F'A;&SM=.%S80!%<F5D;>EN>0!6:7-S>F$@
M87H@;W!C:?-K:&]Z`$%Z(/IJ(&IE;'-Z\W0@[7)J82!B92!I<VWI=`!2Z75N
M:6]N`,%L;.UT<W5K('9I<W-Z82!A(&MO;F9I9W5RX6-I\W0`4FEC:"!497AT
M($5D:71O<B!O<&-I\VL`5&%LX6SS<R!KZ7)DZ7-E:P!J;V)B`$IO8F(@;VQD
M86QI(&9E:FSI8P!*;V)B(&]L9&%L:2#I<G3I:V5K`%-O<B!T=6QA:F1O;G/A
M9V]K+BXN`%-Z97)E<`!2;VWA;FEA`$9O<F=A=.%S(#$X,"!F;VMK86P`0F%L
M<F$@9F]R9V%TX7,`2F]B8G)A(&9O<F=A=.%S`%-O<B!T=6QA:F1O;G/A9V]K
M`%-O<B!T=6QA:F1O;G/A9V]K`%-O<F]K.@!6;VYA;&%K`$UI;F1E;B!S;W(@
MZ7,@;W-Z;&]P(&OV>O9T="!L96=Y96X@=F]N86P`0W-A:R!A>B!O<WIL;W!O
M:R!K]GKV='0@;&5G>65N('9O;F%L`$-S86L@82!S;W)O:R!K]GKV='0@;&5G
M>65N('9O;F%L`$9U='1A=.%S`$]R;W-Z($;V9&5RX6-I\P!2=6%N9&$`4R]-
M24U%(&1I9VETX6QI<R!A;.'M<N%S`%,O34E-12!S>F%B=N%N>2!S>F5R:6YT
M('1I=&MO<^UT;W1T(&QE=NEL`%-!4TP@9F5L:&%S>F[A;/-A>F]N;W/M=.%S
M(&YE;2!T86SA;&AA=/,N`%--4R!K_&QDZ7,`4U%,('!A<F%N8W,@82!K97)E
M<^ES:&5Z`%-32`!324M%4MQ,5`!3>F\`4WIE;G0@26QO;F$M<WII9V5T`%-A
M:6YT($MI='1S(.ES($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92#I
M<R!-:7%U96QO;@!386EN="!6:6YC96YT(.ES($=R96YA9&EN92US>FEG971E
M:P!59WEA;F%Z(&$@9G)A;64@*%]S96QF*0!3>F%M;V$`4V%N($UA<FEN;P!3
M86\@5&]MZ2#I<R!0<NUN8VEP90!-^VAO;&1A<R!I;G1E<FYE=&5LZ7+I<P!3
M>F'Z9"U!<N%B:6$`365N=.ES`"(E<R(@;65N=.ES90`E<R!M96YTZ7-E`$$@
M8F7A;&SM=.%S;VL@;65N=.ES90!-96YT<_QK(&5L(&%Z(&5L:^ES>OQL="!K
M;VYF:6=U<N%C:?-T(%!(4"!P<F]G<F%M(&9O<FWA:N%B86X@82!S>F5R=F5R
M(&ED96EG;&5N97,@X6QL;VWA;GEO:V%T('1A<G1A;&UA>O,@86QK]FYY=G3A
M<N%B86XN`"5S(&MO;F9I9W5RX6-I\VKA="!E;&UE;G1E='3\:RX`16QM96YT
M971T_&L@82!S971U<"!U<&=R861E('!R;V=R86UO="!I9&4Z("(E<R(`4WKS
M<G;A;GEO<R!Z:79A=&%R;VL`5'5D;VWA;GD`2V5R97/I<P!+97)E<^ES:2!S
M>F]L9^%L=&%TX7-O:P#!;&QO;>%N>6]K(&MI=N%L87-Z=.%S80!6X6QA<W-Z
M;VX@:VD@96=Y(&3A='5M;W0`365L>6EK(&-S;W!O<G1O="!K[7;A;FIA(&AO
M>GKA861N:0!6X6QA<W-Z82!K:2!A>B#Z:B!T=6QA:F1O;F]S=`!6X6QA<W-Z
M;VX@<WIE<G9E<G0`365L>6EK(&9E;&AA<WINX6SS="!K[7;A;FIA(&AO>GKA
M861N:0!-:6YD970@:VEJ96SV;&K\:P!6X6QA<W-Z82!K:2!A>B#V<W-Z97,@
M9.%T=6WV<W-Z971E=O5T+@!6X6QA<W-Z;VX@96=Y(&]B:F5K='5M;W0`16=Y
M('-E(&QE9WEE;B!K:6IE;/9L=F4`5N%L87-S>F$@:VD@82!K[7;A;G0@:V%R
M86MT97(H96ME*70@87H@86SA8F)I(&QE:&5T]7/I9V5K(&OV>OQL+B!%>G5T
MX6X@(F-O<'DO<&%S=&4B(&WS9'-Z97)R96P@82!M96=F96QE;/4@:&5L>7)E
M(&WA<V]L:&%T:F$@]6ME="X`5N%L87-S>F$@:VD@82!DX71U;65L=N%L87-Z
M=/,@:V%R86MT97)T.@!6X6QA<W-Z82!K:2!A(&3A='5M(&9O<FWA='5MX70Z
M`%;A;&%S<WIA(&MI+"!M96QY:6L@87IO;F]S[73S:N%T(&OM=N%N:F$@;65G
M=N%L=&]Z=&%T;FDZ`%;A;&%S<WIA(&MI(&%Z(&ED]65L=N%L87-Z=/,@:V%R
M86MT97)T.@!6X6QA<W-Z82!K:2!A>B!I9/4@9F]R;>%T=6WA=#H`5N%L87-S
M>F]N(&MI(&OI="!E9WEMX7-N86L@;65G9F5L96SU(&UE>O5T+@!6X6QA<W-Z
M82!K:2!A(&OM=N%N="!S>NUN96=Y_'1T97-T+@!6X6QA<W-Z82!K:2!A>B#6
M;FYE:R!M96=F96QE;/4@;GEE;'9E=#H`2&EB86IE;&5N=.ES(&O\;&3I<V4`
M4TU3(&O\;&3I<V4`4WIE;F5GX6P`4WIE;GIO<CH@`'-Z97!T96UB97(`4WIE
M<F)I82#I<R!-;VYT96YE9W+S`%-O<F]Z871S>N%M`$$@<WIE<G9E<G3U;"!K
M87!O='0@861A="!H:6+A<RP@=F%G>2!N96T@X6QL(')E;F1E;&ME>NES<F4N
M`$$@9F5L:&%S>F[A;/-K87!C<V]L871O:R!A9&UI;FES>G1RX6-I\VIA`$QE
M:N%R="!A(&9E;&AA<WINX6SS:V%P8W-O;&%T(&%Z;VYO<^UT\VIA("AS97-S
M:6]N($E$*2X`1F5L:&%S>F[A;/-K87!C<V]L871O:P!(86QM87H`3&5H973U
M<^EG(&IE;'-Z87;A;F%K(.%TX6QL[73A<^%R82P@86)B86X@87H@97-E=&)E
M;BP@:&$@96QF96QE:G1E;NDN`%3A=F]L:2!S>F5R=F5R96L@96SI<NES92#A
M;&SM=&AA=/,@8F4L(&UE;'EE:V5T(&%Z(&EN9'5L\V]L9&%LX6X@:^UVX6X@
M;65G:F5L96[M=&5N:2X`02!K[7;A;G0@;GEE;'8L(&ED]7KS;F$@Z7,@9.%T
M=6UF;W)MX71U;2!B9>%L;.UTX7-A+@!"9>%L;.UT:&%T\RP@:&]G>2!M96QY
M:6L@86QK86QM87KA<R!J96QE;FIE;B!M96<@82!B96IE;&5N=&ME>NES('5T
MX6XL(&UI;'EE;B!S>NUN96=Y_'1T97-T+"!O;&1A;&9R:7-S[73I<VD@9WEA
M:V]R:7/A9V]T(&EL;"X@96=YZ6(@8F7A;&SM=.%S;VMA="!S>F5R971N92X`
M0F7A;&SM=.%S;VL`02!B9>%L;.UTX7-O:V%T(&UE9_IJ[73S('!R;V=R86UO
M:R#A;&QN86L@<F5N9&5L:V5ZZ7-R90!!(&UE9V%D;W1T('!A<F%MZ71E<B!T
M]F)B(&AE;'EE="!I<R!J96QE;G1H970Z(`!397EC:&5L;&4M<WII9V5T96L`
M5N%SX7)LX7,`4O9V:60@]G-S>F5F;V=L86SA<P!%;"!K[7;A;FIA(.ER;FD@
M87H@96=Y97,@9G5N:V-I\VMA="!!;'0M8FEL;&5N='G[+6MO;6)I;N%C:?-K
M:V%L(&ES/P!-96=J96QE;NUTZ7,`375T87-S=6L@;65G(&$@:_QL]FYB<^EG
M96ME="!A>B!E;&UE;G1E='0@Z7,@87H@^FIO;FYA;B!LZ71R96AO>F]T="!K
M;VYF:6=U<N%C:?,@:_9Z]G1T+@!-:6YD96X@8F5J96QE;G1K97KI<VMO<B#M
M<O-D:NEK(&MI(&$@:V]RX6)B:2!U=&]L<_,@8F5J96QE;G1K97KI<R!I9&5J
M93\`5N%L87-Z=&AA=/,@;&5G>65N(&%Z(&5R961E=&D@;65G=&%R=.%S80!,
M96=Y96X@9.%T=6UVX6QA<WIT\P!,96=Y96X@96=Y('3A8FSA>F%T:V5Z96SU
M(&UE;OQS;W(_`$UU=&%S<W5K(&$@)7,@;65N_'0@82!B86P@;VQD86QO;C\`
M3NEZ>OQK(&UE9R!TX6)LX7IA="!C96QLX6EN86L@='5L86ID;VYSX6=A:70`
M3NEZ>OQK(&UE9R!TX6)LX7IA="!T=6QA:F1O;G/A9V%I=`!.Z7IZ_&L@;65G
M('3A8FSA>F%T('-O<F%I;F%K('1U;&%J9&]N<^%G86ET`$[I>GK\:R!M96<@
M82!KZ7`@='5L86ID;VYSX6=A:70`375T87-S=6L@82!F96QT]FQTZ7-T`%KA
M<&]R;VL`6N%P;W)O:R!DZ6QE;/5T=`!:X7!O<F]K(&3I;'5TX6XO97-T90!(
M96QY:2!ZX7!O<F]K`$MI8W-I;GGM=.ES`$5L]7-Z]G(@:VEC<VEN>>UT96YI
M92!K96QL+"!V86=Y(&5L(&ME;&P@;6]Z9.UT86YI82!A(&AE;'EE="!E;&9O
M9VQA;/,@8FQO:VMO:V%T+@!3:65R<F$@3&5O;F4`VFH@9F5L:&%S>F[A;/-K
M(&)E:F5L96YT:V5ZZ7-E`$1I9VETX6QI<R!A;.'M<N%S`$$@9&EG:73A;&ES
M(&%LX>URX7,@86QG;W)I=&UU<V$`4WII;F=A</IR`$WI<F5T`$$@:V%R8F%N
M=&%R=.%S(&MI:&%G>>%S80!3>FQO=N%K:6$`4WIL;W;I;FEA`$AA=F%ZX7,`
M2/-ZX7!O<@!(\WKA<&]R;VL`2/-ZX7!O<F]K(&3I;&5L]71T`$OI<_4@9.EL
M=73A;FDO97-T:2!H\WKA<&]R;VL`02!H\R!MZ6QY<^EG93H@`$CS(';M>FUE
M;FYY:7/I9V5B96X@:VEF96IE>G9E.B``4V%L86UO;BUS>FEG971E:P!3>F]M
MX6QI80!$86QO:RP@=F5R<V5K`$$@<V]R8F%R96YD97KI<R!I<N%N>>%N86L@
M:VEVX6QA<WITX7-A`$9E;&%D\VD@8^UM`$3I;"U!9G)I:V$`9.EL+65U<O-P
M86D@*$E33RTX.#4Y+3,I`$3I;&DM1V5O<F=I82#I<R!$Z6QI(%-A;F1W:6-H
M+7-Z:6=E=&5K`$3I;&D@9NEL=&5K90!3>F]M<WKI9&]S(&-E;&SA:R!K]GKV
M='1I('3A=F]L<^%G`$$@8V5L;&$@=&%R=&%L;6$@Z7,@:V5R971E(&OV>O9T
M=&D@=.%V;VQSX6<`2&5L>6MI=/9L=/4`5.%V;VQSX6<`5.%V;VQSX6<@Z7,@
M8F5L<_4@;6%R9_,@8F7A;&SM=.%S`%-P86YY;VQO<G-ZX6<`4W!A;6%S<V%S
M<VEN92!B9>%L;.UTX7-O:P!3<&5C:>%L:7,@:V%R86MT97(@8F5V:71E;&4`
M02!C96QL82!K971TZ6)O;G3A<V$`07H@;W-Z;&]P(&ME='3I8F]N=.%S80!!
M('-O<B!K971TZ6)O;G3A<V$`4W!O<G0`4W+M($QA;FMA`%-T86YD87)D`%-T
M87(@5')E:P!!>B!E;'/U(.EV`,%L;&%M('9A9WD@=&%R=&]MX6YY`,%L;&%P
M;W0`365N=.ES:2!F;W)MX71U;0!#[6T@*'5T8V$I`.%T:/IZ;W1T`%-T<FEN
M9R!L:7-T80!4]G+V;&K\:R!A(&/M;6+U;"!A($`@=73A;FD@<NES>G0`4W3M
M;'5S(%M#4U-=`%9A`$$H>BD@(B5S(B!A;&OV;GEV=.%R(&YE;2!T86SA;&AA
M=/,N`%3A<F=Y`$O\;&1J_&L@96P`(B5S(B#Z:B!F96QH87-Z;N%L\R!B96IE
M;&5N=&ME>NES:2!KZ7)E;&WI="!T;W;A8F+M=&]T='5K+B#6;B!C<V%K(&OI
M<F5L;>EN96L@96QF;V=A9.%SX70@:_9V973U96X@='5D(&UA:F0@8F5J96QE
M;G1K97IN:2X`86QS\R!I;F1E>`!3:6ME<OQL=`!3:6ME<F5S96X@:&]Z>N%A
M9'1U:R`B)7,B+70@82!R96YD<WIE<FAE>BX`(B5S(B!F96QH87-Z;N%L\R!A
M9&%T86ET('-I:V5R97-E;B!T]G+V;'3\:R!A(')E;F1S>F5R8O5L+@!3:6ME
M<F5S96X@=/9R]FQT_&L@(B5S(BUT+@!3:6ME<F5S96X@96QTX79O;.UT;W1T
M=6L@(B5S(BUT(&$@<F5N9'-Z97)B]6PN`$$@:V]N9FEG=7+A8VGS="!S:6ME
M<F5S96X@=FES<WIAX6QL[71O='1U:RX@02!VX6QT;WKA<V]K(&UE9W1E:VEN
M=.ESZ6AE>B!F<FES<^UT<V4@87H@;VQD86QT+@!!(&)A8VMU<"!K;VYF:6=U
M<N%C:?-T(&5L;65N=&5T=/QK+@!3:6ME<F5S96X@96QM96YT971T_&L@82AZ
M*2`E<R!B86-K=7`@:V]N9FEG=7+A8VGS="X`(B5S(B!A9&%T86EN86L@;?-D
M;W/M=.%S82!S:6ME<F5S96X@;65G=/9R=.EN="X`4VEK97)E<V5N(&5L;65N
M=&5T=/QK(&$@)7,@X6QL;VWA;GET+@!3>G5DX6X`UG-S>F5F;V=L86SA<P!.
M87!K96QT90!.87!N>75G=&$`;F%P;W,`3F%P:V5L=&4`3F%P:V5L=&4O;F%P
M;GEU9W1A`$YA<&ME;'1E.B``3F%P;GEU9W1A`$YA<&YY=6=T83H@`&9E;'/U
M(&EN9&5X`$]N;&EN92!K;VUM=6YI:^%C:?,@*&-H870I`%-U<FEN86UE`$-S
M86SA9&[I=@!3=F%L8F%R9"#I<R!*86X@36%Y96X`4WIVX7II9O9L9`!3=NED
M;W)S>N%G`%-VX6IC`$%Z(&%D871S>FEN:W)O;FEZX6-I\W,@;F%P;//A;&QO
M;>%N>70@=/9R]FQT_&L`4WII;G1A:W1I:V%I(&AI8F$@82!K97)E<_5K:69E
M:F5ZZ7-B96X`4WKM<FEA:2!!<F%B($OV>G3A<G-A<^%G`%II=F%T87(`6FEV
M871A<BP@97+U<R!S>NEL`%II=F%T87)O:P!+;W)A:2!Z:79A=&%R;VL`5%-6
M("A404(@:V%R86MT97)R96P@96QVX6QA<WIT;W1T(.ER=.EK96LI(.%L;&]M
MX6YY`%3A8FSA>F%T`$$@=.%B;.%Z870@='5L86ID;VYSX6=A:0!!('3A8FSA
M>F%T('1U;&%J9&]N<^%G86D`5&%J=F%N`%1A:G9A;@!4861Z<VEK:7-Z=.%N
M`%1A;GKA;FEA:2!%9WEE<_QL="!+:7+A;'ESX6<`02!CZ6PZ`$9E;&%D871O
M:P!496QE9F]N<WKA;0!!>B!E;&WZ;'0@\W)A(&CU;>ER<^EK;&5T93H@`$CU
M;>ER<^EK;&5T`$CU;>ER<^EK;&5T.B``2/5MZ7)SZ6ML970\8G(@+SXH)7--
M87@E<R\E<TUI;B5S*2`F9&5G.R5S`$$H>BD@(B5S(B!S86)L;VX@;F5M('1A
M;.%L:&%T\RX`4V%B;&]N;VL@861M:6YI<WITX6-I\VIA`%-Z]G9E9P!C<V%K
M('-Z]G9E9P!3>O9V96=E;&AE;'EE>NES`'-Z]G9E9R!T971E:F4`0W/\`'1H
M86D@*%1)4RTV,C`I`%1H86EF]FQD`$%Z(&9T<"!B]7;M=.ES(&YE;2!T86SA
M;&AA=/,N`$$@2&ES=&]R>2!R96YD<WIE<B!M^VOV9.ES92!N:6YC<R!E;F=E
M9.EL>65Z=F4N`$$@2&]R9&4O2V]L86(@:6YT96=RX6-I\R!E>G0@;F5M('3A
M;6]G871J83H@(B5S(@!!>B!)35-0(&YA<&SS>N%S="!N96T@<VEK97+\;'0@
M;65G:V5Z9&5N:2X`02!-86EN=&5N86YC93HZ(&]S>G3A;'D@8F5T]FQTZ7-E
M(&YE;2!S:6ME<OQL=`!!>B!/<&-I\R!A8FQA:R!B97KA<F]D;W1T+B!+:6SI
M<.ES(&OV=F5T:V5Z:6LN`$$@2F]G;W-U;'1SX6=O:R!H87-Z;N%L873A;F%K
M(&5L]69E;'3I=&5L92P@:&]G>2!A(')E;F1S>F5R9V%Z9&$@:V]N9FEG=7+A
M;&IO;B!E9WD@82!J;V=O<W5L='/A9VD@861A=&]K870@=&%R=/-S86X@=.%R
M;VQN:2!KZ7!E<R!A;')E;F1S>F5R="X`0W-A:R!A;'5L(&QE9WEE;B!K97)E
M=`!!('!A<G1N97(@87IO;F]S[73S<WKA;6$@;F5M('9O;'0@;65G861V82_\
M<F5S96X@;6%R861T('9A9WD@87H@861A=&+A>FES8F%N(&YE;2!V;VQT(&UE
M9W1A;.%L:&%T\RX`02!P87)T;F5R(&%D871A:70@<VEK97)E<V5N(&AO>GKA
M861T=6L@82!C[6UJ96=Y>NEKZ6AE>BX`2_QL]F[A;&SS(%!'4"!A;.'M<N%S
M:2!B;&]K:R!S>OQK<^EG97,@82!D:6=I=.%L:7-A;B!A;.'M<G0@_'IE;F5T
M(&AI=&5L97-SZ6?I;F5K(&5L;&5N]7)ZZ7/I:&5Z+@!!(&OV<FQE=NEL;&ES
M=&$@87IO;F]S[73S<WKA;6$@;F5M('9O;'0@;65G861V82_\<F5S96X@;6%R
M861T('9A9WD@87H@861A=&+A>FES8F%N(&YE;2!V;VQT(&UE9W1A;.%L:&%T
M\RX`02!K]G)L97;I;&QI<W1A(&YE;2!V;VQT(&UE9V%D=F$N`$$@=&ET:V]S
M[73A<VD@<WIO;&?A;'1A=.%S;VMH;WH@8FEZ=&]N<^%G;W,@*'1I=&MO<^UT
M;W1T*2!W96(@:V%P8W-O;&%T(&ME;&PN`$$H>BD@)7,@X6QL;VWA;GEB86X@
M<WIE<F5P96QN:64@:V5L;&5N92!E9WD@)7,@8F7A;&SM=.%S;F%K+@!!*'HI
M("5S(.%L;&]MX6YY8F%N('-Z97)E<&5L;FEE(&ME;&QE;F4@=F%L86UI;'EE
M;B`E<R!B9>%L;.UTX7,H;VLI;F%K+@!!(&;A:FP@;F5M(&WA<V]L:&%T\R#V
M;FUA9^%R82X`02!FX6IL8F%N(&YE;2!V;VQT(&%D870N`$%Z(/QZ96YE="!F
M96ILZ6-S;W)A:2!A(&OV=F5T:V5Z]6LN`$$@=&5L:F5S(&OI<&5R;GGU<R#\
M>F5M;?-D('!R;V)LZ6WA:V%T(&]K;WIH870@87H@26YT97)N970@17AP;&]R
M97(@:&%S>F[A;&%T82!E<V5TZ6XL(&UE<G0@96)B96X@;VQY86X@<')O9W)A
M;6AI8N%K('9A;FYA:RP@86UI:V5T(&YE;2!T=61T=6YK(&UE9VME<OQL;FDN
M($$@:^EP97)N>?5J92!O;'9A<VAA=&%T;&%N;N$@=N%L:&%T+"!B:7IO;GEO
M<R!E9&ET;W(@9G5N:V-I\VL@:&GA;GEO>FAA=&YA:R#I<R]V86=Y(';A<F%T
M;&%N=6P@;&5F86=Y:&%T(&$@8O9N9^ES>O5P<F]G<F%M+B!7:6YD;W=S(#EX
M(&AA<WINX6QA=&$@97-E=.EN(&YA9WEO;B!V86SS<WKM;OLL(&AO9WD@)T=E
M;F5R86P@<')O=&5C=&EO;B!F875L="<@:&EB82!M:6%T="#Z:G)A(&ME;&P@
M:6YD[71A;FEA(&UA:F0@82!GZ7#I="Y<;EQN1FEG>65L;65Z=&5T=/QK(2!+
M871T:6YT<V]N(&%Z($]+(&=O;6)R82P@:&$@;>EG:7,@;65G(&OM=N%N:F$@
M:^USZ7)E;&YI(&$@=&5L:F5S(&OI<&5R;GGU<R#\>F5M;?-D;W0N`$$@(B5S
M(B!A>F]N;W/M=/-T(&MI=/9R]FQT_&LN`$-S86L@8F%L(&]L9&%L;VX@;&5G
M>65N(&ME<F5T`$$@1VYU4$<@<')O9W)A;2!H96QYZ70@;65G(&ME;&P@861N
M:2!A($-R>7!T7W!G<#HZ(&]S>G3A;'D@:&%S>F[A;&%TX6AO>BX`02!L97;I
M;"P@;65L>65T("5S(&YA<&KA;B!K_&QD]G1T("5S(&/M;7IE='1N96L@(B5S
M(B!TX7)G>6)A;BP@82!C[6UZ971T('-ZX6WM=/-GZ7#I;B!M96=J96QE;G0N
M($%R<F$@;FEN8W,@9V%R86YC:6$L(&AO9WD@96P@:7,@;VQV87-TX6L@:6QL
M+B!H;V=Y(&UE9^ER=&5T=.EK+@!-:2!L96=Y96X@82!L97;I;.UR\R!A8FQA
M:VAO>B!M=71A=/,@;&EN:R!E;&YE=F5ZZ7-E`$$@;65Z]6L@<WKA;6$@8W-A
M:R!N=6UE<FEK=7,@Z7)TZ6L@;&5H970N`$%Z(&]P96YS<VP@;6]D=6P@<WK\
M:W/I9V5S(&$@2&]R9&5?0W)Y<'1?<VUI;64Z.B!O<WITX6QY(&AA<WINX6QA
M=.%H;WHN`$$@(B5S(B!S>F5MZ6QY97,@8F7A;&SM=.%S(&YE;2!M96YT:&5T
M]2!E;"P@;65R="!MZ7)E=&4@;65G:&%L861J82!A(&UE9V5N9V5D971T(&UA
M>&EM=6UO=`!.96T@=&%LX6QH873S(&%Z(&$@<')O9W)A;2!A('-Z97)V97)E
M;BP@86UI('-Z_&MSZ6=E<R!E;FYE:R!A>B!A9&%T=.UP=7-N86L@*"5S*2!A
M(&UE9VIE;&5N[73I<^EH97HN`$%Z(&EDZ7KU:F5L(&MA<F%K=&5R(&-S86L@
M96=Y971L96X@:V%R86MT97(@;&5H970N`$IO8F(@Z7,@8F%L(&]L9&%L;VX@
M;&5G>65N(&ME<F5T`$-S86L@:F]B8B!O;&1A;&]N(&QE9WEE;B!K97)E=`!!
M>B!E;';A;&%S>G3S(&MA<F%K=&5R(&-S86L@96=Y971L96X@:V%R86MT97(@
M;&5H970N`$$H>BD@(B5S(B!S>F5R=F5R="!T]G+V;'3\:RX`02AZ*2`B)7,B
M('-Z97)V97)T(&5L;65N=&5T=/QK+@`E<R!B96IE;&5N=&ME>NES:2!KZ7)E
M;&WI="!T]G+V;'3\:RX`02!M96=A9&]T="!S;W(@*"5D*2!N96T@;.ET97II
M:RX`02AZ*2`B)7,B(&ED96EG;&5N97,@9N%J;"!N96T@;.ET97II:RX`02!B
M9>UR="!S>O9V96<@;F5M(&5G>65Z:6L@82!KZ7!E<FYY]6X@;&5V]79E;"X`
M06QU;"#I<R!F]FS\;"!L96=Y96X@:V5R970`0W-A:R!F96YT(&QE9WEE;B!K
M97)E=`!!(&9E;'3V;'3V='0@861A=&]K(&%Z(&5L]7KU(&SI<.ES(/-T82!E
M;'9E<WIT96LN`$$@9F5L=/9L=/9T="!FX6IL="!N96T@<VEK97+\;'0@96QM
M96YT96YI+@!!('=E871H97(N8V]M(&)L;VMK(&YE;2!H87-Z;N%L:&%T\RX`
M02!M96=J96QE;NES:2!S=.UL=7,@*'1H96UE<RD@86QK]FYY=G3A<B`B)7,B
M(&YE;2!T86SA;&AA=/,N`$YI;F-S96X@=N%L87-Z=&AA=/,@;W!C:?,N`$YI
M;F-S(&$@;&5VZ6P@8F5L<V5JZ6)E;B!M96=J96QE;NUT:&5T]2!M96QLZ6ML
M970N`%3Z;"!S;VL@:V%R86MT97(@=F%N(&5B8F5N(&$@;65Z]6)E;BX@UFX@
M)7,@:V%R86MT97)T(&%D;W1T(&UE9SL@82!M87AI;>%L:7-A;B!M96=A9&AA
M=/,@<&5D:6<@:V5V97-E8F(L(&UI;G0@)7,N`"(E<R(@9F5L:&%S>F[A;/-N
M86L@82!R96YD<WIE<FAE>B!A9.%S86MO<B!H:6)A('3V<G3I;G0N("5S`"(E
M<R(@9F5L:&%S>F[A;/,@861A=&%I;F%K('3V<FSI<V4@<V]RX6X@:&EB82!L
MZ7!E='0@9F5L.B``(B5S(B!R96YD<WIE<F+U;"!V86SS('3V<FSI<V5K;W(@
M:&EB82!LZ7!E='0@9F5L.B``(B5S(B!M\V1O<^UTX7-A('-O<N%N(&AI8F$@
M;.EP971T(&9E;#H@)7,`07H@X6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z
M97)V97)R92!F96QT]FQT96YI+B`E<R!N96T@=/9L=/5D]G1T(&9E;"X`07H@
MX6QL;VWA;GET(&YE;2!S:6ME<OQL="!A('-Z97)V97)R92!F96QT]FQT96YI
M+B`E<R!N86=Y;V)B+"!M:6YT(&$@;6%X:6WA;&ES86X@;65G96YG961E='0@
M;>ER970@*"5D(&+A:G0I+@!!>B#A;&QO;>%N>70@;F5M('-I:V5R_&QT(&$@
M<WIE<G9E<G)E(&9E;'3V;'1E;FDN($$H>BD@)7,@9N%J;&YA:R!C<V%K(&5G
M>2!RZ7-Z92!T]FQT]63V='0@9O9L+@!!(&QE=NEL(&4@<NES>NEN96L@;65G
M:F5L96[M=.ES96MO<B!H:6)A('3V<G3I;G0`02!P87)T;F5R(&%D871O:R!I
M;7!O<G3A;.%S82!S;W+A;B!H:6)A('3V<G3I;G0N`$%Z(&E#86QE;F1A<B!A
M9&%T;VL@:6UP;W)TX6SA<V$@<V]RX6X@:&EB82!T]G)TZ6YT+@!(:6+A<R!A
M(&UE9V%D;W1T(&MO;F9I9W5RX6-I\RX@3&5H970L(&AO9WD@;F5M('3V;'3V
M='0@:VD@96=Y('-Z_&MSZ6=E<R!M97KU="X`02!P87)T;F5R:F5G>7KI:VME
M;"!K87!C<V]L871O<R!F96QA9&%T(';I9W)E:&%J=.%S82!S;W+A;B!H:6)A
M(&SI<&5T="!F96PN($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$AI8F$@
M=/9R=.EN="!A('!A<G1N97(@861A=&%I;F%K(&9R:7-S[73I<V4@<V]RX6XN
M($OI<F5M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$$@:_9R;&5VZ6QL:7-T82!A
M9&%T86EN86L@9G)I<W/M=.ES92!S;W+A;B!H:6)A('3V<G3I;G0N($OI<F5M
M('!R\V+A;&IA(&UE9R!KZ7/U8F(N`$5Z(&%Z($E-05`@<WIE<G9E<B!N96T@
M=.%M;V=A=&IA(&$@;6%P<.%K:&]Z('9A;/,@:&]Z>N%FZ7+I<R!M96=O<WIT
MX7/A="X`17H@;F5M('3[;FEK('-Z86+A;'EO<R!R87(@X6QL;VWA;GEN86LN
M`$5Z(&YE;2!T^VYI:R!S>F%BX6QY;W,@>FEP(.%L;&]MX6YY;F%K+@!%>B!N
M96T@=/MN:6L@Z7)VZ6YY97,@:^%R='EA<WKA;6YA:RX`17H@82!M96=H86IT
M\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N(%--4RUT
M(&O\;&1J_&YK(&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!S>F]L9^%L=&%T\VX@X70N`$5Z(&$@;65G:&%J=/,@;&5H973U=ND@=&5S
M>FDL(&AO9WD@2%144"UK87!C<V]L871O;B!335,M="!K_&QD:OQN:R!A(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M
M96=H86IT\R!L96AE=/5VZ2!T97-Z:2P@:&]G>2!(5%10+6MA<&-S;VQA=&]N
M(%--4RUT(&O\;&1J_&YK(&%Z('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I
M;"YC;VTI('-Z;VQGX6QT873S;B#A="X`17H@82!M96=H86IT\R!L96AE=/5V
MZ2!T97-Z:2P@:&]G>2!33510+6MA<&-S;VQA=&]N(%--4RUT(&O\;&1J_&YK
M(%9O9&%F;VYE('-ZX6UO:W)A(&$@5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2!S>F]L9^%L=&%T\VX@X70N($$@<WIO;&?A;'1A=.%S(&EG
MZ6YY8F5VZ71E;.EH97H@5F]D869O;F4@271A;'D@96UA:6P@8^UM('-Z_&MS
MZ6=E<RX`17H@82!M97KU(&YE;2!M87)A9&AA="#\<F5S+@!%8F)E;B!A(&UE
M>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@X6QL:&%T;F%K+@!%8F)E;B!A(&UE
M>O5B96X@8W-A:R!E9^ES>B!S>N%M;VL@Z7,@:V5T=/5S<&]N="!L96AE="X`
M16)B96X@82!M97KU8F5N(&-S86L@;VMTX6QI<R!S>N%M;VL@X6QL:&%T;F%K
M+@!%>B!A(&UE>O4@8W-A:R!V97-S>O5V96P@=F%G>2!S>O-K]GIZ96P@96QV
MX6QA<WIT;W1T(&5GZ7-Z('-ZX6UO:V%T('1A<G1A;&UA>FAA=`!%>B!A>B#I
M<G3I:R!C<V%K('-ZX6T@;&5H970N`$5B8F5N(&$@;65Z]6)E;B!H97AA9&5C
M:6WA;&ES(%)'0B!S>NUN:_-D(.%L;&AA="P@<&PN("<C,3(S-&%F)RX`17IE
M;B!A9&%T;VMK86P@:V%P8W-O;&%T;W,@9F5L861A=&]K870@82!S>F5R=F5R
M(&WA<B!E;';I9V5Z=&4N`$5Z("5S`$5Z(&5G>2!+;VQA8B!'<F]U<'=A<F4@
M;V)J96MT=6TN($%Z(&EL>65N(&]B:F5K='5M(&UE9VIE;&5N[73I<^EH97H@
M;VQY86X@96UA:6P@:VQI96YS<')O9W)A;2!S>OQK<^EG97,L(&%M96QY(&OI
M<&5S(&$@2V]L86(@1W)O=7!W87)E(&9O<FWA='5M(&ME>F5LZ7/I<F4N($EL
M>65N(&5M86EL(&ML:65N<V5K(&QI<W3A:F$@;.%T:&%T\R!I='0Z("5S`$5Z
M="!A(&QE=F5L970@;>%S(&MA<F%K=&5R:^ES>FQE='1E;"`H)7,I(.UR=.%K
M+"!M:6YT(&%M:70@UFX@:&%S>F[A;"X`17H@82!S>N%M(&YE;2!L96AE="!E
M9WENZ6P@:VES96)B+@!%>B!A('-Z97)V97(@;F5M(&OI<&5S(&MI8F]N=&%N
M:2!A('II<"!I;&PN(&=Z:7`@X6QL;VWA;GEO:V%T+@!%>B!A(')E;F1S>F5R
M(&IE;&5N;&5G(&EN86MT:7;A;'9A('9A;BX`17H@87H@Z7)TZ6L@8W-A:R!S
M>N%M(&QE:&5T+@!%>G0@87H@86)L86L@8W-A:R!A>B!/<&-I\VL@86)L86MB
M\VP@:.UV:&%T\P!6:6QLX6ULX7,`2&EB86)E:F5L96YTZ7,M:V5Z96SI<P!)
M9/4`375N:V%I9/4M;GEI;';A;G1A<G3A<P!)9/4@9F]R;>%T=6T`263U(';A
M;&%S>G3A<P!+96QE="U4:6UO<@!4:71U;'5S`$/M;2`H=&]O;'1I<"D`0^UM
M>F5T=`!(82!T]F)B(&5L96UE="!I<R!K:2!A:V%R(&IE;/9L;FDL('1A<G1S
M82!L96YY;VUV82!A($-O;G1R;VP@*%!#*2!V86=Y(&$@0V]M;6%N9"`H36%C
M*2!B:6QL96YT>?MT(&$@:V%T=&EN=.%S(&OV>F)E;BX`36$`2%1-3"!F;W)R
MX7-NZ7IE="!K:2]B90!4;V=O`%1O:V5L874`2&]L;F%P`%1O;F=A`&;V;/QL
M`$QE9V9E;'/U(&9R86UE("A?=&]P*0!&;W)D[73A<V]K`%1R:6YI9&%D(.ES
M(%1O8F%G;P!)9V%Z('9A9WD@:&%M:7,`2V4`5'5NZ7II80!4]G+V:V]R<WKA
M9P!T]G+V:R`H25-/+3@X-3DM.2D`5/QR:VUE;FES>G3A;@!4=7)K<RT@Z7,@
M0V%I8V]S+7-Z:6=E=&5K`%1U=F%L=0#-<FIA(&)E+"!M:70@=N%L87-Z=&]T
M=#H@`%56(&EN9&5X.B``55),`%523"P@;65L>65N(&5G>2!P<F]G<F%M(&5L
M9F]G861J82!A('-Z;VQGX6QT873S(.%L=&%L(&O\;&3V='0@:_QL9/9T="!K
MZ7IB97/M=.ES:2!J96QE;G3I<W0`55),.@!59V%N9&$`56MR86IN80!.96T@
M<VEK97+\;'0@82!61E,@86QK]FYY=.%R8F$@8F5LZ7!N:2X`02!B96IE;&5N
M=&ME>NES:2!J;V=O<W5L='/A9R!I9^EN>6SI<V5K;W(@;F5M('-I:V5R_&QT
M(&%Z(&%D871O:R!E;'3A<F]LX7-A+@!.96T@<VEK97+\;'0@82AZ*2`B)7,B
M(%9&4R!FX6IL(&5LZ7+I<VD@:F]G;W-U;'1SX6=A:70@;65G=N%L=&]Z=&%T
M;FDN`$YE;2!S:6ME<OQL="!A*'HI("5S+R5S(%9&4R!FX6IL(&5LZ7+I<VD@
M:F]G;W-U;'1SX6=A:70@;65G=N%L=&]Z=&%T;FDN`$YE;2!S:6ME<OQL="!A
M*'HI("5S(&%L:_9N>79TX7)B82!B96SI<&YI+@!!*'HI("(E<R(@X6QL;VWA
M;GD@;>ER971E(&YE;2#A;&QA<.UT:&%T\R!M96<N`$$H>BD@(B5S+R5S(B#A
M;&QO;>%N>2!MZ7)E=&4@;F5M(.%L;&%P[71H873S(&UE9RX`07H@4U%,('-Z
M97)V97(@;F5M(.ER:&5T]2!E;"X`07H@4U-,(&MA<&-S;VQA="!N96T@Z7#M
M=&AE=/4@9F5L+@!!(%9&4R!FX6IL(&YE;2!MX7-O;&AA=/,@X70N`$YE;2!S
M:6ME<OQL="!A*'HI("(E<R(@5D93(&%L:_9N>79TX7)T(&SI=')E:&]Z;FDN
M`$YE;2!S:6ME<OQL="!LZ71R96AO>FYI(&$@5D93(&%L:_9N>79TX7)T+@!.
M96T@<VEK97+\;'0@;.ET<F5H;WIN:2!A(%9&4R!FX6IL="X`02AZ*2`B)7,B
M(%9&4R!M87!P82!N96T@:&]Z:&%T\R!LZ71R92X`3F5M('-I:V5R_&QT(&SI
M=')E:&]Z;FD@_')E<R!61E,@9N%J;'0N`$$@=/9M]G+M=&5T="#A;&QO;>%N
M>70@;F5M('-I:V5R_&QT(&MI8F]N=&%N:2X`(B5S(B!N96T@=/9R]FQH973U
M+"!A>B!A;&OV;GEV=.%R(&YE;2#\<F5S+@`B)7,B('3V<FSI<V4@;F5M('-I
M:V5R_&QT.B`E<RX`)7,@;F5M('3V<O9L:&5T]2P@87H@86QK]FYY=G3A<B!N
M96T@_')E<RX`02!61E,@86QK]FYY=G3A<B!N96T@=/9R]FQH973U(')E:W5R
M>NUV86XN`$$@5D93(&%L:_9N>79TX7(@;F5M('3V<O9L:&5T]2X`02!61E,@
M86QK]FYY=G3A<B!N96T@=/9R]FQH973U.B`E<RX`02AZ*2`B)7,B(%9&4R!F
MX6IL(&YE;2!T]G+V;&AE=/4N`$$@5D93(&;A:FP@;F5M('3V<O9L:&5T]2X`
M02AZ*2`B)7,B(%9&4R!M87!P82!N96T@=/9R]FQH973U+@!.96T@=NEG97IH
M973S(')E:W5R>NUV('3V<FSI<R!A(%9&4RUB96XZ("5S+@!.96T@:&%TX7)O
M>FAA=/,@;65G(&$@:F5L96YL96<@Z7)VZ6YY97,@86QK]FYY=.%R+@!!('1A
M;OIS[71VX6YY('+I<WIL971E<R!A9&%T86D@;F5M(&AA=.%R;WIH873S:R!M
M96<`3F5M('-I:V5R_&QT(&)E;VQV87-N:2`E<R!D969I;NUC:?-JX70N`$$@
M5D93(&;A:FP@;F5M(&AE;'EE>FAE=/,@X70N`$$H>BD@(B5S(B!61E,@9N%J
M;"!N96T@;GEI=&AA=/,@;65G+@!!(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M
M96<@[7+A<VD@8^EL;&%L+@!!(%9&4R!FX6IL(&YE;2!N>6ET:&%T\R!M96<@
M+@!!('3V;?9R[71E='0@X6QL;VWA;GD@;F5M(&YY:71H873S(&UE9RX`02!6
M1E,@9N%J;"!N96T@;VQV87-H873S("AA(&9I;&5S:7IE*"D@<VEK97)T96QE
M;B!V;VQT*2X`02!61E,@9N%J;"!N96T@;VQV87-H873S("AA(&=E=$9I;&53
M:7IE*"D@<VEK97)T96QE;B!V;VQT*2X`17H@82!FX6IL(&YE;2!O;'9A<VAA
M=/,Z(`!!('9F<W)O;W0@86QK]FYY=G3A<B!N96T@;VQV87-H873S+@`E<R!N
M96T@;F5V97IH973U(.%T("5S(&[I=G)E.B!MX7(@;.ET97II:R!I;'EE;B!N
M97;[(&UA<'!A`$$@5D93(&%L:_9N>79TX7(@;F5M(&YE=F5Z:&5T]2#A="X`
M02!61E,@86QK]FYY=G3A<B!N96T@;F5V97IH973U(.%T.B`E<RX`02AZ*2`B
M)7,B(%9&4R!FX6IL(&YE;2!N979E>FAE=/4@X70N`$$H>BD@)7,O)7,@5D93
M(&;A:FP@;F5M(&YE=F5Z:&5T]2#A="X`02!61E,@9N%J;"!N96T@;F5V97IH
M973U(.%T+@!!>B`G;6MI<V]F<R<@<')O9W)A;2!N96T@9G5T=&%T:&%T\RX`
M3F5M('-I:V5R_&QT(&QE9F]R9.UT86YI(&5Z="!A(%=O<F0@9&]K=6UE;G1U
M;6]T`$$H>BD@(B5S(B!61E,@9N%J;"!N96T@[7)H873S+@!!(%9&4R!FX6IL
M(&YE;2#M<FAA=/,@*&$@8V]P>2@I('-I:V5R=&5L96X@=F]L="DN`$$@5D93
M(&;A:FP@861A=&%I(&YE;2#M<FAA=/-K(&MI+@!!(%9&4R!FX6IL(.URX7-A
M(&MV\W1A=/IL;.EPZ7,@;6EA='0@;F5M(&9E:F5Z:&5T]2!B92X`86SA:/IZ
M;W1T`$WI9W-E(&UE;G1S_&L@96P`5FES<WIA=F]N:F$@87H@=71O;'/S(';A
M;'1O>G1A=.%S=`!!(&MA<&-S;VQA="!F96QVZ71E;.ET(&OV=F5T]65N(';A
M<F%T;&%N(';A;&%S>B#I<FME>F5T="!A('-Z97)V97)T]6PZ(`!6X7)A=&QA
M;B!VX6QA<WH@Z7)K97IE='0@82!S>F5R=F5R=/5L(&5R<F4Z(`!"97-O<F]L
M871L86X`56YI8V]D92`H551&+3@I`$5G>65S_&QT($%R86(@16WM<G/I9V5K
M`$5G>65S_&QT($MI<N%L>7/A9P!%9WEE<_QL="#!;&QA;6]K`$5G>65S_&QT
M(,%L;&%M;VLL(&MI<V5B8B!K_&QS]2!S>FEG971E:P!E9WESZ6<`27-M97)E
M=&QE;@!)<VUE<F5T;&5N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`$ES
M;65R971L96X@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`02!M96=A
M9&]T="!H96QY(&ES;65R971L96XN`$ES;65R971L96X@9F5L:&%S>F[A;/-I
M(&[I=B!V86=Y(&IE;'-Z\RX`5.%V;VSM='-U:R!E;"!I;FYE;B!A(&QI;FME
M=`!.:6YC<R!E;&YE=F5Z=F4`0FEZ=&]N<^%G:2!O:V]K8O-L(&$@9F5L:&%S
M>F[A;/-I('!R;V=R86UO:R!N96T@:&%S>F[A;&AA=&KA:R!A($MI=N%GX7,O
M3>%S;VSA<R]"96EL;&5S>G3I<R!M\V1S>F5R="X@2V%T=&EN='-O;B!A>B!/
M2R!G;VUB<F$L(&AA(&$@;6]Z:6QL82YO<F<@=V5B;VQD86QO;B!E;"!K[7;A
M;FIA(&]L=F%S;FD@82!T96-H;FEK86D@;&7M<N%S="!M96QY(&UE9V%D:F$L
M(&AO9WEA;B!L96AE="!E>G0@;>EG:7,@96YG963I;'EE>FYI+@!!('-Z[6X@
M=FES<WIAX6QL[73A<V$`3F5M('3A;6]G871O='0@97AT96YZ:?,`3?-D;W/M
M=.%S`"5S(&%D871A:6YA:R!M\V1O<^UTX7-A`$$@9F5L:&%S>F[A;/,@861A
M=&%I;F%K(&WS9&]S[73A<V$`(B5S(B!VX6QT;WKA<V%I="!E;&UE;G1E='3\
M:RX`07H@=7!G<F%D92!P<F]G<F%M;W0@=/9R]FQT_&LN`$9E;'3V;'3I<P!!
M>B#V<W-Z97,@86QK86QM87KA<R!K;VYF:6=U<N%C:?-JX70@9F5L=/9L=/9T
M=/QK(&$@<WIE<G9E<G)E+@!L871I;B!N86=Y8F5T^VL`;F%G>6)E=/MS('+S
M;6%I('-ZX6UO:P!5<G5G=6%Y`$AA<WINX6QJ=6L@82!J96QE;FQE9VET.B`E
M<P!(87-Z;N%L:G5N:R!34TPM=`!!:VMO<B!H87-Z;N%L:G5K+"!H82!A>B!)
M35-0('-Z97)V97)E;B!MX7,@82!B96IE;&5N=&ME>NES:2!N97;\;FLO:F5L
M<WIA=G5N:RX`1F5L:&%S>F[A;/-I(&[I=@`E<R!F96QH87-Z;N%L\R!N96T@
M:F]G;W-U;'0@)7,M<F4N`$9E;&AA<WINX6SS:R!A9&UI;FES>G1RX6SA<V$`
M1F5L:&%S>F[A;/-I(&)EX6QL[73A<V]K`$)E:F5L96YT:V5ZZ7,@:F]G;W-U
M;'1SX6<@:6?I;GELZ7-E`$5Z96X@82!R96YD<WIE<F5N(&YI;F-S(&5N9V5D
MZ6QY97IV92!A>B#Z:B!F96QH87-Z;N%L\VL@8F5J96QE;G1K97KI<VD@:F]G
M;W-U;'1SX6?A;F%K(&EGZ6YY;.ES92X`07H@9F5L:&%S>F[A;/-I(&%Z;VYO
M<^UT\R!N96T@=&%LX6QH873S`$9E;&AA<WINX6SS:2!NZ78`02AZ*2`B)7,B
M(&9E;&AA<WINX6SS:2!NZ78@;>%R(&SI=&5Z:6LN`$9E;&AA<WINX6SS:2!N
MZ78Z`$9E;&AA<WINX6SS:2!NZ78Z(`!!(')E;F1S>F5R(&9E;&AA<WINX6SS
M:3H`W'IB96=I<WITX6X`02!61E,@86QK]FYY=G3A<B!N96T@;.ET97II:RX`
M4WIA8F%D<^%G(&%L871T:2!A=71O;6%T:6MU<R!E;6%I;"UVX6QA<WH`02!K
M]G9E=&ME>O4@:&5L>65K970@=&%LX6QT=6LZ(`#)<G;I;GEE<W/I9P!!>B#I
M<G3I:V5K970@<&5R8V)E;B!A9&IU:R!M96<L(&UO<W1A;G3S;"!S>N%M[71V
M82X`02#I<G3I:R!N86=Y;V)B+"!M:6YT(&$@;&5G;F%G>6]B8B!M96=E;F=E
M9&5T="!H;W-S>OISX6<Z("5S+@#)<G3I:V5K`%;A;&%S>G1H873S(.ER=.EK
M96L`5F%N=6%T=0!VX6QT;WKS`%9E;F5Z=65L80!!(&AI=&5L97/M=.ES(&YE
M;2!S:6ME<OQL="`M(&QE:&5T+"!H;V=Y(&$@;&5V96QE="!V86QA:VD@;65G
M=N%L=&]Z=&%T=&$N`%9E<GII\P!697)Z:?-K]G9E=.ES`$;\9V<N(&5L:&5L
M>65ZZ7,`1OQG9_5L96=E<R!B96QS]2!M87)G\P!F_&=G]6QE9V5S.@!N86=Y
M;VX@;6%G87,`5FEE=&YA;0!V:65T;F%M:2`H5DE30TE)*0`E<R!M96=T96MI
M;G3I<V4`2_QL<_4@=V5B;VQD86P@;65G:F5L96[M=.ES90!*96QE;NUT<_QK
M(&UE9RP@;6EN="`E<P!"<FET(%9I<F=I;BUS>FEG971E:P!!;65R:6MA:2!6
M:7)G:6XM<WII9V5T96L`3.%T\W3A=F]L<^%G`$SA=/-TX79O;'/A9SH@`%9O
M9&%F;VYE($ET86QY('-Z;VQGX6QT873A<R!33510+6X@:V5R97-Z=/QL`$9)
M1UE%3$U%6E1%5,E3`$9)1UE%3$U%6E1%5,E3(2!+R5I:14P@5,%63TS-5%-!
M($5,($$@4T-225!4150@)7,M4M5,+@!724X@<WIO;&?A;'1A=.%S($A45%`M
M;B#A=`!786QL:7,@Z7,@1G5T=6YA`$9I9WEE;&UE>G1E=.ES`%-Z90!)9/5J
MX7+A<R!E;/5R96IE;'KI<P!!>B!I9/5JX7+A<VD@861A=&]K(&9O<G+A<V$`
M5V5B`%=E8FAE;'EE:P!H971E;G1E`-QD=O9Z]FQJ_&L`W&1V]GKV;&K\:SH@
M)7,`W&1V]GKV;&K\:RP@)7,`;GEU9V%T+65U<O-P86D@*$E33RTX.#4Y+3$I
M`&YY=6=A="UE=7+S<&%I("A)4T\M.#@U.2TQ-2D`3GEU9V%T+5-Z86AA<F$`
M36EL>65N(&%L:V%L;6%ZX7-T(&UU=&%S<V]N("5S(&$@8F5J96QE;G1K97KI
M<R!U=.%N/P!-:2!A>B!E;';A;&%S>G3S(&MA<F%K=&5R/P!-:2!A>B!I9.EZ
M971K87)A:W1E<C\`5VAE<F5I<R!!=7-Z='+A;&EA('3I<FOI<`!-96QY:6L@
M8VEK;'5S`$UE;'EI:R!M;V1U;&]K870@86MT:7;A;&IU:R!A(%)I8V@@5&5X
M="!E9&ET;W)B86X_`%-ZZ6QE<W/I9P!3>NEL97-SZ6<@0U-3(&5G>7/I9V)E
M;@!!("5S(&UE;OP@<WKI;&5S<^EG92!A(&)A;"!O;&1A;&]N("AA(&OV=F5T
M:V5Z]2!B96IE;&5N=&ME>NES="!K]G9E=/5E;B!L97-Z(.ER=NEN>65S*0!!
M('3A8FSA>F%T('-ZZ6QE<W/I9V4`02!S>NEL97-SZ6<@;>ER=.EK96=Y<^EG
M90!3>NEL97-SZ6<Z`%=I:VD`4WKI;`!3>NEL(&$@<F5G9V5L:2#S<N%K8F%N
M`%-ZZ6QS96)E<W/I9R!C<V]M\V)A;@!3>NEL.@!3>NEL.B``0O9L8W-E<W/I
M9P!+[7;A;G/A9VQI<W1A`$UU;FMA`$UU;FMA:&5L>6D@8^UM`$UU;FMA:&5L
M>6D@=&5L969O;@!!("5D+B!S;W)B86X@;F5M(&UE9V9E;&5L]2!A(&UE>O5K
M('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"X`3F5M(&UE9V9E;&5L]2!A
M(&UE>O5K('-ZX6UA+B!6X7)T.B`E9"P@=&%LX6QT.B`E9"X`2&EBX7,@;V9F
M<V5T("@E9"D@82!61E,@9N%J;"!O;'9A<^%S86MO<BX`3&EN=7@@9F]R<N%S
M:_-D(&ME<F5S>G)E9F5R96YC:6$`6#4P.78S(&%L87!V973U(&MO<FSA=&]Z
MX7-O:P!8-3`Y=C,@:VET97)J97-Z=&5T="!K=6QC<VAA<WINX6QA=`!8-3`Y
M=C,@='5L86ID;VYO<R!A;'1E<FYA=.UV(&UE9VYE=F5ZZ7-E`%@U,#EV,R!T
M=6QA:F1O;F]S(&MU;&-S87IO;F]S[73S`%@U,#EV,R!K:71E<FIE<WITZ7-E
M:P!960!965E9`%EA:&]O(2!TZ7)KZ7``Z79E;G1E`$IE;65N`$EG96X`26=E
M;BP@8F5L96=Y97IE;2X`36]S="!(5$U,(%1%6%0@;?-D8F%N('9A;BX@2&%S
M>F[A;&IA(&$@6SP^72!G;VUB;W0L(&AA('9I<W-Z82!A:V%R(';A;'1A;FD@
M82!S>F]KX7-O<R!G<F%F:6MU<R`H5UE325=91RD@;65G:F5L96[M=.ES<F4N
M`$YE;2!H;WIH870@;.ET<F4@)60@8FQO:VMNX6P@=/9B8F5T+@!!>B#6;B!F
M96QH87-Z;N%L\V%Z;VYO<^UTX7-A(&YE;2!T]G)TZ6YT(&UE9RX`02!T96QJ
M97,@;NEV8F5N(&YE;2!S>F5R97!E;&AE="!A("=<)R!K87)A:W1E<BX`3F5M
M(&%D;W1T(&UE9R#I<G;I;GEE<R!E;6%I;"!C[6UE="X`3F5M(&%D=&$@;65G
M(&$@;65G9F5L96QT973I<W0@87H@:6UP;W)TX6QT(&;A:FP@Z7,@82AZ*2`E
M<R!M97KU:2!K]GKV='0N`%-I:V5R97-E;B!K:6IE;&5N=&ME>F5T="X`16=Y
M(&UO8FEL=&5L969O;G-ZX6UO="!K96QL(&UE9V%D;FEA+"!C<V%K(&$@<WKA
M;6IE9WEE:V5T+"!E<V5T;&5G(&5G>2`G*R<@:V%R86MT97)R96P@:V5Z9'9E
M+"!H82!N96UZ971K]GII('3A<F-SX7KA<VD@;?-D;W0@:^UVX6X@:&%S>F[A
M;&YI+@!%;&9O9V%D:&%T\R#I<G3I:V5T(&ME;&P@;65G861N:6$N`$$@1&%T
M851R964@86QR96YD<WIE<G0@8F4@:V5L;"#A;&SM=&%N:2!A(&)E:F5L96YT
M:V5ZZ7-I(&IO9V]S=6QT<^%G;VL@:6?I;GELZ7/I:&5Z+@!!(%9&4R!A;')E
M;F1S>F5R(&YI;F-S(&)EX6QL[71V82X`16SU8F(@;&4@:V5L;"#M<FYI82P@
M:&]G>2!M:6QY96X@<')O8FSI;>%T('1A<&%S>G1A;'0L(&UI96SU='0@96QK
M_&QD:2!A(&AI8F%J96QE;G3I<W0N`$UE9R!K96QL(&%D;FD@96=Y(%523"UT
M+"!A:&]V82!E>B!A(&QI;FL@;75T870`2VD@:V5L;"!VX6QA<WIT86YI(&5G
M>2!T]G)L96YD]2!S>F5R=F5R="X`365G(&ME;&P@861N:6$L(&AO9WD@;65L
M>6EK(&9E;&AA<WINX6SS(&%D871A:70@:^UVX6YJ82!T]G+V;&YI+@!-96<@
M:V5L;"!A9&YI82!A>B!E;'3A=F]L[71A;F3S(&9E;&AA<WINX6SS:2!N979E
M="X`365G(&ME;&P@861N:6$@82!H;WIZX6%D86YD\R!F96QH87-Z;N%L\R!N
M97;I="X`365G(&ME;&P@861N:6$L(&AO9WD@;65L>6EK(&9E;&AA<WINX6SS
M(&%D871A:70@:^UVX6YJ82#A=.UR;FDN`$UE9R!K96QL(&%D;FEA(&5G>2!P
M87)A;F-S;W0N`$UE9R!K96QL(&%D;FEA(&%Z(/IJ(&MA=&5G\W)I82!N97;I
M="X`3VQA<WIO<G-ZX6=I('1E;&5F;VYS>N%M;W0@:V5L;"!M96=A9&YI80!!
M>B#6;B`E<R!K87!C<V]L871A(&ED]73Z;&SI<.ES(&UI871T(&UE9W-Z86MA
M9'0N($OI<F5M(&IE;&5N=&ME>GIE;B!B92#Z:G)A+@!!>B#6;B!E;6%I;"!C
M[6UE`$%Z(-9N(&9E;&%D\VD@*$9R;VTZ*2!C[6UE.@!3>F5MZ6QY97,@:6YF
M;W)MX6-I\P!!>B#6;B`E<R!K87!C<V]L873A;F%K(&ME>F1E=&4@\W1A(&UE
M9W;A;'1O>F]T="!A>B!I;G1E<FYE="!C[6UE+B!":7IT;VYSX6?A;F%K(.ER
M9&5KZ6)E;B!I<VWI="!B92!K96QL(&IE;&5N=&ME>FYI92X`07H@UFX@;F5V
M90!!>B#6;B!F96QH87-Z;N%L\V%Z;VYO<^UT\R!A;')E;F1S>F5R92!N96T@
M=&5S>FD@;&5H973U=ND@87H@^FH@9F5L:&%S>F[A;/-K(&SI=')E:&]ZX7/A
M="X@2&$@82!(;W)D92!R96YD<WIE<G)E;"!K[7;A;FIA(&ME>F5L;FD@82!F
M96QH87-Z;N%L\VD@861A=&]K870L(&%K:V]R(&WA<VEK(&9E;&AA<WINX6SS
M87IO;F]S[73S(&%L<F5N9'-Z97)R92!V86X@<WK\:W/I9V4N`$%Z(-9N(&9E
M;&AA<WINX6SS87IO;F]S[73S(&%L<F5N9'-Z97)E(&YE;2!T97-Z:2!L96AE
M=/5VZ2!A(&9E;&AA<WINX6SS:R!L:7-TX7KA<^%T+"!V86=Y('9A;&%M:2!O
M:V+S;"!L971I;'1O='3A:R!E>G0@82!L96AE=/5SZ6=E="X`07H@UFX@8O9N
M9^ES>O5P<F]G<F%M:F$@;65G=N%L=&]Z;W1T(&%Z(-9N("5S(&UU;FMA:V%P
M8W-O;&%TX6YA:R!K97ID971E(/-T82X@0FEZ=&]N<^%G82#I<F1E:^EB96X@
M:7-MZ70@8F4@:V5L;"!J96QE;G1K97IN:64N`$%Z(-9N(&+V;F?I<WKU<')O
M9W)A;6IA(&YE;2!TX6UO9V%T:F$@97IT(&$@;&5H973U<^EG970N`$%Z(-9N
M(&+V;F?I<WKU<')O9W)A;6IA(&YE;2!TX6UO9V%T:F$@97IT(&$@;GEO;71A
M=.%S:2!O<&-I\W0N(%!R\V+A;&IO;B!A($-T<FPM4"`H=F%G>2!#;VUM86YD
M+5`I(&QE;GEO;>%SX79A;"!N>6]M=&%T;FDN`$$@:F5L96YL96<@Z7)VZ6YY
M97,@:63U>O-N83H`07H@UFX@86QA<.ER=&5L;65ZZ7,@<WIE<FEN=&D@87IO
M;F]S[73S:F$@;65G=N%L=&]Z;W1T+@!!>B#6;B!A;&%PZ7)T96QM97KI<R!S
M>F5R:6YT:2!A>F]N;W/M=/-J83H`07H@UFX@=&5L:F5S(&YE=F4Z`$QE:N%R
M="!A(&)E:F5L96YT:V5ZZ7-I(&IO9V]S=6QT<^%G82X`07H@UFX@)7,M<F4@
M:&%S>F[A;'0@^FH@:F5L<WIA=F$Z("5S`$%Z(-9N(/IJ(&)EX6QL[73A<V%I
M="#I<G;I;GEE<^UT971T_&L@82!M;W-T86YI(&)E:F5L96YT:V5ZZ7,@:61E
M:NER92X`07H@UFX@^FH@8F7A;&SM=.%S86ET(&5L;65N=&5T=/QK+@!!>B#6
M;B!J96QS>F%VX70@X73A;&SM=&]T='5K`$%Z(-9N(&IE;'-Z87;A="#A=.%L
M;.UT;W1T=6LL(&[I>GIE(&UE9R!A(&QE=F5L96ET+"!M86ID(&IE;&5N=&ME
M>GIE;B!B92!A>B#Z:B!J96QS>O-V86PN`$%Z(-9N(&IE;'-Z87;A;F%K(&QE
M:N%R="!A>B#I<G;I;GEE<W/I9VD@:61E:F4N`$%Z(-9N(.%L=&%L(&AA<WIN
MX6QT('3A=F]L:2!S>F5R=F5R96LZ`$IU9V]S>FSA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!;3F4@;75T87-S=6L@82!B96EDZ7IE='0@<WKV=F5G971=
M`%M(:6)A:F5L96YTZ7-=`%M-=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E
M="`M`%M-=71A<W-U:R!A(&)E:63I>F5T="!S>O9V96=E="`M("5S('-O<ET`
M6R5S+R5S('-O<ET`7T%D;6EN:7-Z='+A8VGS`%]087)A;F-S<V]R`%-O<G3V
M<FSI<P!?0W-O<&]R=&]K`%-E7V?M='/I9P!!(&OI<"!T=6QA:F1O;G/A9V%I
M+BXN`$)E:F5L96YT:V5ZZ7,`7TMI:F5L96YT:V5ZZ7,`02!L:6YK(&WS9&]S
M[73A<V$N+BX`7T]P8VGS:P!?2F]G;W-U;'1SX6=O:P!!(&QI;FL@=/9R;.ES
M92XN+@!?0F7A;&SM=.%S;VL`5.%B;.%Z870@='5L86ID;VYSX6=O:P!?1F5L
M:&%S>F[A;/-K`&/M;6IE9WEZZ6L`82!C[6UZ971T(&ES;65R971L96X`;F%P
M=.%R`&YY=6=O9'0`82!K:6UE;F5T:2#A;&QO;>%N>2!N96T@:&]Z:&%T\R!L
MZ71R90!A(&)E;65N]2#A;&QO;>%N>2!N96T@;GEI=&AA=/,@;65G`&MA='1I
M;G1S;VX@:61E`'!A<F%N8W-S;W)I(&AI8F$`:V]N9FEG=7+A8VGS<R!H:6)A
M`&AIX6YY>FEK(&5G>2!F;VYT;W,@<F5N9'-Z97+A;&QO;>%N>0!A9&%T9F]R
M;>%T=6T@:&EB80!M\V1O<^UTX7,`87H@861A="!N96T@=&%LX6QH873S`&-S
M]FMK96X`9N%J;``E<R`H)7,I(&ERX6YY8O-L+"`E<R`E<R!S96)E<W/I9V=E
M;`!S>NEL;/9KZ7-E:P!M.@!A(&?I<"!N979E(&YE;2!I<VUE<G0`87IO;FYA
M;&D`:6YP=70O;W5T<'5T(&AI8F$`8F5L<_4@<')O9W)A;6AI8F$`<V]R70!!
M>B!M:W-I;V9S('!R;V=R86T@)60@:&EB86OS9&1A;"!L9>%L;'0@87H@25-/
M(.%L;&]MX6YY(&OI<WKM=.ES92!K]GIB96XN`&[I=@!!('!R;V=R86UN86L@
M97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!!('!R;V=R86UN
M86L@97H@82!RZ7-Z92!MZ6<@;FEN8W,@;65G=F%L\W/M='9A+@!J96=Y>F5T
M=/9M8@!S>N%Z86SI:P!N:6YC<R!M96=F96QE;/4@:F]G;W-U;'1SX6=A`'!I
M>&5L`&%D873A='9I=&5L:2`H<')O=&]K;VQL*2!H:6)A`&5M96QK961I:P!A
M('-Z;VQGX6QT873A<R!N96T@X6QL(')E;F1E;&ME>NES<F4`;NEZ>OQK(&UE
M9R!A(&O\;/9N8G/I9V5K970`<VUS,F5M86EL('-Z;VQGX6QT873A<R!(5%10
M+6X@X70`=N%L=&]Z871L86X`<F5N9'-Z97)H:6)A`&9E;&%D871L:7-T80#A
M=&UE;F5T:2!H:6)A`&UE9V5R]7/M=.ES:^EN="!KZ71S>F5R(.UR:F$@8F4@
M82!J96QS>O-T`&[I=B!NZ6QK_&P`82!F96QH87-Z;N%L\R#A;'1A;"!VX6QA
M<WIT:&%T\P!V0V%R9`!S>CH`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:61?
M240O3$-?34534T%'15,`````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#0V`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]I9%])1"],0U]-15-304=%4R]H;W)D92YM;P``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V-#`Q-B`Q,#4Q-30S-#$T,2`P,C,Q
M-S,`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MWA($E0````!U`P``'````,0;``"=!```;#<```````#@20``!````.%)```D
M````YDD``"D````+2@``&0```#5*```F````3TH```P```!V2@``)````(-*
M```/````J$H```L```"X2@``*````,1*```(````[4H``!4```#V2@``"P``
M``Q+``"%````&$L```H```">2P``#@```*E+```/````N$L``!@```#(2P``
M#@```.%+```.````\$L```@```#_2P``+@````A,```)````-TP```T```!!
M3```!P```$],```*````5TP```\```!B3```!0```'),```1````>$P```@`
M``"*3```"0```)-,```)````G4P``!,```"G3```$````+M,```*````S$P`
M``,```#73```#P```-M,```)````ZTP```T```#U3```#P````--```/````
M$TT```@````C30``)````"Q-```(````44T``!D```!:30``#````'1-```.
M````@4T```,```"030``!0```)1-```*````FDT```,```"E30``%P```*E-
M```*````P4T```X```#,30``(P```-M-```4````_TT``!<````43@``%P``
M`"Q.```7````1$X``!,```!<3@``#P```'!.```&````@$X```L```"'3@``
M$````)-.```5````I$X``!4```"Z3@``!P```-!.```%````V$X``!4```#>
M3@``.P```/1.```4````,$\```,```!%3P``"0```$E/```Y````4T\``"<`
M``"-3P``+````+5/```J````XD\``"4````-4```!@```#-0```1````.E``
M``P```!,4```"@```%E0```0````9%```!0```!U4```"````(I0```.````
MDU````H```"B4```!````*U0```)````LE````8```"\4```$0```,-0```'
M````U5````0```#=4```!@```.)0```-````Z5````,```#W4```$P```/M0
M```(````#U$```0````840``00```!U1```&````7U$``!4```!F40``!P``
M`'Q1```5````A%$```\```":40``#0```*I1```/````N%$```T```#(40``
M%````-91```&````ZU$``!T```#R40``!@```!!2```4````%U(``%0````L
M4@``9````(%2```$````YE(```X```#K4@``&P```/I2```:````%E,``!P`
M```Q4P``*@```$Y3```%````>5,``!,```!_4P``$@```)-3```*````IE,`
M``\```"Q4P``#0```,%3```1````SU,```P```#A4P``!@```.Y3```,````
M]5,```8````"5```$`````E4```1````&E0```4````L5```#````#)4```%
M````/U0```8```!%5```!P```$Q4```-````5%0```D```!B5```"0```&Q4
M```*````=E0``!D```"!5```'0```)M4```,````N50``!````#&5```"```
M`-=4```(````X%0```8```#I5```!````/!4```.````]50``!T````$50``
M(````")5``"B````0U4``!\```#F50``(`````96```P````)U8``)(```!8
M5@``00```.M6```'````+5<```8````U5P``#0```#Q7```0````2E<```P`
M``!;5P``#@```&A7```/````=U<``!,```"'5P``#0```)M7```H````J5<`
M``,```#25P``#0```-97```1````Y%<``!<```#V5P``&P````Y8```"````
M*E@``!`````M6```#0```#Y8```#````3%@```X```!06```"````%]8```/
M````:%@```\```!X6```!P```(A8```-````D%@```T```">6```"P```*Q8
M```&````N%@```L```"_6```#````,M8```+````V%@```T```#D6```(@``
M`/)8```*````%5D``!@````@60``&0```#E9```6````4UD``!0```!J60``
M"P```']9```+````BUD```D```"760``&0```*%9```+````NUD``!<```#'
M60``%P```-]9```)````]UD``!8````!6@``#P```!A:```9````*%H``!8`
M``!"6@``)@```%E:``!#````@%H``!\```#$6@``+P```.1:```%````%%L`
M``0````:6P``"@```!];```*````*EL``!`````U6P``%P```$9;```1````
M7EL``!<```!P6P``"0```(A;```*````DEL```(```"=6P``#0```*!;```X
M````KEL``"````#G6P``#@````A<``![````%UP``!@```"37```!0```*Q<
M```;````LEP```8```#.7```$````-5<```/````YEP``!````#V7```#P``
M``==```/````%UT```P````G70``#P```#1=```'````1%T```X```!,70``
M"````%M=```3````9%T```0```!X70``!0```'U=```(````@UT```H```",
M70``#````)==```+````I%T``!````"P70``#````,%=```'````SET```H`
M``#670``#0```.%=```%````[UT```,```#U70``"@```/E=```$````!%X`
M`"8````)7@``#@```#!>``!\````/UX``!4```"\7@``!0```-)>```'````
MV%X```P```#@7@``"````.U>```*````]EX```8````!7P``"`````A?```"
M````$5\```8````47P``"0```!M?```0````)5\```D````V7P``"0```$!?
M```:````2E\```@```!E7P``&0```&Y?```.````B%\```(```"77P``!@``
M`)I?```-````H5\``!(```"O7P``%````,)?```&````UU\``!$```#>7P``
M"0```/!?```Y````^E\``#T````T8```.@```')@```$````K6```!4```"R
M8```!@```,A@```$````SV```!$```#48```"@```.9@```B````\6````0`
M```480``!0```!EA```.````'V$```4````N80``#P```#1A```2````1&$`
M``L```!780``)@```&-A```I````BF$``"0```"T80``)@```-EA```(````
M`&(```H````)8@``"0```!1B```2````'F(```H````Q8@``#````#QB```/
M````26(``!````!98@``<````&IB```.````VV(```D```#J8@``"@```/1B
M```2````_V(``!,````28P``!@```"9C```/````+6,``!(````]8P``$```
M`%!C```1````86,``&H```!S8P``#P```-YC```0````[F,```L```#_8P``
M(`````MD```4````+&0```P```!!9```#````$YD```/````6V0``!4```!K
M9```*0```(%D```J````JV0``"8```#69```)P```/UD```I````)64``"H`
M``!/90``&0```'IE``!"````E&4``!$```#790``$@```.EE```3````_&4`
M`!0````09@``%@```"5F```7````/&8``!````!49@``$0```&5F```T````
M=V8``!,```"L9@``$@```,!F```4````TV8``!H```#H9@``"0````-G```1
M````#6<```8````?9P``!P```"9G```6````+F<```0```!%9P``!````$IG
M```'````3V<```X```!79P``#````&9G```,````<V<```T```"`9P``#@``
M`(YG```$````G6<```\```"B9P``!P```+)G```(````NF<```D```##9P``
M%````,UG```,````XF<```T```#O9P```P```/UG```&`````6@``!D````(
M:```!````")H```-````)V@```H````U:```$````$!H```/````46@``!$`
M``!A:```%P```'-H```*````BV@``!$```"6:```"````*AH```/````L6@`
M``P```#!:```#@```,YH```0````W6@```L```#N:```&@```/IH```*````
M%6D```P````@:0``#P```"UI```(````/6D```8```!&:0``!P```$UI```%
M````56D```L```!;:0``!````&=I```#````;&D``!,```!P:0``$P```(1I
M```3````F&D```(```"L:0``!````*]I```%````M&D```0```"Z:0``"@``
M`+]I```-````RFD``&@```#8:0``!0```$%J```&````1VH```\```!.:@``
M&````%YJ```7````=VH``!\```"/:@```P```*]J```(````LVH```<```"\
M:@``"@```,1J```+````SVH```T```#;:@``&@```.EJ``!*````!&L```8`
M``!/:P``!@```%9K```8````76L``!<```!V:P``#0```(YK``!7````G&L`
M``(```#T:P``"P```/=K```(`````VP```H````,;```"P```!=L```,````
M(VP```T````P;```#````#YL```*````2VP``!8```!6;```"0```&UL```0
M````=VP``!(```"(;```!P```)ML```%````HVP```P```"I;```"````+9L
M```7````OVP```P```#7;```&@```.1L```3````_VP```0````3;0``"@``
M`!AM```$````(VT```4````H;0``.````"YM```*````9VT```\```!R;0``
M$P```()M```5````EFT``!,```"L;0``"````,!M```(````R6T``"L```#2
M;0``10```/YM``!!````1&X```0```"&;@``$P```(MN```4````GVX``!,`
M``"T;@``!P```,AN```%````T&X``!L```#6;@``"````/)N```1````^VX`
M``X````-;P```@```!QO```.````'V\```<````N;P``#@```#9O```&````
M16\``"@```!,;P``#````'5O```<````@F\``!<```"?;P``7````+=O```4
M````%'```!\````I<```$````$EP```'````6G````X```!B<```#````'%P
M```*````?G```!T```")<```&0```*=P```%````P7```!$```#'<```$0``
M`-EP```(````ZW````D```#T<```#0```/YP```*````#'$```<````7<0``
M#P```!]Q```&````+W$```L````V<0``&@```$)Q```*````77$```<```!H
M<0``#0```'!Q```(````?G$``!X```"'<0``"0```*9Q```*````L'$``!4`
M``"[<0``!0```-%Q```4````UW$```0```#L<0``$````/%Q```&`````G(`
M``<````)<@``'@```!%R```H````,'(``!P```!9<@``&@```'9R```4````
MD7(```0```"F<@``!@```*MR```&````LG(```H```"Y<@``&P```,1R```T
M````X'(``#0````5<P``*0```$IS```H````=',``"D```"=<P``4````,=S
M```(````&'0```4````A=```&0```"=T```9````070``",```!;=```&0``
M`']T```(````F70``!<```"B=```"@```+IT```'````Q70``"$```#-=```
M#@```.]T```3````_G0```@````2=0``!0```!MU```%````(74```0````G
M=0``"@```"QU```)````-W4```L```!!=0``#0```$UU```,````6W4```X`
M``!H=0``!````'=U```R````?'4``$4```"O=0``%P```/5U```>````#78`
M`!0````L=@``!P```$%V```.````278``"H```!8=@``!@```(-V```,````
MBG8``!$```"7=@``"P```*EV```V````M78```H```#L=@``(@```/=V```+
M````&G<```\````F=P``!0```#9W```.````/'<``!,```!+=P``!P```%]W
M```1````9W<``!,```!Y=P``%````(UW```8````HG<```<```"[=P``!0``
M`,-W```2````R7<```X```#<=P``#@```.MW```%````^G<```4`````>```
M+@````9X```F````-7@``",```!<>````P```(!X```-````A'@```D```"2
M>````P```)QX```*````H'@```(```"K>```$@```*YX```$````P7@```<`
M``#&>```#````,YX``!2````VW@``!<````N>0``$@```$9Y```'````67D`
M``8```!A>0``#@```&AY```5````=WD``!(```"->0``#P```*!Y```4````
ML'D``&D```#%>0``&@```"]Z```7````2GH``"<```!B>@``&@```(IZ```7
M````I7H``!L```"]>@``&0```-EZ```?````\WH``!,````3>P``"````"=[
M```)````,'L``$8````Z>P``/P```(%[```W````P7L``%<```#Y>P``!0``
M`%%\```?````5WP``"\```!W?```"````*=\```-````L'P``"T```"^?```
M!````.Q\``!/````\7P``"4```!!?0``'P```&=]```=````AWT``"4```"E
M?0``(````,M]```D````['T``"`````1?@``!P```#)^```-````.GX```P`
M``!(?@``%P```%5^```0````;7X```0```!^?@``"P```(-^```,````CWX`
M`!(```"<?@``$0```*]^```,````P7X``!H```#.?@``#0```.E^```;````
M]WX``!,````3?P``'````"=_```H````1'\```<```!M?P``$P```'5_```$
M````B7\``!<```".?P``"@```*9_```,````L7\```D```"^?P``!@```,A_
M```(````SW\```D```#8?P``!@```.)_```-````Z7\```L```#W?P```@``
M``.````)````!H````<````0@```&@```!B````[````,X```"@```!O@```
M-````)B````5````S8````<```#C@```"````.N````'````](````4```#\
M@```!P````*!```.````"H$```D````9@0``!@```".!```(````*H$```L`
M```S@0``!P```#^!```'````1X$``!$```!/@0``"````&&!```0````:H$`
M`!````![@0``!P```(R!```%````E($``!0```":@0``"P```*^!```-````
MNX$``"@```#)@0``%P```/*!```)````"H(```H````4@@``!P```!^"```"
M````)X(```X````J@@``,0```#F"```G````:X(``!0```"3@@``J0$``*B"
M```C````4H0``!<```!VA```'0```(Z$```8````K(0``"$```#%A```'P``
M`.>$```K````!X4``!T````SA0``$0```%&%```G````8X4``%0```"+A0``
M"P```."%```Q````[(4```<````>A@``!P```":&```-````+H8```L````\
MA@``!0```$B&```0````3H8```4```!?A@``$@```&6&```(````>(8```,`
M``"!A@``$````(6&```,````EH8```(```"CA@``%````*:&```,````NX8`
M``,```#(A@``!````,R&```:````T88```D```#LA@``#````/:&```7````
M`X<```<````;AP``#P```".'```%````,X<``!H````YAP``QP```%2'```+
M````'(@```8````HB```"0```"^(```+````.8@```T```!%B```%P```%.(
M```&````:X@``#,```!RB```$P```*:(```3````NH@``#(```#.B```$P``
M``&)```1````%8D``#(````GB0``%@```%J)```(````<8D```D```!ZB0``
M"@```(2)```4````CXD```@```"DB0``"````*V)```/````MHD```X```#&
MB0``$````-6)```)````YHD```D```#PB0``$P```/J)```9````#HH```H`
M```HB@``#````#.*```J````0(H```<```!KB@```@```'.*```0````=HH`
M`!@```"'B@```P```*"*```(````I(H```<```"MB@``#0```+6*```+````
MPXH``!0```#/B@``%0```.2*```O````^HH``"`````JBP``'````$N+```,
M````:(L``#$```!UBP``!0```*>+```_````K8L``!(```#MBP``"@````",
M```&````"XP```0````2C```!````!>,```*````'(P``!,````GC```!0``
M`#N,```&````08P```8```!(C```"````$^,```$````6(P```4```!=C```
M`@```&.,```,````9HP``$4```!SC```,@```+F,``!%````[(P``#`````R
MC0``*````&.-```I````C(T``"8```"VC0``)0```-V-```H`````XX``!(`
M```LC@``$P```#^.```0````4XX```D```!DC@``<P```&Z.```K````XHX`
M`!<````.CP``)P```":/```6````3H\```\```!ECP``'P```'6/```<````
ME8\``%$```"RCP``%`````20```%````&9```!(````?D```$````#*0```3
M````0Y````\```!7D```!````&>0```)````;)````L```!VD```!P```(*0
M```4````BI````\```"?D```#````*^0```/````O)````8```#,D```%```
M`-.0```&````Z)````0```#OD```!P```/20```9````_)````<````6D0``
M!@```!Z1```&````)9$```0````LD0``!P```#&1```&````.9$```8```!`
MD0``$````$>1```&````6)$``"(```!?D0``!P```(*1```+````BI$``$8!
M``"6D0``!@```-V2```L````Y)(``"P````1DP``%@```#Z3``!`````59,`
M``P```"6DP``,````*.3```5````U),``!(```#JDP``)````/V3```(````
M(I0``!L````KE```#0```$>4``"_````590```@````5E0``#@```!Z5```5
M````+94``!@```!#E0``#0```%R5```-````:I4```8```!XE0``*P```'^5
M```*````JY4```H```"VE0``"````,&5```*````RI4``!````#5E0``!0``
M`.:5```2````[)4```L```#_E0``.@````N6```\````1I8``!$```"#E@``
M#0```)66```)````HY8```8```"ME@``$````+26```.````Q98``!````#4
ME@``%0```.66```3````^Y8```\````/EP``+0```!^7```/````39<``"4`
M``!=EP``#````(.7```,````D)<```4```"=EP``!````*.7```(````J)<`
M``4```"QEP``$P```+>7```*````RY<``!````#6EP``,@```.>7```4````
M&I@``!0````OF```'````$28```6````89@``!(```!XF```#P```(N8```'
M````FY@```@```"CF```#P```*R8```4````O)@``!L```#1F```"0```.V8
M```%````]Y@``!,```#]F```20```!&9```3````6YD```0```!OF0``"@``
M`'29```]````?YD``"P```"]F0``+````.J9```K````%YH``"T```!#F@``
M!P```'&:```4````>9H```L```".F@``#@```)J:```4````J9H``!0```"^
MF@``.0```-.:```/````#9L```D````=FP``"P```">;```4````,YL```8`
M``!(FP``$````$^;```&````8)L```@```!GFP``!0```'";```-````=IL`
M``,```"$FP``#0```(B;```(````EIL```8```"?FP``50```*:;```%````
M_)L``!@````"G```"P```!N<```2````)YP```P````ZG```,0```$><```,
M````>9P``!8```"&G```%````)V<```&````LIP``!D```"YG```!````-.<
M```/````V)P``&8```#HG```:````$^=```(````N)T```\```#!G0``%P``
M`-&=```7````Z9T``"4````!G@``,P```">>```)````6YX``!8```!EG@``
M%@```'R>```2````DYX``!<```"FG@``&````+Z>```1````UYX```T```#I
MG@``!P```/>>```4````_YX```<````4GP``&````!R?```/````-9\```4`
M``!%GP``#0```$N?```%````69\```8```!?GP``!P```&:?```-````;I\`
M``@```!\GP``!P```(6?```'````C9\``!4```"5GP``*````*N?```+````
MU)\``!````#@GP``!@```/&?```&````^)\```8```#_GP``!0````:@```-
M````#*```"8````:H```)````$&@``"[````9J```",````BH0``)0```$:A
M```Q````;*$``+T```">H0``5````%RB```&````L:(```0```"XH@``"0``
M`+VB```)````QZ(```X```#1H@``$P```."B```.````]*(``!$````#HP``
M#0```!6C```W````(Z,```4```!;HP``#0```&&C```1````;Z,``!<```"!
MHP``&P```)FC```"````M:,``!````"XHP``$````,FC```$````VJ,```L`
M``#?HP``"````.NC```-````]*,``!`````"I```!P```!.D```-````&Z0`
M``T````II```"````#>D```%````0*0```D```!&I```"@```%"D```)````
M6Z0```L```!EI```)P```'&D```+````F:0``!T```"EI```&0```,.D```9
M````W:0``!````#WI```"0````BE```,````$J4```L````?I0``'P```"NE
M```+````2Z4``!(```!7I0``$@```&JE```)````?:4``!<```"'I0``$0``
M`)^E```=````L:4``!T```#/I0``*0```.VE``!6````%Z8``"H```!NI@``
M.````)FF```+````TJ8```0```#>I@``"P```..F```)````[Z8```D```#Y
MI@``$@````.G```3````%J<``!(````JIP``"@```#VG```)````2*<```(`
M``!2IP``#````%6G``!!````8J<``"$```"DIP``#P```,:G``"=````UJ<`
M`!H```!TJ```"0```(^H```F````F:@```0```#`J```#P```,6H```.````
MU:@```\```#DJ```#@```/2H```3`````ZD```P````7J0``$P```"2I```(
M````.*D``!<```!!J0``"````%FI```6````8JD```4```!YJ0```P```'^I
M```(````@ZD```<```",J0``"````)2I```0````G:D``!8```"NJ0``#```
M`,6I```&````TJD``!\```#9J0``'P```/FI```%````&:H```@````?J@``
M#0```"BJ```'````-JH``"\````^J@``$P```&ZJ``"?````@JH``!<````B
MJP``"````#JK```'````0ZL```P```!+JP``!P```%BK```)````8*L```4`
M``!JJP``"@```'"K```#````>ZL```4```!_JP``!````(6K```1````BJL`
M``T```"<JP``#````*JK```B````MZL```8```#:JP``'````.&K```4````
M_JL```@````3K```!@```!RL```0````(ZP``!,````TK```$0```$BL```$
M````6JP```D```!?K```"0```&FL``!.````<ZP``%````#"K```4````!.M
M```(````9*T``!4```!MK0``!@```(.M```'````BJT``!H```"2K0``#```
M`*VM```?````NJT```8```#:K0``!0```.&M```.````YZT```4```#VK0``
M'@```/RM```[````&ZX```L```!7K@``.@```&.N```N````GJX``"0```#-
MK@``+@```/*N```*````(:\```L````LKP``!P```#BO```9````0*\```H`
M``!:KP``#0```&6O```0````<Z\```\```"$KP``F@```)2O```-````+[``
M``H````]L```"P```$BP```2````5+```!,```!GL```#0```'NP```1````
MB;```!8```";L```$P```+*P```9````QK```),```#@L```#@```'2Q```0
M````@[$```D```"4L0``(0```)ZQ```9````P+$```\```#:L0``#@```.JQ
M```1````^;$``!D````+L@``-````"6R```T````6K(``#0```"/L@``-```
M`,2R```P````^;(``#`````JLP``&P```%NS``!!````=[,``!<```"YLP``
M%P```-&S```9````Z;,``!D````#M```'````!VT```<````.K0``!D```!7
MM```&0```'&T```\````B[0``!0```#(M```$@```-VT```5````\+0``!<`
M```&M0``"@```!ZU```Y````*;4```P```!CM0``!P```'"U```4````>+4`
M``0```"-M0``!````)*U```$````E[4```L```"<M0``$P```*BU```)````
MO+4```H```#&M0``#@```-&U```)````X+4```X```#JM0``"````/FU```&
M`````K8``"`````)M@``&````"JV```@````0[8``!(```!DM@``!0```'>V
M```(````?;8``!X```"&M@``!````*6V```'````JK8```<```"RM@``%```
M`+JV```:````S[8```<```#JM@``%@```/*V```(````";<```T````2MP``
M#0```""W```1````+K<```P```!`MP``#P```$VW```4````7;<```P```!R
MMP``'P```'^W```-````G[<```P```"MMP``&@```+JW```&````U;<```4`
M``#<MP``!P```.*W```%````ZK<```L```#PMP``!0```/RW```&`````K@`
M`!D````)N```&````".X```9````/+@```(```!6N```!````%FX```%````
M7K@```4```!DN```"P```&JX```,````=K@``&P```"#N```!0```/"X```&
M````]K@``!$```#]N```+@````^Y```L````/KD``"D```!KN0```P```)6Y
M```+````F;D```<```"EN0``"@```*VY```-````N+D```P```#&N0``'```
M`-.Y``!%````\+D```8````VN@``!@```#VZ```L````1+H``"L```!QN@``
M"0```)VZ``!R````I[H```,````:NP``"P```!Z[```&````*KL```@````Q
MNP``"@```#J[```4````1;L``!8```!:NP``%````'&[```*````AKL``!0`
M``"1NP``"````*:[```1````K[L``!@```#!NP``!P```-J[```,````XKL`
M``T```#ONP``"@```/V[```<````"+P```H````EO```%P```#"\```4````
M2+P```8```!=O```"P```&2\```*````<+P```4```![O```2P```(&\```4
M````S;P``!X```#BO```'0````&]```B````'[T``",```!"O0``$````&:]
M```.````=[T``#<```"&O0``8````+Z]``!;````'[X```D```![O@``(@``
M`(6^```9````J+X``!(```#"O@``#````-6^```'````XKX``"\```#JO@``
M"````!J_```,````([\```P````POP```@```#V_```.````0+\```<```!/
MOP``$@```%>_```&````:K\``"(```!QOP``"@```)2_```7````G[\``!X`
M``"WOP``:P```-:_```9````0L```"(```!<P```#@```'_````'````CL``
M`!````"6P```%````*?````(````O,```!8```#%P```&@```-S````)````
M]\````X````!P0``#````!#!```(````'<$```D````FP0``"@```##!```*
M````.\$```L```!&P0``$````%+!```(````8\$``"H```!LP0``'@```)?!
M```)````ML$``!<```#`P0``$````-C!```%````Z<$``!8```#OP0``!@``
M``;"```&````#<(``!(````4P@``!0```"?"```7````+<(```0```!%P@``
M&0```$K"```%````9,(```8```!JP@``(0```''"```S````D\(``"0```#'
MP@``$0```.S"```1````_L(``!,````0PP``!````"3#```%````*<,```\`
M```OPP``(@```#_#```[````8L,``$0```">PP``+P```./#```I````$\0`
M`"T````]Q```8@```&O$```'````SL0```<```#6Q```%P```-[$```6````
M]L0``"(````-Q0``'````##%```'````3<4``!P```!5Q0``"````'+%```%
M````>\4``"<```"!Q0``#0```*G%```1````M\4```8```#)Q0``!0```-#%
M```%````UL4```4```#<Q0``$@```.+%```8````]<4```<````.Q@``$@``
M`!;&```<````*<8```P```!&Q@``!````%/&```]````6,8``%P```"6Q@``
M&0```//&```<````#<<``!4````JQP``"````$#'```-````2<<``"D```!7
MQP``"0```(''```0````B\<``!4```"<QP``$@```++'``!%````Q<<```D`
M```+R```'P```!7(```2````-<@``!8```!(R```#0```%_(```2````;<@`
M`!<```"`R```!0```)C(```2````GL@``!8```"QR```%@```,C(```8````
MW\@```D```#XR```!0````+)```1````",D```X````:R0``#@```"G)```&
M````.,D```8````_R0``-@```$;)```L````?<D``"P```"JR0``"````-?)
M```)````X,D```D```#JR0```P```/3)```*````^,D```,````#R@``%P``
M``?*```&````'\H```D````FR@``#@```##*``!?````/\H``!X```"?R@``
M*0```+[*```0````Z,H```D```#YR@``#P````/+```9````$\L``!(````M
MRP``#````$#+```=````3<L``'D```!KRP``%````.7+```5````^LL``"P`
M```0S```$@```#W,```3````4,P``!L```!DS```&````(#,```@````F<P`
M`!4```"ZS```!P```-#,```)````V,P``%X```#BS```.@```$'-``!`````
M?,T``%0```"]S0``!0```!+.```=````&,X``"X````VS@``!P```&7.```0
M````;<X``#D```!^S@``"0```+C.``!5````PLX``#$````8SP``(P```$K/
M```B````;L\``",```"1SP``'P```+7/```E````U<\``"````#[SP``!P``
M`!S0```4````)-```!H````YT```&0```%30```3````;M````4```""T```
M#0```(C0```-````EM```!H```"DT```(````+_0```0````X-```"(```#Q
MT```#````!31```:````(=$``!0````\T0``(````%'1```H````<M$```L`
M``";T0``)P```*?1```$````S]$``!D```#4T0``#````.[1```.````^]$`
M``X````*T@``"````!G2```'````(M(``!(````JT@``!@```#W2```J````
M1-(```H```!OT@```P```'K2```X````?M(```@```"WT@``&P```,#2``!)
M````W-(``"L````FTP``,P```%+3```;````AM,```D```"BTP``#P```*S3
M```1````O-,```4```#.TP``#P```-33```A````Y-,``!`````&U```$0``
M`!?4```2````*=0``#$````\U```"````&[4```G````=]0``"T```"?U```
M)P```,W4```.````]=0```X````$U0``!P```!/5```%````&]4``!@````A
MU0``!````#K5```%````/]4``"$```!%U0``%0```&?5```*````?=4```T`
M``"(U0``$````);5```#````I]4```X```"KU0``+0```+K5```L````Z-4`
M`!<````5U@``'0(``"W6```=````2]@``!8```!IV```(````(#8```7````
MH=@``",```"YV```)````-W8```[`````MD``"`````^V0``%@```%_9```E
M````=MD``%X```"<V0``#@```/O9```N````"MH```4````YV@``!0```#_:
M```/````1=H```P```!5V@``!0```&+:```8````:-H```@```"!V@``$0``
M`(K:```%````G-H```0```"BV@``$0```*?:```)````N=H```,```##V@``
M$@```,?:```+````VMH```,```#FV@``!````.K:```E````[]H```L````5
MVP``$@```"';```;````--L``!````!0VP``#P```&';```$````<=L``"<`
M``!VVP``&0$``)[;```2````N-P```H```#+W```#0```-;<```3````Y-P`
M`!@```#XW```'0```!'=```&````+]T``#,````VW0``&````&K=```9````
M@]T``#H```"=W0``%0```-C=```4````[MT``#D````#W@``(````#W>```-
M````7MX```X```!LW@``#@```'O>```9````BMX```<```"DW@``"````*S>
M```-````M=X``#8```##W@``,0```/K>```)````+-\```T````VWP``$```
M`$3?```8````5=\```T```!NWP``#@```'S?```Y````B]\```H```#%WP``
M!````-#?```-````U=\``!H```#CWP```P```/[?```(`````N````X````+
MX```%````!K@```2````+^```!0```!"X```%0```%?@```S````;>```"4`
M``"AX```*0```,?@```.````\>```#P`````X0``!0```#WA``!'````0^$`
M``L```"+X0``"@```)?A```&````HN$```0```"IX0``!0```*[A```2````
MM.$``!T```#'X0``!@```.7A```&````[.$```X```#SX0``$`````+B```)
M````$^(```4````=X@```@```"/B```/````)N(``&(````VX@``-@```)GB
M``!.````T.(``#4````?XP``+@```%7C```[````A.,``#L```#`XP``,P``
M`/SC```W````,.0``!$```!HY```$@```'KD```.````C>0```D```"<Y```
M?````*;D```M````(^4``!D```!1Y0``)````&OE```7````D.4``!(```"H
MY0``(P```+OE```=````W^4``&$```#]Y0``$P```%_F```%````<^8``!P`
M``!YY@``$0```);F```:````J.8```T```##Y@``!````-'F```)````UN8`
M``L```#@Y@``!0```.SF```2````\N8```P````%YP``!````!+G```1````
M%^<```8````IYP``$0```##G```(````0N<```8```!+YP``!0```%+G```7
M````6.<```T```!PYP``%@```'[G```&````E><```0```"<YP``!@```*'G
M```%````J.<```0```"NYP``$P```+/G```%````Q^<``"D```#-YP``"@``
M`/?G```+`````N@```$```#/````7`(``!P"``#1`@```````),````4````
M0`(``#H#``!L`0``L````$@#``#<`@```````(H"```H`P``$@```&X#````
M`````````%\#````````X0````````#D`@``&@(```````!Y````1P(`````
M````````X@```$X"``"_`@``/`$```````#7`0``\@```)(!``"``0``+P(`
M`'`````T`P``:P```$L``````````````)P!``#N````<@,``/$!``!5`@``
M$`$```,`````````:P$```````!\````)P```*8!```'`@``?0(``)@```"\
M`@```````!L!``!H````#``````````.`0``/P(```````!T`0``````````
M``"7`@```````!\``````````````````````````````#8```!S`0``A@(`
M`/L```"+`@``]P(``"4#``!B`@``O`$``)L!```U````GP```!L`````````
MF0(``.8````E````!0,``(<!``"/`0```````#T"````````"0```$T"``!=
M````9@(``($"``!C````DP$``',#````````7`,````````W`P``4P```!<`
M````````\`$``*L````"`@``!P```%8#``"L`0``GP$```````#_`@``````
M`/X"```.`P``CP(```8"``#S`0``AP```'`"``!9`P```````)H```!/````
MQ@(``",```"S`````````-4"````````H0$``$,```#J````=@(```````#,
M`0``%@$``+H```!/`0``#`$``&0!```R`P``,````+H!``"M`0``,P,``!$!
M``#1`0````````<#````````(0```)4!```1`@``.P(``$H!````````[`$`
M``````#%`@``)`$`````````````)@````````#O`0``M````/0!``"'`@``
M*`(``-X!``#*````?0````````"#`0``,@$``,X```"Q`0``:@$``/\```#]
M`0``<`,``%\```"0`0```````&@#``"[`0``-P(``/$```!H`@``8P(``+@"
M``#@`0``S`(```````!O````M@````````#J`@```````)4"````````````
M`!P`````````^P$```````#8`@``:P,``!,"``!$`P``>P$``&$"``!C`P``
M<@$``.0!```Z`@```````&D!`````````````&<#````````[0(```````"L
M````=P(``'<!``"^`0``50,``-P!``!#`0```````%\!``!/`@``10(`````
M``!3`@``O0$``&T#```.`@``80,``!0!``"+````(@,``!`"```A`P``K`(`
M`-,"``````````````````!_`@``LP(```````````````````````#K````
MU`$```````#B`0``J0```+<"````````"`$```````"H`@```0,`````````
M````&@,``-X```"4`0``<@```"P```#.`0```````$("```^`@``@`(`````
M```M`P``CP````````!]`0``@@```)$"``#4`````````)@!``!X`0``9P$`
M`"`#``#``0``K@$```````#E`````````),"``#H`0```````',```!)`0``
M3@```$$"````````-0$````````R`@``F0$``,<"``"[`@``9`(`````````
M````<0(``$0!``!Q`````````"4"``!_````RP```(T````]`P``UP(`````
M``!B````%0,```<!`````````````(,```"C`@``I`(``/H"````````````
M`(4```!9`0``A0$```````!U`P```````$P#````````9@$``)<!````````
M"````&<````!`@``G0$``(D!```5`@``V@$```````#Q`@``-@$``'<````K
M`0```````/<````&````?`$````````6`@``=0``````````````````````
M```:`0``F@$``&,!````````^````&`````Q`@``,`(```````!2`@``3`(`
M`+D```!^`0``'@,````````A`0``*0```$8#``#+`@``*````#0"```%````
MM`$``%(!``#0`0``;@$``$<!``"?`@`````````````G`0``!`$``#X`````
M````70(````````X`0``]0```-\```!A`0```````%(```"%`@``@0```(X"
M```=````%0$``!@"```I`P``T@$``-H`````````H`$``/,```"E`0``#P(`
M`)@"````````4`(``*8````4`P``B0(```````#L`@``6```````````````
M_0```#`#`````````````%`!```D````\````(``````````U0`````````U
M`@``/`,``#P```#(`0``T0``````````````TP```+\`````````N`````(#
M`````````````(@"```X`P``2@,``/<!````````V@(```````!Z````90(`
M`'4"``!Z`@``Q0$`````````````*`$``,(```"O`0``W0$``!T!````````
MT@````4!``!+`P```````,4````3`P``Z````,L!```Q`P``X0(``$0"``"J
M`0``HP`````````$`@``P0$``)("``!0````/0```'X"```1````1P```/D`
M``#5`0``QP```'@"``"U`````````)8```````````````\#``!@`@``L@(`
M`#,!``#G````(P(``"X"``!Z`0``30```",!``!'`P``````````````````
MJ0(```````!7````J`$```````!S`@````````````!J`P``G0```#H!````
M````[@$``"L#````````(`(``!8````F`0``7@,````````"`0``W0```*T"
M``#I`````````&T!``"A`@``[P(``&H"`````````````/H```!#`P``(```
M`$8```!I````````````````````M0(``/\!``````````````T```!I`P``
MVP$```4"```3`````````/@!``#9````E@$``*D!``!L`````````"X`````
M````[@(``%D````Y`P```````.4!``!8`@``+`$``+0"````````'P(``)H"
M``"!`0``10,``&8```"V`0``:@```$@!``"^`@``*@$``$H"```B````:0(`
M`"P#``!1````#0$``'0```!O`@````````````">`@``8@$````````-`P``
M```````````Q````@@(``/D!``#F`@``````````````````,P```+<`````
M`````````+P`````````:P(``$\#``"9```````````````*`@``H````*X`
M````````6@$``'0"``#O````>P(``.,"```^`P``;@(``%$#````````#@``
M```````[````20(``"X!``"G`0```````%L!``">`0``BP$``)L```!,````
M`````"H"````````.@````````!`````Z0(`````````````%P$``!(!``!P
M`0``50````````#?`@``6@(``/8````X`@`````````````P`0``S0```#8"
M```I`@``40(``"\!``#U`@``0@$``(D```#V`0```````'D!``!M`@``E0``
M`%D"`````````@```!````!\`@``&`,``!,!``"$`````````"8#```1`P``
M`````+X``````P````````````!-`0``B@$``&4```"Y`0``=@```%X````T
M`0``U`(``(P!````````)0$``*8"```X````K@(```````#`````6P``````
M````````80```.T!``".`0``N`$````````+`0``:`$```H#``!4`P``-```
M`!T"``!%````-P```,0````_`0``"@``````````````&0(``#D"``#)`0``
M(@(``-D"```&`0``&@```.<"```,`@``5P$```````"7`````````+<!```N
M`P```````*H````M````0`$``.@"```6`P````````````#'`0```````*4"
M```M`@``'@```+$"``#T````PP$`````````````H`(``%\"``"1````'@$`
M`+H"````````JP$``%L#````````V````#P"```$````2P$```P#```<`P``
M`````&\#`````````````$0```#[`@``"@$``#4#````````,P(``$8!```)
M`P```````+T"``"1`0``R@$``"$"`````````````,,```#P`@``@P(``,$"
M```/``````(``+T```#U`0```````,("````````6P(```````!V`0``````
M`+`!```C`P``7`$``$X#```;`@``0@````````#R`0``V0$``-`"``#B`@``
M`````,T!``!)````N0(``!@!``#Y`@``]`(``.4"```9`0``Q@```#D!```G
M`@``0P(``"L"``!%`0````````````",````B`$```````!L`@```````)(`
M``#G`0``SP$``)`"``#]`@````````````!O`0``;0````````"R`0``&0``
M`-@!```2`P``7@(``%@!``"&````4P$```,!`````````````#L#``!E`P``
MA@$``/X````;`P``ZP(``*L"``!R`@``SP(``-,!````````$`,``'X```#`
M`@``[0```"0"``"S`0``00````````"O`@````````````#6`0``````````
M````````H0`````````&`P``90$``)T"```I`0``A`$``+4!```+`@``,@``
M``````"P`@``````````````````1@(```````"G````"`(``)0```#,````
MS@(``'\!```B`0``.P$```````"<`@``)P,``%<#````````H@````````#^
M`0``20,``-("````````G````&P#`````````````/,"``!"`P``/P,``.L!
M``#D````C@````````#@`@```````#D`````````)@(``%4!``!T`P``C0$`
M`'L```!:`P``Q`$````````O````&0,```````#V`@```````,D```!1`0``
M`````%0"````````I````#T!````````W``````````K````;@```%T#```4
M`@``%P,```````"B`0``/P```$`#``",`@``PP(```````#\`0```````-``
M```$`P```````-8"``#\`````````+(```#?`0``4P,``$@"````````````
M`'D"```+`P``8`$``%8"``#(`@``Q@$``#X!```V`P``"0$``%T!``!G`@``
M00,``!<"````````Q`(``*H"``#6````3@$``,@```#=`@````````````!>
M`0``>````*\```````````$``"`!````````'`$``*,!````````%0```"\#
M``#;````E@(``)0"```J`P``````````````````"P```'$!``"*````NP``
M````````````#P$``/("``#7```````````````W`0```````$L"``#-`@``
MP0```!X"``#;`@``FP(``*("````````5P(``/P"``"0````8@,``!T#```2
M`@``IP(``.$!``!-`P```````.P```#Z`0```P(```````"_`0```````,D"
M``"-`@``5`$``.,``````````````$P!`````````````(@```!@`P``"0(`
M`(0"``!*````Y@$``'$#```D`P``9````%0```!!`0``7````"T!``#C`0``
M`````((!``#*`@``6`,``%(#```!`0``*@```*0!``#@`````````'4!````
M````#0(``.H!````````6@```&8#`````````````%8```!(````+`(``*4`
M``"Q````&````````````````````&0#``#X`@``5@$``#$!``"V`@``G@``
M`!\#``!0`P``'P$```@#```#`P``P@$``.D!`````````````*T`````````
M`````*@```#>`@```"!A="``(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P
M<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S
M>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@
M;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A
M>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A
M<W0`)7,@+2!.;W1I8V4`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O
M;F9I<FUA=&EO;@`E<R!3971U<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@
M870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O
M<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI
M<R!T:6UE+@`E<R!M:6YU=&5S`"5S('1O("5S(&]F("5S`"P@9W5S=&EN9R`E
M<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`,3(@2&]U<B!&;W)M870`
M,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD(&ES
M(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!32!#;&]U9',`04T@3&EG:'0@
M4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D
M;&4`06-C;W5N="!);F9O<FUA=&EO;@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@2&5R93H`061D($YE=R!'
M<F]U<`!!9&0@82!N97<@=7-E<CH`061D(&YE=R!M96UB97)S`$%D9"!P86ER
M`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=7-E
M<@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,@0F]O:P!!9&UI
M;FES=')A=&EO;@!!9',`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE
M;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@9F]U<B!S:61E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U3
M4"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U3
M4"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@
M=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;G-W97(`07!P;&EC871I;VX`
M07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@
M=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R:6P`07)A8FEC("A7:6YD;W=S
M+3$R-38I`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I
M9VYU<"!R97%U97-T(&9O<B`E<R`_`$%R;65N:6%N("A!4DU30TE)+3@I`$%R
M=`!!<V-I:2!!<G0`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%T=&5M<'0@=&\@9&5L971E(&$@
M;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE
M>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI
M<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T
M96YT('-H87)E+@!!=6=U<W0`079A:6QA8FQE(&9I96QD<SH`0D]&2"!%>&-U
M<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"86QT:6,@*$E33RTX
M.#4Y+3$S*0!"87-E;&EN90!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O
M;&0`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S
M`$)O=&@`0F]T=&]M`$)U;&QE=&5D($QI<W0`0TU3`$-?96QL(%!R;W!E<G1I
M97,N+BX`0V%L96YD87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U
M=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86YC
M96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A<'1I;VX`0V%T96=O<FEE<R!A
M;F0@3&%B96QS`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@
M<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;'1I8R`H25-/+3@X-3DM,30I
M`$-E;G1E<@!#96YT<F%L($5U<F]P96%N("A)4T\M.#@U.2TR*0!#:&%N9V4`
M0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R
M97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@
M=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T
M('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN
M+@!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2D`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O
M<V4@;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VQE87(`
M0VQE87(@35-/9F9I8V4@=&%G<P!#;&5A<B!O=70@=7-E<CH@)7,`0VQE87(@
M=7-E<@!#;&5A<B!U<V5R(&1A=&$`0VQE87)I;F<@3&%T90!#;&EC:R!T;R!#
M;VYT:6YU90!#;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U
M9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#;VQO<@!#
M;VQO<B!0:6-K97(`0V]L<SH`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L
M;`!#;VUP=71E<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO
M;B!$:69F97)E;F-E<P!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+@!#
M;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYT86-T<P!#;VYT:6YU
M90!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W5L9"!N;W0@8FEN9"!T
M;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8V]N;F5C="!T;R!L9&%P('-E<G9E
M<@!#;W5L9"!N;W0@<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S
M=&5D('5S97(N(%-O;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@
M8V]R<F5C="X@5')Y(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A
M=&]R(&EF('EO=2!N965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=F5R
M="!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T
M:6]N+@!#;W5L9"!N;W0@<V%V92!T:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@
M9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE(&-O;F9I9W5R871I;VX@9FEL
M92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N92!O9B!T:&4@;W!T:6]N<R!T
M;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@;W(@8V]P>2!M86YU86QL>2!T
M:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL
M82!3:61E8F%R+B!-86ME('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U
M<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@;VYE`$-U
M<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R96YT(%=E871H97(`0W5R
M<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K
M<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A=&%4<F5E($)R;W=S97(`
M1&%T92!296-E:79E9`!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C
M:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E
M($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W
M`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@
M8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5S8W)I<'1I;VX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0
M;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE
M9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y
M`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L
M87D@9&5T86EL960@9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$
M;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$;V5S('1H
M92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF('EE<RP@
M8VAE8VL@=&AI<R!B;W@Z`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U
M<"X`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C
M<FEP="X`1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O=7``161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`E<P!%9'5C871I;VX`16QE
M;65N="XN+@!%;0!%;6%I;"!!9&1R97-S`$5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N;&%R9V4@161I=&]R`$5N=&5R
M(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@
M:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA
M="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@
M55),(&AE<F4`17)R;W(`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5T
M:&YI8P!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S
M,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!H86QF(&AO=7(`179E
M<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9"!3:61E
M8F%R`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I<@!&87AE<P!&
M96)R=6%R>0!&965L<R!,:6ME`$9E96QS(&QI:V4Z(`!&97<@4VAO=V5R<P!&
M97<@4VYO=R!3:&]W97)S`$9I;&4@36%N86=E<@!&:6QT97)S`$9I<G-T($AA
M;&8`1FER<W0@475A<G1E<@!&;&]A=`!&;V<`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.
M86UE`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=E;F5R
M871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V\`1V]E9&5L
M`$=O;V=L92!396%R8V@`1W)E96L@*$E33RTX.#4Y+3<I`$=R;W5P($%D;6EN
M:7-T<F%T:6]N`$=R;W5P<P!'=65S="!097)M:7-S:6]N<P!'=65S=&)O;VL`
M2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@
M8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-3$%R96$@8V]W87)D
M;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W(&EN('1A8FQE+@!(
M87IE`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S
M:6YG(&5D:71O<@!(96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O
M9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VUE($1I<F5C=&]R>0!(;W)D90!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!)7VYS97)T(%)O=R!"969O<F4`26-O;G,@3VYL>0!)8V]N<R!F
M;W(@)7,`26-O;G,@=VET:"!T97AT`$ED96YT:71Y)W,@;F%M93H`268@>6]U
M(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R97(L
M('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!0
M3D<@=')A;G-P87)E;F-Y+@!);6%G92!0<F5V:65W.@!);6%G92!54DP`26UA
M9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@9G)O;2!G86QL97)Y
M.@!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!)
M;7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EV:61U86P@57-E<G,`26YF;W)M
M871I;VX`26YF;W)M871I;VX@;F\@;&]N9V5R(&%V86EL86)L92X`26YS97)T
M($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN<V5R="!486)L90!);G-E
M<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F;W)E`$EN<V5R="!A(&YE
M=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!C
M;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@<F]W(&)E9F]R
M92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R86=R87!H(&%F=&5R('1H
M92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R87!H(&)E9F]R92!T:&4@
M8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@=&5M<&QA=&4`26YS97)T
M(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U(&-A;B!R96-E:79E('1H
M92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F=&5R`$EN<V5R="!C96QL
M(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN<V5R="!C;VQU;6X@8F5F
M;W)E`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B
M969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E
M<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I
M;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN
M=F%L:60@87!P;&EC871I;VXN`$EN=F%L:60@<&%R96YT('!E<FUI<W-I;VXN
M`$EN=F5N=&]R>0!)<V]L871E9"!4+5-T;W)M<P!)=&%L:6,`2F%N=6%R>0!*
M87!A;F5S92`H25-/+3(P,C(M2E`I`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I
M9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2
M:6=H=`!+97)N96P@3F5W8FEE<P!+:61S`$MO<F5A;B`H155#+4M2*0!,85]Y
M;W5T`$QA;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,
M87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87<`3&%Y;W5T`$QE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(`3&5F=`!,:6=H="!$<FEZ>FQE`$QI9VAT(%)A
M:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@4F%I
M;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO=P!,
M:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK('!O:6YT<R!T;SH`3&EN
M=7@@0V]O:VEE`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES
M="!486)L97,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R
M90!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I
M;@!,;V<@;W5T`$QO9VEN`$QO9VEN(%1A<VMS`$QO=F4`3&]W`$QO=V5R(&=R
M965K(&QE='1E<G,`3&]W97(@;&%T:6X@;&5T=&5R<P!,;W=E<B!R;VUA;B!N
M=6UB97)S`$U-`$U/5$0`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN
M7VLN+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%R8V@`36%R9VEN`$UA=&-H:6YG(&9I
M96QD<P!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V
M(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87D`
M365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE=&%R
M(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO
M8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O
M<B!T:&4@861M:6YI<W1R871O<BX`365T<FEC`$UI9&1L90!-:6X@=&5M<"!L
M87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36ES8V5L
M;&%N96]U<P!-:7-S:6YG(&-O;F9I9W5R871I;VXN(%EO=2!H879E('1O(&=E
M;F5R871E(&ET(&YO=R!I9B!Y;W4@=V%N="!T;R!U<V4@=&AI<R!A<'!L:6-A
M=&EO;BX`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69Y(%523`!-;V]N
M(%!H87-E<P!-;W-T;'D@0VQE87(`36]S=&QY($-L;W5D>0!-;W-T;'D@4W5N
M;GD`37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A
M;`!->2!0;W)T86P@3&%Y;W5T`$Y/+"!)($1O($Y/5"!!9W)E90!.971W;W)K
M`$YE=F5R`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P
M=&EO;F%L*0!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D<R!D;VXG="!M871C
M:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.
M:6=H=`!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO;B!D871A('1O('-H;W<@
M9&EF9F5R96YC97,@9F]R+@!.;R!C:&%N9V4N`$YO(&EC;VYS(&9O=6YD+@!.
M;R!L;V-A=&EO;B!I<R!S970N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P
M96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R
M>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O
M;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U
M<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H
M=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)T:&5R;B!(
M96UI<W!H97)E`$YO="!S970`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O
M(&)A8VLN`$YO=F5M8F5R`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R
M;W=S`$]+`$]B:F5C="!#<F5A=&]R`$]C=&]B97(`3V9F96YS92!F:6QT97(`
M3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E(&1I9F9E<F5N
M="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@8V]R<F5C="X`
M3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!T:&4@;W=N97(@;W(@<WES
M=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N
M97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD
M;W<`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@
M4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R
M9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN
M86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/
M=VYE<B!097)M:7-S:6]N<P!02%`@0V]D90!02%`@4VAE;&P`4$T@3&EG:'0@
M4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U
M;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@8VQI<&)O
M87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N=`!097)F
M;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN=&5N86YC
M92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N("(E<R(@;F]T(&1E
M;&5T960N`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E=',`4&AO=&]S`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S
M92!C;&EC:R!I;G1O('-O;64@8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO
M=2!W86YT('1O(')E;6]V92!T:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M
M('1H870@>6]U('=A;G0@=&\@=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E
M(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E9V]R>3H`4&QE87-E('!R
M;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@<')O=FED
M92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@<F5A9"!T:&4@
M9F]L;&]W:6YG('1E>'0N(%EO=2!-55-4(&%G<F5E('=I=&@@=&AE('1E<FUS
M('1O('5S92!T:&4@<WES=&5M+@!0;VQI=&EC<P!0;VQL<P!0;W-I=&EO;FEN
M9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG(&]F('1H:7,@=&%B;&4`4')E
M8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO
M;CQB<B`O/F-H86YC90!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ
M(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N
M97<@=VEN9&]W`%!R:6YT(&1O8W5M96YT`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4')O:F5C=',`475E<GD`475O=&$`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T
M90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD
M;VT@1F]R='5N90!296%D`%)E86QL>2!D96QE=&4@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E86QL>2!R96UO=F4@=7-E<B!D871A
M(&9O<B!U<V5R("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE
M+@!2961O97,@>6]U<B!L87-T(&%C=&EO;@!2969R97-H($1Y;F%M:6,@365N
M=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M87)K<P!296UO
M=&4@4V5R=F5R<P!296UO=&4@55),("AH='1P.B\O=W=W+F5X86UP;&4N8V]M
M+VAO<F1E*3H`4F5M;W9E`%)E;6]V92!";&]C:P!296UO=F4@9F]R;6%T=&EN
M9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R;VT@<V5R=F5R
M)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!296UO=F4@=&AI
M<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R`%)E;6]V92!U
M<V5R.B`E<P!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W
M;W)D`%)E<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S
M=V]R9`!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P
M=&EO;G,`4FED9&QE<P!2:6=H=`!2;U]W(%!R;W!E<G1I97,N+BX`4F]W(%!R
M;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4TU3($UE<W-A9VEN9P!344P@
M4VAE;&P`4U-(`%-?44P@4VAE;&P`4V$`4V%M92!F<F%M92`H7W-E;&8I`%-A
M=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!38V%T
M=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R
M96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T
M92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA
M;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I
M;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T
M('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N
M9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N<V]R.B``4V5P=&5M8F5R
M`%-E="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W
M;W)D(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V
M97)S('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN
M`%-E="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A
M=&4@;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L
M;W(@<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y
M(&]P=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B
M;&4`4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE
M=&5R.B``4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME
M>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E
M<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@
M9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE
M('=H96X@;&]G9VEN9R!I;C\`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@
M8F%R/P!3:&]W('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!4
M86)L92!#96QL(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R
M;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W
M97)S`%-H;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE
M(%9I8VEN:71Y`%-K:7`@36%I;G1E;F%N8V4`4VYO=P!3;F]W(%-H;W=E<@!3
M;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,
M871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3
M;VYG<R`F(%!O96US`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T
M:&5R;B!(96UI<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`
M4W!A8V4@8F5T=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C
M:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A;0!3<&5C:6%L($-H87)A8W1E
M<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O
M<G1S`%-T86YD87)D`%-T87(@5')E:P!3=&%T=7,`4W1R:6ME=&AR;W5G:`!3
M='EL92!;0U-370!3=0!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A
M=&EO;BX@4F5L;V%D('1O('-E92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V
M960@8F%C:W5P(&-O;F9I9W5R871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T
M:&4@8F%C:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY
M('=R;W1E("5S`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR
M:7-E`%-U;G)I<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``
M4W5P97)S8W)I<'0`4W5P<&]R=`!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y
M`%0M4W1O<FUS`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O<&5R=&EE<P!4
M87)G970Z`%1A<VMS`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E
M`%1E;7!E<F%T=7)E.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E
M<RD@)F1E9SLE<P!496UP;&%T92!!9&UI;FES=')A=&EO;@!497AT($]N;'D`
M5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I`%1H92!-86EN
M=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE
M($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!B;W1T
M;VT@<VED92!O;FQY`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O
M(&-A=7-E('!R;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T
M;R!B<F]W<V5R(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R
M;W5N9"X@(%EO=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@
M;&%C:R!O9B!E9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E
M<B!C<F%S:&5S+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S
M('9E<GD@;&EK96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E
M8W1I;VX@1F%U;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@
M8F5E;B!W87)N960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A
M;G0@=&\@=')Y('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET
M>2`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O
M;FQY`%1H92!R:6=H="!A;F0@;&5F="!S:61E<R!O;FQY`%1H92!R:6=H="UH
M86YD('-I9&4@;VYL>0!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P
M(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!T;W`@86YD
M(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H92!W96%T
M:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5R92!W87,@86X@
M97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@
M;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AI<R!I<R`E<RX`5&AI<R!W
M:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4
M:'5N9&5R`%1I8VME=',`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:71L
M90!4:71L92`H=&]O;'1I<"DZ`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4
M;VUO<G)O=P!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5'4`
M5'5R:VES:"`H25-/+3@X-3DM.2D`52Y6+B!I;F1E>#H@`%523`!54DPZ`%5N
M86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N9&5R;&EN90!5;F1O($-H86YG
M97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YF:6QE9`!5;FEC;V1E("A5
M5$8M."D`56YI=',`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YP<FEV
M:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P
M<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/
M2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC
M:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T
M:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5<&1A=&4`57!D871E("5S`%5P
M9&%T92!U<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E
M9"X`57!L;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE
M<R!T;R!T:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O
M;6%N(&YU;6)E<G,`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT
M(&9O<B!)35-0('-E<G9E<BX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ
M`%9A8V%T:6]N`%9A<FEA8FQE`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A
M;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE
M=&YA;65S92`H5DE30TE)*0!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I
M<VEB:6QI='D`5FES:6)I;&ET>3H@`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+@!787)N:6YG`%=E`%=E871H97(@1F]R96-A
M<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E8@!796(@4VET90!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=H870@87!P;&EC871I;VX@
M<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E
M;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E
M<C\`5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T
M:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I
M;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z
M(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!8+5)E9@!960!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@
M=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!M=7-T(&1E<V-R
M:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L
M96T@<F5P;W)T+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@
M;&EN:R!P;VEN=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B
M92!D96QE=&5D+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE
M87(@;W5T+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E
M+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M
M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U<B!%;6%I
M;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO
M;@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@
M;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S
M(&)E96X@9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>2!H87,@8F5E
M;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N
M86UE.@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@<&%S
M<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R
M97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N
M97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%II<'!Y`%M(:61E
M(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@
M4F]W`%]'<F]U<',`7TEM86=E(%!R;W!E<G1I97,N+BX`7TUO9&EF>2!,:6YK
M+BXN`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L
M92!0<F]P97)T:65S+BXN`%]5<V5R<P!C86QM`&9A;&QI;F<`9G)O;2!T:&4@
M)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&EN;&EN90!L:6YE<UT`;F%M90!P
M97)C96YT`'!I>&5L<P!R:7-I;F<`<VAO=R!D:69F97)E;F-E<P!S=&5A9'D`
M='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'=E
M871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@,C`P-2TP."TP,PI297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E
M871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#4M,#@M,#0@,#DZ,3`K,#(P,`I,87-T+51R86YS;&%T;W(Z
M($IA;65S(#QJ86UE<T!A8W1I;VYM97-S86=E+F-O;3X*3&%N9W5A9V4M5&5A
M;3H@:60@/&ED0&QI+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/553+4%30TE)"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#=B:70*`"!P861A(``B)7,B('-U9&%H(&1I=&%M
M8F%H:V%N(&ME(&1A;&%M('-I<W1E;2!G<G5P+@`B)7,B('-U9&%H(&1I=&%M
M8F%H:V%N(&ME(&1A;&%M(&EZ:6X@<VES=&5M+@`B)7,B(&)E;'5M(&1I8G5A
M=#H@)7,N`"4N,F9-0B!S=61A:"!D:6=U;F%K86X@9&%R:2`E+C)F34(@>6%N
M9R!S=61A:"!D:6EJ:6YK86X@*"4N,F8E)2D`)60@)7,@9&%N("5S`"5D(&AA
M<FD@<V%M<&%I('-A;F1I(&%N9&$@:&%B:7,@;6%S82!B97)L86MU;GEA+@`E
M9"UH87)I(')A;6%L86X@8W5A8V$`)7,@+2!096UB97)I=&%H=6%N`$MO;F9I
M<FUA<VD@+2!/<&5R87-I(%!E;65L:6AA<F%A;B`E<P`E<R!3971U<``E<R!3
M>6%R870M<WEA<F%T(%!E<FIA;FII86X`)7,@<&%D82`E<R`E<P`E<R!S:6%P
M('5N='5K(&UE;&%K<V%N86MA;B!O<&5R87-I('!E;65L:6AA<F%A;B!Y86YG
M('-U9&%H(&1I=&%N9&%I(&1I(&)A=V%H(&EN:2X@0F5R:6QA:"!T86YD82!P
M861A(&MO=&%K('1E<G-E8G5T('5N='5K(&]P97)A<VD@;6%N87!U;B!Y86YG
M(&%N9&$@:6YG:6YK86X@=6YT=6L@9&EL86MS86YA:V%N('!A9&$@=V%K='4@
M:6YI+@`E<R!M96YI=``E<R!U;G1U:R`E<R`E<P`L(&%N9VEN(&ME;F-A;F<@
M)7,@)7,`+"!V87)I86)L92!D87)I("5S(&ME("5S`$9O<FUA="`Q,B!*86T`
M1F]R;6%T(#(T($IA;0`R-"!J86T`1&%T86)A<V4@8F%C:V5N9"!D:7!E<FQU
M:V%N('5N='5K(&%R96$@:6YI+@!!32!-96YD=6YG`$%-($=E<FEM:7,`04T@
M2'5J86X`04T@1V5R:6UI<P!!32!'97)I;6ES(%-A;&IU`$%-+U!-`%1E;G1A
M;F<@961I=&]R(&EN:0!496YT86YG+BXN(`!*87)A:R!A;G1A<F$@8F%G:6%N
M(&)A=V%H(&)A<FES(&1E;F=A;B!B86=I86X@8F%W86@@9V%M8F%R`$IA<F%K
M(&%N=&%R82!B86=I86X@=&5N9V%H(&)A<FES(&1E;F=A;B!B86=I86X@=&5N
M9V%H(&=A;6)A<@!);F9O<FUA<VD@06-C;W5N=`!386YD:2!!8V-O=6YT`$%K
M=6YT86YS:0!486UB86@`5&%M8F%H($=R=7`@06YA:P!486UB86@@1&ES:6YI
M.@!486UB86@@1W)U<"!"87)U`%1A;6)A:"!P96YG9W5N82!B87)U.@!486UB
M86@@86YG9V]T82!B87)U`%1A;6)A:"!P87-A;F=A;@!486UB86@@365N=2`E
M<R!S96)A9V%I(%!A;F5L(&YA=FEG87-I($UO>FEL;&$`5&%M8F%H('!E;F=G
M=6YA`%!E;F%M8F%H86X@<&5N9V=U;F$@=&ED86L@9&EA:W1I9FMA;BX`0G5K
M=2!!;&%M870@`$%D;6EN:7-T<F%S:0!):VQA;@!2871A`%!E<F%T86%N`%-E
M;75A`%-E;75A(%!E;F=G=6YA($%S;&D`4V5M=6$@1W)U<`!396UU82!E;7!A
M="!S:7-I`$EZ:6YK86X@<&5N9V%T=7)A;B!D87)I('1I<&4@9&%F=&%R(&YO
M;6]R(&)E<G5R=70_`%!E;F=G86YT:2!,;V=I;B!)35-0`%!E;F=G86YT:2!3
M86YD:2!)35-0`%!E;F=G86YT:2!.86UA(%!E;F=G=6YA($E-4U``4&5N9V=A
M;G1I(&%L86UA="!E;6%I;`!096YG9V%N=&D@=&5M<&QA=&4`4&5N9V=A;G1I
M('1E:W,Z`$IA=V%B86X`07!L:6MA<VD`1&%F=&%R($%P;&EK87-I`$%P;&EK
M87-I('-U9&%H('-I87`N`$1I9W5N86MA;B!U;G1U:R!"86=I86X@06YA:P!$
M:7-E='5J=6D`07!R:6P`07)A8B`H5VEN9&]W<RTQ,C4V*0!!<&%K86@@86YD
M82!Y86MI;B!A;F1A(&EN9VEN(&UE;6EN9&%H:V%N('!E<FUO:&]N86X@<&5N
M9&%F=&%R86X@=6YT=6L@)7,_`$%R;65N:6$@*$%235-#24DM."D`4V5N:0!+
M;V1E($%S8VEI`$UE;6EN=&$@:V]N9FER;6%S:2!S96)E;'5M(&UE;&%K<V%N
M86MA;B!O<&5R87-I('!E;65L:6AA<F%A;C\`365N8V]B82!U;G1U:R!M96YG
M:&%P=7,@9W)U<"!Y86YG('1I9&%K(&%D82X`365N8V]B82!U;G1U:R!M96YG
M:&%P=7,@:7II;B!Y86YG('1I9&%K(&%D82X`365N8V]B82!U;G1U:R!M96YG
M=6)A:"!I>FEN('EA;F<@=&ED86L@861A+@!-96YC;V)A('5N='5K(&UE;F=U
M8F%H(&)A9VEA;B!Y86YG('1I9&%K(&%D82X`06=U<W1U<P!+;VQO;2!Y86YG
M('1E<G-E9&EA.@!!;&%S86X@0D]&2`!,871A<B!"96QA:V%N9P!787)N82!,
M871A<B!"96QA:V%N9P!"86QT:6,@*$E33RTX.#4Y+3$S*0!*87)A:R!A;G1A
M<F$@8F%G:6%N(&)A=V%H(&=A;6)A<B!D96YG86X@9V%R:7,@9&%S87(@8F%R
M:7,`4&5N9V%T=7)A;B!!<F5A`%1I<&4@07)E80!(=7)U9B!496)A;`!0971U
M;FIU:R!H86QA;6%N('=E8@!";W)D97(`2V5T96)A;&%N($)O<F1E<@!";W)D
M97(`2V5D=6%N>6$`0F%W86@`1&%F=&%R($)U;&QE=`!#35,`4')O<&5R=&D@
M4U]E;`!+86QE;F1E<@!496YA;F<`5&ED86L@9&%P870@;65N9V%T=7(@=6QA
M;F<@<V%N9&D@<V5C87)A(&]T;VUA=&ES+"!S:6QA:V%N(&AU8G5N9VD@861M
M:6YI<W1R871O<B!A;F1A+@!"871A;`!"871A;&MA;B!,87!O<F%N($UA<V%L
M86@`2G5D=6P@5&%B96P`2V%T96=O<FD@9&%N($QA8F5L`%!R;W!E<G1I(%-E
M;`!*87)A:R!S<&%S:2!D87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D86QA
M;2!S96PZ`'!R;W!E<G1I('-E;`!*87)A:R!S<&%S:2!A;G1A<B!S96PN`$-E
M;'1I8R`H25-/+3@X-3DM,30I`%1E;F=A:`!%<F]P82!496YG86@@*$E33RTX
M.#4Y+3(I`%5B86@`56)A:"!386YD:2!!;F1A`%5B86@@;F%M82!D86X@86QA
M;6%T('-E:&EN9V=A(&]R86YG(&1A<&%T(&UE;&EH871N>6$@:V5T:6MA(&UE
M<F5K82!M96UB86-A(&1A;B!M96UB86QA<R!K92!E;6%I;"!A;F1A+@!-96YG
M=6)A:"!S86YD:2!A;F1A('1I9&%K(&1I9'5K=6YG(&1E;F=A;B!K;VYF:6=U
M<F%S:2!Y86YG('-E:V%R86YG+B!3:6QA:V%N(&AU8G5N9VD@861M:6YI<W1R
M871O<B!A;F1A+@!+87)A:W1E<@!097)I:W-A($QI;FLN+BX`0VEN82!3961E
M<FAA;F$@*$=",C,Q,BD`0VEN82!4<F%D:7-I;VYI;"`H0FEG-2D`4&EL:6@@
M8V%R82!U;G1U:R!M96YA;7!I;&MA;B!T86YG9V%L.@!0:6QI:"!D869T87(@
M=&EP92!G87EA("AU;G1U:R!D869T87(@;F]M;W(@8F5R=7)U="D`0F5R<VEH
M:V%N`$)E<G-I:&MA;B!T86<@35-/9F9I8V4`0F5R<VEH:V%N('!E;F=G=6YA
M.B`E<P!"97)S:6AK86X@<&5N9V=U;F$`0F5R<VEH:V%N(&1A=&$@<&5N9V=U
M;F$`0V5R86@@8F5B97)A<&$@<V%A="!L86=I`$ML:6L@=6YT=6L@3&%N:G5T
M`%1U='5P($IE;F1E;&$`365N9'5N9P!-96YD=6YG(&1I('!A9VD@:&%R:0!"
M97)A=V%N`%!E<F)E<V%R(%!A;F5L($YA=FEG87-I(`!097)B97-A<B!B;W)D
M97(`5V%R;F$`4&5M:6QI:"!787)N80!+;VQO;0!#;VUI8W,`0V]M;6%N9`!#
M;VUM86YD(%-H96QL`$MO;7!U=&5R`$MO;F1I<VD`2V]N9&ES:0!097)B961A
M86X@2V]N9FEG=7)A<VD`2V]N9FEG=7)A<VD@<W5D86@@:&%B:7,@;6%S82!B
M97)L86MU;GEA+@!-96YG871U<B`E<P!+;VYF:7)M87-I(%-A;F1I`$MO;G1A
M:P!,86YJ=70`0V]O:VEE`%-A;&EN`%-A;&EN(%!I;&EH86X`5&ED86L@9&%P
M870@=&5R:6MA="!D96YG86X@<V5R=F5R(&QD87``5&ED86L@9&%P870@=&5R
M:'5B=6YG(&ME('-E<G9E<B!L9&%P`%1I9&%K(&1A<&%T(&UE;F=A='5R('5L
M86YG('5N='5K('!E;F=G=6YA('EA;F<@9&EM:6YT82X@0F5B97)A<&$@871A
M=2!S96UU82!D971I;"!T:61A:R!B96YA<BX@0V]B82!L86=I(&%T874@<VEL
M86MA;B!H=6)U;F=I(&%D;6EN:7-T<F%T;W(@86YD82!J:6MA(&%N9&$@;65M
M97)L=6MA;B!B86YT=6%N(&QE8FEH(&QA;FIU="X`5&ED86L@9&%P870@:V5M
M8F%L:2!K92!K;VYF:6=U<F%S:2X`5&ED86L@9&%P870@;65N>6EM<&%N(&MO
M;F9I9W5R87-I("5S+@!4:61A:R!D87!A="!M96YY:6UP86X@9FEL92!K;VYF
M:6=U<F%S:2!B86-K=7`@)7,N`%1I9&%K(&1A<&%T(&UE;GEI;7!A;B!F:6QE
M(&MO;F9I9W5R87-I("5S+B!!;F1A(&1A<&%T(&UE;F=G=6YA:V%N('-A;&%H
M('-A='4@9&%R:2!P:6QI:&%N('5N='5K(&UE;GEI;7!A;B!K;V1E('1E<G-E
M8G5T(&ME;6)A;&D@:V4@)7,@871A=7!U;B!M96YY86QI;B!K;V1E(&1I(&)A
M=V%H(&EN:2!S96-A<F$@;6%N=6%L(&ME("5S+@!4:61A:R!D87!A="!M96YE
M;75K86X@4&%N96P@3F%V:6=A<VD@36]Z:6QL82X@4&%S=&EK86X@<&%N96P@
M;F%V:6=A<VD@<W5D86@@=&5R8G5K82X`2W5R<W5S`$)U870`0G5A="!L:6YK
M`$)U870@8F%R=0!786MT=2!396MA<F%N9P!54DP@4V5K87)A;F<@861A;&%H
M`$-U86-A(%-E:V%R86YG`$MO;F1I<VD@4V5K87)A;F<Z`$=A>6$@4V5K87)A
M;F<`2V]S='5M:7-A<VD@='5G87,@=6YT=6L@9&EJ86QA;FMA;B!S96)E;'5M
M(&QO9V]N(&ME("5S+@!(87!U<P!(87!U<R!P:6QI:&%N`$-Y<FEL;&EC("A+
M3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL;&EC+U5K<F%I
M;FEA;B`H2T])."U5*0!$1`!$871A5')E92!"<F]W<V5R`%1A;F=G86P@1&ET
M97)I;6$`2&%R:0!(87!U<R!+;VQO;0!$97-E;6)E<@!!;F=K82!$97-I;6%L
M`$UE;F=U<F%N9VD@26YD96X`1&5F875L=`!$969A=6QT(%=A<FYA`$1E9F%U
M;'0@4VAE;&P`1&5F:6YI<VD`2&%P=7,`2&%P=7,@4V5L`$AA<'5S($=R=7``
M2&%P=7,@<V5L`$AA<'5S(&MO;&]M`$AA<'5S('!E;F=G86YT:2!T96UP;&%T
M92!Y86YG('-U9&%H(&%D80!(87!U<R!B87)I<P!(87!U<R!I9&5N=&ET87,@
M>6%N9R!T97)P:6QI:`!(87!U<R!K;VQO;2!Y86YG('-E:V%R86YG`$AA<'5S
M(&)A<FES('EA;F<@<V5K87)A;F<`2F5L87-K86X@36%S86QA:`!$97-K<FEP
M<VD`4&5R:V5M8F%N9V%N`%1I=&EK($5M8G5N`%1I=&EK($5M8G5N('5N='5K
M(&IA;2!T97)A:VAI<CH`5&ET:6L@16UB=6X`07)A:"!K:7)I(&ME(&MA;F%N
M`$%R86@@:V%N86X@:V4@:VER:0!$:7)E:W1O<FD`5&%M<&EL:V%N('=A:W1U
M(#(T(&IA;3\`5&%M<&EL:V%N(%!I;&EH86X`5&%M<&EL:V%N(&1E=&EL(')A
M;6%L86X@8W5A8V$`5&%M<&EL:V%N(')A;6%L86X@8W5A8V$@*%1!1BD`2F%N
M9V%N(&QA;F=S=6YG(&UE;F=A:W-E<R!M86EN=&5N86YC92YP:'``07!A:V%H
M(&)A<FES('EA;F<@<&5R=&%M82!T97)D:7)I(&1A<FD@:V]L;VT@;F%M83\@
M:FEK82!Y82P@8F5R:2!T86YD82!P861A(&MO=&%K(&EN:3H`5&ED86L@;65M
M:6QI:VD@86-C;W5N=#\@4VEL86MA;B!M96YD869T87(N`$1O=VYL;V%D(&MO
M;F9I9W5R87-I('EA;F<@9&EH87-I;&MA;B!S96)A9V%I('-C<FEP="!02%`N
M`$]B870M;V)A=&%N`%5B86@`56)A:"!";&]K:7(`56)A:"!'<G5P`%5B86@@
M27II;@!58F%H($EZ:6X@=6YT=6L@)7,`56)A:"!P:6QI:&%N('5N='5K.@!5
M8F%H(&EZ:6X@=6YT=6L@)7,`4&5N9&ED:6MA;@!%;&5M96XN+BX`16T`06QA
M;6%T($5M86EL`$%K=&EF:V%N('!E;GEI<VEP86X@9V%M8F%R+6=A;6)A<B!D
M87)I($=A;&5R:2!&;W1O(&1I(&1A;&%M('1E:W,_`$%K=&EF:V%N(&ML:6L@
M:V%N86X@;65N=2!K;VYT96MS/P!097)B97-A<B!%9&ET;W(`36%S=6MK86X@
M<&5R=&%N>6%A;B!K96%M86YA;B!D:6UA;F$@86YD82!A:V%N(&1I=&%N>6%K
M86X@87!A8FEL82!A;F1A('!E<FQU('5N='5K(&UE;F=A='5R('5L86YG('-A
M;F1I(&%N9&$L("!C;VYT;V@@)V%P86MA:"!N86UA(&)I;F%T86YG(&ME<V%Y
M86YG86X@86YD83\G.@!-87-U:VMA;B!54DP@9V%M8F%R(&1I<VEN:0!+97-A
M;&%H86X`2V5S86QA:&%N('-A870@;65M<&5R8F%H87)U:2!S86YD:3H@)7,`
M4W5K=0!3971I87`@,34@;65N:70`4V5T:6%P(#(@;65N:70`4V5T:6%P(#,P
M(&1E=&EK`%-E=&EA<"`U(&UE;FET`%-E=&EA<"!S971E;F=A:"!J86T`4V5T
M:6%P(&UE;FET`$-O;G1O:"!N:6QA:2UN:6QA:3H`2F%L86YK86X`4&5R8F5S
M87(@4&%N96P@3F%V:6=A<VD`5V%R;F$@1D<`1E10('5P;&]A9"!U;G1U:R!S
M971U<`!#97)A:`!&87@`1F5B<G5A<FD`4V5P97)T:0!397!E<G1I.@!'97)I
M;6ES(%-E8F%G:6%N`$=E<FEM:7,@4V%L:G4@4V5B86=I86X`1FEL92!-86YA
M9V5R`$9I;'1E<@!&87-E('!E<G1A;6$@9&%R:2!397!A<G5H($)U;&%N`$9A
M<V4@<&5R=&%M82!D87)I(%-E<&%R=6@@0G5L86X`1FQO870`0F5R:V%B=70`
M5V%R;F$@5'5L:7-A;@!-86MA;F%N`%5N='5K(&)R;W=S97(@>6%N9R!T:61A
M:R!D87!A="!M96YD=6MU;F<@9V%M8F%R`%)A;6%L86X@8W5A8V$@*%1!1BD`
M2&%R:2!286UA;&%N($-U86-A("AC871A=&%N(&)A:'=A(')A;6%L86X@8W5A
M8V$@>6%N9R!D:6ME;6)A;&EK86X@86MA;B!M96YG96UB86QI:V%N(&)A:6L@
M<VEA;F<@871A=2!M86QA;2!H87)I+"!S96IU;6QA:"!A;F=K82!D87!A="!D
M:6AA<VEL:V%N('!A9&$@87)E82!I;FDI`$QU<&$@9&5N9V%N('-A;F1I(&%N
M9&$_`$9O<FUU;&ER`%)A;6%L86X`5&EP92!286UA;&%N`%)A;6%L86X`4F%M
M86QA;B`R`$9O<G5M`$1I=&5R=7-K86X`2FUT`$9R86UE`$1A<FD`1&5S:W)I
M<'-I($QE;F=K87``0G5L86X@4'5R;F%M80!.86UA($QE;F=K87``1V%L97)I
M('5N='5K(&UE;F=A;6)I;"!G86UB87(@9&%R:0!'86QE<FD`365N9VAA<VEL
M:V%N("5S($MO;F9I9W5R87-I(`!+;V1E('EA;F<@9&EH87-I;&MA;@!*86QA
M;FMA;@!';V5D96P`4&5N8V%R:6%N($=O;V=L90!9=6YA;FD@*$E33RTX.#4Y
M+3<I`$%D;6EN:7-T<F%S:2!'<G5P`$=R=7``27II;B!T86UU`$)U:W4@=&%M
M=0!(5$U,07)E82!D96YG86X@<F%G=2!M96YO;&%K('5N='5K(&UE;F=H87!U
M<R!S96P@>6%N9R!T97)A:VAI<B!D:2!D86QA;2!B87)I<RX`2%1-3$%R96$@
M9&5N9V%N(')A9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@:V]L;VT@>6%N
M9R!T97)A:VAI<B!D:2!D86QA;2!T86)E;"X`2%1-3$%R96$@9&5N9V%N(')A
M9W4@;65N;VQA:R!U;G1U:R!M96YG:&%P=7,@8F%R:7,@>6%N9R!T97)A:VAI
M<B!D:2!D86QA;2!T86)E;"X`0F5R:V%B=70`66%H=61I("A)4T\M.#@U.2TX
M+4DI`%1I;F=G:0!"86YT=6%N`$)A;G1U86X@;65N9V=U;F%K86X@961I=&]R
M`$)E;&%H86X@0G5M:0!);FD@861A;&%H('!E<FUU;&%A;B!D87)I(&9I;&4Z
M`%1I;F=G:0!(;U]M90!$:7)E:W1O<FD@2&]M90!(;W)D90!'87)I<R!(;W)I
M<V]N=&%L(&1I(&1A;&%M($A434P`2F%R86L@9V%R:7,@:&]R:7IO;G1A;"!D
M87)I(&)O<F1E<B!D96YG86X@=&5K<R!D:2!D86QA;2!S96P`2&]R:7IO;G1A
M;#H`0F%G86EM86YA(&-A<F$@86YD82!B:7-A('-A;7!A:2!D:7-I;FD_("A3
M:6QA:V%N(&UE;&%P;W(A*0!"97)A<&$@8F%N>6%K(&MO;&]M('EA;F<@:6YG
M:6X@86YD82!G86)U;F=K86X_`$)E<F%P82!B86YY86L@:V]L;VT@>6%N9R!A
M9&$@9&ES86YA/P!"97)A<&$@8F%N>6%K(&)A<FES('EA;F<@:6YG:6X@86YD
M82!G86)U;F=K86X_`$ME;&5M8F%B86X`2V5L96UB86)A;CH`4&5L87=A:P!-
M87-U:VMA;B!"87)I<R!396)E;'5M;GEA`$AA;GEA(&EK;VX`26MO;B!U;G1U
M:R`E<P!):V]N(&1E;F=A;B!T96MS`$YA;6$@261E;G1I=&%S.@!*:6MA(&%N
M9&$@=&ED86L@;65L:6AA="!I:V]N(&UA;F%P=6X@9&5N9V%N(&UE;F=G=6YA
M:V%N($EN=&5R;F5T($5X<&QO<F5R+"!A;F1A(&UU;F=K:6X@<&5R;'4@=6YT
M=6L@;65N86YD86D@:V]T86L@:6YI('5N='5K(&UE;F]N+6%K=&EF:V%N(&ME
M;&5M86AA;B!03D<N`$QI:&%T($=A;6)A<CH`55),($=A;6)A<@!54DP@1V%M
M8F%R.@!'86UB87(@9&%R:2!G86QE<FD`1V%M8F%R(&1A<FD@9V%L97)I.@!'
M86UB87(M9V%M8F%R`$EM<&]R+"!,86YG:V%H("5D`$MO;&]M('EA;F<@9&EI
M;7!O<CH@)7,`2V]L;VT@>6%N9R!D:6EM<&]R.@!-87-U:VMA;B!"87)I<R!"
M97)I:W5T;GEA`$YA;6$@<&5N9V=U;F$@871A=2!A;&%M870@96UA:6P@<&5N
M9V=A;G1I('1I9&%K(&)E;F%R+B!#;V)A(&QA9VD@871A=2!S:6QA:V%N(&AU
M8G5N9VD@861M:6YI<W1R871O<B!A;F1A(&II:V$@86YD82!M96UE<FQU:V%N
M(&)A;G1U86X@;&5B:6@@;&%N:G5T+@!-96YA;6)A:"!);F1E;@!096YG9W5N
M82!0<FEB861I`$EN9F]R;6%S:0!);F9O<FUA<VD@<W5D86@@=&ED86L@9&ES
M961I86MA;BX`36%S=6MK86X@2V]L;VT@0F5R:6MU=&YY80!-87-U:VMA;B!'
M86UB87(`36%S=6MK86X@5&%B96P`36%S=6MK86X@5V5B($QI;FL`36%S=6MK
M86X@2V]L;VT@4V5B96QU;6YY80!-87-U:VMA;B!K;VQO;2!Y86YG(&)A<G4@
M<V5T96QA:"!K;VQO;2!Y86YG('-E:V%R86YG`$UA<W5K:V%N(&MO;&]M('EA
M;F<@8F%R=2!S96)E;'5M(&MO;&]M('EA;F<@<V5K87)A;F<`36%S=6MK86X@
M8F%R:7,@>6%N9R!B87)U('-E=&5L86@@8F%R:7,@>6%N9R!S96MA<F%N9P!-
M87-U:VMA;B!B87)I<R!Y86YG(&)A<G4@<V5B96QU;2!K;VQO;2!Y86YG('-E
M:V%R86YG`$UA<W5K:V%N('!A<F%G<F%F('-E=&5L86@@<&%R86=R868@>6%N
M9R!S96MA<F%N9P!-87-U:VMA;B!P87)A9W)A9B!S96)E;'5M('!A<F%G<F%F
M('EA;F<@<V5K87)A;F<`36%S=6MK86X@=&5M<&QA=&4@<&5N9V=A;G1I`$UA
M<W5K:V%N(&%L86UA="!E;6%I;"!D:6UA;F$@86YD82!D87!A="!M96YE<FEM
M82!S86YD:2!Y86YG(&)A<G4Z`$UA<W5K:V%N('-E;"!B97)I:W5T;GEA`$UA
M<W5K:V%N('-E;"!S96)E;'5M;GEA`$UA<W5K:V%N(&MO;&]M(&)E<FEK=71N
M>6$`36%S=6MK86X@:V]L;VT@<V5B96QU;6YY80!-87-U:VMA;B!P87)A9W)A
M9B!B97)I:W5T;GEA`$UA<W5K:V%N('!A<F%G<F%F('-E8F5L=6UN>6$`36%S
M=6MK86X@8F%R:7,@8F5R:6MU=&YY80!-87-U:VMA;B!B87)I<R!S96)E;'5M
M;GEA`$UA<W5K:V%N(&IA=V%B86X@>6%N9R!D:7!E<FQU:V%N('5N='5K('!E
M<G1A;GEA86%N(&ME86UA;F%N.@!-87-U:VMA;B]58F%H($=A;6)A<@!-87-U
M:VMA;B]58F%H($QI;FL`07!L:6MA<VD@=&ED86L@=F%L:60N`$EZ:6X@:6YD
M=6L@=&ED86L@=F%L:60N`$EN=F5N=&]R:7,`2'5J86X@<&5T:7(@9&ES97)T
M86D@86YG:6X@<FEB=70@9&D@9&%E<F%H('EA;F<@=&5R<&5N8VEL`$AU<G5F
M($UI<FEN9P!*86YU87)I`$IE<&%N9R`H25-/+3(P,C(M2E`I`$IU;&D`2G5N
M:0!2871A`%)A=&$@5&5N9V%H`%)A=&$@2VER:2!D86X@2V%N86X`4F%T82!+
M:7)I`%)A=&$@2V%N86X`2V5R;F5L($YE=V)I97,`06YA:RUA;F%K`$MO<F5A
M("A%54,M2U(I`%1A;7!I;&%N`$)A:&%S80!&87-E('1E<F%K:&ER(&1A<FD@
M4V5P87)U:"!"=6QA;@!097)U8F%H86X@4V%N9&D@5&5R86MH:7(`1F%S92!T
M97)A:VAI<B!D87)I(%-E<&%R=6@@0G5L86X`4&5R=6)A:&%N(%1E<F%K:7(Z
M`$AU:W5M`%1A;7!I;&%N`%1I;F=G86QK86X@:V]S;VYG('1A;G!A(&)O<F1E
M<@!+:7)I`$=E<FEM:7,`1V5R:6UI<P!'97)I;6ES(&1I('!A9VD@:&%R:0!'
M97)I;6ES(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$=E<FEM:7,@9&ES
M97)T86D@<&5T:7(`0F5R<V%L:G4`1V5R:6UI<R!386QJ=0!086YT=6X@2F5N
M86MA`$QI;FL@;65N=6YJ=6L@:V4Z`$QI;G5X($-O;VMI90!$869T87(@1&%T
M86)A<V4`1&%F=&%R(%1O<&EK($)A;G1U86X`1&%F=&%R(%1A8F5L`$1A9G1A
M<B!P96YG9W5N82!D:6YO;BUA:W1I9FMA;BX`1&%F=&%R($)A8V%A;@!786MT
M=2!L;V-A;#H`5&5M<&%T(%!E<FES=&EW82!D86X@5V%K='4`3&]K87-I`$QO
M9VEN`$QO9R!O=70`3&]G:6X`5'5G87,@3&]G:6X`0VEN=&$`4F5N9&%H`%-I
M;6)O;"!(=7)U9B!K96-I;"!Y=6YA;FD`4VEM8F]L($AU<G5F(&ME8VEL(&QA
M=&EN`%-I;6)O;"!(=7)U9B!K96-I;"!R;VUA=VD`34T`34]41`!3=6QA<`!3
M=7)A=`!3=7)A="!!9&UI;@!"=6%T(&QI;FLN+BX`365N9V%T=7(@9&%F=&%R
M(&MA=&5G;W)I('EA;F<@:&%R=7,@9&EB97)I(&QA8F5L(&ET96TL(&1A;B!W
M87)N82!Y86YG(&)E<FAU8G5N9V%N("!D96YG86X@:V%T96=O<FD@=&5R<V5B
M=70N`$UA<F5T`$UA<F=I;@!-96YC;V-O:VMA;B!K;VQO;0`@4W5H=2!M86MS
M:6UU;2!Y86YG(&)E<FQA;F=S=6YG('-E;&%M82`R-"!J86TZ`%-U:'4@;6%K
M<VEM=6T@>6%N9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$IU;6QA:"!M
M86MS:6UU;2!D87)I('!O<G1A;"!Y86YG(&1I8FQO:VER`$UE:0!/8F%T+6]B
M871A;@!!;F=G;W1A`$UE;G4@;6]D93H`1V%B=6YG:V%N('-E;``@0W5A8V$@
M365T87(`07)E82!-971A<B!T:61A:R!D:7-E9&EA:V%N+@!!<F5A($UE=&%R
M('1I9&%K(&1I<V5D:6%K86XN($1E=&EL('1E;&%H(&1I8V%T870@=6YT=6L@
M861M:6YI<W1R871O<BX`365T<FEK`%1E;F=A:`!3=6AU(&UI;FEM=6T@>6%N
M9R!B97)L86YG<W5N9R!S96QA;6$@,C0@:F%M.@!3=6AU(&UI;FEM=6T@>6%N
M9R!B97)L86YG<W5N9R!S96QA;6$@-B!J86TZ`$QA:6XM;&%I;@!+;VYF:6=U
M<F%S:2!T:61A:R!D:71E;75K86XN($%N9&$@:&%R=7,@;65N9VAA<VEK86X@
M:V]N9FEG=7)A<VD@<V5K87)A;F<@:FEK82!A;F1A(&EN9VEN(&UE;F=G=6YA
M:V%N(&%P;&EK87-I(&EN:2X`4V5N`$UO8FEL92!-86EL`%-E9&%N9P!58F%H
M(%523`!&87-E($)U;&%N`%-E8F%G:6%N(&)E<V%R($-E<F%H`%-E8F%G:6%N
M(&)E<V%R($)E<F%W86X`4V5B86=I86X@8F5S87(@0V5R86@`06-C;W5N="UK
M=0!);F9O<FUA<VD@06-C;W5N="UK=0!0;W)T86QK=0!486UP:6QA;B!0;W)T
M86QK=0!4241!2RP@4V%Y82!4241!2R!3971U:G4`3F5T=V]R:P!4:61A:R!P
M97)N86@`2V%T96=O<FD@0F%R=0!"=6QA;B!"87)U`$YA;6$@4&5N9V=U;F$@
M0F%R=2`H<&EL:6AA;BD`4V%N9&D@0F%R=0!386YD:2!B87)U('1I9&%K(&-O
M8V]K+@!7:6YD;W<@0F%R=2`H7V)L86YK*0!"97)I=&$`1W)U<"!"97)I=&$`
M0F5R:6MU=&YY80!-86QA;0!4:61A:R!A9&$@9&%T82!K;VYF:6=U<F%S:2!Y
M86YG('1E<G-E9&EA('5N='5K(&UE;G5N:G5K:V%N('!E<F)E9&%A;B!U;G1U
M:RX`5&ED86L@861A('!E<G5B86AA;BX`5&ED86L@861A(&EK;VX@>6%N9R!D
M:71E;75K86XN`%1I9&%K(&%D82!L;VMA<VD@>6%N9R!D:6%T=7(N`%1I9&%K
M(&%D82!R86UA;&%N('EA;F<@=&ED86L@<V]P86X`5&ED86L@861A('!E;F1A
M9G1A<F%N('EA;F<@9&ET=6YD82X`5&ED86L@861A(&%T=7)A;@!4:61A:R!A
M9&$@<VES:0!4:61A:R!A9&$@9&ER96MT;W)I('-E;65N=&%R82!Y86YG('1E
M<G-E9&EA('5N='5K(&-A8VAE`%1I9&%K(&%D82!V97)S:2!Y86YG(&1I=&5M
M=6MA;B!D:2!D86QA;2!K;VYF:6=U<F%S:2!Y86YG(&%S;&DN($UE;F=H87-I
M;&MA;B!K;VYF:6=U<F%S:2!K96UB86QI+@!4:61A:R!A9&$@=F5R<VD@>6%N
M9R!D:71E;75K86X@9&D@9&%L86T@:V]N9FEG=7)A<VD@86YD82X@365N9VAA
M<VEL:V%N(&MO;F9I9W5R87-I(&ME;6)A;&DN`%1I9&%K(&%D80!4:61A:R!A
M9&$@*&1I9W5N86MA;B!S96QE;F=K87!N>6$I`%-C86YD:6YA=FEA("A)4T\M
M.#@U.2TQ,"D`0F5L86AA;B!"=6UI(%5T87)A`$)E;'5M(&1I871U<@!#871A
M=&%N`%1I9&%K(&%D82!Y86YG(&1A<&%T(&1I8G)O=W-E+"!S:6QA:V%N(&ME
M;6)A;&DN`$YO=F5M8F5R`$IU;6QA:"!K;VQO;0!*=6UL86@@8F%R:7,`3TL`
M4&5N8VEP=&$@3V)J96L`3VMT;V)E<@!&:6QT97(@4&5L86YG9V%R86X`2V%N
M=&]R`%-A;F1I(&QA;6$@9&%N(&)A<G4@:&%R=7,@8F5R8F5D82X`4V%N9&D@
M;&%M80!386YD:2!L86UA('1I9&%K(&)E;F%R+@!(86YY82!R86UA;&%N('EA
M;F<@=&ED86L@<V]P86X`2&%N>6$@<&5M:6QI:R!A=&%U('-I<W1E;2!A9&UI
M;FES=')A=&]R('-A:F$@>6%N9R!D87!A="!M96YG=6)A:"!K97!E;6EL:6MA
M;B!A=&%U('!E;6EL:6L@:7II;B!U;G1U:R!B86=I86X`0G5K82!D:2!J96YD
M96QA('EA;F<@8F%R=0!"=6MA(&QI;FL@:6YI(&1I(&IE;F1E;&$@>6%N9R!B
M87)U`%-I<W1E;2!/<&5R87-I`%!I;&EH86X`4&EL:6AA;B!U;G1U:R`E<P!$
M869T87(@3F]M;W(@0F5R=7)U=`!-96YG871U<@!!<&QI:V%S:2!T96UP;&%T
M92!A<VQI`%1E;7!L871E(&%S;&D@9&D@9&%L86T@)7,Z`$QA:6XM;&%I;@!)
M;F9O<FUA<VD@3&%I;@!)>FEN(%!E;6EL:6L`2V]D92!02%``4$A0(%-H96QL
M`%!-($=E<FEM:7,`4$T@1V5R:6UI<P!032!"97)S86QJ=0!032!'97)I;6ES
M(%-A;&IU`%!-($-E<F%H`%!-($AU:F%N('!E=&ER(&1I<V5R=&%I(&1E;F=A
M;B!A;F=I;B!R:6)U=`!%:W-T96YS:2!03U-)6"!T:61A:R!D:71E;75K86X`
M4$A0(%-H96QL`$IA<F%K('-P87-I(&1A<FD@8F]R9&5R`%-E8F%G:6%N($)E
M<F%W86X`4V%N9&D`4V%N9&D@8F5R:&%S:6P@9&EU8F%H+@!386YD:3H`4V%N
M9&DZ`%-A;F1I(&AA<G5S(&-O8V]K+@!386QI;@!,96MA=&MA;B!D87)I(&-L
M:7!B;V%R9`!0871H`%!E;F1A9G1A<F%N('EA;F<@9&ET=6YD83H`3W)A;F<`
M4&5R<V5N`$UE;&%K<V%N86MA;B!/<&5R87-I(%!E;65L:6AA<F%A;@!-96QA
M:W-A;F%K86X@;W!E<F%S:2!P96UE;&EH87)A86X@<&%D82!W86MT=2!L;V=I
M;C\`27II;B!U;G1U:R`B)7,B('1I9&%K(&1A<&%T(&1I:&%P=7,N`$EZ:6X@
M061M:6YI<W1R87-I`$EN9F]R;6%S:2!0<FEB861I`$)I;F%T86YG($ME<V%Y
M86YG86X`1F]T;P!0:7AE;`!+871A+6MA=&$@:VQI<V4`4VEL86MA;B!K;&EK
M(&ME(&1A;&%M(&)E8F5R87!A('-E;`!3:6QA:V%N(&MO;F9I<FUA<VD@8F%H
M=V$@86YD82!I;F=I;B!M96UI;F1A:&MA;B!E;&5M96X@:6YI.@!3:6QA:V%N
M(&MO;F9I<FUA<VD@8F%H=V$@86YD82!I;F=I;B!M96YG:&%P=7,@;&EN:R!U
M;G1U:R!E;&5M96X@:6YI+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@=6YT=6L@
M:V%T96=O<FD@>6%N9R!B87)U.@!3:6QA:V%N(&UA<W5K:V%N(')I;F=K87-A
M;B!U;G1U:R!M87-A;&%H+@!3:6QA:V%N(&UA<W5K:V%N(&YA;6$@<&5N9V=U
M;F$@9&%N('-A;F1I(&%N9&$`4VEL86MA;B!M96UB86-A('1E:W,@8F5R:6MU
M="!I;FDN($%N9&$@2$%255,@<V5T=6IU(&1E;F=A;B!S>6%R870M<WEA<F%T
M('5N='5K(&UE;F=G=6YA:V%N('-I<W1E;2X`4&]L:71I:P!0;VQL:6YG`%!O
M<VES:2!U;G1U:R!G86UB87(@:6YI`%!O<VES:2!U;G1U:R!T86)E;"!I;FD`
M2'5J86X@<V%L:G4@=6YT=6L@)7,@:F%M('1E<F%K:&ER.@!+96UU;F=K:6YA
M;B`\8G(O/DAU:F%N('-A;&IU`%1E:V%N86X`5&5K86YA;B!P861A('!E<FUU
M:V%A;B!L875T.@!496MA;F%N.@!,:6AA=`!,:6AA="!G86UB87(@9&D@9&%L
M86T@:F5N9&5L82!Y86YG(&)A<G4`0V5T86L@9&]K=6UE;@!$97-K<FEP<VD@
M36%S86QA:`!0<F]J96L`475E<GD`2W5O=&$`2'5J86X`2'5J86X@9&D@<&%G
M:2!H87)I`$AU:F%N(&)E8F5R87!A('-A870@;&%G:0!'97)I;6ES`$AU:F%N
M(&1A;B!"97)S86QJ=0!(=6IA;B!B97)C86UP=7(@9&5N9V%N('-A;&IU`%)A
M;6%L86X@06-A:P!"86-A`%EA:VEN('5N='5K(&UE;F=H87!U<R`E<S\@3W!E
M<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`66%K:6X@=6YT=6L@
M;65M:6YD86AK86X@9&%T82!P96YG9W5N82!U;G1U:R!P96YG9W5N82`E<S\@
M3W!E<F%S:2!I;FD@=&ED86L@9&%P870@9&EB871A;&MA;BX`56QA;F=I(&%K
M<VD@=&5R86MH:7(@86YD80!2969R97-H($5L96UE;B!-96YU($1I;F%M:7,Z
M`%)E9G)E<V@@3&EH870@4&]R=&%L.@!$:71A;F1A:0!296UO=&4@4V5R=F5R
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I`%!I
M;F1A:&MA;@!0:6YD86AK86X@0FQO:VER`%!I;F1A:&MA;B!#87)A($9O<FUA
M=`!0:6YD86AK86X@<&%S86YG86X`4&EN9&%H:V%N('-C<FEP="!Y86YG('-U
M9&%H(&1I<VEM<&%N(&1A<FD@9&ER96MT;W)I('-E<G9E<B!S96UE;G1A<F$N
M`%!I;F1A:&MA;@!0:6YD86AK86X@;F]D92!I;FD@9&%R:2!D;VMU;65N`%!I
M;F1A:&MA;B!P96YG9W5N80!0:6YD86AK86X@<&5N9V=U;F$Z("5S`$%T=7(@
M:V5M8F%L:2``071U<B!K96UB86QI(%-A;F1I`$%T=7(@:V5M8F%L:2!386YD
M:2!!;F1A`$AA<VEL`$ME;6)A;&D@:V4@4&EL:6AA;@!+971I:R!U;&%N9R!S
M86YD:2!B87)U`$ME;6)A;&D@:V4@2V]N9FEG=7)A<VD`4&EL:6AA;B!%9&ET
M;W(@4FEC:"!497AT`%1E:V$M=&5K:0!+86YA;@!0<F]P97)T:2!"87)I<RXN
M+@!0<F]P97)T:2!"87)I<P!0<F]P97)T:2!B87)I<P!"87)I<SH`071U<F%N
M`$%T=7)A;B!A:V%N(&1I=&%M<&EL:V%N(&1I86YT87)A('-E;75A(&)A<FES
M(&1A;B!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D:6%N
M=&%R82!K;VQO;0!!='5R86X@86MA;B!D:71A;7!I;&MA;B!H86YY82!D:6%N
M=&%R82!B87)I<P!*86QA;FMA;@!097-A;B!335,`4U%,(%-H96QL`%-32`!3
M7U%,(%-H96QL`%-B=`!&<F%M92!Y86YG('-A;6$@*%]S96QF*0!3:6UP86X`
M4VEM<&%N("5S`%-I;7!A;B!0:6QI:&%N`%-I;7!A;B!K;VYF:6=U<F%S:2!Y
M86YG(&1I:&%S:6QK86X@<V5B86=A:2!S8W)I<'0@4$A0(&ME(&1A;&%M(&1I
M<F5K=&]R:2!S97)V97(@<V5M96YT87)A(&%N9&$N`$MO;F9I9W5R87-I("5S
M('-U9&%H(&1I<VEM<&%N+@!396)A9VEA;B!(=6IA;B!P971I<B!D:7-E<G1A
M:2!A;F=I;B!R:6)U=`!);&UU(%!E;F=E=&%H=6%N`%!E;F-A<FEA;@!-97-I
M;B!096YC87)I86X`4&EL:6@@9W)U<"!U;G1U:R!D:71A;6)A:`!0:6QI:"!P
M96UI;&EK(&)A<G4`4&EL:6@@<V5R=F5R`%!I;&EH('!E;F=G=6YA('5N='5K
M(&1I=&%M8F%H`%!I;&EH(&MA<F%K=&5R('EA;F<@86YD82!P97)L=6MA;B!D
M87)I(&MO=&%K+6MO=&%K(&1I8F%W86@@:6YI+B!!;F1A(&1A<&%T(&UE;GEA
M;&EN(&1A;B!M96QE:V%T:V%N;GEA(&ME(&1A;&%M(&%R96$@=&5K<RX`4&EL
M:6@@8F%T87,@=&%N9V=A;#H`4&EL:6@@9F]R;6%T('1A;F=G86PZ`%!I;&EH
M(&ED96YT:71A<R!Y86YG(&EN9VEN(&1I=6)A:"!O;&5H(&%N9&$Z`%!I;&EH
M(&)A=&%S('=A:W1U.@!0:6QI:"!F;W)M870@=V%K='4Z`%!I;&EH(&1U82!K
M;VQO;2!Y86YG(&-O8V]K+@!0:6QI:"!W87)N82!S8VAE;64@86YD82X`4&EL
M:6@@8F%H87-A('EA;F<@86YD82!I;F=I;FMA;CH`2VER:6T@3&%P;W)A;B!-
M87-A;&%H`%-E;G-O<CH`4V5P=&5M8F5R`$%T=7(@<&EL:6AA;B!U;G1U:R!M
M96YG:7II;FMA;B!A;F1A(&1A<&%T(&UE;F=A='5R('5L86YG(&ME;6)A;&D@
M<V%N9&D@86YD82!A<&%B:6QA(&%N9&$@;'5P82X`071U<B!R96UO=&4@<V5R
M=F5R('EA;F<@:6YG:6X@86YD82!A:W-E<R!D87)I('!O<G1A;"!A;F1A+@!!
M='5R(&)A:&%S82P@>F]N82!W86MT=2!D86X@<&EL:6AA;B!T86YG9V%L+"!Y
M86YG(&%N9&$@:6YG:6YK86XN`$%T=7(@87!L:6MA<VD@87=A;"!A;F1A+"!W
M87)N82!S8VAE;64L(&AA;&%M86X@<F5F<F5S:"!D86X@<&EL:6AA;B!T86UP
M:6QA;B!L86EN;GEA+@!3971U<`!38W)I<'0@<V5T=7`@=7!G<F%D92!T97)S
M961I80!"96)E<F%P82!L;VMA<VD@>6%N9R!M=6YG:VEN(&1E;F=A;B!P87)A
M;65T97(Z`$)E;&%N:F$`4FEN9VMA<V%N(%!E;F1E:P!097)L=6MA:"!K=6YC
M:2!A:W-E<R!D:61E9FEN:7-I:V%N('5N='5K(&ME8F%N>6%K86X@;&EN:S\`
M5&%M<&EL:V%N`%1A;7!I;&MA;B!P97)B961A86X@9&EA;G1A<F$@:V]N9FEG
M=7)A<VD@>6%N9R!B87)U(&1I<VEM<&%N(&1A;B!Y86YG(&)A<G4@9&EH87-I
M;&MA;BX`5&%M<&EL:V%N('=A:W1U(&QO9VEN('1E<F%K:&ER(&ME=&EK82!A
M;F1A(&QO9VEN/P!486UP:6QK86X@<&%N96P@;65N=2!T86)E;"!O<&5R87-I
M/P!486UP:6QK86X@365N=2`E<R!D:2!S96)E;&%H(&MI<FD_`%1A;7!I;&MA
M;B!D:6%L;V<@4')O<&5R=&D@4V5L(%1A8F5L`%1A;7!I;&MA;B!D:6%L;V<@
M4')O<&5R=&D@5&%B96P`5&%M<&EL:V%N(&1I86QO9R!0<F]P97)T:2!"87)I
M<R!486)E;`!486UP:6QK86X@9&EA;&]G('!R;W!E<G1I(&=A;6)A<@!'97)I
M;6ES`$=E<FEM:7,@9&D@<&%G:2!H87)I`$=E<FEM:7,@8F5B97)A<&$@<V%A
M="!L86=I`$=E<FEM:7,@9&D@<V5K:71A<B!D865R86@`3&5W871I(%!E;65L
M:6AA<F%A;@!386QJ=0!'97)I;6ES(%-A;&IU`$=E<FEM:7,@4V%L:G4`1V5R
M:6UI<R!386QJ=2!D:2!P86=I(&AA<FD`1V5R:6UI<R!386QJ=2!B96)E<F%P
M82!S86%T(&QA9VD`2V5D86QA;6%N(%-A;&IU.@!097)B86YD:6YG86X@<V%L
M:G4@9&D@*&1A;&%M*2!A:7(Z`$QA9W4@)B!386IA:P!%<F]P82!396QA=&%N
M("A)4T\M.#@U.2TS*0!"96QA:&%N($)U;6D@4V5L871A;@!*87)A:R!A;G1A
M<F$@<V5L('EA;F<@8F5R9&5K871A;@!*87)A:R!A;G1A<F$@:7-I(&1A;B!B
M;W)D97(@9&D@9&%L86T@<V5L`$IA<F%K('-P87-I`$IA<F%K('-P87-I(&1A
M;B!J87)A:R!S<&%S:2!D87)I(&)O<F1E<@!3<&%M`$UA<W5K:V%N($MA<F%K
M=&5R(%-P97-I86P`4&ES86AK86X@4V5L`%!I<V%H:V%N(&MO;&]M`%!I<V%H
M:V%N(&)A<FES`$]L86AR86=A`%-T86YD87(`4&5R:F%L86YA;B!":6YT86YG
M`%-T871U<P!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:6)E<FD@=&%N9&$@
M9V%R:7,`1V%Y82!;0U-370!-:6X`06YG:V$O:'5R=68O<VEM8F]L('EA;F<@
M9&ET=6QI<R!D:6)A=V%H(&=A<FES(&)A<FES('1E:W,`0F5R:&%S:6P`(B5S
M(G-U9&%H(&)E<FAA<VEL(&1I:&%P=7,N`$MO;F9I9W5R87-I('-U9&%H(&)E
M<FAA<VEL(&1I:V5M8F%L:6MA;BX@56QA;F=I('5N='5K(&UE;&EH870@<&5R
M=6)A:&%N+B``0F%C:W5P(&MO;F9I9W5R87-I('-U9&%H(&)E<FAA<VEL(&1I
M<VEM<&%N+@!&:6QE($)A8VMU<"!+;VYF:6=U<F%S:2`E<R!S=61A:"!B97)H
M87-I;"!D:7-I;7!A;BX`)R5S)R!S=61A:"!B97)H87-I;"!D:71U;&ES`%)I
M;F=K87-A;@!-871A:&%R:2!497)B:70`36%T86AA<FD@5&5R8F5N86T`0V5R
M86@`36%T86AA<FD@5&5R8FET`$UA=&%H87)I(%1E<F)I="]-871A:&%R:2!4
M97)B96YA;0!-871A:&%R:2!497)B:70Z`$UA=&%H87)I(%1E<F)E;F%M`$UA
M=&%H87)I(%1E<F)E;F%M.@!!;F=K82]H=7)U9B]S:6UB;VP@>6%N9R!D:71U
M;&ES(&1I871A<R!B87)I<R!T96MS`$1U:W5N9V%N`$AU:F%N('!E=&ER(&1I
M<V5R=&%I(&1E;F=A;B!A;F=I;B!R:6)U=`!(=6IA;B!P971I<B!D:7-E<G1A
M:2!D96YG86X@8F%D86D@86YG:6X@<FEB=70`2'5J86X@<&5T:7(@9&ES97)T
M86D@9&5N9V%N(&%N9VEN(')I8G5T`%!R;W!E<G1I(%1A8F5L`%!R;W!E<G1I
M('1A8F5L`%1A<F=E=#H`5'5G87,`4W5H=2!U;G1U:R!J86T@=&5R86MH:7(Z
M`%-U:'4`4W5H=3H`4W5H=3QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G.R5S
M`%1E;7!L871E($%D;6EN:7-T<F%S:0!(86YY82!496MS`%!E<F%T86%N(%1E
M:W,`5&5K<R!"86=I86X@071A<P!+;7,`5&AA:2`H5$E3+38R,"D`4&5M96QI
M:&%R86%N.CH@8VQA<W,@=&ED86L@8F5R:&%S:6P@9&EP86YG9VEL`%=I;F1O
M=R!0:6QI:&%N('-U9&%H(&1I='5T=7`N(%-I;&%K86X@2V5L=6%R`$AA;GEA
M('-I<VD@8F%G:6%N(&)A=V%H`$UO9&4@3&%Y87(@4&5N=6@@9&EK96YA;"!D
M87!A="!M96YY96)A8FMA;B!M87-A;&%H(&1E;F=A;B!);G1E<FYE="!%>'!L
M;W)E<BP@:G5G82!U;G1U:R!M96YC87)I(&ME<V%L86AA;B!Y86YG(&UE;GEE
M8F%B:V%N(&%N9&$@=&ED86L@;6%M<'4@8F5K97)J82!D96YG86X@8F%I:RX@
M06YD82!M=6YG:VEN('!E<FYA:"!M96YG86QA;6D@=&%M<&EL86X@>6%N9R!B
M=7)U:RP@:V5K=7)A;F=A;B!D87)I(&9U;F=S:2!E9&ET;W(@9&%N+V%T874@
M8G)O=W-E<B!Y86YG('-E<FEN9R!K86QI(')U<V%K(&1A;B!H87)U<R!D:75L
M86YG(&ME;6)A;&DN($II:V$@<VES=&5M(&%N9&$@861A;&%H(%=I;F1O=W,@
M.7@@861A(&ME;75N9VMI;F%N(&%N9&$@86MA;B!M96YD87!A=&MA;B`G2V5S
M86QA:&%N(%!E<FQI;F1U;F=A;B!5;75M)R!D86X@<&5R;'4@=6YT=6L@;64M
M<F5S=&%R="!K;VUP=71E<B!A;F1A+EQN7&X@06YD82!S=61A:"!D:7!E<FEN
M9V%T:2X@4VEL86MA;B!K;&EK($]+(&II:V$@86YD82!I;F=I;B!M96YC;V)A
M(&5D:71O<B!L87EA<B!P96YU:"X`261E;G1I=&%S("(E<R(@<W5D86@@9&EH
M87!U<RX`2&%N>6$@<VES:2!B86=I86X@:VER:0!(86YY82!S:7-I(&)A9VEA
M;B!K86YA;B!D86X@:VER:0!(86YY82!S:7-I(&)A9VEA;B!K86YA;@!397)V
M97(@(B5S(B!S=61A:"!B97)H87-I;"!D:6AA<'5S+@!397)V97(@(B5S(B!S
M=61A:"!B97)H87-I;"!D:7-I;7!A;BX`4&5R;6EN=&%A;B!P96YD869T87)A
M;B!U;G1U:R`E<R!S=61A:"!B97)H87-I;"!D:7!I;F1A:&MA;BX`2&%N>6$@
M<VES:2!B86=I86X@871A<R!D86X@8F%W86@`2&%N>6$@<VES:2!B86=I86X@
M871A<P!!<F5A(&ME('=E871H97(N8V]M('1I9&%K(&1I<V5D:6%K86XN`$%D
M82!K97-A;&%H86X@9&D@9&%L86T@9F]R;75L:7(@:V]N9FEG=7)A<VDN($UU
M;F=K:6X@86YD82!T:61A:R!M96YG:7-I(&MO;&]M('EA;F<@9&EP97)L=6MA
M;BX`26YI(&%D86QA:"`E<RX`5VEN9&]W(&EN:2!H87)U<R!D:7!A;F=G:6P@
M9&%R:2!0:6QI:&%N(%=I;F1O=P!0971I<@!4:6ME=`!-96YG:6MU=&D@5V%K
M='4`1F]R;6%T(%=A:W1U`$IU9'5L`$IU9'5L("A#871A=&%N('!E='5N:G5K
M*0!(87)I($EN:0!'86YT:2!3;W5R8V4@2%1-3`!"97-O:P!!=&%S`$9R86UE
M($%T87,@*%]T;W`I`%1R86YS;&%S:0!396P`5'5R:VD@*$E33RTX.#4Y+3DI
M`$EN9&5K<R!5+E8Z`%523`!54DPZ`%1I9&%K(&1A<&%T('5N='5K(&UE;F=H
M87!U<R`B)7,B.B`E<RX`1V%R:7,@8F%W86@`0F%T86QK86X@4&5R=6)A:&%N
M`$)A=&%L:V%N(&%K<VD@=&5R86MH:7(@86YD80!4:61A:R!D:6%R<VEP:V%N
M`%5N:6-O9&4@*%541BTX*0!5;FET`$)A=&%L:V%N(&QI;FL@<&%D82!E;&5M
M96X@>6%N9R!S96MA<F%N9P!38W)I<'0@>6%N9R!T:61A:R!M96UP=6YY86D@
M:&%K(&ES=&EM97=A('1I9&%K(&1A<&%T(&UE;F=A:W-E<R!(87!U<R]386QI
M;B],96MA=&MA;B!S97-U86D@<F5N8V%N82!U;G1U:R!A;&%S86X@:V5A;6%N
M86XN2VQI:R!/2R!U;G1U:R!M96QI:&%T(&-A=&%T86X@=&5K;FES('!A9&$@
M;6]Z:6QL82YO<F<@9&EM86YA(&%N9&$@86MA;B!D:7!E<FQI:&%T:V%N(&-A
M<F$@8F%G86EM86YA('5N='5K(&UE;F=I>FEN:V%N('-C<FEP="!U;G1U:R!D
M87!A="!M96YG86MS97,@:V4@8VQI<&)O87)D+@!787)N82!B96QU;2!D:6%T
M=7(`4&5R8F%H87)U:0!097)B86AA<G5I("5S`%!E<F)A:&%R=6D@<&5N9V=U
M;F$`(B5S(B!S=61A:"!D:7!E<F)A:&%R=6DN`%-C<FEP="!U<&=R861E('-U
M9&%H(&1I:&%P=7,N`%5P;&]A9`!396UU82!F:6QE('-E='5P(&%P;&EK87-I
M('-U9&%H(&1I=7!L;V%D(&ME('-E<G9E<BX`4VEM8F]L(&AU<G5F(&)E<V%R
M(&QA=&EN`%-I;6)O;"!H=7)U9B!B97-A<B!R;VUA=VD`1W5N86MA;FQA:"!J
M:6MA(&YA;6$O<V%N9&D@86YD82!B97)B961A('5N='5K('-E<G9E<B!)35-0
M+@!!9&UI;FES=')A<VD@4&5N9V=U;F$`4&5N9&%F=&%R86X@4&5N9V=U;F$`
M4&5N9&%F=&%R86X@4&5N9V=U;F$@<W5D86@@9&EN;VXM86MT:69K86X@=6YT
M=6L@<VET92!I;FDN`$%C8V]U;G0@4&5N9V=U;F$@=&ED86L@9&ET96UU:V%N
M`$YA;6$@4&5N9V=U;F$`3F%M82!096YG9W5N83H`3F%M82!096YG9W5N83H`
M4&5N9V=U;F$@9&D@9&%L86T@<VES=&5M.@!,:6)U<F%N`%9A<FEA8FQE`%9E
M<G-I($MO;G1R;VP`2F%R86L@<&]S:7-I('9E<G1I:V%L(&%N=&%R82!G87)I
M<R!D87-A<B!D96YG86X@9V%M8F%R`$IA<F%K('!O<VES:2!V97)T:6MA;"!A
M;G1A<F$@8F]R9&5R(&1E;F=A;B!G86UB87(`5F5R=&EK86PZ`%-A;F=A="!4
M:6YG9VD`5FEE=&YA;2`H5DE30TE)*0!,:6AA="!W96(@<&%G92!E:W-T97)N
M86P`2F%R86L@4&%N9&%N9P!*87)A:R!086YD86YG.@!015))3D=!5$%.(2$A
M(%!)3D1!2$M!3B!30U))4%0@24Y)(%-%0T%202!-04Y504P@1$%222`E<RX`
M4&5R:6YG871A;@!286)U`%)A;6%L86X@0W5A8V$`1&%T82!#=6%C82!D:7-E
M9&EA:V%N(&]L96@`5V5B`%=E8B!3:71E`%-E;&%M870@1&%T86YG`%-E;&%M
M870@9&%T86YG(&ME("5S`%-E;&%M870@9&%T86YG+"`E<P!797-T97)N("A)
M4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`07!A:V%H(&%P;&EK
M87-I("5S('!E<FQU(&1I=&%M<&EL:V%N('-E=&5L86@@;&]G:6X_`$%P86MA
M:"!Y86YG(&UE<G5P86MA;B!B871A<R!K87)A:W1E<C\`07!A:V%H('EA;F<@
M;65R=7!A:V%N(&MA<F%K=&5R(&EN9&5N=&%S:3\`1F%S92!Y86YG(&UA;F$`
M4&QU9VEN(&UA;F%K86@@>6%N9R!D87!A="!D:6%K=&EF:V%N('5N='5K(&5D
M:71O<B!2:6-H(%1E>'0N`$QE8F%R`$QE8F%R(&UE;G4@)7,@<&%D82!B86=I
M86X@:VER:2`H86MA;B!B97)P96YG87)U:"!P861A(&QO9VEN(&)E<FEK=71N
M>6$I`$QE8F%R('1A8F5L`$QE8F%R('5N:70`3&5B87(Z`%=I:VD`06YG:6X`
M06YG:6X@9&D@<&%G:2!H87)I`$ME8V5P871A;B!A;F=I;B!D:2!D86QA;2!K
M;F]T`$%N9VEN.@!!;F=I;CH`2V%T82!":6IA:W-A;F$`1&%F=&%R($ME:6YG
M:6YA;@!096ME<FIA86X`6"U2968`65D`66$L(%-!64$@4T5454I5`$%N9&$@
M8F5R861A(&1I(&1A;&%M($U/1$4@5$5+4RX@1W5N86MA;B!T;VUB;VP@6SP^
M72!U;G1U:R!M96YG9V%N=&D@:V5M8F%L:2!K92!D86QA;2!M;V1E(%=94TE7
M64<N`$%N9&$@=&ED86L@9&EI>FEN:V%N('5N='5K(&UE;6)U870@;&5B:6@@
M9&%R:2`E9"!A<F5A+@!!;F1A(&AA<G5S(&UE;FIE;&%S:V%N(&UA<V%L86@@
M<V5B96QU;2!A;F1A(&1A<&%T(&UE;F=I<FEM:V%N(&QA<&]R86X@;6%S86QA
M:"X`06YD82!H87)U<R!M96UA<W5K:V%N(%523"!D:6UA;F$@;&EN:R!I;FD@
M;65N=6YJ=6L@:V4`06YD82!H87)U<R!M96UI;&EH('-E<G9E<B!U;G1U:R!D
M87!A="!D:6AA<'5S+@!!;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG
M9W5N82!Y86YG(&EN9VEN(&1I8F5R<VEH:V%N+@!!;F1A(&AA<G5S(&UE;F5T
M87!K86X@;F%M82!P96YG9W5N82!Y86YG(&EN9VEN(&1I<&EN9&%H:V%N+@!!
M;F1A(&AA<G5S(&UE;F5T87!K86X@;F%M82!P96YG9W5N82!U;G1U:R!D:71A
M;6)A:"X`06YD82!H87)U<R!M96YE=&%P:V%N(&YA;6$@<&5N9V=U;F$@=6YT
M=6L@9&EP97)B86AA<G5I+@!!;&%M870@16UA:6P@06YD80!!;F1A($1A<FDZ
M(&%L86UA=#H`26YF;W)M87-I($%N9&$`3F%M82!!;F1A`$)A8VME;F0@87-L
M:2!A;F1A('1I9&%K(&1A<&%T(&UE;F1U:W5N9R!P96YD869T87)A;B!P96YG
M9W5N82P@871A=2!F:71U<B!I;FD@<W5D86@@9&EN;VXM86MT:69K86X@=6YT
M=6L@8F5B97)A<&$@86QA<V%N(&QA:6X`0G)O=W-E<B!A;F1A('1I9&%K(&UE
M;F1U:W5N9R!U;G1U:R!F:71U<B!I;FDN`%IO;F$@5V%K='4@06YD82!396MA
M<F%N9SH`1&5F875L="!I9&5N=&ET87,@86YD82!S=61A:"!D:75B86@N`$1E
M9F%U;'0@:61E;G1I=&%S(&%N9&$Z`$YA;6$@;&5N9VMA<"!A;F1A.@!386YD
M:2!B87)U(&%N9&$@=6YT=6L@)7,@861A;&%H.B`E<P!386YD:2!A;F1A('-U
M9&%H(&1I871U<B!U;&%N9P!386YD:2!A;F1A('-U9&%H(&1I871U<B!U;&%N
M9RP@<&5R:6MS86QA:"!E;6%I;"!A;F1A(&1A;B!L;V=I;B!D96YG86X@;65N
M9V=U;F%K86X@<V%N9&D@8F%R=2!A;F1A`%)E;6]T92!S97)V97(@86YD83H`
M0V5R:6$`6U-E;6)U;GEI:V%N($EN9&5N=&%S:2!496MS70!;3&%P;W)A;B!-
M87-A;&%H70!;5&%M<&EL86X@26YD96YT87-I(%1E:W,@+0!?061M:6YI<W1R
M87-I`%]#3$D`7T1A=&%4<F5E`$AA<'5S($)A<FES`%]'<G5P`%!R;W!E<G1I
M($=A;6)A<BXN+@!58F%H($QI;FLN+BX`27II;@!0:6YD86AK86X@3&EN:RXN
M+@!?4V5T=7``4')O<&5R=&D@5&%B96PN+BX`4&5N9V=U;F$`5&5N86YG`&IA
M='5H`$1A<FD@)7,@*"5S*2!P861A("5S("5S`&%N9VEN(&ME;F-A;F<`;6%S
M:6@@9&D@9&%L86T@86YT<FEA;@!B87)I<UT`;F%M80!P97)S96X`<&EX96P`
M;F%I:P!T86UP:6QK86X@<&5R8F5D86%N`'1E=&%P`$ME=&EK('-A;F1I(&1U
M82!K86QI('5N='5K(&UE;F=K;VYF:7)M87-I`&UE;GEA='5K86X`=V5A=&AE
M<BYC;VT`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+VAE7TE,
M+TQ#7TU%4U-!1T53````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,30U-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O:&5?24PO3$-?34534T%'15,O:&]R9&4N;6\`````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,3<S,#(@,3`U,34T,S0Q-#$@,#(S,3<V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````-X2
M!)4`````J0```!P```!D!0``XP```*P*````````.`X```P````Y#@``"P``
M`$8.```'````4@X```<```!:#@``"@```&(.```)````;0X```<```!W#@``
M"0```'\.```'````B0X```<```"1#@``!P```)D.```*````H0X```<```"L
M#@``!@```+0.```'````NPX```@```###@``!@```,P.```1````TPX```<`
M``#E#@``"````.T.```(````]@X```8```#_#@``!@````8/```*````#0\`
M`!@````8#P``!````#$/```%````-@\```4````\#P``!0```$(/```&````
M2`\```@```!/#P``!0```%@/```*````7@\```0```!I#P``!@```&X/```.
M````=0\```<```"$#P``$@```(P/```'````GP\```4```"G#P``"P```*T/
M```(````N0\```0```#"#P``!P```,</```#````SP\```8```#3#P``!0``
M`-H/```&````X`\```<```#G#P``!P```.\/```%````]P\```(```#]#P``
M!@`````0```'````!Q````D````/$```!@```!D0```&````(!````4````G
M$```#0```"T0```$````.Q```!T```!`$```"````%X0```(````9Q````H`
M``!P$```!P```'L0```'````@Q````4```"+$```"0```)$0```9````FQ``
M``0```"U$```!P```+H0```&````PA````4```#)$```!P```,\0```%````
MUQ````8```#=$```!0```.00```&````ZA````<```#Q$```!P```/D0```6
M`````1$```H````8$0``"@```",1```&````+A$```@````U$0``"````#X1
M```$````1Q$```4```!,$0``"@```%(1```)````71$```8```!G$0``!@``
M`&X1```(````=1$```<```!^$0``"@```(81```$````D1$```4```"6$0``
M"P```)P1```+````J!$```D```"T$0``!0```+X1```'````Q!$```8```#,
M$0``!````-,1```'````V!$```4```#@$0``"````.81```&````[Q$```@`
M``#V$0``"````/\1```)````"!(```H````2$@``!````!T2```+````(A(`
M``8````N$@``"````#42```%````/A(```<```!$$@``$@```$P2```&````
M7Q(```P```!F$@``!@```',2```'````>A(```H```""$@``#````(T2```)
M````FA(```<```"D$@``#````*P2```%````N1(```D```"_$@``!0```,D2
M```(````SQ(```D```#8$@``!@```.(2```+````Z1(``!0```#U$@``'```
M``H3```(````)Q,```4````P$P``$P```#83```'````2A,```8```!2$P``
M`P```%D3```$````71,```8```!B$P``!P```&D3```4````<1,```X```"&
M$P``#0```)43```&````HQ,```<```"J$P``"````+(3```'````NQ,```D`
M``##$P``!P```,T3```(````U1,```0```#>$P``!0```.,3```&````Z1,`
M``4```#P$P``"@```/83```&`````10```@````(%```!0```!$4```(````
M%Q0```@````@%```#````"D4```$````-A0``$X!```[%```$P```(H5```0
M````GA4```P```"O%0``#````+P5```?````R14``!````#I%0``#````/H5
M```0````!Q8```X````8%@``$0```"<6```,````.18```P```!&%@``"@``
M`%,6```(````7A8```X```!G%@``#@```'86```*````A18```P```"0%@``
M#@```)T6```.````K!8```H```"[%@``"````,86```&````SQ8```\```#6
M%@``+@```.86```$````%1<```@````:%P``!@```",7```3````*A<``!<`
M```^%P``$````%87```*````9Q<``!,```!R%P``"````(87```.````CQ<`
M``@```">%P``"````*<7```I````L!<```X```#:%P``"@```.D7```5````
M]!<```X````*&```"````!D8```,````(A@```@````O&```"````#@8```(
M````01@```H```!*&```#````%48```,````8A@```8```!O&```!````'88
M```(````>Q@```H```"$&```#@```(\8```*````GA@```H```"I&```"@``
M`+08```<````OQ@```@```#<&```"@```.48```.````\!@```@```#_&```
M"0````@9```.````$AD```P````A&0``"````"X9```2````-QD```@```!*
M&0``"````%,9```,````7!D```P```!I&0``#````'89```,````@QD```8`
M``"0&0``"````)<9```(````H!D```P```"I&0``"@```+89```,````P1D`
M``8```#.&0``$@```-49```,````Z!D```H```#U&0``#@`````:```?````
M#QH```8````O&@``"````#8:```2````/QH``!(```!2&@``#````&4:```*
M````<AH``!````!]&@``"@```(X:```.````F1H```0```"H&@``!@```*T:
M```*````M!H``!,```"_&@``$````-,:```(````Y!H```P```#M&@``$```
M`/H:```*````"QL``!`````6&P``!@```"<;```,````+AL```@````[&P``
M#@```$0;```*````4QL```L```!>&P``#````&H;```&````=QL``!0```!^
M&P``"@```),;```.````GAL```8```"M&P``#````+0;```*````P1L```P`
M``#,&P``%0```-D;```*````[QL```@```#Z&P``$P````,<```5````%QP`
M``X````M'```#````#P<```7````21P```@```!A'```#P```&H<```(````
M>AP```P```"#'```$````)`<```,````H1P```H```"N'```"@```+D<```,
M````Q!P```P```#1'```(````-X<```;````_QP```X````;'0``#@```"H=
M```&````.1T```<```!`'0``#````$@=```0````51T``",```!F'0``&P``
M`(H=```7````IAT```H```"^'0``$````,D=```<````VAT```P```#W'0``
M#@````0>```*````$QX```\````>'@``!@```"X>```'````-1X```@````]
M'@``"````$8>```2````3QX```P```!B'@``$````&\>```(````@!X```X`
M``")'@``$````)@>```3````J1X```0```"]'@```0```*````!`````````
M````````````I@```*,````I````$P````````!B````&````!````!,````
M``````<````Z````,@```&,```"-````&@````````!*````6@```%X```!'
M````:@````P```!?````)````!4````H````,````((```!U````0@```)(`
M``!;````D0```)@````]````,0````H````&````&0```',`````````````
M```````N````'@`````````C`````@``````````````````````````````
M.0```%<`````````'````&D``````````````&0```!Q````*P```"8```!=
M````=P```$X```!)````-````($```!X`````````&<```!O````@P````0`
M``"I````C@```!8````M````9@````T```":````(@```!T````2````2P``
M`*4`````````B@`````````L````>0```)X``````````````#\`````````
ME@```&$```!\````90```&@`````````A0```#4```![````@````"<````?
M````&P````````!6````+P```(<```"7`````````'\```!^`````````%(`
M``"D````;`````4````\````G0`````````#````````````````````.P``
M`````````````````%````````````````````"A````7`````````!%````
M1@```#,``````````````!<`````````H@```$,`````````:P```!0````W
M````00`````````/````(````)D```"(````50```"4````1````A```````
M````````"0```&X``````````````'0```!Z```````````````^````4P``
M`*@``````````````)P```!/````-@```(P```"/````8````)4`````````
M6````(L`````````B0```$@```"?````=@````````!-````E````$0````J
M`````````"$```!M````DP````L```"G````<````%$```!9````FP````@`
M````````?0```%0```"0````<@```#@`````````A@````X`````061D<F5S
M<R!";V]K`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;G1A<F-T:6-A
M`$%R9V5N=&EN80!!<FUE;FEA`$%U<W1R86QI80!!=7-T<FEA`$)A:&%M87,`
M0F%H<F%I;@!"86YG;&%D97-H`$)E;&=I=6T`0F5L:7IE`$)O;&EV:6$`0F]T
M<W=A;F$`0G)A>FEL`$)R=6YE:2!$87)U<W-A;&%M`$)U<G5N9&D`0V%M8F]D
M:6$`0V%M97)O;VX`0V%N861A`$-A;F-E;`!#87!E(%9E<F1E`$-E;G1R86P@
M069R:6-A;B!297!U8FQI8P!#:&%D`$-H:6QE`$-H:6YA`$-L96%R`$-L;W5D
M>0!#;VQO;6)I80!#;VYG;P!#;W-T82!2:6-A`$-U8F$`0WEP<G5S`$-Z96-H
M(%)E<'5B;&EC`$1E;FUA<FL`1&]M:6YI8V%N(%)E<'5B;&EC`$5C=6%D;W(`
M16=Y<'0`16P@4V%L=F%D;W(`171H:6]P:6$`1FEJ:0!&:6YL86YD`$9O9P!&
M<F%N8V4`1V%B;VX`1V%M8FEA`$=E;W)G:6$`1V5R;6%N>0!':&%N80!';P!'
M<F5E8V4`1W)E;F%D80!'=6%T96UA;&$`1W5I;F5A`$=U>6%N80!(86ET:0!(
M96%V>2!4+5-T;W)M`$AE;'``2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T
M92D`2&]N9'5R87,`2'5M:61I='D`2'5M:61I='DZ(`!(=6YG87)Y`$EC96QA
M;F0`26YD:6$`26YD;VYE<VEA`$ER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8`
M27)A<0!)<F5L86YD`$ES<F%E;`!)=&%L>0!*86UA:6-A`$IA<&%N`$IO<F1A
M;@!+96YY80!+=7=A:70`3&5B86YO;@!,:6)E<FEA`$QI8GEA;B!!<F%B($IA
M;6%H:7)I>6$`3'5X96UB;W5R9P!-861A9V%S8V%R`$UA;&%W:0!-86QA>7-I
M80!-86QD:79E<P!-86QI`$UA;'1A`$UA=7)I=&%N:6$`36%U<FET:75S`$UE
M>&EC;P!-;VYA8V\`36]N9V]L:6$`36]R;V-C;P!-;WIA;6)I<75E`$YA;64`
M3F5P86P`3F5T:&5R;&%N9',`3F5W(%IE86QA;F0`3FEC87)A9W5A`$YI9V5R
M`$YI9V5R:6$`3F]R=V%Y`$]M86X`3W!T:6]N<P!/=&AE<@!086MI<W1A;@!0
M86YA;6$`4&%R86=U87D`4&%S<W=O<F0`4&%S<W=O<F0Z`%!A<W-W;W)D.B``
M4&5R=0!0:&EL:7!P:6YE<P!0;VQA;F0`4&]R='5G86P`46%T87(`4F]M86YI
M80!2=7-S:6%N($9E9&5R871I;VX`4G=A;F1A`%-A=61I($%R86)I80!396%R
M8V@`4V5N96=A;`!397EC:&5L;&5S`%-I97)R82!,96]N90!3:6YG87!O<F4`
M4V]M86QI80!3;W5T:"!!9G)I8V$`4W!A:6X`4W)I($QA;FMA`%-U9&%N`%-U
M<FEN86UE`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WER:6%N($%R
M86(@4F5P=6)L:6,`5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9@!4:&%I
M;&%N9`!4;VYG80!4<FEN:61A9"!A;F0@5&]B86=O`%1U;FES:6$`5'5R:V5Y
M`%523`!54DPZ`%5G86YD80!5:W)A:6YE`%5N:71E9"!!<F%B($5M:7)A=&5S
M`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`57!L;V%D`%5R=6=U87D`
M57-E<FYA;64`5F%N=6%T=0!696YE>G5E;&$`5F5R<VEO;@!6:65T($YA;0!7
M:6YD`%=I;F0Z`%=I;F0Z(`!996UE;@!9=6=O<VQA=FEA`%IA;6)I80!::6UB
M86)W90!?2&5L<`!?3&]G(&]U=`!?3W!T:6]N<P!A9&1R97-S(&)O;VL`;F%M
M90!0<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,BUC=G,*4F5P;W)T+4US
M9VED+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N
M+41A=&4Z(#(P,#8M,#(M,#<@,#0Z,#@M,#4P,`I03RU2979I<VEO;BU$871E
M.B`R,#`V+3`R+3`W(#`T.C`X+3`U,#`*3&%S="U4<F%N<VQA=&]R.B!-871T
M(%-E;'-K>2`\<V5L<VMY0&-O;'5M8FEA+F5D=3X*3&%N9W5A9V4M5&5A;3H@
M:3$X;D!L:7-T<RYH;W)D92YO<F<*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5541BTX"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:70*`->AUZ37J"#7F]>JUY77D=>5UZH`UY#7
MI->2UZ#7F=>AUZK7GP#7D-><UY'7H->9UY0`UY#7G->2UZC7F=>4`->9UY'7
MJ=>JXH"3UY#7H->8UY#7J->GUYC7F=>GUY0`UY#7J->2UZ#7F->9UZ#7E`#7
MD->HUY[7H->9UY0`UY#7E=>AUYC7J-><UYG7E`#7D->5UZ'7F->HUYG7E`#7
MD->9UYGB@)/7D=>4UY[7E`#7D=>7UZC7F=>9UY\`UY'7H->2UYS7D]>I`->1
MUYS7DM>9UY0`UY'7G->9UY8`UY'7E=><UYG7D=>9UY0`UY'7E=>FUY77E=>@
MUY0`UY'7J->6UYG7G`#7D=>HUY77H->9UYD`UY'7E=>HUY77H->3UYD`UZ?7
MGM>1UY77D]>9UY0`UZ?7GM>HUY77GP#7I]>@UY/7E`#7J=>@UY0`UZ?7I->4
M(->5UZC7D]>4`->4UZ?7E->9UYS7F=>9UY0@UY37GM>HUYO7EN*`D]>0UZ37
MJ->9UZ?7H->9UZH`UZ;7DP#7IM>9UYS7F0#7H=>9UY\`UZG7GM>9UYT@UY'7
ME->9UZC7G0#7J=>>UYG7G2#7GM>BUY77H->@UYG7G0#7I]>5UYS7E=>>UY'7
MF=>4`->GUY77H->2UY4`UZ?7E=>AUYC7E"#7J->9UZ?7E`#7I]>5UY'7E`#7
MI]>DUZC7F=>AUYG7GP#7IM>;UYG7E`#7D]>@UYG7E`#7E->HUZ37E=>1UYS7
MF=>GUY0@UY37D]>5UY[7F=>@UYG7I]>@UYG7J@#7D->GUY77E=>3UY77J`#7
MGM>FUZC7F=>=`->0UYSB@)/7H=><UY77E=>3UY77J`#7D->JUYG7E=>DUYG7
ME`#7I->9UY+7F0#7I->9UZ#7G->@UY,`UZ+7J->DUYP`UZ;7J->DUZH`UY+7
MD=>5UY\`UY+7GM>1UYG7E`#7DM>5UZC7DM>9UY0`UY+7J->>UZ#7F=>4`->2
MUZ#7E`#7G->:`->9UY77E=>?`->2UZC7H->3UY0`UY+7E=>0UYC7GM><UY0`
MUY+7F=>@UY#7E`#7DM>9UY#7H->4`->4UY#7F=>8UYD`UZ'7E=>DUZKB@)/7
MJ->BUY[7F=>=(->BUY;7E`#7HM>6UZC7E`#7E=>8UYG7I]>?`->4UY77H->3
MUY77J->A`-><UY?7E=>J`#K7G->7UYG7J@#7E->5UZ#7DM>HUYG7E`#7D->9
MUZ'7G->@UY,`UY37E=>3UY4`UY#7F=>@UY/7E=>@UY;7F=>4`->0UYG7J->?
M`->BUYG7J->G`->0UYG7J-><UZ#7DP#7F=>IUX'7J->0UYP`UY#7F=>8UYS7
MF=>4`->2UY[7F=>9UZ?7E`#7F=>DUY\`UYG7J->3UY\`UZ?7H->9UY0`UYO7
ME=>5UYG7F=>J`-><UY'7H->5UY\`UYS7F=>1UZC7F=>4`-><UY77D0#7G->5
MUYO7H=>>UY'7E=>HUY(`UY[7D]>2UZ'7I]>H`->>UYS7E=>5UYD`UY[7G->9
MUYG7EM>9UY0`UY37D->9UYG7G2#7E->>UYS7D]>9UY77E=>9UYG7G0#7GM><
MUYD`UY[7G->8UY0`UY[7D->5UZC7F=>8UZ#7F=>4`->>UY#7E=>HUYG7IM>9
MUY77H0#7GM>;UZ'7F=>GUY4`UY[7E=>@UZ?7E0#7GM>5UZ#7DM>5UYS7F=>4
M`->>UZC7E=>GUY4`UY[7E=>6UY[7D=>9UZ<`UZG7G0#7H->DUYP`UY37E=><
MUZ#7DP#7H->9UY7B@)/7EM>9UYS7H->3`->@UYG7I]>HUY+7E=>0UY0`UZ#7
MF=>6UZ@`UZ#7F=>2UZC7F=>4`->@UY77J->5UY77DM>9UY0`UZ+7E=>>UY#7
MGP#7D->DUZG7J->5UYG7E=>J`->0UY?7J`#7I->GUYG7H=>JUY\`UZ37H->>
MUY0`UZ37J->2UY77D->9UYD`UZ'7F=>AUY[7D`#7H=>9UZ'7GM>0.@#7H=>9
MUZ'7GM>0.B``UZ37J->5`->DUYG7G->9UZ37F=>@UYG7F=>=`->DUY77G->9
MUY\`UZ37E=>HUYC7E=>2UYP`UZ?7F->H`->HUY77GM>@UYG7E`#7J->5UZ'7
MF=>4`->HUY77D->@UY/7E`#7HM>HUY$@UY37H=>BUY77D]>9UZH`UY?7F=>D
MUY77J0#7H=>@UY+7G`#7D->9UYGB@)/7H=>9UYG7J=><`->GUYG7F=>HUY0@
MUYS7F=>0UY77GP#7H=>9UZ#7DM>DUY77J`#7H=>5UY[7G->9UY0`UY/7J->5
MUYWB@)/7D->DUZC7F=>GUY0`UZ'7I->HUY,`UZ'7J->9(-><UZ#7I]>4`->A
MUY77D]>?`->AUY77J->9UZ#7G0#7H=>5UY77EM>9UYS7H->3`->IUY77E=>3
MUYG7E`#7J=>5UY77F=>E`->AUY77J->9UY0`UYC7H->6UZ#7F=>4`->JUY#7
MF=><UZ#7DP#7I]>1UY77IM>JXH"3UY#7F=>9XH"3UYC7E=>@UY+7E`#7F->H
MUYG7H->9UY/7DR#7E=>8UY77D=>2UY4`UYC7E=>@UYG7H=>9UY0`UYC7E=>H
MUZ?7F=>9UY0`UY#7JM>H`->0UZK7J#H`UY#7E=>2UZ#7D]>4`->0UY77I]>H
MUYG7F=>@UY0`UY37D->>UYG7J->5UYG7E=>J(->4UY[7D->5UY?7D]>5UZH`
MUY37GM>>UYS7F]>4(->4UY[7D->5UY?7D]>J`->0UZC7IM>5UZKB@)/7E->1
MUZC7F=>J`->4UZ+7G->0UY0`UY#7E=>HUY77DM>5UY77F0#7I]>5UY,@UY;7
MF=>4UY77F2#7GM>IUZK7GM>I`->5UZ#7E=>0UYC7E0#7E=>@UY;7E=>0UYS7
ME`#7DM>9UZC7H=>4`->5UYG7F=>8XH"3UZ#7G0#7J->5UY<`UZC7E=>7.@#7
MJ->5UY<Z(`#7JM>9UY[7GP#7F=>5UY+7E=>AUYS7D=>9UY0`UY;7GM>1UYG7
MF=>4`->6UYG7GM>1UY'7E=>5UY0`UZ+7EM>HUY0`UY37JM>@UZK7I]>5UZH`
MUY#7I->IUZC7E=>9UY77J@#7H=>DUZ@@UYO7JM>5UY'7E=>J`->IUYT`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V=L7T53+TQ#7TU%4U-!
M1T53````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,30Q(#`R,30V-P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A
M;&4O9VQ?15,O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,30P,C4@,3`U,34T,S0Q-#$@,#(S,C`V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````-X2!)4`````9```
M`!P````\`P``B0```%P&````````@`@``"@```"!"```"````*H(```%````
MLP@```@```"Y"```!P```,((```%````R@@``!\```#0"```$0```/`(```(
M`````@D```@````+"0``%0```!0)```*````*@D```P````U"0``!P```$()
M```I````2@D```(```!T"0``!0```'<)```0````?0D``!0```"."0``+P``
M`*,)```/````TPD``"8```#C"0``!0````H*```-````$`H```4````>"@``
M$````"0*```0````-0H```\```!&"@``"P```%8*```/````8@H```P```!R
M"@``#P```'\*```>````CPH``"$```"N"@```P```-`*```$````U`H```P`
M``#9"@``"@```.8*```%````\0H``!(```#W"@``$`````H+```(````&PL`
M`!`````D"P``!@```#4+```'````/`L```(```!$"P``!````$<+```/````
M3`L```<```!<"P``!P```&0+```$````;`L```4```!Q"P``!0```'<+```'
M````?0L``!$```"%"P``"````)<+```>````H`L```4```"_"P``*````,4+
M```I````[@L``!,````8#```"P```"P,```1````.`P```0```!*#```#```
M`$\,```:````7`P``!<```!W#```%P```(\,```;````IPP``!\```###```
M$P```.,,```0````]PP``!<````(#0``!P```"`-```%````*`T``"$````N
M#0``'````%`-```%````;0T```,```!S#0``(````'<-```F````F`T```P`
M``"_#0``#````,P-```(````V0T```<```#B#0``!@```.H-```-````\0T`
M``L```#_#0``#`````L.```*````&`X```(````C#@``!@```"8.``!%````
M+0X``#````!S#@``$````*0.```?````M0X``!````#5#@``#P```.8.```%
M````]@X``&\!``#\#@``*@```&P0```(````EQ````4```"@$```#@```*80
M```(````M1````8```"^$```)````,40```3````ZA````L```#^$```"@``
M``H1```?````%1$```X````U$0``#P```$01```(````5!$``#(```!=$0``
M`@```)`1```+````DQ$``!D```"?$0``%@```+D1```O````T!$``!@`````
M$@``*P```!D2```2````11(```X```!8$@``!````&<2```/````;!(``!``
M``!\$@``#@```(T2```5````G!(```\```"R$@``"P```,(2```3````SA(`
M`",```#B$@``(P````83```#````*A,```4````N$P``$P```#03```3````
M2!,```4```!<$P``$P```&(3```2````=A,```8```")$P``&````)`3```&
M````J1,```\```"P$P```@```,`3```&````PQ,``!8```#*$P``!P```.$3
M```,````Z1,```0```#V$P``!0```/L3```%`````10```<````'%```$0``
M``\4```/````(10``"$````Q%```"````%,4```>````7!0``"\```![%```
M%@```*L4```+````PA0``!,```#.%```!P```.(4```1````ZA0``"$```#\
M%```'0```!X5```=````/!4``"4```!:%0``%````(`5```=````E14``!,`
M``"S%0``'P```,<5```-````YQ4```<```#U%0``(@```/T5```;````(!8`
M``8````\%@```P```$,6```J````1Q8``"\```!R%@``$P```*(6```2````
MMA8```<```#)%@``!0```-$6```,````UQ8```P```#D%@``#0```/$6```4
M````_Q8``!0````4%P```@```"D7```*````+!<``"X````W%P``/````&87
M```1````HQ<``!\```"U%P``%0```-47```/````ZQ<``!D```#[%P```0``
M`"0`````````3@```!T```!/````%P```$4````'````(@````````!-````
M(0````````!+````8@````H````1``````````P````R````4P```#$`````
M````)0```$8```!=`````````%(```!"````50````````!'````+````"\`
M``!6````40```#4````0````"````#X```!!````7P```"L````/````.0``
M`$H````C````&````#,```!`````*````&`````+``````````````!4````
M```````````]````"0`````````N````2````%P````Z``````````X`````
M````60`````````V`````````!L````_````'````!H````-````.P``````
M```$````!0`````````2`````````!,`````````5P```"T`````````)@``
M````````````%0````8`````````6P```#<````9`````````%X`````````
M.````#0`````````20```!\```!:````1``````````>``````````````!C
M`````````%@````I`````````#```````````````#P```!D````4```````
M```6````(``````````#````80```$,````J````)P```$P````"````````
M`!0`````)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO
M;@`R-"!H;W5R<P!!32]030!!9&0@<&%I<@!!9&1R97-S`$%L:6%S`$%N(&EL
M;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`079A:6QA8FQE(&9I96QD<SH`
M0FER=&AD87D`0V%L96YD87(`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-E;&P@
M4&AO;F4`0VQO<V4@5VEN9&]W`$-O;7!A;GD`0V]U;&0@;F]T(&]P96X@36%I
M;G1E;F%N8V5?5&%S:R!M;V1U;&4@)7,`1$0`1&%I;'D`1&5F875L="!)9&5N
M=&ET>0!$97-C<FEB92!T:&4@4')O8FQE;0!$971A:6QS(&AA=F4@8F5E;B!L
M;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$:7-P;&%Y($]P=&EO;G,`
M1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``16UA:6P`
M16UP='D@<F5S=6QT+@!%<G)O<@!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P
M('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V97)Y(&AA
M;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$9A:6QE9"!R
M971R:65V:6YG('!R969E<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,
M1$%0('-E<G9E<BX`1F%X`$AE;'``2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]R9&4`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`3&%N
M9W5A9V4`3&ES="!(96QP(%1O<&EC<P!,;V<@:6X`3&]G(&]U=`!-30!-86EL
M`$UA=&-H:6YG(&9I96QD<P!-97-S86=E`$UO;G1H;'D`3F%M90!.979E<@!.
M;W1E<P!/<'1I;VYS`$]T:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O
M<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED
M92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO
M=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`
M4F5M;W9E('!A:7(`4F5T=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO
M;G,`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M
M871C:&EN9R!F:65L9',N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I
M86P@0VAA<F%C=&5R($EN<'5T`%-U8V-E<W,`5&%S:W,`5&AI<R!N=6UB97(@
M;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&ET;&4`55),`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N
M9&\@0VAA;F=E<P!5<V5R($]P=&EO;G,`57-E<FYA;64`5V%R;FEN9P!7965K
M;'D`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R
M:R!0:&]N90!960!996%R;'D`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L
M96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO
M=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN
M+@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D
M871E9"X`6U!R;V)L96T@4F5P;W)T70!;;&EN92`E<R!O9B`E<UT`=D-A<F0`
M4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`R+C$*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`S
M+3`X+3$Y(#$S.C,U1TU4*S$*3&%S="U4<F%N<VQA=&]R.B!397)V:6-I;R!D
M92!.;W)M86QI>F%C:6]N($QI;F=U:7-T:6-A(#QS;FQU<V-`=7-C+F5S/@I,
M86YG=6%G92U496%M.B!'86QE9V\*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E33RTX.#4Y+3$*0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I8+4=E;F5R871O<CH@2T)A8F5L
M(#`N.2XU"@!/<&5R86-I\VYS(&1E(&UA;G1E;65N=&\@)7,@+2!#;VYF:7)M
M86-I\VX`,C0@:&]R87,`04TO4$T`16YG861I<B!U;B!P87(`16YD97)E>F\`
M06QC=6UE`$\@=F%L;W(@<75E(&5S<&5C:69I8V]U(&YO;B#I(';A;&ED;P!#
M86UP;W,@9&ES<&_Q:6)L97,Z`$%N:79E<G-A<FEO`$-A;&5N9&%R:6\`0V%N
M8V5L87(@;R!I;F9O<FUE(&1E('!R;V)L96UA<P!496SI9F]N;R!M\V)I;`!0
M96-H87(@82!X86YE;&$`0V]M<&'Q[6$`1F%L;&\@\R!A8G)I<B!O(&WS9'5L
M;R!D92!T87)E9F%S(&1E(&UA;G1E;65N=&\@)7,`1$0`1&EA<FEA;65N=&4`
M261E;G1I9&%D92!P<F5D971E<FUI;F%D80!$97-C<FEC:?-N(&1O('!R;V)L
M96UA`%)E>&ES='+A<F]N<V4@;W,@9&5T86QL97,@<&%R82!O(&%D;6EN:7-T
M<F%D;W(N`$]P8VGS;G,@9&4@=FES=6%L:7IA8VGS;@!.;VX@86-C961A(&1I
M<F5C=&%M96YT92!A(")M86EN=&5N86YC92YP:'`B`$-O<G)E;R!E;&5C='+S
M;FEC;P!396X@<F5S=6QT861O+@!%<G)O`$-A9&$@,34@;6EN=71O<P!#861A
M(#,P('-E9W5N9&]S`$-A9&$@-2!M:6YU=&]S`$-A9&$@:6YI8VEO(&1E('-E
M<VGS;@!#861A(&UE9&EA(&AO<F$`0V%D82!M:6YU=&\`17AE;7!L;R!D92!V
M86QO<F5S.@!&86QL;W4@\R!R96-U<&5R87(@87,@<')E9F5R96YC:6%S+@!&
M86QL;W4@\R!C;VYE8W1A<B!C;R!S97)V:61O<B!,1$%0+@!&87@`07AU9&$`
M16YD97)E>F\@<&%R=&EC=6QA<@!496SI9F]N;R!P87)T:6-U;&%R`$AO<F1E
M`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D;W,Z`$QI;F=U
M80!,:7-T87(@;W,@=&5M87,@9&4@87AU9&$`16YT<F%R`%!E8VAA<B!A('-E
M<VGS;@!-30!#;W)R96\`0V%M<&]S(&-O<G)E<W!O;F1E;G1E<P!-96YS87AE
M`$UE;G-U86QM96YT90!.;VUE`$YU;F-A`$YO=&%S`$]P8VGS;G,`3W5T<F$@
M:6YF;W)M86-I\VX`0VAA=F4@9&4@86-C97-O`%)E86QI>F%R(&]P97)A8VGS
M;G,@9&4@;6%N=&5M96YT;P!496SI9F]N;P!!8VAE9W5E('5N(')E<W5M;R!D
M;R!P<F]B;&5M82X`06-H96=U92!O('-E=2!N;VUE(&1E('5S=6%R:6\@92!C
M:&%V92!D92!A8V-E<V\`1&5S8W)I8VGS;B!D;R!P<F]B;&5M80!386-A<B!O
M('!A<@!296=R97-A<B#A<R!O<&-I\VYS`$9U;F-I\VX`1V%R9&%R(&%S(&]P
M8VGS;G,`4V5L96-C:6]N92!O(&1E;&EM:71A9&]R(&1A(&1A=&$Z`%-E;&5C
M8VEO;F4@;R!F;W)M871O(&1A(&1A=&$Z`%-E;&5C8VEO;F4@;R!F;W)M871O
M(&1A(&AO<F$Z`%-E;&5C8VEO;F4@9&]U<R!C86UP;W,@<75E(&-O:6YC:61A
M;BX`4V5L96-C:6]N92!A(&QI;F=U83H`16YV:6%R(&\@:6YF;W)M92!D92!P
M<F]B;&5M87,`3VUI=&ER(&\@;6%N=&5M96YT;P!%;G1R861A(&1E(&-A<F%C
M=&5R97,@97-P96-I86ES`$-O<G)E8W1A;65N=&4`5&%R969A<P!/(&[Z;65R
M;R!D96)E('-E<B!P;VQO(&UE;F]S('5N(#$N`$\@=F%L;W(@9&5B92!S97(@
M=6X@;OIM97)O+@!4[71U;&\`55),`$YO;B!F;VD@<&]S:6)L92!C;VYE8W1A
M<G-E(/,@<V5R=FED;W(@4U%,+@!.;VX@9F]I('!O<VEB;&4@=')A9'5C:7(@
M97-T92!D;V-U;65N=&\@9&4@5V]R9`!$97-F86-E<B!O<R!C86UB:6]S`$]P
M8VGS;G,@9&\@=7-U87)I;P!5<W5A<FEO`$%V:7-O`%-E;6%N86QM96YT90!"
M96YV:61A(&$@)7,`0F5N=FED;R]A+"`E<P!%;F1E<F5Z;R!D;R!T<F%B86QL
M;P!496SI9F]N;R!D;R!T<F%B86QL;P!!00!!;G5A;&UE;G1E`$1E<V-R:6)A
M(&\@<')O8FQE;6$@86YT97,@9&4@96YV:6%R(&\@:6YF;W)M92X`0V%D=6-O
M=2!A('/Z82!S97-I\VX@96X@)7,@97AP:7)O=2X@26YI8VEE('5N:&$@;F]V
M82!S97-I\VXN`$$@<_IA(&EN9F]R;6%C:?-N`$%C='5A;&EZX7)O;G-E(&%S
M('/Z87,@;W!C:?-N<RX`6TEN9F]R;64@9&\@4')O8FQE;6%=`%ML:?%A("5S
M(&1E("5S70!487)X971A(&1E('9I<VET82`H=D-A<F0I````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&]C86QE+V9R7T92+TQ#7TU%4U-!1T53````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R
M,30W-``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9G)?1E(O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0P
M,C,@,3`U,34T,S0Q-#$@,#(Q-#,W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I
M;F<](FES;RTX.#4Y+3$B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]F
M<E]&4B]H96QP+GAM;"QV(#$N,BXQ,"XQ(#(P,#4O,3(O,#4@,3`Z,S`Z-#4@
M:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T
M871E/2)U<'1O9&%T92(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T
M.3)C9&,Q-2(^"CQT:71L93Y,82!P86=E('!O<G1A:6P@/"]T:71L93X*(#QP
M87)A/@H@($-E='1E('!A9V4@<&]R=&%I;"!V;W5S(&9O=7)N:70@=6X@<NES
M=6WI(&1E('9O<R!I;F9O<FUA=&EO;G,@:6UP;W)T86YT97,N(%!A<B!E>&5M
M<&QE+"!C96QA('!O=7)R86ET('9O=7,@<&5R;65T=')E(&0G869F:6-H97(@
M;&4@;F]M8G)E(&1E(&YO=79E875X(&UE<W-A9V5S(&1A;G,@=F]T<F4@8F_N
M=&4@9&4@<NEC97!T:6]N+"!L97,@;F]U=F5A=7@@Z7;H;F5M96YT<R!D92!V
M;W1R92!C86QE;F1R:65R+"!L97,@=.)C:&5S(&1E('9O=')E(&QI<W1E(&1E
M('1R879A=7@@X"!F86ER92P@;&5S(&=R86YD<R!T:71R97,@9&4@;F]U=F5L
M;&5S+"!E=&,N($QA('!L=7!A<G0@9&5S('+I<W5MZ7,@8V]N=&EE;F1R;VYT
M(&1E<R!R86-C;W5R8VES('9E<G,@9&5S(&9O;F-T:6]N<R!C;&%S<VEQ=65S
M(&-O;6UE(&QA(&-O;7!O<VET:6]N(&0G=6X@;F]U=F5A=2!M97-S86=E+"!L
M82!C<NEA=&EO;B!D)W5N(&YO=79E;"#I=NAN96UE;G0@9&%N<R!L92!C86QE
M;F1R:65R(&]U(&0G=6YE(&YO=79E;&QE('3B8VAE+@H@/"]P87)A/@H@/'!A
M<F$^"B`@3&4@8V]N=&5N=2!D92!C971T92!P86=E('!O<G1A:6P@<&5U="#J
M=')E('!E<G-O;FYA;&ESZ2#@(&PG86ED92!D=2!B;W5T;VX@)U!RZ7-E;G1A
M=&EO;B<N(%!A<B!E>&5M<&QE+"!V;W5S('!O=79E>B!C:&]I<VER(&QE<R!P
M;VEN=',@<'+I<V5N=',@<W5R(&-E='1E('!A9V4@<&]R=&%I;"!E="!L)V]R
M9')E(&1A;G,@;&5Q=65L(&EL<R!S97)O;G0@<'+I<V5N=.ES+@H@/"]P87)A
M/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!S=&%T93TB=7!T;V1A
M=&4B(&UD-3TB8CAC9C!A93$Y934W9&9A,&,R8CDV,F4U,38W.#)F-#<B/@H\
M=&ET;&4^3&4@;65N=2!(;W)D93PO=&ET;&4^"B`\<&%R83X*("!3=7(@;&4@
M8_1TZ2!G875C:&4@9&4@;&$@<&%G92!S92!T<F]U=F4@;&4@;65N=2!(;W)D
M92X*("!#;&EQ=65Z('-U<B!L97,@:6/T;F5S(&1E(&-E(&UE;G4@2&]R9&4@
M<&]U<B!A8V/I9&5R(')A<&ED96UE;G0@970@<VEM<&QE;65N="!A=7@@87!P
M;&EC871I;VYS(&1I<W!O;FEB;&5S+B`*(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A
M=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@
M("`@/'1I=&QE/E!RZ6;I<F5N8V5S.B!-86EN=&5N86YC93H@169F96-T=65R
M(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP
M87)A/@H@("`@4VD@=F]U<R!V;W5L97H@969F96-T=65R(&QE<R!O<.ER871I
M;VYS(&1E(&UA:6YT96YA;F-E(.`@;&$@8V]N;F5X:6]N+"!C;V-H97H@8V5T
M=&4@8V%S92X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R
M969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@;60U
M/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\=&ET
M;&4^4'+I9NER96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M97(\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!3:2!V;W5S('9O=6QE>B!D979O:7(@8V]N9FER
M;65R(&%V86YT(&1E(&QA;F-E<B!L97,@;W#I<F%T:6]N<R!D92!M86EN=&5N
M86YC92P@8V]C:&5Z(&-E='1E(&-A<V4N(%-I('9O=7,@;F4@;&$@8V]C:&5Z
M('!A<RP@=&]U=&5S(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E('-E
M<F]N="!A=71O;6%T:7%U96UE;G0@;&%N8^EE<R#@(&QA(&-O;FYE>&EO;B!S
M86YS(&%U8W5N92!C:&%N8V4@9"=A;FYU;&%T:6]N+@H@("`@/"]P87)A/@H\
M+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O
M9G)?1E(O3$-?34534T%'15,O:&]R9&4N;6\`````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`T,C4U-C<@,3`U,34T,S0Q-#$@,#(S,C,T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````-X2!)4`````B0<``!P`
M``!D/```$PH``*QX````````^*````X```#YH```#P````BA```-````&*$`
M``@````FH0``"P```"^A```,````.Z$```0```!(H0``&````$VA```;````
M9J$``"T```""H0``'0```+"A```D````SJ$``"D```#SH0``&0```!VB```F
M````-Z(```P```!>H@``)````&NB```/````D*(```L```"@H@``#@```*RB
M```%````NZ(``"@```#!H@``"````.JB```*````\Z(``!4```#^H@``$@``
M`!2C```+````)Z,``(4````SHP``#@```+FC```*````R*,```T```#3HP``
M#@```.&C```1````\*,```T````"I```#````!"D```-````':0```8````K
MI```E````#*D```*````QZ0```\```#2I```&````.*D```,````^Z0```X`
M```(I0``#@```!>E```(````)J4```D````OI0``+@```#FE```:````:*4`
M`#(```"#I0``.````+:E``!4````[Z4``%$```!$I@``6@```):F``!7````
M\:8``#0```!)IP``"0```'ZG```-````B*<```<```"6IP``"@```)ZG```/
M````J:<```4```"YIP``!@```+^G```1````QJ<```@```#8IP``"0```.&G
M```)````ZZ<``"4```#UIP``(````!NH```3````/*@``!````!0J```#P``
M`&&H```*````<:@```,```!\J```#P```("H```4````D*@```D```"EJ```
M#0```*^H```2````O:@``!D```#0J```'@```.JH```/````":D```H````9
MJ0``#P```"2I```(````-*D``"0````]J0``%````&*I```6````=ZD```@`
M``".J0``3@```)>I```M````YJD``!D````4J@``!P```"ZJ```,````-JH`
M`"P```!#J@``#@```'"J```#````?ZH```L```"#J@``!P```(^J```'````
MEZH```4```"?J@``!0```*6J```*````JZH```,```"VJ@``%P```+JJ```*
M````TJH```\```#=J@``#@```.VJ```8````_*H``",````5JP``#@```#FK
M```4````2*L``!<```!=JP``%P```'6K```7````C:L``!,```"EJP``#P``
M`+FK```.````R:L``!\```#8JP``'0```/BK```'````%JP```8````>K```
M"````"6L```/````+JP```8````^K```"@```$6L```3````4*P```L```!D
MK```$````'"L```5````@:P``!4```"7K```!P```*VL```0````M:P```4`
M``#&K```%0```,RL```1````XJP```P```#TK```.P````&M```X````/:T`
M``D```!VK0``!P```("M```4````B*T```,```"=K0``!0```*&M```0````
MIZT```D```"XK0``$P```,*M```Y````UJT``!(````0K@``)P```".N```L
M````2ZX``"H```!XK@``)0```*.N```*````R:X```8```#4K@``"0```-NN
M```'````Y:X``"\```#MK@``-P```!VO```N````5:\``%4```"$KP``+0``
M`-JO```M````"+```#T````VL```/P```'2P```M````M+```$````#BL```
M(P```".Q```C````1[$``$````!KL0``+0```*RQ```S````VK$``"4````.
ML@``%0```#2R```9````2K(``"D```!DL@``)````(ZR```H````L[(``!$`
M``#<L@``"@```.ZR```,````^;(```H````&LP``$````!&S```6````(K,`
M`!8````YLP``!P```%"S```'````6+,``!0```!@LP``"@```'6S```(````
M@+,``"<```")LP``"````+&S```'````NK,```<```#"LP``!@```,JS```%
M````T;,```<```#7LP``!@```-^S```(````YK,``"D```#OLP``#@```!FT
M```*````*+0```0````SM```!P```#BT```)````0+0```8```!*M```$0``
M`%&T```'````8[0``!8```!KM```!````(*T```(````A[0```8```"0M```
M#0```)>T```&````I;0``!X```"LM```$0```,NT```(````W;0```T```#F
MM```#````/2T```'`````;4```,````)M0```P````VU```7````$;4``!,`
M```IM0``'0```#VU```(````6[4```0```!DM0``"````&FU```(````<K4`
M`$$```![M0``&@```+VU```K````V+4``"`````$M@``%0```"6V```&````
M.[8```8```!"M@``%0```$FV```8````7[8``"(```!XM@``+@```)NV```=
M````RK8``"$```#HM@``5`````JW```I````7[<```H```")MP``!P```)2W
M```'````G+<``!4```"DMP``#@```+JW```*````R;<```\```#4MP``#0``
M`.2W```/````\K<```T````"N```"0```!"X```4````&K@```8````ON```
M&````#:X```=````3[@``!,```!MN```$0```(&X```4````D[@```0```"H
MN```!@```*VX```4````M+@``%0```#)N```9````!ZY```$````@[D```X`
M``"(N0``!0```)>Y```%````G;D``!L```"CN0``&@```+^Y```3````VKD`
M`!$```#NN0``$0````"Z```<````$KH``"H````ON@``$````%JZ```A````
M:[H```4```"-N@``$P```).Z```+````I[H``!(```"SN@``"@```,:Z```/
M````T;H```T```#AN@``$0```.^Z```3`````;L```P````5NP``!@```"*[
M```,````*;L```8````VNP``%P```#V[```0````5;L``!$```!FNP``"```
M`'B[```%````@;L```P```"'NP``$````)2[```%````I;L```T```"KNP``
M!@```+F[```'````P+L```T```#(NP``!P```-:[```+````WKL```<```#J
MNP``!P```/*[```)````^KL```D````$O```"@````Z\```9````&;P``#T`
M```SO```'0```'&\```,````C[P``!````"<O```!0```*V\```E````L[P`
M`!(```#9O```$P```.R\```K`````+T``#L````LO0``(````&B]```(````
MB;T``#8```"2O0``(0```,F]```0````Z[T```@```#\O0``#`````6^```&
M````$KX```0````9O@``#P```!Z^```.````+KX```<````]O@``"@```$6^
M```-````4+X``!\```!>O@``'````'Z^```A````F[X``!X```"]O@``&0``
M`-R^```>````]KX``!L````5OP``(0```#&_```N````4[\``"8```""OP``
M'````*F_```>````QK\``!P```#EOP``)@````+````K````*<```#,```!5
MP```)@```(G````K````L,```#@```#<P```'0```!7!```5````,\$``"\`
M``!)P0``(````'G!```2````FL$``"D```"MP0``'@```-?!```@````]L$`
M`!(````7P@``H@```"K"```6````S<(``",```#DP@``*`````C#```I````
M,<,``"@```!;PP``'P```(3#```5````I,,``"````"ZPP``)0```-O#```H
M`````<0``"T````JQ```,````%C$``"2````B<0``"$````<Q0``%@```#[%
M```<````5<4``"8```!RQ0``*@```)G%``!!````Q,4``$0````&Q@``#```
M`$O&```'````6,8```<```!@Q@``!@```&C&```-````;\8``!````!]Q@``
M$@```([&```3````H<8``!(```"UQ@``!P```,C&```$````T,8``!````#5
MQ@``$````.;&```,````]\8```X````$QP``#0```!/'```/````(<<``!,`
M```QQP``#0```$7'```H````4\<```,```!\QP``#0```(#'```&````CL<`
M`!$```"5QP``%P```*?'```;````O\<```X```#;QP```@```.K'``!)````
M[<<```4````WR```$````#W(```/````3L@```0```!>R```#0```&/(```.
M````<<@```,```"`R```#@```(3(```(````D\@```\```"<R```#P```*S(
M```'````O,@```T```#$R```$````-+(```-````X\@```L```#QR```!@``
M`/W(```+````!,D```P````0R0``"@```!W)```1````*,D``!D````ZR0``
M"P```%3)```-````8,D``"(```!NR0``#P```)')```;````H<D``#0```"]
MR0``"@```/+)```8````_<D``!(````6R@``&0```"G*```6````0\H``"(`
M``!:R@``#0```'W*```'````B\H``!0```"3R@``"P```*C*```B````M,H`
M`"\```#7R@``"P````?+```)````$\L``!D````=RP``"P```#?+```7````
M0\L``!<```!;RP``"0```'/+```6````?<L```\```"4RP``&0```*3+```6
M````OLL```X```#5RP``&````.3+```(````_<L```T````&S```)@```!3,
M``!#````.\P```@```!_S```$@```(C,```?````F\P```@```"[S```"P``
M`,3,```O````T,P```X`````S0``!0````_-```&````%<T``$4````<S0``
M`P```&+-```'````9LT```0```!NS0``"@```'/-```*````?LT```\```")
MS0``$````)G-```7````JLT``!$```#"S0``&0```-3-```7````[LT```D`
M```&S@``!0```!#.```+````%LX```H````BS@```@```"W.```%````,,X`
M``T````VS@``&P```$3.```7````8,X``!0```!XS@``"0```(W.```.````
ME\X```T```"FS@``$@```+3.```X````Q\X``"``````SP``"````"'/```.
M````*L\``'L````YSP``&````+7/```8````SL\``!$```#GSP``!P```/G/
M```%`````=```!@````'T```'@```"#0```;````/]```!D```!;T```&P``
M`'70```9````D=```!,```"KT```!P```+_0```(````Q]````8```#0T```
M!@```-?0```0````WM````\```#OT```$````/_0```/````$-$```L````@
MT0``#P```"S1```,````/-$```\```!)T0``!P```%G1```&````8=$```X`
M``!HT0``#````'?1```H````A-$```\```"MT0``"````+W1```(````QM$`
M`!,```#/T0``'@```./1```A`````M(``"`````DT@``&0```$72```7````
M7](``"4```!WT@``%P```)W2```6````M=(```0```#,T@``&P```-'2```-
M````[=(```P```#[T@```P````C3```%````#-,```@````2TP``"@```!O3
M```,````)M,```L````STP``$````#_3```,````4-,```X```!=TP``"P``
M`&S3```$````>-,```0```!]TP``$P```(+3```4````EM,```P```"KTP``
M"0```+C3```.````PM,```L```#1TP``&P```-W3```'````^=,```<````!
MU```"@````G4```-````%-0```D````BU```!````"S4```%````,=0```,`
M```WU```&````#O4```*````5-0```0```!?U```)@```&34```.````B]0`
M`'P```":U```%0```!?5```%````+=4```<````SU0``#````#O5```(````
M2-4```H```!1U0``!@```%S5```(````8]4```(```!LU0``!@```&_5```&
M````=M4``!0```!]U0``#0```)+5```0````H-4``!L```"QU0``!````,W5
M```)````TM4``!````#<U0``"0```.W5```)````]]4```4````!U@``&@``
M``?6```(````(M8```8````KU@``&0```#+6```.````3-8```<```!;U@``
M!P```&/6```%````:]8```D```!QU@``"@```'O6```.````AM8```(```"5
MU@``!@```)C6```+````G]8```T```"KU@``"0```+G6```&````P]8``!(`
M``#*U@``"0```-W6```'````Y]8``!0```#OU@``'0````37``!"````(M<`
M`"4```!EUP``)0```(O7```&````L=<```H```"XUP``!````,/7```)````
MR-<```@```#2UP``$0```-O7```)````[=<```8```#WUP``#0```/[7```&
M````#-@```0````3V```.0```!C8```]````4M@``#H```"0V```'@```,O8
M```%````ZM@```X```#PV```!````/_8```&````!-D```<````+V0``(0``
M`!/9```-````-=D``!4```!#V0``!@```%G9```$````8-D``!$```!EV0``
M!@```'?9```*````?MD``"(```")V0``!````*S9```%````L=D``!T```"W
MV0``!````-79```,````VMD```X```#GV0``"@```/;9```(`````=H```D`
M```*V@``!0```!3:```Z````&MH``#````!5V@``-0```(;:```I````O-H`
M`$<```#FV@``.````"[;```I````9]L``#\```"1VP``+@```-';```M````
M`-P``!\````NW```#P```$[<```2````7MP```L```!QW```)@```'W<```I
M````I-P``"0```#.W```)@```//<```(````&MT```H````CW0``"0```"[=
M```'````.-T``"````!`W0``(````&'=```F````@MT```H```"IW0``&0``
M`+3=```I````SMT``!8```#XW0``$@````_>```'````(MX```H````JW@``
M#````#7>```/````0MX``!````!2W@``0````&/>``!P````I-X``&8````5
MWP``#@```'S?```)````B]\```H```"5WP``$@```*#?```3````L]\```P`
M``#'WP``!@```-3?```/````V]\``!(```#KWP``$````/[?```1````#^``
M`!P````AX```(P```#[@``!J````8N````\```#-X```!0```-W@```0````
MX^````D```#TX```!````/[@```+`````^$``"`````/X0``%````##A```,
M````1>$```P```!2X0``#P```%_A```5````;^$``"D```"%X0``*@```*_A
M```F````VN$``"<````!X@``*0```"GB```J````4^(``!D```!^X@``0@``
M`)CB```1````V^(``!(```#MX@``$P````#C```4````%.,```\````IXP``
M%@```#GC```7````4.,``!````!HXP``$0```'GC```T````B^,``!,```#`
MXP``$@```-3C```U````Y^,``!0````=Y```!P```#+D```,````.N0``"``
M``!'Y```$````&CD```4````>>0``!$```".Y```%P```*#D```<````N.0`
M`!,```#5Y```%````.GD```:````_N0``!$````9Y0``&@```"OE```>````
M1N4``!H```!EY0``$P```(#E```5````E.4``!$```"JY0``%P```+SE```4
M````U.4``!<```#IY0``%0````'F```)````%^8``!`````AY@``&0```#+F
M```$````3.8```<```!1Y@``"P```%GF```1````9>8```8```!WY@``!@``
M`'[F```&````A>8```4```",Y@``!P```)+F```'````FN8```4```"BY@``
M%@```*CF```&````O^8```8```#&Y@``!````,WF```$````TN8```<```#7
MY@``#@```-_F```,````[N8```P```#[Y@``#0````CG```*````%N<```X`
M```AYP``!0```##G```H````-N<```X```!?YP``#````&[G```/````>^<`
M``H```"+YP``"````);G```)````G^<``"L```"IYP``!````-7G```(````
MVN<``"8```#CYP``$@````KH```/````'>@```8````MZ```"@```#3H```'
M````/^@```@```!'Z```(````%#H```)````<>@``!0```![Z```#````)#H
M```-````G>@```X```"KZ```%@```+KH```1````T>@```8```#CZ````P``
M`.KH```&````[N@``!D```#UZ```!P````_I```$````%^D```L````<Z0``
M"P```"CI```'````-.D```4````\Z0``!P```$+I```6````2ND```T```!A
MZ0``#0```&_I```*````?>D``!````"(Z0``#P```)GI```1````J>D``!<`
M``"[Z0``"@```-/I```1````WND```@```#PZ0``!````/GI```/````_ND`
M`#H````.Z@``!0```$GJ```,````3^H``!X```!<Z@``#@```'OJ```0````
MBNH```L```";Z@``#````*?J```)````M.H```<```"^Z@``"@```,;J```)
M````T>H```X```#;Z@``$````.KJ```;````^^H``!@````7ZP``&@```##K
M```*````2^L```D```!6ZP``"@```&#K```,````:^L```\```!XZP``"```
M`(CK```&````D>L``!P```"8ZP``!P```+7K```%````O>L```L```##ZP``
M1P```,_K```-````%^P```D````E[```!````"_L```#````-.P``!,````X
M[```$P```$SL```3````8.P```H```!T[````@```'_L```$````@NP``"4`
M``"'[````P```*WL```%````L>P``"H```"W[```"@```.+L```%````[>P`
M``0```#S[```"@```/CL```-`````^T```8````1[0``"````!CM```(````
M(>T```0````J[0``!0```"_M``!H````->T```D```">[0``#````*CM```0
M````M>T```4```#&[0``!@```,SM```;````T^T``"\```#O[0``$````!_N
M```*````,.X```\````[[@``"@```$ON```)````5NX``!,```!@[@``&P``
M`'3N```8````D.X``!<```"I[@``'P```,'N```.````X>X```,```#P[@``
M!P```/3N```(````_.X```<````%[P``"@````WO```+````&.\```<````D
M[P``40```"SO```0````?N\```P```"/[P``#0```)SO```:````JN\``$H`
M``#%[P``&0```!#P```&````*O```!H````Q\```)0```$SP```&````<O``
M``8```!Y\```'P```(#P```&````H/````D```"G\```&````+'P```7````
MRO```"@```#B\```!@````OQ```-````$O$``"(````@\0``5P```$/Q```3
M````F_$``",```"O\0``$P```-/Q```"````Y_$```L```#J\0``"````/;Q
M```-````__$```H````-\@``!P```!CR```4````(/(```8````U\@``"```
M`#SR```.````1?(```<```!4\@``"@```%SR```+````9_(``#(```!S\@``
M!P```*;R```,````KO(```T```"[\@``%P```,GR```,````X?(```D```#N
M\@``"0```/CR```*`````O,```<````-\P``"0```!7S```'````'_,```H`
M```G\P``&P```#+S```/````3O,``!(```!>\P``"@```''S```6````?/,`
M``D```"3\P``$````)WS```'````KO,``!(```"V\P``!````,GS```'````
MSO,```4```#6\P``!0```-SS```+````XO,``!0```#N\P``$0````/T```:
M````%?0``!8````P]```%````$?T```7````7/0``!@```!T]```'````(WT
M```9````JO0```<```#$]```!0```,ST```-````TO0```P```#@]```"```
M`.WT```7````]O0```L````.]0``#````!KU```?````)_4``!H```!']0``
M$P```&+U```$````=O4```H```![]0``!````(;U```-````B_4```P```"9
M]0``!0```*;U```)````K/4```4```"V]0``!P```+SU```%````Q/4```0`
M``#*]0```@```,_U```X````TO4``"P````+]@``$@```#CV```I````2_8`
M`#(```!U]@``"@```*CV```L````L_8``"X```#@]@``,P````_W```S````
M0_<``#@```!W]P``#P```+#W```8````P/<``!````#9]P``#P```.KW```3
M````^O<``!4````.^```%````"3X```2````.?@``!0```!,^```%0```&'X
M```M````=_@``"T```"E^```,0```-/X```N````!?D``"\````T^0``+```
M`&3Y``!B````D?D``!,```#T^0``#0````CZ```(````%OH``!<````?^@``
M"````#?Z```,````0/H``"L```!-^@``(0```'GZ```:````F_H```D```"V
M^@``10```,#Z``!!````!OL```0```!(^P``$P```$W[```4````8?L```X`
M``!V^P``$P```(7[```8````F?L```8```"R^P``"0```+G[```*````P_L`
M``\```#.^P``$````-[[```'````[_L```X```#W^P``!0````;\```;````
M#/P```@````H_```!@```#'\```4````./P``!$```!-_```#@```%_\```X
M````;OP```(```"G_```!@```*K\```.````L?P```4```#`_```!P```,;\
M```.````SOP```8```#=_```*````.3\```,````#?T``!P````:_0``!```
M`#?]```I````//T``!<```!F_0``'P```'[]``!<````GOT``!0```#[_0``
M/@```!#^```?````3_X``!````!O_@``!P```(#^```.````B/X```P```"7
M_@``#````*3^```3````L?X```H```#%_@``'0```-#^```9````[OX```4`
M```(_P``$0````[_```1````(/\``"0````R_P``$@```%?_```5````:O\`
M`!(```"`_P``#@```)/_```9````HO\```@```"\_P``"0```,7_```-````
MS_\```<```#=_P``"@```.7_```'````\/\```\```#X_P``!@````@``0`+
M````#P`!`!H````;``$`"@```#8``0`'````00`!``@```!)``$`!0```%(`
M`0`?````6``!``8```!X``$`$````'\``0`(````D``!``T```"9``$`"```
M`*<``0`>````L``!`!(```#/``$`+````.(``0`:````#P$!``D````J`0$`
M"@```#0!`0`5````/P$!``4```!5`0$`%````%L!`0`$````<`$!`!````!U
M`0$`!@```(8!`0`'````C0$!`!X```"5`0$`*````+0!`0`*````W0$!`!P`
M``#H`0$`$0````4"`0`+````%P(!`!H````C`@$`%````#X"`0`$````4P(!
M``0```!8`@$`"P```%T"`0`%````:0(!``8```!O`@$`"````'8"`0`&````
M?P(!``H```"&`@$`&P```)$"`0`T````K0(!`#0```#B`@$`(````!<#`0`I
M````.`,!`"````!B`P$`00```(,#`0`:````Q0,!`"@```#@`P$`*0````D$
M`0!0````,P0!`"(```"$!`$`!@```*<$`0`(````K@0!``4```"W!`$`"```
M`+T$`0`9````Q@0!`!D```#@!`$`*@```/H$`0`C````)04!`!D```!)!0$`
M+@```&,%`0`T````D@4!``@```#'!0$`%P```-`%`0`*````Z`4!``<```#S
M!0$`(0```/L%`0`0````'08!``X````N!@$`"P```#T&`0`'````208!`!,`
M``!1!@$`"````&4&`0`+````;@8!``H```!Z!@$`%````(4&`0`/````F@8!
M`#(```"J!@$`"P```-T&`0`.````Z08!``4```#X!@$`!0```/X&`0`%````
M!`<!`!<````*!P$`#P```"('`0`$````,@<!``H````W!P$`"0```$('`0`+
M````3`<!``T```!8!P$`#````&8'`0`.````<P<!``4```""!P$`!````(@'
M`0`-````C0<!`#(```";!P$`10```,X'`0`7````%`@!``<````L"`$`'@``
M`#0(`0`4````4P@!``4```!H"`$`%````&X(`0`&````@P@!``<```"*"`$`
M#@```)((`0`J````H0@!``8```#,"`$`#````-,(`0`-````X`@!`!$```#N
M"`$`"P`````)`0`V````#`D!``H```!#"0$`(@```$X)`0`+````<0D!``\`
M``!]"0$`,@```(T)`0`E````P`D!`#````#F"0$`,0```!<*`0`M````20H!
M``X```!W"@$`!0```(8*`0`.````C`H!`!,```";"@$`$@```*\*`0`'````
MP@H!`!$```#*"@$`$P```-P*`0`'````\`H!`!0```#X"@$`&`````T+`0`'
M````)@L!``4````N"P$`#````#0+`0`,````00L!`!(```!."P$`!````&$+
M`0`'````9@L!``H```!N"P$`"P```'D+`0`,````A0L!``X```"2"P$`#@``
M`*$+`0`%````L`L!``4```"V"P$`+@```+P+`0`F````ZPL!`",````2#`$`
M`P```#8,`0`2````.@P!``8```!-#`$`'@```%0,`0`8````<PP!`"4```",
M#`$`#0```+(,`0`)````P`P!`!\```#*#`$``P```.H,`0`'````[@P!``H`
M``#V#`$``@````$-`0`,````!`T!`!4````1#0$`"P```"<-`0`9````,PT!
M`"````!-#0$`$@```&X-`0`%````@0T!``H```"'#0$`%0```)(-`0`2````
MJ`T!``P```"[#0$`!````,@-`0`)````S0T!``<```#7#0$`#````-\-`0!2
M````[`T!`!<````_#@$`)````%<.`0`2````?`X!``<```"/#@$`!@```)<.
M`0`.````G@X!``P```"M#@$`#0```+H.`0`5````R`X!`!(```#>#@$`#P``
M`/$.`0`4`````0\!``H````6#P$`&P```"$/`0`0````/0\!``L```!.#P$`
M:0```%H/`0`:````Q`\!`!<```#?#P$`)P```/</`0`:````'Q`!`!<````Z
M$`$`&P```%(0`0`9````;A`!`!\```"($`$`$P```*@0`0`(````O!`!``<`
M``#%$`$`"````,T0`0`)````UA`!`!4```#@$`$`#0```/80`0`C````!!$!
M``T````H$0$`$P```#81`0`(````2A$!``,```!3$0$`1@```%<1`0`_````
MGA$!`#<```#>$0$`5P```!82`0`%````;A(!`!\```!T$@$`+P```)02`0`*
M````Q!(!``@```#/$@$`#0```-@2`0`M````YA(!``0````4$P$`3P```!D3
M`0`E````:1,!`!P```"/$P$`"P```*P3`0`?````N!,!`!T```#8$P$`)0``
M`/83`0`@````'!0!`"0````]%`$`(````&(4`0`+````@Q0!``<```"/%`$`
M#0```)<4`0`,````I10!`!<```"R%`$`!@```,H4`0`Y````T10!``P````+
M%0$`!P```!@5`0`)````(!4!`!,````J%0$`"0```#X5`0`$````2!4!`!``
M``!-%0$`"````%X5`0`(````9Q4!``0```!P%0$`"P```'45`0`,````@14!
M`!(```".%0$`$0```*$5`0`,````LQ4!`!H```#`%0$`#P```-L5`0`'````
MZQ4!``T```#S%0$`%`````$6`0`.````%A8!``P````E%@$`&P```#(6`0`L
M````3A8!`!,```![%@$`'````(\6`0`H````K!8!``8```#5%@$`!P```-P6
M`0`3````Y!8!``4```#X%@$`!````/X6`0`7`````Q<!``H````;%P$`#```
M`"87`0`)````,Q<!``8````]%P$`"0```$07`0`(````3A<!``D```!7%P$`
M"@```&$7`0`1````;!<!``8```!^%P$`#@```(47`0`.````E!<!``T```"C
M%P$`"P```+$7`0`=````O1<!``L```#;%P$``@```.<7`0`<````ZA<!``<`
M```'&`$`!@````\8`0!D````%A@!``D```![&`$`!P```(48`0`F````C1@!
M`#@```"T&`$`&@```.T8`0`J````"!D!`#L````S&0$`*````&\9`0`T````
MF!D!`!D```#-&0$`%0```.<9`0`%````_1D!``<````#&@$`"`````L:`0`'
M````%!H!``4````<&@$`!P```"(:`0`.````*AH!``D````Y&@$`!@```$,:
M`0`(````2AH!``L```!3&@$`!P```%\:`0`(````9QH!``<```!P&@$`%@``
M`'@:`0`)````CQH!``8```"9&@$`"P```*`:`0`0````K!H!``8```"]&@$`
M'````,0:`0`4````X1H!``<```#V&@$`$0```/X:`0`(````$!L!``X````9
M&P$`"````"@;`0`0````,1L!``D```!"&P$`$````$P;`0`&````71L!`!D`
M``!D&P$`"@```'X;`0`<````B1L!``<```"F&P$`!0```*X;`0`0````M!L!
M`!0```#%&P$`"P```-H;`0`-````YAL!`"@```#T&P$`&````!T<`0`7````
M-AP!``0```!.'`$`"0```%,<`0`*````71P!``<```!H'`$``@```'`<`0`.
M````<QP!``@```""'`$`(P```(L<`0`?````KQP!`#@```#/'`$`)@````@=
M`0`Q````+QT!`"<```!A'0$`9````(D=`0`4````[AT!`%4````#'@$`.```
M`%D>`0!*````DAX!`%L```#='@$`*````#D?`0`X````8A\!`"@```";'P$`
M+````,0?`0`F````\1\!`!L````8(`$`/@```#0@`0"I`0``<R`!`",````=
M(@$`%P```$$B`0!(````62(!`(4```"B(@$`,````"@C`0`E````62,!`$$`
M``!_(P$`6P```,$C`0!)````'20!`#$```!G)`$`'0```)DD`0`8````MR0!
M`"L```#0)`$`(0```/PD`0`?````'B4!`"L````^)0$`)@```&HE`0`G````
MD24!`#H```"Y)0$`'0```/0E`0`1````$B8!`#,````D)@$`)0```%@F`0`G
M````?B8!`"````"F)@$`'P```,<F`0`P````YR8!`&D````8)P$`,0```((G
M`0!!````M"<!`#,```#V)P$`)0```"HH`0`]````4"@!`&4```".*`$`30``
M`/0H`0`O````0BD!`"X```!R*0$`,````*$I`0!4````TBD!`%H````G*@$`
M2````((J`0!*````RRH!`#(````6*P$`+P```$DK`0`L````>2L!`"T```"F
M*P$`<0```-0K`0!F````1BP!`&\```"M+`$`LP```!TM`0`7````T2T!`"4`
M``#I+0$`,@````\N`0`I````0BX!`#X```!L+@$`(@```*LN`0!2````SBX!
M`"4````A+P$`"P```$<O`0"Q````4R\!`$4````%,`$`(0```$LP`0`P````
M;3`!`"4```">,`$`'````,0P`0`Q````X3`!``<````3,0$`!P```!LQ`0`$
M````(S$!``T````H,0$`"P```#8Q`0`.````0C$!``L```!1,0$`!0```%TQ
M`0`0````8S$!``(```!T,0$`60```'<Q`0`%````T3$!`!(```#7,0$`!```
M`.HQ`0`'````[S$!``@```#W,0$`!0`````R`0`P````!C(!``,````W,@$`
M$````#LR`0`,````3#(!`!,```!9,@$`#0```&TR`0`"````>S(!``<```!^
M,@$`!@```(8R`0`4````C3(!``P```"B,@$`&````*\R`0`&````R#(!`!(`
M``#/,@$`#````.(R`0`#````[S(!`"H```#S,@$`!````!XS`0`&````(S,!
M``<````J,P$`'P```#(S`0`U````4C,!`"X```"(,P$`+P```+<S`0`7````
MYS,!`"(```#_,P$`)0```"(T`0`@````2#0!`!L```!I-`$`&````(4T`0`D
M````GC0!`!\```##-`$`&@```.,T`0`A````_C0!`"`````@-0$`&@```$$U
M`0`R````7#4!`!H```"/-0$`+P```*HU`0`K````VC4!`!\````&-@$`(P``
M`"8V`0`?````2C8!`!H```!J-@$`(0```(4V`0`E````IS8!`"8```#--@$`
M)0```/0V`0`D````&C<!`!@````_-P$`'0```%@W`0`D````=C<!`!@```";
M-P$`(@```+0W`0`L````US<!`"\````$.`$`%0```#0X`0`E````2C@!`#P`
M``!P.`$`'P```*TX`0`C````S3@!`!\```#Q.`$`(````!$Y`0`:````,CD!
M`!@```!-.0$`)@```&8Y`0`>````C3D!`"D```"L.0$`'@```-8Y`0`Q````
M]3D!``D````G.@$`#````#$Z`0`7````/CH!`"\```!6.@$`)````(8Z`0`'
M````JSH!``\```"S.@$`%````,,Z`0`.````V#H!``T```#G.@$`)````/4Z
M`0`%````&CL!``<````@.P$`(@```"@[`0`E````2SL!`!H```!Q.P$`'0``
M`(P[`0`:````JCL!``<```#%.P$`QP```,T[`0`+````E3P!`!4```"A/`$`
M!@```+<\`0`)````OCP!``L```#(/`$`#0```-0\`0`7````XCP!``8```#Z
M/`$`,P````$]`0`3````-3T!`!,```!)/0$`!P```%T]`0`/````93T!``<`
M``!U/0$`,@```'T]`0`$````L#T!`"$```"U/0$`$P```-<]`0`,````ZST!
M`!$```#X/0$`,@````H^`0`6````/3X!``@```!4/@$`'0```%T^`0`)````
M>SX!``H```"%/@$`%````)`^`0`*````I3X!`!T```"P/@$`"````,X^`0`?
M````USX!``@```#W/@$`&@`````_`0`G````&S\!``8```!#/P$`%0```$H_
M`0`'````8#\!``@```!H/P$`"0```'$_`0`_````>S\!``<```"[/P$`#P``
M`,,_`0`.````TS\!`!````#B/P$`"0```/,_`0`)````_3\!``@````'0`$`
M$P```!!``0`'````)$`!`!D````L0`$`"@```$9``0`7````44`!`!0```!I
M0`$`"@```'Y``0`,````B4`!`!<```"60`$`!````*Y``0`J````LT`!``P`
M``#>0`$`$0```.M``0`'````_4`!``(````%00$`$`````A!`0`8````&4$!
M``L````R00$``P```#Y!`0`(````0D$!``8```!+00$`!P```%)!`0`-````
M6D$!``L```!H00$`%````'1!`0`5````B4$!``X```"?00$`+P```*Y!`0`@
M````WD$!`!P```#_00$`%0```!Q"`0`,````,D(!`#$````_0@$`!0```'%"
M`0`2````=T(!`#\```"*0@$`$@```,I"`0`*````W4(!``8```#H0@$`!```
M`.]"`0`$````]$(!``H```#Y0@$`$P````1#`0`%````&$,!``8````>0P$`
M!@```"5#`0`(````+$,!``0````U0P$`#````#I#`0`*````1T,!`#D```!2
M0P$`+@```(Q#`0`I````NT,!``4```#E0P$`&````.M#`0`9````!$0!`!\`
M```>1`$`'0```#Y$`0`1````7$0!``(```!N1`$`!````'%$`0`*````=D0!
M``8```"!1`$`!0```(A$`0`#````CD0!``P```"21`$`10```)]$`0`R````
MY40!`!H````810$`-````#-%`0`H````:$4!`%,```"110$`&0```.5%`0!R
M````_T4!`"````!R1@$`-0```)-&`0`A````R48!`$4```#K1@$`,````#%'
M`0`H````8D<!`"D```"+1P$`)@```+5'`0`E````W$<!`"@````"2`$`*```
M`"M(`0`B````5$@!`"L```!W2`$`,````*-(`0`2````U$@!`!,```#G2`$`
M$````/M(`0!Y````#$D!``D```"&20$`H0```)!)`0!S````,DH!`'P```"F
M2@$`*P```"-+`0!4````3TL!`!<```"D2P$`)P```+Q+`0`6````Y$L!``\`
M``#[2P$`%P````M,`0`?````(TP!`$````!#3`$`'P```(1,`0`<````I$P!
M`%$```#!3`$`&@```!--`0`4````+DT!``H```!#30$`!0```$Y-`0`&````
M5$T!``@```!;30$`!0```&1-`0`2````:DT!`!````!]30$`$P```(Y-`0`=
M````HDT!``\```#`30$`#P```-!-`0`$````X$T!``D```#E30$`"P```.]-
M`0`'````^TT!``4````#3@$`%`````E.`0`'````'DX!``@````F3@$`#P``
M`"].`0`(````/TX!``P```!(3@$`#P```%5.`0`&````94X!`!0```!L3@$`
M!@```(%.`0`,````B$X!`!$```"53@$`"````*=.`0`$````L$X!`!D```"U
M3@$`$0```,].`0`*````X4X!`!@```#L3@$`$P````5/`0`<````&4\!`!$`
M```V3P$`!````$A/`0`/````34\!``<```!=3P$`!````&5/`0`9````:D\!
M``<```"$3P$``@```(Q/`0`"````CT\!`!$```"23P$`"0```*1/`0`&````
MKD\!`!(```"U3P$`%P```,A/`0`&````X$\!`"<```#G3P$``@````]0`0`$
M````$E`!``\````74`$`$P```"=0`0`'````.U`!``<```!#4`$`$0```$M0
M`0`&````75`!`!@```!D4`$`!@```'U0`0`3````A%`!`!````"84`$`$@``
M`*E0`0`"````O%`!``8```"_4`$`#````,90`0`)````TU`!`!$```#=4`$`
M(@```.]0`0`'````$E$!``<````:40$`"P```")1`0`%````+E$!``(````T
M40$`"P```#=1`0!_`0``0U$!`!(```##4@$`&P```-92`0`0````\E(!``X`
M```#4P$`"0```!)3`0`'````'%,!``,````D4P$`&P```"A3`0`A````1%,!
M`#4```!F4P$`,0```)Q3`0`K````SE,!`"\```#Z4P$`'0```"I4`0`M````
M2%0!``L```!V5`$`,@```()4`0`4````M50!``L```#*5`$`$P```-94`0`%
M````ZE0!`#$```#P5`$`$````")5`0`1````,U4!`!X```!%50$`#P```&15
M`0`+````=%4!`)8```"`50$`$@```!=6`0`*````*E8!``T````U5@$`#0``
M`$-6`0`7````458!``P```!I5@$`$````'96`0`5````AU8!``<```"=5@$`
MG0```*56`0`,````0U<!``P```!05P$`%````%U7`0`2````<E<!`!````"%
M5P$`$````)97`0`)````IU<!``H```"Q5P$`1````+Q7`0`@`````5@!`#X`
M```B6`$`30```&%8`0!N````KU@!`&H````>60$`=````(E9`0!P````_ED!
M`$$```!O6@$`#P```+%:`0`5````P5H!``X```#76@$`$````.9:`0`8````
M]UH!``4````06P$`!@```!9;`0`7````'5L!``L````U6P$`"@```$%;`0`-
M````3%L!`#0```!:6P$`,````(];`0`4````P%L!`!8```#56P$`#@```.Q;
M`0`'````^UL!``<````#7`$`%@````M<`0`D````(EP!``T```!'7`$`&0``
M`%5<`0`?````;UP!`!\```"/7`$`)0```*]<`0`?````U5P!`!,```#U7`$`
M&P````E=`0`1````)5T!`"@````W70$`'@```&!=`0`?````?UT!`!8```"?
M70$`80```+9=`0`P````&%X!`#(```!)7@$`!P```'Q>`0`1````A%X!`$,`
M``"67@$`#@```-I>`0`$````Z5X!``L```#N7@$`!P```/I>`0`'`````E\!
M``4````*7P$`!P```!!?`0`,````&%\!``0````E7P$`(@```"I?`0`0````
M35\!`!8```!>7P$`$````'5?`0`L````AE\!`#$```"S7P$`"P```.5?`0`A
M````\5\!`!P````38`$`(0```#!@`0`?````4F`!``X```!R8`$`$@```(%@
M`0`/````E&`!`"0```"D8`$`(P```,E@`0`'````[6`!``8```#U8`$`"```
M`/Q@`0`-````!6$!``<````380$`"P```!MA`0`2````)V$!``L````Z80$`
M%````$9A`0`7````6V$!`!L```!S80$`"````(]A`0`4````F&$!``4```"M
M80$`%````+-A`0`9````R&$!`!````#B80$`30```/-A`0!!````06(!``D`
M``"#8@$`!P```(UB`0`4````E6(!``,```"J8@$`!0```*YB`0`/````M&(!
M``D```#$8@$`%0```,YB`0!)````Y&(!`!,````N8P$`+@```$)C`0`U````
M<6,!`#<```"G8P$`,@```-]C`0`*````$F0!``0````=9`$`"0```")D`0`(
M````+&0!`#`````U9`$`-P```&9D`0`O````GF0!`%X```#.9`$`+P```"UE
M`0`O````764!`$L```"-90$`3@```-EE`0`O````*&8!`%0```!89@$`-```
M`*UF`0`W````XF8!`%<````:9P$`+P```')G`0`U````HF<!`"P```#89P$`
M&P````5H`0`>````(6@!`"X```!`:`$`*P```&]H`0`K````FV@!`!0```#'
M:`$`"P```-QH`0`,````Z&@!``\```#U:`$`#P````5I`0`=````%6D!`"$`
M```S:0$`!P```%5I`0`'````76D!`!,```!E:0$`"@```'EI`0`'````A&D!
M`"P```",:0$`#0```+EI`0`'````QVD!``@```#/:0$`!@```-AI`0`%````
MWVD!``@```#E:0$`!P```.YI`0`,````]FD!`"H````#:@$`$P```"YJ`0`,
M````0FH!``0```!/:@$`!P```%1J`0`'````7&H!``<```!D:@$`&0```&QJ
M`0`%````AFH!`!(```",:@$`"````)]J`0`(````J&H!``,```"Q:@$`!@``
M`+5J`0`&````O&H!`"H```##:@$`$@```.YJ`0`(`````6L!``T````*:P$`
M#````!AK`0`'````)6L!`!(````M:P$``P```$!K`0!!````1&L!`!D```"&
M:P$`,````*!K`0`&````T6L!``4```#8:P$`"````-YK`0`(````YVL!`&0`
M``#P:P$`*@```%5L`0`_````@&P!`"H```#`;`$`)@```.ML`0`&````$FT!
M``<````9;0$`'@```"%M`0`J````0&T!`"X```!K;0$`-P```)IM`0`M````
MTFT!`#<`````;@$`;P```#AN`0`S````J&X!``@```#<;@$`!P```.5N`0`,
M````[6X!`!@```#Z;@$`"P```!-O`0`4````'V\!`!@````T;P$`(@```$UO
M`0`8````<&\!`!H```");P$`%0```*1O`0`3````NF\!``<```#.;P$`&0``
M`-9O`0`=````\&\!`!4````.<`$`&@```"1P`0`:````/W`!``4```!:<`$`
M"````&!P`0`;````:7`!`'(```"%<`$`>0```/AP`0`$````<G$!`!$```!W
M<0$`!0```(EQ`0`%````CW$!`!H```"5<0$`&P```+!Q`0`7````S'$!`!<`
M``#D<0$`&P```/QQ`0`G````&'(!`#8```!`<@$`#@```'=R`0`J````AG(!
M``<```"Q<@$`'@```+ER`0`2````V'(!`!D```#K<@$`%0````5S`0`D````
M&W,!`!\```!`<P$`%P```&!S`0`3````>',!`!$```",<P$`!@```)YS`0`/
M````I7,!``<```"U<P$`"@```+US`0`8````R',!`!$```#A<P$`"````/-S
M`0`'````_',!`!,````$=`$`%P```!AT`0`&````,'0!`!$````W=`$`!```
M`$ET`0`(````3G0!``X```!7=`$`"P```&9T`0`)````<G0!``<```!\=`$`
M!P```(1T`0`+````C'0!``D```"8=`$`"@```*)T`0`<````K70!`$D```#*
M=`$`(@```!1U`0`-````-W4!`!D```!%=0$`!0```%]U`0`@````974!`!4`
M``"&=0$`&````)QU`0`M````M74!`#\```#C=0$`)````"-V`0`(````2'8!
M`#P```!1=@$`)P```(YV`0`1````MG8!``H```#(=@$`"0```--V`0`/````
MW78!``8```#M=@$`%@```/1V`0`5````"W<!``@````A=P$`"@```"IW`0`-
M````-7<!`"0```!#=P$`)@```&AW`0`N````CW<!`"<```"^=P$`(````.9W
M`0`E````!W@!`"H````M>`$`)@```%AX`0`T````?W@!`#````"T>`$`*P``
M`.5X`0`L````$7D!`",````^>0$`,0```&)Y`0`V````E'D!`#8```#+>0$`
M*P````)Z`0`Q````+GH!`$$```!@>@$`*@```*)Z`0`I````S7H!`$,```#W
M>@$`*P```#M[`0`;````9WL!`#$```"#>P$`)P```+5[`0`G````W7L!`!H`
M```%?`$`LP```"!\`0`?````U'P!`"H```#T?`$`+@```!]]`0`P````3GT!
M`"T```!_?0$`,@```*U]`0`I````X'T!`"L````*?@$`.P```#9^`0`[````
M<GX!`$````"N?@$`0@```.]^`0"R````,G\!`"<```#E?P$`(0````V``0`E
M````+X`!`#(```!5@`$`.0```(B``0!&````PH`!`$\````)@0$`#````%F!
M`0`$````9H$!``4```!K@0$`!0```'&!`0`-````=X$!`!````"%@0$`%0``
M`):!`0`7````K($!`!D```#$@0$`!P```-Z!`0`$````YH$!`!(```#K@0$`
M$0```/Z!`0`.````$((!`!H````?@@$`%````#J"`0`6````3X(!`!4```!F
M@@$`#0```'R"`0`Y````BH(!``8```#$@@$`$P```,N"`0`&````WX(!`!,`
M``#F@@$`&0```/J"`0`=````%(,!`!(````R@P$``@```$6#`0!)````2(,!
M``L```"2@P$`%@```)Z#`0`0````M8,!``0```#&@P$`$0```,N#`0`4````
MW8,!``0```#R@P$`%0```/>#`0`(````#80!`!`````6A`$`%@```">$`0`&
M````/H0!`!(```!%A`$`$P```%B$`0`C````;(0!``L```"0A`$`!P```)R$
M`0`2````I(0!`!,```"WA`$`$````,N$`0`8````W(0!`"````#UA`$`$@``
M`!:%`0`2````*84!`"(````\A0$`%@```%^%`0`E````=H4!`$4```"<A0$`
M$0```.*%`0`A````](4!`!D````6A@$`&P```#"&`0`:````3(8!`#<```!G
MA@$`$@```)^&`0`(````LH8!`!,```"[A@$`"P```,^&`0`T````VX8!`#0`
M```0AP$`#0```$6'`0`.````4X<!`"@```!BAP$`$0```(N'`0`2````G8<!
M`!(```"PAP$`"@```,.'`0`8````SH<!`!,```#GAP$`'P```/N'`0`;````
M&X@!`!(````WB`$`$0```$J(`0`(````7(@!`!````!EB`$`+````':(`0!B
M````HX@!``D````&B0$`%@```!")`0`M````)XD!``L```!5B0$`#@```&&)
M`0`X````<(D!`!````"IB0$`!P```+J)`0`5````PHD!`$D```#8B0$``P``
M`"**`0`(````)HH!``@````OB@$`#@```#B*`0`0````1XH!`!4```!8B@$`
M%@```&Z*`0`B````A8H!`!D```"HB@$`(@```,**`0`>````Y8H!``D````$
MBP$`!@````Z+`0`(````%8L!``H````>BP$``@```"F+`0`4````+(L!`!0`
M``!!BP$`,````%:+`0`:````AXL!`!D```"BBP$`"@```+R+`0`-````QXL!
M``X```#5BP$`&````.2+`0!%````_8L!`"\```!#C`$`#@```'.,`0`2````
M@HP!`*````"5C`$`)@```#:-`0`?````78T!`!(```!]C0$`"````)"-`0`&
M````F8T!`"<```"@C0$`0````,B-`0!`````"8X!`"X```!*C@$`,@```'F.
M`0`7````K(X!`"H```#$C@$`!P```.^.`0`(````]XX!``@`````CP$`!@``
M``F/`0`9````$(\!`!0````JCP$`%@```#^/`0`4````5H\!`!(```!KCP$`
M&@```'Z/`0`2````F8\!`!0```"LCP$`"````,&/`0`*````RH\!`!@```#5
MCP$`#@```.Z/`0`S````_8\!`!$````QD`$`#````$.0`0`4````4)`!`#H`
M``!ED`$`(P```*"0`0`F````Q)`!`"4```#KD`$`(````!&1`0`?````,I$!
M`"\```!2D0$`(0```(*1`0`B````I)$!``0```#'D0$`&0```,R1`0`*````
MYI$!``\```#QD0$``P````&2`0`*````!9(!``<````0D@$`%0```!B2`0`8
M````+I(!`!````!'D@$`&````%B2`0`2````<9(!``X```"$D@$`&@```).2
M`0`%````KI(!``<```"TD@$`%P```+R2`0`7````U)(!`!@```#LD@$`#@``
M``63`0`0````%),!`!D````EDP$`+0```#^3`0`'````;9,!``@```!UDP$`
M#@```'Z3`0`0````C9,!``X```">DP$`"0```*V3`0`(````MY,!``H```#`
MDP$`%@```,N3`0`1````XI,!``H```#TDP$`,0```/^3`0`/````,90!`(0`
M``!!E`$`)0```,:4`0`+````[)0!``@```#XE`$`$`````&5`0`)````$I4!
M``L````<E0$`!@```"B5`0`+````+Y4!``(````[E0$`!@```#Z5`0`&````
M194!`!4```!,E0$`$````&*5`0`3````<Y4!`"L```"'E0$``@```+.5`0`#
M````MI4!`!0```"ZE0$`"P```,^5`0`+````VY4!``4```#GE0$`&@```.V5
M`0`'````")8!``8````0E@$`'@```!>6`0`+````-I8!``<```!"E@$`"0``
M`$J6`0`%````5)8!``D```!:E@$`!@```&26`0`0````:Y8!``4```!\E@$`
M!@```(*6`0`-````B98!`!````"7E@$`#@```*B6`0`%````MY8!`!$```"]
ME@$`"0```,^6`0`'````V98!`!H```#AE@$`+````/R6`0!0````*9<!`#``
M``!ZEP$`,0```*N7`0`'````W9<!``H```#EEP$`!````/"7`0`)````]9<!
M``D```#_EP$`%P````F8`0`*````(9@!``8````LF`$`#0```#.8`0`&````
M09@!``0```!(F`$`1@```$V8`0!$````E)@!`$,```#9F`$`(@```!V9`0`%
M````0)D!`!4```!&F0$`"P```%R9`0`'````:)D!``@```!PF0$`%@```'F9
M`0`/````D)D!`!4```"@F0$`!P```+:9`0`$````OID!`!,```##F0$`!```
M`->9`0`*````W)D!`!L```#GF0$`!0````.:`0`(````"9H!``\````2F@$`
M!P```"*:`0`3````*IH!`!0````^F@$`$P```%.:`0`(````9YH!``D```!P
MF@$`!0```'J:`0!$````@)H!`#4```#%F@$`/@```/N:`0`L````.IL!`$L`
M``!GFP$`10```+.;`0`Q````^9L!`%(````KG`$`-P```'Z<`0`Z````MIP!
M`"0```#QG`$`$0```!:=`0`6````*)T!``P````_G0$`,P```$R=`0`K````
M@)T!`"<```"LG0$`*@```-2=`0`(````_YT!``L````(G@$`"@```!2>`0`'
M````'YX!`"\````GG@$`,@```%>>`0`Y````BIX!``H```#$G@$`&@```,^>
M`0`D````ZIX!`!@````/GP$`%0```"B?`0`'````/I\!`!````!&GP$`#@``
M`%>?`0`1````9I\!``\```!XGP$`30```(B?`0"+````UI\!`'<```!BH`$`
M$P```-J@`0`6````[J`!`!@````%H0$`$````!ZA`0`2````+Z$!`!<```!"
MH0$`!@```%JA`0`5````8:$!`!(```!WH0$`$0```(JA`0`5````G*$!`!@`
M``"RH0$`-0```,NA`0!X`````:(!`!<```!ZH@$`!````)*B`0`8````EZ(!
M``D```"PH@$`!````+JB`0`,````OZ(!`"0```#,H@$`%@```/&B`0`-````
M"*,!`!(````6HP$`$P```"FC`0`6````/:,!`#8```!4HP$`-@```(NC`0`T
M````PJ,!`#0```#WHP$`,````"RD`0`P````7:0!`!<```".I`$`5````*:D
M`0`5````^Z0!`!4````1I0$`%0```">E`0`5````/:4!`!0```!3I0$`&```
M`&BE`0`8````@:4!`!0```":I0$`%````*^E`0`P````Q*4!`!H```#UI0$`
M'````!"F`0`[````+:8!`!,```!II@$`!@```'VF`0`.````A*8!`!\```"3
MI@$`%````+.F`0`5````R*8!`!,```#>I@$`&P```/*F`0`@````#J<!`!L`
M```OIP$`&0```$NG`0`=````9:<!`!0```"#IP$`'@```)BG`0`B````MZ<!
M`!0```#:IP$`&P```.^G`0`9````"Z@!`!,````EJ`$`'@```#FH`0`9````
M6*@!`!@```!RJ`$`&````(NH`0`*````I*@!`!4```"OJ`$`!````,6H`0`$
M````RJ@!``<```#/J`$`"@```->H`0`0````XJ@!``8```#SJ`$`"````/JH
M`0`(`````ZD!``8````,J0$`"````!.I`0`'````'*D!``4````DJ0$`%@``
M`"JI`0`&````0:D!``@```!(J0$`!P```%&I`0`$````6:D!``D```!>J0$`
M!P```&BI`0`)````<*D!`!````!ZJ0$`$````(NI`0`*````G*D!`!,```"G
MJ0$`!0```+NI`0`P````P:D!`!(```#RJ0$`$`````6J`0`4````%JH!`!,`
M```KJ@$`#````#^J`0`6````3*H!`#8```!CJ@$`!P```)JJ`0`(````HJH!
M``T```"KJ@$`#````+FJ`0`/````QJH!``8```#6J@$`#````-VJ`0`-````
MZJH!``8```#XJ@$`!````/^J`0`.````!*L!`"4````3JP$`$````#FK`0`6
M````2JL!`!<```!AJP$`)@```'FK`0`;````H*L!``@```"\JP$``P```,6K
M`0`,````R:L!`"D```#6JP$`!0````"L`0`&````!JP!``T````-K`$`$0``
M`!NL`0`'````+:P!``8````UK`$`!P```#RL`0`%````1*P!``T```!*K`$`
M#0```%BL`0`,````9JP!`"````!SK`$`$0```)2L`0`/````IJP!`!H```"V
MK`$`$P```-&L`0`6````Y:P!``4```#\K`$`!`````*M`0`5````!ZT!`$P`
M```=K0$`!0```&JM`0`-````<*T!`"@```!^K0$`&@```*>M`0`/````PJT!
M`!,```#2K0$`%````.:M`0`0````^ZT!``\````,K@$`&````!RN`0`0````
M-:X!`!4```!&K@$`&0```%RN`0`C````=JX!`"<```":K@$`-P```,*N`0`+
M````^JX!``@````&KP$`#0````^O`0`/````':\!``\````MKP$`!````#VO
M`0`)````0J\!`"\```!,KP$`"P```'RO`0`)````B*\!`!,```"2KP$`:P``
M`*:O`0`3````$K`!``H````FL`$`!0```#&P`0`&````-[`!`!H````^L`$`
M&0```%FP`0`9````<[`!``H```"-L`$``@```)BP`0`6````F[`!`#,```"R
ML`$``P```.:P`0`%````ZK`!`!<```#PL`$`"@````BQ`0`%````$[$!``@`
M```9L0$`&@```"*Q`0`.````/;$!``8```!,L0$`"````%.Q`0`(````7+$!
M``0```!EL0$`!0```&JQ`0!*````<+$!``\```"[L0$`$@```,NQ`0`=````
MWK$!``0```#\L0$`!0````&R`0`E````![(!`#D````ML@$`#0```&>R`0`*
M````=;(!`!$```"`L@$`"@```)*R`0`+````G;(!`!8```"IL@$`&P```,"R
M`0`O````W+(!`"X````,LP$`(@```#NS`0`0````7K,!``,```!OLP$`!P``
M`'.S`0`*````>[,!``<```"&LP$`#@```(ZS`0`6````G;,!``<```"TLP$`
M6@```+RS`0`/````%[0!``\````GM`$`"P```#>T`0`G````0[0!`%T```!K
MM`$`&P```,FT`0`'````Y;0!`",```#MM`$`*0```!&U`0`(````.[4!``<`
M``!$M0$`&P```$RU`0`&````:+4!``D```!OM0$`+@```'FU`0`M````J+4!
M`#<```#6M0$`!@````ZV`0`&````%;8!`"P````<M@$`9@```$FV`0`7````
ML+8!`"0```#(M@$`%P```.VV`0`"````!;<!`!$````(MP$`!@```!JW`0`4
M````(;<!``X````VMP$`!@```$6W`0`(````3+<!``8```!5MP$`"````%RW
M`0`-````9;<!``T```!SMP$`"@```(&W`0`1````C+<!`#L```">MP$`!0``
M`-JW`0`7````X+<!`!0```#XMP$`(0````VX`0`7````+[@!``L```!'N`$`
M$0```%.X`0`1````9;@!``P```!WN`$`"P```(2X`0`,````D+@!``H```"=
MN`$`(````*BX`0`5````R;@!`!(```#?N`$`%0```/*X`0`8````"+D!``L`
M```AN0$`&P```"VY`0`(````2;D!`!4```!2N0$``P```&BY`0`'````;+D!
M``4```!TN0$`!0```'JY`0`(````@+D!`!8```")N0$`%P```*"Y`0`D````
MN+D!`",```#=N0$`'@````&Z`0`:````(+H!`!L````[N@$`(@```%>Z`0`;
M````>KH!``8```"6N@$`!@```)VZ`0`2````I+H!`!(```"WN@$`#0```,JZ
M`0`E````V+H!`!````#^N@$`%`````^[`0`G````)+L!`"4```!,NP$`&0``
M`'*[`0`)````C+L!``8```"6NP$`!P```)V[`0`2````I;L!`!$```"XNP$`
M"````,J[`0`)````T[L!``4```#=NP$`!P```..[`0`$````Z[L!``0```#P
MNP$``P```/6[`0!(````^;L!`#8```!"O`$`)0```'F\`0`J````G[P!`$$`
M``#*O`$`#`````R]`0!`````&;T!`#8```!:O0$`.0```)&]`0`Y````R[T!
M`#X````%O@$`&````$2^`0`;````7;X!`!0```!YO@$`$P```(Z^`0`<````
MHKX!`"````"_O@$`%````."^`0`3````];X!`!8````)OP$`&@```""_`0`[
M````.[\!`#L```!WOP$`/P```+._`0`T````\[\!`#L````HP`$`.````&3`
M`0![````G<`!`!X````9P0$`&````#C!`0`-````4<$!`!H```!?P0$`#```
M`'K!`0`2````A\$!`#@```":P0$`,P```-/!`0`J````!\(!``T````RP@$`
M4P```$#"`0!,````E,(!``4```#AP@$`'@```.?"`0`6````!L,!``L````=
MPP$`#P```"G#`0`6````.<,!``<```!0PP$`"0```%C#`0`)````8L,!``X`
M``!LPP$`#P```'O#`0`'````B\,!`!,```"3PP$`!0```*?#`0`F````K<,!
M``@```#4PP$`!@```-W#`0`4````Y,,!`!(```#YPP$`$0````S$`0!$````
M'L0!``(```!CQ`$`!0```&;$`0`0````;,0!``4```!]Q`$`!P```(/$`0`5
M````B\0!``8```"AQ`$`/0```*C$`0`3````YL0!`",```#ZQ`$`!````![%
M`0`X````(\4!`"8```!<Q0$`)@```(/%`0!=````JL4!`"`````(Q@$`30``
M`"G&`0`J````=\8!`!8```"BQ@$`!P```+G&`0`/````P<8!``\```#1Q@$`
M#````.'&`0`7````[L8!``P````&QP$`'0```!/'`0`;````,<<!``4```!-
MQP$`$P```%/'`0`;````9\<!`"P```"#QP$`$0```+#'`0`7````PL<!`!4`
M``#:QP$`$0```/#'`0`=`````L@!``@````@R`$`$````"G(`0`9````.L@!
M`!(```!4R`$`%````&?(`0`2````?,@!`!P```"/R`$`$P```*S(`0`3````
MP,@!`!<```#4R`$`$0```.S(`0`+````_L@!``@````*R0$`!0```!/)`0`=
M````&<D!``8````WR0$`&0```#[)`0`(````6,D!`!4```!AR0$`#````'?)
M`0`D````A,D!`!8```"IR0$`,P```,#)`0`>````],D!``X````3R@$`#P``
M`"+*`0`J````,LH!``8```!=R@$`'P```&3*`0`&````A,H!`!H```"+R@$`
M"0```*;*`0`+````L,H!`"<```"\R@$`.````.3*`0`*````'<L!`"D````H
MRP$`$@```%++`0`+````9<L!`!X```!QRP$`%````)#+`0`%````I<L!``<`
M``"KRP$`"P```+/+`0`)````O\L!``8```#)RP$`"````-#+`0`&````V<L!
M``H```#@RP$`'````.O+`0`M````",P!`#$````VS`$`)0```&C,`0`S````
MCLP!`"8```#"S`$`1P```.G,`0`A````,<T!`"<```!3S0$`/@```'O-`0!<
M````NLT!`#`````7S@$`!P```$C.`0`)````4,X!``@```!:S@$`"````&/.
M`0`7````;,X!`!8```"$S@$`+````)O.`0`N````R,X!`!D```#WS@$`,```
M`!'/`0`Z````0L\!``@```!]SP$`'P```(;/`0`+````IL\!``8```"RSP$`
M*P```+G/`0`3````Y<\!`!0```#YSP$`"P````[0`0`(````&M`!`!<````C
MT`$`!P```#O0`0`+````0]`!``T```!/T`$`&P```%W0`0`A````>=`!`#P`
M``";T`$`"@```-C0`0`3````X]`!``4```#WT`$`!P```/W0`0`%````!=$!
M`!L````+T0$`#P```"?1`0`%````-]$!`!(````]T0$`&@```%#1`0`'````
M:]$!``X```!ST0$`$````(+1`0`3````D]$!``0```"GT0$`!````*S1`0`,
M````L=$!`!X```"^T0$`6@```-W1`0`?````.-(!``H```!8T@$`*P```&/2
M`0`@````C](!`!8```"PT@$`%@```,?2`0`)````WM(!``D```#HT@$`$0``
M`/+2`0`N````!-,!``<````STP$`#P```#O3`0`2````2],!`!0```!>TP$`
M$````'/3`0!!````A-,!``H```#&TP$`'````-'3`0`5````[M,!`!H````$
MU`$`.0```!_4`0`C````6=0!`$P```!]U`$`4````,K4`0!)````&]4!`!$`
M``!EU0$``P```'?5`0`=````>]4!`"(```"9U0$`'0```+S5`0`)````VM4!
M`!,```#DU0$`(0```/C5`0`'````&M8!`"4````BU@$`'@```$C6`0`*````
M9]8!``8```!RU@$`$````'G6`0`1````BM8!`!P```"<U@$`!````+G6`0`(
M````OM8!``L```#'U@$`$````-/6`0`0````Y-8!`!<```#UU@$`%P````W7
M`0`)````)=<!``8````OUP$`0````#;7`0`T````=]<!`#,```"LUP$`!@``
M`.#7`0`&````Y]<!``8```#NUP$`'0```/77`0`6````$]@!`"P````JV`$`
M#@```%?8`0`0````9M@!`"0```!WV`$``P```)S8`0`&````H-@!`!$```"G
MV`$``@```+G8`0`-````O-@!`!H```#*V`$`#````.78`0`8````\M@!`!\`
M```+V0$`$@```"O9`0`2````/MD!``L```!1V0$`%````%W9`0`5````<MD!
M``\```"(V0$`"P```)C9`0`2````I-D!``X```"WV0$`%P```,;9`0!H````
MWMD!`"(```!'V@$`/P```&K:`0`-````JMH!``<```"XV@$`"0```,#:`0`4
M````RMH!`!<```#?V@$`%0```/?:`0`@````#=L!`"0````NVP$`%P```%/;
M`0`E````:]L!`!$```"1VP$`+P```*/;`0`3````T]L!`!4```#GVP$`D```
M`/W;`0`D````CMP!`"````"SW`$`,0```-3<`0`D````!MT!`",````KW0$`
M)````$_=`0`E````=-T!`"0```":W0$`'0```+_=`0`+````W=T!``<```#I
MW0$`"````/'=`0`)````^MT!`!0````$W@$`#P```!G>`0`W````*=X!`!L`
M``!AW@$`%@```'W>`0`(````E-X!``P```"=W@$`:@```*K>`0!"````%=\!
M`$H```!8WP$`@````*/?`0`-````).`!`#$````RX`$`,0```&3@`0`*````
MEN`!``4```"AX`$`!@```*?@`0!%````KN`!``@```#TX`$`9@```/W@`0`U
M````9.$!`"@```":X0$`%````,/A`0`G````V.$!`!X`````X@$`+0```!_B
M`0`W````3>(!`$0```"%X@$`-P```,KB`0`;`````N,!``<````>XP$`&P``
M`";C`0`7````0N,!`!4```!:XP$`"0```'#C`0`T````>N,!``P```"OXP$`
M"@```+SC`0`)````Q^,!`!<```#1XP$`"0```.GC`0`&````\^,!`!8```#Z
MXP$`"0```!'D`0`(````&^0!``4````DY`$`#P```"KD`0`0````.N0!`"0`
M``!+Y`$`(````'#D`0`3````D>0!`#0```"EY`$`#````-KD`0`'````Y^0!
M`!(```#OY`$`&P````+E`0`.````'N4!``X````MY0$`&0```#SE`0`F````
M5N4!``X```!]Y0$`(````(SE`0`V````K>4!``@```#DY0$`"@```.WE`0`9
M````^.4!``<````2Y@$`"````!KF`0`3````(^8!`!(````WY@$`$@```$KF
M`0`1````7>8!``8```!OY@$`"0```';F`0`(````@.8!``D```")Y@$`#@``
M`)/F`0`0````HN8!``8```"SY@$`%````+KF`0`#````S^8!``4```#3Y@$`
M$````-GF`0`?````ZN8!``L````*YP$``@```!;G`0`A````&><!``4````[
MYP$`!0```$'G`0!R````1^<!``8```"ZYP$`!@```,'G`0`<````R.<!`$8`
M``#EYP$`'@```"SH`0`<````2^@!`%L```!HZ`$`.P```,3H`0!/`````.D!
M`"````!0Z0$`%0```''I`0`&````A^D!``@```".Z0$`#P```)?I`0`1````
MI^D!``H```"YZ0$`#P```,3I`0`7````U.D!`!$```#LZ0$`$0```/[I`0`4
M````$.H!``@````EZ@$`"@```"[J`0`=````.>H!``X```!7Z@$`&@```&;J
M`0`)````@>H!``4```"+Z@$`!@```)'J`0`C````F.H!``8```"\Z@$`+@``
M`,/J`0`%````\NH!``8```#XZ@$`#0```/_J`0`&````#>L!``\````4ZP$`
M"P```"3K`0`5````,.L!`!(```!&ZP$`%0```%GK`0`&````;^L!`!D```!V
MZP$`"@```)#K`0`(````F^L!``<```"DZP$`!@```*SK`0`3````L^L!`"4`
M``#'ZP$`"P```.WK`0`.````^>L!`"@````([`$`&````#'L`0`:````2NP!
M``4```!E[`$`"@```&OL`0`3````=NP!``T```"*[`$``@```)CL`0`.````
MF^P!``D```"J[`$`)0```+3L`0`?````VNP!`#H```#Z[`$`*P```#7M`0`X
M````8>T!`"P```":[0$`9P```,?M`0`;````+^X!`&````!+[@$`.````*SN
M`0!*````Y>X!`%D````P[P$`+P```(KO`0`Q````NN\!`"L```#L[P$`,0``
M`!CP`0`O````2O`!`"8```!Z\`$`/0```*'P`0`B`@``W_`!`",````"\P$`
M&````";S`0!*````/_,!`($```"*\P$`,P````ST`0`O````0/0!`$````!P
M]`$`6@```+'T`0!0````#/4!`#D```!=]0$`(P```)?U`0`7````N_4!`"P`
M``#3]0$`(0````#V`0`C````(O8!`#,```!&]@$`)````'KV`0`J````G_8!
M`#8```#*]@$`&P````'W`0`1````'?<!`%0````O]P$`*P```(3W`0`M````
ML/<!`"<```#>]P$`(@````;X`0`M````*?@!`%D```!7^`$`-0```+'X`0!4
M````Y_@!`#H````\^0$`/````'?Y`0!.````M/D!`&\````#^@$`6````'/Z
M`0!'````S/H!`$H````4^P$`20```%_[`0!K````J?L!`'4````5_`$`:0``
M`(O\`0!F````]?P!`#\```!<_0$`+0```)S]`0`L````ROT!`#````#W_0$`
M=P```"C^`0!F````H/X!`'4````'_P$`P````'W_`0`9````/@`"`"H```!8
M``(`/0```(,``@`R````P0`"`%(```#T``(`)````$<!`@!;````;`$"`"``
M``#(`0(`"0```.D!`@"]````\P$"`$H```"Q`@(`(P```/P"`@`]````(`,"
M`"8```!>`P(`(0```(4#`@`^````IP,"``@```#F`P(`!P```.\#`@`%````
M]P,"``T```#]`P(`#@````L$`@`4````&@0"``X````O!`(`!0```#X$`@`3
M````1`0"``$```!8!`(`>0```%H$`@`+````U`0"`!,```#@!`(`!````/0$
M`@`'````^00"``8````!!0(`!0````@%`@`\````#@4"``0```!+!0(`%```
M`%`%`@`+````904"`!$```!Q!0(`#````(,%`@`"````D`4"``<```"3!0(`
M!P```)L%`@`1````HP4"``P```"U!0(`%P```,(%`@`&````V@4"`!4```#A
M!0(`#````/<%`@`#````!`8"`"T````(!@(`!````#8&`@`'````.P8"``<`
M``!#!@(`*0```$L&`@!&````=08"`$(```"\!@(`00```/\&`@`>````00<"
M`#8```!@!P(`.0```)<'`@`D````T0<"`!L```#V!P(`)````!((`@`M````
M-P@"`"8```!E"`(`(P```(P(`@`M````L`@"`"D```#>"`(`+@````@)`@`\
M````-PD"`"8```!T"0(`-P```)L)`@`P````TPD"`"D````$"@(`+P```"X*
M`@`M````7@H"`"8```","@(`,````+,*`@`J````Y`H"`"P````/"P(`+P``
M`#P+`@`J````;`L"`"8```"7"P(`*@```+X+`@`O````Z0L"`",````9#`(`
M+0```#T,`@`X````:PP"`#L```"D#`(`(````.`,`@`L`````0T"`#X````N
M#0(`*0```&T-`@`N````EPT"`"T```#&#0(`+````/0-`@`F````(0X"`"``
M``!(#@(`*````&D.`@`J````D@X"`$,```"]#@(`+P````$/`@`\````,0\"
M``D```!N#P(`%P```'@/`@`<````D`\"`#4```"M#P(`(@```.,/`@`.````
M!A`"``\````5$`(`$P```"40`@`+````.1`"``H```!%$`(`'P```%`0`@`&
M````<!`"``<```!W$`(`(@```'\0`@`E````HA`"`"````#($`(`*@```.D0
M`@`8````%!$"``@````M$0(`^````#81`@`:````+Q("`!T```!*$@(`"```
M`&@2`@`+````<1("`!8```!]$@(`%@```)02`@`E````JQ("``<```#1$@(`
M4P```-D2`@`:````+1,"`!H```!($P(`!P```&,3`@`9````:Q,"``P```"%
M$P(`3````)(3`@`+````WQ,"`#````#K$P(`'P```!P4`@`8````/!0"`!\`
M``!5%`(`/````'44`@`=````LA0"`!$```#0%`(`)P```.(4`@`3````"A4"
M`!0````>%0(`%@```#,5`@`+````2A4"`!H```!6%0(`"````'$5`@`L````
M>A4"``@```"G%0(`*0```+`5`@`O````VA4"``<````*%@(`&0```!(6`@`'
M````+!8"``@````T%@(`"0```#T6`@!%````1Q8"``<```"-%@(`$P```)46
M`@`3````J18"`!0```"]%@(`"@```-(6`@`*````W18"``<```#H%@(`%```
M`/`6`@`'````!1<"`!D````-%P(`#0```"<7`@`9````-1<"`!L```!/%P(`
M"@```&L7`@`-````=A<"`!<```"$%P(`!@```)P7`@`T````HQ<"``P```#8
M%P(`$````.47`@`)````]A<"``(`````&`(`$`````,8`@`:````%!@"``L`
M```O&`(``P```#L8`@`(````/Q@"``X```!(&`(`"0```%<8`@`.````81@"
M``T```!P&`(`%P```'X8`@`8````EA@"`!$```"O&`(`/````,$8`@`E````
M_A@"`",````D&0(`%P```$@9`@`.````8!D"`#0```!O&0(`!P```*09`@`5
M````K!D"`%D```#"&0(`$@```!P:`@`0````+QH"``D```!`&@(`!````$H:
M`@`$````3QH"`!$```!4&@(`'@```&8:`@`&````A1H"``<```",&@(`!P``
M`)0:`@`3````G!H"``<```"P&@(`%P```+@:`@`7````T!H"`$(```#H&@(`
M-````"L;`@`X````8!L"``4```"9&P(`&P```)\;`@`A````NQL"`!D```#=
M&P(`(@```/<;`@`1````&AP"``(````L'`(`!````"\<`@`1````-!P"``P`
M``!&'`(`!0```%,<`@`#````61P"``X```!='`(`5@```&P<`@`R````PQP"
M`!P```#V'`(`00```!,=`@`V````51T"`%@```",'0(`&0```.4=`@![````
M_QT"`"@```!['@(`2````*0>`@`D````[1X"`$<````2'P(`+````%H?`@`L
M````AQ\"`"\```"T'P(`+@```.0?`@`N````$R`"`#@```!"(`(`+````'L@
M`@`T````J"`"`"T```#=(`(`-0````LA`@`9````02$"`",```!;(0(`&```
M`'\A`@!Z````F"$"``D````3(@(`RP```!TB`@"0````Z2("`'P```!Z(P(`
M+0```/<C`@!N````)20"`!T```"4)`(`)@```+(D`@`3````V20"`!,```#M
M)`(`%@````$E`@`J````&"4"`$````!#)0(`(0```(0E`@`E````IB4"`'$`
M``#,)0(`'````#XF`@`7````6R8"``L```!S)@(`!0```'\F`@`&````A28"
M``@```",)@(`!0```)4F`@`6````FR8"`!4```"R)@(`&0```,@F`@`D````
MXB8"`!`````')P(`#P```!@G`@`2````*"<"``D````[)P(`%````$4G`@`(
M````6B<"``4```!C)P(`&0```&DG`@`*````@R<"``P```".)P(`&````)LG
M`@`(````M"<"``P```"])P(`$````,HG`@`.````VR<"`!8```#J)P(`#0``
M``$H`@`1````#R@"`!0````A*`(`!@```#8H`@`%````/2@"`"@```!#*`(`
M'````&PH`@`+````B2@"`"P```"5*`(`%P```,(H`@`E````VB@"`!H`````
M*0(`"````!LI`@`1````)"D"``<````V*0(`!P```#XI`@`9````1BD"``D`
M``!@*0(``P```&HI`@`"````;BD"`!(```!Q*0(`#0```(0I`@`*````DBD"
M`!8```"=*0(`&0```+0I`@`'````SBD"`"8```#6*0(``@```/TI`@`#````
M`"H"`!(````$*@(`&0```!<J`@`*````,2H"``L````\*@(`$@```$@J`@`&
M````6RH"`"$```!B*@(`"0```(0J`@`7````CBH"`!<```"F*@(`$@```+XJ
M`@`"````T2H"``0```#4*@(`#@```-DJ`@`/````Z"H"`!````#X*@(`+P``
M``DK`@`&````.2L"``@```!`*P(`%P```$DK`@`%````82L"``,```!G*P(`
M"P```&LK`@`!````TP0``!P$```Q!0``7P,```````"<`0``;0(``*`$````
M````E`,``,<!``#[!@``?```````````````A@(``"D'```+`0```````($'
M``#!````=P4``!4$``#P!0``+````-L#``#!!@``(P<```@"```!!```O`4`
M``('```Q`P```````*8"``#O!0``9`(``+("```/!```@0,`````````````
M``````````#6!```404``(4$`````````````/8!``!P`@````````````!_
M`@``+@0````````C`0``I`4```````!B!P``XP4``(\&```E`0``<`8``/4$
M``!N`@``<`$``#,'``#"`0``T0(``"\$``!O`P``3@<``%H```"B`0``,P$`
M`(D'````````>P$``.L```"6!@``P`4``%P'``!*!0``S`8```````"4!```
M8@(``/(````I`@``9@(```````#;!```A`8``-T%`````````````*4`````
M``````````````"8`P```````$````#D!@```````,T!````````G00``$@"
M``"_!0```````/T"``"(!P````````P%````````3P0``,L%``#L`@``)@4`
M`!<`````````-````%@```"\`0````````````"U`@``6@0``&4#``!J`P``
M7P$``(('``````````````````#Z`0``9`,``&\```#6`0```````'T&````
M````"`<``)``````````30,``)L"````````'`,``%T&``#T`0``WP```"@#
M``#<`0``T`$``+8#``!'`P```````!L'```1!P``)0,``/$```"P!0``T@0`
M````````````JP,``*0`````````R@4``&$#``!Y`P``E00```H$````````
MB@8``,`!````````X00``'@'``#9`P``YP$```````#^!0``2@<``*D!``!8
M!```Y`$```````!/````O@$``````````````````"\#``!L!P```````+(`
M````````F`4``&<$``"D!@``X@$``$8&````````*@```/L!``!H`0``5`<`
M`-H#```H!@``HP0``%0&``!6!```KP8```````"=`@``6P```)(&``"+`P``
MJ0````````"L!0``TP```*`#``!Z`0``9P(``,(#```H!P``>P,``"L`````
M````-@``````````````,0(``(,```#D!````````/8$``!Y!```1`<`````
M``#W``````````````"3`@``N@4````````7!0``J@,``"L"``!Z!P``````
M`'0$```[`@````````````"0`@``C@$``(H$``#<````?`<``%<%``":`P``
M`P(``#L'``!>`P``!@$```````!%!````````"T'``"?`P``I0$`````````
M````9P4``'$!`````````````$(&``#;````/0<``$H``````````@(`````
M```I`0```````%8#````````G`0```````#,`0``800``!8#````````)P0`
M`&$``````````````"4$``!W````[@,``&8&````````G`8``/\%``![````
M`````!@&``"Q!````P````,'``#<!0``MP8``,D#``!\`@``%@<``.P`````
M`````````&,!````````[@(``)H```"2````G@,```````";`0``*P4``'$"
M``#S`P``1@,``+X"``"Z`0``W00``-8&``"T`P``XP0``,H$``"J!```````
M`!@'```7`@``OP0``!@!``"Q`@````````````#B`P``CP(```````!^`0``
M_04``&D!```6!@``^`$``"H#``!+`P``<@,``$<$``"6`0``1P```,@!``!Q
M`P``3@8``#H```!@!@``4P```-4&``!V`@```````"X%```F`@``<P8``.T`
M```*!@``!````.0"``!^`P``@P4``(D!``"3!```_@(``&0'``#F!0``%P$`
M``````"?`0``#0<``'L"``!^````!00```D'```M!@``-`8```````!2`@``
MOP````````!W`P``_P,````````+````,P4`````````````9@<``"<&``#=
M`````````/0"```_!P```````-@#``#:!`````````````!H````#0(``'(&
M````````TP8``,4&``!Q````H````/P&``!"`@```````)L$``"Y`P``P```
M``0$```.!@``3`$``)0"``"Y!0``H`$``,$!````````!0````````!,!P``
MU@(``&,`````````Q````````````````````/($````````0`4``&\'````
M````S08````````7`P``@08`````````````4@4`````````````\P0``'<$
M``"C!@``;P0```@```!>````2`<``+H#``!V!0``W@```(0#```D!```.P4`
M`/<&``"<`P``=P(```````!J`0``/@(``+X&``#M!0``O@0```````!O!@``
M`````(D```"E`@```````#,&````````'`<```````!5`0``(@0``#@!````
M````;00```````"'`@``>04``(`%``#6`````````"$"``!/!@``-P0``#,"
M`````````````)<#``#_!`````<```<#``!I!@```````/$!``#&````\`,`
M`(\```!;!P````````````#G!@``A0,`````````````W0(``"X#``!7`0``
M]`8```````#E`0``_@```$T```#-!```$`4````````V`0``D`,``'T!``"7
M````600``'\$``!S````IP4``%@"``""`@```````$$&``!V`0``_@$`````
M``#G!````````"0`````````^`0``&L$``#&!```60$``"$$```&````GP(`
M`%X"``````````````,&``"4!0```````.$&``".`P``/@```"L!```4`@``
MUP,``)$&``!`!P```````&P#````````C@0``*,`````````Q0,``%$```"]
M`@``+`0``"`$``#I!````````"P&``#V`@``+@8``%@%````````````````
M``"I`@``)`,`````````````LP$```````!]````)P,```````!R!P``````
M`)$$````````S@$``/`&```(`0````````````````````$``$P%```X!@``
M`````,@%```1`0``7P0``/H#``"<````L`,``,0!````````=00``'$$``#7
M`@``R04``'P!``",`0``````````````````_`4``#4$````````/@<``*4&
M``#0`P``J`8``.T!``"F`````````.\"``````````````````"M!```ZP$`
M`/D$``#?`P``*`0```````!F!```GP````\&``"Y!```Z@,```````#)!```
M6P(``(P$````````Q`(``+X%``!"!0``=`<``-4%``"3!@```````&,'````
M`````````!L$````````]`,``%0```#9`````````$@```"6`````````%8"
M```W````'P8``#P"``!S`@```````/,"````````"`0``+<"``"E!```=P<`
M``````#:!@``%0````````#9!````````/P`````````'P4``(L%``#W`0``
M]@4``'P#``#8!@``M`4``)4%```#!0```````````````````````(,$``"_
M`@``S@(```P'``"9`P``_P(```````#T!```/P(``%,!````````Q00``#(!
M````````RP(``(P``````````````$L!`````````````+H&```)`0``W@$`
M`"8$``"D`P``S`4``',!```S!```$`8``(L$``!B`````````"\```"@!@``
M.`(``%D"``!_!P``1P<``(T%```9`````````*T```#O`P``T08``'P%```R
M````O04``,H"````````]@8``+8&``!;!0``1`$`````````````'0(``!X'
M``#;!@````````X%````````8`$``#D"``!#`@``NP$``(`#````````*@$`
M`$8```#0`@``$P8```````!_````0@,``#4'```M`0``,00``.$!````````
MT04``+0"``#H`0``5`,``/@#``!]!````````*(#``#4`@``8@,``.H%````
M`````````%\````?`@``,@,``/P"````````<P0```````"`!@``-P4``#H%
M```8!````````'8```"C`P```````)<%``!B!0``$@(``&P!```B`0``````
M`(X`````````:@4```````#%!0``&@$``.`!````````DP,``)@`````````
MA04``!@`````````+`4``(8$````````'````)D&``!H!@``^P(``(4!````
M````3`,``&@'``!Z!```$`0``&4```!4!0``Q`8``'0"``#@````````````
M``"W`P``=0,`````````````````````````````7`$````````X!P``?@(`
M`&P``````````````(@"````````S@8```L"```/!0``;0$``"T"``#?!0``
MYP(``$\#```-`0``8````&<`````````OP8``-D"``"Y!@``````````````
M````Z@```+($```H`````````"\'````````\P```*H%``#]`0``U00``!H`
M``````````````````!B!````````,@&``!?!@``3@`````````3`@``````
M``````!*!```%08``",````_````@@4``*@$``"X`@``D04``.0```!"!```
M`````+@%``!!!0``'P$``+@!````````FP4```````"U`````0<``"L'````
M`````````+`$````````:0<``'L%``!F````````````````````S@0```<!
M``!7!@````````````#?!@``8`<``#L!```[!```=0(``.L&```Y!```'P<`
M`/T&``!Q!@``#`$```````!'!@``G08``+P$``!E!@``"04``$4'````````
M``````````!S`P``BP```'D'``#2`P```0(``*,!```L`P```````+,$````
M````)`<```$#``#K`@``<````&T&``#8````$08``$4#``!=!P``\@4``.@&
M``#1!```/P,```````#Z!0``90<``)\&``#2`@```````&L!``#1````B08`
M`#````#(`@``H00``.P!``#B````:@(``*8!``!<`@```````#@#````````
M6P8``"L$``!@`P``X`4```````#/````E@4``-<&``!%`@````````````"5
M`0`````````````&!@``1@4``/X&````````20,``&P%``!3!P``TP$``(`!
M`````````````````````````````/T$``!L!```!@0``#X#```?!```WP0`
M``````!<`P``?@0``!$"```K!@``RP0``!L#````````?@8``'4````%`P``
MD0$```````"L``````````0"``!Y`0``*00``#0'````````>@```'0`````
M`````````&(!``!4`0``#0```#\!``#>`P``M`8``#<'`````````````"8`
M``````````````````"(!0``CP0```````!&!`````8```````"S````4`$`
M`)`&``"R`0``%@(``%`"``"'`P``;@<``/4"``"V````\@8``/$#``!1`0``
MX@0``.\$````````SP8````````O`@````````L'``!0`````````%0"````
M````2P8``($"````````&P8```````#S!@``BP8``+L```!<!@```````/D!
M``"$````108```````!U`0````````````!$`@``2`$``!4#````````)`$`
M`%D#``#U````F@4``%,%``#<!@``.0$``!D'````````B`$``%P%``!7!```
M00<``)H"```]`P``$0,``*X%``!)`0```````)\$````````/@$``&H```!^
M!0``IP,``*<&```@`````````*X```!+````$@```*8$```!`0``>`8`````
M``#5`0``N@```.0#``"V`0````````````!H!`````````````"^````N0``
M`'($````````$0```%\%``#F!```(`,``*L!``#F````(@(``)X&``"]`0``
M\@$``#D&``""!@```````($````2!```NP(``#T$``!_`0``&P```+,"````
M````O0,``'4%``!E`@``A0````````#-`@``PP8``'\%````````5P(``)\%
M``#P`0``K0,```````"*!0``<@$``+$```"!!````````.\&````````$`<`
M`&\"````````[0,````````0`@``%`$``"T#``!$!````````-4#``#?`@``
M`````'L&``!)!0```````-H%``"'!````````+$&``#W`@``KP0```4"````
M````(0```/L%``!W`0``/`,```D&``#S!0``\`(``'$%``"X`P```````-0#
M``#H`@``6`8```````![!```00,````````J`@``G`4``,8%``#9!0``804`
M````````````_P8``'H%``!'`@``/````+P```````````````\#````````
M``````\'```V!@``%`0`````````````80(```<'```S`P```````$`!```]
M!0```````)H&`````````````(<!``#)````Z0,``.,&``"]````BP$``+T$
M````````-@,``#4"```=!0```````(8&``"N!```!P(``.L$``"_`P``````
M````````````200``%`&``"U!```<P4``,0#````````:P,``-H!``"P`0``
M`````),%````````R08``*(%````````"0,``'T#```3````#00``,4!```+
M!````````$$"``!5````X@4```````"L`P```P,``!D$```%!@``````````
M``#J!```ZP4```H#``"H!0``MP0``!8```!4!```-P$``%4%``"D`@``^0(`
M``````"``@``(P4``/L#``!#`0``:@0`````````````/P4``!,!````````
M\@,``,<$``"]!@```````$@#````````S0,``%T%``!\!```/`8``/D````>
M!0``1@$```````"K````5@$``.@$``"-`````````,X#```W!@``````````
M``#+````AP```-T#`````````````,P$````````40<````````9!0``````
M`.<#```Q````S`,``(D%```0`0``#@```&H'``"G````SP0``&$'```7!@``
MV@```"$!``"B`@``F`(``%X$```M!```(@<``&4!``!X`@``$P<``!T$``#8
M!0``G`(``%T`````````X`0``&8%```^!@``Y@(```````"R!0````````0#
M```>!```````````````````!`4```````"3`0``A08``'0#``"O`P``^08`
M``````"2!```A0(``!T&````````W`,```````!;`0``6@<``!0#``#Q`@``
M,@<``'0%``"H`P``70$``"H&``````````````````"N!@``X`,``$X#``#\
M!```.0<``'@$````````+P4``&<&``#4````H`(``/D#````````*`4``(4'
M``#L!0``<@(````````I``````````8"````````"@<``.4$````````408`
M````````````)@<```$&````````1@(``````````````````-<!``#-````
M-P,```0!````````*@<``'$'``!B!@```````($%``!N`0``KP(``,0$```N
M`@``500``````````````````(0%```3!```D0(``%8&``#2````K@,``$@&
M```V!P``>P<```````#0!```&P4```````"Z!`````````````""`0``````
M```````C`@``6@$````````:!P``,0<``"`"``"H`@``)0<````````Z!```
MB0(``&L```#Q!@``.04``#P!```1!0```````.0%``"*````'`$``*L$``")
M`P``!@4````````B!0``70(```````#J`0```````/H$````````WP$``$<%
M````````$@8``(@```#I`@``-`0``.4#``"K!0``S04``,<#````````/P0`
M`````````````````.H"``"A`P``_@,``!@%```S````]04``'8'````````
M;@8```````#+`P``;P$``!X#``!9!0```````(8```"#`0```````+0```"/
M`P``A`0``#`$``"W`0``F0(``*`%``"V`@``Y0(````````R!```H0```"P"
M``#(`P``"P,```````",!0```````!H&``"L!```````````````````:P4`
M``````#8`0````````X$```'!@```````"4```#A`P``G@``````````````
M<@4``!X&````````%0$``#X%```=````S`(``)X%``"(!@``C@(``"$%``"6
M`@```````#\&``!`!@``H0$``*$%```G`@`````````````M````20<``)4"
M``!2!``````````````T`@``]P4``'0!``!=`P``-0$```````!.!```5@4`
M`*($```)````PP4``(,#````````6`$``&D"``#L`P``&0(```````#"`@``
M60<``$,#```\!```D`$``.8!``#C`P``400`````````````K`(```X"```<
M`@``3@$``$@$```*`````````$P&``#\`0``+@```(T!````````+`<``.T"
M``#I`0``SP$``&P"`````````````-H"``##`@``)P```+,#``"2!0``````
M`&X````0`````````(T$```;`0``<`0``'4'`````P``W@4``%('``"R`P``
M!@<``(T#````````C0(``&<!``""`P``OP$``'8&``!N!```J@```$X"``!D
M!0```````(P#```N!P``@@0```````"\`P``/@0``!@"````````-P(``)(#
M``""``````0```````````````````\"```5`@``P@```+L#````````T`8`
M`#`%``#N````P04```````!(!0``$@<``%@'```"!```7@$`````````````
MV0$``$D&``#Q!```;`8``#@%```Z!P``F@$``.$```"\`@``O@,``!8$````
M`````````)D%``#I!0``]0,```````!"!P``&0,``.P$``"5`P```@,```@&
M``"-!@```````&L&``!?!P``+@$``"4&````````9`8``&D#````````7@8`
M`+4#```*`@``20(``!\````+!@``9`$`````````````3P(`````````````
MI@4``#`&``"Q`0``#`8``-(!```U!0``A@$``%P`````````.@8``.8#```:
M!0``NP0``*T"````````@````'H#``"'!@```````(,&``#=`0``-0,``.\!
M``````````````P```"6`P``8P(``)X"``#Q!0``````````````````9`0`
M````````````Z0```+8%``"A!@```````!X!``#!`P``.P8``'`%``"$`0``
M:P(```````!-!```Y@8```````#&!@``CP$```````##````'0<```````!C
M!```<P<````````-!0``/0$``$\'``!M`P``(08``$0````5!P``````````
M``#8`@``20```#L#```7!````````.\```!J!@````````H%``!3`P``!P4`
M`"0%``"U!@``J00```<$``!'`0``0P8``````````````````"`%````````
ML````*\````O!@``[@8``.,`````````(@8``!(#``#!!```V08`````````
M````?P,```P$```8`P``K`$```````"Y`0``X@8``,X`````````D@$``'X'
M``#%`@```@4````````T`0```````*@````L`0``#@,```````"0!```&0$`
M`*(```!0!0```````.D&``#5`@``````````````````"00``)D!``";`P``
MJ@$```P"``#4!0``]`4``/4!```-`P```````)T!``#%`````````,8"``!7
M````.````"@"`````````````/T#``"G!```NP4```````#"!0```````$\!
M```=`0``[`8``/@&``"6!```4`0```````"M`0````````````"D`0``J04`
M`+`"``!C!@```````-8#```6!0``I@,````````:`@````4```````"&!P``
M@`<``-`%``#C`0``K`8``.,"``#`!@``JP(``'`#``"0!0``KP$```````#2
M!0``H@8```````"U!0```````,X%``!M!0```````/@"````````W08`````
M````````'P,``'T'``"T!```I@8```````#$!0``IP$``$,```"=`P``&P(`
M``````!,!`````````(!``"7`@``3P4``$`#``!Y!@``W`(```````!&!P``
M8P4``'\&``!$`P``Y0```$T%``#"!@```````````````````````-````!;
M`P``MP```'D"``!#!0```````%(&``#6!0``2@(``#T````M!0```````'H&
M``#@`@``8`0``!H#``````````````````##!````````-,#``#B`@``>`,`
M`)0```"'!P``&@0```````````````````````!!!```&08`````````````
M4`<````````I`P``_0```%<#`````````````"$'``!1`P``.@(``),```#S
M`0``50(`````````````#08```````"9!````````$(!``!?`@``2P0``$L'
M``!N!0``L0,```````"$`@``308````````F`0```````-L!````````L04`
M`'`'``#<!```:04``+,&```G!0``/`<``$,'``!*`P``:00``,\#````````
M:`(``*\%``"`!```=@,``-$#``!0`P``F`$``.$"``!,`@``P@0```````"(
M!```:P<``'(```````````````````#Z`@```````#(%``!H`P``!0<``",#
M``!\!@```````.@#``"7!```M0$``,H&``#/`@``*`$``)<!``#+`0``````
M`%8'``!3`@``6@,``(8%````````,`(``/@```"9`````````,P```"N`@``
M-`4```````#7`````````*4%```````````````````D!@``F`8``.X!```A
M`P``.P```)<&``!!`0``Q@,``(P"```$!P``%04``&4%````````````````
M```B`P``B@(``!X```"#!P``50<``*T%``!%````=08``#@$``##`0``U`$`
M`$(```!E!```)P<``&\%``#U!@``5@````X!``#Y!0``30(``/X$``!:`@``
MHP4```0&``#H!0``(@```$4%````````2@8``)@$``";!@``P0(```,$````
M`````````+P&``!N`P``%`8``.T&````````?04``.@````T`P``6@4``!(%
M```/`0``'@(```````!H!0```````"\!```]`@``30$``#`!```E`@``U0``
M```````E!0``9@,``/8```!Z`@``C@8`````````````HP(```````"N`0``
M_`,``&$!``"X````D0```````````````````)4````F`P``#P``````````
M````B@,```````!]`@``QP4``,8!````````A@,``"`'``">`0```````-L"
M``#)`0``"@$``%4#``!Y````U`0``,,#````````R@$``!,#````````````
M``````!M!P``\`0``'8$```(`P```````#T&``#8!````````*$"``!M````
MCP4``!<'````````5P<``"H$```"````8`(``!P%````````^`4``$X%````
M````R`````P#``"+`@```````*4#```(!0```````#D#``#_`0``#@<``%T$
M```)`@```````$P```":!```T0$``"D%``#G!0```````'@`````````9@$`
M`/````#N!0``2P(``+<%```%!0```````%(```#K`P``2P4``-0&```Y````
MR`0``)T%``#``@``7@<```,!``!W!@``1`4``-X&``````````````<````V
M!0``*P,``/H```#'!@``%`<```(&``#*````>`$``!(!``#W`P``Y04``*H&
M``!3!```4@$````````&`P``N0(``$T'```4````D0,``*H"``!<!```UP0`
M`#H#```P`P``]````$`$````````W@(``+`&`````````````-L%``!A!@``
MP`,``,H#``#M!```6P0``)0!``"(`P``9P<``(0'`````````````!,%``",
M!@``I`0``#`'``"*`0``0P0``)L````@!@``\@(``'0&`````````````+8$
M````````$`,``.H&``!@!0```````/L$``"4!@``X04``"D&````````````
M`/<$````````N@(```````"T`0``1`8```````"M!@``508``#P%````````
M00```#8$````````,@(````````!!0```````(X%```=`P``IP(`````````
M````4@,``"8&``#3!0``^@8```````"H`0``8P,``!$$`````````````%,&
M```G`0``LP4```````#E!@``TP(```````"'!0``@P(``+@&``!8`P``@0$`
M``````#N!```)`(``-(&````````-0```+L&``#)`@``J0,``%D`````````
M,0$```````#@!@``L@8```L%``!%`0``6@8``+@$```U!@```````%D&````
M````9````",&``#'`@```````)T```#_````!0$``$`"``")!```:0```-<%
M```@`0``G@0```````"2`@``%`4````````Z`0``SP4````````6`0``````
M`'@%``#'````RP8`````````````7@4``",$``#V`P``*@4``.<```#`!```
MJ08``!P&``!*`0``,08````"``!G`P``W@0``#8"`````````````/L```"K
M!@``E08``%$"````````,@8````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME
M>2`E<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE
M<W1E<F1A>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`
M(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S
M(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@
M5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E
M<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E
M<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R
M`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M
M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@
M0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O
M=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I
M;VXN`"P@9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U
M<B!&;W)M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N
M9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H
M87,@;V-C=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E
M9"!T;R!V97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME
M>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER
M960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D
M96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T
M92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E
M9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A
M:6X`04T@4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!
M4$D@240`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B
M<VUI9&1L90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN
M`$%C8V5S<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF
M;W)M871I;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C
M;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI
M<W-I;VX@=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@
M;F5W(&UE;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z
M:6QL82!3:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A
M9&1R97-S(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M
M+"!B=70@8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA
M=&EO;CH@)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L
M;V<@:6X@;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`
M061D<F5S<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R
M(&]T:&5R('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!
M;&)A;FEA`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL
M($%U=&AE;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO
M;G,`06QL(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L
M;&]W('-E='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI
M<W1S`$%L=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W
M;W)D`$%L=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A
M9&1R97-S`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M
M97)I8V%N(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`
M06X@=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`
M06YG=6EL;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N
M=&EG=6$@86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES
M=`!!<'!L:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S
M`$%P<')O=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O
M=W,M,3(U-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y
M;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S
M(B!A;F0@86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N
M:6%N("A!4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S
M8VEI($%R=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T
M:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I
M9VYM96YT(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E
M;G0@9W)O=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M
M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N
M`$%T=')I8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER
M<W%L.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL
M:71E<RX`075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET
M8V@N`$%U=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T
M:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@
M=&AE('-E<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E
M('5S97(@)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`
M075T:%]L9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S
M;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&%T
M($E-05`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T
M960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E
M<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N('1O('1H92!334(@<V5R=F5R
M(&9A:6QE9"X`079A:6QA8FQE(&9I96QD<SH`07IE<F)A:6IA;@!"3T9(($5X
M8W5S97,`0F%C:V=R;W5N9`!"86-K9W)O=6YD($-O;&]R`$)A9"!K97)B97)O
M<R!P87-S=V]R9"X`0F%D(&ME<F)E<F]S('5S97)N86UE+@!"86AA;6%S`$)A
M:')A:6X`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B861O
M<P!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`0F%S
M96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M=61A`$)H
M=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N("(E<R(@
M;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O;&0`0F]L
M:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O<F1E
M<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA`$)O='1O
M;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/8V5A;B!4
M97)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L;&5T960@
M3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$:7-T<FEB
M=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%C:&4@:6YI="!W
M87,@;F]T(&-O;7!L971E9"X`0V%L96YD87(`0V%L;0!#86UB;V1I80!#86UE
M<F]O;@!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O(&9I
M;&4@(B5S(@!#86XG="!A9&UI;FES=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N
M9&QE<G,N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;B=T
M(&]P96X@9FEL92`B)7,B+@!#86YA9&$`0V%N8V5L`$-A;F-E;"!0<F]B;&5M
M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@
M82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T
M("=T87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T
M;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#
M86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R
M(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T
M(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P92!697)D
M90!#87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA
M;B!)<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D
M9&EN9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE
M`$-E;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF
M:6-A=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0
M;VQI8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N
M9V4@=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@
M=&AE>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@
M>6]U<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM
M<&QI9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#
M:&]O<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A
M('5S97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E
M(&QI<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA
M<R!)<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L
M96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T
M('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG
M($QA=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#
M;&]S92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@
M8F]R9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E
M;&5C=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O
M;6UA;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A
M;GD`0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I
M;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H
M(%!$07,L(%-M87)T<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N
M(&ES(&]U="!O9B!D871E+@!#;VYF:6=U<F4@)7,`0V]N9FER;2!087-S=V]R
M9`!#;VYG;P!#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M`$-O;FYE8W1I;VX@9F%I;&5D+@!#;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C
M=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ
M("5S("@E<RD`0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N
M=&%C=',`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L;'D@861D960@=&\@>6]U
M<B!A9&1R97-S(&)O;VLN`$-O;G1E;G0@='EP92!O9B!C;VUP<F5S<V5D(&9I
M;&4Z(`!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#
M;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S96QE8W1I;VX`0V]S
M="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E
M;F-R>7!T(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@
M`$-O=6QD(&YO="!3+TU)344@96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@
M4R]-24U%('-I9VX@;65S<V%G92X`0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E
M<P!#;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-H
M96-K(&)A;&%N8V4N("5S`$-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@8V]N;F5C="!T;R!S97)V97(@(B5S(B!U<VEN9R!&
M5%`Z("5S`$-O=6QD(&YO="!C<F5A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S
M`$-O=6QD(&YO="!D96-R>7!T(%!'4"!D871A.B``0V]U;&0@;F]T(&1E8W)Y
M<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`
M0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N
M;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`
M0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N
M;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI
M<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@
M;6MD:7(@(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@
M=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN
M9RX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B
M)7,B+@!#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N
M;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@
M=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL
M<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD
M(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@
M8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E
M<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O
M=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER
M("(E<R(N`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD
M(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A
M=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S
M971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@
M=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S
M879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R
M('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K
M(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N
M`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@
M=6YL:6YK("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T
M('=R:71E(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I
M;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R
M(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I
M;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X
M=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E
M(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S
M:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@
M-"!0:&%S97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N
M="!54DP@:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N
M="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T
M;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP
M<G5S`$-Y<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I
M`$-Y<FEL;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$
M1`!$4TX@*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K
M86=E+F1A=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E
M($)R;W=S97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$
M871E('-E;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C
M:6UA;"!N=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@
M0V]L;W(`1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I
M;VYS`$1E;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO
M9P!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S
M`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L
M=&5R;F%T92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI
M<W-I;VYS(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A
M;F0@86YY('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L
M96-T960@:61E;G1I='D`1&5L971E('-U8B!F;VQD97)S`$1E;&5T92!T:&4@
M8W5R<F5N="!C;VQU;6X`1&5L971E('1H92!C=7)R96YT(')O=P!$96QE=&5D
M('-E='5P('5P9W)A9&4@<V-R:7!T("(E<R(N`$1E;&EV97)Y('1I;64`1&5N
M;6%R:P!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS
M("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N
M(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E
M=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@
M`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L
M969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@
M3W!T:6]N<P!$:7-P;&%Y(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R
M96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]N)W0@:&%V92!A;B!A
M8V-O=6YT/R!3:6=N('5P+@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$;W=N;&]A
M9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T+@!$<F]P
M(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`14UA:6PM=&\M4TU3(&=A=&5W87D@
M9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES('-E<G9I
M8V4N`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D
M:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO
M;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@
M9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F;W(@)7,`161U8V%T:6]N`$5G
M>7!T`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C
M;VYF:7)M871I;VX`16UA:6PM=&\M4TU3($=A=&5W87D`16UO=&EC;VYS`$5M
M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E<W5L="X`16UP='D@<V5A<F-H('1E<FUS
M`$5N86)L92!I;G-E<G1I;VX@;V8@:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R
M:65S(&EN('1E>'0_`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_
M`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E
M<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K960@:68@>6]U(&YE960@=&\@
M<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G=VAA="!I<R!T:&4@;F%M92!O
M9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA9V4@55),(&AE<F4`16YT97(@
M=&AE(&QE='1E<G,@8F5L;W<Z`$5Q=6%T;W)I86P@1W5I;F5A`$5R:71R96$`
M17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ("5S`$5R<F]R(&1E;&5T:6YG
M('-Y;F,@86YC:&]R.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&QO9SH@)7,`
M17)R;W(@9V5T=&EN9R!C;VYT96YT.B`E<P!%<G)O<B!U<&1A=&EN9R!P87-S
M=V]R9#H@)7,`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<G)O<B!W<FET
M:6YG("(E<R(N`$5S=&]N:6$`171H:6]P:6$`171H;FEC`$5U<F]P90!%=F5R
M>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R>2`S,"!S96-O;F1S
M`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R>2!H86QF(&AO=7(`
M179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C=71E`$5X<&%N9`!%
M>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP96-T960@8F%R92!W;W)D
M(&]R('%U;W1E9"!S96%R8V@@=&5R;0!%>'!I<F%T:6]N($1A=&4`17AP;VYE
M;G0`1D<@0V]L;W(`1E10('5P;&]A9"!O9B!S971U<`!&86EL960@<F5T<FEE
M=FEN9R!P<F5F97)E;F-E<RX`1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S
M97)V97(N`$9A:6QE9"!T;R!C;VYN96-T('1O(%--0B!S97)V97(N`$9A:6QE
M9"!T;R!C;W!Y(&9R;VT@(B5S(BX`1F%I;&5D('1O(&-O<'D@=&\@(B5S(BX`
M1F%I;&5D('1O(&-R96%T92!N97<@4T%33"!C;VYN96-T:6]N+@!&86EL960@
M=&\@;6]V92!T;R`B)7,B+@!&86EL960@=&\@<F5T<FEE=F4Z("5S`$9A:7(`
M1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I`$9A<F]E($ES;&%N9',`1F%T
M86P@17)R;W(Z`$9A>`!&87AE<P!&96)R=6%R>0!&965L<R!,:6ME`$9E96QS
M(&QI:V4Z(`!&97<@4VAO=V5R<P!&97<@4VYO=R!3:&]W97)S`$9I96QD(&UA
M=')I>`!&:6=L970@0T%05$-(00!&:6=L970@9F]N=`!&:6II`$9I;&4`1FEL
M92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA
M;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I
M;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I;FQA;F0`1FER
M<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&;&EP`$9L;V%T`$9O
M9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#;VQO<@!&;V]D`$9O
M<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA9V5S`$9O<F5C87-T
M("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T:&4@<F5T=7)N960@
M9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG:'0[(&$@;&%R9V4@
M;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED92!B;&]C:RD`1F]R
M9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T>7!E
M`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R86UE
M<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E;F-H($=U:6%N80!&
M<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&
M<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL
M($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D
M($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.
M86UE`$=L;V)A;"!/<'1I;VYS`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G
M;&4@4V5A<F-H`$=R87ES8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I
M`$=R965N;&%N9`!'<F5N861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T
M;R!A9&0@9W)O=7`@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P
M7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E
M;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO
M;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,
M`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T
M(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R
M9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(')O=R!I;B!T86)L92X`
M2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG
M;W)I=&AM`$AA>F4`2&5A9&5R`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-
M8T1O;F%L9"!)<VQA;F1S`$AE879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U
M.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(
M96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`
M2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE
M`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U
M<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!8
M34P@9&%T82!E;F-O=6YT97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B
M.B!.;R!M97-S86=E(&-O<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@3F\@;V)J96-T(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(
M;W)D92]+;VQA8CH@5&AE(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T
M:&4@)V1O;7AM;"<@4$A0(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE
M('1O(&-R96%T92!N97<@6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+
M;VQA8CH@56YA8FQE('1O(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O(')E=')I979E($U)344@240@9F]R('1H92!P87)T(&]F
M('1Y<&4@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E
M<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E
M('-H87)E<SH@)7,`2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(
M;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ
M`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M
M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY
M(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O
M=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU
M;6]R:7-T<P!(=6YG87)Y`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z
M("5S`$E-05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I
M;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@
M061D<F5S<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@
M86QL;W=E9"!#2412(&)L;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?
M;G-E<G0@4F]W($)E9F]R90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R
M("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES
M(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@
M;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@
M26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES
M(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E
M('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N
M="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E
M<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@
M9G)O;2!G86QL97)Y`$EM86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D
M`$EM86=E<P!);7!O<G0L(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM
M<&]R=&5D(&9I96QD<SH`26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C
M=&EO;B!C;V1E(&=I=F5N+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A
M<W-W;W)D+@!);F-O<G)E8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E
M<W,N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I
M9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I
M80!);F1I=FED=6%L(%5S97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N
M`$EN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L
M=6UN($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E
M8B!,:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L
M=6UN(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN
M(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R
M<F5N="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E
M;G0@;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E
M;6%I;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W
M('!A<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O
M<F4`26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!)
M;G-E<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@
M<&%R86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@
M8F5F;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U
M<FET>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D
M:69Y($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D
M:7-T<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E
M<@!);G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R
M*2X`26YV86QI9"!:25`@9&%T80!);G9A;&ED(&%P<&QI8V%T:6]N+@!);G9A
M;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A;&ED
M(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`26YV
M86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E9"X`
M26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I9"X`
M26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R96YT
M('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P<F]D
M=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C:7!I96YT
M.B`B)7,B`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D
M9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`26YV97)T
M('-E;&5C=&EO;@!)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F`$ER87$`27)E
M;&%N9`!)<VQE(&]F($UA;@!)<V]L871E9"!4+5-T;W)M<P!)<W)A96P`27-S
M=65R`$ET86QI8P!)=&%L>0!*86UA:6-A`$IA;G5A<GD`2F%P86X`2F%P86YE
M<V4@*$E33RTR,#(R+4I0*0!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T
M:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`
M2G5S=&EF>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA
M`$ME<F)E<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R
M;F5L($YE=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@
M3&5N9W1H`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@
M;VX@=&AE('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L
M($1E;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B
M;&EC(&]F`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y
M;W5T`$QA;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC
M`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`
M3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F
M<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE
M879E(&5M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A
M9&5R`$QE9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@
M07)A8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,
M:6=H="!286EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI
M9VAT(%)A:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT
M(%-N;W<`3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O
M:6YT<R!T;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S
M92!P86=E('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES
M="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI
M<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M
M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R
M:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z
M("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES
M(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO
M8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO
M9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I
M;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL
M960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO
M=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O
M=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D
M871A+@!-4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V
M(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN
M`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`
M36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@
M=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I
M=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-
M87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5
M;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R
M=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA
M=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E
M9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X
M:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-
M87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@
M8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I
M9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A
M=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE
M=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E
M9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N
M97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI
M;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z
M(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI
M<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G
M96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC
M871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!0
M14%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I
M;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D
M=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N
M=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO
M<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@
M)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY
M($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E
M($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO
M>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P
M(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O
M=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY
M86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.
M97!A;`!.971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P
M92!"87-E(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P
M92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E
M(%)E=F]C871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S
M8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E
M('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R
M>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N
M9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@97AP:7)E(&]N("5X
M+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@=VEN9&]W("A?8FQA
M;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0:&%S97,`3F5X="!O
M<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YI9VAT`$YI
M=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@9&%T82!T;R!S:&]W
M(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T<F%T96=Y(&9O<B!M
M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA=&4N`$YO(&)L;V-K
M(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N`$YO(&-A;&5N9&%R
M(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC871I;VXN`$YO(&-H
M86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES
M<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE
M9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M
M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L
M969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E
M9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!L;V-A
M=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S
M<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F
M;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P87)A=&]R('-P96-I
M9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO
M('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/
M+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`
M3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T
M($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@
M<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G
M;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`
M3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@
M<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`
M3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS
M92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W;W)D<R!M=7-T(&)E
M(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S=V]R9"!I<R!N;W0@
M8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E
M9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE<P!/;FQY(&]N92!E
M;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W;F5R(&]R('-Y<W1E
M;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S:&EP(&]R(&]W;F5R
M('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@82!N97<@=VEN9&]W
M`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S
M:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN:R!I;B!A(&YE=R!W
M:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S
M`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI<V%T:6]N86P@56YI
M=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N('1E;7!L871E`$]R
M:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H97(@26YF;W)M871I
M;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I8V%T:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!01U`@1&EG:71A;"!3
M:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'
M4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-
M($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-(%-N;W<`4$T@4VYO
M=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)6"!E>'1E;G-I;VX@
M:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`
M4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@
M3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A
M<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S=V]R9"!I;F-O<G)E
M8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO
M;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W
M;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E`%!A<W1E(&9R;VT@
M8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!096]P;&4`4&5R8V5N
M=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`4&5R9F]R;2!M86EN
M=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M:7-S:6]N`%!E<FUI
M<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO;B!$96YI960`4&5R
M;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@
M26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O
M<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT
M;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R
M96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W
M86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO
M;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N
M97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N
M`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@
M;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I
M;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`
M4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE
M87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E('1Y<&4@
M=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`
M4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN
M9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O
M<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H
M<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R969S7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`4')E9G-?<V5S<VEO
M;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T(&9O=6YD+@!0<F5S
M<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S<W5R93H@`%!R979I
M97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN9&]W`%!R979I;W5S
M(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI
M8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC($ME>2!);F9O`%!U
M8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L
M;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A=&%R`%%U97)Y`%%U
M;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5G97@`
M4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R:W,`4F5M;W1E(%-E
M<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D
M92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!296UO=F4@
M9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R:7!T(&9R
M;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E('1H90!2
M96UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V92!U<V5R
M`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N<W=E<F5D
M+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@<V5R=FEC92!C;W5L
M9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T('-P96-I9FEE9"!I
M;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("(E<R(@;F]T('-P
M96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"!&:65L9`!297-E
M=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W1O<F4@
M3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E='EP92!N
M97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A=&EO;@!2:6-H
M(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2:6=H="!H96%D
M97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2;VQE`%)O;6%N
M:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R
M;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W
M:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P
M<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U<F4`4R]-24U%
M($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I;VX@:7,@;F]T
M(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`4U%,('-T871E
M;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T534P!37U%,(%-H96QL
M`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@3F5V:7,`4V%I;G0@
M3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!386EN="!6:6YC96YT
M(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?<V5L9BD`4V%M;V$`
M4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`4V%T96QL:71E(%!R
M;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S(@!3879E("5S`%-A
M=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@
M4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O
M<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D('-E='5P('5P9W)A
M9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC
M90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A
M(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE
M<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T
M(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`4V5L96-T(&%N(&]B
M:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A8W1E<G,@>6]U(&YE
M960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@=&AE;B!C;W!Y(&%N
M9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T
M('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z`%-E;&5C="!T:&4@
M=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F;W)M870Z`%-E;&5C
M="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U<B!C;VQO<B!S8VAE
M;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B
M;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E;6)E
M<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S:6]N($%D;6EN`%-E
M<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E="!O<'1I;VYS('1O
M(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF('EO=2!E=F5R
M(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H870@>6]U('=A
M;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y;W5R('!R969E
M<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T:6]N<RX`4V5T
M('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H96UE+"!P86=E
M(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E='5P
M`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V97)A;"!L;V-A
M=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``4V5Y8VAE;&QE
M<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B
M92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC
M97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE
M<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H
M;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO
M=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L
M;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S
M(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`
M4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:&]W97)S(&EN
M('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R
M:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I97)R82!,96]N
M90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I=&AM`%-I;F=A
M<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`4VQO=F5N:6$`
M4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3:&]W97)S($5A
M<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3;F]W(&5Q=6EV
M86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M86QI80!3;VYG
M<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C92!A9&1R97-S
M`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U
M=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',`4V]U
M=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS
M`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A
M8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I;@!3<&%M`%-P
M96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN
M`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D`%-T87(@5')E
M:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U<P!3=&]R86=E
M(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H`%-T<FEN9R!L
M:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T>6QE(%M#4U-=
M`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`4W5B:F5C=`!3=6)M
M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@=&\@=&AE('-Y<W1E
M;2X@66]U(&-A;FYO="!L;V<@:6X@=6YT:6P@>6]U<B!R97%U97-T(&AA<R!B
M965N(&%P<')O=F5D+@!3=6)S8W)I<'0`4W5C8V5S<P!3=6-C97-S9G5L;'D@
M861D960@(B5S(B!T;R!T:&4@<WES=&5M+@!3=6-C97-S9G5L;'D@8VQE87)E
M9"!D871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M+@!3=6-C97-S
M9G5L;'D@9&5L971E9"`B)7,B+@!3=6-C97-S9G5L;'D@<F5M;W9E9"`B)7,B
M(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(')E=F5R=&5D(&-O;F9I
M9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C8V5S<V9U;&QY
M('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S9G5L;'D@<V%V
M960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`%-U8V-E<W-F
M=6QL>2!U<&1A=&5D("(E<R(`4W5C8V5S<V9U;&QY('=R;W1E("5S`%-U9&%N
M`%-U;6UA<GD`4W5N(%)I<V4`4W5N(%-E=`!3=6YN>0!3=6YR:7-E`%-U;G)I
M<V4O4W5N<V5T`%-U;G)I<V4Z(`!3=6YS970`4W5N<V5T.B``4W5P97)S8W)I
M<'0`4W5P<&]R=`!3=7)I;F%M90!3=7)N86UE`%-V86QB87)D(&%N9"!*86X@
M36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>6YC(&QO9R!D
M96QE=&5D`%-Y;F--3`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y
M<FEA;B!!<F%B(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`
M5"U3=&]R;7,`5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R
M=&EE<P!486)L92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N
M+"!0<F]V:6YC92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET
M960@4F5P=6)L:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R
M`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E
M.B``5&5M<&5R871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!4
M96UP;&%T92`B)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I
M;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@
M*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P
M;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE
M9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E
M<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN
M9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R
M;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E
M(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C
M="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@
M=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A
M<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H
M92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O
M('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@
M;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@
M;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T
M=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL
M92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S
M('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-A
M;FYO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A:6YE
M9"!N;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@
M=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@
M;6]D92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T
M($5X<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG
M="!A8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G
M87)B86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O
M;W(@<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES
M(%=I;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@
M82`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O
M;W0N7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+
M(&EF('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I
M=&]R+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@
M;&5F="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'
M(&)I;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S
M<RX`5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@
M(B5S(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E
M('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D
M+@!4:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E
M('!A9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4
M:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#
M<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M
M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE
M=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y
M<W1E;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@
M8VAA<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@
M<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N
M92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@
M9&5L971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@
M<VEG;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S
M<&5C:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A
M<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT
M97)E9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H
M92!T;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY
M`%1H92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U
M<R!S=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N
M`%1H92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M
M97,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T
M:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B
M92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C
M=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A
M8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S
M(&$@<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R
M92!W87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F
M<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG
M("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U
M<&1A=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE
M(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R
M9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN
M`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H
M92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A
M;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A
M<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H
M97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!0
M97)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W
M87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@
M8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L
M96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A
M=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@
M;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R
M:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@
M=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A
M;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES
M(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H
M92!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@
M2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G
M97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O
M;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L
M;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE
M(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M
M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@
M<F5Q=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R
M<RX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H
M92!C;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A
M;'5E<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P
M87)A=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@
M=F%L:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R
M(&-O9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R
M,S1A9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`
M5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N
M(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C
M;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O
M<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E
M('9I<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A
M8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E
M<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC
M;VUP<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U
M<G)E;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M
M8F5R+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO
M;G,@=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`
M5&EM92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`
M5&ET;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L
M(&AO;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@
M:V5Y('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`
M5&]G;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@
M;&]G:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE
M("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E
M(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y
M+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V
M86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F
M;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G
M86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG
M;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@
M9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@
M=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F
M:6QE('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,
M('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O
M<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F
M;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`
M56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B
M)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E
M;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C
M=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!6
M1E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N
M86)L92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O
M(&1E=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A
M8W0@8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F
M:6QE(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA
M8FQE('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A
M9"!61E,@9FEL92`H9V5T1FEL95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@
M<F5A9"!F:6QE.B``56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@<F5N86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F
M;VQD97(@86QR96%D>2!E>&ES=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER
M96-T;W)Y+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5
M;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA
M;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N
M`%5N86)L92!T;R!R=6X@)VUK:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E
M('1H:7,@5V]R9"!D;V-U;65N=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M(B5S(BX`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D
M*2X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W
M<FET92!61E,@9FEL92P@<75O=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L
M:6YE`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5
M;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5
M;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI
M;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY
M:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!
M4$D@365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S
M86=E($E$*2X`56YK;F]W;B!L;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U
M<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE
M;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S
M($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@
M<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T
M(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S
M8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N
M<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U
M<V5R`%5P9&%T960@(B5S(BX`57!G<F%D92!S8W)I<'0@9&5L971E9"X`57!L
M;V%D`%5P;&]A9&5D(&%L;"!A<'!L:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T
M:&4@<V5R=F5R+@!5<'!E<B!L871I;B!L971T97)S`%5P<&5R(')O;6%N(&YU
M;6)E<G,`57)U9W5A>0!5<V4@0W5R<F5N=#H@)7,`57-E(%-33`!5<V4@:68@
M;F%M92]P87-S=V]R9"!I<R!D:69F97)E;G0@9F]R($E-4U`@<V5R=F5R+@!5
M<V5R`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D
M;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5
M<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S
M:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N86UE`%5S97)N86UE
M("(E<R(@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD
M(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L
M=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O
M;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A
M;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE
M=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER
M9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5TE.('9I82!(5%10`%=A;&QI<R!A;F0@1G5T=6YA`%=A<FYI;F<`5V4`
M5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A
M=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H870@87!P;&EC871I
M;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE
M(&1E;&EM:71E<B!C:&%R86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A
M8W1E<C\`5VAE<F5I<R!!=7-T<F%L:6$@;6%P`%=H:6-H('!H87-E<P!7:&EC
M:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N
M`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N
M=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`
M5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`5VEN
M9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN9#H@
M`%=I<V1O;0!7:7-H;&ES=`!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',@:6X@;&EN92`E9"X@17AP96-T960@
M)60L(&9O=6YD("5D+@!7<F]N9R!N=6UB97(@;V8@9FEE;&1S+B!%>'!E8W1E
M9"`E9"P@9F]U;F0@)60N`%=R;VYG(&]F9G-E="`E9"!W:&EL92!R96%D:6YG
M(&$@5D93(&9I;&4N`%@M4F5F`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8
M-3`Y=C,@17AT96YD960@2V5Y(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R
M;F%T:79E($YA;64`6#4P.78S(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P
M.78S(&5X=&5N<VEO;G,`65D`65E960!986AO;R$@;6%P`%EE87)L>0!996UE
M;@!997,`665S+"!)($%G<F5E`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E
M('1H92!;/#Y=(&)U='1O;B!T;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9
M;W4@87)E(&YO="!A;&QO=V5D('1O(&-R96%T92!M;W)E('1H86X@)60@8FQO
M8VMS+@!9;W4@87)E(&YO="!A=71H96YT:6-A=&5D+@!9;W4@8V%N;F]T(&AA
M=F4@=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D
M:60@;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG
M="!M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H
M92!C;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L
M;V=G960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N
M92!N=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O
M<B!T:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@
M=&\@96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N
M9FEG=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P
M<F]B;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T
M+@!9;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN
M=',@=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D
M+@!9;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S
M="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I
M9GD@=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W
M:&%T(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A
M=&5G;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P
M:&]N92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A
M<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ
M(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R
M97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E
M<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T
M(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B
M86-K96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@
M=VES:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S
M+"!Y;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C
M:V5N9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U
M<'!O<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@
M9&ES86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@
M87!P96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O
M9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@
M>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U
M<'!O<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N
M9"`K(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@
M9&5F875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U
M;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@
M;W!T:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F
M('1H:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+@!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@
M:&%S(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W
M:71H('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I
M<F5D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?
M26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN
M`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B
M;V]K`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R
M96%T92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E
M`&-O;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R
M`&-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R
M;W(`961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE
M("5S("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK
M;F]W;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E
M<FYA;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E
M("5D('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D
M`&YO="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I
M;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES
M:6YG`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R
M96UA:6P@=FEA($A45%``<W,`<W1E861Y`'-Y<W1E;2!E<G)O<@!T87-K(&QI
M<W0`=&5M<&]R87)Y(&9A:6QU<F4`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@
M=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`
M=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!F<E]&4@I297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E
M871I;VXM1&%T93H@,C`P-BTP,RTP-B`Q,CHT-RLP,3`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#8M,#,M,S$@,C(Z,S`K,#(P,`I,87-T+51R86YS;&%T;W(Z
M(%1H:65R<GD@5&AO;6%S(#QT:&EE<G)Y0'!O;7!O+FYE=#X*3&%N9W5A9V4M
M5&5A;3H@1G)E;F-H(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S
M:6]N.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/4E3
M3RTX.#4Y+3$*0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`I0;'5R
M86PM1F]R;7,Z(&YP;'5R86QS/3([('!L=7)A;#TH;B`^(#$I.PH`("AI;"!Y
M(&$@)7,@:F]U<G,I`"`H5&]U8VAE(&0G86-CZ',@<F%P:61E("5S*0`@*&1A
M;G,@)7,@:F]U<G,I`"`H875J;W5R9"=H=6DI`"`H9&5M86EN*0`@*&AI97(I
M`"#@(`"KH"5SH+L@;B=E<W0@<&%S('5N(&1O<W-I97(`JZ`E<Z"[(&XG97-T
M('!A<R!U;B!C:&]I>"!V86QI9&4N`*N@)7.@NR!N)V5S="!P87,@8V]N9FEG
M=7+I(&1A;G,@;&4@<F5G:7-T<F4@9&4@2&]R9&4N`$PG:6YT97)P<NET975R
M(&0G87)B<F4@JZ`E<Z"[(&XG82!P87,@Z73I('1R;W5VZ2X`JZ`E<Z"[(&$@
MZ73I(&%J;W5TZ2!A=2!S>7-TZ&UE(&1E<R!G<F]U<&5S+@"KH"5SH+L@82#I
M=.D@86IO=73I(&%U('-Y<W3H;64@9&5S('!E<FUI<W-I;VYS+@"KH"5SH+L@
M;B=A('!A<R#I=.D@8W+IZ:`Z("5S+@`E+C)FH$UO('5T:6QI<^ES('-U<B`E
M+C)FH$UO('!E<FUI<R`H)2XR9J`E)2D`)60@)7,@970@)7,`)60@:F]U<G,@
M879A;G0@;"=E>'!I<F%T:6]N(&1E('9O=')E(&UO="!D92!P87-S92X`)60M
M<'+I=FES:6]N(&1U(&IO=7(`)7,@+2!.;W1I8V4`16UP<F5I;G1E(%!'4"!D
M92`E<P`E<Z!+;P`E<R!O<.ER871I;VYS(&1E(&UA:6YT96YA;F-E("9N9&%S
M:#L@0V]N9FER;6%T:6]N`$-O;F9I9W5R871I;VX@)7,`26YS8W)I<'1I;VX@
M9&4@)7,`0V]N9&ET:6]N<R!D)W5T:6QI<V%T:6]N(&1E("5S`"5S(&5X:7-T
M92!DZ6K@+@`@)7.@X"`E<R`E<P`E<R!E<W0@<'+J="#@(&5F9F5C='5E<B!L
M97,@;W#I<F%T:6]N<R!D92!M86EN=&5N86YC92!C;V-HZ65S(&-I+61E<W-O
M=7,N(%/I;&5C=&EO;FYE>B!L82!O=2!L97,@;W#I<F%T:6]N*',I('%U92!V
M;W5S('9O=6QE>B!E9F9E8W1U97(@8V5T=&4@9F]I<RUC:2X`)7,@97-T(&]B
M;&EG871O:7)E`"5S(&UI;G5T97,`)7,@;F]N('1R;W5VZ0`E<Z#@("5S(&1E
M("5S`$-A<FYE="!D)V%D<F5S<V5S(&1E("5S`$%G96YD82!D92`E<P!";&]C
M+6YO=&5S(&1E("5S`$QI<W1E(&1E('3B8VAE<R!D92`E<P`E<Z`Z("5S`"5S
MH#H@;"?I;65T=&5U<B!D92!C92!M97-S86=E(&$@<'4@ZG1R92!F86QS:69I
MZ2X@071T96YT:6]N(&5N('-U:79A;G0@;&5S(&QI96YS('%U)VEL(&-O;G1I
M96YT(&]U(&5N(&9O=7)N:7-S86YT(&1E<R!I;F9O<FUA=&EO;G,@<&5R<V]N
M;F5L;&5S(.`@;"?I;65T=&5U<BX`+"!E;B!R869A;&4@`')A9F%L92`E<R`E
M<P!V87)I86)L92!D=2`E<R!A=2`E<P`M+2!3Z6QE8W1I;VYN97(@+2T`1F]R
M;6%T(#$R(&AE=7)E<P!&;W)M870@,C0@:&5U<F5S`#(T(&AE=7)E<P`\4'+I
M8^ED96YT`%5N92!B87-E(&1E(&1O;F[I97,@<')I;F-I<&%L92`H8F%C:V5N
M9"D@97-T(&[I8V5S<V%I<F4@<&]U<B!C92!B;&]C`%5N92!E<G)E=7(@9F%T
M86QE(',G97-T('!R;V1U:71E`%5N92!C;&5F('!U8FQI<75E(%!'4"!E<W0@
M;NEC97-S86ER92!P;W5R(&-H:69F<F5R('5N(&UE<W-A9V4N`%5N92!C;&5F
M('!U8FQI<75E(%!'4"!E<W0@;NEC97-S86ER92!P;W5R(';I<FEF:65R(&QA
M('-I9VYA='5R92!D)W5N(&UE<W-A9V4N`%5N92!C;&5F('!U8FQI<75E(%!'
M4"P@=6YE(&-L968@<')I=NEE(%!'4"P@970@=6YE('!H<F%S92!S96-RZ'1E
M('-O;G0@;NEC97-S86ER97,@<&]U<B!DZ6-H:69F<F5R('5N(&UE<W-A9V4N
M`%5N92!C;&5F('!U8FQI<75E(%!'4"P@=6YE(&-L968@<')I=NEE(%!'4"P@
M970@=6YE('!H<F%S92!S96-RZ'1E('-O;G0@;NEC97-S86ER97,@<&]U<B!S
M:6=N97(@=6X@;65S<V%G92X`56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U
M;F4@8VQE9B!P<FEVZ64@4R]-24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@
M<V]N="!NZ6-E<W-A:7)E<R!P;W5R(&3I8VAI9F9R97(@=6X@;65S<V%G92X`
M56YE(&-L968@<'5B;&EQ=64@4R]-24U%+"!U;F4@8VQE9B!P<FEVZ64@4R]-
M24U%+"!E="!U;F4@<&AR87-E('-E8W+H=&4@<V]N="!NZ6-E<W-A:7)E<R!P
M;W5R('-I9VYE<B!U;B!M97-S86=E+@!5;F4@8VQE9B!P=6)L:7%U92!3+TU)
M344@97-T(&[I8V5S<V%I<F4@<&]U<B!C:&EF9G)E<B!U;B!M97-S86=E+@!.
M=6%G97,@;&4@;6%T:6X`4&QU:64@;.EGZ')E(&QE(&UA=&EN`%!L=6EE(&QE
M(&UA=&EN`$%V97)S97,@;&4@;6%T:6X`0VAU=&5S(&1E(&YE:6=E(&QE(&UA
M=&EN`$%-+U!-`$%022!)1`#`('!R;W!O<R!D92!C970@Z61I=&5U<@#`('!R
M;W!O<RXN+@!"87,@86)S;VQU`$UI;&EE=2!A8G-O;'4`06-CZ',@<F5F=7/I
M(&QO<G,@9&4@;&$@8W+I871I;VX@9&4@<NEP97)T;VER92!61E,@+@!!8V/H
M<R!R969U<^D@;&]R<R!D92!L82!C<NEA=&EO;B!D92!F:6-H:65R(%9&4RX`
M1&]N;NEE<R!P97)S;VYN96QL97,`36]T(&1E('!A<W-E(&1U(&-O;7!T90!#
M;VUP=&4@:6YA8W1I9@!#;VUP=&5S`$%J;W5T97(`06IO=71E<B!U;B!S;W5S
M+6=R;W5P90!!:F]U=&5R('5N92!N;W5V96QL92!S;W5S+7!E<FUI<W-I;VX`
M06IO=71E<B!I8VF@.@!!:F]U=&5R('5N(&YO=79E874@9W)O=7!E`$%J;W5T
M97(@=6YE(&YO=79E;&QE('!E<FUI<W-I;VX`06IO=71E<B!U;B!G<F]U<&4@
M9FEL<R#@(*N@)7.@NP!!:F]U=&5R('5N92!P97)M:7-S:6]N(&9I;&QE(.`@
MJZ`E<Z"[`$%J;W5T97(@=6X@;F]U=F5L('5T:6QI<V%T975RH#H`06IO=71E
M<B!U;F4@8V]L;VYN90!!:F]U=&5R(&1E(&YO=79E875X(&UE;6)R97,`06IO
M=71E<B!U;F4@<&%I<F4`06IO=71E<B!L92!M96YU("5S(.`@;&$@8F%R<F4@
M9&4@36]Z:6QL80!!:F]U=&5R(&%U(&-A<FYE="!D)V%D<F5S<V5SH#H`06IO
M=71E<B#@(&UO;B!C87)N970@9"=A9')E<W-E<P!!:F]U=&5R('5N('5T:6QI
M<V%T975R`*N@)7.@NR!A(.ETZ2!A:F]U=.D@874@<WES=.AM92P@;6%I<R!L
M)V%J;W5T(&0G:6YF;W)M871I;VX@<W5P<&SI;65N=&%I<F5S("5S(&XG97-T
M('!A<R!P;W-S:6)L92X`JZ`E<Z"[(&$@Z73I(&%J;W5TZ2X@5F]U<R!P;W5V
M97H@=F]U<R!C;VYN96-T97(N`$QA(&9O;F-T:6]N(&0G86IO=70@9"=U=&EL
M:7-A=&5U<G,@97-T(&3I<V%C=&EVZ64N`$%D<F5S<V4`0V%R;F5T(&0G861R
M97-S97,`061M:6YI<W1R871E=7(@+2!A:G5S=&5R(&QE<R!P97)M:7-S:6]N
M<R!P;W5R(&0G875T<F5S('5T:6QI<V%T975R<P!!9&UI;FES=')A=&EO;@!0
M=6)S`$%F9VAA;FES=&%N`$%L8F%N:64`06QGZ7)I90!!;&EA<P!!;&EG;F5R
M`$%L:6=N96UE;G2@.@!4;W5T`%1O=7,@;&5S('!A<G1I8VEP86YT<R!A=71H
M96YT:69IZ7,`5&]U<R!L97,@9W)O=7!E<P!4;W5T97,@;&5S('!E<FUI<W-I
M;VYS`$QE<R!Q=6%T<F4@8_1TZ7,`4&5R;65T=')E(&1E<R!A9')E<W-E<R!D
M92!C;W5R<FEE;"!M=6QT:7!L97,`075T;W)I<V5R(&QA(&UI<V4@96X@<&QA
M8V4@9&4@;&ES=&5S(&YU;>ER;W3I97.@/P!%>&ES=&4@9.EJX`!.;VT@9"=U
M=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68`36]T(&1E('!A<W-E($E-4U`@
M86QT97)N871I9@!.;VT@9"=U=&EL:7-A=&5U<B!)35-0(&%L=&5R;F%T:68`
M061R97-S92!D92!C;W5R<FEE;"!A;'1E<FYA=&EV90!!=71R97,@;6]DZ&QE
M<P!497AT92!A;'1E<FYA=&EFH#H`4V%M;V$@06WI<FEC86EN`%5N92!V86QE
M=7(@:6QLZ6=A;&4@82#I=.D@<W#I8VEF:>EE+@!5;F4@97)R975R(&EN8V]N
M;G5E(',G97-T('!R;V1U:71E+@!!;F1O<G)E`$%N9V]L80!!;F=U:6QL80!0
M<F]X>2!A;F]N>6UE`%+I<&]N<V4`06YT87)C=&EQ=64`06YT:6=U82UE="U"
M87)B=61A`$%P<&QI8V%T:6]N`$QI<W1E(&0G87!P;&EC871I;VYS`$PG87!P
M;&EC871I;VX@97-T('!RZG1E`$%P<&QI<75E<B!A=7@@<&%R=&%G97,@9FEL
M<P!!<'!R;W5VZ0!486EL;&4@87!P<F]X:6UA=&EV90!!=G)I;`!!<F%B92`H
M5VEN9&]W<RTQ,C4V*0!486EL;&4@9'4@9FEC:&EE<B!A<F-H:79E`$YO;2!D
M92!L)V%R8VAI=F4`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!S=7!P
M<FEM97(@8V5T=&4@<F5Q=>IT92!D)VEN<V-R:7!T:6]N("!P;W5R("5SH#\`
MRG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@)7.@NR!E
M="!S97,@<V]U<RUG<F]U<&5SH#\`07)G96YT:6YE`$%R;>EN:64`07)MZ6YI
M96X@*$%235-#24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B`HSFQE*0!!<G0@
M05-#24D`4NEG:6]N($%S:64O4&%C:69I<75E`$1E;6%N9&5R('5N92!C;VYF
M:7)M871I;VX@879A;G0@9&4@;&%N8V5R(&QE<R!O<.ER871I;VYS(&1E(&UA
M:6YT96YA;F-EH#\`0V]L;VYN97,@9&5S('3B8VAE<P!496YT871I=F4@9"=E
M9F9A8V5M96YT(&0G=6X@9W)O=7!E(&EN97AI<W1A;G0N`%1E;G1A=&EV92`@
M9"=E9F9A8V5M96YT(&0G=6YE('!E<FUI<W-I;VX@:6YE>&ES=&%N=&4N`%1E
M;G1A=&EV92!D92!M;V1I9FEC871I;VX@9"=U;F4@<&5R;6ES<VEO;B!I;F5X
M:7-T86YT92X`5&5N=&%T:79E(&1E(&UO9&EF:6-A=&EO;B!D)W5N('!A<G1A
M9V4@:6YE>&ES=&%N="X`4')O<')IZ73I<P!!;_MT`$%U<W1R86QI90!!=71R
M:6-H90!!=71H7V-Y<G5SH#H@17AT96YS:6]N(')E<75I<V4@24U!4"!N;VX@
M=')O=7;I92X`075T:%]C>7)U<Z`Z(&QE(&)A8VME;F0@;B=A('!A<R!L97,@
M8V%P86-I=.ES(')E<75I<V5S+@!!=71H7V-Y<G5SH#H@97AT96YS:6]N(')E
M<75I<V4@24U!4"!N;VX@=')O=7;I90!!=71H7V9T<*`Z(&5X=&5N<VEO;B!R
M97%U:7-E($944"!N;VX@=')O=7;I92X@26P@9F%U="!C;VUP:6QE<B!02%`@
M879E8R!L)V]P=&EO;B`M+65N86)L92UF='`N`$%U=&A?:6UA<*`Z(&5X=&5N
M<VEO;B!R97%U:7-E($E-05`@;F]N('1R;W5VZ64N`$%U=&A?:W)B-:`Z(&5X
M=&5N<VEO;B!R97%U:7-E(&MR8C4@;F]N('1R;W5VZ64N`$%U=&A?;&1A<*`Z
M(&PG86IO=70@9"=U=&EL:7-A=&5U<G,@;B=E<W0@<&%S('-U<'!O<G3I(&%V
M96,@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87"@.B!L92!R971R86ET(&0G
M=71I;&ES871E=7)S(&XG97-T('!A<R!S=7!P;W)TZ2!A=F5C($%C=&EV92!$
M:7)E8W1O<GD`075T:%]L9&%PH#H@97AT96YS:6]N(')E<75I<V4@3$1!4"!N
M;VX@=')O=7;I92X`075T:%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@
M;"=U=&EL:7-A=&5U<B`E<RX@0V5C:2!E<W0@;&$@<NEP;VYS92!D=2!S97)V
M975RH#H@`$%U=&A?;&1A<*`Z(&EM<&]S<VEB;&4@9&4@<W5P<')I;65R(&PG
M=71I;&ES871E=7(@)7,`075T:%]L9&%PH#H@;6]D:69I8V%T:6]N(&EM<&]S
M<VEB;&4@9&4@;"=U=&EL:7-A=&5U<B`E<P!!=71H7VQD87"@.B!L82!M;V1I
M9FEC871I;VX@9&5S('5T:6QI<V%T975R<R!N)V5S="!P87,@<W5P<&]R=.EE
M(&%V96,@06-T:79E($1I<F5C=&]R>2X`075T:%]M8V%LH#H@97AT96YS:6]N
M(')E<75I<V4@34-!3"!N;VX@=')O=7;I92X`075T:%]S;6)A=71HH#H@97AT
M96YS:6]N(')E<75I<V4@<VUB875T:"!N;VX@=')O=7;I92X`R6-H96,@9&4@
M;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@24U!4"X`R6-H96,@9&4@
M;"=A=71H96YT:69I8V%T:6]N`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO
M;B`E<P!,92!S97)V975R(%)!1$E54R!A(')E:F5TZ2!L)V%U=&AE;G1I9FEC
M871I;VXN`,EC:&5C(&1E(&PG875T:&5N=&EF:6-A=&EO;B!A=2!S97)V975R
M($944"X`R6-H96,@9&4@;"=A=71H96YT:69I8V%T:6]N(&%U('-E<G9E=7(@
M4TU"+@!#:&%M<',@9&ES<&]N:6)L97.@.@!!>F5R8F'O9&IA;@!%>&-U<V5S
M($)/1D@`0V]U;&5U<B!D92!F;VYD`$-O=6QE=7(@9&4@9F]N9`!-;W0@9&4@
M<&%S<V4@2V5R8F5R;W,@97)R;V[I+@!.;VT@9&4@8V]N;F5X:6]N($ME<F)E
M<F]S(&5R<F]NZ2X`0F%H86UA<P!"86AR9>]N`$)A;'1E("A)4T\M.#@U.2TQ
M,RD`0F%N9VQA9&5S:`!"87)B861E`%+I<&5R=&]I<F4@9&5S(&=R87!H:7%U
M97,@JZ`E<Z"[(&YO;B!T<F]U=NDN`$QI9VYE(&1E(&)A<V4`0NEL87)U<P!"
M96QG:7%U90!"96QI>F4`0NEN:6X`0F5R;75D97,`0FAO=71A;@!!;FYI=F5R
M<V%I<F4`0FQO8R"K)7,@NR!D92!L)V%P<&QI8V%T:6]N(*N@)7.@NR!I;F-O
M;FYU`%!RZ6;I<F5N8V5S(&1E(&)L;V,`5'EP92!D92!B;&]C`$=R87,`0F]L
M:79I90!3:6=N971S`$)O<F1U<F4`R7!A:7-S975R(&1E(&QA(&)O<F1U<F6@
M.@!";W)D<P!";W-N:64M2&5R>NEG;W9I;F4`3&5S(&1E=7@`0F]T<W=A;F$`
M0F%S`$)O=79E=`!"<NES:6P`5&5R<FET;VER97,@8G)I=&%N;FEQ=65S(&1E
M(&PG3V/I86X@26YD:65N`%-U;'1A;F%T(&1U($)R=6[I:0!"=6QG87)I90!,
M:7-T92#@('!U8V5S`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$=E<W1I;VX@9&4@
M8V]N=&5N=0!#4D,`1&ES=')I8G5T:6]N(&1E<R!P;VEN=',@3%)#("A,:7-T
M92!D92!RZ79O8V%T:6]N(&1E<R!C97)T:69I8V%T<RD`4')O<')IZ73I<R!D
M92!L82!#7V5L;'5L90!,)VEN:71I86QI<V%T:6]N(&1U(&-A8VAE(&YE(',G
M97-T('!A<R!T97)M:6[I92X`06=E;F1A`$-A;&UE`$-A;6)O9&=E`$-A;65R
M;W5N`$EM<&]S<VEB;&4@9&4@<NEI;FET:6%L:7-E<B!L92!M;W0@9&4@<&%S
M<V4@875T;VUA=&EQ=65M96YT+"!C;VYT86-T97H@=F]T<F4@861M:6YI<W1R
M871E=7(@<WES=.AM92X`26UP;W-S:6)L92!D92!S=7!P<FEM97(@;&4@9FEC
M:&EE<B"KH"5SH+LN`$EM<&]S<VEB;&4@9"=A9&UI;FES=')E<B!D97,@9V5S
M=&EO;FYA:7)E<R!D92!S97-S:6]N(&5X=&5R;F5S+@#)8VAE8R!D92!L82!C
M;VYN97AI;VX@874@<V5R=F5U<B!)34%0H#H@)7,`26UP;W-S:6)L92!D)V]U
M=G)I<B!L92!F:6-H:65R(*N@)7.@NRX`0V%N861A`$%N;G5L97(`06YN=6QE
M<B!L92!R87!P;W)T(&1U('!R;V)LZ&UE`$EM<&]S<VEB;&4@9&4@<W5P<')I
M;65R(&QE(&9I8VAI97(@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E('1R;W5V97(@
M=6X@<NEP97)T;VER92!T96UP;W)A:7)E`$EM<&]S<VEB;&4@9&4@<')O8^ED
M97(@<V%N<R!L92!P87)A;>AT<F4@JR!T87)G971&:6QE(+L`26UP;W-S:6)L
M92!D92!S=7!P<FEM97(@;&4@<NEP97)T;VER92"KH"5SH+LN`%-U<'!R97-S
M:6]N(&EM<&]S<VEB;&4L(&EL('D@82`E9"!E;G)E9VES=')E;65N=',@9FEL
M<RX`26UP;W-S:6)L92!D92!RZ6]R9&]N;F5R+"!L92!N;VUB<F4@9"?I;.EM
M96YT<R#@('+I;W)D;VYN97(@;F4@8V]R<F5S<&]N9"!P87,@874@;F]M8G)E
M(&0GZ6SI;65N=',@96YR96=I<W1RZ7,N`$YE('!E=70@9&ER:6=E<B!L92!M
M97-S86=E('9E<G,@;&4@;F]M8G)E('-PZ6-I9FGI+@!#87`M5F5R=`!,Z6=E
M;F1E`%1R86YS<&]R=&5U<@!#873I9V]R:65S(&5T(,ET:7%U971T97,`SFQE
M<R!#8>]M86X`5.ELZ7!H;VYE(&-E;&QU;&%I<F4`4')O<')IZ73I<R!D92!L
M82!C96QL=6QE`%)E;7!L:7-S86=E(&%U=&]U<B!D92!L82!C96QL=6QEH#H`
M4')O<')IZ73I<R!D92!L82!C96QL=6QE`$5S<&%C96UE;G0@9&4@;&$@8V5L
M;'5L9:`Z`%3I;.EP:&]N92!C96QL=6QA:7)E(`!#96QT92`H25-/+3@X-3DM
M,30I`$-E;G1R97(`4NEP=6)L:7%U92!C96YT<F%F<FEC86EN90!%=7)O<.EE
M;B!C96YT<F%L("A)4T\M.#@U.2TR*0!$Z71A:6QS(&1U(&-E<G1I9FEC870`
M4')O<')IZ71A:7)E(&1U(&-E<G1I9FEC870`4&]L:71I<75E(&1E(&-E<G1I
M9FEC871I;VX`5&-H860`36]D:69I97(`36]D:69I97(@=F]T<F4@;6]T(&1E
M('!A<W-E`$-H86YG97(@;&4@;F]M+"!L)V%D<F5S<V4@970@;&$@<VEG;F%T
M=7)E('%U92!L97,@<&5R<V]N;F5S('9O:65N="!Q=6%N9"!E;&QE<R!L:7-E
M;G0@970@<NEP;VYD96YT(.`@=F]S(&UE<W-A9V5S+@!,82!M;V1I9FEC871I
M;VX@9&4@=F]T<F4@;6]T(&1E('!A<W-E(&XG97-T('!A<R!S=7!P;W)TZ64@
M879E8R!L82!C;VYF:6=U<F%T:6]N(&%C='5E;&QE+B!#;VYT86-T97H@=F]T
M<F4@861M:6YI<W1R871E=7(N`$-H87(`5NE?<FEF:65R(&QE(&QI96X`0VAI
M;&D`0VAI;F4`0VAI;F]I<R!S:6UP;&EF:>D@*$=",C,Q,BD`0VAI;F]I<R!T
M<F%D:71I;VYN96P@*$)I9S4I`$-H;VES:7(@;"=A<'!L:6-A=&EO;J`Z`$-H
M;VES:7(@=6X@;6]T(&1E('!A<W-E`$-H;VES:7(@=6X@;F]M(&1E(&-O;FYE
M>&EO;@!#:&]I<VER(&QE(&UO9&4@9"=A9F9I8VAA9V4@9&5S(&1A=&5SH#H`
M0VAO:7-I<B!L92!S='EL92!D92!L:7-T92`H<&]U<B!L97,@;&ES=&5S(&YU
M;>ER:7%U97,I`,YL97,@0VAR:7-T;6%S`$3I9FEN:71I;VX@9&4@;&$@8VQA
M<W-E(&1E("5S(&YO;B!T<F]U=NEE+@!%9F9A8V5R`$YE='1O>65R(&QE<R!B
M86QI<V5S($U3+4]F9FEC90!%9F9A8V5R(&QA(')E<77J=&4`4F5T:7)E<B!L
M)W5T:6QI<V%T975R.B`E<P!%9F9A8V5R(&PG=71I;&ES871E=7(`169F86-E
M<B!L97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R`,EC;&%I<F-I97,@=&%R
M9"!D86YS(&QA(&IO=7)NZ64`0VQI<75E<B!P;W5R('!O=7)S=6EV<F4`0VQI
M8VMA=&5L;"!V:6$@2%144`!&97)M97(@;&$@9F5NZG1R90!.=6%G97,`3G5A
M9V5S(&UA=&EN875X`$YU86=E=7@`SFQE<R!#;V-O<P!297!L:65R(&QA(&)A
M<G)E(&1E(&/T=.D`4NED=6ER92!L97,@8F]R9',`0V]L;VUB:64`0V]U;&5U
M<@!086QE='1E(&1E(&-O=6QE=7)S`%/I;&5C=&EO;B!D)W5N92!C;W5L975R
M`$-O;'.@.@!4:71R97,@9&4@8V]L;VYN90!"+D0N`$-O;6UA;F1E`$-O;6UA
M;F1E('-H96QL`$-O;6UE;G1A:7)E`$YO;2!U<W5E;`!#;VUO<F5S`%-O8VGI
M=.D`3W)D:6YA=&5U<G,`0V]N9&ET:6]N`$-O;F1I=&EO;G,`1&EF9NER96YC
M97,@9&4@8V]N9FEG=7)A=&EO;@!3>6YC:')O;FES871I;VX@9&5S(&%S<VES
M=&%N=',@<&5R<V]N;F5L<RP@/$D^<VUA<G1P:&]N97,\+TD^(&5T($]U=&QO
M;VLN`$QA(&-O;F9I9W5R871I;VX@;B=E<W0@<&%S(.`@:F]U<BX`0V]N9FEG
M=7)E<B`E<P!#;VYF:7)M97(@;&4@;6]T(&1E('!A<W-E`$-O;F=O`%+I<'5B
M;&EQ=64@9.EM;V-R871I<75E(&1U($-O;F=O`,EC:&5C(&1E(&QA(&-O;FYE
M>&EO;@#)8VAE8R!D92!L82!C;VYN97AI;VZ@.B``0V]N;F5X:6]N(&%U('-E
M<G9E=7(@9&4@8VQE9G,@<'5B;&EC(')E9G5SZ64N`$-O;FYE>&EO;B!A=2!S
M97)V975R(&1E(&-L969S('!U8FQI8R!R969U<^EE+B!286ES;VZ@.B`@)7,@
M*"5S*0#)8VAE8R!D92!L82!C;VYN97AI;VX@874@<V5R=F5U<B!&5%``0V]N
M=&%C=',`0V5S(&-O;G1A8W1S(&]N="!B:65N(.ETZ2!A:F]U=.ES(.`@=F]T
M<F4@8V%R;F5T(&0G861R97-S97,N`%1Y<&4@9&4@8V]N=&5N=2!D=2!F:6-H
M:65R(&-O;7!R97-SZ:`Z(`!#;VYT96YU(&1E(*N@)7.@NP!0;W5R<W5I=G)E
M`,YL97,@0V]O:P!4Z6UO:6X@*&-O;VMI92D`0V]P:65R`,EC:&5C(&1E(&QA
M(&-O<&EEH#H@)7,`4^EL96-T:6]N(&0G=6YE(&-O<&EE`$ED+B!C;_MT`$-O
M<W1A(%)I8V$`0_1T92!D)TEV;VER90!);7!O<W-I8FQE(&1E(&-H:69F<F5R
M(&QE(&UE<W-A9V6@.B``4VEG;F%T=7)E(%!'4"!D=2!M97-S86=E(&EM<&]S
M<VEB;&6@.B``26UP;W-S:6)L92!D92!C:&EF9G)E<B!L92!M97-S86=E(&%V
M96,@4R]-24U%+@!3:6=N871U<F4@4R]-24U%(&1U(&UE<W-A9V4@:6UP;W-S
M:6)L92X`06IO=70@9'4@8V]N=&%C="`E<R!I;7!O<W-I8FQE+B``3F4@<&5U
M="!S92!C;VYN96-T97(@874@<V5R=F5U<B!,1$%0+@!6Z7)I9FEC871I;VX@
M9&4@;&$@8F%L86YC92`E<R!I;7!O<W-I8FQE+B``R6-H96,@9&4@;&$@8V]N
M;F5X:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H96,@9&4@;&$@8V]N;F5X:6]N
M(&%U('-E<G9E=7(@JZ`E<Z"[('9I82!&5%"@.B`E<P!#<NEA=&EO;B!D92!L
M:7-T92!D92!D:7-T<FEB=71I;VX@:6UP;W-S:6)L92X@)7,`26UP;W-S:6)L
M92!D92!DZ6-H:69F<F5R(&QE<R!D;VYNZ65S(%!'4*`Z(`!);7!O<W-I8FQE
M(&1E(&3I8VAI9F9R97(@;&5S(&1O;F[I97,@4R]-24U%+@!.92!P975T('!A
M<R!S=7!P<FEM97(@;&4@8V]N=&%C="`E<P!.92!P975T('!A<R!S=7!P<FEM
M97(@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N("5S`$YE('!E=70@<&%S('-U
M<'!R:6UE<B!L92!S8W)I<'0@9&4@;6ES92#@(&IO=7(@JZ`E<Z"[+@!$Z71E
M<FUI;F%T:6]N(&1E(&PG861R97-S92!D=2!D97-T:6YA=&%I<F4@:6UP;W-S
M:6)L92X`3F4@<&5U="!RZ6-U<.ER97(@=&]U="!L92!C87)N970@9"=A9')E
M<W-E+@!.92!P975T('+I8W5PZ7)E<B!T;W5T92!L82!L:7-T92!D92!D:7-T
M<FEB=71I;VXN`$XG82!P87,@<'4@<NEC=7#I<F5R(&QA(&QI<W1E(&-O;7!L
MZ'1E(&1E(&QI<W1E<R!D92!D:7-T<FEB=71I;VXN`$EM<&]S<VEB;&4@9&4@
M8VAA<F=E<B!L82!S=')A=.EG:64@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(&-R
MZ65R(&QE('+I<&5R=&]I<F4@JZ`E<Z"[+@!);7!O<W-I8FQE(&0G;V)T96YI
M<B!L82!C;&5F('!U8FQI<75E(.`@<&%R=&ER(&1U('-E<G9E=7(@9&4@8VQE
M9G,N`$]U=F5R='5R92!D92"KH"5SH+L@:6UP;W-S:6)L92!E;B#I8W)I='5R
M92X`3W5V97)T=7)E(&1E("5S(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9"=O
M=79R:7(@;&4@;6]D=6QE($UA:6YT96YA;F-E7U1A<VL@)7,`3W5V97)T=7)E
M(&1U(&1O<W-I97(@JZ`E<Z"[(&EM<&]S<VEB;&4N`$EM<&]S<VEB;&4@9"=A
M='1E:6YD<F4@;&4@<V5R=F5U<B!,1$%0+@!,96-T=7)E(&1E("5S(&EM<&]S
M<VEB;&4N(`!.)V$@<'4@<F5M971T<F4@X"!ZZ7)O(&QE(&UO="!D92!P87-S
M92!P;W5R(&PG=71I;&ES871E=7(@9&5M86YDZ2X@0V5R=&%I;G,@*&]U('1O
M=7,I(&QE<R!DZ71A:6QS(&YE('-O;G0@<&%S(&-O<G)E8W1S+B!2Z65S<V%Y
M97H@;W4@8V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T<F%T975R('!O=7(@9&4@
M;"=A:61E+@!2Z6-U<.ER871I;VX@9&5S($%#3"!I;7!O<W-I8FQE`$YE('!E
M=70@<NEC=7#I<F5R(&QE(&-A<FYE="!D)V%D<F5S<V5S+B`E<P!.92!P975T
M('+I8W5PZ7)E<B!L82!L:7-T92!D92!D:7-T<FEB=71I;VXN("5S`$YE('!E
M=70@<NEC=7#I<F5R(&QE<R!L:7-T97,@9&4@9&ES=')I8G5T:6]N+B`E<P!.
M92!P975T('+I8W5PZ7)E<B!L97,@<&]S<VEB:6QI=.ES(&1U('-E<G9E=7(`
M3F4@<&5U="!P87,@<F5V96YI<B#@(&QA(&-O;F9I9W5R871I;VX@<'+I8^ED
M96YT92X`169F86-E;65N="!D=2!D;W-S:65R(*N@)7.@NR!I;7!O<W-I8FQE
M+B``3F4@<&5U="!P87,@96YR96=I<W1R97(@;&$@8V]N9FEG=7)A=&EO;B`E
M<P!.92!P975T('!A<R!E;G)E9VES=')E<B!U;F4@<V%U=F5G87)D92!D92!L
M82!C;VYF:6=U<F%T:6]N+@!);7!O<W-I8FQE(&0G96YR96=I<W1R97(@=6YE
M(&-O<&EE(&1E(&QA(&-O;F9I9W5R871I;VZ@.B`E<P!);7!O<W-I8FQE(&0G
M96YR96=I<W1R97(@;&4@<V-R:7!T(&1E(&UI<V4@X"!J;W5R(&1A;G.@.B"K
MH"5SH+LN`$EM<&]S<VEB;&4@9"=E;G)E9VES=')E<B!U;F4@8V]P:64@9'4@
M9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+@!);7!O<W-I8FQE(&0G96YR
M96=I<W1R97(@;&4@9FEC:&EE<B!D92!C;VYF:6=U<F%T:6]N("5S+B!6;W5S
M('!O=79E>B!S;VET('5T:6QI<V5R('5N92!D97,@;W!T:6]N<R!P;W5R('-A
M=79E<B!L92!C;V1E('-U<B`E<R!S;VET(&-O<&EE<B!M86YU96QL96UE;G0@
M;&4@8V]D92!C:2UD97-S;W5S(&1A;G,@)7,N`$YE('!E=70@<&%S(')E8VAE
M<F-H97(@;&4@<V5R=F5U<B!,1$%0+@!3=7!P<F5S<VEO;B!D92"KH"5SH+L@
M:6UP;W-S:6)L92X`36ES92#@(&IO=7(@9'4@8V]N=&%C="!I;7!O<W-I8FQE
M+B`E<P!.92!P975T(&UE='1R92#@(&IO=7(@;&$@;&ES=&4@9&4@9&ES=')I
M8G5T:6]N+B`E<P!.92!P975T('!A<R!E;G)E9VES=')E<B!L82!C;VYF:6=U
M<F%T:6]N('!O=7(@JZ`E<Z"[H#H@)7,`3F4@<&5U="!T<F]U=F5R(&QA(&)A
M<G)E(&1E($UO>FEL;&$N("!!<W-U<F5Z+79O=7,@<74G96QL92!E<W0@86-T
M:79E+@!.92!P975T(&%T=')I8G5E<B!C97,@9')O:71S(.`@;"=U=&EL:7-A
M=&5U<B"KH"5SH+L@('-U<B!L92!D;W-S:65R(*N@)7.@NZ`Z("5S`%1E>'1E
M(&-O;7!TZ0!087ES`$-O=7)S`$-RZ65R`$-RZ65R('5N(&QI96X`0W+I97(@
M=6X@;F]U=F5A=0!#<NEE<B!U;B!S;W5S+61O<W-I97(`4&5R;6ES<VEO;G,@
M1&4@0W+I871E=7(`3G5MZ7)O(&1E(&-A<G1E(&1E(&-RZ61I=`!#<F]A=&EE
M`$-U8F$`-"!P:&%S97,@8V]U<F%N=&5S`%-E<W-I;VYS(&5N(&-O=7)S`$AE
M=7)E(&%C='5E;&QE`$PG861R97-S92!54DP@86-T=65L;&4@97-T`%5T:6QI
M<V%T975R<R!A8W1U96QS`$]B<V5R=F%T:6]N<R!A8W1U96QL97,`0V]N9&ET
M:6]N(&%C='5E;&QEH#H@`%-T>6QE(&-O=7)A;G0`1.EF:6YI<B!L97,@=.)C
M:&5S(.`@969F96-T=65R(&QO<G,@9&4@;&$@8V]N;F5X:6]N(.`@)7,N`$-O
M=7!E<@!#;W5P97(@;&$@<^EL96-T:6]N`$-H>7!R90!#>7)I;&QI<75E("A+
M3TDX+5(I`$-Y<FEL;&EQ=64@*%=I;F1O=W,M,3(U,2D`0WER:6QL:7%U92]5
M:W)A:6YI96X@*$M/23@M52D`4NEP=6)L:7%U92!48VCH<75E`$I*`$133B`H
M0V8N(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T
M86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`0VAA<75E(&IO=7(`3F%V:6=A=&5U
M<B!D92!$871A5')E90!!;&EA<R!D92!L82!B87-E`$1A=&4`1&%T92!D92!R
MZ6-E<'1I;VX`4^EL96-T:6]N(&0G=6YE(&1A=&4`2F]U<@!3=7!P<FEM97(@
M7VQA(&-O;&]N;F4`1.EC96UB<F4`3F]M8G)E<R!DZ6-I;6%U>`!$:6UI;G5E
M<B!L)VEN9&5N=&%T:6]N`$3I9F%U=`!#;W5L975R('!A<B!DZ69A=70`261E
M;G1I=.D@<&%R(&3I9F%U=`!);G1E<G!RZ71E=7(@9&4@8V]M;6%N9&4@<&%R
M(&3I9F%U=`!$Z69I;FET:6]N<P!%9F9A8V5R`$5F9F%C97(@;&$@8V5L;'5L
M90!3=7!P<FEM97(@=6X@9W)O=7!E`$5F9F%C97(@;&$@=')A8V4`4W5P<')I
M;65R('5N92!P97)M:7-S:6]N`%-U<'!R:6UE<B!E="!P=7)G97(@;&5S(&UE
M<W-A9V5S`$5F9F%C97(@;&$@8V5L;'5L90!%9F9A8V5R(&QA(&-O;&]N;F4`
M4W5P<')I;65R('5N(&%U=')E(&UO9.AL92!E>&ES=&%N=`!3=7!P<FEM97(@
M;&5S(&UE<W-A9V5S`%-U<'!R:6UE<B!L97,@<&5R;6ES<VEO;G,@<&]U<B"K
MH"5SH+L`RG1E<RUV;W5S(&-E<G1A:6X@9&4@=F]U;&]I<B!E9F9A8V5R(*N@
M)7.@NR!E="!S97,@<V]U<RUP97)M:7-S:6]N<Z`_`$5F9F%C97(@;&$@<F%N
M9^EE`%-U<'!R:6UE<B!L)VED96YT:73I('/I;&5C=&EO;F[I90!3=7!P<FEM
M97(@=6X@<V]U<RUD;W-S:65R`$5F9F%C97(@;&$@8V]L;VYN92!A8W1U96QL
M90!%9F9A8V5R(&QA(')A;F?I92!A8W1U96QL90!38W)I<'0@9&4@8V]N9FEG
M=7)A=&EO;B!D92!M:7-E(.`@:F]U<B!S=7!P<FEMZ2"KH"5SH+LN`$AE=7)E
M(&1E(&QI=G)A:7-O;@!$86YE;6%R:P!$Z6-R:7)E(&QE('!R;V)LZ&UE`$1E
M<V-R:7!T:6]N`$3I=&%I;',@*&%U<W-I(&1A;G,@;&4@9FEC:&EE<B!D92!T
M<F%C97,@9&4@2&]R9&4IH#H`3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=N
MZ7,@<&]U<B!L)V%D;6EN:7-T<F%T975R+@!$Z79E;&]P<&5M96YT`%!O:6YT
M(&1E(')O<^EE`%!O:6YT(&1E(')O<^EE('!O=7(@;&$@9&5R;FGH<F4@:&5U
M<F6@.B``4&]I;G0@9&4@<F]SZ66@.B``1&4@9V%U8VAE(.`@9')O:71E`$1E
M(&1R;VET92#@(&=A=6-H90!2Z7!E<G1O:7)E`$%F9FEC:&5R('-U<B`R-"!H
M975R97.@/P!/<'1I;VYS(&0G869F:6-H86=E`$%F9FEC:&5R(&QA('!RZ79I
M<VEO;B!DZ71A:6QLZ64`069F:6-H97(@;&$@<'+I=FES:6]N("A4048I`$9O
M<FUA="!D)V%F9FEC:&%G90!!=FES(&1E(&QI=G)A:7-O;@!$:FEB;W5T:0!.
M92!P87,@<W5P<')I;65R`$YE('!A<R!A8V/I9&5R(&1I<F5C=&5M96YT(.`@
M;6%I;G1E;F%N8V4N<&AP`$QE('!R96UI97(@96YR96=I<W1R96UE;G0@8V]N
M=&EE;G0M:6P@;&4@;F]M(&1E<R!C:&%M<'.@/R!$86YS(&PG869F:7)M871I
M=F4L(&-O8VAE>B!C971T92!B;^YT9:`Z`$1O;6EN:7%U90!2Z7!U8FQI<75E
M(&1O;6EN:6-A:6YE`%9O=7,@;B=A=F5Z('!A<R!D92!C;VUP=&6@/R!%;G)E
M9VES=')E>BUV;W5S+@!4Z6SI8VAA<F=E<@!4Z6SI8VAA<F=E<B`E<P!4Z6SI
M8VAA<F=E<B!L82!C;VYF:6=U<F%T:6]N(&?I;NERZ64@8V]M;64@=6X@<V-R
M:7!T(%!(4`!,:7-T92!DZ7)O=6QA;G1E`$1R;V=U97,`0V]U<G)I97(@Z6QE
M8W1R;VYI<75E`%!I;&]T92!D92!P87-S97)E;&QE(&-O=7)R:65R("\@4TU3
M+"!P;W5R(&QE<R!F;W5R;FES<V5U<G,@9&4@8V4@<V5R=FEC92X`15)2`,EQ
M=6%T975R`$UO9&EF:65R`,ED:71E<B!L92!B;&]C`,ED:71E<B!U;B!G<F]U
M<&4`R61I=&5R('5N92!P97)M:7-S:6]N`,ED:71E<B!L97,@<&5R;6ES<VEO
M;G,`R61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R(*N@)7.@NP#)9&ET97(@
M;&5S(&]P=&EO;G,@<&]U<J`Z`,ED:71E<B!L97,@<&5R;6ES<VEO;G,@<&]U
M<B"KH"5SH+L`R61I=&5R(&QE<R!P97)M:7-S:6]N<R!P;W5R("5S`,ED=6-A
M=&EO;@#)9WEP=&4`4V%L=F%D;W(`R6SI;65N="XN+@!%;0!!9')E<W-E(.EL
M96-T<F]N:7%U90!!9')E<W-E(.EL96-T<F]N:7%U90!,97,@861R97-S97,@
MZ6QE8W1R;VYI<75E<R!D;VEV96YT(&-O<G)E<W!O;F1R92X`0V]U<G)I97(@
M879E8R!C;VYF:7)M871I;VX`4&%S<V5R96QL92!C;W5R<FEE<B`O(%--4P#)
M;6]T:6/T;F5S`$UE<W-A9V4@=FED92X`4NES=6QT870@=FED92X`5&5R;65S
M(&1E(')E8VAE<F-H92!V:61E`$%C=&EV97(@;"=I;G-E<G1I;VX@9"=I;6%G
M97,@=F5N86YT(&1E<R!A;&)U;7,@<&AO=&]S(&1A;G,@;&4@=&5X=&6@/P!!
M8W1I=F5R(&QE(&UE;G4@8V]N=&5X='5E;"!A=F5C('5N(&-L:6,@9')O:72@
M/P!&:6X@9&4@;"=A;F[I90!!9W)A;F1I<B!L)^ED:71E=7(`R6-R:79E>B!U
M;F4@<75E<W1I;VX@9&4@<^EC=7)I=.D@<74G;VX@=F]U<R!P;W-E<F$@<VD@
M=F]U<R!D979E>B!R96UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E
M+"!P87(@97AE;7!L92"K(%%U96P@97-T(&QE(&YO;2!D92!V;W1R92!A;FEM
M86P@<'+I9NERZ:`_H+N@.@!);G-C<FEV97H@;"=A9')E<W-E(%523"!D92!L
M)VEM86=E(&EC:0!%;G1R97H@;&5S(&QE='1R97,@8VDM9&5S<V]U<Z`Z`$=U
M:6[I92#I<75A=&]R:6%L90#)<GET:'+I90!%<G)E=7(`17)R975R(&QO<G,@
M9&4@;&$@8W+I871I;VX@9'4@8FQO8Z`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA
M('-U<'!R97-S:6]N(&1E(&PG86YC<F4@9&4@<WEN8VAR;VYI<V%T:6]NH#H@
M)7,`17)R975R(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9'4@:F]U<FYA;"!D
M92!S>6YC:')O;FES871I;VZ@.B`E<P!%<G)E=7(@;&]R<R!D92!L82!RZ6-U
M<.ER871I;VX@9'4@8V]N=&5N=:`Z("5S`$5R<F5U<B!L;W)S(&1E(&QA(&UI
M<V4@X"!J;W5R(&1U(&UO="!D92!P87-S9:`Z("5S`$5R<F5U<B!A=F5C(&QE
M(&UE<W-A9V4N`$5R<F5U<B!L;W)S(&1E(&PG96YR96=I<W1R96UE;G0@9&4@
MJZ`E<Z"[+@!%<W1O;FEE`,ET:&EO<&EE`$5T:&YI<75E`$5U<F]P90!4;W5S
M(&QE<R`F9G)A8S$T.R!D)VAE=7)E`%1O=71E<R!L97,@,B!M:6YU=&5S`%1O
M=71E<R!L97,@,S`@<V5C;VYD97,`5&]U=&5S(&QE<R`U(&UI;G5T97,`P"!C
M:&%Q=64@8V]N;F5X:6]N`%1O=71E<R!L97,@)F9R86,Q,CL@:&5U<F5S`%1O
M=71E<R!L97,@;6EN=71E<P!%>&5M<&QE(&1E('9A;&5U<G.@.@!%>.EC=71E
M<@!$Z79E;&]P<&5R`$3I<&QI97(@;&$@8F%R<F4@9&4@8_1TZ0"K("D@NR!A
M='1E;F1U90!5;B!S975L(&UO="!O=2!E>'!R97-S:6]N(&5N=')E(&=U:6QL
M96UE=',@871T96YD=7,`1&%T92!D)V5X<&ER871I;VX`4F5P<NES96YT86YT
M`$-O=6QE=7(@9"=A=F%N="UP;&%N`%3I;.EC:&%R9V5M96YT('9E<G,@;&4@
M<V5R=F5U<B!D92!L82!C;VYF:6=U<F%T:6]N('!A<B!&5%``3&5C='5R92!D
M97,@<'+I9NER96YC97,@:6UP;W-S:6)L92X`R6-H96,@9&4@;&$@8V]N;F5X
M:6]N(&%U('-E<G9E=7(@3$1!4"X`R6-H96,@9&4@;&$@8V]N;F5X:6]N(&%U
M('-E<G9E=7(@4TU"+@#)8VAE8R!D92!L82!C;W!I92!D97!U:7,@JZ`E<Z"[
M+@#)8VAE8R!D92!L82!C;W!I92!V97)S(""KH"5SH+LN`$EM<&]S<VEB;&4@
M9&4@8W+I97(@=6YE(&YO=79E;&QE(&-O;FYE>&EO;B!305-,`,EC:&5C(&1U
M(&3I<&QA8V5M96YT('9E<G,@JZ`E<Z"[+@#)8VAE8R!L;W)S(&1E(&QA('+I
M8W5PZ7)A=&EO;J`Z("5S`$)E874`SFQE<R!&86QK;&%N9"`H36%L;W5I;F5S
M*0#.;&5S($;I<F_I`$5R<F5U<B!F871A;&6@.@!&87@`5.ELZ6-O<&EE<P!&
MZ79R:65R`%1E;7#I<F%T=7)E(')E<W-E;G1I90!496UPZ7)A='5R92!R97-S
M96YT:66@.B``475E;'%U97,@879E<G-E<P!1=65L<75E<R!C:'5T97,@9&4@
M;F5I9V4`36%T<FEC92!D97,@8VAA;7!S`$9I9VQE="!#05!40TA!`%!O;&EC
M92!D92!L82`\23YF:6=L970\+TD^`$9I9&II`$9I8VAI97(`3F]M8G)E(&1E
M(&9I8VAI97)SH#H@)7,`3F]M8G)E(&1E(&9I8VAI97)SH#H@)7,`1V5S=&EO
M;FYA:7)E(&1E(&9I8VAI97)S`$YO;2!D=2!F:6-H:65R`$-H;VEX(&1E(&9I
M8VAI97(`5.ELZ6-H87)G96UE;G0@9&4@9FEC:&EE<@!,)V5N=F]I(&1E(&9I
M8VAI97)S(&XG97-T('!A<R!P<FES(&5N(&-O;7!T92X`1FEL=')E<P!&:6YL
M86YD90!0<F5M:>AR92!D96UI90!0<F5M:65R('%U87)T:65R`$9I>&5R(&QE
M(')A=&EO`%)E=&]U<FYE<@!&;&]T=&%N=`!"<F]U:6QL87)D`$1O<W-I97(@
M)7,@:6YE>&ES=&%N="X`0V]U;&5U<B!D92!P;VQI8V4`3F]U<G)I='5R90!0
M;W5R(&QE<R!N879I9V%T975R<R!N92!S=7!P;W)T86YT('!A<R!L97,@:6UA
M9V5S`%!RZ79I<VEO;B`H5$%&*0!*;W5R<R!D92!P<NEV:7-I;VX@*&YO=&5Z
M('%U92!L97,@<'+I=FES:6]N<R!F;W5R;FEE<R!D;VYN96YT(&QE(&IO=7(@
M970@;&$@;G5I=*`[('5N(&=R86YD(&YO;6)R92!I8VD@<&5U="!F86ER92!U
M;B!B;&]C('1RZ',@;&%R9V4`5F]U<R!A=F5Z(&]U8FQIZ2!V;W1R92!M;W0@
M9&4@<&%S<V6@/P!&;W)M=6QA:7)E<P!#:71A=&EO;@!4>7!E(&1E(&-I=&%T
M:6]N`$-I=&%T:6]N<P!#:71A=&EO;G,@,@!&;W)U;7,`4F5D:7)E8W1I;VX`
M5F4`0V%D<F5S`$9R86YC90!&<F%N8V4@;>ET<F]P;VQI=&%I;F4`1W5Y86YE
M(&9R86[G86ES90!0;VQY;NES:64@9G)A;N=A:7-E`%1E<G)E<R!A=7-T<F%L
M97,@970@86YT87)C=&EQ=65S(&9R86[G86ES97,`1&4`1'4@`$1E<V-R:7!T
M:6]N(&-O;7!LZ'1E`%!L96EN92!L=6YE`$YO;2!C;VUP;&5T`$=A8F]N`$%L
M8G5M(&0G;W)I9VEN92!D92!L)VEM86=E`$%L8G5MH#H`1V%M8FEE`$?I;NER
M97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!#;V1E(&?I;NERZ0!'Z6]R9VEE
M`$%L;&5M86=N90!':&%N80!':6)R86QT87(`4'+I;F]M`$]P=&EO;G,@9VQO
M8F%L97,`06QL97(`1V]E9&5L`$-A<G1E<R!';V]G;&4`4F5C:&5R8VAE($=O
M;V=L90!.:79E874@9&4@9W)I<P!'<NAC90!'<F5C("A)4T\M.#@U.2TW*0!'
M<F_K;FQA;F0`1W)E;F%D90!!9&UI;FES=')A=&EO;B!D97,@9W)O=7!E<P!,
M97,@;F]M<R!D92!G<F]U<&4@;F4@<&5U=F5N="!P87,@ZG1R92!V:61E<P!'
M<F]U<%]L9&%PH#H@:6UP;W-S:6)L92!D)V%J;W5T97(@;&4@9W)O=7!E("5S
M+B!#96-I(&5S="!L82!RZ7!O;G-E(&1U('-E<G9E=7*@.@!'<F]U<%]L9&%P
MH#H@<W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!G<F]U<&4@)7,`1W)O=7!?
M;&1A<*`Z(&UO9&EF:6-A=&EO;B!I;7!O<W-I8FQE(&1U(&=R;W5P92`E<P!'
M<F]U<&5S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYE<V5Y`%!E
M<FUI<W-I;VYS(&1E<R!I;G9I=.ES`$QI=G)E(&0G;W(`1W5I;NEE`$=U:6[I
M92U":7-S874`1W5Y86YA`$A434P`2%1-3$%R96$@<F5F=7-E(&+J=&5M96YT
M(&1E('-U<'!R:6UE<B!L82!D97)N:>AR92!C96QL=6QE(&1E(&QA(')A;F?I
M90!(5$U,07)E82!R969U<V4@8NIT96UE;G0@9&4@<W5P<')I;65R(&QA(&1E
M<FYIZ')E(&-O;&]N;F4@9'4@=&%B;&5A=0!(5$U,07)E82!R969U<V4@8NIT
M96UE;G0@9&4@<W5P<')I;65R(&QA(&1E<FYIZ')E(')A;F?I92!D=2!T86)L
M96%U`$%U=&AE;G1I9FEC871I;VX@2%144"!N;VX@=')O=7;I92X`2&'O=&D`
M06QG;W)I=&AM92!D92!H86-H86=E`$)R=6UE('/H8VAE`$5N+73J=&4`16XM
M=.IT97,`SFQE<R!(96%R9"!E="!-8T1O;F%L9`!/<F%G97,@=FEO;&5N=',`
M2.EB<F5U("A)4T\M.#@U.2TX+4DI`$AA=71E=7(`06ED90!!:61E('!O=7(@
M;"?I9&ET975R`$%I9&4`2.EM:7-P:.AR90!6;VEC:2!L92!DZ6)U="!D=2!F
M:6-H:65RH#H`2&%U=&4`05]C8W5E:6P`0VETZ2!D=2!6871I8V%N`$%C8W5E
M:6P`061R97-S92!P97)S;VYN96QL90!2Z7!E<G1O:7)E('!E<G-O;FYE;`!4
MZ6SI<&AO;F4@<&5R<V]N;F5L`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(
M;W)D92]+;VQA8J`Z(&1O;F[I97,@6$U,("5S(&EN=F%L:61E<R!R971R;W5V
MZ65S(&1A;G,@;&4@;65S<V%G92`E<P!(;W)D92]+;VQA8J`Z(&%U8W5N(&UE
M<W-A9V4@;F4@8V]R<F5S<&]N9"!A=2!S=6IE="`E<P!(;W)D92]+;VQA8J`Z
M('!A<R!D)V]B:F5T(&1E('1Y<&4@)7,@=')O=7;I(&1A;G,@;&4@;65S<V%G
M92`E<P!(;W)D92]+;VQA8J`Z("5S('-U<'!R:6WI(*N@)7.@NR!A=F5C('-U
M8V/H<P!(;W)D92]+;VQA8J`Z(&QE(&UO=&5U<B!D)VEN=.EG<F%T:6]N(&[I
M8V5S<VET92!L)V5X=&5N<VEO;B`G9&]M>&UL)R!D92!02%``2&]R9&4O2V]L
M86*@.B!I;7!O<W-I8FQE(&1E(&-RZ65R('5N(&YO=79E;"!A<F)R92!834P@
M<&]U<B!L)V]B:F5T("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S:6)L92!D)V5N
M;&5V97(@)7,@JZ`E<Z"[H#H@)7,`2&]R9&4O2V]L86*@.B!I;7!O<W-I8FQE
M(&1E('+I8W5PZ7)E<B!L)VED96YT:69I86YT($U)344@<&]U<B!L82!P87)T
M:64@9&4@='EP92`E<P!(;W)D92]+;VQA8J`Z(&EM<&]S<VEB;&4@9&4@<WEN
M8VAR;VYI<V5R("5S(*N@)7.@NZ`Z("5S`$AO<F1E+TMO;&%BH#H@:6UP;W-S
M:6)L92!D92!S>6YC:')O;FES97(@;&5S('!A<G1A9V5SH#H@)7,`2&]R9&4O
M2V]L86*@.B!P87)T86=E(&EN8V]N;G4@JZ`E<Z"[`$QI9VYE(&AO<FEZ;VYT
M86QE`%)E;7!L:7-S86=E(&AO<FEZ;VYT86P`2&]R:7IO;G1A;*`Z`$-O;6UE
M;G0@ZG1E<RUV;W5S(&%R<FEVZ2!I8VF@/R`H4U90(')A<'!O<G1E>BUL9:`A
M*0!#;VUB:65N(&1E(&-O;&]N;F5S('9O=6QE>BUV;W5S(&9U<VEO;FYE<J`_
M`$-O;6)I96X@9&4@8VAA;7!S("AC;VQO;FYE<RD@>2!A+70M:6R@/P!#;VUB
M:65N(&1E(')A;F?I97,@=F]U;&5Z+79O=7,@9G5S:6]N;F5RH#\`2'5M:61I
M=.D`2'5M:61I=.F@.B``2'5M;W)I<W1E<P!(;VYG<FEE`,EC:&5C(&QO<G,@
M9&4@;&$@8W+I871I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S`,EC:&5C(&QO
M<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@;&$@8F_N=&4@24U!4*`Z("5S`,EC
M:&5C(&QO<G,@9&4@;&$@8W+I871I;VX@9'4@<75O=&$@<W5R(&QA(&)O[G1E
M($E-05"@.B`E<P!!9')E<W-E($E0`$%D<F5S<V4@25`@;F]N(&1I<W!O;FEB
M;&4N`$%D<F5S<V4@25`@:&]R<R!D=2!B;&]C($-)1%(@86QL;W7I+@!6:6]L
M871I;VX@9&4@8FQO8V%G92!)4"X`25]N<^ER97(@<F%N9^EE(&%V86YT`$ES
M;&%N9&4`26/T;F5S('-E=6QE;65N=`!)8_1N97,@<&]U<B`E<P!)8_1N97,@
M<&QU<R!T97AT90!.;VT@9'4@8V]M<'1EH#H`4VD@;"=A9F9I8VAA9V4@;B=E
M<W0@<&%S(&-O<G)E8W0L("5S('!O=7(@;"=O=79R:7(@9&%N<R!U;F4@;F]U
M=F5L;&4@9F5NZG1R92X`4VD@=F]U<R!N92!V;WEE>B!A=6-U;B!I8_1N92!E
M;B!U=&EL:7-A;G0@26YT97)N970@17AP;&]R97(L('9O=7,@<&]U=F5Z(&%V
M;VER(.`@8V]C:&5R(&-E='1E(&-A<V4@<&]U<B!DZ7-A8W1I=F5R(&QA('1R
M86YS<&%R96YC92!D97,@4$Y'+@!3:2!V;W5S('9O>65Z(&-E(&UE<W-A9V4@
M;6%I<R!A=6-U;F4@:6UA9V4L(&PG:6UA9V4@<75E('9O=7,@=F]U;&5Z(&5N
M=F]Y97(@;F4@<&5U="#J=')E(&%F9FEC:.EE('!A<B!V;W1R92!N879I9V%T
M975R+@!!<&5RYW4@9&4@;"=I;6%G9:`Z`$%D<F5S<V4@55),(&1E(&PG:6UA
M9V4`061R97-S92!54DP@9&4@;"=I;6%G9:`Z`$EM86=E(&1E(&PG86QB=6T`
M26UA9V4@9&4@;"=A;&)U;:`Z`%3I;.EC:&%R9V5M96YT(&0G:6UA9V5S`$EM
M86=E<P!);7!O<G1A=&EO;BP@Z71A<&4@)60`0VAA;7`@:6UP;W)TZ:`Z("5S
M`$-H86UP<R!I;7!O<G3I<Z`Z`$EN7W/I<F5R(')A;F?I92!A<'+H<P!#;V1E
M(&0G86-T:6]N(&EN8V]R<F5C="X`3F]M(&0G=71I;&ES871E=7(@970O;W4@
M=F]T<F4@;6]T(&1E('!A<W-E(&EN8V]R<F5C="X`3F]M(&0G=71I;&ES871E
M=7(@;W4@861R97-S92!A;'1E<FYA=&EV92!I;F-O<G)E8W0N("!2Z65S<V%Y
M97H@;W4@8V]N=&%C=&5Z('9O=')E(&%D;6EN:7-T<F%T975R('-Y<W3H;64@
M<&]U<B!D92!L)V%I9&4N`$%U9VUE;G1E<B!L)VEN9&5N=&%T:6]N`$EN9&4`
M571I;&ES871E=7)S(&EN9&EV:61U96QS`$EN9&]NZ7-I90!);F9O`$EN9F]R
M;6%T:6]N<P!,)VEN9F]R;6%T:6]N(&XG97-T('!L=7,@9&ES<&]N:6)L92X`
M26YSZ7)E<B!C7V]L;VYN92!A<'+H<P!);G/I<F5R(&EM86=E`$EN<^ER97(@
M=6X@=&%B;&5A=0!);G/I<F5R('5N(&QI96X@=V5B`$EN<^ER97(@7V-O;&]N
M;F4@879A;G0`26YSZ7)E<B!U;F4@;F]U=F5L;&4@8V]L;VYN92!A<'+H<R!L
M82!C;VQO;FYE(&%C='5E;&QE`$EN<^ER97(@=6YE(&YO=79E;&QE(&-O;&]N
M;F4@879A;G0@;&$@8V]L;VYN92!A8W1U96QL90!);G/I<F5R('5N92!N;W5V
M96QL92!R86YGZ64@87!RZ',@;&$@<F%N9^EE(&%C='5E;&QE`$EN<^ER97(@
M=6YE(&YO=79E;&QE(')A;F?I92!A=F%N="!L82!R86YGZ64@86-T=65L;&4`
M26YSZ7)E<B!U;B!P87)A9W)A<&AE(&%P<NAS(&QE(&XF;V5L:6<[=60@86-T
M=65L`$EN<^ER97(@=6X@<&%R86=R87!H92!A=F%N="!L92!N)F]E;&EG.W5D
M(&%C='5E;`!);G/I<F5R('5N(&%U=')E(&UO9.AL90!);G-C<FEV97H@=6YE
M(&%D<F5S<V4@9&4@8V]U<G)I97(@X"!L87%U96QL92!V;W5S(')E8V5V<F5Z
M(&QE(&YO=79E874@;6]T(&1E('!A<W-EH#H`26YSZ7)E<B!C96QL=6QE(&%P
M<NAS`$EN<^ER97(@8V5L;'5L92!A=F%N=`!);G/I<F5R(&-O;&]N;F4@87!R
MZ',`26YSZ7)E<B!C;VQO;FYE(&%V86YT`$EN<^ER97(@;&5S(&UE<W-A9V5S
M`$EN<^ER97(@<&%R86=R87!H92!A<'+H<P!);G/I<F5R('!A<F%G<F%P:&4@
M879A;G0`26YSZ7)E<B!R86YGZ64@87!RZ',`26YSZ7)E<B!R86YGZ64@879A
M;G0`26YS8W)I=F5Z(&QA('+I<&]N<V4@X"!L82!Q=65S=&EO;B!D92!SZ6-U
M<FETZ:`Z`$EN<^ER97(O36]D:69I97(@=6YE(&EM86=E`$EN<^ER97(O36]D
M:69I97(@=6X@;&EE;B!W96(`0W+I9&ET(&EN<W5F9FES86YT('!O=7(@96YV
M;WEE<B#@(&QA(&QI<W1E(&1E(&1I<W1R:6)U=&EO;BX`0W+I9&ET(&EN<W5F
M9FES86YT+@!%;G1I97(`3&ES=&4@8V]M<&SH=&4`541(("A5<V5R($1A=&$@
M2&5A9&5R*2!I;G9A;&ED90!$;VYNZ64@6DE0(&EN=F%L:61E+@!!<'!L:6-A
M=&EO;B!I;G9A;&ED92X`1W)O=7!E($E$(&EN=F%L:61E+@!%;G9O:2!D92!D
M;VYNZ65S(&EN=F%L:61E<RX`061R97-S92!D92!D97-T:6YA=&EO;B!I;G9A
M;&ED92X`1F]R;6%T(&1E(&9I8VAI97(@:6YV86QI9&4N`$-L968@9&4@;&EC
M96YC92!I;G9A;&ED92X`16UP;&%C96UE;G0@:6YD:7%UZ2!I;G9A;&ED92X`
MJVUS9U]T>7!ENR!I;G9A;&ED92X`JV%P:5]I9+L@:6YV86QI9&4@;W4@;6%N
M<75A;G0N`%!A<F%MZ'1R97,@:6YV86QI9&5S(&]U(&UA;G%U86YT<RX`4&5R
M;6ES<VEO;B!I;G9A;&ED92X`260N(&1E('!A<G1E;F%I<F4@:6YV86QI9&4N
M`$-O9&4@9&4@<')O9'5I="!I;G9A;&ED92X`4')O=&]C;VQE(&EN=F%L:61E
M+@!$97-T:6YA=&%I<F4@:6YV86QI9&6@.B"KH"5SH+L`3V)J970@9&4@<&%R
M=&%G92!I;G9A;&ED90!!9')E<W-E('-O=7)C92!I;G9A;&ED92X`1&]N;NEE
M(%5N:6-O9&4@:6YV86QI9&4N`$EN=F5N=&%I<F4`26YV97)S97(@;&$@<^EL
M96-T:6]N`$ER86X`27)A:P!)<FQA;F1E`,YL92!D92!-86X`5&5M<.IT97,@
M:7-O;.EE<P!)<W)AZVP`R6UE='1E=7(`271A;&EQ=64`271A;&EE`$IA;6'O
M<75E`$IA;G9I97(`2F%P;VX`2F%P;VYA:7,@*$E33RTR,#(R+4I0*0!*97)S
M97D`2F]R9&%N:64`2G5I;&QE=`!*=6EN`$IU<W1I9FEE<@!#96YT<F5R`$IU
M<W1I9FEE<@!!;&EG;F5R(.`@9V%U8VAE`$%L:6=N97(@X"!D<F]I=&4`2V%Z
M86MH<W1A;@!'87)D97(@;"=O<FEG:6YA;*`_`$ME;GEA`$QE('-E<G9E=7(@
M2V5R8F5R;W,@82!R96IE=.D@;"=A=71H96YT:69I8V%T:6]N+@!$Z6)U=&%N
M=',@9'4@;F]Y874`0W+I871I;VX@9&4@8VQE9@!%;7!R96EN=&4@9&4@;&$@
M8VQE9@!,;VYG=65U<B!D92!L82!C;&5F`%1Y<&4@9&4@8VQE9@!5=&EL:7-A
M=&EO;B!D92!L82!C;&5F`$QA(&-L968@<V4@=')O=79E(&3I:N`@<W5R(&QE
M('-E<G9E=7(@9&4@8VQE9G,@<'5B;&EC+@!%;F9A;G1S`$MI<FEB871I`$-O
M<NEE(&1U($YO<F0`0V]RZ64@9'4@4W5D`$-O<NEE;B`H155#+4M2*0!+;W=E
M[W0`2VER9VAI>FES=&%N`%!RZ5]S96YT871I;VX`3&%N9W5E`$QA;W,`1&5R
M;FGH<F4@9&5M:64`1&5R;FGH<F4@;6]D:69I8V%T:6]N(&1U(&UO="!D92!P
M87-S90!$97)N:65R('%U87)T:65R`$1E<FYIZ')E(&UI<V4@X"!J;W5RH#H`
M1&5R;FGH<F4@8V]N;F5X:6]NH#H@)7,`1&5R;FGH<F4@8V]N;F5X:6]NH#H@
M)7,@X"!P87)T:7(@9&4@)7,`1&5R;FGH<F4@8V]N;F5X:6]NH#H@:F%M86ES
M`$QE='1O;FEE`$QO:0!0<NES96YT871I;VX`3&%I<W-E<B!V:61E('!O=7(@
M;F4@<&%S(&%V;VER(&1E(&)O<F1U<F4`3&EB86X`1V%U8VAE`$5N=.IT92!G
M875C:&4`5F%L975R<R!D92!G875C:&4`3&5S;W1H;P!.:79E874`3&EBZ7)I
M80!,:6)Y90!,:65C:'1E;G-T96EN`$)R=6EN92!LZ6?H<F4`4&QU:64@;.EG
MZ')E`%!L=6EE(&SI9^AR92!T]'0@9&%N<R!L82!J;W5R;NEE`%!L=6EE(&SI
M9^AR92!T87)D`$%V97)S97,@;.EGZ')E<P!0;'5I92!LZ6?H<F4@879E8R!T
M;VYN97)R90!.96EG92!I;G1E<FUI='1E;G1E`$%V97)S92!D92!N96EG92!L
MZ6?H<F4`4FEM97,`3&EE;@!,92!L:65N('!O:6YT92!V97)SH#H`3&EE(&PG
M861R97-S92!D92!C;W5R<FEE;"#@(&QA('!A9V4@9&4@8V]M<&]S:71I;VX@
M9'4@;65S<V%G92!E;B!L)V%F9FEC:&%N=`!,:65N<P!":7-C=6ET($QI;G5X
M`$QI<W1E("T@=71I;&ES871E=7(@<&5U="!V;VER(&QE(&1O<W-I97(`3&ES
M=&4@9&5S(&)A<V5S(&1E(&1O;F[I97,`26YD97@@9&4@;"=A:61E`$%F9FEC
M:&5R(&QE<R!T86)L97,`07)C:&EV97,@9&4@;&$@;&ES=&4`06ED92!D92!L
M82!L:7-T90!)9"X@9&4@;&$@;&ES=&4`4')O<')IZ71A:7)E(&1E(&QA(&QI
M<W1E`$5N=F]I(.`@;&$@;&ES=&4`06)O;FYE;65N="#@(&QA(&QI<W1E`$3I
M<V%B;VYN96UE;G0@9&4@;&$@;&ES=&4`R6-H96,@9&4@;&$@;&ES=&4@9&5S
M('-E<W-I;VYSH#H@)7,`R6-H96,@9&4@;&$@;&ES=&4@9&5S('5T:6QI<V%T
M975R<Z`Z("5S`$PG869F:6-H86=E(&1E(&QA(&QI<W1E(&1E<R!U=&EL:7-A
M=&5U<G,@97-T(&3I<V%C=&EVZ2X`3&ET=.ER871U<F4`3&ET=6%N:64`0VAA
M<F=E;65N="XN+@!(975R92!L;V-A;&6@.B``2&5U<F4@970@;&]C86QE`$QI
M974`0V]N;F5X:6]N`%1R86-E(&1E(&QA(&1E<FYIZ')E('-E<W-I;VX@9&4@
M<WEN8VAR;VYI<V%T:6]N`$3I8V]N;F5X:6]N`$-O;FYE>&EO;@!4XF-H97,@
M9&4@8V]N;F5X:6]N`$QA(&-O;FYE>&EO;B!E<W0@<F5F=7/I92X@26P@97-T
M('!R;V)A8FQE('%U92!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!O=2!V;W1R
M92!M;W0@9&4@<&%S<V4@82#I=.D@;6%L('-A:7-I`,EC:&5C(&1E(&-O;FYE
M>&EO;BX`5&5X=&4@;&]N9P!!;6]U<@!&86EB;&4`3&5T=')E(&=R96-Q=65S
M(&UI;G5S8W5L97,`3&5T=')E(&QA=&EN97,@;6EN=7-C=6QE<P!.;VUB<F4@
M<F]M86EN<R!M:6YU<V-U;&5S`$QU>&5M8F]U<F<`34T`365S<V%G92!D=2!J
M;W5R("A-3U1$*0!,82!P:>AC92!J;VEN=&4@35,M5$Y%1B!N92!C;VYT96YA
M:70@875C=6YE(&1O;F[I92X`35-'`$UA8V%O`%+I<'5B;&EQ=64@9&4@36%C
MZ61O:6YE`$UA9&%G87-C87(`36%G:64`0V]U<G)I97(`061M:6YI<W1R871I
M;VX@9'4@8V]U<G)I96P`1F%I<F4@=6X@;&EE7VX`36%L87=I`$UA;&%I<VEE
M`$UA;&1I=F5S`$UA;&D`36%L=&4`061M:6YI<W1R97H@;&$@;&ES=&4@9&4@
M8V%TZ6=O<FEE<R!E="!L97,@8V]U;&5U<G,@;&GI97,@X"!C97,@8V%TZ6=O
M<FEE<RX`0V%R=&4@JR!-87`R-""[`$-A<G1E(*L@36%P<75E<W0@NP!#;W)R
M97-P;VYD86YC97,@96YR96=I<W1RZ65S+@!-87)S`$UA<F=E`$UA<G%U97(@
M879E8R!D97,@Z71I<75E='1E<R!6=2].;VX@=G4`36%R<75E<B!A=F5C(&0G
M875T<F5S(.ET:7%U971T97,@*&5X+CH@26UP;W)T86YT+U+I<&]N9'4I`,YL
M97,@36%R<VAA;&P`36%R=&EN:7%U90!#:&%M<',@87!P87)E;G3I<P!-875R
M:71A;FEE`,YL92!-875R:6-E`$-RZ61I="!M87AI;75M(&%L;&]UZ2X`3&EM
M:71E(&1U(&UE<W-A9V4@9.EP87-SZ64N`%1E;7#I<F%T=7)E(&UA>&EM86QE
M(&1E<R`R-"!D97)N:>AR97,@:&5U<F5SH#H@`%1E;7#I<F%T=7)E(&UA>&EM
M86QE(&1E<R`V(&1E<FYIZ')E<R!H975R97.@.B``3F]M8G)E(&UA>&EM=6T@
M9&4@8FQO8W,@9'4@<&]R=&%I;`!,;VYG=65U<B!M87AI;75M`$UA:0!-87EO
M='1E`$WI9&EC86UE;G0`365M8G)E<P!4>7!E(&1E(&UE;G6@.@!&=7-I;VYN
M97(@;&5S(&-E;&QU;&5S`$UE<W-A9V4`5NER:69I8V%T:6]N(&1U(&UE<W-A
M9V4@<NEU<W-I92P@;6%I<R!L92!C97)T:69I8V%T(&1U('-I9VYA=&%I<F4@
M;B=A('!A<R!P=2#J=')E(';I<FEF:>DN`$UE<W-A9V4@97AP:7+I+@!4>7!E
M(&1E(&UE<W-A9V4`3>ETZ6\@365T87(`3&4@8FQO8R"K($UE=&%R(+L@;B=E
M<W0@<&%S(&1I<W!O;FEB;&4N`$QE(&)L;V,@JR!-971A<B"[(&XG97-T('!A
M<R!D:7-P;VYI8FQE+B`@3&5S(&3I=&%I;',@;VYT(.ETZ2!C;VYS:6=NZ7,@
M<&]U<B!L)V%D;6EN:7-T<F%T975R+@!-971A<D1"(&XG97-T('!A<R!C;VYN
M96-TZ2X`3>ET:&]D90!,82!MZ71H;V1E(*N@)7.@NR!N)V5S="!P87,@9.EF
M:6YI90!-Z71H;V1E(&YO;B!DZ69I;FEE+B!-Z71H;V1E(&%P<&5LZ66@.B`E
M<P!-Z71R:7%U90!-97AI<75E`,ET871S(&;I9.ERZ7,@9&4@36EC<F]NZ7-I
M90!-:6QI974`5'EP92!-24U%`%1E;7#I<F%T=7)E(&UI;FEM=6T@9&5S(#(T
M(&1E<FYIZ')E<R!H975R97.@.B``5&5M<.ER871U<F4@;6EN:6UU;2!D97,@
M-B!D97)N:>AR97,@:&5U<F5SH#H@`$QA(&1U<NEE(&UI;FEM86QE(&1U(&UO
M="!D92!P87-S92!N)V$@<&%S(&5N8V]R92!E>'!I<ND`36ER;VER`%9A<FGI
M<P!,92!P87%U971A9V4@2%144%]R97%U97-T(%!%05(@97-T(&UA;G%U86YT
M+@!#;VYF:6=U<F%T:6]N(&EN97AI<W1A;G1E+B!6;W5S(&1E=F5Z(&QA(&?I
M;NER97(@;6%I;G1E;F%N="!S:2!V;W5S('9O=6QE>B!U=&EL:7-E<B!C971T
M92!A<'!L:6-A=&EO;BX`240@9'4@;65S<V%G92!M86YQ=6%N="X`3&4@<&%Q
M=65T86=E(%!%05(@36%I;"!E<W0@;6%N<75A;G0N`$E$(&1E('-E<W-I;VX@
M;6%N<75A;G0N`$QU`$-O=7)R:65L('-A;G,@9FEL`$UO9.ERZ0!$871E(&1E
M(&UO9&EF:6-A=&EO;@!-;V1I9FEE<B!L)U523`!-;V1U;&\`36]L9&%V:64`
M36]N86-O`$UO;F=O;&EE`$UO:7,@970@86YNZ64`365N<W5E;&QE;65N=`!-
M;VYT<V5R<F%T`%!H87-E<R!D92!L82!L=6YE`$-H86UP<R!S=7!P;.EM96YT
M86ER97,@=')O=7;I<R#@(&QA(&QI9VYE("5D("AA='1E;F1U<R`E9"DN`$UA
M<F]C`$?I;NER86QE;65N="!E;G-O;&5I;&SI`$?I;NER86QE;65N="!N=6%G
M975X`%!R:6YC:7!A;&5M96YT(&YU86=E=7@@970@=F5N=&5U>`!'Z6[I<F%L
M96UE;G0@96YS;VQE:6QLZ0!697)S(&QE(&)A<P!$Z7!L86-E<B#@(&=A=6-H
M90!$Z7!L86-E<B#@(&1R;VET90!697)S(&QE(&AA=70`5F5R<R!L92!B87,`
M5F5R<R!L92!H875T`$UO>F%M8FEQ=64`3&ES=&5S(&3I<F]U;&%N=&5S(&UU
M;'1I+6YI=F5A=7@`0V%R=&4@JZ!-=6QT:6UA<"!52Z"[`%/I;&5C=&EO;B!M
M=6QT:7!L90!087)A;>ET<F%G92!D=2!C;VUP=&4`365S(&1O;F[I97,@<&5R
M<V]N;F5L;&5S`$UO;B!P;W)T86EL`%!RZ7-E;G1A=&EO;B!D92!M;VX@<&]R
M=&%I;`!":7)M86YI90!.3TXL(&IE(&XG86-C97!T92!P87,`3F]M`$YA;6EB
M:64`3F%U<G4`3NEP86P`4&%Y<RU"87,`06YT:6QL97,@;NEE<FQA;F1A:7-E
M<P!54DP@9&4@8F%S92!D92!.971S8V%P90!54DP@9&4@<NEV;V-A=&EO;B!D
M92!L)T$N0RX@3F5T<V-A<&4`55),(&1E(&QA('!O;&ET:7%U92!D)T$N0RX@
M3F5T<V-A<&4`55),(&1E(')E;F]U=F5L;&5M96YT($YE='-C87!E`%523"!D
M92!RZ79O8V%T:6]N($YE='-C87!E`$YO;2!D=2!S97)V975R(%-33"!.971S
M8V%P90!#;VUM96YT86ER92!D=2!C97)T:69I8V%T($YE='-C87!E`%1Y<&4@
M9'4@8V5R=&EF:6-A="!.971S8V%P90!2Z7-E874`2F%M86ES`$YO=79E;&QE
M+4-A;.ED;VYI90!.;W5V96QL92!C873I9V]R:64`3F]U=F5L;&4@;'5N90!.
M;W5V96%U(&YO;2!D92!C;VYN97AI;VX@*&9A8W5L=&%T:68I`$YO=79E;&QE
M+5KI;&%N9&4`3F]U=F5A=2!M;W0@9&4@<&%S<V4`3&4@;F]U=F5A=2!M;W0@
M9&4@<&%S<V4@97AP:7)E<F$@;&4@)7@N`$QE<R!N;W5V96%U>"!M;W1S(&1E
M('!A<W-E(&1I9F;H<F5N="X`3F]U=F5L;&4@9F5NZG1R92`H7V)L86YK*0!.
M;W5V96QL97,`1F]R=6US`%-U:79A;G0`-"!P:&%S97,@<W5I=F%N=&5S`$]P
M=&EO;G,@<W5I=F%N=&5S`%-U:79A;G0^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YU:70`3FEU90!.;VX`4&%S(&1E(&1O;F[I97,@9&4@8V]N9FEG=7)A
M=&EO;B!P;W5R(&QE<W%U96QL97,@;6]N=')E<B!L97,@9&EF9NER96YC97,N
M`%!A<R!D92!S=')A=.EG:64@9&ES<&]N:6)L92!P;W5R(&9A:7)E(&1E<R!I
M;6%G97,@25-/+@!087,@9&4@9V%B87)I="!E;B!T<F%I=&5M96YT('!A<B!L
M;W0N`$%U8W5N(&)L;V,@;B=E>&ES=&4@X"!L82!P;W-I=&EO;B!D96UA;F3I
M90!087,@9&4@;F]M(&1E(&-A;&5N9')I97(@9F]U<FYI('!O=7(@;"=A=71H
M96YT:69I8V%T:6]N('!A<B!-0T%,+@!.;VX@;6]D:69IZ2X`075C=6YE('-O
M=7,M<&5R;6ES<VEO;B!N)V$@8F5S;VEN(&0GZG1R92!A:F]U=.EE('-O=7,@
M8V4@;FEV96%U+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO
M;B!S<.EC:69IZ64@<&]U<B`E<RX`075C=6YE(&EN9F]R;6%T:6]N(&1E(&-O
M;F9I9W5R871I;VX@9F]U<FYI92!P;W5R($944"!61E,N`$%U8W5N92!I;F9O
M<FUA=&EO;B!D92!C;VYF:6=U<F%T:6]N(&9O=7)N:64@<&]U<B!344P@5D93
M+@!!=6-U;F4@:6YF;W)M871I;VX@9&4@8V]N9FEG=7)A=&EO;B!F;W5R;FEE
M('!O=7(@4U%,+49I;&4@5D93+@!!=6-U;B!C<NED:70@9&ES<&]N:6)L92X`
M075C=6YE(&1E<W1I;F%T:6]N('1R;W5VZ64N`$%U8W5N(&9I8VAI97(@96YV
M;WGI`$%U8W5N(&EC]&YE('1R;W5VZ2X`075C=6X@;&EE=2!N)V5S="!SZ6QE
M8W1I;VYNZ0!!=6-U;B!E;7!L86-E;65N="!N)V5S="!I;F1I<77I+@!!=6-U
M;B!M97-S86=E(&9O=7)N:0!!=6-U;B!N;VT@<W#I8VEF:>DN`$%U8W5N(&YO
M;6)R92!S<.EC:69IZ2X`4&%S(&0G87!H;W)I<VUE<R!C:&]Q=6%N=',`075C
M=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO
M;B!P87(@2%144"X`075C=6X@;6]T(&1E('!A<W-E(&9O=7)N:2!P;W5R(&PG
M875T:&5N=&EF:6-A=&EO;B!P87(@24U!4"X`075C=6X@;6]T(&1E('!A<W-E
M(&9O=7)N:2!P;W5R(&PG875T:&5N=&EF:6-A=&EO;B!P87(@2V5R8F5R;W,N
M`$%U8W5N(&UO="!D92!P87-S92!S<.EC:69IZ2!P;W5R(&PG875T:&5N=&EF
M:6-A=&EO;BX`075C=6X@;6]T(&1E('!A<W-E('-PZ6-I9FGI('!O=7(@;"=A
M=71H96YT:69I8V%T:6]N(%!!4U-71"X`075C=6X@;6]T(&1E('!A<W-E('-P
MZ6-I9FGI('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%--0BX`075C=6X@8VAE
M;6EN('9E<G,@;&4@8FEN86ER92!/<&5N4U-,(&9O=7)N:2X@3&4@8FEN86ER
M92!D)T]P96Y34TP@97-T(&[I8V5S<V%I<F4@<&]U<B!F;VYC=&EO;FYE<B!A
M=F5C(&1E<R!D;VYNZ65S(%!+0U,@,3(N`$%U8W5N92!C;VYF:7)M871I;VX@
M96X@871T96YT90!087,@9&4@<75O=&$@<&]S:71I;VYNZ2X`4&%S(&1E('+H
M9VQE<P!!=6-U;B!SZ7!A<F%T975R('-PZ6-I9FGI+@!087,@9&4@8_1TZ7,`
M1FEC:&EE<B!I;F5X:7-T86YT`$%U8W5N('+I<&5R=&]I<F4@=&5M<&]R86ER
M92!E<W0@9&ES<&]N:6)L92!P;W5R(&QA(&-A8VAE`$%U8W5N(&YO;2!D)W5T
M:6QI<V%T975R(&5T("]O=2!M;W0@9&4@<&%S<V4@96YV;WGI+@!!=6-U;F4@
M9&]N;NEE(%A-3"!V86QI9&4@;B=A(.ETZ2!R971O=7)NZ64`4&%S(&1E('9A
M;&5U<@!087,@9&4@=F5R<VEO;B!T<F]U=NEE(&1A;G,@;&$@8V]N9FEG=7)A
M=&EO;B!O<FEG:6YA;&4N(%+I9^ENZ7)E>B!L82!C;VYF:6=U<F%T:6]N+@!0
M87,@9&4@=F5R<VEO;B!T<F]U=NEE(&1A;G,@=F]T<F4@8V]N9FEG=7)A=&EO
M;BX@4NEGZ6[I<F5Z(&QA(&-O;F9I9W5R871I;VXN`$%U8W5N`$%U8W5N("AU
M=&EL:7-E<B!I;7!L:6-I=&5M96YT*0!.;W)D:7%U92`H25-/+3@X-3DM,3`I
M`,YL92!.;W)F;VQK`$CI;6ES<&CH<F4@3F]R9`#.;&5S($UA<FEA;FYE<R!D
M=2!N;W)D`$YO<G;H9V4`4&%S(&%P<NAS`%!A<R!A=F%N=`!087,@=6X@9&]S
M<VEE<@!.;VX@:6UP;.EM96YTZ2X`26YA8W1I9@!.;VX@<')I<R!E;B!C;VUP
M=&4N`$YO=&5S`%)I96X@X"!N879I9W5E<BP@<F5T;W5R;F5Z(&5N(&%R<FGH
M<F4N`$YO=F5M8G)E`$YO;6)R90!.;VUB<F4@9&4@8V%R86-TZ')E<P!.;VUB
M<F4@9&4@8V]L;VYN97,`3F]M8G)E(&1E(')A;F?I97,`3F]M8G)E(&YO;B!S
M<.EC:69IZ2!P;W5R(&QA(&UI<V4@X"!J;W5R(&1E(&QA(&QI<W1E(&1E(&1I
M<W1R:6)U=&EO;BX`3TL`3V)J970`0W+I871E=7(@9"=O8FIE=`!/8W1A;`!/
M8W1O8G)E`$9I;'1R92!A;G1I+6]F9F5N<V%N=`!"=7)E874`3"=A;F-I96X@
M970@;&4@;F]U=F5A=2!M;W1S(&1E('!A<W-E(&1O:79E;G0@ZG1R92!D:69F
MZ7)E;G1S+@!!;F-I96X@;6]T(&1E('!A<W-E`$PG86YC:65N(&UO="!D92!P
M87-S92!E<W0@:6YC;W)R96-T`$]M86X`4V5U;"!L97,@<V5R=F5U<G,@24U!
M4"!S=7!P;W)T96YT(&QE<R!D;W-S:65R<R!P87)T86?I<RX`4V5U;&5M96YT
M(&QE<R"KH&9O<G1U;F5SH+L@;V9F96YS86YT97,`56YE('-E=6QE(&%D<F5S
M<V4@9&4@8V]U<G)I96P@<&5R;6ES92X`4V5U;',@;&4@<')O<')IZ71A:7)E
M(&]U(&PG861M:6YI<W1R871E=7(@<WES=.AM92!P975T(&UO9&EF:65R(&QE
M<R!P97)M:7-S:6]N<R!D)W5N('!A<G1A9V4N`$]U=G)I<B!D86YS('5N92!N
M;W5V96QL92!F96[J=')E`$5R<F5U<B!/<&5N4U-,H#H@:6UP;W-S:6)L92!D
M)V5X=')A:7)E(&QE<R!D;VYNZ65S(&1E(&QA('!A<G1I92!S:6=NZ64@4R]-
M24U%`$]U=G)I<B!L97,@;&EE;G,@9&%N<R!U;F4@;F]U=F5L;&4@9F5NZG1R
M90!3>7-TZ&UE(&0G97AP;&]I=&%T:6]N`$]P=&EO;G,`3W!T:6]N<R!P;W5R
M("5S`$QI<W1E(&YU;>ER;W3I90!/<F=A;FES871I;VX`56YI=.D@;W)G86YI
M<V%T:6]N;F5L;&4`3W)G86YI<V%T:6]N`$UO9.AL92!O<FEG:6YA;"!D)V%P
M<&QI8V%T:6]N`$UO9.AL97,@;W)I9VEN875X(&1A;G,@)7.@.@!!=71R90!!
M=71R97,@:6YF;W)M871I;VYS`%!E<FUI<W-I;VYS(&1U('!R;W!R:>ET86ER
M90!,)V%U=&AE;G1I9FEC871I;VX@4$%-(&XG97-T('!A<R!D:7-P;VYI8FQE
M+@!-;V1U;&4@4$5!4CHZ36%I;`!3:6=N871U<F4@;G5MZ7)I<75E(%!'4`!$
M;VYNZ65S(%!'4"!C:&EF9G+I97,`0VQE9B!P=6)L:7%U92!01U``1&]N;NEE
M<R!01U`@<VEG;NEE<R]C:&EF9G+I97,`0V]D92!02%``26YT97)P<NET975R
M(%!(4`!0;'5I92!LZ6?H<F4@;"=A<'+H<RUM:61I`%!L=6EE(&PG87!RZ',M
M;6ED:0!!=F5R<V5S(&PG87!RZ',M;6ED:0!.96EG92!L)V%P<NAS+6UI9&D`
M0VAU=&5S(&1E(&YE:6=E(&PG87!RZ',M;6ED:0!3;VQE:6P@;"=A<'+H<RUM
M:61I`$]R86=E<R!L)V%P<NAS+6UI9&D`17AT96YS:6]N(%!/4TE8(&%B<V5N
M=&4`26YT97)P<NET975R(%!?2%``4F5M<&QI<W-A9V4`4&%K:7-T86X`0F5L
M874`4&%L97-T:6YE("AT97)R:71O:7)E(&]C8W5PZ2D`4&%N86UA`%!A<&]U
M87-I92U.;W5V96QL92U'=6ENZ64`4&%R86=U87D`4&%R=&EE;&QE;65N="!N
M=6%G975X`$UO="!D92!P87-S90!#:&%N9V5M96YT(&1U(&UO="!D92!P87-S
M92!E9F9E8W1UZ2X`36]T(&1E('!A<W-E(&EN8V]R<F5C=`!-;W0@9&4@<&%S
M<V4@<F5Q=6ES('!O=7(@;"=A=71H96YT:69I8V%T:6]N(%)!1$E54RX`36]T
M(&1E('!A<W-E(&%V96,@8V]N9FER;6%T:6]N`$UO="!D92!P87-S9:`Z`$UO
M="!D92!P87-S9:`Z(`!,97,@;6]T<R!D92!P87-S92!D;VEV96YT(.IT<F4@
M:61E;G1I<75E<RX`0V]L;&5R`$-O;&QE<B!D97!U:7,@;&4@<')E<W-E+7!A
M<&EE<G,`0VAE;6EN`$-O;F9I<FUA=&EO;G,@96X@871T96YT9:`Z`%!E<G-O
M;FYE<P!0;W5R8V5N=&%G90!%9F9E8W1U97(@;&5S(&]PZ7)A=&EO;G,@9&4@
M;6%I;G1E;F%N8V4`169F96-T=65R(&QE<R!O<.ER871I;VYS(&1E(&UA:6YT
M96YA;F-E(.`@;&$@8V]N;F5X:6]NH#\`4&5R;6ES<VEO;@!,82!P97)M:7-S
M:6]N(*N@)7.@NR!N)V5S="!P87,@<W5P<')I;>EE+@!097)M:7-S:6]N(')E
M9G5SZ64`4&5R;6ES<VEO;G,`061M:6YI<W1R871I;VX@9&5S('!E<FUI<W-I
M;VYS`$1O;F[I97,@<&5R<V]N;F5L;&5S`%#I<F]U`$%N:6UA=7@`4&AI;&EP
M<&EN97,`5.ELZ7!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET
M=61E<P!35E`@8VQI<75E>B!D86YS('5N92!C96QL=6QE`%-64"!C;VYF:7)M
M97H@;&$@<W5P<')E<W-I;VX@9&4@8V5T(.ELZ6UE;G2@.@!35E`@8V]N9FER
M;65Z('%U92!V;W5S('9O=6QE>B!DZ6QI97(@8V5T(.ELZ6UE;G0N`%9E=6EL
M;&5Z('-A:7-I<B!U;B!M;VES(&5T('5N92!A;F[I92X`5F5U:6QL97H@<V%I
M<VER('5N(&YO;2!P;W5R(&QA(&YO=79E;&QE(&-A=.EG;W)I9:`Z`%9E=6EL
M;&5Z(&5N=')E<B!U;F4@861R97-S92!)4"!V86QI9&4N`%9E=6EL;&5Z(&5N
M=')E<B!U;F4@9&%T92!V86QI9&6@.R!VZ7)I9FEE>B!L92!N;VUB<F4@9&4@
M:F]U<G,@9'4@;6]I<RX@`%9E=6EL;&5Z(&5N=')E<B!U;F4@:&5U<F4@=F%L
M:61E+@!6975I;&QE>B!F;W5R;FER('5N('+I<W5MZ2!D=2!P<F]B;.AM92X`
M5F5U:6QL97H@9F]U<FYI<B!V;W1R92!N;VT@9"=U=&EL:7-A=&5U<B!E="!V
M;W1R92!M;W0@9&4@<&%S<V4`5F5U:6QL97H@;&ER92!L92!T97AT92!S=6EV
M86YT+B!6;W5S(&1E=F5Z(&%C8V5P=&5R(&QE<R!C;VYD:71I;VYS('!O=7(@
M=71I;&ES97(@;&4@<WES=.AM92X`5F5U:6QL97H@96YT<F5R(&QE(&YO=79E
M874@;F]MH&1E(&QA(&-A=.EG;W)I9:`Z`%!O;&]G;F4`4&]L:71I<75E`%-C
M<G5T:6YS`%!O<G1U9V%L`%!O<VET:6]N(&1E(&-E='1E(&EM86=E`%!O<VET
M:6]N(&1E(&-E('1A8FQE874`16YV;WEE<B#@(&-E(&1O<W-I97(@*&YO;B!A
M<'!L:7%UZ2!P87(@24U!4"D`4'+I8VEP:71A=&EO;G,@<&]U<B!L97,@)7,@
M9&5R;FGH<F5S(&AE=7)E<Z`Z(`!0<F]B86)I;&ETZ3QB<B`O/F1E('!L=6EE
M`%!R969S7VQD87"@.B!E>'1E;G-I;VX@<F5Q=6ES92!,1$%0(&YO;B!T<F]U
M=NEE+@!0<F5F<U]S97-S:6]NH#H@97AT96YS:6]N(')E<75I<V4@JZ!S97-S
M:6]NH+L@;F]N('1R;W5VZ64N`%!R97-S:6]N`%!R97-S:6]N(&%U(&YI=F5A
M=2!D92!L82!M97*@.B``4')E<W-I;VZ@.B``07!E<N=U`$%P97+G=2!D92!L
M)VEM86=E(&1A;G,@=6YE(&YO=79E;&QE(&9E;NIT<F4`3W!T:6]N<R!P<NEC
MZ61E;G1E<P!);7!R:6UE<B!L92!D;V-U;65N=`!#;&5F('!R:7;I90!0<F]B
M;.AM90!$97-C<FEP=&EO;B!D=2!P<F]B;.AM90!0<F]J971S`%1E>'1E(&-O
M=7)T`$-L968@<'5B;&EQ=64`06QG;W)I=&AM92!D92!C;&5F('!U8FQI<75E
M`$EN9F]R;6%T:6]N<R!S=7(@;&$@8VQE9B!P=6)L:7%U90#)8VAE8R!D92!L
M82!GZ6[I<F%T:6]N(&1E(&QA('!A:7)E(&1E(&-L969S('!U8FQI<75E+W!R
M:7;I92X`4&]R=&\@4FEC;P!0=7)G97(@;&5S(&UE<W-A9V5S`%%A=&%R`%)E
M<77J=&4`475O=&$`0VQE9B!P=6)L:7%U92!24T$@*"5D(&)I=',I`%/I;&5C
M=&EO;B!R861I;P!0;'5I90!0;'5I92!T]'0@;&4@;6%T:6X`4&QU:64@=&%R
M9"!D86YS(&QA(&IO=7)NZ64`079E<G-E<P!0;'5I92!E="!N96EG90!0;'5I
M92!P=6ES(&YE:6=E`$%P:&]R:7-M92!A=2!H87-A<F0`5&%U>`!,:7)E`$UE
M<W-A9V5S(&QU<P!3=7!P<F5S<VEO;B!DZ69I;FET:79E(&1E("5SH#\`4W5P
M<')E<W-I;VX@9.EF:6YI=&EV92!D97,@9&]N;NEE<R!P;W5R(&PG=71I;&ES
M871E=7(@)7.@/R!#971T92!O<.ER871I;VX@97-T(&3I9FEN:71I=F4N`%)E
M<')E;F1R92!V;W1R92!D97)N:>AR92!A8W1I;VX`4F%F<F'N8VAI<@!2869R
M8>YC:&ER(&QE<R#I;.EM96YT<R!D=2!M96YU(&1Y;F%M:7%U9:`Z`%)A9G)A
M[F-H:7(@;"?I8W)A;B!D=2!S;VUM86ER9:`Z`$5X<')E<W-I;VX@<F%T:6]N
M;F5L;&4`3F%V:6=A=&5U<B!R96QA=&EO;FYE;`!296-H87)G97(`4F5M87)Q
M=65S`%-E<G9E=7)S(&1I<W1A;G1S`%523"!D:7-T86YT92`H:'1T<#HO+W=W
M=RYE>&5M<&QE+F-O;2]H;W)D92\IH#H`4F5T:7)E<@!2971I<F5R(&QE(&)L
M;V,`4F5T:7)E<B!L82!C;VQO;FYE`%)E=&ER97(@;&4@9F]R;6%T86=E`%)E
M=&ER97(@;&$@<&%I<F4`16YL979E<B!L92!S8W)I<'0@96YR96=I<W1RZ2!D
M=2!RZ7!E<G1O:7)E('1E;7!O<F%I<F4@9'4@<V5R=F5U<BX`4F5T:7)E<B!L
M90!2971I<F5R(&-E(&YO975D(&1U(&1O8W5M96YT`%)E=&ER97(@;"=U=&EL
M:7-A=&5U<@!2971I<F5R(&PG=71I;&ES871E=7*@.B`E<P!!=6-U;F4@<NEP
M;VYS92#@('9O=')E(')E<77J=&4N($-O9&4@9"=E<G)E=7(@<F5T;W5R;NF@
M.B``3&4@<V5R=FEC92!D96UA;F3I(&5S="!I;G1R;W5V86)L92X`3&4@<&%R
M86WH=')E(&]B;&EG871O:7)E(*N@)7.@NR!N)V5S="!P87,@<W#I8VEF:>D@
M9&%N<R!L82!C;VYF:6=U<F%T:6]N("5S+@!,92!P87)A;>AT<F4@;V)L:6=A
M=&]I<F4@JZ`E<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I
M9W5R871I;VX@9'4@5D93+@!,92!P87)A;>AT<F4@;V)L:6=A=&]I<F4@JZ`E
M<Z"[(&XG97-T('!A<R!S<.EC:69IZ2!D86YS(&QA(&-O;F9I9W5R871I;VXN
M`$-H86UP(&]B;&EG871O:7)E`%+`6@!296UI<V4@X"!ZZ7)O(&1U(&UO="!D
M92!P87-S90!296UE='1R92#@('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E`%)E
M=F5N:7(@X"!L82!D97)N:>AR92!R97%UZG1E`%+I<W5L=&%T<P!2979E;FER
M(&%U>"!O<'1I;VYS`%+I+65N=')E<B!L92!N;W5V96%U(&UO="!D92!P87-S
M90!2Z75N:6]N`%)E=F5N:7(@X"!L82!C;VYF:6=U<F%T:6]N('!RZ6/I9&5N
M=&4`3W!T:6]N<R!D92!L)^ED:71E=7(@4FEC:"!497AT`$1E=FEN971T97,`
M1')O:71E`$5N=.IT92!D92!D<F]I=&4`5F%L975R<R!C;W)R96-T97,`4')O
M<')IZ73I<R!D92!L82!R86Y?9^EE("XN+@!2]&QE`%)O=6UA;FEE`%!I=F]T
M97(@,3@P`%!I=F]T97(@X"!G875C:&4`4&EV;W1E<B#@(&1R;VET90!0<F]P
M<FGI=.ES(&1E(&QA(')A;F?I90!0<F]P<FGI=.ES(&1E(&QA(')A;F?I90!2
M86YGZ65SH#H`4NAG;&5S`$1E<R!F:6QE=',@87!P87)A[G1R;VYT(&5N=')E
M('1O=71E<R!L97,@<F%N9^EE<R!E="!L97,@8V]L;VYN97,`1&5S(&9I;&5T
M<R!A<'!A<F'N=')O;G0@96YT<F4@;&5S(&-O;&]N;F5S('-E=6QE;65N=`!$
M97,@9FEL971S(&%P<&%R8>YT<F]N="!E;G1R92!L97,@<F%N9^EE<R!S975L
M96UE;G0`3&%N8V5R`%)U<W-I90!2=V%N9&$`4VEG;F%T=7)E(.EL96-T<F]N
M:7%U92!3+TU)344`365S<V%G92!C:&EF9G+I(%,O34E-10!,)V%U=&AE;G1I
M9FEC871I;VX@4T%33"!N)V5S="!P87,@9&ES<&]N:6)L90!-97-S86=E<FEE
M(%--4P!);G1E<G!RZ71E=7(@4U%,`$]R9')E(%-13"!P;W5R(')E=&]U<FYE
M<B!L97,@=F%L975R<P!34T@`4U5#0\A3`$EN=&5R<'+I=&5U<B!37U%,`%-A
M`%-A:6YT92U(Z6SH;F4`4V%I;G0M0VAR:7-T;W!H92UE="U.:>EVZ',`4V%I
M;G1E+4QU8VEE`%-A:6YT+5!I97)R92!E="!-:7%U96QO;@!386EN="U6:6YC
M96YT+65T+6QE<R!'<F5N861I;F5S`$WJ;64@8V%D<F4@*%]S96QF*0!386UO
M82!O8V-I9&5N=&%L97,`4V%I;G0M36%R:6X`4V%O+51O;>DM970M4')I;F-I
M<&4`1F]U<FYI<W-E=7(@<V%T96QL:71E`$%R86)I92!386]U9&ET90!%;G)E
M9VES=')E<@!%;G)E9VES=')E<B"KH"5SH+L`16YR96=I<W1R97(@)7,`16YR
M96=I<W1R97(@;&5S(&]P=&EO;G,`16YR96=I<W1R97(@;&$@8V]N9FEG=7)A
M=&EO;B!GZ6[I<NEE(&-O;6UE('5N('-C<FEP="!02%`@9&%N<R!L92!RZ7!E
M<G1O:7)E('1E;7!O<F%I<F4@9&4@=F]T<F4@<V5R=F5U<BX`16YR96=I<W1R
M97(@;&$@8V]N9FEG=7)A=&EO;B!D92`E<P!38W)I<'0@9&4@;6ES92#@(&IO
M=7(@9&4@8V]N9FEG=7)A=&EO;B!E;G)E9VES='+I('-O=7.@.B"K("5SH+L`
M3W)A9V5S(&ES;VSI<P!38VEE;F-E`%)E8VAE<F-H90!-;W1E=7)S(&1E(')E
M8VAE<F-H90!#:&]I<VES<V5Z(&QE<R!F:6-H:65R<P!3Z6QE8W1I;VYN97H@
M=6YE(&1A=&4`4^EL96-T:6]N;F5Z('5N(&=R;W5P92#@(&%J;W5T97(`4^EL
M96-T:6]N;F5Z('5N(&YO=79E874@<')O<')IZ71A:7)E`%/I;&5C=&EO;FYE
M>B!U;B!S97)V975R`%/I;&5C=&EO;FYE>B!U;B!U=&EL:7-A=&5U<B#@(&%J
M;W5T97(`5&]U="!SZ6QE8W1I;VYN97(`4^EL96-T:6]N;F5Z('1O=71E<R!L
M97,@8V]M<&]S86YT97,@9&4@;&$@9&%T92X`0VAO:7-I<W-E>B!U;B!O8FIE
M=`!.92!SZ6QE8W1I;VYN97(@875C=6X`4^EL96-T:6]N;F5Z(&QE<R!C87)A
M8W3H<F5S(&1O;G0@=F]U<R!A=F5Z(&)E<V]I;B#@(&PG86ED92!D92!L)V]U
M=&EL(&-I+61E<W-O=7,N(%9O=7,@<&]U=F5Z(&5N<W5I=&4@;&5S(&-O<&EE
M<B!E="!L97,@8V]L;&5R(&1A;G,@=F]T<F4@=&5X=&4N`%/I;&5C=&EO;FYE
M>B!L92!DZ6QI;6ET975R(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R
M;6%T(&1E(&1A=&6@.@!3Z6QE8W1I;VYN97(@;&4@<')O9FEL('%U92!V;W5S
M(&3I<VER97H@;6]D:69I97(Z`%/I;&5C=&EO;FYE>B!L92!DZ6QI;6ET975R
M(&0G:&5U<F6@.@!3Z6QE8W1I;VYN97H@;&4@9F]R;6%T(&1E(&PG:&5U<F6@
M.@!3Z6QE8W1I;VYN97H@9&5U>"!C:&%M<',@87!P87)E;G3I<RX`4^EL96-T
M:6]N;F5Z('9O=')E('1HZ&UE(&1E(&-O=6QE=7)S+@!3Z6QE8W1I;VYN97H@
M=F]T<F4@;&%N9W5E('!RZ6;I<NEEH#H`16YV;WEE<B!L92!R87!P;W)T(&0G
M86YO;6%L:64`16YV;WEE<B!335,`4^ENZ6=A;`!3;VYD9:`Z(`!397!T96UB
M<F4`4V5R8FEE(&5T($UO;G1E;F5G<F\`3G5MZ7)O(&1E('/I<FEE`$QE<R!D
M;VYNZ65S(&1U('-E<G9E=7(@<V]N="!F875S<V5S(&]U(&YO;B!D:7-P;VYI
M8FQE<RX`061M:6YI<W1R871I;VX@9&5S('-E<W-I;VYS`$ED+B!D92!S97-S
M:6]N(&5X<&ERZ2X`4V5S<VEO;G,`4^EL96-T:6]N;F5R`$-O;F9I9W5R97(@
M;&5S(&]P=&EO;G,@<&]U<B!V;W5S('!E<FUE='1R92!D92!R96UE='1R92#@
M('KI<F\@=F]T<F4@;6]T(&1E('!A<W-E('-I(&IA;6%I<R!V;W5S(&PG;W5B
M;&EE>BX`0V]N9FEG=7)E<B!L97,@<V5R=F5U<G,@9&ES=&%N=',@86-C97-S
M:6)L97,@9&5P=6ES('9O=')E('!O<G1A:6PN`%/I;&5C=&EO;FYE>B!V;W1R
M92!L86YG=64@<'+I9NERZ64L(&9U<V5A=2!H;W)A:7)E(&5T(&QE<R!O<'1I
M;VYS(&1E(&1A=&4N`$3I9FEN:7-S97H@;&$@<')E;6GH<F4@87!P;&EC871I
M;VX@;&%N8^EE+"!L92!T:.AM92!D92!C;W5L975R<RP@;&4@<F%F<F'N8VAI
M<W-E;65N="!D97,@<&%G97,L(&5T(&0G875T<F5S(&]P=&EO;G,@9"=A9F9I
M8VAA9V4N`$-O;F9I9W5R871I;VX`4V-R:7!T(&1E(&-O;F9I9W5R871I;VX@
M9&4@;6ES92#@(&IO=7(@9&ES<&]N:6)L90!0;'5S:65U<G,@96YD<F]I=',@
M<&]S<VEB;&5S(&%V96,@;&4@<&%R86WH=')EH#H@`%-E>6-H96QL97,`06-H
M870`4NES=6WI`$1O:70M;VX@9.EF:6YI<B!D97,@=&]U8VAE<R!D92!R86-C
M;W5R8VES('!O=7(@;&$@<&QU<&%R="!D97,@;&EE;G.@/P!!9F9I8VAE<@!-
M;VYT<F5R(&QE<R!D:69FZ7)E;F-E<R!E;G1R92!L82!C;VYF:6=U<F%T:6]N
M(&5N<F5G:7-T<NEE(&%C='5E;&QE;65N="!E="!C96QL92!N;W5V96QL96UE
M;G0@9^ENZ7+I92X`36]N=')E<B!L)VAE=7)E(&1E(&QA(&1E<FYIZ')E(&-O
M;FYE>&EO;B#@(&PG96YT<NEEH#\`36]N=')E<B!L)V]P=&EO;B!D92!C;VYS
M97)V97(@;"=O<FEG:6YA;`!-;VYT<F5R(&QE('/I;&5C=&5U<@!!9F9I8VAE
M<B!L82!B87)R92!D92!M96YU(&1E('1A8FQE875XH#\`069F:6-H97(@;&4@
M;65N=2`E<R#@(&=A=6-H9:`_`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO
M9W5E('1A8FQE874@8V5L;'5L90!!9F9I8VAE<B!L82!B;^YT92!D92!D:6%L
M;V=U92!D97,@<')O<')IZ73I<R!D=2!T86)L96%U`$%F9FEC:&5R(&QA(&)O
M[G1E(&1E(&1I86QO9W5E(&1E<R!P<F]P<FGI=.ES(&1E(&QA(')A;F?I92!D
M=2!T86)L96%U`$%F9FEC:&5R(&QA(&)O[G1E(&1E(&1I86QO9W5E(&1E<R!P
M<F]P<FGI=.ES(&1E(&PG:6UA9V4`069F:6-H97(@;"=E;G9O:2!D92!F:6-H
M:65R`$%V97)S97,`079E<G-E<R!T]'0@9&%N<R!L82!J;W5R;NEE`$%V97)S
M97,@=&%R9"!E;B!J;W5R;NEE`$%V97)S97,@875X(&%L96YT;W5R<P!297-S
M97)R97(`4F5S<V5R<F5R(&]U(&3I9V%G97(@9"=A8F]R9"!L92AS*2!B;&]C
M*',I('9O:7-I;BAS*0!3:65R<F$@3&5O;F4`4R=I;G-C<FER90!3:6=N871U
M<F4`06QG;W)I=&AM92!D92!S:6=N871U<F4`4VEN9V%P;W5R`%1A:6QL90!!
M;FYU;&5R(&QA(&UA:6YT96YA;F-E`%-L;W9A<75I90!3;&]VZ6YI90!.96EG
M90!!=F5R<V4@9&4@;F5I9V4`079E<G-E<R!D92!N96EG90!!=F5R<V5S(&1E
M(&YE:6=E('3T="!D86YS(&QA(&IO=7)NZ64`079E<G-E<R!D92!N96EG92!T
M87)D(&5N(&IO=7)NZ64`2&%U=&5U<B!D92!N96EG9:`Z(`!1=6%N=&ETZ2!D
M)V5A=2#I<75I=F%L96YT92#@(&QA('%U86YT:73I(&1E(&YE:6=EH#H@`,YL
M97,@4V%L;VUO;@!3;VUA;&EE`$-H86YS;VYS(&5T('!OZ&UE<P!3Z6QE8W1I
M;VX@9&4@;"=O<F1R92!D92!T<FD`061R97-S92!S;W5R8V4`069R:7%U92!D
M=2!S=60`4W5D+65U<F]PZ65N("A)4T\M.#@U.2TS*0!'Z6]R9VEE+61U+7-U
M9"!E="#N;&5S(%-A;F1W:6-H+61U+7-U9`!(Z6UI<W!HZ')E(%-U9`!%<W!A
M8V4@96YT<F4@8V5L;'5L97,@861J86-E;G1E<P!%<W!A8V4@96YT<F4@;&4@
M8V]N=&5N=2!E="!L82!B;W)D=7)E(&1A;G,@=6YE(&-E;&QU;&4`17-P86-E
M=7(`17-P86-E;65N=`!%<W!A8V5M96YT(&5T(')E;7!L:7-S86=E`$5S<&%G
M;F4`4&]U<G)I96P`0V%R86-TZ')E<R!S<.EC:6%U>`!38VEN9&5R(&QA(&-E
M;&QU;&4`4V-I;F1E<B!L82!C;VQO;FYE`%-C:6YD97(@;&$@<F%N9^EE`%-P
M;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`$%N;NEE(&1E(&3I
M8G5T`,ET870@;W4@<')O=FEN8V4`4W1A='5T`$9O<FUA="!D92!S875V96=A
M<F1E`%)U90!"87)RZ0!,:7-T92!D92!C:&'N;F5S`%)E=&ER97(@;&4@9&]M
M86EN92!D92!L)V%D<F5S<V4`4W1Y;&4@6T-34UT`1&D`4V]U<RURZ7!E<G1O
M:7)E(*N@)7.@NR!N;VX@=')O=7;I`%-U:F5T`$5N=F]I`$QA(&1E;6%N9&4@
M9"=A:F]U="!D92"KH"5SH+L@874@<WES=.AM92!A(.ETZ2!S;W5M:7-E+B!6
M;W5S(&YE('!O=7)R97H@<&%S('9O=7,@8V]N;F5C=&5R(&IU<W%U)^`@<V]N
M(&%P<')O8F%T:6]N+@!);F1I8V4`4W5C8^AS`*N@)7.@NR!A(&)I96X@Z73I
M(&%J;W5TZ2AE*2X`3&5S(&1O;F[I97,@9&4@;"=U=&EL:7-A=&5U<B"KH"5S
MH+L@;VYT(&)I96X@Z73I(')E=&ERZ65S(&1U('-Y<W3H;64N+@"KH"5SH+L@
M82!B:65N(.ETZ2!S=7!P<FEMZ2AE*2X`JZ`E<Z"[(&$@8FEE;B#I=.D@<F5T
M:7+I*&4I+@!2971O=7(@X"!L82!C;VYF:6=U<F%T:6]N(&EN:71I86QE('+I
M=7-S:2X@(%)A9G)A[F-H:7(@;&$@<&%G92!P;W5R('9O:7(@;&5S(&UO9&EF
M:6-A=&EO;G,N`$5N<F5G:7-T<F5M96YT(&1E(&QA(&-O;F9I9W5R871I;VX@
M9&4@;&$@<V%U=F5G87)D92!RZ75S<VDN`$5N<F5G:7-T<F5M96YT('+I=7-S
M:2!D92!L82!C;W!I92!D92!S875V96=A<F1E(&1U(&9I8VAI97(@9&4@8V]N
M9FEG=7)A=&EO;B`E<RX`JZ`E<Z"[(&$@8FEE;B#I=.D@;6ES*&4I(.`@:F]U
M<BX`R6-R:71U<F4@9&4@)7,@<NEU<W-I`%-O=61A;@!3;VUM86ER90!,979E
M<B!D=2!3;VQE:6P`0V]U8VAE<B!D=2!3;VQE:6P`16YS;VQE:6QLZ0!,979E
M<B!D=2!3;VQE:6P`3&5V97(O0V]U8VAE<B!D=2!3;VQE:6P`3&5V97(@9'4@
M4V]L96EL.B``0V]U8VAE<B!D=2!3;VQE:6P`0V]U8VAE<B!D=2!3;VQE:6R@
M.B``17AP;W-A;G0`07-S:7-T86YC90!3=7)I;F%M(&]U($=U>6%N92!H;VQL
M86YD86ES90!.;VT@9&4@9F%M:6QL90#.;&5S(%-V86QB87)D(&5T($IA;B!-
M87EE;@!3=V%Z:6QA;F0`4W7H9&4`4W5I<W-E`$IO=7)N86P@9&4@<WEN8VAR
M;VYI<V%T:6]N('-U<'!R:6WI`%-Y;F--3`!%<G)E=7(@9&4@<WEN=&%X92!D
M86YS(&QE<R!T97)M97,@9&4@<F5C:&5R8VAE`%-Y<FEE`$]R86=E<P!/<F%G
M92!E="!V96YT`$]R86=E<P!/<F%G97,@;6%T:6YA=7@`1FEC:&EE<B!44U8`
M4')O<')IZ73I<R!D=2!T86)L96%U`%1A8FQE874@9&4@=F%L975R<P!0<F]P
M<FGI=.ES(&1U('1A8FQE874`5&'O=V%N`%1A[W=A;BP@<')O=FEN8V4@9&4@
M0VAI;F4`5&%J:6MI<W1A;@!486YZ86YI90!#:6)L9:`Z`%3B8VAE<P!.=6WI
M<F\@9&4@=.ELZ7!H;VYE`%1E;7#I<F%T=7)E('!O=7(@;&$@9&5R;FGH<F4@
M:&5U<F6@.B``5&5M<.ER871U<F4`5&5M<.ER871U<F6@.B``5&5M<.ER871U
M<F4\8G(@+SXH)7-(825S+R5S0F$E<RD@)F1E9SLE<P!0<F]F:6P@JZ`E<Z"[
M(&YO;B!T<F]U=ND`061M:6YI<W1R871I;VX@9&5S(&UO9.AL97,`5&5X=&4`
M5&5X=&4@<V5U;`!!;&EG;F5M96YT(&1U('1E>'1E`%1E>'1E(&5N(&AA=70`
M2F4`5&AA[R`H5$E3+38R,"D`5&AA[VQA;F1E`$PG97AT96YS:6]N($944"!N
M)V5S="!P87,@9&ES<&]N:6)L92X`3"=H:7-T;W)I<V%T:6]N(&5S="!DZ7-A
M8W1I=NEE+@!,92!M;W1E=7(@9"=I;G3I9W)A=&EO;B!(;W)D92]+;VQA8B!N
M92!S=7!P;W)T92!P87,@JZ`E<Z"[`$QE(&IO=7)N86P@24U34"!N)V$@<&%S
M('!U(.IT<F4@:6YI=&EA;&ESZ2X`3&$@8VQA<W-E($UA:6YT96YA;F-E.CH@
M;B=A('!A<R#I=.D@8VAA<F?I92!C;W)R96-T96UE;G0`3&$@9F5NZG1R92!D
M97,@;W!T:6]N<R!S)V5S="!F97)MZ64N(%-O<G1I92X`3"=A9&UI;FES=')A
M=&5U<B!D;VET(&-O;F9I9W5R97(@=6X@8F%C:V5N9"!P97)M86YE;G0@<&]U
M<B!L97,@<&5R;6ES<VEO;G,@<VD@=F]U<R!V;W5L97H@;&5S(&5M<&QO>65R
M+@!,82!B;W)D=7)E(&1U(&)A<R!S975L96UE;G0`3"=)1"!D=2!C;VYT86-T
M(&XG82!P87,@Z73I('-PZ6-I9FGI+"!L86ES<^D@=FED92!O=2!N)V$@<&%S
M(.ETZ2!T<F]U=ND@9&%N<R!L82!B87-E(&1E(&1O;F[I97,N`$-E(&-O;G1A
M8W0@82!B:65N(.ETZ2!A:F]U=.D@X"!V;W1R92!C87)N970@9"=A9')E<W-E
M<RX@`$QE(&)L;V,@9&4@<VEG;F%T=7)E(%!'4"!SZ7!A<ND@97-T(&[I8V5S
M<V%I<F4@<&]U<B!VZ7)I9FEE<B!L82!S:6=N871U<F4N`$PG240@9&4@;&$@
M;&ES=&4@;B=A('!A<R#I=.D@<W#I8VEF:>DL(&QA:7-SZ2!V:61E(&]U(&YO
M;B!T<F]U=ND@9&%N<R!L82!B87-E(&1E(&1O;F[I97,N`$QA(&QI<W1E(&1E
M(&1I<W1R:6)U=&EO;B!N)V$@<&%S(.ETZ2!S<.EC:69IZ64N`$QE(&-H:69F
M<F5M96YT(&[I8V5S<VET92!U;F4@8V]N;F5X:6]N('/I8W5R:7/I92X`3&4@
M9FEC:&EE<B`E<R!D;VET(&-O;G1E;FER(&QE<R!O<'1I;VYS("5S+@!,92!F
M:6-H:65R("5S(&1O:70@8V]N=&5N:7(@8V5R=&%I;F5S(&]P=&EO;G,@)7,N
M`$QE(&9I8VAI97(@;F4@<&5U="!P87,@ZG1R92!C;W!IZ2!S=7(@;'5I+6WJ
M;64N`$QE(&9I8VAI97(@;F4@8V]N=&5N86ET(&%U8W5N92!D;VYNZ64N`$-E
M('%U:2!S=6ET('-O;G0@;&5S(&5N+73J=&5S('!O=7(@8V4@;65S<V%G92!M
M97-S86=E+U)&0S@R,BX`3&4@;6]D92!P;&5I;B#I8W)A;B!C875S92!D97,@
M<')O8FSH;65S(&%V96,@26YT97)N970@17AP;&]R97(@9/L@X"!D97,@8F]G
M=65S(&1U(&YA=FEG871E=7(@<75I(&XG;VYT('!U(.IT<F4@8V]N=&]U<F[I
M<RX@5F]U<R!P;W5V97H@ZG1R92!C;VYF<F]N=.ES(.`@9&4@;"=A9F9I8VAA
M9V4@9&4@8V%R86-TZ')E<R#I=')A;F=E<RP@874@;F]N+69O;F-T:6]N;F5M
M96YT(&1E<R!C97)T86EN97,@9F]N8W1I;VYS(&5T+V]U(&%U('!L86YT86=E
M(&%LZ6%T;VER92!D=2!N879I9V%T975R+B!3:2!V;W1R92!S>7-TZ&UE(&5S
M="!U;B!7:6YD;W=S(#EX+"!I;"!E<W0@='+H<R!P;W-S:6)L92!Q=64@=F]U
M<R!A=7)E>B!U;F4@)T9A=71E(&?I;NER86QE(&1E('!R;W1E8W1I;VXG(&5T
M('%U92!V;W5S(&1E=G)E>B!R963I;6%R<F5R('9O=')E(&]R9&EN871E=7(N
M7&Y<;E9O=7,@879E>B#I=.D@<'+I=F5N=7,N(%-64"!A<'!U>65Z('-U<B!/
M2R!S:2!V;W5S('9O=6QE>B!T;W5J;W5R<R!E<W-A>65R(&QE(&UO9&4@<&QE
M:6X@Z6-R86X@9&4@;"?I9&ET975R`$PG:61E;G1I=.D@JZ`E<Z"[("!A(.ET
MZ2!S=7!P<FEMZ64N`$QE(&/T=.D@9V%U8VAE('-E=6QE;65N=`!,)V5M<&QA
M8V5M96YT(&1U('!R;V=R86UM92!';G501R!D;VET(.IT<F4@9F]U<FYI(.`@
M;&$@8VQA<W-E($-R>7!T7W!G<#HZ+@!,92!M97-S86=E(&5N=F]YZ2!L92`E
M<R#@("5S(&%V96,@8V]M;64@<W5J970@JZ`E<Z"[(&$@Z73I(&%F9FEC:.DN
M(`I);"!N)WD@82!A=6-U;F4@9V%R86YT:64@<75E(&-E(&UE<W-A9V4@82#I
M=.D@;'4@;W4@8V]M<')I<RX`3&4@;F]M(.`@=71I;&ES97(@96X@;&EA;G0@
MX"!L82!P86=E(&1E(&-O;7!O<VET:6]N`$QE(&YO;6)R92!D92!C:&%M<',@
M9&]I="#J=')E('5N(&YO;6)R92!V86QI9&4N`$QE(&UO9'5L92!/<&5N4U-,
M(&5S="!R97%U:7,@<&]U<B!L82!C;&%S<V4@2&]R9&5?0W)Y<'1?<VUI;64Z
M.BX`3&$@<'+I9NER96YC92"KH"5SH+L@;B=A('!A<R!P=2#J=')E(&5N<F5G
M:7-T<NEE(&-A<B!S82!T86EL;&4@9.EP87-S92!L92!M87AI;75M(&%U=&]R
M:7/I`$QE('!R;V=R86UM92!U=&EL:7/I('!O=7(@=FES=6%L:7-E<B!C92!T
M>7!E(&1E(&1O;F[I97,@*"5S*2!N)V$@<&%S(.ETZ2!T<F]U=NDN`$QE(&-A
M<F%C=.AR92!D92!P<F]T96-T:6]N(&1O:70@ZG1R92!U;B!C87)A8W3H<F4@
M=6YI<75E+@!,97,@8_1TZ7,@9V%U8VAE(&5T(&1R;VET('-E=6QE;65N=`!,
M92!C]'3I(&1R;VET('-E=6QE;65N=`!,92!SZ7!A<F%T975R(&1O:70@ZG1R
M92!U;B!C87)A8W3H<F4@=6YI<75E+@!,92!S97)V975R(*N@)7.@NR!A(.ET
MZ2!S=7!P<FEMZ2X`3&4@<V5R=F5U<B"KH"5SH+L@82#I=.D@96YR96=I<W1R
MZ2X`3&$@<F5Q=>IT92!D)V5N<F5G:7-T<F5M96YT('!O=7(@)7,@82#I=.D@
M9.EP;&%CZ64N`$QA(&QI9VYE(&1E;6%N9.EE("@E9"D@;B=E>&ES=&4@<&%S
M+@!,92!F:6-H:65R('1E;7!O<F%I<F4@JR`E<Z"[(&XG97AI<W1E('!A<RX`
M3&4@=&5X=&4@96YT<ND@;F4@8V]R<F5S<&]N9"!P87,@874@=&5X=&4@<W5R
M(&PGZ6-R86XN`$QE(&AA=70@970@;&4@8F%S('-E=6QE;65N=`!,92!H875T
M('-E=6QE;65N=`!,97,@9&]N;NEE<R!TZ6SI8VAA<F?I97,@=F5R<R!L92!S
M97)V975R(&]N="#I=.D@<&5R9'5E<R!D97!U:7,@;"?I=&%P92!P<NECZ61E
M;G1E+B``3&4@9FEC:&EE<B#I;6ES(&XG82!P87,@<'4@ZG1R92!E;G)E9VES
M='+I+@!,92!B;&]C(*N@=V5A=&AE<BYC;VV@NR!N)V5S="!P87,@9&ES<&]N
M:6)L92X`4NEP97)T;VER92!D97,@=&CH;65S(*N@)7.@NR!N;VX@=')O=7;I
M`$EL(&XG>2!A('!A<R!D)V]P=&EO;G,@9&ES<&]N:6)L97,`075C=6YE('!A
M<G1I92!N92!P975T(.IT<F4@869F:6-HZ64@96X@;&EG;F4N`$EL('D@(&$@
M=')O<"!D92!C87)A8W3H<F5S(&1A;G,@8V4@8VAA;7`N(%9O=7,@96X@879E
M>B!E;G1RZ2`E<Z`[(&EL(&5N(&9A=70@;6]I;G,@9&4@)7,N`%5N('!R;V)L
MZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L)V%J;W5T(&1E(*N@)7.@NZ`Z("5S
M`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!S=7!P<F5S<VEO
M;B!D97,@9&]N;NEE<R!D92!L)W5T:6QI<V%T975R(*N@)7.@NZ`Z(`!5;B!P
M<F]B;.AM92!E<W0@87!P87)U(&QO<G,@9&4@;&$@<W5P<')E<W-I;VX@9&4@
MJZ`E<Z"[H#H@`%5N('!R;V)LZ&UE(&5S="!A<'!A<G4@;&]R<R!D92!L82!M
M:7-E(.`@:F]U<B!D92"KH"5SH+N@.B`E<P!5;B!P<F]B;.AM92!E<W0@87!P
M87)U(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@875C=6X@)7,@;B=A
M(.ETZ2!T<F%N<VUI<RX`56YE(&5R<F5U<B!E<W0@<W5R=F5N=64@;&]R<R!D
M92!L)V5N=F]I(&1U(&9I8VAI97*@.B!L92`E<R#I=&%I="!P;'5S(&=R;W,@
M<75E(&QE(&UA>&EM=6T@875T;W)I<^D@*"5D(&]C=&5T<RDN`%5N92!E<G)E
M=7(@97-T('-U<G9E;G5E(&QO<G,@9&4@;"=E;G9O:2!D=2!F:6-H:65RH#H@
M;&4@)7,@82#I=.D@=')A;G-M:7,@<&%R=&EE;&QE;65N="X`56YE(&5R<F5U
M<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG869F:6-H86=E(&1E(&-E='1E
M('!A<G1E(&1U(&UE<W-A9V4`56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L
M;W)S(&1E(&PG:6UP;W)T871I;VX@9&5S(&1O;F[I97,@9&4@8V4@8V]N=&%C
M="X`56YE(&5R<F5U<B!S)V5S="!P<F]D=6ET92!L;W)S(&1E(&PG:6UP;W)T
M871I;VX@9&4@8V5T=&4@8V%R=&4@:4-A;&5N9&%R+@!);"!Y(&%V86ET('5N
M92!E<G)E=7(@9&%N<R!L92!F;W)M=6QA:7)E(&1E(&-O;F9I9W5R871I;VXN
M(%!E=70MZG1R92!A=F5Z+79O=7,@;&%I<W/I('5N(&-H86UP(')E<75I<R!V
M:61E+@!5;F4@97)R975R(',G97-T('!R;V1U:71E(&QO<G,@9&4@;"=E>.EC
M=71I;VX@9&4@8V5T=&4@9F]N8W1I;VX@9'4@8V%R;F5T(&0G861R97-S92X@
M4U90(&5S<V%Y97(@X"!N;W5V96%U('!L=7,@=&%R9"X`26P@>2!A(&5U('5N
M92!E<G)E=7(@;&]R<R!D92!L82!M:7-E(.`@:F]U<B!D97,@:6YF;W)M871I
M;VYS('-U<B!L92!C;VYT86-T+B`@5F5U:6QL97H@97-S87EE<B#@(&YO=79E
M874N`$EL('D@82!E=2!U;F4@97)R975R(&QO<G,@9&4@;&$@;6ES92#@(&IO
M=7(@9&4@;&$@;&ES=&4@9&4@9&ES=')I8G5T:6]N+B`@5F5U:6QL97H@97-S
M87EE<B!D92!N;W5V96%U+@!,92!P<NES96YT('-E<G9E=7(@24U!4"!N92!S
M=7!P;W)T92!P87,@;&4@<&%R=&%G92!D92!D;W-S:65R<RX`QV$@;F4@<V5M
M8FQE('!A<R#J=')E('5N92!A<F-H:79E(%)!4B!V86QI9&4N`,=A(&YE('-E
M;6)L92!P87,@ZG1R92!U;B!F:6-H:65R(%I)4"!V86QI9&4N`,=A(&YE('-E
M;6)L92!P87,@ZG1R92!U;B!N=6WI<F\@9&4@8V%R=&4@=F%L:61E+@!#92!P
M:6QO=&4@<&5R;65T(&PG96YV;VD@9&4@;65S<V%G97,@X"!T<F%V97)S(&QA
M('!A<W-E<F5L;&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2!E;B!U=&EL:7-A;G0@;"=!4$D@2%144`!#92!P:6QO=&4@<&5R;65T(&PG
M96YV;VD@9&4@;65S<V%G97,@=FEA(&QA('!A<W-E<F5L;&4@5TE.("AH='1P
M.B\O=VEN<&QC+F-O;2D@96X@=71I;&ES86YT(&PG05!)($A45%``0V4@<&EL
M;W1E('!E<FUE="!L)V5N=F]I(&1E(&UE<W-A9V5S(.`@=')A=F5R<R!L82!P
M87-S97)E;&QE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&5N
M('5T:6QI<V%N="!L)T%022!(5%10`$-E('!I;&]T92!P97)M970@;"=E;G9O
M:2!D92!M97-S86=E<R!P87(@4TU44"#@('1R879E<G,@;&$@<&%S<V5R96QL
M92!6;V1A9F]N92!)=&%L:64L('-E=6QE;65N="!A=7@@;G5MZ7)O<R!6;V1A
M9F]N92X@0V5L82!NZ6-E<W-I=&4@=6X@8V]M<'1E(&1E(&-O=7)R:65L(%9O
M9&%F;VYE($ET86QI92`H:'1T<#HO+W=W=RXQ.3`N:70I+@!#92!C:&%M<"!E
M<W0@;V)L:6=A=&]I<F4N`$-E(&-H86UP(&YE(&1O:70@8V]N=&5N:7(@<75E
M(&1E<R!E;G1I97)S+@!#92!C:&%M<"!N92!D;VET(&-O;G1E;FER('%U92!D
M97,@;F]M8G)E<R!E="!L97,@9&5U>"UP;VEN=',N`$-E(&-H86UP(&YE(&1O
M:70@8V]N=&5N:7(@<75E(&1E<R!V86QE=7)S(&]C=&%L97,N`$-E(&-H86UP
M(&1O:70@8V]N=&5N:7(@=6YE(&QI<W1E(&0G96YT:65R<R!SZ7!A<NES('!A
M<B!D97,@=FER9W5L97,@;W4@9&5S(&5S<&%C97,`0V4@8VAA;7`@9&]I="#J
M=')E('5N(&YO;6)R92!V86QI9&4N`$-E(&-H86UP(&1O:70@8V]N=&5N:7(@
M=6X@8V]D92!D92!C;W5L975R(&%U(&9O<FUA="!21T(@:&5X863I8VEM86PL
M('!A<B!E>&5M<&QE("<C,3(S-&%F)RX`0V4@9F]R;75L86ER92!A(&3I:N`@
MZ73I('1R86ETZ2X`0R=E<W0@)7,N`$-E8VD@97-T('5N(&]B:F5T($MO;&%B
M($=R;W5P=V%R92X@4&]U<B!V;VER(&-E="!O8FIE="P@=F]U<R!D979R97H@
M879O:7(@=6X@8VQI96YT(&1E(&-O=7)R:65L('%U:2!C;VUP<F5N9"!L92!F
M;W)M870@2V]L86(@1W)O=7!W87)E+B!0;W5R('5N92!L:7-T92!D92!C97,@
M8VQI96YT<R!D92!C;W5R<FEE;"P@=FES:71E>B`E<P!#92!M97-S86=E(&$@
MZ73I(.EC<FET(&1A;G,@=6X@8V]D92!D92!C87)A8W3H<F5S("@E<RD@875T
M<F4@<75E(&QE(';T=')E+@!#92!N;VUB<F4@9&]I="#J=')E('-U<.ER:65U
M<B#@('5N+@!#92!S97)V975R(&YE('!E=70@<&%S(&3I8V]M<')E<W-E<B!L
M97,@9FEC:&EE<G,@6DE0(&5T(&=Z:7`N`$-E('-Y<W3H;64@97-T('!RZ7-E
M;G1E;65N="!DZ7-A8W1I=NDN`$-E='1E('9A;&5U<B!D;VET(.IT<F4@=6X@
M;F]M8G)E+@!#971T92!F96[J=')E(&1O:70@ZG1R92!A<'!E;.EE(&1E<'5I
M<R!U;F4@9F5NZG1R92!D97,@;W!T:6]N<P!4;VYN97)R90!4:6-K971S`$AE
M=7)E`%-U:79I(&AO<F%I<F4`1F]R;6%T(&0G:&5U<F4`4^EL96-T:6]N(&1E
M(&PG:&5U<F4`5&EM;W(@;W)I96YT86P`5&ET<F4`5&ET<F4@*&EN9F]B=6QL
M92F@.@#``%!O=7(@<^EL96-T:6]N;F5R('!L=7-I975R<R!I=&5M<R#@(&QA
M(&9O:7,L(&UA:6YT96YE>B!E;F9O;F/I(&QE(&)O=71O;B"KH$-T<FR@NR`H
M4$,I(&]U(*N@0V]M;6%N9&6@NR`H36%C*2!E;B!C;&EQ=6%N="X`075J;W5R
M9"=H=6D`5F]I<B!L82!S;W5R8V4@2%1-3`!4;V=O`%1O:V5L874`1&5M86EN
M`%1O;F=A`%1R;W`@9&4@8V]N;F5X:6]N<R!I;F9R=6-T=65U<V5S(&1A;G,@
M;&5S(&1E<FYIZ')E<R!M:6YU=&5S+@!(875T`$-A9')E(&1U(&AA=70@*%]T
M;W`I`%1R861U8W1I;VYS`%1R:6YI=.DM970M5&]B86=O`%9R86D@;W4@9F%U
M>`!-80!4=6YI<VEE`%1U<G%U:64`5'5R8R`H25-/+3@X-3DM.2D`5'5R:VWI
M;FES=&%N`,YL97,@5'5R<75E<R!E="!#8>]Q=65S`%1U=F%L=0!%;G1R97H@
M=F]T<F4@8VAO:7B@.B``26YD:6-E(%56H#H@`%523`!54DP@<&]U<B!V;W1R
M92!R87!P;W)T(&1E(&QI=G)A:7-O;B!D=2!S8W)I<'0`55),.@!/=6=A;F1A
M`%5K<F%I;F4`26UP;W-S:6)L92!D)V%T=&5I;F1R92!L92!RZ7!E<G1O:7)E
M(%9&4RX`26UP;W-S:6)L92!D)V%J;W5T97(@9&5S(&EN9F]R;6%T:6]N<R!C
M;VUP;.EM96YT86ER97,@X"!L)VEN<V-R:7!T:6]N+@!);7!O<W-I8FQE(&1E
M(&UO9&EF:65R(&QE<R!P97)M:7-S:6]N<R!P;W5R(&QE(&9I8VAI97(@5D93
M(*N@)7.@NRX`26UP;W-S:6)L92!D92!M;V1I9FEE<B!L97,@<&5R;6ES<VEO
M;G,@<&]U<B!L92!F:6-H:65R(%9&4R`E<R\E<RX`26UP;W-S:6)L92!D92!C
M:&%N9V5R('!O=7(@)7,N`$EM<&]S<VEB;&4@9&4@=NER:69I97(@;&$@=&%I
M;&QE(&1U(&9I8VAI97(@9&4@JZ`E<Z"[+@!);7!O<W-I8FQE(&1E(';I<FEF
M:65R(&QA('1A:6QL92!D=2!F:6-H:65R(&1E(*L@)7,O)7,@NRX`0V]N;F5X
M:6]N(&EM<&]S<VEB;&4@874@<V5R=F5U<B!344PN`$-O;FYE>&EO;B!I;7!O
M<W-I8FQE(&5N(%-33`!);7!O<W-I8FQE(&1E(&-O<&EE<B!U;B!F:6-H:65R
M(%9&4RX`26UP;W-S:6)L92!D92!C<NEE<B!U;B!RZ7!E<G1O:7)E(%9&4R"K
MH"5SH+LN`$EM<&]S<VEB;&4@9&4@8W+I97(@=6X@<NEP97)T;VER92!61E,N
M`$EM<&]S<VEB;&4@9&4@8W+I97(@;&4@9FEC:&EE<B!61E,N`$EM<&]S<VEB
M;&4@9&4@8W+I97(@;&4@<NEP97)T;VER92!61E,@JZ`E<Z"[+@!);7!O<W-I
M8FQE(&1E(&-RZ65R('5N(&9I8VAI97(@5D93('9I9&4N(`!/=79E<G1U<F4@
M:6UP;W-S:6)L92!D92!L)V%R8VAI=F4@8V]M<')E<W/I92X@`%-U<'!R97-S
M:6]N(&EM<&]S<VEB;&4@9&4@JZ`E<Z"[+"!L92!D;W-S:65R(&XG97-T('!A
M<R!V:61E+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E(*N@)7.@NZ`Z("5S
M+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1E("5S+"!L92!D;W-S:65R(&XG
M97-T('!A<R!V:61E`%-U<'!R97-S:6]N('+I8W5R<VEV92!D=2!D;W-S:65R
M(%9&4R!I;7!O<W-I8FQE+@!3=7!P<F5S<VEO;B!D=2!RZ7!E<G1O:7)E(%9&
M4R!I;7!O<W-I8FQE+@!);7!O<W-I8FQE(&1E('-U<'!R:6UE<B!L92!RZ7!E
M<G1O:7)E(%9&4Z`Z("5S+@!3=7!P<F5S<VEO;B!I;7!O<W-I8FQE(&1U(&9I
M8VAI97(@5D93(*N@)7.@NRX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!F
M:6-H:65R(%9&4RX`4W5P<')E<W-I;VX@:6UP;W-S:6)L92!D=2!RZ7!E<G1O
M:7)E(%9&4R"KH"5SH+LN`%-U<'!R97-S:6]N(%9&4R!RZ6-U<G-I=F4@:6UP
M;W-S:6)L9:`Z("5S+@!);7!O<W-I8FQE(&1E(&3I=&5R;6EN97(@;&4@9&]S
M<VEE<B!C;W5R86YT+@!);7!O<W-I8FQE(&0G97AT<F%I<F4@;&5S(&3I=&%I
M;',@9'4@8V5R=&EF:6-A=`!);7!O<W-I8FQE(&1E(&-H87)G97(@;&$@9.EF
M:6YI=&EO;B!D92`E<RX`26UP;W-S:6)L92!D92!DZ7!L86-E<B!L92!F:6-H
M:65R(%9&4RX`26UP;W-S:6)L92!D)V]U=G)I<B!L92!F:6-H:65R(%9&4R"K
MH"5SH+LN`$EM<&]S<VEB;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!61E,@96X@
MZ6-R:71U<F4N`$EM<&]S<VEB;&4@9"=O=79R:7(@=6X@9FEC:&EE<B!61E,N
M`$]U=F5R='5R92!I;7!O<W-I8FQE(&1E(&PG87)C:&EV92!C;VUP<F5S<^EE
M+@!);7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE<B!61E,@*.EC:&5C(&1E
M(&9I;&5S:7IE*"DI+@!);7!O<W-I8FQE(&1E(&QI<F4@;&4@9FEC:&EE<B!6
M1E,@*.EC:&5C(&1E(&=E=$9I;&53:7IE*"DI+@!);7!O<W-I8FQE(&1E(&QI
M<F4@;&4@9FEC:&EE<J`Z(`!,96-T=7)E(&1U('+I<&5R=&]I<F4@<F%C:6YE
M(%9&4R!I;7!O<W-I8FQE+@!);7!O<W-I8FQE(&1E(')E;F]M;65R("5S(&5N
M("5SH#H@;&4@9&]S<VEE<B!C:6)L92!E>&ES=&4@9.EJX`!);7!O<W-I8FQE
M(&1E(')E;F]M;65R(&QE('+I<&5R=&]I<F4@5D93+@!);7!O<W-I8FQE(&1E
M(')E;F]M;65R(&QE('+I<&5R=&]I<F4@5D93H#H@)7,N`$EM<&]S<VEB;&4@
M9&4@<F5N;VUM97(@;&4@9FEC:&EE<B!61E,@JZ`E<Z"[+@!);7!O<W-I8FQE
M(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93("5S+R5S+@!);7!O<W-I8FQE
M(&1E(')E;F]M;65R(&QE(&9I8VAI97(@5D93+@!);7!O<W-I8FQE(&0G97CI
M8W5T97(@)VUK:7-O9G,G+@!);7!O<W-I8FQE(&1E('1R861U:7)E(&-E(&1O
M8W5M96YT(%=O<F0N`$EM<&]S<VEB;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!6
M1E,@JZ`E<Z"[+@!);7!O<W-I8FQE(&0GZ6-R:7)E(&QE<R!D;VYNZ65S(&1U
M(&9I8VAI97(@5D93("AC;W!Y*"D@:6UP;W-S:6)L92DN`$EM<&]S<VEB;&4@
M9"?I8W)I<F4@;&5S(&1O;F[I97,@9'4@9FEC:&EE<B!61E,N`$EM<&]S<VEB
M;&4@9"?I8W)I<F4@;&4@9FEC:&EE<B!61E,L(&QE('%U;W1A('-E<F%I="!D
MZ7!A<W/I+@!3;W5L:6=N97(`06YN=6QE<B!L97,@8VAA;F=E;65N=',`06YN
M=6QE('9O=')E(&1E<FYIZ')E(&%C=&EO;@!2Z7!O;G-E(&EN871T96YD=64@
M9'4@<V5R=F5U<B!L;W)S(&1E(&QA(&-O;FYE>&EO;J`Z(`!2Z7!O;G-E(&EN
M871T96YD=64@9'4@<V5R=F5U<B#@H#H@`$AO<G,@8V%TZ6=O<FEE`%5N:6-O
M9&4@*%541BTX*0#);6ER871S($%R86)E<R!5;FES`%)O>6%U;64M56YI`,ET
M871S+55N:7,`SFQE<R!E>'3I<FEE=7)E<R!D97,@R71A=',M56YI<P!5;FET
MZ7,`26YC;VYN=0!A<&EM<V=I9"!I;F-O;FYU("A!4$D@365S<V%G92!)1"DN
M`&-L:6US9VED(&EN8V]N;G4@*$-L:65N="!-97-S86=E($E$*2X`16UP;&%C
M96UE;G0@<^EL96-T:6]N;ND@:6YC;VYN=2X`3F]M(&0G=71I;&ES871E=7(@
M;W4@;6]T(&1E('!A<W-E(&EN8V]N;G4N`$3I;&EE<B!L)^ELZ6UE;G0@8V]U
M<F%N=`!386YS(&YO;0!,97,@<V-R:7!T<R!N;VXM<')I=FELZ6=IZ7,@;F4@
M<&5U=F5N="!A8V/I9&5R(&%U>"!F;VYC=&EO;G,@8V]U<&5R+V-O<&EE<B]C
M;VQL97(@<&]U<B!D97,@<F%I<V]N<R!D92!SZ6-U<FETZ2X@07!P=7EE>B!S
M=7(@3TL@<&]U<B!V;VER('5N92!N;W1E('1E8VAN:7%U92!S=7(@;6]Z:6QL
M82YO<F<@<75I('9O=7,@97AP;&EQ=65R82!C;VUM96YT(&%U=&]R:7-E<B!U
M;B!S8W)I<'0@X"!U=&EL:7-E<B!L92!P<F5S<V4M<&%P:65R<P!296UE='1R
M92!L82!C;W5L975R(.`@>NER;P!%>'1E;G-I;VX@;F]N('!R:7-E(&5N(&-O
M;7!T90!-;V1I9FEE<@!-;V1I9FEE<B`E<P!-;V1I9FEE<B!L)W5T:6QI<V%T
M975R`$UI<V4@X"!J;W5R(&1E(*N@)7.@NRX`3&4@<V-R:7!T(&1E(&UI<V4@
MX"!J;W5R(&5S="!S=7!P<FEMZ0!#:&%R9V5R`%1O=7,@;&5S(&9I8VAI97)S
M(&1E(&-O;F9I9W5R871I;VX@9&5S(&%P<&QI8V%T:6]N<R!O;G0@Z73I(&5N
M=F]YZ7,@<W5R(&QE('-E<G9E=7(N`$QE='1R97,@;&%T:6YE<R!M86IU<V-U
M;&5S`$YO;6)R97,@<F]M86EN<R!M86IU<V-U;&5S`%5R=6=U87D`16UP;&]Y
MZ2!A8W1U96QL96UE;G2@.B`E<P!5=&EL:7-E<B!34TP`571I;&ES97(@<VD@
M;&4@;F]M(&0G=71I;&ES871E=7(O;6]T(&1E('!A<W-E(&5S="!D:69FZ7)E
M;G0@9'4@<V5R=F5U<B!)35-0+@!5=&EL:7-A=&5U<@!,)W5T:6QI<V%T975R
M("5S(&XG82!P87,@;"=A=71O<FES871I;VX@<&]U<B`E<RX`061M:6YI<W1R
M871I;VX@9&5S('5T:6QI<V%T975R<P!0<NEFZ7)E;F-E<R!P97)S;VYN96QL
M97,`16YR96=I<W1R96UE;G0@9&5S('5T:6QI<V%T975R<P!,)V5N<F5G:7-T
M<F5M96YT(&0G=71I;&ES871E=7(@97-T(&3I<V%C=&EVZ2!S=7(@8V4@<WES
M=.AM92X`0V]M<'1E('5T:6QI<V%T975R(&YO;B!T<F]U=ND`3F]M(&0G=71I
M;&ES871E=7(`3&4@;F]M(&1E(&-O;FYE>&EO;B"KH"5SH+L@97AI<W1E(&3I
M:N`N`$YO;2!D)W5T:6QI<V%T975RH#H`3F]M(&0G=71I;&ES871E=7*@.B``
M571I;&ES871E=7)S(&3I9FEN:7.@.@!/=7IBZ6MI<W1A;@!2Z7!E<G1O:7)E
M(%9&4R!I;F5X:7-T86YT+@!!8G-E;F-E<P!,97,@96UP;&%C96UE;G1S('9A
M;&ED97,@=')O=7;I<R!I;F-L=65N=*`Z(`!686QI9&ETZ0!686QE=7(@96X@
M;6EN=71E<R#@('!A<G1I<B!D92!M86EN=&5N86YT+@!686QE=7(@<W5PZ7)I
M975R92#@(&QA(&QO;F=U975R(&UA>&EM86QE(&1E("5S+@!686QE=7)S`%9A
M;&5U<G,@X"!SZ6QE8W1I;VYN97(@9&4`5F%N=6%T=0!687)I86)L90!6Z6[I
M>G5E;&$`R6-H96,@9&4@;&$@=NER:69I8V%T:6]N("9M9&%S:#L@8V4@;65S
M<V%G92!A('!E=70MZG1R92#I=.D@9F%L<VEF:>DN`%9E<G-I;VX`0V]N='+T
M;&4@9&4@=F5R<VEO;@!!;&EG;F5M96YT('9E<G1I8V%L`%)E;7!L:7-S86=E
M('9E<G1I8V%L`%9E<G1I8V%LH#H`5'+H<R!H875T90!6:65T;F%M`%9IZG0M
M;F%M:65N("A625-#24DI`%9O:7(@)7,`5F]I<B!U;F4@<&%G92!W96(@97AT
M97)N90!6;VER(&-O;6UE("5S`,YL97,@5FEE<F=E<R!B<FET86YN:7%U97,`
MSFQE<R!6:65R9V5S(&1E<R#)=&%T<RU5;FES`%9I<VEB:6QI=.D`5FES:6)I
M;&ETZ:`Z(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!.3U1)0T4`051414Y4
M24].(2$A("!355!04DE-15(@3$4@4T-225!4($U!3E5%3$Q%345.5"!$12`E
M<P!724X@=FEA($A45%``5V%L;&ES(&5T($9U='5N80!!='1E;G1I;VX`364`
M4'+I=FES:6]N<R!MZ73I;P!$;VYNZ65S(&WI=.EO(&9O=7)N:65S('!A<@!7
M96%T:&5R+F-O;0!796(`4VET92!W96(`0VAA<75E('-E;6%I;F4`0FEE;G9E
M;G5E`$)I96YV96YU92#@("5S`$)I96YV96YU92P@)7,`3V-C:61E;G1A;"`H
M25-/+3@X-3DM,2D`3V-C:61E;G1A;"`H25-/+3@X-3DM,34I`%-A:&%R82!/
M8V-I9&5N=&%L`%%U96QL92!A<'!L:6-A=&EO;B`E<R!D;VET+6EL('!RZ7-E
M;G1E<B!A<'+H<R!L82!C;VYN97AI;VZ@/P!1=65L(&5S="!L92!C87)A8W3H
M<F4@9&4@<^EP87)A=&EO;J`_`%%U96P@97-T(&QE(&-A<F%C=.AR92!D92!C
M:71A=&EO;J`_`$-A<G1E(%=H97)E:7,@075S=')A;&EE`%%U96QL97,@<&AA
M<V5S`%%U96QL97,@97AT96YS:6]N<R!A8W1I=F5R('!O=7(@;"?I9&ET975R
M(%)I8V@@5&5X="X`3&%R9V5U<@!,87)G975R(&5N('5N:73I<R!#4U,`3&%R
M9V5U<B!D=2!M96YU(&1E(&=A=6-H92`E<R`@*&QA(&-O;F9I9W5R871I;VX@
M<')E;F1R82!E9F9E="#@(&QA('!R;V-H86EN92!C;VYN97AI;VXIH#H`3&%R
M9V5U<B!D=2!T86)L96%U`%5N:73I(&1E(&QA<F=E=7(`3&%R9V5U<J`Z`%=I
M:VD`5F5N=`!696YT('3T="!L92!M871I;@!6:71E<W-E(&1U('9E;G0@96X@
M;B9O96QI9SMU9',`5F5N=*`Z`%9E;G2@.B``4V%G97-S90!,:7-T92!D92!V
M)F]E;&EG.W5X`%1R879A:6P`061R97-S92!P<F]F97-S:6]N;F5L;&4`5.EL
MZ7!H;VYE('!R;V9E<W-I;VYN96P`3F]M8G)E(&1E(&-H86UP<R!I;F-O<G)E
M8W0@X"!L82!L:6=N92`E9"X@)60@871T96YD=7,L("5D('1R;W5VZ7,N`$YO
M;6)R92!D92!C:&%M<',@:6YC;W)R96-T+B`E9"!A='1E;F1U<RP@)60@=')O
M=7;I<RX`1.EC86QA9V4@)60@:6YC;W)R96-T(&QO<G,@9&4@;&$@;&5C='5R
M92!D92!F:6-H:65R(%9&4RX`6"U2968`0V]N=')A:6YT97,@8F%S:7%U97,@
M6#4P.78S`%5T:6QI<V%T:6]N(&1E(&-LZ2#I=&5N9'5E(%@U,#EV,P!!=71R
M92!N;VT@9'4@<W5J970@6#4P.78S`$ED96YT:69I86YT(&1E(&-LZ2!D=2!S
M=6IE="!8-3`Y=C,`17AT96YS:6]N<R!8-3`Y=C,`04$`04%!00!#87)T92"K
MH%EA:&]OH"&@NP!!;FYU96QL96UE;G0`6>EM96X`3W5I`$]U:2P@:B=A8V-E
M<'1E`%9O=7,@ZG1E<R!E;B!M;V1E(*N@5&5X=&6@NRX@571I;&ES97H@;&4@
M8F]U=&]N(%L\/ET@<&]U<B!R979E;FER(&%U(&UO9&4@JZ!765-)5UE'H+LN
M`%9O=7,@;B?J=&5S('!A<R!A=71O<FESZ2#@(&-RZ65R('!L=7,@9&4@)60@
M8FQO8W,N`%9O=7,@;B?J=&5S('!A<R!A=71H96YT:69IZ2X`5F]U<R!N92!P
M;W5V97H@<&%S(&%V;VER(&QE(&-A<F%C=.AR92"K7+L@9&%N<R!V;W1R92!N
M;VT@8V]M<&QE="X`5F]U<R!N)V%V97H@<&%S('-A:7-I('5N92!A9')E<W-E
M(.EL96-T<F]N:7%U92!V86QI9&4N`%9O=7,@;B=A=F5Z('!A<R!A<W-O8VGI
M(&QE<R!C:&%M<',@9'4@9FEC:&EE<B!I;7!O<G3I(&%U>"!C:&%M<',@8V]R
M<F5S<&]N9&%N=',@9&%N<R`E<RX`5F]U<R!A=F5Z(.ETZ2!DZ6-O;FYE8W3I
M+@!6;W5S(&1E=F5Z(&EN<V-R:7)E('5N(&YU;>ER;R!D92!C96QL=6QA:7)E
M('9A;&ED92P@<V5U;',@9&5S(&YO;6)R97,@970@=6X@JZ`KH+L@;W!T:6]N
M;F5L('!O=7(@;&5S(&%P<&5L<R!I;G1E<FYA=&EO;F%U>"X`5F]U<R!N)V%V
M97H@<&%S('-A:7-I('5N92!E;G1RZ64@=F%L:61E+@!6;W5S(&1E=F5Z(&-O
M;F9I9W5R97(@=6X@8F%C:V5N9"!$871A5')E92!P;W5R('5T:6QI<V5R(&QE
M<R!I;G-C<FEP=&EO;G,`5F]U<R!D979E>B!C;VYF:6=U<F5R('5N(&UO9'5L
M92!61E,N`%9O=7,@9&5V97H@9.EC<FER92!L92!P<F]B;.AM92!A=F%N="!D
M92!N;W5S(&9A:7)E('!A<G9E;FER(&QE(')A<'!O<G0N`%9O=7,@9&5V97H@
M96YT<F5R('5N92!54DP@;_D@<&]I;G1E(&1E(&QI96XN`$EL(&9A=70@<^EL
M96-T:6]N;F5R('5N('-E<G9E=7(@X"!S=7!P<FEM97(N`%9O=7,@9&5V97H@
M<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@<F5T:7)E<BX@`%9O=7,@9&5V
M97H@<W#I8VEF:65R('5N('5T:6QI<V%T975R(.`@<F5T:7)E<BX`5F]U<R!D
M979E>B!S<.EC:69I97(@=6X@=71I;&ES871E=7(@X"!A:F]U=&5R+@!6;W5S
M(&1E=F5Z('-PZ6-I9FEE<B!L92!N;VT@9&4@;"=U=&EL:7-A=&5U<B#@(&UO
M9&EF:65R+@!6;W5S(&1E=F5Z(&EN9&EQ=65R('%U96QL92!A8W1I;VX@86-C
M;VUP;&ER+@!6;W5S(&1E=F5Z(.EC<FER92!U;B!N;VT@<&]U<B!L82!N;W5V
M96QL92!C873I9V]R:64N`%9O=7,@9&5V97H@9F]U<FYI<B!U;B!NL"!D92!T
MZ6SI<&AO;F4@:71A;&EE;@!6;W1R92!S97-S:6]N("5S(&$@97AP:7+I+B!6
M975I;&QE>B!V;W5S(')E8V]N;F5C=&5R+@!6;W1R92!A9')E<W-E(&1E(&-O
M=7)R:65L`%9O=')E(&%D<F5S<V4@9&4@8V]U<G)I96P@JR!$93H@NZ`Z`%9O
M<R!D;VYNZ65S('!E<G-O;FYE;&QE<P!6;W1R92!A9')E<W-E($EN=&5R;F5T
M(&$@8VAA;F?I(&1E<'5I<R!L)V]U=F5R='5R92!D92!V;W1R92!S97-S:6]N
M("5S+B`@4&]U<B!V;W1R92!SZ6-U<FETZ2P@=F]U<R!D979E>B!V;W5S(')E
M8V]N;F5C=&5R+@!6;W1R92!N;VT`5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF
M:6-A=&EO;B!N92!S=7!P;W)T92!P87,@;"=A:F]U="!D)W5T:6QI<V%T975R
M<RP@4VD@=F]U<R!S;W5H86ET97H@=71I;&ES97H@2&]R9&4@<&]U<B!A9&UI
M;FES=')E<B!L97,@8V]M<'1E<R!U=&EL:7-A=&5U<G,L('9O=7,@9&5V97H@
M=71I;&ES97(@=6X@875T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO;BX`
M5F]T<F4@;6]D=6QE(&0G875T:&5N=&EF:6-A=&EO;B!N)V5S="!P87,@96X@
M;65S=7)E(&0GZ71A8FQI<B!U;F4@;&ES=&4@9&5S('5T:6QI<V%T975R<RP@
M;W4@8V5T=&4@9F]N8W1I;VX@82#I=.D@<F5T:7+I92!P;W5R('5N92!A=71R
M92!R86ES;VXN`%9O=')E(&YA=FEG871E=7(@<V5M8FQE(&%V;VER(&-H86YG
MZ2!D97!U:7,@;&4@9.EB=70@9&4@=F]T<F4@<V5S<VEO;B`E<RX@(%!O=7(@
M=F]T<F4@<^EC=7)I=.DL('9O=7,@9&5V97H@=F]U<R!R96-O;FYE8W1E<BX`
M5F]T<F4@;F%V:6=A=&5U<B!N92!S=7!P;W)T92!P87,@8V5T=&4@;W!T:6]N
M`%9O=')E(&YA=FEG871E=7(@;F4@<')E;F0@<&%S(&5N(&-O;7!T92!C971T
M92!O<'1I;VX@9"=I;7!R97-S:6]N+B!0<F5S<V5Z($-O;G1R]&QE+T-O;6UA
M;F1E("L@4"!P;W5R(&EM<')I;65R`%9O=')E(&9U<V5A=2!H;W)A:7)E(&%C
M='5E;*`Z`%9O=')E('!R;V9I;"!P87(@9.EF875T(&$@Z73I(&UO9&EF:>DN
M`%!R;V9I;"!P87(@9.EF875TH#H`5F]T<F4@;F]M(&-O;7!L972@.@!6;W1R
M92!C;VUP=&4@82!E>'!I<NDN`%9O=')E(&YO=79E874@;6]T(&1E('!A<W-E
M('!O=7(@)7,@97-TH#HE<P!6;W,@;W!T:6]N<R!O;G0@Z73I(&UI<V5S(.`@
M:F]U<B!P;W5R(&QA(&1U<NEE(&1E(&-E='1E('-E<W-I;VXN`%9O<R!O<'1I
M;VYS(&]N="#I=.D@;6ES97,@X"!J;W5R+@!6;W1R92!M;W0@9&4@<&%S<V4@
M82#I=.D@<F5M:7,@X"!ZZ7)O`%9O=')E(&UO="!D92!P87-S92!A(.ETZ2!R
M96UI<R#@('KI<F\L(';I<FEF:65R('9O=')E(&-O=7)R:65R(&5T(&-O;FYE
M8W1E>BUV;W5S(&%V97H@=F]T<F4@;F]U=F5A=2!M;W0@9&4@<&%S<V4N`%9O
M=')E(&UO="!D92!P87-S92!A(&5X<&ERZ2X`5F]S('-E<G9E=7)S(&1I<W1A
M;G1SH#H`66]U9V]S;&%V:64`6F'O<F4`6F%M8FEE`%II;6)A8G=E`%II<'!Y
M`%M#86-H97(@;&5S(&-I=&%T:6]N<UT`6U)A<'!O<G0@9&4@<')O8FSH;65=
M`%M!9F9I8VAE<B!L92!T97AT92!C:73I("T`6T%F9FEC:&5R(&QE('1E>'1E
M(&-I=.D@+2`E<R!L:6=N97-=`%ML:6=N92`E<R!D92`E<UT`7T%D;6EN:7-T
M<F%T:6]N`$QI9VYE(&1E(%]C;VUM86YD90!?1&%T851R964`4W5P<')I;65R
M(&QA(%]R86YGZ64`7T=R;W5P97,`7T%I9&4`4')O<')?:>ETZ7,@9&4@;"=I
M;6%G92XN+@!?0V]N;F5X:6]N`%]$Z6-O;FYE>&EO;@!?36]D:69I97(@=6X@
M;&EE;B!W96(N+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]2971I<F5R('5N
M(&QI96X`7T-O;F9I9W5R871I;VX`4')O<')IZ73I<R!D=2!?=&%B;&5A=0!?
M571I;&ES871E=7)S`&-A<FYE="!D)V%D<F5S<V5S`&1E<W1I;F%T86ER92!I
M;F-O;FYU`&%G96YD80!C86QM90!I;7!O<W-I8FQE(&1E(&-RZ65R(&QE(&9I
M8VAI97(@9&4@<V]R=&EE`&EM<&]S<VEB;&4@9"=O=79R:7(@;"=E;G1RZ64`
M8VQI<75E>B!I8VD`97)R975R(&0G=71I;&ES871I;VX@9&4@;&$@;&EG;F4@
M9&4@8V]M;6%N9&4`97)R975R(&1E(&-O;F9I9W5R871I;VX`86)S96YC92!C
M<FET:7%U92!D)W5N(&9I8VAI97(@<WES=.AM90!E<G)E=7(@9&4@9F]R;6%T
M(&1E(&1O;F[I90!M;V1I9FEE<@!E;G1RZ64@;F]N('1R;W5VZ0!T;VUB86YT
M`&9I8VAI97(`9&5P=6ES(&QE("5S("@E<RD@X"`E<R`E<P!E;B!R869A;&4`
M:*`Z`&AH`&YO;2!D)VCT=&4@:6YC;VYN=0!I;6WI9&EA=&5M96YT`&EN8V]R
M<&]RZ64`97)R975R(&0G96YT<NEE+W-O<G1I90!E<G)E=7(@;&]G:6-I96QL
M92!I;G1E<FYE`&QI9VYE<UT`97)R975R(&UK:7-O9G,@8V]D92`E9"!E;B!C
M<NEA;G0@;"=)4T\`;6T`;F]M`&YO;B!P<FES(&5N(&-O;7!T90!P87,@96YC
M;W)E('!R:7,@96X@8V]M<'1E`&)L;V,M;F]T97,`<&]U<F-E;G1A9V4`<&5R
M;6ES<VEO;B!R969U<^EE`'!I>&5L<P!E<G)E=7(@9&ES=&%N=&4@9&%N<R!L
M92!P<F]T;V-O;&4`<R?I;&5V86YT`'-E<G9I8V4@;F]N(&1I<W!O;FEB;&4N
M`&UO;G1R97(@;&5S(&1I9F;I<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S
M<P!F:7AE`&5R<F5U<B!S>7-TZ&UE`&QI<W1E(&1E('3B8VAE<P#I8VAE8R!T
M96UP;W)A:7)E`&5N=')E>B!L92!M;W0@9&4@<&%S<V4@9&5U>"!F;VES('!O
M=7(@8V]N9FER;65R`'5N:69IZ0!S86YS(&YO;0!3Z6QE8W1I;VX@9"=U=&EL
M:7-A=&5U<@!V0V%R9`!LH#H`=V5A=&AE<BYC;VT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L;V-A;&4O971?144O3$-?34534T%'15,`````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@
M,#(Q-#4W`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E=%]%12]H96QP
M+GAM;```````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,S,R,"`Q,#4Q-30S-#$T,2`P,C$T,C$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CPA
M+2T@)$AO<F1E.B!H;W)D92]L;V-A;&4O971?144O:&5L<"YX;6PL=B`Q+C(@
M,C`P-"\P-2\R-R`R,#HR,CHQ-2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE
M;G1R>2!I9#TB<W5M;6%R>2(@<W1A=&4](FYE=R(^"CQT:71L93Y4:&4@4&]R
M=&%L(%!A9V4\+W1I=&QE/@H@/'!A<F$^"B`@5&AI<R!P;W)T86P@<&%G92!P
M<F]V:61E<R!A('%U:6-K('-U;6UA<GD@;V8@86QL('EO=7(@:6UP;W)T86YT
M"B`@:6YF;W)M871I;VXN($9O<B!E>&%M<&QE+"!I="!M:6=H="!S:&]W(&AO
M=R!M86YY(&YE=R!E+6UA:6P@;65S<V%G97,@>6]U"B`@:&%V92!I;B!Y;W5R
M($E.0D]8+"!U<&-O;6EN9R!E=F5N=',@;VX@>6]U<B!C86QE;F1A<BP@=&%S
M:W,@;VX@>6]U<B!T;RUD;PH@(&QI<W0L(&AE861L:6YE<R!F<F]M('-E;&5C
M=&5D(&YE=W,@<V5R=FEC97,L(&%N9"!S;R!O;BX@($UA;GD@;V8@=&AE<V4*
M("!S=6UM87)I97,@=VEL;"!C;VYT86EN('%U:6-K('-H;W)T8W5T<R!T;R!C
M;VUM;VX@9G5N8W1I;VYS+"!S=6-H(&%S"B`@8V]M<&]S:6YG(&$@;F5W(&UA
M:6P@;65S<V%G92P@8W)E871I;F<@82!N97<@8V%L96YD87(@979E;G0@;W(@
M=&%S:RP@971C+@H@/"]P87)A/@H@/'!A<F$^"B`@5&AE(&-O;G1E;G1S(&]F
M('1H:7,@<&]R=&%L('!A9V4@87)E(&-U<W1O;6EZ86)L92!V:6$@=&AE($QA
M>6]U="!B=71T;VXN"B`@1F]R(&5X86UP;&4L('EO=2!C86X@8VAO;W-E('=H
M:6-H(&ET96US('1O(&EN8VQU9&4@;VX@=&AI<R!P;W)T86P@<&%G92!A<PH@
M('=E;&P@87,@:6X@=VAI8V@@;W)D97(@=&AE>2!A<F4@<VAO=VXN"B`\+W!A
M<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)N879B87(B('-T871E/2)N97<B
M/@H\=&ET;&4^5&AE($%P<&QI8V%T:6]N($YA=FEG871I;VX@0F%R/"]T:71L
M93X*(#QP87)A/@H@($%T('1H92!L969T(&AA;F0@<VED92!O9B!T:&4@=V5B
M('!A9V4@:7,@=&AE(&%P<&QI8V%T:6]N(&YA=FEG871I;VX@8F%R+@H@($-L
M:6-K(&]N('1H92!I8V]N<R!O;B!T:&ES(&YA=FEG871I;VX@8F%R('1O('%U
M:6-K;'D@86YD(&5A<VEL>2!S=VET8V@*("!B971W965N('1H92!A=F%I;&%B
M;&4@87!P;&EC871I;VYS+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B('-T871E/2)N97<B/@H@("`@/'1I
M=&QE/E!R969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P
M97)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K
M('1H:7,@8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I9#TB
M<')E9G,M8V]N9FER;5]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@("`\
M=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!#;VYF:7)M($UA:6YT
M96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@268@>6]U('=O=6QD(&QI
M:V4@=&\@8V]N9FER;2!A;&P@;6%I;G1E;F%N8V4@=&%S:W,@8F5F;W)E('1H
M97D@87)E(')U;BP@8VAE8VL@=&AI<R!B;W@N($EF(&QE9G0@=6YC:&5C:V5D
M+"!A;&P@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!T:&%T(&YE960@=&\@8F4@
M<G5N('=I;&P@8F4@<&5R9F]R;65D(&%U=&]M871I8V%L;'D@=VET:"!N;R!C
M:&%N8V4@=&\@8V%N8V5L(&]N(&QO9VEN+@H@("`@/"]P87)A/@H\+V5N=')Y
M/@H\+VAE;'`^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O971?144O3$-?34534T%'
M15,O:&]R9&4N;6\`````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,#(R,S(@
M,3`U,34T,S0Q-#$@,#(S,3<W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````-X2!)4`````CP<``!P```"4/```'PH```QY````
M````B*$```X```")H0``#P```)BA```-````J*$```@```"VH0``"P```+^A
M```,````RZ$```0```#8H0``&````-VA```;````]J$``"T````2H@``'0``
M`$"B```D````7J(``"D```"#H@``&0```*VB```F````QZ(```P```#NH@``
M)````/NB```/````(*,```L````PHP``#@```#RC```%````2Z,``"@```!1
MHP``"````'JC```*````@Z,``!4```".HP``$@```*2C```+````MZ,``(4`
M``##HP``#@```$FD```*````6*0```T```!CI```#@```'&D```1````@*0`
M``T```"2I```#````*"D```-````K:0```8```"[I```E````,*D```*````
M5Z4```\```!BI0``&````'*E```,````BZ4```X```"8I0``#@```*>E```(
M````MJ4```D```"_I0``+@```,FE```:````^*4``#(````3I@``.````$:F
M``!4````?Z8``%$```#4I@``6@```":G``!7````@:<``#0```#9IP``"0``
M``ZH```-````&*@```<````FJ```"@```"ZH```/````.:@```4```!)J```
M!@```$^H```1````5J@```@```!HJ```"0```'&H```)````>Z@``"4```"%
MJ```(````*NH```3````S*@``!````#@J```#P```/&H```*`````:D```,`
M```,J0``#P```!"I```4````(*D```D````UJ0``#0```#^I```2````3:D`
M`!D```!@J0``'@```'JI```/````F:D```H```"IJ0``#P```+2I```(````
MQ*D``"0```#-J0``%````/*I```6````!ZH```@````>J@``3@```">J```M
M````=JH``!D```"DJ@``!P```+ZJ```,````QJH``"P```#3J@``#@````"K
M```#````#ZL```L````3JP``!P```!^K```'````)ZL```4````OJP``!0``
M`#6K```*````.ZL```,```!&JP``%P```$JK```*````8JL```\```!MJP``
M#@```'VK```8````C*L``",```"EJP``#@```,FK```4````V*L``!<```#M
MJP``%P````6L```7````':P``!,````UK```#P```$FL```.````6:P``!\`
M``!HK```'0```(BL```'````IJP```8```"NK```"````+6L```/````OJP`
M``8```#.K```"@```-6L```3````X*P```L```#TK```$`````"M```5````
M$:T``!4````GK0``!P```#VM```0````1:T```4```!6K0``%0```%RM```1
M````<JT```P```"$K0``.P```)&M```X````S:T```D````&K@``!P```!"N
M```4````&*X```,````MK@``!0```#&N```0````-ZX```D```!(K@``$P``
M`%*N```Y````9JX``!(```"@K@``)P```+.N```L````VZX``"H````(KP``
M)0```#.O```*````6:\```8```!DKP``"0```&NO```'````=:\``"\```!]
MKP``-P```*VO```N````Y:\``%4````4L```+0```&JP```M````F+```#T`
M``#&L```/P````2Q```M````1+$``$````!RL0``(P```+.Q```C````U[$`
M`$````#[L0``+0```#RR```S````:K(``!4```">L@``&0```+2R```I````
MSK(``"0```#XL@``*````!VS```1````1K,```H```!8LP``#````&.S```*
M````<+,``!````![LP``%@```(RS```6````H[,```<```"ZLP``!P```,*S
M```4````RK,```H```#?LP``"````.JS```G````\[,```@````;M```!P``
M`"2T```'````++0```8````TM```!0```#NT```'````0;0```8```!)M```
M"````%"T```I````6;0```X```"#M```"@```)*T```$````G;0```<```"B
MM```"0```*JT```&````M+0``!$```"[M```!P```,VT```6````U;0```0`
M``#LM```"````/&T```&````^K0```T````!M0``!@````^U```>````%K4`
M`!$````UM0``"````$>U```-````4+4```P```!>M0``!P```&NU```#````
M<[4```,```!WM0``%P```'NU```3````D[4``!T```"GM0``"````,6U```$
M````SK4```@```#3M0``"````-RU``!!````Y;4``!H````GM@``*P```$*V
M```@````;K8``!4```"/M@``!@```*6V```&````K+8``!4```"SM@``&```
M`,FV```B````XK8``"X````%MP``'0```#2W```A````4K<``%0```!TMP``
M*0```,FW```*````\[<```<```#^MP``!P````:X```5````#K@```X````D
MN```"@```#.X```/````/K@```T```!.N```#P```%RX```-````;+@```D`
M``!ZN```%````(2X```&````F;@``!@```"@N```'0```+FX```3````U[@`
M`!$```#KN```%````/VX```$````$KD```8````7N0``%````!ZY``!4````
M,[D``&0```"(N0``!````.VY```.````\KD```4````!N@``!0````>Z```;
M````#;H``!H````IN@``$P```$2Z```1````6+H``!$```!JN@``'````'RZ
M```J````F;H``!````#$N@``(0```-6Z```%````][H``!,```#]N@``"P``
M`!&[```2````';L```H````PNP``#P```#N[```-````2[L``!$```!9NP``
M$P```&N[```,````?[L```8```",NP``#````).[```&````H+L``!<```"G
MNP``$````+^[```1````T+L```@```#BNP``!0```.N[```,````\;L``!``
M``#^NP``!0````^\```-````%;P```8````CO```!P```"J\```-````,KP`
M``<```!`O```"P```$B\```'````5+P```<```!<O```"0```&2\```)````
M;KP```H```!XO```&0```(.\```]````G;P``!T```#;O```#````/F\```0
M````!KT```4````7O0``)0```!V]```2````0[T``!,```!6O0``*P```&J]
M```[````EKT``"````#2O0``"````/.]```V````_+T``!`````SO@``"```
M`$2^```,````3;X```8```!:O@``!````&&^```/````9KX```X```!VO@``
M!P```(6^```*````C;X```T```"8O@``'@```*:^```;````Q;X``"$```#A
MO@``'@````._```9````(K\``!X````\OP``'0```%N_```;````>;\``"$`
M``"5OP``+@```+>_```F````YK\``!L````-P```'@```"G````<````2,``
M`"8```!EP```*P```(S````S````N,```"8```#LP```*P```!/!```X````
M/\$``!T```!XP0``%0```);!```O````K,$``"````#<P0``$@```/W!```I
M````$,(``!X````ZP@``(````%G"```2````>L(``*(```"-P@``%@```###
M```C````1\,``"@```!KPP``*0```)3#```H````OL,``!\```#GPP``%0``
M``?$```@````'<0``"4````^Q```*````&3$```M````C<0``#````"[Q```
MD@```.S$```A````?\4``!8```"AQ0``'````+C%```F````U<4``"H```#\
MQ0``00```"?&``!$````:<8```P```"NQ@``!P```+O&```'````P\8```8`
M``#+Q@``#0```-+&```0````X,8``!(```#QQ@``$P````3'```2````&,<`
M``<````KQP``!````#/'```0````.,<``!````!)QP``#````%K'```.````
M9\<```T```!VQP``#P```(3'```3````E,<```T```"HQP``*````+;'```#
M````W\<```T```#CQP``!@```/''```1````^,<``!<````*R```&P```"+(
M```.````/L@```(```!-R```20```%#(```%````FL@``!````"@R```#P``
M`+'(```$````P<@```T```#&R```#@```-3(```#````X\@```X```#GR```
M"````/;(```/````_\@```\````/R0``!P```!_)```-````)\D``!`````U
MR0``#0```$;)```+````5,D```8```!@R0``"P```&?)```,````<\D```H`
M``"`R0``$0```(O)```9````G<D```L```"WR0``#0```,/)```B````T<D`
M``\```#TR0``&P````3*```T````(,H```H```!5R@``&````&#*```9````
M><H``!8```"3R@``(@```*K*```-````S<H```<```#;R@``%````./*```+
M````^,H``"(````$RP``+P```"?+```+````5\L```D```!CRP``&0```&W+
M```+````A\L``!<```"3RP``%P```*O+```)````P\L``!8```#-RP``#P``
M`.3+```9````],L``!8````.S```#@```"7,```8````-,P```@```!-S```
M#0```%;,```F````9,P``$,```"+S```"````,_,```2````V,P``!\```#K
MS```"`````O-```+````%,T``"\````@S0``#@```%#-```%````7\T```8`
M``!ES0``10```&S-```#````LLT```<```"VS0``!````+[-```*````P\T`
M``H```#.S0``#P```-G-```0````Z<T``!<```#ZS0``$0```!+.```9````
M),X``!<````^S@``"0```%;.```%````8,X``#T```!FS@``"P```*3.```*
M````L,X```(```"[S@``!0```+[.```-````Q,X``!L```#2S@``%P```.[.
M```4````!L\```D````;SP``#@```"7/```-````-,\``!(```!"SP``.```
M`%7/```@````CL\```@```"OSP``#@```+C/``![````Q\\``!@```!#T```
M&````%S0```1````==````<```"'T```!0```(_0```8````E=```!X```"N
MT```&P```,W0```9````Z=```!L````#T0``&0```!_1```3````.=$```<`
M``!-T0``"````%71```&````7M$```8```!ET0``$````&S1```/````?=$`
M`!````"-T0``#P```)[1```+````KM$```\```"ZT0``#````,K1```/````
MU]$```<```#GT0``!@```._1```.````]M$```P````%T@``*````!+2```/
M````.](```@```!+T@``"````%32```3````7=(``!X```!QT@``(0```)#2
M```@````LM(``!D```#3T@``%P```.W2```E````!=,``!<````KTP``%@``
M`$/3```$````6M,``!L```!?TP``#0```'O3```,````B=,```,```"6TP``
M!0```)K3```(````H-,```H```"ITP``#````+33```+````P=,``!````#-
MTP``#````-[3```.````Z],```L```#ZTP``!`````;4```$````"]0``!,`
M```0U```%````"34```,````.=0```D```!&U```#@```%#4```+````7]0`
M`!L```!KU```!P```(?4```'````C]0```H```"7U```#0```*+4```)````
ML-0```0```"ZU```!0```+_4```#````Q=0``!@```#)U```"@```.+4```$
M````[=0``"8```#RU```#@```!G5``!\````*-4``!4```"EU0``!0```+O5
M```'````P=4```P```#)U0``"````-;5```*````W]4```8```#JU0``"```
M`/'5```"````^M4```8```#]U0``!@````36```4````"]8```T````@U@``
M$````"[6```;````/]8```0```!;U@``"0```&#6```0````:M8```D```![
MU@``"0```(76```%````C]8``!H```"5U@``"````+#6```&````N=8``!D`
M``#`U@``#@```-K6```'````Z=8```<```#QU@``!0```/G6```)````_]8`
M``H````)UP``#@```!37```"````(]<```8````FUP``"P```"W7```-````
M.=<```D```!'UP``!@```%'7```2````6-<```D```!KUP``!P```'77```4
M````?=<``!T```"2UP``0@```+#7```E````\]<``"4````9V```!@```#_8
M```*````1M@```0```!1V```"0```%;8```(````8-@``!$```!IV```"0``
M`'O8```&````A=@```T```",V```!@```)K8```$````H=@``#D```"FV```
M/0```.#8```Z````'MD``!X```!9V0``!0```'C9```.````?MD```0```"-
MV0``!@```)+9```'````F=D``"$```"AV0``#0```,/9```5````T=D```8`
M``#GV0``!````.[9```1````\]D```8````%V@``"@````S:```B````%]H`
M``0````ZV@``!0```#_:```=````1=H```0```!CV@``#````&C:```.````
M==H```H```"$V@``"````(_:```)````F-H```4```"BV@``.@```*C:```P
M````X]H``#4````4VP``*0```$K;``!'````=-L``#@```"\VP``*0```/7;
M```_````']P``"X```!?W```+0```([<```?````O-P```\```#<W```$@``
M`.S<```+````_]P``"8````+W0``*0```#+=```D````7-T``"8```"!W0``
M"````*C=```*````L=T```D```"\W0``!P```,;=```@````SMT``"````#O
MW0``)@```!#>```*````-]X``!D```!"W@``*0```%S>```6````AMX``!(`
M``"=W@``!P```+#>```*````N-X```P```##W@``#P```-#>```0````X-X`
M`$````#QW@``<````#+?``!F````H]\```X````*X```"0```!G@```*````
M(^```!(````NX```$P```$'@```,````5>````8```!BX```#P```&G@```2
M````>>```!````",X```$0```)W@```<````K^```",```#,X```:@```/#@
M```/````6^$```4```!KX0``$````''A```)````@N$```0```",X0``"P``
M`)'A```@````G>$``!0```"^X0``#````-/A```,````X.$```\```#MX0``
M%0```/WA```I````$^(``"H````]X@``)@```&CB```G````C^(``"D```"W
MX@``*@```.'B```9````#.,``$(````FXP``$0```&GC```2````>^,``!,`
M``".XP``%````*+C```/````M^,``!8```#'XP``%P```-[C```0````]N,`
M`!$````'Y```-````!GD```3````3N0``!(```!BY```-0```'7D```4````
MJ^0```<```#`Y```#````,CD```@````U>0``!````#VY```%`````?E```1
M````'.4``!<````NY0``'````$;E```3````8^4``!0```!WY0``&@```(SE
M```1````I^4``!H```"YY0``'@```-3E```:````\^4``!,````.Y@``%0``
M`"+F```1````..8``!<```!*Y@``%````&+F```7````=^8``!4```"/Y@``
M"0```*7F```0````K^8``!D```#`Y@``!````-KF```'````W^8```L```#G
MY@``$0```//F```&````!><```8````,YP``!@```!/G```%````&N<```<`
M```@YP``!P```"CG```%````,.<``!8````VYP``6P```$WG```&````J><`
M``8```"PYP``!````+?G```$````O.<```<```#!YP``#@```,GG```,````
MV.<```P```#EYP``#0```/+G```*`````.@```X````+Z```!0```!KH```H
M````(.@```X```!)Z```#````%CH```/````9>@```H```!UZ```"````(#H
M```)````B>@``"L```"3Z```!````+_H```(````Q.@``"8```#-Z```$@``
M`/3H```/````!^D```8````7Z0``"@```![I```'````*>D```@````QZ0``
M(````#KI```)````6^D``!0```!EZ0``#````'KI```-````A^D```X```"5
MZ0``%@```*3I```1````N^D```8```#-Z0```P```-3I```&````V.D``!D`
M``#?Z0``!P```/GI```$`````>H```L````&Z@``"P```!+J```'````'NH`
M``4````FZ@``!P```"SJ```6````-.H```T```!+Z@``#0```%GJ```*````
M9^H``!````!RZ@``#P```(/J```1````D^H``!<```"EZ@``"@```+WJ```1
M````R.H```@```#:Z@``!````./J```/````Z.H``#H```#XZ@``!0```#/K
M```,````.>L``!X```!&ZP``#@```&7K```0````=.L```L```"%ZP``#```
M`)'K```)````GNL```<```"HZP``"@```+#K```)````N^L```X```#%ZP``
M$````-3K```;````Y>L``!@````![```&@```!KL```*````->P```D```!`
M[```"@```$KL```,````5>P```\```!B[```"````'+L```&````>^P``!P`
M``""[```!P```)_L```%````I^P```L```"M[```1P```+GL```-`````>T`
M``D````/[0``!````!GM```#````'NT``!,````B[0``$P```#;M```3````
M2NT```H```!>[0```@```&GM```$````;.T``"4```!Q[0```P```)?M```%
M````F^T``"H```"A[0``"@```,SM```%````U^T```0```#=[0``"@```.+M
M```-````[>T```8```#[[0``"`````+N```(````"^X```0````4[@``!0``
M`!GN``!H````'^X```D```"([@``#````)+N```0````G^X```4```"P[@``
M!@```+;N```;````O>X``"\```#9[@``$`````GO```*````&N\```\````E
M[P``"@```#7O```)````0.\``!,```!*[P``&P```%[O```8````>N\``!<`
M``"3[P``'P```*OO```.````R^\```,```#:[P``!P```-[O```(````YN\`
M``<```#O[P``"@```/?O```+`````O````<````.\```40```!;P```0````
M:/````P```!Y\```#0```(;P```:````E/```$H```"O\```&0```/KP```&
M````%/$``!H````;\0``)0```#;Q```&````7/$```8```!C\0``'P```&KQ
M```&````BO$```D```"1\0``&````)OQ```7````M/$``"@```#,\0``!@``
M`/7Q```-````_/$``"(````*\@``5P```"WR```3````A?(``",```"9\@``
M$P```+WR```"````T?(```L```#4\@``"````.#R```-````Z?(```H```#W
M\@``!P````+S```4````"O,```8````?\P``"````";S```.````+_,```<`
M```^\P``"@```$;S```+````4?,``#(```!=\P``!P```)#S```,````F/,`
M``T```"E\P``%P```+/S```,````R_,```D```#8\P``"0```.+S```*````
M[/,```<```#W\P``"0```/_S```'````"?0```H````1]```&P```!ST```/
M````./0``!(```!(]```"@```%OT```6````9O0```D```!]]```$````(?T
M```'````F/0``!(```"@]```!````+/T```'````N/0```4```#`]```!0``
M`,;T```+````S/0``!0```#8]```$0```.WT```:````__0``!8````:]0``
M%````#'U```7````1O4``!@```!>]0``'````'?U```9````E/4```<```"N
M]0``!0```+;U```-````O/4```P```#*]0``$0```-?U```(````Z?4``!<`
M``#R]0``"P````KV```,````%O8``!\````C]@``&@```$/V```3````7O8`
M``0```!R]@``"@```'?V```$````@O8```T```"']@``#````)7V```%````
MHO8```D```"H]@``!0```++V```'````N/8```4```#`]@``!````,;V```"
M````R_8``#@```#.]@``+`````?W```2````-/<``"D```!']P``,@```''W
M```*````I/<``"P```"O]P``+@```-SW```S````"_@``#,````_^```.```
M`'/X```/````K/@``!@```"\^```$````-7X```/````YO@``!,```#V^```
M%0````KY```4````(/D``!(````U^0``%````$CY```5````7?D``"T```!S
M^0``+0```*'Y```Q````S_D``"X````!^@``+P```##Z```L````8/H``&(`
M``"-^@``$P```/#Z```-````!/L```@````2^P``%P```!O[```(````,_L`
M``P````\^P``*P```$G[```A````=?L``!H```"7^P``"0```++[``!%````
MO/L``$$````"_```!````$3\```3````2?P``!0```!=_```#@```'+\```3
M````@?P``!@```"5_```!@```*[\```)````M?P```H```"__```#P```,K\
M```0````VOP```<```#K_```#@```//\```%`````OT``!L````(_0``"```
M`"3]```&````+?T``!0````T_0``$0```$G]```.````6_T``#@```!J_0``
M`@```*/]```&````IOT```X```"M_0``!0```+S]```'````POT```X```#*
M_0``!@```-G]```H````X/T```P````)_@``'````!;^```$````,_X``"D`
M```X_@``%P```&+^```?````>OX``%P```":_@``%````/?^```^````#/\`
M`!\```!+_P``$````&O_```'````?/\```X```"$_P``#````)/_```,````
MH/\``!,```"M_P``"@```,'_```=````S/\``!D```#J_P``!0````0``0`1
M````"@`!`!$````<``$`)````"X``0`2````4P`!`!4```!F``$`$@```'P`
M`0`.````CP`!`!D```">``$`"````+@``0`)````P0`!``T```#+``$`!P``
M`-D``0`*````X0`!``<```#L``$`#P```/0``0`&````!`$!``L````+`0$`
M&@```!<!`0`*````,@$!``<````]`0$`"````$4!`0`%````3@$!`!\```!4
M`0$`!@```'0!`0`0````>P$!``@```",`0$`#0```)4!`0`(````HP$!`!X`
M``"L`0$`$@```,L!`0`L````W@$!`!H````+`@$`"0```"8"`0`*````,`(!
M`!4````[`@$`!0```%$"`0`4````5P(!``0```!L`@$`$````'$"`0`&````
M@@(!``<```")`@$`'@```)$"`0`H````L`(!``H```#9`@$`'````.0"`0`1
M`````0,!``L````3`P$`&@```!\#`0`4````.@,!``0```!/`P$`!````%0#
M`0`+````60,!``4```!E`P$`!@```&L#`0`(````<@,!``8```![`P$`"@``
M`((#`0`;````C0,!`#0```"I`P$`-````-X#`0`@````$P0!`"D````T!`$`
M(````%X$`0!!````?P0!`!H```#!!`$`*````-P$`0`I````!04!`%`````O
M!0$`(@```(`%`0`&````HP4!``@```"J!0$`!0```+,%`0`(````N04!`!D`
M``#"!0$`&0```-P%`0`J````]@4!`",````A!@$`&0```$4&`0`N````7P8!
M`#0```".!@$`"````,,&`0`7````S`8!``H```#D!@$`!P```.\&`0`A````
M]P8!`!`````9!P$`#@```"H'`0`+````.0<!``<```!%!P$`$P```$T'`0`(
M````80<!``L```!J!P$`"@```'8'`0`4````@0<!``\```"6!P$`,@```*8'
M`0`+````V0<!``X```#E!P$`!0```/0'`0`%````^@<!``4`````"`$`%P``
M``8(`0`/````'@@!``0````N"`$`"@```#,(`0`)````/@@!``L```!("`$`
M#0```%0(`0`,````8@@!``X```!O"`$`!0```'X(`0`$````A`@!``T```")
M"`$`,@```)<(`0!%````R@@!`!<````0"0$`!P```"@)`0`>````,`D!`!0`
M``!/"0$`!0```&0)`0`4````:@D!``8```!_"0$`!P```(8)`0`.````C@D!
M`"H```"="0$`!@```,@)`0`,````SPD!``T```#<"0$`$0```.H)`0`+````
M_`D!`#8````("@$`"@```#\*`0`B````2@H!``L```!M"@$`#P```'D*`0`R
M````B0H!`"4```"\"@$`,````.(*`0`Q````$PL!`"T```!%"P$`#@```',+
M`0`%````@@L!``X```"("P$`$P```)<+`0`2````JPL!``<```"^"P$`$0``
M`,8+`0`3````V`L!``<```#L"P$`%````/0+`0`8````"0P!``<````B#`$`
M!0```"H,`0`,````,`P!``P````]#`$`$@```$H,`0`$````70P!``<```!B
M#`$`"@```&H,`0`+````=0P!``P```"!#`$`#@```(X,`0`.````G0P!``4`
M``"L#`$`!0```+(,`0`N````N`P!`"8```#G#`$`(P````X-`0`#````,@T!
M`!(````V#0$`!@```$D-`0`>````4`T!`!@```!O#0$`)0```(@-`0`-````
MK@T!``D```"\#0$`'P```,8-`0`#````Y@T!``<```#J#0$`"@```/(-`0`"
M````_0T!``P`````#@$`%0````T.`0`+````(PX!`!D````O#@$`(````$D.
M`0`2````:@X!``4```!]#@$`"@```(,.`0`5````C@X!`!(```"D#@$`#```
M`+<.`0`$````Q`X!``D```#)#@$`!P```-,.`0`,````VPX!`%(```#H#@$`
M%P```#L/`0`D````4P\!`!(```!X#P$`!P```(L/`0`&````DP\!``X```":
M#P$`#````*D/`0`-````M@\!`!4```#$#P$`$@```-H/`0`/````[0\!`!0`
M``#]#P$`"@```!(0`0`;````'1`!`!`````Y$`$`"P```$H0`0!I````5A`!
M`!H```#`$`$`%P```-L0`0`G````\Q`!`!H````;$0$`%P```#81`0`;````
M3A$!`!D```!J$0$`'P```(01`0`3````I!$!``@```"X$0$`!P```,$1`0`(
M````R1$!``D```#2$0$`%0```-P1`0`-````\A$!`",`````$@$`#0```"02
M`0`3````,A(!``@```!&$@$``P```$\2`0!&````4Q(!`#\```":$@$`-P``
M`-H2`0!7````$A,!``4```!J$P$`'P```'`3`0`O````D!,!``H```#`$P$`
M"````,L3`0`-````U!,!`"T```#B$P$`!````!`4`0!/````%10!`"4```!E
M%`$`'````(L4`0`+````J!0!`!\```"T%`$`'0```-04`0`E````\A0!`"``
M```8%0$`)````#D5`0`@````7A4!``L```!_%0$`!P```(L5`0`-````DQ4!
M``P```"A%0$`%P```*X5`0`&````QA4!`#D```#-%0$`#`````<6`0`'````
M%!8!``D````<%@$`$P```"86`0`)````.A8!``0```!$%@$`$````$D6`0`(
M````6A8!``@```!C%@$`!````&P6`0`+````<18!``P```!]%@$`$@```(H6
M`0`1````G18!``P```"O%@$`&@```+P6`0`/````UQ8!``<```#G%@$`#0``
M`.\6`0`4````_18!``X````2%P$`#````"$7`0`;````+A<!`"P```!*%P$`
M$P```'<7`0`<````BQ<!`"@```"H%P$`!@```-$7`0`'````V!<!`!,```#@
M%P$`!0```/07`0`$````^A<!`!<```#_%P$`"@```!<8`0`,````(A@!``D`
M```O&`$`!@```#D8`0`)````0!@!``@```!*&`$`"0```%,8`0`*````71@!
M`!$```!H&`$`!@```'H8`0`.````@1@!``X```"0&`$`#0```)\8`0`+````
MK1@!`!T```"Y&`$`"P```-<8`0`"````XQ@!`!P```#F&`$`!P````,9`0`&
M````"QD!`&4````2&0$`"0```'@9`0`'````@AD!`"8```"*&0$`.````+$9
M`0`:````ZAD!`"H````%&@$`.P```#`:`0`H````;!H!`#0```"5&@$`&0``
M`,H:`0`5````Y!H!``4```#Z&@$`!P`````;`0`(````"!L!``<````1&P$`
M!0```!D;`0`'````'QL!``X````G&P$`"0```#8;`0`&````0!L!``@```!'
M&P$`"P```%`;`0`'````7!L!``@```!D&P$`!P```&T;`0`6````=1L!``D`
M``",&P$`!@```)8;`0`+````G1L!`!````"I&P$`!@```+H;`0`<````P1L!
M`!0```#>&P$`!P```/,;`0`1````^QL!``@````-'`$`#@```!8<`0`(````
M)1P!``4````N'`$`$````#0<`0`)````11P!`!````!/'`$`!@```&`<`0`9
M````9QP!``H```"!'`$`'````(P<`0`'````J1P!``4```"Q'`$`$````+<<
M`0`4````R!P!``L```#='`$`#0```.D<`0`H````]QP!`!@````@'0$`%P``
M`#D=`0`$````41T!``D```!6'0$`"@```&`=`0`'````:QT!``(```!S'0$`
M#@```'8=`0`(````A1T!`!\```".'0$`(P```*X=`0`?````TAT!`#@```#R
M'0$`)@```"L>`0`Q````4AX!`"<```"$'@$`9````*P>`0`4````$1\!`%4`
M```F'P$`.````'P?`0!*````M1\!`%L`````(`$`*````%P@`0`X````A2`!
M`"@```"^(`$`+````.<@`0`G````%"$!`!L````\(0$`/@```%@A`0"I`0``
MER$!`",```!!(P$`%P```&4C`0!(````?2,!`(4```#&(P$`,````$PD`0`E
M````?20!`$$```"C)`$`6P```.4D`0!)````024!`#$```"+)0$`'0```+TE
M`0`8````VR4!`"L```#T)0$`(0```"`F`0`?````0B8!`"L```!B)@$`)@``
M`(XF`0`A````M28!`"<```#7)@$`.@```/\F`0`=````.B<!`!$```!8)P$`
M,P```&HG`0`E````GB<!`"<```#$)P$`(````.PG`0`?````#2@!`#`````M
M*`$`:0```%XH`0`Q````R"@!`$$```#Z*`$`,P```#PI`0`E````<"D!`#T`
M``"6*0$`90```-0I`0!-````.BH!`"\```"(*@$`+@```+@J`0`P````YRH!
M`%0````8*P$`6@```&TK`0!(````R"L!`$H````1+`$`,@```%PL`0`O````
MCRP!`"P```"_+`$`+0```.PL`0!Q````&BT!`&8```",+0$`;P```/,M`0"S
M````8RX!`!<````7+P$`)0```"\O`0`R````52\!`"D```"(+P$`/@```+(O
M`0`B````\2\!`%(````4,`$`)0```&<P`0`+````C3`!`+$```"9,`$`10``
M`$LQ`0`A````D3$!`#````"S,0$`)0```.0Q`0`<````"C(!`#$````G,@$`
M!P```%DR`0`'````83(!``0```!I,@$`#0```&XR`0`+````?#(!``X```"(
M,@$`"P```)<R`0`%````HS(!`!````"I,@$``@```+HR`0!9````O3(!``4`
M```7,P$`$@```!TS`0`$````,#,!``<````U,P$`"````#TS`0`%````1C,!
M`#````!,,P$``P```'TS`0`0````@3,!``P```"2,P$`$P```)\S`0`-````
MLS,!``(```#!,P$`!P```,0S`0`&````S#,!`!0```#3,P$`#````.@S`0`8
M````]3,!``8````.-`$`$@```!4T`0`,````*#0!``,````U-`$`*@```#DT
M`0`$````9#0!``8```!I-`$`!P```'`T`0`?````>#0!`#4```"8-`$`+@``
M`,XT`0`O````_30!`!<````M-0$`(@```$4U`0`E````:#4!`"````".-0$`
M&P```*\U`0`8````RS4!`"0```#D-0$`'P````DV`0`:````*38!`"$```!$
M-@$`(````&8V`0`:````AS8!`#(```"B-@$`&@```-4V`0`O````\#8!`"L`
M```@-P$`'P```$PW`0`C````;#<!`!\```"0-P$`&@```+`W`0`A````RS<!
M`"4```#M-P$`)@```!,X`0`E````.C@!`"0```!@.`$`&````(4X`0`=````
MGC@!`"0```"\.`$`&````.$X`0`B````^C@!`"P````=.0$`+P```$HY`0`5
M````>CD!`"4```"0.0$`/````+8Y`0`?````\SD!`",````3.@$`'P```#<Z
M`0`@````5SH!`!H```!X.@$`&````),Z`0`F````K#H!`!X```#3.@$`*0``
M`/(Z`0`>````'#L!`#$````[.P$`"0```&T[`0`,````=SL!`!<```"$.P$`
M+P```)P[`0`D````S#L!``<```#Q.P$`#P```/D[`0`4````"3P!``X````>
M/`$`#0```"T\`0`D````.SP!``4```!@/`$`!P```&8\`0`B````;CP!`"4`
M``"1/`$`&@```+<\`0`=````TCP!`!H```#P/`$`!P````L]`0#'````$ST!
M``L```#;/0$`%0```.<]`0`&````_3T!``D````$/@$`"P````X^`0`-````
M&CX!`!<````H/@$`!@```$`^`0`S````1SX!`!,```![/@$`$P```(\^`0`'
M````HSX!``\```"K/@$`!P```+L^`0`R````PSX!``0```#V/@$`(0```/L^
M`0`3````'3\!``P````Q/P$`$0```#X_`0`R````4#\!`!8```"#/P$`"```
M`)H_`0`=````HS\!``D```#!/P$`"@```,L_`0`4````UC\!``H```#K/P$`
M'0```/8_`0`(````%$`!`!\````=0`$`"````#U``0`:````1D`!`"<```!A
M0`$`!@```(E``0`5````D$`!``<```"F0`$`"````*Y``0`)````MT`!`#\`
M``#!0`$`!P````%!`0`/````"4$!``X````900$`$````"A!`0`)````.4$!
M``D```!#00$`"````$U!`0`3````5D$!``<```!J00$`&0```')!`0`*````
MC$$!`!<```"700$`%````*]!`0`*````Q$$!``P```#/00$`%P```-Q!`0`$
M````]$$!`"H```#Y00$`#````"1"`0`1````,4(!``<```!#0@$``@```$M"
M`0`0````3D(!`!@```!?0@$`"P```'A"`0`#````A$(!``@```"(0@$`!@``
M`)%"`0`'````F$(!``T```"@0@$`"P```*Y"`0`4````ND(!`!4```#/0@$`
M#@```.5"`0`O````]$(!`"`````D0P$`'````$5#`0`5````8D,!``P```!X
M0P$`,0```(5#`0`%````MT,!`!(```"]0P$`/P```-!#`0`2````$$0!``H`
M```C1`$`!@```"Y$`0`$````-40!``0````Z1`$`"@```#]$`0`3````2D0!
M``4```!>1`$`!@```&1$`0`&````:T0!``@```!R1`$`!````'M$`0`,````
M@$0!``H```"-1`$`.0```)A$`0`N````TD0!`"D````!10$`!0```"M%`0`8
M````,44!`!D```!*10$`'P```&1%`0`=````A$4!`!$```"B10$``@```+1%
M`0`$````MT4!``H```"\10$`!@```,=%`0`%````SD4!``,```#410$`#```
M`-A%`0!%````Y44!`#(````K1@$`&@```%Y&`0`U````>48!`"@```"O1@$`
M4P```-A&`0`9````+$<!`'(```!&1P$`(````+E'`0`U````VD<!`"$````0
M2`$`10```#)(`0`P````>$@!`"@```"I2`$`*0```-)(`0`F````_$@!`"4`
M```C20$`*````$E)`0`H````<DD!`"(```";20$`*P```+Y)`0`P````ZDD!
M`!(````;2@$`$P```"Y*`0`0````0DH!`'D```!32@$`"0```,U*`0"A````
MUTH!`',```!Y2P$`?````.U+`0`K````:DP!`%0```"63`$`%P```.M,`0`G
M`````TT!`!8````K30$`#P```$)-`0`7````4DT!`!\```!J30$`0````(I-
M`0`?````RTT!`!P```#K30$`40````A.`0`:````6DX!`!0```!U3@$`"@``
M`(I.`0`%````E4X!``8```";3@$`"````*).`0`%````JTX!`!(```"Q3@$`
M$````,1.`0`3````U4X!`!T```#I3@$`#P````=/`0`/````%T\!``0````G
M3P$`"0```"Q/`0`+````-D\!``<```!"3P$`!0```$I/`0`4````4$\!``<`
M``!E3P$`"````&U/`0`/````=D\!``@```"&3P$`#````(]/`0`/````G$\!
M``8```"L3P$`%````+-/`0`&````R$\!``P```#/3P$`$0```-Q/`0`(````
M[D\!``0```#W3P$`&0```/Q/`0`1````%E`!``H````H4`$`&````#-0`0`3
M````3%`!`!P```!@4`$`$0```'U0`0`$````CU`!``\```"44`$`!P```*10
M`0`$````K%`!`!D```"Q4`$`!P```,M0`0`"````TU`!``(```#64`$`$0``
M`-E0`0`)````ZU`!``8```#U4`$`$@```/Q0`0`7````#U$!``8````G40$`
M)P```"Y1`0`"````5E$!``0```!940$`#P```%Y1`0`3````;E$!``<```""
M40$`!P```(I1`0`1````DE$!``8```"D40$`&````*M1`0`&````Q%$!`!,`
M``#+40$`$````-]1`0`2````\%$!``(````#4@$`!@````92`0`5````#5(!
M``P````C4@$`"0```#!2`0`1````.E(!``D```!,4@$`(@```%92`0`'````
M>5(!``<```"!4@$`"P```(E2`0`%````E5(!``(```";4@$`"P```)Y2`0!<
M`0``JE(!`!(````'5`$`#P```!I4`0`2````*E0!``<````]5`$`"````$54
M`0`'````3E0!``L```!65`$`%0```&)4`0`;````>%0!`"@```"45`$`'```
M`+U4`0`>````VE0!`!T```#Y5`$`$P```!=5`0`I````*U4!``L```!550$`
M(@```&%5`0`1````A%4!``\```"650$`#````*95`0`%````LU4!`!D```"Y
M50$`#````--5`0`3````X%4!`!0```#T50$`$@````E6`0`2````'%8!`%H`
M```O5@$`$0```(I6`0`*````G%8!``T```"G5@$`$````+56`0`:````QE8!
M`!0```#A5@$`$P```/96`0`5````"E<!``8````@5P$`FP```"=7`0`-````
MPU<!`!(```#15P$`%@```.17`0`*````^U<!`!$````&6`$`$0```!A8`0`(
M````*E@!``@````S6`$`(````#Q8`0`3````75@!`#$```!Q6`$`-````*-8
M`0!8````V%@!`%,````Q60$`7@```(59`0!9````Y%D!`#,````^6@$`"@``
M`'):`0`-````?5H!``<```"+6@$`"@```)-:`0`1````GEH!``4```"P6@$`
M!@```+9:`0`2````O5H!``<```#06@$`"0```-A:`0`)````XEH!`"L```#L
M6@$`*````!A;`0`*````05L!``X```!,6P$`$0```%M;`0`/````;5L!``0`
M``!]6P$`#@```();`0`.````D5L!``H```"@6P$`#@```*M;`0`.````NEL!
M`!0```#)6P$`%````-Y;`0`2````\UL!``H````&7`$`$0```!%<`0`)````
M(UP!`!\````M7`$`&````$U<`0`<````9EP!``T```"#7`$`3P```)%<`0`M
M````X5P!`"$````/70$`!P```#%=`0`.````.5T!`"<```!(70$`!@```'!=
M`0`'````=UT!``H```!_70$`"````(I=`0`(````DUT!``4```"<70$`!P``
M`*)=`0`(````JET!``0```"S70$`&P```+A=`0`+````U%T!``P```#@70$`
M#P```.U=`0`3````_5T!`"0````17@$`#@```#9>`0`8````15X!`!L```!>
M7@$`'P```'I>`0`=````FEX!`!4```"X7@$`%````,Y>`0`.````XUX!`!L`
M``#R7@$`%`````Y?`0`'````(U\!``<````K7P$`"````#-?`0`3````/%\!
M``8```!07P$`"@```%=?`0`2````8E\!``@```!U7P$`$P```'Y?`0`6````
MDE\!`!0```"I7P$`!P```+Y?`0`1````QE\!``8```#87P$`%@```-]?`0`.
M````]E\!``P````%8`$`-````!)@`0!&````1V`!``H```".8`$`"````)E@
M`0`4````HF`!``4```"W8`$`!0```+U@`0`-````PV`!``\```#18`$`'0``
M`.%@`0`F````_V`!``8````F80$`(````"UA`0`@````3F$!`!P```!O80$`
M&@```(QA`0`*````IV$!``8```"R80$`"@```+EA`0`'````Q&$!`#````#,
M80$`,````/UA`0`O````+F(!`%$```!>8@$`+@```+!B`0`N````WV(!`#\`
M```.8P$`0````$YC`0`N````CV,!`#4```"^8P$`*````/1C`0`D````'60!
M`#P```!"9`$`+@```']D`0`T````KF0!`!0```#C9`$`&````/AD`0`F````
M$64!`"0````X90$`)````%UE`0`3````@F4!``P```"690$`$````*-E`0`%
M````M&4!``L```"Z90$`&````,9E`0`<````WV4!``8```#\90$`!P````-F
M`0`3````"V8!``H````?9@$`"````"IF`0`F````,V8!``@```!:9@$`"0``
M`&-F`0`&````;68!``8```!T9@$`!0```'MF`0`'````@68!``8```")9@$`
M"0```)!F`0`F````FF8!``\```#!9@$`"@```-%F`0`)````W&8!``@```#F
M9@$`#````.]F`0`(````_&8!``T````%9P$`"@```!-G`0`7````'F<!``<`
M```V9P$`"````#YG`0`$````1V<!``L```!,9P$`"0```%AG`0`@````8F<!
M`!(```"#9P$`"0```)9G`0`'````H&<!``P```"H9P$`!P```+5G`0`*````
MO6<!``,```#(9P$`'P```,QG`0`3````[&<!`"X`````:`$`"````"]H`0`&
M````.&@!``D````_:`$`!P```$EH`0!'````46@!`!\```"9:`$`.@```+EH
M`0`B````]&@!`!L````7:0$`!@```#-I`0`%````.FD!``4```!`:0$`(```
M`$9I`0`9````9VD!`"X```"!:0$`)````+!I`0`C````U6D!`%X```#Y:0$`
M*````%AJ`0`5````@6H!``@```"7:@$`#@```*!J`0`8````KVH!``X```#(
M:@$`#0```-=J`0`/````Y6H!`!$```#U:@$`#P````=K`0`4````%VL!``T`
M```L:P$`$P```#IK`0`'````3FL!`!4```!6:P$`&0```&QK`0`7````AFL!
M`!,```">:P$`%P```+)K`0`&````RFL!``4```#1:P$`#@```-=K`0!8````
MYFL!`%8````_;`$`!````)9L`0`3````FVP!``<```"O;`$`!0```+=L`0`;
M````O6P!`!T```#9;`$`#@```/=L`0`-````!FT!`!$````4;0$`&P```"9M
M`0`N````0FT!``L```!Q;0$`'P```'UM`0`%````G6T!`!H```"C;0$`#P``
M`+YM`0`4````SFT!`!````#C;0$`&````/1M`0`.````#6X!`!(````<;@$`
M$P```"]N`0`)````0VX!``8```!-;@$`#P```%1N`0`&````9&X!`!X```!K
M;@$`#@```(IN`0`3````F6X!``@```"M;@$`!````+9N`0`*````NVX!``L`
M``#&;@$`!P```-)N`0`3````VFX!``D```#N;@$`!````/AN`0`(````_6X!
M``H````&;P$`"````!%O`0`(````&F\!``4````C;P$`!P```"EO`0`#````
M,6\!``,````U;P$`&P```#EO`0!"````56\!`!4```"8;P$`"P```*YO`0`0
M````NF\!``4```#+;P$`&P```-%O`0`/````[6\!`!````#];P$`)`````YP
M`0`T````,W`!`!T```!H<`$`"0```(9P`0`R````D'`!``D```##<`$`!0``
M`,UP`0`,````TW`!``D```#@<`$`!P```.IP`0`6````\G`!``T````)<0$`
M!P```!=Q`0`*````'W$!``T````J<0$`'P```#AQ`0`D````6'$!`"(```!]
M<0$`)P```*!Q`0`=````R'$!`"````#F<0$`'P````=R`0`D````)W(!`"(`
M``!,<@$`+@```&]R`0`B````GG(!`"$```#!<@$`)````.-R`0`@````"',!
M`"<````I<P$`-P```%%S`0`U````B7,!`"L```"_<P$`*P```.MS`0`W````
M%W0!`"<```!/=`$`$@```'=T`0`N````BG0!`"(```"Y=`$`$@```-QT`0`K
M````[W0!`!\````;=0$`'@```#MU`0`3````6G4!`)(```!N=0$`&@````%V
M`0`I````''8!`"D```!&=@$`*P```'!V`0`H````G'8!`"<```#%=@$`&0``
M`.UV`0`B````!W<!`#`````J=P$`,P```%MW`0`_````CW<!`#X```#/=P$`
MFP````YX`0`3````JG@!`!,```"^>`$`'@```-)X`0`E````\7@!`"<````7
M>0$`/````#]Y`0!"````?'D!`!@```"_>0$`!````-AY`0`(````W7D!``,`
M``#F>0$`"0```.IY`0`(````]'D!`!````#]>0$`#@````YZ`0`4````'7H!
M``D````R>@$`!0```#QZ`0`1````0GH!`!0```!4>@$`"````&EZ`0`/````
M<GH!`!,```"">@$`#````)9Z`0`-````HWH!``X```"Q>@$`+````,!Z`0`%
M````[7H!``L```#S>@$`!@```/]Z`0`3````!GL!`!D````:>P$`&P```#1[
M`0`/````4'L!``(```!@>P$`2P```&-[`0`(````KWL!`!````"X>P$`$```
M`,E[`0`'````VGL!`!$```#B>P$`#@```/1[`0`$`````WP!``X````(?`$`
M"0```!=\`0`.````(7P!`!$````P?`$`"0```$)\`0`.````3'P!``\```!;
M?`$`#P```&M\`0`-````>WP!``<```")?`$`#@```)%\`0`-````H'P!``P`
M``"N?`$`#0```+M\`0`9````R7P!``X```#C?`$`#0```/)\`0`E`````'T!
M`!,````F?0$`%P```#I]`0`L````4GT!``P```!_?0$`&@```(Q]`0`6````
MIWT!`!4```"^?0$`+@```-1]`0`4`````WX!``4````8?@$`$@```!Y^`0`)
M````,7X!`"<````[?@$`*````&-^`0`'````C'X!``H```"4?@$`&````)]^
M`0`+````N'X!`!<```#$?@$`%P```-Q^`0`(````]'X!`!P```#]?@$`#@``
M`!I_`0`:````*7\!`!4```!$?P$`#@```%I_`0`8````:7\!``@```""?P$`
M"P```(M_`0`N````EW\!`#H```#&?P$`"`````&``0`4````"H`!`!T````?
M@`$`"````#V``0`+````1H`!`"@```!2@`$`"````'N``0`'````A(`!``8`
M``",@`$`2@```).``0`#````WH`!``<```#B@`$`!0```.J``0`,````\(`!
M``P```#]@`$`#`````J!`0`,````%X$!``\````D@0$`#@```#2!`0`1````
M0X$!``\```!5@0$`!P```&6!`0`'````;8$!`$0```!U@0$`"P```+J!`0`*
M````QH$!``(```#1@0$`!@```-2!`0`/````VX$!`"(```#K@0$`$@````Z"
M`0`2````(8(!``<````T@@$`#@```#R"`0`0````2X(!`!<```!<@@$`+@``
M`'2"`0`=````HX(!``H```#!@@$`#P```,R"`0!K````W((!`!8```!(@P$`
M$P```%^#`0`1````<X,!``<```"%@P$`!````(V#`0`7````DH,!`"L```"J
M@P$`+````-:#`0`8`````X0!`!L````<A`$`%````#B$`0`7````380!``4`
M``!EA`$`"````&N$`0`)````=(0!``<```!^A`$`%````(:$`0`3````FX0!
M`!4```"OA`$`$P```,6$`0`3````V80!`!8```#MA`$`#`````2%`0`0````
M$84!``<````BA0$`!P```"J%`0`.````,H4!``L```!!A0$`,P```$V%`0`0
M````@84!``D```"2A0$`"P```)R%`0`B````J(4!`!P```#+A0$`(@```.B%
M`0`A````"X8!`!P````MA@$`&P```$J&`0`A````9H8!`!<```"(A@$`%```
M`*"&`0`#````M88!`!P```"YA@$`#````-:&`0`-````XX8!``0```#QA@$`
M!@```/:&`0`(````_88!``L````&AP$`#0```!*'`0`1````((<!`!0````R
MAP$`#````$>'`0`.````5(<!``L```!CAP$`!0```&^'`0`$````=8<!`!0`
M``!ZAP$`%0```(^'`0`+````I8<!``H```"QAP$`"P```+R'`0`3````R(<!
M`"$```#<AP$`!P```/Z'`0`%````!H@!``P````,B`$`#P```!F(`0`,````
M*8@!``@````VB`$`!@```#^(`0`#````1H@!`!@```!*B`$`"P```&.(`0`$
M````;X@!`"4```!TB`$`#@```)J(`0!P````J8@!`!,````:B0$`!@```"Z)
M`0`$````-8D!``H````ZB0$`!@```$6)`0`(````3(D!``@```!5B0$`!P``
M`%Z)`0`"````9HD!``8```!IB0$`"P```'")`0`8````?(D!`!(```"5B0$`
M%````*B)`0`3````O8D!``<```#1B0$`"````-F)`0`2````XHD!``<```#U
MB0$`"````/V)`0`%````!HH!`!@````,B@$`"````"6*`0`&````+HH!`!P`
M```UB@$`$0```%**`0`'````9(H!``@```!LB@$`!0```'6*`0`)````>XH!
M``<```"%B@$`#@```(V*`0`$````G(H!``4```"AB@$`#@```*>*`0`-````
MMHH!``X```#$B@$`!@```-.*`0`3````VHH!``D```#NB@$`!P```/B*`0`/
M`````(L!`"$````0BP$`,P```#*+`0`F````9HL!`"(```"-BP$`!@```+"+
M`0`*````MXL!``0```#"BP$`"@```,>+`0`(````THL!`!````#;BP$`#P``
M`.R+`0`%````_(L!``P````"C`$`"`````^,`0`$````&(P!`#\````=C`$`
M00```%V,`0`_````GXP!`!L```#?C`$`!@```/N,`0`,`````HT!``0````/
MC0$`!````!2-`0`&````&8T!`!\````@C0$`#P```$"-`0`6````4(T!``8`
M``!GC0$``P```&Z-`0`6````<HT!``<```")C0$`"````)&-`0`3````FHT!
M``4```"NC0$`"````+2-`0`=````O8T!``D```#;C0$`#@```.6-`0`,````
M](T!``X````!C@$`"0```!".`0`(````&HX!``4````CC@$`+````"F.`0`M
M````5HX!`#<```"$C@$`)P```+R.`0`^````Y(X!`#8````CCP$`*0```%J/
M`0`\````A(\!`"\```#!CP$`+P```/&/`0`?````(9`!``\```!!D`$`%P``
M`%&0`0`.````:9`!`"<```!XD`$`)````*"0`0`<````Q9`!`"(```#BD`$`
M!P````61`0`(````#9$!``H````6D0$`!@```"&1`0`A````*)$!`"4```!*
MD0$`*````'"1`0`*````F9$!`!8```"DD0$`*````+N1`0`6````Y)$!``\`
M``#[D0$`!@````N2`0`.````$I(!``H````AD@$`$````"R2`0`1````/9(!
M`#D```!/D@$`>P```(F2`0!X````!9,!``\```!^DP$`"0```(Z3`0`*````
MF),!``X```"CDP$`#P```+*3`0`3````PI,!``8```#6DP$`#P```-V3`0`3
M````[9,!`!(````!E`$`$0```!24`0`;````)I0!`"````!"E`$`7P```&.4
M`0`2````PY0!``4```#6E`$`$0```-R4`0`*````[I0!``0```#YE`$`#0``
M`/Z4`0`>````#)4!`!(````KE0$`"0```#Z5`0`*````2)4!``X```!3E0$`
M$````&*5`0`D````<Y4!`"(```"8E0$`(0```+N5`0`?````W94!`"$```#]
ME0$`'P```!^6`0`7````/Y8!`#@```!7E@$`$@```)"6`0`0````HY8!`!$`
M``"TE@$`#P```,:6`0`+````UI8!`!````#BE@$`#@```/.6`0`0`````I<!
M``X````3EP$`(0```"*7`0`/````1)<!``\```!4EP$`+P```&27`0`2````
ME)<!``<```"GEP$`$P```*^7`0`>````PY<!`!,```#BEP$`$````/:7`0`-
M````!Y@!`!D````5F`$`$P```"^8`0`1````0Y@!`!4```!5F`$`&````&N8
M`0`/````A)@!`!L```"4F`$`(0```+"8`0`1````TI@!`!(```#DF`$`$0``
M`/>8`0`1````"9D!`!(````;F0$`%0```"Z9`0`4````1)D!`!<```!9F0$`
M"````'&9`0`*````>ID!`!4```"%F0$`!0```)N9`0`'````H9D!``D```"I
MF0$`%````+.9`0`'````R)D!``H```#0F0$`"````-N9`0`'````Y)D!``<`
M``#LF0$`!P```/29`0`&````_)D!`!4````#F@$`4@```!F:`0`&````;)H!
M``D```!SF@$`!0```'V:`0`%````@YH!``@```")F@$`!P```)*:`0`(````
MFIH!``@```"CF@$`"````*R:`0`)````M9H!`!(```"_F@$`!@```-*:`0`B
M````V9H!``\```#\F@$`#0````R;`0`/````&IL!``P````JFP$`"@```#>;
M`0`-````0IL!`"8```!0FP$`!@```'>;`0`(````?IL!`"````"'FP$`#@``
M`*B;`0`.````MYL!``8```#&FP$`"@```,V;`0`)````V)L!``0```#BFP$`
M(````.>;`0`,````")P!`!8````5G`$`#P```"R<`0`1````/)P!`!0```!.
MG`$`(@```&.<`0`>````AIP!``0```"EG`$`!@```*J<`0`(````L9P!`"$`
M``"ZG`$`"````-R<`0`%````Y9P!``H```#KG`$`$0```/:<`0`'````")T!
M``0````0G0$`"````!6=`0`7````'IT!``T````VG0$`#0```$2=`0`)````
M4IT!`!8```!<G0$`$P```'.=`0`-````AYT!`!(```"5G0$`#@```*B=`0`.
M````MYT!``<```#&G0$`!````,Z=`0`5````TYT!`#(```#IG0$`!@```!R>
M`0`.````(YX!`"`````RG@$`%````%.>`0`8````:)X!`!````"!G@$`#```
M`)*>`0`)````GYX!``<```"IG@$`"@```+&>`0`)````O)X!``X```#&G@$`
M$````-6>`0`J````YIX!`"D````1GP$`)P```#N?`0`)````8Y\!``4```!M
MGP$`!P```'.?`0`-````>Y\!``X```")GP$`!P```)B?`0`*````H)\!`!X`
M``"KGP$`"@```,J?`0`,````U9\!`!,```#BGP$`/P```/:?`0`5````-J`!
M``H```!,H`$`"````%>@`0`%````8*`!`!$```!FH`$`$0```'B@`0`6````
MBJ`!``H```"AH`$``@```*R@`0`$````KZ`!`"4```"TH`$``P```-J@`0`%
M````WJ`!`"@```#DH`$`"@````VA`0`&````&*$!``8````?H0$`%````":A
M`0`)````.Z$!``8```!%H0$`"````$RA`0`)````5:$!``0```!?H0$`!0``
M`&2A`0!I````:J$!``L```#4H0$`#@```."A`0`7````[Z$!``4````'H@$`
M!`````VB`0`?````$J(!`"D````RH@$`$````%RB`0`*````;:(!``X```!X
MH@$`"P```(>B`0`*````DZ(!`!<```">H@$`'0```+:B`0`F````U*(!`"4`
M``#[H@$`'````"&C`0`-````/J,!``,```!,HP$`!P```%"C`0`)````6*,!
M``<```!BHP$`#0```&JC`0`.````>*,!``4```"'HP$`4P```(VC`0`1````
MX:,!``H```#SHP$`"0```/ZC`0`<````"*0!`$4````EI`$`%P```&ND`0`&
M````@Z0!`!\```"*I`$`,0```*JD`0`&````W*0!``<```#CI`$`&````.ND
M`0`'````!*4!``D````,I0$`)@```!:E`0`D````/:4!`"<```!BI0$`"```
M`(JE`0`+````DZ4!`"````"?I0$`8@```,"E`0`1````(Z8!`"`````UI@$`
M%````%:F`0`"````:Z8!``\```!NI@$`"````'ZF`0`0````AZ8!``D```"8
MI@$`!````**F`0`0````IZ8!``8```"XI@$`"0```+^F`0`,````R:8!``D`
M``#6I@$`"@```."F`0`)````ZZ8!`"L```#UI@$`!@```"&G`0`/````**<!
M`!`````XIP$`&P```$FG`0`;````9:<!``L```"!IP$`#P```(VG`0`/````
MG:<!``L```"MIP$`"P```+FG`0`+````Q:<!``D```#1IP$`%0```-NG`0`1
M````\:<!``4````#J`$`"@````FH`0`/````%*@!``P````DJ`$`%@```#&H
M`0`'````2*@!`!(```!0J`$`!````&.H`0`(````:*@!``4```!QJ`$`!@``
M`'>H`0`'````?J@!`!$```"&J`$`$0```)BH`0`9````JJ@!`!8```#$J`$`
M%0```-NH`0`6````\:@!`!D````(J0$`(````"*I`0`:````0ZD!``0```!>
MJ0$`#````&.I`0`.````<*D!``X```!_J0$`#@```(ZI`0`'````G:D!`",`
M``"EJ0$`"P```,FI`0`,````U:D!`!8```#BJ0$`&@```/FI`0`3````%*H!
M``<````HJ@$`!@```#"J`0`(````-ZH!`!$```!`J@$`$````%*J`0`)````
M8ZH!``H```!MJ@$`!0```'BJ`0`(````?JH!``(```"'J@$`!````(JJ`0`"
M````CZH!`#@```"2J@$`(@```,NJ`0`,````[JH!`!T```#[J@$`,@```!FK
M`0`1````3*L!`"<```!>JP$`&````(:K`0`=````GZL!`!T```"]JP$`(@``
M`-NK`0`6````_JL!`!,````5K`$`#P```"FL`0`1````.:P!`!(```!+K`$`
M$0```%ZL`0`-````<*P!``P```!^K`$`#@```(NL`0`6````FJP!`"$```"Q
MK`$`(0```-.L`0`E````]:P!`"(````;K0$`(P```#ZM`0`@````8JT!`&4`
M``"#K0$`&P```.FM`0`1````!:X!``@````7K@$`%P```""N`0`0````.*X!
M`!0```!)K@$`)P```%ZN`0`I````AJX!`"4```"PK@$`$@```-:N`0!'````
MZ:X!`$8````QKP$`"0```'BO`0`)````@J\!`!<```",KP$`#0```*2O`0`-
M````LJ\!`!4```#`KP$`!0```-:O`0`0````W*\!``\```#MKP$`#P```/VO
M`0`/````#;`!``D````=L`$`$````">P`0`'````.+`!`"$```!`L`$`"```
M`&*P`0`#````:[`!``L```!OL`$`#````'NP`0`*````B+`!`#L```"3L`$`
M`@```,^P`0`&````TK`!``T```#9L`$`#P```.>P`0`(````][`!``X`````
ML0$`"@````^Q`0`K````&K$!`!$```!&L0$`'@```%BQ`0`%````=[$!`"P`
M``!]L0$`&0```*JQ`0`F````Q+$!`%4```#KL0$`#@```$&R`0!$````4+(!
M`!L```"5L@$`$P```+&R`0`&````Q;(!``T```#,L@$`$P```-JR`0`.````
M[K(!``@```#]L@$`!`````:S`0`4````"[,!`!P````@LP$``P```#VS`0`(
M````0;,!``\```!*LP$`(````%JS`0`/````>[,!`!,```"+LP$`%````)^S
M`0`/````M+,!`",```#$LP$`"````.BS`0`,````\;,!``T```#^LP$`!P``
M``RT`0`,````%+0!``<````AM`$`$````"FT`0`(````.K0!``T```!#M`$`
M%0```%&T`0`-````9[0!``4```!UM`$`"````'NT`0`%````A+0!`",```"*
MM`$`!@```*ZT`0`0````M;0!``@```#&M`$`$0```,^T`0`(````X;0!`!(`
M``#JM`$`#0```/VT`0`I````"[4!`!0````UM0$`"0```$JU`0`*````5+4!
M`!H```!?M0$`!0```'JU`0`3````@+4!``<```"4M0$`%0```)RU`0`(````
MLK4!``D```"[M0$`$P```,6U`0`>````V;4!``4```#XM0$`&@```/ZU`0`3
M````&;8!``<````MM@$`#@```#6V`0`,````1+8!``4```!1M@$`#````%>V
M`0`*````9+8!``<```!OM@$`!0```'>V`0`(````?;8!``<```"&M@$`"@``
M`(ZV`0`6````F;8!`"L```"PM@$`,````-RV`0`5````#;<!`"(````CMP$`
M'0```$:W`0`W````9+<!`!8```"<MP$`$P```+.W`0`D````Q[<!`$D```#L
MMP$`'````#:X`0`%````4[@!``D```!9N`$`"@```&.X`0`(````;K@!`!0`
M``!WN`$`%0```(RX`0`K````HK@!`!H```#.N`$`%P```.FX`0`O`````;D!
M`#4````QN0$`!P```&>Y`0`3````;[D!``@```"#N0$`"````(RY`0`9````
ME;D!``\```"ON0$`#@```+^Y`0`-````SKD!``@```#<N0$`$P```.6Y`0`)
M````^;D!``X````#N@$`"P```!*Z`0`6````'KH!`!(````UN@$`)P```$BZ
M`0`+````<+H!`!X```!\N@$`!0```)NZ`0`&````H;H!``<```"HN@$`&@``
M`+"Z`0`%````R[H!``0```#1N@$`#0```-:Z`0`*````Y+H!``<```#ON@$`
M#````/>Z`0`,````!+L!``T````1NP$`"````!^[`0`#````*+L!``D````L
MNP$`,P```#:[`0!#````:KL!`!@```"NNP$`"0```,>[`0`G````T;L!`!D`
M``#YNP$`#P```!.\`0`.````([P!``H````RO`$`"````#V\`0`0````1KP!
M`"H```!7O`$`!P```(*\`0`-````BKP!``T```"8O`$`$````*:\`0`,````
MM[P!`#D```#$O`$`!P```/Z\`0`3````!KT!`!`````:O0$`%````"N]`0`V
M````0+T!`!T```!WO0$`(P```)6]`0`D````N;T!`"````#>O0$`$````/^]
M`0`(````$+X!``X````9O@$`%@```"B^`0`5````/[X!``D```!5O@$`$@``
M`%^^`0`2````<KX!``<```"%O@$`&P```(V^`0`;````J;X!``L```#%O@$`
M!0```-&^`0`*````U[X!`!$```#BO@$`#@```/2^`0`$`````[\!``@````(
MOP$`"0```!&_`0`.````&[\!``X````JOP$`"@```#F_`0`*````1+\!``4`
M``!/OP$`!@```%6_`0`N````7+\!`"4```"+OP$`(P```+&_`0`'````U;\!
M`!$```#=OP$`!@```.^_`0`?````]K\!`!4````6P`$`(0```"S``0`/````
M3L`!``P```!>P`$`(````&O``0`#````C,`!``@```"0P`$`#0```)G``0`"
M````I\`!``P```"JP`$`%````+?``0`+````S,`!`!@```#8P`$`'````/'`
M`0`4````#L$!``4````CP0$`"@```"G!`0`4````-,$!`!8```!)P0$`#0``
M`&#!`0`)````;L$!``T```!XP0$`"P```(;!`0`2````DL$!`$\```"EP0$`
M'P```/7!`0`U````%<(!`!$```!+P@$`!@```%W"`0`&````9,(!``\```!K
MP@$`"P```'O"`0`,````A\(!`!(```"4P@$`#P```*?"`0`+````M\(!`!4`
M``##P@$`"0```-G"`0`?````X\(!``L````#PP$`#P````_#`0!&````'\,!
M`!<```!FPP$`&0```'[#`0`B````F,,!`!<```"[PP$`&0```-/#`0`8````
M[<,!`!`````&Q`$`%````!?$`0`9````+,0!``D```!&Q`$`!P```%#$`0`(
M````6,0!``D```!AQ`$`%````&O$`0`+````@,0!`"4```",Q`$`$@```++$
M`0`8````Q<0!``L```#>Q`$`!````.K$`0!,````[\0!`#T````\Q0$`-@``
M`'K%`0!;````L<4!``D````-Q@$`*P```!?&`0`L````0\8!``H```!PQ@$`
M"0```'O&`0`-````A<8!`#,```"3Q@$`!0```,?&`0!"````S<8!`"\````0
MQP$`)P```$#'`0`-````:,<!`"````!VQP$`%P```)?'`0`E````K\<!`!X`
M``#5QP$`(@```/3'`0`=````%\@!``T````UR`$`!P```$/(`0`2````2\@!
M``\```!>R`$`%@```&[(`0`(````A<@!`#D```".R`$`#````,C(`0`%````
MU<@!``<```#;R`$`$0```./(`0`(````]<@!``8```#^R`$`$P````7)`0`)
M````&<D!``D````CR0$`!````"W)`0`-````,LD!`!$```!`R0$`&@```%+)
M`0`7````;<D!``T```"%R0$`%0```)/)`0`0````J<D!``@```"ZR0$`%```
M`,/)`0`;````V,D!``P```#TR0$`#0````'*`0`:````#\H!`"<````JR@$`
M#0```%+*`0`3````8,H!`!X```!TR@$`"````)/*`0`$````G,H!`!(```"A
MR@$`"0```+3*`0`)````OLH!`!,```#(R@$`#@```-S*`0`,````Z\H!``L`
M``#XR@$`!0````3+`0`)````"LL!``@````4RP$`"0```!W+`0`*````)\L!
M`!,````RRP$`!````$;+`0`0````2\L!``T```!<RP$`$@```&K+`0`/````
M?<L!`!@```"-RP$`"P```*;+`0`"````LLL!`!T```"URP$`!0```-/+`0`'
M````V<L!`&H```#ARP$`"0```$S,`0`*````5LP!`!D```!AS`$`)0```'O,
M`0`3````H<P!`!X```"US`$`1P```-3,`0`P````',T!`#@```!-S0$`%P``
M`(;-`0`7````GLT!``8```"VS0$`#0```+W-`0`+````R\T!``X```#7S0$`
M$0```.;-`0`+````^,T!`!,````$S@$`#0```!C.`0`.````)LX!`!`````U
MS@$`"0```$;.`0`$````4,X!``@```!5S@$`#0```%[.`0`5````;,X!``D`
M``""S@$`!@```(S.`0`'````D\X!`"$```";S@$`!@```+W.`0`<````Q,X!
M`!<```#AS@$`"@```/G.`0`5````!,\!``X````:SP$`%P```"G/`0`(````
M0<\!``4```!*SP$`#P```%#/`0`-````8,\!``\```!NSP$`!@```'[/`0`6
M````A<\!``L```"<SP$`%P```*C/`0`*````P,\!``0```#+SP$`#@```-#/
M`0`:````W\\!``L```#ZSP$`#0````;0`0`J````%-`!`!4````_T`$`#@``
M`%70`0`%````9-`!``P```!JT`$`#@```'?0`0`'````AM`!``(```".T`$`
M#0```)'0`0`#````G]`!`!,```"CT`$`'0```+?0`0`C````U=`!`#````#Y
MT`$`(@```"K1`0`E````3=$!`"````!ST0$`4@```)31`0`3````Y]$!`$H`
M``#[T0$`+@```$;2`0!'````==(!`$8```"]T@$`'0````33`0`M````(M,!
M`"4```!0TP$`+@```';3`0`F````I=,!`!L```#,TP$`+````.C3`0#7`0``
M%=0!`!X```#MU0$`$0````S6`0!%````'M8!`'4```!DU@$`+````-K6`0`;
M````!]<!`#$````CUP$`5P```%77`0!-````K=<!`!T```#[UP$`&@```!G8
M`0`1````--@!`!T```!&V`$`&@```&38`0`;````?]@!`!X```";V`$`'P``
M`+K8`0`:````VM@!`!\```#UV`$`,````!79`0`>````1MD!`!,```!EV0$`
M*@```'G9`0`D````I-D!`"4```#)V0$`)````._9`0`9````%-H!`"<````N
MV@$`6````%;:`0`K````K]H!`#\```#;V@$`+@```!O;`0`B````2ML!`#H`
M``!MVP$`7````*C;`0!'````!=P!`"8```!-W`$`*````'3<`0`M````G=P!
M`$L```#+W`$`6P```!?=`0!#````<]T!`$0```"WW0$`+@```/S=`0`F````
M*]X!`"0```!2W@$`)P```'?>`0!G````G]X!`%T````'WP$`9@```&7?`0"R
M````S-\!`!@```!_X`$`)@```)C@`0`T````O^`!`"T```#TX`$`0@```"+A
M`0`B````9>$!`$0```"(X0$`'P```,WA`0`*````[>$!`*T```#XX0$`/@``
M`*;B`0`@````Y>(!`#4````&XP$`)@```#SC`0`?````8^,!`",```"#XP$`
M!````*?C`0`(````K.,!``,```"UXP$`"P```+GC`0`*````Q>,!``D```#0
MXP$`"0```-KC`0`(````Y.,!`!(```#MXP$`!P````#D`0!:````".0!``0`
M``!CY`$`$0```&CD`0`$````>N0!``<```!_Y`$`!0```(?D`0`%````C>0!
M`#H```"3Y`$`!````,[D`0`7````T^0!``8```#KY`$`$@```/+D`0`-````
M!>4!``(````3Y0$`"````!;E`0`%````'^4!`!(````EY0$`#````#CE`0`/
M````1>4!``8```!5Y0$`$@```%SE`0`+````;^4!``,```![Y0$`)P```'_E
M`0`$````I^4!``8```"LY0$`!P```+/E`0`>````N^4!`#8```#:Y0$`(P``
M`!'F`0`D````->8!`!H```!:Y@$`+0```'7F`0`P````H^8!`!X```#4Y@$`
M'P```//F`0`=````$^<!`"(````QYP$`'0```%3G`0`9````<N<!`!\```",
MYP$`'````*SG`0`6````R><!`"P```#@YP$`&@````WH`0`I````*.@!`"0`
M``!2Z`$`(0```'?H`0`C````F>@!`"````"]Z`$`'0```-[H`0`A````_.@!
M`"@````>Z0$`*````$?I`0`C````<.D!`"(```"4Z0$`'P```+?I`0`<````
MU^D!`"(```#TZ0$`&0```!?J`0`?````,>H!`"P```!1Z@$`+P```'[J`0`9
M````KNH!`"(```#(Z@$`.0```.OJ`0`E````)>L!`"<```!+ZP$`)0```'/K
M`0`H````F>L!`"$```#"ZP$`'P```.3K`0`J````!.P!`"`````O[`$`*P``
M`%#L`0`F````?.P!`#,```"C[`$`$@```-?L`0`.````ZNP!`!T```#Y[`$`
M+0```!?M`0`;````1>T!``P```!A[0$`#P```&[M`0`6````?NT!``T```"5
M[0$`%````*/M`0`A````N.T!``8```#:[0$`"````.'M`0`C````ZNT!`"8`
M```.[@$`&0```#7N`0`C````3^X!`!D```!S[@$`!@```(WN`0"\````E.X!
M``P```!1[P$`$@```%[O`0`'````<>\!``@```!Y[P$`#@```(+O`0`.````
MD>\!`!L```"@[P$`#@```+SO`0`T````R^\!`!``````\`$`%````!'P`0`'
M````)O`!`!,````N\`$`"P```$+P`0`W````3O`!``@```"&\`$`'P```(_P
M`0`.````K_`!`!(```"^\`$`&````-'P`0`W````ZO`!`!@````B\0$`#```
M`#OQ`0`A````2/$!``T```!J\0$`#0```'CQ`0`4````AO$!``H```";\0$`
M&@```*;Q`0`&````P?$!`"4```#(\0$`"````.[Q`0`G````]_$!`"(````?
M\@$`"0```$+R`0`>````3/(!``<```!K\@$`!P```'/R`0`+````>_(!`$(`
M``"'\@$`"P```,KR`0`/````UO(!`!,```#F\@$`%0```/KR`0`,````$/,!
M``H````=\P$`!P```"CS`0`1````,/,!``@```!"\P$`%P```$OS`0`,````
M8_,!`!(```!P\P$`$````(/S`0`(````E/,!``H```"=\P$`%P```*CS`0`'
M````P/,!`#$```#(\P$`#````/KS`0`0````!_0!``<````8]`$``@```"#T
M`0`,````(_0!`!$````P]`$`"P```$+T`0`$````3O0!``D```!3]`$`#```
M`%WT`0`-````:O0!`!(```!X]`$`$0```(OT`0`2````G?0!`!,```"P]`$`
M#````,3T`0`V````T?0!`"4````(]0$`)@```"[U`0`7````5?4!``\```!M
M]0$`+@```'WU`0`%````K/4!`!(```"R]0$`0````,7U`0`,````!O8!``D`
M```3]@$`!@```!WV`0`$````)/8!``0````I]@$`#0```"[V`0`5````//8!
M``4```!2]@$`!@```%CV`0`&````7_8!``T```!F]@$``P```'3V`0`/````
M>/8!``H```"(]@$`-0```)/V`0`J````R?8!`"<```#T]@$`!0```!SW`0`:
M````(O<!`!\````]]P$`(@```%WW`0`D````@/<!`!$```"E]P$``@```+?W
M`0`$````NO<!``P```"_]P$`"P```,SW`0`&````V/<!``,```#?]P$`#@``
M`./W`0!!````\O<!`"D````T^`$`&````%[X`0`I````=_@!`"T```"A^`$`
M/0```,_X`0`2````#?D!`)`````@^0$`)0```+'Y`0`W````U_D!`"`````/
M^@$`+@```##Z`0`K````7_H!`"$```"+^@$`*@```*WZ`0`I````V/H!`"8`
M```"^P$`)0```"G[`0`H````3_L!`",```!X^P$`)0```)S[`0`U````POL!
M`!4```#X^P$`%`````[\`0`)````(_P!`&@````M_`$`"0```);\`0"-````
MH/P!`'<````N_0$`;P```*;]`0`V````%OX!`%\```!-_@$`#@```*W^`0`A
M````O/X!`!4```#>_@$`$@```/3^`0`>````!_\!`!L````F_P$`,0```$+_
M`0`:````=/\!`!H```"/_P$`2P```*K_`0`9````]O\!`!8````0``(`"P``
M`"<``@`$````,P`"``8````X``(`"````#\``@`%````2``"`!<```!.``(`
M$````&8``@`9````=P`"`"(```"1``(`#P```+0``@`'````Q``"``D```#,
M``(`"0```-8``@`-````X``"``<```#N``(`!````/8``@`2````^P`"``L`
M```.`0(`"P```!H!`@`/````)@$"``H````V`0(`"````$$!`@`0````2@$"
M``H```!;`0(`$P```&8!`@`*````>@$"``X```"%`0(`$@```)0!`@`(````
MIP$"``8```"P`0(`&P```+<!`@`6````TP$"``L```#J`0(`%P```/8!`@`/
M````#@("`!\````>`@(`%0```#X"`@`%````5`("`!````!:`@(`!@```&L"
M`@`$````<@("`!T```!W`@(`"P```)4"`@`"````H0("``(```"D`@(`$@``
M`*<"`@`+````N@("``8```#&`@(`$P```,T"`@`6````X0("``4```#X`@(`
M(````/X"`@`"````'P,"``0````B`P(`#@```"<#`@`3````-@,"``<```!*
M`P(`"0```%(#`@`0````7`,"``<```!M`P(`'````'4#`@`&````D@,"`!<`
M``"9`P(`#P```+$#`@`2````P0,"``(```#4`P(`!P```-<#`@`7````WP,"
M``T```#W`P(`$P````4$`@`-````&00"``T````G!`(`,````#4$`@`(````
M9@0"``8```!O!`(`#@```'8$`@`%````A00"``(```"+!`(`"P```(X$`@`!
M````7`<``#`````L!@``&`4```````"X!```J@8``!X`````````"08``.0!
M``#&!```C`4``"L"````````E`$``*L%``````````````````!F!```7@(`
M`",$``#*`````````!T#``"4!````````"$`````````V0(```````"?`@``
M>`$``)L#```J````[`8```````"3!````````-(!``#*!0``:`$``!L!``"/
M`P```````,`#``";`@``:0$``(('```H````)@(``'\!``#V`P```````'H'
M````````10(``"\%`````````````!L'`````````````+H#````````````
M`'`$``!,````Y@8``$0!````````2P8``#H"``"T`@``I0(```````!/`0``
M2P(````````=`@``>`<``(("``"F`@``"@<``!@!``!X!`````````H!``!!
M```````````````>!0```````,L```#Z`@``,P```%X&``#/`P``GP0``(\%
M``!>`0```````%L!``!S!```Z@(``/L#``!I`@```````/8$````````W0$`
M````````````<````+\!````````J08``'$#`````````````&D%````````
M+P0``&@&``#$````C0$```P$``#O`P``2@$``'0"``!4`@```````#$`````
M`````````*4`````````"0$``,D&```$````;@4``'L&````````IP8``.L&
M````````&@0``````````````````#0```#C!```LP4```````#1````)P``
M`!<$````````5@0``.@"``!;!```L0,```````#5`@````````````#-`P``
M`00``````````````````#\'```P`@```````-,#``#V`0```````/@"```7
M`@````````P'````````<`(``%4```#Q`P``O0,``*\%``"Y!0``N`$``-@$
M``"-!0``800``-`%``!.!P```````'0!```*````50<```````!:`0``R@$`
M`$H```#I!@``@0$``+D#``#4`0```````(<&````````R`0``%P!``#`````
MN@8```````"[!0``9`8``&$```#R`P``2P$``"H"```F!```<P8``%\%``!<
M````:`,``$P%````````L`$````'``#B!``````````````X!P``,`8`````
M```/`P`````````````@`P``O`,``)T```#$`@``V@,`````````````D`8`
M``0#``"]````B`(```````"M!0```````-P&```:`P``G`(``&\'````````
MM`8```````"&````P@$``*\&``#I!```B0,```````!S`0``*P0``$X%````
M`````````!L%``"A````%`0```````!;`@``.P,``,\%``"A`@```````)<#
M``!B!```!`4``-H&````````(````"0$``#(`0```````+($```B!@``0P<`
M`*P$``!Y`P```````(X#``#1`@``6P,``#P#``#5`0``EP$```````!Y!@``
M`````&\```#>!0````````````#Q!@```````(P!```,`P``X`4``-D#``!(
M!P``E`4``'$$``#V````80$``$(&````````&P0``"P%``"-````(08`````
M``"V`@``3`8```````#<````1`<``+D!``"(`0``;@<``.T#```X!```(00`
M`!\!``!H````LP```!(`````````HP4```````"R`@``<0```/0!``!\````
M_@4```T'``"*`````````/X"``"3````S`(```````":`0``'0<``+8#``!#
M!@``3`<``'`&`````````````*8#``!Z!0``````````````````.P(``&<!
M``!1!P``?P(``*L!````````'`(``"T!```W!@``F04`````````````&0$`
M`$X```"X!@``\P8``*8$`````````````,D`````````D@,```````#>!@``
MW0```,H&``#A````]````#`!``#^````+`0``$D```"C`P``?`$```````#Q
M``````````````#6!0```````&0'``!`!P``;P$``)L$``"C````+@<``(`%
M````````:@<```````"L`0```````$D&````````+P```/D"````````<0$`
M``````#<`0````````````#@`@````````@&```-`0``#@<``-D$``!:````
M^P$``!T$```/`````04``(\````=!0`````````````&!```6`8``$@&``"*
M!@```````%(!``!B!@``W`4``"$%``"/!```^P4``-```````````````'@&
M````````#@$``#8"``#T!@``O@$``%$"``#T!0``Q@4``(\'``"@````````
M``````"I`P``J`8``(L%``"=`P``M@4``&8&````````Z`,```````"`!@``
MT`(``&X````"`0``0`,``!D'``".!@``````````````````-@,``(L```!`
M`0``30```%<%``!)`0```````%$$````````U@(``*\```#W!@``.00``$,!
M``"]!@``60<``-L```"7!````````"0````(`0``?0,``)<&````````-@$`
M`*P%```1````$`0``-8$````````,0$``,P!``"Y`@```````#D```"]!```
M```````````.!```"0<``$H'``!2!P``1@<``"P"````````)0,``&<"``"8
M!```U`,``"`"````````O@4``.(````(`P``=@$``,8&``!I!@```````.L#
M``!+!```X@(``#@#``!"`0``Z````,($````````30(``&X#````````>@0`
M``````!7`@``AP0``.```````````````(H%``"<`P``-P4``)\%``"[`0``
M^@4```````"W`P``*P,``$4&``#7!0``D`(``%\'```!`@``+P8```<#```C
M!0``K`(``$X"```#!@```````-H%```S!@```````',```"*!```\P$`````
M``#]`0````````````#Z````U`8``.X````U!0``A`0``&H#``!M!@``````
M``````!/!```8`(``!,!``!!`0``@`0```````"U!```-@```"H#``!0`0``
M1P4``'P'```[!0``6@,``'P#``#5!@``$@4``#P!``!D!```$@<`````````
M````?0<```````!P!P``Y0(```````#S````/0(``$D$```F`0``B@,```,$
M``#I`@``PP8``-$!```)`@``?P4``"@$``#^`P``V@0``.H&````````````
M`'8#````````_0```!8%``""`P``_P,``,\"```U!@``3`,``-@#``!1````
M:P0```8#```A`P``Y08`````````````9P,``(L#````````2P4```````!2
M````.@8``&P"```B`P```````)H"```>!P````````\'``!Y`0``5P```.`&
M``!Z````(@4``&,$``#(`@`````````````'!@``G````%,!``#.`0``@04`
M``P%``!R!@```P,``","```X````5`4````````M````C@<``"0"````````
M(@$``&<`````````W@,``%,````K!0``)`$``````````````````$0$````
M````"`4``/4%````````:`4``"T%`````````````$0`````````5@$``#<'
M``#J`P``6@8``!,$`````````````"D'````````B0```+0```#>````````
M`'4&`````````````&$%```'`0````````X"``````````````````#G`0``
MF@```,P#``#<`P````````````"O`@``9@(``(X$````````/`<```````!9
M!```%@,````````&!P``V@````````#0!```\P0```````!8`@```````&`$
M``!]!```S`8``,@%``"R````)00```````"$`P``9P<``+4````"!0``J@4`
M``(&```:````<@4``$L```!J!```Q00``+X#``!8`P```````#0"````````
M`````*0!```"`````````*,$``````````````````#@`P``404``"@#``!-
M`P``(0<``-H!``#X!```\`4``$4#``!?`````````*P&```6````````````
M`````````````#L```!4````I00``#,$``#3`@``OP(``.\&```;`P``C```
M`)X#``!,`@```````%X%````````60,``-0%````````@`(```````!0`P``
M\`8``*<#``#3````SP````````#B!@``@@```-,$```'!```7P(``!P%``!B
M!P``Y00``/`$``!5`@``+@8``,(&``!7!```Q0$``&X&````````000`````
M``"#````F@0````"``"Q!@``5@,``+L```"2`0``G@8`````````````````
M``````"$````A`8``$P!``````````````````#[`@```````(<!``#;`P``
M`````#(%``#N`@``#P$``(4!```;!@```````+`````8!@``:@$``(`!````
M````E0```-\$```[`0``>P$``(P"``#&`@``MP0``%<'````````2@(```X&
M``#&`P``-`,```@"```P!0``40$``,<#```4!P``100``&4%``#A`0``````
M`"H!``!.`0``3`0``-<!``"?`P```0$``,<%````````5P$``,X%``!Z`P``
MK@,``-@```"Q`0``/00``#,"``!2!```!@4```````!#!0``1`,``*4!``"1
M!```'P```*`"``````````````````#!`0``6@<``)P!``#[!@```````!D%
M``#O`0``<`$```````"T!0``;`4``-@"````!@```````-D!````````]0,`
M``````"!!@``*@0``&,```````````````````````````````````#%`@``
M^`,``!@"``#1`P``$@0``&,"````````O0(`````````````9`,```````#'
M````$P(``&4'``"0`P``/P4``%0#```]```````````````@!@```````,`%
M``!E!@``E@$``````````````P<``'D"````````L@$``+8`````````1P0`
M`(,$``!^````IP4``,L!````````]`,``)0&``!0!0``!0<``(4'```F`P``
M%0```(4#```W!```.P<``%T"````````*`<``````````````````+4&``#Q
M!```'P<``)<````B!`````````````!4!@``TP8``+L$``"S!@``GP$```P`
M```$`0``,08``$$'``#9!0``F`(```````#!!```XP,``+,!``#\!```````
M`'('````````;P,``'<$````!0``2@8``,0$``#Y`````````%0'``#>`@``
M'`8``.8```"M!@```````-8&``#_!```W`0````````U````!0,``%,"````
M````=0$``",&````````!00``-,!````````I08``(8#```^`0``P@,``#P%
M``",!@``````````````````@`````````"%````%P8``'4#````````ZP0`
M`+L#````````A@8````````N`@``K@8``)(```!/!@``F@,``$@%````````
M5@```-X!``"2!```C`,``%(%````````<P(``',#```-!@``%0$```````"?
M````A00``````````````````$`&```#!0``F@4``#X'````````1@8``&`&
M``````````````````"H`P``D04``(<'``"'`P``C@4``'X"````````"P0`
M``````!Q`@``504``-L&``"@!@``L0`````````0`@``G0$````````,`@``
MG0(````````1`0````````````!3!```2`$``-T"``#[!````````!4'``!K
M`@```````-X$```T!@``5P,``$('``#?`P````````````#=!0``%@0``&\&
M``"L````$0(``*`$````````LP(```````#-!0``J`$``+<"``#G!@``<`,`
M`%T!``#I`0``H`4``!X"`````````````.,"```?!`````````````"(!@``
M)`<`````````````\04``&0"````````R0$``&\"```G`@``\0$``,`"```A
M`0``'@,``!(&```X!@``60```%T```!O!0``WP$``/P"```W`0``]00``!P$
M``````````````````#B`0``W`(```T$``"E!0``HP$```0"``!^`P``CP(`
M`&,#````````4`0``.H```"^````<`4```````#)!```_`4``)@!````````
M`````&P!```6!@``-@4``)8"`````````````+`%``"8`P``,@(``*L$````
M````?04``)D&``!)!P``_@$``'\````7!0``QP$``/X&``!L!@``$00``!,%
M```4`0``Z@$```````!@`0``K@4``,,#```4`P```````'4"````````9@$`
M````````````C0<``"T#````````)`,``,H"``!I`P```````)X`````````
M````````````````J@0``+4!``"Q!```S@(```````!-!P``.0<``/,#````
M````T@0``"X#```9`P``@0,``-`#```U!P```````,P%``#V`@``3P``````
M``#6`0```````&(```#4!```"@(`````````````E`(``)``````````````
M`"D&````````S0(``*0#``#P`@``8P<``-D`````````:P<``,`&````````
M2@0``#\&````````[P(``"D```"'`@```````'T&````````>@$```H%``!7
M!@``,0(`````````````WP(``+,$````````Y`(``,T````-````+P<`````
M``!E!```RP4```````#6````X`$``(8!```S!0``QP(``)(%``!R`P``````
M`-\&``!;!0``)08`````````````[``````````-!0````````````!M`0``
M#P(```````"A!@````````````"\!```8`<``(,"```0!@``2P<``-$&```]
M!P```````),!``#+!````````),#````````.0$``)P&``"Y````H@(``/4"
M```]!0``/P0````!``!/`@``7@<````````@`0``F0$``-(#```$!```N`(`
M`+\#````````<08``,L&``#/!```DP8````````:!0``Y04``*@````T`0``
M_P4``!D&``#Y`P``,0<```4!``#E`0``*0$``+(&`````````````*D"``#$
M`P``]P0````````L`0``2`(``)X%```<````%`(``*T"```P!```;`0``(@$
M``#0`0``UP0``.(#```M`@``9````"D%```F!0``N@$``)8&``!0!@``(@(`
M`"$"```X!0``Y@0``/T&``#\!@``$````%H$````````2`,``%4&````````
M4@8```````#I!0``@0(``*X!```R`P```````!\&```7!P````````````"\
M````304```````!^!@``R04``.<"``"K!@```````.$&```5`@``X`0``)T$
M`````````````/D!``"1`@``S@8``!L```!U````L`,```````#H`0``[P0`
M`.P#``#C`````````*(```#+`P``L`(``)8#``"5!@````````````!:!0``
MY@,``&\$``!8!```^04``!\%```G!P``HP8``*$$``#]`@``I`(```````"U
M`@``_P```+@#```"`P``[`0``-$%`````````````/P#``"5`@``90$``'P&
M``!%!P``_00``,,!``#&`0```````!@'``#=!````````%T%````````OP8`
M`'L"``"Z!```ZP(``#,#``!T!```W0,``&L!````````U00``.<#``#X`0``
MN@4``.L%```)`````````(L'``#(!@``O@0`````````````8@(``&T```!8
M``````````,````^!0```@<```````#Z!@``PP```,,"````````F`8`````
M``!W`@```````#T#``````````````````#!`@``H0$``(X```!%!0``-`4`
M`#('```&!@``:`(``"4"``!*!0```````+<%`````P```````-4#```E!P``
M-`<``(L"``"*`0``[00``)(&```7`0```````-L!`````````````*0```!A
M!@``%04``(8"````````[`4````````=````'08```````"T`0```````(<%
M`````````````)$#```*!@``+P(``)0`````````=P$``#\!````````$P8`
M``````!9!0``8P4``,,%``#D!@``C`<```````#M!0``Y`0``+8$``#U!@``
ML@4````````D!0``4@(``#H!````````V@(```````!'`@``/08``.0%````
M````B08``.0```#"`@``_04```````"0!0``1P```.X%``!!`P``````````
M`````````````)$````Z!P``:@(``(\&```X`0``Y@$``(H"````````6P``
M`(<````@!P``M04``.,!``"H`@``\@```#,!```:!P``;`<``(8%``!2`P``
MQ`$`````````````I@$``,0&````````1@,``-,%``"F`````````',%``#6
M`P``8@$```````"5!````````/``````````K00```````#W`0``)@<``+@%
M``"+`0````````````!1!@``VP4``!\#`````````````.H$``"1`0``O04`
M`!`%``!W!0`````````````M!P``A`(``&`%````````!P```/`#``!$!@``
M`````!0%``!5!```O`8``*(%````````!P(``"T&``!R!```A`<``#$#``!=
M!@```````#4"```S!P```````!<``````````````+0$``#.````F`4``+P"
M```E`0``;0<``!$'``#N`0``4````&H&````````!P<``!@$``!+`P``^00`
M````````````ZP````\$```%`@```````!("````````>P0``'T"````````
M@P$```<%````````'P(``*T#```V!P``PP0```````!B`P``,`<``$("``#N
M!```8`````````!X!0``>`(``$($````````<@```/P!``""!```/@,``)P%
M``#R!```Y0```-T&````````/0$``*H#```W``````````````!4!```````
M`"4```!-!@``(P<``!X&``#%!0```````&`#`````````````.$#``!Q!P``
M]P4```````">`@``@@8``"<&````````^P```!4$````````7P8``,<&``#J
M!0````````````"=!@``"P,``!,#````````RP(``-@%```G!```$@,``#8&
M````````EP4`````````````10```*@$``!.!@``,04`````````````P@``
M`+<!``"O!```&P(```````!^!0```````(L$``#2`@``N`````L'````````
MP0```"H'````````&@(``-4````0`P``^`8``/<#``"G````0`4``-@!```W
M`@``Q`4`````````````QP0``,4#``"I!````````-\`````````B`4``&4#
M``!K``````````````#O````M@$``%,#````````6`$`````````````````
M`*0%``!Z!@```@(```````!)!0``.`(``'X$``"K`````````)8%```_`P``
M_0,``'0#````````"`0``*L#``!G!```3P4``,T!```1!0```````,@#``"O
M`0``<@$```````#V!@`````````````#`0``7@,``"D#````````8P8```8!
M````````E`,``&8#``"B!```B0(``&T%``#.`P``7`(``.T&````````;@$`
M`)D$``#&````H0,``(4%``#U`````````+\````.````8@4```````!Q!0``
M$P```)D```!K`P````````P&````````H`,``.X&```*!```.0(```````!5
M`0``I@8``,$%``#%````@P,```L&```F!@``5@4``%D"``";`0``A08``#X&
M``"``P``?0$``#$$``!G!0``=P8``(,&````````.P0``'\$```B!P``%`8`
M`(H'````````\P(``#P$``!4`0```````.D#``#F`@```````"8```!-!```
M#0,```````````````````````!0!P```````"(```#X!0``9P8``"X```"\
M`0````````````!Z`@``A`$``&D```!"!0``F``````````<`P```````.T!
M``"-`@``UP````````!)`@````````````!I!P``80,``$8%```^!```"@,`
M`)("`````````````'\'``!!!0``'@0``'L'``!U!```%@$``-(````H!@``
M7P,``(@'````````:`<``*$%``"1!@``XP8``!P'``!&!```+`<``'8```!)
M`P``SP$```````#H!0``+P$``/H$```0`0``/```````````````````````
M``#R!@``[P4``,(%````````.@4``.8%````````$P<```````#A!```9@4`
M`"D$`````````````,D#``!V!```IP(````````<`0``=@4``$4!``#%!@``
M"`<```````#,!```2`````8```#M`````````(8$``!9!@``.@0```L"```4
M````G@$``%,%``#T!```6P<``(T#````````_`````````!A`@``X04``!H&
M``#X`````````-`&``"(`P``=`8``!@#```@!0``/`8``&$'``!'!@``^@$`
M`&4"``!3!P``<P<``*0&```"!```>P```/\&``!:`@```````&@$````````
M*@8``&T"``#P`0``.@```"@"````````X0(```````````````````````"!
M!P``L0(``#(````K`0```````/("```+`0``(`0```\&``!1`P``H@$``'D'
M``"V!@``R````%P&``!L````JP(```````!#`P```P(``&4```!3!@``A0(`
M``````![`P``HP(``+4#``#I````K0$````````+````$`<```D%``"N!```
M+@4``&0!`````````````,`$````````7`0``)8```#N`P``/`(```````"N
M````=`4```````!M!```CP$```````#R`0``=@<``!$#``"M````%P,`````
M``![!0``T00``!(!```L`P``700``!D"``"F!0``;0,```````"-!```!0``
M`"X$```%!0```````$,$```!`P``=0<``",#``!J!0``+P,``)`$````````
M`````````````````````%4#````````U`(```X%``!/`P``.P8```````!9
M`0```````*<!``#C!0````````````#*`P``DP(``*H```#G!```F0(``%@'
M`````````````)4#``!V`@``WP4``'8&````````G`0``/0"``!F````````
M`$H#```)`P```````%P%``!$!0``N08``.4#``!0`@``@P4`````````````
M/@(``+0#``#Z`P``-@0``&0%``#H!@``-P,``%P#``#*!````````%T#``!!
M`@``L`0``*4#```L`````````+$%``#H!```]P(````````)!```F0,``/,%
M``#8!@````````T"``#_`@``$08``(@````>`0``L@,```0'``#Y!@``F@8`
M`.(%`````````````*`!```K!@``#`$```````"[!@``U04```````!?!```
M[0(``)\&``"S`P``"````$0"```/!0``/P(``$$&``"D!```?P,``.P!``!&
M`@``2`0``&L%````````)04``,T$``!^`0`````````````U`P```````'P"
M``"&!P```````(X"``#7`P``%08``,X$```C`0````````````"G!```1P<`
M``````#``0``)P4```0&`````````````$8!``"6!```(P```-L$````!```
MNP(``*D!````````L`8``"X!``!`!```C08```````"!!```````````````
M````&0```(P$`````````````'D$``!.!```)P,``!T!``#G!0``T@8``.0#
M````````E04``),%``!\!0``P08````````&`@``1P,``+X"``"#!P``3P<`
M```````%!@``7@```!D$`````````08``/\!````````S````!8'``#2!0``
M`````&X$``#-!@```````((!``")`0```````"D"```T!```0@```'<'``#^
M!````````+T!``!J````0`(``+\$``"W!@``UP(``````````````````#(!
M``!^!P``D`$``$,"``".`0``J`4``$8````P`P``EP(``,$#``!6!@``````
M```````8````:00``+H"``!.`P``5@<`````````````````````````````
MJ04``'4%``!R`@``\@4```````!6`@``8P$``"<!``#9!@``6`4``*D```!=
M!P````````````"Y!```*`$``"L```")!````````$(#````````.0,```X#
M``"L`P``ZP$``"@%``!K!@```````#D&```J!0```0<``&X"```6`@``A`4`
M``````";````SP8``-<&``!-`0``N@```%L&```R!````````-0```")!P``
M]0$```````!```````````````!?`0``"P4``*\#``!'`0```````/$"````
M````[`(``"0&```:`0````````````")!0```````)T%``!W````>04``*(&
M``"+!@``?`0`````````````,@8``'\&````````+00``#H#```5`P``.04`
M`&P#```K!P``@`<``((%``">!```9@<``$,`````````/@````````#G````
MVP(``'0```!X`P``OP4```````#)`@``]@4```````"^!@``?0```*H!````
M````@0``````````````>````)4!```U!````````'D```"N`@``]P``````
M``";!@``J@(``#\```"B`P``MP```#4!``!T!P```````)L%````````=P,`
M``````"\!0``7@0````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B(&ES(&YO="!A(&1I<F5C=&]R>2X`(B5S(B!I<R!N;W0@
M82!V86QI9"!C:&]I8V4N`"(E<R(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE
M($AO<F1E(%)E9VES=')Y+@`B)7,B('1R964@<F5N9&5R97(@;F]T(&9O=6YD
M+@`B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`(B5S(B!W
M87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S(B!W87,@
M;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@86QL;W=E
M9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y;W5R('!A
M<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E
M<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS
M("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@
M;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E
M<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O<&5R871I
M;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N>2!O<&5R
M871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I;64N`"5S
M(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E
M<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@
M3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`E<SH@5&AI<R!M97-S86=E
M(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET(&-L86EM<R!T;R!B92X@0F5W87)E
M(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@:6X@:70@;W(@;V8@<')O=FED:6YG
M('1H92!S96YD97(@=VET:"!A;GD@<&5R<V]N86P@:6YF;W)M871I;VXN`"P@
M9W5S=&EN9R``+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M
M870`,C0@:&]U<G,`/%!R979I;W5S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R
M97%U:7)E9"!F;W(@=&AI<R!B;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C
M=7)R960`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V
M97)I9GD@82!S:6=N960@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@
M4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-
M12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A
M(&UE<W-A9V4N`$$@<'5B;&EC(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E
M;F-R>7!T(&$@;65S<V%G92X`04T@0VQO=61S`$%-($QI9VAT(%)A:6X`04T@
M4F%I;@!!32!3:&]W97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`
M06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L
M90!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S
M<R!D96YI960@8W)E871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I
M;VX`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN
M9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D
M9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE
M;6)E<G,`061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3
M:61E8F%R`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S
M(&)O;VL`061D('5S97(`061D960@(B5S(B!T;R!T:&4@<WES=&5M+"!B=70@
M8V]U;&0@;F]T(&%D9"!A9&1I=&EO;F%L('-I9VYU<"!I;F9O<FUA=&EO;CH@
M)7,N`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!L;V<@:6X@
M;F]W+@!!9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S
M<R!";V]K`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R
M('5S97)S`$%D;6EN:7-T<F%T:6]N`$%D<P!!9F=H86YI<W1A;@!!;&)A;FEA
M`$%L9V5R:6$`06QI87,`06QI9VX`06QI9VYM96YT.@!!;&P`06QL($%U=&AE
M;G1I8V%T960@57-E<G,`06QL($=R;W5P<P!!;&P@4&5R;6ES<VEO;G,`06QL
M(&9O=7(@<VED97,`06QL;W<@;75L=&EP;&4@861D<F5S<V5S`$%L;&]W('-E
M='1I;F<@;V8@;W)D97)E9"!L:7-T('1Y<&4_`$%L<F5A9'D@97AI<W1S`$%L
M=&5R;F%T92!)35-0($QO9VEN`$%L=&5R;F%T92!)35-0(%!A<W-W;W)D`$%L
M=&5R;F%T92!)35-0(%5S97)N86UE`$%L=&5R;F%T92!E;6%I;"!A9&1R97-S
M`$%L=&5R;F%T92!T96UP;&%T97,`06QT97)N871E('1E>'0Z`$%M97)I8V%N
M(%-A;6]A`$%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I9FEE9"X`06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`06YO;GEM;W5S(%!R;WAY`$%N<W=E<@!!;G1A<F-T:6-A`$%N=&EG=6$@
M86YD($)A<F)U9&$`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L
M:6-A=&EO;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O
M=F4`07!P<F]X:6UA=&4@4VEZ90!!<')I;`!!<F%B:6,@*%=I;F1O=W,M,3(U
M-BD`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.86UE`$%R92!Y;W4@<W5R
M92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU<"!R97%U97-T(&9O<B`E
M<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D96QE=&4@(B5S(B!A;F0@
M86YY('-U8BUG<F]U<',_`$%R9V5N=&EN80!!<FUE;FEA`$%R;65N:6%N("A!
M4DU30TE)+3@I`$%R=`!!<G5B80!!<V-E;G-I;VX@27-L86YD`$%S8VEI($%R
M=`!!<VEA+U!A8VEF:6,@4F5G:6]N`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E
M9F]R92!D;VEN9R!M86EN=&5N86YC92!O<&5R871I;VYS/P!!<W-I9VYM96YT
M(&-O;'5M;G,`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT('!E<FUI<W-I
M;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N
M+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<VAA<F4N`$%T=')I
M8G5T97,`075G=7-T`$%U<W1R86QI80!!=7-T<FEA`$%U=&A?8WER<W%L.B!2
M97%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?8WER=7,Z
M($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E9"!C87!A8FEL:71E<RX`
M075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+@!!=71H7V9T<#H@4F5Q=6ER960@1E10(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M($-O;7!I;&4@4$A0('=I=&@@=&AE("TM96YA8FQE+69T<"!S=VET8V@N`$%U
M=&A?:6UA<#H@4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@
M06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E;6]V:6YG('5S97)S(&ES
M(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P
M.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A
M<#H@56YA8FQE('1O(&%D9"!U<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E
M<G9E<B!S86ED.B``075T:%]L9&%P.B!5;F%B;&4@=&\@<F5M;W9E('5S97(@
M)7,`075T:%]L9&%P.B!5;F%B;&4@=&\@=7!D871E('5S97(@)7,`075T:%]L
M9&%P.B!5<&1A=&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y+@!!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!297%U:7)E9"!S;6)A=71H
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!
M=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C
M=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S
M97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E
M<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R
M;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"
M86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D
M;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A
M<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!"
M:'5T86X`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B
M(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O
M;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D
M97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T
M;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@
M5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D
M($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I
M8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@
M=V%S(&YO="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M
M97)O;VX`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F
M:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA
M;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG
M="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE
M;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD
M(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U
M="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C
M=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`
M0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O
M<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO
M="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R
M9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM
M86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A
M9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N
M90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N
M(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I
M9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@
M4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA
M;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N
M('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG
M('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R
M96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I
M;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`
M0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@
M82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S
M92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M
M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#
M;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U
M="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN
M9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``
M0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S
M("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D
M(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S
M96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#
M;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP
M86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T
M:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET
M:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO
M;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O
M<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H
M90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN
M96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE
M8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N
M.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O
M;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO
M=7(@861D<F5S<R!B;V]K+@!#;VYT96YT<R!O9B`B)7,B`$-O;G1I;G5E`$-O
M;VL@27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y(&9A:6QE9#H@)7,`0V]P>2!S
M96QE8W1I;VX`0V]S="!)1`!#;W-T82!2:6-A`$-O=&4@9"=)=F]I<F4`0V]U
M;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!01U`@<VEG
M;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O
M=6QD(&YO="!B:6YD('1O(&QD87`@<V5R=F5R`$-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E
M<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-
M24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@
M;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E
M;&5T92!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@
M;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E
M=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T
M8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#
M;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`B)7,B+@!#;W5L9"!N;W0@;6MD:7(@
M(B5S(BX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME
M>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@(B5S(B!F;W(@=W)I=&EN9RX`0V]U
M;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E7U1A
M<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R>2`B)7,B+@!#
M;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@<F5A
M9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P87-S=V]R9"!F;W(@=&AE(')E
M<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O9B!T:&4@9&5T86EL<R!A<F4@
M;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C;VYT86-T('EO=7(@861M:6YI
M<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R(&AE;'`N`$-O=6QD(&YO="!R
M971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I979E(&%D9')E<W,@8F]O:RX@
M)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#
M;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T:6]N(&QI<W1S+B`E<P!#;W5L
M9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S`$-O=6QD(&YO
M="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T(')M9&ER("(E<R(N
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!S971U<"!U
M<&=R861E('-C<FEP="!T;SH@(B5S(BX`0V]U;&0@;F]T('-A=F4@=&AE(&)A
M8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N`$-O=6QD(&YO="!S879E('1H
M92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N(%EO=2!C86X@96ET:&5R('5S92!O
M;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V92!T:&4@8V]D92!B86-K(&]N("5S
M(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O9&4@8F5L;W<@=&\@)7,N`$-O=6QD
M(&YO="!S96%R8V@@=&AE($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@=6YL:6YK
M("(E<R(N`$-O=6QD(&YO="!U<&1A=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M('5P9&%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T('=R:71E
M(&-O;F9I9W5R871I;VX@9F]R("(E<R(Z("5S`$-O=6QD;B=T(&9I;F0@=&AE
M($UO>FEL;&$@4VED96)A<BX@36%K92!S=7)E('1H92!S:61E8F%R(&ES(&]P
M96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`B)7,B('1H92!F;VQL;W=I;F<@<FEG
M:'1S(&9O<B!T:&4@9F]L9&5R("(E<R(Z("5S`$-O=6YT960@=&5X=`!#;W5N
M=')Y`$-O=7)S97,`0W)E871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W
M(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`0W)E871O<B!097)M:7-S:6]N<P!#
M<F5D:70@8V%R9"!N=6UB97(`0W)O871I80!#=6)A`$-U<G)E;G0@-"!0:&%S
M97,`0W5R<F5N="!397-S:6]N<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@
M:7,`0W5R<F5N="!5<V5R<P!#=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD
M:71I;VXZ(`!#=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@
M=7!O;B!L;V=O;B!T;R`E<RX`0W5T`$-U="!S96QE8W1I;VX`0WEP<G5S`$-Y
M<FEL;&EC("A+3TDX+5(I`$-Y<FEL;&EC("A7:6YD;W=S+3$R-3$I`$-Y<FEL
M;&EC+U5K<F%I;FEA;B`H2T])."U5*0!#>F5C:"!297!U8FQI8P!$1`!$4TX@
M*'-E92!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]P86-K86=E+F1A
M=&%B87-E+F1B+FEN=')O+61S;BYP:'`I`$1A:6QY`$1A=&%4<F5E($)R;W=S
M97(`1&%T86)A<V4@3&]O:W5P`$1A=&4`1&%T92!296-E:79E9`!$871E('-E
M;&5C=&EO;@!$87D`1&5?;&5T92!#;VQU;6X`1&5C96UB97(`1&5C:6UA;"!N
M=6UB97)S`$1E8W)E87-E($EN9&5N=`!$969A=6QT`$1E9F%U;'0@0V]L;W(`
M1&5F875L="!)9&5N=&ET>0!$969A=6QT(%-H96QL`$1E9FEN:71I;VYS`$1E
M;&5T90!$96QE=&4@0V5L;`!$96QE=&4@1W)O=7``1&5L971E($QO9P!$96QE
M=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T
M92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T
M92!T96UP;&%T90!$96QE=&4@;65S<V%G97,`1&5L971E('!E<FUI<W-I;VYS
M(&9O<B`B)7,B`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(B!A;F0@86YY
M('-U8BUP97)M:7-S:6]N<S\`1&5L971E(')O=P!$96QE=&4@<V5L96-T960@
M:61E;G1I='D`1&5L971E('1H92!C=7)R96YT(&-O;'5M;@!$96QE=&4@=&AE
M(&-U<G)E;G0@<F]W`$1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S
M(BX`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0<F]B;&5M
M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE
M*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R
M871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S
M="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`
M1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M
M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9&5T86EL960@
M9F]R96-A<W0`1&ES<&QA>2!F;W)E8V%S="`H5$%&*0!$:7-P;&%Y(&9O<FUA
M=`!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VX`1&II8F]U=&D`1&\@;F]T(&1E
M;&5T90!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E+G!H<`!$
M;V5S('1H92!F:7)S="!R;W<@8V]N=&%I;B!T:&4@9FEE;&0@;F%M97,_($EF
M('EE<RP@8VAE8VL@=&AI<R!B;W@Z`$1O;6EN:6-A`$1O;6EN:6-A;B!297!U
M8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N`$1O=VYL;V%D
M`$1O=VYL;V%D("5S`$1O=VYL;V%D(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M(&%S(%!(4"!S8W)I<'0N`$1R;W`@9&]W;B!L:7-T`$1R=6=S`$4M36%I;`!%
M36%I;"UT;RU335,@9V%T97=A>2!D<FEV97(L(&9O<B!C87)R:65R<R!W:&EC
M:"!P<F]V:61E('1H:7,@<V5R=FEC92X`15)2`$5C=6%D;W(`161I=`!%9&ET
M($)L;V-K`$5D:70@1W)O=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES
M<VEO;G,`161I="!097)M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O
M<CH`161I="!P97)M:7-S:6]N<R!F;W(@(B5S(@!%9&ET('!E<FUI<W-I;VYS
M(&9O<B`E<P!%9'5C871I;VX`16=Y<'0`16ET:&5R(&5N86)L92!I="!T:&5N
M.B`E<RP@;W(@=7-E('1H92!B87-I8R!(5$U,('9E<G-I;VXZ("5S+@!%;"!3
M86QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA
M:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T
M:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S
M86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@
M:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T
M97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A
M<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H
M:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO
M=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P
M970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T
M97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R
M<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N
M8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E
M='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S
M`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B
M+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN
M=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U
M(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI
M;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I
M9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T
M960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O
M;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E
M9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&
M86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P
M>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T
M;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@
M=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD
M($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R
M.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``
M1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG
M;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z
M("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I
M;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A
M9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`
M1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R
M("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E
M<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&
M;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T
M(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H
M97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R
M('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE
M<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E
M`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O
M;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M
M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A
M8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I
M80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E
M;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B
M86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C
M:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA
M;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R
M;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?
M;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5
M;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U
M86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T
M8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E
M82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN
M(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE
M(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T
M:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(
M87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@
M27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(
M96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R
M90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?
M;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D
M9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@
M96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S
M<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO
M(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O
M2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L
M86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX
M;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A
M=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L
M92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z
M("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A
M;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED
M('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU
M;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@
M*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@
M;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`
M2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0
M(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@
M;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@
M0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O
M=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N
M<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES
M<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD
M;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T
M($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@
M='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE
M<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L
M;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E
M(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L
M;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`
M26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F
M:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D
M92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`
M26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I
M9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA
M=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E
M<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!)
M;G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E
M<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@
M=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D
M90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`
M26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D
M<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R
M9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R
M="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE
M<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P
M:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!)
M;G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E
M<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK
M`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T
M:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E
M<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L
M:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C
M:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA
M=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC
M96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@
M;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@
M;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S
M:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E
M+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!)
M;G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!)
M;G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I
M;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L
M92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L
M:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M
M,C`R,BU*4"D`2F%V87-C<FEP="!H87,@8F5E;B!D:7-A8FQE9"!O;B!Y;W5R
M(&)R;W=S97(@86YD('1H:7,@<&%G92!M87D@;F]T(&)E(&1I<W!L87EI;F<@
M8V]R<F5C=&QY+@!*97)S97D`2F]R9&%N`$IU;'D`2G5N90!*=7-T:69Y`$IU
M<W1I9GD@0V5N=&5R`$IU<W1I9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF
M>2!2:6=H=`!+87IA:VAS=&%N`$ME97`@;W)I9VEN86P_`$ME;GEA`$ME<F)E
M<F]S('-E<G9E<B!R96IE8W1E9"!A=71H96YT:6-A=&EO;BX`2V5R;F5L($YE
M=V)I97,`2V5Y($-R96%T:6]N`$ME>2!&:6YG97)P<FEN=`!+97D@3&5N9W1H
M`$ME>2!4>7!E`$ME>2!5<V%G90!+97D@86QR96%D>2!E>&ES=',@;VX@=&AE
M('!U8FQI8R!K97ES97)V97(N`$MI9',`2VER:6)A=&D`2V]R96$L($1E;6]C
M<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8`2V]R96$L(%)E<'5B;&EC(&]F
M`$MO<F5A;B`H155#+4M2*0!+=7=A:70`2WER9WEZ<W1A;@!,85]Y;W5T`$QA
M;F=U86=E`$QA;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA<W0@
M2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U87)T97(`3&%S="!5
M<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S
M`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y;W5T`$QE879E(&5M
M<'1Y(&9O<B!N;R!B;W)D97(`3&5B86YO;@!,969T`$QE9G0@:&5A9&5R`$QE
M9G0@=F%L=65S`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A8B!*
M86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EG:'0@1')I>GIL90!,:6=H="!2
M86EN`$QI9VAT(%)A:6X@16%R;'D`3&EG:'0@4F%I;B!,871E`$QI9VAT(%)A
M:6X@4VAO=V5R`$QI9VAT(%)A:6X@=VET:"!4:'5N9&5R`$QI9VAT(%-N;W<`
M3&EG:'0@4VYO=R!3:&]W97(`3&EM97)I8VL`3&EN:P!,:6YK('!O:6YT<R!T
M;SH`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P86=E
M('=H96X@9&ES<&QA>6EN9P!,:6YK<P!,:6YU>"!#;V]K:64`3&ES="`M('5S
M97(@8V%N('-E92!T:&4@9F]L9&5R`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L
M<"!4;W!I8W,`3&ES="!486)L97,`3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,
M:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI
M<W0M56YS=6)S8W)I8F4`3&ES=&EN9R!S97-S:6]N<R!F86EL960Z("5S`$QI
M<W1I;F<@=7-E<G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I
M;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P
M<F5V:6]U<R!S>6YC('-E<W-I;VX`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K
M<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W
M;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO
M;F<@=&5X=`!,;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA
M=&EN(&QE='1E<G,`3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-
M`$U/5$0`35,M5$Y%1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-
M4T<`36%C86\`36%C961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B
M;&EC(&]F`$UA9&%G87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@
M;&EN7VLN+BX`36%L87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`
M36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B
M96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO
M<V4@8V%T96=O<FEE<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG
M<R!S=&]R960N`$UA<F-H`$UA<F=I;@!-87)K('=I=&@@4V5E;B]5;G-E96X@
M9FQA9W,`36%R:R!W:71H(&]T:&5R(&9L86=S("AE+F<N($EM<&]R=&%N="]!
M;G-W97)E9"D`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA=&-H:6YG
M(&9I96QD<P!-875R:71A;FEA`$UA=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D
M:70N`$UA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T
M(#(T(&AO=7)S.B``36%X('1E;7`@;&%S="`V(&AO=7)S.B``36%X:6UU;2!.
M=6UB97(@;V8@4&]R=&%L($)L;V-K<P!-87AI;75M(&QE;F=T:`!-87D`36%Y
M;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`
M365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE
M('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE9"X`
M365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE<@!-
M971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@879A
M:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!-971A<D1"(&ES(&YO="!C;VYN96-T960N`$UE=&AO9`!-
M971H;V0@(B5S(B!I<R!N;W0@9&5F:6YE9`!-971H;V0@;F]T(&1E9FEN960N
M($-A;&QE9"!M971H;V0Z("5S`$UE=')I8P!-97AI8V\`36EC<F]N97-I82P@
M1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP
M(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI
M;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-
M:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A45%!?4F5Q=65S
M="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T
M92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I;VXN
M`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E9"!014%2('!A
M8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-;V)I;&4@36%I
M;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`36]D=6QU<P!-
M;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`36]N=&@@86YD
M('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE
M;&1S(&9O=6YD(&EN(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N`$UO
M<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D
M>2!A;F0@5VEN9'D`36]S=&QY(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`
M36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ
M=64`375L=&DM;&5V96P@9')O<"!D;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA
M<`!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN
M9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`
M3D\L($D@1&\@3D]4($%G<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.
M971H97)L86YD<P!.971H97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E
M(%523`!.971S8V%P92!#02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P
M;VQI8WD@55),`$YE='-C87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C
M871I;VX@55),`$YE='-C87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C
M97)T:69I8V%T92!C;VUM96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`
M3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@
M365S<V%G92!T;R`E<P!.97<@36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L
M*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D('=I;&P@
M97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H+@!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@-"!0
M:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E<@!.:6=E
M<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R871I;VX@
M9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA8FQE('-T
M<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@=&5M<&QA
M=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O<VET:6]N
M`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T:&5N=&EC
M871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D9&5D('1O
M('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO
M;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T
M:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O;F9I9W5R
M871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N
M`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@
M9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@
M<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S=7!P;&EE
M9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO
M(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V
M:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H
M92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y
M(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P
M96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`3F\@<V5P
M87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE`$YO('1E
M;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E
M<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A
M(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I
M;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`
M3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N
M97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I
M`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N
M($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.
M;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE
M;65N=&5D+@!.;W0@<V5T`$YO="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@
M=&\@8G)O=W-E+"!G;R!B86-K+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F
M(&-H87)A8W1E<G,`3G5M8F5R(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`
M3G5M8F5R<R!N;W0@<W!E8VEF:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB
M=71I;VX@;&ES="X`3TL`3V)J96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C
M=&]B97(`3V9F96YS92!F:6QT97(`3V9F:6-E`$]L9"!A;F0@;F5W('!A<W-W
M;W)D<R!M=7-T(&)E(&1I9F9E<F5N="X`3VQD('!A<W-W;W)D`$]L9"!P87-S
M=V]R9"!I<R!N;W0@8V]R<F5C="X`3VUA;@!/;FQY($E-05`@<V5R=F5R<R!S
M=7!P;W)T('-H87)E9"!F;VQD97)S+@!/;FQY(&]F9F5N<VEV92!F;W)T=6YE
M<P!/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N`$]N;'D@=&AE(&]W
M;F5R(&]R('-Y<W1E;2!A9&UI;FES=')A=&]R(&UA>2!C:&%N9V4@;W=N97)S
M:&EP(&]R(&]W;F5R('!E<FUI<W-I;VYS(&9O<B!A('-H87)E`$]P96X@:6X@
M82!N97<@=VEN9&]W`$]P96Y34TP@97)R;W(Z($-O=6QD(&YO="!E>'1R86-T
M(&1A=&$@9G)O;2!S:6=N960@4R]-24U%('!A<G0N`$]P96YS('1H:7,@;&EN
M:R!I;B!A(&YE=R!W:6YD;W<`3W!E<F%T:6YG(%-Y<W1E;0!/<'1I;VYS`$]P
M=&EO;G,@9F]R("5S`$]R9&5R960@3&ES=`!/<F=A;FES871I;VX`3W)G86YI
M<V%T:6]N86P@56YI=`!/<F=A;FEZ:6YG`$]R:6=I;F%L(&%P<&QI8V%T:6]N
M('1E;7!L871E`$]R:6=I;F%L('1E;7!L871E<R!I;B`E<SH`3W1H97(`3W1H
M97(@26YF;W)M871I;VX`3W=N97(@4&5R;6ES<VEO;G,`4$%-(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%!%05(Z.DUA:6P@8F%C:V5N9`!0
M1U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y<'1E9"!$871A`%!'4"!0
M=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D($1A=&$`4$A0($-O9&4`
M4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4F%I;@!032!3:&]W97)S`%!-
M(%-N;W<`4$T@4VYO=R!3:&]W97)S`%!-(%-U;@!032!4+5-T;W)M<P!03U-)
M6"!E>'1E;G-I;VX@:7,@;6ES<VEN9P!07TA0(%-H96QL`%!A9&1I;F<`4&%K
M:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE9`!0
M86YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A9W5A>0!087)T;'D@0VQO=61Y
M`%!A<W-W;W)D`%!A<W-W;W)D(&-H86YG960@<W5C8V5S<V9U;&QY+@!087-S
M=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A
M=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C;VYF:7)M871I;VX`4&%S
M<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU<W0@;6%T8V@N`%!A<W1E
M`%!A<W1E(&9R;VT@8VQI<&)O87)D`%!A=&@`4&5N9&EN9R!3:6=N=7!S.@!0
M96]P;&4`4&5R8V5N=`!097)F;W)M($UA:6YT96YA;F-E($]P97)A=&EO;G,`
M4&5R9F]R;2!M86EN=&5N86YC92!O<&5R871I;VYS(&]N(&QO9VEN/P!097)M
M:7-S:6]N`%!E<FUI<W-I;VX@(B5S(B!N;W0@9&5L971E9"X`4&5R;6ES<VEO
M;B!$96YI960`4&5R;6ES<VEO;G,`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R=0!0971S`%!H:6QI<'!I;F5S
M`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE;',`4&QA=&ET=61E<P!0;&5A
M<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M96YT.@!0;&5A<V4@8V]N9FER
M;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T:&ES(&5L96UE;G0N`%!L96%S
M92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N`%!L96%S92!E;G1E<B!A(&YA
M;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L96%S92!E;G1E<B!A('9A;&ED
M($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H96-K
M('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N`%!L96%S92!E;G1E
M<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V:61E(&$@<W5M;6%R>2!O9B!T
M:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M92!A;F0@
M<&%S<W=O<F0`4&QE87-E(')E860@=&AE(&9O;&QO=VEN9R!T97AT+B!9;W4@
M35535"!A9W)E92!W:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`
M4&QE87-E('1Y<&4@=&AE(&YE=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L
M:71I8W,`4&]L;',`4&]R='5G86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G
M90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD
M97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L
M87-T("5S(&AO=7(H<RDZ(`!0<F5C:7!I=&%T:6]N/&)R("\^8VAA;F-E`%!R
M969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V96PZ(`!0<F5S
M<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@82!N97<@=VEN
M9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+
M97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP
M="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC
M($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E
M9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%!U<F=E(&UE<W-A9V5S`%%A
M=&%R`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO
M('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO
M=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE
M`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4
M:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E
M('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T
M(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:`!2
M969R97-H($1Y;F%M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@
M5FEE=SH`4F5G97@`4F5L871I;VYS:&EP($)R;W=S97(`4F5L;V%D`%)E;6%R
M:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M
M<&QE+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O
M;'5M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V
M960@<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M4F5M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT
M`%)E;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T
M(&)E(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U97-T960@
M<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U;F0N`%)E<75I<F5D("(E<R(@;F]T
M('-P96-I9FEE9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B
M(&YO="!S<&5C:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D
M("(E<R(@;F]T('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"!&:65L9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W
M;W)D`%)E<W1O<F4@3&%S="!1=65R>0!297-U;'1S`%)E='5R;B!T;R!/<'1I
M;VYS`%)E='EP92!N97<@<&%S<W=O<F0`4F5U;FEO;@!2979E<G0@0V]N9FEG
M=7)A=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H
M=`!2:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN
M+@!2;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@
M4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L
M97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA
M;B!&961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N
M871U<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE
M;&P`4U%,('-T871E;65N="!F;W(@=F%L=64@;&]O:W5P<P!34T@`4U5#0T53
M4P!37U%,(%-H96QL`%-A`%-A:6YT($AE;&5N80!386EN="!+:71T<R!A;F0@
M3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;@!3
M86EN="!6:6YC96YT(&%N9"!T:&4@1W)E;F%D:6YE<P!386UE(&9R86UE("A?
M<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@5&]M92!A;F0@4')I;F-I<&4`
M4V%T96QL:71E(%!R;W9I9&5R`%-A=61I($%R86)I80!3879E`%-A=F4@(B5S
M(@!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-A=F5D
M('-E='5P('5P9W)A9&4@<V-R:7!T('1O.B`B)7,B+@!38V%T=&5R960@5"U3
M=&]R;7,`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T($9I
M;&5S`%-E;&5C="!A(&1A=&4`4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C
M="!A(&YE=R!O=VYE<@!396QE8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T
M;R!A9&0`4V5L96-T(&%L;`!396QE8W0@86QL(&1A=&4@8V]M<&]N96YT<RX`
M4V5L96-T(&%N(&]B:F5C=`!396QE8W0@;F]N90!396QE8W0@=&AE(&-H87)A
M8W1E<G,@>6]U(&YE960@9G)O;2!T:&4@8F]X97,@8F5L;W<N(%EO=2!C86X@
M=&AE;B!C;W!Y(&%N9"!P87-T92!T:&5M(&9R;VT@=&AE('1E>'0@87)E82X`
M4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O
M<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N9V4Z
M`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM92!F
M;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@>6]U
M<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G
M93H`4V5N9"!0<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O
M<CH@`%-E<'1E;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU
M;6)E<@!397)V97(@9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+@!397-S
M:6]N($%D;6EN`%-E<W-I;VX@240@97AP:7)E9"X`4V5S<VEO;G,`4V5T`%-E
M="!O<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D
M(&EF('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S
M('1H870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E
M="!Y;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@
M;W!T:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@
M<V-H96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P
M=&EO;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`
M4V5V97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R
M.B``4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A
M8V-E<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H
M;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H
M92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO
M9VEN('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P
M(&]R:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M
M96YU(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T
M:&4@5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L
M92!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R
M=&EE<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`
M4VAO=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T
M90!3:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO
M=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T
M`%-I97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG
M;W)I=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K
M:6$`4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO
M=R!3:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z
M(`!3;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`
M4V]M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O
M=7)C92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/
M+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H
M($ES;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D
M:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R
M(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3
M<&%I;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`
M4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD
M87)D`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T
M871U<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O
M=6=H`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S
M`%-T>6QE(%M#4U-=`%-U`%-U8F1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`
M4W5B:F5C=`!3=6)M:70`4W5B;6ET=&5D(')E<75E<W0@=&\@861D("(E<R(@
M=&\@=&AE('-Y<W1E;2X@66]U(&-A;B!N;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O
M<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE
M`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E
M<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI
M<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S
M:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP
M97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE
M<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E
M;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI
M9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y
M;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES
M(&YO="!A=F%I;&%B;&4N`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE
M9"X`5&AE($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO
M="!S=7!P;W)T("(E<R(`5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET
M:6%L:7IE9"X`5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D
M('-U8V-E<W-F=6QL>0!4:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@
M17AI=&EN9RX`5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E
M(&$@<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@
M=&\@=7-E(%!E<FUI<W-I;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@
M8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA
M;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT
M86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O
M;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I
M<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB
M=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@
M8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R
M:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO
M;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F
M:6QE(&-A;B!N;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C
M;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E
M<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@
M<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!)
M;G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E
M('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R
M:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO
M;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y
M<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G
M;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@
M=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P
M<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R
M965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E
M9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H
M92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P
M.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S
M=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U
M87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD
M97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@
M8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M
M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@
M2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S
M(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E
M9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D
M('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N
M('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@
M<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N
M;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S
M="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E
M9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D
M+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@
M<W!E8VEF:65D(')O=R!D;V5S(&YO="!E>&ES="X`5&AE('1E;7!O<F%R>2!F
M:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N`%1H92!T97AT('EO=2!E;G1E<F5D
M(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@;VX@=&AE('-C<F5E;BX`5&AE('1O
M<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE
M('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T
M97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE
M('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H96UE<R!D
M:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%1H97)E(&%R92!N;R!O<'1I;VYS
M(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I
M<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S
M(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R
M<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P
M<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H92!S>7-T96TZ("5S`%1H97)E('=A
M<R!A('!R;V)L96T@8VQE87)I;F<@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@
M=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@<F5M;W9I;F<@(B5S
M(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M('5P9&%T
M:6YG("(E<R(Z("5S`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL
M92!U<&QO860Z($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O
M8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@
M=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE
M<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S
M('=A<R!O;FQY('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N
M(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@
M86X@97)R;W(@:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@
M=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA
M<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A
M;B!E<G)O<B!P97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K
M(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@
M86X@97)R;W(@=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E
M('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG
M('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@
M9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R
M87(@87)C:&EV92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI
M9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@
M8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T
M96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I
M=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE(%=)
M3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]O(&UA;GD@:6YV86QI9"!L;V=I
M;G,@9'5R:6YG('1H92!L87-T(&UI;G5T97,N`%1O<`!4;W`@9G)A;64@*%]T
M;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A9"!A;F0@5&]B86=O`%1R=64@;W(@
M9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`5'5R:VES:"`H25-/+3@X-3DM.2D`
M5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#86EC;W,@27-L86YD<P!4=79A;'4`
M5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@:6YD97@Z(`!54DP`55),(&9O<B!Y
M;W5R('-C<FEP="!D96QI=F5R>2!S=&%T=7,@<F5P;W)T`%523#H`56=A;F1A
M`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B
M;&4@=&\@861D(&5X=')A('5S97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG
M('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C
M:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`56YA8FQE('1O(&-H96-K(&9I;&4@
M<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R
M=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O
M<'D@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B
M)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&9O;&1E
M<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@9&5L971E("(E<R(L
M('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B;&4@=&\@9&5L971E
M("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y
M(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GD@
M<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F
M:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE
M('1O(&1E;&5T92!61E,@<F5C=7)S:79E;'DZ("5S+@!5;F%B;&4@=&\@9&5T
M97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@97AT<F%C="!C
M97)T:69I8V%T92!D971A:6QS`%5N86)L92!T;R!L;V%D('1H92!D969I;FET
M:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V92!61E,@9FEL92X`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M9F]R('=R:71I;F<N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI=F4N`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AG971&:6QE4VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D
M(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN
M`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E
M<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O
M<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI
M<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B
M+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5
M;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`
M56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T
M960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP
M96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O
M9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O
M;0!5;FET960@4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@
M27-L86YD<P!5;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-
M97-S86=E($E$*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@
M240I+@!5;FMN;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N
M86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5
M;FYA;65D`%5N<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T
M+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S
M;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z
M:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP
M="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P
M;W)T960@17AT96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`
M57!D871E9"`B)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`
M57!L;V%D960@86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S
M97)V97(N`%5P<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R
M<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE
M+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M`%5S97(@86-C;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S
M(B!A;')E861Y(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@
M:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@
M;F]T(&5X:7-T+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC
M;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A
M;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`
M5F%L=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU
M96QA`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA
M=F4@8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O
M;`!697)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!6
M97)Y($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S
M`%9I97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@
M27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL
M:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).
M`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!7
M24X@=FEA($A45%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T
M:&5R($9O<F5C87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R
M+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E
M<P!796QC;VUE+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)
M4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S
M:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R
M/P!7:&5R96ES($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L
M=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED
M=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N
M('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T
M:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I
M;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES
M9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O
M;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@
M9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D
M+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!6
M1E,@9FEL92X`6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV
M,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I
M=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@
M97AT96YS:6]N<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE
M<P!997,L($D@06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE
M(%L\/ET@8G5T=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A
M<F4@;F]T(&%L;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N
M`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86X@;F]T(&AA=F4@
M=&AE("=<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@
M;F]T(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RX`66]U(&1I9&XG="!M
M87`@86YY(&9I96QD<R!F<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C
M;W)R97-P;VYD:6YG(&9I96QD<R!I;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G
M960@;W5T+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED(&-E;&QP:&]N92!N
M=6UB97(L(&1I9VET<R!O;FQY('=I=&@@86X@;W!T:6]N86P@)RLG(&9O<B!T
M:&4@:6YT97)N871I;VYA;"!D:6%L:6YG('!R969I>"X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!V86QU92X`66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T
M851R964@8F%C:V5N9"!T;R!U<V4@4VEG;G5P<RX`66]U(&UU<W0@8V]N9FEG
M=7)E(&$@5D93(&)A8VME;F0N`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B
M;&5M(&)E9F]R92!Y;W4@8V%N('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9
M;W4@;75S="!E;G1E<B!T:&4@55),('=H97)E('1H:7,@;&EN:R!P;VEN=',@
M=&\`66]U(&UU<W0@<V5L96-T(&%N('-E<G9E<B!T;R!B92!D96QE=&5D+@!9
M;W4@;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+@!9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@<F5M;W9E+@!9;W4@;75S="!S
M<&5C:69Y('1H92!U<V5R;F%M92!T;R!A9&0N`%EO=2!M=7-T('-P96-I9GD@
M=&AE('5S97)N86UE('1O('5P9&%T92X`66]U(&UU<W0@<W!E8VEF>2!W:&%T
M(&%C=&EO;B!T;R!P97)F;W)M+@!9;W4@;75S="!T>7!E(&$@;F5W(&-A=&5G
M;W)Y(&YA;64N`%EO=2!N965D('1O('!R;W9I9&4@86X@271A;&EA;B!P:&]N
M92!N=6UB97(`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@
M;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D
M9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E<FYE="!!9&1R97-S
M(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S
M97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO
M9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT:6-A=&EO;B!B86-K
M96YD(&1O97,@;F]T('-U<'!O<G0@861D:6YG('5S97)S+B!)9B!Y;W4@=VES
M:"!T;R!U<V4@2&]R9&4@=&\@861M:6YI<W1E<B!U<V5R(&%C8V]U;G1S+"!Y
M;W4@;75S="!U<V4@82!D:69F97)E;G0@875T:&5N=&EC871I;VX@8F%C:V5N
M9"X`66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O
M<G0@;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES
M86)L960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P
M96%R<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y
M;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U
M(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K
M(%`@=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F
M875L="!I9&5N=&ET>2!H87,@8F5E;B!C:&%N9V5D+@!9;W5R(&1E9F%U;'0@
M:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&QO9VEN(&AA<R!E>'!I
M<F5D+@!9;W5R(&YE=R!P87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H
M:7,@<V5S<VEO;BX`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S
M(&)E96X@<F5S970L(&-H96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H
M('EO=7(@;F5W('!A<W-W;W)D+@!9;W5R('!A<W-W;W)D(&AA<R!E>'!I<F5D
M+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA;6)I
M80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L96T@
M4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!497AT
M("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I;VX`
M7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?26UA
M9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@3&EN
M:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN`%]3
M971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B;V]K
M`&%D9')E<W-E92!U;FMN;W=N`&-A;&5N9&%R`&-A;&T`8V%N;F]T(&-R96%T
M92!O=71P=70@9FEL90!C86YN;W0@;W!E;B!I;G!U=`!C;&EC:R!H97)E`&-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`
M961I=`!E;G1R>2!N;W0@9F]U;F0`9F%L;&EN9P!F:6QE`&9R;VT@=&AE("5S
M("@E<RD@870@)7,@)7,`9W5S=&EN9P!H.@!H:`!H;W-T(&YA;64@=6YK;F]W
M;@!I;6UE9&EA=&4`:6YL:6YE`&EN<'5T+V]U='!U="!E<G)O<@!I;G1E<FYA
M;"!S;V9T=V%R92!E<G)O<@!L:6YE<UT`;6MI<V]F<R!E<G)O<B!C;V1E("5D
M('=H:6QE(&UA:VEN9R!)4T\N`&UM`&YA;64`;F]T(&EM<&QE;65N=&5D`&YO
M="!Y970@:6UP;&5M96YT960`;F]T97!A9`!P97)C96YT`'!E<FUI<W-I;VX@
M9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C;VP`<FES:6YG
M`'-E<G9I8V4@=6YA=F%I;&%B;&4`<VAO=R!D:69F97)E;F-E<P!S;7,R96UA
M:6P@=FEA($A45%``<W,`<W1E861Y`'-W:71C:"!O9F8@:F%V87-C<FEP=`!S
M>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1R>2!A
M9V%I;@!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I
M960`=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0
M<F]J96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2UC=G,*4F5P;W)T+4US9VED
M+4)U9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A
M=&4Z(#(P,#4M,3`M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R
M,#`V+3`S+3,P(#$V.C$Q*S`S,#`*3&%S="U4<F%N<VQA=&]R.B!4;V]M87,@
M06%S(#QT;V]M87,N86%S0&UA:6PN964^"DQA;F=U86=E+51E86TZ($5S=&]N
M:6%N(#QD979`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#
M;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]25-/+3@X-3DM,3,*
M0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9SH@.&)I=`H`("@E<R!PY&5V82!T
M86=A<VDI`"`H2VEI<FML86AV("5S*0`@*"5S('#D979A('#D<F%S="D`("AT
MY&YA*0`@*&AO;6UE*0`@*&5I;&4I`"!K:6ER=7-E9V$@`"(E<R(@96D@;VQE
M(&MA=&%L;V]G+@`B)7,B(&5I(&]L92!V]6EM86QI:R!V86QI:RX`(B5S(B!E
M:2!O;&4@2&]R9&4@<F5G:7-T<FES(&CDY&QE<W1A='5D+@`B)7,B('!U=2!E
M<VET86IA="!E:2!L96ET=60N`"(E<R(@;&ES871I(&=R=7!P:61E('/\<W1E
M96UI+@`B)7,B(&QI<V%T:2#U:6=U<W1E('/\<W1E96UI+@`B)7,B(&5I(&QO
M;V1U9#H@)7,N`"4N,F9-0B!K87-U=&%T=60@:V]K:W4@)2XR9DU"+7-T("@E
M+C)F)24I`"5D("5S(&IA("5S`%-I;G4@<&%R;V]L(&%E9W5B("5D('#D979A
M('#D<F%S="X`)60@<.1E=F$@96YN=7-T=7,`)7,@+2!4Y&AE;&5P86YU`"5S
M('/U<FUE:N1L9P`E<R!+0@`E<R!H;V]L9'5S=/;V9"`M(&MI;FYI='5S`"5S
M('!A:6=A;&1U<P`E<R!K;VYT;R!T86]T;&5M:6YE`"5S(&MA<W5T=7-T:6YG
M:6UU<V5D`"5S(&]N(&IU8F$@;VQE;6%S+@`E<R!K:6ER=7-E9V$@)7,@)7,`
M)7,@;VX@=F%L;6ES('1E9V5M82!A;&QP;V]L(&QO971L971U9"!H;V]L9'5S
M=/;V9"X@3>1R9VES=&$@=/;V9"P@;6ED82!S;V]V:60@<')A96=U('1E:&$N
M`"5S(&]N(&MO:'5S='5S;&EK`"5S(&UI;G5T:70`)7,@96D@;&5I='5D+@`E
M<R!K=6YI("5S("5S+7-T`$MA<W5T86IA("5S(&%A9')E<W-I<F%A;6%T`$MA
M<W5T86IA("5S(&MA;&5N9&5R`$MA<W5T86IA("5S(&WD<FMM960`2V%S=71A
M:F$@)7,@_&QE<V%N9&5D`"5S.B`E<P`E<SH@4V5E('1E861E(&5I('!R=75G
M:2!O;&QA('-A871J86QT+"!K96QL96QT('-E92!P86ES=&%B(&]L979A="X@
MQ')A(&MI:7)U<W1A(&ML]7!S86UA('-E;&QE<R!E<VEN979A:60@;&EN:V4@
M=O5I(&5S:71A;6$@<V%A=&IA;&4@;6EN9VET:7-I:VQI:VMU(&EN9F]T+@`L
M('1U=6QE:6EL:60@`"P@='5U;&5I:6QI9"`E<R`E<P`L('9A:&5M:6MU<R`E
M<R!K=6YI("5S`"TM('9A;&D@+2T`,3(M='5N;FEN92!E<VET=7,`,C0M='5N
M;FEN92!E<VET=7,`,C0@='5N9&D`/$5E;&UI;F4`4V5E(&)L;VMK('9A:F%B
M(&%N9&UE8F%A<VD@='5G92X`2G5H='5S(&MO:'5T878@=FEG80!+:7)J82!K
M<OQP=&5E<FEM:7-E:W,@;VX@=F%J82!A=F%L:6MK=2!01U`@=O5T:70N`$%L
M;&MI<FIA(&MO;G1R;VQL:6UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%!'4"!V
M]71I="X`2W+\<'1E97)I='5D(&MI<FIA(&%V86UI<V5K<R!O;B!V86IA(&%V
M86QI:VMU(%!'4"!V]71I="P@<V%L86IA<W0@4$=0(';U=&ET(&IA('-A;&%S
M]6YA+@!+:7)J82!A;&QK:7)J87-T86UI<V5K<R!O;B!V86IA(&%V86QI:VMU
M(%!'4"!V]71I="P@<V%L86IA<W0@4$=0(';U=&ET(&IA('-A;&%S]6YA+@!+
M<OQP=&5E<FET=60@:VER:F$@879A;6ES96MS(&]N('9A:F$@879A;&EK:W4@
M4R]-24U%(';U=&ET+"!S86QA:F%S="!3+TU)344@=O5T:70@:F$@<V%L87/U
M;F$N`$MI<FIA(&%L;&MI<FIA<W1A;6ES96MS(&]N('9A:F$@879A;&EK:W4@
M4R]-24U%(';U=&ET+"!S86QA:F%S="!3+TU)344@=O5T:70@:F$@<V%L87/U
M;F$N`$MI<FIA(&MR_'!T965R:6UI<V5K<R!O;B!V86IA(&%V86QI:VMU(%,O
M34E-12!V]71I=`!%3"!P:6QV:6YE`$5,(&ME<F=E('9I:&T`14P@=FEH;0!%
M3"!H;V]V:6AM`$5,('1U9V5V(&QU;65S861U`$5,+U!,`$%022!)1`!396QL
M92!E9&ET;W)I(&EN9F\`26YF;RXN+@!!8G-B;W1T;VT`06)S;6ED9&QE`%9&
M4R!K871A;&]O9VD@;&]O;6ES96MS(&IU=7)D97#DY',@:V5E;&%T=60`5D93
M(&9A:6QI(&QO;VUI<V5K<R!J=75R9&5PY.1S(&ME96QA='5D+@!+;VYT;R!I
M;F9O`$MO;G1O('-A;&%S]6YA`$MO;G1O(&QU:W5S=&%T=60N`%)A86UA='5P
M:61A;6EN90!,:7-A`$QI<V$@86QA;6=R=7!P`$QI<V$@86QA;?5I9W5S`$QI
M<V$@<VEI83H`3&ES82!U=7,@9W)U<'``3&ES82!U=7,@]6EG=7,`3&ES82!G
M<G5P<"`B)7,B(&%L;&$`3&ES82#U:6=U<R`B)7,B(&%L;&$`3&ES82!U=7,@
M:V%S=71A:F$Z`$QI<V$@=F5E<F<`3&ES82!U=65D(&QI:6MM960`3&ES82!P
M86%R`%1E92`E<R!M96[\_"!-;WII;&QA(&O\;&=R:6)A:W,`3&ES82!A861R
M97-S:7)A86UA='5S<V4Z`$QI<V$@;6EN=2!A861R97-S:7)A86UA='5S<V4`
M3&ES82!K87-U=&%J80`B)7,B(&QI<V%T:2!S_'-T965M:2P@:W5I9"!TY&EE
M;F1A=F%T(&QI:71U;6ES:6YF;W0@<&]L;G5D(';U:6UA;&EK(&QI<V%D83H@
M)7,N`"(E<R(@;&ES871I('/\<W1E96UI+B!._/QD(';U:60@<VES<V4@;&]G
M:61A+@!+87-U=&%J871E(&QI<V%M:6YE('!O;&4@;'5B871U9"X`06%D<F5S
M<P!!861R97-S:7)A86UA=`!(86QD=7,@+2!M=75D82!T96ES=&4@:V%S=71A
M:F%T92#U:6=U<VD`2&%L9'5S`%)E:VQA86T`069G86YI<W1A;@!!;&)A86YI
M80!!;'IE97)I80!!;&EA<P!*;V]N9'5S`$IO;VYD=7,Z`$OU:6L`2_5I:R!S
M:7-S96QO9VET=60@:V%S=71A:F%D`$OU:6L@9W)U<&ED`$OU:6L@]6EG=7-E
M9`!+]6EK(&YE;&D@:_QL9V4`3'5B82!M:71U="!A861R97-S:0!,=6)A(&WD
MY')A=&$@:N1R:F5S=&%T=60@;&]E;F1I('3\_'``3VX@:G5B82!O;&5M87,`
M06QT97)N871I:79N92!)35-0(&MO;G1O`$%L=&5R;F%T:6EV;F4@24U34"!S
M86QA<_5N80!!;'1E<FYA=&EI=FYE($E-4U`@:V%S=71A:F%N:6UI`$%L=&5R
M;F%T:6EV;F4@92UP;W-T:2!A861R97-S`$%L=&5R;F%T:6EV<V5D(&UA;&QI
M9`!!;'1E<FYA=&EI=FYE('1E:W-T.@!!;65E<FEK82!386UO80!3:7-E<W1A
M=&D@;'5B86UA='4@=N3D<G1U<RX`2G5H='5S('1U;F1M871U('9I9V$`06YD
M;W)R80!!;F=O;VQA`$%N9W5I;&QA`$%N;V[\_&UN92!V86AE;F1A:F$`5F%S
M='5S`$%N=&%R:W1I:V$`06YT:6=U82!J82!"87)B=61A`%)A:V5N9'5S`%)A
M:V5N9'5S=&4@;FEM96MI<FD`4F%K96YD=7,@;VX@=/;V=F%L;6ES+@!286ME
M;F1A(&%L86UJ86=U9&5L90!+:6YN:71A`$QI9VEK875D;F4@<W5U<G5S`$%P
M<FEL;`!!<F%A8FEA("A7:6YD;W=S+3$R-38I`$%R:&EI=FD@<W5U<G5S`$%R
M:&EI=FD@;FEM:0!/;&5D('-A(&MI;F1E;"!E="!S;V]V:60@)7,@;&EI='5M
M:7-S;V]V:2!K=7-T=71A9&$_`$]L960@<V$@:VEN9&5L(&5T('-O;W9I9"!K
M=7-T=71A9&$@9W)U<&D@(B5S(B!J82!K]6EK('1E;6$@86QA;6=R=7!I9#\`
M07)G96YT:6EN80!!<FUE96YI80!!<FUE96YI82`H05)-4T-)22TX*0!+=6YS
M=`!!<G5B80!,:6AA=O5T=&5S86%R`$%30TE)(&IO;VYI<W1U<P!!87-I82]6
M86EK<V4@;V]K96%N:2!P:6ER:V]N9`!+_'-I(&AO;VQD=7-T]O9D92!T96=E
M;6ES96MS(&MI;FYI='5S=`!6965R=60`2V%T<V4@:W5S='5T861A(&]L96UA
M='5T(&=R=7!P:2X`2V%T<V4@:W5S='5T861A(&]L96UA='5T(/5I9W5S="X`
M2V%T<V4@;75U=&$@;VQE;6%T=70@]6EG=7-T+@!+871S92!M=75T82!O;&5M
M871U="!J86=U+@!!=')I8G5U9&ED`$%U9W5S=`!!=7-T<F%A;&EA`$%U<W1R
M:6$`075T:%]C>7)S<6PZ('9A:F%L:6MK=2!)34%0(&QA:65N9'5S="!E:2!L
M96ET=60N`$%U=&A?8WER=7,Z('/\<W1E96UI;"!P=75D=79A9"!V86IA;&EK
M=60@=O5I;65D+@!!=71H7V-Y<G5S.B!V86IA;&EK:W4@24U!4"!L86EE;F1U
M<W0@96D@;&5I='5D+@!!=71H7V9T<#H@5F%J86QI:VMU($944"!L86EE;F1U
M<W0@96D@;&5I='5D+B!+;VUP:6QE97)I(%!(4"!V]71M96=A("TM96YA8FQE
M+69T<"X`075T:%]I;6%P.B!686IA;&EK:W4@24U!4"!L86EE;F1U<W0@96D@
M;&5I='5D+@!!=71H7VMR8C4Z(%9A:F%L:6MK=2!K<F(U(&QA:65N9'5S="!E
M:2!L96ET=60N`$%U=&A?;&1A<#H@06-T:79E($1I<F5C=&]R>2=S<V4@:V%S
M=71A:F%T92!L:7-A;6ES92!T=6=I('!U=61U8@!!=71H7VQD87`Z($%C=&EV
M92!$:7)E8W1O<GES="!K87-U=&%J871E(&5E;6%L9&%M:7-E('1U9VD@<'5U
M9'5B`$%U=&A?;&1A<#H@5F%J86QI:VMU($Q$05`@;&%I96YD=7-T(&5I(&QE
M:71U9"X`075T:%]L9&%P.B!%:2!S86$@;&ES861A(&MA<W5T86IA="`E<RX@
M4V5R=F5R(/QT;&5S.B``075T:%]L9&%P.B!%:2!S86$@965M86QD861A(&MA
M<W5T86IA="`E<P!!=71H7VQD87`Z($5I('-A82!M=75T82!K87-U=&%J870@
M)7,`075T:%]L9&%P.B!!8W1I=F4@1&ER96-T;W)Y(&MA<W5T86IA=&4@;75U
M=&UI<V4@='5G:2!P=75D=6(N`$%U=&A?;6-A;#H@5F%J86QI:VMU($U#04P@
M;&%I96YD=7-T(&5I(&QE:71U9"X`075T:%]S;6)A=71H.B!686IA;&EK:W4@
M<VUB875T:"!L86EE;F1U<W0@96D@;&5I='5D+@!3:7-S96QO9VEM:6YE(&YU
M<FIU<P!3:7-S96QO9VEM:6YE(&YU<FIU<RX@)7,`4D%$2553('-E<G9E<B!E
M:2!L=6)A;G5D('-I<W-E(&QO9VED82X`1E10('-E<G9E<FES<V4@<VES<V5L
M;V=I;6EN92!N=7)J=7,N`%--0B!S97)V97)I<W-E('-I<W-E;&]G:6UI;F4@
M;G5R:G5S+@!+87-U=&%T879A9"!VY&QJ860Z`$%S97)B86ED>F%A;@!"3T9(
M(&5T=&5KY.1N9&5D`%1A=7-T`%1A=7-T82!VY')V`%9A;&4@:V5R8F5R;W-E
M('-A;&%S]6YA+@!686QE(&ME<F)E<F]S92!K87-U=&%J86YI;6DN`$)A:&%M
M80!"86AR96EN`$)A;'1I("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S:`!"87)B
M861O<P!'<F%A9FEK82!P]6AI:V%T86QO;V=I("(E<R(@96D@;&5I='5D+@!"
M87-E;&EN90!686QG979E;F4`0F5L9VEA`$)E;&EZ90!"96YI;@!"97)M=61A
M`$)H=71A;@!3_&YN:7#D978`0FQO:VMI("(E<R(@<F%K96YD=7-E<R`B)7,B
M(&5I(&QE:71U9"X`0FQO:VD@:.3D;&5S='5S`$)L;VMI('3\_'``4&%K<R!K
M:7)I`$)O;&EI=FEA`$KD<FIE:&]I9&IA9`!0:6ER:F]O;@!*;V]N92!P86MS
M=7,Z`%!I:7)J;V]N960`0F]S;FEA(&IA($AE<G1S96=O=FEI;F$`3?5L96UA
M9`!";W1S=V%N80!!;&QA`$)O=79E="!S86%R`$)R87-I:6QI80!"<FET:2!)
M;F1I82!/;VME86YI(%1E<G)I=&]O<FEU;0!"<G5N96D@4W5L=&%N:7)I:6L`
M0G5L9V%A<FEA`$QO971E;'4`0G5R:VEN82!&87-O`$)U<G5N9&D`4VES=6AA
M;&1U<P!#4D,`5/QH:7-T=7-N:6UE:VER:F$@:F%O='5S<'5N:W1I9`!,7V%H
M=')I(&]M861U<V5D+BXN`%9A:&5MY&QU(&EN:71S:6%L:7-E97)I;6EN92!E
M:2!J]75D;G5D(&SU<'5L92X`2V%L96YD97(`5F%I:VYE`$MA;6)O9'IH80!+
M86UE<G5N`%!A<F]O;&D@96D@<V%A(&%U=&]M86%T<V5L="!T_&AI<W1A9&$L
M(';U=&$@_&AE;F1U<W0@861M:6YI<W1R86%T;W)I9V$N`$5I(/5N;F5S='4@
M:VER:G5T861A(&9A:6QI("(E<R(`5N1L:7-E:60@<V5S<VEO;VYI:&%L9'5R
M96ED('!O;&4@=O5I;6%L:6L@861M:6YI<W1R965R:61A+@!%:2!S86$@_&AE
M;F1U<W0@24U!4"!S97)V97)I9V$Z("5S`$5I(/5N;F5S='4@879A9&$@9F%I
M;&D@(B5S(@!+86YA9&$`3&]O8G4`3&]O8G4`16D@]6YN97-T=2!K=7-T=71A
M9&$@9F%I;&D@(B5S(BX`16D@;&5I82!A:G5T:7-T(&MA=&%L;V]G:0!);&UA
M("=T87)G971&:6QE)R!P87)A;65E=')I=&$@96D@<V%A(&KD=&MA=&$N`$5I
M(/5N;F5S='4@965M86QD861A(&MA=&%L;V]G:2`B)7,B+@!%:2!S86$@965M
M86QD861A+"`E9"UL(&]N(&%L;'5V86ED+@!%:2!S86$@_&UB97(@:N1R:F5S
M=&%D82P@_&UB97)JY')J97-T86UI<V5K<R!MY.1R871U9"!K86YN971E(&%R
M=B!E:2!K;&%P:2!S86QV97-T871U9"!A<G9U9V$N`$5I('-A82!S=75N871A
M('1E861E="!MY.1R871U9"!N=6UB<FEL92X`4F]H96QI<V4@3F5E;64@<V%A
M<F5D`%!E86QK:7)I`%1E96YU<V5P86MK=6IA`$MA=&5G;V]R:6%D(&IA(&WD
M<F=E;F1I9`!#87EM86YI(%-A87)E9`!-;V)I:6QT96QE9F]N`$QA:'1R:2!O
M;6%D=7-E9`!,86AT<FD@=F]O9&5R9'5S.@!,86AT<FD@;VUA9'5S960`3&%H
M=')I=&4@=F%H96MA=6=U<SH`36]B:6EL=&5L969O;@!+96QT:2`H25-/+3@X
M-3DM,30I`$ME<VME;&4`2V5S:RU!869R:6MA(%9A8F%R:6EK`$ME<VLM175R
M;V]P82`H25-/+3@X-3DM,BD`4V5R=&EF:6MA861I(/QK<VEK87-J860`4V5R
M=&EF:6MA861I(&]M86YI:P!397)T:69I:V%A9&D@<&]L:6ET:6MA9`!4<VAA
M860`375U9&$`375U9&$@<V%L87/U;F$`375U9&$@;FEM92!J82!A861R97-S
M:2!M:61A(&EN:6UE<V5D(&[D979A9"!K=6D@;F%D('-I;G4@:VER:G4@;&]E
M=F%D(&IA(&YE:6QE('9A<W1A=F%D+@!3_'-T965M:2!K;VYF:6=U<F%T<VEO
M;VX@96D@=O5I;6%L9&$@<V%L87/U;F$@;75U=&$N(%;U=&$@_&AE;F1U<W0@
M(&%D;6EN:7-T<F%A=&]R:6=A+@!-Y')K`%]+;VYT<F]L;&D@;&EN:VDN+BX`
M5'-H:6EL:0!(:6EN80!(:6EN82!L:6AT<W5S=&%T=60@*$=",C,Q,BD`2&EI
M;F$@=')A9&ET<VEO;VYI;&EN92`H0FEG-2D`5F%L:2!R86ME;F1U<SH`5F%L
M:2!S86QA<_5N80!686QI(&MA<W5T86IA;FEM:0!686QI(&MU=7#D979A9&4@
M97-I='5S=FEI<SH`5F%L:2!L;V5N9&D@<W1I:6P@*&KD<FIE<W1A='5D(&QO
M96YD:71E(&IA;VMS*0!*]75L=7-A87)E9`!+;&%S<VD@)7,@:VER:F5L9'5S
M="!E:2!L96ET=60N`%-E;&=E`$5E;6%L9&$@35-/9F9I8V4@;>1R9V5N9&ED
M`%3\:&IE;F1A('#D<FEN9P!%96UA;&1A(&MA<W5T86IA.B`E<P!%96UA;&1A
M(&MA<W5T86IA`%3\:&IE;F1A(&MA<W5T86IA(&%N9&UE9`#5:'1U;"!S96QG
M:6YE8@!+;/5P<V$@:N1T:V%M:7-E:W,`0VQI8VMA=&5L;"#\;&4@2%144`!3
M=6QE(&%K96X`4&EL=F5D`$AO;6UI:W5L('!I;'9E<P!0:6QV97,`2V]O:V]S
M<V%A<F5D("A+965L:6YG:2!S86%R960I`%!E:61A(&O\;&=R:6)A`%!E:61E
M='5D('!I:7)J;V]N960`2V]L=6UB:6$`5N1R=@!6Y')V:79A;&EK`%;D<G9I
M('9A;&EK`%9E97)G93H`5F5E<F=U9&4@<&5A;&MI<FIA9`!+;V]M:6MS:60`
M2^1S:P!+Y'-U<FED80!+;VUM96YT86%R`$QI:'1N:6UI`$MO;6]O<FED`$9I
M<FUA`$%R=G5T:60`26QM`$EL;0!+;VYF:6=U<F%T<VEO;VYI(&5R:6YE=G5S
M960`4V5A9&ES='5S('/\;FMR;VYI<V5E<FEM:7-E:W,@4$1!9&4L(&YU=&ET
M96QE9F]N:61E(&IA($]U=&QO;VMI9V$N`%-E861I<W1U<R!O;B!A96=U;G5D
M+@!396%D:7-T82`E<P!+:6YN:71A('-A;&%S]6YA`$MO;F=O`$MO;F=O($1E
M;6]K<F%A=&QI:R!686)A<FEI:P#<:&5N9'5S(&YU<FIU<RX`W&AE;F1U<R!N
M=7)J=7,Z(`!!=F%L:6L@=O5T;65S97)V97(@96D@86YN82#\:&5N9'5S="X`
M079A;&EK(';U=&UE<V5R=F5R(&5I(&%N;F$@_&AE;F1U<W0N(%#U:&IU<SH@
M)7,@*"5S*0#<:&5N9'5S($944"!S97)V97)I9V$@;G5R:G5S+@!+;VYT86MT
M:60`2V]N=&%K=&ED(/5N;F5S='5S(&QI<V%D82!S:6YU(&%A9')E<W-I<F%A
M;6%T=7-S92X`(B5S(B!S:7-U`$KD=&MA`$-O;VMI(%-A87)E9`!-]71T971E
M<F$`2V]P965R:0!+;W!E97)I;6EN92!N=7)J=7,Z("5S`$MO<&5E<FD@=F%L
M:6L`0V]S="!)1`!+;W-T87)I:6MA`$-O=&4@9"=)=F]I<F4`16D@<V%A;G5D
M(&MI<FIA(%!'4&=A(&MR_'!T:61A+@!%:2!S86%N=60@:VER:F$@4$=09V$@
M86QL:VER:F%S=&%D82X`16D@<V%A;G5D(&MI<FIA(%,O34E-16=A(&MR_'!T
M:61A+@!%:2!S86%N=60@:VER:F$@4R]-24U%9V$@86QL:VER:F%S=&%D82X`
M16D@<V%A;G5D(&QI<V%D82!K;VYT86MT:2X@)7,`16D@<V%A;G5D('-I<W-E
M($Q$05`@<V5R=F5R:7-S92X`16D@<V%A;G5D('-I<W-E($Q$05`@<V5R=F5R
M:7-S90!%:2!S86%N=60@:V]N=&]JY.1K:2!K;VYT<F]L;&ED82X@)7,`16D@
M<V%A;G5D(/QH96YD=7-T($Q$05`@<V5R=F5R:6=A+@!%:2!S86%N=60@<V5R
M=F5R:6=A("(E<R(@1E10(&%B:6P@_&AE;F1U<W0Z("5S`$IA;W1U<VYI;65K
M:7)J82!L;V]M:6YE(&YU<FIU<RX@)7,`16D@<V%A;G5D(%!'4"!A;F1M96ED
M(&1E:W+\<'1I9&$N`$5I('-A86YU9"!3+TU)344@86YD;65I9"!D96MR_'!T
M:61A+@!%:2!S86%N=60@:W5S='5T861A(&MO;G1A:W1I+B`E<P!%:2!S86%N
M=60@:W5S='5T861A(&IA;W1U<VYI;65K:7)J82X@)7,`16D@<V%A;G5D(&MU
M<W1U=&%D82!P86EG86QD=7-E('5U96YD86UI<V4@<VMR:7!T:2`B)7,B+@!%
M:2!S=75T;G5D(';D;&IA('-E;&=I=&%D82!A9')E<W-A861I(&4M<&]S=&D@
M86%D<F5S<P!+;V=U(&%A9')E<W-I<F%A;6%T=2!K;VAA;&5T:7)I;6EN92!N
M=7)J=7,N`$MO9W4@:F%O='5S;FEM96MI<FIA(&MO:&%L971I<FEM:6YE(&YU
M<FIU<RX`2V]G=2!J86]T=7-N:6UE:VER:F%D92!N:6UE:VER:F$@:V]H86QE
M=&ER:6UI;F4@;G5R:G5S+@!%:2#U;FYE<W1U;G5D(&QA861I9&$@<W1R871E
M96=I870@(B5S(BX`;6MD:7(@(B5S(B!N=7)J=7,N`$5I('-A86YU9"!V]71M
M97-E<G9E<FES="!A=F%L:6MK=2!V]71I="!KY'1T92X`(B5S(B!A=F%M:6YE
M(&MI<FIU=&%M:7-E:W,@;G5R:G5S+@`E<R!A=F%M:6YE(&YU<FIU<RX`16D@
M<W5U=&YU9"!KY&EV:71A9&$@:&]O;&1U<W3V]B!M;V]D=6QI="`E<P!%:2!S
M86%N=60@879A9&$@:V%T86QO;V=I("(E<R(N`$5I('-A86YU9"!KY'1T92!,
M1$%0('-E<G9E<FET+@`E<R!L=6=E;6EN92!N=7)J=7,N`%-O;W9I='5D(&MA
M<W5T86IA('!A<F]O;&D@=/QH:F5N9&%M:6YE(&YU<FIU<RX@3?5N960@86YD
M;65D(&5I(&]L92#U:6=E9"X@4')O;W9I('5U97-T:2!V]6D@=O5T82#\:&5N
M9'5S="!A9&UI;FES=')A871O<FEG82P@:W5I('9A:F%D('-I:7-K:2!A8FDN
M`$%#3&D@;&%A9&EM:6YE(&5B8?5N;F5S='5S`$%A9')E<W-I<F%A;6%T=2!L
M86%D:6UI;F4@96)A]6YN97-T=7,N("5S`$IA;W1U<VYI;65K:7)J82!L86%D
M:6UI;F4@96)A]6YN97-T=7,N("5S`$IA;W1U<VYI;65K:7)J861E(&QA861I
M;6EN92!E8F'U;FYE<W1U<RX@)7,`4V5R=F5R:2!V]6EM86QU<W1E(&QA861I
M;6EN92!E8F'U;FYE<W1U<P!+;VYF:6=U<F%T<VEO;VYI('1A9V%S:6UU=71M
M:6YE(&YU<FIU<RX`<FUD:7(@(B5S(B!E:2#U;FYE<W1U;G5D+@`E<R!S96%D
M:7-T=7-E('-A;'9E<W1A;6EN92!N=7)J=7,N`$MO;F9I9W5R871S:6]O;FD@
M=F%R=6MO;W!I82!S86QV97-T86UI;F4@;G5R:G5S+@!+;VYF:6=U<F%T<VEO
M;VYI('9A<G5K;V]P:6$@<V%L=F5S=&%M:6YE(&YU<FIU<SH@)7,`4&%I9V%L
M9'5S92!U=65N9&%M:7-E('-K<FEP=&D@96D@<V%A;G5D('-A;'9E<W1A9&$@
M:V]H=&$Z("(E<R(N`$5I(/5N;F5S='5N=60@<V%L=F5S=&%D82!K;VYF:6=U
M<F%T<VEO;VYI9F%I;&D@=F%R=6MO;W!I870@)7,N`$MO;F9I9W5R871S:6]O
M;FEF86EL:2`E<R!E:2#U;FYE<W1U;G5D('-A;'9E<W1A9&$N(%-A(';U:60@
M:V%S=71A9&$@_&AT(';U:6UA;'5S="!K;V]D:2!S86QV97-T86UI<V5K<R!T
M86=A<VD@9F%I;&D@)7,@=O5I(&MO<&5E<FED82!K;V]D(&OD<VET<VD@9F%I
M;&D@)7,N`$Q$05`@;W1S:6YG(&YU<FIU<RX`=6YL:6YK("(E<R(@;G5R:G5S
M+@!+;VYT86MT:2!U=65N9&%M:6YE(&YU<FIU<RX@)7,`2F%O='5S;FEM96MI
M<FIA('5U96YD86UI;F4@;G5R:G5S+B`E<P`B)7,B('-E861I<W1U<V4@<V%L
M=F5S=&%M:6YE(&YU<FIU<SH@)7,`16D@;&5I9&YU9"!-;WII;&QA(&O\;&=I
M<F)A+B!686%T82!E="!K_&QG<FEB82!O;&5K<R!A=F%T=60N`$MA<W5T86IA
M;&4@(B5S(B!E:2!S86%N=60@86YD82!JY')G;6ES:2#U:6=U<V5I9"!K875S
M=&%L92`B)7,B.B`E<P!0:6ER871U9"!P:6MK=7-E9V$@=&5K<W0`4FEI:P!+
M=7)S=7-E9`!,;V\`3&ES82!L:6YK`$QI<V$@=75S`$QI<V$@86QA;6MA=7-T
M860`075T;W)I(/5I9W5S960`2W)E9&EI=&MA87)D:2!N=6UB97(`2&]R=F%A
M=&EA`$MU=6)A`%!R865G=7-E9"`T(&9A87-I`$%K=&EI=G-E9"!S97-S:6]O
M;FED`$ME;&QA865G`%!R865G=6YE(%523"!O;@!!:W1I:79S960@:V%S=71A
M:F%D`%!R865G=6YE(&EL;0!0<F%E9W5N92!I;&TZ`%!R865G=6YE('-T:6EL
M`$CDY&QE<W1A('3V:60@;6ED82!T96AA:W-E('-I<V5N96UI<V5L("5S+6DN
M`$SU:6MA`$SU:6MA('9A;&EK`$O\<')O<P!+:7)I;&QI='-A("A+3TDX+5(I
M`$MI<FEL;&ET<V$@*%=I;F1O=W,M,3(U,2D`2VER:6QL:71S82]5:W)A:6YA
M("A+3TDX+54I`%1S96AH:2!686)A<FEI:P!04`!$4TX@*'9A871A(&AT='`Z
M+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N
M:6YT<F\M9'-N+G!H<"D`26=A('#D978`1&%T851R964@<VER=FEJ80!!;F1M
M96)A87-I;W1S:6YG`$MU=7#D978`4V%A8G5M:7-E(&MU=7#D978`2W5U<.1E
M=F$@=F%L:6L`4.1E=@!+=5]S='5T82!V965R9P!$971S96UB97(`2_QM;F5N
M9&YU;6)R:60`5N1H96YD82!T86%N9')I9&$`5F%I:VEM:7-I`%9A:6MI;6ES
M:2!VY')V`%9A:6ME:61E;G1I=&5E=`!686EK:6UI<VD@<VAE;&P`4_5N87-E
M;&5T=7-E9`!+=7-T=71A`$MU<W1U=&$@;&%H=&5R`$MU<W1U=&$@9W)U<'``
M2W5S='5T82!L;V=I`$MU<W1U=&$@]6EG=7,`2W5S='5T82!J82!E96UA;&1A
M(&MI<FIA9`!+=7-T=71A(&QA:'1E<@!+=7-T=71A('9E97)G`$MU<W1U=&$@
M;VQE;6%S;VQE=B!A;'1E<FYA=&EI=FYE(&UA;&P`2VER:F%D92!K=7-T=71A
M;6EN90!+=7-T=71A(/5I9W5S960@(B5S(BUL90!+=7-T=71A(/5I9W5S960@
M(B5S(BUL92!J82!K]6EK(&%L86WU:6=U<V5D/P!+=7-T=71A(')I9&$`2W5S
M='5T82!V86QI='5D(&ED96YT:71E970`2W5S='5T82!A:W1I:79N92!V965R
M9P!+=7-T=71A(&%K=&EI=FYE(')I9&$`2W5S='5T87-I;B!P86EG86QD=7-E
M('5U96YD86UI<V4@<VMR:7!T:2`B)7,B+@!+Y'1T971O:6UE=&%M:7-E(&%E
M9P!486%N:0!+:7)J96QD82!P<F]B;&5E;6D`2VER:F5L9'5S`-QK<VEK87-J
M860@*&MA;G1U9"!K82!(;W)D92!L;V=I9F%I;&DI.@#<:W-I:V%S:F%D(&QO
M9VET:2!A9&UI;FES=')A871O<FD@:F%O:W,N`$%R96YD=7,`2V%S=&5P=6YK
M=`!%96QM:7-E('1U;FYI(&MA<W1E<'5N:W0`2V%S=&5P=6YK=#H`4W5U;F0@
M=F%S86MU;'0@<&%R96UA;&4`4W5U;F0@<&%R96UA;'0@=F%S86MU;&4`2V%T
M86QO;V<`17-I=&$@:V5L;&%A:F%D(#(T+71U;FYI<V5N80!%:W)A86YI('-E
M861E9`!.Y&ET82!P]6AJ86QI:VMU(&5N;G5S='5S=`!.Y&ET82!E;FYU<W1U
M<W0@*%1!1BD`16MR86%N:2!S96%D960`1&ES<&]S:71I;VX@3F]T:69I8V%T
M:6]N`$1J:6)O=71I`,1R82!K=7-T=71A`,1R82#\<FET82!M86EN=&5N86YC
M92YP:'`@9F%I;&D@;W1S92!KY&EV:71A9&$`2W5I(&5S:6UE;F4@<FED82!S
M:7-A;&1A8B!VY&QJ861E(&YI;65S:60L(&WD<F=I('-E92!R=75T.@!$;VUI
M;FEC80!$;VUI;FEK86%N:2!686)A<FEI:P!3=6P@<&]L92!K;VYT;W0_(%)E
M9VES=')E97)U+@!386QV97-T80!386QV97-T82`E<P!386QV97-T82!L;V]D
M=60@<V5A9&ES='5S(%!(4"!S:W)I<'1I;F$N`$YI;65K:7)I`%)A=FEM:60`
M12UP;W-T`$4M<&]S="U335-I;&4@=F%H96YD=7-D<F%I=F5R+"!T965N=7-E
M<&%K:W5J871E;&4@:V5L;&5L('-E;&QI;F4@=&5E;G5S(&]N`$524@!%:W5A
M9&]R`$UU=61A`$UU=61A(&)L;VMK:0!-=75D82!G<G5P<&D`375U9&$@]6EG
M=7-T`$UU=61A(/5I9W5S:0!-=75D82`E<R#U:6=U<VD`375U9&$@<V5A9&5I
M9#H`375U9&$@(B5S(B#U:6=U<VD`375U9&$@)7,@]6EG=7-I`$AA<FED=7,`
M16=I<'1U<P!,_&QI=&$@<V5E('-I<W-E(&IA('-I:7,Z("5S+"!V]6D@:V%S
M=71A(&QI:'1S870@2%1-3"!V97)S:6]O;FDZ("5S+@!%;"!386QV861O<@!%
M;&5M96YT+BXN`$5M`$4M<&]S=`!%+7!O<W1I(&%A9')E<W,`12UP;W-T:2!A
M861R97-S:60@<&5A=F%D(&ML87!P:6UA+@!%+7!O<W0@:VEN;FET=7-E9V$`
M12UP;W-T+5--4VEL92!L_/QS`%-M86EL:60`4_5N=6T@;VX@=/QH:2X`5'5L
M96UU<R!O;B!T_&AI+@!/='-I;F=U=&EN9VEM=7,@;VX@=/QH:0!,=6)A('1E
M:W-T:2!S:7-S92!L:7-A9&$@<&EL=&4@9F]T;V=A;&5R:6ED97-T`$QU8F$@
M<&%R96UK;/5P<W5G82!H_'!I:VUE;OS\`$%A<W1A(&SU<'``4W5U<F5N9&$@
M961I=&]R`%-I<V5S=&$@<V%L86IA;F4@:_QS:6UU<R!M:61A('-I;G5L="!K
M_'-I=&%K<V4@<&%R;V]L:2!M=75T;6ES96MS+"!NY&ET96MS("=M:7,@;VX@
M<VEN=2!L96UM:6ML;V]M82!N:6UI/R<Z`%-I<V5S=&$@<VEI82!P:6QD:2!5
M4DP`4VES97-T82!A;&QA('3D:&5D.@!%:W9A=&]R:6%A;"U':6YE80!%<FET
M<F5A`%9I9V$`5FEG82!B;&]K:2!L;V]M:7-E;#H@)7,`5FEG82!S_&YK<F]N
M:7-E97)I;6ES86YK<G4@:W5S='5T86UI<V5L.B`E<P!6:6=A('/\;FMR;VYI
M<V5E<FEM:7-E(&QO9VD@:W5S='5T86UI<V5L.B`E<P!6:6=A('-I<W4@;&%A
M9&EM:7-E;#H@)7,`5FEG82!S86QA<_5N82!M=75T;6ES96PZ("5S`%9I9V$@
M92UP;W-T:2!T96%T97,N`%9I9V$@(B5S(B!K:7)J=71A;6ES96PN`$5E<W1I
M`$5T:6]O<&EA`%)A:'9U<VQI:P!%=7)O;W!A`$EG82`Q-2!M:6YU=&D@=&%G
M86YT`$EG82`R(&UI;G5T:2!T86=A;G0`26=A(#,P('-E:W5N9&D@=&%G86YT
M`$EG82`U(&UI;G5T:2!T86=A;G0`26=A;"!S:7-S96QO9VEM:7-E;`!)9V$@
M<&]O;&4@='5N;FD@=&%G86YT`$MO<F0@;6EN=71I<P!.Y&ED:7-VY.1R='5S
M960Z`$OD:79I=&$`3&%I96YD80!.Y&ET82!K_&QG<FEB80!/;W1A<VEN("<I
M)P!/;W1A<VEN(&QI:'1S870@<_5N82!V]6D@:G5T=6WD<FMI9&5S(&]T<VEN
M9W5F<F%A<VD`065G=6UI<V4@:W5U<.1E=@!%:W-P;VYE;G0`5&5K<W1I(';D
M<G8`4V5A9&ES='5S92#\;&5S;&%A9&EM:6YE($944"!K875D=0!(Y.1L97-T
M=7-E(&QA861I;6EN92!N=7)J=7,N`$5I('-A86YU9"#\:&5N9'5S="!,1$%0
M('-E<G9E<FEG82X`16D@<V%A;G5D(/QH96YD=7-T(%--0B!S97)V97)I9V$N
M`$5I('-A86YU9"!K;W!E97)I9&$@(B5S(BUS="X`16D@<V%A;G5D(&MO<&5E
M<FED82`B)7,B+6DN`%5U92!305-,(/QH96YD=7-E(&QO;VUI;F4@;G5R:G5S
M+@!%:2!S86%N=60@=/5S=&$@(B5S(BUI+@!%:2!S86%N=60@=&ER:61A.B`E
M<P!(96$`1F%L:VQA;F1I('-A87)E9"`H36%L=FEI;FED*0!&Y.1R:2!S86%R
M960`2V]H=71A=B!V:6=A.@!&86MS`$9A:W-I9`!6965B<G5A<@!4=6YD=6(@
M;F%G=0!4=6YD=6(@;F%G=3H@`-QK<VEK=60@=FEH;6%H;V]D`-QK<VEK=60@
M;'5M97-A:G5H;V]D`$9I96QD(&UA=')I>`!&:6=L970@0T%05$-(00!&:6=L
M970@9F]N=`!&:61Z:0!&86EL`$9A:6QI9&4@87)V.B`E<R!F86EL`$9A:6QI
M9&4@87)V.B`E<R!F86EL:0!&86EL:6AA;&1U<@!&86EL:2!N:6UI`$9A:6QI
M('9A;&EK`$9A:6QI(/QL97-L86%D:6UI;F4`1F%I;&ED92#\;&5S;&%A9&EM
M:7-T(&5I('1O971A=&$N`$9I;'1R:60`4V]O;64`17-I;65N92!P;V]L`$5S
M:6UE;F4@=F5E<F%N9`!3Y&EL:71A('-U:&4`4&5E9V5L9&$`2/5L:G5V`%5D
M=0!+871A;&]O9VD@)7,@<&]L92!O;&5M87,`5&5K<W1I(';D<G8`5&]I=`!6
M965B:6QE:&ET<V5J871E;&4@;6ES('!I;'1E(&5I('1O971A`$5N;G5S='5S
M("A4048I`%#D979A9&4@87)V("AO;&=U(/9E;&1U9"!E="!T86=A<W1A=&%V
M(&5N;G5S='5S('-I<V%L9&%B(&YI:2!PY&5V:2!K=6D@]FED.R!S=75R(&%R
M=B!V]6EB(&)L;VMI(&QA:6%K<R!V96YI=&%D82D`56YU<W1A<VED('-A;&%S
M]6YA/P!6;W)M:60`2VEL9`!+:6QL=2!T_/QP`$MI;&QU9`!+:6QL=60@,@!&
M;V]R=6UI9`!%9&%S='5S`%)E`%)A86UI9`!0<F%N='-U<VUA80!0<F%N='-U
M<VUA82P@175R;V]P82UO<V$`4')A;G1S=7-E($=U86IA86YA`%!R86YT<W5S
M92!0;VS\;F5E<VEA`%!R86YT<W5S92!,]75N86%L860`2V5L;&5L=`!3=75N
M86=A(`!0]6AJ86QI:R!K:7)J96QD=7,`5.1I<VMU=0!4Y&ES;FEM:0!'86)O
M;@!'86QE<FEI+"!K=7-T('!I;'0@=O5T=&$`1V%L97)I:3H`1V%M8FEA`$=E
M;F5R965R:2`E<R!K;VYF:6=U<F%T<VEO;VX`1V5N97)E97)I='5D(&MO;V0`
M1W)U=7-I80!386MS86UA80!'86%N80!':6)R86QT87(`165S;FEM:0#<;&1I
M<V5D('-E861E9`!-:6YE`$?V9&5L`$=O;V=L92!K86%R9&ED`$=O;V=L92!O
M='-I;F<`2&%L;'1O;VYI9&5S<V4`2W)E96MA`$MR965K82`H25-/+3@X-3DM
M-RD`1W+V]FYI;6%A`$=R96YA9&$`1W)U<'!I9&4@:&%L9'5S`$=R=7!P:61E
M(&YI;65D(&5I(';U:2!O;&QA('3\:&IA9`!'<F]U<%]L9&%P.B!%:2!S86$@
M;&ES861A(&=R=7!P:2`E<RX@4V5R=F5R(/QT;&5S.B``1W)O=7!?;&1A<#H@
M16D@<V%A(&MU<W1U=&%D82!G<G5P<&D@)7,`1W)O=7!?;&1A<#H@16D@<V%A
M(&UU=71A(&=R=7!P:2`E<P!'<G5P:60`1W5A9&5L;W5P90!'=6%M`$=U871E
M;6%A;&$`1W5E<FYS97D`2_QL86QI<V4@]6EG=7-E9`!+_&QA;&ES=&5R86%M
M870`1VEN96$`1VEN96$M0FES<V%U`$=U86IA86YA`$A434P`2%1-3$%R96$@
M:V5E;&1U8B!A<F=P_&MS;&EK=6QT(&MU<W1U=&%M87-T(')E82!V:6EM87-T
M(&QA:'1R:70N`$A434Q!<F5A(&ME96QD=6(@87)G</QK<VQI:W5L="!K=7-T
M=71A;6%S="!T86)E;&D@=FEI;6%S="!V965R9W4N`$A434Q!<F5A(&ME96QD
M=6(@87)G</QK<VQI:W5L="!K=7-T=71A;6%S="!T86)E;&D@=FEI;6%S="!R
M:61A+@!(5%10(&%U=&5N=&EM:7-T(&5I(&QE:71U9"X`2&%I:71I`%+D<VEA
M;&=O<FET;0!(Y&=U`%#D:7,`4.1I<V5D`$AE87)D:2!S86%R(&IA($UC1&]N
M86QD:2!S86%R960`4N1N:R#D:6ME<V5T;W)M`$AE96)R96$@*$E33RTX.#4Y
M+3@M22D`2_5R9W5S`$%B:0!%9&ET;W)I(&MA<W5T86UI<V4@86)I`$%B:6QI
M;F4`<&]O;&ME<F$`4VEI;B!O;B!F86EL:2!A;&=U<P!+]7)G90!?079A;&5H
M=`!0_&AA(%1O;VP@*%9A=&EK86YI($QI;FYR:6EK*0!!=F%L96AE;&4`2V]D
M=6YE(&%A9')E<W,`2V]D=6MA=&%L;V]G`$MO9'5N92!T96QE9F]N`$AO;F1U
M=7)A<P!(;VYG:V]N9P!(;W)D90!(;W)D92]+;VQA8CH@5FEG87-E9"`E<R!8
M34P@86YD;65D(&MI<FIA<R`E<P!(;W)D92]+;VQA8CH@3V)J96MT:6QE("5S
M(&5I('9A<W1A(/QK<VMI(&MI<FD`2&]R9&4O2V]L86(Z($5I(&QE:71U9"#\
M:'1K:2`E<R!T_/QP:2!O8FIE:W1I(&MI<FIA<R`E<P!(;W)D92]+;VQA8CH@
MU6YN97-T=7,@965M86QD861A("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G
M<F%T<VEO;VYI;6]O=&]R('9A:F%B("=D;VUX;6PG(%!(4"!L86EE;F1U<W0`
M2&]R9&4O2V]L86(Z($5I('-A82!L=75A('5U="!834P@<'5U9"!O8FIE:W1I
M("5S(&IA;VMS`$AO<F1E+TMO;&%B.B!%:2!S86$@965M86QD861A("5S("(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2#U;FYE<W1U(&AA;FMI9&$@34E-12!)
M1"UD("5S('3\_'!I(&]S82!J86]K<P!(;W)D92]+;VQA8CH@16D@<V%A('/\
M;FMR;VYI<V5E<FED82`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@16D@<V%A
M('/\;FMR;VYI<V5E<FED82!J86=U<VED.B`E<P!(;W)D92]+;VQA8CH@5'5N
M9&UA='4@:F%G=2`B)7,B`$AO<FES;VYT86%L:F]O;@!(;W)I<V]N=&%A;&YE
M('9O;V1E<F1U<P!(;W)I<V]N=&%A;&YE.@!+=6ED87,@<V$@<VEI82!S871T
M=7-I9#\@*%!A;'5N('1E871A(2D`2W5I('!A;&IU('9E97)G92!S;V]V:6MS
M:60@_&AE;F1A9&$_`$MU:2!P86QJ=2!VY&QJ=2`H=F5E<F=E*2!O;C\`2W5I
M('!A;&IU(')I9'4@<V]O=FEK<VED(/QH96YD861A/P!.:6ES:W5S`$YI:7-K
M=7,Z`$AU;6]R:7-T:60`56YG87)I`$E-05`@<&]S=&MA<W1I(&QO;VUI;F4@
M;G5R:G5S.B`E<P!)34%0('!O<W1K87-T:2!K=7-T=71A;6EN92!N=7)J=7,Z
M("5S`$E-05`@<&]S=&MA<W1I(&MV;V]D:2!L;V]M:6YE(&YU<FIU<SH@)7,`
M25`@86%D<F5S<P!)4"!A861R97-S('!O;&4@=&5A9&$N`$E0(&%A9')E<W,@
M96D@:W5U;'4@;'5B871U9"!#2412(&)L;VMK:2X`25`@<&EI<F%N9W4@<FEK
M:W5M:6YE+@!,:7-A(')I9&$@7V5N;F4`27-L86YD`$%I;G5L="!I:V]O;FED
M`"5S(&EK;V]N:60`26MO;VYI9"!J82!T96MS=`!)9&5N=&ET965D:2!N:6UI
M.@!+=6D@<V5D82#U:65T:2!E:2!NY&ED871A+"`E<R!J82!S964@879A=&%K
M<V4@=75E<R!A:VYA<RX`2W5I('-A(&MA<W5T860@26YT97)N970@17AP;&]R
M97)I="!J82!E:2!NY&4@_&QD<V4@:6MO;VYE+"!S:6ES('!R;V]V:2!MY')K
M:61A('-E92!R=75T+"!L_&QI=&%M86MS('-I<W-E(%!.1R!LY&)I<&%I<W1V
M=7,N`$MU:2!S82!NY&5D('-E9&$@=&5A9&5T(&%G82!P:6QT:2!E:2!NY&4L
M('-I:7,@96D@;W-K82!S:6YU('9E96)I;&5H:71S96IA(&[D:61A=&$@<V5D
M82!P:6QT:2P@;6ED82!S;V]V:60@_&QE<R!L86%D:61A+@!0:6QD:2!E96QV
M86%D93H`4&EL9&D@55),`%!I;&1I(%523#H`4&EL="!G86QE<FEI<W0`4&EL
M="!G86QE<FEI<W0Z`%!I;&1I(/QL97-L86%D:6UI;F4`4&EL9&ED`$EM<&]R
M="P@<V%M;2`E9`!);7!O<F1I='5D(';D;&DZ("5S`$EM<&]R9&ET=60@=N1L
M:F%D.@!,:7-A(')I9&$@7W#D<F%S=`!%<VET871I('9A;&4@=&5G979U<V4@
M:V]O9"X`5F%L92!K87-U=&%J86YI;6D@:F$O=O5I('!A<F]O;"X`5F%L92!K
M87-U=&%J86YI;6D@=O5I(&%L=&5R;F5T:6EV;F4@86%D<F5S<RX@4')O;W9I
M('5U97-T:2!V]6D@=O5T82#\:&5N9'5S="!A9&UI;FES=')A871O<FEG82X`
M4W5U<F5N9&$@=&%A;F1R:61A`$EN9&EA`-QK<VEK=60@:V%S=71A:F%D`$EN
M9&]N965S:6$`26YF;P!);F9O<FUA='-I;V]N`%1E879E(&5I(&]L92!E;F%M
M(&OD='1E<V%A9&%V+@!,:7-A(%]V965R9R!PY')A<W0`3&ES82!P:6QT`$QI
M<V$@=&%B96P`3&ES82!H_'!E<FQI;FL`3&ES82!V965?<F<@96YN90!,:7-A
M('5U<R!V965R9R!A:W1I:79S92!V965R=2!JY')E;&4`3&ES82!U=7,@=F5E
M<F<@86MT:6EV<V4@=F5E<G4@971T90!,:7-A('5U<R!R:61A(&%K=&EI=G-E
M(')E82!JY')E;&4`3&ES82!U=7,@<FED82!A:W1I:79S92!R96$@971T90!,
M:7-A(&SU:6L@<')A96=U<V4@87-U:V]H82!JY')E;&4`3&ES82!L]6EK('!R
M865G=7-E(&%S=6MO:&$@971T90!,:7-A(&%L=&5R;F%T:6EV;F4@;6%L;`!3
M:7-E<W1A(&UA:6QI86%D<F5S<R!K=6AU('-A86MS('-U;&QE('5U92!P87)O
M;VQI('-A871A.@!,:7-A(&QA:'1E<B!PY')A<W0`3&ES82!L86AT97(@96YN
M90!,:7-A('9E97)G('#D<F%S=`!,:7-A('9E97)G(&5N;F4`3&ES82!K:7)J
M860`3&ES82!L]6EK('#D<F%S=`!,:7-A(&SU:6L@96YN90!,:7-A(')I9&$@
M<.1R87-T`$QI<V$@<FED82!E;FYE`$MI<FIU=&$@<V%L86O\<VEM=7-E(/5I
M9V4@=F%S='5S.@!,:7-A+VUU=61A('!I;'0`3&ES82]M=75D82!L:6YK`$IA
M;W1U<VYI;65K:7)J86QE('-A871M:7-E:W,@96D@:N1T:W4@:W)E9&EI=&DN
M`$MR961I:71I(&5I(&KD=&MU+@!4Y&ES87)V`%3D:7-A<G9U9&4@;FEM96MI
M<FD`5FEG86YE(%5$2"`H57-E<B!$871A($AE861E<BDN`%9I9V%S960@6DE0
M(&%N9&UE9"X`5FEG86YE(')A:V5N9'5S+@!686QE(&)A=&-H($E$`%-I<V5S
M=&%T:2!V:6=A<V5D(&%N9&UE9"X`5FEG86YE('-I:'1A861R97-S+@!686QE
M(&9A:6QI9F]R;6%A=`!6:6=A;F4@;&ET<V5N='-I=O5T:2X`4VES97-T871I
M('9I9V%N92!A<W5K;VAT`%9I9V%N92!M<V=?='EP90!A<&E?:60@;VX@<'5U
M9'4@=O5I('9I9V%N92X`5FEG87-E9"!V]6D@<'5U9'5V860@<&%R86UE971R
M:60N`%9I9V%N92#\;&5M]6EG=7,N`%9I9V%N92!P87)T;F5R:2!)1`!6:6=A
M;F4@=&]O=&5K;V]D+@!6:6=A;F4@<')O=&]K;VQL+@!6:6=A;F4@<V%A:F$Z
M("(E<R(`5FEG86YE(&IA9V%T=60@;V)J96MT`%9I9V%N92!LY&AT96%A9')E
M<W,N`%9I9V%S960@=6YI8V]D92!A;F1M960N`$YI;65K:7)I`%#V]G)D=F%L
M:6L`27)A86YI($ES;&%M:79A8F%R:6EK`$ER86%K`$EI<FEM86$`36%N:2!S
M86%R`-QK<VEK=60@Y&EK97-E=&]R;6ED`$EI<W)A96P`5N1L:F%A;F1J80!+
M86QD:VER:0!)=&%A;&EA`$IA;6%I:V$`2F%A;G5A<@!*86%P86X`2F%A<&%N
M:2`H25-/+3(P,C(M2E`I`$MU;F$@<VEN=2!V965B:6QE:&ET<V5J87,@;VX@
M2F%V87-C<FEP="!K965L871U9"P@96D@<')U=6=I('-E92!L96AT(/5I971I
M('!A:7-T82X`2F5R<V5Y`$IO<F1A86YI80!*=75L:0!*=75N:0!2]O9P<V5L
M=`!+97-K96QE`%+V]G!S96QT`%9A<V%K=6QE`%!A<F5M86QE`$MA<V%H<W1A
M;@!3Y&EL:71A(&]R:6=I;F%A;#\`2V5E;FEA`$ME<F)E<F]S92!S97)V97(@
M96D@;&%S:VYU9"!S:7-S92X`2V5R;F5L:2!V]6AI:W5D`%;U=&UE(&QO;VUI
M;F4`5O5T;64@<_5R;65JY&QG`%;U=&UE('!I:VMU<P!6]71M92!T_/QP`%;U
M=&UE(&MA<W5T=7,`5O5T:2!O;B!A=F%L:6MU<R!S97)V97)I<R!J=6)A(&]L
M96UA<RX`3&%P<V5D`$MI<FEB871I`$MO<F5A(%)A:'9A9&5M;VMR86%T;&EK
M(%9A8F%R:6EK`$MO<F5A(%9A8F%R:6EK`$MO<F5A("A%54,M2U(I`$MU=F5I
M=`!+]7)G]7IS=&%N`%]+=6IU;F1U<P!+965L`$QA;W-E(%)A:'9A9&5M;VMR
M86%T;&EK(%9A8F%R:6EK`%9I:6UA;F4@<&]O;`!6:6EM86YE('!A<F]O;&D@
M;75U='5S`%9I:6UA;F4@=F5E<F%N9`!6:6EM871I(&UU=61E='5D.@!%96QM
M:6YE(&O\;&%S='5S.B`E<P!%96QM:6YE(&O\;&%S='5S.B`E<R!A861R97-S
M:6QT("5S`$5E;&UI;F4@:_QL87-T=7,Z(&UI='1E(&MU;F%G:0!,Y'1I`%-E
M861U<P!+=6IU;F1U<P!4_&AI('3D:&5N9&%B('!I:7)J;V]N92!P=75D=6UI
M<W0`3&EI8F%N;VX`5F%S86L`5F%S86L@<.1I<P!687-A:W5D(';DY')T=7-E
M9`!,97-O=&AO`%1A<V4`3&EB965R:6$`3&EI8OQA($%R86%B:6$@5F%B87)I
M:6L`3&EE8VAT96YS=&5I;@!4:6)U=&%B('9I:&UA`%-E96YE=FEH;0!(;VUM
M:6MU;"!T:6)U=&%B('9I:&UA`-5H='5L('1I8G5T86(@=FEH;6$`2V5R9V4@
M:&]O=FEH;0!+97)G92!V:6AM(&IA(.1I:V4`2V5R9V4@;'5M97-A9'4`2V5R
M9V4@;'5M971O<FT`3&EM97)I:P!,:6YK`$QI;FL@=FEI=&%B(&%S=6MO:'1A
M.@!%<VET86UI<V5L('-E;W-T82!E+7!O<W1I(&%A9')E<W,@=75E(&MI<FIA
M(&%K;F%G80!,:6YG:60`3&EN=7AI('!RY.1N:6L`3&ES="`M(&MA<W5T86IA
M(';U:6(@:V%U<W1A(&[D:&$`06YD;65B86%S:61E(&QO971E;'4`06)I:6YF
M;R!T965M861E(&YI;65K:7)I`%1A8F5L:71E(&QO971E;'4`3&ES="U!<F-H
M:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T`$QI
M<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`4V5S<VEO;VYI9&4@;FEM
M96MI<FIA(&5S:71A;6EN92!N=7)J=7,Z("5S`$MA<W5T86IA=&4@;FEM96MI
M<FIA(&5S:71A;6EN92!N=7)J=7,Z("5S`$MA<W5T86IA=&4@;FEM96MI<FIA
M('!O;&4@;'5B871U9"!NY&AA+@!+:7)J86YD=7,`3&5E9'4`3&%E;BXN+@!+
M;VAA;&EK(&%E9SH@`%)E9VEO;VX@:F$@865G`$%S=6MO:'0`3&]G:2!S:7-S
M90!%96QM:7-E('/\;FMR;VYI<V5E<FEM:7-E(&QO9VD`3&]G:2!VY&QJ80!+
M87-U=&%J86YI;6D`5/;V9"!S:7-S96QO9VEM:7-E;`!3:7-S96QO9VEM:6YE
M(&YU<FIU<RP@:W5N82!K87-U=&%J86YI;6D@=O5I('!A<F]O;"!P;VQN=60@
M]6EG92X`4VES<V5L;V=I;6EN92!N=7)J=7,N`%!I:VL@=&5K<W0`07)M87-T
M=7,`36%D86P`2W)E96MA(';D:6ME=.1H960`3&%D:6YA(';D:6ME=.1H960`
M5N1I:V5S960@<F]O;6$@;G5M8G)I9`!,=6MS96UB=7)G`$M+`$U/5$0`35,M
M5$Y%1B!L:7-A;F0@96D@<VES86QD86YU9"!A;F1M96ED+@!-4T<`36%K86\`
M36%K961O;VYI82`H16YD:6YE($IU9V]S;&%A=FEA(%9A8F%R:6EK*0!-861A
M9V%S:V%R`$UA86=I80!%+7!O<W0`4&]S=&D@861M:6YI<W1R86%T;W(`7U1E
M92!L:6YK`$UA;&%W:0!-86QA:7-I80!-86QD:6EV:60`36%L:0!-86QT80!3
M96%D:7-T82!K871E9V]O<FEA:60L(&UI9&$@:V%S=71A=&%K<V4@_&MS=7-T
M92!MY')G96YD86UI<V5K<R!J82!N96YD96QE(&MA=&5G;V]R:6%T96QE('9A
M<W1A=F%I9"!VY')V92X`36%P,C0@:V%A<G0`36%P475E<W0@:V%A<G0`5F%S
M=&%V=7-E9"!S86QV97-T871U9"X`3>1R=',`4V5R=@!4Y&AI<W1A(&QO971U
M9"]L=6=E;6%T82!S=&%A='5S`%3D:&ES=&$@;75U('-T86%T=7,@*&YT+B!T
MY&AT:7,O=F%S=&%T=60I`$UA<G-H86QL:2!S86%R960`36%R=&EN:7%U90!3
M;V)I=F%D(';D;&IA9`!-875R971A86YI80!-875R:6ET:75S`%-U=7)I;2!L
M=6)A='5D(&MR961I:70N`$MI<FIA(&]S861E('!I:7)A;F<@_&QE=&%T=60N
M`%9I:6UA<V4@,C0@='5N;FD@:_5R9V5I;2!T96UP97)A='5U<CH@`%9I:6UA
M<V4@-B!T=6YN:2!K]7)G96EM('1E;7!E<F%T=75R.B``4W5U<FEM('!O<G1A
M86QI(&)L;VMK:61E(&%R=@!3=75R:6T@<&EK:W5S`$UA:0!-87EO='1E`$UE
M9&ET<VEI;@!,:6EK;65D`$UE;OS\(&5S:71U<SH`W&AE;F1A(&QA:'1R:60`
M5&5A9&4`2VER:2!O;B!E9'5K86QT(&MO;G1R;VQL:71U9"P@96YT(&%L;&MI
M<FIA<W1A:F$@<V5R=&EF:6MA871I(&5I('-A86YU9"!K;VYT<F]L;&ED82X`
M5&5A9&4@;VX@865G=6YU9"X`5&5A=&4@=/S\<`!-971A<B!I;&T`365T87(@
M8FQO:VL@96D@;VQE('-A861A=F%L+@!-971A<B!B;&]K:R!E:2!O;&4@<V%A
M9&%V86PN(-QK<VEK87-J860@;&]G:71I(&%D;6EN:7-T<F%A=&]R:2!J86]K
M<RX`365T87)$0B#\:&5N9'5S('!U=61U8BX`365E=&]D`$UE971O9"`B)7,B
M(&5I(&]L92!D969I;F5E<FET=60`365E=&]D(&5I(&]L92!D969I;F5E<FET
M=60N($OD:79I=&%T=60@;65E=&]D.B`E<P!-965T97(`365H:&EK;P!-:6MR
M;VYE97-I82!&]F1E<F%T<VEO;VX`2V5S:V5L90!-24U%('3\_'``5FEI;6%S
M92`R-"!T=6YN:2!M861A;&%I;2!T96UP97)A='5U<CH`5FEI;6%S92`V('1U
M;FYI(&UA9&%L86EM('1E;7!E<F%T=75R`%!A<F]O;&D@;6EN:6UA86QN92!V
M86YU<R!P;VQE('9E96P@=.1I<P!0965G96QD80!-:71M97-U9W5S=`!0=75D
M=6(@4$5!4B!P86ME='0@2%144%]297%U97-T+@!+;VYF:6=U<F%T<VEO;VX@
M<'5U9'5B+B!+=6D@=&%H860@<V5D82!R86ME;F1U<W0@:V%S=71A9&$L('!E
M860@96YN92!G96YE<F5E<FEM82!K;VYF:6=U<F%T<VEO;VYI+@!0=75D=6(@
M<_5N=6UI($E$+@!0=75D=6(@=F%J86QI:R!014%2('!A:V5T="!-86EL+@!0
M=75D=6(@<V5S<VEO;VYI($E$+@!%<P!-;V)I:6QN92!E+7!O<W0`3?7U9'5K
M87,`375U=&UI<V4@:W5U<.1E=@!-=75D82!54DP`2N3D:P!-;VQD;W9A(%9A
M8F%R:6EK`$UO;F%K;P!-;VYG;V]L:6$`2W5U(&IA(&%A<W1A`$MO<F0@:W5U
M<P!-;VYT<V5R<F%T`$MU=69A87-I9`!296%S("5D(&QE:71I(')O:&ME;2!V
MY&QJ=2!K=6D@965L9&%T878@)60N`$UA<F]K;P!686QD879A;'0@<V5L9V4`
M5F%L9&%V86QT('!I;'9E<P!686QD879A;'0@<&EL=F5S(&IA('1U=6QI;F4`
M5F%L9&%V86QT('#D:6ME<V5P86ES=&5L:6YE`$YI:'5T82!A;&QA`$YI:'5T
M82!V87-A:W5L90!.:6AU=&$@<&%R96UA;&4`3FEH=71A(/QL97,`3FEH=71A
M(&%L;&$`3FEH=71A(/QL97,`36]S86UB:6EK`$UI=&UE=&%S96UE;&EN92!L
M;V5N9`!-=6QT:6UA<"!52R!K86%R=`!686QI:P!-:6YU(&MO;G1O`$UI;G4@
M:V]N=&\@:6YF;P!-:6YU('!O<G1A86P`36EN=2!P;W)T86%L:2!K=6IU;F1U
M<P!->6%N;6%R`$5)+"!M82!%22!/3$4@;O5U<P!.:6UI`$YA;6EI8FEA`$YA
M=7)U`$YE<&%A;`!(;VQL86YD`$AO;&QA;F1I($%N=&EL;&ED`$YE='-C87!E
M($)A<V4@55),`$YE='-C87!E($-!('3\:&ES='5S92!54DP`3F5T<V-A<&4@
M0T$@<&]L:6-Y(%523`!.971S8V%P92!U=65N9'5S92!54DP`3F5T<V-A<&4@
M=/QH:7-T=7-E(%523`!.971S8V%P92!34TP@<V5R=F5R:2!N:6UI`$YE='-C
M87!E('-E<G1I9FEK86%D:2!K;VUM96YT86%R`$YE='-C87!E('-E<G1I9FEK
M86%D:2!T_/QP`%;U<FL`36ET=&4@:W5N86=I`%5U<RU+86QE9&]O;FEA`%5U
M<R!K871E9V]O<FEA`%5U<R!K:7)I("5S+6QE`$YO;W)K=74`575S(&MA<W5T
M86IA;FEM:2`H<&]L92!K;VAU<W1U<VQI:RD`575S+4UE<F5M86$`575S('-A
M;&%S]6YA`%5U<R!S86QA<_5N82!A96=U8B`E>"X`4V%L87/U;F%D('!E879A
M9"!K;&%P<&EM82X`575E<R!A:VYA<R`H7V)L86YK*0!5=61I<V5D`$=R=7!I
M9`!*Y')G;6EN90!*Y')G;6ES960@-"!F86%S:0!*Y')G;6ES960@<V5A9&5D
M`$KD<F=M:6YE/@!.:6MA<F%A9W5A`$YI9V5R`$YI9V5E<FEA`-;V`$YI=64`
M16D`4'5U9'5V860@:V]N9FEG=7)A='-I;V]N:6%N9&UE9"!M:6QL92!E<FEN
M979U<VD@;N1I9&%T82X`4'5U9'5B('-T<F%T965G:6$@25-/9&4@;&]O;6ES
M96MS+@!0=75D=6(@;6%L;"X`4V5L;&5S(&%S=6MO:&%S(&5I(&]L92!B;&]K
M:VD`34-!3"!A=71E;G1I;6ES96MS('9A:F%L:6L@:V%L96YD<FD@;FEM:2!O
M;B!P=75D=2X`17)I;F5V=7-I(&5I(&]L92X`4V5L;&5L92#U:6=U<V5L92!E
M:2!S86$@86QA;6%I9"!L:7-A9&$N`"5S(&CDY&QE<W1U<VEN9F\@<'5U9'5B
M+@!&5%`@5D93(&CDY&QE<W1U<VEN9F\@<'5U9'5B+@!344P@5D93(&CDY&QE
M<W1U<VEN9F\@<'5U9'5B+@!344PM1FEL92!61E,@:.3D;&5S='5S:6YF;R!P
M=75D=6(N`$MR961I:70@;VX@86UM96YD871U9"X`4VEH=&MO:'0@;>3D<F%M
M871A+@!&86EL:2!E:2!L865T=60`26MO;VYE(&5I(&QE:71U9"X`07-U:V]H
M="!MY.1R86UA=&$N`$%S=6MO:'0@;>3D<F%M871A`%/U;G5M('!U=61U8BX`
M3FEM:2!P=75D=6(N`$YU;6)E<B!P=75D=6(N`$%I;G5L="!V:6ES86MA9"!K
M:6QL=60`2%144"!A=71E;G1I;6ES92!S86QA<_5N82!P=75D=6(N`$E-05`@
M875T96YT:6UI<V4@<V%L87/U;F$@<'5U9'5B+@!+97)B97)O<R!A=71E;G1I
M;6ES92!S86QA<_5N82!P=75D=6(N`$QO9VEN(&%U=&5N=&EM:7-E('-A;&%S
M]6YA('!U=61U8BX`4$%34U=$(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U
M8BX`4TU"(&%U=&5N=&EM:7-E('-A;&%S]6YA('!U=61U8BX`3W!E;E-33"!P
M<F]G<F%M;6D@87-U:V]H="!E:2!O;&4@;>3D<F%T=60N($]P96Y34TP@<')O
M9W)A;6T@;VX@=F%J86QI:R!02T-3(S$R(&%N9&UE=&5G82!T]O9T86UI<V5K
M<RX`3V]T96P@;&EI='5M:7-S;V]V92!E:2!O;&4N`%!I:7)A;F=U="!E:2!O
M;&4N`%!U=61U=F%D`$5R86QD86IA('!O;&4@;>3D<F%T=60N`$UI='1E(/QK
M<VMI(&O\;&<`4V5L;&ES="!F86EL:2!E:2!O;&4`4'5H=F5R9&%M:7-E:W,@
M<'5U9'5B(&%J=71I;F4@:V%T86QO;V<N`$MA<W5T86IA;FEM92!J82]V]6D@
M<V%L87/U;F$@96D@<V%A9&5T=60N`$5I('1A9V%S=&%T=60@:V]R<F5K='-E
M:60@6$U,(&%N9&UE:60`5N3D<G1U<V5D('!U=61U=F%D`$%L9VYE(&MO;F9I
M9W5R871S:6]O;B!E:2!S:7-A;&1A('9E<G-I;V]N:2X@3&]O(&MO;F9I9W5R
M871S:6]O;B!U=65S=&DN`%-I;G4@:V]N9FEG=7)A='-I;V]N(&5I('-I<V%L
M9&$@=F5R<VEO;VYI+B!,;V\@:V]N9FEG=7)A='-I;V]N('5U97-T:2X`3>3D
M<F%M871A`$WDY')A;6%T80!0]6AJ86UA860@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK:2!S86%R`%#U:&IA<&]O;&ME<F$`4/5H:F$M36%R:6%A;FD@<V%A<F5D
M`$YO<G)A`$UI='1E(&AI;&IE;2!K=6D`36ET=&4@=F%R96T@:W5I`$5I(&]L
M92!K871A;&]O9P!0;VQE('1E;W-T871U9"X`3>3D<F%M871A`$5I(&]L92!T
M;V5T871U9"X`3>1R:VUE9`!0;VQE(&UI9&%G:2!S:7)V:61A+"!M:6YE('1A
M9V%S:2X`3F]V96UB97(`07)V`$WD<FMI9&4@87)V`%9E97)G=61E(&%R=@!2
M:61A9&4@87)V`$IA;W1U<VYI;65K:7)J87,@;75U=&UI<V5L92!K=75L=79A
M9"!N=6UB<FED('!O;&4@;>3D<F%T=60N`$]+`$]B:F5K=`!/8FIE:W1I(&QO
M;VIA`$MA:&5K<V%N9&YU;6)E<@!/:W1O;V)E<@!6:6ES86MU<V4@87-T90!+
M;VYT;W)I=/;V`%9A;F$@:F$@=75S('-A;&%S]6YA('!E879A9"!O;&5M82!E
M<FEN979A9"X`4')A96=U;F4@<V%L87/U;F$`4')A96=U;F4@<V%L87/U;F$@
M96D@;VQE(/5I9V4N`$]M86%N`-QH:7-K875S='4@=O5I;6%L9&%V860@86EN
M=6QT($E-05`@<V5R=F5R:60N`$%I;G5L="!E8F%V:6ES86MA9"!K:6QL=60`
M3'5B871U9"!O;B!A:6YU;'0@_&MS(&4M<&]S=&D@86%D<F5S<RX`2F%O(&]M
M86YI:VMU(';U:2!O;6%N:6MU(/5I9W5S:2!S86%B(&UU=71A(&%I;G5L="!O
M;6%N:6L@=O5I('/\<W1E96UI(&%D;6EN:7-T<F%A=&]R+@!!=F$@=75E<R!A
M:VYA<P!/<&5N4U-,('9I9V$Z($%N9&UE=&4@97)A;&1A;6EN92!A;&QK:7)J
M87-T871U9"!3+TU)344@;W-A<W0@;G5R:G5S+@!!=F%B('-E;&QE(&QI;F=I
M('5U97,@86MN87,`3W!E<F%T<VEO;VYI<_QS=&5E;0!396%D960`4V5A9&ES
M='5S.B`E<P!.=6UM97)D871U9"!L;V5T96QU`$]R9V%N:7-A='-I;V]N`$%L
M;/QK<W5S`$EN9F\`4F%K96YD=7-E(&%L9VYE(&UA;&P`06QG<V5D(&UA;&QI
M9"!K871A;&]O9VES("5S.@!-=74`375U(&EN9F\`3VUA;FEK=2#U:6=U<V5D
M`%!!32!A=71E;G1I;6EN92!E:2!O;&4@<V%A9&%V86PN`%!%05(Z.DUA:6P@
M='5G:0!01U`@9&EG:71A86QA;&QK:7)I`%!'4"!K<OQP=&ET=60@86YD;65D
M`%!'4"!A=F%L:6L@=O5T:0!01U`@86QL:VER:F%S=&%T=60O:W+\<'1I='5D
M(&%N9&UE9`!02%`@:V]O9`!02%`@:^1S=7)I9&$`4$P@:V5R9V4@=FEH;0!0
M3"!V:6AM`%!,(&AO;W9I:&UA9`!03"!L=6UI`%!,('1I:&4@;'5M97-A9'4`
M4$P@<.1I:V4`4$P@Y&EK97-E=&]R;0!03U-)6"!L86EE;F1U<R!P=75D=6(`
M4%](4"!KY'-U<FED80!4Y&ED90!086MI<W1A;@!086QA=0!086QE<W1I:6YA
M(&]K=7!E97)I='5D('1E<G)I=&]O<FEU;0!086YA;6$`4&%A<'5A(%5U<RU'
M:6YE80!087)A9W5A:0!686AE;&1U=B!P:6QV:7-U<P!386QA<_5N80!386QA
M<_5N82!M=75D971U9"X`5F%L92!S86QA<_5N80!2041)55,@875T96YT:6UI
M<V5K<R!O;B!V86IA;&EK('-A;&%S]6YA+@!386QA<_5N82!K:6YN:71U<V5G
M80!386QA<_5N83H`4V%L87/U;F$Z(`!386QA<_5N860@<&5A=F%D(&ML87!P
M:6UA+@!!<V5T80!!<V5T82!L]6EK97!U:'9R:7-T`$%S=6MO:'0`3V]T96P@
M;&EI='5M:7-S;V]V:60Z`$EN:6UE<V5D`%!R;W1S96YT:0!+Y&EV:71A(&AO
M;VQD=7-T]O9D`%1E92!S:7-S96QO9VEM:7-E;"!H;V]L9'5S=/9I9`#5:6=U
M<P#5:6=U<W0@(B5S(B!E:2!K=7-T=71A='5D+@!*=75R9&5PY.1S(&ME96QA
M='5D`-5I9W5S960`U6EG=7-T92!H86QD=7,`27-I:VQI:R!I;F9O`%!E<G5U
M`$QE;6UI:VQO;VUA9`!&:6QI<&EI;FED`%1E;&5F;VX`1F]T;V0`4&ET8V%I
M<FX`4&EK<VQI=`!-]71T971U<V5D`$ML]7!S82!M]6YD82!L86AT<FES<V4`
M2VEN;FET82!E="!S;V]V:60@<V5L;&4@96QE;65N9&D@965M86QD861A.@!+
M:6YN:71A(&5T('-O;W9I9"!S96QL92!E;&5M96YD:2!L86AT:2#\:&5N9&%D
M82X`4VES97-T82!K=74@:F$@86%S=&$N`%-I<V5S=&$@<V5L;&4@=75E(&MA
M=&5G;V]R:6$@;FEM:3H`4VES97-T82!K;W)R96MT;F4@25`@86%D<F5S<RX`
M4VES97-T82!K;W)R96MT;F4@:W5U<.1E=BP@:V]N=')O;&QI('#D979A9&4@
M87)V=2!K=75S+@!3:7-E<W1A(&MO<G)E:W1N92!A96<N`$MI<FIE;&1A('!R
M;V)L965M:2X`4VES97-T82!O;6$@:V%S=71A:F%N:6UI(&IA('-A;&%S]6YA
M`$QO92!JY')G;F5V('1E:W-T(&SD8FDN(%/\<W1E96UI(&MA<W5T86UI<V5K
M<R!014%$('1I;F=I;75S=&5G82!N]75S='5M82X`2VER:G5T82!U=64@:V%T
M96=O;W)I82!N:6UI.@!0;V]L80!0;VQI:71I:V$`2_QS:71L=7-E9`!0;W)T
M=6=A;`!396QL92!P:6QD:2!P86EG=71U<P!396QL92!T86)E;&D@<&%I9W5T
M=7,`2VER:G5T82!S96QL97-S92!K875S=&$@*$E-05`@96D@:V]N=')O;&QI
M*0!6:6EM87-E("5S('1U;FYI('-A9&5M960Z(`!3861E;65T93QB<B`O/G3U
M96[D;W-U<P!0<F5F<U]L9&%P.B!686IA;&EK:W4@3$1!4"!L86EE;F1U<W0@
M96D@;&5I='5D+@!0<F5F<U]S97-S:6]N.B!686IA;&EK:W4@<V5S<VEO;B!L
M86EE;F1U<W0@96D@;&5I='5D+@#5:'5R]6AK`-5H=7+U:&L@;65R97!I;FYA
M;#H`U6AU<O5H:SH`165L=F%A9&4`4&EL9&D@965L=F%A9&4@=75E<R!A:VYA
M<P!%96QM:7-E9"!S96%D960`5'+\:VD@9&]K=6UE;G0`4V%L86IA;F4@=O5T
M:0!0<F]B;&5E;0!0<F]B;&5E;6D@:VER:F5L9'5S`%!R;VIE:W1I9`!396QG
M:71A=B!T96MS=`!!=F%L:6L@=O5T:0!!=F%L:6MU(';U=&UE(&%L9V]R:71M
M`$%V86QI:W4@=O5T;64@:6YF;P!6]71M97!A87)I(&=E;F5R965R:6UI;F4@
M96D@]6YN97-T=6YU9"X`4'5E<G1O<FEI:V\`2W5S='5T871U9"!K:7)J861E
M(&5E;6%L9&%M:6YE`$MA=&%R`%#D<FEN9P!0:6ER86YG`%)302!A=F%L:6L@
M=O5T:2`H)60@8FET=&DI`%9A;&EK`%9I:&T`2&]M;6EK=6P@=FEH;0#5:'1U
M;"!V:6AM`$AO;W9I:&T`5FEH;2!J82!L=6UI`%9I:&T@:F$@;'5M:0!*=6AU
M<VQI:R!K:6QD`%!R;W1S96YT`$QO90!,;V4@:VER:G4`2V%S('3U97-T:2!K
M=7-T=71A9&$@)7,_(%-E92!T;VEM:6YG(&]N('#V]G)D=6UA='4N`$MA<R!T
M]65S=&D@:W5S='5T861A(&MA<W5T86IA("5S(&%N9&UE9#\@4V5E('1O:6UI
M;F<@;VX@</;V<F1U;6%T=2X`5&%A<W1A8B!V:6EM87-E('1E9V5V=7-E`%;D
M<G-K96YD80!6Y')S:V5N9&$@9/QN86%M:6QI<V5D(&UE;OS\(&5L96UE;F1I
M9#H`5N1R<VME;F1A('!O<G1A86QI('9A861E.@!296=U;&%A<F%V86QD:7,`
M4W5H971E('-I<G9I:F$`3&%E('5U97-T:0!-Y')K=7-E9`!6Y&QI<V5D('-E
M<G9E<FED`%;D;&EN92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.@!%96UA;&1A`$5E;6%L9&$@8FQO:VL`2W5S='5T82!V965R9P!%96UA
M;&1A(&MU:G5N9'5S`$5E;6%L9&$@<&%A<@!+=7-T=71A('-A;'9E<W1A='5D
M('-K<FEP="!S97)V97)I(&%J=71I<V5S="!K871A;&]O9VES="X`165M86QD
M80!%96UA;&1A(&1O:W5M96YD:7-T`$MU<W1U=&$@:V%S=71A:F$`2W5S='5T
M82!K87-U=&%J83H@)7,`4.1R:6YG=6QE('!O;&YU9"!V]6EM86QI:R!V87-T
M871A+B!486=A<W1A=&D@=F5A:V]O9#H@`%-O;W9I=&%V870@=&5E;G5S="!E
M:2!L96ET=60N`%9A:F%L:6L@(B5S(B!P=75D=6(@)7,@<V5A9&ES='5S97,N
M`%9A:F%L:6L@(B5S(B!P=75D=6(@5D93('-E861I<W1U<V5S+@!686IA;&EK
M("(E<R(@<'5U9'5B('-E861I<W1U<V5S+@!+;VAU<W1U<VQI:R!VY&QI`%3\
M:&IE;F1A`$UU=61A('-A;&%S]6YA`%5N=7-T87-I;B!O;6$@<V%L87/U;F$`
M5&%A<W1A(&5E;&UI;F4@<.1R:6YG`%1U;&5M=7-E9`!486=A<VD@<V5A9&ES
M='5S<V4`2V]R9&$@=75T('-A;&%S]6YA`%)E=6YI;VX`5O5T82!K;VYF:6=U
M<F%T<VEO;VX@=&%G87-I`%)I8V@@5&5X="!%9&ET;W)I('-E861I<W1U<P!-
M]6ES=&%T=7-E9`!087)E;0!087)E;2!PY&ES`%!A<F5M860@=N3D<G1U<V5D
M`%]296$@<V5A9&5D+BXN`%)O;&P`4G5M965N:6$`4/;V<F$@,3@P`%#V]G)A
M('9A<V%K=6QE`%#V]G)A('!A<F5M86QE`%)E82!S96%D960`4F5A('-E861E
M9`!2:61U.@!*;V]N960`2F]O;F5D('1E:VEV860@:_5I9VD@<FED861E(&IA
M('9E97)G=61E('9A:&5L90!*;V]N960@=&5K:79A9"!A:6YU;'0@=F5E<F=U
M9&4@=F%H96QE`$IO;VYE9"!T96MI=F%D(&%I;G5L="!R:61A9&4@=F%H96QE
M`$OD:79I=&$`5F5N92!&]F1E<F%T<VEO;VX`4G5A;F1A`%,O34E-12!K<OQP
M=&]G<F%A9FEL:6YE(&%L;&MI<FD`4R]-24U%(&MR_'!T:71U9"!K:7)I`%-!
M4TP@875T96YT:6UI;F4@96D@;VQE('-A861A=F%L+@!335,@;/QH:7/U;G5M
M:60`4U%,(&OD<W5R:61A`%-13"!A=F%L9&ES(';DY')T=7-T92!L96ED;6ES
M96MS`%-32`#53DY%4U154P!37U%,(&OD<W5R:61A`$QA`%-A:6YT($AE;&5N
M80!386EN="!+:71T<R!J82!.979I<P!386EN="!,=6-I80!386EN="!0:65R
M<F4@:F$@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!J82!'<F5N861I:6YI9`!3
M86UA<R!R86%M:7,@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;R!4;VUE
M(&IA(%!R:6YC:7!E`%-A=&5L;&EI='-I9&4@:V%S=71A:F$`4V%U9&D@07)A
M86)I80!386QV97-T82``4V%L=F5S=&$@(B5S(@!386QV97-T82`E<P!386QV
M97-T82!S96%D:7-T=7,`4V%L=F5S=&$@9V5N97)E97)I='5D(&MO;F9I9W5R
M871S:6]O;B!02%`@<VMR:7!T:6YA('-E<G9E<FD@86IU=&ES<V4@:V%T86QO
M;V=I+@`E<R!K;VYF:6=U<F%T<VEO;VX@<V%L=F5S=&%T=60N`%!A:6=A;&1U
M<V4@=75E;F1A;6ES92!S:W)I<'0@<V%L=F5S=&%T=60@9F%I;&DZ("(E<R(N
M`$AA:G5S860@Y&EK97-H;V]D`%1E861U<P!/='-I;F<`3W1S:6YG=6UO;W1O
M<FED`%9A;&D@9F%I;&ED`%9A;&D@:W5U<.1E=@!686QI(&QI<V%T878@9W)U
M<'``5F%L:2!U=7,@;VUA;FEK`%9A;&D@<V5R=F5R`%9A;&D@;&ES871A=B!K
M87-U=&%J80!686QI(&OU:6L`5F%L:2!K]6EK(&MU=7#D979A(&MO;W-T:7-O
M<V%D+@!686QI(&]B:F5K=`#$<F$@=F%L:2!M:61A9VD`5F%L:2!V86IA;&EK
M=60@;>1R9VED(&MA<W1I9&5S="X@4VEI<R!S86%D(&YE960@:V]P965R:61A
M(&MI<FIA('-I<W-E+@!686QI(&MU=7#D979A(&5R86QD86IA.@!686QI(&MU
M=7#D979A(&5S:71U<W9I:7,Z`%9A;&D@:61E;G1I=&5E="!M:61A('-O;W9I
M9"!M=75T83H`5F%L:2!K96QL86%J82!E<F%L9&%J83H`5F%L:2!K96QL86%J
M82!E<VET=7-V:6ES.@!686QI(&MA:W,@<V]B:79A="!VY&QJ82X`5F%L:2!V
MY')V:7-K965M+@!686QI(&]M82!L96UM:6MK965L.@!386%D82!P<F]B;&5E
M;6D@:VER:F5L9'5S`%-A861A(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@:F$@36]N=&5N96=R;P!*Y')J96YU;6)E<@!397)V97)I
M(&%N9&UE9"!O;B!V86QE9"!V]6D@<'5U9'5V860N`%-E<W-I;V]N:61E(&AA
M;&1U<P!397-S:6]O;FD@240@;VX@865G=6YU9"X`4U]E<W-I;V]N:60`2'5L
M:P!-Y.1R82!A;F1M960@;6ES(';U:6UA;&1A=F%D('-U;"!O;6$@<&%R;V]L
M:2#D<F$@;75U=&$@:W5I('-A('-E;&QE('5N=7-T860N`%-E861I<W1A(';D
M;&ES960@<V5R=F5R:60@;6ED82!S;V]V:60@;VUA('!O<G1A86QI<R!K87-U
M=&%D82X`4&%N92!P86EK82!O;6$@:V5E;&4L(&%J87;V]FYD:2!J82!K=75P
MY&5V82!S96%D:7-T=7,N`$WDY')A(&]M82!A;&=R86ME;F1U<RP@=N1R=FES
M:V5E;2P@;&5H96O\;&IE(';D<G-K96YD86UI<V4@<V%G961U<R!J82!M=75D
M("!E<VET=7-E('-E861E9"X`4&%I9V%L9'5S`$]L96UA<V]L979A9"!P86EG
M86QD=7-E('5U96YD86UI<V4@<VMR:7!T:60`4&%R86UE971E<B!MY.1R86(@
M;6ET=2!V]6EM86QI:VMU(&%S=6MO:'1A.B``4V5I<VAE;&QI9`!/<W1L96UI
M;F4`3/QH:6MO:VMU=O5T90!+87,@96YA;75S96QE(&QI;FMI9&5L92!T=6QE
M:W,@;>3D<F%T82!K:6ER:VQA:'9I9#\`3N1I=&$`3N1I=&$@;VQE;6%S;VQE
M=F$@:F$@Y'-J82!G96YE<F5E<FET=60@:V]N9FEG=7)A='-I;V]N:2!E<FEN
M979U<VDN`$[D:71A('-I<W-E;&]G:6UI<V5L(&5E;&UI<V4@<VES<V5L;V=I
M;6ES92!A96=A`%!A:W4@=O5I;6%L=7-T(&]R:6=I;F%A;&D@<^1I;&ET86UI
M<V5K<P!.Y&ET82!V86QI:F%T`$[D:71A('1A8F5L:71O:6UI;F=U=&4@;65N
M_/QR:6)A`$[D:71A('9A<V%K=6P@)7,@;65N_/QD`$[D:71A('1A8F5L:2!L
M86AT<FD@;VUA9'5S=&4@9&EA;&]O9VD`3N1I=&$@=&%B96QI(&]M861U<W1E
M(&1I86QO;V=I`$[D:71A('1A8F5L:2!R96$@;VUA9'5S=&4@9&EA;&]O9VD`
M3N1I=&$@<&EL9&D@;VUA9'5S=&4@9&EA;&]O9VD`3N1I=&$@=7!L;V%D:0!(
M;V]V:6AM`$AO;6UI:W5L(&AO;W9I:&UA9`#5:'1U;"!H;V]V:6AM860`2&]O
M=FEH;6%D(/QM8G)U<VMO;FYA<P!+:71S96YD80!+:71S96YD82!K]6EG97!E
M86QT(&YA86)E<F)L;VMK92!V]6D@;FEH=71A(&YE960@965S="#D<F$`4VEE
M<G)A($QE;VYE`$QI:71U`$%L;&MI<FD`06QL:VER:F$@86QG;W)I=&T`4VEN
M9V%P=7(`4W5U<G5S`$KD=&$@:&]O;&1U<R!V86AE;&4`4VQO=F%K:VEA`%-L
M;W9E96YI80!,=6UI`%1I:&4@;'5M97-A9'4`5&EH961A9"!L=6UE<V%J=60`
M2&]M;6EK=6P@=&EH961A9"!L=6UE<V%J=60`U6AT=6P@=&EH961A9"!L=6UE
M<V%J=60`3'5M92!P86MS=7,Z(`!,=6UE('9E92UE:W9I=F%L96YT.B``4V%A
M;&]M;VYI('-A87)E9`!3;VUA86QI80!,875L=60@:F$@;'5U;&5T=7-E9`!3
M;W)T965R:6UI<VKD<FIE:V]R<F$@=F%L:6L`3.1H=&5A861R97-S`$SU=6YA
M+4%A9G)I:V$`3/5U;F$M175R;V]P82`H25-/+3@X-3DM,RD`3/5U;F$M1V5O
M<F=I82!J82!,]75N82U386YD=VEC:&D@4V%A<F5D`$SU=6YA<&]O;&ME<F$`
M5F%H92!L86AT<FET92!V86AE;`!686AE(&QA:'1R:2!S:7-U(&IA(.3D<F4@
M=F%H96P`17)A;&1A:F$`5F%H90!686AE9"!J82!V;V]D97)D=7,`2&ES<&%A
M;FEA`%+D;7!S<&]S=`!%<FEMY')K:61E('-I<V5S='5S`$5R86QD82!L86AT
M<FED`$QA:'5T82!V965R9P!,86AU=&$@<FED80!3<&]R=`!3<FD@3&%N:V$`
M4W1A;F1A<F0`4W1A<B!4<F5K`$%L9W5S86%S=&$`3W-A<FEI:R!V]6D@;6%A
M:V]N9`!/;&5K`%-A;'9E<W1U<V9O<FUA870`5.1N878@:F$@;6%J80!,Y&)I
M:F]O;FET=60@=&5K<W0`4W1R:6YG:61E(&QO96YD`$5R86QD82!D;VUE96X@
M86%D<F5S<VES=`!3=&EI;"!;0U-370!0_`!!;&%M:V%T86QO;V=I("(E<R(@
M96D@;&5I='5D+@!4965M80!+:6YN:71A`%-O;W8@(B5S(B!L:7-A;6ES96MS
M('/\<W1E96UI(&]N('-A;'9E<W1A='5D+B!382!E:2!S86$@<VES<V4@;&]G
M:61A(&5N;F4@:W5I('-I;G4@<V]O=B!O;B!H96%K<R!K:6ED971U9"X`06QA
M:6YD96MS`$SD:W,@:V]R9&$`(B5S(B!O;B!S_'-T965M:2!L:7-A='5D+@`B
M)7,B(&%N9&UE9"!O;B!S_'-T965M:7-T(&5E;6%L9&%T=60N`"(E<R(@;VX@
M:W5S='5T871U9"X`(B5S(B!O;B!S_'-T965M:7-T(&5E;6%L9&%T=60N`$MO
M;F9I9W5R871S:6]O;B!O;B!T86=A<VD@=O5E='5D+B!-=75T=7-T92!NY&=E
M;6ES96MS(';D<G-K96YD82!V86%D970N`$MO;F9I9W5R871S:6]O;FD@=F%R
M=6MO;W!I82#U;FYE<W1U<R!S86QV97-T861A+@!+;VYF:6=U<F%T<VEO;VYI
M9F%I;&D@=F%R=6MO;W!I82`E<R#U;FYE<W1U<R!S86QV97-T861A+@`B)7,B
M(&UU=71M:6YE(/5N;F5S='5S+@`E<R!K:7)J=71A;6EN92#U;FYE<W1U<P!3
M=61A86X`4VES=6MO:VMU=O5T90!0Y&EK97-E=/5U<P!0Y&EK97-E;&]O:F%N
M9P!0Y&EK97-E<&%I<W1E;&EN90!0Y&EK97-E=/5U<P!0Y&EK97-E=/5U<R]L
M;V]J86YG`%#D:6ME<V5T]75S.B``4.1I:V5S96QO;VIA;F<`4.1I:V5S96QO
M;VIA;F<Z(`#<;&%I;F1E:W,`5'5G:0!3=7)I;F%M:0!097)E:V]N;F%N:6UI
M`%-V86QB87)D(&IA($IA;B!-87EE;@!3=F%A<VEM86$`4F]O='-I`%-H=F5I
M=',`4_QN:W)O;FES965R:6UI<V4@;&]G:2!K=7-T=71A='5D`%-Y;F--3`!+
M:7)J879I9V$@;W1S:6YG=71I;F=I;75S=&5S`%/\_')I82!!<F%A8FEA(%9A
M8F%R:6EK`,1I:V5S971O<FT`5'5U;&EN92!J82#D:6ME<V5L:6YE`,1I:V5S
M97!U:&%N9W5D`$AO;6UI:W5L(.1I:V5S97!U:&%N9W5D`%135B!F86EL`%1A
M8F5L`%1A8F5L:2!O;6%D=7-E9`!486)E;&ET92!H=6QK`%1A8F5L:2!O;6%D
M=7-E9`!486EV86X`5&%I=F%N+"!(:6EN82!P<F]V:6YT<P!4861Z:6MI<W1A
M;@!486YS86%N:6$@W&AE;F1V86)A<FEI:P!!=F%N96UI;F4Z`%3V]F0`5&5L
M969O;FEN=6UB97(`5FEI;6%S92!T=6YN:2!T96UP97)A='5U<CH`5&5M<&5R
M871U=7(`5&5M<&5R871U=7(Z(`!496UP97)A='5U<CQB<B`O/B@E<TUA>"5S
M+R5S36EN)7,I("9D96<[)7,`36%L;&D@(B5S(B!E:2!L96ET=60N`$UA;&QI
M9&4@:&%L9'5S`%1E:W-T`$%I;G5L="!T96MS=`!496MS=&D@:F]O;F1U<P!4
M97AT=&]P`$YE`%1A:2`H5$E3+38R,"D`5&%I`%3D;F%M92!K_&QA<W1A;6%S
M="X`1E10(&QA:65N9'5S(&5I(&]L92!S86%D879A;"X`2&ES=&]R>2!S_'-T
M965M(&]N(';D;&IA(&S\;&ET871U9"X`2&]R9&4O2V]L86(@:6YT96=R871S
M:6]O;FEM;V]T;W(@96D@=&]E=&$@(B5S(BUI`$E-4U`@;&]G:2!A;&=VY.1R
M='5S=&%M:6YE(&YU<FIU<RX`36%I;G1E;F%N8V4Z.B!K;&%S<VD@;&%A9&EM
M:6YE(&YU<FIU<P!396%D971E(&%K96X@;VX@<W5L971U9"X@5N1L:G5N+@!+
M=6D@=&%H860@:V%S=71A9&$@]6EG=7-I+"!P96%B(&%D;6EN:7-T<F%A=&]R
M('-E861I<W1A;6$@</QS:79A(/5I9W5S=&4@<_QS=&5E;6DN`$%I;G5L="!A
M;'5M:6YE(&O\;&<`2V]N=&%K=&D@240@;G5M8G)I="!E:2!MY.1R871U9"P@
M:N1E=&D@=/QH:F%K<R!V]6D@<V5E('!U=61U8B!A;F1M96)A87-I<RX`2VER
M:F4@]6YN97-T=7,@;&ES861A('-I;G4@86%D<F5S<VER86%M871U<W-E+@!!
M;&QK:7)J87-T871U9"!K:7)J82!K;VYT<F]L;&EM:7-E:W,@;VX@=F%J82!E
M<F%L9&D@4$=0(&%L;&MI<FIA8FQO:VMI+@!*86]T=7-N:6UE:VER:F$@240@
M;VX@;>3D<F%M871A+"!JY&5T:2!T_&AJ86MS(';U:2!P=75D=6(@86YD;65B
M86%S:7,N`$IA;W1U<VYI;65K:7)I('!O;&4@;>3D<F%T=60N`$MR_'!T:6UI
M<V5K<R!O;B!V86IA('1U<G9A;&ES="!(5%10(/QH96YD=7-T+@!&86EL("5S
M('!E86MS('-I<V%L9&%M82`E<R!MY.1R86YG=70N`$9A:6P@)7,@<&5A:W,@
M<VES86QD86UA(&UI;F=E:60@)7,@;>3D<F%N9W5I9"X`1F%I;&D@96D@<V%A
M(&MO<&5E<FED82!I<V5E;F1A;&4@;W1S82X`1F%I;"!E:2!S:7-A;&1A;G5D
M(&%N9&UE:60N`$KD<F=N979A9"!S96QL92!M97-S86=E+W)F8S@R,B!K:7)J
M82!PY&ES960N`%3D:7-E:W)A86YI<F5Z:6EM:2!K87-U=&%M:6YE('1E:VET
M86(@<')O8FQE96UE($EN=&5R;F5T($5X<&QO<F5R:7,@=.1N=2!S96QL92!V
M965B:6QE:&ET<V5J82!V:6=A9&5L92P@;6ED82!M96EL(&5I(/5N;F5S='4@
M;6%H82!S=7)U9&$N($5S:6YE9&$@=O5I8B!LY&)U(&MU:G5T:7-E<RP@961I
M=&]R:2!F=6YK='-I;V]N:61E('!U=61U;6ES="!J82]V]6D@=F5E8FEL96AI
M='-E:F$@:G5H=7-L:6MK=2!K:6YN:6IO;VMS;6ES="X@2W5I('-I;G4@87)V
M=71I(&]P97)A='-I;V]N:6MS(&]N(%=I;F1O=W,@.7@L('-I:7,@;VX@=N1G
M82!T]65NY&]L:6YE(&5T('-A860@(D=E;F5R86P@4')O=&5C=&EO;B!&875L
M="(@=F5A=&5A=&4@:F$@<&5A9"!A<G9U=&D@=&%A<VOD:79I=&%M82Y<;EQN
M4VEN9"!O;B!H;VEA=&%T=60N($ML]7!S82!/2RP@:W5I('-O;W9I9"!S:6ES
M:VD@=.1I<V5K<F%A;FER97II:6UI('!R;V]V:61A+@!)9&5N=&ET965T("(E
M<R(@;VX@:W5S='5T871U9"X`06EN=6QT('9A<V%K(&O\;&<`0W)Y<'1?<&=P
M.CH@:VQA<W-I(&IA;VMS('!E86(@;VQE;6$@;>3D<F%T=60@1VYU4$<@<')O
M9W)A;6UI(&%S=6MO:'0N`$MI<FD@;6ES('-A861E=&D@)7,@86%D<F5S<VEL
M92`E<R!T965M86=A("(E<R(@;VX@879A='5D+@I3964@96D@9V%R86YT965R
M:2!E="!K:7)I(&SD8FD@;&]E=&D@=O5I('-E;&QE<W0@87)U('-A861I+@!.
M:6UI(&UI9&$@:V%S=71A9&$@961I=&]R:2!L96AE9V$@;&EN:VEM:7-E;`!6
MY&QJ861E(&%R=B!P96%B(&]L96UA(&%R=BX`2&]R9&5?0W)Y<'1?<VUI;64Z
M.B!K;&%S<R!V86IA8B!O<&5N<W-L(&UO;V1U;&ET+@!%96QI<W1U<W0@(B5S
M(B!E:2#U;FYE<W1U;G5D('-A;'9E<W1A9&$L(&MU;F$@86YD;65T92!H=6QK
M(/QL971A<R!S=75R:6UA(&QU8F%T=60@;>3D<F$`4V5D82!T_/QP:2!A;F1M
M971E("@E<RD@=F%A=&%M:7-E:W,@=F%J86QI:VMU('!R;V=R86UM:2!E:2!L
M96ET=60@<_QS=&5E;6ES="X`2G5T=6WD<FL@<&5A8B!O;&5M82#\:W,@;>1R
M:RX`06EN=6QT('9A<V%K(&IA('!A<F5M(&O\;&<`06EN=6QT('!A<F5M(&O\
M;&<`17)A;&1A:F$@<&5A8B!O;&5M82#\:W,@;>1R:RX`4V5R=F5R("(E<R(@
M;VX@:W5S='5T871U9"X`4V5R=F5R("(E<R(@;VX@<V%L=F5S=&%T=60N`"5S
M(&QI:71U;6ES<V]O=B!O;B!E96UA;&1A='5D+@!-Y.1R871U9"!R:61A("@E
M9"D@<&]L92!O;&5M87,N`$WDY')A='5D(')I9&$@<&]L92!O;&5M87,N`$%J
M=71I<W0@9F%I;&D@(B5S(B!P;VQE(&]L96UA<RX`4VEN=2!S:7-E<W1A='5D
M('1E:W-T(&5I(&MA='1U(&5K<F%A;FEL(&]L979A9V$N`$%I;G5L="#\;&5M
M:6YE(&IA(&%L=6UI;F4@:_QL9P!!:6YU;'0@_&QE;6EN92!K_&QG`%-A861E
M='5D(&%N9&UE9"!O;B!V86AE<&5A;"!K86]T<VD@;.1I;G5D+@!386%D971U
M9"!F86EL:2!E:2!S86%N=60@<V%L=F5S=&%D82X`=V5A=&AE<BYC;VT@8FQO
M:VL@96D@;VQE(&OD='1E<V%A9&%V+@!+=6IU;F1U<W1E(&MA=&%L;V]G:2`B
M)7,B(&5I(&QE:71U9"X`16D@;VQE(&UI9&%G:2!S96%D:7-T861A+@!+:7)J
M86P@96D@;VQE('9A:&5T=6QT(&5S:71A=&%V86ED(&]S:2X`4V5L;&5S(';D
M;&IA<R!O;B!L:6EA;'0@<&%L:G4@;>1R:V4N(%-A('-I<V5S=&%S:60@)7,@
M;>1R:VD[(&QU8F%T=60@<&]L92!R;VAK96T@:W5I("5S+@`B)7,B(&QI<V%M
M:7-E;"!S_'-T965M:2!T96MK:7,@<')O8FQE96TZ("5S`$MA<W5T86IA("(E
M<R(@86YD;65T92!S_'-T965M:7-T(&5E;6%L9&%M:7-E;"!T96MK:7,@<')O
M8FQE96TZ(``B)7,B(&5E;6%L9&%M:7-E;"!S_'-T965M:7-T('1E:VMI<R!P
M<F]B;&5E;3H@`"(E<R(@;75U=&UI<V5L('1E:VMI<R!P<F]B;&5E;3H@)7,`
M1F%I;&D@;&%A9&EM:7-E;"!S97)V97)I<W-E('1E:VMI<R!P<F]B;&5E;3H@
M)7,@96D@;&%E='5D+@!&86EL:2!L86%D:6UI<V5L('-E<G9E<FES<V4@=&5K
M:VES('!R;V)L965M.B`E<R!O;&D@<W5U<F5M(&MU:2!V]6EM86QD86(@<&EI
M<F%N9R`H)60@8F%I=&DI+@!&86EL:2!L86%D:6UI<V5L('-E<G9E<FES<V4@
M=&5K:VES('!R;V)L965M.B`E<R!L865T:2!A:6YU;'0@;W-A;&ES96QT+@!3
M96QL92!K:7)J82!O<V$@97-I=&%M:7-E;"!T96MK:7,@=FEG80!+;VYT86MT
M86YD;65T92!I;7!O<G1I;6ES96P@=&5K:VES('9I9V$N`&E#86QE;F1A<B=I
M(&%N9&UE=&4@:6UP;W)T:6UI<V5L('1E:VMI<R!V:6=A+@!396%D:7-T=7-E
M('9O<FUI;"!E<VEN97,@=FEG82X@16AK(&KD='-I9"!TY&ET;6%T82!M]6YE
M(&MO:'5S='5S;&EK=2!VY&QJ82X`4V]O=FET=60@86%D<F5S<VER86%M871U
M(&]P97)A='-I;V]N:2!S;V]R:71A;6ES96P@=&5K:VES('9I9V$N(%!A;'5N
M('!R;V]V:2!H:6QJ96T@=75E<W1I+@!+;VYT86MT86YD;65T92!U=65N9&%M
M:7-E;"!T96MK:7,@=FEG82X@4&%L=6X@<')O;W9I(&AI;&IE;2!U=65S=&DN
M`$IA;W1U<VYI;65K:7)J82!U=65N9&%M:7-E;"!T96MK:7,@=FEG82X@4&%L
M=6X@<')O;W9I(&AI;&IE;2!U=65S=&DN`%-E92!)34%0('-E<G9E<B!E:2!V
M]6EM86QD82!K875S=&%D92!J86=A;6ES="X`4V5E(&5I(&[D:2!O;&5V870@
M:V]R<F%L:6L@4D%2(&%R:&EI=BX`4V5E(&5I(&[D:2!O;&5V870@:V]R<F%L
M:6L@6DE0(&9A:6PN`%-E92!E:2!NY&D@;VQE=F%T(&ME:'1I=B!K86%R9&D@
M;G5M8F5R+@!3964@9')A:79E<B!V]6EM86QD86(@<V%A=&$@<_5N=6UE:60@
M;.1B:2!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L;"YC;VTI(&S\_'-I
M+"!K87-U=&%D97,@2%144"!!4$ET`%-E92!D<F%I=F5R(';U:6UA;&1A8B!S
M86%T82!S]6YU;65I9"!LY&)I(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&S\
M_'-I+"!K87-U=&%D97,@2%144"!!4$ET+@!3964@9')A:79E<B!V]6EM86QD
M86(@<V%A=&$@<_5N=6UE:60@;.1B:2!S;7,R96UA:6P@*&AT='`Z+R]S;7,R
M96UA:6PN8V]M*2!L_/QS:2P@:V%S=71A9&5S($A45%`@05!)="X`4V5E(&1R
M86EV97(@=O5I;6%L9&%B('/U;G5M:71E('-A871M:7-T(%--5%`@<')O=&]K
M;VQL:6=A(&SD8FD@5F]D869O;F4@271A;'D@;/S\<VDL(&%I;G5L="!6;V1A
M9F]N92!N=6UB<FET96QE+B!396QL96MS(&]N('9A:F$@5F]D869O;F4@271A
M;'D@92UP;W-T:2!K;VYT;W0@*&AT='`Z+R]W=W<N,3DP+FET*0!3964@=N1L
M:2!O;B!K;VAU<W1U<VQI:RX`4V5E(';D;&D@=O5I8B!S:7-A;&1A9&$@=F%I
M9"!TY&ES87)V92X`4V5E(';D;&D@=O5I8B!S:7-A;&1A9&$@86EN=6QT(&YU
M;6)R96ED(&IA(&MO;VQO;FET+@!3964@=N1L:2!V]6EB('-I<V%L9&%D82!A
M:6YU;'0@:V%H96MS86YD87)V92X`4V5E(';D;&D@<&5A8B!O;&5M82!K;VUA
M9V$@=O5I('3\:&EK=6=A(&5R86QD871U9"!TY&ES87)V=61E(&QO96YD`%-E
M92!VY&QI('!E86(@;VQE;6$@:V]R<F5K=&YE(&%R=BX`4V5E(';D;&D@<&5A
M8B!S:7-A;&1A;6$@=N1R=FEK;V]D:2!21T(@2&5X(&MU:G5L+"!NY&ET96MS
M("<C,3(S-&%F)RX`4V5E('9O<FT@;VX@:G5B82!LY&)I('3V]G1A='5D+@!3
M964@;VX@)7,N`%-E92!O;B!+;VQA8B!'<F]U<'=A<F4@;V)J96MT+B!396QL
M92!O8FIE:W1I('9A871A;6ES96MS('9A:F%D(&4M<&]S=&D@:VQI96YT:2!M
M:7,@;?5I<W1A8B!+;VQA8B!'<F]U<'=A<F4@9F]R;6%A=&DN(%-E;&QI<W1E
M(&4M<&]S=&D@:VQI96YT:61E(&YI;65K:7)J82!L96EA9"!A861R97-S:6QT
M("5S`%-E92!K:7)I(&]N(&MI<FIU=&%T=60@;>1R9VES=&EK=7,@*"5S*2!M
M:7,@97)I;F5B('-I;G4@;VUA<W0N`%-E92!A<G8@<&5A8B!O;&5M82!VY&AE
M;6%L="#\:W,N`%-E92!S97)V97(@96D@;?5I<W1A(&QA:'1I('!A:VMI9&$@
M>FEP(&IA(&=Z:7`@9F%I;&4N`%-E92!S_'-T965M(&]N('!R865G=2!VY&QJ
M82!L_&QI=&%T=60N`%-E;&QE(&MO:&$@<&5A;"!P96%B(&]L96UA(&%R=BX`
M4V5E(&%K96X@='5L96(@879A9&$@4V5A9&5T92!A:VYA<W0`Q&EK90!(96QP
M9&5S:P!!96<`5/;V86IA=&%B96P`06IA(&5S:71U<P!!:F$@=F%L:6L`261A
M+51I;6]R`%!E86QK:7)I`%!E86QK:7)I("AT;V]L=&EP*0!+96QL96QE`$UI
M=&UE(&]B:F5K=&D@=F%L:6UI<V5K<R!H;VEA(&%L;"!#=')L("A00RD@=O5I
M($-O;6UA;F0@*$UA8RD@:VQA:'9I(&IA(&ML]7!S82!O8FIE:W1I9&5L+@!4
MY&YA`$A434P@:V]O9&D@<F5Z:6EM`%1O9V\`5&]K96QA=0!(;VUM90!4;VYG
M80!6:6EM87-T96P@;6EN=71I=&5L(&]N(&QI:6=A('!A;&IU(&YU<FIU;G5D
M('-I<W-E;&]G:6UI<VDN`-QL97,`4&5A;&UI<V5S(')A86UI<R`H7W1O<"D`
M5/5L:V5D`%1R:6YI9&%D(&IA(%1O8F%G;P!4]61E(';U:2!V86QE`%1E`%1U
M;F5E<VEA`%3\<F=I`%3\<F=I("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`
M5'5R:W,@:F$@0V%I8V]S`%1U=F%L=0!+:7)J=71A(&]M82!V86QI:SH`558M
M:6YD96MS.B``55),`%-I;G4@<VMR:7!T:2!KY'1T971O:6UE=&%M:7-R87!O
M<G1I(%523`!54DPZ`%5G86YD80!5:W)A:6YA`$5I('#DY'-E(&QI9VD@5D93
M(&MA=&%L;V]G:6QE+@!4Y&EE;F1A=F$@:V%S=71A:F%I;F9O(&QI<V%M:6YE
M(&QI:71U;6ES96P@96D@]6YN97-T=2X`16D@<V%A(&UU=71A(%9&4R!F86EL
M:2`B)7,B(/5I9W5S:2X`16D@<V%A(&UU=71A(%9&4R!F86EL:2`E<R\E<R#U
M:6=U<VDN`$5I('-A82!M:6YN82!K871A;&]O9VD@)7,N`$9A:6QI("(E<R(@
M<W5U<G5S="!P;VQE(';U:6UA;&EK(&MO;G1R;VQL:61A+@!&86EL:2`B)7,O
M)7,B('-U=7)U<W0@<&]L92!V]6EM86QI:R!K;VYT<F]L;&ED82X`16D@<V%A
M(/QH96YD=7-T(%-13"!S97)V97)I9V$N`%-33"#\:&5N9'5S92!A;&=A=&%M
M:6YE(&YU<FIU<RX`5D93(&9A:6QI(&MO<&5E<FEM:6YE(&YU<FIU<RX`5D93
M(&MA=&%L;V]G:2`B)7,B(&QO;VUI;F4@;G5R:G5S+@!61E,@:V%T86QO;V=I
M(&QO;VUI;F4@;G5R:G5S+@!61E,@9F%I;&D@;&]O;6EN92!N=7)J=7,N`%9&
M4R!K875S=&$@(B5S(B!L;V]M:6YE(&YU<FIU<RX`16D@<V%A(&QU=6$@=/QH
M:F$@5D93(&9A:6QI+@!,86AT:7!A:VMI;6EN92!N=7)J=7,N`"(E<R(@96D@
M<V%A(&MU<W1U=&%D82P@:V%T86QO;V<@96D@;VQE('3\:&DN`$5I('-A82!K
M=7-T=71A9&$@(B5S(CH@)7,N`"5S(&5I('-A82!K=7-T=71A9&$L(&MA=&%L
M;V]G(&5I(&]L92!T_&AI`%9&4R!K871A;&]O9VEP=74@:W5S='5T86UI;F4@
M;G5R:G5S+@!61E,@:V%T86QO;V=I(&MU<W1U=&%M:6YE(&YU<FIU<RX`16D@
M<V%A(&MU<W1U=&%D82!61E,@:V%T86QO;V=I.B`E<RX`16D@<V%A(&MU<W1U
M=&%D82!61E,@9F%I;&D@(B5S(BX`5D93(&9A:6QI(&MU<W1U=&%M:6YE(&YU
M<FIU<RX`16D@<V%A(&MU<W1U=&%D82!61E,@:V%U<W1A("(E<R(N`$5I('-A
M82!K=7-T=71A9&$@5D93:2!R96MU<G-I:79S96QT.B`E<RX`2F]O:W-V870@
M:V%T86QO;V=I(&5I(/5N;F5S='4@='5V87-T861A+@!%:2!S86$@:^1T=&4@
M<V5R=&EF:6MA861I(/QK<VEK87-J=0`E<R!D969I;FET<VEO;VYI(&QA861I
M;6EN92!N=7)J=7,N`%9&4R!F86EL:2#\;6)E<G3U<W1M:6YE(&YU<FIU<RX`
M16D@<V%A(&%V861A(%9&4R!F86EL:2`B)7,B+@!%:2!S86$@879A9&$@5D93
M(&9A:6QI(&UU=71M:7-E:W,N`%9&4R!F86EL:2!A=F%M:6YE(&YU<FIU<RX`
M4&%K:71U9"!A<FAI:79I(&%V86UI;F4@;G5R:G5S+@!%:2!S86$@;'5G961A
M(%9&4R!F86EL:2`H9FEL97-I>F4H*2!N=7)J=7,I+@!%:2!S86$@;'5G961A
M(%9&4R!F86EL:2`H9V5T1FEL95-I>F4H*2!N=7)J=7,I+@!%:2#U;FYE<W1U
M(&QU9V5D82!F86EL:3H@`'9F<W)O;W0@:V%T86QO;V=I(&QU9V5M:6YE(&YU
M<FIU<RX`)7,@96D@<V%A(/QM8F5R(&YI;65T861A("5S+6MS.B!S:6AT:V%U
M<W0@;VX@:G5B82!O;&5M87,N`%9&4R!K871A;&]O9VD@_&UB97)N:6UE=&%M
M:6YE(&YU<FIU<RX`16D@<V%A(/QM8F5R(&YI;65T861A(%9&4R!K871A;&]O
M9VDZ("5S`$5I('-A82#\;6)E<B!N:6UE=&%D82!61E,@9F%I;&D@(B5S(BX`
M16D@<W5U9&$@_&UB97(@;FEM971A9&$@5D93(&9A:6QI("5S+R5S+@!61E,@
M9F%I;&D@_&UB97)N:6UE=&%M:6YE(&YU<FIU<RX`16D@]6YN97-T=2!KY&EV
M:71A9&$@)VUK:7-O9G,G+@!3961A(%=O<F1I(&1O:W5M96YT:2!O;B!V]6EM
M871U('3U;&=E;F1A9&$`16D@<V%A(&MI<FIU=&%D82!61E,@9F%I;&D@(B5S
M(BX`16D@<V%A(&MI<FIU=&%D82!61E,@9F%I;&D@*&-O<'DH*2!N=7)J=7,I
M+@!61E,@9F%I;&D@86YD;65T92!S86QV97-T86UI;F4@;G5R:G5S+@!%:2!S
M86$@:VER:G5T861A(%9&4R!F86EL:2P@:V5T=&%K=F]O="!LY&AE8B!L]6AK
M:2X`06QL86IO;VYI='5D('1E:W-T`%1A87-T82!A;&=S96ES`%;U=&%B('9I
M:6UA<V4@=&5G979U<V4@=&%G87-I`$]O=&%M871U('9A<W1U<R!S97)V97)I
M;'0@_&AE;F1U<V4@;&]O;6ES96PZ(`!/;W1A;6%T=2!V87-T=7,@<V5R=F5R
M:6QT.B``2V%T96=O;W)I871A`%5N:6-O9&4@*%541BTX*0!!<F%A8FEA(-QH
M96YD96UI<F%A9&ED`%-U=7)B<FET86YN:6$`06UE97)I:V$@W&AE;F1R:6EG
M:60`06UE97)I:V$@W&AE;F1R:6EK:61E(';D:6ME<V%A<F5D`-QH:6MU9`!4
M=6YD;6%T=0!4=6YD;6%T=2!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!4
M=6YD;6%T=2!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!-Y.1R871I
M('1U;F1M871U(&%S=6MO:'0N`%1U;F1M871U(&MA<W5T86IA;FEM:2!J82!S
M86QA<_5N;F$N`-QH96YD82!S964@96QE;65N="!L86AT:2X`3FEM971U`-5I
M9W5S=&5T82!S:W)I<'1I9"!E:2!S86$@='5R=F%K86%L=71L=7-T96P@<')O
M9W)A;7-E;'0@<V]O<FET861A(&SU:6MA;6ES="]K;&5E<&EM:7-T+B!+=6D@
M:VSU<'-A9"!/2RP@;N1E9"!M;WII;&QA+F]R9R!T96AN:6QI<W0@<V5L9VET
M=7-T(&MU:61A<R!L=6)A9&$@<VMR:7!T:61E;"!L]6EK97!U:'9R:70@:V%S
M=71A9&$N`$5E;6%L9&$@=N1R=@!4;V5T86UA=&$@;&%I96YD=7,`2VEN;FET
M80!-=75D82`E<P!-=75D82!K87-U=&%J80`B)7,B(&UU=61E='5D+@!5=65N
M9'5S92!S:W)I<'0@:W5S='5T871U9"X`3&%E('-E<G9E<FES<V4`2_5I:R!R
M86ME;F1U<V4@<&%I9V%L9'5S9F%I;&ED(&]N('-E<G9E<FES<V4@;&%E='5D
M+@!,861I;F$@<W5U<G3D:&5D`%-U=7)E9"!R;V]M82!N=6UB<FED`%5R=6=U
M86D`2V%S=71A('!R865G=7-T.B`E<P!+87-U=&$@4U-,:0!+87-U=&$@:G5H
M=6P@:W5I(&YI;6DO<V%L87/U;F$@24U34"!S97)V97)I<R!O;B!E<FEN978N
M`$MA<W5T86IA`$MA<W5T86IA;"`E<R!E:2!O;&4@;'5B871U9"`E<RX`2V%S
M=71A:F%H86QD=7,`2V%S=71A:F$@<V5A9&ES='5S`$MA<W5T86IA(')E9VES
M=')E97)I;6EN90!396QL97,@<V%I9&ES(&MA<W5T86IA=&4@<F5G:7-T<F5E
M<FEM:7-T(&5I(';U:6UA;&1A=&$N`$MA<W5T86IA:V]N=&]T(&5I(&QE:71U
M9`!+87-U=&%J86YI;6D`2V%S=71A:F%N:6UI("(E<R(@;VX@:G5B82!O;&5M
M87,N`$MA<W5T86IA;FEM:3H`2V%S=71A:F%N:6UI.@!+87-U=&%J860@<_QS
M=&5E;6ES.@!5<V)E:VES=&%N`%9&4R!K871A;&]O9VD@<&]L92!O;&5M87,N
M`%!U:&MU<P!/;&5M87-O;&5V860@:V]R<F5K='-E9"!A<W5K;VAA9"!O;CH@
M`$ME:'1I=G5S`$UI;G5T:71E(&%R=B!P<F%E9W5S97-T(&AE=&ME<W0@86QA
M=&5S+@!6Y.1R='5S(/QL971A8B`E<R!M86MS:6UU;7!I:VMU<V4N`%;DY')T
M=7-E9`!6Y.1R='5S960@;6EL;&4@:'5L9V%S="!V86QI9&$`5F%N=6%T=0!-
M=75T;&EK`%9E;F5T<W5E96QA`$MO;G1R;VQL:6UI;F4@;G5R:G5S("T@<V5E
M(&MI<FD@=O5I8B!O;&QA('!A:&%T86AT;&EK=6QT(&UU=61E='5D+@!*Y')J
M96YU;6)E<@!697)S:6]O;FEH86QD=7,`5F5R=&EK86%L;F4@:F]O;F1U<P!6
M97)T:6MA86QN92!V;V]D97)D=7,`5F5R=&EK86%L;F4Z`%;D9V$@:_5R9V4`
M5FEE=&YA;0!6:65T;F%M:2`H5DE30TE)*0!686%T82`E<P!686%T82!VY&QI
M<W0@=F5E8FEL96AT90!686%T82!K=6D@)7,`0G)I=&D@3F5I='-I<V%A<F5D
M`%5302!.96ET<VES86%R960`3N1H=&%V=7,`3N1H=&%V=7,Z(`!6;V1A9F]N
M92!)=&%L>2#\;&4@4TU44`!(3TE!5%53`$A/24%455,A(2$@2U535%5402!3
M2U))4%0@2\13251322!+051!3$]/1TE35"`E<RX`5TE.(/QL92!(5%10`%=A
M;&QI<R!J82!&=71U;F$`2&]I871U<P!+;P!);&UA96YN=7-T=7,`26QM86%N
M9&UE:60@<&%K=6(`5V5A=&AE<BYC;VT`5F5E8@!6965B:7-A:70`2V]R9"!N
MY&1A;&%S`%1E<F4@='5L96UA<W0`5&5R92!T=6QE;6%S="`E<RUI`%1E<F4@
M='5L96UA<W0L("5S`$SDY&YE("A)4T\M.#@U.2TQ*0!,Y.1N92`H25-/+3@X
M-3DM,34I`$SDY&YE+5-A:&%R80!-:6QL:7-E(')A:V5N9'5S92!P96%K<R`E
M<R!PY')A<W0@<VES<V5L;V=I;6ES="!A=F%M83\`36EL;&ES="!MY')K:2!K
M87-U=&%T86MS92!E<F%L9&%J86YA/P!-:6QL:7-T(&WD<FMI(&MA<W5T871A
M:W-E(&IU='5MY')G:6YA/P!7:&5R96ES($%U<W1R86QI82!K86%R=`!-:6QL
M:7-E9"!F86%S:60`36EL;&ES96ED('!L=6=I;F%I9"!L=6)A9&$@4FEC:"!4
M97AT(&5D:71O<FES+@!,86EU<P!,86EU<R!#4U,@_&AI:W5T97,`)7,@;65N
M_/P@;&%I=7,@=F%S86MU;"`H:&%K:V%B(&WU:G5M82!JY')G;6ES96P@<VES
M<V5L;V=I;6ES96PI.@!486)E;&D@;&%I=7,`3&%I=7/\:&EK`$QA:75S.@!7
M:6MI`%1U=6P`2&]M;6EK=6P@='5U;`!4=75L92!K:6ER=7,@<_5L;65D97,`
M5'5U;#H`5'5U;#H@`%1A<FMU<P!3;V]V:6YI;65K:7)I`%3V]@!4]O9K;VAA
M(&%A9')E<W,`5/;V=&5L969O;@!296%S("5D(&]N('9A;&4@87)V(';D;&IU
M+B!096%K<R!O;&5M82`E9"P@86=A(&]N("5D+@!686QE(&%R=B!VY&QJ=2X@
M4&5A:W,@;VQE;6$@)60L(&%G82!O;B`E9"X`5F%L92!A;&=U<W!U;FMT("5D
M(%9&4R!F86EL:2!L=6=E;6ES96PN`%@M4F5F`%@U,#EV,R!P]6AI;&ES960@
M<&EI<F%N9W5D`%@U,#EV,R!V]71M92!L86EE;F1A='5D(&MA<W5T=7,`6#4P
M.78S('-U8FIE:W1I(&%L=&5R;F%T:6EV;F4@;FEM:0!8-3`Y=C,@<W5B:F5K
M=&D@=O5T;64@:61E;G1I9FEK86%T;W(`6#4P.78S(&QA:65N9'5S960`04$`
M04%!00!986AO;R$@:V%A<G0`2V]R9"!A87-T87,`2F5E;65N`$IA:`!*86@L
M(&]L96X@;O5U<P!/;&5D(%1%2U-425)%6DE)34E3+B!+;/5P<V$@6SP^72!E
M="!M:6YN82!T86=A<VD@5UE325=91R!R97II:6UI+@!%:2!O;&4@;'5B871U
M9"!L=75A(')O:&ME;2!K=6D@)60@8FQO:VMI+@!382!E:2!O;&4@<VES<V4@
M;&]G:71U9"X`4VEN=2!TY&ES;FEM:2!E:2!V]6D@<VES86QD861A("=<)R!M
MY')K:2X`4V$@96D@<VES97-T86YU9"!K;W)R96MT<V5T(&4M<&]S=&D@86%D
M<F5S<VDN`%-A(&5I('-E861N=60@:6UP;W)D:71U9"!F86EL:2!VY&QJ=2!V
M87-T879U<W-E("5S(';D;&IA9&5G82X`4VEN9"!L;V=I=&D@=N1L:F$N`%-A
M('!E860@<VES97-T86UA(&ME:'1I=F$@;6]B:6EL=&5L969O;FD@;G5M8G)I
M(&UI<R!S:7-A;&1A8B!A:6YU;'0@;G5M8G)E:60@:F$@;6EL;&4@86QG=7-E
M<R!V]6EB(&]L;&$@)RLG(')A:'9U<W9A:&5L:7-E('-U=6YA:V]O9&D@='5N
M;G5S96YA+@!382!P96%D('-I<V5S=&%M82!K;W)R96MT<V4@=N3D<G1U<V4N
M`$QI:71U;6ES92!L=6)A;6ES96MS('!E860@<V5A9&ES=&%M82!$871A5')E
M92!S_'-T965M:2X`4V$@<&5A9"!S96%D:7-T86UA(%9&4R!S_'-T965M:2X`
M16YN92!S86%T;6ES="!O;&5K<R!T87)K('!R;V)L965M:2!K:7)J96QD861A
M+@!382!P96%D('-I<V5S=&%M82!54DQI(&MU:'4@<V5E(&QI;FL@=FEI=&%B
M`%!E860@;>3D<F%M82!K=7-T=71A=&%V82!S97)V97)I+@!096%D(&WDY')A
M;6$@:V%S=71A:F%N:6UE(&UI9&$@=/QH:F5N9&%D82X`4&5A9"!MY.1R86UA
M(&MA<W5T86IA;FEM92!M:61A(&5E;6%L9&%D82X`4&5A9"!MY.1R86UA(&MA
M<W5T86IA;FEM92!M:61A(&QI<V%D82X`4&5A9"!MY.1R86UA(&MA<W5T86IA
M;FEM92!M:61A(&UU=71A+@!096%D(&WDY')A;6$@=&5G979U<V4L(&UI9&$@
M<V]O=FED('1E:&$N`%!E860@<VES97-T86UA('5U92!K871E9V]O<FEA(&YI
M;64N`%!E860@<VES97-T86UA($ET86%L:6$@=&5L969O;FEN=6UB<FD`4VEN
M=2`E<R!S97-S:6]O;B!O;B!A96=U;G5D+B!086QU;B!L;V=I('5U97-T:2!S
M:7-S92X`4VEN=2!E+7!O<W1I(&%A9')E<W,Z`%-I;G4@<V%A=&IA(&%A9')E
M<W,Z`%-I;G4@:6YF;P!3:6YU(&EN=&5R;F5T:6%A9')E<W,@;VX@)7,@<V5S
M<VEO;VYI(&IO;VMS=6P@;75U='5N=60N(%1U<G9A;&ES=7-E('1A9V%M:7-E
M:W,@<&5A9"!U=65S=&D@<VES<V4@;&]G:6UA+@!3:6YU(&YI;6D`4VEN=2!A
M=71E;G1I;6ES<_QS=&5E;2!E:2!V]6EM86QD82!K87-U=&%J86ED(&QI<V%D
M82X@2W5I('-O;W9I9"!(;W)D92!A8FEL(&MA<W5T86IA:60@:&%L;&%T82P@
M<&5A9"!K87-U=&%M82!T96ES='-U9W5S="!A=71E;G1I;6ES<_QS=&5E;6DN
M`%-I;G4@875T96YT:6UI<W/\<W1E96T@96D@=O5I;6%L9&$@:V%S=71A:F%T
M92!N:6UE:VER:F$@;N1H82P@=O5I(&]N('-E92!V]6EM86QU<R!M:6YG:6P@
M;75U;"!P]6AJ=7-E;"!VY&QJ82!L_&QI=&%T=60N`%-I;G4@=F5E8FEL96AI
M='-E:F$@;N1I8B!O;&5V870@)7,@<V5S<VEO;VYI(&IO;VMS=6P@;75U='5N
M=60N(%1U<G9A;&ES=7-E('1A9V%M:7-E:W,@<&5A9"!U=65S=&D@<VES<V4@
M;&]G:6UA+@!3:6YU('9E96)I;&5H:71S96IA(&5I(';U:6UA;&1A('-E9&$@
M;VUA9'5S="!K87-U=&%D82X`4VEN=2!V965B:6QE:&ET<V5J82!E:2!V]6EM
M86QD82!N:6EM;V]D:2!T<OQK:VED82X@5F%J=71A('1R_&MK:6UI<V5K<R!#
M;VYT<F]L*U`@=O5I($-O;6UA;F0K4"X`4VEN=2!A:F%V]O9N9#H`4VEN=2!V
M86EK96ED96YT:71E970@;VX@;75U9&5T=60N`%-I;G4@=F%I:V5I9&5N=&ET
M965T.@!3:6YU('3D:65L:6L@;FEM:3H`4VEN=2!S:7-S96QO9VEM:6YE(&]N
M(&%E9W5N=60N`%-I;G4@=75S("5S('-A;&%S]6YA(&]N.B`E<P!-=75D871U
M<V5D(&]N('-A;'9E<W1A='5D('-E;&QE('-E<W-I;V]N:2!L]7!U;FDN`$UU
M=61A='5S960@;VX@<V%L=F5S=&%T=60N`%-I;G4@<V%L87/U;F$@;VX@=F%H
M971A='5D`%-I;G4@<V%L87/U;F$@;VX@=F%H971A='5D+"!V86%T82!O;6$@
M92UP;W-T:2!J82!L;V=I('-I<W-E('5U92!S86QA<_5N86=A+@!3:6YU('-A
M;&%S]6YA(&]N(&%E9W5N=60N`%-I;G4@=N1L:7-E9"!S97)V97)I9#H`2G5G
M;W-L86%V:6$`6F%I<@!386UB:6$`6FEM8F%B=V4`6FEP<'D`6U!E:61A(&]S
M=6YD871U9"!T96MS=%T`6TAO<F1E('!R;V)L965M70!;3N1I=&$@;W-U;F1A
M='5D('1E:W-T:2`M`%M.Y&ET82!O<W5N9&%T=60@=&5K<W1I("T@)7,@<FED
M85T`6W)I9&$@)7,@)7,M<W1=`%](86QD=7,`2^1S=5]R:61A`%]$871A5')E
M90!?2W5S='5T82!R:61A`%]'<G5P:60`05]B:0!?4&EL9&D@;VUA9'5S960N
M+BX`7TQO9VD@<VES<V4`7TQO9VD@=N1L:F$`7TUU=61A(&QI;FMI+BXN`%]3
M96%D:7-T=7,`U6EG7W5S960`7T5E;6%L9&$@;&EN:RXN+@!?4&%I9V%L9'5S
M`%]486)E;&D@;VUA9'5S960N+BX`7TMA<W5T86IA9`!A861R97-S:7)A86UA
M=`!A9')E<W-A870@='5N9&UA='4`:V%L96YD97(`=F%I:VYE`';D;&IU;F1F
M86EL:2!L;V]M:6YE(&YU<FIU<P!S:7-E;F1I(&%V86UI;F4@;G5R:G5S`&ML
M]7!S82!S:6EA`&OD<W5R96$@:V%S=71A;6ES92!V:6=A`'-E861I<W1U<V4@
M=FEG80!E;'5TY&AT:7,@<_QS=&5E;6EF86EL(&]N('!U=61U`&%N9&UE=&4@
M9F]R;6%A9&D@=FEG80!M=75D80!K86YN970@96D@;&5I='5D`&QA;F=E8@!F
M86EL`'-U=6YD("5S("@E<RD@:F$@:VEI<G5S("5S("5S`'!U:&%N9W5L:6YE
M`&LZ`'1T`'1U;F1M871U(&AO<W1I;FEM:0!V:6EV:71A;6%T=0!I;FQI;F4`
M<VES96YD+W;D;&IU;F0@=FEG80!T87)K=F%R82!S965S;6EN92!V:6=A`')I
M9&%=`&UK:7-O9G,@=F5A:V]O9"`E9"!)4T\@;&]O;6ES96PN`&UM`&YI;6D`
M<&]L92!T96]S=&%T=60`<&]L92!V965L('1E;W-T871U9`!MY')K;6EK`'!R
M;W1S96YT:0#U:6=U<V5D('!U=61U=F%D`'!I:W-L:70`<')O=&]K;VQL:2!V
M:6=A('1E:7-E<R!O='-A<P!T]75S96(`=&5E;G5S('!O;&4@:^1T=&5S86%D
M878`;N1I=&$@97)I;F5V=7-I`'-M<S)E;6%I;"#\;&4@2%144`!S<P#\:'1L
M86YE`&S\;&ET82!J879A<V-R:7!T(';D;&IA`'/\<W1E96UI('9I9V$`_&QE
M<V%N;F5T92!N:6UE:VER:0!A:G5T:6YE('3U<F=E`'!R;V]V:2!U=65S=&D`
M:VER:G5T82!S86QA<_5N82!E:W-I='5S92!VY&QT:6UI<V5K<R!K86MS(&MO
M<F1A`/QH:71A='5D`&YI;65T=0!K87-U=&%J82!V86QI:P!V0V%R9`!L.@!W
M96%T:&5R+F-O;0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V9I7T9)
M+TQ#7TU%4U-!1T53````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,30U,@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O9FE?1DDO:&5L<"YX;6P`````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0S,S<@,3`U,34T,S0Q-#$@,#(Q-#(U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE
M+V9I7T9)+VAE;'`N>&UL+'8@,2XS+C$P+C,@,C`P-B\P,B\R,"`Q,3HR,#HQ
M,2!J86X@17AP("0@+2T^"CQH96QP/@H@(#QE;G1R>2!I9#TB<W5M;6%R>2(@
M;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(@<W1A=&4]
M(G5P=&]D871E(CX*/'1I=&QE/E!O<G1A86QI/"]T:71L93X*(#QP87)A/@H@
M(%!O<G1A86QI<W-A('9O:70@;B8C>$4T.VAD)B-X130[('!I:V%I<V5S=&D@
M;'EH>65N('EH=&5E;G9E9&]N('0F(WA%-#MR:V4F(WA%-#MK<VD*("!M97)K
M:71S96UI<W0F(WA%-#L@87-I;VES=&$N($5S:6UE<FMI:W-I('9O:70@;B8C
M>$4T.VAD)B-X130[(&UO;G1A:V\@=75T=&$*("!S)B-X130[:&LF(WA&-CMP
M;W-T:79I97-T:28C>$4T.R!S:6YU;&QE(&]N('1U;&QU="!)3D)/6"!K86YS
M:6]O;BP@='5L979A=`H@('1A<&%H='5M870@:V%L96YT97)I<W-A+"!T96AT
M)B-X130[=B8C>$4T.W0@=&\M9&\@;&ES=&%L;&$L(&]T<VEK;W0*("!V86QI
M='-E;6ES=&%S:2!U=71I<W!A;'9E;'5I<W1A(&IN92X@36]N970@;B8C>$4T
M.VES="8C>$4T.R!Y:'1E96YV961O:7-T80H@('-I<R8C>$4T.VQT)B-X130[
M=B8C>$4T.W0@;&EN:VME:B8C>$4T.R!Y;&5I<VEM<&EI;B!T;VEM:6YT;VEH
M:6X@:W5T96X@97-I;65R:VEK<VD@=FEE<W1I;@H@(&MI<FIO:71U<RP@:V%L
M96YT97)I;65R:VEN;B8C>$4T.VX@=&%I('1E:'0F(WA%-#MV)B-X130[;B!L
M:7,F(WA%-#MY<R!J;F4N"B`\+W!A<F$^"B`\<&%R83X*("!0;W)T86%L:6X@
M<VES)B-X130[;'0F(WA&-CL@;VX@;75O:V%T=&%V:7-S82!!<V5T=&5L=2!P
M86EN:6MK965N(&MA=71T82X@5F]I=`H@(&5S:6UE<FMI:W-I('9A;&ET82!M
M:71K)B-X130[(&%S:6%T(&QI:71E="8C>$4T.R8C>$4T.VX@<&]R=&%A;&EI
M;B!J82!M:7-S)B-X130["B`@:B8C>$4T.W)J97-T>6MS97-S)B-X130[(&YE
M(&XF(WA%-#MY=&5T)B-X130[)B-X130[;BX*(#PO<&%R83X*/"]E;G1R>3X*
M("`\96YT<GD@:60](FYA=F)A<B(@;60U/2)B.&-F,&%E,3EE-3=D9F$P8S)B
M.38R934Q-C<X,F8T-R(@<W1A=&4](G5P=&]D871E(CX*/'1I=&QE/D]H:F5L
M;6EE;B!N879I9V]I;G1I=F%L:6MK;SPO=&ET;&4^"B`\<&%R83X*("!7=W<M
M<VEV=6X@=F%S96UA;&QA(&QA:61A;&QA(&]N(&YA=FEG;VEN=&EV86QI:VMO
M(&5R:2!O:&IE;&UI:6XN"B`@3F%P<V%U='1A;6%L;&$@:6MO;F5I=&$@;F%V
M:6=O:6YT:79A;&EK;W-S82!V;VET(&AE;'!O<W1I(&IA"B`@;F]P96%S=&D@
M=F%I:'1A82!O:&IE;&UA<W1A('1O:7-E96XN"B`\+W!A<F$^"CPO96YT<GD^
M"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@;60U/2)D9#DU
M9&8P-V$P,S`S,3(S,F)A96$Y,3DR.#AB,F0P,"(@<W1A=&4](G5P=&]D871E
M(CX*("`@(#QT:71L93Y!<V5T=6MS970Z(%EL;"8C>$4T.W!I=&]T;VEM96YP
M:71E970Z(%-U;W)I=&$@>6QL)B-X130[<&ET;W1O:6UE=#PO=&ET;&4^"B`@
M("`\<&%R83X*("`@($IO<R!H86QU870@<W5O<FET=&%A('EL;"8C>$4T.W!I
M=&]T;VEM96YP:71E:70F(WA%-#L@<VES)B-X130[)B-X130[;FMI<FIA=71U
M;6ES96X*("`@('EH=&5Y9&5S<R8C>$4T.RP@;FEI;B!A<V5T82!T)B-X130[
M;28C>$4T.R!T;VEM:6YT;R!P)B-X130[)B-X130[;&QE('9A;&EN=&%R=75D
M=7-T82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S
M+6-O;F9I<FU?;6%I;G1E;F%N8V4B(&UD-3TB83(Q,38R8V1F9C-B,60X9F%E
M861B-S(Y-C(T,#`S-F4B('-T871E/2)U<'1O9&%T92(^"B`@("`\=&ET;&4^
M07-E='5K<V5T.B!9;&PF(WA%-#MP:71O=&]I;65N<&ET965T.B!687)M:7-T
M82!Y;&PF(WA%-#MP:71O=&]I;65T/"]T:71L93X*("`@(#QP87)A/@H@("`@
M2F]S(&AA;'5A="!V87)M:7-T86$@:V%I:VMI('EL;"8C>$4T.W!I=&]T;VEM
M96YP:71E970@96YE;FYK=6EN(&YE"B`@("!S=6]R:71E=&%A;BP@;FEI;B!A
M<V5T82!T)B-X130[;28C>$4T.R!T;VEM:6YT;R!P)B-X130[)B-X130[;&QE
M"B`@("!V86QI;G1A<G5U9'5S=&$N($IO<R!V87)M:7-T=7-T82!E:2!O;&4@
M<"8C>$4T.R8C>$4T.VQL)B-X130[+"!N:6EN(&MA:6MK:0H@("`@>6QL)B-X
M130[<&ET;W1O:6UE;G!I=&5E="!S=6]R:71E=&%A;B!A=71O;6%A='1I<V5S
M=&D@:F$@;FEI="8C>$4T.R!E:2!V;VD*("`@('!E<G5A+@H@("`@/"]P87)A
M/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9FE?1DDO3$-?34534T%'15,O:&]R
M9&4N;6\`````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,3(T,#$@,3`U,34T
M,S0Q-#$@,#(S,3<Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````-X2!)4`````B@<``!P```!L/```$PH``+QX````````"*$`
M``X````)H0``#P```!BA```-````**$```@````VH0``"P```#^A```,````
M2Z$```0```!8H0``&````%VA```;````=J$``"T```"2H0``'0```,"A```D
M````WJ$``"D````#H@``&0```"VB```F````1Z(```P```!NH@``)````'NB
M```/````H*(```L```"PH@``#@```+RB```%````RZ(``"@```#1H@``"```
M`/JB```*`````Z,``!4````.HP``$@```"2C```+````-Z,``(4```!#HP``
M#@```,FC```*````V*,```T```#CHP``#@```/&C```1`````*0```T````2
MI```#````""D```-````+:0```8````[I```E````$*D```*````UZ0```\`
M``#BI```&````/*D```,````"Z4```X````8I0``#@```">E```(````-J4`
M``D````_I0``+@```$FE```:````>*4``#(```"3I0``.````,:E``!4````
M_Z4``%$```!4I@``6@```*:F``!7`````:<``#0```!9IP``"0```(ZG```-
M````F*<```<```"FIP``"@```*ZG```/````N:<```4```#)IP``!@```,^G
M```1````UJ<```@```#HIP``"0```/&G```)````^Z<``"4````%J```(```
M`"NH```3````3*@``!````!@J```#P```'&H```*````@:@```,```",J```
M#P```)"H```4````H*@```D```"UJ```#0```+^H```2````S:@``!D```#@
MJ```'@```/JH```/````&:D```H````IJ0``#P```#2I```(````1*D``"0`
M``!-J0``%````'*I```6````AZD```@```">J0``3@```*>I```M````]JD`
M`!D````DJ@``!P```#ZJ```,````1JH``"P```!3J@``#@```("J```#````
MCZH```L```"3J@``!P```)^J```'````IZH```4```"OJ@``!0```+6J```*
M````NZH```,```#&J@``%P```,JJ```*````XJH```\```#MJ@``#@```/VJ
M```8````#*L``",````EJP``#@```$FK```4````6*L``!<```!MJP``%P``
M`(6K```7````G:L``!,```"UJP``#P```,FK```.````V:L``!\```#HJP``
M'0````BL```'````)JP```8````NK```"````#6L```/````/JP```8```!.
MK```"@```%6L```3````8*P```L```!TK```$````("L```5````D:P``!4`
M``"GK```!P```+VL```0````Q:P```4```#6K```%0```-RL```1````\JP`
M``P````$K0``.P```!&M```X````3:T```D```"&K0``!P```)"M```4````
MF*T```,```"MK0``!0```+&M```0````MZT```D```#(K0``$P```-*M```Y
M````YJT``!(````@K@``)P```#.N```L````6ZX``"H```"(K@``)0```+.N
M```*````V:X```8```#DK@``"0```.NN```'````]:X``"\```#]K@``-P``
M`"VO```N````9:\``%4```"4KP``+0```.JO```M````&+```#T```!&L```
M/P```(2P```M````Q+```$````#RL```(P```#.Q```C````5[$``$````![
ML0``+0```+RQ```S````ZK$``"4````>L@``%0```$2R```9````6K(``"D`
M``!TL@``)````)ZR```H````P[(``!$```#LL@``"@```/ZR```,````";,`
M``H````6LP``$````"&S```6````,K,``!8```!)LP``!P```&"S```'````
M:+,``!0```!PLP``"@```(6S```(````D+,``"<```"9LP``"````,&S```'
M````RK,```<```#2LP``!@```-JS```%````X;,```<```#GLP``!@```.^S
M```(````]K,``"D```#_LP``#@```"FT```*````.+0```0```!#M```!P``
M`$BT```)````4+0```8```!:M```$0```&&T```'````<[0``!8```![M```
M!````)*T```(````E[0```8```"@M```#0```*>T```&````M;0``!X```"\
MM```$0```-NT```(````[;0```T```#VM```#`````2U```'````$;4```,`
M```9M0```P```!VU```7````(;4``!,````YM0``'0```$VU```(````:[4`
M``0```!TM0``"````'FU```(````@K4``$$```"+M0``&@```,VU```K````
MZ+4``"`````4M@``%0```#6V```&````2[8```8```!2M@``%0```%FV```8
M````;[8``"(```"(M@``+@```*NV```=````VK8``"$```#XM@``5````!JW
M```I````;[<```H```"9MP``!P```*2W```'````K+<``!4```"TMP``#@``
M`,JW```*````V;<```\```#DMP``#0```/2W```/`````K@```T````2N```
M"0```""X```4````*K@```8````_N```&````$:X```=````7[@``!,```!]
MN```$0```)&X```4````H[@```0```"XN```!@```+VX```4````Q+@``%0`
M``#9N```9````"ZY```$````D[D```X```"8N0``!0```*>Y```%````K;D`
M`!L```"SN0``&@```,^Y```3````ZKD``!$```#^N0``$0```!"Z```<````
M(KH``"H````_N@``$````&JZ```A````>[H```4```"=N@``$P```*.Z```+
M````M[H``!(```##N@``"@```-:Z```/````X;H```T```#QN@``$0```/^Z
M```3````$;L```P````ENP``!@```#*[```,````.;L```8```!&NP``%P``
M`$V[```0````9;L``!$```!VNP``"````(B[```%````D;L```P```"7NP``
M$````*2[```%````M;L```T```"[NP``!@```,F[```'````T+L```T```#8
MNP``!P```.:[```+````[KL```<```#ZNP``!P````*\```)````"KP```D`
M```4O```"@```!Z\```9````*;P``#T```!#O```'0```(&\```,````G[P`
M`!````"LO```!0```+V\```E````P[P``!(```#IO```$P```/R\```K````
M$+T``#L````\O0``(````'B]```(````F;T``#8```"BO0``(0```-F]```0
M````^[T```@````,O@``#````!6^```&````(KX```0````IO@``#P```"Z^
M```.````/KX```<```!-O@``"@```%6^```-````8+X``!\```!NO@``'```
M`(Z^```A````J[X``!X```#-O@``&0```.R^```>````!K\``!L````EOP``
M(0```$&_```N````8[\``"8```"2OP``'````+F_```>````UK\``!P```#U
MOP``)@```!+````K````.<```#,```!EP```)@```)G````K````P,```#@`
M``#LP```'0```"7!```5````0\$``"\```!9P0``(````(G!```2````JL$`
M`"D```"]P0``'@```.?!```@````!L(``!(````GP@``H@```#K"```6````
MW<(``",```#TP@``*````!C#```I````0<,``"@```!KPP``'P```)3#```5
M````M,,``"````#*PP``)0```.O#```H````$<0``"T````ZQ```,````&C$
M``"2````F<0``"$````LQ0``%@```$[%```<````9<4``"8```""Q0``*@``
M`*G%``!!````U,4``$0````6Q@``#````%O&```'````:,8```<```!PQ@``
M!@```'C&```-````?\8``!````"-Q@``$@```)[&```3````L<8``!(```#%
MQ@``!P```-C&```$````X,8``!````#EQ@``$````/;&```,````!\<```X`
M```4QP``#0```"/'```/````,<<``!,```!!QP``#0```%7'```H````8\<`
M``,```",QP``#0```)#'```&````GL<``!$```"EQP``%P```+?'```;````
MS\<```X```#KQP```@```/K'``!)````_<<```4```!'R```$````$W(```/
M````7L@```0```!NR```#0```'/(```.````@<@```,```"0R```#@```)3(
M```(````H\@```\```"LR```#P```+S(```'````S,@```T```#4R```$```
M`.+(```-````\\@```L````!R0``!@````W)```+````%,D```P````@R0``
M"@```"W)```1````.,D``!D```!*R0``"P```&3)```-````<,D``"(```!^
MR0``#P```*')```;````L<D``#0```#-R0``"@````+*```8````#<H``!(`
M```FR@``&0```#G*```6````4\H``"(```!JR@``#0```(W*```'````F\H`
M`!0```"CR@``"P```+C*```B````Q,H``"\```#GR@``"P```!?+```)````
M(\L``!D````MRP``"P```$?+```7````4\L``!<```!KRP``"0```(/+```6
M````C<L```\```"DRP``&0```+3+```6````SLL```X```#ERP``&````/3+
M```(````#<P```T````6S```)@```"3,``!#````2\P```@```"/S```$@``
M`)C,```?````J\P```@```#+S```"P```-3,```O````X,P```X````0S0``
M!0```!_-```&````)<T``$4````LS0```P```'+-```'````=LT```0```!^
MS0``"@```(/-```*````CLT```\```"9S0``$````*G-```7````NLT``!$`
M``#2S0``&0```.3-```7````_LT```D````6S@``!0```"#.```+````)LX`
M``H````RS@```@```#W.```%````0,X```T```!&S@``&P```%3.```7````
M<,X``!0```"(S@``"0```)W.```.````I\X```T```"VS@``$@```,3.```X
M````U\X``"`````0SP``"````#'/```.````.L\``'L```!)SP``&````,7/
M```8````WL\``!$```#WSP``!P````G0```%````$=```!@````7T```'@``
M`##0```;````3]```!D```!KT```&P```(70```9````H=```!,```"[T```
M!P```,_0```(````U]````8```#@T```!@```.?0```0````[M````\```#_
MT```$`````_1```/````(-$```L````PT0``#P```#S1```,````3-$```\`
M``!9T0``!P```&G1```&````<=$```X```!XT0``#````(?1```H````E-$`
M``\```"]T0``"````,W1```(````UM$``!,```#?T0``'@```//1```A````
M$M(``"`````TT@``&0```%72```7````;](``"4```"'T@``%P```*W2```6
M````Q=(```0```#<T@``&P```.'2```-````_=(```P````+TP```P```!C3
M```%````'-,```@````BTP``"@```"O3```,````-M,```L```!#TP``$```
M`$_3```,````8-,```X```!MTP``"P```'S3```$````B-,```0```"-TP``
M$P```)+3```4````IM,```P```"[TP``"0```,C3```.````TM,```L```#A
MTP``&P```.W3```'````"=0```<````1U```"@```!G4```-````)-0```D`
M```RU```!````#S4```%````0=0```,```!'U```&````$O4```*````9-0`
M``0```!OU```)@```'34```.````F]0``'P```"JU```%0```"?5```%````
M/=4```<```!#U0``#````$O5```(````6-4```H```!AU0``!@```&S5```(
M````<]4```(```!\U0``!@```'_5```&````AM4``!0```"-U0``#0```*+5
M```0````L-4``!L```#!U0``!````-W5```)````XM4``!````#LU0``"0``
M`/W5```)````!]8```4````1U@``&@```!?6```(````,M8```8````[U@``
M&0```$+6```.````7-8```<```!KU@``!P```'/6```%````>]8```D```"!
MU@``"@```(O6```.````EM8```(```"EU@``!@```*C6```+````K]8```T`
M``"[U@``"0```,G6```&````T]8``!(```#:U@``"0```.W6```'````]]8`
M`!0```#_U@``'0```!37``!"````,M<``"4```!UUP``)0```)O7```&````
MP=<```H```#(UP``!````-/7```)````V-<```@```#BUP``$0```.O7```)
M````_=<```8````'V```#0````[8```&````'-@```0````CV```.0```"C8
M```]````8M@``#H```"@V```'@```-O8```%````^M@```X`````V0``!```
M``_9```&````%-D```<````;V0``(0```"/9```-````1=D``!4```!3V0``
M!@```&G9```$````<-D``!$```!UV0``!@```(?9```*````CMD``"(```"9
MV0``!````+S9```%````P=D``!T```#'V0``!````.79```,````ZMD```X`
M``#WV0``"@````;:```(````$=H```D````:V@``!0```"3:```Z````*MH`
M`#````!EV@``-0```);:```I````S-H``$<```#VV@``.````#[;```I````
M=]L``#\```"AVP``+@```.';```M````$-P``!\````^W```#P```%[<```2
M````;MP```L```"!W```)@```(W<```I````M-P``"0```#>W```)@````/=
M```(````*MT```H````SW0``"0```#[=```'````2-T``"````!0W0``(```
M`''=```F````DMT```H```"YW0``&0```,3=```I````WMT``!8````(W@``
M$@```!_>```'````,MX```H````ZW@``#````$7>```/````4MX``!````!B
MW@``0````'/>``!P````M-X``&8````EWP``#@```(S?```)````F]\```H`
M``"EWP``$@```+#?```3````P]\```P```#7WP``!@```.3?```/````Z]\`
M`!(```#[WP``$`````[@```1````'^```!P````QX```(P```$[@``!J````
M<N````\```#=X```!0```.W@```0````\^````D````$X0``!`````[A```+
M````$^$``"`````?X0``%````$#A```,````5>$```P```!BX0``#P```&_A
M```5````?^$``"D```"5X0``*@```+_A```F````ZN$``"<````1X@``*0``
M`#GB```J````8^(``!D```".X@``0@```*CB```1````Z^(``!(```#]X@``
M$P```!#C```4````).,```\````YXP``%@```$GC```7````8.,``!````!X
MXP``$0```(GC```T````F^,``!,```#0XP``$@```.3C```U````]^,``!0`
M```MY```!P```$+D```,````2N0``"````!7Y```$````'CD```4````B>0`
M`!$```">Y```%P```+#D```<````R.0``!,```#EY```%````/GD```:````
M#N4``!$````IY0``&@```#OE```>````5N4``!H```!UY0``$P```)#E```5
M````I.4``!$```"ZY0``%P```,SE```4````Y.4``!<```#YY0``%0```!'F
M```)````)^8``!`````QY@``&0```$+F```$````7.8```<```!AY@``"P``
M`&GF```1````=>8```8```"'Y@``!@```([F```&````E>8```4```"<Y@``
M!P```*+F```'````JN8```4```"RY@``%@```+CF```&````S^8```8```#6
MY@``!````-WF```$````XN8```<```#GY@``#@```._F```,````_N8```P`
M```+YP``#0```!CG```*````)N<```X````QYP``!0```$#G```H````1N<`
M``X```!OYP``#````'[G```/````B^<```H```";YP``"````*;G```)````
MK^<``"L```"YYP``!````.7G```(````ZN<``"8```#SYP``$@```!KH```/
M````+>@```8````]Z```"@```$3H```'````3^@```@```!7Z```(````&#H
M```)````@>@``!0```"+Z```#````*#H```-````K>@```X```"[Z```%@``
M`,KH```1````X>@```8```#SZ````P```/KH```&````_N@``!D````%Z0``
M!P```!_I```$````)^D```L````LZ0``"P```#CI```'````1.D```4```!,
MZ0``!P```%+I```6````6ND```T```!QZ0``#0```'_I```*````C>D``!``
M``"8Z0``#P```*GI```1````N>D``!<```#+Z0``"@```./I```1````[ND`
M``@`````Z@``!`````GJ```/````#NH``#H````>Z@``!0```%GJ```,````
M7^H``!X```!LZ@``#@```(OJ```0````FNH```L```"KZ@``#````+?J```)
M````Q.H```<```#.Z@``"@```-;J```)````X>H```X```#KZ@``$````/KJ
M```;````"^L``!@````GZP``&@```$#K```*````6^L```D```!FZP``"@``
M`'#K```,````>^L```\```"(ZP``"````)CK```&````H>L``!P```"HZP``
M!P```,7K```%````S>L```L```#3ZP``1P```-_K```-````)^P```D````U
M[```!````#_L```#````1.P``!,```!([```$P```%SL```3````<.P```H`
M``"$[````@```(_L```$````DNP``"4```"7[````P```+WL```%````P>P`
M`"H```#'[```"@```/+L```%````_>P```0````#[0``"@````CM```-````
M$^T```8````A[0``"````"CM```(````,>T```0````Z[0``!0```#_M``!H
M````1>T```D```"N[0``#````+CM```0````Q>T```4```#6[0``!@```-SM
M```;````X^T``"\```#_[0``$````"_N```*````0.X```\```!+[@``"@``
M`%ON```)````9NX``!,```!P[@``&P```(3N```8````H.X``!<```"Y[@``
M'P```-'N```.````\>X```,`````[P``!P````3O```(````#.\```<````5
M[P``"@```!WO```+````*.\```<````T[P``40```#SO```0````CN\```P`
M``"?[P``#0```*SO```:````NN\``$H```#5[P``&0```"#P```&````.O``
M`!H```!!\```)0```%SP```&````@O````8```")\```'P```)#P```&````
ML/````D```"W\```&````,'P```7````VO```"@```#R\```!@```!OQ```-
M````(O$``"(````P\0``5P```%/Q```3````J_$``",```"_\0``$P```./Q
M```"````]_$```L```#Z\0``"`````;R```-````#_(```H````=\@``!P``
M`"CR```4````,/(```8```!%\@``"````$SR```.````5?(```<```!D\@``
M"@```&SR```+````=_(``#(```"#\@``!P```+;R```,````OO(```T```#+
M\@``%P```-GR```,````\?(```D```#^\@``"0````CS```*````$O,```<`
M```=\P``"0```"7S```'````+_,```H````W\P``&P```$+S```/````7O,`
M`!(```!N\P``"@```('S```6````C/,```D```"C\P``$````*WS```'````
MOO,``!(```#&\P``!````-GS```'````WO,```4```#F\P``!0```.SS```+
M````\O,``!0```#^\P``$0```!/T```:````)?0``!8```!`]```%````%?T
M```7````;/0``!@```"$]```'````)WT```9````NO0```<```#4]```!0``
M`-ST```-````XO0```P```#P]```"````/WT```7````!O4```L````>]0``
M#````"KU```?````-_4``!H```!7]0``$P```'+U```$````AO4```H```"+
M]0``!````);U```-````F_4```P```"I]0``!0```+;U```)````O/4```4`
M``#&]0``!P```,SU```%````U/4```0```#:]0```@```-_U```X````XO4`
M`"P````;]@``$@```$CV```I````6_8``#(```"%]@``"@```+CV```L````
MP_8``"X```#P]@``,P```!_W```S````4_<``#@```"']P``#P```,#W```8
M````T/<``!````#I]P``#P```/KW```3````"O@``!4````>^```%````#3X
M```2````2?@``!0```!<^```%0```''X```M````A_@``"T```"U^```,0``
M`./X```N````%?D``"\```!$^0``+````'3Y``!B````H?D``!,````$^@``
M#0```!CZ```(````)OH``!<````O^@``"````$?Z```,````4/H``"L```!=
M^@``(0```(GZ```:````J_H```D```#&^@``10```-#Z``!!````%OL```0`
M``!8^P``$P```%W[```4````<?L```X```"&^P``$P```)7[```8````J?L`
M``8```#"^P``"0```,G[```*````T_L```\```#>^P``$````.[[```'````
M__L```X````'_```!0```!;\```;````'/P```@````X_```!@```$'\```4
M````2/P``!$```!=_```#@```&_\```X````?OP```(```"W_```!@```+K\
M```.````P?P```4```#0_```!P```-;\```.````WOP```8```#M_```*```
M`/3\```,````'?T``!P````J_0``!````$?]```I````3/T``!<```!V_0``
M'P```([]``!<````KOT``!0````+_@``/@```"#^```?````7_X``!````!_
M_@``!P```)#^```.````F/X```P```"G_@``#````+3^```3````P?X```H`
M``#5_@``'0```.#^```9````_OX```4````8_P``$0```![_```1````,/\`
M`"0```!"_P``$@```&?_```5````>O\``!(```"0_P``#@```*/_```9````
MLO\```@```#,_P``"0```-7_```-````W_\```<```#M_P``"@```/7_```'
M```````!``\````(``$`!@```!@``0`+````'P`!`!H````K``$`"@```$8`
M`0`'````40`!``@```!9``$`!0```&(``0`?````:``!``8```"(``$`$```
M`(\``0`(````H``!``T```"I``$`"````+<``0`>````P``!`!(```#?``$`
M+````/(``0`:````'P$!``D````Z`0$`"@```$0!`0`5````3P$!``4```!E
M`0$`%````&L!`0`$````@`$!`!````"%`0$`!@```)8!`0`'````G0$!`!X`
M``"E`0$`*````,0!`0`*````[0$!`!P```#X`0$`$0```!4"`0`+````)P(!
M`!H````S`@$`%````$X"`0`$````8P(!``0```!H`@$`"P```&T"`0`%````
M>0(!``8```!_`@$`"````(8"`0`&````CP(!``H```"6`@$`&P```*$"`0`T
M````O0(!`#0```#R`@$`(````"<#`0`I````2`,!`"````!R`P$`00```),#
M`0`:````U0,!`"@```#P`P$`*0```!D$`0!0````0P0!`"(```"4!`$`!@``
M`+<$`0`(````O@0!``4```#'!`$`"````,T$`0`9````U@0!`!D```#P!`$`
M*@````H%`0`C````-04!`!D```!9!0$`+@```',%`0`T````H@4!``@```#7
M!0$`%P```.`%`0`*````^`4!``<````#!@$`(0````L&`0`0````+08!``X`
M```^!@$`"P```$T&`0`'````608!`!,```!A!@$`"````'4&`0`+````?@8!
M``H```"*!@$`%````)4&`0`/````J@8!`#(```"Z!@$`"P```.T&`0`.````
M^08!``4````(!P$`!0````X'`0`%````%`<!`!<````:!P$`#P```#('`0`$
M````0@<!``H```!'!P$`"0```%('`0`+````7`<!``T```!H!P$`#````'8'
M`0`.````@P<!``4```"2!P$`!````)@'`0`-````G0<!`#(```"K!P$`10``
M`-X'`0`7````)`@!``<````\"`$`'@```$0(`0`4````8P@!``4```!X"`$`
M%````'X(`0`&````DP@!``<```":"`$`#@```*((`0`J````L0@!``8```#<
M"`$`#````.,(`0`-````\`@!`!$```#^"`$`"P```!`)`0`V````'`D!``H`
M``!3"0$`(@```%X)`0`+````@0D!``\```"-"0$`,@```)T)`0`E````T`D!
M`#````#V"0$`,0```"<*`0`M````60H!``X```"'"@$`!0```)8*`0`.````
MG`H!`!,```"K"@$`$@```+\*`0`'````T@H!`!$```#:"@$`$P```.P*`0`'
M``````L!`!0````("P$`&````!T+`0`'````-@L!``4````^"P$`#````$0+
M`0`,````40L!`!(```!>"P$`!````'$+`0`'````=@L!``H```!^"P$`"P``
M`(D+`0`,````E0L!``X```"B"P$`#@```+$+`0`%````P`L!``4```#&"P$`
M+@```,P+`0`F````^PL!`",````B#`$``P```$8,`0`2````2@P!``8```!=
M#`$`'@```&0,`0`8````@PP!`"4```"<#`$`#0```,(,`0`)````T`P!`!\`
M``#:#`$``P```/H,`0`'````_@P!``H````&#0$``@```!$-`0`,````%`T!
M`!4````A#0$`"P```#<-`0`9````0PT!`"````!=#0$`$@```'X-`0`%````
MD0T!``H```"7#0$`%0```*(-`0`2````N`T!``P```#+#0$`!````-@-`0`)
M````W0T!``<```#G#0$`#````.\-`0!2````_`T!`!<```!/#@$`)````&<.
M`0`2````C`X!``<```"?#@$`!@```*<.`0`.````K@X!``P```"]#@$`#0``
M`,H.`0`5````V`X!`!(```#N#@$`#P````$/`0`4````$0\!``H````F#P$`
M&P```#$/`0`0````30\!``L```!>#P$`:0```&H/`0`:````U`\!`!<```#O
M#P$`)P````<0`0`:````+Q`!`!<```!*$`$`&P```&(0`0`9````?A`!`!\`
M``"8$`$`$P```+@0`0`(````S!`!``<```#5$`$`"````-T0`0`)````YA`!
M`!4```#P$`$`#0````81`0`C````%!$!``T````X$0$`$P```$81`0`(````
M6A$!``,```!C$0$`1@```&<1`0`_````KA$!`#<```#N$0$`5P```"82`0`%
M````?A(!`!\```"$$@$`+P```*02`0`*````U!(!``@```#?$@$`#0```.@2
M`0`M````]A(!``0````D$P$`3P```"D3`0`E````>1,!`!P```"?$P$`"P``
M`+P3`0`?````R!,!`!T```#H$P$`)0````84`0`@````+!0!`"0```!-%`$`
M(````'(4`0`+````DQ0!``<```"?%`$`#0```*<4`0`,````M10!`!<```#"
M%`$`!@```-H4`0`Y````X10!``P````;%0$`!P```"@5`0`)````,!4!`!,`
M```Z%0$`"0```$X5`0`$````6!4!`!````!=%0$`"````&X5`0`(````=Q4!
M``0```"`%0$`"P```(45`0`,````D14!`!(```">%0$`$0```+$5`0`,````
MPQ4!`!H```#0%0$`#P```.L5`0`'````^Q4!``T````#%@$`%````!$6`0`.
M````)A8!``P````U%@$`&P```$(6`0`L````7A8!`!,```"+%@$`'````)\6
M`0`H````O!8!``8```#E%@$`!P```.P6`0`3````]!8!``4````(%P$`!```
M``X7`0`7````$Q<!``H````K%P$`#````#87`0`)````0Q<!``8```!-%P$`
M"0```%07`0`(````7A<!``D```!G%P$`"@```'$7`0`1````?!<!``8```".
M%P$`#@```)47`0`.````I!<!``T```"S%P$`"P```,$7`0`=````S1<!``L`
M``#K%P$``@```/<7`0`<````^A<!``<````7&`$`!@```!\8`0!D````)A@!
M``D```"+&`$`!P```)48`0`F````G1@!`#@```#$&`$`&@```/T8`0`J````
M&!D!`#L```!#&0$`*````'\9`0`T````J!D!`!D```#=&0$`%0```/<9`0`%
M````#1H!``<````3&@$`"````!L:`0`'````)!H!``4````L&@$`!P```#(:
M`0`.````.AH!``D```!)&@$`!@```%,:`0`(````6AH!``L```!C&@$`!P``
M`&\:`0`(````=QH!``<```"`&@$`%@```(@:`0`)````GQH!``8```"I&@$`
M"P```+`:`0`0````O!H!``8```#-&@$`'````-0:`0`4````\1H!``<````&
M&P$`$0````X;`0`(````(!L!``X````I&P$`"````#@;`0`%````01L!`!``
M``!'&P$`"0```%@;`0`0````8AL!``8```!S&P$`&0```'H;`0`*````E!L!
M`!P```"?&P$`!P```+P;`0`%````Q!L!`!````#*&P$`%````-L;`0`+````
M\!L!``T```#\&P$`*`````H<`0`8````,QP!`!<```!,'`$`!````&0<`0`)
M````:1P!``H```!S'`$`!P```'X<`0`"````AAP!``X```")'`$`"````)@<
M`0`C````H1P!`!\```#%'`$`.````.4<`0`F````'AT!`#$```!%'0$`)P``
M`'<=`0!D````GQT!`!0````$'@$`50```!D>`0`X````;QX!`$H```"H'@$`
M6P```/,>`0`H````3Q\!`#@```!X'P$`*````+$?`0`L````VA\!`"8````'
M(`$`&P```"X@`0`^````2B`!`*D!``")(`$`(P```#,B`0`7````5R(!`$@`
M``!O(@$`A0```+@B`0`P````/B,!`"4```!O(P$`00```)4C`0!;````UR,!
M`$D````S)`$`,0```'TD`0`=````KR0!`!@```#-)`$`*P```.8D`0`A````
M$B4!`!\````T)0$`*P```%0E`0`F````@"4!`"<```"G)0$`.@```,\E`0`=
M````"B8!`!$````H)@$`,P```#HF`0`E````;B8!`"<```"4)@$`(````+PF
M`0`?````W28!`#````#])@$`:0```"XG`0`Q````F"<!`$$```#*)P$`,P``
M``PH`0`E````0"@!`#T```!F*`$`90```*0H`0!-````"BD!`"\```!8*0$`
M+@```(@I`0`P````MRD!`%0```#H*0$`6@```#TJ`0!(````F"H!`$H```#A
M*@$`,@```"PK`0`O````7RL!`"P```"/*P$`+0```+PK`0!Q````ZBL!`&8`
M``!<+`$`;P```,,L`0"S````,RT!`!<```#G+0$`)0```/\M`0`R````)2X!
M`"D```!8+@$`/@```((N`0`B````P2X!`%(```#D+@$`)0```#<O`0`+````
M72\!`+$```!I+P$`10```!LP`0`A````83`!`#````"#,`$`)0```+0P`0`<
M````VC`!`#$```#W,`$`!P```"DQ`0`'````,3$!``0````Y,0$`#0```#XQ
M`0`+````3#$!``X```!8,0$`"P```&<Q`0`%````<S$!`!````!Y,0$``@``
M`(HQ`0!9````C3$!``4```#G,0$`$@```.TQ`0`$`````#(!``<````%,@$`
M"`````TR`0`%````%C(!`#`````<,@$``P```$TR`0`0````43(!``P```!B
M,@$`$P```&\R`0`-````@S(!``(```"1,@$`!P```)0R`0`&````G#(!`!0`
M``"C,@$`#````+@R`0`8````Q3(!``8```#>,@$`$@```.4R`0`,````^#(!
M``,````%,P$`*@````DS`0`$````-#,!``8````Y,P$`!P```$`S`0`?````
M2#,!`#4```!H,P$`+@```)XS`0`O````S3,!`!<```#],P$`(@```!4T`0`E
M````.#0!`"````!>-`$`&P```'\T`0`8````FS0!`"0```"T-`$`'P```-DT
M`0`:````^30!`"$````4-0$`(````#8U`0`:````5S4!`#(```!R-0$`&@``
M`*4U`0`O````P#4!`"L```#P-0$`'P```!PV`0`C````/#8!`!\```!@-@$`
M&@```(`V`0`A````FS8!`"4```"]-@$`)@```.,V`0`E````"C<!`"0````P
M-P$`&````%4W`0`=````;C<!`"0```",-P$`&````+$W`0`B````RC<!`"P`
M``#M-P$`+P```!HX`0`5````2C@!`"4```!@.`$`/````(8X`0`?````PS@!
M`",```#C.`$`'P````<Y`0`@````)SD!`!H```!(.0$`&````&,Y`0`F````
M?#D!`!X```"C.0$`*0```,(Y`0`>````[#D!`#$````+.@$`"0```#TZ`0`,
M````1SH!`!<```!4.@$`+P```&PZ`0`D````G#H!``<```#!.@$`#P```,DZ
M`0`4````V3H!``X```#N.@$`#0```/TZ`0`D````"SL!``4````P.P$`!P``
M`#8[`0`B````/CL!`"4```!A.P$`&@```(<[`0`=````HCL!`!H```#`.P$`
M!P```-L[`0#'````XSL!``L```"K/`$`%0```+<\`0`&````S3P!``D```#4
M/`$`"P```-X\`0`-````ZCP!`!<```#X/`$`!@```!`]`0`S````%ST!`!,`
M``!+/0$`$P```%\]`0`'````<ST!``\```![/0$`!P```(L]`0`R````DST!
M``0```#&/0$`(0```,L]`0`3````[3T!``P````!/@$`$0````X^`0`R````
M(#X!`!8```!3/@$`"````&H^`0`=````<SX!``D```"1/@$`"@```)L^`0`4
M````ICX!``H```"[/@$`'0```,8^`0`(````Y#X!`!\```#M/@$`"`````T_
M`0`:````%C\!`"<````Q/P$`!@```%D_`0`5````8#\!``<```!V/P$`"```
M`'X_`0`)````AS\!`#\```"1/P$`!P```-$_`0`/````V3\!``X```#I/P$`
M$````/@_`0`)````"4`!``D````30`$`"````!U``0`3````)D`!``<````Z
M0`$`&0```$)``0`*````7$`!`!<```!G0`$`%````']``0`*````E$`!``P`
M``"?0`$`%P```*Q``0`$````Q$`!`"H```#)0`$`#````/1``0`1`````4$!
M``<````300$``@```!M!`0`0````'D$!`!@````O00$`"P```$A!`0`#````
M5$$!``@```!800$`!@```&%!`0`'````:$$!``T```!P00$`"P```'Y!`0`4
M````BD$!`!4```"?00$`#@```+5!`0`O````Q$$!`"````#T00$`'````!5"
M`0`5````,D(!``P```!(0@$`,0```%5"`0`%````AT(!`!(```"-0@$`/P``
M`*!"`0`2````X$(!``H```#S0@$`!@```/Y"`0`$````!4,!``0````*0P$`
M"@````]#`0`3````&D,!``4````N0P$`!@```#1#`0`&````.T,!``@```!"
M0P$`!````$M#`0`,````4$,!``H```!=0P$`.0```&A#`0`N````HD,!`"D`
M``#10P$`!0```/M#`0`8`````40!`!D````:1`$`'P```#1$`0`=````5$0!
M`!$```!R1`$``@```(1$`0`$````AT0!``H```",1`$`!@```)=$`0`%````
MGD0!``,```"D1`$`#````*A$`0!%````M40!`#(```#[1`$`&@```"Y%`0`T
M````244!`"@```!^10$`4P```*=%`0`9````^T4!`'(````51@$`(````(A&
M`0`U````J48!`"$```#?1@$`10````%'`0`P````1T<!`"@```!X1P$`*0``
M`*%'`0`F````RT<!`"4```#R1P$`*````!A(`0`H````04@!`"(```!J2`$`
M*P```(U(`0`P````N4@!`!(```#J2`$`$P```/U(`0`0````$4D!`'D````B
M20$`"0```)Q)`0"A````IDD!`',```!(2@$`?````+Q*`0`K````.4L!`%0`
M``!E2P$`%P```+I+`0`G````TDL!`!8```#Z2P$`#P```!%,`0`7````(4P!
M`!\````Y3`$`0````%E,`0`?````FDP!`!P```"Z3`$`40```-=,`0`:````
M*4T!`!0```!$30$`"@```%E-`0`%````9$T!``8```!J30$`"````'%-`0`%
M````>DT!`!(```"`30$`$````)--`0`3````I$T!`!T```"X30$`#P```-9-
M`0`/````YDT!``0```#V30$`"0```/M-`0`+````!4X!``<````13@$`!0``
M`!E.`0`4````'TX!``<````T3@$`"````#Q.`0`/````14X!``@```!53@$`
M#````%Y.`0`/````:TX!``8```![3@$`%````().`0`&````ETX!``P```">
M3@$`$0```*M.`0`(````O4X!``0```#&3@$`&0```,M.`0`1````Y4X!``H`
M``#W3@$`&`````)/`0`3````&T\!`!P````O3P$`$0```$Q/`0`$````7D\!
M``\```!C3P$`!P```'-/`0`$````>T\!`!D```"`3P$`!P```)I/`0`"````
MHD\!``(```"E3P$`$0```*A/`0`)````ND\!``8```#$3P$`$@```,M/`0`7
M````WD\!``8```#V3P$`)P```/U/`0`"````)5`!``0````H4`$`#P```"U0
M`0`3````/5`!``<```!14`$`!P```%E0`0`1````85`!``8```!S4`$`&```
M`'I0`0`&````DU`!`!,```":4`$`$````*Y0`0`2````OU`!``(```#24`$`
M!@```-50`0`,````W%`!``D```#I4`$`$0```/-0`0`B````!5$!``<````H
M40$`!P```#!1`0`+````.%$!``4```!$40$``@```$I1`0`+````35$!`%<!
M``!940$`$P```+%2`0`1````Q5(!``X```#74@$`"0```.92`0`+````\%(!
M``@```#\4@$``0````53`0`5````!U,!`!H````=4P$`*@```#A3`0`A````
M8U,!`"(```"%4P$`&@```*A3`0`2````PU,!`"H```#64P$`"P````%4`0`F
M````#50!`!(````T5`$`#0```$=4`0`.````550!``4```!D5`$`(P```&I4
M`0`*````CE0!`!````"95`$`#@```*I4`0`2````N50!``\```#,5`$`90``
M`-Q4`0`0````0E4!``P```!350$`#P```&!5`0`,````<%4!`!````!]50$`
M#@```(Y5`0`0````G54!`!$```"N50$`!@```,!5`0#"````QU4!``\```"*
M5@$`%0```)I6`0`5````L%8!``T```#&5@$`%0```-16`0`5````ZE8!``D`
M````5P$`"@````I7`0`\````%5<!`!4```!25P$`,````&A7`0!#````F5<!
M`%X```#=5P$`8````#Q8`0!<````G5@!`&8```#Z6`$`,@```&%9`0`)````
ME%D!`!(```">60$`!P```+%9`0`*````N5D!``X```#$60$`!0```--9`0`&
M````V5D!`!(```#@60$`"@```/-9`0`)````_ED!``T````(6@$`+@```!9:
M`0`M````15H!`!@```!S6@$`&@```(Q:`0`6````IUH!``H```"^6@$`!0``
M`,E:`0`.````SUH!``\```#>6@$`#````.Y:`0`0````^UH!`!$````,6P$`
M&P```!Y;`0`6````.EL!`!0```!16P$`#````&9;`0`3````<UL!``H```"'
M6P$`*````));`0`4````NUL!`!4```#06P$`#@```.9;`0!;````]5L!`#@`
M``!17`$`(0```(I<`0`&````K%P!``L```"S7`$`.0```+]<`0`(````^5P!
M``D````"70$`"@````Q=`0`'````%UT!``<````?70$`!0```"==`0`%````
M+5T!``<````S70$`!@```#M=`0`>````0ET!``T```!A70$`#P```&]=`0`9
M````?UT!`!4```"970$`)P```*]=`0`.````UUT!`"<```#F70$`'`````Y>
M`0`B````*UX!`"(```!.7@$`%0```'%>`0`6````AUX!`!(```">7@$`%P``
M`+%>`0`:````R5X!``<```#D7@$`!@```.Q>`0`(````\UX!``X```#\7@$`
M!P````M?`0`)````$U\!`!(````=7P$`!P```#!?`0`,````.%\!`!(```!%
M7P$`(0```%A?`0`'````>E\!``T```""7P$`"````)!?`0`5````F5\!``P`
M``"O7P$`#````+Q?`0`_````R5\!`#\````)8`$`"0```$E@`0`'````4V`!
M`!,```!;8`$`!0```&]@`0`%````=6`!`!````![8`$`"P```(Q@`0`6````
MF&`!`#<```"O8`$`$````.=@`0`E````^&`!`"<````>80$`)P```$9A`0`D
M````;F$!``\```"380$`!@```*-A`0`)````JF$!``@```"T80$`-@```+UA
M`0`_````]&$!`#4````T8@$`70```&IB`0`T````R&(!`#0```#]8@$`00``
M`#)C`0!#````=&,!`#0```"X8P$`1P```.UC`0`H````-60!`"H```!>9`$`
M10```(ED`0`T````SV0!`#H````$90$`+````#]E`0`9````;&4!`!T```"&
M90$`+@```*1E`0`K````TV4!`"L```#_90$`&P```"MF`0`+````1V8!``\`
M``!39@$`!@```&-F`0`*````:F8!`!@```!U9@$`'@```(YF`0`&````K68!
M``<```"T9@$`%````+QF`0`*````T68!``@```#<9@$`+@```.5F`0`*````
M%&<!``P````?9P$`!@```"QG`0`&````,V<!``4````Z9P$`!P```$!G`0`&
M````2&<!``P```!/9P$`*````%QG`0`/````A6<!``P```"59P$`"0```*)G
M`0`'````K&<!``P```"T9P$`!0```,%G`0`/````QV<!``8```#79P$`$@``
M`-YG`0`(````\6<!``@```#Z9P$`!`````-H`0`-````"&@!``@````6:`$`
M)P```!]H`0`0````1V@!``@```!8:`$`#0```&%H`0`,````;V@!``<```!\
M:`$``P```(1H`0`#````B&@!`!,```",:`$`$````*!H`0`C````L6@!``D`
M``#5:`$`!0```-]H`0`)````Y6@!``<```#O:`$`1@```/=H`0`A````/FD!
M`#H```!@:0$`)@```)MI`0`<````PFD!``8```#?:0$`!````.9I`0`2````
MZVD!`"````#^:0$`(0```!]J`0`O````06H!`"$```!Q:@$`*````)-J`0!A
M````O&H!`"D````>:P$`"0```$AK`0`*````4FL!`!````!=:P$`%0```&YK
M`0`-````A&L!``P```"2:P$`#````)]K`0`,````K&L!``P```"Y:P$`#```
M`,9K`0`,````TVL!`!0```#@:P$`"@```/5K`0`7`````&P!`!L````8;`$`
M$0```#1L`0`3````1FP!`!4```!:;`$`!````'!L`0`%````=6P!`!$```![
M;`$`2P```(UL`0!3````V6P!``8````M;0$`$P```#1M`0`%````2&T!``4`
M``!.;0$`(````%1M`0`8````=6T!``\```".;0$`$````)YM`0`6````KVT!
M`!\```#&;0$`,````.9M`0`+````%VX!`"`````C;@$`!@```$1N`0`5````
M2VX!``T```!A;@$`$P```&]N`0`/````@VX!`!<```"3;@$`$@```*MN`0`4
M````OFX!`!<```#3;@$`#````.MN`0`&````^&X!`!$```#_;@$`"````!%O
M`0`7````&F\!`!0````R;P$`$@```$=O`0`(````6F\!``0```!C;P$`#```
M`&AO`0`+````=6\!``8```"!;P$`$P```(AO`0`*````G&\!``<```"G;P$`
M#0```*]O`0`)````O6\!``P```#';P$`!P```-1O`0`&````W&\!``L```#C
M;P$`"````.]O`0`*````^&\!``\````#<`$`0P```!-P`0`:````5W`!`!(`
M``!R<`$`*@```(5P`0`%````L'`!`!\```"V<`$`$P```-9P`0`4````ZG`!
M`#,```#_<`$`0@```#-Q`0`D````=G$!``P```";<0$`)@```*AQ`0`=````
MSW$!``X```#M<0$`!0```/QQ`0`+`````G(!``8````.<@$`!@```!5R`0`9
M````''(!``X````V<@$`!P```$5R`0`*````37(!`!$```!8<@$`)0```&IR
M`0`Q````D'(!`"<```#"<@$`,P```.IR`0`;````'G,!`#`````Z<P$`'0``
M`&MS`0`C````B7,!`#D```"M<P$`'P```.=S`0`G````!W0!`"D````O=`$`
M(0```%ET`0`A````>W0!`"<```"==`$`0@```,5T`0`A````"'4!`"$````J
M=0$`*P```$QU`0`?````>'4!`!\```"8=0$`.@```+AU`0`B````\W4!`!4`
M```6=@$`)P```"QV`0`@````5'8!`"L```!U=@$`%0```*%V`0"2````MW8!
M`!H```!*=P$`'P```&5W`0`?````A7<!`"````"E=P$`+@```,9W`0`=````
M]7<!`!\````3>`$`(````#-X`0`L````5'@!`"X```"!>`$`,````+!X`0`O
M````X7@!`*$````1>0$`*P```+-Y`0`@````WWD!`"0`````>@$`(P```"5Z
M`0`L````27H!`$````!V>@$`1````+=Z`0`/````_'H!``,````,>P$`!P``
M`!![`0`#````&'L!``\````<>P$`"````"Q[`0`9````-7L!`!(```!/>P$`
M$@```&)[`0`'````=7L!``4```!]>P$`&````(-[`0`6````G'L!`!D```"S
M>P$`%````,U[`0`7````XGL!`!$```#Z>P$`%`````Q\`0`3````(7P!`$X`
M```U?`$`!P```(1\`0`/````C'P!``8```"<?`$`$P```*-\`0`9````MWP!
M`!L```#1?`$`$````.U\`0`"````_GP!`%`````!?0$`"@```%)]`0`/````
M77T!``X```!M?0$`!P```'Q]`0`8````A'T!`!,```"=?0$`!0```+%]`0`.
M````MWT!``@```#&?0$`$````,]]`0`3````X'T!``8```#T?0$`"@```/M]
M`0`.````!GX!`!0````5?@$`"P```"I^`0`&````-GX!``L````]?@$`#```
M`$E^`0`+````5GX!``T```!B?@$`*@```'!^`0`+````FWX!``T```"G?@$`
M*P```+5^`0`4````X7X!`!<```#V?@$`00````Y_`0`+````4'\!`!<```!<
M?P$`&0```'1_`0`5````CG\!`!,```"D?P$`'P```+A_`0`,````V'\!``8`
M``#E?P$`#P```.Q_`0`&````_'\!`#D````#@`$`.````#V``0`'````=H`!
M``P```!^@`$`'P```(N``0`.````JX`!`!H```"Z@`$`&@```-6``0`)````
M\(`!`!T```#Z@`$`$0```!B!`0`D````*H$!`!P```!/@0$`"@```&R!`0`3
M````=X$!``@```"+@0$`#@```)2!`0`D````HX$!`$````#(@0$`#@````F"
M`0`8````&((!`#`````Q@@$`"````&*"`0`+````:X(!`"0```!W@@$`#P``
M`)R"`0`'````K((!`!````"T@@$`5@```,6"`0`%````'(,!``<````B@P$`
M!P```"J#`0`.````,H,!``X```!!@P$`$````%"#`0`1````88,!`!@```!S
M@P$`$@```(R#`0`8````GX,!`!8```"X@P$`"````,^#`0`&````V(,!``L`
M``#?@P$`#````.N#`0`"````^(,!``H```#[@P$`$`````:$`0`G````%X0!
M`!D````_A`$`%````%F$`0`&````;H0!``T```!UA`$`#@```(.$`0`/````
MDH0!`#H```"BA`$`+0```-V$`0`.````"X4!`!$````:A0$`9P```"R%`0`4
M````E(4!`!0```"IA0$`%@```+Z%`0`'````U84!``4```#=A0$`'P```..%
M`0`L`````X8!`"(````PA@$`'@```%.&`0`B````<H8!`!H```"5A@$`&P``
M`+"&`0`%````S(8!``<```#2A@$`!P```-J&`0`(````XH8!`!(```#KA@$`
M$0```/Z&`0`2````$(<!`!$````CAP$`(````#6'`0`4````5H<!``\```!K
MAP$`#P```'N'`0`'````BX<!``@```"3AP$`%````)R'`0`6````L8<!`#``
M``#(AP$`#P```/F'`0`+````"8@!``<````5B`$`(````!V(`0`;````/H@!
M`"0```!:B`$`(P```'^(`0`?````HX@!`!\```##B`$`*0```..(`0`<````
M#8D!`!8````JB0$`!@```$&)`0`<````2(D!``H```!EB0$`#0```'")`0`%
M````?HD!``8```"$B0$`"````(N)`0`+````E(D!``T```"@B0$`$````*Z)
M`0`4````OXD!``X```#4B0$`#@```..)`0`/````\HD!``4````"B@$`"```
M``B*`0`B````$8H!`",````TB@$`%0```%B*`0`.````;HH!`!$```!]B@$`
M$````(^*`0`H````H(H!``L```#)B@$`!0```-6*`0`4````VXH!`!4```#P
MB@$`#`````:+`0`-````$XL!``<````ABP$`!````"F+`0`<````+HL!``\`
M``!+BP$`!0```%N+`0`A````88L!``T```"#BP$`DP```)&+`0`5````)8P!
M``D````[C`$`"@```$6,`0`3````4(P!``P```!DC`$`#@```'&,`0`(````
M@(P!`!(```")C`$``@```)R,`0`(````GXP!``8```"HC`$`$0```*^,`0`.
M````P8P!`!$```#0C`$`'0```.*,`0`)`````(T!``H````*C0$`#P```!6-
M`0`(````)8T!``D````NC0$`!0```#B-`0`<````/HT!``D```!;C0$`!@``
M`&6-`0`0````;(T!``\```!]C0$`!P```(V-`0`%````E8T!``4```";C0$`
M"0```*&-`0`'````JXT!`!$```"SC0$`!````,6-`0`%````RHT!``T```#0
MC0$`"P```-Z-`0`*````ZHT!``<```#UC0$`%````/V-`0`)````$HX!``<`
M```<C@$`#P```"2.`0`C````-(X!`$@```!8C@$`*P```*&.`0`K````S8X!
M``8```#YC@$`"@````"/`0`$````"X\!``D````0CP$`"````!J/`0`4````
M(X\!``L````XCP$`!@```$2/`0`-````2X\!``8```!9CP$`!````&"/`0!&
M````98\!`$\```"LCP$`2P```/R/`0`@````2)`!``4```!ID`$`#@```&^0
M`0`$````?I`!``8```"#D`$`!@```(J0`0`8````D9`!`!0```"JD`$`%0``
M`+^0`0`'````U9`!``0```#=D`$`%@```.*0`0`$````^9`!``\```#^D`$`
M&P````Z1`0`&````*I$!``4````QD0$`)P```#>1`0`$````7Y$!``H```!D
MD0$`#0```&^1`0`.````?9$!``@```",D0$`"0```)61`0`%````GY$!`#``
M``"ED0$`,@```-:1`0`Z````"9(!`"````!$D@$`20```&62`0`Y````KY(!
M`"D```#ID@$`.````!.3`0`J````3),!`"P```!WDP$`(0```*23`0`1````
MQI,!`!````#8DP$`"P```.F3`0`E````]9,!`"<````;E`$`(0```$.4`0`C
M````990!``<```")E`$`"0```)&4`0`*````FY0!``8```"FE`$`*0```*V4
M`0`I````UY0!`#(````!E0$`"0```#25`0`?````/I4!`"T```!>E0$`%@``
M`(R5`0`1````HY4!``<```"UE0$`"P```+V5`0`-````R94!`!````#7E0$`
M#P```.B5`0!`````^)4!`(T````YE@$`9````,>6`0`1````+)<!``@````^
MEP$`"0```$>7`0`0````49<!`!$```!BEP$`#````'27`0`%````@9<!`!``
M``"'EP$`$````)B7`0`.````J9<!`!,```"XEP$`'````,R7`0`F````Z9<!
M`'0````0F`$`$````(68`0`%````EI@!`!4```"<F`$`"0```+*8`0`$````
MO)@!``L```#!F`$`'@```,V8`0`5````[)@!``H````"F0$`#@````V9`0`0
M````')D!`!,````MF0$`(@```$&9`0`@````9)D!`"````"%F0$`'@```*:9
M`0`D````Q9D!`"(```#JF0$`&@````V:`0`U````*)H!`!(```!>F@$`$```
M`'&:`0`2````@IH!`!(```"5F@$`%````*B:`0`5````O9H!`!,```#3F@$`
M$````.>:`0`2````^)H!`"D````+FP$`$P```#6;`0`5````29L!`$H```!?
MFP$`'````*J;`0`,````QYL!`!$```#4FP$`(0```.:;`0`5````")P!`!$`
M```>G`$`$@```#"<`0`=````0YP!`!\```!AG`$`%@```(&<`0`7````F)P!
M`!4```"PG`$`$P```,:<`0`=````VIP!`"````#XG`$`)0```!F=`0`3````
M/YT!`!0```!3G0$`%````&B=`0`<````?9T!`!4```":G0$`%0```+"=`0`9
M````QIT!``L```#@G0$`&P```.R=`0`<````")X!``0````EG@$`!P```"J>
M`0`)````,IX!`!<````\G@$`!@```%2>`0`1````6YX!``H```!MG@$`!@``
M`'B>`0`'````?YX!``@```"'G@$`!@```)">`0`4````EYX!``8```"LG@$`
M"````+.>`0`(````O)X!``<```#%G@$`!P```,V>`0`0````U9X!``X```#F
MG@$`$@```/6>`0`0````")\!``D````9GP$`%0```".?`0`%````.9\!`#``
M```_GP$`$P```'"?`0`.````A)\!`!````"3GP$`#@```*2?`0`.````LY\!
M``X```#"GP$`*P```-&?`0`&````_9\!``@````$H`$`-0````V@`0`>````
M0Z`!``X```!BH`$`!@```'&@`0`)````>*`!``D```""H`$`!0```(R@`0`D
M````DJ`!`!4```"WH`$`&0```,V@`0`6````YZ`!`!0```#^H`$`(0```!.A
M`0`E````-:$!`"T```!;H0$`!@```(FA`0`$````D*$!``@```"5H0$`'```
M`)ZA`0`'````NZ$!``4```##H0$`#````,FA`0`+````UJ$!``8```#BH0$`
M!````.FA`0`'````[J$!`!4```#VH0$`#`````RB`0`.````&:(!``\````H
MH@$`&````#BB`0`9````4:(!`!,```!KH@$`'0```'^B`0`3````G:(!`!,`
M``"QH@$`"0```,6B`0`&````SZ(!`!````#6H@$`/P```.>B`0`&````)Z,!
M``\````NHP$`'@```#ZC`0`1````7:,!`!4```!OHP$`#````(6C`0`.````
MDJ,!``L```"AHP$`"0```*VC`0`/````MZ,!``P```#'HP$`#0```-2C`0`=
M````XJ,!`"(`````I`$`(@```".D`0`H````1J0!``P```!OI`$`!P```'RD
M`0`+````A*0!`!,```"0I`$`%````*2D`0`&````N:0!``\```#`I`$`(@``
M`-"D`0`-````\Z0!``\````!I0$`'@```!&E`0!E````,*4!`"````"6I0$`
M#````+>E`0`'````Q*4!``8```#,I0$`'@```-.E`0`=````\J4!`!H````0
MI@$`"0```"NF`0`"````-:8!``0````XI@$`(````#VF`0`&````7J8!``4`
M``!EI@$`*@```&NF`0`*````EJ8!``<```"AI@$`"@```*FF`0`/````M*8!
M``X```#$I@$`!@```-.F`0`'````VJ8!``H```#BI@$`!0```.VF`0`%````
M\Z8!`(,```#YI@$`#````'VG`0`/````BJ<!`!@```":IP$`"0```+.G`0`*
M````O:<!`!X```#(IP$`+````.>G`0`/````%*@!``H````DJ`$`$````"^H
M`0`*````0*@!``D```!+J`$`&@```%6H`0`I````<*@!`"<```":J`$`)@``
M`,*H`0`>````Z:@!`!8````(J0$`"````!^I`0`)````**D!``H````RJ0$`
M!P```#VI`0`,````1:D!``T```!2J0$`!@```&"I`0!2````9ZD!``\```"Z
MJ0$`#@```,JI`0`)````V:D!`"````#CJ0$`60````2J`0`:````7JH!``8`
M``!YJ@$`'@```("J`0`M````GZH!``@```#-J@$`!P```-:J`0`?````WJH!
M``@```#^J@$`"P````>K`0`G````$ZL!`"8````[JP$`)0```&*K`0`)````
MB*L!``H```"2JP$`(@```)VK`0!<````P*L!`!0````=K`$`)@```#*L`0`4
M````6:P!``(```!NK`$`$0```'&L`0`+````@ZP!`!8```"/K`$`#@```*:L
M`0`'````M:P!`!(```"]K`$`!@```-"L`0`(````UZP!`!$```#@K`$`#0``
M`/*L`0`*`````*T!``P````+K0$`,P```!BM`0`'````3*T!`!$```!4K0$`
M$@```&:M`0`@````>:T!`!<```":K0$`#P```+*M`0`1````PJT!``\```#4
MK0$`#P```.2M`0`/````]*T!``\````$K@$`"````!2N`0`<````':X!`!X`
M```ZK@$`"P```%FN`0`2````9:X!`!T```!XK@$`#````):N`0`7````HZX!
M``\```"[K@$`#0```,NN`0`$````V:X!``<```#>K@$`!0```.:N`0`%````
M[*X!``H```#RK@$`%0```/VN`0`1````$Z\!`!H````EKP$`%@```$"O`0`4
M````5Z\!`!<```!LKP$`'@```(2O`0`=````HZ\!`!H```#!KP$`!@```-RO
M`0`*````XZ\!``X```#NKP$`#0```/VO`0`'````"[`!`",````3L`$`#0``
M`#>P`0`-````1;`!`!H```!3L`$`)@```&ZP`0`4````E;`!``<```"JL`$`
M$````+*P`0`(````P[`!`!0```#,L`$`$P```.&P`0`)````];`!``D```#_
ML`$`!0````FQ`0`'````#[$!``(````7L0$`!````!JQ`0`"````'[$!`$0`
M```BL0$`0P```&>Q`0`-````J[$!`"(```"YL0$`-@```-RQ`0`,````$[(!
M`"D````@L@$`'0```$JR`0`B````:+(!`"(```"+L@$`)P```*ZR`0`0````
MUK(!`!0```#GL@$`'@```/RR`0`5````&[,!`!@````QLP$`%P```$JS`0`3
M````8K,!`!<```!VLP$`'````(ZS`0`:````J[,!`"\```#&LP$`+P```/:S
M`0`S````)K0!`#````!:M`$`,0```(NT`0`N````O;0!`&L```#LM`$`)0``
M`%BU`0`9````?K4!``L```"8M0$`&P```*2U`0`*````P+4!`!4```#+M0$`
M*@```.&U`0`L````#+8!`"@````YM@$`"0```&*V`0!;````;+8!`$T```#(
MM@$`"0```!:W`0`@````(+<!`"8```!!MP$`#@```&BW`0`8````=[<!`!L`
M``"0MP$`!0```*RW`0`*````LK<!``@```"]MP$`$````,:W`0`2````U[<!
M``L```#JMP$`"@```/:W`0`-`````;@!`"4````/N`$`"0```#6X`0`)````
M/[@!`!(```!)N`$`%0```%RX`0`0````<K@!`#D```"#N`$``@```+VX`0`'
M````P+@!``X```#(N`$`!P```->X`0`'````W[@!`!,```#GN`$`"````/NX
M`0`X````!+D!``X````]N0$`&0```$RY`0`$````9KD!`#````!KN0$`'```
M`)RY`0`L````N;D!`%4```#FN0$`%@```#RZ`0!'````4[H!`",```";N@$`
M$0```+^Z`0`)````T;H!`!````#;N@$`$0```.RZ`0`,````_KH!`!,````+
MNP$`#````!^[`0`;````++L!`!L```!(NP$``P```&2[`0`+````:+L!`!(`
M``!TNP$`*````(>[`0`<````L+L!`!X```#-NP$`$P```.R[`0`2`````+P!
M`"<````3O`$`"0```#N\`0`1````1;P!`!(```!7O`$`!P```&J\`0`*````
M<KP!``<```!]O`$`#@```(6\`0`'````E+P!`!````"<O`$`'````*V\`0`2
M````RKP!``4```#=O`$`"````..\`0`%````[+P!`!P```#RO`$`!@````^]
M`0`1````%KT!``@````HO0$`$0```#&]`0`(````0[T!`!H```!,O0$`#@``
M`&>]`0`K````=KT!`!<```"BO0$`"0```+J]`0`*````Q+T!`!T```#/O0$`
M!0```.V]`0`3````\[T!``4````'O@$`*`````V^`0`'````-KX!``D````^
MO@$`'````$B^`0`\````9;X!``8```"BO@$`&P```*F^`0`0````Q;X!``@`
M``#6O@$`$P```-^^`0`+````\[X!``0```#_O@$`"`````2_`0`+````#;\!
M``<````9OP$`"0```"&_`0`(````*[\!``<````TOP$`!P```#R_`0`5````
M1+\!`"T```!:OP$`.P```(B_`0`7````Q+\!`"````#<OP$`%0```/V_`0`^
M````$\`!`!P```!2P`$`'0```&_``0`E````C<`!`%@```"SP`$`(`````S!
M`0`%````+<$!``H````SP0$`!P```#[!`0`)````1L$!`!(```!0P0$`%0``
M`&/!`0`X````><$!`",```"RP0$`'P```-;!`0`U````]L$!`#H````LP@$`
M"@```&?"`0`:````<L(!``P```"-P@$`"@```)K"`0`A````I<(!`!,```#'
MP@$`$@```-O"`0`.````[L(!``<```#]P@$`#P````7#`0`)````%<,!`!``
M```?PP$`#@```###`0`:````/\,!`!<```!:PP$`,````'+#`0`+````H\,!
M`!\```"OPP$`!0```,_#`0`&````U<,!``<```#<PP$`'@```.3#`0`,````
M`\0!``0````0Q`$`$````!7$`0`/````)L0!``D````VQ`$`#````$#$`0`.
M````3<0!`!8```!<Q`$`!0```'/$`0`$````><0!`!(```!^Q`$`,0```)'$
M`0!$````P\0!`!<````(Q0$`!P```"#%`0`C````*,4!`!@```!,Q0$`%```
M`&7%`0`.````>L4!``\```")Q0$`#0```)G%`0`-````I\4!`"\```"UQ0$`
M!@```.7%`0`+````[,4!``T```#XQ0$`#P````;&`0`+````%L8!`#P````B
MQ@$`!@```%_&`0`>````9L8!``\```"%Q@$`$P```)7&`0`G````J<8!`!\`
M``#1Q@$`.P```/'&`0`\````+<<!`#@```!JQP$`$0```*/'`0`(````M<<!
M`!$```"^QP$`$P```-#'`0`8````Y,<!``@```#]QP$`$`````;(`0`6````
M%\@!``<````NR`$`$0```#;(`0`<````2,@!``L```!ER`$`!0```''(`0`,
M````=\@!``L```"$R`$`$````)#(`0`%````H<@!``<```"GR`$`"@```*_(
M`0`3````NL@!`!,```#.R`$`#````.+(`0`,````[\@!``8```#\R`$`"0``
M``/)`0`V````#<D!`"@```!$R0$`(P```&W)`0`'````D<D!`"````"9R0$`
M!@```+K)`0`D````P<D!`!4```#FR0$`*````/S)`0`1````)<H!`!$````W
MR@$`'````$G*`0`#````9LH!``@```!JR@$`$@```'/*`0`"````ALH!``P`
M``")R@$`%````);*`0`+````J\H!`!@```"WR@$`'````-#*`0`8````[<H!
M``4````&RP$`"@````S+`0`4````%\L!`!P````LRP$`#0```$G+`0`'````
M5\L!``P```!?RP$`"@```&S+`0`1````=\L!`$H```")RP$`'````-3+`0`W
M````\<L!`!@````IS`$`!0```$+,`0`$````2,P!``H```!-S`$`$0```%C,
M`0`2````:LP!`!<```!]S`$`%0```)7,`0`0````J\P!`!H```"\S`$`#@``
M`-?,`0`D````YLP!``\````+S0$`$````!O-`0!K````+,T!`"````"8S0$`
M'@```+G-`0`<````V,T!`"````#US0$`&````!;.`0`D````+\X!`!(```!4
MS@$`&0```&?.`0`4````@<X!``H```"6S@$`!P```*'.`0`+````J<X!``<`
M``"US@$`%````+W.`0`+````TLX!`#H```#>S@$`$P```!G/`0`:````+<\!
M``@```!(SP$`!0```%'/`0!*````5\\!`$\```"BSP$`30```/+/`0!D````
M0-`!``<```"ET`$`*````*W0`0`L````UM`!``H````#T0$`"`````[1`0`-
M````%]$!`#(````ET0$`!0```%C1`0!2````7M$!`"P```"QT0$`)````-[1
M`0`.`````](!`"`````2T@$`'````#/2`0`C````4-(!`!T```!TT@$`(P``
M`)+2`0`:````MM(!``P```#1T@$`!P```-[2`0`0````YM(!`!$```#WT@$`
M%`````G3`0`(````'M,!`$`````GTP$`#````&C3`0`(````==,!``T```!^
MTP$`&@```(S3`0`)````I],!``0```"QTP$`%@```+;3`0`(````S=,!``@`
M``#6TP$`!````-_3`0`+````Y-,!``L```#PTP$`%````/S3`0`3````$=0!
M``X````EU`$`%````#34`0`.````2=0!``<```!8U`$`$````&#4`0`<````
M<=0!``L```".U`$`#0```)K4`0`;````J-0!`"H```#$U`$`&````._4`0`>
M````"-4!`"H````GU0$`!````%+5`0`$````5]4!``T```!<U0$`!P```&K5
M`0`*````<M4!`!8```!]U0$`"````)35`0`*````G=4!``@```"HU0$`!P``
M`+'5`0`)````N=4!``D```##U0$`"0```,W5`0`,````U]4!``X```#DU0$`
M!````//5`0`.````^-4!``H````'U@$`"@```!+6`0`/````'=8!`!P````M
MU@$`"P```$K6`0`"````5M8!`!\```!9U@$`!P```'G6`0`&````@=8!`&@`
M``"(U@$`#````/'6`0`(````_M8!`"@````'UP$`1````##7`0`?````==<!
M`"T```"5UP$`6````,/7`0`F````'-@!`"D```!#V`$`&````&W8`0`=````
MAM@!``4```"DV`$`"@```*K8`0`-````M=@!``T```##V`$`"P```-'8`0`-
M````W=@!`!4```#KV`$`#P````'9`0`-````$=D!``\````?V0$`#P```"_9
M`0`$````/]D!``<```!$V0$`"````$S9`0`9````5=D!``@```!OV0$`!@``
M`'C9`0`'````?]D!`!,```"'V0$`!@```)O9`0`;````HMD!`!8```"^V0$`
M"P```-79`0`9````X=D!``P```#[V0$`%@````C:`0`,````']H!``@````L
MV@$`#P```#7:`0`2````1=H!``\```!8V@$`!@```&C:`0`7````;]H!``L`
M``"'V@$`'@```)/:`0`&````LMH!``@```"YV@$`#0```,+:`0`@````T-H!
M``D```#QV@$`"P```/O:`0`F````!]L!`!@````NVP$`$````$?;`0`&````
M6-L!``L```!?VP$`#@```&O;`0`)````>ML!``(```"$VP$`#@```(?;`0`'
M````EML!`"8```">VP$`*0```,7;`0`K````[]L!`!P````;W`$`+````#C<
M`0`I````9=P!`%H```"/W`$`#0```.K<`0!-````^-P!`#0```!&W0$`4P``
M`'O=`0!,````S]T!`"$````<W@$`,P```#[>`0`F````<MX!`#(```"9W@$`
M*P```,S>`0`3````^-X!`#T````,WP$`F`(``$K?`0`:````X^$!`!````#^
MX0$`/P````_B`0"%````3^(!`"X```#5X@$`)0````3C`0!$````*N,!`$\`
M``!OXP$`2@```+_C`0`L````"N0!`!D````WY`$`$````%'D`0`E````8N0!
M`!L```"(Y`$`'````*3D`0`H````P>0!`"<```#JY`$`*@```!+E`0`P````
M/>4!`!D```!NY0$`#0```(CE`0`K````EN4!`"0```#"Y0$`*````.?E`0`A
M````$.8!`!P````RY@$`.@```$_F`0!E````BN8!`#4```#PY@$`2P```";G
M`0`U````<N<!`"@```"HYP$`-@```-'G`0!<````".@!`#H```!EZ`$`+P``
M`*#H`0`H````T.@!`"P```#YZ`$`5P```";I`0!6````?ND!`$<```#5Z0$`
M10```!WJ`0`O````8^H!`"D```"3Z@$`*0```+WJ`0`I````Y^H!`&@````1
MZP$`8@```'KK`0!K````W>L!`+L```!)[`$`&@````7M`0`N````(.T!`#<`
M``!/[0$`*````(?M`0!D````L.T!`!@````5[@$`6````"[N`0`<````A^X!
M``L```"D[@$`S````+#N`0!/````?>\!`"(```#-[P$`/````/#O`0`@````
M+?`!`!@```!.\`$`,P```&?P`0`&````F_`!``<```"B\`$`!````*KP`0`,
M````K_`!`!````"\\`$`#````,WP`0`+````VO`!``<```#F\`$`$@```.[P
M`0`-`````?$!`((````/\0$`!@```)+Q`0`5````F?$!``0```"O\0$`!P``
M`+3Q`0`(````O/$!``4```#%\0$`4@```,OQ`0`$````'O(!`!D````C\@$`
M"@```#WR`0`2````2/(!`!````!;\@$``@```&SR`0`'````;_(!``8```!W
M\@$`$P```'[R`0`,````DO(!`!8```"?\@$`!@```+;R`0`4````O?(!``\`
M``#2\@$``P```.+R`0`N````YO(!``0````5\P$`!@```!KS`0`'````(?,!
M`!X````I\P$`/````$CS`0`N````A?,!`"\```"T\P$`%@```.3S`0`H````
M^_,!`#`````D]`$`(@```%7T`0`J````>/0!`"````"C]`$`(P```,3T`0`>
M````Z/0!`!P````']0$`+````"3U`0`D````4?4!`!H```!V]0$`+@```)'U
M`0`:````P/4!`"P```#;]0$`,`````CV`0`@````.?8!`"0```!:]@$`)```
M`'_V`0`?````I/8!`",```#$]@$`+````.CV`0`G````%?<!`"<````]]P$`
M)0```&7W`0`?````B_<!`"0```"K]P$`,````-#W`0`=`````?@!`"H````?
M^`$`-@```$KX`0`Y````@?@!`!H```"[^`$`)P```-;X`0!-````_O@!`"D`
M``!,^0$`+0```';Y`0`M````I/D!`"X```#2^0$`*`````'Z`0`F````*OH!
M`"$```!1^@$`)P```'/Z`0`X````F_H!`"H```#4^@$`-0```/_Z`0`,````
M-?L!``X```!"^P$`(````%'[`0`J````<OL!`"$```"=^P$`#P```+_[`0`/
M````S_L!`!H```#?^P$`&@```/K[`0`+````%?P!`"<````A_`$`#````$G\
M`0`*````5OP!`"4```!A_`$`*````(?\`0`B````L/P!`"<```#3_`$`(@``
M`/O\`0`'````'OT!`-P````F_0$`"P````/^`0`3````#_X!``<````C_@$`
M"@```"O^`0`0````-OX!`!(```!'_@$`'````%K^`0`#````=_X!`#,```![
M_@$`&P```*_^`0`8````R_X!``<```#D_@$`$@```.S^`0`2````__X!`#,`
M```2_P$`"````$;_`0`I````3_\!`!,```!Y_P$`$P```(W_`0`9````H?\!
M`#,```"[_P$`'0```.__`0`.````#0`"`",````<``(`#P```$```@`0````
M4``"`!<```!A``(`"@```'D``@`?````A``"``\```"D``(`'0```+0``@`/
M````T@`"`!X```#B``(`)@````$!`@`%````*`$"`!`````N`0(`!P```#\!
M`@`+````1P$"``D```!3`0(`.````%T!`@`&````E@$"``\```"=`0(`$0``
M`*T!`@`0````OP$"``L```#0`0(`#P```-P!`@`'````[`$"`!````#T`0(`
M"`````4"`@`;````#@("``@````J`@(`&P```#,"`@`;````3P("``L```!K
M`@(`#0```'<"`@`<````A0("``@```"B`@(`,0```*L"`@`1````W0("`!``
M``#O`@(`"``````#`@`"````"0,"``H````,`P(`&````!<#`@`+````,`,"
M``,````\`P(`"P```$`#`@`+````3`,"``H```!8`P(`%P```&,#`@`.````
M>P,"`!@```"*`P(`'@```*,#`@`,````P@,"`#D```#/`P(`(@````D$`@`C
M````+`0"`!D```!0!`(`#0```&H$`@!%````>`0"``8```"^!`(`&@```,4$
M`@!6````X`0"``\````W!0(`$````$<%`@`'````6`4"``0```!@!0(`!0``
M`&4%`@`1````:P4"`!8```!]!0(`!@```)0%`@`'````FP4"``<```"C!0(`
M"P```*L%`@`#````MP4"``P```"[!0(`#0```,@%`@`Y````U@4"`"X````0
M!@(`+````#\&`@`%````;`8"`!8```!R!@(`)0```(D&`@`B````KP8"`!\`
M``#2!@(`$P```/(&`@`"````!@<"``0````)!P(`#0````X'`@`*````'`<"
M``4````G!P(`!0```"T'`@`/````,P<"`$T```!#!P(`)````)$'`@`7````
MM@<"`"(```#.!P(`,````/$'`@!.````(@@"`!8```!Q"`(`?@```(@(`@`>
M````!PD"`%D````F"0(`*@```(`)`@!/````JPD"`#````#["0(`*````"P*
M`@`M````50H"`"T```"#"@(`*P```+$*`@`N````W0H"`"D````,"P(`*```
M`#8+`@`L````7PL"`#<```","P(`%````,0+`@`:````V0L"``P```#T"P(`
MJ`````$,`@`&````J@P"`+D```"Q#`(`A0```&L-`@"@````\0T"`"````"2
M#@(`5P```+,.`@`0````"P\"`!T````<#P(`$0```#H/`@`'````3`\"`!D`
M``!4#P(`'@```&X/`@!!````C0\"`!D```#/#P(`%@```.D/`@!7`````!`"
M`!H```!8$`(`#P```',0`@`*````@Q`"``4```".$`(`!@```)00`@`(````
MFQ`"``4```"D$`(`&0```*H0`@`)````Q!`"`!@```#.$`(`(@```.<0`@`/
M````"A$"``D````:$0(`#@```"01`@`)````,Q$"``P````]$0(`!P```$H1
M`@`%````4A$"`!````!8$0(`$````&D1`@`.````>A$"`!````")$0(`"@``
M`)H1`@`)````I1$"`!````"O$0(`"````,`1`@`3````R1$"``H```#=$0(`
M"P```.@1`@`8````]!$"``D````-$@(`!@```!<2`@`;````'A("`!@````Z
M$@(`#@```%,2`@`4````8A("``L```!W$@(`)@```(,2`@`4````JA("``<`
M``"_$@(`%0```,<2`@`'````W1("``@```#E$@(`(@```.X2`@`+````$1,"
M``(````=$P(``@```"`3`@`:````(Q,"``P````^$P(`!@```$L3`@`(````
M4A,"`!H```!;$P(`!@```'83`@`E````?1,"``(```"C$P(`!````*83`@`1
M````JQ,"`!<```"]$P(`"P```-43`@`)````X1,"`!````#K$P(`"@```/P3
M`@`6````!Q0"``<````>%`(`'````"84`@`*````0Q0"`!<```!.%`(``@``
M`&84`@`%````:10"`!````!O%`(`#````(`4`@`2````C10"`"D```"@%`(`
M!P```,H4`@`'````TA0"`!$```#:%`(`!0```.P4`@`"````\A0"``L```#U
M%`(``0```-,$```<!```,04``%\#````````G`$``&T"``"@!````````)0#
M``#'`0``_`8``'P``````````````(8"```J!P``"P$```````""!P``P0``
M`'<%```5!```\04``"P```#;`P``P@8``"0'```(`@```00``+P%```#!P``
M,0,```````"F`@``\`4``&0"``"R`@``#P0``($#````````````````````
M````U@0``%$%``"%!`````````````#V`0``<`(`````````````?P(``"X$
M````````(P$``*0%````````8P<``.0%``"0!@``)0$``'$&``#U!```;@(`
M`'`!```T!P``P@$``-$"```O!```;P,``$\'``!:````H@$``#,!``"*!P``
M`````'L!``#K````EP8``,`%``!=!P``2@4``,T&````````E`0``&("``#R
M````*0(``&8"````````VP0``(4&``#>!0````````````"E````````````
M````````F`,```````!`````Y08```````#-`0```````)T$``!(`@``OP4`
M``````#]`@``B0<````````,!0```````$\$``#,!0``[`(``"8%```7````
M`````#0```!8````O`$`````````````M0(``%H$``!E`P``:@,``%\!``"#
M!P``````````````````^@$``&0#``!O````U@$```````!^!@````````D'
M``"0`````````$T#``";`@```````!P#``!>!@``]`$``-\````H`P``W`$`
M`-`!``"V`P``1P,````````<!P``$@<``"4#``#Q````L`4``-($````````
M`````*L#``"D`````````,L%``!A`P``>0,``)4$```*!````````(L&``#`
M`0```````.$$``!Y!P``V0,``.<!````````_P4``$L'``"I`0``6`0``.0!
M````````3P```+X!```````````````````O`P``;0<```````"R````````
M`)@%``!G!```I08``.(!``!'!@```````"H```#[`0``:`$``%4'``#:`P``
M*08``*,$``!5!@``5@0``+`&````````G0(``%L```"3!@``BP,``*D`````
M````K`4``-,```"@`P``>@$``&<"``#"`P``*0<``'L#```K`````````#8`
M`````````````#$"``"#````Y`0```````#V!```>00``$4'````````]P``
M````````````DP(``+H%````````%P4``*H#```K`@``>P<```````!T!```
M.P(`````````````D`(``(X!``"*!```W````'T'``!7!0``F@,```,"```\
M!P``7@,```8!````````100````````N!P``GP,``*4!`````````````&<%
M``!Q`0````````````!#!@``VP```#X'``!*``````````("````````*0$`
M``````!6`P```````)P$````````S`$``&$$```6`P```````"<$``!A````
M```````````E!```=P```.X#``!G!@```````)T&````!@``>P`````````9
M!@``L00```,````$!P``W04``+@&``#)`P``?`(``!<'``#L````````````
M``!C`0```````.X"``":````D@```)X#````````FP$``"L%``!Q`@``\P,`
M`$8#``"^`@``N@$``-T$``#7!@``M`,``.,$``#*!```J@0````````9!P``
M%P(``+\$```8`0``L0(`````````````X@,``(\"````````?@$``/X%``!I
M`0``%P8``/@!```J`P``2P,``'(#``!'!```E@$``$<```#(`0``<0,``$\&
M```Z````808``%,```#6!@``=@(````````N!0``)@(``'0&``#M````"P8`
M``0```#D`@``?@,``(,%``")`0``DP0``/X"``!E!P``YP4``!<!````````
MGP$```X'``![`@``?@````4$```*!P``+@8``#4&````````4@(``+\`````
M````=P,``/\#````````"P```#,%`````````````&<'```H!@``W0``````
M``#T`@``0`<```````#8`P``V@0`````````````:`````T"``!S!@``````
M`-0&``#&!@``<0```*````#]!@``0@(```````";!```N0,``,`````$!```
M#P8``$P!``"4`@``N04``*`!``#!`0````````4`````````30<``-8"``!C
M`````````,0```````````````````#R!````````$`%``!P!P```````,X&
M````````%P,``((&`````````````%(%`````````````/,$``!W!```I`8`
M`&\$```(````7@```$D'``"Z`P``=@4``-X```"$`P``)`0``#L%``#X!@``
MG`,``'<"````````:@$``#X"``"_!@``[@4``+X$````````<`8```````")
M````I0(````````T!@```````!T'````````50$``"($```X`0```````&T$
M````````AP(``'D%``"`!0``U@`````````A`@``4`8``#<$```S`@``````
M``````"7`P``_P0```$'```'`P``:@8```````#Q`0``Q@```/`#``"/````
M7`<`````````````Z`8``(4#`````````````-T"```N`P``5P$``/4&````
M````Y0$``/X```!-````S00``!`%````````-@$``)`#``!]`0``EP```%D$
M``!_!```<P```*<%``!8`@``@@(```````!"!@``=@$``/X!````````YP0`
M```````D`````````/@$``!K!```Q@0``%D!```A!```!@```)\"``!>`@``
M```````````$!@``E`4```````#B!@``C@,``#X````K`0``%`(``-<#``"2
M!@``00<```````!L`P```````(X$``"C`````````,4#``!1````O0(``"P$
M```@!```Z00````````M!@``]@(``"\&``!8!0``````````````````J0(`
M`"0#`````````````+,!````````?0```"<#````````<P<```````"1!```
M`````,X!``#Q!@``"`$````````````````````!``!,!0``.08```````#)
M!0``$0$``%\$``#Z`P``G````+`#``#$`0```````'4$``!Q!```UP(``,H%
M``!\`0``C`$``````````````````/T%```U!````````#\'``"F!@``T`,`
M`*D&``#M`0``I@````````#O`@``````````````````K00``.L!``#Y!```
MWP,``"@$````````9@0``)\````0!@``N00``.H#````````R00``%L"``",
M!````````,0"``"^!0``0@4``'4'``#6!0``E`8```````!D!P``````````
M```;!````````/0#``!4````V0````````!(````E@````````!6`@``-P``
M`"`&```\`@``<P(```````#S`@````````@$``"W`@``I00``'@'````````
MVP8``!4`````````V00```````#\`````````!\%``"+!0``]P$``/<%``!\
M`P``V08``+0%``"5!0```P4```````````````````````"#!```OP(``,X"
M```-!P``F0,``/\"````````]`0``#\"``!3`0```````,4$```R`0``````
M`,L"``",``````````````!+`0````````````"[!@``"0$``-X!```F!```
MI`,``,T%``!S`0``,P0``!$&``"+!```8@`````````O````H08``#@"``!9
M`@``@`<``$@'``"-!0``&0````````"M````[P,``-(&``!\!0``,@```+T%
M``#*`@```````/<&``"W!@``6P4``$0!`````````````!T"```?!P``W`8`
M```````.!0```````&`!```Y`@``0P(``+L!``"``P```````"H!``!&````
MT`(``!0&````````?P```$(#```V!P``+0$``#$$``#A`0```````-(%``"T
M`@``Z`$``%0#``#X`P``?00```````"B`P``U`(``&(#``#K!0``````````
M``!?````'P(``#(#``#\`@```````',$````````@08``#<%```Z!0``&`0`
M``````!V````HP,```````"7!0``8@4``!("``!L`0``(@$```````".````
M`````&H%````````Q04``!H!``#@`0```````),#``"8`````````(4%```8
M`````````"P%``"&!````````!P```":!@``:08``/L"``"%`0```````$P#
M``!I!P``>@0``!`$``!E````5`4``,4&``!T`@``X```````````````MP,`
M`'4#`````````````````````````````%P!````````.0<``'X"``!L````
M``````````"(`@```````,\&```+`@``#P4``&T!```M`@``X`4``.<"``!/
M`P``#0$``&````!G`````````,`&``#9`@``N@8``````````````````.H`
M``"R!```*``````````P!P```````/,```"J!0``_0$``-4$```:````````
M````````````8@0```````#)!@``8`8``$X`````````$P(`````````````
M2@0``!8&```C````/P```((%``"H!```N`(``)$%``#D````0@0```````"X
M!0``004``!\!``"X`0```````)L%````````M0````('```L!P``````````
M``"P!````````&H'``![!0``9@```````````````````,X$```'`0``6`8`
M````````````X`8``&$'```[`0``.P0``'4"``#L!@``.00``"`'``#^!@``
M<@8```P!````````2`8``)X&``"\!```9@8```D%``!&!P``````````````
M````<P,``(L```!Z!P``T@,```$"``"C`0``+`,```````"S!````````"4'
M```!`P``ZP(``'````!N!@``V````!(&``!%`P``7@<``/,%``#I!@``T00`
M`#\#````````^P4``&8'``"@!@``T@(```````!K`0``T0```(H&```P````
MR`(``*$$``#L`0``X@```&H"``"F`0``7`(````````X`P```````%P&```K
M!```8`,``.$%````````SP```)8%``#8!@``10(`````````````E0$`````
M````````!P8``$8%``#_!@```````$D#``!L!0``5`<``-,!``"``0``````
M``````````````````````#]!```;`0```8$```^`P``'P0``-\$````````
M7`,``'X$```1`@``+`8``,L$```;`P```````'\&``!U````!0,``)$!````
M````K``````````$`@``>0$``"D$```U!P```````'H```!T````````````
M``!B`0``5`$```T````_`0``W@,``+4&```X!P`````````````F````````
M````````````B`4``(\$````````1@0```$&````````LP```%`!``"1!@``
ML@$``!8"``!0`@``AP,``&\'``#U`@``M@```/,&``#Q`P``40$``.($``#O
M!````````-`&````````+P(````````,!P``4`````````!4`@```````$P&
M``"!`@```````!P&````````]`8``(P&``"[````708```````#Y`0``A```
M`$8&````````=0$`````````````1`(``$@!```5`P```````"0!``!9`P``
M]0```)H%``!3!0``W08``#D!```:!P```````(@!``!<!0``5P0``$('``":
M`@``/0,``!$#``"N!0``20$```````"?!````````#X!``!J````?@4``*<#
M``"H!@``(`````````"N````2P```!(```"F!````0$``'D&````````U0$`
M`+H```#D`P``M@$`````````````:`0`````````````O@```+D```!R!```
M`````!$```!?!0``Y@0``"`#``"K`0``Y@```"("``"?!@``O0$``/(!```Z
M!@``@P8```````"!````$@0``+L"```]!```?P$``!L```"S`@```````+T#
M``!U!0``90(``(4`````````S0(``,0&``!_!0```````%<"``"?!0``\`$`
M`*T#````````B@4``'(!``"Q````@00```````#P!@```````!$'``!O`@``
M`````.T#````````$`(``!0!```M`P``1`0```````#5`P``WP(```````!\
M!@``204```````#;!0``AP0```````"R!@``]P(``*\$```%`@```````"$`
M``#\!0``=P$``#P#```*!@``]`4``/`"``!Q!0``N`,```````#4`P``Z`(`
M`%D&````````>P0``$$#````````*@(``)P%``#&!0``V@4``&$%````````
M```````'``!Z!0``1P(``#P```"\```````````````/`P`````````````0
M!P``-P8``!0$`````````````&$"```(!P``,P,```````!``0``/04`````
M``";!@````````````"'`0``R0```.D#``#D!@``O0```(L!``"]!```````
M`#8#```U`@``'04```````"'!@``K@0```<"``#K!```OP,`````````````
M`````$D$``!1!@``M00``',%``#$`P```````&L#``#:`0``L`$```````"3
M!0```````,H&``"B!0````````D#``!]`P``$P````T$``#%`0``"P0`````
M``!!`@``50```.,%````````K`,```,#```9!```!@8`````````````Z@0`
M`.P%```*`P``J`4``+<$```6````5`0``#<!``!5!0``I`(``/D"````````
M@`(``",%``#[`P``0P$``&H$`````````````#\%```3`0```````/(#``#'
M!```O@8```````!(`P```````,T#``!=!0``?`0``#T&``#Y````'@4``$8!
M````````JP```%8!``#H!```C0````````#.`P``.`8`````````````RP``
M`(<```#=`P````````````#,!````````%('````````&04```````#G`P``
M,0```,P#``")!0``$`$```X```!K!P``IP```,\$``!B!P``&`8``-H````A
M`0``H@(``)@"``!>!```+00``",'``!E`0``>`(``!0'```=!```V04``)P"
M``!=`````````.`$``!F!0``/P8``.8"````````L@4````````$`P``'@0`
M``````````````````0%````````DP$``(8&``!T`P``KP,``/H&````````
MD@0``(4"```>!@```````-P#````````6P$``%L'```4`P``\0(``#,'``!T
M!0``J`,``%T!```K!@``````````````````KP8``.`#``!.`P``_`0``#H'
M``!X!````````"\%``!H!@``U````*`"``#Y`P```````"@%``"&!P``[04`
M`'("````````*0`````````&`@````````L'``#E!````````%(&````````
M`````"<'```"!@```````$8"``````````````````#7`0``S0```#<#```$
M`0```````"L'``!R!P``8P8```````"!!0``;@$``*\"``#$!```+@(``%4$
M``````````````````"$!0``$P0``)$"``!7!@``T@```*X#``!)!@``-P<`
M`'P'````````T`0``!L%````````N@0`````````````@@$`````````````
M(P(``%H!````````&P<``#('```@`@``J`(``"8'````````.@0``(D"``!K
M````\@8``#D%```\`0``$04```````#E!0``B@```!P!``"K!```B0,```8%
M````````(@4``%T"````````Z@$```````#Z!````````-\!``!'!0``````
M`!,&``"(````Z0(``#0$``#E`P``JP4``,X%``#'`P```````#\$````````
M``````````#J`@``H0,``/X#```8!0``,P```/8%``!W!P```````&\&````
M````RP,``&\!```>`P``604```````"&````@P$```````"T````CP,``(0$
M```P!```MP$``)D"``"@!0``M@(``.4"````````,@0``*$````L`@``R`,`
M``L#````````C`4````````;!@``K`0``````````````````&L%````````
MV`$````````.!```"`8````````E````X0,``)X``````````````'(%```?
M!@```````!4!```^!0``'0```,P"``">!0``B08``(X"```A!0``E@(`````
M``!`!@``008``*$!``"A!0``)P(`````````````+0```$H'``"5`@``4@0`
M````````````-`(``/@%``!T`0``70,``#4!````````3@0``%8%``"B!```
M"0```,,%``"#`P```````%@!``!I`@``[`,``!D"````````P@(``%H'``!#
M`P``/`0``)`!``#F`0``XP,``%$$`````````````*P"```.`@``'`(``$X!
M``!(!```"@````````!-!@``_`$``"X```"-`0```````"T'``#M`@``Z0$`
M`,\!``!L`@````````````#:`@``PP(``"<```"S`P``D@4```````!N````
M$`````````"-!```&P$``'`$``!V!P````,``-\%``!3!P``L@,```<'``"-
M`P```````(T"``!G`0``@@,``+\!``!W!@``;@0``*H```!.`@``9`4`````
M``",`P``+P<``(($````````O`,``#X$```8`@```````#<"``"2`P``@@``
M```$```````````````````/`@``%0(``,(```"[`P```````-$&```P!0``
M[@```,$%````````2`4``!,'``!9!P```@0``%X!`````````````-D!``!*
M!@``\00``&T&```X!0``.P<``)H!``#A````O`(``+X#```6!```````````
M``"9!0``Z@4``/4#````````0P<``!D#``#L!```E0,```(#```)!@``C@8`
M``````!L!@``8`<``"X!```F!@```````&4&``!I`P```````%\&``"U`P``
M"@(``$D"```?````#`8``&0!`````````````$\"`````````````*8%```Q
M!@``L0$```T&``#2`0``-04``(8!``!<`````````#L&``#F`P``&@4``+L$
M``"M`@```````(````!Z`P``B`8``,@%``"$!@``W0$``#4#``#O`0``````
M```````,````E@,``&,"``">`@``\@4``````````````````&0$````````
M`````.D```"V!0``H@8````````>`0``P0,``#P&``!P!0``A`$``&L"````
M````300``.<&````````QP8``(\!````````PP```!X'````````8P0``'0'
M````````#04``#T!``!0!P``;0,``"(&``!$````%@<`````````````V`(`
M`$D````[`P``%P0```````#O````:P8````````*!0``4P,```<%```D!0``
MM@8``*D$```'!```1P$``$0&```````````````````@!0```````+````"O
M````,`8``.\&``#C`````````",&```2`P``P00``-H&`````````````'\#
M```,!```&`,``*P!````````N0$``.,&``#.`````````)(!``!_!P``Q0(`
M``(%````````-`$```````"H````+`$```X#````````D`0``!D!``"B````
M4`4```````#J!@``U0(```````````````````D$``"9`0``FP,``*H!```,
M`@``U04``/4%``#U`0``#0,```````"=`0``Q0````````#&`@``5P```#@`
M```H`@````````````#]`P``IP0``+L%````````P@4```````!/`0``'0$`
M`.T&``#Y!@``E@0``%`$````````K0$`````````````I`$``*D%``"P`@``
M9`8```````#6`P``%@4``*8#````````&@(````%````````AP<``($'``#1
M!0``XP$``*T&``#C`@``P08``*L"``!P`P``D`4``*\!````````TP4``*,&
M````````M04```````#/!0``;04```````#X`@```````-X&````````````
M`!\#``!^!P``M`0``*<&````````Q`4``*<!``!#````G0,``!L"````````
M3`0````````"`0``EP(``$\%``!``P``>@8``-P"````````1P<``&,%``"`
M!@``1`,``.4```!-!0``PP8```````````````````````#0````6P,``+<`
M``!Y`@``0P4```````!3!@``UP4``$H"```]````+04```````![!@``X`(`
M`&`$```:`P``````````````````PP0```````#3`P``X@(``'@#``"4````
MB`<``!H$````````````````````````000``!H&`````````````%$'````
M````*0,``/T```!7`P`````````````B!P``40,``#H"``"3````\P$``%4"
M``````````````X&````````F00```````!"`0``7P(``$L$``!,!P``;@4`
M`+$#````````A`(``$X&````````)@$```````#;`0```````+$%``!Q!P``
MW`0``&D%``"T!@``)P4``#T'``!$!P``2@,``&D$``#/`P```````&@"``"O
M!0``@`0``'8#``#1`P``4`,``)@!``#A`@``3`(``,($````````B`0``&P'
M``!R````````````````````^@(````````R!0``:`,```8'```C`P``?08`
M``````#H`P``EP0``+4!``#+!@``SP(``"@!``"7`0``RP$```````!7!P``
M4P(``%H#``"&!0```````#`"``#X````F0````````#,````K@(``#0%````
M````UP````````"E!0``````````````````)08``)D&``#N`0``(0,``#L`
M``"8!@``00$``,8#``",`@``!0<``!4%``!E!0``````````````````(@,`
M`(H"```>````A`<``%8'``"M!0``10```'8&```X!```PP$``-0!``!"````
M900``"@'``!O!0``]@8``%8````.`0``^@4``$T"``#^!```6@(``*,%```%
M!@``Z04``"(```!%!0```````$L&``"8!```G`8``,$"```#!```````````
M``"]!@``;@,``!4&``#N!@```````'T%``#H````-`,``%H%```2!0``#P$`
M`!X"````````:`4````````O`0``/0(``$T!```P`0``)0(``-4`````````
M)04``&8#``#V````>@(``(\&`````````````*,"````````K@$``/P#``!A
M`0``N````)$```````````````````"5````)@,```\``````````````(H#
M````````?0(``,<%``#&`0```````(8#```A!P``G@$```````#;`@``R0$`
M``H!``!5`P``>0```-0$``##`P```````,H!```3`P``````````````````
M;@<``/`$``!V!```"`,````````^!@``V`0```````"A`@``;0```(\%```8
M!P```````%@'```J!````@```&`"```<!0```````/D%``!.!0```````,@`
M```,`P``BP(```````"E`P``"`4````````Y`P``_P$```\'``!=!```"0(`
M``````!,````F@0``-$!```I!0``Z`4```````!X`````````&8!``#P````
M[P4``$L"``"W!0``!04```````!2````ZP,``$L%``#5!@``.0```,@$``"=
M!0``P`(``%\'```#`0``>`8``$0%``#?!@`````````````'````-@4``"L#
M``#Z````R`8``!4'```#!@``R@```'@!```2`0``]P,``.8%``"K!@``4P0`
M`%(!````````!@,``+D"``!.!P``%````)$#``"J`@``7`0``-<$```Z`P``
M,`,``/0```!`!````````-X"``"Q!@````````````#<!0``8@8``,`#``#*
M`P``[00``%L$``"4`0``B`,``&@'``"%!P`````````````3!0``C08``*0$
M```Q!P``B@$``$,$``";````(08``/("``!U!@````````````"V!```````
M`!`#``#K!@``8`4```````#[!```E08``.(%```J!@````````````#W!```
M`````+H"````````M`$``$4&````````K@8``%8&```\!0```````$$````V
M!````````#("`````````04```````".!0``'0,``*<"`````````````%(#
M```G!@``U`4``/L&````````J`$``&,#```1!`````````````!4!@``)P$`
M`+,%````````Y@8``-,"````````AP4``(,"``"Y!@``6`,``($!````````
M[@0``"0"``#3!@```````#4```"\!@``R0(``*D#``!9`````````#$!````
M````X08``+,&```+!0``10$``%L&``"X!```-@8```````!:!@```````&0`
M```D!@``QP(```````"=````_P````4!``!``@``B00``&D```#8!0``(`$`
M`)X$````````D@(``!0%````````.@$``-`%````````%@$```````!X!0``
MQP```,P&`````````````%X%```C!```]@,``"H%``#G````P`0``*H&```=
M!@``2@$``#(&`````@``9P,``-X$```V`@````````````#[````K`8``)8&
M``!1`@```````#,&````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I
M`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D
M87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T
M(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H
M92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N
M9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@
M=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S
M(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W
M960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P
M87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`
M)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N
M<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS
M(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`
M)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T
M:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E
M<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E
M<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@
M)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S
M($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G
M92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R
M92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN
M9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L
M(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@
M=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R
M;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@
M<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C
M8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@
M=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R
M:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O
M(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)
M344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP
M="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-
M24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@
M82!M97-S86=E+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@
M96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-
M(%)A:6X`04T@4VAO=V5R<P!!32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$
M`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D
M;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E
M<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T
M:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I
M;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!
M9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D
M(&$@8VAI;&0@9W)O=7`@=&\@(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N
M('1O("(E<R(`061D(&$@;F5W('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M
M96UB97)S`$%D9"!P86ER`$%D9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@
M4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S
M<R!B;V]K`$%D9"!U<V5R`$%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T
M(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ
M("5S+@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN
M(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E
M<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE
M<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI
M80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H
M96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L
M;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!
M;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!
M;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S
M<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A
M;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N
M:VYO=VX@97)R;W(@:&%S(&]C8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I
M;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A
M(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R
M-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<F4@>6]U('-U<F4@>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD
M(&%N>2!S=6(M9W)O=7!S/P!!<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H
M05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!
M<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B
M969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N
M="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R
M;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO
M;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R
M:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@
M4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S
M.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N
M`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N
M9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD
M+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!
M=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`
M075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&A?;&1A<#H@061D:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R
M($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I
M<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A
M<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD
M87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S
M97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R
M("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?
M;&1A<#H@57!D871I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T
M:79E($1I<F5C=&]R>2X`075T:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N
M<VEO;B!N;W0@9F]U;F0N`$%U=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T
M:"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0
M('-E<G9E<B!F86EL960N`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT
M:6-A=&EO;B!F86EL960N("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y
M(%)!1$E54R!S97)V97(N`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@
M9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL
M960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S
M`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S
M<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN
M`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S
M92!G<F%P:&EC<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE
M`$)E;&%R=7,`0F5L9VEU;0!"96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`
M0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F
M;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`
M0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O
M<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U
M=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET
M;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`
M0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N
M(%!O:6YT<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO
M="!C;VUP;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`
M0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T
M('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E
M<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S
M+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N
M(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O
M<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M
M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R
M9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B
M)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T
M(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R
M9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T
M92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P
M=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L
M86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z
M`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT
M:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B
M;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E
M($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I
M97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H
M92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O<&QE('-E92!W:&5N('1H97D@
M<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@
M<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O
M;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA
M<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I
M960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E
M($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R
M;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T
M('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L
M86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#
M;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R
M.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E
M`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@
M5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L
M:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E
M<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I
M;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD
M(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O
M;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I
M9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S
M+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O
M=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N
M9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN
M96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N
M(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@
M<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H
M)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S
M`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``
M0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE
M`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`
M0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-
M12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U
M;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E
M<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L
M9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O
M34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D
M96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E
M=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F
M971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E
M=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`
M0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER
M("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K
M97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O
M=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]4
M87-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E
M860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R
M97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E
M(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@
M<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN
M("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`
M0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U
M;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N
M;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B
M+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@
M<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@
M8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@
M=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B
M86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T
M:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@
M;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E
M<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L
M9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN
M:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO
M="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET
M92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H
M92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O
M<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I
M9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U
M;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE
M=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`
M0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA
M<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),
M(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N
M9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N
M('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#
M>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I
M;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.
M("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W
M<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S
M96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@
M;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R
M`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$
M96QE=&4`1&5L971E($-E;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L
M971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE
M=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA
M=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N
M<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N
M>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D
M(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E
M;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U
M<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`
M1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS
M;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G
M960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I
M;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E
M8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$
M:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO
M;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T
M("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO
M;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E
M<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN
M('1H92!F:65L9"!N86UE<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M
M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N
M=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N
M97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N
M(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E
M<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%
M4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E
M<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O
M<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B
M)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%
M;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER
M;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M
M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B
M;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I
M;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@
M>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N
M('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T
M('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U
M<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L
M971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R
M`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC
M(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R
M(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z
M("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B
M)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@
M;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R
M>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y
M(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD
M(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q
M=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'
M($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@
M<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R
M+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@
M8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE
M9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO
M=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML
M86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R
M<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U
M;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R
M`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P
M;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA
M;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L
M9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&
M*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C
M87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E
M<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y
M;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T
M=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A
M;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H
M(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&
M<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE
M`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A
M;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E
M`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`1VEV96X@3F%M90!'
M;&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E
M87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E
M;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE
M<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D
M(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O
M=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P
M.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E
M`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U
M97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL
M(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@
M=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R
M969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@
M075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H
M;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA
M;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)
M*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P
M:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`
M2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE
M($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(
M;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A
M=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@
M;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R
M9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O
M2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D
M;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C
M<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N
M86)L92!T;R!R971R:65V92!-24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E
M("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R
M97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO
M;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@
M9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C
M;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L
M9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES
M=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)
M34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@
M<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E
M<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W
M960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T
M(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)
M8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@
M9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W
M:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R
M;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@
M=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES
M(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@
M=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM
M86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E
M9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@
M8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD
M:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O
M<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L
M:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE
M8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,
M86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T
M($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,
M969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@
M=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G
M92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U
M<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE
M;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``
M3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,
M:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,
M:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A
M8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T
M:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@
M<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S
M:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S
M=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,
M;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L
M871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-
M30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@;F\@9&%T82X`
M35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U
M8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME
M(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A
M`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H879E('1O(&QA
M8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H
M;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN
M9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R:R!W:71H(%-E96XO56YS965N
M(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O
M06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN
M9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`36%X(&%L;&]W960@8W)E
M9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S
M="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@
M3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA
M>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS
M`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H
M92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N
M`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`
M365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`365T:&]D(&YO="!D969I;F5D
M+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L
M($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M
M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN
M:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`
M36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E
M<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A
M=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N
M+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P
M86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA
M:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`
M36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N
M9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I
M96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-
M;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U
M9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T
M`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I
M<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M
M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!)
M;F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R
M`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`
M3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S
M92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@
M<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O
M8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@
M8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E
M`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W
M($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W
M('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W
M('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.
M97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N
M<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO
M`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F
M97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG
M($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES
M=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE
M('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N
M`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R
M($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`
M3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@
M:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@
M<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF
M:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N
M97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N=&EC871I
M;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T
M:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H
M96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A
M=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@
M<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@
M=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.
M;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N
M`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y
M(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S
M=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU
M97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N
M+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@
M:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I
M;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y
M+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H
M97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O
M<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.
M;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C
M:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E
M<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I
M9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B
M:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL
M=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F
M97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E
M8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L
M9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@
M861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M
M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M
M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N
M4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D
M(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W
M`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E
M<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G
M86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA
M;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W
M;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A
M:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T
M=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG
M;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H
M="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO
M=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI
M<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S
M=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'
M=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R
M9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A
M<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A
M<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@
M`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B
M;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R
M9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N
M8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N
M("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I
M;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R
M;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET
M8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M
M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E
M('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T
M;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A
M;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A
M=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A
M<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A
M>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0
M;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S
M92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R
M96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T
M:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N
M97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U
M9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@
M=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@
M8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``
M4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E
M9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E
M<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`
M4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R
M979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I
M;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE
M;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y
M`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O
M4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0
M=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!2
M4T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!2
M86EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W
M`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E860@
M;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S
M97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E
M<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE
M;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T
M:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S
M`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!2
M96UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA
M='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E
M<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E
M('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO
M=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T
M=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T
M(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN
M(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I
M960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S
M970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@
M475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A
M<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT
M($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I
M9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O
M=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T
M:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P
M96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A
M<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@
M8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N
M9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R
M>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@
M9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!3
M86EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA
M`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@
M=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-
M87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E
M<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E($]P
M=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S
M8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3
M879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C
M<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A
M<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E
M`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L
M96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`
M4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`
M4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D(&9R
M;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S
M=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D
M96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@
M:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@
M9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O
M(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!3
M96QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!2
M97!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R
M8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@
M=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N
M($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO
M<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F
M:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E
M='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G
M9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I
M8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE
M("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O
M<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L
M;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@
M=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E
M<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@
M5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG
M;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`
M4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3
M;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT
M(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0
M;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T
M:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E
M;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N
M($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C
M92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3
M<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L
M($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI
M="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A
M<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M
M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3
M=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3
M=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U
M8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO
M=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A
M<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D
M("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY
M(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M
M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T
M:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E
M9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H
M92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@
M=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM
M87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U
M;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U
M<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N
M`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E
M9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@
M07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O
M<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E
M<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A
M;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E
M<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R
M93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`
M5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T
M:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I
M("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@
M879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H
M92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P
M<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ
M960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C
M97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I
M;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E
M<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S
M92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A
M8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R
M('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W
M87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4
M:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T
M;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N
M(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK
M(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I
M;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A
M='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I
M;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E
M<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C
M86YN;W0@8F4@8V]P:65D(&]N=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN
M960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R
M('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N
M(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE
M="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N
M)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@
M9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD
M+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I
M<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T
M(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B
M;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/
M2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D
M:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE
M(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G50
M1R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA
M<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T
M("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E
M92!T:&%T('1H92!M97-S86=E(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O
M9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S
M92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`
M5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?
M0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L
M9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@9&%T82!E>&-E961E9"!T:&4@
M;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE
M(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE
M(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O
M;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N
M(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE
M('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@
M<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5M<&]R
M87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1E>'0@>6]U(&5N
M=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+@!4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL
M>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N9"X`5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R=',@=&AA="!C86X@
M8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O;R!M86YY(&-H87)A
M8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT97)E9"`E<R!C:&%R
M86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@)7,N`%1H97)E('=A
M<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@=&AE('-Y<W1E;3H@)7,`5&AE
M<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D871A(&9O<B!U<V5R("(E<R(@
M9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!R96UO=FEN
M9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A('!R;V)L96T@
M=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P;&]A9&5D+@!4:&5R92!W87,@
M82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&QA
M<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W960@<VEZ92`H)60@8GET97,I
M+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4
M:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P;&]A9&5D+@!4:&5R92!W87,@
M86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&5R92!W
M87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C;VYT86-T(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+@!4
M:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R;2X@
M4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"X`5&AE<F4@
M=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE('-P96-I9FEE9"!A9&1R97-S
M(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E
M('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@8V]N=&%C="!D971A:6QS+B!0
M;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D
M871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+B!0;&5A<V4@=')Y(&%G86EN
M(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A('9A
M;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@;F]T(&%P<&5A<B!T;R!B92!A
M('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@;F]T('-E96T@=&\@8F4@82!V
M86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@
M;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI8VMA=&5L;"`H:'1T<#HO+V-L
M:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI
M<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T
M:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE
M($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A
M9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H:'1T<#HO+W-M<S)E;6%I;"YC
M;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A
M;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V:6$@4TU44"!T:')O=6=H('1H
M92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O;FQY('1O(%9O9&%F;VYE(&YU
M;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL(&%C8V]U;G0@=VET:"!6;V1A
M9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N:70I+@!4:&ES(&9I96QD(&ES
M(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@:6YT96=E
M<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!N=6UB97)S(&%N9"!T
M:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V
M86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A(&-O;6UA(&]R('-P86-E('-E
M<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H:7,@9FEE;&0@;75S="!B92!A
M('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO
M<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q
M,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A9'D@8F5E;B!P<F]C97-S960N
M`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA8B!'<F]U<'=A<F4@;V)J96-T
M+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W:6QL(&YE960@86X@96UA:6P@
M8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE($MO;&%B($=R;W5P=V%R92!F
M;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E;6%I;"!C;&EE;G1S('!L96%S
M92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C:&%R
M86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BX`5&AI<R!N=6UB
M97(@;75S="!B92!A="!L96%S="!O;F4N`%1H:7,@<V5R=F5R(&-A;B=T('5N
M8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+@!4:&ES('-Y<W1E;2!I<R!C
M=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@=F%L=64@;75S="!B92!A(&YU
M;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C86QL960@9G)O;2!A;B!/<'1I
M;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`5&EM90!4:6UE(%1R86-K:6YG
M`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N`%1I;6]R+4QE<W1E`%1I=&QE
M`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I<&QE(&ET96US
M+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I
M(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A434P@4V]U<F-E
M`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG80!4;V\@;6%N>2!I;G9A;&ED
M(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN=71E<RX`5&]P`%1O<"!F<F%M
M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U
M92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U
M.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U
M=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@
M9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!5
M9V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I
M9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93
M(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!6
M1E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE
M('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B+@!5;F%B;&4@=&\@8VAE8VL@
M9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L92!T;R!C;VYN96-T('1O(%-1
M3"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@
M=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@
M9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@
M(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D
M96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E
M8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C
M=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93(&9O;&1E<B`B)7,B+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I=F5L>3H@)7,N`%5N86)L92!T
M;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O<GDN`%5N86)L92!T;R!E>'1R
M86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA8FQE('1O(&QO860@=&AE(&1E
M9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M;W9E(%9&4R!F:6QE+@!5;F%B
M;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@;W!E;B!61E,@
M9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O(&]P96X@5D93(&9I;&4N`%5N
M86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C:&EV92X`56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O(')E
M860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@9F%I;&5D*2X`56YA8FQE('1O
M(')E860@9FEL93H@`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C
M=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@
M9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I
M<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N
M86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE
M+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T
M92!T:&ES(%=O<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE
M9"DN`%5N86)L92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N`%5N9&5R
M;&EN90!5;F1O($-H86YG97,`56YD;V5S('EO=7(@;&%S="!A8W1I;VX`56YE
M>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!O;B!C;VYN96-T:6]N.B``
M56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E<G9E<B!T;SH@`%5N9FEL960`
M56YI8V]D92`H551&+3@I`%5N:71E9"!!<F%B($5M:7)A=&5S`%5N:71E9"!+
M:6YG9&]M`%5N:71E9"!3=&%T97,`56YI=&5D(%-T871E<R!-:6YO<B!/=71L
M>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO=VX`56YK;F]W;B!A<&EM<V=I9"`H
M05!)($UE<W-A9V4@240I+@!5;FMN;W=N(&-L:6US9VED("A#;&EE;G0@365S
M<V%G92!)1"DN`%5N:VYO=VX@;&]C871I;VX@<')O=FED960N`%5N:VYO=VX@
M=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M
M96YT`%5N;F%M960`56YP<FEV:6QE9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S
M<R!#=70O0V]P>2]087-T92!P<F]G<F%M871I8V%L;'D@9F]R('-E8W5R:71Y
M(')E87-O;G,N("!#;&EC:R!/2R!T;R!S964@82!T96-H;FEC86P@;F]T92!A
M="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@
M<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5
M;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D871E`%5P9&%T92`E<P!5<&1A=&4@
M=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P
M;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`
M57-E<@!5<V5R("5S(&ES(&YO="!A=71H;W)I<V5D(&9O<B`E<RX`57-E<B!!
M9&UI;FES=')A=&EO;@!5<V5R($]P=&EO;G,`57-E<B!296=I<W1R871I;VX`
M57-E<B!296=I<W1R871I;VX@:&%S(&)E96X@9&ES86)L960@9F]R('1H:7,@
M<VET92X`57-E<B!A8V-O=6YT(&YO="!F;W5N9`!5<V5R;F%M90!5<V5R;F%M
M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5<V5R;F%M93H`57-E<FYA;64Z(`!5
M<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E:VES=&%N`%9&4R!D:7)E8W1O<GD@
M9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N
M9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO
M=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L96YG=&@@;V8@)7,N`%9A
M;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%N=6%T=0!687)I86)L90!6
M96YE>G5E;&$`5F5R:69I8V%T:6]N(&9A:6QE9"`M('1H:7,@;65S<V%G92!M
M87D@:&%V92!B965N('1A;7!E<F5D('=I=&@N`%9E<G-I;VX`5F5R<VEO;B!#
M;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E<G1I8V%L('!A9&1I;F<`5F5R=&EC
M86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6:65T;F%M97-E("A625-#24DI`%9I
M97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I
M<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I<F=I;B!)<VQA;F1S+"!5+E,N`%9I
M<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O9&%F;VYE($ET86QY('9I82!33510
M`%=!4DX`5T%23DE.1R$A(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@
M)7,N`%=)3B!V:6$@2%144`!786QL:7,@86YD($9U='5N80!787)N:6YG`%=E
M`%=E871H97(@1F]R96-A<W0`5V5A=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E
M871H97(N8V]M`%=E8@!796(@4VET90!7965K;'D`5V5L8V]M90!796QC;VUE
M('1O("5S`%=E;&-O;64L("5S`%=E<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E
M<FX@*$E33RTX.#4Y+3$U*0!797-T97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H
M92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R
M86-T97(_`%=H97)E:7,@075S=')A;&EA(&UA<`!7:&EC:"!P:&%S97,`5VAI
M8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E>'0@961I=&]R
M+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@=&AE("5S(&UE
M;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ
M`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H.@!7:6MI`%=I
M;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z
M(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D
M("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M8F5R(&]F(&9I96QD<RX@17AP96-T
M960@)60L(&9O=6YD("5D+@!7<F]N9R!O9F9S970@)60@=VAI;&4@<F5A9&EN
M9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`
M6#4P.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E
M<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U
M,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M
M96X`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S
M92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`
M66]U(&%R92!N;W0@86QL;W=E9"!T;R!C<F5A=&4@;6]R92!T:&%N("5D(&)L
M;V-K<RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A;FYO="!H
M879E('1H92`G7"<@8VAA<F%C=&5R(&EN('EO=7(@9G5L;"!N86UE+@!9;W4@
M9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N`%EO=2!D:61N
M)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T:&4@:6UP;W)T960@9FEL92!T;R!T
M:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@:6X@)7,N`%EO=2!H879E(&)E96X@
M;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO
M;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F
M;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA;&EN9R!P<F5F:7@N`%EO=2!H879E
M('1O(&5N=&5R(&$@=F%L:60@=F%L=64N`%EO=2!M=7-T(&-O;F9I9W5R92!A
M($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E(%-I9VYU<',N`%EO=2!M=7-T(&-O
M;F9I9W5R92!A(%9&4R!B86-K96YD+@!9;W4@;75S="!D97-C<FEB92!T:&4@
M<')O8FQE;2!B969O<F4@>6]U(&-A;B!S96YD('1H92!P<F]B;&5M(')E<&]R
M="X`66]U(&UU<W0@96YT97(@=&AE(%523"!W:&5R92!T:&ES(&QI;FL@<&]I
M;G1S('1O`%EO=2!M=7-T('-E;&5C="!A;B!S97)V97(@=&\@8F4@9&5L971E
M9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(&-L96%R(&]U="X`
M66]U(&UU<W0@<W!E8VEF>2!A('5S97)N86UE('1O(')E;6]V92X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@861D+@!9;W4@;75S="!S<&5C
M:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N`%EO=2!M=7-T('-P96-I9GD@
M=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`66]U(&UU<W0@='EP92!A(&YE=R!C
M871E9V]R>2!N86UE+@!9;W4@;F5E9"!T;R!P<F]V:61E(&%N($ET86QI86X@
M<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S<VEO;B!H87,@97AP:7)E9"X@4&QE
M87-E(&QO9VEN(&%G86EN+@!9;W5R($5M86EL($%D9')E<W,`66]U<B!&<F]M
M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T:6]N`%EO=7(@26YT97)N970@061D
M<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@
M)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S
M="!L;V=I;B!A9V%I;BX`66]U<B!.86UE`%EO=7(@875T:&5N=&EC871I;VX@
M8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&%D9&EN9R!U<V5R<RX@268@>6]U
M('=I<V@@=&\@=7-E($AO<F1E('1O(&%D;6EN:7-T97(@=7-E<B!A8V-O=6YT
M<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R96YT(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0N`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S
M=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA<R!B965N
M(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!B<F]W<V5R
M(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@
M<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S
M=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N+B!0<F5S<R!#;VYT<F]L+T-O;6UA
M;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E96X@8VAA;F=E9"X`66]U<B!D969A
M=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@
M97AP:7)E9"X`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R
M(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O
M9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E
M9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D
M(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@
M=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP
M:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R<SH`675G;W-L879I80!:86ER90!:
M86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B
M;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@
M5&5X="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T
M:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``
M7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y
M($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN
M+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@
M8F]O:P!A9&1R97-S964@=6YK;F]W;@!C86QE;F1A<@!C86QM`&-A;FYO="!C
M<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T(&]P96X@:6YP=70`8VQI8VL@:&5R
M90!C;VUM86YD(&QI;F4@=7-A9V4@97)R;W(`8V]N9FEG=7)A=&EO;B!E<G)O
M<@!C<FET:6-A;"!S>7-T96T@9FEL92!M:7-S:6YG`&1A=&$@9F]R;6%T(&5R
M<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD`&9A;&QI;F<`9FEL90!F<F]M('1H
M92`E<R`H)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:&@`:&]S="!N86UE('5N
M:VYO=VX`:6UM961I871E`&EN;&EN90!I;G!U="]O=71P=70@97)R;W(`:6YT
M97)N86P@<V]F='=A<F4@97)R;W(`;&EN97-=`&UK:7-O9G,@97)R;W(@8V]D
M92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N86UE`&YO="!I;7!L96UE;G1E
M9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P860`<&5R8V5N=`!P97)M:7-S
M:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L`')I
M<VEN9P!S97)V:6-E('5N879A:6QA8FQE`'-H;W<@9&EF9F5R96YC97,`<VUS
M,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!S>7-T96T@97)R;W(`=&%S:R!L
M:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y<&4@=&AE('!A<W-W;W)D('1W:6-E
M('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@<V5L96-T`'9#87)D
M`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO;CH@2&]R9&4@,RXQ
M+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R
M9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP,BTR-R`Q.3HU,2LP,C`P"E!/
M+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M,C0@,3(Z-3DK,#(P,`I,87-T+51R
M86YS;&%T;W(Z($QE96YA($AE:6YO(#QL:6EN=4!U=&$N9FD^"DQA;F=U86=E
M+51E86TZ($9I;FYI<V@@/&DQ.&Y`;&ES=',N:&]R9&4N;W)G/@I-24U%+59E
M<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[(&-H87)S970]
M:7-O+3@X-3DM,0I#;VYT96YT+51R86YS9F5R+45N8V]D:6YG.B`X+6)I=`H`
M("@E<R!PY&EVY.0@<VET=&5N*0`@*%!I:V%NY'!PY&EN("5S*0`@*"5S('#D
M:7;D<W/D*0`@*'3D;N3D;BD`("AH=6]M96YN82D`("AE:6QE;BD`(``B)7,B
M(&5I(&]L92!H86ME;6ES=&\`(B5S(B!E:2!K96QP86$@=F%L:6YN86MS:2X`
M(B5S(B!E:2!O;&4@87-E;FYE='1U($AO<F1E;B!R96MI<W1E<FES<^0N`"(E
M<R(@<'5I9&5N(&MU=F%A:F%A(&5I(&SV>71Y;GET+@`B)7,B(&QI<^1T=&EI
M;B!R>6AMY&KD<FIE<W1E;&WDY&XN`"(E<R(@;&ESY'1T:6EN(&]I:V5U:W-I
M:6XN`"(E<R(@96D@;'5O='4Z("5S+@`E+C)F34(@:^1Y=&5T='D@)2XR9DU"
M('-A;&QI='5S=&$@*"4N,F8E)2D`)60@)7,@:F$@)7,`4V%L87-A;F%S:2!V
M86YH96YT=74@)60@<.1I=N1N('#DY'-TY"X`)60@<.1I=N1N(&5N;G5S='5S
M`"5S("T@26QM;VET=7,`)7,@4V]R;65N:N1L:VD`)7,@2T(`)7,@66QLY'!I
M=&]T;VEM96YP:71E970@+2!687)M:7-T=7,`)7,@87-E;FYU<P`E<R!K:7)J
M875T=6UI;F5N`"5S(&OD>71T]F5H9&]T`"5S(&]N(&IO(&]L96UA<W-A+@`E
M<R!S=75N=&$@)7,@)7,`)7,@;VX@=F%L;6ES('-U;W)I='1A;6%A;B!Y;&SD
M<&ET;W1O:6UE;G!I=&5I=.0N(%9A;&ET<V4@=F%L:6YT87)U=61U:7-T82!S
M=6]R:71E='1A=F%T('1O:6UE;G!I=&5E="X`)7,@;VX@<&%K;VQL:6YE;@`E
M<R!M:6YU=71T:6$`)7,@96D@;/9Y='EN>70N`"5S("T@)7,@+R`E<P`E<SIN
M(&]S;VET96MI<FIA`"5S.FX@:V%L96YT97)I`"5S.FX@;75I<W1I;&ES=&$`
M)7,Z;B!T96ATY';D;&ES=&$`)7,Z("5S`"5S(#H@5.1MY"!V:65S=&D@96D@
M;VQE(';D;'1TY&WD='3D('-I;'3D(&SD:&5T=.1JY&QTY"P@:F]K82!O;B!M
M97)K:71T>2!LY&AE='3D:N1K<VDN(%-U:'1A=61U('9A<F%U:W-E;&QA('9I
M97-T:7-SY"!O;&5V:6EN(&QI;FMK96EH:6X@:F$@=F%R;R!A;G1A;6%S=&$@
M;.1H971TY&KD;&QE(&UI=.3D;B!Y:W-I;/9I=FGD('1I971O:F$N`"P@<'5U
M<VMI='1A:7-T80`L('!U=7-K:71T86ES=&$@)7,@)7,`+"!V86EH=&5L979A
M82`E<R`M("5S`"TM('9A;&ET<V4@+2T`,3(M='5N;FEN(&KD<FIE<W1E;&WD
M`#(T+71U;FYI;B!JY')J97-T96QMY``R-"!T=6YT:6$`/$5D96QL:6YE;@!4
M:65T;VMA;G1A=&%U<W1A:N1R:F5S=&5L;>3D(&5I(&]L92!MY.1R:71E;'1Y
M('3D;&QE(&]S:6]L;&4`5&%P86AT=6D@=F%K879A('9I<FAE`%9I97-T:6X@
M<V%L875K<V5E;B!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+@!!;&QE
M:VER:F]I=&5T=6X@=FEE<W1I;B!T87)K:7-T=6MS965N('1A<G9I=&%A;B!J
M=6QK:6YE;B!01U`M879A:6XN`%-A;&%T=6X@=FEE<W1I;B!A=F%A;6ES965N
M('1A<G9I=&%A;B!J=6QK:6YE;B!01U`M879A:6XL('-A;&%I;F5N(%!'4"UA
M=F%I;B!J82!S86QA<V%N871E:W-T:2X`5FEE<W1I;B!A;&QE:VER:F]I='1A
M;6ES96MS:2!T87)V:71A86X@:G5L:VEN96X@4$=0+6%V86EN+"!S86QA:6YE
M;B!01U`M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@879A86UI
M<V5E;B!T87)V:71A86X@:G5L:VEN96X@4R]-24U%+6%V86EN+"!S86QA:6YE
M;B!3+TU)344M879A:6X@:F$@<V%L87-A;F%T96MS=&DN`%9I97-T:6X@86QL
M96MI<FIO:71T86UI<V5K<VD@=&%R=FET86%N(&IU;&MI;F5N(%,O34E-12UA
M=F%I;BP@<V%L86EN96X@4R]-24U%+6%V86EN(&IA('-A;&%S86YA=&5K<W1I
M+@!6:65S=&EN('-A;&%U:W-E96X@=&%R=FET86%N(&IU;&MI;F5N(%--24U%
M+6%V86EN+@!!32!0:6QV:>0`04T@:V5V>71TY"!S861E='1A`$%-('-A9&4`
M04T@<V%T96ET80!!32!L=6UI<V%T96ET80!!32]030!!4$D@240`5&EE=&]J
M82!E9&ET;W)I<W1A`%1I971O:F$N+BX`06)S+B!A;&EN`$%B<RX@:V5S:V5L
M;.0`4VEN=6QL82!E:2!O;&4@;VEK975K<VEA(&QU;V1A(%9&4RUH86ME;6ES
M=&]A+@!3:6YU;&QA(&5I(&]L92!O:6ME=6MS:6$@;'5O9&$@5D93+71I961O
M<W1O82X`2^1Y='3D:N1T=6YN=6MS96X@=&EE9&]T`$OD>71TY&KD='5N;G5K
M<V5N('-A;&%S86YA`$OD>71TY&KD=&EL:2!S=6QJ971T=2X`2VER:F%N<&ET
M;P!,:7/DY`!,:7/DY"!A;&ER>6AMY`!,:7/DY"!A;&EO:6ME=7,`3&ESY.0@
M=.1HY&XZ`$QI<^3D('5U<VD@<GEH;>0`3&ESY.0@=75S:2!O:6ME=7,`3&ES
MY.0@86QI<GEH;>0@<GEH;>3D;B`B)7,B`$QI<^3D(&%L:6]I:V5U9&5T("(E
M<R(`3&ESY.0@=75S:2!KY'ET=.1JY#H`3&ESY.0@<V%R86ME`$QI<^3D('5U
M<VEA(&KD<V5N:>0`3&ESY.0@<&%R:0!,:7/DY"`E<R!V86QI:VMO($UO>FEL
M;&%N(%-I9&5B87(@;W-I;V]N`$QI<^3D(&]S;VET96MI<FIA86XZ`$QI<^3D
M(&]S;VET96MI<FIA86YI.@!,:7/DY"!KY'ET=.1JY`!,:7/D='1I:6X@(B5S
M(B!JY')J97-T96QMY.1N+"!M=71T82!E:2!V;VD@;&ESY'3D('-I<^3D;FMI
M<FIA=71U;6ES<'EY;F[V;B!L:7/D=&EE=&]J83H@)7,N`$QI<^1T=&EI;B`B
M)7,B(&KD<FIE<W1E;&WDY&XN(%9O:70@;GET(&MI<FIA=71U82!S:7/DY&XN
M`$OD>71TY&II96X@;&ESY.1M:6YE;B!O;B!E<W1E='1Y+@!/<V]I=&4`3W-O
M:71E:VER:F$`5F]I(&%S971T86$@=&%I(&WDY')I=&5L;.0@;VEK975K<VEA
M('1O:7-I;&QE(&OD>71TY&II;&QE`%EL;.1P:71O`$UA:6YO:W-E=`!!9F=A
M;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!487-A80!487-A=7,Z`$MA
M:6MK:0!+86EK:VD@875T96YT:6MO:61U="!KY'ET=.1JY'0`2V%I:VMI(')Y
M:&WD=`!+86EK:VD@;VEK975D970`2V%I:VEL=&$@;F5L:N1L=.0@<VEV=6QT
M80!386QL:2!M;VYE="!O<V]I='1E970`4V%L;&D@:N1R:F5S=&5T>6X@;&ES
M=&%N('1Y>7!I;B!A<V5T=7,N`$]N(&IO(&]L96UA<W-A`%9A:6AT;V5H=&]I
M;F5N($E-4U`M<VESY.1N:VER:F%U='5M:6YE;@!686EH=&]E:'1O:6YE;B!)
M35-0+7-A;&%S86YA`%9A:6AT;V5H=&]I;F5N($E-4U`M:^1Y='3D:N1T=6YN
M=7,`5F%I:'1O96AT;VES970@<^1H:_9P;W-T:6]S;VET=&5E=`!686EH=&]E
M:'1O:7-E="!M86QL:70`5F%I:'1O96AT;VEN96X@=&5K<W1I.@!9:&1Y<W9A
M;'1A:6X@4V%M;V$`06YN971T=2!A<G9O(&5I(&ME;'!A82X`=&%P86AT=6D@
M='5N=&5M871O;B!V:7)H92X`06YD;W)R80!!;F=O;&$`06YG=6EL;&$`06YO
M;GEY;6D@<')O>'D`5F%S=&%U<P!!;G1A<FMT:7,`06YT:6=U82!J82!"87)B
M=61A`$]H:F5L;6$`3VAJ96QM86QI<W1A`$]H:F5L;6$@;VX@=F%L;6ES+@!,
M86ET82!KY'ET=/;V;B!K86EK:VD@86QI:F%K;VEH:6X`2'EVY&MS>0!!<G9I
M;VET=2!K;VMO`&AU:'1I:W5U`$%R86)I82`H5VEN9&]W<RTQ,C4V*0!086ME
M=&EN(&MO:V\`4&%K971I;B!N:6UI`$]L971K;R!V87)M82P@971TY"!H86QU
M870@<&]I<W1A82!S:7/DY&YK:7)J875T=6UI<W!Y>6YN]FX@)7,@/P!/;&5T
M:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O:7-T86$@(B5S(B!J82!K86EK:VD@
M<V5N(&%L:7)Y:&WD=#\`06=E;G1I:6YA`$%R;65N:6$`07)M96YI82`H05)-
M4T-)22TX*0!486ED90!!<G5B80!!<V-E;G-I;VX@<V%A<F5T`$%S8VEI+71A
M:61E`$%S:6%N+U1Y>6YE;FUE<F5N(&%L=64`2WES>2!V87)M:7-T=7,@96YN
M96X@:W5I;B!T96ADY.1N('EL;.1P:71O=&]I;65N<&ET965T+@!496ATY';D
M<V%R86MK965T`%ER:71E='1I:6X@<&]I<W1A82!O;&5M871O;G1A(')Y:&WD
MY"X`67)I=&5T=&EI;B!P;VES=&%A(&]L96UA=&]N=&$@;VEK975T=&$N`%ER
M:71E='1I:6X@;75O:V%T82!O;&5M871O;G1A(&]I:V5U='1A+@!9<FET971T
M:6EN(&UU;VMA=&$@;VQE;6%T;VYT82!J86MO82X`3&ESY&WDY')I='EK<V5T
M`&5L;VMU=0!!=7-T<F%L:6$`273D=F%L=&$`075T:%]C>7)S<6PZ(%1A<G9I
M='1A=F%A($E-05`M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?8WER
M=7,Z(%1A=7-T86KD<FIE<W1E;&WD(&5I('1U92!T87)V:71T879I82!O;6EN
M86ES=75K<VEA+@!!=71H7V-Y<G5S.B!487)V:71T879A82!)34%0+6QA86IE
M;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7V9T<#H@=&%R=FET=&%V86$@1E10
M+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+B!+Y.1N;N0@4$A0(&OD>71TY&5N
M("TM96YA8FQE+69T<"!A<V5T=7-T82X`075T:%]I;6%P.B!487)V:71T879A
M82!)34%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET+@!!=71H7VMR8C4Z(%1A
M<G9I='1A=F%A(&MR8C4M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&A?
M;&1A<#H@:^1Y='3D:FEE;B!L:7/DY&UI;F5N($%C=&EV92!$:7)E8W1O<GEY
M;B!E:2!O;&4@='5E='1U`$%U=&A?;&1A<#H@2^1Y='3D:FEE;B!P;VES=&%M
M:65N;B!!8W1I=F4@1&ER96-T;W)Y<W3D(&5I(&]L92!T=65T='4`075T:%]L
M9&%P.B!487)V:71T879A82!,1$%0+6QA86IE;FYU<W1A(&5I(&SV>71Y;GET
M+@!!=71H7VQD87`Z($5I('9O:61A(&QI<^1TY"!KY'ET=.1JY.0@)7,N(%!A
M;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ(`!!=71H7VQD87`Z($5I('9O
M:61A('!O:7-T86$@:^1Y='3D:N3D("5S`$%U=&A?;&1A<#H@16D@=F]I9&$@
M<.1I=N1T=.3D(&OD>71TY&KDY"`E<P!!=71H7VQD87`Z($OD>71TY&II96X@
M<.1I=FET=.1M:6YE;B!!8W1I=F4@1&ER96-T;W)Y>6X@96D@;VQE('1U971T
M=2X`075T:%]M8V%L.B!487)V:71T879A82!-0T%,+6QA86IE;FYU<W1A(&5I
M(&SV>71Y;GET+@!!=71H7W-M8F%U=&@Z(%1A<G9I='1A=F%A('-M8F%U=&@M
M;&%A:F5N;G5S=&$@96D@;/9Y='EN>70N`$%U=&5N=&EK;VEN=&D@24U!4"UP
M86QV96QI;65L;&4@97#D;VYN:7-T=6DN`$%U=&5N=&EK;VEN=&D@97#D;VYN
M:7-T=6D`075T96YT:6MO:6YT:2!E<.1O;FYI<W1U:2X@)7,`075T96YT:6MO
M:6YT:2!2041)55,M<&%L=F5L:6UE;'1A(&5PY&]N;FES='5I+@!!=71E;G1I
M:V]I;G1I($944"UP86QV96QI;65L;&4@97#D;VYN:7-T=6DN`$%U=&5N=&EK
M;VEN=&D@4TU"+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`2^1Y=&5T=.1V
M:7-SY&]L979A="!K96YTY'0Z`$%Z97)B86EZ9&%N`$)/1D@@<V5L:71Y:W-E
M=`!4875S=&$`5&%U<W1A=N1R:0!6Y.1RY"!K97)B97)O<R!S86QA<V%N82X`
M5N3D<N0@:V5R8F5R;W,@:^1Y='3D:N1T=6YN=7,N`$)A:&%M80!"86AR86EN
M`$)A;'1I82`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`1W)A
M9FEI:V]I9&5N('!E<G5S:&%K96UI<W1O82`B)7,B(&5I(&SV>71Y;GET+@!0
M97)U<W9I:79A`%9A;&MO+59E;N1JY`!"96QG:6$`0F5L:7IE`$)E;FEN`$)E
M<FUU9&$`0FAU=&%N`%-Y;G1Y;>1PY&EVY`!/<VEO=&$@(B5S(B!O:&IE;&UA
M;&QE("(E<R(@96D@;/9Y='EN>70N`$]S:6]N(&%S971U:W-E=`!/<VEO;B!T
M>7EP<&D`3&EH879O:71U`$)O;&EV:6$`2VER:F%N;65R:VET`%)E=6YA`%)E
M=6YA;B!V86AV=75S.@!2975N870`0F]S;FEA($AE<GIE9V]V:6YA`$UO;&5M
M;6%T`$)O='-W86YA`$%L:6X`0F]U=F5T('-A87)E=`!"<F%S:6QI80!"<FET
M86YN:6%N($EN=&EA;B!V86QT86UE<F5N('1E<G)I=&]R:6\`0G)U;F5I($1A
M<G5S86QA;0!"=6QG87)I80!086QL=6MK86QI<W1A`$)U<FMI;F$@1F%S;P!"
M=7)U;F1I`$--4P!#4D,`0U),+6IA:V5L=6]S;VET=&5E=`!37V]L=6X@=&EE
M9&]T+BXN`%;D;&EM=6ES=&EN(&%L=7-T=7,@96D@=F%L;6ES='5N=70N`$MA
M;&5N=&5R:0!4>7EN:0!+86UP=71S96$`2V%M97)U;@!386QA<V%N86$@96D@
M=F]I('1Y:&IE;G3DY"!A=71O;6%A='1I<V5S=&DL(&]T82!Y:'1E>71TY"!Y
M;&SD<&ETY&KDY&XN`$5I('9O:2!K:7)J;VET=&%A('1I961O<W1O;VX@(B5S
M(@!5;&MO:7-I82!I<W1U;G1O:^1S:71T96QI:O9I=.0@96D@;VQE(&UA:&1O
M;&QI<W1A(&AA;&QI=&$N`$E-05`M<&%L=F5L:6UE96X@96D@<V%A='4@>6AT
M97ET=.0Z("5S`$5I('9O:2!A=F%T82!T:65D;W-T;V$@(B5S(BX`2V%N861A
M`%!E<G4`4&5R=2!O;F=E;&UA=FEE<W1I`$5I('9O:61A('!O:7-T86$@=&EE
M9&]S=&]A("(E<R(N`%;D;&EA:6MA:7-H86ME;6ES=&]A(&5I(&SV>71Y;GET
M+@!%:2!V;VED82!J871K86$@:6QM86X@)W1A<F=E=$9I;&4G("UP87)A;65T
M<FEA+@!%:2!V;VED82!P;VES=&%A(&AA:V5M:7-T;V$@(B5S(BX`16D@=F]I
M9&$@<&]I<W1A82P@)60@86QI=&%S;VIA(&]L96UA<W-A+@!%:2!V;VD@=75D
M96QL965N:N1R:F5S=.3D+"!A;FYE='1U:F5N('1I971U96ED96X@;>3D<N0@
M96D@=F%S=&%A('1A;&QE=&5T='5J96X@=&EE='5E:61E;B!MY.1RY.0N`$5I
M('9O:2!O:&IA=&$@=FEE<W1IY"!A;FYE='1U=6X@;G5M97)O;VXN`$MA<"!6
M97)D90!+=79A=&5K<W1I`%!A;'9E;'5N=&%R:F]A:F$`2V%T96=O<FEA="!J
M82!O='-I:V]T`$-A>6UA;B!S86%R970`4'5H96QI;BA'4TTI`%-O;'5N('1I
M961O=`!3;VQU;B!TY'ET93H`4V]L=6X@=&EE9&]T`%-O;'5N(';D;'ES.@!-
M871K87!U:&5L:6X`2V5L='1I("A)4T\M.#@U.2TQ-"D`2V5S:VET971T>0!+
M97-K:2U!9G)I:V%N('1A<V%V86QT80!+97-K:2U%=7)O;W!P82`H25-/+3@X
M-3DM,BD`5F%R;65N=&5E;B!T:65D;W0`5F%R;65N=&5E;B!O;6ES=&%J80!6
M87)M96YT965N('!O;&ET:6EK870`5'-A9`!-=75T80!686EH9&$@<V%L87-A
M;F%S:0!6;VET(&UU=71T86$@;.1H971TY&UI<W/D<VD@<^1H:_9P;W-T96ES
M<V$@;N1K>79IY"!N:6UI+2!T86D@;W-O:71E=&EE=&]J82X`4V%L87-A;F%N
M('9A:6AT;R!E:2!O;&4@:^1Y=/9S<^0@;GEK>6ES:6QLY"!A<V5T=6MS:6QL
M82X@3W1A('EH=&5Y='3D('EL;.1P:73D:FEI;BX`365R:VMI`%1A<FMI<W1?
M82!L:6YK:VDN+BX`0VAI;&4`2VEI;F$`2VEI;F$@>6MS:6YK97)T86ES=&5T
M='4@*$=",C,Q,BD`2VEI;F$@<&5R:6YT96EN96X@*$)I9S4I`%9A;&ET<V4@
M;VAJ96QM80!686QI='-E('-A;&%S86YA`%9A;&ET<V4@:^1Y='3D:N1T=6YN
M=7,`5F%L:71S92!PY&EVY&WDY')I96X@97-I='ES87-U.@!686QI='-E(&QI
M<W1A;B!T>7EP<&D@*&KD<FIE<W1E='EI;&QE(&QI<W1O:6QL92D`2F]U;'5S
M86%R970`3'5O:VMA;>3D<FET>7-TY"`E<R!E:2!L]GET>6YY="X`4V5L:V7D
M`%!O:7-T82!-4T]F9FEC92!T86=I=`!0;VES=&$@:WES96QY`%!O:7-T82!K
MY'ET=.1JY#H@)7,`4&]I<W1A(&OD>71TY&KD`%!O:7-T82!KY'ET=.1JY&X@
M=&EE9&]T`%-E;&ME;F5VY.0@;7GV:.3D;@!.87!S875T82!J871K86%K<V5S
M:0!#;&EK871E;&P@2%144#IN(&MA=71T80!3=6QJ92!I:VMU;F$`4&EL=FGD
M`%!I;'9I;F5N(&%I:V%I<VEN`%!I;'9I;F5N`$MO;VMO<R`H2V5E;&EN9RD@
M<V%A<F5T`%!I96YE;F[D('-I=G5V86QI:VMO`%!I96YE;FYE='ET(')E=6YA
M=`!+;VQU;6)I80!6Y')I`%;D<FEV86QI='-I;@!6Y')I=F%L:6YT80!387)A
M:SH`4V%R86MK96ED96X@;W1S:6MO=`!387)J86MU=F%T`$MO;65N=&\`2V]M
M96YT;W1U;&MK:0!+;VUM96YT=&D`66QE:6YE;B!N:6UI`$MO;6]R:70`67)I
M='ES`%1I971O:V]N965T`$]L;W-U:&1E`$]L;W-U:'1E970`07-E='5K<VEE
M;B!E<F]T`$%S971U:W-E="!01$$M;&%I='1E:61E;BP@Y&QY<'5H96QI;6EE
M;B!J82!/=71L;V]K:6X@<WEN:W)O;F]I=&EI;BX`07-E='5K<VEA('!I=.3D
M('#D:79I='3DY"X`07-E=&$@87-E='5K<V5T("5S`%9A:'9I<W1A(&MI<FIO
M:71T86UA;&QA('-A;&%S86YA('5U9&5S=&%A;@!+;VYG;P!+;VYG;VX@9&5M
M;VMR86%T=&EN96X@=&%S879A;'1A`%EH=&5Y<R!E<.1O;FYI<W1U:2X`66AT
M97ES(&5PY&]N;FES='5I.B``66AT97ES(&IU;&MI<W1E;B!A=F%I;G1E;B!P
M86QV96QI;65L;&4@97#D;VYN:7-T=6DN`%EH=&5Y<R!J=6QK:7-T96X@879A
M:6YT96X@<&%L=F5L:6UE;&QE(&5PY&]N;FES='5I+B!6:7)H93H@)7,@*"5S
M*0!9:'1E>7,@9G1P+7!A;'9E;&EM96QL92!E<.1O;FYI<W1U:2X`66AT97ES
M=&EE9&]T`%EH=&5Y<W1I961O="!L:7/D='1I:6X@;W-O:71E:VER:F%A<VDN
M`%1I:79I<W1E='EN('1I961O<W1O;B!T>7EP<&DZ`"(E<R(Z;B!S:7/D;'3V
M`$IA=&MA`$-O;VL@<V%A<F5T`$5VY'-T90!+;W!I;VD`2V]P:6]I;G1I(&5P
MY&]N;FES='5I.B`E<P!+;W!I;VD@=F%L:6YT80!#;W-T($E$`$-O<W1A(%)I
M8V$`3F]R<W5N;'5U<F%N;FEK:V\`5FEE<W1I;B!01U`M<V%L875S=&$@96D@
M=F]I='4@=&5H9.0Z(`!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4$=0
M+6%L;&5K:7)J;VET=7-T83H@`%9I97-T:6X@4R]-24U%+7-A;&%U<W1A(&5I
M('9O:71U('1E:&3D+@!6:65S=&EI;B!E:2!V;VET=2!M=6]D;W-T86$@4R]-
M24U%+6%L;&5K:7)J;VET=7-T82X`16D@=F]I='4@;W1T86$@>6AT97ET=.0N
M("5S`$QD87`M<&%L=F5L:6UE96X@96D@<V%A='4@875T;W)I<V]I='5A('EH
M=&5Y='3D+@!%:2!V;VET=2!T87)K:7-T86$@<V%L9&]A+B`E<P!,1$%0+7!A
M;'9E;&EM965N(&5I('-A871U('EH=&5Y='3D+@!%:2!V;VET=2!O='1A82!Y
M:'1E>71TY"!P86QV96QI;65E;B`B)7,B(&OD>71TY&5N($944#H@)7,`16D@
M=F]I='4@;'5O9&$@:F%K96QU;&ES=&%A+B`E<P!01U`M<V%L871T=6$@=&EE
M=&]A(&5I('9O:71U(&%U:V%I<W1A.B``4R]-24U%+7-A;&%T='5A('1I971O
M82!E:2!V;VET=2!A=6MA:7-T82X`16D@=F]I='4@<&]I<W1A82!Y:'1E>7-T
M:65T;V$N("5S`$5I('9O:71U('!O:7-T86$@:F%K96QU;&ES=&%A+B`E<P!%
M:2!V;VET=2!P;VES=&%A('#D:79I='ES<VMR:7!T:>0@(B5S(BX`5FEE<W1I
M;B!LY&AE='3D:N1N('/D:&OV<&]S=&EO<V]I=&5T=&$@96D@<'ES='ET='D@
M;>3D<FET=&5L96WDY&XN`$5I('9O:71U(&AA:V5A(&MO:V\@;W-O:71E:VER
M:F%A+@!%:2!V;VET=2!H86ME82!K;VMO(&IA:V5L=6QI<W1A82X`16D@=F]I
M='4@:&%K96$@:V]K;R!L:7-T86$@:F%K96QU;&ES=&]I<W1A+@!%:2!V;VET
M=2!L=6ME82!S=')A=&5G:6%A("(E<R(N`$MO;65N=&\@;6MD:7(@(B5S(B!E
M<.1O;FYI<W1U:2X`2G5L:VES=&5N(&%V86EN=&5N('!A;'9E;&EM96QT82!E
M:2!S86%T=2!J=6QK:7-T82!A=F%I;G1A+@!4:65D;W-T;V]N("(E<R(@96D@
M=F]I(&MI<FIO:71T86$N`$5I('9O:71U(&%U:V%I<W1A("5S+@!9;&SD<&ET
M;VUO9'5U;&EN("5S(&%U:V%I<W4@97#D;VYN:7-T=6D`16D@=F]I(&%U:V%I
M<W1A(&AA:V5M:7-T;V$@(B5S(BX`3$1!4"UP86QV96QI;65L=&$@96D@;VQE
M(&UA:&1O;&QI<W1A(&5T<VGD+@`E<SKDY"!E:2!V;VET=2!L=6ME82X`2^1Y
M='3D:N1N('-A;&%S86YA82!E:2!V;VET=2!N;VQL871A+B!*;W1K=70@=&%R
M=FET=&%V870@=&EE9&]T(&]V870@=N3D<FEN+B!9<FETY"!U=61E<W1A86X@
M=&%I(&]T82!Y:'1E>71TY"!Y;&SD<&ET;V]N(&IO<R!T87)V:71S970@;&ES
MY.0@87!U82X`16D@=F]I='4@:&%K96$@04-,+71I971O:F$`16D@=F]I='4@
M:&%K96$@;W-O:71E:VER:F%A+B`E<P!%:2!V;VET=2!H86ME82!J86ME;'5L
M:7-T86$N("5S`$5I('9O:71U(&AA:V5A(&IA:V5L=6QI<W1O:F$N("5S`$5I
M('9O:71U(&AA:V5A('1I971O:F$@<&%L=F5L:6UE;B!T;VEM:6YN;VES=&$`
M16D@=F]I='4@<&%L875T=&%A(&%S971U:W-I82X`2V]M96YT;R!R;61I<B`B
M)7,B(&5PY&]N;FES='5I+@!%:2!V;VET=2!T86QL971T86$@)7,@87-E='5K
M<VEA+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I
M;W1A+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU=7-K;W!I
M;W1A("5S`$5I('9O:71U('1A;&QE='1A82!A<V5T=7-PY&EV:71Y<W-K<FEP
M=&GD.B`B)7,B+@!%:2!V;VET=2!T86QL971T86$@87-E='5S=&5N('9A<FUU
M=7-K;W!I;W1A("5S+@!!<V5T=7-T:65D;W-T;VX@)7,@=&%L;&5T=7,@97#D
M;VYN:7-T=6DN(%9O:70@:^1Y='3DY"!J;W1A:VEN(&%S971U<W1A('1A;&QE
M='1A86MS97-I(&MO;V1I;B!T86MA:7-I;B`E<R!T86D@=&%I(&MO<&EO:61A
M(&OD<VEN(&%L;&$@;VQE=F%N(&MO;V1I;B!T:65D;W-T;V]N("5S+@!,1$%0
M+7!A;'9E;&EM96QT82!E:2!O;&4@;6%H9&]L;&ES=&$@971S:>0N`$MO;65N
M=&\@=6YL:6YK("(E<R(@97#D;VYN:7-T=6DN`$5I('9O:71U('#D:79I='3D
MY"!Y:'1E>7-T:65T;VIA+B`E<P!%:2!V;VET=2!PY&EV:71TY.0@:F%K96QU
M;&ES=&%A+B`E<P!6:65S=&5JY"!E:2!V;VET=2!P;VES=&%A(&MA;G-I;W-T
M82`B)7,B.B`E<P!-;WII;&QA(%-I9&5B87(@96D@;/9Y='EN>70N(%9A<FUI
M<W1A(&5T=.0@4VED96)A<B!O<VEO(&]N(&%U:VDN`$OD>71TY&KD;&QE("(E
M<R(@96D@=F]I='4@86YT86$@<V5U<F%A=FEA(&]I:V5U<VEA(&MA;G-I;V]N
M("(E<R(Z("5S`$QA<VME='1U('1E:W-T:0!-86$`2W5R<W-I=`!,=6\`3'5O
M('5U<VD@;&EN:VMI`$QU;R!U=7-I`%9O:2!L=6]D82!U=7-I82!K86YS:6]I
M=&$`3VEK975D970@=&5K:6KD;&SD`$QU;W1T;VMO<G1I;FYU;65R;P!+<F]A
M=&EA`$MU=6)A`%3D;>1N:&5T:VEN96X@-"!V86EH971T80!4Y&WD;FAE=&MI
M<V5T(&ES='5N;F]T`$ME;&QO;F%I:V$@=.1L;.0@:&5T:V5L;.0`5.1MY&YH
M971K:6YE;B!54DP@;VX`5.1MY&YH971K:7-E="!KY'ET=.1JY'0`5.1MY&YH
M971K:6YE;B!SY.0`5.1MY&YH971K:6YE;B!T:6QA.B``5.1MY&YH971K:6YE
M;B!T>7EL:0!6;VET(&UU;VMA=&$@=&5H=.1V:>0L(&IO=&MA('-U;W)I=&5T
M86%N(&MU;B!K:7)J875D=71A86X@<VESY.1N(&]H:F5L;6%A;B`E<RX`3&5I
M:VMA80!,96EK:V%A('9A;&ET='4`2WEP<F]S`$MY<FEL;&EN96X@*$M/23@M
M4BD`2WER:6QL:6YE;B`H5VEN9&]W<RTQ,C4Q*0!+>7)I;&QI;F5N+U5K<F%I
M;F$@*$M/23@M52D`5'-E:VEN('1A<V%V86QT80!04`!$4TX@*&QI<^1T:65T
M;V$@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A
M8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!0Y&EV:71TY&EN`$1A=&%4<F5E+7-E
M;&%I;@!4:65T;VMA;G1A:&%K=0!0Y&EVY'ES`%#D:7;D;>3D<N0@=F%S=&%A
M;F]T971T=0!0Y&EVY&WDY'+D;B!V86QI;G1A`%#D:7;D`%!O7VES=&$@<V%R
M86ME`&IO=6QU:W5U`$1E<VEM86%L:6YU;65R;W0`4&EE;F5N;N0@<VES96YN
M>7-TY`!/;&5T=7,`3VQE='5S=N1R:0!/;&5T=7-P<F]F:6EL:0!/;&5T=7,@
M:V]M96YT;W1U;&MK:0!-Y.1R:71E;&WD=`!0;VES=&$`4&]I<W1A('-O;'4`
M4&]I<W1A(')Y:&WD`%!O:7-T82!L;VMI`%!O:7-T82!O:6ME=7,`5F]I('!O
M:7-T86$@:F$@='5H;W1A('!O:7-T971T=6IA('9I97-T96KD`%!O:7-T82!S
M;VQU`%!O:7-T82!S87)A:V4`4&]I<W1A(&]L96UA<W-A(&]L979A="!V86EH
M=&]E:'1O:6YE;B!M86QL:0!6;VD@<&]I<W1A82!V:65S=&5JY`!0;VES=&$@
M(B5S(CIN(&]I:V5U:W-I80!/;&5T:V\@=F%R;6$L(&5T=.0@:&%L=6%T('!O
M:7-T86$@(B5S(B!J82!K86EK:VD@<V5N(&%L:6]I:V5U9&5T/P!0;VES=&$@
M<FEV:0!0;VES=&$@=F%L:71T=2!P<F]F:6EL:0!6;VD@;'5O9&$@=75S:6$@
M:V%N<VEO:71A`%!O:7-T82!V86QI='1U('-A<F%K90!0;VES=&$@=F%L:71T
M=2!R:79I`%!O:7-T971T=2!PY&EV:71Y<W-K<FEP=&D@(B5S(BX`5&]I;6ET
M=7-A:6MA`%1A;G-K80!/;F=E;&UA;B!K=79A=7,`2W5V875S`%1A<FME;6UA
M="!T:65D;W0@*&SV>71Y=N1T(&UY]G,@2&]R9&4Z;B!L;VMI=&EE9&]S=&]S
M=&$I.@!487)K96UM870@=&EE9&]T(&]N('1A;&QE=&5T='4@>6QLY'!I9&]N
M(&OD<VET96QTY';D:W-I+@!+96AI='ES`$MO<W1E=7-P:7-T90!%9&5L;&ES
M96X@='5N;FEN(&MO<W1E=7-P:7-T93H@`$MO<W1E=7-P:7-T93H@`%-U=6YT
M82!V87-E;6UA;'1A(&]I:V5A;&QE`%-U=6YT82!O:6ME86QT82!V87-E;6UA
M;&QE`$AA:V5M:7-T;P!+Y'ETY"`R-"UT=6YN:6X@86EK865S:71Y<W3D+@!.
MY&MY;>1N(&%S971U:W-E=`!%<VET>7-T87!A('EK<VET>6ES:V]H=&%I;F5N
M(&5N;G5S=&4`17-I='ES=&%P82!E;FYU<W1E96QL92`H5$%&*0!%<VET>7-T
M87!A`%!E<FEL;&5M96YO:6QM;VET=7,`1&II8F]U=&D`16D@<V%A('!O:7-T
M86$`Q&SD(&OD>73D('-U;W)A86X@;6%I;G1E;F%N8V4N<&AP.G3D`$IO<R!E
M;G-I;6WD:6YE;B!R:79I('-I<^1L=.3D('-A<F%K:V5I9&5N(&]T<VEK;W0L
M(&YI:6X@=F%L:71S93H`1&]M:6YI:V%A;FEN96X`1&]M:6YI:V%A;FEN96X@
M=&%S879A;'1A`$5I:_8@;VQE(&OD>71TY&KD='5N;G5S=&$_($MI<FIA=61U
M(&OD>71TY&KD:W-I+@!486QL96YN80!486QL96YN82`E<P!486QL96YN82!L
M=6]T=2!A<V5T=7,@4$A0+7-K<FEP=&ENY"X`06QA<W9E=&]V86QI:VMO`$AU
M=6UE970`4^1H:_9P;W-T:6]S;VET90!%36%I;"UT;RU335,@9V%T97=A>2!A
M:G5R:2P@;FEI;&QE('!A;'9E;'5N=&%R:F]A:FEL;&4L(&IO=&MA('1A<FIO
M879A="!TY'3D('!A;'9E;'5A+@!625)(10!%8W5A9&]R`$UU;VMK86$`375O
M:VMA82!O<VEO=&$`375O:VMA82!R>6AMY.0`375O:VMA82!O:6ME=71T80!-
M=6]K:V%A(&]I:V5U:W-I80!-=6]K:V%A("<E<R<Z;B!O:6ME=6MS:6$`375O
M:VMA82!A<V5T=6MS:6$Z`$UU;VMK86$@(B5S(CIN(&]I:V5U:W-I80!-=6]K
M:V%A("5S.FX@;VEK975K<VEA`$MO=6QU='5S`$5G>7!T:0!%;"!386QV861O
M<@!%;&5M96YT=&DN+BX`16T`4^1H:_9P;W-T:0!3Y&AK]G!O<W1I;W-O:71E
M`%/D:&OV<&]S=&EO<V]I='1E:61E;B!P:73DY"!O;&QA('-A;6%T+@!3Y&AK
M]G!O<W1I('9A<FUI<W1U:W-E;&QA`$5M86EL+71O+5--4R!'871E=V%Y`$AY
M;6GV=`!4>6AJY"!V:65S=&DN`%1Y:&KD('9A<W1A=7,N`%1Y:&KD(&AA:W5T
M97)M:0!386QL:2!K=79I96X@;&%I='1A;6EN96X@:W5V86=A;&QE<FEA<W1A
M('1E:W-T:6X@:F]U:VMO;VXN`$QA:71A('#DY&QL92!O:6ME86X@<&%I;FEK
M:V5E;B!K;VYT96MS=&EM96YU+@!0Y.1T='EM:7-V=6]S:0!3=75R96YN82!E
M9&ET;W)I80!!;FYA(&MY<WEM>7,@:F]K82!K>7-Y=.3D;BP@:F]S('-A;&%S
M86YA<VD@:F]U9'5T86%N(&YO;&QA86UA86X@97-I;65R:VEK<VD@)VUI:^0@
M;VX@;&5M;6EK:VES:2!N:6UI/R<Z`$QA:71A(&MU=F$@55),('3D:.1N`$%N
M;F$@:VER:F%I;65T(&%L;&4Z`$5K=F%T;W)I86%L:6YE;B!'=6EN96$`17)I
M=')E80!6:7)H90!6:7)H92!PY&EV:71E='3D97-SY"!O<VEO=&$Z("5S`%9I
M<FAE('#D:79I=&5T=.1E<W/D('-Y;F,@86YC:&]R("UT:65T;V$Z("5S`%9I
M<FAE('!O:7-T971T865S<V$@<WEN8R!L;VMI83H@)7,`5FER:&4@:&%E='1A
M97-S82!S:7/D;'3VY#H@)7,N`%9I<FAE('#D:79I=&5T=.1E<W/D('-A;&%S
M86YA83H@)7,`5FER:&4@<^1H:_9P;W-T:79I97-T:7-SY"X`5FER:&4@:VER
M:F]I=&5T=&%E<W-A("(E<R(N`$5E<W1I`$5T:6]P:6$`171N:6YE;@!%=7)O
M;W!P80`Q-2!M:6YU=71I;B!VY&QE:6X`,B!M:6YU=71I;B!VY&QE:6X`,S`@
M<V5K=6YN:6X@=N1L96EN`#4@;6EN=75T:6X@=N1L96EN`$IO:V%I<V5L;&$@
M<VESY.1N:VER:F%U='5M:7-E;&QA`%!U;VQE;B!T=6YN:6X@=N1L96EN`$UI
M;G5U=&EN(';D;&5I;@!%<VEM97)K:VEA<G9O=#H`4W5O<FET80!,86%J96YN
M80!,86%J96YN82!S:79U=F%L:6MK;P!/9&]T971T:6EN(&UE<FMK:>0@)RDG
M`%-A;F$@<V5L;&%I<V5N86%N('1A:2!H86MU=&5R;6D@;&%I;F%U<VUE<FME
M:7-SY`!,;W!P=7#D:7;D;>3D<N0`16MS<&]N96YT=&D`1D<@=N1R:0!!<V5T
M=7-T:65D;W-T;VIE;B!T=6]N=&D@1E10.FQLY`!!<V5T=7-T96X@:&%K=2!E
M<.1O;FYI<W1U:2X`66AT97ES($Q$05`M<&%L=F5L:6UE96X@97#D;VYN:7-T
M=6DN`%EH=&5Y<R!334(M<&%L=F5L:6UE96X@97#D;VYN:7-T=6DN`$MO<&EO
M:6YT:2`B)7,B.FQTY"!E<.1O;FYI<W1U:2X`2V]P:6]I;G1I("(E<R(Z;&QE
M(&5PY&]N;FES='5I+@!5=61E;B!305-,+7EH=&5Y9&5N(&QU;VUI;F5N(&5P
MY&]N;FES='5I+@!3:6ER=&\@(B5S(CKDY&X@97#D;VYN:7-T=6DN`%-I:7)T
M;R!E<.1O;FYI<W1U:3H@)7,`2V%U;FES`$9A;&ML86YD:6X@<V%A<F5T("A-
M86QV:6YA<RD`1N1R('-A87)E=`!686MA=F$@=FER:&4Z`$9A:W-I`$9A:W-I
M=`!H96QM:6MU=0!4=6YT=74@:W5I;@!4=6YT=74@:W5I;CH@`$UU=71A;6EA
M('-A=&5I=&$`375U=&%M:6$@;'5M:7-A=&5I=&$`2V5N='3D;6%T<FEI<VD`
M1FEG;&5T($-!4%1#2$$`1FEG;&5T(&MI<FIA<VEN`$9I9'II`%1I961O<W1O
M`%1I961O<W1O:F5N(&QU:W5MY.1RY#H@)7,@=&EE9&]S=&\`5&EE9&]S=&]J
M96X@;'5K=6WDY'+D.B`E<R!T:65D;W-T;V$`5&EE9&]S=&]J96X@:^1S:71T
M96QY`%1I961O<W1O;B!N:6UI`%1I961O<W1O;B!V86QI;G1A`%1I961O<W1O
M;B!T=6]N=&D`5&EE9&]S=&]J96X@='5O;G1I(&5I(&]L92!KY'ET971TY'9I
M<W/D+@!3=6]D871T:6UE=`!3=6]M:0!%;G-I;6WD:6YE;B!P=6]L:7-K;P!%
M;G-I;6WD:6YE;B!N96QJY&YN97,`2V]R:F%A('-U:&1E`$ODY&YNY"!Y;7#D
M<FD`2V5L;'5V80!3=6UU`$MA;G-I;W1A("5S(&5I(&]L92!O;&5M87-S82X`
M2VER:F%S:6UE;B!VY')I`%)U;VMA`%-E;&%I;6EL;&4L(&IO=&MA(&5I=N1T
M('1U92!K=79I80!%;FYU<W1E("A4048I`$5N;G5S=&5T=&%V870@=G5O<F]K
M875D970@*$AU;VUA871H86X@971TY"!E;FYU<W1U:W-E<W-A(&]N('1I961O
M="!S96OD('#D:79I<W3D(&5T=.0@]FES=.0L(&IO=&5N('-U=7)I(&WDY'+D
M('#D:79IY"!A:6AE=71T86$@;&EI86X@;&5V9>1N(&]S:6]N*0!5;F]H9&ET
M:V\@<V%L87-A;F%S:3\`3&]M86MK965T`$UI971E;&%U<V4`36EE=&5L875S
M965N('1Y>7!P:0!-:65T96QA=7-E970`36EE=&5L875S965T(#(`1F]O<G5M
M:70`575D96QL965N;VAJ875K<V5T`'!E`$ME:'EK<V5T`%)A;G-K80!286YS
M:V$L($UE=')O<&]L:0!286YS:V%N($=U>6%N80!286YS:V%N(%!O;'EN97-I
M80!286YS:V%N(&5T96SD:7-E="!T97)R:71O<FEO=`!,Y&AE='3D:N0`4W5U
M;FYA<W1A(`!0:61E;7!I(&MU=F%U<SH`5.1Y<VEK=74`2V]K;R!N:6UI`$=A
M8F]N`$=A;&QE<FEA+"!J;W-T82!K=79A(&]T971A86X`1V%L;&5R:6$Z`$=A
M;6)I80!4964@)7,@87-E='5K<V5T`$=E;F5R;VET=2!K;V]D:0!'96]R9VEA
M`%-A:W-A`$=H86YA`$=I8G)A;'1A<@!%='5N:6UI`%EL96ES970@87-E='5K
M<V5T`$UE;F4`1_9D96P`1V]O9VQE($MA<G1A=`!';V]G;&4@:&%K=0!(87)M
M86%SY'9Y`$MR96EK:V$`2W)E:6MK82`H25-/+3@X-3DM-RD`1W+V;FQA;G1I
M`$=R96YA9&$`4GEH;>1N('EL;.1P:71O`%)Y:&UI96X@;FEM970@96EVY'0@
M<V%A(&]L;&$@='EH:FGD`$=R;W5P7VQD87`Z($5I('9O:61A(&QI<^1TY"!K
MY'ET=.1JY.0@)7,N(%!A;'9E;&EM96X@=FER:&5I;&UO:71U<R!O;&DZ(`!'
M<F]U<%]L9&%P.B!%:2!V;VED82!PY&EVY'1TY.0@:^1Y='3D:N3D("5S`$=R
M;W5P7VQD87`Z($5I('9O:61A('#D:7;D='3DY"!KY'ET=.1JY.0@)7,`4GEH
M;>1T`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`5FEE<F%I
M;&EJ86X@;VEK975D970`5FEE<F%S:VER:F$`1W5I;F5A`$=U:6YE82U":7-S
M874`1W5Y86YA`$A434P`2%1-3$%R96$@<&5L:W5R:6UA:7-E<W1I(&MI96QT
MY'ET>7D@<&]I<W1A;6%S=&$@<FEV:6X@=FEI;65I<W3D('-O;'5A+@!(5$U,
M07)E82!P96QK=7)I;6%I<V5S=&D@:VEE;'3D>71Y>2!P;VES=&%M87-T82!V
M:6EM96ES=.0@<V%R86ME='1A('1A=6QU:V]S=&$N`$A434Q!<F5A('!E;&MU
M<FEM86ES97-T:2!K:65L=.1Y='EY('!O:7-T86UA<W1A('9I:6UE:7-TY"!R
M:79IY"!T875L=6MO<W1A+@!(5%10+6%U=&5N=&EK;VEN=&EA(&5I(&SV>71Y
M;GET+@!(86ET:0!(87-H+6%L9V]R:71M:0!5<W9A`$]T<V%K90!/='-A:V4`
M2&5A<F0@:F$@36-$;VYA;&0@<V%A<F5T`%9O:6UA:V%S('5K:V]S;7ER<VMY
M`$AE<')E82`H25-/+3@X-3DM."U)*0!+;W)K975S`$]H:F4`07!U82!E9&ET
M;W)I;B!KY'ET=/;V;@!/:&IE`%!A;&QO;G!U;VQI<VMO.@!4Y'-SY"!O;B!T
M:65D;W-T;VX@86QK=6]S83H`2V]R:V5A`$MO7W1I`%!Y:.0@:7-T=6EN("A6
M871I:V%A;FEN(&MA=7!U;FMI=F%L=&EO*0!+;W1I`$MO=&EO<V]I=&4`2V]T
M:6AA:V5M:7-T;P!0=6AE;&EN("AK;W1I*0!(;VYD=7)A<P!(;VYG($MO;F<`
M2&]R9&4`2&]R9&4O2V]L86(Z($5PY&ME;'!O82`E<R!834PM9&%T86$@=FEE
M<W1I<W/D("5S`$AO<F1E+TMO;&%B.B!9:W-I:^3D;B!V:65S=&D@96D@=F%S
M=&%A(&]B:F5K=&EA("5S`$AO<F1E+TMO;&%B.B!9:'3D:^3D;B!O8FIE:W1I
M82`E<R!E:2!L]GET>6YY="!V:65S=&ES=.0@)7,`2&]R9&4O2V]L86(Z(%!O
M:7-T971T:6EN("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F%A=&EO:V]N
M92!V86%T:6D@=&]I;6EA:W-E96X@)V1O;7AM;"<@4$A0+6QA86IE;FYU:W-E
M;@!(;W)D92]+;VQA8CH@16D@=F]I9&$@;'5O9&$@=75T=&$@6$U,+7!U=71A
M(&]B:F5K=&EL;&4@)7,`2&]R9&4O2V]L86(Z($5I('9O:71U('!O:7-T86$@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($5I('9O:61A(&AA:V5A($U)344@
M240ZY"!O<VEO;&QE('1Y>7!P:>0@)7,`2&]R9&4O2V]L86(Z($5I('9O:2!S
M>6MR;VYO:61A("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!%:2!V;VED82!S
M>6YK<F]N;VED82!J86MO:F$Z("5S`$AO<F1E+TMO;&%B.B!4=6YT96UA=&]N
M(&IA:V\@(B5S(@!686%K87-U;W)A('/DY&YT]@!686%K87-U;W)A('3D>71E
M`%9A86MA<W5O<F$Z`$UI=&5N('1U;&ET('3D;FYE/R`H4F%P;W)T;VD@:VEI
M=&]S(2D`2W5I;FMA(&UO;G1A('-A<F%K971T82!H86QU870@>6AD:7-TY.0_
M`$ME;G1T:65N("AS87)A:VME:61E;BD@;'5K=6WDY'+D+@!+=6EN:V$@;6]N
M=&$@<FEV:>0@:&%L=6%T('EH9&ES=.3D/P!+;W-T975S`$MO<W1E=7,Z(`!(
M=6UO<FES=&ET`%5N:V%R:0!)34%0+7!O<W1I;&%A=&EK;VX@;'5O;G1I(&5P
MY&]N;FES='5I.B`E<P!)34%0+7!O<W1I;&%A=&EK;VX@<&]I<W1O(&5PY&]N
M;FES='5I.B`E<P!)34%0+7!O<W1I;&%A=&EK;VX@:VEI;G1I]FX@;'5O;G1I
M(&5PY&]N;FES='5I.B`E<P!)4"UO<V]I=&4`25`M;W-O:71E(&5I(&]L92!K
MY'ET971TY'9I<W/D+@!)4"UO<V]I=&4@96D@;VQE('-A;&QI='5N($-)1%(M
M8FQO:VEN('-I<^1L;.0`25`M<^3D;F[V<W3V;B!R:6MK;VUU<P!,7V%I=&$@
M<FEV:2!E;FYE;@!)<VQA;G1I`%9A:6X@:6MO;FET`$EK;VYI="`E<SIL;&4`
M26MO;FET(&IA('1E:W-T:0!0<F]F:6EL:6X@;FEM:3H`2F]S('-I=G4@96D@
M;N1Y(&MU;FYO;&QA+"!N:6EN(&%U:V%I<V4@)7,@97)I;&QI<V5S<^0@:6MK
M=6YA<W-A+@!*;W,@970@;N1E(&EK;VYE:71A(&OD>71TY&5S<^1S:2!);G1E
M<FYE="!%>'!L;W)E<B!S96QA:6YT82P@;FEI;B!S:6YU;B!P:73DY"!O='1A
M82!P;VES('#DY&QTY"!03D<@;.1P:6[D:WEV>7ES(')A<W1I='1A;6%L;&$@
M=.1MY"!L86%T:6MK;RX`2F]S(&[D970@=.1MY&X@=FEE<W1I;BP@;75T=&$@
M970@:W5V86$L(&YI:6X@='5O;6%A<VD@:W5V86$@96D@=F]I(&[D>71TY.0@
M:^1Y='3D;>1S<^1S:2!S96QA:6UE<W-A+@!+=79I96X@97-I:V%T<V5L=0!+
M=79A(%523`!+=79A(%523#H`2W5V82!G86QL97)I87-T80!+=79A(&=A;&QE
M<FEA<W1A.@!+=79A;B!V:65N=&D`2W5V870`5'5O;G1I+"!A<VME;"`E9`!4
M=6]T=2!K96YT=.0Z("5S`%1U;V1U="!K96YTY'0Z`$QA7VET82!R:79I(&KD
M;&ME96X`5N3D<N0@=&]I;6EN=&]K;V]D:2!A;FYE='1U+@!+Y'ET=.1JY'1U
M;FYU<R!T86D@<V%L87-A;F$@;VX@=N3D<FEN+@!6Y.1RY"!KY'ET=.1JY'1U
M;FYU<R!T86D@=F%I:'1O96AT;VEN96X@;W-O:71E+B!9<FETY"!U=61E<W1A
M86X@:F$@;W1A('EH=&5Y='3D('EL;.1P:71O;VX@:F]S('1A<G9I='-E="!L
M:7/DY"!A<'5A+@!,:7/DY"!S:7-E;FYY<W3D`$EN=&EA`%EK<VET=.1I<V5T
M(&OD>71TY&KD=`!);F1O;F5S:6$`26YF;P!);F9O<FUA871I;P!4:65T;V$@
M96D@;VQE(&5NY.0@<V%A=&%V:6QL82X`3&%I=&$@<U]A<F%K92!JY&QK965N
M`$QA:71A(&MU=F$`3&%I=&$@=&%U;'5K:V\`3&%I=&$@=W=W+6QI;FMK:0!,
M86ET82!?<V%R86ME(&5N;F5N`$QA:71A('5U<VD@<V%R86ME(&YY:WEI<V5N
M(&KD;&ME96X`3&%I=&$@=75S:2!S87)A:V4@96YN96X@;GEK>6ES=.0`3&%I
M=&$@=75S:2!R:79I(&YY:WEI<V5N(&KD;&ME96X`3&%I=&$@=75S:2!R:79I
M(&5N;F5N(&YY:WEI<W3D`$QA:71A(&MA<'!A;&4@;GEK>6ES96X@;F]D96X@
M:N1L:V5E;@!,86ET82!K87!P86QE(&5N;F5N(&YY:WEI<W3D(&YO9&5A`$QA
M:71A('9A:6AT;V5H=&]I;F5N(&UA;&QI`$%N;F$@<^1H:_9P;W-T:6]S;VET
M92!J;VAO;B!U=7-I('-A;&%S86YA(&SD:&5T973DY&XZ`$QA:71A('-O;'4@
M:N1L:V5E;@!,86ET82!S;VQU(&5N;F5N`$QA:71A('-O;'4@:N1L:V5E;@!,
M86ET82!S87)A:V4@96YN96X`5F]I(&QA:71T86$@=FEE<W1E:N0`3&%I=&$@
M:V%P<&%L92!JY&QK965N`$QA:71A(&MA<'!A;&4@96YN96X`3&%I=&$@<FEV
M:2!E;FYE;@!,86ET82!R:79I(&KD;&ME96X`06YN82!V86%D:71T879A('9A
M<W1A=7,@='5R=F%K>7-Y;7EK<V5E;CH`3&EI=.0O375O:VMA82!K=79I80!,
M:6ETY"]-=6]K:V%A(&QI;FMK:>0`4VEN=6QL82!E:2!O;&4@=&%R<&5E:W-I
M(&MR961I:71T96KD(&SD:&5T=.3D:W-E<VD@=FEE<W1I;B!J86ME;'5L:7-T
M86QL92X`4FEI='3D;>1T=/9MY'-T:2!K<F5D:6ET=&5JY`!+;VMO;F%I<VQU
M:W4`2V]K;VYA:7-L=6MU;&ES=&$`17#D:V5L<&\@(%5$2"`H57-E<B!$871A
M($AE861E<BDN`$5PY&ME;'!O82!:25`M=&EE=&]A+@!%<.1K96QP;R!O:&IE
M;&UA+@!%<.1K96QP;R!B871C:"!)1"X`3.1H971E='1I:6X@97#D:V5L<&]A
M('1I971O82X`17#D:V5L<&\@=F%S=&%A;F]T=&%J86X@;W-O:71E+@!%<.1K
M96QP;R!T:65D;W-T;VUU;W1O`$5PY&ME;'!O(&QI<V5N<W-I879A:6XN`$5P
MY&ME;'!O('!A:6MK871I971O+@!%<.1K96QP;R!M<V=?='EP92`N`$5PY&ME
M;'!O('1A:2!P=75T='5V82!A<&E?:60N`$5PY&ME;'!O('1A:2!P=75T='5V
M82!P87)A;65T<FDN`$5PY&ME;'9O="!O:6ME=61E="!Y;&5M;>1L;.0@=&%S
M;VQL82X`17#D:V5L<&\@<&%R;F5R(&ED+@!%<.1K96QP;R!T=6]T96MO;V1I
M+@!%<.1K96QP;R!P<F]T;VMO;&QA+@!%<.1K96QP;R!V87-T86%N;W1T86IA
M.B`B)7,B`$5PY&ME;'!O(&IA:V\M;V)J96MT:0!%<.1K96QP;R!LY&AD96]S
M;VET92X`17#D:V5L<&]A('5N:6-O9&4M=&EE=&]A+@!);G9E;G1A87)I;P!+
MY.1N;N0@=F%L:6YT82!KY.1N=&5I<V5K<VD`27)A;BP@27-L86UI;&%I;F5N
M('1A<V%V86QT80!)<F%K`$ER;&%N=&D`36%N+7-A87)I`$5R:6QL:7-IY"!5
M:VMO<VUY<G-K>6KD`$ES<F%E;`!,:6EK:V5E;&QE;&%S:VEJ80!+=7)S:79O
M:71U`$ET86QI80!*86UA:6MA`'1A;6UI:W5U`$IA<&%N:0!*87!A;FD@*$E3
M3RTR,#(R+4I0*0!*97)S97D`2F]R9&%N:6$`:&5I;N1K=74`:V5SY&MU=0!+
M97-K:73D`$ME<VMI=.0@:V5S:V5L;&4`2V5S:VETY"!TY'ES:6X`2V5S:VET
MY"!V87-E;6UA;&QE`$ME<VMI=.0@;VEK96%L;&4`2V%Z86MS=&%N`%/D:6QY
M=.0@86QK=7!E<N1I;F5N/P!+96YI80!!=71E;G1I:V]I;G1I(&5PY&]N;FES
M='5I($ME<F)E<F]S+7!A;'9E;&EM96QL92X`2V5R;F5L(&%L;VET=&5L:6IA
M=`!!=F%I;65N(&QU;VYT:0!!=F%I;65N('1U;FYI<W1E`$%V86EM96X@<&ET
M=75S`$%V86EM96X@='EY<'!I`$%V86EM96X@:^1Y='3V`$%V86EN(&]N(&IO
M(&IU;&MI<W1E;B!A=F%I;G1E;B!P86QV96QI;65L;&$`3&%P<V5T`$MI<FEB
M871I`$MO<F5A+"!D96UO:W)A871T:6YE;B!K86YS86YT87-A=F%L=&$@*%!O
M:&IO:7,M2V]R96$I`$MO<F5A+"!T87-A=F%L=&$@*$5T96SD+4MO<F5A*0!+
M;W)E82`H155#+4M2*0!+=7=A:70`2VER9VES=&%N`$%S7V5T=&5L=0!+:65L
M:0!,86]S+"!D96UO:W)A871T:6YE;B!K86YS86YT87-A=F%L=&$`2N1L:VEM
M;>1I;F5N('!U;VQI<VMO`$5D96QL:6YE;B!S86QA<V%N86YV86EH=&\`2N1L
M:VEM;>1I;F5N(&YE;&KD;FYE<P!0Y&EV:71E='1Y('9I:6UE:W-I.@!%9&5L
M;&EN96X@<VESY.1N:VER:F%U='5M:6YE;CH@)7,`161E;&QI;F5N('-I<^3D
M;FMI<FIA=71U;6EN96XZ("5S+"`E<P!%9&5L;&EN96X@<VESY.1N:VER:F%U
M='5M:6YE;CH@16D@;6EL;&]I;FMA86X`3&%T=FEA`$QA:VD`07-E='1E;'4`
M2N1TY"!T>6AJY&MS:2!J;W,@96D@<F5U;F]J80!,:6)A;F]N`%9A<V5N`%9A
M<V5N(&]T<V%K90!687-E;B!A<G9O=`!,97-O=&\`5&%S;P!,:6)E<FEA`$QI
M8GEA($%R86(@2F%M86AI<FEY80!,:6-H=&5N<W1A:6X`2V5V>71TY"!RY&YT
MY.0`2VER:F%U9'4@<VESY.1N`$ME=GET=.0@<V%D971T82!A:6MA:7-I;@!+
M979Y='3D('-A9&5T=&$@;7GV:&5M;6EN`$ME=GEI=.0@<V%D96MU=7)O:F$`
M2V5V>71TY"!S861E='1A(&IA(&UY<G-K>6ES=.0`2V5V>71TY"!L=6UI<V%D
M971T80!+979Y:73D(&QU;6EK=75R;VIA`$QI;65R:6MI=`!,:6YK:VD`3&EN
M:VMI(&]S;VET=&%A.@!,:6YK:73D('/D:&OV<&]S=&EO<V]I=&4@:VER:F]I
M=&$@=75S:2!V:65S=&D@<VEV=6QL92!NY&MY;>1S<^0`3&EN:VET`$QI;G5X
M('!I<&%R96ET80!6;VD@;&ES=&%U:W-E<W-A(&[D:&3D(&MA;G-I;VX`3N1Y
M=.0@=&EE=&]K86YN870`3N1Y=.0@;VAJ96ED96X@86EH965T`$[D>73D('1A
M=6QU=`!,:7-T86XM07)K:7-T;P!,:7-T86XM3VAJ90!,:7-T86XM260`3&ES
M=&%N+4]M:7-T86IA`$QI<W1A+79I97-T:0!,:7-T86XM5&EL875S`$QI<W1A
M;BU4:6QA=6MS96XM;&]P971T86UI;F5N`$ES='5N=&]J96X@;&ES=&%U<R!E
M<.1O;FYI<W1U:3H@)7,`2^1Y='3D:FEE;B!L:7-T875S(&5PY&]N;FES='5I
M.B`E<P!+Y'ET=.1JY'1I971O:F5N(&[D>71TY&UI;F5N(&]N(&5S=&5T='DN
M`$MI<FIA;&QI<W5U<P!,:65T='5A`$QA9&%T86%N+BXN`%!A:6MA;&QI<W1A
M(&%I:V%A.B``3&]K86QI<V%A=&EO(&IA(&%I:V$`4&%I:VMA`$MI<FIA=61U
M('-I<^3D;@!%9&5L;&ES96X@<WEN:W)O;F]I;G1I<V5S<VEO;B!L;VMI`$MI
M<FIA=61U('5L;W,`2VER:F%U9'4@<VESY.1N`%1E:'3D=N1T('-I<^3D;FMI
M<FIA=71U;6ES97-S80!3:7/DY&YK:7)J875T=6UI<V5S:2!E<.1O;FYI<W1U
M:2X@5&]D96YNY&OV:7-E<W1I(&MI<FIO:71I="!VY.1R:6X@:^1Y='3D:N1T
M=6YN=6MS97-I('1A:2!S86QA<V%N87-I+@!3:7/DY&YK:7)J875T=6UI;F5N
M(&5PY&]N;FES='5I+@!0:71KY"!T96MS=&D`4F%K:V%U<P!-871A;&$`4&EE
M;F5T(&MR96EK:V%L86ES970@:VER:F%I;65T`%!I96YE="!L871I;F%L86ES
M970@:VER:F%I;65T`%!I96YE="!R;V]M86QA:7-E="!N=6UE<F]T`$QU>&5M
M8G5R9P!+2P!-3U1$`$U3+51.148@;&EI=&5T:65D;W-T;R!O;&D@='EH:N0N
M`%9)15-420!-86-A;P!-86ME9&]N:6$L($5N=&EN96X@2G5G;W-L879I86X@
M=&%S879A;&QA;BX`36%D86=A<VMA<@!486EK=75S`%/D:&OV<&]S=&D`4&]S
M=&EN('EL;.1P:71O`%1E92!L:6YK7VMI+BXN`$UA;&%W:0!-86QE<VEA`$UA
M;&5D:6EV:70`4&]S=&D`36%L=&$`5F]I="!H86QL:6YN;VED82!L:7-T86$@
M:V%T96=O<FEO:7-T82P@:F]I9&5N(&%V=6QL82!V;VET(&QI:71TY.0@87-I
M;VET82!Y:'1E96X@<V%M;VIE;B!O='-A:VME:61E;B!A;&QE(&IA(&QI:71T
MY.0@;FEI:&EN(';D<F5JY"X`36%P,C0@:V%R='1A`$UA<%%U97-T(&MA<G1T
M80!687-T86%V=75D970@=&%L;&5T971T=2X`;6%A;&ES:W5U`$UA<F=I;F%A
M;&D`5F]I(&UE<FMI=.0@5F%N:&$O575S:2!T:65T;VIA`%9O:2!M97)K:73D
M('9I97-T96KD("AE<VEM+B!4Y')K9>0O5F%S=&%T='4I`$UA<G-H86QL('-A
M87)E=`!-87)T:6YI<75E`%3D<VWDY';D="!K96YTY'0`36%U<FET86YI80!-
M875R:71I=7,`4W5U<FEN('-A;&QI='1Y(&MR961I:71T:2X`4W5U<FEN('-A
M;&QI='1U('9I97-T:6]S:6]MY.1RY"!Y;&ET971T>2X`161E;&QI<V5N(#(T
M('1U;FYI;B!K;W)K96EN(&SD;7#V=&EL83H@`$5D96QL:7-E;B`V('1U;FYI
M;B!K;W)K96EN(&SD;7#V=&EL83H@`%!O<G1A86QI;W-I;VED96X@96YI;6WD
M:7-MY.1RY`!3=75R:6X@<V%L;&ET='4@<&ET=75S`'1O=6MO:W5U`$UA>6]N
M971T90!,Y.1K971I961E`$KD<V5N970`365N=6X@;75O=&\Z`%EH9&ES=.0@
M<V]L=70`5FEE<W1I`%9I97-T:6X@=&%R:VES='5S(&]N;FES='5I+"!M=71T
M82!A;&QE:VER:F]I='1A:F%N('9A<FUE;FYE='1A(&5I('9O:71U('1A<FMI
M<W1A82X`5FEE<W1I('9A;FAE;FDN`%9I97-T:6X@='EY<'!I`$UE=&%R('/D
MY`!-971A<BUO<VEO(&5I(&]L92!KY'ET971TY'9I<W/D+@!-971A<BUO<VEO
M(&5I(&]L92!KY'ET971TY'9I<W/D+B!487)K96UM870@=&EE9&]T(&]N('1A
M;&QE=&5T='4@>6QLY'!I9&]N(&OD<VET96QTY';D:W-I+@!-971A<D1"(&5I
M(&]L92!Y:&1I<W1E='1Y+@!-971O9&D`365T;V1I82`B)7,B(&5I(&]L92!M
MY.1R:71E;'1Y`$UE=&]D:6$@96D@;VQE(&WDY')I=&5L='DN($MU='-U=F$@
M;65T;V1I.B`E<P!-971R:6YE;@!-96MS:6MO`$UI:W)O;F5S:6$L(%EH9&ES
M='EN965T('9A;'1I;W0`2V5S:V5L;.0`36EM92UT>7EP<&D`161E;&QI<V5N
M(#(T('1U;FYI;B!M871A;&EN(&SD;7#V=&EL83H@`$5D96QL:7-E;B`V('1U
M;FYI;B!M871A;&EN(&SD;7#V=&EL83H@`%-A;&%S86YA(&5I(&]L92!V:65L
MY"!T87)P965K<VD@=F%N:&$`4&5I;&EK=79A`%-E:V%L86ES970`4$5!4BUP
M86ME='1I($A45%!?4F5Q=65S="!P=75T='5U+@!0=75T='5V870@87-E='5S
M=&EE9&]S=&\N(%-I;G5N('!I=.3D('1E:&3D(&%S971U<W1I961O<W1O(&IO
M<R!H86QU870@:^1Y='3DY"!TY'3D(&]H:F5L;6%A+@!0=75T='5V82!M97-S
M86=E($E$+@!6Y&QT=.1MY'3V;B!014%2+7!A:V5T=&D@36%I;"!P=75T='5U
M+@!0=75T='5V82!S97-S:6]N($E$+@!M80!-;V)I:6QI<^1H:_9P;W-T:0!+
M;VAT86QA:6YE;@!-=6]K:V%U:W-E;B!PY&EVY&WDY'+D`$UU;VMK86$@55),
M.FEA`$ME<G)O:6X`36]L9&]V82P@=&%S879A;'1A`$UO;F%C;P!-;VYG;VQI
M80!K=75K875S:2!J82!V=6]S:0!+=75K875S:71T86EN`$UO;G1S97)R870`
M2W5U;B!V86EH965T`%)I=FEL=.0@)60@;/9Y='EI(&5N96UMY&X@:V5N='1I
MY"!K=6EN(&]D;W1E='1U("5D+@!-87)O:VMO`$5N:6UMY&MS:2!S96QK9>3D
M`$5N:6UMY&MS:2!P:6QV:7-TY`!%;FEM;>1K<V5E;B!P:6QV:7-TY"!J82!T
M=75L:7-T80!%;FEM;>1K<V5E;B!A=7)I;FMO:7-T80!3:6ER<N0@86QA<W#D
M:6X`4VEI<G+D('9A<V5M;6%L;&4`4VEI<G+D(&]I:V5A;&QE`%-I:7)RY"!Y
M;/9S<.1I;@!3:6ER<N0@86QA<W#D:6X`4VEI<G+D('EL]G-PY&EN`$UO<V%M
M8FEK`$UO;FET87-O:6YE;B!A;&%S=F5T;W9A;&EK:V\`375L=&EM87`@27-O
M+4)R:71A;FYI86X@:V%R='1A`$UO;FEV86QI;G1A`$OD>71TY&KD='5N;G5K
M<V5N:0!/;6%N(&OD>71TY&KD='5N;G5K<V5N('1I961O=`!/;6$@<&]R=&%A
M;&D`3VUA;B!P;W)T86%L:6X@87-E='1E;'4`37EA;FUA<B`H0G5R;6$I`$5)
M+"!%3B!S=6]S='4`3FEM:0!.86UI8FEA`$YA=7)U`$YE<&%L`$%L86YK;VUA
M870`06QA;FMO;6%I9&5N($%N=&EL;&ET`$YE='-C87!E($)A<V4@55),`$YE
M='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!5
M4DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!5
M4DP`3F5T<V-A<&4@4U-,+7!A;'9E;&EM96X@;W-O:71E`$YE='-C87!E('9A
M<FUE;G1E96X@:V]M;65N='1I`$YE='-C87!E('9A<FUE;G1E96X@='EY<'!I
M`%9E<FMK;P!%:2!K;W-K86%N`%5U<VDM2V%L961O;FEA`%5U<VD@;'5O:VET
M=7,`575S:6MU=0!5=7-I(&OD>71TY&KD='5N;G5S("AV87!A865H=&]I;F5N
M*0!5=7-I+5-E96QA;G1I`%5U<VD@<V%L87-A;F$`575S:2!S86QA<V%N82!V
M86YH96YE92`E>"X`06YT86UA<VD@=75D970@<V%L87-A;F%T(&5I=N1T('3D
M<VWDY"X`575S:2!I:VMU;F$@*%]B;&%N:RD`575T:7-E=`!+97-K=7-T96QU
M<GEH;>1T`%-E=7)A879A`%-E=7)A879A="`T('9A:6AE='1A`%-E=7)A879A
M="!A<V5T=6MS970`4V5U<F%A=F$^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA
M`%GV`$YI=64`16D`07-E='5S=&EE=&]J82!E:2!O;&4@<V%A=&%V:6QL82P@
M:F]S=&$@=F]I<VD@;N1Y='3DY"!E<F]A=F%I<W5U:W-I82X`16D@;VQE('-A
M871A=FEL;&$@<W5U;FYI=&5L;6%A($E33R!L979Y:W5V871I961O<W1O:F5N
M('1E:V5M:7-E:W-I+@!%:2!E<N1M86QL:6$N`$]S:6]T82!E:2!O;&4@<'EY
M9&5T>7-SY"!P86EK87-S82X`2V%L96YT97)I;B!N:6UEY"!E:2!O;&4@86YN
M971T=2!-0T%,+6%U=&5N=&EK;VEN;FEL;&4N`$5I(&UU=71O<W1A+@!!;&ET
M87-O:F$@96D@=F]I(&QI<^1TY"!TY&QL92!O:6ME=61E;&QE+@!!<V5T=6MS
M:6$@96D@;/9Y='EN>70@)7,Z;&QE+@!!<V5T=6MS:6$@96D@;/9Y='EN>70@
M1E10(%9&4SIL;&4N`$%S971U:W-I82!E:2!L]GET>6YY="!344P@5D93.FQL
M92X`07-E='5K<VEA(&5I(&SV>71Y;GET(%-13"U&:6QE(%9&4SIL;&4N`$MR
M961I:71I="!L;W!P=2X`2V]H9&5T=&$@96D@86YN971T=2X`16D@='5O='4@
M86EN=71T86MA86X@=&EE9&]S=&]A`$EK;VYE:71A(&5I(&SV>71Y;GET+@!0
M86EK:V%A(&5I(&]L92!A<V5T971T=2X`4&%I:VMA82!E:2!O;&4@86YN971T
M=2X`16D@86YN971T=2!V:65S=&GD+@!.:6UEY"!E:2!O;&QU="!A;FYE='1U
M+@!,=6MU;>3D<N3D(&5I(&]L;'5T(&%N;F5T='4N`$5I(&QO=6MK86%V870@
M;6EE=&5L875S965T`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!(5%10+6%U
M=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!)34%0
M+6%U=&5N=&EK;VEN;FES<V$N`%-A;&%S86YA82!E:2!O;&4@86YN971T=2!+
M97)B97)O<RUA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@96D@;VQE(&%N
M;F5T='4@3&]G:6X@875T96YT:6MO:6YN:7-S82X`4V%L87-A;F%A(&5I(&]L
M92!A;FYE='1U(%!!4U-71"UA=71E;G1I:V]I;FYI<W-A+@!386QA<V%N86$@
M96D@;VQE(&%N;F5T='4@4TU"+6%U=&5N=&EK;VEN;FES<V$N`%!O;&MU82!/
M<&5N4U-,(&MO;65N=&]O;B!E:2!O;&4@;>3D<FET96QT>2X@3W!E;E-33"!P
M:73DY"!O;&QA(&OD>71E='3D=FES<^0@:F]S(&OD<VET96QLY.1N(%!+0U,@
M,3(@9&%T86$N`$5I('-I<^3D;FMI<FIA=71U;6ES<'EY;G3V:N0@:F]N;W-S
M82X`2VEI;G1I]G3D(&5I(&]L92!A<V5T971T=0!%:2!SY.1N=/9JY`!%<F]T
M:6YT82!E:2!O;&4@;>3D<FET96QT>2X`16D@<F5U;F]J80!%:2!L]GET>6YY
M="!T:65D;W-T;V$`5N1L:6UU:7-T:6QL92!E:2!O;&4@=N1L:6%I:V%I<VAA
M:V5M:7-T;V$N`$OD>71TY&KD='5N;G5S=&$@=&%I('-A;&%S86YA82!E:2!L
MY&AE=&5T='DN`$MA:6MK:2!P86QA=71U;G5T(%A-3"UD871A(&]L:2!E<.1K
M96QP;V$`16D@87)V;VIA`%9E<G-I;W1I971O:F$@96D@;/9Y='EN>70@86QK
M=7!E<N1I<VETY"!A<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@87-E
M='5K<V5T('5U9&5S=&%A;BX`5F5R<VEO=&EE=&]J82!E:2!L]GET>6YY="!A
M<V5T=6MS:7-T82X@4VEN=6X@<&ETY.0@=&5H9.0@87-E='5K<V5T('5U9&5S
M=&%A;BX`16D@;6ETY.1N`$5I(&UI=.3D;B`H2^1Y=.0@:6UP;&ES:6ET=&ES
M=.0I`$QA<'!I+U!O:&IO:7-M86%T+T5S:VEM;R`H25-/+3@X-3DM,3`I`$YO
M<F9O;&L@<V%A<F5T`%!O:&IO:6YE;B!P86QL;VYP=6]L:7-K;P!0;VAJ;VES
M970@36%R:6%A;FEE;B!S86%R970`3F]R:F$`16D@:N1L:V5E;@!%:2!E;FYE
M;@!%:2!O;&4@:&%K96UI<W1O`$5I(&]L92!T;W1E=71E='1U+@!%:2!A<V5T
M971T=0!%:2!T=65T='4N`$UU:7-T:6EN<&%N;W0`16D@;6ETY.1N('-E;&%T
M=&%V86$L('!A;&%A('1A:V%I<VEN+@!M87)R87-K=74`3'5K=6WDY'+D`$UE
M<FMK:65N(&QU:W5MY.1RY`!387)A:VME:61E;B!L=6MU;>3D<N0`4FEV:65N
M(&QU:W5MY.1RY`!*86ME;'5L:7-T86X@;G5M97)O:71A(&5I(&]L92!MY.1R
M:71E;'1Y('#D:79I=&5T=.1VY&MS:2X`3TL`3V)J96MT:0!/8FIE:W1I;B!L
M=6]J80!/:W1A86QI`&QO:V%K=74`3&]U:VMA879U=7-S=6]D871I;@!4;VEM
M:7-T;P!5=7-I('-A;&%S86YA(&5I('-A82!O;&QA('-A;6$@:W5I;B!N>6MY
M:6YE;B!S86QA<V%N87-I+@!686YH82!S86QA<V%N80!686YH82!S86QA<V%N
M82!O;B!VY.1R:6XN`$]M86X`5F%I;B!)34%0+7!A;'9E;&EM970@='5K979A
M="!J865T='5J82!K86YS:6]I=&$N`%9A:6X@;&]U:VMA879A="!M:65T96QA
M=7-E970`5F]I="!L86ET=&%A('9A:6X@>6AD96X@<^1H:_9P;W-T:6]S;VET
M=&5E;BX`5F%I;B!O;6ES=&%J82!T86D@:N1R:F5S=&5L;>1N('EL;.1P:73D
M:N0@=F]I(&UU=71T86$@:F%K;VIE;B!O;6ES=&%J:6$@=&%I(&]I:V5U:W-I
M80!!=F%A('5U9&5S<V$@:6MK=6YA<W-A`$]P96Y34TP@=FER:&4Z(%1I971O
M:F$@96D@<V%A='4@97-I;&QE(&%L;&5K:7)J;VET971U<W1A(%,O34E-12UO
M<V%S=&$N`$%V86$@=.1MY&X@;&EN:VEN('5U9&5S<V$@:6MK=6YA<W-A`$OD
M>71T]FKD<FIE<W1E;&WD`$%S971U:W-E=`!!<V5T=6MS970@)7,Z;&QE`$KD
M<FIE<W1E='1Y(&QI<W1A`$]R9V%N:7-A871I;P!/<F=A;FES86%T:6]Y:W-I
M:VOV`$]R9V%N:7-O:6YT:0!!;&MU<&5RY&EN96X@;VAJ96QM86X@;6%L;&D`
M06QK=7!E<N1I<V5T(&UA;&QI="`E<SIS<^0Z`$UU=0!-=75T('1I961O=`!/
M;6ES=&%J86X@;VEK975D970`4$%-+6%U=&5N=&EK;VEN=&EA(&5I(&]L92!K
MY'ET971TY'9I<W/D+@!014%2.CI-86EL('1A=7-T86KD<FIE<W1E;&WD`$1I
M9VET86%L:6YE;B!01U`M86QL96MI<FIO:71U<P!01U`M<V%L871T=6$@=&EE
M=&]A`$IU;&MI;F5N(%!'4"UA=F%I;@!01U`M86QL96MI<FIO:71E='1U82!J
M82!S86QA='1U82!T:65T;V$`4$A0+6MO;V1I`%!(4"UK;VUE;G1O='5L:VMI
M`%!-(&ME=GET=.0@<V%D971T80!032!S861E`%!-(&MU=7)O:F$`4$T@;'5M
M:0!032!L=6UI<V%T96ET80!032!L=6UI`%!-('5K:V]S;7ER<VMY:N0`4$]3
M25@M;&%A:F5N;G5K<V5T('!U=71T=79A=`!07TA0+6MO;65N=&]T=6QK:VD`
M5.1Y=&4`4&%K:7-T86X`4&%L874`4&%L97-T:6EN82`H;6EE:&ET971T>2!A
M;'5E*0!086YA;6$`4&%P=6$@575S:2U'=6EN96$`4&%R86=U87D`3W-I='1A
M:6X@<&EL=FES=.0`4V%L87-A;F$`4V%L87-A;F%N('9A:6AT;R!O;FYI<W1U
M:2X`5N3D<N0@<V%L87-A;F$`4V%L87-A;F%A('1A<G9I=&%A;B!2041)55,M
M875T96YT:6MO:6YT:6EN+@!386QA<V%N82!V87)M:7-T=6MS96QL80!386QA
M<V%N83H`4V%L87-A;F$Z(`!386QA<V%N;VIE;B!P:73DY"!O;&QA('-A;6%T
M+@!,:6ETY`!,:6ETY"!L96EK97#V>63D;'3D`%!O;&MU`$IO;F]S<V$@;VQE
M=F%T('-I<^3D;FMI<FIA=71U;6ES<'EY;F[V=#H`26AM:7-E=`!0<F]S96YT
M=&D`4W5O<FET82!Y;&SD<&ET;W1O:6UE;G!I=&5E=`!3=6]R:71A('EL;.1P
M:71O=&]I;65N<&ET965T('-I<^3D;FMI<FIA=71U;6ES96X@>6AT97ED97-S
MY"X`3VEK975S`$]I:V5U='1A("(E<R(@96D@<&]I<W1E='1U+@!+Y'ET=/8@
M:VEE;&QE='1Y`$]I:V5U9&5T`$]I:V5U:W-I96X@>6QLY'!I=&\`3VUA="!T
M:65D;W0`4&5R=0!,96UM:6MI=`!&:6QI<'!I:6YI=`!0=6AE;&EN`%9A;&]K
M=79A=`!0:71C86ER;@!0:6MS96QI`$ML:7-E970`3F%P<V%U=&$@:F]T86EN
M('-O;'5A`%9A<FUI<W1A(&5T=.0@:&%L=6%T('!O:7-T86$@=.1MY&X@96QE
M;65N=&EN.@!687)M:7-T82!E='3D(&AA;'5A="!P;VES=&%A(&QI;FMI='EK
M<V5N('3D:.1N(&5L96UE;G1T:6EN+@!!;FYA(&MU=6MA=7-I(&IA('9U;W-I
M+@!!;FYA(&YI;6D@=75D96QL92!L=6]K:71U:W-E;&QE.@!!;FYA(&]I:V5A
M($E0+6]S;VET92X`06YN82!O:6ME82!PY&EVY&WDY'+D.R!487)K:7-T82!P
MY&EV:65N(&QU:W5MY.1RY"!K=75K875D97-S82X`06YN82!A:6MA(&]I:V5A
M<W-A(&UU;V1O<W-A+@!!;FYA(&QY:'ET(&MU=F%U<R!O;F=E;&UA<W1A+@!!
M;FYA(&OD>71TY&KD='5N;G5K<V5S:2!J82!S86QA<V%N87-I`$QU92!S975R
M86%V82!T96MS=&DN(%-I;G5N(%!)5,3$('-U;W-T=6$@:^1Y='3V96AT;VEH
M:6X@=F]I9&%K<V5S:2!KY'ET=.3D(&KD<FIE<W1E;&WDY"X`06YN82!N:6UI
M('5U9&5L;&4@;'5O:VET=6MS96QL93H`4'5O;&$`4&]L:71I:6MK80!+>7-E
M;'ET`%!O<G1U9V%L:0!4Y&WD;B!K=79A;B!P86EK:V$`5.1MY&X@=&%U;'5K
M;VX@<&%I:VMA`%9O:2!LY&AE='3DY"!V:65S=&5JY"!K86YS:6]O;B`H96D@
M:V]S:V4@24U!4"!Y:'1E>6MS:>0I`%-A9&5MY.1RY"!E9&5L;&ES:6QL92`E
M<R!T=6YN:6QL93H@`$AA:6AT=79U=7,@/&)R("\^=&]D96YNY&OV:7-Y>7,`
M4')E9G-?;&1A<#H@5&%R=FET=&%V86$@3$1!4"UL86%J96YN=7-T82!E:2!L
M]GET>6YY="X`4')E9G-?<V5S<VEO;CH@5&%R=FET=&%V86$@<V5S<VEO;BUL
M86%J96YN=7-T82!E:2!L]GET>6YY=`!);&UA;G!A:6YE`$EL;6%N<&%I;F4@
M;65R96YP:6YN87-S83H@`$EL;6%N<&%I;F4Z(`!%<VEK871S96QU`$5S:6MA
M='-E;&4@:W5V82!U=61E<W-A(&EK:W5N87-S80!%9&5L;&ES970@87-E='5K
M<V5T`%1U;&]S=&$@9&]K=6UE;G1T:0!386QA:6YE;B!A=F%I;@!/;F=E;&UA
M`$]N9V5L;6%N(&MU=F%U<P!0<F]J96MT:70`2V5H;W1T965N('1E:W-T:0!*
M=6QK:6YE;B!A=F%I;@!*=6QK:7-E;B!A=F%I;65N(&%L9V]R:71M:0!*=6QK
M:7-E;B!A=F%I;65N('1I961O=`!*=6QK:7-E;B]S86QA:7-E;B!A=F%I;G!A
M<FEN(&QU;VYT:2!E<.1O;FYI<W1U:2X`4'5E<G1O(%)I8V\`5F]I('1U:&]T
M82!P;VES=&5T='5J82!V:65S=&5JY`!1871A<@!+>7-E;&4`2VEI;G1I]@!2
M4T$@2G5L:VEN96X@879A:6X@*"5D(&)I='1IY"D`4F%D:6]P86EN:6ME`%-A
M9&4`4V%D971T82!A:6MA:7-I;@!3861E='1A(&UY]FCDY&X`4V%D96MU=7)O
M`%9E<VD@:F$@;'5M:0!6961E<W3D(&QU;65E;@!3871U;FYA:6YE;B!M:65T
M96QA=7-E`%-U:&1E`$QU:W4`5F]I(&QU:V5A('9I97-T96KD`%!O:7-T971A
M86YK;R`E<S\@5.1TY"!T;VEM:6YT;V$@96D@=F]I('!E<G5U='1A82X`4&]I
M<W1E=&%A;FMO('1I961O="!KY'ET=.1JY'-TY"`E<S\@5.1TY"!T;VEM:6YT
M;V$@96D@=F]I('!E<G5U='1A82X`5&5E(&UU=71O:W-E="!U=61E<W1A86X`
M4.1I=FETY`!0Y&EVY'0@9'EN86%M:7-E="!V86QI:VMO96QE;65N=&ET.@!0
MY&EV:73D('!O<G1A86QI;N1K>6WDY#H`4^3D;F[V;&QI;F5N(&QA=7-E:V4`
M4F5L86%T:6]S96QA:6X`3&%T86$@=75D96QL965N`$UU:7-T:6EN<&%N;W0`
M173D<&%L=F5L:6UE=`!%=.1P86QV96QU;B!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!0;VES=&$`4&]I<W1A(&]S:6\`4&]I<W1A('-A
M<F%K90!0;VES=&$@;75O=&]I;'4`4&]I<W1A('!A<FD`4&]I<W1A('1A;&QE
M=&5T='4@<VMR:7!T:2!P86QV96QI;65N(';D;&EA:6MA:7-H86ME;6ES=&]S
M=&$N`%!O:7-T80!0;VES=&$@=.1MY"!N;V]D:2!D;VMU;65N=&ES=&$`4&]I
M<W1A(&OD>71TY&KD`%!O:7-T82!KY'ET=.1JY#H@)7,`4'EY;G3V]FX@96D@
M=F]I='4@=F%S=&%T82X@5FER:&5K;V]D:3H@`%!Y>61E='1YY"!P86QV96QU
M82!E:2!L]GET>6YY="X`5&%R=FET=&%V86$@(B5S(BUT:65T;V$@96D@;VQL
M=70@;>3D<FET96QT>2`E<R!A<V5T=6MS:7-S82X`5&%R=FET=&%V86$@(B5S
M(BUT:65T;V$@96D@;VQL=70@;>3D<FET96QT>2!61E,@87-E='5K<VES<V$N
M`%1A<G9I='1A=F%A("(E<R(M=&EE=&]A(&5I(&]L;'5T(&WDY')I=&5L='D@
M87-E='5K<VES<V$N`%!A:V]L;&EN96X@:V5N='3D`%1Y:&IE;F[D`%1Y:&IE
M;F[D('-A;&%S86YA`%1Y:&IE;F[D('-A;&%S86YA<VD`4&%L875T82!E9&5L
M;&EN96X@:WES96QY`%1U;&]K<V5T`%!A;&%A(&%S971U:W-I:6X`5F%H=FES
M=&$@=75S:2!S86QA<V%N80!2975N:6]N`%!A;&%U=&$@87-E='5K<V5T`%)I
M8V@@5&5X="!%9&ET;W)I;B!A<V5T=6MS970`07)V;VET=6MS970`3VEK96$`
M3VEK96$@;W1S86ME`$]I:V5A(&%R=F]T`%)I=FE?;B!T:65D;W0N+BX`4F]O
M;&D`4F]M86YI80!+Y.1N;N0@,3@P`$ODY&YNY"!V87-T87#D:7;DY&X`2^3D
M;F[D(&UY]G3D<.1I=N3D;@!2:79I;B!T:65D;W0`4FEV:6X@=&EE9&]T`%)I
M=FET.@!6:6EV;VET:6X`5FEI=F]I=&EN(&[D:WEY(&MA:6MK:65N(')I=FEE
M;B!J82!S87)A:VME:61E;B!VY&QI;&SD`%9I:79O:71I;B!NY&MY>2!V86EN
M('-A<F%K:V5I9&5N(';D;&EL;.0`5FEI=F]I=&EN(&[D:WEY('9A:6X@<FEV
M:65N(';D;&EL;.0`4W5O<FET80!696[D:N1N($9E9&5R871I:79I;F5N('1A
M<V%V86QT80!2=6%N9&$`4R]-24U%(&MR>7!T;V=R86%F:6YE;B!A;&QE:VER
M:F]I='5S`%,O34E-12!S86QA='1U('9I97-T:0!305-,+6%U=&5N=&EK;VEN
M=&D@96D@;VQE(&OD>71E='3D=FES<^0N`%--4R!496MS=&EV:65S=&ET`%-1
M3"UK;VUE;G1O='5L:VMI`%-13"UL875S92!A<G9O:F5N(&AA:V5M:7-E96X`
M4U-(`$].3DE35%5)`%-?44PM:V]M96YT;W1U;&MK:0!L80!386EN="!(96QE
M;F$`4V%I;G0@2VET=',@:F$@3F5V:7,`4V%I;G0@3'5C:6$`4V%I;G0@4&EE
M<G)E(&IA($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@:F$@1W)E;F%D:6EN:70`
M4V%M86%N(&ME:'EK<V5E;B`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O
M(%1O;64@:F$@4')I;F-I<&4`4V%T96QL:6ET=&D@<&%L=F5L=6YT87)J;V%J
M80!3875D:6$@07)A8FEA`%1A;&QE=&$`5&%L;&5T82`B)7,B`%1A;&QE=&$@
M)7,`5&%L;&5T82!A<V5T=6MS970`5&%L;&5T82!L=6]D=70@87-E='5K<V5T
M(%!(4"US:W)I<'1I;N0@<&%L=F5L:6UE<VD@=N1L:6%I:V%I<VAA:V5M:7-T
M;V]N+B``5&%L;&5T971T:6EN("5S.FX@87-E='5K<V5T+@!!<V5T=7-T96X@
M<.1I=FET>7-S:W)I<'1I(&]N('1A;&QE=&5T='4@<&%I:VMA86XZ("(E<R(N
M`$AA:F%N86ES:6$@=6MK;W-M>7)S:WEJY`!4:65D90!(86MU`$AA:W5K;VYE
M970`5F%L:71S92!T:65D;W-T;W0`5F%L:71S92!PY&EVY&WDY'+D`%9A;&ET
M<V4@;&ESY'1TY';D(')Y:&WD`%9A;&ET<V4@=75S:2!O;6ES=&%J80!686QI
M='-E('!A;'9E;&EN`%9A;&ET<V4@;&ESY'1TY';D(&OD>71TY&KD`%9A;&ET
M<V4@:V%I:VMI`%9A;&ET<V4@:V%I:VMI('#D:7;D;>3D<N1K;VUP;VYE;G1I
M=`!686QI='-E(&]B:F5K=&D`5'EH:F5N;N0@=F%L:6YT80!686QI='-E('1A
M<G9I='1A=F%T(&UE<FMI="!A;&QA(&]L979I<W1A('9A;&EK;VES=&$N(%9O
M:70@<V5N(&KD;&ME96X@:V]P:6]I9&$@:F$@;&EI='3DY"!M97)K:70@=&5K
M<W1I:7-I+@!686QI='-E('#D:7;D>6MS96X@97)O=&EN;65R:VMI.@!686QI
M='-E('#D:7;D>6MS96X@97-I='ES=&%P83H`5F%L:71S92!M=75T971T879A
M('!R;V9I:6QI.@!686QI='-E(&ME;&QO;F%J86X@97)O=&EN;65R:VMI.@!6
M86QI='-E(&%J86X@97-I='ES=&%P83H`5F%L:71S92!K86MS:2!Y:'1E96YS
M;W!I=F%A(&ME;G1TY.0N`%9A;&ET<V4@=N1R:71E96UA+@!686QI='-E(&OD
M>71E='3D=N0@:VEE;&DZ`$SD:&5TY"!O;F=E;&UA=FEE<W1I`$SD:&5TY"!3
M35,`4V5N96=A;`!4=6YN:7-T:6XZ(`!S>7ES:W5U`%-E<F)I82!J82!-;VYT
M96YE9W)O`%-A<FIA;G5M97)O`%!A;'9E;&EM96X@=&EE9&]T(&]V870@=N3D
M<FGD('1A:2!E:7;D="!O;&4@:^1Y=&5T=.1V:7-SY"X`27-T=6YT;VIE;B!H
M86QL:6YT80!397-S:6]N($E$(&]N('9A;FAE;G1U;G5T+@!)<W1U;FYO=`!!
M<V5T80!386QA<V%N86X@<F5S971O:6YT:6EN(&QI:71T>79IY"!A<V5T=6MS
M:6$L(&IO<R!J;W-K=7,@=6YO:&1A="!S86QA<V%N87-I+@!6;VET(&%S971T
M86$@=6QK;VES=&5N('!A;'9E;&EM:65N(&%S971U:W-E="P@:F]I=&$@:&%L
M=6%T(&OD>71TY.0@<&]R=&%A;&ES<V$N`%9O:70@87-E='1A82!KY'ET971T
MY';D;B!K:65L96XL(&%I:V%V>?9H>6MK965N(&IA(&UU:71A('#D:7;D;>3D
M<N1A<V5T=6MS:6$N`%9O:70@87-E='1A82!A;&]I='5S;VAJ96QM86XL(';D
M<FET965M86XL(&[D:WEMY&X@<.1I=FET>6MS96X@:F$@;75I=&$@;N1K>6WD
MY&X@;&EI='1Y=FGD(&%S971U:W-I82X`07-E;FYU<P!!<V5N;G5K<V5N('#D
M:79I='ES<VMR:7!T:2!O;B!S86%T879I;&QA`%5S96%T('!A:6MA="!S;W!I
M=F%T(&%N;F5T='5U;B!P87)A;65T<FEI;CH@`%-E>6-H96QL:70`3W-T;VMS
M970`3'EH>70@:W5V875S.@!!<V5T971A('!I:V%V86QI;G1A;N1P<.1I;65T
M('5S96EM;6EL;&4@;&EN:V5I;&QE+@!.Y'ETY`!.Y'ETY"!E<F]A=F%I<W5U
M9&5T(&%S971U:W-I96X@=&%L;&5T971U<W-A(&IA('5U9&5S<V$@:G5U<FD@
M;75O:V%T=7-S82!V97)S:6]S<V$N`$[D>73D(&5D96QL:7-E;B!S:7/DY&YK
M:7)J875T=6UI<V5N('#D:7;D>7,N`$[D>73D(&%S971U<R!P:73DY&MS97-I
M(&%L:W5P97+D:7-E;@!.Y'ETY"!V86QI='-I;@!.Y'ETY"!T875L=6MK;W1O
M:6UI;FYO="!V86QI:VMO+@!.Y'ETY"!V87-E;6UA;&QA("5S('9A;&EK:V\N
M`$[D>73D('1A=6QU:V]N('-O;'5N('1I961O="!D:6%L;V=I`$[D>73D('1A
M=6QU:V]N('1I961O="!D:6%L;V=I`$[D>73D('1A=6QU:V]N(')I=FEN('1I
M961O="!D:6%L;V=I`$[D>73D(&MU=F%N('1I961O="!D:6%L;V=I`$[D>73D
M('1U;VYT:0!3871E:71A`%-A=&5I=&$@86EK86ES:6X`4V%T96ET82!M>?9H
M96UM:6X`4V%T96ET82!LY&AE='1Y=FEL;&$`4&EE;F5N;N0`4&EE;F5N;N0@
M=&%I('-I:7)RY"!V:65R96ES:>0@;W-I;VET82P@:F]T=&$@;F4@96EVY'0@
M;VQE('1I96QLY`!3:65R<F$@3&5O;F4`2VER:F%U9'4`06QL96MI<FIO:71U
M<P!!;&QE:VER:F]I='5K<V5N(&%L9V]R:71M:0!3:6YG87!O<F4`2V]K;P!/
M:&ET82!Y;&SD<&ET;W1E:'3D=N1T`%-L;W9A:VEA`%-L;W9E;FEA`$QU;6D`
M3'5M:7-A9&5T=&$`3'5M:7-A=&5I=&$`3'5M:7-A=&5I=&$@86EK86ES:6X`
M3'5M:7-A=&5I=&$@;7GV:.3D;@!,=6UE;B!S>79Y>7,Z(`!,=6UE;B!MY.1R
MY"!V971E;N0Z(`!386QO;6]N('-A87)E=`!3;VUA;&EA`$QA=6QU="!J82!2
M=6YO=7,`2N1R:F5S='EK<V5N('-U=6YN86X@=F%L:6YT80!,Y&AD96]S;VET
M90!%=&5LY"U!9G)I:VMA`$5T96SD+45U<F]O<'!A("A)4T\M.#@U.2TS*0!%
M=&5LY"U'96]R9VEA(&IA(&5T96SD:7-E="!386YD=VEC:"!S86%R970`171E
M;.1I;F5N('!A;&QO;G!U;VQI<VMO`%;D;&D@=FEE<F5I<V5T('-O;'5J96X@
M=N1L:7-SY`!6Y&QI('-O;'5N(&QE:7#D=&5K<W1I;B!J82!R975N86X@=N1L
M:7-SY"``5N1L:0!6Y&QI`%;D;&D@:F$@=.1Y=&4`17-P86YJ80!2;W-K87!O
M<W1I`$5R:6MO:7-M97)K:VEE;B!S>?9T=/8`2F%A('-O;'4`2F%A('-A<F%K
M90!*86$@<FEV:0!5<FAE:6QU`%-R:2!,86YK80!3=&%N9&%R9&D`4W1A<B!4
M<F5K`$%L:V%M:7-V=6]S:0!,Y.1N:2!T86D@86QU90!4:6QA`%1A;&QE;FYU
M<VUU;W1O`$MA='5O<V]I=&4`3.1P:6QY]FYT:0!-97)K:VEJ;VYO;&ES=&$`
M4&]I<W1A('1O:6UI86QU92!O<V]I='1E97-T80!4>7EL:2!;0U-370!S=0!!
M;&EH86ME;6ES=&]A("(E<R(@96D@;/9Y='EN>70N`$]T<VEK:V\`3.1H973D
M`$SD:&5T971T:6EN("(E<R(Z;B!L:7/D>7-P>7EN=/8N($5T('9O:2!K:7)J
M875T=6$@<VESY.1N(&5N;F5N(&MU:6X@<'EY;G3V<VD@;VX@:^1S:71E;'1Y
M(&IA(&AY=N1K<WET='DN`$%L:6MI<FIO:71U<P!/;FYI<W1U:0`B)7,B.B!L
M:7/DY&UI;F5N(&KD<FIE<W1E;&WDY&X@;VYN:7-T=6DN`$OD>71TY&KD;B`B
M)7,B(&OD>71TY&KD=&EE=&]J96X@<&]I<W1A;6EN96X@:N1R:F5S=&5L;>1S
M=.0@;VYN:7-T=6DN`"(E<R(@<&]I<W1E='1I:6X@;VYN:7-T=6YE97-T:2X`
M(B5S(CH@;VYN:7-T=71T:6EN('!O:7-T86UA86X@:N1R:F5S=&5L;>1S=.0N
M`%!A;&%T=&EI;B!O;FYI<W1U;F5E<W1I('9A;FAO:6AI;B!A<V5T=6MS:6EN
M+B!,871A82!S:79U('5U9&5S=&%A;B!NY&ADY&MS97-I(&UU=71O:W-E="X`
M5&%L;&5N;F5T=&EI;B!A<V5T=6MS:65N('9A<FUU=7-K;W!I;RX`5&%L;&5N
M;F5T=&EI;B!A<V5T=6MS:65N('9A<FUU=7-K;W!I;R`E<RX`)R5S)SH@<.1I
M=FET>7,@;VYN:7-T=6DN`"5S.FX@:VER:F]I='1A;6EN96X@;VYN:7-T=6DN
M`%-U9&%N`%EH=&5E;G9E=&\`075R:6YG;VYN;W5S=0!!=7)I;F=O;FQA<VMU
M`$%U<FEN:V]I;F5N`$%U<FEN9V]N;F]U<W4`075R:6YK;R!N;W5S964O;&%S
M:V5E`$%U<FEN9V]N;F]U<W4Z(`!!=7)I;F=O;FQA<VMU`$%U<FEN9V]N;&%S
M:W4Z(`!0Y.1L;&5K:7)J;VET=7,`5'5K:0!3=7)I;F%M`%-U:W5N:6UI`$AU
M:7!P=79U;W)E="!J82!*86X@36%Y96X`4W=A>FEM86$`4G5O='-I`%-V96ET
M<VD`4WEN8R!L;VMI('!O:7-T971T=0!3>6YC34P`4WEN=&%K<VEV:7)H92!H
M86MU=&5R;65I<W/D`%-Y>7)I82P@87)A8FET87-A=F%L=&$`56MK;W-M>7)S
M:WD`56MK;W-M>7)S:WEJY"!J82!T=75L:7-T80!5:VMO<VUY<G-K>70`56MK
M;W-M>7)S:WEJY"!A:6MA:7-I;@!44U8M=&EE9&]S=&\`5&%U;'5K:V\`5&%U
M;'5K;VX@=&EE9&]T`%1A=6QU:V]N(&%S971U:W-E=`!4875L=6MO;B!T:65D
M;W0`5&%I=V%N`%1A:7=A;BP@2VEI;F%N(&UA86MU;G1A`%1A9'II:VES=&%N
M`%1A;GIA;FEA+"!9:&1I<W1Y;GET('1A<V%V86QT80!+;VAD93H`5&5H=.1V
MY'0`4'5H96QI;FYU;65R;P!,Y&UP]G1I;&$@961E;&QI<V5L;&4@='5N;FEL
M;&4Z(`!,Y&UP]G1I;&$`3.1M</9T:6QA.B``3.1M</9T:6QA/&)R("\^*"5S
M2&DE<R\E<TQO)7,I("9D96<[)7,`36%L;&EA("(E<R(@96D@;/9Y='EN>70N
M`$UA;&QI96X@:&%L;&EN=&$`5&5K<W1I`%9A:6X@=&5K<W1I`%1E:W-T:6X@
M=&%S875S`%1E:W-T:71O<`!T;P!4:&%I("A425,M-C(P*0!4:&%I;6%A`$94
M4"UL:7/D=&]I;6EN=&\@96D@;VQE(&OD>71E='3D=FES<^0N`$AI<W1O<GD@
M:N1R:F5S=&5L;>0@96D@;VQE(&OD>71E='3D=FES<^0N`$AO<F1E+TMO;&%B
M(&EN=&5G<F]I;G1I;6]O='1O<FD@96D@='5E("(E<R(`24U34"!L;VMI82!E
M:2!V;VET=2!A;'5S=&%A+@!-86EN=&5N86YC93HZ("UL=6]K86X@;&%T86%M
M:6YE;B!E<.1O;FYI<W1U:0!!<V5T=6MS970@:6MK=6YA(&]N('-U;&IE='1U
M+B!0;VES='5T86%N+@!9;&SD<&ED;VX@<&ETY.0@;W1T86$@:^1Y='3V]FX@
M<'ES>7;D('1A;&QE='5S='EY<'!I(%!E<FUI<W-I;VXL(&IO<R!H86QU870@
M:^1Y='3DY"!N:6ETY"X`5F%I;B!A;&%P=6]L:0!#;VYT86-T(&ED(&YU;65R
M;V$@96D@;VQE(&WDY')I=&5L='DL(&]N('1Y:&KD('1A:2!E:2!L]GET>6YY
M="!T:65T;VMA;FYA<W1A+@!9:'1E>7-T:65D;W0@;&ESY'1T:6EN(&]N;FES
M='5N965S=&D@;W-O:71E:VER:F%A<VDN`%9I97-T:6X@86QL96MI<FIO:71U
M:W-E;B!T87)K:7-T86UI<V5E;B!T87)V:71A86X@97)I;&QI;F5N(%!'4"UA
M;&QE:VER:F]I='5S;&]H:V\N`$IA:V5L=6QI<W1A;B!)1"!E:2!O;&QU="!M
MY.1R:71E;'1Y+"!O;B!T>6AJY"!T86D@96D@;/9Y='EN>70@=&EE=&]K86YN
M87-T82X`2F%K96QU;&ES=&%A(&5I(&]L;'5T(&WDY')I=&5L='DN`%-A;&%U
M<W1O:6UI;FYO;B!KY'ET=/8@=F%A=&D@<V%L871T=6$@5U=7+7EH=&5Y='3D
M+@!4:65D;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@)7,@87-E='5S+@!4:65D
M;W-T;W-S82`E<R!P:73D:7-I(&]L;&$@:F]I=&%K:6X@)7,@87-E='5K<VEA
M+@!4:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$@:71S96YSY"!PY.1L;&4N
M`%1I961O<W1O(&]L:2!T>6AJY"X`4V5U<F%A=F%S<V$@;VX@;W1S:6MK;W1I
M961O="!TY'-TY"!M97-S86=E+W)F8S@R,B`M=FEE<W1I<W3D+@!+;VMO<G5U
M9'5N(&[D>71T]G1I;&$@86EH975T=&%A(&]N9V5L;6EA(&IO:6QL86MI;B!)
M;G1E<FYE="!%>'!L;W)E<B!S96QA:6UE;B!KY'ET=.1J:6QLY"X@5F%L:71E
M='1A=F%S=&D@:WES96EN96X@<V5L86EN('-I<^1L=.3D('!I:7)T96ETY"!J
M82!V:7)H96ETY"!J;VEH:6X@96D@;VQE(&SV>71Y;GET(&MO<FIA=7-T82!T
M86D@:V5I;F]A(&MI97)TY.0@;VYG96QM82X@2'5O;6%A=&AA;B!E='3D(&IO
M<R!KY'ETY'0@=.1TY"!NY'ET=/9T:6QA82!J82!);G1E<FYE="!%>'!L;W)E
M<B!S96QA:6YT82P@;FEI;B!NY'ET=/8@<V%A='1A82!M96YNY"!S96MA:7-I
M;BP@:F]T:W5T('1O:6UI;FYO="!E:7;D="!T;VEM:2!T86D@<V5L86EN('-A
M871T86$@:V%A='5A+B!*;W,@:^1Y=.1T(%=I;F1O=W,@.7@@=&%I($U%('9E
M<G-I;W1A+"!N:6EN(&]N(&UA:&1O;&QI<W1A(&5T=.0@:^1Y='3V:N1R:F5S
M=&5L;>0@:V%A='5U(&YS+B`G1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R`M
M=FER:&5E<V5E;B!J82!S:6YU;B!P:73DY"!KY'EN;FES=.3D(&MO;F4@=75D
M97-T86%N+EQN7&X@375I<W1A(&5T=.0@<VEN=6$@;VX@=F%R;VET971T=2X@
M3F%P<V%U=&$@3TLM;F%P<'5L86$@:F]S(&AA;'5A="!K;VME:6QL92!E9&ET
M;W)I;B!K;VMO<G5U='4@;N1Y='3V=&EL86$N`%!O:7-T971T:6EN('!R;V9I
M:6QI("(E<R(N`%9A:6X@=F%S96X@<'5O;&D`1VYU4$<@;VAJ96QM86X@<VEJ
M86EN=&D@<&ETY.0@;>3D<FET96QLY"!#<GEP=%]P9W`Z.B`M;'5O:V%S<V$N
M`%9I97-T:2!LY&AE=&5T='D@)7,@=F%S=&%A;F]T=&%J86QL92`E<R!O='-I
M:VMO;F$@(B5S(B!O;B!NY'ET971T>2X*16D@;VQE(&UI=.3D;B!T86ME:71A
M('-I:73D(&5T=.0@=FEE<W1I(&]N(&QU971T=2!T86D@>6UMY')R971T>2X`
M3FEM:2!J;W1A(&OD>71E=.3D;B!L:6YK:71E='3D97-S82!L=6\@<VEV=6QL
M90!+96YT=&EE;B!MY.1RY"!P:73DY"!A;G1A82!N=6UE<F]I;F$N`$UO9'5U
M;&D@;W!E;G-S;"!T87)V:71A86X@2&]R9&5?0W)Y<'1?<VUI;64Z.B`M;'5O
M:V%N(&OD>71TY&UI<V5K<VDN`$%S971U<W1A("(E<R(@:V]S:V$@<V5N('1I
M961O="!Y;&ET=&EVY'0@=&%L;&5T=7-T879A;B!S=75R:6UM86X@<V%L;&ET
M=6X@<F%J86X`3VAJ96QM86$L(&IO;&QA('9O:2!K871S;V$@=FEE<W1I='EY
M<'!IY"`H)7,I+"!E:2!L]GET>6YY="!JY')J97-T96QMY'-TY"X`3&%I;F%U
M<VUE<FMK:2!P:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`5F%I;B!O
M:6ME82!J82!V87-E;B!P=6]L:0!686EN(&]I:V5A('!U;VQI`$5R;W1I;B!P
M:73DY"!O;&QA('EK<VET=.1I;F5N(&UE<FMK:2X`4&%L=F5L:6X@(B5S(B!O
M;B!P;VES=&5T='4N`%!A;'9E;&EN("(E<R(@;VX@=&%L;&5T971T=2X`4VES
MY.1N:VER:F%U='5M:7-P>7EN=/8@)7,@;VX@<&]I<W1E='1U+@!-Y.1R:71E
M;'1YY"!R:79IY"`H)60I(&5I(&]L92!O;&5M87-S82X`5F%L:>1A:6MA:7-T
M:65D;W-T;V$@(B5S(B!E:2!O;&4@;VQE;6%S<V$N`$MI<FIO:71T86UA<VD@
M=&5K<W1I(&5I('9A<W1A82!T96MS=&GD(')U=61U;&QA+@!686EN('ELY'!U
M;VQI(&IA(&%L87!U;VQI`%9A:6X@>6SD<'5O;&D`5'5O='4@=&EE=&\@:.1V
M:7-I(&5D96QL:7-E;B!K;VAD86X@86EK86YA+@!4=6]T=6$@=&EE9&]S=&]A
M(&5I('9O:71U('1A;&QE='1A82X`3W-I;W1A('=E871H97(N8V]M(&5I(&]L
M92!KY'ET971TY'9I<W/D+@!4965M86AA:V5M:7-T;V$@(B5S(B!E:2!L]GET
M>6YY="X`07-E='5K<VEA(&5I(&]L92!S86%T879I;&QA+@!%:2!O;&4@;W-I
M;VET82P@:F]T:V$@=F]I9&%A;B!NY'ET=.3D('9I97-T:65N('EH=&5Y9&5S
M<^0N`%3D<W/D(&ME;G3D<W/D(&]N(&QI:6%N(&UO;G1A(&UE<FMK:>0N($%N
M;F]I="`E<R!M97)K:VGD.R!S:6YU;B!P:73DY"!A;G1A82!VY&AE;6WD;B!K
M=6EN("5S(&UE<FMK:>0N`$IO:71A:VEN(&]N9V5L;6EA("(E<R(@;&ESY.1M
M:7-E<W/D(&KD<FIE<W1E;&WDY&XZ("5S`$OD>71TY&KD;B`B)7,B(&OD>71T
MY&KD=&EE=&]J96X@<&]I<W1A;6ES97-S82!JY')J97-T96QMY'-SY"!O;&D@
M;VYG96QM:6$Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('!O:7-T86UI<V5S
M<V$@:N1R:F5S=&5L;>1S=.0Z(`!*;VET86MI;B!O;F=E;&UI82`B)7,B('#D
M:79I='EK<V5S<^0Z("5S`%1I961O<W1O;B!T=6]N;FES<V$@;VQI(&]N9V5L
M;6EA+B!9:'3DY&X@)7,Z82!E:2!T=6]T=0!4:65D;W-T;VX@='5O;FYI<W-A
M(&]L:2!O;F=E;&UI82X@)7,@:V]K;R!O;&D@<W5U<F5M<&D@:W5I;B!S=75R
M:6X@<V%L;&ET='4@:V]K;R`H)60@=&%V=6$I+@!4:65D;W-T;VX@='5O;FYI
M<W-A(&]L:2!O;F=E;&UI82X@)7,@;&%T875T=6D@=F%I;B!O<V%K<VDN`%1A
M<&%H='5I('9I<FAE(&[D>71E='3D97-SY"!V:65S=&EN('3D=.0@;W-I;W1A
M`%EH=&5Y<W1I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`:4-A
M;&5N9&%R+71I971O:F5N('1U;VYN:7-S82!T87!A:'1U:2!V:7)H92X`07-E
M='5S=&EE=&]L;VUA:VME97-S82!O;B!J;VMI;B!V:7)H92X@16AKY"!JY'1I
M="!J;VYK=6X@<&%K;VQL:7-E;B!K;VAD86X@=.1Y='3D;>1T=.0N`%1A<&%H
M='5I('9I<FAE('ER:71E='3D97-SY"!S=6]R:71T86$@;W-O:71E:VER:F%T
M;VEM:6YT;V$N(%ER:73D(&UY]FAE;6UI;B!U=61E<W1A86XN`%EH=&5Y<W1I
M971O:F5N('#D:79I='EK<V5S<^0@=&%P86AT=6D@=FER:&4N(%ER:73D(&UY
M]FAE;6UI;B!U=61E<W1A86XN`$IA:V5L=6QI<W1A;B!PY&EV:71Y:W-E<W/D
M('1A<&%H='5I('9I<FAE+B!9<FETY"!M>?9H96UM:6X@=75D97-T86%N+@!4
MY&WD($E-05`@<&%L=F5L:6X@96D@='5E(&MA;G-I;VED96X@:F%K86UI<W1A
M+@!4Y&WD('1I961O<W1O(&5I('9A:6MU=&$@<F%R+71I961O<W1O;'1A+@!4
MY&WD('1I961O<W1O(&5I('9A:6MU=&$@>FEP+71I961O<W1O;'1A+@!4Y&WD
M(&5I('9A:6MU=&$@;VEK96%L=&$@:V]R='1I;G5M97)O;'1A+@!4Y&QLY"!A
M:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@0VQI8VMA=&5L;&EN("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87D@<&%L=F5L=6$@2%144"!!
M4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@
M5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T97=A>2!P86QV96QU;B!K875T
M=&$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R:6QL82!V;VD@;.1H971TY.0@
M=FEE<W1E:N0@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@9V%T
M97=A>2!P86QV96QU;B!K875T=&$@2%144"!!4$DZ;&QA+@!4Y&QLY"!A:G5R
M:6QL82!V;VD@;.1H971TY.0@=FEE<W1E:N0@5F]D869O;F5N(&YU;65R;VEH
M:6X@4TU44#IL;.0@:^1Y='3D96X@5F]D869O;F4@271A;'D@9V%T97=A>2!P
M86QV96QU82X@5.1TY"!P86QV96QU82!V;VD@:^1Y='3DY"!V86EN(%9O9&%F
M;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="D@='5N;G5K<VEL;&$N`%3D
M;>0@:V5N='3D(&]N('!A:V]L;&EN96XN`%3D<W/D(&ME;G3D<W/D('!I=.3D
M(&]L;&$@=F%I;B!K;VMO;F%I<VQU:W5J82X`5.1S<^0@:V5N=.1S<^0@<&ET
MY.0@;VQL82!N=6UE<F]I=&$@:F$@<&EL:VMU+6UE<FMK96KD+@!4Y'-SY"!K
M96YTY'-SY"!P:73DY"!O;&QA(&]K=&%A;&EL=6MU:F$N`%3D<W/D(&ME;G3D
M<W/D('!I=.3D(&]L;&$@;&ES=&$@:V]K;VYA:7-L=6MU:F$L(&IO=&MA('!I
M=.3D(&]L;&$@97)O=&5T='4@<&EL:W5L;&$@=&%I(';D;&EL>?9N;FEL;.0`
M07)V;VX@<&ETY.0@;VQL82!N=6UE<F\N`%3D<W/D(&ME;G3D<W/D(&]N(';D
M<FEMY.1R:71Y<RP@:F]N:V$@<&ETY.0@;VQL82!21T(@2&5X(&UU;V1O<W,L
M(&5S:6UE<FMI:W-I("<C,3(S-&%F)RX`5.1MY"!L;VUA:V4@;VX@:F\@:^1S
M:71E;'1Y+@!4Y&WD(&]N("5S+@!4Y&WD(&]N($MO;&%B($=R;W5P=V%R92!O
M8FIE:W1I+B!+871S;V%K<V5S:2!TY&WD;B!O8FIE:W1I;B!S:6YU;&QA('!I
M=.3D(&]L;&$@<^1H:_9P;W-T:6]H:F5L;6$L(&IO:V$@>6UMY')TY.0@2V]L
M86(@1W)O=7!W87)E(&9O<FUA871T:6$N($QI<W1A('EH=&5E;G-O<&EV:7-T
M82!SY&AK]G!O<W1I;VAJ96QM:7-T82!L]GET>7D@;W-O:71T965S=&$@)7,`
M5.1MY"!V:65S=&D@;VX@:VER:F]I=&5T='4@97)I(&UE<FMI<W3V;&SD("@E
M<RD@:W5I;B!M:6OD('-I;G5L;&$@;VX@:^1Y=/9S<^0N(`!.=6UE<F]N('!I
M=.3D(&]L;&$@=N1H:6YTY.1N('EK<VDN`%3D;&SD('!A;'9E;&EM96QL82!E
M:2!V;VD@875K86ES=&$@>FEP+2!T86D@9WII<"UT:65D;W-T;VIA+@!4Y&WD
M(&KD<FIE<W1E;&WD(&]N('!O:7,@<.3D;'3D+@!!<G9O;B!P:73DY"!O;&QA
M(&YU;65R;RX`5.1MY&X@:6MK=6YA;B!V;VD@875K86ES=&$@=F%I;B!!<V5T
M=6MS970@:6MK=6YA<W1A`$UY<G-K>0!4:6ME=&ET`$%I:V$`06IA;G-E=7)A
M;G1A`$%J86X@97-I='ES;75O=&\`06IA;B!V86QI;G1A`%1I;6]R+4QE<W1E
M`%1I='1E;&D`3W1S:6MK;R`H=&]O;'1I<"DZ`%9A<W1A86YO='1A:F$`5F]I
M9&%K<V5S:2!V86QI=&$@=7-E86UP:6$@=F%I:'1O96AT;VIA+"!P:63D($-O
M;G1R;VPM("A00RD@=&%I($-O;6UA;F0M("A-86,I(&[D<'#D:6YTY"!P;VAJ
M87-S82!K=6X@;F%P<V%U=&%T(&AI:7)E;B!P86EN:6ME='1A+@!4Y&[DY&X`
M3N1Y=.0@2%1-3"ULY&AD96MO;V1I`%1O9V\`5&]K96QA=0!(=6]M96YN80!4
M;VYG80!,:6EA;B!M;VYT82!E<.1O;FYI<W1U;G5T=&$@:VER:F%U='5M:7-Y
M<FET>7-TY"!V:6EM96ES:6UP:65N(&UI;G5U='1I96X@:W5L=65S<V$N`%EL
M]G,`66QI;7#DY&X@:V5H>6MS965N("A?=&]P*0!+Y.1N;O9K<V5T`%1R:6YI
M9&%D(&IA(%1O8F%G;P!4;W-I('9A:2!E<.1T;W-I`'1I`%1U;FES:6$`5'5R
M:VMI`%1U<FMK:2`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&IA
M($-A:6-O<R!S86%R970`5'5V86QU`$MI<FIO:71A('9A;&EN=&%S:3H@`%4N
M5BX@+6EN9&5K<VDZ(`!54DP`55),(&IO:&]N('!A;&%U=&5T86%N('-K<FEP
M=&EN('-T871U<R!R87!O<G1T:0!54DPZ`%5G86YD80!5:W)A:6YA`%9&4RUH
M86ME;6ES=&]A(&5I('9O:71U(&QU:V5A+@!+Y'ET=.1JY&X@;&ESY'1I971O
M:F5N(&QI<^1Y<R!E:2!O;FYI<W1U;G5T(&MI<FIA=71U;6ES97-S82X`16D@
M=F]I('9A:6AT86$@;VEK975K<VEA(%9&4RUT:65D;W-T;VQL92`B)7,B+@!%
M:2!V;VD@=F%I:'1A82!O:6ME=6MS:6$@5D93+71I961O<W1O;&QE("5S+R5S
M+@!%:2!V;VED82!V86EH=&%A("5S.FXN`%1I961O<W1O;B`B)7,B(&MO:V]A
M(&5I('9O:71U('1A<FMI<W1A82X`16D@=F]I9&$@;FEM973D('5U9&5L;&5E
M;B!61E,M=&EE9&]S=&]A("(E<R\E<R(N`%-13"UP86QV96QI;65E;B!E:2!S
M86%D82!Y:'1E>71TY"X`66AT97ET=.0@96D@=F]I9&$@;75O9&]S=&%A(%-3
M3"US86QA='1U;F$N`%9&4RUT:65D;W-T;V$@96D@=F]I9&$@:V]P:6]I9&$N
M`$5I('9O:61A(&QU;V1A(%9&4RUH86ME;6ES=&]A("(E<R(N`$5I('9O:61A
M(&QU;V1A(%9&4RUH86ME;6ES=&]A+@!%:2!V;VET=2!L=6]D82!61E,M=&EE
M9&]S=&]A`$5I('9O:61A(&YI;65TY"!U=61E;&QE96X@5D93+6MA;G-I;W1A
M("(E<R(N`$5I('9O:71U(&QU;V1A('1Y:&KDY"!61E,M=&EE9&]S=&]A+@!4
M:65T;V$@96D@=F]I9&$@;&%A:F5N=&%A+@!%:2!V;VED82!P;VES=&%A("(E
M<R(L(&AA:V5M:7-T;R!E:2!O;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@
M(B5S(CH@)7,N`$5I('9O:61A('!O:7-T86$@)7,L(&AA:V5M:7-T;R!E:2!O
M;&4@='EH:N0N`$5I('9O:61A('!O:7-T86$@5D93+6AA:V5M:7-T;V$@<F5K
M=7)S:6EV:7-E<W1I+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A
M+@!%:2!V;VED82!P;VES=&%A(%9&4RUH86ME;6ES=&]A.B`E<RX`16D@=F]I
M9&$@<&]I<W1A82!61E,M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A('!O:7-T
M86$@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M:V%N<VEO
M=&$@(B5S(BX`16D@=F]I9&$@<&]I<W1A82!61E,ZY.0@<F5K=7)S:6EV:7-E
M<W1I.B`E<RX`3GEK>6ES=.0@:&%K96UI<W1O82!E:2!V;VET=2!S96QV:71T
MY.0N`%9A<FUE;G1E96X@=&EE=&]J82!E:2!V;VED82!E>'1R86MT;VED80!-
MY.1R:71Y:W-E;B`E<R!L=6ME;6EN96X@97#D;VYN:7-T=6DN`$5I('9O:61A
M('-I:7)TY.0@5D93+71I961O<W1O82X`16D@=F]I9&$@<&]I<W1A82!61E,M
M=&EE9&]S=&]A("(E<R(N`$5I('9O:61A(&%V871A(%9&4RUT:65D;W-T;V$@
M:VER:F]I='5S=&$@=F%R=&5N+@!%:2!V;VED82!A=F%T82!61E,M=&EE9&]S
M=&]A+@!4:6EV:7-T971Y;B!T:65D;W-T;VX@875K86ES=2!E<.1O;FYI<W1U
M:2X`16D@=F]I='4@;'5K96$@5D93+71I961O<W1O82`H9FEL97-I>F4H*2!E
M<.1O;FYI<W1U:2DN`$5I('9O:61A(&QU:V5A(%9&4RUT:65D;W-T;V$@*&=E
M=$9I;&53:7IE*"D@97#D;VYN:7-T=6DI+@!%:2!V;VET=2!L=6ME82!T:65D
M;W-T;V$Z(`!V9G-R;V]T(&IU=7)I:&%K96UI<W1O82!E:2!V;VET=2!L=6ME
M82X`575D96QL965N;FEM9>1M:6YE;B`E<R`E<SIK<VD@97#D;VYN:7-T=6D@
M:V]S:V$@:V]H9&5H86ME;6ES=&\@;VX@:F\@;VQE;6%S<V$`16D@=F]I9&$@
M;FEM973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O82X`16D@=F]I9&$@;FEM
M973D('5U9&5L;&5E;B!61E,M:&%K96UI<W1O83H@)7,N`$5I('9O:61A(&YI
M;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82`B)7,B+@!%:2!V;VED82!N
M:6UE=.0@=75D96QL965N(%9&4RUT:65D;W-T;V$@)7,O)7,N`$5I('9O:71U
M(&YI;65TY"!U=61E;&QE96X@5D93+71I961O<W1O82X`16D@=F]I9&$@<W5O
M<FET=&%A(&MO;65N=&]A("=M:VES;V9S)RX`5V]R9"UD;VMU;65N='1I82!E
M:2!V;VET=2!KY.1N=.3D`$5I('9O:61A(&MI<FIO:71T86$@5D93+71I961O
M<W1O82`B)7,B+@!%:2!V;VED82!K:7)J;VET=&%A(%9&4RUT:65D;W-T;V]N
M("AC;W!Y*"D@97#D;VYN:7-T=6DI+@!%:2!V;VED82!K:7)J;VET=&%A(%9&
M4RUT:65D;W-T;VX@=&EE=&]J82X`16D@=F]I9&$@:VER:F]I='1A82!61E,M
M=&EE9&]S=&]A+"!K:6EN=&GV(&]N('3D>6YNY"X`06QL979I:79A='1U`%!E
M<G4@;75U=&]K<V5T`%!E<G5U='1A82!E9&5L;&ES96X@=&]I;65N<&ET965N
M`%1U;G1E;6%T;VX@=F%S=&%U<R!P86QV96QI;65L=&$@>6AT97ET965N.@!4
M=6YT96UA=&]N('9A<W1A=7,@<&%L=F5L:6UE;'1A.B``3'5O:VET=&5L96UA
M=&]N`%5N:6-O9&4@*%541BTX*0!9:&1I<W1Y;F5E="!A<F%B:65M:7)A871I
M=`!9:&1I<W1Y;F5E="!K=6YI;F=A<VMU;FYA=`!9:&1Y<W9A;&QA=`!9:&1Y
M<W9A;'1O:F5N(%1Y>6YE;FUE<F5N(&5R:6QL:7-S86%R970`36ET=&%Y:W-I
M:_9T`%1U;G1E;6%T;VX`5'5N=&5M871O;B!A<&EM<V=I9"`H05!)($UE<W-A
M9V4@240I+@!4=6YT96UA=&]N(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)
M1"DN`$%N;F5T='4@<&%I:VMA=&EE=&\@;VX@='5N=&5M871O;BX`5'5N=&5M
M871O;B!KY'ET=.1JY'1U;FYU<R!T86D@<V%L87-A;F$N`%!O:7-T82!N>6MY
M:7-E;B!E;&5M96YT:6X@;&EN:VET>7,`3FEM973V;@!4:65T;W1U<G9A<WEI
M<W3D(&5I+7!R:79I;&5E9VES970@<VMR:7!T:70@96EVY'0@=F]I(&MU='-U
M82!,96EK:V%A+TMO<&EO:2],:6ETY"!T;VEM:6YT;VIA+B!.87!S875T82!/
M2RUN87!P=6QA82!NY&ADY&MS97-I(&UO>FEL;&$N;W)G('-I=G5I;&QA(&]L
M979A;B!O:&IE96XL(&IO<W-A(&YE=79O=&%A;B!M:71E;B!S:W)I<'1I<VD@
M=F]I=F%T(&OD>71TY.0@;&5I:V5P]GETY.0N`%!O:7-T82!VY')I`$5I+71U
M971T=2!L86%J96YN=7,`4.1I=FETY`!0Y&EV:73D("5S`%#D:79I=.0@:^1Y
M='3D:N0`4.1I=FET971T:6EN("(E<R(N`%#D:79I='ES<VMR:7!T:2!P;VES
M=&5T=&EI;BX`5'5O`'1U;R!K86EK:VD@;VAJ96QM:65N(&%S96YN=7-T:65D
M;W-T;W0@<&%L=F5L:6UE;&QE+@!)<V]T(&QA=&EN86QA:7-E="!K:7)J86EM
M970`27-O="!R;V]M86QA:7-E="!N=6UE<F]T`%5R=6=U87D`2^1Y=.0@;GEK
M>6ES=.0Z("5S`$OD>73D(%-33"US86QA=7-T80!+Y'ETY"!J;W,@='5N;G5S
M+W-A;&%S86YA(&]N(&5R:2!)35-0+7!A;'9E;&EM96QL92X`2^1Y='3D:N0`
M2^1Y='3D:N1L;.0@)7,@96D@;VQE(&]I:V5U:W-I82!T96ADY"`E<RX`2^1Y
M='3D:FEE;B!Y;&SD<&ET;P!+Y'ET=.1JY&X@87-E='5K<V5T`$OD>71TY&KD
M;B!R96MI<W1E<O9I;6EN96X`5.1S<^0@:N1R:F5S=&5L;>1S<^0@96D@=F]I
M(')E:VES=&5R]FEDY"!KY'ET=.1J:>0N`$OD>71TY&KD='5N;G5S=&$@96D@
M;/9Y='EN>70N`$OD>71TY&KD='5N;G5S`$OD>71TY&KD='5N;G5S("(E<R(@
M;VX@:F\@;VQE;6%S<V$N`$OD>71TY&KD='5N;G5S.@!+Y'ET=.1JY'1U;FYU
M<SH@`$KD<FIE<W1E;&WD;B!KY'ET=.1JY'0Z`%5Z8F5K:7-T86X`5D93+6AA
M:V5M:7-T;V$@96D@;VQE(&]L96UA<W-A+@!0;VES<V%O;&]V:65S=&D`4&%I
M:VMO:F$@;/9Y='EI(&5S:6UE<FMI:W-I.B``5F]I;6%S<V%O;&]A:6MA`$%R
M=F\@;6EN=75T96ES<V$@;GEK>6AE=&ME<W3D+@!!<G9O(&]N('EL:2!P:71U
M=61E;B!M86MS:6UI87)V;VX@)7,N/`!!<G9O=`!686QI='1A=F%T(&%R=F]T
M`%9A;G5A='4`5F%I:'1E;&5V86$`5F5N97IU96QA`%1A<FMI<W1U<R!E<.1O
M;FYI<W1U:2`M(%3D=.0@=FEE<W1IY"!O;B!V;VET=2!KY'-I=&5L;.0N`%9E
M<G-I;P!697)S:6]N:&%L;&EN=&$`4'ES='ES=6]R82!T87-A=7,`4'ES='ES
M=6]R82!TY'ET90!0>7-T>7-U;W)A.@!%<FET=.1I;B!K;W)K96$`5FEE=&YA
M;0!6:65T;F%M("A625-#24DI`$[D>73D("5S`$[D>73D(&5R:6QL:7-E;N0@
M=W=W+7-I=G5N80!.Y'ETY"`E<P!.96ET<WET<V%A<F5T+"!"<FET=&ELY&EN
M96X`3F5I='-Y='-A87)E="P@66AD>7-V86QT86EN`$[D:WEVY&ES>7ES`$[D
M:WEVY&ES>7ES.B``5F]D869O;F4@271A;'D@4TU44#IN(&%V=6QL80!605)/
M25154P!605)/25154R$A(2!03TE35$$@4TM225!422!+Y%-)3B!004Q614Q)
M345,5$$@)7,N`%=)3B!(5%10.FX@879U;&QA`%=A;&QI<R!J82!&=71U;F$`
M5F%R;VET=7,`:V4`4^3D96YN=7-T90!3Y.1T:65D;W0@;VX@=&]I;6ET=&%N
M=70`5V5A=&AE<BYC;VT`5U=7`%=75RUS:79U<W1O`%9I:6MO:71T86EN`%1E
M<G9E='5L;V$`5&5R=F5T=6QO82!O:&IE;&UA86X@)7,`5&5R=F5T=6QO82P@
M)7,`3.1N<VEM86EN96X@*$E33RTX.#4Y+3$I`$SD;G-I;6%I;F5N+T5U<F\@
M*$E33RTX.#4Y+3$U*0!,Y&YS:2U386AA<F$`36EN:^0@;VAJ96QM86X@)7,@
M:^1Y;FYI<W3DY"!S:7/DY&YK:7)J875T=6UI<V5N(&KD;&ME96XN`$UI=.0@
M;65R:VMIY"!KY'ET973DY&X@97)O='1I;65N83\`36ETY"!M97)K:VGD(&OD
M>71E=.3D;B!L86EN875K<V5E;C\`5VAE<F5I<R!!=7-T<F%L:6%N(&MA<G1T
M80!-:71KY"!V86EH965T`%9O:70@;>3D<FET96QLY"!L:7/D=&]I;6EN=&]J
M82!L86ET971A86X@<.3D;&QE(%)I8V@@5&5X="!E9&ET;W)I<W-A+@!,979E
M>7,`3&5V97ES($-34R!M:71T87EK<VEK:_9I;N0`5F%S96UM86QL82!O;&5V
M86X@)7,@=F%L:6MO;B!L979E>7,@*'1U;&5E('9O:6UA86X@<V5U<F%A=F%L
M;&$@<VESY.1N:VER:F%U='5M:7-E;&QA*3H`5&%U;'5K;VX@;&5V97ES`$QE
M=F5Y9&5N('EK<VEK:_8`3&5V97ES.@!7:6MI`%1U=6QI`%1U=6QI<W1A(&%I
M:V%I<VEN`%1U=6QE;FYO<&5U<R!S;VQM=6ES<V$`5'5U;&DZ`%1U=6QI.B``
M5FEI<V%U<P!4;VEV96QI<W1A=`!4>?8`3W-O:71E("AT>?8I`%!U:&5L:6X@
M*'1Y]BD`5N3D<N0@;>3D<N0@:V5N='1IY"!R:79I;&SD("5D+B!/9&]T971T
M:6EN("5D+"!L]GET>6D@)60N`%;DY'+D(&WDY'+D(&ME;G1T:>0N($]D;W1E
M='1I:6X@)60L(&SV>71Y:2`E9"X`5N3D<N0@<&]I:VME86UA("5D(&QU971T
M865S<V$@5D93+71I961O<W1O82X`6"U2968`6#4P.78S('!E<G5S<F%J;VET
M=&5E=`!8-3`Y=C,@;&ESY'1O:6UI;FYO="!A=F%I;65N(&OD>73V;&QE`%@U
M,#EV,R!+;VAT965N('9A:6AT;V5H=&]I;F5N(&YI;6D`6#4P.78S($MO:'1E
M96X@879A:6UE;B!T=6YN:7-T90!8-3`Y=C,M;&%A:F5N;G5K<V5T`%96`%96
M5E8`66%H;V\A(&MA<G1T80!6=6]S:71T86EN`$IE;65N`$MY;&SD`$MY;&SD
M+"!S=6]S='5N+@!+Y'ETY'0@5$5+4U1)5$E,04$N($OD>73D(%L\/ET@;F%P
M<'5L86$@=F%I:'1A86MS97-I('1A:V%I<VEN(%=94TE764<M=&EL86%N+@!%
M="!V;VD@=&5H9.0@96YE;7#DY"!K=6EN("5D(&]S:6]T82X`170@;VQE(&%U
M=&5N=&EK;VET=6YU="X`3FEM97-SY'-I(&5I('-A82!O;&QA("=<)RUM97)K
M:VGD+@!%="!A;G1A;G5T(&]I:V5A;B!M=6]T;VES=&$@<^1H:_9P;W-T:6]S
M;VET971T82X`170@;>3D<FET96QL>70@;6ET:^0@='5O9'5N('1I961O<W1O
M;B!K96YTY'0@=F%S=&%A=F%T(&UI=.1K:6X@:V5N='1IY"`E<SIS<^0N`$]L
M970@:VER:F%U='5N=70@=6QO<RX`4VEN=6X@<&ETY.0@86YT86$@;VEK96$@
M;6%T:V%P=6AE;&EN;G5M97)O+"!V86EN(&YU;65R;VET82!J82!M86AD;VQL
M:7-E<W1I("<K)R!J;W,@:^1Y=.1T(&MA;G-A:6YVY&QI<W3D('!U:&5L:6YN
M=6UE<F]M=6]T;V$N`%-I;G5N('3D>71Y>2!A;G1A82!O:6ME82!A<G9O+@!3
M:6YU;B!P:73DY"!A<V5N=&%A($1A=&%4<F5E+71A=7-T86KD<FIE<W1E;&WD
M(&5N;F5N(&MU:6X@=F]I="!KY'ET=.3D(%-I9VYU<"UT;VEM:6YT;VIA+@!3
M:6YU;B!P:73DY"!A<V5N=&%A(%9&4RUT875S=&%JY')J97-T96QMY"X`4VEN
M=6X@='5L964@:W5V86EL;&$@;VYG96QM871I;&%N;F5T=&$@96YN96X@:W5I
M;B!V;VET(&SD:&5T=.3D(&]N9V5L;6%V:65S=&EN+@!3:6YU;B!P:73DY"!A
M;G1A82!54DP@;6EH:6X@=.1MY"!L:6YK:VD@;W-O:71T86$`4VEN=6X@<&ET
MY.0@=F%L:71A('!O:7-T971T879A('!A;'9E;&EN+@!3:6YU;B!P:73DY"!A
M;G1A82!P;VES=&5T=&%V82!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@
M86YT86$@<&]I<W1E='1A=F$@:^1Y='3D:N1T=6YN=7,N`%-I;G5N('!I=.3D
M(&%N=&%A(&QI<^1T=.1VY"!KY'ET=.1JY'1U;FYU<RX`4VEN=6X@<&ETY.0@
M86YT86$@<.1I=FET971TY';D(&OD>71TY&KD='5N;G5S+@!3:6YU;B!P:73D
MY"!V86QI=&$@<W5O<FET971T879A('1O:6UI;G1O+@!3:6YU;B!P:73DY"!A
M;G1A82!U=61E;B!K871E9V]R:6%N(&YI;6DN`%-I;G5N('!I=.3D(&%N=&%A
M(&ET86QI86QA:6YE;B!P=6AE;&EN;G5M97)O`$ES='5N=&]S:2`E<R!O;B!V
M86YH96YT=6YU="X@2VER:F%U9'4@=75D96QL965N('-I<^3D;BX`4^1H:_9P
M;W-T:6]S;VET=&5E<VD`4VEN=6X@;.1H971TY&KD;W-O:71T965S:3H`3VUA
M="!T:65T;W-I`%-I;G5N('1I971O:V]N965S:2!KY'ET=.1MY"!T:65T;W9E
M<FMK;RUO<V]I=&4@;VX@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T
M(&%L;VET=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN
M=6X@<&ETY.0@:VER:F%U='5A('5U9&5S=&%A;B!JY')J97-T96QMY.1N+@!.
M:6UE<VD`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%JY')J97-T
M96QMY"!E:2!T=64@:^1Y='3D:FEE;B!L:7/DY&UI<W3D+B!*;W,@:&%L=6%T
M(&AA;&QI;FYO:61A(&OD>71TY&KD='5N;G5K<VEA+"!S:6YU;B!P:73DY"!K
MY'ET=.3D(&IO=&%K:6X@=&]I<W1A(&%U=&AE;G1I8V%T:6]N('1A=7-T86KD
M<FIE<W1E;&WDY"X`2^1Y='3D;>1S:2!A=71H96YT:6-A=&EO;B!T875S=&%J
MY')J97-T96QMY"!E:2!T=64@:^1Y='3D:N1T:65T;VIE;B!NY'ET=.1M:7-T
MY"!T86D@=.1MY"!P:6ER<F4@96D@;VQE(&IO<W1A:VEN('-Y>7-TY"!KY'ET
M971TY'9I<W/D+@!3:6YU;B!KY'ET=.1MY'-I('=W=RUS96QA:6X@;N1Y='3D
MY"!O;&5V86X@;75U='1U;G5T('-E;B!JY&QK965N(&MU;B!O;&5T(&%L;VET
M=&%N=70@)7,@:7-T=6YN;VXN(%1I971O='5R=F%S>6ES=.0@<VEN=6X@<&ET
MY.0@:VER:F%U='5A('5U9&5S=&%A;FKD<FIE<W1E;&WDY&XN`%-E;&%I;65S
M:2!E:2!T=64@=.1TY"!T;VEM:6YT;V$N`%-E;&%I;65S:2!E:2!T=64@=&%R
M=FET=&%V86$@='5L;W-T=7-T;VEM:6YT;V$N(%!A:6YA($-O;G1R;VPO3W!T
M:6]N("L@4"!T=6QO<W1A86MS97-I+@!!:6MA=GGV:'EK:V5E<VDZ`$]L971U
M<W!R;V9I:6QI<VD@;VX@;75U=&5T='4N`$]L971U<W!R;V9I:6QI<VDZ`$YI
M;65S:3H`27-T=6YT;W-I(&]N('9A;FAE;G1U;G5T+@!3:6YU;B!S86QA<V%N
M87-I("5S.FQL92!O;CH@)7,`07-E='5K<V5S:2!O;B!PY&EV:71E='1Y(&IA
M(&YE(&]V870@=F]I;6%S<V$@=.1MY&X@:7-T=6YN;VX@86IA;BX`07-E='5K
M<V5S:2!O;B!PY&EV:71E='1Y+@!386QA<V%N87-I(&]N(&YO;&QA='1U`%-A
M;&%S86YA<VD@;VX@;F]L;&%T='4L('1A<FMI<W1A('/D:&OV<&]S=&ES:2!J
M82!K:7)J875D=2!S:7/DY&X@=75D96QL82!S86QA<V%N86QL87-I+@!386QA
M<V%N87-I(&]N('9A;FAE;G1U;G5T+@!%=.1P86QV96QI;65S:3H`2G5G;W-L
M879I80!:86ER90!386UB:6$`6FEM8F%B=V4`6FEP<'D`6U!I:6QO=&$@;&%I
M;F%T='4@=&5K<W1I70!;3VYG96QM85T`6T[D>73D(&QA:6YA='1U('1E:W-T
M:2`M`%M.Y'ETY"!L86EN871T=2!T96MS=&D@+2`E<R!R:79IY%T`6W)I=FEL
M;.0@)7,O)7-=`%]9;&SD<&ET;P!?2V]M96YT;W1U;&MK:0!?1&%T851R964`
M7U!O:7-T82!R:79I`%]2>6AMY'0`7T]H:F4`7TMU=F%N('1I961O="XN+@!?
M2VER:F%U9'4@<VESY.1N`%]+:7)J875D=2!U;&]S`%]-=6]K:V%A(&QI;FMK
M:>0`7T%S971U:W-E=`!?3VEK975D970`4&]I<W1A(&QI;FMK:2XN+@!?07-E
M;FYU<P!?5&%U;'5K;VX@=&EE9&]T+BXN`%]+Y'ET=.1JY'0`;W-O:71E:VER
M:F$`=F%S=&%A;F]T=&%J82!T=6YT96UA=&]N`&MA;&5N=&5R:0!T>7EN=.0`
M96D@=F]I(&QU;V1A('1U;&]S=&EE9&]S=&]A`&5I('9O:2!A=6MA:7-T82!L
MY&AD971TY`!N87!S875T82!TY'-TY`!V:7)H92!K;VUE;G1O<FEV:6QLY`!A
M<V5T=7-V:7)H90!K<FEI='1I;F5N(&KD<FIE<W1E;&WD=&EE9&]S=&\@<'5U
M='1U=0!M=6]T;W9I<FAE('1I961O:7-S80!M=6]K:V%A`'1I971U971T82!E
M:2!L]GET>6YY=`!L87-K979A`'1I961O<W1O`'-U=6YN87-T82`E<R`H)7,I
M(&YO<&5U9&5L;&$@)7,@)7,`<'5U<VMI='1A:6X`:#H`:&@`='5N=&5M871O
M;B!P86QV96QI;65N(&YI;6D`=N1L:71T]FWD<W1I`&EN;&EN90!I;RUV:7)H
M90!O:&IE;&UI<W1O;B!S:7/D:6YE;B!V:7)H90!R:79I=%T`;6MI<V]F<R!V
M:7)H96MO;V1I("5D($E33SIA('1E:&1E<W/D+@!M;0!N:6UI`&5I(&]L92!T
M;W1E=71E='1U`&5I(&]L92!V:65LY"!T;W1E=71E='1U`&UU:7-T:6QI<W1A
M`'!R;W-E;G1T:0!KY'ET=/8@:VEE;&QE='1Y`'!I:W-E;&5I=.0`973D=FER
M:&4@<')O=&]K;VQL87-S80!N;W5S979A`'!A;'9E;'4@96D@;VQE(&OD>71E
M='3D=FES<^0`;N1Y=.0@97)O=`!S;7,R96UA:6P@2%144#IN(&%V=6QL80!S
M<P!V86MA80!JY')J97-T96QMY'9I<FAE`'1E:'3D=N1L:7-T80!VY&QI86EK
M86EN96X@=FER:&4`=F%R;6ES=&%A:W-E<VD@:VER:F]I=&$@<V%L87-A;F$@
M:V%H9&5S=&D`=6YI9FEE9`!N:6UE=/9N`&OD>71TY&KD;B!V86QI;G1A`'9#
M87)D`'<Z`'=E871H97(N8V]M````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]E<U]%4R],0U]-
M15-304=%4P``````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$T,2`P,C$T-S0`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V5S7T53+VAE;'`N>&UL````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`T,S(S(#$P-3$U-#,T,30Q(#`R,30T,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/WAM;"!V
M97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]E<U]%
M4R]H96QP+GAM;"QV(#$N,R`R,#`T+S$R+S$P(#$V.C$W.C,W(&IA;B!%>'`@
M)"`M+3X*/&AE;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB=7!T
M;V1A=&4B(&UD-3TB-CAC83,S9C=F,&,Y86%E-&,Q,#-E8C0W-#DR8V1C,34B
M/@H\=&ET;&4^3&$@<"8C>$4Q.V=I;F$@9&5L('!O<G1A;#PO=&ET;&4^"B`\
M<&%R83X*("!%<W1A('`F(WA%,3MG:6YA(&1E;"!P;W)T86P@<')O<&]R8VEO
M;F$@=6X@<B8C>$4Q.W!I9&\@<F5S=6UE;B!D92!T;V1A('-U(&EN9F]R;6%C
M:28C>$8S.VX*("!I;7!O<G1A;G1E+B!0;W(@96IE;7!L;RP@<'5E9&4@;6]S
M=')A<B!C=28C>$4Q.VYT;W,@;65N<V%J97,@;G5E=F]S('1I96YE(&5N(&5L
M"B`@8G5Z)B-X1C,[;B!D92!%;G1R861A+"!A8V]N=&5C:6UI96YT;W,@:6YM
M:6YE;G1E<R!D92!L82!A9V5N9&$L('1A<F5A<R!P96YD:65N=&5S"B`@9&4@
M;&$@;&ES=&$@9&4@=&%R96%S+"!T:71U;&%R97,@9&4@<V5R=FEC:6]S(&1E
M(&YO=&EC:6%S('-E;&5C8VEO;F%D;W,L(&5T8RX*("!-=6-H;W,@9&4@97-T
M;W,@<F5S)B-X1D$[;65N97,@<&]D<B8C>$4Q.VX@8V]N=&5N97(@871A:F]S
M(&$@86-T:79I9&%D97,@=7-U86QE<R!T86QE<PH@(&-O;6\@;&$@<F5D86-C
M:28C>$8S.VX@9&4@;G5E=F]S(&UE;G-A:F5S+"!L82!C<F5A8VDF(WA&,SMN
M(&1E(&%C;VYT96-I;6EE;G1O<R!D92!L80H@(&%G96YD82!O('1A<F5A<R!N
M=65V87,L(&5T8RX*(#PO<&%R83X*(#QP87)A/@H@($QO<R!C;VYT96YI9&]S
M(&1E(&5S=&$@<"8C>$4Q.V=I;F$@9&5L('!O<G1A;"!S92!P=65D96X@<&5R
M<V]N86QI>F%R(&UE9&EA;G1E(&5L"B`@8F]T)B-X1C,[;B!$:7-T<FEB=6-I
M)B-X1C,[;BX@4&]R(&5J96UP;&\L('!U961E(&5L96=I<B!Q=28C>$4Y.R!E
M;&5M96YT;W,@:6YC;'5I<B!E;B!E<W1A"B`@<"8C>$4Q.V=I;F$@9&5L('!O
M<G1A;"!A<R8C>$5$.R!C;VUO(&5L(&]R9&5N(&5N(&5L('%U92!S92!M;W-T
M<F%R)B-X13$[;BX*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA
M=F)A<B(@<W1A=&4](G5P=&]D871E(B!M9#4](F(X8V8P864Q.64U-V1F83!C
M,F(Y-C)E-3$V-S@R9C0W(CX*/'1I=&QE/DQA(&)A<G)A(&1E(&YA=F5G86-I
M)B-X1C,[;B!D92!A<&QI8V%C:6]N97,\+W1I=&QE/@H@/'!A<F$^"B`@16X@
M96P@;&%D;R!I>G%U:65R9&\@9&4@;&$@<"8C>$4Q.V=I;F$@=V5B('-E(&5N
M8W5E;G1R82!L82!B87)R82!D92!N879E9V%C:28C>$8S.VX@9&4*("!A<&QI
M8V%C:6]N97,N(%!U;'-E(&QO<R!I8V]N;W,@9&4@9&EC:&$@8F%R<F$@<&%R
M82!C86UB:6%R('(F(WA%,3MP:61A('D@9B8C>$4Q.V-I;&UE;G1E"B`@96YT
M<F4@;&%S(&%P;&EC86-I;VYE<R!D:7-P;VYI8FQE<RX*(#PO<&%R83X*/"]E
M;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E(B!S=&%T
M93TB=7!T;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P,S$R,S)B865A.3$Y,C@X
M8C)D,#`B/@H@("`@/'1I=&QE/E!R969E<F5N8VEA<SH@36%N=&5N:6UI96YT
M;SH@4F5A;&EZ87(@;6%N=&5N:6UI96YT;SPO=&ET;&4^"B`@("`\<&%R83X*
M("`@(%-I(&1E<V5A(')E86QI>F%R(&QA<R!O<&5R86-I;VYE<R!D92!M86YT
M96YI;6EE;G1O(&%L(&EN:6-I87(@;&$@<V5S:28C>$8S.VXL"B`@("!S96QE
M8V-I;VYE(&5S=&$@8V%S:6QL82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U
M<'1O9&%T92(@;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V
M92(^"B`@("`\=&ET;&4^4')E9F5R96YC:6%S.B!-86YT96YI;6EE;G1O.B!#
M;VYF:7)M87(@;6%N=&5N:6UI96YT;SPO=&ET;&4^"B`@("`\<&%R83X*("`@
M(%-I('%U:7-I97)A(&-O;F9I<FUA<B!L87,@=&%R96%S(&1E(&UA;G1E;FEM
M:65N=&\@86YT97,@9&4@<75E('-E(&5J96-U=&5N+`H@("`@<V5L96-C:6]N
M92!E<W1A(&-A<VEL;&$N(%-I('-E(&1E:F$@<VEN('-E;&5C8VEO;F%R+"!S
M92!E:F5C=71A<B8C>$4Q.VX*("`@(&%U=&]M)B-X13$[=&EC86UE;G1E(&%L
M(&EN:6-I87(@;&$@<V5S:28C>$8S.VX@=&]D87,@;&%S('1A<F5A<R!D92!M
M86YT96YI;6EE;G1O"B`@("!P96YD:65N=&5S('-I;B!L82!P;W-I8FEL:61A
M9"!D92!C86YC96QA<FQA<RX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&]C86QE+V5S7T53+TQ#7TU%4U-!1T53+VAO<F1E+FUO
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-#(Q-S,T(#$P-3$U-#,T,30Q
M(#`R,S(R-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````#>$@25`````(H'```<````;#P``!,*``"\>`````````BA```.````
M":$```\````8H0``#0```"BA```(````-J$```L````_H0``#````$NA```$
M````6*$``!@```!=H0``&P```':A```M````DJ$``!T```#`H0``)````-ZA
M```I`````Z(``!D````MH@``)@```$>B```,````;J(``"0```![H@``#P``
M`*"B```+````L*(```X```"\H@``!0```,NB```H````T:(```@```#ZH@``
M"@````.C```5````#J,``!(````DHP``"P```#>C``"%````0Z,```X```#)
MHP``"@```-BC```-````XZ,```X```#QHP``$0````"D```-````$J0```P`
M```@I```#0```"VD```&````.Z0``)0```!"I```"@```->D```/````XJ0`
M`!@```#RI```#`````NE```.````&*4```X````GI0``"````#:E```)````
M/Z4``"X```!)I0``&@```'BE```R````DZ4``#@```#&I0``5````/^E``!1
M````5*8``%H```"FI@``5P````&G```T````6:<```D```".IP``#0```)BG
M```'````IJ<```H```"NIP``#P```+FG```%````R:<```8```#/IP``$0``
M`-:G```(````Z*<```D```#QIP``"0```/NG```E````!:@``"`````KJ```
M$P```$RH```0````8*@```\```!QJ```"@```(&H```#````C*@```\```"0
MJ```%````*"H```)````M:@```T```"_J```$@```,VH```9````X*@``!X`
M``#ZJ```#P```!FI```*````*:D```\````TJ0``"````$2I```D````3:D`
M`!0```!RJ0``%@```(>I```(````GJD``$X```"GJ0``+0```/:I```9````
M)*H```<````^J@``#````$:J```L````4ZH```X```"`J@```P```(^J```+
M````DZH```<```"?J@``!P```*>J```%````KZH```4```"UJ@``"@```+NJ
M```#````QJH``!<```#*J@``"@```.*J```/````[:H```X```#]J@``&```
M``RK```C````):L```X```!)JP``%````%BK```7````;:L``!<```"%JP``
M%P```)VK```3````M:L```\```#)JP``#@```-FK```?````Z*L``!T````(
MK```!P```":L```&````+JP```@````UK```#P```#ZL```&````3JP```H`
M``!5K```$P```&"L```+````=*P``!````"`K```%0```)&L```5````IZP`
M``<```"]K```$````,6L```%````UJP``!4```#<K```$0```/*L```,````
M!*T``#L````1K0``.````$VM```)````AJT```<```"0K0``%````)BM```#
M````K:T```4```"QK0``$````+>M```)````R*T``!,```#2K0``.0```.:M
M```2````(*X``"<````SK@``+````%NN```J````B*X``"4```"SK@``"@``
M`-FN```&````Y*X```D```#KK@``!P```/6N```O````_:X``#<````MKP``
M+@```&6O``!5````E*\``"T```#JKP``+0```!BP```]````1K```#\```"$
ML```+0```,2P``!`````\K```",````SL0``(P```%>Q``!`````>[$``"T`
M``"\L0``,P```.JQ```E````'K(``!4```!$L@``&0```%JR```I````=+(`
M`"0```">L@``*````,.R```1````[+(```H```#^L@``#`````FS```*````
M%K,``!`````ALP``%@```#*S```6````2;,```<```!@LP``!P```&BS```4
M````<+,```H```"%LP``"````)"S```G````F;,```@```#!LP``!P```,JS
M```'````TK,```8```#:LP``!0```.&S```'````Y[,```8```#OLP``"```
M`/:S```I````_[,```X````IM```"@```#BT```$````0[0```<```!(M```
M"0```%"T```&````6K0``!$```!AM```!P```'.T```6````>[0```0```"2
MM```"````)>T```&````H+0```T```"GM```!@```+6T```>````O+0``!$`
M``#;M```"````.VT```-````]K0```P````$M0``!P```!&U```#````&;4`
M``,````=M0``%P```"&U```3````.;4``!T```!-M0``"````&NU```$````
M=+4```@```!YM0``"````(*U```[````B[4``#0```#'M0``00```/RU```:
M````/K8``"L```!9M@``(````(6V```5````IK8```8```"\M@``!@```,.V
M```5````RK8``!@```#@M@``(@```/FV```N````'+<``!T```!+MP``(0``
M`&FW``!4````B[<``"D```#@MP``"@````JX```'````%;@```<````=N```
M%0```"6X```.````.[@```H```!*N```#P```%6X```-````9;@```\```!S
MN```#0```(.X```)````D;@``!0```";N```!@```+"X```8````M[@``!T`
M``#0N```$P```.ZX```1`````KD``!0````4N0``!````"FY```&````+KD`
M`!0````UN0``5````$JY``!D````G[D```0````$N@``#@````FZ```%````
M&+H```4````>N@``&P```"2Z```:````0+H``!,```!;N@``$0```&^Z```1
M````@;H``!P```"3N@``*@```+"Z```0````V[H``"$```#LN@``!0````Z[
M```3````%+L```L````HNP``$@```#2[```*````1[L```\```!2NP``#0``
M`&*[```1````<+L``!,```""NP``#````):[```&````H[L```P```"JNP``
M!@```+>[```7````OKL``!````#6NP``$0```.>[```(````^;L```4````"
MO```#`````B\```0````%;P```4````FO```#0```"R\```&````.KP```<`
M``!!O```#0```$F\```'````5[P```L```!?O```!P```&N\```'````<[P`
M``D```![O```"0```(6\```*````C[P``!D```":O```/0```+2\```=````
M\KP```P````0O0``$````!V]```%````+KT``"4````TO0``$@```%J]```3
M````;;T``"L```"!O0``.P```*V]```@````Z;T```@````*O@``-@```!.^
M```A````2KX``!````!LO@``"````'V^```,````AKX```8```"3O@``!```
M`)J^```/````G[X```X```"OO@``!P```+Z^```*````QKX```T```#1O@``
M'P```-^^```<````_[X``"$````<OP``'@```#Z_```9````7;\``!X```!W
MOP``&P```):_```A````LK\``"X```#4OP``)@````/````<````*L```!X`
M``!'P```'````&;````F````@\```"L```"JP```,P```-;````F````"L$`
M`"L````QP0``.````%W!```=````EL$``!4```"TP0``+P```,K!```@````
M^L$``!(````;P@``*0```"["```>````6,(``"````!WP@``$@```)C"``"B
M````J\(``!8```!.PP``(P```&7#```H````B<,``"D```"RPP``*````-S#
M```?````!<0``!4````EQ```(````#O$```E````7,0``"@```""Q```+0``
M`*O$```P````V<0``)(````*Q0``(0```)W%```6````O\4``!P```#6Q0``
M)@```//%```J````&L8``$$```!%Q@``1````(?&```,````S,8```<```#9
MQ@``!P```.'&```&````Z<8```T```#PQ@``$````/[&```2````#\<``!,`
M```BQP``$@```#;'```'````2<<```0```!1QP``$````%;'```0````9\<`
M``P```!XQP``#@```(7'```-````E,<```\```"BQP``$P```++'```-````
MQL<``"@```#4QP```P```/W'```-`````<@```8````/R```$0```!;(```7
M````*,@``!L```!`R```#@```%S(```"````:\@``$D```!NR```!0```+C(
M```0````OL@```\```#/R```!````-_(```-````Y,@```X```#RR````P``
M``')```.````!<D```@````4R0``#P```!W)```/````+<D```<````]R0``
M#0```$7)```0````4\D```T```!DR0``"P```'+)```&````?LD```L```"%
MR0``#````)')```*````GLD``!$```"IR0``&0```+O)```+````U<D```T`
M``#AR0``(@```._)```/````$LH``!L````BR@``-````#[*```*````<\H`
M`!@```!^R@``$@```)?*```9````JLH``!8```#$R@``(@```-O*```-````
M_LH```<````,RP``%````!3+```+````*<L``"(````URP``+P```%C+```+
M````B,L```D```"4RP``&0```)[+```+````N,L``!<```#$RP``%P```-S+
M```)````],L``!8```#^RP``#P```!7,```9````)<P``!8````_S```#@``
M`%;,```8````9<P```@```!^S```#0```(?,```F````E<P``$,```"\S```
M"`````#-```2````"<T``!\````<S0``"````#S-```+````1<T``"\```!1
MS0``#@```('-```%````D,T```8```"6S0``10```)W-```#````X\T```<`
M``#GS0``!````._-```*````],T```H```#_S0``#P````K.```0````&LX`
M`!<````KS@``$0```$/.```9````5<X``!<```!OS@``"0```(?.```%````
MD<X```L```"7S@``"@```*/.```"````KLX```4```"QS@``#0```+?.```;
M````Q<X``!<```#AS@``%````/G.```)````#L\```X````8SP``#0```"?/
M```2````-<\``#@```!(SP``(````('/```(````HL\```X```"KSP``>P``
M`+K/```8````-M```!@```!/T```$0```&C0```'````>M````4```""T```
M&````(C0```>````H=```!L```#`T```&0```-S0```;````]M```!D````2
MT0``$P```"S1```'````0-$```@```!(T0``!@```%'1```&````6-$``!``
M``!?T0``#P```'#1```0````@-$```\```"1T0``"P```*'1```/````K=$`
M``P```"]T0``#P```,K1```'````VM$```8```#BT0``#@```.G1```,````
M^-$``"@````%T@``#P```"[2```(````/M(```@```!'T@``$P```%#2```>
M````9-(``"$```"#T@``(````*72```9````QM(``!<```#@T@``)0```/C2
M```7````'M,``!8````VTP``!````$W3```;````4M,```T```!NTP``#```
M`'S3```#````B=,```4```"-TP``"````)/3```*````G-,```P```"GTP``
M"P```+33```0````P-,```P```#1TP``#@```-[3```+````[=,```0```#Y
MTP``!````/[3```3`````]0``!0````7U```#````"S4```)````.=0```X`
M``!#U```"P```%+4```;````7M0```<```!ZU```!P```(+4```*````BM0`
M``T```"5U```"0```*/4```$````K=0```4```"RU````P```+C4```8````
MO-0```H```#5U```!````.#4```F````Y=0```X````,U0``?````!O5```5
M````F-4```4```"NU0``!P```+35```,````O-4```@```#)U0``"@```-+5
M```&````W=4```@```#DU0```@```.W5```&````\-4```8```#WU0``%```
M`/[5```-````$]8``!`````AU@``&P```#+6```$````3M8```D```!3U@``
M$````%W6```)````;M8```D```!XU@``!0```(+6```:````B-8```@```"C
MU@``!@```*S6```9````L]8```X```#-U@``!P```-S6```'````Y-8```4`
M``#LU@``"0```/+6```*````_-8```X````'UP```@```!;7```&````&=<`
M``L````@UP``#0```"S7```)````.M<```8```!$UP``$@```$O7```)````
M7M<```<```!HUP``%````'#7```=````A=<``$(```"CUP``)0```.;7```E
M````#-@```8````RV```"@```#G8```$````1-@```D```!)V```"````%/8
M```1````7-@```D```!NV```!@```'C8```-````?]@```8```"-V```!```
M`)38```Y````F=@``#T```#3V```.@```!'9```>````3-D```4```!KV0``
M#@```''9```$````@-D```8```"%V0``!P```(S9```A````E-D```T```"V
MV0``%0```,39```&````VMD```0```#AV0``$0```.;9```&````^-D```H`
M``#_V0``(@````K:```$````+=H```4````RV@``'0```#C:```$````5MH`
M``P```!;V@``#@```&C:```*````=]H```@```""V@``"0```(O:```%````
ME=H``#H```";V@``,````-;:```U````!]L``"D````]VP``1P```&?;```X
M````K]L``"D```#HVP``/P```!+<```N````4MP``"T```"!W```'P```*_<
M```/````S]P``!(```#?W```"P```/+<```F````_MP``"D````EW0``)```
M`$_=```F````=-T```@```";W0``"@```*3=```)````K]T```<```"YW0``
M(````,'=```@````XMT``"8````#W@``"@```"K>```9````-=X``"D```!/
MW@``%@```'G>```2````D-X```<```"CW@``"@```*O>```,````MMX```\`
M``##W@``$````-/>``!`````Y-X``'`````EWP``9@```);?```.````_=\`
M``D````,X```"@```!;@```2````(>```!,````TX```#````$C@```&````
M5>````\```!<X```$@```&S@```0````?^```!$```"0X```'````*+@```C
M````O^```&H```#CX```#P```$[A```%````7N$``!````!DX0``"0```'7A
M```$````?^$```L```"$X0``(````)#A```4````L>$```P```#&X0``#```
M`-/A```/````X.$``!4```#PX0``*0````;B```J````,.(``"8```!;X@``
M)P```(+B```I````JN(``"H```#4X@``&0```/_B``!"````&>,``!$```!<
MXP``$@```&[C```3````@>,``!0```"5XP``#P```*KC```6````NN,``!<`
M``#1XP``$````.GC```1````^N,``#0````,Y```$P```$'D```2````5>0`
M`#4```!HY```%````)[D```'````L^0```P```"[Y```(````,CD```0````
MZ>0``!0```#ZY```$0````_E```7````(>4``!P````YY0``$P```%;E```4
M````:N4``!H```!_Y0``$0```)KE```:````K.4``!X```#'Y0``&@```.;E
M```3`````>8``!4````5Y@``$0```"OF```7````/>8``!0```!5Y@``%P``
M`&KF```5````@N8```D```"8Y@``$````*+F```9````L^8```0```#-Y@``
M!P```-+F```+````VN8``!$```#FY@``!@```/CF```&````_^8```8````&
MYP``!0````WG```'````$^<```<````;YP``!0```"/G```6````*><```8`
M``!`YP``!@```$?G```$````3N<```0```!3YP``!P```%CG```.````8.<`
M``P```!OYP``#````'SG```-````B><```H```"7YP``#@```*+G```%````
ML><``"@```"WYP``#@```.#G```,````[^<```\```#\YP``"@````SH```(
M````%^@```D````@Z```*P```"KH```$````5N@```@```!;Z```)@```&3H
M```2````B^@```\```">Z```!@```*[H```*````M>@```<```#`Z```"```
M`,CH```@````T>@```D```#RZ```%````/SH```,````$>D```T````>Z0``
M#@```"SI```6````.^D``!$```!2Z0``!@```&3I```#````:^D```8```!O
MZ0``&0```';I```'````D.D```0```"8Z0``"P```)WI```+````J>D```<`
M``"UZ0``!0```+WI```'````P^D``!8```#+Z0``#0```.+I```-````\.D`
M``H```#^Z0``$`````GJ```/````&NH``!$````JZ@``%P```#SJ```*````
M5.H``!$```!?Z@``"````''J```$````>NH```\```!_Z@``.@```(_J```%
M````RNH```P```#0Z@``'@```-WJ```.````_.H``!`````+ZP``"P```!SK
M```,````*.L```D````UZP``!P```#_K```*````1^L```D```!2ZP``#@``
M`%SK```0````:^L``!L```!\ZP``&````)CK```:````L>L```H```#,ZP``
M"0```-?K```*````X>L```P```#LZP``#P```/GK```(````">P```8````2
M[```'````!GL```'````-NP```4````^[```"P```$3L``!'````4.P```T`
M``"8[```"0```*;L```$````L.P```,```"U[```$P```+GL```3````S>P`
M`!,```#A[```"@```/7L```"`````.T```0````#[0``)0````CM```#````
M+NT```4````R[0``*@```#CM```*````8^T```4```!N[0``!````'3M```*
M````>>T```T```"$[0``!@```)+M```(````F>T```@```"B[0``!````*OM
M```%````L.T``&@```"V[0``"0```!_N```,````*>X``!`````V[@``!0``
M`$?N```&````3>X``!L```!4[@``+P```'#N```0````H.X```H```"Q[@``
M#P```+SN```*````S.X```D```#7[@``$P```.'N```;````]>X``!@````1
M[P``%P```"KO```?````0N\```X```!B[P```P```''O```'````=>\```@`
M``!][P``!P```(;O```*````CN\```L```"9[P``!P```*7O``!1````K>\`
M`!````#_[P``#````!#P```-````'?```!H````K\```2@```$;P```9````
MD?````8```"K\```&@```++P```E````S?````8```#S\```!@```/KP```?
M`````?$```8````A\0``"0```"CQ```8````,O$``!<```!+\0``*````&/Q
M```&````C/$```T```"3\0``(@```*'Q``!7````Q/$``!,````<\@``(P``
M`##R```3````5/(```(```!H\@``"P```&OR```(````=_(```T```"`\@``
M"@```([R```'````F?(``!0```"A\@``!@```+;R```(````O?(```X```#&
M\@``!P```-7R```*````W?(```L```#H\@``,@```/3R```'````)_,```P`
M```O\P``#0```#SS```7````2O,```P```!B\P``"0```&_S```)````>?,`
M``H```"#\P``!P```([S```)````EO,```<```"@\P``"@```*CS```;````
ML_,```\```#/\P``$@```-_S```*````\O,``!8```#]\P``"0```!3T```0
M````'O0```<````O]```$@```#?T```$````2O0```<```!/]```!0```%?T
M```%````7?0```L```!C]```%````&_T```1````A/0``!H```"6]```%@``
M`+'T```4````R/0``!<```#=]```&````/7T```<````#O4``!D````K]0``
M!P```$7U```%````3?4```T```!3]0``#````&'U```(````;O4``!<```!W
M]0``"P```(_U```,````F_4``!\```"H]0``&@```,CU```3````X_4```0`
M``#W]0``"@```/SU```$````!_8```T````,]@``#````!KV```%````)_8`
M``D````M]@``!0```#?V```'````/?8```4```!%]@``!````$OV```"````
M4/8``#@```!3]@``+````(SV```2````N?8``"D```#,]@``,@```/;V```*
M````*?<``"P````T]P``+@```&'W```S````D/<``#,```#$]P``.````/CW
M```/````,?@``!@```!!^```$````%KX```/````:_@``!,```![^```%0``
M`(_X```4````I?@``!(```"Z^```%````,WX```5````XO@``"T```#X^```
M+0```";Y```Q````5/D``"X```"&^0``+P```+7Y```L````Y?D``&(````2
M^@``$P```'7Z```-````B?H```@```"7^@``%P```*#Z```(````N/H```P`
M``#!^@``*P```,[Z```A````^OH``!H````<^P``"0```#?[``!%````0?L`
M`$$```"'^P``!````,G[```3````SOL``!0```#B^P``#@```/?[```3````
M!OP``!@````:_```!@```#/\```)````.OP```H```!$_```#P```$_\```0
M````7_P```<```!P_```#@```'C\```%````A_P``!L```"-_```"````*G\
M```&````LOP``!0```"Y_```$0```,[\```.````X/P``#@```#O_````@``
M`"C]```&````*_T```X````R_0``!0```$']```'````1_T```X```!/_0``
M!@```%[]```H````9?T```P```"._0``'````)O]```$````N/T``"D```"]
M_0``%P```.?]```?````__T``%P````?_@``%````'S^```^````D?X``!\`
M``#0_@``$````/#^```'`````?\```X````)_P``#````!C_```,````)?\`
M`!,````R_P``"@```$;_```=````4?\``!D```!O_P``!0```(G_```1````
MC_\``!$```"A_P``)````+/_```2````V/\``!4```#K_P``$@````$``0`.
M````%``!`!D````C``$`"````#T``0`)````1@`!``T```!0``$`!P```%X`
M`0`*````9@`!``<```!Q``$`#P```'D``0`&````B0`!``L```"0``$`&@``
M`)P``0`*````MP`!``<```#"``$`"````,H``0`%````TP`!`!\```#9``$`
M!@```/D``0`0``````$!``@````1`0$`#0```!H!`0`(````*`$!`!X````Q
M`0$`$@```%`!`0`L````8P$!`!H```"0`0$`"0```*L!`0`*````M0$!`!4`
M``#``0$`!0```-8!`0`4````W`$!``0```#Q`0$`$````/8!`0`&````!P(!
M``<````.`@$`'@```!8"`0`H````-0(!``H```!>`@$`'````&D"`0`1````
MA@(!``L```"8`@$`&@```*0"`0`4````OP(!``0```#4`@$`!````-D"`0`+
M````W@(!``4```#J`@$`!@```/`"`0`(````]P(!``8``````P$`"@````<#
M`0`;````$@,!`#0````N`P$`-````&,#`0`@````F`,!`"D```"Y`P$`(```
M`.,#`0!!````!`0!`!H```!&!`$`*````&$$`0`I````B@0!`%````"T!`$`
M(@````4%`0`&````*`4!``@````O!0$`!0```#@%`0`(````/@4!`!D```!'
M!0$`&0```&$%`0`J````>P4!`",```"F!0$`&0```,H%`0`N````Y`4!`#0`
M```3!@$`"````$@&`0`7````408!``H```!I!@$`!P```'0&`0`A````?`8!
M`!````">!@$`#@```*\&`0`+````O@8!``<```#*!@$`$P```-(&`0`(````
MY@8!``L```#O!@$`"@```/L&`0`4````!@<!``\````;!P$`,@```"L'`0`+
M````7@<!``X```!J!P$`!0```'D'`0`%````?P<!``4```"%!P$`%P```(L'
M`0`/````HP<!``0```"S!P$`"@```+@'`0`)````PP<!``L```#-!P$`#0``
M`-D'`0`,````YP<!``X```#T!P$`!0````,(`0`$````"0@!``T````."`$`
M,@```!P(`0!%````3P@!`!<```"5"`$`!P```*T(`0`>````M0@!`!0```#4
M"`$`!0```.D(`0`4````[P@!``8````$"0$`!P````L)`0`.````$PD!`"H`
M```B"0$`!@```$T)`0`,````5`D!``T```!A"0$`$0```&\)`0`+````@0D!
M`#8```"-"0$`"@```,0)`0`B````SPD!``L```#R"0$`#P```/X)`0`R````
M#@H!`"4```!!"@$`,````&<*`0`Q````F`H!`"T```#*"@$`#@```/@*`0`%
M````!PL!``X````-"P$`$P```!P+`0`2````,`L!``<```!#"P$`$0```$L+
M`0`3````70L!``<```!Q"P$`%````'D+`0`8````C@L!``<```"G"P$`!0``
M`*\+`0`,````M0L!``P```#""P$`$@```,\+`0`$````X@L!``<```#G"P$`
M"@```.\+`0`+````^@L!``P````&#`$`#@```!,,`0`.````(@P!``4````Q
M#`$`!0```#<,`0`N````/0P!`"8```!L#`$`(P```),,`0`#````MPP!`!(`
M``"[#`$`!@```,X,`0`>````U0P!`!@```#T#`$`)0````T-`0`-````,PT!
M``D```!!#0$`'P```$L-`0`#````:PT!``<```!O#0$`"@```'<-`0`"````
M@@T!``P```"%#0$`%0```)(-`0`+````J`T!`!D```"T#0$`(````,X-`0`2
M````[PT!``4````"#@$`"@````@.`0`5````$PX!`!(````I#@$`#````#P.
M`0`$````20X!``D```!.#@$`!P```%@.`0`,````8`X!`%(```!M#@$`%P``
M`,`.`0`D````V`X!`!(```#]#@$`!P```!`/`0`&````&`\!``X````?#P$`
M#````"X/`0`-````.P\!`!4```!)#P$`$@```%\/`0`/````<@\!`!0```""
M#P$`"@```)</`0`;````H@\!`!````"^#P$`"P```,\/`0!I````VP\!`!H`
M``!%$`$`%P```&`0`0`G````>!`!`!H```"@$`$`%P```+L0`0`;````TQ`!
M`!D```#O$`$`'P````D1`0`3````*1$!``@````]$0$`!P```$81`0`(````
M3A$!``D```!7$0$`%0```&$1`0`-````=Q$!`",```"%$0$`#0```*D1`0`3
M````MQ$!``@```#+$0$``P```-01`0!&````V!$!`#\````?$@$`-P```%\2
M`0!7````EQ(!``4```#O$@$`'P```/42`0`O````%1,!``H```!%$P$`"```
M`%`3`0`-````61,!`"T```!G$P$`!````)43`0!/````FA,!`"4```#J$P$`
M'````!`4`0`+````+10!`!\````Y%`$`'0```%D4`0`E````=Q0!`"````"=
M%`$`)````+X4`0`@````XQ0!``L````$%0$`!P```!`5`0`-````&!4!``P`
M```F%0$`%P```#,5`0`&````2Q4!`#D```!2%0$`#````(P5`0`'````F14!
M``D```"A%0$`$P```*L5`0`)````OQ4!``0```#)%0$`$````,X5`0`(````
MWQ4!``@```#H%0$`!````/$5`0`+````]A4!``P````"%@$`$@````\6`0`1
M````(A8!``P````T%@$`&@```$$6`0`/````7!8!``<```!L%@$`#0```'06
M`0`4````@A8!``X```"7%@$`#````*86`0`;````LQ8!`"P```#/%@$`$P``
M`/P6`0`<````$!<!`"@````M%P$`!@```%87`0`'````71<!`!,```!E%P$`
M!0```'D7`0`$````?Q<!`!<```"$%P$`"@```)P7`0`,````IQ<!``D```"T
M%P$`!@```+X7`0`)````Q1<!``@```#/%P$`"0```-@7`0`*````XA<!`!$`
M``#M%P$`!@```/\7`0`.````!A@!``X````5&`$`#0```"08`0`+````,A@!
M`!T````^&`$`"P```%P8`0`"````:!@!`!P```!K&`$`!P```(@8`0`&````
MD!@!`&0```"7&`$`"0```/P8`0`'````!AD!`"8````.&0$`.````#49`0`:
M````;AD!`"H```")&0$`.P```+09`0`H````\!D!`#0````9&@$`&0```$X:
M`0`5````:!H!``4```!^&@$`!P```(0:`0`(````C!H!``<```"5&@$`!0``
M`)T:`0`'````HQH!``X```"K&@$`"0```+H:`0`&````Q!H!``@```#+&@$`
M"P```-0:`0`'````X!H!``@```#H&@$`!P```/$:`0`6````^1H!``D````0
M&P$`!@```!H;`0`+````(1L!`!`````M&P$`!@```#X;`0`<````11L!`!0`
M``!B&P$`!P```'<;`0`1````?QL!``@```"1&P$`#@```)H;`0`(````J1L!
M`!````"R&P$`"0```,,;`0`0````S1L!``8```#>&P$`&0```.4;`0`*````
M_QL!`!P````*'`$`!P```"<<`0`%````+QP!`!`````U'`$`%````$8<`0`+
M````6QP!``T```!G'`$`*````'4<`0`8````GAP!`!<```"W'`$`!````,\<
M`0`)````U!P!``H```#>'`$`!P```.D<`0`"````\1P!``X```#T'`$`"```
M``,=`0`C````#!T!`!\````P'0$`.````%`=`0`F````B1T!`#$```"P'0$`
M)P```.(=`0!D````"AX!`!0```!O'@$`50```(0>`0`X````VAX!`$H````3
M'P$`6P```%X?`0`H````NA\!`#@```#C'P$`*````!P@`0`L````12`!`!L`
M``!R(`$`/@```(X@`0"I`0``S2`!`",```!W(@$`%P```)LB`0!(````LR(!
M`(4```#\(@$`,````((C`0`E````LR,!`$$```#9(P$`6P```!LD`0!)````
M=R0!`#$```#!)`$`'0```/,D`0`8````$24!`"L````J)0$`(0```%8E`0`?
M````>"4!`"L```"8)0$`)@```,0E`0`G````ZR4!`#H````3)@$`'0```$XF
M`0`1````;"8!`#,```!^)@$`)0```+(F`0`G````V"8!`"``````)P$`'P``
M`"$G`0`P````02<!`&D```!R)P$`,0```-PG`0!!````#B@!`#,```!0*`$`
M)0```(0H`0`]````JB@!`&4```#H*`$`30```$XI`0`O````G"D!`"X```#,
M*0$`,````/LI`0!4````+"H!`%H```"!*@$`2````-PJ`0!*````)2L!`#(`
M``!P*P$`+P```*,K`0`L````TRL!`"T`````+`$`<0```"XL`0!F````H"P!
M`&\````'+0$`LP```'<M`0`7````*RX!`"4```!#+@$`,@```&DN`0`I````
MG"X!`#X```#&+@$`(@````4O`0!2````*"\!`"4```![+P$`"P```*$O`0"Q
M````K2\!`$4```!?,`$`(0```*4P`0`P````QS`!`"4```#X,`$`'````!XQ
M`0`Q````.S$!``<```!M,0$`!P```'4Q`0`$````?3$!``T```"",0$`"P``
M`)`Q`0`.````G#$!``L```"K,0$`!0```+<Q`0`0````O3$!``(```#.,0$`
M60```-$Q`0`%````*S(!`!(````Q,@$`!````$0R`0`'````23(!``@```!1
M,@$`!0```%HR`0`P````8#(!``,```"1,@$`$````)4R`0`,````IC(!`!,`
M``"S,@$`#0```,<R`0`"````U3(!``<```#8,@$`!@```.`R`0`4````YS(!
M``P```#\,@$`&`````DS`0`&````(C,!`!(````I,P$`#````#PS`0`#````
M23,!`"H```!-,P$`!````'@S`0`&````?3,!``<```"$,P$`'P```(PS`0`U
M````K#,!`"X```#B,P$`+P```!$T`0`7````030!`"(```!9-`$`)0```'PT
M`0`@````HC0!`!L```##-`$`&````-\T`0`D````^#0!`!\````=-0$`&@``
M`#TU`0`A````6#4!`"````!Z-0$`&@```)LU`0`R````MC4!`!H```#I-0$`
M+P````0V`0`K````-#8!`!\```!@-@$`(P```(`V`0`?````I#8!`!H```#$
M-@$`(0```-\V`0`E`````3<!`"8````G-P$`)0```$XW`0`D````=#<!`!@`
M``"9-P$`'0```+(W`0`D````T#<!`!@```#U-P$`(@````XX`0`L````,3@!
M`"\```!>.`$`%0```(XX`0`E````I#@!`#P```#*.`$`'P````<Y`0`C````
M)SD!`!\```!+.0$`(````&LY`0`:````C#D!`!@```"G.0$`*0```,`Y`0`>
M````ZCD!`"D````).@$`'@```#,Z`0`Q````4CH!``D```"$.@$`#````(XZ
M`0`7````FSH!`"\```"S.@$`)````.,Z`0`'````"#L!``\````0.P$`%```
M`"`[`0`.````-3L!``T```!$.P$`)````%([`0`%````=SL!``<```!].P$`
M(@```(4[`0`E````J#L!`!H```#..P$`'0```.D[`0`:````!SP!``<````B
M/`$`QP```"H\`0`+````\CP!`!4```#^/`$`!@```!0]`0`)````&ST!``L`
M```E/0$`#0```#$]`0`7````/ST!``8```!7/0$`,P```%X]`0`3````DCT!
M`!,```"F/0$`!P```+H]`0`/````PCT!``<```#2/0$`,@```-H]`0`$````
M#3X!`"$````2/@$`$P```#0^`0`,````2#X!`!$```!5/@$`,@```&<^`0`6
M````FCX!``@```"Q/@$`'0```+H^`0`)````V#X!``H```#B/@$`%````.T^
M`0`*`````C\!`!T````-/P$`"````"L_`0`?````-#\!``@```!4/P$`&@``
M`%T_`0`G````>#\!``8```"@/P$`%0```*<_`0`'````O3\!``@```#%/P$`
M"0```,X_`0`_````V#\!``<````80`$`#P```"!``0`.````,$`!`!`````_
M0`$`"0```%!``0`)````6D`!``@```!D0`$`$P```&U``0`'````@4`!`!D`
M``")0`$`"@```*-``0`7````KD`!`!0```#&0`$`"@```-M``0`,````YD`!
M`!<```#S0`$`!`````M!`0`J````$$$!``P````[00$`$0```$A!`0`'````
M6D$!``(```!B00$`$````&5!`0`8````=D$!``L```"/00$``P```)M!`0`(
M````GT$!``8```"H00$`!P```*]!`0`-````MT$!``L```#%00$`%````-%!
M`0`5````YD$!``X```#\00$`+P````M"`0`@````.T(!`!P```!<0@$`%0``
M`'E"`0`,````CT(!`#$```"<0@$`!0```,Y"`0`2````U$(!`#\```#G0@$`
M$@```"=#`0`*````.D,!``8```!%0P$`!````$Q#`0`$````44,!``H```!6
M0P$`$P```&%#`0`%````=4,!``8```![0P$`!@```()#`0`(````B4,!``0`
M``"20P$`#````)=#`0`*````I$,!`#D```"O0P$`+@```.E#`0`I````&$0!
M``4```!"1`$`&````$A$`0`9````840!`!\```![1`$`'0```)M$`0`1````
MN40!``(```#+1`$`!````,Y$`0`*````TT0!``8```#>1`$`!0```.5$`0`#
M````ZT0!``P```#O1`$`10```/Q$`0`R````0D4!`!H```!U10$`-````)!%
M`0`H````Q44!`%,```#N10$`&0```$)&`0!R````7$8!`"````#/1@$`-0``
M`/!&`0`A````)D<!`$4```!(1P$`,````(Y'`0`H````OT<!`"D```#H1P$`
M)@```!)(`0`E````.4@!`"@```!?2`$`*````(A(`0`B````L4@!`"L```#4
M2`$`,`````!)`0`2````,4D!`!,```!$20$`$````%A)`0!Y````:4D!``D`
M``#C20$`H0```.U)`0!S````CTH!`'P````#2P$`*P```(!+`0!4````K$L!
M`!<````!3`$`)P```!E,`0`6````04P!``\```!83`$`%P```&A,`0`?````
M@$P!`$````"@3`$`'P```.%,`0`<`````4T!`%$````>30$`&@```'!-`0`4
M````BTT!``H```"@30$`!0```*M-`0`&````L4T!``@```"X30$`!0```,%-
M`0`2````QTT!`!````#:30$`$P```.M-`0`=````_TT!``\````=3@$`#P``
M`"U.`0`$````/4X!``D```!"3@$`"P```$Q.`0`'````6$X!``4```!@3@$`
M%````&9.`0`'````>TX!``@```"#3@$`#P```(Q.`0`(````G$X!``P```"E
M3@$`#P```+).`0`&````PDX!`!0```#)3@$`!@```-Y.`0`,````Y4X!`!$`
M``#R3@$`"`````1/`0`$````#4\!`!D````23P$`$0```"Q/`0`*````/D\!
M`!@```!)3P$`$P```&)/`0`<````=D\!`!$```"33P$`!````*5/`0`/````
MJD\!``<```"Z3P$`!````,)/`0`9````QT\!``<```#A3P$``@```.E/`0`"
M````[$\!`!$```#O3P$`"0````%0`0`&````"U`!`!(````24`$`%P```"50
M`0`&````/5`!`"<```!$4`$``@```&Q0`0`$````;U`!``\```!T4`$`$P``
M`(10`0`'````F%`!``<```"@4`$`$0```*A0`0`&````NE`!`!@```#!4`$`
M!@```-I0`0`3````X5`!`!````#U4`$`$@````91`0`"````&5$!``8````<
M40$`#````"-1`0`)````,%$!`!$````Z40$`(@```$Q1`0`'````;U$!``<`
M``!W40$`"P```']1`0`%````BU$!``(```"140$`"P```)11`0!]`0``H%$!
M``\````>4P$`$@```"Y3`0`-````05,!``8```!/4P$`"0```%93`0`'````
M8%,!``,```!H4P$`&0```&Q3`0`?````AE,!`#(```"F4P$`+P```-E3`0`H
M````"50!`"T````R5`$`&0```&!4`0`K````>E0!``H```"F5`$`+@```+%4
M`0`6````X%0!``H```#W5`$`%`````)5`0`%````%U4!`"X````=50$`$P``
M`$Q5`0`+````8%4!`!H```!L50$`#0```(=5`0`.````E54!`)D```"D50$`
M#0```#Y6`0`*````3%8!`!<```!75@$`#@```&]6`0`1````?E8!``P```"0
M5@$`%@```)U6`0`,````M%8!``8```#!5@$`G0```,A6`0`*````9E<!``\`
M``!Q5P$`%0```(%7`0`1````EU<!`!,```"I5P$`$P```+U7`0`(````T5<!
M``D```#:5P$`-@```.17`0`D````&U@!`#@```!`6`$`0P```'E8`0!E````
MO5@!`&(````C60$`:P```(99`0!H````\ED!`#H```!;6@$`#P```)9:`0`5
M````IEH!``X```"\6@$`$P```,M:`0`9````WUH!``4```#Y6@$`"0```/]:
M`0`1````"5L!``P````;6P$`#0```"A;`0`-````-EL!`#0```!$6P$`,0``
M`'E;`0`)````JUL!`!0```"U6P$`%````,I;`0`,````WUL!``8```#L6P$`
M&0```/-;`0`>````#5P!``P````L7`$`#````#E<`0`1````1EP!`",```!8
M7`$`*````'Q<`0`2````I5P!``X```"X7`$`#P```,=<`0`*````UUP!`"\`
M``#B7`$`&0```!)=`0`9````+%T!``X```!&70$`7````%5=`0`Z````LET!
M`"H```#M70$`"0```!A>`0`+````(EX!`#0````N7@$`#@```&->`0`(````
M<EX!``H```![7@$`!P```(9>`0`'````CEX!``4```"67@$`!P```)Q>`0`+
M````I%X!``4```"P7@$`(0```+9>`0`0````V%X!`!4```#I7@$`#P```/]>
M`0`;````#U\!`#0````K7P$`"0```&!?`0`7````:E\!`!8```""7P$`&```
M`)E?`0`A````LE\!`!<```#47P$`$0```.Q?`0`/````_E\!`!\````.8`$`
M)0```"Y@`0`'````5&`!``8```!<8`$`!P```&-@`0`-````:V`!``D```!Y
M8`$`"0```(-@`0`2````C6`!``H```"@8`$`%0```*M@`0`9````P6`!`"P`
M``#;8`$`!P````AA`0`1````$&$!``4````B80$`%@```"AA`0`2````/V$!
M`!(```!280$`/@```&5A`0`^````I&$!``D```#C80$`!P```.UA`0`3````
M]6$!``0````)8@$`!0````YB`0`.````%&(!``X````C8@$`%P```#)B`0!'
M````2F(!`!8```"28@$`)@```*EB`0`K````T&(!`"P```#\8@$`-````"EC
M`0`)````7F,!``8```!H8P$`"0```&]C`0`'````>6,!`#@```"!8P$`.@``
M`+IC`0`W````]6,!`%P````M9`$`-@```(ID`0`V````P60!`$<```#X9`$`
M2P```$!E`0`V````C&4!`$X```##90$`+````!)F`0`N````/V8!`$T```!N
M9@$`-@```+QF`0`\````\V8!`"X````P9P$`&````%]G`0`<````>&<!`#,`
M``"59P$`+0```,EG`0`M````]V<!`!,````E:`$`"@```#EH`0`,````1&@!
M``4```!1:`$`#@```%=H`0`?````9F@!`"8```"&:`$`!P```*UH`0`'````
MM6@!`!4```"]:`$`"@```--H`0`(````WF@!`#,```#G:`$`"@```!MI`0`'
M````)FD!``<````N:0$`!@```#9I`0`%````/6D!``@```!#:0$`!@```$QI
M`0`*````4VD!`#0```!>:0$`$@```)-I`0`.````IFD!``<```"U:0$`!P``
M`+UI`0`*````Q6D!``4```#0:0$`$0```-9I`0`&````Z&D!`!(```#O:0$`
M!0````)J`0`(````"&H!``@````1:@$`#@```!IJ`0`&````*6H!`"D````P
M:@$`$0```%IJ`0`(````;&H!`!$```!U:@$`#````(=J`0`'````E&H!``,`
M``"<:@$``P```*!J`0`:````I&H!`!@```"_:@$`*@```-AJ`0`&`````VL!
M``4````*:P$`!P```!!K`0`'````&&L!`$@````@:P$`3P```&EK`0!E````
MN6L!`"<````?;`$`.````$=L`0`I````@&P!`"(```"J;`$`!@```,UL`0`(
M````U&P!`!T```#=;`$`)0```/ML`0`G````(6T!`#0```!);0$`*````'YM
M`0`M````IVT!`&(```#5;0$`-@```#AN`0`*````;VX!``D```!Z;@$`"0``
M`(1N`0`6````CFX!``P```"E;@$`#@```+)N`0`4````P6X!`!````#6;@$`
M%````.=N`0`3````_&X!``X````0;P$`%0```!]O`0`'````-6\!`!@````]
M;P$`&P```%9O`0`8````<F\!`!L```"+;P$`&0```*=O`0`$````P6\!``<`
M``#&;P$`%````,YO`0!8````XV\!`'(````\<`$`!P```*]P`0`5````MW`!
M``4```#-<`$`!0```--P`0`;````V7`!`!@```#U<`$`"P````YQ`0`4````
M&G$!`!H````O<0$`'@```$IQ`0`[````:7$!``X```"E<0$`+````+1Q`0`'
M````X7$!`!L```#I<0$`#P````5R`0`2````%7(!``X````H<@$`&````#=R
M`0`0````4'(!`!8```!A<@$`$P```'AR`0`.````C'(!``4```";<@$`#P``
M`*%R`0`&````L7(!`!@```"X<@$`%0```-%R`0`/````YW(!``@```#W<@$`
M!0````!S`0`1````!G,!`!(````8<P$`"0```"MS`0`7````-7,!``8```!-
M<P$`!P```%1S`0`1````7',!``H```!N<P$`#````'ES`0`'````AG,!``@`
M``".<P$`"P```)=S`0`)````HW,!``L```"M<P$`'P```+ES`0!)````V7,!
M`"4````C=`$`#0```$ET`0`4````5W0!``4```!L=`$`(````')T`0`2````
MDW0!`!,```"F=`$`.@```+IT`0!*````]70!`"<```!`=0$`"0```&AU`0`\
M````<G4!`"H```"O=0$`$0```-IU`0`)````['4!``H```#V=0$`!@````%V
M`0`&````"'8!`!(````/=@$`$````")V`0`+````,W8!``H````_=@$`#P``
M`$IV`0`L````6G8!`"P```"'=@$`+0```+1V`0`N````XG8!`"(````1=P$`
M)0```#1W`0`B````6G<!`"8```!]=P$`-@```*1W`0`N````VW<!`"8````*
M>`$`*````#%X`0`D````6G@!`#$```!_>`$`10```+%X`0!`````]W@!`#4`
M```X>0$`-````&YY`0`^````HWD!`"8```#B>0$`)0````EZ`0`\````+WH!
M`"4```!L>@$`%0```))Z`0`Y````J'H!`"4```#B>@$`)P````A[`0`4````
M,'L!`,H```!%>P$`&P```!!\`0`Q````+'P!`#````!>?`$`,P```(]\`0`Q
M````PWP!`"<```#U?`$`*````!U]`0`K````1GT!`#(```!R?0$`-0```*5]
M`0!+````VWT!`#0````G?@$`I````%Q^`0`G`````7\!`!T````I?P$`)@``
M`$=_`0`S````;G\!`#$```"B?P$`3@```-1_`0!5````(X`!``T```!Y@`$`
M!````(>``0`&````C(`!``4```"3@`$`#P```)F``0`%````J8`!`!$```"O
M@`$`%@```,&``0`<````V(`!``<```#U@`$`!````/V``0`0`````H$!`!$`
M```3@0$`"P```"6!`0`*````,8$!`!$````\@0$`#0```$Z!`0`2````7($!
M``T```!O@0$`.@```'V!`0`&````N($!`!````"_@0$`!@```-"!`0`1````
MUX$!`!<```#I@0$`&P````&"`0`/````'8(!``(````M@@$`20```#""`0`+
M````>H(!``P```"&@@$`'````)."`0`%````L((!`!<```"V@@$`$@```,Z"
M`0`#````X8(!`!$```#E@@$`"0```/>"`0`1`````8,!`!`````3@P$`"P``
M`"2#`0`1````,(,!`!4```!"@P$`$0```%B#`0`,````:H,!`!0```!W@P$`
M#@```(R#`0`.````FX,!`!$```"J@P$`$P```+R#`0`:````T(,!``X```#K
M@P$`$````/J#`0`K````"X0!`!$````WA`$`'````$F$`0!$````9H0!``T`
M``"KA`$`'P```+F$`0`4````V80!`!D```#NA`$`%@````B%`0!#````'X4!
M`!````!CA0$`"0```'2%`0`4````?H4!``L```"3A0$`-@```)^%`0`U````
MUH4!``H````,A@$`%0```!>&`0`I````+88!`!<```!7A@$`%@```&^&`0`6
M````AH8!``H```"=A@$`(````*B&`0`9````R88!`!P```#CA@$`&`````"'
M`0`9````&8<!`!@````SAP$`"````$R'`0`+````58<!`"D```!AAP$`6```
M`(N'`0`(````Y(<!`!0```#MAP$`(@````*(`0`)````)8@!``P````OB`$`
M-@```#R(`0`1````<X@!``8```"%B`$`!@```(R(`0!5````DX@!``,```#I
MB`$`!P```.V(`0`5````]8@!`!`````+B0$`#P```!R)`0`4````+(D!`!4`
M``!!B0$`&P```%>)`0`6````<XD!`!T```"*B0$`&P```*B)`0`)````Q(D!
M``8```#.B0$`"P```-6)`0`+````X8D!``(```#MB0$`!@```/")`0`3````
M]XD!`"\````+B@$`%P```#N*`0`5````4XH!``H```!IB@$`$0```'2*`0`4
M````AHH!`!P```";B@$`.0```+B*`0`W````\HH!`!(````JBP$`#P```#V+
M`0"&````38L!`",```#4BP$`(````/B+`0`1````&8P!``<````KC`$`!0``
M`#.,`0`<````.8P!`"T```!6C`$`,P```(2,`0`?````N(P!`"4```#8C`$`
M'P```/Z,`0`7````'HT!``<````VC0$`!P```#Z-`0`&````1HT!``8```!-
MC0$`#P```%2-`0`.````9(T!`!````!SC0$`#@```(2-`0`5````DXT!``\`
M``"IC0$`"P```+F-`0`3````Q8T!``@```#9C0$`"````.*-`0`5````ZXT!
M``\````!C@$`10```!&.`0`4````5XX!``D```!LC@$`#@```':.`0`?````
MA8X!`"````"EC@$`)P```,:.`0`F````[HX!`!@````5CP$`%P```"Z/`0`@
M````1H\!`!@```!GCP$`%@```("/`0`)````EX\!`!D```"ACP$`"P```+N/
M`0`4````QX\!``,```#<CP$`!0```."/`0`'````YH\!``X```#NCP$`$```
M`/V/`0`-````#I`!`!@````<D`$`$````#60`0`1````1I`!``\```!8D`$`
M!````&B0`0`'````;9`!`!H```!UD`$`&P```)"0`0`(````K)`!`!$```"U
MD`$`%````,>0`0`.````W)`!`"<```#KD`$`!P```!.1`0`)````&Y$!`!``
M```ED0$`$````#:1`0`*````1Y$!``<```!2D0$`"P```%J1`0`&````9I$!
M`!@```!MD0$`#@```(:1`0`&````E9$!`"@```"<D0$`$````,61`0";````
MUI$!`!L```!RD@$`"P```(Z2`0`'````FI(!``\```"BD@$`"````+*2`0`*
M````NY(!``4```#&D@$`"````,R2`0`#````U9(!``8```#9D@$`!P```."2
M`0`6````Z)(!`!````#_D@$`$@```!"3`0`=````(Y,!``(```!!DP$`!```
M`$23`0`4````29,!``H```!>DP$`#P```&F3`0`%````>9,!`",```!_DP$`
M"````*.3`0`&````K),!`!L```"SDP$`#P```,^3`0`'````WY,!``@```#G
MDP$`!0```/"3`0`)````]I,!``\`````E`$`$0```!"4`0`"````(I0!``8`
M```EE`$`#P```"R4`0`2````/)0!`!````!/E`$`!@```&"4`0`3````9Y0!
M``L```![E`$`!P```(>4`0`8````CY0!`#````"HE`$`30```-F4`0`K````
M)Y4!`"T```!3E0$`!@```(&5`0`)````B)4!``0```"2E0$`"0```)>5`0`)
M````H94!`!<```"KE0$`#````,.5`0`&````T)4!``T```#7E0$`!P```.65
M`0`$````[94!`$$```#RE0$`2````#26`0!!````?98!`"<```"_E@$`!0``
M`.>6`0`-````[98!``<```#[E@$`"`````.7`0`)````#)<!`!L````6EP$`
M&0```#*7`0`5````3)<!``8```!BEP$`!0```&F7`0`0````;Y<!``@```"`
MEP$`"@```(F7`0`C````E)<!``0```"XEP$`!P```+V7`0`G````Q9<!``8`
M``#MEP$`"0```/27`0`3````_I<!`!,````2F`$`"````":8`0`)````+Y@!
M``4````YF`$`1P```#^8`0`T````AY@!`$$```"\F`$`,@```/Z8`0!)````
M,9D!`#L```![F0$`+````+>9`0`^````Y)D!`"\````CF@$`/0```%.:`0`Q
M````D9H!`!````##F@$`$0```-2:`0`+````YIH!`#(```#RF@$`(0```"6;
M`0`?````1YL!`!X```!GFP$`!P```(:;`0`)````CIL!``H```"8FP$`!P``
M`*.;`0`I````JYL!`"P```#5FP$`/0````*<`0`,````0)P!`",```!-G`$`
M-@```'&<`0`6````J)P!`!4```"_G`$`"````-6<`0`+````WIP!``P```#J
MG`$`$````/><`0`7````")T!`$4````@G0$`?````&:=`0!G````XYT!``T`
M``!+G@$`$````%F>`0`1````:IX!`!0```!\G@$`%0```)&>`0`7````IYX!
M``@```"_G@$`$0```,B>`0`3````VIX!`!(```#NG@$`%0````&?`0`N````
M%Y\!`"T```!&GP$`EP```'2?`0`1````#*`!``4````>H`$`%0```"2@`0`)
M````.J`!``L```!$H`$`"P```%"@`0`E````7*`!`!@```""H`$`#P```)N@
M`0`.````JZ`!`!0```"ZH`$`&0```,^@`0`M````Z:`!`"X````7H0$`*@``
M`$:A`0`J````<:$!`"8```"<H0$`*````,.A`0`>````[*$!`$$````+H@$`
M%0```$VB`0`4````8Z(!`!<```!XH@$`%@```)"B`0`1````IZ(!`!<```"Y
MH@$`%@```-&B`0`4````Z*(!`!0```#]H@$`.P```!*C`0`9````3J,!`!H`
M``!HHP$`.@```(.C`0`3````OJ,!``8```#2HP$`$````-FC`0`M````ZJ,!
M`!0````8I`$`%0```"VD`0`5````0Z0!`"````!9I`$`'@```'JD`0`<````
MF:0!`!P```"VI`$`)P```-.D`0`3````^Z0!`"`````/I0$`)@```#"E`0`@
M````5Z4!`!D```!XI0$`'0```)*E`0`4````L*4!`!P```#%I0$`'````.*E
M`0`A````_Z4!`!D````AI@$`"@```#NF`0`2````1J8!`!L```!9I@$`!```
M`'6F`0`'````>J8!``L```""I@$`$@```(ZF`0`&````H:8!``8```"HI@$`
M!P```*^F`0`&````MZ8!``<```"^I@$`!0```,:F`0`%````S*8!`!4```#2
MI@$`!@```.BF`0`&````[Z8!``4```#VI@$`!0```/RF`0`*`````J<!`!$`
M```-IP$`"@```!^G`0`6````*J<!`!0```!!IP$`"@```%:G`0`7````8:<!
M``4```!YIP$`-0```'^G`0`2````M:<!`!$```#(IP$`&@```-JG`0`/````
M]:<!``T````%J`$`$````!.H`0`T````)*@!``4```!9J`$`"````%^H`0`G
M````:*@!`!,```"0J`$`$````*2H`0`&````M:@!``H```"\J`$`#0```,>H
M`0`&````U:@!`"(```#<J`$`$````/^H`0`;````$*D!`!`````LJ0$`%0``
M`#VI`0`1````4ZD!`!H```!EJ0$`%````("I`0`&````E:D!``4```"<J0$`
M#````**I`0`F````KZD!``<```#6J0$`"0```-ZI`0`2````Z*D!`!<```#[
MJ0$`!P```!.J`0`%````&ZH!``<````AJ@$`%@```"FJ`0`-````0*H!``\`
M``!.J@$`#0```%ZJ`0`6````;*H!`!@```"#J@$`#P```)RJ`0`1````K*H!
M``P```"^J@$`&````,NJ`0`,````Y*H!``<```#QJ@$`%````/FJ`0!"````
M#JL!``@```!1JP$`#````%JK`0`M````9ZL!`!4```"5JP$`%0```*NK`0`-
M````P:L!``P```#/JP$`"0```-RK`0`'````YJL!``H```#NJP$`"0```/FK
M`0`.`````ZP!`!`````2K`$`*0```".L`0`E````3:P!`"H```!SK`$`"@``
M`)ZL`0`(````J:P!``H```"RK`$`#````+VL`0`-````RJP!``D```#8K`$`
M#@```.*L`0`U````\:P!``4````GK0$`#@```"VM`0`:````/*T!`%T```!7
MK0$`&@```+6M`0`.````T*T!``0```#?K0$`!````.2M`0`:````Z:T!`!H`
M```$K@$`&@```!^N`0`*````.JX!``(```!%K@$`!````$BN`0`E````3:X!
M``,```!SK@$`!0```'>N`0`I````?:X!``H```"GK@$`!0```+*N`0`&````
MN*X!``L```"_K@$`$0```,NN`0`&````W:X!``<```#DK@$`"````.RN`0`$
M````]:X!``4```#ZK@$`:P````"O`0`*````;*\!``T```!WKP$`'0```(6O
M`0`%````HZ\!``8```"IKP$`*0```+"O`0`V````VJ\!``X````1L`$`"0``
M`""P`0`3````*K`!``H````^L`$`"````$FP`0`7````4K`!`#@```!JL`$`
M'P```*.P`0`>````P[`!`",```#BL`$`#P````:Q`0`$````%K$!``<````;
ML0$`"````".Q`0`(````++$!`!$````UL0$`#P```$>Q`0`'````5[$!`&$`
M``!?L0$`$0```,&Q`0`/````T[$!``\```#CL0$`&P```/.Q`0!1````#[(!
M`!P```!AL@$`!@```'ZR`0`?````A;(!`"8```"EL@$`!P```,RR`0`&````
MU+(!`"````#;L@$`"````/RR`0`)````!;,!`"$````/LP$`(````#&S`0`\
M````4K,!``@```"/LP$`"@```)BS`0`G````H[,!`%0```#+LP$`&P```""T
M`0`?````/+0!`!H```!<M`$``P```'>T`0`,````>[0!``@```"(M`$`&0``
M`)&T`0`-````J[0!``8```"YM`$`%@```,"T`0`&````U[0!``@```#>M`$`
M"0```.>T`0`,````\;0!``H```#^M`$`$`````FU`0!!````&K4!``D```!<
MM0$`&@```&:U`0`7````@;4!`"$```"9M0$`&````+NU`0`5````U+4!`!@`
M``#JM0$`%@````.V`0`6````&K8!`!4````QM@$`%@```$>V`0`*````7K8!
M`!\```!IM@$`$````(FV`0`2````FK8!``D```"MM@$`#````+>V`0`)````
MQ+8!`!D```#.M@$`!P```.BV`0`7````\+8!``8````(MP$`!P````^W`0`%
M````%[<!``4````=MP$`!P```".W`0`3````*[<!`!0````_MP$`(@```%2W
M`0`B````=[<!`!T```":MP$`'````+BW`0`B````U;<!`"8```#XMP$`'P``
M`!^X`0`#````/[@!``4```!#N`$`#P```$FX`0`/````6;@!``H```!IN`$`
M(@```'2X`0`-````E[@!`!````"EN`$`(P```+:X`0`=````VK@!`!8```#X
MN`$`"`````^Y`0`.````&+D!``D````GN0$`$````#&Y`0`3````0KD!``H`
M``!6N0$`"0```&&Y`0`%````:[D!``<```!QN0$`!0```'FY`0`$````?[D!
M``(```"$N0$`-P```(>Y`0`[````O[D!`!D```#[N0$`)@```!6Z`0!&````
M/+H!``P```"#N@$`-````)"Z`0`[````Q;H!`$0````!NP$`1````$:[`0!,
M````B[L!``\```#8NP$`(````.B[`0`?````";P!`!P````IO`$`'P```$:\
M`0`?````9KP!`"````"&O`$`(````*>\`0`@````R+P!``P```#IO`$`00``
M`/:\`0!!````.+T!`$4```!ZO0$`1@```,"]`0!#````![X!`$````!+O@$`
M>0```(R^`0`5````!K\!`!`````<OP$`"0```"V_`0`C````-[\!``<```!;
MOP$`%````&._`0`Z````>+\!`#@```"SOP$`)````.R_`0`+````$<`!`%,`
M```=P`$`2@```''``0`'````O,`!`!<```#$P`$`%0```-S``0`/````\L`!
M`!`````"P0$`&````!/!`0`'````+,$!``H````TP0$`"````#_!`0`3````
M2,$!`!````!<P0$`#@```&W!`0`2````?,$!``4```"/P0$`)````)7!`0`)
M````NL$!``8```#$P0$`%````,O!`0`2````X,$!``\```#SP0$`2`````/"
M`0`'````3,(!``8```!4P@$`$@```%O"`0`%````;L(!``<```!TP@$`#P``
M`'S"`0`'````C,(!`#4```"4P@$`$@```,K"`0`E````W<(!``0````#PP$`
M.P````C#`0`.````1,,!`"@```!3PP$`AP```'S#`0`:````!,0!`$4````?
MQ`$`)P```&7$`0`1````C<0!``@```"?Q`$`#@```*C$`0`.````M\0!``P`
M``#&Q`$`$P```-/$`0`,````Y\0!`"````#TQ`$`'````!7%`0`$````,L4!
M`!`````WQ0$`&P```$C%`0`J````9,4!`!4```"/Q0$`$0```*7%`0`6````
MM\4!`!$```#.Q0$`'P```.#%`0`*`````,8!``P````+Q@$`$P```!C&`0`1
M````+,8!`!<````^Q@$`$````%;&`0`<````9\8!``X```"$Q@$`%0```)/&
M`0`B````J<8!``T```#,Q@$`!@```-K&`0`(````X<8!``4```#JQ@$`(```
M`/#&`0`&````$<<!`!(````8QP$`"````"O'`0`3````-,<!``H```!(QP$`
M*````%/'`0`5````?,<!`$$```"2QP$`&P```-3'`0`+````\,<!``P```#\
MQP$`)0````G(`0`%````+\@!`!8````UR`$``P```$S(`0`1````4,@!``4`
M``!BR`$`"@```&C(`0`E````<\@!`#D```"9R`$`"@```-/(`0`F````WL@!
M`!,````%R0$`"P```!G)`0`=````)<D!`!0```!#R0$`!````%C)`0`(````
M7<D!``D```!FR0$`"````'#)`0`+````><D!``@```"%R0$`!P```([)`0`'
M````ELD!`!(```">R0$`*@```+')`0`W````W,D!`!L````4R@$`*P```##*
M`0`C````7,H!`$$```"`R@$`&P```,+*`0`D````WLH!`"T````#RP$`3```
M`#'+`0`H````?LL!``<```"GRP$`"````*_+`0`)````N,L!``@```#"RP$`
M%0```,O+`0`4````X<L!`"P```#VRP$`+P```"/,`0`B````4\P!`#<```!V
MS`$`/P```*[,`0`'````[LP!`!H```#VS`$`"0```!'-`0`,````&\T!`"X`
M```HS0$`$P```%?-`0`2````:\T!``T```!^S0$`"P```(S-`0`8````F,T!
M``D```"QS0$`$@```+O-`0`1````SLT!`!H```#@S0$`'````/O-`0`Y````
M&,X!``L```!2S@$`$````%[.`0`%````;\X!``@```!US@$`!0```'[.`0`:
M````A,X!``\```"?S@$`!@```*_.`0`/````MLX!`!$```#&S@$`"````-C.
M`0`.````X<X!``X```#PS@$`$P```/_.`0`%````$\\!`!`````9SP$`#0``
M`"K/`0`\````.,\!`%(```!USP$`(@```,C/`0`*````Z\\!`"<```#VSP$`
M&P```![0`0`%````.M`!`!<```!`T`$`"0```%C0`0`-````8M`!`!(```!P
MT`$`*@```(/0`0`&````KM`!``T```"UT`$`#@```,/0`0`0````TM`!``H`
M``#CT`$`/0```.[0`0`)````+-$!`"`````VT0$`$````%?1`0`4````:-$!
M`$````!]T0$`)@```+[1`0!"````Y=$!`$,````HT@$`/````&S2`0`/````
MJ=(!``<```"YT@$`$@```,'2`0`2````U-(!`!D```#GT@$`"@````'3`0`3
M````#-,!`!L````@TP$`!P```#S3`0`7````1-,!`"@```!<TP$`!@```(73
M`0`'````C-,!`!````"4TP$`%0```*73`0`7````N],!``<```#3TP$`!P``
M`-O3`0`)````X],!`!0```#MTP$`$@````+4`0`3````%=0!`!,````IU`$`
M!@```#W4`0`%````1-0!`#$```!*U`$`*````'S4`0`E````I=0!``@```#+
MU`$`#P```-34`0`&````Y-0!`!H```#KU`$`&0````;5`0`K````(-4!``D`
M``!,U0$`#````%;5`0`G````8]4!``,```"+U0$`!0```(_5`0`-````E=4!
M``,```"CU0$`#````*?5`0`3````M-4!``L```#(U0$`%P```-35`0`8````
M[-4!`!,````%U@$`!0```!G6`0`*````']8!`!8````JU@$`%0```$'6`0`.
M````5]8!``<```!FU@$`#````&[6`0`*````>]8!`!````"&U@$`70```)?6
M`0`F````]=8!`#P````<UP$`$@```%G7`0`'````;-<!``8```!TUP$`"P``
M`'O7`0`4````A]<!`!0```"<UP$`'````+'7`0`?````SM<!`!8```#NUP$`
M'@````78`0`0````)-@!`"T````UV`$`%0```&/8`0`-````>=@!`&X```"'
MV`$`)````/;8`0`@````&]D!`"L````\V0$`(P```&C9`0`?````C-D!`",`
M``"LV0$`)0```-#9`0`?````]MD!`!L````6V@$`"@```#+:`0`'````/=H!
M``@```!%V@$`"@```$[:`0`3````6=H!``\```!MV@$`+0```'W:`0`8````
MJ]H!`!P```#$V@$`"````.':`0`*````ZMH!`%(```#UV@$`10```$C;`0!`
M````CML!`'@```#/VP$`#0```$C<`0`P````5MP!`#$```"'W`$`"@```+G<
M`0`'````Q-P!``T```#,W`$`.@```-K<`0`3````%=T!`$0````IW0$`+0``
M`&[=`0`G````G-T!`!````#$W0$`,@```-7=`0`C````"-X!`#,````LW@$`
M*@```&#>`0`R````B]X!`"L```"^W@$`#0```.K>`0`)````^-X!`!$````"
MWP$`$P```!3?`0`8````*-\!``<```!!WP$`-P```$G?`0`,````@=\!``0`
M``".WP$`!0```)/?`0`2````F=\!``@```"LWP$`!@```+7?`0`4````O-\!
M``H```#1WP$`"0```-S?`0`%````YM\!`!$```#LWP$`$0```/[?`0`:````
M$.`!`!P````KX`$`%0```$C@`0`A````7N`!``T```"`X`$`!P```([@`0`2
M````EN`!`"D```"IX`$`"0```-/@`0`)````W>`!`!L```#GX`$`*`````/A
M`0`.````+.$!`"$````[X0$`-````%WA`0`)````DN$!``D```"<X0$`$@``
M`*;A`0`&````N>$!``0```#`X0$`(@```,7A`0`-````Z.$!``\```#VX0$`
M#`````;B`0`(````$^(!``D````<X@$`"````";B`0`)````+^(!``T````Y
MX@$`$@```$?B`0`&````6N(!`!D```!AX@$`%0```'OB`0`'````D>(!`!``
M``"9X@$`(````*KB`0`,````R^(!``,```#8X@$`)0```-SB`0`&`````N,!
M``8````)XP$`>P```!#C`0`)````C.,!``4```"6XP$`+````)SC`0!&````
MR>,!`",````0Y`$`+P```#3D`0!0````9.0!`#H```"UY`$`/0```/#D`0`D
M````+N4!`"````!3Y0$`!0```'3E`0`'````>N4!``@```""Y0$`"0```(OE
M`0`'````E>4!``@```"=Y0$`$@```*;E`0`*````N>4!``D```#$Y0$`"P``
M`,[E`0`+````VN4!``<```#FY0$`!P```.[E`0`(````]N4!`!0```#_Y0$`
M"P```!3F`0`&````(.8!``4````GY@$`)````"WF`0`&````4N8!`"T```!9
MY@$`&````(?F`0`(````H.8!`!0```"IY@$`"0```+[F`0`3````R.8!``L`
M``#<Y@$`%````.CF`0`%````_>8!`!0````#YP$`!@```!CG`0`:````'^<!
M``H````ZYP$`'````$7G`0`(````8N<!``8```!KYP$`$@```'+G`0`D````
MA><!``L```"JYP$`#0```+;G`0`J````Q.<!`"$```#OYP$`'````!'H`0`%
M````+N@!``H````TZ`$`$P```#_H`0`8````4^@!``,```!LZ`$`$P```'#H
M`0`)````A.@!`"0```".Z`$`*````+/H`0`S````W.@!`"@````0Z0$`-0``
M`#GI`0`O````;^D!`&0```"?Z0$`%@````3J`0!<````&^H!`#H```!XZ@$`
M20```+/J`0!K````_>H!`"H```!IZP$`00```)3K`0`Q````UNL!`#<````(
M[`$`'0```$#L`0!"````7NP!`-,!``"A[`$`(@```'7N`0`7````F.X!`$P`
M``"P[@$`@````/WN`0`W````?N\!`"P```"V[P$`/P```./O`0!>````(_`!
M`$H```""\`$`*@```,WP`0`B````^/`!`!0````;\0$`'P```##Q`0`A````
M4/$!`"````!R\0$`*P```)/Q`0`D````O_$!`",```#D\0$`/@````CR`0`B
M````1_(!`!4```!J\@$`-P```(#R`0`F````N/(!`"P```#?\@$`*P````SS
M`0`:````./,!`"T```!3\P$`:0```('S`0`V````Z_,!`$D````B]`$`-P``
M`&ST`0`M````I/0!`$````#2]`$`<````!/U`0!2````A/4!`#4```#7]0$`
M-P````WV`0`T````1?8!`&L```!Z]@$`<P```.;V`0!:````6O<!`%D```"U
M]P$`-P````_X`0`I````1_@!`"D```!Q^`$`+P```)OX`0!Y````R_@!`&X`
M``!%^0$`=P```+3Y`0#$````+/H!`!8```#Q^@$`)P````C[`0`X````,/L!
M`"\```!I^P$`30```)G[`0`J````Y_L!`&,````2_`$`(P```';\`0`+````
MFOP!`*@```"F_`$`2@```$_]`0`I````FOT!`#@```#$_0$`*@```/W]`0`C
M````*/X!`#T```!,_@$`!@```(K^`0`+````D?X!``0```"=_@$`"@```*+^
M`0`/````K?X!`!$```"]_@$`"P```,_^`0`&````V_X!`!$```#B_@$`!```
M`/3^`0!F````^?X!``,```!@_P$`%````&3_`0`$````>?\!``<```!^_P$`
M!@```(;_`0`%````C?\!`#0```"3_P$`"````,C_`0`5````T?\!``P```#G
M_P$`$0```/3_`0`1````!@`"``,````8``(`!0```!P``@`'````(@`"`!(`
M```J``(`#````#T``@`4````2@`"``8```!?``(`%0```&8``@`-````?``"
M``,```"*``(`+@```(X``@`$````O0`"``8```#"``(`!P```,D``@`E````
MT0`"`$<```#W``(`.````#\!`@`Y````>`$"`!@```"R`0(`)P```,L!`@`J
M````\P$"`"8````>`@(`'````$4"`@`A````8@("`"@```"$`@(`(P```*T"
M`@`@````T0("`"0```#R`@(`)@```!<#`@`B````/@,"`#8```!A`P(`'0``
M`)@#`@`S````M@,"`#D```#J`P(`)@```"0$`@`J````2P0"`"@```!V!`(`
M(P```)\$`@`H````PP0"`#(```#L!`(`*P```!\%`@`P````2P4"`"8```!\
M!0(`)````*,%`@`E````R`4"`"X```#N!0(`(````!T&`@`G````/@8"`#<`
M``!F!@(`.@```)X&`@`<````V08"`"8```#V!@(`/0```!T'`@`G````6P<"
M`"L```"#!P(`*````*\'`@`J````V`<"`"0````#"`(`'@```"@(`@!.````
M1P@"`"@```"6"`(`-P```+\(`@`N````]P@"`#D````F"0(`"0```&`)`@`0
M````:@D"`!@```!["0(`,@```)0)`@`E````QPD"``T```#M"0(`#P```/L)
M`@`6````"PH"``H````B"@(`#@```"T*`@`J````/`H"``@```!G"@(`"P``
M`'`*`@`O````?`H"`#$```"L"@(`*0```-X*`@`B````"`L"`"0````K"P(`
M"@```%`+`@#L````6PL"``P```!(#`(`%@```%4,`@`*````;`P"``T```!W
M#`(`$@```(4,`@`7````F`P"`"H```"P#`(`!@```-L,`@!2````X@P"`!H`
M```U#0(`&@```%`-`@`'````:PT"``\```!S#0(`"````(,-`@!"````C`T"
M``<```#/#0(`+0```-<-`@`:````!0X"`!,````@#@(`%````#0.`@`T````
M20X"`"````!^#@(`!P```)\.`@`D````IPX"``@```#,#@(`"0```-4.`@`7
M````WPX"``H```#W#@(`'`````(/`@`(````'P\"`"X````H#P(`!P```%</
M`@`C````7P\"`"<```"##P(`!P```*L/`@`5````LP\"``<```#)#P(`"```
M`-$/`@`)````V@\"`$````#D#P(`!P```"40`@`,````+1`"`!,````Z$`(`
M#P```$X0`@`)````7A`"``@```!H$`(`!P```'$0`@`3````>1`"``8```"-
M$`(`&@```)00`@`+````KQ`"`!H```"[$`(`%````-80`@`+````ZQ`"``T`
M``#W$`(`(`````41`@`%````)A$"`#4````L$0(`#````&(1`@`/````;Q$"
M``L```!_$0(``P```(L1`@`4````CQ$"`"(```"D$0(`"P```,<1`@`#````
MTQ$"``@```#7$0(`#````.`1`@`*````[1$"`!````#X$0(`#@````D2`@`2
M````&!("`!,````K$@(`$0```#\2`@`X````41("`"$```"*$@(`'P```*P2
M`@`A````S!("``D```#N$@(`-````/@2`@`'````+1,"`!<````U$P(`0```
M`$T3`@`3````CA,"`!,```"B$P(`"````+83`@`$````OQ,"``8```#$$P(`
M#P```,L3`@`=````VQ,"``<```#Y$P(`"`````$4`@`)````"A0"``8````4
M%`(`!@```!L4`@`5````(A0"`!0````X%`(`0@```$T4`@`S````D!0"`"D`
M``#$%`(`!0```.X4`@`;````]!0"`!T````0%0(`(P```"X5`@`G````4A4"
M`!(```!Z%0(``@```(T5`@`$````D!4"``\```"5%0(`"@```*45`@`%````
ML!4"``(```"V%0(`#0```+D5`@!(````QQ4"`#<````0%@(`%@```$@6`@`W
M````7Q8"`"P```"7%@(`6@```,06`@`7````'Q<"`(,````W%P(`)0```+L7
M`@`Z````X1<"`"(````<&`(`-@```#\8`@`X````=A@"`"T```"O&`(`+```
M`-T8`@`L````"AD"`"H````W&0(`+@```&(9`@`N````D1D"`#(```#`&0(`
M,P```/,9`@`R````)QH"`!8```!:&@(`#0```'$:`@`.````?QH"`(8```".
M&@(`"0```!4;`@"M````'QL"`'$```#-&P(`A0```#\<`@`K````Q1P"`%P`
M``#Q'`(`%````$X=`@`H````8QT"`!8```",'0(`$````*,=`@`D````M!T"
M`"(```#9'0(`0@```/P=`@`@````/QX"`!X```!@'@(`7````'\>`@`:````
MW!X"`!,```#W'@(`"@````L?`@`%````%A\"``8````<'P(`"````",?`@`%
M````+!\"`!8````R'P(`%0```$D?`@`7````7Q\"`"(```!W'P(`$````)H?
M`@`/````JQ\"``0```"['P(`#````,`?`@`.````S1\"``<```#<'P(`!@``
M`.0?`@`9````ZQ\"``\````%(`(`!@```!4@`@`5````'"`"``D````R(`(`
M#````#P@`@`4````22`"``P```!>(`(`&````&L@`@`)````A"`"``L```".
M(`(`&````)H@`@`&````LR`"``4```"Z(`(`)P```,`@`@`;````Z"`"``H`
M```$(0(`&0````\A`@`6````*2$"`"0```!`(0(`&0```&4A`@`)````?R$"
M`!4```")(0(`"````)\A`@`'````J"$"`!<```"P(0(`!P```,@A`@`"````
MT"$"``(```#3(0(`'P```-8A`@`.````]B$"``@````%(@(`%P````XB`@`9
M````)B("``<```!`(@(`*P```$@B`@`"````="("``8```!W(@(`#P```'XB
M`@`9````CB("``4```"H(@(`"@```*XB`@`3````N2("``<```#-(@(`&0``
M`-4B`@`*````[R("`!<```#Z(@(`$P```!(C`@`2````)B,"``(````Y(P(`
M!P```#PC`@`1````1","``8```!6(P(`#@```%TC`@`P````;","``D```"=
M(P(`"@```*<C`@`4````LB,"``4```#'(P(``@```,TC`@`+````T","``$`
M``#5!```'@0``#,%``!A`P```````)X!``!O`@``H@0```````"6`P``R0$`
M`/P&``!\``````````````"(`@``*@<```T!````````@@<``,$```!Y!0``
M%P0``/$%```L````W0,``,(&```D!P``"@(```,$``"^!0```P<``#,#````
M````J`(``+@&``!F`@``M`(``!$$``"#`P```````````````````````-@$
M``!3!0``AP0`````````````^`$``'("`````````````($"```P!```````
M`"4!``"F!0```````&,'``#E!0``D`8``"<!``!Q!@``]P0``'`"``!R`0``
M-`<``,0!``#3`@``,00``'$#``!/!P``6@```*0!```U`0``B@<```````!]
M`0``[0```)<&``#"!0``70<``$P%``#-!@```````)8$``!D`@``]````"L"
M``!H`@```````-T$``"%!@``WP4`````````````I0``````````````````
M`)H#````````0````.4&````````SP$```````"?!```2@(``,$%````````
M_P(``(D'````````#@4```````!1!```S04``.X"```H!0``%P`````````T
M````6````+X!`````````````+<"``!<!```9P,``&P#``!A`0``@P<`````
M`````````````/P!``!F`P``;P```-@!````````?@8````````)!P``D```
M``````!/`P``G0(````````>`P``7@8``/8!``#?````*@,``-X!``#2`0``
MN`,``$D#````````'`<``!('```G`P``\P```+(%``#4!`````````````"M
M`P``I`````````#,!0``8P,``'L#``"7!```#`0```````"+!@``P@$`````
M``#C!```>0<``-L#``#I`0```````/\%``!+!P``JP$``%H$``#F`0``````
M`$\```#``0``````````````````,0,``&T'``"(!@``L@````````":!0``
M:00``*4&``#D`0``1P8````````J````_0$``&H!``!5!P``W`,``"D&``"E
M!```508``%@$``"P!@```````)\"``!;````DP8``(T#``"I`````````*X%
M``#3````H@,``'P!``!I`@``Q`,``"D'``!]`P``*P`````````V````````
M```````S`@``@P```.8$````````^`0``'L$``!%!P```````/D`````````
M`````)4"``"\!0```````!D%``"L`P``+0(``'L'````````=@0``#T"````
M`````````)("``"0`0``C`0``-P```!]!P``604``)P#```%`@``/`<``&`#
M```(`0```````$<$````````+@<``*$#``"G`0````````````!I!0``<P$`
M````````````0P8``-L````^!P``2@`````````$`@```````"L!````````
M6`,```````">!````````,X!``!C!```&`,````````I!```80``````````
M````)P0``'<```#P`P``9P8```````"=!@````8``'L`````````&08``+,$
M```#````!`<``-X%````````RP,``'X"```7!P``[@``````````````90$`
M``````#P`@``F@```)(```"@`P```````)T!```M!0``<P(``/4#``!(`P``
MP`(``+P!``#?!```UP8``+8#``#E!```S`0``*P$````````&0<``!D"``#!
M!```&@$``+,"`````````````.0#``"1`@```````(`!``#^!0``:P$``!<&
M``#Z`0``+`,``$T#``!T`P``200``)@!``!'````R@$``',#``!/!@``.@``
M`&$&``!3````U@8``'@"````````,`4``"@"``!T!@``[P````L&```$````
MY@(``(`#``"%!0``BP$``)4$`````P``90<``.@%```9`0```````*$!```.
M!P``?0(``'X````'!```"@<``"X&```U!@```````%0"``"_`````````'D#
M```!!`````````L````U!0````````````!G!P``*`8``-T`````````]@(`
M`$`'````````V@,``-P$`````````````&@````/`@``<P8```````#4!@``
MQ@8``'$```"@````_08``$0"````````G00``+L#``#`````!@0```\&``!.
M`0``E@(``+L%``"B`0``PP$````````%`````````$T'``#8`@``8P``````
M``#$````````````````````]`0```````!"!0``<`<```````#.!@``````
M`!D#``""!@````````````!4!0````````````#U!```>00``*0&``!Q!```
M"````%X```!)!P``O`,``'@%``#>````A@,``"8$```]!0``^`8``)X#``!Y
M`@```````&P!``!``@``OP8``.\%``#`!````````'`&````````B0```*<"
M````````-`8````````=!P```````%<!```D!```.@$```````!O!```````
M`(D"``![!0``@@4``-8`````````(P(``%`&```Y!```-0(`````````````
MF0,```$%```!!P``"0,``&H&````````\P$``,8```#R`P``CP```%P'````
M`````````.@&``"'`P````````````#?`@``,`,``%D!``#U!@```````.<!
M`````0``30```,\$```2!0```````#@!``"2`P``?P$``)<```!;!```@00`
M`',```"I!0``6@(``(0"````````0@8``'@!`````@```````.D$````````
M)`````````#Z!```;00``,@$``!;`0``(P0```8```"A`@``8`(`````````
M````!`8``)8%````````X@8``)`#```^````+0$``!8"``#9`P``D@8`````
M````````;@,```````"0!```HP````````#'`P``40```+\"```N!```(@0`
M`.L$````````+08``/@"```O!@``6@4``````````````````*L"```F`P``
M``````````"U`0```````'T````I`P```````','````````DP0```````#0
M`0``\08```H!```````````````````"`0``3@4``#D&````````R@4``!,!
M``#G````_`,``)P```"R`P``Q@$```````!W!```<P0``-D"``#+!0``?@$`
M`(X!``````````````````#]!0``-P0````````_!P``I@8``-(#``"I!@``
M[P$``*8`````````\0(``````````````````*\$``#M`0``^P0``.$#```J
M!````````&@$``"?````$`8``+L$``#L`P```````,L$``!=`@``C@0`````
M``#&`@``P`4``$0%``!U!P``UP4``)0&````````9`<`````````````'00`
M``````#V`P``5````-D`````````2````)8`````````6`(``#<````@!@``
M/@(``'4"````````]0(````````*!```N0(``*<$``!X!P```````-L&```5
M`````````-L$````````_@`````````A!0``C04``/D!``#W!0``?@,``-D&
M``"V!0``EP4```4%````````````````````````A00``,$"``#0`@``#0<`
M`)L#```!`P```````/8$``!!`@``50$```````#'!```-`$```````#-`@``
MC`````````!R!@``30$`````````````NP8```L!``#@`0``*`0``*8#``#.
M!0``=0$``#4$```1!@``C00``&(`````````+P```*$&```Z`@``6P(``(`'
M``!(!P``CP4``!D`````````K0```/$#``#2!@``?@4``#(```"_!0``S`(`
M``````#W!@``MP8``%T%``!&`0`````````````?`@``'P<``-P&````````
M$`4```````!B`0``.P(``$4"``"]`0``@@,````````L`0``1@```-("```4
M!@```````'\```!$`P``-@<``"\!```S!```XP$```````#3!0``M@(``.H!
M``!6`P``^@,``'\$````````I`,``-8"``!D`P``[`4`````````````7P``
M`"$"```T`P``_@(```````!U!````````($&```Y!0``/`4``!H$````````
M=@```*4#````````F04``&0%```4`@``;@$``"0!````````C@````````!L
M!0```````,<%```<`0``X@$```````"5`P``F`````````"'!0``&```````
M```N!0``B`0````````<````F@8``&D&``#]`@``AP$```````!.`P``:0<`
M`'P$```2!```90```%8%``#%!@``=@(``.```````````````+D#``!W`P``
M``````````````````````````!>`0```````#D'``"``@``;```````````
M````B@(```````#/!@``#0(``!$%``!O`0``+P(``.$%``#I`@``40,```\!
M``!@````9P````````#`!@``VP(``+H&``````````````````#L````M`0`
M`"@`````````,`<```````#U````K`4``/\!``#7!```&@``````````````
M`````&0$````````R08``&`&``!.`````````!4"`````````````$P$```6
M!@``(P```#\```"$!0``J@0``+H"``"3!0``Y````$0$````````N@4``$,%
M```A`0``N@$```````"=!0```````+4````"!P``+`<`````````````L@0`
M``````!J!P``?04``&8```````````````````#0!```"0$``%@&````````
M`````.`&``!A!P``/0$``#T$``!W`@``[`8``#L$```@!P``_@8``.8````.
M`0```````$@&``">!@``O@0``&8&```+!0``1@<``````````````````'4#
M``"+````>@<``-0#```#`@``I0$``"X#````````M00````````E!P```P,`
M`.T"``!P````;@8``-@````2!@``1P,``%X'``#S!0``Z08``-,$``!!`P``
M`````/L%``!F!P``H`8``-0"````````;0$``-$```"*!@``,````,H"``"C
M!```[@$``.(```!L`@``J`$``%X"````````.@,```````!<!@``+00``&(#
M``#B!0```````,\```"8!0``V`8``$<"`````````````)<!````````````
M``<&``!(!0``_P8```````!+`P``;@4``%0'``#5`0``@@$`````````````
M````````````````_P0``&X$```(!```0`,``"$$``#A!````````%X#``"`
M!```$P(``"P&``#-!```'0,```````!_!@``=0````<#``"3`0```````*P`
M````````!@(``'L!```K!```-0<```````!Z````=```````````````9`$`
M`%8!```-````00$``.`#``"U!@``.`<`````````````)@``````````````
M`````(H%``"1!````````$@$```!!@```````+,```!2`0``D08``+0!```8
M`@``4@(``(D#``!O!P``]P(``+8```#S!@``\P,``%,!``#D!```\00`````
M``#0!@```````#$"````````#`<``%``````````5@(```````!,!@``@P(`
M```````<!@```````/0&``",!@``NP```%T&````````^P$``(0```!&!@``
M`````'<!`````````````$8"``!*`0``%P,````````F`0``6P,``/<```"<
M!0``504``-T&```[`0``&@<```````"*`0``7@4``%D$``!"!P``G`(``#\#
M```3`P``L`4``$L!````````H00```````!``0``:@```(`%``"I`P``J`8`
M`"``````````K@```$L````2````J`0```,!``!Y!@```````-<!``"Z````
MY@,``+@!`````````````&H$`````````````+X```"Y````=`0````````1
M````804``.@$```B`P``K0$``.@````D`@``GP8``+\!``#T`0``.@8``(,&
M````````@0```!0$``"]`@``/P0``($!```;````M0(```````"_`P``=P4`
M`&<"``"%`````````,\"``#$!@``@04```````!9`@``H04``/(!``"O`P``
M`````(P%``!T`0``L0```(,$````````\`8````````1!P``<0(```````#O
M`P```````!("```6`0``+P,``$8$````````UP,``.$"````````?`8``$L%
M````````W`4``(D$````````L@8``/D"``"Q!```!P(````````A````_`4`
M`'D!```^`P``"@8``/0%``#R`@``<P4``+H#````````U@,``.H"``!9!@``
M`````'T$``!#`P```````"P"``">!0``R`4``-L%``!C!0``````````````
M!P``?`4``$D"```\````O```````````````$0,`````````````$`<``#<&
M```6!`````````````!C`@``"`<``#4#````````0@$``#\%````````FP8`
M````````````B0$``,D```#K`P``Y`8``+T```"-`0``OP0````````X`P``
M-P(``!\%````````AP8``+`$```)`@``[00``,$#``````````````````!+
M!```408``+<$``!U!0``Q@,```````!M`P``W`$``+(!````````E04`````
M``#*!@``I`4````````+`P``?P,``!,````/!```QP$```T$````````0P(`
M`%4```#D!0```````*X#```%`P``&P0```8&`````````````.P$``#M!0``
M#`,``*H%``"Y!```%@```%8$```Y`0``5P4``*8"``#[`@```````(("```E
M!0``_0,``$4!``!L!`````````````!!!0``%0$```````#T`P``R00``+X&
M````````2@,```````#/`P``7P4``'X$```]!@``^P```"`%``!(`0``````
M`*L```!8`0``Z@0``(T`````````T`,``#@&`````````````,L```"'````
MWP,`````````````S@0```````!2!P```````!L%````````Z0,``#$```#.
M`P``BP4``!(!```.````:P<``*<```#1!```8@<``!@&``#:````(P$``*0"
M``":`@``8`0``"\$```C!P``9P$``'H"```4!P``'P0``-H%``">`@``70``
M``````#B!```:`4``#\&``#H`@```````+0%````````!@,``"`$````````
M```````````&!0```````)4!``"&!@``=@,``+$#``#Z!@```````)0$``"'
M`@``'@8```````#>`P```````%T!``!;!P``%@,``/,"```S!P``=@4``*H#
M``!?`0``*P8``````````````````*\&``#B`P``4`,``/X$```Z!P``>@0`
M```````Q!0``:`8``-0```"B`@``^P,````````J!0``A@<``.X%``!T`@``
M`````"D`````````"`(````````+!P``YP0```````!2!@`````````````G
M!P```@8```````!(`@``````````````````V0$``,T````Y`P``!@$`````
M```K!P``<@<``&,&````````@P4``'`!``"Q`@``Q@0``#`"``!7!```````
M````````````A@4``!4$``"3`@``5P8``-(```"P`P``208``#<'``!\!P``
M`````-($```=!0```````+P$`````````````(0!`````````````"4"``!<
M`0```````!L'```R!P``(@(``*H"```F!P```````#P$``"+`@``:P```/(&
M```[!0``/@$``!,%````````Y@4``(H````>`0``K00``(L#```(!0``````
M`"0%``!?`@```````.P!````````_`0```````#A`0``204````````3!@``
MB````.L"```V!```YP,``*T%``#/!0``R0,```````!!!```````````````
M````[`(``*,#````!```&@4``#,```#V!0``=P<```````!O!@```````,T#
M``!Q`0``(`,``%L%````````A@```(4!````````M````)$#``"&!```,@0`
M`+D!``";`@``H@4``+@"``#G`@``;`8``#0$``"A````+@(``,H#```-`P``
M`````(X%````````&P8``*X$``````````````````!M!0```````-H!````
M````$`0```@&````````)0```.,#``">``````````````!T!0``'P8`````
M```7`0``0`4``!T```#.`@``H`4``(D&``"0`@``(P4``)@"````````0`8`
M`$$&``"C`0``HP4``"D"`````````````"T```!*!P``EP(``%0$````````
M`````#8"``#X!0``=@$``%\#```W`0```````%`$``!8!0``I`0```D```#%
M!0``A0,```````!:`0``:P(``.X#```;`@```````,0"``!:!P``10,``#X$
M``"2`0``Z`$``.4#``!3!`````````````"N`@``$`(``!X"``!0`0``2@0`
M``H`````````308``/X!```N````CP$````````M!P``[P(``.L!``#1`0``
M;@(`````````````W`(``,4"```G````M0,``)0%````````;@```!``````
M````CP0``!T!``!R!```=@<```(#``#@!0``4P<``+0#```'!P``CP,`````
M``"/`@``:0$``(0#``#!`0``=P8``'`$``"J````4`(``&8%````````C@,`
M`"\'``"$!````````+X#``!`!```&@(````````Y`@``E`,``((````"!```
M````````````````$0(``!<"``#"````O0,```````#1!@``,@4``/````##
M!0```````$H%```3!P``60<```0$``!@`0````````````#;`0``2@8``/,$
M``!M!@``.@4``#L'``"<`0``X0```+X"``#``P``&`0`````````````FP4`
M`.L%``#W`P```````$,'```;`P``[@0``)<#```$`P``"08``(X&````````
M800``&`'```P`0``)@8```````!E!@``:P,```````!?!@``MP,```P"``!+
M`@``'P````P&``!F`0````````````!1`@````````````"H!0``,08``+,!
M```-!@``U`$``#<%``"(`0``7``````````[!@``Z`,``!P%``"]!```KP(`
M``````"`````?`,``$$'````````A`8``-\!```W`P``\0$`````````````
M#````)@#``!E`@``H`(``/(%``````````````````!F!`````````````#K
M````N`4``*(&````````(`$``,,#```\!@``<@4``(8!``!M`@```````$\$
M``#G!@```````,<&``"1`0```````,,````>!P```````&4$``!T!P``````
M``\%```_`0``4`<``&\#```B!@``1````!8'`````````````-H"``!)````
M/0,``!D$````````\0```&L&````````#`4``%4#```)!0``)@4``+8&``"K
M!```"00``$D!``!$!@``````````````````(@4```````"P````KP```#`&
M``#O!@``XP`````````C!@``%`,``,,$``#:!@````````````"!`P``#@0`
M`!H#``"N`0```````+L!``#C!@``S@````````"4`0``?P<``,<"```$!0``
M`````#8!````````J````"X!```0`P```````)($```;`0``H@```%(%````
M````Z@8``-<"```````````````````+!```FP$``)T#``"L`0``#@(``-8%
M``#U!0``]P$```\#````````GP$``,4`````````R`(``%<````X````*@(`
M````````````_P,``*D$``"]!0```````,0%````````40$``!\!``#M!@``
M^08``)@$``!2!````````*\!`````````````*8!``"K!0``L@(``&0&````
M````V`,``!@%``"H`P```````!P"```"!0```````(<'``"!!P``T@4``.4!
M``"M!@``Y0(``,$&``"M`@``<@,``)(%``"Q`0```````-0%``"C!@``````
M`+<%````````T`4``&\%````````^@(```````#>!@`````````````A`P``
M?@<``+8$``"G!@```````,8%``"I`0``0P```)\#```=`@```````$X$````
M````!`$``)D"``!1!0``0@,``'H&``#>`@```````$<'``!E!0``@`8``$8#
M``#E````3P4``,,&````````````````````````T````%T#``"W````>P(`
M`$4%````````4P8``-@%``!,`@``/0```"\%````````>P8``.("``!B!```
M'`,``````````````````,4$````````U0,``.0"``!Z`P``E````(@'```<
M!````````````````````````$,$```:!@````````````!1!P```````"L#
M``#_````60,`````````````(@<``%,#```\`@``DP```/4!``!7`@``````
M```````.!@```````)L$````````1`$``&$"``!-!```3`<``'`%``"S`P``
M`````(8"``!.!@```````"@!````````W0$```````"S!0``<0<``-X$``!K
M!0``M`8``"D%```]!P``1`<``$P#``!K!```T0,```````!J`@``L04``(($
M``!X`P``TP,``%(#``":`0``XP(``$X"``#$!````````(H$``!L!P``<@``
M`````````````````/P"````````-`4``&H#```&!P``)0,``'T&````````
MZ@,``)D$``"W`0``RP8``-$"```J`0``F0$``,T!````````5P<``%4"``!<
M`P``B`4````````R`@``^@```)D`````````S````+`"```V!0```````-<`
M````````IP4``````````````````"4&``"9!@``\`$``",#```[````F`8`
M`$,!``#(`P``C@(```4'```7!0``9P4``````````````````"0#``",`@``
M'@```(0'``!6!P``KP4``$4```!V!@``.@0``,4!``#6`0``0@```&<$```H
M!P``<04``/8&``!6````$`$``/H%``!/`@````4``%P"``"E!0``!08``.H%
M```B````1P4```````!+!@``F@0``)P&``##`@``!00`````````````O08`
M`'`#```5!@``[@8```````!_!0``Z@```#8#``!<!0``%`4``!$!```@`@``
M`````&H%````````,0$``#\"``!/`0``,@$``"<"``#5`````````"<%``!H
M`P``^````'P"``"/!@````````````"E`@```````+`!``#^`P``8P$``+@`
M``"1````````````````````E0```"@#```/``````````````",`P``````
M`'\"``#)!0``R`$```````"(`P``(0<``*`!````````W0(``,L!```,`0``
M5P,``'D```#6!```Q0,```````#,`0``%0,``````````````````&X'``#R
M!```>`0```H#````````/@8``-H$````````HP(``&T```"1!0``&`<`````
M``!8!P``+`0```(```!B`@``'@4```````#Y!0``4`4```````#(````#@,`
M`(T"````````IP,```H%````````.P,```$"```/!P``7P0```L"````````
M3````)P$``#3`0``*P4``.D%````````>`````````!H`0``\@```/`%``!-
M`@``N04```<%````````4@```.T#``!-!0``U08``#D```#*!```GP4``,("
M``!?!P``!0$``'@&``!&!0``WP8`````````````!P```#@%```M`P``_```
M`,@&```5!P```P8``,H```!Z`0``%`$``/D#``#G!0``JP8``%4$``!4`0``
M``````@#``"[`@``3@<``!0```"3`P``K`(``%X$``#9!```/`,``#(#``#V
M````0@0```````#@`@``L08`````````````W04``&(&``#"`P``S`,``.\$
M``!=!```E@$``(H#``!H!P``A0<`````````````%04``(T&``"F!```,0<`
M`(P!``!%!```FP```"$&``#T`@``=08`````````````N`0````````2`P``
MZP8``&(%````````_00``)4&``#C!0``*@8`````````````^00```````"\
M`@```````+8!``!%!@```````*X&``!6!@``/@4```````!!````.`0`````
M```T`@````````,%````````D`4``!\#``"I`@````````````!4`P``)P8`
M`-4%``#[!@```````*H!``!E`P``$P0`````````````5`8``"D!``"U!0``
M`````.8&``#5`@```````(D%``"%`@``N08``%H#``"#`0```````/`$```F
M`@``TP8````````U````O`8``,L"``"K`P``60`````````S`0```````.$&
M``"S!@``#04``$<!``!;!@``N@0``#8&````````6@8```````!D````)`8`
M`,D"````````G0````$!```'`0``0@(``(L$``!I````V04``"(!``"@!```
M`````)0"```6!0```````#P!``#1!0```````!@!````````>@4``,<```#,
M!@````````````!@!0``)00``/@#```L!0``Z0```,($``"J!@``'08``$P!
M```R!@```@(``&D#``#@!```.`(`````````````_0```*P&``"6!@``4P(`
M```````S!@```"`H)7,@9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN
M("5S(&1A>7,I`"`H=&]D87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@
M870@`"(E<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A
M;&ED(&-H;VEC92X`(B5S(B!I<R!N;W0@8V]N9FEG=7)E9"!I;B!T:&4@2&]R
M9&4@4F5G:7-T<GDN`"(E<R(@=')E92!R96YD97)E<B!N;W0@9F]U;F0N`"(E
M<R(@=V%S(&%D9&5D('1O('1H92!G<F]U<',@<WES=&5M+@`B)7,B('=A<R!A
M9&1E9"!T;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+@`B)7,B('=A<R!N;W0@
M8W)E871E9#H@)7,N`"4N,F9-0B!U<V5D(&]F("4N,F9-0B!A;&QO=V5D("@E
M+C)F)24I`"5D("5S(&%N9"`E<P`E9"!D87ES('5N=&EL('EO=7(@<&%S<W=O
M<F0@97AP:7)E<RX`)60M9&%Y(&9O<F5C87-T`"5S("T@3F]T:6-E`"5S($9I
M;F=E<G!R:6YT`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#
M;VYF:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!
M9W)E96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&ES
M(')E861Y('1O('!E<F9O<FT@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M8VAE8VME9"!B96QO=RX@0VAE8VL@=&AE(&)O>"!F;W(@86YY(&]P97)A=&EO
M;BAS*2!Y;W4@=V%N="!T;R!P97)F;W)M(&%T('1H:7,@=&EM92X`)7,@:7,@
M<F5Q=6ER960`)7,@;6EN=71E<P`E<R!N;W0@9F]U;F0N`"5S('1O("5S(&]F
M("5S`"5S)W,@061D<F5S<R!";V]K`"5S)W,@0V%L96YD87(`)7,G<R!.;W1E
M<&%D`"5S)W,@5&%S:VQI<W0`)7,Z("5S`"5S.B!4:&ES(&UE<W-A9V4@;6%Y
M(&YO="!B92!F<F]M('=H;VT@:70@8VQA:6US('1O(&)E+B!"97=A<F4@;V8@
M9F]L;&]W:6YG(&%N>2!L:6YK<R!I;B!I="!O<B!O9B!P<F]V:61I;F<@=&AE
M('-E;F1E<B!W:71H(&%N>2!P97)S;VYA;"!I;F9O<FUA=&EO;BX`+"!G=7-T
M:6YG(``L(&=U<W1I;F<@)7,@)7,`+"!V87)I86)L92!F<F]M("5S('1O("5S
M`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA=``R-"!(;W5R($9O<FUA=``R
M-"!H;W5R<P`\4')E=FEO=7,`02!D871A8F%S92!B86-K96YD(&ES(')E<75I
M<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA<R!O8V-U<G)E
M9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O('9E<FEF
M>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E
M(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!D96-R
M>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@
M:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE
M<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME
M>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M
M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K
M97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S
M<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y
M<'0@82!M97-S86=E+@!!32!#;&]U9',`04T@3&EG:'0@4F%I;@!!32!286EN
M`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U
M="!T:&ES(&5D:71O<@!!8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C
M8V5S<R!D96YI960@8W)E871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E
M;FEE9"!C<F5A=&EN9R!61E,@9FEL92X`06-C;W5N="!);F9O<FUA=&EO;@!!
M8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%D
M9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI<W-I;VX`061D($AE
M<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S:6]N`$%D9"!A(&-H
M:6QD(&=R;W5P('1O("(E<R(`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B
M)7,B`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L
M9"!N;W0@861D(&%D9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`
M061D960@(B5S(B!T;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N
M`$%D9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O
M;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E
M<G,`061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG
M97)I80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC
M871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U
M<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN
M9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N
M871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N
M871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT
M97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M
M;V$`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N
M(&5R<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!
M;F]N>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@
M0F%R8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T
M:6]N(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!
M<'!R;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!
M<F-H:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO
M=2!W86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`
M07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@
M<W5B+6=R;W5P<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#
M24DM."D`07)T`$%R=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S
M:6$O4&%C:69I8R!296=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E
M(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L
M=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`
M071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`
M071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T
M=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E
M<P!!=6=U<W0`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C
M:V5N9"!D;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H
M7V-Y<G5S.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?9G1P.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M
M<&EL92!02%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I
M;6%P.B!297%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?
M:W)B-3H@4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7VQD87`Z($%D9&EN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I
M=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T
M('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E
M<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5
M;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R
M('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!
M=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z
M(%5P9&%T:6YG('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$
M:7)E8W1O<GDN`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V
M97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I
M;VX@9F%I;&5D+B`E<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)
M55,@<V5R=F5R+@!!=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE
M9"X`075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!
M=F%I;&%B;&4@9FEE;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K
M9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D
M+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT
M:6,@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A
M<&AI8W,@9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA
M<G5S`$)E;&=I=6T`0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H
M9&%Y`$)L;V-K("(E<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N
M`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM
M87)K<P!";W)D97(`0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@
M86YD($AE<GIE9V]V:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)
M<VQA;F0`0G)A>FEL`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"
M<G5N96D@1&%R=7-S86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI
M;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN
M=',`0U]E;&P@4')O<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M
M<&QE=&5D+@!#86QE;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B!N
M;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA=&EO;B!A<F4@
M=&AE('-A;64N`$-A;B!N;W0@;6]V92!F:6QE*',I("T@9&5S=&EN871I;VX@
M:7,@=VET:&EN('-O=7)C92X`0V%N(&YO="!R97-E="!P87-S=V]R9"!A=71O
M;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O<BX`0V%N(&YO
M="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E<B!E>'1E<FYA
M;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R
M=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A`$-A;F-E;`!#
M86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E<R(N
M`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T('!R
M;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN;W0@
M<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R:65S
M('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E<B!S
M=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N=6UB
M97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R
M=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I
M;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX
M.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@3W=N97(`
M0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA;F=E(%EO=7(@
M4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN
M80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I
M;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O<V4@82!P87-S
M=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L87D@
M9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI
M<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@
M;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(%%U
M97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@
M9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E
M;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`
M0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B
M87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC
M:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI
M8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`
M0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`0V]N9&ET:6]N
M<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R871I;VX@9F]R
M('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@3W5T;&]O:RX`
M0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O
M;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F
M86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES
M97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E
M<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY
M(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT('1Y<&4@;V8@
M8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#;VYT:6YU90!#
M;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z("5S`$-O<'D@
M<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G279O:7)E`$-O
M=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@;F]T(%!'4"!S
M:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G
M92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A
M9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N
M`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8V]N;F5C
M="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R
M("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T83H@`$-O
M=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N;W0@9&5L971E
M(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I8G5T:6]N(&QI
M<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S
M(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@
M;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L:7-T(&]F(&1I
M<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R871E9WD@(B5S
M(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O8G1A:6X@<'5B
M;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O<&5N("(E
M<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#;W5L9"!N;W0@
M;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L9"!N;W0@;W!E
M;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E
M<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T:&4@
M<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A;&P@
M;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R971R
M:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D:7-T
M<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R:6)U
M=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S(&-A
M<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN`$-O
M=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN
M`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;CH@)7,`0V]U
M;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z("(E<R(N`$-O
M=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S
M+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B!9
M;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS('1O('-A=F4@
M=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY('1H92!C;V1E
M(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,1$%0('-E<G9E
M<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@=7!D871E(&-O
M;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T:6]N(&QI<W0N
M("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O<B`B)7,B.B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E('5S97(@(B5S
M(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E<B`B)7,B.B`E
M<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@
M82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F;VQD97)S`$-R
M96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`
M0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO;G,`0W5R<F5N
M="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`0W5R<F5N="!7
M96%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T
M;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@
M<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H
M5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE
M8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M
M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$
M86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU<`!$871E`$1A
M=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN
M`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F
M875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F875L="!3
M:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`1&5L971E($=R
M;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L971E(&%N9"!P
M=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L=6UN`$1E;&5T
M92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E(&UE<W-A9V5S
M`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@<&5R;6ES<VEO
M;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_`$1E;&5T92!R
M;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S=6(@9F]L9&5R
M<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N
M="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B)7,B+@!$96QI
M=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L96T`1&5S8W)I
M<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I;&4I.@!$971A
M:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!$
M979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L87-T(&AO=7(Z
M(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H=`!$:7)E8W1I
M;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R-"UH;W5R('1I
M;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE9"!F;W)E8V%S
M=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R;6%T`$1I<W!O
M<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@9&5L971E`$1O
M(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O97,@=&AE
M(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@>65S+"!C
M:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E<'5B;&EC`$1O
M;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO860`1&]W;FQO
M860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$5-86EL+71O
M+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H:6-H('!R;W9I
M9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D:70@0FQO8VL`
M161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M:7-S:6]N<P!%
M9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@9F]R.@!%9&ET
M('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S
M`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M
M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N
M`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--4R!'871E=V%Y
M`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y
M('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M
M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@
M8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A
M('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF
M('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@
M:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%52
M3"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A=&]R:6%L($=U
M:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L;V-K.B`E<P!%
M<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@9&5L971I;F<@
M<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@
M=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G
M92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI
M8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E
M<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E
M<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE
M8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C
M=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO
M;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``
M1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN
M96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@
M<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C
M;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C
M=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I
M979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O
M92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E
M;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO
M=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`
M1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@
M9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&
M:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R
M<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`
M1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@
M0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM
M86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@
M=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI
M9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I
M9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE
M`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W
M87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R
M96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C<FEP=&EO;@!&
M=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@=&%K92!I;6%G
M92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#;VYF:6=U<F%T
M:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R
M86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!';V5D96P`1V]O
M9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E96-E`$=R965K
M("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<"!!9&UI;FES
M=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<%]L
M9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES('=H870@=&AE
M('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O(&1E;&5T92!G
M<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P("5S
M`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=U
M97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E
M;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@8V]W87)D;'D@
M<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN('1A8FQE+@!(
M5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!R
M;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T(&9O=6YD+@!(
M86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D97)S`$AE87)D
M($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4+5-T;W)M`$AE
M8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B96=I;FYI;F<@
M;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A=&EC86X@0VET
M>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E8W1O<GD`2&]M
M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O2V]L86(Z
M($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E
M<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD<R!T;R!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E("5S(&9O=6YD
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F=6QL>2!R96UO
M=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A=&EO;B!E;F=I
M;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I;VX`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E(&9O<B!O8FIE
M8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-24U%($E$(&9O
M<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@
M<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T
M;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B.B!5;FMN;W=N
M('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT86P@<&%D9&EN
M9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@*%!L96%S92!R
M97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L:6ME('1O(&UE
M<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T:&5R93\`2&]W
M(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`2'5M:61I='D`
M2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA:6QB;W@@8W)E
M871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)
M4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S
M<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N9`!)8V]N<R!/
M;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N
M86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@
M;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY
M(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@
M=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC
M>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@
M:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B
M>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G
M92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ
M`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R
M`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N
M86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L
M=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D
M;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S
M92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O;F5S:6$`26YF
M;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@879A:6QA8FQE
M+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A
M8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS
M97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T
M(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R
M;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@
M869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F
M;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T
M90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E
M8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS
M97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O
M;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@
M869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E
M<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E
M<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA
M9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@
M<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C
M<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E
M<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L
M:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U8FUI
M='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I
M;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I
M;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!)
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N
M`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A
M;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A
M;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV
M96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R
M;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y
M`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*
M=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`
M2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R
M:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N
M=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN
M9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L
M<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI
M<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F
M`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY
M<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R
M871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`
M3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S
M="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`
M3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`
M3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI
M8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI
M9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT
M(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@
M5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W0M
M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R`$QI<W0M4&]S
M=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI<W1I;F<@<V5S
M<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE9#H@)7,`3&ES
M=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,:71H=6%N:6$`
M3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4:6UE`$QO8V%T
M:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S:6]N`$QO9R!O
M=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U
M<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L
M>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E
M96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU
M;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C
M;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O
M<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA
M:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-
M87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-87)G:6X`36%R
M:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G
M<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`
M36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I
M=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E
M961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@
M-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!";&]C:W,`36%X
M:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M8F5R<P!-96YU
M(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!697)I9FEE9"!3
M=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L
M9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`365S<V%G92!T
M>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`
M365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$0B!I<R!N;W0@
M8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T(&1E9FEN960`
M365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E<P!-971R:6,`
M365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8`36ED9&QE
M`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``36EN('1E;7`@
M;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@:&%S(&YO="!Y
M970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@
M<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@
M66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S
M92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I
M;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO
M;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-
M;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O
M`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-
M;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE("5D('1H86X@
M=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@
M0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L>2!3=6YN>0!-
M;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5<`!-;W9E(&1O
M=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L
M:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T:6]N`$UY($%C
M8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T86P`37D@4&]R
M=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E90!.86UE`$YA
M;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R;&%N9',@06YT
M:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@4F5V;V-A=&EO
M;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P92!296YE=V%L
M(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P92!34TP@<V5R
M=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P
M92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W($-A;&5D;VYI
M80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE("AO<'1I;VYA
M;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S=V]R9"!W:6QL
M(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M871C:"X`3F5W
M('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@
M4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG
M97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S
M=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L
M871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO
M(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES
M('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI
M960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.
M;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O
M<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F
M;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T
M:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R
M>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@
M<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-E
M<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@9FEL90!.;R!T
M96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C:&4N`$YO('5S
M97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI9"!834P@9&%T
M82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG
M:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T:6]N+B!296=E
M;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E(&EM<&QI8VET
M*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N9`!.;W)T:&5R
M;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD<P!.;W)W87D`
M3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L
M96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG
M('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O
M9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S
M`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I
M8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/
M8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S
M=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S
M<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0('-E<G9E<G,@
M<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N
M97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O
M=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R
M<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN
M(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C
M="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI
M;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/
M<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N
M:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO
M;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T
M:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT
M:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`
M4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@
M4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E
M`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!0
M32!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]3
M25@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A
M:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`
M4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D
M>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S
M<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@
M875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A
M<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T
M90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`
M4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS
M`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R
M;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I
M;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE
M<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE
M87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@
M>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I
M<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A
M<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N
M86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI
M9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C
M:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT
M97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U
M($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN
M`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O
M;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA
M9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L
M9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@
M;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E
M<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@
M2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M
M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI
M8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T
M960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1
M871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I
M;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H
M;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N
M90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@
M5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V
M92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO
M="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L
M(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA
M<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A
M=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN
M`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N
M=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG
M="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D
M('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO
M="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S
M(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S
M=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T
M:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I
M9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG
M:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N
M+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E
M(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U
M;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O
M;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I
M86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG
M;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I
M8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H
M96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%
M4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD
M($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`
M4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H
M7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E
M<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E
M9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M
M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&
M:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE
M8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@
M=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N
M`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS
M;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.
M=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S
M<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3
M970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R
M9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R
M<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3
M970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E
M(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R
M('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O
M<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE
M`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E
M<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@
M86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3
M:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T
M:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L
M;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E
M<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@
M;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@
M=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B
M;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E
M<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G
M`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA
M=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M
M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S
M=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L
M9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A
M:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N
M;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H
M.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S
M`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3
M;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E3
M3RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC
M:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A
M9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E
M<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`
M4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL
M`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N
M9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3
M=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR
M;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S
M<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B
M('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@
M<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`
M4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S
M<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y
M<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY
M(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R
M979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N
M`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C
M8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE
M("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W
M<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`
M4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E
M=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L
M8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA
M;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E
M87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O
M<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY`%135B!F:6QE
M`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A8FQE('!R;W!E<G1I97,`
M5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI;F$`5&%J:6MI<W1A;@!4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A<F=E=#H`5&%S:W,`5&5L
M97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO=7(Z(`!496UP97)A='5R
M90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R("\^*"5S2&DE<R\E<TQO
M)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@9F]U;F0N`%1E;7!L871E
M($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X
M='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&4@1E10(&5X=&5N
M<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES=&]R>2!S>7-T96T@:7,@
M9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@
M9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0(&QO9R!C;W5L9"!N;W0@
M8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I9"!N
M;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C
M;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O
M;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO
M=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N
M;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D+"!L
M969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4
M:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D
M<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C:R!I
M<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4:&4@
M9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H
M92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE(&5N
M8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N;F5C
M=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG
M+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S
M+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O;&QO=VEN9R!A
M<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X,C(@;65S<V%G
M92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@8V%U<V4@<')O
M8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O(&)R;W=S97(@
M8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O=6YD+B`@66]U
M(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L86-K(&]F(&5D
M:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R(&-R87-H97,N
M("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@=F5R>2!L:6ME
M;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C=&EO;B!&875L
M="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B965N('=A<FYE
M9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N="!T;R!T<GD@
M=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y("(E<R(@:&%S
M(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N;'D`5&AE(&QO
M8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G:79E;B!T;R!T
M:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E;G0@;VX@)7,@
M=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES<&QA>65D+@I4
M:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E(&AA<R!B965N
M(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E('=H96X@;&EN
M:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@;V8@9FEE;&1S
M(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE(&ES(')E<75I
M<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S<RX`5&AE('!R
M969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C875S92!I=',@
M9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@<VEZ90!4:&4@
M<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@
M;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C:&%R86-T97(@
M;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S
M97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE('-E
M<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V97(@(B5S(B!H
M87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@
M8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I(&1O97,@;F]T
M(&5X:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES
M="X`5&AE('1E>'0@>6]U(&5N=&5R960@9&ED(&YO="!M871C:"!T:&4@=&5X
M="!O;B!T:&4@<V-R965N+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL
M>0!4:&4@=&]P('-I9&4@;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S
M="!S:6YC92!T:&4@<')E=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@
M8V]U;&0@;F]T(&)E('-A=F5D+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@
M;F]T(&%V86EL86)L92X`5&AE;65S(&1I<F5C=&]R>2`B)7,B(&YO="!F;W5N
M9"X`5&AE<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@
M;F\@<&%R=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@
M87)E('1O;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA
M=F4@96YT97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S
M('1H86X@)7,N`%1H97)E('=A<R!A('!R;V)L96T@861D:6YG("(E<R(@=&\@
M=&AE('-Y<W1E;3H@)7,`5&AE<F4@=V%S(&$@<')O8FQE;2!C;&5A<FEN9R!D
M871A(&9O<B!U<V5R("(E<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S
M(&$@<')O8FQE;2!R96UO=FEN9R`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H
M97)E('=A<R!A('!R;V)L96T@=7!D871I;F<@(B5S(CH@)7,`5&AE<F4@=V%S
M(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@3F\@)7,@=V%S('5P
M;&]A9&5D+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L
M;V%D.B!4:&4@)7,@=V%S(&QA<F=E<B!T:&%N('1H92!M87AI;75M(&%L;&]W
M960@<VEZ92`H)60@8GET97,I+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@
M=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R=&EA;&QY('5P
M;&]A9&5D+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE
M<W-A9V4@<&%R=`!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE
M(&E#86QE;F1A<B!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O
M;F9I9W5R871I;VX@9F]R;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U
M:7)E9"!F:65L9"X`5&AE<F4@=V%S(&%N(&5R<F]R('!E<F9O<FUI;F<@=&AE
M('-P96-I9FEE9"!A9&1R97-S(&)O;VL@9G5N8W1I;VXN(%!L96%S92!T<GD@
M86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@
M8V]N=&%C="!D971A:6QS+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R
M92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&1I<W1R:6)U=&EO;B!L:7-T
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&ES($E-05`@<V5R=F5R(&1O
M97,@;F]T('-U<'!O<G0@<VAA<FEN9R!F;VQD97)S+@!4:&ES(&1O97,@;F]T
M(&%P<&5A<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+@!4:&ES(&1O97,@
M;F]T(&%P<&5A<B!T;R!B92!A('9A;&ED('II<"!F:6QE+@!4:&ES(&1O97,@
M;F]T('-E96T@=&\@8F4@82!V86QI9"!C87)D(&YU;6)E<BX`5&AI<R!D<FEV
M97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@0VQI
M8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M*2!G871E=V%Y+"!U<VEN
M9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@
M;65S<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`
M5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N
M`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG
M80!4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@;6EN
M=71E<RX`5&]P`%1O<"!F<F%M92`H7W1O<"D`5')A;G-L871I;VYS`%1R:6YI
M9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS90!4=0!4=6YI<VEA`%1U<FME
M>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD
M($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E('EO=7(@8VAO:6-E.B``52Y6
M+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@<V-R:7!T(&1E;&EV97)Y('-T
M871U<R!R97!O<G0`55),.@!59V%N9&$`56MR86EN90!5;F%B;&4@=&\@86-C
M97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@=7-E<B!I
M;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&-H86YG
M92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(&-H
M86YG92!T;R`E<RX`56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,B
M+@!5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE(&]F("(E<R\E<R(N`%5N86)L
M92!T;R!C;VYN96-T('1O(%-13"!S97)V97(N`%5N86)L92!T;R!C;VYN96-T
M('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P>2!61E,@9FEL92X`56YA8FQE('1O
M(&-R96%T92!61E,@9&ER96-T;W)Y("(E<R(N`%5N86)L92!T;R!C<F5A=&4@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&-R96%T92!61E,@9FEL92X`56YA
M8FQE('1O(&-R96%T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!C<F5A
M=&4@96UP='D@5D93(&9I;&4N`%5N86)L92!T;R!D96-O;7!R97-S(&1A=&$N
M`%5N86)L92!T;R!D96QE=&4@(B5S(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@
M96UP='DN`%5N86)L92!T;R!D96QE=&4@(B5S(CH@)7,N`%5N86)L92!T;R!D
M96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T
M;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O
M(&1E;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@
M5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&9I;&5S:7IE*"D@9F%I
M;&5D*2X`56YA8FQE('1O(')E860@5D93(&9I;&4@*&=E=$9I;&53:7IE*"D@
M9F%I;&5D*2X`56YA8FQE('1O(')E860@9FEL93H@`%5N86)L92!T;R!R96%D
M('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92`E<R!T
M;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L<F5A9'D@97AI<W1S`%5N86)L
M92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(')E;F%M92!6
M1E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`B
M)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@=&\@<G5N("=M:VES;V9S)RX`
M56YA8FQE('1O('1R:6=G97(@9G)E92]B=7-Y('5P9&%T92!F;W(@)7,`56YA
M8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!W<FET92!6
M1E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L92!T;R!W<FET92!61E,@
M9FEL92!D871A+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4L('%U;W1A('=I
M;&P@8F4@97AC965D960N`%5N9&5R;&EN90!5;F1O($-H86YG97,`56YD;V5S
M('EO=7(@;&%S="!A8W1I;VX`56YE>'!E8W1E9"!R97-P;VYS92!F<F]M('-E
M<G9E<B!O;B!C;VYN96-T:6]N.B``56YE>'!E8W1E9"!R97-P;VYS92!F<F]M
M('-E<G9E<B!T;SH@`%5N9FEL960`56YI8V]D92`H551&+3@I`%5N:71E9"!!
M<F%B($5M:7)A=&5S`%5N:71E9"!+:6YG9&]M`%5N:71E9"!3=&%T97,`56YI
M=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S`%5N:71S`%5N:VYO
M=VX`56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!5;FMN;W=N
M(&-L:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`%5N:VYO=VX@;&]C871I
M;VX@<')O=FED960N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N`%5N
M;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE9V5D
M('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G<F%M
M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T;R!S
M964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S:&]W
M<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@8VQI
M<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`57!D
M871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P9W)A
M9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC
M871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@
M;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E
M;G0Z("5S`%5S92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R
M96YT(&9O<B!)35-0('-E<G9E<BX`57-E<@!5<V5R("5S(&ES(&YO="!A=71H
M;W)I<V5D(&9O<B`E<RX`57-E<B!!9&UI;FES=')A=&EO;@!5<V5R($]P=&EO
M;G,`57-E<B!296=I<W1R871I;VX`57-E<B!296=I<W1R871I;VX@:&%S(&)E
M96X@9&ES86)L960@9F]R('1H:7,@<VET92X`57-E<B!A8V-O=6YT(&YO="!F
M;W5N9`!5<V5R;F%M90!5<V5R;F%M92`B)7,B(&%L<F5A9'D@97AI<W1S+@!5
M<V5R;F%M93H`57-E<FYA;64Z(`!5<V5R<R!I;B!T:&4@<WES=&5M.@!5>F)E
M:VES=&%N`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N
M`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L
M=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X
M:6UU;2!L96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R
M;VT`5F%N=6%T=0!687)I86)L90!696YE>G5E;&$`5F5R:69I8V%T:6]N(&9A
M:6QE9"`M('1H:7,@;65S<V%G92!M87D@:&%V92!B965N('1A;7!E<F5D('=I
M=&@N`%9E<G-I;VX`5F5R<VEO;B!#;VYT<F]L`%9E<G1I8V%L(&%L:6=N`%9E
M<G1I8V%L('!A9&1I;F<`5F5R=&EC86PZ`%9E<GD@2&EG:`!6:65T($YA;0!6
M:65T;F%M97-E("A625-#24DI`%9I97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W
M96(@<&%G90!6:65W(&%S("5S`%9I<F=I;B!)<VQA;F1S+"!"<FET:7-H`%9I
M<F=I;B!)<VQA;F1S+"!5+E,N`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O
M9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=)3B!V:6$@2%144`!786QL:7,@
M86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A=&AE
M<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET90!7
M965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E<W1E
M<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T97)N
M(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F
M=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7
M:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H97)E:7,@075S=')A;&EA
M(&UA<`!7:&EC:"!P:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R
M('1H92!2:6-H(%1E>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI
M=',`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F
M9F5C="!O;B!N97AT(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T
M:"!U;FET`%=I9'1H.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D
M(&EN(&MN;W1S`%=I;F0Z`%=I;F0Z(`!7:7-D;VT`5VES:&QI<W0`5V]R:P!7
M;W)K($%D9')E<W,`5V]R:R!0:&]N90!7<F]N9R!N=6UB97(@;V8@9FEE;&1S
M(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;G5M
M8F5R(&]F(&9I96QD<RX@17AP96-T960@)60L(&9O=6YD("5D+@!7<F]N9R!O
M9F9S970@)60@=VAI;&4@<F5A9&EN9R!A(%9&4R!F:6QE+@!8+5)E9@!8-3`Y
M=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N9&5D($ME>2!5<V%G
M90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE`%@U,#EV,R!3=6)J
M96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I;VYS`%E9`%E965D`
M66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@22!!9W)E90!9;W4@
M87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I
M=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@86QL;W=E9"!T;R!C
M<F5A=&4@;6]R92!T:&%N("5D(&)L;V-K<RX`66]U(&%R92!N;W0@875T:&5N
M=&EC871E9"X`66]U(&-A;FYO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W4@;F5E9"!T
M;R!P<F]V:61E(&%N($ET86QI86X@<&AO;F4@;G5M8F5R`%EO=7(@)7,@<V5S
M<VEO;B!H87,@97AP:7)E9"X@4&QE87-E(&QO9VEN(&%G86EN+@!9;W5R($5M
M86EL($%D9')E<W,`66]U<B!&<F]M.B!A9&1R97-S.@!9;W5R($EN9F]R;6%T
M:6]N`%EO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T
M:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y
M;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!.86UE
M`%EO=7(@875T:&5N=&EC871I;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T
M(&%D9&EN9R!U<V5R<RX@268@>6]U('=I<V@@=&\@=7-E($AO<F1E('1O(&%D
M;6EN:7-T97(@=7-E<B!A8V-O=6YT<RP@>6]U(&UU<W0@=7-E(&$@9&EF9F5R
M96YT(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0N`%EO=7(@875T:&5N=&EC871I
M;VX@8F%C:V5N9"!D;V5S(&YO="!S=7!P;W)T(&QI<W1I;F<@=7-E<G,L(&]R
M('1H92!F96%T=7)E(&AA<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R
M(')E87-O;BX`66]U<B!B<F]W<V5R(&%P<&5A<G,@=&\@:&%V92!C:&%N9V5D
M('-I;F-E('1H92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P
M<F]T96-T('EO=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9
M;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO
M=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@<')I;G0@;W!T:6]N
M+B!0<F5S<R!#;VYT<F]L+T-O;6UA;F0@*R!0('1O('!R:6YT+@!9;W5R(&-U
M<G)E;G0@=&EM92!Z;VYE.@!9;W5R(&1E9F%U;'0@:61E;G1I='D@:&%S(&)E
M96X@8VAA;F=E9"X`66]U<B!D969A=6QT(&ED96YT:71Y.@!9;W5R(&9U;&P@
M;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`66]U<B!N97<@<&%S<W=O
M<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T
M:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E
M;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y
M;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`
M66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U<B!R96UO=&4@<V5R=F5R
M<SH`675G;W-L879I80!:86ER90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`6TAI
M9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M(%)E<&]R=%T`6U-H;W<@475O=&5D
M(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X="`M("5S(&QI;F5S70!;;&EN92`E
M<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N`%]#3$D`7T1A=&%4<F5E`%]$96QE
M=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM86=E(%!R;W!E<G1I97,N+BX`7TQO
M9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI;FLN+BX`7T]P=&EO;G,`7U!E<FUI
M<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?4V5T=7``7U1A8FQE(%!R;W!E<G1I
M97,N+BX`7U5S97)S`&%D9')E<W,@8F]O:P!A9&1R97-S964@=6YK;F]W;@!C
M86QE;F1A<@!C86QM`&-A;FYO="!C<F5A=&4@;W5T<'5T(&9I;&4`8V%N;F]T
M(&]P96X@:6YP=70`8VQI8VL@:&5R90!C;VUM86YD(&QI;F4@=7-A9V4@97)R
M;W(`8V]N9FEG=7)A=&EO;B!E<G)O<@!C<FET:6-A;"!S>7-T96T@9FEL92!M
M:7-S:6YG`&1A=&$@9F]R;6%T(&5R<F]R`&5D:70`96YT<GD@;F]T(&9O=6YD
M`&9A;&QI;F<`9FEL90!F<F]M('1H92`E<R`H)7,I(&%T("5S("5S`&=U<W1I
M;F<`:#H`:&@`:&]S="!N86UE('5N:VYO=VX`:6UM961I871E`&EN;&EN90!I
M;G!U="]O=71P=70@97)R;W(`:6YT97)N86P@<V]F='=A<F4@97)R;W(`;&EN
M97-=`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M
M;0!N86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO
M=&5P860`<&5R8V5N=`!P97)M:7-S:6]N(&1E;FEE9`!P:7AE;',`<F5M;W1E
M(&5R<F]R(&EN('!R;W1O8V]L`')I<VEN9P!S97)V:6-E('5N879A:6QA8FQE
M`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I82!(5%10`'-S`'-T96%D
M>0!S>7-T96T@97)R;W(`=&%S:R!L:7-T`'1E;7!O<F%R>2!F86EL=7)E`'1Y
M<&4@=&AE('!A<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA
M;65D`'5S97(@<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M
M260M5F5R<VEO;CH@2&]R9&4@,RXP+6-V<PI297!O<G0M37-G:60M0G5G<RU4
M;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P
M-BTP-2TQ."`P.#HQ-RLP,C`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#(M
M,34@,3<Z,C0K,#$P,`I,87-T+51R86YS;&%T;W(Z($UA;G5E;"!0+B!!>6%L
M82`\;6%Y86QA0'5N97@N97,^"DQA;F=U86=E+51E86TZ(&DQ.&Y`;&ES=',N
M:&]R9&4N;W)G"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X
M="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ"D-O;G1E;G0M5')A;G-F97(M
M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STR.R!P;'5R
M86P]*&X@(3T@,2D["@`@*&AA8V4@)7,@9.UA<RD`("A!8V-E9&EE;F1O(&$@
M)7,I`"`H96X@)7,@9.UA<RD`("AH;WDI`"`H;6'Q86YA*0`@*&%Y97(I`&5N
M(``B)7,B(&YO(&5S('5N(&1I<F5C=&]R:6\N`"(E<R(@;F\@97,@=6YA(&5L
M96-C:?-N(';A;&ED82X`3F\@<V4@:&$@8V]N9FEG=7)A9&\@(B5S(B!E;B!E
M;"!R96=I<W1R;R!D92!(;W)D92X`3F\@<V4@96YC;VYT<O,@96P@9V5N97)A
M9&]R(&1E(.%R8F]L97,@9&4@(B5S(BX`4V4@:&$@8?%A9&ED;R`B)7,B(&%L
M('-I<W1E;6$@9&4@9W)U<&]S+@!392!H82!A\6%D:61O("(E<R(@86P@<VES
M=&5M82!D92!P<FEV:6QE9VEO<RX`3F\@<V4@:&$@8W)E861O("(E<R(Z("5S
M+@!5<V%D;W,@)2XR9DU"(&1E("4N,F9-0B!P97)M:71I9&]S("@E+C)F)24I
M`"5D("5S('D@)7,`475E9&%N("5D(&3M87,@:&%S=&$@<75E(&5X<&ER92!L
M82!C;VYT<F%S9?%A+@`E9"!P<F]N\W-T:6-O<R!D:6%R:6]S`"5S("T@079I
M<V\`2'5E;&QA(&1I9VET86P@9&4@)7,`)7,@2T(`)7,@;W!E<F%C:6]N97,@
M9&4@;6%N=&5N:6UI96YT;R`M($-O;F9I<FUA8VGS;@!#;VYF:6=U<F%C:?-N
M(&1E("5S`$9I<FUA(&1E("5S`$%C=65R9&]S(&1E(&QI8V5N8VEA(&1E("5S
M`%EA(&5X:7-T92`E<RX`)7,@82!L87,@)7,@)7,`)7,@97-TX2!P<F5P87)A
M9&\@<&%R82!R96%L:7IA<B!L87,@;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI
M96YT;R!S96QE8V-I;VYA9&%S+D%C=&EV92!L87,@8V%S:6QL87,@9&4@;&%S
M(&]P97)A8VEO;F5S('%U92!D97-E82!E:F5C=71A<B!E;B!E<W1A(&]C87-I
M\VXN`$AA8V4@9F%L=&$@)7,`)7,@;6EN=71O<P!.;R!S92!H82!E;F-O;G1R
M861O("5S+@`E<R!A;"`E<R!D92`E<P!$:7)E8V-I;VYE<R!D92`E<P!!9V5N
M9&$@9&4@)7,`3&EB<F5T82!D92!N;W1A<R!D92`E<P!487)E87,@9&4@)7,`
M)7,Z("5S`"5S.B!%<W1E(&UE;G-A:F4@<'5E9&4@<75E(&YO('!R;V-E9&$@
M9&4@<75I96X@<&%R96-E('-E<BX@179I=&4@<V5G=6ER(&-U86QQ=6EE<B!V
M[6YC=6QO(&EN8VQU[61O(&\@<W5M:6YI<W1R87(@8W5A;'%U:65R(&EN9F]R
M;6%C:?-N('!E<G-O;F%L(&%L(')E;6ET96YT92X`+"!V96YT;W-O(``L('9E
M;G1O<V\@)7,@)7,`+"!V87)I86)L92!D92`E<R!A("5S`"TM('-E;&5C8VEO
M;F%R("TM`$9O<FUA=&\@9&4@,3(@:&]R87,`1F]R;6%T;R!D92`R-"!H;W)A
M<P`R-"!H;W)A<P`\06YT97)I;W(`4&%R82!E<W1E(&)L;W%U92!H86-E(&9A
M;'1A('5N(&UO=&]R(&1E(&)A<V4@9&4@9&%T;W,N`%-E(&AA('!R;V1U8VED
M;R!U;B!E<G)O<B!I<G)E<&%R86)L90!(86-E(&9A;'1A('5N82!C;&%V92!0
M1U`@</IB;&EC82!P87)A(&-I9G)A<B!U;B!M96YS86IE+@!(86-E(&9A;'1A
M('5N82!C;&%V92!01U`@</IB;&EC82!P87)A(&-O;7!R;V)A<B!U;B!M96YS
M86IE(&9I<FUA9&\N`$AA8V5N(&9A;'1A('5N82!C;&%V92!01U`@</IB;&EC
M82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A
M<F$@9&5S8VEF<F%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V
M92!01U`@</IB;&EC82P@=6YA(&-L879E(%!'4"!P<FEV861A('D@=6YA(&9R
M87-E(&-L879E('!A<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V5N(&9A;'1A
M('5N82!C;&%V92!3+TU)344@</IB;&EC82P@=6YA(&-L879E(%,O34E-12!P
M<FEV861A('D@=6YA(&9R87-E(&-L879E('!A<F$@9&5S8VEF<F%R('5N(&UE
M;G-A:F4N`$AA8V5N(&9A;'1A('5N82!C;&%V92!3+TU)344@</IB;&EC82P@
M=6YA(&-L879E(%,O34E-12!P<FEV861A('D@=6YA(&9R87-E(&-L879E('!A
M<F$@9FER;6%R('5N(&UE;G-A:F4N`$AA8V4@9F%L=&$@=6YA(&-L879E(%--
M24U%('#Z8FQI8V$@<&%R82!C:69R87(@=6X@;65N<V%J92X`3G5B97,@;6%T
M:6YA;&5S`$QI9V5R82!L;'5V:6$@;6%T:6YA;`!,;'5V:6$@;6%T:6YA;`!!
M9W5A8V5R;W,@;6%T:6YA;&5S`$%G=6%C97)O(&UA=&EN86P@9&4@;FEE=F4`
M04TO4$T`240@9&4@05!)`$%C97)C82!D96P@961I=&]R`$%C97)C82!D92XN
M+@!);F9E<FEO<B!!8G,N`$5N(&UE9&EO($%B<RX`4V4@:&$@9&5N96=A9&\@
M96P@86-C97-O(&%L(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93+@!392!H82!D
M96YE9V%D;R!E;"!A8V-E<V\@86P@8W)E87(@96P@87)C:&EV;R!61E,N`$ED
M96YT:61A9`!#;VYT<F%S9?%A(&1E(&%C8V5S;P!)9&5N=&ED860@8FQO<75E
M861A+@!#;VYT86)I;&ED860`0?%A9&ER`$'Q861I<B!G<G5P;R!D97-C96YD
M:65N=&4`0?%A9&ER('!R:79I;&5G:6\@9&5S8V5N9&EE;G1E`$'Q861I<B!A
M<77M.@!!\6%D:7(@9W)U<&\`0?%A9&ER('!R:79I;&5G:6\`0?%A9&ER(&$@
M(B5S(B!U;B!G<G5P;R!D97-C96YD:65N=&4`0?%A9&ER(&$@(B5S(B!U;B!P
M<FEV:6QE9VEO(&1E<V-E;F1I96YT90!!\6%D:7(@=6X@=7-U87)I;SH`0?%A
M9&ER(&-O;'5M;F$`0?%A9&ER(&UI96UB<F]S`$'Q861I<B!P87(`0?%A9&ER
M(&5L(&UE;OH@)7,@8V]M;R!P86YE;"!L871E<F%L(&1E($UO>FEL;&$`0?%A
M9&ER(&$@;&%S(&1I<F5C8VEO;F5S.@!!\6%D:7(@82!L87,@9&ER96-C:6]N
M97,Z`$'Q861I<B!U<W5A<FEO`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S:7-T
M96UA+"!P97)O(&YO('-E('!U961E(&'Q861I<B!L82!I;F9O<FUA8VGS;B!A
M9&EC:6]N86P@9&4@86QT83H@)7,N`%-E(&AA(&'Q861I9&\@(B5S(B!A;"!S
M:7-T96UA+B!982!P=65D92!I;FEC:6%R(&QA('-E<VGS;BX`3&$@861I8VGS
M;B!D92!U<W5A<FEO<R!E<W3A(&1E<VAA8FEL:71A9&$N`$1I<F5C8VGS;@!$
M:7)E8V-I;VYE<P!!9&UI;FES=')A9&]R("T@9&5F:6YE('!R:79I;&5G:6]S
M(&1E(&]T<F]S('5S=6%R:6]S`$%D;6EN:7-T<F%C:?-N`$%N=6YC:6]S`$%F
M9V%N:7-TX6X`06QB86YI80!!<F=E;&EA`$%L:6%S`$%L:6YE87(`06QI;F5A
M8VGS;CH`5&]D;W,`5&]D;W,@;&]S('5S=6%R:6]S(&%U=&5N=&EF:6-A9&]S
M`%1O9&]S(&QO<R!G<G5P;W,`5&]D;W,@;&]S('!R:79I;&5G:6]S`%1O9&]S
M(&QO<R!L861O<P!097)M:71I<B!V87)I87,@9&ER96-C:6]N97,`OU!E<FUI
M=&ER(&-O;F9I9W5R86-I\VX@9&4@=&EP;R!D92!L:7-T87,@;W)D96YA9&%S
M/P!982!E>&ES=&4`06-C97-O($E-4U`@86QT97)N871I=F\`0VQA=F4@24U3
M4"!A;'1E<FYA=&EV80!5<W5A<FEO($E-4%,@86QT97)N871I=F\`1&ER96-C
M:?-N(&5L96-T<O-N:6-A(&%L=&5R;F%T:79A`%!L86YT:6QL87,@86QT97)N
M871I=F%S`%1E>'1O(&%L=&5R;F%T:79O`%-A;6]A($%M97)I8V%N80!392!H
M82!I;F1I8V%D;R!U;B!V86QO<B!I;&5G86PN`%-E(&AA('!R;V1U8VED;R!U
M;B!E<G)O<B!D97-C;VYO8VED;RX`06YD;W)R80!!;F=O;&$`06YG=6EL80!0
M<F]X>2!A;O-N:6UO`%)E<W!U97-T80!!;G3A<G1I9&$`06YT:6=U82!Y($)A
M<F)A9&]S`$%P;&EC86-I\VX`3&ES=&$@9&4@87!L:6-A8VEO;F5S`$QA(&%P
M;&EC86-I\VX@97-TX2!L:7-T82X`07!L:6-A<B!A(')E8W5R<V]S(&-O;7!A
M<G1I9&]S(&1E<V-E;F1I96YT97,`07!R;V)A<@!486UA\6\@87!R;WAI;6%D
M;P!!8G)I;`!!<N%B:6=O("A7:6YD;W=S+3$R-38I`%1A;6'Q;R!D96P@87)C
M:&EV;P!.;VUB<F4@9&5L(&%R8VAI=F\`OT5S=&$@<V5G=7)O(&1E('%U92!D
M97-E82!E;&EM:6YA<B!L82!S;VQI8VET=60@9&4@86QT82!D92`E<S\`OT5S
M=.$@<V5G=7)O(&1E('%U92!D97-E82!E;&EM:6YA<B`B)7,B('D@=&]D;W,@
M<W5S('-U8F=R=7!O<S\`07)G96YT:6YA`$%R;65N:6$`07)M96YI;R`H05)-
M4T-)22TX*0!!<G1E`$%R=6)A`$ES;&$@07-C96YS:?-N`$=RX69I8V]S($%S
M8VEI`%)E9VGS;B!D92!!<VEA+U!A8^UF:6-O`+]3;VQI8VET87(@8V]N9FER
M;6%C:?-N(&%N=&5S(&1E(')E86QI>F%R(&]P97)A8VEO;F5S(&1E(&UA;G1E
M;FEM:65N=&\_`$-O;'5M;F%S(&1E(&%S:6=N86-I\VX`26YT96YT82!E;&EM
M:6YA<B!U;B!G<G5P;R!I;F5X:7-T96YT92X`26YT96YT82!E;&EM:6YA<B!U
M;B!P<FEV:6QE9VEO(&EN97AI<W1E;G1E+@!);G1E;G1A(&UO9&EF:6-A<B!U
M;B!P<FEV:6QE9VEO(&EN97AI<W1E;G1E+@!);G1E;G1A(&UO9&EF:6-A<B!U
M;B!R96-U<G-O(&-O;7!A<G1I9&\@:6YE>&ES=&5N=&4N`$%T<FEB=71O<P!!
M9V]S=&\`075S=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ($YO('-E(&5N
M8V]N='+S(&QA(&5X=&5N<VGS;B!I;6%P(&YE8V5S87)I82X`075T:%]C>7)U
M<SH@16P@;6]T;W(@8V%R96-E(&1E(&QA<R!C87!A8VED861E<R!N96-E<V%R
M:6%S+@!!=71H7V-Y<G5S.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I\VX@
M:6UA<"!N96-E<V%R:6$N`$%U=&A?9G1P.B!.;R!S92!E;F-O;G1R\R!L82!E
M>'1E;G-I\VX@1E10(&YE8V5S87)I82X@0V]M<&EL92!02%`@8V]N(&QA(&]P
M8VGS;B`M+65N86)L92UF='`N`$%U=&A?:6UA<#H@3F\@<V4@96YC;VYT<O,@
M;&$@97AT96YS:?-N($E-05`@;F5C97-A<FEA+@!!=71H7VMR8C4Z($YO('-E
M(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!K<F(U(&YE8V5S87)I82X`075T:%]L
M9&%P.B!.;R!E<W3A('-O<&]R=&%D82!L82!A9&EC:?-N(&1E('5S=6%R:6]S
M(&1E($%C=&EV92!$:7)E8W1O<GD`075T:%]L9&%P.B!.;R!E<W3A('-O<&]R
M=&%D82!L82!E;&EM:6YA8VGS;B!D92!U<W5A<FEO<R!D92!!8W1I=F4@1&ER
M96-T;W)Y`$%U=&A?;&1A<#H@3F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N
M($Q$05`@;F5C97-A<FEA+@!!=71H7VQD87`Z($YO('-E('!U961E(&'Q861I
M<B!E;"!U<W5A<FEO("5S+B#)<W1O(&5S(&QO('%U92!D:6IO(&5L('-E<G9I
M9&]R.B``075T:%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L('5S=6%R
M:6\@)7,`075T:%]L9&%P.B!);F-A<&%Z(&1E(&%C='5A;&EZ87(@96P@=7-U
M87)I;R`E<P!!=71H7VQD87`Z($YO(&5S=.$@<V]P;W)T861A(&QA(&%C='5A
M;&EZ86-I\VX@9&4@=7-U87)I;W,@9&4@06-T:79E($1I<F5C=&]R>0!!=71H
M7VUC86PZ($YO('-E(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!-0T%,(&YE8V5S
M87)I82X`075T:%]S;6)A=71H.B!.;R!S92!E;F-O;G1R\R!L82!E>'1E;G-I
M\VX@<VUB875T:"!N96-E<V%R:6$N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS
M;B!C;VX@96P@<V5R=FED;W(@24U!4"X`1F%L;/,@;&$@875T96YT:69I8V%C
M:?-N`$9A;&SS(&QA(&%U=&5N=&EF:6-A8VGS;BX@)7,`16P@<V5R=FED;W(@
M4D%$2553(&AA(')E8VAA>F%D;R!L82!A=71E;G1I9FEC86-I\VXN`$9A;&SS
M(&QA(&%U=&5N=&EF:6-A8VGS;B!C;VX@96P@<V5R=FED;W(@1E10+@!&86QL
M\R!L82!A=71E;G1I9FEC86-I\VX@8V]N(&5L('-E<G9I9&]R(%--0BX`0V%M
M<&]S(&1I<W!O;FEB;&5S.@!!>F5R8F%I:F%N`$5X8W5S87,@0D]&2`!&;VYD
M;P!#;VQO<B!D92!F;VYD;P!#;VYT<F%S9?%A(&ME<F)E<F]S(&EN8V]R<F5C
M=&$N`$YO;6)R92!D92!U<W5A<FEO(&ME<F)E<F]S(&EN8V]R<F5C=&\N`$)A
M:&%M87,`0F%H<F%I;@!"X6QT:6-O("A)4T\M.#@U.2TQ,RD`0F%N9VQA9&5S
M:`!"87)B861O<P!.;R!S92!E;F-O;G1R\R!E;"!D:7)E8W1O<FEO(&)A<V4@
M9&4@:6WA9V5N97,@(B5S(BX`3.UN96$@8F%S90!"96QA<G5S`$+I;&=I8V$`
M0F5L:7IE`$)E;FEN`$)E<FUU9&%S`$)H=71A;@!#=6UP;&5A\6]S`$YO('-E
M(&5N8V]N='+S(&5L(&)L;W%U92`B)7,B(&1E(&QA(&%P;&EC86-I\VX@(B5S
M(BX`3W!C:6]N97,@9&4@8FQO<75E`%1I<&\@9&4@8FQO<75E`$YE9W)I=&$`
M0F]L:79I80!-87)C861O<F5S`$)O<F1E`$=R;W-O<B!D96P@8F]R9&4Z`$)O
M<F1E<P!";W-N:6$@2&5R>F5G;W9I;F$`06UB;W,`0F]T<W=A;F$`26YF97)I
M;W(`27-L82!D92!";W5V970`0G)A<VEL`%1E<G)I=&]R:6\@;V-EX6YI8V\@
M9&4@;&$@26YD:6$@8G)I=.%N:6-A`$)R=6YE:2!$87)U<W-A;&%M`$)U;&=A
M<FEA`$QI<W1A(&1E<V]R9&5N861A`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--
M4P!#4D,`4'5N=&]S(&1E(&1I<W1R:6)U8VGS;B!#4D,`4')O<&EE9&%D97,@
M9&4@7V-E;&1A+BXN`$YO('-E(&AA(&9I;F%L:7IA9&\@96P@:6YI8VEO(&1E
M(&QA(&-A8VCI+@!!9V5N9&$`0V%L;6$`0V%M8F]Y80!#86UE<OIN`$YO('-E
M('!U961E*&XI(&-O<&EA<B!E;"]L;W,@87)C:&EV;RAS*2`M(&]R:6=E;B!Y
M(&1E<W1I;F\@<V]N(&5L(&UI<VUO+@!.;R!S92!P=65D92AN*2!T<F%S;&%D
M87(@96PO;&]S(&%R8VAI=F\H<RD@+2!E;"!D97-T:6YO(&5S=.$@9&5N=')O
M(&1E;"!O<FEG96XN`$YO('-E('!U961E(')E86IU<W1A<B!L82!C;&%V92!A
M=71O;>%T:6-A;65N=&4L('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D
M;6EN:7-T<F%D;W(@9&5L('-I<W1E;6$N`$YO('-E('!U961E(&5S8W)I8FER
M(&5N(&5L(&%R8VAI=F\@(B5S(@!.;R!S92!P=65D96X@861M:6YI<W1R87(@
M;6%N96IA9&]R97,@9&4@<V5S:?-N(&5X=&5R;F]S+@!.;R!S92!P=65D92!C
M;VYE8W1A<B!A;"!S97)V:61O<B!)34%0.B`E<P!.;R!S92!P=65D92!A8G)I
M<B!E;"!A<F-H:79O("(E<R(N`$-A;F%DX0!#86YC96QA<@!#86YC96QA<B!I
M;F9O<FUE(&1E('!R;V)L96UA<P!.;R!S92!P=65D92!E;&EM:6YA<B!E;"!A
M<F-H:79O("(E<R(N`$YO('-E(&5N8W5E;G1R82!U;B!D:7)E8W1O<FEO('1E
M;7!O<F%L+@!.;R!S92!P=65D92!C;VYT:6YU87(@<VEN(&5L('!A<N%M971R
M;R`G=&%R9V5T1FEL92<N`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C
M=&]R:6\@(B5S(BX`3F\@<V4@<'5E9&4@96QI;6EN87(L('1I96YE("5D(&1E
M<V-E;F1I96YT97,N`$YO('-E('!U961E(')E;W)D96YA<BP@96P@;OIM97)O
M(&1E(&5N=')A9&%S('%U92!S92!D97-E82!O<F1E;F%R(&YO(&-O:6YC:61E
M(&-O;B!L87,@86QM86-E;F%D87,N`$YO('-E('!U961E(&1I<FEG:7(@96P@
M;65N<V%J92!A;"!N^FUE<F\@97-P96-I9FEC861O+@!#86)O(%9E<F1E`%-U
M8G3M='5L;P!0<F]V965D;W(`0V%T96=O<NUA<R!Y(&5T:7%U971A<P!)<VQA
M<R!#86EMX6X`5&5LZ69O;F\@;?-V:6P`4')O<&EE9&%D97,@9&4@8V5L9&$`
M36%R9V5N(&1E(&-E;&1A.@!0<F]P:65D861E<R!D92!C96QD80!%<W!A8VEA
M9&\@9&4@8V5L9&$Z`%1E;.EF;VYO(&WS=FEL`$/I;'1I8V\@*$E33RTX.#4Y
M+3$T*0!#96YT<F%R`%)E</IB;&EC82!#96YT<F]A9G)I8V%N80!%=7)O<&$@
M0V5N=')A;"`H25-/+3@X-3DM,BD`1&5T86QL97,@9&5L(&-E<G1I9FEC861O
M`%!R;W!I971A<FEO(&1E;"!C97)T:69I8V%D;P!0;VSM=&EC87,@9&5L(&-E
M<G1I9FEC861O`$-H860`0V%M8FEA<@!#86UB:64@;&$@8V]N=')A<V7Q80!#
M86UB:6$@96P@;F]M8G)E('D@;&$@9&ER96-C:?-N(&5L96-T<O-N:6-A('9I
M<VEB;&5S(&%L(&QE97(@;R!R97-P;VYD97(@82!S=7,@;65N<V%J97,N`$QA
M(&-O;F9I9W5R86-I\VX@86-T=6%L(&YO('-O<&]R=&$@96P@8V%M8FEO(&1E
M(&-O;G1R87-E\6%S+B!0\VYG87-E(&5N(&-O;G1A8W1O(&-O;B!E;"!A9&UI
M;FES=')A9&]R(&1E;"!S:7-T96UA+@!'<N%F:6-O`%9E<FEF:6-A<B!?=NUN
M8W5L;RXN+@!#:&EL90!#:&EN80!#:&EN;R!S:6UP;&EF:6-A9&\@*$=",C,Q
M,BD`0VAI;F\@=')A9&EC:6]N86P@*$)I9S4I`$%P;&EC86-I\VXZ`$5L:6IA
M('5N82!C;VYT<F%S9?%A`$5L:6IA('5N(&YO;6)R92!D92!U<W5A<FEO`$5L
M:6IA(&/S;6\@;6]S=')A<B!L87,@9F5C:&%S.@!396QE8V-I;VYA<B!T:7!O
M(&1E(&5S=&EL;R!D92!L:7-T82`H<&%R82!L:7-T87,@;W)D96YA9&%S*0!)
M<VQA(&1E(%!A<V-U80!.;R!S92!E;F-O;G1R\R!L82!D969I;FEC:?-N(&1E
M(&-L87-E(&1E("5S+@!,:6UP:6%R`$5L:6UI;F%R(&5T:7%U971A<R!-4T]F
M9FEC90!";W)R87(@8V]N<W5L=&$`0F]R<F%R('5S=6%R:6\Z("5S`$)O<G)A
M<B!U<W5A<FEO`$)O<G)A<B!D871O<R!D96P@=7-U87)I;P!$97-P96IA9&\@
M=&%R9.UO`$AA9V$@8VQI8VL@<&%R82!S96=U:7(`0VQI8VMA=&5L;"!P;W(@
M2%144`!#97)R87(@=F5N=&%N80!.=6)E<P!.=6)E<R!T96UP<F%N87,`;G5B
M;W-O`$ES;&%S(&1E(&-O8V]S("A+965L:6YG*0!/8W5L=&%R(&)A<G)A(&QA
M=&5R86P`0V]L87!S87(@8F]R9&5S`$-O;&]M8FEA`$-O;&]R`%-E;&5C=&]R
M(&1E(&-O;&]R`%-E;&5C8VGS;B!D92!C;VQO<@!#;VQU;6YA<SH`5.UT=6QO
M<R!D92!L87,@8V]L=6UN87,`0_-M:6-S`$-O;6%N9&\`26YTZ7)P<BX@8V]M
M86YD;W,`0V]M96YT87)I;P!.;VUB<F4@8V]M^FX`0V]M;W)O<P!#;VUP8?'M
M80!/<F1E;F%D;W)E<P!#;VYD:6-I\VX`0V]N9&EC:6]N97,`1&EF97)E;F-I
M87,@9&4@;&$@8V]N9FEG=7)A8VGS;@!#;VYF:6=U<F%C:?-N('!A<F$@<VEN
M8W)O;FEZ86-I\VX@8V]N(%!$07,L($WS=FEL97,@8V]N(&%G96YD82!Y($]U
M=&QO;VLN`$QA(&-O;F9I9W5R86-I\VX@97-TX2!D97-A8W1U86QI>F%D82X`
M0V]N9FEG=7)A<B`E<P!#;VYF:7)M87(@8V]N=')A<V7Q80!#;VYG;P!#;VYG
M;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(&1E;`!&86QL\R!L82!C;VYE>&GS
M;BX`1F%L;/,@;&$@8V]N97AI\VXZ(`!392!H82!R96-H87IA9&\@;&$@8V]N
M97AI\VX@86P@<V5R=FED;W(@9&4@8VQA=F5S('#Z8FQI8V\N`%-E(&AA(')E
M8VAA>F%D;R!L82!C;VYE>&GS;B!A;"!S97)V:61O<B!D92!C;&%V97,@</IB
M;&EC;RX@36]T:79O.B`E<R`H)7,I`$AA(&9A;&QA9&\@;&$@8V]N97AI\VX@
M86P@<V5R=FED;W(@1E10+@!#;VYT86-T;W,`4V4@:&%N(&'Q861I9&\@8V]R
M<F5C=&%M96YT92!L;W,@8V]N=&%C=&]S(&$@<W5S(&1I<F5C8VEO;F5S`%1I
M<&\@9&4@8V]N=&5N:61O(&1E;"!A<F-H:79O(&-O;7!R:6UI9&\Z(`!#;VYT
M96YI9&\@9&4@(B5S(@!#;VYT:6YU87(`27-L87,@0V]O:P!#;V]K:64`0V]P
M:6%R`$9A;&SS(&QA(&-O<&EA.B`E<P!#;W!I87(@<V5L96-C:?-N`$E$(&1E
M(&-O<W1E`$-O<W1A(%)I8V$`0V]S=&$@9&4@36%R9FEL`$YO('-E('!U961E
M(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E
M(&9I<FUA<B!E;"!M96YS86IE(&UE9&EA;G1E(%!'4#H@`$YO('-E('!U961E
M(&-I9G)A<B!E;"!M96YS86IE(&UE9&EA;G1E(%,O34E-10!.;R!S92!P=65D
M92!F:7)M87(@96P@;65N<V%J92!M961I86YT92`@4R]-24U%`$YO('-E('!U
M961E(&'Q861I<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@96YL87IA
M<B!A;"!S97)V:61O<B!,1$%0+@!.;R!S92!P=65D92!C;VUP<F]B87(@96P@
M<V%L9&\N("5S`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R($Q$
M05`N`$YO('-E('!U961E(&-O;F5C=&%R(&%L('-E<G9I9&]R("(E<R(@;65D
M:6%N=&4@1E10.B`E<P!.;R!S92!P=65D92!C<F5A<B!L82!L:7-T82!D92!D
M:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A
M=&]S(%!'4#H@`$YO('-E('!U961E;B!D97-C:69R87(@;&]S(&1A=&]S(%,O
M34E-12X`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@8V]N=&%C=&\N("5S`$YO
M('-E('!U961E(&5L:6UI;F%R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@
M)7,`3F\@<V4@<'5E9&4@96QI;6EN87(@96P@9W5I\VX@9&4@86-T=6%L:7IA
M8VGS;B!D92!C;VYF:6=U<F%C:?-N("(E<R(N`$YO('-E('!U961E(&1E=&5R
M;6EN87)A(&QA(&1I<F5C8VGS;B!D92!C;W)R96\@9&5L(&1E<W1I;F%T87)I
M;RX`3F\@<V4@<'5E9&4@=')A97(@;&$@;&EB<F5T82!D92!D:7)E8V-I;VYE
M<R!C;VUP;&5T82X`3F\@<V4@<'5E9&4@=')A97(@;&$@;&ES=&$@9&4@9&ES
M=')I8G5C:?-N(&-O;7!L971A+@!.;R!S92!P=65D92!T<F%E<B!L82!L:7-T
M82!C;VUP;&5T82!D92!L:7-T87,@9&4@9&ES=')I8G5C:?-N+@!.;R!S92!P
M=65D92!C87)G87(@;&$@97-T<F%T96=I82`B)7,B+@!.;R!S92!P=65D92!C
M<F5A<B!E;"!D:7)E8W1O<FEO("(E<R(N`$YO('-E('!U961E(&]B=&5N97(@
M;&$@8VQA=F4@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=F5S+@!.;R!S
M92!P=65D92!A8G)I<B`B)7,B('!A<F$@97-C<FEB:7(N`$YO('-E('!U961E
M(&%B<FER("5S+@!.;R!S92!P=65D92!A8G)I<B!E;"!M\V1U;&\@9&4@=&%R
M96%S(&1E(&UA;G1E;FEM:65N=&\@)7,`3F\@<V4@<'5E9&4@86)R:7(@96P@
M9&ER96-T;W)I;R`B)7,B+@!.;R!S92!P=65D92!L;V-A;&EZ87(@96P@<V5R
M=FED;W(@3$1!4"X`3F\@<V4@<'5E9&4@;&5E<B`E<RX`3F\@<V4@<'5E9&4@
M<F5S=&%B;&5C97(@;&$@8V]N=')A<V7Q82!D96P@=7-U87)I;R!S;VQI8VET
M861O+B!087)T92!D92!L;W,@9&5T86QL97,@;R!T;V1O<RP@<V]N(&EN8V]R
M<F5C=&]S+B!0<G5E8F4@;W1R82!V97H@;R!P\VYG87-E(&5N(&-O;G1A8W1O
M(&-O;B!E;"!A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA('!A<F$@;>%S(&EN
M9F]R;6%C:?-N+@!.;R!S92!P=65D92!O8G1E;F5R(&QA($%#3"X`3F\@<V4@
M<'5E9&4@;V)T96YE<B!L82!L:6)R971A(&1E(&1I<F5C8VEO;F5S+B`E<P!.
M;R!S92!P=65D92!O8G1E;F5R(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX@
M)7,`3F\@<V4@<'5E9&5N(&]B=&5N97(@;&%S(&QI<W1A<R!D92!D:7-T<FEB
M=6-I\VXN("5S`$YO('-E('!U961E;B!O8G1E;F5R(&QA<R!C87!A8VED861E
M<R!D96P@<V5R=FED;W(`3F\@<V4@<'5E9&4@<F5S=&%U<F%R(&QA(&-O;F9I
M9W5R86-I\VXN`$YO('-E('!U961E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@
M(B5S(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;VYF:6=U<F%C:?-N(&1E
M("5S+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L82!C;VYF
M:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R('5N82!C;W!I82!D92!L
M82!C;VYF:6=U<F%C:?-N.B`E<P!.;R!S92!P=65D92!G=6%R9&%R(&5L(&=U
M:?-N(&1E(&%C='5A;&EZ86-I\VX@9&4@;&$@8V]N9FEG=7)A8VGS;B!E;CH@
M(B5S(BX`3F\@<V4@<'5E9&4@9W5A<F1A<B!L82!C;W!I82`E<R!D92!L82!C
M;VYF:6=U<F%C:?-N+@!.;R!S92!P=65D92!G=6%R9&%R(&5L(&%R8VAI=F\@
M)7,@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@=71I;&EZ87(@=6YA(&1E(&QA
M<R!O<&-I;VYE<R!P87)A(')E<W1A=7)A<B!E;"!C\V1I9V\@9&4@)7,@;R!C
M;W!I87(@;6%N=6%L;65N=&4@82`E<R!E;"!C\V1I9V\@<VEG=6EE;G1E+@!.
M;R!S92!P=65D92!B=7-C87(@96X@96P@<V5R=FED;W(@3$1!4"X`3F\@<V4@
M<'5E9&4@9&5S=FEN8W5L87(@(B5S(BX`3F\@<V4@<'5E9&4@86-T=6%L:7IA
M<B!E;"!C;VYT86-T;RX@)7,`3F\@<V4@<'5E9&4@86-T=6%L:7IA<B!L82!L
M:7-T82!D92!D:7-T<FEB=6-I\VXN("5S`$YO('-E('!U961E(&5S8W)I8FER
M(&QA(&-O;F9I9W5R86-I\VX@9&4@(B5S(CH@)7,`3F\@<V4@<'5E9&4@;&]C
M86QI>F%R(&5L('!A;F5L(&QA=&5R86P@9&4@36]Z:6QL82X@0V]M<')U96)E
M('%U92!E<W3I(&%B:65R=&\N`$YO('-E('!U961E;B!O=&]R9V%R(&%L('5S
M=6%R:6\@(B5S(B!L;W,@<VEG=6EE;G1E<R!D97)E8VAO<R!P87)A(&QA(&-A
M<G!E=&$@(B5S(CH@)7,`5&5X=&\@8V]N=&%D;P!08>US`$-U<G-O<P!#<F5A
M<@!#<F5A('5N(';M;F-U;&\`0W)E87(`0W)E87(@<W5B8V%R<&5T87,`4')I
M=FEL96=I;W,@9&4@8W)E861O<@!.^FUE<F\@9&4@=&%R:F5T82!D92!C<NED
M:71O`$-R;V%C:6$`0W5B80`T($9A<V5S(&%C='5A;&5S`%-E<VEO;F5S(&%C
M='5A;&5S`$AO<F$@86-T=6%L`%523"!A8W1U86P`57-U87)I;W,@86-T=6%L
M97,`5&EE;7!O(&%C='5A;`!#;VYD:6-I\VX@86-T=6%L.B``17-T:6QO(&%C
M='5A;`!097)S;VYA;&EZ82!L87,@=&%R96%S(&$@96IE8W5T87(@86P@:6YI
M8VEA<B!S97-I\VX@96X@)7,N`$-O<G1A<@!#;W)T87(@<V5L96-C:?-N`$-H
M:7!R90!#:7+M;&EC;R`H2T])."U2*0!#:7+M;&EC;R`H5VEN9&]W<RTQ,C4Q
M*0!#:7+M;&EC;R]58W)A;FEA;F\@*$M/23@M52D`4F5P^F)L:6-A($-H96-A
M`$1$`$133B`H=F5A(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5S+W!A
M8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M9'-N+G!H<"D`1&EA<FEA;65N=&4`
MP7)?8F]L(&1A=&]S`$-O;G-U;'1A(&1E(&QA(&)A<V4@9&4@9&%T;W,`1F5C
M:&$`4V4@:&$@<F5C:6)I9&\@;&$@9F5C:&$`4V5L96-C:?-N(&1E(&9E8VAA
M`$3M80!%7VQI;6EN87(@8V]L=6UN80!$:6-I96UB<F4`3OIM97)O<R!D96-I
M;6%L97,`4F5D=6-I<B!S86YG<F%D;P!0;W(@;VUI<VGS;@!#;VQO<B!P;W(@
M;VUI<VGS;@!)9&5N=&ED860@<&]R(&]M:7-I\VX`4VAE;&P@<&]R(&]M:7-I
M\VX`1&5F:6YI8VEO;F5S`"9N8G-P.T5L:6UI;F%R)FYB<W`[`$5L:6UI;F%R
M(&-E;&1A`$5L:6UI;F%R(&=R=7!O`$5L:6UI;F%R(')E9VES=')O`$5L:6UI
M;F%R('!R:79I;&5G:6\`16QI;6EN87(@>2!V86-I87(@;65N<V%J97,`16QI
M;6EN87(@8V5L9&$`16QI;6EN87(@8V]L=6UN80!%;&EM:6YA<B!P;&%N=&EL
M;&%S(&%L=&5R;F%T:79A<R!E>&ES=&5N=&5S`$5L:6UI;F%R(&UE;G-A:F5S
M`$5L:6UI;F%R('!R:79I;&5G:6]S(&1E("(E<R(`OT5L:6UI;F%R('!R:79I
M;&5G:6]S('!A<F$@(B5S(B!Y(&-U86QQ=6EE<B!P<FEV:6QE9VEO(&1E<V-E
M;F1I96YT93\`16QI;6EN87(@9FEL80!%;&EM:6YA<B!I9&5N=&ED860@<V5L
M96-C:6]N861A`$5L:6UI;F%R('-U8F-A<G!E=&%S`$5L:6UI;F$@;&$@8V]L
M=6UN82!A8W1U86P`16QI;6EN82!L82!F:6QA(&%C='5A;`!392!H82!E;&EM
M:6YA9&\@96P@9W5I\VX@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U
M<F%C:?-N("(E<R(N`$AO<F$@9&4@96YT<F5G83H`1&EN86UA<F-A`$1E<V-R
M:6)A(&5L('!R;V)L96UA`$1E<V-R:7!C:?-N`$1E=&%L;&5S("AT86UB:>EN
M(&5N(&5L(&%R8VAI=F\@9&4@<F5G:7-T<F\@9&4@2&]R9&4I.@!392!H86X@
M<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI;FES=')A9&]R
M+@!$97-A<G)O;&QO`%!U;G1O(&1E(&-O;F1E;G-A8VGS;@!0=6YT;R!D92!C
M;VYD96YS86-I\VX@9&4@;&$@^FQT:6UA(&AO<F$Z(`!0=6YT;R!D92!C;VYD
M96YS86-I\VXZ(`!$92!I>G%U:65R9&$@82!D97)E8VAA`$1E(&1E<F5C:&$@
M82!I>G%U:65R9&$`1&ER96-T;W)I;P"_36]S=')A<B!E;B!F;W)M871O(&1E
M(#(T+6AO<F%S/P!/<&-I;VYE<R!D92!6:7-U86QI>F%C:?-N`$UO<W1R87(@
M<')O;O-S=&EC;R!D971A;&QA9&\`36]S=')A<B!P<F]N\W-T:6-O("A4048I
M`$9O<FUA=&\@9&4@=FES=7IA;&EZ86-I\VX`3F]T:69I8V%C:?-N(&1E(&-O
M;G-U;'1A`$1J:6)O=71I`$YO(&5L:6UI;F%R`$YO(&%C8V5D97(@9&ER96-T
M86UE;G1E(&$@;6%I;G1E;F%N8V4N<&AP`+]#;VYT:65N92!L82!P<FEM97)A
M(&9I;&$@;&]S(&YO;6)R97,@9&4@;&]S(&-A;7!O<S\@4VD@97,@87/M+"!S
M96QE8V-I;VYE(&5S=&$@8V%S:6QL83H`1&]M:6YI8V$`4F5P^F)L:6-A($1O
M;6EN:6-A;F$`OTYO(&1I<W!O;F4@9&4@8W5E;G1A/R!3;VQI8^UT96QA+@!$
M97-C87)G87(`1&5S8V%R9V%R("5S`$1E<V-A<F=A<B!L82!C;VYF:6=U<F%C
M:?-N(&=E;F5R861A(&-O;6\@=6X@9W5I\VX@4$A0+@!,:7-T82!D97-P;&5G
M86)L90!$<F]G87,`0V]R<F5O`$-O;G1R;VQA9&]R(&1E('!A<V%R96QA($-O
M<G)E;RUA+5--4R!P87)A('!R;W9E961O<F5S('%U92!P<F]P;W)C:6]N96X@
M97-T92!S97)V:6-I;RX`15)2`$5C=6%D;W(`)FYB<W`[36]D:69I8V%R)FYB
M<W`[`$UO9&EF:6-A<B!B;&]Q=64`36]D:69I8V%R(&=R=7!O`$UO9&EF:6-A
M<B!P<FEV:6QE9VEO`$UO9&EF:6-A<B!P<FEV:6QE9VEO<P!-;V1I9FEC87(@
M<')I=FEL96=I;W,@9&4@)7,`36]D:69I8V%R(&]P8VEO;F5S(&1E.@!-;V1I
M9FEC87(@<')I=FEL96=I;W,@9&4@(B5S(@!-;V1I9FEC87(@<')I=FEL96=I
M;W,@9&4@)7,`161U8V%C:?-N`$5G:7!T;P!%;"!386QV861O<@!%;&5M96YT
M;RXN+@!%;0!#;W)R96\`1&ER96-C:?-N(&1E(&-O<G)E;P!,87,@9&ER96-C
M:6]N97,@9&4@8V]R<F5O('1I96YE;B!Q=64@8V]I;F-I9&ER+@!#;W)R96\@
M8V]N(&-O;F9I<FUA8VGS;@!087-A<F5L82!#;W)R96\M82U335,`16UO=&EC
M;VYE<P!-96YS86IE(&5N(&)L86YC;P!297-U;'1A9&\@96X@8FQA;F-O+@!,
M:6UP:6%R('3I<FUI;F]S(&1E(&+Z<W%U961A`+]097)M:71I<B!I;G-E<F-I
M\VX@9&4@:6WA9V5N97,@9&4@;&%S($=A;&5R[6%S(&1E(&9O=&]S/P"_4&5R
M;6ET:7(@;65N^B!D92!C;VYT97AT;R!D96P@8F]T\VX@9&5R96-H;R!D96P@
M<F%T\VX_`$'Q;R!D92!T97)M:6YA8VGS;@!!9W)A;F1A<B!E9&ET;W(`26YT
M<F]D=7IC82!U;F$@<')E9W5N=&$@9&4@<V5G=7)I9&%D('%U92!S92!L92!F
M;W)M=6QA<N$@<VD@<')E8VES82!R96%J=7-T87(@;&$@8V]N=')A<V7Q82P@
M<"YE+B`GOT-UX6P@97,@96P@;F]M8G)E(&1E('-U(&UA<V-O=&$_)SH`26YT
M<F]D=7IC82!A<77M(&QA(%523"!D92!L82!I;6%G96X`26YT<F]D=7IC82!L
M87,@;&5T<F%S(&1E(&1E8F%J;SH`1W5I;F5A($5C=6%T;W)I86P`17)I=')E
M80!%<G)O<@!%<G)O<B!A;"!C<F5A<B!E;"!B;&]Q=64Z("5S`$5R<F]R(&%L
M(&5L:6UI;F%R(&%N8VQA(&1E('-I;F-R;VYI>F%C:?-N.B`E<P!%<G)O<B!A
M;"!E;&EM:6YA<B!E;"!R96=I<W1R;R!D92!S:6YC<F]N:7IA8VGS;CH@)7,`
M17)R;W(@86P@;V)T96YE<B!C;VYT96YI9&]S.B`E<P!%<G)O<B!A;"!A8W1U
M86QI>F%R(&QA(&-O;G1R87-E\6$Z("5S`$5R<F]R(&-O;B!E;"!M96YS86IE
M(&1E(&-O<G)E;RX`17)R;W(@86P@97-C<FEB:7(@(B5S(BX`17-T;VYI80!%
M=&EO<.UA`,ET;FEC;P!%=7)O<&$`0V%D82`Q-2!M:6YU=&]S`$-A9&$@,B!M
M:6YU=&]S`$-A9&$@,S`@<V5G=6YD;W,`0V%D82`U(&UI;G5T;W,`0V%D82!I
M;FEC:6\@9&4@<V5S:?-N`$-A9&$@;65D:6$@:&]R80!#861A(&UI;G5T;P!6
M86QO<F5S(&1E(&5J96UP;&\Z`$5J96-U=&%R`$5X<&%N9&ER`$UO<W1R87(@
M8F%R<F$@;&%T97)A;`!S92!E<W!E<F%B82`G*2<`4V4@97-P97)A8F$@=6YA
M(/IN:6-A('!A;&%B<F$@;R!U;B!TZ7)M:6YO(&1E(&+Z<W%U961A(&5N=')E
M8V]M:6QL861O`$9E8VAA(&1E('9E;F-I;6EE;G1O`$5X<&]N96YT90!#;VQO
M<B!D92!L971R80!#87)G87(@;&$@8V]N9FEG=7)A8VGS;B!P;W(@1E10`$9A
M;&QO(&%L('1R865R(&QA<R!P<F5F97)E;F-I87,N`$EN8V%P87H@9&4@8V]N
M96-T87)S92!A;"!S97)V:61O<B!,1$%0+@!);F-A<&%Z(&1E(&-O;F5C=&%R
M<V4@86P@<V5R=FED;W(@4TU"+@!&86QL;R!A;"!C;W!I87(@9&4@(B5S(BX`
M1F%L;&\@86P@8V]P:6%R(&$@(B5S(BX`1F%L;&\@86P@8W)E87(@=6YA(&-O
M;F5X:?-N(%-!4TP`1F%L;&\@86P@=')A<VQA9&%R("(E<R(N`$9A;&QO(&%L
M(')E8W5P97)A<CH@)7,`1&5S<&5J861O`$ES;&%S($UA;'9I;F%S("A&86QK
M;&%N9"D`27-L87,@1F%R;V4`17)R;W(@:7)R96-U<&5R86)L93H`1F%X`$9A
M>&5S`$9E8G)E<F\`4V4@<VEE;G1E(&-O;6\`4V4@<VEE;G1E(&-O;6\Z(`!0
M;V-A<R!L;'5V:6%S`$5S8V%S;R!A9W5A8V5R;R!D92!N:65V90!-871R:7H@
M9&4@8V%M<&]S`$-!4%1#2$$@9&4@1FEG;&5T`$QE=')A(&1E($9I9VQE=`!&
M:6II`$%R8VAI=F\`3KH@9&4@87)C:&EV;W,Z("5S(&%R8VAI=F\`3KH@9&4@
M87)C:&EV;W,Z("5S(&%R8VAI=F]S`$%R8VAI=F]S`$YO;6)R92!D92!A<F-H
M:79O`%-E;&5C8VGS;B!D92!A<F-H:79O`$-A<F=A<B!A<F-H:79O`$QA(&-A
M<F=A(&1E(&%R8VAI=F]S(&YO(&5S=.$@<V]P;W)T861A+@!&:6QT<F]S`$9I
M;FQA;F1I80!#=6%R=&\@8W)E8VEE;G1E`$-U87)T;R!C<F5C:65N=&4`4F%Z
M\VX@9FEJ80!6;VQT96%R`$1I<W!O<VEC:?-N`$YI96)L80!,82!C87)P971A
M("5S(&YO(&5X:7-T92X`0V]L;W(@9&4@;&5T<F$`0V]M:61A`%!A<F$@;F%V
M96=A9&]R97,@<75E(&YO(&%D;6ET86X@:6WA9V5N97,`4')O;O-S=&EC;R`H
M5$%&*0!$[6%S(&1E;"!P<F]N\W-T:6-O("AT96YG82!E;B!C=65N=&$@<75E
M(&5L('!R;V[S<W1I8V\@9F%C:6QI=&%D;R!I;F-L=7EE('1A;G1O(&5L(&3M
M82!C;VUO(&QA(&YO8VAE.R!U;B!N^FUE<F\@9W)A;F1E('-E('1R861U8VER
MX2!E;B!U;B!B;&]Q=64@;75Y(&%N8VAO*0"_2&$@;VQV:61A9&\@;&$@8V]N
M=')A<V7Q83\`1F]R;75L87)I;W,`1F]R='5N80!4:7!O(&1E(&9O<G1U;F$`
M1F]R='5N87,`1F]R='5N87,@,@!&;W)O<P!2965N=NUO<P!6:64`1G)A;65S
M`$9R86YC:6$`1G)A;F-I82P@365T<F]P;VQI=&%N80!'=6%Y86YA(&9R86YC
M97-A`%!O;&EN97-I82!F<F%N8V5S80!497)R:71O<FEO<R!F<F%N8V5S97,@
M9&5L('-U<@!$90!$96P@`$1E<V-R:7!C:?-N(&-O;7!L971A`$QU;F$@;&QE
M;F$`3F]M8G)E(&-O;7!L971O`$=A8O-N`$=A;&5R[6$@9&4@;&$@<75E(&]B
M=&5N97(@;&$@:6UA9V5N`$=A;&5R[6$Z`$=A;6)I80!'96YE<F%R(&-O;F9I
M9W5R86-I\VX@9&4@)7,`0_-D:6=O(&=E;F5R861O`$=E;W)G:6$`06QE;6%N
M:6$`1VAA;F$`1VEB<F%L=&%R`$YO;6)R92!I;F1I8V%D;P!/<&-I;VYE<R!G
M;&]B86QE<P!)<@!';V5D96P`36%P87,@9&4@1V]O9VQE`$+Z<W%U961A(&5N
M($=O;V=L90!%<V-A;&$@9&4@9W)I<V5S`$=R96-I80!'<FEE9V\@*$E33RTX
M.#4Y+3<I`$=R;V5N;&%N9&EA`$=R86YA9&$`061M:6YI<W1R86-I\VX@9&4@
M9W)U<&]S`$QO<R!N;VUB<F5S(&1E(&=R=7!O(&YO('!U961E;B!D96IA<G-E
M(&5N(&)L86YC;P!'<F]U<%]L9&%P.B!.;R!S92!P=65D92!A\6%D:7(@96P@
M9W)U<&\@)7,N(,ES=&\@97,@;&\@<75E(&1I:F\@96P@<V5R=FED;W(Z(`!'
M<F]U<%]L9&%P.B!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&=R=7!O("5S`$=R
M;W5P7VQD87`Z($EN8V%P87H@9&4@86-T=6%L:7IA<B!E;"!G<G5P;R`E<P!'
M<G5P;W,`1W5A9&%L=7!E`$=U86T`1W5A=&5M86QA`$=U97)N97-E>0!0<FEV
M:6QE9VEO<R!D92!I;G9I=&%D;P!,+B!I;G9I=&%D;W,`1W5I;F5A`$=U:6YE
M82U":7-S874`1W5A>6%N80!(5$U,`$A434P@<V4@;FEE9V$@8V]B87)D96UE
M;G1E(&$@96QI;6EN87(@;&$@^FQT:6UA(&-E;&1A(&1E(&QA(&9I;&$N`$A4
M34Q!<F5A('-E(&YI96=A(&-O8F%R9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL
M=&EM82!C;VQU;6YA(&1E(&QA('1A8FQA+@!(5$U,('-E(&YI96=A(&-O8F%R
M9&5M96YT92!A(&5L:6UI;F%R(&QA(/IL=&EM82!F:6QA(&1E(&QA('1A8FQA
M+@!.;R!S92!E;F-O;G1R\R!L82!A=71E;G1I9FEC86-I\VX@2%144"X`2&%I
M=.T`06QG;W)I;6\@2&%S:`!.96)L:6YA`$-A8F5C97)A`$-A8F5C97)A<P!)
M<VQA($AE87)D(&4@27-L87,@36-$;VYA;&0`5&]R;65N=&$@=')O<&EC86P@
M:6YT96YS80!(96)R96\@*$E33RTX.#4Y+3@M22D`06QT=7)A`$%Y=61A`$%Y
M=61A(&1E;"!E9&ET;W(`07EU9&%N=&4`2&5M:7-F97)I;P!!<77M('1I96YE
M(&5L(&-O;6EE;GIO(&1E;"!A<F-H:79O.@!!;'1A`%]);FEC:6\`4V%N=&$@
M4V5D92`H0VEU9&%D+45S=&%D;R!D96P@5F%T:6-A;F\I`$EN:6-I;P!$;VUI
M8VEL:6\`1&ER96-T;W)I;R!P97)S;VYA;`!496SI9F]N;R!P87)T:6-U;&%R
M`$AO;F1U<F%S`$AO;F<@2V]N9P!(;W)D90!(;W)D92]+;VQA8CH@4V4@:&%N
M(&5N8V]N=')A9&\@9&%T;W,@6$U,("5S(&YO(';A;&ED;W,@96X@96P@;65N
M<V%J92`E<P!(;W)D92]+;VQA8CH@3FEN9_IN(&UE;G-A:F4@8V]R<F5S<&]N
M9&4@86P@;V)J971O("5S`$AO<F1E+TMO;&%B.B!.;R!S92!E;F-O;G1R\R!U
M;B!O8FIE=&\@9&4@=&EP;R`E<R!E;B!E;"!M96YS86IE("5S`$AO<F1E+TMO
M;&%B.B!392!H82!E;&EM:6YA9&\@8V]R<F5C=&%M96YT92`E<R`B)7,B`$AO
M<F1E+TMO;&%B.B!%;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!P<F5C:7-A(&1E
M(&QA(&5X=&5N<VGS;B!02%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($EN8V%P
M87H@9&4@8W)E87(@;G5E=F\@X7)B;VP@6$U,(&1E;"!O8FIE=&\@)7,`2&]R
M9&4O2V]L86(Z($EN8V%P87H@9&4@96QI;6EN87(@)7,@(B5S(CH@)7,`2&]R
M9&4O2V]L86(Z($EN8V%P87H@9&4@;V)T96YE<B!)1"!-24U%(&1E(&QA('!A
M<G1E(&1E('1I<&\@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN8W)O
M;FEZ87(@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z($EN8V%P87H@9&4@<VEN
M8W)O;FEZ87(@96QE;65N=&]S(&-O;7!A<G1I9&]S.B`E<P!(;W)D92]+;VQA
M8CH@16QE;65N=&\@8V]M<&%R=&ED;R!D97-C;VYO8VED;R`B)7,B`$SM;F5A
M(&AO<FEZ;VYT86P`36%R9V5N(&AO<FEZ;VYT86P`2&]R:7IO;G1A;#H`OT/S
M;6\@;&QE9_,@:&%S=&$@87%U[3\@**%#;VUU;NUQ=65L;RP@<&]R(&9A=F]R
M(2D`OT-U86YT87,@8V]L=6UN87,@9&5S96$@8V]M8FEN87(_`+]#=>%N=&]S
M(&-A;7!O<R`H8V]L=6UN87,I(&AA>3\`OT-U86YT87,@9FEL87,@9&5S96$@
M8V]M8FEN87(_`$AU;65D860`2'5M961A9#H@`$AU;6]R:7-T87,`2'5N9W+M
M80!(82!F86QL861O(&QA(&-R96%C:?-N(&1E;"!B=7KS;B!)34%0.B`E<P!(
M82!F86QL861O(&QA(&5L:6UI;F%C:?-N(&1E;"!B=7KS;B!)34%0.B`E<P!(
M82!F86QL861O(&QA(&-R96%C:?-N(&1E(&5S<&%C:6\@87-I9VYA9&\@9&5L
M(&)U>O-N($E-05`Z("5S`$1I<F5C8VGS;B!)4`!,82!D:7)E8V-I\VX@25`@
M;F\@97-TX2!D:7-P;VYI8FQE+@!,82!D:7)E8V-I\VX@25`@;F\@97-TX2!E
M;G1R92!B;&]Q=65S($-)1%(@<&5R;6ET:61O<RX`5FEO;&%C:?-N(&QO8VMD
M;W=N($E0+@!)7VYS97)T87(@9FEL82!E;F-I;6$`27-L86YD:6$`4_-L;R!I
M8V]N;W,`26-O;F]S(&1E("5S`$EC;VYO<R!C;VX@=&5X=&\`3F]M8G)E(&1E
M(&QA(&ED96YT:61A9#H`4VD@;F\@<V4@;75E<W1R82!C;W)R96-T86UE;G1E
M+"`E<R!P87)A(&%B<FER;&\@96X@=6YA('9E;G1A;F$@;G5E=F$N`%-I(&YO
M('9E(&YI;F?Z;B!I8V]N;R!M961I86YT92!);G1E<FYE="!%>'!L;W)E<BP@
M<'5E9&4@=&5N97(@<75E(&%C=&EV87(@97-T82!C87-I;&QA('!A<F$@9&5S
M86-T:79A<B!L82!T<F%N<W!A<F5N8VEA(%!.1RX`4VD@=F4@97-T92!M96YS
M86IE('-I;B!N:6YG=6YA(&EM86=E;BP@;&$@:6UA9V5N('%U92!Q=6EE<F4@
M8V%R9V%R(&YO('-E('!U961E(&UO<W1R87(@96X@<W4@;F%V96=A9&]R+@!6
M:7-T82!P<F5V:6$Z`%523"!D92!L82!I;6%G96X`55),(&1E(&QA(&EM86=E
M;CH`26UA9V5N(&1E(&QA(&=A;&5R[6$`26UA9V5N(&1E(&QA(&=A;&5R[6$Z
M`%-E(&AA(&-A<F=A9&\@;&$@:6UA9V5N`$EMX6=E;F5S`$EM<&]R=&%R+"!P
M87-O("5D`$-A;7!O(&EM<&]R=&%D;SH@)7,`0V%M<&]S(&EM<&]R=&%D;W,Z
M`$EN7W-E<G1A<B!F:6QA(&1E8F%J;P!392!H82!I;F1I8V%D;R!U;B!C\V1I
M9V\@9&4@86-C:?-N(&EN8V]R<F5C=&\N`$YO;6)R92!D92!U<W5A<FEO('DO
M;R!C;VYT<F%S9?%A(&EN8V]R<F5C=&]S+@!.;VUB<F4@9&4@=7-U87)I;R!O
M(&1I<F5C8VGS;B!A;'1E<FYA=&EV82!I;F-O<G)E8W1O<RX@5G5E;'9A(&$@
M:6YT96YT87)L;R!O('#S;F=A<V4@96X@8V]N=&%C=&\@8V]N(&5L(&%D;6EN
M:7-T<F%D;W(@9&4@<VES=&5M87,@<&%R82!MX7,@:6YF;W)M86-I\VXN`$%U
M;65N=&%R('-A;F=R861O`$EN9&EA`%5S=6%R:6]S(&EN9&EV:61U86QE<P!)
M;F1O;F5S:6$`26YF;W)M86-I\VX`26YF;W)M86-I\VX`3&$@:6YF;W)M86-I
M\VX@>6$@;F\@97-TX2!D:7-P;VYI8FQE+@!);G-E<G1A<B!C7V]L=6UN82!D
M971RX7,`26YS97)T87(@:6UA9V5N`$EN<V5R=&%R('1A8FQA`$EN<V5R=&%R
M(';M;F-U;&\@5V5B`$EN<V5R=&%R(%]C;VQU;6YA(&1E;&%N=&4`26YS97)T
M82!U;F$@;G5E=F$@8V]L=6UN82!D971RX7,@9&4@;&$@86-T=6%L`$EN<V5R
M=&$@=6YA(&YU979A(&-O;'5M;F$@9&5L86YT92!D92!L82!A8W1U86P`26YS
M97)T82!U;F$@9FEL82!N=65V82!D96)A:F\@9&4@;&$@86-T=6%L`$EN<V5R
M=&$@=6YA(&9I;&$@;G5E=F$@96YC:6UA(&1E(&QA(&%C='5A;`!);G-E<G1A
M('5N('#A<G)A9F\@=')A<R!E;"!N;V1O(&%C='5A;`!);G-E<G1A('5N('#A
M<G)A9F\@86YT97,@9&5L(&YO9&\@86-T=6%L`$EN<V5R=&%R('!L86YT:6QL
M82!A;'1E<FYA=&EV80!);G-E<G1A<B!U;F$@9&ER96-C:?-N(&1E(&-O<G)E
M;R!E;B!L82!Q=64@<F5C:6)I<B!L82!C;VYT<F%S9?%A.@!);G-E<G1A<B!C
M96QD82!D971RX7,`26YS97)T87(@8V5L9&$@86YT97,`26YS97)T87(@8V]L
M=6UN82!D971RX7,`26YS97)T87(@8V]L=6UN82!A;G1E<P!);G-E<G1A<B!M
M96YS86IE<P!);G-E<G1A<B!PX7)R869O(&1E='+A<P!);G-E<G1A<B!PX7)R
M869O(&%N=&5S`$EN<V5R=&%R(&9I;&$@9&5B86IO`$EN<V5R=&%R(&9I;&$@
M96YC:6UA`$EN<V5R=&%R(&QA(')E<W!U97-T82!N96-E<V%R:6$@82!L82!P
M<F5G=6YT82!D92!S96=U<FED860Z`$EN<V5R=&%R+TUO9&EF:6-A<B!I;6%G
M96X`26YS97)T87(O36]D:69I8V%R(';M;F-U;&\`4V%L9&\@:6YS=69I8VEE
M;G1E('!A<F$@96YV:6%R(&$@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+@!3
M86QD;R!I;G-U9FEC:65N=&4N`$5N=&5R;P!,:7-T82!D92!E;G1E<F]S`%5$
M2"`H0V%B96-E<F$@9&4@1&%T;W,@9&4@57-U87)I;RD@;F\@=N%L:61A+@!$
M871O<R!:25`@;F\@=N%L:61O<P!!<&QI8V%C:?-N(&YO(';A;&ED82X`240@
M9&4@;&]T92!N;R!VX6QI9&\N`%-E(&AA;B!E;G9I861O(&1A=&]S(&YO(';A
M;&ED;W,N`$1I<F5C8VGS;B!D92!C;W)R96\@;F\@=N%L:61A+@!&;W)M871O
M(&1E(&%R8VAI=F\@;F\@=N%L:61O`$-L879E(&1E(&QI8V5N8VEA(&YO(';A
M;&ED82X`4V4@:&$@:6YD:6-A9&\@=6YA('5B:6-A8VGS;B!N;R!VX6QI9&$N
M`&US9U]T>7!E(&YO(';A;&ED;RX`87!I7VED(&YO(';A;&ED;R!O(&1E<V%P
M87)E8VED;RX`4&%RX6UE=')O<R!N;R!VX6QI9&]S(&\@9&5S87!A<F5C:61O
M<RX`4')I=FEL96=I;R!D96P@<&%D<F4@;F\@=N%L:61O<RX`240@9&4@87-O
M8VEA9&\@;F\@=N%L:61O+@!#\V1I9V\@9&4@<')O9'5C=&\@;F\@=N%L:61O
M+@!0<F]T;V-O;&\@;F\@=N%L:61O+@!$97-T:6YA=&%R:6\@;F\@=N%L:61O
M.B`B)7,B`$]B:F5T;R!C;VUP87)T:61O(&YO(';A;&ED;RX`1&ER96-C:?-N
M(&1E;"!R96UI=&5N=&4@;F\@=N%L:61A`$1A=&]S('5N:6-O9&4@;F\@=N%L
M:61O<RX`26YV96YT87)I;P!);G9E<G1I<B!S96QE8V-I\VX`27+A;BP@4F5P
M^F)L:6-A($ES;.%M:6-A(&1E`$ER87$`27)L86YD80!)<VQA(&1E($UA;@!"
M;W)R87-C87,@86ES;&%D87,`27-R865L`$5M:7-O<@!#=7)S:79A`$ET86QI
M80!*86UA:6-A`$5N97)O`$IA</-N`$IA<&]NZ7,@*$E33RTR,#(R+4I0*0!*
M97)S97D`2F]R9.%N`$IU;&EO`$IU;FEO`$IU<W1I9FEC87(`06QI;F5A<B!A
M;"!C96YT<F\`2G5S=&EF:6-A<@!!;&EN96%R(&$@;&$@:7IQ=6EE<F1A`$%L
M:6YE87(@82!L82!D97)E8VAA`$MA>F%K:'-T86X`OT-O;G-E<G9A<B!E;"!O
M<FEG:6YA;#\`2V5N>6$`16P@<V5R=FED;W(@2V5R8F5R;W,@:&$@<F5C:&%Z
M861O(&QA(&%U=&5N=&EF:6-A8VGS;BX`3F]V871O<R!D96P@2V5R;F5L`$-R
M96%C:?-N(&1E(&-L879E`$AU96QL82!D:6=I=&%L(&1E(&QA(&-L879E`%1A
M;6'Q;R!D92!C;&%V90!4:7!O(&1E(&-L879E`%5S;R!D92!L82!C;&%V93H`
M3&$@8VQA=F4@>6$@97AI<W1E(&5N(&5L('-E<G9I9&]R(&1E(&-L879E<R!P
M^F)L:6-O+@!.:?%O<P!+:7)I8F%T:0!#;W)E82P@4F5P^F)L:6-A(%!O<'5L
M87(@1&5M;V-RX71I8V$@9&4`0V]R96$L(%)E</IB;&EC82!D90!#;W)E86YO
M("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`%]$:7-T<FEB=6-I\VX`261I
M;VUA`$QA;RP@4F5P^F)L:6-A($1E;6]C<N%T:6-A(%!O<'5L87(`0W5A<G1O
M(&UE;F=U86YT90#:;'1I;6\@8V%M8FEO(&1E(&-O;G1R87-E\6$`0W5A<G1O
M(&UE;F=U86YT90#:;'1I;6$@86-T=6%L:7IA8VGS;CH`VFQT:6UA('-E<VGS
M;CH@)7,`VFQT:6UA('-E<VGS;CH@)7,@9&5S9&4@)7,`VFQT:6UA('-E<VGS
M;CH@3G5N8V$`3&%T=FEA`$QE>65S`$1I<W1R:6)U8VGS;@!$96IA<B!E;B!B
M;&%N8V\@<&%R82!E;&EM:6YA<B!E;"!B;W)D90!,96)A;F]N`$EZ<75I97)D
M80!#86)E8V5R82!I>G%U:65R9&$`5F%L;W)E<R!D92!L82!I>G%U:65R9&$`
M3&5S;W1H;P!.:79E;`!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H:7)I>6$`
M3&EE8VAT96YS=&5I;@!,:6=E<F$@;&QO=FEZ;F$`3&QU=FEA(&QI9V5R80!,
M;'5V:6$@;&EG97)A(&UA='5T:6YA`$QL=79I82!L:6=E<F$@=F5S<&5R=&EN
M80!!9W5A8V5R;R!L:6=E<F\`3&QU=FEA<R!Y('1R=65N;W,`3F5V861A('-U
M879E`$QI9V5R;R!A9W5A8V5R;R!D92!N:65V90!#:&%S8V%R<FEL;&\`5NUN
M8W5L;P!%;"!V[6YC=6QO(&%P=6YT82!A.@!6:6YC=6QA<B!D:7)E8V-I\VX@
M9&4@8V]R<F5O(&$@;&$@<.%G:6YA(&1E(&-O;7!O<VEC:?-N(&%L(&UO<W1R
M87(`5NUN8W5L;W,`0V]O:VEE($QI;G5X`$QI<W1A<B`M(&5L('5S=6%R:6\@
M<'5E9&4@97AA;6EN87(@;&$@8V%R<&5T80!,:7-T87(@8F%S97,@9&4@9&%T
M;W,`3&ES=&%R('1E;6%S(&1E(&%Y=61A`$QI<W1A<B!T86)L87,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`2&$@9F%L;&%D;R!E
M;"!L:7-T861O(&1E(&QA<R!S97-I;VYE<SH@)7,`2&$@9F%L;&%D;R!E;"!L
M:7-T861O(&1E('5S=6%R:6]S.B`E<P!%;"!L:7-T861O(&1E('5S=6%R:6]S
M(&5S=.$@9&5S:&%B:6QI=&%D;RX`3&ET97)A='5R80!,:71U86YI80!,97EE
M;F1O+BXN`$AO<F$@;&]C86PZ(`!)9&EO;6$@>2!H;W)A`%5B:6-A8VGS;@!)
M;FEC:6%R('-E<VGS;@!296=I<W1R;R!D92!L87,@<V5S:6]N97,@9&4@<VEN
M8W)O;FEZ86-I\VX@86YT97)I;W)E<P!386QI<@!);FEC:6%R('-E<VGS;@!4
M87)E87,@9&4@:6YI8VEO(&1E('-E<VGS;@!&86QL\R!E;"!I;FEC:6\@9&4@
M<V5S:?-N('!O<G%U92!I;G1R;V1U:F\@:6YC;W)R96-T86UE;G1E('-U(&YO
M;6)R92!D92!U<W5A<FEO(&\@8V]N=')A<V7Q82X`1F%L;/,@96P@:6YI8VEO
M(&1E('-E<VGS;BX`5&5X=&\@8V]M<&QE=&\`06UO<@!"86IA`$%L9F%B971O
M(&=R:65G;R!E;B!M:6[Z<V,N`$%L9F%B971O(&QA=&EN;R!E;B!M:6[Z<V,N
M`$[Z;65R;W,@<F]M86YO<R!E;B!M:6[Z<V,N`$QU>&5M8G5R9V\`34T`34]4
M1`!%;"!A9&IU;G1O($U3+51.148@;F\@8V]N=&5N[6$@9&%T;W,N`$U31P!-
M86-A;P!-86-E9&]N:6$L($%N=&EG=6$@4F5P^F)L:6-A(%EU9V]S;&%V82!D
M90!-861A9V%S8V%R`$UA9VEA`$-O<G)E;P!!9&TN(&-O<G)E;P!#<F5A<B!?
M=NUN8W5L;RXN+@!-86QA=VD`36%L87-I80!-86QD:79A<P!-86QI`$UA;'1A
M`$=E<W1I;VYA(&QA(&QI<W1A(&1E(&-A=&5G;W+M87,@8V]N(&QA('%U92!E
M=&EQ=65T87(@96QE;65N=&]S('D@;&]S(&-O;&]R97,@87-O8VEA9&]S(&$@
M9&EC:&%S(&-A=&5G;W+M87,N`$UA<&$@;6%P,C0`36%P82!M87!Q=65S=`!#
M;W)R97-P;VYD96YC:6%S(&%L;6%C96YA9&%S+@!-87)Z;P!-87)G96X`36%R
M8V%R(&-O;B!L87,@8F%N9&5R87,@9&4@3&7M9&\O4VEN(&QE97(`36%R8V%R
M(&-O;B!O=')A<B!B86YD97)A<R`H<"YE+B!);7!O<G1A;G1E+U)E<W!O;F1I
M9&\I`$ES;&%S($UA<G-H86QL`$UA<G1I;FEC80!#86UP;W,@8V]I;F-I9&5N
M=&5S`$UA=7)I=&%N:6$`36%U<FEC:6\`4V%L9&\@;>%X:6UO('!E<FUI=&ED
M;RX`4V4@:&$@<V]B<F5P87-A9&\@96P@;OIM97)O(&WA>&EM;R!D92!P87)T
M97,@9&4@;65N<V%J92X`5&5M<"X@;>%X:6UA(/IL=&EM87,@,C0@:&]R87,Z
M(`!496UP+B!MX7AI;6$@^FQT:6UA<R`V(&AO<F%S.B``3OIM97)O(&WA>&EM
M;R!D92!B;&]Q=65S(&1E;"!P;W)T86P`3&]N9VET=60@;>%X:6UA`$UA>6\`
M36%Y;W1T90!-961I8VEN80!-:65M8G)O<P!&;W)M871O(&1E;"!M96[Z.@!#
M;VUB:6YA<B!C96QD87,`365N<V%J90!392!H82!C;VUP<F]B861O(&-O<G)E
M8W1A;65N=&4@96P@;65N<V%J92!P97)O(&YO('-E('!U961E('9E<FEF:6-A
M<B!E;"!C97)T:69I8V%D;R!D96P@9FER;6%N=&4N`$UE;G-A:F4@8V%D=6-A
M9&\N`%1I<&\@9&4@;65N<V%J90!4:65M<&\@9&4@365T87(`0FQO<75E($UE
M=&%R(&YO(&1I<W!O;FEB;&4N`$)L;W%U92!-971A<B!N;R!D:7-P;VYI8FQE
M+B!392!H86X@<F5G:7-T<F%D;R!L;W,@9&5T86QL97,@<&%R82!E;"!A9&UI
M;FES=')A9&]R+@!.;R!E<W3A(&-O;F5C=&%D82!L82!-971A<D1"`$WI=&]D
M;P!%;"!MZ71O9&\@(B5S(B!N;R!E<W3A(&1E9FEN:61O`$WI=&]D;R!N;R!D
M969I;FED;RX@3>ET;V1O(&QL86UA9&\Z("5S`$WI=')I8V\`3>EJ:6-O`$UI
M8W)O;F5S:6$L($5S=&%D;W,@1F5D97)A9&]S(&1E`$5N(&UE9&EO`%1I<&\@
M36EM90!496UP+B!M[6XN(&QA<R#Z;'1I;6%S(#(T(&AO<F%S.B``5&5M<"X@
M;>UN+B!L87,@^FQT:6UA<R`V(&AO<F%S.B``5&]D87;M82!N;R!H82!E>'!I
M<F%D;R!L82!A;G1I9_QE9&%D(&WM;FEM82!D92!L82!C;VYT<F%S9?%A`%)E
M9FQE:F%R`$UI<V-E;.%N96$`4&%Q=65T92!014%2($A45%!?4F5Q=65S="!D
M97-A<&%R96-I9&\N`$9A;'1A(&QA(&-O;F9I9W5R86-I\VXN(%1I96YE('%U
M92!G96YE<F%R;&$@86AO<F$@<VD@9&5S96$@=71I;&EZ87(@97-T82!A<&QI
M8V%C:?-N+@!)1"!D92!M96YS86IE(&1E<V%P87)E8VED;RX`4&%Q=65T92!0
M14%2($UA:6P@9&5S87!A<F5C:61O+@!)1"!D92!S97-I\VX@9&5S87!A<F5C
M:61O+@!,=6X`0V]R<F5O(&WS=FEL`$UO9&5R861O`%-E(&AA(&UO9&EF:6-A
M9&\@;&$@9F5C:&$`36]D:69I8V%R(%523`!-\V1U;&\`36]L9&%V:6$L(%)E
M</IB;&EC82!D90!-\VYA8V\`36]N9V]L:6$`365S('D@8?%O`$UE;G-U86QM
M96YT90!-;VYT<V5R<F%T`$9A<V5S(&1E(&QA(&QU;F$`4V4@:&%N(&5N8V]N
M=')A9&\@;>%S(&-A;7!O<R!E;B!L82!L[6YE82`E9"!Q=64@;&]S("5D(&5S
M<&5R861O<RX`36%R<G5E8V]S`$9U;F1A;65N=&%L;65N=&4@9&5S<&5J861O
M`$9U;F1A;65N=&%L;65N=&4@;G5B;W-O`$9U;F1A;65N=&%L;65N=&4@;G5B
M;W-O('D@=F5N=&]S;P!&=6YD86UE;G1A;&UE;G1E('-O;&5A9&\`1&5S<&QA
M>F%R(&AA8VEA(&%B86IO`$1E<W!L87IA<B!A(&QA(&EZ<75I97)D80!$97-P
M;&%Z87(@82!L82!D97)E8VAA`$1E<W!L87IA<B!H86-I82!A<G)I8F$`1&5S
M<&QA>F%R(&AA8VEA(&%B86IO`$1E<W!L87IA<B!H86-I82!A<G)I8F$`36]Z
M86UB:7%U90!,:7-T87,@9&5S<&QE9V%B;&5S(&UU;'1I+6YI=F5L`$UA<&$@
M54L@;?IL=&EP;&4`4V5L96-C:?-N(&WZ;'1I<&QE`$ED96YT:61A9`!-:2!I
M9&5N=&ED860`36D@<&]R=&%L`$1I<W1R:6)U8VGS;B!D92!M:2!P;W)T86P`
M37EA;FUA<@!.3RP@3D\@97-T;WD@9&4@86-U97)D;P!.;VUB<F4`3F%M:6)I
M80!.875R=0!.97!A;`!(;VQA;F1A`$%N=&EL;&%S($AO;&%N9&5S87,`55),
M(&)A<V4@9&4@3F5T<V-A<&4`55),(&1E(&%N=6QA8VGS;B!D92!#02!D92!.
M971S8V%P90!54DP@9&4@<&]L[71I8V%S(&1E($-!(&1E($YE='-C87!E`%52
M3"!D92!R96YO=F%C:?-N(&1E($YE='-C87!E`%523"!D92!A;G5L86-I\VX@
M9&4@3F5T<V-A<&4`3F]M8G)E(&1E('-E<G9I9&]R(%-33"!D92!.971S8V%P
M90!#;VUE;G1A<FEO(&1E;"!C97)T:69I8V%D;R!D92!.971S8V%P90!4:7!O
M(&1E(&-E<G1I9FEC861O(&1E($YE='-C87!E`%)E9`!.=6YC80!.=65V82!#
M86QE9&]N:6$`3G5E=F$@8V%T96=O<NUA`$QU;F$@;G5E=F$`3G5E=F\@;F]M
M8G)E(&1E('5S=6%R:6\@*&]P8VEO;F%L*0!.=65V82!:96QA;F1A`$-O;G1R
M87-E\6$@;G5E=F$`3&$@;G5E=F$@8V]N=')A<V7Q82!E>'!I<F%RX2!E;"`E
M>"X`3&%S(&-O;G1R87-E\6%S(&YO(&-O:6YC:61E;BX`3G5E=F$@=F5N=&%N
M82`H7V)L86YK*0!.;W1I8VEA<P!'+B!D92!N;W1I8VEA<P!3:6=U:65N=&4`
M4'+S>&EM87,@-"!F87-E<P!/<&-I;VYE<R!S:6=U:65N=&5S`%-I9W5I96YT
M93X`3FEC87)A9W5A`$YI9V5R`$YI9V5R:6$`3F]C:&4`3FEU90!.;P!.;R!H
M87D@9&%T;W,@9&4@8V]N9FEG=7)A8VGS;B!P87)A(&UO<W1R87(@9&EF97)E
M;F-I87,N`$YO('-E(&1I<W!O;F4@9&4@97-T<F%T96=I82!D92!E;&%B;W)A
M8VGS;B!D92!I;>%G96YE<R!)4T\N`$YO(&AA>2!P;&%N=&EL;&$@9&4@;&]T
M97,`3F\@:&%Y(&)L;W%U97,@96X@;&$@<&]S:6-I\VX@:6YD:6-A9&$`3F\@
M<V4@:&$@:6YT<F]D=6-I9&\@=6X@;F]M8G)E(&1E(&%G96YD82!P87)A(&QA
M(&%U=&5N=&EF:6-A8VGS;B!-0T%,+@!3:6X@8V%M8FEO<RX`3F\@<V4@<'5E
M9&5N(&'Q861I<B!D97-C96YD:65N=&5S(&$@97-T92!P<FEV:6QE9VEO+@!.
M;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A
M8VGS;B!P87)A("5S+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I
M\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@1E10+@!.;R!S92!H
M82!E<W!E8VEF:6-A9&\@:6YF;W)M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P
M87)A(%9&4R!P;W(@4U%,+@!.;R!S92!H82!E<W!E8VEF:6-A9&\@:6YF;W)M
M86-I\VX@9&4@8V]N9FEG=7)A8VGS;B!P87)A(%9&4R!P;W(@87)C:&EV;R!3
M44PN`$YO('%U961A('-A;&1O+@!.;R!S92!H82!I;G1R;V1U8VED;R!E;"!D
M97-T:6YO+@!.;R!S92!H82!C87)G861O(&YI;F?Z;B!A<F-H:79O`$YO('-E
M(&AA;B!E;F-O;G1R861O(&EC;VYO<RX`3F\@<V4@:&$@9&5F:6YI9&\@;&$@
M=6)I8V%C:?-N+@!.;R!S92!H82!D969I;FED;R!L82!U8FEC86-I\VXN`$YO
M('-E(&AA(&EN=')O9'5C:61O('5N(&UE;G-A:F4N`$YO('-E(&AA(&5S<&5C
M:69I8V%D;R!U;B!N;VUB<F4N`$YO('-E(&AA(&5S<&5C:69I8V%D;R!U;B!N
M^FUE<F\N`$YO(&]F96YS:79A<P!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@
M8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!(5%10+@!.;R!S
M92!H82!I;G1R;V1U8VED;R!U;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N
M=&EF:6-A8VGS;B!)34%0+@!.;R!S92!H82!I;G1R;V1U8VED;R!U;F$@8V]N
M=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!+97)B97)O<RX`3F\@
M<V4@:&$@:6YT<F]D=6-I9&\@=6YA(&-O;G1R87-E\6$@<&%R82!L82!A=71E
M;G1I9FEC86-I\VX@9&4@:6YI8VEO+@!.;R!S92!H82!I;G1R;V1U8VED;R!U
M;F$@8V]N=')A<V7Q82!P87)A(&QA(&%U=&5N=&EF:6-A8VGS;B!005-35T0N
M`$YO('-E(&AA(&EN=')O9'5C:61O('5N82!C;VYT<F%S9?%A('!A<F$@;&$@
M875T96YT:69I8V%C:?-N(%--0BX`3F\@<V4@:&$@:6YD:6-A9&\@=NUA(&1E
M(&%C8V5S;R!A(&QO<R!B:6YA<FEO<R!/<&5N4U-,+B!087)A('1R86)A:F%R
M(&-O;B!D871O<R!02T-3(#$R(&AA8V5N(&9A;'1A(&QO<R!B:6YA<FEO<R!/
M<&5N4U-,+@!3:6X@86QT87,@<&5N9&EE;G1E<RX`0V%R96-E(&1E('%U;W1A
M+@!3:6X@<F%Y87,`3F\@<V4@:&$@97-P96-I9FEC861O('5N('-E<&%R861O
M<BX`3FEN9W5N;P!.;R!E>&ES=&4@96P@87)C:&EV;P!.;R!S92!D:7-P;VYE
M(&1E('5N(&1I<F5C=&]R:6\@9&4@86QM86-E;F%M:65N=&\@=&5M<&]R86PN
M`$YO('-E(&AA(&5N=FEA9&\@96P@;F]M8G)E(&1E('5S=6%R:6\@>2]O(&QA
M(&-O;G1R87-E\6$N`$YO('-E(&AA;B!D979U96QT;R!D871O<R!834P@=N%L
M:61O<P!3:6X@=F%L;W)E<P!.;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N
M(&QA(&-O;F9I9W5R86-I\VX@;W)I9VEN86PN(%)E9V5N97)A<B!L82!C;VYF
M:6=U<F%C:?-N+@!.;R!S92!E;F-O;G1R\R!L82!V97)S:?-N(&5N(&QA(&-O
M;F9I9W5R86-I\VXN(%)E9V5N97)A<B!L82!C;VYF:6=U<F%C:?-N+@!.:6YG
M=6YA`$YI;F=U;F\@*'5S;R!I;7!L[6-I=&\I`$[S<F1I8V\@*$E33RTX.#4Y
M+3$P*0!)<VQA(&1E($YO<F9O;&L`2&5M:7-F97)I;R!N;W)T90!)<VQA<R!-
M87)I86YA<R!D96P@3F]R=&4`3F]R=65G80!.;R!D97-P=>ES`$YO(&%N=&5S
M`$YO(&5S('5N(&1I<F5C=&]R:6\`4VEN(&1E<V%R<F]L;&%R+@!3:6X@97-T
M86)L96-E<@!.;R!E<W3A('-O<&]R=&%D;RX`3F]T87,`3F\@:&%Y(&YA9&$@
M=FES=6%L:7IA8FQE+"!R971R;V-E9&$N`$YO=FEE;6)R90!.^FUE<F\`3OIM
M97)O(&1E(&-A<F%C=&5R97,`3OIM97)O(&1E(&-O;'5M;F%S`$[Z;65R;R!D
M92!F:6QA<P!.;R!S92!H86X@97-P96-I9FEC861O(&[Z;65R;W,@82!A8W1U
M86QI>F%R(&5N(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS;BX`06-E<'1A<@!/
M8FIE=&\`0W)E861O<B!D92!O8FIE=&]S`$]C=&%L`$]C='5B<F4`1FEL=')A
M<B!O9F5N<V%S`$]F:6-I;F$`3&$@8V]N=')A<V7Q82!A;G1I9W5A('D@;&$@
M;G5E=F$@9&5B96X@<V5R(&1I<W1I;G1A<RX`0V]N=')A<V7Q82!A;G1I9W5A
M`$QA(&-O;G1R87-E\6$@86YT:6=U82!N;R!E<R!C;W)R96-T82X`3VWA;@!3
M\VQO(&QO<R!S97)V:61O<F5S($E-05`@<V]P;W)T86X@;&%S(&-A<G!E=&%S
M(&-O;7!A<G1I9&%S+@!3\VQO(&]F96YS:79A<P!3\VQO('-E('!E<FUI=&4@
M=6YA(&1I<F5C8VGS;B!D92!C;W)R96\N`%/S;&\@96P@<')O<&EE=&%R:6\@
M;R!U;B!A9&UI;FES=')A9&]R(&1E('-I<W1E;6%S('!U961E(&-A;6)I87(@
M;&$@<')O<&EE9&%D(&\@;&]S('!R:79I;&5G:6]S(&1E('!R;W!I971A<FEO
M(&1E('5N(')E8W5R<V\@8V]M<&%R=&ED;P!!8G)I<B!E;B!U;F$@;G5E=F$@
M=F5N=&%N80!%<G)O<B!/<&5N4U-,.B!.;R!S92!P=65D96X@97AT<F%E<B!D
M871O<R!D92!L82!P87)T92!3+TU)344@9FER;6%D82X`06)R:7(@97-T92!V
M[6YC=6QO(&5N('5N82!V96YT86YA(&YU979A`%-I<W1E;6$@;W!E<F%T:79O
M`$]P8VEO;F5S`$]P8VEO;F5S(&1E("5S`$QI<W1A(&]R9&5N861A`$]R9V%N
M:7IA8VGS;@!5;FED860@;W)G86YI>F%T:79A`$]R9V%N:7IA8VGS;@!0;&%N
M=&EL;&$@9&4@87!L:6-A8VGS;B!O<FEG:6YA;`!0;&%N=&EL;&%S(&]R:6=I
M;F%L97,@96X@)7,Z`$]T<F\`3W1R82!I;F9O<FUA8VGS;@!0<FEV:6QE9VEO
M<R!D96P@<')O<&EE=&%R:6\`3&$@875T96YT:69I8V%C:?-N(%!!32!N;R!E
M<W3A(&1I<W!O;FEB;&4N`%!%05(Z.DUO=&]R(&1E(&-O<G)E;P!&:7)M82!D
M:6=I=&%L(%!'4`!$871O<R!C:69R861O<R!C;VX@4$=0`$-L879E(%!'4"!P
M^F)L:6-A`$1A=&]S(&9I<FUA9&]S+V-I9G)A9&]S(&-O;B!01U``0_-D:6=O
M(%!(4`!);G3I<G!R+B!02%``3&QO=FEZ;F$@=F5S<&5R=&EN80!,;'5V:6$@
M=F5S<&5R=&EN80!#:&%P87)R;VYE<R!V97-P97)T:6YO<P!.:65V92!V97-P
M97)T:6YA`$%G=6%C97)O(&1E(&YI979E('9E<W!E<G1I;F\`4V]L('9E<W!E
M<G1I;F\`0F]R<F%S8V%S('9E<W!E<G1I;F%S`$YO('-E(&5N8W5E;G1R82!L
M82!E>'1E;G-I\VX@4$]325@`26YTZ7)P<BX@4%](4`!-87)G96X`4&%K:7-T
MX6X`4&%L874`4&%L97-T:6YO<RP@5&5R<FET;W)I;W,@3V-U<&%D;W,`4&%N
M86WA`%!A</IA($YU979A($=U:6YE80!087)A9W5A>0!087)C:6%L;65N=&4@
M;G5B;W-O`$-O;G1R87-E\6$`3&$@8V]N=')A<V7Q82!S92!C86UB:6%D;R!C
M;W)R96-T86UE;G1E+@!#;VYT<F%S9?%A(&EN8V]R<F5C=&$`2&%Y('%U92!I
M;G1R;V1U8VER('5N82!C;VYT<F%S9?%A('!A<F$@;&$@875T96YT:69I8V%C
M:?-N(%)!1$E54RX`0V]N=')A<V7Q82!C;VX@8V]N9FER;6%C:?-N`$-O;G1R
M87-E\6$Z`$-O;G1R87-E\6$Z(`!,87,@8V]N=')A<V7Q87,@=&EE;F5N('%U
M92!C;VEN8VED:7(N`%!E9V%R`%!E9V%R(&1E;"!P;W)T87!A<&5L97,`5NUA
M`$%L=&%S('!E;F1I96YT97,Z`$=E;G1E`%!O<F-E;G1A:F4`4F5A;&EZ87(@
M;W!E<F%C:6]N97,@9&4@;6%N=&5N:6UI96YT;P"_4F5A;&EZ87(@;W!E<F%C
M:6]N97,@9&4@;6%N=&5N:6UI96YT;R!A;"!I;FEC:6%R('-E<VGS;C\`4')I
M=FEL96=I;P!.;R!S92!H82!E;&EM:6YA9&\@96P@<')I=FEL96=I;R`B)7,B
M+@!0<FEV:6QE9VEO(&1E;F5G861O`%!R:79I;&5G:6]S`$%D;6EN:7-T<F%C
M:?-N(&1E('!R:79I;&5G:6]S`$EN9F]R;6%C:?-N('!E<G-O;F%L`%!E<OH`
M36%S8V]T87,`1FEL:7!I;F%S`%1E;.EF;VYO`$9O=&]G<F%F[6%S`%!I=&-A
M:7)N`%#M>&5L97,`5/-P:6-O<P!0=6QS92!E;B!U;F$@8V5L9&$`0V]N9FER
M;64@<75E(&1E<V5A(&5L:6UI;F%R(&5S=&4@96QE;65N=&\Z`$-O;F9I<FUE
M('%U92!D97-E82!E;&EM:6YA<B!E;"!V[6YC=6QO(&$@97-T92!E;&5M96YT
M;RX`26YT<F]D=7IC82!U;B!M97,@>2!U;B!A\6\N`$EN=')O9'5Z8V$@96P@
M;F]M8G)E(&1E(&QA(&YU979A(&-A=&5G;W+M83H`26YT<F]D=7IC82!U;F$@
M9&ER96-C:?-N($E0(';A;&ED82X`26YT<F]D=7IC82!U;F$@9F5C:&$@=N%L
M:61A+"!C;VUP<G5E8F4@96P@;OIM97)O(&1E(&3M87,@9&5L(&UE<RX`26YT
M<F]D=7IC82!U;F$@:&]R82!VX6QI9&$N`%!R;W!O<F-I;VYE('5N(')E<W5M
M96X@9&5L('!R;V)L96UA+@!);G1R;V1U>F-A('-U(&YO;6)R92!D92!U<W5A
M<FEO('D@8V]N=')A<V7Q82X`3&5A(&5L('1E>'1O('-I9W5I96YT92X@1$5"
M12!A8V5P=&%R(&QO<R!TZ7)M:6YO<R!S:2!Q=6EE<F4@=7-A<B!E;"!S:7-T
M96UA+@!);G1R;V1U>F-A(&5L(&YU979O(&YO;6)R92!D92!C871E9V]R[6$Z
M`%!O;&]N:6$`4&]L[71I8V$`16YC=65S=&%S`%!O<G1U9V%L`%!O<VEC:?-N
M(&1E(&QA(&EM86=E;@!0;W-I8VGS;B!D92!L82!T86)L80!%;G9I87(@82!E
M<W1A(&-A<G!E=&$@*&YO(&]B;&EG861O('!O<B!)34%0*0!0<F5C:7!I=&%C
M:6]N97,@9&4@;&$H<RD@^FQT:6UA*',I("5S(&AO<F$H<RDZ(`!0<F]B86)I
M;&ED860\8G(@+SYD92!P<F5C:7!I=&%C:?-N`%!R969S7VQD87`Z(&YO('-E
M(&5N8V]N='+S(&QA(&5X=&5N<VGS;B!,1$%0(')E<75E<FED82X`4')E9G-?
M<V5S<VEO;CH@;F\@<V4@96YC;VYT<O,@;&$@97AT96YS:?-N(&1E('-E<VGS
M;B!R97%U97)I9&$N`%!R97-I\VX`4')E<VGS;B!A;"!N:79E;"!D96P@;6%R
M.B``4')E<VGS;CH@`%9I<W1A('!R979I80!6:7-T82!P<F5V:6$@9&4@;&$@
M:6UA9V5N(&5N('5N82!N=65V82!V96YT86YA`$]P8VEO;F5S(&%N=&5R:6]R
M97,`26UP<FEM:7(@9&]C=6UE;G1O`$-L879E('!R:79A9&$`OU!R;V)L96UA
M<S\`1&5S8W)I<&-I\VX@9&5L('!R;V)L96UA`%!R;WEE8W1O<P!497AT;R!D
M96P@:6YD=6-T;W(`0VQA=F4@4$=0('#Z8FQI8V$`06QG;W)I=&UO(&1E(&-L
M879E('#Z8FQI8V$`26YF;W)M86-I\VX@9&4@8VQA=F4@</IB;&EC80!.;R!S
M92!G96YE<F%R;VX@8V]R<F5C=&%M96YT92!L87,@8VQA=F5S(%#Z8FQI8V$O
M4')I=F%D82X`4'5E<G1O(%)I8V\`3&EM<&EA<B!M96YS86IE<P!1871A<@!#
M;VYS=6QT80!1=6]T80!#;&%V92!24T$@</IB;&EC82`H)60@8FET*0!";W3S
M;B!D92!O<&-I\VX`3&QU=FEA`$QL=79I82!M871U=&EN80!,;'5V:6$@=F5S
M<&5R=&EN80!!9W5A8V5R;P!,;'5V:6$@>2!.:65V90!,;'5V:6$@82!.:65V
M90!2=65D82!D92!L82!F;W)T=6YA`%)A>O-N`"9N8G-P.TQE97(F;F)S<#L`
M3&5E<B!M96YS86IE<P"_16QI;6EN87(@<F5A;&UE;G1E("5S/R!%<W1A(&]P
M97)A8VGS;B!N;R!S92!P=65D92!D97-H86-E<BX`OT5L:6UI;F%R(')E86QM
M96YT92!L;W,@9&%T;W,@9&5L('5S=6%R:6\@)7,_($5S=&$@;W!E<F%C:?-N
M(&YO('-E('!U961E(&1E<VAA8V5R+@!6=65L=F4@82!R96%L:7IA<B!L82#Z
M;'1I;6$@86-C:?-N`$%C='5A;&EZ87(`06-T=6%L:7IA<B!E;&5M96YT;W,@
M9&4@;65N^B!D:6[A;6EC;W,Z`$%C='5A;&EZ87(@=FES=&$@9&5L('!O<G1A
M;`!296=E>`!.879E9V%D;W(@9&4@<F5L86-I;VYE<P!2969R97-C87(`3V)S
M97)V86-I;VYE<P!397)V:61O<F5S(')E;6]T;W,`55),(')E;6]T82`H:'1T
M<#HO+W=W=RYE:F5M<&QO+F-O;2]H;W)D92DZ`%%U:71A<@!1=6ET87(@8FQO
M<75E`%%U:71A<B!C;VQU;6YA`$5L:6UI;F%R(&9O<FUA=&\`475I=&%R('!A
M<@!%;&EM:6YA<B!G=6GS;B!G=6%R9&%D;R!D96P@9&ER96-T;W)I;R!T96UP
M;W)A;"!D96P@<V5R=FED;W(N`$5L:6UI;F%R(`!%;&EM:6YA<B!E<W1E(&YO
M9&\@9&5L(&1O8W5M96YT;P!%;&EM:6YA<B!U<W5A<FEO`$5L:6UI;F%R('5S
M=6%R:6\Z("5S`$YO('-E('!U961E(')E<W!O;F1E<B!A(&QA('-O;&EC:71U
M9"X@0_-D:6=O(&1E(&5R<F]R(&1E=G5E;'1O.B``3F\@<V4@96YC;VYT<O,@
M96P@<V5R=FEC:6\@<V]L:6-I=&%D;RX`3F\@<V4@:&$@97-P96-I9FEC861O
M(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VX@9&4@)7,N
M`$YO('-E(&AA(&5S<&5C:69I8V%D;R!E;"`B)7,B(')E<75E<FED;R!E;B!L
M82!C;VYF:6=U<F%C:?-N(&1E(%9&4RX`3F\@<V4@:&$@97-P96-I9FEC861O
M(&5L("(E<R(@<F5Q=65R:61O(&5N(&QA(&-O;F9I9W5R86-I\VXN`$-A;7!O
M(&YE8V5S87)I;P!,:6UP:6%R`$QI;7!I87(@8V]N=')A<V7Q80!,:6UP:6%R
M(&-O;G1R87-E\6$`4F5S=&%U<F%R(/IL=&EM82!C;VYS=6QT80!297-U;'1A
M9&]S`%)E9W)E<V%R(&$@;W!C:6]N97,`4F5E<V-R:6)I<B!C;VYT<F%S9?%A
M(&YU979A`%)E=6YI\VX`4F5S=&%U<F%R(&-O;F9I9W5R86-I\VX`3W!C:6]N
M97,@9&4@961I8VGS;B!D92!T97AT;R!E;G)I<75E8VED;P!#<FEB87,`1&5R
M96-H80!#86)E8V5R82!D97)E8VAA`%9A;&]R97,@9&4@;&$@9&5R96-H80!0
M<F]P:65D861E<R!D92!?9FEL82XN+@!&=6YC:?-N`%)U;6%N[6$`1VER87(@
M,3@P`$=I<F%R(&$@;&$@:7IQ=6EE<F1A`$=I<F%R(&$@;&$@9&5R96-H80!0
M<F]P:65D861E<R!D92!F:6QA`%!R;W!I961A9&5S(&1E(&9I;&$`1FEL87,Z
M`%)A>6%S`$%P87)E8V5RX6X@<F%Y87,@96YT<F4@=&]D87,@;&%S(&9I;&%S
M('D@8V]L=6UN87,`07!A<F5C97+A;B!R87EA<R!S\VQO(&5N=')E(&QA<R!C
M;VQU;6YA<P!!<&%R96-E<N%N(')A>6%S('/S;&\@96YT<F4@;&%S(&9I;&%S
M`$5J96-U=&%R`$9E9&5R86-I\VX@4G5S80!2=6%N9&$`1FER;6$@8W)I<'1O
M9W+A9FEC82!3+TU)344`365N<V%J92!C:69R861O(&5N(%,O34E-10!.;R!E
M<W3A(&1I<W!O;FEB;&4@;&$@875T96YT:69I8V%C:?-N(%-!4TPN`$UE;G,N
M(%--4P!);G3I<G!R+B!344P`4V5N=&5N8VEA(%-13"!P87)A(&-O;G-U;'1A
M<R!D92!V86QO<F5S`%-32`#)6$E43P!);G3I<G!R+B!37U%,`%-A8@!386YT
M82!(96QE;F$`4V%I;G0@2VET=',@>2!.979I<P!386YT82!,=6/M80!386EN
M="!0:65R<F4@>2!-:7%U96QO;@!386X@5FEC96YT92!Y($=R86YA9&EN87,`
M36ES;6\@9G)A;64@*%]S96QF*0!386UO80!386X@36%R:6YO`%-A;G1O(%1O
M;>%S('D@4'+M;F-I<&4`4')O=F5E9&]R(&1E('-A=.EL:71E`$%R86)I82!3
M875D:71A`$=U87)D87(`1W5A<F1A<B`B)7,B`$=U87)D87(@)7,`1W5A<F1A
M<B!O<&-I;VYE<P!'=6%R9&%R(&QA(&-O;F9I9W5R86-I\VX@9V5N97)A9&$@
M8V]M;R!U;B!G=6GS;B!02%`@96X@96P@9&ER96-T;W)I;R!T96UP;W)A;"!D
M92!S=2!S97)V:61O<BX`4V4@:&$@9W5A<F1A9&\@;&$@8V]N9FEG=7)A8VGS
M;B!D92`E<RX`1W5A<F1A<B!G=6GS;B!D92!A8W1U86QI>F%C:?-N(&1E(&QA
M(&-O;F9I9W5R86-I\VX@96XZ("(E<R(N`$)O<G)A<V-A<R!A:7-L861A<P!#
M:65N8VEA`$)U<V-A<@!-+B!B^G-Q=65D80!396QE8V-I;VYA<B!A<F-H:79O
M<P!396QE8V-I;VYE('5N82!F96-H80!396QE8V-I;VYE(&5L(&=R=7!O(&$@
M8?%A9&ER`%-E;&5C8VEO;F4@=6X@;G5E=F\@<')O<&EE=&%R:6\`4V5L96-C
M:6]N92!U;B!S97)V:61O<@!396QE8V-I;VYE(&5L('5S=6%R:6\@82!A\6%D
M:7(`4V5L96-C:6]N87(@=&]D;P!396QE8V-I;VYE('1O9&]S(&QO<R!C;VUP
M;VYE;G1E<R!D92!L82!F96-H82X`4V5L96-C:6]N87(@=6X@;V)J971O`%-I
M;B!S96QE8V-I\VX`4V5L96-C:6]N92!L;W,@8V%RX6-T97)E<R!Q=64@;F5C
M97-I=&4@9&4@;&%S(&-A<VEL;&%S(&1E(&%B86IO+B!0=65D92!C;W!I87)L
M;W,@>2!P96=A<FQO<R!D96P@X7)E82!D92!T97AT;RX`4V5L96-C:6]N92!E
M;"!D96QI;6ET861O<B!D92!F96-H87,Z`%-E;&5C8VEO;F4@96P@9F]R;6%T
M;R!D92!F96-H87,Z`%-E;&5C8VEO;F4@;&$@:61E;G1I9&%D('%U92!Q=6EE
M<F$@8V%M8FEA<CH`4V5L96-C:6]N92!E;"!D96QI;6ET861O<B!D92!H;W)A
M<SH`4V5L96-C:6]N92!E;"!F;W)M871O(&1E(&AO<F%S.@!396QE8V-I;VYE
M(&1O<R!C86UP;W,@8V]I;F-I9&5N=&5S+@!396QE8V-I;VYE('-U(&-O;6)I
M;F%C:?-N(&1E(&-O;&]R97,N`%-E;&5C8VEO;F4@<W4@:61I;VUA('!R969E
M<FED;SH`16YV:6%R(&EN9F]R;64@9&4@<')O8FQE;6%S`$5N=FEA<B!335,`
M4V5N96=A;`!396YS;W(Z(`!397!T:65M8G)E`%-E<F)I82!Y($UO;G1E;F5G
M<F\`3OIM97)O(&1E('-E<FEE`$1A=&]S(&1E;"!S97)V:61O<B!E<G+S;F5O
M<R!O(&YO(&1I<W!O;FEB;&5S+@!!9&UI;FES=')A8VGS;B!D92!S97-I\VX`
M2&$@8V%D=6-A9&\@96P@240@9&4@<V5S:?-N+@!397-I;VYE<P!%<W1A8FQE
M8V5R`$5S=&%B;&5C92!O<&-I;VYE<R!Q=64@;&4@<&5R;6ET96X@<F5A:G5S
M=&%R('-U(&-O;G1R87-E\6$@<VD@;&QE9V%R82!A(&]L=FED87)L82X`0V]N
M9FEG=7)A('-E<G9I9&]R97,@<F5M;W1O<R!A(&QO<R!Q=64@9&5S964@86-C
M961E<B!D97-D92!E;"!P;W)T86PN`$1E9FEN92!L87,@;W!C:6]N97,@<')E
M9F5R:61A<R!D92!I9&EO;6$L('IO;F$@:&]R87)I82!Y(&9E8VAA<RX`1&5F
M:6YE(&QA(&%P;&EC86-I\VX@9&4@:6YI8VEO+"!L82!C;VUB:6YA8VGS;B!D
M92!C;VQO<F5S+"!L82!A8W1U86QI>F%C:?-N(&1E('#A9VEN82!Y(&]T<F%S
M(&]P8VEO;F5S(&1E('9I<W5A;&EZ86-I\VXN`$-O;F9I9W5R86-I\VX`2&%Y
M(&=U:6]N97,@9&4@86-T=6%L:7IA8VGS;B!D92!L82!C;VYF:6=U<F%C:?-N
M`%9A<FEA<R!U8FEC86-I;VYE<R!D:7-P;VYI8FQE<R!C;VX@96P@<&%RX6UE
M=')O.B``4V5Y8VAE;&QE<P!#;VUP<F%S`%)E<W5M96X@8V]R=&\`OT1E9FEN
M:7(@8VQA=F5S(&1E(&%C8V5S;R!P87)A(&QA(&UA>6]R[6$@9&4@;&]S(';M
M;F-U;&]S/P`F;F)S<#M-;W-T<F%R)FYB<W`[`$UU97-T<F$@;&%S(&1I9F5R
M96YC:6%S(&5N=')E(&QA(&YU979A(&-O;F9I9W5R86-I\VX@>2!L82!A;&UA
M8V5N861A`+]-;W-T<F%R(&AO<F$@9&4@;&$@^FQT:6UA('-E<VGS;B!A;"!I
M;FEC:6%R/P!-;W-T<F%R(&]P8VGS;B!D92!C;VYS97)V87(@96P@;W)I9VEN
M86P`36]S=')A<B!S96QE8W1O<@"_36]S=')A<B!L82!B87)R82!D92!M96[Z
M(&1E(&]P97)A8VEO;F5S(&1E('1A8FQA/P"_36]S=')A<B!E;"!M96[Z("5S
M(&$@;&$@:7IQ=6EE<F1A/P!-=65S=')A(&5L(&1IX6QO9V\@9&4@<')O<&EE
M9&%D97,@9&4@8V5L9&$@9&4@=&%B;&$`375E<W1R82!E;"!D:>%L;V=O(&1E
M('!R;W!I961A9&5S(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G;R!D92!P
M<F]P:65D861E<R!D92!F:6QA(&1E('1A8FQA`$UU97-T<F$@96P@9&GA;&]G
M;R!D92!P<F]P:65D861E<R!D92!I;6%G96X`36]S=')A<B!C87)G80!!9W5A
M8V5R;W,`3&QU=FEA<R!M871U=&EN87,`3&QU=FEA<R!V97-P97)T:6YA<P!!
M9W5A8V5R;W,@96X@;&$@=F5C:6YD860`4F5D=6-I<@!0<FEM97)O(')E9'5Z
M8V$@;R!Q=6ET92!D92!E;FUE9&EO(&QO<R!B;&]Q=65S(&-E<F-A;F]S`%-I
M97)R82!,96]N80!!;'1A`$9I<FUA`$%L9V]R:71M;R!D92!F:7)M80!3:6YG
M87!U<@!486UA\6\`3VUI=&ER(&UA;G1E;FEM:65N=&\`17-L;W9A<75I80!%
M<VQO=F5N:6$`3FEE=F4`06=U86-E<F\@9&4@;FEE=F4`06=U86-E<F\@9&4@
M;FEE=F4`06=U86-E<F\@9&4@;FEE=F4@;6%T=71I;F\`06=U86-E<F\@9&4@
M;FEE=F4@=F5S<&5R=&EN;P!%<W!E<V]R(&1E(&QA(&YI979E.B``17%U:79A
M;&5N=&4@9&4@;&$@;FEE=F4@96X@86=U83H@`$ES;&%S(%-A;&]M\VX`4V]M
M86QI80!#86YC:6]N97,@)B!0;V5M87,`4V5L96-C:?-N(&1E;"!S96YT:61O
M(&1E(&QA(&-L87-I9FEC86-I\VX`4F5M:71E;G1E`%-U9.%F<FEC80!%=7)O
M<&$@9&5L('-U<B`H25-/+3@X-3DM,RD`1V5O<F=I82!D96P@4W5R(&4@27-L
M87,@4V%N9'=I8V@@9&5L(%-U<@!(96UI<V9E<FEO('-U<@!%<W!A8VEA9&\@
M96YT<F4@8V5L9&%S(&%D>6%C96YT97,`17-P86-I861O(&5N=')E(&5L(&-O
M;G1E;FED;R!Y(&5L(&)O<F1E(&1E('5N82!C96QD80!397!A<F%D;W(`17-P
M86-I861O`$5S<&%C:6%D;R!Y(&UA<F=E;@!%<W!A\6$`4W!A;0!%<V-R:71U
M<F$@9&4@8V%R86-T97)E<R!E<W!E8VEA;&5S`$1I=FED:7(@8V5L9&$`1&EV
M:61I<B!C;VQU;6YA`$1I=FED:7(@9FEL80!$97!O<G1E<P!3<FD@3&%N:V$`
M17-TX6YD87(`4W1A<B!4<F5K`$'Q;R!D92!I;FEC:6\`17-T861O(&\@<')O
M=FEN8VEA`$5S=&%D;P!&;W)M871O(&1E(&%L;6%C96YA;6EE;G1O`$1I<F5C
M8VGS;B!D92!L82!C86QL90!486-H861A`$QI<W1A(&1E(&-A9&5N87,`16QI
M;6EN87(@9&]M:6YI;R!D92!L82!D:7)E8V-I\VX`17-T:6QO(%M#4U-=`$1O
M;0!.;R!S92!E;F-O;G1R\R!E;"!S=6)D:7)E8W1O<FEO("(E<R(N`$%S=6YT
M;P!%;G9I87(`4V4@:&$@96YV:6%D;R!U;F$@<V]L:6-I='5D(&1E(&%L=&$@
M9&4@(B5S(B!E;B!E;"!S:7-T96UA+B!.;R!P;V1RX2!I;FEC:6%R('-E<VGS
M;B!H87-T82!Q=64@<V4@:&%Y82!A<')O8F%D;R!L82!S;VQI8VET=60N`%-U
M8NUN9&EC90#)>&ET;P!392!H82!A\6%D:61O(&-O<G)E8W1A;65N=&4@(B5S
M(B!A;"!S:7-T96UA+@!392!H86X@96QI;6EN861O(&-O<G)E8W1A;65N=&4@
M;&]S(&1A=&]S(&1E;"!U<W5A<FEO("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA
M(&5L:6UI;F%D;R!C;W)R96-T86UE;G1E("(E<R(N`%-E(&AA(&5L:6UI;F%D
M;R!C;W)R96-T86UE;G1E("(E<R(@9&5L('-I<W1E;6$N`%-E(&AA(')E<W1A
M=7)A9&\@8V]R<F5C=&%M96YT92!L82!C;VYF:6=U<F%C:?-N+B!2969R97-Q
M=64@<&%R82!V97(@;&]S(&-A;6)I;W,N`%-E(&AA(&=U87)D861O(&-O<G)E
M8W1A;65N=&$@;&$@8V]P:6$@9&4@;&$@8V]N9FEG=7)A8VGS;BX`4V4@:&$@
M9W5A<F1A9&\@8V]R<F5C=&%M96YT92!L82!C;W!I82`E<R!D92!L82!C;VYF
M:6=U<F%C:?-N+@!392!H82!A8W1U86QI>F%D;R!C;W)R96-T86UE;G1E("(E
M<R(`4V4@:&$@97-C<FET;R!C;W)R96-T86UE;G1E("<E<R<`4W5DX6X`4F5S
M=6UE;@!!;6%N96-E<@!!=&%R9&5C97(`4V]L96%D;P!!;6%N96-E<@!!;6%N
M96-E<B]!=&%R9&5C97(`06UA;F5C97(Z(`!!=&%R9&5C97(`071A<F1E8V5R
M.B``4W5P97+M;F1I8V4`4V]P;W)T90!3=7)I;F%M`$%P96QL:61O`%-V86QB
M87)D('D@2F%N($UA>65N`%-W87II;&%N9&EA`%-U96-I80!3=6EZ80!296=I
M<W1R;R!D92!S:6YC<F]N:7IA8VGS;B!E;&EM:6YA9&\`4WEN8TU,`$5R<F]R
M(&1E('-I;G1A>&ES(&5N(&QO<R!TZ7)M:6YO<R!D92!B^G-Q=65D80!297#Z
M8FQI8V$@P7)A8F4@9&4@4VER:6$`0VAU8F%S8V\`0F]R<F%S8V]S;R!Y('9E
M;G1O<V\`0F]R<F%S8V%S`$)O<G)A<V-A<R!M871U=&EN87,`07)C:&EV;R!4
M4U8`4')O<&EE9&%D97,@9&4@=&%B;&$`5&%B;&$`4')O<&EE9&%D97,@9&4@
M=&%B;&$`5&%I=^%N`%1A:7?A;BP@4')O=FEN8VEA(&1E($-H:6YA`%1A>6EK
M:7-TX6X`5&%N>F%N:6$L(%)E</IB;&EC82!5;FED82!D90!$97-T:6YO.@!4
M87)E87,`3OIM97)O(&1E('1E;.EF;VYO`%1E;7!E<F%T=7)A(&1U<F%N=&4@
M;&$@^FQT:6UA(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@`%1E
M;7!E<F%T=7)A/&)R("\^*"5S3>%X)7,O)7--[6XE<RD@)F1E9SLE<P!.;R!S
M92!E;F-O;G1R\R!L82!P;&%N=&EL;&$@(B5S(BX`061M:6YI<W1R86-I\VX@
M9&4@<&QA;G1I;&QA<P!497AT;P!3\VQO('1E>'1O`$%L:6YE86-I\VX@9&4@
M=&5X=&\`0F]R9&4@<W5P97)I;W(@9&5L('1E>'1O`$IU90!486EL86YDZ7,@
M*%1)4RTV,C`I`%1A:6QA;F1I80!.;R!E<W3A(&1I<W!O;FEB;&4@;&$@97AT
M96YS:?-N($944"X`16P@<VES=&5M82!H:7-T\W)I8V\@97-TX2!D97-H86)I
M;&ET861O+@!%;"!M;W1O<B!D92!I;G1E9W)A8VGS;B!(;W)D92]+;VQA8B!N
M;R!S;W!O<G1A("(E<R(`3F\@<V4@<'5E9&4@:6YI8VEA<B!E;"!R96=I<W1R
M;R!D92!)35-0+@!.;R!S92!H82!C87)G861O(&-O<G)E8W1A;65N=&4@;&$@
M8VQA<V4@36%I;G1E;F%N8V4Z.@!392!H82!C97)R861O(&QA('9E;G1A;F$@
M9&4@;W!C:6]N97,N(%-A;&EE;F1O+@!3:2!D97-E82!U=&EL:7IA<B!P97)M
M:7-O<RP@96P@861M:6YI<W1R861O<B!T:65N92!Q=64@8V]N9FEG=7)A<B!U
M;B!S;W!O<G1E(&1E('!E<FUI<V]S('!E<FUA;F5N=&4N`%/S;&\@96P@8F]R
M9&4@:6YF97)I;W(`16P@240@9&5L(&-O;G1A8W1O(&YO('-E(&5S<&5C:69I
M8_,L('-E(&1E:O,@96X@8FQA;F-O(&\@;F\@<V4@96YC;VYT<O,@96X@;&$@
M8F%S92!D92!D871O<RX`4V4@:&$@8?%A9&ED;R!C;W)R96-T86UE;G1E(&5L
M(&-O;G1A8W1O(&$@<W5S(&1I<F5C8VEO;F5S+@!087)A(&-O;7!R;V)A<B!E
M;"!M96YS86IE(&9I<FUA9&\@:&%C92!F86QT82!E;"!B;&]Q=64@9&4@9FER
M;6$@<V5P87)A9&\N`$5L($E$(&1E(&QA(&QI<W1A(&1E(&1I<W1R:6)U8VGS
M;B!N;R!S92!E<W!E8VEF:6/S+"!S92!D96KS(&5N(&)L86YC;R!O(&YO('-E
M(&5N8V]N='+S(&5N(&QA(&)A<V4@9&4@9&%T;W,N`$YO('-E(&5S<&5C:69I
M8_,@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+@!,87,@8V%R86-T97+M<W1I
M8V%S(&1E(&-I9G)A9&\@;F5C97-I=&%N('5N82!C;VYE>&GS;B!W96(@<V5G
M=7)A+@!%;"!A<F-H:79O("5S('1E;F1R[6$@<75E(&-O;G1E;F5R('5N82!O
M<&-I\VX@)7,N`$5L(&%R8VAI=F\@)7,@=&5N9'+M82!Q=64@8V]N=&5N97(@
M86QG=6YA<R!O<&-I;VYE<R`E<RX`16P@87)C:&EV;R!N;R!C;VYT:65N92!D
M871O<RX`02!C;VYT:6YU86-I\VX@=&EE;F4@;&%S(&-A8F5C97)A<R!D92!E
M<W1E(&UE;G-A:F4@;65S<V%G92]R9F,X,C(N`%-E('-A8F4@<75E(&5L(&UO
M9&\@9&4@<&%N=&%L;&$@8V]M<&QE=&$@9&$@<')O8FQE;6%S(&-O;B!);G1E
M<FYE="!%>'!L;W)E<B!D96)I9&\@82!F86QL;W,@9&5L(&YA=F5G861O<B!Q
M=64@;F\@:&5M;W,@<&]D:61O('-O<VQA>6%R+B!0=65D92!S=69R:7(@=FES
M=6%L:7IA8VGS;B!D92!B87-U<F$L('#I<F1I9&$@9&4@9G5N8VEO;F5S(&1E
M;"!E9&ET;W(@>2]O(&-U96QG=65S(&%L96%T;W)I;W,@9&5L(&YA=F5G861O
M<BX@4VD@<W4@<VES=&5M82!O<&5R871I=F\@97,@5VEN9&]W<R`Y>"P@97,@
M;75Y('!R;V)A8FQE('%U92!S=69R82!U;B!F86QL;R!D92!P<F]T96-C:?-N
M(&=E;F5R86P@>2!T96YG82!Q=64@<F5I;FEC:6%R(&5L(&5Q=6EP;RY<;EQN
M66$@97-TX2!A=FES861O+B!0=6QS92!!8V5P=&%R('-I(&'Z;B!D97-E82!P
M<F]B87(@96P@961I=&]R(&5N(&UO9&\@9&4@<&%N=&%L;&$@8V]M<&QE=&$N
M`%-E(&AA(&5L:6UI;F%D;R!L82!I9&5N=&ED860@(B5S(BX`4_-L;R!E;"!B
M;W)D92!I>G%U:65R9&\`2&%Y('%U92!I;F1I8V%R;&4@82!L82!C;&%S92!#
M<GEP=%]P9W`Z.B!L82!U8FEC86-I\VX@9&4@;&]S(&)I;F%R:6]S($=N=5!'
M+@!392!H82!M;W-T<F%D;R!E;"!M96YS86IE(&5N=FEA9&\@96P@)7,@82`E
M<R!C;VX@96P@87-U;G1O("(E<R(N"LES=&\@;F\@9V%R86YT:7IA('%U92!E
M;"!M96YS86IE(&AA>6$@<VED;R!L96ED;R!O(&-O;7!R96YD:61O+@!.;VUB
M<F4@=71I;&EZ861O(&%L('9I;F-U;&%R(&$@;&$@<.%G:6YA(&1E(&-O;7!O
M<VEC:?-N`$5L(&[Z;65R;R!D92!C86UP;W,@=&EE;F4@<75E('-E<B!U;B!N
M^FUE<F\N`$AA8V4@9F%L=&$@96P@;?-D=6QO(&]P96YS<VP@<&%R82!L82!C
M;&%S92!(;W)D95]#<GEP=%]S;6EM93HZ+@!.;R!S92!P=65D92!G=6%R9&%R
M(&QA('!R969E<F5N8VEA("(E<R(@<&]R<75E('-U<R!D871O<R!S;V)R97!A
M<V%N(&5L('1A;6'Q;R!MX7AI;6\@<&5R;6ET:61O`$YO('-E(&5N8V]N='+S
M(&5N(&5L('-I<W1E;6$@96P@<')O9W)A;6$@<&%R82!V97(@97-T92!T:7!O
M(&1E(&1A=&]S("@E<RDN`$5L(&-A<N%C=&5R(&1E(&-I=&$@9&5B92!S97(@
M<V5R('/S;&\@=6YO+@!3\VQO(&QO<R!L861O<R!I>G%U:65R9&\@>2!D97)E
M8VAO`%/S;&\@96P@;&%D;R!D97)E8VAO`$5L('-E<&%R861O<B!D96)E('-E
M<B!S\VQO('5N;RX`4V4@:&$@96QI;6EN861O(&5L('-E<G9I9&]R("(E<R(N
M`%-E(&AA(&=U87)D861O(&5L('-E<G9I9&]R("(E<R(N`%-E(&AA(&5L:6UI
M;F%D;R!L82!S;VQI8VET=60@9&4@86QT82!D92`E<RX`3&$@9FEL82!E<W!E
M8VEF:6-A9&$@*"5D*2!N;R!E>&ES=&4N`$5L(&%R8VAI=F\@=&5M<&]R86P@
M(B5S(B!N;R!E>&ES=&4N`$5L('1E>'1O('%U92!H82!I;G1R;V1U8VED;R!N
M;R!C;VEN8VED92!C;VX@96P@9&4@;&$@<&%N=&%L;&$N`%/S;&\@;&]S(&QA
M9&]S('-U<&5R:6]R(&4@:6YF97)I;W(`4_-L;R!E;"!L861O('-U<&5R:6]R
M`%-E('!E<F1I97)O;B!L;W,@9&%T;W,@8V%R9V%D;W,@9&5S9&4@96P@<&%S
M;R!A;G1E<FEO<BX`3F\@<V4@<'5D;R!G=6%R9&%R(&5L(&%R8VAI=F\@8V%R
M9V%D;RX`3F\@97-TX2!D:7-P;VYI8FQE(&5L(&)L;W%U92!D92!W96%T:&5R
M+F-O;2X`3F\@<V4@96YC;VYT<O,@96P@9&ER96-T;W)I;R!D92!496UA<R`B
M)7,B+@!.;R!S92!D:7-P;VYE(&1E(&]P8VEO;F5S+@!.;R!H87D@<&%R=&5S
M('%U92!S92!P=65D86X@;6]S=')A<B!E;B!L[6YE82X`16X@97-T92!C86UP
M;R!H87D@9&5M87-I861O<R!C87)A8W1E<F5S+B!(82!I;G1R;V1U8VED;R`E
M<R!C87)A8W1E<F5S('D@=&EE;F4@<75E(&EN=')O9'5C:7(@;65N;W,@9&4@
M)7,N`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@86P@8?%A9&ER(&$@(B5S(B!A
M;"!S:7-T96UA.B`E<P!392!P<F]D=6IO('5N('!R;V)L96UA(&%L(&)O<G)A
M<B!L;W,@9&%T;W,@9&5L('5S=6%R:6\@(B5S(B!D96P@<VES=&5M83H@`%-E
M('!R;V1U:F\@=6X@<')O8FQE;6$@86P@96QI;6EN87(@82`B)7,B(&1E;"!S
M:7-T96UA.B``4V4@<')O9'5J;R!U;B!P<F]B;&5M82!A;"!A8W1U86QI>F%R
M("(E<R(Z("5S`%-E('!R;V1U:F\@=6X@<')O8FQE;6$@8V]N(&QA(&-A<F=A
M(&1E;"!A<F-H:79O.B!.;R!S92!C87)G\R`E<RX`4V4@<')O9'5J;R!U;B!P
M<F]B;&5M82!C;VX@;&$@8V%R9V$@9&5L(&%R8VAI=F\N($5L("5S(&5R82!M
MX7,@9W)A;F1E('%U92!E;"!T86UA\6\@;>%X:6UO('!E<FUI=&ED;R`H)60@
M8GET97,I+@!392!P<F]D=6IO('5N('!R;V)L96UA(&-O;B!L82!C87)G82!D
M96P@87)C:&EV;RX@4_-L;R!S92!C87)G\R!P87)C:6%L;65N=&4@96P@)7,N
M`%-E('!R;V1U:F\@=6X@97)R;W(@86P@;6]S=')A<B!E<W1A('!A<G1E(&1E
M;"!M96YS86IE`%-E('!R;V1U:F\@=6X@97)R;W(@86P@:6UP;W)T87(@;&]S
M(&1A=&]S(&1E;"!C;VYT86-T;RX`4V4@<')O9'5J;R!U;B!E<G)O<B!A;"!I
M;7!O<G1A<B!L;W,@9&%T;W,@:4-A;&5N9&%R+@!392!P<F]D=6IO('5N(&5R
M<F]R(&5N(&5L(&9O<FUU;&%R:6\@9&4@8V]N9FEG=7)A8VGS;BX@4'5E9&4@
M<75E(&AA>6$@;VQV:61A9&\@<F5L;&5N87(@=6X@8V%M<&\@;F5C97-A<FEO
M+@!392!P<F]D=6IO('5N(&5R<F]R(&%L(&5J96-U=&%R(&QA(&9U;F-I\VX@
M97-P96-I9FEC861A(&1E(&QA(&QI8G)E=&$@9&4@9&ER96-C:6]N97,N(%9U
M96QV82!A('!R;V)A<B!MX7,@861E;&%N=&4N`%-E('!R;V1U:F\@=6X@97)R
M;W(@86P@86-T=6%L:7IA<B!L;W,@9&5T86QL97,@9&5L(&-O;G1A8W1O+B!6
M=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!392!P<F]D=6IO('5N(&5R
M<F]R(&%L(&%C='5A;&EZ87(@;&$@;&ES=&$@9&4@9&ES=')I8G5C:?-N+B!6
M=65L=F$@82!P<F]B87(@;>%S(&%D96QA;G1E+@!%<W1E('-E<G9I9&]R($E-
M05`@;F\@<V]P;W)T82!L87,@8V%R<&5T87,@8V]M<&%R=&ED87,N`,ES=&4@
M;F\@<&%R96-E('-E<B!U;B!A<F-H:79O(')A<B!VX6QI9&\N`,ES=&4@;F\@
M<&%R96-E('-E<B!U;B!A<F-H:79O('II<"!VX6QI9&\N`,ES=&4@;F\@<&%R
M96-E('-E<B!U;B!N^FUE<F\@9&4@=&%R:F5T82!VX6QI9&\N`$5S=&4@8V]N
M=')O;&%D;W(@<&5R;6ET92!E;G9I87(@;65N<V%J97,@82!T<F%VZ7,@9&4@
M;&$@<&%S87)E;&$@0VQI8VMA=&5L;"`H:'1T<#HO+V-L:6-K871E;&PN8V]M
M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT<F]L861O<B!P97)M
M:71E(&5N=FEA<B!M96YS86IE<R!A('1R87;I<R!D92!L82!P87-A<F5L82!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``
M17-T92!C;VYT<F]L861O<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!A('1R
M87;I<R!D92!L82!P87-A<F5L82!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA
M:6PN8V]M*2P@;65D:6%N=&4@;&$@05!)($A45%``17-T92!C;VYT<F]L861O
M<B!P97)M:71E(&5N=FEA<B!M96YS86IE<R!V:6$@4TU44"!A('1R87;I<R!D
M92!L82!P87-A<F5L82!D92!6;V1A9F]N92!D92!)=&%L:6$L('/S;&\@82!N
M^FUE<F]S(%9O9&%F;VYE+B!(86-E(&9A;'1A('5N82!C=65N=&$@9&4@8V]R
M<F5O(&1E(%9O9&%F;VYE(&1E($ET86QI82`H:'1T<#HO+W=W=RXQ.3`N:70I
M+@!(86-E(&9A;'1A(&5S=&4@8V%M<&\N`$5S=&4@8V%M<&\@<_-L;R!P=65D
M92!C;VYT96YE<B!E;G1E<F]S+@!%<W1E(&-A;7!O('/S;&\@<'5E9&4@8V]N
M=&5N97(@;OIM97)O<R!Y(&QO<R!D;W,@<'5N=&]S+@!%<W1E(&-A;7!O('/S
M;&\@<'5E9&4@8V]N=&5N97(@=F%L;W)E<R!O8W1A;&5S+@!%<W1E(&-A;7!O
M('1I96YE('%U92!S97(@=6YA(&QI<W1A(&1E(&5N=&5R;W,@<V5P87)A9&]S
M('!O<B!C;VUA<R!O(&5S<&%C:6]S+@!%<W1E(&-A;7!O('1I96YE('%U92!S
M97(@=6X@;OIM97)O(';A;&ED;RX`17-T92!C86UP;R!T:65N92!Q=64@8V]N
M=&5N97(@=6X@8_-D:69O(&1E(&-O;&]R(&5N(&9O<FUA=&\@4D="($AE>&%D
M96-I;6%L+"!P;W(@96IE;7!L;R`G(S$R,S1A9B<N`%EA('-E(&AA('!R;V-E
M<V%D;R!E<W1E(&9O<FUU;&%R:6\N`$5S=&\@97,@)7,N`,ES=&\@97,@=6X@
M;V)J971O(&1E($MO;&%B($=R;W5P=V%R92X@4&%R82!V97)L;R!N96-E<VET
M82!U;B!C;&EE;G1E(&1E(&-O<G)E;R`@<75E(&5N=&EE;F1A(&5L(&9O<FUA
M=&\@2V]L86(@1W)O=7!W87)E+B!087)A('9E<B!U;F$@;&ES=&$@9&4@9&EC
M:&]S(&-L:65N=&5S('9I<VET92`E<P!%<W1E(&UE;G-A:F4@<V4@97-C<FEB
M:?,@8V]N('5N(&IU96=O(&1E(&-A<F%C=&5R97,@*"5S*2!D:7-T:6YT;R!A
M;"!S=7EO+@!%<W1E(&[Z;65R;R!D96)E('-E<B!P;W(@;&\@;65N;W,@=6X@
M=6YO+@!%<W1E('-E<G9I9&]R(&YO('!U961E(&1E<V-O;7!R:6UI<B!A<F-H
M:79O<R!Z:7`@>2!G>FEP+@!%<W1E('-I<W1E;6$@86-T=6%L;65N=&4@97-T
MX2!D97-A8W1I=F%D;RX`17-T92!V86QO<B!T:65N92!Q=64@<V5R('5N(&[Z
M;65R;RX`17-T82!V96YT86YA('/S;&\@<'5E9&4@86)R:7)S92!D97-D92!U
M;F$@=F5N=&%N82!D92!O<&-I;VYE<P!4<G5E;F\`26YC:61E;F-I87,`2&]R
M80!#+B!T:65M<&]S`$9O<FUA=&\@:&]R87)I;P!396QE8V-I\VX@9&4@:&]R
M80!4:6UO<BU,97-T90!4[71U;&\`5.UT=6QO("AC;VYS96IO*3H`4&%R80!0
M87)A('-E;&5C8VEO;F%R('9A<FEO<R!C86UP;W,L(&UA;G1E;F=A('!U;'-A
M9&$@;&$@=&5C;&$@0V]N=')O;"`H4$,I(&\@0V]M86YD;R`H36%C*2!A;"!H
M86-E<B!C;&EC:RX`2&]Y`$-O;FUU=&%R(&]R:6=E;B!(5$U,`%1O9V\`5&]K
M96QA=0!-8?%A;F$`5&]N9V$`1&5M87-I861O<R!I;G1E;G1O<R!F86QL:61O
M<R!E;B!L;W,@^FQT:6UO<R!M:6YU=&]S+@!3=7!E<FEO<@!&<F%M92!S=7!E
M<FEO<B`H7W1O<"D`5')A9'5C8VEO;F5S`%1R:6YI9&%D('D@5&]B86=O`%9E
M<F1A9&5R;R!O(&9A;'-O`$UA<@!4^FYE>@!4=7)Q=>UA`%1U<F-O("A)4T\M
M.#@U.2TY*0!4=7)K;65N:7-TX6X`27-L87,@5'5R:W,@>2!#86EC;W,`5'5V
M86QU`$5S8W)I8F$@<W4@96QE8V-I\VXZ(`#-;F1I8V4@52Y6+CH@`%523`!5
M4DP@9&4@<W4@:6YF;W)M92!D92!E<W1A9&\@9&4@96YV[6\@9&5L(&=U:?-N
M`%523#H`56=A;F1A`%5C<F%N:6$`26YC87!A>B!D92!A8V-E9&5R(&%L(&1I
M<F5C=&]R:6\@5D93+@!);F-A<&%Z(&1E(&'Q861I<B!I;F9O<FUA8VGS;B!D
M92!U<W5A<FEO(&%D:6-I;VYA;"!A;"!R96%L:7IA<B!E;"!A;'1A+@!);F-A
M<&%Z(&1E(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E;"!A<F-H:79O(%9&
M4R`B)7,B+@!);F-A<&%Z(&1E(&-A;6)I87(@;&]S('!R:79I;&5G:6]S(&1E
M;"!A<F-H:79O(%9&4R`E<R\E<RX`26YC87!A>B!D92!C86UB:6%R(&$@)7,N
M`$EN8V%P87H@9&4@8V]M<')O8F%R(&5L('1A;6'Q;R!D92`B)7,B+@!);F-A
M<&%Z(&1E(&-O;7!R;V)A<B!E;"!T86UA\6\@9&4@(B5S+R5S(BX`26YC87!A
M>B!D92!C;VYE8W1A<G-E(&%L('-E<G9I9&]R(%-13"X`26YC87!A>B!D92!C
M;VYE8W1A<B!C;VX@4U-,+@!);F-A<&%Z(&1E(&-O<&EA<B!E;"!A<F-H:79O
M(%9&4RX`26YC87!A>B!D92!C<F5A<B!E;"!D:7)E8W1O<FEO(%9&4R`B)7,B
M+@!);F-A<&%Z(&1E(&-R96%R(&5L(&1I<F5C=&]R:6\@5D93+@!);F-A<&%Z
M(&1E(&-R96%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&-R96%R(&QA
M(&-A<G!E=&$@5D93("(E<R(`26YC87!A>B!D92!C<F5A<B!U;B!A<F-H:79O
M(%9&4R!V86/M;RX`26YC87!A>B!D92!D97-C;VUP<FEM:7(@;&]S(&1A=&]S
M+@!);F-A<&%Z(&1E(&5L:6UI;F%R("(E<R(L(&5L(&1I<F5C=&]R:6\@;F\@
M97-TX2!V86/M;RX`26YC87!A>B!D92!E;&EM:6YA<B`B)7,B.B`E<RX`26YC
M87!A>B!D92!E;&EM:6YA<B`E<RP@96P@9&ER96-T;W)I;R!N;R!E<W3A('9A
M8^UO`$EN8V%P87H@9&4@96QI;6EN87(@96P@9&ER96-T;W)I;R!61E,@9&4@
M9F]R;6$@<F5C=7)S:79A+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C
M=&]R:6\@5D93+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&1I<F5C=&]R:6\@
M5D93.B`E<RX`26YC87!A>B!D92!E;&EM:6YA<B!E;"!A<F-H:79O(%9&4R`B
M)7,B+@!);F-A<&%Z(&1E(&5L:6UI;F%R(&5L(&%R8VAI=F\@5D93+@!);F-A
M<&%Z(&1E(&5L:6UI;F%R(&QA(&-A<G!E=&$@5D93("(E<R(N`$EN8V%P87H@
M9&4@96QI;6EN87(@96P@5D93(&1E(&9O<FUA(')E8W5R<VEV83H@)7,N`$EN
M8V%P87H@9&4@9&5T97)M:6YA<B!E;"!D:7)E8W1O<FEO(&%C='5A;"X`26YC
M87!A>B!D92!E>'1R865R(&QO<R!D971A;&QE<R!D96P@8V5R=&EF:6-A9&\N
M`$EN8V%P87H@9&4@8V%R9V%R(&QA(&1E9FEN:6-I\VX@9&4@)7,N`$EN8V%P
M87H@9&4@=')A<VQA9&%R(&5L(&%R8VAI=F\@5D93+@!);F-A<&%Z(&1E(&%B
M<FER(&5L(&%R8VAI=F\@5D93("(E<R(N`$EN8V%P87H@9&4@86)R:7(@96P@
M87)C:&EV;R!61E,@<&%R82!E<V-R:6)I<BX`26YC87!A>B!D92!A8G)I<B!E
M;"!A<F-H:79O(%9&4RX`26YC87!A>B!D92!A8G)I<B!E;"!A<F-H:79O(&-O
M;7!R:6UI9&\N`$EN8V%P87H@9&4@;&5E<B!U;B!A<F-H:79O(%9&4R`H:&$@
M9F%L;&%D;R!F:6QE<VEZ92@I*2X`26YC87!A>B!D92!L965R('5N(&%R8VAI
M=F\@5D93("AH82!F86QL861O(&=E=$9I;&53:7IE*"DI+@!);F-A<&%Z(&1E
M(&QE97(@=6X@87)C:&EV;SH@`$EN8V%P87H@9&4@;&5E<B!E;"!D:7)E8W1O
M<FEO('9F<W)O;W0N`$EN8V%P87H@9&4@<F5N;VUB<F%R("5S(&-O;6\@)7,Z
M(&QA(&-A<G!E=&$@9&5S=&EN;R!Y82!E>&ES=&4`26YC87!A>B!D92!R96YO
M;6)R87(@96P@9&ER96-T;W)I;R!61E,N`$EN8V%P87H@9&4@<F5N;VUB<F%R
M(&5L(&1I<F5C=&]R:6\@5D93.B`E<RX`26YC87!A>B!D92!R96YO;6)R87(@
M96P@87)C:&EV;R!61E,@(B5S(@!);F-A<&%Z(&1E(')E;F]M8G)A<B!E;"!A
M<F-H:79O(%9&4R`E<R\E<RX`26YC87!A>B!D92!R96YO;6)R87(@96P@87)C
M:&EV;R!61E,N`$EN8V%P87H@9&4@96IE8W5T87(@)VUK:7-O9G,G+@!.;R!S
M92!P=65D92!A8W1I=F%R(&QA(&%C='5A;&EZ86-I\VX@9&4@:6YF;W)M86-I
M\VX@9&4@=&EE;7!O(&1I<W!O;FEB;&4@9&4@)7,`26YC87!A>B!D92!E<V-R
M:6)I<B!E;"!A<F-H:79O(%9&4R`B)7,B+@!);F-A<&%Z(&1E(&5S8W)I8FER
M('5N(&%R8VAI=F\@5D93("AH82!F86QL861O(&-O<'DH*2DN`$EN8V%P87H@
M9&4@97-C<FEB:7(@;&]S(&1A=&]S(&1E;"!A<F-H:79O(%9&4RX`26YC87!A
M>B!D92!E<V-R:6)I<B!U;B!A<F-H:79O(%9&4RP@<V4@<W5P97)A<N$@;&$@
M<75O=&$N`%-U8G)A>6%D80!$97-H86-E<B!C86UB:6]S`$1E<VAA8V4@;&$@
M^FQT:6UA(&%C8VGS;@!297-P=65S=&$@:6YE<W!E<F%D82!D96P@<V5R=FED
M;W(@96X@;&$@8V]N97AI\VXZ(`!297-P=65S=&$@:6YE<W!E<F%D82!D96P@
M<V5R=FED;W(@83H@`%-I;B!C871E9V]R[6$`56YI8V]D92`H551&+3@I`$5M
M:7)A=&]S(,%R86)E<R!5;FED;W,`26YG;&%T97)R80!%<W1A9&]S(%5N:61O
M<P!%<W1A9&]S(%5N:61O<R!M96YO<R!L87,@:7-L87,@<&5R:6;I<FEC87,`
M56YI9&%D97,`1&5S8V]N;V-I9&\`07!I;7-G:60@9&5S8V]N;V-I9&\@*$E$
M(&1E(&UE;G-A:F4@9&4@;&$@05!)*2X`0VQI;7-G:60@9&5S8V]N;V-I9&\@
M*$E$(&1E(&UE;G-A:F4@9&5L(&-L:65N=&4I+@!392!H82!D969I;FED;R!U
M;F$@=6)I8V%C:?-N(&1E<V-O;F]C:61A+@!5<W5A<FEO(&\@8V]N=')A<V7Q
M82!D97-C;VYO8VED;W,N`$5L:6UI;F%R(';M;F-U;&\@9&5L(&5L96UE;G1O
M(&%C='5A;`!3:6X@;F]M8G)E`$QO<R!G=6EO;F5S('-I;B!P<FEV:6QE9VEO
M<R!N;R!P=65D96X@86-C961E<B!D92!F;W)M82!P<F]G<F%MX71I8V$@82!#
M;W)T87(O0V]P:6%R+U!E9V%R('!O<B!R87IO;F5S(&1E('-E9W5R:61A9"X@
M4'5L<V4@06-E<'1A<B!P87)A('9E<B!E;B!M;WII;&QA+F]R9R!U;F$@;F]T
M82!TZ6-N:6-A('%U92!L92!M=65S=')E(&/S;6\@<&5R;6ET:7(@<75E('5N
M(&=U:?-N(&%C8V5D82!A;"!P;W)T87!A<&5L97,N`$%N=6QA<B!C;VQO<@!%
M>'1E;G-I\VX@;F\@<V]P;W)T861A`$%C='5A;&EZ87(`06-T=6%L:7IA<B`E
M<P!!8W1U86QI>F%R('5S=6%R:6\`4V4@:&$@86-T=6%L:7IA9&\@(B5S(BX`
M4V4@:&$@96QI;6EN861O(&5L(&=U:?-N(&1E(&%C='5A;&EZ86-I\VXN`$-A
M<F=A<@!392!H86X@8V%R9V%D;R!E;B!E;"!S97)V:61O<B!T;V1O<R!L;W,@
M87)C:&EV;W,@9&4@8V]N9FEG=7)A8VGS;B!D92!A<&QI8V%C:6]N97,N`$%L
M9F%B971O(&QA=&EN;R!E;B!M87GZ<V,N`$[Z;65R;W,@<F]M86YO<R!E;B!M
M87GZ<V,N`%5R=6=U87D`57-A<B!A8W1U86PZ("5S`%5S87(@4U-,`%-E('5S
M82!S:2!E;"!U<W5A<FEO+V-O;G1R87-E\6$@<V]N(&1I<W1I;G1O<R!E;B!E
M;"!S97)V:61O<B!)35-0+@!5<W5A<FEO`$5L('5S=6%R:6\@)7,@8V%R96-E
M(&1E(&%U=&]R:7IA8VGS;B!P87)A("5S+@!!9&UI;FES=')A8VGS;B!D92!U
M<W5A<FEO<P!/<&-I;VYE<R!D92!U<W5A<FEO`%)E9VES=')O(&1E('5S=6%R
M:6]S`$5S=&$@<V5D92!T:65N92!D97-A8W1I=F%D;R!E;"!R96=I<W1R;R!D
M92!U<W5A<FEO<RX`3F\@<V4@:&$@96YC;VYT<F%D;R!L82!I9&5N=&ED860`
M57-U87)I;P!982!E>&ES=&4@96P@;F]M8G)E(&1E('5S=6%R:6\@(B5S(BX`
M57-U87)I;SH`57-U87)I;SH@`%5S=6%R:6]S(&5N(&5L('-I<W1E;6$Z`%5Z
M8F5K:7-TX6X`3F\@97AI<W1E(&5L(&1I<F5C=&]R:6\@5D93+@!!=7-E;F-I
M80!,87,@=6)I8V%C:6]N97,@=N%L:61A<R!E;F-O;G1R861A<R!I;F-L=7EE
M;CH@`%9A;&ED97H`5F%L;W(@96X@;6EN=71O<R!A('!A<G1I<B!D92!A:&]R
M82X`16P@=F%L;W(@97AC961E(&5L('1A;6'Q;R!MX7AI;6\@9&4@)7,N`%9A
M;&]R97,`5F%L;W)E<R!A('-E;&5C8VEO;F%R`%9A;G5A='4`5F%R:6%B;&4`
M5F5N97IU96QA`$AA(&9A;&QA9&\@;&$@8V]M<')O8F%C:?-N("T@97-T92!M
M96YS86IE('!U961E(&AA8F5R<V4@9F]R>F%D;RX`5F5R<VGS;@!#+B!V97)S
M:6]N97,`06QI;F5A8VGS;B!V97)T:6-A;`!-87)G96X@=F5R=&EC86P`5F5R
M=&EC86PZ`$UU>2!A;'1A`%9I971N86T`5FEE=&YA;6ET82`H5DE30TE)*0!6
M97(@)7,`5F5R('5N82!PX6=I;F$@=V5B(&5X=&5R;F$`5F5R(&-O;6\@)7,`
M27-L87,@5NUR9V5N97,L($)R:73A;FEC87,`27-L87,@5NUR9V5N97,L(%4N
M4RX`5FES:6)I;&ED860`5FES:6)I;&ED860Z(`!6;V1A9F]N92!D92!)=&%L
M:6$@;65D:6%N=&4@4TU44`!!5DE33P"AH:%!1%9%4E1%3D-)02$A(2!%3$E-
M24Y%($U!3E5!3$U%3E1%($5,($=52=-.($1%("5S+@!724X@<&]R($A45%``
M5V%L;&ES('D@1G5T=6YA`$%D=F5R=&5N8VEA`$UI90!0<F5V:7-I\VX@9&5L
M('1I96UP;P!$871O<R!D96P@=&EE;7!O('-U;6EN:7-T<F%D;W,@<&]R`%=E
M871H97(N8V]M`%=E8@!3961E(%=E8@!396UA;F%L;65N=&4`0FEE;G9E;FED
M;P!":65N=F5N:61O<R!A("5S`$)I96YV96YI9&\L("5S`$]E<W1E("A)4T\M
M.#@U.2TQ*0!/97-T92`H25-/+3@X-3DM,34I`%/A:&%R82!/8V-I9&5N=&%L
M`+]1=>D@87!L:6-A8VGS;B!D96)E<NUA(&UO<W1R87(@)7,@86P@:6YI8VEA
M<B!L82!S97-I\VX_`+]#=>%L(&5S(&5L(&-A<N%C=&5R(&1E;&EM:71A9&]R
M/P"_0W7A;"!E<R!E;"!C87+A8W1E<B!D92!C:71A9&\_`$UA<&$@9&4@;&]C
M86QI>F%C:?-N(&1E($%U<W1R86QI80!1=>D@9F%S97,`4&QU9VEN<R!H86)I
M;&ET861O<R!D96P@961I=&]R(&1E('1E>'1O(&5N<FEQ=65C:61O+@!!;F-H
M=7)A`$%N8VAU<F$@96X@=6YI9&%D97,@0U-3`$%N8VAU<F$@9&5L(&UE;OH@
M)7,@:7IQ=6EE<F1O("AD:7-P;VYI8FQE(&5N(&QA('!R\WAI;6$@<V5S:?-N
M*3H`06YC:'5R82!D92!L82!T86)L80!5;FED861E<R!D92!A;F-H=7)A`$%N
M8VAU<F$Z`%=I:VD`5FEE;G1O`%9I96YT;R!M871U=&EN80!696QO8VED860@
M9&5L('9I96YT;R!E;B!N=61O<P!6:65N=&\Z`%9I96YT;SH@`%-A8FED=7+M
M80!$97-E;W,`16UP;&5O`$1I<F5C8VGS;B!D96P@=')A8F%J;P!496SI9F]N
M;R!D96P@=')A8F%J;P!.^FUE<F\@97)R\VYE;R!D92!C86UP;W,@96X@;&$@
M;.UN96$@)60N(%-E(&5S<&5R86)A;B`E9"!Y(&AA>2`E9"X`3OIM97)O(&5R
M<O-N96\@9&4@8V%M<&]S+B!392!E<W!E<F%B86X@)60@>2!H87D@)60N`$]F
M9G-E="`E9"!E<G+S;F5O(&%L(&QE97(@=6X@87)C:&EV;R!61E,N`%@M4F5F
M`$QI;6ET86-I;VYE<R!BX7-I8V%S(%@U,#EV,P!5<V\@9&4@8VQA=F4@97AT
M96YD:61A(%@U,#EV,P!.;VUB<F4@86QT97)N871I=F\@9&4@87-U;G1O(%@U
M,#EV,P!)9&5N=&EF:6-A9&]R(&1E(&-L879E(&1E(&%S=6YT;R!8-3`Y=C,`
M17AT96YS:6]N97,@6#4P.78S`$%!`$%!04$`H4UA<&$@9&4@66%H;V\A`$%N
M=6%L;65N=&4`665M96X`4^T`4^TL(&QO(&%C97!T;P!%<W3A(&5N($U/1$\@
M5$585$\N(%5T:6QI8V4@96P@8F]T\VX@6SP^72!P87)A(')E9W)E<V%R(&%L
M(&UO9&\@5UE325=91RX`3F\@9&ES<&]N92!D92!P<FEV:6QE9VEO<R!P87)A
M(&-R96%R(&WA<R!D92`E9"!B;&]Q=65S+@!.;R!E<W3A(&%U=&5N=&EF:6-A
M9&\N`$YO('!U961E(&EN8VQU:7(@96P@8V%RX6-T97(@(EPB(&5N(&5L(&YO
M;6)R92!C;VUP;&5T;RX`3F\@:6YT<F]D=6IO('5N82!D:7)E8V-I\VX@9&4@
M8V]R<F5O(';A;&ED82X`3F\@87-O8VGS(&YI;F=U;F\@9&4@;&]S(&-A;7!O
M<R!D96P@87)C:&EV;R!I;7!O<G1A9&\@82!L;W,@8V%M<&]S(&-O<G)E<W!O
M;F1I96YT97,@9&4@)7,N`$AA('-A;&ED;R!D92!L82!S97-I\VXN`%1I96YE
M('%U92!I;G1R;V1U8VER('5N(&[Z;65R;R!D92!T96SI9F]N;R!M\W9I;"!V
MX6QI9&\L('/S;&\@9.UG:71O<R!C;VX@=6X@)RLG(&]P8VEO;F%L('!A<F$@
M96P@<')E9FEJ;R!D92!L;&%M861A(&EN=&5R;F%C:6]N86PN`%1I96YE('%U
M92!I;G1R;V1U8VER('5N('9A;&]R(';A;&ED;RX`4&%R82!U<V%R($%L=&%S
M('1I96YE('%U92!C;VYF:6=U<F%R('5N(&UO=&]R(&1E($1A=&%4<F5E+@!4
M:65N92!Q=64@8V]N9FEG=7)A<B!U;B!M;W1O<B!61E,N`$1E8F4@9&5S8W)I
M8FER(&5L('!R;V)L96UA(&%N=&5S(&1E(&5N=FEA<B!E;"!I;F9O<FUE+@!4
M:65N92!Q=64@:6YT<F]D=6-I<B!L82!54DP@82!L82!Q=64@87!U;G1A(&5S
M=&4@=NUN8W5L;P!4:65N92!Q=64@<V5L96-C:6]N87(@=6X@<V5R=FED;W(@
M82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@
M82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('5N('5S=6%R:6\@
M82!E;&EM:6YA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R(&5L('5S=6%R:6\@
M82!A\6%D:7(N`%1I96YE('%U92!E<W!E8VEF:6-A<B!E;"!U<W5A<FEO(&$@
M86-T=6%L:7IA<BX`5&EE;F4@<75E(&5S<&5C:69I8V%R('%UZ2!A8V-I\VX@
M<V4@96IE8W5T87+A+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N=65V;R!N
M;VUB<F4@9&4@8V%T96=O<NUA+@!4:65N92!Q=64@:6YT<F]D=6-I<B!U;B!N
M^FUE<F\@9&4@=&5LZ69O;F\@:71A;&EA;F\`2&$@97AP:7)A9&\@<W4@<V5S
M:?-N("5S+B!6=65L=F$@82!I;FEC:6%R('-E<VGS;BX`4W4@9&ER96-C:?-N
M(&1E(&-O<G)E;P!$:7)E8V-I\VX@1&4Z`%-U(&EN9F]R;6%C:?-N`$AA(&-A
M;6)I861O('-U(&1I<F5C8VGS;B!D92!);G1E<FYE="!D97-D92!E;"!C;VUI
M96YZ;R!D92!S=2!S97-I\VX@)7,N(%!O<B!R87IO;F5S(&1E('-E9W5R:61A
M9"!T:65N92!Q=64@=F]L=F5R(&$@:6YI8VEA<B!L82!S97-I\VXN`%-U(&YO
M;6)R90!3=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!A
M\6%D:7(@=7-U87)I;W,N(%-I('%U:7-I97)A('5S87(@2&]R9&4@<&%R82!A
M9&UI;FES=')A<B!C=65N=&%S(&1E('5S=6%R:6\L('1E;F1RX2!Q=64@=71I
M;&EZ87(@=6X@;6]T;W(@9&4@875T96YT:69I8V%C:?-N(&1I<W1I;G1O+@!3
M=2!M;W1O<B!D92!A=71E;G1I9FEC86-I\VX@;F\@<&5R;6ET92!L:7-T87(@
M=7-U87)I;W,L(&\@<V4@:&$@9&5S:&%B:6QI=&%D;R!L82!C87)A8W1E<NUS
M=&EC82!P;W(@86QG^FX@;6]T:79O+@!087)E8V4@<75E(&AA(&-A;6)I861O
M('-U(&YA=F5G861O<B!D97-D92!E;"!C;VUI96YZ;R!D92!S=2!S97-I\VX@
M)7,N(%!O<B!R87IO;F5S(&1E('-E9W5R:61A9"!T:65N92!Q=64@=F]L=F5R
M(&$@:6YI8VEA<B!L82!S97-I\VXN`%-U(&YA=F5G861O<B!N;R!A9&UI=&4@
M97-T82!C87)A8W1E<NUS=&EC82X`16P@;F%V96=A9&]R(&YO(&%D;6ET92!E
M<W1A(&]P8VGS;B!D92!I;7!R97-I\VXN(%!R97-I;VYE($-O;G1R;VPO0V]M
M86YD;R`K(%`@<&%R82!I;7!R:6UI<BX`6F]N82!H;W)A<FEA(&%C='5A;#H`
M4V4@:&$@8V%M8FEA9&\@<W4@:61E;G1I9&%D('!O<B!O;6ES:?-N+@!)9&5N
M=&ED860@<&]R(&]M:7-I\VXZ`$YO;6)R92!C;VUP;&5T;SH`4V4@:&$@86=O
M=&%D;R!S=2!T:65M<&\@9&4@8V]N97AI\VXN`$QA(&YU979A(&-O;G1R87-E
M\6$@<&%R82`E<R!E<SH@)7,`4V4@:&%N(&%C='5A;&EZ861O('-U<R!O<&-I
M;VYE<R!S\VQO('!O<B!L82!D=7)A8VGS;B!D92!L82!S97-I\VXN`%-E(&AA
M;B!A8W1U86QI>F%D;R!S=7,@;W!C:6]N97,N`%-E(&AA(')E86IU<W1A9&\@
M<W4@8V]N=')A<V7Q80!392!H82!R96%J=7-T861O('-U(&-O;G1R87-E\6$L
M(&-O;7!R=65B92!E;"!C;W)R96\@92!I;FEC:64@<V5S:?-N(&-O;B!S=2!N
M=65V82!C;VYT<F%S9?%A+@!,82!C;VYT<F%S9?%A(&AA(&5X<&ER861O+@!3
M97)V:61O<F5S(')E;6]T;W,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M/8W5L=&%R('1E>'1O(&-I=&%D;UT`6TEN9F]R;64@
M9&4@<')O8FQE;6%=`%M-;W-T<F%R('1E>'1O(&-I=&%D;R`M`%M-;W-T<F%R
M('1E>'1O(&-I=&%D;R`M("5S(&SM;F5A<UT`6VSM;F5A("5S(&1E("5S70!?
M061M:6YI<W1R86-I\VX`7T-,20#!<E]B;VP@9&%T;W,`15]L:6UI;F%R(&9I
M;&$`7T=R=7!O<P!!7WEU9&$`4')O<&EE9&%D97,@9&4@7VEM86=E;BXN+@!?
M26YI8VEA<B!S97-I\VX`7U-A;&ER`$UO9&EF:6-A<B!?=NUN8W5L;RXN+@!?
M3W!C:6]N97,`7U!R:79I;&5G:6]S`%]%;&EM:6YA<B!V[6YC=6QO+BXN`$-O
M;E]F:6=U<F%C+@!0<F]P:65D861E<R!D92!?=&%B;&$N+BX`7U5S=6%R:6]S
M`&1I<F5C8VEO;F5S`&1E<W1I;F%T87)I;R!D97-C;VYO8VED;P!A9V5N9&$`
M8V%L;6$`;F\@<V4@<'5E9&4@8W)E87(@96P@87)C:&EV;R!D92!D97-T:6YO
M`&YO('-E('!U961E(&%B<FER(&5L(&]R:6=E;@!P=6QS92!A<77M`&5R<F]R
M(&1E(&SM;F5A(&1E(&-O;6%N9&\`97)R;W(@9&4@8V]N9FEG=7)A8VGS;@!F
M86QT82!U;B!A<F-H:79O(&-R[71I8V\@9&5L('-I<W1E;6$`97)R;W(@9&4@
M9F]R;6%T;R!D92!D871O<P!M;V1I9FEC87(`96YT<F%D82!N;R!E;F-O;G1R
M861A`&1E<V-E;G-O`&%R8VAI=F\`9&5L("5S("@E<RD@82!L87,@)7,@)7,`
M=F5N=&]S;P!H.@!H:`!N;VUB<F4@9&4@86YF:71R:?-N(&1E<V-O;F]C:61O
M`&EN;65D:6%T86UE;G1E`&5N(&SM;F5A`&5R<F]R(&1E(&5N=')A9&$O<V%L
M:61A`&5R<F]R(&1E('-O9G1W87)E(&EN=&5R;F\`;.UN96%S70!C\V1I9V\@
M9&4@97)R;W(@;6MI<V]F<R`E9"!A;"!R96%L:7IA<B!)4T\N`&UM`&YO;6)R
M90!S:6X@9&5S87)R;VQL87(`8?IN(&YO('-E(&AA(&1E<V%R<F]L;&%D;P!N
M;W1A<P!P;W)C96YT86IE`'!R:79I;&5G:6\@9&5N96=A9&\`<.UX96QE<P!E
M<G)O<B!R96UO=&\@9&4@<')O=&]C;VQO`&5N(&%U;65N=&\`<V5R=FEC:6\@
M;F\@9&ES<&]N:6)L92X`;6]S=')A<B!D:69E<F5N8VEA<P!S;7,R96UA:6P@
M<&]R($A45%``<W,`97-T86)L90!E<G)O<B!D96P@<VES=&5M80!T87)E87,`
M9F%L;&\@=&5M<&]R86P`97-C<FEB82!D;W,@=F5C97,@;&$@8V]N=')A<V7Q
M82!P87)A(&-O;F9I<FUA<FQA`'5N:69I8V%D;P!S:6X@;F]M8G)E`'5S=6%R
M:6\@<V5L96-C:6]N861O`'9#87)D`'<Z`'=E871H97(N8V]M````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQO8V%L92]E;E]54R]H96QP+GAM;```````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S$Q-"`Q,#4Q-30S-#$T,2`P,C$T
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CQH96QP/@H*/&5N=')Y(&ED/2)S=6UM
M87)Y(CX*/'1I=&QE/E1H92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*
M("!4:&ES('!O<G1A;"!P86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O
M9B!A;&P@>6]U<B!I;7!O<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP
M;&4L(&ET(&UI9VAT('-H;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E
M<R!Y;W4*("!H879E(&EN('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O
M;B!Y;W5R(&-A;&5N9&%R+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@
M:&5A9&QI;F5S(&9R;VT@<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O
M(&]N+B`@36%N>2!O9B!T:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@
M<75I8VL@<VAO<G1C=71S('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*
M("!C;VUP;W-I;F<@82!N97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE
M=R!C86QE;F1A<B!E=F5N="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R
M83X*("!4:&4@8V]N=&5N=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S
M=&]M:7IA8FQE('9I82!T:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L
M92P@>6]U(&-A;B!C:&]O<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T
M:&ES('!O<G1A;"!P86=E(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T
M:&5Y(&%R92!S:&]W;BX*(#PO<&%R83X*/"]E;G1R>3X*"CQE;G1R>2!I9#TB
M;F%V8F%R(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO;B!.879I9V%T:6]N($)A
M<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F="!H86YD('-I9&4@;V8@
M=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO;B!N879I9V%T:6]N(&)A
M<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI<R!N879I9V%T:6]N(&)A
M<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H"B`@8F5T=V5E;B!T:&4@
M879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R83X*/"]E;G1R>3X*"CQE
M;G1R>2!I9#TB<')E9G,M9&]?;6%I;G1E;F%N8V4B/@H@("`@/'1I=&QE/E!R
M969E<F5N8V5S.B!-86EN=&5N86YC93H@1&\@36%I;G1E;F%N8V4\+W1I=&QE
M/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!P97)F;W)M
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6XL(&-H96-K('1H:7,@
M8F]X+@H@("`@/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@
M36%I;G1E;F%N8V4Z($-O;F9I<FT@36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!)9B!Y;W4@=V]U;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M
M86EN=&5N86YC92!T87-K<R!B969O<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T
M:&ES(&)O>"X@268@;&5F="!U;F-H96-K960L(&%L;"!M86EN=&5N86YC92!O
M<&5R871I;VYS('1H870@;F5E9"!T;R!B92!R=6X@=VEL;"!B92!P97)F;W)M
M960@875T;VUA=&EC86QL>2!W:71H(&YO(&-H86YC92!T;R!C86YC96P@;VX@
M;&]G:6XN"B`@("`\+W!A<F$^"CPO96YT<GD^"@H\+VAE;'`^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O9F%?25(O3$-?34534T%'15,`````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#4V`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F85])4B]H96QP+GAM;```````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#8Q-"`Q,#4Q
M-30S-#$T,2`P,C$T,C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B`_/B`-"CQH96QP/@T*
M(#QE;G1R>2!I9#TB<W5M;6%R>2(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P
M,V5B-#<T.3)C9&,Q-2(@<W1A=&4](G5P=&]D871E(CX-"B`@/'1I=&QE/MBO
MV+':K]BGV8<\+W1I=&QE/B`-"B`@/'!A<F$^V*?9BMF&(-BOV+':K]BGV8<@
MV*[9A-BGV+79A^*`C-BGV8K9BB#8I]BR(-BGV+?9A-BGV+G8I]BJ(-F%V8?9
MA2#8M-F%V*<@V+'8IR#8K]BQ(-BGV*[8JMF*V*?8L2#9@MBQV*?8L2#9A=F*
MXH",V*_9A]BO+B#8J-BQV*?;C"#9A=BKV*?9A"#8I]F*V88@V*_8L=JOV*?9
MAR#9AMBTV*?9AB#9A=F*XH",V*_9A]BO(-JIV8<@VH;9AMBO(-F&V*?9A=F'
MV90@V*?9A-JIV*K8L=F(V8;9BMJIVXP@V*K8I]BRV8<@V*_8L2#9AMBGV879
MA^*`C-BOV*?9AB#8M-F%V*<@V879B-BLV8C8KR#8I]BSV*K8C"#:AMF'(-F(
MV8+8I]F*V+G;C"#8M]BHV8(@V*K9@MF(V8K9A2#8M-F%V*<@V+'8KB#8K]BG
MV*_9AR#8I]BSV*K8C"#:AMF'(-F(V+C8I]F*V8';C"#8M]BHV8(@V839BMBS
MV*H@V8C8N-BGV8K9@2#8M-F%V*<@V*C9AR#8N=F'V*_9A^*`C-BGV*K8I]F&
M(-BGV+/8JMB,(-BSV+'8JMF*V*K8L=F'V*?;C"#8L]BQV8C9BMBSV8?8I]N,
M(-BNV*C8L=N,(-BGV8;8JMBNV*?8J-N,(-BTV878IR#:AMF*V+/8JB#9B"`N
M+BXN/"]P87)A/B`-"B`@/'!A<F$^V878K=BJV8C8I]N,(-BGV8K9AB#8K]BQ
MVJ_8I]F'(-BGV+(@V+?8L=F*V8(@V*_:K]F%V8?9E"#8K-BGV8;9A=BGV*;;
MC"#9A=N,XH",V*K9B-BGV8;8KR#8J-F'(-BTVJG9A"#8K]F$V*[9B-BGV8<@
MV+39A=BG(-BOV+'8J-F*V*?9BMBO+B#8J-BQV*?;C"#9A=BKV*?9A"#8M-F%
MV*<@V87;C.*`C-BJV8C8I]F&V8K8KR#9A=F(V*?8L=BO(-BOV838KMF(V*?9
MAR#8KMF(V*\@V+'8IR#8J-BQV*?;C"#9AMF%V*?9BMBT(-BOV+$@V*_8L=JO
MV*?9AR#9B"#9A]F%VH;9AMF*V88@V*K8L=BJV8K8J"#9AMF%V*?9BMBT(-BB
MV8;9A]BG(-BQV*<@V8;9BMBR(-BJV+G9BMF*V88@V8;9A=BGV8K9BMBO+CPO
M<&%R83X@#0H@/"]E;G1R>3X-"B`\96YT<GD@:60](FYA=F)A<B(@;60U/2)B
M.&-F,&%E,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T-R(@<W1A=&4](G5P=&]D
M871E(CX-"B`@/'1I=&QE/MJOV++;C-F&VJ_8I]F&(-F%V+'9B-BQVJ_8L2#8
MJ-BQV8;8I]F%V8?B@(S9A]BG/"]T:71L93X@#0H@(#QP87)A/MBOV+$@V+/9
MA=BJ(-BQV*?8L]BJ(-BGV8K9AB#8K]BQVJ_8I]F'(-JOV++;C-F&VJ_8I]F&
M(-F%V+'9B-BQVJ_8L2#8J-BQV8;8I]F%V8?B@(S9A]BGVXP@VJG8I]BQV*C8
ML=BOVXP@V8+8L=BGV+$@V*_8I]BQV*\@VJG9AR#8J-BG(-F!V+38L=BOV88@
MV*_:K]F%V8<@V879B-BS(-BHV+$@V+'9B-N,(-F'V+$@V8K:J2#8I]BR(-BG
MV8K9AB#8J-BQV8;8I]F%V8?B@(S9A]BG(-BHV8<@V+'8I]BMV*K;C"#9A=N,
MXH",V*K9B-BGV8;9BMBO(-BGV+(@V*+9AMF'V*<@V*?8L]BJV8'8I]BOV8<@
MV8;9A=BGV8K9BMBO+CPO<&%R83X@#0H@/"]E;G1R>3X-"B`\96YT<GD@:60]
M(G!R969S+61O7VUA:6YT96YA;F-E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R
M8F%E83DQ.3(X.&(R9#`P(B!S=&%T93TB=7!T;V1A=&4B/@T*("`\=&ET;&4^
MV*K8L=BLV8K8K=BGV*H@.B#9AMJOV8?8K]BGV+';C"`Z(-BGV8;8K-BGV84@
MV8;:K]F'V*_8I]BQVXP\+W1I=&QE/B`-"B`@/'!A<F$^V*?:K]BQ(-BTV878
MIR#9A=BGV8K9A"#8J-F'(-BGV8;8K-BGV84@V+G9A=F$V8K8I]BJ(-F&VJ_9
MA]BOV*?8L=N,(-BHV8<@V8?9AMJOV*?9A2#9B-BQV8C8KR#9A=N,XH",V*C8
MI]BTV8K8KR#8I]F*V88@VJ_8LMF*V8;9AR#8L=BG(-BHV*?9BMBO(-BGV8;8
MJMBNV*?8J"#:J=F&V8K8KRX\+W!A<F$^(`T*(#PO96YT<GD^#0H@/&5N=')Y
M(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!M9#4](F$R,3$V,F-D
M9F8S8C%D.&9A96%D8C<R.38R-#`P,S9E(B!S=&%T93TB=7!T;V1A=&4B/@T*
M("`\=&ET;&4^V*K8L=BLV8K8K=BGV*H@.B#9AMJOV8?8K]BGV+';C"`Z(-BJ
MV*/8IMF*V*\@V8;:K]F'V*_8I]BQVXP\+W1I=&QE/B`-"B`@/'!A<F$^V*?:
MK]BQ(-BTV878IR#9A=BGV8K9A"#9A]BSV*K9BMBO(-JIV8<@V+G9A=F$V8K8
MI]BJ(-F&VJ_9A]BOV*?8L=N,(-BQV*<@V8+8J-F$(-BGV+(@V*?9AMBLV*?9
MA2#8HMF&V8?8IR#8JMBCV*;9BMBO(-JIV8;9BMBOV(P@V*?9BMF&(-JOV++9
MBMF&V8<@V+'8IR#8I]F&V*K8KMBGV*@@VJG9AMF*V*\N(-BOV+$@V+K9BMBQ
M(-BGV8K9AB#8M=F(V+'8JB#8JMF%V*?9A2#8N=F%V839BMBGV*H@V8;:K]F'
MV*_8I]BQVXP@V*C9AR#9A]F&VJ_8I]F%(-F(V+'9B-BO(-BGV8;8K-BGV84@
MV8K8I]F!V*K9AR#9B"#8M-F%V*<@V+38I]F&V+/;C"#8J-BQV*?;C"#9A=F$
MV+K;C"#:J=BQV*_9AB#8HMF&(-F&V*[9B-BGV8?9BMBO(-BOV*?8M-BJ+CPO
M<&%R83X@#0H@/"]E;G1R>3X-"CPO:&5L<#X`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]F85])4B],
M0U]-15-304=%4R]H;W)D92YM;P``````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#,U-S<Q-R`Q,#4Q-30S-#$T,2`P,C,R,3<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````WA($E0````"G!0``'````%0M``"+
M!P``C%H```````"X>```#@```+EX```/````R'@```T```#8>```"````.9X
M```+````[W@```P```#[>```!`````AY```D````#7D``"D````R>0``&0``
M`%QY```F````=GD```P```"=>0``)````*IY```/````SWD```L```#?>0``
M#@```.MY```%````^GD``"@`````>@``"````"EZ```*````,GH``!4````]
M>@``$@```%-Z```+````9GH``(4```!R>@``#@```/AZ```*````!WL```T`
M```2>P``#@```"![```1````+WL```T```!!>P``#````$][```-````7'L`
M``8```!J>P``"@```'%[```/````?'L``!@```",>P``#````*5[```.````
MLGL```X```#!>P``"````-![```N````V7L``!H````(?```,@```"-\```X
M````5GP``%0```"/?```40```.1\``!:````-GT``%<```"1?0``-````.E]
M```-````'GX```<````L?@``"@```#1^```/````/WX```4```!/?@``$0``
M`%5^```(````9WX```D```!P?@``"0```'I^```E````A'X``"````"J?@``
M$P```,M^```0````WWX```\```#P?@``"@````!_```#````"W\```\````/
M?P``%````!]_```)````-'\```T````^?P``$@```$Q_```>````7W\```\`
M``!^?P``"@```(Y_```/````F7\```@```"I?P``)````+)_```4````UW\`
M`!8```#L?P``"`````.````9````#(````<````F@```#````"Z````L````
M.X````X```!H@````P```'>````%````>X````4```"!@```"@```(>````#
M````DH```!<```"6@```"@```*Z````/````N8````X```#)@```&````-B`
M```C````\8````X````5@0``%````"2!```7````.8$``!<```!1@0``%P``
M`&F!```3````@8$```\```"5@0``'P```*6!```/````Q8$```8```#5@0``
M"P```-R!```0````Z($``!4```#Y@0``%0````^"```'````)8(``!`````M
M@@``!0```#Z"```5````1((``!$```!:@@``#````&R"```[````>8(``!0`
M``"U@@```P```,J"```Y````SH(``!(````(@P``)P```!N#```L````0X,`
M`"H```!P@P``)0```)N#```*````P8,```8```#,@P``+P```-.#```W````
M`X0``"X````[A```50```&J$```M````P(0``"T```#NA```+0```!R%``!`
M````2H4``",```"+A0``(P```*^%```M````TX4``#,````!A@``%0```#6&
M```9````2X8``"D```!EA@``)````(^&```1````M(8```H```#&A@``$```
M`-&&```6````XH8``!8```#YA@``%````!"'```(````)8<``"D````NAP``
M#@```%B'```*````9X<```0```!RAP``"0```'>'```&````@8<``!$```"(
MAP``!P```)J'```$````HH<```8```"GAP``#0```*Z'```#````O(<```,`
M``#`AP``%P```,2'```3````W(<```@```#PAP``!````/F'``!!````_H<`
M`!H```!`B```(````%N(```5````?(@```8```"2B```%0```)F(```8````
MKX@``"(```#(B```+@```.N(```=````&HD``"$````XB0``5````%J)```I
M````KXD```<```#9B0``!P```.&)```5````Z8D```H```#_B0``#P````J*
M```-````&HH```\````HB@``#0```#B*```)````1HH``!0```!0B@``!@``
M`&6*```=````;(H``!,```"*B@``%````)Z*```&````LXH``!0```"ZB@``
M5````,^*``!D````)(L```0```")BP``#@```(Z+```%````G8L``!L```"C
MBP``&@```+^+```1````VHL``!$```#LBP``'````/Z+```J````&XP``"$`
M``!&C```!0```&B,```3````;HP``!(```""C```"@```)6,```/````H(P`
M`!$```"PC```$P```,*,```,````UHP```8```#CC```!@```.J,```0````
M\8P``!$````"C0``!0```!2-```,````&HT``!`````GC0``!0```#B-```-
M````/HT```8```!,C0``!P```%.-```-````6XT```<```!IC0``"P```'&-
M```'````?8T```D```"%C0``"0```(^-```*````F8T``!D```"DC0``#```
M`+Z-```0````RXT``!(```#<C0``$P```.^-```K`````XX``#L````OC@``
M(````&N.```(````C(X``#8```"5C@``"````,R.```&````U8X```0```#<
MC@``#@```.&.```>````\(X``!L````/CP``(0```"N/```>````38\``!D`
M``!LCP``'@```(:/```=````I8\``!L```##CP``(````-^/```F`````)``
M`!L````GD```'@```$.0```<````8I```"8```!_D```,P```*:0```F````
MVI```"L````!D0``.````"V1```O````9I$``!(```"6D0``*0```*F1```2
M````TY$``*(```#FD0``%@```(F2```C````H)(``"@```#$D@``*0```.V2
M```H````%Y,``!\```!`DP``(````&"3```E````@9,``"@```"GDP``,```
M`-"3``"2`````90``"$```"4E```'````+:4```F````TY0``$$```#ZE```
M#````#R5```'````294```<```!1E0``!@```%F5```-````8)4``!````!N
ME0``$@```'^5```3````DI4``!(```"FE0``#````+F5```.````QI4```\`
M``#5E0``$P```.65```-````^94``"@````'E@```P```#"6```-````-)8`
M`!$```!"E@``%P```%26```;````;)8```(```"(E@``!0```(N6```0````
MD98```0```"BE@``#0```*>6```.````M98```,```#$E@``#@```,B6```(
M````UY8```\```#@E@``#P```/"6```'`````)<```T````(EP``$````!:7
M```-````)Y<```L````UEP``!@```$&7```,````2)<``!$```!5EP``&0``
M`&>7```+````@9<```T```"-EP``(@```)N7```;````OI<``#0```#:EP``
M"@````^8```8````&I@``!D````SF```%@```$V8```-````9)@``!0```!R
MF```"P```(>8```B````DY@``"\```"VF```"P```.:8```)````\I@``!D`
M``#\F```"P```!:9```7````(ID``!<````ZF0``"0```%*9```6````7)D`
M``\```!SF0``&0```(.9```6````G9D```X```"TF0``&````,.9```-````
MW)D``"8```#JF0``0P```!&:```(````59H```L```!>F@``+P```&J:```.
M````FIH```4```"IF@``!@```*^:```#````MIH```0```"ZF@``"@```+^:
M```*````RIH```\```#5F@``$````.6:```7````]IH``!$````.FP``&0``
M`"";```7````.IL```D```!2FP``"@```%R;```"````9YL```4```!JFP``
M#0```'";```;````?IL``!<```":FP``"0```+*;```.````O)L```T```#+
MFP``$@```-F;```X````[)L``"`````EG```"````$:<```.````3YP``'L`
M``!>G```&````-J<```%````\YP``!@```#YG```&0```!*=```;````+)T`
M`!D```!(G0``!@```&*=```&````:9T``!````!PG0``#P```(&=```0````
MD9T```\```"BG0``"P```+*=```/````OIT```P```#.G0``#P```-N=```'
M````ZYT```8```#SG0``#@```/J=```,````"9X```\````6G@``"````":>
M```(````+YX``!,````XG@``'@```$R>```A````:YX``"````"-G@``&0``
M`*Z>```7````R)X``"4```#@G@``%P````:?```$````'I\```P````CGP``
M`P```#"?```(````-)\```L````]GP``$````$F?```3````6I\``!0```!N
MGP``#````(.?```)````D)\```X```":GP``"P```*F?```;````M9\```<`
M``#1GP``"@```-F?```-````Y)\```D```#RGP``!0```/R?```#`````J``
M`!@````&H```"@```!^@```$````*J```"8````OH```#@```%:@```5````
M9:````4```![H```!P```(&@```,````B:````@```"6H```"@```)^@```&
M````JJ````@```"QH````@```+J@```&````O:````0```#$H```"0```,F@
M```0````TZ````D```#DH```"0```.Z@```:````^*````@````3H0``&0``
M`!RA```.````-J$```H```!%H0```@```%"A```-````4Z$```D```!AH0``
M$@```&NA```4````?J$``!T```"3H0``!@```+&A```1````N*$```D```#*
MH0``!````-2A```Y````V:$``#T````3H@``.@```%&B```>````C*(```X`
M``"KH@``!````+JB```&````OZ(``!4```#&H@``!@```-RB```$````XZ(`
M`!$```#HH@``!@```/JB```*`````:,``"(````,HP``!````"^C```%````
M-*,```0````ZHP``#````#^C```.````3*,```H```!;HP``!0```&:C```Z
M````;*,``#````"GHP``-0```-BC```I````#J0``#@````XI```*0```'&D
M```_````FZ0``"X```#;I```+0````JE```?````.*4```\```!8I0``$@``
M`&BE```+````>Z4``"8```"'I0``*0```*ZE```D````V*4``"8```#]I0``
M"````"2F```*````+:8``"`````XI@``(````%FF```F````>J8```H```"A
MI@``&0```*RF```I````QJ8``!(```#PI@``"@````.G```,````#J<```\`
M```;IP``$````"NG``!`````/*<``'````!]IP``9@```.ZG```.````5:@`
M``D```!DJ```"@```&ZH```2````>:@``!,```",J```#````*"H```&````
MK:@```\```"TJ```$@```,2H```0````UZ@``!$```#HJ```'````/JH```C
M````%ZD``&H````[J0``#P```*:I```0````MJD```0```#'J0``"P```,RI
M```@````V*D``!0```#YJ0``#`````ZJ```,````&ZH```\````HJ@``%0``
M`#BJ```I````3JH``"H```!XJ@``)@```*.J```G````RJH``"D```#RJ@``
M*@```!RK```9````1ZL``$(```!AJP``$0```*2K```2````MJL``!,```#)
MJP``%````-VK```/````\JL``!8````"K```%P```!FL```0````,:P``!$`
M``!"K```-````%2L```3````B:P``!(```"=K```-0```+"L```4````YJP`
M``<```#[K```#`````.M```@````$*T``!0````QK0``$0```$:M```7````
M6*T``!P```!PK0``$P```(VM```1````H:T``!H```"SK0``'@```,ZM```:
M````[:T``!$````(K@``%P```!JN```4````,JX``!<```!'K@``%0```%^N
M```)````=:X``!````!_K@``$0```)"N```&````HJX```8```"IK@``!P``
M`+"N```6````N*X```8```#/K@``!````-:N```$````VZX```<```#@K@``
M#@```.BN```,````]ZX```P````$KP``#0```!&O```.````'Z\``"@````N
MKP``#````%>O```/````9*\```H```!TKP``"````'^O```)````B*\``"L`
M``"2KP``!````+ZO```/````PZ\```<```#3KP``"````-NO```)````Y*\`
M`!0```#NKP``#`````.P```-````$+````X````>L```%@```"VP```1````
M1+````,```!6L```!@```%JP```$````8;````L```!FL```"P```'*P```-
M````?K````H```",L```$````)>P```/````J+```!$```"XL```%P```,JP
M```*````XK```!$```#ML```!````/^P```/````!+$``#H````4L0``!0``
M`$^Q```,````5;$``!X```!BL0``#@```(&Q```0````D+$```L```"AL0``
M#````*VQ```)````NK$```<```#$L0``"@```,RQ```)````U[$```X```#A
ML0``$````/"Q```:`````;(```H````<L@``"@```">R```,````,K(```\`
M```_L@``"````$^R```&````6+(```<```!?L@``!0```&>R```+````;;(`
M`$<```!YL@``#0```,&R```)````S[(```0```#9L@```P```-ZR```3````
MXK(``!,```#VL@``$P````JS```"````'K,```0````ALP``)0```":S```#
M````3+,```4```!0LP``!````%:S```*````6[,```T```!FLP``:````'2S
M```)````W;,```P```#GLP``!0```/2S```&````^K,``!L````!M```+P``
M`!VT```/````3;0``!,```!=M```&P```'&T```8````C;0``!<```"FM```
M#@```+ZT```#````S;0```@```#1M```!P```-JT```*````XK0```L```#M
MM```!P```/FT``!1`````;4``!````!3M0``#````&2U```-````<;4``!H`
M``!_M0``2@```)JU```&````Y;4```8```#LM0``!@```/.U```)````^K4`
M`!@````$M@``%P```!VV```&````-;8```T````\M@``5P```$JV```3````
MHK8``!,```"VM@```@```,JV```+````S;8```@```#9M@``#0```.*V```*
M````\+8```X```#[M@``!P````JW```+````$K<```P````>MP``#0```"NW
M```,````.;<```D```!&MP``"0```%"W```*````6K<```<```!EMP``"0``
M`&VW```'````=[<``!L```!_MP``$@```)NW```*````KK<``!8```"YMP``
M"0```-"W```0````VK<``!(```#KMP``!````/ZW```1`````[@``!H````5
MN```%@```#"X```4````1[@``!<```!<N```'````'2X```9````D;@```<`
M``"KN```!0```+.X```,````N;@```@```#&N```%P```,^X```,````Y[@`
M`!\```#TN```&@```!2Y```3````+[D```0```!#N0``"@```$BY```$````
M4[D```P```!8N0``!0```&6Y```"````:[D``#@```!NN0``+````*>Y```2
M````U+D``"D```#GN0``,@```!&Z```*````1+H``"P```!/N@``+@```'RZ
M```S````J[H``#,```#?N@``.````!.[```/````3+L``!@```!<NP``$```
M`'6[```/````AKL``!,```"6NP``%````*J[```2````O[L``!0```#2NP``
M%0```.>[```M````_;L``"T````KO```,0```%F\```N````B[P``"\```"Z
MO```+````.J\```3````%[T```@````KO0``%P```#2]```(````3+T``"L`
M``!5O0``(0```(&]```:````H[T```D```"^O0``10```,B]``!!````#KX`
M``0```!0O@``$P```%6^```4````:;X``!,```!^O@``"0```)*^```*````
MG+X```\```"GO@``$````+>^```'````R+X```X```#0O@``!0```-^^```;
M````Y;X```@````!OP``!@````J_```4````$;\``!$````FOP``#@```#B_
M```X````1[\```(```"`OP``!@```(._```.````BK\```4```"9OP``!P``
M`)^_```.````I[\```8```"VOP``*````+V_```,````YK\``!P```#SOP``
M*0```!#````7````.L```!\```!2P```7````'+````4````S\```!\```#D
MP```$`````3!```'````%<$```X````=P0``#````"S!```,````.<$``!,`
M``!&P0``"@```%K!```=````9<$``!D```"#P0``!0```)W!```1````H\$`
M`!$```"UP0``)````,?!```5````[,$``!(````"P@``#@```!7"```9````
M),(```@````^P@``"0```$?"```-````4<(```H```!?P@``!P```&K"```/
M````<L(```L```""P@``&@```(["```*````J<(```<```"TP@``#0```+S"
M```(````RL(``!X```#3P@``$@```/+"```L````!<,``!H````RPP``"0``
M`$W#```*````5\,``!4```!BPP``!0```'C#```4````?L,```0```"3PP``
M$````)C#```&````J<,```<```"PPP``'@```+C#```H````U\,```H`````
MQ```'`````O$```+````*,0``!H````TQ```%````$_$```$````9,0```4`
M``!IQ```!@```&_$```&````=L0``!L```!]Q```-````)G$```T````SL0`
M`"`````#Q0``*0```"3%```@````3L4``$$```!OQ0``&@```+'%```H````
MS,4``"D```#UQ0``4````!_&```B````<,8```@```"3Q@``!0```)S&```9
M````HL8``!D```"\Q@``*@```-;&```C`````<<``"X````EQP``-````%3'
M```(````B<<``!<```"2QP``"@```*K'```'````M<<``"$```"]QP``$```
M`-_'```.````\,<```L```#_QP``!P````O(```3````$\@```@````GR```
M"P```##(```*````/,@``!0```!'R```,@```%S(```%````C\@```4```"5
MR```%P```)O(```/````L\@```0```##R```"@```,C(```)````T\@```L`
M``#=R```#0```.G(```,````]\@```X````$R0``!0```!/)```$````&<D`
M``T````>R0``,@```"S)``!%````7\D``!<```"ER0``'@```+W)```4````
MW,D``!0```#QR0``!P````;*```.````#LH``"H````=R@``!@```$C*```,
M````3\H```T```!<R@``$0```&K*```+````?,H``#8```"(R@``"@```+_*
M```B````RLH```L```#MR@``#P```/G*```R````"<L```X````\RP``!0``
M`$O+```.````4<L``!,```!@RP``!P```'3+```1````?,L``!,```".RP``
M!P```*++```4````JLL``!@```"_RP``!P```-C+```%````X,L```P```#F
MRP``#````//+```2`````,P```0````3S```"@```!C,```+````(\P```P`
M```OS```#@```#S,```.````2\P```4```!:S```!0```&#,```N````9LP`
M`"8```"5S```(P```+S,```#````X,P``!@```#DS```)0```/W,```-````
M(\T```D````QS0```P```#O-```'````/\T```H```!'S0```@```%+-```2
M````5<T```0```!HS0``!P```&W-```,````=<T``%(```""S0``%P```-7-
M```'````[<T```8```#US0``#@```/S-```,````"\X```T````8S@``%0``
M`";.```2````/,X```\```!/S@``%````%_.```*````=,X``!L```!_S@``
M$````)O.```+````K,X``&D```"XS@``&@```"+/```7````/<\``"<```!5
MSP``&@```'W/```7````F,\``!L```"PSP``&0```,S/```?````YL\``!,`
M```&T```"````!K0```(````(]````D````LT```#0```#;0```3````1-``
M``,```!8T```1@```%S0```_````H]```#<```#CT```5P```!O1```%````
M<]$``!\```!YT0``+P```)G1```(````R=$```T```#2T0``+0```.#1```$
M````#M(``$\````3T@``)0```&/2```<````B=(```L```"FT@``'P```++2
M```=````TM(``"4```#PT@``(````!;3```D````-],``"````!<TP``"P``
M`'W3```'````B=,```T```"1TP``#````)_3```&````K-,``#D```"STP``
M!P```.W3```)````]=,``!,```#_TP``!````!/4```0````&-0```0````I
MU```"P```"[4```,````.M0``!(```!'U```$0```%K4```,````;-0``!H`
M``!YU```#0```)34```4````HM0```X```"WU```&P```,;4```3````XM0`
M`!P```#VU```*````!/5```&````/-4```<```!#U0``$P```$O5```$````
M7]4``!<```!DU0``"@```'S5```,````A]4```D```"4U0``!@```)[5```(
M````I=4```D```"NU0``"@```+C5```1````P]4```8```#5U0``#@```-S5
M```.````Z]4```L```#ZU0``"P````;6```"````$M8```<````5U@``!@``
M`!W6```)````)-8```<````NU@``&@```#;6```[````4=8``"@```"-U@``
M-````+;6```5````Z]8```<````!UP``"`````G7```'````$M<```4````:
MUP``!P```"#7```.````*-<```D````WUP``!@```$'7```(````2-<```L`
M``!1UP``!P```%W7```'````9=<``!P```!MUP``!P```(K7```(````DM<`
M``@```";UP``!0```*37```0````JM<``!````"[UP``!P```,S7```%````
MU-<``!````#:UP``%````.O7```+`````-@```T````,V```%P```!K8```$
M````,M@```D````WV```"@```$'8```'````3-@```(```!4V```#@```%?8
M```?````9M@``",```"&V```,0```*K8```G````W-@``&0````$V0``%```
M`&G9``!5````?MD``#@```#4V0``2@````W:``!;````6-H``"@```"TV@``
M.````-W:```H````%ML``"P````_VP``)P```&S;```;````E-L``*D!``"P
MVP``(P```%K=```7````?MT``(4```"6W0``,````!S>```E````3=X``%L`
M``!SW@``20```,_>```=````&=\``!@````WWP``*P```%#?```A````?-\`
M`!\```">WP``*P```+[?```A````ZM\``"<````,X```'0```#3@```1````
M4N```#,```!DX```)0```)C@```G````ON```!\```#FX```,`````;A``!I
M````-^$``#T```"AX0``90```-_A``!-````1>(``"\```"3X@``+@```,/B
M```P````\N(``%0````CXP``6@```'CC``!(````T^,``$H````<Y```,@``
M`&?D```O````FN0``"P```#*Y```+0```/?D```7````)>4``"4````]Y0``
M,@```&/E```I````EN4``#X```#`Y0``(@```/_E```+````(N8``$4````N
MY@``(0```'3F```P````EN8``"4```#'Y@``'````.WF```Q````"N<```<`
M```\YP``!P```$3G```$````3.<```T```!1YP``"P```%_G```.````:^<`
M``4```!ZYP``$````(#G```"````D><``%D```"4YP``!0```.[G```(````
M].<```,```#]YP``$`````'H```,````$N@```T````?Z````@```"WH```4
M````,.@``!(```!%Z```#````%CH```#````9>@```0```!IZ```'P```&[H
M```U````CN@``"X```#$Z```+P```//H```7````(^D``"`````[Z0``&P``
M`%SI```8````>.D``"0```"1Z0``'P```+;I```:````UND``"````#QZ0``
M&@```!+J```R````+>H``!H```!@Z@``+P```'OJ```K````J^H``!\```#7
MZ@``(P```/?J```?````&^L``!H````[ZP``)0```%;K```F````?.L``"4`
M``"CZP``)````,GK```8````[NL``!T````'[```)````"7L```8````2NP`
M`"(```!C[```)0```(;L```\````K.P``!\```#I[```(P````GM```?````
M+>T``"````!-[0``&@```&[M```8````B>T``"8```"B[0``'@```,GM```I
M````Z.T``!X````2[@``"0```#'N```,````.^X``!<```!([@``+P```&#N
M```D````D.X```<```"U[@``#P```+WN```%````S>X```<```#3[@``'0``
M`-ON```:````^>X```<````4[P``QP```!SO```+````Y.\``!4```#P[P``
M!@````;P```)````#?````L````7\```#0```"/P```7````,?````8```!)
M\```,P```%#P```3````A/```!,```"8\```#P```*SP```'````O/```#(`
M``#$\```(0```/?P```3````&?$```P````M\0``$0```#KQ```R````3/$`
M`!8```!_\0``"````);Q```)````G_$```H```"I\0``%````+3Q```=````
MR?$```@```#G\0``'P```/#Q```(````$/(``!H````9\@``)P```#3R```&
M````7/(``!4```!C\@``"````'GR```'````@O(```\```"*\@``#@```)KR
M```0````J?(```D```"Z\@``"0```,3R```3````SO(```<```#B\@``&0``
M`.KR```*````!/,```H````/\P``#````!KS```J````)_,```<```!2\P``
M`@```%KS```0````7?,``!@```!N\P``"P```(?S```#````D_,```@```"7
M\P``!@```*#S```'````I_,```T```"O\P``"P```+WS```4````R?,``!4`
M``#>\P``+P```/3S```@````)/0``!P```!%]```#````&+T```Q````;_0`
M``4```"A]```$@```*?T```_````NO0``!(```#Z]```"@````WU```&````
M&/4```0````?]0``!````"3U```*````*?4``!,````T]0``!0```$CU```&
M````3O4```8```!5]0``!````%SU```,````8?4```H```!N]0```@```'GU
M```$````?/4```8```"!]0```P```(CU```,````C/4``$4```"9]0``&@``
M`-_U```U````^O4``"@````P]@``4P```%GV```9````K?8``'(```#']@``
M(````#KW```U````6_<``"$```"1]P``10```+/W```P````^?<``"@````J
M^```*0```%/X```F````??@``"4```"D^```*````,KX```H````\_@``"(`
M```<^0``,````#_Y```2````</D``!,```"#^0``$````)?Y``!Y````J/D`
M``D````B^@``<P```"SZ``!\````H/H``"L````=^P``%P```$G[```6````
M8?L```\```!X^P``%P```(C[```?````H/L``$````#`^P``'P````'\```<
M````(?P``%$````^_```&@```)#\```4````J_P``!(```#`_```$````-/\
M```3````Y/P``!T```#X_```#P```!;]```/````)OT```0````V_0``"0``
M`#O]```+````1?T```<```!1_0``!0```%G]```4````7_T```<```!T_0``
M"````'S]```/````A?T```@```"5_0``#````)[]```/````J_T```8```"[
M_0``%````,+]```&````U_T```P```#>_0``"````.O]```$````]/T```H`
M``#Y_0``!`````3^```9````"?X```<````C_@```@```"O^```)````+OX`
M``8````X_@``!@```#_^```$````1OX```\```!+_@``$P```%O^```'````
M;_X```<```!W_@``!@```'_^```&````AOX``!````"-_@``!@```)[^```)
M````I?X``"(```"O_@``!P```-+^```'````VOX```L```#B_@``!0```.[^
M```"````]/X```L```#W_@``<0$```/_```3````=0`!`!H```")``$`$```
M`*0``0`-````M0`!``L```##``$`#0```,\``0`&````W0`!`#@```#D``$`
M-@```!T!`0`D````5`$!`#H```!Y`0$`"P```+0!`0`Z````P`$!`!P```#[
M`0$`#0```!@"`0`4````)@(!`!,````[`@$`*P```$\"`0`?````>P(!`!``
M``";`@$`%@```*P"`0`@````PP(!``T```#D`@$`PP```/("`0`;````M@,!
M``T```#2`P$`$@```.`#`0`2````\P,!`!H````&!`$`#0```"$$`0`,````
M+P0!`!@````\!`$`!@```%4$`0`)````7`0!``\```!F!`$`'P```'8$`0`.
M````E@0!`!@```"E!`$`&````+X$`0`/````UP0!`%(```#G!`$`*0```#H%
M`0!=````9`4!`&\```#"!0$`E````#(&`0".````QP8!`)(```!6!P$`D0``
M`.D'`0!;````>P@!`"````#7"`$`&0```/@(`0`9````$@D!`!<````L"0$`
M#0```$0)`0`D````4@D!``\```!W"0$`$P```(<)`0`/````FPD!`#@```"K
M"0$`/````.0)`0`7````(0H!`!8````Y"@$`$P```%`*`0`0````9`H!`!,`
M``!U"@$`)0```(D*`0`H````KPH!`!L```#8"@$`)0```/0*`0`E````&@L!
M`#0```!`"P$`+0```'4+`0`<````HPL!`"<```#`"P$`&@```.@+`0!4````
M`PP!`#$```!8#`$`-0```(H,`0`>````P`P!`#0```#?#`$`"````!0-`0`8
M````'0T!`$P````V#0$`#@```(,-`0`.````D@T!``H```"A#0$`$0```*P-
M`0`)````O@T!``8```#(#0$`.````,\-`0`6````"`X!`!8````?#@$`&```
M`#8.`0`<````3PX!`$D```!L#@$`'0```+8.`0`<````U`X!`"$```#Q#@$`
M)P```!,/`0`Q````.P\!`"````!M#P$`%@```(X/`0`U````I0\!``P```#;
M#P$`"````.@/`0`@````\0\!`"\````2$`$`'@```$(0`0`R````81`!``H`
M``"4$`$`&0```)\0`0`*````N1`!`!4```#$$`$`)````-H0`0`1````_Q`!
M`'0````1$0$`%````(81`0`&````FQ$!`%P```"B$0$`&0```/\1`0!$````
M&1(!`$0```!>$@$`2@```*,2`0!.````[A(!`!$````]$P$`"@```$\3`0`Z
M````6A,!`%T```"5$P$`-@```/,3`0`V````*A0!`#<```!A%`$`.````)D4
M`0`X````TA0!`'<````+%0$`,0```(,5`0`\````M14!`#@```#R%0$`/@``
M`"L6`0`K````:A8!`"\```"6%@$`2````,86`0!"````#Q<!`"4```!2%P$`
M$0```'@7`0`8````BA<!`",```"C%P$`)P```,<7`0`4````[Q<!``T````$
M&`$`10```!(8`0`7````6!@!``\```!P&`$`"````(`8`0`-````B1@!``8`
M``"7&`$`$@```)X8`0`-````L1@!``D```"_&`$`"@```,D8`0`:````U!@!
M``,```#O&`$``P```/,8`0`7````]Q@!`!H````/&0$`"@```"H9`0`(````
M-1D!`)8````^&0$`,0```-49`0!/````!QH!`#8```!7&@$`#````(X:`0`G
M````FQH!`#@```##&@$`.````/P:`0!3````-1L!`#(```")&P$`0P```+P;
M`0#!`````!P!`%$```#"'`$`"@```!0=`0`(````'QT!`"$````H'0$`#```
M`$H=`0`7````5QT!`!,```!O'0$`%P```(,=`0`@````FQT!``P```"\'0$`
M%````,D=`0`(````WAT!`!T```#G'0$`&`````4>`0`;````'AX!``L````Z
M'@$`+0```$8>`0"0````=!X!`*0````%'P$`"@```*H?`0`8````M1\!``,`
M``#.'P$`&P```-(?`0`:````[A\!`!\````)(`$`)0```"D@`0`P````3R`!
M`$H```"`(`$`)@```,L@`0`&````\B`!`",```#Y(`$`'P```!TA`0`:````
M/2$!`"4```!8(0$`)P```'XA`0`=````IB$!`!,```#$(0$`"@```-@A`0`(
M````XR$!`"$```#L(0$`&P````XB`0`&````*B(!`!X````Q(@$`$P```%`B
M`0`-````9"(!`!D```!R(@$`"````(PB`0`*````E2(!`!4```"@(@$`"@``
M`+8B`0`1````P2(!``@```#3(@$`$P```-PB`0`&````\"(!``H```#W(@$`
M(0````(C`0`3````)",!`!@````X(P$`(````%$C`0`@````<B,!`#H```"3
M(P$`30```,XC`0`V````'"0!``P```!3)`$`7P```&`D`0`*````P"0!``@`
M``#+)`$`#````-0D`0`V````X20!`#T````8)0$`.0```%8E`0!`````D"4!
M`#P```#1)0$`.`````XF`0`T````1R8!`#,```!\)@$`,@```+`F`0`V````
MXR8!`#\````:)P$`/@```%HG`0!!````F2<!`#,```#;)P$`0@````\H`0!>
M````4B@!`$<```"Q*`$`1P```/DH`0!6````02D!`%<```"8*0$`)P```/`I
M`0!,````&"H!`"0```!E*@$`*`$``(HJ`0`Y````LRL!`%$```#M*P$`40``
M`#\L`0!1````D2P!`%4```#C+`$`.@```#DM`0`\````="T!`$0```"Q+0$`
M20```/8M`0!4````0"X!`"(!``"5+@$`.@```+@O`0`^````\R\!`$P````R
M,`$`@P```'\P`0`8`````S$!``@````<,0$`#P```"4Q`0`*````-3$!`!H`
M``!`,0$`&@```%LQ`0`@````=C$!`"0```"7,0$`(@```+PQ`0`1````WS$!
M`!,```#Q,0$`&0````4R`0`5````'S(!``\````U,@$`/````$4R`0`*````
M@C(!`!<```"-,@$`$0```*4R`0`7````MS(!`!L```#/,@$``@```.LR`0`,
M````[C(!`!X```#[,@$`"@```!HS`0`>````)3,!`!<```!$,P$`!@```%PS
M`0`/````8S,!``P```!S,P$`%0```(`S`0`<````EC,!``T```"S,P$`%```
M`,$S`0`8````UC,!`!H```#O,P$`#`````HT`0`&````%S0!``\````>-`$`
M#P```"XT`0`G````/C0!``\```!F-`$`#P```'8T`0`K````AC0!`"(```"R
M-`$`1P```-4T`0`-````'34!`"4````K-0$`&````%$U`0`6````:C4!`!,`
M``"!-0$`#P```)4U`0`*````I34!``\```"P-0$`10```,`U`0`*````!C8!
M`!$````1-@$`,````",V`0`3````5#8!`!X```!H-@$`'@```(<V`0`(````
MIC8!`#H```"O-@$`'@```.HV`0`H````"3<!`!L````R-P$`$P```$XW`0`1
M````8C<!``\```!T-P$`0````(0W`0"$````Q3<!``X```!*.`$`$0```%DX
M`0!2````:S@!`!P```"^.`$`#````-LX`0`=````Z#@!``,````&.0$`#```
M``HY`0`5````%SD!`!4````M.0$`%0```$,Y`0`9````63D!`"4```!S.0$`
M(0```)DY`0`J````NSD!`"@```#F.0$`#@````\Z`0`+````'CH!``(````J
M.@$`'0```"TZ`0`H````2SH!`%(```!T.@$`+P```,<Z`0`.````]SH!`!T`
M```&.P$`'````"0[`0`G````03L!`%4```!I.P$`2P```+\[`0`3````"SP!
M`"(````?/`$`NP```$(\`0`P````_CP!``8````O/0$`'@```#8]`0`@````
M53T!`#$```!V/0$`-@```*@]`0`*````WST!``H```#J/0$`'````/4]`0`4
M````$CX!`!0````G/@$`%@```#P^`0`2````4SX!`!0```!F/@$`#P```'L^
M`0`6````BSX!``@```"B/@$`#P```*L^`0`B````NSX!`!D```#>/@$`%P``
M`/@^`0`.````$#\!`!H````?/P$`$P```#H_`0`R````3C\!`#@```"!/P$`
M.````+H_`0`V````\S\!`#<````J0`$`/P```&)``0`M````HD`!``@```#0
M0`$`$0```-E``0`&````ZT`!``H```#R0`$`$P```/U``0`/````$4$!`"@`
M```A00$`*````$I!`0`5````<T$!`!,```")00$`&0```)U!`0`7````MT$!
M`#H```#/00$`#@````I"`0`/````&4(!``T````I0@$`$0```#="`0`,````
M24(!``\```!60@$`(````&9"`0`-````AT(!``8```"50@$`5P```)Q"`0`0
M````]$(!`#T````%0P$`"@```$-#`0`(````3D,!``\```!70P$`#````&=#
M`0`/````=$,!``X```"$0P$`#@```)-#`0`(````HD,!`!````"K0P$`!```
M`+Q#`0`%````P4,!``\```#'0P$`#P```-=#`0`/````YT,!`"P```#W0P$`
M"P```"1$`0`>````,$0!`!8```!/1`$`%@```&9$`0`&````?40!`!4```"$
M1`$`%P```)I$`0`2````LD0!`!<```#%1`$`+````-U$`0`4````"D4!`!D`
M```?10$`&P```#E%`0`$````544!`$D```!:10$`20```*1%`0!)````[D4!
M`"P````X1@$`%0```&5&`0`/````>T8!``H```"+1@$`%0```)9&`0`*````
MK$8!``P```"W1@$`,P```,1&`0`1````^$8!``\````*1P$`.````!I'`0`(
M````4T<!``@```!<1P$`"````&5'`0`1````;D<!`!,```"`1P$`'````)1'
M`0`(````L4<!`%H```"Z1P$`1P```!5(`0!.````74@!`#8```"L2`$`6@``
M`.-(`0`R````/DD!`%P```!Q20$`0@```,Y)`0!+````$4H!`"\```!=2@$`
M$P```(U*`0`@````H4H!``D```#"2@$`4````,Q*`0`^````'4L!`"X```!<
M2P$`/````(M+`0`*````R$L!``P```#32P$`/````.!+`0`X````'4P!`$T`
M``!63`$`"P```*1,`0`J````L$P!`$L```#;3`$`*````"=-`0`5````4$T!
M`!H```!F30$`&@```(%-`0`2````G$T!`'@```"O30$`F````"A.`0#@````
MP4X!`!T```"B3P$`#@```,!/`0`/````ST\!`!H```#?3P$`&P```/I/`0`5
M````%E`!``P````L4`$`'0```#E0`0`E````5U`!`"L```!]4`$`*````*E0
M`0`U````TE`!`#4````(40$`W0```#Y1`0`;````'%(!`!4````X4@$`#@``
M`$Y2`0`.````75(!`#````!L4@$`&P```)U2`0`1````N5(!``\```#+4@$`
M%@```-M2`0`H````\E(!`$0````;4P$`1````&!3`0!`````I5,!`$````#F
M4P$`00```"=4`0!!````:50!`"````"K5`$`9@```,Q4`0`6````,U4!`!8`
M``!*50$`%@```&%5`0`6````>%4!`!$```"/50$`'@```*%5`0`>````P%4!
M`!4```#?50$`%````/55`0!1````"E8!`!P```!<5@$`'````'E6`0!*````
MEE8!`!D```#A5@$`#P```/M6`0`:````"U<!`!(````F5P$`+````#E7`0`:
M````9E<!`"L```"!5P$`(````*U7`0`F````SE<!`"````#U5P$`0````!98
M`0`Z````5U@!`!X```"26`$`&P```+%8`0`C````S5@!`#T```#Q6`$`)```
M`"]9`0`E````5%D!``P```!Z60$`'P```(=9`0`(````IUD!`!4```"P60$`
M#0```,99`0`,````U%D!`!8```#A60$`%````/A9`0`*````#5H!``@````8
M6@$`&````"%:`0`8````.EH!`!H```!36@$`%@```&Y:`0`;````A5H!`",`
M``"A6@$`/0```,5:`0`3`````UL!`!H````76P$`#P```#);`0`/````0EL!
M`!4```!26P$`2P```&A;`0`0````M%L!``\```#%6P$`#@```-5;`0`(````
MY%L!`!$```#M6P$`(P```/];`0`-````(UP!`!X````Q7`$`%P```%!<`0`@
M````:%P!`!T```")7`$`"````*=<`0`.````L%P!``0```"_7`$`#P```,1<
M`0`1````U%P!`!8```#F7`$`%0```/U<`0`F````$UT!`"8````Z70$`(P``
M`&%=`0`H````A5T!``T```"N70$`&P```+Q=`0`*````V%T!`!D```#C70$`
M@````/U=`0`1````?EX!`!4```"07@$`0@```*9>`0`>````Z5X!`"0````(
M7P$`%0```"U?`0`5````0U\!`!<```!97P$`#0```'%?`0`3````?U\!`!,`
M``"37P$`%P```*=?`0`>````OU\!`#0```#>7P$`#````!-@`0`1````(&`!
M`!,````R8`$`&````$9@`0`,````7V`!``@```!L8`$`"````'5@`0`(````
M?F`!`!,```"'8`$`=````)M@`0`?````$&$!``\````P80$`!@```$!A`0`*
M````1V$!`!X```!280$`'````'%A`0`@````CF$!``(```"O80$`$0```+)A
M`0!`````Q&$!``,````%8@$`"`````EB`0`=````$F(!`!4````P8@$`&```
M`$9B`0"#````7V(!``D```#C8@$`#````.UB`0`(````^F(!``H````#8P$`
M3@````YC`0!<````76,!`!X```"Z8P$`(@```-EC`0`T````_&,!`#,````Q
M9`$`,0```&5D`0`3````EV0!``0```"K9`$`"@```+!D`0`*````NV0!`!8`
M``#&9`$`%P```-UD`0`*````]60!`(8`````90$`&@```(=E`0`1````HF4!
M`!8```"T90$`*P```,ME`0!Q````]V4!``8```!I9@$`$P```'!F`0`&````
MA&8!``L```"+9@$`+P```)=F`0`M````QV8!``@```#U9@$`#````/YF`0"O
M````"V<!`"(```"[9P$`(0```-YG`0`,`````&@!`!$````-:`$`$P```!]H
M`0`@````,V@!``X```!4:`$`$````&-H`0`,````=&@!`!,```"!:`$`$0``
M`)5H`0`3````IV@!`!<```"[:`$`'````--H`0`:````\&@!`!H````+:0$`
M&@```"9I`0`<````06D!`!H```!>:0$`+````'EI`0`5````IFD!``T```"\
M:0$`'````,II`0`/````YVD!`!X```#W:0$`(0```!9J`0`&````.&H!`!4`
M```_:@$`&@```%5J`0`6````<&H!`!0```"':@$`%P```)QJ`0`>````M&H!
M`!H```#3:@$`"````.YJ`0`(````]VH!`!$`````:P$`"P```!)K`0`M````
M'FL!`!8```!,:P$`+0```&-K`0`R````D6L!`!X```#$:P$`"@```.-K`0`:
M````[FL!``@````);`$`'````!)L`0`$````+VP!``0````T;`$`:0```#EL
M`0!/````HVP!`"4```#S;`$`1@```!EM`0!9````8&T!`!,```"Z;0$`6@``
M`,YM`0!"````*6X!`$<```!L;@$`1P```+1N`0!,````_&X!`"D```!);P$`
M(P```'-O`0`N````EV\!`"8```#&;P$`)0```.UO`0`E````$W`!`!\````Y
M<`$`+0```%EP`0`D````AW`!`$X```"L<`$`3@```/MP`0!2````2G$!`%(`
M``"=<0$`4````/!Q`0!-````07(!`$(```"/<@$`$P```-)R`0`S````YG(!
M``\````:<P$`.0```"IS`0!$````9',!`$4```"I<P$`$P```.]S`0!R````
M`W0!`'D```!V=`$`$0```/!T`0`T`````G4!`!0````W=0$`&````$QU`0`+
M````974!``L```!Q=0$`%@```'UU`0`>````E'4!`!,```"S=0$`&0```,=U
M`0`2````X74!`#P```#T=0$`#````#%V`0`&````/G8!`!P```!%=@$`%P``
M`&)V`0`5````>G8!`%(```"0=@$`"@```.-V`0`&````[G8!`!P```#U=@$`
M#````!)W`0`*````'W<!`!P````J=P$`#P```$=W`0!1````5W<!`!@```"I
M=P$`+0```,)W`0!C````\'<!`"````!4>`$`0@```'5X`0">````N'@!`"L`
M``!7>0$`/0```(-Y`0`3````P7D!`!8```#5>0$`%@```.QY`0`8`````WH!
M``P````<>@$`%P```"EZ`0`2````07H!`#$```!4>@$`(````(9Z`0`(````
MIWH!`!<```"P>@$`&@```,AZ`0`X````XWH!`"(````<>P$`)@```#][`0`8
M````9GL!`#8```!_>P$`"````+9[`0`.````OWL!`"0```#.>P$`&0```/-[
M`0`5````#7P!`!<````C?`$`"````#M\`0`K````1'P!``X```!P?`$`%P``
M`']\`0`3````EWP!``X```"K?`$`.````+I\`0`B````\WP!`$(````6?0$`
M'@```%E]`0`/````>'T!`!````"(?0$`,P```)E]`0`.````S7T!`",```#<
M?0$`"`````!^`0`B````"7X!``@````L?@$`"````#5^`0`F````/GX!`$L`
M``!E?@$`"````+%^`0`<````NGX!``P```#7?@$`&P```.1^`0`7`````'\!
M`!D````8?P$`"````#)_`0`*````.W\!``X```!&?P$`-0```%5_`0!=````
MBW\!`&L```#I?P$`.````%6``0!!````CH`!`#4```#0@`$`=`````:!`0`U
M````>X$!`$,```"Q@0$`3@```/6!`0"'````1((!`#L```#,@@$`#@````B#
M`0`(````%X,!`"L````@@P$`*0```$R#`0`;````=H,!`"P```"2@P$`.0``
M`+^#`0`_````^8,!``@````YA`$`'P```$*$`0`*````8H0!`!,```!MA`$`
M/0```(&$`0`<````OX0!``T```#<A`$`$0```.J$`0`(````_(0!`!,````%
MA0$`$0```!F%`0`1````*X4!`!,````]A0$`)````%&%`0!-````=H4!``\`
M``#$A0$`"@```-2%`0`D````WX4!`!<````$A@$`"@```!R&`0`;````)X8!
M`!L```!#A@$`&````%^&`0`4````>(8!`!8```"-A@$`%0```*2&`0`(````
MNH8!``P```##A@$`'````-"&`0!*````[88!`'8````XAP$`+0```*^'`0`Z
M````W8<!`",````8B`$`(P```#R(`0`.````8(@!`"(```!OB`$``P```)*(
M`0`&````EH@!``\```"=B`$`#P```*V(`0`8````O8@!``T```#6B`$`40``
M`.2(`0`&````-HD!`"`````]B0$`$0```%Z)`0`5````<(D!`%<```"&B0$`
M(````-Z)`0`0````_XD!`!X````0B@$`,P```"^*`0`*````8XH!`",```!N
MB@$`+@```)**`0`0````P8H!`"4```#2B@$`*P```/B*`0`,````)(L!``@`
M```QBP$`$P```#J+`0`5````3HL!`!@```!DBP$`!@```'V+`0`8````A(L!
M`!(```"=BP$`%@```+"+`0`5````QXL!`!4```#=BP$`"P```/.+`0`*````
M_XL!`%(````*C`$`2P```%V,`0!)````J8P!``@```#SC`$`*P```/R,`0`Y
M````*(T!``X```!BC0$`#@```'&-`0`#````@(T!`!````"$C0$`#@```)6-
M`0`(````I(T!`"````"MC0$`#P```,Z-`0`2````WHT!`!@```#QC0$`@0``
M``J.`0`?````C(X!``8```"LC@$`#P```+..`0`0````PXX!`"````#4C@$`
M'````/6.`0`W````$H\!`",```!*CP$`'@```&Z/`0`Y````C8\!`!,```#'
MCP$`-````-N/`0`6````$)`!`!X````GD`$`\````$:0`0`E````-Y$!`"$`
M``!=D0$`1P```'^1`0`E````QY$!`!\```#MD0$`)0````V2`0`A````,Y(!
M`"T```!5D@$`%0```(.2`0`.````F9(!``H```"HD@$`#@```+.2`0`7````
MPI(!`"0```#:D@$`"@```/^2`0"2````"I,!`)$```"=DP$`4@```"^4`0"`
M````@I0!`!H````#E0$`4P```!Z5`0`^````<I4!``@```"QE0$`%0```+J5
M`0!D````T)4!``H````UE@$`:P```$"6`0!7````K)8!`#L````$EP$`(@``
M`$"7`0!4````8Y<!`$,```"XEP$`/0```/R7`0`O````.I@!`#8```!JF`$`
M,0```*&8`0`5````TY@!``@```#IF`$`&P```/*8`0`;````#ID!``T````J
MF0$`.0```#B9`0`-````<ID!``H```"`F0$`&P```(N9`0`,````IYD!`"``
M``"TF0$`!@```-69`0`(````W)D!``@```#EF0$`&P```.Z9`0`;````"IH!
M``\````FF@$`'0```#::`0`:````5)H!`"4```!OF@$`%0```)6:`0`;````
MJYH!`!@```#'F@$`+0```.":`0`V````#IL!`!4```!%FP$`"@```%N;`0`K
M````9IL!``X```"2FP$`(P```*&;`0`3````Q9L!`!,```#9FP$`$0```.V;
M`0`*````_YL!`!(````*G`$`"@```!V<`0`/````*)P!`!H````XG`$`#0``
M`%.<`0`<````89P!`!4```!^G`$`$P```)2<`0`.````J)P!``P```"WG`$`
M"@```,2<`0`*````SYP!``X```#:G`$`$````.F<`0`F````^IP!`)`````A
MG0$`00```+*=`0!1````])T!`"@```!&G@$`"@```&^>`0`3````>IX!`!,`
M``".G@$`#````**>`0`(````KYX!`!$```"XG@$`"@```,J>`0`(````U9X!
M``H```#>G@$`$````.F>`0`0````^IX!`!<````+GP$`+````".?`0`(````
M4)\!``@```!9GP$`$````&*?`0`(````<Y\!`!<```!\GP$`%P```)2?`0`'
M````K)\!``H```"TGP$`$P```+^?`0`<````TY\!`!,```#PGP$`%0````2@
M`0`9````&J`!``8````TH`$`#0```#N@`0`/````2:`!`!$```!9H`$`#@``
M`&N@`0`.````>J`!`$D```")H`$`)P```-.@`0`]````^Z`!`#8````YH0$`
MGP```'"A`0`:````$*(!`&4````KH@$`5````)&B`0!O````YJ(!`&$```!6
MHP$`,````+BC`0!D````Z:,!`#H```!.I`$`/````(FD`0!)````QJ0!`#0`
M```0I0$`#@$``$6E`0`D````5*8!`!0```!YI@$`O````(ZF`0!M````2Z<!
M`#@```"YIP$`?````/*G`0"S````;Z@!`"`````CJ0$`&````$2I`0`S````
M7:D!`"8```"1J0$`)@```+BI`0!%````WZD!`"P````EJ@$`,````%*J`0`F
M````@ZH!`!@```"JJ@$`30```,.J`0!`````$:L!`#$```!2JP$`,@```(2K
M`0!2````MZL!`,H````*K`$`4@```-6L`0"+````**T!`((```"TK0$`2```
M`#>N`0!1````@*X!`%4```#2K@$`B````"BO`0"4````L:\!`'8```!&L`$`
M>````+VP`0!4````-K$!`$8```"+L0$`2````-*Q`0!*````&[(!`"@```!F
ML@$`10```(^R`0!,````U;(!`$X````BLP$`B````'&S`0`X````^K,!`!D`
M```SM`$`CP```$VT`0`O````W;0!`%$````-M0$`/P```%^U`0`J````G[4!
M`%D```#*M0$`!@```"2V`0`,````*[8!``@````XM@$`%0```$&V`0`1````
M5[8!`!<```!IM@$`"@```(&V`0`C````C+8!``0```"PM@$`CP```+6V`0`*
M````1;<!``@```!0MP$`"````%FW`0`@````8K<!`!$```"#MP$`'0```)6W
M`0`-````L[<!`!0```#!MP$`*P```-:W`0`0`````K@!``,````3N`$`!```
M`!>X`0`R````'+@!`&H```!/N`$`4````+JX`0!6````"[D!`"L```!BN0$`
M-````(ZY`0`H````P[D!`$8```#LN0$`/````#.Z`0`W````<+H!`#L```"H
MN@$`0````.2Z`0`N````);L!`#H```!4NP$`+@```(^[`0`X````OKL!`%``
M``#WNP$`,P```$B\`0`X````?+P!`#P```"UO`$`-P```/*\`0!,````*KT!
M`#P```!WO0$`1@```+2]`0`U````^[T!`#L````QO@$`/````&V^`0!)````
MJKX!`#<```#TO@$`.@```"R_`0`R````9[\!`&P```":OP$`/`````?``0!!
M````1,`!`$4```"&P`$`1@```,S``0!`````$\$!`#(```!4P0$`/0```(?!
M`0`W````Q<$!`#(```#]P0$`.P```##"`0`3````;,(!`"$```"`P@$`*P``
M`*+"`0!&````SL(!`#0````5PP$`#P```$K#`0`/````6L,!``P```!JPP$`
M&0```'?#`0`X````D<,!`",```#*PP$`"P```.[#`0"3`0``^L,!`!H```".
MQ0$`(````*G%`0`2````RL4!`!4```#=Q0$`'0```//%`0`<````$<8!`#0`
M```NQ@$`$P```&/&`0!S````=\8!`!P```#KQ@$`(`````C'`0`<````*<<!
M`!<```!&QP$`9````%['`0!`````P\<!`!D````$R`$`'@```![(`0`8````
M/<@!`$P```!6R`$`(P```*/(`0`1````Q\@!`!(```#9R`$`$P```.S(`0`<
M`````,D!`"`````=R0$`#@```#[)`0!$````3<D!``P```"2R0$`*````)_)
M`0!!````R,D!``P````*R@$`)P```!?*`0`,````/\H!``@```!,R@$`$P``
M`%7*`0`3````:<H!`"(```!]R@$`"P```*#*`0`1````K,H!`!,```"^R@$`
M"P```-+*`0`F````WLH!`!H````%RP$`&0```"#+`0`;````.LL!`$\```!6
MRP$`#````*;+`0`0````L\L!`!@```#$RP$`/0```-W+`0`+````&\P!``0`
M```GS`$`#0```"S,`0`*````.LP!`!$```!%S`$`&0```%?,`0`6````<<P!
M`!0```"(S`$`%0```)W,`0!:````L\P!`",````.S0$`*````#+-`0`/````
M6\T!`&P```!KS0$`!@```-C-`0`<````W\T!`%T```#\S0$`$P```%K.`0`1
M````;LX!``D```"`S@$`!````(K.`0`'````C\X!`!D```"7S@$`+P```+'.
M`0`'````X<X!``@```#IS@$`!@```/+.`0`&````^<X!`!8`````SP$`%@``
M`!?/`0`%````+L\!``0````TSP$`#````#G/`0`&````1L\!`!4```!-SP$`
M<@```&//`0`G````UL\!`&(```#^SP$`4P```&'0`0",````M=`!`!@```!"
MT0$`L0```%O1`0!)````#=(!`'H```!7T@$`4P```-+2`0!*````)M,!`&@`
M``!QTP$`4@```-K3`0!3````+=0!`%$```"!U`$`5P```-/4`0!>````*]4!
M`%$```"*U0$`/P```-S5`0!6````'-8!`"0```!SU@$`(````)C6`0`5````
MN=8!`+T```#/U@$`#0```(W7`0#:````F]<!`+D```!VV`$`3````##9`0`W
M````?=D!`"````"UV0$`%P```-;9`0`H````[MD!`#4````7V@$`7````$W:
M`0`[````JMH!`#0```#FV@$`H0```!O;`0`N````O=L!`"T```#LVP$`,0``
M`!K<`0`6````3-P!`"D```!CW`$`,@```(W<`0`3````P-P!``X```#4W`$`
M`P```./<`0`1````Y]P!``T```#YW`$`%`````?=`0`,````'-T!`!P````I
MW0$`"````$;=`0`(````3]T!`!@```!8W0$`$0```''=`0`,````@]T!`!0`
M``"0W0$`&@```*7=`0`:````P-T!``X```#;W0$`&````.K=`0`*`````]X!
M``@````.W@$`(0```!?>`0`,````.=X!`!<```!&W@$`!@```%[>`0`"````
M9=X!``H```!HW@$`"````'/>`0`)````?-X!``8```"&W@$`'````(W>`0`L
M````JMX!``<```#7W@$`"````-_>`0`.````Z-X!``@```#WW@$`&0````#?
M`0`/````&M\!`!4````JWP$`0P```$#?`0`1````A-\!``L```"6WP$`%P``
M`*+?`0`%````NM\!``(```#`WP$`"P```,/?`0`!````+@```#X```#<!```
MP@````````#0!````````.T"```````````````````K`0```````$4%``",
M!0``XP(``&0%```-````L````$@!``````````````````"9`0``#P0``*`$
M````````W00``!<%````````F0(``'D```#D`0```````)$#````````B00`
M``````"B!```PP,``/($````````-0(``.H$``#3`@````````````!F`0``
M&@,``!`#````````^`0``%L#```'`0``LP$``-,#````````````````````
M````10,``!0"``"=!0``<`0``'\#``![`P```````(4"``````````````X`
M``"8`@```````(H#````````?@$``/T$```O`@```````!H"``!\!```GP4`
M`)($``"I`0``NP,``+,```"S`P``[@$```````!]`P```````#8```"8!```
MK0$``.H"```Z`P````````````"F!0``5P(``"<%``#[````C`,``)(`````
M````L`0``.<"``#8`@```````)P"``#?`````````'@%``!7`P``.`,`````
M```X`@``"@```'P#```5!0````,``/<#````````9P$``#P!``!%!```/04`
M`)\!``!^`````````!\```!V````OP$`````````````&0,````````O`P``
MT`````````#6`P``B`$``#4#```#`0``^`$``*,!````````]00``/$"``"N
M!```P````!L```!(`P```````,`#``":`@``_`0```````"N````80```&D!
M````````T@,``%<%```?!0```````$0"``#L```````````````D!```````
M````````````R@(``%@$```5`````````#,```"_`@``DP```%0#``#K`P``
MF04``#$$``!X`@``?@(``%T```"X!```H```````````````!P0```````#T
M`@```````/,#``!?`@``6`,````````,`0``6P$``'(#```)`0```````(8"
M``````````````````#\`@``BP,```````#:!```2P$``-H!````````=@$`
M`*\$```V`0``*`,````````Y`P``K@$``.<!``"E`@``00$``/,!```4!0``
M:04``'H!```Q``````````X%``#-!```>0$``(@```"W````@@(``!@$````
M````D00``&4#```````````````````G````W@0``&8%``"!!```%P,``,`!
M``#_`0```````!\#```D````,@$`````````````G@$```L```#T`P``````
M`+0#`````````````'(%`````````````($"```@`0````````,```#O`0``
MO@$``(<```#I!```Y@```!P"````````EP4``,@$``"F`0``3P,```````!5
M!```(@,``-<````M!0``M`````````"X`0``X@,``+\#```5`0``-@,```$#
M``#Q`0``%P```*<$``##`0``60```"H`````````#04``"8$```6!0``````
M`.`$```K`@```````+4"``"&!0``60,``$T%``"0!0``````````````````
M<`$```8"``!5`@```````(D#`````````````+P$```1!0``D`$``$D!``#X
M`@``*0`````````/`P``<@(```````#G!```B0```-@!``#Q````Q00``(\!
M``!G`@``G00````````_!0``C0```',!`````````````(4$``!K`P``I0,`
M```````Y````;P$``,<$``#6`````````'0`````````/@4``%@!````````
M`````",%```H!0``&04``'P!```,`@``)`(``)T```!X`````````*$```#I
M````X0(``'H$```B!```H@$``(H!````````@@```(\%``"^````"0(``(8$
M``````````````H$``#<`@``Y@$``*,```![!```904``#P````D`0``,@4`
M`!X#``!P```````````````D`P``B`(``%(%```4`P``,P0``+@#``!3!0``
M'`4`````````````9`,``%8%``!+!```L@$``!$`````````CP0``)8$``!/
M`@``````````````````;00``),"``#[!```^P$``)X"``!Z!0``]```````
M``"9````V0,`````````````Y@,``(H$````````X@(``-X!``!.`P``C0$`
M````````````JP0```````!;!0```````*\!``````````````\"``!7!```
MQ@```/T```"A!0``I04```````#7`P``@P```&X"```Z`0``[P,``$D%``!>
M`P``D@4``(L%``"S!```"0,``!,"``````````````````#(`@``T0```#T!
M``!Y`P``V0$``)0%`````````````+T!`````````````'4#``"$````X0$`
M`)8```!.````D`(``&\#``"7````IP(``#T#````````ZP```&<`````````
M+`$``*T#````````@@0``%4`````````MP,``$@$``"!!0``&@````````!H
M`0``A@,``(0%`````````````*H!``#D`@``]@``````````````````````
M``"(`P``%@(``*0!``#N`P``R0(``/("```!!```50$``$X!````````R@0`
M`*@`````````OP0``,X"``"6`P``M`0``&(#``!*!```'04````````?!```
MY0,``#X"````````<00``%D"````````8`0``-\"```X!0``I`4````````'
M`@``4@$``%`$````````$P```,8#``"P`@``[`(````````4`0``-P```-P`
M``"C!0```````.L!```.`P``*P0``````````````````/X!``!2`@``=`(`
M`+L!````````=0(```````!3`0``704``(X!``"J````?P```,H!```9!```
MD0$``+4```"$`@``7`,`````````````2P,``,D$``#C`0``#0(``-X"```.
M!````````-D$```&!```:`(``/D!``#A!`````````P`````````,@(``.T!
M``!<`@``T`,``*@"``!?!0``ZP(``,0"```=`0``&`$``-,!``#R`P``3@4`
M`)(!````````HP0``!L$``"X````8@$```@%```*`@````(``!$!````````
M``````````#H`P``#`0``$8#``#J````$@4``"`"```A!0``O@(``&H````M
M!````````"H$``#2!```F`4````````L````6@$``*$!``"F`P``X`$``*\"
M``";!0``.P(``"L%``!*!0``)P0``!P!``"5`P```````+H```"O`P``````
M`)("```W!0``"`0`````````````"`$````````>````?@,``)@```!%````
MS0$``/,```#Z!```CP```(D"``":`P```````$D#``"8`0``BP0``/P!```/
M````-P$``#X#``#!`@``.P`````%``"Q`0``P@$``"4%``!T!```O`,``$P"
M```3!0``C0(``%$"`````````````/P#```"`P``VP(``+H$````````EP$`
M`&L%````````5`(````````'`P``400``'D%````````F0,``$<```!=`@``
M`````#$%``#)``````````````!.!```GP(``#P%``"'!```"04``,,`````
M````3P```(,#``#%`P``'00``.D"``!:`P```````'P```#C!```/P```"X"
M````````,0,``"$```"#!```E@(``+4!````````%P(````````[`0``````
M`&,"```-`P``<P,``)T#```F````N@$``"D"``#J`0``&`(```````"K`0``
M`````*P"``#'`P``W`,``*(#````````?0$``-X`````````%0(``+4$``!!
M!0````````````!<`0``:`4``!\"```(`@``-`,``/H"````````@0,``,T"
M``!'!````````-H"``"1`````````,P#``#Y`P``80$````````:`0``````
M`)0$````````Y0```!,#```6`0``0@,``%D!``"I````EP0``!8#```]`@``
M<@0```````"L`P``9@```!<!``!6`P``:`,````````>!0``LP(``%T#```B
M`@```````$P#```M````D````,0#``#C`P``T00``'0!``!T`P``;@``````
M```B````L@```.8$``";`P```````%8"``#-`P``[`$```T$``!^!0``U```
M``````"'`0``FP$``$T````7!```CP,``%@"````````(00``&,```#5`P``
M@`````````#^`P``<P4``"4!```5`P``3P$``%($````````X0```/0$```X
M!```````````````````_P,``#4!``!@`@```````,8"``#H!```:@0`````
M````````,`$``)$"``",````(````!(!``"-`P```````$<#``#Q!```/00`
M`)T!```N!0````````````#_````<P0``.@````Q`0``@@4``&`#``!K````
M?04```````#:`P``)0,``&($```N`P``$@0``'L%``"#`@``A0$``-T!``"0
M`P```````/,$````````[0```),!```T`0``K0``````````````9P0``$@`
M```%!0````````````"(!````````&,#````````````````````````7@4`
M`%@%`````````````(0!````````U0(```````#7`@``S````*<#``#.`P``
M`````/H#``!:`@```````#H%````````G`0``+D"``#6`@``4`4````````3
M!```0@````,#````````$00``/`#``#>`P``!0(```````"L`0``V````.\$
M``!F!```C@0```````#/````5@```"@$``"M`@``#`,``#@```#2`@``$`$`
M`.L$````````N0$`````````````I@```*H$`````````@0``+X$```?`0``
M^0```-(````T!0``RP```.P#``"V`0```````*`%```*!0``J@(```````!M
M`P```````*T$````````PP(``%$```!B`````````,8$```+!0``9````'X$
M``#,!````````)8!```&`0``X@0``.$#``#+`@``?00``%,"``"E`0``````
M`)$%```A`0``;P```'`"``#Y`@``!````*$"``"W!```!0$```````#1`0``
M%00``%`````8!0``IP$````````[!```F00```````!Z`@```````%X"``"O
M````00,````````F`P```@(```````"D`P``'@(```````#L!```;`$`````
M``````````````````"0!```10(``.@!``!<!0````````````"7`@``BP$`
M`)H%``"/`@```````,L#``!D`@```````+("`````````````)0"``!;!```
M`````+$"`````0``\`(``*(`````````U@$``',"````````1`4``&\%``!M
M````2P4``%H```"\`0``9P,``/X$``"``0```````%P```"L!```Q@$``!(`
M```%!```N@,``'T"```C````.P,```````"``@``B0$```````#8`P``P`(`
M`/\$`````````````&T!``#]`0``"0```"`#```````````````````"````
M&@4``$P```!$!```;P(```````!4!```E04```````!(!0``-P0``$P!``!"
M!0``;@4``+X#``!A`P``@P4`````````````&@0``-4```#E`@``O`````\!
M```K````%@````$%``!3````,P$``-0#``!J`P``,````,L$``#I`0``B@``
M`&8#```D!0````````````!J!0``U`(``$8%``!3!```>`,``.T#``"5````
M`````!$#``!_`@``.00```L"```G`@``?P0```````#V`P``.P4```````#/
M`0``-00``&,$`````````````&,%``"%````NP0```T!``!U!0``Z`(``%T$
M``!<!````````%\`````````=P```&`!```N!```900``.D#```H`0``````
M`*0"``#X`P````````````#Y!```=P$``&4```#9`@````````````#)`P``
M``````````"[`````````'$%``!Q`P``P@(```````!L`P``U@0``-P!````
M````+0,``"(!```#!```Q`$``'$`````````6@4``$T!``"6!0``G@0``&X$
M``#2`0``6P```",$`````````````!T```"Y`P``S@0``,H```#?`0``U0$`
M````````````NP(`````````````@0````````#4!```DP,``'4```#4`0``
MG````'`%``#(````J0(``"P"``"&````X````(P$``#%````WP0``/````":
M````K@,``.X$``#.`0``I`0``"P%```J`@``!@```%0!```$`P``[@(``'P%
M``!J`@``Q0(```````!:!````````"8%``#X`````````-<!``"Q````>`0`
M`&<%``!``P``P0,``#\$```C`@``(0,```````!M!0``Y`````L#``".````
MH`(``"8!``!4!0``-P,``/0!``!)`````````&4"``!Y!````````#0$````
M````+`,```````!Z`P``-04```````!?`0``;````.8"````````B04``$8"
M````````A@$``#,%````````J0,``"\!```I!0``C`(``,4!``#/`@``/@$`
M`,P"``".`@``=0$``.`#````````"@,``!`$````````H00`````````````
M200```````!(`@``&````%`"``#O````I@(`````````````2@(``!`%````
M`````@4``#P"````````=@(``$<"`````````````````````````````$(!
M```P!```O0(``&X#```R````"`````````!-`P``"P$``$\$``#B````````
M`'$!```A`@``)@(``/4```#\````1````+($``!2`````````,0```#'`@``
M"`,``+4#``"H`0``>P(```````````````````````"?````$0(``&@$```L
M!```+P```#($``!`!0``X@$```0"````````$@(``*,#``!]````!`0``",!
M``````````````<%```9`@```````+T```#V!```(`4```````!1!0``90$`
M``````#9````I````,`$``"T`0``G@4``*L#``#:````>0(```````";!```
MB`4``$$$````````J@,``&D$````````K@(```````#1`@``C00``)L```"V
M!```B@(```````````````````0%``!L!````````$("`````````````$L"
M``#[`P``BP(```,"``#W`0``M@,``%(#``"4`P``G@```%`#``!\`@``@`0`
M````````````&P,````````.`@````````````"$`P``QP```-,`````````
M`````#,"`````````````"H%``"*!0``=P(``#P$````````"@$``!`"````
M````]0,``'@!``!>`0``;0(``"\$```2`P````````````"7`P``[00`````
M``!D!```P00``'L```#P!```!@4````````B!0``'`0``$8$````````````
M`*8$``#!`0```````!X!``!>!```O00``#$"``!>````8@(``-@$``"@`P``
MI0````````!!`@```````$P$``!7`0``_0(``&`%``#P`0```````),$````
M`````````$,#``!O!`````````````#O`@``VP$```````#;````\P(``#0`
M``"Y````A0,``%\$``#+`0``/P(``&D"``!-`@``-`(``/(```"<`P``6P(`
M`-L#``"Z`@````0``+T#``"!`0```````#\#``!_!0``4`$``"\%``!-!```
MTP0``)X#```$`0```````,T````Z````GP,``&L"```I`0``N00``"`$``!`
M!````````+$$````````]P```$P%````````=P,``+P"```^!```<`,``#@!
M```"`0```````#`%```<````2@`````````E`@``0P$``"X!```K`P``0P(`
M`)\$``"G!0``E0$``-<$````````VP0``,$`````````````````````````
M(P,```````!#!0``0@0``%4%````````_0,``!@#````````$P$`````````
M```````````````H`````````.0#````````E00``'<$``""`P``)P$``!T"
M``"+````,`,``(<%``````````````````!I`P``C04``#D%``"X`@``````
M`+<!`````````````+8`````````804``,,$``!L`@``;`4```````!K!```
M'@0```````````````````````!`````D@,```````#J`P```````&L!````
M````Y0$``!8$```V`@```````%D$```%`P``E0(``#,#```]````````````
M```P`@```````!L!```+!```XP```*@$````````7P,``$D"``"8`P``.0$`
M`!D```"<`0``2@$```<```!R`0``_@```$X"```!`0``,@,``#4```!/!0``
M*`(``"H!``".!0``'0,`````````````.0(```````"3!0``4P,``'$"````
M````1`,``%0`````````9`$```````#W`@``9@(``(P!``#'`0``=P4``%<`
M``````````````4``````````````$8!``"4`0``:@$`````````````````
M`%8!``!1`0``@`,```````!V`P````````````":!```JP```!0$````````
MI00```````"L````604``$H#``!T!0```````&@```````````````````"'
M`P``]0$``*@#``":`0``8P$``#H$```0````<@```$8`````````T0,``,@#
M```.`0``;@$``#P#``"_````W0```'4$````````A`0``/8!```W`@``E```
M`"T!``!Z`````````*<```"I!````````/L"````````HP(```\%``!V!```
M+0(``!L%``"`!0``1`$``*$#``#D!```/P$``+(#``#0`0``M@(``,@!````
M````A04``#H"``!1`P```````!D!``!+````8@4``&D``````````````.`"
M``!8````50,```````#?`P``_P(``#8$``"P`P``*00``$<!``#^`@``?P$`
M``8#``#N````U00``-T#```!`@``M`(``$,$``";`@``H`$`````````````
M0P```-T"``"=`@``1P4``"D#``!%`0``"00``$`!````````]0(``%8$``#)
M`0``G`4``"H#```<`P``8````,\$````````00```+$#``".`P``80(``',`
M```;`@```````,\#``"'`@``@@$``+<"````````>P$```,%``#G`P``````
M``````!``@``L`$``#8%````````\@$``/<$````````\0,``"<#````````
M`````/8"``"#`0```````%T!````````Q`0`````````````^@$``,P!``#G
M`````````,H#``"K`@``P@0``&$$```,!0``%```````````````=@4``*(%
M`````````````-`"````````S@```/H```"B`@````````````#"`P``````
M`.4$```E````)00````@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E<RD`
M("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E<F1A
M>2D`(&%T(``B)7,B('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`
M(B5S(B!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`(B5S
M(B!W87,@;F]T(&-R96%T960Z("5S+@`E+C)F34(@=7-E9"!O9B`E+C)F34(@
M86QL;W=E9"`H)2XR9B4E*0`E9"`E<R!A;F0@)7,`)60@9&%Y<R!U;G1I;"!Y
M;W5R('!A<W-W;W)D(&5X<&ER97,N`"5D+61A>2!F;W)E8V%S=``E<R`M($YO
M=&EC90`E<R!&:6YG97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R
M871I;VYS("T@0V]N9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@
M5&5R;7,@;V8@06=R965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E
M<R`E<P`E<R!I<R!R96%D>2!T;R!P97)F;W)M('1H92!M86EN=&5N86YC92!O
M<&5R871I;VYS(&-H96-K960@8F5L;W<N($-H96-K('1H92!B;W@@9F]R(&%N
M>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R;2!A="!T:&ES('1I
M;64N`"5S(&ES(')E<75I<F5D`"5S(&UI;G5T97,`)7,@;F]T(&9O=6YD+@`E
M<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@0F]O:P`E<R=S($-A;&5N9&%R
M`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T`"5S.B`E<P`L(&=U<W1I;F<@
M`"P@9W5S=&EN9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@
M<V5L96-T("TM`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO
M=7)S`$$@9&%T86)A<V4@8F%C:V5N9"!I<R!R97%U:7)E9"!F;W(@=&AI<R!B
M;&]C:RX`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`02!P=6)L:6,@4$=0
M(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4$=0(&ME>2!I<R!R97%U:7)E9"!T;R!V97)I9GD@82!S:6=N960@;65S
M<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@
M<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N
M`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC
M(%--24U%(&ME>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92X`
M04T@3&EG:'0@4F%I;@!!32!286EN`$%-(%-H;W=E<G,`04T@4VYO=R!3:&]W
M97)S`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B<V)O='1O
M;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T
M;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT
M($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O<F0`06-C;W5N="!F<F]Z96XN
M`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'<F]U<`!!9&0@0VAI;&0@4&5R
M;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'<F]U<`!!9&0@3F5W(%!E<FUI
M<W-I;VX`061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R`B)7,B`$%D9"!A(&YE
M=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R<P!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1I;F<@=7-E<G,@:7,@9&ES86)L960N`$%D9')E<W,`061D<F5S<R!";V]K
M`$%D;6EN:7-T97(@+2!S970@<&5R;6ES<VEO;G,@9F]R(&]T:&5R('5S97)S
M`$%D;6EN:7-T<F%T:6]N`$%D<P!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L
M;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M
M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S
M97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D
M>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@
M4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E<FYA;64`06QT97)N871E(&5M
M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X
M=#H`06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;F]N>6UO=7,@
M4')O>'D`06YS=V5R`$%P<&QI8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P
M;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R
M;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R
M-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@/P!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07-K(&9O<B!C;VYF:7)M
M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E(&]P97)A=&EO;G,_`$%S
M<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES
M=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@
M<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('!E
M<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!S:&%R
M92X`071T<FEB=71E<P!!=6=U<W0`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM
M87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D
M;V5S(&YO="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S
M.B!297%U:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P
M.B!297%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!0
M2%`@=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!2
M97%U:7)E9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@
M4F5Q=6ER960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z
M(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P
M.B!5;F%B;&4@=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R
M=F5R('-A:60Z(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E
M<P!!=71H7VQD87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC
M86PZ(%)E<75I<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S
M;6)A=71H.B!297%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`$%U=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N
M("5S`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N
M`$%U=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=F%I;&%B
M;&4@9FEE;&1S.@!"86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%D(&ME
M<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA;64N`$)A;'1I
M8R`H25-/+3@X-3DM,3,I`$)A<V5L:6YE`$)L;V-K("(E<R(@;V8@87!P;&EC
M871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I;F=S`$)L;V-K(%1Y
M<&4`0F]L9`!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z`$)O
M<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES=`!#35,`0U)#`$-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD
M87(`0V%L;0!#86X@;F]T(')E<V5T('!A<W-W;W)D(&%U=&]M871I8V%L;'DL
M(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#86X@;F]T('=R:71E('1O
M(&9I;&4@(B5S(@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#
M86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N8V5L`$-A;F-E;"!0<F]B;&5M(%)E
M<&]R=`!#86YN;W0@9&5L971E(&9I;&4@(B5S(BX`0V%N;F]T(&9I;F0@82!T
M96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN;W0@<')O8V5E9"!W:71H;W5T("=T
M87)G971&:6QE)R!P87)A;65T97(N`$-A;FYO="!R96UO=F4@9&ER96-T;W)Y
M("(E<R(N`$-A;FYO="!R96UO=F4L("5D(&-H:6QD<F5N(&5X:7-T+@!#86YN
M;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E
M;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"X`0V%N;F]T(')O
M=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D(&YU;6)E<BX`0V%P=&EO;@!#87)R
M:65R`$-A=&5G;W)I97,@86YD($QA8F5L<P!#96QL(%!H;VYE`$-E;&P@4')O
M<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P
M86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`
M0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A=&4@1&5T
M86EL<P!#97)T:69I8V%T92!0;VQI8VEE<P!#:&%N9V4`0VAA;F=E(%EO=7(@
M4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@<&5O
M<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E;6%I
M;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U<'!O<G1E9"!W
M:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#:&EL90!#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@=7-E<FYA;64`0VAO
M;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@;&ES="!S='EL92!T
M>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VQA<W,@9&5F:6YI=&EO;B!O9B`E
M<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@
M;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L:6-K
M('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W
M`$-L;W5D<P!#;&]U9'D`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R
M9&5R<P!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#;VQS
M.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE;&P`
M0V]M;65N=`!#;VUM;VX@3F%M90!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I
M;VX`0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I
M9W5R92`E<P!#;VYF:7)M(%!A<W-W;W)D`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',`0V]N=&%C=',@=V5R92!S
M=6-C97-S9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1I
M;G5E`$-O;VMI90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!01U`@
M96YC<GEP="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`
M0V]U;&0@;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3
M+TU)344@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S
M`$-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8FEN
M9"!T;R!L9&%P('-E<G9E<@!#;W5L9"!N;W0@8VAE8VL@8F%L86YC92X@)7,`
M0V]U;&0@;F]T(&-O;FYE8W0@=&\@;&1A<"!S97)V97(`0V]U;&0@;F]T(&-R
M96%T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E8W)Y<'0@
M4$=0(&1A=&$N`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D971E<FUI;F4@=&AE(')E
M8VEP:65N="=S(&4M;6%I;"!A9&1R97-S+@!#;W5L9"!N;W0@9F5T8V@@8V]M
M<&QE=&4@861D<F5S<R!B;V]K+@!#;W5L9"!N;W0@9F5T8V@@8V]M<&QE=&4@
M9&ES=')I8G5T:6]N(&QI<W0N`$-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE
M=&4@;&ES="!O9B!D:7-T<FEB=71I;VX@;&ES=',N`$-O=6QD(&YO="!O8G1A
M:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO="!O
M<&5N("5S+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L
M92`E<P!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H92!P
M87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L;"!O
M9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O<B!C
M;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T:&5R
M(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E=')I
M979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I8G5T
M:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P
M86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`0V]U
M;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A=&EO;BX`0V]U;&0@;F]T('-A=F4@
M82!B86-K=7`@8V]N9FEG=6%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU
M<"!C;VYF:6=U871I;VXZ("5S`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@
M8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F
M('1H92!O<'1I;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C
M;W!Y(&UA;G5A;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@
M<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C;VYT
M86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E
M<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@<W5R
M92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R>0!#
M;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`
M0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET
M(&-A<F0@;G5M8F5R`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#=7)R
M96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T>6QE
M`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`0W5T
M`$-U="!S96QE8W1I;VX`0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I
M;F1O=W,M,3(U,2D`0WER:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`$1A
M:6QY`$1A=&%4<F5E($)R;W=S97(`1&%T90!$871E(%)E8V5I=F5D`$1A=&4@
M<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$96-I;6%L
M(&YU;6)E<G,`1&5C<F5A<V4@26YD96YT`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4VAE;&P`1&5F:6YI=&EO;G,`
M1&5L971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`
M1&5L971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<&5R
M;6ES<VEO;G,@9F]R("(E<R(`1&5L971E('!E<FUI<W-I;VYS(&9O<B`B)7,B
M(&%N9"!A;GD@<W5B+7!E<FUI<W-I;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S
M96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E
M;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$97-C<FEB92!T
M:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$971A:6QS("AA;'-O(&EN($AO<F1E
M)W,@;&]G9FEL92DZ`$1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N`$1E=F5L;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I
M;G0@9F]R(&QA<W0@:&]U<CH@`$1E=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T
M('1O(')I9VAT`$1I<F5C=&EO;B!R:6=H="!T;R!L969T`$1I<F5C=&]R>0!$
M:7-P;&%Y(#(T+6AO=7(@=&EM97,_`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y
M(&1E=&%I;&5D(&9O<F5C87-T`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES
M<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1O(&YO="!D
M96QE=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``
M1&]E<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)
M9B!Y97,L(&-H96-K('1H:7,@8F]X.@!$;W=N;&]A9`!$;W=N;&]A9"`E<P!$
M;W=N;&]A9"!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!02%`@<V-R:7!T
M+@!$<F]P(&1O=VX@;&ES=`!$<G5G<P!%+4UA:6P`15)2`$5D:70`161I="!"
M;&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I
M;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z
M`$5D:70@<&5R;6ES<VEO;G,@9F]R("(E<R(`161I="!P97)M:7-S:6]N<R!F
M;W(@)7,`161U8V%T:6]N`$5L96UE;G0N+BX`16T`16UA:6P`16UA:6P@061D
M<F5S<P!%;6%I;"!A9&1R97-S97,@;75S="!M871C:"X`16UA:6P@=VET:"!C
M;VYF:7)M871I;VX`16UO=&EC;VYS`$5M<'1Y(&UE<W-A9V4N`$5M<'1Y(')E
M<W5L="X`16UP='D@<V5A<F-H('1E<FUS`$5N86)L92!I;G-E<G1I;VX@;V8@
M:6UA9V5S(&9R;VT@4&AO=&\@1V%L;&5R:65S(&EN('1E>'0_`$5N86)L92!R
M:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5N9"!Y96%R`$5N;&%R9V4@161I
M=&]R`$5N=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@
M8F4@87-K960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@
M92YG+B`G=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T
M:&4@:6UA9V4@55),(&AE<F4`17)R;W(`17)R;W(@8W)E871I;F<@8FQO8VLZ
M("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,`17)R;W(@=7!D871I;F<@
M<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA:6P@;65S<V%G92X`171H;FEC
M`$5U<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#(@;6EN=71E<P!%=F5R
M>2`S,"!S96-O;F1S`$5V97)Y(#4@;6EN=71E<P!%=F5R>2!,;V=I;@!%=F5R
M>2!H86QF(&AO=7(`179E<GD@;6EN=71E`$5X86UP;&4@=F%L=65S.@!%>&5C
M=71E`$5X<&%N9`!%>'!A;F0@4VED96)A<@!%>'!E8W1E9"`G*2<`17AP:7)A
M=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T
M=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T
M;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N
M;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I<@!&871A;"!%
M<G)O<CH`1F%X`$9E8G)U87)Y`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E
M<G,`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&
M:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L
M;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I<G-T
M($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQO870`1F]G`$9O;&1E
M<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R`$9O;V0`1F]R(&)R;W=S
M97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`1F]R96-A<W0@*%1!1BD`
M1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`1F]R='5N92!T
M>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A<F1S`$9R`$9R
M86UE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U;&P@36]O
M;@!&=6QL($YA;64`1V%L;&5R>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R
M>3H`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'96YE<F%T960@0V]D90!'
M:79E;B!.86UE`$=O`$=O;V=L92!396%R8V@`1W)A>7-C86QE`$=R965K("A)
M4T\M.#@U.2TW*0!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M
M=7-T(&)E(&YO;BUE;7!T>0!'<F]U<',`1W5E<W0@4&5R;6ES<VEO;G,`1W5E
M<W1B;V]K`$A434P`2%1-3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE
M=&4@=&AE(&QA<W0@8V5L;"!I;B!R;W<N`$A434Q!<F5A(&-O=V%R9&QY(')E
M9G5S97,@=&\@9&5L971E('1H92!L87-T(&-O;'5M;B!I;B!T86)L92X`2%1-
M3$%R96$@8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@<F]W
M(&EN('1A8FQE+@!(5%10($%U=&AE;G1I8V%T:6]N(&YO="!F;W5N9"X`2&%S
M:"U!;&=O<FET:&T`2&%Z90!(96%D97(`2&5B<F5W("A)4T\M.#@U.2TX+4DI
M`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H
M97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(
M;U]M90!(;VUE`$AO;64@061D<F5S<P!(;VUE($1I<F5C=&]R>0!(;VUE(%!H
M;VYE`$AO<F1E`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N
M8V]U;G1E<F5D(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A
M9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O
M8FIE8W0@;V8@='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO
M;&%B.B!3=6-C97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B
M.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@=')E92!F;W(@;V)J96-T("5S
M`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M;W9E("5S("(E<R(Z("5S`$AO
M<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@34E-12!)1"!F;W(@=&AE
M('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H
M<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<WEN
M8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+;VQA8CH@56YK;F]W;B!S:&%R
M92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I>F]N=&%L('!A9&1I;F<`2&]R
M:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE<F4_("A0;&5A<V4@<F5P;W)T
M(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A<F4@=&AE<F4_`$AO=R!M86YY
M(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AU;6ED:71Y`$AU;6ED
M:71Y.B``24U!4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M
M86EL8F]X(&1E;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A
M(&-R96%T:6]N(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO
M="!A=F%I;&%B;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)
M1%(@8FQO8VLN`$E?;G-E<G0@4F]W($)E9F]R90!)8V]N<R!/;FQY`$EC;VYS
M(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E;G1I='DG<R!N86UE.@!)9B!I
M="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I
M;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG="!S964@86YY(&EC;VYS('5S
M:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@;6%Y(&YE960@=&\@8VAE8VL@
M=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R86YS<&%R96YC>2X`268@>6]U
M('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA9V4@>6]U
M('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y;W5R(&)R
M;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E(%523`!);6%G92!54DPZ`$EM
M86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P
M;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D`$EM<&]R=&5D(&9I96QD.B`E
M<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C
M="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R96-T('5S97)N86UE(&%N9"]O
M<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N86UE(&]R(&%L=&5R;F%T92!A
M9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T
M;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP+@!);F-R96%S92!);F1E;G0`
M26YD:79I9'5A;"!5<V5R<P!);F9O`$EN9F]R;6%T:6]N`$EN9F]R;6%T:6]N
M(&YO(&QO;F=E<B!A=F%I;&%B;&4N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN
M<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R
M="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H
M92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@
M8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N
M="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN
M<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E
M<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S
M('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!)
M;G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O
M;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G
M97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E
M9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R
M="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO
M;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS
M=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@
M;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI
M<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`26YV86QI9"!A
M<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D871A('-U
M8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED
M(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES
M<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!)
M;G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R;W1O8V]L+@!)
M;G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B:F5C=`!)
M;G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`
M26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27-O;&%T960@5"U3=&]R;7,`
M27-S=65R`$ET86QI8P!*86YU87)Y`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`
M2F5R<V5Y`$IU;'D`2G5N90!*=7-T:69Y`$IU<W1I9GD@0V5N=&5R`$IU<W1I
M9GD@1G5L;`!*=7-T:69Y($QE9G0`2G5S=&EF>2!2:6=H=`!+965P(&]R:6=I
M;F%L/P!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN
M`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@
M5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L
M:6,@:V5Y<V5R=F5R+@!+:61S`$MO<F5A;B`H155#+4M2*0!,85]Y;W5T`$QA
M;F=U86=E`$QA<W0@2&%L9@!,87-T(%!A<W-W;W)D($-H86YG90!,87-T(%%U
M87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN
M.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA=P!,87EO=70`3&5F
M=`!,969T(&AE861E<@!,969T('9A;'5E<P!,:6=H="!$<FEZ>FQE`$QI9VAT
M(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`3&EG:'0@
M4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG:'0@4VYO
M=P!,:6=H="!3;F]W(%-H;W=E<@!,:6YK`$QI;FL@<&]I;G1S('1O.@!,:6YK
M('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE;B!D
M:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,:7-T("T@=7-E<B!C86X@
M<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`3&ES="!(96QP(%1O<&EC
M<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES="U(96QP`$QI<W0M260`
M3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S8W)I8F4`3&ES="U5;G-U
M8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E
M`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,;V-A
M=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F
M86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E
M;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,
M;W9E`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E
M<G,`3&]W97(@<F]M86X@;G5M8F5R<P!-30!-3U1$`$U3+51.148@071T86-H
M;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R
M:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@
M87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-
M87!1=65S="!M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E
M;B!F;&%G<P!-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT
M+T%N<W=E<F5D*0!-871C:&EN9R!F:65L9',`36%X(&%L;&]W960@8W)E9&ET
M+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R
M-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@;&5N
M9W1H`$UA>0!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L
M;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B=70@
M=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I9FEE
M9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A=&AE
M<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N;W0@
M879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A
M9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UI9&1L90!-:6UE(%1Y<&4`
M36EN('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R
M<SH@`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@8V]N9FEG=7)A=&EO
M;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O
M('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI
M<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D
M:69I960@1&%T90!-;V1I9GD@55),`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`
M36]O;B!0:&%S97,`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY
M(%-U;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P
M`$UO=F4@9&]W;@!-;W9E('5P`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T
M<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!!8V-O=6YT($EN
M9F]R;6%T:6]N`$UY(%!O<G1A;`!->2!0;W)T86P@3&%Y;W5T`$Y/+"!)($1O
M($Y/5"!!9W)E90!.86UE`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!
M(%)E=F]C871I;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A
M<&4@4F5N97=A;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A
M<&4@8V5R=&EF:6-A=&4@8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T
M>7!E`$YE='=O<FL`3F5V97(`3F5W($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!5
M<V5R;F%M92`H;W!T:6]N86PI`$YE=R!P87-S=V]R9`!.97<@<&%S<W=O<F0@
M=VEL;"!E>'!I<F4@;VX@)7@N`$YE=R!P87-S=V]R9',@9&]N)W0@;6%T8V@N
M`$YE=R!W:6YD;W<@*%]B;&%N:RD`3F5W<P!.97=S9W)O=7!S`$YE>'0`3F5X
M="!O<'1I;VYS`$YI9VAT`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N
M(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S
M=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L
M871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO
M;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I
M8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T
M;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA
M=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93
M+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO
M(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES
M('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N
M`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.
M;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`
M3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N=&EC871I;VXN
M`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A
M=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I
M8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P96YD:6YG('-I9VYU<',N`$YO(')U;&5S`$YO('-E
M<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E
M8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R
M('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO
M('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R
M871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F
M;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG
M=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/
M+3@X-3DM,3`I`$YO<G1H97)N($AE;6ES<&AE<F4`3F]T($%F=&5R`$YO="!"
M969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I;7!L96UE;G1E9"X`3F]T('-E
M=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@
M8F%C:RX`3F]V96UB97(`3G5M8F5R`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU
M;6)E<B!O9B!C;VQU;6YS`$YU;6)E<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P
M96-I9FEE9"!F;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+
M`$]B:F5C=`!/8FIE8W0@0W)E871O<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@
M9FEL=&5R`$]F9FEC90!/;&0@86YD(&YE=R!P87-S=V]R9',@;75S="!B92!D
M:69F97)E;G0N`$]L9"!P87-S=V]R9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O
M<G)E8W0N`$]N;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E
M<G,N`$]N;'D@;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D
M9')E<W,@86QL;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN
M:7-T<F%T;W(@;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES
M<VEO;G,@9F]R(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;G,@
M=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P
M=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO
M;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P
M;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/
M=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@
M875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@
M4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!0
M1U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!0
M32!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3;F]W(%-H;W=E
M<G,`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](
M4"!3:&5L;`!0861D:6YG`%!A<G1L>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O
M<F0@8VAA;F=E9"!S=6-C97-S9G5L;'DN`%!A<W-W;W)D(&EN8V]R<F5C=`!0
M87-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N+@!0
M87-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O<F0Z
M(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C;&EP
M8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT`%!E
M<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO
M;B`B)7,B(&YO="!D96QE=&5D+@!097)M:7-S:6]N<P!097)M:7-S:6]N<R!!
M9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA=&EO;@!0971S`%!H;VYE
M`%!H;W1O<P!0:7AE;',`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L
M96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE
M;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@
M=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R
M+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0
M;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@
M82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE
M(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O
M=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E
M('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F
M;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@
M=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O
M<GD@;F%M93H`4&]L:71I8W,`4&]L;',`4&]S:71I;VYI;F<@;V8@=&AI<R!I
M;6%G90!0;W-I=&EO;FEN9R!O9B!T:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F
M;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O
M<B!L87-T("5S(&AO=7(H<RDZ(`!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0
M(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D
M('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U
M<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@
M=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R
M:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C
M<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI
M8R!+97D@06QG;W)I=&AM`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E
M;F5R871E9"!S=6-C97-S9G5L;'DN`%%U97)Y`%%U;W1A`%)302!0=6)L:6,@
M2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`
M4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3
M;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!2
M96%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD
M;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI
M<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S
M="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E
M<V@@4&]R=&%L(%9I97<Z`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`
M4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE
M+F-O;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M
M;@!296UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@
M<V-R:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M
M;W9E('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E
M;6]V92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E
M(&%N<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"!&:65L
M9`!297-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E
M<W5L=',`4F5T=7)N('1O($]P=&EO;G,`4F5T>7!E(&YE=R!P87-S=V]R9`!2
M975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N`%)I8V@@5&5X="!%9&ET;W(@
M3W!T:6]N<P!2:61D;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU
M97,`4F]?=R!0<F]P97)T:65S+BXN`%)O;&4`4F]T871E(#$X,`!2;W1A=&4@
M3&5F=`!2;W1A=&4@4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I
M97,`4F]W<SH`4G5L97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@
M<F]W<R!A;F0@8V]L=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O
M;'5M;G,@;VYL>0!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL
M>0!2=6X`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC
M871I;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE
M;&P`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386UE(&9R86UE("A?<V5L
M9BD`4V%V90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C
M;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S
M('1E;7!O<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN
M`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!3
M96QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N
M97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D
M`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C
M="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S
M('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@
M8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C
M="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z
M`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE
M8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T
M.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L
M;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E
M;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N<V]R.B``4V5P=&5M8F5R
M`%-E<FEA;"!.=6UB97(`4V5S<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P
M=&EO;G,@=&\@86QL;W<@>6]U('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@
M>6]U(&5V97(@9F]R9V5T(&ET+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA
M="!Y;W4@=V%N="!T;R!A8V-E<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO
M=7(@<')E9F5R<F5D(&QA;F=U86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I
M;VYS+@!3970@>6]U<B!S=&%R='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE
M;64L('!A9V4@<F5F<F5S:&EN9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N
M<RX`4V5T=7``4V5T=7`@=7!G<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E
M<F%L(&QO8V%T:6]N<R!P;W-S:6)L92!W:71H('1H92!P87)A;65T97(Z(`!3
M:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E<W,@:V5Y<R!B92!D
M969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@9&EF9F5R96YC97,@
M8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N97=L>2!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE;B!L
M;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R:6=I;F%L`%-H;W<@
M<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU(&)A<C\`4VAO=R!T
M:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@5&%B;&4@0V5L;"!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0<F]P97)T:65S(&1I
M86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO=R!U<&QO860`4VAO
M=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3:')I;FL`4VAR:6YK
M(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y
M(&9I<G-T`%-I9VX@=7``4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`
M4VEZ90!3:VEP($UA:6YT96YA;F-E`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]N9W,@
M)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3
M;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4V]U=&AE<FX@2&5M:7-P:&5R
M90!3<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@
M8V]N=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A
M8VEN9R!A;F0@<&%D9&EN9P!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T
M`%-P;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W1A
M;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE87(`4W1A=&4@;W(@4')O=FEN8V4`
M4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T<F5E="!!9&1R97-S`%-T<FEN9R!L
M:7-T`%-T>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3
M=6-C97-S`%-U8V-E<W-F=6QL>2!D96QE=&5D("(E<R(N`%-U8V-E<W-F=6QL
M>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG
M97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`
M4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5M;6%R>0!3=6X@4FES
M90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES
M93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FYA
M;64`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!4+5-T;W)M`%0M4W1O
M<FUS`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@<')O
M<&5R=&EE<P!487)G970Z`%1A<VMS`%1E;&5P:&]N92!.=6UB97(`5&5M<"!F
M;W(@;&%S="!H;W5R.B``5&5M<&5R871U<F4`5&5M<&5R871U<F4Z(`!496UP
M;&%T92!!9&UI;FES=')A=&EO;@!497AT`%1E>'0@3VYL>0!497AT(&%L:6=N
M`%1E>'1T;W``5&@`5&AA:2`H5$E3+38R,"D`5&AA;FL@>6]U(&9O<B!U<VEN
M9R!T:&4@<WES=&5M+@!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA
M8FQE+@!4:&4@36%I;G1E;F%N8V4Z.B!C;&%S<R!D:60@;F]T(&QO860@<W5C
M8V5S<V9U;&QY`%1H92!/<'1I;VYS('=I;F1O=R!H87,@8VQO<V5D+B!%>&ET
M:6YG+@!4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C;VYF:6=U<F4@82!P
M97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y;W4@=V%N="!T;R!U
M<V4@4&5R;6ES<VEO;G,N`%1H92!B;W1T;VT@<VED92!O;FQY`%1H92!C;VYT
M86-T($E$(&YU;6)E<B!W87,@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N:R!O
M<B!W87,@;F]T(&9O=6YD(&EN('1H92!D871A8F%S92X`5&AE(&-O;G1A8W0@
M=V%S('-U8V-E<W-F=6QL>2!A9&1E9"!T;R!Y;W5R(&%D9')E<W,@8F]O:RX`
M5&AE(&1E=&%C:&5D(%!'4"!S:6=N871U<F4@8FQO8VL@:7,@<F5Q=6ER960@
M=&\@=F5R:69Y('1H92!S:6=N960@;65S<V%G92X`5&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I9FEE9"P@;&5F="!B;&%N
M:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E+@!4:&4@9&ES=')I8G5T
M:6]N(&QI<W0@=V%S(&YO="!S<&5C:69I960N`%1H92!E;F-R>7!T:6]N(&9E
M871U<F5S(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN`%1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RX`5&AE(&9I;&4@
M)7,@<VAO=6QD(&-O;G1A:6X@<V]M92`E<R!S971T:6YG<RX`5&AE(&9I;&4@
M8V%N(&YO="!B92!C;W!I960@;VYT;R!I='-E;&8N`%1H92!F:6QE(&-O;G1A
M:6YE9"!N;R!D871A+@!4:&4@9G5L;"!S8W)E96X@;6]D92!I<R!K;F]W;B!T
M;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X<&QO<F5R+"!D=64@
M=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A8FQE('1O('=O<FMA
M<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B86=E(&1I<W!L87DL
M(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@<F%N9&]M(&)R;W=S
M97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I;F1O=W,@.7@@:70G
M<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G1V5N97)A;"!0<F]T
M96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N7&Y<;EEO=2!H879E
M(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF('EO=2!S=&EL;"!W
M86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R+@!4:&4@:61E;G1I
M='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F="UH86YD('-I9&4@
M;VYL>0!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I=&@@<W5B:F5C
M="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N;R!G=6%R86YT
M964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R('5N9&5R<W1O
M;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O
M<V4@<&%G90!4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N
M`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A=F5D(&)E8V%U
M<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL;W=A8FQE('-I
M>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T82!T>7!E("@E
M<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@<FEG:'0@86YD
M(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E(&]N;'D`5&AE
M('-E<&%R871O<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA<F%C=&5R+@!4:&4@
M<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE('-E<G9E<B`B)7,B
M(&AA<R!B965N('-A=F5D+@!4:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(&AA
M<R!B965N(')E;6]V960N`%1H92!S<&5C:69I960@<F]W(&1O97,@;F]T(&5X
M:7-T+@!4:&4@=&5M<&]R87)Y(&9I;&4@(B5S(B!D;V5S(&YO="!E>&ES="X`
M5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`5&AE('1O<"!S:61E(&]N
M;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R979I
M;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O=6QD(&YO="!B92!S879E
M9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO="!A=F%I;&%B;&4N`%1H
M97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO('!A
M<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R92!T
M;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E(&5N
M=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T:&%N
M("5S+@!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D
M.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL
M>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P
M;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I
M;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R
M(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E('=A<R!A;B!E
M<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H87!S('EO=2!L
M969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@86X@97)R;W(@
M<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO
M;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R
M('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A
M:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN9R!T:&4@9&ES
M=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H:7,@
M24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N
M`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R(&%R8VAI
M=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I
M;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A<F0@;G5M
M8F5R+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!I<R`E<RX`
M5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H
M)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@
M870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@
M=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`
M5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA
M=`!4:6UE('-E;&5C=&EO;@!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O
M('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L
M("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O
M9&%Y`%1O;6]R<F]W`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N
M<P!4<G5E(&]R(&9A;'-E`%1U`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%1Y<&4@
M>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523#H`56YA8FQE('1O
M(&%C8V5S<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S
M97(@:6YF;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA
M;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T
M;R!C:&%N9V4@=&\@)7,N`%5N86)L92!T;R!C;VYN96-T('1O(%-13"!S97)V
M97(N`%5N86)L92!T;R!C;VYN96-T('=I=&@@4U-,+@!5;F%B;&4@=&\@8V]P
M>2!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y("(E
M<R(N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O
M(&-R96%T92!61E,@9FEL92X`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@
M9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E
M;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE
M('1O(&1E;&5T92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE
M(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@
M9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E
M;&5T92!61E,@9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D('1H92!V9G-R;V]T(&1I<F5C=&]R>2X`56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX
M*0!5;FET<P!5;FMN;W=N`%5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N
M`%5N;&EN:R!T:&4@8W5R<F5N="!E;&5M96YT`%5N;F%M960`56YP<FEV:6QE
M9V5D('-C<FEP=',@8V%N;F]T(&%C8V5S<R!#=70O0V]P>2]087-T92!P<F]G
M<F%M871I8V%L;'D@9F]R('-E8W5R:71Y(')E87-O;G,N("!#;&EC:R!/2R!T
M;R!S964@82!T96-H;FEC86P@;F]T92!A="!M;WII;&QA+F]R9R!W:&EC:"!S
M:&]W<R!Y;W4@:&]W('1O(&%L;&]W(&$@<V-R:7!T('1O(&%C8V5S<R!T:&4@
M8VQI<&)O87)D+@!5;G-E="!C;VQO<@!5;G-U<'!O<G1E9"!%>'1E;G-I;VX`
M57!D871E`%5P9&%T92`E<P!5<&1A=&4@=7-E<@!5<&1A=&5D("(E<R(N`%5P
M9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P
M;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T
M:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!#=7)R96YT.B`E
M<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@9F]R
M("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N`%5S97(@3W!T:6]N<P!5<V5R(%)E
M9VES=')A=&EO;@!5<V5R(%)E9VES=')A=&EO;B!H87,@8F5E;B!D:7-A8FQE
M9"!F;W(@=&AI<R!S:71E+@!5<V5R(&%C8V]U;G0@;F]T(&9O=6YD`%5S97)N
M86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S>7-T96TZ
M`%9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED
M(&QO8V%T:6]N<R!F;W5N9"!I;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RX`5F%L=64@:7,@;W9E<B!T:&4@;6%X:6UU;2!L
M96YG=&@@;V8@)7,N`%9A;'5E<P!686QU97,@=&\@<V5L96-T(&9R;VT`5F%R
M:6%B;&4`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@86QI9VX`
M5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I971N86UE
M<V4@*%9)4T-)22D`5FEE=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E
M`%9I97<@87,@)7,`5FES:6)I;&ET>0!6:7-I8FEL:71Y.B``5T%23DE.1R$A
M(2!214U/5D4@4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A<FYI;F<`5V4`
M5V5A=&AE<B!&;W)E8V%S=`!796%T:&5R(&1A=&$@<')O=FED960@8GD`5V5A
M=&AE<BYC;VT`5V5B`%=E8B!3:71E`%=E96ML>0!796QC;VUE`%=E;&-O;64@
M=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X-3DM,2D`5V5S=&5R
M;B`H25-/+3@X-3DM,34I`%=H870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I
M<W!L87D@869T97(@;&]G:6X_`%=H870@:7,@=&AE(&1E;&EM:71E<B!C:&%R
M86-T97(_`%=H870@:7,@=&AE('%U;W1E(&-H87)A8W1E<C\`5VAI8V@@<&AA
M<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT
M(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I9'1H(&]F('1H
M92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@;VX@;F5X="!L
M;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`
M5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD
M.@!7:6YD.B``5VES9&]M`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`
M65D`65E960!996%R;'D`665S`%EE<RP@22!!9W)E90!9;W4@87)E(&EN(%1%
M6%0@34]$12X@(%5S92!T:&4@6SP^72!B=71T;VX@=&\@<W=I=&-H(&)A8VL@
M=&\@5UE325=91RX`66]U(&%R92!N;W0@875T:&5N=&EC871E9"X`66]U(&-A
M;B!N;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M
M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A9&1R97-S+@!9
M;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I
M;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V
M92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@
M8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA
M;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9
M;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S="!C;VYF
M:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I
M8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@<')O8FQE
M;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@=&AI<R!L
M:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R('1O(&)E
M(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!C;&5A
M<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R96UO=F4N
M`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`66]U(&UU
M<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@;75S="!S
M<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@
M82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I
M<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D<F5S<P!9
M;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I;VX`66]U<B!);G1E
M<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H92!B96=I;FYI;F<@
M;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO=7(@<V5C=7)I='DL
M('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`66]U<B!A=71H96YT
M:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN9R!U<V5R
M<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R('-O;64@
M;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H879E(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@9F5A='5R
M92X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!L;V=I;B!H87,@97AP:7)E9"X`
M66]U<B!N97<@<&%S<W=O<F0@9F]R("5S(&ES.B`E<P!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960@9F]R('1H92!D=7)A=&EO;B!O9B!T:&ES('-E
M<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E(&)E96X@=7!D871E9"X`66]U<B!P
M87-S=V]R9"!H87,@8F5E;B!R97-E=`!9;W5R('!A<W-W;W)D(&AA<R!B965N
M(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL(&%N9"!L;V<@:6X@=VET:"!Y;W5R
M(&YE=R!P87-S=V]R9"X`66]U<B!P87-S=V]R9"!H87,@97AP:7)E9"X`66]U
M<B!R96UO=&4@<V5R=F5R<SH`6TAI9&4@475O=&5D(%1E>'1=`%M0<F]B;&5M
M(%)E<&]R=%T`6U-H;W<@475O=&5D(%1E>'0@+0!;4VAO=R!1=6]T960@5&5X
M="`M("5S(&QI;F5S70!;;&EN92`E<R!O9B`E<UT`7T%D;6EN:7-T<F%T:6]N
M`%]#3$D`7T1A=&%4<F5E`%]$96QE=&4@4F]W`%]'<F]U<',`7TAE;'``7TEM
M86=E(%!R;W!E<G1I97,N+BX`7TQO9R!I;@!?3&]G(&]U=`!?36]D:69Y($QI
M;FLN+BX`7T]P=&EO;G,`7U!E<FUI<W-I;VYS`%]296UO=F4@3&EN:RXN+@!?
M4V5T=7``7U1A8FQE(%!R;W!E<G1I97,N+BX`7U5S97)S`&%D9')E<W,@8F]O
M:P!C86QE;F1A<@!C86QM`&-L:6-K(&AE<F4`9FEL90!F<F]M('1H92`E<R`H
M)7,I(&%T("5S("5S`&=U<W1I;F<`:#H`:6UM961I871E`&EN;&EN90!L:6YE
M<UT`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N
M;W1E<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S
M`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@<&%S<W=O<F0@='=I8V4@=&\@
M8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE8W0`=D-A<F0`=SH`
M=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!(;W)D92`S(`I297!O
M<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E
M871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES:6]N
M+41A=&4Z(#(P,#4M,#<M,#@@,34Z,C<K,#(P,`I,87-T+51R86YS;&%T;W(Z
M06UI<FMA8FER($UE=&%N971W;W)K:6YG(&QT9"X@/'!E<G-I86XM:&]R9&5`
M;65T86YE='=O<FMI;F<N8V]M/@I,86YG=6%G92U496%M.B!097)S:6%N(#QI
M,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N
M="U4>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/5541BTX"D-O;G1E;G0M5')A
M;G-F97(M16YC;V1I;F<Z(#AB:70*`"`HV+'9B-BR(-F"V*C9A"`E<RD`*-JI
MV83;C-BO(-BOV+/8JMBQV+/;C"`E<RD`*-BOV+$@)7,@V+'9B-BR*0`@*-BG
MV878L=F(V+(I`"`HV8'8L=BOV*<I`"`HV*_;C-BQV8C8LBD`(-BOV+$@`"(E
M<R(@V*C9AR#:K]BQV8C9A^*`C-F'V*?;C"#8L]BGV878I]F&V8<@V*?8MMBG
MV8'9AR#8M-BO`"(E<R(@V*C9AR#8L]BGV878I]F&V8<@V878K-F(V++B@(S9
MA]BG(-BGV+;8I]F!V8<@V+38KP`B)7,B(-BGVXS8K-BGV*\@V8;8M-BOV8<@
MV*C9B-BO.B`E<RX`)2XR9DU"(-BGV+/8JMF!V*?8K]F'(-BTV*_9AR#8I]BR
M("4N,F9-0B#9A=BLV*?8LB`H)2XR9DU"*0`E9"`E<R#9B"`E<P#8I]BSV84@
MV+'9A=BR(-BTV878IR`E9"#8L=F(V+(@V*_;C-JOV+$@V878N=BJV*C8L2#8
MI]BSV*HN`-F^VXS8M,*MV*C;C-F&VXP@)60MV+'9B-BRV8<`)7,@+2#8JMF(
MV*S9AP#8I]BKV+$@V*?9AMJOV+38JB`E<P#:J=N,V839B-BHV*?;C-BJ("5S
M`"5S(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"`M(-BJV*/;C-N,V*\`
M(-BQV*?9AR8C>#(P,&,[V*?9AMBOV*?8LMN,("5S(``E<R#8J]BHV*H@V8;8
MI]F%`-BTV+'9B-BW(-BJV8C8I]F!V8(@)7,`)7,@V*?8LB#9@MBHV80@V879
MB-BLV8C8KR#8I]BSV*H`)7,@V*_8L2`E<R`E<P`E<R#8HMF%V*?8K]F'(-BG
MV*S8L=BGVXP@V+G9A=F$VXS8I]BJ(-F&VJ_9A]BOV*?8L=N,(-BGV8;8JMBN
MV*?8J"#8M-BOV8<@V*?8L]BJ+B#8K-BYV*C9AR#9A]BQ(-BYV879A-N,V*?8
MJMN,(-BQV*<@VJG9AR#9A]F%(-BGVJG9AMF(V88@V87;C.*`C-BNV8C8I]F'
MVXS8KR#8I]BLV+'8IR#:J=F&VXS8KR#8N=F$V*?9A=BJ(-BHV++9AMN,V*\`
M)7,@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`"5S(-BOV8+;C-F"V8<`)7,@
MV;[;C-BOV*<@V8;8M-BO`"5S(-BHV8<@)7,@V*?8LB`E<P#:J=BJV*?8J-J&
MV8?9E"#8HMBOV+'8LR`E<P#8JMF"V8C;C-F%("5S`"5S)W,@3F]T97!A9`#9
M@=F'V+'8L]BJ(-F(V+C8I]N,V8$@)7,`)7,Z("5S`-B,(-BHV*?8KP#8C"#8
MJ-BGV*\@)7,@)7,`V(P@V878JMBZVXS;C-BQ(-BGV+(@)7,@V*C9AR`E<P`@
MV*?9AMBJV*[8I]BH(`#9@MBGV838J"#;L=NR(-BSV*?8N=BJVXP`V8+8I]F$
MV*@@V[+;M"#8L]BGV+G8JMN,`-NRV[0@V+/8I]BYV*K9AP#;C-JI(-F^V+38
MJMN,V*C8I]F&(-BOV*?8K]JOV*?9AB#8J-BQV*?;C"#8I]N,V88@V*C9A-BG
MVJD@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-N,VJD@V*[8M]BGVXP@V*S8
MK]N,(-BQV*X@V*_8I]BOV8<@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9A=F(
MV87;C"!01U`@V*C8L=BGVXP@V+'9A=BRV*C9AMBOVXP@VXS:J2#9OMN,V+K8
MI]F%(-F%V8C8L=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BY
MV879B-F%VXP@4$=0(-BHV+'8I]N,(-BHV*?8LMBHVXS9AMN,(-N,VJD@V;[;
MC-BZV*?9A2#8I]F%V+;8I]BA(-BTV*_9AR#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,V(P@VXS:J2#:J=F$VXS8
MKR#8KMBUV8C8M=N,(%!'4"#9B"#;C-JI(-BYV*C8I]BQV*H@VJ_8L-BQ(-BH
MV+'8I]N,(-BQV878LMJOV+38I]N,VXP@VXS:J2#9OMN,V+K8I]F%(-F%V8C8
ML=BO(-F&VXS8I]BR(-BGV+/8J@#;C-JI(-JIV83;C-BO(-BYV879B-F%VXS8
MC"#;C-JI(-JIV83;C-BO(-BNV+79B-BUVXP@4$=0(-F((-N,VJD@V+G8J-BG
MV+'8JB#:K]BPV+$@V*C8L=BGVXP@V*?9A=BVV*?8H2#;C-JI(-F^VXS8NMBG
MV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-N,VJD@VJG9A-N,V*\@V+G9
MA=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;C"!3+TU)344@V8@@
MVXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8L=F%V++:K]BTV*?;
MC-N,(-F^VXS8NMBGV84@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-N,VJD@
MVJG9A-N,V*\@V+G9A=F(V87;C-B,(-N,VJD@VJG9A-N,V*\@V*[8M=F(V+7;
MC"!3+TU)344@V8@@VXS:J2#8N=BHV*?8L=BJ(-JOV+#8L2#8J-BQV*?;C"#8
MI]F%V+;8I]BA(-N,VJD@V;[;C-BZV*?9A2#9A=F(V+'8KR#9AMN,V*?8LB#8
MI]BSV*H`VXS:J2#:J=F$VXS8KR#8N=F%V8C9A=N,(%,O34E-12#8J-BQV*?;
MC"#8L=F%V++8J-F&V*_;C"#9OMN,V+K8I]F%(-F%V8C8L=BO(-F&VXS8I]BR
M(-BGV+/8J@#8J-BGV+'8I]F&(-BSV*C:J2#8M=BHV*W:K]BGV8?;C`#8J-BG
MV+'8I]F&(-BUV*C8K=JOV*?9A]N,`-BQVJ_8J-BGV+$@V+78J-BMVJ_8I]F'
MVXP`V*K:K]BQVJ\@V+78J-BMVJ_8I]F'VXP`V+78J-BM+]BYV+78L0#8K]BQ
MV*C8I]BQV8<@V*?;C-F&(-F(VXS8L=BGV+/8JMBGV+$`V*_8L=BHV*?8L=F'
M+BXN`-F^V*?;C-N,V88@V878M]F$V8(`V8C8L]BW(-F%V+?9A-F"`-BGVXS8
MK-BGV*\@V+38I]BNV8<@5D93(-F%V*S9B-BR(-BOV+/8JMBQV+/;C"#9AMBO
MV*?8L=BO`-BGVXS8K-BGV*\@V;[8L=F(V8;8K]F'(%9&4R#9A=BLV8C8LB#8
MK]BSV*K8L=BSVXP@V8;8K]BGV+'8KP#8I]BWV838I]BYV*?8JB#8K=BSV*?8
MJ`#8I]BSV84@V+'9A=BR(-BMV+/8I]BH`-BMV+/8I]BH(-F%V+/8K]F(V*\`
MV*W8L]BGV*C8K]BGV+';C`#8I]BVV*?9@=F'(-JIV+'8K]F&`-BGV+;8I]F!
MV8<@VJG8L=BOV88@VJ_8L=F(V8<@V8'8L=BYVXP`V*?8MMBGV8'9AR#:J=BQ
MV*_9AB#9A=BLV8C8LB#9@=BQV+G;C.*`C`#8I]N,V8;8K-BG(-BGV+;8I]F!
MV8<@VJG9ACH`V*?8MMBGV8'9AR#:J=BQV*_9AB#:K]BQV8C9AR#8K-BOVXS8
MKP#8I]BVV*?9@=F'(-JIV+'8K]F&(-F%V*S9B-BR(-BLV*_;C-BO`-BGV+;8
MI]F!V8<@VJG8L=BOV88@VXS:J2#9A=BLV8C8LB#9@=BQV+G;C"#8J-F'("(E
M<R(`V*?8MMBGV8'9AR#:J=BQV*_9AB#;C-JI(-JIV*?8L=BHV+$@V*S8K]N,
MV*\Z`-BGV+;8I]F!V8<@VJG8L=BOV88@V+/8JMF(V88`V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#8I]BYV+;8I]N,(-BLV*_;C-BO`-BGV+;8I]F!V8<@VJG8L=BO
MV88@V++9B-BL`"#8I]BVV*?9@=F'(-JIV+'8K]F&(-JOV++;C-F&VJ_8I]F&
M("5S(-BHV+G9AMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMN,
MV838IP#8I]BVV*?9@=F'(-JIV+'8K]F&(-BHV8<@VJG8JMBGV*C:AMF'V90@
MV*+8K]BQV+,Z`-BGV+;8I]F!V8<@VJG8L=BOV88@V*C9AR#:J=BJV*?8J-J&
MV8?9E"#8HMBOV+'8LR#9A=F&`-BGV+;8I]F!V8<@V8/8L=BOV88@VJG8I]BQ
MV*C8L0#8I]BVV*?9@=F'(-JIV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-F!V+G8
MI]F$(-F&VXS8L]BJ`-BBV*_8L=BS`-JIV*K8I]BHVH;9A]F4(-BBV*_8L=BS
M(`#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'+2#8JMBYVXS;C-F&(-F%V*S9
MB-BRV8?8I]N,(-JIV*?8L=BHV+'8I]F&(-BOVXS:K]BQ`-BSV+'9OMBQV+/8
MJMN,`-BJV*C9A-N,V+K8I]BJ`-F%V+G8I]BOV80`V*K8L=BGV+(@VJG8L=BO
MV88`V*K8L=BGV+(Z`-F'V879AP#8JMF%V*?9A=N,(-JIV*?8L=BHV+'8I]F&
M(-BJV*/;C-N,V*\@V+79A-BGV*W;C-BJ(-BTV*_9AP#9A]F%V8<@VJ_8L=F(
MV8?B@(S9A]BG`-F'V879AR#9A=BLV8C8LN*`C-F'V*<`V8?9A=F'V90@VH;9
MA]BGV+$@V+/9A=BJ`-BGV*S8I]BRV8<@VH;9AMBO(-BBV*_8L=BSVXP`V*+;
MC-BG(-BGV*S8I]BRV8<@V*K9AMBXVXS9A2#9AMF(V+D@V8'9A]BQV+/8JB#9
MA=BQV*K8J"#8K]BGV*_9AR#8M-F(V*_8GP#8I]BR(-F"V*C9A"#9A=F(V*S9
MB-BO(-BGV+/8J@#9B-BQV8C8KR!)35-0(-BLV*?;C-JOV++;C-F&`-BGV+/9
MA2#8L=F%V+(@24U34"#8K-BGVXS:K]BRVXS9A@#9AMBGV84@VJG8I]BQV*C8
ML=N,($E-4U`@V*S8I]N,VJ_8LMN,V88`V*+8K]BQV+,@V;[8L]BJ(-BGV83:
MJ=BJV+'9B-F&VXS:J2#8K-BGVXS:K]BRVXS9A@#8I]F$VJ_9B.*`C-F'V*?;
MC"#8K-BGVXS:K]BRVXS9A@#9A=BJV88@V*S8I]N,VJ_8LMN,V88Z`-N,VJD@
MV879@MBOV*?8L2#9AMBGV*_8L=BSV*H@V*K8N=N,VXS9AB#8M-BOV8<@V*C9
MB-BO`-F^VXS8M-JIV*?8L0#9OMBGV+/8K@#8J-BQV8;8I]F%V8?9E.*`C"#:
MJ=BGV+'8J-BQV*_;C`#9@=F'V+'8L]BJ(-BHV+'9AMBGV879A^*`C-F'V*?;
MC"#:J=BGV+'8J-BQV*_;C`#8J-BQV8;8I]F%V8<@V*+9A=BGV*_9AR#8I]BS
MV*H`V*?8N=F%V*?9A"#8J-BQ(-BQV8C;C"#8I]BTV*K8L=BGVJG9A]BGVXP@
MV8'8L=BYVXP`V*K8M=F(VXS8J`#8I]F&V*_8I]BRV8<@V*K9@MBQVXS8J-N,
M`-BBV8C8L=N,V80`07)A8FEC("A7:6YD;W=S+3$R-38I`-BGV8;8K]BGV++9
MAR#9OMBQV8C9AMBOV8<@V*+8L=BTVXS9B`#9AMBGV84@V*+8L=BTVXS9B`#8
MHMN,V*<@V+39A=BG(-F%V+?9A=BFV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8
MI]F'VXS8KR#8I]BWV838I]BYV*?8JB#8I]F!V*K8JMBGV*T@V*W8L]BGV*@@
M)7,@V+'8IR#9OMBGVJD@VJG9AMN,V*_8GP!!<FUE;FEA;B`H05)-4T-)22TX
M*0#9A]F&V+$`V*+;C-BG(-F"V*C9A"#8I]BR(-BYV879A-N,V*?8JB#9AMJO
MV8?8K]BGV+';C"#8J-BQV*?;C"#8JMBCVXS;C-BO(-BBV88@V+/8IMF(V*?9
MA"#8M-F(V*_8GR``V*?9AMBJV+/8I]BH(-BSV*K9B-F&V8?8IP#8L]BYVXP@
MV*_8L2#8K=BPV8$@VJ_8L=F(V8?;C"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879
MB-BLV8C8KR#9AMN,V+/8J@#8L]BYVXP@V*_8L2#8K=BPV8$@V878K-F(V++;
MC"#8M-BOV8<@V*?8L]BJ(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#8L]BY
MVXP@V*_8L2#9B-N,V+'8I]N,V+0@V878K-F(V++;C"#8M-BOV8<@V*?8L]BJ
M(-JIV8<@V879B-BLV8C8KR#9AMN,V+/8J@#8L]BYVXP@V*_8L2#9B-N,V+'8
MI]N,V+0@V*?8M-BJV+'8I]JIVXP@V+38K]F'(-BGV+/8JB#:J=F'(-F%V8C8
MK-F(V*\@V8;;C-BSV*H`XH",V8C;C-J8VJ_;C-F'V*<`V*+:K]F(V+/8J@!!
M=71H7V-Y<G-Q;#H@V*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR($E-05`@V;[;
MC-BOV*<@V8;8M-BO`$%U=&A?8WER<W%L.B#8L]BGV878I]F&V8<@V;[8M-BJ
MVXS8J-BGV88@V8+8I]BHV83;C-BJV8?8I]N,(-F%V8C8L=BO(-F&VXS8I]BR
M(-BQV*<@V8;8K]BGV+'8KP!!=71H:6UP.B#8J-BSV+<@V879B-BQV*\@V8;;
MC-BGV+(@24U!4"#9OMN,V*_8IR#9AMBTV*\`075T:%]F='`Z(-BHV+/8MR#9
MA=F(V+'8KR#9AMN,V*?8LB!&5%`@V;[;C-BOV*<@V8;8M-BO`$%U=&A?:6UP
M.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@24U!4"#9OMN,V*_8IR#9AMBT
MV*\`075T:%]K<F(U.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@:W)B-2#9
MOMN,V*_8IR#9AMBTV*\`075T:%]L9&%P.B#8J-BSV+<@V879B-BQV*\@V8;;
MC-BGV+(@3$1!4"#9OMN,V*_8IR#9AMBTV*\`075T:%]L9&%P.MBGV+;8I]F!
MV8<@VJG8L=BOV88@VJG8I]BQV*C8L2`E<R#9A=F%VJG9AB#9AMN,V+/8JBX@
MV*?;C-F&(-J&VXS8LMN,(-BGV+/8JB#:J=F'(-JIV*?8L=BSV*?8LB#:K]F!
MV*K9AR#8I]BSV*H`075T:%]L9&%P.MBMV+#9@2#:J=BGV+'8J-BQ("5S(-F%
MV87:J=F&(-F&VXS8L]BJ(`!!=71H7VQD87`ZV*C8L=F(V++8L=BSV*?9AMN,
M(-JIV*?8L=BHV+$@)7,@V879A=JIV88@V8;;C-BSV*H`075T:%]M8V%L.B#8
MJ-BSV+<@V879B-BQV*\@V8;;C-BGV+(@34-!3"#9OMN,V*_8IR#9AMBTV*\`
M075T:%]S;6)A=71H.B#8J-BSV+<@V879B-BQV*\@V8;;C-BGV+(@<VUB875T
M:"#9OMN,V*_8IR#9AMBTV*\`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V*?9
MA=F(V8'9D=F"(-BHV8C8KP#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V8;8I]F%
MV8C9@=F1V8(@V*C9B-BO+B`E<P#8JMBUV*_;C-F"(-F'V8C;C-F1V*H@V*?8
MLB#8M]BQV8$@VJG8I]BQV+/8I]BR(%)!1$E54R#8L=BO(-BTV*_9AR#8I]BS
MV*H`V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BOV+$@VJG8I]BQV+/8I]BR($94
M4"#9AMBGV879B-F!V9'9@B#8J-F(V*\@`-F!VXS9A-BOV8?8I]N,(-F"V*?8
MJ-F$(-BOV+/8JMBQV+/;C#H`V;[8L^*`C-BRV87;C-F&V8<`V+'9AMJO(-F^
MV+/B@(S8LMF%VXS9AMF'`-BGV+/9A2#8L=F%V+(@V8;8I]BOV+'8L]BJ(&ME
M<F)E<F]S`-F&V*?9A2#:J=BGV+'8J-BQ(-F&V*?8K]BQV+/8JB!K97)B97)O
M<P!"86QT:6,@*$E33RTX.#4Y+3$S*0#8KMBW(-F%V*C9AMBG`-BHV839B-JI
M("(E<R(@V*?8LB#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C"`B)7,B
M(-N,V*?9@=BJ(-F&V+38KP#8JMF&V+C;C-F%V*?8JB#8J-F$V8C:J0#9AMF(
MV+D@V*C9A-F(VJD`V+/;C-BGV8<`VH;9B-BH(-BGV839@0#9A-BHV8<`V;[9
MA]F&V*?;C"#9A-BHV8<Z`-F$V*C9A^*`C-F'V*<`V8?8L2#8K]F(`-F^V*?;
MC-N,V88`V83;C-BSV*H@V*C9B-F$V*KB@(S8K]BGV+$`0TU3`$-20P#9AMF"
MV*?8MR#8JMF(V++;C-BY($-23`#8KMBUV8C8M=N,V*?8JB#8L]F$V8C9A"XN
M+@#8JMF"V8C;C-F%`-BBV+'8I]F%`-F&V87;C.*`C-BJV8C8I]F&(-BGV+/9
MA2#8L=F%V+(@V+'8IR#8J-BWV8C8L2#8KMF(V*_:J=BGV+$@V*_9B-BHV*?8
ML=F'(-BHV*?8LMF&V+38I]F&V*_8C"#8J-BG(-BSV+'9OMBQV+/8JB#8L]BG
MV878I]F&V8<@V*[9B-BO(-BJV878I]BS(-BHVJ_;C-BQVXS8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9AR`B)7,B(-F&V8C8M-BJ`-F&
MV87;C.*`C-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(-F^V+/8JB#8I]F$
MVJG8JMBQV8C9AMN,VJD@V878JMBUV80@V+38KSH@)7,`V8;9A=N,XH",V*K9
MB-BGV88@V;[8L=F(V8;8K]F'("(E<R(@V+'8IR#8J-BGV+(@VJG8L=BO`-BG
MV8;8M=BQV*?9@0#8I]F&V+78L=BGV8$@V*?8LB#8I]BQV+/8I]F$(-JOV++8
MI]BQV+0`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'("(E<R(@V+'8
MIR#8K=BPV8$@VJG8L=BO("``V8;9A=N,XH",V*K9B-BGV88@VXS:J2#8M-BG
MV*[9AR#9A=F(V8+8JB#9OMN,V*_8IR#:J=BQV*\`V8;9A=N,XH",V*K9B-BG
MV88@V*C8K]F(V88@V;[8I]BQV*?9A=BJV+$@)]F^V+'9B-F&V*_9AR#9A=F"
MV+78KR<@V*?8K]BGV879AR#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V+38
MI]BNV8<@(B5S(MBQV*<@V*W8L-F!(-JIV+'8KR``V8;9A=N,XH",V*K9B-BG
MV88@V*W8L-F!(-F&V879B-BOV(P@)60@V8'8L=BRV8;8KR#9A=F(V*S9B-BO
M(-BGV+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#8K]F(V*C8I]BQV8<@V878L=BJ
MV*@@V8;9A=F(V*_8C"#8J-BQV*[;C"#8I]BR(-F(V+'9B-BOVXS9A]BGVXP@
MV8'8L=BGV8?9A2#8M-BOV8<@V*C8L=BGVXP@V878L=BJV*@@V+/8I]BRVXP@
MV*C8IR#8M-F%V*?8L=F'XH",V8?8I]N,(-BPV*[;C-BQV8<@V+38K]F'V(P@
MV+/8I]BRVJ_8I]BQ(-F&VXS8L]BJ`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS8
MNMBGV84@V+'8IR#8J-F'(-BTV878I]BQV8<@V*K8N=N,VXS9AB#8M-BOV8<@
MVJ_8L-BQ(-BOV*?8KP#8N=F&V8C8I]F&`-BMV*?9A=F$`-JOV+'9B-F'XH",
MV8?8IR#9B"#8J-BQVH;8L]BHV8?8IP#9A=F(V*C8I]N,V80`V*[8M=F(V+7;
MC-BGV*H@V+/9A-F(V80`V8'8I]BUV839AR#8L]F$V8C9A`#8KMBUV8C8M=N,
MV*?8JB#8L]F$V8C9A`#9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8L]F$V8C9
MA`#9A=F(V*C8I]N,V80`0V5L=&EC("A)4T\M.#@U.2TQ-"D`V878L=JIV+(`
M0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`V*S8LMBFVXS8I]BJ(-JO
MV8C8I]F'VXP@`-BSVXS8I]BSV*K9A]BGVXP@VJ_9B-BGV8?;C`#8JMBZVXS;
MC-BQ(`#8I]BSV84@V+'9A=BR(-BNV8C8KR#8L=BG(-BJV+K;C-N,V+$@V*_9
MA]N,V*\`V*K8NMN,VXS8L=BOV*?8K]F&(-F&V*?9A2#9B"#8HMBOV+'8L]N,
M(-JIV8<@V*?9@=BQV*?8KR#9A]F&VJ_8I]F%(-BNV8C8I]F&V*_9AB#9B"#9
MOMBGV+/8KB#8K]BGV*_9AB#8J-F'(-F&V*?9A=F'V90@V+39A=BG(-BNV8C8
MI]F'V8;8KR#8K]N,V*\@`-BJV+K;C-N,V+'8K]BGV*_9AB#8I]BSV84@V+'9
MA=BR(-BTV878IR#8K]BQ(-F^VXS:J=BQV*C9AMBOVXP@V8'8N=F$VXP@V;[8
MM-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N(-BHV*<@V+/8L=F^V+'8
ML]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@V*K9A=BGV+,@V*C:K]N,V+';C-BO
M`-F&V8C;C-BSV8<`V*C8L=BQV+/;C"#9OMN,V8C9AMBO+BXN`.*`C`!#:&EN
M97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4<F%D:71I;VYA;"`H
M0FEG-2D`V*?9AMBJV*[8I]BH(-N,VJD@V*?8L]F%(-BQV878L@#8I]F&V*K8
MKMBGV*@@VXS:J2#9AMBGV84@VJG8I]BQV*C8L=N,`-BGV8;8JMBNV*?8J"#:
MAMJOV8C9AMJOVXP@V8;9A=BGVXS8M"#8JMBGV+';C-BN.@#8I]F&V*K8KMBG
MV*@@V8;9B-BY(-BSV*C:J2#9@=F'V+'8L]BJ("C8J-BQV*?;C"#9@=F'V+'8
ML]BJV8?8I]N,(-F%V+'8JMBH*0#8JMBYV+';C-F!(-JIV838I]BS("5S(-N,
MV*?9@=BJ(-F&V+38KP#8M=BGV8$`V;[8I]JI(-JIV+'8K]F&(-BJVJ_9A]BG
MVXP@35-/9F9I8V4`V;[8I]JI(-JIV+'8K]F&(-JIV*?8L=BHV+$@.B`E<P#9
MOMBGVJD@VJG8L=BOV88@VJG8I]BQV*C8L0#9OMBGVJD@VJG8L=BOV88@V*_8
MI]BOV8?9E"#:J=BGV+'8J-BQ`-BHV+'8I]N,(-BGV*_8I]F%V8?8C"#:J=F$
MVXS:J2#:J=F&VXS8KP!#;&EC:V%T96QL(-BGV+(@V+?8L=N,V8(@2%144`#8
MJ-BSV*K9AB#9OMF&V*S8L=F'`-BGV*C8L=F'V*<`V*?8J-BQVXP`V*S9A=BY
M(-BTV*_9AB#9AMF(V*?8L2#:J=F&V*?8L=N,`-J&V878N2#8M-BOV88@V838
MJ-F'XH",V8?8IP#8L=F&VJ\`V*?9AMBJV*[8I]BH(-JIV8;9AMBOV8<@V+'9
MAMJO`-BGV8;8JMBNV*?8J"#8L=F&VJ\`V+/8JMF(V8;9A]BG.@#8N=F&V*?9
MB-N,V88@V+/8JMF(V8;9A]BG`-F%V+;8K=JI`-F!V+'9A=BGV88`V;[9B-BS
MV*K9AR#9@=BQV878I]F&`-BJV8C8MMN,V*T`V8;8I]F%(-BYV879B-F%VXP`
MV+38L=JIV*H`V+'8I]N,V*?9AMF'XH",V8?8IP#8M-BQV+<`V+38L=BGVXS8
MMP#8JMF!V*?9B-BJV8?8I]N,(-F^VXS:J=BQV*C9AMBOVXP`V;[;C-JIV+'8
MJ-F&V*_;C"`E<P#8JMBCVXS;C-BO(-BGV+/9A2#8L=F%V+(`V*?8JMBUV*?9
MA"#9AMBGV879B-F!V9'9@B#8J-F(V*\`V*?8JMBUV*?9A"#9AMBGV879B-F!
MV9'9@B#8J-F(V*\`V*?8JMBUV*?9A"#8J-F'(-JIV*?8L=BSV*?8LB#:J=F$
MVXS8KR#8N=F%V8C9A=N,(-BQV*\@V+38KP#8I]BJV+78I]F$(-BHV8<@VJG8
MI]BQV+/8I]BR(-JIV83;C-BO(-BYV879B-F%VXP@V+'8KR#8M-BO+B#8K]F$
MVXS9A#H@)7,@*"5S*0#8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR($94
M4"#9AMBGV879B-F!V9'9@B#8J-F(V*\`V8;9A=BGV+/9A]BG`-BJV878I]BS
MV8?8IR#8J-BG(-F%V8C9@=F1V8+;C-F1V*H@V*C9AR#:J=BJV*?8J-J&V8?9
ME"#8HMBOV+'8LR#8M-F%V*<@V*?8MMBGV8'9AR#8M-BOV8<@V*C9B-BO`-BG
MV*_8I]F%V8<`VJG9B-JIVXP`V+'9B-F&V8C8M-BJ`-BQV8C9AMF(V+38JB#8
MJ-BQV*_8I]BTV*K9AB#8I]BR(-BHV*[8M"#8I]F&V*K8KMBGV*C;C`#9AMF%
MVXSB@(S8JMF(V*?9AMBO(-F^VXS8NMBGV84@V+'8IR#8L=F%V++8J-F&V*_;
MC"#:J=F&V*\@4$=0`-F&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8
ML=BG(-BGV878MMBGV*$@VJG9AMBO(%!'4`#9AMF%VXSB@(S8JMF(V*?9AMBO
M(-F^VXS8NMBGV84@V+'8IR#8L=F%V++8J-F&V*_;C"#:J=F&V*\@4R]-24U%
M`-F&V87;C.*`C-BJV8C8I]F&V*\@V;[;C-BZV*?9A2#8L=BG(-BGV878MMBG
MV*$@VJG9AMBO(%,O34E-10#9AMF%VXSB@(S8JMF(V*?9AB#8JMF%V*?8L]F'
MV*<@V+'8IR#8I]BVV*?9@=F'(-JIV+'8KR`E<P#9AMF%VXSB@(S8JMF(V*?9
MAB#8J-F'(-JIV*?8L=BSV*?8LB!,1$%0(-F^VXS9B-BSV*H@`-F&V87;C.*`
MC-BJV8C8I]F&(-BHV8<@VJG8I]BQV+/8I]BR(&QD87`@V;[;C-F(V+/8J@#9
MAMF%VXSB@(S8JMF(V*?9AB#8J-BGV838I]F&V+,@V+'8IR#:AMJI(-JIV+'8
MKR`E<P#9AMF%VXSB@(S8JMF(V*?9AB#8J-F'(-JIV*?8L=BSV*?8LB!L9&%P
M(-F%V*K8M=F$(-BTV*\`V8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8
MJMF(V++;C-BYVXP@V*?;C-BLV*?8KR#:J=BQV*\N("5S`-F&V87;C.*`C-BJ
MV8C8I]F&(-BOV*?8K]F'(%!'4"#8L=BG(-BQV878LMJOV+38I]N,VXP@V8;9
MA=F(V*\@`-F&V87;C.*`C-BJV8C8I]F&(-BOV*?8K]F'(%,O34E-12#8L=BG
M(-BQV878LMJOV+38I]N,VXP@V8;9A=F(V*\@`-F&V87;C.*`C-BJV8C8I]F&
M(-BJV878I]BS(-BQV*<@V*W8L-F!(-F&V879B-BO+B`E<P#9AMF%VXSB@(S8
MJMF(V*?9AB#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BG(-BMV+#9@2#9
MAMF%V8C8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@V*+8K]BQV+,@VJ_;C-BQ
MV8;8K]F'(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V+'8IR#8
MJMBTV*[;C-BU(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=F$(-JIV*K8
MI]BHVH;9A]F4(-BBV*_8L=BS(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9
MAMF%VXSB@(S8JMF(V*?9AB#:J=F$(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,
M(-BQV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#9
M@=F'V+'8L]BJ(-JIV*?9A=F$(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-BQ
MV*<@V8C8I]JIV+3;C"#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#:J=F$
MVXS8KR#8N=F%V8C9A=N,(-BQV*<@V*?8LB#:J=BGV+'8L]BGV+(@VJG9A-N,
MV*\@V*C8K]BSV*H@V*+9B-BQV*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8
MIR#8J-BGV+(@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F%V*_9B-F$(-F(
MV+C8I]N,V8$@V8;:K]F'V*_8I]BQVXP@)7,@V+'8IR#8J-BGV+(@V8;9A=F(
MV*\`V8;9A=N,XH",V*K9B-BGV88@)7,@V+'8IR#8KMF(V*?9AMBO`-F&V87;
MC.*`C-BJV8C8I]F&(-BGV+/9A2#8L=F%V+(@V+'8IR#8J-BQV*?;C"#:J=BG
MV+'8J-BQ(-F%V8C8L=BO(-F&V+C8L2#8J-BGV++9AMBTV*?9AMBO+B#8J-BY
MV+;;C"#;C-BG(-F'V879AR#8K-BRV*;;C-BGV*H@V878L=BHV8C8MR#8J-F'
M(-BBV88@V8;8I]BOV+'8L]BJ(-F%VXSB@(S8J-BGV+38KRX@V*_9B-BHV*?8
ML=F'(-BSV+G;C"#:J=F&VXS8KR#;C-BG(-BHV+'8I]N,(-JIV87:J2#8J-N,
MV+38JMBQ(-BHV*<@V+/8L=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8KMF(V*\@
MV*K9A=BGV+,@V*C:K]N,V+';C-BO`-F&V87;C.*`C-BJV8C8I]F&($%#3"#8
ML=BG(-BOV8C8J-BGV+'9AR#8J-BOV+/8JB#8HMF(V+'8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#:J=BJV*?8J-J&V8?9E"#8HMBOV+'8LR#8L=BG(-BOV8C8J-BG
MV+'9AR#8J-BOV+/8JB#8HMF(V+'8KRX@)7,`V8;9A=N,XH",V*K9B-BGV88@
MV8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V+'8IR#8K]F(V*C8I]BQV8<@V*C8
MK]BSV*H@V*+9B-BQV*\N("5S`-F&V87;C.*`C-BJV8C8I]F&(-F!V8?8L=BS
MV*H@V*K9B-BRVXS8N=N,(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BB
MV8C8L=BO+B`E<P#9AMF%VXSB@(S8JMF(V*?9AB#9@MBGV*C9A-N,V*K9A]BG
MVXP@VJG8I]BQV+/8I]BR(-BQV*<@V*_9B-BHV*?8L=F'(-BHV*_8L]BJ(-BB
MV8C8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V+'8
MIR#8J-BGV++:K]BQV*_8I]F&V*\`V8;9A=N,XH",V*K9B-BGV88@V;[;C-JI
MV+'8J-F&V*_;C"`E<R#8L=BG(-BOV*[;C-BQV8<@VJG8L=BO`-F&V87;C.*`
MC-BJV8C8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V;[8M-BJVXS8J-BGV88@V+'8
MIR#8K=F!V+@@VJG8L=BO`-F&V87;C.*`C-BJV8C8I]F&(-F^VXS:J=BQV*C9
MAMBOVXP@V;[8M-BJVXS8J-BGV88@V+'8IR#8K=F!V+@@VJG8L=BO.B`E<R``
MV8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8I]F&
M(-F^VXS:J=BQV*C9AMBOVXP@)7,@V+'8IR#8K=F!V+@@VJG8L=BO`-F&V87;
MC.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#9OMN,VJG8L=BHV8;8K]N,("5S
M(-BQV*<@V*W9@=BX(-F&V879B-BO+B#8M-F%V*<@V87;C"#8JMF(V*?9AMN,
MV*\@V*?8LB#;C-JIVXP@V*?8LB#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;
MC"#8K=F!V+@@VJG8KR#8J-BQ(-BQV8C;C"`E<R#8I]BSV*K9@=BGV*_9AR#9
MAMF%V*?;C-N,V*\@V8@@VXS8IR#8I]N,V8;:J=F'(-BGV+(@VJG8KR#8J-F'
M(-BUV8C8L=BJ(-BOV+/8JMN,(-BOV+$E<R#8L=F(V8;9B-BTV*H@V*K9A]N,
MV8<@V8;9A=BGVXS;C-BO`-F&V87;C.*`C-BJV8C8I]F&(-JIV*?8L=BSV*?8
MLB!,1$%0(-BQV*<@V*S8L]BJV*S9B"#:J=BQV*\`V8;9A=N,XH",V*K9B-BG
MV88@V*K9A=BGV+,@(-BQV*<@V*C8L=F(V++8L=BSV*?9AMN,(-JIV+'8KRX@
M)7,`V8;9A=N,XH",V*K9B-BGV88@V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@
MV+'8IR#8J-BQV8C8LMBQV+/8I]F&VXP@VJG8L=BO+B`E<P#9AMF%VXSB@(S8
MJMF(V*?9AB#9AMF(V*?8L2#8K-BGV8;8J-N,(-F%V8C8LMN,V838IR#8L=BG
M(-F^VXS8K]BG(-JIV+'8KRX@V878M]F%V*;9AB#8M-F(VXS8KR#:J=F'(-F&
MV8C8I]BQ(-BLV*?9AMBHVXP@V*C8I]BR(-BGV+/8J@#9A=BJV88@V+39A=BG
MV+'8M"#8M-BOV8<`VJG8M-F(V+$`V*_9B-BQV8?B@(S9A]BG`-BGVXS8K-BG
MV*\`V*?;C-BLV*?8KR#;C-JI(-F^VXS9B-F&V*\`V*?;C-BLV*?8KR#;C-JI
MVXP@V*S8K]N,V*\`V*?;C-BLV*?8KR#8LMN,V+'9OMF(V+39A^*`C-F'V*<`
MV878K-F(V++9A]BGVXP@V*?;C-BLV*?8KR#:J=F&V8;8K]F'`-BTV878I]BQ
MV8<@VJG8I]BQV*H@V*?8N=BJV*C8I]BQVXP`V+/8I]BYV*H@V8'8N=F$VXP`
M55),(-F!V+G9A-N,(-F'V+/8J@#8HMBH(-F((-F'V8C8I]N,(-F!V+G9A-N,
M`-BTV+'8I]N,V+<@V8'8N=F$VXPZ(`#8L]BHVJD@V8'8N=F$VXP`V+/9@=BG
MV+'8M-N,(-JIV+'8K]F&(-F(V+C8I]N,V8$@V8?9AMJOV*?9A2#9B-BQV8C8
MKR#8J-F'("5S`-BHV+';C-BOV88`V*C8L=N,V*_9AB#8I]F&V*K8KMBGV*@`
M0WER:6QL:6,@*$M/23@M4BD`0WER:6QL:6,@*%=I;F1O=W,M,3(U,2D`0WER
M:6QL:6,O56MR86EN:6%N("A+3TDX+54I`$1$`-BQV8C8LMBGV8;9AP#9A=BQ
MV8C8L=JOV+$@V*_8L=BNV*H@V*_8I]BOV8<`V*K8I]BQVXS8K@#8JMBGV+';
MC-BN(-BOV+';C-BGV8'8JB#8M-BOV8<`V*K8I]BQVXS8KB#8I]F&V*K8KMBG
MV*@`V+'9B-BR`-BMV+#9@2#8L]BJV8C9A@#8K]BSV*?9A=BHV+$`V*?8N=BO
MV*?8KR#8K]F'V*_9A]N,`-JIV84@VJG8L=BOV88@V*K9B-BQV8'8JMJOVXP`
MV;[;C-BT(-F!V+'8M@#8L=F&VJ\@V;[;C-BT(-F!V+'8M@#9A]F(VXS9D=BJ
M(-F^VXS8M"#9@=BQV+8`V;[9B-BSV*K9A]F4(-F^VXS8M"#9@=BQV+8`V*K8
MN=BGV+';C-F!`-BMV+#9@0#8K=BPV8$@VJ_8L=F(V8<`V*W8L-F!(-F%V*S9
MB-BR`-BMV+#9@2#9B"#9OMBGVJG8L]BGV++;C"#9OMN,V+K8I]F%V8?8IP#8
MK=BPV8$@V+/9A-F(V80`V*W8L-F!(-BSV*K9B-F&`-BMV+#9@2#8I]F$VJ_9
MB-N,(-BLV*?;C-JOV++;C-F&(-F%V8C8K-F(V*\`V*W8L-F!(-F%V*S9B-BR
MV8?8IR#8J-BQV*?;C"`@(B5S(@#8HMN,V*<@V878K-F(V++9A]BG(-F((-BR
MVXS8L=F%V*S9B-BRV8?8IR#8J-BQV*?;C"`B)7,B(-BMV+#9@2#8M-F(V*_8
MGP#8K=BPV8$@V+/8M]BQ`-BMV+#9@2#9A]F(VXS9D=BJ(-BGV8;8JMBNV*?8
MJ"#8M-BOV8<`V*W8L-F!(-BSV*K9B-F&(-F!V+G9A-N,`-BMV+#9@2#8L]BW
MV+$@V8'8N=F$VXP`V++9A=BGV88@V*?8L=BSV*?9A`#8M-BQV*T@V878M-JI
MV80`V*K9B-BVVXS8K0#8K-BRV9#8IMN,V*?8JCH`(-BLV++8IMN,V*?8JB#8
MJ-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'(-BKV*C8JB#8M-BO
MV8<@V*?8L]BJ`-JOV+/8JMBQV+0`V8;9@MBWV8<@V+38J-F&V84`V8;9@MBW
MV8<@V+38J-F&V84@V*C8L=BGVXP@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@`-F&
MV8+8M]F'(-BTV*C9AMF%.B``V*S9A]BJ(-BGV+(@VH;9OB#8J-F'(-BQV*?8
ML]BJ`-BLV8?8JB#8I]BR(-BQV*?8L]BJ(-BHV8<@VH;9O@#8M-BGV*[9AP#8
MHMN,V*<@V++9A=BGV88@,C0@V+/8I]BYV*K9AR#9AMF%V*?;C-BT(-BOV*?8
MK]F'(-BTV8C8K]B?`-JOV++;C-F&V8?B@(S9A]BGVXP@V8;9A=BGVXS8M`#9
MAMF%V*?;C-BT(-BLV++8IMN,V*?8JB#9OMN,V+3"K=BHVXS9AMN,`-F&V878
MI]N,V+0@V;[;C-BTPJW8J-N,V8;;C`#9AMF%V*?;C-BT(-F"V*?9A-BH`-BM
MV*?9A-BJ(-BJV+#:J=BQ`-BMV+#9@2#9AMBTV8C8KP#8K]BSV*K8L=BSVXP@
MV878L]BJV8+;C-F%(-BHV8<@;6%I;G1E;F%N8V4N<&AP(-F%V87:J=F&(-F&
MVXS8L]BJ`-BBVXS8IR#8L]BWV+$@V*?9B-F$(-BTV*?9A=F$(-F!VXS9A-BO
M(-F&V*?9A2#9A=N,XH",V*C8I]BTV*_8GR#8I]JOV+$@VH;9AMN,V88@V*?8
ML]BJV(P@V*?;C-F&(-BLV+G8J-F'(-BQV*<@V+G9A-BGV878JB#8J-BRV8;;
MC-BO.@#8I]BSV*K9@MBQV*?8L0#8I]BSV*K9@MBQV*?8L2`E<P#8I]BSV*K9
M@MBQV*?8L2#9OMN,VJG8L=BHV8;8K]N,(-BJV8C9A-N,V*\@V+38K]F'(-BH
MV+G9AMF(V*?9AB#8K]BSV*H@V8;9B-N,V+,@4$A0`-F!V8?8L=BSV*H@V;[8
MI]N,VXS9AN*`C-F^V+$`V*_8I]BQV8C9A]BG`-F&V*?9A=F'(-BGV83:J=BJ
MV+'9B-F&VXS:J=N,`$524@#9B-N,V+'8I]N,V+0`V8C;C-BQV*?;C-BT(-BH
MV839B-JI`-F(VXS8L=BGVXS8M"#:K]BQV8C9AP#9B-N,V+'8I]N,V+0@V878
MK-F(V+(`V8C;C-BQV*?;C-BT(-F%V*S9B-BRV8?8IP#9B-N,V+'8I]N,V+0@
MV878K-F(V++9A]BG(-BHV+'8I]N,("5S`-JOV++;C-F&V8?B@(S9A]BGVXP@
MV8C;C-BQV*?;C-BT.@#9B-N,V+'8I]N,V+0@V878K-F(V++B@(S9A]BG(-BH
MV+'8I]N,("(E<R(`V8C;C-BQV*?;C-BT(-F%V*S9B-BRXH",V8?8IR#8J-BQ
MV*?;C"`E<P#8JMBMV+7;C-F$V*?8J@#8N=F&V+78L2XN+@!%;0#9AMBGV879
MAR#8I]F$VJG8JMBQV8C9AMN,VJG;C`#8HMBOV+'8LR#9AMBGV879A]F4(-BG
MV83:J=BJV+'9B-F&VXS:J=N,`-BBV*_8L=BSV8?8I]N,(-F&V*?9A=F'XH",
MV8?8I]N,(-BGV83:J=BJV+'9B-F&VXS:J=N,(-BHV*?;C-BO(-F%V8;8M]BH
MV8(@V*C8I]BTV*\`V8;8I]F%V8?9E"#8I]F$VJG8JMBQV8C9AMN,VJG;C"#8
MJ-BG(-BJV*/;C-N,V*\`V*?8K=BSV*?8L]BGV*H`V*[8I]F$VXP@VJG8L=BO
MV88@V;[;C-BZV*?9A2``V*[8I]F$VXP@VJG8L=BOV88@V8;8JMN,V*S9AP#8
MKMBGV83;C"#:J=BQV*_9AB#9A=F(V*?8L=BO(-BLV+/8JMBLV8@`V*+;C-BG
M(-BOV+'8K"#8JMBUV*?9B-N,V+$@V*?8LB#:K]BGV838L=N,V8?8I]N,(-BY
MVJG8LR#8K]BQ(-F%V*K9AB#9@=BYV*?9A"#8M-F(V*_8GP#8HMN,V*<@VJ_8
MLMN,V8;:K]BGV88@V++9A=N,V8;9AR#8L=F(VXP@VJG9A-N,VJD@V+'8I]BS
MV*H@V8'8N=BGV80@V+39B-BOV)\`V*?9AMBJV8?8I]N,(-BSV*?9A`#8J-BR
MV+':KR#:J=BQV*_9AB#9B-N,V+'8I]BSV*K8I]BQ`-N,VJD@V+/8IMF(V*?9
MA"#8I]F%V8;;C-BJVXP@V*C8L=BGVXP@V;[8L=BSV+0@V*?8LB#8M-F%V*<@
MV*C9AR#9A]F&VJ_8I]F%(-BHV*?8LMF&V+38I]F&V*_9AB#8I]BSV84@V+'9
MA=BR(-F(V*?8L=BO(-JIV8;;C-BOV(P@V878J]F$V*?9DB`GV8;8I]F%(-BM
MVXS9B-BGV88@V*[8I]F&VJ_;C"#8M-F%V*<@VH;;C-BSV*K8GR<`55),(-BJ
MV+79B-N,V+$@V+'8IR#8I]N,V8;8K-BG(-F(V*?8L=BO(-JIV8;;C-BO`-BN
MV+?8IP#8J-F$V8C:J2#8I]N,V*S8I]BO(-BNV+?8ISH@)7,`V*[8M]BG(-BO
MV+$@VJG8L]BH(-F%V*W8JMF(V*<Z)7,`V*[8M]BG(-BOV+$@V*C8L=F(V++8
ML=BSV*?9AMN,(-BGV+/9A2#8L=F%V+(@.B`E<P#8KMBWV*<@V*C8IR#9OMN,
MV+K8I]F%(-F&V*?9A=F'V90@V*?9A-JIV*K8L=F(V8;;C-JIVXP`V+G8JMN,
MV8+9AP#8I]BQV8C9OMBG`-F'V+$@V;[8I]F&V++8K]F'(-BOV8+;C-F"V8<`
MV8?8L2#8K]F((-BOV8+;C-F"V8<`V8?8L2#8L]N,(-BOV8+;C-F"V8<`V8?8
ML2#9OMF&V*P@V*_9@MN,V8+9AP#8K]BQ(-F'V+$@V8C8L=F(V*\`V8?8L2#9
MAMN,V84@V+/8I]BYV*H`V8?8L2#8K]F"VXS9@MF'`-F%V8+8I]BOVXS8L2#9
MA=BKV*?9A#H`V*?8K-BQV*<`V*C8I]BR(-JIV+'8K]F&`-BHV*?8LMJIV+'8
MK]F&(-F&V8C8I]BQ(-JIV8;8I]BQVXP`V*?9AMBJV+C8I]BQ(-BHV+'8I]N,
M("<H)P#8JMBGV+';C-BN(-BGV8;9@MBVV*?8H0#9AMF%V*?;C-F&V*_9AP#8
ML=F&VJ\@V;[;C-BTXH",V++9A=N,V8;9AP!&5%`@=7!L;V%D(&]F('-E='5P
M`"#8J-BGV++;C-BGV*C;C"#8JMF"V*_9A=BGV*H@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO`"#8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8I]BR($Q$05`@V8;8
MI]F%V8C9@=F1V8(@V*C9B-BO`"#8I]BJV+78I]F$(-BHV8<@VJG8I]BQV+/8
MI]BR(%--0B#9AMBGV879B-F!V9'9@B#8J-F(V*\@`"#8JMF'VXS9AR#8L=F(
MV8;9B-BTV*H@V*?8LB`B)7,B(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP#8I]N,
MV*S8I]BO(-BQV8C9AMF(V+38JB#8K]BQ("(E<R(@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO`"#8I]N,V*S8I]BO(-N,VJD@V*?8JMBUV*?9A"#8K-BOVXS8KR!3
M05-,(-F&V*?9A=F(V8'9D=F"(-BHV8C8KP`@V*?9AMBJV8+8I]F$(-BHV8<@
M(B5S(B#9AMBGV879B-F!V9'9@B#8J-F(V*\`V838M]N,V8$`V*[8M]BGVXP@
MV*S8K]N,.B``V8':J=BS`-F!V8C8L=N,V8<`V+':K]BHV*?8L2#8KMF!VXS9
M@0#:J=F%VXP@V*K:K]BQVJ\`V+39A=BGV+'8M"#9OMBQV8C9AMBOV8<Z("5S
M(-F^V+'9B-F&V*_9AP#8M-F%V*?8L=BT(-F^V+'9B-F&V*_9ASH@)7,@V;[8
ML=F(V8;8K]F'`-F%V*_;C-BQ(-F^V+'9B-F&V*_9AP#9AMBGV84@V;[8L=F(
MV8;8K]F'`-BGV8;8JMBNV*?8J"#9OMBQV8C9AMBOV8<`V*?8L=BSV*?9A"#9
MOMBQV8C9AMBOV8<`V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@V;[8M-BJVXS8
MJ-BGV8;;C"#9AMF%VXSB@(S8M-F(V*\N+@#9@=N,V838JMBQV8?8IP#9AMN,
MV879AR#8I]F(V80`V+'8J-BY(-BGV8C9A`#9AMBSV*C8JB#8J]BGV*C8J@#8
MI]BYV+38I]BQVXP`V879A^*`C-BBV839B-BO`-F^V8C8M-F'("5S(-F%V8C8
MK-F(V*\@V8;;C-BSV*H@`-BQV8;:KR#9@MF$V84`V+K8L-BG`-BHV+'8I]N,
M(-F%V+'9B-BQVJ_8L=F'V*?;C-N,(-JIV8<@V*K8M=BGV8C;C-BQ(-BQV*<@
MV;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:J=F&V8;8KP#9OMN,V+3"K=BH
MVXS9AMN,`-BGV+/9A2#8L=F%V+(@V*[9B-BO(-BQV*<@V8'8L=BGV879B-BT
M(-JIV+'8K]F'XH",V*?B@(S;C-BOV)\`V8'8L=F%V8?8IP#8M]BGV838N0#9
MAMF(V+D@V+?8I]F$V+D`V+?8I]F$V+G9A]BG`-BWV*?9A-BYV8?8IR#;L@#8
MI]F&V*S9A=F&V8?8IP#8I]BQV*S8I]BYV8?8IP#8K-F%V+G9AP#:AMBGV+':
MAMF(V*C9A]BG`-BGV+(`V*?8LB``V+38L=BM(-JIV*?9A=F$`-F%V*?9AR#:
MJ=BGV879A`#9AMBGV84@VJG8I]F%V80`VJ_8I]F$V+';C"#8J-BQV*?;C"#8
MK]BQVXS8I]F!V*H@V*K8M=F(VXS8L2``VJ_8I]F$V+';C#H`V*K9B-F$VXS8
MKR#9OMN,VJG8L=BHV8;8K]N,("5S`-JIV*\@V*K9B-F$VXS8KR#8M-BOV8<`
MV8;8I]F%(-BOV*?8K]F'(-BTV*_9AP#8J-BQV8@`V*S8L]F&V*S9B-N,(-JO
MV8C:K]F$`-BOV+'8K-F'(-BNV*?:J=BSV*K8L=N,`$=R965K("A)4T\M.#@U
M.2TW*0#8L]BQV;[8L=BSV*K;C"#:K]BQV8C9AP#9AMBGV84@VJ_8L=F(V8<@
MV8;8J-BGVXS8KR#8KMBGV83;C"#8J-BGV+38KP#:K]BQV8C9AR8C>#(P,&,[
MV8?8IP#9A=BLV8C8LMF'V*?;C"#9A=F'V878I]F&`-JIV*K8I]BHVH;9A]F4
M(-N,V*?8K]BHV8C8KP!(5$U,`$A434Q!<F5A(-BMV+#9@2#8HMBNV+';C-F&
M(-BSV839B-F$(-BQV*<@V*_8L2#8L=BOVXS9@2#8L=BO(-F%VXSB@(S:J=F&
MV*\`2%1-3$%R96$@V*W8L-F!(-BBV*[8L=N,V88@V+/8JMF(V88@V+'8IR#8
MK]BQ(-BLV*_9B-F$(-BQV*\@V87;C.*`C-JIV8;8KP!(5$U,07)E82#8K=BP
MV8$@V*+8KMBQVXS9AB#8L=BOVXS9@2#8L=BG(-BOV+$@V*S8K]F(V80@V+'8
MKR#9A=N,XH",VJG9AMBO`-BJV+78K]N,V8(@V8?9B-N,V9'8JB!(5%10(-N,
MV*?9@=BJV8<@V8;8M-BO`-BGV83:K]F(V+';C-BJV84@2&%S:`#9A=F'XH",
MV*+9A-F(V*\`V+/8L=BBV878KP!(96)R97<@*$E33RTX.#4Y+3@M22D`V*C9
MA-F&V*_;C`#8L=BGV8?9AMF%V*<`V+'8I]F'V8;9A=BGVXP@V*?8L]BJV8'8
MI]BOV8<@V*?8LB#9B-N,V+'8I]N,V+3:K]BQ`-JIV87:J2#:J=F&V8;8K]F'
M`-F&VXS9A>*`C-JIV+'9AP#8I]N,V8;8K-BG(-BGV*C8JMBOV*?;C"#9OMBQ
MV8C9AMBOV8?B@(P@V87;C.*`C-BHV*?8M-BO.@#8J-BGV838IP#8KMBGV8;9
MAP#8KMBGV8;9AP#8HMBOV+'8LR#8KMBGV8;9AP#8M-BGV*[9A]F4(-BGV+79
MA-N,`-BTV878I]BQV8<@V*K9A-F!V88@V879AMBRV80`V8?9B-BQV*\`2&]R
M9&4O2V]L86(Z("5S(-BHV*<@V*_8I]BOV8<@V8;8I]BOV+'8L]BJ(%A-3"#8
MK]BQ(-F^VXS8NMBGV84@)7,@V879B-BGV*S9AR#8M-BOV8<@V*?8L]BJ`$AO
M<F1E+TMO;&%B.B#9A]N,VH8@V;[;C-BZV*?9A=N,(-F%V+?8I]BHV8+8JB#8
MJ-BG(-BTVXS8H2`E<R#9AMBOV*?8L=BO`$AO<F1E+TMO;&%B.B#9A]N,VH8@
MV+3;C-BFVXP@V*?8LB#9AMF(V+D@)7,@V*_8L2#9OMN,V+K8I]F%("5S(-N,
MV*?9@=BJ(-F&V+38KP!(;W)D92]+;VQA8CH@V*C8IR#9A=F(V8'9D=F"VXS9
MD=BJ("5S("(E<R(@V*W8L-F!(-BTV*\`2&]R9&4O2V]L86(Z(-BJV8C9A-N,
MV*\@VXS:J2#8K]BQV*[8JB#8K-BOVXS8KR!834P@V*C8L=BGVXP@V+3;C-BA
M("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO<F1E+TMO;&%B.B#8K=BPV8$@
M)7,@(B5S(CHE<R#9A=F"V*_9B-BQ(-F&VXS8L]BJ`$AO<F1E+TMO;&%B.B#8
MJ-BGV++;C-BGV*C;C"`@34E-12!)1"#8J-BQV*?;C"#9@MBSV878JMN,(-BG
MV+(@V8;9B-BY("5S(-F%V8+8K]F(V+$@V8;;C-BSV*H@`$AO<F1E+TMO;&%B
M.B#8L]F&VJG8L=F(V88@VJG8L=BOV88@)7,@(B5S(CH@)7,@V879@MBOV8C8
ML2#9AMN,V+/8J@!(;W)D92]+;VQA8CH@V+/9AMJIV+'9B-F&(-JIV+'8K]F&
M(-BGV+38JMBQV*?:J=F'V*<@V879@MBOV8C8L2#9AMN,V+/8JCH@)7,`2&]R
M9&4O2V]L86(Z(-BGV+38JMBQV*?:J2#9AMBGV+39AMBGV*[8JMF'("(E<R(`
MV8+8I]F&V8C9AB#8I]F!V8+;C`#9@=BGV+79A-F'XH",VJ_8L-BGV+';C"#8
MI]F!V8+;C``ZV*?9@=F"VXP`VH;:K]F(V8;9AR#8J-BG(-BGVXS9AMBLV*<@
MV*+8M-F&V*<@V+38K]N,V*_8GR`HV838M]F!V*?9BR#:K]BRV*?8L=BT(-BO
MV8?;C-BO*2$`VH;9AMBO(-BSV*K9B-F&(-BQV*<@V87;C.*`C-BNV8C8I]F'
MVXS8KR#8I]BOV+K8I]F%(-JIV8;;C-BOV)\`VH;9AMBO(-F!VXS9A-BO("C8
ML]BJV8C9ABD@V8C8K-F(V*\@V*_8I]BQV*_8GP#:AMF&V*\@V+/8M]BQ(-BQ
MV*<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]BOV+K8I]F%(-JIV8;;C-BOV)\`
MV+'8M]F(V*C8J@#8L=BWV8C8J-BJ.B``V*?;C-BLV*?8KR#9AMBGV879A^*`
MC-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KSH@("5S`-BMV+#9
M@2#9AMBGV879A^*`C-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8
MKR`Z("5S`-BGVXS8K-BGV*\@V878K=BOV8C8K]N,V9'8JB#9AMBGV879A^*`
MC-BOV*?9AB!)34%0(-F&V*?9A=F(V8'9D=F"(-BHV8C8KR`Z("5S`-BBV*_8
ML=BS($E0`-BBV*_8L=BS($E0(-F"V*?8J-F$(-BOV+/8JMBQV+/;C"#9AMN,
MV+/8J@#8HMBOV+'8LR!)4"#8K]BQ(-BOV*?8KMF$(-BHV839B-JI($-)1%(@
MV*?8K-BGV++9AR#8K]BGV*_9AR#9AMF%VXSB@(S8M-F(V*\`V*?8J-BJV*_8
MIR#8L]BWV+$@V+'8IR#9B-BGV+'8KR#:J=F&VXS8KP#9@=F"V+<@V*+;C-JI
MV8C9AMF'V*<`V*+;C-JIV8C9AMF'V*<@V*C8L=BGVXP@)7,`V*+;C-JIV8C9
MAMF'V*<@V*C8IR#9A=BJV88`V8;8I]F%(-F'V8C;C-F1V*HZ`-BGVJ_8L2#8
MHMF&(-BHV8<@V*_8L=BSV*K;C"#9AMF%V*?;C-BT(-BOV*?8K]F'(-F&V+38
MK]B,("5S("#8J-BQV*?;C"#8J-BGV+(@VJG8L=BOV88@V*+9AB#8K]BQ(-N,
MVJD@V;[9AMBLV+'9AR#8K-BOVXS8KP#8I]JOV+$@V+39A=BG(-F'VXS:AB#8
MHMN,VJG9B-F&VXP@V+'8IR#8K]BQ(-F%V+'9B-BQVJ_8L2#9AMBHVXS9AMN,
MV*_8C"#9A=F%VJG9AB#8I]BSV*H@V838I]BRV84@V*C8I]BTV*\@VJG9AR!0
M3D<@5')A;G-P87)E;F-Y(-BQV*<@V*[8I]F%V8C8M"#:J=F&VXS8KP#8I]JO
MV+$@V+39A=BG(-BGVXS9AB#9OMN,V+K8I]F%(-BQV*<@V878M-BGV8?8K]F'
M(-JIV8;;C-BO(-BGV878IR#8JMBUV8C;C-BQVXP@V+'8IR#9A=BTV*?9A]BO
MV8<@V8;:J=F&VXS8K]B,(-BGVXS9AB#8J-F'(-BGVXS9AB#8N=F$V*H@V*[9
MB-BGV8?8KR#8J-F(V*\@VJG9AR#9A=BQV8C8L=JOV+$@V+39A=BG(-F!V*?8
MK]BQ(-BHV8<@V8;9A=BGVXS8M"#8JMBUV8C;C-BQ(-F&VXS8L]BJ(`#9OMN,
MV+3B@(S9AMF%V*?;C"#8JMBUV8C;C-BQ.@!54DP@V*K8M=F(VXS8L0!54DP@
MV*K8M=F(VXS8L3H`V*K8M=F(VXS8L2#8I]BR(-JOV*?9A-BQVXP`V*K8M=F(
MVXS8L2#8I]BR(-JOV*?9A-BQVXPZ`-BGV+'8L]BGV80@V*K8M=F(VXS8L0#8
MJMBUV*?9B-N,V+$`V*_8L=F(V8;B@(S8J-BQV*_8C"#:K]BGV84@)60`V8';
MC-F$V*\@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'.B`E<P#9@=N,V838K^*`
MC-F'V*?;C"#8K]BQV8C9AN*`C-BHV+'8KR#8M-BOV8<Z`-BHV+G8K]BGV8L@
MV+/8M]BQ(-BQV*<@V8C8I]BQV*\@VJG9AMN,V*\`VJG8KR#8N=F%V83:J=BQ
MV*\@V8;8I]BOV+'8L]BJ(-BOV*?8K]F'(-BTV*_9AR#8I]BSV*H`(-F&V*?9
MA2#:J=BGV+'8J-BQ+]BGV+/9A2#8L=F%V+(@(-F&V*?8K]BQV+/8JB#8I]BS
MV*H`V8;8I]F%(-JIV*?8L=BHV+$@VXS8IR#8HMBOV+'8LR#8K-BGVXS:K]BR
MVXS9AB#9AMBGV*_8L=BSV*H@V87;C.*`C-BHV*?8M-BO+B#9A-BWV8'8IR#9
MA=BLV*_8K]BGV9(@V+/8N=N,(-JIV8;;C-BO(-F((-N,V*<@V*_8L2#8M=F(
MV+'8JB#9AMN,V*?8LB#8J-F'(-JIV87:J2#8J-N,V+38JMBQ(-BHV*<@V+/8
ML=F^V+'8L]BJ(-BSV*?9A=BGV8;9AR#8JMF%V*?8LR#8J-JOVXS8L=N,V*\`
MV*?9@=BRV*?;C-BT(-BJV8C8L=F!V*K:K]N,`-JIV*?8L=BHV+'8I]F&(-BN
MV*?8M0#8I]BWV838I]BYV*?8J@#8I]BWV838I]BYV*?8J@#8I]BWV838I]BY
MV*?8JB#8K]N,VJ_8L2#8K]BQ(-BOV+/8JMBQV+,@V8;;C-BSV*H`V*_8L=BL
M(-BSV*K9B-F&(-BHV+G8KR#8I]BR`-BOV+'8K"#8JMBUV8C;C-BQ`-BOV+'8
MK"#8K-BOV8C9A`#8K]BQV*P@V;[;C-F(V8;8KR#9B-BH`-BGV*C8JMBOV*<@
MV+/8JMF(V88@V+'8IR#8K]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BJV8C9AB#8
MK-BOVXS8KR#8J-BYV*\@V*?8LB#8L]BJV8C9AB#9@=BYV83;C"#8K]BQV*P@
MVJG9AMN,V*\`VXS:J2#8L]BJV8C9AB#8K-BOVXS8KR#9@MBHV80@V*?8LB#8
ML]BJV8C9AB#9@=BYV83;C"#8K]BQV*P@VJG9AMN,V*\`VXS:J2#8L]BWV+$@
MV*S8K]N,V*\@V*C8N=BO(-BGV+(@V+/8M]BQ(-F!V+G9A-N,(-BOV+'8K"#:
MJ=F&VXS8KP#;C-JI(-BSV+?8L2#8K-BOVXS8KR#9@MBHV80@V*?8LB#8L]BW
MV+$@V8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-N,VJD@V;[8I]BQV*?:K]BQ
MV*?9@2#8J-BYV*\@V*?8LB#:K]BQV8<@V8'8N=F$VXP@V*_8L=BL(-JIV8;;
MC-BO`-N,VJD@V;[8I]BQV*?:K]BQV*?9@2#9@MBHV80@V*?8LB#:K]BQV8<@
MV8'8N=F$VXP@V*_8L=BL(-JIV8;;C-BO`-BOV+'8K"#8I]F$VJ_9B-N,(-BL
MV*?;C-JOV++;C-F&`-N,VJD@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJV+'9
MB-F&VXS:J2#8J-BQV*?;C"#8K]BQVXS8I]F!V*H@V*?8L]F%(-BQV878LB`@
MV*S8K]N,V*\@V*_8L=BL(-JIV8;;C-BO(`#8K]BQV*P@V+/9A-F(V80@V*C8
MN=BO`-BOV+'8K"#8L]F$V8C9A"#9@MBHV80`V*_8L=BL(-BSV*K9B-F&(-BH
MV+G8KP#8K]BQV*P@V+/8JMF(V88@V8+8J-F$`-BOV+'8K"#9OMN,V+K8I]F%
M`-BOV+'8K"#9OMBGV+'8I]JOV+'8I]F!(-BHV+G8KP#8K]BQV*P@V;[8I]BQ
MV*?:K]BQV*?9@2#9@MBHV80`V*_8L=BL(-BSV+?8L2#8J-BYV*\@`-BOV+'8
MK"#8L]BWV+$@V8+8J-F$`-F^V*?8L]BN(-F%V8C8L=BO(-F&VXS8I]BR(-BQ
MV*<@V*C8L=BGVXP@V+/8IMF(V*?9A"#8I]F%V8;;C-BJVXP@V*_8L=BL(-JI
MV8;;C-BO.@#8K]BQV*POV*K8NMN,VXS8L2#8JMBUV8C;C-BQ`-BOV+'8K"_8
MJMBZVXS;C-BQ(-F^VXS9B-F&V*\`V*?8N=BJV*C8I]BQ(-F&V*?:J=BGV8';
MC"#8J-BQV*?;C"#8I]BQV+/8I]F$(-BHV8<@V8'9A]BQV+/8JB#8JMF(V++;
MC-BYVXP`V*?8N=BJV*C8I]BQ(-F&V*?:J=BGV8';C`#8N=BOV*\@V+78K=N,
MV*T`V8'9A]BQV+/8JB#8N=BOV*\@V+78K=N,V*T`541((-F&V*?9A=BYV*K8
MJ-BQ`-BHV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-F&V*?9A=BYV*K8
MJ-BQ`-BOV+/8JMF'($E$(-F&V*?9A=BYV*K8J-BQ`-BOV*?8K]F'V90@V8;8
MI]F%V+G8JMBHV+$@V*?8L=BGV*;9AR#8M-BOV8<`V*+8K]BQV+,@V879@MBU
MV*\@V8;8I]F%V+G8JMBHV+$`V8+8I]F$V*@@V;[8L=F(V8;8K]F'V90@V8;8
MI]F%V+G8JMBHV+$`V8;9B-BY(-F^VXS8NMBGV84@V8;8I]F%V+G8JMBHV+$`
M87!I7VED(-F&V*?9A=BYV*K8J-BQ(-BGV+/8JB#9B"#;C-BG(-BGV+(@V*C;
MC-F&(-BQV8'8JMF'(-BGV+/8J@#9OMBGV+'8I]F%V*K8L2#9AMBGV878N=BJ
MV*C8L2#9B"#;C-BG(-BGV+(@V*C;C-F&(-BQV8'8JMF'`-F%V*S9B-BR(-F^
MV*_8L2#9AMBGV878N=BJV*C8L0#9OMBQV8C8JMJIV80@V8;8I]F%V+G8JMBH
MV+$`VJ_;C-BQV8;8K]F'V90@V8;8I]F%V+G8JMBHV+$Z("(E<R(`V+3;C-BA
M(-BHV8<@V*?8M-BJV+'8I]JI(-JOV+#8I]BTV*K9AR#8M-BOV8?9E"#9AMBG
MV878N=BJV*C8L0#8HMBOV+'8LR#8L]BQVH;8M-F%V8<@V8;8I]F%V+G8JMBH
MV+$`V*_8I]BOV8<@VXS9B-F&VXS:J=BO(-F&V*?9A=BYV*K8J-BQ(`#9A=F(
MV*S9B-BOVXP`V*C8L=JOV+'8K]BGV8;8K]F&(-BGV8;8JMBNV*?8J`!4+5-T
M;W)M<P#9A=F&V*K8M-BQ(-JIV8;9AMBOV8<`V*W8L=F(V8$@VJG8K`#:F-BG
MV8;9B-N,V8<`2F%P86YE<V4@*$E33RTR,#(R+4I0*0#8LMN,V+'9OMN,V+'8
MI]F'V8;;C`#:F-F(V*;;C-F'`-J8V8C8IMF&`-F'V87B@(S8JMBQV*?8LB#:
MJ=BQV*_9A@#9A]F%XH",V*K8L=BGV++;C"#9B-BSV+<`V8?9A>*`C-BJV+'8
MI]BRVXP@VJG8I]F%V80`V8?9A>*`C-BJV+'8I]BRVXP@VH;9O@#9A]F%XH",
MV*K8L=BGV++;C"#8L=BGV+/8JB``V*?8M=F$VXP@V8;:K]F'(-BOV*?8M-BJ
MV8<@V+39B-BOV)\`VJG8I]BQV+/8I]BR(&ME<F)E<F]S92#8JMBUV*_;C-F"
M(-F'V8C;C-F1V*H@V+'8IR#8L=BO(-JIV+'8KP#8I]N,V*S8I]BO(-JIV83;
MC-BO`-BGV*O8L2#8I]F&VJ_8M-BJ(-JIV83;C-BO`-BWV8C9A"#:J=F$VXS8
MKP#9AMF(V+D@VJG9A-N,V*\`VJG8I]BQV*C8L=BO(-JIV83;C-BO`-JIV83;
MC-BO(-F"V*C9A-BGV8L@V*_8L2#:J=BGV+'8L]BGV+(@V+G9A=F(V87;C"#:
MJ=F$VXS8KR#9A=F(V*S9B-BO(-BGV+/8J@#B@(S8J-J&V8?B@(S9A]BG`$MO
M<F5A;B`H155#+4M2*0#8K-BGV8;9A=BGVXS;C`#8LMBHV*?9A@#9AMN,V879
MA]F4(-BBV*[8L0#8JMBZVXS;C-BQ(-BBV*[8L=N,V88@V*?8L]F%(-BQV878
ML@#8L=BHV+D@V*+8KMBQ`-BBV*[8L=N,V88@V*C8L=F(V++8L=BSV*?9AMN,
M.@#8HMBNV+';C-F&(-F(V+'9B-BO.B`E<P#8HMBNV+';C-F&(-F(V+'9B-BO
M(#H@)7,@V*?8LB`E<P#8HMBNV+';C-F&(-F(V+'9B-BO.B#9A]BQVJ_8L@#8
MK=F"V8C9@@#8K-BGV8;9A=BGVXS;C`#:AMF^`-BSV+'8HMF%V*\@VH;9O@#9
MA=F"V*?8K]N,V+$@VH;9O@#9AMF%XH",V8;9A2#8J-BGV+'8I]F&`-BHV*?8
ML=F&V*_:K]N,(-BSV*C:J0#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V++9B-BO
MV8?9AMJOV*?9A0#8J-BGV+'9AMBOVJ_;C"#8L]BHVJD@V*_;C-BQV8?9AMJO
MV*?9A0#8J-BGV+'9AMBOVJ_;C"#9B"#8L=JOV*C8I]BQ(-BSV*C:J0#8J-BG
MV+'8I]F&(-BSV*C:J2#8J-F'(-F'V878L=BGV8<@V+'8N=BO`-BHV+'9@2#8
ML]BHVJD`V*C8L=F!(-F((-BQVJ_8J-BGV+$@V+/8J-JI`-F^VXS9B-F&V*\`
MV8;9@MBGV+<@V;[;C-F(V8;8KR#8J-F'.@#8HMBOV+'8LR#9OMBSV*H@V*?9
MA-JIV*K8L=F(V8;;C-JI(-BQV*<@V*C9AR#8M=F!V*W9AR#8I]N,V*S8I]BO
M(-F^VXS8NMBGV878C"#8J-F'(-F'V8;:K]BGV84@V878M-BGV8?8K]F'V(P@
MV;[;C-F(V8;8KR#8K]F'VXS8KP#9OMN,V8C9AMBOXH",V8?8IP#:J=F(VJG;
MC"#9A-N,V8;9B-JIV+,`V8'9A]BQV+/8JB`M(-JIV*?8L=BHV+$@V87;C.*`
MC-BJV8C8I]F&V*\@V;[9B-BTV8<@V+'8IR#8J-BHVXS9AMBO`-F!V8?8L=BS
MV*H@V*_8I]BOVJ_8I]F&V8?8I^*`C`#9@=F'V+'8L]BJ(-BYV8;8I]F(VXS9
MAB#8L=BGV8?9AMF%V*<`V8'9A]BQV+/8JB#8K-BOV*?9B-F$`-F!V8?8L=BS
MV*H@V*+8L=BTVXS9B`#9@=F'V+'8L]BJ(-BQV*?9A]F&V878IP#9@=F'V+'8
ML]BJ($ED`-F!V8?8L=BSV*H@V878I]F$VJD`V8'9A]BQV+/8JB#9OMBSV*K;
MC`#9@=F'V+'8L]BJ(-BYV+;9B-N,V9'8J@#9@=F'V+'8L]BJ(-BYV*_9A2#8
MN=BVV8C;C-F1V*H`V8'9A]BQV+/8JB#:J=BGV+'8J-BQV*?9AB#9@=BYV*?9
MA"#9AMF%VXSB@(S8J-BGV+38KP#8I]BOV*C;C-BGV*H`V*C8I]BQVJG8L=BO
MV88N+BX`V+/8I]BYV*H@V878K=F$VXPZ(`#9A=BMV83;C-F1V*H@V8@@V+/8
MI]BYV*H`V879B-F"V+G;C-BJ`-F(V+'9B-BO`-BNV+'9B-BL`-F(V+'9B-BO
M`-F(V+C8I]N,V8$@V8C8L=F(V*\`V8C8L=F(V*\@V8;8I]F%V8C9@=F1V8(@
MV*C9B-BO(-BRVXS8L=BG(-F&V*?9A2#:J=BGV+'8J-BQ(-F((-N,V*<@V*?8
ML]F%(-BQV878LB#9B-BGV+'8KR#8M-BOV8<@V*?8M-BJV*C8I]F'(-BHV8C8
MKR``V8C8L=F(V*\@V8;8I]F%V8C9@=F1V8(@V*C9B-BO+@#9A=BJV88@V*C9
MA-F&V*\`V+G8M-F"`-F^V*?;C-N,V88`V*W8L=F(V8$@VJG9B-J&VJD@VXS9
MB-F&V*?9AMN,`-BMV+'9B-F!(-JIV8C:AMJI(-F$V*?8JMN,V88`V*?8N=BO
MV*?8KR#:J=F(VH;:J2#;C-F(V8;8I]F&VXP`34T`V;[;C-BZV*?9A2#8L=F(
MV+(`V;[;C-F(V+/8JB!-4RU43D5&(-BTV*?9A=F$(-F'VXS:AB#8K]BGV*_9
MA^*`C-BGXH",VXS;C"#9AMN,V+/8J@!-4T<`V*S8I]BOV8@`V8;8I]F%V8<@
MV*?9A-JIV*K8L=F(V8;;C-JIVXP`V+/8L=F^V+'8L]BJ(-F&V*?9A=F'`-BS
MV*?8KMBJV88@V;[;C-F(V8;8KRXN+@#9A=BOVXS8L=N,V*H@V8@@V*K8N=N,
MVXS9AB#8L=F&VJ\@V*_8L]BJV8?B@(S9A]BGVXS;C"#:J=F'(-BTV878IR#9
MA=F(V*?8L=BO(-BQV*<@V*C8IR#8HMF&V8?8IR#9AMBGV87B@(S:K]BPV*?8
ML=N,(-F%VXSB@(S:J=F&VXS8KP!-87`R-"!M87``36%P475E<W0@;6%P`-F%
MV*?8L=BS`-BMV*?8M-N,V8<`V+G9A-BGV878JB#:K]BPV*?8L=N,(-BHV*<@
MV;[8L=J&V84@V878M-BGV8?8K]F'(-BTV*_9AR\@V878M-BGV8?8K]F'(-F&
MV+38K]F'`"#8N=F$V*?9A=BJ(-JOV+#8I]BQVXP@V*C8IR#8N=F$V*?8IMF%
M(-BOVXS:K]BQ("C9A=BGV8;9AMBO(-F%V8?9A2_9OMBGV+/8KB#8K]BGV*_9
MAR#8M-BOV8<I`-F!VXS9A-BOXH",V8?8I]N,(-BGV8;8M]BHV*?9@@#8J-N,
MV+3;C-F&V8<@V*?8N=BJV*C8I]BQ(-F%V*S8I]BR`-BJV*[8M]N,(-BGV+(@
MV*C;C-BTVXS9AMF'(-F"V+/9A=BJV8?8I]N,(-F^VXS8NMBGV84`V*C;C-BT
MVXS9AMF'(-BOV878IR#8K]BQ(-NRV[0@V+/8I]BYV*H@VJ_8L-BTV*K9ASH@
M`-BHVXS8M-N,V8;9AR#8K]F%V*<@V*_8L2#;MB#8L]BGV+G8JB#:K]BPV+38
MJMF'.B``V*C;C-BTVXS9AMF'(-BWV8C9A`#9A=N,`-F^V++8M-JIVXP`V*?8
MN=BVV*?8H0#9A=BO(-JOV++;C-F&VJ_8I]F&VXPZ`-BGV*_8NMBGV84@V+/9
MA-F(V839A]BG`-F^VXS8NMBGV84`V;[;C-BZV*?9A2#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*C8I]BRV*C;C-F&VXP@V+38KR#8I]F%V*<@VJ_9B-BGV8?;
MC"#8I]F%V+;8I]BA(-JIV8;9AMBOV8<@V8;9A=N,XH",V*K9B-BGV8;8KR#8
MJ-BGV++8J-N,V8;;C"#8M-F(V*\`V;[;C-BZV*?9A2#9A=F&V8+8MMN,(-BT
MV*\`V8;9B-BY(-F^VXS8NMBGV84`V*+8J"#9B"#9A]F(V*?;C"!-971A<@#8
MJ-F$V8C:J2!-971A<B#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ`-BH
MV839B-JI($UE=&%R(-F"V*?8J-F$(-BOV+/8JMBQV+,@V8;;C-BSV*HN(-BL
MV++8IMN,V*?8JB#8J-BQV*?;C"#8L]BQV;[8L=BSV*H@V+/8I]F%V*?9AMF'
M(-BKV*C8JB#8M-BOV8<@V*?8L]BJ`-BQV8C8M`#8I]F&V*_8I]BRV8?B@(S8
MI]N,`-F(V+/8MP#9AMF(V+D@36EM90`@VJG9A=N,V8;9AR#8K]F%V*?;C"#;
MLMNT(-BSV*?8N=BJ(-JOV+#8M-BJV8<Z(``@VJG9A=N,V8;9AR#8K]F%V*?;
MC"#;MB#8L]BGV+G8JB#:K]BPV+38JMF'.B``V*+;C-F&V8<`V878JMF!V+'9
M@MF'`-F^VXS:J=BQV*C9AMBOVXP@V879B-BLV8C8KR#9AMN,V+/8JBX@V+39
MA=BG(-BGVJ_8L2#9A=N,XH",V*[9B-BGV8?;C-BO(-BGV+(@V*?;C-F&(-BH
MV+'9AMBGV879A]F4(-JIV*?8L=BHV+'8K]N,(-BGV+/8JMF!V*?8K]F'(-JI
MV8;;C-BO(-BHV*?;C-BO(-BBV8;8L=BG(-BJV8C9A-N,V*\@VJG9AMN,V*\`
MV*?8LB#8J-N,V88@V+'9@=BJV88@240@V;[;C-BZV*?9A0#8I]BR(-BHVXS9
MAB#8L=F!V*K9AB!)1"#9AMBTV+/8JB``V*_9B-BTV8;8J-F'`-F^V+/8JB#8
ML]F$V8C9A-N,`-F%V+G8JMBOV80@VJG8L=BOV88`V*K8I]BQVXS8KB#8JMBZ
MVXS;C-BQ(-N,V*?9@=BJV8<`V*K8NMN,VXS8L2!54DP`V878I]F'(-F((-BS
MV*?9A`#9A=BGV8?8I]F&V8<`V8'8I]BRV8?8I]N,(-F%V*?9AP#8J-N,V+38
MJMBQ(-BUV*?9@0#8J-N,V+38JMBQ(-BGV*C8L=N,`-BHVXS8M-BJV+$@V*+9
M@=BJV*?8J-N,`-BGV8;8JMF"V*?9A"#8J-F'(-F^V*?;C-N,V88`V*?9AMBJ
MV8+8I]F$(-BHV8<@V*C8I]F$V*<`V*?9AMBJV8+8I]F$(-BHV8<@V+'8I]BS
MV*H`V*?9AMBJV8+8I]F$(-BHV8<@V*C8I]F$V*<`V*?9AMBJV8+8I]F$(-BH
MV8<@V;[8I]N,VXS9A@#8I]F&V*K9@MBGV80@V*C9AR#8J-BGV838IP#9@=F'
MV+'8L]BJ(-F^V*?;C-N,V8;B@(S9OMBQ(-J&V8;8KR#8L]BWV*W;C`#:AMF&
MV*\@V*?9AMBJV*[8I]BHVXP`V*W8L]BGV*@@V879A@#8I]BWV838I]BYV*?8
MJB#8K=BSV*?8J"#9A=F&`-BOV+':K]BGV8<@V879A@#8K-BGV8;9A=BGVXS;
MC"#8K]BQVJ_8I]F'(-F%V88`V8;9A]B,(-F%V88@V879B-BGV8'9@B#9AMN,
MV+/8JMF%`-F&V*?9A0!54DP@V;[8I]N,V8<@3F5T<V-A<&4`3F5T<V-A<&4@
M0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S
M8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`#8JMF(
MV+;;C-BM(-JOV8C8I]F'VXP@3F5T<V-A<&4`V8;9B-BY(-JOV8C8I]F'VXP@
M3F5T<V-A<&4`V+38J-JIV8<`V8?8L=JOV+(`V*_8L]BJV8<@V*S8K]N,V*\`
MV878I]F'(-F&V8@`V8;8I]F%(-JIV*?8L=BHV+';C"#8K-BOVXS8KR`HV*?8
MKMBJVXS8I]BQVXPI`-BGV+/9A2#8L=F%V+(@V*S8K]N,V*\`V*?8L]F%(-BQ
MV878LB#9A-BZV8@@V*[9B-BGV8?8KR#8M-BO(-BOV+$@)7@@`-BGV+/9A2#8
ML=F%V++9A]BGVXP@V*S8K]N,V*\@V*K8M]BGV*C9@B#9AMBOV*?8L=BO`-F^
MV8;8K-BQV8<@V*S8K]N,V*\@*-BNV*?9A-N,*0#8I]BNV*C8I]BQ`-JOV+'9
MB-F'XH",V8?8I]N,(-BNV*C8L=N,`-BHV+G8K]N,`-JOV++;C-F&V8?B@(S9
MA]BGVXP@V*C8N=BOVXP`V+38J`#9AMF'`-BOV*?8K]F'(-F^VXS:J=BQV*C9
MAMBOVXP@V*_8L2#8K]BSV*K8L=BSVXP@V*C8L=BGVXP@V8;8M-BGV88@V*_8
MI]BOV88@V*K9@=BGV8C8JMF'V*<@V8C8K-F(V*\@V8;8K]BGV+'8KP!)4T\@
MV8;;C-BSV*H@V*?8L]BJV+'8I]BJVIC;C"#8K]BQ(-BOV+/8JMBQV+/;C"#8
MJ-BQV*?;C"#8L]BGV*[8JMF&(-BJV+79B-N,V+$@`-BGV83:K]F(VXP@V*_8
ML]BJV8?B@(S8I]N,VXP@V8;;C-BSV*H`V*C9A-BGVJG;C"#8K]BQ(-F%V8C9
M@MBYVXS8JB#8K]BQV*[9B-BGV+/8JB#8M-BOV8<@V879B-BLV8C8KR#9AMN,
MV+/8J@#9A]N,VH8@V8;8I]F%(-BJV8+9B-N,V87;C"#8J-BQV*?;C"#8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@34-!3"#9@=BQV*?9A]F%(-F&V+38K]F'(-BG
MV+/8J@#8J-BOV8C9AB#8JMBZVXS;C-BQ`-F'VXS:AB#9A=BLV8C8LB#9@=BQ
MV+G;C.*`C-BGVXP@V8;9A=N,XH",V*K9B-BGV8;8KR#8J-F'(-BGVXS9AB#9
MA=BLV8C8LB#8I]BVV*?9@=F'(-BTV8C8KP#9A]N,VH8@V*?8M]F$V*?8N=BG
MV*H@V;[;C-JIV+'8J-F&V*_;C"#8J-BQV*?;C"`E<R#9A=BTV*[8M2#9AMBT
MV*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8
ML=BGVXP@1E10(%9&4R#9A=BTV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+?9A-BG
MV+G8I]BJ(-F^VXS:J=BQV*C9AMBOVXP@V*C8L=BGVXP@4U%,(%9&4R#9A=BT
MV*[8M2#9AMBTV*\`V8?;C-J&(-BGV+?9A-BGV+G8I]BJ(-F^VXS:J=BQV*C9
MAMBOVXP@V*C8L=BGVXP@4U%,+49I;&4@5D93(-F%V+38KMBU(-F&V+38KP#9
MA]N,VH8@V*?8N=BJV*C8I]BQVXP@V*C8I]F"VXP@V8;9A=BGV8;8KP#9A]N,
MVH8@V879@MBUV*_;C"#9@=BQV*?9A]F%(-F&V+38KP#9A]N,VH8@V;[8L=F(
MV8;8K]F'XH",V*?;C-N,(-BGV+'8L]BGV80@V8;8M-BO`-F'VXS:AB#8HMN,
MVJG9B-F&VXSB@(P@V;[;C-BOV*<@V8;8M-BO`-F'VXS:AB#9A=JIV*?9AMN,
M(-BJV8;8N-N,V84@V8;8M-BOV8<`V8?;C-J&(-F^VXS8NMBGV87;C"#9@=BQ
MV*?9A]F%(-F&V+38KP#9A]N,VH8@V8;8I]F%VXP@V878M-BNV+4@V8;8M-BO
M`-F'VXS:AB#8M-F%V*?8L=F'XH",V*?B@(S;C-N,(-F%V+38KMBU(-F&V+38
MKP#8HMN,V8;8K]F'(-F&V*?9A=BWV*C9B-BYVXP@V8;;C-BSV*H`V*C8L=BG
MVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ($A45%`@V*?8L]F%(-BQV878LMN,
M(-F!V+'8I]F'V84@V8;8M-BOV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78K]N,
MV8(@V8?9B-N,V9'8JB!)34%0(-BGV+/9A2#8L=F%V++;C"#9@=BQV*?9A]F%
M(-F&V+38K]F'(-BGV+/8J@#8J-BQV*?;C"#8JMBUV*_;C-F"(-F'V8C;C-F1
MV*H@2V5R8F5R;W,@V*?8L]F%(-BQV878LMN,(-F!V+'8I]F'V84@V8;8M-BO
MV8<@V*?8L]BJ`-BHV+'8I]N,(-BJV+78K]N,V8(@V8?9B-N,V9'8JB#9B-BQ
MV8C8KR#8I]BSV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BS
MV*H`V*C8L=BGVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%!!4U-71"#8I]BS
MV84@V+'9A=BRVXP@V8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*C8L=BG
MVXP@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(%--0B#8I]BSV84@V+'9A=BRVXP@
MV8'8L=BGV8?9A2#9AMBTV*_9AR#8I]BSV*H`V*K9@MBGV+;8I]N,(-BKV*C8
MJB#9AMBGV87;C"#8K]BQ(-BGV8;8JMBXV*?8L2#8JMBCVXS;C-BO(-F&VXS8
ML]BJ`-BHV*_9B-F&(-F"V8C8I]BYV*\`V8?;C-J&(-BLV*_8I]JIV8;9AMBO
MV8?B@(S8I^*`C-N,VXP@V878M-BNV+4@V8;8M-BO`-BHV*_9B-F&(-BSV878
MJ@#8M-BGV*[9AR#9A=F(V8+8JMN,(-BHV+'8I]N,(-JIV*?8M-F'(-F%V8C8
MK-F(V*\@V8;;C-BSV*H`V8?;C-J&(-F&V*?9A2#:J=BGV+'8J-BQVXP@V8@@
MVXS8IR#8I]BSV84@V+'9A=BRVXP@V*?8L=BSV*?9A"#9AMBTV*\`V8?;C-J&
M(-BOV*?8K]F'(%A-3"#9A=BYV*K8J-BQVXP@V*C8I]BRVJ_8L=BOV*?9AMBO
MV8<@V8;8M-BOV8<@V*?8L]BJ`-BHV*_9B-F&(-F%V8+8K]BGV+$`V8;8L]BN
MV8?B@(P@V*_8L2#9OMN,VJG8L=BHV8;8K]N,(-BGV+79A-N,(-F^VXS8K]BG
M(-F&V+38KRX@V;[;C-JIV+'8J-F&V*_;C"#8L=BG(-BOV8C8J-BGV+'9AR#8
MJMF(V83;C-BO(-JIV8;;C-BO`-F&V+/8KMF'XH",(-BOV+$@V;[;C-JIV+'8
MJ-F&V*_;C"#8M-F%V*<@V;[;C-BOV*<@V8;8M-BOV8<@V*?8L]BJ+B#9OMN,
MVJG8L=BHV8;8K]N,(-BQV*<@V*_9B-BHV*?8L=F'(-BJV8C9A-N,V*\@VJG9
MAMN,V*\`V8?;C-J&XH",VJG8K]BGV84`V8?;C-J&XH",VJG8K]BGV84@*-BV
MV879AMN,(-BGV+/8JMF!V*?8K]F'(-JIV8;;C-BO*0!.;W)D:6,@*$E33RTX
M.#4Y+3$P*0#9AMN,V84@VJG8L=F'(-BTV878I]F$VXP`V8;9AR#8J-BYV*\`
MV8;9AR#9@MBHV80`VXS:J2#8M-BGV*[9AR#9AMN,V+/8J@#9OMN,V*?8K]F'
MXH",V+/8I]BRVXP@V8;8M-BOV8<`V*K9AMBXVXS9A2#9AMBTV*_9AP#9OMBT
MV*K;C-BHV*?9AMN,(-F&V+38K]F'`-N,V*?8K]BOV*?8M-BJV8?8IP#:AMN,
MV++;C"#8J-BQV*?;C"#9A=BQV8C8L2#9AMN,V+/8JMB,(-BHV8<@V+G9@MBH
M(-BHV+':K]BQV*\`V8;9B-BGV878J-BQ`-BYV*_8KP#8JMBYV*_8I]BO(-F&
MV8C;C-BSV8?B@(S9A]BG`-BJV+G8K]BGV*\@V+/8JMF(V8;9A]BG`-BJV+G8
MK]BGV*\@V+/8M]BQV8?8IP#8I]BYV*_8I]BO(-BHV+'8I]N,(-BHV+'9B-BR
MV+'8L]BGV8;;C"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#9A=BTV*[8M2#9
MAMBTV*_9AMBO`-BJV*/;C-N,V*\`V+3;C-BA`-BGVXS8K-BGV*\@VJG9AMF&
MV*_9AR#8M-N,V*$`V8?8M-BJV*?;C-N,`-BGVJG8JMBHV+$`V8';C-F$V*K8
ML2#8J-N,XH",V*W8L=F%V*K;C`#8K]F!V*K8L2#:J=BGV+$`V*?8L]F%(-BQ
MV878LB#8K-BOVXS8KR#9B"#8I]BSV84@V+'9A=BR(-F!V+G9A-N,(-BHV*?;
MC-BO(-F%V*K9@=BGV8C8JB#8J-BGV+39AMBO`-BGV+/9A2#8L=F%V+(@V8+8
MK]N,V87;C`#8I]BSV84@V+'9A=BR("#9@MBOVXS9A=N,(-F&V*?8K]BQV+/8
MJB#8I]BSV*H`V*K9AMF'V*<@VJG8I]BQV+/8I]BRV8?8I]N,($E-05#9OMF(
MV+39A^*`C-F'V*?;C"#9A=BTV*K8L=JI(-BQV*<@V;[8M-BJVXS8J-BGV8;;
MC"#9A=N,XH",VJG9AMF&V*\@`-F!V8+8MR#8HMN,V8;8K]F'(-F&V*?9A=BW
MV*C9B-BY`-BJV8;9A]BG(-N,VJD@V*+8K]BQV+,@V;[8L]BJ(-BGV83:J=BJ
MV+'9B-F&VXS:J=N,(-F%V*S8I]BR(-BGV+/8J@#8JMF&V8?8IR#9A=BGV83:
MJ2#;C-BG(-BSV+'9OMBQV+/8JB#8L]BGV878I]F&V8<@V87;C.*`C-BJV8C8
MI]F&V*\@V878I]F$VJG;C-BJ(-N,V*<@V878K-F(V++9A]BGVXP@V878I]F$
MVJD@V+'8IR#8J-BQV*?;C"#;C-JI(-BGV+38JMBQV*?:J2#8JMBZVXS;C-BQ
M(-BOV8?8KP#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8KR#8J-BGV+(@
MV+39B-BO`-BGVXS9AB#9OMN,V8C9AMBO(-BOV+$@VXS:J2#9OMF&V*S8L=F'
M(-BLV*_;C-BO(-BHV*?8LB#8M-F(V*\`V+/;C-BSV*K9A2#8N=BGV879A`#:
MK]BRVXS9AMF')B-X,C`P8SO9A]BG`-JOV++;C-F&V8?B@(S9A]BGVXP@)7,`
MV83;C-BSV*H@V878L=BJV*@@V+38K]F'`-BSV*?8LMF%V*?9A@#9B-BGV*W8
MKR#8L]BGV++9A=BGV8;;C`#8L]BGV++9A=BGV8;8K]F'VXP`V*?9A-JOV8C;
MC"#8I]BUV83;C"#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8J-BQV*_;C`#8I]F$
MVJ_9B-F'V*?;C"#8I]BUV83;C"#8K]BQ("5S.@#8K]N,VJ_8L0#8I]BWV838
MI]BYV*?8JB#8K]N,VJ_8L0#9A=BLV8C8LN*`C-F'V*?;C"#9A=BGV83:J0#8
MJMBUV*_;C-F"(-F'V8C;C-F1V*H@4$%-(-F"V*?8J-F$(-BOV+/8JMBQV+/;
MC"#9AMN,V+/8J@#8I]F%V+;8I]BAXH",(-BOVXS8K-N,V*K8I]F$VXP@4$=0
M`-F^VXS8NMBGV84@V+'9A=BRV*C9AMBOVXP@V+38K]F'V90@4$=0`"#:J=F$
MVXS8KR#8N=F%V8C9A=N,(%!'4`#9OMN,V+K8I]F%(-BQV878LMBHV8;8K]N,
M(-BTV*_9AR_8I]F%V+;8I]BA(-BTV*_9AR!01U``VJG8KR!02%``V;[9B-BS
MV*K9AR!02%``V*C8I]BQV8;8K]JOVXP@V+/8J-JI(-BYV+78L=JOV*?9A]N,
M`-BQVJ_8J-BGV+$@V+G8M=BQVJ_8I]F'VXP`V*C8L=F!(-BYV+78L=JOV*?9
MA]N,`-BJVJ_8L=JO(-BYV+78L=JOV*?9A]N,`%0M4W1O<FUS`-BHV+/8MR!0
M3U-)6"#8I]BR(-BHVXS9AB#8L=F!V*K9AR#B@(S8I]BSV*H`V;[9B-BSV*K9
MAR!02%``V8'8I]BUV839A^*`C-JOV+#8I]BQVXP`V8+8L]F%V*K;C"#8I]BH
MV+';C`#8I]BSV84@V+'9A=BR(`#8I]BSV84@V+'9A=BR(-BHV*<@V879B-F!
MV9'9@MN,V9'8JB#8JMBZVXS;C-BQ(-N,V*?9@=BJ+@#8I]BSV84@V+'9A=BR
M("#9AMBGV*_8L=BSV*H@V*?8L]BJ`-BGV+/9A2#8L=F%V+(@(-BHV8<@V*K8
MM=BOVXS9@B#9A]F(VXS9D=BJ(%)!1$E54R#9AMN,V*?8LB#8K]BGV+'8KP#8
MI]BSV84@V+'9A=BR("#8J-BG(-BJV*/;C-N,V*\`V*?8L]F%(-BQV878LB`Z
M`-BGV+/9A2#8L=F%V+(@.B``V*?8L]F%(-BQV878LN*`C-F'V*<@V*C8I]N,
MV*\@V879AMBWV*C9@B#8J-BGV+39AMBO`-J&V+/8J-BGV8;8K]F&`-J&V+/8
MJ-BGV8;8K]F&(-BGV+(@V*K8KMBJV8<@V+'8L]F%`-F%V+/;C-BQ`-BKV*C8
MJB#9AMBGV879A]BGVXP@V8;8I]F%V+G9A-F(V84`V878L=BOV84`V*_8L=BU
MV*\`V*?8K-BQV*?;C"#8N=F%V83;C-BGV*H@V8;:K]F'V*_8I]BQVXP`V*+;
MC-BG(-BYV879A-N,V*?8JB#9AMJOV8?8K]BGV+';C"#8K]BQ(-F$V*W8N-F'
M(-F(V+'9B-BO(-BGV*S8L=BG(-BTV8C8K]B?`-F%V*S9B-BR`-F%V*S9B-BR
M("`B)7,B(-BMV+#9@2#9AMBTV*\`V878K-F(V++9A]BG`-BSV+'9OMBQV+/8
MJMN,(-F%V*S9B-BRV8?8IP#8I]BWV838I]BYV*?8JB#8M-BNV+7;C`#8K=N,
MV8C8I]F&V*?8JB#8KMBGV8;:K]N,`-BJV839@=F&`-BYVJG8L]F'V*<`V;[;
MC-JIV+/9A-F'V*<`V838M]F!V*?9BR#8K]BGV*[9A"#:AMF&V*\@V+/9A-F(
MV80@VJG9A-N,VJD@VJG9AMN,V*\`V838M]F!V*?9BR#8JMBCVXS;C-BO(-JI
MV8;;C-BO(-JIV8<@V87;C.*`C-BNV8C8I]F'VXS8KR#8I]N,V88@V+G9AMBU
MV+$@V+'8IR#8K=BPV8$@VJG9AMN,V*\Z`-F$V+?9@=BGV8L@V*K8H]N,VXS8
MKR#:J=F&VXS8KR#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V;[;C-F(V8;8
MKR#8I]N,V88@V+G9AMBUV+'9A]BG(-BQV*<@V8+8M]BY(-JIV8;;C-BO`-F$
MV+?9@=BGV8L@VXS:J2#9A=BGV8<@V8@@VXS:J2#8L]BGV80@V8C8I]BQV*\@
MVJG9AMN,V*\N`-F$V+?9@=BGV8L@V8;8I]F%VXP@V*C8L=BGVXP@V*_8L]BJ
MV8<@V*S8K]N,V*\@V8C8I]BQV*\@VJG9AMN,V*\Z`-F$V+?9@=BGV8L@V*+8
MK]BQV+,@25`@V878N=BJV*C8L=N,(-F(V*?8L=BO(-JIV8;;C-BO`-F$V+?9
M@=BGV8L@VXS:J2#8JMBGV+';C-BN(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9
MAMN,V*_8C"#8JMBYV*_8I]BO(-BQV8C8LMF'V*<@V*_8L2#9A=BGV8<@V+'8
MIR#:J=F&V*K8L=F$(-JIV8;;C-BO`-F$V+?9@=BGV8L@VXS:J2#8LMF%V*?9
MAB#9A=BYV*K8J-BQ(-F(V*?8L=BO(-JIV8;;C-BO`-F$V+?9@=BGV8L@V*[9
MA-BGV+79A^*`C-BGXH",VXS;C"#8I]BR(-F%V+3:J=F$(-BQV*<@V*C9AMF(
MVXS8L]N,V*\`V838M]F!V*?9BR#9AMBGV84@VJG8I]BQV*C8L2#9B"#8I]BS
MV84@V+'9A=BR("#8KMF(V*\@V+'8IR#8HMF%V*?8K]F'(-JIV8;;C-BO`-F$
MV+?9@=BGV8L@V878JMF&(-BRVXS8L2#8L=BG(-BHV*[9B-BGV8;;C-BO+B#8
MM-F%V*<@V*C8L=BGVXP@V*?8L]BJV8'8I]BOV8<@V*?8LB#8L]BGV878I]F&
MV8<@V*C8I]N,V*\@V+38L=F(V+<@V+'8IR#9@MBHV8C9A"#:J=F&VXS8KP#9
MA-BWV8'8I]F+(-F&V*?9A2#8K]BSV*K9AR#8K-BOVXS8KR#8L=BG(-F(V*?8
ML=BO(-JIV8;;C-BO.@#8L]N,V*?8L]BJV8?8IP#8HMBQV*?8H0#9A=BMV80@
MV8+8L=BGV+':K]BQV8'8JMF&(-BGVXS9AB#8JMBUV8C;C-BQ`-F%V*W9A"#9
M@MBQV*?8L=JOV+'9@=BJV88@V*?;C-F&(-BLV*_9B-F$`-F^V+/8JB#8J-F'
M(-BGVXS9AB#9OMF(V+39AP#8K]BQV+78KR#8L=BWV8C8J-BJ(-BOV+$@)7,@
MV+/8I]BYV*H@V8+8J-F$.@!0<F5F<U]L9&%P.B#8J-BSV+<@V879B-BQV*\@
MV8;;C-BGV+(@3$1!4"#9OMN,V*_8IR#9AMBTV*\`4')E9G-?<V5S<VEO;CH@
MV*C8L]BW(-F%V8C8L=BO(-F&VXS8I]BR('-E<W-I;VX@V;[;C-BOV*<@V8;8
MM-BO`-F!V+38I]BQ`-F!V+38I]BQ(-BOV+$@V+/8M]BM(-BOV+';C-BG.B``
MV8'8M-BGV+$Z(`#9OMN,V+3B@(S9AMF%V*?;C-BT`-F^VXS8M.*`C-F&V878
MI]N,V+0@V*K8M=F(VXS8L2#8K]BQ(-N,VJD@V;[9AMBLV+'9AR#8K-BOVXS8
MKR``VJ_8LMN,V8;9A^*`C-F'V*?;C"#9@MBHV83;C`#:AMBGV;X@V+/9AMBO
M`-JIV83;C-BO(-BTV*[8M=N,`-F%V+3:J=F$`-BJV8C8MMN,V*T@V878M-JI
MV80`V;[8L=F(VIC9A^*`C-F'V*<`V878JMF&(-BGV+G9A-BGV88`VJG9A-N,
MV*\@V+G9A=F(V87;C`#8I]F$VJ_9B-BQVXS8JMF%(-JIV83;C-BO(-BYV879
MB-F%VXP`V*S9@=BJ(-JIV83;C-BO(-BYV879B-F%VXPOV*[8M=F(V+7;C"#8
MJ-BG(-F%V8C9@=F1V8+;C-F1V*H@V*K9B-F$VXS8KR#9AMBTV*\`V;[8L=BS
MXH",V8C8K-F(`-BSV8?9A=N,V8<`(-JIV83;C-BO(-BYV879B-F%VXP@4E-!
M("@E9"#8J-N,V*HI`-BGV8;8JMBNV*?8J"#8L=BGV*_;C-F(`-BHV*?8L=BG
MV88`V*C8I]BQV*?9AB#8LMF(V*_9A]F&VJ_8I]F%`-BHV*?8L=BGV88@V*_;
MC-BQV8?9AMJOV*?9A0#8J-BGV+'8I]F&(-F((-BQVJ_8J-BGV+$`V*C8I]BQ
MV*?9AB#9B"#8J-BQV8$`V*C8I]BQV*?9AB#8J-F'(-BHV+'9@0#8M]BGV838
MN2#8JMBUV*?8K]F!VXP`V8;8L]BHV*H`V*[9B-BGV8;8K]F&`-BNV8C8I]F&
MV*_9AB#9OMN,V+K8I]F%V8?8IR``V8C8I]F"V+G8I]F2("5S(-BMV+#9@2#8
MM-F(V*_8GR#8I]N,V88@V+G9A=F$(-F"V*?8J-F$(-F(V*?:K]BQV*\@V8;;
MC-BSV*H`V8C8I]F"V+G8I]F+(-BOV*?8K]F'V90@VJG8I]BQV*C8L=N,(-BH
MV+'8I]N,(-JIV*?8L=BHV+$@)7,@V*W8L-F!(-BTV8C8K]B?(-BGVXS9AB#8
MN=F%V80@V8+8I]BHV80@V8C8I]JOV+'8KR#9AMN,V+/8J@#8I]F&V*S8I]F%
M(-BBV*[8L=N,V88@V+G9A=F$(-BTV878IR#8I]BR(-F&V8@`V*C8I]BRV*+9
MB-BQVXP@V+G9AMBGV+78L2#:K]BRVXS9AMJOV*?9AB#8K]N,V8;8I]F%VXS:
MJ=N,.@#8J-BGV++8HMF(V+';C"#9AMF%V*?;C"#8K]BQVJ_8I]F'.@#9A=BQ
MV8C8L=JOV+$@V+'8I]BHV+?9A^*`C-BGXH",VXS;C`#8JMF(V+;;C-BMV*?8
MJ@#:J=BGV+'8L]BGV++9A]BGVXP@V+'8I]F'XH",V*_9B-BQ`%523`#8K=BP
MV8$`V*W8L-F!(-BHV839B-JI`-BMV+#9@2#8L]BJV8C9A@#8K=BPV8$@V8+8
MI]F$V*@@V*C9AMBOVXP`V*W8L-F!(-BRV8C8K`#8K=BPV8$@V*_8L]BJ(.*`
MC-F&V8C;C-BSV8?8I]N,(-BMV8'8N"#8M-BOV8<@V*_8L2#8M-BGV*[9AR#9
MA=F(V8+8JB#:J=BGV+'8L]BGV+(`V*W8L-F!`-BMV+#9@2#8I]N,V88@VJ_8
ML=F'(-BGV+(@V+/9AMBO`-BMV+#9@2#:J=BGV+'8J-BQ`-BMV+#9@2#:J=BG
MV+'8J-BQ.B`E<P#8JMF"V*?8MMBG(-F"V*?8J-F$(-F^V*?8L]BNVJ_9B-N,
MVXP@V8;;C-BSV*HN(-JIV*\@V*[8M]BGVXP@V*C8L=JOV+'8K]BGV8;8K]F'
M(-BTV*_9ASH`V8';C-F$V*_9A]BGVXP@V879B-BQV*\@V8;;C-BGV+(`V*C8
MI]BRV8;8M-BGV8;;C`#8J-BGV++9AMBTV*?9AMN,(-BGV+/9A2#8L=F%V+(`
MV*?8L]F%(-BQV878LB#8KMF(V*\@V+'8IR#8J-BGV++9AMBTV*?9AMN,(-JI
MV8;;C-BO`-F&V*K8I]N,V*P`V*C8I]BRVJ_8M-BJ(-BHV8<@VJ_8LMN,V8;9
MA^*`C-F'V*<`V*K8I]N,V;X@V*_9B-BHV*?8L=F'(-BGV+/9A2#8L=F%V+(@
M(-BLV*_;C-BO(`#:K]BQV*_9A]F%V*?;C-N,`-BHV*?8LMJOV+'8K]BGV8;8
MK]F&(-F^VXS:J=BQV*C9AMBOVXP`VJ_8LMN,V8;9A^*`C-F'V*?;C"#9B-N,
MV+'8I]N,V+3:K]BQ(-F%V*K9A@#9A=BYV878I]F'V*<`V+'8I]BSV*H`V+/8
ML=BBV878KR#8L=BGV+/8J@#9A=F"V*?8K]N,V+$@V+'8I]BSV*H`V*[8M=F(
MV+7;C-BGV*H@V+/8M]BQ+BXN`-F&V8+8M`#:AMBQV*[8M"#;L=NXV[`@V*_8
ML=BLV8<`VH;8L=BNV+0@V*C9AR#:AMF^`-J&V+'8KMBT(-BHV8<@V+'8I]BS
MV*H`V*[8M=F(V+7;C-BGV*H@V+/8M]BQ`-BNV+79B-BUVXS8I]BJ(-BSV+?8
ML0#8L]BWV+'9A]BG.@#9@MF(V*?8N=BO`-F"V8C8I]BYV*\@V*C;C-F&(-BJ
MV878I]F%(-BSV+?8L=F'V*<@V8@@V+/8JMF(V8;9A]BG(-F&V878I]N,V*?9
MAB#8KMF(V*?9A]BO(-BTV*\`V8+9B-BGV+G8KR#9@=F"V+<@V*C;C-F&(-BJ
MV878I]F%(-BSV*K9B-F&V8?8IR#9AMF%V*?;C-BGV88@V*[9B-BGV8?8KR#8
MM-BO`-F"V8C8I]BYV*\@V8'9@MBW(-BHVXS9AB#8JMF%V*?9A2#8L]BWV+'9
MA]BG(-F&V878I]N,V*?9AB#8KMF(V*?9A]BO(-BTV*\`V*?8K-BQV*<`V;[;
MC-BZV*?9A2#8L=F%V++8J-F&V*_;C"`@V+38K]F'V90@4R]-24U%(`#8JMBU
MV*_;C-F"(-F'V8C;C-F1V*H@4T%33"#9@MBGV*C9A"#8K]BSV*K8L=BSVXP@
MV8;;C-BSV*H`V;[;C-BZV*?9A2!335,`V;[9B-BSV*K9AR!344P`4U-(`-F%
MV8C9@=F1V8+;C-F1V*H`V;[9B-BSV*K9AR!344P`V+39AMBHV8<`V8?9A=BG
MV88@VH;8I]BQVH;9B-BH("C8KMF(V*_8M"D`V*W9@=BX(-JIV+'8K]F&`-BM
MV8'8N"#:J=BQV*_9AB`E<P#8K=F!V+@@VJ_8LMN,V8;9A^*`C-F'V*<`V;[;
MC-JIV+'8J-F&V*_;C"#8JMF(V83;C-BO(-BTV*_9AR#8J-BYV8;9B-BGV88@
MV*_8L]BJ(.*`C-F&V8C;C-BS(%!(4"#8K]BQ(-BTV*?8KMF'V90@V879B-F"
MV*H@VJG8I]BQV+/8I]BR(-BTV878IR#8K=F!V+@@V+39B-BO`-F^VXS:J=BQ
MV*C9AMBOVXP@)7,@V*W9@=BX(-BTV*\`V+G9A-F%`-BLV+/8JN*`C-F(V*S9
MB`#8K-F(VXS8M-JOV+'9A]BG`-BGV8;8JMBNV*?8J"#9OMBQV8C9AMBOV8?B
M@(S9A]BG`-BGV8;8JMBNV*?8J"#;C-JI(-BJV*?8L=N,V*X`V*?9AMBJV*[8
MI]BH(-N,VJD@VJ_8L=F(V8<@V*C8L=BGVXP@V*?8MMBGV8'9AR#:J=BQV*_9
MA@#8I]F&V*K8KMBGV*@@VXS:J2#9A=BGV83:J2#8K-BOVXS8KP#8I]F&V*K8
MKMBGV*@@VXS:J2#:J=BGV+'8L]BGV+(`V*?9AMBJV*[8I]BH(-N,VJD@VJG8
MI]BQV*C8L2#8J-BQV*?;C"#8I]BVV*?9@=F'(-JIV+'8K]F&`-BGV8;8JMBN
MV*?8J"#9A]F%V8<`V*?9AMBJV*[8I]BH(-BJV878I]F%(-F%V*39A-F!V8?B
M@(S9A]BGVXP@V*K8I]BQVXS8K@#8I]F&V*K8KMBGV*@@VXS:J2#8M-BF`-BG
MV8;8JMBNV*?8J"#9A]N,VH;B@(S:J=BOV*?9A0#9AMF(VXS8L]F'XH",V8?8
MI]N,VXP@VJG9AR#9A-BGV++9A2#8K]BGV+';C-BO(-BQV*<@V*?8LB#8K-BY
MV*C9AR#8LMN,V+$@V*?9AMBJV*[8I]BH(-JIV8;;C-BO+B#8L]F^V+,@V+39
MA=BG(-F%VXSB@(S8JMF(V*?9AMN,V*\@V*?8LB#8HMF&V8?8IR#8K]BQ(-F%
MV8;8M]F"V8<@V878JMF&(-F&V+/8KMF'XH",V*C8L=BOV*?8L=N,(-JIV+'8
MK]F'(-F((-BOV+$@V878K=F$(-BOVXS:K]BQ(-BHVH;8L]BHV*?9AMN,V*\`
MV*?9AMBJV*[8I]BH(-F%V*W8K]F(V*_9AR#8JMBGV+';C-BN.@#8I]F&V*K8
MKMBGV*@@V8+8I]F$V*@@V*K8I]BQVXS8KCH`V*?9AMBJV*[8I]BH(-F'V8C;
MC-F1V*K;C"#:J=F'(-F%VXSB@(S8KMF(V*?9A]N,V*\@V*K8NMN,VXS8L2#8
MK]F'VXS8KSH`V*?9AMBJV*[8I]BH(-F%V*W8K]F(V*_9A]F4(-BRV878I]F&
M.@#8I]F&V*K8KMBGV*@@V8+8I]F$V*@@V++9A=BGV88Z`-BGV8;8JMBNV*?8
MJ"#8K]F((-F!VXS9A-BO(-F%V8;8M]BHV8(`V*?9AMBJV*[8I]BH(-BWV+'8
MK2#8L=F&VJ\@V+39A=BG`-BGV8;8JMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8
MKR#9AMBXV+$@V+39A=BG.@#8I]BQV+/8I]F$(-JOV++8I]BQV+0`V*?8L=BS
MV*?9A"!335,`V*W8L]JOV+$Z(`#8L]F^V*K8I]F%V*C8L0#8I]BYV*_8I]BO
M(-BJV+'8JMN,V*C;C`!)1"#9AMBTV+/8JB#9A=F&V8+8MMN,(-BTV*_9AR#8
MI]BSV*H`V*K9AMBXVXS9A0#8JMF&V+C;C-F%(-JOV++;C-F&V8?B@(S9A]BG
M(-BHV+'8I]N,(-BGV*S8I]BRV8<@V*_8I]BOV88@V*C9AR#8M-F%V*<@V*C8
ML=BGVXP@V*C8I]BRV8;8M-BGV8;;C"#8I]BSV84@V+'9A=BR(-BHV8<@V8?9
MAMJOV*?9A2#9@=BQV*?9A=F(V+3;C"#8HMF&(`#8JMF&V+C;C-F%(-JIV*?8
ML=BSV*?8LMF'V*?;C"#8L=BGV8<@V*_9B-BQVXP@VJG9AR#8M-F%V*<@V87;
MC.*`C-BNV8C8I]F'VXS8KR#8I]BR(-BOV+':K]BGV8<@V*[9B-BO(-BHV8<@
MV*+9AB#8K]BSV*K8L=BSVXP@V*_8I]BTV*K9AR#8J-BGV+3;C-BO`-BGV8;8
MJMBNV*?8J"#8LMBHV*?9AB#9A=F(V+'8KR#9AMBXV+'8C"#8L]BGV+G8JB#9
MB"#:K]BRVXS9AMF'XH",V8?8I]N,(-BJV*?8L=N,V*X`V*?9AMBJV*[8I]BH
M(-BHV+'9AMBGV879AR#8LMF%V*?9AB#8M-BQV8C8N=B,(-BWV+'8K2#8L=F&
MVJ_8C"#8J-BGV++8HMF(V+';C"#8M=F!V*W9AR#9B"#8J-F"VXS9AR#:K]BR
MVXS9AMF'XH",V8?8I]N,(-F&V878I]N,V+0`V+'8I]F')B-X,C`P8SO8I]F&
MV*_8I]BRVXP`V*_8L]BJ(.*`C-F&V8C;C-BS("#8J-BQV8C8LMBQV+/8I]F&
MVXP@V+'8I]F'XH",V*?9AMBOV*?8LMN,(-BOV+$@V*_8L]BJV+'8LR#8I]BS
MV*H`VH;9AMBOVXS9AB#9A=F(V8+8N=N,V9'8JB#8J-BG(-F^V*?8L=BGV878
MJMBQ(-F%V87:J=F&(-BGV+/8JCH`V*[8L=N,V*\`V*[9A-BGV+79AR#:J=F(
MV*K8I]F'`-BBVXS8IR#:J=F$VXS8K]F'V*?;C"#8K]BSV*K8L=BSVXP@V*C8
MI]N,V*\@V*C8L=BGVXP@V*C;C-BTV*K8L2#9OMN,V8C9AMBOV8?8IR#8JMBY
MV+';C-F!(-BTV8C9AMBOV)\`V8;9A=BGVXS8M``@V8;9A=BGVXS8M"#8JMF!
MV*?9B-BJV8?8I]N,(-F%VXS8I]F&(-F^VXS:J=BQV*C9AMBOVXP@V*W9@=BX
M(-BTV*_9AR#9@=BYV83;C"#9B"#8JMF(V83;C-BO(-BTV*_9AR#8K-BOVXS8
MKP#8HMN,V*<@V++9A=BGV88@V*+8KMBQVXS9AB#9B-BQV8C8KR#8J-F'(-F'
MV8;:K]BGV84@V8C8L=F(V*\@V8;8M-BGV88@V*_8I]BOV8<@V+39B-BOV)\`
MV8;9A=BGVXS8M"#:K]BRVXS9AMF'XH",V8?8IR#8J-BQV*?;C"#9AMJOV8?8
MK]BGV+';C"#8I]BUV80`V*?9AMBJV*[8I]BH(-F#V8;9AMBOV8<@V8;9A=BG
MVXS8M`#8HMN,V*<@V87;C-F$V8<@VJ_8LMN,V8;:K]BGV88@V+G9A=F$VXS8
MI]BJ(-BLV*_9B-F$XH",(-F&V878I]N,V+0@V*_8I]BOV8<@V+39B-BOV)\`
MV*+;C-BG(-JOV++;C-F&VJ_8I]F&("5S(-BSV878JB#8L=BGV+/8JB#9AMBT
MV*?9AB#8K]BGV*_9AR#8M-F(V*_8GP#9AMF%V*?;C-BT(-JOV8'8JN*`C-F(
MVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BSV839B-F$(-BLV*_9B-F$`-F&V878
MI]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BLV*_9B-F$`-F&
MV878I]N,V+0@VJ_9@=BJVJ_9B-N,(-BNV+79B-BUVXS8I]BJ(-BSV+?8L2#8
MK-BOV8C9A`#9AMF%V*?;C-BT(-JOV8'8JMJOV8C;C"#8KMBUV8C8M=N,V*?8
MJB#8JMBUV8C;C-BQ`-F&V878I]N,V+0@V*?8L=BSV*?9A`#8JMJOV+':KP#8
ML=JOV*C8I]BQ(-BRV8C8K]F'V8;:K]BGV84`V+':K]BHV*?8L2#8K]N,V+'9
MA]F&VJ_8I]F%`-BLV878N2#8M-BOV88`V*S9A=BY(-BTV*_9AB#;C-BG(-BG
MV8;8JMF"V*?9A"#8J-F$V8C:J=F'V*?;C"#9A=BLV*?9B-BQ`-BKV*C8JB#9
MAMBGV84`V*?9A=BVV*?8H0#8I]F$VJ_9B-BQVXS8JMF%(-BGV878MMBGV*$`
MV*?9AMBOV*?8LMF'`-BUV+'9@=F&V+C8L2#8I]BR(-F&VJ_9A]BOV*?8L=N,
M`-BHV+'9@0#8JMJOV+':KP#8JMJOV+':KP#8L=JOV*C8I]BQ(-BRV8C8K]F'
MV8;:K]BGV84`V+':K]BHV*?8L2#8K]N,V+'9A]F&VJ_8I]F%`-BYV879@B#8
MJ-BQV8$Z(`#9A=BYV*?8K]F$(-BHV+'9@2#8K]BQ(-BBV*@Z(`#8M-BYV+'9
MA]BG(-F((-BBV8C8I]BRV8?8IP#8I]F&V*K8KMBGV*@@V*S9A]BJ(-F%V+'8
MJMBH(-BSV*?8LMN,`-BBV*_8L=BS(-BSV+':AMBTV879AP!3;W5T:"!%=7)O
M<&5A;B`H25-/+3@X-3DM,RD`V8;;C-F%(-JIV+'9AR#8K-F&V8C8J-N,`-F!
MV*?8M=F$V8?9E"#8J-N,V88@V+/9A-F(V839A]BGVXP@V878K-BGV8C8L0#9
M@=BGV+79A-F'V90@V*C;C-F&(-F%V*W8JMF(V*<@V8@@V838J-F'(-BOV+$@
MV+/9A-F(V80`V8'8I]BUV839A^*`C-JOV+#8I]BQ`-F!V*?8M=F$V8<`V8'8
MI]BUV839A^*`C-JOV+#8I]BQVXP@V8@@V*_8L=BRVJ_8L-BGV+';C`#9A]BQ
MV++9AMBGV879AP#:J=BGV+'8I]JIV*K8L2#8KMBGV+4@V8C8I]BQV*\@V+38
MKP#8JMF"V+/;C-F%(-BSV839B-F$`-BJV8+8L]N,V84@V+/8JMF(V88`V*K9
M@MBSVXS9A2#8L]BWV+$`V8C8L=BRV+3;C`#8I]BSV*K8I]F&V*_8I]BQV*\`
MV+/8JMBGV+'9AP#8L]BGV80@V+38L=F(V+D`V8C8MMBYVXS8JB#8K=F(V++9
MA^*`C-F'V*<`V8C8MMBYVXS8JN*`C`#9@MBGV838J"#8L-BNVXS8L=F'(-BS
MV*?8LMN,`-BBV*_8L=BS(-BNVXS8I]BHV*?9A@#9@=F'V+'8L]BJ(-BQV+38
MJMF'`-BTVXS9B-F'(%M#4U-=`-N,VJG8M-F&V*C9AP#8N=F&V8C8I]F&`-BG
MV+'8L]BGV80`V++;C-BQV8;9B-N,V+,`V879B-F!V9'9@MN,V9'8J@`B)7,B
M(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8K=BPV8$@V+38KP#9OMN,VJG8L=BH
MV8;8K]N,(-BHV*<@V879B-F!V9'9@MN,V9'8JB#8J-BGV++:K]BQV*_8I]F&
MV*_9AR#8M-BO+B#8J-BQV*?;C"#9A=BTV*?9A]BOV8<@V*K8NMN,VXS8L=BG
MV*H@V878K-BOV*_8I]F2(-BBV8;8L=BG(-BHV*?8L2#9AMF%V*?;C-N,V*\`
MV;[;C-JIV+'8J-F&V*_;C"#9OMBTV*K;C-BHV*?9AB#8J-BG(-F%V8C9@=F1
MV8+;C-F1V*H@V*W9@=BX(-BTV*\`V;[8L=F(V8;8K]F'(-F^V+38JMN,V*C8
MI]F&(-F^VXS:J=BQV*C9AMBOVXP@)7,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ
M(-BMV8'8N"#8M-BO`"5S(-BHV*<@V879B-F!V9'9@MN,V9'8JB#9AMF(V+38
MJMF'(-BTV*\`V*[9A-BGV+79AP#8M]F$V8C8N2#8HMF!V*K8I]BH`-BZV+'9
MB-BH(-BBV8'8JMBGV*@`V*+9@=BJV*?8J-N,`-BWV839B-BY`-BWV839B-BY
M+]BZV+'9B-BH`-BWV839B-BY.B``V+K8L=F(V*@`V+K8L=F(V*@Z(`#8J-BG
MV838I]F&V8C;C-BS`-F^V+38JMN,V*C8I]F&VXP`V8;8I]F%(-BNV*?9AMF(
MV*?8K]JOVXP`V*[8M]BGVXP@V8;8K=F(VXP@V*_8L2#9A=F(V*?8L=BO(-BL
MV+/8JMBLV8@`5"U3=&]R;7,`5"U3=&]R;7,`V;[8L=F(V8;8K]F'(%135@#8
MK-BOV8C9A`#8KMBUV8C8M=N,V*?8JB#8K-BOV8C9A`#8KMBUV8C8M=N,V*?8
MJB#8K-BOV8C9A`#9A]BOV8$Z`-F(V+C8I]N,V8$`V+39A=BGV+'9AR#8JMF$
MV8'9A@#8K]F%V*?;C"#8L]BGV+G8JB#8I]BNVXS8L3H@`-BOV+'8K-F'(-BM
MV+'8I]BQV*H`V*_8L=BLV8<@V*W8L=BGV+'8JCH@`-BGV83:K]F(VXP@V+/8
ML=F^V+'8L]BJVXP`V878JMF&`-F!V8+8MR#9A=BJV88`V*K8L=BGV+(@V878
MJMF&`-BHV*?9A-BGVXP@V878JMF&`-F^V8;8K-BTV8;8J-F'`%1H86D@*%1)
M4RTV,C`I`-BGV+(@V+39A=BG(-BHV8<@V*[8I]BWV+$@V*?8L]BJV8'8I]BO
MV8<@V*?8LB#8L]BGV878I]F&V8<@V878JMBTVJG8L=N,V84`V*C8L]BW($94
M4"#9@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ`-F&VJ_9A]BOV*?8L=N,
M.CH@VJG9A-BGV+,@V*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV*?8L2#9AMBT
MV*\`V;[9AMBLV+'9A]F4(-JOV++;C-F&V8?B@(S9A]BG(-BHV+/8JMF'(-BT
MV*\N(-BNV+'9B-BL`-BSV+'9OMBQV+/8JB#8J-BGVXS8KR#;C-JI(-F^V+38
MJMN,V*C8I]F&(-F%V*S9B-BRV8?8IR#8L=BGV(P@(-BOV+$@V+79B-BQV*H@
MV*K9A=BGVXS9A"#8M-F%V*<@V*C9AR#8I]BSV*K9@=BGV*_9AR#8I]BR(-F%
MV*S9B-BRV8?8I]B,(-F^VXS:J=BQV*C9AMBOVXP@VJG9AMBO+@#8JMF&V8?8
MIR#8L]F%V*H@V;[8I]N,VXS9A@#8M-F%V*?8L=F'($E$(-BJV878I]BS(-F%
MV+38KMBU(-F&V+38K]F'(-BGV+/8JMB,(-BGVXS9AB#8M-F%V*?8L=F'(-BO
MV+$@V*_8I]BOVJ_8I]F&(-N,V*?9@=BJ(-F&V+38KP#8JMF%V*?8LR`@)7,@
MV*C8IR#9A=F(V8'9D=F"VXS9D=BJ(-BHV8<@VJG8JMBGV*C:AMF'(-BBV*_8
ML=BS(-BTV878IR#8I]BVV*?9@=F'(-BTV*\`VXS:J2#8J-F$V8C:J2#8I]F%
MV+;8I]N,(%!'4"#8J-BQV*?;C"#8J-BGV++8J-N,V8;;C"#;C-JI(-F^VXS8
MNMBGV84@V*?9A=BVV*?8H2#8M-BOV8<@V879B-BQV*\@V8;;C-BGV+(@V*?8
ML]BJ`$E$(-F!V8?8L=BSV*H@V*K9B-BRVXS8N=N,(-F%V+38KMBU(-F&V+38
MK]F'(-BGV+/8JB#9B"#;C-BG(-BOV+$@V*_8I]BOVJ_8I]F&(-F%V8C8K-F(
MV*\@V8;;C-BSV*H`V8'9A]BQV+/8JB#8JMF(V++;C-BYVXP@V878M-BNV+4@
MV8;8M-BOV8<@V*?8L]BJ`-F%V+38KMBUV8?B@(SB@(S9A]BGVXP@V+'9A=BR
MV*C9AMBOVXP@V8;;C-BGV++9A=F&V*\@VXS:J2#8I]BQV*K8M=BGV80@V*?9
MA=F&(-F(V*@@V87;C.*`C-BHV*?8M-F&V*\`V;[8L=F(V8;8K]F'("5S(-BH
MV*?;C-BO(-BOV*?8L=BGVXP@V*K9AMBXVXS9A2`E<R#8J-BGV+38KP#9OMBQ
MV8C9AMBOV8<@)7,@V*C8I]N,V*\@V*W8I]F(VXP@V*K9AMBXVXS9A=BGV*H@
M)7,@V*C8I]BTV*\`V;[8L=F(V8;8K]F'(-BHV+$@V+'9B-N,(-BNV8C8K]BT
M(-F&V87;C.*`C-BJV8C8I]F&V*\@V+'9B-F&V8C8M-BJ(-BTV8C8KP#9OMBQ
MV8C9AMBOV8<@V*W8I]F(VXP@V*_8I]BOV8?B@(S8I^*`C-N,VXP@V8;;C-BS
MV*H@`-F%V*\@V*K9A=BGV84@V+79@=BMV8<@V*C8IR!)12#9A=BTVJG9A"#8
MK]BGV+'8KR#9B"#8I]N,V88@V*?8LB#9A=BTVJG9A-BGV*H@V878L=F(V+':
MK]BQ(-F%VXSB@(S8J-BGV+38KRX@V*?:K]BQ(-F'V8;9B-BR(-F%VXSB@(S8
MKMF(V*?9A]N,V*\@V*W8I]F$V*H@V8C;C-BQV*?;C-BTVJ_8L2#8JMF%V*?9
MA2#8M=F!V*W9AR#8L=BG(-BGV878JMBMV*?9AB#:J=F&VXS8K]B,(-F$V+?9
M@=BGV8L@VJG9A-N,V*\@V*K8H]N,VXS8KR#8L=BG(-F!V+38I]BQ(-BOV8?;
MC-BO(`#9A]F(VXS9D=BJ("(E<R(@V*W8L-F!(-BTV*_9AR#8I]BSV*H`V*K9
MAMF'V*<@V+/9A=BJ(-J&V;X`V;[;C-BZV*?9A2#9@=BQV+/8JMBGV*_9AR#8
MM-BOV8<@V+'9B-N,("5S(-BHV8<@)7,@V*C8IR#9A=F(V+;9B-BY("(E<R(@
MV8;9A=BGVXS8M"#8K]BGV*_9AR#8M-BOV8<@V*?8L]BJ+@K8JMBVV87;C-F&
MVXP@V*C8L=BGVXP@V*[9B-BGV8;8K]F'(-BTV*_9AB#9B"#;C-BG(-BOV+':
MJ2#8HMF&(-F(V*S9B-BO(-F&V*_8I]BQV*\`V8;8I]F%VXP@VJG9AR#8J-F'
M(-F'V8;:K]BGV84@V;[;C-F(V8;8K]BOV8?;C"#8J-F'(-BUV8'8K=F'(-BG
MVXS8K-BGV*\@V8;8I]F%V8<@V*?8L]BJV8'8I]BOV8<@V87;C.*`C-BTV8C8
MKP#8JMBYV*_8I]BO(-F!VXS9A-BOXH",V8?8IR#8J-BGVXS8KR#;C-JI(-BY
MV*_8KR#8J-BGV+38KP#8I]F(V839B-N,V*H@(B5S(B#9AMF%VXSB@(S8JMF(
MV*?9AMBO(-BMV8'8N"#:K]BQV*_8KR#8LMN,V+'8IR#9A=F"V*_8I]BQ(-BO
MV*?8K]F'(-BBV88@V*?8LB#8K=BO(-F%V*S8I]BR(-BHVXS8M-BJV+$@V*?8
ML]BJ`-BHV+'9AMBGV879A^*`C-BGXH",VXS;C"#:J=F'(-BHV+'8I]N,(-F%
MV+38I]F'V*_9AR#8I]N,V88@V8;9B-BY(-BOV*?8K]F'("@E<RD@V8+8J-F$
MV*?9BR#9A=F(V+'8KR#8I]BSV*K9@=BGV*_9AR#9@MBQV*?8L2#9A=N,XH",
MVJ_8L=F!V*K8C"#8K]BQ(-BSV*?9A=BGV8;9AR#9A=F(V*S9B-BO(-F&VXS8
ML]BJ`-BJV8;9A]BG(-BSV878JB#8L=BGV+/8JB#9B"#:AMF^`-BJV8;9A]BG
M(-BSV878JB#8L=BGV+/8J@#8K-BOV*<@VJG9AMF&V*_9AR#8J-BGVXS8KR#;
MC-JI(-F&V8C;C-BSV8<@V*C8I]BTV*\`VJG8I]BQV+/8I]BR("(E<R(@V*W8
ML-F!(-BTV*_9AR#8I]BSV*H`VJG8I]BQV+/8I]BR("(E<R(@V*W9@=BX(-BT
MV*_9AR#8I]BSV*H`V*_8L=BNV8C8I]BSV*H@V*?9@=BJV*K8I]BM(-BMV+/8
MI]BH(-BHV+'8I]N,("5S(-BMV+#9@2#8M-BOV8<@V*?8L]BJ`-BQV*_;C-F!
M(-F%V+38KMBU(-BTV*_9AR#9B-BLV8C8KR#9AMBOV*?8L=BO`-F^V+'9B-F&
MV*_9AR#9A=F(V8+8JMN,("`B)7,BV879B-BLV8C8KR#9AMN,V+/8J@#8JMF&
MV8?8IR#8L]F%V*H@V*C8I]F$V*<@V8@@V;[8I]N,VXS9A@#8JMF&V8?8IR#8
ML]F%V*H@V*C8I]F$V*<`V*_8I]BOV8?9E"#8I]BQV+/8I]F$(-BTV*_9AR#8
MI]BR(-JOV*?9A2#9@MBHV83;C"#8I]BR(-BOV+/8JB#8L=F!V*K9AR#8I]BS
MV*H`V;[8L=F(V8;8K]F'(-BGV+'8L]BGV80@V+38K]F'(-F&V87;C.*`C-BJ
MV8C8I]F&V*\@V*W9@=BX(-BTV8C8KP#8J-F$V8C:J2!W96%T:&5R+F-O;2#9
M@MBGV*C9A"#8K]BSV*K8L=BS(-F&VXS8L]BJ`-JOV++;C-F&V8?B@(S8I^*`
MC.*`C-N,VXP@V*_8L2#8K]BSV*K8L=BS(-F&VXS8L]BJ`-BHV*[8M-N,(-JI
MV8<@V*C8JMF(V*?9AMBO(-BHV+'8KMBW(-F&V878I]N,V+0@V*_8I]BOV8<@
MV+39B-BO(-F%V8C8K-F(V*\@V8;;C-BSV*H`V8;9B-N,V+/9A^*`C-F'V*?;
MC"#8LMN,V*?8K]N,(-BOV+$@V*?;C-F&(-F!VXS9A-BO(-F"V+'8I]BQ(-BO
MV*?8L=BO+B#8M-F%V*<@)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=BQV*_9
MA^*`C-BGXH",VXS8KR#8K]BQ(-BMV*?9A-N,(-JIV8<@V+39A=BG(-BHV*?;
MC-BO(-JIV878JMBQ(-BGV+(@)7,@V8;9B-N,V+/9AR#9B-BGV+'8KR#:J=F&
MVXS8KP#9A=BTVJG9A-N,(-BOV+$@V*?8L=BSV*?9A"#9OMBQV8C9AMBOV8<@
MV+'8KB#8K]BGV*_9AR#8I]BSV*HZ("5S(-BGV+'8L]BGV80@V8;8M-BO`-F%
MV+3:J=F$VXP@V*_8L2#8I]BQV+/8I]F$(-F^V+'9B-F&V*_9AR#8L=BN(-BO
MV*?8K]F'(-BGV+/8JCH@V*?9AMBOV*?8LMF'("5S(-BHVXS8M-BJV+$@V*?8
MLB#8K=BO(-F%V*S8I]BR(-BHV8C8K]F'(-BGV+/8JB`H("5D(-BHV*?;C-BJ
M*2X`V878M-JIV83;C"#8K]BQ(-BGV+'8L]BGV80@V;[8L=F(V8;8K]F'(-F(
MV*S9B-BO(-BOV*?8M-BJV8<@V*?8L]BJ.B`@)7,@V*C9AR#8M=F(V+'8JB#8
MJMJIV8?B@(S8I^*`C-N,VXP@V*?8L=BSV*?9A"#8M-BOV8<@V*?8L]BJ(`#8
MKMBWV*?;C-N,(-BOV+$@V8;9A=BGVXS8M"#8I]N,V88@V*C8KMBT(-F^VXS8
MNMBGV84@V+'8KB#8K]BGV*_9AR#8I]BSV*H`V*[8M]BGVXS;C"#8K]BQ(-BO
MV+'9B-F&XH",V*C8L=BO(-JIV+'8K]F&(-BOV*?8K]F'(-BJV878I]BS(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ`-BNV+?8I]N,VXP@V*_8L2#8K]BQV8C9AN*`
MC-BHV+'8KR#:J=BQV*_9AB#8K]BGV*_9A]F4(-BJV8+9B-N,V84@V+'8KB#8
MK]BGV*_9AR#8I]BSV*H`V*[8M]BGVXS;C"#8K]BQ(-F^VXS:J=BQV*C9AMBO
MVXP@V8'8L=F%(-BQV*X@V*_8I]BOV8<@V*?8L]BJ+B#8M-BGVXS8KR#9@=N,
MV838KR#9A=F(V+'8KR#9AMN,V*?8LMN,(-BQV*<@V*S8IR#8I]F&V*_8I]BN
MV*K9A^*`C-BGXH",VXS8KP#8KMBWV*?;C-N,(-BOV+$@V*?8K-BQV*<@VJG8
ML=BOV88@V+G9A=F$VXS8I]BJ(-F%V+38KMBU(-BTV*_9A]F4(-JIV*K8I]BH
MVH;9AR#8HMBOV+'8LR#8L=BN(-BOV*?8K]F'(-BGV+/8JBX@V838M]F!V*?9
MBR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO`-BNV+?8I]N,VXP@V*_8
ML2#8J-BQV8C8LMBQV+/8I]F&VXP@V*S8LMBFVXS8I]BJ(-BJV878I]BS(-BQ
MV*X@V*_8I]BOV8<@V*?8L]BJ+B#9A-BWV8'8I]F+(-BOV8C8J-BGV+'9AR#8
ML]BYVXP@VJG9AMN,V*\`V*[8M]BGVXS;C"#8K]BQ(-BHV+'9B-BRV+'8L]BG
MV8;;C"#9@=F'V+'8L]BJ(-BJV8C8LMN,V+G;C"#8L=BN(-BOV*?8K]F'(-BG
MV+/8JBX@V838M]F!V*?9BR#8K]F(V*C8I]BQV8<@V+/8N=N,(-JIV8;;C-BO
M`"#:J=BGV+'8L]BGV+(@24U!4-F^V8C8M-F'XH",V8?8I]N,(-F%V+38JMBQ
MVJD@V+'8IR#9OMBTV*K;C-BHV*?9AMN,(-F&V87;C.*`C-JIV8;8KP`@V*C9
MAR#9AMBXV+$@V8;9A=N,XH",V+'8L]BO(-JIV8<@V*+8L=BTVXS9B"!R87(@
MV878N=BJV*C8L=N,(-BHV*?8M-BO`"#8J-F'(-F&V+C8L2#9AMF%VXSB@(S8
ML=BSV*\@VJG9AR#9OMBQV8C9AMBOV8<@>FEP(-F%V+G8JMBHV+';C"#8J-BG
MV+38KP#8J-F'(-F&V+C8L2#9AMF%VXSB@(S8L=BSV*\@VJG9AR#8M-F%V*?8
ML=F'(-JIV*?8L=BJ(-F%V+G8JMBHV+';C"#8J-BGV+38KP#8I]N,V88@V8';
MC-F$V*\@V879B-BQV*\@V8;;C-BGV+(@V*?8L]BJ`-BGVXS9AB#9@=N,V838
MKR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V*?8N=BOV*?8KR#8M=BMVXS8
MK2#8J-BGV+38KP#8I]N,V88@V8';C-F$V*\@V879A=JIV88@V*?8L]BJ(-BT
MV*?9A=F$(-BGV+G8K]BGV*\@V8@@V8C;C-BQVJ_9B-F$(-BHV*?8M-BO`-BG
MVXS9AB#9@=N,V838KR#9A=F%VJG9AB#8I]BSV*H@V+38I]F%V80@V879@MBG
MV*_;C-BQ(-F'V+38JB#9A]BTV*K;C"#8J-BGV+38KP#8I]N,V88@V8';C-F$
MV*\@V*C8I]N,V*\@V*W8I]F(VXP@VJG8I]F%V*<@V8@@VXS8IR#9@=F'V+'8
ML]BJVXP@V*?8LB#8I]BYV*_8I]BO(-BUV*W;C-BM(-BLV*_8IR#8M-BOV8<@
MV*C8IR#9AMF(VXS8L]F'(-BNV*?9A-N,(-BHV*?8M-BO`-BGVXS9AB#9@=N,
MV838KR#8J-BGVXS8KR#;C-JI(-BYV*_8KR#9A=BYV*K8J-BQ(-BHV*?8M-BO
M`-BGVXS9AB`E<R#9A=N,XH",V*C8I]BTV*\`V*?;C-F&(-F^VXS8NMBGV84@
MV*C8IR#9A=BLV879B-BYV8<@VJG8I]BQV*?:J=BJV+$@)7,@V8;9B-BTV*K9
MAR#8M-BOV8<@V*?8L]BJ(-JIV8<@V*C8IR#9A=BLV879B-BYV8<@VJG8I]BQ
MV*?:J=BJV+$@V+39A=BG(-F%V*K9@=BGV8C8JB#8I]BSV*H`V*?;C-F&(-BY
MV*_8KR#8K=BOV*?9@MF$(-BHV*?;C-BO(-N,VJD@V*C8I]BTV*\`V*?;C-F&
M(-JIV*?8L=BSV*?8LB#9OMBQV8C9AMBOV8?B@(S9A]BGVXP@>FEP(-F((&=Z
M:7`@V+'8IR#8J-BGV+(@V8;9A=N,XH",VJG9AMBO`-BGVXS9AB#8L]BGV878
MI]F&V8<@V*_8L2#8K=BGV80@V*W8I]BVV+$@V+K;C-BQ(-F!V+G8I]F$(-BG
MV+/8J@#8I]N,V88@V879@MBOV*?8L2#8J-BGVXS8KR#8N=BOV*\@V*C8I]BT
MV*\`V*?;C-F&(-F^V8;8K-BQV8<@V*C8I]N,V*\@V*?8LB#9OMF&V*S8L=F'
MV90@VJ_8LMN,V8;9A^*`C.*`C-F'V*<@V8'8L=BGV*[9B-BGV8;;C"#8M-F(
MV*\`V+'8N=BO`-BHV83;C-BWV8?8IP#8LMF%V*?9A@#8L=BOVXS8I]BHVXP@
MV++9A=BGV88`V8+8I]F$V*@@V++9A=BGV88`(-BGV8;8JMBNV*?8J"#8LMF%
MV*?9AB``V+G9AMF(V*?9A@#8N=F&V8C8I]F&("C8L=BGV8?9AMF%V*?;C"#8
MHMF&VXPI.@#8J-F'`-BHV+'8I]N,(-BGV8;8JMBNV*?8J"#:AMF&V*\@V8';
MC-F$V*_8C"#8K]JIV879AR!#=')L(-BQV8C;C"`H4$,I(-N,V*<@0V]M;6%N
M9"#8L=F(VXP@*$UA8RD@V+'8IR#8K]BQ(-F%V*_8JB#:J=F$VXS:J2#:J=BQ
MV*_9AB#9AMJOV8?8K]BGV+';C-BO`-BGV878L=F(V+(`V8'8L=BOV*<`V*C8
MI]F$V*<`VH;8I]BQVH;9B-BH(-BHV*?9A-BG("C8J-BGV838IRD`V*K8L=BL
MV879A^*`C-F'V*<`V*_8L=BSV*H@V8@@VXS8IR#9AMBGV*_8L=BSV*H`V+/9
MAR#8M-F&V*C9AP!4=7)K:7-H("A)4T\M.#@U.2TY*0#8I]F&V*K8KMBGV*@@
MV*[9B-BO(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\Z`-BTV*?8KMBU(%4N5BX@
M.B``55),`%523#H`V*?9A=JIV*?9AB#8K]BSV*K8L=BSVXP@V*C9AR#8M-BG
MV*[9AR!61E,@V8;;C-BSV*H`V*?9A=JIV*?9AB#8I]BVV*?9@=F'(-JIV+'8
MK]F&(-BGV+?9A-BGV+G8I]BJ(-BGV+;8I]F!VXP@VJG8I]BQV*C8L2#8J-F'
M(-F'V8;:K]BGV84@V*O8J-BJ(-F&V*?9A2#9AMN,V+/8J@#9AMF%VXSB@(S8
MJMF(V*?9AB#9A=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9OMBQV8C9AMBO
MV8<@(B5S(B#8JMBZVXS;C-BQ(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#9
MA=BLV8C8LMF'V*<@V+'8IR#8J-BQV*?;C"#9OMBQV8C9AMBOV8<@)7,O)7,@
M5D93("#8JMBZVXS;C-BQ(-BOV*?8KP#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ
M("5S(-BJV+K;C-N,V+$@V*_8I]BO`-F&V87;C.*`C-BJV8C8I]F&(-BHV8<@
MVJG8I]BQV+/8I]BR(%-13-F%V*K8M=F$(-BTV*\`V8;9A=N,XH",V*K9B-BG
MV88@V*C8IR!34TP@V878JMBUV80@V+38KP#9AMF%VXSB@(S8JMF(V*?9AB#8
MI]BR(-F^V+'9B-F&V*_9AR!61E,@V+'9B-F&V8C8M-BJ(-BJV8?;C-F'(-F&
MV879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R`B)7,B(-BQ
MV*<@V*?;C-BLV*?8KR#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8M-BG
MV*[9AR!61E,@V+'8IR#8I]N,V*S8I]BO(-F&V879B-BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-F^V+'9B-F&V*_9AR!61E,@V+'8IR#8I]N,V*S8I]BO(-F&V879
MB-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&V*_9AR#8KMBGV83;C"!6
M1E,@(-BGVXS8K-BGV*\@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BGV88@V*_8
MI]BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO(`#8K=BPV8$@(B5S(B#9A=F%VJG9
MAB#9AMN,V+/8JMB,(-BTV*?8KMF'(-BNV*?9A-N,(-F&VXS8L]BJ`-F&V87;
MC.*`C-BJV8C8I]F&("(E<R(@V+'8IR#8K=BPV8$@VJG8L=BO.B`E<RX`V*W8
ML-F!("5S(-F%V87:J=F&(-F&VXS8L]BJV(P@V+38I]BNV8<@V*[8I]F$VXP@
MV8;;C-BSV*H`V8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@
MV*C9AR#8M=F(V+'8JB#8JMF((-BOV+$@V*K9B"#8K=BPV8$@V8;9A=F(V*\`
MV8;9A=N,XH",V*K9B-BGV88@V+38I]BNV8<@5D93(-BQV*<@V*W8L-F!(-F&
MV879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-BTV*?8KMF'(%9&4R#8L=BG(-BM
MV+#9@2#9AMF%V8C8KSH@)7,N`-F&V87;C.*`C-BJV8C8I]F&(-F^V+'9B-F&
MV*_9AR!61E,@(B5S(B#8L=BG(-BMV+#9@2#9AMF%V8C8KP#9AMF%VXSB@(S8
MJMF(V*?9AB#9OMBQV8C9AMBOV8<@5D93(-BQV*<@V*W8L-F!(-F&V879B-BO
M`-F&V87;C.*`C-BJV8C8I]F&(%9&4R#8L=BG(-BHV8<@V+79B-BQV*H@V*K9
MB"#8K]BQ(-BJV8@@V*W8L-F!(-F&V879B-BO.B`E<RX`V8;9A=N,XH",V*K9
MB-BGV88@V+38I]BNV8?9E"#9@=BYV83;C"#8L=BG(-BJV+38KMN,V+4@V*_8
MI]BO`-F&V87;C.*`C-BJV8C8I]F&(-BLV++8IMN,V*?8JB#:K]F(V*?9A]N,
M(-BQV*<@V*?8L]BJV*[8L=BGV*P@V8;9A=F(V*\`V8;9A=N,XH",V*K9B-BG
MV88@V*K8N=BQVXS9@2`E<R`@V+'8IR#8J-BGV+$@V8;9A=F(V*\`V8;9A=N,
MXH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8L=BG(-BGV8;8JMF"V*?9
MA"#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`B
M)7,B(-BQV*<@V*C8I]BR(-F&V879B-BO`-F&V87;C.*`C-BJV8C8I]F&(-F^
MV+'9B-F&V*_9AR!61E,@V+'8IR#8J-BQV*?;C"#9AMF(V+38JMF&(-BHV*?8
MLB#:J=BQV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R#8
ML=BG(-BHV*?8LB#9AMF%V8C8KP#9AMF%VXSB@(S8JMF(V*?9AB#8HMBQV+3;
MC-F((-F!V+38L=BOV8<@V+'8IR#8J-BGV+(@VJG8L=BO`-F&V87;C.*`C-BJ
MV8C8I]F&(-BTV*?8KMF'('9F<W)O;W0@V+'8IR#8KMF(V*?9AMBO`-F&V87;
MC.*`C-BJV8C8I]F&("5S(-BQV*<@V*C9AR`E<R`@V*K8NMN,VXS8L2#9AMBG
MV84@V*_8I]BO.B#9OMF(V+39AR#9A=F"V+78KR#8I]BR(-F"V*C9A"#9A=F(
MV*S9B-BO(-BGV+/8J@#9AMF%VXSB@(S8JMF(V*?9AB#8M-BGV*[9AR!61E,@
MV+'8IR#8JMBZVXS;C-BQ(-F&V*?9A2#8K]BGV*\`V8;9A=N,XH",V*K9B-BG
MV88@V+38I]BNV8<@5D93(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO
M.B`E<RX`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&4R`B)7,B
M(-BQV*<@V*K8NMN,VXS8L2#9AMBGV84@V*_8I]BO`-F&V87;C.*`C-BJV8C8
MI]F&(-F^V+'9B-F&V*_9AR!61E,@)7,O)7,@V+'8IR#8JMBZVXS;C-BQ(-F&
MV*?9A2#8K]BGV*\`V8;9A=N,XH",V*K9B-BGV88@V;[8L=F(V8;8K]F'(%9&
M4R#8L=BG(-BJV+K;C-N,V+$@V8;8I]F%(-BOV*?8KP#9AMF%VXSB@(S8JMF(
MV*?9AB`G;6MI<V]F<R<@V+'8IR#8I]BLV+'8IR#9AMF%V8C8KP#9AMF%VXSB
M@(S8JMF(V*?9AB#8I]N,V88@V+/9AMBO(%=O<F0@V+'8IR#8JMBQV*S9A=F'
M(-F&V879B-BO`"#9AMF%VXSB@(S8JMF(V*?9AB#8K]BQ(-F^V+'9B-F&V*_9
MAR`B)7,B(%9&4R`@V8;9B-BTV*H`(-F&V87;C.*`C-BJV8C8I]F&(-BOV+$@
MV;[8L=F(V8;8K]F'(%9&4R#9AMF(V+38JBX`V8;9A=N,XH",V*K9B-BGV88@
MV*_8L2#9OMBQV8C9AMBOV8?9E"#8K]BGV*_9AR!61E,@V8;9B-BTV*H`V++;
MC-BQV*[8M^*`C-BOV*?8L0#9B-BGVJ_8L=BOV*?9AMBOV88@V*K8NMN,VXS8
ML=BGV*H`V8C8I]JOV+'8K]BGV8;8K]F&(-BBV*[8L=N,V88@V+G9A=F$(-BT
MV878IP#9OMBGV+/8KB#8NMN,V+$@V879AMBJV+C8L=F'(-BGV+(@VJG8I]BQ
MV+/8I]BR(-BHV+$@V+'9B-N,(-BGV*K8M=BGV80Z`-F^V*?8L]BN(-BZVXS8
ML2#9A=F&V*K8N-BQV8<@V*?8LB#:J=BGV+'8L]BGV+(@V*C9ASH`V+K;C-BQ
M(-BMV8C8LMF'`%5N:6-O9&4@*%541BTX*0#9B-BGV*W8K]F'V*<`V*_8I]BO
MV8<@V8;8I]BTV8;8I]BNV*K9AP#9AMBGV84@VJG8I]BQV*C8L2#9B"#;C-BG
M(-BGV+/9A2#8L=F%V+(@V8;8I]BTV8;8I]BNV*K9AP#9@MBWV+D@V;[;C-F(
MV8;8KR#8N=F&V+78L2#9@=BYV83;C`#8J-N,(-F&V*?9A0#8K]BSV*H@XH",
MV8;9B-N,V+/9A]BGVXP@V*C8K]F(V88@V*?9A=BJVXS8I]BR(-BHV8<@V*_9
MA-N,V80@V*?9A=F&VXS8JMN,(-F&V87;C.*`C-BJV8C8I]F&V8;8KR#8I]BR
M(-BWV+';C-F"(-BHV+'9AMBGV879AR#9AMF(VXS8L]N,(-BHV+';C-BOV8<O
MV+'9B-F&V8C8M-BJ(-JOV+'9@=BJV8<OVH;8L]BHVXS8K]F'(-BTV8C9AMBO
M+B#:J=F$VXS8KR#8JMBCVXS;C-BO(-BQV*<@V8'8M-BGV+$@V*_9A]N,V*\@
MV*K8IR#9A=BJV88@V8'9AMN,XH",V*?B@(S;C-N,(-BQV*<@V*_8L2!M;WII
M;&QA+F]R9R#8J-BG(-BYV8;9B-BGV88@VH;:K]F(V8;:K]N,(-BOV+/8JMBQ
MV+/;C"#;C-JI(-BOV+/8JB#B@(S9AMF(VXS8LR#8J-F'(-BJV*[8JMF'V90@
MV+'8L]F%(-BQV*<@V878M-BGV8?8K]F'(-JIV8;;C-BO`-BQV8;:KR#8JMF&
MV+C;C-F%(-F&V+38K]F'`-BHV+/8MR#8J-BOV8C9AB#9OMBTV*K;C-BHV*?9
MAMN,`-BHV+'9B-BRV+'8L]BGV8;;C`#8J-BQV8C8LMBQV+/8I]F&VXP@)7,`
MV*C8L=F(V++8L=BSV*?9AMN,(-JIV*?8L=BHV+$`(B5S(B#8J-BQV8C8LMBQ
MV+/8I]F&VXP@V+38KP#8K]BSV*KB@(P@V8;9B-N,V+,@V*C9A]N,V8;9A^*`
MC-BSV*?8LMN,(-BMV+#9@2#8M-BO`-BGV+'8L]BGV80@VJG8L=BOV88`V*K9
MA=BGV84@V;[8L=F(V8;8K]F'XH",XH",V8?8I]N,(-BJV8;8N-N,V84@V*C8
ML=F&V*?9A=F'XH",V8?8I]N,(-JIV*?8L=BHV+'8K]N,(-BHV8<@VJG8I]BQ
MV+/8I]BR(-BGV+'8L]BGV80@V+38KP#8K=BQV8C9@2#8J-BRV+':KR#9A-BG
MV*K;C-F&`-BGV+G8K]BGV*\@VXS9B-F&V*?9AMN,(-BHV++8L=JO`"#8I]BS
MV*K9@=BGV*_9AR#9@=BYV83;C#H@)7,`V*?8L]BJV8'8I]BOV8<@V*?8LB!3
M4TP`V*?:K]BQ(-F&V*?9A2_8I]BSV84@V+'9A=BR(-BHV+'8I]N,(-JIV*?8
ML=BSV*?8LB!)35-0(-F%V*K9@=BGV8C8JB#8I]BSV*K8C"#8I]BSV*K9@=BG
MV*_9AR#:J=F&VXS8KP#:J=BGV+'8J-BQ("5S("#8J-BQV*?;C"`E<R#8I]BM
MV+'8I]BR(-F'V8C;C-F1V*H@V8;8M-BOV8<@V*?8L]BJ`-BSV+'9OMBQV+/8
MJMN,(-JIV*?8L=BHV+$`VJ_8LMN,V8;9A^*`C-F'V*?;C"#:J=BGV+'8J-BQ
M`-BKV*C8JB#9AMBGV84@VJG8I]BQV*C8L0#8J]BHV*H@VJG8I]BQV*C8L2#8
MJ-BQV*?;C"#8I]N,V88@V;[8I]N,VJ_8I]F'(-BZVXS8L2#9@=BYV*?9A"#8
MM-BOV8<@V*?8L]BJ`-BMV+/8I]BH(-JIV*?8L=BHV+$@V;[;C-BOV*<@V8;8
MM-BO`-F&V*?9A2#:J=BGV+'8J-BQ`-F&V*?9A2#:J=BGV+'8J-BQ.@#9AMBG
MV84@VJG8I]BQV*C8L3H@`-JIV*?8L=BHV+'8I]F&(-BSV*?9A=BGV8;9ASH`
MV+38I]BNV8<@5D93(-F(V*S9B-BO(-F&V*_8I]BQV*\`V*K8N=BWVXS9A-BG
MV*H`V879B-F"V+G;C-BJV8?8I]N,(-F%V+G8JMBHV+$@VXS8I]F!V*K9AR#8
MM-BOV8<@V+G8J-BGV+'8JMF&V*\@V*?8LCH`V*?8N=BJV*C8I]BQ`-F%V8+8
MK]BGV+$@V*C9AR#8K]F"VXS9@MF'(-BGV+(@V*W8I]F$V*<`V879@MBOV*?8
ML2#8I]BR(-BHVXS8M-N,V8;9AR#8M]F(V80@V878K-BGV+(@)7,@V*C;C-BT
MV*K8L2#8I]BSV*H`V879@MBGV*_;C-BQ`-F%V8+8I]BOVXS8L2#8J-BQV*?;
MC"#8I]F&V*K8KMBGV*@@V*?8L@#9A=BJV+K;C-N,V+$`V8;8L]BNV8<`VJG9
MAMBJV+'9A"#9AMBSV*[9AP#8JMBQV*?8LB#8N=F%V8C8K]N,`-F!V*?8M=F$
MV8?B@(S:K]BPV*?8L=N,(-BYV879B-BOVXP`V+G9A=F(V*_;C#H`V*[;C-F$
MVXP@V*C8I]F$V*<`5FEE=&YA;65S92`H5DE30TE)*0#9AMF%V*?;C"`E<P#9
MAMF%V*?;C"#;C-JI(-BUV8'8K=F'(-F(V*@@V*[8I]BQV*S;C``@V8;9A=BG
M(-BHV8<@V+G9AMF(V*?9AB`E<P#9@MBGV*C9A-N,V*H@V878M-BGV8?8K]F'
M`-F"V*?8J-F$VXS8JB#9A=BTV*?9A]BOV8<Z(`#8I]BNV+?8I]BQ(2$A(-BO
MV+/8JB#B@(S9AMF(VXS8LR#8L=BG(-BHV+?9B-BQ(-BOV+/8JMN,(-BGV+(@
M)7,@V*W8L-F!(-JIV8;;C-BO`-BGV*[8M]BGV+$Z(`#:AMF'V*?8L=BTV8;8
MJ-F'`-F^VXS8M.*`C-BHVXS9AMN,(-F'V8C8IP#8K]BGV*_9AR#8HMBH(-F(
M(-F'V8C8I]N,VXP@V8'8L=BGV8?9A2#8M-BOV8<@V*C9AR#9B-BSVXS9A-F'
M`'=E871H97(N8V]M`-F(V*@`V8C8J.*`C-JOV*?9AP#9A]F!V*K:K]N,`-BN
MV8C8M"#8HMF%V*_;C-BO`-BHV8<@)7,@V*[9B-BT(-BBV878K]N,V*\`)7/8
MC"#8KMF(V+0@V*+9A=BOVXS8KP!797-T97)N("A)4T\M.#@U.2TQ*0!797-T
M97)N("A)4T\M.#@U.2TQ-2D`VH;9AR#8J-BQV8;8I]F%V8?9E"#:J=BGV+'8
MJ-BQV*_;C"#8L=BG("5S(-BHV*?;C-BO(-BHV+G8KR#8I]BR(-F(V+'9B-BO
M(-F&V+38I]F&(-BOV8?8K]B?`-F&V8C;C-BSV8?9E.*`C"#8K=BGV*;9A"#:
MAMN,V+/8JMB?`-F&V8C;C-BSV8?B@(S;C"#9AMF"V80@V8+9B-F$(-J&VXS8
ML]BJV)\`VJG8K]BGV84@V8'8I]BR`-JIV*_8I]F%(-BHV+'9AMBGV879A^*`
MC-F'V*?;C"#9A=BJV+79A.*`C-JIV8;9AMBOV8<@XH",V*C8L=BGVXP@V8C;
MC-BQV*?;C-BTVJ_8L2#9A=BJV88@V8'8N=BGV80@V*C8I]BTV8;8KP#8N=BQ
MV+8`(-F^V8?9AMBG(-BOV+$@V8C8I]BMV*\@0U-3(`#9OMF'V8;8I]N,(-JO
MV++;C-F&VJ_8I]F&("5S(-BOV+$@V+'8I]BSV*H@*-BOV+$@V8C8L=F(V*\@
MV*C8N=BOVXP@V879B-BKV+$@V87;C.*`C-JOV+'8K]BO*3H`V;[9A]F&V*?;
MC"#8K-BOV8C9A`#9B-BGV*W8KR#9OMF'V8;8IP#9OMF'V8;8ISH`5VEK:0#8
MJ-BGV*\Z`-BHV*?8KR#8LMF(V*_9A]F&VJ_8I]F%.B``V+/8L=BYV*H@V*C8
MI]BO(-BHV+'8K=BSV*@@V8'9B-BJ(-BHV+$@V+/8I]BYV*H`V*C8I]BO.@#8
MJ-BGV*\Z(`#8N=F"V80`VJG8I]BQ`-BBV*_8L=BS(-F%V*W9A"#:J=BGV+$`
MV*K9A-F!V88@V878K=F$(-JIV*?8L0#B@(Q960!965E9`-BSV*?9A-BGV8;9
MAP#8HMBQVXP`V*C9A-F'V(P@V879B-BGV8'9@MF%`-BTV878IR#8K]BQ(-F%
MV*\@V878JMF&(-F'V+/8JMN,V*\N(-BGV+(@V*_:J=F%V8<@(%L\/ET@V*C8
ML=BGVXP@V*C8L=JOV+38JMF&(-BHV8<@5UE325=91R#8I]BSV*K9@=BGV*_9
MAR#:J=F&VXS8KP#8M-F%V*<@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-F&V+38
MK]N,V*\`V+39A=BG(-F&V87;C.*`C-BJV8C8I]F&VXS8KR#9AMF(VXS8L]F'
M("=<)R#8L=BG(-BOV+$@V8;8I]F%(-JIV*?9A=F$(-BNV8C8KR#8K]BGV+38
MJMF'(-BHV*?8M-N,V*\`V+39A=BG(-BBV*_8L=BS(-F^V+/8JB#8I]F$VJG8
MJMBQV8C9AMN,VJD@V878N=BJV*C8L=N,(-F(V*?8L=BO(-F&VJG8L=BOV8?B
M@(S8I]N,V*\`V+39A=BG(-F'VXS:AB#9@=N,V838K]N,(-BQV*<@V*_8L2#9
MOMBQV8C9AMBOV8<@V*_8L=F(V8;B@(S8J-BQV*\@V+38K]F'(-BHV8<@V8';
MC-F$V*\@V878JMF"V*?8J-F$VXP@V*_8L2`E<R#9AMJOV*?8M-BJ(-F&VJG8
ML=BOV8?B@(S8I]N,V*\`V+39A=BG(-BNV*?8L=BL(-BTV*_;C-BO`-BTV878
MIR#9A=BLV*C9B-BQ(-F'V+/8JMN,V*\@VXS:J2#8M-F%V*?8L=F'(-BJV839
M@=F&(-F%V+G8JMBHV+$@V8C8I]BQV*\@VJG9AMN,V*_8C"#8I]BR(-BYV838
MI]F%V*H@)RLG(-BHV+'8I]N,(-BTV878I]BQV8?B@(S9A]BGVXP@V*C;C-F&
M(-BGV839A=F$V83;C"#8I]BSV*K9@=BGV*_9AR#:J=F&VXS8KP#8M-F%V*<@
MV878K-BHV8C8L2#9A]BSV*K;C-BO(-N,VJD@V879@MBOV*?8L2#9A=BYV*K8
MJ-BQ(-F(V*?8L=BO(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-F^
MV+38JMN,V*C8I]F&(-BOV+'8KMBJ(-BOV*?8K]F'(-BHV+'8I]N,(-BGV+/8
MJMF!V*?8K]F'(-BGV+(@V*O8J-BJ(-F&V*?9A2#9OMN,VJG8L=BHV8;8K]N,
M(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-BSV*?9A=BGV8;9AR#9
MOMBTV*K;C-BHV*?9AB!61E,@V+'8IR#9OMN,VJG8L=BHV8;8K]N,(-JIV8;;
MC-BO`-F"V*C9A"#8I]BR(-BGV+'8L]BGV80@VJ_8LMBGV+'8M-B,(-BHV*?;
MC-BO(-F%V+3:J=F$(-BQV*<@V+38L=BM(-BOV8?;C-BO`-BTV878IR#8J-BG
MVXS8KR!54DS8I]N,(-JIV8<@V*?;C-F&(-F^VXS9B-F&V*\@V*C9AR#8HMF&
M(-BGV+38I]BQV8<@V87;C.*`C-JIV8;8KR#8L=BG(-F(V*?8L=BO(-JIV8;;
MC-BO`-BTV878IR#8J-BGVXS8KR#;C-JI(-JIV*?8L=BSV*?8LMB,(-BHV+'8
MI]N,(-BMV+#9@2#:J=BQV*_9AB#8I]F&V*K8KMBGV*@@VJG9AMN,V*\`V+39
MA=BG(-BHV*?;C-BO(-N,VJD@V8;8I]F%(-JIV*?8L=BHV+'8C"#8J-BQV*?;
MC"#8K=BPV8$@VJG8L=BOV88@V878M-BNV+4@VJG9AMN,V*\`V+39A=BG(-BH
MV*?;C-BO(-N,VJD@V8;8I]F%(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8K=BP
MV8$@V+38K]F&(-F%V+38KMBU(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8KR#;
MC-JI(-F&V*?9A2#:J=BGV+'8J-BQV(P@V*C8L=BGVXP@V*?8MMBGV8'9AR#:
MJ=BQV*_9AB#9A=BTV*[8M2#:J=F&VXS8KP#8M-F%V*<@V*C8I]N,V*\@VXS:
MJ2#8M-F&V*?8L]F'(-JIV*?8L=BHV+'8C"#8J-BQV*?;C"#8J-BQV8C8LMBQ
MV+/8I]F&VXP@V*?9AMBJV*[8I]BH(-JIV8;;C-BO`-BTV878IR#8J-BGVXS8
MKR#9A=BTV*[8M2#:J=F&VXS8KR#:J=F'(-J&V8<@V+G9A=F$VXP@V*C8I]N,
MV*\@V*?9AMBLV*?9A2#:K]N,V+'8KP#8M-F%V*<@V*C8I]N,V*\@V8;8I]F%
M(-BLV*_;C-BO(-BOV+/8JMF'(-BQV*<@V*K8I]N,V;X@VJG9AMN,V*\`V8;8
MM-BSV*H@)7,@V+39A=BG(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8JBX@V838
MM]F!V*?9BR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39B-N,V*\`V*+8K]BQ
MV+,@V*?9A-JIV*K8L=F(V8;;C-JIVXP@V+39A=BG`-BBV*_8L=BS(-F!V+'8
ML]BJV8;8K]F'.B#8M-F%V*<Z`-BGV+?9A-BGV+G8I]BJ(-BTV878IP#8HMBO
MV+'8LR#8I]N,V8;8JMBQV8;8JMN,(-BTV878IR#9AMBSV*C8JB#8J-F'(-BG
MV*C8JMBOV*?;C"#9AMBTV+/8JB`E<R#8M-F%V*<@V*K8NMN,VXS8L2#:J=BQ
MV*_9AR#8I]BSV*HNV*C8L=BGVXP@V+'8N=BGVXS8JB#9A=BSV*?8IMF$(-BG
MV879AMN,V*K;C"#8J-BGVXS8KR#8K]F(V*C8I]BQV8<@V8C8I]BQV*\@V+39
MB-N,V*\`V8;8I]F%(-BTV878IP#8L]BGV878I]F&V8<@V;[8M-BJVXS8J-BG
MV88@V*K8M=BOVXS9@B#9A]F(VXS9D=BJ(-BTV878IR#9@=F'V+'8L]BJ(-JI
MV+'8K]F&(-JIV*?8L=BHV+'8I]F&(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9
MAMF%VXSB@(S:J=F&V*_8C"#;C-BG(-BTV*?;C-BO(-BHV8;8IR#8J-F'(-BO
MV83;C-F$(-BOVXS:K]BQVXP@V*?;C-F&(-JIV*?8L2#8I]F&V*S8I]F%(-F&
MV87;C.*`C-BTV8C8KP#8N-BGV8?8L2#9A=BQV8C8L=JOV+$@V+39A=BG(-F&
MV+/8J-BJ(-BHV8<@V*?8J-BJV*_8I]N,(-F&V+38L]BJ("5S(-BTV878IR#8
MJMBZVXS;C-BQ(-JIV+'8K]F'(-BGV+/8JB[8J-BQV*?;C"#8L=BYV*?;C-BJ
M(-F%V+/8I]BFV80@V*?9A=F&VXS8JMN,(-BHV*?;C-BO(-BOV8C8J-BGV+'9
MAR#9B-BGV+'8KR#8M-F(VXS8KP#9A=BQV8C8L=JOV+$@V+39A=BG(-BGVXS9
MAB#9A=BTV*[8M=F'(-BQV*<@V;[8M-BJVXS8J-BGV8;;C"#9AMF%VXSB@(S:
MJ=F&V*\N`-BRV878I]F&(-F!V+G9A-N,(-F%V8;8M]F"V8<@V*S8NMBQV*?9
M@=N,V*?;C-N,(-BTV878ISH`V8?9B-N,V9'8JB#9OMN,V+0@V8'8L=BV(-BT
MV878ISH`V8;8I]F%(-JIV*?9A=F$(-BTV878ISH`V8C8L=F(V*\@V+39A=BG
M(-F%V8;9@MBVVXP@V+38K]F'(-BGV+/8J@#8I]BSV84@V+'9A=BR("#8K-BO
MVXS8KR#8M-F%V*<@V*C8L=BGVXP@)7,@V8?8L]BJ.B`E<P#:K]BRVXS9AMF'
MXH",V8?8I]N,(-BTV878IR#8J-BQV*?;C"#8M]F(V80@V*?;C-F&(-F&V+38
ML]BJ(-BHV+'9B-BRV+'8L]BGV8;;C"#8M-BOV8<@V*?8L]BJ(`#:K]BRVXS9
MAMF'XH",V8?8I]N,(-BTV878IR#8J-BQV8C8LMBQV+/8I]F&VXP@V+38K]F'
M(-BGV+/8J@#8I]BSV84@V+'9A=BR("#8M-F%V*<@V*C8I]BRV8;8M-BGV8;;
MC"#8M-BOV8<@V*?8L]BJ`-BGV+/9A2#8L=F%V+(@V+39A=BG(-BHV*?8LMF&
MV+38I]F&VXP@V+38K]F'(-BGV+/8JMB,(-F^V+/8JB#8I]F$VJG8JMBQV8C9
MAMN,VJD@V*[9B-BO(-BQV*<@VH;:J2#:J=F&VXS8KR#9B"#8J-BG(-BGV+/9
MA2#8L=F%V+(@V*S8K]N,V*\@V*[9B-BO(-F(V*?8L=BO(-BTV8C;C-BO`-BG
MV+/9A2#8L=F%V+(@(-BTV878IR#9A=F&V8+8MMN,(-BTV*_9AR#8I]BSV*H`
MVJG8I]BQV+/8I]BRXH",V8?8I]N,(-BQV*?9A^*`C-BOV8C8L2#8M-F%V*<Z
M`%O9OMF&V8?8I]F&(-JIV+'8K]F&(-F%V*K9AB#9AMF"V80@V8+9B-F$(-BT
MV*_9AUT`6]JOV++8I]BQV+0@V878M-JIV81=(`!;V8;9A=BGVXS8M"#9A=BJ
MV88@V8;9@MF$(-F"V8C9A"#8M-BOV8<@+0#9AMF%V*?;C-BT(-F%V*K9AB#9
MAMF"V80@V8+9B-F$(-BTV*_9AUL@+2`E<R#8KMBW70!;V*[8MR`E<R#8I]BR
M("5S(%T@`-BSV+'9OMBQV+/8JMN,`$-,20#8K]BQV*[8JB#8K]BGV*_9AP#8
MK=BPV8$@V+/8M]BQ`-JOV+'9B-F')B-X,C`P8SO9A]BG`-BQV*?9A]F&V878
MIP#8KMBUV8C8M=N,V*?8JB#8JMBUV8C;C-BQ+BXN`-F(V+'9B-BO`-BNV+'9
MB-BL`-BJV+K;C-N,V+$@V;[;C-F(V8;8KRXN+@#:K]BRVXS9AMF'XH",V8?8
MIP#9A=BLV8C8LMF'V*<`V*W8L-F!(-F^VXS9B-F&V*\N+BX`V+'8I]F')B-X
M,C`P8SO8I]F&V*_8I]BRVXP`V*[8M=F(V+7;C-BGV*H@V*S8K]F(V80N+BX`
MVJG8I]BQV*C8L=BGV88`VJG8JMBGV*C:AMF'V90@V*+8K]BQV+,@`-BJV8+9
MB-N,V84`V*+8L=BGV84`V*?;C-F&V*S8IR#8L=BG(-F!V+38I]BQ(-BOV8?;
MC-BO`-F^V+'9B-F&V*_9AP#8I]BR("5S("@E<RD@V*_8L2`E<R`E<P#8J-BG
MV*\`:#H`V8'9B-BQV*?9BP#8K]BQV*[8MP#8KMBWV8C8MUT`V8;8I]F%`-F^
MVXS8I]BOV8<@V+/8I]BRVXP@V8;8M-BOV8<`V8?9AMF(V+(@V;[;C-BGV*_9
MAR#8L]BGV++;C"#9AMBTV*_9AR#8I]BSV*H`;F]T97!A9`#8K]BQV+78KP#9
MOMN,VJG8L]F$V8?8IP#8M]F$V8C8N0#9AMF%V*?;C-BT(-BJV8'8I]F(V*K9
MA]BG`-F^VXSB@(S8K]BQV;[;C`#9@=F'V+'8L]BJ(-F(V+C;C-F!V8<`V*?8
ML]F%(-BQV878LB#8L=BG(-BHV+'8I]N,(-BJV*/;C-N,V*\@V*_9B-BHV*?8
ML2#9B-BGV+'8KR#:J=F&VXS8KP#;C-JOV*?9AMF'(-BTV*_9AP#8J-N,(-F&
MV*?9A0#8I]F&V*K8KMBGV*@@VJG8I]BQV*C8L0!V0V%R9`!W.@!W96%T:&5R
M+F-O;0``````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V5L7T=2
M+TQ#7TU%4U-!1T53````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,30V-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O96Q?1U(O:&5L<"YX;6P`````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,S,C`@,3`U,34T,S0Q-#$@,#(Q-#,P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M>&UL('9E<G-I;VX](C$N,"(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE
M+V5L7T=2+VAE;'`N>&UL+'8@,2XR(#(P,#0O,#4O,C<@,C`Z,C(Z,38@:F%N
M($5X<"`D("TM/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E
M/2)N97<B/@H\=&ET;&4^5&AE(%!O<G1A;"!086=E/"]T:71L93X*(#QP87)A
M/@H@(%1H:7,@<&]R=&%L('!A9V4@<')O=FED97,@82!Q=6EC:R!S=6UM87)Y
M(&]F(&%L;"!Y;W5R(&EM<&]R=&%N=`H@(&EN9F]R;6%T:6]N+B!&;W(@97AA
M;7!L92P@:70@;6EG:'0@<VAO=R!H;W<@;6%N>2!N97<@92UM86EL(&UE<W-A
M9V5S('EO=0H@(&AA=F4@:6X@>6]U<B!)3D)/6"P@=7!C;VUI;F<@979E;G1S
M(&]N('EO=7(@8V%L96YD87(L('1A<VMS(&]N('EO=7(@=&\M9&\*("!L:7-T
M+"!H96%D;&EN97,@9G)O;2!S96QE8W1E9"!N97=S('-E<G9I8V5S+"!A;F0@
M<V\@;VXN("!-86YY(&]F('1H97-E"B`@<W5M;6%R:65S('=I;&P@8V]N=&%I
M;B!Q=6EC:R!S:&]R=&-U=',@=&\@8V]M;6]N(&9U;F-T:6]N<RP@<W5C:"!A
M<PH@(&-O;7!O<VEN9R!A(&YE=R!M86EL(&UE<W-A9V4L(&-R96%T:6YG(&$@
M;F5W(&-A;&5N9&%R(&5V96YT(&]R('1A<VLL(&5T8RX*(#PO<&%R83X*(#QP
M87)A/@H@(%1H92!C;VYT96YT<R!O9B!T:&ES('!O<G1A;"!P86=E(&%R92!C
M=7-T;VUI>F%B;&4@=FEA('1H92!,87EO=70@8G5T=&]N+@H@($9O<B!E>&%M
M<&QE+"!Y;W4@8V%N(&-H;V]S92!W:&EC:"!I=&5M<R!T;R!I;F-L=61E(&]N
M('1H:7,@<&]R=&%L('!A9V4@87,*("!W96QL(&%S(&EN('=H:6-H(&]R9&5R
M('1H97D@87)E('-H;W=N+@H@/"]P87)A/@H\+V5N=')Y/@H@(#QE;G1R>2!I
M9#TB;F%V8F%R(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H92!!<'!L:6-A=&EO
M;B!.879I9V%T:6]N($)A<CPO=&ET;&4^"B`\<&%R83X*("!!="!T:&4@;&5F
M="!H86YD('-I9&4@;V8@=&AE('=E8B!P86=E(&ES('1H92!A<'!L:6-A=&EO
M;B!N879I9V%T:6]N(&)A<BX*("!#;&EC:R!O;B!T:&4@:6-O;G,@;VX@=&AI
M<R!N879I9V%T:6]N(&)A<B!T;R!Q=6EC:VQY(&%N9"!E87-I;'D@<W=I=&-H
M"B`@8F5T=V5E;B!T:&4@879A:6QA8FQE(&%P<&QI8V%T:6]N<RX*(#PO<&%R
M83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA:6YT96YA;F-E
M(B!S=&%T93TB;F5W(CX*("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E
M;F%N8V4Z($1O($UA:6YT96YA;F-E/"]T:71L93X*("`@(#QP87)A/@H@("`@
M268@>6]U('=O=6QD(&QI:V4@=&\@<&5R9F]R;2!M86EN=&5N86YC92!O<&5R
M871I;VYS(&]N(&QO9VEN+"!C:&5C:R!T:&ES(&)O>"X*("`@(#PO<&%R83X*
M/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+6-O;F9I<FU?;6%I;G1E;F%N
M8V4B('-T871E/2)N97<B/@H@("`@/'1I=&QE/E!R969E<F5N8V5S.B!-86EN
M=&5N86YC93H@0V]N9FER;2!-86EN=&5N86YC93PO=&ET;&4^"B`@("`\<&%R
M83X*("`@($EF('EO=2!W;W5L9"!L:6ME('1O(&-O;F9I<FT@86QL(&UA:6YT
M96YA;F-E('1A<VMS(&)E9F]R92!T:&5Y(&%R92!R=6XL(&-H96-K('1H:7,@
M8F]X+B!)9B!L969T('5N8VAE8VME9"P@86QL(&UA:6YT96YA;F-E(&]P97)A
M=&EO;G,@=&AA="!N965D('1O(&)E(')U;B!W:6QL(&)E('!E<F9O<FUE9"!A
M=71O;6%T:6-A;&QY('=I=&@@;F\@8VAA;F-E('1O(&-A;F-E;"!O;B!L;V=I
M;BX*("`@(#PO<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&]C86QE+V5L7T=2+TQ#7TU%4U-!1T53+VAO<F1E+FUO````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,S4W-S$Q(#$P-3$U-#,T,30Q(#`R,S(R,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#>$@25````
M``L&```<````=#````\(``#,8`````````B!```E````"8$``$@````O@0``
M#@```'B!```/````AX$```T```"7@0``"````*6!```+````KH$```P```"Z
M@0``!````,>!```,````S($```\```#9@0``"P```.F!```1````]8$```X`
M```'@@``*````!:"```(````/X(```H```!(@@``%0```%."```2````:8(`
M``L```!\@@``%````(B"```F````G8(``"<```#$@@``)@```.R"```.````
M$X,```H````B@P``)P```"V#```@````58,```X```!V@P``%P```(6#```B
M````G8,``#4```#`@P``$0```/:#```-````"(0```P````6A```#0```".$
M```;````,80``"T```!-A```'0```'N$```D````F80``"D```"^A```&0``
M`.B$```/`````H4``!@````2A0``#````"N%```.````.(4```X```!'A0``
M"````%:%```B````7X4``!H```""A0``,@```)V%```X````T(4``%0````)
MA@``40```%Z&``!:````L(8``%<````+AP``-````&.'```%````F(<``!$`
M``">AP``"````+"'```)````N8<```D```##AP``#@```,V'```(````W(<`
M`"4```#EAP``(`````N(```0````+(@```\````]B```"@```$V(```'````
M6(@```,```!@B```#P```&2(```4````=(@```D```")B```#0```).(```2
M````H8@``!D```"TB```'@```,Z(```/````[8@```H```#]B```#P````B)
M```(````&(D``"0````AB0``%P```$:)```4````7HD``!8```!SB0``"```
M`(J)``!.````DXD``"T```#BB0``&0```!"*```'````*HH```P````RB@``
M+````#^*```.````;(H```X```![B@``%@```(J*```%````H8H```4```"G
MB@``"@```*V*```#````N(H``!<```"\B@``"@```-2*```/````WXH```X`
M``#OB@``&````/Z*```C````%XL```X````[BP``%````$J+```7````7XL`
M`!<```!WBP``%P```(^+```3````IXL```\```"[BP``'P```,N+```1````
MZXL``!$```#]BP``#P````^,```&````'XP```L````FC```$````#*,```5
M````0XP``!4```!9C```!P```&^,```%````=XP```X```!]C```$0```(R,
M```,````GHP``#L```"KC```.````.>,```#````((T```D````DC0``.0``
M`"Z-```2````:(T```\```![C0``.0```(N-```G````Q8T``"P```#MC0``
M*@```!J.```E````18X```D```!KC@``"@```'6.```&````@(X``!4```"'
MC@``&0```)V.```I````MXX``"0```#AC@``$0````:/```1````&(\```H`
M```JCP``$````#6/```6````1H\``!8```!=CP``!````'2/```G````>8\`
M``@```"ACP``"````*J/```I````LX\```X```#=CP``"@```.R/```$````
M]X\```<```#\CP``!`````20```&````"9````T````0D```%P```!Z0```#
M````-I```!,````ZD```"````$Z0```0````5Y````D```!HD```!````'*0
M``!!````=Y```"````"YD```!@```-J0```5````X9```!@```#WD```(@``
M`!"1```N````,Y$``!T```!BD0``(0```("1``!4````HI$``"D```#WD0``
M!P```"&2```5````*9(```H````_D@``#P```$J2```-````6I(```\```!H
MD@``#0```'B2```)````AI(```8```"0D@``$P```)>2```4````JY(```P`
M``#`D@``!@```,V2```/````U)(``%0```#DD@``!````#F3```.````/I,`
M`$0```!-DP``#0```)*3```3````H),``!$```"TDP``$0```,:3```1````
MV),``!P```#JDP``*@````>4```3````,I0``"$```!&E```!0```&B4```3
M````;I0``!(```""E```"@```)64```/````H)0``!$```"PE```"@```,*4
M```1````S90```P```#?E```$````.R4```1````_90```4````/E0``#```
M`!65```0````(I4```4````SE0``#0```#F5```&````1Y4```<```!.E0``
M#0```%:5```'````9)4```L```!LE0``!P```'B5```)````@)4``!0```"*
ME0``"0```)^5```*````J94``!D```"TE0``/0```,Z5```=````#)8``!T`
M```JE@``#````$B6```0````598``!(```!FE@``$P```'F6```K````C98`
M`#L```"YE@``(````/66```.````%I<``#8````EEP``$````%R7```;````
M;9<```@```")EP``!````)*7```.````EY<``!X```"FEP``&P```,67```A
M````X9<``!X````#F```&0```"*8```>````/)@``!L```!;F```+@```'>8
M```F````II@``!L```#-F```'@```.F8```<````")D``"8````EF0``*P``
M`$R9```S````>)D``"8```"LF0``*P```-.9```X````_YD``!T````XF@``
M%0```%::```O````;)H``!(```"<F@``(````*^:```I````T)H``!X```#Z
MF@``$@```!F;``"B````+)L``!8```#/FP``(P```.:;```H````"IP``"D`
M```SG```*````%V<```?````AIP``!4```"FG```(````+R<```E````W9P`
M`"@````#G0``+0```"R=```P````6IT``)(```"+G0``(0```!Z>```6````
M0)X``!P```!7G@``)@```'2>```J````FYX``$$```#&G@``1`````B?```,
M````39\```<```!:GP``!P```&*?```&````:I\```T```!QGP``$````'^?
M```2````D)\``!,```"CGP``$@```+>?```'````RI\```T```#2GP``#```
M`."?```.````[9\```\```#\GP``$P````R@```-````(*```"@````NH```
M`P```%>@```-````6Z````(```!IH```!0```&R@```$````<J```!````!W
MH```%@```(B@```$````GZ````T```"DH```#@```+*@```#````P:````X`
M``#%H```"````-2@```/````W:````@```#MH```#P```/:@```'````!J$`
M``T````.H0``$````!RA```3````+:$``!,```!!H0``"P```%6A```1````
M8:$```D```!SH0``!@```'VA```,````A*$``!$```"1H0``&0```*.A```+
M````O:$```T```#)H0``(@```->A```;````^J$``#0````6H@``"@```$NB
M```8````5J(``!D```!OH@``%@```(FB```O````H*(``"(```#0H@``#0``
M`/.B```,`````:,``"8````.HP``%````#6C```+````2J,``"(```!6HP``
M+P```'FC```+````J:,```D```"UHP``&0```+^C```+````V:,``!<```#E
MHP``%P```/VC```)````%:0``!8````?I```#P```#:D```6````1J0```X`
M``!=I```&````&RD```-````A:0``"8```"3I```0P```+JD```(````_J0`
M``L````'I0``+P```!.E```.````0Z4```4```!2I0``!````%BE```*````
M7:4```H```!HI0``#P```'.E```0````@Z4``!<```"4I0``$0```*RE```7
M````OJ4``!D```#6I0``#P```/"E```*`````*8```4````+I@``#0```!&F
M```;````'Z8``!<````[I@``"0```%.F```.````7:8```T```!LI@``$@``
M`'JF```X````C:8``"````#&I@```P```.>F```(````ZZ8```X```#TI@``
M>P````.G```8````?Z<```4```"8IP``&````)ZG```9````MZ<``!,```#1
MIP``!@```.6G```&````[*<``!````#SIP``#P````2H```0````%*@```\`
M```EJ```"P```#6H```/````0:@```P```!1J```#P```%ZH```'````;J@`
M``8```!VJ```#@```'VH```@````C*@``!T```"MJ```#````,NH```H````
MV*@```\````!J0``"````!&I```(````&JD``!,````CJ0``'@```#>I```A
M````5JD``"````!XJ0``&0```)FI```7````LZD``"4```#+J0``%P```/&I
M``!"````":H```0```!,J@``#````%&J```#````7JH```@```!BJ@``"@``
M`&NJ```,````=JH```L```"#J@``$````(^J```,````H*H``!,```"MJ@``
M%````,&J```,````UJH```D```#CJ@``#@```.VJ```+````_*H``!L````(
MJP``!P```"2K```*````+*L```T````WJP``"0```$6K```$````3ZL```4`
M``!4JP```P```%JK```8````7JL```H```!WJP``!````(*K```F````AZL`
M`!4```"NJP``!0```,2K```'````RJL```P```#2JP``"````-^K```*````
MZ*L```8```#SJP``"````/JK```"`````ZP```8````&K```%0````VL```/
M````(ZP``!$````SK```&@```$6L```$````8*P```D```!EK```$````&^L
M```1````@*P```D```"2K```"0```)RL```:````IJP```@```#!K```"@``
M`,JL```.````U:P```(```#DK```!@```.>L```2````[JP``!0````!K0``
M'0```!:M```1````-*T```8```!&K0``$0```$VM```1````7ZT```D```!Q
MK0``'@```'NM```&````FJT```0```"AK0``$0```*:M```&````N*T```H`
M``"_K0``$0```,JM```B````W*T```0```#_K0``)0````2N```%````*JX`
M``0````PK@``#````#6N```*````0JX```4```!-K@``"P```%.N```,````
M7ZX```X```!LK@``(````'NN```/````G*X``!(```"LK@``"P```+^N```F
M````RZX``"D```#RK@``)````!RO```F````0:\```@```!HKP``"@```'&O
M```)````?*\``"````"&KP``(````*>O```F````R*\```4```#OKP``"@``
M`/6O```9`````+```"D````:L```%@```$2P```&````6[```!(```!BL```
M"@```'6P```,````@+````\```"-L```$````)VP``!`````KK```'````#O
ML```9@```&"Q```.````Q[$```D```#6L0``$@```."Q```3````\[$```P`
M```'L@``!@```!2R```&````&[(```X````BL@``#P```#&R```2````0;(`
M`!````!4L@``"@```&6R```1````<+(``!P```""L@``(P```)^R``!J````
MP[(```\````NLP``$````#ZS```$````3[,```L```!4LP``%````&"S```,
M````=;,```P```""LP``#P```(^S```5````G[,``"D```"ULP``*@```-^S
M```F````"K0``"<````QM```*0```%FT```J````@[0``!D```"NM```0@``
M`,BT```1````"[4``!(````=M0``$P```#"U```4````1+4```\```!9M0``
M%@```&FU```7````@+4``!````"8M0``$0```*FU```T````N[4``!,```#P
MM0``$@````2V```U````%[8``!0```!-M@``!P```&*V```,````:K8``"L`
M``!WM@``(````*.V```4````Q+8``!$```#9M@``%P```.NV```<`````[<`
M`!,````@MP``$0```#2W```:````1K<``!X```!AMP``&@```("W```1````
MF[<``!<```"MMP``%````,6W```7````VK<``!4```#RMP``"0````BX```&
M````$K@```<````9N```!````"&X```$````)K@```<````KN```#@```#.X
M```,````0K@```P```!/N```#0```%RX```0````:K@``!$```![N```$```
M`(VX```.````GK@``!$```"MN```*````+^X```/````Z+@```X```#XN```
M#`````>Y```/````%+D```H````DN0``"````"^Y```)````.+D``"L```!"
MN0``!````&ZY```+````<[D```X```!_N0``!P```(ZY```.````EKD```D`
M``"EN0``#````*^Y```-````O+D```X```#*N0``%@```-FY```1````\+D`
M``,````"N@``!@````:Z```9````#;H```0````GN@``"P```"RZ```+````
M.+H```@```!$N@``#@```$VZ```$````7+H```\```!AN@``.@```'&Z```%
M````K+H```P```"RN@``'@```+^Z```.````WKH``!````#MN@``"P```/ZZ
M```:````"KL```H````ENP``#````#"[```/````/;L```@```!-NP``!@``
M`%:[```'````7;L```L```!ENP``7````'&[```-````SKL```8```#<NP``
M"0```..[```$````[;L```,```#RNP``$P```/:[```3````"KP``!,````>
MO````@```#*\```%````-;P```0````[O```"@```$"\```-````2[P``&@`
M``!9O```!@```,*\```8````R;P``!$```#BO```!0```/2\```&````^KP`
M`!L````!O0``+P```!V]```/````3;T``!,```!=O0``&P```'&]```8````
MC;T``!<```"FO0``#@```+Z]```#````S;T``!0```#1O0``$P```.:]```0
M````^KT```T````+O@``#@```!F^```6````*+X```<````_O@``!0```$>^
M```*````3;X```L```!8O@``!P```&2^``!1````;+X``!````"^O@``#```
M`,^^```-````W+X``!H```#JO@``2@````6_```&````4+\``!H```!7OP``
M!@```'*_```&````>;\```D```"`OP``&````(J_```7````H[\```8```"[
MOP``#0```,*_```B````T+\``%<```#SOP``$P```$O````C````7\```!,`
M``"#P````@```)?````+````FL````@```"FP```#0```*_````*````O<``
M``H```#(P```#@```-/````'````XL```!,```#JP```"P```/[````)````
M"L$```D````4P0``"@```![!```'````*<$```D````QP0``!P```#O!```;
M````0\$``!(```!?P0``"@```'+!```)````?<$``!````"'P0``"@```)C!
M```0````H\$``!(```"TP0``!````,?!```,````S,$```<```#9P0``!0``
M`.'!```,````Y\$```@```#TP0``#````/W!```4````"L(``!<````?P@``
M$P```#?"```$````2\(```H```!0P@``!````%O"```)````8,(```H```!J
MP@``#````'7"```"````@L(``#@```"%P@``+````+["```2````Z\(``"D`
M``#^P@``,@```"C#```*````6\,``#8```!FPP``+````)W#```N````RL,`
M`#,```#YPP``/````"W$```Z````:L0``#L```"EQ```,P```.'$```^````
M%<4``#@```!4Q0``#P```(W%```8````G<4``!````"VQ0``#P```,?%```3
M````U\4``!0```#KQ0``$@````#&```4````$\8``!4````HQ@``$P```#[&
M```=````4L8```@```!PQ@``"````'G&```K````@L8``"$```"NQ@``&@``
M`-#&```)````Z\8``$4```#UQ@``00```#O'```/````?<<```0```"-QP``
M$P```)+'```3````IL<```D```"ZQP``"@```,3'```/````S\<``!````#?
MQP``!P```/#'```.````^,<```4````'R```#0````W(```'`0``&\@```8`
M```CR0``&P```"K)```&````1LD``",```!-R0``"````'')```&````>LD`
M`!0```"!R0``$0```);)```F````J,D```X```#/R0``.````-[)```&````
M%\H```X````>R@``&@```"W*```%````2,H```<```!.R@``#@```%;*```&
M````9<H```P```!LR@``*0```'G*```7````H\H``!\```"[R@``7````-O*
M```4````.,L``#X```!-RP``'P```(S+```0````K,L``!0```"]RP``!P``
M`-++```+````VLL```X```#FRP``#````/7+```,`````LP``!,````/S```
M"@```"/,```=````+LP``!D```!,S```!0```&;,```1````;,P``!$```!^
MS```)````)#,```5````M<P``!(```#+S```#@```-[,```9````[<P```@`
M```'S0``"0```!#-```*````&LT```<````ES0``"````"W-```K````-LT`
M`!(```!BS0``+````'7-```:````HLT```D```"]S0``"@```,?-```5````
MTLT``!````#HS0``!0```/G-```4````_\T```0````4S@``$````!G.```&
M````*LX```<````QS@``'@```#G.```H````6,X```H```"!S@``'````(S.
M```:````J<X```\```#$S@``%````-3.```$````Z<X```4```#NS@``!@``
M`/3.```&````^\X```H````"SP``&P````W/```T````*<\``#0```!>SP``
M(````)//```I````M,\``"````#>SP``00```/_/```:````0=```!T```!<
MT```*````'K0```<````H]```!P```#`T```*0```-W0```I````!]$``%$`
M```QT0``5P```(/1```L````V]$``"(````(T@``'P```"O2```9````2](`
M`!D```!ET@``*@```'_2```K````JM(``",```#6T@``+@```/K2```T````
M*=,```T```!>TP``"````&S3```7````==,```H```"-TP``!P```)C3```A
M````H-,```T```#"TP``$````-#3```.````X=,```L```#PTP``!P```/S3
M```3````!-0```@````8U```"P```"'4```*````+=0``!0````XU```,@``
M`$W4```%````@-0``!<```"&U```#P```)[4```.````KM0```4```"]U```
M!````,/4```-````R-0``#(```#6U```10````G5```7````3]4``!X```!G
MU0``%````(;5```5````F]4```4```"QU0``%````+?5```'````S-4``",`
M``#4U0``#@```/C5```J````!]8```8````RU@``#````#G6```-````1M8`
M`!$```!4U@``%P```&;6```+````?M8``#8```"*U@``"@```,'6```B````
MS-8```L```#OU@``#P```/O6```+````"]<``"`````7UP``)P```#C7```K
M````8-<```D```",UP``,@```);7```P````R=<``#$```#ZUP``+0```"S8
M``!`````6M@``#T```";V```0@```-G8```^````'-D``#\```!;V0``0@``
M`)O9```^````WMD``#\````=V@``0@```%W:```^````H-H``#\```#?V@``
M00```!_;```]````8=L``#X```"?VP``/P```-[;```[````'MP``#P```!:
MW```/0```)?<```Z````U=P``$(````0W0``/@```%/=```_````DMT```X`
M``#2W0``%````.'=```%````]MT```X```#\W0``$P````O>```'````']X`
M`!$````GW@``#@```#G>```'````2-X``!0```!0W@``#@```&7>```8````
M=-X```<```"-W@``!0```)7>```,````F]X```P```"HW@``$@```+7>```$
M````R-X```H```#-W@``"P```-C>```,````Y-X```X```#QW@``#@````#?
M```%````#]\```4````5WP``+@```!O?```F````2M\``",```!QWP```P``
M`)7?```>````F=\``!@```"XWP``)0```-'?```-````]]\```D````%X```
M!P````_@```*````%^````(````BX```$@```"7@```-````..```!(```!&
MX```!````%G@```'````7N````D```!FX```#````'#@``!2````?>```!<`
M``#0X```)````.C@```'````#>$```8````5X0``#@```!SA```+````*^$`
M``X````WX0``#````$;A```-````4^$``!4```!AX0``$@```'?A```/````
MBN$``!0```":X0``&P```*_A```0````R^$``&@```#<X0``&@```$7B```7
M````8.(``"<```!XX@``&@```*#B```7````N^(``!L```#3X@``&0```._B
M```?````">,``!<````IXP``$P```$'C```(````5>,```@```!>XP``"0``
M`&?C```-````<>,``!,```!_XP```P```)/C``!&````E^,``#\```#>XP``
M-````![D```D````4^0``#<```!XY```5P```+#D```%````".4``!\````.
MY0``+P```"[E```(````7N4```T```!GY0``#@```'7E```M````A.4```0`
M``"RY0``3P```+?E```E````!^8``!P````MY@``"P```$KF```?````5N8`
M`!T```!VY@``)0```)3F```@````NN8``"0```#;Y@``(`````#G```+````
M(><```8````MYP``.0```#3G```'````;N<``!D```!VYP``"0```)#G```3
M````FN<```0```"NYP``$````+/G```P````Q.<``!0```#UYP``#0````KH
M```.````&.@``!,````GZ```'````#OH```H````6.@```8```"!Z```!P``
M`(CH```3````D.@```0```"DZ```%P```*GH```*````P>@```P```#,Z```
M"0```-GH```&````X^@```4```#JZ```"@```/#H```1````^^@```8````-
MZ0``#@```!3I```.````(^D```T````RZ0``"P```$#I```=````3.D```L`
M``!JZ0```@```';I```<````>>D```<```"6Z0``%P```)[I```&````MND`
M`&4```"]Z0``"0```"/J```'````+>H``"8````UZ@``.````%SJ```:````
ME>H``"H```"PZ@``.P```-OJ```H````%^L``#0```!`ZP``&0```'7K```5
M````C^L```<```"EZP``"````*WK```'````MNL```<```"^ZP``#@```,;K
M```)````U>L```8```#?ZP``"````.;K```+````[^L```<```#[ZP``!P``
M``/L```0````"^P```8````<[```'````"/L```%````0.P``!````!&[```
M$````%?L```/````:.P```<```!X[```!0```(#L```-````ANP``!````"4
M[```%````*7L```+````NNP```T```#&[```&````-3L```7````[>P``!H`
M```%[0``%````"#M```$````->T```D````Z[0``"@```$3M```'````3^T`
M``(```!7[0``'P```%KM```C````>NT``#@```">[0``,0```-?M```G````
M">X``&0````Q[@``%````);N```<````J^X``%4```#([@``.````![O``!*
M````5^\``%L```"B[P``*````/[O```X````)_```"H```!@\```*````(OP
M```L````M/```"<```#A\```&P````GQ```^````)?$``*D!``!D\0``(P``
M``[S```7````,O,``$@```!*\P``(P```)/S``"%````M_,``#`````]]```
M00```&[T``!;````L/0``$P````,]0``CP```%GU```=````Z?4``!@````'
M]@``(0```"#V```?````0O8``"L```!B]@``(0```([V```I````L/8``"<`
M``#:]@``'0````+W```1````(/<``#,````R]P``)0```&;W```X````C/<`
M`"````#%]P``'P```.;W```P````!O@``&D````W^```,@```*'X```Q````
MU/@``$$````&^0``,P```$CY```E````?/D``#T```"B^0``90```.#Y``!-
M````1OH``"\```"4^@``+@```,3Z```K````\_H``#`````?^P``*@```%#[
M```^````>_L``%0```"Z^P``6@````_\``!(````:OP``$H```"S_```%```
M`/[\```R````$_T``!T```!&_0``(P```&3]```O````B/T``"P```"X_0``
M+0```.7]``!Q````$_X``&\```"%_@``LP```/7^```7````J?\``"4```#!
M_P``,@```.?_```I````&@`!`#X```!$``$`(@```(,``0!2````I@`!`,T`
M``#Y``$`FP```,<!`0"F````8P(!`"4````*`P$`"P```#`#`0"Q````/`,!
M`(D```#N`P$`10```'@$`0`A````O@0!`)<```#@!`$`,````'@%`0`E````
MJ04!`!P```#/!0$`!P```.P%`0`$````]`4!``T```#Y!0$`"P````<&`0`.
M````$P8!``4````B!@$`$````"@&`0`"````.08!`%D````\!@$`!0```)8&
M`0`2````G`8!``@```"O!@$``P```+@&`0`0````O`8!``P```#-!@$`$```
M`-H&`0`-````ZP8!``(```#Y!@$`#@```/P&`0`2````"P<!``,````>!P$`
M*@```"('`0`$````30<!`!\```!2!P$`-0```'('`0`N````J`<!`"\```#7
M!P$`%P````<(`0`@````'P@!`!L```!`"`$`&````%P(`0`D````=0@!`!\`
M``":"`$`&@```+H(`0`@````U0@!`!H```#V"`$`,@```!$)`0`O````1`D!
M`!H```!T"0$`*P```(\)`0`?````NPD!`",```#;"0$`'P```/\)`0`:````
M'PH!`"4````Z"@$`)@```&`*`0`E````APH!`"0```"M"@$`&````-(*`0`=
M````ZPH!`"0````)"P$`&````"X+`0`B````1PL!`"4```!J"P$`*@```)`+
M`0`\````NPL!`!\```#X"P$`(P```!@,`0`?````/`P!`"````!<#`$`&@``
M`'T,`0`8````F`P!`"8```"Q#`$`'@```-@,`0`I````]PP!`!X````A#0$`
M"0```$`-`0`,````2@T!`!<```!7#0$`%P```&\-`0`O````APT!`"0```"W
M#0$`!P```-P-`0`?````Y`T!``4````$#@$`!P````H.`0`B````$@X!`"4`
M```U#@$`'0```%L.`0`:````>0X!``<```"4#@$`QP```)P.`0`+````9`\!
M`!4```!P#P$`!@```(8/`0`)````C0\!`!@```"7#P$`"P```+`/`0`-````
MO`\!`!<```#*#P$`!@```.(/`0`S````Z0\!`!,````=$`$`$P```#$0`0`/
M````11`!`!$```!5$`$`!P```&<0`0`R````;Q`!`"$```"B$`$`$P```,00
M`0`,````V!`!`!$```#E$`$`,@```/<0`0`4````*A$!`!`````_$0$`"```
M`%`1`0`=````61$!``D```!W$0$`"@```($1`0`%````C!$!`!0```"2$0$`
M'0```*<1`0`(````Q1$!`!\```#.$0$`"````.X1`0`:````]Q$!``8````2
M$@$`%0```!D2`0`(````+Q(!`#\````X$@$`!P```'@2`0`/````@!(!``X`
M``"0$@$`$````)\2`0`)````L!(!``D```"Z$@$`!P```,02`0`9````S!(!
M``H```#F$@$`"@```/$2`0`)````_!(!``H````&$P$`#````!$3`0`7````
M'A,!``0````V$P$`*@```#L3`0`'````9A,!``(```!N$P$`!@```'$3`0`'
M````>!,!``T```"`$P$`"P```(X3`0`O````FA,!`#(```#*$P$`(````/T3
M`0`<````'A0!``P````[%`$`,0```$@4`0`%````>A0!`!(```"`%`$`/P``
M`),4`0`2````TQ0!``H```#F%`$`!@```/$4`0`3````^!0!``4````,%0$`
M!@```!(5`0`&````&14!``D````@%0$`!````"H5`0`,````+Q4!``H````\
M%0$`!0```$<5`0`8````314!`!D```!F%0$`'P```(`5`0`=````H!4!`!$`
M``"^%0$``@```-`5`0`$````TQ4!``8```#8%0$``P```-\5`0`,````XQ4!
M`$4```#P%0$`&@```#86`0`U````418!`"@```"'%@$`4P```+`6`0`9````
M!!<!`#X````>%P$`(````%T7`0`U````?A<!`"$```"T%P$`10```-87`0`P
M````'!@!`"@```!-&`$`*0```'88`0`F````H!@!`"4```#'&`$`*````.T8
M`0`H````%AD!`"(````_&0$`,````&(9`0`2````DQD!`!,```"F&0$`$P``
M`+H9`0`0````SAD!`'D```#?&0$`"0```%D:`0!R````8QH!`',```#6&@$`
M?````$H;`0`K````QQL!`%,```#S&P$`%P```$<<`0`6````7QP!``\```!V
M'`$`'P```(8<`0!`````IAP!`!\```#G'`$`'`````<=`0!1````)!T!`!L`
M``!V'0$`%````)(=`0`2````IQT!`!````"Z'0$`$P```,L=`0`=````WQT!
M``\```#]'0$`#P````T>`0`+````'1X!``<````I'@$`!0```#$>`0`4````
M-QX!``<```!,'@$`"````%0>`0`/````71X!``@```!M'@$`#````'8>`0`/
M````@QX!``8```"3'@$`%````)H>`0`&````KQX!``P```"V'@$`"````,,>
M`0`$````S!X!``H```#1'@$`!````-P>`0`9````X1X!``(```#['@$`"0``
M`/X>`0`&````"!\!``8````/'P$`)P```!8?`0`$````/A\!``\```!#'P$`
M$P```%,?`0`'````9Q\!``<```!O'P$`!@```'<?`0`0````?A\!`!(```"/
M'P$`!@```*(?`0`)````J1\!``4```"S'P$`(@```+D?`0`'````W!\!``<`
M``#D'P$`"P```.P?`0`%````^!\!`&<!``#^'P$`*P```&8A`0!=````DB$!
M`!4```#P(0$`%@````8B`0`/````'2(!``D````M(@$`"````#<B`0`'````
M0"(!``8```!((@$`#````$\B`0`0````7"(!``T```!M(@$`#0```'LB`0`6
M````B2(!`"<```"@(@$`$@```,@B`0`*````VR(!``X```#F(@$`#P```/4B
M`0`+````!2,!`!`````1(P$`)@```"(C`0`B````22,!`"H```!L(P$`%```
M`)<C`0`(````K",!`"D```"U(P$`(P```-\C`0`/`````R0!`"`````3)`$`
M)0```#0D`0`W````6B0!`!4```"2)`$`#P```*@D`0`1````N"0!`!(```#*
M)`$`'@```-TD`0`X````_"0!`"T````U)0$`)P```&,E`0`K````BR4!`!L`
M``"W)0$`#P```-,E`0`8````XR4!``T```#\)0$`"P````HF`0`+````%B8!
M``<````B)@$`)@```"HF`0`;````428!`$,```!M)@$`3````+$F`0!?````
M_B8!`%\```!>)P$`8@```+XG`0!B````(2@!`$8```"$*`$`!0```,LH`0`<
M````T2@!``<```#N*`$`#0```/8H`0`,````!"D!`!$````1*0$`#@```",I
M`0`X````,BD!`#8```!K*0$`$P```*(I`0`5````MBD!``D```#,*0$`"0``
M`-8I`0`(````X"D!`!(```#I*0$`+````/PI`0`-````*2H!`!0````W*@$`
M%````$PJ`0`;````82H!`"\```!]*@$`%0```*TJ`0`/````PRH!`!0```#3
M*@$`$````.@J`0`E````^2H!`"$````?*P$`'0```$$K`0`@````7RL!``\`
M``"`*P$`50```)`K`0`Y````YBL!`"@````@+`$`"0```$DL`0`0````4RP!
M`"\```!D+`$`"@```)0L`0`2````GRP!`!D```"R+`$`"0```,PL`0`,````
MUBP!``T```#C+`$``P```/$L`0`7````]2P!``X````-+0$`$0```!PM`0`;
M````+BT!`"4```!*+0$`+P```'`M`0`+````H"T!`!@```"L+0$`&0```,4M
M`0`=````WRT!`!L```#]+0$`$P```!DN`0`4````+2X!`"(```!"+@$`%0``
M`&4N`0`7````>RX!`"````"3+@$`"````+0N`0`(````O2X!``\```#&+@$`
M&````-8N`0`G````[RX!``<````7+P$`"````!\O`0`2````*"\!`!T````[
M+P$`&@```%DO`0`\````="\!`$0```"Q+P$`!0```/8O`0`+````_"\!`#H`
M```(,`$`#@```$,P`0`2````4C`!`$,```!E,`$`*````*DP`0`M````TC`!
M`#``````,0$`,P```#$Q`0`/````93$!``D```!U,0$`"0```'\Q`0`9````
MB3$!`!T```"C,0$`-````,$Q`0`J````]C$!`!`````A,@$`%````#(R`0`(
M````1S(!``\```!0,@$`%P```&`R`0`<````>#(!``4```"5,@$`+0```)LR
M`0`-````R3(!``@```#7,@$`+0```.`R`0`2````#C,!``X````A,P$`!@``
M`#`S`0`$````-S,!``H````\,P$`"````$<S`0`0````4#,!`!,```!A,P$`
M*````'4S`0`3````GC,!``H```"R,P$`%````+TS`0`+````TC,!``8```#>
M,P$`3````.4S`0`H````,C0!``<```!;-`$`'````&,T`0`D````@#0!`"8`
M``"E-`$`-````,PT`0`D`````34!`"D````F-0$`@````%`U`0`W````T34!
M``L````)-@$`%P```!4V`0`/````+38!`!`````]-@$`#P```$XV`0`0````
M7C8!``\```!O-@$`#P```'\V`0`&````CS8!`!L```"6-@$`%P```+(V`0`(
M````RC8!``8```#3-@$`#@```-HV`0!:````Z38!``H```!$-P$`$P```$\W
M`0!;````8S<!`!````"_-P$`$@```-`W`0`/````XS<!`!4```#S-P$`%@``
M``DX`0`L````(#@!`"\```!-.`$`%P```'TX`0`B````E3@!``@```"X.`$`
M)````,$X`0`5````YC@!`!$```#\.`$`&P````XY`0`7````*CD!`!$```!"
M.0$`&P```%0Y`0`2````<#D!`!L```"#.0$`%@```)\Y`0`%````MCD!`!(`
M``"\.0$`$````,\Y`0`'````X#D!``T```#H.0$`!@```/8Y`0`&````_3D!
M``\````$.@$`!@```!0Z`0`+````&SH!``@````G.@$`#````#`Z`0`6````
M/3H!``L```!4.@$`"````&`Z`0`9````:3H!`#X```"#.@$`*P```,(Z`0`G
M````[CH!`!(````6.P$`$P```"D[`0`2````/3L!`!,```!0.P$`-````&0[
M`0!$````F3L!`",```#>.P$`$`````(\`0`W````$SP!`!0```!+/`$`&P``
M`&`\`0`(````?#P!``D```"%/`$`$@```(\\`0`M````HCP!`"@```#0/`$`
M,````/D\`0`K````*CT!`"4```!6/0$`)````'P]`0`?````H3T!`#X```#!
M/0$`*``````^`0`I````*3X!`"P```!3/@$`'0```(`^`0`F````GCX!`"X`
M``#%/@$`,P```/0^`0`O````*#\!`"X```!8/P$`-0```(<_`0`D````O3\!
M`"(```#B/P$`1@````5``0`6````3$`!`"0```!C0`$`+````(A``0`C````
MM4`!`!@```#90`$`P````/)``0`Q````LT$!`"<```#E00$`)@````U"`0`F
M````-$(!`#````!;0@$`'@```(Q"`0`H````JT(!`"0```#40@$`,@```/E"
M`0`U````+$,!`#4```!B0P$`-````)A#`0"U````S4,!`"H```"#1`$`'```
M`*Y$`0`C````RT0!`"L```#O1`$`*P```!M%`0!.````1T4!`$L```"610$`
M$0```.)%`0`$````]$4!``<```#Y10$`"@````%&`0`9````#$8!`!0````F
M1@$`%0```#M&`0`:````448!`!D```!L1@$`"P```(9&`0`-````DD8!``P`
M``"@1@$`$P```*U&`0`-````P48!`!(```#/1@$`"P```.)&`0`_````[D8!
M``<````N1P$`$````#9'`0`"````1T<!``@```!*1P$`"````%-'`0`;````
M7$<!`"<```!X1P$`"@```*!'`0`4````JT<!`!,```#`1P$`!0```-1'`0`/
M````VD<!``H```#J1P$`$0```/5'`0`-````!T@!`!$````52`$`#@```"=(
M`0`3````-D@!`!<```!*2`$`'P```&)(`0`?````@D@!``<```"B2`$`$0``
M`*I(`0`/````O$@!``@```#,2`$`#P```-5(`0`7````Y4@!`!\```#]2`$`
M#P```!U)`0`/````+4D!`"D````]20$`(0```&=)`0`]````B4D!``\```#'
M20$`%P```-=)`0`9````[TD!`!H````)2@$`/@```"1*`0`H````8TH!``H`
M``",2@$`$````)=*`0`O````J$H!`!D```#82@$`"0```/)*`0`Z````_$H!
M`#4````W2P$`"````&U+`0`.````=DL!`"8```"%2P$`$````*Q+`0`E````
MO4L!`"@```#C2P$`"0````Q,`0`=````%DP!`!(````T3`$`&0```$=,`0`/
M````84P!`!(```!Q3`$`#0```(1,`0!`````DDP!`#X```#33`$`"0```!)-
M`0`,````'$T!`#`````I30$`$````%I-`0`1````:TT!``L```!]30$`$0``
M`(E-`0`2````FTT!`!H```"N30$`&P```,E-`0`B````Y4T!`!D````(3@$`
M(@```").`0`D````14X!`!4```!J3@$`"P```(!.`0`,````C$X!``\```"9
M3@$`)@```*E.`0`3````T$X!``D```#D3@$`#````.Y.`0`>````^TX!`!H`
M```:3P$`/P```#5/`0`G````=4\!``4```"=3P$`"P```*-/`0`7````KT\!
M`(X```#'3P$`(````%90`0`%````=U`!`"````!]4`$`%@```)Y0`0`5````
MM5`!``8```#+4`$`!@```-)0`0`-````V5`!``P```#G4`$`%````/10`0`,
M````"5$!`"0````640$`#0```#M1`0`*````25$!`!8```!440$`"````&M1
M`0`(````=%$!`!D```!]40$`(@```)=1`0`C````NE$!``\```#>40$`.```
M`.Y1`0`0````)U(!``<````X4@$`$````$!2`0`8````45(!`#<```!J4@$`
M+````*)2`0`B````SU(!`!T```#R4@$`'````!!3`0`C````+5,!`!L```!1
M4P$`30```&U3`0`'````NU,!`!(```##4P$``P```-93`0`+````VE,!``L`
M``#F4P$`#0```/)3`0`,`````%0!`!(````-5`$`#@```"!4`0`:````+U0!
M`!H```!*5`$`%````&54`0`-````>E0!``\```"(5`$`$@```)A4`0`E````
MJU0!``8```#15`$`"@```-A4`0`-````XU0!``X```#Q5`$`!`````!5`0`%
M````!54!``8````+50$`&````!)5`0`/````*U4!``4````[50$`*@```$%5
M`0`8````;%4!``8```"%50$`"````(Q5`0`/````E54!``H```"E50$`#```
M`+!5`0`&````O54!``H```#$50$``@```,]5`0`'````TE4!`!H```#:50$`
M%P```/55`0`5````#58!`"$````C5@$``P```$56`0`'````258!`!,```!1
M5@$`%````&56`0`-````>E8!``P```"(5@$`+@```)56`0`(````Q%8!``L`
M``#-5@$`$````-E6`0`(````ZE8!``8```#S5@$`%0```/I6`0`1````$%<!
M`"X````B5P$`%@```%%7`0`&````:%<!``\```!O5P$`#P```']7`0`)````
MCU<!`"P```"95P$`!````,97`0`'````RU<!`"8```#35P$`!@```/I7`0`*
M`````5@!`!4````,6`$`'0```")8`0`$````0%@!`"P```!%6`$`#0```')8
M`0`-````@%@!`!$```".6`$`$````*!8`0`-````L5@!`"\```"_6`$`#P``
M`.]8`0`0````_U@!`"T````060$`$@```#Y9`0`3````45D!``H```!E60$`
M/````'!9`0`C````K5D!`!\```#160$`)````/%9`0`'````%EH!``@````>
M6@$`#````"=:`0`M````-%H!`"L```!B6@$`00```(Y:`0`+````T%H!``P`
M``#<6@$`(0```.E:`0`M````"UL!`!8````Y6P$`"P```%!;`0`5````7%L!
M``X```!R6P$`$````(%;`0`5````DEL!`!$```"H6P$`/````+I;`0",````
M]UL!`'8```"$7`$`%@```/M<`0`+````$ET!`!(````>70$`$P```#%=`0`0
M````15T!``<```!670$`"````%Y=`0`9````9UT!`!$```"!70$`%0```)-=
M`0`5````J5T!``X```"_70$`%0```,Y=`0`?````Y%T!`"$````$7@$`<@``
M`"9>`0`1````F5X!`!(```"K7@$`"P```+Y>`0`+````REX!`!0```#67@$`
M$````.M>`0`/````_%X!`!4````,7P$`%````")?`0`F````-U\!`"H```!>
M7P$`)P```(E?`0`G````L5\!`"H```#97P$`*P````1@`0`>````,&`!`$P`
M``!/8`$`%````)Q@`0`4````L6`!`!0```#&8`$`%````-M@`0`2````\&`!
M`!@````#80$`&````!QA`0`5````-6$!`!4```!+80$`.P```&%A`0`9````
MG6$!`!H```"W80$`-````-)A`0`4````!V(!``@````<8@$`#@```"5B`0`O
M````-&(!`!X```!D8@$`$P```(-B`0`/````EV(!`!D```"G8@$`&P```,%B
M`0`7````W6(!`!,```#U8@$`&@````EC`0`A````)&,!`!H```!&8P$`%0``
M`&%C`0`;````=V,!`"$```"38P$`&P```+5C`0`;````T6,!`!0```#M8P$`
M!@````)D`0`*````"60!``<````49`$`!P```!QD`0`,````)&0!`!<````Q
M9`$`$P```$ED`0`5````760!`!(```!S9`$`%0```(9D`0`4````G&0!`!4`
M``"Q9`$`&````,=D`0`6````X&0!`"T```#W9`$`%````"5E`0`.````.F4!
M`!,```!)90$`$@```%UE`0`.````<&4!``X```!_90$`#@```(YE`0`Y````
MG64!``8```#790$`#@```-YE`0`3````[64!``<````!9@$`$P````EF`0`.
M````'68!`!$````L9@$`%````#YF`0`C````4V8!`"H```!W9@$`)0```*)F
M`0`%````R&8!``<```#.9@$`*0```-9F`0`(`````&<!`!0````)9P$`#P``
M`!YG`0`*````+F<!`!(````Y9P$`!P```$QG`0`7````5&<!`#4```!L9P$`
M"0```*)G`0`,````K&<!`"@```"Y9P$`%@```.)G`0`6````^6<!``T````0
M:`$`,0```!YH`0`*````4&@!``P```!;:`$`#0```&AH`0`)````=F@!``<`
M``"`:`$`!@```(AH`0`2````CV@!`$<```"B:`$`$````.IH`0`&````^V@!
M``X````":0$`!0```!%I`0`&````%VD!`!<````>:0$`%P```#9I`0`6````
M3FD!``(```!E:0$`!@```&AI`0`,````;VD!`!````!\:0$`%@```(UI`0`]
M````I&D!``H```#B:0$`&@```.UI`0`/````"&H!``<````8:@$`!````"!J
M`0`R````)6H!`#8```!8:@$`%````(]J`0`:````I&H!`!D```"_:@$`*```
M`-EJ`0`G`````FL!``T````J:P$`!0```#AK`0`2````/FL!`!8```!1:P$`
M%0```&AK`0`6````?FL!`!<```"5:P$`'P```*UK`0`$````S6L!``H```#2
M:P$`$````-UK`0`1````[FL!``8`````;`$`8@````=L`0`0````:FP!``\`
M``![;`$`$````(ML`0`:````G&P!`$H```"W;`$`!P````)M`0`;````"FT!
M``<````F;0$`!@```"YM`0`)````-6T!`"H````_;0$`*0```&IM`0`)````
ME&T!``<```">;0$`(@```*9M`0!D````R6T!`!L````N;@$`(P```$IN`0`:
M````;FX!``(```");@$`&````(QN`0`'````I6X!`!<```"M;@$`#P```,5N
M`0`-````U6X!``X```#C;@$`!P```/)N`0`7````^FX!``X````2;P$`"P``
M`"%O`0`/````+6\!``P````];P$`"P```$IO`0`+````5F\!``L```!B;P$`
M)P```&YO`0`0````EF\!`!$```"G;P$`&````+EO`0`E````TF\!``\```#X
M;P$`%0````AP`0`/````'G`!``4````N<`$`$P```#1P`0`&````2'`!``0`
M``!/<`$`#0```%1P`0`*````8G`!``P```!M<`$`$P```'IP`0`>````CG`!
M`!,```"M<`$``P```,%P`0`;````Q7`!``<```#A<`$`#@```.EP`0`,````
M^'`!`!$````%<0$``P```!=Q`0`Z````&W$!`#L```!6<0$`'@```))Q`0`E
M````L7$!`"D```#7<0$`%0````%R`0!"````%W(!`$(```!:<@$`*P```)UR
M`0`P````R7(!`#X```#Z<@$`/@```#ES`0`_````>',!`"\```"X<P$`1```
M`.AS`0`T````+70!`!,```!B=`$`%````'9T`0`4````BW0!`!8```"@=`$`
M%P```+=T`0`1````SW0!`!,```#A=`$`%0```/5T`0`B````"W4!`!8````N
M=0$`)````$5U`0`4````:G4!`!0```!_=0$`+0```)1U`0`F````PG4!`"0`
M``#I=0$`$@````YV`0!`````(78!`$0```!B=@$`$@```*=V`0`&````NG8!
M`!X```#!=@$`$0```.!V`0`(````\G8!``@```#[=@$`$P````1W`0`5````
M&'<!``X````N=P$`$0```#UW`0`*````3W<!`!4```!:=P$`3P$``'!W`0`+
M````P'@!`!\```#,>`$`#````.QX`0`_````^7@!``D````Y>0$`!P```$-Y
M`0`2````2WD!``X```!>>0$`*P```&UY`0`/````F7D!`#<```"I>0$`"P``
M`.%Y`0`7````[7D!`"<````%>@$`"0```"UZ`0`)````-WH!`!````!!>@$`
M!P```%)Z`0`.````6GH!`#<```!I>@$`&@```*%Z`0`E````O'H!`(,```#B
M>@$`%P```&9[`0!*````?GL!`"H```#)>P$`$P```/1[`0`7````"'P!``@`
M```@?`$`#````"E\`0`/````-GP!`!(```!&?`$`"@```%E\`0`0````9'P!
M``@```!U?`$`&P```'Y\`0`8````FGP!``0```"S?`$`$0```+A\`0`9````
MRGP!`"H```#D?`$`%`````]]`0`<````)'T!`!(```!!?0$`*@```%1]`0`+
M````?WT!``L```"+?0$`"P```)=]`0`'````HWT!``<```"K?0$`,P```+-]
M`0`-````YWT!`"X```#U?0$`%@```"1^`0`(````.WX!``D```!$?@$`'@``
M`$Y^`0`:````;7X!``H```"(?@$`&P```)-^`0`(````KWX!`!8```"X?@$`
M"````,]^`0`'````V'X!`!\```#@?@$`,`````!_`0`-````,7\!`"4````_
M?P$`&@```&5_`0`3````@'\!`!8```"4?P$`"@```*M_`0`(````MG\!``L`
M``"_?P$`#@```,M_`0`+````VG\!`"(```#F?P$`0`````F``0!"````2H`!
M`!T```"-@`$`+@```*N``0`G````VH`!`$P````"@0$`&@```$^!`0`@````
M:H$!`"P```"+@0$`'0```+B!`0`>````UH$!`"H```#U@0$`-0```"""`0!Q
M````5H(!`%D```#(@@$`-0```"*#`0`L````6(,!`"<```"%@P$`%@```*V#
M`0`<````Q(,!`#H```#A@P$`.````!R$`0`L````580!`#,```""A`$`.P``
M`+:$`0`,````\H0!``4```#_A`$`(`````6%`0`'````)H4!``T````NA0$`
M*@```#R%`0`2````9X4!`!4```!ZA0$`$0```)"%`0`0````HH4!``@```"S
MA0$`%0```+R%`0`.````TH4!`!$```#AA0$`#@```/.%`0`<`````H8!`$$`
M```?A@$`!P```&&&`0`;````:88!``P```"%A@$`#P```)*&`0`%````HH8!
M``@```"HA@$`$@```+&&`0`_````Q(8!`%D````$AP$`*````%Z'`0`K````
MAX<!`"(```"SAP$`(````-:'`0`%````]X<!`!````#]AP$`!@````Z(`0`I
M````%8@!`!L````_B`$`-P```%N(`0`(````DX@!``X```"<B`$`#P```*N(
M`0`5````NX@!`!X```#1B`$`$````/"(`0!)`````8D!``P```!+B0$`*```
M`%B)`0`/````@8D!`!,```"1B0$`$@```*6)`0`E````N(D!`$0```#>B0$`
M-@```".*`0`,````6HH!`$$```!GB@$`.0```*F*`0`Z````XXH!`#8````>
MBP$`3````%6+`0!+````HHL!`$X```#NBP$`2````#V,`0!-````AHP!`$X`
M``#4C`$`2````".-`0!-````;(T!`$X```"ZC0$`2`````F.`0!-````4HX!
M`$T```"@C@$`1P```.Z.`0!,````-H\!`$L```"#CP$`10```,^/`0!*````
M%9`!`$D```!@D`$`2````*J0`0!.````\Y`!`$@```!"D0$`30```(N1`0`1
M````V9$!`!<```#KD0$`"0````.2`0`.````#9(!`!8````<D@$`#````#.2
M`0`7````0)(!`!L```!8D@$`"0```'22`0`7````?I(!`!$```"6D@$`+```
M`*B2`0`)````U9(!``4```#?D@$`$0```.62`0`,````]Y(!`!0````$DP$`
M!0```!F3`0`/````'Y,!`!,````ODP$`$````$.3`0`1````5),!`!$```!F
MDP$`"````'B3`0`'````@9,!`$$```")DP$`,0```,N3`0`R````_9,!``@`
M```PE`$`'@```#F4`0`=````6)0!`"L```!VE`$`#````**4`0`+````KY0!
M``@```"[E`$`#````,24`0`"````T90!`!0```#4E`$`$0```.F4`0`1````
M^Y0!``H````-E0$`#0```!B5`0`/````)I4!`!,````VE0$`9@```$J5`0`>
M````L94!`#4```#0E0$`"`````:6`0`)````#Y8!`!(````9E@$`$P```"R6
M`0`7````0)8!``\```!8E@$`%P```&B6`0`;````@)8!`!8```"<E@$`%```
M`+.6`0`<````R)8!`!T```#EE@$`&0````.7`0"%````'9<!`",```"CEP$`
M+````,>7`0`M````])<!`!P````BF`$`)````#^8`0`B````9)@!`!X```"'
MF`$`%P```*:8`0`F````OI@!`!T```#EF`$`#`````.9`0`,````$)D!``L`
M```=F0$`$0```"F9`0`9````.YD!``0```!5F0$`8````%J9`0!`````NYD!
M`$@```#\F0$`(@```$6:`0!"````:)H!`'@```"KF@$`!P```"2;`0`L````
M+)L!`#8```!9FP$`!@```)";`0`0````EYL!`!$```"HFP$`00```+J;`0`(
M````_)L!`%$````%G`$`0````%><`0`O````F)P!`!$```#(G`$`*P```-J<
M`0`C````!IT!`"T````JG0$`)@```%B=`0`N````?YT!`"<```"NG0$`&@``
M`-:=`0`*````\9T!`#$```#\G0$`$````"Z>`0`H````/YX!``@```!HG@$`
M%````'&>`0`'````AIX!`!(```".G@$`-P```*&>`0`?````V9X!`!(```#Y
MG@$`#P````R?`0`0````')\!`"$````MGP$`+P```$^?`0`3````?Y\!``<`
M``"3GP$`$P```)N?`0`$````KY\!`!L```"TGP$`#P```-"?`0`/````X)\!
M`!````#PGP$`"`````&@`0`&````"J`!``P````1H`$`$@```!Z@`0`)````
M,:`!`!$````[H`$`#@```$V@`0`.````7*`!``P```!KH`$`)````'B@`0`*
M````G:`!``(```"HH`$`'0```*N@`0`$````R:`!`"0```#.H`$`"````/.@
M`0!L````_*`!``H```!IH0$`"````'2A`0`C````?:$!`$````"AH0$`%P``
M`.*A`0`F````^J$!`%$````AH@$`+````'.B`0`[````H*(!`!<```#<H@$`
M$P```/2B`0`1````"*,!``<````:HP$`!````"*C`0`'````)Z,!``P````O
MHP$`"0```#RC`0`$````1J,!``8```!+HP$`"P```%*C`0`*````7J,!``<`
M``!IHP$`+````'&C`0`&````GJ,!`"4```"EHP$`!P```,NC`0`0````TZ,!
M`!````#DHP$`%````/6C`0`'````"J0!``@````2I`$`$P```!ND`0`1````
M+Z0!`!\```!!I`$`"P```&&D`0`-````;:0!`!L```![I`$`$P```)>D`0`;
M````JZ0!`!(```#'I`$`!P```-JD`0`,````XJ0!`!$```#OI`$`#P````&E
M`0`"````$:4!`#`````4I0$`*0```$6E`0`K````;Z4!`"H```";I0$`)0``
M`,:E`0!Y````[*4!`!(```!FI@$`*````'FF`0!,````HJ8!`#0```#OI@$`
M5P```"2G`0!2````?*<!`"$```#/IP$`.@```/&G`0`I````+*@!`"\```!6
MJ`$`-0```(:H`0`Q````O*@!`"````#NJ`$`0`````^I`0#P`0``4*D!`!P`
M``!!JP$`%@```%ZK`0!'````=:L!`"D```"]JP$`@````.>K`0!#````:*P!
M`#X```"LK`$`:@```.NL`0!I````5JT!`)H```#`K0$`(0```%NN`0`3````
M?:X!`!X```"1K@$`'P```+"N`0`D````T*X!`"$```#UK@$`+````!>O`0`E
M````1*\!`!P```!JKP$`$@```(>O`0`Y````FJ\!`"L```#4KP$`-0````"P
M`0`D````-K`!`"$```!;L`$`0````'VP`0!K````OK`!`#`````JL0$`,```
M`%NQ`0!$````C+$!`"\```#1L0$`)`````&R`0`T````)K(!`'P```!;L@$`
M50```-BR`0!(````+K,!`$(```!WLP$`.0```+JS`0`]````]+,!`#@````R
MM`$`1@```&NT`0!5````LK0!`'(````(M0$`<````'NU`0!9````[+4!`!@`
M``!&M@$`.P```%^V`0`B````F[8!`"T```"^M@$`+````.RV`0`L````&;<!
M`#$```!&MP$`:````'BW`0!E````X;<!`+,```!'N`$`&0```/NX`0`L````
M%;D!`$@```!"N0$`-@```(NY`0!=````PKD!`#,````@N@$`6@```%2Z`0#(
M````K[H!`-T```!XNP$`@P```%:\`0`C````VKP!``X```#^O`$`P`````V]
M`0"O````SKT!`$D```!^O@$`,````,B^`0":````^;X!`$,```"4OP$`)0``
M`-B_`0`D````_K\!``D````CP`$``P```"W``0`4````,<`!``H```!&P`$`
M#````%'``0`&````7L`!`!$```!EP`$`!````'?``0!U````?,`!``8```#R
MP`$`%P```/G``0`%````$<$!``8````7P0$`$P```![!`0`+````,L$!`!0`
M```^P0$`#P```%/!`0`"````8\$!`!P```!FP0$`(````(/!`0`5````I,$!
M`$P```"ZP0$`%@````?"`0`E````'L(!`$,```!$P@$`.````(C"`0`Y````
MP<(!`!@```#[P@$`+@```!3#`0`B````0\,!`"````!FPP$`*````(?#`0`C
M````L,,!`"$```#4PP$`)P```/;#`0`@````'L0!`#,````_Q`$`,````'/$
M`0`<````I,0!`#\```#!Q`$`(0````'%`0`U````(\4!`"@```!9Q0$`(P``
M`(+%`0`Z````IL4!`"X```#AQ0$`+````!#&`0`A````/<8!`"0```!?Q@$`
M*````(3&`0`O````K<8!`",```#=Q@$`*0````''`0`U````*\<!`$8```!A
MQP$`.@```*C'`0`H````X\<!`"P````,R`$`*P```#G(`0`L````9<@!`"8`
M``"2R`$`(0```+G(`0`O````V\@!`"8````+R0$`,@```#+)`0`K````9<D!
M``X```"1R0$`#P```*#)`0`B````L,D!`"$```#3R0$`.0```/7)`0`Q````
M+\H!`!$```!AR@$`(0```'/*`0`'````E<H!``<```"=R@$`(@```*7*`0`E
M````R,H!`!\```#NR@$`'@````[+`0`'````+<L!``<!```URP$`$0```#W,
M`0`:````3\P!``D```!JS`$`#````'3,`0`@````@<P!`!````"BS`$`$0``
M`+/,`0`D````Q<P!``@```#JS`$`-0```//,`0`:````*<T!`!D```!$S0$`
M$P```%[-`0`F````<LT!``D```"9S0$`-@```*/-`0`O````VLT!`!(````*
MS@$`#P```!W.`0`.````+<X!`#<````\S@$`%0```'3.`0`6````BLX!``P`
M``"AS@$`(0```*[.`0`-````T,X!``X```#>S@$`!P```.W.`0`4````]<X!
M`!P````*SP$`"````"?/`0`T````,,\!``H```!ESP$`%P```'#/`0`%````
MB,\!`!H```".SP$`"0```*G/`0`[````L\\!``8```#OSP$`#P```/;/`0`3
M````!M`!``X````:T`$`!P```"G0`0`)````,=`!``L````[T`$`'P```$?0
M`0`/````9]`!`!(```!WT`$`$0```(K0`0`)````G-`!``H```"FT`$`&@``
M`+'0`0`'````S-`!`#,```#4T`$`#0````C1`0`"````%M$!``L````9T0$`
M"P```"71`0`2````,=$!``\```!$T0$`/P```%31`0`[````E-$!`"<```#0
MT0$`)0```/C1`0`,````'M(!`%,````KT@$`!@```'_2`0`5````AM(!`$4`
M``"<T@$`$0```.+2`0`.````]-(!``<````#TP$`&`````O3`0`'````)-,!
M``@````LTP$`!0```#73`0`/````.],!``<```!+TP$`$@```%/3`0`1````
M9M,!``4```!XTP$`&@```'[3`0`A````F=,!`!\```"[TP$`(P```-O3`0`1
M````_],!``(````1U`$`!````!34`0`&````&=0!``,````@U`$`#````"34
M`0!E````,=0!`!L```"7U`$`.````+/4`0`A````[-0!`%,````.U0$`$@``
M`&+5`0!&````==4!`"$```"\U0$`/@```-[5`0`C````'=8!`$$```!!U@$`
M.````(/6`0`Q````O-8!`#````#NU@$`,````!_7`0`P````4-<!`#$```"!
MUP$`+````+/7`0`P````X-<!`$$````1V`$`&P```%/8`0`<````;]@!`!$`
M``",V`$`$@```)[8`0!]````L=@!``P````OV0$`=P```#S9`0!T````M-D!
M`(@````IV@$`,0```++:`0!B````Y-H!`!4```!'VP$`'P```%W;`0`4````
M?=L!`",```"2VP$`1````+;;`0`A````^]L!`!0````=W`$`5````#+<`0`>
M````A]P!`",```"FW`$`(0```,K<`0`5````[-P!`"(````"W0$`+@```"7=
M`0`2````5-T!``H```!GW0$`$````'+=`0`&````@]T!``<```"*W0$`%```
M`)+=`0`'````I]T!``8```"OW0$`&````+;=`0`(````S]T!``\```#8W0$`
M%0```.C=`0`)````_MT!`!,````(W@$`!P```!S>`0`0````)-X!``H````U
MW@$`!@```$#>`0`+````1]X!``8```!3W@$`&0```%K>`0`"````=-X!``4`
M``!WW@$`#````'W>`0`(````BMX!`#$```"3W@$`!0```,7>`0`5````R]X!
M`!L```#AW@$`#0```/W>`0`*````"]\!``X````6WP$`$0```"7?`0`6````
M-]\!``@```!.WP$`#@```%??`0`%````9M\!`"L```!LWP$`"P```)C?`0`'
M````I-\!``X```"LWP$`#0```+O?`0`!````V@0``(,"``!+`@``J@$``$X"
M``"O!0````````````""!```-P````````!T`P``@P```&X"```7!0``````
M`&@"``!^!0``U@4``/,$``":````@@4```````"0````J0$``(X$``#H````
M;`4``!8#``"E`@``G@0``````````````````"`%``!(!```X`,``.,```"4
M`0``^`4`````````````1P```*<```#A`P``A0,``.\```"8!0``=04``/X%
M``#+`0``,@(``(<!```G`0```````#\#``#0`@``J04``'L```!K`0``+P0`
M`!4#```Y````G@$``%4%````````K0$``"\#``!;``````,``!(!``"J`@``
MX@$`````````````IP$``-<%``"[````J```````````````Z@````````#(
M`0``JP0```D&``#E`0``\`$``#<%````````[00``!<#`````````````+@#
M``#D````(`,```````"#`0``)`,```H%``!/`0``*P4````````[`P``NP(`
M`)H%`````````````+8!`````````````,0%````````C@$``.H%``#%`@``
MA@$```````#(`@``R00`````````````[P,``#X$````````=0$``)L!``"C
M`P``?`4``,T!````````&P`````````]`0```````.<%````````'00``+L$
M```[!```J0(`````````````M@,```````#<!0``.@```#8$```E!```Q@0`
M`+H"``!<`0``Z@$``%````#U!0``\@4``(X%``"<!0``BP$``"($````````
MVP(``"`"````````,P0``+@!``!R!0``[@4``'D%``!I`P``X@0``/X`````
M````Z`,```````#*`P``$0,```````"M!```L0$``*`"```#!```#@$``%0#
M```V`@```````'<!``"F`@``4P0``)0$``"+!```RP```-8#``"D````^`$`
M`+P"````````&@(``,\#``!R`P````````T#````````E0$``$<!```A`@``
M``````````"B!0``&P$``)4#````````Z`4``&D"`````````````%($``#V
M!```3`(``#$%````````;@````````"P`@``0`,``'($``"(!```>@(``#P"
M````````9P,``,<%```C`P``P@```)$#``#>````U`0``-\%````````#P4`
M`$4%``!1!````````.$```#&`0```````#T$``!3`P````````````#-````
MZP,```````"O`0``[P4``*8```#5`@``J@,```````"&`@``10````4!````
M````904``,D"````````3@0``%X%````````R@````````!E`@``VP,``)<#
M``!4!```S`,``(\#```B`````````/<"````````>````,X"``#6`@``R@4`
M`!\$``"L`0````````````#A`0``GP$``````````````````&(```#+`@``
MH`4```X`````````E0(``!4````F`P``C04``',$```E``````````````!*
M`@```````/0`````````4P$``&\!``#$`0``^P```)$!``!P````$P```"D$
M``"N`0```````&<$``"X!`````````\#````````70```(L#``#Z`@``40``
M`.8#``#$`@``P`,```````#Y!0``%04``)4%````````N0,````````*`0``
MVP4``,@#``!^`P```````+$#``!A!0``ZP0``&$```"L`P```````-,$``#4
M`@``>P$``%X$`````````````*L#``"B`````````)\"``!B`P```````$,`
M``"&`P``-00``&H%```)````D@0``,$```!-`@```````-,`````````-P$`
M````````````4`4``"8$````````:@```$8"```^!0``"`4``)D#``!C````
MN00``/@$```H!````````&@!``!M!0``Q@(``/0"``#&````DP0``)D$``!+
M!0``<`(``%L"``!S`P``Z0$```\"`````````````$<$````````8P(``$D#
M``"Y!0``6P4``.P$````````M0(``)H!``"4``````````H&``!,````````
M`,X%``#M`@``*@4``/(!``#Q!0``9P```"X%```B`0``304``.4"``"/`0``
MOP0``"0!``"J!````````-@!````````4P(```````#>!0``"`$```````!J
M`P``OP4``#<"``!T`@``5P,``"T$````````XP4``&T"``#:!0``20```!P%
M`````````````","````````=`0``/X$``!G!0```````-X!``!/`P``````
M`&X%``"T`0``#`,``%P"```3!```!@4``+<$```(!@``.@4``+(#``"<!```
M$@0``,$$``#9`P``=P(```````#6````2P```.X!``#S`0```````"4!```H
M`0``4`,``+D!``#`!```:`0```T```!``0``Q0,``(L"``#>`P``U`4``%D!
M``!F`P``!P,``"T!````````A0````````#%`0``N@,``#L````U`0``````
M`"T#```-`@``20$```L$``!&!```<`,``````````````````-`!``"W!0``
MU04``!H!``"P`0``W@(``'\%``"-`@``D@,``/\$``"M`P``$@``````````
M````_`,``,\!```A`P``?0````4#``#2!0``OP```)D%``!C!````````(P!
M``"S`0``,@,``%<!``")`@``=@(``,T"``!#`P```````.D$``!.````K0(`
M`'`$````````@@(``'4"```I`P```````&P!```6`0``T@```.8%``"!!```
MC@(```````"!`0``:P,```````#%````%0$``-0```"$`@``S`0`````````
M`````````!X!```^`@```````$P$```P`0``X@```-,!````````>P0``)T"
M``#V`0```````,,$``!A`0```````*$%```Y!```!04```````"!!0``I0``
M`'D$``#D`P```````#@"``````````````T%``"K````NP$``$L$``!$````
ML@(``"4#```$!@``HP0``+`$``#_``````````````",!```$`,``-<````L
M`P```````%0%````````\P,```$&``!3!0``P@(``)P"``#*`0``P0$``.P!
M```R!0``&P,```````#H`0```````/\!``"T``````````H$``!:!```20(`
M`,L%``!Y`@```````"@"``"B`@````````,"``"]`P``K@(``/\"````````
M```````!``"\`````````-`$``#B`P``*P(``"\%``"J!0```````-D"````
M````>P,``(`#```N````2`(``*<"``#S````D@4```````#]!0``S`4``(`%
M``````````````````#\!0``>`,```````#P!```5@0``'0%```T!```````
M`)D"````````:````(D!``````````````````!V`0``IP4``/D````.`@``
M[0```+T%``#[`P``I04``,X#````````A0$``-T!``!L`@``?0,``+$$```T
M`@``)P,`````````````Y0```)0"```<!```)`(``,(!```"````Q`,``.`%
M``"9`0```````.H"```S`0``)`0``'T!``!*!0``````````````````7`0`
M``````!1`P``L@0```````#U!````````$$```"N!0``D0(```\`````````
MU0,`````````````\`4``!`%```K!````````&,!````````K`(``'@$````
M````W0,``((!```"!@```````+@```##````H@$```````!_````````````
M````````6@(``%0!````````]`,``)T$``"J````'@,``#T```#[`0``1P,`
M``$%``"S`P``5P4``-T`````````YP$````````T`0``>`(``)\$``"(`@``
M`````/H%``!(`P```0$``)P!````````ZP4``/,"``#;`0``2@,``"\"````
M````U00``-P#`````````````(0#``!Z!````````,D#```3`P``*@$``%<"
M````````,`(``.,!```=````WP(```````#)````FP(```````#Y`0``*`,`
M```````I````#P0````%``#^`0``M@0```X%``"W`P``&`$``*$!``!X`0``
M`````$0"``"Y`@``ZP(```````#W````Q04````````7````W`(``&0"``!W
M````>@```/P$````````O@````````"?```````````````1````Y0,``!D%
M```````````````&```P!```B@```/T$```\!0``6`4``'("```Q!```````
M``````"M````X@4```````!>````4@4```````#F!```G@,```D#``"$!0``
M6P0``%\"```K`0``!@```*($``#F`@``"00```````"*!0``@P,``'P"``"Z
M`````````-4``````````````````````````````.0!``!2`````````%X"
M```<`0``F@0``-`%````````WP```&H$``!9`@``<0,```````#U````````
M``````#I`P``2P,``#($``#V`P``-@4````````9!```]@(``)\%````````
M>P4``/\%``#7!```40$```````"I!```:`4``'L"```@!```0P(``)\#``"7
M`0```````#T%``!/!```[04``&,#``!9`P``6`,``%L#``"!````:P```"P`
M```F`0``"P4``&T!````````:P4```````"6`0```````#4#````````;0,`
M`,0```#C`P``O`0```````#^`P```````"H$```@````+@(````````I`@``
M)P(```````!^`0``MP$``.0%````````,`4```````"<`P```````&P`````
M````.04``,,"``!=!0```````'D#``!V`P``?````'T"``#@````^0,`````
M``!,!0``L04``+,$``"D`P````````````!N`0``VP0```H```#Q````N@4`
M``````#1`P````````````#T!````````(<```"H!```!@0````````F`@``
MPP$``%0````6`@``%@0``%\%```G````5`(``+X!``"$!```9`4```L&```&
M`@``7P$``%\$`````````````',````2!0``F@,``(@%```2`@``1@```+,"
M```K`P``````````````````9@```%$%``"Z!```P@0````````>````:04`
M`%8#``"'`@``Z0```'P!``"^!0``X04``+8`````````B@$``,<"``!_`@``
M/`,``/````"*!```I`0``!D#``#N````604``!\"````````HP$``+T$``#V
M`````````)(``````````````&`$``!C!0```````````````````````/4#
M``!_`0``(P```&0#``"$`````````*\`````````4@(``%8````!!```````
M`$X#``!)!0``````````````````0````#@#```,`@``-`,`````````````
MEP```"4%````````!`4``"T````[!0``/P```)L%``!V````(P4``#\"``"@
M`P``A0(`````````````XP(``,P!````````S@$``-8$``#9!````````$4!
M````````R0$``%(#````````@0,``.8`````````!08``-\$``#K````H`0`
M```````"!```&`,``````````````````"@````>!0``Z`(```````#I!0``
M.@$``+X$``!E`P``00$``#8!````````/`$``-P!````````Q00``#@$``#Q
M!```/P$```@"```'!@``[0,``#D#```0`0``%P$``#<#``#R````,0$``%`$
M```#`0``.@,`````````````;P4``+T`````````[`4``*@#````````]P0`
M`)L#```V`P```````+P%``!_`P``@````(X#``#\````D`0``/$!````````
M^@$```````!"!````````-T%```X!0``5@(``+(!````````J`4``-H```"1
M!```H0(``(<$````````"0(```````#J`P``:`,``-$"``!Q`0``'0,`````
M``#!`P``<04```,#```:!0``QP,`````````````G@```-X$``!U````_0(`
M`%(!``"C!0``WP$````````.`P``\0(```<``````````````(L`````````
M6@,``+4``````````````.\!`````````````%@"``!:!0``XP0``#\$```0
M!```F0```,\````Y`@``$P4``"D%````````H00```8&````````?`,``+<`
M```4`0``=`$``'<$`````````````$8%```P````'@(```````"I`P``YP,`
M``L"`````````````&0!````````!`(`````````````&0$``/<#``"&!0``
M<0(``!P"``"Z`0``8@4``$(```!P`0``V`4``#H$````````[@,``/("``#]
M`0``<P4``*X```!I`0``+P$``$P#``"E`0``J`(```````#D!```"P```%4`
M````````V`0```@#```S`@```````&`%``"V`@```````(D%``"T!```&P0`
M`'T$``!/````(0$``!P````B!0``JP4````````^````G0$``'H#``#L`@``
MF`,```L#``!S`@``D@(``/D"````````IP,``"(#``!I`````P8``.`"````
M````+`4``"$`````````$`````````!O`@``S`(```(%`````````````(@#
M```'`@```````+P#``#8````!@$``#$`````````90$```````#2!```?`0`
M`&D$``">`@``CP0``(8$``!0`0```````-4!`````````````&($````````
M7@$``*8!``"P!0```````````````````````#$#``#,`````````-<#``!V
M!0``V`(```````"U!```]@4``!P#``!>`P`````````````,!0``(P$``!@"
M``"K`0``1`4``&$"``"]`@``E@,``"T%````````<P$``#(````L`0``.```
M`!0$``!;`0`````````````R`0``RP,``+$`````````!00``!0%````````
M```````````1!````````-0#```5!```;P,```````!"`0``@P0``,,%``"O
M`P``E0```),`````````)`````````"``@``9@0``&T$````````(@(``*$`
M```_!0``T04``*<$```)!0``K`0``(@```!7````\P4```````!B`0``!@,`
M`%\#```,`````````!L%``!O````+@$``'X````]`@```````,````#Z````
M`````/@#``#Y!`````````T!```X`0``G0````````"P````BP4``"P$``!:
M`0``Q`0``+L%````````S00``$H$``!L`P``2`4````````4`@``-````&<"
M``"N`P```````)$%``"H`0```````-$!``#G`@``N0```*,"``#]````C0$`
M`%P#````````W`0``),%``"7`@``A04``)H"```8!```TP(```````#7`@``
M1P4``"H```##`P``T00``,$"``!G`0``+P`````````Y`0``@`0``+0"``#'
M````UP$``,\%``",`````````#P$````````P`(``&0````$`0```@(``/T#
M```L`@``50,```0$``".````T0```*8%`````````````!0#``"<````8`,`
M`%P````-!```00,```````!Z!0``````````````````C`,``'`%```:!```
M'P```-P```!O!```\`(```````!F`0```````)T#```7!```3`$``$T```#G
M````E00````````/`0````````````!T````"@(``*,```#9!0```````'$`
M````!```M0,``"H"````````D`4``(\`````````CP(``!T!```?!0``````
M`+<"````````2@$``+0#``#3`P``.P$``/0!````````8`$``*0!```2`P``
M-`4``($"``!!!```I0,``.4%``!6`0``H````&8%````````)`4``/$#``"[
M`P````````````"O`@```````$\"``#:`@``YP0````"````````+@,```@$
M``!&`P``(P0```````#J!````````(0!``#A!```_`$```````!-`P``/0,`
M`'X$``!%`P``!P$``$4"```+`0``5@4```X$``#X`@````````,%``#R`P``
M700``/`#``"F`P``3P4``%T#```:`P``300``)T%```*`P``=0,```,```#+
M!````````,$%``!?`````````!T"``#"`P```````!L"````````L@4``,@%
M``#2`0```````),!``"O!````````#4```!D!```E@``````````````OP$`
M`&$#``#O!````````#,```#O`@``600``),"```^`P``Q@,``/H#``#W`0``
ML@````````!5`@``R````!0```"B`P``<@````````!#!0``6@``````````
M````LP4``%$"```7`@```````((#``!7!```0@(```````"7!```VP``````
M```!`@``<00``-T"`````````````"<%``#W!0``:P(```<$``#2`P``FP``
M`&4$`````````````.`!````````P`4``'H!``#'`0``0`(`````````````
MAP4`````````````1P(````````,!```````````````````S@````````!@
M``````````````"U`0``\@0``+\#``````````````````!W`P``6`$``#X!
M````````S0,`````````````$0$``+@"``#'!```S04`````````````TP4`
M``````!(`0``100``)`"``"#!0``I00``%,```"4!0``+@0``#4%``!5!```
M^P(```````#B`@``O@,```````#I`@``Q@4``(P%```S`P``_@(``$0!````
M````T````)@!``"U!0``B@,````````>!```E@0```````"T!0``(00``-T$
M````````F`(``````````````````&P$``#E!```A@```(T$````````00(`
M`#L"``!)!```R@(``&$$```U`@``30$``!@```!F`@```````)<%``!=`@``
MP@4``.L!````````[@(```4```"\`0``SP(``)@```!(````2@```!8%``",
M`@```````*$#````````&`4``(`!```!`P```````````````````````,H$
M``#D`@```@$``````````````````'8$``!Y`0``-P0``,X$``"*`@``K04`
M``````!$!```SP0``!$"````````50$``'T%``!U!```)P0``%P%````````
M,0(```````")`````````%T!```E`@``'P$``-H#````````"```````````
M`````````(\%````````:@$````````K`````````'D````,`0``1`,```(#
M````````'04``$`$````````I`(``#`#``"8!```6````)L$````````]0(`
M`$`%``!.!0``)@```*8$``!B`@``(`$``#H"````````L`,``&`"````````
MB`$``.`$`````````````/P"``!"`P``%0(`````````````[@0``&T````$
M`P```````-\#``"X!0``3@$``-@#``"]`0```````!$%``"K`@``E`,``*D`
M````````V@$```````"V!0``H`$```````````````````````!R`0``(04`
M``````"0`0```````"D!``"L!0``$P(```D!``"%!```)@4``(<#````````
M`````!H```#[!0``K````)`#```S!0``G@4``!\#``#L`P``90``````````
M`````````````````````````&X#``#L````B0,``$,$````````L0(``)(!
M``#Z!````````/\#````````V0```"T"````````LP```.$"``"^`@``````
M`!`"``#M`0```````/0%````````;@0``#P```"_`@``!````/@```#)!0``
M?@(`````````````*@,`````````````C0,``%D```""````T@(``%`"``!K
M!```D0```)8"``!!!0``0@4``.@$`````````````,`!``#4`0``C0```'@%
M``"D!0``:@(```4"``"6!0``6`0``/L$```3`0``=P4``!D```#F`0``````
M`(D$``#U`0``-@```!8```!_!````````-8!````````T`,```````!#`0``
M2P$``"@%```'!0``1@$``-D!```9`@``DP,```````#(!```K@0````@(%1H
M92!M86EL8F]X('1R87-H(&ES(&%L<F5A9'D@96UP='DN`"`F(S$U,3L@)7,@
M:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N
M<R!C:&5C:V5D(&)E;&]W+@`@*"5S(&1A>7,@86=O*0`@*$%C8V5S<VME>2`E
M<RD`("AI;B`E<R!D87ES*0`@*'1O9&%Y*0`@*'1O;6]R<F]W*0`@*'EE<W1E
M<F1A>2D`(&%T(``E9"`E<R!A;F0@)7,`)60M9&%Y(&9O<F5C87-T`"5S("T@
M3F]T:6-E`"5S($%D;6EN:7-T<F%T:6]N`"5S($9I;F=E<G!R:6YT`"5S($UA
M:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF:7)M871I;VX`)7,@4V5T=7``
M)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E96UE;G0`)7,@86QR96%D>2!E
M>&ES=',N`"5S(&%T("5S("5S`"5S(&AA<R!C86YC96QL960@)7,N`"5S(&AA
M<R!R97!L:65D('1O(&$@9G)E92]B=7-Y(')E<75E<W0N`"5S(&AA<R!R97!L
M:65D('1O('1H92!I;G9I=&%T:6]N('1O("5S+@`E<R!H87,@<V5N="!Y;W4@
M9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU
M=&5S`"5S(')E<75E<W1S('EO=7(@9G)E92]B=7-Y(&EN9F]R;6%T:6]N+@`E
M<R!R97%U97-T<R!Y;W5R('!R97-E;F-E(&%T("5S+@`E<R!T;R`E<R!O9B`E
M<P`E<R!W:7-H97,@=&\@861D('1O("5S+@`E<R!W:7-H97,@=&\@;6%K92!Y
M;W4@87=A<F4@;V8@)7,N`"5S('=I<VAE<R!T;R!R96-E:79E('1H92!L871E
M<W0@:6YF;W)M871I;VX@86)O=70@)7,N`"5S)W,@061D<F5S<R!";V]K`"5S
M)W,@0V%L96YD87(`)7,G<R!.;W1E<&%D`"5S)W,@5&%S:VQI<W0`)R5S)R!I
M<R!N;W0@82!V86QI9"!C:&]I8V4N`"<E<R<@:7,@;F]T(&-O;F9I9W5R960@
M:6X@=&AE($AO<F1E(%)E9VES=')Y+@`G)7,G('1R964@<F5N9&5R97(@;F]T
M(&9O=6YD+@`G)7,G('=A<R!A9&1E9"!T;R!T:&4@9W)O=7!S('-Y<W1E;2X`
M)R5S)R!W87,@861D960@=&\@=&AE('!E<FUI<W-I;VYS('-Y<W1E;2X`)R5S
M)R!W87,@;F]T(&-R96%T960Z("5S+@`L(&=U<W1I;F<@)7,@)7,`+"!V87)I
M86)L92!F<F]M("5S('1O("5S`"TM('-E;&5C="`M+0`Q,B!(;W5R($9O<FUA
M=``R-"!(;W5R($9O<FUA=``R-"!H;W5R<P`\8CY!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9#H\+V(^`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@
M<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@
M<VEG;F5D(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0
M(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@
M82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL
M(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G
M92X`02!P=6)L:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A
M;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A
M9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@
M86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E
M+@!!('!U8FQI8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A
M(&UE<W-A9V4N`$%-+U!-`$%B;W5T('1H:7,@961I=&]R`$%B;W5T+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`06-C97!T(')E<75E<W0`06-C97!T960`06-C
M97-S(&1E;FEE9"!C<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U
M;G0@9G)O>F5N+@!!8V-O=6YT:6YG`$%C=&EO;G,`061D`$%D9"!#:&EL9"!'
M<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'
M<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@
M)R5S)P!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("<E<R<`061D(&$@;F5W
M('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&AI<R!T
M;R!M>2!C86QE;F1A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&0@=&\@;7D@
M861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D9&5D("<E<R<@=&\@=&AE('-Y<W1E
M;2P@8G5T(&-O=6QD(&YO="!A9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M
M871I;VXZ("5S+@!!9&1E9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@
M;&]G(&EN(&YO=RX`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S
M`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O
M<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!:W1I;VX@06ER<&]R=`!!
M;&5X86YD<F]U<&]L:2!!:7)P;W)T`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`
M06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E
M<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E
M<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E
M861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U3
M4"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@
M96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T
M97AT.@!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N8VAI86QO
M<R!!:7)P;W)T`$%N9')A=FED82!!:7)P;W)T`$%N;VYY;6]U<R!0<F]X>0!!
M;G-W97(`07!P;&EC871I;VX`07!P;&EC871I;VX@3&ES=`!!<'!L:6-A=&EO
M;B!I<R!R96%D>2X`07!P;'D@=&\@0VAI;&0@4VAA<F5S`$%P<')O=F4`07!R
M:6P`07)A>&]S($%I<G!O<G0`07)C:&EV92!&:6QE(%-I>F4`07)C:&EV92!.
M86UE`$%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-I9VYU
M<"!R97%U97-T(&9O<B`E<R`_`$%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!D
M96QE=&4@)R5S)R!A;F0@86YY('-U8BUG<F]U<',_`$%R=`!!<V-I:2!!<G0`
M07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!=&AI;F%I($%I<G!O
M<G0`071T86-H960@:7,@86X@:4-A;&5N9&%R(&9I;&4@<F5P;'D@=&\@82!R
M97%U97-T('EO=2!S96YT`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!='1E;F1E97,`071T<FEB=71E<P!!=6=U<W0`075T:&5N=&EC871I;VX@
M9F%I;&5D`$%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%W86ET
M:6YG(%)E<W!O;G-E`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@
M:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%R
M90!"87-E(&=R87!H:6-S(&1I<F5C=&]R>2`G)7,G(&YO="!F;W5N9"X`0F%S
M96QI;F4`0FER=&AD87D`0FQO8VL@(B5S(B!O9B!A<'!L:6-A=&EO;B`B)7,B
M(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN9W,`0FQO8VL@5'EP90!";VQD`$)O
M<F1E<G,`0F]T:`!";W1T;VT`0G5L;&5T960@3&ES=`!#4DP@1&ES=')I8G5T
M:6]N(%!O:6YT<P!#5E,`0U]E;&P@4')O<&5R=&EE<RXN+@!#86QE;F1A<@!#
M86QE;F1A<B!3=6UM87)Y`$-A;&5N9&%R.@!#86QM`$-A;B!N;W0@<F5S970@
M<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN:7-T
M<F%T;W(N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F-E
M;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F:6QE("(E
M<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`0V%N;F]T
M('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R+@!#86YN
M;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E+"`E9"!C
M:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O9B!E;G1R
M:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H(&YU;6)E
M<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A<'1I;VX`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-E;&P@4&AO
M;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN9SH`0V5L;"!P<F]P97)T
M:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E;G1E<@!#97)T:69I8V%T
M92!$971A:6QS`$-E<G1I9FEC871E(%!O;&EC:65S`$-H86ER(%!E<G-O;@!#
M:&%N9V4`0VAA;F=E(%!A<W-W;W)D`$-H86YG92!T:&4@;F%M92!A;F0@861D
M<F5S<R!T:&%T('!E;W!L92!S964@=VAE;B!T:&5Y(')E860@86YD(')E<&QY
M('1O('EO=7(@96UA:6QS+@!#:&%R`$-H96-?:R!,:6YK+BXN`$-H96-K('1H
M92!B;W@@9F]R(&%N>2!O<&5R871I;VXH<RD@>6]U('=A;G0@=&\@<&5R9F]R
M;2!A="!T:&ES('1I;64N`$-H:6]S($%I<G!O<G0`0VAO;W-E($%P<&QI8V%T
M:6]N.@!#:&]O<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O
M<V4@86X@86-T:6]N.@!#:&]O<V4@:&]W('1O(&1I<W!L87D@9&%T97,Z`$-H
M;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D(&QI<W1S*0!#:')Y
M<V]U<&]L:2!!:7)P;W)T`$-L87-S(&1E9FEN:71I;VX@;V8@)7,@;F]T(&9O
M=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R(&]U="!U<V5R
M.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&EC:R!T;R!#;VYT
M:6YU90!#;&]S92!(96QP`$-L;W-E($AE;'`@5VEN9&]W`$-L;W-E(%=I;F1O
M=P!#;VQL87!S92!3:61E8F%R`$-O;&QA<'-E9"!B;W)D97)S`$-O;&]R`$-O
M;&]R(%!I8VME<@!#;VQO=7(@<V5L96-T:6]N`$-O;',Z`$-O;'5M;B!T:71L
M97,`0V]M:6-S`$-O;6UA;F0`0V]M;6%N9"!3:&5L;`!#;VUM96YT`$-O;6UO
M;B!.86UE`$-O;7!A;GD`0V]M<&QE=&5D`$-O;7!O<V4@365S<V%G92`H)7,I
M`$-O;7!U=&5R<P!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC
M97,`0V]N9FEG=7)A=&EO;B!F;W(@<WEN8VEN9R!W:71H(%!$07,L(%-M87)T
M<&AO;F5S(&%N9"!/=71L;V]K+@!#;VYF:6=U<F%T:6]N(&ES(&]U="!O9B!D
M871E+@!#;VYF:6=U<F%T:6]N(&YE961S('5P9&%T:6YG+@!#;VYF:6=U<F4@
M)7,`0V]N9FER;2!087-S=V]R9`!#;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C
M=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U8FQI
M8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC
M(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N`$-O;G1A8W0@4V5A<F-H`$-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT
M96YT<R!O9B`G)7,G`$-O;G1E;G1S(&]F('1H92!205(@87)C:&EV90!#;VYT
M:6YU90!#;W!Y`$-O<'D@<V5L96-T:6]N`$-O=6QD(&YO="!01U`@96YC<GEP
M="!M97-S86=E+@!#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!E;F-R>7!T(&UE<W-A9V4N`$-O=6QD(&YO="!3+TU)344@
M<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@861D(&-O;G1A8W0N("5S`$-O=6QD
M(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+@!#;W5L9"!N;W0@8VAE8VL@8F%L
M86YC92X@)7,`0V]U;&0@;F]T(&-O;FYE8W0@=&\@<V5R=F5R("<E<R<@=7-I
M;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E
M8W)Y<'0@4R]-24U%(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@
M)7,`0V]U;&0@;F]T(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U
M;&0@;F]T(&1E;&5T92!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!#;W5L
M9"!N;W0@9&5T97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S
M<RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U
M;&0@;F]T(&9E=&-H(&-O;7!L971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L
M9"!N;W0@9F5T8V@@=&AE(&-O;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N
M(&QI<W1S+@!#;W5L9"!N;W0@;&]A9"!S=')A=&5G>2`G)7,G+@!#;W5L9"!N
M;W0@;6MD:7(@)R5S)RX`0V]U;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R
M;VT@=&AE(&ME>7-E<G9E<BX`0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO
M="!O<&5N("<E<R<@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N($UA:6YT
M96YA;F-E7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!O<&5N(&1I<F5C=&]R
M>2`G)7,G+@!#;W5L9"!N;W0@<F5A9"`E<RX`0V]U;&0@;F]T(')E<V5T('1H
M92!P87-S=V]R9"!F;W(@=&AE(')E<75E<W1E9"!U<V5R+B!3;VUE(&]R(&%L
M;"!O9B!T:&4@9&5T86EL<R!A<F4@;F]T(&-O<G)E8W0N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$-O=6QD(&YO="!R971R:65V92!!0TP`0V]U;&0@;F]T(')E
M=')I979E(&%D9')E<W,@8F]O:RX@)7,`0V]U;&0@;F]T(')E=')I979E(&1I
M<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@9&ES=')I
M8G5T:6]N(&QI<W1S+B`E<P!#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@
M8V%P86)I;&ET:65S`$-O=6QD(&YO="!R979E<G0@8V]N9FEG=7)A=&EO;BX`
M0V]U;&0@;F]T(')M9&ER("<E<R<N`$-O=6QD(&YO="!S879E("5S(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;BX`0V]U;&0@;F]T('-A=F4@82!B86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#
M;W5L9"!N;W0@<V%V92!S971U<"!U<&=R861E('-C<FEP="!T;SH@)R5S)RX`
M0V]U;&0@;F]T('-A=F4@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N`$-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@<V%V
M92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE(&-O
M9&4@8F5L;W<@=&\@)7,N`$-O=6QD(&YO="!S96%R8V@@=&AE($Q$05`@<V5R
M=F5R+@!#;W5L9"!N;W0@=6YL:6YK("<E<R<N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&0@;F]T('=R:71E(&-O;F9I9W5R871I;VX@9F]R("<E<R<Z
M("5S`$-O=6QD;B=T(&9I;F0@=&AE($UO>FEL;&$@4VED96)A<BX@36%K92!S
M=7)E('1H92!S:61E8F%R(&ES(&]P96XN`$-O=6QD;B=T(&=I=F4@=7-E<B`G
M)7,G('1H92!F;VQL;W=I;F<@<FEG:'1S(&9O<B!T:&4@9F]L9&5R("<E<R<Z
M("5S`$-O=6YT960@=&5X=`!#;W5N=')Y`$-O=7)S97,`0W)E871E`$-R96%T
M92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B(&9O;&1E<G,`
M0W)E871O<B!097)M:7-S:6]N<P!#<F5D:70@8V%R9"!N=6UB97(`0W)E9&ET
M<P!#=7)R96YT(%!H87-E`$-U<G)E;G0@5&EM90!#=7)R96YT(%523"!I<P!#
M=7)R96YT(%=E871H97(`0W5R<F5N="!C;VYD:71I;VXZ(`!#=7)R96YT('-T
M>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O;B!T;R`E<RX`
M0W5T`$-U="!S96QE8W1I;VX`1$0`1&%I;'D`1&%T80!$871A5')E92!"<F]W
M<V5R`$1A=&%B87-E('%U97)Y(&9A:6QE9"X`1&%T90!$871E(%)E8V5I=F5D
M`$1A=&4@<V5L96-T:6]N`$1A>0!$95]L971E($-O;'5M;@!$96-E;6)E<@!$
M96-I;6%L(&YU;6)E<G,`1&5C;&EN960`1&5C<F5A<V4@26YD96YT`$1E9F%U
M;'0`1&5F875L="!#;VQO<@!$969A=6QT($ED96YT:71Y`$1E9F%U;'0@4&5R
M;6ES<VEO;G,`1&5F875L="!P97)M:7-S:6]N<P!$969I;FET:6]N<P!$96QE
M9V%T92!P;W-I=&EO;@!$96QE9V%T960`1&5L971E`$1E;&5T92!'<F]U<`!$
M96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E
M;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T90!$96QE=&4@<&5R;6ES<VEO;G,@9F]R("<E<R<`1&5L
M971E('!E<FUI<W-I;VYS(&9O<B`G)7,G(&%N9"!A;GD@<W5B+7!E<FUI<W-I
M;VYS/P!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE
M=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`
M1&5L971E('1H:7,@<&5R;6ES<VEO;B!A;F0@86YY('-U8BUP97)M:7-S:6]N
M<S\`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`G)7,G+@!$96QI=F5R
M>2!T:6UE`$1E;GD@<F5Q=65S=`!$96YY(')E<75E<W0@9F]R(&9R964O8G5S
M>2!I;F9O<FUA=&EO;@!$97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO
M;@!$971A:6QS("AA;'-O(&EN($AO<F1E)W,@;&]G9FEL92DZ`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1E=F5L
M;W!M96YT`$1E=R!0;VEN=`!$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CH@`$1E
M=R!P;VEN=#H@`$1I<F5C=&EO;B!L969T('1O(')I9VAT`$1I<F5C=&EO;B!R
M:6=H="!T;R!L969T`$1I<F5C=&]R>0!$:7-P;&%Y(#(T+6AO=7(@=&EM97,_
M`$1I<W!L87D@3W!T:6]N<P!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L
M87D@9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$;R!N;W0@9&5L
M971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP`$1O
M97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@268@
M>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]W;FQO860`1&]W;FQO860@)7,`1&]W
M;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`
M1')O<"!D;W=N(&QI<W0`1')U9W,`161I=`!%9&ET($)L;V-K`$5D:70@1W)O
M=7``161I="!097)M:7-S:6]N`$5D:70@4&5R;6ES<VEO;G,`161I="!097)M
M:7-S:6]N<R!F;W(@)7,`161I="!O<'1I;VYS(&9O<CH`161I="!P97)M:7-S
M:6]N<R!F;W(@)7,`161I="!P97)M:7-S:6]N<R!F;W(@)R5S)P!%;&5F<VES
M($%I<G!O<G0`16QE;65N="XN+@!%;6%I;`!%;6%I;"!!9&1R97-S`$5M86EL
M(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6%I;"!W:71H(&-O;F9I<FUA=&EO
M;@!%;6]T:6-O;G,`16UP='D@;65S<V%G92X`16UP='D@<F5S=6QT+@!%;7!T
M>2!S96%R8V@@=&5R;7,`16YA8FQE(&EN<V5R=&EO;B!O9B!I;6%G97,@9G)O
M;2!0:&]T;R!'86QL97)I97,@:6X@=&5X=#\`16YA8FQE(')I9VAT(&-L:6-K
M(&-O;G1E>'0@;65N=3\`16YD`$5N9"!Y96%R`$5N;&%R9V4@161I=&]R`$5N
M=&5R(&$@<V5C=7)I='D@<75E<W1I;VX@=VAI8V@@>6]U('=I;&P@8F4@87-K
M960@:68@>6]U(&YE960@=&\@<F5S970@>6]U<B!P87-S=V]R9"P@92YG+B`G
M=VAA="!I<R!T:&4@;F%M92!O9B!Y;W5R('!E=#\G.@!%;G1E<B!T:&4@:6UA
M9V4@55),(&AE<F4`17)R;W(`17)R;W(@<V5N9&EN9R!R97!L>3H@)7,N`$5R
M<F]R('=I=&@@96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`G)7,G+@!%
M=&AN:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S
M`$5V97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN
M`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z
M`$5X96-U=&4`17AP86YD`$5X<&%N9"!3:61E8F%R`$5X<&5C=&5D(")"14=)
M3B(@:6X@=&AE(&QI;F4@)60N`$5X<&5C=&5D(")%3D0Z)7,B(&EN(&QI;F4@
M)60N`$5X<&5C=&5D("<I)P!%>'!E8W1E9"!B87)E('=O<F0@;W(@<75O=&5D
M('-E87)C:"!T97)M`$5X<&ER871I;VX@1&%T90!%>'!O;F5N=`!&1R!#;VQO
M<@!&5%`@=7!L;V%D(&]F('-E='5P`$9A:6QE9"!R971R:65V:6YG('!R969E
M<F5N8V5S+@!&86EL960@=&\@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`1F%I
M;&5D('1O(&-O;FYE8W0@=&\@4TU"('-E<G9E<BX`1F%I;&5D('1O(&-O<'D@
M9G)O;2`B)7,B+@!&86EL960@=&\@8V]P>2!T;R`B)7,B+@!&86EL960@=&\@
M8W)E871E(&YE=R!305-,(&-O;FYE8W1I;VXN`$9A:6QE9"!T;R!M;W9E('1O
M("(E<R(N`$9A:6QU<F4@:6X@8VAA;F=I;F<@<&%S<W=O<F0@9F]R('5S97(@
M)7,@9G)O;2!C;&EE;G0@)7,L(')E87-O;B`E<P!&86ER`$9A=&%L($5R<F]R
M.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H
M;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEL92!#;W5N
M=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F:6QE<P!&:6QE($UA;F%G97(`
M1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I;&4@=7!L;V%D`$9I;&4@=7!L
M;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S`$9I<G-T($AA;&8`1FER<W0@
M475A<G1E<@!&:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O
M97,@;F]T(&5X:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA
M="!D;VXG="!S=7!P;W)T(&EM86=E<P!&;W)G;W0@>6]U<B!P87-S=V]R9#\`
M1F]R;7,`1F]R='5N90!&;W)T=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@
M,@!&;W)U;7,`1F]R=V%R9',`1G(`1G)A;65S`$9R964O0G5S>2!);F9O<FUA
M=&EO;@!&<F5E+T)U<WD@4F5P;'D`1G)E92]"=7-Y(%)E<75E<W0`1G)E92]"
M=7-Y(%)E<75E<W0@4F5S<&]N<V4`1G)O;0!&<F]M('1H92``1G5L;"!$97-C
M<FEP=&EO;@!&=6QL($1E<V-R:7!T:6]N.@!&=6QL($UO;VX`1G5L;"!.86UE
M`$=A;&QE<GD@=&\@=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=I=F5N($YA
M;64`1VQO8F%L($]P=&EO;G,`1V\`1W)E96-E`$=R965K("A)4T\M.#@U.2TW
M*0!'<F]U<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO
M;BUE;7!T>0!'<F]U<"!P97)M:7-S:6]N<P!'<F]U<',`1W5E<W0@4&5R;6ES
M<VEO;G,`1W5E<W0@<&5R;6ES<VEO;G,`1W5E<W1B;V]K`$A45%`@075T:&5N
M=&EC871I;VX@;F]T(&9O=6YD+@!(96EG:'0`2&5L<`!(96QP('5S:6YG(&5D
M:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)A:VQI;VX@06ER<&]R=`!(97)E
M(&ES('1H92!B96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&ES=&]R>2!E
M;G1R>2!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>0!(;U]M90!(;VUE`$AO;64@
M061D<F5S<P!(;VUE(%!H;VYE`$AO<F1E`$AO<F1E($QO9VEN`$AO<F1E(%-Y
M<W1E;0!(;W)D92!7:7)E;&5S<P!(;W)D92!I<R!N;W0@<')O<&5R;'D@8V]N
M9FEG=7)E9`!(;W)I>F]N=&%L(%)U;&4`2&]R:7IO;G1A;"!P861D:6YG`$AO
M<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E="!H97)E/R`H4&QE87-E(')E<&]R
M="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U;&0@>6]U(&QI:V4@=&\@;65R9V4_
M`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN<RD@87)E('1H97)E/P!(;W<@;6%N
M>2!R;W=S('=O=6QD('EO=2!L:6ME('1O(&UE<F=E/P!(=6UI9&ET>0!(=6UI
M9&ET>3H@`$AU;6]R:7-T<P!)34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D
M.B`E<P!)34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<P!)34%0(&UA
M:6QB;W@@<75O=&$@8W)E871I;VX@9F%I;&5D.B`E<P!)3D)/6`!)4"!!9&1R
M97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`25`@061D<F5S<R!N;W0@
M=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@;&]C:V1O=VX@=FEO;&%T
M:6]N+@!)7VYB;W@`25]N<V5R="!2;W<@0F5F;W)E`$EC;VYS($]N;'D`26-O
M;G,@9F]R("5S`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF
M(&ET(&ES(&YO="!D:7-P;&%Y960@8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET
M(&EN(&$@;F5W('=I;F1O=RX`268@>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@
M=7-I;F<@26YT97)N970@17AP;&]R97(L('EO=2!M87D@;F5E9"!T;R!C:&5C
M:R!T:&ES(&)O>"!T;R!T=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y
M;W4@<V5E('1H:7,@;65S<V%G92!B=70@;F\@:6UA9V4L('1H92!I;6%G92!Y
M;W4@=V%N="!T;R!U<&QO860@8V%N)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@
M8G)O=W-E<BX`26UA9V4@4')E=FEE=SH`26UA9V4@55),`$EM86=E(&9R;VT@
M9V%L;&5R>0!);6%G92!F<F]M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G
M97,`26UP;W)T`$EM<&]R="!%<G)O<CH@`$EM<&]R="P@4W1E<"`E9`!);7!O
M<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);B!0<F]C97-S`$EN
M7W-E<G0@4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`
M26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T
M('5S97)N86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@
M8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE
M<B!H96QP+@!);F-R96%S92!);F1E;G0`26YD:79I9'5A;"!5<V5R<P!);F9O
M`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN($%F=&5R`$EN<V5R="!);6%G
M90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,:6YK`$EN<V5R="!?0V]L=6UN
M($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN(&%F=&5R('1H92!C=7)R96YT
M(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E9F]R92!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS
M97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A
M('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A('!A
M<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@86QT97)N
M871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I;"!A9&1R97-S('1O('=H:6-H
M('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A<W-W;W)D.@!);G-E<G0@8V5L
M;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`26YS97)T(&-O;'5M;B!A9G1E
M<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E<G0@;65S<V%G97,`26YS97)T
M('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R86=R87!H(&)E9F]R90!);G-E
M<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F;W)E`$EN<V5R="!T:&4@<F5Q
M=6ER960@86YS=V5R('1O('1H92!S96-U<FET>2!Q=65S=&EO;CH`26YS97)T
M+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y($QI;FL`26YS=69F:6-I96YT
M(&-R961I="!T;R!S96YD('1O('1H92!D:7-T<FEB=71I;VX@;&ES="X`26YS
M=69F:6-I96YT(&-R961I="X`26YT96=E<@!);G1E9V5R(&QI<W0`26YV86QI
M9"!!8W1I;VX@<V5L96-T960@9F]R('1H:7,@8V]M<&]N96YT+@!);G9A;&ED
M(%5$2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N
M+@!);G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!)
M;G9A;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M
M870`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<F5C
M:7!I96YT.B`G)7,G`$EN=F%L:60@<VAA<F4@;V)J96-T`$EN=F%L:60@<V]U
M<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D92!D871A+@!);G9E;G1O<GD`
M271A;&EC`$IA;G5A<GD`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT
M97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA
M;&%M871A($%I<G!O<G0`2V%R<&%T:&]S($%I<G!O<G0`2V%S=&]R:6$@06ER
M<&]R=`!+965P(&]R:6=I;F%L/P!+969A;&AN:6$@06ER<&]R=`!+97)B97)O
M<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FMY<F$@06ER
M<&]R=`!+97)N96P@3F5W8FEE<P!+97D@0W)E871I;VX`2V5Y($9I;F=E<G!R
M:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2V5Y(%5S86=E`$ME>2!A;')E861Y
M(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME>7-E<G9E<BX`2VED<P!+;W,@06ER
M<&]R=`!+;WIA;FD@06ER<&]R=`!,85]Y;W5T`$QA<FES82!!:7)P;W)T`$QA
M<W0@2&%L9@!,87-T(%%U87)T97(`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN
M.B`E<P!,87-T(&QO9VEN.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R
M`$QA=P!,87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,969T`$QE
M9G0@:&5A9&5R`$QE9G0@=F%L=65S`$QI;65R:6-K`$QI;6YO<R!!:7)P;W)T
M`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL(&%D9')E<W,@
M=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`3&EN:W,`3&EN
M=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<@!,:7-T
M($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B;&5S`$QI<W1I
M;F<@=7-E<G,@:7,@9&ES86)L960N`$QO861I;F<N+BX`3&]C86P@=&EM93H@
M`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I
M;B!487-K<P!,;V=I;B!F86EL960@9F]R('-O;64@<F5A<V]N+B!-;W-T(&QI
M:V5L>2!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN
M8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO9V]U=`!,;VYG('1E>'0`3&]V
M90!,;W<`3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S
M`$QO=V5R(')O;6%N(&YU;6)E<G,`34T`36%G:6,`36%I;`!-86EL($%D;6EN
M`$UA:V4@;&EN7VLN+BX`36%N86=E('1H92!L:7-T(&]F(&-A=&5G;W)I97,@
M>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O;&]R<R!A<W-O
M8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%N=6%L`$UA<"!$871E
M(&%N9"!4:6UE($9I96QD<P!-87`@26UP;W)T($9I96QD<P!-87)C:`!-87)G
M:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE
M<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA=&-H:6YG(&9I
M96QD<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S(&5X
M8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@;&%S
M="`V(&AO=7)S.B``36%X:6UU;2!L96YG=&@`36%Y`$UE971I;F<@0V%N8V5L
M;&%T:6]N`$UE971I;F<@26YF;W)M871I;VX`365E=&EN9R!0<F]P;W-A;`!-
M965T:6YG(%)E<&QY`$UE971I;F<@57!D871E`$UE971I;F<@57!D871E(%)E
M<75E<W0`365M8F5R<P!-96UO<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE
M<W-A9V4`365S<V%G92!697)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S
M:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE
M<W-A9V4@97AP:7)E9"X`365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T
M87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL
M86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI
M<W1R871O<BX`365T:&]D`$UE=&AO9"`G)7,G(&ES(&YO="!D969I;F5D`$UE
M=')I8P!-:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z
M(`!-:6X@=&5M<"!L87-T(#8@:&]U<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U
M<P!-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@
M8V]N9FEG=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF
M('EO=2!W86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE
M<W-A9V4@240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN
M`$UI<W-I;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`
M36]D:69I960@1&%T90!-;V1I9GD@55),`$UO;G1H(%9I97<`36]N=&@@86YD
M('EE87(`36]N=&AL>0!-;VYT:&QY($5V96YT<R!,:7-T`$UO;VX@4&AA<V5S
M`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO=F4@
M9&]W;@!-;W9E('5P`$UU;'1I+6QE=F5L(&1R;W`@9&]W;B!L:7-T<P!-=6QT
M:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!->2!0;W)T86P`37D@4&]R=&%L
M($QA>6]U=`!->2!3=6UM87)Y`$UY=&EL:6YI($%I<G!O<G0`3D\L($D@1&\@
M3D]4($%G<F5E`$YA;64`3F5E9',@06-T:6]N`$YE='=O<FL`3F5V97(`3F5W
M($-A=&5G;W)Y`$YE=R!-;V]N`$YE=R!087-S=V]R9`!.97<@4&%S<W=O<F0@
M*&%G86EN*0!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@=VEN9&]W("A?
M8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@4&%G90!.97AT(%!H
M87-E`$YE>'0@;W!T:6]N<P!.;P!.;R!A=F%I;&%B;&4@8V]N9FEG=7)A=&EO
M;B!D871A('1O('-H;W<@9&EF9F5R96YC97,@9F]R+@!.;R!A=F%I;&%B;&4@
M<W1R871E9WD@9F]R(&UA:VEN9R!)4T\@:6UA9V5S+@!.;R!B871C:"!T96UP
M;&%T92X`3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I
M;VX`3F\@8V%L96YD87(@;F%M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT
M:6-A=&EO;BX`3F\@8VAA;F=E+@!.;R!C:&EL9"!P97)M:7-S:6]N<R!A<F4@
M=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X`3F\@8VAI;&1R96X@8V%N
M(&)E(&%D9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($Q$05`@4')E
M9F5R96YC97,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF
M:65D(&9O<B!344P@0V%T96=O<FEE<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!0<F5F97)E;F-E<RX`3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N
M`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!3
M44P@875T:&5N=&EC871I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I
M;VX@<W!E8VEF:65D(&9O<B!344PM1FEL92!61E,N`$YO(&-R961I="!L969T
M+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE9"X`3F\@9FEL92!U<&QO861E9`!.
M;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I;VX@:7,@<V5T+@!.;R!M97-S86=E
M('-U<'!L:65D+@!.;R!N86UE('-P96-I9FEE9"X`3F\@;G5M8F5R('-P96-I
M9FEE9"X`3F\@;V9F96YS:79E(&9O<G1U;F5S`$YO('!E;F1I;F<@<VEG;G5P
M<RX`3F\@<')E9F5R96YC97,@87)E(&%V86EL86)L92X`3F\@<G5L97,`3F\@
M<VED97,`3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A
M8VAE+@!.;R!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0@<V5N="X`3F\@=F%L
M:60@6$U,(&1A=&$@<F5T=7)N960`3F\@=F%L=65S`$YO('9E<G-I;VX@9F]U
M;F0@:6X@;W)I9VEN86P@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T92!C;VYF
M:6=U<F%T:6]N+@!.;R!V97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A
M=&EO;BX@4F5G96YE<F%T92!C;VYF:6=U<F%T:6]N+@!.;VX@4&%R=&EC:7!A
M;G0`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<G1H97)N($AE;6ES<&AE
M<F4`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y`$YO="!I
M;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E<P!.;W1E
M<R!3=6UM87)Y`$YO=&5S(&ES(&%N(&%P<&QI8V%T:6]N('=H:6-H(&%L;&]W
M<R!Y;W4@=&\@8W)E871E('1H92!C;VUP=71E<B!E<75I=F%L96YT(&]F('-T
M:6-K>2!N;W1E<RX@3F]T97,@8V%N(&)E(&-R96%T960L(&UO9&EF:65D+"!D
M96QE=&5D+"!A;F0@<')I;G1E9"X@66]U(&-A;B!A;'-O('-E87)C:"!O;B!Y
M;W5R(&YO=&5S('1O(&QO8V%T92!I;F9O<FUA=&EO;BX@4W5P<&]R="!F;W(@
M:6UP;W)T:6YG(&%N9"!E>'!O<G1I;F<@;F]T97,@:7,@86QS;R!A=F%I;&%B
M;&4N`$YO=&5S.@!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]T:6-E
M`$YO=&EF:6-A=&EO;B!L:7-T96YE<B`E<R!N;W0@9F]U;F0N`$YO=F5M8F5R
M`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN
M<P!.=6UB97(@;V8@8V]L=6UN<R!I;B!T:&4@<W5M;6%R>2!V:65W.@!.=6UB
M97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P9&%T:6YG
M(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/8FIE8W0`3V)J96-T($-R96%T;W(`
M3V)J96-T(&-R96%T;W(@<&5R;6ES<VEO;G,`3V-T86P`3V-T;V)E<@!/9F9E
M;G-E(&9I;'1E<@!/9F9I8V4`3VQD(%!A<W-W;W)D`$]N;'D@24U!4"!S97)V
M97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@;V9F96YS:79E(&9O
M<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL;W=E9"X`3VYL>2!T
M:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@;6%Y(&-H86YG92!O
M=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R(&$@<VAA<F4`3W!E
M;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@0V]U;&0@;F]T(&5X
M=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R="X`3W!E;G,@=&AI
M<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@4WES=&5M`$]P=&EO
M;F%L(%!A<G1I8VEP86YT`$]P=&EO;G,`3W!T:6]N<R!F;W(`3W!T:6]N<R!F
M;W(@)7,`3W)D97)E9"!,:7-T`$]R9V%N:7-A=&EO;@!/<F=A;FES871I;VYA
M;"!5;FET`$]R9V%N:7II;F<`3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4`3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O
M<FUA=&EO;@!/=VYE<B!097)M:7-S:6]N<P!004T@875T:&5N=&EC871I;VX@
M:7,@;F]T(&%V86EL86)L92X`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%
M;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y
M<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!07TA0(%-H96QL`%!A9&1I
M;F<`4&%S<W=O<F0`4&%S<W=O<F0@8VAA;F=E9"!F;W(@=7-E<B`E<R!F<F]M
M(&-L:65N="`E<P!087-S=V]R9"!I;F-O<G)E8W0`4&%S<W=O<F0@<F5Q=6ER
M960@9F]R(%)!1$E54R!A=71H96YT:6-A=&EO;BX`4&%S<W=O<F0@=VET:"!C
M;VYF:7)M871I;VX`4&%S<W=O<F0Z`%!A<W-W;W)D.B``4&%S<W=O<F1S(&UU
M<W0@;6%T8V@N`%!A<W0@179E;G1S($QI<W0`4&%S=&4`4&%S=&4@9G)O;2!C
M;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES
M<VEO;B`G)7,G(&YO="!D96QE=&5D+@!097)M:7-S:6]N<R!!9&UI;FES=')A
M=&EO;@!097)M:7-S:6]N<R!F;W(`4&5R<V]N86P@26YF;W)M871I;VX`4&5T
M<P!0:&]N90!0:&]T;W,`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K
M(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@
M=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y
M;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@
M82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T
M:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R
M97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M
M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI
M9"!T:6UE+@!0;&5A<V4@<')O=FED92!A(&YE=R!P87-S=V]R9`!0;&5A<V4@
M<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V
M:61E('EO=7(@<&%S<W=O<F0`4&QE87-E('!R;W9I9&4@>6]U<B!U<V5R;F%M
M90!0;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0
M;&5A<V4@<')O=FED92!Y;W5R('5S97)N86UE('=I=&@@0&1O;6%I;@!0;&5A
M<V4@<F5A9"!T:&4@9F]L;&]W:6YG('1E>'0N("!9;W4@35535"!A9W)E92!W
M:71H('1H92!T97)M<R!T;R!U<V4@=&AE('-Y<W1E;2X`4&QE87-E(')E=FEE
M=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N+"!A;F0@=&AE;B!S96QE8W0@
M86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!S96QE8W0@
M86X@86-T:6]N(&9R;VT@=&AE(&UE;G4@8F5L;W<N`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&QE87-E('9E<FEF>2!Y;W5R(&YE=R!P
M87-S=V]R9`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N:6YG
M(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N9F]R
M8V5D(&)Y($E-05`I`%!R96-E9&4@>6]U<B!S:6=N871U<F4@=VET:"!D87-H
M97,@*"<M+2`G*3\`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!0<F5F<U]S97-S:6]N.B!297%U:7)E9"!S97-S:6]N(&5X=&5N<VEO
M;B!N;W0@9F]U;F0N`%!R97-E;G1A=&EO;G,`4')E<W-U<F4`4')E<W-U<F4@
M870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE
M(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!086=E`%!R979I;W5S
M(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`4')I=F%T92!+97D`4')O8FQE;0!0
M<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE8W1S`%!R;VUP="!T97AT`%!U8FQI
M8R!+97D`4'5B;&EC($ME>2!!;&=O<FET:&T`4'5B;&EC+U!R:79A=&4@:V5Y
M<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2X`475E<GD`4E-!(%!U
M8FQI8R!+97D@*"5D(&)I="D`4F%D:6\@<V5L96-T:6]N`%)A;F1O;2!&;W)T
M=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S
M/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M
M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N
M;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S
M:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z
M`%)E9G)E<V@@4W5M;6%R>2!6:65W.@!296=E>`!296QA=&EO;G-H:7`@0G)O
M=W-E<@!296UA<FMS`%)E;65M8F5R('1H92!F<F5E+V)U<WD@:6YF;W)M871I
M;VXN`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA
M;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C
M;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E(&9R;VT@;7D@8V%L96YD
M87(`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E
M<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H
M:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@
M=7-E<CH@)7,`4F5P;'D@4V5N="X`4F5P;'D@=VET:"!.;W0@4W5P<&]R=&5D
M($UE<W-A9V4`4F5P;'D@=VET:"!F<F5E+V)U<WD@9F]R(&YE>'0@,B!M;VYT
M:',N`%)E<&QY('=I=&@@<F5Q=65S=&5D(&9R964O8G5S>2!I;F9O<FUA=&EO
M;BX`4F5P;'DZ("5S`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E
M='5R;F5D(&5R<F]R8V]D93H@`%)E<75I<F5D("<E<R<@;F]T('-P96-I9FEE
M9"!I;B`E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G)7,G(&YO="!S<&5C
M:69I960@:6X@5D93(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("<E<R<@;F]T
M('-P96-I9FEE9"!I;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G8F%S961N
M)R!N;W0@<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=B87-E9&XG(&YO="!S<&5C:69I960@:6X@<')E9F5R
M96YC97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)V1A=&%B87-E)R!N;W0@
M<W!E8VEF:65D(&EN(&%U=&AE;G1I8V%T:6]N(&-O;F9I9W5R871I;VXN`%)E
M<75I<F5D("=D871A8F%S92<@;F]T('-P96-I9FEE9"!I;B!C871E9V]R:65S
M(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=D871A8F%S92<@;F]T('-P96-I
M9FEE9"!I;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G
M:&]S='-P96,G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N
M9FEG=7)A=&EO;BX`4F5Q=6ER960@)VAO<W1S<&5C)R!N;W0@<W!E8VEF:65D
M(&EN(&-A=&5G;W)I97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)VAO<W1S
M<&5C)R!N;W0@<W!E8VEF:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I
M;VXN`%)E<75I<F5D("=P87-S=V]R9"<@;F]T('-P96-I9FEE9"!I;B!A=71H
M96YT:6-A=&EO;B!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G<&%S<W=O<F0G
M(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF:6=U<F%T:6]N+@!2
M97%U:7)E9"`G<&%S<W=O<F0G(&YO="!S<&5C:69I960@:6X@<')E9F5R96YC
M97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W!H<'1Y<&4G(&YO="!S<&5C
M:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER
M960@)W!H<'1Y<&4G(&YO="!S<&5C:69I960@:6X@8V%T96=O<FEE<R!C;VYF
M:6=U<F%T:6]N+@!297%U:7)E9"`G<&AP='EP92<@;F]T('-P96-I9FEE9"!I
M;B!P<F5F97)E;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=&%B;&4G
M(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I
M97,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W1A8FQE)R!N;W0@<W!E8VEF
M:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D("=U
M:60G(&YO="!S<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A
M=&EO;BX`4F5Q=6ER960@)W5I9"<@;F]T('-P96-I9FEE9"!I;B!P<F5F97)E
M;F-E<R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`G=7-E<FYA;64G(&YO="!S
M<&5C:69I960@:6X@875T:&5N=&EC871I;VX@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF:65D(&EN(&-A=&5G;W)I97,@
M8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@)W5S97)N86UE)R!N;W0@<W!E8VEF
M:65D(&EN('!R969E<F5N8V5S(&-O;F9I9W5R871I;VXN`%)E<75I<F5D($9I
M96QD`%)E<75I<F5D(%!A<G1I8VEP86YT`%)E<V5T`%)E<V5T(%!A<W-W;W)D
M`%)E<V5T(%EO=7(@4&%S<W=O<F0`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N
M<P!2971U<FX@=&\@;6%I;`!2975N:6]N`%)E=F5R="!#;VYF:6=U<F%T:6]N
M`%)H;V1E<R!!:7)P;W)T`%)I8V@@5&5X="!%9&ET;W(@3W!T:6]N<P!2:61D
M;&5S`%)I9VAT`%)I9VAT(&AE861E<@!2:6=H="!V86QU97,`4F]?=R!0<F]P
M97)T:65S+BXN`%)O;&4`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@
M4FEG:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L
M97,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L
M=6UN<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2
M=6QE<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4R]-24U%
M($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S
M<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--
M4R!-97-S86=I;F<`4U%,(%-H96QL`%-50T-%4U,`4U]13"!3:&5L;`!380!3
M86UE(&9R86UE("A?<V5L9BD`4V%M;W,@06ER<&]R=`!3871E;&QI=&4@4')O
M=FED97(`4V%V90!3879E("5S`%-A=F4@)R5S)P!3879E($]P=&EO;G,`4V%V
M92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@
M>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C
M;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@
M)R5S)RX`4V-I96YC90!396%R8V@`4V5A<F-H($5N9VEN97,`4V5A<F-H($UA
M:6P`4V5A<F-H(%)E<W5L=',`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`
M4V5L96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE
M8W0@82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D
M871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C
M:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@
M8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT87)E
M82X`4V5L96-T('1H92!D871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E
M(&9O<FUA=#H`4V5L96-T('1H92!I9&5N=&ET>2!Y;W4@=V%N="!T;R!C:&%N
M9V4Z`%-E;&5C="!T:&4@=&EM92!D96QI;6ET97(Z`%-E;&5C="!T:&4@=&EM
M92!F;W)M870Z`%-E;&5C="!T=V\@;6%T8VAI;F<@9FEE;&1S+@!396QE8W0@
M>6]U<B!C;VQO<B!S8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG
M=6%G93H`4V5N9"!,871E<W0@26YF;W)M871I;VX`4V5N9"!0<F]B;&5M(%)E
M<&]R=`!396YD(%--4P!396YS;W(Z(`!397!T96UB97(`4V5R:6%L($YU;6)E
M<@!397-S:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO
M=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G
M970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O
M(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P86=E(')E9G)E
M<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO;G,N`%-E="!Y;W5R('!R
M969E<G)E9"!D:7-P;&%Y(&QA;F=U86=E+@!3970@>6]U<B!P<F5F97)R960@
M;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R
M('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R
M97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U
M<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS
M('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-H;W!P:6YG`%-H;W)T
M(%-U;6UA<GD`4VAO<G0@4W5M;6%R>3H`4VAO=6QD(&%C8V5S<R!K97ES(&)E
M(&1E9FEN960@9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E
M<R!B971W965N(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R
M871E9"!C;VYF:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N
M(&QO9V=I;F<@:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO
M=R!P:6-K97(`4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W
M('1H92`E<R!-96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL
M(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@
M9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3
M:&]W('1H92!I;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3
M:')I;FL`4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U
M="!O9B!T:&4@=V%Y(&9I<G-T`%-I9VX@=7``4VEG;B!U<"!I9B!N;W0@<F5G
M:7-T97)E9`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:7IE`%-K
M:7`@36%I;G1E;F%N8V4`4V]M92!O9B!(;W)D92=S(&-O;F9I9W5R871I;VX@
M9FEL97,@87)E(&UI<W-I;F<Z`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=61A
M($%I<G!O<G0`4V]U<F-E(&%D9')E<W,`4V]U=&AE<FX@2&5M:7-P:&5R90!3
M<&%C92!B971W965N(&%D:F%C96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N
M=&5N="!A;F0@8F]R9&5R(&EN(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN
M9R!A;F0@<&%D9&EN9P!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P
M;&ET(&-E;&P`4W!L:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W1A<G0`
M4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F
M;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES
M=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3
M=0!3=6)D:7)E8W1O<GD@)R5S)R!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B:F5C
M="!0=6)L:6,@2V5Y($EN9F\`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`G)7,G('1O('1H92!S>7-T96TN(%EO=2!C86X@;F]T(&QO9R!I;B!U
M;G1I;"!Y;W5R(')E<75E<W0@:&%S(&)E96X@87!P<F]V960N`%-U8G-C<FEP
M=`!3=6-C97-S`%-U8V-E<W-F=6QL>2!A9&1E9"`G)7,G('1O('1H92!S>7-T
M96TN`%-U8V-E<W-F=6QL>2!C;&5A<F5D(&1A=&$@9F]R('5S97(@)R5S)R!F
M<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!D96QE=&5D("<E<R<N`%-U
M8V-E<W-F=6QL>2!R96UO=F5D("<E<R<@9G)O;2!T:&4@<WES=&5M+@!3=6-C
M97-S9G5L;'D@<F5V97)T960@8V]N9FEG=7)A=&EO;BX@4F5L;V%D('1O('-E
M92!C:&%N9V5S+@!3=6-C97-S9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R
M871I;VXN`%-U8V-E<W-F=6QL>2!S879E9"!T:&4@8F%C:W5P(&-O;F9I9W5R
M871I;VX@9FEL92`E<RX`4W5C8V5S<V9U;&QY('5P9&%T960@)R5S)P!3=6-C
M97-S9G5L;'D@=W)O=&4@)7,`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U
M;G)I<V4`4W5N<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z
M(`!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FYA;64`4WEN8R!L;V<@9&5L971E
M9`!3>6YC34P`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M<P!486)L90!4
M86)L92!0<F]P97)T:65S`%1A8FQE('!R;W!E<G1I97,`5&%N86=R82!!:7)P
M;W)T`%1A<F=E=#H`5&%S:W,`5&%T;VD@06ER<&]R=`!496QE<&AO;F4@3G5M
M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T
M=7)E.B``5&5M<&QA=&4@)R5S)R!N;W0@9F]U;F0N`%1E;7!L871E($%D;6EN
M:7-T<F%T:6]N`%1E;G1A=&EV96QY($%C8V5P="!R97%U97-T`%1E;G1A=&EV
M96QY($%C8V5P=&5D`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O
M<`!4:`!4:&%N:R!Y;W4@9F]R('5S:6YG('1H92!S>7-T96TN`%1H92!&5%`@
M97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I
M;G1E9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-
M86EN=&5N86YC93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`
M5&AE($]P=&EO;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A
M9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!0
M97)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S
M:6]N<RX`5&AE(&)O='1O;2!S:61E(&]N;'D`5&AE(&-A;&5N9&%R(&1A=&$@
M:7,@:6YV86QI9`!4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S9G5L;'D@861D960@=&\@
M>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE9"!01U`@<VEG;F%T=7)E
M(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE<W-A
M9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W87,@96ET:&5R(&YO="!S
M<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O=6YD(&EN('1H92!D871A
M8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A<R!N;W0@<W!E8VEF:65D
M+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U:7)E(&$@<V5C=7)E('=E
M8B!C;VYN96-T:6]N+@!4:&4@979E;G0@:&%S(&)E96X@861D960@=&\@>6]U
M<B!C86QE;F1A<BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S
M971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E
M='1I;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L
M9BX`5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@
M87)E('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A
M9V4N`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R
M;V)L96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R
M(&)U9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO
M=2!M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E
M9&ET;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S
M+B`@268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK
M96QY('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U
M;'0G(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N
M960N("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y
M('1H92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA
M<R!B965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L
M;V-A=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@
M=&AE($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;6%I;&)O>"!T<F%S:"!I<R!A
M;')E861Y(&5M<'1Y+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O("5S('=I
M=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI<R!I<R!N
M;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R96%D(&]R
M('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI;F<@=&\@
M=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER
M960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E
M9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D
M871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE`%1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&UE<W-A9V4@='EP92`H)7,I('=A
M<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')E9VES=')Y(&ES(&AO
M=R!(;W)D92!A<'!L:6-A=&EO;G,@9FEN9"!O=70@:&]W('1O('1A;&L@=&\@
M96%C:"!O=&AE<BX@66]U('-H;W5L9"!L:7-T(&%N>2!I;G-T86QL960@2&]R
M9&4@87!P;&EC871I;VYS('1H870@>6]U(&AA=F4@:&5R92X`5&AE(')I9VAT
M(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY
M`%1H92!S97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R
M("(E<R(@:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@
M)7,@:&%S(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N
M;W0@97AI<W0N`%1H92!T87-K(&AA<R!B965N(&%D9&5D('1O('EO=7(@=&%S
M:VQI<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T
M+@!4:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@
M;VYL>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E
M=FEO=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A
M=F5D+@!4:&4@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;B!W87,@<W5C
M97-S9G5L;'D@<W1O<F5D+@!4:&5M97,@9&ER96-T;W)Y("<E<R<@;F]T(&9O
M=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N<R!A=F%I;&%B;&4N`%1H97)E(&%R
M92!N;R!P87)T<R!T:&%T(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+@!4:&5R
M92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@
M:&%V92!E;G1E<F5D("5S(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE
M<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@)R5S)R!T
M;R!T:&4@<WES=&5M+B`E<RX`5&AE<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@
M)R5S)R!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W87,@82!P<F]B;&5M(&-L
M96%R:6YG(&1A=&$@9F]R('5S97(@)R5S)R!F<F]M('1H92!S>7-T96TZ(`!4
M:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("<E<R<@9G)O;2!T:&4@<WES
M=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A=&EN9R`G)7,G.B`E<P!4
M:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E
M<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@
M9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM
M=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L
M96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T
M:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG
M('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I
M;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R
M=&EN9R!T:&4@979E;G0Z("5S+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T
M:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@=&%S:SH@)7,N`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=7-E<B=S(&9R964O8G5S>2!I;F9O<FUA=&EO;CH@)7,N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H97-S86QO;FEK:2!!:7)P;W)T`%1H:7,@24U!4"!S97)V97(@9&]E
M<R!N;W0@<W5P<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@86-T:6]N(&ES
M(&YO="!S=7!P;W)T960N`%1H:7,@86-T:6]N(&ES(&YO="!Y970@:6UP;&5M
M96YT960N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@<F%R
M(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED(&-A
M<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S
M86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA=&5L
M;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E
M<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R
M96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T
M:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T
M97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A
M;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W
M=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L
M9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD
M(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU
M<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E
M9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@
M9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE
M>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F:6QE(&-O
M;G1R;VQS('1H92!G;&]B86P@<V5T(&]F($U)344@9')I=F5R<R!F;W(@=&AE
M($AO<F1E(&9R86UE=V]R:RP@86QL;W=I;F<@87!P;&EC871I;VYS('1O(&UA
M:V4@=7-E(&]F('!R;V=R86US('-U8V@@87,@96YS8W)I<'0@;W(@;7-W;W)D
M=FEE=R!T;R!R96YD97(@8V]N=&5N="!I;G1O($A434P@9F]R('9I97=I;F<@
M:6X@82!B<F]W<V5R+@!4:&ES(&9I;&4@8V]N=')O;',@=&AE('-T>6QE<VAE
M970@=&AA="!I<R!U<V5D('1O('-E="!C;VQO<G,@86YD(&9O;G1S(&9O<B!T
M:&4@2&]R9&4@9G)A;65W;W)K(&%N9"!A;&P@87!P;&EC871I;VYS('1H870@
M9&\@;F]T('!R;W9I9&4@=&AE:7(@;W=N('-E='1I;F=S+@!4:&ES(&9I;&4@
M;6%P<R!F:6QE(&5X=&5N<VEO;G,@=&\@;&]G:6-A;"!-24U%('1Y<&5S+"!E
M;F%B;&EN9R!(;W)D92!A<'!L:6-A=&EO;G,@=&\@9FEG=7)E(&]U="!H;W<@
M=&\@:&%N9&QE('-O;64@8V]N=&5N="!S=6-H(&%S(&5M86EL(&%T=&%C:&UE
M;G1S(&]R($-64R!C:&5C:V]U=',N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B
M965N('!R;V-E<W-E9"X`5&AI<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R
M;W5P=V%R92!O8FIE8W0N(%1O('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@
M;F5E9"!A;B!E;6%I;"!C;&EE;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L
M86(@1W)O=7!W87)E(&9O<FUA="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL
M(&-L:65N=',@<&QE87-E('9I<VET("5S`%1H:7,@:7,@=&AE(&UA:6X@2&]R
M9&4@8V]N9FEG=7)A=&EO;B!F:6QE+B!)="!C;VYT86EN<R!P871H<R!A;F0@
M8F%S:6,@:71E;7,@=&AA="!A<'!L>2!T;R!T:&4@8V]R92!F<F%M97=O<FL@
M86YD(&%L;"!(;W)D92!A<'!L:6-A=&EO;G,N`%1H:7,@;65S<V%G92!W87,@
M=W)I='1E;B!I;B!A(&-H87)A8W1E<B!S970@*"5S*2!O=&AE<B!T:&%N('EO
M=7(@;W=N+@!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI
M<R!P<F]B;&5M(')E<&]R="!W87,@<F5C96EV960@9G)O;2`E<RX@5&AE('5S
M97(@8VQI8VME9"!T:&4@<')O8FQE;2!R97!O<G0@;&EN:R!F<F]M('1H92!F
M;VQL;W=I;F<@;&]C871I;VXZ)7,@86YD(&ES('5S:6YG('1H92!F;VQL;W=I
M;F<@8G)O=W-E<CHE<P!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II
M<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E
M86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N`%1I8VME
M=',`5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T
M:6]N`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L96-T(&UU;'1I
M<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM
M86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`5&]G9VQE($A4
M34P@4V]U<F-E`%1O;6]R<F]W`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS
M;&%T:6]N<P!4<FEP;VQI<R!!:7)P;W)T`%1R=64@;W(@9F%L<V4`5'4`5'EP
M92!M:7-M871C:"X`5'EP92!Y;W5R(&-H;VEC93H@`%523`!54DP@9F]R('EO
M=7(@<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!A9&0@97AT<F$@
M=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N`%5N86)L92!T;R!C
M:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O
M(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E<R\E<RX`56YA8FQE
M('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(&5M<'1Y(%9&
M4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5;F%B;&4@=&\@
M9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y+@!5;F%B
M;&4@=&\@9&5L971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5
M;F%B;&4@=&\@9&5L971E("<E<R<Z("5S+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y.B`E
M<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@
M9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&4R!R96-U<G-I
M=F5L>3H@)7,N`%5N86)L92!T;R!D971E<FUI;F4@8W5R<F5N="!D:7)E8W1O
M<GDN`%5N86)L92!T;R!E>'1R86-T(&-E<G1I9FEC871E(&1E=&%I;',`56YA
M8FQE('1O(&QO860@=&AE(&1E9FEN:71I;VX@;V8@)7,N`%5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RX`56YA8FQE('1O
M(&]P96X@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(&-O;7!R97-S960@87)C
M:&EV92X`56YA8FQE('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5
M;F%B;&4@=&\@<F5G:7-T97(@<')E9F5R96YC97,@:6X@<V5S<VEO;BX`56YA
M8FQE('1O(')E;F%M92`E<R!T;R`E<SH@9&5S=&EN871I;VX@9F]L9&5R(&%L
M<F5A9'D@97AI<W1S`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>2X`
M56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y.B`E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+@!5;F%B;&4@
M=&\@<G5N("=M:VES;V9S)RX`56YA8FQE('1O('1R86YS;&%T92!T:&ES(%=O
M<F0@9&]C=6UE;G0`56YA8FQE('1O('=R:71E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!W<FET92!61E,@9FEL92`H8V]P>2@I(&9A:6QE9"DN`%5N86)L
M92!T;R!W<FET92!61E,@9FEL92!D871A+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@96YD(&]F
M(&9I;&4N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@;VX@8V]N
M;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z
M(`!5;F9I;&5D`%5N:&%N9&QE9"!C;VUP;VYE;G0@;V8@='EP93H@)7,`56YI
M=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN
M`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W
M;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H92!C=7)R96YT(&5L
M96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T<R!C86YN;W0@86-C
M97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I
M='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E8VAN:6-A;"!N;W1E
M(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H;W<@=&\@86QL;W<@
M82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R
M`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D871E("5S`%5P9&%T
M92!R97-P;VYD96YT('-T871U<P!5<&1A=&4@=7-E<@!5<&1A=&5D("<E<R<N
M`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@
M87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@
M;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N=6UB97)S`%5S92!#=7)R96YT
M.B`E<P!5<V4@1&5F875L="!686QU90!5<V4@4U-,`%5S92!I9B!N86UE+W!A
M<W-W;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@
M:7,@;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($%D;6EN:7-T<F%T:6]N
M`%5S97(@3W!T:6]N<P!5<V5R(%)E9VES=')A=&EO;@!5<V5R(%)E9VES=')A
M=&EO;B!H87,@8F5E;B!D:7-A8FQE9"!F;W(@=&AI<R!S:71E+@!5<V5R('!A
M<W-W;W)D(&-H86YG90!5<V5R('!E<FUI<W-I;VYS`%5S97)N86UE`%5S97)N
M86UE("<E<R<@86QR96%D>2!E>&ES=',N`%5S97)N86UE.@!5<V5R;F%M93H@
M`%5S97)S`%5S97)S(&EN('1H92!S>7-T96TZ`%9&4R!D:7)E8W1O<GD@9&]E
M<R!N;W0@97AI<W0N`%9A8V%T:6]N`%9A;&ED(&QO8V%T:6]N<R!F;W5N9"!I
M;F-L=61E.B``5F%L:61I='D`5F%L=64@:6X@;6EN=71E<R!F<F]M(&YO=RX`
M5F%L=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!687)I86)L90!697)I9FEC
M871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA>2!H879E(&)E96X@=&%M
M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O;G1R;VP`5F5R=&EC86P@
M86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A;#H`5F5R>2!(:6=H`%9I
M97<@)7,`5FEE=R!A;B!E>'1E<FYA;"!W96(@<&%G90!6:65W(&%S("5S`%9I
M97<@979E;G0`5FEE=R!T87-K`%9I<VEB:6QI='D`5FES:6)I;&ET>3H@`%9O
M9&%F;VYE($ET86QY('9I82!33510`%=!4DX`5T%23DE.1R$A(2!214U/5D4@
M4T-225!4($U!3E5!3$Q9($923TT@)7,N`%=A<FYI;F<`5V4`5V5E:VQY`%=E
M;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!7:&%T(&%P<&QI8V%T
M:6]N('-H;W5L9"`E<R!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T(&%P<&QI
M8V%T:6]N('-H;W5L9"!(;W)D92!D:7-P;&%Y(&%F=&5R(&QO9VEN/P!7:&%T
M(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R/P!7:&%T(&ES('1H92!Q=6]T
M92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7:&EC:"!P;'5G:6YS('1O(&5N
M86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET;W(N`%=I9'1H`%=I9'1H(&EN
M($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@;65N=2!O;B!T:&4@;&5F="`H
M=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN*3H`5VED=&@@;V8@=&AE('1A
M8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I;F0@<W!E960@:6X@:VYO=',`5VEN
M9#H`5VEN9#H@`%=I<V1O;0!7:7-H;&ES=',`5V]R:P!7;W)K($%D9')E<W,`
M5V]R:R!0:&]N90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P
M.78S($5X=&5N9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA
M=&EV92!.86UE`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV
M,R!E>'1E;G-I;VYS`%E9`%E965D`665A<FQY`%EE<P!997,L($D@06=R964`
M66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O
M('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%U=&AE;G1I
M8V%T960N`%EO=2!C86X@;F]T(&AA=F4@=&AE("=<)R!C:&%R86-T97(@:6X@
M>6]U<B!F=6QL(&YA;64N`%EO=2!D:60@;F]T(&5N=&5R(&$@=F%L:60@96UA
M:6P@861D<F5S<RX`66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F<F]M('1H
M92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I96QD<R!I
M;B`E<RX`66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W4@:&%V92!B965N
M(&QO9V=E9"!O=70N/&)R("\^5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES
M=&5M+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@;75S
M="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N=7!S
M+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU<W0@
M9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T:&4@
M<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE<F4@
M=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R=F5R
M('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T;R!R
M96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D9"X`
M66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9;W4@
M;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M=7-T
M('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S:6]N(&AA
M<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA:6P@061D
M<F5S<P!9;W5R($5M86EL($%D9')E<W,Z`%EO=7(@1G)O;3H@861D<F5S<SH`
M66]U<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H
M86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN
M(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A
M:6XN`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E
M<R!N;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,L(&]R('1H92!F96%T=7)E(&AA
M<R!B965N(&1I<V%B;&5D(&9O<B!S;VUE(&]T:&5R(')E87-O;BX`66]U<B!A
M=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@;&ES=&EN
M9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L960@9F]R
M('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R<R!T;R!H
M879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E
M<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G
M:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T('1H:7,@
M9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!P
M<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO3W!T:6]N("L@4"!T;R!P<FEN
M="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y.@!9;W5R(&9U;&P@;F%M93H`66]U<B!N97<@<&%S<W=O<F0@9F]R("5S
M(&ES.B`E<P!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960@9F]R('1H
M92!D=7)A=&EO;B!O9B!T:&ES('-E<W-I;VXN`%EO=7(@;W!T:6]N<R!H879E
M(&)E96X@=7!D871E9"X`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E=`!9
M;W5R('!A<W-W;W)D(&AA<R!B965N(')E<V5T+"!C:&5C:R!Y;W5R(&5M86EL
M(&%N9"!L;V<@:6X@=VET:"!Y;W5R(&YE=R!P87-S=V]R9"X`66]U<B!P87-S
M=V]R9',@9&\@;F]T(&UA=&-H`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%M(:61E
M(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@
M;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?1&5L971E(%)O=P!?1W)O=7!S`%](
M96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO
M9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI
M;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R
M97-S(&)O;VL`8V%L96YD87(`8V%L;0!C;&EC:R!H97)E`&9I;&4`9G)O;2!T
M:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI;F5S
M70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&EX96QS`'-H;W<@9&EF9F5R96YC97,`<VUS,F5M86EL('9I
M82!(5%10`'-T96%D>0!T87-K(&QI<W0`=')A<V@`='EP92!T:&4@<&%S<W=O
M<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E<B!S96QE
M8W0`=D-A<F0`4')O:F5C="U)9"U697)S:6]N.B!(;W)D93H@,RXP+6-V<PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P,BTQ,2TP-R`Q,CHP-BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#0M,C8@,3$Z,3,K,#(P,`I,87-T+51R86YS;&%T
M;W(Z($MO;G-T86YT:6YO<R!#+B!-:6QO<VES(#QK;6EL;W-I<T!Y86AO;RYC
M;VT^"DQA;F=U86=E+51E86TZ($=R965K(#QD979`;&ES=',N:&]R9&4N;W)G
M/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z('1E>'0O<&QA:6X[
M(&-H87)S970]:7-O+3@X-3DM-PI#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B`X+6)I=`H`("#'(./QX>SLX?3OZ/7QW^3A("?JW.3O\B<@Y=_MX>D@WN3G
M(-SDY>GA+@`@)B,Q-3$[("5S(,7?[>'I(.<@\_3IX^S>(.WA(./?[>_U[2#O
MZ2#KY>GT[_7QX]_E\B#S]>WTWO'G\^?R(/#O]2#EW^WAZ2#E\.GKY>/LW>WE
M\B#PX?'AZMST^2X`("CP\>GM(.'P_"`E<R#G[-WQY?(I`"`HRNOEZ>3?(/#Q
M_//BX?/G\B`E<RD`("CSY2`E<R#G[-WQY?(I`"`H\][LY?'A*0`@*.']\>GO
M*0`@*/?HY?(I`"#S].GR(``E9"`E<R#JX>D@)7,`)60M[.7QYR#P\?SBZ^7X
MYP`E<R`M(-/G[.7?^?/G`"5S+<3IX??EW_'I\^<`)7,@Q.'J]/7KZ>K\(.'P
M[_3]\/GLX0`E<R#+Y>GT[_7QX]_E\B#3]>WTWO'G\^?R("T@Q?#IXN7BX=_Y
M\^<`)7,MT.'QX>SE]/'O\._?Y_/G`"5S(,7CX_'A]MX`)7,@S_'OZ2#W\=[S
MY_(`)7,@WN3G(/7PW/'WY>DN`"5S(//E("5S("5S`"5S(.'J]?'^Z.?JY2`E
M<RX`)7,@X?#<[?3G\^4@\^4@Y?'^].?LX2#DZ>'HY?/I[/STY_3A\BX`)7,@
MX?#<[?3G\^4@\_3G[2#P\?SSZNOG\^<@X^GA("5S+@`E<R#SX?(@W?/TY>GK
MY2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\BX`)7,@Y=_MX>D@X?#AZ?3O
M_>SE[>\`)7,@Z^7P]-P`)7,@\^'R(.;>].?SY2#PZ^?Q[_;O\=_E\B#DZ>'H
MY?/I[/STY_3A\BX`)7,@YM[TY_/E(/3G[2#PX?'O]?/?X2#SX?(@\_3I\B`E
M<RX`)7,@^?(@)7,@X?#\("5S`"5S(.7PZ>CU[.7?(/3G[2#P\>_SZ-[JYR#S
M].\@)7,N`"5S(.7PZ>CU[.7?(.WA(//A\B#E[>?LY?'^\^7I(./IX2`E<RX`
M)7,@Y?#IZ/7LY=\@[>$@Z]SBY>D@].GR(/3EZ^7U].'?Y?(@\.OG\>_V[_'?
MY?(@X^GA("5S+@`E<R=S(,3IY?7H]>WSZ>_C\=SV[_(`)7,G<R#'[.7Q[^O\
MX^GO`"5S<R#3Y^SEZ?GLX?3<\>GO`"5S<R#+W_/TX2#%\>/A\^G^[0`G)7,G
M(.3E[2#EW^WAZ2#=X^KU\><@Y?#IZ^_CWBX`)R5S)R#DY>T@W??EZ2#Q]>CL
MZ?/TY=\@\_3O(')E9VES=')Y(/3G\B#E]N'Q[._CWO(@2&]R9&4`)7,@X>WA
M\.'QX?/TW/3G\B#DY>WD\>GJWO(@Y._LWO(@Y.7M(.+QW>CGZN4N`"<E<R<@
M\/'O\_3=Z.?JY2#S].GR(._LW.3E\B#S]?/TWNSA]._R+@`G)7,G(/#Q[_/T
MW>CGZN4@\_3I\B#<Y.7IY?(@]._U(//U\_3>[.'T[_(N`"<E<R<@Y.7M(.3G
M[.GO]?'CWNCGZN4Z("5S+@`L(&=U<W1I;F<@)7,@)7,`+"#LY?3AXNOG]-X@
MX?#\("5S(//E("5S`"TM(.7PZ>OOX]X@+2T`,3+Y\><@[._Q]MX`,C3Y\><@
M[._Q]MX`,C0@_O'E\@`\8C[0X?'O]?/IW//TY^KE(-WMX2#S[^+A\?P@Z]SH
M[_(Z/"]B/@#0X?'O]?/IW//HY^KE(.KQW_/I[.\@Z]SH[_(`P?#AZ?3EW_3A
MZ2#DY^S\\^GO(.KKY>GDWR!01U`@X^GA(/3G[2#J\?7P]._C\=SVY_/G(.7M
M_/(@[.?M_>SA]._R+@#!\.'I].7?].'I(.3G[/SSZ>\@ZNOEZ>3?(%!'4"#C
MZ>$@Y?#IXN7BX=_Y\^<@Y>W\\B#U\._CY>/QX>SLW>WO]2#LY^W][.'T[_(N
M`,'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%!'4"#JZ^7IY-\@ZN'I
M(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@X?#OZO'U\/3OX_'A]M[SY?3E(-WMX2#L
MWNWU[.$N`,'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%!'4"#JZ^7I
MY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@]?#OX_'<^.7TY2#XY_;IX>K<
M(-WMX2#LWNWU[.$N`,'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O\_GPZ>K\(%,O
M34E-12#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@X?#OZO'U\/3O
MX_'A]M[SY?3E(-WMX2#LWNWU[.$N`,'PX>GTY=_TX>D@Y.?L_//I[RP@\/'O
M\_GPZ>K\(%,O34E-12#JZ^7IY-\@ZN'I(.O=[N<MZOGDZ>K\\B#CZ>$@[>$@
M]?#OX_'<^.7TY2#XY_;IX>K<(-WMX2#LWNWU[.$N`,'PX>GTY=_TX>D@Y.?L
M_//I[R#JZ^7IY-\@4R]-24U%(./IX2#TY^T@ZO'U\/3OX_'<]N?SYR#E[?SR
M(.SG[?WLX?3O\BX`\.PO[.P`T.7QWR#A]?3O_2#T[_4@RN7I[.7M[^/QW/;O
M]0#0Y?'?+BXN`,'P_.OU].\@]-WK[_(`P?#\Z_7TYR#,W?/G`,'P[^3O]]X@
MX>GTWNSA]._R`,7CZ>WE(.'P[^3EZO3\`,<@\/'\\^+A\^<@X?#O\?'?]NCG
MZN4@ZN'TW"#TYR#DY^SI[_7QX]_A(%9&4R#JX?3AZ_SC[_4N`,<@\/'\\^+A
M\^<@X?#O\?'?]NCGZN4@ZN'TW"#TYR#DY^SI[_7QX]_A(%9&4R#A\??EW^_U
M+@#*^>3IZOSR(,OOX^'QZ>'S[._]`,\@Z^_CX?'IX?/L_/(@\-SC^?/E+@#*
MX?3AX_'A]MX`Q>W=\>/EZ>7R`-#Q[_/HWNKG`-#Q[_/HWNKG(/7P[^_LW.3A
M\@#0\>_SZ-[JYR#<Y.7IX?(@]?#O[^S<Y.'R("AC:&EL9"!P97)M:7-S:6]N
M*0#0\>_SZ-[JYR#EY/XZ`-#Q[_/HWNKG(,W=X?(@S^S<Y.'R`-#Q[_/HWNKG
M(.W=X?(@W.3EZ>'R`-#Q[_/HWNKG(/7P[^_LW.3A\B#S].\@)R5S)P#0\>_S
MZ-[JYR#<Y.7IX?(@*'!E<FUI<W-I;VXI(/7P[^_LW.3A\B#S].\@)R5S)P#0
M\>_SZ-[JYR#MW>_U(/?QWO/TYSH`T/'O\^C>ZN<@\_3>Z^?R`-#Q[_/HWNKG
M(.W=[_4@[-WK[_7R`-#Q[_/HWNKG(.;E_>/O]?(`T/'O\^C>ZN<@]._U("5S
M(//T[R#LY>WO_2#T[_4@36]Z:6QL80#0\>_SZ-[JYR#A]?3O_2#S].\@Y^SE
M\>_K_./I_"#L[_4`T/'O\^C>ZN<@\_3O(,3IY?7H]>WSZ>_C\=SV[SH`T/'O
M\^C>ZN<@\_3O(,3IY?7H]>WSZ>_C\=SV[R#L[_4`T/'O\^C>ZN<@]_'>\_3G
M`-#Q[_/TW>CGZN4@)R5S)R#S].\@\_WS].?LX2P@X>OKW"#DY>T@[/#\\>7S
MX2#MX2#P\>_SZ-WS^2#S]>SPZ^?Q^>SA].GJW?(@\.OG\>_V[_'?Y?(`T/'O
M\_3=Z.?JY2`G)7,G(//T[R#S_?/TY^SA+B#,\._QY=_TY2#MX2#S]>WDY>CE
MW_3E(/3^\>$N`,<@\/'O\^C>ZN<@]_'G\_3^[2#=]^7I(.'PY>WE\>/O\._I
MY^CEWRX`Q.GE_>CU[?/G`,3IY?7H]>WSZ>_C\=SV[_(`Q.GA]^7?\>GSYR`M
M(,3^\_3E(.3IZN'I_NSA].$@\^4@W.OK[_7R(/?QWO/TY?(`Q.GA]^7?\>GS
MYP#!Y?'OZ^GLW>WA\B#!ZO3?[_4`P>7Q[^OI[-[M(,'KY>[A[>3Q[_WP[^OG
M\@#8Y?7D_NWU[.\`Q?7H]>/QW.SLZ?/E`,7UZ/7C\=SL[.GSYSH`S^OA`,_K
M[^D@[^D@W>/J]?'OZ2#W\=[S].7R`,_KY?(@[^D@S^S<Y.7R`,_KX2#TX2#D
MZ>KAZ?[LX?3A`,KAZ2#OZ2#TW?/SY?'I\B`H-"D@\.OE]?'=\@#-X2#E\.GT
M\=WP[^WTX>D@\._KZ^'PZ]WR(.3IY?7H_>WSY>GR`,WA(.7PZ?3QW?#O[?3A
MZ2#Q]>CLW_/EZ?(@].'NZ>WO[.GLW>WY[2#KZ?/T_NT[`,?DYR#U\-SQ]^7I
M`,7MX>OKX>KTZ>K>($E-4U`@Q=_S[^3O\@#%[>'KZ^'J].GJ_/(@24U34"#*
M^>3IZOSR`,7MX>OKX>KTZ>K\($E-4U`@O.WO[.$@U_'>\_3G`,7MX>OKX>KT
MZ>K>(.3IY?WH]>WSYR!E;6%I;`#%[>'KZ^'J].GJW"#P\?ST]?#A`,7MX>OK
MX>KTZ>K\(.KEW^SE[>\Z`,_QW_/TY^KE(.S?X2#LYR#E\.GT\>7P_.SE[><@
M].GLWBX`P>7Q[^OI[-WMX?(@P>/WW^'K[_4N`,'E\>_KZ>S=[>'R(,'MY/'A
MXM_DX?(N`,'M_NWU[._R(,3IX>SLY?/OZ^'BY_3>\B`H4')O>'DI`,'PW.WT
MY_/G`,7VX?'L[^/>`,O?\_3A(,7VX?'L[^/>\@#'(.7VX?'L[^/>(.7?[>'I
M(-WT[^GLYRX`Q?;A\>SOX]X@ZN'I(//TX2#E[N'Q]/[LY>WA(.KOZ>W\]_'G
M\_3A`,7CZO'?[?D`P?#QW^OI[_(`P>7Q[^OI[-WMX?(@P?'<[N_U`,S=X^7H
M[_(@X?'WY=_O]2#A\??EZ>_HW?3G\^?R`,_M[^SA(.'Q]^7?[_4@X?'WY>GH
MW?3G\^?R`,7?\_3E(//?X^_U\><@X^GA(/3G(.3IX>/QX?;>(/3G\B#AW_3G
M\^?R(/7P[^/QX?;>\B#CZ>$@)7,@/P#%W_/TY2#SW^/O]?'OZ2#\].D@Z-WK
MY?3E(.WA(.3IX>/QW/CE].4@)R5S)R#JX>D@_.OE\B#TZ?(@]?#O[^S<Y.7R
M/P#4W??MYP!!4T-)22#4W??MYP#-X2#FY_3EW_3E(.7PZ>+EXN'?^?/G(/#Q
MW^T@X?#\(.K<Z.4@Y>W=\>/EZ>$@Y.GA]^7?\>GSY_([`,'MW.CE\^<@\_3G
MZ_[M`,'E\>_KZ>S=[>'R(,'HY^W^[0#4[R#S]>WG[.S=[>\@Y=_MX>D@W>WA
M(.'Q]^7?[R#G[.7Q[^OOX]_O]2#SY2#A\-SM].?SYR#AZ?3>[.'T_/(@\^'R
M`-#Q[_/PW.CEZ>$@Y.GAX_'A]M[R(.SG(/7PX?'J]-[R(._LW.3A\BX`T/'O
M\_#<Z.7IX2#DZ>'C\>'VWO(@[.<@]?#A\>KT[_T@Y.GJX>G^[.'T[_(N`-#Q
M[_/PW.CEZ>$@Y?#E[N7QX^'SW^'R(.SG(/7PX?'J]._](.3IZN'I_NSA]._R
M+@#0\>_S\-SHY>GA(.7PY>[E\>/A\]_A\B#LYR#U\.'QZO3O_2#DZ>'L[^GQ
MX?/LW>WO]2X`T.'QY?7QZ?/J_.SE[>_I`,GDZ?STY_3E\@#!_>/O]?/T[_(`
MQR#A]>CE[?3IZN_P[]_G\^<@X?#=]/7WY0#'(.'UZ.7M].GJ[_#OW^?SYR#A
M\-WT]??E+B`E<P#'(.'UZ.7M].GJ[_#OW^?SYR#A\._Q\=_VZ.?JY2#A\/P@
M]._M(%)!1$E54R!S97)V97(N`,<@X?7HY>WTZ>KO\._?Y_/G(//T[^T@1E10
M+5-E<G9E<B#A\-WT]??E+@#$Z>'HW?/I[.$@T.7DW^$Z`,'MX>S=[>_M].'R
M(.'PW.WTY_/G`-7P_.+AZ/'O`-?Q_NSA(/7P_.+AZ/'O]0#+W.CO\B!+97)B
M97)O<RWJ^>3IZOSR+@#+W.CO\B!+97)B97)O<RV\[>_LX2#7\=[S].<N`,'D
MY>GO`,\@ZOWQZ>_R(.KA]-SK[^/O\B#C\>'VZ>K^[2`G)7,G(.3E[2#B\=WH
MY^KE+@#"X?/IZMX@X_'A[.S>`,/E[=WHZ^GA`-3O(/3LWNSA("(E<R(@].?R
M(.7VX?'L[^/>\B`B)7,B(.3E[2#B\=WHY^KE+@#1]>CLW_/EZ?(@].S>[.'T
M[_(`U/WP[_(@].S>[.'T[_(`N.WT[^WA`+SQZ>$`RN'I(/3A(.3][P#*X?3^
M].'T[P#+W_/TX2#LY2#TY>OEW^7R`-/G[.7?X2#DZ>'M[^S>\B!#4DP`P?'W
MY=_O(.KEZ>S=[>_U(/?Y\>GS[-WM[R#LY2#J_.SLX2`H0U93*0#)Y.G\].?T
MY?(@RN7KZ?[M+BXN`,?LY?'OZ_SCZ>\`T.7QW^OG^.<@Q^SE\>_K_./I[_4`
MQ^SE\>_K_./I[SH`Q_'E[-_A`,'D_>WA].<@YR#A\??IZN_P[]_G\^<@]._U
M(.KYY.GJ[_T@X?7T_.SA].$L(.7PZ>KOZ>WY[=[S].4@[.4@].\@Y.GA]^7I
M\>GS]-X`P>3][>'TYR#G(//][>3E\^<@[.4@]._M($E-05`M4V5R=F5R.B`E
M<P#!ZOWQ^?/G`,'J_?'Y\^<@P>WA]N_QW/(@T/'OXNO>[.'T[_(`P>3][>'T
MYR#G(.3IX>/QX?;>(/3O]2#A\??EW^_U("(E<R(N`,3E(.+QW_/J^2#P\>_S
M^?'I[?P@]MSJY>OO("AT96UP(&1I<BDN`,'D_>WA].<@YR#S]>W=]^7IX2#W
M^?'?\B#TY^T@\.'QW.SE]/'O(")T87)G971&:6QE(BX`P>3][>'TYR#G(.3I
MX>/QX?;>(/3O]2#VX>K=Z^_U("(E<R(N`,'D_>WA].<@YR#DZ>'C\>'VWBP@
M)60@]?#VW.KEZ^_R(/7PW/'WY>DN`,'D_>WA].<@YR#E\.'MX?3A[NGM_.SG
M\^<L(.\@X?'IZ.S\\B#T^>T@Y>/C\>'V_NT@\._U(.3^\^'TY2#CZ>$@Y?#A
M[>'TX>[I[?SLY_/G+"#DY>T@].'I\>G<YN7I(.SE(/3O[2#A\>GH[/P@]/GM
M(.'P[^CGZN7U[-WM^>TN`,3E(.SP[_'^(.WA(.3Q[^SOZ^_CWO/Y(.S>[?7L
MX2#S]._M(.'QZ>CL_"#P[_4@[_'?\^'TY2X`Q?#IZN7VX>O?Y.$`RN'TY^/O
M\=_E\B#JX>D@Q?3IZMWTY?(`RNGMY_3\(-3GZ]WV^>WO`,GDZ?STY_3E\B#*
MY>OI[_T`P]WLZ?/LX2#*Y>OI[_TZ`,GDZ?STY_3E\B#*Y>OI[_T`Q.G<ZN7M
M[R#*Y>OI_NTZ`,KI[>?T_"#4Y^O=]OGM[P#*W>WT\>\`R^7P]._LW?'EZ>7R
M(-#I\_3O\._IY_3IZN_]`-#OZ^GTZ>K>(-#I\_3O\._IY_3IZN_]`-#Q_.7D
M\>_R`,'KZ^'CW@#!Z^OAX]X@ZOGDZ>KO_0#!Z^O<[O3E(/3O(/SM[^SA(.KA
MZ2#TYR#DZ>7]Z/7M\^<@\._U(.CA(.+KW?#O]>T@_/3A[2#DZ>'BW.;O]>T@
MWB#A\.'M]._][2#SY2#LY^W][.'TW"#SX?(`U^'QX>KTWO'A\@"XZ^7C]^_R
M(//][>3E\^?R+BXN`-/G[.7I_O/TY2#T[R#TY?3QX>/Y[=_DZ>\@X^GA(._P
M[^GAY-[P[_3E(.7QX^'SW^$HY?(I(.C=Z^7TY2#MX2#EZO3EZ^7S]._][2#A
M]?3>(/3G(//TZ>/LWBX`P>7Q[^OI[-WMX?(@U]_O]0#%\.GKW>[TY2#%]N'Q
M[._CWCH`Q?#IZ]WN].4@ZOGDZ>K\`,7PZ>O=[O3E(/SM[^SA(/?QWO/TYP#%
M\.GKW>[TY2#LZ>$@Y>W=\>/EZ>$Z`,7PZ>O=[O3E(/#Y\B#HX2#E[/;A[=_F
M[^WTX>D@[^D@Y^SE\>_LY^W?Y?(Z`,7PZ>O=[O3E(/3]\.\@Z]_S].'R("CC
MZ>$@].'NZ>WO[.?LW>WE\B#KW_/TY?(I`,'E\>_KZ>S=[>'R(-?Q]?/O_?#O
MZ^?R`,3E[2#B\=WHY^KE(._QZ?/L_/(@ZNO<\^?R(/3O]2`E<RX`RN'HW/'I
M\^4`RN'HX?'I\^S\\B#E].GJY?3^[2`H=&%G<RD@35,M3V9F:6-E`"?!Y.7I
MX?/LX2<@U_'>\_3G.B`E<P#*X>CA\>GS[/SR(-?QWO/TYP#*X>CA\>GS[/SR
M(.3EY._LW>WY[2#W\=[S].<`RMSM].4@ZNOIZB#CZ>$@\_7MW??EZ>$`RNOE
MW_/I[.\@PN_>Z.7IX?(`RNOEW_/I[.\@T.'QW.CU\>_U(,+OWNCEZ>'R`,KK
MY=_SZ>SO(-#A\=SH]?'O]0#![>'DW_#K^?/G(-#KY?7QZ>K>\B#,\-SQX?(`
MP>WAY.GPZ_GLW>WA(-#E\>GH_O'IX0#7\?[LX0#%\.GKW>KTY_(@U_'^[.'T
M[_(`Q?#IZ^_CWB#7\?[LX?3O\@#3]-[KY?(Z`-3?].OOZ2#3].?K_NT`0V]M
M:6-S`,7M]._KW@#*W>OU]N_R(,7M]._K_NT`T_?\Z^GO`,KOZ>W\(+SM[^SA
M`,7TX>GQY=_A`,_K[^KKY_'^Z.?JY0#3_>WHY?/G(,SG[?WLX?3O\B`H)7,I
M`-7P[^OOX^GS]-WR`-/U[>C>ZN7R`,3IX?;O\=WR(-#A\>'LY?3Q[_#OW^?S
MY_(`Q?#IZ^_CW?(@X^GA(//UX_?Q[^WI\^S\(.SE(%!$07,L(-WN]?#MX2#4
MY^O=]OGMX2#JX>D@3W5T;&]O:RX`1&EE($MO;F9I9W5R871I;VX@;75S<R!A
M:W1U86QI<VEE<G0@=V5R9&5N+@#'(/#A\>'LY?3Q[_#OW^?SYR#W\>7IW.;E
M].'I(.7MY^S=\?GSYRX`T.'QX>SE]/'O\._?Y_/G("5S`,7PZ>+EXN'?^?/G
M(,KYY.GJ[_T`QR#S_>WDY?/G(.'PW?3U]^4N`,<@\_WMY.7SYR#A\-WT]??E
M.B``P?'MY_/G(//][>3E\^?R(.'P_"#T[R#DY^S\\^GO(.7N]?#G\>7TY_3>
M(.KKY>GDZ?[M+@#!\>WG\^<@\_WMY.7SY_(@X?#\(/3O(.3G[/SSZ>\@Y>[U
M\.?QY?3G]-X@ZNOEZ>3I_NTN(,O\X^_R(#H@)7,@*"5S*0#'(//][>3E\^<@
M[.4@].\@1E10+5-E<G9E<B#A\-WT]??E+@#![>'FWO3G\^<@Q?#A]M[R`,_I
M(.7PX?;=\B#P\>_S]-WHY^KA[2#E\.GT]??^\B#S].\@Q.GE]>CU[?/I[^/Q
MW/;O(//A\BX`T.7QZ>7W_.SE[>$@]._U("<E<R<`T.7QZ>7W_.SE[>$@]/GM
M(.'Q]^7?^>T@4D%2`-/U[=WWY>GA`,'M].GC\>'VW@#![?3IX_'A]MX@Q?#I
MZ^_CWO(`P>3][>'TYR#G(.KQ]?#T[^/QW/;G\^<@]._U(.SG[?WLX?3O\B#L
MY2!01U`N`,'D_>WA].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R(.SE(%!'
M4"X`P>3][>'TYR#G(.KQ]?#T[^/QW/;G\^<@]._U(.SG[?WLX?3O\B#LY2!3
M+TU)344N`,'D_>WA].<@YR#U\._C\>'VWB#T[_4@[.?M_>SA]._R(.SE(%,O
M34E-12X`Q.7M(.SP_/'E\^$@[>$@\/'O\^C=\_D@].?M(.7PX?;>+B`E<P#!
MY/WMX?3G(.<@\_WMY.7SYR#LY2#T[R!,1$%0+5-E<G9E<BX`P>3][>'T[_(@
M[R#=Z^7C[_(@]?#OZ^_?\._U+B`E<P#!Y/WMX?3G(.<@\_WMY.7SYR#S]._M
M(.7N]?#G\>7TY_3>("<E<R<@]_'G\^GL\._I_NWTX?(@1E10.B`E<P#!Y/WM
MX?3G(.<@Y.?LZ>_U\>/?X2#KW_/TX?,@Y.GA[>_LWO(N("5S`,'D_>WA].<@
MYR#A\._J\?7P]._C\=SVY_/G(%!'4"#DY>3O[-WM^>TN`,'D_>WA].<@YR#A
M\._J\?7P]._C\=SVY_/G(%,O34E-12#DY>3O[-WM^>TN`,'D_>WA].<@YR#D
MZ>'C\>'VWB#E\.'VWO(N("5S`,'D_>WA].<@YR#DZ>'C\>'VWB#KW_/TX?(@
MY.GA[>_LWO(N("5S`,'D_>WA].<@YR#DZ>'C\>'VWB!S971U<"!U<&=R861E
M('-C<FEP="`G)7,G("X`Q.4@[/#O\?X@[>$@Y.GE]>KQZ>W>\_D@].<@Y.GE
M_>CU[?/G(/3O]2#PX?'AZ][P].<N`,'D_>WA].<@YR#PZ][QY_(@\/'\\^+A
M\^<@]._U(,3IY?7H]>WSZ>_C\=SV[_4N`,'D_>WA].<@YR#PZ][QY_(@\/'\
M\^+A\^<@].?R(.O?\_3A\B#DZ>'M[^S>\BX`P>3][>'TYR#G(/#KWO'G\B#P
M\?SSXN'SYR#KW_/TX?(@X?#\(.O?\_3E\B#DZ>'M[^S>\BX`P>3][>'T[R#T
M[R#V_/'T^>SA(//T\>'TY^/IZM[R("(E<R(N`,'D_>WA].<@YR#DY^SI[_7Q
MX]_A(/;AZMWK[_4@(B5S(BX`P>3][>'TYR#G(.'MW.KTY_/G(.3G[/SSZ>_U
M(.KKY>GDZ>_](.'P_"#T[^T@Y>[U\.?QY?3G]-X@Q.?L+LKKY>GDZ?[M+@#!
MY/WMX?3O(/3O(-SM[^GC[.$@)7,N`,'D_>WA].\@].\@W.WOZ>/LX2`B)7,B
M(./IX2#EX^/QX?;>+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(.S=\>_U\B#$
MZ>'WY=_QZ?/G\B`E<P#$Y>T@[/#O\?X@[>$@X>WOW^[Y(/3O(/;<ZN7K[R`B
M)7,B+@#$Y>T@[/#O\?X@[>$@Y.GAXMSS^2`E<RX`P>3][>'TYR#G(.'Q]^GJ
M[_#OW^?SYR#T[_4@ZOGDZ>KO_2#CZ>$@]._M(.'I]._][.7M[R#W\=[S].<N
M(,K<\._IX2#>(/SKY?(@[^D@Z^7P]._LW?'EZ>7R(.3E[2#EW^WAZ2#S^?/T
MW?(N(,[A[>'D[^KI[-SS].4@WB#E\.GJ[^GM^>W>\_3E(.SE(/3O(.3IX??E
MZ2WQZ?/TWB#A[2#W\>7IW//E\^CE(/#E\>GS\_STY?'G(.+OWNCEZ>$N`,'D
M_>WA].<@YR#A[=SJ].?SYR#+W_/TX?(@RN'M_.WY[2#0\?SSXN'SY_(@*$%#
M3"D`P>3][>'TYR#G(.'MW.KTY_/G(,3IY?7H]>WSZ>_C\=SV[_4N("5S`,'D
M_>WA].<@YR#A[=SJ].?SYR#+W_/TX?(@Q.GA[>_LWO(N("5S`,'D_>WA].<@
MYR#A[=SJ].?SYR#+Z?/T_NT@Q.GA[>_LWO(N("5S`,'D_>WA].<@YR#A[=SJ
M].?SYR#T^>T@Z>3I[_3>]/GM(/3O]2#E[O7PY_'E].?TW@#!Y/WMX?3G(.<@
MY?#A[>'V[_'<(/'UZ.S?\^7Y[2X`P>3][>'TYR#G(.3IX>/QX?;>(/;AZMWK
M[_4@*')M9&ER*2`B)7,B+@#$Y2#L\._Q_B#MX2#A\._HY^KE_?/Y("5S(/'U
MZ.S?\^7I\BX`Q.4@[/#O\?X@[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?X_'A]N\@
M]/GM(/'UZ.S?\^7Y[2X`Q.4@[/#O\?X@[>$@ZMSM^2#E]N7D\>GJ_"#A[?3?
MX_'A]N\@]/GM(/'UZ.S?\^7Y[3H@)7,`Q.4@[/#O\?X@[>$@X?#OZ.?JY?WS
M^2#P\?SC\>'L[.$@Y>WG[-WQ^?/G\B#S].\@)R5S)RX`Q.4@[/#O\?X@[>$@
MX?#OZ.?JY?WS^2#E]N7D\>GJ_"#A\??EW^\@\?7H[-_SY?GM("5S+@#$Y2#L
M\._Q_B#MX2#A\._HY^KE_?/Y(/3O(.'Q]^7?[R#Q]>CLW_/E^>T@)7,N(,SP
M[_'EW_3E(.7?].4@[>$@]_'G\^GL[_#OZ=XM\^7TY2#LZ>$@X?#\(/3I\B#E
M\.GK[^/=\B#CZ>$@[>$@X?#OZ.?JY?WSY?3E(/#?\_D@\_3O("5S(-X@X>WT
MZ>/QW/CTY2#LY2#T[R#WW?'I(/3O[2#J_N3IZN$@\-_S^2#S].\@)7,N`,'D
M_>WA].<@YR#A[>'FWO3G\^<@\_3O[2#E[O7PY_'E].?TWB!,1$%0+@#$Y2#L
M\._Q_B#MX2#A\._S]>WDW?/Y("(E<R(N`,3E(.SP[_'^(.WA(.7MY^SE\?[S
M^2#TY^T@Y?#A]MXN("5S`,3E(.SP[_'^(.WA(.7MY^SE\?[S^2#TYR#+W_/T
MX2#$Z>'M[^S>\BX@)7,`Q.4@[/#O\?X@[>$@X_'<^/D@].GR(/'U[-_SY>GR
M(./IX2`G)7,G.B`E<P#$Y2#L\._Q_B#MX2#B\?X@].<@\.OE]?'IZMX@[/#<
M\>$@]._U($UO>FEL;&$N(,+EXN'I^>CEW_3AZ2#\].D@Y=_MX>D@X>WOZ>KT
MWBX`Q.4@[/#O\?X@[>$@Y/[S^2#S].\@]_'>\_3G("<E<R<@].$@\.'QX>K<
M]/D@Y.GJX>G^[.'TX2#S].\@]MSJY>OO("<E<R<Z("5S`,SE]/'G[-WM[R#J
MY=_LY>WO`-?^\>$`T._QY=_E\@#$Y^SI[_7QX]_A`,3G[.GO]?'CW^$@Y>W\
M\B#S]>WDW?/L[_4`Q.?LZ>_U\>/?X2#LZ>'R(.W=X?(`Q.?LZ>_U\>/?X2#U
M\._VX>K=Z_GM`,7N[_7SZ>_D[_3>\^7I\B#$Y^SI[_7QX^_]`,'QZ>CL_/(@
MT.GS]/GTZ>K>\B#*W/'TX?(`Q?7WX?'I\_3?Y?(`U/'=]^_U\^$@UMSSYP#4
M\=WW[_7SX2#^\>$`U.\@]/'=]^_M(%523"#EW^WAZ0#4\=WW[^T@RN'I\?SR
M`-3QW??O]?/A(//U[>C>ZN<Z(`#4\=WW^>T@\_3]ZP#0X?'A[.7T\>_P[]_G
M\^<@Y.GAY.GJX?/I_NT@\._U(.7J].7K[_WM].'I(.KA]-P@].?M(.7?\^_D
M[R`E<RX`P?#OZN_PW@#!\._J[_#>(.7PZ>OOX][R`,S,`,?LY?'>\^GA`,3E
MY._LW>WA`,7L]MSMZ?/G("A"<F]W<V5R*2!$871A5')E90#'(.'MX>;>].?S
MYR#S].<@PMSSYR#$Y>3O[-WM^>T@X?#=]/7WY2X`Q^SE\>_LY^W?X0#'[.7Q
M[^SG[=_A(/#A\>'KX>+>\@#%\.GK[^/>(,?LY?'O[.?MW^'R`,?LW?'A`,3I
MX>/QX?;>(-/TWNOG\@#$Y>K=[.+QZ>_R`,3EZN'DZ>KOWR#A\>GH[._?`+CW
M[_7M(.'Q[>?HY=\`S.7?^?/G(-#E\>GH^?'?[_4`T/'OZN'H[_'I\^S=[>\`
MT/'OY?#IZ^7C[-WM[R#7\?[LX0#0\>_E\.GKY>/LW>WG(-3A]?3\].?TX0#0
M\>_JX>CO\>GS[-WMY?(@Q>[O]?/I[^3O]-[SY>GR`-#Q[^KAZ._QZ?/LW>WE
M\B#%[N_U\^GOY._TWO/EZ?(`S_'I\^SOWP#(W?/G(.'M].GP\>_S_O#O]0#!
M[?3I\/'O\_GPY^S=[>\`Q.GAX_'A]MX`Q.GAX_'A]MX@S^S<Y.'R`,3IX>/Q
MX?;>(,7N[_7SZ>_D_/3G\^?R`,3IX>/QX?;>(.KAZ2#EZNK=[?GSYR#LY^WU
M[-ST^>T`Q.GAX_'A]MX@ZN7KZ>_]`,3IX>/QX?;>(-/TWNOG\@#$Z>'C\>'V
MWB#U\-SQ]^_M]._R(.7MX>OKX>KTZ>KO_2#P\>_T_?#O]0#$Z>'C\>'VWB#E
M[N_U\^GOY._TWO/E^>T@X^GA("<E<R<`Q.GAX_'A]MX@Y>[O]?/I[^3O]-[S
MY?GM(./IX2`G)7,G(.KAZ2#JW.CE(/7P[RWE[N_U\^GOY/STY_/G.P#$Z>'C
M\>'VWB#S]-[KY_(`T/'OY?#IZ^7C[-WMYR#4X?7T_/3G].$`Q.GAX_'A]MX@
M]/'=]^_U\^'R(//TWNOG\@#$Z>'C\>'VWB#T\=WW[_7SX?(@X_'A[.S>\@#$
MZ>'C\>'VWB#A]?3>\B#TY_(@Y>[O]?/I[^3\].?SY_(@ZN'I(.K<Z.4@]?#O
M+>7N[_7SZ>_D_/3G\^?R.P#$Z>'C\=SVY^KE(/3O('-E='5P('5P9W)A9&4@
M<V-R:7!T("<E<R<N`+_QX2#<]NGNY_(`P?'MY_/G(.'I]-[LX?3O\@#!\>WG
M\^<@X>GTWNSA]._R(./IX2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/STY_3A\@#0
MY?'IX_'A]MX@]._U(-#Q[^+KWNSA]._R`-#E\>GC\>'VW@#+Y?#T[^S=\>7I
MY?(@*.7PW_/G\B#JX>D@\_3O(.'Q]^7?[R#JX?3AX_'A]M[R(/3O]2!(;W)D
M92DZ`,_I(.OE\/3O[-WQY>GE\B#=]^_U[2#JX?3AX_'A]N7?(./IX2#T[^T@
MY.GA]^7I\>GS]-XN`,'MW/#T]>[G`-/G[.7?[R#$\>_SZ=SR`-/G[.7?[R#$
M\>_SZ=SR(./IX2#TY^T@].7KY?7TX=_A(/[QX3H@`-/G[.7?[R#$\>_SZ=SR
M.B``RN'TY?WH]>WSYR#A\/P@X?'I\_3E\=P@\/'O\B#TX2#DY>[IW`#*X?3E
M_>CU[?/G(.'P_"#TX2#DY>[IW"#P\>_R(/3A(.'QZ?/TY?'<`,KA]-SK[^/O
M\@#%[/;<[>GSYR#^\>'R(//E(#(T^?'G(.SO\?;>.P#%\.GK[^/=\B#%[/;<
M[>GSY_(`Q>SVW.WI\^<@\/'OXNO=^.7Y[2`H5$%&*0#,[_'VWB#%[/;<[>GS
MY_(`Q>WG[-WQ^?/G(,3IW/3A[N?R`,SG(.3IX>/QW/;EZ?(`S.?M(.7PZ??E
MZ?'>\^7TY2#MX2#A[>_?[N7TY2#A\.7UZ.7?X?(@].\@X?'WY=_O(&UA:6YT
M96YA;F-E+G!H<`#0Y?'IW??EZ2#G(/#Q_O3G(./QX>SLWB#O[?SLX?3A(/#E
MY-_Y[3L@P>T@[>'I(/3SY>K<\>7TY2#A]?3\.@#*X?3=XN'S[.$`RN'TW>+A
M\^SA("5S`,KA]-WBX?/LX2#T[_4@X?'WY=_O]2#PX?'A[-WT\?GM(//A[2!0
M2%`M<V-R:7!T+@#+W_/TX2#*X?3A\=SJ].?R`-;<\>SAZN$M[>'QZOGTZ>K<
M`,7PY>[E\>/A\]_A`,7PY>[E\>/A\]_A($)L;V-K`,7PY>[E\>/A\]_A(,_L
MW.3A\@#%\.7NY?'CX?/?X2#%[N_U\^GOY/STY_/G\@#%\.7NY?'CX?/?X2#%
M[N_U\^GOY._TWO/E^>T`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[SY?GM(./I
MX2`E<P#%\.7NY?'CX?/?X2#E\.GK[^/^[2#CZ>$Z`,7PY>[E\>/A\]_A(,7N
M[_7SZ>_D[_3>\^7Y[2#CZ>$@)7,`Q?#E[N7QX^'SW^$@Q>[O]?/I[^3O]-[S
MY?GM(./IX2`G)7,G`,'E\>_KZ>S=[>'R(,7KY?7SW^WA\@#3]._I]^7?[RXN
M+@#!Z^OGZ^_C\>'VW^$`Q.GE_>CU[?/G($5M86EL`,<@Y.GE_>CU[?/G($5M
M86EL(/#QW?#EZ2#MX2#TX>GQZ=SFY>DN`,S>[?7LX2#LY2#Q]>CLW_/EZ?(`
MP>GSZ-[LX?3A`,KE[?P@[-[M]>SA+@#$Y>T@Y?#I\_3QW/;GZN'M(,'P[_3E
MZ]WS[.'TX2X`P>3EZ>7R(//U[>C>ZN7R(.'MX>;>].?SY_(`Q>WE\>/O\._?
MY_/G(.7I\^'C^>/>\B#EZ>K\[?GM(.'P[R!0:&]T;R!#86QL97)I97<@\_3O
M(.KEW^SE[>\[`,WA(.7MY?'C[_#OZ>?HY=\@].\@[.7M[_T@[.4@Y.7NWR#J
MZ^GJ.P#4W>OO\@"X]._R(-3=Z^_U\@#,Y>/=[>CU\^<@RN7I[.7M[^/QW/;O
M]0#$_O/TY2#LZ>$@Y?'^].?SYR#A\_;AZ^7?X?(L(.<@[_#OW^$@Z.$@\^'R
M(.;G].?HY=\@X>T@]_'EZ>'SZ.7?(.WA(.'KZ]SNY2WTY2#T[^T@ZOGDZ>K\
M(//A\BP@\"[W+B`GT._I_"#EW^WAZ2#T[R#\[>_LX2#T[_4@ZN'T[^GJZ>3?
M[_4@\^'R.R<Z`,3^\_3E(/3G(//][>3E\^<@].?R(.7IZOSMX?(@Y>3^`,O<
MZ._R`,O<Z._R(.'P[_/TW>OK[^WTX?(@X?#<[?3G\^<Z("5S`,O<Z._R(.SE
M(.S>[?7LX2!E;6%I;"X`R]SH[_(@X_'<]N_M].'R("(E<R(N`,7H[>GJ_`#%
M]?'^\.<`RMSHY2`Q-2#KY?#TW`#*W.CE(#(@R^7P]-P`RMSHY2`S,"#DY?7T
MY?'\Z^7P].$`RMSHY2`U(.OE\/3<`,K<Z.4@]N_QW"#P[_4@[/#AW^WE].4@
M\_3G[2#U\.?QY?/?X0#*W.CE(.SI\]X@_O'A`,K<Z.4@Z^7P]/P`T.'QX>3E
MZ>/LX?3IZMWR(/3I[-WR.@#%ZO3=Z^7SYP#%\-WJ].'SYP#%\-WJ].'SYR#0
MZ^7U\>GJWO(@S/#<\>'R`,'MX>SE[?SLY>WO(")"14=)3B(@\_3G(./QX>SL
MWB`E9"X`P>WA[.7M_.SE[>\@(D5.1#HE<R(@\_3G(./QX>SLWB`E9"X`P>WA
M[-WM[^WTX>T@)RDG`,'MX>S=[>_M].'M(.'PZ]X@Z]WNYR#>(//U[>C>ZN<@
MX>WAYM[TY_/G\B#SY2#EZ?/AX_GCZ>K<`,?LY?'O[.?MW^$@R][NY_(`Q>KH
MW?3G\@#7\?[LX2#P\>_SZM[MZ>_U`-'UZ.S?\^7I\B#CZ>$@1E10('5P;&]A
M9`#!\._T]???X2#JX?3<(/3G[2#P\>_S\-SHY>GA(.'MW.KTY_/G\B#T^>T@
M\/'O].GLWO/E^>TN`,'P[_3U]]_A(//][>3E\^?R(//T[^T@Y.GAZN_LZ?/T
MWB#*X?3AZ_SC[_4N`,'P[_3U]]_A(//][>3E\^?R(//T[^T@4TU"+5-E<G9E
M<BX`P?#O]/7WW^$@X>WTZ>/QX?;>\B#A\/P@(B5S(BX`P?#O]/7WW^$@X>WT
MZ>/QX?;>\B#SY2`B)7,B+@#!\._T]???X2#DY^SI[_7QX]_A\B#S_>WDY?/G
M\B!305-,+@#!\._T]???X2#LY?3A]N_QW/(@\^4@(B5S(BX`P?#O]/7WW^$@
MZN'TW"#TY^T@X>OKX>/>(.KYY.GJ[_T@X^GA(/3O[2#W\=[S].<@)7,@X?#\
M(/3O(//TX>CL_"`E<RP@Z_SC[_(@)7,`P=_H\>GO\@#0[^O](//OXN'Q_"#+
MW.CO\CH`UL'.`-;EXO'O]=SQZ>_R`,3IW.CE\^<@X^GA`,3IW.CE\^<@X^GA
M.B``R]_CY?(@XO'O]]WR`,O?X^7R(/?I[^WO\/3^\^7I\@#0W^WAZN'R(-#E
MY-_O]0#!\>GH[/SR(.'Q]^7?[_4Z("5S(.'Q]^7?[P#!\>GH[/SR(.'Q]^7?
M[_4Z("5S(.'Q]^7?X0#$Z>'WY>GQZ?/TWO(@P?'WY=_Y[0"\[>_LX2#!\??E
MW^_U`,7PZ>OOX]X@P?'WY=_O]0`GP>W=XN'S[.$G(,'Q]^7?[_4`)\'MW>+A
M\^SA)R#!\??EW^_U(.3E[2#U\._S].?QW^;E].'I+@#6W^OT\>$`T/'^].\@
MS.GS_`#0\?[T[R#4W?3A\?3O`-/TX>CE\?SR(.O\X^_R`$9L:7``1FQO870`
MS^S?]^OG`,\@]MSJY>OO\B`E<R#DY>T@]?#<\??EZ0#7\?[LX2#C\=SL[.'T
M[_(`U/'O]MX`P^GA($)R;W=S97)S+"#P[_4@Y.7M(/7P[_/TY_'?YN_U[2#E
MZ>K\[>7R`,[E]]SSX?3E(/3O[2#J^>3IZOP@\^'R.P#6_/'LY?(`T/'\XNOE
M^.<`U/WP[_(@T/'\XNOE^.?R`-#Q[^+KW?CEZ?(`T/'OXNO=^.7I\B`R`$9O
M<G5M<P#0\>_YZ-[SY>GR`-#A`-#KX=_SZ>$`T.OG\>_V[_'?Y?(@Q.GAZ.7S
MZ>S\].?TX?(`P?#<[?3G\^<@Q.GAZ.7SZ>S\].?TX?(`P=_TY^SA(,3IX>CE
M\^GL_/3G].'R`,'PW.WTY_/G(//E(.'?].?LX2#$Z>'HY?/I[/STY_3A\@#!
M\/P`P?#\(/3O(`#![>'K]?3IZMX@T.7QZ>/QX?;>`,'MX>OU].GJWB#0Y?'I
MX_'A]MXZ`-#KWO'G\B#3Y>O>[><`T.O>\>7R(+SM[^SA`$=A;&QE<GD@X?#\
M(/3G[2#O\._?X2#HX2#PX=_Q[>_M].'I(._I(.7IZOSMY?(`1V%L;&5R>3H`
MS.GJ\?P@O.WO[.$`P^7MZ>K=\B#%\.GK[^/=\@#,Y?3<XN'SYP#%Z^O<Y.$`
MQ>OKY^WIZMP@*$E33RTX.#4Y+3<I`,3IX??EW_'I\^<@S^S<Y/GM`-3A(._M
M_.SA].$@]/GM(._LW.3Y[2#DY>T@\/'=\.7I(.WA(.7?[>'I(.KE[=P`Q>[O
M]?/I[^3O]-[SY>GR(,_LW.3Y[0#/[-SDY?(`R>3I_/3G].7R($=U97-T`,GD
MZ?STY_3E\B!'=65S=`!'=65S=&)O;VL`U.\@\_WS].?LX2#A]>CE[?3IZN_P
M[]_G\^?R($A45%`@Y.4@XO'=Z.?JY2X`OOCO\@#"[][HY>GA`,+OWNCEZ>$@
MX^GA(/3G(/?QWO/G(/3O]2#JY>GLY>WOX_'<]N_U`,+OY^C\\@#'[.GS]N'?
M\>GO`,'E\>_KZ>S=[>'R(,?QX>KKY=_O]0#%Y/X@Y=_MX>D@YR#A\??>(/3O
M]2#A\??EW^_U.@#8Y^O<`,<@Y>/C\>'VWB#I\_3O\>GJ[_T@Y.7M(/#QW?#E
MZ2#MX2#EW^WAZ2#JY>W>`,'Q]^GJWB#3Y>O?Y.$`P?'WZ>K>(-/EZ]_DX0#$
MZ>7]Z/7M\^<@T_#I].GO_0#4Y^O=]OGM[R#3\.GTZ>_]`,'Q]^GJWB#3Y>O?
MY.$`Q=_S[^3O\B#S].?M(-7PY_'E\]_A(,?+Y>KT\>_MZ>KO_2#4X??UY/'O
M[.7?[_4`T_WS].?LX2`G2&]R9&4G`"=(;W)D92<@P?/]\>SA].<`U.\@\/'\
MX_'A[.SA("=(;W)D92<@Y.7M(-WWY>D@\?7H[.GS].7?(//Y\_3<`,_QZ>;\
M[?3I[_(@RN'M_.WA\@#/\>GF_.WTZ>\@)^/=[.GS[.$G`,_QZ>;\[?3I[SH`
MT/GR(/;HW//A].4@Y>3^.R`H\.'QX>KAZ_X@[>$@].\@X>WA]MWQY?3E(//T
M[R#DZ>'WY>GQZ?/TWB$I`-#\\^7R(//TWNOE\B#HW>OE].4@[>$@Y>WO\._I
MWO/E].4[`-#\\^$@\.7DW^$@*//TWNOE\BD@Y=_MX>D@Y>KEWSL`T/SSY?(@
MX_'A[.S=\B#HW>OE].4@[>$@Y>WO\._IWO/E].4[`-7C\>'SW^$`U>/QX?/?
MX3H`U^GO]>SO\=_S].'R`,<@Q.?LZ>_U\>/?X2#C\>'L[.'T[^CU\=_DX?(@
M24U!4"#A\-WT]??E.B`E<P#'(.3IX>/QX?;>(./QX>SLX?3OZ/7QW^3A\B!)
M34%0(.'PW?3U]^4Z("5S`,<@Q.?LZ>_U\>/?X2#PY>GQ[_'I\^S^[2`H<75O
M=&$I(./QX>SLX?3OZ/7QW^3A\B!)34%0(.'PW?3U]^4Z("5S`,7I\^7Q]_SL
MY>WA`$E0+<3IY?WH]>WSYP!)4"W$Z>7]Z/7M\^<@Y.7M(.7?[>'I(.3IX>C=
M\^GLYRX`25`MQ.GE_>CU[?/G(.SG(.7PZ?3QY?#TWB#LW?/A(//E($-)1%(M
M0FQO8VLN`,KKY=_D^>SA+=#A\>'BW^'SYR!)4"X`Q>GSY?'W_.SE[>$`Q>GS
MX>/YX]X@P_'A[.S>\B#0\>GM`,S\[>\@Q>GJ[^W?Y.GA`,7IZN_MW^3IX2#C
MZ>$@)7,`Q>GJ[^W?Y.GA(.KAZ2#*Y=_LY>WO`,_M[^SA(/3A]?3\].?TX?(Z
M`,'M(.3E[2#E[/;A[=_FY?3AZ2#S^?/TW"P@)7,@X^GA(.WA(.'M[]_NY>D@
M\^4@[=WO(/#A\=SH]?'O+@#![2#DY2#BZ]WPY?3E(.KA[=WMX2#EZ>KO[=_D
MZ>\@]_'G\^GL[_#OZ?[M].'R(/3O[2!);G1E<FYE="!%>'!L;W)E<BP@W_/Y
M\B#P\=WPY>D@[>$@]//EZMSQY?3E(.7D_B#CZ>$@[>$@X?#E[>7QX^_P[^G>
M\^7TY2#TYR#DZ>'VW.WEZ>$@4$Y'+@#![2#BZ]WPY?3E(.'U]/P@].\@[-[M
M]>SA(/?Y\=_R(.7IZOSMX2P@YR#EZ>K\[>$@\._U(.C=Z^7TY2#MX2#JX?3E
MXMSSY?3E(.3E(.SP[_'EWR#MX2#E[/;A[>GSZ.7?(.'P_"#T[^T@8G)O=W-E
M<B#SX?(N`-#Q[^7PZ?/J_/#I\^<@Q>GJ_.WA\CH`55),(,7IZOSMX?(`Q>GJ
M_.WA(.'P_"!'86QL97)Y`,7IZOSMX2#A\/P@1V%L;&5R>3H`P?#O\_3OZ]X@
MQ>GJ_.WA\@#%Z>K\[>7R`,7I\^'C^>/>`,O<Z._R(.KA]-P@].?M(,7I\^'C
M^>/>.B``Q>GSX>/YX]XL(,+>[.$@)60`T.7DW^\@\._U(.7I\][WZ.<Z("5S
M`-#EY-_A(/#O]2#EZ?/>]^CG\^'M.@#3Y2#%\.7NY?'CX?/?X0#%Z?/AX_GC
MWB##\>'L[-[R(,SE]-P`Q/SHY^KE(.O<Z._R(.KYY.GJ_/(@Y>W=\>/EZ>'R
M+@#+W.CO\B#\[>_LX2#W\=[S].<@WB_JX>D@ZOGDZ>K\\BX`R]SH[_(@_.WO
M[.$@]_'>\_3G(-X@Y>WAZ^OAZO3IZMX@Y.GE_>CU[?/G+B#.X>WAY._JZ>S<
M\_3E(-X@Y?#IZN_I[?GMWO/TY2#LY2#T[R#DZ>'WY>GQZ?/TWB#CZ>$@\.7Q
MX>GTW?'Y(.+OWNCEZ>$N`,'][N?SYR#0Y?'IZ/GQW^_U`,GDZ>'?].7Q[^D@
MU_'>\_3E\@#0Z^?Q[_;O\=_E\@#0Z^?Q[_;O\=_E\@#%Z?/AX_GCWB#3]-[K
MY_(@S.7TW`#%Z?/AX_GCWB#%Z>K\[>'R`,7I\^'C^>/>(-#?[>'JX0#%Z?/A
MX_GCWB#S_>WDY?/G\B!796(`Q>GSX>/YX]X@T_3>Z^?R(-#QZ>T`Q>GSX>/Y
MX]X@[=WA\B#S]-[KY_(@[.7TW"#TY^T@]/'=]^_U\^$`Q>GSX>/YX]X@[=WA
M\B#S]-[KY_(@\/'I[2#A\/P@].?M(/3QW??O]?/A`,7I\^'C^>/>(.W=X?(@
MX_'A[.S>\B#LY?3<(/3G[2#T\=WW[_7SX0#%Z?/AX_GCWB#MW>'R(./QX>SL
MWO(@[.7TW"#TY^T@]/'=]^_U\^$`Q>GAX_GCWB#PX?'AX_'<]N_U(.SE]-P@
M]._M(/3QW??O[?3A(.K\[.+O`,7I\^'C^>/>(/#A\>'C\=SV[_4@\/'I[2#T
M[^T@]/'=]^_M].$@ZOSLXN\`Q>GSX>/YX]X@Y>WAZ^OAZO3IZN_](/#Q[_3]
M\._U`,3^\_3E(&5M86EL(.3IY?WH]>WSYR#S].?M(._P[]_A(.7PZ>CU[.7?
M].4@[>$@\.'QX>O<XN7TY2#T[R#MW>\@\^'R(.KYY.GJ_#H`Q>GSX>/YX]X@
MZN7KZ>_](.SE]-P`Q>GSX>/YX]X@ZN7KZ>_](/#QZ>T`Q>GSX>/YX]X@\_3>
MZ^?R(.SE]-P`Q>GSX>/YX]X@\_3>Z^?R(/#QZ>T`Q>GSX>/YX]X@[.?M_>SA
M]._R`,7I\^'C^>/>(/#A\>'C\=SV[_4@[.7TW`#%Z?/AX_GCWB#PX?'AX_'<
M]N_U(/#QZ>T`Q>GSX>/YX]X@X_'A[.S>\B#LY?3<`,7I\^'C^>/>(./QX>SL
MWO(@\/'I[0#%Z?/AX_GCWB#TY_(@X?#AZ?3O_>SE[>?R(.'PW.WTY_/G\B#S
M].?M(.7Q_O3G\^<@X?/VX>OEW^'R.@#%Z?/AX_GCWB_$Z?SQZ/GSYR#%Z>K\
M[>'R`,7I\^'C^>/>+\3I_/'H^?/G(-/][>3E\^?R`,SG(.7PX?'JW?(@]?#\
MZ^_I\.\@X^GA(.'P[_/T[^O>(//TYR#KW_/TX2#DZ>'M[^S>\BX`S.<@Y?#A
M\>K=\B#U\/SK[^GP[RX`P>K=\>'I[_(`R]_S].$@P>KE\>'?^>T`Q?#IZ]WN
MX?3E(,O<Z._R(,7MW?'CY>GA(./I)R#A]?3\(/3O(//U\_3A].GJ_"X`P>KU
M\>\@541(+B`H57-E<B!$871A($AE861E<BDN`,SG(-WCZO7QYR#E]N'Q[._C
MWBX`P>KU\>\@0F%T8V@M240N`-/TW.OHY^KA[2#KW.CO\B#DY>3O[-WMX2X`
MP>KU\><@Y.GE_>CU[?/G(/#Q[^_QZ?/L[_TN`,SG(-WCZO7QYR#L[_'VWB#A
M\??EW^_U`,SG(-WCZO7Q[R!M<V=?='EP92X`S.<@W>/J]?'O(-X@Z^7?\.7I
M(&%P:5]I9"X`S.<@W>/J]?'E\B#>(.7KZ^GPY=_R(/#A\=SLY?3Q[^DN`$EN
M=F%L:60@<&%R96YT('!E<FUI<W-I;VXN`,SG(-WCZO7Q[R#P\?GT_.KOZ^OO
M+@#,YR#=X^KU\>_R(/#A\>'KWO#TY_(Z("<E<R<`S.<@W>/J]?'O(.KOZ>W\
M]_'G\_3O(.'M].GJY=_LY>WO`,SG(-WCZO7QYR#A\??IZMX@Y.GE_>CU[?/G
M+@#,YR#=X^KU\>$@Y.7D[^S=[>$@56YI8V]D92X`RN'TW.OOX^_R(-7PX?'W
M_.WT^>T`T.OAX^GA`,GA[>_UW/'I[_(`R>_]Z^GO\@#)[_WMZ>_R`,7UZ/7C
M\=SL[.GSYP#%]>CUX_'<[.SI\^<@\_3O(,K=[?3Q[P#0Z][QY_(@Q?7H]>/Q
MW.SLZ?/G`,7UZ/7C\=SL[.GSYR#!\>GS].7QW`#%]>CUX_'<[.SI\^<@Q.7N
MZ=P`P>7Q[^OI[-WMX?(@RN'KX>S<].'R`,'E\>_KZ>S=[>'R(,KA\?#<Z._U
M`,'E\>_KZ>S=[>'R(,KA\_3O\>G<\@#-X2#J\>'TWO/Y(/3O(.'UZ.7M].GJ
M_#L`P>7Q[^OI[-WMX?(@RN7VX>OO[>G<\@!+97)B97)O<RU397)V97(@X?'M
MWNCGZN4@].?M(.'UZ.7M].GJ[_#OW^?SYRX`P>7Q[^OI[-WMX?(@RMWQZO7Q
MX?(`S=WA(.'P_"!+97)N96P`Q.?LZ>_U\>/?X2#*Z^7IY.GO_0#!\._T_?#Y
M[.$@RNOEZ>3I[_T`S-[J[_(@RNOEZ>3I[_T`U/WP[_(@RNOEZ>3I[_T`U_'>
M\^<@RNOEZ>3I[_T`U.\@ZNOEZ>3?(/7PW/'WY>D@WN3G(//T[^T@Y>[U\.?Q
MY?3G]-X@Y.?L_//I^>T@ZNOEZ>3I_NTN`-#AZ>3IW`#!Y?'OZ^GLW>WA\B#*
M^0#!Y?'OZ^GLW>WA\B#*[^;<[>?R`,3IW/3A[N<`P>7Q[^OI[-WMX?(@R]SQ
MZ?/A\@#4Y>OE]?3AW^\@S.GS_`#4Y>OE]?3AW^\@U-WTX?'T[P#4Y>OE]?3A
MW^$@Q>WG[-WQ^?/G.@#4Y>OE]?3AW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A
M.B`E<P#4Y>OE]?3AW^$@Q=_S[^3O\B#S].?M(/7PY_'E\]_A.B`E<R#A\/P@
M)7,`U.7KY?7TX=_A(,7?\^_D[_(@\_3G[2#U\.?QY?/?X3H@T._TW0#-_.SO
M\@#$Z=STX>[G`,'VWO/TY2#JY>W\(./IX2#MX2#LY^T@]?#<\??O]>T@\.7Q
MZ>C^\>GA`,'QZ?/TY?'<`,'QZ?/TY?'>(,7PZ>KE]N'KW^3A`,'QZ?/TY?'=
M\B#4Z>S=\@#0Y>WTW//TZ??O`,'E\>_KZ>S=[>'R(,O>[.WO]0#3_>WDY?/G
M`-/][>3E\^<@\._U(.3EW_?MY>D@\^4Z`-/][>3E\^<@].?R(.3IY?WH]>WS
MYR#CZ>$@W.WOZ>/LX2#PX?'AZ/WQ[_4@\_WMZ.7SY_([`-/U[>3=\^7I\@!,
M:6YU>"U#;V]K:64`3&ES="`M(,\@]_'>\_3G\B#L\._QY=\@[>$@Y.7?(/3O
M(/;<ZN7K[P#+W_/TX2#"W//E^>T@Q.7D[^S=[?GM`,O?\_3A(.CE[-ST^>T@
MPN_>Z.7IX?(`R]_S].$@T.GMW.KY[0#'(.3G[.GO]?'CW^$@Z]_S].'R(/?Q
MY_/T_NT@W??EZ2#A\.7MY?'C[_#OZ>?HY=\N`-;\\?3Y\^<N+BX`U._PZ>K>
M(+_QX3H@`-3\\._R(.KAZ2#^\>$`U/SP[^CE\]_A`,7?\^_D[_(`N.[OY._R
M`,3IY?'CX?/?Y?(@Y>GS_.3O]0#'(.7?\^_D[_(@P?#=]/7WY2X@T.GHX>W\
M].'TX2#D_.CGZN4@Z]SH[_(@].\@O.WO[.$@U_'>\_3G(-X@[R#*^>3IZOSR
M+@#%W_/OY._R(,'PW?3U]^4N`+CN[^3O\@#,Y>/<Z^\@RN7?[.7M[P#!X]SP
MYP#7X>SGZ_P`S.GJ\=P@Q>OKY^WIZMP@X_'<[.SA].$`S.GJ\=P@Z^'TZ>WI
MZMP@X_'<[.SA].$`S.GJ\=P@T?GLX?KJWB#!\=_H[.?SYP#,S`#,X>/IZOP`
MP>OKY^OOX_'A]M_A`,3IX??EW_'I\^<@16UA:6P`Q.?LZ>_U\>/?X2#3_>WD
MY?/G\BXN+@#$Z>'WY=_QZ?/G(.KA].?C[_'I_NT@ZN'I(/?Q^>S<]/GM(/#O
M]2#HX2#E[/;A[=_F[^WTX>D@X?7TW?(N`,7C]^7I\=_DZ>\`T.7DW^$@Q^SE
M\>_LY^W?X?(@ZN'I(+_QX?(`T.7DW^$@Y>GSX>/YX][R`,S<\?3I[_(`O/'I
M[P#,X?'JW/'I\^SA(.SE(-WMY.7I[N<@P>WAX^WY\^S=[>_U+\SG(.'MX>/M
M^?/LW>WO]0#,X?'JW/'I\^SA(.SE(-SKZ^<@W>WDY>GNYR`H\"[W+B#3Y^SA
M[?3IZOPOP?#A[?3G[-WM[RD`T.7DW^$@\._U(/3AZ?'IW.;O]>T`S-WCZ?/T
MYR#E\.GT\>7P]-X@\-_S]/GSYRX`U?#=\>+A\^<@[_'?[_4@[.?M_>SA]._R
M+@#,W>/I\_3G(.CE\>SOZO'A\]_A(/3EZ^7U].'?^>T@,C0@^?'^[3H@`,S=
MX^GS].<@Z.7Q[._J\>'SW^$@].7KY?7TX=_Y[2`V(/GQ_NTZ(`#,W>/I\_3O
M(.S>ZN_R`,S<Z>_R`,'J_?'Y\^<@T_7MW.WTY_/G\@#0Z^?Q[_;O\=_E\B#3
M]>W<[?3G\^?R`-#Q_/3A\^<@X^GA(-/U[=SM].?SYP#!\-SM].?SYR#CZ>$@
MT_7MW.WTY_/G`,7MY^S=\?GSYR#CZ>$@T_7MW.WTY_/G`,'?].?LX2#E[>?L
MW?'Y\^?R(./IX2#3]>W<[?3G\^<`S-WKYP#3Y^SEZ?[SY>GR`,KA]-SS].'S
MYR#,Y>WO_3H`T_7C]_[MY?7SYR#JY>OI_NT`S-[M]>SA`-3O(.S>[?7LX2#E
M\.GBY>+AZ?[HY^KE(.7PZ?3U]_[R+"#AZ^O<(/3O(/#I\_3O\._IY_3IZOP@
M]._U(/7P[^/QW/;O[?3A(.3E(.SP[_'EWR#MX2#E\.GBY>+AZ?GHY=\N`-3O
M(.S>[?7LX2#=Z^?NY2X`U/WP[_(@[.?M_>SA]._R`,KAZ?'\\B#A\/P@365T
M87(`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X`365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92X@1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@
M861M:6YI<W1R871O<BX`S-WH[^3O\@#'(,S=Z._D[_(@)R5S)R#DY>T@[_'?
M\^CGZN4`S.7T\>GJ_`#,Y?/AW^\`36EM92!4>7!E`,SIZO'\].7QYR#HY?'L
M[^KQX?/?X2#TY>OE]?3AW_GM(#(T(/GQ_NTZ(`#,Z>KQ_/3E\><@Z.7Q[._J
M\>'SW^$@].7KY?7TX=_Y[2`V(/GQ_NTZ(`#*X>CQW?#TY_(`Q.G<]N_QX0!-
M:7-S:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`,OEW_#EZ2#T[R!C
M;VYF:6=U<F%T:6]N+B#0\=WPY>D@[>$@].\@Y.?LZ>_U\>/>\^7TY2#A[2#H
MW>OE].4@[>$@]_'G\^DM[._P[^G>\^7TY2#A]?3>(/3G[2#E]N'Q[._CWBX`
MR^7?\.7I(/3O($E$(/3O]2#LY^W][.'T[_(N`$UI<W-I;F<@<F5Q=6ER960@
M4$5!4B!P86-K86=E($UA:6PN`,OEW_#EZ2#T[R!)1"#TY_(@\_WMY.7SY_(N
M`,3E`$5M86EL(,KI[>?TWO(@U.?KY?;Y[=_A\@#,W?3QZ>_R`,?LY?'O[.?M
MW^$@]/'O\._P[]_G\^?R`-3Q[_#O\._?Y_/G(%523`#%[/;<[>GSYR#,WNWA
M`,S>[>'R(.KAZ2#=]._R`,SG[>GAW^$`S.?MZ>'?X2#+W_/TX2##Y>/O[?ST
M^>T`UMSSY>GR(-/EZ][MY_(`RM_MY_/G(.K<]/D`RM_MY_/G(.'QZ?/TY?'<
M`,K?[>?SYR#DY>[IW`#*W^WG\^<@\-SM^0#*W^WG\^<@ZMST^0#*W^WG\^<@
M\-SM^0#0[^OKX?#KW?(@Z]_S].7R(.7PZ>OOX][R("CJX?3A\?'<ZO3E\BD`
MT._KZ^'PZ]X@Y?#IZ^_CW@#/(,OOX^'QZ>'S[/SR(.SO]0#/(.GS]/ST[_#\
M\B#L[_4@*'!O<G1A;"D`QR#E[/;<[>GSYR#T[_4@Z?/T_/3O\._](.SO]2`H
M<&]R=&%L*0#'(-#E\=_KY_CG(.SO]3H`P>7Q[^OI[-WMX?(@S/7TY^O>[>?R
M`,_7R2P@Q,4@\_7L]OGM_@"\[>_LX0#!\.'I].7?].'I(.7MW?'CY>GA`,3?
MZO3U[P#0[_3=`,W=X2#*X?3GX^_QW^$`S=WA(-/EZ][MYP#-W>_R(,KYY.GJ
M_/(`S=WO\B#*^>3IZOSR("CNX>W<*0#-W>\@_.WO[.$@U_'>\_3G("CP\>_A
MZ?'E].GJ_"D`S=WO(/#A\=SH]?'O("CJY>W\*0#-W>$`S^S<Y.7R(./IX2#M
MW>$@*&YE=W-G<F]U<',I`,7P_.SE[>\`Q?#\[.7MYR#3Y>O?Y.$`Q?#\[.7M
MYR#6W//G`,7P_.SE[>7R(,7PZ>OOX]WR`,_WZ0#$Y>T@]?#<\??EZ2#DZ>'H
MW?/I[.\@8V]N9FEG=7)A=&EO;B#CZ>$@[>$@Y.7?[OD@Y.GA]N_QW?(N`,3E
M[2#U\-SQ]^7I(.3IX>C=\^GLYR#S]/'A].?CZ>K>(./IX2#DY^SI[_7QX]_A
M($E33R!I;6%G97,N`,3E[2#U\-SQ]^7I(/#Q_/3U\.\@X^GA($)A=&-H+@#$
MY>T@]?#<\??EZ2!";&]C:R#S].?M(.'I]._][.7MYR#HW?/G`,3E(.3\Z.?J
MY2#\[>_LX2#CZ>$@X?7HY>WTZ>KO\._?Y_/G($U#04PN`,3E[2#U\-SQ]^_U
M[2#AZ^OAX]WR+@#$Y2#L\._Q[_WM(.WA(/#Q[_/TY>CO_>T@Y>[O]?/I[^3O
M]-[SY>GR(.K<]/D@X?`G(.'U]/P@].\@Y?#?\.7D[RX`Q.7M(.SP[_'O_>T@
M[>$@\/'O\_3EZ._][2#U\._JX?3GX^_QW^7R(//E(.'U]-X@].?M(.7N[_7S
MZ>_D_/3G\^<N`,3E[2#O\=_SZ.?JX>T@\.OG\>_V[_'?Y?(@\?7H[-_SY?GM
M(./IX2`E<RX`Q.7M(._QW_/HY^KA[2#PZ^?Q[_;O\=_E\B#Q]>CLW_/E^>T@
MX^GA($944"!61E,N`,3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?
MY?(@X^GA(/3G[2#U\.?QY?/?X2#*X?3AZ_SC[_4N`,3E[2#=]^_U[2#Q]>CL
MZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3I\B#JX?3GX^_QW^7R(/3G\B!3
M44PN`,3E[2#=]^_U[2#Q]>CLZ?/TY=\@[^D@\.OG\>_V[_'?Y?(@X^GA(/3I
M\B#P\>_TZ>S>\^7I\B#TY_(@4U%,+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I
M(/#KY_'O]N_QW^7R(./IX2!344P@5D93+@#$Y>T@W??O]>T@\?7H[.GS].7?
M(._I(/#KY_'O]N_QW^7R(./IX2#TY^T@X?7HY>WTZ>KO\._?Y_/G(//TY^T@
M4U%,+@#$Y>T@W??O]>T@\?7H[.GS].7?(._I(/#KY_'O]N_QW^7R(./IX2!3
M44PM1FEL92!61E,N`,3E[2#=[.7I[>4@\-_S]/GSYRX`Q.4@Y/[SX?3E(/#Q
M[^_QZ?/L_"X`Q.4@]N_Q]/[HY^KA[2#A\??EW^$`Q.4@XO'=Z.?JX>T@Y>GJ
M[^W?Y.GA+@#$Y>T@[_'?\^CGZN4@]._P[^CE\]_A+@#$Y2#D_O/A].4@[-[M
M]>SA+@#$Y>T@[_'?\^CGZN4@_.WO[.$N`,3E[2#O\=_SZ.?JY2#A\>GH[/SR
M+@#$Y>T@]?#<\??O]>T@Y/7SW/'E\_3E\B#P\>_BZ]WXY>GR`,3E[2#EZNKQ
MY>SO_>T@Y=_S[^3OZ2X`S^D@\/'O].GLWO/EZ?(@Y.7M(.7?[>'I(.3IX>C=
M\^GLY?(N`,3E[2#U\-SQ]^_U[2#JX>W\[>7R`,3E[2#U\-SQ]^_U[2#PZ^7U
M\=WR`,3E[2#U\-SQ]^7I(/#Q[_/Y\>GM_/(@]_[Q[_(@X^GA(.SMWNSG(&-A
M8VAE+@#$Y>T@Y/SHY^KE(/SM[^SA(/?QWO/TYR#>+^KAZ2#J^>3IZOSR+@#$
MY>T@Y?#I\_3QW/;GZN'M(-WCX_7QX2!834P@Y.7D[^S=[>$`Q.7M(/7PW/'W
M[_7M(/3I[-WR`,3E(.+QW>CGZN4@W>KD[_/G(//T[R#A\??IZOP@8V]N9FEG
M=7)A=&EO;BX@SN'MX>3G[.GO]?'CWO/TY2#T[RX`Q.4@XO'=Z.?JY2#=ZN3O
M\^<@\_3O(.'Q]^GJ_"#SX?(@8V]N9FEG=7)A=&EO;BX@SN'MX>3G[.GO]?'C
MWO/TY2#T[RX`RN'MW>WA\B#3]>SLY?3=]_GM`,KA[.S?X0#*X>W=[>$@*-?Q
MWO/G(/#Q[^KAZ._QZ?/LW>WO]2D`POSQY>GO(,?LZ?/VX=_QZ>\`O/?I(,SE
M]-P`O/?I(-#QZ>T`Q.7M(.7?[>'I(.KA]-SK[^/O\@#$Y>T@W??EZ2#OZ^_J
MZ^?Q^>CEWRX`Q.7M(-WWZ>4@].7HY=\`Q.7M(/7P[_/TY_'?YN7TY2X`T^?L
MY>G^\^7I\@#3Y^SEZ?[SY>GR("T@T.7QW^OG^.<`S^D@\^?LY>G^\^7I\B#E
MW^WAZ2#LZ>$@Y?;A\>SOX]X@\._U(//A\B#E\.GT\=WPY>D@[>$@Y.?LZ>_U
M\>/>\^7TY2#T[R#A[?3?\_3OZ??O(/3Y[2#JW_3QZ>WY[2#LZ>KQ_NT@]^'Q
M].G^[2#S]._M(/7P[^OOX^GS]-XN(,SP[_'EW_3E(.WA(.3G[.GO]?'CWO/E
M].4L(.WA(/3Q[_#O\._IWO/E].4L(.WA(.3IX>/QW/CE].4@ZN'I(.WA(/3U
M\/[SY?3E+B#,\._QY=_TY2#E\-_SY_(@[>$@^-SNY?3E(//TZ?(@\^?LY=_Y
M\^7I\B#SX?(@X^GA(.WA(.7M]._PW_/E].4@[.GA(/#KY_'O]N_QW^$N(-7P
M[_/TY_'?YN7TX>D@ZN'I(.7I\^'C^>/>("T@Y>[AX_GCWB#T^>T@\^?LY>G^
M\^7Y[2X`T^?LY>G^\^7I\CH`U-_P[_3A(./IX2#E[/;<[>GSYRP@Y?#I\_3Q
M[_;>+@#![>'J[^GM_O/EZ?(`U.\@\/'\X_'A[.SA(/#O]2#DZ>'WY>GQW^;E
M].'I(/3I\B#EZ>3O\._IWO/EZ?(@)7,@Y.7M(.+QW>CGZN4N`,WOW>SB\>GO
M\@#!\>GH[/SR`,'QZ>CL_/(@]^'QX>KTWO'Y[0#!\>GH[/SR(//TY^O^[0#!
M\>GH[/SR(//TY^O^[2#S].?M(.7L]MSMZ?/G(/3G\B#PY?'?Z^?XY_(Z`,'Q
MZ>CL_/(@X_'A[.S^[0#$Y>T@[_'?\^CGZN4@X?'IZ.S\\B#CZ>$@Y>WG[-WQ
M^?/G(/3Y[2#KZ?/T_NT@Y.GA[>_LWO(N`,'M].GJY=_LY>WO`,3G[.GO]?'C
M_/(@P>WTZ>KEZ>S=[>_U`,7N[_7SZ>_D[_3>\^7I\B#$Y^SI[_7QX^_](,'M
M].GJY>GLW>WO]0#/ZO3AY.GJ_/(`S^KT_N+QZ>_R`-;?Z_3Q[R#P\>_SXN_K
M_NT`P_'A]N7?[P#0X>OI_/(@ROGDZ>K\\@#,_.WO($E-05`M4V5R=F5R<R#U
M\._S].?QW^;O]>T@ZN_U[?SW\>?S]._U\B#VX>K=Z^OO]?(N`,S\[>\@Y/7S
MW/'E\_3E\B#P\>_BZ]WXY>GR`,S\[>\@[.GA($5M86EL(.3IY?WH]>WSYR#E
M\.GT\=WPY?3AZ2X`S/SM[R#O(.GDZ>_J]-[TY_(@WB#O(.3IX??EZ?'I\_3>
M\B#S]?/TWNSA]._R(.SP[_'EWR#MX2#AZ^O<[N7I(/3G[2#IY.GOZO3G\]_A
M(-X@].GR(.7N[_7SZ>_D[_3>\^7I\B#T[_4@Z>3I[^KTWO3G(./IX2#J[^GM
MWB#W\=[SYRX`P>WOZ>/LX2#SY2#MW>\@\.'QW.CU\>\`3W!E;E-33"W+W.CO
M\CH@Q.7M(.SP[_'^(.WA(.+CW.OY(.3EY._LW>WA(.'P_"!3+TU)344@]?#O
MX^7C\>'L[-WM[R#LW?'O\BX`P>WOZ>/LX2#A]?3>\B#TY_(@\_WMY.7SY_(@
M\^4@[=WO(/#A\=SH]?'O`,OEZ?3O]?'CZ>K\(-/]\_3G[.$`T/'OY?'AZ?3I
MZOSR(-/U[.SE]-WW^>T`Q?#IZ^_CW?(`Q?#IZ^_CW?(@X^GA`,7PZ>OOX]WR
M(./IX2`E<P#4X>[I[>_LY^S=[><@R]_S].$`S_'CX>WI\^S\\@#4[-[LX2#/
M\>/A[>GS[._]`,_QX]SM^?/G`,'UZ.7M].GJ_"#P\?ST]?#O(.7VX?'L[^/>
M\@#!]>CE[?3IZMP@\/'\]/7PX2#S92`E<SH`P>OK[P#!Z^OE\B#0Z^?Q[_;O
M\=_E\@#%[N_U\^GOY._TWO/EZ?(@R>3I[^KTWO3G`,<@P?7HY>WTZ>KO\._?
MY_/G(%!!32#DY>T@Y=_MX>D@Y.GAZ-WSZ>SG+@#8Y_;IX>K>(-7P[^/QX?;>
M(%!'4`#*\?7P]._C\>'VY^S=[>$@Y.7D[^S=[>$@4$=0`,3G[/SSZ>\@RNOE
MZ>3?(%!'4`#5\._CY>/QX>SLW>WA+\KQ]?#T[^/QX?;G[-WMX2!01U`@Y.7D
M[^S=[>$`4$A0(,K^Y.GJX?(`4$A0(,K=Z_7V[_(`4$A0(,K=Z_7V[_(`P]WL
MZ?/LX0#*^>3IZOSR`,\@ZOGDZ>K\\B#<Z^OA[N4@X^GA(/3O[2#W\=[S].<@
M)7,@X?#\(/3O(//TX>CL_"`E<P#+W.CO\B#J^>3IZOSR`,'PX>GTY=_TX>D@
MZOGDZ>K\\B#CZ>$@X?7HY>WTZ>KO\._?Y_/G(%)!1$E54RX`ROGDZ>K\\B#L
MY2#E\.GBY>+AW_GSYP#*^>3IZOSR.@#*^>3IZOSR.B``SR#J^>3IZOSR(/#Q
MW?#EZ2#MX2#TX>GQZ=SFY>DN`,O?\_3A(-#E\>'S[-WM^>T@X^7C[^W\]/GM
M`,7PZ>K\Z^OG\^<`Q?#IZOSKZ^?SYR#A\/P@].\@8VQI<&)O87)D`,3IX>3Q
M[^S>`,7?\^_D[^D@\._U(.7JZO'E[._][3H`P>WH\?GP[^D`T._S[_/T_`#%
MZO3=Z^7SYR#+Y>GT[_7QX^G^[2#3]>WTWO'G\^?R`,7J]-WKY?/G(,OEZ?3O
M]?'CZ?[M(-/U[?3>\>?SY_(@ZN'TW"#TY^T@Y=_S[^3O.P#%[N_U\^GOY/ST
MY_/G`,7N[_7SZ>_D_/3G\^<@X^GA("<E<R<@Y.4@Y.GAX_'<]N?JY2X`Q.GA
M]^7?\>GSYR#%[N_U\^GOY._TWO/E^>T`Q>[O]?/I[^3O]-[SY>GR(./IX0#0
M\>_S^?#IZMWR(/#KY_'O]N_QW^7R`,KA]._IZM_DZ>$`U.?KW?;Y[>\`UOGT
M[^/QX?;?Y?(`Q>GJ[^WO\_3OZ??EW^$`RN_I[>_T]?#?Y?(`T.'QX>KAZ_X@
MZMSM].4@ZNOIZB#SY2#JW/#OZ>\@ZN7KWP#0X?'AZN'K_B#E\.GBY>+AZ?[S
M].4@_/3I(.C=Z^7TY2#MX2#DZ>'C\=SXY?3E(.'U]/P@].\@\_3OZ??EW^\Z
M`-#A\>'JX>O^(.7PZ>+EXN'I_O/TY2#\].D@Z-WKY?3E(.WA(.'P[_/U[>3=
M\^7TY2#A]?3\(/3O(//T[^GWY=_O+@#0X?'AZN'K_B#D_O/TY2#LWNWA(.KA
MZ2#=]._R+@#0X?'AZN'K_B#D_O/TY2#=[>$@_.WO[.$@X^GA(/3G(.W=X2#J
MX?3GX^_QW^$Z`-#A\>'JX>O^(.3^\_3E(.SIX2#=X^KU\><@25`@Y.GE_>CU
M[?/G+@#0X?'AZN'K_B#D_O/TY2#LZ>$@W>/J]?'G(.?LY?'O[.?MW^$L(.7K
MW>[TY2#T[^T@X?'IZ.S\(/3Y[2#G[.7Q_NT@]._U(.S>[>$N`-#A\>'JX>O^
M(.3^\_3E(-WCZO7QYR#^\>$N`-#A\>'JX>O^(.3^\_3E(/3O(.W=[R#J^>3I
MZOP@\^'R`-#A\>'JX>O^(.3^\_3E(.SIX2#PY?'?Z^?XYR#T[_4@\/'OXNO>
M[.'T[_(N`-#A\>'JX>O^(.3^\_3E(/3O[2#J^>3IZOP@\^'R`-#A\>'JX>O^
M(.3^\_3E(/3O(+SM[^SA(-?QWO/TYP#0X?'AZN'K_B#D_O/TY2#T[R#\[>_L
MX2#JX>D@]._M(.KYY.GJ_"#SX?(`T_7L\.OG\?[S].4@].\@_.WO[.$@]_'>
M\_3G(.SE(/3O[2#T[^S=X2`H0&5R;6ES+GED="D`T.'QX>KAZ_X@Y.GAXMSS
M].4@].\@X>K\Z^_UZ.\@ZN7?[.7O[2X@T/'=\.7I(.WA(//U[/;Y[>7?].4@
M[.4@]._U\B#\\>_U\B#CZ>$@[>$@]_'G\^GL[_#OZ=[SY?3E(.'U]/P@].\@
M\_WS].?LX2X`T.'QX>KAZ_X@Y.7?].4@].GR(.'J_.OO]>CE\B#PZ^?Q[_;O
M\=_E\B#JX>D@Y?#IZ]WN].4@[.GA(.7MW?'CY>GA(.'P_"#T[R#PX?'AZMST
M^2#LY>WO_2X`T.'QX>KAZ_X@Y?#IZ]WN].4@[.GA(.7MW?'CY>GA(.'P_"#T
M[R#PX?'AZMST^2#LY>WO_2X`T.'QX>KAZ_X@Y/[S].4@].\@_.WO[.$@].?R
M(.W=X?(@ZN'TY^/O\=_A\CH`T.'QX>KAZ_X@Y?#IXN7BX>G^\_3E(/3O(.W=
M[R#J^>3IZOP@\^'R`,C=\^<@X?7TWO(@].?R(.7IZOSMX?(`U._P[^CE]/[M
M].'R(.'U]/P@]._M(/#?[>'JX0#!\._S]._KWB#SY2#A]?3\(/3O(/;<ZN7K
M[R`HY.7M(/7P[_/TY_'?YN7TX>D@X?#\(/3O($E-05`I`,WA(/#Q[_3<\_/O
M[?3AZ2#D_>\@\.']Z^7R(/#QW^T@].?M(/7P[^/QX?;>(//A\B`H)RTM)RD[
M`,KA].'J\=[L[>GSYR#CZ>$@].GR(/3EZ^7U].'?Y?(@)7,@_O'A*.7R*3H@
M`%!R969S7VQD87`Z(,3E(.+QW>CGZN4@YR#A\.'I]._][.7MYR#E\-WJ].'S
MYR!,1$%0+@!0<F5F<U]S97-S:6]N.B#$Y2#B\=WHY^KE(.<@X?#AZ?3O_>SE
M[><@Y?#=ZO3A\^<@\_7MY>3QW^'R+@#0X?'O]?/IW//EZ?(`T-_E\^<`T-_E
M\^<@\_3O(.7PW_#EY.\@].?R(.C<Z^'S\^'R.B``T-_E\^<Z(`#0\>_E\.GS
MZOSPZ?/G`-#Q[^7PZ?/J_/#I\^<@].?R(.7IZOSM[^'R(//E(.W=[R#PX?'<
MZ/7Q[P#0\>_GX^_][.7MYR#3Y>O?Y.$`T/'OY^/O_>SE[>7R(,7PZ>OOX]WR
M`,7J]/WP^?/G(.7CX_'<]N_U`-#Q[_/Y\.GJ_"#*Z^7IY-\`T/'\XNOG[.$`
MT.7QZ>/QX?;>(-#Q[^+KWNSA]._R`+CQX^\@*'!R;VIE8W0I`,KEW^SE[>\@
M\/'O]/'O\-[R`,3G[/SSZ>\@RNOEZ>3?`,'KX_SQZ>CL[_(@Q.?L_//I[_4@
MRNOEZ>3I[_T`U.\@YN7]X^_R(,3G[/SSZ>_U+]#Q[_/Y\.GJ[_T@ZNOEZ>3I
M[_T@Y.4@Y.?LZ>_U\>/>Z.?JY2#E\.GT]??^\BX`Q?'^].?SYP#$Y^S\\^GO
M(,KKY>GDWR!24T$@*"5D($)I="D`Q?#IZ^_CWR#E[?SR`-3U]^'?X2#0\?SB
MZ^7XYP#+_./O\@#![=SC[?GSYP#![=SC[?GSYR#LY^W][.'T[_(`Q=_S].4@
MXMWBX>GO\B#CZ>$@].<@Y.GAX_'A]MX@)7,[(,'U]/P@Y.7M(.SP[_'EWR#M
MX2#E\.'MW>OHY>DN`,7?\_3E(//?X^_U\>_R(./IX2#TYR#DZ>'C\>'VWB#T
M^>T@Y.7D[^S=[?GM(/3O]2#W\=[S].<@)7,[(,'U]/P@Y.7M(.SP[_'EWR#M
MX2#E\.'MW>OHY>DN`,7PX>WEZO3=Z^7SYR#TY_(@].7KY?7TX=_A\B#E\>/A
M\]_A\B#SX?(`P>WA[=WY\^<@]/GM(.3U[>'LZ>K^[2#S]._I]^7?^>T@]._U
M(,SE[>_].@#![>'MW?GSYR#TY_(@Y>SVW.WI\^?R(/3O]2!0;W)T86PZ`,'M
MX>W=^?/G(/3G\B#0\>_B[^O>\B#0Y?'?Z^?XY_(Z`%)E9V5X`,7L]MSMZ?/G
M(-/WW?/E^>T`T_?\Z^GA`,'P[^SMY^S\[>7U\^<@\.OG\>_V[_'I_NT@Y.GA
MZ.7SZ>S\].?TX?(N`,'P[^SAZO'U\^S=[>_I(,7N]?#G\>7TY_3=\@#!\._L
MX>KQ]?/LW>WG(.3IY?WH]>WSYR`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`,'VX=_QY?/G`,'VX=_QY?/G(,SPZ_SJ`,'VX=_QY?/G(-/TWNOG
M\@#!]N'?\>7SYR#L[_'V[_#OW^?SY_(`P?;AW_'E\^<@X?#\(/3O(.?LY?'O
MZ_SCZ?P@[._U`,'VX=_QY?/G(.;E_>/O]?(`P?;AW_'E\^<@X?#OZ.?JY?7L
MW>WO]2!S8W)I<'0@X?#\(/3O[2#P\>_S^?'I[?P@ZN'TW.OOX^\@]._U(.7N
M]?#G\>7TY_3>+@#!]N'?\>7SYR#T[_4`P?;AW_'E\^<@X?7T[_T@]._U(.K\
M[.+O]2#A\/P@].\@W>/C\>'V[P#$Z>'C\>'VWB#W\=[S].<`Q.GAX_'A]MX@
MU_'>\_3G.B`E<P#3]-SKZ.?JY2#!\-SM].?SYRX`P?#<[?3G\^<@[.4@S,<@
M]?#O\_3G\>GF_.SE[>\@[-[M]>SA+@#!\-SM].?SYR#LY2#PZ^?Q[_;O\=_E
M\B#DZ>'HY?/I[/STY_3A\B#CZ>$@]._U\B#E\/SLY>WO]?(@Y/WO(.S>[>7R
M+@#!\-SM].?SYR#LY2#TZ?(@YN?T[_WLY>WE\B#PZ^?Q[_;O\=_E\B#DZ>'H
MY?/I[/STY_3A\BX`P?#<[?3G\^<Z("5S`-3O(.'?].?LX2#DY2#L\._QY=\@
M[>$@X?#A[?3GZ.7?+B#%\.GS]/'E]OSLY>WO\B#J^>3IZOSR(.O<Z._U\CH@
M`-3O(.'PX>GT[_WLY>WO("<E<R<@Y.7M(.KAZ._QW_/HY^KE(//T[R`E<R!C
M;VYF:6=U<F%T:6]N+@#4[R#A\.'I]._][.7M[R`G)7,G(.3E[2#JX>CO\=_S
MZ.?JY2#S].\@5D93(&-O;F9I9W5R871I;VXN`-3O(.'PX>GT[_WLY>WO("<E
M<R<@Y.7M(.KAZ._QW_/HY^KE(//T[R!C;VYF:6=U<F%T:6]N+@#4[R#A\.'I
M]._][.7M[R`G8F%S961N)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=B87-E
M9&XG(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q
M[_3I[-[SY?GM+@#4[R#A\.'I]._][.7M[R`G9&%T86)A<V4G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@X?7HY>WTZ>KO\._?Y_/G\BX`
MU.\@X?#AZ?3O_>SE[>\@)V1A=&%B87-E)R#DY>T@W??EZ2#JX>CO\>GS].7?
M(//TZ?(@\?7H[-_SY>GR(.KA].?C[_'I_NTN`-3O(.'PX>GT[_WLY>WO("=D
M871A8F%S92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#T
M^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WLY>WO("=H;W-T<W!E8R<@Y.7M
M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P[]_G
M\^?R+@#4[R#A\.'I]._][.7M[R`G:&]S='-P96,G(.3E[2#=]^7I(.KAZ._Q
MZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#AZ?3O_>SE
M[>\@)VAO<W1S<&5C)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_S
MY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W!A<W-W;W)D
M)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H[-_SY>GR(.'UZ.7M].GJ
M[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=P87-S=V]R9"<@Y.7M(-WWY>D@
MZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+@#4[R#A\.'I
M]._][.7M[R`G<&%S<W=O<F0G(.3E[2#=]^7I(.KAZ._QZ?/TY=\@\_3I\B#Q
M]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#4[R#A\.'I]._][.7M[R`G<&AP
M='EP92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE
M[?3IZN_P[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G<&AP='EP92<@Y.7M(-WW
MY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3GX^_QZ?[M+@#4[R#A
M\.'I]._][.7M[R`G<&AP='EP92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR
M(/'UZ.S?\^7I\B#T^>T@\/'O].GLWO/E^>TN`-3O(.'PX>GT[_WLY>WO("=T
M86)L92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE
M[?3IZN_P[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G=&%B;&4G(.3E[2#=]^7I
M(.KAZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@ZN'TY^/O\>G^[2X`U.\@X?#A
MZ?3O_>SE[>\@)W1A8FQE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O_>SE[>\@)W5I9"<@
MY.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#A]>CE[?3IZN_P
M[]_G\^?R+@#4[R#A\.'I]._][.7M[R`G=6ED)R#DY>T@W??EZ2#JX>CO\>GS
M].7?(//TZ?(@\?7H[-_SY>GR(/3Y[2#P\>_TZ>S>\^7Y[2X`U.\@X?#AZ?3O
M_>SE[>\@)W5S97)N86UE)R#DY>T@W??EZ2#JX>CO\>GS].7?(//TZ?(@\?7H
M[-_SY>GR(.'UZ.7M].GJ[_#OW^?SY_(N`-3O(.'PX>GT[_WLY>WO("=U<V5R
M;F%M92<@Y.7M(-WWY>D@ZN'H[_'I\_3EWR#S].GR(/'UZ.S?\^7I\B#JX?3G
MX^_QZ?[M+@#4[R#A\.'I]._][.7M[R`G=7-E<FYA;64G(.3E[2#=]^7I(.KA
MZ._QZ?/TY=\@\_3I\B#Q]>CLW_/EZ?(@]/GM(/#Q[_3I[-[SY?GM+@#!\.'I
M]._][.7M[R#0Y>3?[P#!\.'I]._][.7M[_(@T_7L[.7TW??Y[0#%\.'MX?;O
M\=P`P>OKX>/>(,KYY.GJ[_T`P>OKW.[TY2#T[^T@ROGDZ>K\(//A\@#!\._T
MY>O=\^SA].$`Q?#I\_3Q[_;>(//TZ?(@Q?#IZ^_CW?(`Q?#I\_3Q[_;>(//T
MY^T@X>OKY^OOX_'A]M_A`,7PX>W=[?GSYP#%\.'MX?;O\=P@0V]N9FEG=7)A
M=&EO;@#!Y?'OZ^GLW>WA\B#1_.3O]0#%\.GK[^/=\B#E\.7NY?'CX?/TWB#E
M[/#K[_7TZ?/LW>WO]2#JY>GLW>WO]0#!Z>W?X^SA].$`Q.7NZ=P`Q.7NZ=P@
MY?#IZN7VX>O?Y.$`Q.7NZ=WR(/3I[-WR`,GDZ?STY_3E\B#C\>'L[-[R+BXN
M`-'\Z^_R`-#E\>GS]/'O]MX@,3@PL`#0Y?'I\_3Q[_;>(,'QZ?/TY?'<`-#E
M\>GS]/'O]MX@Q.7NZ=P`R>3I_/3G].7R(,/QX>SLWO(`R>3I_/3G].7R(,/Q
MX>SLWO(`P_'A[.S=\CH`RN'M_.WE\@#/Z2#JX>W\[>7R(.CA(.7L]N'MW^;O
M[?3AZ2#LY?3A[OT@_.OY[2#T^>T@X_'A[.S^[2#JX>D@]/GM(//TY^O^[0#/
MZ2#JX>W\[>7R(.CA(.7L]N'MW^;O[?3AZ2#LY?3A[OT@]/GM(//TY^O^[2#L
M_.WO`,_I(.KA[?SMY?(@Z.$@Y>SVX>W?YN_M].'I(.SE].'N_2#T^>T@X_'A
M[.S^[2#L_.WO`,7J]-WKY?/G`-7P[^/QX?;>(,KQ]?#T[^/QW/;G\^?R(%,O
M34E-10#*\?7P]._C\>'VY^S=[>\@[-[M]>SA(%,O34E-10#'(.'UZ.7M].GJ
M[_#OW^?SYR!305-,(.3E[2#EW^WAZ2#DZ>'HW?/I[.<N`,SG[?WLX?3A(%--
M4P!344P@RMWK]?;O\@#%T,G4U=?9TP!37U%,(,K=Z_7V[_(`T^$`NN3I[R#P
MZ^'?\^GO("A?<V5L9BD`P>7Q[^OI[-WMX?(@T]SL[_4`T-SQ[_?O\B#$[_'U
M]OSQ[_4`P?#OZ-[JY?7SYP#!\._HWNKE]?/G("5S`,'P[^C>ZN7U\^<@)R5S
M)P#!\._HWNKE]?/G(,7PZ>OOX_[M`,'P[^C>ZN7U\^<@]._U(&-O;F9I9W5R
M871I;VX@\._U(.3G[.GO]?'CWNCGZN4@\^'M(%!(4"!38W)I<'0@\_3O[2#P
M\>_S^?'I[?P@ZN'TW.OOX^\@]._U(.7N]?#G\>7TY_3>+@#!\._HY^KE]>S=
M[>\@)7,@8V]N9FEG=7)A=&EO;BX`U.\@<V-R:7!T(.7MY^S=\?GSY_(@].\@
M<V5T=7`@X?#OZ.?JY?WHY^KE(//T[SH@)R5S)RX`Q?#I\_3>[.<`P>WAYM[T
MY_/G`,SG]^'MW?(@P>WAYM[TY_/G\@#![>'FWO3G\^<@S.?M]>S<]/GM`,'P
M[_3EZ]WS[.'TX2#![>'FWO3G\^?R`,7PZ>OOX]X@P?'WY=_Y[0#%\.GKW>[T
MY2#LZ>$@Y^SE\>_LY^W?X0#%\.GKW>[TY2#O[-SDX2#CZ>$@\/'O\^C>ZN<`
MQ?#IZ]WN].4@[=WO(,GDZ>_J]-[TYP#%\.GKW>[TY2#E[O7PY_'E].?TW@#%
M\.GKW>[TY2#W\=[S].<@X^GA(/#Q[_/HWNKG`,7PZ>OOX]X@_.OY[2#T^>T@
MY^SE\>_LY^WI_NTN`,7PZ>OOX]X@Y>W\\B#A[?3IZN7I[-WM[_4`Q?#IZ]WN
M].4@]._U\B#WX?'AZO3>\>7R(/#O]2#HW>OE].4@X?#\(/3I\B#PX?'AZMST
M^2#KW_/TY?(N(,KA]/SPZ>WL\._QY=_TY2#MX2#TX2#A[?3IX_'<^.7TY2#J
MX>D@[>$@].$@Y?#IZN_KZ][SY?3E(//T[R#LWNWU[.$@\^'R+@#%\.GK[^/>
M(/3O]2#DZ>'W^?'I\_3>(.?LY?'O[.?MW^'R.@#%\.GK[^/>(/3G\B#L[_'V
MWO(@\._U(.CA(-WWY>D@YR#G[.7Q[^SG[=_A.@#%\.GKW>[TY2#TYR#TX?7T
M_/3G].$@\._U(.C=Z^7TY2#MX2#AZ^O<[N7TY3H`Q?#IZ]WN].4@].\@Y.GA
M]_GQZ?/TWB#^\>'R.@#%\.GKW>[TY2#TYR#L[_'VWB#P[_4@Z.$@W??EZ2#G
M(/[QX3H`Q?#IZ]WN].4@Y/WO(/#EY-_A(/#O]2#TX>GQZ=SF[_7M+@#%\.GK
MW>[TY2#T[R#W\?GLX?3IZOP@)_/WWNSA)RX`Q?#IZ]WN].4@].<@X^O^\_/A
M(//A\CH`P?#O\_3OZ]X@]/GM(/#I[R#P\?SS]N'T^>T@\.OG\>_V[_'I_NT`
MP?#O\_3OZ]X@P>WA]N_QW/(@T/'OXNO>[.'T[_(`P?#O\_3OZ]X@4TU3`,'I
M\^CG]-[QX?(Z(`#3Y?#TW>SB\>GO\@#3Y>GQZ>'J_/(@P?'IZ.S\\@#4[R!)
M1"#TY_(@\_WMY.7SY_(@W>OG[N4N`,C=\^4`R-WS].4@Y?#IZ^_CW?(@\._U
M(.CA(//A\B#E\.GT\=WP[_7M(.WA(.'KZ]SFY?3E(/3O[2#J^>3IZOP@\^'R
M+"#AZOSLYR#JX>D@X>T@]._M(-WWY?3E(.[E]]SSY>DN`-#A\>'LY?3Q[_#O
MW^?SYR#A\._LX>KQ]?/LW>WY[2#E[O7PY_'E].?T_NT@\._U(.C=Z^7TY2#P
M\?SSXN'SYRX`T?7H[-_S].4@Y.G<]N_QY?(@Y?#IZ^_CW?(@Y>SVW.WI\^?R
M(.KAZ2#T[R#W\?SM[R#A[>'MW?GSY_(@]/GM(//EZ]_D^>TN`,7PZ>OOX]X@
M].?R(/#Q[_3I[._][.7MY_(@X^O^\_/A\BX`RN'H[_'?\_3E(/3G[2#P\>_T
MZ>S^[.7MYR#CZ_[S\^$L(.;^[><@_O'A\B#JX>D@[._Q]MX@Y^SE\>_LY^W?
MX?(N`,KAZ._QW_/TY2#TY^T@Y?;A\>SOX]X@Y>KJW^WG\^?R+"#TX2#P\>_T
MZ>S^[.7MX2#W\?[LX?3A+"#TYR#PY?'?[^3O(.'MX>W=^?/G\B#TY_(@\^7K
MW^3A\B#JX>D@W.OKY?(@Y?#IZ^_CW?(@Y>SVW.WI\^?R+@#1_>CLZ?/G`,7?
M[>'I(.3IX>C=\^GLX2!38W)I<'1S(.7MY^S=\?GSY_(@\?7H[-_SY?GM`-#O
MZ^O=\B#T[_#OZ.7SW^7R(.7?[>'I(/#IZ.'MW?(@[.4@X?7TWB#TYR#PX?'<
M[.7T\>\Z(`#!X^_QW?(`T_WM]._LYR#0Y?'?Z^?XYP#3_>WT[^SG(-#E\=_K
MY_CG.@#0\=WPY>D@].\@ZNOEZ>3?(/#Q_//BX?/G\B#MX2#O\>GSZ.7?(./I
MX2#PY?'I\_/\].7QY?(@\_7MY-WSY>GR.P#%[/;<[>GSYP#%[/;<[>GSYR#D
MZ>'V[_'^[2#LY?3A[OT@]._U(.'P[^CGZN7U[-WM[_4@ZN'I(/3O]2#DY^SI
M[_7QX^?HW>WT[_(@8V]N9FEG=7)A=&EO;BX`Q>SVW.WI\^<@].?R(/[QX?(@
M].7KY?7TX=_A\B#EZ?/\Y._U(/STX>T@[/#AW^WO]>SE(//T[R#S_?/TY^SA
M.P#%[/;<[>GSYR#E\.GK[^/>\B#CZ>$@X?#OZ-[JY?7SYR#T[_4@X?7HY>WT
MZ>KO_0#%[/;<[>GSYR#S]>OKW>KTYP#-X2#E[/;A[=_FY?3AZ2#T[R#LY>WO
M_2#LY2#E\>/A\]_E\B#PW^WAZN$[`,7L]MSMZ?/G(/3O]2`E<R#,Y>WO_2#S
M].$@X?'I\_3E\=P[`,7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@
MRN7KZ?[M(-#?[>'JX0#%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM
M(-#?[>'JX0#%[/;<[>GSYR#T[_4@Y.GAZ_SC[_4@R>3I[_3>]/GM(,/QX>SL
M_NT@T-_MX>KA`,7L]MSMZ?/G(/3O]2#DZ>'K_./O]2#)Y.GO]-[T^>T@Q>GJ
M_.WA\@#%[/;<[>GSYR#V_/'T^?/G\B`H=7!L;V%D*0#3]?'QW^KM^?/G`-#Q
M_O3A(//U\?'?ZNWY\^<@WB#LY?3AZM_MY_/G(./EZ?3O[>GJ_NT@].SG[-ST
M^>T`Q=_S[^3O\BW5\._C\>'VW@#'(,7?\^_D[_(MU?#OX_'A]MX@Y.7M(-WW
MY>D@ZN'TX??Y\>?HY=\N`-7P[^/QX?;>`,'KX_SQZ>CL[_(@U?#OX_'A]M[R
M`,S=X^7H[_(`P>K]\?GSYR#3]>WTWO'G\^?R`,SE\>GJW"#A\/P@].$@X?'W
MY=_A(.3IX??EW_'I\^?R(/3O]2!(;W)D92#=]^_U[2#WX>CEWSH`Q?#IZ^_C
MWB#JX?3E_>CU[?/G\B#TX>[I[?SLY_/G\@#!Y?'OZ^GLW>WA\B#3[_WDX?(`
MQ.GE_>CU[?/G(-#GX][R`,W\].GO(,?LZ?/VX=_QZ>\`Q.G<\_3G[.$@[.7T
MX>[](./EZ?3O[>GJ_NT@ZN7KZ?[M`,3IW//TY^SA(.SE].'N_2#PY?'IY??O
M[-WM[_4@ZN'I(./QX>SLWO(@ZN7KZ?[M`-#KWNKT\>\@Q.GA\_3>[.'T[_(`
MP?'AW_GSYP#!\>'?^?/G(.KAZ2#CW>SI\^SA`%-P86T`Q>GSX>/YX]X@Q>GD
MZ>K^[2#7X?'AZO3>\?GM`,3IX=_QY?/G(.KEZ^GO_0#$Z>'?\>7SYR#S]-[K
MY_(`Q.GAW_'E\^<@X_'A[.S>\@#!Z.O>[.'TX0"X[>'Q[N<`N/3O\B"X[>'Q
M[N?R`-#OZ^GTY=_A(-X@Q?#A\???X0#*X?3<\_3A\^<`S._Q]MX@X?#OZ-[J
MY?7SY_(`Q.GE_>CU[?/G+<_D_/(`Q.GAX_'A[.SI\^S=[>$`R]_S].$@Z]WN
MY?GM`,'VX=_QY?/G(/3O]2!D;VUA:6X@X?#\(/3G(.3IY?WH]>WSYP#3]/WK
M(%M#4U-=`,KU`,\@]?#O]MSJY>OO\B`G)7,G(.3E(.+QW>CGZN4N`,C=[.$`
MR-WLX2`GT.OG\>_V[_'?Y?(@Q.?L_//I[_4@RNOEZ>3I[_TG`,'P[_/T[^O>
M`-3O(.'?].?LX2#CZ>$@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?LX2#A\.7S
M]-SKYRX@Q.4@[/#O\>7?].4@[>$@[N'MX>SPY=_TY2#LW??QZ2#MX2#EX^KQ
MZ>CEWR#T[R#AW_3G[-P@\^'R+@#5\._DY=_J].?R`,7PZ?3U]]_A`,7PZ?3U
M]][R(/#Q[_/HWNKG("<E<R<@\_3O(//]\_3G[.$N`-3A(.3EY._LW>WA(/3O
M]2#W\=[S].<@)R5S)R#DZ>'C\=SVY^KA[2#E\.GT]??^\B#A\/P@].\@\_WS
M].?LX2X`Q?#I]/7WWO(@Y.GAX_'A]MX@)R5S)RX`Q?#I]/7WWO(@Y.GAX_'A
M]MX@)R5S)R#A\/P@].\@\_WS].?LX2X`S^D@\?7H[-_SY>GR(.7PX>WA]MWQ
MZ.?JX>T@Y?#I]/7W_O(N(,K<[?3E(.7PX>WA]OSQ]/GSYR#CZ>$@[>$@Y.7?
M].4@].GR(.'KZ^'CW?(N`,7PZ?3U]][R(.7P[^C>ZN7U\^<@Y?;EY/'IZN_]
M(&-O;F9I9W5R871I;VXN`,7PZ?3U]][R(.'P[^C>ZN7U\^<@]._U(.7VY>3Q
MZ>KO_2#A\??EW^_U(&-O;F9I9W5R871I;VX@)7,N`,7PZ?3U]][R(.7MY^S=
M\?GSYR`G)7,G`,7PZ?3U]][R(.7CX_'A]MX@)7,`T_WM[_CG("T@T.7QW^OG
M^.<`P>WA]._KW@#$_?/G`,'MX?3OZ]X`P>WA]._KWB_$_?/G`,'MX?3OZ]XZ
M(`#$_?/G`,3]\^<Z(`#5\.7QY.7?ZO3E\@#5\._S]-[QZ>[G`,7PW^CE].\`
MU.\@X?'WY=_O(.KA].'C\>'VWO(@\_7C]_'O[>GS[._](.3IX>/QW/;GZN4`
M4WEN8TU,`,O<Z._R(//][?3A[N?R(//T[_7R(/SQ[_7R(.'MX>;>].?SY_(`
MT-_MX>KA\@#)Y.G\].?TY?(@T-_MX>KA`,GDZ?STY_3E\B#0W^WAZN$`P>7Q
M[^OI[-WMX?(@U.'MW./QX?(`T_3\]^_R.@#%\>/A\]_E\@#!Y?'OZ^GLW>WA
M\B#4X?3O^N_U`,'QZ>CL_/(@U.?KY?;^[>_U`,CE\>SOZO'A\]_A(/3G[2#T
MY>OE]?3AW^$@_O'A.B``R.7Q[._J\>'SW^$`R.7Q[._J\>'SW^$Z(`#4[R#P
M\?ST]?#O("<E<R<@Y.4@XO'=Z.?JY2X`Q.GA]^7?\>GSYR#0\>_T_?#O]0#0
M\>_S^?'I[=X@P?#OY._WWB#AZ?3>[.'T[_(`T/'O\_GQZ>W<(,'P[^3EZO3\
M`,KEW^SE[>\`S/SM[R#*Y=_LY>WO`-/T[]_WY_/G(.KEZ>S=[>_U`,KO\?7V
MWB#JY>GLW>WO]0#4Y0#%]??A\>GS]._][.4@\._U(/?QY_/I[._P[^G>\^'T
MY2#T[R#3_?/TY^S<(.SA\BX`QR#E\-WJ].'SYR!&5%`@Y.7M(.7?[>'I(.'J
M_.SG(.3IX>C=\^GLYRX`U.\@\_WS].?LX2!(;W)D92]+;VQA8B#DY>T@]?#O
M\_3G\=_FY>D@(B5S(@#$Z>'WY=_QZ?/G.CH@QR#JZ]SSYR#DY2#V[_'T_NCG
MZN4@Y?#I]/7W_O(`U.\@\.'QW.CU\>\@Y?#IZ^_C_NT@W>KKY>GSY2X@N.[O
MY._R+@#/(.3IX??EZ?'I\_3>\B#P\=WPY>D@[>$@\?7H[-_SY>D@W>WA(.S\
M[>GL[R#PZ^'?\^GO(,7N[_7SZ>_D[_3>\^7Y[2P@X^GA(.WA(.SP[_'EW_3E
M(.WA(/?QY_/I[._P[^G>\^7TY2#E[N_U\^GOY._TWO/EZ?(N`,<@ZMST^2#P
MZ^7U\=P@[/SM[P#4X2#DY>3O[-WMX2#G[.7Q[^OOX]_O]2#DY>T@Y=_MX>D@
MW>/J]?'A`-3O($E$(/3G\B#E\.'VWO(@Y.7M(.KAZ._QW_/HY^KE+"#>].'M
M(.KE[?P@WB#DY2#B\=WHY^KE(//TYR#BW//G(.3EY._LW>WY[2X`QR#E\.'V
MWB#P\>_S]-WHY^KE(.7PZ?3U]_[R(//T[R#$Z>7UZ/7M\^GOX_'<]N\@\^'R
M+@#4[R#T[-[LX2!01U`@\._U(.'P[_/PW//HY^KE(.'PX>GTY=_T[R#CZ>$@
M].?M(.7PX>O>Z.7U\^<@]._U(/7P[^/EX_'A[.S=[>_U(.SG[=[LX?3O\BX`
MU.\@240@].?R(.O?\_3A\B#DZ>'M[^S>\B#DY>T@[_'?\^CGZN4L(-[TX>T@
MZN7M_"#>(.3E(.+QW>CGZN4@\_3G(.+<\^<@Y.7D[^S=[?GM+@#'(.O?\_3A
M(.3IX>WO[-[R(.3E[2#JX>CO\=_SZ.?JY2X`S^D@Y/7MX?3\].?TY?(@ZO'U
M\/3OX_'<]N?SY_(@X?#AZ?3O_>T@X?/VX>O>(//][>3E\^<@5T5"+@#4[R#C
MY>/O[?SR(/#Q[_/TW>CGZN4@\_3O(.?LY?'OZ_SCZ?P@\^'R+@#4[R#A\??E
MW^\@)7,@\/'=\.7I(.WA(/#E\>G=]^7I(.SIX2`E<R#Q_>CLZ?/G+@#4[R#A
M\??EW^\@)7,@\/'=\.7I(.WA(/#E\>G=]^7I(.K<\._IY?(@)7,@\?7H[-_S
MY>GR+@#4[R#A\??EW^\@Y.4@[/#O\>7?(.WA(.'M].GC\>'VY=\@\_3O[2#E
MX?7T_"#T[_4N`-3O(.'Q]^7?[R#DY>T@\.7QZ=WWY>D@Y.7D[^S=[>$N`-3A
M(/#A\>'JW/3Y(.7?[>'I(.7PZ>KE]N'KW^3E\B#CZ>$@X?7T_"#T[R#LWNWU
M[.$O<F9C.#(R(.S>[?7LX2X`QR#JX?3<\_3A\^<@\.O>\>_U\B#OZ/SMY_(@
MY=_MX>D@X^WY\_3\(/STZ2#DY^SI[_7QX^7?(/#Q_.+KY^SA(.SE(/3O[2!)
M;G1E<FYE="!%>'!L;W)E<BP@Y>[AZ?3?X?(@\/'OXNOG[-ST^>T@*&)U9W,I
M(/3O]2!B<F]W<V5R+"#TX2#O\._?X2#DY>T@Y=_AZ2#D]>WA]/P@[>$@[N7P
MY?'A\^CO_>TN(,SP[_'EWR#MX2#DY=_TY2`G\^KO]?#?Y.GA)R#S].?M(._H
M_.WG+"#P\>_BZ][LX?3A(//TYR#KY>GT[_7QX]_A(/3O]2!B<F]W<V5R(-X@
MZN'I(.K\Z^?LW"#T[_4N(,'M(/3O(//]\_3G[-P@\^'R(.7?[>'I(%=I;F1O
M=R`Y>"#EW^WAZ2#P[^O](/#IZ.'M_"#MX2#DY=_TY2`GP^7MZ>K>(,'P[_3U
M]]_A(-#Q[_/TX?/?X?(G(.KAZ2#MX2#P\=WPY>D@[>$@Y?#A[>7JZNGMWO/E
M].4@*')E8F]O="DN7&Y<P?7TWB#EW^WAZ2#P\>_EZ>3O\._?Y_/G+B#0X?3>
M\_3E(,_*(.'M(.C=Z^7TY2#AZOSLYR#MX2#D[_7KW?CE].4@\^4@ZN'TW//T
MX?/G(/#KWO'O]?(@[^C\[>?R+@#'(/3A]?3\].?TX2`B)7,B(.3IX>/QW/;G
MZN4N`,<@X?'I\_3E\=X@\.OE]?'<(.S\[>\`QR#HW?/G(/3O]2#P\>_C\=SL
M[.'T[_(@1VYU4$<@\/'=\.7I(.WA(.3OZ.7?(./IX2#TYR!#<GEP=%]P9W`Z
M.B#JZ]SSYRX`QR#C\>'L[.'T[^CU\=_DX2`GZMSD[_(G(.7?[>'I(-[DYR#<
MY.7IX2X`U.\@[-[M]>SA(/#O]2#S]-SKZ.?JY2#S].GR("5S(//T[^T@)7,@
M[.4@Z-WLX2`E<R#E[/;A[=_SZ.?JY2X*P?7T_"#DY>T@X?#O].7KY=\@Y?#I
MXN7BX=_Y\^<@_/3I(.3IX>+<\^CGZN4@ZN'I(-WCZ>WE(.KA].'M[^?T_"X`
MU.\@_.WO[.$@\._U(.CA(/?QY_/I[._P[^GEW_3AZ2#\].'M(//U[>3=Y?/T
MY2#S].<@\^7KW^3A(//][>CE\^?R+@#'(.+IXNOI[^C>ZN<@3W!E;E-33"#A
M\.'I].7?].'I(./IX2!(;W)D95]#<GEP=%]S;6EM93HZ(.KKW//G+@#'(/#Q
M[_3?[.?SYR`B)7,B(.3E[2#L\/SQY?/E(.WA(.'P[^CGZN7UZ.7?(./IX?3?
M(/3A(.3EY._LW>WA(/3G\B#U\.7QXN'?[>_U[2#T[R#LW>/I\_3O(.7PZ?3Q
MY?#T_"#LW>/EZ._R`-3O(/#Q_./QX>SLX2#P[_4@]_'G\^GL[_#OZ>7?].4@
MX^GA(/3G[2#E[/;<[>GSYR#A]?3O_2#T[_4@Y=_D[_7R(.SG[?7LW/3Y[2`H
M)7,I(.3E[2#B\=WHY^KE(//T[R#S_?/TY^SA+@#'(')E9VES=')Y(.7?[>'I
M(.\@]/'\\._R(.SE(/3O[2#O\._?[R#OZ2#E]N'Q[._CW?(@]._U($AO<F1E
M(.7PZ>KOZ>WY[>_][2X@[.7TX>[](/3O]?(N(,7D_B#P\=WPY>D@[>$@X_'<
M^.7TY2#\].D@Y?;A\>SOX]WR(/3O]2!(;W)D92#=]^7TY2#EX^KA].'S]-[S
MY>DN`,<@X?'I\_3E\=X@ZN'I(.3E[NG<(/#KY?7QW?(@[/SM[P#'(.3E[NG<
M(/#KY?7QW"#L_.WO`,\@Y>[U\.?QY?3G]-[R("(E<R(@Y.GAX_'<Y^KE+@#/
M(.7N]?#G\>7TWO(@(B5S(B#A\._HY^KE_>CGZN4N`-3O(.'?].?LX2#EZ?/\
MY._U(./IX2`E<R#DZ>'C\=SVY^KE+@#'(./QX>SLWB#P[_4@[_'?\^'TY2#D
MY>T@]?#<\??EZ2X`QR#E\>/A\]_A(/#Q[_/TW>CGZN4@\_3G(.O?\_3A(.7Q
MX^'SZ?[M(//A\BX`U.\@\/'O\_GQZ>W\(.'Q]^7?[R`B)7,B(.3E[2#U\-SQ
M]^7I+@#'(/#<[?D@ZN'I(.K<]/D@\.OE]?'=\B#L_.WO`,<@\-SM^2#PZ^7U
M\=P@[/SM[P#4X2#DY>3O[-WMX2#P[_4@\_3=Z^WA].4@]]SHY^KA[2#A\/P@
M].\@\/'OY^/O_>SE[>\@XM[LX2X`U.\@X?'WY=_O(/#O]2#S].7?Z^'TY2#D
MY2#L\/SQY?/E(.WA(//YZ.7?+@#/Z2#PZ^?Q[_;O\=_E\B#DZ>'HY?/I[/ST
MY_3A\B#A\._HY^KE_>CGZN'M(.7PZ?3U]_[R+@#/(.KA]-SK[^/O\B#HY>S<
M]/GM("<E<R<@Y.4@XO'=Z.?JY2X`Q.7M(/7PW/'W[_7M(,7PZ>OOX]WR(.3I
MX>C=\^GLY?(N`,3E[2#U\-SQ]^_U[2#T[-[LX?3A(/#O]2#DY2#L\._Q[_WM
M(.WA(.7L]N'MZ?/H[_WM(.7M\_GLX?3Y[-WMX2X`U?#<\??O]>T@\._KZ^_?
M(/?A\>'J]-[QY?(@\^4@X?7T_"#T[R#PY>3?[RX@Q>GSX>/<X^'TY2`E<R#W
MX?'AZO3>\>7R+"#P\=WPY>D@[>$@]?#<\??O]>T@Z^GC_/3E\>_I(.'P_"`E
M<RX`T/'\XNOG[.$@ZN'TW"#TY^T@\/'O\^C>ZN<@)R5S)R#S].\@\_WS].?L
MX2X@)7,N`-#Q_.+KY^SA(.KA]-P@].?M(/#Q[_/HWNKG("<E<R<@\_3O(//]
M\_3G[.$Z("5S+@#0\?SBZ^?LX2#JX?3<(/3G(.3IX>/QX?;>(.3EY._LW>WY
M[2#T[_4@]_'>\_3G("<E<R<@X?#\(/3O(//]\_3G[.$Z(`#0\?SBZ^?LX2#J
MX?3<(/3G(.3IX>/QX?;>("<E<R<@X?#\(/3O(//]\_3G[.$Z(`#0\?SBZ^?L
MX2#JX?3<(/3G[2#E[>?LW?'Y\^<@)R5S)SH@)7,`T/'\XNOG[.$@ZN'TW"#T
MY^T@X?#O\_3OZ]X@X?'WY=_O]3H@Q.7M(//TW.OHY^KE("5S+@#0X?'O]?/I
MW//HY^KE(/#Q_.+KY^SA(.KA]-P@].?M(.'P[_/T[^O>(/3O]2#A\??EW^_U
M.B#4[R`E<R#EW^WAZ2#LY>/AZ_WTY?'O(.'P_"#T[R#LW>/I\_3O(.7PZ?3Q
MY?#\[.7M[R#LW>/EZ._R("@E9"!">71E<RDN`-#A\>_U\^G<\^CGZN4@\/'\
MXNOG[.$@ZN'TW"#TY^T@X?#O\_3OZ]X@]._U(.'Q]^7?[_4Z(-/TW.OHY^KE
M(.S\[>\@W>WA(/3LWNSA(/3O]2`E<RX`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@
MZN'TW"#TY^T@Y>SVW.WI\^<@X?7T[_T@]._U(/3LWNSA]._R(/3O]2#LY^W]
M[.'T[_(N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(.KA]-P@].?M(.7I\^'C^>/>
M(.3EY._LW>WY[2#$Z>7UZ/7M\^GOX_'<]N_U+@#0X?'O]?/IW//HY^KE(//V
MW.OLX2#JX?3<(/3G[2#EZ?/AX_GCWB#T[_4@X^7C[^WO]._R.B`E<RX`T.'Q
M[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>GSX>/YX]X@Y.7D[^S=[?GM
M(.?LY?'OZ^_CW^_U+@#0X?'O]?/IW//HY^KE(//VW.OLX2#JX?3<(/3G[2#E
MZ?/AX_GCWB#TY_(@Y?'CX?/?X?(Z("5S+@#0X?'O]?/IW//HY^KE(//VW.OL
MX2#JX?3<(/3G[2#EZ?/AX_GCWB#PZ^?Q[_;O\>G^[2#DZ>'HY?/I[/STY_3A
M\CH@)7,N`-#A\>_U\^G<\^CGZN4@\_;<Z^SA(//TYR#V_/'LX2#Q]>CLW_/E
M^>TN(+KS^?(@X?;>\^'TY2#JY>W\(.K<\._I[R#A\.'I]._][.7M[R#PY>3?
M[RX`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@\_3G[2#EZO3=Z^7SYR#TY_(@ZN'H
M[_'I\^S=[>?R(.OEZ?3O]?'CW^'R(/3O]2#$Z>7UZ/7M\^GOX_'<]N_U+B#0
MX?'AZN'K_B#D[^KI[-SS].4@X?'C_/3E\>$N`$)E:2!D97(@06MT=6%L:7-I
M97)U;F<@9&5R($MO;G1A:W1D971A:6QS(&ES="!E:6X@1F5H;&5R(&%U9F=E
M=')E=&5N+B!":71T92!V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I
M;FUA;"X`T.'Q[_7SZ=SSZ.?JY2#S]MSK[.$@ZN'TW"#TY^T@Y>WG[-WQ^?/G
M(/3G\B#KW_/TX?(@Y.GA[>_LWO(N(-#A\>'JX>O^(.3OZNGLW//TY2#A\>/\
M].7QX2X`P>7Q[^OI[-WMX?(@R.7S\^'K[^W?ZN?R`,\@Y>[U\.?QY?3G]-[R
M($E-05`@Y.7M(/7P[_/TY_'?YN7I(.KOZ>W\]_'G\_3O]?(@]N'JW>OO]?(N
M`,'U]-X@YR#E[=WQX^7IX2#DY>T@]?#O\_3G\=_FY?3AZ2X`P?7TWB#G(.OE
MZ?3O]?'CW^$@Y.7M(-WWY>D@[^OOZNOG\?GHY=\@X>K\[.<N`,'U]/P@Y.4@
M]N'?[>7TX>D@[>$@Y=_MX>D@W>/J]?'O(.'Q]^7?[R!R87(N`,'U]/P@Y.4@
M]N'?[>7TX>D@[>$@Y=_MX>D@W>/J]?'O(.'Q]^7?[R!Z:7`N`,'U]/P@Y.4@
M]N'?[>7TX>D@[>$@Y=_MX>D@W>/J]?'O\B#A\>GH[/SR(.K<\?3A\BX`P?7T
M_/(@[R#OY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W][.'T
MX2#LW?/Y($-L:6-K871E;&PM*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@[-WS
M^2!(5%10+4%022X`P?7T_/(@[R#OY.?C_/(@\^'R(.7PZ?3QW?#EZ2#MX2#S
M]-WK[>7TY2#LY^W][.'TX2#LW?/Y('-M<S)E;6%I;"TH:'1T<#HO+W-M<S)M
M86EL+F-O;2D@[-WS^2!(5%10+4%022X`P?7T_/(@[R#OY.?C_/(@\^'R(.7P
MZ?3QW?#EZ2#MX2#S]-WK[>7TY2#LY^W][.'TX2#LW?/Y(%--5%`@(.KAZ2#T
MY_(@5F]D869O;F4M271A;'D@[/SM[R#SY2#A\>GH[._]\B!6;V1A9F]N92X@
MP?#AZ?3EWR#=[>$@Z^_CX?'IX?/L_"!E;6%I;"#S].<@5F]D869O;F4@271A
M;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`U.\@\.7DW^\@X?7T_"#A\.'I].7?
M].'I+@#4[R#PY>3?[R#A]?3\(.SP[_'EWR#MX2#=]^7I(.S\[>\@X>K=\>'I
M[_7R+@#!]?3\(/3O(/#EY-_O]2#L\._QY=\@[>$@\.7QZ=WWY>D@[/SM[R#A
M\>GH[._]\B#JX>D@W.WY(.K<]/D@].7KY=_A("@Z*2X`P?7T_"#T[R#PY>3?
M[R#L\._QY=\@[>$@\.7QZ=WWY>D@[/SM[R#OZO3AY.GJW?(@].GLW?(N`,'U
M]/P@].\@\.7DW^\@[/#O\>7?(.WA(/#E\>G=]^7I(.S\[>\@Z]_S].$@X?'I
MZ.S^[2#W^?'I\^S=[?GM(.SE(.KE[?P@WB#EZ^OG[>GJ_"#E\?GTY^SA].GJ
M_`#!]?3\(/3O(/#EY-_O(/#QW?#EZ2#MX2#EW^WAZ2#=[>'R(-WCZO7Q[_(@
MX?'IZ.S\\BX`P?7T_"#T[R#PY>3?[R#P\=WPY>D@[>$@\.7QZ=WWY>D@ZOGD
MZ>K\(/?Q_NSA]._R(//E(%)'0B#DY>KAY>[AY.GJWB#L[_'VWBP@\"[W+B`G
M(S$R,S1A9B<N`,'U]/P@].\@X?'WY=_O(/#E\>G=]^7I(/3O]?(@34E-12!D
M<FEV97)S(/#O]2#W\>?SZ>SO\._I[_WM].'I(.'P_"#TY^T@]?#G\>7SW^$@
MY?#I]/'=\._M].'R(.3IW/;O\>$@\/'OX_'<[.SA].$@[>$@Y.GA]^7I\=_F
M[^WTX>D@].$@\.7QZ>7W_.SE[>$@]/GM(&5M86EL(.KAZ2#MX2#TX2#E[/;A
M[=_F[_7M(.SE(/3O[2#JX?3<Z^OGZ^\@]/'\\.\N`,'U]/P@].\@X?'WY=_O
M(.7KW>/WY>D@].GR(/'UZ.S?\^7I\B#T^>T@]_'Y[-ST^>T@ZN'I(/3Y[2#C
M\>'L[.'T[_/EZ?'^[2#CZ>$@_.OA(/3O(/#Q_./QX>SLX2#T[_4@2&]R9&4L
M(.KAZ2#CZ>$@].GR(.7VX?'L[^/=\B#P[_4@Y=_MX>D@Y>/JX?3E\_3G[-WM
MY?(@\^4@X?7T_"#JX>D@Y.7M(/#A\=WW[_7M(.3IZMWR(/3O]?(@Y?#IZ^_C
MW?(@X^GA(.'U]-WR(/3I\B#Q]>CLW_/EZ?(N`,'U]/P@].\@X?'WY=_O(.KA
M].'C\=SVY>D@].GR(.7PY>KTW//EZ?(@]/GM(/3]\/GM(,S)S,4L(/[S].4@
M].$@\.7QZ>7W_.SE[>$@[_'I\^S=[?GM(&UA:6P@[>$@Y>SVX>W?YN_M].'I
M(.SE(/3O[2#JX?3<Z^OGZ^\@]/'\\.\N`,'U]-X@YR#V_/'LX2#=]^7I(-[D
MYR#E\.7NY?'CX?/HY=\N`,'U]/P@Y=_MX>D@)7,N`,'U]/P@Y=_MX>D@2V]L
M86(@1W)O=7!W87)E(&]B:F5C="X@P^GA(.WA(.3EW_3E(/3O(.'M].GJY=_L
MY>WO(.'U]/P@]_'EZ=SFY?/HY2#=[>$@\/'\X_'A[.SA(&5M86EL(/#O]2#J
MX?3AZ^'BX=_MY>D@X?7TWB#TYR#L[_'VWBX@P^GA(.O?\_3A(/3=]._I^>T@
M\/'OX_'A[.S<]/GM(.SP[_'EW_3E(.WA(.7PZ?/JY?7HY=_TY2#T[R`E<P#!
M]?3\(.7?[>'I(/3O(.+A\^GJ_"#A\??EW^\@\?7H[-_SY?GM(/3O]2#P\>_C
M\=SL[.'T[_(@)TAO<F1E)RX@T.7QZ=WWY>D@].$@[._M[_#<].GA(.KAZ2#T
MX2#BX?/IZMP@[-WQYR#P[_4@]_'G\^GL[_#OZ>_][?3AZ2#A\/P@]._M(/#U
M\=[MX2#JX>D@].GR(.7VX?'L[^/=\B#T[_4@\_7S]-[LX?3O\BX@`-3O(.S>
M[?7LX2#A]?3\(./QW/;HY^KE(.SE(.KYY.GJ[_/EZ]_DX2`H)7,I(.3IX?;O
M\>7TZ>K>(.'P_"#TYR#DZ>K>(//A\BX`P?7T_/(@[R#A\>GH[/SR(/#QW?#E
MZ2#MX2#EW^WAZ2#T[_7KW/?I\_3O[2#=[>$N`-3O(/#Q_.+KY^SA(.'U]/P@
MX>WA]MWQZ.?JY2#A\/P@)7,N(,\@]_'>\_3G\B#JW.OE\^4@].?M/&)R+S[A
M[>'V[_'<(/#Q[^+KWNSA]._R(.'P_"#T[R#PX?'AZMST^2!54DPZ/&)R+SXE
M<R#JX>D@]_'G\^GL[_#OZ>7?(/3O[2#AZOSK[_7H[R!B<F]W<V5R.CQB<B\^
M)7,`P?7T_/(@[R#E[O7PY_'E].?TWO(@Y.4@[/#O\>7?(.WA(.'P[_/U[/#I
MW?/EZ2!Z:7`@ZN'I(&=Z:7`@X?'WY=_A+@#4[R#S_?/TY^SA(.'U]/P@W??E
MZ2#A\.7MY?'C[_#OZ>?HY=\N`,'U]-X@YR#TZ>S>(/#QW?#EZ2#MX2#EW^WA
MZ2#A\>GH[/SR+@#%Z?/I]-[QZ>$`V?'A`,GW[>?KX?3^[?3A\B#TY^T@_O'A
M`,SO\?;>(/[QX?(`Q?#IZ^_CWB#^\>'R`-3?].OO\@#4W_3K[_(@*%1O;VQT
M:7`I.@#0\?SR`,/IX2#MX2#J\>'TWO/E].4@\._KZ^'PZ]P@X>WTZ>KEW^SE
M[>$L(.KQX?3>\_3E(/#A].?LW.WO(/3O($-O;G1R;VP@*%!#*2#>(/3O($-O
M;6UA;F0@*$UA8RD@\.O>ZO3Q[RP@Y>W^(.K<[>7TY2#JZ^GJ+@#3WNSE\>$`
MQ>WAZ^OAX]X@\^4@\.?CX=_O($A434P`P?WQZ>\`RN_Q]?;>`-#<[?D@\.OA
MW_/I[R`H7W1O<"D`S.7TX?;QW//EZ?(`P>7Q[^OI[-WMX?(@U/'?\._KY_(`
MP>OGZ-WR(-X@^.7UY-WR`-3Q`,OA[>CA\^S=[>_R(/3]\._R(.3EY._LW>WY
M[2X`T.OGZO3Q[^OOX][S].4@].?M(.7PZ>OOX]X@\^'R.B``Q^OEZO3Q[^WI
MZMX@Q.GE_>CU[?/G`,?KY>KT\>_MZ>K>(,3IY?WH]>WSYR#CZ>$@Y?#I\_3Q
M[_;>(.'MX?;O\=SR(.KA]-SS].'SY_(@]._U(/#Q[^/QW.SLX?3\\B#SX?(`
MQ^OEZO3Q[^WIZMX@Q.GE_>CU[?/G.@#!Y/WMX?3G(.<@\/'\\^+A\^<@\_3O
M[2!61E,@ZN'TW.OOX^\N`,'D_>WA].<@YR#P\>_SZ-[JY2#E\.GPZ]WO[2#P
MZ^?Q[_;O\>G^[2#JX?3<(/3G[2#EW_/OY.\@]._U(/?QWO/TYRX`P>3][>'T
MYR#G(.'KZ^'CWB#E[N_U\^GOY._TWO/E^>T@X^GA(/3O(%9&4R#A\??EW^\@
M(B5S(BX`P>3][>'TYR#G(.'KZ^'CWB#E[N_U\^GOY._TWO/E^>T@X^GA(/3O
M(%9&4R#A\??EW^\@)7,O)7,N`,'D_>WA].<@YR#AZ^OAX]X@]._U("5S+@#$
MY>T@Y=_MX>D@Y/7MX?3>(.<@\_WMY.7SYR#S].\@Y.GAZN_LZ?/TWB!344PN
M`,3E[2#EW^WAZ2#D]>WA]-X@YR#S_>WDY?/G(.SE(%-33"X`P>3][>'TYR#G
M(.'M].GC\>'VWB!61E,@X?'WY=_O]2X`P>3][>'TYR#G(.3G[.GO]?'CW^$@
MZN'TX>O\X^_U(%9&4R`B)7,B+@#!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2#JX?3A
MZ_SC[_4@5D93+@#!Y/WMX?3G(.<@Y.?LZ>_U\>/?X2!61E,@X?'WY=_O]2X`
MP>3][>'TYR#G(.3G[.GO]?'CW^$@ZN7M[_T@5D93(.'Q]^7?[_4N`,'D_>WA
M].<@YR#A\._S]>SPW^7SYR#DY>3O[-WM^>TN`,'D_>WA].<@YR#DZ>'C\>'V
MWB`B)7,B+"#O(/;<ZN7K[_(@Y.7M(.7?[>'I(.KE[?SR+@#!Y/WMX?3G(.<@
MY.GAX_'A]MX@)7,L(.\@]MSJY>OO\B#DY>T@Y=_MX>D@ZN7M_/(`P>3][>'T
MYR#G(.3IX>/QX?;>("<E<R<Z("5S+@#!Y/WMX?3G(.<@Y.GAX_'A]MX@ZN'T
MX>O\X^_U(%9&4R#E\.'MX>OLXN'M_.SE[>$@*')E8W5R<VEV96QY*2X`P>3]
M[>'TYR#G(.3IX>/QX?;>(.KA].'K_./O]2!61E,N`$1A<R!61E,M5F5R>F5I
M8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;CH@)7,N`,'D_>WA
M].<@YR#DZ>'C\>'VWB#T[_4@5D93(.'Q]^7?[_4@(B5S(BX`P>3][>'TYR#G
M(.3IX>/QX?;>(/3O]2!61E,@X?'WY=_O]2X`P>3][>'TYR#G(.3IX>/QX?;>
M(%9&4R#E\.'MX>OA[.+A[?SLY>WA("AR96-U<G-I=F5L>2DZ("5S+@#$Y2#L
M\._Q_B#MX2#P\>_SY.GO\=_S^2#T[^T@]/'=]^_M].$@ZN'TW.OOX^\N`,3E
M(.SP[_'^(.WA(.7NW./Y(/#KY_'O]N_QW^7R(/#I\_3O\._IY_3IZN_]`,'D
M_>WA].<@YR#V_/'T^?/G(._QZ?/L[_T@]._U("5S+@#!Y/WMX?3G(.<@[.7T
MX>K?[>?SYR#T[_4@5D93(.'Q]]_O]2X`P>3][>'T[R#T[R#<[>_IX^SA(/3O
M]2!61E,@X?'WY=_O]2`B)7,B+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U(%9&
M4R#A\??EW^_U(./IX2#C\=SXZ>SO+@#!Y/WMX?3O(/3O(-SM[^GC[.$@]._U
M(%9&4R#A\??EW^_U+@#$Y2#L\._Q_B#MX2#A[>_?[OD@].\@\_7L\.GE\^S=
M[>\@X?'WY=_O+@#$Y2#L\._Q_B#MX2#DZ>'BW//Y(/3O[2#J_?'I[R#JX?3<
MZ^_C[R!61E,@*'9F<W)O;W0I+@#$Y>T@Y=_MX>D@Y/7MX?3\[2#MX2#JX?3A
M]_GQY^CO_>T@[^D@\/'O].GLWO/EZ?(@X^GA(.'U]-X@].?M(//][>3E\^<N
M`,'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@)7,@\^4@)7,Z(.\@]MSJY>OK
M[_(@]?#<\??EZ2#>Y.<`P>3][>'TYR#G(.SE]._M[^SA\]_A(/3O]2!61E,@
MZN'TX>O\X^_U+@#!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#JX?3A
MZ_SC[_4Z("5S+@#!Y/WMX?3G(.<@[.7T[^WO[.'SW^$@]._U(%9&4R#A\??E
MW^_U("(E<R(N`,'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?
M[_4@)7,O)7,N`,'D_>WA].<@YR#LY?3O[>_LX?/?X2#T[_4@5D93(.'Q]^7?
M[_4N`,'D_>WA].<@YR#EZO3=Z^7SYR#T[_4@(FUK:7-O9G,B+@#$Y>T@[/#\
M\>7SY2#MX2#LY?3A]O'A\_3EWR#A]?3\(/3O(-WCX_'A]N\@5V]R9`#$Y2#L
M\._Q_B#MX2#C\=SX^2#S].\@5D93(.'Q]^7?[R`B)7,B+@#$Y2#L\._Q_B#M
MX2#C\=SXYR#S].\@5D93(.'Q]^7?[R`H8V]P>2@I(.'PW?3U]^4I+@#$Y2#L
M\._Q_B#MX2#C\=SX^2#DY>3O[-WMX2#T[_4@5D93(.'Q]^7?[_4N`-7P[^/Q
MX>SLZ?/LW>WA`,'J_?'Y\^<@P>OKX>/^[0#!ZO7Q_NWEZ2#TYR#TY>OE]?3A
MW^$@\^'R(.7MW?'CY>GA`,SG(.'MX>SE[?SLY>WO(/3=Z^_R(/3O]2#A\??E
MW^_U+@#,YR#A[>'LY>W\[.7MYR#A\-SM].?SYR#A\/P@]._M(.7N]?#G\>7T
MY_3>(//TYR#S_>WDY?/G.B``S.<@X>WA[.7M_.SE[><@X?#<[?3G\^<@X?#\
M(/3O[2#E[O7PY_'E].?TWB#S].\Z(`#,YR#!\??EZ>_HY?3G[-WM[P#,YR#W
MY>GQZ>;\[.7M[R#S]._I]^7?[R#T_?#O]3H@)7,`S._MW.3E\@#!X^WY\_3O
M`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C
M;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@#!X^WY\_3O(/SM[^SA(/?Q
MWO/TYR#>(.KYY.GJ_/(N`,'P[_/][>3E\^<@]/'=]^_M]._R(//T[^GWY=_O
M]0#![?[M]>SO`,SG(.7N[_7SZ>_D[_3G[-WMX2#P\>_C\=SL[.'TX2#DY2#L
M\._Q[_WM(.WA(-WW[_7M(/#Q_//BX?/G(//E(.OEZ?3O]?'CW^7R(.'P[^KO
M\-[R+^'M].GC\>'VWO(OY?#IZOSKY_/G\B#CZ>$@Z_SC[_7R(.'S]N'KY=_A
M\BX@T.'TWO/TY2#/RB#CZ>$@[>$@Y.7?].4@].7W[>GJW?(@\^?LY>G^\^7I
M\B#S].\@;6]Z:6QL82YO<F<@\._U(//A\B#DY=_W[>_U[2#P^?(@[>$@Y?#I
M]/'=^.7TY2#SY2#P\>_C\=SL[.'TX2#TYR#P\?SSXN'SYR#S].\@8VQI<&)O
M87)D`,SG(._QZ?/LW>WO(/?Q_NSA`,SG(/7P[_/TY_'IYOSLY>WG(.7PW>KT
MX?/G`,7MY^S=\?GSYP#%[>?LW?'Y\^<@)7,`Q>WG[-WQ^?/G(.KA]-SS].'S
MY_(@X?#A[?3G[-WM[_4`Q>WG[-WQ^?/G(/?QWO/TYP`G)7,G(,7MY^SE\?[H
MY^KE+@#4[R#P\?SC\>'L[.$@X>WAXMSH[.GSY_(@Y.GAX_'<]N?JY2X`P?#O
M\_3OZ]X`P?#O\_3OZ]X@_.OY[2#T^>T@X?'WY=_Y[2#Q]>CLW_/E^>T@\_3O
M[2#E[O7PY_'E].?TWBX`RN7VX>OAW^$@Z^'TZ>WIZMP@X_'<[.SA].$`T?GL
MX?KJ[]\@X?'IZ.SOWRW*Y?;AZ^'?X0#7\=[SYR#T\=WW[^WT[_(Z("5S`,WA
M(/?QY_/I[._P[^GGZ.7?(.<@\/'OY?#IZ^7C[-WMYR#TZ>S>`-?QWO/G(%-3
M3`#7\>?SZ>SO\._IY=_TX>D@X>T@].\@_.WO[.$OZOGDZ>K\\B#EW^WAZ2#D
MZ>'V[_'E].GJW"X`SR#W\=[S].?R("5S(.3E[2#EW^WAZ2#E[N_U\^GOY._T
MY^S=[>_R(./IX2`E<RX`Q.GA]^7?\>GSYR#7\>?S]/[M`,7PZ>OOX]WR(-?Q
MWO/TYP#%X^/QX?;>(-?QWO/TYP#'(.7CX_'A]MX@]_'>\_3G(-WWY>D@X?#E
M[>7QX^_P[^GGZ.7?(./I)R#A]?3\(/3O('-I=&4N`,'KZ^'CWB#J^>3IZN_]
M(/?QWO/TYP#%[N_U\^GOY._TWO/EZ?(@U_'>\_3G`+SM[^SA(-?QWO/TYP#4
M[R#\[>_LX2#W\=[S].<@)R5S)R#U\-SQ]^7I(-[DYRX`O.WO[.$@U_'>\_3G
M.@"\[>_LX2#7\=[S].<Z(`#7\=[S].7R`-?QWO/TY?(@\_3O(-/]\_3G[.$Z
M`,\@ZN'TW.OOX^_R(%9&4R#DY>T@]?#<\??EZ2X`Q.GAZN_PW?(`N./J]?'E
M\B#T[_#OZ.7SW^7R(/#O]2#B\=WHY^KA[2#S]>SPY?'IZ^'LXMSM[^WTX>DZ
M(`#%X^KU\?STY_3A`-3I[-X@\^4@Z^7P]-P@X?#\(/3^\>$N`-3I[-WR`,3^
M\_3E(/3I[-WR(./IX2#MX2#E\.GKW>[Y`,SE].'BZ^?TW@#'(.7PZ>+EXN'?
M^?/G(.'PW?3U]^4@+2#A]?3\(/3O(.S>[?7LX2#L\._QY=\@[>$@W.OKX>[E
M(.SE+@"XZN3O\^<`N.OEX_?O\B"XZN3O\^?R`,K<Z.7TYR#%]>CUX_'<[.SI
M\^<`RMSHY?3O(./=[.GS[.$`RMSHY?3A.@#0[^O](/CGZ]X`Q>SVW.WI\^<@
M)7,`Q>SVW.WI\^<@Y>[Y].7QZ>K>\B#I\_3O\^7KW^3A\@#%[/;<[>GSYR#S
MX>T@)7,`Q>SVW.WI\^<@X^7C[^W\]._R`,7L]MSMZ?/G(.7QX^'SW^'R`,_Q
MX?3\].?TX0#/\>'T_/3G].$Z`%9O9&%F;VYE(,GTX>O?X?(@[-WS^2!33510
M`-#1S]//U\<`T-'/T\_7QR$A(2#!UL')T<73U,4@U,\@T-'/P]'!S,S!(,S/
MS<_)(-/!TR#!T,\@)7,N`-#Q[^7IY._P[]_G\^<`U.4`Q>+D[^SAY.GAW^$`
MRN'K^?/>Z^CA].4`RN'K^?/>Z^CA].4@\_3O("5S`,KAZ_GSWNOHX?3E+"`E
M<P#0[^G<(.7VX?'L[^/>(.CA(.7L]N'LW^;EZ2#T[R`E<R#A]N_](//U[>3E
MZ.7?].4@\_3G[2#U\.?QY?/?X3L`T._IX2#E]N'Q[._CWB#MX2#E[/;A[=_F
MY?3AZ2#A]N_](//U[>3EZ.7?].4@\_3G[2#U\.?QY?/?X3L`T._I_/(@Y=_M
MX>D@[R#DZ>'W^?'I\_3IZOSR(/?A\>'J]-[QX?([`-#OZ?SR(.7?[>'I(.\@
M]^'QX>KTWO'A\B#EZ?/AX_GCZ>K^[3L`T._IW?(@UMSSY>GR`,KAZ._QW_/T
MY2#P[^G<(/#Q_//HY?3A(.CA(.7MY?'C[_#OZ>?H[_WM(//T[^T@Y?#E[N7Q
MX^'S]-X@Y>SPZ^_U].GS[-WM[_4@ZN7I[-WM[_4N`-#KW/3O\@#0Z]ST[_(@
M\^4@[._MW.3E\B!#4U,`T.O<]._R(/3O]2`E<R#LY>WO_2#S].$@X?'I\_3E
M\=P@*.CA(.7VX?'L[_/HY=\@\_3G[2#E\/SLY>WG(.7?\^_D[RDZ`-#KW/3O
M\B#T[_4@\-_MX>KA`,SO[=SDX2#PZ]ST[_7R`-#KW/3O\CH`N.WTX?/G(.'M
MW>SO]2#SY2#J_.SB[_7R`,'MY>SO\CH`P>WE[._R.B``T^_VW^$`R]_S].$@
MY?#IZ/7LZ?[M`,7QX^'SW^$`Q.GE_>CU[?/G(,7QX^'SW^'R`-3GZ]WV^>WO
M(,7QX^'SW^'R`%@M4F5F`%@U,#EV,R#"X?/IZN_?(-#E\>GO\>GS[._?`%@U
M,#EV,R#7\=[SYR#E\.7J].'LW>WO]2#JZ^7IY.GO_0!8-3`Y=C,@Q>WAZ^'J
M].GJ_""\[>_LX2#(W>SA]._R`%@U,#EV,R#![>'C[?GQZ?/TZ>K\(,KKY>GD
MWR#(W>SA]._R`%@U,#EV,R#%\.7J]-SSY>GR`,7%`,7%Q<4`Q?3>\^GA`,WA
MWP#-X>DL(-/U[/;Y[?X`Q=_S].4@\^4@ZN'TW//TX?/G(,K%R<S%S<_5+B#7
M\>?SZ>SO\._IY=_S].4@].\@6SP^72#PZ][J]/'O(./IX2#MX2#E\.GS]/'=
M^.7TY2#SY2#JX?3<\_3A\^<@5UE325=)1RX`Q.7M(-WWY?3E(.'UZ.7M].GJ
M[_#OZ>?HY=\N`,3E[2#E\.GT\=WPY?3AZ2#MX2#=]^7TY2#T[R#WX?'AZO3>
M\>$@)UPG(//T[R"\[>_LW"#SX?(N`,3E(.3^\^'TY2#=X^/U\><@Y.GE_>CU
M[?/G(&5M86EL+@#$Y>T@X>WTZ?/T[^GWW_/A].4@ZN'MW>WA(/#EY-_O(.'P
M_"#T[R#A\??EW^\@Y>GSX>/YX][R(//E(.'M]-_S]._I]^$@\.7DW^$@\_3O
M("5S+@"X]^7TY2#A\._S]>WDY>CEWRX`N/?E].4@X?#O\_7MY.7HY=\N/&)R
M("\^Q?7WX?'I\_3O_>SE(/#O]2#W\>?SZ>SO\._IWO/A].4@].?M(/7PY_'E
M\]_A+@#0\=WPY>D@[>$@Y/[SY?3E(.SIX2#=X^KU\><@].GLWBX`T/'=\.7I
M(.WA(/'UZ.S?\^7TY2#T[R!$871A5')E92#CZ>$@[>$@]_'G\^GL[_#OZ>7?
M].4@4VEG;G5P<RX`T/'=\.7I(.WA(/'UZ.S?\^7TY2#T[R!61E,M0F%C:V5N
M9"X`T/'=\.7I(.WA(/#E\>GC\=SXY?3E(/3O(/#Q_.+KY^SA(/#QZ>T@\_3E
MW^OE].4@X>WA]N_QW"#CZ>$@X?7T_"X`T/'=\.7I(.WA(//U[/#KY_'^\^7T
MY2#T[R!54DP@\._U(.3EW_?MY>D@X?7TWB#G(//][>3E\^<`T/'=\.7I(.WA
M(.7PZ>O=[N7TY2#T[^T@Y>[U\.?QY?3G]-X@X^GA(.3IX>/QX?;>+@#0\=WP
MY>D@[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./IX2#DZ>'C\>'VWBX`
MT/'=\.7I(.WA(._QW_/E].4@W>WA(/SM[^SA(/?QWO/TYR#CZ>$@Y.GAX_'A
M]MXN`-#QW?#EZ2#MX2#O\=_SY?3E(-WMX2#\[>_LX2#W\=[S].<@X^GA(/#Q
M[_/HWNKG+@#0\=WPY>D@[>$@[_'?\^7TY2#=[>$@_.WO[.$@]_'>\_3G(./I
MX2#E[>?LW?'Y\^<N`-#QW?#EZ2#MX2#O\=_SY?3E(.SIX2#E[=WQX^7IX2#C
MZ>$@Y>KTW>OE\^<N`-#QW?#EZ2#MX2#D_O/E].4@W>WA(/SM[^SA(./IX2#T
MYR#MW>$@ZN'TY^/O\=_A+@#'(//][>3E\^<@\^'R("5S(.3IX>K\\.?JY2X@
MT.'QX>KAZ_X@Y._JZ>S<\_3E(.WA(.[A[>'S]>WDY>CEW_3E+@#'(,?KY>KT
M\>_MZ>K>(//A\B#$Z>7]Z/7M\^<`QR#'Z^7J]/'O[>GJWB#SX?(@Q.GE_>CU
M[?/G.@#'(,'P_#H@Q.GE_>CU[?/G.@#/Z2#0Z^?Q[_;O\=_E\B#SX?(`QR!)
M;G1E<FYE="#DZ>7]Z/7M\]X@\^'R(-SKZ^'NY2#A\/P@].?M(-WMX?'NYR#T
MY_(@)7,@\_WMY.7SWO(@\^'R+B##Z>$@].?M(/#Q[_/TX?/?X2#TY_(@X?/V
MW.OEZ>'R(/#QW?#EZ2#MX2#NX>WA\_7MY.7HY=_TY2X`U.\@_.WO[-P@\^'R
M`-3O(//]\_3G[.$@X?7HY>WTZ>KO\._?Y_/G\B#DY>T@]?#O\_3G\=_FY>D@
M\/'O\^C>ZN<@]_'G\_3^[2P@WB#G(.OEZ?3O]?'CW^$@X?7TWB#=]^7I(.'P
MY>WE\>/O\._IY^CEWR#CZ>$@ZMSP[^GO(.O\X^\N`-3O(//]\_3G[.$@X?7H
MY>WTZ>KO\._?Y_/G\B#DY>T@]?#O\_3G\=_FY>D@Z]_S].$@]_'G\_3^[2P@
MWB#G(.OEZ?3O]?'CW^$@X?7TWB#=]^7I(.'PY>WE\>/O\._IY^CEWR#CZ>$@
MZMSP[^GO(.O\X^\N`,\@0G)O=W-E<B#SX?(@]N'?[>7TX>D@[>$@W??EZ2#A
MZ^O<[N7I(.'P_"#TY^T@W>WA\>[G(/3G\B`E<R#S_>WDY?/>\B#SX?(N(,/I
MX2#TY^T@\/'O\_3A\]_A(/3G\B#A\_;<Z^7IX?(L(.CA(/#QW?#EZ2#MX2#N
MX>WA\_7MY.7HY=_TY2X`SR!"<F]W<V5R(//A\B#DY>T@]?#O\_3G\=_FY>D@
MX?7TWB#TYR#KY>GT[_7QX]_A+@#/($)R;W=S97(@\^'R(.3E[2#U\._S].?Q
MW^;EZ2#A]?3>(/3G[2#E\.GK[^/>(.7J]/WP^?/G\BX@T.'TWO/TY2!#;VYT
M<F]L+T]P=&EO;B`K(%`@X^GA(.7J]/WP^?/G+@#'(/3QW??O]?/A(.;^[><@
M_O'A\CH`QR#P\>_JX>CO\>GS[-WMYR#SX?(@].'U]/STY_3A.@#4[R#PZ][Q
MY?(@_.WO[-P@\^'R.@#/(.W=[_(@\^'R(.KYY.GJ_/(@X^GA("5S(.7?[>'I
M.B`E<P#/Z2#E\.GK[^/=\B#SX?(@W??O]>T@Y>WG[.7Q^>CEWR#CZ>$@].<@
MY.G<\>KEZ>$@X?7TWO(@].?R(//][>3E\^?R+@#/Z2#E\.GK[^/=\B#SX?(@
MW??O]>T@Y>WG[.7Q^>CEWRX`SR#J^>3IZOSR(//A\B#<Z^OA[N4`SR#J^>3I
MZOSR(//A\B#<Z^OA[N4L(.7KW>/N].4@].$@[.?M_>SA]-P@\^'R(.KAZ2#J
MW.WTY2#EW_/OY.\@[.4@].\@[=WO(//A\B#J^>3IZOPN`,_I(.W=[^D@ZOGD
MZ>KOWR#DY>T@].'I\>G<YN_U[0#/Z2#A\._LX>KQ]?/LW>WOZ2#SX?(@Y>[U
M\.?QY?3G]-WR.@!;P?#\ZO'U^.<@ZN7I[-WM[_4@\^4@Y>GSX>/YX^GJW%T`
M6\'MX?;O\=P@T/'OXNO>[.'T[_)=`%O%[/;<[>GSYR#JY>GLW>WO]2#SY2#E
MZ?/AX_GCZ>K<("T`6\7L]MSMZ?/G(.KEZ>S=[>_U(//E(.7I\^'C^>/IZMP@
M+2`E<R#C\>'L[-WR70!;X_'A[.S>("5S(.'P_"`E<UT`Q.GA]^7?\>GSYP#$
MZ>'C\>'VWB##\>'L[-[R`,_LW.3E\@#"[][HY>GA`,GDZ?STY_3E\B#%Z>K\
M[>'R+BXN`,7?\^_D[_(`Q>[OY._R`-3Q[_#O\._?Y_/G(-/][>3E\^SO]2XN
M+@#%\.GK[^/=\@#%[N_U\^GOY._TWO/EZ?(`Q.GAX_'A]MX@T_7MY-WS[._U
M+BXN`-'UZ.S?\^7I\@#)Y.G\].?TY?(@T-_MX>KA+BXN`-?QWO/TY?(`Q.GE
M]>CU[?/I[^/QW/;O\@#'[.7Q[^O\X^GO`.?QY>S?X0#PX?3>\_3E(.7D_@#A
M\??EW^\`X?#\(/3O("5S("@E<RD@\_3I\B`E<R`E<P!H.@#<[.7SX0#E[?/Y
M[.'T^>S=[>\`X_'A[.S=\ET`;6MI<V]F<RWJ^>3IZOSR(.O<Z._U\B`E9"#J
MX?3<(/3G(.3G[.GO]?'CW^$@25-/+@#\[>_LX0#DY>T@W??EZ2#EX^KA].'S
M].'HY=\`Y.7M(-WWY>D@Y>/JX?3A\_3AZ.7?(.'J_.SG`//G[.7I^>SA]-SQ
MZ>\`]._I\B#EZN'T_`#EZ>KO[>_S]._I]^7?X0#E[/;<[>GSYR#DZ>'V[_'^
M[0!S;7,@\^4@96UA:6P@[-WS^2!(5%10`//TX>CE\?SR`.O?\_3A(.7QX^'S
MZ?[M`.K<Y._R`,/QW/CTY2#T[^T@ZOGDZ>K\(.3][R#V[_'=\B#CZ>$@Y?#I
MXN7BX=_Y\^<`Y>WO\._IY^S=[>$`X>W^[?7LX0#E\.GK[^/>(/?QWO/TYP#8
MY_;IX>K>(,K<\?3A````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L;V-A;&4O8W-?0UHO3$-?34534T%'15,`````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#<W`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]C<U]#6B]H96QP+GAM;```````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S(V,2`Q,#4Q
M-30S-#$T,2`P,C$T-#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB:7-O
M+3@X-3DM,B(_/@H\(2TM("1(;W)D93H@:&]R9&4O;&]C86QE+V-S7T-:+VAE
M;'`N>&UL+'8@,2XV(#(P,#0O,#@O,3@@,#@Z-#(Z-3$@:F%N($5X<"`D("TM
M/@H\:&5L<#X*("`\96YT<GD@:60](G-U;6UA<GDB('-T871E/2)U<'1O9&%T
M92(@;60U/2(V.&-A,S-F-V8P8SEA864T8S$P,V5B-#<T.3)C9&,Q-2(^"CQT
M:71L93Y0;W)TX6P\+W1I=&QE/@H@/'!A<F$^"B`@4W1RX6YK82!0;W)TX6QU
M('!O<VMY='5J92!S=')UZ&[]('#X96AL960@=KEE8V@@9/EL9;YI=/UC:"!I
M;F9O<FUA8^TN"B`@3F%P^.UK;&%D(&WYOF4@>F]B<F%Z;W9A="!P;^AE="!E
M;6%I;/DL(&EN9F]R;6%C:2!O('-C:/EZ:^%C:"!V92!68>QE;2!K86QE;F3A
M^&DL"B`@^FMO;&5C:"P@871D+B!6['2Y:6YA('3L8VAT;R!I;F9O<FUC[2!P
M;W-K>71U:NT@;&EN:WD@:R!B[+YN_6T@9G5N:V/M;2P@"B`@:F%K;R!N87#X
M[6ML860@=GET=F_X96[M(&YO=ND@96UA:6QO=ND@>G!RX79Y+"!V>71V;_AE
M;FWM(&YO=ND@<V-H^7IK>2P@871D+@H@/"]P87)A/@H@/'!A<F$^"B`@4F]Z
M=G*^96[M('3I=&\@<W1RX6YK>2!P;W)TX6QU(&QZ92!N87-T879I="!P;VUO
M8^T@=&QAZ.UT:V$@4F]Z;&^^96[M+@H@($YA</CM:VQA9"P@;?F^971E('-I
M('9Y8G)A="P@:W1E<ND@<')V:WD@<VD@</AE:F5T92!Z;V)R87II="!A('1A
M:^D@=B!J86OI;0H@('!O^&%D[2X@"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)N879B87(B('-T871E/2)U<'1O9&%T92(@;60U/2)B.&-F,&%E
M,3EE-3=D9F$P8S)B.38R934Q-C<X,F8T-R(^"CQT:71L93Y.879I9V'H;NT@
M3&FY=&$@<')O($%P;&EK86-E/"]T:71L93X*(#QP87)A/@H@($YA=FEG8>AN
M[2!L:;ET82!J92!U;>US=&[L;F$@=FQE=F\@;F$@=V5B<W1RX6YC92X@2VQI
M:V[L=&4@;F$@:6MO;FMY"B`@=.ET;R!L:;ET>2!P;W-K>71U:NUC[2!P^&5H
M;&5D;NQJN>T@82!R>6-H;&5JN>T@</AE<.UNX6[M(&UE>FD@87!L:6MA8V5M
M:2X*(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](G!R969S+61O7VUA
M:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB9&0Y-61F,#=A,#,P
M,S$R,S)B865A.3$Y,C@X8C)D,#`B/@H@("`@/'1I=&QE/DYA<W1A=F5N[3H@
MVF1ROF)A.B!0<F]VZ7-T(-ID<KYB=3PO=&ET;&4^"B`@("`\<&%R83X*("`@
M($]Z;F'H=&4@=&5N=&\@<N%M9>AE:RP@<&]K=60@<VD@</AE:F5T92!P<F]V
MZ7-T(&]P97)A8V4@^F1ROF)Y('#X:0H@("`@</AI:&SAN65N[2!D;R!S>73I
M;74N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUC
M;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB83(Q
M,38R8V1F9C-B,60X9F%E861B-S(Y-C(T,#`S-F4B/@H@("`@/'1I=&QE/DYA
M<W1A=F5N[3H@VF1ROF)A.B!0;W1V<F1I="#:9'*^8G4\+W1I=&QE/@H@("`@
M/'!A<F$^"B`@("!/>FYAZ'1E('1E;G1O('+A;67H96LL('!O:W5D('-I('#X
M96IE=&4@<&]T=G)D:70@=KEE8VAN>2!O<&5R86-E(/ID<KYB>0H@("`@;F6^
M('-E('!R;W9E9&]U+B!0;VMU9"!T96YT;R!RX6UEZ&5K('KY<W1A;F4@;F5O
M>FYAZ&5N_2P@<&]T^&5B;ND@;W!E<F%C92`*("`@('-E('!R;W9E9&]U(&%U
M=&]M871I8VMY(&)E>B!M;[YN;W-T:2!S=&]R;F$N"B`@("`\+W!A<F$^"CPO
M96YT<GD^"CPO:&5L<#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O8W-?0UHO3$-?34534T%'15,O:&]R9&4N
M;6\`````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`S,S8P,S4@,3`U,34T,S0Q
M-#$@,#(S,C(V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````-X2!)4`````F`8``!P```#<-```RP@``)QI````````R(P```X`
M``#)C```#P```-B,```-````Z(P```@```#VC```"P```/^,```,````"XT`
M``0````8C0``#````!V-```/````*HT```L````ZC0``#@```$:-```%````
M58T``"@```!;C0``"````(2-```*````C8T``!4```"8C0``$@```*Z-```+
M````P8T```X```#-C0``"@```-R-```-````YXT```X```#UC0``$0````2.
M```-````%HX```P````DC@``#0```#&.```&````/XX```\```!&C@``&```
M`%:.```,````;XX```X```!\C@``#@```(N.```(````FHX``"X```"CC@``
M&@```-*.```R````[8X``#@````@CP``5````%F/``!1````KH\``%H`````
MD```5P```%N0```T````LY````<```#HD```"@```/"0```/````^Y````4`
M```+D0``!@```!&1```1````&)$```@````JD0``"0```#.1```)````/9$`
M`"4```!'D0``(````&V1```0````CI$```\```"?D0``"@```*^1```#````
MNI$```\```"^D0``%````,Z1```)````XY$```T```#MD0``$@```/N1```/
M````#I(```H````>D@``#P```"F2```(````.9(``"0```!"D@``%````&>2
M```6````?)(```@```"3D@``&0```)R2```'````MI(```P```"^D@``+```
M`,N2```.````^)(```,````'DP``"P````N3```'````%Y,```<````?DP``
M!0```">3```%````+9,```H````SDP```P```#Z3```7````0I,```H```!:
MDP``#P```&63```.````=9,``!@```"$DP``(P```)V3```.````P9,``!0`
M``#0DP``%P```.63```7````_9,``!<````5E```$P```"V4```/````090`
M``X```!1E```'P```&"4```'````@)0```8```"(E```"````(^4```/````
MF)0```8```"HE```"@```*^4```3````NI0```L```#.E```$````-J4```5
M````ZY0``!4````!E0``!P```!>5```0````'Y4```4````PE0``%0```#:5
M```1````3)4```P```!>E0``.P```&N5```)````IY4```<```"QE0``%```
M`+F5```#````SI4```4```#2E0``$````-B5```)````Z94``!,```#SE0``
M.0````>6```2````098``"<```!4E@``+````'R6```J````J98``"4```#4
ME@``"@```/J6```&````!9<```D````,EP``!P```!:7```O````'I<``#<`
M``!.EP``+@```(:7``!5````M9<``"T````+F```+0```#F8```M````9Y@`
M`$````"5F```(P```-:8```C````^I@``"T````>F0``,P```$R9```5````
M@)D``!D```"6F0``*0```+"9```D````VID``!$```#_F0``"@```!&:```,
M````')H```H````IF@``$````#2:```6````19H``!8```!<F@``!P```'.:
M```'````>YH``!0```"#F@``"@```)B:```(````HYH```@```"LF@``!P``
M`+6:```'````O9H```8```#%F@``!0```,R:```'````TIH```8```#:F@``
M"````.&:```I````ZIH```X````4FP``"@```".;```$````+IL```<````S
MFP``"0```#N;```&````19L``!$```!,FP``!P```%Z;```6````9IL```0`
M``!]FP``"````(*;```&````BYL```T```"2FP``!@```*";```>````IYL`
M`!$```#&FP``"````-B;```-````X9L```P```#OFP``!P```/R;```#````
M!)P```,````(G```%P````R<```3````))P```@````XG```!````$&<```(
M````1IP```@```!/G```00```%B<```@````FIP```8```"[G```!@```,*<
M```5````R9P``!@```#?G```(@```/B<```N````&YT``!T```!*G0``(0``
M`&B=``!4````BIT``"D```#?G0``"@````F>```'````%)X``!4````<G@``
M#@```#*>```*````09X```\```!,G@``#0```%R>```/````:IX```T```!Z
MG@``"0```(B>```4````DIX```8```"GG@``&````*Z>```=````QYX``!,`
M``#EG@``%````/F>```$````#I\```8````3GP``5````!J?```$````;Y\`
M``X```!TGP``!0```(.?```%````B9\``!L```"/GP``&@```*N?```1````
MQI\``!$```#8GP``'````.J?```J````!Z```!`````RH```(0```$.@```%
M````9:```!,```!KH```$@```'^@```*````DJ````\```"=H```$0```*V@
M```3````OZ````P```#3H```!@```."@```&````YZ```!<```#NH```$```
M``:A```1````%Z$```@````IH0``!0```#*A```,````.*$``!````!%H0``
M!0```%:A```-````7*$```8```!JH0``!P```'&A```-````>:$```<```"'
MH0``"P```(^A```'````FZ$```<```"CH0``"0```*NA```*````M:$``!D`
M``#`H0``#````-JA```0````YZ$```4```#XH0``)0```/ZA```2````)*(`
M`!,````WH@``*P```$NB```[````=Z(``"````"SH@``-@```-2B```(````
M"Z,```P````4HP``!@```"&C```$````**,```X````MHP``"@```#RC```-
M````1Z,``!X```!5HP``&P```'2C```A````D*,``!X```"RHP``&0```-&C
M```>````ZZ,``!L````*I```)@```":D```;````3:0``!X```!II```'```
M`(BD```F````I:0``#,```#,I```)@````"E```K````)Z4``#@```!3I0``
M+P```(RE```2````O*4``"D```#/I0``$@```/FE``"B````#*8``!8```"O
MI@``(P```,:F```H````ZJ8``"D````3IP``*````#VG```?````9J<``"``
M``"&IP``)0```*>G```P````S:<``"$```#^IP``'````""H```F````/:@`
M`$$```!DJ```#````*:H```'````LZ@```<```"[J```!@```,.H```-````
MRJ@``!````#8J```$@```.FH```3````_*@``!(````0J0``!P```".I```$
M````*ZD```P````PJ0``#@```#VI```/````3*D``!,```!<J0``#0```'"I
M```H````?JD```,```"GJ0``#0```*NI```&````N:D``!$```#`J0``%P``
M`-*I```;````ZJD```X````&J@```@```!6J```%````&*H``!`````>J@``
M!````"^J```-````-*H```X```!"J@```P```%&J```.````5:H```@```!D
MJ@``#P```&VJ```/````?:H```<```"-J@``#0```)6J```0````HZH```L`
M``"TJ@``!@```,"J```,````QZH``!$```#4J@``&0```.:J```+`````*L`
M``T````,JP``(@```!JK```*````/:L``!@```!(JP``&0```&&K```6````
M>ZL```T```"2JP``!P```*"K```4````J*L```L```"]JP``(@```,FK```O
M````[*L```L````<K```"0```"BL```9````,JP```L```!,K```%P```%BL
M```7````<*P```D```"(K```%@```)*L```/````J:P``!8```"YK```#@``
M`-"L```8````WZP```@```#XK```#0````&M```F````#ZT``$,````VK0``
M"````'JM```2````@ZT```@```"6K0``"P```)^M```O````JZT```X```#;
MK0``!0```.JM```&````\*T```,```#WK0``!P```/NM```$`````ZX```H`
M```(K@``"@```!.N```/````'JX``!`````NK@``%P```#^N```1````5ZX`
M`!<```!IK@``"0```(&N```%````BZX```L```"1K@``"@```)VN```"````
MJ*X```4```"KK@``#0```+&N```;````OZX``!<```#;K@``"0```/.N```.
M````_:X```T````,KP``$@```!JO```X````+:\``"````!FKP``"````(>O
M```.````D*\``'L```"?KP``&````!NP```1````-+````<```!&L```!0``
M`$ZP```9````5+````<```!NL```"````':P```&````?[````8```"&L```
M$````(VP```/````GK```!````"NL```#P```+^P```+````S[````\```#;
ML```#````.NP```/````^+````<````(L0``!@```!"Q```.````%[$```P`
M```FL0``*````#.Q```/````7+$```@```!LL0``"````'6Q```3````?K$`
M`!X```"2L0``(0```+&Q```@````T[$``!D```#TL0``%P````ZR```E````
M)K(``!<```!,L@``!````&2R```;````:;(```T```"%L@``#````).R```#
M````H+(```@```"DL@``"@```*VR```,````N+(```L```#%L@``$````-&R
M```,````XK(```0```#OL@``$P```/2R```4````"+,```P````=LP``"0``
M`"JS```.````-+,```L```!#LP``&P```$^S```'````:[,```<```!SLP``
M"@```'NS```-````AK,```D```"4LP``!````)ZS```%````H[,```,```"I
MLP``&````*VS```*````QK,```0```#1LP``)@```-:S```.````_;,``'P`
M```,M```%0```(FT```%````G[0```<```"EM```#````*VT```(````NK0`
M``H```##M```!@```,ZT```(````U;0```(```#>M```!@```.&T```&````
MZ+0``!0```#OM```#0````2U```0````$K4``!L````CM0``!````#^U```)
M````1+4``!````!.M0``"0```%^U```)````:;4```4```!SM0``&@```'FU
M```(````E+4```8```"=M0``&0```*2U```.````OK4```<```#-M0``!P``
M`-6U```%````W;4```D```#CM0``"@```.VU```"````^+4```8```#[M0``
M#0````*V```)````$+8```8````:M@``$@```"&V```)````-+8```<````^
MM@``%````$:V```=````6[8```8```!YM@``"@```("V```$````B[8```D`
M``"0M@``"````)JV```1````H[8```D```"UM@``!@```+^V```-````QK8`
M``8```#4M@``!````-NV```Y````X+8``#T````:MP``.@```%BW```>````
MD[<```4```"RMP``#@```+BW```$````Q[<```8```#,MP``(0```-.W```5
M````];<```8````+N```!````!*X```1````%[@```8````IN```"@```#"X
M```B````.[@```0```!>N```!0```&.X```=````:;@```0```"'N```#```
M`(RX```*````F;@```@```"DN```"0```*VX```%````M[@``#H```"]N```
M,````/BX```U````*;D``"D```!?N0``1P```(FY```X````T;D``"D````*
MN@``/P```#2Z```N````=+H``"T```"CN@``'P```-&Z```/````\;H``!(`
M```!NP``"P```!2[```F````(+L``"D```!'NP``)````'&[```F````EKL`
M``@```"]NP``"@```,:[```)````T;L```<```#;NP``(````..[```@````
M!+P``"8````EO```"@```$R\```9````5[P``"D```!QO```%@```)N\```2
M````LKP```<```#%O```"@```,V\```,````V+P```\```#EO```$````/6\
M``!`````!KT``'````!'O0``9@```+B]```.````'[X```D````NO@``"@``
M`#B^```2````0[X``!,```!6O@``#````&J^```&````=[X```\```!^O@``
M$@```(Z^```0````H;X``!$```"RO@``'````,2^```C````X;X``&H````%
MOP``#P```'"_```%````@+\``!````"&OP``"0```)>_```$````H;\```L`
M``"FOP``%````+*_```,````Q[\```P```#4OP``#P```.&_```5````\;\`
M`"D````'P```*@```#'````F````7,```"<```"#P```*0```*O````J````
MU<```!D`````P0``0@```!K!```1````7<$``!(```!OP0``$P```(+!```4
M````EL$```\```"KP0``%@```+O!```7````TL$``!````#JP0``$0```/O!
M```T````#<(``!,```!"P@``$@```%;"```U````:<(``!0```"?P@``!P``
M`+3"```,````O,(``"````#)P@``%````.K"```1````_\(``!<````1PP``
M'````"G#```3````1L,``!$```!:PP``&@```&S#```>````A\,``!H```"F
MPP``$0```,'#```4````T\,``!<```#HPP``%0````#$```)````%L0``!D`
M```@Q```!````#K$```'````/\0```L```!'Q```$0```%/$```&````9<0`
M``8```!LQ```!@```'/$```%````>L0```<```"`Q```!P```(C$```%````
MD,0``!8```"6Q```!@```*W$```&````M,0```0```"[Q```!````,#$```'
M````Q<0```X```#-Q```#````-S$```,````Z<0```T```#VQ```"@````3%
M```.````#\4```4````>Q0``*````"3%```.````3<4```P```!<Q0``#P``
M`&G%```*````><4```@```"$Q0``"0```(W%```K````E\4```0```##Q0``
M"````,C%```F````T<4``!(```#XQ0``#P````O&```&````&\8```H````B
MQ@``!P```"W&```(````-<8``"`````^Q@``"0```%_&```,````:<8```T`
M``!VQ@``#@```(3&```6````D\8``!$```"JQ@``!@```+S&```#````P\8`
M``8```#'Q@``&0```,[&```'````Z,8```0```#PQ@``"P```/7&```+````
M`<<```<````-QP``!P```!7'```6````'<<```T````TQP``#0```$+'```*
M````4,<``!````!;QP``#P```&S'```1````?,<``!<```".QP``"@```*;'
M```1````L<<```@```##QP``!````,S'```/````T<<``#H```#AQP``!0``
M`!S(```,````(L@``!X````OR```#@```$[(```0````7<@```L```!NR```
M#````'K(```)````A\@```<```"1R```"@```)G(```)````I,@```X```"N
MR```$````+W(```:````SL@```H```#IR```"0```/3(```*````_L@```P`
M```)R0``#P```!;)```(````)LD```8````OR0``!P```#;)```+````/LD`
M`$<```!*R0``#0```)+)```)````H,D```0```"JR0```P```*_)```3````
ML\D``!,```#'R0``$P```-O)```*````[\D```(```#ZR0``!````/W)```E
M`````LH```,````HR@``!0```"S*```J````,LH```H```!=R@``!0```&C*
M```$````;LH```H```!SR@``#0```'[*```&````C,H```@```"3R@``"```
M`)S*```$````I<H```4```"JR@``:````+#*```)````&<L```P````CRP``
M!0```##+```&````-LL``!L````]RP``+P```%G+```0````B<L```H```":
MRP``#P```*7+```*````M<L```D```#`RP``$P```,K+```;````WLL``!@`
M``#ZRP``%P```!/,```.````*\P```,````ZS```!P```#[,```(````1LP`
M``<```!/S```"@```%?,```+````8LP```<```!NS```40```';,```0````
MR,P```P```#9S```#0```.;,```:````],P``$H````/S0``!@```%K-```&
M````8<T```8```!HS0``'P```&_-```&````C\T```D```"6S0``&````*#-
M```7````N<T```8```#1S0``#0```-C-```B````YLT``%<````)S@``$P``
M`&'.```C````=<X``!,```"9S@```@```*W.```+````L,X```@```"\S@``
M#0```,7.```*````T\X```<```#>S@``%````.;.```&````^\X```@````"
MSP``#@````O/```'````&L\```H````BSP``"P```"W/```'````.<\```P`
M``!!SP``#0```$[/```,````7,\```D```!ISP``"0```'//```*````?<\`
M``<```"(SP``"0```)#/```'````FL\```H```"BSP``&P```*W/```2````
MR<\```H```#<SP``"0```.?/```0````\<\```<````"T```$@````K0```$
M````'=````<````BT```!0```"K0```%````,-````L````VT```%````$+0
M```1````5]```!H```!IT```%@```(30```4````F]```!<```"PT```&```
M`,C0```<````X=```!D```#^T```!P```!C1```%````(-$```T````FT0``
M#````#31```(````0=$``!<```!*T0``"P```&+1```3````;M$```0```""
MT0``"@```(?1```$````DM$```P```"7T0``"0```*31```%````KM$```<`
M``"TT0``!0```+S1```$````PM$```(```#'T0``.````,K1```L`````](`
M`!(````PT@``*0```$/2```R````;=(```H```"@T@``+````*O2```N````
MV-(``#,````'TP``,P```#O3```X````;],```\```"HTP``&````+C3```0
M````T=,```\```#BTP``$P```/+3```4````!M0``!(````;U```%````"[4
M```5````0]0``"T```!9U```+0```(?4```Q````M=0``"X```#GU```+P``
M`!;5```L````1M4``&(```!SU0``$P```-;5```(````ZM4```@```#SU0``
M*P```/S5```A````*-8``!H```!*U@``"0```&76``!%````;]8``$$```"U
MU@``!````/?6```3````_-8``!0````0UP``#@```"77```3````--<``!@`
M``!(UP``!@```&'7```)````:-<```H```!RUP``#P```'W7```0````C=<`
M``<```">UP``#@```*;7```%````M=<``!L```"[UP``"````-?7```&````
MX-<``!0```#GUP``$0```/S7```.````#M@``#@````=V````@```%;8```&
M````6=@```X```!@V```!0```&_8```'````==@```X```!]V```!@```(S8
M```$````D]@``"D```"8V```%P```,+8```?````VM@``%P```#ZV```%```
M`%?9```^````;-D``!\```"KV0``$````,O9```'````W-D```X```#DV0``
M#````//9```,`````-H``!,````-V@``"@```"':```=````+-H``!D```!*
MV@``!0```&3:```1````:MH``!$```!\V@``)````([:```5````L]H``!(`
M``#)V@``#@```-S:```9````Z]H```@````%VP``"0````[;```-````&-L`
M``H````FVP``!P```#';```/````.=L```L```!)VP``"@```%7;```'````
M8-L```@```!HVP``!0```'';```?````=]L```8```"7VP``$````)[;```(
M````K]L```T```"XVP``"````,;;```2````S]L``"P```#BVP``&@````_<
M```)````*MP```H````TW```%0```#_<```%````5=P``!0```!;W```!```
M`'#<```0````==P```8```"&W```!P```(W<```>````E=P``"@```"TW```
M"@```-W<```:````Z-P``!0````#W0``!````!C=```$````'=T```L````B
MW0``!0```"[=```&````--T```@````[W0``!@```$3=```*````2]T``!L`
M``!6W0``-````'+=```T````I]T``"````#<W0``*0```/W=```@````)]X`
M`$$```!(W@``&@```(K>```H````I=X``"D```#.W@``(@```/C>```&````
M&]\```@````BWP``!0```"O?```(````,=\``!D````ZWP``&0```%3?```J
M````;M\``",```"9WP``+@```+W?```T````[-\```@````AX```%P```"K@
M```*````0N````<```!-X```(0```%7@```0````=^````X```"(X```"P``
M`)?@```'````H^```!,```"KX```"````+_@```+````R.````H```#4X```
M%````-_@```R````].````L````GX0``!0```#/A```%````.>$``!<````_
MX0``#P```%?A```$````9^$```H```!LX0``"0```'?A```+````@>$```T`
M``"-X0``#````)OA```.````J.$```4```"WX0``!````+WA```-````PN$`
M`#(```#0X0``10````/B```7````2>(``!X```!AX@``%````(#B```%````
ME>(``!0```";X@``!P```+#B```.````N.(``"H```#'X@``!@```/+B```,
M````^>(```T````&XP``$0```!3C```+````)N,``#8````RXP``"@```&GC
M```B````=.,```L```"7XP``#P```*/C```R````L^,```X```#FXP``!0``
M`/7C```.````^^,``!,````*Y```!P```![D```1````)N0```<````XY```
M%````$#D```8````5>0```<```!NY```!0```';D```,````?.0```P```")
MY```$@```);D```$````J>0```<```"NY```"@```+;D```+````P>0```P`
M``#-Y```#@```-KD```.````Z>0```4```#XY```!0```/[D```N````!.4`
M`"8````SY0``(P```%KE```#````?N4``!(```""Y0``!@```)7E```>````
MG.4``!@```"[Y0``)0```-3E```-````^N4```D````(Y@```P```!+F```'
M````%N8```H````>Y@```@```"GF```,````+.8``!4````YY@``"P```$_F
M```9````6^8``"````!UY@``$@```);F```%````J>8```H```"OY@``%0``
M`+KF```2````T.8```P```#CY@``!````/#F```'````]>8```P```#]Y@``
M4@````KG```7````7><```<```!UYP``!@```'WG```.````A.<```P```"3
MYP``#0```*#G```5````KN<``!(```#$YP``#P```-?G```4````Y^<``!L`
M``#\YP``$````!CH``!I````*>@``!H```"3Z```%P```*[H```G````QN@`
M`!H```#NZ```%P````GI```;````(>D``!D````]Z0``'P```%?I```3````
M=^D```@```"+Z0``!P```)3I```(````G.D```D```"EZ0``%0```*_I```-
M````Q>D``!,```#3Z0```P```.?I``!&````Z^D``#\````RZ@``-P```'+J
M``!7````JNH```4````"ZP``'P````CK```O````*.L```H```!8ZP``"```
M`&/K```-````;.L``"T```!ZZP``!````*CK``!/````K>L``"4```#]ZP``
M'````"/L```+````0.P``!\```!,[```'0```&SL```E````BNP``"````"P
M[```)````-'L```@````]NP```L````7[0``!P```"/M```-````*^T```P`
M```Y[0``%P```$;M```&````7NT``#D```!E[0``#````)_M```'````K.T`
M``D```"T[0``$P```+[M```)````TNT```0```#<[0``$````.'M```(````
M\NT```@```#[[0``!`````3N```+````">X```P````5[@``$@```"+N```1
M````->X```P```!'[@``&@```%3N```/````;^X```<```!_[@``#0```(?N
M```4````E>X```X```"J[@``#````+GN```;````QNX``"P```#B[@``$P``
M``_O```<````(^\``"@```!`[P``!@```&GO```'````<.\``!,```!X[P``
M!0```(SO```$````DN\``!<```"7[P``"@```*_O```,````NN\```D```#'
M[P``!@```-'O```)````V.\```@```#B[P``"0```.OO```*````]>\``!$`
M````\```!@```!+P```.````&?````X````H\```#0```#?P```+````1?``
M`!T```!1\```"P```&_P```"````>_````<```!^\```!@```(;P```)````
MC?````<```"7\```.P```)_P```H````V_```#0````$\0``%0```#GQ```%
M````3_$```<```!5\0``"````%WQ```'````9O$```4```!N\0``!P```'3Q
M```.````?/$```D```"+\0``!@```)7Q```(````G/$```L```"E\0``!P``
M`+'Q```(````N?$```<```#"\0``%@```,KQ```)````X?$```8```#K\0``
M"P```/+Q```<````_O$``!0````;\@``!P```##R```(````./(```@```!!
M\@``!0```$KR```0````4/(``!````!A\@``!@```'+R```9````>?(```H`
M``"3\@``'````)[R```'````N_(```4```##\@``$````,GR```4````VO(`
M``L```#O\@``#0```/OR```7````"?,```0````A\P``"0```";S```*````
M,/,```<````[\P```@```$/S```.````1O,```@```!5\P``'P```%[S```C
M````?O,``#@```"B\P``,0```-OS```G````#?0``&0````U]```%````)KT
M``!5````K_0``#@````%]0``2@```#[U``!;````B?4``"@```#E]0``.```
M``[V```H````1_8``"P```!P]@``)P```)WV```;````Q?8``#X```#A]@``
MJ0$``"#W```C````RO@``!<```#N^```2`````;Y``"%````3_D``#````#5
M^0``00````;Z``!;````2/H``$D```"D^@``'0```.[Z```8````#/L``"$`
M```E^P``'P```$?[```K````9_L``"$```"3^P``)P```+7[```=````W?L`
M`!$```#[^P``,P````W\```E````0?P``"<```!G_```'P```(_\```P````
MK_P``&D```#@_```/0```$K]``!E````B/T``$T```#N_0``+P```#S^```N
M````;/X``#````";_@``5````,S^``!:````(?\``$@```!\_P``2@```,7_
M```R````$``!`"\```!#``$`+````',``0`M````H``!`'$```#.``$`;P``
M`$`!`0"S````L`$!`!<```!D`@$`)0```'P"`0`R````H@(!`"D```#5`@$`
M/@```/\"`0`B````/@,!`%(```!A`P$`)0```+0#`0`+````V@,!`+$```#F
M`P$`10```)@$`0`A````W@0!`#``````!0$`)0```#$%`0`<````5P4!`#$`
M``!T!0$`!P```*8%`0`'````K@4!``0```"V!0$`#0```+L%`0`+````R04!
M``X```#5!0$`"P```.0%`0`%````\`4!`!````#V!0$``@````<&`0!9````
M"@8!``4```!D!@$`$@```&H&`0`$````?08!``<```""!@$`"````(H&`0`%
M````DP8!``,```"9!@$`$````)T&`0`,````K@8!`!,```"[!@$`#0```,\&
M`0`"````W08!``<```#@!@$`!@```.@&`0`4````[P8!``P````$!P$`&```
M`!$'`0`&````*@<!`!(````Q!P$`#````$0'`0`#````40<!`"H```!5!P$`
M!````(`'`0`&````A0<!``<```",!P$`'P```)0'`0`U````M`<!`"X```#J
M!P$`+P```!D(`0`7````20@!`"````!A"`$`&P```(((`0`8````G@@!`"0`
M``"W"`$`'P```-P(`0`:````_`@!`"`````7"0$`&@```#@)`0`R````4PD!
M`"\```"&"0$`*P```+8)`0`?````X@D!`",````""@$`'P```"8*`0`:````
M1@H!`"4```!A"@$`)@```(<*`0`E````K@H!`"0```#4"@$`&````/D*`0`=
M````$@L!`"0````P"P$`&````%4+`0`B````;@L!`"4```"1"P$`/````+<+
M`0`?````]`L!`",````4#`$`'P```#@,`0`@````6`P!`!H```!Y#`$`&```
M`)0,`0`F````K0P!`!X```#4#`$`*0```/,,`0`>````'0T!``D````\#0$`
M#````$8-`0`7````4PT!`"\```!K#0$`)````)L-`0`'````P`T!``\```#(
M#0$`%````-@-`0`.````[0T!``T```#\#0$`)`````H.`0`%````+PX!``<`
M```U#@$`(@```#T.`0`E````8`X!`!T```"&#@$`&@```*0.`0`'````OPX!
M`,<```#'#@$`"P```(\/`0`5````FP\!``8```"Q#P$`"0```+@/`0`+````
MP@\!`!<```#.#P$`!@```.8/`0`S````[0\!`!,````A$`$`$P```#40`0`'
M````21`!``\```!1$`$`!P```&$0`0`R````:1`!`"$```"<$`$`$P```+X0
M`0`,````TA`!`!$```#?$`$`,@```/$0`0`(````)!$!``D````M$0$`"@``
M`#<1`0`4````0A$!``H```!7$0$`'0```&(1`0`(````@!$!`!\```")$0$`
M"````*D1`0`:````LA$!``8```#-$0$`%0```-01`0`'````ZA$!``@```#R
M$0$`"0```/L1`0`_````!1(!``<```!%$@$`#P```$T2`0`.````71(!`!``
M``!L$@$`"0```'T2`0`)````AQ(!``@```"1$@$`$P```)H2`0`'````KA(!
M`!D```"V$@$`"@```-`2`0`7````VQ(!`!0```#S$@$`"@````@3`0`,````
M$Q,!`!<````@$P$`!````#@3`0`J````/1,!`!$```!H$P$`!P```'H3`0`"
M````@A,!`!````"%$P$`&````)83`0`+````KQ,!``,```"[$P$`"````+\3
M`0`&````R!,!``<```#/$P$`#0```-<3`0`+````Y1,!`!0```#Q$P$`%0``
M``84`0`.````'!0!`"\````K%`$`(````%L4`0`<````?!0!``P```"9%`$`
M,0```*84`0`%````V!0!`!(```#>%`$`/P```/$4`0`2````,14!``H```!$
M%0$`!@```$\5`0`$````5A4!``0```!;%0$`"@```&`5`0`3````:Q4!``4`
M``!_%0$`!@```(45`0`&````C!4!``0```"3%0$`#````)@5`0`*````I14!
M``4```"P%0$`&````+85`0`9````SQ4!`!\```#I%0$`'0````D6`0`1````
M)Q8!``(````Y%@$`!````#P6`0`*````018!``8```!,%@$`!0```%,6`0`#
M````618!``P```!=%@$`10```&H6`0`:````L!8!`#4```#+%@$`*`````$7
M`0!3````*A<!`!D```!^%P$`<@```)@7`0`@````"Q@!`#4````L&`$`(0``
M`&(8`0!%````A!@!`#````#*&`$`*````/L8`0`I````)!D!`"8```!.&0$`
M)0```'49`0`H````FQD!`"@```#$&0$`(@```.T9`0`P````$!H!`!(```!!
M&@$`$P```%0:`0`0````:!H!`'D```!Y&@$`"0```/,:`0!S````_1H!`'P`
M``!Q&P$`*P```.X;`0`7````&AP!`!8````R'`$`#P```$D<`0`?````61P!
M`$````!Y'`$`'P```+H<`0`<````VAP!`%$```#W'`$`%````$D=`0`*````
M7AT!``4```!I'0$`!@```&\=`0`(````=AT!``4```!_'0$`$@```(4=`0`0
M````F!T!`!,```"I'0$`'0```+T=`0`/````VQT!``\```#K'0$`!````/L=
M`0`)`````!X!``L````*'@$`!P```!8>`0`%````'AX!`!0````D'@$`!P``
M`#D>`0`(````01X!``\```!*'@$`"````%H>`0`,````8QX!``\```!P'@$`
M!@```(`>`0`4````AQX!``8```"<'@$`#````*,>`0`(````L!X!``0```"Y
M'@$`"@```+X>`0`'````R1X!``0```#1'@$`&0```-8>`0`"````\!X!``D`
M``#S'@$`!@```/T>`0`&````!!\!`"<````+'P$`!````#,?`0`/````.!\!
M`!,```!('P$`!P```%P?`0`'````9!\!``8```!L'P$`!@```',?`0`0````
M>A\!`!(```"+'P$`!@```)X?`0`)````I1\!`"(```"O'P$`!P```-(?`0`'
M````VA\!``L```#B'P$`!0```.X?`0`"````]!\!``L```#W'P$`QP$```,@
M`0`.````RR$!`!4```#:(0$`#0```/`A`0`'````_B$!``@````&(@$`"```
M``\B`0`*````&"(!``H````C(@$`$@```"XB`0`-````02(!``@```!/(@$`
M!0```%@B`0`=````7B(!``P```!\(@$`#0```(DB`0`5````ER(!`!````"M
M(@$`"P```+XB`0`0````RB(!``@```#;(@$`$P```.0B`0`-````^"(!``H`
M```&(P$`"P```!$C`0`+````'2,!``\````I(P$`!@```#DC`0`0````0",!
M`!8```!1(P$`"P```&@C`0`2````=",!`!(```"'(P$`"````)HC`0`M````
MHR,!`!D```#1(P$`.````.LC`0!!````)"0!`%,```!F)`$`40```+HD`0!9
M````#"4!`%<```!F)0$`.P```+XE`0`*````^B4!``X````%)@$`%@```!0F
M`0`%````*R8!``8````Q)@$`&0```#@F`0`,````4B8!`!0```!?)@$`%P``
M`'0F`0`G````C"8!`"8```"T)@$`$0```-LF`0`?````[28!``\````-)P$`
M!````!TG`0`1````(B<!`!`````T)P$`!P```$4G`0`4````32<!`!$```!B
M)P$`&````'0G`0`.````C2<!`!$```"<)P$`"@```*XG`0`I````N2<!`!,`
M``#C)P$`%P```/<G`0`0````#R@!`",````@*`$`!@```$0H`0`'````2R@!
M`$H```!3*`$`#````)XH`0`(````JR@!``L```"T*`$`!P```,`H`0`(````
MR"@!``\```#1*`$`"````.$H`0`*````ZB@!``,```#U*`$`&0```/DH`0`/
M````$RD!`!D````C*0$`%````#TI`0`2````4BD!`"@```!E*0$`#````(XI
M`0`G````FRD!`!<```##*0$`(P```-LI`0`=````_RD!`!(````=*@$`$@``
M`#`J`0`.````0RH!`!\```!2*@$`!@```'(J`0`&````>2H!``@```"`*@$`
M#@```(DJ`0`'````F"H!``H```"@*@$`$0```*LJ`0`(````O2H!``\```#&
M*@$`%@```-8J`0`:````[2H!``@````(*P$`$@```!$K`0`%````)"L!`!8`
M```J*P$`'@```$$K`0`-````8"L!`#````!N*P$`"0```)\K`0`'````J2L!
M`!0```"Q*P$`!0```,8K`0`%````S"L!`!````#2*P$`"P```.,K`0`:````
M[RL!`#,````*+`$`#P```#XL`0`F````3BP!`#,```!U+`$`,0```*DL`0`P
M````VRP!``@````,+0$`!0```!4M`0`)````&RT!``@````E+0$`.0```"XM
M`0`M````:"T!`#@```"6+0$`4P```,\M`0`W````(RX!`#<```!;+@$`-@``
M`),N`0`W````RBX!`"4````"+P$`*@```"@O`0`W````4R\!`#T```"++P$`
M#P```,DO`0`3````V2\!`"<```#M+P$`'````!4P`0`.````,C`!``L```!!
M,`$`#````$TP`0`&````6C`!``P```!A,`$`&@```&XP`0`F````B3`!``8`
M``"P,`$`!P```+<P`0`6````OS`!``D```#6,`$`"````.`P`0`&````Z3`!
M``D```#P,`$`!@```/HP`0`%`````3$!``4````',0$`!P````TQ`0`&````
M%3$!``H````<,0$`)0```"<Q`0`/````33$!``D```!=,0$`!0```&<Q`0`'
M````;3$!``<```!U,0$`!0```'TQ`0`-````@S$!``8```"1,0$`$P```)@Q
M`0`#````K#$!``@```"P,0$`"@```+DQ`0`-````Q#$!``@```#2,0$`(P``
M`-LQ`0`1````_S$!``D````1,@$`$@```!LR`0`,````+C(!``<````[,@$`
M`P```$,R`0`#````1S(!`!0```!+,@$`%````&`R`0`(````=3(!``@```!^
M,@$`"````(<R`0`'````D#(!`%<```"8,@$`)````/`R`0`&````%3,!``8`
M```<,P$`%P```",S`0`:````.S,!`!P```!6,P$`+````',S`0`;````H#,!
M`"X```"\,P$`<@```.LS`0`E````7C0!``H```"$-`$`!P```(\T`0`2````
MES0!`!$```"J-`$`#P```+PT`0`.````S#0!`!0```#;-`$`$````/`T`0`4
M`````34!``\````6-0$`%0```"8U`0`%````/#4!`!<```!"-0$`&P```%HU
M`0`7````=C4!`!0```".-0$``P```*,U`0`&````IS4!`&@```"N-0$`!```
M`!<V`0`6````'#8!``4````S-@$`!````#DV`0`>````/C8!`!@```!=-@$`
M#````'8V`0`8````@S8!`!@```"<-@$`+0```+4V`0`.````XS8!`"(```#R
M-@$`"````!4W`0`:````'C<!`!@````Y-P$`$P```%(W`0`<````9C<!`!@`
M``"#-P$`%````)PW`0`+````L3<!``@```"]-P$`!P```,8W`0`0````SC<!
M`!4```#?-P$`$````/4W`0`(````!C@!``4````/.`$`"P```!4X`0`,````
M(3@!``@````N.`$`#0```#<X`0`'````13@!``8```!-.`$`$0```%0X`0`(
M````9C@!``P```!O.`$`!P```'PX`0`%````A#@!``@```"*.`$`"````),X
M`0`3````G#@!``L```"P.`$`#@```+PX`0`%````RS@!`!T```#1.`$`$```
M`.\X`0`1`````#D!`#0````2.0$`1````$<Y`0`?````C#D!`#$```"L.0$`
M"@```-XY`0`/````Z3D!``<```#Y.0$`"0````$Z`0`/````"SH!``D````;
M.@$`$0```"4Z`0`A````-SH!`"$```!9.@$`)````'LZ`0`D````H#H!`!@`
M``#%.@$`(0```-XZ`0`;`````#L!`"4````<.P$`&@```$([`0`=````73L!
M`!@```![.P$`(P```)0[`0`I````N#L!`!L```#B.P$`)@```/X[`0`P````
M)3P!`"X```!6/`$`$0```(4\`0`I````ESP!``X```#!/`$`L````-`\`0`0
M````@3T!`!@```"2/0$`(P```*L]`0`D````SST!`!\```#T/0$`&P```!0^
M`0`@````,#X!`"$```!1/@$`+@```',^`0`<````HCX!`!X```"_/@$`*0``
M`-X^`0!+````"#\!``\```!4/P$`!````&0_`0`2````:3\!``@```!\/P$`
M#@```(4_`0`.````E#\!`!(```"C/P$`"P```+8_`0`4````PC\!``H```#7
M/P$`!````.(_`0`,````YS\!``\```#T/P$`#P````1``0`3````%$`!``P`
M```H0`$`,0```#5``0`+````9T`!`!$```!S0`$`!````(5``0`/````BD`!
M`!4```":0`$`&````+!``0`/````R4`!``(```#90`$`!0```-Q``0`2````
MXD`!``4```#U0`$`"P```/M``0`,````!T$!``,````400$`#P```!A!`0`(
M````*$$!`!@````Q00$`$````$I!`0`*````6T$!`!````!F00$`$P```'=!
M`0`(````BT$!``8```"400$`#@```)M!`0`,````JD$!`!@```"W00$`#```
M`-!!`0`.````W4$!`",```#L00$`#````!!"`0`>````'4(!`!<````\0@$`
M%0```%1"`0`,````:D(!``8```!W0@$`#@```'Y"`0`%````C4(!`"<```"3
M0@$`/P```+M"`0`%````^T(!``D````!0P$`'@````M#`0`+````*D,!`!,`
M```V0P$`$P```$I#`0`'````7D,!`!D```!F0P$`$@```(!#`0`8````DT,!
M`!````"L0P$`%0```+U#`0`(````TT,!``@```#<0P$`)@```.5#`0!(````
M#$0!``@```!51`$`%@```%Y$`0`'````=40!``H```!]1`$`,0```(A$`0`/
M````ND0!``4```#*1`$`!@```-!$`0`#````UT0!``<```#;1`$`!P```.-$
M`0`,````ZT0!``\```#X1`$`#0````A%`0`-````%D4!`!0````D10$`%0``
M`#E%`0`4````3T4!``4```!D10$`!0```&I%`0`+````<$4!``@```!\10$`
M`@```(5%`0`%````B$4!``\```".10$`(0```)Y%`0`2````P$4!`!````#3
M10$`#P```.1%`0`1````]$4!`!X````&1@$`,0```"5&`0`M````5T8!``H`
M``"%1@$`#@```)!&`0"+````GT8!`!8````K1P$`$````$)'`0`'````4T<!
M``4```!;1P$`(0```&%'`0`(````@T<!``<```",1P$`!P```)1'`0`&````
MG$<!`!````"C1P$`#@```+1'`0`1````PT<!``\```#51P$`&P```.5'`0`1
M`````4@!``T````32`$`%P```"%(`0`'````.4@!``D```!!2`$`%````$M(
M`0`-````8$@!`#L```!N2`$`&0```*I(`0`(````Q$@!``T```#-2`$`'0``
M`-M(`0`9````^4@!`"$````320$`(````#5)`0`:````5DD!`!L```!Q20$`
M)0```(U)`0`:````LTD!``4```#.20$`'0```-1)`0`0````\DD!``X````#
M2@$``P```!)*`0`$````%DH!``T````;2@$`#@```"E*`0`/````.$H!`!<`
M``!(2@$`"P```&!*`0`$````;$H!`!@```!Q2@$`&0```(I*`0`/````I$H!
M``T```"T2@$`#0```,)*`0`.````T$H!`!\```#?2@$`!@```/]*`0`&````
M!DL!``X````-2P$`#@```!Q+`0`-````*TL!``@````Y2P$`"````$)+`0`$
M````2TL!`!0```!02P$`"P```&5+`0`%````<4L!`"0```!W2P$`#P```)Q+
M`0!K````K$L!`!H````83`$`"0```#-,`0`&````/4P!``H```!$3`$`!@``
M`$],`0`(````5DP!``0```!?3`$`"@```&1,`0`"````;TP!``0```!R3`$`
M!P```'=,`0`5````?TP!`!(```"53`$`%````*A,`0`:````O4P!``(```#8
M3`$``@```-M,`0`.````WDP!``8```#M3`$`"@```/1,`0`%````_TP!`!D`
M```%30$`"````!]-`0`&````*$T!`!<````O30$`$````$=-`0`)````6$T!
M``<```!B30$`!0```&I-`0`)````<$T!``T```!Z30$`!@```(A-`0`&````
MCTT!`!D```"630$`"P```+!-`0`%````O$T!`!(```#"30$`!P```-5-`0`'
M````W4T!`!@```#E30$`'0```/Y-`0`'````'$X!``H````D3@$`!````"].
M`0`)````-$X!``@````^3@$`"P```$=.`0`+````4TX!``8```!?3@$`#0``
M`&9.`0`&````=$X!``0```![3@$`-P```(!.`0!!````N$X!`#@```#Z3@$`
M)@```#-/`0`%````6D\!``\```!@3P$`!@```'!/`0`(````=T\!`!\```"`
M3P$`&@```*!/`0`%````NT\!``@```#!3P$`$P```,I/`0`(````WD\!``D`
M``#G3P$`%P```/%/`0`&````"5`!``8````04`$`%0```!=0`0`%````+5`!
M``L````S4`$`#````#]0`0`(````3%`!``D```!54`$`!0```%]0`0`N````
M95`!`#0```"44`$`/````,E0`0`G````!E$!`#X````N40$`.````&U1`0`H
M````IE$!`#(```#/40$`+0````)2`0`U````,%(!`"@```!F4@$`$@```(]2
M`0`3````HE(!``T```"V4@$`,0```,12`0`<````]E(!`!P````34P$`&@``
M`#!3`0`'````2U,!``@```!34P$`!P```%Q3`0`(````9%,!`"8```!M4P$`
M)````)13`0`Q````N5,!``D```#K4P$`&````/53`0`H````#E0!`!8````W
M5`$`$@```$Y4`0`&````850!``L```!H5`$`#````'14`0`.````@50!``\`
M``"05`$`.````*!4`0"`````V50!`&8```!:50$`#P```,%5`0`+````T54!
M``P```#=50$`$0```.I5`0`2````_%4!``X````/5@$`!P```!Y6`0`/````
M)E8!`!0````V5@$`$0```$M6`0`/````758!`!X```!M5@$`,````(Q6`0!]
M````O58!`!`````[5P$`!0```$Q7`0`4````4E<!``D```!G5P$`"0```'%7
M`0`)````>U<!`!(```"%5P$`#@```)A7`0`.````IU<!`!,```"V5P$`%0``
M`,I7`0`?````X%<!`"$`````6`$`'0```")8`0`?````0%@!`"````!@6`$`
M(@```(%8`0`8````I%@!`#<```"]6`$`#P```/58`0`1````!5D!`!$````7
M60$`$P```"E9`0`-````/5D!`!(```!+60$`%````%Y9`0`/````<UD!`!$`
M``"#60$`,@```)59`0`6````R%D!`!0```#?60$`/````/19`0`4````,5H!
M``H```!&6@$`$P```%%:`0`B````95H!`!(```"(6@$`*````)M:`0`9````
MQ%H!`!D```#>6@$`%P```/A:`0`2````$%L!`!\````C6P$`(@```$-;`0`:
M````9EL!`!(```"!6P$`%P```)1;`0`<````K%L!`!8```#)6P$`"````.!;
M`0`8````Z5L!``0````"7`$`!0````=<`0`+````#5P!`!`````97`$`!@``
M`"I<`0`,````,5P!``<````^7`$`!@```$9<`0`'````35P!``4```!57`$`
M"````%M<`0`8````9%P!``8```!]7`$`"0```(1<`0`(````CEP!``8```"7
M7`$`"````)Y<`0`1````IUP!`!(```"Y7`$`#P```,Q<`0`0````W%P!``H`
M``#M7`$`$0```/A<`0`$````"ET!`"$````/70$`#P```#%=`0`/````05T!
M`!8```!170$`"P```&A=`0`)````=%T!``L```!^70$`+P```(I=`0`$````
MNET!``@```"_70$`!````,A=`0`%````S5T!`!$```#370$`!@```.5=`0`*
M````[%T!``H```#W70$`!0````)>`0`C````"%X!``X````L7@$`$0```#M>
M`0`5````35X!`!<```!C7@$`'````'M>`0`:````F%X!``4```"S7@$`!0``
M`+E>`0`)````OUX!`!D```#)7@$`!P```.->`0`&````ZUX!``T```#R7@$`
M#@````!?`0`'````#U\!``<````77P$`!0```!]?`0`/````)5\!``X````U
M7P$`"@```$1?`0`0````3U\!`!(```!@7P$`%````'-?`0`4````B%\!``T`
M``"=7P$`%@```*M?`0`(````PE\!``4```#+7P$`$@```-%?`0!(````Y%\!
M``8````M8`$`#P```#1@`0`C````1&`!``\```!H8`$`%0```'A@`0`.````
MCF`!``T```"=8`$`#P```*M@`0`)````NV`!``\```#%8`$`#P```-5@`0`1
M````Y6`!`!````#W8`$`'@````AA`0`*````)V$!``@````R80$`#````#MA
M`0`,````2&$!``P```!580$`!0```&)A`0`,````:&$!``D```!U80$`'@``
M`']A`0!G````GF$!`!,````&8@$`"P```!IB`0`%````)F(!``4````L8@$`
M$@```#)B`0`4````16(!`!,```!:8@$`"P```&YB`0`"````>F(!``H```!]
M8@$`+P```(AB`0`#````N&(!``4```"\8@$`)@```,)B`0`*````Z6(!``4`
M``#T8@$`!0```/IB`0`3`````&,!`!(````48P$`!@```"=C`0`(````+F,!
M``<````W8P$`!````#]C`0`%````1&,!`&X```!*8P$`"@```+EC`0`-````
MQ&,!``8```#28P$`!0```-EC`0`I````WV,!`#(````)9`$`$0```#QD`0`*
M````3F0!`!$```!99`$`"@```&MD`0`)````=F0!`!D```"`9`$`)P```)ID
M`0`I````PF0!`"@```#L9`$`#P```!5E`0`&````)64!``<````L90$`"```
M`#1E`0`'````/64!``X```!%90$`#````%1E`0`&````864!`$4```!H90$`
M$````*YE`0`*````OV4!``8```#*90$`'````-%E`0!A````[F4!``8```!0
M9@$`"````%=F`0`&````8&8!`!0```!G9@$`"0```'QF`0`(````AF8!`"D`
M``"/9@$`*````+EF`0`)````XF8!``4```#L9@$`*P```/)F`0!G````'F<!
M`"D```"&9P$`+@```+!G`0`8````WV<!``(```#X9P$`#0```/MG`0`%````
M"6@!`!0````/:`$`"@```"1H`0`%````+V@!``@````U:`$`!@```#YH`0`)
M````16@!``L```!/:`$`!P```%MH`0`(````8V@!``L```!L:`$`!@```'AH
M`0`.````?V@!`!````".:`$`$0```)]H`0`-````L6@!``\```"_:`$`$```
M`,]H`0`/````X&@!``T```#P:`$`#P```/YH`0`(````#FD!`!X````7:0$`
M$P```#9I`0`(````2FD!``H```!3:0$`%@```%YI`0`'````=6D!``\```!]
M:0$`!0```(UI`0`'````DVD!``4```";:0$`!0```*%I`0`(````IVD!`!$`
M``"P:0$`$0```,)I`0`:````U&D!`!8```#O:0$`%`````9J`0`7````&VH!
M`!H````S:@$`'P```$YJ`0`8````;FH!``,```"':@$`!0```(MJ`0`.````
MD6H!``X```"@:@$`%@```*]J`0`B````QFH!``L```#I:@$`%````/5J`0`'
M````"FL!``H````2:P$`!0```!UK`0`.````(VL!``D````R:P$`!0```#QK
M`0`'````0FL!``,```!*:P$`!````$YK`0`"````4VL!`#X```!6:P$`-```
M`)5K`0`4````RFL!`"H```#?:P$`10````IL`0`*````4&P!`"P```!;;`$`
M,P```(AL`0`X````O&P!`#@```#U;`$`/0```"YM`0`4````;&T!`!H```"!
M;0$`&P```)QM`0`<````N&T!`!L```#5;0$`'P```/%M`0`;````$6X!`!L`
M```M;@$`#@```$EN`0`P````6&X!`#````");@$`-````+IN`0`]````[VX!
M`#(````M;P$`+P```&!O`0!R````D&\!`"8````#<`$`#````"IP`0`*````
M-W`!`#,```!"<`$`-0```'9P`0`G````K'`!``T```#4<`$`1````.)P`0`_
M````)W$!``4```!G<0$`&P```&UQ`0`6````B7$!`!(```"@<0$`$0```+-Q
M`0`9````Q7$!``8```#?<0$`!P```.9Q`0`)````[G$!``X```#X<0$`%```
M``=R`0`.````''(!`!$````K<@$`"````#UR`0`>````1G(!``@```!E<@$`
M!0```&YR`0`+````='(!``T```"`<@$`"P```(YR`0`Z````FG(!``(```#5
M<@$`!@```-AR`0`.````WW(!``D```#N<@$`!0```/AR`0`2````_G(!``@`
M```1<P$`!````!IS`0`S````'W,!``X```!3<P$`*0```&)S`0!0````C',!
M`!4```#=<P$`.@```/-S`0`@````+G0!``\```!/=`$`"````%]T`0`/````
M:'0!``\```!X=`$`"@```(AT`0`4````DW0!``P```"H=`$`&@```+5T`0`5
M````T'0!``<```#F=`$`$0```.YT`0`1`````'4!`"$````2=0$`%````#1U
M`0`2````274!`!````!<=0$`(P```&UU`0`'````D74!``L```"9=0$`%```
M`*5U`0`2````NG4!`!$```#-=0$`&@```-]U`0`0````^G4!``P````+=@$`
M!P```!AV`0`(````('8!``4````I=@$`(0```"]V`0`&````478!`!$```!8
M=@$`"````&IV`0`.````<W8!``4```""=@$`#P```(AV`0`O````F'8!`!(`
M``#(=@$`!@```-MV`0`'````XG8!`!<```#J=@$`!@````)W`0`2````"7<!
M``4````<=P$`%0```")W`0`$````.'<!``<````]=P$`%@```$5W`0`Q````
M7'<!``4```".=P$`$P```)1W`0`0````J'<!``0```"Y=P$`#@```+YW`0`(
M````S7<!``<```#6=P$`"@```-YW`0`(````Z7<!``8```#R=P$`!0```/EW
M`0`@````_W<!`#4````@>`$`-0```%9X`0`;````C'@!`"0```"H>`$`(P``
M`,UX`0`_````\7@!`!L````Q>0$`)@```$UY`0`M````='D!`"0```"B>0$`
M!@```,=Y`0`(````SGD!``D```#7>0$`"P```.%Y`0`7````[7D!`!`````%
M>@$`+@```!9Z`0`D````17H!`#0```!J>@$`.````)]Z`0`1````V'H!`"(`
M``#J>@$`$@````U[`0`&````('L!`!L````G>P$`$@```$-[`0`1````5GL!
M``T```!H>P$`!P```'9[`0`.````?GL!``@```"->P$`"P```)9[`0`,````
MHGL!`!L```"O>P$`-````,M[`0`)`````'P!``4````*?`$`"0```!!\`0`:
M````&GP!`!$````U?`$`!````$=\`0`*````3'P!``L```!7?`$`$````&-\
M`0`.````='P!``P```"#?`$`%@```)!\`0`%````IWP!``4```"M?`$`#P``
M`+-\`0`L````PWP!`$L```#P?`$`%@```#Q]`0`=````4WT!`!H```!Q?0$`
M!0```(Q]`0`0````DGT!``<```"C?0$`$0```*M]`0`L````O7T!``D```#J
M?0$`#@```/1]`0`1`````WX!`!4````5?@$`#0```"M^`0`Y````.7X!``D`
M``!S?@$`'0```'U^`0`3````FWX!`!<```"O?@$`+P```,=^`0`/````]WX!
M`!$````'?P$`%P```!E_`0`>````,7\!``@```!0?P$`$@```%E_`0`'````
M;'\!`!0```!T?P$`&@```(E_`0`'````I'\!``<```"L?P$`$````+1_`0`/
M````Q7\!`!$```#5?P$`!0```.=_`0`(````[7\!``T```#V?P$`#0````2`
M`0`.````$H`!`!`````A@`$`$````#*``0`&````0X`!``@```!*@`$`+@``
M`%.``0`F````@H`!`"0```"I@`$`!P```,Z``0`.````UH`!``8```#E@`$`
M%P```.R``0`7````!($!`"(````<@0$`"@```#^!`0`+````2H$!``,```!6
M@0$`!@```%J!`0`,````88$!``(```!N@0$`#````'&!`0`3````?H$!``L`
M``"2@0$`&0```)Z!`0`@````N($!`!(```#9@0$`!0```.R!`0`*````\H$!
M`!4```#]@0$`$0```!."`0`.````)8(!``8````T@@$`"0```#N"`0`0````
M18(!`$H```!6@@$`%P```*&"`0`$````N8(!``@```"^@@$`%````,>"`0`.
M````W((!``P```#K@@$`(@```/B"`0`7````&X,!``T````S@P$`(P```$&#
M`0`<````98,!``T```""@P$`8@```)"#`0`B````\X,!`!8````6A`$`*P``
M`"V$`0`@````680!`!0```!ZA`$`'@```(^$`0`6````KH0!`!\```#%A`$`
M&````.6$`0`*````_H0!``<````)A0$`!P```!&%`0`$````&84!`!,````>
MA0$`#0```#*%`0`1````0(4!``@```!2A0$`00```%N%`0`\````G84!`$(`
M``#:A0$`8````!V&`0`)````?H8!`#X```"(A@$`+P```,>&`0`*````]X8!
M``H````"AP$`#@````V'`0`[````'(<!``@```!8AP$`.````&&'`0`N````
MFH<!`"(```#)AP$`#P```.R'`0`I````_(<!`!@````FB`$`,````#^(`0`B
M````<(@!`"@```"3B`$`(@```+R(`0`/````WX@!``@```#OB`$`#@```/B(
M`0`/````!XD!`!`````7B0$`!P```"B)`0`]````,(D!``P```!NB0$`#@``
M`'N)`0`&````BHD!`!4```"1B0$`"````*>)`0`(````L(D!``\```"YB0$`
M"0```,F)`0`)````TXD!``<```#=B0$`$````.6)`0`0````]HD!`!8````'
MB@$`%P```!Z*`0`1````-HH!`!L```!(B@$`$P```&2*`0`(````>(H!``T`
M``"!B@$`#````(^*`0`/````G(H!``P```"LB@$`&0```+F*`0`L````TXH!
M``\`````BP$`'P```!"+`0`H````,(L!``@```!9BP$`!@```&*+`0`0````
M:8L!``D```!ZBP$`!````(2+`0`8````B8L!``X```"BBP$`$````+&+`0`.
M````PHL!``4```#1BP$`"0```->+`0`(````X8L!``D```#JBP$`"P```/2+
M`0`1`````(P!``0````2C`$`#@```!>,`0`%````)HP!``L````LC`$`#@``
M`#B,`0`A````1XP!``H```!IC`$``@```'2,`0`'````=XP!``4```!_C`$`
M"P```(6,`0`'````D8P!`#(```"9C`$`)````,R,`0`Q````\8P!`!<````C
MC0$`!0```#N-`0`'````08T!``<```!)C0$`#````%&-`0`(````7HT!``T`
M``!GC0$`$P```'6-`0`/````B8T!``P```"9C0$`#@```*:-`0`+````M8T!
M``<```#!C0$`"````,F-`0`(````THT!`!8```#;C0$`"0```/*-`0`'````
M_(T!``D````$C@$`(`````Z.`0`%````+XX!``8````UC@$`!@```#R.`0`*
M````0XX!``<```!.C@$`$@```%:.`0`2````:8X!``8```!\C@$`%@```(..
M`0`+````FHX!`!L```"FC@$`!````,*.`0`%````QXX!``\```#-C@$`'```
M`-V.`0`'````^HX!``D````"CP$`%0````R/`0`$````(H\!``H````GCP$`
M#P```#*/`0`*````0H\!``(```!-CP$`$0```%"/`0`'````8H\!`!X```!J
MCP$`'@```(F/`0`S````J(\!`"4```#<CP$`*0````*0`0!=````+)`!`!,`
M``"*D`$`5````)Z0`0`N````\Y`!`$$````BD0$`7@```&21`0`@````PY$!
M`$H```#DD0$`*````"^2`0`R````6)(!`",```"+D@$`'0```*^2`0`L````
MS9(!`.X!``#ZD@$`&P```.F4`0`4````!94!`$8````:E0$`A0```&&5`0`_
M````YY4!`#$````GE@$`2P```%F6`0`X````I98!`!P```#>E@$`%0```/N6
M`0`8````$9<!`!<````JEP$`*P```$*7`0`<````;I<!`!\```"+EP$`$P``
M`*N7`0`,````OY<!`"\```#,EP$`'@```/R7`0`?````&Y@!`"$````[F`$`
M0@```%V8`0!0````H)@!`#4```#QF`$`80```">9`0!&````B9D!`"\```#0
MF0$`)P````":`0`L````*)H!`$<```!5F@$`4````)V:`0!!````[IH!`$X`
M```PFP$`+0```'^;`0`E````K9L!`"4```#3FP$`)@```/F;`0!J````()P!
M`&@```"+G`$`K@```/2<`0`;````HYT!`"H```"_G0$`-@```.J=`0`O````
M(9X!`$4```!1G@$`(````)>>`0!1````N)X!`"$````*GP$`"P```"R?`0"U
M````.)\!`#P```#NGP$`(@```"N@`0`J````3J`!`"L```!YH`$`'````*6@
M`0`O````PJ`!``8```#RH`$`!@```/F@`0`#`````*$!``X````$H0$`"P``
M`!.A`0`*````'Z$!``L````JH0$`!0```#:A`0`,````/*$!``0```!)H0$`
M;@```$ZA`0`$````O:$!`!8```#"H0$`!````-FA`0`'````WJ$!``4```#F
MH0$`!0```.RA`0`$````\J$!`!````#WH0$`"`````BB`0`1````$:(!`!,`
M```CH@$``@```#>B`0`'````.J(!``<```!"H@$`%````$JB`0`,````7Z(!
M`!8```!LH@$`!@```(.B`0`3````BJ(!``P```">H@$``P```*NB`0`H````
MKZ(!``0```#8H@$`!@```-VB`0`(````Y*(!`!L```#MH@$`-`````FC`0`G
M````/J,!`"@```!FHP$`$P```(^C`0`@````HZ,!`!T```#$HP$`&P```.*C
M`0`@````_J,!`!L````?I`$`&@```#ND`0`B````5J0!`!0```!YI`$`,0``
M`(ZD`0`O````P*0!`"8```#PI`$`&@```!>E`0`>````,J4!`!X```!1I0$`
M&0```'"E`0`C````BJ4!`!T```"NI0$`*````,RE`0`:````]:4!`!L````0
MI@$`(````"RF`0`C````3:8!`!D```!QI@$`(0```(NF`0`>````K:8!`#8`
M``#,I@$`'@````.G`0`B````(J<!`"(```!%IP$`(P```&BG`0`=````C*<!
M`!@```"JIP$`(@```,.G`0`A````YJ<!`#(````(J`$`(````#NH`0`*````
M7*@!``L```!GJ`$`%@```'.H`0`H````BJ@!`!T```"SJ`$`"@```-&H`0`/
M````W*@!`!<```#LJ`$`#@````2I`0`6````$ZD!`"$````JJ0$`"````$RI
M`0`'````5:D!`"(```!=J0$`)0```("I`0`E````IJD!`!8```#,J0$`"@``
M`..I`0#<````[JD!`!$```#+J@$`%0```-VJ`0`,````\ZH!``\`````JP$`
M%@```!"K`0`C````)ZL!``8```!+JP$`0````%*K`0`5````DZL!`!0```"I
MJP$`!P```+ZK`0`3````QJL!``H```#:JP$`-P```.6K`0`I````':P!`!8`
M``!'K`$`%````%ZL`0`4````<ZP!`#$```"(K`$`$0```+JL`0`2````S*P!
M`!,```#?K`$`$0```/.L`0`*````!:T!`!<````0K0$`"````"BM`0`@````
M,:T!``@```!2K0$`$P```%NM`0`'````;ZT!`!$```!WK0$`!P```(FM`0`(
M````D:T!``D```":K0$`-@```*2M`0`%````VZT!``\```#AK0$`%````/&M
M`0`1````!JX!``L````8K@$`#````"2N`0`'````,:X!`!,````YK@$`"P``
M`$VN`0`;````6:X!`!````!UK@$`&@```(:N`0`7````H:X!``L```"YK@$`
M#````,6N`0`8````TJX!``D```#KK@$`*@```/6N`0`1````(*\!``H````R
MKP$``@```#VO`0`0````0*\!`!<```!1KP$`"P```&FO`0`#````=:\!``H`
M``!YKP$`!0```(2O`0`'````BJ\!``P```"2KP$`"P```)^O`0`4````JZ\!
M`!4```#`KP$`#@```-:O`0`X````Y:\!`!@````>L`$`&````#>P`0`*````
M4+`!`"4```!;L`$`!0```(&P`0`6````A[`!`#P```">L`$`#0```-NP`0`.
M````Z;`!``8```#XL`$`!````/^P`0`$````!+$!``H````)L0$`%P```!2Q
M`0`%````++$!``8````RL0$`"````#FQ`0`%````0K$!`!0```!(L0$`%0``
M`%VQ`0`%````<[$!`!<```!YL0$`'@```)&Q`0`?````L+$!`!H```#0L0$`
M$````.NQ`0`"````_+$!``0```#_L0$`"P````2R`0`%````$+(!``4````6
ML@$``P```!RR`0`.````(+(!`$P````OL@$`'````'RR`0`J````F;(!`"8`
M``#$L@$`3@```.NR`0`?````.K,!`%T```!:LP$`'0```+BS`0!'````UK,!
M`"`````>M`$`,0```#^T`0`S````<;0!`"@```"EM`$`-````,ZT`0`V````
M`[4!`#0````ZM0$`,````&^U`0`H````H+4!`"(```#)M0$`.````.RU`0`4
M````);8!`!4````ZM@$`#@```%"V`0!A````7[8!``H```#!M@$`8P```,RV
M`0!I````,+<!`"<```":MP$`&P```,*W`0`8````WK<!`!$```#WMP$`'0``
M``FX`0`Y````)[@!`"(```!AN`$`&P```(2X`0!J````H+@!`!8````+N0$`
M"@```"*Y`0`$````+;D!``8````RN0$`"````#FY`0`%````0KD!`!4```!(
MN0$`$@```%ZY`0`9````<;D!`",```"+N0$`#P```*^Y`0`-````O[D!``0`
M``#-N0$`"0```-*Y`0`-````W+D!``@```#JN0$`"0```/.Y`0`6````_;D!
M``L````4N@$`"@```""Z`0`5````*[H!``D```!!N@$`!@```$NZ`0`3````
M4KH!``H```!FN@$`%@```'&Z`0`*````B+H!``<```"3N@$`"````)NZ`0`(
M````I+H!``P```"MN@$`!@```+JZ`0`&````P;H!`!D```#(N@$``@```.*Z
M`0`(````Y;H!``8```#NN@$`!@```/6Z`0`I````_+H!``4````FNP$`$P``
M`"R[`0`9````0+L!``@```!:NP$`!P```&.[`0`&````:[L!``H```!RNP$`
M$````'V[`0`9````CKL!``@```"HNP$`#````+&[`0`C````OKL!``H```#B
MNP$`"0```.V[`0`0````][L!``4````(O`$``@````Z\`0`+````$;P!``$`
M```N`0``$`4``(@&``#/!```X@4``/\````5`@```````#0%```=`0``/P,`
M``````!(!`````````4#```D````=08`````````````(@$``-4#``!H`0``
MG@$``"$#``!L!```S@$``$`&``!)`P``0`````````"?`P````````````#@
M`P``*04``)<!````````N0,``)4$````````*0``````````````'`0``$<&
M````````KP,`````````````.@$``&T!``#7!```/0,``/8#```V`P``````
M``D$````````+0$``",$``#R!0``7`$`````````````5P,```````"Q`P``
MG0(``)8#``!=`0``>`0``/X"````````W0(``/H```"5`0```````"X&``#2
M````%`8```<$````````O`,``.0%``"2!```#`,``'(&``"B`P``00$`````
M``#K!```````````````````50```#D"``"\````%P8``.`````W!```80``
M``,``````````P$``-,"``"7!```2@,``-(!```)`@```````(8!``#)!```
M'P(``.$`````````G@,```T$``!.`P``=@,``+<#``#/`````````,<!``!%
M`0```````"`%``!^!0``)08``.8```#P!```.`,``&T$`````````````!D"
M``#N`@``F`8``'<$``"C`0``S`0``-P```#K`@``30$``!`"``#'````#0,`
M`%,#```8!@``0`4```@!````````;@0``$8!````````_P(``'D%``#7`0``
MK@0``&8`````````*@0``````````````````/0"``!&!@``F`0``.8$``!7
M!@``X@,``"8&``#]`P``RP4``-T#```````````````````F`@```````!X`
M``#@!0``S@(``````````````````(D%``"0`P``,P(``/(#``"Y`0``Y`(`
M`'\$``!*!0```````-H%``".!@``I0,``'4```#@`0``G@4``"0"````````
M<@4``,`$``!;`@``1P$``!0$`````````````,8#``"-!0``FP,`````````
M````8`$``(H````M!0``?0,``(0%``!\!0``O@,```@````$!@``YP0``-@$
M``#:!`````````<!```\````.`(``$8```#M!```.P(````````V````````
M`)`$````````VP````````"$!```B`0```````"G`P``4P$``#T"``#E`P``
M$@$```````";`@```````*0#``"D`@``;`,``%@#``#G`@`````````%``#4
M`@``^`$``#\```"N`0```````(@%``!A`@``Q04``$4"```S!0``I0$``'0#
M``"-!@``D@```+H%``!#`0``O@0```````````````````````"2!@``\0$`
M`(8$``"3`0``1`(```````!W!@```````%@```!1`0``J`0``(P"````````
M9@,``*4"````````J````#0!````````H0```'L!``#8!0``5@8``%(&``!@
M`P``208`````````````<`$``+T$`````````````$T%``"#`P```````$P$
M``#]!```%P(``$D```#C`0``TP,```````"J`0``>````&L#``#L`@``M`0`
M````````````<`4``)P```#"!0``.@```"4"```M!```7@(```````#S`P``
M"@(```````!P`@``_P0``(0```#)````%@8`````````````30```#,```#E
M!````````*8!``!>`P``*P$``'<#``"G!0```````#X#``!,`0````````\`
M``"1!@``5P(``/``````````P04```\"``"$`@``;0,``'0$```+`P``*```
M`)T$``"/`P``@0,``#$#``!Z!```H0$``+H#``"8`P``+@4``%,&`````@``
M.P,``-(#````````<P0``$H$``".`0``O04``+(%``"L`@``(`(`````````
M````W`4``,8"`````````0(``!4!``#,`@```````!````!=````````````
M``!``0``JP4``.P#```\`@``"08```````"-`0``C@4```````#&!0``9`$`
M`/,"````````(````.,````3!0```````"4$``````````````````!T!@``
MU0(``'(````8!``````````````T!```W`(```````"?````U@(```,&````
M````D0,```\%``!B`@``.@4`````````````;@4``*X%```9!@``5`8``*\"
M``"=`0``CP````````"I!0```````/<!```6````$@,``,$```!P`P``#@(`
M`",%````````;P0`````````````,`8``%0```!8`0``OP$``($$``"#`@``
M`````*D"``"'!@``'````%4"````````)P$```````!#!0``^0(``/@"``#`
M!0``1@4``)D$`````````````#8$```'`P``8P4``(P!````````````````
M`````````````&`$`````````````'8!````````>0(`````````````````
M`+,!````````=0$```````#I!```]`4``,$!```````````````````W````
M@@0``",```!"`0``TP````````#"`````````$X``````````````&<$``![
M!```WP```$X%``#P`P````````````#``0``'0(````````9!0``"P8``+4%
M``"(````Y@4``/4"``#(`@``-`,```````!>!@``8@```%D!``"A`@``C`8`
M`.$$``"@!```````````````````C@```.@"```H`P``@`4``&<&```G`@``
M&P(``)H"``##````4@4```0"``!=!```S`,``)`!``"V`@``>0```(,%```0
M!@```@(``&L%``"#`0``(P(``!`#``!\`0``YP$``!P!````````4P```+D$
M``#P!0``[0(``.@%``!E````R0(``'H&`````````````%H```"[````[```
M`*T"``!4`0```````"D!``"J````B`$``"<&```A`@``&`4``"@&````````
M`````#("``!=!@```````$,#``":!0````````X%``!U!```E@8```$%```9
M!```.0$````````P!```4@,`````````````OP,```````"X!0``````````
M``!6`@```````#D&``#)!0``90,``.\%``"S!0``9P,``.T!``#V!```````
M````````````Y04``*@%``!$````Q0$```````!'!0``,P0``!4%```C!@``
MJ`$``'\!```-`@``D@$``-D```!:`0``W@4``'\%```2`@``;P(``'D$``#=
M!0```P(``$0#``!;!0``?@(``'L```!3!```EP(``(P%````````@`$``,@!
M``!8!```M`4```````#B`````````)X"``"?!0``00(```````"R`P``````
M`'("````````3@8``%(!``#W`P``!@,```````#R`0``HP4`````````````
M`````(\!``!8`@``:0(``&X````N!````````!8"``#5!````````-8#``!S
M`P``0@(``!\$``!E`0``5@,````````Q`@``0`0``'8"``"+!0``WP4`````
M``!F`@``$08``"`&``#_!0``&`,``((#``!H!0``]00```````"I!```.`0`
M`+H"``![!0``&@$``&P```"?`@``````````````````2P```#4%````````
MSP(```,#```Y!```'08``%4&``"K!```^00``*P$``#T`0``#@$``-@#```'
M`@```````&`````K!0``F@,``*H$`````````````-D%``#!`@```````,,%
M``"P`P``1`8``)L```````````````````#O`@``B08``$L&````````W@$`
M``````"X````1@(```````!0`@``=0(``"H!````````.P8``!@"``!#!```
MM@4```````"R!```[P,```````"V!```$0```*0%``"3!@``DP(``%("``"D
M`0``A00````````K````W`$``&,"``````````````````#:`P``B`(``%8!
M``#'`P``2`$``$X$```<`@``/P$```(#```O!````````/D!````````20(`
M``````!W`@``*@,``,L!```_!@```````'@%``!<`@``H@4``,@`````````
M5P```(P$``#C`P``2P0``(D```"1````D@4``)P!```<!0``<P$``-0%```M
M`P``JP$`````````````H@```+T#``#B`@```````)8"``"W!0``````````
M``!Q`0``3P,``/T"``#.!```2@```'X````K!@``%P,``(0#``#W`@``````
M`,H%```H`0``Q`(``"8#``#'!0```@4``-L%`````````````!X!```B`@``
MHP0````````7!0```````/4````!`0``@0$``*`%``#`````.@0``#T!````
M````U@$`````````````]`````````#A`0````````````!F!```D````!X"
M````````'@0``*D```"S`@``,`,``-X```#"`0````````````!0!@``7`,`
M``````!Z`P````````````#Q`P``)`$````````_!0``104``#X```"(`P``
M``````````!!`````````,L`````````808``&0``````````````)4&``"*
M!0``^P,``#(%````````$P8``)0&``#I`@````````````!T````^`,``'8&
M``!1`P``!@8``#T%````````M@,``+@!``#'`@```````(4%````````(`,`
M`!(%``"7`P```````'@&``"G!```B@8`````````````HP(``+`"```6`0``
M(0$``#X$``!1`@``&`$``$<```!$`0``^@(````````A!````````#P$``!D
M`@``\P```#@```!9````S@```&,$``!D!```KP0```````")!```[P0`````
M````````;@(`````````````B@,``+`$``""!0``)P,``$@"``"%`@``````
M````````````'0,``-\!`````````````.$%```6!0``-P8``#4```"%`P``
M`````+`%``!J``````````````#%`P````,``.D!````````VP0```\&``#,
M!0``$P0```````"Q````%P$``,T!``!4`@``)@0```````!N`P````8``(X"
M``!O`P``#`4``(4!```M!@``0P````````"N`P``4@0``*T```";!0``L@(`
M``($``#:`0``9@8``)0!``#$`````````+<$``!_````FP0``$`"``!O`0``
M>@4``*<````$`P``)@```(<#`````0```````/P#``#^!0``9`8```````")
M`0``U`0```````##`0``8@$``.4```!X`P``;P4```````"D!```?08``#L!
M````````3P```"\```!/`@````````````#1`@``Z````-````!@`@``!`0`
M``4```"N`@``#@0```\!``"_`````````+P"``"#!@``````````````````
ML`$``)H$``#]!0``K00``,@$````````4`4```````#6````E0(``$@&````
M````_@,``%L````5````+`$``*T%````````?`8``,\#````````````````
M```O`P``1P(```````#4`P``:00``&(%``!5`0``+P$```````#U`0``````
M`.0$``#C`@``"@4``/T!```E````%````````````````````&`&````````
M`````````````````````!0%``````````````````#7`````````%0#```A
M!@``@`0`````````````$@````````#-````5`4``-(%```E`0``CP0``#D#
M``#5!0``'`8``/\!``#$`0```````%\&``"^`@``<08``-X#``!F`0``<P8`
M`````````````````)$!``!/!0``7@4``&\````N````"@$`````````````
MT0$``-D$```&`0```````*\```````````````L!```*!```W00````````-
M`0```````%D&````````E````/@%```J`@``I@(``-<%``"B`0``$0,``'``
M``"1`@``````````````````IP(``$\$````````4`,``,P!```G!```````
M`.,$``!D!0`````````````:`@```````)8%``#Z`0``2P$``"P`````````
M`````%H"`````````````'T!`````````````+,`````````$0(``#T```!,
M`@``VP(``$(&````````3````)@"``#[`0``(`$``*H#`````````````*8`
M``#.`P``EP4``.D#``#D`````````/0$```I`P````````````#M`P``Y`,`
M`.H#```E`P````````````!0!```M00``-<"``#9`P``.04``#@&``#N!```
MG04``+L$``"4!```F0(``!H````Q!@``(@4``)8!``!E!0```````"@%````
M````^`0```````!G`@``8@8``/P%```_`@```````#<"`````````````+0`
M```/`P``X0(````$```.`P```````"X#````````-`(``-@`````````6P8`
M`"0#``"]`0``)04``/H#````````WP(``%$%``#Y````A`8``"8%``!>````
MV`(``+8```!S!0```````"D&```2!@``\0```'P"``!O!@``!@(``#8"``##
M`P``V@(``-<#````````2P,````````/!```D`(``)P%``",`P``Y@,``'($
M``!R`0```````%D$``"9``````````````!:`P``504``/L```#^`0``````
M`&H!```;!@```````!H%`````````````$4#``!S````F@````````#S!```
M00,``(0!```=````I0```'H!``!?`P``O@$`````````````A@,`````````
M````-0(``.($``!=`P``+`8``'X$`````````````),#``#"`P``-```````
M``"/!0``!@````````"@`@``Q0```/($````````,`(``%$```##!```(P$`
M`,@%``!)!```_@```&L!``"L`````````!L```#@`@```````.L%````````
M`````$4$```4`P``H00``(T$``!)`0````````P"``!?`@```````+\%````
M````WP0```````!?`0``"@8``)H!``"9`0``800``(\&``!@!0```@```'4#
M``!S`@```````!D`````````0@0``&$!``!R`P``!@4``.H$``#&`0``6`8`
M`&L&``#J````AP(``,D!````````G`0```````"F!0```````"$```"8!0``
M;@8``&@"``#\`0``S````(<!``"K`P````````P!``!9`P``3P$```T&````
M````/@$``)8```!C!@``=`(``"L"````````ZP```)@!``"!!@``@````.L#
M```V!0``JP```)T#`````````````)@`````````'@,``!H&``!2````[`0`
M``P````M````>P,```````!*`0```````+4#``"W`@``]P4``'D!```Z`@``
M?P(``#$```!.`@``908``.<````U!@``"`8``.<#``#2!```6`4``$<#``!>
M!```>P(```````#$!0``$@0```````"X`P````````$&```?`P``\0(`````
M``"E!````````#\$```B`P```````&P!``!T`0``^0,````````-````Z04`
M`#($````````2`,``,$#````````-@$``"$%``"-````TP$``.8!``">!```
M``````````!L`@``;08``!H$``#W````204``($```#;`P``A0```'X#``#\
M!```Q`,```````#+!```804``+H!``#[`@``>P8``.(!``!&`P``LP0``(T#
M``"R`0``(@0``*T!```8````O`0``)4#```M`@```````-4!``!#!@``?`,`
M```````5!```5P4``%0$`````````````!`$``#"!````````+4```"U`0``
M?````%\%````````,`4``#(!``"?!```#`8```````"@`0``108``-P#``!L
M!@``G`(``'T%``#O`0``9P$`````````````J@(``$<$`````````P4``+@$
M``"Y````3`4``/@```!^!@```````$@%````````T`,``&,```"&````DP``
M`%,%``"D`````````.P%````````-00``+P%``#Q!````````#L%````````
MRP(```X&```^!0``V0(``*$%``"Z!```>`$``-8$``#N````G0```&8%```@
M!````````-$`````````K@```$H&``"!!0``7`0`````````````9P```*8#
M``````````````````#3!```WP,``)8$````````1@0``#(```#^!```FP$`
M`&D&`````````````)0#``#6!0``[0`````````P`0``"@```'`$``#V`@``
M900``"P#```B`````@$``!D!````````:@0``),$``#J`0``2P(``+H````%
M`0``NP4``&P%````````Q0(``*("``#(`P``S0,``&($``!H`P``O0(`````
M``#W!```H`````<````5`P``V0$``/,!````````Q@```+X%````````$04`
M`((&``!0`0```````)`%``!<!0``@`,``(D"```3`@``>`(```````#4`0``
M_````/,%``!;`0``_`(``.X#``!"!0``_0````````"'!````````.@$````
M````````````````````*P0``$\&`````````````(L"````````+P8``((`
M``!=`@``M`(``*D!``"%!@``W0```(L```!J`P``!`$```````!+!0``:P(`
M`%``````````M0(```````!!!@``-0$```````#N`0``;0(```L$```?!0``
M)`4``,T"``````````````````!<````.P0``,H```"L`P``LP,``,\!````
M`````````.L!``!``P``\`(```````"P````4P(````````S!@``V`$```@#
M``#E`@``R@$``'<```"H`P``T@(``&D!`````````````$4```!:!@``W@0`
M`+D"``"#!```:@4``+<`````````/`$`````````````H0,``.H"````````
MB@(``*`#`````````````-$#``")`P``+P(``/D%``"#````*@````````"K
M`@```````)D#``"-`@``6P0``"D$``"``@``L@```````````````````+\$
M```L!```,@8``+$$````````EP```.@#``!U!0````````D`````````T`(`
M`'P$``#.!0````````@$```X!0```````/$%``#5````/`8```D!```"!@``
MKP$`````````````=`4``+<!````````"04`````````````:0```-H```"4
M`@``D@(``"0&``!]`````````(X#``"]````D@,```````#)`P``TP4``&$#
M``#C!0```````!0!````````P@(``"P%``````````````@"````````````
M`!T%``!,`P``=P$``+L#````````M@$``#$%``!(`````````#$$``#E`0``
M`````"\%``!,!@``O@```)X````3````K`4```,$``!7`0``M`$``/4#```]
M!```A@4```````##`@``$00``.@!``!H`````````$T&````````7@$``%\$
M``!Z`@``0@,``&,#```+!0```````,`#``#V````0P(```@%```$````60(`
M```````$!0``.@,``)0%````````&P,``!X&``"9!0``)`0``)4%``!1!```
MN04``'\#``#G!0```````)<&``!G!0``?00``/L$``!Q!0``*@8``+0#````
M````500``(\"``!!!````````'D#``!6````=@0``"H%```S`P``!P8``,<$
M```;`0``#`0``*,#````````W`0``-`$``""`@``R@0``"8!``"+`0``````
M`&@&``"Q`0``)P````L`````````Q`0``,T%```*`P````````````#Z!0``
M-P,``(<````Z!@``:@(```````#L`0``]04``%L#``!1!@``,`````````"C
M````DP4``#,!````````/@(``$$%````````,0$```````"0!@``A@(`````
M``""`0```````&L```"I`P``]@4```X```#O````<0,``"@"``"+`P``=@4`
M`#<%``!Z`````````/`!````````;04```````#V`0```````)\!``#*`@``
M/08```````#&!````````!$!``!6!0``````````````````@0(``$T#``!P
M!@``2@(``(H!```!!```*`0```````!7!```P00``"X"``#;`0``)P4```L"
M````````$P$``#<!``!<!@````````````#Z!```J`(``#0&````````#04`
M`'8```!$!0``6@0```````!]`@``;@$``.X%``!:!0``50,````````\`P``
M```````````C`P``````````````````%@0```8$````````X0,``"L#``!I
M!0``1`0``/(`````````9`,``!\&``#*`P``%@,``'$"``"1!0``X`0`````
M````````SP4``,L#``"&!@``;0`````````7````U````$(````5!@``%`(`
M`/\#``#0`0``:P0``$T$``#M!0``7P```/("``!-`@```````+$"````````
M>08```````#T`P``&0,``#8&````````Q00``-$$``",````BP0````````:
M`P```````#(#``"`!@``.0```!<$```L`@``'`,`````````````BP8``!L%
M``#D`0``.`$```4"``!.`0```````````````````````*($``!9!0``````
M`+L"``"[`0``704``-`%``!B`P``!08``'X!``"G`0```````#P%``#>`@``
M=P4```````"_`@``N`(```4%````````Z0````````!E`@``C@0``'\&```B
M!@``*0(``!\``````````````!,#``"E!0``KP4``#4#```)`P``:@8``'$`
M```%!```<00``)4```"Q!0``'00``/L%````````K`$``!`!``#``@``K0,`
M`+P!```>!0``!P4``.8"``"*!````````#X&``#1!0```````&,!``"F!```
M`0,```````"<`P```````*H%``#J!0``.P````````!6!```:`0``&D#````
M````&P0`````````````AP4```````#=`0```````)$$````````'P$``,T$
M````("@E<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y
M<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``)60@
M)7,@86YD("5S`"5D+61A>2!F;W)E8V%S=``E<R`M($YO=&EC90`E<R!&:6YG
M97)P<FEN=``E<R!+0@`E<R!-86EN=&5N86YC92!/<&5R871I;VYS("T@0V]N
M9FER;6%T:6]N`"5S(%-E='5P`"5S(%-I9VX@57``)7,@5&5R;7,@;V8@06=R
M965M96YT`"5S(&%L<F5A9'D@97AI<W1S+@`E<R!A="`E<R`E<P`E<R!I<R!R
M97%U:7)E9``E<R!M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@
M)7,`)7,G<R!!9&1R97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P
M860`)7,G<R!487-K;&ES=``E<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R
M:6%B;&4@9G)O;2`E<R!T;R`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M
M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`02!D871A8F%S92!B86-K96YD
M(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L;V-K+@!!(&9A=&%L(&5R<F]R(&AA
M<R!O8V-U<G)E9`!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D
M('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+@!!('!U8FQI8R!01U`@:V5Y
M+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E
M9"!T;R!D96-R>7!T(&$@;65S<V%G92X`02!P=6)L:6,@4$=0(&ME>2P@<')I
M=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@<F5Q=6ER960@=&\@
M<VEG;B!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-12!K97DL('!R:79A=&4@
M4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E
M8W)Y<'0@82!M97-S86=E+@!!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E
M(%,O34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S
M:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4TU)344@:V5Y(&ES(')E<75I<F5D
M('1O(&5N8W)Y<'0@82!M97-S86=E+@!!32!286EN`$%-(%-H;W=E<G,`04T@
M4VYO=R!3:&]W97)S`$%-+U!-`$%022!)1`!!8F]U="!T:&ES(&5D:71O<@!!
M8F]U="XN+@!!8G-B;W1T;VT`06)S;6ED9&QE`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&1I<F5C=&]R>2X`06-C97-S(&1E;FEE9"!C<F5A=&EN9R!6
M1E,@9FEL92X`06-C;W5N="!087-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C
M;W5N=&EN9P!!9&0`061D($-H:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S
M:6]N`$%D9"!(97)E.@!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO
M;@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@;F5W(&UE;6)E<G,`
M061D('!A:7(`061D('1H92`E<R!-96YU(&%S(&$@36]Z:6QL82!3:61E8F%R
M`$%D9"!T;R!A9&1R97-S(&)O;VLZ`$%D9"!T;R!M>2!A9&1R97-S(&)O;VL`
M061D('5S97(`061D:6YG('5S97)S(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D
M9')E<W,@0F]O:P!!9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O
M=&AE<B!U<V5R<P!!9&UI;FES=')A=&EO;@!!9',`069G:&%N:7-T86X`06QB
M86YI80!!;&=E<FEA`$%L:6%S`$%L:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!
M=71H96YT:6-A=&5D(%5S97)S`$%L;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS
M`$%L;"!F;W5R('-I9&5S`$%L;&]W(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO
M=R!S971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;')E861Y(&5X:7-T
M<P!!;'1E<FYA=&4@24U34"!,;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R
M9`!!;'1E<FYA=&4@24U34"!5<V5R;F%M90!!;'1E<FYA=&4@96UA:6P@861D
M<F5S<P!!;'1E<FYA=&4@=&5M<&QA=&5S`$%L=&5R;F%T92!T97AT.@!!;65R
M:6-A;B!386UO80!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%N
M9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X>0!!;G-W97(`
M06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI8V%T:6]N`$%P
M<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN`$%P<&QY('1O
M($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I>F4`07!R:6P`
M07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3:7IE`$%R8VAI
M=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!S
M:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F=E;G1I;F$`07)M96YI80!!<FUE
M;FEA;B`H05)-4T-)22TX*0!!<G0`07)U8F$`07-C96YS:6]N($ES;&%N9`!!
M<V-I:2!!<G0`07-I82]086-I9FEC(%)E9VEO;@!!<VL@9F]R(&-O;F9I<FUA
M=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`07-S
M:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@=&\@9&5L971E(&$@;F]N+65X:7-T
M96YT(&=R;W5P+@!!='1E;7!T('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!P
M97)M:7-S:6]N+@!!='1E;7!T('1O(&5D:70@82!N;VXM97AI<W1E;G0@<&5R
M;6ES<VEO;BX`071T96UP="!T;R!E9&ET(&$@;F]N+65X:7-T96YT('-H87)E
M+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L:6$`075S=')I80!!=71H7V-Y
M<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H
M7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T(&AA=F4@<F5Q=6ER960@8V%P86)I
M;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I<F5D(&EM87`@97AT96YS:6]N(&YO
M="!F;W5N9"X`075T:%]F='`Z(%)E<75I<F5D($944"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H('1H92`M+65N86)L92UF='`@<W=I
M=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D($E-05`@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:%]K<F(U.B!297%U:7)E9"!K<F(U(&5X=&5N<VEO;B!N;W0@
M9F]U;F0N`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@=7-E<B`E<RX@5&AI
M<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?;&1A<#H@56YA8FQE
M('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA8FQE('1O('5P9&%T
M92!U<V5R("5S`$%U=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+@!!=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:&5N=&EC871I;VX@9F%I;&5D`$%U=&AE
M;G1I8V%T:6]N(&9A:6QE9"X@)7,`075T:&5N=&EC871I;VX@<F5J96-T960@
M8GD@4D%$2553('-E<G9E<BX`075T:&5N=&EC871I;VX@=&\@1E10('-E<G9E
M<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z97)B86EJ86X`0D]&2"!%
M>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#;VQO<@!"860@:V5R8F5R
M;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R;F%M92X`0F%H86UA<P!"
M86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A;F=L861E<V@`0F%R8F%D
M;W,`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI;@!"97)M
M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B(&]F(&%P<&QI8V%T:6]N
M("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG<P!";&]C:R!4>7!E`$)O
M;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O<F1E<B!T:&EC:VYE<W,Z
M`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN80!";W1H`$)O='-W86YA
M`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"<FET:7-H($EN9&EA;B!/
M8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:6$`0G5L
M;&5T960@3&ES=`!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$-23"!$
M:7-T<FEB=71I;VX@4&]I;G1S`$-?96QL(%!R;W!E<G1I97,N+BX`0V%L96YD
M87(`0V%L;0!#86UB;V1I80!#86UE<F]O;@!#86X@;F]T(')E<V5T('!A<W-W
M;W)D(&%U=&]M871I8V%L;'DL(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R
M+@!#86XG="!C;VYN96-T('1O($E-05`@<V5R=F5R.B`E<P!#86YA9&$`0V%N
M8V5L`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#86YN;W0@9&5L971E(&9I;&4@
M(B5S(BX`0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+@!#86YN
M;W0@<')O8V5E9"!W:71H;W5T("=T87)G971&:6QE)R!P87)A;65T97(N`$-A
M;FYO="!R96UO=F4@9&ER96-T;W)Y("(E<R(N`$-A;FYO="!R96UO=F4L("5D
M(&-H:6QD<F5N(&5X:7-T+@!#86YN;W0@<F5O<F1E<BP@;G5M8F5R(&]F(&5N
M=')I97,@<W5P<&QI960@9F]R(')E;W)D97(@9&]E<R!N;W0@;6%T8V@@;G5M
M8F5R('-T;W)E9"X`0V%N;F]T(')O=71E(&UE<W-A9V4@=&\@<W!E8VEF:65D
M(&YU;6)E<BX`0V%P92!697)D90!#87!T:6]N`$-A=&5G;W)I97,@86YD($QA
M8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E;&P@4')O<&5R=&EE
M<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#96QL('-P86-I;F<Z
M`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT97(`0V5N=')A
M;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E86X@*$E33RTX.#4Y
M+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A=&4@4&]L:6-I97,`
M0VAA9`!#:&%N9V4`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S('1H870@
M<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@>6]U<B!E
M;6%I;',N`$-H87(`0VAE8U]K($QI;FLN+BX`0VAI;&4`0VAI;F$`0VAI;F5S
M92!3:6UP;&EF:65D("A'0C(S,3(I`$-H:6YE<V4@5')A9&ET:6]N86P@*$)I
M9S4I`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S97)N86UE`$-H;V]S
M92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI<W0@<W1Y;&4@='EP
M92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)<VQA;F0`0VQA<W,@
M9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R`$-L96%R($U33V9F
M:6-E('1A9W,`0VQE87(@;W5T('5S97(Z("5S`$-L96%R('5S97(`0VQE87(@
M=7-E<B!D871A`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A4
M5%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9'D`0V]C;W,@*$ME96QI;F<I
M($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R9&5R<P!#
M;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C=&EO;@!#
M;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA;F0@4VAE
M;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`0V]M<'5T
M97)S`$-O;F1I=&EO;G,`0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E<P!#;VYF
M:6=U<F4@)7,`0V]N9FER;2!087-S=V]R9`!#;VYG;P!#;VYG;RP@5&AE($1E
M;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE`$-O;FYE8W1I;VX@9F%I;&5D+@!#
M;VYN96-T:6]N(&9A:6QE9#H@`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX`0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P
M=6)L:6,@:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RD`0V]N;F5C=&EO;B!T
M;R!&5%`@<V5R=F5R(&9A:6QE9"X`0V]N=&%C=',@=V5R92!S=6-C97-S9G5L
M;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`$-O;G1I;G5E`$-O;VL@
M27-L86YD<P!#;V]K:64`0V]P>0!#;W!Y('-E;&5C=&EO;@!#;W-T82!2:6-A
M`$-O=&4@9"=)=F]I<F4`0V]U;&0@;F]T(%!'4"!E;F-R>7!T(&UE<W-A9V4N
M`$-O=6QD(&YO="!01U`@<VEG;B!M97-S86=E+@!#;W5L9"!N;W0@4R]-24U%
M(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A
M9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@
M=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#
M;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N
M;W0@9&5C<GEP="!01U`@9&%T82X`0V]U;&0@;F]T(&1E8W)Y<'0@4R]-24U%
M(&1A=&$N`$-O=6QD(&YO="!D96QE=&4@8V]N=&%C="X@)7,`0V]U;&0@;F]T
M(&1E;&5T92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(&1E=&5R
M;6EN92!T:&4@<F5C:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO
M="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C
M:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H
M('1H92!C;VUP;&5T92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U
M;&0@;F]T(&]B=&%I;B!P=6)L:6,@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX`
M0V]U;&0@;F]T(&]P96X@)7,N`$-O=6QD(&YO="!O<&5N($UA:6YT96YA;F-E
M7U1A<VL@;6]D=6QE("5S`$-O=6QD(&YO="!R96%D("5S+@!#;W5L9"!N;W0@
M<F5S970@=&AE('!A<W-W;W)D(&9O<B!T:&4@<F5Q=65S=&5D('5S97(N(%-O
M;64@;W(@86QL(&]F('1H92!D971A:6QS(&%R92!N;W0@8V]R<F5C="X@5')Y
M(&%G86EN(&]R(&-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N
M965D(&9U<G1H97(@:&5L<"X`0V]U;&0@;F]T(')E=')I979E($%#3`!#;W5L
M9"!N;W0@<F5T<FEE=F4@861D<F5S<R!B;V]K+B`E<P!#;W5L9"!N;W0@<F5T
M<FEE=F4@9&ES=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S`$-O=6QD(&YO="!R971R:65V92!S
M97)V97(G<R!C87!A8FEL:71I97,`0V]U;&0@;F]T(')E=F5R="!C;VYF:6=U
M<F%T:6]N+@!#;W5L9"!N;W0@<V%V92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L
M9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF:6=U871I;VXN`$-O=6QD(&YO="!S
M879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!#;W5L9"!N
M;W0@<V5A<F-H('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5P9&%T92!C
M;VYT86-T+B`E<P!#;W5L9"!N;W0@=7!D871E(&1I<W1R:6)U=&EO;B!L:7-T
M+B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N($UA:V4@
M<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5N=&5D('1E>'0`0V]U;G1R
M>0!#;W5R<V5S`$-R96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O
M;F4`0W)E871E('-U8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E
M9&ET(&-A<F0@;G5M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(%1I;64`0W5R
M<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N
M.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@
M;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI
M8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5
M:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1&%I;'D`1&%T
M851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I
M;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R
M<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U
M;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L971E`$1E;&5T92!'<F]U<`!$
M96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD('!U<F=E(&UE<W-A9V5S`$1E
M;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L971E(&5X:7-T:6YG(&%L=&5R
M;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E;&5T92!S96QE8W1E9"!I9&5N
M=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T:&4@8W5R
M<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM87)K`$1E<V-R:6)E('1H92!0
M<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L
M;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M
M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W(%!O:6YT`$1E=R!0;VEN="!F
M;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``1&ER96-T:6]N(&QE9G0@=&\@
M<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE9G0`1&ER96-T;W)Y`$1I<W!L
M87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/<'1I;VYS`$1I<W!L87D@9F]R
M96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`1&ES<&]S:71I;VX@3F]T:69I
M8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE=&4`1&\@;F]T(&1I<F5C=&QY
M(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E<R!T:&4@9FER<W0@<F]W(&-O
M;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y97,L(&-H96-K('1H:7,@8F]X
M.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L:6,`1&]W;FQO860`1&]W;FQO
M860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I;VX@87,@4$A0
M('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL`$524@!%8W5A
M9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R;W5P`$5D:70@4&5R;6ES<VEO
M;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@9F]R("5S`$5D
M:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES<VEO;G,@9F]R("5S`$5D=6-A
M=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT+BXN`$5M`$5M86EL`$5M
M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N`$5M86EL
M('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%
M;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T
M:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%
M;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA
M<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO
M=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S
M<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`
M16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q=6%T;W)I86P@1W5I;F5A`$5R
M:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I;"!M97-S86=E+@!%<W1O;FEA
M`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R
M>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`
M179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M
M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP
M96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H
M('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U
M<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N
M`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@
M8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E
M<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@
M;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`
M1F%I<@!&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RD`1F%R;V4@27-L86YD
M<P!&871A;"!%<G)O<CH`1F%X`$9E8G)U87)Y`$9E96QS($QI:V4`1F5E;',@
M;&EK93H@`$9E=R!3:&]W97)S`$9E=R!3;F]W(%-H;W=E<G,`1FEE;&0@;6%T
M<FEX`$9I:FD`1FEL92!#;W5N=#H@)7,@9FEL90!&:6QE($-O=6YT.B`E<R!F
M:6QE<P!&:6QE($UA;F%G97(`1FEL92!.86UE`$9I;&4@<V5L96-T:6]N`$9I
M;&4@=7!L;V%D`$9I;&4@=7!L;V%D<R!N;W0@<W5P<&]R=&5D+@!&:6QT97)S
M`$9I;FQA;F0`1FER<W0@2&%L9@!&:7)S="!1=6%R=&5R`$9I>"!R871I;P!&
M;&EP`$9L;V%T`$9O9P!&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0`1F]N="!#
M;VQO<@!&;V]D`$9O<B!B<F]W<V5R<R!T:&%T(&1O;B=T('-U<'!O<G0@:6UA
M9V5S`$9O<F5C87-T("A4048I`$9O<F5C87-T($1A>7,@*&YO=&4@=&AA="!T
M:&4@<F5T=7)N960@9F]R96-A<W0@<F5T=7)N<R!B;W1H(&1A>2!A;F0@;FEG
M:'0[(&$@;&%R9V4@;G5M8F5R(&AE<F4@8V]U;&0@<F5S=6QT(&EN(&$@=VED
M92!B;&]C:RD`1F]R9V]T('EO=7(@<&%S<W=O<F0_`$9O<FUS`$9O<G1U;F4`
M1F]R='5N92!T>7!E`$9O<G1U;F5S`$9O<G1U;F5S(#(`1F]R=6US`$9O<G=A
M<F1S`$9R`$9R86UE<P!&<F%N8V4`1G)A;F-E+"!-971R;W!O;&ET86X`1G)E
M;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R96YC:"!3;W5T:&5R;B!4
M97)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL($1E<V-R:7!T:6]N`$9U
M;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R>2!T;R!T86ME(&EM86=E
M(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E("5S($-O;F9I9W5R871I
M;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M86YY`$=H86YA`$=I8G)A
M;'1A<@!':79E;B!.86UE`$=O`$=O961E;`!';V]G;&4@4V5A<F-H`$=R87ES
M8V%L90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N
M861A`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@
M;F]N+65M<'1Y`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%R
M9"!)<VQA;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5B<F5W("A)4T\M.#@U
M.2TX+4DI`$AE:6=H=`!(96QP`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(
M96UI<W!H97)E`$AE<F4@:7,@=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`
M2&EG:`!(;U]M90!(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE
M`$AO;64@061D<F5S<P!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M;W)D90!(;W)D92]+;VQA8CH@26YV86QI9"`E<R!834P@9&%T82!E;F-O=6YT
M97)E9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!.;R!M97-S86=E(&-O
M<G)E<W!O;F1S('1O(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@3F\@;V)J96-T
M(&]F('1Y<&4@)7,@9F]U;F0@:6X@;65S<V%G92`E<P!(;W)D92]+;VQA8CH@
M4W5C8V5S<V9U;&QY(')E;6]V960@)7,@(B5S(@!(;W)D92]+;VQA8CH@5&AE
M(&EN=&5G<F%T:6]N(&5N9VEN92!R97%U:7)E<R!T:&4@)V1O;7AM;"<@4$A0
M(&5X=&5N<VEO;@!(;W)D92]+;VQA8CH@56YA8FQE('1O(&-R96%T92!N97<@
M6$U,('1R964@9F]R(&]B:F5C="`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O
M(')E;6]V92`E<R`B)7,B.B`E<P!(;W)D92]+;VQA8CH@56YA8FQE('1O(')E
M=')I979E($U)344@240@9F]R('1H92!P87)T(&]F('1Y<&4@)7,`2&]R9&4O
M2V]L86(Z(%5N86)L92!T;R!S>6YC:')O;FES92`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E('-H87)E<SH@)7,`2&]R
M9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@(B5S(@!(;W)I>F]N=&%L(%)U;&4`
M2&]R:7IO;G1A;"!P861D:6YG`$AO<FEZ;VYT86PZ`$AO=R!D:60@>6]U(&=E
M="!H97)E/R`H4&QE87-E(')E<&]R="$I`$AO=R!M86YY(&-O;'5M;G,@=V]U
M;&0@>6]U(&QI:V4@=&\@;65R9V4_`$AO=R!M86YY(&9I96QD<R`H8V]L=6UN
M<RD@87)E('1H97)E/P!(;W<@;6%N>2!R;W=S('=O=6QD('EO=2!L:6ME('1O
M(&UE<F=E/P!(=6UI9&ET>0!(=6UI9&ET>3H@`$AU;6]R:7-T<P!(=6YG87)Y
M`$E-05`@;6%I;&)O>"!C<F5A=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O
M>"!D96QE=&EO;B!F86EL960Z("5S`$E-05`@;6%I;&)O>"!Q=6]T82!C<F5A
M=&EO;B!F86EL960Z("5S`$E0($%D9')E<W,`25`@061D<F5S<R!N;W0@879A
M:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E9"!#2412(&)L
M;V-K+@!)4"!L;V-K9&]W;B!V:6]L871I;VXN`$E?;G-E<G0@4F]W($)E9F]R
M90!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S`$EC;VYS('=I=&@@
M=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EF(&ET(&ES(&YO="!D:7-P;&%Y960@
M8V]R<F5C=&QY+"`E<R!T;R!O<&5N(&ET(&EN(&$@;F5W('=I;F1O=RX`268@
M>6]U(&1O;B=T('-E92!A;GD@:6-O;G,@=7-I;F<@26YT97)N970@17AP;&]R
M97(L('EO=2!M87D@;F5E9"!T;R!C:&5C:R!T:&ES(&)O>"!T;R!T=7)N(&]F
M9B!03D<@=')A;G-P87)E;F-Y+@!)9B!Y;W4@<V5E('1H:7,@;65S<V%G92!B
M=70@;F\@:6UA9V4L('1H92!I;6%G92!Y;W4@=V%N="!T;R!U<&QO860@8V%N
M)W0@8F4@9&ES<&QA>65D(&)Y('EO=7(@8G)O=W-E<BX`26UA9V4@4')E=FEE
M=SH`26UA9V4@55),`$EM86=E(%523#H`26UA9V4@9G)O;2!G86QL97)Y`$EM
M86=E(&9R;VT@9V%L;&5R>3H`26UA9V4@=7!L;V%D`$EM86=E<P!);7!O<G0L
M(%-T97`@)60`26UP;W)T960@9FEE;&0Z("5S`$EM<&]R=&5D(&9I96QD<SH`
M26Y?<V5R="!2;W<@069T97(`26YC;W)R96-T(&%C=&EO;B!C;V1E(&=I=F5N
M+@!);F-O<G)E8W0@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D+@!);F-O<G)E
M8W0@=7-E<FYA;64@;W(@86QT97)N871E(&%D9')E<W,N(%1R>2!A9V%I;B!O
M<B!C;VYT86-T('EO=7(@861M:6YI<W1R871O<B!I9B!Y;W4@;F5E9"!F=7)T
M:&5R(&AE;'`N`$EN8W)E87-E($EN9&5N=`!);F1I80!);F1I=FED=6%L(%5S
M97)S`$EN9&]N97-I80!);F9O`$EN9F]R;6%T:6]N`$EN<V5R="!#7V]L=6UN
M($%F=&5R`$EN<V5R="!);6%G90!);G-E<G0@5&%B;&4`26YS97)T(%=E8B!,
M:6YK`$EN<V5R="!?0V]L=6UN($)E9F]R90!);G-E<G0@82!N97<@8V]L=6UN
M(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@82!N97<@8V]L=6UN(&)E
M9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!A9G1E<B!T
M:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(')O=R!B969O<F4@=&AE(&-U
M<G)E;G0@;VYE`$EN<V5R="!A('!A<F%G<F%P:"!A9G1E<B!T:&4@8W5R<F5N
M="!N;V1E`$EN<V5R="!A('!A<F%G<F%P:"!B969O<F4@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@86QT97)N871E('1E;7!L871E`$EN<V5R="!A;B!E;6%I
M;"!A9&1R97-S('1O('=H:6-H('EO=2!C86X@<F5C96EV92!T:&4@;F5W('!A
M<W-W;W)D.@!);G-E<G0@8V5L;"!A9G1E<@!);G-E<G0@8V5L;"!B969O<F4`
M26YS97)T(&-O;'5M;B!A9G1E<@!);G-E<G0@8V]L=6UN(&)E9F]R90!);G-E
M<G0@;65S<V%G97,`26YS97)T('!A<F%G<F%P:"!A9G1E<@!);G-E<G0@<&%R
M86=R87!H(&)E9F]R90!);G-E<G0@<F]W(&%F=&5R`$EN<V5R="!R;W<@8F5F
M;W)E`$EN<V5R="!T:&4@<F5Q=6ER960@86YS=V5R('1O('1H92!S96-U<FET
M>2!Q=65S=&EO;CH`26YS97)T+TUO9&EF>2!);6%G90!);G-E<G0O36]D:69Y
M($QI;FL`26YS=69F:6-I96YT(&-R961I="!T;R!S96YD('1O('1H92!D:7-T
M<FEB=71I;VX@;&ES="X`26YS=69F:6-I96YT(&-R961I="X`26YT96=E<@!)
M;G1E9V5R(&QI<W0`26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A9&5R*2X`
M26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI
M9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S
M+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!R
M;W1O8V]L+@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A
M9&1R97-S+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$ER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8`27)A<0!)<F5L86YD`$ES;&4@;V8@36%N
M`$ES;VQA=&5D(%0M4W1O<FUS`$ES<F%E;`!)<W-U97(`271A;&EC`$ET86QY
M`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A;F5S92`H25-/+3(P,C(M2E`I
M`$IE<G-E>0!*;W)D86X`2G5L>0!*=6YE`$IU<W1I9GD`2G5S=&EF>2!#96YT
M97(`2G5S=&EF>2!&=6QL`$IU<W1I9GD@3&5F=`!*=7-T:69Y(%)I9VAT`$MA
M>F%K:'-T86X`2V5E<"!O<FEG:6YA;#\`2V5N>6$`2V5R8F5R;W,@<V5R=F5R
M(')E:F5C=&5D(&%U=&AE;G1I8V%T:6]N+@!+97)N96P@3F5W8FEE<P!+97D@
M0W)E871I;VX`2V5Y($9I;F=E<G!R:6YT`$ME>2!,96YG=&@`2V5Y(%1Y<&4`
M2V5Y(%5S86=E`$ME>2!A;')E861Y(&5X:7-T<R!O;B!T:&4@<'5B;&EC(&ME
M>7-E<G9E<BX`2VED<P!+:7)I8F%T:0!+;W)E82P@1&5M;V-R871I8R!096]P
M;&4G<R!297!U8FQI8R!O9@!+;W)E82P@4F5P=6)L:6,@;V8`2V]R96%N("A%
M54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA7WEO=70`3&%N9W5A9V4`3&%O
M(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,`3&%S="!(86QF`$QA<W0@
M475A<G1E<@!,87-T(%5P9&%T960Z`$QA<W0@;&]G:6XZ("5S`$QA<W0@;&]G
M:6XZ("5S(&9R;VT@)7,`3&%S="!L;V=I;CH@3F5V97(`3&%T=FEA`$QA=P!,
M87EO=70`3&5A=F4@96UP='D@9F]R(&YO(&)O<F1E<@!,96)A;F]N`$QE9G0`
M3&5F="!H96%D97(`3&5F="!V86QU97,`3&5S;W1H;P!,:6)E<FEA`$QI8GEA
M;B!!<F%B($IA;6%H:7)I>6$`3&EE8VAT96YS=&5I;@!,:6=H="!$<FEZ>FQE
M`$QI9VAT(%)A:6X`3&EG:'0@4F%I;B!%87)L>0!,:6=H="!286EN($QA=&4`
M3&EG:'0@4F%I;B!3:&]W97(`3&EG:'0@4F%I;B!W:71H(%1H=6YD97(`3&EG
M:'0@4VYO=P!,:6=H="!3;F]W(%-H;W=E<@!,:6UE<FEC:P!,:6YK`$QI;FL@
M<&]I;G1S('1O.@!,:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP
M;W-E('!A9V4@=VAE;B!D:7-P;&%Y:6YG`$QI;FMS`$QI;G5X($-O;VMI90!,
M:7-T("T@=7-E<B!C86X@<V5E('1H92!F;VQD97(`3&ES="!$871A8F%S97,`
M3&ES="!(96QP(%1O<&EC<P!,:7-T(%1A8FQE<P!,:7-T+4%R8VAI=F4`3&ES
M="U(96QP`$QI<W0M260`3&ES="U/=VYE<@!,:7-T+5!O<W0`3&ES="U3=6)S
M8W)I8F4`3&ES="U5;G-U8G-C<FEB90!,:7-T:6YG('5S97)S(&ES(&1I<V%B
M;&5D+@!,:71E<F%T=7)E`$QI=&AU86YI80!,;V%D:6YG+BXN`$QO8V%L('1I
M;64Z(`!,;V-A;&4@86YD(%1I;64`3&]C871I;VX`3&]G(&EN`$QO9R!O=70`
M3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2X`3&]G:6X@
M9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`3&]W97(@9W)E96L@;&5T=&5R
M<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R(')O;6%N(&YU;6)E<G,`3'5X
M96UB;W5R9P!-30!-3U1$`$U3+51.148@071T86-H;65N="!C;VYT86EN960@
M;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O
M<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R`$UA9VEC`$UA:6P`36%I;"!!
M9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-86QA>7-I80!-86QD:79E<P!-
M86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O9B!C871E9V]R:65S('EO=2!H
M879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C;VQO<G,@87-S;V-I871E
M9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<#(T(&UA<`!-87!1=65S="!M
M87``36%R8V@`36%R9VEN`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-
M87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D
M*0!-87)S:&%L;"!)<VQA;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S
M`$UA=7)I=&%N:6$`36%U<FET:75S`$UA>"!A;&QO=V5D(&-R961I="X`36%X
M(&UE<W-A9V4@<&%R=',@97AC965D960N`$UA>"!T96UP(&QA<W0@,C0@:&]U
M<G,Z(`!-87@@=&5M<"!L87-T(#8@:&]U<G,Z(`!-87AI;75M(&QE;F=T:`!-
M87D`36%Y;W1T90!-961I8VEN90!-96UB97)S`$UE;G4@;6]D93H`365R9V4@
M8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF:65D(%-U8V-E<W-F=6QL>2!B
M=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E(&-O=6QD(&YO="!B92!V97)I
M9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S86=E('1Y<&4`365T87(@5V5A
M=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+@!-971A<B!B;&]C:R!N
M;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H
M92!A9&UI;FES=')A=&]R+@!-971H;V0`365T<FEC`$UE>&EC;P!-:6-R;VYE
M<VEA+"!&961E<F%T960@4W1A=&5S(&]F`$UI9&1L90!-:6UE(%1Y<&4`36EN
M('1E;7`@;&%S="`R-"!H;W5R<SH@`$UI;B!T96UP(&QA<W0@-B!H;W5R<SH@
M`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@4$5!4B!P86-K86=E($A4
M5%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T
M;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P
M;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`36ES<VEN9R!R97%U:7)E
M9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S97-S:6]N($E$+@!-;P!-
M;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$871E`$UO9&EF>2!54DP`
M36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-;VYA8V\`36]N9V]L:6$`
M36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R<F%T`$UO;VX@4&AA<V5S
M`$UO<F]C8V\`36]S=&QY($-L96%R`$UO<W1L>2!#;&]U9'D`36]S=&QY(%-U
M;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO
M=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S`$UU;'1I<&QE('-E;&5C=&EO;@!->2!!8V-O=6YT`$UY(%!O
M<G1A;`!->2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G
M<F5E`$YA;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H
M97)L86YD<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#
M02!2979O8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C
M87!E(%)E;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C
M87!E(%-33"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM
M96YT`$YE='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.
M97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA
M;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@=VEN9&]W("A?8FQA;FLI
M`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T:6]N<P!.:6-A<F%G=6$`
M3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO
M8V%T:6]N(&ES('-E="X`3F\@;65S<V%G92!S=7!P;&EE9"X`3F\@;F%M92!S
M<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I960N`$YO(&]F9F5N<VEV92!F
M;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT
M:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($E-05`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A
M=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN
M(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@4$%3
M4U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@
M4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H('1O('1H92!/<&5N4U-,(&)I
M;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@8FEN87)Y(&ES(&YE8V5S<V%R
M>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A+@!.;R!P96YD:6YG('-I9VYU
M<',N`$YO(')U;&5S`$YO('-I9&5S`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@
M879A:6QA8FQE(&9O<B!C86-H92X`3F\@=7-E<FYA;64@86YD+V]R('!A<W-W
M;W)D('-E;G0N`$YO('9A;&ED(%A-3"!D871A(')E='5R;F5D`$YO('9A;'5E
M<P!.;R!V97)S:6]N(&9O=6YD(&EN(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I
M;B!Y;W5R(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO
M;BX`3F]N90!.;VYE("AU<V4@:6UP;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM
M,3`I`$YO<F9O;&L@27-L86YD`$YO<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W0@069T97(`3F]T($)E9F]R
M90!.;W0@82!D:7)E8W1O<GD`3F]T(&EM<&QE;65N=&5D+@!.;W0@<V5T`$YO
M="!S=7!P;W)T960N`$YO=&5S`$YO=&AI;F<@=&\@8G)O=W-E+"!G;R!B86-K
M+@!.;W9E;6)E<@!.=6UB97(`3G5M8F5R(&]F(&-H87)A8W1E<G,`3G5M8F5R
M(&]F(&-O;'5M;G,`3G5M8F5R(&]F(')O=W,`3G5M8F5R<R!N;W0@<W!E8VEF
M:65D(&9O<B!U<&1A=&EN9R!I;B!D:7-T<FEB=71I;VX@;&ES="X`3TL`3V)J
M96-T`$]B:F5C="!#<F5A=&]R`$]C=&%L`$]C=&]B97(`3V9F96YS92!F:6QT
M97(`3V9F:6-E`$]M86X`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R
M960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@
M96UA:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T
M96T@861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE
M<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O
M=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@
M<VEG;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@
M=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E
M<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N
M:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/
M<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T
M:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N
M;W0@879A:6QA8FQE+@!01U`@1&EG:71A;"!3:6=N871U<F4`4$=0($5N8W)Y
M<'1E9"!$871A`%!'4"!0=6)L:6,@2V5Y`%!'4"!3:6=N960O16YC<GEP=&5D
M($1A=&$`4$A0($-O9&4`4$A0(%-H96QL`%!-($QI9VAT(%)A:6X`4$T@4VAO
M=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!4+5-T;W)M<P!07TA0
M(%-H96QL`%!A9&1I;F<`4&%K:7-T86X`4&%L874`4&%L97-T:6YI86X@5&5R
M<FET;W)Y+"!/8V-U<&EE9`!086YA;6$`4&%P=6$@3F5W($=U:6YE80!087)A
M9W5A>0!087)T;'D@0VQO=61Y`%!A<W-W;W)D`%!A<W-W;W)D(&EN8V]R<F5C
M=`!087-S=V]R9"!R97%U:7)E9"!F;W(@4D%$2553(&%U=&AE;G1I8V%T:6]N
M+@!087-S=V]R9"!W:71H(&-O;F9I<FUA=&EO;@!087-S=V]R9#H`4&%S<W=O
M<F0Z(`!087-S=V]R9',@;75S="!M871C:"X`4&%S=&4`4&%S=&4@9G)O;2!C
M;&EP8F]A<F0`4&%T:`!096YD:6YG(%-I9VYU<',Z`%!E;W!L90!097)C96YT
M`%!E<F9O<FT@36%I;G1E;F%N8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,@;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES
M<VEO;G,@061M:6YI<W1R871I;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&5R
M=0!0971S`%!H:6QI<'!I;F5S`%!H;VYE`%!H;W1O<P!0:71C86ER;@!0:7AE
M;',`4&QA=&ET=61E<P!0;&5A<V4@8VQI8VL@:6YT;R!S;VUE(&-E;&P`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!R96UO=F4@=&AI<R!E;&5M
M96YT.@!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O('5N;&EN:R!T
M:&ES(&5L96UE;G0N`%!L96%S92!E;G1E<B!A(&UO;G1H(&%N9"!A('EE87(N
M`%!L96%S92!E;G1E<B!A(&YA;64@9F]R('1H92!N97<@8V%T96=O<GDZ`%!L
M96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N`%!L96%S92!E;G1E<B!A
M('9A;&ED(&1A=&4L(&-H96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@
M;6]N=&@N`%!L96%S92!E;G1E<B!A('9A;&ED('1I;64N`%!L96%S92!P<F]V
M:61E(&$@<W5M;6%R>2!O9B!T:&4@<')O8FQE;2X`4&QE87-E('!R;W9I9&4@
M>6]U<B!U<V5R;F%M92!A;F0@<&%S<W=O<F0`4&QE87-E('1Y<&4@=&AE(&YE
M=R!C871E9V]R>2!N86UE.@!0;VQA;F0`4&]L:71I8W,`4&]L;',`4&]R='5G
M86P`4&]S:71I;VYI;F<@;V8@=&AI<R!I;6%G90!0;W-I=&EO;FEN9R!O9B!T
M:&ES('1A8FQE`%!O<W0@=&\@=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B
M>2!)34%0*0!0<F5C:7!I=&%T:6]N(&9O<B!L87-T("5S(&AO=7(H<RDZ(`!0
M<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N
M`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E
M<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I
M;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@
M2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M
M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI
M8R]0<FEV871E(&ME>7!A:7(@;F]T(&=E;F5R871E9"!S=6-C97-S9G5L;'DN
M`%!U97)T;R!2:6-O`%%A=&%R`%%U97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B
M:70I`%)A9&EO('-E;&5C=&EO;@!286EN`%)A:6X@16%R;'D`4F%I;B!,871E
M`%)A:6X@4VAO=V5R`%)A:6X@86YD(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O
M;2!&;W)T=6YE`%)A=&EO`%)E860`4F5A9"!M97-S86=E<P!296%L;'D@9&5L
M971E("5S/R!4:&ES(&]P97)A=&EO;B!C86YN;W0@8F4@=6YD;VYE+@!296%L
M;'D@<F5M;W9E('5S97(@9&%T82!F;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I
M;VX@8V%N;F]T(&)E('5N9&]N92X`4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`
M4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L
M(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M
M;W1E(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O
M;2]H;W)D92DZ`%)E;6]V90!296UO=F4@0FQO8VL`4F5M;W9E(&-O;'5M;@!2
M96UO=F4@9F]R;6%T=&EN9P!296UO=F4@<&%I<@!296UO=F4@<V%V960@<V-R
M:7!T(&9R;VT@<V5R=F5R)W,@=&5M<&]R87)Y(&1I<F5C=&]R>2X`4F5M;W9E
M('1H90!296UO=F4@=&AI<R!N;V1E(&9R;VT@=&AE(&1O8W5M96YT`%)E;6]V
M92!U<V5R`%)E;6]V92!U<V5R.B`E<P!297%U97-T(&-O=6QD;B=T(&)E(&%N
M<W=E<F5D+B!2971U<FYE9"!E<G)O<F-O9&4Z(`!297%U:7)E9"!&:65L9`!2
M97-E=`!297-E="!087-S=V]R9`!297-E="!9;W5R(%!A<W-W;W)D`%)E<W5L
M=',`4F5T=7)N('1O($]P=&EO;G,`4F5U;FEO;@!2979E<G0@0V]N9FEG=7)A
M=&EO;@!2:6-H(%1E>'0@161I=&]R($]P=&EO;G,`4FED9&QE<P!2:6=H=`!2
M:6=H="!H96%D97(`4FEG:'0@=F%L=65S`%)O7W<@4')O<&5R=&EE<RXN+@!2
M;VQE`%)O;6%N:6$`4F]T871E(#$X,`!2;W1A=&4@3&5F=`!2;W1A=&4@4FEG
M:'0`4F]W(%!R;W!E<G1I97,`4F]W('!R;W!E<G1I97,`4F]W<SH`4G5L97,`
M4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!A;&P@<F]W<R!A;F0@8V]L=6UN
M<P!2=6QE<R!W:6QL(&%P<&5A<B!B971W965N(&-O;'5M;G,@;VYL>0!2=6QE
M<R!W:6QL(&%P<&5A<B!B971W965N(')O=W,@;VYL>0!2=6X`4G5S<VEA;B!&
M961E<F%T:6]N`%)W86YD80!3+TU)344@0W)Y<'1O9W)A<&AI8R!3:6=N871U
M<F4`4R]-24U%($5N8W)Y<'1E9"!-97-S86=E`%-!4TP@875T:&5N=&EC871I
M;VX@:7,@;F]T(&%V86EL86)L92X`4TU3($UE<W-A9VEN9P!344P@4VAE;&P`
M4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@
M2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M
M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD
M(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V
M90!3879E("5S`%-A=F4@3W!T:6]N<P!3879E(&=E;F5R871E9"!C;VYF:6=U
M<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN`%-A=F5D("5S(&-O;F9I9W5R871I;VXN`%-C:65N
M8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@
M82!D871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N
M97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C
M="!A;&P@9&%T92!C;VUP;VYE;G1S+@!396QE8W0@86X@;V)J96-T`%-E;&5C
M="!T:&4@8VAA<F%C=&5R<R!Y;W4@;F5E9"!F<F]M('1H92!B;WAE<R!B96QO
M=RX@66]U(&-A;B!T:&5N(&-O<'D@86YD('!A<W1E('1H96T@9G)O;2!T:&4@
M=&5X="!A<F5A+@!396QE8W0@=&AE(&1A=&4@9&5L:6UI=&5R.@!396QE8W0@
M=&AE(&1A=&4@9F]R;6%T.@!396QE8W0@=&AE(&ED96YT:71Y('EO=2!W86YT
M('1O(&-H86YG93H`4V5L96-T('1H92!T:6UE(&1E;&EM:71E<CH`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R(&-O;&]R('-C:&5M92X`4V5L96-T('EO=7(@<')E9F5R
M<F5D(&QA;F=U86=E.@!396YD(%!R;V)L96T@4F5P;W)T`%-E;F0@4TU3`%-E
M;F5G86P`4V5N<V]R.B``4V5P=&5M8F5R`%-E<F)I82!A;F0@36]N=&5N96=R
M;P!397)I86P@3G5M8F5R`%-E<W-I;VX@240@97AP:7)E9"X`4V5T`%-E="!O
M<'1I;VYS('1O(&%L;&]W('EO=2!T;R!R97-E="!Y;W5R('!A<W-W;W)D(&EF
M('EO=2!E=F5R(&9O<F=E="!I="X`4V5T('5P(')E;6]T92!S97)V97)S('1H
M870@>6]U('=A;G0@=&\@86-C97-S(&9R;VT@>6]U<B!P;W)T86PN`%-E="!Y
M;W5R('!R969E<G)E9"!L86YG=6%G92P@=&EM97IO;F4@86YD(&1A=&4@;W!T
M:6]N<RX`4V5T('EO=7(@<W1A<G1U<"!A<'!L:6-A=&EO;BP@8V]L;W(@<V-H
M96UE+"!P86=E(')E9G)E<VAI;F<L(&%N9"!O=&AE<B!D:7-P;&%Y(&]P=&EO
M;G,N`%-E='5P`%-E='5P('5P9W)A9&4@<V-R:7!T<R!A=F%I;&%B;&4`4V5V
M97)A;"!L;V-A=&EO;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B``
M4V5Y8VAE;&QE<P!3:&]P<&EN9P!3:&]R="!3=6UM87)Y`%-H;W5L9"!A8V-E
M<W,@:V5Y<R!B92!D969I;F5D(&9O<B!M;W-T(&QI;FMS/P!3:&]W`%-H;W<@
M9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX`4VAO=R!L87-T(&QO9VEN
M('1I;64@=VAE;B!L;V=G:6YG(&EN/P!3:&]W(&]P=&EO;B!T;R!K965P(&]R
M:6=I;F%L`%-H;W<@<&EC:V5R`%-H;W<@=&%B;&4@;W!E<F%T:6]N<R!M96YU
M(&)A<C\`4VAO=R!T:&4@)7,@365N=2!O;B!T:&4@;&5F=#\`4VAO=R!T:&4@
M5&%B;&4@0V5L;"!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!0
M<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!486)L92!2;W<@4')O<&5R=&EE
M<R!D:6%L;V<`4VAO=R!T:&4@:6UA9V4@<')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!U<&QO860`4VAO=V5R<P!3:&]W97)S($5A<FQY`%-H;W=E<G,@3&%T90!3
M:&]W97)S(&EN('1H92!6:6-I;FET>0!3:')I;FL`4VAR:6YK(&]R(&UO=F4@
M;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I<G-T`%-I
M97)R82!,96]N90!3:6=N('5P`%-I9VYA='5R90!3:6=N871U<F4@06QG;W)I
M=&AM`%-I;F=A<&]R90!3:7IE`%-K:7`@36%I;G1E;F%N8V4`4VQO=F%K:6$`
M4VQO=F5N:6$`4VYO=P!3;F]W(%-H;W=E<@!3;F]W(%-H;W=E<G,`4VYO=R!3
M:&]W97)S($5A<FQY`%-N;W<@4VAO=V5R<R!,871E`%-N;W<@9&5P=&@Z(`!3
M;F]W(&5Q=6EV86QE;G0@:6X@=V%T97(Z(`!3;VQO;6]N($ES;&%N9',`4V]M
M86QI80!3;VYG<R`F(%!O96US`%-O<G0@;W)D97(@<V5L96-T:6]N`%-O=7)C
M92!A9&1R97-S`%-O=71H($%F<FEC80!3;W5T:"!%=7)O<&5A;B`H25-/+3@X
M-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES
M;&%N9',`4V]U=&AE<FX@2&5M:7-P:&5R90!3<&%C92!B971W965N(&%D:F%C
M96YT(&-E;&QS`%-P86-E(&)E='=E96X@8V]N=&5N="!A;F0@8F]R9&5R(&EN
M(&-E;&P`4W!A8V5R`%-P86-I;F<`4W!A8VEN9R!A;F0@<&%D9&EN9P!3<&%I
M;@!3<&%M`%-P96-I86P@0VAA<F%C=&5R($EN<'5T`%-P;&ET(&-E;&P`4W!L
M:70@8V]L=6UN`%-P;&ET(')O=P!3<&]R=',`4W)I($QA;FMA`%-T86YD87)D
M`%-T87(@5')E:P!3=&%R="!Y96%R`%-T871E(&]R(%!R;W9I;F-E`%-T871U
M<P!3=&]R86=E(&9O<FUA=`!3=')E970@061D<F5S<P!3=')I:V5T:')O=6=H
M`%-T<FEN9R!L:7-T`%-T<FEP(&1O;6%I;B!F<F]M('1H92!A9&1R97-S`%-T
M>6QE(%M#4U-=`%-U`%-U8FIE8W0`4W5B;6ET`%-U8G-C<FEP=`!3=6-C97-S
M`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@
M=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N
M9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N
M9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=W)O=&4@)7,`4W5D
M86X`4W5M;6%R>0!3=6X@4FES90!3=6X@4V5T`%-U;FYY`%-U;G)I<V4`4W5N
M<FES92]3=6YS970`4W5N<FES93H@`%-U;G-E=`!3=6YS970Z(`!3=7!E<G-C
M<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-U<FYA;64`4W9A;&)A<F0@86YD($IA
M;B!-87EE;@!3=V%Z:6QA;F0`4W=E9&5N`%-W:71Z97)L86YD`%-Y;G1A>"!E
M<G)O<B!I;B!S96%R8V@@=&5R;7,`4WER:6%N($%R86(@4F5P=6)L:6,`5"U3
M=&]R;0!4+5-T;W)M<P!44U8@9FEL90!486)L90!486)L92!0<F]P97)T:65S
M`%1A8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@
M0VAI;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F
M`%1A<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T
M(&AO=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!L871E($%D
M;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY`%1E>'0@86QI9VX`5&5X='1O
M<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N9`!4:&%N:R!Y;W4@9F]R('5S
M:6YG('1H92!S>7-T96TN`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I
M;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I;F4@9&]E
M<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L87-S(&1I
M9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN9&]W(&AA
M<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O;2!S:61E
M(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E8VEF:65D
M+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@
M861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R92!B;&]C
M:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S86=E+@!4
M:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@<W!E8VEF
M:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T86)A<V4N
M`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE9"X`5&AE
M(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W96(@8V]N
M;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T
M:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I
M;F=S+@!4:&4@9FEL92!C86X@;F]T(&)E(&-O<&EE9"!O;G1O(&ET<V5L9BX`
M5&AE(&9I;&4@8V]N=&%I;F5D(&YO(&1A=&$N`%1H92!F;VQL;W=I;F<@87)E
M('1H92!H96%D97)S(&9O<B!T:&ES(&UE<W-A9V4O<F9C.#(R(&UE<W-A9V4N
M`%1H92!F=6QL('-C<F5E;B!M;V1E(&ES(&MN;W=N('1O(&-A=7-E('!R;V)L
M96US('=I=&@@26YT97)N970@17AP;&]R97(L(&1U92!T;R!B<F]W<V5R(&)U
M9W,@=&AA="!W92!W97)E;B=T(&%B;&4@=&\@=V]R:V%R;W5N9"X@(%EO=2!M
M:6=H="!E>'!E<FEE;F-E(&=A<F)A9V4@9&ES<&QA>2P@;&%C:R!O9B!E9&ET
M;W(@9G5N8W1I;VYS(&%N9"]O<B!R86YD;VT@8G)O=W-E<B!C<F%S:&5S+B`@
M268@>6]U<B!S>7-T96T@:7,@5VEN9&]W<R`Y>"!I="=S('9E<GD@;&EK96QY
M('1H870@>6]U)VQL(&=E="!A("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G
M(&%N9"!N965D('1O(')E8F]O="Y<;EQN66]U(&AA=F4@8F5E;B!W87)N960N
M("!0;&5A<V4@<')E<W,@3TL@:68@>6]U('-T:6QL('=A;G0@=&\@=')Y('1H
M92!F=6QL('-C<F5E;B!E9&ET;W(N`%1H92!I9&5N=&ET>2`B)7,B(&AA<R!B
M965N(&1E;&5T960N`%1H92!L969T+6AA;F0@<VED92!O;FQY`%1H92!L;V-A
M=&EO;B!O9B!T:&4@1VYU4$<@8FEN87)Y(&UU<W0@8F4@9VEV96X@=&\@=&AE
M($-R>7!T7W!G<#HZ(&-L87-S+@!4:&4@;65S<V%G92!S96YT(&]N("5S('1O
M("5S('=I=&@@<W5B:F5C="`B)7,B(&AA<R!B965N(&1I<W!L87EE9"X*5&AI
M<R!I<R!N;R!G=6%R86YT964@=&AA="!T:&4@;65S<V%G92!H87,@8F5E;B!R
M96%D(&]R('5N9&5R<W1O;V0N`%1H92!N86UE('1O('5S92!W:&5N(&QI;FMI
M;F<@=&\@=&AE(&-O;7!O<V4@<&%G90!4:&4@;W!E;G-S;"!M;V1U;&4@:7,@
M<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP=%]S;6EM93HZ(&-L87-S+@!4
M:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO="!B92!S879E9"!B96-A=7-E
M(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI;75M(&%L;&]W86)L92!S:7IE
M`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I
M('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2X`5&AE(')I9VAT(&%N9"!L
M969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O;FQY`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@<V5R=F5R("(E<R(@
M:&%S(&)E96X@<V%V960N`%1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@:&%S
M(&)E96X@<F5M;W9E9"X`5&AE('-P96-I9FEE9"!R;W<@9&]E<R!N;W0@97AI
M<W0N`%1H92!T96UP;W)A<GD@9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4
M:&4@=&]P(&%N9"!B;W1T;VT@<VED97,@;VYL>0!4:&4@=&]P('-I9&4@;VYL
M>0!4:&4@=7!L;V%D960@9&%T82!W87,@;&]S="!S:6YC92!T:&4@<')E=FEO
M=7,@<W1E<"X`5&AE('5P;&]A9&5D(&9I;&4@8V]U;&0@;F]T(&)E('-A=F5D
M+@!4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92X`5&AE
M<F4@87)E(&YO(&]P=&EO;G,@879A:6QA8FQE+@!4:&5R92!A<F4@;F\@<&%R
M=',@=&AA="!C86X@8F4@9&ES<&QA>65D(&EN;&EN92X`5&AE<F4@87)E('1O
M;R!M86YY(&-H87)A8W1E<G,@:6X@=&AI<R!F:65L9"X@66]U(&AA=F4@96YT
M97)E9"`E<R!C:&%R86-T97)S.R!Y;W4@;75S="!E;G1E<B!L97-S('1H86X@
M)7,N`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z
M($YO("5S('=A<R!U<&QO861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H
M('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@
M;6%X:6UU;2!A;&QO=V5D('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@
M<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY
M('!A<G1I86QL>2!U<&QO861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L
M87EI;F<@=&AI<R!M97-S86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM
M<&]R=&EN9R!T:&4@8V]N=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@
M:6UP;W)T:6YG('1H92!I0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R
M<F]R(&EN('1H92!C;VYF:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE
M9G0@;W5T(&$@<F5Q=6ER960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P
M97)F;W)M:6YG('1H92!S<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N
M+B!0;&5A<V4@=')Y(&%G86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@
M=7!D871I;F<@=&AE(&-O;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I
M;B!L871E<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T
M<FEB=71I;VX@;&ES="X@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)
M34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`
M5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV
M92X`5&AI<R!D;V5S(&YO="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL
M92X`5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB
M97(N`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H
M<F]U9V@@=&AE($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE('-M<S)E;6%I;"`H
M:'1T<#HO+W-M<S)E;6%I;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!V
M:6$@4TU44"!T:')O=6=H('1H92!6;V1A9F]N92!)=&%L>2!G871E=V%Y+"!O
M;FQY('1O(%9O9&%F;VYE(&YU;6)E<G,N($ET(')E<75I<F5S(&%N(&5M86EL
M(&%C8V]U;G0@=VET:"!6;V1A9F]N92!)=&%L>2`H:'1T<#HO+W=W=RXQ.3`N
M:70I+@!4:&ES(&9I96QD(&ES(')E<75I<F5D+@!4:&ES(&9I96QD(&UA>2!O
M;FQY(&-O;G1A:6X@:6YT96=E<G,N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N
M=&%I;B!N=6UB97)S(&%N9"!T:&4@8V]L;VXN`%1H:7,@9FEE;&0@;6%Y(&]N
M;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N`%1H:7,@9FEE;&0@;75S="!B92!A
M(&-O;6UA(&]R('-P86-E('-E<&%R871E9"!L:7-T(&]F(&EN=&5G97)S`%1H
M:7,@9FEE;&0@;75S="!B92!A('9A;&ED(&YU;6)E<BX`5&AI<R!F:65L9"!M
M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN('1H92!21T(@2&5X(&9O<FUA
M="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+@!4:&ES(&9O<FT@:&%S(&%L<F5A
M9'D@8F5E;B!P<F]C97-S960N`%1H:7,@:7,@)7,N`%1H:7,@:7,@82!+;VQA
M8B!'<F]U<'=A<F4@;V)J96-T+B!4;R!V:65W('1H:7,@;V)J96-T('EO=2!W
M:6QL(&YE960@86X@96UA:6P@8VQI96YT('1H870@=6YD97)S=&%N9',@=&AE
M($MO;&%B($=R;W5P=V%R92!F;W)M870N($9O<B!A(&QI<W0@;V8@<W5C:"!E
M;6%I;"!C;&EE;G1S('!L96%S92!V:7-I="`E<P!4:&ES(&UE<W-A9V4@=V%S
M('=R:71T96X@:6X@82!C:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y
M;W5R(&]W;BX`5&AI<R!N=6UB97(@;75S="!B92!A="!L96%S="!O;F4N`%1H
M:7,@<V5R=F5R(&-A;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S
M+@!4:&ES('-Y<W1E;2!I<R!C=7)R96YT;'D@9&5A8W1I=F%T960N`%1H:7,@
M=F%L=64@;75S="!B92!A(&YU;6)E<BX`5&AI<R!W:6YD;W<@;75S="!B92!C
M86QL960@9G)O;2!A;B!/<'1I;VYS('=I;F1O=P!4:'5N9&5R`%1I8VME=',`
M5&EM90!4:6UE(%1R86-K:6YG`%1I;64@9F]R;6%T`%1I;64@<V5L96-T:6]N
M`%1I;6]R+4QE<W1E`%1I=&QE`%1I=&QE("AT;V]L=&EP*3H`5&\`5&\@<V5L
M96-T(&UU;'1I<&QE(&ET96US+"!H;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#
M*2!O<B!#;VUM86YD("A-86,I(&ME>2!W:&EL92!C;&EC:VEN9RX`5&]D87D`
M5&]G9VQE($A434P@4V]U<F-E`%1O9V\`5&]K96QA=0!4;VUO<G)O=P!4;VYG
M80!4;W``5&]P(&9R86UE("A?=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@
M86YD(%1O8F%G;P!4<G5E(&]R(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U
M<FMI<V@@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I
M8V]S($ES;&%N9',`5'5V86QU`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN
M9&5X.B``55),`%523"!F;W(@>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S
M(')E<&]R=`!54DPZ`%5G86YD80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@
M5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R
M;6%T:6]N('=H96X@<VEG;FEN9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M
M:7-S:6]N(&9O<B!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E
M('1O("5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B
M;&4@=&\@8V]N;F5C="!W:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I
M;&4N`%5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B
M;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@
M5D93(&9I;&4N`%5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N`%5N
M86)L92!T;R!D96-O;7!R97-S(&1A=&$N`%5N86)L92!T;R!D96QE=&4@(B5S
M(BP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DN`%5N86)L92!T;R!D96QE
M=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I=F5L>2X`56YA8FQE('1O(&1E
M;&5T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E
M8W1O<GDZ("5S+@!5;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE("(E<R(N`%5N
M86)L92!T;R!D96QE=&4@5D93(&9I;&4N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E
M8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N
M(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D
M:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E
M;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T;R!W<FET92!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL
M960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T82X`56YD97)L:6YE
M`%5N9&\@0VAA;F=E<P!5;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C
M=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X
M<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC
M;V1E("A55$8M."D`56YI=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D
M;VT`56YI=&5D(%-T871E<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG
M($ES;&%N9',`56YI=',`56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@
M365S<V%G92!)1"DN`%5N:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E
M($E$*2X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R9"X`56YL:6YK('1H
M92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I;&5G960@<V-R:7!T
M<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R;V=R86UA=&EC86QL
M>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+('1O('-E92!A('1E
M8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H('-H;W=S('EO=2!H
M;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H92!C;&EP8F]A<F0N
M`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO;@!5<&1A=&4`57!D
M871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T(&1E;&5T960N`%5P
M;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T=7`@9FEL97,@=&\@
M=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5<'!E<B!R;VUA;B!N
M=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S92!34TP`57-E(&EF
M(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)35-0('-E<G9E<BX`
M57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI
M<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@
M4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N
M`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S97)S(&EN('1H92!S
M>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D;V5S(&YO="!E>&ES
M="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z(`!6
M86QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+@!686QU97,`5F%L
M=65S('1O('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA
M`%9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@
M8F5E;B!T86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!6
M97)T:6-A;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y
M($AI9V@`5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I
M97<@86X@97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L
M86YD<RP@0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y
M`%9I<VEB:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!
M4DY)3D<A(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!786QL
M:7,@86YD($9U='5N80!787)N:6YG`%=E`%=E871H97(@1F]R96-A<W0`5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y`%=E871H97(N8V]M`%=E8@!796(@4VET
M90!7965K;'D`5V5L8V]M90!796QC;VUE('1O("5S`%=E;&-O;64L("5S`%=E
M<W1E<FX@*$E33RTX.#4Y+3$I`%=E<W1E<FX@*$E33RTX.#4Y+3$U*0!797-T
M97)N(%-A:&%R80!7:&%T(&%P<&QI8V%T:6]N('-H;W5L9"`E<R!D:7-P;&%Y
M(&%F=&5R(&QO9VEN/P!7:&%T(&ES('1H92!D96QI;6ET97(@8VAA<F%C=&5R
M/P!7:&%T(&ES('1H92!Q=6]T92!C:&%R86-T97(_`%=H:6-H('!H87-E<P!7
M:&EC:"!P;'5G:6YS('1O(&5N86)L92!F;W(@=&AE(%)I8V@@5&5X="!E9&ET
M;W(N`%=I9'1H`%=I9'1H(&EN($-34R!U;FET<P!7:61T:"!O9B!T:&4@)7,@
M;65N=2!O;B!T:&4@;&5F="`H=&%K97,@969F96-T(&]N(&YE>'0@;&]G+6EN
M*3H`5VED=&@@;V8@=&AE('1A8FQE`%=I9'1H('5N:70`5VED=&@Z`%=I:VD`
M5VEN9`!7:6YD($5A<FQY`%=I;F0@<W!E960@:6X@:VYO=',`5VEN9#H`5VEN
M9#H@`%=I<V1O;0!7;W)K`%=O<FL@061D<F5S<P!7;W)K(%!H;VYE`%@M4F5F
M`%@U,#EV,R!"87-I8R!#;VYS=')A:6YT<P!8-3`Y=C,@17AT96YD960@2V5Y
M(%5S86=E`%@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E($YA;64`6#4P.78S
M(%-U8FIE8W0@2V5Y($ED96YT:69I97(`6#4P.78S(&5X=&5N<VEO;G,`65D`
M65E960!986AO;R$@;6%P`%EE87)L>0!996UE;@!997,`665S+"!)($%G<F5E
M`%EO=2!A<F4@:6X@5$585"!-3T1%+B`@57-E('1H92!;/#Y=(&)U='1O;B!T
M;R!S=VET8V@@8F%C:R!T;R!765-)5UE'+@!9;W4@87)E(&YO="!A=71H96YT
M:6-A=&5D+@!9;W4@8V%N(&YO="!H879E('1H92`G7"<@8VAA<F%C=&5R(&EN
M('EO=7(@9G5L;"!N86UE+@!9;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M
M86EL(&%D9')E<W,N`%EO=2!D:61N)W0@;6%P(&%N>2!F:65L9',@9G)O;2!T
M:&4@:6UP;W)T960@9FEL92!T;R!T:&4@8V]R<F5S<&]N9&EN9R!F:65L9',@
M:6X@)7,N`%EO=2!H879E(&)E96X@;&]G9V5D(&]U="X`66]U(&AA=F4@=&\@
M96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I=',@;VYL>2!W
M:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T:6]N86P@9&EA
M;&EN9R!P<F5F:7@N`%EO=2!H879E('1O(&5N=&5R(&$@=F%L:60@=F%L=64N
M`%EO=2!M=7-T(&-O;F9I9W5R92!A($1A=&%4<F5E(&)A8VME;F0@=&\@=7-E
M(%-I9VYU<',N`%EO=2!M=7-T(&-O;F9I9W5R92!A(%9&4R!B86-K96YD+@!9
M;W4@;75S="!D97-C<FEB92!T:&4@<')O8FQE;2!B969O<F4@>6]U(&-A;B!S
M96YD('1H92!P<F]B;&5M(')E<&]R="X`66]U(&UU<W0@96YT97(@=&AE(%52
M3"!W:&5R92!T:&ES(&QI;FL@<&]I;G1S('1O`%EO=2!M=7-T('-E;&5C="!A
M;B!S97)V97(@=&\@8F4@9&5L971E9"X`66]U(&UU<W0@<W!E8VEF>2!A('5S
M97)N86UE('1O(&-L96%R(&]U="X`66]U(&UU<W0@<W!E8VEF>2!A('5S97)N
M86UE('1O(')E;6]V92X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@
M=&\@861D+@!9;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A
M=&4N`%EO=2!M=7-T('-P96-I9GD@=VAA="!A8W1I;VX@=&\@<&5R9F]R;2X`
M66]U(&UU<W0@='EP92!A(&YE=R!C871E9V]R>2!N86UE+@!9;W5R("5S('-E
M<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%
M;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA
M=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@
M=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@
M>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M
M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R
M="!L:7-T:6YG('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A
M8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E
M87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO
M=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@
M;75S="!L;V=I;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O
M<G0@=&AI<R!F96%T=7)E+@!9;W5R(&-U<G)E;G0@=&EM92!Z;VYE.@!9;W5R
M(&1E9F%U;'0@:61E;G1I='DZ`%EO=7(@9G5L;"!N86UE.@!9;W5R(&YE=R!P
M87-S=V]R9"!F;W(@)7,@:7,Z("5S`%EO=7(@;W!T:6]N<R!H879E(&)E96X@
M=7!D871E9"!F;W(@=&AE(&1U<F%T:6]N(&]F('1H:7,@<V5S<VEO;BX`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D+@!9;W5R('!A<W-W;W)D(&AA
M<R!B965N(')E<V5T`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970L(&-H
M96-K('EO=7(@96UA:6P@86YD(&QO9R!I;B!W:71H('EO=7(@;F5W('!A<W-W
M;W)D+@!9;W5R(')E;6]T92!S97)V97)S.@!9=6=O<VQA=FEA`%IA:7)E`%IA
M;6)I80!::6UB86)W90!::7!P>0!;2&ED92!1=6]T960@5&5X=%T`6U!R;V)L
M96T@4F5P;W)T70!;4VAO=R!1=6]T960@5&5X="`M`%M3:&]W(%%U;W1E9"!4
M97AT("T@)7,@;&EN97-=`%ML:6YE("5S(&]F("5S70!?061M:6YI<W1R871I
M;VX`7T-,20!?1&%T851R964`7T1E;&5T92!2;W<`7T=R;W5P<P!?2&5L<`!?
M26UA9V4@4')O<&5R=&EE<RXN+@!?3&]G(&EN`%],;V<@;W5T`%]-;V1I9GD@
M3&EN:RXN+@!?3W!T:6]N<P!?4&5R;6ES<VEO;G,`7U)E;6]V92!,:6YK+BXN
M`%]3971U<`!?5&%B;&4@4')O<&5R=&EE<RXN+@!?57-E<G,`861D<F5S<R!B
M;V]K`&-A;&5N9&%R`&-A;&T`8VQI8VL@:&5R90!F86QL:6YG`&9I;&4`9G)O
M;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!H.@!I;6UE9&EA=&4`:6YL:6YE`&QI
M;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`
M;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E
M<&%D`'!E<F-E;G0`<&EX96QS`')I<VEN9P!S:&]W(&1I9F9E<F5N8V5S`'-M
M<S)E;6%I;"!V:6$@2%144`!S=&5A9'D`=&%S:R!L:7-T`'1Y<&4@=&AE('!A
M<W-W;W)D('1W:6-E('1O(&-O;F9I<FT`=6YI9FEE9`!U;FYA;65D`'5S97(@
M<V5L96-T`'9#87)D`'<Z`'=E871H97(N8V]M`%!R;VIE8W0M260M5F5R<VEO
M;CH@2&]R9&4@,RXP"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES=',N
M:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`U+3$P+3$X(#$U.C$R
M*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-"TP-RTR,B`Q,3HT.2TP-S`P
M"DQA<W0M5')A;G-L871O<CH@36EL;W,@5VEM;65R(#QW:6UM97)`>F-U+F-Z
M/@I,86YG=6%G92U496%M.B!#>F5C:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^
M"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@
M8VAA<G-E=#U)4T\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z
M(#AB:70*4&QU<F%L+49O<FUS.B!N<&QU<F%L<STS.R!P;'5R86P]*&XE,3`]
M/3$@)B8@;B4Q,#`A/3$Q(#\@,"`Z(&XE,3`^/3(@)B8@;B4Q,#P]-"`F)B`H
M;B4Q,#`\,3`@?'P@;B4Q,#`^/3(P*2`_(#$@.B`R*3L*`"`H</AE9"`E<R!D
M;GDI`"`H4/CM<W1U<&]V_2!K;.WH("5S*0`@*'8@)7,@9&YE8V@I`"`H9&YE
M<RD`("AZ[71R82D`("AVZ&5R82D`(')Y8VAL;W-T(``E9"`E<R!A("5S`"5D
M+61E;F[M('#X961P;W;L[P`E<R`M(&]Z;N%M96[M`"5S(&]T:7-K`"5S($M"
M`"5S(&]P97)A8V4@^F1ROF)Y("T@<&]T=G)Z96[M`"5S(&YA<W1A=F5N[0`E
M<R!R96=I<W1R86-E`"5S('!O9&WM;FMY('!O=;[M=N%N[0`E<R!J:;X@97AI
M<W1U:F4N`"5S(&YA("5S("5S`"5S(&IE('!OOF%D;W;A;F\`)7,@;6EN=70`
M)7,@;F5B>6QO(&YA;&5Z96YO+@`E<R!AOB`E<R!Z("5S`"5S(&%D<F5SX?@`
M)7,@:V%L96YDX?@`)7,@>N%P:7-N[6L`)7,@<V5Z;F%M(/IK;VSY`"5S.B`E
M<P`L(&[A<F%Z;W;]("5S("5S`"P@<')O;>QN;N$@;V0@)7,@9&\@)7,`+2T@
M=OUB['(@+2T`,3(@:&]D:6YO=OT@9F]R;>%T`#(T(&AO9&EN;W;](&9O<FWA
M=``R-"!H;V1I;@!0<F\@=&5N=&\@8FQO:R!J92!V>;YA9&]VX6X@9&%T86+A
M>F]V_2!Z9')O:BX`5GES:WET;&$@<V4@>N%V8;YNX2!C:'EB80!0<F\@>F&Y
M:69R;W;A;NT@>G!RX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K
M;.WH+@!0<F\@=F5R:69I:V%C:2!P;V1E<'-A;ND@>G!RX79Y(&IE(&YU=&YO
M('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+@!0<F\@9&6Y:69R;W;A;NT@>G!R
MX79Y(&IE(&YU=&YO('!O=;[M="!V9?AE:F[](%!'4"!K;.WH+"!P<FEVX71N
M[2!01U`@:VSMZ"!A(&AE<VQO+@!0<F\@<&]D97!SX6[M('IP<N%V>2!J92!N
M=71N;R!P;W6^[70@=F7X96IN_2!01U`@:VSMZ"P@<')I=N%T;NT@4$=0(&ML
M[>@@82!H97-L;RX`4')O(&1EN6EF<F]VX6[M('IP<N%V>2!J92!N=71N;R!P
M;W6^[70@=F7X96IN_2!3+TU)344@:VSMZ"P@<')I=N%T;NT@4R]-24U%(&ML
M[>@@82!H97-L;RX`4')O('!O9&5P<^%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]U
MONUT('9E^&5J;OT@4R]-24U%(&ML[>@L('!R:7;A=&[M(%,O34E-12!K;.WH
M(&$@:&5S;&\N`%!R;R!Z8;EI9G)O=N%N[2!Z<'+A=GD@:F4@;G5T;F\@<&]U
MONUT('9E^&5J;OT@4R]-24U%(&ML[>@N`%)A;F[M(&3IN;L`4F%N;NT@</AE
M:.'R:WD`4F%N;NT@<V[L:&]VZ2!P^&5HX?)K>0!!32]030!!4$D@240`26YF
M;W)M86-E(&\@=&]M=&\@961I=&]R=0!);F9O<FUA8V4N+BX`5&5X="!D;VSY
M(&1O(&]B<N%Z:W4`5&5X="!D;W!R;W-T^&5D(&]B<N%Z:W4`5GET=F_X96[M
M(%9&4R!A9')A<^'X92!N96)Y;&\@<&]V;VQE;F\N`%9Y='9O^&5N[2!61E,@
M<V]U8F]R=2!N96)Y;&\@<&]V;VQE;F\N`%6^:79A=&5L<VOI(&AE<VQO`%6^
M:79A=&5L:_T@^NAE="!B>6P@>F%B;&]K;W;A;BX`5;YI=F%T96QKZ2#ZZ'1Y
M`%9L;[X`4/AI9&%T('!O9'-K=7!I;G4`4/AI9&%T('!O9"UP<N%V80!0^&ED
M870Z`%#X:61A="!N;W9O=2!S:W5P:6YU`%#X:61A="!N;W;A('!RX79A`%#X
M:61A="!N;W;I:&\@=;YI=F%T96QE.@!0^&ED870@<VQO=7!E8P!0^&ED870@
M;F]VZ2#H;&5N>0!0^&ED870@<.%R`%#X:61A="`E<R!M96YU(&IA:V\@8F_H
M;NT@<VQO=7!E8R!-;WII;&QY`%#X:61A="!D;R!A9')E<^'X93H`4/AI9&%T
M(&1O(&WI:&\@861R97/A^&4`4/AI9&%T('6^:79A=&5L90!0^&EDX7;A;NT@
M=;YI=F%T96SY(&IE('IA8FQO:V]VX6YO+@!!9')E<V$`061R97/A^`!6>6MO
M;N%V870@861M:6YI<W1R86-I("T@;F%S=&%V96[M('#X[7-T=7!O=OUC:"!P
M<N%V('!R;R!O<W1A=&[M('6^:79A=&5L90!!9&UI;FES=')A8V4`26YZ97+A
M='D`069G:.%N:7-TX6X`06QBX6YI90!!;+[M<G-K;P!0^&5Z9.UV:V$O06QI
M87,`6F%R;W9N870`6F%R;W9NX6[M.@!6N64`5KEI8VAN:2!O=NSX96[M('6^
M:79A=&5LZ0!6N65C:&YY('-K=7!I;GD`5KEE8VAN82!UOFEV871E;'-KX2!P
M<N%V80!6N65C:&YY(.AT>?AI('-T<F%N>0!0;W9O;&ET(';M8V4@861R97,`
M4&]V;VQI="!N87-T879E;NT@='EP=2!S973X[63L;OT@<V5Z;F%M/P!*:;X@
M97AI<W1U:F4`06QT97)N871I=F[M($E-4U`@</AI:&SAN65N[2!D;R!S>7-T
MZ6UU`$%L=&5R;F%T:79N[2!)35-0(&AE<VQO`$%L=&5R;F%T:79N[2!)35-0
M('6^:79A=&5L<VOI(&IMZ6YO`$%L=&5R;F%T:79N[2!E+6UA:6QO=N$@861R
M97-A`$%L=&5R;F%T:79N[2!V>F]R>0!!;'1E<FYA=&EV;NT@=&5X=#H`06UE
M<FEC:^$@4V%M;V$`0GEL82!Z863A;F$@;F5P;W9O;&5NX2!H;V1N;W1A+@!!
M;F1O<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6[M('!R;WAY`$]D<&]V[.\`
M06YT87)K=&EK80!!;G1I9W5A(&$@0F%R8G5D80!!<&QI:V%C90!397IN86T@
M87!L:6MA8^T`07!L:6MA8V4@:F4@</AI<')A=F5N80!0;W6^[70@<')O(&3L
M9&GH;ND@<V3M;&5N[0!38VAVX6QI=`!0^&EB;&F^;N$@=F5L:6MO<W0`1'5B
M96X`07)A8G-K>2`H5VEN9&]W<RTQ,C4V*0!696QI:V]S="!A<F-H:79O=F%N
MZ6AO('-O=6)O<G4`2FWI;F\@87)C:&EV=0!5<NAI=.P@8VAC971E('9Y;6%Z
M870@ON%D;W-T(&\@</AI:&SAN65N[2!D;R`E<S\`07)G96YT:6YA`$%R;>EN
M:64`07)MZ6YS:_T@*$%235-#24DM."D`56WL;NT`07)U8F$`07-C96YS:6]N
M($ES;&%N9`!!<V-I:2!U;>QN[0!!<VEE+W)E9VEO;B!4:6-HZ6AO(&]C9>%N
M=0!0;[[A9&%T(&\@<&]T=G)Z96[M('#X960@<')O=F5D96[M;2!O<&5R86/M
M(/ID<KYB>3\`4VQO=7!C92!S(/IK;VQY`%!O:W5S(&\@=GEM87KA;NT@;F5E
M>&ES='5J[6/M('-K=7!I;GDN`%!O:W5S(&\@=GEM87KA;NT@;F5E>&ES='5J
M[6/M8V@@=;YI=F%T96QS:_UC:"!P<N%V+@!0;VMU<R!O(/IP<F%V=2!N965X
M:7-T=6KM8^UC:"!UOFEV871E;'-K_6-H('!RX78N`%!O:W5S(&\@^G!R879U
M(&YE97AI<W1U:NUC[6AO('-D[6QE;NEH;R!O8FIE:W1U+@!!=')I8G5T>0!3
M<G!E;@!!=7-T<N%L:64`4F%K;W5S:V\`075T:%]C>7)S<6PZ($YE8GEL82!N
M86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@<')O(&EM87`N`$%U=&A?8WER
M=7,Z(%ID<F]J(&YE;>$@<&^^861O=F%NZ2!S8VAO<&YO<W1I+@!!=71H7V-Y
M<G5S.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!I
M;6%P+@!!=71H7V9T<#H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A;N$@</CM
M<&]N82!P<F\@9G1P+B!+;VUP:6QU:G1E(%!(4"!S("TM96YA8FQE+69T<`!!
M=71H7VEM87`Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O;F$@
M<')O($E-05`N`$%U=&A?:W)B-3H@3F5B>6QA(&YA;&5Z96YA('!OOF%D;W9A
M;N$@</CM<&]N82!P<F\@:W)B-2X`075T:%]L9&%P.B!.96)Y;&$@;F%L97IE
M;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!,1$%0`$%U=&A?;&1A<#H@3F5L
M>F4@</AI9&%T('6^:79A=&5L92`E<RX@2&SAN65N[2!S97)V97)U.B``075T
M:%]L9&%P.B!.96QZ92!V>6UA>F%T('6^:79A=&5L92`E<P!!=71H7VQD87`Z
M($YE;'IE(&%K='5A;&EZ;W9A="!UOFEV871E;&4@)7,`075T:%]M8V%L.B!.
M96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA('!R;R!-0T%,+@!!
M=71H7W-M8F%U=&@Z($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A('#X[7!O
M;F$@<')O('-M8F%U=&@N`$]V[/AE;NT@<V5L:&%L;P!/=NSX96[M('-E;&AA
M;&\N("5S`$]V[/AE;NT@8GEL;R!Z86WM=&YU=&\@4D%$2553('-E<G9E<F5M
M+@!396QH86QO(&]V[/AE;NT@1E10('-E=F5R96TN`$1O<W1U<&[A('!O;&4Z
M`$%Z97)B86IDON%N`$)/1D@@=OUM;'5V>0!0;WIA9.T`0F%R=F$@<&]Z863M
M`*EP871NZ2!H97-L;R!P<F\@:V5R8F5R;W,N`*EP871NZ2!UOFEV871E;'-K
MZ2!J;>EN;R!P<F\@:V5R8F5R;W,N`$)A:&%M>0!"86AR86EN`$)A;'1I8VOI
M("A)4T\M.#@U.2TQ,RD`0F%N9VQA9.FY`$)A<F)A9&]S`%KA:VQA9`!"[&QO
M<G5S:V\`0F5L9VEE`$)E;&EZ`$)E;FEN`$)E<FUU9'D`0FCZ=.%N`$YA<F]Z
M96YI;GD`3F5L>F4@;F%LZ7IT(.CA<W0@(B5S(B!A<&QI:V%C92`B)7,B+@!.
M87-T879E;NT@8FQO:W4`5'EP(&)L;VMU`%1UZ&[L`$)O;.UV:64`6N%L;[YK
M>0!/:W)A:@"I[?AK82!O:W)A:F4Z`$]K<F%J90!";W-N82!A($AE<F-E9V]V
M:6YA`$]B80!";W1S=V%N80!$;VQN[2#HX7-T`$)O=79E="!)<VQA;F0`0G)A
M>NUL:64`0G)I='-KX2!T97)I=&]R:6$@=B!);F1I8VOI;2!O8V7A;NP`0G)U
M;F5I($1A<G5S<V%L86T`0G5L:&%R<VMO`%-E>FYA;2!S(&]D<N&^:V%M:0!"
M=7)K:6YA($9A<V\`0G5R=6YD80!#35,`0U)#`$-23"!D:7-T<FEB=>AN[2!B
M;V1Y`%9L87-T;F]S=&D@8E]U\FMY+BXN`$MA;&5N9.'X`$)E>G;L=/CM`$MA
M;6)O9+YA`$MA;65R=6X`2&5S;&\@;F5L>F4@;F%S=&%V:70@875T;VUA=&EC
M:WDL('!R;W/M;2!K;VYT86MT=6IT92!68;EE:&\@<WES=.EM;W;I:&\@861M
M:6YI<W1RX71O<F$N`$YE;'IE('-E('#X:7!O:FET(&L@24U!4"!S97)V97)U
M.B`E<P!+86YA9&$`4W1O<FYO`%-T;W)N;R!H;.&Y96[M('!R;V)LZ6UU`$YE
M;'IE('9Y;6%Z870@<V]U8F]R("(E<R(N`$YE;'IE(&YA:NUT(&1OZ&%S;OT@
M861R97/A^"X`3F5L>F4@<&]K<F'H;W9A="!B97H@<&%R86UE=')U("=T87)G
M971&:6QE)RX`3F5L>F4@=GEM87IA="!A9')E<^'X("(E<R(N`$YE;'IE('9Y
M;6%Z870L('!R;W1OOF4@97AI<W1U:NT@<&]D<VMU<&EN>2`E9"X`3F5L>F4@
M<')O=NES="!Z;>QN=2!U<W!O^.%DX6[M+"!P;^AE="!P;W-K>71N=73]8V@@
M<&]L;[YE:R!P<F\@;F]VZ2!U<W!O^.%DX6[M(&YE;V1P;W;M9.$@<&_H='4@
M=6QOOF5N_6-H('!O;&^^96LN`$YE;'IE('IA<VQA="!Z<'+A=G4@;F$@>F%D
M86[I(.CM<VQO+B``0V%P92!697)D90!4:71U;&MY`$MA=&5G;W)I92!A('IN
M8>AK>0!+86IM86YS:^D@;W-T<F]V>0!-;V)I;&[M('1E;&5F;VX`36^^;F]S
M=&D@8G7R:WD`3V1S='5P(&UE>FD@8G7R:V%M:3H`5FQA<W1N;W-T:2!B=?)K
M>0!-97IE<GD@;65Z:2!B=?)K86UI.@!-;V)I;&[M('1E;&5F;VX`2V5L='-K
M_2`H25-/+3@X-3DM,30I`%-T^&5D`%-T^&5D;V%F<FEC:^$@<F5P=6)L:6MA
M`%-T^&5D;V5V<F]P<VO]("A)4T\M.#@U.2TR*0!0;V1R;V)N;W-T:2!C97)T
M:69I:^%T=0!0;V1M[6YK>2!C97)T:69I:^%T=0#(860`6FWL;FET`$YA<W1A
M=F5N[2!J;>EN82!A(&5M86EL;W;I(&%D<F5S>2X@5'ET;R!P;VQOOFMY(&QI
M9.D@=79I9.TL(&MD>;X@<VD@Z'1O=2!N96)O(&]D<&]V[61A:NT@;F$@5F&Y
M92!Z<'+A=GDN`%IN86L`6FMO;G1?<F]L;W9A="!O9&MA>BXN+@!#:&EL90#(
M[6YA`,CM;KET:6YA('IJ961N;V1UN65NX2`H1T(R,S$R*0!4<F%D:>AN[2#H
M[6ZY=&EN82`H0FEG-2D`6G9O;'1E(&AE<VQO`%IV;VQT92!UOFEV871E;'-K
MZ2!J;>EN;P!6>6)R870@>F]B<F%Z96[M(&1A='5M=3H`5GEB<F%T('1Y<"!S
M='EL=2!S97IN86UU("AP<F\@^&%Z96[I('-E>FYA;7DI`%;A;F_H;NT@;W-T
M<F]V`$YE8GEL82!N86QE>F5N82!D969I;FEC92!T^.UD>2`E<RX`5GGH:7-T
M:70`5GGH:7-T:70@>FYAZ&MY('H@35-/9F9I8V4`3V1S=')A;NQN[2!UOFEV
M871E;&4Z("5S`$]D<W1R86YI="!UOFEV871E;&4`3V1S=')A;NQN[2#Z9&%J
M^2!O('6^:79A=&5L:0!+;&EK;NQT92!P<F\@<&]K<F'H;W;A;NT`0VQI8VMA
M=&5L;"!P^&5S($A45%``6F%V^.UT(&]K;F\`6F%T8;YE;F\`3V)L8>AN;P!+
M;VMO<V]VZ2!O<W1R;W9Y`%-K;&%P;F]U="!B;^AN[2!L:;ET=0!3:VQA<&YO
M=70@;VMR86IE`$MO;'5M8FEE`$)A<G9A`%;]8NQR(&)A<F5V`%!A;&5T82!B
M87)E=@!3;&]U<&-E.@!.X7IV>2!S;&]U<&-E`$MO;6EK<WD`4/CM:V%Z`%#X
M[6MA>F]VX2!K;VYZ;VQA`%!O>F[A;6MA`$]B96-NZ2!J;>EN;P!+;VUO<F]S
M`$9I<FUA`%!OZ.UT8>AE`%!O9&WM;FMY`%)O>F3M;'D@=B!N87-T879E;NT`
M3F%S=&%V:70@)7,`4&]T=G)D:70@:&5S;&\`2V]N9V\`2V]N9V\L($1E;6]K
M<F%T:6-KX2!R97!U8FQI:V$`4W!O:F5N[2!S96QH86QO+@!3<&]J96[M('-E
M;&AA;&\Z(`!">6QO('IA;>UT;G5T;R!S<&]J96[M(',@=F7X96IN_6T@:VSM
MZ&]V_6T@<V5R=F5R96TN`$)Y;&\@>F%M[71N=71O('-P;VIE;NT@<R!V9?AE
M:F[];2!K;.WH;W;];2!S97)V97)E;2X@1/EV;V0@.B`E<R`H)7,I`%-E;&AA
M;&\@<W!O:F5N[2!S($944"!S97)V97)E;2X`2V]N=&%K='D@8GEL>2#Z<W#L
MN6[L('#X:63A;GD@9&\@5F&Y96AO(&%D<F5SX?AE+@!0;VMR8>AO=F%T`$-O
M;VMO=GD@;W-T<F]V>0!+;VSAZ&5K`$MO<.UR;W9A=`!+;W#M<F]V870@=OUB
M['(`2V]S=&%R:6MA`%!O8OAEONT@<VQO;F]V:6YY`%IP<N%V=2!N96QZ92"Y
M:69R;W9A="!P;VUO8^T@4$=0+@!:<'+A=G4@;F5L>F4@<&]D97!S870@<&]M
M;V/M(%!'4"X`6G!RX79U(&YE;'IE(+EI9G)O=F%T('!O;6]C[2!3+TU)344N
M`%IP<N%V=2!N96QZ92!P;V1E<'-A="!P;VUO8^T@4R]-24U%+@!.96QZ92!P
M^&ED870@:V]N=&%K="X@)7,`3F5L>F4@<V4@</AI<&]J:70@:R!,1$%0('-E
M<G9E<G4N`$YE;'IE('IK;VYT<F]L;W9A="#ZZ&5T+B`E<P!.96QZ92!V>71V
M;_AI="!D:7-T<FEB=>AN[2!S97IN86TN("5S`$YE;'IE(&1EN6EF<F]V870@
M4$=0(&1A=&$N`$YE;'IE(&1EN6EF<F]V870@4R]-24U%(&1A=&$N`$YE;'IE
M('-M87IA="!K;VYT86MT+B`E<P!.96QZ92!S;6%Z870@9&ES=')I8G7H;NT@
M<V5Z;F%M+B`E<P!.96QZ92!Z:FES=&ET(&4M;6%I;&]V;W4@861R97-U('#X
M[6IE;6-E+@!.96QZ92!Z[7-K870@^G!L;OT@861R97/A^"X`3F5L>F4@>NUS
M:V%T(/IP;&[](&1I<W1R:6)UZ&[M('-E>FYA;2X`3F5L>F4@>NUS:V%T(/IP
M;&[]('-E>FYA;2!D:7-T<FEB=>AN[6-H('-E>FYA;?DN`$YE;'IE('KM<VMA
M="!V9?AE:F[](&ML[>@@>B!K;.WH;W;I:&\@<V5R=F5R=2X`3F5L>F4@;W1E
M=OCM="`E<RX`3F5L>F4@<')O=NES="!O<&5R86-E(/ID<KYB>2!P<F\@;6]D
M=6P@)7,`3F5L>F4@Z.US="`E<RX`3F5L>F4@<F5S971O=F%T(&AE<VQO('!R
M;R!D86[I:&\@=;YI=F%T96QE+B!6N65C:&YY(&YE8F\@;NQK=&5RZ2!Z('!O
M9')O8FYO<W3M(&YE8GEL>2!S<'+A=F[L('IA9.%N>2X@6FMU<W1E('1O('IN
M;W9U(&YE8F\@<&]K=60@<&]T^&5B=6IE=&4@<&]M;V,L(&MO;G1A:W1U:G1E
M('-P<N%V8V4@<WES=.EM=2X`3F5L>F4@>NUS:V%T($%#3`!.96QZ92!Z[7-K
M870@861R97/A^"X@)7,`3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA
M;2X@)7,`3F5L>F4@>NUS:V%T(&1I<W1R:6)UZ&[M('-E>FYA;7DN("5S`$YE
M;'IE('KM<VMA="!S8VAO<&YO<W1I('-E<G9E<G4`3F5L>F4@</AE<&YO=70@
M:V]N9FEG=7)A8VDN`$YE;'IE('5L;[YI="!K;VYF:6=U<F%C:2!P<F\@)7,N
M`$YE;'IE('5L;[YI="!ZX6QOOF[M(&MO;F9I9W5R86-I+@!.96QZ92!U;&^^
M:70@>N%L;VAU(&MO;F9I9W5R8>AN[6AO('-O=6)O<G4@)7,N`$YE;'IE(&AL
M961A="!V($Q$05`@<V5R=F5R=2X`3F5L>F4@86MT=6%L:7IO=F%T(&MO;G1A
M:W0N("5S`$YE;'IE(&%K='5A;&EZ;W9A="!D:7-T<FEB=>AN[2!S97IN86TN
M("5S`$YE;'IE(&YA;.EZ="!B;^AN[2!L:;ET=2!P<F\@36]Z:6QL=2X@4')O
M<^UM('#X97-V[&3H=&4@<V4L(+YE(&IE(&]T97;X96[A+@!/9'!OZ.UT86[]
M('1E>'0`6F5M[`!6>77H;W9A8^T@</AE9&WL='D`5GET=F_X:70`5GET=F_X
M:70@;V1K87H`5GET=F_X:70@;F]V;W4`5GET=F_X:70@<&]D<VQOOFMY`%1V
M^7)C92!P<N%V`,CM<VQO(&MR961I=&[M(&MA<G1Y`$-H;W)V871S:V\`2W5B
M80!!:W1UX6QN[2#H87,`06MT=>%L;NT@55),(&IE`$%K='7A;&[M('!OZ&%S
M[0!!:W1UX6QN[2!P;V1M[6YK>3H@`$YY;NQJN>T@<W1Y;`!.87-T879E;NT@
M^FMO;/D@<')O=N%D[&[]8V@@</AI('#X:6ALX;EE;NT@9&\@)7,N`%9Y<W3X
M:6AN;W5T`%9Y<W3X:6AN;W5T(';]8NQR`$MY<'(`07IB=6MA("A+3TDX+5(I
M`$%Z8G5K82`H5VEN9&]W<RTQ,C4Q*0!!>F)U:V$O56MR86II;F$@*$M/23@M
M52D`R&5S:^$@<F5P=6)L:6MA`$1$`$1E;F[L`$1A=&%4<F5E('!R;VAL[;YE
MZ`!$871U;0!0^&EJ871O(&1N90!6_6+L<B!D871U;74`1&5N`%-M85]Z870@
M<VQO=7!E8P!0<F]S:6YE8P#([7-L82!D97/M=&MO=ND@<V]U<W1A=GD`6FUE
M;KEI="!O9'-A>F5N[0!);7!L:6-I=&[M`$EM<&QI8VET;NT@8F%R=F$`26UP
M;&EC:71N[2!I9&5N=&ET80!$969I;FEC90!3;6%Z870`4VUA>F%T('-K=7!I
M;G4`4VUA>F%T('!RX79A`%-M87IA="!A('9YZ&ES=&ET('IP<N%V>0!3;6%Z
M870@8G7R:W4`4VUA>F%T('-L;W5P96,`4VUA>F%T(&5X:7-T=6KM8^T@86QT
M97)N871I=F[M('9Z;W(`4VUA>F%T(/CA9&5K`%-M87IA="!V>6)R86YO=2CI
M*2!I9&5N=&ET=2AY*0!3;6%Z870@<V]UZ&%S;OT@<VQO=7!E8P!3;6%Z870@
M<V]UZ&%S;OT@^.%D96L`R&%S(&1O<G7H96[M`$3A;G-K;P!0;W!S870@<')O
M8FSI;0!0;W!I<P!0;V1R;V)N;W-T:2`H=&%KZ2!V(&QO9R!S;W5B;W)U($AO
M<F1E*3H`4&]D<F]B;F]S=&D@8GEL>2!Z87IN86UE;N%N>2!D;R!L;V<@<V]U
M8F]R=2!P<F\@861M:6YI<W1RX71O<F$N`%;]=F]J`%)O<V[](&)O9`!2;W-N
M_2!B;V0@>F$@<&]S;&5D;NT@:&]D:6YU.B``4F]S;OT@8F]D.B``4VWL<B!Z
M(&QE=F$@9&]P<F%V80!3;>QR('H@<')A=F$@9&]L979A`$%D<F5SX?@`6F]B
M<F%Z:70@,C0M:&]D:6YO=OT@Z&%S/P!-;[YN;W-T:2!Z;V)R87IE;NT`6F]B
M<F%Z:70@</AE9'!O=NSO("A4048I`$9O<FWA="!Z;V)R87IE;NT`1&ES<&]Z
M:>AN[2!U<&]Z;W)N[&[M`$1J:6)O=71I`$YE<VUA>F%T`$YE</AI<W1U<&]V
M870@</CM;6\@9&\@;6%I;G1E;F%N8V4N<&AP`$]B<V%H=6IE('!R=F[M(/CA
M9&5K(&[A>F5V('-L;W5P8_D_(%!O:W5D(&%N;RP@>F&Y:W)T;NQT92!T96YT
M;R!RX6UEZ&5K.@!$;VUI;FEK80!$;VUI;FEKX6YS:^$@<F5P=6)L:6MA`%-T
M8;YE;NT`4W1AOF5N[2`E<P!3=&%H;F]U="!G96YE<F]V86YO=2!K;VYF:6=U
M<F%C:2!J86MO(%!(4"!S:W)I<'0N`%)O;&5T;W;]('-E>FYA;0!$<F]G>0!%
M+6UA:6P`15)2`$5K=N%D;W(`57!R879I=`!5<')A=FET(&)L;VL`57!R879I
M="!S:W5P:6YU`%5P<F%V:70@<'+A=F$`57!R879I="!P<N%V80!5<')A=FET
M('!RX79A('!R;R`E<P!5<')A=FET(&UOOFYO<W1I('!R;SH`57!R879I="!P
M<N%V82!P<F\@)7,`5OUU:V$`16=Y<'0`16P@4V%L=F%D;W(`4')V96LN+BX`
M16T`16UA:6P`16UA:6QO=N$@861R97-A`$5M86EL;W;I(&%D<F5S>2!S92!M
M=7/M('-H;V1O=F%T+@!%;6%I;"!S('!O='9R>F5N[6T`26MO;FMY(',@96UO
M8V5M:0!0<N%Z9&[A('IP<N%V82X`4'+A>F1N_2!V_7-L961E:RX`4'+A>F1N
M_2!T97)M[6X@<')O('9Y:&QE9.%VX6[M`%!O=F]L:70@=FMLX63A;NT@;V)R
M87IK^2!Z(&9O=&\@9V%L97)I[2!D;R!T97AT=3\`06MT:79O=F%T('!R87;I
M(&ML:6MN=73M('!R;R!K;VYT97AT;W;I(&UE;G4_`$MO;F5C(')O:W4`6G;L
M=+EI="!E9&ET;W(`6F%D96IT92!B97IP9>AN;W-T;NT@;W3A>FMU+"!N82!K
M=&5R;W4@8G5D971E(&UU<V5T(&]D<&]V[&3L="!P;VMU9"!S:2!B=61E=&4@
M8VAT[70@<F5S971O=F%T('-VZ2!H97-L;RP@;F%P^"X@)TIA:^D@:F4@:FWI
M;F\@5F&Y96AO('!S83\G.@!:9&4@=FQOOFET(%523"!O8G+A>FMU`%)O=F[M
M:V]VX2!'=6EN96$`17)I=')E80!#:'EB80!.87-T86QA(&-H>6)A(',@<&^Y
M=&]V;NT@>G!RX79O=2X`17-T;VYS:V\`171I;W!I90!%=&YI8VOI`$5V<F]P
M80!+8;YD_6-H(#$U(&UI;G5T`$MAOF3I(#(@;6EN=71Y`$MAOF3]8V@@,S`@
M<V5K=6YD`$MAOF3]8V@@-2!M:6YU=`!+8;YDZ2!P^&EH;.&Y96[M(&1O('-Y
M<W3I;74`2V&^9&]U('#Y;"!H;V1I;G4`2V&^9&]U(&UI;G5T=0!6>F]R;W;]
M('#X[6ML860@:&]D;F]T.@!0<F]VZ7-T`%)O>G9I;F]U=`!2;WIB86QI="!B
M;^AN[2!L:;ET=0!/Z&5KX7;A;F$@)RDG`$_H96OA=N%N;R!S86UO<W1A=&[I
M('-L;W9O(&YE8F\@:&QE9&%N_2!T97)M[6X@=B!U=F]Z;W9KX6-H`$1A='5M
M('!R;R!K;VYE8R!P;&%T;F]S=&D`17AP;VYE;G0`0F%R=F$@<&]P^&5D[0!0
M^&5N;W,@:V]N9FEG=7)A8V4@<&]M;V/M($944`!396QH86QO('KM<VOA;NT@
M;6^^;F]S=.TN`$YE;'IE('-E('#X:7!O:FET(&L@3$1!4"!S97)V97)U+@!.
M96QZ92!S92!P^&EP;VII="!K(%--0B!S97)V97)U+@!396QH86QO(&MO<.UR
M;W;A;NT@>B`B)7,B+@!396QH86QO(&MO<.UR;W;A;NT@9&\@(B5S(BX`4V5L
M:&%L;R!Z86QOOF5N[2!N;W;I:&\@4T%33"!S<&]J96[M+@!396QH86QO('#X
M97-U;G5T[2!D;R`B)7,B+@!$;V)RZ0!&86QK;&%N9'-KZ2!O<W1R;W9Y("A-
M86QV:6YY*0!&87)I:G-KZ2!O<W1R;W9Y`%KA=F&^;N$@8VAY8F$Z`$9A>`#:
M;F]R`$/M=&ET('-E(&IA:V\`0^UT:70@<V4@:F%K;SH`1')O8F[I('#X96CA
M\FMY`$1R;V)NZ2!S;NQH;W;I('#X96CA\FMY`$UA=&EC92!P;VQE`$9I:FD`
M4&_H970@<V]U8F]R^3H@)7,@<V]U8F]R`%!OZ&5T('-O=6)O<ODZ("5S('-O
M=6)O<OD`4W!RX79C92!S;W5B;W+Y`$[A>F5V('-O=6)O<G4`5OUB['(@<V]U
M8F]R=0!0^&5NZ7-T('-O=6)O<@!0^&5N;W,@<V]U8F]R^2!N96[M('!O9'!O
M<F]VX6XN`$9I;'1R>0!&:6YS:V\`4')V;NT@<&]L;W9I;F$`4')V;NT@Z'1V
M<G1I;F$`4&5V;ND@;>SX[71K;P!0^&5H;V1I=`!0;&]V;W5C[0!-;&AA`%-L
M;[YK82`E<R!N965X:7-T=6IE`$)A<G9A('#M<VUA`$KM9&QO`%!R;R!P<F]H
M;.V^9>AE(&YE<&]D<&]R=6KM8^T@;V)RX7IK>0!0^&5D<&]V[.\@*%1!1BD`
M4/AE9'!O=NSO('!OZ&%S[2!P<F\@9&YY("AP;WINX6UK83H@</AE9'!O=NSO
M(&IE('!R;R!D;GD@:2!N;V-I.R!T;W1O(&WYOF4@=GET=F_X:70@<&]M[')N
M["!O8G/A:&S]('-E>FYA;2X`6F%P;VUN[&QI(&IS=&4@5F&Y92!H97-L;S\`
M1F]R;75LX?AE`*ET['-T[0!4>7`@N73L<W3M`*ET['-T[0"I=.QS=.T@,@!&
M\W)A`%#X97!O<VSA;NT`4.$`4N%M>0!&<F%N8VEE`$9R86YC:64L(&UE=')O
M<&]L:71N[0!&<F%N8V]U<VOA($=U86GA;F$`1G)A;F-O=7-KX2!0;VQY;NES
M:64`1G)A;F-O=7-KX2!J:;YN[2!T97)I=&]R:6$`3V0`3V0`4&]D<F]B;OT@
M<&]P:7,`VG!L;NQK`$-E;.D@:FWI;F\`1V%B;VX`1V%L97)I92!P<F\@=OUB
M['(@;V)RX7IK^0!'86QE<FEE.@!'86UB:64`5GET=F_X:70@)7,@:V]N9FEG
M=7)A8VD`5GEG96YE<F]V86[](&OS9`!'<G5Z[6YS:V\`3NQM96-K;P!':&%N
M80!':6)R86QT87(`2_AE<W1N[2!J;>EN;P!*9&D@;F$`1V]E9&5L`%9Y:&QE
M9.%VX6[M('!O;6]C[2!';V]G;'4`4W1U<&[L(+EE9&D`V&5C:V\`V&5C:^D@
M*$E33RTX.#4Y+3<I`$=R\VYS:V\`1W)E;F%D80!!9&UI;FES=')A8V4@<')O
M('-K=7!I;GD`375S[2!B_70@>F%DX6YO(&IMZ6YO('-K=7!I;GD`4VMU<&EN
M>0!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`%!RX79A(&AO
M<W3Y`$MN:6AA(&AO<W3Y`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(
M5$U,`$A434Q!<F5A('IB86+L;&4@;V1M[73A('-M87IA="!P;W-L961N[2!B
M=?)K=2!N82#XX61K=2X`2%1-3$%R96$@>F)A8NQL92!O9&WM=.$@<VUA>F%T
M('!O<VQE9&[M(&)U\FMU('9E('-L;W5P8VD@=&%B=6QK>2X`2%1-3$%R96$@
M>F)A8NQL92!O9&WM=.$@<VUA>F%T('!O<VQE9&[M(/CA9&5K('8@=&%B=6QC
M92X`3W;L^&]VX6[M('!O;6]C[2!(5%10(&YE8GEL;R!N86QE>F5N;RX`2&%I
M=&D`2&%S:"UA;&=O<FET;75S`$UL:&%V;P!(;&%V:>AK80!(96%R9"!)<VQA
M;F0@82!-8T1O;F%L9"!)<VQA;F1S`$AE8G)E:KET:6YA("A)4T\M.#@U.2TX
M+4DI`%;]N6MA`$[A<&]V[&1A`$[A<&]V[&1A('!R;R!E9&ET;W(`4&]M;V-N
M[6L`2&5M:7-FZ7)A`%ID92!J92!Z8>CA=&5K('-O=6)O<G4Z`%9Y<V]KX0!?
M2&]R9&4`4W9A=.D@3>QS=&\@*%9A=&EKX6XI`$AO<F1E`$%D<F5S82!D;VWY
M`%1E;&5F;VX@9&]M^0!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R9&4O
M2V]L86(Z($YE<&QA=&[I("5S(%A-3"!D871A('9E('IP<N%V["`E<P!(;W)D
M92]+;VQA8CH@KN%D;N$@>G!RX79A('-E(&YE<VAO9'5J92!S(&]B:F5K=&5M
M("5S`$AO<F1E+TMO;&%B.B!.96)Y;"!N86QE>F5N(+[A9&[](&]B:F5K="!T
M>7!U("5S('9E('IP<N%V["`E<P!(;W)D92]+;VQA8CH@VG-P[+ENZ2!O9'-T
M<F%N[&[M("5S("(E<R(`2&]R9&4O2V]L86(Z($EN=&5G<F'H;NT@;N%S=')O
M:B!P;W3X96)U:F4@4$A0('#X[7!O;G4@)V1O;7AM;"<`2&]R9&4O2V]L86(Z
M($YE;'IE('9Y='9O^&ET(&YO=OT@<W1R;VT@6$U,('!R;R!O8FIE:W0@)7,`
M2&]R9&4O2V]L86(Z($YE;'IE(&]D<W1R86YI="`E<R`B)7,B.B`E<P!(;W)D
M92]+;VQA8CH@3F5L>F4@>NUS:V%T($U)344@240@<')O(.CA<W0@='EP=2`E
M<P!(;W)D92]+;VQA8CH@3F5L>F4@<WEN8VAR;VYI>F]V870@)7,@(B5S(CH@
M)7,`2&]R9&4O2V]L86(Z($YE;'IE('-Y;F-H<F]N:7IO=F%T('-D[6QE;ND@
M;V)J96MT>3H@)7,`2&]R9&4O2V]L86(Z($YE>F[A;?T@<V3M;&5N_2!O8FIE
M:W0@(B5S(@!6;V1O<F]V;ND@<')A=NUT:V\`2&]R:7IO;G3A;&[M(&]D<W1U
M<`!(;W)I>F]N=.%L;NTZ`$IA:R!J<W1E('-E('-E;2!D;W-T86QI/R`H6F&Y
M;&5T92!P<F]S[6T@>G!RX79U(2D`2V]L:6L@<VQO=7!C^2!C:&-E=&4@<W!O
M:FET/P!+;VQI:R!J92!T86T@<&]L[2`H<VQO=7!C^2D_`$MO;&EK(/CA9&OY
M(&-H8V5T92!S<&]J:70_`%9L:&MO<W0`5FQH:V]S=#H`2'5M;W)NZ0!-8>]A
M<G-K;P!396QH86QO('9Y='9O^&5N[2!)34%0;W;I('-C:'+A;FMY.B`E<P!3
M96QH86QO('-M87KA;NT@24U!4&]VZ2!S8VARX6YK>3H@)7,`4V5L:&%L;R!N
M87-T879E;NT@:W;S='D@<')O($E-05!O=F]U('-C:'+A;FMU.B`E<P!)4"!A
M9')E<V$`25`@861R97-A(&YE;NT@9&]S='5P;N$N`$E0(&%D<F5S82!N96[M
M('8@<&]V;VQE;NEM($-)1%(@<F]Z<V%H=2X`4&]R=;EE;NT@:6YT96=R:71Y
M($E0+@!67VQOOG1E(/CA9&5K('#X960`27-L86YD`%!O=7IE(&EK;VYY`$EK
M;VYY('!R;R`E<P!):V]N>2!S('1E>'1E;0!.X7IE=B!I9&5N=&ET>3H`4&]K
M=60@>F]B<F%Z96[M(&YE;NT@=B!P;_CA9&MU+"`E<R!O=&5V^.UT('8@;F]V
MZ6T@;VMN["X`4&]K=60@<&]UONUVX71E($EN=&5R;F5T($5X<&QO<F5R(&$@
M;F5V:63M=&4@ON%D;ND@:6MO;GDL('KX96IM["!P;W3X96)U:F5T92!O>FYA
MZ&ET('1E;G1O('+A;67H96L@<')O('9Y<&YU=.T@4$Y'('1R86YS<&%R96YC
M92X`4&]K=60@=FED[71E('1U=&\@>G!RX79U(&WM<W1O(&]B<N%Z:W4L(&]B
M<N%Z96L@:W1E<OT@8VAC971E('#X96[I<W0@;F5L>F4@5F&Y[6T@<')O:&SM
MOF7H96T@>F]B<F%Z:70N`$[A:&QE9"!O8G+A>FMU.@!54DP@;V)RX7IK=0!5
M4DP@;V)RX7IK=3H`3V)RX7IE:R!Z(&=A;&5R:64`3V)RX7IE:R!Z(&=A;&5R
M:64Z`%#X96YO<R!O8G+A>FMU`$]B<N%Z:WD`26UP;W)T+"!K<F]K("5D`$EM
M<&]R=&]V86[I('!O;&4Z("5S`$EM<&]R=&]V86[A('!O;&4Z`%9L;[YI="#X
MX61K=2!Z80!">6P@>F%DX6X@;F5S<'+A=F[](&%KZ&[M(&OS9"X`3F5S<'+A
M=F[L('IA9&%NZ2!UOFEV871E;'-KZ2!J;>EN;R!A+VYE8F\@:&5S;&\N`$YE
M<W!RX79NZ2!UOFEV871E;'-KZ2!J;>EN;R!N96)O(&%L=&5R;F%T:79N[2!A
M9')E<V$N(%IK=7-T92!J9;ET["!J961N;W4@;F5B;R!K;VYT86MT=6IT92!6
M8;EE:&\@<WES=.EM;W;I:&\@861M:6YI<W1RX71O<F$N`%IV['2Y:70@;V1S
M87IE;NT`26YD:64`2F5D;F]T;&EV[2!UOFEV871E;.D`26YD;V[I<VEE`$EN
M9F]R;6%C90!);F9O<FUA8V4`5FQOOFET('-?;&]U<&5C('IA`%9L;[YI="!O
M8G+A>F5K`%9L;[YI="!T86)U;&MU`%9L;[YI="!W96)O=OT@;V1K87H`5FQO
MOFET(%]S;&]U<&5C('#X960@`%9L;[YI="!N;W;]('-L;W5P96,@>F$@<V]U
MZ&%S;OT`5FQOOFET(&YO=OT@<VQO=7!E8R!P^&5D('-O=>AA<V[]`%9L;[YI
M="!N;W;](/CA9&5K('IA('-O=>AA<V[]`%9L;[YI="!N;W;](/CA9&5K('#X
M960@<V]UZ&%S;OT`5FQOOFET(&]D<W1A=F5C('IA('-O=>AA<V[]('5Z96P`
M5FQOOFET(&]D<W1A=F5C('#X960@<V]UZ&%S;OT@=7IE;`!6;&^^:70@86QT
M97)N871I=F[M('9Z;W(`5FQOOG1E(&5M86EL;W9O=2!A9')E<W4L(&YA(&MT
M97)O=2!O8F1RONUT92!N;W;I(&AE<VQO.@!6;&^^:70@8G7R:W4@>F$`5FQO
MOFET(&)U\FMU('#X960`5FQOOFET('-L;W5P96,@>F$`5FQOOFET('-L;W5P
M96,@</AE9`!6;&^^:70@>G!RX79Y`%9L;[YI="!O9'-T879E8R!Z80!6;&^^
M:70@;V1S=&%V96,@</AE9`!6;&^^:70@^.%D96L@>F$`5FQOOFET(/CA9&5K
M('#X960`5FQOOG1E('!OOF%D;W9A;F]U(&]D<&]V[.\@;F$@8F5Z<&7H;F]S
M=&[M(&]TX7IK=3H`5FQOOFET+W5P<F%V:70@;V)RX7IE:P!6;&^^:70O=7!R
M879I="!O9&MA>@!.961O<W1A=&7H;OT@:W)E9&ET(&L@;V1E<VSA;NT@>G!R
MX79Y(&YA(&1I<W1R:6)UZ&[M('-E>FYA;2X`3F5D;W-T871EZ&[](&MR961I
M="X`0V5LZ2#H[7-L;P!397IN86T@8V5L_6-H(.CM<V5L`$YE<W!RX79NZ2!5
M1$@N("A5<V5R($1A=&$@2&5A9&5R*2X`3F5P;&%T;N$@87!L:6MA8V4N`$YE
M<&QA=&[I(&ED96YT:69I:V'H;NT@Z.US;&\@*$E$*2!DX79K>2X`0GEL82!Z
M863A;F$@;F5P;&%T;N$@9&%T80!.97!L871NX2!A9')E<V$@</CM:F5M8V4N
M`$YE<&QA=&[](&9O<FWA="!S;W5B;W)U`$YE<&QA=&[](&US9U]T>7!E+@!.
M97!L871NZ2!N96)O(&-H>6+L:NUC[2!A<&E?:60N`$YE<&QA=&[I(&YE8F\@
M8VAY8NQJ[6/M('!A<F%M971R>2X`3F5P;&%T;N$@=FQA<W1N:6-KX2!P<N%V
M82X`3F5P;&%T;OT@<')O=&]K;VPN`$YE<&QA=&[]('-D[6QE;OT@;V)J96MT
M`$YE<&QA=&[A(&%D<F5S82!O9&5S[6QA=&5L92X`3F5P;&%T;N$@9&%T82!U
M;FEC;V1E+@!);G9E;G3A^`#-<N%N+"!)<VSA;7-KX2!R97!U8FQI:V$`27+A
M:P!)<G-K;P!/<W1R;W8@;76^90!/:F5D:6[L;.D@8F]U^&MY`$ES<F%E;`!0
M;W-K>71O=F%T96P`2W5R>NUV80!)=.%L:64`2F%M86IK80!,961E;@!*87!O
M;G-K;P!*87!O;KET:6YA("A)4T\M,C`R,BU*4"D`5')I:V]T`$IO<F3A;G-K
M;P#(97)V96YE8P#(97)V96X`6F%R;W9N870`6F%R;W9N870@;F$@<W3X960`
M6F%R;W9N870@=GEP;&[L;NUM`%IA<F]V;F%T(&1O;&5V80!:87)O=FYA="!D
M;W!R879A`$MA>F%C:'-TX6X`56-H;W9A="!O<FEG:6[A;#\`2V7R80!+97)B
M97)O<R!S97)V97(@>F%M[71N=6P@;W;L^&5N[2X`3F]VX>AC:2!K97)N96QU
M`%9Y='9O^&5N[2!K;.WH90!6>71V;_AE;NT@;W1I<VMU(&ML[>AE`$3I;&MA
M(&ML[>AE`%1Y<"!K;.WH90!5OFET[2!K;.WH90!+;.WH(&IIOB!E>&ES='5J
M92!N82!V9?AE:F[I;2!K;.WH;W;I;2!S97)V97)U+@!$['1I`$MI<FEB871I
M`$M,1%(`2V]R96$`2V]R96IS:WD@*$550RU+4BD`2W5V86IT`$MY<F=I>G-T
MX6X`7U)O>FQOOF5N[0!*87IY:P!,86]S+"!,:61O=NP@1&5M;VMR871I8VMA
M(%)E<'5B;&EK80!$<G5HX2!P;VQO=FEN80!0;W-L961N[2#H='9R=&EN80!0
M;W-L961N[2!A:W1U86QI>F%C93H`4&]S;&5D;NT@</AI:&SAN65N[3H@)7,`
M4&]S;&5D;NT@</AI:&SAN65N[3H@)7,@>B`E<P!0;W-L961N[2!P^&EH;.&Y
M96[M.B!.:6MD>0!,:71V80!0<N%V;P!2;WIL;[YE;NT`3F5C:&%T('!RX7ID
M;ND@8F5Z(&]K<F%J90!,:6)A;F]N`$1O;&5V80!,97;A(&AL879IZ&MA`$AO
M9&YO='D@;F%L979O`$QE<V]T:&\`3&EBZ7)I90!,:6)I90!,:6-H=&5NN71E
M:FYS:V\`3&5H:^D@;7)H;VQE;NT`3&5H:_T@9.FYNP!"<GIK_2!L96AK_2!D
MZ;F[`%!O>F3L:FD@;&5H:_T@9.FYNP!,96AKZ2!D9;F[;W;I('-RX;YK>0!,
M96AK_2!DZ;F[(',@:/AM[&[M;0!,96AKZ2!S;NR^96[M`$QE:&OI('-N[&AO
M=ND@</AE:.'R:WD`3&EM97)I8VL`3V1K87H`3V1K87IY('5K87IU:NT@;F$Z
M`%!O=;[M="!O9&MA>GD@;F$@96UA:6QO=ND@861R97-Y('#X:2!Z;V)R87IO
M=N%N[2!S='+A;FMY('!R;R!P<V%N[2!Z<'+A=@!/9&MA>GD`3&EN=7AO=ND@
M8V]O:VEE`%-E>FYA;2`M('6^:79A=&5L(&WYOF4@=FED['0@<VQOOFMU`%-E
M>FYA;2!D871A8N%Z[0!397IN86T@=.EM870@;N%P;W;L9'D`4V5Z;F%M('1A
M8G5L96L`4V5Z;F%M+4%R8VAI=@!397IN86TM3N%P;W;L9&$`4V5Z;F%M+4ED
M`%-E>FYA;2U6;&%S=&[M:P!397IN86TM3V1E<VSA;NT`4V5Z;F%M+5#X:6AL
MX;EE;NT`4V5Z;F%M+4]D:&SAN65N[0!6_7!I<R!UOFEV871E;/D@;F5N[2!D
M;W-T=7!N_2X`3&ET97)A='5R80!,;W1YN7-K;P!.86ARX7;A;NTN+BX`3>US
M=&[M(.AA<SH@`$QO8V%L92!A(.AA<P!-[7-T;P!0^&EH;.%S:70@<V4`3V1H
M;.&Y96[M`-IK;VQY('!R;W;A9.QNZ2!P^&D@</AI:&SAN65N[0!396QH86QO
M('#X:6ALX;EE;NT@9&\@<WES=.EM=2X@4')A=F3L<&]D;V)N["!68;EE('6^
M:79A=&5L<VOI(&IMZ6YO(&$O;F5B;R!H97-L;R!N96)Y;&\@<W!RX79N["!Z
M863A;F\N`%#X:6ALX;EE;NT@<V5L:&%L;RX`1&QO=6C]('1E>'0`3.%S:V$`
M3NUZ:^$`36%LX2#X96-KX2!P[7-M96YA`$UA;.$@=&ES:V%C[2!P[7-M96YA
M`$UA;.D@^.UM<VOI(.CM<VQI8V4`3'5C96UB=7)S:V\`34T`6G!RX79A(&1N
M90!0^&EP;VIE;OT@<V]U8F]R($U3+4Y4148@;F5O8G-A:'5J92"^X61NX2!D
M871A+@!-4T<`36%K86\`36%K961O;FEE+"!B_79A;.$@4F5P=6)L:6MA($IU
M9V]S;.%V:64`36%D86=A<VMA<@!-86=I90!0;[ET80!!9&UI;FES='+A=&]R
M('!ON71Y`%9Y='9O^&ET(&]D7VMA>BXN+@!-86QA=VD`36%L86IS:64`36%L
M9&EV>0!-86QI`$UA;'1A`%!R;R!U;6^^;NQN[2!O=FSA9.%N[2!K871E9V]R
M:>T@:F4@>F%P;W3X96+M(&]Z;F'H:70@<&]L;[YK>2!B87)V86UI+"!K=&5R
MZ2!J<V]U('#X:?AA>F5N>2!K('3L;71O(&MA=&5G;W)I[6TN`$UA<&$@36%P
M,C0`36%P82!-87!1=65S=`!"^&5Z96X`3VMR86H`3WIN8>AI="!Z;F'H:V]U
M(%!R;VALZ61N=71O+TYE<')O:&SI9&YU=&\`3WIN8>AI="!J:6[];6D@>FYA
MZ&MA;6D@*&IA:V\@1/EL9;YI=.DO3V1P;W;L>F5NZ2D`36%RN6%L<VOI($]S
M=')O=GD`36%R=&EN:7%U90!3:&]D=6KM8^T@<V4@<&]L90!-875R973A;FEE
M`$UA=7)I8VEU<P!-87AI;6%L;NT@<&]V;VQE;OT@:W)E9&ET`$)Y;&$@</AE
M:W)OZ&5N82!M87AI;6%L;NT@9.EL:V$@>G!RX79Y+@!.96IV>;FY[2!T97!L
M;W1A('IA('!O<VQE9&[M8V@@,C0@:&]D:6XZ(`!.96IV>;FY[2!T97!L;W1A
M('IA('!O<VQE9&[M8V@@-B!H;V1I;CH@`$UA>&EMX6QN[2!DZ6QK80!+=NQT
M96X`36%Y;W1T90!-961I8^UN80#(;&5N;W;I`$WS9'D@<')O(&UE;G4Z`%-P
M;VII="!B=?)K>0!:<'+A=F$`6G!RX79A(&)Y;&$@;W;L^&5N82!V('!O^.%D
M:W4L(&%L92!N96QZ92!O=NSX:70@<&]D<&ES;W;](&-E<G1I9FEKX70N`%IP
M<N%V82!P<F]P861L82X`5'EP('IP<N%V>0!0;^AA<^T`0FQO:R!O('!OZ&%S
M[2!N96[M(&1O<W1U<&[]+@!";&]K(&\@<&_H87/M(&YE;NT@9&]S='5P;OTN
M(%!O9')O8FYO<W1I(&)Y;'D@>F%Z;F%M96[A;GD@<')O('-Y<W3I;6]VZ6AO
M(&%D;6EN:7-T<N%T;W)A(&1O(&QO9W4N`$UE=&]D80!-971R:6-K_0!-97AI
M:V\`36EK<F]NZ7-I92P@1F5D97)A8V4`57!R;W-T^&5D`%1Y<"!-:6UE`$YE
M:FYIOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`R-"!H;V1I;CH@`$YE:FYI
MOKGM('1E<&QO=&$@>F$@<&]S;&5D;NUC:"`V(&AO9&EN.B``6G)C861L;W;L
M`%+Y>F[I`%!R;V=R86UO=OT@8F%L[6L@2%144%]297%U97-T(&-H>6+M('8@
M4$5!4BX`0VAY8NQJ[6/M(&MO;F9I9W5R86-E+B!0;VMU9"!S:2!P^&5J971E
M('!O=;[M=F%T('1U=&\@87!L:6MA8VDL(&UU<^UT92!V>6=E;F5R;W9A="!K
M;VYF:6=U<F'H;NT@<V]U8F]R+@!#:'EB[&KM8^T@240@>G!RX79Y("AI9&5N
M=&EF:6MAZ&[M(.CM<VQO*0!0;[YA9&]V86[]('!R;V=R86UO=OT@8F%L[6L@
M36%I;"!C:'EB[2!V(%!%05(N`$-H>6+L:NUC[2!)1"!P<F\@<F5L86-I+@!0
M;P!-;V)I;&[M('!ON71A`$WM<F[]`$1A='5M('!O<VQE9&[M('IM[&YY`%IM
M[/)I="!54DP`36]D=6P`36]L9.%V:64`36]N86MO`$UO;F=O;'-K;P!-['/M
M8R!A(')O:P!-['/MZ&[L`$UO;G-E<F%T`$;A>F4@3>QS[6-E`$UA<F]K;P!0
M^&5VX;YN["!J87-N;P!0^&5VX;YN["!O8FQAZ&YO`%#X97;AOF[L('-L=6YE
MZ&YO`%!O<W5N;W5T(&1O;/D`4&]S=6YO=70@9&]L979A`%!O<W5N;W5T(&1O
M<')A=F$`4&]S=6YO=70@;F%H;W)U`%!O<W5N;W5T(&1O;/D`4&]S=6YO=70@
M;F%H;W)U`$UO<V%M8FEK`%;M8V4M^G)O=O)O=ND@<F]L971O=ND@<V5Z;F%M
M>0!6[6-E;N%S;V)NX2!S96QE:V-E`$WY:B#ZZ&5T`$WY:B!P;W)TX6P`36]J
M92!R;WIL;[YE;NT@<&]R=.%L=0!->6%N;6%R`$Y%+"!.15-/54A,05/-30!*
M;>EN;P!.86UI8FEE`$YA=7)U`$YE<.%L`$YI>F]Z96WM`$YI>F]Z96US:^D@
M06YT:6QY`$YE='-C87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I
M;VX@55),`$YE='-C87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A
M;"!54DP`3F5T<V-A<&4@4F5V;V-A=&EO;B!54DP`2FWI;F\@3F5T<V-A<&4@
M4U-,('-E<G9E<G4`4&]Z;N%M:V$@:R!C97)T:69I:^%T=2!.971S8V%P=0!4
M>7`@8V5R=&EF:6OA='4@3F5T<V-A<'4`4^V[`$YI:V1Y`$YO=N$@2V%L961O
M;FEE`$YO=N$@:V%T96=O<FEE`$WL<^UC('8@<')V;NT@Z'1V<G1I;NP`3F]V
MZ2!UOFEV871E;'-KZ2!J;>EN;R`H;F5P;W9I;F[I*0!.;W;](%KI;&%N9`!.
M;W;I(&]K;F\@*%]P<N%Z9&[I*0!.;W9I;FMY`$YE=W-G<F]U<',`1&%LN>T`
M1&%LN>T@;6^^;F]S=&D`3FEK87)A9W5A`$YI9V5R`$YI9^ER:64`3F]C`$YI
M=64`3F4`KF%D;N$@:V]N9FEG=7)AZ&[M(&1A=&$@;F5J<V]U(&1O<W1U<&[A
M('!R;R!Z;V)R87IE;NT@<F]Z9.UL^2X`3F5N[2!D;W-T=7!NX2"^X61NX2!S
M=')A=&5G:64@<')O('1V;W)B=2!)4T\@;V)R87KY+@!"97H@9.%V:V]VZ6AO
M('9Z;W)U+@!.82!P;[YA9&]V86[I('!O>FEC:2!N965X:7-T=6IE(+[A9&[]
M(&)L;VL`3F5B>6QO('!O<VMY=&YU=&\@ON%D;ND@:FWI;F\@<')O(&MA;&5N
M9.'X('#X:2!O=NSX;W;A;NT@<&]M;V/M($U#04PN`$)E>B!Z;>QN>2X`3F5L
M>F4@</AI9&%T(+[A9&[A('!O9"UP<N%V82!K('3L;71O('!RX7;Y;2X`3F5B
M>6QY('5V961E;GD@ON%D;ND@:V]N9FEG=7)AZ&[M(&EN9F]R;6%C92!P<F\@
M)7,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA
M8V4@<')O($944"!61E,N`$YE8GEL>2!U=F5D96YY(+[A9&[I(&MO;F9I9W5R
M8>AN[2!I;F9O<FUA8V4@<')O(%-13"!61E,N`$YE8GEL>2!U=F5D96YY(+[A
M9&[I(&MO;F9I9W5R8>AN[2!I;F9O<FUA8V4@<')O(%-13"U&:6QE(%9&4RX`
M3F5MX71E(+[A9&[](&MR961I="X`3F5B>6P@<&]S:WET;G5T(+[A9&[](&/M
M;"X`KN%D;OT@<V]U8F]R(&YE8GEL('#X96YE<V5N`$YE8GEL>2!N86QE>F5N
M>2"^X61NZ2!I:V]N>2X`3F5B>6QO('9Y8G+A;F\@ON%D;ND@;>US=&\N`$YE
M8GEL>2!P;W-K>71N=71Y(+[A9&[I('IP<N%V>2X`3F5B>6QO('5V961E;F\@
MON%D;ND@:FWI;F\N`$YE8GEL;R!U=F5D96YO(+[A9&[I(.CM<VQO+@!"97H@
M;F5S;'6Y;OUC:`!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N
M[2!P;VUO8^T@2%144"X`3F5B>6QO('!O<VMY=&YU=&\@:&5S;&\@<')O(&]V
M[/AE;NT@<&]M;V/M($E-05`N`$YE8GEL;R!P;W-K>71N=71O(&AE<VQO('!R
M;R!O=NSX96[M('!O;6]C[2!+97)B97)O<RX`3F5B>6QO('!O<VMY=&YU=&\@
M:&5S;&\@<')O(&]V[/AE;NT@</AI:&SAN65N[2!S92!D;R!S>7-TZ6UU+@!.
M96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO8^T@4$%3
M4U=$+@!.96)Y;&\@<&]S:WET;G5T;R!H97-L;R!P<F\@;W;L^&5N[2!P;VUO
M8^T@4TU"+@!.96)Y;&$@<&]S:WET;G5T82!C97-T82!K(&)I;N%R;NUM=2!S
M;W5B;W)U($]P96Y34TPN($)I;N%R;NT@<V]U8F]R($]P96Y34TP@:F4@>F%P
M;W3X96+M('!R;R!P<N%C:2!S(%!+0U,@,3(@9&%T>2X`KN%D;ND@;F5V>?CM
M>F5NZ2"^X61O<W1I(&\@</AI:&SAN65N[2X`0F5Z('!R879I9&5L`$)E>B!O
M:W)A:OD`KN%D;OT@>B!D;^AA<V[]8V@@861R97/A^/D@;F5N[2!D;W-T=7!N
M_2!P<F\@8V%C:&4N`$YE8GEL;R!O9&5S;.%N;R"^X61NZ2!UOFEV871E;'-K
MZ2!J;>EN;R!A+VYE8F\@:&5S;&\N`$YE8GEL82!N879RX6-E;F$@ON%D;N$@
M<&QA=&[A(%A-3"!D871A+@"NX61NZ2!H;V1N;W1Y`%8@;W)I9VENX6QN[2!K
M;VYF:6=U<F%C:2!N96)Y;&$@;F%L97IE;F$@=F5R>F4N($]B;F]V=&4@:V]N
M9FEG=7)A8VDN`%9E(%9AN>T@:V]N9FEG=7)A8VD@;F5B>6QA(&YA;&5Z96YA
M('9E<GIE+B!/8FYO=G1E(&MO;F9I9W5R86-I+@"NX61N_0"NX61N_2`H<&]U
MOFEJ=&4@:6UP;&EC:71N[2D`4V5V97)S:_T@*$E33RTX.#4Y+3$P*0!.;W)F
M;VQK<VOI(&]S=')O=GD`4V5V97)N[2!P;VQO:V]U;&4`4V5V97)N[2!-87)I
MX6YS:^D@;W-T<F]V>0!.;W)S:V\`3F5N[2!P;P!.96[M('#X960`3F5N[2!A
M9')E<^'X96T`3F5N[2!I;7!L96UE;G1O=N%N;RX`3F5N[2!N87-T879E;F\`
M3F5N[2!P;V1P;W)O=N%N;RX`4&]Z;N%M:V$`3FEC(&L@<')O:&SI9&YU=.TL
M(&+LOG1E('IP['0N`$QI<W1O<&%D`,CM<VQO`%!OZ&5T('IN86OY`%!OZ&5T
M('-L;W5P8_D`4&_H970@^.%D:_D`3F5B>6QA('IA9.%N82#H[7-L82!P<F\@
M86MT=6%L:7IA8VD@9&ES=')I8G7H;NUH;R!S97IN86UU+@!/2P!/8FIE:W0`
M5';Y<F-E(&]B:F5K=/D`3W-M:>AK;W;]`-CM:F5N`$9I;'1R;W9A="!N97-L
M=;ENZ0!+86YC96SA^`!/;>%N`%-D[6QE;ND@<VQOOFMY(&IS;W4@<&]S:WET
M;W;A;GD@<&]U>F4@24U!4"!S97)V97)Y+@!0;W5Z92!N97-L=;ENZ0!*92!P
M;W9O;&5N82!P;W5Z92!J961N82!E+6UA:6QO=N$@861R97-A+@!0;W5Z92!V
M;&%S=&[M:R!N96)O('-Y<W3I;6]V_2!A9&UI;FES='+A=&]R(&WYOF4@;>QN
M:70@<'+A=F$@<')O('-D[6QE;OT@;V)J96MT+@!/=&5V^.UT('8@;F]VZ6T@
M;VMN["X`0VAY8F$@3W!E;E-33#H@3F5L>F4@>NUS:V%T(&1A=&$@>B!P;V1E
M<'-A;ND@Z.%S=&D@4R]-24U%+@!/=&5V^.UT('1E;G1O(&]D:V%Z('8@;F]V
MZ6T@;VMN[`!/<&5R8>AN[2!S>7-TZ6T`36^^;F]S=&D`36^^;F]S=&D@<')O
M("5S`%-E^&%Z96[]('-E>FYA;0!/<F=A;FEZ86-E`$]R9V%N:7IAZ&[M(&IE
M9&YO=&MA`$]R9V%N:7IO=N%N[0!/<FEG:6[A;&[M('9Z;W(@<')O(+[A9&]S
M=`!/<FEG:6[A;&[M('9Z;W(@=B`E<SH`3W-T871N[0!/<W1A=&[M(&EN9F]R
M;6%C90!5OFEV871E;'-KX2!P<N%V80!/=NSX96[M('!O;6]C[2!004T@;F5N
M[2!D;W-T=7!NZ2X`4$=0(&1I9VETX6QN[2!P;V1P:7,`4$=0(+EI9G)O=F%N
MX2!D871A`%9E^&5J;OT@4$=0(&ML[>@`1&%T82!P;V1E<'-A;N$ON6EF<F]V
M86[A('!O;6]C[2!01U``4$A0(&OS9`!02%`@:V]N>F]L80!/9'!O;&5D;NT@
M;&5H:_T@9.FYNP!/9'!O;&5D;NT@</AE:.'R:WD`3V1P;VQE9&[M('-N[+YE
M;NT`3V1P;VQE9&[M('-N[&AO=ND@</AE:.'R:WD`3V1P;VQE9&[M(&)O=?AK
M>0!07TA0(&MO;GIO;&$`3V1S='5P>0!0X6MI<W3A;@!086QA=0!086QE<W1I
M;G-KZ2!T97)I=&]R:75M+"!O:W5P;W9A;ND`4&%N86UA`%!A<'5A($YO=N$@
M1W5I;F5A`%!A<F%G=6%Y`$WM<W1Y('IA=&&^96YO`$AE<VQO`$YE<W!RX79N
MZ2!H97-L;P!0<F\@;W;L^&5N[2!P;VUO8^T@4D%$54E3(&IE(&YU=&YO('IA
M9&%T(&AE<VQO+@!(97-L;R!S('!O='9R>F5N[6T`2&5S;&\Z`$AE<VQO.B``
M2&5S;&$@<V4@;75S[2!S:&]D;W9A="X`5FQOOFET`%9L;[YI="!Z92!S8VAR
MX6YK>0!#97-T80"NX61O<W1I(&\@</AI:&SAN65N[3H`3&EDZ0!0<F]C96YT
M`%!R;W;I<W0@;W!E<F%C92#Z9'*^8GD`4')O=NES="!O<&5R86-E(/ID<KYB
M>2!P^&D@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!0<N%V80!!9&UI;FES=')A
MZ&[M('!RX79A`$]S;V)N[2!I;F9O<FUA8V4`4&5R=0!$;VWA8^T@>G;M^&%T
M80!&:6QI<.UN>0!496QE9F]N`$9O=&]G<F%F:64`4&ET8V%I<FX`4&EX96SY
M`$9RX7IE`%!R;W/M;2!K;&EK;NQT92!N82!N[&IA:V]U(&)U\FMU`%!R;W/M
M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@=&5N=&\@<')V
M96LZ`%!R;W/M;2!P;W1V<N]T92P@OF4@<VD@</AE:F5T92!O9'-T<F%N:70@
M=&5N=&\@<')V96LN`%!R;W/M;2!Z861E:G1E(&WL<^UC(&$@<F]K+@!0<F]S
M[6T@>F%D96IT92!NX7IE=B!N;W;I(&MA=&5G;W)I93H`4')O<^UM('IA9&5J
M=&4@<W!RX79N;W4@25`@861R97-U+BX`4')O<^UM('IA9&5J=&4@<W!RX79N
M_2!D871U;2!A('IK;VYT<F]L=6IT92!P;^AE="!D;NT@=B!M['/M8VDN`%!R
M;W/M;2!Z861E:G1E('-P<N%V;OT@Z&%S+@!0<F]S[6T@=79E[W1E('-H<FYU
M=.T@5F&Y96AO('!R;V)LZ6UU+@!0<F]S[6T@>F%D96IT92!68;EE('6^:79A
M=&5L<VOI(&IMZ6YO(&$@:&5S;&\`4')O<^UM('IA9&5J=&4@;F]V_2!NX7IE
M=B!K871E9V]R:64Z`%!O;'-K;P!0;VQI=&EK80!(;&%S;W;A;NT`4&]R='5G
M86QS:V\`56WM<W3L;NT@=&]H;W1O(&]B<N%Z:W4`56WM<W3L;NT@=&%B=6QK
M>0!:87-L870@9&\@=.ET;R!S;&^^:WD@*&YE;NT@<&]S:WET;G5T;R!)34%0
M96TI`%-RX;YK>2!Z82!P;W-L961N[2AC:"D@)7,@:&]D:6XH=2DZ(`!0<F5F
M<U]L9&%P.B!.96)Y;&$@;F%L97IE;F$@<&^^861O=F%NX2!P^.UP;VYA($Q$
M05`N`%!R969S7W-E<W-I;VXZ($YE8GEL82!N86QE>F5N82!P;[YA9&]V86[A
M('#X[7!O;F$@<V5K8V4N`$)A<F]M971R:6-K_2!T;&%K`$)A<F]M971R:6-K
M_2!T;&%K(&YA(/IR;W9N:2!M;_AE.B``0F%R;VUE=')I8VO]('1L86LZ`$[A
M:&QE9`!.X6AL960@;V)RX7IK=2!V(&YO=NEM(&]K;NP`4/AE9&-H;WKM(&UO
MOFYO<W1I`%1I<VMN;W5T(&1O:W5M96YT`%!R:7;A=&[M(&ML[>@`4')O8FSI
M;0!0;W!I<R!P<F]B;.EM=0!0<F]J96MT>0!0<F]M<'0@=&5X=`!69?AE:F[]
M(&ML[>@`06QG;W)I=&UU<R!P<F\@=F7X96IN_2!K;.WH`%9E^&5J;OTO<')I
M=N%T;NT@:VSMZ&]V_2!PX7(@;F5B>6P@^G-P[+EN["!V>71V;_AE;BX`4&]R
M=&]R:6MO`$MA=&%R`%9Y:&QE9.%N[0!24T$@=F7X96IN_2!K;.WH("@E9"!B
M:73Y*0!3</AAOF5NZ2!T;&'H[71K;P!$Z;F[`$)R>FO](&3IN;L`4&]Z9&[M
M(&3IN;L`1&6YNV]VZ2!P^&5HX?)K>0!$Z;F[('-E('-N[&AE;0!$Z;F[(&&^
M('-N[6@`3N%H;V1N["!V>6)R86[I(+ET['-T[0!0;VWL<@#(=&5C[0!0^&7H
M=&5NZ2!Z<'+A=GD`3W!R879D=2!S;6%Z870@)7,_(%1A=&\@;W!E<F%C92!J
M92!N979R871NX2X`3W!R879D=2!S;6%Z870@=;YI=F%T96QS:^$@9&%T82!P
M<F\@=;YI=F%T96QE("5S/R!4871O(&]P97)A8V4@:F4@;F5V<F%T;N$N`$]P
M86MO=F%T('!O<VQE9&[M(&%K8VD`3V)N;W9I="!D>6YA;6EC:^D@<')V:WD@
M;65N=3H`3V)N;W9A('IO8G)A>F5N[2!P;W)TX6QU.B``4F5G97@`4')O:&SM
MOF7H('9Z=&%H^0!(;V1N;W1Y`%9Z9.%L96[I('-E<G9E<GDN`%9Z9.%L96[A
M(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H;W)D92DZ`$]D<W1R86YI
M=`!/9'-T<F%N:70@8FQO:P!/9'-T<F%N:70@<VQO=7!E8P!/9'-T<F%N:70@
M9F]R;>%T;W;A;NT`3V1S=')A;FET('#A<@!/9'-T<F%T:70@=6QOOF5N_2!S
M:W)I<'0@>B!D;^AA<V[I:&\@861R97/A^&4@;F$@<V5R=F5R=2X`3V1S=')A
M;FET`$]D<W1R86YI="!T=71O(.CA<W0@9&]K=6UE;G1U`$]D<W1R86YI="!U
MOFEV871E;&4`3V1S=')A;FET('6^:79A=&5L93H@)7,`3F5L>F4@;V1P;W;L
M9.QT(&YA('!OOF%D879E:RX@0VAY8F]VZ2!H;.&Y96[M.B``4&^^861O=F%N
MZ2!P;VQE`%;]8VAO>NT@;F%S=&%V96[M`%;]8VAO>NT@;F%S=&%V96[M(&AE
M<VQA`%;]8VAO>NT@;F%S=&%V96[M(%9AN65H;R!H97-L80!6_7-L961K>0!.
MX79R870@9&\@;6^^;F]S=.T`4F5U;FEO;@!0^&5P;F]U="!K;VYF:6=U<F%C
M:0!-;[YN;W-T:2!2:6-H(%1E>'0@961I=&]R=0!(X61A;FMY`$1O<')A=F$`
M2&QA=FGH:V$@;F%P<F%V;P!(;V1N;W1Y(&YA<')A=F\`5FQA<W1N;W-T:2#X
MX5]D:W4`VFQO:&$`4G5M=6YS:V\`3W1OZ&ET(&\@,3@PL`!/=&_H:70@9&]L
M979A`$]T;^AI="!D;W!R879A`%9L87-T;F]S=&D@^.%D:W4`5FQA<W1N;W-T
M:2#XX61K=0#8X61K>3H`4')A=FED;&$`4')A=FED;&$@<V4@=7!L871N[2!M
M97II(':Y96UI(/CA9&MY(&$@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M
M('!O=7IE(&UE>FD@<VQO=7!C:0!0<F%V:61L82!S92!U<&QA=&[M('!O=7IE
M(&UE>FD@^.%D:WD`4')O=NES=`!2=7-KX2!F961E<F%C90!2=V%N9&$`4R]-
M24U%(+EI9G)O=F%N_2!P;V1P:7,`4R]-24U%(+EI9G)O=F%NX2!Z<'+A=F$`
M3W;L^&5N[2!P;VUO8^T@4T%33"!N96[M(&1O<W1U<&[I+@!335,@>G!RX79Y
M`%-13"!K;VYZ;VQA`%-32`#:4U#,0T@`4U]13"!K;VYZ;VQA`%-O`%-V873A
M($AE;&5N80!3=F%T_2!+:71T<R!A($YE=FES`%-A:6YT($QU8VEA`%-A:6YT
M(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R
M96YA9&EN97,`4W1E:F[]('+A;2`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%9L87-T;NUK('-A=&5L:71U`%-A=61S
M:^$@07+A8FEE`%5L;[YI=`!5;&^^:70@)7,`56QOOF5N[2!M;[YN;W-T[0!5
M;&^^:70@=GET=F_X96[](&MO;F9I9W5R8>AN[2!02%`@<VMR:7!T(&1O(&1O
MZ&%S;NEH;R!A9')E<^'X92!N82!S97)V97)U+@!+;VYF:6=U<F%C92`E<R!U
M;&^^96YA+@!6[&1A`%9Y:&QE9&%T`%9Y:&QE9.%V86/M(&[A<W1R;VIE`%9Y
M8G)A="!S;W5B;W)Y`%9Y8G)A="!D871U;0!6>6)R870@<VMU<&EN=2P@:W1E
M<N$@8G5D92!P^&EDX6YA`%9Y8G)A="!N;W;I:&\@=FQA<W1N[6MA`%9Y8G)A
M="!S97)V97(`5GEB<F%T('6^:79A=&5L92P@:W1E<OT@8G5D92!P^&EDX6X`
M5GEB<F%T(':Y96-H;GD@Z.%S=&D@9&%T=6UU+@!6>6)R870@;V)J96MT`%9Y
M8F5R=&4@<&]T^&5B;ND@>FYA:WD@>B!N[;YE('5V961E;OUC:"!B;WCY+B!0
M;W3I(&IE(&WYOF5T92!K;W#M<F]V870@82!V;&^^:70@>B!T97AT;W;I(&]B
M;&%S=&DN`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R;R!D871U;3H`5GEB
M97)T92!F;W)MX70@9&%T=6UU.@!6>6)E<G1E(&ED96YT:71U+"!K=&5R;W4@
M<VD@</AE:F5T92!Z;>QN:70Z`%9Y8F5R=&4@;V1D[&QO=F%C[2!Z;F%K('!R
M;R#H87,Z`%9Y8F5R=&4@9F]R;>%T(.AA<W4Z`%9Y8F5R=&4@9';L(&]D<&]V
M[61A:NUC[2!P;VQE+@!6>6)E<G1E(&)A<F5V;OT@;6]T:78N`%9Y8F5R=&4@
M5N%M:2!P<F5F97)O=F%N_2!J87IY:SH`4&]S;&%T('IP<N%V=2!O('!R;V)L
MZ6UU`%!O<VQA="!335,`4V5N96=A;`!396YS;W(Z`%KA^.T`4W)B<VMO(&$@
MR&5R;N$@2&]R80!3Z7)I;W;I(.CM<VQO`$E$('-E:V-E('IA;FEK;&\N`$YA
M<W1A=FET`$YA<W1A=FET(&UOOFYO<W1I('!R;R!P;W9O;&5N[2!R97-E='4@
M:&5S;&$L('!O:W5D(&AO('IA<&]M96YE=&4N`$YA<W1A=FET('9Z9.%L96[I
M('-E<G9E<GD@=&%K+""^92!B=61O=2!P^.US='5P;ND@>B!P;W)TX6QU+@!.
M87-T879E;NT@5N%M:2!P<F5F97)O=F%NZ6AO(&IA>GEK82P@Z&%S;W;I:&\@
M<.%S;6$@82!T>7!U(&1A='5M=2X`3F%S=&%V96[M('!OZ.%T9>AN[2!A<&QI
M:V%C92P@8F%R979NZ6AO(&UO=&EV=2P@;V)N;W9O=N%N[2!S='+A;F5K(&$@
M9&%LN>UC:"!M;[YN;W-T[2!Z;V)R87IE;NTN`$YA<W1A=F5N[0!.87-T879O
M=F%C[2!K;VYF:6=U<F'H;NT@<VMR:7!T>2!P<F\@86MT=6%L:7IA8VD@:G-O
M=2!D;W-T=7!NZ0!.[&MT97+A(&WM<W1A(&QZ92!N87-T879I="!S('3M;71O
M('!A<F%M971R96TZ(`!397EC:&5L;&5S`$YA:W5P;W;A;NT`2W+A=&OI('-H
M<FYU=.T`3>QL>2!B>2!B_70@</CM<W1U<&]VZ2!K;.WH92!D969I;F]VX6YY
M('!R;R!V['2Y:6YU(&]D:V%Z^3\`6F]B<F%Z:70`6F]B<F%Z:70@<F]Z9.UL
M>2!M97II('-O=>AA<VYO=2!A('#X961C:&]Z[2!K;VYF:6=U<F%C[2X`6F]B
M<F%Z:70@Z&%S('!O<VQE9&[M:&\@</AI:&SAN65N[2!D;R!S>7-TZ6UU/P!:
M;V)R87II="!M;[YN;W-T('5D<KYE;NT@;W)I9VENX6QU`%IO8G)A>FET('-B
M[')AZ`!:;V)R87II="!M96YU(&]P97)AZ&[M(&QIN71U('!R;R!T86)U;&MY
M/P!:;V)R87II="`E<R!M96YU(&YA;&5V;S\`6F]B<F%Z:70@9&EA;&]G('!R
M;R!V;&%S=&YO<W1I(&)U;NQK('8@=&%B=6QKX6-H`%IO8G)A>FET(&1I86QO
M9R!V;&%S=&YO<W3M('1A8G5L96L`6F]B<F%Z:70@9&EA;&]G('9L87-T;F]S
M=.T@^.%D96L@=&%B=6QE:P!:;V)R87II="!D:6%L;V<@=FQA<W1N;W-T[2!O
M8G+A>FOY`%IO8G)A>FET('#X96YO<P!0^&5HX?)K>0!"<GIKZ2!P^&5HX?)K
M>0!0;WID;NT@</AE:.'R:WD`4/AE:.'R:WD@=B!O:V]L[0!:;65NN6ET`%IM
M96ZY:70@;F5B;R!P;W-U;F]U="!D;R!S;W5S961N[6AO(&)L;VMU*/DI+"!Z
M(&-E<W1Y('!R=F[M;74`4VEE<G)A($QE;VYE`%)E9VES=')O=F%T('-E`%!O
M9'!I<P!!;&=O<FET;75S('!R;R!P;V1P:7,`4VEN9V%P=7(`5F5L:6MO<W0`
M5GEN96-H870@^F1ROF)U`%-L;W9E;G-K;P!3;&]V:6YS:V\`4V[LOF5N[0!3
M;NQH;W;A('#X96CA\FMA`%-N[&AO=ND@</AE:.'R:WD`4F%N;NT@<V[L:&]V
MZ2!P^&5HX?)K>0!0;WID;NT@<V[L:&]VZ2!P^&5HX?)K>0!3;NQH;W;A('!O
M:W+]=FMA.@!6;V1N[2!E:W9I=F%L96YT('!R;R!S;NUH.B``J6%L86UO=6YO
M=GD@;W-T<F]V>0!3;VWA;'-K;P!0[7-N["!A(&+A<V[L`%-M['(@=/CM9.QN
M[0!:9')O:F]VX2!A9')E<V$`2FF^;NT@069R:6MA`$II:&]E=G)O<'-K_2`H
M25-/+3@X-3DM,RD`4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',`2FF^;NT@<&]L;VMO=6QE`%!R;W-T;W(@;65Z:2!S;W5S
M961N[6UI(&)U\FMA;6D`4')O<W1O<B!M97II(&]B<V%H96T@82!H<F%N:6-E
M;6D@=B!B=?)C90!-97IE<F[M:P!-97IE<GD`3V1S='5P>2!A(&UE>F5R>0"I
M<&%N[&QS:V\`4W!A;0!6<W1U<"!P<F\@>G9LX;ET;NT@>FYA:WD`4F]Z9.QL
M:70@8G7R:W4`4F]Z9.QL:70@<VQO=7!E8P!2;WID[&QI="#XX61E:P!3<&]R
M=`!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%)O:R!Z8>CA=&MU`%-T
MX70@Z&D@<')O=FEN8VEE`%-T878`1F]R;>%T('5L;[YE;NT`56QI8V4`4/AE
MN6MR=&YU=/T`4V5Z;F%M(/AE=.QZ8V4`3V1S=')A;FET(&1O;>EN;W;I(&IM
MZ6YO('H@861R97-Y`%-T>6P@6T-34UT`3F4`4/AE9&WL=`!0;V1A=`!$;VQN
M[2!I;F1E>`#:<W#LN6[L`$MO;F9I9W5R86-E(&)Y;&$@^G-P[+EN["!Z;>QN
M[&YA+B!/8FYO=G1E('-T<N%N:W4N`-IS<.RY;ND@=6QOOF5N[2!ZX6QOOF[M
M(&MO;F9I9W5R86-E+@#:<W#LN6[I('5L;[YE;NT@>N%L;VAY(&MO;F9I9W5R
M8>AN[6AO('-O=6)O<G4@)7,N`"5S(&)Y;&\@^G-P[+EN["!Z87!SX6YO`%-U
M9.%N`%-H<FYU=.T`4W;M=.%N[0!:X7!A9"!3;'5N8V4`4VQU;F7H;F\`5OUC
M:&]D(%-L=6YC90!6_6-H;V0O>N%P860@4VQU;F-E`%;]8VAO9"!3;'5N8V4Z
M(`!:X7!A9"!3;'5N8V4`6N%P860@4VQU;F-E.B``2&]R;NT@:6YD97@`4&]D
M<&]R80!3=7)I;F%M90!0^.UJ;65N[0!3=F%L8F%R9"!A;F0@2F%N($UA>65N
M`%-W87II;'-K;P"I=NED<VMO`*EV_6-A<G-K;P!3>6YT87AO=N$@8VAY8F$@
M=B!H;&5D86[I;2!T97AT=0!3_7)I90!";W7X:V$`0F]U^&MY`%135B!S;W5B
M;W(`5&%B=6QK80!6;&%S=&YO<W1I('1A8G5L:WD`5FQA<W1N;W-T:2!T86)U
M;&MY`%1A:7=A;@!486EW86XL('!R;W9I;F-I92#([6YY`%1A9+YI:VES=.%N
M`%1A;GKA;FEE+"!3<&]J96[A(')E<'5B;&EK80!#[6PZ`-IK;VQY`%1E;&5F
M;VYN[2#H[7-L;P!497!L;W1A('IA('!O<VQE9&[M(&AO9&EN=3H@`%1E<&QO
M=&$`5&5P;&]T83H@`%9Z;W(@<')O(&%D;6EN:7-T<F%C:0!497AT`%!O=7IE
M('1E>'0`6F%R;W9NX6[M('1E>'1U`%9R8V@@=&5X='4`R'0`5&AA:G-K>2`H
M5$E3+38R,"D`5&AA:G-K;P!$[&MU:F5M92!Z82!P;W6^[7;A;NT@<WES=.EM
M=2X`4/CM<&]N82!P<F\@1E10(&YE;NT@9&]S='5P;N$N`$EN=&5G<F'H;NT@
M86QG;W)I=&UY('8@2&]R9&4O2V]L86(@;F5P;V1P;W)U:NT@(B5S(@!.9?IS
M<.RY;ND@;F'H=&5N[2!T^.UD>2!-86EN=&5N86YC93HZ`$)Y;&\@=7IA=OAE
M;F\@;VMN;R!S(&UOOFYO<W1M:2X@56MO;NAE;F\N`$%D;6EN:7-T<NUT;W(@
M<&]T^&5B=6IE(&YA:V]N9FEG=7)O=F%T('1R=F%LX2!P<N%V82!V('-Y<W3I
M;74L('!O:W5D('-I('#X96IE=&4@<&]UONUT('!RX79A+@!0;W5Z92!S<&]D
M;NT@<W1R86YA`$YE8GEL;R!U=F5D96YO($E$('!R;R!K;VYT86MT+"!N96)Y
M;&\@;F%L97IE;F\@=B!D871A8N%Z:2!N96)O(&)Y;&\@^G!L;NP@=GEN96-H
MX6YO+@!+;VYT86MT(&)Y;"#Z<W#LN6[L('#X:63A;B!D;R!68;EE:&\@861R
M97/A^&4N`$L@;W;L^&5N[2!P;V1E<'-A;ND@>G!RX79Y(&IE('3X96)A(&]D
M9.QL96[](&)L;VL@<R!01U`@<&]D<&ES96TN`$YE8GEL;R!U=F5D96YO($E$
M(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2P@;F5B>6QO(&YA;&5Z96YO('8@9&%T
M86+A>FD@;F5B;R!B>6QO(/IP;&[L('9Y;F5C:.%N;RX`3F5B>6P@=79E9&5N
M(&1I<W1R:6)UZ&[M('-E>FYA;2X`J6EF<F]V86/M(&UOOFYO<W1I(&QZ92!V
M>76^[70@<&]U>F4@</AI(&)E>G!EZ&[I;2!S<&]J96[M(',@=V5B96T@*&AT
M='!S*2X`4V]U8F]R("5S(&)Y(&WL;"!O8G-A:&]V870@;F%S=&%V96[M("5S
M+@!3;W5B;W(@)7,@8GD@;>QL(&]B<V%H;W9A="!N[&MT97+A('H@;F%S=&%V
M96[M("5S+@!3;W5B;W(@;F5L>F4@:V]P[7)O=F%T('/A;2!D;R!S96)E+@!3
M;W5B;W(@;F5O8G-A:'5J92"^X61NX2!D871A+@!.X7-L961U:NT@:&QA=FGH
M:WD@<')O(&UE<W-A9V4O<F9C.#(R('IP<N%V=0!*92!Z;N%MZ2P@OF4@;?-D
M('#X97,@8V5L;W4@;V)R87IO=FMU('8@26YT97)N970@17AP;&]R97)U('#Y
M<V]B[2!P<F]B;.EM>2P@<')O=&^^92!S92!V(&[L;2!V>7-K>71U:F4@8VAY
M8F$L(&MT97+I('-E(&YE;'IE('9Y:&YO=70N($IA:V\@;N%S;&5D96L@;?F^
M92!B_70@;N%H;V1NZ2!Z:')O=6-E;NT@=&]H;W1O('!R;V=R86UU+"!C:'EB
M[&KM8^T@9G5N:V-E(&5D:71O<G4@;F5B;R!N97-P<N%V;ND@>F]B<F%Z;W;A
M;NTN(%!O:W5D(&IE(%;AN2!S>7-T96WI;2!7:6YO9'=S(#EX+"!J92!V96QM
M:2!P<F%V9.QP;V1O8F[I+""^92!S92!O8FIE=NT@8VAY8F]VZ2!H;.&Y96[M
M("='96YE<F%L(%!R;W1E8W1I;VX@1F%U;'0G(&$@8G5D971E(&UU<V5T(')E
M<W1A<G1O=F%T('!OZ.UT8>@N7&Y<;D)Y;&D@:G-T92!V87)O=N%N:2X@4')O
M<^UM('-T:7-K;NQT92!/2R!P;VMU9"!S:2!P^&5J971E('!O:W)AZ&]V870@
M=B!M\V1U('#X97,@8V5L;W4@;V)R87IO=FMU+@!)9&5N=&ET82`B)7,B(&)Y
M;&$@<VUA>N%N82X`4&]U>F4@;F$@;&5VZ2!S=')A;NP`56WM<W3L;NT@8FEN
MX7)N[6AO('-O=6)O<G4@1VYU4$<@;75S[2!B_70@>F%DX6YO(&1O('3X[61Y
M($-R>7!T7W!G<#HZ+@!:<'+A=F$@>F%S;&%NX2!V("5S(&L@)7,@<R!P^&5D
M;>QT96T@(B5S(B!B>6QA('IO8G)A>F5N82X*5&]T;R!N97IA<G7H=6IE+""^
M92!Z<'+A=F$@8GEL82!P^&7H=&5N82!N96)O(+YE(&KM(&%D<F5SX70H:V$I
M(')O>G5M[&PH82DN`$[A>F5V+"!K=&5R_2!B=61E('!O=;YI="!P^&D@;V1K
M87IO=N%N[2!N82!S='+A;F-E('1V;W)B>2!Z<'+A=@!4^.UD82!(;W)D95]#
M<GEP=%]S;6EM93HZ('9YOF%D=6IE(&UO9'5L(&]P96YS<VPN`$YE;'IE('5L
M;[YI="!N87-T879E;NT@(B5S(BP@<')O=&^^92!J96AO('9E;&EK;W-T('#X
M97/A:&QA('!O=F]L96[](&QI;6ET+@!.96)Y;&$@;F%L97IE;F$@87!L:6MA
M8V4@<')O(.AT96[M('1O:&]T;R!T>7!U(&1A="`H)7,I+@!0;W5Z92!N82!P
M<F%VZ2!A(&QE=ND@<W1R86[L`%!O=7IE(&YA('!R87;I('-T<F%N[`!397)V
M97(@(B5S(B!B>6P@=GEM87KA;BX`4V5R=F5R("(E<R(@8GEL('5L;[YE;BX`
M0GEL82!O9'-T<F%N[&YA(+[A9&]S="!O('#X:6ALX;EE;NT@<')O("5S+@!0
M;[YA9&]V86[](/CA9&5K(&YE97AI<W1U:F4N`$1OZ&%S;OT@<V]U8F]R("(E
M<R(@;F5E>&ES='5J92X`4&]U>F4@;F%H;_AE(&$@9&]L90!0;W5Z92!N86AO
M^&4`6G1R871I;&$@<V4@</AE;F5S96[A(&1A=&$@>B!P^&5D8VAO>NUH;R!K
M<F]K=2X`4/AE;F5S96[]('-O=6)O<B!N96QZ92!U;&^^:70N`$)L;VL@=V5A
M=&AE<BYC;VT@;F5N[2!D;W-T=7!N_2X`KN%D;ND@>B!M;[YN;W-T[2!N96IS
M;W4@9&]S='5P;NDN`$YE8GEL>2!N86QE>F5N>2"^X61NZ2#HX7-T:2P@:W1E
M<ND@8GD@8GEL;R!M;[YN;R!Z;V)R87II="!V(/CA9&MU+@!0^.UL:;D@;6YO
M:&\@>FYA:_D@=B!P;VQI+B!:861A;&D@:G-T92`E<R!Z;F%K^3L@;75S[71E
M('IA9&%T(&WI;NP@;F6^("5S('IN86OY+@!.87-T86QA(&-H>6)A('#X:2!P
M^&5N;W-U('-O=6)O<G4Z("5S(&YE8GEL('#X96YE<V5N+@!.87-T86QA(&-H
M>6)A('#X:2!P^&5N;W-U('-O=6)O<G4N("5S(&YE;?F^92!B_70@=NQTN>T@
M;F6^(&UA>&EMX6QN[2!P;W9O;&5NX2!V96QI:V]S="`H)60@8GET^2DN`$YA
M<W1A;&$@8VAY8F$@</AI('#X96YO<W4@<V]U8F]R=3H@8GEL82!P^&5N97-E
M;F$@:F5N(.CA<W0@<V]U8F]R=2`E<RX`1&^Y;&\@:R!C:'EB["!P^&D@>F]B
M<F%Z;W;A;NT@=.ET;R#HX7-T:2!Z<'+A=GD`3F%S=&%L82!C:'EB82!P^&D@
M:6UP;W)T;W;A;NT@:V]N=&%K='4N`%#X:2!I;7!O<G1O=N%N[2!I0V%L96YD
M87(@9&%T(&1ON6QO(&L@8VAY8NPN`$-H>6)A('8@:V]N9FEG=7)AZ&[M;2!F
M;W)M=6SA^&DN(%KX96IM["!J<W1E('9Y;F5C:&%L:2!P;[YA9&]V86[I('!O
M;&4N`$YA<W1A;&$@8VAY8F$@</AI('!R;W;A9.QN[2!Z861A;ND@;W!E<F%C
M92!V(&%D<F5SX?AI+B!0<F]S[6T@>FMU<W1E('1O('!O>F3L:FDN`$YA<W1A
M;&$@8VAY8F$@</AI(&%K='5A;&EZ86-I(&MO;G1A:W1U+B!0<F]S[6T@>FMU
M<W1E('1O('!O>F3L:FDN`$YA<W1A;&$@8VAY8F$@</AI(&%K='5A;&EZ86-I
M(&1I<W1R:6)UZ&[M:&\@<V5Z;F%M=2X@4')O<^UM('IK=7-T92!T;R!P;WID
M[&II+@!496YT;R!)34%0('-E<G9E<B!N97!O9'!O<G5J92!S9.UL96[M('-L
M;[YE:RX`5&]T;R!N979Y<&%DX2!J86MO('!L871N_2!R87(@87)C:&EV+@!4
M;W1O(&YE=GEP863A(&IA:V\@<&QA=&[]('II<"!S;W5B;W(N`%1O=&\@;F5V
M>7!A9.$@:F%K;R!P;&%T;ND@Z.US;&\@:V%R='DN`%1E;G1O(&]V;&%D8>@@
M=6UOOO)U:F4@<&]S[6SA;NT@>G!RX78@<&]M;V/M($-L:6-K871E;&P@*&AT
M='`Z+R]C;&EC:V%T96QL+F-O;2D@8G+A;GD@</AI('!O=;YI=.T@2%144"!!
M4$D`5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M;.%N[2!Z<'+A=B!P;VUO
M8^T@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@8G+A;GD@</AI
M('!O=;YI=.T@2%144"!!4$D`5&5N=&\@;W9L861AZ"!U;6^^\G5J92!P;W/M
M;.%N[2!Z<'+A=B!P;VUO8^T@4TU44"!D;R!6;V1A9F]N92!)=&%L>2!B<N%N
M>2!P;W5Z92!P<F\@Z.US;&$@<&]S:WET;G5TZ2!6;V1A9F]N96TN($UU<^UT
M92!M[70@96UA:6QO=OT@^NAE="!U(%9O9&%F;VYE($ET86QY("AH='1P.B\O
M=W=W+C$Y,"YI="DN`%1O=&\@<&]L92!J92!N=71NZ2!V>7!L;FET+@!4;W1O
M('!O;&4@;?F^92!O8G-A:&]V870@<&]U>F4@8V5LX2#H[7-L82X`5&]T;R!P
M;VQE(&WYOF4@;V)S86AO=F%T('!O=7IE(&-E;.$@Z.US;&$@82!D=F]J=&7H
M:W4N`%1O=&\@<&]L92!M^;YE(&]B<V%H;W9A="!P;W5Z92!O<VUIZ&MO=ND@
MZ.US;&$N`%1O=&\@<&]L92!M=7/M(&+]="!S97IN86T@8V5L_6-H(.CM<V5L
M(&]D9.QL96[]8V@@Z.%R:V]U(&YE8F\@;65Z97)O=0!4;W1O('!O;&4@;75S
M[2!B_70@<&QA=&[I(.CM<VQO+@!4;W1O('!O;&4@;75S[2!P8G-A:&]V870@
M8F%R979N_2!K\V0@=B"Y97-T;N%C:V]VZ6T@4D="(&9O<FWA='4L(&YA</@N
M("<C,3(S-&%F)RX`5&5N=&\@9F]R;75LX?@@:FF^(&)Y;"!Z<')A8V]VX6XN
M`%1O=&\@:F4@)7,N`%1O=&\@:F4@;V)J96MT($MO;&%B($=R;W5P=V%R=2X@
M2R!Z:&SI9&YU=.T@=&]H;W1O(&]B:F5K='4@:F4@>F%P;W3X96+M(&WM="!P
M;[ET;W9N[6AO(&ML:65N=&$L(&MT97+](')O>G5M[2!F;W)MX71U($MO;&%B
M($=R;W5P=V%R=2X@4')O('-E>FYA;2!T86MO=OUC:"!K;&EE;G3Y('!R;W/M
M;2!N87:Y=&EV=&4@)7,`5&%T;R!Z<'+A=F$@8GEL82!N87!SX6YA('8@:FEN
MZ2!Z;F%K;W;I('-A9.P@*"5S*2!N9;X@5F&Y[2X@`%1O=&\@Z.US;&\@;75S
M[2!B_70@;F5J;>EN["!J961N82X`4V5R=F5R(&YE;?F^92!R;WIB86QI="!Z
M:7`@82!G>FEP('-O=6)O<GDN`%1E;G1O('-Y<W3I;2!J92!V('-O=>AA<VYO
M<W1I(&1E86MT:79O=F%N_2X`5&%T;R!H;V1N;W1A(&UU<^T@8OUT(.CM<VQO
M+@!4;W1O(&]K;F\@;76^92!B_70@=F]LX6YO('!O=7IE('H@;VMN82!M;[YN
M;W-T[0!(^&WL;NT`3.US=&MY`,AA<P!3;&5D;W;A;NT@Z&%S=0!&;W)MX70@
MZ&%S=0!6_6+L<B#H87-U`%1I;6]R+4QE<W1E`%1I='5L`%1I='5L("AT:7`I
M.@!+;VUU`%!O:W5D('-I('#X96IE=&4@=GEB<F%T(';M8V4@<&]L;[YE:RP@
M>FWAZ&MN['1E(&MLX79E<W4@0V]N=')O;"`H4$,I(&YE8F\@0V]M;6%N9"`H
M36%C*2!A(&ML:6MN['1E(&YA('!O;&^^:W4N`$1N97,`4/AE<&YO=70@;F$@
M2%1-3"!Z9')O:@!4;V=O`%1O:V5L874`6NUT<F$`5&]N9V$`5G)C:`!(;W)N
M[2!RX6T@*%]T;W`I`%#X96ML861Y`%1R:6YI9&%D(&$@5&]B86=O`%-P<N%V
M;NP@;F5B;R"Y<&%T;NP`VG0`5'5N:7-K;P!4=7)E8VMO`%1U<F5C:WD@*$E3
M3RTX.#4Y+3DI`%1U<FMM96YI<W3A;@!4=7)K<R!A($-A:6-O<R!O<W1R;W9Y
M`%1U=F%L=0!.87!IN71E(%9AN6D@=F]L8G4Z`%4N5BX@:6YD97@Z(`!54DP`
M55),('!R;R!Z<'+A=G4@;R!S=&%V=2!Z87-L86[I:&\@<VMR:7!T=0!54DPZ
M`%5G86YD80!5:W)A:FEN80!61E,@861R97/A^"!J92!N97#X[7-T=7!N_2X`
M4/AI(')E9VES=')A8VD@;F5L>F4@</AI9&%T(&5X=')A('6^:79A=&5L<VOI
M(/ID86IE+@!.96QZ92!Z;>QN:70@<'+A=F$@<')O(%9&4R!S;W5B;W(@(B5S
M(BX`3F5L>F4@>FWL;FET('!RX79A('!R;R!61E,@<V]U8F]R("5S+R5S+@!.
M96QZ92!Z;>QN:70@;F$@)7,N`$YE;'IE('-E('#X:7!O:FET(&L@4U%,('-E
M<G9E<G4N`$YE;'IE('-E('#X:7!O:FET('!O;6]C[2!34TPN`$YE;'IE(&MO
M<.UR;W9A="!61E,@<V]U8F]R+@!.96QZ92!V>71V;_AI="!61E,@861R97/A
M^"`B)7,B+@!.96QZ92!V>71V;_AI="!61E,@861R97/A^"X`3F5L>F4@=GET
M=F_X:70@5D93('-O=6)O<BX`3F5L>F4@=GET=F_X:70@<'+A>F1N_2!61E,@
M<V]U8F]R+@!.96QZ92!R;WIB86QI="!D871A+@!.96QZ92!V>6UA>F%T("(E
M<R(L('!R;W1OOF4@861R97/A^"!N96[M('!RX7ID;OTN`$YE;'IE('9Y;6%Z
M870@)7,L('!R;W1OOF4@861R97/A^"!N96[M('!RX7ID;OTN`$YE;'IE(')E
M:W5R>FEV["!O9'-T<F%N:70@5D93(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@
M5D93(&%D<F5SX?@N`$YE;'IE('9Y;6%Z870@5D93(&%D<F5SX?@Z("5S+@!.
M96QZ92!V>6UA>F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@=GEM87IA="!6
M1E,@<V]U8F]R+@!.96QZ92!R96MU<GII=F[L(&]D<W1R86YI="!61E,Z("5S
M+@!.96QZ92!U<NAI="!A:W1UX6QN[2!A9')E<^'X+@!.96QZ92!Z:FES=&ET
M('!O9')O8FYO<W1I(&\@8V5R=&EF:6OA='4N`$1E9FEN:6-E("5S(&YE;NT@
M9&]S='5P;N$N`$YE;'IE('#X97-U;F]U="!61E,@<V]U8F]R+@!.96QZ92!P
M^&5S=6YO=70@5D93('-O=6)O<B`B)7,B+@!61E,@<V]U8F]R(&YE;'IE(&]T
M97;X[70@<')O('KA<&ES+@!.96QZ92!O=&5V^.UT(%9&4R!S;W5B;W(N`$YE
M;'IE(&]T97;X[70@87)C:&EV;W9A;OT@<V]U8F]R+@!.96QZ92#H[7-T('H@
M=F9S<F]O="!A9')E<^'X92X`3F5L>F4@</AE:FUE;F]V870@)7,@;F$@)7,Z
M(&/M;&]VX2!S;&^^:V$@:FF^(&5X:7-T=6IE`%9&4R!A9')E<^'X(&YE;'IE
M('#X96IM96YO=F%T+@!61E,@861R97/A^"!N96QZ92!P^&5J;65N;W9A=#H@
M)7,N`$YE;'IE('#X96IM96YO=F%T(%9&4R!S;W5B;W(@(B5S(BX`3F5L>F4@
M</AE:FUE;F]V870@5D93('-O=6)O<B`E<R\E<RX`3F5L>F4@</AE:FUE;F]V
M870@5D93('-O=6)O<BX`3F5L>F4@<')O=NES="`G;6MI<V]F<R<N`%1E;G1O
M(&1O:W5M96YT(%=O<F0@;F5L>F4@</AE;&^^:70`3F5L>F4@>F%P<V%T(&1O
M(%9&4R!S;W5B;W)U("(E<R(N`$YE;'IE('IA<'-A="!D871A(&1O(%9&4R!S
M;W5B;W)U("AS96QH86QO(&-O<'DH*2DN`$YE;'IE('IA<'-A="!D871A(&1O
M(%9&4R!S;W5B;W)U`%!O9'1R:&YU=.D`4W1O<FYO('IM[&X`4W1O<FYO=F%T
M('!O<VQE;NT@86MC:0!.96_H96OA=F%NX2!O9'!O=NSO('-E<G9E<G4@;F$@
M<W!O:F5N[3H@`$YE;^AE:^%V86[A(&]D<&]V[.\@<V5R=F5R=3H@`$YE=GEP
M;&[L;F\`56YI8V]D92`H551&+3@I`%-P;VIE;ND@07)A8G-KZ2!%;6ERX71Y
M`%9E;&OA($)R:73A;FEE`%-P;VIE;ND@4W3A='D@06UE<FEC:^D`4W!O:F5N
MZ2!3=.%T>2!-96ZY:6YO=OUC:"!O<W1R;W;Y`$IE9&YO=&MY`$YE>F[A;>D`
M3F5Z;N%MZ2!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+@!.97INX6WI(&-L
M:6US9VED("A#;&EE;G0@365S<V%G92!)1"DN`$YE>F[A;>D@=;YI=F%T96QS
M:^D@:FWI;F\@;F5B;R!H97-L;RX`3V1P;VII="!S;W7H87-N_2!P<G9E:P!"
M97IE(&IMZ6YA`$YE<')I=FEL96=O=F%NZ2!S:W)I<'1Y(&YE;6]H;W4@=GEU
MONUV870@9G5N:V-A(%9Y:FUO=70O2V]P[7)O=F%T+U9L;[X@>B!B97IP9>AN
M;W-T;NUC:"!D^79O9/DN($ML:6MN['1E(&YA($]+(&%B>7-T92!V:63L;&D@
M=&5C:&YI8VMO=2!Z<'+A=G4@>B!M;WII;&QA+F]R9RP@:W1E<N$@=GES=NQT
M;'5J92P@:F%K(&YA<W1A=FET('-K<FEP="!P<F\@</CM<W1U<"!K92!S8VAR
MX6YC92X`3F5N87-T879E;N$@8F%R=F$`3F5P;V1P;W)O=F%NX2!P^.UP;VYA
M`$%K='5A;&EZ;W9A=`!!:W1U86QI>F]V870@)7,`06MT=6%L:7IO=F%T('6^
M:79A=&5L90!3:W)I<'0@<')O(&%K='5A;&EZ86-I(&)Y;"!V>6UA>N%N+@!0
M^&5N;W,`5KEE8VAN>2!S;W5B;W)Y('!R;R!N87-T879E;NT@87!L:6MA8^T@
M8GEL>2!P^&5N97-E;GD@;F$@<V5R=F5R+@!696QKX2!T:7-K86/M('#M<VUE
M;F$`5F5L:^D@^.UM<VOI(.CM<VQI8V4`57)U9W5A>0!0;W6^[70@86MT=>%L
M;NTZ("5S`%!O=;[M="!34TP`4&]UONUT('!O:W5D(&IMZ6YO+VAE<VQO(&IS
M;W4@:FENZ2!N9;X@<')O($E-4U`@<V5R=F5R+@!5OFEV871E;"`E<R!N96[M
M(&]P<N%V;NQN(&L@<&]UONUVX6[M("5S+@!!9&UI;FES=')A8V4@=;YI=F%T
M96SY`%6^:79A=&5L<VOI(&UOOFYO<W1I`%)E9VES=')A8V4@=;YI=F%T96SY
M`$YA('1O;71O('-E<G9E<G4@;F5N[2!M;[YNX2!R96=I<W1R86-E('6^:79A
M=&5L^2X`5;YI=F%T96QS:^D@:FWI;F\`5;YI=F%T96QS:^D@:FWI;F\Z`%6^
M:79A=&5L<VOI(&IMZ6YO.B``4V5Z;F%M('6^:79A=&5L^3H`57IB96MI<W3A
M;@!61E,@861R97/A^"!N965X:7-T=6IE+@!$;W9O;&5NX0!.86QE>F5NX2!P
M;&%T;N$@;>US=&$@>F%H<FYU:NTZ(`!0;&%T;F]S=`!(;V1N;W1A('8@;6EN
M=73A8V@N`$AO9&YO='D`5GEB<F%NZ2!H;V1N;W1Y('H`5F%N=6%T=0!0<F]M
M[&YNZ0!696YE>G5E;&$`4V5L:&%L82!V97)I9FEK86-E("T@=&%T;R!Z<'+A
M=F$@;6]H;&$@8OUT('IF86RY;W;A;F$N`%9E<GIE`%9E<G-I;VX@0V]N=')O
M;`!697)T:6OA;&[M('IA<F]V;N%N[0!697)T:6OA;&[M(&]D<W1U<`!697)T
M:6OA;&[M.@!696QM:2!V>7-O:^$`5FEE=&YA;0!6:65T;F%M<VMY("A625-#
M24DI`%IO8G)A>FET("5S`%IO8G)A>FET(&5X=&5R;NT@=V5B<W1RX6YK=0!:
M;V)R87II="!J86MO("5S`%!A;FYE;G-KZ2!/<W1R;W9Y+"!"<FET<VOI`%!A
M;FYE;G-KZ2!/<W1R;W9Y+"!5+E,N`%9I9&ET96QN;W-T`%9I9&ET96QN;W-T
M.@!6;V1A9F]N92!)=&%L>2!P^&5S(%--5%``55!/6D]23DE4`%503UI/4D[,
M3LTA(2$@3T135%)!TE1%(%-+4DE05"!25<A.S"!:("5S+@!786QL:7,@86YD
M($9U='5N80!5<&]Z;W)N[&[M`%-T`%#X961P;W;L[R!P;^AA<^T`1&%T82!O
M('!OZ&%S[2!P;W-K>71U:F4`5V5A=&AE<BYC;VT`5V5B`%=E8B!S97)V97(`
M5/UD;NP`5NUT96IT90!6[71E:G1E('8@)7,`5NUT96IT92P@)7,`6N%P861N
M[2`H25-/+3@X-3DM,2D`6N%P861N[2`H25-/+3@X-3DM,34I`%KA<&%D;NT@
M4V%H87)A`$MT97)O=2!A<&QI:V%C:2!MX2`E<R!Z;V)R87II="!P;R!P^&EH
M;.&Y96[M(&1O('-Y<W3I;74_`$IA:_T@:F4@;V1D[&QO=F%C[2!Z;F%K/P!*
M86O](&IE('IN86L@<')O(&-I=&%C:3\`2W1E<ND@9N%Z90!6;VQB82!R;WJY
M[?AE;NT@<')O(%)I8V@@5&5X="!E9&ET;W(N`*GM^&MA`*GM^&MA('8@0U-3
M(&IE9&YO=&OA8V@`J>WX:V$@)7,@;65N=2!V;&5V;R`H>FWL;F$@<V4@;V)J
M97;M('#X:2!D86RY[6T@</AI:&SAN65N[2DZ`*GM^&MA('1A8G5L:WD`2F5D
M;F]T:V$@N>WX:WD`J>WX:V$Z`%=I:VD`5NUT<@!286YN[2!V[71R`%)Y8VAL
M;W-T(';L=')U('8@=7IL96-H`%;M='(Z`%;M='(Z(`!-;W5D<F]S=`!0<N%C
M90!!9')E<V$@9&\@>F%M['-T;N%N[0!496QE9F]N(&1O('IA;>QS=&[A;NT`
M6"U2968`6#4P.78S('KA:VQA9&[M(&]M97IE;NT`6#4P.78S(')O>KGM^&5N
MZ2!P;W6^:73M(&ML[>AE`%@U,#EV,R!A;'1E<FYA=&EV;NT@:FWI;F\@;W-O
M8GD`6#4P.78S(&ED96YT:69I:^%T;W(@:VSMZ&4`6#4P.78S(')O>KGM^&5N
M[0!24@!24E)2`$UA<&$@66%H;V\A`%)OZ&[L`$IE;65N`$%N;P!!;F\L('-O
M=6AL87/M;0!*<W1E('8@5$585$]6R4T@3=-$52X@4&]UOFEJ=&4@6SP^72!T
M;&'H[71K82!K('IP['1NZ6UU('#X97!N=73M(&1O(%=94TE764<N`$YE8GEL
M:2!J<W1E('-P<N%V;NP@;W;L^&5N:2X`6FYA:R`G7"<@;F5M^;YE(&+]="!S
M;W7HX7-T[2!68;EE:&\@:FWI;F$N`$)Y;&$@>F%DX6YA(&YE<&QA=&[A(&4M
M;6%I;&]VX2!A9')E<V$N`$YE;6%P;W9A;&D@:G-T92"^X61NX2!P;VQE('H@
M:6UP;W)T;W9A;NEH;R!S;W5B;W)U(&L@;V1P;W;M9&%J[6/M;2!P;VSM;2!V
M("5S+@!">6QI(&IS=&4@;V1H;.&Y96YI('IE('-Y<W3I;74N`%9L;[YT92#H
M[7-L;R!M;V)I;&[M:&\@=&5L969O;G4L('!O=;YI:G1E(&IE;B#H[7-L:6,@
M;F5B;R!P^.UP861N["`G*R<@<')O(&UE>FENX7)O9&[M(.AI<VQA+@!-=7/M
M=&4@>F%D870@<&QA=&YO=2!H;V1N;W1U+@!-=7/M=&4@:V]N9FEG=7)O=F%T
M(&1A=&%BX7II(&1A="P@<&]K=60@<VD@</AE:F5T92!P;W6^[79A="!296=I
M<W1R86-E+@!-=7/M=&4@:V]N9FEG=7)O=F%T(%9&4R!B86-K96YD+@!-=7/M
M=&4@;F5J9/CM=F4@<&]P<V%T('!R;V)LZ6T@82!P;W3I(&AO(&]D97-L870N
M`$UU<^UT92!Z861A="!54DP@;F$@:W1E<ND@8G5D92!T96YT;R!O9&MA>B!U
M:V%Z;W9A=`!-=7/M=&4@=GEB<F%T('-E<G9E<BP@:W1E<OT@8G5D92!S;6%Z
MX6XN`$UU<^UT92!V>6)R870@=;YI=F%T96QS:^D@:FWI;F\L(&MT97+I(&)U
M9&4@<VUA>N%N;RX`375S[71E('IA9&%T('6^:79A=&5L<VOI(&IMZ6YO+"!K
M=&5RZ2!B=61E(&]D<W1R86[L;F\N`$YE=79E9&QI(&IS=&4@=;YI=F%T96QS
M:^D@:FWI;F\L(&MT97+I(&)U9&4@</AI9.%N;RX`3F5U=F5D;&D@:G-T92!U
MOFEV871E;'-KZ2!J;>EN;R!P<F\@86MT=6%L:7IA8VDN`$UU<^UT92!Z861A
M="!A:V-I+"!K=&5RX2!B=61E('!R;W9E9&5N82X`375S[71E('IA9&%T(&IM
MZ6YO(&YO=ND@:V%T96=O<FEE+@!68;EE("5S(')E;&%C92!B>6QA('5K;V[H
M96YA+B!/<.QT('-E('#X:6AL8;ET92P@<')O<^UM+@!68;EE(&5M86EL;W;A
M(&%D<F5S80!68;EE($]D+6MO:&\Z(&%D<F5S83H`5F&Y92!I;F9O<FUA8V4`
M5B!R96QA8VD@)7,@<V4@>FWL;FEL82!68;EE(&EN=&5R;F5T;W;A(&%D<F5S
M82X@6B!B97IP9>AN;W-T;NUC:"!D^79O9/D@<V4@;75S[71E(&]P['0@</AI
M:&SA<VET+@!68;EE(&IMZ6YO`%;AN2!O=NSX;W9A8^T@<WES=.EM(&YE<&]D
M<&]R=6IE(';]<&ES('6^:79A=&5L^2!A;F5B;R!T871O(&UOOFYO<W0@;F5N
M[2!P^.US='5P;N$@>B!J:6[]8V@@9/EV;V3Y+@!:9.$@<V4L(+YE('8@<'+Y
M8NQH=2!R96QA8V4@)7,@<V4@>FWL;FEL(%;AN2!P<F]H;.V^9>@N(%H@8F5Z
M<&7H;F]S=&[M8V@@9/EV;V3Y('-E(&UU<^UT92!O<.QT('#X:6ALX7-I="X`
M5N&Y('!R;VAL[;YEZ"!N97!O9'!O<G5J92!T=71O(&UOOFYO<W0N`%9AN64@
M<V]UZ&%S;ND@Z&%S;W;I('#A<VUO.@!68;EE(&EM<&QI8VET;NT@:61E;G1I
M=&$`5F&Y92#Z<&QNZ2!J;>EN;SH`5F&Y92!N;W;I(&AE<VQO('!R;R`E<R!J
M93H@)7,`5F&Y92!N87-T879E;NT@8GEL;R!A:W1U86QI>F]VX6YO('!R;R!T
M<G;A;NT@=.ET;R!R96QA8V4N`%9AN64@;F%S=&%V96[M(&)Y;&\@86MT=6%L
M:7IO=N%N;RX`5F&Y92!H97-L;R!B>6QO(')E<V5T;W;A;F\N`%9AN64@:&5S
M;&\@8GEL;R!R97-E=&]VX6YO+"!Z:V]N=')O;'5J=&4@<VD@>G!RX79Y(&5L
M96MT<F]N:6-KZ2!P;[ET>2!A('#X:6AL8;ET92!S92!S(%9AN>UM(&YO=OUM
M(&AE<VQE;2X`5F&Y92!V>F3A;&5NZ2!S97)V97)Y.@!*=6=O<VSA=FEE`%IA
M:7(`6F%M8FEE`%II;6)A8G9E`%II<'!Y`%M5:W+]="!C:71O=F%N_2!T97AT
M70!;2&SAN65N[2!P<F]B;.EM=5T`6UIO8G)A>FET(&-I=&]V86[]('1E>'0@
M+0!;6F]B<F%Z:70@8VET;W9A;OT@=&5X="`M("5S(/CA9&OY70!;^.%D96L@
M)7,@>B`E<UT`7T%D;6EN:7-T<F%C90!?0TQ)`%]$871A5')E90!?4VUA>F%T
M(/CA9&5K`%]3:W5P:6YY`%].X7!O=NQD80!?5FQA<W1N;W-T:2!O8G+A>FMU
M+BXN`%]0^&EH;.&Y96[M`%]/9&ALX;EE;NT`7TUO9&EF:6MO=F%T(&]D:V%Z
M+BXN`%]-;[YN;W-T:0!?4'+A=F$`7T]D<W1R86YI="!O9&MA>BXN+@!?3F%S
M=&%V96[M`%]6;&%S=&YO<W1I('1A8G5L:WDN+BX`7U6^:79A=&5LZ0!A9')E
M<^'X`&MA;&5N9.'X`&)E>G;L=/CM`&ML:6MN;W5T('ID90!S<N&^:WD`<V]U
M8F]R`'H@)7,@*"5S*2!R>6-H;&]S=.T@)7,@)7,`:#H`;VMA;;YI=.P`=B#X
M863L`/CA9&OY70!C:'EB;W;](&OS9"!M:VES;V9S("5D('#X:2!V>71VX?AE
M;NT@25-/+@!J;>EN;P!N96[M(&EM<&QE;65N=&]VX6YO`&YE;NT@9&]S=60@
M:6UP;&5M96YT;W;A;F\`>N%P:7-N[6L`<')O8V5N=`!P:7AE;/D`<W1O=7!A
M:NUC[0!Z;V)R87II="!R;WID[6QY`'-M<S)E;6%I;"!Z82!P;W6^:73M($A4
M5%``=GET<G9A;.D`<V5Z;F%M(/IK;VSY`'!R;R!P;W1V<GIE;NT@;F%P:;ET
M92!H97-L;R!D=F%K<N%T`'-J961N;V-E;OT`8F5Z(&[A>G9U`'9Y8G)A="!U
MOFEV871E;&4`=D-A<F0`=SH`=V5A=&AE<BYC;VT`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C
M86QE+V1E7T1%+TQ#7TU%4U-!1T53````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`R,30S-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O:&5L<"YX;6P`````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0T,3`@,3`U,34T,S0Q
M-#$@,#(Q-#`Q`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y
M+3$B/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]D95]$12]H96QP+GAM
M;"QV(#$N-2`R,#`T+S$P+S(R(#$S.C,W.C$Y(&IA;B!%>'`@)"`M+3X*/&AE
M;'`^"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!M9#4](C8X8V$S,V8W9C!C.6%A
M931C,3`S96(T-S0Y,F-D8S$U(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/D1I92!0;W)T86QS96ET93PO=&ET;&4^"B`@("`\<&%R83X*("`@("`@
M1&EE(%!O<G1A;'-E:71E(&5R;&%U8G0@96EN92!K=7)Z92#<8F5R<VEC:'0@
M_&)E<B!A;&QE($EH<F4@=VEC:'1I9V5N"B`@("`@($EN9F]R;6%T:6]N96XN
M(%-I92!K86YN('IU;2!"96ES<&EE;"!A;GIE:6=E;BP@=VEE('9I96QE(&YE
M=64@16UA:6QS(%-I90H@("`@("!H86)E;BP@=V5L8VAE(%1E<FUI;F4@9&5M
M;N1C:'-T(&%N<W1E:&5N+"!W96QC:&4@075F9V%B96X@4VEE(&YO8V@@>G4*
M("`@("`@97)L961I9V5N(&AA8F5N(&]D97(@875C:"!D:64@;F5U97-T96X@
M3F%C:')I8VAT96XN(%9I96QE(&1I97-E<@H@("`@("#<8F5R<VEC:'1E;B!E
M;G1H86QT96X@<V-H;F5L;&4@6G5G<FEF9F4@875F(&CD=69I9R!B96[V=&EG
M=&4@1G5N:W1I;VYE;BP*("`@("`@=VEE(&1A<R!38VAR96EB96X@;F5U97(@
M16UA:6QS(&]D97(@9&5M($%N;&5G96X@;F5U97(@2V%L96YD97)E:6YT<N1G
M90H@("`@("!O9&5R($%U9F=A8F5N+@H@("`@/"]P87)A/@H@("`@/'!A<F$^
M"B`@("`@($1E<B!);FAA;'0@9&EE<V5R(%!O<G1A;'-E:71E(&MA;FX@_&)E
M<B!D96X@(D%N<&%S<V5N(BU,:6YK"B`@("`@('9E<N1N9&5R="!W97)D96XN
M(%-I92!K]FYN96X@>G5M($)E:7-P:65L(&%U<W?D:&QE;BP@=V5L8VAE(-QB
M97)S:6-H=&5N"B`@("`@(&EN(&1I92!0;W)T86QS96ET92!A=69G96YO;6UE
M;B!W97)D96X@<V]L;&5N+"!U;F0@9F5S=&QE9V5N+"!I;B!W96QC:&5R"B`@
M("`@(%)E:6AE;F9O;&=E('-I92!A;F=E>F5I9W0@=V5R9&5N+@H@("`@/"]P
M87)A/@H@(#PO96YT<GD^"@H@(#QE;G1R>2!I9#TB;F%V8F%R(B!M9#4](F(X
M8V8P864Q.64U-V1F83!C,F(Y-C)E-3$V-S@R9C0W(B!S=&%T93TB=7!T;V1A
M=&4B/@H@("`@/'1I=&QE/D1I92!!;G=E;F1U;F=S+4YA=FEG871I;VYS;&5I
M<W1E/"]T:71L93X*("`@(#QP87)A/@H@("`@("!!=68@9&5R(&QI;FME;B!3
M96ET92!D97,@1F5N<W1E<G,@8F5F:6YD970@<VEC:"!D:64@3F%V:6=A=&EO
M;G-L96ES=&4*("`@("`@9OQR(&1I92!!;G=E;F1U;F=E;BX@2VQI8VME;B!3
M:64@875F(&1I92!3>6UB;VQE(&]D97(@3F%M96X@9&5R"B`@("`@($%N=V5N
M9'5N9V5N+"!U;2!S8VAN96QL('5N9"!E:6YF86-H('IW:7-C:&5N(&1I97-E
M;B!H:6XM('5N9`H@("`@("!H97)Z=7-C:&%L=&5N+@H@("`@/"]P87)A/@H@
M(#PO96YT<GD^"B`@/&5N=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@
M<W1A=&4](G5P=&]D871E(B!M9#4](F1D.35D9C`W83`S,#,Q,C,R8F%E83DQ
M.3(X.&(R9#`P(CX*("`@(#QT:71L93Y%:6YS=&5L;'5N9V5N.B!!;FUE;&1E
M875F9V%B96XZ(%=A<G1U;F=S87)B96ET96X*("`@("`@9'5R8VAF_&AR96X\
M+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@(%=E;FX@4VEE(&WV8VAT96XL(&1A
M<W,@;F%C:"!D97(@06YM96QD=6YG(%=A<G1U;F=S87)B96ET96X@9'5R8VAG
M96;\:')T"B`@("`@('=E<F1E;BP@;6%R:VEE<F5N(%-I92!D:65S97,@075S
M=V%H;&9E;&0N"B`@("`\+W!A<F$^"B`@/"]E;G1R>3X*("`\96YT<GD@:60]
M(G!R969S+6-O;F9I<FU?;6%I;G1E;F%N8V4B('-T871E/2)U<'1O9&%T92(@
M;60U/2)A,C$Q-C)C9&9F,V(Q9#AF865A9&(W,CDV,C0P,#,V92(^"B`@("`\
M=&ET;&4^16EN<W1E;&QU;F=E;CH@06YM96QD96%U9F=A8F5N.B!787)T=6YG
M<V%R8F5I=&5N(&)E<W3D=&EG96X\+W1I=&QE/@H@("`@/'!A<F$^"B`@("`@
M(%=E;FX@4VEE(&%L;&4@5V%R='5N9W-A<F)E:71E;B!B97-TY'1I9V5N(&WV
M8VAT96XL(&)E=F]R(&1I97-E"B`@("`@(&%U<V=E9OQH<G0@=V5R9&5N+"!M
M87)K:65R96X@4VEE(&1I97-E<R!!=7-W86AL9F5L9"X@5V5N;B!3:64@9&%S
M($9E;&0*("`@("`@9&5A:W1I=FEE<G0@;&%S<V5N+"!W97)D96X@86QL92!7
M87)T=6YG<V%R8F5I=&5N(&%U=&]M871I<V-H"B`@("`@(&1U<F-H9V5F_&AR
M="P@;VAN92!D87-S(%-I92!B96D@9&5R($%N;65L9'5N9R!D:64@1V5L96=E
M;FAE:70@:&%B96XL"B`@("`@(&1I97-E(&%B>G5B<F5C:&5N+@H@("`@/"]P
M87)A/@H@(#PO96YT<GD^"CPO:&5L<#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O9&5?1$4O3$-?3453
M4T%'15,O:&]R9&4N;6\`````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`T,C8S
M-#`@,3`U,34T,S0Q-#$@,#(S,38T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````-X2!)4`````D`<``!P```"</```'PH``!QY
M````````F*$```X```"9H0``#P```*BA```-````N*$```@```#&H0``"P``
M`,^A```,````VZ$```0```#HH0``&````.VA```;````!J(``"T````BH@``
M'0```%"B```D````;J(``"D```"3H@``&0```+VB```F````UZ(```P```#^
MH@``)`````NC```/````,*,```L```!`HP``#@```$RC```%````6Z,``"@`
M``!AHP``"````(JC```*````DZ,``!4```">HP``$@```+2C```+````QZ,`
M`(4```#3HP``#@```%FD```*````:*0```T```!SI```#@```(&D```1````
MD*0```T```"BI```#````+"D```-````O:0```8```#+I```E````-*D```*
M````9Z4```\```!RI0``&````(*E```,````FZ4```X```"HI0``#@```+>E
M```(````QJ4```D```#/I0``+@```-FE```:````"*8``#(````CI@``.```
M`%:F``!4````CZ8``%$```#DI@``6@```#:G``!7````D:<``#0```#IIP``
M"0```!ZH```-````**@```T````VJ```!P```$2H```*````3*@```\```!7
MJ```!0```&>H```&````;:@``!$```!TJ```"````(:H```)````CZ@```D`
M``"9J```)0```*.H```@````R:@``!,```#JJ```$````/ZH```/````#ZD`
M``H````?J0```P```"JI```/````+JD``!0````^J0``"0```%.I```+````
M7:D```T```!IJ0``$@```'>I```9````BJD``!X```"DJ0``#P```,.I```*
M````TZD```@```#>J0``)````.>I```4````#*H``!8````AJ@``"````#BJ
M``!.````0:H``"T```"0J@``&0```+ZJ```'````V*H```P```#@J@``+```
M`.VJ```.````&JL```,````IJP``"P```"VK```'````.:L```<```!!JP``
M!0```$FK```%````3ZL```H```!5JP```P```&"K```7````9*L```H```!\
MJP``#P```(>K```.````EZL``!@```"FJP``(P```+^K```.````XZL``!0`
M``#RJP``%P````>L```7````'ZP``!<````WK```$P```$^L```/````8ZP`
M``X```!SK```'P```(*L```=````HJP```<```#`K```!@```,BL```(````
MSZP```\```#8K```!@```.BL```*````[ZP``!,```#ZK```"P````ZM```0
M````&JT``!4````KK0``%0```$&M```'````5ZT``!````!?K0``!0```'"M
M```5````=JT``!$```",K0``#````)ZM```[````JZT``#@```#GK0``"0``
M`""N```'````*JX``!0````RK@```P```$>N```%````2ZX``!````!1K@``
M"0```&*N```3````;*X``#D```"`K@``$@```+JN```G````S:X``"P```#U
MK@``*@```"*O```E````3:\```H```!SKP``!@```'ZO```)````A:\```<`
M``"/KP``+P```)>O```W````QZ\``"X```#_KP``50```"ZP```M````A+``
M`"T```"RL```/0```."P```_````'K$``"T```!>L0``0````(RQ```C````
MS;$``",```#QL0``0````!6R```M````5K(``#,```"$L@``)0```+BR```5
M````WK(``!D```#TL@``*0````ZS```D````.+,``"@```!=LP``$0```(:S
M```*````F+,```P```"CLP``"@```+"S```0````N[,``!8```#,LP``%@``
M`..S```'````^K,```<````"M```%`````JT```*````'[0```@````JM```
M)P```#.T```(````6[0```<```!DM```!P```&RT```&````=+0```4```![
MM```!P```(&T```&````B;0```@```"0M```*0```)FT```.````P[0```H`
M``#2M```!````-VT```'````XK0```D```#JM```!@```/2T```1````^[0`
M``<````-M0``%@```!6U```$````++4```@````QM0``!@```#JU```-````
M0;4```8```!/M0``'@```%:U```1````=;4```@```"'M0``#0```)"U```,
M````GK4```<```"KM0```P```+.U```#````M[4``!<```"[M0``$P```-.U
M```=````Y[4```@````%M@``!`````ZV```(````$[8```@````<M@``*P``
M`"6V```@````4;8``!4```!RM@``!@```(BV```&````C[8``!4```"6M@``
M.@```*RV```8````Y[8``"(`````MP``,P```".W```N````5[<``!T```"&
MMP``(0```*2W``!4````QK<``$`````;N```*0```%RX```9````AK@```H`
M``"@N```!P```*NX```'````L[@``!4```"[N```#@```-&X```*````X+@`
M``\```#KN```#0```/NX```/````";D```T````9N0``"0```">Y```4````
M,;D```8```!&N0``&````$VY```=````9KD``!,```"$N0``$0```)BY```4
M````JKD```0```"_N0``!@```,2Y```4````R[D``%0```#@N0``9````#6Z
M```$````FKH```X```"?N@``!0```*ZZ```%````M+H``!L```"ZN@``&@``
M`-:Z```3````\;H``!$````%NP``$0```!>[```<````*;L``"H```!&NP``
M$````'&[```A````@KL```4```"DNP``$P```*J[```+````OKL``!(```#*
MNP``"@```-V[```/````Z+L```T```#XNP``$0````:\```3````&+P```P`
M```LO```!@```#F\```,````0+P```8```!-O```%P```%2\```0````;+P`
M`!$```!]O```"````(^\```%````F+P```P```">O```$````*N\```%````
MO+P```T```#"O```!@```-"\```'````U[P```T```#?O```!P```.V\```+
M````];P```<````!O0``!P````F]```)````$;T```D````;O0``"@```"6]
M```9````,+T``!T```!*O0``#````&B]```0````=;T```4```"&O0``)0``
M`(R]```2````LKT``!,```#%O0``*P```-F]```[````!;X``"````!!O@``
M"````&*^```V````:[X``"$```"BO@``$````,2^```(````U;X```P```#>
MO@``!@```.N^```$````\KX```\```#WO@``#@````>_```'````%K\```H`
M```>OP``#0```"F_```?````-[\``!P```!7OP``(0```'2_```>````EK\`
M`!D```"UOP``'@```,^_```;````[K\``"$````*P```+@```"S````F````
M6\```!P```""P```'@```)_````<````OL```"8```#;P```*P````+!```S
M````+L$``"8```!BP0``*P```(G!```X````M<$``!T```#NP0``%0````S"
M```O````(L(``"````!2P@``$@```'/"```I````AL(``!X```"PP@``(```
M`,_"```2````\,(``*(````#PP``%@```*;#```C````O<,``"@```#APP``
M*0````K$```H````-,0``!\```!=Q```%0```'W$```@````D\0``"4```"T
MQ```*````-K$```M`````\4``#`````QQ0``D@```&+%```A````]<4``!8`
M```7Q@``'````"[&```F````2\8``"H```!RQ@``00```)W&``!$````W\8`
M``P````DQP``!P```#''```'````.<<```8```!!QP``#0```$C'```0````
M5L<``!(```!GQP``$P```'K'```2````CL<```<```"AQP``!````*G'```0
M````KL<``!````"_QP``#````-#'```.````W<<```T```#LQP``#P```/K'
M```3````"L@```T````>R```*````"S(```#````5<@```T```!9R```!@``
M`&?(```1````;L@``!<```"`R```&P```)C(```.````M,@```(```##R```
M20```,;(```%````$,D``!`````6R0``#P```"?)```$````-\D```T````\
MR0``#@```$K)```#````6<D```X```!=R0``"````&S)```/````=<D```\`
M``"%R0``!P```)7)```-````G<D``!````"KR0``#0```+S)```+````RLD`
M``8```#6R0``"P```-W)```,````Z<D```H```#VR0``$0````'*```9````
M$\H```L````MR@``#0```#G*```B````1\H```\```!JR@``&P```'K*```T
M````ELH```H```#+R@``&````-;*```2````[\H``!D````"RP``%@```!S+
M```B````,\L```T```!6RP``!P```&3+```4````;,L```L```"!RP``(@``
M`(W+```O````L,L```L```#@RP``"0```.S+```9````]LL```L````0S```
M%P```!S,```7````-,P```D```!,S```%@```%;,```/````;<P``!D```!]
MS```%@```)?,```.````KLP``!@```"]S```"````-;,```-````W\P``"8`
M``#MS```0P```!3-```(````6,T``!(```!AS0``'P```'3-```(````E,T`
M``L```"=S0``+P```*G-```.````V<T```4```#HS0``!@```.[-``!%````
M]<T```,````[S@``!P```#_.```$````1\X```H```!,S@``"@```%?.```/
M````8LX``!````!RS@``%P```(/.```1````F\X``!D```"MS@``%P```,?.
M```)````W\X```4```#IS@``"P```._.```*````^\X```(````&SP``!0``
M``G/```-````#\\``!L````=SP``%P```#G/```4````4<\```D```!FSP``
M#@```'#/```-````?\\``!(```"-SP``.````*#/```@````V<\```@```#Z
MSP``#@````/0``![````$M```!@```".T```&````*?0```1````P-````<`
M``#2T```!0```-K0```8````X-```!X```#YT```&P```!C1```9````--$`
M`!L```!.T0``&0```&K1```3````A-$```<```"8T0``"````*#1```&````
MJ=$```8```"PT0``$````+?1```/````R-$``!````#8T0``#P```.G1```+
M````^=$```\````%T@``#````!72```/````(M(```<````RT@``!@```#K2
M```,````0=(``"@```!.T@``#P```'?2```(````A](```@```"0T@``$P``
M`)G2```>````K=(``"$```#,T@``(````.[2```9````#],``!<````ITP``
M)0```$'3```7````9],``!8```!_TP``!````);3```;````F],```T```"W
MTP``#````,73```#````TM,```4```#6TP``"````-S3```*````Y=,```P`
M``#PTP``"P```/W3```0````"=0```P````:U```#@```"?4```+````-M0`
M``0```!"U```!````$?4```3````3-0``!0```!@U```#````'74```)````
M@M0```X```",U```"P```)O4```;````I]0```<```##U```!P```,O4```*
M````T]0```T```#>U```"0```.S4```$````]M0```4```#[U````P````'5
M```8````!=4```H````>U0``!````"G5```F````+M4```X```!5U0``?```
M`&35```5````X=4```4```#WU0``!P```/W5```,````!=8```@````2U@``
M"@```!O6```&````)M8```@````MU@```@```#;6```&````.=8```8```!`
MU@``%````$?6```0````7-8```T```!MU@``$````'O6```;````C-8```0`
M``"HU@``"0```*W6```0````M]8```D```#(U@``"0```-+6```%````W-8`
M`!H```#BU@``"````/W6```&````!M<``!D````-UP``#@```"?7```'````
M-M<```<````^UP``!0```$;7```)````3-<```H```!6UP``#@```&'7```"
M````<-<```8```!SUP``"P```'K7```-````AM<```D```"4UP``!@```)[7
M```2````I=<```D```"XUP``!P```,+7```4````RM<``!T```#?UP``0@``
M`/W7```E````0-@``"4```!FV```!@```(S8```*````D]@```0```">V```
M"0```*/8```(````K=@``!$```"VV```"0```,C8```&````TM@```T```#9
MV```!@```.?8```$````[M@``#D```#SV```/0```"W9```Z````:]D``!X`
M``"FV0``!0```,79```.````R]D```0```#:V0``!@```-_9```'````YMD`
M`"$```#NV0``#0```!#:```5````'MH```8````TV@``!````#O:```1````
M0-H```8```!2V@``"@```%G:```B````9-H```0```"'V@``!0```(S:```=
M````DMH```P```"PV@``#@```+W:```*````S-H```@```#7V@``"0```.#:
M```%````ZMH``#H```#PV@``,````"O;```U````7-L``"D```"2VP``1P``
M`+S;```X````!-P``"D````]W```/P```&?<```N````I]P``"T```#6W```
M'P````3=```/````)-T``!(````TW0``"P```$?=```F````4]T``"D```!Z
MW0``)````*3=```F````R=T```@```#PW0``"@```/G=```)````!-X```<`
M```.W@``(````!;>```@````-]X``"8```!8W@``"@```'_>```9````BMX`
M`"D```"DW@``%@```,[>```2````Y=X```<```#XW@``"@````#?```,````
M"]\```\````8WP``$````"C?``!`````.=\``'````!ZWP``9@```.O?```.
M````4N````D```!AX```"@```&O@```2````=N```!,```")X```#````)W@
M```&````JN````\```"QX```$@```,'@```0````U.```!$```#EX```'```
M`/?@```C````%.$``&H````XX0``#P```*/A```%````L^$``!````"YX0``
M"0```,KA```$````U.$```L```#9X0``(````.7A```1````!N(``!0````8
MX@``#````"WB```,````.N(```\```!'X@``%0```%?B```I````;>(``"H`
M``"7X@``)@```,+B```G````Z>(``"D````1XP``*@```#OC```9````9N,`
M`$(```"`XP``$0```,/C```2````U>,``!,```#HXP``%````/SC```/````
M$>0``!8````AY```%P```#CD```0````4.0``!$```!AY```-````'/D```3
M````J.0``!(```"\Y```-0```,_D```4````!>4```<````:Y0``#````"+E
M```@````+^4``!````!0Y0``%````&'E```1````=N4``!<```"(Y0``'```
M`*#E```3````O>4``!0```#1Y0``&@```.;E```1`````>8``!H````3Y@``
M'@```"[F```:````3>8``!,```!HY@``%0```'SF```1````DN8``!<```"D
MY@``%````+SF```7````T>8``!4```#IY@``"0```/_F```0````"><``!D`
M```:YP``!````#3G```'````.><```L```!!YP``$0```$WG```&````7^<`
M``8```!FYP``!@```&WG```%````=.<```<```!ZYP``!P```(+G```%````
MBN<``!8```"0YP``!@```*?G```&````KN<```0```"UYP``!````+KG```'
M````O^<```X```#'YP``#````-;G```,````X^<```T```#PYP``"@```/[G
M```.````">@```4````8Z```*````![H```.````1^@```P```!6Z```#P``
M`&/H```*````<^@```@```!^Z```"0```(?H```K````D>@```0```"]Z```
M"````,+H```F````R^@``!(```#RZ```#P````7I```&````%>D```H````<
MZ0``!P```"?I```(````+^D``"`````XZ0``"0```%GI```4````8^D```P`
M``!XZ0``#0```(7I```.````D^D``!8```"BZ0``$0```+GI```&````R^D`
M``,```#2Z0``!@```-;I```9````W>D```<```#WZ0``!````/_I```+````
M!.H```L````0Z@``!P```!SJ```%````).H```<````JZ@``%@```#+J```-
M````2>H```T```!7Z@``"@```&7J```0````<.H```\```"!Z@``$0```)'J
M```7````H^H```H```"[Z@``$0```,;J```(````V.H```0```#AZ@``"```
M`.;J```/````[^H```\```#_Z@``"P````_K```)````&^L``#H````EZP``
M%````&#K```%````=>L```P```![ZP``'@```(CK```.````I^L``!````"V
MZP``"P```,?K```,````T^L```D```#@ZP``!P```.KK```*````\NL```D`
M``#]ZP``#@````?L```0````%NP``!L````G[```&````$/L```:````7.P`
M``H```!W[```"0```(+L```*````C.P```P```"7[```#P```*3L```(````
MM.P```8```"][```'````,3L```'````X>P```4```#I[```"P```._L``!'
M````^^P```T```!#[0``"0```%'M```$````6^T```,```!@[0``$P```&3M
M```3````>.T``!,```",[0``"@```*#M```"````J^T```0```"N[0``)0``
M`+/M```#````V>T```4```#=[0``*@```./M```*````#NX```4````9[@``
M!````!_N```*````).X```T````O[@``!@```#WN```(````1.X```@```!-
M[@``!````%;N```%````6^X``&@```!A[@``"0```,KN```,````U.X``!``
M``#A[@``!0```/+N```&````^.X``!L```#_[@``+P```!OO```0````2^\`
M``H```!<[P``#P```&?O```*````=^\```D```""[P``$P```(SO```;````
MH.\``!@```"\[P``%P```-7O```?````[>\```X````-\````P```!SP```'
M````(/````@````H\```!P```#'P```*````.?````L```!$\```!P```%#P
M``!1````6/```!````"J\```#````+OP```-````R/```!H```#6\```2@``
M`/'P```9````//$```8```!6\0``&@```%WQ```E````>/$```8```">\0``
M!@```*7Q```?````K/$```8```#,\0``"0```-/Q```8````W?$``!<```#V
M\0``*`````[R```&````-_(```T````^\@``(@```$SR``!7````;_(``!,`
M``#'\@``(P```-OR```3````__(```(````3\P``"P```!;S```(````(O,`
M``T````K\P``"@```#GS```'````1/,``!0```!,\P``!@```&'S```(````
M:/,```X```!Q\P``!P```(#S```*````B/,```L```"3\P``,@```)_S```'
M````TO,```P```#:\P``#0```.?S```7````]?,```P````-]```"0```!KT
M```)````)/0```H````N]```!P```#GT```)````0?0```<```!+]```"@``
M`%/T```;````7O0```\```!Z]```$@```(KT```*````G?0``!8```"H]```
M"0```+_T```0````R?0```<```#:]```$@```.+T```$````]?0```<```#Z
M]```!0````+U```%````"/4```L````.]0``%````!KU```1````+_4``!H`
M``!!]0``%@```%SU```4````<_4``!<```"(]0``&````*#U```<````N?4`
M`!D```#6]0``!P```/#U```%````^/4```T```#^]0``#`````SV```(````
M&?8``!<````B]@``"P```#KV```,````1O8``!\```!3]@``&@```'/V```3
M````CO8```0```"B]@``"@```*?V```$````LO8```T```"W]@``#````,7V
M```%````TO8```D```#8]@``!0```.+V```'````Z/8```4```#P]@``!```
M`/;V```"````^_8``#@```#^]@``+````#?W```2````9/<``"D```!W]P``
M,@```*'W```*````U/<``"P```#?]P``+@````SX```S````._@``#,```!O
M^```.````*/X```/````W/@``!@```#L^```$`````7Y```/````%OD``!,`
M```F^0``%0```#KY```4````4/D``!(```!E^0``%````'CY```5````C?D`
M`"T```"C^0``+0```-'Y```Q````__D``"X````Q^@``+P```&#Z```L````
MD/H``&(```"]^@``$P```"#[```-````-/L```@```!"^P``%P```$O[```(
M````8_L```P```!L^P``*P```'G[```A````I?L``!H```#'^P``"0```.+[
M``!%````[/L``$$````R_```!````'3\```3````>?P``!0```"-_```#@``
M`*+\```3````L?P``!@```#%_```!@```-[\```)````Y?P```H```#O_```
M#P```/K\```*````"OT``!`````5_0``!P```";]```.````+OT```4````]
M_0``&P```$/]```(````7_T```8```!H_0``%````&_]```1````A/T```X`
M``"6_0``.````*7]```"````WOT```8```#A_0``#@```.C]```%````]_T`
M``<```#]_0``#@````7^```&````%/X``"@````;_@``#````$3^```<````
M4?X```0```!N_@``#0```'/^```I````@?X``!<```"K_@``'P```,/^``!<
M````X_X``!0```!`_P``/@```%7_```?````E/\``!````"T_P``!P```,7_
M```.````S?\```P```#<_P``#````.G_```3````]O\```H````*``$`'0``
M`!4``0`9````,P`!``4```!-``$`$0```%,``0`1````90`!`"0```!W``$`
M$@```)P``0`5````KP`!`!(```#%``$`#@```-@``0`9````YP`!``@````!
M`0$`"0````H!`0`-````%`$!``<````B`0$`"@```"H!`0`'````-0$!``\`
M```]`0$`!@```$T!`0`+````5`$!`!H```!@`0$`"@```'L!`0`'````A@$!
M``@```".`0$`!0```)<!`0`?````G0$!``8```"]`0$`$````,0!`0`(````
MU0$!``T```#>`0$`"````.P!`0`>````]0$!`!(````4`@$`+````"<"`0`:
M````5`(!``D```!O`@$`"@```'D"`0`5````A`(!``4```":`@$`%````*`"
M`0`$````M0(!`!````"Z`@$`!@```,L"`0`'````T@(!`!X```#:`@$`*```
M`/D"`0`*````(@,!`!P````M`P$`$0```$H#`0`+````7`,!`!H```!H`P$`
M%````(,#`0`$````F`,!``0```"=`P$`"P```*(#`0`%````K@,!``8```"T
M`P$`"````+L#`0`&````Q`,!``H```#+`P$`&P```-8#`0`T````\@,!`#0`
M```G!`$`(````%P$`0`I````?00!`"````"G!`$`00```,@$`0`:````"@4!
M`"@````E!0$`*0```$X%`0!0````>`4!`"(```#)!0$`!@```.P%`0`(````
M\P4!``4```#\!0$`"`````(&`0`9````"P8!`!D````E!@$`*@```#\&`0`C
M````:@8!`!D```".!@$`+@```*@&`0`T````UP8!``@````,!P$`%P```!4'
M`0`*````+0<!``<````X!P$`(0```$`'`0`0````8@<!``X```!S!P$`"P``
M`(('`0`'````C@<!`!,```"6!P$`"````*H'`0`+````LP<!``H```"_!P$`
M%````,H'`0`/````WP<!`#(```#O!P$`"P```"((`0`.````+@@!``4````]
M"`$`!0```$,(`0`%````20@!`!<```!/"`$`#P```&<(`0`$````=P@!``H`
M``!\"`$`"0```(<(`0`+````D0@!``T```"="`$`#````*L(`0`.````N`@!
M``4```#'"`$`!````,T(`0`-````T@@!`#(```#@"`$`10```!,)`0`7````
M60D!``<```!Q"0$`'@```'D)`0`4````F`D!``4```"M"0$`%````+,)`0`&
M````R`D!``<```#/"0$`#@```-<)`0`J````Y@D!``8````1"@$`#````!@*
M`0`-````)0H!`!$````S"@$`"P```$4*`0`V````40H!``H```"("@$`(@``
M`),*`0`+````M@H!``\```#""@$`,@```-(*`0`E````!0L!`#`````K"P$`
M,0```%P+`0`M````C@L!``X```"\"P$`!0```,L+`0`.````T0L!`!,```#@
M"P$`$@```/0+`0`'````!PP!`!$````/#`$`$P```"$,`0`'````-0P!`!0`
M```]#`$`&````%(,`0`'````:PP!``4```!S#`$`#````'D,`0`,````A@P!
M`!(```"3#`$`!````*8,`0`'````JPP!``H```"S#`$`"P```+X,`0`,````
MR@P!``X```#7#`$`#@```.8,`0`%````]0P!``4```#[#`$`+@````$-`0`F
M````,`T!`",```!7#0$``P```'L-`0`2````?PT!``8```"2#0$`'@```)D-
M`0`8````N`T!`"4```#1#0$`#0```/<-`0`)````!0X!`!\````/#@$``P``
M`"\.`0`'````,PX!``H````[#@$``@```$8.`0`,````20X!`!4```!6#@$`
M"P```&P.`0`9````>`X!`"````"2#@$`$@```+,.`0`%````Q@X!``H```#,
M#@$`%0```-<.`0`2````[0X!``P`````#P$`!`````T/`0`)````$@\!``<`
M```<#P$`#````"0/`0!2````,0\!`!<```"$#P$`)````)P/`0`2````P0\!
M``<```#4#P$`!@```-P/`0`.````XP\!``P```#R#P$`#0```/\/`0`5````
M#1`!`!(````C$`$`#P```#80`0`4````1A`!``H```!;$`$`&P```&80`0`0
M````@A`!``L```"3$`$`:0```)\0`0`:````"1$!`!<````D$0$`)P```#P1
M`0`:````9!$!`!<```!_$0$`&P```)<1`0`9````LQ$!`!\```#-$0$`$P``
M`.T1`0`(`````1(!``<````*$@$`"````!(2`0`)````&Q(!`!4````E$@$`
M#0```#L2`0`C````21(!``T```!M$@$`$P```'L2`0`(````CQ(!``,```"8
M$@$`1@```)P2`0`_````XQ(!`#<````C$P$`5P```%L3`0`%````LQ,!`!\`
M``"Y$P$`+P```-D3`0`*````"10!``@````4%`$`#0```!T4`0`M````*Q0!
M``0```!9%`$`3P```%X4`0`E````KA0!`!P```#4%`$`"P```/$4`0`?````
M_10!`!T````=%0$`)0```#L5`0`@````814!`"0```""%0$`(````*<5`0`+
M````R!4!``<```#4%0$`#0```-P5`0`,````ZA4!`!<```#W%0$`!@````\6
M`0`Y````%A8!``P```!0%@$`!P```%T6`0`)````918!`!,```!O%@$`"0``
M`(,6`0`$````C18!`!````"2%@$`"````*,6`0`(````K!8!``0```"U%@$`
M"P```+H6`0`,````QA8!`!(```#3%@$`$0```.86`0`,````^!8!`!H````%
M%P$`#P```"`7`0`'````,!<!``T````X%P$`%````$87`0`.````6Q<!``P`
M``!J%P$`&P```'<7`0`L````DQ<!`!,```#`%P$`'````-07`0`H````\1<!
M``8````:&`$`!P```"$8`0`3````*1@!``4````]&`$`!````$,8`0`7````
M2!@!``H```!@&`$`#````&L8`0`)````>!@!``8```""&`$`"0```(D8`0`(
M````DQ@!``D```"<&`$`"@```*88`0`1````L1@!``8```##&`$`#@```,H8
M`0`.````V1@!``T```#H&`$`"P```/88`0`=`````AD!``L````@&0$``@``
M`"P9`0`<````+QD!``<```!,&0$`!@```%09`0!D````6QD!``D```#`&0$`
M!P```,H9`0`F````TAD!`#@```#Y&0$`&@```#(:`0`J````31H!`#L```!X
M&@$`*````+0:`0`T````W1H!`!D````2&P$`%0```"P;`0`%````0AL!``<`
M``!(&P$`"````%`;`0`'````61L!``4```!A&P$`!P```&<;`0`.````;QL!
M``D```!^&P$`!@```(@;`0`(````CQL!``L```"8&P$`!P```*0;`0`(````
MK!L!``<```"U&P$`%@```+T;`0`)````U!L!``8```#>&P$`"P```.4;`0`0
M````\1L!`!P````"'`$`%````!\<`0`'````-!P!`!$````\'`$`"````$X<
M`0`.````5QP!``@```!F'`$`$````&\<`0`)````@!P!`!````"*'`$`!@``
M`)L<`0`9````HAP!``H```"\'`$`'````,<<`0`'````Y!P!``4```#L'`$`
M$````/(<`0`4`````QT!``L````8'0$`#0```"0=`0`H````,AT!`!@```!;
M'0$`%P```'0=`0`$````C!T!``D```"1'0$`"@```)L=`0`'````IAT!``(`
M``"N'0$`#@```+$=`0`(````P!T!`",```#)'0$`'P```.T=`0`X````#1X!
M`"8```!&'@$`,0```&T>`0`G````GQX!`&0```#''@$`%````"P?`0!5````
M01\!`#@```"7'P$`2@```-`?`0!;````&R`!`"@```!W(`$`.````*`@`0`H
M````V2`!`"P````"(0$`&P```"\A`0`^````2R$!`*D!``"*(0$`(P```#0C
M`0`7````6",!`$@```!P(P$`A0```+DC`0`P````/R0!`"4```!P)`$`00``
M`)8D`0!;````V"0!`$D````T)0$`,0```'XE`0`=````L"4!`!@```#.)0$`
M*P```.<E`0`A````$R8!`!\````U)@$`*P```%4F`0`F````@28!`"<```"H
M)@$`.@```-`F`0`=````"R<!`!$````I)P$`,P```#LG`0`E````;R<!`"<`
M``"5)P$`(````+TG`0`?````WB<!`#````#^)P$`:0```"\H`0`Q````F2@!
M`$$```#+*`$`,P````TI`0`E````02D!`#T```!G*0$`90```*4I`0!-````
M"RH!`"\```!9*@$`+@```(DJ`0`P````N"H!`%0```#I*@$`6@```#XK`0!(
M````F2L!`$H```#B*P$`,@```"TL`0`O````8"P!`"P```"0+`$`+0```+TL
M`0!Q````ZRP!`&8```!=+0$`;P```,0M`0"S````-"X!`!<```#H+@$`)0``
M```O`0`R````)B\!`"D```!9+P$`/@```(,O`0`B````PB\!`%(```#E+P$`
M)0```#@P`0`+````7C`!`+$```!J,`$`10```!PQ`0`A````8C$!`#````"$
M,0$`)0```+4Q`0`<````VS$!`#$```#X,0$`!P```"HR`0`'````,C(!``0`
M```Z,@$`#0```#\R`0`+````33(!``X```!9,@$`"P```&@R`0`%````=#(!
M`!````!Z,@$``@```(LR`0!9````CC(!``4```#H,@$`$@```.XR`0`$````
M`3,!``<````&,P$`"`````XS`0`%````%S,!`#`````=,P$``P```$XS`0`0
M````4C,!``P```!C,P$`$P```'`S`0`-````A#,!``(```"2,P$`!P```)4S
M`0`&````G3,!`!0```"D,P$`#````+DS`0`8````QC,!``8```#?,P$`$@``
M`.8S`0`,````^3,!``,````&-`$`*@````HT`0`$````-30!``8````Z-`$`
M!P```$$T`0`?````230!`#4```!I-`$`+@```)\T`0`O````SC0!`!<```#^
M-`$`(@```!8U`0`E````.34!`"````!?-0$`&P```(`U`0`8````G#4!`"0`
M``"U-0$`'P```-HU`0`:````^C4!`"$````5-@$`(````#<V`0`:````6#8!
M`#(```!S-@$`&@```*8V`0`O````P38!`"L```#Q-@$`'P```!TW`0`C````
M/3<!`!\```!A-P$`&@```($W`0`A````G#<!`"4```"^-P$`)@```.0W`0`E
M````"S@!`"0````Q.`$`&````%8X`0`=````;S@!`"0```"-.`$`&````+(X
M`0`B````RS@!`"P```#N.`$`*````!LY`0`5````1#D!`"4```!:.0$`/```
M`(`Y`0`?````O3D!`",```#=.0$`'P````$Z`0`@````(3H!`!H```!".@$`
M&````%TZ`0`F````=CH!`"D```"=.@$`'@```,<Z`0`I````YCH!`!X````0
M.P$`,0```"\[`0`)````83L!``P```!K.P$`%P```'@[`0`O````D#L!`"0`
M``#`.P$`!P```.4[`0`/````[3L!`!0```#].P$`#@```!(\`0`-````(3P!
M`"0````O/`$`!0```%0\`0`'````6CP!`"(```!B/`$`)0```(4\`0`:````
MJSP!`!T```#&/`$`&@```.0\`0`'````_SP!`,<````'/0$`"P```,\]`0`5
M````VST!``8```#Q/0$`"0```/@]`0`+`````CX!``T````./@$`%P```!P^
M`0`&````-#X!`#,````[/@$`$P```&\^`0`3````@SX!``<```"7/@$`#P``
M`)\^`0`'````KSX!`#(```"W/@$`!````.H^`0`A````[SX!`!,````1/P$`
M#````"4_`0`1````,C\!`#(```!$/P$`%@```'<_`0`(````CC\!`!T```"7
M/P$`"0```+4_`0`*````OS\!`!0```#*/P$`"@```-\_`0`=````ZC\!``@`
M```(0`$`'P```!%``0`(````,4`!`!H````Z0`$`)P```%5``0`&````?4`!
M`!4```"$0`$`!P```)I``0`(````HD`!``D```"K0`$`/P```+5``0`'````
M]4`!``\```#]0`$`#@````U!`0`0````'$$!``D````M00$`"0```#=!`0`(
M````04$!`!,```!*00$`!P```%Y!`0`9````9D$!``H```"`00$`%P```(M!
M`0`4````HT$!``H```"X00$`#````,-!`0`7````T$$!``0```#H00$`*@``
M`.U!`0`,````&$(!`!$````E0@$`!P```#="`0`"````/T(!`!````!"0@$`
M&````%-"`0`+````;$(!``,```!X0@$`"````'Q"`0`&````A4(!``<```",
M0@$`#0```)1"`0`+````HD(!`!0```"N0@$`%0```,-"`0`.````V4(!`"\`
M``#H0@$`(````!A#`0`<````.4,!`!4```!60P$`#````&Q#`0`Q````>4,!
M``4```"K0P$`$@```+%#`0`_````Q$,!`!(````$1`$`"@```!=$`0`&````
M(D0!``0````I1`$`!````"Y$`0`*````,T0!`!,````^1`$`!0```%)$`0`&
M````6$0!``8```!?1`$`"````&9$`0`$````;T0!``P```!T1`$`"@```(%$
M`0`Y````C$0!`"X```#&1`$`*0```/5$`0`%````'T4!`!@````E10$`&0``
M`#Y%`0`?````6$4!`!T```!X10$`$0```)9%`0`"````J$4!``0```"K10$`
M"@```+!%`0`&````NT4!``4```#"10$``P```,A%`0`,````S$4!`$4```#9
M10$`,@```!]&`0`:````4D8!`#0```!M1@$`*````*)&`0!3````RT8!`!D`
M```?1P$`<@```#E'`0`@````K$<!`#4```#-1P$`(0````-(`0!%````)4@!
M`#````!K2`$`*````)Q(`0`I````Q4@!`"8```#O2`$`)0```!9)`0`H````
M/$D!`"@```!E20$`(@```(Y)`0`K````L4D!`#````#=20$`$@````Y*`0`3
M````(4H!`!`````U2@$`>0```$9*`0`)````P$H!`*$```#*2@$`<P```&Q+
M`0!\````X$L!`"L```!=3`$`5````(E,`0`7````WDP!`"<```#V3`$`%@``
M`!Y-`0`/````-4T!`!<```!%30$`'P```%U-`0!`````?4T!`!\```"^30$`
M'````-Y-`0!1````^TT!`!H```!-3@$`%````&A.`0`*````?4X!``4```"(
M3@$`!@```(Y.`0`(````E4X!``4```">3@$`$@```*1.`0`0````MTX!`!,`
M``#(3@$`'0```-Q.`0`/````^DX!``\````*3P$`!````!I/`0`)````'T\!
M``L````I3P$`!P```#5/`0`4````/4\!``<```!23P$`"````%I/`0`/````
M8T\!``@```!S3P$`#````'Q/`0`/````B4\!``8```"93P$`%````*!/`0`&
M````M4\!``P```"\3P$`$0```,E/`0`(````VT\!``0```#D3P$`&0```.E/
M`0`1`````U`!``H````54`$`&````"!0`0`3````.5`!`!P```!-4`$`$0``
M`&I0`0`$````?%`!``\```"!4`$`!P```)%0`0`$````F5`!`!D```">4`$`
M!P```+A0`0`"````P%`!``(```##4`$`$0```,90`0`)````V%`!``8```#B
M4`$`$@```.E0`0`7````_%`!``8````440$`)P```!M1`0`"````0U$!``0`
M``!&40$`#P```$M1`0`3````6U$!``<```!O40$`!P```'=1`0`1````?U$!
M``8```"140$`&````)A1`0`&````L5$!`!,```"X40$`$````,Q1`0`2````
MW5$!``(```#P40$`!@```/-1`0`,````^E$!``D````'4@$`$0```!%2`0`B
M````(U(!``<```!&4@$`!P```$Y2`0`+````5E(!``4```!B4@$``@```&A2
M`0`+````:U(!`%@!``!W4@$`#P```-!3`0`3````X%,!``X```#T4P$`"```
M``-4`0`)````#%0!``H````65`$`!0```"%4`0`:````)U0!`!\```!"5`$`
M,@```&)4`0`P````E50!`"D```#&5`$`*````/!4`0`>````&54!`#,````X
M50$`#````&Q5`0`G````>54!`!(```"A50$`#````+15`0`0````P54!``4`
M``#250$`(0```-A5`0`0````^E4!`!`````+5@$`%@```!Q6`0`5````,U8!
M``P```!)5@$`A0```%96`0`0````W%8!``H```#M5@$`$@```/A6`0`0````
M"U<!``X````<5P$`#````"M7`0`.````.%<!`!$```!'5P$`!@```%E7`0#!
M````8%<!``<````B6`$`"P```"I8`0`:````-E@!``\```!16`$`$0```&%8
M`0`1````<U@!``H```"%6`$`!P```)!8`0`L````F%@!`"0```#%6`$`50``
M`.I8`0!A````0%D!`'D```"B60$`>````!Q:`0!\````E5H!`'L````26P$`
M6````(Y;`0`1````YUL!`!D```#Y6P$`'@```!-<`0`0````,EP!`!(```!#
M7`$`&````%9<`0`%````;UP!``8```!U7`$`$@```'Q<`0`'````CUP!``T`
M``"77`$`#0```*5<`0`W````LUP!`"X```#K7`$`$@```!I=`0`-````+5T!
M`!(````[70$`"P```$Y=`0`*````6ET!`!L```!E70$`&P```(%=`0`0````
MG5T!`!4```"N70$`%@```,1=`0`6````VUT!`!X```#R70$`'@```!%>`0`E
M````,%X!`!$```!67@$`#P```&A>`0`J````>%X!`!H```"C7@$`'P```+Y>
M`0`3````WEX!`'H```#R7@$`0@```&U?`0`O````L%\!``<```#@7P$`"@``
M`.A?`0`P````\U\!``X````D8`$`!P```#-@`0`+````.V`!``@```!'8`$`
M"````%!@`0`)````66`!``L```!C8`$`#````&]@`0`$````?&`!`!0```"!
M8`$`#````)9@`0`+````HV`!`!````"O8`$`&0```,!@`0`F````VF`!`!$`
M```!80$`&@```!-A`0`:````+F$!`!X```!)80$`&@```&AA`0`4````@V$!
M`!(```"880$`$@```*MA`0`G````OF$!`"<```#F80$`!P````YB`0`&````
M%F(!``@````=8@$`#@```"9B`0`'````-6(!``D````]8@$`$P```$=B`0`)
M````6V(!``\```!E8@$`%0```'5B`0`8````BV(!``H```"D8@$`#P```*]B
M`0`%````OV(!`!<```#%8@$`"P```-UB`0`*````Z6(!`$L```#T8@$`10``
M`$!C`0`+````AF,!``@```"28P$`%0```)MC`0`%````L6,!``4```"W8P$`
M$````+UC`0`+````SF,!`!<```#:8P$`+@```/)C`0`0````(60!`#T````R
M9`$`/````'!D`0`_````K60!`#\```#M9`$`"0```"UE`0`&````-V4!``H`
M```^90$`"@```$EE`0!!````5&4!`#T```"690$`0````-1E`0!Q````%68!
M`#\```"'9@$`0P```,=F`0!3````"V<!`%````!?9P$`/P```+!G`0!1````
M\&<!`#,```!":`$`-P```'9H`0!7````KF@!`#\````&:0$`0P```$9I`0`J
M````BFD!`"````"U:0$`'````-9I`0`]````\VD!`"D````Q:@$`*0```%MJ
M`0`2````A6H!``T```"8:@$`#0```*9J`0`+````M&H!`!````#`:@$`&P``
M`-%J`0`?````[6H!``<````-:P$`!P```!5K`0`6````'6L!``L````T:P$`
M"````$!K`0`M````26L!``H```!W:P$`"@```()K`0`'````C6L!``8```"5
M:P$`!0```)QK`0`(````HFL!``8```"K:P$`"@```+)K`0`M````O6L!`!(`
M``#K:P$`"````/YK`0`$````!VP!``@````,;`$`"P```!5L`0`$````(6P!
M``P````F;`$`!@```#-L`0`3````.FP!``8```!.;`$`"````%5L`0`%````
M7FP!``L```!D;`$`"0```'!L`0`I````>FP!`!$```"D;`$`"0```+9L`0`3
M````P&P!``P```#4;`$`!P```.%L`0`#````Z6P!``,```#M;`$`%P```/%L
M`0`7````"6T!`#<````A;0$`"````%EM`0`)````8FT!``H```!L;0$`!P``
M`'=M`0`Z````?VT!`#P```"Z;0$`*@```/=M`0`&````(FX!``D````I;@$`
M&````#-N`0!.````3&X!`"P```";;@$`)0```,AN`0!2````[FX!`#8```!!
M;P$`,@```'AO`0`S````JV\!`)$```#?;P$`8P```'%P`0!(````U7`!`"P`
M```><0$`"0```$MQ`0`+````57$!``@```!A<0$`'0```&IQ`0`-````B'$!
M``P```"6<0$`$P```*-Q`0`-````MW$!`!,```#%<0$`#@```-EQ`0`,````
MZ'$!`!8```#U<0$`"0````QR`0`<````%G(!`!T````S<@$`$0```%%R`0`2
M````8W(!`!4```!V<@$`!@```(QR`0`&````DW(!`!<```":<@$`@P```+)R
M`0![````-G,!``<```"R<P$`$P```+IS`0`%````SG,!``4```#4<P$`'P``
M`-IS`0`>````^G,!`!0````9=`$`%P```"YT`0`>````1G0!`#0```!E=`$`
M+P```)IT`0`/````RG0!`"@```#:=`$`!@````-U`0`8````"G4!`!0````C
M=0$`&0```#AU`0`5````4G4!`!4```!H=0$`$0```'YU`0`*````D'4!`!,`
M``";=0$`$0```*]U`0`&````P74!``L```#(=0$`!P```-1U`0`+````W'4!
M``X```#H=0$`%P```/=U`0`)````#W8!``4````9=@$`"P```!]V`0`(````
M*W8!``@````T=@$`%````#UV`0`&````4G8!``8```!9=@$`#````&!V`0`)
M````;78!`!````!W=@$`!P```(AV`0`%````D'8!``@```"6=@$`"P```)]V
M`0`+````JW8!`!H```"W=@$`*P```-)V`0`0````_G8!`!,````/=P$`!0``
M`"-W`0`<````*7<!`!H```!&=P$`&P```&%W`0`]````?7<!`$P```"[=P$`
M*`````AX`0`(````,7@!`#T````Z>`$`)````'AX`0`/````G7@!``8```"M
M>`$`"P```+1X`0`&````P'@!``@```#'>`$`&P```-!X`0`0````['@!``D`
M``#]>`$`"@````=Y`0`.````$GD!`#D````A>0$`.0```%MY`0`[````E7D!
M`#L```#1>0$`*P````UZ`0`J````.7H!`"P```!D>@$`*@```)%Z`0!"````
MO'H!`"\```#_>@$`+@```"][`0`P````7GL!`"@```"/>P$`+P```+A[`0`\
M````Z'L!`$`````E?`$`-````&9\`0`Q````FWP!`#D```#-?`$`+P````=]
M`0`R````-WT!`$8```!J?0$`,````+%]`0`?````XGT!`#H````"?@$`+@``
M`#U^`0`[````;'X!`!\```"H?@$`W````,A^`0`?````I7\!`"X```#%?P$`
M,0```/1_`0`R````)H`!`#4```!9@`$`,````(^``0`N````P(`!`#$```#O
M@`$`.0```"&!`0`\````6X$!`$0```"8@0$`/````-V!`0#%````&H(!`"\`
M``#@@@$`(@```!"#`0`O````,X,!`#,```!C@P$`/@```)>#`0!D````UH,!
M`%T````[A`$`#@```)F$`0`$````J(0!``4```"MA`$`"0```+.$`0`.````
MO80!`!8```#,A`$`%0```..$`0`/````^80!`!(````)A0$`"````!R%`0`$
M````)84!`!$````JA0$`$0```#R%`0`-````3H4!`!````!<A0$`$0```&V%
M`0`0````?X4!`!@```"0A0$`#@```*F%`0!1````N(4!``P````*A@$`%```
M`!>&`0`&````+(8!`!,````SA@$`&0```$>&`0`>````888!`!4```"`A@$`
M`@```):&`0!+````F88!``<```#EA@$`$````.V&`0`0````_H8!``4````/
MAP$`#0```!6'`0`-````(X<!``,````QAP$`#P```#6'`0`(````18<!``8`
M``!.AP$`$0```%6'`0`(````9X<!``T```!PAP$`$0```'Z'`0`-````D(<!
M``P```">AP$`!P```*N'`0`-````LX<!``X```#!AP$`"P```-"'`0`.````
MW(<!`"$```#KAP$`#0````V(`0`.````&X@!`"8````JB`$`$P```%&(`0`7
M````98@!`"T```!]B`$`#0```*N(`0`=````N8@!`!,```#7B`$`&P```.N(
M`0`:````!XD!`"X````BB0$`$0```%&)`0`(````8XD!`!L```!LB0$`#```
M`(B)`0`B````E8D!`#````"XB0$`"P```.F)`0`(````]8D!`!T```#^B0$`
M"@```!R*`0`5````)XH!`!4````]B@$`"P```%.*`0`C````7XH!`!4```"#
MB@$`'P```)F*`0`9````N8H!``T```#3B@$`$P```.&*`0`)````]8H!``T`
M``#_B@$`+P````V+`0!1````/8L!``@```"/BP$`%P```)B+`0`B````L(L!
M``T```#3BP$`$````.&+`0`T````\HL!``P````GC`$`!@```#2,`0`&````
M.XP!`$P```!"C`$`!@```(^,`0`'````EHP!``H```">C`$`$````*F,`0`1
M````NHP!`!$```#,C`$`$0```-Z,`0`:````\(P!`!T````+C0$`&@```"F-
M`0`8````1(T!``<```!=C0$`!P```&6-`0`+````;8T!``H```!YC0$``@``
M`(2-`0`&````AXT!``X```".C0$`)P```)V-`0`>````Q8T!`!<```#DC0$`
M!P```/R-`0`0````!(X!`!`````5C@$`%````":.`0`[````.XX!`"<```!W
MC@$`!P```)^.`0`1````IXX!`)<```"YC@$`&0```%&/`0`C````:X\!`!$`
M``"/CP$`!P```*&/`0`&````J8\!`"8```"PCP$`,@```->/`0`P````"I`!
M`"0````[D`$`)````&"0`0`?````A9`!`!\```"ED`$`!P```,60`0`)````
MS9`!``D```#7D`$`!@```.&0`0`/````Z)`!``X```#XD`$`$`````>1`0`.
M````&)$!`!,````GD0$`$0```#N1`0`0````39$!``X```!>D0$`"0```&V1
M`0`*````=Y$!``P```""D0$`/0```(^1`0`-````S9$!``@```#;D0$`$```
M`.21`0`C````]9$!`#,````9D@$`)P```$V2`0`F````=9(!`"\```"<D@$`
M*0```,R2`0`V````]I(!`"P````MDP$`%0```%J3`0`&````<),!``X```!W
MDP$`!@```(:3`0`0````C9,!``,```">DP$`!````**3`0`'````IY,!`!,`
M``"ODP$`%0```,.3`0`3````V9,!`!D```#MDP$`"@````>4`0`.````$I0!
M``L````AE`$`!P```"V4`0`%````-90!`!`````[E`$`$@```$R4`0`,````
M7Y0!``D```!LE`$`#````':4`0`/````@Y0!`#$```"3E`$`!@```,64`0`(
M````S)0!``P```#5E`$`#@```.*4`0`7````\90!``@````)E0$`"````!*5
M`0`%````&Y4!`"(````AE0$`#````$25`0`%````494!`"H```!7E0$`$```
M`(*5`0!Q````DY4!`!,````%E@$`"0```!F6`0`*````(Y8!``T````NE@$`
M"P```#R6`0`-````2)8!``4```!6E@$`#0```%R6`0`"````:I8!``8```!M
ME@$`"@```'26`0`7````?Y8!`!(```"7E@$`$P```*J6`0`6````OI8!`#$`
M``#5E@$``P````>7`0`$````"Y<!`!D````0EP$`"````"J7`0`2````,Y<!
M``4```!&EP$`&0```$R7`0`(````9I<!``8```!OEP$`&0```':7`0`.````
MD)<!``@```"?EP$`"P```*B7`0`%````M)<!``D```"ZEP$`!P```,27`0`8
M````S)<!``,```#EEP$`!@```.F7`0`+````\)<!``P```#\EP$`"@````F8
M`0`,````%)@!`!<````AF`$`"````#F8`0`'````0I@!`!$```!*F`$`(P``
M`%R8`0!0````@)@!`#8```#1F`$`.@````B9`0`'````0YD!``H```!+F0$`
M!````%:9`0`)````6YD!``@```!EF0$`"@```&Z9`0`)````>9D!``8```"#
MF0$`#0```(J9`0`&````F)D!``0```"?F0$`.P```*29`0`^````X)D!`#T`
M```?F@$`)@```%V:`0`%````A)H!`!````"*F@$`!@```)N:`0`+````HIH!
M``P```"NF@$`&0```+N:`0`0````U9H!`!@```#FF@$`!````/^:`0`%````
M!)L!``L````*FP$`!0```!:;`0`*````')L!`!X````GFP$`!````$:;`0`+
M````2YL!``P```!7FP$`#@```&2;`0`/````<YL!``X```"#FP$`"````)*;
M`0`)````FYL!``4```"EFP$`,P```*N;`0`S````WYL!`#P````3G`$`+P``
M`%"<`0!.````@)P!`$@```#/G`$`-0```!B=`0!6````3IT!`#L```"EG0$`
M3````.&=`0`P````+IX!`!$```!?G@$`&0```'&>`0`+````BYX!`$,```"7
MG@$`+P```-N>`0`B````"Y\!`"X````NGP$`$````%V?`0`2````;I\!``<`
M``"!GP$`!@```(F?`0`Q````D)\!`#$```#"GP$`.````/2?`0`*````+:`!
M`!L````XH`$`*0```%2@`0`?````?J`!`!,```">H`$`!@```+*@`0`*````
MN:`!``P```#$H`$`#P```-&@`0`9````X:`!`%\```#[H`$`?0```%NA`0!Z
M````V:$!``T```!4H@$`"````&*B`0`)````:Z(!`!````!UH@$`$0```(:B
M`0`.````F*(!``8```"GH@$`%P```*ZB`0`5````QJ(!`!,```#<H@$`%```
M`/"B`0`;````!:,!`"H````AHP$`EP```$RC`0`1````Y*,!``8```#VHP$`
M$0```/VC`0`*````#Z0!``L````:I`$`#0```":D`0`C````-*0!`!,```!8
MI`$`%@```&RD`0`/````@Z0!`!````"3I`$`#0```*2D`0`7````LJ0!`"P`
M``#*I`$`*P```/>D`0`K````(Z4!`"H```!/I0$`-@```'JE`0`U````L:4!
M`!P```#GI0$`40````2F`0`5````5J8!`!0```!LI@$`%@```(&F`0`5````
MF*8!`!8```"NI@$`%@```,6F`0`5````W*8!`!4```#RI@$`%`````BG`0`S
M````':<!`!@```!1IP$`&````&JG`0`[````@Z<!`!(```"_IP$`"````-*G
M`0`4````VZ<!`",```#PIP$`%````!2H`0`4````*:@!`!,````^J`$`&0``
M`%*H`0`6````;*@!`!8```"#J`$`&P```)JH`0`9````MJ@!`!0```#0J`$`
M'P```.6H`0`B````!:D!`!4````HJ0$`%0```#ZI`0`7````5*D!`!4```!L
MJ0$`&@```(*I`0`=````G:D!`!L```"[J0$`&````->I`0`(````\*D!`!``
M``#YJ0$`&`````JJ`0`$````(ZH!``8````HJ@$`"P```"^J`0`4````.ZH!
M``8```!0J@$`"@```%>J`0`&````8JH!``<```!IJ@$`!P```'&J`0`&````
M>:H!``4```"`J@$`%P```(:J`0`&````GJH!``D```"EJ@$`!````*^J`0`$
M````M*H!``D```"YJ@$`"@```,.J`0`)````SJH!`!````#8J@$`$0```.FJ
M`0`*````^ZH!`!4````&JP$`!0```!RK`0`U````(JL!``\```!8JP$`$@``
M`&BK`0`<````>ZL!``X```"8JP$`#````*>K`0`.````M*L!`$D```##JP$`
M!@````VL`0`(````%*P!`"$````=K`$`#@```#^L`0`3````3JP!``8```!B
MK`$`"P```&FL`0`)````=:P!``<```!_K`$`!````(>L`0`-````C*P!`!<`
M``":K`$`#P```+*L`0`6````PJP!`!0```#9K`$`&P```.ZL`0`:````"JT!
M``@````EK0$`!@```"ZM`0`&````-:T!`!T````\K0$`!P```%JM`0`%````
M8JT!`!$```!HK0$`"P```'JM`0`'````AJT!``4```".K0$`!P```)2M`0`&
M````G*T!``T```"CK0$`"@```+&M`0`.````O*T!`!,```#+K0$`%0```-^M
M`0`4````]:T!`!L````*K@$`$P```":N`0`5````.JX!``@```!0K@$`!```
M`%FN`0`(````7JX!`!(```!GK@$`$@```'JN`0`)````C:X!``D```"7K@$`
M&0```*&N`0`3````NZX!``4```#/K@$`$0```-6N`0`E````YZX!`!0````-
MKP$`%@```"*O`0`1````.:\!``T```!+KP$`#````%FO`0`)````9J\!``\`
M``!PKP$`#@```("O`0`0````CZ\!`!````"@KP$`,````+&O`0`P````XJ\!
M`"P````3L`$`"0```$"P`0`'````2K`!``<```!2L`$`$````%JP`0`0````
M:[`!``,```!\L`$`"````("P`0`@````B;`!``@```"JL`$`"````+.P`0`/
M````O+`!`&D```#,L`$`&0```#:Q`0`+````4+$!``4```!<L0$`!P```&*Q
M`0`:````:K$!`!H```"%L0$`$P```*"Q`0`)````M+$!``(```"^L0$`!```
M`,&Q`0`D````QK$!``<```#KL0$`!0```/.Q`0`O````^;$!``H````IL@$`
M!0```#2R`0`'````.K(!`!4```!"L@$`$````%BR`0`&````:;(!``@```!P
ML@$`"0```'FR`0`$````@[(!``4```"(L@$`=````(ZR`0`+`````[,!``X`
M```/LP$`&````!ZS`0`$````-[,!``P````\LP$`)@```$FS`0`U````<+,!
M``X```"FLP$`"@```+6S`0`2````P+,!``L```#3LP$`"0```-^S`0`9````
MZ;,!`"@````#M`$`*0```"RT`0`H````5K0!`"````!_M`$`#@```*"T`0`#
M````K[0!``X```"SM`$`!P```,*T`0`*````RK0!``H```#5M`$`%````."T
M`0`)````];0!`%H```#_M`$`'````%JU`0`.````=[4!``P```"&M0$`&P``
M`).U`0!,````K[4!`!T```#\M0$`!P```!JV`0`D````(K8!`#````!'M@$`
M"````'BV`0`&````@;8!`"(```"(M@$`!0```*NV`0`'````L;8!`"D```"Y
MM@$`*````..V`0`T````#+<!``@```!!MP$`#0```$JW`0`>````6+<!`&(`
M``!WMP$`&````-JW`0`6````\[<!`!4````*N`$``@```""X`0`,````([@!
M``4````PN`$`#@```#:X`0`.````1;@!``<```!4N`$`#P```%RX`0`&````
M;+@!``@```!SN`$`#@```'RX`0`)````B[@!``H```"5N`$`"@```*"X`0`W
M````J[@!``<```#CN`$`$@```.NX`0`3````_K@!`!X````2N0$`$@```#&Y
M`0`*````1+D!``H```!/N0$`"P```%JY`0`)````9KD!``H```!PN0$`"0``
M`'NY`0`(````A;D!`!\```".N0$`$0```*ZY`0`/````P+D!``H```#0N0$`
M"@```-NY`0`+````YKD!`!$```#RN0$`!0````2Z`0`9````"KH!``0````D
MN@$`!P```"FZ`0`%````,;H!``4````WN@$`"P```#VZ`0`8````2;H!`!(`
M``!BN@$`&0```'6Z`0`;````C[H!`"(```"KN@$`%@```,ZZ`0`7````Y;H!
M`!(```#]N@$`%@```!"[`0`(````)[L!``,````PNP$`#0```#2[`0`.````
M0KL!``<```!1NP$`'0```%F[`0`*````=[L!``X```""NP$`)@```)&[`0`K
M````N+L!`!8```#DNP$`"P```/N[`0`+````![P!``8````3O`$`$````!J\
M`0`5````*[P!``<```!!O`$`"0```$F\`0`%````4[P!``<```!9O`$`!@``
M`&&\`0`$````:+P!``0```!MO`$`0````'*\`0`Z````L[P!`!0```#NO`$`
M,P````.]`0`[````-[T!`!$```!SO0$`3````(6]`0`Z````TKT!`$L````-
MO@$`2P```%F^`0!1````I;X!`!<```#WO@$`&0````^_`0`7````*;\!`!4`
M``!!OP$`'0```%>_`0`3````=;\!`!H```")OP$`%````*2_`0`7````N;\!
M`!P```#1OP$`-P```.Z_`0`W````)L`!`#L```!>P`$`.````)K``0`Y````
MT\`!`#8````-P0$`=0```$3!`0`C````NL$!`"D```#>P0$`#`````C"`0`<
M````%<(!``P````RP@$`%````#_"`0`T````5,(!`"P```")P@$`,````+;"
M`0`+````Y\(!`%P```#SP@$`5@```%##`0`%````I\,!`!D```"MPP$`%@``
M`,?#`0`,````WL,!`!0```#KPP$`$@````#$`0`(````$\0!``H````<Q`$`
M"0```"?$`0`0````,<0!``\```!"Q`$`%````%+$`0`0````9\0!`!(```!X
MQ`$`!P```(O$`0`E````D\0!``@```"YQ`$`!````,+$`0`2````Q\0!`!(`
M``#:Q`$`$0```.W$`0`O````_\0!``(````OQ0$`!@```#+%`0`/````.<4!
M``D```!)Q0$`!P```%/%`0`<````6\4!``0```!XQ0$`.P```'W%`0`.````
MN<4!`!@```#(Q0$`!````.'%`0`-````YL4!`"\```#TQ0$`&0```"3&`0`@
M````/L8!`%X```!?Q@$`%P```+[&`0!'````UL8!`"D````>QP$`#0```$C'
M`0`-````5L<!`!0```!DQP$`$0```'G'`0`,````B\<!`!8```"8QP$`#```
M`*_'`0`=````O,<!`!8```#:QP$`"````/''`0`4````^L<!``X````/R`$`
M*@```![(`0`2````2<@!`!D```!<R`$`&````';(`0`:````C\@!`"L```"J
MR`$`"````-;(`0`)````W\@!`!D```#IR`$`$0````/)`0`3````%<D!`!(`
M```IR0$`&0```#S)`0`1````5LD!`!0```!HR0$`&P```'W)`0`*````F<D!
M``P```"DR0$`"````+')`0`%````NLD!`"$```#`R0$`!@```.+)`0`/````
MZ<D!``@```#YR0$`$0````+*`0`(````%,H!`!X````=R@$`$0```#S*`0`Y
M````3LH!`!@```"(R@$`"0```*'*`0`*````J\H!`"(```"VR@$`"````-G*
M`0`?````XLH!``0````"RP$`'`````?+`0`(````),L!``<````MRP$`'```
M`#7+`0`P````4LL!``8```"#RP$`(````(K+`0`2````J\L!``8```"^RP$`
M$````,7+`0`3````ULL!``0```#JRP$`"0```._+`0`+````^<L!``<````%
MS`$`!0````W,`0`(````$\P!``4````<S`$`"P```"+,`0`?````+LP!`#X`
M``!.S`$`3````(W,`0`G````VLP!`#8````"S0$`)P```#G-`0!5````8<T!
M`"<```"WS0$`-P```-_-`0`W````%\X!`(L```!/S@$`*````-O.`0`%````
M!,\!``<````*SP$`"````!+/`0`(````&\\!`!L````DSP$`'0```$#/`0`J
M````7L\!`"H```")SP$`)@```+3/`0!`````V\\!`$8````<T`$`"0```&/0
M`0`7````;=`!``L```"%T`$`"````)'0`0`X````FM`!`!8```#3T`$`$```
M`.K0`0`2````^]`!``@````.T0$`$P```!?1`0`(````*]$!``T````TT0$`
M%@```$+1`0`G````6=$!`"@```"!T0$`0P```*K1`0`+````[M$!`!T```#Z
MT0$`!0```!C2`0`'````'M(!`!@````FT@$`(P```#_2`0`,````8](!``4`
M``!PT@$`"@```';2`0`,````@=(!``P```".T@$`"P```)O2`0`:````I](!
M``H```#"T@$`"@```,W2`0`%````V-(!`!$```#>T@$`20```/#2`0!=````
M.M,!`!X```"8TP$`#````+?3`0`F````Q-,!`!P```#KTP$`$@````C4`0`3
M````&]0!``T````OU`$`"P```#W4`0`0````2=0!`"T```!:U`$`"0```(C4
M`0`-````DM0!``X```"@U`$`%@```*_4`0`,````QM0!`#X```#3U`$`"```
M`!+5`0`I````&]4!`!````!%U0$`%````%;5`0!%````:]4!`#,```"QU0$`
M-P```.75`0`T````'=8!`#````!2U@$`$````(/6`0`,````E-8!`!4```"A
MU@$`'@```+?6`0`7````UM8!``H```#NU@$`%P```/G6`0`>````$=<!``<`
M```PUP$`&@```#C7`0`<````4]<!``8```!PUP$`!@```'?7`0`2````?M<!
M``P```"1UP$`%P```)[7`0`%````MM<!``@```"\UP$`#@```,77`0`1````
MU-<!`!(```#FUP$`$P```/G7`0`3````#=@!``<````AV`$`!@```"G8`0`H
M````,-@!`!L```!9V`$`&@```'78`0`'````D-@!`!4```"8V`$`!@```*[8
M`0`C````M=@!`",```#9V`$`*P```/W8`0`+````*=D!``D````UV0$`(P``
M`#_9`0`#````8]D!``8```!GV0$`"@```&[9`0`"````>=D!``P```!\V0$`
M%0```(G9`0`+````G]D!`!D```"KV0$`(````,79`0`7````YMD!``4```#^
MV0$`"@````3:`0`5````#]H!`!(````EV@$`#0```#C:`0`)````1MH!``X`
M``!0V@$`#````%_:`0`7````;-H!`%@```"$V@$`'0```-W:`0`T````^]H!
M`!0````PVP$`#````$7;`0`%````4ML!``T```!8VP$`$0```&;;`0`/````
M>-L!`"````"(VP$`&````*G;`0`0````PML!`"(```#3VP$`#@```/;;`0`F
M````!=P!`!`````LW`$`$````#W<`0"1````3MP!`"(```#@W`$`'`````/=
M`0`Q````(-T!`"````!2W0$`&@```'/=`0`L````CMT!`!H```"[W0$`(P``
M`-;=`0`9````^MT!``\````4W@$`!P```"3>`0`(````+-X!``D````UW@$`
M%@```#_>`0`,````5MX!`"H```!CW@$`$@```([>`0`6````H=X!``D```"X
MW@$`#````,+>`0![````S]X!`%0```!+WP$`10```*#?`0!P````YM\!``T`
M``!7X`$`)0```&7@`0`L````B^`!``H```"XX`$`!P```,/@`0`5````R^`!
M`$(```#AX`$`!@```"3A`0!4````*^$!`#````"`X0$`(@```+'A`0`2````
MU.$!`"4```#GX0$`*@````WB`0`O````..(!`"D```!HX@$`+P```)+B`0`E
M````PN(!`!4```#HX@$`!P```/[B`0`,````!N,!``X````3XP$`%P```"+C
M`0`+````.N,!`#T```!&XP$`#````(3C`0`,````D>,!``@```">XP$`$P``
M`*?C`0`(````N^,!``4```#$XP$`'0```,KC`0`(````Z.,!``D```#QXP$`
M!@```/OC`0`-`````N0!``T````0Y`$`$@```![D`0`4````,>0!``P```!&
MY`$`&````%/D`0`-````;.0!``@```!ZY`$`$0```(/D`0`>````E>0!`!``
M``"TY`$`"0```,7D`0`:````S^0!`"P```#JY`$`$P```!?E`0`M````*^4!
M`"T```!9Y0$`#0```(?E`0`'````E>4!``@```"=Y0$`!P```*;E`0`$````
MKN4!`!4```"SY0$`#````,GE`0`-````UN4!``P```#DY0$`!0```/'E`0`)
M````]^4!``@````!Y@$`"0````KF`0`)````%.8!`!@````>Y@$`!@```#?F
M`0`.````/N8!``8```!-Y@$`#P```%3F`0`,````9.8!`"````!QY@$`"@``
M`)+F`0`"````G>8!`"4```"@Y@$`!P```,;F`0`*````SN8!`(H```#9Y@$`
M#````&3G`0`&````<><!`",```!XYP$`-````)SG`0`@````T><!`"````#R
MYP$`5P```!/H`0`Q````:^@!`#0```"=Z`$`(P```-+H`0`@````]N@!``4`
M```7Z0$`#P```!WI`0`-````+>D!``\````[Z0$`!@```$OI`0`-````4ND!
M`!,```!@Z0$`#P```'3I`0`/````A.D!`!$```"4Z0$`#````*;I`0`'````
ML^D!``<```"[Z0$`"````,/I`0`6````S.D!``D```#CZ0$`"````.WI`0`'
M````]ND!`!P```#^Z0$`'0```!OJ`0`9````.>H!``@```!3Z@$`$P```%SJ
M`0`(````<.H!``T```!YZ@$`"0```(?J`0`5````D>H!``<```"GZ@$`%0``
M`*_J`0`&````Q>H!`!L```#,Z@$`#0```.CJ`0`<````]NH!``4````3ZP$`
M"````!GK`0`-````(NL!`!\````PZP$`"@```%#K`0`,````6^L!`"D```!H
MZP$`'````)+K`0`2````K^L!``0```#"ZP$`"````,?K`0`+````T.L!``D`
M``#<ZP$``@```.;K`0`6````Z>L!``@`````[`$`)@````GL`0`F````,.P!
M`#X```!7[`$`+P```);L`0`T````QNP!`#H```#[[`$`;P```#;M`0`)````
MINT!`&P```"P[0$`.P```!WN`0!3````6>X!`'(```"M[@$`*0```"#O`0!'
M````2N\!`"\```"2[P$`,0```,+O`0`?````].\!`#X````4\`$`Z`$``%/P
M`0`B````//(!``D```!?\@$`20```&GR`0"H````L_(!`"L```!<\P$`-0``
M`(CS`0!#````OO,!`'8````"]`$`2````'GT`0!"````PO0!`!0````%]0$`
M"@```!KU`0`]````)?4!`!\```!C]0$`(@```(/U`0`P````IO4!`"H```#7
M]0$`*0````+V`0!0````+/8!`!(```!]]@$`"````)#V`0!(````F?8!`#<`
M``#B]@$`*@```!KW`0`G````1?<!`"8```!M]P$`*P```)3W`0!H````P/<!
M`$,````I^`$`1@```&WX`0!"````M/@!`#L```#W^`$`4````#/Y`0!M````
MA/D!`%@```#R^0$`00```$OZ`0`]````C?H!`$````#+^@$`9@````S[`0!X
M````<_L!`'````#L^P$`<````%W\`0`X````SOP!`"X````'_0$`+@```#;]
M`0`P````9?T!`(,```"6_0$`>````!K^`0!_````D_X!`-4````3_P$`&@``
M`.G_`0`L````!``"`#8````Q``(`*P```&@``@!8````E``"`"T```#M``(`
M5P```!L!`@`J````<P$"``P```">`0(`P````*L!`@!=````;`("`",```#*
M`@(`.````.X"`@`G````)P,"`"````!/`P(`0P```'`#`@`&````M`,"``<`
M``"[`P(`!````,,#`@`-````R`,"``H```#6`P(`"P```.$#`@`+````[0,"
M``4```#Y`P(`$````/\#`@`"````$`0"`%\````3!`(`!0```',$`@`<````
M>00"``0```"6!`(`!P```)L$`@`&````HP0"``4```"J!`(`.@```+`$`@`$
M````ZP0"`!<```#P!`(`#0````@%`@`3````%@4"`!`````J!0(``@```#L%
M`@`(````/@4"``8```!'!0(`%0```$X%`@`,````9`4"`!<```!Q!0(`!@``
M`(D%`@`.````D`4"``H```"?!0(`"````*H%`@`N````LP4"``@```#B!0(`
M!@```.L%`@`'````\@4"`#@```#Z!0(`7````#,&`@!(````D`8"`$D```#9
M!@(`,@```",'`@`P````5@<"`#,```"'!P(`.````+L'`@`O````]`<"`"H`
M```D"`(`-@```$\(`@`Q````A@@"`"L```"X"`(`-@```.0(`@`M````&PD"
M`"T```!)"0(`0@```'<)`@`D````N@D"`#\```#?"0(`.@```!\*`@`Q````
M6@H"`#4```","@(`,````,(*`@`K````\PH"`#8````?"P(`,@```%8+`@`V
M````B0L"`#4```#`"P(`*P```/8+`@`M````(@P"`#````!0#`(`.P```($,
M`@`K````O0P"`"@```#I#`(`1@```!(-`@!"````60T"`"<```"<#0(`-```
M`,0-`@!/````^0T"`#(```!)#@(`-@```'P.`@`Q````LPX"`#(```#E#@(`
M+````!@/`@`I````10\"`"X```!O#P(`1P```)X/`@`S````Y@\"`$8````:
M$`(`+P```&$0`@!@````D1`"``T```#R$`(`'``````1`@`B````'1$"`$$`
M``!`$0(`)0```((1`@`0````J!$"``\```"Y$0(`'````,D1`@`6````YA$"
M`!(```#]$0(`)````!`2`@`)````-1("``D````_$@(`)0```$D2`@`H````
M;Q("`"<```"8$@(`)P```,`2`@`D````Z!("``D````-$P(``P$``!<3`@`2
M````&Q0"`!T````N%`(`#@```$P4`@`0````6Q0"`!8```!L%`(`&````(,4
M`@`?````G!0"``D```"\%`(`3@```,84`@`:````%14"`!,````P%0(`!P``
M`$05`@`5````3!4"``P```!B%0(`60```&\5`@`(````R14"`"D```#2%0(`
M$@```/P5`@`5````#Q8"`!4````E%@(`/@```#L6`@`<````>A8"``P```"7
M%@(`*````*06`@`-````S18"``X```#;%@(`%0```.H6`@`*`````!<"`"0`
M```+%P(`"P```#`7`@`9````/!<"``H```!6%P(`'0```&$7`@`M````?Q<"
M``4```"M%P(`)P```+,7`@`'````VQ<"``<```#C%P(`"0```.L7`@!,````
M]1<"``<```!"&`(`$0```$H8`@`+````7!@"`!<```!H&`(`"0```(`8`@`)
M````BA@"``<```"4&`(`%@```)P8`@`+````LQ@"`!X```"_&`(`#P```-X8
M`@`8````[A@"`!P````'&0(`!0```"09`@`'````*AD"`!D````R&0(`!P``
M`$P9`@`Q````5!D"``T```"&&0(`$0```)09`@`'````IAD"``(```"N&0(`
M$````+$9`@`/````PAD"``L```#2&0(``P```-X9`@`'````XAD"``L```#J
M&0(`"@```/89`@`1`````1H"``X````3&@(`&P```"(:`@`<````/AH"``H`
M``!;&@(`-@```&8:`@`D````G1H"`"H```#"&@(`%P```.T:`@`-````!1L"
M`#X````3&P(`!@```%(;`@`7````61L"`$````!Q&P(`#@```+(;`@`'````
MP1L"``<```#)&P(`!````-$;`@`$````UAL"``D```#;&P(`'@```.4;`@`%
M````!!P"``8````*'`(`"````!$<`@`,````&AP"``8````G'`(`%````"X<
M`@`4````0QP"`$````!8'`(`-````)D<`@`N````SAP"``P```#]'`(`'@``
M``H=`@`A````*1T"`"\```!+'0(`*0```'L=`@`4````I1T"``(```"Z'0(`
M!````+T=`@`,````PAT"``@```#/'0(`!0```-@=`@`"````WAT"`!$```#A
M'0(`80```/,=`@`N````51X"`!H```"$'@(`.@```)\>`@`Q````VAX"`%X`
M```,'P(`%@```&L?`@!]````@A\"`"D`````(`(`5@```"H@`@`I````@2`"
M`$````"K(`(`/@```.P@`@`U````*R$"`$P```!A(0(`-0```*XA`@`W````
MY"$"`#D````<(@(`'P```%8B`@`N````=B("`#(```"E(@(`0````-@B`@`3
M````&2,"`!(````M(P(`#````$`C`@")````32,"``@```#7(P(`Q@```.`C
M`@!Q````IR0"`(L````9)0(`+0```*4E`@!E````TR4"`!<````Y)@(`)@``
M`%$F`@`7````>"8"`!<```"0)@(`&@```*@F`@`D````PR8"`$,```#H)@(`
M)@```"PG`@`@````4R<"`'<```!T)P(`'````.PG`@`,````"2@"``L````6
M*`(`!0```"(H`@`&````*"@"``@````O*`(`!0```#@H`@`6````/B@"`!``
M``!5*`(`%0```&8H`@`@````?"@"`!$```"=*`(`#P```*\H`@`-````OR@"
M``D```#-*`(`#@```-<H`@`(````YB@"`!4```#O*`(`"0````4I`@`)````
M#RD"`!,````9*0(`#@```"TI`@`'````/"D"`!(```!$*0(`#@```%<I`@`9
M````9BD"``D```"`*0(`"@```(HI`@`2````E2D"``@```"H*0(`"0```+$I
M`@`I````NRD"`"(```#E*0(`$`````@J`@`E````&2H"`!0````_*@(`&P``
M`%0J`@`1````<"H"``H```""*@(`%@```(TJ`@`'````I"H"``4```"L*@(`
M%0```+(J`@`$````R"H"``(```#-*@(``@```-`J`@`2````TRH"``8```#F
M*@(`!@```.TJ`@`2````]"H"`!<````'*P(`!P```!\K`@`Z````)RL"``(`
M``!B*P(`!````&4K`@`3````:BL"`!@```!^*P(`"@```)<K`@`'````HBL"
M`!(```"J*P(`!0```+TK`@`9````PRL"``@```#=*P(`%P```.8K`@`5````
M_BL"`!,````4+`(``@```"@L`@`.````*RP"``P````Z+`(`#0```$<L`@`6
M````52P"`#H```!L+`(`!P```*<L`@`)````KRP"`!$```"Y+`(`!0```,LL
M`@`"````T2P"``L```#4+`(``0```%\'```P````+P8``"`%````````P`0`
M`*X&```>`````````!@'``#H`0``S@0``)0%```M`@```````)<!``"S!0``
M````````````````;@0``&$"```I!```S``````````@`P``G`0````````A
M`````````-L"````````H0(``'L!``"B`P``*@``````````````FP0`````
M``#6`0``908``&L!```?`0``E@,```````#'`P``G@(``&P!``"%!P``*```
M`"@"``""`0``_0,```````!]!P```````$<"```W!0`````````````?!P``
M``````````#!`P``100```````!X!```30```.H&``!'`0``7@$``$X&```\
M`@``M@(``*<"````````4P$``$T"````````'P(``'L'``"%`@``J`(`````
M```<`0``@`0````````.`0``0@``````````````)@4```````#-````_0(`
M`#,```!A!@``U@,``*<$``"7!0``80$`````````````>P0``.T"```!!```
M;`(````````)!P```````.$!`````````````'$```##`0```````*T&``!X
M`P````````````!Q!0```````#4$``!K!@``Q@```)`!```2!```]@,``$X!
M``!W`@``5@(````````Q``````````````"F``````````T!``#-!@``!```
M`'8%``!^!@```````*L&``#O!@```````"`$```````````````````T````
MZP0``+L%``"Q!0``TP```"<````=!````````%X$``#K`@``8P0``+@#````
M````UP(`````````````U`,```<$``````````````````#,!@``,@(`````
M``#:`P``^0$```````#[`@``&@(````````0!P```````',"``!6````^`,`
M`,0#``"W!0``P04``+L!``#@!```E04``&D$``#6!0``4@<```````!W`0``
M"@```%@'````````70$``,X!``!+````[08``(0!``#``P``V`$```````"*
M!@```````-`$``!?`0``P@```+X&````````PP4``&<&``!B````^0,``$\!
M```L`@``+`0``'8&``!G!0``70```&\#``!4!0```````+,!```$!P``Z@0`
M`````````````````#,&````````````````````````(@,``,,#``">````
MQ@(``.$#`````````````)0&```'`P``OP```(L"````````M04```````#@
M!@``'0,``!(#``!R!P```````+@&````````AP```,8!``"S!@``\00``)`#
M````````=@$``#$$``!6!0`````````````C!0``H@```!H$````````7@(`
M`#T#``#5!0``HP(```````">`P``:@0```P%``#>!@```````"`````J!```
MS`$``$P&``"Z!```)08``$<'``"T!```@`,```````"5`P``TP(``%\#```^
M`P``V0$``)H!````````?`8```````!P````Y`4`````````````]08`````
M``"/`0``#P,``.8%``#@`P``3`<``)P%``!Y!```^@```&0!``!%!@``````
M`"$$```T!0``C@```"0&````````N`(``$\&````````W@```$@'``"\`0``
MBP$``'$'``#T`P``/@0``"<$```C`0``:0```+4````2`````````*L%````
M````M`(``'(```#W`0``?0````(&```1!P``BP`````````!`P``E````,X"
M````````G0$``"$'``"]`P``=P8``%`'``!S!@````````````"M`P``@@4`
M`````````````````#T"``!J`0``5`<``(("``"N`0``FP8``!X"```Q`0``
M.@8``*$%`````````````!T!``!0````O`8``/<&``"N!`````````````#+
M`````````)D#````````X@8``-\```#.!@``XP```/@````T`0```@$``#($
M``!*````J@,``'\!````````\P``````````````W`4``$\```!G!P``1`<`
M`'(!``"C!```I````#('``"(!0``P`$``&T'````````KP$````````%!@``
M`````"\```#\`@```````'0!````````X`$`````````````XP(````````+
M!@``$0$``!('``#A!```6P```/X!```C!```#P````D%``"0````)04`````
M````````#`0``%L&``!+!@``C08```````!6`0```````.(%```I!0``EP0`
M`/\%``#2``````````````![!@```````!(!```X`@``^`8``,(!``!3`@``
M^`4``,T%``"0!P``H0``````````````L`,``*P&``"3!0``I`,``+X%``!I
M!@```````.\#````````@P8``-("``!O````!@$``$(#```=!P``D@8`````
M`````````````#@#``",````0P$``$X```!?!0``30$```````!8!```````
M`-@"``"Q````80,``#\$``!&`0``P08``%P'``#=````GP0````````D````
M#`$``(0#``#H!```A`8``#H!``"T!0``$0```!8$``#>!````````#4!``#0
M`0``NP(````````Y````Q00`````````````%`0```T'``!.!P``50<``+\#
M```N`@```````"<#``!J`@``H`0``-L#```B`@```````,8%``#D````"P,`
M`'D!``#*!@``;`8```````#R`P``4@0``.4"```Z`P``10$``.@```#*!```
M`````$\"``!U`P```````(($````````60(``(\$``#B``````````````"2
M!0``HP,``#\%``"G!0``O@$``/X%````````O@,``"T#``!(!@``W04``),"
M``!B!P``!`(``#(&```*`P``*P4``*X"``!0`@``!P8``#,'``#@!0``-@8`
M``````!T````D@0``/8!``````````(`````````````_@```-@&``#O````
M/04``(P$``!Q`P``<`8`````````````]P```&,"```7`0``1`$``(@$````
M````O00``#8````L`P``_@0``$\%````````0P4``%P#``"#`P``V08``!H%
M```_`0``;`0``!8'`````````````(`'````````<P<``.@"````````]@``
M`#\"``!0!```*@$``)$#```)!```[`(``,<&``#5`0``#`(``(<%```N!```
M!`0``.($``#N!@````````````!]`P````````$!```>!0``B0,```4$``#1
M`@``.`8``$X#``#?`P``4P```',$```)`P``(P,``.D&`````````````&X#
M``"2`P```````%,%````````5````#T&``!O`@``)`,```````"=`@``(@<`
M```````3!P``?`$``%@```#D!@``>P```"H%``!K!```R@(`````````````
MHP8``)T```!7`0```````(D%```4!0``=08```8#```E`@``.````%P%````
M````+0```(\'```F`@```````"8!``!H`````````.4#``!5````,P4``"@!
M``````````````````!+!````````!`%``#Y!0```````'`%```U!0``````
M``````!%`````````(D$```[!P``\0,``%T&```9!``````````````M!P``
M`````(H```"V````X`````````!X!@````````````!I!0``"P$````````1
M`@``````````````````ZP$``)L```#3`P``XP,`````````````L0(``&D"
M``"6!````````$`'````````800``!D#````````"@<``-P`````````V`0`
M`/L$````````6@(```````!H!```A00``-`&``#/!0``M````"L$````````
MBP,``&H'``"W````[0```+(%```&!@``&@````````!,````<@0``,T$``#%
M`P``6@,````````V`@````````````"G`0```@````````"K!```````````
M````````YP,``%D%```J`P``3P,``"4'``#>`0````4``/4%``!'`P``8```
M``````"P!@``%@`````````````````````````\````_````*T$```Y!```
MU0(``,$"``#S!@``'@,``(T```"E`P``3@(```````!F!0```````%L#``#:
M!0```````(,"````````4@,``/0&``"N`P``U0```-$`````````Y@8``(,`
M``#;!```#00``&("```D!0``90<``.T$``#X!```5P(``#$&``#&!@``7P0`
M`,D!``!Q!@```````$@$````````A````*($```#`@``M08``%@#``"]````
ME0$``*(&````````````````````````A0```(<&``!0`0``````````````
M````_@(```````"*`0``X@,````````Z!0``\0(``!,!``"(`0``'@8`````
M``"R````&P8``&T!``"#`0```````)8```#G!```/@$``'X!``"/`@``R`(`
M`+\$``!:!P```````$P"```1!@``S0,``#8#```+`@``.`4``'H%``#.`P``
M?`<``$P$``!M!0``Y0$````````N`0``4@$``%,$``#;`0``I@,```4!``#.
M!0```````%H!``#4!0``@0,``+4#``#:````M`$``$,$```U`@``600```X%
M````````2P4``$8#``"H`0``F00``!\```"B`@````````H%````````Q0$`
M`%T'``"?`0``_P8````````A!0``\@$``',!````````O`4``'0%``#:`@``
M!`8```````#=`0```````/P#`````````````#`$``!D````````````````
M````````````````````QP(``/\#```;`@``V`,``!@$``!F`@```````+\"
M`````````````&L#````````R0```!8"``!H!P``EP,``$<%``!6`P``/@``
M````````````(P8```````#(!0``:`8``)D!``````````````<'``!\`@``
M`````+4!``"X`````````$X$``"+!```?P```*\%``#/`0```````/L#``"8
M!@``6`4``#P'``"'!P``*`,``!4```",`P``/00``#\'``!@`@```````"P'
M``````````````````"Y!@``^00``",'``"8````*`0`````````````5P8`
M`-<&``##!```MP8``*(!```,````"`$``#0&``!%!P``WP4``)L"````````
MR00``.H#``"V`0``!`4```````!U!P```````'8#``!_!```"`4``$T&``#,
M!```_0````````!7!P``X0(``!\&``!``P``L08```````#:!@``!P4``.0$
M````````-0````@#``!5`@```````'@!```F!@````````L$``#7`0``````
M`*D&``"-`P``00$``,D#``!$!0``D`8``````````````````($`````````
MA@```!H&``!\`P```````/,$``#"`P```````(D&````````,`(``+(&``"3
M````4@8``*$#``!0!0```````%<```#B`0``F@0``),#``!:!0```````'8"
M``!Z`P``$`8``!D!````````H````(T$`````````````'X'``!#!@``"P4`
M`*(%``!"!P```````$D&``!C!@``````````````````KP,``#L```")!P``
MC@,``)8%``"!`@```````!$$````````=`(``%T%``#?!@``I`8``+,`````
M````$P(``*`!````````#P(``)\"````````%0$````````<!P``6@0``$P!
M``#?`@```P4````````9!P``;@(```````#F!```-P8``%D#``!&!P``Y@,`
M````````````XP4``!P$``!R!@``K0```!0"``"H!````````+4"````````
MTP4``*L!``"Y`@``ZP8``'<#``!@`0``[0$``*@%```@`@````````````#F
M`@``)00`````````````BP8``"@'`````````````/8%``!G`@```````,T!
M``!R`@``*0(``/0!``#"`@``)0$``!L%```5!@``.P8``%H```!>````=P4`
M`.,!``#_`@``.P$``/T$```B!```````````````````Y@$``-X"```3!```
MK04``*8!```'`@``A0,``)("``!J`P```````%<$``#J````P````'@%````
M````T00````&``";`0````````````!O`0``&08``#X%``"9`@``````````
M``"X!0``GP,``#0"``"S!````````(4%``"=!@``30<```$"``"`````'P4`
M`,L!```"!P``;P8``,H#``"`!@``&`$``.X!````````8P$``+8%``#U````
M%P,```````!X`@```````&D!``!>`P```````(X'```O`P```````"8#``#,
M`@``<`,```````"?`````````````````````````+($``"X`0``N00``-`"
M````````40<``#T'``#Z`P```````-H$```P`P``'`,``(@#``#7`P``.0<`
M``````#2!0``^0(``%$`````````V@$```````!C````W`0```T"````````
M`````)<"``"1````^P8````````L!@```````,\"``"K`P``\P(``&8'``#;
M`````````&X'``#$!@```````%$$``!"!@```````/("```I````B@(`````
M``!#!P```````'T!```2!0``6@8``#,"`````````````.("``"[!```````
M`.<"``#/````#0```/``````````;00``-$%````````V````.0!``")`0``
M.P4``,D"``":!0``>0,```````#C!@``8P4``"@&````````5`$``.P`````
M````%04`````````````<`$``!("````````I08`````````````Q`0``&,'
M``"&`@``$P8``$\'``#5!@``00<```````"6`0``TP0```````":`P``````
M`-(!``"/!@``NP```*0"``#X`@``104``$8$```$`0``40(``&$'````````
M)`$``)P!``#9`P``"@0``+H"``#&`P```````'0&``#/!@``UP0``/`&````
M````(@4``.H%``"I````.`$```,&```<!@```````#4'```)`0``Z0$``"T!
M``"V!@````````````"K`@``RP,``/\$````````,`$``$H"``"F!0``'```
M`!<"``"O`@``-@0``'0$``"0!```U`$``-\$``#I`P``+P(``&4````Q!0``
M+@4``+T!``":!@``4P8``"0"```C`@``0`4``.X$```!!P````<``!````!B
M!````````$H#``!8!@``2@<``%4&`````````````(0"``"Q`0``-`,`````
M```B!@``&P<`````````````O@```%4%````````@08``.X%``#J`@``KP8`
M``````#E!@``&`(``%8$``"E!`````````````#\`0``E`(``-(&```;````
M=@```+<#````````[`$``/<$``#S`P``Y0````````"C````T@,``+("``"=
M`P``F08`````````````8@4``.T#``!=`P``8`0``/T%```G!0``*P<``*<&
M``"I!`````,``*8"````````MP(```,!``!@`P``!0,``/0$``#7!0``````
M```````"!```F`(``&@!``!_!@``20<```4%``#'`0``R@$`````````````
MY00```````!E!0```````,,&``!^`@``P@0``.X"```U`P``?`0``.0#``!N
M`0```````-T$``#N`P``^P$``,(%``#P!0``"0````````",!P``F04``,8$
M`````````````&4"``!N````60`````````#````1@4```8'````````_@8`
M`,4```#%`@```````)P&````````>@(````````_`P``````````````````
MPP(``*0!``"/````304``#P%```V!P``"@8``&L"```G`@``4@4```````"_
M!0```P,```````#<`P``*0<``#@'``".`@``C0$``/4$``"6!@``&P$`````
M``#?`0``C04```````"E````9`8``!T%``")`@```````/$%````````'0``
M`"`&````````MP$``*`&``"/!0````````````"8`P``#08``#$"``"5````
M`````'H!``!"`0```````!8&````````804``&L%``#*!0``Z`8``(T'````
M````\@4``.P$``"^!```^08``+H%````````20$``%0"```]`0```````-P"
M````````20(``$`&``#I!0```````(P&``#F````Q`(```$&````````F`4`
M`$@```#S!0``0P,```````````````````````"2````/@<``&T"``"3!@``
M/`$``.H!``"-`@```````%P```"(````)`<``+T%``#G`0``J@(``/0````W
M`0``'@<``&\'``".!0``5`,``,@!`````````````*D!``#(!@```````$@#
M``#9!0``IP````````![!0``W0,``&4!````````G00```````#R````````
M`+4$````````^@$``"H'``#`!0``C@$`````````````5`8``.$%```A`P``
M``````````#R!```E`$``,4%```8!0``?P4`````````````,0<``(<"``!H
M!0````````<```#W`P``1P8````````<!0``700``,`&``````````````H"
M```P!@``>@0````````S`P``8`8````````W`@``-P<````````7````````
M``````"\!```T````*`%``"^`@``*0$``'`'```5!P``3P0``%(```!M!@``
M``````L'```>!```30,```$%`````````````.L````5!```"`(``(8'```5
M`@```````(,$``"``@```````(8!```/!0```````"$"``"T`P``.@<``,L$
M````````:0,``#0'``!$`@``]@0``&$`````````@`4``'L"``!)!```````
M`',```#_`0``B@0``$8&``"D!0``^@0``#D&``#A!@```````$`!``"Q`P``
M-P``````````````6P0````````E````4`8``"<'```A!@``S`4```````!G
M`P````````````#H`P``=`<``/L%````````H`(``(4&```J!@```````/\`
M```;!````````&(&``#+!@``[P4`````````````H08```X#```6`P``````
M`,T"``#>!0``+00``!4#``"7!@```````)\%`````````````$8```"P!```
M408``#D%`````````````,0```"Z`0``MP0``!T"````````A@4```````"3
M!```U`(``+H````/!P```````,,````N!P````````````#7````$P,``/P&
M``#^`P``J````$@%``#<`0``.0(``,L%`````````````,\$``#,`P``L00`
M``````#A`````````)`%``!L`P``;`````````!C`P``\0```+D!``!5`P``
M`````%L!``````````````````"L!0``?08```4"````````404``#H"``"&
M!```K`````````">!0``00,```,$``![`P````````X$``"R`P``;P0``%<%
M``#1`0``&04```````#/`P``L@$``'4!````````^@8`````````````!P$`
M`&4#```K`P```````&8&```*`0```````)L#``!M`P``J@0``(P"``!U!0``
MU0,``%\"``#Q!@```````'$!``"A!```R````*@#``!<`@``^0````````#!
M````#@```&H%````````>04``!,```":````<@,````````/!@```````*<#
M``#R!@``$`0``#L"````````60$``*H&```,!@``QP```(H#```.!@``*08`
M`%X%``!;`@``G@$``(@&``!!!@``AP,``(`!```W!```;P4``'H&``"&!@``
M`````$$$``"'!```)@<``!<&``"+!P```````/8"``!"!```6`$```````#P
M`P``Z0(````````F````5`0``!`#````````````````````````````````
M```B````_`4``&H&```N````OP$`````````````?0(``(<!``!J````2@4`
M`)D`````````'P,```````#Q`0``D`(``-D`````````2P(`````````````
M;`<``&@#``!.!0``1`0```T#``"5`@``J@4```````""!P``204``"0$``"N
M````?00``!H!``#4````*P8``&8#`````````````&L'``"I!0``E08``.<&
M```@!P``300``#`'``!W````2P,``-,!````````[04``#,!```"!0``%`$`
M`#T`````````````````````````]@8``/0%``#)!0```````$(%``#K!0``
M`````!<'````````Z00``&X%```O!`````````````#0`P``?@0``*D"````
M````(`$``'X%``!(`0``R08```P'````````U`0``$D````&````[@``````
M``".!```7`8``$`$```.`@``%````*$!``!;!0``_`0``%X'``"4`P``````
M```!````````9`(````````=!@````````````#4!@``CP,````````;`P``
M*`4``#\&``!D!P``2@8``/T!``!H`@``5@<``'8'``"H!@``"`0``'P````#
M!P``70(```````!P!````````"T&``!P`@``\P$``#H````J`@```````.0"
M````````````````````````A`<``+,"```R````+P$```````#U`@``#P$`
M`"8$```2!@``4P,``*4!````````N@8``,H```!?!@``;0```*T"````````
M10,```8"``!F````5@8``(@"````````@@,``*4"``"\`P``Z0```+`!````
M````"P```!0'```1!0``M@0``#8%``!G`0````````````#(!````````&0$
M``"7````]0,``#X"````````L````'P%````````=00``)(!````````]0$`
M`'D'```4`P``KP```!H#````````@P4``-D$```6`0``+@,``&4$```<`@``
MK@4``'0#````````E00```4````T!```#04```````!*!```!`,``'@'```E
M`P``<@4``#$#``"8!`````````````````````````````!7`P```````-8"
M```6!0``40,``#X&````````7`$```````"J`0``Z`4`````````````T0,`
M`)8"``"K````[P0``)P"``!;!P````````````"<`P``>0(``.4%``!Y!@``
M`````*0$``#W`@``9P```.`"``!,`P``#`,```````!D!0``3`4``+T&``#L
M`P``4@(``(L%`````````````$`"``"[`P````0``#P$``!L!0``[`8``#D#
M``!B`P``T@0```````!D`P``0P(``+@$``"L`P``+`````````"Y!0``\`0`
M`/H"````````#P0``*`#``#W!0``W`8````````0`@```@,``!0&``")````
M(@$``+D#```(!P``_08``)X&``#G!0````````````"C`0``+@8``!`!````
M````OP8``-L%````````9P0``/`"``!_!P``N@,```@```!&`@``%P4``$$"
M``!$!@``K`0``(8#``#P`0``2`(```````!S!0```````"T%``#5!```@0$`
M````````````-P,``"P%``!_`@``B`<```````"1`@``W@,``!@&``#6!```
M)P$`````````````KP0``$L'````````Q`$``"\%```(!@````````````!*
M`0``G@0``",```#C!```!@0``+T"``"L`0```````+0&```R`0``1P0``)$&
M````````T`4``````````````````!D```"4!`````````````"!!```500`
M`"D#```A`0``[`4``-8&``#K`P```````)T%``";!0``A`4``,4&````````
M"0(``$D#``#``@``7`0``%,'````````"08``%\````?!````````'<$```"
M`@```````,X````:!P``V`4```````!V!```T08```````"%`0``C`$`````
M```K`@``.@0``$,```!Z!P``!@4```````#!`0``:P```$("``#'!```NP8`
M`-D"```````````````````V`0``@0<``),!``!%`@``D0$``+`%``!'````
M,@,``)H"``#(`P``608`````````````&````'$$``"\`@``4`,``%D'````
M`````````````````````````!<$``!]!0``=0(```X'````````6`(``&8!
M```K`0``W08``&`%``"J````8`<`````````````P00``"P!```K````D00`
M``````!$`P```````#L#```1`P``LP,``.\!```P!0``;@8````````\!@``
M,@4```4'``!Q`@``&0(``(P%````````G````-,&``#;!@``40$``+P```!>
M!@``.`0```````#6````B@<``/@!````````00``````````````8@$``!,%
M``"V`P``2P$```````#T`@```````.\"```G!@``'@$`````````````D04`
M``````"E!0``>````($%``"F!@``C@8``(0$`````````````#4&``""!@``
M`````#,$```\`P``&`,``$$%``!S`P``+P<``(,'``"*!0``I@0``&D'``!$
M`````````#\`````````YP```-T"``!U````?P,``,<%````````RP(``/H%
M````````P@8``'X```"M`0```````((``````````````'D```"8`0``.P0`
M``````!Z````L`(``/L`````````GP8``*P"``!`````J0,``+D````Y`0``
M=P<``%4!``"C!0```````'X#````````Q`4``&8$````("@E<R!D87ES(&%G
M;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N;W0@82!D:7)E
M8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B)7,B(&ES(&YO
M="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`(B5S(B!T<F5E
M(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@=&\@=&AE(&=R
M;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P97)M:7-S:6]N
M<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`)2XR9DU"('5S
M960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@86YD("5S`"5D
M(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E9"UD87D@9F]R
M96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@36%I
M;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U<``E
M<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y(&5X
M:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R9F]R;2!T:&4@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W+B!#:&5C:R!T
M:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT('1O('!E<F9O
M<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M:6YU=&5S`"5S
M(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S($)O;VL`
M)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES=``E<SH@
M)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@=VAO;2!I="!C
M;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY(&QI;FMS(&EN
M(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@86YY('!E<G-O
M;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN9R`E<R`E<P`L
M('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM`#$R($AO=7(@
M1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V:6]U<P!!(&1A
M=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@8FQO8VLN`$$@
M9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'4"!K97D@:7,@
M<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%!'4"!K
M97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE<W-A9V4N`$$@
M<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A
M<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E+@!!('!U8FQI
M8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S<&AR87-E(&%R
M92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L:6,@4R]-24U%
M(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H<F%S92!A<F4@
M<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B;&EC(%,O34E-
M12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P:')A<V4@87)E
M(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI8R!334E-12!K
M97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$%-($-L;W5D
M<P!!32!,:6=H="!286EN`$%-($QI9VAT(%-N;W<`04T@4F%I;@!!32!3:&]W
M97)S`$%-(%-N;W<@4VAO=V5R<P!!32]030!!4$D@240`06)O=70@=&AI<R!E
M9&ET;W(`06)O=70N+BX`06)S8F]T=&]M`$%B<VUI9&1L90!!8V-E<W,@9&5N
M:65D(&-R96%T:6YG(%9&4R!D:7)E8W1O<GDN`$%C8V5S<R!D96YI960@8W)E
M871I;F<@5D93(&9I;&4N`$%C8V]U;G0@26YF;W)M871I;VX`06-C;W5N="!0
M87-S=V]R9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($-H
M:6QD($=R;W5P`$%D9"!#:&EL9"!097)M:7-S:6]N`$%D9"!(97)E.@!!9&0@
M365M8F5R<P!!9&0@3F5W($=R;W5P`$%D9"!.97<@4&5R;6ES<VEO;@!!9&0@
M82!C:&EL9"!G<F]U<"!T;R`B)7,B`$%D9"!A(&-H:6QD('!E<FUI<W-I;VX@
M=&\@(B5S(@!!9&0@82!N97<@=7-E<CH`061D(&-O;'5M;@!!9&0@<&%I<@!!
M9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B87(`061D('1O(&%D
M9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O:P!!9&0@=7-E<@!!
M9&1E9"`B)7,B('1O('1H92!S>7-T96TL(&)U="!C;W5L9"!N;W0@861D(&%D
M9&ET:6]N86P@<VEG;G5P(&EN9F]R;6%T:6]N.B`E<RX`061D960@(B5S(B!T
M;R!T:&4@<WES=&5M+B!9;W4@8V%N(&QO9R!I;B!N;W<N`$%D9&EN9R!U<V5R
M<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`061M:6YI<W1E
M<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`061M:6YI<W1R
M871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!
M;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E9"!5<V5R<P!!
M;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S:61E<P!!;&QO
M=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O9B!O<F1E<F5D
M(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E($E-4U`@3&]G
M:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E($E-4U`@57-E
M<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N871E('1E;7!L
M871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`06X@:6QL96=A
M;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R<F]R(&AA<R!O
M8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N>6UO=7,@4')O
M>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R8G5D80!!<'!L
M:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N(&ES(')E861Y
M+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R;WAI;6%T92!3
M:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H:79E($9I;&4@
M4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E
M;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)E('EO=2!S=7)E
M('EO=2!W:7-H('1O(&1E;&5T92`B)7,B(&%N9"!A;GD@<W5B+6=R;W5P<S\`
M07)G96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R
M=6)A`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!2
M96=I;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT
M96YA;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T
M('1O(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D
M96QE=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E
M9&ET(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I
M="!A(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S
M=')A;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT
M96YS:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO
M="!H879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U
M:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET
M:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E
M9"!)34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER
M960@:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z($%D9&EN
M9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O<B!!8W1I=F4@1&ER96-T;W)Y
M`$%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E9"!F
M;W(@06-T:79E($1I<F5C=&]R>0!!=71H7VQD87`Z(%)E<75I<F5D($Q$05`@
M97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@=&\@861D
M('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD87`Z(%5N
M86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VQD87`Z(%5P9&%T:6YG('5S
M97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GDN`$%U
M=&A?;6-A;#H@4F5Q=6ER960@34-!3"!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!
M=71H7W-M8F%U=&@Z(%)E<75I<F5D('-M8F%U=&@@97AT96YS:6]N(&YO="!F
M;W5N9"X`075T:&5N=&EC871I;VX@870@24U!4"!S97)V97(@9F%I;&5D+@!!
M=71H96YT:6-A=&EO;B!F86EL960`075T:&5N=&EC871I;VX@9F%I;&5D+B`E
M<P!!=71H96YT:6-A=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+@!!
M=71H96YT:6-A=&EO;B!T;R!&5%`@<V5R=F5R(&9A:6QE9"X`075T:&5N=&EC
M871I;VX@=&\@=&AE(%--0B!S97)V97(@9F%I;&5D+@!!=F%I;&%B;&4@9FEE
M;&1S.@!!>F5R8F%I:F%N`$)/1D@@17AC=7-E<P!"86-K9W)O=6YD`$)A8VMG
M<F]U;F0@0V]L;W(`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R
M;W,@=7-E<FYA;64N`$)A:&%M87,`0F%H<F%I;@!"86QT:6,@*$E33RTX.#4Y
M+3$S*0!"86YG;&%D97-H`$)A<F)A9&]S`$)A<V4@9W)A<&AI8W,@9&ER96-T
M;W)Y("(E<R(@;F]T(&9O=6YD+@!"87-E;&EN90!"96QA<G5S`$)E;&=I=6T`
M0F5L:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$)I<G1H9&%Y`$)L;V-K("(E
M<R(@;V8@87!P;&EC871I;VX@(B5S(B!N;W0@9F]U;F0N`$)L;V-K(%-E='1I
M;F=S`$)L;V-K(%1Y<&4`0F]L9`!";VQI=FEA`$)O;VMM87)K<P!";W)D97(`
M0F]R9&5R('1H:6-K;F5S<SH`0F]R9&5R<P!";W-N:6$@86YD($AE<GIE9V]V
M:6YA`$)O=&@`0F]T<W=A;F$`0F]T=&]M`$)O=79E="!)<VQA;F0`0G)A>FEL
M`$)R:71I<V@@26YD:6%N($]C96%N(%1E<G)I=&]R>0!"<G5N96D@1&%R=7-S
M86QA;0!"=6QG87)I80!"=6QL971E9"!,:7-T`$)U<FMI;F$@1F%S;P!"=7)U
M;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;B!0;VEN=',`0U]E;&P@4')O
M<&5R=&EE<RXN+@!#86-H92!I;FET('=A<R!N;W0@8V]M<&QE=&5D+@!#86QE
M;F1A<@!#86QM`$-A;6)O9&EA`$-A;65R;V]N`$-A;B=T(&%D;6EN:7-T97(@
M97AT97)N86P@<V5S<VEO;B!H86YD;&5R<RX`0V%N)W0@8V]N;F5C="!T;R!)
M34%0('-E<G9E<CH@)7,`0V%N)W0@;W!E;B!F:6QE("(E<R(N`$-A;F%D80!#
M86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A;FYO="!C;W!Y(&9I;&4H
M<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92X`0V%N
M;F]T(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y
M(&1I<F5C=&]R>2X`0V%N;F]T(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N
M(&ES('=I=&AI;B!S;W5R8V4N`$-A;FYO="!P<F]C965D('=I=&AO=70@)W1A
M<F=E=$9I;&4G('!A<F%M971E<BX`0V%N;F]T(')E;6]V92!D:7)E8W1O<GD@
M(B5S(BX`0V%N;F]T(')E;6]V92P@)60@8VAI;&1R96X@97AI<W0N`$-A;FYO
M="!R96]R9&5R+"!N=6UB97(@;V8@96YT<FEE<R!S=7!P;&EE9"!F;W(@<F5O
M<F1E<B!D;V5S(&YO="!M871C:"!N=6UB97(@<W1O<F5D+@!#86YN;W0@<F5S
M970@<&%S<W=O<F0@875T;VUA=&EC86QL>2P@8V]N=&%C="!Y;W5R(&%D;6EN
M:7-T<F%T;W(N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I9FEE9"!N
M=6UB97(N`$-A;FYO="!W<FET92!T;R!F:6QE("(E<R(`0V%P92!697)D90!#
M87!T:6]N`$-A<G)I97(`0V%T96=O<FEE<R!A;F0@3&%B96QS`$-A>6UA;B!)
M<VQA;F1S`$-E;&P@4&AO;F4`0V5L;"!0<F]P97)T:65S`$-E;&P@<&%D9&EN
M9SH`0V5L;"!P<F]P97)T:65S`$-E;&P@<W!A8VEN9SH`0V5L;'!H;VYE`$-E
M;'1I8R`H25-/+3@X-3DM,30I`$-E;G1E<@!#96YT<F%L($%F<FEC86X@4F5P
M=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0V5R=&EF:6-A
M=&4@1&5T86EL<P!#97)T:69I8V%T92!/=VYE<@!#97)T:69I8V%T92!0;VQI
M8VEE<P!#:&%D`$-H86YG90!#:&%N9V4@66]U<B!087-S=V]R9`!#:&%N9V4@
M=&AE(&YA;64@86YD(&%D9')E<W,@=&AA="!P96]P;&4@<V5E('=H96X@=&AE
M>2!R96%D(&%N9"!R97!L>2!T;R!Y;W5R(&5M86EL<RX`0VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!I<R!N;W0@<W5P<&]R=&5D('=I=&@@=&AE(&-U<G)E;G0@
M8V]N9FEG=7)A=&EO;BX@($-O;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R+@!#
M:&%R`$-H96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI
M9FEE9"`H1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O
M<V4@07!P;&EC871I;VXZ`$-H;V]S92!A('!A<W-W;W)D`$-H;V]S92!A('5S
M97)N86UE`$-H;V]S92!H;W<@=&\@9&ES<&QA>2!D871E<SH`0VAO;W-E(&QI
M<W0@<W1Y;&4@='EP92`H9F]R(&]R9&5R960@;&ES=',I`$-H<FES=&UA<R!)
M<VQA;F0`0VQA<W,@9&5F:6YI=&EO;B!O9B`E<R!N;W0@9F]U;F0N`$-L96%R
M`$-L96%R($U33V9F:6-E('1A9W,`0VQE87(@475E<GD`0VQE87(@;W5T('5S
M97(Z("5S`$-L96%R('5S97(`0VQE87(@=7-E<B!D871A`$-L96%R:6YG($QA
M=&4`0VQI8VL@=&\@0V]N=&EN=64`0VQI8VMA=&5L;"!V:6$@2%144`!#;&]S
M92!7:6YD;W<`0VQO=61S`$-L;W5D<R!%87)L>0!#;&]U9'D`0V]C;W,@*$ME
M96QI;F<I($ES;&%N9',`0V]L;&%P<V4@4VED96)A<@!#;VQL87!S960@8F]R
M9&5R<P!#;VQO;6)I80!#;VQO<@!#;VQO<B!0:6-K97(`0V]L;W5R('-E;&5C
M=&EO;@!#;VQS.@!#;VQU;6X@=&ET;&5S`$-O;6EC<P!#;VUM86YD`$-O;6UA
M;F0@4VAE;&P`0V]M;65N=`!#;VUM;VX@3F%M90!#;VUO<F]S`$-O;7!A;GD`
M0V]M<'5T97)S`$-O;F1I=&EO;@!#;VYD:71I;VYS`$-O;F9I9W5R871I;VX@
M1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N
M9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$
M96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`
M0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE
M('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@
M=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@
M<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT
M96YT('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S
M(@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL
M960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E
M(&0G279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U
M;&0@;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N
M8W)Y<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N
M`$-O=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@
M3$1!4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L
M9"!N;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE
M8W0@=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E
M871E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!0
M1U`@9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L
M9"!N;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES
M=')I8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G
M<F%D92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C
M:7!I96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP
M;&5T92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D
M:7-T<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T
M92!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@
M<W1R871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO
M="!O8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD
M(&YO="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S
M+@!#;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#
M;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H
M('1H92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO
M="!R97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@
M4V]M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4
M<GD@86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U
M(&YE960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O
M=6QD(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R
M971R:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I
M979E(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E
M('-E<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I
M9W5R871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V
M92`E<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A
M=&EO;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M=&\Z("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I
M;VYS('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A
M;&QY('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N
M;W0@=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N
M(&9O<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B
M87(N($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G
M:79E('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O
M;&1E<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R
M96%T90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U
M8B!F;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M
M8F5R`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S
M<VEO;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E
M<G,`0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N
M="!S='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@
M)7,N`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2
M*0!#>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@
M*$M/23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E
M87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R
M;RUD<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO
M;VMU<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E
M7VQE=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S
M92!);F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I
M='D`1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E
M;&P`1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`
M1&5L971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@
M8V]L=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L
M971E(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE
M=&4@<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO
M;G,_`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T
M92!S=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T
M92!T:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP
M="`B)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R
M;V)L96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO
M9V9I;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI
M;FES=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O
M<B!L87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R
M:6=H=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA
M>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A
M:6QE9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@
M9F]R;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N
M;W0@9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N
M<&AP`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE
M<S\@268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N
M(%)E<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W
M;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R
M871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-
M86EL`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S
M('=H:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET
M`$5D:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!0
M97)M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO
M;G,@9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O
M+5--4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R
M97-U;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F
M(&EM86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@
M<FEG:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D
M:71O<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL
M(&)E(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L
M(&4N9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@
M=&AE(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%
M<75A=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG
M(&)L;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R
M;W(@9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N
M=#H@)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@
M96UA:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T
M:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R
M(&UI;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E
M<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE
M('9A;'5E<SH`17AE8W5T90!%>'!A;F0`17AP96-T960@)RDG`$5X<&5C=&5D
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$
M871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I
M;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T
M('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R
M=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y
M('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO
M;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E
M.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)
M<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B<G5A<GD`1F5E;',@
M3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R
M<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T(&9O;G0`1FEJ
M:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#;W5N=#H@)7,@9FEL
M97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E;&5C=&EO;@!&:6QE
M('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"X`1FEL=&5R<P!&
M:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&:7@@<F%T:6\`1FQI
M<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X:7-T`$9O;G0@0V]L
M;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&EM86=E
M<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN;W1E('1H870@=&AE
M(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D87D@86YD(&YI9VAT
M.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L="!I;B!A('=I9&4@
M8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M<P!&;W)T=6YE`$9O
M<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O<G5M<P!&;W)W87)D
M<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P;VQI=&%N`$9R965Z
M:6YG($1R:7IZ;&4`1G)E;F-H($=U:6%N80!&<F5N8V@@4&]L>6YE<VEA`$9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<P!&<F]M`$9R;VT@=&AE(`!&=6QL
M($1E<V-R:7!T:6]N`$9U;&P@36]O;@!&=6QL($YA;64`1V%B;VX`1V%L;&5R
M>2!T;R!T86ME(&EM86=E(&9R;VT`1V%L;&5R>3H`1V%M8FEA`$=E;F5R871E
M("5S($-O;F9I9W5R871I;VX`1V5N97)A=&5D($-O9&4`1V5O<F=I80!'97)M
M86YY`$=H86YA`$=I8G)A;'1A<@!':79E;B!.86UE`$=L;V)A;"!/<'1I;VYS
M`$=O`$=O961E;`!';V]G;&4@36%P<P!';V]G;&4@4V5A<F-H`$=R87ES8V%L
M90!'<F5E8V4`1W)E96L@*$E33RTX.#4Y+3<I`$=R965N;&%N9`!'<F5N861A
M`$=R;W5P($%D;6EN:7-T<F%T:6]N`$=R;W5P(&YA;65S(&UU<W0@8F4@;F]N
M+65M<'1Y`$=R;W5P7VQD87`Z(%5N86)L92!T;R!A9&0@9W)O=7`@)7,N(%1H
M:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z(`!'<F]U<%]L9&%P.B!5;F%B
M;&4@=&\@9&5L971E(&=R;W5P("5S`$=R;W5P7VQD87`Z(%5N86)L92!T;R!U
M<&1A=&4@9W)O=7`@)7,`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA
M;&$`1W5E<FYS97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE
M80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY
M(')E9G5S97,@=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,
M07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU
M;6X@:6X@=&%B;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L
M971E('1H92!L87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO
M;B!N;W0@9F]U;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R
M`$AE861E<G,`2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$AE
M879Y(%0M4W1O<FT`2&5B<F5W("A)4T\M.#@U.2TX+4DI`$AE:6=H=`!(96QP
M`$AE;'`@=7-I;F<@961I=&]R`$AE;'!E<@!(96UI<W!H97)E`$AE<F4@:7,@
M=&AE(&)E9VEN;FEN9R!O9B!T:&4@9FEL93H`2&EG:`!(;U]M90!(;VQY(%-E
M92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE($%D9')E<W,`2&]M92!$:7)E
M8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F
M=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B
M.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT
M86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T
M:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N
M9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E
M(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M
M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@
M4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+@!);FAE<FET960@365M8F5R<P!);G-E<G0@0U]O;'5M;B!!
M9G1E<@!);G-E<G0@26UA9V4`26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN
M:P!);G-E<G0@7T-O;'5M;B!"969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A
M9G1E<B!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O
M<F4@=&AE(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE
M(&-U<G)E;G0@;VYE`$EN<V5R="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R
M96YT(&]N90!);G-E<G0@82!P87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@
M;F]D90!);G-E<G0@82!P87)A9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO
M9&4`26YS97)T(&%L=&5R;F%T92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@
M861D<F5S<R!T;R!W:&EC:"!Y;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S
M=V]R9#H`26YS97)T(&-E;&P@869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN
M<V5R="!C;VQU;6X@869T97(`26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T
M(&UE<W-A9V5S`$EN<V5R="!P87)A9W)A<&@@869T97(`26YS97)T('!A<F%G
M<F%P:"!B969O<F4`26YS97)T(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R
M90!);G-E<G0@=&AE(')E<75I<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@
M<75E<W1I;VXZ`$EN<V5R="]-;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,
M:6YK`$EN<W5F9FEC:65N="!C<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I
M8G5T:6]N(&QI<W0N`$EN<W5F9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT
M96=E<B!L:7-T`$EN=F%L:60@541(+B`H57-E<B!$871A($AE861E<BDN`$EN
M=F%L:60@6DE0(&1A=&$`26YV86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B
M871C:"!)1"X`26YV86QI9"!D871A('-U8FUI='1E9"X`26YV86QI9"!D97-T
M:6YA=&EO;B!A9&1R97-S+@!);G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@
M;&EC96YS92!K97DN`$EN=F%L:60@;&]C871I;VX@<')O=FED960N`$EN=F%L
M:60@;7-G7W1Y<&4N`$EN=F%L:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L
M:60@;W(@;6ES<VEN9R!P87)A;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M
M:7-S:6]N+@!);G9A;&ED('!A<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C
M;V1E+@!);G9A;&ED('!R;W1O8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S
M(@!);G9A;&ED('-H87)E(&]B:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S
M+@!);G9A;&ED('5N:6-O9&4@9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE
M8W1I;VX`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`
M27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)
M=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)
M4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*
M=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I
M9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B
M97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.
M97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T
M:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H
M92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO
M8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O
M9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,
M86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T
M($AA;&8`3&%S="!087-S=V]R9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@
M57!D871E9#H`3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E
M<P!,87-T(&QO9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E
M;7!T>2!F;W(@;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,
M969T('9A;'5E<P!,97-O=&AO`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@
M2F%M86AI<FEY80!,:65C:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@
M4F%I;@!,:6=H="!286EN($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!2
M86EN(%-H;W=E<@!,:6=H="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W
M`$QI9VAT(%-N;W<@4VAO=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!54DP`3&EN
M:R!A8V-E<W,@:V5Y`$QI;FL@<&]I;G1S('1O.@!,:6YK('1A<F=E=`!,:6YK
M('1E>'0`3&EN:R!T:&4@96UA:6P@861D<F5S<R!T;R!T:&4@8V]M<&]S92!P
M86=E('=H96X@9&ES<&QA>6EN9P!,:6YK('1I=&QE(&%T=')I8G5T90!,:6YK
M<P!,:6YU>"!#;V]K:64`3&ES="`M('5S97(@8V%N('-E92!T:&4@9F]L9&5R
M`$QI<W0@1&%T86)A<V5S`$QI<W0@2&5L<"!4;W!I8W,`3&ES="!486)L97,`
M3&ES="U!<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES
M="U0;W-T`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&EN
M9R!S97-S:6]N<R!F86EL960Z("5S`$QI<W1I;F<@=7-E<G,@9F%I;&5D.B`E
M<P!,:7-T:6YG('5S97)S(&ES(&1I<V%B;&5D+@!,:71E<F%T=7)E`$QI=&AU
M86YI80!,;V%D:6YG+BXN`$QO8V%L('1I;64Z(`!,;V-A;&4@86YD(%1I;64`
M3&]C871I;VX`3&]G(&EN`$QO9R!O9B!P<F5V:6]U<R!S>6YC('-E<W-I;VX`
M3&]G(&]U=`!,;V=I;@!,;V=I;B!487-K<P!,;V=I;B!F86EL960@8F5C875S
M92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R
M<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E`$QO=P!,;W=E
M<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`3&]W97(@<F]M
M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%1B!!='1A8VAM
M96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C961O;FEA+"!4
M:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G87-C87(`36%G
M:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L87=I`$UA;&%Y
M<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L:7-T(&]F(&-A
M=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET:"P@86YD(&-O
M;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE<RX`36%P,C0@
M;6%P`$UA<%%U97-T(&UA<`!-87!P:6YG<R!S=&]R960N`$UA<F-H`$UA<F=I
M;@!-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,`36%R:R!W:71H(&]T:&5R
M(&9L86=S("AE+F<N($EM<&]R=&%N="]!;G-W97)E9"D`36%R<VAA;&P@27-L
M86YD<P!-87)T:6YI<75E`$UA=&-H:6YG(&9I96QD<P!-875R:71A;FEA`$UA
M=7)I=&EU<P!-87@@86QL;W=E9"!C<F5D:70N`$UA>"!M97-S86=E('!A<G1S
M(&5X8V5E9&5D+@!-87@@=&5M<"!L87-T(#(T(&AO=7)S.B``36%X('1E;7`@
M;&%S="`V(&AO=7)S.B``36%X:6UU;2!.=6UB97(@;V8@4&]R=&%L($)L;V-K
M<P!-87AI;75M(&QE;F=T:`!-87D`36%Y;W1T90!-961I8VEN90!-96UB97)S
M`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S<V%G90!-97-S86=E(%9E<FEF
M:65D(%-U8V-E<W-F=6QL>2!B=70@=&AE('-I9VYE<B=S(&-E<G1I9FEC871E
M(&-O=6QD(&YO="!B92!V97)I9FEE9"X`365S<V%G92!E>'!I<F5D+@!-97-S
M86=E('1Y<&4`365T87(@5V5A=&AE<@!-971A<B!B;&]C:R!N;W0@879A:6QA
M8FQE+@!-971A<B!B;&]C:R!N;W0@879A:6QA8FQE+B!$971A:6QS(&AA=F4@
M8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES=')A=&]R+@!-971A<D1"(&ES
M(&YO="!C;VYN96-T960N`$UE=&AO9`!-971H;V0@(B5S(B!I<R!N;W0@9&5F
M:6YE9`!-971H;V0@;F]T(&1E9FEN960N($-A;&QE9"!M971H;V0Z("5S`$UE
M=')I8P!-97AI8V\`36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-
M:61D;&4`36EM92!4>7!E`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@
M=&5M<"!L87-T(#8@:&]U<G,Z(`!-:6YI;75M('!A<W-W;W)D(&%G92!H87,@
M;F]T('EE="!E>'!I<F5D`$UI<G)O<@!-:7-C96QL86YE;W5S`$UI<W-I;F<@
M4$5!4B!P86-K86=E($A45%!?4F5Q=65S="X`36ES<VEN9R!C;VYF:6=U<F%T
M:6]N+B!9;W4@:&%V92!T;R!G96YE<F%T92!I="!N;W<@:68@>6]U('=A;G0@
M=&\@=7-E('1H:7,@87!P;&EC871I;VXN`$UI<W-I;F<@;65S<V%G92!)1"X`
M36ES<VEN9R!R97%U:7)E9"!014%2('!A8VMA9V4@36%I;"X`36ES<VEN9R!S
M97-S:6]N($E$+@!-;P!-;V)I;&4@36%I;`!-;V1E<F%T90!-;V1I9FEE9"!$
M871E`$UO9&EF>2!54DP`36]D=6QU<P!-;VQD;W9A+"!297!U8FQI8R!O9@!-
M;VYA8V\`36]N9V]L:6$`36]N=&@@86YD('EE87(`36]N=&AL>0!-;VYT<V5R
M<F%T`$UO;VX@4&AA<V5S`$UO<F4@9FEE;&1S(&9O=6YD(&EN(&QI;F4@)60@
M=&AA;B!T:&4@97AP96-T960@)60N`$UO<F]C8V\`36]S=&QY($-L96%R`$UO
M<W1L>2!#;&]U9'D`36]S=&QY($-L;W5D>2!A;F0@5VEN9'D`36]S=&QY(%-U
M;FYY`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V92!2:6=H=`!-;W9E(%5P`$UO
M=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`375L=&DM;&5V96P@9')O<"!D
M;W=N(&QI<W1S`$UU;'1I;6%P(%5+(&UA<`!-=6QT:7!L92!S96QE8W1I;VX`
M37D@06-C;W5N=`!->2!!8V-O=6YT($EN9F]R;6%T:6]N`$UY(%!O<G1A;`!-
M>2!0;W)T86P@3&%Y;W5T`$UY86YM87(`3D\L($D@1&\@3D]4($%G<F5E`$YA
M;64`3F%M:6)I80!.875R=0!.97!A;`!.971H97)L86YD<P!.971H97)L86YD
M<R!!;G1I;&QE<P!.971S8V%P92!"87-E(%523`!.971S8V%P92!#02!2979O
M8V%T:6]N(%523`!.971S8V%P92!#02!P;VQI8WD@55),`$YE='-C87!E(%)E
M;F5W86P@55),`$YE='-C87!E(%)E=F]C871I;VX@55),`$YE='-C87!E(%-3
M3"!S97)V97(@;F%M90!.971S8V%P92!C97)T:69I8V%T92!C;VUM96YT`$YE
M='-C87!E(&-E<G1I9FEC871E('1Y<&4`3F5T=V]R:P!.979E<@!.97<@0V%L
M961O;FEA`$YE=R!#871E9V]R>0!.97<@36]O;@!.97<@57-E<FYA;64@*&]P
M=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@<&%S<W=O<F0`3F5W('!A<W-W;W)D
M('=I;&P@97AP:7)E(&]N("5X+@!.97<@<&%S<W=O<F1S(&1O;B=T(&UA=&-H
M+@!.97<@=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE
M>'0@-"!0:&%S97,`3F5X="!O<'1I;VYS`$YE>'0^`$YI8V%R86=U80!.:6=E
M<@!.:6=E<FEA`$YI9VAT`$YI=64`3F\`3F\@879A:6QA8FQE(&-O;F9I9W5R
M871I;VX@9&%T82!T;R!S:&]W(&1I9F9E<F5N8V5S(&9O<BX`3F\@879A:6QA
M8FQE('-T<F%T96=Y(&9O<B!M86MI;F<@25-/(&EM86=E<RX`3F\@8F%T8V@@
M=&5M<&QA=&4N`$YO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N`$YO(&-A;&5N9&%R(&YA;64@<')O=FED960@9F]R($U#04P@875T
M:&5N=&EC871I;VXN`$YO(&-H86YG92X`3F\@8VAI;&1R96X@8V%N(&)E(&%D
M9&5D('1O('1H:7,@<&5R;6ES<VEO;BX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O
M<FUA=&EO;B!S<&5C:69I960@9F]R("5S+@!.;R!C;VYF:6=U<F%T:6]N(&EN
M9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@1E10(%9&4RX`3F\@8V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R(%-13"!61E,N`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344PM1FEL
M92!61E,N`$YO(&-R961I="!L969T+@!.;R!D97-T:6YA=&EO;B!S=7!P;&EE
M9"X`3F\@9FEL92!U<&QO861E9`!.;R!I8V]N<R!F;W5N9"X`3F\@;&]C871I
M;VX@:7,@<V5T+@!.;R!L;V-A=&EO;B!P<F]V:61E9"X`3F\@;65S<V%G92!S
M=7!P;&EE9"X`3F\@;F%M92!S<&5C:69I960N`$YO(&YU;6)E<B!S<&5C:69I
M960N`$YO(&]F9F5N<VEV92!F;W)T=6YE<P!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@2%144"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($E-05`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I
M9&5D(&9O<B!+97)B97)O<R!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@
M<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R
M9"!P<F]V:61E9"!F;W(@4$%34U=$(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S
M=V]R9"!P<F]V:61E9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;R!P871H
M('1O('1H92!/<&5N4U-,(&)I;F%R>2!P<F]V:61E9"X@5&AE($]P96Y34TP@
M8FEN87)Y(&ES(&YE8V5S<V%R>2!T;R!W;W)K('=I=&@@4$M#4R`Q,B!D871A
M+@!.;R!P96YD:6YG('-I9VYU<',N`$YO('%U;W1A('-E="X`3F\@<G5L97,`
M3F\@<V5P87)A=&]R('-P96-I9FEE9"X`3F\@<VED97,`3F\@<W5C:"!F:6QE
M`$YO('1E;7!O<F%R>2!D:7)E8W1O<GD@879A:6QA8FQE(&9O<B!C86-H92X`
M3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D('-E;G0N`$YO('9A;&ED(%A-
M3"!D871A(')E='5R;F5D`$YO('9A;'5E<P!.;R!V97)S:6]N(&9O=6YD(&EN
M(&]R:6=I;F%L(&-O;F9I9W5R871I;VXN(%)E9V5N97)A=&4@8V]N9FEG=7)A
M=&EO;BX`3F\@=F5R<VEO;B!F;W5N9"!I;B!Y;W5R(&-O;F9I9W5R871I;VXN
M(%)E9V5N97)A=&4@8V]N9FEG=7)A=&EO;BX`3F]N90!.;VYE("AU<V4@:6UP
M;&EC:70I`$YO<F1I8R`H25-/+3@X-3DM,3`I`$YO<F9O;&L@27-L86YD`$YO
M<G1H97)N($AE;6ES<&AE<F4`3F]R=&AE<FX@36%R:6%N82!)<VQA;F1S`$YO
M<G=A>0!.;W0@069T97(`3F]T($)E9F]R90!.;W0@82!D:7)E8W1O<GD`3F]T
M(&9O=6YD+@!.;W0@:6UP;&5M96YT960N`$YO="!S970`3F]T('-U<'!O<G1E
M9"X`3F]T97,`3F]T:&EN9R!T;R!B<F]W<V4L(&=O(&)A8VLN`$YO=F5M8F5R
M`$YU;6)E<@!.=6UB97(@;V8@8VAA<F%C=&5R<P!.=6UB97(@;V8@8V]L=6UN
M<P!.=6UB97(@;V8@<F]W<P!.=6UB97)S(&YO="!S<&5C:69I960@9F]R('5P
M9&%T:6YG(&EN(&1I<W1R:6)U=&EO;B!L:7-T+@!/2P!/8FIE8W0`3V)J96-T
M($-R96%T;W(`3V-T86P`3V-T;V)E<@!/9F9E;G-E(&9I;'1E<@!/9F9I8V4`
M3VQD(&%N9"!N97<@<&%S<W=O<F1S(&UU<W0@8F4@9&EF9F5R96YT+@!/;&0@
M<&%S<W=O<F0`3VQD('!A<W-W;W)D(&ES(&YO="!C;W)R96-T+@!/;6%N`$]N
M8VQI8VL@979E;G0`3VYL>2!)34%0('-E<G9E<G,@<W5P<&]R="!S:&%R960@
M9F]L9&5R<RX`3VYL>2!O9F9E;G-I=F4@9F]R='5N97,`3VYL>2!O;F4@96UA
M:6P@861D<F5S<R!A;&QO=V5D+@!/;FQY('1H92!O=VYE<B!O<B!S>7-T96T@
M861M:6YI<W1R871O<B!M87D@8VAA;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P
M97)M:7-S:6]N<R!F;W(@82!S:&%R90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/
M<&5N4U-,(&5R<F]R.B!#;W5L9"!N;W0@97AT<F%C="!D871A(&9R;VT@<VEG
M;F5D(%,O34E-12!P87)T+@!/<&5N<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN
M9&]W`$]P97)A=&EN9R!3>7-T96T`3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/
M<F1E<F5D($QI<W0`3W)G86YI<V%T:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`
M3W)G86YI>FEN9P!/<FEG:6YA;"!A<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG
M:6YA;"!T96UP;&%T97,@:6X@)7,Z`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N
M`$]W;F5R(%!E<FUI<W-I;VYS`%!!32!A=71H96YT:6-A=&EO;B!I<R!N;W0@
M879A:6QA8FQE+@!014%2.CI-86EL(&)A8VME;F0`4$=0($1I9VET86P@4VEG
M;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B;&EC($ME>0!01U`@
M4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,
M:6=H="!286EN`%!-(%)A:6X`4$T@4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@
M4VAO=V5R<P!032!3=6X`4$T@5"U3=&]R;7,`4$]325@@97AT96YS:6]N(&ES
M(&UI<W-I;F<`4%](4"!3:&5L;`!0861D:6YG`%!A:VES=&%N`%!A;&%U`%!A
M;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960`4&%N86UA`%!A<'5A($YE
M=R!'=6EN96$`4&%R86=U87D`4&%R=&QY($-L;W5D>0!087-S=V]R9`!087-S
M=V]R9"!C:&%N9V5D('-U8V-E<W-F=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T
M`%!A<W-W;W)D(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN
M`%!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R
M9#H@`%!A<W-W;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L
M:7!B;V%R9`!0871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`
M4&5R9F]R;2!-86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S
M:6]N("(E<R(@;F]T(&1E;&5T960N`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI
M<W-I;VYS`%!E<FUI<W-I;VYS($%D;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN
M9F]R;6%T:6]N`%!E<G4`4&5T<P!0:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`
M4&ET8V%I<FX`4&EX96QS`%!L871I='5D97,`4&QE87-E(&-L:6-K(&EN=&\@
M<V]M92!C96QL`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@<F5M
M;W9E('1H:7,@96QE;65N=#H`4&QE87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N
M="!T;R!U;FQI;FL@=&AI<R!E;&5M96YT+@!0;&5A<V4@96YT97(@82!M;VYT
M:"!A;F0@82!Y96%R+@!0;&5A<V4@96YT97(@82!N86UE(&9O<B!T:&4@;F5W
M(&-A=&5G;W)Y.@!0;&5A<V4@96YT97(@82!V86QI9"!)4"!A9&1R97-S+@!0
M;&5A<V4@96YT97(@82!V86QI9"!D871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F
M(&1A>7,@:6X@=&AE(&UO;G1H+@!0;&5A<V4@96YT97(@82!V86QI9"!T:6UE
M+@!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L
M96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD('!A<W-W;W)D`%!L96%S
M92!R96%D('1H92!F;VQL;W=I;F<@=&5X="X@66]U($U54U0@86=R964@=VET
M:"!T:&4@=&5R;7,@=&\@=7-E('1H92!S>7-T96TN`%!L96%S92!T>7!E('1H
M92!N97<@8V%T96=O<GD@;F%M93H`4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O
M<G1U9V%L`%!O<VET:6]N:6YG(&]F('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@
M;V8@=&AI<R!T86)L90!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@96YF;W)C
M960@8GD@24U!4"D`4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I
M.B``4')E8VEP:71A=&EO;CQB<B`O/F-H86YC90!0<F5F<U]L9&%P.B!297%U
M:7)E9"!,1$%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ
M(%)E<75I<F5D('-E<W-I;VX@97AT96YS:6]N(&YO="!F;W5N9"X`4')E<W-U
M<F4`4')E<W-U<F4@870@<V5A(&QE=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W
M`%!R979I97<@=&AE(&EM86=E(&EN(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O
M<'1I;VYS`%!R:6YT(&1O8W5M96YT`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O
M8FQE;2!$97-C<FEP=&EO;@!0<F]J96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@
M2V5Y`%!U8FQI8R!+97D@06QG;W)I=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L
M:6,O4')I=F%T92!K97EP86ER(&YO="!G96YE<F%T960@<W5C8V5S<V9U;&QY
M+@!0=65R=&\@4FEC;P!0=7)G92!M97-S86=E<P!1871A<@!1=65R>0!1=6]T
M80!24T$@4'5B;&EC($ME>2`H)60@8FET*0!2861I;R!S96QE8W1I;VX`4F%I
M;@!286EN($5A<FQY`%)A:6X@3&%T90!286EN(%-H;W=E<@!286EN(&%N9"!3
M;F]W`%)A:6X@=&\@4VYO=P!286YD;VT@1F]R='5N90!2871I;P!296%D`%)E
M860@;65S<V%G97,`4F5A;&QY(&1E;&5T92`E<S\@5&AI<R!O<&5R871I;VX@
M8V%N;F]T(&)E('5N9&]N92X`4F5A;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R
M('5S97(@)7,_(%1H:7,@;W!E<F%T:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E
M9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC
M($UE;G4@16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E
M;&%T:6]N<VAI<"!"<F]W<V5R`%)E;&]A9`!296UA<FMS`%)E;6]T92!397)V
M97)S`%)E;6]T92!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I
M.@!296UO=F4`4F5M;W9E($)L;V-K`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O
M<FUA='1I;F<`4F5M;W9E('!A:7(`4F5M;W9E('-A=F5D('-C<FEP="!F<F]M
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M
M;W9E('1H:7,@;F]D92!F<F]M('1H92!D;V-U;65N=`!296UO=F4@=7-E<@!2
M96UO=F4@=7-E<CH@)7,`4F5Q=65S="!C;W5L9&XG="!B92!A;G-W97)E9"X@
M4F5T=7)N960@97)R;W)C;V1E.B``4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@
M;F]T(&)E(&9O=6YD+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@
M)7,@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@(B5S(B!N;W0@<W!E8VEF:65D
M(&EN(%9&4R!C;VYF:6=U<F%T:6]N+@!297%U:7)E9"`B)7,B(&YO="!S<&5C
M:69I960@:6X@8V]N9FEG=7)A=&EO;BX`4F5Q=6ER960@1FEE;&0`4F5S970`
M4F5S970@4&%S<W=O<F0`4F5S970@66]U<B!087-S=V]R9`!297-T;W)E($QA
M<W0@475E<GD`4F5S=6QT<P!2971U<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W
M('!A<W-W;W)D`%)E=6YI;VX`4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!4
M97AT($5D:71O<B!/<'1I;VYS`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R
M`%)I9VAT('9A;'5E<P!2;U]W(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA
M`%)O=&%T92`Q.#``4F]T871E($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P
M97)T:65S`%)O=R!P<F]P97)T:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@
M87!P96%R(&)E='=E96X@86QL(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL
M;"!A<'!E87(@8F5T=V5E;B!C;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E
M87(@8F5T=V5E;B!R;W=S(&]N;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2
M=V%N9&$`4R]-24U%($-R>7!T;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%
M;F-R>7!T960@365S<V%G90!305-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A
M=F%I;&%B;&4N`%--4R!-97-S86=I;F<`4U%,(%-H96QL`%-13"!S=&%T96UE
M;G0@9F]R('9A;'5E(&QO;VMU<',`4U-(`%-50T-%4U,`4U]13"!3:&5L;`!3
M80!386EN="!(96QE;F$`4V%I;G0@2VET=',@86YD($YE=FES`%-A:6YT($QU
M8VEA`%-A:6YT(%!I97)R92!A;F0@36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A
M;F0@=&AE($=R96YA9&EN97,`4V%M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A
M;B!-87)I;F\`4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V
M:61E<@!3875D:2!!<F%B:6$`4V%V90!3879E("(E<R(`4V%V92`E<P!3879E
M($]P=&EO;G,`4V%V92!G96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(
M4"!S8W)I<'0@=&\@>6]U<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y
M+@!3879E9"`E<R!C;VYF:6=U<F%T:6]N+@!3879E9"!S971U<"!U<&=R861E
M('-C<FEP="!T;SH@(B5S(BX`4V-A='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`
M4V5A<F-H`%-E87)C:"!%;F=I;F5S`%-E;&5C="!&:6QE<P!396QE8W0@82!D
M871E`%-E;&5C="!A(&=R;W5P('1O(&%D9`!396QE8W0@82!N97<@;W=N97(`
M4V5L96-T(&$@<V5R=F5R`%-E;&5C="!A('5S97(@=&\@861D`%-E;&5C="!A
M;&P`4V5L96-T(&%L;"!D871E(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE
M8W0`4V5L96-T(&YO;F4`4V5L96-T('1H92!C:&%R86-T97)S('EO=2!N965D
M(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@
M<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N`%-E;&5C="!T:&4@9&%T
M92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F;W)M870Z`%-E;&5C="!T
M:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@=&AE('1I
M;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@9F]R;6%T.@!396QE8W0@
M='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO=7(@8V]L;W(@<V-H96UE
M+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE
M;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS;W(Z(`!397!T96UB97(`
M4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A
M=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S<VEO;B!!9&UI;@!397-S
M:6]N($E$(&5X<&ER960N`%-E<W-I;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A
M;&QO=R!Y;W4@=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F
M;W)G970@:70N`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT
M('1O(&%C8V5S<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y
M;W5R('-T87)T=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R
M969R97-H:6YG+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3
M971U<"!U<&=R861E('-C<FEP=',@879A:6QA8FQE`%-E=F5R86P@;&]C871I
M;VYS('!O<W-I8FQE('=I=&@@=&AE('!A<F%M971E<CH@`%-E>6-H96QL97,`
M4VAO<'!I;F<`4VAO<G0@4W5M;6%R>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@
M9&5F:6YE9"!F;W(@;6]S="!L:6YK<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S
M(&)E='=E96X@8W5R<F5N=&QY('-A=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VXN`%-H;W<@;&%S="!L;V=I;B!T:6UE('=H96X@
M;&]G9VEN9R!I;C\`4VAO=R!O<'1I;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W
M('!I8VME<@!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_`%-H;W<@
M=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@
M4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D
M:6%L;V<`4VAO=R!T:&4@5&%B;&4@4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(&EM86=E('!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H
M;W=E<G,`4VAO=V5R<R!%87)L>0!3:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T
M:&4@5FEC:6YI='D`4VAR:6YK`%-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN
M9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`
M4VEG;B!U<`!3:6=N871U<F4`4VEG;F%T=7)E($%L9V]R:71H;0!3:6YG87!O
M<F4`4VEZ90!3:VEP($UA:6YT96YA;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N
M;W<`4VYO=R!3:&]W97(`4VYO=R!3:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L
M>0!3;F]W(%-H;W=E<G,@3&%T90!3;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L
M96YT(&EN('=A=&5R.B``4V]L;VUO;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@
M)B!0;V5M<P!3;W)T(&]R9&5R('-E;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3
M;W5T:"!!9G)I8V$`4V]U=&@@175R;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H
M($=E;W)G:6$@86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-O=71H
M97)N($AE;6ES<&AE<F4`4W!A8V4@8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3
M<&%C92!B971W965N(&-O;G1E;G0@86YD(&)O<F1E<B!I;B!C96QL`%-P86-E
M<@!3<&%C:6YG`%-P86-I;F<@86YD('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C
M:6%L($-H87)A8W1E<B!);G!U=`!3<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3
M<&QI="!R;W<`4W!O<G1S`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`
M4W1A<G0@>65A<@!3=&%T92!O<B!0<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F
M;W)M870`4W1R965T($%D9')E<W,`4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES
M=`!3=')I<"!D;VUA:6X@9G)O;2!T:&4@861D<F5S<P!3='EL92!;0U-370!3
M=0!3=6)D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET
M`%-U8FUI='1E9"!R97%U97-T('1O(&%D9"`B)7,B('1O('1H92!S>7-T96TN
M(%EO=2!C86YN;W0@;&]G(&EN('5N=&EL('EO=7(@<F5Q=65S="!H87,@8F5E
M;B!A<'!R;W9E9"X`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&-L96%R960@
M9&%T82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U
M;&QY(&1E;&5T960@(B5S(BX`4W5C8V5S<V9U;&QY(')E;6]V960@(B5S(B!F
M<F]M('1H92!S>7-T96TN`%-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U
M<F%T:6]N+B!296QO860@=&\@<V5E(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S
M879E9"!B86-K=7`@8V]N9FEG=7)A=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L
M;'D@=7!D871E9"`B)7,B`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3
M=6UM87)Y`%-U;B!2:7-E`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E
M+U-U;G-E=`!3=6YR:7-E.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T
M`%-U<'!O<G0`4W5R:6YA;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA
M>65N`%-W87II;&%N9`!3=V5D96X`4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L
M971E9`!3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E<FUS`%-Y<FEA;B!!<F%B
M(%)E<'5B;&EC`%0M4W1O<FT`5"U3=&]R;2!A;F0@5VEN9'D`5"U3=&]R;7,`
M5"U3=&]R;7,@16%R;'D`5%-6(&9I;&4`5&%B;&4@4')O<&5R=&EE<P!486)L
M92!3970`5&%B;&4@<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC
M92!O9B!#:&EN80!486II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L
M:6,@;V8`5&%R9V5T.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R
M(&QA<W0@:&]U<CH@`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&5R
M871U<F4\8G(@+SXH)7-(:25S+R5S3&\E<RD@)F1E9SLE<P!496UP;&%T92`B
M)7,B(&YO="!F;W5N9"X`5&5M<&QA=&4@061M:6YI<W1R871I;VX`5&5X=`!4
M97AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H86D@*%1)4RTV,C`I
M`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO="!A=F%I;&%B;&4N
M`%1H92!(:7-T;W)Y('-Y<W1E;2!I<R!D:7-A8FQE9"X`5&AE($AO<F1E+TMO
M;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T("(E<R(`
M5&AE($E-4U`@;&]G(&-O=6QD(&YO="!B92!I;FET:6%L:7IE9"X`5&AE($UA
M:6YT96YA;F-E.CH@8VQA<W,@9&ED(&YO="!L;V%D('-U8V-E<W-F=6QL>0!4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&%D
M;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@<&5R;6%N96YT(%!E
M<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@=7-E(%!E<FUI<W-I
M;VYS+@!4:&4@8F]T=&]M('-I9&4@;VYL>0!4:&4@8V]N=&%C="!)1"!N=6UB
M97(@=V%S(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F
M;W5N9"!I;B!T:&4@9&%T86)A<V4N`%1H92!C;VYT86-T('=A<R!S=6-C97-S
M9G5L;'D@861D960@=&\@>6]U<B!A9&1R97-S(&)O;VLN`%1H92!D971A8VAE
M9"!01U`@<VEG;F%T=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T
M:&4@<VEG;F5D(&UE<W-A9V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!)1"!W
M87,@96ET:&5R(&YO="!S<&5C:69I960L(&QE9G0@8FQA;FL@;W(@;F]T(&9O
M=6YD(&EN('1H92!D871A8F%S92X`5&AE(&1I<W1R:6)U=&EO;B!L:7-T('=A
M<R!N;W0@<W!E8VEF:65D+@!4:&4@96YC<GEP=&EO;B!F96%T=7)E<R!R97%U
M:7)E(&$@<V5C=7)E('=E8B!C;VYN96-T:6]N+@!4:&4@9FEL92`E<R!S:&]U
M;&0@8V]N=&%I;B!A("5S('-E='1I;F<N`%1H92!F:6QE("5S('-H;W5L9"!C
M;VYT86EN('-O;64@)7,@<V5T=&EN9W,N`%1H92!F:6QE(&-O;G1A:6YE9"!N
M;R!D871A+@!4:&4@9F]L;&]W:6YG(&%R92!T:&4@:&5A9&5R<R!F;W(@=&AI
M<R!M97-S86=E+W)F8S@R,B!M97-S86=E+@!4:&4@9G5L;"!S8W)E96X@;6]D
M92!I<R!K;F]W;B!T;R!C875S92!P<F]B;&5M<R!W:71H($EN=&5R;F5T($5X
M<&QO<F5R+"!D=64@=&\@8G)O=W-E<B!B=6=S('1H870@=V4@=V5R96XG="!A
M8FQE('1O('=O<FMA<F]U;F0N("!9;W4@;6EG:'0@97AP97)I96YC92!G87)B
M86=E(&1I<W!L87DL(&QA8VL@;V8@961I=&]R(&9U;F-T:6]N<R!A;F0O;W(@
M<F%N9&]M(&)R;W=S97(@8W)A<VAE<RX@($EF('EO=7(@<WES=&5M(&ES(%=I
M;F1O=W,@.7@@:70G<R!V97)Y(&QI:V5L>2!T:&%T('EO=2=L;"!G970@82`G
M1V5N97)A;"!0<F]T96-T:6]N($9A=6QT)R!A;F0@;F5E9"!T;R!R96)O;W0N
M7&Y<;EEO=2!H879E(&)E96X@=V%R;F5D+B`@4&QE87-E('!R97-S($]+(&EF
M('EO=2!S=&EL;"!W86YT('1O('1R>2!T:&4@9G5L;"!S8W)E96X@961I=&]R
M+@!4:&4@:61E;G1I='D@(B5S(B!H87,@8F5E;B!D96QE=&5D+@!4:&4@;&5F
M="UH86YD('-I9&4@;VYL>0!4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I
M;F%R>2!M=7-T(&)E(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RX`
M5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H('-U8FIE8W0@(B5S
M(B!H87,@8F5E;B!D:7-P;&%Y960N"E1H:7,@:7,@;F\@9W5A<F%N=&5E('1H
M870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O<B!U;F1E<G-T;V]D+@!4
M:&4@;F%M92!T;R!U<V4@=VAE;B!L:6YK:6YG('1O('1H92!C;VUP;W-E('!A
M9V4`5&AE(&YU;6)E<B!O9B!F:65L9',@;75S="!B92!N=6UE<FEC+@!4:&4@
M;W!E;G-S;"!M;V1U;&4@:7,@<F5Q=6ER960@9F]R('1H92!(;W)D95]#<GEP
M=%]S;6EM93HZ(&-L87-S+@!4:&4@<')E9F5R96YC92`B)7,B(&-O=6QD(&YO
M="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M87AI
M;75M(&%L;&]W86)L92!S:7IE`%1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T
M:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E
M;2X`5&AE('%U;W1E(&-H87)A8W1E<B!M=7-T(&)E(&]N92!S:6YG;&4@8VAA
M<F%C=&5R+@!4:&4@<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG
M:'0M:&%N9"!S:61E(&]N;'D`5&AE('-E<&%R871O<B!M=7-T(&)E(&]N92!S
M:6YG;&4@8VAA<F%C=&5R+@!4:&4@<V5R=F5R("(E<R(@:&%S(&)E96X@9&5L
M971E9"X`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N('-A=F5D+@!4:&4@<VEG
M;G5P(')E<75E<W0@9F]R("5S(&AA<R!B965N(')E;6]V960N`%1H92!S<&5C
M:69I960@<F]W("@E9"D@9&]E<R!N;W0@97AI<W0N`%1H92!T96UP;W)A<GD@
M9FEL92`B)7,B(&1O97,@;F]T(&5X:7-T+@!4:&4@=&5X="!Y;W4@96YT97)E
M9"!D:60@;F]T(&UA=&-H('1H92!T97AT(&]N('1H92!S8W)E96XN`%1H92!T
M;W`@86YD(&)O='1O;2!S:61E<R!O;FQY`%1H92!T;W`@<VED92!O;FQY`%1H
M92!U<&QO861E9"!D871A('=A<R!L;W-T('-I;F-E('1H92!P<F5V:6]U<R!S
M=&5P+@!4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@<V%V960N`%1H
M92!W96%T:&5R+F-O;2!B;&]C:R!I<R!N;W0@879A:6QA8FQE+@!4:&5M97,@
M9&ER96-T;W)Y("(E<R(@;F]T(&9O=6YD+@!4:&5R92!A<F4@;F\@;W!T:6]N
M<R!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!P87)T<R!T:&%T(&-A;B!B92!D
M:7-P;&%Y960@:6YL:6YE+@!4:&5R92!A<F4@=&]O(&UA;GD@8VAA<F%C=&5R
M<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S(&-H87)A8W1E
M<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RX`5&AE<F4@=V%S(&$@
M<')O8FQE;2!A9&1I;F<@(B5S(B!T;R!T:&4@<WES=&5M.B`E<P!4:&5R92!W
M87,@82!P<F]B;&5M(&-L96%R:6YG(&1A=&$@9F]R('5S97(@(B5S(B!F<F]M
M('1H92!S>7-T96TZ(`!4:&5R92!W87,@82!P<F]B;&5M(')E;6]V:6YG("(E
M<R(@9G)O;2!T:&4@<WES=&5M.B``5&AE<F4@=V%S(&$@<')O8FQE;2!U<&1A
M=&EN9R`B)7,B.B`E<P!4:&5R92!W87,@82!P<F]B;&5M('=I=&@@=&AE(&9I
M;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R
M('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H97)E('=A<R!A;B!E
M<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T`%1H97)E('=A<R!A
M;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82X`5&AE<F4@=V%S
M(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R(&1A=&$N`%1H97)E
M('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO;B!F;W)M+B!097)H
M87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD+@!4:&5R92!W87,@
M86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D(&%D9')E<W,@8F]O
M:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@=V%S
M(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E=&%I;',N(%!L96%S
M92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E<G)O<B!U<&1A=&EN
M9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T<GD@86=A:6X@;&%T
M97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S:&%R:6YG
M(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@
M<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L
M:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T;R!B92!A('9A;&ED
M(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M
M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI8VMA
M=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R
M:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!7
M24X@*&AT='`Z+R]W:6YP;&,N8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%14
M4"!!4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@
M=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL+F-O;2D@
M9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W
M<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@=&AE(%9O
M9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@;G5M8F5R
M<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O9&%F;VYE
M($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN`%1H:7,@9FEE;&0@:7,@<F5Q
M=6ER960N`%1H:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!I;G1E9V5R<RX`
M5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&YU;6)E<G,@86YD('1H92!C
M;VQO;BX`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&]C=&%L('9A;'5E
M<RX`5&AI<R!F:65L9"!M=7-T(&)E(&$@8V]M;6$@;W(@<W!A8V4@<V5P87)A
M=&5D(&QI<W0@;V8@:6YT96=E<G,`5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L
M:60@;G5M8F5R+@!4:&ES(&9I96QD(&UU<W0@8V]N=&%I;B!A(&-O;&]R(&-O
M9&4@:6X@=&AE(%)'0B!(97@@9F]R;6%T+"!F;W(@97AA;7!L92`G(S$R,S1A
M9B<N`%1H:7,@9F]R;2!H87,@86QR96%D>2!B965N('!R;V-E<W-E9"X`5&AI
M<R!I<R`E<RX`5&AI<R!I<R!A($MO;&%B($=R;W5P=V%R92!O8FIE8W0N(%1O
M('9I97<@=&AI<R!O8FIE8W0@>6]U('=I;&P@;F5E9"!A;B!E;6%I;"!C;&EE
M;G0@=&AA="!U;F1E<G-T86YD<R!T:&4@2V]L86(@1W)O=7!W87)E(&9O<FUA
M="X@1F]R(&$@;&ES="!O9B!S=6-H(&5M86EL(&-L:65N=',@<&QE87-E('9I
M<VET("5S`%1H:7,@;65S<V%G92!W87,@=W)I='1E;B!I;B!A(&-H87)A8W1E
M<B!S970@*"5S*2!O=&AE<B!T:&%N('EO=7(@;W=N+@!4:&ES(&YU;6)E<B!M
M=7-T(&)E(&%T(&QE87-T(&]N92X`5&AI<R!S97)V97(@8V%N)W0@=6YC;VUP
M<F5S<R!Z:7`@86YD(&=Z:7`@9FEL97,N`%1H:7,@<WES=&5M(&ES(&-U<G)E
M;G1L>2!D96%C=&EV871E9"X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R
M+@!4:&ES('=I;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@
M=VEN9&]W`%1H=6YD97(`5&EC:V5T<P!4:6UE`%1I;64@5')A8VMI;F<`5&EM
M92!F;W)M870`5&EM92!S96QE8W1I;VX`5&EM;W(M3&5S=&4`5&ET;&4`5&ET
M;&4@*'1O;VQT:7`I.@!4;P!4;R!S96QE8W0@;75L=&EP;&4@:71E;7,L(&AO
M;&0@9&]W;B!T:&4@0V]N=')O;"`H4$,I(&]R($-O;6UA;F0@*$UA8RD@:V5Y
M('=H:6QE(&-L:6-K:6YG+@!4;V1A>0!4;V=G;&4@2%1-3"!3;W5R8V4`5&]G
M;P!4;VME;&%U`%1O;6]R<F]W`%1O;F=A`%1O;R!M86YY(&EN=F%L:60@;&]G
M:6YS(&1U<FEN9R!T:&4@;&%S="!M:6YU=&5S+@!4;W``5&]P(&9R86UE("A?
M=&]P*0!4<F%N<VQA=&EO;G,`5')I;FED860@86YD(%1O8F%G;P!4<G5E(&]R
M(&9A;'-E`%1U`%1U;FES:6$`5'5R:V5Y`%1U<FMI<V@@*$E33RTX.#4Y+3DI
M`%1U<FMM96YI<W1A;@!4=7)K<R!A;F0@0V%I8V]S($ES;&%N9',`5'5V86QU
M`%1Y<&4@>6]U<B!C:&]I8V4Z(`!5+E8N(&EN9&5X.B``55),`%523"!F;W(@
M>6]U<B!S8W)I<'0@9&5L:79E<GD@<W1A='5S(')E<&]R=`!54DPZ`%5G86YD
M80!5:W)A:6YE`%5N86)L92!T;R!A8V-E<W,@5D93(&1I<F5C=&]R>2X`56YA
M8FQE('1O(&%D9"!E>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN
M9R!U<"X`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL
M92`B)7,B+@!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F
M:6QE("5S+R5S+@!5;F%B;&4@=&\@8VAA;F=E('1O("5S+@!5;F%B;&4@=&\@
M8VAE8VL@9FEL92!S:7IE(&]F("(E<R(N`%5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@(B5S+R5S(BX`56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E
M<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN`%5N86)L92!T;R!C
M;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E8W1O<GD@
M(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@
M=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F;VQD
M97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!61E,@9FEL92X`56YA
M8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O(&1E;&5T92`B)7,B
M+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA8FQE('1O(&1E;&5T
M92`B)7,B.B`E<RX`56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='D`56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M(')E8W5R<VEV96QY+@!5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN
M`%5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@
M9FEL92X`56YA8FQE('1O(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L
M92!T;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E
M=&5R;6EN92!C=7)R96YT(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@
M8V5R=&EF:6-A=&4@9&5T86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI
M=&EO;B!O9B`E<RX`56YA8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T
M;R!O<&5N(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M(&9O<B!W<FET:6YG+@!5;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE
M('1O(&]P96X@8V]M<')E<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H9FEL97-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!6
M1E,@9FEL92`H<VEZ92@I(&9A:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z
M(`!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!R96YA;64@)7,@=&\@)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E
M861Y(&5X:7-T<P!5;F%B;&4@=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N
M86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92`E<R\E<RX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O
M(')U;B`G;6MI<V]F<R<N`%5N86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D
M(&1O8W5M96YT`%5N86)L92!T;R!T<FEG9V5R(&9R964O8G5S>2!U<&1A=&4@
M9F]R("5S`%5N86)L92!T;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@
M=&\@=W)I=&4@5D93(&9I;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@
M=W)I=&4@5D93(&9I;&4@9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE
M+"!Q=6]T82!W:6QL(&)E(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N
M9V5S`%5N9&]E<R!Y;W5R(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N
M<V4@9G)O;2!S97)V97(@;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S
M<&]N<V4@9G)O;2!S97)V97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX
M*0!5;FET960@07)A8B!%;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@
M4W1A=&5S`%5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5
M;FET<P!5;FMN;W=N`%5N:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$
M*2X`56YK;F]W;B!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN
M;W=N(&QO8V%T:6]N('!R;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A
M<W-W;W)D+@!5;FQI;FL@=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N
M<')I=FEL96=E9"!S8W)I<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S
M=&4@<')O9W)A;6%T:6-A;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI
M8VL@3TL@=&\@<V5E(&$@=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@
M=VAI8V@@<VAO=W,@>6]U(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E
M<W,@=&AE(&-L:7!B;V%R9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT
M96YS:6]N`%5P9&%T90!5<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B
M)7,B+@!5<&=R861E('-C<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@
M86QL(&%P<&QI8V%T:6]N('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P
M<&5R(&QA=&EN(&QE='1E<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y
M`%5S92!#=7)R96YT.B`E<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D
M(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I
M<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`
M57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T
M:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C
M;W5N="!N;W0@9F]U;F0`57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y
M(&5X:7-T<RX`57-E<FYA;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y
M<W1E;3H`57IB96MI<W1A;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T
M+@!686-A=&EO;@!686QI9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A
M;&ED:71Y`%9A;'5E(&EN(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V
M97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O
M('-E;&5C="!F<F]M`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF
M:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T
M86UP97)E9"!W:71H+@!697)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A
M;"!A;&EG;@!697)T:6-A;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`
M5FEE="!.86T`5FEE=&YA;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@
M97AT97)N86P@=V5B('!A9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@
M0G)I=&ES:`!6:7)G:6X@27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB
M:6QI='DZ(`!6;V1A9F]N92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A
M(2$@4D5-3U9%(%-#4DE05"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A4
M5%``5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C
M87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES
M($%U<W1R86QI82!M87``5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@
M96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@
M:6X@0U-3('5N:71S`%=I9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T
M("AT86ME<R!E9F9E8W0@;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@
M=&%B;&4`5VED=&@@=6YI=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`
M5VEN9"!S<&5E9"!I;B!K;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL
M:7-T`%=O<FL`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R
M(&]F(&9I96QD<R!I;B!L:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N
M`%=R;VYG(&YU;6)E<B!O9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E
M9"X`5W)O;F<@;V9F<V5T("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`
M6"U2968`6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E
M9"!+97D@57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8
M-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N
M<P!960!965E9`%EA:&]O(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@
M06=R964`66]U(&%R92!I;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T
M=&]N('1O('-W:71C:"!B86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L
M;&]W960@=&\@8W)E871E(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@
M;F]T(&%U=&AE;G1I8V%T960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H
M87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@
M82!V86QI9"!E;6%I;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE
M;&1S(&9R;VT@=&AE(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I
M;F<@9FEE;&1S(&EN("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO
M=2!H879E('1O(&5N=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG
M:71S(&]N;'D@=VET:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA
M=&EO;F%L(&1I86QI;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A
M;&ED('9A;'5E+@!9;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K
M96YD('1O('5S92!3:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@
M8F%C:V5N9"X`66]U(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E
M('EO=2!C86X@<V5N9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N
M=&5R('1H92!54DP@=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S
M="!S96QE8W0@86X@<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P
M96-I9GD@82!U<V5R;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I
M9GD@82!U<V5R;F%M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE
M('5S97)N86UE('1O(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA
M;64@=&\@=7!D871E+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O
M('!E<F9O<FTN`%EO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`
M66]U(&YE960@=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9
M;W5R("5S('-E<W-I;VX@:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I
M;BX`66]U<B!%;6%I;"!!9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U
M<B!);F9O<FUA=&EO;@!9;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG
M960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O
M('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN
M`%EO=7(@3F%M90!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N
M;W0@<W5P<&]R="!A9&1I;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(
M;W)D92!T;R!A9&UI;FES=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S
M92!A(&1I9F9E<F5N="!A=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U
M=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG
M('5S97)S+"!O<B!T:&4@9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@
M<V]M92!O=&AE<B!R96%S;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA
M=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S
M<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I
M;B!A9V%I;BX`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F
M96%T=7)E+@!9;W5R(&)R;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R
M:6YT(&]P=&EO;BX@4')E<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN
M="X`66]U<B!C=7)R96YT('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT
M:71Y(&AA<R!B965N(&-H86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`
M66]U<B!F=6QL(&YA;64Z`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@
M;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@
M8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N
M+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O
M<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E
M="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@
M<&%S<W=O<F0N`%EO=7(@<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M
M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E
M`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3
M:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE
M<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A
M5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%]);6%G92!0<F]P97)T:65S+BXN
M`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]0
M97)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P
M97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO
M=VX`8V%L96YD87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A
M;FYO="!O<&5N(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E
M(&5R<F]R`&-O;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I
M;&4@;6ES<VEN9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F
M;W5N9`!F86QL:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G
M=7-T:6YG`&@Z`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI
M;F4`:6YP=70O;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R
M`&QI;F5S70!M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E3
M3RX`;6T`;F%M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E
M9`!N;W1E<&%D`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E
M;6]T92!E<G)O<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL
M86)L90!S:&]W(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S
M=&5A9'D`<WES=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R
M90!T>7!E('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`
M=6YN86UE9`!U<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J
M96-T+4ED+59E<G-I;VXZ($AO<F1E(#,N,2UC=G,*4F5P;W)T+4US9VED+4)U
M9W,M5&\Z(&1E=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z
M(#(P,#8M,#<M,S$@,3@Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`V
M+3`X+3`Y(#$V.C0U*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@I,86YG=6%G92U496%M.B!'97)M86X@/&1E
M=D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M
M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#UI<V\M.#@U.2TQ"D-O;G1E;G0M
M5')A;G-F97(M16YC;V1I;F<Z(#@M8FET"@`@*'9O<B`E<R!486=E;BD`("A:
M=6=R:69F<W1A<W1E("5S*0`@*&EN("5S(%1A9V5N*0`@*&AE=71E*0`@*&UO
M<F=E;BD`("AG97-T97)N*0`@;6ET(``B)7,B(&ES="!K96EN(%9E<GIE:6-H
M;FES+@`B)7,B(&ES="!K96EN92!G_&QT:6=E($%U<W=A:&PN`"(E<R(@:7-T
M(&EN(&1E<B!(;W)D92!296=I<W1R>2!N:6-H="!K;VYF:6=U<FEE<G0N`$1E
M<B!"875M+5)E;F1E<F5R(&;\<B`B)7,B('=U<F1E(&YI8VAT(&=E9G5N9&5N
M+@`B)7,B('=U<F1E('IU;2!'<G5P<&5N<WES=&5M(&AI;GIU9V5F_&=T+@`B
M)7,B('=U<F1E('IU;2!296-H=&5S>7-T96T@:&EN>G5G96;\9W0N`"(E<R(@
M=W5R9&4@;FEC:'0@97)S=&5L;'0Z("5S+@`E+C)F34(@*"4S)"XR9B4E*2!V
M;VX@)3(D+C)F34(@97)L875B=&5N('9E<F)R875C:'0`)60@)7,@=6YD("5S
M`$EN("5D(%1A9V5N('=I<F0@26AR(%!A<W-W;W)T('5N9_QL=&EG+@`E9"U4
M86=E+59O<FAE<G-A9V4`)7,@+2!(:6YW96ES`"5S($9I;F=E<F%B9')U8VL`
M)7,@2T(`)7,@5V%R='5N9W-A<F)E:71E;B`M($)E<W3D=&EG=6YG`"5S+4MO
M;F9I9W5R871I;VX`)7,@4F5G:7-T<FEE<G5N9P`E<R!.=71Z=6YG<V)E9&EN
M9W5N9V5N`"5S(&5X:7-T:65R="!B97)E:71S+@`E<R!M:70@)7,@)7,`)7,@
M=VER9"!D:64@5V%R='5N9W-A<F)E:71E;B!D=7)C:&;\:')E;BP@9&EE('5N
M=&5N(&UA<FMI97)T('-I;F0N($UA<FMI97)E;B!3:64@86QL92!!=69G86)E
M;BP@9&EE(&IE='IT(&1U<F-H9V5F_&AR="!W97)D96X@<V]L;&5N+@`E<R!I
M<W0@;F]T=V5N9&EG`"5S($UI;G5T96X`)7,@;FEC:'0@9V5F=6YD96XN`"5S
M(&)I<R`E<R!V;VX@)7,`)7-S($%D<F5S<V)U8V@`)7-S($MA;&5N9&5R`"5S
M<R!.;W1I>F)L;V-K`"5S<R!!=69G86)E;FQI<W1E`"5S.B`E<P`E<SH@1&EE
M<V4@3F%C:')I8VAT('-T86UM="!U;G1E<B!5;7-TY&YD96X@;FEC:'0@=F]N
M(&1E;2!A;F=E9V5B96YE;B!!8G-E;F1E<BX@1F]L9V5N(%-I92!K96EN96X@
M3&EN:W,@:6X@9&EE<V5R($YA8VAR:6-H="!U;F0@:/QT96X@4VEE('-I8V@@
M9&%V;W(L(&1E;2!!8G-E;F1E<B!P97)S]FYL:6-H92!$871E;B!P<F5I<WIU
M9V5B96XN`"P@8O9I9R``+"!B:6<@)7,@)7,`+"!S8VAW86YK96YD('9O;B`E
M<R!B:7,@)7,`+2T@075S=^1H;&5N("TM`#$R+5-T=6YD96XM1F]R;6%T`#(T
M+5-T=6YD96XM1F]R;6%T`#(T(%-T=6YD96X`/%IU<OQC:P!&<B!D:65S96X@
M0FQO8VL@=VER9"!E:6YE($1A=&5N8F%N:R!B96YT:6=T+@!%:6X@<V-H=V5R
M97(@1F5H;&5R(&ES="!A=69G971R971E;CH`16EN(/9F9F5N=&QI8VAE<B!0
M1U`M4V-H;/QS<V5L('=I<F0@9OQR(&1I92!697)S8VAL_'-S96QU;F<@96EN
M97(@3F%C:')I8VAT(&)E;O9T:6=T+@!%:6X@]F9F96YT;&EC:&5R(%!'4"U3
M8VAL_'-S96P@=VER9"!F_'(@9&EE(-QB97)P<OQF=6YG(&5I;F5R('5N=&5R
M>F5I8VAN971E;B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H
M97(@=6YD(&5I;B!P<FEV871E<B!01U`M4V-H;/QS<V5L('-O=VEE(&5I;B!0
M87-S=V]R="!W:7)D(&;\<B!D:64@16YT<V-H;/QS<V5L=6YG(&5I;F5R($YA
M8VAR:6-H="!B96[V=&EG="X`16EN(/9F9F5N=&QI8VAE<B!U;F0@96EN('!R
M:79A=&5R(%!'4"U38VAL_'-S96P@<V]W:64@96EN(%!A<W-W;W)T('=I<F0@
M9OQR(&1I92!5;G1E<GIE:6-H;G5N9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I
M9W0N`$5I;B#V9F9E;G1L:6-H97(@=6YD(&5I;B!P<FEV871E<B!3+TU)344M
M4V-H;/QS<V5L('-O=VEE(&5I;B!087-S=V]R="!W:7)D(&;\<B!D:64@16YT
M<V-H;/QS<V5L=6YG(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`16EN(/9F
M9F5N=&QI8VAE<B!U;F0@96EN('!R:79A=&5R(%,O34E-12U38VAL_'-S96P@
M<V]W:64@96EN(%!A<W-W;W)T('=I<F0@9OQR(&1I92!5;G1E<GIE:6-H;G5N
M9R!E:6YE<B!.86-H<FEC:'0@8F5N]G1I9W0N`$5I;B#V9F9E;G1L:6-H97(@
M4R]-24U%+5-C:&S\<W-E;"!W:7)D(&;\<B!D:64@5F5R<V-H;/QS<V5L=6YG
M(&5I;F5R($YA8VAR:6-H="!B96[V=&EG="X`5F]R;6ET=&%G<R!7;VQK96X`
M5F]R;6ET=&%G<R!L96EC:'1E<B!296=E;@!6;W)M:71T86=S(&QE:6-H=&5R
M(%-C:&YE969A;&P`5F]R;6ET=&%G<R!296=E;@!6;W)M:71T86=S(%-C:&%U
M97(`5F]R;6ET=&%G<R!38VAN965S8VAA=65R`$%-+U!-`$%022!)1`#<8F5R
M(&1I97-E;B!%9&ET;W(`26YF;RXN+@!!8G-O;'5T(%5N=&5N`$%B<V]L=70@
M36ET=&4`6G5G<FEF9B!V97)W96EG97)T(&)E:6T@06YL96=E;B!D97,@5D93
M+59E<GIE:6-H;FES<V5S+@!:=6=R:69F('9E<G=E:6=E<G0@8F5I;2!!;FQE
M9V5N(&1E<B!61E,M1&%T96DN`$MO;G1O:6YF;W)M871I;VYE;@!+;VYT;W!A
M<W-W;W)T`$MO;G1O(&5I;F=E9G)O<F5N+@!"=6-H:&%L='5N9P!(:6YZ=6;\
M9V5N`$YE=64@56YT97)G<G5P<&4@:&EN>G5F_&=E;@!.975E(%5N=&5R<F5C
M:'1E(&AI;GIU9OQG96X`2&EE<B!H:6YZ=6;\9V5N.@!-:71G;&EE9&5R(&AI
M;GIU9OQG96X`3F5U92!'<G5P<&4@:&EN>G5F_&=E;@!.975E(%)E8VAT92!H
M:6YZ=6;\9V5N`%5N=&5R9W)U<'!E('IU("(E<R(@:&EN>G5F_&=E;@!5;G1E
M<G)E8VAT92!Z=2`B)7,B(&AI;GIU9OQG96X`1OQG96X@4VEE(&5I;F5N(&YE
M=65N($)E;G5T>F5R(&AI;GIU.@!3<&%L=&4@:&EN>G5F_&=E;@!086%R(&AI
M;GIU9OQG96X`1&%S("5S+4UE;OP@>G5R($UO>FEL;&$@4VED96)A<B!H:6YZ
M=6;\9V5N`%IU;2!!9')E<W-B=6-H(&AI;GIU9OQG96XZ`%IU(&UE:6YE;2!!
M9')E<W-B=6-H(&AI;GIU9OQG96X`0F5N=71Z97(@:&EN>G5F_&=E;@`B)7,B
M('=U<F1E('IU;2!3>7-T96T@:&EN>G5G96;\9W0L(&%B97(@9&EE('IU<^1T
M>FQI8VAE;B!296=I<W1R:65R=6YG<VEN9F]R;6%T:6]N96X@:V]N;G1E;B!N
M:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S+@`B)7,B('=U<F1E('IU;2!3
M>7-T96T@:&EN>G5G96;\9W0N(%-I92!K]FYN96X@<VEC:"!J971Z="!A;FUE
M;&1E;BX`1&%S($AI;GIU9OQG96X@=F]N($)E;G5T>F5R;B!I<W0@;FEC:'0@
M;?9G;&EC:"X`061R97-S90!!9')E<W-B=6-H`%9E<G=A;'1E;B`M(%)E8VAT
M92!F_'(@86YD97)E($)E;G5T>F5R(&9E<W1L96=E;@!!9&UI;FES=')A=&EO
M;@!797)B=6YG`$%F9VAA;FES=&%N`$%L8F%N:65N`$%L9V5R:65N`%-P:71Z
M;F%M90!!=7-R:6-H='5N9P!!=7-R:6-H='5N9SH`06QL90!!;F=E;65L9&5T
M92!"96YU='IE<@!!;&QE($=R=7!P96X`06QL92!296-H=&4`06QL92!V:65R
M(%-E:71E;@!-96AR97)E($%D<F5S<V5N(&5R;&%U8F5N`$9O<FUA="!V;VX@
M;G5M;65R:65R=&5N($QI<W1E;B#D;F1E<FX_`$5X:7-T:65R="!B97)E:71S
M`$%L=&5R;F%T:79E($E-4U`M06YM96QD=6YG`$%L=&5R;F%T:79E<R!)35-0
M+5!A<W-W;W)T`$%L=&5R;F%T:79E<B!)35-0+4)E;G5T>F5R;F%M90!!;'1E
M<FYA=&EV92!%+4UA:6PM061R97-S90!!;'1E<FYA=&EV92!6;W)L86=E;@!!
M;'1E<FYA=&EV97(@5&5X=#H`06UE<FEK86YI<V-H+5-A;6]A`$5S('=U<F1E
M(&5I;B!U;F?\;'1I9V5R(%=E<G0@86YG96=E8F5N+@!%:6X@=6YB96MA;FYT
M97(@1F5H;&5R(&ES="!A=69G971R971E;BX`06YD;W)R80!!;F=O;&$`06YG
M=6EL;&$`06YO;GEM97(@4')O>'D`06YT=V]R=`!!;G1A<FMT:7,`06YT:6=U
M82!U;F0@0F%R8G5D80!!;G=E;F1U;F<`06YW96YD=6YG<VQI<W1E`$%N=V5N
M9'5N9R!I<W0@8F5R96ET+@!!=68@56YT97)R96-H=&4@86YW96YD96X`0F5S
M=.1T:6=E;@!5;F=E9N1H<F4@1W+VWV4`07!R:6P`07)A8FES8V@@*%=I;F1O
M=W,M,3(U-BD`07)C:&EV9W+VWV4`07)C:&EV;F%M90!3:6YD(%-I92!S:6-H
M97(L(&1A<W,@4VEE(&1I92!296=I<W1R:65R=6YG<V%N9G)A9V4@=F]N("5S
M(&SV<V-H96X@;?9C:'1E;C\`4VEN9"!3:64@<VEC:&5R+"!D87-S(%-I92`B
M)7,B('5N9"!A;&QE(%5N=&5R9W)U<'!E;B!L]G-C:&5N(&WV8VAT96X_`$%R
M9V5N=&EN:65N`$%R;65N:65N`$%R;65N:7-C:"`H05)-4T-)22TX*0!+=6YS
M=`!!<G5B80!!<V-E;G-I;VXM26YS96QN`$%30TE)+4MU;G-T`$%S:65N+U!A
M>FEF:7-C:&4@4F5G:6]N`$%N<W1E:&5N9&4@5V%R='5N9W-A<F)E:71E;B!B
M97-TY'1I9V5N(&QA<W-E;C\`6G5O<F1N=6YG<V9E;&1E<@!%<R!W=7)D92!V
M97)S=6-H="P@96EN92!N:6-H="!E>&ES=&EE<F5N9&4@1W)U<'!E('IU(&SV
M<V-H96XN`$5S('=U<F1E('9E<G-U8VAT+"!E:6X@;FEC:'0@97AI<W1I97)E
M;F1E<R!296-H="!Z=2!L]G-C:&5N+@!%<R!W=7)D92!V97)S=6-H="P@96EN
M(&YI8VAT(&5X:7-T:65R96YD97,@4F5C:'0@>G4@8F5A<F)E:71E;BX`17,@
M=W5R9&4@=F5R<W5C:'0L(&5I;B!N:6-H="!E>&ES=&EE<F5N9&5S(%)E8VAT
M('IU(&)E87)B96ET96XN`$%T=')I8G5T90!!=6=U<W0`075S=')A;&EE;@#6
M<W1E<G)E:6-H`$%U=&A?8WER<W%L.B!$:64@8F5N]G1I9W1E($E-05`M17)W
M96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`$%U=&A?8WER=7,Z($1A
M<R!"86-K96YD(&AA="!N:6-H="!D:64@8F5N]G1I9W1E;B!&Y&AI9VME:71E
M;BX`075T:%]C>7)U<SH@1&EE(&)E;O9T:6=T92!)34%0+45R=V5I=&5R=6YG
M('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!=71H7V9T<#H@1&EE(&)E;O9T:6=T
M92!&5%`M17)W96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN($MO;7!I
M;&EE<F5N(%-I92!02%`@;6ET(&1E;2`M+65N86)L92UF='`@4&%R86UE=&5R
M+@!!=71H7VEM87`Z($1I92!B96[V=&EG=&4@24U!4"U%<G=E:71E<G5N9R!W
M=7)D92!N:6-H="!G969U;F1E;BX`075T:%]K<F(U.B!$:64@8F5N]G1I9W1E
M($ME<F)E<F]S+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E9G5N9&5N+@!!
M=71H7VQD87`Z($1A<R!(:6YZ=6;\9V5N('9O;B!"96YU='IE<FX@=VER9"!F
M_'(@06-T:79E($1I<F5C=&]R>2!N:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD
M87`Z($1A<R!,]G-C:&5N('9O;B!"96YU='IE<FX@=VER9"!F_'(@06-T:79E
M($1I<F5C=&]R>2!N:6-H="!U;G1E<G-T_'1Z=`!!=71H7VQD87`Z($1I92!B
M96[V=&EG=&4@3$1!4"U%<G=E:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E
M;BX`075T:%]L9&%P.B!$97(@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&AI
M;GIU9V5F_&=T('=E<F1E;BX@365L9'5N9R!D97,@4V5R=F5R<SH@`$%U=&A?
M;&1A<#H@0F5N=71Z97(@)7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E
M;@!!=71H7VQD87`Z($)E;G5T>F5R("5S(&MO;FYT92!N:6-H="!A:W1U86QI
M<VEE<G0@=V5R9&5N`$%U=&A?;&1A<#H@1&%S($%K='5A;&ES:65R96X@=F]N
M($)E;G5T>F5R;B!W:7)D(&;\<B!!8W1I=F4@1&ER96-T;W)Y(&YI8VAT('5N
M=&5R<W3\='IT+@!!=71H7VUC86PZ($1I92!B96[V=&EG=&4@34-!3"U%<G=E
M:71E<G5N9R!W=7)D92!N:6-H="!G969U;F1E;BX`075T:%]S;6)A=71H.B!$
M:64@8F5N]G1I9W1E(%-A;6)A+45R=V5I=&5R=6YG('=U<F1E(&YI8VAT(&=E
M9G5N9&5N+@!!;FUE;&1U;F<@8F5I;2!)34%0+5-E<G9E<B!F96AL9V5S8VAL
M86=E;BX`075T:&5N=&EF:7II97)U;F<@9F5H;&=E<V-H;&%G96X`06YM96QD
M=6YG(&9E:&QG97-C:&QA9V5N+B`E<P!$:64@075T:&5N=&EF:7II97)U;F<@
M=W5R9&4@=F]M(%)!1$E54RU397)V97(@>G5R_&-K9V5W:65S96XN`$%N;65L
M9'5N9R!B96EM($944"U397)V97(@9F5H;&=E<V-H;&%G96XN`$%N;65L9'5N
M9R!B96EM(%--0BU397)V97(@9F5H;&=E<V-H;&%G96XN`%9E<F;\9V)A<F4@
M1F5L9&5R.@!!<V5R8F%I9'-C:&%N`$)/1D@M075S<F5D96X`2&EN=&5R9W)U
M;F0`2&EN=&5R9W)U;F1F87)B90!&86QS8VAE<R!+97)B97)O<RU087-S=V]R
M="X`1F%L<V-H97(@2V5R8F5R;W,M0F5N=71Z97)N86UE+@!"86AA;6%S`$)A
M:')E:6X`0F%L=&ES8V@@*$E33RTX.#4Y+3$S*0!"86YG;&%D97-C:`!"87)B
M861O<P!"87-I<RU":6QD97(M5F5R>F5I8VAN:7,@(B5S(B!N:6-H="!G969U
M;F1E;BX`1W)U;F1L:6YI90!796G?<G5L86YD`$)E;&=I96X`0F5L:7IE`$)E
M;FEN`$)E<FUU9&%S`$)H=71A;@!'96)U<G1S=&%G`$)L;V-K("(E<R(@9&5R
M($%N=V5N9'5N9R`B)7,B(&YI8VAT(&=E9G5N9&5N+@!";&]C:V5I;G-T96QL
M=6YG96X`0FQO8VMT>7``1F5T=`!";VQI=FEE;@!,97-E>F5I8VAE;@!286YD
M`%)A:&UE;F1I8VME.@!2Y&YD97(`0F]S;FEE;BU(97)Z96=O=VEN80!"96ED
M97,`0F]T<W=A;F$`56YT96X`0F]U=F5T:6YS96P`0G)A<VEL:65N`$)R:71I
M<V-H97,@5&5R<FET;W)I=6T@:6T@26YD:7-C:&5N($]Z96%N`$)R=6YE:2!$
M87)U<W-A;&%M`$)U;&=A<FEE;@!5;FYU;6UE<FEE<G1E($QI<W1E`$)U<FMI
M;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`0U),($1I<W1R:6)U=&EO;G-S=&5L
M;&4`7UIE;&QE;F5I9V5N<V-H869T96XN+BX`1&5R(%IW:7-C:&5N<W!E:6-H
M97(@:V]N;G1E(&YI8VAT(&EN:71I86QI<VEE<G0@=V5R9&5N+@!+86QE;F1E
M<@!7:6YD<W1I;&P`2V%M8F]D<V-H80!+86UE<G5N`$5X=&5R;F4@4V5S<VEO
M;BU(86YD;&5R(&OV;FYE;B!N:6-H="!A9&UI;FES=')I97)T('=E<F1E;BX`
M5F5R8FEN9'5N9R!Z=6T@24U!4"U397)V97(@:V%N;B!N:6-H="!H97)G97-T
M96QL="!W97)D96XZ("5S`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V7V
M9F9N970@=V5R9&5N+@!+86YA9&$`06)B<F5C:&5N`%!R;V)L96UB97)I8VAT
M(&%B8G)E8VAE;@!$871E:2AE;BD@:_9N;F5N(&YI8VAT(&MO<&EE<G0@=V5R
M9&5N("T@475E;&PM('5N9"!::65L9&%T96EE;B!S:6YD(&ED96YT:7-C:"X`
M1&EE($1A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX`
M2V5I;B!T96UP;W+D<F5S(%9E<GIE:6-H;FES(&=E9G5N9&5N+@!$871E:2AE
M;BD@:_9N;F5N(&YI8VAT('9E<G-C:&]B96X@=V5R9&5N("T@6FEE;&1A=&5I
M(&)E9FEN9&5T('-I8V@@:6T@475E;&QO<F1N97(N`$9O<G1S971Z=6YG(&]H
M;F4@(G1A<F=E=$9I;&4B+5!A<F%M971E<B!N:6-H="!M]F=L:6-H+@!$87,@
M5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N
M+@!+;VYN=&4@;FEC:'0@96YT9F5R;G0@=V5R9&5N+"`E9"!+:6YD97(@97AI
M<W1I97)E;BX`56US;W)T:65R96X@;FEC:'0@;?9G;&EC:"X@1&EE($%N>F%H
M;"!D97(@16EN='+D9V4L(&1I92!U;7-O<G1I97)T('=E<F1E;B!S;VQL96XL
M('-T:6UM="!N:6-H="!M:70@9&5R($%N>F%H;"!D97(@9V5S<&5I8VAE<G1E
M;B!%:6YT<N1G92#\8F5R96EN+@!087-S=V]R="!K86YN(&YI8VAT(&%U=&]M
M871I<V-H('IU<OQC:V=E<V5T>G0@=V5R9&5N+"!B:71T92!W96YD96X@4VEE
M('-I8V@@86X@26AR96X@061M:6YI<W1R871O<BX`1&EE($YA8VAR:6-H="!K
M;VYN=&4@;FEC:'0@86X@9&EE(&%N9V5G96)E($YU;6UE<B!W96ET97)G96QE
M:71E="!W97)D96XN`$1I92!$871E:2`B)7,B(&MA;FX@;FEC:'0@9V5S<&5I
M8VAE<G0@=V5R9&5N`$MA<"!697)D90#<8F5R<V-H<FEF=`!0<F]V:61E<@!+
M871E9V]R:65N('5N9"!"97-C:')I9G1U;F=E;@!#87EM86XM26YS96QN`$UO
M8FEL=&5L969O;@!:96QL96YE:6=E;G-C:&%F=&5N`$EN;F5N86)S=&%N9#H`
M6F5L;&5N96EG96YS8VAA9G1E;@!:96QL96YA8G-T86YD.@!-;V)I;'1E;&5F
M;VX`2V5L=&ES8V@@*$E33RTX.#4Y+3$T*0!:96YT<FEE<G0`6F5N=')A;&%F
M<FEK86YI<V-H92!297!U8FQI:P!-:71T96QE=7)O<.1I<V-H("A)4T\M.#@U
M.2TR*0!:97)T:69I:V%T9&5T86EL<P!:97)T:69I:V%T8F5S:71Z97(`6F5R
M=&EF:6MA=')I8VAT;&EN:65N`%1S8VAA9`#$;F1E<FX`Q&YD97)N(%-I92!)
M:'(@4&%S<W=O<G0`Q&YD97)N(%-I92!D96X@3F%M96X@;V1E<B!D:64@061R
M97-S92P@9&EE(&1I92!%;7!FY&YG97(@26AR97(@12U-86EL+4YA8VAR:6-H
M=&5N('-E:&5N+"!W96YN('-I92!D:65S92!L97-E;B!O9&5R(&1A<F%U9B!A
M;G=O<G1E;BX`1&%S(,1N9&5R;B!):')E<R!087-S=V]R=',@=VER9"!V;VX@
M9&EE<V5M(%-Y<W1E;2!Z=7(@6F5I="!N:6-H="!U;G1E<G-T_'1Z="X@0FET
M=&4@=V5N9&5N(%-I92!S:6-H(&%N($EH<F5N($%D;6EN:7-T<F%T;W(N`%IE
M:6-H96X`3&EN:R#\8F5R7W!R_&9E;BXN+@!#:&EL90!#:&EN80!#:&EN97-I
M<V-H('9E<F5I;F9A8VAT("A'0C(S,3(I`$-H:6YE<VES8V@@=')A9&ET:6]N
M96QL("A":6<U*0!!;G=E;F1U;F<@875S=^1H;&5N.@!7Y&AL96X@4VEE(&5I
M;B!087-S=V]R=`!7Y&AL96X@4VEE(&5I;F5N($)E;G5T>F5R;F%M96X`3&5G
M96X@4VEE(&9E<W0L('=I92!D87,@1&%T=6T@86YG97IE:6=T('=E<F1E;B!S
M;VQL.@!,:7-T96YF;W)M870@875S=^1H;&5N("AF_'(@;G5M;65R:65R=&4@
M3&ES=&5N*0!796EH;F%C:'1S:6YS96P`2VQA<W-E;F1E9FEN:71I;VX@9OQR
M("5S(&YI8VAT(&=E9G5N9&5N+@!(96ET97(`35,M3V9F:6-E+51A9W,@96YT
M9F5R;F5N`$%B9G)A9V4@>G5R_&-K<V5T>F5N`$)E;G5T>F5R9&%T96X@;/9S
M8VAE;CH@)7,`0F5N=71Z97)D871E;B!L]G-C:&5N`$)E;G5T>F5R9&%T96X@
M;/9S8VAE;@!3<.1T97(@075F:VQA<F5N9`!&;W)T9F%H<F5N`$-L:6-K871E
M;&P@<&5R($A45%``1F5N<W1E<B!S8VAL:67?96X`5V]L:V5N`$9R_&@@5V]L
M:V5N`$)E=_9L:W0`2V]K;W-I;G-E;&X`365N_"!E:6YF86AR96X`6G5S86UM
M96YHY&YG96YD92!286AM96X`2V]L=6UB:65N`$9A<F)E`$9A<F)A=7-W86AL
M`$9A<F)W86AL`%-P86QT96XZ`%-P86QT96[\8F5R<V-H<FEF=&5N`$-O;6EC
M<P!"969E:&P`0F5F96AL<WIE:6QE`$MO;6UE;G1A<@!%:6YD975T:6=E<B!.
M86UE`$MO;6]R96X`1FER;6$`0V]M<'5T97(`0F5D:6YG=6YG96X`0F5D:6YG
M=6YG96X`2V]N9FEG=7)A=&EO;G-U;G1E<G-C:&EE9&4`1&EE($MO;F9I9W5R
M871I;VX@;75S<R!A:W1U86QI<VEE<G0@=V5R9&5N+@`E<R!K;VYF:6=U<FEE
M<F5N`%!A<W-W;W)T(&)E<W3D=&EG96X`2V]N9V\`1&5M;VMR871I<V-H92!2
M97!U8FQI8R!+;VYG;P!697)B:6YD=6YG(&9E:&QG97-C:&QA9V5N+@!697)B
M:6YD=6YG(&9E:&QG97-C:&QA9V5N.B``5F5R8FEN9'5N9R!Z=6T@]F9F96YT
M;&EC:&5N(%-C:&S\<W-E;'-E<G9E<B!W=7)D92!A8F=E=VEE<V5N+@!697)B
M:6YD=6YG('IU;2#V9F9E;G1L:6-H96X@4V-H;/QS<V5L<V5R=F5R('=U<F1E
M(&%B9V5W:65S96XN($=R=6YD.B`E<R`H)7,I`%9E<F)I;F1U;F<@>G5M($94
M4"U397)V97(@9F5H;&=E<V-H;&%G96X`2V]N=&%K=&4`1&EE($MO;G1A:W1E
M('=U<F1E;B!E<F9O;&=R96EC:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F
M_&=T+@!);FAA;'1S='EP(&1E<B!K;VUP<FEM:65R=&5N($1A=&5I.B``26YH
M86QT('9O;B`B)7,B`%=E:71E<@!#;V]K+4EN<V5L;@!#;V]K:64`2V]P:65R
M96X`2V]P:65R96X@9F5H;&=E<V-H;&%G96XZ("5S`$%U<W=A:&P@:V]P:65R
M96X`2V]S=&5N+4E$`$-O<W1A(%)I8V$`16QF96YB96EN:_QS=&4`1&EE($YA
M8VAR:6-H="!K;VYN=&4@;FEC:'0@;6ET(%!'4"!V97)S8VAL_'-S96QT('=E
M<F1E;CH@`$1I92!.86-H<FEC:'0@:V]N;G1E(&YI8VAT(&UI="!01U`@=6YT
M97)Z96EC:&YE="!W97)D96XZ(`!$:64@3F%C:')I8VAT(&MO;FYT92!N:6-H
M="!M:70@4R]-24U%('9E<G-C:&S\<W-E;'0@=V5R9&5N+@!$:64@3F%C:')I
M8VAT(&MO;FYT92!N:6-H="!M:70@4R]-24U%('5N=&5R>F5I8VAN970@=V5R
M9&5N+@!+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XN
M("5S`%9E<F)I;F1U;F<@>G5M($Q$05`M4V5R=F5R(&9E:&QG97-C:&QA9V5N
M+@!+;VYT;W-T86YD(&MO;FYT92!N:6-H="#\8F5R<'+\9G0@=V5R9&5N+B`E
M<P!697)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!F96AL9V5S8VAL86=E;BX`
M1E10+59E<F)I;F1U;F<@>G5M(%-E<G9E<B`B)7,B(&MO;FYT92!N:6-H="!H
M97)G97-T96QL="!W97)D96XZ("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N
M:6-H="!E<G-T96QL="!W97)D96XN("5S`%!'4"U$871E;B!K;VYN=&5N(&YI
M8VAT(&5N='-C:&S\<W-E;'0@=V5R9&5N.B``4R]-24U%+41A=&5N(&MO;FYT
M96X@;FEC:'0@96YT<V-H;/QS<V5L="!W97)D96XN`$MO;G1A:W0@:V]N;G1E
M(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX@)7,`5F5R=&5I;&5R;&ES=&4@:V]N
M;G1E(&YI8VAT(&=E;/9S8VAT('=E<F1E;BX@)7,`1&%S($%K='5A;&ES:65R
M=6YG<W-K<FEP="`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN
M`$1I92!%+4UA:6PM061R97-S92!D97,@16UP9N1N9V5R<R!K;VYN=&4@;FEC
M:'0@97)M:71T96QT('=E<F1E;BX`1&%S($%D<F5S<V)U8V@@:V]N;G1E(&YI
M8VAT(&MO;7!L971T(&=E;&5S96X@=V5R9&5N+@!697)T96EL97)L:7-T92!K
M;VYN=&4@;FEC:'0@875S9V5L97-E;B!W97)D96XN("5S`$QI<W1E(&1E<B!6
M97)T96EL97)L:7-T96X@:V]N;G1E(&YI8VAT(&%U<V=E;&5S96X@=V5R9&5N
M+@!$:64@4W1R871E9VEE("(E<R(@:V]N;G1E(&YI8VAT(&=E;&%D96X@=V5R
M9&5N+@!$87,@5F5R>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@86YG96QE
M9W0@=V5R9&5N+@#69F9E;G1L:6-H97(@4V-H;/QS<V5L(&MO;FYT92!N:6-H
M="!V;VT@4V-H;/QS<V5L<V5R=F5R(&=E:&]L="!W97)D96XN`"(E<R(@:V]N
M;G1E(&YI8VAT('IU;2!38VAR96EB96X@9V7V9F9N970@=V5R9&5N+@`E<R!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN`$1A<R!-86EN=&5N86YC95]4
M87-K($UO9'5L("5S(&MO;FYT92!N:6-H="!G9?9F9FYE="!W97)D96X`5F5R
M>F5I8VAN:7,@(B5S(B!K;VYN=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!6
M97)B:6YD=6YG('IU;2!,1$%0+5-E<G9E<B!K;VYN=&4@;FEC:'0@:&5R9V5S
M=&5L;'0@=V5R9&5N+@`E<R!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN
M`$1A<R!087-S=V]R="!F_'(@9&5N(&%N9V5G96)E;F5N($)E;G5T>F5R(&MO
M;FYT92!N:6-H="!Z=7+\8VMG97-E='IT('=E<F1E;BP@=V5I;"!E:6YI9V4@
M06YG86)E;B!N:6-H="!R:6-H=&EG('=A<F5N+B!697)S=6-H96X@4VEE(&5S
M(&5R;F5U="!O9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!!9&UI;FES
M=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T:6=E;BX`04-,
M(&MO;FYT92!N:6-H="!G96QE<V5N('=E<F1E;@!$87,@061R97-S8G5C:"!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN("5S`%9E<G1E:6QE<FQI<W1E
M(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`5F5R=&5I;&5R
M;&ES=&5N(&MO;FYT92!N:6-H="!A=7-G96QE<V5N('=E<F1E;BX@)7,`1&EE
M(%-E<G9E<F;D:&EG:V5I=&5N(&MO;FYT96X@;FEC:'0@875S9V5L97-E;B!W
M97)D96X`2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@>G5R_&-K9V5S971Z
M="!W97)D96XN`%9E<GIE:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&=E;/9S
M8VAT('=E<F1E;BX`)7,M2V]N9FEG=7)A=&EO;B!K;VYN=&4@;FEC:'0@9V5S
M<&5I8VAE<G0@=V5R9&5N+@!"86-K=7`@9&5R($MO;F9I9W5R871I;VX@:V]N
M;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`0F%C:W5P(&1E<B!+;VYF
M:6=U<F%T:6]N(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W97)D96XZ("5S
M`$1A<R!!:W1U86QI<VEE<G5N9W-S:W)I<'0@:V]N;G1E(&YI8VAT(&YA8V@@
M(B5S(B!G97-P96EC:&5R="!W97)D96XN`$)A8VMU<"!D97(@2V]N9FEG=7)A
M=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$:64@
M2V]N9FEG=7)A=&EO;B`E<R!K;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R
M9&5N+B!3:64@:_9N;F5N(&5N='=E9&5R(&5I;F4@9&5R($WV9VQI8VAK96ET
M96X@=6YT97(@)7,@=F5R=V5N9&5N+"!U;2!D96X@0V]D92!Z=2!S<&5I8VAE
M<FXL(&]D97(@9&5N('5N=&5N<W1E:&5N9&5N($-O9&4@;6%N=65L;"!N86-H
M("5S(&MO<&EE<F5N+@!$97(@3$1!4"U397)V97(@:V]N;G1E(&YI8VAT(&1U
M<F-H<W5C:'0@=V5R9&5N+@`B)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W
M97)D96XN`$1E<B!+;VYT86MT(&MO;FYT92!N:6-H="!G97-P96EC:&5R="!W
M97)D96XN("5S`%9E<G1E:6QE<FQI<W1E(&MO;FYT92!N:6-H="!A:W1U86QI
M<VEE<G0@=V5R9&5N+B`E<P!$:64@2V]N9FEG=7)A=&EO;B!F_'(@(B5S(B!K
M;VYN=&4@;FEC:'0@9V5S<&5I8VAE<G0@=V5R9&5N.B`E<P!$:64@36]Z:6QL
M82!3:61E8F%R(&MO;FYT92!N:6-H="!G969U;F1E;B!W97)D96XN(%-T96QL
M96X@4VEE('-I8VAE<BP@9&%S<R!D:64@4VED96)A<B!G9?9F9FYE="!I<W0N
M`$1E;2!"96YU='IE<B`B)7,B(&MO;FYT96X@9&EE(&9O;&=E;F1E(%)E8VAT
M92!F_'(@9&5N($]R9&YE<B`B)7,B(&YI8VAT('IU9V5W:65S96X@=V5R9&5N
M.B`E<P!'97KD:&QT97(@5&5X=`!,86YD`$MU<G-E`$5R<W1E;&QE;@!,:6YK
M(&5R<W1E;&QE;@!.975E($ED96YT:73D="!A;FQE9V5N`%5N=&5R;W)D;F5R
M(&5R<W1E;&QE;@!%<G-T96QL97)R96-H=&4`2W)E9&ET:V%R=&5N;G5M;65R
M`$MR;V%T:65N`$MU8F$`06MT=65L;&4@-"!0:&%S96X`06MT=65L;&4@4V5S
M<VEO;G,`06MT=65L;&4@6F5I=`!!:W1U96QL92!54DP@:7-T`$%K='5E;&QE
M($)E;G5T>F5R`$%K='5E;&QE<R!7971T97(`1&5R>F5I=&EG92!"961I;F=U
M;F=E;CH@`$%K='5E;&QE<B!3=&EL`$QE9V5N(%-I92!F97-T+"!W96QC:&4@
M075F9V%B96X@;F%C:"!D97(@06YM96QD=6YG(&)E:2`E<R!E<FQE9&EG="!W
M97)D96X@<V]L;&5N+@!!=7-S8VAN96ED96X`075S=V%H;"!A=7-S8VAN96ED
M96X`6GEP97)N`$MY<FEL;&ES8V@@*$M/23@M4BD`2WER:6QL:7-C:"`H5VEN
M9&]W<RTQ,C4Q*0!+>7)I;&QI<V-H+U5K<F%I;FES8V@@*$M/23@M52D`5'-C
M:&5C:&ES8VAE(%)E<'5B;&EK`%14`$133B`H<VEE:&4@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!4Y&=L:6-H`$1A=&%4<F5E($)R;W=S97(`1&%T96YB86YK86)F
M<F%G90!$871U;0!%;7!F86YG<V1A='5M`$1A='5M<V%U<W=A:&P`5&%G`%-P
M86QT92!?;/9S8VAE;@!$97IE;6)E<@!:86AL96X`16EN>G5G('9E<G)I;F=E
M<FX`4W1A;F1A<F0`4W1A;F1A<F1F87)B90!3=&%N9&%R9&ED96YT:73D=`!3
M=&%N9&%R9'-H96QL`$1E9FEN:71I;VYE;@!,]G-C:&5N`%IE;&QE(&SV<V-H
M96X`1W)U<'!E(&SV<V-H96X`3&]G(&SV<V-H96X`4F5C:'1E(&SV<V-H96X`
M3F%C:')I8VAT96X@;/9S8VAE;B!U;F0@96YT9F5R;F5N`%IE;&QE(&SV<V-H
M96X`4W!A;'1E(&SV<V-H96X`0F5S=&5H96YD92!A;'1E<FYA=&EV92!6;W)L
M86=E(&SV<V-H96X`3F%C:')I8VAT96X@;/9S8VAE;@!296-H=&4@9OQR("(E
M<R(@;/9S8VAE;@!296-H=&4@9OQR("(E<R(@=6YD(&%L;&4@56YT97)R96-H
M=&4@;/9S8VAE;C\`6F5I;&4@;/9S8VAE;@!!=7-G97?D:&QT92!)9&5N=&ET
MY'0@;/9S8VAE;@!5;G1E<F]R9&YE<B!L]G-C:&5N`$1I92!A:W1U96QL92!3
M<&%L=&4@;/9S8VAE;@!$:64@86MT=65L;&4@6F5I;&4@;/9S8VAE;@!$87,@
M06MT=6%L:7-I97)U;F=S<VMR:7!T("(E<R(@=W5R9&4@9V5L]G-C:'0N`$%U
M<VQI969E<G5N9W-Z96ET`$3D;F5M87)K`$)E<V-H<F5I8F5N(%-I92!D87,@
M4')O8FQE;0!"97-C:')E:6)U;F<`1&5T86EL<R`H875C:"!I;B!(;W)D97,@
M3&]G9&%T96DI.@!$971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T
M;W(@;6ET9V5L;V=G="X`16YT=VEC:VQU;F<`5&%U<'5N:W0`5&%U<'5N:W0@
M9&5R(&QE='IT96X@4W1U;F1E.B``5&%U<'5N:W0Z(`!6;VX@;&EN:W,@;F%C
M:"!R96-H=',`5F]N(')E8VAT<R!N86-H(&QI;FMS`%9E<GIE:6-H;FES`%IE
M:70@:6T@,C0M4W1U;F1E;BU&;W)M870@86YZ96EG96X_`$%N>F5I9V4M16EN
M<W1E;&QU;F=E;@!$971A:6QI97)T92!6;W)H97)S86=E(&%N>F5I9V5N`%9O
M<FAE<G-A9V4@*%1!1BD@86YZ96EG96X`06YZ96EG969O<FUA=`!%;7!F86YG
M<V)E<W3D=&EG=6YG`$1S8VAI8G5T:0!.:6-H="!L]G-C:&5N`$=R96EF96X@
M4VEE(&YI8VAT(&1I<F5K="!A=68@;6%I;G1E;F%N8V4N<&AP('IU`$5N=&CD
M;'0@9&EE(&5R<W1E(%IE:6QE(&1I92!&96QD;F%M96X_(%=E;FX@:F$L(&1I
M97-E<R!!=7-W86AL:^1S=&-H96X@;6%R:VEE<F5N.@!$;VUI;FEC80!$;VUI
M;FEK86YI<V-H92!297!U8FQI:P!.;V-H(&ME:6YE;B!:=6=A;F<_($AI97(@
M86YM96QD96XN`$AE<G5N=&5R;&%D96X`)7,@2&5R=6YT97)L861E;@!%<GIE
M=6=T92!+;VYF:6=U<F%T:6]N(&%L<R!02%`M4VMR:7!T(&AE<G5N=&5R;&%D
M96XN`$%U<W=A:&QL:7-T90!$<F]G96X`12U-86EL`$4M36%I;"UN86-H+5--
M4RUG871E=V%Y(&;\<B!0<F]V:61E<BP@9&EE(&5I;F5N('-O;&-H96X@1&EE
M;G-T('5N=&5R<W3\='IE;BX`1D5(3$52`$5C=6%D;W(`0F5A<F)E:71E;@!"
M;&]C:R!B96%R8F5I=&5N`$=R=7!P92!B96%R8F5I=&5N`%)E8VAT92!B96%R
M8F5I=&5N`%)E8VAT92!B96%R8F5I=&5N`%)E8VAT92!F_'(@)R5S)R!B96%R
M8F5I=&5N`$5I;G-T96QL=6YG96X@8F5A<F)E:71E;B!F_'(Z`%)E8VAT92!F
M_'(@(B5S(B!B96%R8F5I=&5N`%)E8VAT92!F_'(@)7,@8F5A<F)E:71E;@!"
M:6QD=6YG`,1G>7!T96X`16P@4V%L=F%D;W(`16QE;65N="XN+@!%;0!%+4UA
M:6P`12U-86EL+4%D<F5S<V4`1&EE($4M36%I;"U!9')E<W-E;B!M_'-S96X@
M9VQE:6-H('-E:6XN`$4M36%I;"U!9')E<W-E(&UI="!"97-TY'1I9W5N9P!%
M+4UA:6PM;F%C:"U335,M1V%T97=A>0!3;6EL97ES`$QE97)E($YA8VAR:6-H
M="X`3&5E<F5S($5R9V5B;FES+@!3=6-H8F5G<FEF9F4@;/9S8VAE;@!%:6YF
M_&=E;B!V;VX@0FEL9&5R;B!A=7,@1F]T;V=A;&5R:65N(&EN(&1E;B!497AT
M(&5R;&%U8F5N/P!+;VYT97AT;65N_"!B96D@4F5C:'1S:VQI8VL@86MT:79I
M97)E;C\`16YD:F%H<@!%9&ET;W(@=F5R9W+VWV5R;@!'96)E;B!3:64@96EN
M92!3:6-H97)H96ET<V9R86=E(&5I;BP@9&EE($EH;F5N(&=E<W1E;&QT('=I
M<F0L('=E;FX@4VEE($EH<B!087-S=V]R="!Z=7+\8VMS971Z96X@;?9C:'1E
M;BP@>BX@0BX@(E=I92!L875T970@9&5R($YA;64@26AR97,@2&%U<W1I97)S
M/R(Z`$AI97(@9&EE($)I;&0M55),(&%N9V5B96X`1V5B96X@<VEE(&1I92!"
M=6-H<W1A8F5N('5N=&5N(&5I;CH`Q'%U871O<FEA;"U'=6EN96$`17)I=')E
M80!&96AL97(`1F5H;&5R(&)E:6T@17)S=&5L;&5N(&5I;F5S($)L;V-K<SH@
M)7,`1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T:6]N<V%N
M:V5R<SH@)7,`1F5H;&5R(&)E:6T@3/9S8VAE;B!D97,@4WEN8VAR;VYI<V%T
M:6]N<VQO9W,Z("5S`$9E:&QE<B!B96EM($5R>F5U9V5N(&1E<R!);FAA;'1S
M.B`E<P!&96AL97(@8F5I;2#$;F1E<FX@9&5S(%!A<W-W;W)T<SH@)7,`1F5H
M;&5R(&EN(&1E<B!%+4UA:6PM3F%C:')I8VAT+@!&96AL97(@8F5I;2!38VAR
M96EB96X@=F]N("(E<R(N`$5S=&QA;F0`Q'1H:6]P:65N`$5T;FES8VAE<P!%
M=7)O<&$`06QL92`Q-2!-:6YU=&5N`$%L;&4@,B!-:6YU=&5N`$%L;&4@,S`@
M4V5K=6YD96X`06QL92`U($UI;G5T96X`0F5I(&IE9&5R($%N;65L9'5N9P!!
M;&QE(&AA;&)E(%-T=6YD90!!;&QE(#8P(%-E:W5N9&5N`$)E:7-P:65L=V5R
M=&4Z`$%U<V;\:')E;@!697)G<O;?97)N`"<I)R!E<G=A<G1E=`!%:6YZ96QN
M97,@5V]R="!O9&5R(%-U8VAB96=R:69F(&EN($%N9OQH<G5N9W-Z96EC:&5N
M(&5R=V%R=&5T`%9E<F9A;&QS9&%T=6T`17AP;VYE;G0`5F]R9&5R9W)U;F1F
M87)B90!(;V-H;&%D96X@9&5R($MO;F9I9W5R871I;VX@<&5R($944`!"96YU
M='IE<F5I;G-T96QL=6YG96X@:V]N;G1E;B!N:6-H="!G96QA9&5N('=E<F1E
M;BX`5F5R8FEN9'5N9R!Z=6T@3$1!4"!397)V97(@9V5S8VAE:71E<G0N`%9E
M<F)I;F1U;F<@>G5M(%--0BU397)V97(@9V5S8VAE:71E<G0N`$5S(&MO;FYT
M92!K96EN92!+;W!I92!V;VX@(B5S(B!E<G-T96QL="!W97)D96XN`$5S(&MO
M;FYT92!N:6-H="!N86-H("(E<R(@:V]P:65R="!W97)D96XN`$%U9F)A=2!E
M:6YE;B!N975E;B!305-,+59E<F)I;F1U;F<@:7-T(&9E:&QG97-C:&QA9V5N
M+@!%<R!K;VYN=&4@;FEC:'0@;F%C:"`B)7,B('9E<G-C:&]B96X@=V5R9&5N
M+@!&96AL97(@8F5I;2!,97-E;CH@)7,`2&5I=&5R`$9A;&ML86YD:6YS96QN
M`$9A<O9E<@!38VAW97)E<B!&96AL97(Z`$9A>`!&87AE`$9E8G)U87(`1V5F
M_&AL=&4@5&5M<&5R871U<@!'96;\:&QT92!496UP97)A='5R.B``5F5R96EN
M>F5L=&4@4V-H875E<@!697)E:6YZ96QT92!38VAN965S8VAA=65R`$9E;&1M
M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG;&5T+49O;G0`1FED<V-H:0!$871E
M:0!!;GIA:&PZ("5S($1A=&5I`$%N>F%H;#H@)7,@1&%T96EE;@!$871E:6UA
M;F%G97(`1&%T96EN86UE`$1A=&5I875S=V%H;`!$871E:2U(;V-H;&%D96X`
M1&%S($AO8VAL861E;B!V;VX@1&%T96EE;B!W:7)D(&YI8VAT('5N=&5R<W3\
M='IT+@!&:6QT97(`1FEN;FQA;F0`17)S=&4@2.1L9G1E`$5R<W1E<R!6:65R
M=&5L`%9E<FCD;'1N:7,@>G5R_&-K<V5T>F5N`%5M9')E:&5N`%1E>'1F;'7?
M`$YE8F5L`$1A<R!697)Z96EC:&YI<R`E<R!E>&ES=&EE<G0@;FEC:'0`4V-H
M<FEF=&9A<F)E`$5S<V5N`$;\<B!"<F]W<V5R+"!D:64@:V5I;F4@0FEL9&5R
M('5N=&5R<W3\='IE;@!6;W)H97)S86=E("A4048I`%9O<FAE<F=E<V%G=&4@
M5&%G92`H5F]R:&5R<V%G96X@96YT:&%L=&5N(%1A9V4@=6YD($[D8VAT92P@
M96EN(&AO:&5R(%=E<G0@:V%N;B!Z=2!E:6YE;2!S96AR(&=R;]]E;B!";&]C
M:R!F_&AR96XI`%!A<W-W;W)T('9E<F=E<W-E;C\`1F]R;75L87)E`$=L_&-K
M<VME:W,`1VS\8VMS:V5K<W1Y<`!';/QC:W-K96MS90!';/QC:W-K96MS92`R
M`$9O<F5N`%=E:71E<FQE:71U;F<`1G(`4F%H;65N`$9R86YK<F5I8V@`175R
M;W#D:7-C:&5S($9R86YK<F5I8V@`1V5F<FEE<F5N9&5R(%)E9V5N`$9R86YZ
M]G-I<V-H+4=U87EA;F$`1G)A;GKV<VES8V@M4&]L>6YE<VEE;@!&<F%N>O9S
M:7-C:&4@1V5B:65T92!I;2!S_&1L:6-H96X@26YD:7-C:&5N($]Z96%N`%9O
M;@!!=7,@`%9O;&QS=.1N9&EG92!"97-C:')E:6)U;F<`5F]L;&UO;F0`5F]L
M;'-TY&YD:6=E<B!.86UE`$=A8G5N`$)I;&1E<B!A=7,@9&EE<V5R($=A;&5R
M:64`1V%L97)I93H`1V%M8FEA`"5S+4MO;F9I9W5R871I;VX@97)Z975G96X`
M17)Z975G=&5R($-O9&4`1V5O<F=I96X`1&5U='-C:&QA;F0`1VAA;F$`1VEB
M<F%L=&%R`%9O<FYA;64`06QL9V5M96EN92!%:6YS=&5L;'5N9V5N`$QO<P!'
M;V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-U8VAE`$=R875S='5F96X`1W)I
M96-H96YL86YD`$=R:65C:&ES8V@@*$E33RTX.#4Y+3<I`$=R]FYL86YD`$=R
M96YA9&$`1W)U<'!E;G9E<G=A;'1U;F<`1W)U<'!E;FYA;65N(&3\<F9E;B!N
M:6-H="!L965R('-E:6X`1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN
M=&4@;FEC:'0@:&EN>G5G96;\9W0@=V5R9&5N+B!-96QD=6YG(&1E<R!397)V
M97)S.B``1W)O=7!?;&1A<#H@1&EE($=R=7!P92`E<R!K;VYN=&4@;FEC:'0@
M9V5L]G-C:'0@=V5R9&5N`$=R;W5P7VQD87`Z($1I92!'<G5P<&4@)7,@:V]N
M;G1E(&YI8VAT(&%K='5A;&ES:65R="!W97)D96X`1W)U<'!E;@!'=6%D96QO
M=7!E`$=U86T`1W5A=&5M86QA`$=U97)N<V5Y`$=A<W1R96-H=&4`1^1S=&5B
M=6-H`$=U:6YE80!'=6EN96$M0FES<V%U`$=U>6%N80!(5$U,`$1E<B!%9&ET
M;W(@:V%N;B!D:64@;&5T>G1E(%IE;&QE(&5I;F5R(%IE:6QE(&YI8VAT(&SV
M<V-H96XN`$1E<B!%9&ET;W(@:V%N;B!D:64@;&5T>G1E(%-P86QT92!E:6YE
M<B!486)E;&QE(&YI8VAT(&SV<V-H96XN`$1E<B!%9&ET;W(@:V%N;B!D:64@
M;&5T>G1E(%IE:6QE(&5I;F5R(%1A8F5L;&4@;FEC:'0@;/9S8VAE;BX`2%14
M4"U!=71H96YT:69I>FEE<G5N9R!N:6-H="!G969U;F1E;BX`2&%I=&D`2&%S
M:"U!;&=O<FET:&UU<P!$:65S:6<`W&)E<G-C:')I9G0`2V]P9F5I;G1RY&=E
M`$AE87)D+2!U;F0@36-$;VYA;&1I;G-E;&X`4V-H=V5R92!'97=I='1E<@!(
M96)RY&ES8V@@*$E33RTX.#4Y+3@M22D`2/9H90!(:6QF90!%9&ET;W)H:6QF
M90!(:6QF90!(96UI<W!H97)E`$1I97,@:7-T(&1E<B!"96=I;FX@9&5R($1A
M=&5I.@!(;V-H`%]3=&%R='-E:71E`%9A=&EK86YS=&%D=`!!9')E<W-E('!R
M:79A=`!(96EM=F5R>F5I8VAN:7,`5&5L969O;B!P<FEV870`2&]N9'5R87,`
M2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B.B!5;F?\;'1I9V4@)7,M6$U,
M+41A=&5N(&EN($YA8VAR:6-H="`E<P!(;W)D92]+;VQA8CH@17,@<&%S<W0@
M:V5I;F4@3F%C:')I8VAT('IU;2!/8FIE:W0@)7,`2&]R9&4O2V]L86(Z($ME
M:6X@3V)J96MT('9O;2!4>7`@)7,@:6X@3F%C:')I8VAT("5S(&=E9G5N9&5N
M`$AO<F1E+TMO;&%B.B`E<R`B)7,B('=U<F1E(&5R9F]L9W)E:6-H(&5N=&9E
M<FYT`$AO<F1E+TMO;&%B.B!$:64@26YT96=R871I;VYS9G5N:W1I;VYE;B!B
M96[V=&EG96X@9&EE(")D;VUX;6PB(%!(4"U%<G=E:71E<G5N9P!(;W)D92]+
M;VQA8CH@1OQR(&1A<R!/8FIE:W0@)7,@:V]N;G1E(&ME:6X@;F5U97(@6$U,
M+4)A=6T@97)Z975G="!W97)D96X`2&]R9&4O2V]L86(Z("5S("(E<R(@:V]N
M;G1E(&YI8VAT(&5N=&9E<FYT('=E<F1E;CH@)7,`2&]R9&4O2V]L86(Z($1I
M92!-24U%+4E$(&1E<R!!8G-C:&YI='1S('9O;2!4>7`@)7,@:V]N;G1E(&YI
M8VAT(&AE<F%U<V=E9G5N9&5N('=E<F1E;BX`2&]R9&4O2V]L86(Z("5S("(E
M<R(@:V]N;G1E(&YI8VAT('-Y;F-H<F]N:7-I97)T('=E<F1E;CH@)7,`2&]R
M9&4O2V]L86(Z($1I92!G96UE:6YS86UE;B!/8FIE:W1E(&MO;FYT96X@;FEC
M:'0@<WEN8VAR;VYI<VEE<G0@=V5R9&5N.B`E<P!(;W)D92]+;VQA8CH@56YB
M96MA;FYT97,@9V5M96EN<V%M97,@3V)J96MT("(E<R(`2&]R:7IO;G1A;&4@
M3&EN:64`2&]R:7IO;G1A;&5R($EN;F5N86)S=&%N9`!(;W)I>F]N=&%L.@!7
M:64@<VEN9"!3:64@:&EE<FAE<F=E;&%N9W0_($)I='1E(&%N(&1I92!%;G1W
M:6-K;&5R('IU<OQC:VUE;&1E;B$I`%=I92!V:65L92!3<&%L=&5N('-O;&QE
M;B!Z=7-A;6UE;F=E9OQG="!W97)D96X_`%=I979I96QE($9E;&1E<B`H4W!A
M;'1E;BD@9VEB="!E<S\`5VEE('9I96QE(%IE:6QE;B!S;VQL96X@>G5S86UM
M96YG96;\9W0@=V5R9&5N/P!,=69T9F5U8VAT:6=K96ET`$QU9G1F975C:'1I
M9VME:70Z(`!+;VUI:V5R`%5N9V%R;@!!;FQE9V5N(&1E<R!)34%0+5!O<W1F
M86-H<R!I<W0@9F5H;&=E<V-H;&%G96XZ("5S`$SV<V-H96X@9&5S($E-05`M
M4&]S=&9A8VAS(&ES="!F96AL9V5S8VAL86=E;CH@)7,`1F5S=&QE9V5N(&1E
M<B!)34%0+5!O<W1F86-H+5%U;W1A(&ES="!F96AL9V5S8VAL86=E;CH@)7,`
M25`M061R97-S90!)4"U!9')E<W-E(&YI8VAT('9E<F;\9V)A<BX`25`M061R
M97-S92!N:6-H="!I;2!E<FQA=6)T96X@0TE$4BU";&]C:RX`5F5R;&5T>G5N
M9R!D97(@9F5S=&=E;&5G=&5N($E0+@!:96EL92!E:6YF_&=E;B!?=F]R`$ES
M;&%N9`!.=7(@0FEL9&5R`$EC;VYS(&;\<B`E<P!":6QD97(@=6YD(%1E>'0`
M0F5Z96EC:&YU;F<@9&5R($ED96YT:73D=`!796YN('-I92!N:6-H="!K;W)R
M96MT(&%N9V5Z96EG="!W:7)D+"`E<RP@=6T@<VEE(&EN(&5I;F5M(&YE=65N
M($9E;G-T97(@86YG97IE:6=T('IU(&)E:V]M;65N+@!796YN(%-I92!M:70@
M9&5M($EN=&5R;F5T($5X<&QO<F5R(&ME:6YE(%-Y;6)O;&4@<V5H96XL(&W\
M<W-E;B!3:64@9&EE<V5S($OD<W1C:&5N(&UA<FMI97)E;BP@=6T@4$Y'+51R
M86YP87)E;GH@875S>G5S=&5L;&5N+@!796YN(%-I92!D:65S92!.86-H<FEC
M:'0@86X@4W1E;&QE(&5I;F4@0FEL9&5S('-E:&5N+"!K86YN($EH<B!"<F]W
M<V5R(&1A<R!":6QD+"!D87,@4VEE(&AO8VAL861E;B!M]F-H=&5N(&YI8VAT
M(&%N>F5I9V5N+@!":6QD=F]R<V-H874Z`$)I;&0M55),`$)I;&0M55),.@!"
M:6QD('9O;B!'86QE<FEE`$)I;&0@=F]N($=A;&5R:64Z`$)I;&0M2&]C:&QA
M9&5N`$)I;&1E<@!);7!O<G1I97)E;BP@4V-H<FET="`E9`!);7!O<G1I97)T
M97,@1F5L9#H@)7,`26UP;W)T:65R=&4@1F5L9&5R.@!:96EL92!E:6YF_&=E
M;B!?;F%C:`!5;F?\;'1I9V4@06MT:6]N(&%N9V5G96)E;BX`56YG_&QT:6=E
M<B!"96YU='IE<FYA;64@=6YD+V]D97(@4&%S<W=O<G0N`$9A;'-C:&5R($)E
M;G5T>F5R;F%M92!O9&5R($4M36%I;"U!9')E<W-E+B!697)S=6-H96X@4VEE
M(&5S(&5R;F5U="!O9&5R('=E;F1E;B!3:64@<VEC:"!A;B!):')E;B!3>7-T
M96UA9&UI;FES=')A=&]R+"!W96YN(%-I92!W96ET97)E($AI;&9E(&)E;O9T
M:6=E;BX`16EN>G5G('9E<F=R]M]E<FX`26YD:65N`$5I;GIE;&YE($)E;G5T
M>F5R`$EN9&]N97-I96X`26YF;W)M871I;VX`26YF;W)M871I;VYE;@!);F9O
M<FUA=&EO;F5N(&YI8VAT(&UE:'(@=F5R9OQG8F%R+@!697)E<F)T92!-:71G
M;&EE9&5R`%]3<&%L=&4@9&%V;W(@96EN9OQG96X`0FEL9"!H:6YZ=6;\9V5N
M`%1A8F5L;&4@96EN9OQG96X`3&EN:R!E:6YF_&=E;@!37W!A;'1E(&1A;F%C
M:"!E:6YF_&=E;@!%:6YE(&YE=64@4W!A;'1E(&YA8V@@9&5R(&%K='5E;&QE
M;B!E:6YF_&=E;@!%:6YE(&YE=64@4W!A;'1E('9O<B!D97(@86MT=65L;&5N
M(&5I;F;\9V5N`$5I;F4@;F5U92!:96EL92!N86-H(&1E<B!A:W1U96QL96X@
M96EN9OQG96X`16EN92!N975E(%IE:6QE('9O<B!D97(@86MT=65L;&5N(&5I
M;F;\9V5N`$5I;F5N(&YE=65N($%B<V%T>B!N86-H(&1E;2!A:W1U96QL96X@
M16QE;65N="!E:6YF_&=E;@!%:6YE;B!N975E;B!!8G-A='H@=F]R(&1E;2!A
M:W1U96QL96X@16QE;65N="!E:6YF_&=E;@!!;'1E<FYA=&EV92!6;W)L86=E
M(&5I;F;\9V5N`$=E8F5N(%-I92!E:6YE($4M36%I;"U!9')E<W-E(&%N+"!A
M;B!D:64@9&%S(&YE=64@4&%S<W=O<G0@9V5S8VAI8VMT('=E<F1E;B!S;VQL
M.@!:96QL92!D86YA8V@@96EN9OQG96X`6F5L;&4@9&%V;W(@96EN9OQG96X`
M4W!A;'1E(&1A;F%C:"!E:6YF_&=E;@!3<&%L=&4@9&%V;W(@96EN9OQG96X`
M3F%C:')I8VAT96X@:&EN>G5F_&=E;@!!8G-A='H@9&%N86-H(&5I;F;\9V5N
M`$%B<V%T>B!D879O<B!E:6YF_&=E;@!:96EL92!D86YA8V@@96EN9OQG96X`
M6F5I;&4@9&%V;W(@96EN9OQG96X`1V5B96X@4VEE(&1I92!!;G1W;W)T(&%U
M9B!D:64@4VEC:&5R:&5I='-F<F%G92!E:6XZ`$)I;&0@96EN9OQG96XO8F5A
M<F)E:71E;@!,:6YK(&5I;F;\9V5N+V)E87)B96ET96X`6G4@=V5N:6<@1W5T
M:&%B96XL('5M(&%N(&1I92!697)T96EL97)L:7-T92!Z=2!V97)S8VAI8VME
M;BX`6G4@=V5N:6<@1W5T:&%B96XN`$=A;GIZ86AL`$QI<W1E('9O;B!'86YZ
M>F%H;&5N`%5N9_QL=&EG97(@541(+B`H57-E<B!$871A($AE861E<BDN`%5N
M9_QL=&EG92!:25`M1&%T96XN`%5N9_QL=&EG92!!;G=E;F1U;F<N`%5N9_QL
M=&EG92!"871C:"U)1"X`56YG_&QT:6=E($1A=&5N(&5I;F=E8F5N+@!5;F?\
M;'1I9V4@6FEE;&%D<F5S<V4N`%5N9_QL=&EG97,@1&%T96EF;W)M870`56YG
M_&QT:6=E<B!,:7IE;GIS8VAL_'-S96PN`%5N9_QL=&EG97(@3W)T(&%N9V5G
M96)E;BX`56YG_&QT:6=E<B!M<V=?='EP92X`56YG_&QT:6=E(&]D97(@9F5H
M;&5N9&4@87!I7VED+@!5;F?\;'1I9V4@;V1E<B!F96AL96YD92!087)A;65T
M97(N`%5N9_QL=&EG97,@W&)E<G)E8VAT+@!5;F?\;'1I9V4@4&%R=&YE<BU)
M1"X`56YG_&QT:6=E<B!0<F]D=6MT8V]D92X`56YG_&QT:6=E<R!0<F]T;VMO
M;&PN`%5N9_QL=&EG97(@16UP9N1N9V5R.B`B)7,B`%5N9_QL=&EG97,@9V5M
M96EN<V%M97,@3V)J96MT`%5N9_QL=&EG92!5<G-P<G5N9W-A9')E<W-E+@!5
M;F?\;'1I9V4@56YI8V]D92U$871E;BX`26YV96YT87(`075S=V%H;"!U;6ME
M:')E;@!)<VQA;6ES8VAE(%)E<'5B;&EK($ER86X`27)A:P!)<FQA;F0`27-L
M92!O9B!-86X`5F5R96EN>F5L=&4@1V5W:71T97(`27-R865L`$%U<W-T96QL
M97(`2W5R<VEV`$ET86QI96X`2F%M86EK80!*86YU87(`2F%P86X`2F%P86YI
M<V-H("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;FEE;@!*=6QI`$IU;FD`
M0FQO8VMS871Z`%IE;G1R:65R96X`0FQO8VMS871Z`$QI;FMS(&%U<W)I8VAT
M96X`4F5C:'1S(&%U<W)I8VAT96X`2V%S86-H<W1A;@!/<FEG:6YA;"!B96EB
M96AA;'1E;C\`2V5N:6$`2V5R8F5R;W,M4V5R=F5R(&AA="!!=71H96YT:69I
M>FEE<G5N9R!Z=7+\8VMG97=I97-E;BX`2V5R;F5L+4YE=6QI;F=E`%-C:&S\
M<W-E;&5R>F5U9W5N9P!&:6YG97)A8F1R=6-K(&1E<R!38VAL_'-S96QS`%-C
M:&S\<W-E;&SD;F=E`%-C:&S\<W-E;'1Y<`!38VAL_'-S96QZ=V5C:P!$97(@
M4V-H;/QS<V5L(&)E9FEN9&5T('-I8V@@8F5R96ET<R!A=68@9&5M(/9F9F5N
M=&QI8VAE;B!38VAL_'-S96QS97)V97(N`$MI;F1E<@!+:7)I8F%T:0!$96UO
M:W)A=&ES8VAE(%9O;&MS<F5P=6)L:6,@2V]R96$`4F5P=6)L:6L@2V]R96$`
M2V]R96%N:7-C:"`H155#+4M2*0!+=7=A:70`2VER9VES:7-T86X`06Y?<&%S
M<V5N`%-P<F%C:&4`3&%O<P!,971Z=&4@2.1L9G1E`$QE='IT92!087-S=V]R
M=.1N9&5R=6YG`$QE='IT97,@5FEE<G1E;`!,971Z=&4@06MT=6%L:7-I97)U
M;F<Z`$QE='IT92!!;FUE;&1U;F<Z("5S`$QE='IT92!!;FUE;&1U;F<Z("5S
M('9O;B`E<P!,971Z=&4@06YM96QD=6YG.B!.;V-H(&YI90!,971T;&%N9`!'
M97-E='H`1F]R;6%T`$QE97(@;&%S<V5N(&;\<B!K96EN96X@4F%H;65N`$QI
M8F%N;VX`3&EN:W,`3&EN:V4@W&)E<G-C:')I9G0`3&EN:V4@5V5R=&4`3&5S
M;W1H;P!%8F5N90!,:6)E<FEA`$QI8GEE;@!,:65C:'1E;G-T96EN`%-P<OQH
M<F5G96X`3&5I8VAT97(@4F5G96X`1G+\:"!L96EC:'1E<B!296=E;@!3<.1T
M97(@3&5I8VAT97(@4F5G96X`3&5I8VAT92!296=E;G-C:&%U97(`3&5I8VAT
M97(@4F5G96X@;6ET($=E=VET=&5R`$QE:6-H=&5R(%-C:&YE969A;&P`3&5I
M8VAT92!38VAN965S8VAA=65R`$QI;65R:6-K`$QI;FL`3&EN:RU54DP`3&EN
M:RU:=6=R:69F<W1A<W1E`$QI;FL@=F5R=V5I<W0@875F.@!,:6YK+5II96P`
M3&EN:RU497AT`$4M36%I;"U!9')E<W-E('9E<FQI;FME;C\`3&EN:RU4:71L
M92U!='1R:6)U=`!,:6YK<P!,:6YU>"U';/QC:W-K96MS90!,:7-T("T@0F5N
M=71Z97(@:V%N;B!D96X@3W)D;F5R('-E:&5N`$1A=&5N8F%N:V5N(&%N>F5I
M9V5N`$AI;&9E96EN='+D9V4@86YZ96EG96X`5&%B96QL96X@86YZ96EG96X`
M3&ES=&5N+4%R8VAI=@!,:7-T96XM2&EL9F4`3&ES=&5N+4ED`$QI<W1E;BU"
M97-I='IE<@!,:7-T96XM061R97-S90!,:7-T96XM06YM96QD=6YG`$QI<W1E
M;BU!8FUE;&1U;F<`1&%S($%N>F5I9V5N(&1E<B!397-S:6]N<R!I<W0@9F5H
M;&=E<V-H;&%G96XZ("5S`$1A<R!!;GIE:6=E;B!D97(@0F5N=71Z97(@:7-T
M(&9E:&QG97-C:&QA9V5N.B`E<P!$87,@06YZ96EG96X@9&5R($)E;G5T>F5R
M(&ES="!N:6-H="!M]F=L:6-H+@!,:71E<F%T=7(`3&ET875E;@!,861E+BXN
M`$QO:V%L92!5:')Z96ET.B``4W!R86-H92!U;F0@6F5I=`!/<G0`06YM96QD
M96X`3&]G(&1E<B!L971Z=&5N(%-Y;F-H<F]N:7-A=&EO;BX`06)M96QD96X`
M06YM96QD96X`06YM96QD96%U9F=A8F5N`$1I92!!;FUE;&1U;F<@:7-T(&9E
M:&QG97-C:&QA9V5N+"!W96EL(%-I92!):')E;B!"96YU='IE<FYA;65N(&]D
M97(@26AR(%!A<W-W;W)T(&9A;'-C:"!E:6YG96=E8F5N(&AA8F5N+@!!;FUE
M;&1U;F<@9F5H;&=E<V-H;&%G96XN`$QA;F=E<B!497AT`$QI96)E`$YI961R
M:6<`2VPN(&=R:65C:&ES8VAE($)U8VAS=&%B96X`2VPN(&QA=&5I;FES8VAE
M($)U8VAS=&%B96X`2VPN('+V;6ES8VAE(%IA:&QE;@!,=7AE;6)U<F<`34T`
M34]41`!-4RU43D5&+4%N:&%N9R!E;G1H:65L="!K96EN92!$871E;BX`2$E.
M5T5)4P!-86-A;P!$:64@96AE;6%L:6=E($IU9V]S;&%W:7-C:&4@4F5P=6)L
M:6L@36%Z961O;FEE;@!-861A9V%S:V%R`$UA9VEE`%=E8FUA:6P`12U-86EL
M($%D;6EN:7-T<F%T:6]N`$QI;FL@7V%N;&5G96XN+BX`36%L87=I`$UA;&%Y
M<VEA`$UA;&ED:79E;@!-86QI`$UA;'1A`%9E<G=A;'1E;B!3:64@9&EE($MA
M=&5G;W)I96XL(&UI="!D96YE;B!3:64@16QE;65N=&4@=6YD($5I;G1RY&=E
M(&ME;FYZ96EC:&YE;B!K]FYN96XL('-O=VEE(&1I92!Z=6=E:/9R:6=E;B!&
M87)B96XN`$UA<#(T+4MA<G1E`$UA<%%U97-T+4MA<G1E`%IU;W)D;G5N9V5N
M(&=E<W!E:6-H97)T+@!-Y')Z`$%UWV5N86)S=&%N9`!-:70@1V5L97-E;BTO
M56YG96QE<V5N+5-T871U<R!V97)S96AE;@!-:70@86YD97)E;2!3=&%T=7,@
M=F5R<V5H96X@*'HN0BX@5VEC:'1I9R]"96%N=V]R=&5T*0!-87)S:&%L;&EN
M<V5L;@!-87)T:6YI<75E`%IU9V5O<F1N971E($9E;&1E<@!-875R971A;FEE
M;@!-875R:71I=7,`36%X:6UA;"!E<FQA=6)T97(@2W)E9&ET+@!-87AI;6%L
M92!.86-H=&EC:'1E;G1E:6QE(/QB97)S8VAR:71T96XN`$CV8VAS='1E;7!E
M<F%T=7(@9&5R(&QE='IT96X@,C0@4W1U;F1E;CH@`$CV8VAS='1E;7!E<F%T
M=7(@9&5R(&QE='IT96X@-B!3='5N9&5N.B``36%X:6UA;&4@06YZ86AL(&%N
M(%!O<G1A;&)L]F-K96X`36%X:6UA;&4@3.1N9V4`36%I`$UA>6]T=&4@27-L
M86YD`$UE9&EZ:6X`36ET9VQI961E<@!-96[\;6]D=7,Z`%IE;&QE;B!Z=7-A
M;6UE;F;\9V5N`$YA8VAR:6-H=`!$:64@3F%C:')I8VAT(&MO;FYT92!E<F9O
M;&=R96EC:"#\8F5R<'+\9G0@=V5R9&5N(&%B97(@;FEC:'0@9&%S(%IE<G1I
M9FEK870@9&5S($%B<V5N9&5R<RX`3F%C:')I8VAT(&YI8VAT(&UE:'(@9_QL
M=&EG+@!.86-H<FEC:'1E;G1Y<`!-971A<B!7971T97(`365T87)B;&]C:R!N
M:6-H="!V97)F_&=B87(N`$UE=&%R8FQO8VL@;FEC:'0@=F5R9OQG8F%R+B!$
M971A:6QS('=U<F1E;B!F_'(@9&5N($%D;6EN:7-T<F%T;W(@;6ET9V5L;V=G
M="X`2V5I;F4@5F5R8FEN9'5N9R!Z=7(@365T87)$0BX`365T:&]D90!$:64@
M365T:&]D92`B)7,B(&ES="!N:6-H="!D969I;FEE<G0`365T:&]D92!N:6-H
M="!D969I;FEE<G0N($%U9F=E<G5F96YE($UE=&AO9&4Z("5S`$UE=')I<V-H
M`$UE>&EK;P!&]F1E<FEE<G1E(%-T86%T96X@=F]N($UI:W)O;F5S:65N`$UI
M='1E`$UI;65T>7``5&EE9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`R-"!3
M='5N9&5N.B``5&EE9G-T=&5M<&5R871U<B!D97(@;&5T>G1E;B`V(%-T=6YD
M96XZ(`!$87,@;6EN:6UA;&4@4&%S<W=O<G1A;'1E<B!I<W0@;F]C:"!N:6-H
M="!A8F=E;&%U9F5N`%-P:65G96QN`%9E<G-C:&EE9&5N97,`4$5!4BU086ME
M="!(5%107U)E<75E<W0@9F5H;'0N`$9E:&QE;F1E($MO;F9I9W5R871I;VXN
M(%-I92!M_'-S96X@9&EE<V4@:F5T>G0@97)Z975G96XL('=E;FX@4VEE(&1I
M92!!;G=E;F1U;F<@=F5R=V5N9&5N(&WV8VAT96XN`$9E:&QE;F1E($YA8VAR
M:6-H=&5N+4E$+@!014%2+5!A:V5T($UA:6P@9F5H;'0N`$9E:&QE;F1E(%-I
M='IU;F=S+4E$+@!-;P!%+4UA:6P@36]B:6P`3>3?:6<`Q&YD97)U;F=S9&%T
M=6T`55),(&)E87)B96ET96X`36]D=6QU<P!297!U8FQI:R!-;VQD874`36]N
M86-O`$UO;F=O;&5I`$UO;F%T('5N9"!*86AR`$UO;F%T;&EC:`!-;VYT<V5R
M<F%T`$UO;F1P:&%S96X`365H<B!&96QD97(@:6X@6F5I;&4@)60@86QS(&1I
M92!E<G=A<G1E=&5N("5D(&=E9G5N9&5N+@!-87)O:VMO`-QB97)W:65G96YD
M(&AE:71E<@#<8F5R=VEE9V5N9"!"97?V;&MT`-QB97)W:65G96YD($)E=_9L
M:W0@=6YD(%=I;F1I9P#<8F5R=VEE9V5N9"!3;VYN:6<`3F%C:"!U;G1E;@!.
M86-H(&QI;FMS`$YA8V@@<F5C:'1S`$YA8V@@;V)E;@!.86-H('5N=&5N`$YA
M8V@@;V)E;@!-;W-A;6)I:P!!=7-W86AL;&ES=&4@:6X@;65H<F5R96X@16)E
M;F5N`$UU;'1I;6%P+55++4MA<G1E`$UE:')F86-H875S=V%H;`!-96EN($MO
M;G1O`$UE:6X@2V]N=&\`365I;B!0;W)T86P`365I;B!0;W)T86QL87EO=70`
M0G5R;6$`3D5)3BP@:6-H('-T:6UM92!.24-(5"!Z=0!.86UE`$YA;6EB:6$`
M3F%U<G4`3F5P86P`3FEE9&5R;&%N9&4`3FEE9&5R;.1N9&ES8VAE($%N=&EL
M;&5N`$YE='-C87!E+4)A<VES+5523`!.971S8V%P92U#02U3<&5R<G5N9W,M
M55),`$YE='-C87!E+4-!+5)I8VAT;&EN:65N+5523`!.971S8V%P92U:971I
M9FEK871S97)N975E<G5N9W,M55),`$YE='-C87!E+5-P97)R=6YG<RU54DP`
M3F5T<V-A<&4M4U-,+5-E<G9E<FYA;64`3F5T<V-A<&4M2V]M;65N=&%R`$YE
M='-C87!E+5IE<G1I9FEK871T>7``3F5T>G=E<FL`3FEE`$YE=6MA;&5D;VYI
M96X`3F5U92!+871E9V]R:64`3F5U;6]N9`!.975E<B!"96YU='IE<FYA;64@
M*&]P=&EO;F%L*0!.975S965L86YD`$YE=65S(%!A<W-W;W)T`$1A<R!N975E
M(%!A<W-W;W)D('=I<F0@86T@)7@@86)L875F96XN`$1I92!N975E;B!087-S
M=_9R=&5R('-T:6UM96X@;FEC:'0@_&)E<F5I;BX`3F5U97,@1F5N<W1E<B`H
M7V)L86YK*0!.86-H<FEC:'1E;@!.97=S9W)U<'!E;@!796ET97(`3N1C:'-T
M92`T(%!H87-E;@!.Y&-H<W1E($5I;G-T96QL=6YG96X`5V5I=&5R/@!.:6-A
M<F%G=6$`3FEG97(`3FEG97)I80!.86-H=',`3FEU90!.96EN`$ME:6YE($MO
M;F9I9W5R871I;VYS9&%T96X@=F5R9OQG8F%R+"!U;2!5;G1E<G-C:&EE9&4@
M86YZ=7IE:6=E;BX`2V5I;F4@4W1R871E9VEE('IU;2!%<G-T96QL96X@=F]N
M($E33RU!8F)I;&1E<FX@=F5R9OQG8F%R+@!+96EN92!"871C:"U6;W)L86=E
M+@!%<R!E>&ES=&EE<G0@:V5I;B!";&]C:R!A;B!D97(@86YG96=E8F5N96X@
M4&]S:71I;VX`2V5I;B!+86QE;F1E<FYA;64@9OQR(&1I92!-0T%,+4%U=&AE
M;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;F4@Q&YD97)U;F=E;BX`56YT
M97)H86QB(&1I97-E<B!%8F5N92!K]FYN96X@:V5I;F4@=V5I=&5R96X@56YT
M97)R96-H=&4@:&EN>G5G96;\9W0@=V5R9&5N+@!&_'(@)7,@=W5R9&5N(&ME
M:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E9V5B96XN`$;\
M<B!D96X@1E10+59&4RU4<F5I8F5R('=U<F1E;B!K96EN92!+;VYF:6=U<F%T
M:6]N<VEN9F]R;6%T:6]N96X@86YG96=E8F5N+@!&_'(@9&5N(%-13"U61E,M
M5')E:6)E<B!W=7)D96X@:V5I;F4@2V]N9FEG=7)A=&EO;G-I;F9O<FUA=&EO
M;F5N(&%N9V5G96)E;BX`1OQR(&1E;B!344PM1&%T96DM5D93+51R96EB97(@
M=W5R9&5N(&ME:6YE($MO;F9I9W5R871I;VYS:6YF;W)M871I;VYE;B!A;F=E
M9V5B96XN`$ME:6X@2W)E9&ET(&UE:'(@_&)R:6<N`$ME:6X@16UP9N1N9V5R
M(&%N9V5G96)E;BX`2V5I;F4@1&%T96D@:&]C:&=E;&%D96X`2V5I;F4@26-O
M;G,@9V5F=6YD96XN`$5S('=U<F1E(&ME:6X@3W)T(&9E<W1G96QE9W0N`$ME
M:6X@3W)T(&%N9V5G96)E;BX`2V5I;F4@3F%C:')I8VAT(&%N9V5G96)E;BX`
M2V5I;B!.86UE(&%N9V5G96)E;BX`2V5I;F4@3G5M;65R(&%N9V5G96)E;BX`
M2V5I;F4@86YS=/;?:6=E;B!';/QC:W-K96MS90!+96EN(%!A<W-W;W)T(&;\
M<B!D:64@2%144"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`$ME:6X@
M4&%S<W=O<G0@9OQR(&1I92!)34%0+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G
M96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE($ME<F)E<F]S+4%U=&AE;G1I
M9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R="!F_'(@9&EE($QO
M9VEN+4%U=&AE;G1I9FEZ:65R=6YG(&%N9V5G96)E;BX`2V5I;B!087-S=V]R
M="!F_'(@9&EE(%!!4U-71"U!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN
M`$ME:6X@4&%S<W=O<G0@9OQR(&1I92!334(M075T:&5N=&EF:7II97)U;F<@
M86YG96=E8F5N+@!+96EN(%!F860@>G5M($]P96Y34TPM4')O9W)A;6T@86YG
M96=E8F5N+B!$87,@3W!E;E-33"U0<F]G<F%M;2!W:7)D(&)E;O9T:6=T+"!U
M;2!02T-3+3$R+41A=&5N('9E<F%R8F5I=&5N('IU(&OV;FYE;BX`2V5I;F4@
M875S<W1E:&5N9&5N(%)E9VES=')I97)U;F=E;BX`2V5I;B!3<&5I8VAE<G!L
M871Z+4MO;G1I;F=E;G0@9F5S=&=E;&5G="X`2V5I;F4@4F%H;65N`$ME:6X@
M5')E;FYZ96EC:&5N(&%N9V5G96)E;BX`2V5I;F4@4V5I=&5N`$1A=&5I(&YI
M8VAT(&=E9G5N9&5N`$ME:6YE('1E;7!O<N1R97,@5F5R>F5I8VAN:7,@9OQR
M(&1E;B!#86-H92!G969U;F1E;BX`2V5I;B!"96YU='IE<FYA;64@=6YD+V]D
M97(@4&%S<W=O<G0@86YG96)E;BX`17,@=W5R9&5N(&ME:6YE(&?\;'1I9V5N
M(%A-3"U$871E;B!Z=7+\8VMG96=E8F5N`$ME:6YE(%=E<G1E`$ME:6YE(%9E
M<G-I;VYS;G5M;65R(&EN(&1E<B!/<FEG:6YA;&MO;F9I9W5R871I;VX@9V5F
M=6YD96XN($5R;F5U97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE
M(%9E<G-I;VYS;G5M;65R(&EN($EH<F5R($MO;F9I9W5R871I;VX@9V5F=6YD
M96XN($5R;F5U97)N(%-I92!):')E($MO;F9I9W5R871I;VXN`$ME:6YE`$ME
M:6YS("A3=&%N9&%R9"!B96YU='IE;BD`3F]R9&ES8V@@*$E33RTX.#4Y+3$P
M*0!.;W)F;VQK:6YS96P`3O9R9&QI8VAE($AE;6ES<&AE<F4`3O9R9&QI8VAE
M($UA<FEA;F5N`$YO<G=E9V5N`$?\;'1I9R!B:7,`1_QL=&EG(&%B`$ME:6X@
M5F5R>F5I8VAN:7,`3FEC:'0@9V5F=6YD96XN`$YI8VAT(&EM<&QE;65N=&EE
M<G0N`$YI8VAT(&9E<W1G96QE9W0`3FEC:'0@=6YT97)S=/QT>G0N`$YO=&EZ
M96X`3FEC:'1S(&%N>G5Z96EG96XL(&)I='1E('IU<OQC:V=E:&5N+@!.;W9E
M;6)E<@!:86AL`$%N>F%H;"!D97(@6F5I8VAE;@!!;GIA:&P@9&5R(%-P86QT
M96X`06YZ86AL(&1E<B!:96EL96X`2V5I;F4@3G5M;65R;B!F_'(@9&EE(%9E
M<G1E:6QE<FQI<W1E(&%N9V5G96)E;BX`3TL`3V)J96MT`$]B:F5K=&5R<W1E
M;&QE<@!/:W1A;'IA:&P`3VMT;V)E<@!&:6QT97(@9OQR(&%N<W3VWVEG92!)
M;FAA;'1E`$+\<F\`26AR(&YE=65S(%!A<W-W;W)T(&UU<W,@<VEC:"!V;VX@
M26AR96T@86QT96X@=6YT97)S8VAE:61E;BX`06QT97,@4&%S<W=O<G0`1F%L
M<V-H97,@86QT97,@4&%S<W=O<G0N`$]M86X`3VYC;&EC:RU%=F5N=`!.=7(@
M24U!4"U397)V97(@=6YT97)S=/QT>F5N(&=E;65I;G-A;64@3W)D;F5R+@!.
M=7(@86YS=/;?:6=E($=L_&-K<VME:W-E`$YU<B!E:6YE($4M36%I;"U!9')E
M<W-E(&5R;&%U8G0N`$YU<B!D97(@0F5S:71Z97(@;V1E<B!D97(@4WES=&5M
M861M:6YI<W1R871O<B!K86YN(&1E;B!"97-I='IE<B!O9&5R(&1I92!"97-I
M='IE<G)E8VAT92#D;F1E<FX`26X@;F5U96T@1F5N<W1E<B#V9F9N96X`3W!E
M;E-33"U&96AL97(Z(%-I9VYI97)T92!3+TU)344M1&%T96X@:V]N;G1E;B!N
M:6-H="!E>'1R86AI97)T('=E<F1E;BX`1&EE<V5N($QI;FL@:6X@96EN96T@
M;F5U96T@1F5N<W1E<B#V9F9N96X`0F5T<FEE8G-Y<W1E;0!%:6YS=&5L;'5N
M9V5N`$5I;G-T96QL=6YG96X@9OQR("5S`$YU;6UE<FEE<G1E($QI<W1E`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYS86)T96EL=6YG`$]R9V%N:7-I97)E
M;@!/<FEG:6YA;'9O<FQA9V4@9&5R($%N=V5N9'5N9P!/<FEG:6YA;'9O<FQA
M9V4@:6X@)7,Z`%-O;G-T:6=E`$%N9&5R92!);F9O<FUA=&EO;F5N`$)E<VET
M>F5R<F5C:'1E`%!!32U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R
M9OQG8F%R+@!014%2.CI-86EL+4)A8VME;F0`1&EG:71A;&4@4$=0+55N=&5R
M<V-H<FEF=`!01U`M=F5R<V-H;/QS<V5L=&4@1&%T96X`UF9F96YT;&EC:&5R
M(%!'4"U38VAL_'-S96P`36ET(%!'4"!U;G1E<GIE:6-H;F5T92]V97)S8VAL
M_'-S96QT92!$871E;@!02%`@0V]D90!02%`@4VAE;&P`5F]R;6ET=&%G<R!L
M96EC:'1E<B!296=E;@!.86-H;6ET=&%G<R!296=E;@!.86-H;6ET=&%G<R!3
M8VAA=65R`$YA8VAM:71T86=S(%-C:&YE90!.86-H;6ET=&%G<R!38VAN965S
M8VAA=65R`$YA8VAM:71T86=S(%-O;FYE`$YA8VAM:71T86=S($=E=VET=&5R
M`$1I92!03U-)6"U%<G=E:71E<G5N9R!F96AL=`!?4$A0(%-H96QL`$EN;F5N
M86)S=&%N9`!086MI<W1A;@!086QA=0!"97-E='IT92!086SD<W1I;F5N<VES
M8VAE($=E8FEE=&4`4&%N86UA`%!A<'5A+4YE=6=U:6YE80!087)A9W5A>0!4
M96EL=V5I<V4@0F5W]FQK=`!087-S=V]R=`!087-S=V]R="!E<F9O;&=R96EC
M:"!G9>1N9&5R="X`1F%L<V-H97,@4&%S<W=O<G0`2V5I;B!087-S=V]R="!F
M_'(@9&EE(%)!1$E54RU!=71H96YT:69I>FEE<G5N9R!A;F=E9V5B96XN`%!A
M<W-W;W)T(&UI="!"97-TY'1I9W5N9P!087-S=V]R=#H`4&%S<W=O<G0Z(`!$
M:64@4&%S<W?V<G1E<B!M_'-S96X@9VQE:6-H('-E:6XN`$5I;F;\9V5N`%9O
M;B!D97(@6G=I<V-H96YA8FQA9V4@96EN9OQG96X`4&9A9`!!=7-S=&5H96YD
M92!296=I<W1R:65R=6YG96XZ`%!E<G-O;F5N`%!R;WIE;G0`5V%R='5N9W-A
M<F)E:71E;B!D=7)C:&;\:')E;@!787)T=6YG<V%R8F5I=&5N(&YA8V@@9&5R
M($%N;65L9'5N9R!D=7)C:&;\:')E;C\`4F5C:'1E`%)E8VAT("(E<R(@=W5R
M9&4@;FEC:'0@9V5L]G-C:'0N`%IU9W)I9F8@=F5R=V5I9V5R=`!296-H=&4`
M4F5C:'1E=F5R=V%L='5N9P!097)S]FYL:6-H92!!;F=A8F5N`%!E<G4`2&%U
M<W1I97)E`%!H:6QI<'!I;F5N`%1E;&5F;VX`1F]T;W,`4&ET8V%I<FX`4&EX
M96P`4&QA='1H96ET96X`0FET=&4@:VQI8VME;B!3:64@:6X@96EN92!:96QL
M90!":71T92!B97-TY'1I9V5N(%-I92P@9&%S<R!3:64@9&EE<V5S($5L96UE
M;G0@;/9S8VAE;B!M]F-H=&5N.@!":71T92!B973D=&EG96X@4VEE+"!D87-S
M(%-I92!D96X@3&EN:R!V;VX@9&EE<V5M($5L96UE;G0@96YT9F5R;F5N(&WV
M8VAT96XN`$)I='1E(&5I;F5N($UO;F%T('5N9"!E:6X@2F%H<B!A;F=E8F5N
M+@!":71T92!G96)E;B!3:64@96EN96X@3F%M96X@9OQR(&1I92!N975E($MA
M=&5G;W)I92!A;CH`0FET=&4@96EN92!G_&QT:6=E($E0+4%D<F5S<V4@96EN
M9V5B96XN`$)I='1E(&=E8F5N(%-I92!E:6X@9_QL=&EG97,@1&%T=6T@86X[
M(/QB97)P<OQF96X@4VEE(&1I92!:86AL(&1E<B!486=E(&EN(&1E;2!-;VYA
M="X`0FET=&4@96EN96X@9_QL=&EG96X@6F5I='=E<G0@96EN9V5B96XN`$)I
M='1E(&=E8F5N(%-I92!E:6YE(%IU<V%M;65N9F%S<W5N9R!):')E<R!0<F]B
M;&5M<R!A;BX`0FET=&4@9V5B96X@4VEE($EH<F5N($)E;G5T>F5R;F%M96X@
M=6YD($EH<B!087-S=V]R="!A;@!":71T92!L97-E;B!3:64@<VEC:"!D96X@
M9F]L9V5N9&5N(%1E>'0@<V]R9V;D;'1I9R!D=7)C:"X@4VEE($W<4U-%3B!D
M:65S96X@0F5D:6YG=6YG96X@>G5S=&EM;65N+"!W96YN(%-I92!D:65S97,@
M4WES=&5M(&)E;G5T>F5N(&WV8VAT96XN`$)I='1E(&1E;B!N975E;B!+871E
M9V]R:65N86UE;B!E:6YG96)E;CH`4&]L96X`4&]L:71I:P!5;69R86=E;@!0
M;W)T=6=A;`!0;W-I=&EO;FEE<G5N9R!D:65S92!":6QD97,`4&]S:71I;VYI
M97)U;F<@9&EE<V5R(%1A8F5L;&4`4V5N9&5N(&%N(&1I97-E;B!/<F1N97(@
M*&YI8VAT(&1U<F-H($E-05`I`$YI961E<G-C:&QA9R!I;B!D96X@;&5T>G1E
M;B`E<R!3='5N9&4H;BDZ(`!.:65D97)S8VAL86=S+3QB<B`O/G=A:')S8VAE
M:6YL:6-H:V5I=`!0<F5F<U]L9&%P.B!$:64@8F5N]G1I9W1E($Q$05`M17)W
M96ET97)U;F<@=W5R9&4@;FEC:'0@9V5F=6YD96XN`%!R969S7W-E<W-I;VXZ
M($1I92!B96[V=&EG=&4@4V5S<VEO;BU%<G=E:71E<G5N9R!W=7)D92!N:6-H
M="!G969U;F1E;BX`3'5F=&1R=6-K`$QU9G1D<G5C:R!A=68@4V5E:/9H93H@
M`$QU9G1D<G5C:SH@`%9O<G-C:&%U`$5I;F4@5F]R<V-H874@9&5S($)I;&1E
M<R!I;B!E:6YE;2!N975E;2!&96YS=&5R(&%N>F5I9V5N`%9O:&5R:6=E($5I
M;G-T96QL=6YG96X`1&]K=6UE;G0@9')U8VME;@!0<FEV871E<B!38VAL_'-S
M96P`4')O8FQE;64`4')O8FQE;6)E<V-H<F5I8G5N9P!0<F]J96MT90!.86-H
M9G)A9V5T97AT`-9F9F5N=&QI8VAE<B!38VAL_'-S96P`06QG;W)I=&AM=7,@
M9&5S(/9F9F5N=&QI8VAE;B!38VAL_'-S96QS`$EN9F]R;6%T:6]N96X@>G5M
M(/9F9F5N=&QI8VAE;B!38VAL_'-S96P`1&%S(/9F9F5N=&QI8VAE+W!R:79A
M=&4@4V-H;/QS<V5L<&%A<B!K;VYN=&4@;FEC:'0@97)S=&5L;'0@=V5R9&5N
M+@!0=65R=&\@4FEC;P!.86-H<FEC:'1E;B!E;F1G_&QT:6<@;/9S8VAE;@!+
M871A<@!!8F9R86=E`%-P96EC:&5R<&QA='HM2V]N=&EN9V5N=`#69F9E;G1L
M:6-H97(@4E-!(%-C:&S\<W-E;"`H)60@0FET*0!!=7-W86AL:VYO<&8`4F5G
M96X`1G+\:"!296=E;@!3<.1T97(@4F5G96X`4F5G96YS8VAA=65R`%-C:&YE
M97)E9V5N`%)E9V5N(&EN(%-C:&YE92#\8F5R9V5H96YD`$=L_&-K<VME:W,`
M5F5R:.1L=&YI<P!,97-E;@!.86-H<FEC:'1E;B!L97-E;@`E<R!W:7)K;&EC
M:"!L]G-C:&5N/R!$:65S97(@5F]R9V%N9R!K86YN(&YI8VAT('+\8VMGY&YG
M:6<@9V5M86-H="!W97)D96XN`$1A=&5N(&1E<R!"96YU='IE<G,@)7,@=VER
M:VQI8V@@;/9S8VAE;C\@1&EE<V5R(%9O<F=A;F<@:V%N;B!N:6-H="!R_&-K
M9^1N9VEG(&=E;6%C:'0@=V5R9&5N+@!&_&AR="!L971Z=&4@06MT:6]N(&5R
M;F5U="!A=7,`06MT=6%L:7-I97)E`$1Y;F%M:7-C:&4@365N_&5L96UE;G1E
M(&%K='5A;&ES:65R96XZ`%!O<G1A;&%N<VEC:'0@86MT=6%L:7-I97)E;CH`
M4F5G=6SD<F5R($%U<V1R=6-K`%9E<F)I;F1U;F=S+4)R;W=S97(`06MT=6%L
M:7-I97)E;@!"96UE<FMU;F=E;@!%;G1F97)N=&4@4V5R=F5R`%-E<G9E<F%D
M<F5S<V4@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!%;G1F97)N
M96X`0FQO8VL@;/9S8VAE;@!3<&%L=&4@;/9S8VAE;@!&;W)M871I97)U;F<@
M96YT9F5R;F5N`%!A87(@;/9S8VAE;@!'97-P96EC:&5R=&5S(%-K<FEP="!A
M=7,@9&5M('1E;7!O<N1R96X@5F5R>F5I8VAN:7,@96YT9F5R;F5N+@!%;G1F
M97)N90!$:65S97,@16QE;65N="!A=7,@9&5M($1O:W5M96YT(&5N=&9E<FYE
M;@!"96YU='IE<B!L]G-C:&5N`$)E;G5T>F5R(&SV<V-H96XZ("5S`$%N9G)A
M9V4@:V]N;G1E(&YI8VAT(&)E86YT=V]R=&5T('=E<F1E;BX@6G5R_&-K9V5G
M96)E;F5R($9E:&QE<F-O9&4Z(`!$97(@9V5W_&YS8VAT92!$:65N<W0@:V]N
M;G1E(&YI8VAT(&=E9G5N9&5N('=E<F1E;BX`(B5S(B!W=7)D92!I;B!D97(@
M2V]N9FEG=7)A=&EO;B!F_'(@)7,@;FEC:'0@86YG96=E8F5N+@`B)7,B('=U
M<F1E(&EN(&1E<B!61E,M2V]N9FEG=7)A=&EO;B!N:6-H="!A;F=E9V5B96XN
M`"(E<R(@=W5R9&4@:6X@9&5R($MO;F9I9W5R871I;VX@;FEC:'0@86YG96=E
M8F5N+@!.;W1W96YD:6=E<R!&96QD`%IU<OQC:W-E='IE;@!087-S=V]R="!Z
M=7+\8VMS971Z96X`4V5T>F5N(%-I92!):'(@4&%S<W=O<G0@>G5R_&-K`$QE
M='IT92!!8F9R86=E(&5I;F;\9V5N`$5R9V5B;FES<V4`6G5R_&-K('IU($5I
M;G-T96QL=6YG96X`3F5U97,@4&%S<W=O<G0@97)N975T(&5I;F=E8F5N`%+I
M=6YI;VX`2V]N9FEG=7)A=&EO;B!Z=7+\8VMS971Z96X`5UE325=91RU%9&ET
M;W(@16EN<W1E;&QU;F=E;@!2Y'1S96P`4F5C:'1S`%)E8VAT92#<8F5R<V-H
M<FEF=`!296-H=&4@5V5R=&4`7UIE:6QE;F5I9V5N<V-H869T96XN+BX`4F]L
M;&4`4G5MY&YI96X`56T@,3@PL"!D<F5H96X`3F%C:"!L:6YK<R!D<F5H96X`
M3F%C:"!R96-H=',@9')E:&5N`%IE:6QE;F5I9V5N<V-H869T96X`6F5I;&5N
M96EG96YS8VAA9G1E;@!:96EL96XZ`%)E9V5L;@!286AM96X@>G=I<V-H96X@
M86QL96X@6F5I;&5N('5N9"!3<&%L=&5N`%)A:&UE;B!N=7(@>G=I<V-H96X@
M4W!A;'1E;@!286AM96X@;G5R('IW:7-C:&5N(%IE:6QE;@!3=&%R=&5N`%)U
M<W-I<V-H92!&]G)D97)A=&EO;@!2=6%N9&$`4R]-24U%(&MR>71O9W)A<&AI
M<V-H92!5;G1E<G-C:')I9G0`36ET(%,O34E-12!V97)S8VAL_'-S96QT92!.
M86-H<FEC:'0`4T%33"U!=71H96YT:69I>FEE<G5N9R!I<W0@;FEC:'0@=F5R
M9OQG8F%R+@!335,M5F5R<V%N9`!344P@4VAE;&P`4U%,+4%N=V5I<W5N9R!Z
M=7(@06)F<F%G92!D97(@5V5R=&4`4U-(`$521D],1P!37U%,(%-H96QL`%-A
M`%-A:6YT($AE;&5N80!386EN="!+:71T<R!U;F0@3F5V:7,`4V%I;G0@3'5C
M:6$`4V%I;G0@4&EE<G)E('5N9"!-:7%U96QO;@!386EN="!6:6YC96YT('5N
M9"!D:64@1W)E;F%D:6YE;@!';&5I8VAE<B!286AM96X@*%]S96QF*0!386UO
M80!386X@36%R:6YO`%-A;R!4;VUE('5N9"!0<FEN8VEP90!3871E;&QI=&5N
M<')O=FED97(`4V%U9&DM07)A8FEE;@!3<&5I8VAE<FX`(B5S(B!S<&5I8VAE
M<FX`)7,@<W!E:6-H97)N`$5I;G-T96QL=6YG96X@<W!E:6-H97)N`$5R>F5U
M9W1E($MO;F9I9W5R871I;VX@86QS(%!(4"U3:W)I<'0@:6T@=&5M<&]RY')E
M;B!697)Z96EC:&YI<R!):')E<R!397)V97)S('-P96EC:&5R;BX`)7,M2V]N
M9FEG=7)A=&EO;B!G97-P96EC:&5R="X`1&%S($%K='5A;&ES:65R=6YG<W-K
M<FEP="!W=7)D92!I;B`B)7,B(&=E<W!E:6-H97)T+@!697)E:6YZ96QT92!'
M97=I='1E<@!7:7-S96YS8VAA9G0`4W5C:&4`4W5C:&UA<V-H:6YE;@!$871E
M:65N(&%U<W?D:&QE;@!$871U;2!A=7-WY&AL96X`2&EN>G5Z=6;\9V5N9&4@
M1W)U<'!E;B!A=7-WY&AL96X`3F5U96X@0F5S:71Z97(@875S=^1H;&5N`%-E
M<G9E<B!A=7-WY&AL96X`2&EN>G5Z=6;\9V5N9&5N($)E;G5T>F5R(&%U<W?D
M:&QE;@!!;&QE(&%U<W?D:&QE;@!,96=E;B!3:64@86QL92!$871U;7-K;VUP
M;VYE;G1E;B!F97-T+@!/8FIE:W0@875S=^1H;&5N`$ME:6YE;B!A=7-WY&AL
M96X`5^1H;&5N(%-I92!D:64@8F5N]G1I9W1E;B!:96EC:&5N(&%U<R!D96X@
M:F5W96EL:6=E;B!&96QD97)N(&%U<RX@1&%N;B!K]FYN96X@4VEE(&1I97-E
M(&%U<R!D96T@5&5X=&9E;&0@:V]P:65R96X@=6YD(&EN($EH<F4@3F%C:')I
M8VAT(&5I;F;\9V5N+@!7Y&AL96X@4VEE(&1A<R!$871U;7-T<F5N;GIE:6-H
M96XZ`%?D:&QE;B!3:64@9&%S($1A='5M<V9O<FUA=#H`5^1H;&5N(%-I92!D
M:64@261E;G1I=.1T+"!D:64@4VEE(.1N9&5R;B!M]F-H=&5N.@!7Y&AL96X@
M4VEE(&1A<R!:96ET=')E;FYZ96EC:&5N.@!7Y&AL96X@4VEE(&1A<R!:96ET
M9F]R;6%T.@!7Y&AL96X@4VEE('IW96D@>G5S86UM96YG96CV<FEG92!&96QD
M97(@875S+@!7Y&AL96X@4VEE(&5I;B!&87)B<V-H96UA+@!7Y&AL96X@4VEE
M($EH<F4@8F5V;W)Z=6=T92!3<')A8VAE.@!0<F]B;&5M8F5R:6-H="!A8G-C
M:&EC:V5N`%--4R!V97)S8VAI8VME;@!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:65N('5N9"!-;VYT96YE9W)O`%-E<FEE;FYU;6UE<@!397)V
M97)D871E;B!U;F?\;'1I9R!O9&5R(&YI8VAT('9E<F;\9V)A<BX`4V5S<W-I
M;VYV97)W86QT=6YG`%-E<W-I;VXM240@86)G96QA=69E;BX`4VET>G5N9V5N
M`$%U<W=A:&PM4V%T>@!,96=E;B!3:64@9&EE($5I;G-T96QL=6YG96X@9F5S
M="P@9&EE(&5S($EH;F5N(&5R;&%U8F5N($EH<B!087-S=V]R="!Z=7+\8VMZ
M=7-E='IE;BP@9F%L;',@<VEE(&5S(&5I;FUA;"!V97)G97-S96X@<V]L;'1E
M;BX`3&5G96X@4VEE(&5N=&9E<FYT92!397)V97(@9F5S="P@875F(&1I92!3
M:64@=F]N($EH<F5M(%!O<G1A;"!A=7,@>G5G<F5I9F5N(&WV8VAT96XN`%?D
M:&QE;B!3:64@26AR92!B979O<GIU9W1E(%-P<F%C:&4L(%IE:71Z;VYE('5N
M9"!$871U;7-E:6YS=&5L;'5N9V5N+@!,96=E;B!3:64@9&%S(&1I92!3=&%R
M=&%N=V5N9'5N9RP@9&%S($9A<F)S8VAE;6$L(&1I92!396ET96YA:W1U86QI
M<VEE<G5N9R!U;F0@86YD97)E($%N>F5I9V5E:6YS=&5L;'5N9V5N(&9E<W0N
M`$MO;F9I9W5R871I;VX`06MT=6%L:7-I97)U;F=S<VMR:7!T92!S:6YD('9E
M<F;\9V)A<@!-96AR97)E('!A<W-E;F1E($]R=&4@;6ET(&1I97-E;2!087)A
M;65T97(Z(`!397EC:&5L;&5N`$5I;FMA=68`2W5R>F4@6G5S86UM96YF87-S
M=6YG`%-O;&QE;B!487-T96YK;VUB:6YA=&EO;F5N(&;\<B!D:64@;65I<W1E
M;B!,:6YK<R!A:W1I=FEE<G0@=V5R9&5N/P!:96EG96X`56YT97)S8VAI961E
M('IW:7-C:&5N(&1E<B!A:W1U96QL96X@=6YD(&1E<B!G97)A9&4@97)Z975G
M=&5N($MO;F9I9W5R871I;VX@86YZ96EG96XN`$%N>F5I9V5N+"!W86YN(&1I
M92!L971Z=&4@06YM96QD=6YG(&5R9F]L9W0@:7-T/P!%<FAA;'1E;B!D97,@
M3W)I9VEN86QS(&5R;?9G;&EC:&5N`$%U<W?D:&QE<B!A;GIE:6=E;@!797)K
M>F5U9VQE:7-T92!F_'(@5&%B96QL96X@86YZ96EG96X_`$1A<R`E<RU-96[\
M(&%U9B!D97(@;&EN:V5N(%-E:71E(&%N>F5I9V5N/P!$:6%L;V<@9OQR(%1A
M8F5L;&5N>F5L;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR
M(%1A8F5L;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR(%1A
M8F5L;&5N>F5I;&5N96EG96YS8VAA9G1E;B!A;GIE:6=E;@!$:6%L;V<@9OQR
M($)I;&1E:6=E;G-C:&%F=&5N(&%N>F5I9V5N`$AO8VAL861E;B!E<FWV9VQI
M8VAE;@!38VAA=65R`$9R_&@@4V-H875E<@!3<.1T97(@4V-H875E<@!38VAA
M=65R(&EN(&1E<B!5;6=E8G5N9P!697)K;&5I;F5R;@!697)K;&5I;F5R;B!O
M9&5R('9E<G-C:&EE8F5N(%-I92!E<G-T(&1I92!B96YA8VAB87)T96X@0FSV
M8VME`%-I97)R82!,96]N90!296=I<W1R:65R96X`4VEG;F%T=7(`4VEG;F%T
M=7)A;&=O<FET:&UU<P!3:6YG87!U<@!'<O;?90!787)T=6YG<V%R8F5I=&5N
M(/QB97)S<')I;F=E;@!3;&]W86ME:0!3;&]W96YI96X`4V-H;F5E`%-C:&YE
M97-C:&%U97(`4V-H;F5E<V-H875E<@!&<OQH(%-C:&YE97-C:&%U97(`4W#D
M=&5R(%-C:&YE97-C:&%U97(`4V-H;F5E:/9H93H@`%-C:&YE96UE;F=E(&%L
M<R!787-S97(Z(`!3;VQO;6]N:6YS96QN`%-O;6%L:65N`$QI961E<B`F($=E
M9&EC:'1E`$%U<W=A:&P@9&5R(%-O<G1I97)R96EH96YF;VQG90!5<G-P<G5N
M9W-A9')E<W-E`%/\9&%F<FEK80!3_&1E=7)O<.1I<V-H("A)4T\M.#@U.2TS
M*0!3_&1G96]R9VEE;B!U;F0@9&EE(%/\9&QI8VAE;B!386YD=VEC:&EN<V5L
M;@!3_&1L:6-H92!(96UI<W!H97)E`$%B<W1A;F0@>G=I<V-H96X@875F96EN
M86YD97(@9F]L9V5N9&5N(%IE;&QE;@!!8G-T86YD('IW:7-C:&5N($EN:&%L
M="!U;F0@4F%H;65N('9O;B!:96QL96X`06)S=&%N9&AA;'1E<@!!8G-T86YD
M`$%B<W3D;F1E`%-P86YI96X`4W!A;0!3;VYD97)Z96EC:&5N+45I;F=A8F4`
M6F5L;&4@=&5I;&5N`%-P86QT92!T96EL96X`6F5I;&4@=&5I;&5N`%-P;W)T
M`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G1J86AR`$)U;F1E
M<W-T86%T(&]D97(@4')O=FEN>@!3=&%T=7,`4W!E:6-H97)F;W)M870`4W1R
M8=]E`$1U<F-H9V5S=')I8VAE;@!:96EC:&5N;&ES=&4`1&]M86EN(&%U<R!D
M97(@061R97-S92!E;G1F97)N96X`4W1I;"!;0U-370!3;P!5;G1E<G9E<GIE
M:6-H;FES("(E<R(@;FEC:'0@9V5F=6YD96XN`$)E=')E9F8`06)S8VAI8VME
M;@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E(&;\<B`B)7,B('=U<F1E(&%B
M9V5S8VAI8VMT+B!3:64@:_9N;F5N('-I8V@@;F]C:"!N:6-H="!A;FUE;&1E
M;BP@<V]L86YG92!D:64@06YF<F%G92!N;V-H(&YI8VAT(&)E<W3D=&EG="!W
M=7)D92X`5&EE9F=E<W1E;&QT`$5R9F]L9P`B)7,B('=U<F1E(&5R9F]L9W)E
M:6-H(&AI;GIU9V5F_&=T+@!$871E;B!D97,@0F5N=71Z97)S("(E<R(@=W5R
M9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N`"(E<R(@=W5R9&4@97)F;VQG<F5I
M8V@@9V5L]G-C:'0N`"(E<R(@=W5R9&4@97)F;VQG<F5I8V@@9V5L]G-C:'0N
M`$MO;F9I9W5R871I;VX@97)F;VQG<F5I8V@@>G5R_&-K9V5S971Z="X@4V5I
M=&4@;F5U(&QA9&5N+"!U;2!D:64@Q&YD97)U;F=E;B!A;GIU>F5I9V5N+@!"
M86-K=7`@9&5R($MO;F9I9W5R871I;VX@97)F;VQG<F5I8V@@9V5S<&5I8VAE
M<G0N`$)A8VMU<"!D97(@2V]N9FEG=7)A=&EO;B`E<R!E<F9O;&=R96EC:"!G
M97-P96EC:&5R="X`(B5S(B!W=7)D92!E<F9O;&=R96EC:"!A:W1U86QI<VEE
M<G0`)7,@=W5R9&4@97)F;VQG<F5I8V@@9V5S<&5I8VAE<G0`4W5D86X`6G5S
M86UM96YF87-S=6YG`%-O;FYE;F%U9F=A;F<`4V]N;F5N=6YT97)G86YG`%-O
M;FYI9P!3;VYN96YA=69G86YG`%-O;FYE;F%U9B]U;G1E<F=A;F<`4V]N;F5N
M875F9V%N9SH@`%-O;FYE;G5N=&5R9V%N9P!3;VYN96YU;G1E<F=A;F<Z(`!(
M;V-H9V5S=&5L;'0`4W5P<&]R=`!3=7)I;F%M`$YA8VAN86UE`%-V86QB87)D
M('5N9"!*86X@36%Y96X`4W=A<VEL86YD`%-C:'=E9&5N`%-C:'=E:7H`4WEN
M8VAR;VYI>F%T:6]N<VQO9R!G96SV<V-H=`!&;W)M871F96AL97(@:6X@4W5C
M:&)E9W)I9F9E;@!!<F%B:7-C:&4@4F5P=6)L:6L@4WER:65N`$=E=VET=&5R
M`$=E=VET=&5R('5N9"!7:6YD:6<`1V5W:71T97(`1G+\:"!'97=I='1E<@!4
M4U8M1&%T96D`5&%B96QL96YE:6=E;G-C:&%F=&5N`%1A8F5L;&4`5&%B96QL
M96YE:6=E;G-C:&%F=&5N`%1A:7=A;@!486EW86XL(&-H:6YE<VES8VAE(%!R
M;W9I;GH`5&%D<V-H:6MI<W1A;@!697)E:6YI9W1E(%)E<'5B;&EK(%1A;G-A
M;FEA`%II96PZ`$%U9F=A8F5N`%1E;&5F;VYN=6UM97(`5&5M<&5R871U<B!D
M97(@;&5T>G1E;B!3='5N9&4Z(`!496UP97)A='5R`%1E;7!E<F%T=7(Z(`!4
M96UP97)A='5R/&)R("\^*"5S36%X)7,O)7--:6XE<RD@)F1E9SLE<P!6;W)L
M86=E("(E<R(@;FEC:'0@9V5F=6YD96XN`%9O<FQA9V5N=F5R=V%L='5N9P!4
M97AT`$YU<B!497AT`$%U<W)I8VAT=6YG`%1E>'0@3V)E;@!$;P!4:&%I;.1N
M9&ES8V@@*%1)4RTV,C`I`%1H86EL86YD`$1I92!&5%`M17AT96YS:6]N(&ES
M="!N:6-H="!V97)F_&=B87(N`$1I92!#:')O;FEK('-T96AT(&YI8VAT('IU
M<B!697)F_&=U;F<N`$1I92!(;W)D92]+;VQA8B!);G1E9W)A=&EO;G-F=6YK
M=&EO;F5N('5N=&5R<W3\='IE;B`B)7,B(&YI8VAT`$1I92!)35-0+4QO9V1A
M=&5I(&MO;FYT92!N:6-H="!E<G-T96QL="!W97)D96XN`$1I92!-86EN=&5N
M86YC93HZ($ML87-S92!K;VYN=&4@;FEC:'0@9V5L861E;B!W97)D96X`1&%S
M($5I;G-T96QL=6YG96XM1F5N<W1E<B!I<W0@9V5S8VAL;W-S96X@=V]R9&5N
M+B!!8F)R=6-H+@!$97(@061M:6YI<W1R871O<B!M=7-S(&5I;B!P97)M86YE
M;G1E<R!296-H=&4M0F%C:V5N9"!E:6YR:6-H=&5N+"!W96YN(%-I92!D:64@
M4F5C:'1E=F5R=V%L='5N9R!N=71Z96X@;?9C:'1E;BX`3G5R('5N=&5N`$1I
M92!)1"U.=6UM97(@9&5S($MO;G1A:W1S('=U<F1E(&YI8VAT(&%N9V5B96XL
M('=A<B!L965R(&]D97(@:V]N;G1E(&EN(&1E<B!$871E;F)A;FL@;FEC:'0@
M9V5F=6YD96X@=V5R9&5N+@!$97(@2V]N=&%K="!W=7)D92!E<F9O;&=R96EC
M:"!):')E;2!!9')E<W-B=6-H(&AI;GIU9V5F_&=T+@!$97(@4$=0+5-I9VYA
M='5R8FQO8VL@=VER9"!B96[V=&EG="P@=6T@9&EE('5N=&5R>F5I8VAN971E
M($YA8VAR:6-H="!Z=2#\8F5R<'+\9F5N+@!$:64@240M3G5M;65R(&1E<B!6
M97)T96EL97)L:7-T92!W=7)D92!N:6-H="!A;F=E8F5N+"!W87(@;&5E<B!O
M9&5R(&MO;FYT92!I;B!D97(@1&%T96YB86YK(&YI8VAT(&=E9G5N9&5N('=E
M<F1E;BX`1&EE(%9E<G1E:6QE<FQI<W1E('=U<F1E(&YI8VAT(&%N9V5G96)E
M;BX`1&EE(%9E<G-C:&S\<W-E;'5N9W-F=6YK=&EO;F5N(&)E;O9T:6=E;B!E
M:6YE('-I8VAE<F4@4V5R=F5R=F5R8FEN9'5N9RX`1&EE($1A=&5I("5S('-O
M;&QT92!E:6YE;B`E<R!%:6YT<F%G(&5N=&AA;'1E;BX`1&EE($1A=&5I("5S
M('-O;&QT92!E:6YI9V4@)7,@16EN='+D9V4@96YT:&%L=&5N+@!$:64@1&%T
M96D@96YT:&EE;'0@:V5I;F4@1&%T96XN`$AI97(@<VEN9"!D:64@2V]P9F5I
M;G1RY&=E(&;\<B!D:65S92!M97-S86=E+W)F8S@R,B!.86-H<FEC:'0N`$1E
M<B!6;VQL8FEL9&UO9'5S('9E<G5R<V%C:'0@875F($=R=6YD('9O;B!&96AL
M97)N(&EM($EN=&5R;F5T($5X<&QO<F5R(&)E:V%N;G1E<FUAWV5N(%!R;V)L
M96UE(&UI="!D:65S96T@0G)O=W-E<BP@9&EE('=I<B!N:6-H="!U;6=E:&5N
M(&OV;FYE;BX@56YT97(@56US=.1N9&5N(&5R:&%L=&5N(%-I92!E:6YE(&9E
M:&QE<FAA9G1E($%N>F5I9V4L(&9E:&QE;B!%9&ET;W)F=6YK=&EO;F5N+"!O
M9&5R(&1E<B!"<F]W<V5R('-T_')Z="!A8BX@075F(&5I;F5M(%=I;F1O=R`Y
M>"!3>7-T96T@=V5R9&5N(%-I92!V97)M=71L:6-H(&5I;F4@)T%L;&=E;65I
M;F4@4V-H=71Z=F5R;&5T>G5N9R<@97)H86QT96X@=6YD(&W\<W-E;B!D96X@
M4F5C:&YE<B!N974@<W1A<G1E;BY<;EQN4VEE('=U<F1E;B!G97=A<FYT+B!"
M:71T92!D<OQC:V5N(%-I92!A=68@3TLL('=E;FX@4VEE(&YO8V@@:6UM97(@
M9&5N(%9O;&QB:6QD;6]D=7,@=F5R=V5N9&5N(&WV8VAT96XN`$1I92!)9&5N
M=&ETY'0@(B5S(B!W=7)D92!G96SV<V-H="X`3G5R(&QI;FMS`$1E<B!/<G0@
M9&5S($=N=5!'+5!R;V=R86UM<R!M=7-S(&1E<B!#<GEP=%]P9W`Z.B!+;&%S
M<V4@_&)E<F=E8F5N('=E<F1E;BX`1&EE($YA8VAR:6-H="!M:70@9&5M($)E
M=')E9F8@(B4S)',B+"!D:64@86T@)3$D<R!A;B`E,B1S(&=E<V-H:6-K="!W
M=7)D92P@:7-T(&%N9V5Z96EG="!W;W)D96XN"D1A<R!H96G?="!N:6-H="P@
M9&%S<R!D:64@3F%C:')I8VAT(&%U8V@@9V5L97-E;B!O9&5R('9E<G-T86YD
M96X@=W5R9&4N`$YA;64@9OQR(&1E;B!,:6YK('IU<B!.86-H<FEC:'1E;F5R
M<W1E;&QU;F<`1&EE($%N>F%H;"!D97(@1F5L9&5R(&UU<W,@86QS(%IA:&P@
M86YG96=E8F5N('=E<F1E;BX`1&%S($]P96Y34TPM36]D=6P@=VER9"!F_'(@
M9&EE($AO<F1E7T-R>7!T7W-M:6UE.CH@2VQA<W-E(&)E;O9T:6=T+@!$:64@
M0F5N=71Z97)E:6YS=&5L;'5N9R`B)7,B(&MO;FYT92!N:6-H="!G97-P96EC
M:&5R="!W97)D96XL('=E:6P@:6AR92!$871E;B!D:64@;6%X:6UA;"!E<FQA
M=6)T92!'<O;?92#\8F5R<V-H<F5I=&5N`$1A<R!0<F]G<F%M;2!F_'(@9&EE
M($%N>F5I9V4@9&EE<V5S($1A=&5I='EP<R`H)7,I('=U<F1E(&YI8VAT(&=E
M9G5N9&5N+@!$87,@06YF_&AR=6YG<WIE:6-H96X@;75S<R!A;',@96EN>F5L
M;F5S(%IE:6-H96X@86YG96=E8F5N('=E<F1E;BX`3G5R(&QI;FMS('5N9"!R
M96-H=',`3G5R(')E8VAT<P!$87,@5')E;FYZ96EC:&5N(&UU<W,@86QS(&5I
M;GIE;&YE<R!:96EC:&5N(&%N9V5G96)E;B!W97)D96XN`$1E<B!397)V97(@
M(B5S(B!W=7)D92!E;G1F97)N="X`1&5R(%-E<G9E<B`B)7,B('=U<F1E(&=E
M<W!E:6-H97)T+@!$:64@4F5G:7-T<FEE<G5N9W-A;F9R86=E('9O;B`E<R!W
M=7)D92!E;G1F97)N="X`1&EE(&%N9V5G96)E;F4@6F5I;&4@*"5D*2!E>&ES
M=&EE<G0@;FEC:'0N`$1I92!T96UP;W+D<F4@1&%T96D@(B5S(B!E>&ES=&EE
M<G0@;FEC:'0N`$1E<B!497AT+"!D96X@4VEE(&%N9V5G96)E;B!H86)E;BP@
M96YT<W!R:6-H="!N:6-H="!D96T@5&5X="!A=68@9&5M($)I;&1S8VAI<FTN
M`$YU<B!O8F5N('5N9"!U;G1E;@!.=7(@;V)E;@!$:64@:&]C:&=E;&%D96YE
M;B!$871E;B!S:6YD(&YA8V@@9&5M(&QE='IT96X@4V-H<FET="!V97)L;W)E
M;B!G96=A;F=E;BX`1&EE(&AO8VAG96QA9&5N92!$871E:2!K;VYN=&4@;FEC
M:'0@9V5S<&5I8VAE<G0@=V5R9&5N+@!$97(@=V5A=&AE<BYC;VT@0FQO8VL@
M:7-T(&YI8VAT('9E<F;\9V)A<BX`5&AE;65N+59E<GIE:6-H;FES("(E<R(@
M;FEC:'0@9V5F=6YD96XN`$5S('-I;F0@:V5I;F4@16EN<W1E;&QU;F=E;B!V
M97)F_&=B87(N`$5S(&=I8G0@:V5I;F4@86YZ96EG8F%R96X@3F%C:')I8VAT
M96YT96EL92X`1&EE<V5S($9E;&0@96YT:.1L="!Z=2!V:65L92!:96EC:&5N
M+B!3:64@:&%B96X@)7,@6F5I8VAE;B!A;F=E9V5B96X[(%-I92!M_'-S96X@
M=V5N:6=E<B!A;',@)7,@86YG96)E;BX`0F5I;2!(:6YZ=6;\9V5N('9O;B`B
M)7,B('IU;2!3>7-T96T@:7-T(&5I;B!0<F]B;&5M(&%U9F=E=')E=&5N.B`E
M<P!"96EM($SV<V-H96X@9&5R($1A=&5N('9O;B!"96YU='IE<B`B)7,B(&ES
M="!E:6X@4')O8FQE;2!A=69G971R971E;CH@`$)E:6T@3/9S8VAE;B!V;VX@
M(B5S(B!A=7,@9&5M(%-Y<W1E;2!I<W0@96EN(%!R;V)L96T@875F9V5T<F5T
M96XZ(`!"96EM($%K='5A;&ES:65R96X@=F]N("(E<R(@:7-T(&5I;B!0<F]B
M;&5M(&%U9F=E=')E=&5N.B`E<P!"96EM($AO8VAL861E;B!D97(@1&%T96D@
M:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN("5S('=U<F1E(&YI8VAT(&AO
M8VAG96QA9&5N+@!"96EM($AO8VAL861E;B!D97(@1&%T96D@:7-T(&5I;B!&
M96AL97(@875F9V5T<F5T96XN("5S('=A<B!G<O;?97(@86QS(&1I92!M87AI
M;6%L(&5R;&%U8G1E($=R]M]E("@E9"!">71E<RDN`$)E:6T@2&]C:&QA9&5N
M(&1E<B!$871E:2!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@)7,@=W5R
M9&4@;G5R('1E:6QW96ES92!H;V-H9V5L861E;BX`0F5I;2!!;GIE:6=E;B!D
M:65S97,@3F%C:')I8VAT96YT96EL<R!I<W0@96EN($9E:&QE<B!A=69G971R
M971E;BX`0F5I;2!);7!O<G1I97)E;B!D97(@2V]N=&%K=&1A=&5N(&ES="!E
M:6X@1F5H;&5R(&%U9F=E=')E=&5N+@!"96EM($EM<&]R=&EE<F5N(&1E<B!I
M0V%L96YD87(@1&%T96X@:7-T(&5I;B!&96AL97(@875F9V5T<F5T96XN`$1A
M<R!+;VYF:6=U<F%T:6]N<RU&;W)M=6QA<B!E;G1H:65L="!E:6YE;B!&96AL
M97(N(%9I96QL96EC:'0@:&%B96X@4VEE(&5I;B!09FQI8VAT9F5L9"!L965R
M(&=E;&%S<V5N+@!"96EM($%U<V;\:')E;B!D97(@86YG96=E8F5N96X@061R
M97-S8G5C:&9U;FMT:6]N(&ES="!E:6X@1F5H;&5R(&%U9F=E=')E=&5N+B!"
M:71T92!V97)S=6-H96X@4VEE(&5S('-PY'1E<B!N;V-H(&5I;FUA;"X`0F5I
M(&1E<B!!:W1U86QI<VEE<G5N9R!D97(@2V]N=&%K=&1E=&%I;',@:7-T(&5I
M;B!&96AL97(@875F9V5T<F5T96XN($)I='1E('9E<G-U8VAE;B!3:64@97,@
M<W#D=&5R(&YO8V@@96EN;6%L+@!"96D@9&5R($%K='5A;&ES:65R=6YG(&1E
M<B!697)T96EL97)L:7-T92!I<W0@96EN($9E:&QE<B!A=69G971R971E;BX@
M0FET=&4@=F5R<W5C:&5N(%-I92!E<R!S<.1T97(@;F]C:"!E:6YM86PN`$1I
M97-E<B!)34%0+5-E<G9E<B!U;G1E<G-T_'1Z="!K96EN92!G96UE:6YS86UE
M;B!/<F1N97(N`$1I97,@<V-H96EN="!K96EN(&?\;'1I9V5S(%)!4BU!<F-H
M:78@>G4@<V5I;BX`1&EE<R!S8VAE:6YT(&ME:6X@9_QL=&EG97,@6DE0+4%R
M8VAI=B!Z=2!S96EN+@!$:65S('-C:&5I;G0@:V5I;F4@9_QL=&EG92!+87)T
M96YN=6UM97(@>G4@<V5I;BX`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@
M5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!#;&EC:V%T
M96QL+4=A=&5W87D@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@;6ET($AI;&9E
M(&1E<B!(5%10+4%022X`1&EE<V5R(%1R96EB97(@97)L875B="!D87,@5F5R
M<V-H:6-K96X@=F]N($YA8VAR:6-H=&5N(&1U<F-H(&1E;B!724XM1V%T97=A
M>2`H:'1T<#HO+W=I;G!L8RYC;VTI(&UI="!(:6QF92!D97(@2%144"U!4$DN
M`$1I97-E<B!4<F5I8F5R(&5R;&%U8G0@9&%S(%9E<G-C:&EC:V5N('9O;B!.
M86-H<FEC:'1E;B!D=7)C:"!D96X@<VUS,FUA:6PM1V%T97=A>2`H:'1T<#HO
M+W-M<S)M86EL+F-O;2D@;6ET($AI;&9E(&1E<B!(5%10+4%022X`1&EE<V5R
M(%1R96EB97(@97)L875B="!D87,@5F5R<V-H:6-K96X@=F]N($YA8VAR:6-H
M=&5N('!E<B!33510(&1U<F-H(&1E;B!6;V1A9F]N92U)=&%L:65N+4=A=&5W
M87D@875S<V-H;&EEWVQI8V@@86X@5F]D869O;F4M3G5M;65R;BX@1&%F_'(@
M=VER9"!E:6X@12U-86EL+4MO;G1O(&)E:2!6;V1A9F]N92!)=&%L:65N("AH
M='1P.B\O=W=W+C$Y,"YI="D@8F5N]G1I9W0N`$1I97-E<R!&96QD(&ES="!N
M;W1W96YD:6<N`$1I97-E<R!&96QD(&1A<F8@;G5R(&=A;GIE(%IA:&QE;B!E
M;G1H86QT96XN`$1I97-E<R!&96QD(&1A<F8@;G5R(%IA:&QE;B!U;F0@96EN
M96X@4'5N:W0@96YT:&%L=&5N+@!$:65S97,@1F5L9"!D87)F(&YU<B!/:W1A
M;'IA:&QE;B!E;G1H86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN92!K;VUM
M82T@;V1E<B!L965R>F5I8VAE;F=E=')E;FYT92!,:7-T92!V;VX@9V%N>F5N
M(%IA:&QE;B!E;G1H86QT96X`1&EE<V5S($9E;&0@;75S<R!E:6YE(&?\;'1I
M9V4@6F%H;"!E;G1H86QT96XN`$1I97-E<R!&96QD(&UU<W,@96EN96X@1F%R
M8G=E<G0@:6T@:&5X861E>FEM86QE;B!21T(M1F]R;6%T(&5N=&AA;'1E;BP@
M>BX@0BX@)R,Q,C,T868G+@!$:65S97,@1F]R;75L87(@=W5R9&4@8F5R96ET
M<R!V97)A<F)E:71E="X`1&EE<R!I<W0@)7,N`$1I92!I<W0@96EN($MO;&%B
M+4=R;W5P=V%R92U/8FIE:W0N(%5M(&1I97-E<R!/8FIE:W0@86YZ=7IE:6=E
M;BP@8F5N]G1I9V5N(%-I92!E:6X@12U-86EL+5!R;V=R86UM+"!D87,@9&%S
M($MO;&%B+4=R;W5P=V%R92U&;W)M870@=6YT97)S=/QT>G0N($5I;F4@3&ES
M=&4@<V]L8VAE<B!0<F]G<F%M;64@9FEN9&5N(%-I92!U;G1E<B`E<P!$:65S
M92!.86-H<FEC:'0@=W5R9&4@:6X@96EN96T@6F5I8VAE;G-A='H@*"5S*2!E
M<G-T96QL="P@9&5R(&YI8VAT($EH<F5M(&5I9V5N96X@96YT<W!R:6-H="X`
M1&EE<V4@6F%H;"!M=7-S(#$@;V1E<B!G<O;?97(@<V5I;BX`1&EE<V5R(%-E
M<G9E<B!K86YN(%I)4"T@=6YD($=:25`M1&%T96EN(&YI8VAT(&5N='!A8VME
M;BX`1&EE<V5S(%-Y<W1E;2!I<W0@>G5R(%IE:70@9&5A:W1I=FEE<G0N`$1I
M97-E<B!797)T(&UU<W,@96EN92!:86AL('-E:6XN`$1I97-E<R!&96YS=&5R
M(&UU<W,@=F]N(&5I;F5M($5I;G-T96QL=6YG96XM1F5N<W1E<B!G9?9F9FYE
M="!W97)D96X`1&]N;F5R`%1I8VME=',`6F5I=`!:96ET97)F87-S=6YG`%IE
M:71F;W)M870`6F5I=&%U<W=A:&P`5&EM;W(M3&5S=&4`5&ET96P`5&ET96P@
M*%1O;VQT:7`I.@!!;@!(86QT96X@4VEE(&)E:6T@2VQI8VME;B!3=')G(&)Z
M=RX@*%!#*2!#;VUM86YD("A-86,I(&=E9'+\8VMT+"!U;2!M96AR97)E($5I
M;G1RY&=E(&%U<WIU=^1H;&5N+@!(975T90!:=2!(5$U,+5%U96QL8V]D92!U
M;7-C:&%L=&5N`%1O9V\`5&]K96QA=0!-;W)G96X`5&]N9V$`6G4@=FEE;&4@
M=6YG_&QT:6=E($%N;65L9&5V97)S=6-H92!I;B!D96X@;&5T>G1E;B!-:6YU
M=&5N+@!/8F5N`,1UWV5R<W1E<B!286AM96X@*%]T;W`I`-QB97)S971Z=6YG
M96X`5')I;FED860@=6YD(%1O8F%G;P!786AR(&]D97(@9F%L<V-H`$1I`%1U
M;F5S:65N`%3\<FME:0!4_')K:7-C:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES
M=&%N`%1U<FMS+2!U;F0@0V%I8V]S:6YS96QN`%1U=F%L=0!):')E($%U<W=A
M:&PZ(`!55BU);F1E>#H@`$AO;65P86=E`%523"!):')E<R!3:W)I<'1S(&;\
M<B!D96X@5F5R<V%N9'-T871U<V)E<FEC:'0`061R97-S93H`56=A;F1A`%5K
M<F%I;F4`075F(&1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT('IU
M9V5G<FEF9F5N('=E<F1E;BX`1&EE('IU<^1T>FQI8VAE;B!"96YU='IE<FEN
M9F]R;6%T:6]N96X@:V]N;G1E;B!B96D@9&5R(%)E9VES=')I97)U;F<@;FEC
M:'0@:&EN>G5F_&=T('=E<F1E;BX`1&EE(%IU9W)I9F9S<F5C:'1E(&;\<B!D
M:64@5D93+41A=&5I("(E<R(@:V]N;G1E;B!N:6-H="!G9>1N9&5R="!W97)D
M96XN`$1I92!:=6=R:69F<W)E8VAT92!F_'(@9&EE(%9&4RU$871E:2`E<R\E
M<R!K;VYN=&5N(&YI8VAT(&=EY&YD97)T('=E<F1E;BX`17,@:V%N;B!N:6-H
M="!I;B!697)Z96EC:&YI<R`E<R!G97=E8VAS96QT('=E<F1E;BX`1&EE($=R
M]M]E('9O;B`B)7,B(&MO;FYT92!N:6-H="!B97-T:6UM="!W97)D96XN`$1I
M92!'<O;?92!V;VX@(B5S+R5S(B!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R
M9&5N+@!697)B:6YD=6YG('IU;2!344P@4V5R=F5R(&MA;FX@;FEC:'0@:&5R
M9V5S=&5L;'0@=V5R9&5N+@!34TPM5F5R8FEN9'5N9R!K;VYN=&4@;FEC:'0@
M:&5R9V5S=&5L;'0@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H
M="!K;W!I97)T('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO
M;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1A<R!61E,M5F5R>F5I8VAN
M:7,@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@86YG96QE9W0@=V5R9&5N+@!$87,@5D93+59E<GIE
M:6-H;FES("(E<R(@:V]N;G1E(&YI8VAT(&%N9V5L96=T('=E<F1E;BX`3&5E
M<F4@5D93+41A=&5I(&MO;FYT92!N:6-H="!A;F=E;&5G="!W97)D96XN`$1I
M92!$871E;B!K;VYN=&5N(&YI8VAT(&1E:V]M<')I;6EE<G0@=V5R9&5N+@`B
M)7,B(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL(&1A<R!697)Z96EC
M:&YI<R!I<W0@;FEC:'0@;&5E<BX`(B5S(B!K86YN(&YI8VAT(&=E;/9S8VAT
M('=E<F1E;CH@)7,N`"5S(&MO;FYT92!N:6-H="!G96SV<V-H="!W97)D96XL
M(&1A<R!697)Z96EC:&YI<R!I<W0@;FEC:'0@;&5E<@!$87,@5D93+59E<GIE
M:6-H;FES(&MO;FYT92!N:6-H="!R96MU<G-I=B!G96SV<V-H="!W97)D96XN
M`$1A<R!61E,M5F5R>F5I8VAN:7,@:V]N;G1E(&YI8VAT(&=E;/9S8VAT('=E
M<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@9V5L]G-C
M:'0@=V5R9&5N.B`E<RX`1&EE(%9&4RU$871E:2`B)7,B(&MO;FYT92!N:6-H
M="!G96SV<V-H="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT
M(&=E;/9S8VAT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R`B)7,B(&MO
M;FYT92!N:6-H="!G96SV<V-H="!W97)D96XN`$1A<R!61E,@:V]N;G1E(&YI
M8VAT(')E:W5R<VEV(&=E;/9S8VAT('=E<F1E;CH@)7,N`$1A<R!A:W1U96QL
M92!697)Z96EC:&YI<R!K;VYN=&4@;FEC:'0@8F5S=&EM;70@=V5R9&5N+@!$
M:64@6F5R=&EF:6MA=&1E=&%I;',@:V]N;G1E;B!N:6-H="!A=7-G96QE<V5N
M('=E<F1E;@!$97(@)7,M5')E:6)E<B!K;VYN=&4@;FEC:'0@9V5L861E;B!W
M97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI8VAT('9E<G-C:&]B96X@
M=V5R9&5N+@!$:64@5D93+41A=&5I("(E<R(@:V]N;G1E(&YI8VAT(&=E]F9F
M;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@>G5M($)E
M<V-H<F5I8F5N(&=E]F9F;F5T('=E<F1E;BX`1&EE(%9&4RU$871E:2!K;VYN
M=&4@;FEC:'0@9V7V9F9N970@=V5R9&5N+@!$87,@07)C:&EV(&MO;FYT92!N
M:6-H="!G9?9F9FYE="!W97)D96XN`$1I92!61E,M1&%T96D@:V]N;G1E(&YI
M8VAT(&=E;&5S96X@=V5R9&5N("AF:6QE<VEZ92@I(&9E:&QG97-C:&QA9V5N
M*2X`1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96X@
M*'-I>F4H*2!F96AL9V5S8VAL86=E;BDN`$1I92!$871E:2!K;VYN=&4@;FEC
M:'0@9V5L97-E;B!W97)D96XZ(`!$87,@=F9S<F]O="U697)Z96EC:&YI<R!K
M;VYN=&4@;FEC:'0@9V5L97-E;B!W97)D96XN`"5S(&MO;FYT92!N:6-H="!N
M86-H("5S('5M8F5N86YN="!W97)D96XZ($1A<R!::65L=F5R>F5I8VAN:7,@
M97AI<W1I97)T(&)E<F5I=',`1&%S(%9&4RU697)Z96EC:&YI<R!K;VYN=&4@
M;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&%S(%9&4RU697)Z96EC:&YI<R!K
M;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;CH@)7,N`$1I92!61E,M1&%T
M96D@(B5S(B!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`1&EE(%9&
M4RU$871E:2`E<R\E<R!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`
M1&EE(%9&4RU$871E:2!K;VYN=&4@;FEC:'0@=6UB96YA;FYT('=E<F1E;BX`
M(FUK:7-O9G,B(&MO;FYT92!N:6-H="!A=7-G96;\:')T('=E<F1E;BX`1&EE
M<V5S(%=O<F0M1&]K=6UE;G0@;.1S<W0@<VEC:"!N:6-H="!A;GIE:6=E;@!$
M:64@1G)E:2]'96)U8VAT+4EN9F]R;6%T:6]N96X@9OQR("5S(&MO;FYT96X@
M;FEC:'0@86MT=6%L:7-I97)T('=E<F1E;@!$:64@5D93+41A=&5I("(E<R(@
M:V]N;G1E(&YI8VAT(&=E<W!E:6-H97)T('=E<F1E;BX`1&EE(%9&4RU$871E
M:2!K;VYN=&4@;FEC:'0@9V5S8VAR:65B96X@=V5R9&5N("AC;W!Y*"D@9F5H
M;&=E<V-H;&%G96XI+@!$:64@5D93+41A=&5N(&MO;FYT96X@;FEC:'0@9V5S
M8VAR:65B96X@=V5R9&5N+@!$:64@5D93+41A=&5I(&MO;FYT92!N:6-H="!G
M97-C:')I96)E;B!W97)D96XL(&1A<R!3<&5I8VAE<G!L871Z+4MO;G1I;F=E
M;G0@=_QR9&4@_&)E<G-C:')I='1E;BX`56YT97)S=')I8VAE;@#$;F1E<G5N
M9V5N('+\8VMGY&YG:6<@;6%C:&5N`$UA8VAT(&1I92!L971Z=&4@06MT:6]N
M('+\8VMGY&YG:6<`56YG_&QT:6=E(%+\8VMM96QD=6YG('9O;2!397)V97(@
M8F5I;2!(97)S=&5L;&5N(&1E<B!697)B:6YD=6YG.B``56YE<G=A<G1E=&4@
M06YT=V]R="!D97,@4V5R=F5R<R!A=68Z(`!.:6-H="!Z=6=E;W)D;F5T`%5N
M:6-O9&4@*%541BTX*0!697)E:6YI9W1E($%R86)I<V-H92!%;6ER871E`%9E
M<F5I;FEG=&5S($OV;FEG<F5I8V@`5F5R96EN:6=T92!3=&%A=&5N`$ML96EN
M97)E($%M97)I:V%N:7-C:&4@W&)E<G-E96EN<V5L;@!%:6YH96ET96X`56YB
M96MA;FYT`%5N8F5K86YN=&4@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`
M56YB96MA;FYT92!C;&EM<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!%<R!W
M=7)D92!E:6X@=6YB96MA;FYT97(@3W)T(&%N9V5G96)E;BX`56YB96MA;FYT
M97(@0F5N=71Z97)N86UE(&]D97(@4&%S<W=O<G0N`$QI;FL@=F]M(&%K='5E
M;&QE;B!%;&5M96YT(&5N=&9E<FYE;@!5;F)E;F%N;G0`075S(%-I8VAE<FAE
M:71S9W+\;F1E;B!D_')F96X@=6YA=71O<FES:65R=&4@4VMR:7!T92!N:6-H
M="!A=7-C:&YE:61E;BP@:V]P:65R96X@=6YD(&5I;F;\9V5N+B!+;&EC:V5N
M(%-I92!A=68@3TLL('5M(&5I;F5N($AI;G=E:7,@875F(&UO>FEL;&$N;W)G
M(&%N9V5Z96EG="!Z=2!B96MO;6UE;BP@9&5R(&)E<V-H<F5I8G0L('=I92!3
M:64@96EN96T@4VMR:7!T(&1E;B!:=6=R:69F(&%U9B!D:64@6G=I<V-H96YA
M8FQA9V4@97)L875B96X@:_9N;F5N+@!&87)B92!Z=7+\8VMS971Z96X`17)W
M96ET97)U;F<@;FEC:'0@=6YT97)S=/QT>G0`06MT=6%L:7-I97)U;F<`)7,@
M86MT=6%L:7-I97)E;@!"96YU='IE<B!A:W1U86QI<VEE<F5N`"(E<R(@=W5R
M9&4@86MT=6%L:7-I97)T+@!!:W1U86QI<VEE<G5N9W-S:W)I<'0@9V5L]G-C
M:'0N`$AO8VAL861E;@!$:64@2V]N9FEG=7)A=&EO;G-D871E:65N(&%L;&5R
M($%N=V5N9'5N9V5N('=U<F1E;B!A=68@9&5N(%-E<G9E<B!H;V-H9V5L861E
M;BX`1W(N(&QA=&5I;FES8VAE($)U8VAS=&%B96X`1W(N('+V;6ES8VAE(%IA
M:&QE;@!5<G5G=6%Y`$%K='5E;&QE(&)E;G5T>F5N.B`E<P!34TP@8F5N=71Z
M96X`0FET=&4@875S9OQL;&5N+"!W96YN(%-I92!E:6YE;B!A;F1E<F5N($)E
M;G5T>F5R;F%M96XO4&%S<W=O<G0@9OQR(&1E;B!)35-0+5-E<G9E<B!H86)E
M;BX`0F5N=71Z97(`0F5N=71Z97(@)7,@:7-T(&;\<B`E<R!N:6-H="!A=71O
M<FES:65R="X`0F5N=71Z97)V97)W86QT=6YG`$)E;G5T>F5R96EN<W1E;&QU
M;F=E;@!"96YU='IE<G)E9VES=')I97)U;F<`1&EE($)E;G5T>F5R<F5G:7-T
M<FEE<G5N9R!W=7)D92!A=68@9&EE<V5M(%-Y<W1E;2!D96%K=&EV:65R="X`
M0F5N=71Z97)K;VYT;R!N:6-H="!G969U;F1E;@!"96YU='IE<FYA;64`1&5R
M($)E;G5T>F5R;F%M92`B)7,B(&5X:7-T:65R="!B97)E:71S+@!"96YU='IE
M<FYA;64Z`$)E;G5T>F5R;F%M93H@`$)E;G5T>F5R(&1E<R!3>7-T96US.@!5
M<V)E:VES=&%N`$1A<R!61E,M5F5R>F5I8VAN:7,@97AI<W1I97)T(&YI8VAT
M+@!!8G=E<V5N:&5I=`!087-S96YD92!G969U;F1E;F4@3W)T93H@`$?\;'1I
M9VME:70`5V5R="!I;B!-:6YU=&5N('9O;B!J971Z="!A;BX`1&5R(%=E<G0@
M:7-T(/QB97(@9&5R(&UA>&EM86QE;B!,Y&YG92!V;VX@)7,N`%=E<G1E`%=E
M<G1E+"!A=7,@9&5N96X@875S9V5WY&AL="!W97)D96X@:V%N;@!686YU871U
M`$1R96AE;F0`5F5N97IU96QA`-QB97)P<OQF=6YG(&9E:&QG97-C:&QA9V5N
M("T@9&EE<V4@3F%C:')I8VAT(&OV;FYT92!M86YI<'5L:65R="!W;W)D96X@
M<V5I;BX`5F5R<VEO;@!697)S:6]N<VMO;G1R;VQL90!!=7-R:6-H='5N9P!6
M97)T:6MA;&5R($EN;F5N86)S=&%N9`!697)T:6MA;#H`4V5H<B!(;V-H`%9I
M971N86T`5FEE=&YA;65S:7-C:"`H5DE30TE)*0`E<R!A;GIE:6=E;@!%:6YE
M(&5X=&5R;F4@5V5B<V5I=&4@86YZ96EG96X`06YZ96EG96X@86QS("5S`$)R
M:71I<V-H92!*=6YG9F5R;FEN<V5L;@!!;65R:6MA;FES8VAE($IU;F=F97)N
M:6YS96QN`%-I8VAT`%-I8VAT.B``5F]D869O;F4@271A;&EE;B!P97(@4TU4
M4`!705).54Y'`%=!4DY53D<A(2$@3-930TA%3B!3244@1$%3(%-+4DE05"!-
M04Y514Q,($%54R`E<RX`5TE.(/QB97(@2%144`!786QL:7,@=6YD($9U='5N
M80!787)N=6YG`$UI`%=E='1E<G9O<FAE<G-A9V4`5V5T=&5R9&%T96X@=F]N
M`%=E871H97(N8V]M`%=E8@!796)S:71E`%?V8VAE;G1L:6-H`%=I;&QK;VUM
M96X`5VEL;&MO;6UE;B!B96D@)7,`5VEL;&MO;6UE;BP@)7,`5V5S=&5U<F]P
MY&ES8V@@*$E33RTX.#4Y+3$I`%=E<W1E=7)O<.1I<V-H("A)4T\M.#@U.2TQ
M-2D`5V5S='-A:&%R80!796QC:&4@06YW96YD=6YG('-O;&P@)7,@;F%C:"!D
M96T@06YM96QD96X@86YG97IE:6=E;C\`5V5L8VAE<R!4<F5N;GIE:6-H96X@
M=VER9"!V97)W96YD970_`%=E;&-H92!!;F;\:')U;F=S>F5I8VAE;B!W97)D
M96X@=F5R=V5N9&5T/P!7:&5R96ES+4%U<W1R86QI82U+87)T90!796QC:&4@
M4&AA<V5N`%=E;&-H92!0;'5G:6YS(&;\<B!D96X@5UE325=91RU%9&ET;W(@
M<V]L;&5N(&%K=&EV:65R="!W97)D96X_`$)R96ET90!"<F5I=&4@:6X@0U-3
M+45I;FAE:71E;@!"<F5I=&4@9&5S("5S+4UE;OQS(&QI;FMS("AW:7)K<V%M
M(&YA8V@@9&5R(&[D8VAS=&5N($%N;65L9'5N9RDZ`%1A8F5L;&5N8G)E:71E
M`$5I;FAE:70`0G)E:71E.@!7:6MI`%=I;F0`1G+\:"!7:6YD`%=I;F1G97-C
M:'=I;F1I9W1K96ET(&EN($MN;W1E;@!7:6YD.@!7:6YD.B``5V5I<VAE:70`
M5W5N<V-H>F5T=&5L`$%R8F5I=`!!9')E<W-E(&=E<V-HY&9T;&EC:`!496QE
M9F]N(&=E<V-HY&9T;&EC:`!&86QS8VAE($%N>F%H;"!A;B!&96QD97)N(&EN
M(%IE:6QE("5D+B`E9"!E<G=A<G1E="P@)60@9V5F=6YD96XN`$9A;'-C:&4@
M06YZ86AL(&%N($9E;&1E<FXN("5D(&5R=V%R=&5T+"`E9"!G969U;F1E;BX`
M56YG_&QT:6=E<B!/9F9S970@)60@8F5I;2!,97-E;B!D97(@5D93+41A=&5I
M+@!1=65R=F5R=V5I<V4`6#4P.78S($=E;F5R96QL92!%:6YS8VARY&YK=6YG
M`%@U,#EV,R!%<G=E:71E<G1E<B!38VAL_'-S96QZ=V5C:P!8-3`Y=C,@06QT
M97)N871I=F5R($YA;64@9&5S(%IE<G1I9FEK871I;FAA8F5R<P!8-3`Y=C,@
M261E;G1I=.1T(&1E<R!:97)T:69I:V%T<V-H;/QS<V5L<P!8-3`Y=C,@17)W
M96ET97)U;F=E;@!*2@!*2DI*`%EA:&]O(2!+87)T90!*Y&AR;&EC:`!*96UE
M;@!*80!*82P@:6-H('-T:6UM92!Z=0!3:64@8F5F:6YD96X@<VEC:"!I;2!4
M97AT;6]D=7,N($)E;G5T>F5N(%-I92!D96X@6SP^72!+;F]P9BP@=6T@:6X@
M9&5N(%=94TE724<M36]D=7,@>G4@=V5C:'-E;&XN`%-I92!D_')F96X@;FEC
M:'0@;65H<B!A;',@)60@0FSV8VME(&5R<W1E;&QE;BX`4VEE('-I;F0@;FEC
M:'0@86YG96UE;&1E="X`4VEE(&3\<F9E;B!D87,@6F5I8VAE;B`G7"<@;FEC
M:'0@:6X@26AR96T@3F%M96X@=F5R=V5N9&5N+@!3:64@:&%B96X@:V5I;F4@
M9_QL=&EG92!%+4UA:6PM061R97-S92!A;F=E9V5B96XN`%-I92!H86)E;B!K
M96EN92!&96QD97(@875S(&1E;B!I;7!O<G1I97)T96X@1&%T96X@9&5N(&5N
M='-P<F5C:&5N9&5N($9E;&1E<FX@:6X@)7,@>G5G96]R9&YE="X`4VEE('=U
M<F1E;B!A8F=E;65L9&5T+@!3:64@;?QS<V5N(&5I;F4@9_QL=&EG92!-;V)I
M;'1E;&5F;VYN=6UM97(@86YG96)E;BP@;G5R(&%U<R!:86AL96X@=6YD(&=G
M9BX@96EN96T@(BLB(&;\<B!I;G1E<FYA=&EO;F%L92!6;W)W86AL96X@8F5S
M=&5H96YD+@!3:64@;?QS<V5N(&5I;F5N(&?\;'1I9V5N(%=E<G0@86YG96=E
M8F5N+@!3:64@;?QS<V5N(&5I;B!$871A5')E92U"86-K96YD(&MO;F9I9W5R
M:65R96XL('5M(%)E9VES=')I97)U;F=E;B!V97)W96YD96X@>G4@:_9N;F5N
M+@!3:64@;?QS<V5N(&5I;B!61E,M0F%C:V5N9"!K;VYF:6=U<FEE<F5N+@!3
M:64@;?QS<V5N(&1A<R!0<F]B;&5M(&)E<V-H<F5I8F5N+"!U;2!D96X@0F5R
M:6-H="!A8GIU<V-H:6-K96XN`%-I92!M_'-S96X@9&EE(%523"!A;F=E8F5N
M+"!A=68@9&EE(&1I97-E<B!,:6YK('9E<G=E:7-E;B!S;VQL`%-I92!M_'-S
M96X@97)S="!D96X@>G4@96YT9F5R;F5N9&5N(%-E<G9E<B!A=7-WY&AL96XN
M`%-I92!M_'-S96X@96EN96X@0F5N=71Z97)N86UE;B!A;F=E8F5N+"!D97-S
M96X@1&%T96X@9V5L]G-C:'0@=V5R9&5N('-O;&QE;BX`4VEE(&W\<W-E;B!E
M:6YE;B!Z=2!L]G-C:&5N9&5N($)E;G5T>F5R;F%M96X@86YG96)E;BX`4VEE
M(&W\<W-E;B!E:6YE;B!H:6YZ=7IU9OQG96YD96X@0F5N=71Z97)N86UE;B!A
M;F=E8F5N+@!3:64@;?QS<V5N(&1E;B!Z=2!A:W1U86QI<VEE<F5N9&5N($)E
M;G5T>F5R;F%M96X@86YG96)E;BX`4VEE(&W\<W-E;B!E:6YE($%K=&EO;B!A
M;F=E8F5N+@!3:64@;?QS<V5N(&5I;F5N(&YE=65N($MA=&5G;W)I96YA;65N
M(&%N9V5B96XN`%-I92!M_'-S96X@96EN92!)=&%L:65N:7-C:&4@5&5L969O
M;FYU;6UE<B!A;F=E8F5N`$EH<F4@)7,M4V5S<VEO;B!I<W0@86)G96QA=69E
M;BX@0FET=&4@;65L9&5N(%-I92!S:6-H(&5R;F5U="!A;BX`26AR92!%+4UA
M:6PM061R97-S90!):')E(%9O;CH@061R97-S93H`26AR92!!;F=A8F5N`$EH
M<F4@26YT97)N971A9')E<W-E(&AA="!S:6-H(&=EY&YD97)T+"!S96ET(%-I
M92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@6G5M(%-C:'5T>B!)
M:')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N974@86YM96QD96XN
M`$EH<B!.86UE`$EH<B!!=71H96YT:69I>FEE<G5N9W-S>7-T96T@97)L875B
M="!K96EN($AI;GIU9OQG96X@=F]N(&YE=65N($)E;G5T>F5R;BX@5V5N;B!3
M:64@2&]R9&4@8F5N=71Z96X@;?9C:'1E;BP@=6T@26AR92!"96YU='IE<B!Z
M=2!V97)W86QT96XL(&W\<W-E;B!3:64@96EN96X@86YD97)E;B!!=71H96YT
M:69I>FEE<G5N9W-T<F5I8F5R(&)E;G5T>F5N+@!):'(@075T:&5N=&EF:7II
M97)U;F=S<WES=&5M(&5R;&%U8G0@9&%S($%N>F5I9V5N(&1E<B!"96YU='IE
M<B!N:6-H="P@;V1E<B!D:65S92!-]F=L:6-H:V5I="!W=7)D92!A=7-G97-C
M:&%L=&5T+@!):'(@0G)O=W-E<B!H870@<VEC:"!A;G-C:&5I;F5N9"!G9>1N
M9&5R="!S96ET(%-I92!D:64@)7,M4VET>G5N9R!B96=O;FYE;B!H86)E;BX@
M6G5M(%-C:'5T>B!):')E<B!3:6-H97)H96ET(&W\<W-E;B!3:64@<VEC:"!N
M974@86YM96QD96XN`$EH<B!"<F]W<V5R('5N=&5R<W3\='IT(&1I97-E($9U
M;FMT:6]N(&YI8VAT+@!):'(@0G)O=W-E<B!U;G1E<G-T_'1Z="!D:65S92!$
M<G5C:V9U;FMT:6]N(&YI8VAT+B!":71T92!D<OQC:V5N(%-I92!3=')G+TMO
M;6UA;F1O("L@4"!U;2!Z=2!D<G5C:V5N+@!):')E(&%K='5E;&QE(%IE:71Z
M;VYE.@!):')E(%-T86YD87)D:61E;G1I=.1T('=U<F1E(&=EY&YD97)T+@!)
M:')E(%-T86YD87)D:61E;G1I=.1T.@!):'(@=F]L;'-TY&YD:6=E<B!.86UE
M.@!):'(@6G5G86YG(&ES="!A8F=E;&%U9F5N+@!):'(@;F5U97,@4&%S<W=O
M<G0@9OQR("5S(&QA=71E=#H@)7,`26AR92!%:6YS=&5L;'5N9V5N('=U<F1E
M;B!F_'(@9&EE($1A=65R(&1I97-E<B!3:71Z=6YG(&=E<W!E:6-H97)T+@!)
M:')E($5I;G-T96QL=6YG96X@=W5R9&5N(&=E<W!E:6-H97)T+@!):'(@4&%S
M<W=O<G0@=W5R9&4@>G5R_&-K9V5S971Z=`!):'(@4&%S<W=O<G0@=W5R9&4@
M>G5R_&-K9V5S971Z="X@4G5F96X@4VEE($EH<F4@12U-86EL+4YA8VAR:6-H
M=&5N(&%B('5N9"!M96QD96X@4VEE('-I8V@@;6ET($EH<F5M(&YE=65N(%!A
M<W-W;W)T(&%N+@!):'(@4&%S<W=O<G0@:7-T(&%B9V5L875F96XN`$EH<F4@
M4V5R=F5R.@!*=6=O<VQA=VEE;@!:86ER90!386UB:6$`4VEM8F%B=V4`6FEP
M<'D`6UII=&%T=&5X="!V97)S=&5C:V5N70!;4')O8FQE;6)E<FEC:'1=`%M:
M:71A='1E>'0@86YZ96EG96X@+0!;6FET871T97AT(&%N>F5I9V5N("T@)7,@
M6F5I;&5N70!;6F5I;&4@)7,@=F]N("5S70!?061M:6YI<W1R871I;VX`0F5?
M9F5H;'-Z96EL90!?1&%T851R964`6F5I;&4@7VSV<V-H96X`7T=R=7!P96X`
M7T)I;&1E:6=E;G-C:&%F=&5N+BXN`$%N7VUE;&1E;@!!8E]M96QD96X`3&EN
M:R!?8F5A<F)E:71E;BXN+@!?16EN<W1E;&QU;F=E;@!?4F5C:'1E`$QI;FL@
M7V5N=&9E<FYE;BXN+@!?2V]N9FEG=7)A=&EO;@!?5&%B96QL96YE:6=E;G-C
M:&%F=&5N+BXN`%]"96YU='IE<@!!9')E<W-B=6-H`$%D<F5S<V%T('5N8F5K
M86YN=`!+86QE;F1E<@!W:6YD<W1I;&P`075S9V%B961A=&5I(&MO;FYT92!N
M:6-H="!E<G-T96QL="!W97)D96X`16EN9V%B92!K86YN(&YI8VAT(&=E]F9F
M;F5T('=E<F1E;@!K;&EC:V5N(%-I92!H:65R`%5N9_QL=&EG92!"96YU='IU
M;F<@9&5R($MO;6UA;F1O>F5I;&4`2V]N9FEG=7)A=&EO;G-F96AL97(`2W)I
M=&ES8VAE(%-Y<W1E;61A=&5I(&9E:&QT`$1A=&5N9F]R;6%T9F5H;&5R`&)E
M87)B96ET96X`16EN=')A9R!N:6-H="!G969U;F1E;@!F86QL96YD`$1A=&5I
M`&%U<R`E<R`H)7,I(&UI="`E<R`E<P!B]FEG`&@Z`&AH`$AO<W1N86UE('5N
M8F5K86YN=`!S;V9O<G0`26YL:6YE`$5I;BTO075S9V%B969E:&QE<@!);G1E
M<FYE<B!3;V9T=V%R969E:&QE<@!:96EL96Y=`&UK:7-O9G,M1F5H;&5R8V]D
M92`E9"!B96D@9&5R($5R<W1E;&QU;F<@9&5S($E33RU!8F)I;&1E<RX`;6T`
M3F%M90!N:6-H="!I;7!L96UE;G1I97)T`$YO8V@@;FEC:'0@:6UP;&5M96YT
M:65R=`!.;W1I>F)L;V-K`%!R;WIE;G0`6G5G<FEF9B!V97)W96EG97)T`%!I
M>&5L`%)E;6]T969E:&QE<B!I;2!0<F]T;VMO;&P`<W1E:6=E;F0`4V5R=FEC
M92!N:6-H="!V97)F_&=B87(`56YT97)S8VAI961E(&%N>F5I9V5N`'-M<S)E
M;6%I;"#\8F5R($A45%``<W,`9VQE:6-H8FQE:6)E;F0`4WES=&5M9F5H;&5R
M`$%U9F=A8F5N;&ES=&4`5F]R_&)E<F=E:&5N9&5R($9E:&QE<@!G96)E;B!3
M:64@9&%S(%!A<W-W;W)T(&5I;B!Z=V5I=&5S($UA;"!Z=7(@0F5S=.1T:6=U
M;F<@96EN`'5N:69I960`=6YB96YA;FYT`&)E;G5T>F5R9&5F:6YI97)T`'9#
M87)D`&(Z`'=E871H97(N8V]M````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]D85]$2R],0U]-15-304=%4P``````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T,2`P,C$T-#``(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V1A7T1+
M+VAE;'`N>&UL````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S,S(P(#$P-3$U-#,T,30Q(#`R,30P,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/WAM;"!V97)S:6]N/2(Q+C`B
M/SX*/"$M+2`D2&]R9&4Z(&AO<F1E+VQO8V%L92]D85]$2R]H96QP+GAM;"QV
M(#$N,B`R,#`T+S`U+S(W(#(P.C(R.C$V(&IA;B!%>'`@)"`M+3X*/&AE;'`^
M"B`@/&5N=')Y(&ED/2)S=6UM87)Y(B!S=&%T93TB;F5W(CX*/'1I=&QE/E1H
M92!0;W)T86P@4&%G93PO=&ET;&4^"B`\<&%R83X*("!4:&ES('!O<G1A;"!P
M86=E('!R;W9I9&5S(&$@<75I8VL@<W5M;6%R>2!O9B!A;&P@>6]U<B!I;7!O
M<G1A;G0*("!I;F9O<FUA=&EO;BX@1F]R(&5X86UP;&4L(&ET(&UI9VAT('-H
M;W<@:&]W(&UA;GD@;F5W(&4M;6%I;"!M97-S86=E<R!Y;W4*("!H879E(&EN
M('EO=7(@24Y"3U@L('5P8V]M:6YG(&5V96YT<R!O;B!Y;W5R(&-A;&5N9&%R
M+"!T87-K<R!O;B!Y;W5R('1O+61O"B`@;&ES="P@:&5A9&QI;F5S(&9R;VT@
M<V5L96-T960@;F5W<R!S97)V:6-E<RP@86YD('-O(&]N+B`@36%N>2!O9B!T
M:&5S90H@('-U;6UA<FEE<R!W:6QL(&-O;G1A:6X@<75I8VL@<VAO<G1C=71S
M('1O(&-O;6UO;B!F=6YC=&EO;G,L('-U8V@@87,*("!C;VUP;W-I;F<@82!N
M97<@;6%I;"!M97-S86=E+"!C<F5A=&EN9R!A(&YE=R!C86QE;F1A<B!E=F5N
M="!O<B!T87-K+"!E=&,N"B`\+W!A<F$^"B`\<&%R83X*("!4:&4@8V]N=&5N
M=',@;V8@=&AI<R!P;W)T86P@<&%G92!A<F4@8W5S=&]M:7IA8FQE('9I82!T
M:&4@3&%Y;W5T(&)U='1O;BX*("!&;W(@97AA;7!L92P@>6]U(&-A;B!C:&]O
M<V4@=VAI8V@@:71E;7,@=&\@:6YC;'5D92!O;B!T:&ES('!O<G1A;"!P86=E
M(&%S"B`@=V5L;"!A<R!I;B!W:&EC:"!O<F1E<B!T:&5Y(&%R92!S:&]W;BX*
M(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](FYA=F)A<B(@<W1A=&4]
M(FYE=R(^"CQT:71L93Y4:&4@07!P;&EC871I;VX@3F%V:6=A=&EO;B!"87(\
M+W1I=&QE/@H@/'!A<F$^"B`@070@=&AE(&QE9G0@:&%N9"!S:61E(&]F('1H
M92!W96(@<&%G92!I<R!T:&4@87!P;&EC871I;VX@;F%V:6=A=&EO;B!B87(N
M"B`@0VQI8VL@;VX@=&AE(&EC;VYS(&]N('1H:7,@;F%V:6=A=&EO;B!B87(@
M=&\@<75I8VML>2!A;F0@96%S:6QY('-W:71C:`H@(&)E='=E96X@=&AE(&%V
M86EL86)L92!A<'!L:6-A=&EO;G,N"B`\+W!A<F$^"CPO96YT<GD^"B`@/&5N
M=')Y(&ED/2)P<F5F<RUD;U]M86EN=&5N86YC92(@<W1A=&4](FYE=R(^"B`@
M("`\=&ET;&4^4')E9F5R96YC97,Z($UA:6YT96YA;F-E.B!$;R!-86EN=&5N
M86YC93PO=&ET;&4^"B`@("`\<&%R83X*("`@($EF('EO=2!W;W5L9"!L:6ME
M('1O('!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;BP@
M8VAE8VL@=&AI<R!B;W@N"B`@("`\+W!A<F$^"CPO96YT<GD^"B`@/&5N=')Y
M(&ED/2)P<F5F<RUC;VYF:7)M7VUA:6YT96YA;F-E(B!S=&%T93TB;F5W(CX*
M("`@(#QT:71L93Y0<F5F97)E;F-E<SH@36%I;G1E;F%N8V4Z($-O;F9I<FT@
M36%I;G1E;F%N8V4\+W1I=&QE/@H@("`@/'!A<F$^"B`@("!)9B!Y;W4@=V]U
M;&0@;&EK92!T;R!C;VYF:7)M(&%L;"!M86EN=&5N86YC92!T87-K<R!B969O
M<F4@=&AE>2!A<F4@<G5N+"!C:&5C:R!T:&ES(&)O>"X@268@;&5F="!U;F-H
M96-K960L(&%L;"!M86EN=&5N86YC92!O<&5R871I;VYS('1H870@;F5E9"!T
M;R!B92!R=6X@=VEL;"!B92!P97)F;W)M960@875T;VUA=&EC86QL>2!W:71H
M(&YO(&-H86YC92!T;R!C86YC96P@;VX@;&]G:6XN"B`@("`\+W!A<F$^"CPO
M96YT<GD^"CPO:&5L<#X*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]D85]$2R],0U]-
M15-304=%4R]H;W)D92YM;P``````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#0P
M-3`P,2`Q,#4Q-30S-#$T,2`P,C,Q-34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````WA($E0````"+!P``'````'0\```3"@``
MS'@````````8H0``#@```!FA```/````**$```T````XH0``"````$:A```+
M````3Z$```P```!;H0``!````&BA```8````;:$``!L```"&H0``+0```**A
M```=````T*$``"0```#NH0``*0```!.B```9````/:(``"8```!7H@``#```
M`'ZB```D````BZ(```\```"PH@``"P```,"B```.````S*(```4```#;H@``
M*````.&B```(````"J,```H````3HP``%0```!ZC```2````-*,```L```!'
MHP``A0```%.C```.````V:,```H```#HHP``#0```/.C```.`````:0``!$`
M```0I```#0```"*D```,````,*0```T````]I```!@```$ND``"4````4J0`
M``H```#GI```#P```/*D```8`````J4```P````;I0``#@```"BE```.````
M-Z4```@```!&I0``"0```$^E```N````6:4``!H```"(I0``,@```*.E```X
M````UJ4``%0````/I@``40```&2F``!:````MJ8``%<````1IP``-````&FG
M```)````GJ<```T```"HIP``!P```+:G```*````OJ<```\```#)IP``!0``
M`-FG```&````WZ<``!$```#FIP``"````/BG```)`````:@```D````+J```
M)0```!6H```@````.Z@``!,```!<J```$````'"H```/````@:@```H```"1
MJ````P```)RH```/````H*@``!0```"PJ```"0```,6H```-````SZ@``!(`
M``#=J```&0```/"H```>````"JD```\````IJ0``"@```#FI```/````1*D`
M``@```!4J0``)````%VI```4````@JD``!8```"7J0``"````*ZI``!.````
MMZD``"T````&J@``&0```#2J```'````3JH```P```!6J@``+````&.J```.
M````D*H```,```"?J@``"P```*.J```'````KZH```<```"WJ@``!0```+^J
M```%````Q:H```H```#+J@```P```-:J```7````VJH```H```#RJ@``#P``
M`/VJ```.````#:L``!@````<JP``(P```#6K```.````6:L``!0```!HJP``
M%P```'VK```7````E:L``!<```"MJP``$P```,6K```/````V:L```X```#I
MJP``'P```/BK```=````&*P```<````VK```!@```#ZL```(````1:P```\`
M``!.K```!@```%ZL```*````9:P``!,```!PK```"P```(2L```0````D*P`
M`!4```"AK```%0```+>L```'````S:P``!````#5K```!0```.:L```5````
M[*P``!$````"K0``#````!2M```[````(:T``#@```!=K0``"0```):M```'
M````H*T``!0```"HK0```P```+VM```%````P:T``!````#'K0``"0```-BM
M```3````XJT``#D```#VK0``$@```#"N```G````0ZX``"P```!KK@``*@``
M`)BN```E````PZX```H```#IK@``!@```/2N```)````^ZX```<````%KP``
M+P````VO```W````/:\``"X```!UKP``50```*2O```M````^J\``"T````H
ML```/0```%:P```_````E+```"T```#4L```0`````*Q```C````0[$``",`
M``!GL0``0````(NQ```M````S+$``#,```#ZL0``)0```"ZR```5````5+(`
M`!D```!JL@``*0```(2R```D````KK(``"@```#3L@``$0```/RR```*````
M#K,```P````9LP``"@```":S```0````,;,``!8```!"LP``%@```%FS```'
M````<+,```<```!XLP``%````("S```*````E;,```@```"@LP``)P```*FS
M```(````T;,```<```#:LP``!P```.*S```&````ZK,```4```#QLP``!P``
M`/>S```&````_[,```@````&M```*0````^T```.````.;0```H```!(M```
M!````%.T```'````6+0```D```!@M```!@```&JT```1````<;0```<```"#
MM```%@```(NT```$````HK0```@```"GM```!@```+"T```-````M[0```8`
M``#%M```'@```,RT```1````Z[0```@```#]M```#0````:U```,````%+4`
M``<````AM0```P```"FU```#````+;4``!<````QM0``$P```$FU```=````
M7;4```@```![M0``!````(2U```(````B;4```@```"2M0``00```)NU```:
M````W;4``"L```#XM0``(````"2V```5````1;8```8```!;M@``!@```&*V
M```5````:;8``!@```!_M@``(@```)BV```N````N[8``!T```#JM@``(0``
M``BW``!4````*K<``"D```!_MP``"@```*FW```'````M+<```<```"\MP``
M%0```,2W```.````VK<```H```#IMP``#P```/2W```-````!+@```\````2
MN```#0```"*X```)````,+@``!0````ZN```!@```$^X```8````5K@``!T`
M``!ON```$P```(VX```1````H;@``!0```"SN```!````,BX```&````S;@`
M`!0```#4N```5````.FX``!D````/KD```0```"CN0``#@```*BY```%````
MM[D```4```"]N0``&P```,.Y```:````W[D``!,```#ZN0``$0````ZZ```1
M````(+H``!P````RN@``*@```$^Z```0````>KH``"$```"+N@``!0```*VZ
M```3````L[H```L```#'N@``$@```-.Z```*````YKH```\```#QN@``#0``
M``&[```1````#[L``!,````ANP``#````#6[```&````0KL```P```!)NP``
M!@```%:[```7````7;L``!````!UNP``$0```(:[```(````F+L```4```"A
MNP``#````*>[```0````M+L```4```#%NP``#0```,N[```&````V;L```<`
M``#@NP``#0```.B[```'````]KL```L```#^NP``!P````J\```'````$KP`
M``D````:O```"0```"2\```*````+KP``!D````YO```/0```%.\```=````
MD;P```P```"OO```$````+R\```%````S;P``"4```#3O```$@```/F\```3
M````#+T``"L````@O0``.P```$R]```@````B+T```@```"IO0``-@```+*]
M```A````Z;T``!`````+O@``"````!R^```,````);X```8````RO@``!```
M`#F^```/````/KX```X```!.O@``!P```%V^```*````9;X```T```!PO@``
M'P```'Z^```<````GKX``"$```"[O@``'@```-V^```9````_+X``!X````6
MOP``&P```#6_```A````4;\``"X```!SOP``)@```**_```<````R;\``!X`
M``#FOP``'`````7````F````(L```"L```!)P```,P```'7````F````J<``
M`"L```#0P```.````/S````=````-<$``!4```!3P0``+P```&G!```@````
MF<$``!(```"ZP0``*0```,W!```>````]\$``"`````6P@``$@```#?"``"B
M````2L(``!8```#MP@``(P````3#```H````*,,``"D```!1PP``*````'O#
M```?````I,,``!4```#$PP``(````-K#```E````^\,``"@````AQ```+0``
M`$K$```P````>,0``)(```"IQ```(0```#S%```6````7L4``!P```!UQ0``
M)@```)+%```J````N<4``$$```#DQ0``1````";&```,````:\8```<```!X
MQ@``!P```(#&```&````B,8```T```"/Q@``$````)W&```2````KL8``!,`
M``#!Q@``$@```-7&```'````Z,8```0```#PQ@``$````/7&```0````!L<`
M``P````7QP``#@```"3'```-````,\<```\```!!QP``$P```%''```-````
M9<<``"@```!SQP```P```)S'```-````H,<```8```"NQP``$0```+7'```7
M````Q\<``!L```#?QP``#@```/O'```"````"L@``$D````-R```!0```%?(
M```0````7<@```\```!NR```!````'[(```-````@\@```X```"1R````P``
M`*#(```.````I,@```@```"SR```#P```+S(```/````S,@```<```#<R```
M#0```.3(```0````\L@```T````#R0``"P```!')```&````'<D```L````D
MR0``#````##)```*````/<D``!$```!(R0``&0```%K)```+````=,D```T`
M``"`R0``(@```([)```/````L<D``!L```#!R0``-````-W)```*````$LH`
M`!@````=R@``$@```#;*```9````2<H``!8```!CR@``(@```'K*```-````
MG<H```<```"KR@``%````+/*```+````R,H``"(```#4R@``+P```/?*```+
M````)\L```D````SRP``&0```#W+```+````5\L``!<```!CRP``%P```'O+
M```)````D\L``!8```"=RP``#P```+3+```9````Q,L``!8```#>RP``#@``
M`/7+```8````!,P```@````=S```#0```";,```F````-,P``$,```!;S```
M"````)_,```2````J,P``!\```"[S```"````-O,```+````Y,P``"\```#P
MS```#@```"#-```%````+\T```8````US0``10```#S-```#````@LT```<`
M``"&S0``!````([-```*````D\T```H```">S0``#P```*G-```0````N<T`
M`!<```#*S0``$0```.+-```9````],T``!<````.S@``"0```";.```%````
M,,X```L````VS@``"@```$+.```"````3<X```4```!0S@``#0```%;.```;
M````9,X``!<```"`S@``%````)C.```)````K<X```X```"WS@``#0```,;.
M```2````U,X``#@```#GS@``(````"#/```(````0<\```X```!*SP``>P``
M`%G/```8````U<\``!@```#NSP``$0````?0```'````&=````4````AT```
M&````"?0```>````0-```!L```!?T```&0```'O0```;````E=```!D```"Q
MT```$P```,O0```'````W]````@```#GT```!@```/#0```&````]]```!``
M``#^T```#P````_1```0````']$```\````PT0``"P```$#1```/````3-$`
M``P```!<T0``#P```&G1```'````>=$```8```"!T0``#@```(C1```,````
ME]$``"@```"DT0``#P```,W1```(````W=$```@```#FT0``$P```._1```>
M`````](``"$````BT@``(````$32```9````9=(``!<```!_T@``)0```)?2
M```7````O=(``!8```#5T@``!````.S2```;````\=(```T````-TP``#```
M`!O3```#````*-,```4````LTP``"````#+3```*````.],```P```!&TP``
M"P```%/3```0````7],```P```!PTP``#@```'W3```+````C-,```0```"8
MTP``!````)W3```3````HM,``!0```"VTP``#````,O3```)````V-,```X`
M``#BTP``"P```/'3```;````_=,```<````9U```!P```"'4```*````*=0`
M``T````TU```"0```$+4```$````3-0```4```!1U````P```%?4```8````
M6]0```H```!TU```!````'_4```F````A-0```X```"KU```?````+K4```5
M````-]4```4```!-U0``!P```%/5```,````6]4```@```!HU0``"@```''5
M```&````?-4```@```"#U0```@```(S5```&````C]4```8```"6U0``%```
M`)W5```-````LM4``!````#`U0``&P```-'5```$````[=4```D```#RU0``
M$````/S5```)````#=8```D````7U@``!0```"'6```:````)]8```@```!"
MU@``!@```$O6```9````4M8```X```!LU@``!P```'O6```'````@]8```4`
M``"+U@``"0```)'6```*````F]8```X```"FU@```@```+76```&````N-8`
M``L```"_U@``#0```,O6```)````V=8```8```#CU@``$@```.K6```)````
M_=8```<````'UP``%`````_7```=````)-<``$(```!"UP``)0```(77```E
M````J]<```8```#1UP``"@```-C7```$````X]<```D```#HUP``"````/+7
M```1````^]<```D````-V```!@```!?8```-````'M@```8````LV```!```
M`#/8```Y````.-@``#T```!RV```.@```+#8```>````Z]@```4````*V0``
M#@```!#9```$````']D```8````DV0``!P```"O9```A````,]D```T```!5
MV0``%0```&/9```&````>=D```0```"`V0``$0```(79```&````E]D```H`
M``">V0``(@```*G9```$````S-D```4```#1V0``'0```-?9```$````]=D`
M``P```#ZV0``#@````?:```*````%MH```@````AV@``"0```"K:```%````
M--H``#H````ZV@``,````'7:```U````IMH``"D```#<V@``1P````;;```X
M````3ML``"D```"'VP``/P```+';```N````\=L``"T````@W```'P```$[<
M```/````;MP``!(```!^W```"P```)'<```F````G=P``"D```#$W```)```
M`.[<```F````$]T```@````ZW0``"@```$/=```)````3MT```<```!8W0``
M(````&#=```@````@=T``"8```"BW0``"@```,G=```9````U-T``"D```#N
MW0``%@```!C>```2````+]X```<```!"W@``"@```$K>```,````5=X```\`
M``!BW@``$````'+>``!`````@]X``'````#$W@``9@```#7?```.````G-\`
M``D```"KWP``"@```+7?```2````P-\``!,```#3WP``#````.??```&````
M]-\```\```#[WP``$@````O@```0````'N```!$````OX```'````$'@```C
M````7N```&H```""X```#P```.W@```%````_>```!`````#X0``"0```!3A
M```$````'N$```L````CX0``(````"_A```4````4.$```P```!EX0``#```
M`'+A```/````?^$``!4```"/X0``*0```*7A```J````S^$``"8```#ZX0``
M)P```"'B```I````2>(``"H```!SX@``&0```)[B``!"````N.(``!$```#[
MX@``$@````WC```3````(.,``!0````TXP``#P```$GC```6````6>,``!<`
M``!PXP``$````(CC```1````F>,``#0```"KXP``$P```.#C```2````].,`
M`#4````'Y```%````#WD```'````4N0```P```!:Y```(````&?D```0````
MB.0``!0```"9Y```$0```*[D```7````P.0``!P```#8Y```$P```/7D```4
M````">4``!H````>Y0``$0```#GE```:````2^4``!X```!FY0``&@```(7E
M```3````H.4``!4```"TY0``$0```,KE```7````W.4``!0```#TY0``%P``
M``GF```5````(>8```D````WY@``$````$'F```9````4N8```0```!LY@``
M!P```''F```+````>>8``!$```"%Y@``!@```)?F```&````GN8```8```"E
MY@``!0```*SF```'````LN8```<```"ZY@``!0```,+F```6````R.8```8`
M``#?Y@``!@```.;F```$````[>8```0```#RY@``!P```/?F```.````_^8`
M``P````.YP``#````!OG```-````*.<```H````VYP``#@```$'G```%````
M4.<``"@```!6YP``#@```'_G```,````CN<```\```";YP``"@```*OG```(
M````MN<```D```"_YP``*P```,GG```$````]><```@```#ZYP``)@````/H
M```2````*N@```\````]Z```!@```$WH```*````5.@```<```!?Z```"```
M`&?H```@````<.@```D```"1Z```%````)OH```,````L.@```T```"]Z```
M#@```,OH```6````VN@``!$```#QZ```!@````/I```#````"ND```8````.
MZ0``&0```!7I```'````+^D```0````WZ0``"P```#SI```+````2.D```<`
M``!4Z0``!0```%SI```'````8ND``!8```!JZ0``#0```('I```-````C^D`
M``H```"=Z0``$````*CI```/````N>D``!$```#)Z0``%P```-OI```*````
M\^D``!$```#^Z0``"````!#J```$````&>H```\````>Z@``.@```"[J```%
M````:>H```P```!OZ@``'@```'SJ```.````F^H``!````"JZ@``"P```+OJ
M```,````Q^H```D```#4Z@``!P```-[J```*````YNH```D```#QZ@``#@``
M`/OJ```0````"NL``!L````;ZP``&````#?K```:````4.L```H```!KZP``
M"0```';K```*````@.L```P```"+ZP``#P```)CK```(````J.L```8```"Q
MZP``'````+CK```'````U>L```4```#=ZP``"P```./K``!'````[^L```T`
M```W[```"0```$7L```$````3^P```,```!4[```$P```%CL```3````;.P`
M`!,```"`[```"@```)3L```"````G^P```0```"B[```)0```*?L```#````
MS>P```4```#1[```*@```-?L```*`````NT```4````-[0``!````!/M```*
M````&.T```T````C[0``!@```#'M```(````..T```@```!![0``!````$KM
M```%````3^T``&@```!5[0``"0```+[M```,````R.T``!````#5[0``!0``
M`.;M```&````[.T``!L```#S[0``+P````_N```0````/^X```H```!0[@``
M#P```%ON```*````:^X```D```!V[@``$P```(#N```;````E.X``!@```"P
M[@``%P```,GN```?````X>X```X````![P```P```!#O```'````%.\```@`
M```<[P``!P```"7O```*````+>\```L````X[P``!P```$3O``!1````3.\`
M`!````">[P``#````*_O```-````O.\``!H```#*[P``2@```.7O```9````
M,/````8```!*\```&@```%'P```E````;/````8```"2\```!@```)GP```?
M````H/````8```#`\```"0```,?P```8````T?```!<```#J\```*`````+Q
M```&````*_$```T````R\0``(@```$#Q``!7````8_$``!,```"[\0``(P``
M`,_Q```3````\_$```(````'\@``"P````KR```(````%O(```T````?\@``
M"@```"WR```'````./(``!0```!`\@``!@```%7R```(````7/(```X```!E
M\@``!P```'3R```*````?/(```L```"'\@``,@```)/R```'````QO(```P`
M``#.\@``#0```-OR```7````Z?(```P````!\P``"0````[S```)````&/,`
M``H````B\P``!P```"WS```)````-?,```<````_\P``"@```$?S```;````
M4O,```\```!N\P``$@```'[S```*````D?,``!8```"<\P``"0```+/S```0
M````O?,```<```#.\P``$@```-;S```$````Z?,```<```#N\P``!0```/;S
M```%````_/,```L````"]```%`````[T```1````(_0``!H````U]```%@``
M`%#T```4````9_0``!<```!\]```&````)3T```<````K?0``!D```#*]```
M!P```.3T```%````[/0```T```#R]```#`````#U```(````#?4``!<````6
M]0``"P```"[U```,````.O4``!\```!']0``&@```&?U```3````@O4```0`
M``"6]0``"@```)OU```$````IO4```T```"K]0``#````+GU```%````QO4`
M``D```#,]0``!0```-;U```'````W/4```4```#D]0``!````.KU```"````
M[_4``#@```#R]0``+````"OV```2````6/8``"D```!K]@``,@```)7V```*
M````R/8``"P```#3]@``+@````#W```S````+_<``#,```!C]P``.````)?W
M```/````T/<``!@```#@]P``$````/GW```/````"O@``!,````:^```%0``
M`"[X```4````1/@``!(```!9^```%````&SX```5````@?@``"T```"7^```
M+0```,7X```Q````\_@``"X````E^0``+P```%3Y```L````A/D``&(```"Q
M^0``$P```!3Z```-````*/H```@````V^@``%P```#_Z```(````5_H```P`
M``!@^@``*P```&WZ```A````F?H``!H```"[^@``"0```-;Z``!%````X/H`
M`$$````F^P``!````&C[```3````;?L``!0```"!^P``#@```);[```3````
MI?L``!@```"Y^P``!@```-+[```)````V?L```H```#C^P``#P```.[[```0
M````_OL```<````/_```#@```!?\```%````)OP``!L````L_```"````$C\
M```&````4?P``!0```!8_```$0```&W\```.````?_P``#@```"._````@``
M`,?\```&````ROP```X```#1_```!0```.#\```'````YOP```X```#N_```
M!@```/W\```H````!/T```P````M_0``'````#K]```$````5_T``"D```!<
M_0``%P```(;]```?````GOT``%P```"^_0``%````!O^```^````,/X``!\`
M``!O_@``$````(_^```'````H/X```X```"H_@``#````+?^```,````Q/X`
M`!,```#1_@``"@```.7^```=````\/X``!D````._P``!0```"C_```1````
M+O\``!$```!`_P``)````%+_```2````=_\``!4```"*_P``$@```*#_```.
M````L_\``!D```#"_P``"````-S_```)````Y?\```T```#O_P``!P```/W_
M```*````!0`!``<````0``$`#P```!@``0`&````*``!``L````O``$`&@``
M`#L``0`*````5@`!``<```!A``$`"````&D``0`%````<@`!`!\```!X``$`
M!@```)@``0`0````GP`!``@```"P``$`#0```+D``0`(````QP`!`!X```#0
M``$`$@```.\``0`L`````@$!`!H````O`0$`"0```$H!`0`*````5`$!`!4`
M``!?`0$`!0```'4!`0`4````>P$!``0```"0`0$`$````)4!`0`&````I@$!
M``<```"M`0$`'@```+4!`0`H````U`$!``H```#]`0$`'`````@"`0`1````
M)0(!``L````W`@$`&@```$,"`0`4````7@(!``0```!S`@$`!````'@"`0`+
M````?0(!``4```")`@$`!@```(\"`0`(````E@(!``8```"?`@$`"@```*8"
M`0`;````L0(!`#0```#-`@$`-`````(#`0`@````-P,!`"D```!8`P$`(```
M`((#`0!!````HP,!`!H```#E`P$`*``````$`0`I````*00!`%````!3!`$`
M(@```*0$`0`&````QP0!``@```#.!`$`!0```-<$`0`(````W00!`!D```#F
M!`$`&0`````%`0`J````&@4!`",```!%!0$`&0```&D%`0`N````@P4!`#0`
M``"R!0$`"````.<%`0`7````\`4!``H````(!@$`!P```!,&`0`A````&P8!
M`!`````]!@$`#@```$X&`0`+````708!``<```!I!@$`$P```'$&`0`(````
MA08!``L```".!@$`"@```)H&`0`4````I08!``\```"Z!@$`,@```,H&`0`+
M````_08!``X````)!P$`!0```!@'`0`%````'@<!``4````D!P$`%P```"H'
M`0`/````0@<!``0```!2!P$`"@```%<'`0`)````8@<!``L```!L!P$`#0``
M`'@'`0`,````A@<!``X```"3!P$`!0```*('`0`$````J`<!``T```"M!P$`
M,@```+L'`0!%````[@<!`!<````T"`$`!P```$P(`0`>````5`@!`!0```!S
M"`$`!0```(@(`0`4````C@@!``8```"C"`$`!P```*H(`0`.````L@@!`"H`
M``#!"`$`!@```.P(`0`,````\P@!``T`````"0$`$0````X)`0`+````(`D!
M`#8````L"0$`"@```&,)`0`B````;@D!``L```"1"0$`#P```)T)`0`R````
MK0D!`"4```#@"0$`,`````8*`0`Q````-PH!`"T```!I"@$`#@```)<*`0`%
M````I@H!``X```"L"@$`$P```+L*`0`2````SPH!``<```#B"@$`$0```.H*
M`0`3````_`H!``<````0"P$`%````!@+`0`8````+0L!``<```!&"P$`!0``
M`$X+`0`,````5`L!``P```!A"P$`$@```&X+`0`$````@0L!``<```"&"P$`
M"@```(X+`0`+````F0L!``P```"E"P$`#@```+(+`0`.````P0L!``4```#0
M"P$`!0```-8+`0`N````W`L!`"8````+#`$`(P```#(,`0`#````5@P!`!(`
M``!:#`$`!@```&T,`0`>````=`P!`!@```"3#`$`)0```*P,`0`-````T@P!
M``D```#@#`$`'P```.H,`0`#````"@T!``<````.#0$`"@```!8-`0`"````
M(0T!``P````D#0$`%0```#$-`0`+````1PT!`!D```!3#0$`(````&T-`0`2
M````C@T!``4```"A#0$`"@```*<-`0`5````L@T!`!(```#(#0$`#````-L-
M`0`$````Z`T!``D```#M#0$`!P```/<-`0`,````_PT!`%(````,#@$`%P``
M`%\.`0`D````=PX!`!(```"<#@$`!P```*\.`0`&````MPX!``X```"^#@$`
M#````,T.`0`-````V@X!`!4```#H#@$`$@```/X.`0`/````$0\!`!0````A
M#P$`"@```#8/`0`;````00\!`!````!=#P$`"P```&X/`0!I````>@\!`!H`
M``#D#P$`%P```/\/`0`G````%Q`!`!H````_$`$`%P```%H0`0`;````<A`!
M`!D```".$`$`'P```*@0`0`3````R!`!``@```#<$`$`!P```.40`0`(````
M[1`!``D```#V$`$`%0`````1`0`-````%A$!`",````D$0$`#0```$@1`0`3
M````5A$!``@```!J$0$``P```',1`0!&````=Q$!`#\```"^$0$`-P```/X1
M`0!7````-A(!``4```".$@$`'P```)02`0`O````M!(!``H```#D$@$`"```
M`.\2`0`-````^!(!`"T````&$P$`!````#03`0!/````.1,!`"4```")$P$`
M'````*\3`0`+````S!,!`!\```#8$P$`'0```/@3`0`E````%A0!`"`````\
M%`$`)````%T4`0`@````@A0!``L```"C%`$`!P```*\4`0`-````MQ0!``P`
M``#%%`$`%P```-(4`0`&````ZA0!`#D```#Q%`$`#````"L5`0`'````.!4!
M``D```!`%0$`$P```$H5`0`)````7A4!``0```!H%0$`$````&T5`0`(````
M?A4!``@```"'%0$`!````)`5`0`+````E14!``P```"A%0$`$@```*X5`0`1
M````P14!``P```#3%0$`&@```.`5`0`/````^Q4!``<````+%@$`#0```!,6
M`0`4````(18!``X````V%@$`#````$46`0`;````4A8!`"P```!N%@$`$P``
M`)L6`0`<````KQ8!`"@```#,%@$`!@```/46`0`'````_!8!`!,````$%P$`
M!0```!@7`0`$````'A<!`!<````C%P$`"@```#L7`0`,````1A<!``D```!3
M%P$`!@```%T7`0`)````9!<!``@```!N%P$`"0```'<7`0`*````@1<!`!$`
M``",%P$`!@```)X7`0`.````I1<!``X```"T%P$`#0```,,7`0`+````T1<!
M`!T```#=%P$`"P```/L7`0`"````!Q@!`!P````*&`$`!P```"<8`0`&````
M+Q@!`&0````V&`$`"0```)L8`0`'````I1@!`"8```"M&`$`.````-08`0`:
M````#1D!`"H````H&0$`.P```%,9`0`H````CQD!`#0```"X&0$`&0```.T9
M`0`5````!QH!``4````=&@$`!P```",:`0`(````*QH!``<````T&@$`!0``
M`#P:`0`'````0AH!``X```!*&@$`"0```%D:`0`&````8QH!``@```!J&@$`
M"P```',:`0`'````?QH!``@```"'&@$`!P```)`:`0`6````F!H!``D```"O
M&@$`!@```+D:`0`+````P!H!`!````#,&@$`!@```-T:`0`<````Y!H!`!0`
M```!&P$`!P```!8;`0`1````'AL!``@````P&P$`#@```#D;`0`(````2!L!
M``4```!1&P$`$````%<;`0`)````:!L!`!````!R&P$`!@```(,;`0`9````
MBAL!``H```"D&P$`'````*\;`0`'````S!L!``4```#4&P$`$````-H;`0`4
M````ZQL!``L`````'`$`#0````P<`0`H````&AP!`!@```!#'`$`%P```%P<
M`0`$````=!P!``D```!Y'`$`"@```(,<`0`'````CAP!``(```"6'`$`#@``
M`)D<`0`(````J!P!`",```"Q'`$`'P```-4<`0`X````]1P!`"8````N'0$`
M,0```%4=`0`G````AQT!`&0```"O'0$`%````!0>`0!5````*1X!`#@```!_
M'@$`2@```+@>`0!;`````Q\!`"@```!?'P$`.````(@?`0`H````P1\!`"P`
M``#J'P$`)@```!<@`0`;````/B`!`#X```!:(`$`J0$``)D@`0`C````0R(!
M`!<```!G(@$`2````'\B`0"%````R"(!`#````!.(P$`)0```'\C`0!!````
MI2,!`%L```#G(P$`20```$,D`0`Q````C20!`!T```"_)`$`&````-TD`0`K
M````]B0!`"$````B)0$`'P```$0E`0`K````9"4!`"8```"0)0$`(0```+<E
M`0`G````V24!`#H````!)@$`'0```#PF`0`1````6B8!`#,```!L)@$`)0``
M`*`F`0`G````QB8!`"````#N)@$`'P````\G`0`P````+R<!`&D```!@)P$`
M,0```,HG`0!!````_"<!`#,````^*`$`)0```'(H`0`]````F"@!`&4```#6
M*`$`30```#PI`0`O````BBD!`"X```"Z*0$`,````.DI`0!4````&BH!`%H`
M``!O*@$`2````,HJ`0!*````$RL!`#(```!>*P$`+P```)$K`0`L````P2L!
M`"T```#N*P$`<0```!PL`0!F````CBP!`&\```#U+`$`LP```&4M`0`7````
M&2X!`"4````Q+@$`,@```%<N`0`I````BBX!`#X```"T+@$`(@```/,N`0!2
M````%B\!`"4```!I+P$`"P```(\O`0"Q````FR\!`$4```!-,`$`(0```),P
M`0`P````M3`!`"4```#F,`$`'`````PQ`0`Q````*3$!``<```!;,0$`!P``
M`&,Q`0`$````:S$!``T```!P,0$`"P```'XQ`0`.````BC$!``L```"9,0$`
M!0```*4Q`0`0````JS$!``(```"\,0$`60```+\Q`0`%````&3(!`!(````?
M,@$`!````#(R`0`'````-S(!``@````_,@$`!0```$@R`0`P````3C(!``,`
M``!_,@$`$````(,R`0`,````E#(!`!,```"A,@$`#0```+4R`0`"````PS(!
M``<```#&,@$`!@```,XR`0`4````U3(!``P```#J,@$`&````/<R`0`&````
M$#,!`!(````7,P$`#````"HS`0`#````-S,!`"H````[,P$`!````&8S`0`&
M````:S,!``<```!R,P$`'P```'HS`0`U````FC,!`"X```#0,P$`+P```/\S
M`0`7````+S0!`"(```!'-`$`)0```&HT`0`@````D#0!`!L```"Q-`$`&```
M`,TT`0`D````YC0!`!\````+-0$`&@```"LU`0`A````1C4!`"````!H-0$`
M&@```(DU`0`R````I#4!`!H```#7-0$`+P```/(U`0`K````(C8!`!\```!.
M-@$`(P```&XV`0`?````DC8!`!H```"R-@$`(0```,TV`0`E````[S8!`"8`
M```5-P$`)0```#PW`0`D````8C<!`!@```"'-P$`'0```*`W`0`D````OC<!
M`!@```#C-P$`(@```/PW`0`L````'S@!`"\```!,.`$`%0```'PX`0`E````
MDC@!`#P```"X.`$`'P```/4X`0`C````%3D!`!\````Y.0$`(````%DY`0`:
M````>CD!`!@```"5.0$`)@```*XY`0`>````U3D!`"D```#T.0$`'@```!XZ
M`0`Q````/3H!``D```!O.@$`#````'DZ`0`7````ACH!`"\```">.@$`)```
M`,XZ`0`'````\SH!``\```#[.@$`%`````L[`0`.````(#L!``T````O.P$`
M)````#T[`0`%````8CL!``<```!H.P$`(@```'`[`0`E````DSL!`!H```"Y
M.P$`'0```-0[`0`:````\CL!``<````-/`$`QP```!4\`0`+````W3P!`!4`
M``#I/`$`!@```/\\`0`)````!CT!``L````0/0$`#0```!P]`0`7````*CT!
M``8```!"/0$`,P```$D]`0`3````?3T!`!,```"1/0$`!P```*4]`0`/````
MK3T!``<```"]/0$`,@```,4]`0`$````^#T!`"$```#]/0$`$P```!\^`0`,
M````,SX!`!$```!`/@$`,@```%(^`0`6````A3X!``@```"</@$`'0```*4^
M`0`)````PSX!``H```#-/@$`%````-@^`0`*````[3X!`!T```#X/@$`"```
M`!8_`0`?````'S\!``@````_/P$`&@```$@_`0`G````8S\!``8```"+/P$`
M%0```)(_`0`'````J#\!``@```"P/P$`"0```+D_`0`_````PS\!``<````#
M0`$`#P````M``0`.````&T`!`!`````J0`$`"0```#M``0`)````14`!``@`
M``!/0`$`$P```%A``0`'````;$`!`!D```!T0`$`"@```(Y``0`7````F4`!
M`!0```"Q0`$`"@```,9``0`,````T4`!`!<```#>0`$`!````/9``0`J````
M^T`!``P````F00$`$0```#-!`0`'````14$!``(```!-00$`$````%!!`0`8
M````84$!``L```!Z00$``P```(9!`0`(````BD$!``8```"300$`!P```)I!
M`0`-````HD$!``L```"P00$`%````+Q!`0`5````T4$!``X```#G00$`+P``
M`/9!`0`@````)D(!`!P```!'0@$`%0```&1"`0`,````>D(!`#$```"'0@$`
M!0```+E"`0`2````OT(!`#\```#20@$`$@```!)#`0`*````)4,!``8````P
M0P$`!````#=#`0`$````/$,!``H```!!0P$`$P```$Q#`0`%````8$,!``8`
M``!F0P$`!@```&U#`0`(````=$,!``0```!]0P$`#````()#`0`*````CT,!
M`#D```":0P$`+@```-1#`0`I`````T0!``4````M1`$`&````#-$`0`9````
M3$0!`!\```!F1`$`'0```(9$`0`1````I$0!``(```"V1`$`!````+E$`0`*
M````OD0!``8```#)1`$`!0```-!$`0`#````UD0!``P```#:1`$`10```.=$
M`0`R````+44!`!H```!@10$`-````'M%`0`H````L$4!`%,```#910$`&0``
M`"U&`0!R````1T8!`"````"Z1@$`-0```-M&`0`A````$4<!`$4````S1P$`
M,````'E'`0`H````JD<!`"D```#31P$`)@```/U'`0`E````)$@!`"@```!*
M2`$`*````'-(`0`B````G$@!`"L```"_2`$`,````.M(`0`2````'$D!`!,`
M```O20$`$````$-)`0!Y````5$D!``D```#.20$`H0```-A)`0!S````>DH!
M`'P```#N2@$`*P```&M+`0!4````ETL!`!<```#L2P$`)P````1,`0`6````
M+$P!``\```!#3`$`%P```%-,`0`?````:TP!`$````"+3`$`'P```,Q,`0`<
M````[$P!`%$````)30$`&@```%M-`0`4````=DT!``H```"+30$`!0```)9-
M`0`&````G$T!``@```"C30$`!0```*Q-`0`2````LDT!`!````#%30$`$P``
M`-9-`0`=````ZDT!``\````(3@$`#P```!A.`0`$````*$X!``D````M3@$`
M"P```#=.`0`'````0TX!``4```!+3@$`%````%%.`0`'````9DX!``@```!N
M3@$`#P```'=.`0`(````ATX!``P```"03@$`#P```)U.`0`&````K4X!`!0`
M``"T3@$`!@```,E.`0`,````T$X!`!$```#=3@$`"````.].`0`$````^$X!
M`!D```#]3@$`$0```!=/`0`*````*4\!`!@````T3P$`$P```$U/`0`<````
M84\!`!$```!^3P$`!````)!/`0`/````E4\!``<```"E3P$`!````*U/`0`9
M````LD\!``<```#,3P$``@```-1/`0`"````UT\!`!$```#:3P$`"0```.Q/
M`0`&````]D\!`!(```#]3P$`%P```!!0`0`&````*%`!`"<````O4`$``@``
M`%=0`0`$````6E`!``\```!?4`$`$P```&]0`0`'````@U`!``<```"+4`$`
M$0```)-0`0`&````I5`!`!@```"L4`$`!@```,50`0`3````S%`!`!````#@
M4`$`$@```/%0`0`"````!%$!``8````'40$`#`````Y1`0`)````&U$!`!$`
M```E40$`(@```#=1`0`'````6E$!``<```!B40$`"P```&I1`0`%````=E$!
M``(```!\40$`"P```']1`0"4`0``BU$!`!`````@4P$`#P```#%3`0`-````
M05,!``@```!/4P$`"P```%A3`0`(````9%,!``4```!M4P$`&````'-3`0`;
M````C%,!`"\```"H4P$`'@```-A3`0`E````]U,!`"@````=5`$`&@```$94
M`0`J````850!``L```",5`$`(````)A4`0`.````N50!``L```#(5`$`#P``
M`-14`0`%````Y%0!`"````#J5`$`#`````M5`0`.````&%4!`!,````G50$`
M%P```#M5`0`,````4U4!`(H```!@50$`"0```.M5`0`+````]54!``\````!
M5@$`#P```!%6`0`3````(58!``P````U5@$`#0```$)6`0`+````4%8!``8`
M``!<5@$`J@```&-6`0`(````#E<!`!`````75P$`&@```"A7`0`*````0U<!
M`!````!.5P$`$````%]7`0`(````<%<!``\```!Y5P$`+0```(E7`0`A````
MMU<!`#L```#95P$`1@```!58`0!;````7%@!`%D```"X6`$`8@```!)9`0!>
M````=5D!`#X```#460$`#P```!-:`0`2````(UH!``X````V6@$`#P```$5:
M`0`2````55H!``4```!H6@$`!@```&Y:`0`1````=5H!``4```"'6@$`"0``
M`(U:`0`)````EUH!`"H```"A6@$`)@```,Q:`0`1````\UH!`!`````%6P$`
M$@```!9;`0`*````*5L!``8````T6P$`$@```#M;`0`>````3EL!``L```!M
M6P$`$````'E;`0`3````BEL!`!L```">6P$`(0```+I;`0`5````W%L!``X`
M``#R6P$`%`````%<`0`)````%EP!`"<````@7`$`&P```$A<`0`>````9%P!
M``P```"#7`$`6@```)!<`0`P````ZUP!`"(````<70$`!P```#]=`0`/````
M1UT!`#,```!770$`#@```(M=`0`(````FET!``L```"C70$`"````*]=`0`(
M````N%T!``D```#!70$`"@```,M=`0`*````UET!``0```#A70$`$P```.9=
M`0`,````^ET!`!`````'7@$`#P```!A>`0`8````*%X!`"4```!!7@$`$P``
M`&=>`0`5````>UX!`!<```"17@$`&@```*E>`0`2````Q%X!`!8```#77@$`
M$0```.Y>`0`0`````%\!`"T````17P$`'@```#]?`0`'````7E\!``8```!F
M7P$`"````&U?`0`4````=E\!``8```"+7P$`"````))?`0`3````FU\!``L`
M``"O7P$`$0```+M?`0`5````S5\!`!,```#C7P$`!P```/=?`0`.````_U\!
M``4````.8`$`%@```!1@`0`2````*V`!``D````^8`$`0@```$A@`0!`````
MBV`!``D```#,8`$`"````-9@`0`3````WV`!``4```#S8`$`!0```/E@`0`,
M````_V`!``D````,80$`&0```!9A`0!$````,&$!``\```!U80$`,````(5A
M`0`T````MF$!`#,```#K80$`+P```!]B`0`+````3V(!``8```!;8@$`"@``
M`&)B`0`&````;6(!`#````!T8@$`,0```*5B`0`O````UV(!`%$````'8P$`
M+@```%EC`0`N````B&,!`$<```"W8P$`2````/]C`0`N````2&0!`#D```!W
M9`$`)````+%D`0`F````UF0!`$L```#]9`$`+@```$EE`0`T````>&4!`"``
M``"M90$`#P```,YE`0`3````WF4!`"````#R90$`(P```!-F`0`C````-V8!
M`!0```!;9@$`"P```'!F`0`3````?&8!``H```"09@$`#@```)MF`0`9````
MJF8!`!P```#$9@$`!@```.%F`0`'````Z&8!`!8```#P9@$`"@````=G`0`(
M````$F<!`"4````;9P$`"@```$%G`0`,````3&<!``<```!99P$`!@```&%G
M`0`%````:&<!``<```!N9P$`!@```'9G`0`*````?6<!`"H```"(9P$`#P``
M`+-G`0`(````PV<!``,```#,9P$`"````-!G`0`)````V6<!``0```#C9P$`
M#@```.AG`0`%````]V<!`!8```#]9P$`!0```!1H`0`(````&F@!``0````C
M:`$`"0```"AH`0`)````,F@!`!H````\:`$`$0```%=H`0`)````:6@!``H`
M``!S:`$`#````'YH`0`'````BV@!``,```"3:`$``P```)=H`0`7````FV@!
M`!,```"S:`$`-@```,=H`0`(````_F@!``H````':0$`"````!)I`0`(````
M&VD!`$$````D:0$`'````&9I`0`K````@VD!`"4```"O:0$`%P```-5I`0`&
M````[6D!``@```#T:0$`'0```/UI`0`9````&VH!`"<````U:@$`,````%UJ
M`0`=````CFH!`"0```"L:@$`90```-%J`0`L````-VL!``D```!D:P$`"P``
M`&YK`0`'````>FL!`!0```"":P$`"P```)=K`0`%````HVL!`!````"I:P$`
M#0```+IK`0`0````R&L!`!````#9:P$`#````.IK`0`5````]VL!``<````-
M;`$`'@```!5L`0`>````-&P!`!,```!3;`$`#P```&=L`0`5````=VP!``4`
M``"-;`$`!0```)-L`0`1````F6P!`%\```"K;`$`7`````MM`0`$````:&T!
M``X```!M;0$`!0```'QM`0`$````@FT!`!\```"';0$`'````*=M`0`1````
MQ&T!``\```#6;0$`$@```.9M`0`?````^6T!`"0````9;@$`!P```#YN`0`C
M````1FX!``4```!J;@$`&P```'!N`0`4````C&X!`!(```"A;@$`#@```+1N
M`0`2````PVX!``T```#6;@$`%0```.1N`0`3````^FX!``H````.;P$`!0``
M`!EO`0`-````'V\!``4````M;P$`%0```#-O`0`5````26\!`!,```!?;P$`
M"0```'-O`0`%````?6\!``L```"#;P$`"0```(]O`0`%````F6\!``T```"?
M;P$`"P```*UO`0`(````N6\!``T```#";P$`"0```-!O`0`+````VF\!``D`
M``#F;P$`!0```/!O`0`)````]F\!``<`````<`$`"P````AP`0`7````%'`!
M`$,````L<`$`'````'!P`0`-````C7`!``\```";<`$`!0```*MP`0`@````
ML7`!`!@```#2<`$`&0```.MP`0`M````!7$!`#P````S<0$`)P```'!Q`0`)
M````F'$!`#$```"B<0$`(0```-1Q`0`/````]G$!``<````&<@$`#`````YR
M`0`'````&W(!``8````C<@$`&0```"IR`0`0````1'(!``@```!5<@$`"@``
M`%YR`0`/````:7(!`"````!Y<@$`'P```)IR`0`B````NG(!`"$```#=<@$`
M'@```/]R`0`A````'G,!`"$```!`<P$`)````&)S`0`W````AW,!`"D```"_
M<P$`(````.ES`0`B````"G0!`!T````M=`$`*````$MT`0!$````='0!`"\`
M``"Y=`$`)@```.ET`0`I````$'4!`$(````Z=0$`'P```'UU`0`6````G74!
M`#$```"T=0$`(P```.9U`0`3````"G8!`"P````>=@$`'0```$MV`0`<````
M:78!`!,```"&=@$`LP```)IV`0`4````3G<!`"8```!C=P$`)P```(IW`0`H
M````LG<!`!X```#;=P$`(@```/IW`0`6````'7@!`"$````T>`$`*0```%9X
M`0`L````@'@!`#\```"M>`$`+P```.UX`0">````'7D!`!X```"\>0$`(```
M`-MY`0`?````_'D!`"H````<>@$`+````$=Z`0!%````='H!`$0```"Z>@$`
M#````/]Z`0`$````#'L!``8````1>P$`!0```!A[`0`3````'GL!``L````R
M>P$`$````#Y[`0`3````3WL!`!$```!C>P$`"````'5[`0`$````?GL!`!$`
M``"#>P$`$P```)5[`0`*````J7L!`!````"T>P$`$0```,5[`0`,````UWL!
M`!````#D>P$`"P```/5[`0`Z`````7P!``0````\?`$`"0```$%\`0`&````
M2WP!`!(```!2?`$`&````&5\`0`;````?GP!``@```":?`$``@```*-\`0!)
M````IGP!``8```#P?`$`$@```/=\`0`/````"GT!``0````:?0$`#P```!]]
M`0`(````+WT!``,````X?0$`#````#Q]`0`(````27T!``H```!2?0$`$0``
M`%U]`0`(````;WT!``T```!X?0$`$@```(9]`0`-````F7T!``P```"G?0$`
M!````+1]`0`*````N7T!``L```#$?0$`"P```-!]`0`0````W'T!`!@```#M
M?0$`"@````9^`0`,````$7X!`"<````>?@$`#0```$9^`0`9````5'X!`#L`
M``!N?@$`"@```*I^`0`5````M7X!`!````#+?@$`&0```-Q^`0`7````]GX!
M`"`````.?P$`$@```"]_`0`'````0G\!`!$```!*?P$`"P```%Q_`0`A````
M:'\!`#\```"*?P$`"0```,I_`0`(````U'\!`!H```#=?P$`"@```/A_`0`9
M`````X`!`!D````=@`$`!P```#>``0`5````/X`!`!D```!5@`$`&````&^`
M`0`4````B(`!``X```"=@`$`$P```*R``0`(````P(`!`!````#)@`$`*```
M`-J``0!"`````X$!`!D```!&@0$`&0```&"!`0`F````>H$!``0```"A@0$`
M!P```*:!`0`P````KH$!`!$```#?@0$`#````/&!`0`&````_H$!`$@````%
M@@$``P```$Z"`0`'````4H(!``<```!:@@$`"@```&*"`0`,````;8(!`!``
M``!Z@@$`$0```(N"`0`8````G8(!``\```"V@@$`&@```,:"`0`8````X8(!
M``H```#Z@@$`!P````6#`0`+````#8,!``H````9@P$``@```"2#`0`%````
M)X,!``X````M@P$`&P```#R#`0`6````6(,!`!0```!O@P$`!P```(2#`0`+
M````C(,!``\```"8@P$`"P```*B#`0`Z````M(,!`"````#O@P$`!P```!"$
M`0`9````&(0!`(,````RA`$`&@```+:$`0`;````T80!`!$```#MA`$`!P``
M`/^$`0`$````!X4!`!T````,A0$`)0```"J%`0`C````4(4!`"(```!TA0$`
M)````)>%`0`A````O(4!`!T```#>A0$`!P```/R%`0`(````!(8!``8````-
MA@$`!@```!2&`0`,````&X8!``X````HA@$`$````#>&`0`-````2(8!``\`
M``!6A@$`#P```&:&`0`*````=H8!`!````"!A@$`!0```)*&`0`%````F(8!
M`!$```">A@$`#@```+"&`0`J````OX8!``\```#JA@$`"0```/J&`0`(````
M!(<!`!@````-AP$`(0```":'`0`L````2(<!`",```!UAP$`'@```)F'`0`<
M````N(<!`"@```#5AP$`&P```/Z'`0`4````&H@!``4````OB`$`&0```#6(
M`0`(````3X@!``T```!8B`$``P```&:(`0`*````:H@!``<```!UB`$`!0``
M`'V(`0`'````@X@!``@```"+B`$`"P```)2(`0`+````H(@!``X```"LB`$`
M%P```+N(`0`$````TX@!``,```#8B`$`$P```-R(`0`5````\(@!``T````&
MB0$`!P```!2)`0`'````'(D!``H````DB0$`'0```"^)`0`&````38D!``<`
M``!4B0$`#@```%R)`0`.````:XD!`!@```!ZB0$`!````).)`0`(````F(D!
M``0```"AB0$`&````*:)`0`.````OXD!``,```#.B0$`,0```-*)`0`0````
M!(H!`(`````5B@$`$@```):*`0`*````J8H!``@```"TB@$`"P```+V*`0`*
M````R8H!``P```#4B@$`!````.&*`0`.````YHH!``,```#UB@$`!@```/F*
M`0`(`````(L!`!8````)BP$`#0```""+`0`1````+HL!`!L```!`BP$``P``
M`%R+`0`#````8(L!`!````!DBP$`"````'6+`0`*````?HL!``4```")BP$`
M)@```(^+`0`(````MHL!``8```"_BP$`&````,:+`0`.````WXL!``@```#N
MBP$`"````/>+`0`%`````(P!``D````&C`$`!P```!",`0`;````&(P!``4`
M```TC`$`!0```#J,`0`+````0(P!``X```!,C`$`"````%N,`0`*````9(P!
M`!(```!OC`$`"````(*,`0`'````BXP!`!4```"3C`$`'@```*F,`0`Y````
MR(P!`"4````"C0$`)P```"B-`0`'````4(T!``H```!8C0$`!````&.-`0`)
M````:(T!``@```!RC0$`$````'N-`0`(````C(T!``8```"5C0$`#0```)R-
M`0`&````JHT!``0```"QC0$`/@```+:-`0!`````]8T!`#X````VC@$`&0``
M`'6.`0`%````CXX!``X```"5C@$``P```*2.`0`(````J(X!``P```"QC@$`
M(0```+Z.`0`.````X(X!`!<```#OC@$`!0````>/`0`%````#8\!`!P````3
MCP$`!P```#"/`0`)````.(\!`!@```!"CP$``P```%N/`0`$````7X\!`!@`
M``!DCP$`!````'V/`0`.````@H\!``T```"1CP$`#@```)^/`0`(````KH\!
M``D```"WCP$`!0```,&/`0`V````QX\!`"X```#^CP$`-P```"V0`0`=````
M99`!`$````"#D`$`-0```,20`0`H````^I`!`#L````CD0$`+@```%^1`0`O
M````CI$!`!\```"^D0$`#0```-Z1`0`+````[)$!``@```#XD0$`-P````&2
M`0`M````.9(!`"0```!GD@$`*P```(R2`0`)````N)(!``L```#"D@$`"@``
M`,Z2`0`&````V9(!`"0```#@D@$`(@````63`0`N````*),!``H```!7DP$`
M'0```&*3`0`C````@),!`!8```"DDP$`$````+N3`0`&````S),!``H```#3
MDP$`#0```-Z3`0`0````[),!``\```#]DP$`/P````V4`0!]````390!`&X`
M``#+E`$`%P```#J5`0`*````4I4!``L```!=E0$`$P```&F5`0`4````?94!
M`!````"2E0$`"````*.5`0`4````K)4!`!8```#!E0$`$P```-B5`0`2````
M[)4!`"````#_E0$`)0```""6`0!_````1I8!`!````#&E@$`!@```->6`0`4
M````WI8!``H```#SE@$`!````/Z6`0`+`````Y<!`"0````/EP$`%````#27
M`0`.````29<!``P```!8EP$`%0```&67`0`2````>Y<!`"<```".EP$`)0``
M`+:7`0`E````W)<!`",````"F`$`*P```":8`0`I````4I@!`!H```!\F`$`
M0@```)>8`0`2````VI@!`!````#MF`$`%````/Z8`0`2````$YD!``\````F
MF0$`%0```#:9`0`5````3)D!`!(```!BF0$`$````'69`0`S````AID!`!0`
M``"ZF0$`%P```,^9`0`[````YYD!`!<````CF@$`!@```#N:`0`,````0IH!
M`"````!/F@$`$0```'":`0`5````@IH!`!,```"8F@$`%@```*R:`0`4````
MPYH!`!(```#8F@$`%````.N:`0`:`````)L!`!$````;FP$`'0```"V;`0`C
M````2YL!`!X```!OFP$`$P```(Z;`0`5````HIL!`!$```"XFP$`%@```,J;
M`0`6````X9L!`!L```#XFP$`%0```!2<`0`%````*IP!`!(````PG`$`&P``
M`$.<`0`$````7YP!``8```!DG`$``P```&N<`0`.````;YP!``8```!^G`$`
M"````(6<`0`)````CIP!``<```"8G`$`!P```*"<`0`&````J)P!``4```"O
MG`$`%0```+6<`0`&````RYP!``8```#2G`$`!````-F<`0`$````WIP!``8`
M``#CG`$`!P```.J<`0`-````\IP!``\`````G0$`#0```!"=`0`*````'IT!
M``\````IG0$`!0```#F=`0`Q````/YT!`!8```!QG0$`#@```(B=`0`2````
MEYT!``L```"JG0$`"0```+:=`0`/````P)T!`#@```#0G0$`!`````F>`0`(
M````#IX!``@````7G@$`"0```"">`0`1````*IX!``8````\G@$`"P```$.>
M`0`*````3YX!``4```!:G@$`!````&">`0`.````99X!`!8```!TG@$`#@``
M`(N>`0`0````FIX!`!````"KG@$`'````+R>`0`4````V9X!``<```#NG@$`
M`P```/:>`0`&````^IX!`!0````!GP$`!P```!:?`0`'````'I\!`!`````F
MGP$`#P```#>?`0`&````1Y\!``8```!.GP$`"````%6?`0`&````7I\!``T`
M``!EGP$`"````'.?`0`(````?)\!`!````"%GP$`#0```):?`0`(````I)\!
M`!,```"MGP$`!P```,&?`0`,````R9\!``D```#6GP$`"@```."?`0`4````
MZY\!`#X`````H`$`#````#^@`0`*````3*`!`!P```!7H`$`#@```'2@`0`9
M````@Z`!``T```"=H`$`#0```*N@`0`)````N:`!``<```##H`$`"@```,N@
M`0`)````UJ`!``X```#@H`$`$````.^@`0`@`````*$!`!\````AH0$`(```
M`$&A`0`*````8J$!``<```!MH0$`"0```'6A`0`*````?Z$!`!,```"*H0$`
M!````)ZA`0`'````HZ$!`"D```"KH0$`!@```-6A`0`'````W*$!``T```#D
MH0$`2````/*A`0`3````.Z(!``H```!/H@$`"0```%JB`0`#````9*(!``\`
M``!HH@$`$0```'BB`0`,````BJ(!``D```"7H@$``@```*&B`0`$````I*(!
M`"(```"IH@$``P```,RB`0`%````T*(!`"\```#6H@$`"@````:C`0`$````
M$:,!``8````6HP$`%````!VC`0`1````,J,!``8```!$HP$`"````$NC`0`*
M````5*,!``0```!?HP$`!0```&2C`0!P````:J,!``H```#;HP$`#0```.:C
M`0`1````]*,!``4````&I`$`!@````RD`0`8````$Z0!`"H````LI`$`#0``
M`%>D`0`*````9:0!`!8```!PI`$`"P```(>D`0`)````DZ0!`!,```"=I`$`
M(0```+&D`0`<````TZ0!`!P```#PI`$`'@````VE`0`.````+*4!``,````[
MI0$`!P```#^E`0`'````1Z4!``D```!/I0$`#@```%FE`0`,````:*4!``8`
M``!UI0$`50```'RE`0`/````TJ4!``H```#BI0$`#0```.VE`0`;````^Z4!
M`%0````7I@$`&@```&RF`0`&````AZ8!`!T```".I@$`)0```*RF`0`)````
MTJ8!``8```#<I@$`"P```..F`0`$````[Z8!``D```#TI@$`'````/ZF`0`;
M````&Z<!`"L````WIP$`!@```&.G`0`+````:J<!`"````!VIP$`:````)>G
M`0`2`````*@!`!\````3J`$`$P```#.H`0`#````1Z@!``P```!+J`$`!```
M`%BH`0`,````7:@!``D```!JJ`$`!P```'2H`0`'````?*@!``8```"$J`$`
M"0```(NH`0`+````E:@!``@```"AJ`$`"@```*JH`0`)````M:@!`#4```"_
MJ`$`!P```/6H`0`,````_:@!``H````*J0$`%@```!6I`0`(````+*D!``@`
M```UJ0$`$````#ZI`0`)````3ZD!``<```!9J0$`"````&&I`0`'````:JD!
M``H```!RJ0$`'P```'VI`0`0````G:D!``T```"NJ0$`"0```+RI`0`8````
MQJD!``H```#?J0$`%0```.JI`0`'`````*H!`!4````(J@$`!````!ZJ`0`'
M````(ZH!``4````KJ@$`!0```#&J`0`,````-ZH!`!,```!$J@$`$0```%BJ
M`0`:````:JH!`!8```"%J@$`%````)RJ`0`7````L:H!`!@```#)J@$`'```
M`.*J`0`8````_ZH!``<````8JP$`!@```""K`0`-````)ZL!``L````UJP$`
M!@```$&K`0`9````2*L!``L```!BJP$`"P```&ZK`0`>````>JL!`!@```"9
MJP$`$P```+*K`0`'````QJL!``T```#.JP$`!0```-RK`0`-````XJL!``T`
M``#PJP$`!@```/ZK`0`)````!:P!``4````/K`$`!P```!6L`0`#````':P!
M``0````AK`$``P```":L`0`[````*JP!`#0```!FK`$`%@```)NL`0`Z````
MLJP!`"@```#MK`$`#@```!:M`0`P````):T!`"\```!6K0$`-````(:M`0`T
M````NZT!`#D```#PK0$`#@```"JN`0`?````.:X!``\```!9K@$`$P```&FN
M`0`6````?:X!`!,```"4K@$`%0```*BN`0`3````OJX!`!4```#2K@$`'```
M`.BN`0`P````!:\!`#`````VKP$`-````&>O`0`I````G*\!`"H```#&KP$`
M)@```/&O`0!D````&+`!`!T```!]L`$`%@```)NP`0`-````LK`!`!D```#`
ML`$`"P```-JP`0`/````YK`!`#0```#VL`$`*````"NQ`0`A````5+$!``T`
M``!VL0$`1P```(2Q`0!"````S+$!``4````/L@$`%0```!6R`0`5````*[(!
M``<```!!L@$`$@```$FR`0`3````7+(!``4```!PL@$`#P```':R`0`(````
MAK(!`!(```"/L@$`$P```**R`0`/````MK(!`!(```#&L@$`!0```-FR`0`>
M````W[(!``@```#^L@$``P````>S`0`*````"[,!``X````6LP$`#````"6S
M`0`U````,K,!``(```!HLP$`!@```&NS`0`,````<K,!``4```!_LP$`!P``
M`(6S`0`1````C;,!``8```"?LP$`+0```*:S`0`/````U+,!`"````#DLP$`
M!`````6T`0`N````"K0!`!H````YM`$`'@```%2T`0!?````<[0!`!0```#3
MM`$`/P```.BT`0`E````*+4!``X```!.M0$`#0```%VU`0`4````:[4!``P`
M``"`M0$`#````(VU`0`4````FK4!``P```"OM0$`'P```+RU`0`<````W+4!
M``4```#YM0$`$0```/^U`0`/````$;8!`"$````AM@$`$````$.V`0`4````
M5+8!`!(```!IM@$`$P```'RV`0`;````D+8!``@```"LM@$`"````+6V`0`.
M````OK8!``H```#-M@$`"P```-BV`0`)````Y+8!``X```#NM@$`"0```/VV
M`0`+````![<!`!@````3MP$`"````"RW`0`'````-;<!``@````]MP$`!0``
M`$:W`0`)````3+<!``8```!6MP$`#P```%VW`0`(````;;<!``T```!VMP$`
M!P```(2W`0`/````C+<!``\```"<MP$`(@```*RW`0`7````S[<!``@```#G
MMP$`"0```/"W`0`9````^K<!``8````4N`$`&````!NX`0`#````-+@!`!<`
M```XN`$`!````%"X`0`'````5;@!`!4```!=N`$`(@```'.X`0`+````EK@!
M`!T```"BN`$`$0```,"X`0`+````TK@!`!H```#>N`$`"````/FX`0`$````
M`KD!``<````'N0$`#`````^Y`0`'````'+D!``4````DN0$`"````"JY`0`'
M````,[D!``L````[N0$`#P```$>Y`0`M````5[D!`"X```"%N0$`'@```+2Y
M`0`E````T[D!`!T```#YN0$`.````!>Z`0`@````4+H!`#H```!QN@$`)@``
M`*RZ`0!,````T[H!`!T````@NP$`!0```#Z[`0`'````1+L!``\```!,NP$`
M"````%R[`0`5````9;L!`!@```![NP$`,0```)2[`0`?````QKL!`!(```#F
MNP$`+0```/F[`0`U````)[P!``0```!=O`$`%0```&*\`0`&````>+P!``4`
M``!_O`$`(````(6\`0`/````IKP!`!````"VO`$`#````,>\`0`'````U+P!
M`!(```#<O`$`"0```.^\`0`-````^;P!`!`````'O0$`&0```!B]`0`;````
M,KT!`#$```!.O0$`"P```("]`0`/````C+T!``4```"<O0$`#````**]`0`%
M````K[T!`!P```"UO0$`#@```-*]`0`$````X;T!``P```#FO0$`"0```/.]
M`0`)````_;T!``L````'O@$`!````!.^`0`2````&+X!``<````KO@$``P``
M`#.^`0`,````-[X!`#L```!$O@$`2P```("^`0`9````S+X!``<```#FO@$`
M(0```.Z^`0`9````$+\!``\````JOP$`#@```#J_`0`*````2;\!``4```!4
MOP$`#@```%J_`0`I````:;\!``0```"3OP$`"0```)B_`0`-````HK\!`!``
M``"POP$`"````,&_`0`U````RK\!``4`````P`$`(`````;``0`+````)\`!
M``\````SP`$`-````$/``0`C````>,`!`#````"<P`$`,````,W``0`O````
M_L`!``L````NP0$`!P```#K!`0`/````0L$!`!,```!2P0$`&P```&;!`0`*
M````@L$!`!L```"-P0$`$P```*G!`0`'````O<$!`!0```#%P0$`)@```-K!
M`0`%`````<(!``4````'P@$`#@````W"`0`-````',(!`!,````JP@$`!0``
M`#["`0`(````1,(!``D```!-P@$`#0```%?"`0`+````9<(!`!````!QP@$`
M$````(+"`0`'````D\(!``<```";P@$`+0```*/"`0`G````T<(!`"4```#Y
MP@$`!0```!_#`0`'````)<,!``8````MPP$`'0```#3#`0`6````4L,!`"$`
M``!IPP$``P```(O#`0`-````C\,!`"````"=PP$``P```+[#`0`&````PL,!
M``T```#)PP$``P```-?#`0`+````V\,!`!,```#GPP$`"@```/O#`0`7````
M!L0!`!P````>Q`$`$P```#O$`0`%````3\0!``H```!5Q`$`%````&#$`0`.
M````=<0!``P```"$Q`$``P```)'$`0`(````E<0!``@```">Q`$`$P```*?$
M`0!.````N\0!`!8````*Q0$`-````"'%`0`-````5L4!``D```!DQ0$``P``
M`&[%`0`,````<L4!``H```!_Q0$`#````(K%`0`9````E\4!``\```"QQ0$`
M#@```,'%`0`9````T,4!``D```#JQ0$`&P```/3%`0`.````$,8!``H````?
MQ@$`80```"K&`0`6````C,8!`!````"CQ@$`)0```+3&`0`6````VL8!`!``
M``#QQ@$`*`````+'`0`<````*\<!`!H```!(QP$`%P```&/'`0`(````>\<!
M``<```"$QP$`!P```(S'`0`)````E,<!`!4```">QP$`"P```+3'`0`K````
MP,<!`!4```#LQP$`$P````+(`0`)````%L@!``8````@R`$`7@```"?(`0`^
M````AL@!`#4```#%R`$`8````/O(`0`+````7,D!`#$```!HR0$`)````)K)
M`0`,````O\D!``@```#,R0$`$````-7)`0`\````YLD!``,````CR@$`2```
M`"?*`0`P````<,H!`"8```"AR@$`"P```,C*`0`F````U,H!`!H```#[R@$`
M+P```!;+`0`L````1LL!`"\```!SRP$`+````*/+`0`,````T,L!``4```#=
MRP$`#0```./+`0`*````\<L!`!````#\RP$`!@````W,`0`K````%,P!``P`
M``!`S`$`"0```$W,`0`+````5\P!`!$```!CS`$`"0```'7,`0`)````?\P!
M`!L```")S`$`"0```*7,`0`)````K\P!``,```"YS`$`!P```+W,`0`(````
MQ<P!`!````#.S`$`#0```-_,`0`*````[<P!`!8```#XS`$`#`````_-`0`'
M````',T!``X````DS0$`#@```#/-`0`/````0LT!``D```!2S0$`&0```%S-
M`0`E````=LT!`!$```"<S0$`%@```*[-`0`D````Q<T!`!````#JS0$`"0``
M`/O-`0`/````!<X!``<````5S@$`"0```!W.`0`?````)\X!``D```!'S@$`
M"P```%'.`0`)````7<X!``4```!GS@$`"0```&W.`0`(````=\X!``D```"`
MS@$`#0```(K.`0`5````F,X!``8```"NS@$`#@```+7.`0`#````Q,X!``\`
M``#(S@$`$````-C.`0`9````Z<X!``H````#SP$``P````[/`0`>````$L\!
M``0````QSP$`!P```#;/`0!M````/L\!``H```"LSP$`!@```+?/`0`@````
MOL\!`"\```#?SP$`#0````_0`0`:````'=`!`#L````XT`$`&@```'30`0`@
M````C]`!``\```"PT`$`#0```,#0`0`%````SM`!``<```#4T`$`"0```-S0
M`0`*````YM`!``<```#QT`$`"0```/G0`0`4`````]$!``L````8T0$`"@``
M`"31`0`,````+]$!``P````\T0$`!0```$G1`0`'````3]$!``D```!7T0$`
M%0```&'1`0`)````=]$!``<```"!T0$`!P```(G1`0`0````D=$!``8```"B
MT0$`%0```*G1`0`&````O]$!``8```#&T0$`#@```,W1`0`&````W-$!``X`
M``#CT0$`!P```/+1`0`%````^M$!`!``````T@$`"P```!'2`0`0````'=(!
M``8````NT@$`'0```#72`0`+````4](!``@```!?T@$`!````&C2`0`'````
M;=(!``T```!UT@$`$P```(/2`0`*````E](!``P```"BT@$`*0```*_2`0`:
M````V=(!`!<```#TT@$`!0````S3`0`)````$M,!``\````<TP$`"0```"S3
M`0`#````-M,!``X````ZTP$`"````$G3`0`D````4M,!`!\```!WTP$`-@``
M`)?3`0`A````SM,!`"<```#PTP$`+````!C4`0!Q````1=0!``X```"WU`$`
M60```,;4`0`R````(-4!`%<```!3U0$`4````*O5`0`A````_-4!`#H````>
MU@$`*0```%G6`0`N````@]8!`"<```"RU@$`&P```-K6`0`V````]M8!`,<!
M```MUP$`'````/78`0`1````$MD!`$,````DV0$`EP```&C9`0`X`````-H!
M`"0````YV@$`.0```%[:`0!?````F-H!`%L```#XV@$`*0```%3;`0`9````
M?ML!`!,```"8VP$`+````*S;`0`9````V=L!`!8```#SVP$`*@````K<`0`G
M````-=P!`"(```!=W`$`)@```(#<`0!!````I]P!``\```#IW`$`!P```/G<
M`0`S`````=T!`"0````UW0$`*````%K=`0`@````@]T!`!L```"DW0$`,P``
M`,#=`0!=````]-T!`$````!2W@$`3````)/>`0`[````X-X!`#(````<WP$`
M0P```$_?`0!J````D]\!`$D```#^WP$`,P```$C@`0`]````?.`!`#D```"Z
MX`$`5@```/3@`0!9````2^$!`$4```"EX0$`1@```.OA`0`U````,N(!`#$`
M``!HX@$`+@```)KB`0`R````R>(!`'L```#\X@$`<````'CC`0!Y````Z>,!
M`+X```!CY`$`%0```"+E`0`C````..4!`"L```!<Y0$`*P```(CE`0!'````
MM.4!`"<```#\Y0$`1@```"3F`0`G````:^8!``P```"3Y@$`I0```*#F`0`_
M````1N<!`!@```"&YP$`-@```)_G`0`<````UN<!`!T```#SYP$`+@```!'H
M`0`&````0.@!``4```!'Z`$``P```$WH`0`-````4>@!``H```!?Z`$`"```
M`&KH`0`+````<^@!``4```!_Z`$`$````(7H`0`#````EN@!`&D```":Z`$`
M!0````3I`0`0````"ND!``0````;Z0$`!P```"#I`0`(````*.D!``4````Q
MZ0$`/P```#?I`0`#````=^D!`!````![Z0$`#0```(SI`0`2````FND!`!``
M``"MZ0$``P```+[I`0`(````PND!``<```#+Z0$`%````-/I`0`,````Z.D!
M`!4```#UZ0$`!@````OJ`0`0````$NH!``T````CZ@$``P```#'J`0`Q````
M->H!``0```!GZ@$`!@```&SJ`0`'````<^H!`!T```![Z@$`/0```)GJ`0`L
M````U^H!`"T````$ZP$`%P```#+K`0`F````2NL!`"D```!QZP$`*P```)OK
M`0`@````Q^L!`!D```#HZP$`(`````+L`0`;````(^P!`!8````_[`$`(```
M`%;L`0`:````=^P!`!L```"2[`$`+0```*[L`0`9````W.P!`"H```#V[`$`
M*````"'M`0`<````2NT!`"````!G[0$`'0```(CM`0`8````INT!`!\```"_
M[0$`(@```-_M`0`B`````NX!`"0````E[@$`)````$KN`0`8````;^X!`!L`
M``"([@$`)````*3N`0`6````R>X!`"````#@[@$`*P````'O`0`N````+>\!
M`!,```!<[P$`(````'#O`0`T````D>\!`!P```#&[P$`(````./O`0`=````
M!/`!`!X````B\`$`&````$'P`0`;````6O`!`"@```!V\`$`'0```)_P`0`I
M````O?`!`!P```#G\`$`-@````3Q`0`-````._$!`!$```!)\0$`&0```%OQ
M`0`M````=?$!`"````"C\0$`#````,3Q`0`/````T?$!`!H```#A\0$`#@``
M`/SQ`0`#````"_(!`!4````/\@$`!P```"7R`0`&````+?(!`"$````T\@$`
M)````%;R`0`4````>_(!`"````"0\@$`&````+'R`0`.````RO(!`-P```#9
M\@$`%0```+;S`0`<````S/,!``<```#I\P$`"@```/'S`0`.````_/,!``\`
M```+]`$`(````!OT`0`&````//0!`#D```!#]`$`&````'WT`0`.````EO0!
M``<```"E]`$`%````*WT`0`(````PO0!`#4```#+]`$`!@````'U`0`A````
M"/4!`!4````J]0$`$P```$#U`0`3````5/4!`#D```!H]0$`%P```*+U`0`*
M````NO4!`"````#%]0$`"P```.;U`0`,````\O4!`!,```#_]0$`"@```!/V
M`0`<````'O8!``4````[]@$`(0```$'V`0`)````8_8!`!D```!M]@$`+0``
M`(?V`0`'````M?8!`!\```"]]@$`!P```-WV`0`)````Y?8!``D```#O]@$`
M/@```/GV`0`'````./<!``\```!`]P$`$0```%#W`0`.````8O<!``<```!Q
M]P$`"0```'GW`0`'````@_<!`!4```"+]P$`!@```*'W`0`5````J/<!``H`
M``"^]P$`$P```,GW`0`6````W?<!``D```#T]P$`"P```/[W`0`9````"O@!
M``0````D^`$`*````"GX`0`,````4O@!`!````!?^`$`"````'#X`0`#````
M>?@!``H```!]^`$`)@```(CX`0`+````K_@!``,```"[^`$`!P```+_X`0`(
M````Q_@!``D```#0^`$`$````-KX`0`-````Z_@!`!0```#Y^`$`%0````[Y
M`0`*````)/D!`"X````O^0$`&````%[Y`0`8````=_D!`!<```"0^0$`#```
M`*CY`0`V````M?D!``8```#L^0$`%````//Y`0!$````"/H!`!(```!-^@$`
M#````&#Z`0`'````;?H!``0```!U^@$`!````'KZ`0`-````?_H!`!0```"-
M^@$`!0```*+Z`0`&````J/H!``8```"O^@$`"@```+;Z`0`'````P?H!`!$`
M``#)^@$`$0```-OZ`0`Y````[?H!`"X````G^P$`-@```%;[`0`%````C?L!
M`!@```"3^P$`&0```*S[`0`?````QOL!`!T```#F^P$`$@````3\`0`"````
M%_P!``0````:_`$`"P```!_\`0`%````*_P!``4````Q_`$``@```#?\`0`/
M````.OP!`%0```!*_`$`.0```)_\`0`1````V?P!`"T```#K_`$`+````!G]
M`0!B````1OT!`!<```"I_0$`;````,']`0`A````+OX!`$L```!0_@$`)```
M`)S^`0!*````P?X!`#D````,_P$`*P```$;_`0`O````<O\!`"\```"B_P$`
M,````-+_`0`Q`````P`"`"X````U``(`(P```&0``@`X````B``"`#$```#!
M``(`$@```/,``@`2````!@$"`!(````9`0(`B````"P!`@`(````M0$"`+0`
M``"^`0(`@P```',"`@!]````]P("`#,```!U`P(`6````*D#`@`6`````@0"
M`"(````9!`(`%P```#P$`@`/````5`0"`!8```!D!`(`'0```'L$`@!!````
MF00"`!H```#;!`(`(````/8$`@!8````%P4"`!<```!P!0(`%````(@%`@`+
M````G04"``4```"I!0(`!@```*\%`@`(````M@4"``4```"_!0(`%0```,4%
M`@`4````VP4"`!0```#P!0(`'P````4&`@`3````)08"``X````Y!@(``P``
M`$@&`@`(````3`8"``H```!5!@(`!P```&`&`@`%````:`8"`!0```!N!@(`
M!P```(,&`@`&````BP8"`!4```"2!@(`#0```*@&`@`+````M@8"`!(```#"
M!@(`"0```-4&`@`3````WP8"``<```#S!@(`#P```/L&`@`0````"P<"``@`
M```<!P(`"@```"4'`@`9````,`<"`!4```!*!P(`"````&`'`@`E````:0<"
M`!(```"/!P(`&0```*('`@`1````O`<"``<```#.!P(`$P```-8'`@`(````
MZ@<"``,```#S!P(`%0```/<'`@`)````#0@"``(````7"`(``@```!H(`@`1
M````'0@"``T````O"`(`"0```#T(`@`3````1P@"`!0```!;"`(`!P```'`(
M`@`J````>`@"``(```"C"`(`!````*8(`@`2````JP@"`!@```"^"`(`"0``
M`-<(`@`'````X0@"`!$```#I"`(`!P```/L(`@`>`````PD"``@````B"0(`
M%0```"L)`@`-````00D"`!(```!/"0(``@```&()`@`'````90D"``H```!M
M"0(`"P```'@)`@`8````A`D"`"H```"="0(`#0```,@)`@`*````U@D"``H`
M``#A"0(`!0```.P)`@`"````\@D"``L```#U"0(``0```-,$```<!```,04`
M`%\#````````G`$``&T"``"@!````````)0#``#'`0``_08``'P`````````
M`````(8"```K!P``"P$```````"#!P``P0```'<%```5!```\04``"P```#;
M`P``PP8``"4'```(`@```00``+P%```$!P``,0,```````"F`@``\`4``&0"
M``"R`@``#P0``($#````````````````````````U@0``%$%``"%!```````
M``````#V`0``<`(`````````````?P(``"X$````````(P$``*0%````````
M9`<``.0%``"1!@``)0$``'(&``#U!```;@(``'`!```U!P``P@$``-$"```O
M!```;P,``%`'``!:````H@$``#,!``"+!P```````'L!``#K````F`8``,`%
M``!>!P``2@4``,X&````````E`0``&("``#R````*0(``&8"````````VP0`
M`(8&``#>!0````````````"E````````````````````F`,```````!`````
MY@8```````#-`0```````)T$``!(`@``OP4```````#]`@``B@<````````,
M!0```````$\$``#,!0``[`(``"8%```7`````````#0```!8````O`$`````
M````````M0(``%H$``!E`P``:@,``%\!``"$!P``````````````````^@$`
M`&0#``!O````U@$```````!_!@````````H'``"0`````````$T#``";`@``
M`````!P#``!?!@``]`$``-\````H`P``W`$``-`!``"V`P``1P,````````=
M!P``$P<``"4#``#Q````L`4``-($`````````````*L#``"D`````````,L%
M``!A`P``>0,``)4$```*!````````(P&``#``0```````.$$``!Z!P``V0,`
M`.<!````````_P4``$P'``"I`0``6`0``.0!````````3P```+X!````````
M```````````O`P``;@<```````"R`````````)@%``!G!```I@8``.(!``!(
M!@```````"H```#[`0``:`$``%8'``#:`P``*@8``*,$``!6!@``5@0``+$&
M````````G0(``%L```"4!@``BP,``*D`````````K`4``-,```"@`P``>@$`
M`&<"``#"`P``*@<``'L#```K`````````#8``````````````#$"``"#````
MY`0```````#V!```>00``$8'````````]P``````````````DP(``+H%````
M````%P4``*H#```K`@``?`<```````!T!```.P(`````````````D`(``(X!
M``"*!```W````'X'``!7!0``F@,```,"```]!P``7@,```8!````````100`
M```````O!P``GP,``*4!`````````````&<%``!Q`0````````````!$!@``
MVP```#\'``!*``````````("````````*0$```````!6`P```````)P$````
M````S`$``&$$```6`P```````"<$``!A```````````````E!```=P```.X#
M``!H!@```````)X&````!@``>P`````````:!@``L00```,````%!P``W04`
M`+D&``#)`P``?`(``!@'``#L``````````````!C`0```````.X"``":````
MD@```)X#````````FP$``"L%``!Q`@``\P,``$8#``"^`@``N@$``-T$``#8
M!@``M`,``.,$``#*!```J@0````````:!P``%P(``+\$```8`0``L0(`````
M````````X@,``(\"````````?@$``/X%``!I`0``&`8``/@!```J`P``2P,`
M`'(#``!'!```E@$``$<```#(`0``<0,``%`&```Z````8@8``%,```#7!@``
M=@(````````N!0``)@(``'4&``#M````#`8```0```#D`@``?@,``(,%``")
M`0``DP0``/X"``!F!P``YP4``!<!````````GP$```\'``![`@``?@````4$
M```+!P``+P8``#8&````````4@(``+\`````````=P,``/\#````````"P``
M`#,%`````````````&@'```I!@``W0````````#T`@``00<```````#8`P``
MV@0`````````````:`````T"``!T!@```````-4&``#'!@``<0```*````#^
M!@``0@(```````";!```N0,``,`````$!```$`8``$P!``"4`@``N04``*`!
M``#!`0````````4`````````3@<``-8"``!C`````````,0`````````````
M``````#R!````````$`%``!Q!P```````,\&````````%P,``(,&````````
M`````%(%`````````````/,$``!W!```I08``&\$```(````7@```$H'``"Z
M`P``=@4``-X```"$`P``)`0``#L%``#Y!@``G`,``'<"````````:@$``#X"
M``#`!@``[@4``+X$````````<08```````")````I0(````````U!@``````
M`!X'````````50$``"($```X`0```````&T$````````AP(``'D%``"`!0``
MU@`````````A`@``408``#<$```S`@````````````"7`P``_P0```('```'
M`P``:P8```````#Q`0``Q@```/`#``"/````70<`````````````Z08``(4#
M`````````````-T"```N`P``5P$``/8&````````Y0$``/X```!-````S00`
M`!`%````````-@$``)`#``!]`0``EP```%D$``!_!```<P```*<%``!8`@``
M@@(```````!#!@``=@$``/X!````````YP0````````D`````````/@$``!K
M!```Q@0``%D!```A!```!@```)\"``!>`@`````````````$!@``E`4`````
M``#C!@``C@,``#X````K`0``%`(``-<#``"3!@``0@<```````!L`P``````
M`(X$``"C`````````,4#``!1````O0(``"P$```@!```Z00````````N!@``
M]@(``#`&``!8!0``````````````````J0(``"0#`````````````+,!````
M````?0```"<#````````=`<```````"1!````````,X!``#R!@``"`$`````
M```````````````!``!,!0``.@8```````#)!0``$0$``%\$``#Z`P``G```
M`+`#``#$`0```````'4$``!Q!```UP(``,H%``!\`0``C`$`````````````
M`````/T%```U!````````$`'``"G!@``T`,``*H&``#M`0``I@````````#O
M`@``````````````````K00``.L!``#Y!```WP,``"@$````````9@0``)\`
M```1!@``N00``.H#````````R00``%L"``",!````````,0"``"^!0``0@4`
M`'8'``#6!0``E08```````!E!P`````````````;!````````/0#``!4````
MV0````````!(````E@````````!6`@``-P```"$&```\`@``<P(```````#S
M`@````````@$``"W`@``I00``'D'````````W`8``!4`````````V00`````
M``#\`````````!\%``"+!0``]P$``/<%``!\`P``V@8``+0%``"5!0```P4`
M``````````````````````"#!```OP(``,X"```.!P``F0,``/\"````````
M]`0``#\"``!3`0```````,4$```R`0```````,L"``",``````````````!+
M`0````````````"\!@``"0$``-X!```F!```I`,``,T%``!S`0``,P0``!(&
M``"+!```8@`````````O````H@8``#@"``!9`@``@0<``$D'``"-!0``&0``
M``````"M````[P,``-,&``!\!0``,@```+T%``#*`@```````/@&``"X!@``
M6P4``$0!`````````````!T"```@!P``W08````````.!0```````&`!```Y
M`@``0P(``+L!``"``P```````"H!``!&````T`(``!4&````````?P```$(#
M```W!P``+0$``#$$``#A`0```````-(%``"T`@``Z`$``%0#``#X`P``?00`
M``````"B`P``U`(``&(#``#K!0````````````!?````'P(``#(#``#\`@``
M`````',$````````@@8``#<%```Z!0``&`0```````!V````HP,```````"7
M!0``8@4``!("``!L`0``(@$```````".`````````&H%````````Q04``!H!
M``#@`0```````),#``"8`````````(4%```8`````````"P%``"&!```````
M`!P```";!@``:@8``/L"``"%`0```````$P#``!J!P``>@0``!`$``!E````
M5`4``,8&``!T`@``X```````````````MP,``'4#````````````````````
M`````````%P!````````.@<``'X"``!L``````````````"(`@```````-`&
M```+`@``#P4``&T!```M`@``X`4``.<"``!/`P``#0$``&````!G````````
M`,$&``#9`@``NP8``````````````````.H```"R!```*``````````Q!P``
M`````/,```"J!0``_0$``-4$```:````````````````````8@0```````#*
M!@``808``$X`````````$P(`````````````2@0``!<&```C````/P```((%
M``"H!```N`(``)$%``#D````0@0```````"X!0``004``!\!``"X`0``````
M`)L%````````M0````,'```M!P````````````"P!````````&L'``![!0``
M9@```````````````````,X$```'`0``608`````````````X08``&('```[
M`0``.P0``'4"``#M!@``.00``"$'``#_!@``<P8```P!````````208``)\&
M``"\!```9P8```D%``!'!P``````````````````<P,``(L```![!P``T@,`
M``$"``"C`0``+`,```````"S!````````"8'```!`P``ZP(``'````!O!@``
MV````!,&``!%`P``7P<``/,%``#J!@``T00``#\#````````^P4``&<'``"A
M!@``T@(```````!K`0``T0```(L&```P````R`(``*$$``#L`0``X@```&H"
M``"F`0``7`(````````X`P```````%T&```K!```8`,``.$%````````SP``
M`)8%``#9!@``10(`````````````E0$`````````````"`8``$8%````!P``
M`````$D#``!L!0``50<``-,!``"``0````````````````````````````#]
M!```;`0```8$```^`P``'P0``-\$````````7`,``'X$```1`@``+08``,L$
M```;`P```````(`&``!U````!0,``)$!````````K``````````$`@``>0$`
M`"D$```V!P```````'H```!T``````````````!B`0``5`$```T````_`0``
MW@,``+8&```Y!P`````````````F````````````````````B`4``(\$````
M````1@0```$&````````LP```%`!``"2!@``L@$``!8"``!0`@``AP,``'`'
M``#U`@``M@```/0&``#Q`P``40$``.($``#O!````````-$&````````+P(`
M```````-!P``4`````````!4`@```````$T&``"!`@```````!T&````````
M]08``(T&``"[````7@8```````#Y`0``A````$<&````````=0$`````````
M````1`(``$@!```5`P```````"0!``!9`P``]0```)H%``!3!0``W@8``#D!
M```;!P```````(@!``!<!0``5P0``$,'``":`@``/0,``!$#``"N!0``20$`
M``````"?!````````#X!``!J````?@4``*<#``"I!@``(`````````"N````
M2P```!(```"F!````0$``'H&````````U0$``+H```#D`P``M@$`````````
M````:`0`````````````O@```+D```!R!````````!$```!?!0``Y@0``"`#
M``"K`0``Y@```"("``"@!@``O0$``/(!```[!@``A`8```````"!````$@0`
M`+L"```]!```?P$``!L```"S`@```````+T#``!U!0``90(``(4`````````
MS0(``,4&``!_!0```````%<"``"?!0``\`$``*T#````````B@4``'(!``"Q
M````@00```````#Q!@```````!('``!O`@```````.T#````````$`(``!0!
M```M`P``1`0```````#5`P``WP(```````!]!@``204```````#;!0``AP0`
M``````"S!@``]P(``*\$```%`@```````"$```#\!0``=P$``#P#```+!@``
M]`4``/`"``!Q!0``N`,```````#4`P``Z`(``%H&````````>P0``$$#````
M````*@(``)P%``#&!0``V@4``&$%``````````````$'``!Z!0``1P(``#P`
M``"\```````````````/`P`````````````1!P``.`8``!0$````````````
M`&$"```)!P``,P,```````!``0``/04```````"<!@````````````"'`0``
MR0```.D#``#E!@``O0```(L!``"]!````````#8#```U`@``'04```````"(
M!@``K@0```<"``#K!```OP,``````````````````$D$``!2!@``M00``',%
M``#$`P```````&L#``#:`0``L`$```````"3!0```````,L&``"B!0``````
M``D#``!]`P``$P````T$``#%`0``"P0```````!!`@``50```.,%````````
MK`,```,#```9!```!P8`````````````Z@0``.P%```*`P``J`4``+<$```6
M````5`0``#<!``!5!0``I`(``/D"````````@`(``",%``#[`P``0P$``&H$
M`````````````#\%```3`0```````/(#``#'!```OP8```````!(`P``````
M`,T#``!=!0``?`0``#X&``#Y````'@4``$8!````````JP```%8!``#H!```
MC0````````#.`P``.08`````````````RP```(<```#=`P````````````#,
M!````````%,'````````&04```````#G`P``,0```,P#``")!0``$`$```X`
M``!L!P``IP```,\$``!C!P``&08``-H````A`0``H@(``)@"``!>!```+00`
M`"0'``!E`0``>`(``!4'```=!```V04``)P"``!=`````````.`$``!F!0``
M0`8``.8"````````L@4````````$`P``'@0```````````````````0%````
M````DP$``(<&``!T`P``KP,``/L&````````D@0``(4"```?!@```````-P#
M````````6P$``%P'```4`P``\0(``#0'``!T!0``J`,``%T!```L!@``````
M````````````L`8``.`#``!.`P``_`0``#L'``!X!````````"\%``!I!@``
MU````*`"``#Y`P```````"@%``"'!P``[04``'("````````*0`````````&
M`@````````P'``#E!````````%,&`````````````"@'```"!@```````$8"
M``````````````````#7`0``S0```#<#```$`0```````"P'``!S!P``9`8`
M``````"!!0``;@$``*\"``#$!```+@(``%4$``````````````````"$!0``
M$P0``)$"``!8!@``T@```*X#``!*!@``.`<``'T'````````T`0``!L%````
M````N@0`````````````@@$`````````````(P(``%H!````````'`<``#,'
M```@`@``J`(``"<'````````.@0``(D"``!K````\P8``#D%```\`0``$04`
M``````#E!0``B@```!P!``"K!```B0,```8%````````(@4``%T"````````
MZ@$```````#Z!````````-\!``!'!0```````!0&``"(````Z0(``#0$``#E
M`P``JP4``,X%``#'`P```````#\$``````````````````#J`@``H0,``/X#
M```8!0``,P```/8%``!X!P```````'`&````````RP,``&\!```>`P``604`
M``````"&````@P$```````"T````CP,``(0$```P!```MP$``)D"``"@!0``
MM@(``.4"````````,@0``*$````L`@``R`,```L#````````C`4````````<
M!@``K`0``````````````````&L%````````V`$````````.!```"08`````
M```E````X0,``)X``````````````'(%```@!@```````!4!```^!0``'0``
M`,P"``">!0``B@8``(X"```A!0``E@(```````!!!@``0@8``*$!``"A!0``
M)P(`````````````+0```$L'``"5`@``4@0`````````````-`(``/@%``!T
M`0``70,``#4!````````3@0``%8%``"B!```"0```,,%``"#`P```````%@!
M``!I`@``[`,``!D"````````P@(``%L'``!#`P``/`0``)`!``#F`0``XP,`
M`%$$`````````````*P"```.`@``'`(``$X!``!(!```"@````````!.!@``
M_`$``"X```"-`0```````"X'``#M`@``Z0$``,\!``!L`@````````````#:
M`@``PP(``"<```"S`P``D@4```````!N````$`````````"-!```&P$``'`$
M``!W!P````,``-\%``!4!P``L@,```@'``"-`P```````(T"``!G`0``@@,`
M`+\!``!X!@``;@0``*H```!.`@``9`4```````",`P``,`<``(($````````
MO`,``#X$```8`@```````#<"``"2`P``@@`````$```````````````````/
M`@``%0(``,(```"[`P```````-(&```P!0``[@```,$%````````2`4``!0'
M``!:!P```@0``%X!`````````````-D!``!+!@``\00``&X&```X!0``/`<`
M`)H!``#A````O`(``+X#```6!`````````````"9!0``Z@4``/4#````````
M1`<``!D#``#L!```E0,```(#```*!@``CP8```````!M!@``80<``"X!```G
M!@```````&8&``!I`P```````&`&``"U`P``"@(``$D"```?````#08``&0!
M`````````````$\"`````````````*8%```R!@``L0$```X&``#2`0``-04`
M`(8!``!<`````````#P&``#F`P``&@4``+L$``"M`@```````(````!Z`P``
MB08``,@%``"%!@``W0$``#4#``#O`0`````````````,````E@,``&,"``">
M`@``\@4``````````````````&0$`````````````.D```"V!0``HP8`````
M```>`0``P0,``#T&``!P!0``A`$``&L"````````300``.@&````````R`8`
M`(\!````````PP```!\'````````8P0``'4'````````#04``#T!``!1!P``
M;0,``",&``!$````%P<`````````````V`(``$D````[`P``%P0```````#O
M````;`8````````*!0``4P,```<%```D!0``MP8``*D$```'!```1P$``$4&
M```````````````````@!0```````+````"O````,08``/`&``#C````````
M`"0&```2`P``P00``-L&`````````````'\#```,!```&`,``*P!````````
MN0$``.0&``#.`````````)(!``"`!P``Q0(```(%````````-`$```````"H
M````+`$```X#````````D`0``!D!``"B````4`4```````#K!@``U0(`````
M``````````````D$``"9`0``FP,``*H!```,`@``U04``/4%``#U`0``#0,`
M``````"=`0``Q0````````#&`@``5P```#@````H`@````````````#]`P``
MIP0``+L%````````P@4```````!/`0``'0$``.X&``#Z!@``E@0``%`$````
M````K0$`````````````I`$``*D%``"P`@``908```````#6`P``%@4``*8#
M````````&@(````%````````B`<``(('``#1!0``XP$``*X&``#C`@``P@8`
M`*L"``!P`P``D`4``*\!````````TP4``*0&````````M04```````#/!0``
M;04```````#X`@```````-\&`````````````!\#``!_!P``M`0``*@&````
M````Q`4``*<!``!#````G0,``!L"````````3`0````````"`0``EP(``$\%
M``!``P``>P8``-P"````````2`<``&,%``"!!@``1`,``.4```!-!0``Q`8`
M``````````````````````#0````6P,``+<```!Y`@``0P4```````!4!@``
MUP4``$H"```]````+04```````!\!@``X`(``&`$```:`P``````````````
M````PP0```````#3`P``X@(``'@#``"4````B0<``!H$````````````````
M````````000``!L&`````````````%('````````*0,``/T```!7`P``````
M```````C!P``40,``#H"``"3````\P$``%4"``````````````\&````````
MF00```````!"`0``7P(``$L$``!-!P``;@4``+$#````````A`(``$\&````
M````)@$```````#;`0```````+$%``!R!P``W`0``&D%``"U!@``)P4``#X'
M``!%!P``2@,``&D$``#/`P```````&@"``"O!0``@`0``'8#``#1`P``4`,`
M`)@!``#A`@``3`(``,($````````B`0``&T'``!R````````````````````
M^@(````````R!0``:`,```<'```C`P``?@8```````#H`P``EP0``+4!``#,
M!@``SP(``"@!``"7`0``RP$```````!8!P``4P(``%H#``"&!0```````#`"
M``#X````F0````````#,````K@(``#0%````````UP````````"E!0``````
M````````````)@8``)H&``#N`0``(0,``#L```"9!@``00$``,8#``",`@``
M!@<``!4%``!E!0``````````````````(@,``(H"```>````A0<``%<'``"M
M!0``10```'<&```X!```PP$``-0!``!"````900``"D'``!O!0``]P8``%8`
M```.`0``^@4``$T"``#^!```6@(``*,%```&!@``Z04``"(```!%!0``````
M`$P&``"8!```G08``,$"```#!`````````````"^!@``;@,``!8&``#O!@``
M`````'T%``#H````-`,``%H%```2!0``#P$``!X"````````:`4````````O
M`0``/0(``$T!```P`0``)0(``-4`````````)04``&8#``#V````>@(``)`&
M`````````````*,"````````K@$``/P#``!A`0``N````)$`````````````
M``````"5````)@,```\``````````````(H#````````?0(``,<%``#&`0``
M`````(8#```B!P``G@$```````#;`@``R0$```H!``!5`P``>0```-0$``##
M`P```````,H!```3`P``````````````````;P<``/`$``!V!```"`,`````
M```_!@``V`0```````"A`@``;0```(\%```9!P```````%D'```J!````@``
M`&`"```<!0```````/D%``!.!0```````,@````,`P``BP(```````"E`P``
M"`4````````Y`P``_P$``!`'``!=!```"0(```````!,````F@0``-$!```I
M!0``Z`4```````!X`````````&8!``#P````[P4``$L"``"W!0``!04`````
M``!2````ZP,``$L%``#6!@``.0```,@$``"=!0``P`(``&`'```#`0``>08`
M`$0%``#@!@`````````````'````-@4``"L#``#Z````R08``!8'```#!@``
MR@```'@!```2`0``]P,``.8%``"L!@``4P0``%(!````````!@,``+D"``!/
M!P``%````)$#``"J`@``7`0``-<$```Z`P``,`,``/0```!`!````````-X"
M``"R!@````````4&``#<!0``8P8``,`#``#*`P``[00``%L$``"4`0``B`,`
M`&D'``"&!P`````````````3!0``C@8``*0$```R!P``B@$``$,$``";````
M(@8``/("``!V!@````````````"V!````````!`#``#L!@``8`4```````#[
M!```E@8``.(%```K!@````````````#W!````````+H"````````M`$``$8&
M````````KP8``%<&```\!0```````$$````V!````````#("`````````04`
M``````".!0``'0,``*<"`````````````%(#```H!@``U`4``/P&````````
MJ`$``&,#```1!`````````````!5!@``)P$``+,%````````YP8``-,"````
M````AP4``(,"``"Z!@``6`,``($!````````[@0``"0"``#4!@```````#4`
M``"]!@``R0(``*D#``!9`````````#$!````````X@8``+0&```+!0``10$`
M`%P&``"X!```-P8```````!;!@```````&0````E!@``QP(```````"=````
M_P````4!``!``@``B00``&D```#8!0``(`$``)X$````````D@(``!0%````
M````.@$``-`%````````%@$```````!X!0``QP```,T&`````````````%X%
M```C!```]@,``"H%``#G````P`0``*L&```>!@``2@$``#,&`````@``9P,`
M`-X$```V`@````````````#[````K08``)<&``!1`@```````#0&````("@E
M<R!D87ES(&%G;RD`("A!8V-E<W-K97D@)7,I`"`H:6X@)7,@9&%Y<RD`("AT
M;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``(B5S(B!I<R!N
M;W0@82!D:7)E8W1O<GDN`"(E<R(@:7,@;F]T(&$@=F%L:60@8VAO:6-E+@`B
M)7,B(&ES(&YO="!C;VYF:6=U<F5D(&EN('1H92!(;W)D92!296=I<W1R>2X`
M(B5S(B!T<F5E(')E;F1E<F5R(&YO="!F;W5N9"X`(B5S(B!W87,@861D960@
M=&\@=&AE(&=R;W5P<R!S>7-T96TN`"(E<R(@=V%S(&%D9&5D('1O('1H92!P
M97)M:7-S:6]N<R!S>7-T96TN`"(E<R(@=V%S(&YO="!C<F5A=&5D.B`E<RX`
M)2XR9DU"('5S960@;V8@)2XR9DU"(&%L;&]W960@*"4N,F8E)2D`)60@)7,@
M86YD("5S`"5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+@`E
M9"UD87D@9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@
M2T(`)7,@36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E
M<R!3971U<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A
M;')E861Y(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5A9'D@=&\@<&5R
M9F]R;2!T:&4@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!C:&5C:V5D(&)E;&]W
M+B!#:&5C:R!T:&4@8F]X(&9O<B!A;GD@;W!E<F%T:6]N*',I('EO=2!W86YT
M('1O('!E<F9O<FT@870@=&AI<R!T:6UE+@`E<R!I<R!R97%U:7)E9``E<R!M
M:6YU=&5S`"5S(&YO="!F;W5N9"X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R
M97-S($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K
M;&ES=``E<SH@)7,`)7,Z(%1H:7,@;65S<V%G92!M87D@;F]T(&)E(&9R;VT@
M=VAO;2!I="!C;&%I;7,@=&\@8F4N($)E=V%R92!O9B!F;VQL;W=I;F<@86YY
M(&QI;FMS(&EN(&ET(&]R(&]F('!R;W9I9&EN9R!T:&4@<V5N9&5R('=I=&@@
M86YY('!E<G-O;F%L(&EN9F]R;6%T:6]N+@`L(&=U<W1I;F<@`"P@9W5S=&EN
M9R`E<R`E<P`L('9A<FEA8FQE(&9R;VT@)7,@=&\@)7,`+2T@<V5L96-T("TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V
M:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!
M32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT($EN9F]R;6%T:6]N`$%C8V]U;G0@4&%S<W=O
M<F0`06-C;W5N="!F<F]Z96XN`$%C8V]U;G1I;F<`061D`$%D9"!#:&EL9"!'
M<F]U<`!!9&0@0VAI;&0@4&5R;6ES<VEO;@!!9&0@2&5R93H`061D($YE=R!'
M<F]U<`!!9&0@3F5W(%!E<FUI<W-I;VX`061D(&$@8VAI;&0@9W)O=7`@=&\@
M(B5S(@!!9&0@82!C:&EL9"!P97)M:7-S:6]N('1O("(E<R(`061D(&$@;F5W
M('5S97(Z`$%D9"!C;VQU;6X`061D(&YE=R!M96UB97)S`$%D9"!P86ER`$%D
M9"!T:&4@)7,@365N=2!A<R!A($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D
M<F5S<R!B;V]K.@!!9&0@=&\@;7D@861D<F5S<R!B;V]K`$%D9"!U<V5R`$%D
M9&5D("(E<R(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A9&0@861D
M:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+@!!9&1E9"`B)7,B('1O
M('1H92!S>7-T96TN(%EO=2!C86X@;&]G(&EN(&YO=RX`061D:6YG('5S97)S
M(&ES(&1I<V%B;&5D+@!!9&1R97-S`$%D9')E<W,@0F]O:P!!9&UI;FES=&5R
M("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<P!!9&UI;FES=')A
M=&EO;@!!9',`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L:6%S`$%L
M:6=N`$%L:6=N;65N=#H`06QL`$%L;"!!=71H96YT:6-A=&5D(%5S97)S`$%L
M;"!'<F]U<',`06QL(%!E<FUI<W-I;VYS`$%L;"!F;W5R('-I9&5S`$%L;&]W
M(&UU;'1I<&QE(&%D9')E<W-E<P!!;&QO=R!S971T:6YG(&]F(&]R9&5R960@
M;&ES="!T>7!E/P!!;')E861Y(&5X:7-T<P!!;'1E<FYA=&4@24U34"!,;V=I
M;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5<V5R
M;F%M90!!;'1E<FYA=&4@96UA:6P@861D<F5S<P!!;'1E<FYA=&4@=&5M<&QA
M=&5S`$%L=&5R;F%T92!T97AT.@!!;65R:6-A;B!386UO80!!;B!I;&QE9V%L
M('9A;'5E('=A<R!S<&5C:69I960N`$%N('5N:VYO=VX@97)R;W(@:&%S(&]C
M8W5R960N`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY;6]U<R!0<F]X
M>0!!;G-W97(`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A`$%P<&QI
M8V%T:6]N`$%P<&QI8V%T:6]N($QI<W0`07!P;&EC871I;VX@:7,@<F5A9'DN
M`$%P<&QY('1O($-H:6QD(%-H87)E<P!!<'!R;W9E`$%P<')O>&EM871E(%-I
M>F4`07!R:6P`07)A8FEC("A7:6YD;W=S+3$R-38I`$%R8VAI=F4@1FEL92!3
M:7IE`$%R8VAI=F4@3F%M90!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M
M;W9E('1H92!S:6=N=7`@<F5Q=65S="!F;W(@)7,@/P!!<F4@>6]U('-U<F4@
M>6]U('=I<V@@=&\@9&5L971E("(E<R(@86YD(&%N>2!S=6(M9W)O=7!S/P!!
M<F=E;G1I;F$`07)M96YI80!!<FUE;FEA;B`H05)-4T-)22TX*0!!<G0`07)U
M8F$`07-C96YS:6]N($ES;&%N9`!!<V-I:2!!<G0`07-I82]086-I9FEC(%)E
M9VEO;@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O<F4@9&]I;F<@;6%I;G1E
M;F%N8V4@;W!E<F%T:6]N<S\`07-S:6=N;65N="!C;VQU;6YS`$%T=&5M<'0@
M=&\@9&5L971E(&$@;F]N+65X:7-T96YT(&=R;W5P+@!!='1E;7!T('1O(&1E
M;&5T92!A(&YO;BUE>&ES=&5N="!P97)M:7-S:6]N+@!!='1E;7!T('1O(&5D
M:70@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('-H87)E+@!!='1R:6)U=&5S`$%U9W5S=`!!=7-T
M<F%L:6$`075S=')I80!!=71H7V-Y<G-Q;#H@4F5Q=6ER960@:6UA<"!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!!=71H7V-Y<G5S.B!"86-K96YD(&1O97,@;F]T
M(&AA=F4@<F5Q=6ER960@8V%P86)I;&ET97,N`$%U=&A?8WER=7,Z(%)E<75I
M<F5D(&EM87`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]F='`Z(%)E<75I
M<F5D($944"!E>'1E;G-I;VX@;F]T(&9O=6YD+B!#;VUP:6QE(%!(4"!W:71H
M('1H92`M+65N86)L92UF='`@<W=I=&-H+@!!=71H7VEM87`Z(%)E<75I<F5D
M($E-05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]K<F(U.B!297%U:7)E
M9"!K<F(U(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?;&1A<#H@061D:6YG
M('5S97)S(&ES(&YO="!S=7!P;W)T960@9F]R($%C=&EV92!$:7)E8W1O<GD`
M075T:%]L9&%P.B!296UO=FEN9R!U<V5R<R!I<R!N;W0@<W5P<&]R=&5D(&9O
M<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4F5Q=6ER960@3$1!4"!E
M>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%5N86)L92!T;R!A9&0@
M=7-E<B`E<RX@5&AI<R!I<R!W:&%T('1H92!S97)V97(@<V%I9#H@`$%U=&A?
M;&1A<#H@56YA8FQE('1O(')E;6]V92!U<V5R("5S`$%U=&A?;&1A<#H@56YA
M8FQE('1O('5P9&%T92!U<V5R("5S`$%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2X`075T
M:%]M8V%L.B!297%U:7)E9"!-0T%,(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U
M=&A?<VUB875T:#H@4F5Q=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O
M=6YD+@!!=71H96YT:6-A=&EO;B!A="!)34%0('-E<G9E<B!F86EL960N`$%U
M=&AE;G1I8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S
M`$%U=&AE;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U
M=&AE;G1I8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A
M=&EO;B!T;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L
M9',Z`$%Z97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R
M;W5N9"!#;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O
M<R!U<V5R;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM
M,3,I`$)A;F=L861E<V@`0F%R8F%D;W,`0F%S92!G<F%P:&EC<R!D:7)E8W1O
M<GD@(B5S(B!N;W0@9F]U;F0N`$)A<V5L:6YE`$)E;&%R=7,`0F5L9VEU;0!"
M96QI>F4`0F5N:6X`0F5R;75D80!":'5T86X`0FER=&AD87D`0FQO8VL@(B5S
M(B!O9B!A<'!L:6-A=&EO;B`B)7,B(&YO="!F;W5N9"X`0FQO8VL@4V5T=&EN
M9W,`0FQO8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!"
M;W)D97(@=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$`0F]T:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`
M0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A
M;&%M`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N
M9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT<P!#7V5L;"!0<F]P
M97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N`$-A;&5N
M9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO="!R97-E="!P87-S
M=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@861M:6YI<W1R871O
M<BX`0V%N(&YO="!W<FET92!T;R!F:6QE("(E<R(`0V%N)W0@861M:6YI<W1E
M<B!E>'1E<FYA;"!S97-S:6]N(&AA;F1L97)S+@!#86XG="!C;VYN96-T('1O
M($E-05`@<V5R=F5R.B`E<P!#86XG="!O<&5N(&9I;&4@(B5S(BX`0V%N861A
M`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T(&1E;&5T92!F
M:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I<F5C=&]R>2X`
M0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@<&%R86UE=&5R
M+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN;W0@<F5M;W9E
M+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L(&YU;6)E<B!O
M9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@;F]T(&UA=&-H
M(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E('1O('-P96-I
M9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#87)R:65R`$-A=&5G
M;W)I97,@86YD($QA8F5L<P!#87EM86X@27-L86YD<P!#96QL(%!H;VYE`$-E
M;&P@4')O<&5R=&EE<P!#96QL('!A9&1I;F<Z`$-E;&P@<')O<&5R=&EE<P!#
M96QL('-P86-I;F<Z`$-E;&QP:&]N90!#96QT:6,@*$E33RTX.#4Y+3$T*0!#
M96YT97(`0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC`$-E;G1R86P@175R;W!E
M86X@*$E33RTX.#4Y+3(I`$-E<G1I9FEC871E($1E=&%I;',`0V5R=&EF:6-A
M=&4@3W=N97(`0V5R=&EF:6-A=&4@4&]L:6-I97,`0VAA9`!#:&%N9V4`0VAA
M;F=E(%EO=7(@4&%S<W=O<F0`0VAA;F=E('1H92!N86UE(&%N9"!A9&1R97-S
M('1H870@<&5O<&QE('-E92!W:&5N('1H97D@<F5A9"!A;F0@<F5P;'D@=&\@
M>6]U<B!E;6%I;',N`$-H86YG:6YG('EO=7(@<&%S<W=O<F0@:7,@;F]T('-U
M<'!O<G1E9"!W:71H('1H92!C=7)R96YT(&-O;F9I9W5R871I;VXN("!#;VYT
M86-T('EO=7(@861M:6YI<W1R871O<BX`0VAA<@!#:&5C7VL@3&EN:RXN+@!#
M:&EL90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S
M92!4<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E($%P<&QI8V%T:6]N.@!#:&]O
M<V4@82!P87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O
M(&1I<W!L87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O
M<F1E<F5D(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S
M`$-L96%R(%%U97)Y`$-L96%R(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L
M96%R('5S97(@9&%T80!#;&5A<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E
M`$-L:6-K871E;&P@=FEA($A45%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U
M9',@16%R;'D`0VQO=61Y`$-O8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA
M<'-E(%-I9&5B87(`0V]L;&%P<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`
M0V]L;W(@4&EC:V5R`$-O;&]U<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I
M=&QE<P!#;VUI8W,`0V]M;6%N9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M
M;6]N($YA;64`0V]M;W)O<P!#;VUP86YY`$-O;7!U=&5R<P!#;VYD:71I;VX`
M0V]N9&ET:6]N<P!#;VYF:6=U<F%T:6]N($1I9F9E<F5N8V5S`$-O;F9I9W5R
M871I;VX@9F]R('-Y;F-I;F<@=VET:"!01$%S+"!3;6%R='!H;VYE<R!A;F0@
M3W5T;&]O:RX`0V]N9FEG=7)A=&EO;B!I<R!O=70@;V8@9&%T92X`0V]N9FEG
M=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`0V]N9V\`0V]N9V\L(%1H92!$96UO
M8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#;VYN96-T:6]N(&9A:6QE9"X`0V]N
M;F5C=&EO;B!F86EL960Z(`!#;VYN96-T:6]N(')E9G5S960@=&\@=&AE('!U
M8FQI8R!K97ES97)V97(N`$-O;FYE8W1I;VX@<F5F=7-E9"!T;R!T:&4@<'5B
M;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E<R`H)7,I`$-O;FYE8W1I;VX@=&\@
M1E10('-E<G9E<B!F86EL960N`$-O;G1A8W1S`$-O;G1A8W1S('=E<F4@<W5C
M8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!#;VYT96YT
M('1Y<&4@;V8@8V]M<')E<W-E9"!F:6QE.B``0V]N=&5N=',@;V8@(B5S(@!#
M;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F86EL960Z
M("5S`$-O<'D@<V5L96-T:6]N`$-O<W0@240`0V]S=&$@4FEC80!#;W1E(&0G
M279O:7)E`$-O=6QD(&YO="!01U`@96YC<GEP="!M97-S86=E.B``0V]U;&0@
M;F]T(%!'4"!S:6=N(&UE<W-A9V4Z(`!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y
M<'0@;65S<V%G92X`0V]U;&0@;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O
M=6QD(&YO="!A9&0@8V]N=&%C="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!
M4"!S97)V97(N`$-O=6QD(&YO="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N
M;W0@8V]N;F5C="!T;R!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@<V5R=F5R("(E<R(@=7-I;F<@1E10.B`E<P!#;W5L9"!N;W0@8W)E871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!01U`@
M9&%T83H@`$-O=6QD(&YO="!D96-R>7!T(%,O34E-12!D871A+@!#;W5L9"!N
M;W0@9&5L971E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!D96QE=&4@9&ES=')I
M8G5T:6]N(&QI<W0N("5S`$-O=6QD(&YO="!D96QE=&4@<V5T=7`@=7!G<F%D
M92!S8W)I<'0@(B5S(BX`0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I
M96YT)W,@92UM86EL(&%D9')E<W,N`$-O=6QD(&YO="!F971C:"!C;VUP;&5T
M92!A9&1R97-S(&)O;VLN`$-O=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T
M<FEB=71I;VX@;&ES="X`0V]U;&0@;F]T(&9E=&-H('1H92!C;VUP;&5T92!L
M:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<RX`0V]U;&0@;F]T(&QO860@<W1R
M871E9WD@(B5S(BX`0V]U;&0@;F]T(&UK9&ER("(E<R(N`$-O=6QD(&YO="!O
M8G1A:6X@<'5B;&EC(&ME>2!F<F]M('1H92!K97ES97)V97(N`$-O=6QD(&YO
M="!O<&5N("(E<R(@9F]R('=R:71I;F<N`$-O=6QD(&YO="!O<&5N("5S+@!#
M;W5L9"!N;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!#;W5L
M9"!N;W0@;W!E;B!D:7)E8W1O<GD@(B5S(BX`0V]U;&0@;F]T(')E86-H('1H
M92!,1$%0('-E<G9E<BX`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R
M97-E="!T:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M
M92!O<B!A;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@
M86=A:6X@;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE
M960@9G5R=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD
M(&YO="!R971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R
M:65V92!D:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E
M(&1I<W1R:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R
M871I;VXN`$-O=6QD(&YO="!R;61I<B`B)7,B+@!#;W5L9"!N;W0@<V%V92`E
M<R!C;VYF:6=U<F%T:6]N+@!#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C;VYF
M:6=U871I;VXN`$-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO
M;CH@)7,`0V]U;&0@;F]T('-A=F4@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z
M("(E<R(N`$-O=6QD(&YO="!S879E('1H92!B86-K=7`@8V]N9FEG=7)A=&EO
M;B!F:6QE("5S+@!#;W5L9"!N;W0@<V%V92!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE("5S+B!9;W4@8V%N(&5I=&AE<B!U<V4@;VYE(&]F('1H92!O<'1I;VYS
M('1O('-A=F4@=&AE(&-O9&4@8F%C:R!O;B`E<R!O<B!C;W!Y(&UA;G5A;&QY
M('1H92!C;V1E(&)E;&]W('1O("5S+@!#;W5L9"!N;W0@<V5A<F-H('1H92!,
M1$%0('-E<G9E<BX`0V]U;&0@;F]T('5N;&EN:R`B)7,B+@!#;W5L9"!N;W0@
M=7!D871E(&-O;G1A8W0N("5S`$-O=6QD(&YO="!U<&1A=&4@9&ES=')I8G5T
M:6]N(&QI<W0N("5S`$-O=6QD(&YO="!W<FET92!C;VYF:6=U<F%T:6]N(&9O
M<B`B)7,B.B`E<P!#;W5L9&XG="!F:6YD('1H92!-;WII;&QA(%-I9&5B87(N
M($UA:V4@<W5R92!T:&4@<VED96)A<B!I<R!O<&5N+@!#;W5L9&XG="!G:79E
M('5S97(@(B5S(B!T:&4@9F]L;&]W:6YG(')I9VAT<R!F;W(@=&AE(&9O;&1E
M<B`B)7,B.B`E<P!#;W5N=&5D('1E>'0`0V]U;G1R>0!#;W5R<V5S`$-R96%T
M90!#<F5A=&4@82!L:6YK`$-R96%T92!A(&YE=R!O;F4`0W)E871E('-U8B!F
M;VQD97)S`$-R96%T;W(@4&5R;6ES<VEO;G,`0W)E9&ET(&-A<F0@;G5M8F5R
M`$-R;V%T:6$`0W5B80!#=7)R96YT(#0@4&AA<V5S`$-U<G)E;G0@4V5S<VEO
M;G,`0W5R<F5N="!4:6UE`$-U<G)E;G0@55),(&ES`$-U<G)E;G0@57-E<G,`
M0W5R<F5N="!796%T:&5R`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S
M='EL90!#=7-T;VUI>F4@=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N
M`$-U=`!#=70@<V5L96-T:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#
M>7)I;&QI8R`H5VEN9&]W<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/
M23@M52D`0WIE8V@@4F5P=6)L:6,`1$0`1%-.("AS964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD8BYI;G1R;RUD
M<VXN<&AP*0!$86EL>0!$871A5')E92!"<F]W<V5R`$1A=&%B87-E($QO;VMU
M<`!$871E`$1A=&4@4F5C96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE
M=&4@0V]L=6UN`$1E8V5M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!)
M;F1E;G0`1&5F875L=`!$969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`
M1&5F875L="!3:&5L;`!$969I;FET:6]N<P!$96QE=&4`1&5L971E($-E;&P`
M1&5L971E($=R;W5P`$1E;&5T92!,;V<`1&5L971E(%!E<FUI<W-I;VX`1&5L
M971E(&%N9"!P=7)G92!M97-S86=E<P!$96QE=&4@8V5L;`!$96QE=&4@8V]L
M=6UN`$1E;&5T92!E>&ES=&EN9R!A;'1E<FYA=&4@=&5M<&QA=&4`1&5L971E
M(&UE<W-A9V5S`$1E;&5T92!P97)M:7-S:6]N<R!F;W(@(B5S(@!$96QE=&4@
M<&5R;6ES<VEO;G,@9F]R("(E<R(@86YD(&%N>2!S=6(M<&5R;6ES<VEO;G,_
M`$1E;&5T92!R;W<`1&5L971E('-E;&5C=&5D(&ED96YT:71Y`$1E;&5T92!S
M=6(@9F]L9&5R<P!$96QE=&4@=&AE(&-U<G)E;G0@8V]L=6UN`$1E;&5T92!T
M:&4@8W5R<F5N="!R;W<`1&5L971E9"!S971U<"!U<&=R861E('-C<FEP="`B
M)7,B+@!$96QI=F5R>2!T:6UE`$1E;FUA<FL`1&5S8W)I8F4@=&AE(%!R;V)L
M96T`1&5S8W)I<'1I;VX`1&5T86EL<R`H86QS;R!I;B!(;W)D92=S(&QO9V9I
M;&4I.@!$971A:6QS(&AA=F4@8F5E;B!L;V=G960@9F]R('1H92!A9&UI;FES
M=')A=&]R+@!$979E;&]P;65N=`!$97<@4&]I;G0`1&5W(%!O:6YT(&9O<B!L
M87-T(&AO=7(Z(`!$97<@<&]I;G0Z(`!$:7)E8W1I;VX@;&5F="!T;R!R:6=H
M=`!$:7)E8W1I;VX@<FEG:'0@=&\@;&5F=`!$:7)E8W1O<GD`1&ES<&QA>2`R
M-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!D971A:6QE
M9"!F;W)E8V%S=`!$:7-P;&%Y(&9O<F5C87-T("A4048I`$1I<W!L87D@9F]R
M;6%T`$1I<W!O<VET:6]N($YO=&EF:6-A=&EO;@!$:FEB;W5T:0!$;R!N;W0@
M9&5L971E`$1O(&YO="!D:7)E8W1L>2!A8V-E<W,@;6%I;G1E;F%N8V4N<&AP
M`$1O97,@=&AE(&9I<G-T(')O=R!C;VYT86EN('1H92!F:65L9"!N86UE<S\@
M268@>65S+"!C:&5C:R!T:&ES(&)O>#H`1&]M:6YI8V$`1&]M:6YI8V%N(%)E
M<'5B;&EC`$1O;B=T(&AA=F4@86X@86-C;W5N=#\@4VEG;B!U<"X`1&]W;FQO
M860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O;F9I9W5R871I
M;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U9W,`12U-86EL
M`$5-86EL+71O+5--4R!G871E=V%Y(&1R:79E<BP@9F]R(&-A<G)I97)S('=H
M:6-H('!R;W9I9&4@=&AI<R!S97)V:6-E+@!%4E(`16-U861O<@!%9&ET`$5D
M:70@0FQO8VL`161I="!'<F]U<`!%9&ET(%!E<FUI<W-I;VX`161I="!097)M
M:7-S:6]N<P!%9&ET(%!E<FUI<W-I;VYS(&9O<B`E<P!%9&ET(&]P=&EO;G,@
M9F]R.@!%9&ET('!E<FUI<W-I;VYS(&9O<B`B)7,B`$5D:70@<&5R;6ES<VEO
M;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M96YT
M+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S(&UU
M<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M86EL+71O+5--
M4R!'871E=V%Y`$5M;W1I8V]N<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U
M;'0N`$5M<'1Y('-E87)C:"!T97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM
M86=E<R!F<F]M(%!H;W1O($=A;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG
M:'0@8VQI8VL@8V]N=&5X="!M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O
M<@!%;G1E<B!A('-E8W5R:71Y('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E
M(&%S:V5D(&EF('EO=2!N965D('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N
M9RX@)W=H870@:7,@=&AE(&YA;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE
M(&EM86=E(%523"!H97)E`$5N=&5R('1H92!L971T97)S(&)E;&]W.@!%<75A
M=&]R:6%L($=U:6YE80!%<FET<F5A`$5R<F]R`$5R<F]R(&-R96%T:6YG(&)L
M;V-K.B`E<P!%<G)O<B!D96QE=&EN9R!S>6YC(&%N8VAO<CH@)7,`17)R;W(@
M9&5L971I;F<@<WEN8R!L;V<Z("5S`$5R<F]R(&=E='1I;F<@8V]N=&5N=#H@
M)7,`17)R;W(@=7!D871I;F<@<&%S<W=O<F0Z("5S`$5R<F]R('=I=&@@96UA
M:6P@;65S<V%G92X`17)R;W(@=W)I=&EN9R`B)7,B+@!%<W1O;FEA`$5T:&EO
M<&EA`$5T:&YI8P!%=7)O<&4`179E<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI
M;G5T97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@
M3&]G:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A
M;'5E<SH`17AE8W5T90!%>'!A;F0`17AP86YD(%-I9&5B87(`17AP96-T960@
M)RDG`$5X<&5C=&5D(&)A<F4@=V]R9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`
M17AP:7)A=&EO;B!$871E`$5X<&]N96YT`$9'($-O;&]R`$944"!U<&QO860@
M;V8@<V5T=7``1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE
M9"!T;R!C;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C
M="!T;R!334(@<V5R=F5R+@!&86EL960@=&\@8V]P>2!F<F]M("(E<R(N`$9A
M:6QE9"!T;R!C;W!Y('1O("(E<R(N`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!
M4TP@8V]N;F5C=&EO;BX`1F%I;&5D('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D
M('1O(')E=')I979E.B`E<P!&86ER`$9A;&ML86YD($ES;&%N9',@*$UA;'9I
M;F%S*0!&87)O92!)<VQA;F1S`$9A=&%L($5R<F]R.@!&87@`1F%X97,`1F5B
M<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME.B``1F5W(%-H;W=E<G,`1F5W
M(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`1FEG;&5T($-!4%1#2$$`1FEG
M;&5T(&9O;G0`1FEJ:0!&:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&4`1FEL92!#
M;W5N=#H@)7,@9FEL97,`1FEL92!-86YA9V5R`$9I;&4@3F%M90!&:6QE('-E
M;&5C=&EO;@!&:6QE('5P;&]A9`!&:6QE('5P;&]A9',@;F]T('-U<'!O<G1E
M9"X`1FEL=&5R<P!&:6YL86YD`$9I<G-T($AA;&8`1FER<W0@475A<G1E<@!&
M:7@@<F%T:6\`1FQI<`!&;&]A=`!&;V<`1F]L9&5R("5S(&1O97,@;F]T(&5X
M:7-T`$9O;G0@0V]L;W(`1F]O9`!&;W(@8G)O=W-E<G,@=&AA="!D;VXG="!S
M=7!P;W)T(&EM86=E<P!&;W)E8V%S="`H5$%&*0!&;W)E8V%S="!$87ES("AN
M;W1E('1H870@=&AE(')E='5R;F5D(&9O<F5C87-T(')E='5R;G,@8F]T:"!D
M87D@86YD(&YI9VAT.R!A(&QA<F=E(&YU;6)E<B!H97)E(&-O=6QD(')E<W5L
M="!I;B!A('=I9&4@8FQO8VLI`$9O<F=O="!Y;W5R('!A<W-W;W)D/P!&;W)M
M<P!&;W)T=6YE`$9O<G1U;F4@='EP90!&;W)T=6YE<P!&;W)T=6YE<R`R`$9O
M<G5M<P!&;W)W87)D<P!&<@!&<F%M97,`1G)A;F-E`$9R86YC92P@365T<F]P
M;VQI=&%N`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I80!&<F5N8V@@
M4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&<F]M('1H92``1G5L;"!$97-C
M<FEP=&EO;@!&=6QL($UO;VX`1G5L;"!.86UE`$=A8F]N`$=A;&QE<GD@=&\@
M=&%K92!I;6%G92!F<F]M`$=A;&QE<GDZ`$=A;6)I80!'96YE<F%T92`E<R!#
M;VYF:6=U<F%T:6]N`$=E;F5R871E9"!#;V1E`$=E;W)G:6$`1V5R;6%N>0!'
M:&%N80!':6)R86QT87(`1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!'
M;V5D96P`1V]O9VQE($UA<',`1V]O9VQE(%-E87)C:`!'<F%Y<V-A;&4`1W)E
M96-E`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U
M<"!!9&UI;FES=')A=&EO;@!'<F]U<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T
M>0!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B``1W)O=7!?;&1A<#H@56YA8FQE('1O
M(&1E;&5T92!G<F]U<"`E<P!'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E
M(&=R;W5P("5S`$=R;W5P<P!'=6%D96QO=7!E`$=U86T`1W5A=&5M86QA`$=U
M97)N<V5Y`$=U97-T(%!E<FUI<W-I;VYS`$=U97-T8F]O:P!'=6EN96$`1W5I
M;F5A+4)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!C;W=A<F1L>2!R969U
M<V5S('1O(&1E;&5T92!T:&4@;&%S="!C96QL(&EN(')O=RX`2%1-3$%R96$@
M8V]W87)D;'D@<F5F=7-E<R!T;R!D96QE=&4@=&AE(&QA<W0@8V]L=6UN(&EN
M('1A8FQE+@!(5$U,07)E82!C;W=A<F1L>2!R969U<V5S('1O(&1E;&5T92!T
M:&4@;&%S="!R;W<@:6X@=&%B;&4N`$A45%`@075T:&5N=&EC871I;VX@;F]T
M(&9O=6YD+@!(86ET:0!(87-H+4%L9V]R:71H;0!(87IE`$AE861E<@!(96%D
M97)S`$AE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96%V>2!4
M+5-T;W)M`$AE8G)E=R`H25-/+3@X-3DM."U)*0!(96EG:'0`2&5L<`!(96QP
M('5S:6YG(&5D:71O<@!(96QP97(`2&5M:7-P:&5R90!(97)E(&ES('1H92!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4Z`$AI9V@`2&]?;64`2&]L>2!3964@*%9A
M=&EC86X@0VET>2!3=&%T92D`2&]M90!(;VUE($%D9')E<W,`2&]M92!$:7)E
M8W1O<GD`2&]M92!0:&]N90!(;VYD=7)A<P!(;VYG($MO;F<`2&]R9&4`2&]R
M9&4O2V]L86(Z($EN=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@
M;65S<V%G92`E<P!(;W)D92]+;VQA8CH@3F\@;65S<V%G92!C;W)R97-P;VYD
M<R!T;R!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z($YO(&]B:F5C="!O9B!T>7!E
M("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z(%-U8V-E<W-F
M=6QL>2!R96UO=F5D("5S("(E<R(`2&]R9&4O2V]L86(Z(%1H92!I;G1E9W)A
M=&EO;B!E;F=I;F4@<F5Q=6ER97,@=&AE("=D;VUX;6PG(%!(4"!E>'1E;G-I
M;VX`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T<F5E
M(&9O<B!O8FIE8W0@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO=F4@
M)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R971R:65V92!-
M24U%($E$(&9O<B!T:&4@<&%R="!O9B!T>7!E("5S`$AO<F1E+TMO;&%B.B!5
M;F%B;&4@=&\@<WEN8VAR;VYI<V4@)7,@(B5S(CH@)7,`2&]R9&4O2V]L86(Z
M(%5N86)L92!T;R!S>6YC:')O;FES92!S:&%R97,Z("5S`$AO<F1E+TMO;&%B
M.B!5;FMN;W=N('-H87)E("(E<R(`2&]R:7IO;G1A;"!2=6QE`$AO<FEZ;VYT
M86P@<&%D9&EN9P!(;W)I>F]N=&%L.@!(;W<@9&ED('EO=2!G970@:&5R93\@
M*%!L96%S92!R97!O<G0A*0!(;W<@;6%N>2!C;VQU;6YS('=O=6QD('EO=2!L
M:6ME('1O(&UE<F=E/P!(;W<@;6%N>2!F:65L9',@*&-O;'5M;G,I(&%R92!T
M:&5R93\`2&]W(&UA;GD@<F]W<R!W;W5L9"!Y;W4@;&EK92!T;R!M97)G93\`
M2'5M:61I='D`2'5M:61I='DZ(`!(=6UO<FES=',`2'5N9V%R>0!)34%0(&UA
M:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@9&5L971I
M;VX@9F%I;&5D.B`E<P!)34%0(&UA:6QB;W@@<75O=&$@8W)E871I;VX@9F%I
M;&5D.B`E<P!)4"!!9&1R97-S`$E0($%D9')E<W,@;F]T(&%V86EL86)L92X`
M25`@061D<F5S<R!N;W0@=VET:&EN(&%L;&]W960@0TE$4B!B;&]C:RX`25`@
M;&]C:V1O=VX@=FEO;&%T:6]N+@!)7VYS97)T(%)O=R!"969O<F4`26-E;&%N
M9`!)8V]N<R!/;FQY`$EC;VYS(&9O<B`E<P!)8V]N<R!W:71H('1E>'0`261E
M;G1I='DG<R!N86UE.@!)9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O<G)E8W1L
M>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N`$EF('EO=2!D;VXG
M="!S964@86YY(&EC;VYS('5S:6YG($EN=&5R;F5T($5X<&QO<F5R+"!Y;W4@
M;6%Y(&YE960@=&\@8VAE8VL@=&AI<R!B;W@@=&\@='5R;B!O9F8@4$Y'('1R
M86YS<&%R96YC>2X`268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM
M86=E+"!T:&4@:6UA9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I
M<W!L87EE9"!B>2!Y;W5R(&)R;W=S97(N`$EM86=E(%!R979I97<Z`$EM86=E
M(%523`!);6%G92!54DPZ`$EM86=E(&9R;VT@9V%L;&5R>0!);6%G92!F<F]M
M(&=A;&QE<GDZ`$EM86=E('5P;&]A9`!);6%G97,`26UP;W)T+"!3=&5P("5D
M`$EM<&]R=&5D(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$EN7W-E<G0@
M4F]W($%F=&5R`$EN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BX`26YC;W)R
M96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"X`26YC;W)R96-T('5S97)N
M86UE(&]R(&%L=&5R;F%T92!A9&1R97-S+B!4<GD@86=A:6X@;W(@8V]N=&%C
M="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R=&AE<B!H96QP
M+@!);F-R96%S92!);F1E;G0`26YD:6$`26YD:79I9'5A;"!5<V5R<P!);F1O
M;F5S:6$`26YF;P!);F9O<FUA=&EO;@!);F9O<FUA=&EO;B!N;R!L;VYG97(@
M879A:6QA8FQE+@!);G-E<G0@0U]O;'5M;B!!9G1E<@!);G-E<G0@26UA9V4`
M26YS97)T(%1A8FQE`$EN<V5R="!796(@3&EN:P!);G-E<G0@7T-O;'5M;B!"
M969O<F4`26YS97)T(&$@;F5W(&-O;'5M;B!A9G1E<B!T:&4@8W5R<F5N="!O
M;F4`26YS97)T(&$@;F5W(&-O;'5M;B!B969O<F4@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!R;W<@869T97(@=&AE(&-U<G)E;G0@;VYE`$EN<V5R
M="!A(&YE=R!R;W<@8F5F;W)E('1H92!C=7)R96YT(&]N90!);G-E<G0@82!P
M87)A9W)A<&@@869T97(@=&AE(&-U<G)E;G0@;F]D90!);G-E<G0@82!P87)A
M9W)A<&@@8F5F;W)E('1H92!C=7)R96YT(&YO9&4`26YS97)T(&%L=&5R;F%T
M92!T96UP;&%T90!);G-E<G0@86X@96UA:6P@861D<F5S<R!T;R!W:&EC:"!Y
M;W4@8V%N(')E8V5I=F4@=&AE(&YE=R!P87-S=V]R9#H`26YS97)T(&-E;&P@
M869T97(`26YS97)T(&-E;&P@8F5F;W)E`$EN<V5R="!C;VQU;6X@869T97(`
M26YS97)T(&-O;'5M;B!B969O<F4`26YS97)T(&UE<W-A9V5S`$EN<V5R="!P
M87)A9W)A<&@@869T97(`26YS97)T('!A<F%G<F%P:"!B969O<F4`26YS97)T
M(')O=R!A9G1E<@!);G-E<G0@<F]W(&)E9F]R90!);G-E<G0@=&AE(')E<75I
M<F5D(&%N<W=E<B!T;R!T:&4@<V5C=7)I='D@<75E<W1I;VXZ`$EN<V5R="]-
M;V1I9GD@26UA9V4`26YS97)T+TUO9&EF>2!,:6YK`$EN<W5F9FEC:65N="!C
M<F5D:70@=&\@<V5N9"!T;R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N`$EN<W5F
M9FEC:65N="!C<F5D:70N`$EN=&5G97(`26YT96=E<B!L:7-T`$EN=F%L:60@
M541(+B`H57-E<B!$871A($AE861E<BDN`$EN=F%L:60@6DE0(&1A=&$`26YV
M86QI9"!A<'!L:6-A=&EO;BX`26YV86QI9"!B871C:"!)1"X`26YV86QI9"!D
M871A('-U8FUI='1E9"X`26YV86QI9"!D97-T:6YA=&EO;B!A9&1R97-S+@!)
M;G9A;&ED(&9I;&4@9F]R;6%T`$EN=F%L:60@;&EC96YS92!K97DN`$EN=F%L
M:60@;&]C871I;VX@<')O=FED960N`$EN=F%L:60@;7-G7W1Y<&4N`$EN=F%L
M:60@;W(@;6ES<VEN9R!A<&E?:60N`$EN=F%L:60@;W(@;6ES<VEN9R!P87)A
M;65T97)S+@!);G9A;&ED('!A<F5N="!P97)M:7-S:6]N+@!);G9A;&ED('!A
M<G1N97(@:60N`$EN=F%L:60@<')O9'5C="!C;V1E+@!);G9A;&ED('!R;W1O
M8V]L+@!);G9A;&ED(')E8VEP:65N=#H@(B5S(@!);G9A;&ED('-H87)E(&]B
M:F5C=`!);G9A;&ED('-O=7)C92!A9&1R97-S+@!);G9A;&ED('5N:6-O9&4@
M9&%T82X`26YV96YT;W)Y`$EN=F5R="!S96QE8W1I;VX`27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9@!)<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T
M960@5"U3=&]R;7,`27-R865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC
M80!*86YU87)Y`$IA<&%N`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y
M`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T
M:69Y($9U;&P`2G5S=&EF>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A
M;@!+965P(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T
M960@875T:&5N=&EC871I;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO
M;@!+97D@1FEN9V5R<')I;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A
M9V4`2V5Y(&%L<F5A9'D@97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R
M+@!+:61S`$MI<FEB871I`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E
M<'5B;&EC(&]F`$MO<F5A+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`
M2W5W86ET`$MY<F=Y>G-T86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE
M)W,@1&5M;V-R871I8R!297!U8FQI8P!,87-T($AA;&8`3&%S="!087-S=V]R
M9"!#:&%N9V4`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`3&%S="!L;V=I
M;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO9VEN.B!.979E
M<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@;F\@8F]R9&5R
M`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E<P!,97-O=&AO
M`$QE=F5L`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C:'1E
M;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN($5A
M<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H="!2
M86EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO=V5R
M`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M86EL
M(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI;F<`
M3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE(&9O
M;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@5&%B
M;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W;F5R
M`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E`$QI
M<W1I;F<@<V5S<VEO;G,@9F%I;&5D.B`E<P!,:7-T:6YG('5S97)S(&9A:6QE
M9#H@)7,`3&ES=&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`3&ET97)A='5R90!,
M:71H=6%N:6$`3&]A9&EN9RXN+@!,;V-A;"!T:6UE.B``3&]C86QE(&%N9"!4
M:6UE`$QO8V%T:6]N`$QO9R!I;@!,;V<@;V8@<')E=FEO=7,@<WEN8R!S97-S
M:6]N`$QO9R!O=70`3&]G:6X`3&]G:6X@5&%S:W,`3&]G:6X@9F%I;&5D(&)E
M8V%U<V4@>6]U<B!U<V5R;F%M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I
M;F-O<G)E8W1L>2X`3&]G:6X@9F%I;&5D+@!,;VYG('1E>'0`3&]V90!,;W<`
M3&]W97(@9W)E96L@;&5T=&5R<P!,;W=E<B!L871I;B!L971T97)S`$QO=V5R
M(')O;6%N(&YU;6)E<G,`3'5X96UB;W5R9P!-30!-3U1$`$U3+51.148@071T
M86-H;65N="!C;VYT86EN960@;F\@9&%T82X`35-'`$UA8V%O`$UA8V5D;VYI
M82P@5&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9@!-861A9V%S8V%R
M`$UA9VEC`$UA:6P`36%I;"!!9&UI;@!-86ME(&QI;E]K+BXN`$UA;&%W:0!-
M86QA>7-I80!-86QD:79E<P!-86QI`$UA;'1A`$UA;F%G92!T:&4@;&ES="!O
M9B!C871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N
M9"!C;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA
M<#(T(&UA<`!-87!1=65S="!M87``36%P<&EN9W,@<W1O<F5D+@!-87)C:`!-
M87)G:6X`36%R:R!W:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O
M=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL
M($ES;&%N9',`36%R=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI
M80!-875R:71I=7,`36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P
M87)T<R!E>&-E961E9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T
M96UP(&QA<W0@-B!H;W5R<SH@`$UA>&EM=6T@3G5M8F5R(&]F(%!O<G1A;"!"
M;&]C:W,`36%X:6UU;2!L96YG=&@`36%Y`$UA>6]T=&4`365D:6-I;F4`365M
M8F5R<P!-96YU(&UO9&4Z`$UE<F=E(&-E;&QS`$UE<W-A9V4`365S<V%G92!6
M97)I9FEE9"!3=6-C97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I
M8V%T92!C;W5L9"!N;W0@8F4@=F5R:69I960N`$UE<W-A9V4@97AP:7)E9"X`
M365S<V%G92!T>7!E`$UE=&%R(%=E871H97(`365T87(@8FQO8VL@;F]T(&%V
M86EL86)L92X`365T87(@8FQO8VL@;F]T(&%V86EL86)L92X@1&5T86EL<R!H
M879E(&)E96X@;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`365T87)$
M0B!I<R!N;W0@8V]N;F5C=&5D+@!-971H;V0`365T:&]D("(E<R(@:7,@;F]T
M(&1E9FEN960`365T:&]D(&YO="!D969I;F5D+B!#86QL960@;65T:&]D.B`E
M<P!-971R:6,`365X:6-O`$UI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@
M;V8`36ED9&QE`$UI;64@5'EP90!-:6X@=&5M<"!L87-T(#(T(&AO=7)S.B``
M36EN('1E;7`@;&%S="`V(&AO=7)S.B``36EN:6UU;2!P87-S=V]R9"!A9V4@
M:&%S(&YO="!Y970@97AP:7)E9`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG
M=7)A=&EO;BX@66]U(&AA=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W
M86YT('1O('5S92!T:&ES(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@
M240N`$UI<W-I;F<@<F5Q=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I
M;F<@<V5S<VEO;B!)1"X`36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I
M960@1&%T90!-;V1I9GD@55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@
M;V8`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N
M='-E<G)A=`!-;V]N(%!H87-E<P!-;W)E(&9I96QD<R!F;W5N9"!I;B!L:6YE
M("5D('1H86X@=&AE(&5X<&5C=&5D("5D+@!-;W)O8V-O`$UO<W1L>2!#;&5A
M<@!-;W-T;'D@0VQO=61Y`$UO<W1L>2!#;&]U9'D@86YD(%=I;F1Y`$UO<W1L
M>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:6UA<"!52R!M87``375L=&EP;&4@<V5L96-T
M:6]N`$UY($%C8V]U;G0`37D@06-C;W5N="!);F9O<FUA=&EO;@!->2!0;W)T
M86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/5"!!9W)E
M90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`3F5T:&5R
M;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A<&4@0T$@
M4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.971S8V%P
M92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.971S8V%P
M92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@8V]M;65N
M=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V97(`3F5W
M($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S97)N86UE
M("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('!A<W-W;W)D`$YE=R!P87-S
M=V]R9"!W:6QL(&5X<&ER92!O;B`E>"X`3F5W('!A<W-W;W)D<R!D;VXG="!M
M871C:"X`3F5W('=I;F1O=R`H7V)L86YK*0!.97=S`$YE=W-G<F]U<',`3F5X
M=`!.97AT(#0@4&AA<V5S`$YE>'0@;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`
M3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO(&%V86EL86)L92!C;VYF
M:6=U<F%T:6]N(&1A=&$@=&\@<VAO=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V
M86EL86)L92!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N`$YO(&)A
M=&-H('1E;7!L871E+@!.;R!B;&]C:R!E>&ES=',@870@=&AE(')E<75E<W1E
M9"!P;W-I=&EO;@!.;R!C86QE;F1A<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,
M(&%U=&AE;G1I8V%T:6]N+@!.;R!C:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B
M92!A9&1E9"!T;R!T:&ES('!E<FUI<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@
M:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($944"!61E,N`$YO(&-O;F9I
M9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!344P@5D93+@!.
M;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,
M+49I;&4@5D93+@!.;R!C<F5D:70@;&5F="X`3F\@9&5S=&EN871I;VX@<W5P
M<&QI960N`$YO(&9I;&4@=7!L;V%D960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO
M8V%T:6]N(&ES('-E="X`3F\@;&]C871I;VX@<')O=FED960N`$YO(&UE<W-A
M9V4@<W5P<&QI960N`$YO(&YA;64@<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E
M8VEF:65D+@!.;R!O9F9E;G-I=F4@9F]R='5N97,`3F\@<&%S<W=O<F0@<')O
M=FED960@9F]R($A45%`@875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R
M;W9I9&5D(&9O<B!)34%0(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P
M<F]V:61E9"!F;W(@2V5R8F5R;W,@875T:&5N=&EC871I;VXN`$YO('!A<W-W
M;W)D('!R;W9I9&5D(&9O<B!,;V=I;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S
M<W=O<F0@<')O=FED960@9F]R(%!!4U-71"!A=71H96YT:6-A=&EO;BX`3F\@
M<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A=&EO;BX`3F\@
M<&%T:"!T;R!T:&4@3W!E;E-33"!B:6YA<GD@<')O=FED960N(%1H92!/<&5N
M4U-,(&)I;F%R>2!I<R!N96-E<W-A<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@
M9&%T82X`3F\@<&5N9&EN9R!S:6=N=7!S+@!.;R!Q=6]T82!S970N`$YO(')U
M;&5S`$YO('-E<&%R871O<B!S<&5C:69I960N`$YO('-I9&5S`$YO('-U8V@@
M9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E
M(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N
M9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD
M<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y
M`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E
M<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;&0@86YD
M(&YE=R!P87-S=V]R9',@;75S="!B92!D:69F97)E;G0N`$]L9"!P87-S=V]R
M9`!/;&0@<&%S<W=O<F0@:7,@;F]T(&-O<G)E8W0N`$]M86X`3VYL>2!)34%0
M('-E<G9E<G,@<W5P<&]R="!S:&%R960@9F]L9&5R<RX`3VYL>2!O9F9E;G-I
M=F4@9F]R='5N97,`3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO=V5D+@!/
M;FQY('1H92!O=VYE<B!O<B!S>7-T96T@861M:6YI<W1R871O<B!M87D@8VAA
M;F=E(&]W;F5R<VAI<"!O<B!O=VYE<B!P97)M:7-S:6]N<R!F;W(@82!S:&%R
M90!/<&5N(&EN(&$@;F5W('=I;F1O=P!/<&5N4U-,(&5R<F]R.B!#;W5L9"!N
M;W0@97AT<F%C="!D871A(&9R;VT@<VEG;F5D(%,O34E-12!P87)T+@!/<&5N
M<R!T:&ES(&QI;FL@:6X@82!N97<@=VEN9&]W`$]P97)A=&EN9R!3>7-T96T`
M3W!T:6]N<P!/<'1I;VYS(&9O<B`E<P!/<F1E<F5D($QI<W0`3W)G86YI<V%T
M:6]N`$]R9V%N:7-A=&EO;F%L(%5N:70`3W)G86YI>FEN9P!/<FEG:6YA;"!A
M<'!L:6-A=&EO;B!T96UP;&%T90!/<FEG:6YA;"!T96UP;&%T97,@:6X@)7,Z
M`$]T:&5R`$]T:&5R($EN9F]R;6%T:6]N`$]W;F5R(%!E<FUI<W-I;VYS`%!!
M32!A=71H96YT:6-A=&EO;B!I<R!N;W0@879A:6QA8FQE+@!014%2.CI-86EL
M(&)A8VME;F0`4$=0($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@
M1&%T80!01U`@4'5B;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A
M`%!(4"!#;V1E`%!(4"!3:&5L;`!032!,:6=H="!286EN`%!-(%)A:6X`4$T@
M4VAO=V5R<P!032!3;F]W`%!-(%-N;W<@4VAO=V5R<P!032!3=6X`4$T@5"U3
M=&]R;7,`4$]325@@97AT96YS:6]N(&ES(&UI<W-I;F<`4%](4"!3:&5L;`!0
M861D:6YG`%!A:VES=&%N`%!A;&%U`%!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@
M3V-C=7!I960`4&%N86UA`%!A<'5A($YE=R!'=6EN96$`4&%R86=U87D`4&%R
M=&QY($-L;W5D>0!087-S=V]R9`!087-S=V]R9"!C:&%N9V5D('-U8V-E<W-F
M=6QL>2X`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D(')E<75I<F5D(&9O
M<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D('=I=&@@8V]N9FER
M;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W;W)D<R!M=7-T(&UA
M=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0871H`%!E;F1I;F<@
M4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-86EN=&5N86YC92!/
M<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L
M;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N("(E<R(@;F]T(&1E;&5T960N
M`%!E<FUI<W-I;VX@1&5N:65D`%!E<FUI<W-I;VYS`%!E<FUI<W-I;VYS($%D
M;6EN:7-T<F%T:6]N`%!E<G-O;F%L($EN9F]R;6%T:6]N`%!E<G4`4&5T<P!0
M:&EL:7!P:6YE<P!0:&]N90!0:&]T;W,`4&ET8V%I<FX`4&EX96QS`%!L871I
M='5D97,`4&QE87-E(&-L:6-K(&EN=&\@<V]M92!C96QL`%!L96%S92!C;VYF
M:7)M('1H870@>6]U('=A;G0@=&\@<F5M;W9E('1H:7,@96QE;65N=#H`4&QE
M87-E(&-O;F9I<FT@=&AA="!Y;W4@=V%N="!T;R!U;FQI;FL@=&AI<R!E;&5M
M96YT+@!0;&5A<V4@96YT97(@82!M;VYT:"!A;F0@82!Y96%R+@!0;&5A<V4@
M96YT97(@82!N86UE(&9O<B!T:&4@;F5W(&-A=&5G;W)Y.@!0;&5A<V4@96YT
M97(@82!V86QI9"!)4"!A9&1R97-S+@!0;&5A<V4@96YT97(@82!V86QI9"!D
M871E+"!C:&5C:R!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H+@!0
M;&5A<V4@96YT97(@82!V86QI9"!T:6UE+@!0;&5A<V4@<')O=FED92!A('-U
M;6UA<GD@;V8@=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E
M<FYA;64@86YD('!A<W-W;W)D`%!L96%S92!R96%D('1H92!F;VQL;W=I;F<@
M=&5X="X@66]U($U54U0@86=R964@=VET:"!T:&4@=&5R;7,@=&\@=7-E('1H
M92!S>7-T96TN`%!L96%S92!T>7!E('1H92!N97<@8V%T96=O<GD@;F%M93H`
M4&]L86YD`%!O;&ET:6-S`%!O;&QS`%!O<G1U9V%L`%!O<VET:6]N:6YG(&]F
M('1H:7,@:6UA9V4`4&]S:71I;VYI;F<@;V8@=&AI<R!T86)L90!0;W-T('1O
M('1H:7,@9F]L9&5R("AN;W0@96YF;W)C960@8GD@24U!4"D`4')E8VEP:71A
M=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B``4')E8VEP:71A=&EO;CQB<B`O
M/F-H86YC90!0<F5F<U]L9&%P.B!297%U:7)E9"!,1$%0(&5X=&5N<VEO;B!N
M;W0@9F]U;F0N`%!R969S7W-E<W-I;VXZ(%)E<75I<F5D('-E<W-I;VX@97AT
M96YS:6]N(&YO="!F;W5N9"X`4')E<W-U<F4`4')E<W-U<F4@870@<V5A(&QE
M=F5L.B``4')E<W-U<F4Z(`!0<F5V:65W`%!R979I97<@=&AE(&EM86=E(&EN
M(&$@;F5W('=I;F1O=P!0<F5V:6]U<R!O<'1I;VYS`%!R:6YT(&1O8W5M96YT
M`%!R:79A=&4@2V5Y`%!R;V)L96T`4')O8FQE;2!$97-C<FEP=&EO;@!0<F]J
M96-T<P!0<F]M<'0@=&5X=`!0=6)L:6,@2V5Y`%!U8FQI8R!+97D@06QG;W)I
M=&AM`%!U8FQI8R!+97D@26YF;P!0=6)L:6,O4')I=F%T92!K97EP86ER(&YO
M="!G96YE<F%T960@<W5C8V5S<V9U;&QY+@!0=65R=&\@4FEC;P!0=7)G92!M
M97-S86=E<P!1871A<@!1=65R>0!1=6]T80!24T$@4'5B;&EC($ME>2`H)60@
M8FET*0!2861I;R!S96QE8W1I;VX`4F%I;@!286EN($5A<FQY`%)A:6X@3&%T
M90!286EN(%-H;W=E<@!286EN(&%N9"!3;F]W`%)A:6X@=&\@4VYO=P!286YD
M;VT@1F]R='5N90!2871I;P!296%D`%)E860@;65S<V%G97,`4F5A;&QY(&1E
M;&5T92`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`4F5A
M;&QY(')E;6]V92!U<V5R(&1A=&$@9F]R('5S97(@)7,_(%1H:7,@;W!E<F%T
M:6]N(&-A;FYO="!B92!U;F1O;F4N`%)E9&]E<R!Y;W5R(&QA<W0@86-T:6]N
M`%)E9G)E<V@`4F5F<F5S:"!$>6YA;6EC($UE;G4@16QE;65N=',Z`%)E9G)E
M<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N<VAI<"!"<F]W<V5R`%)E
M;&]A9`!296UA<FMS`%)E;6]T92!397)V97)S`%)E;6]T92!54DP@*&AT='`Z
M+R]W=W<N97AA;7!L92YC;VTO:&]R9&4I.@!296UO=F4`4F5M;W9E($)L;V-K
M`%)E;6]V92!C;VQU;6X`4F5M;W9E(&9O<FUA='1I;F<`4F5M;W9E('!A:7(`
M4F5M;W9E('-A=F5D('-C<FEP="!F<F]M('-E<G9E<B=S('1E;7!O<F%R>2!D
M:7)E8W1O<GDN`%)E;6]V92!T:&4`4F5M;W9E('1H:7,@;F]D92!F<F]M('1H
M92!D;V-U;65N=`!296UO=F4@=7-E<@!296UO=F4@=7-E<CH@)7,`4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B``
M4F5Q=65S=&5D('-E<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+@!297%U:7)E
M9"`B)7,B(&YO="!S<&5C:69I960@:6X@)7,@8V]N9FEG=7)A=&EO;BX`4F5Q
M=6ER960@(B5S(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N
M+@!297%U:7)E9"`B)7,B(&YO="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO
M;BX`4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@
M66]U<B!087-S=V]R9`!297-T;W)E($QA<W0@475E<GD`4F5S=6QT<P!2971U
M<FX@=&\@3W!T:6]N<P!2971Y<&4@;F5W('!A<W-W;W)D`%)E=6YI;VX`4F5V
M97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%)I
M9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W(%!R
M;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E($QE
M9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T:65S
M`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL(')O
M=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C;VQU
M;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N;'D`
M4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T;V=R
M87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!305-,
M(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S86=I
M;F<`4U%,(%-H96QL`%-13"!S=&%T96UE;G0@9F]R('9A;'5E(&QO;VMU<',`
M4U-(`%-50T-%4U,`4U]13"!3:&5L;`!380!386EN="!(96QE;F$`4V%I;G0@
M2VET=',@86YD($YE=FES`%-A:6YT($QU8VEA`%-A:6YT(%!I97)R92!A;F0@
M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,`4V%M
M92!F<F%M92`H7W-E;&8I`%-A;6]A`%-A;B!-87)I;F\`4V%O(%1O;64@86YD
M(%!R:6YC:7!E`%-A=&5L;&ET92!0<F]V:61E<@!3875D:2!!<F%B:6$`4V%V
M90!3879E("(E<R(`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G96YE<F%T
M960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U<B!S97)V
M97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF:6=U<F%T
M:6]N+@!3879E9"!S971U<"!U<&=R861E('-C<FEP="!T;SH@(B5S(BX`4V-A
M='1E<F5D(%0M4W1O<FUS`%-C:65N8V4`4V5A<F-H`%-E87)C:"!%;F=I;F5S
M`%-E;&5C="!&:6QE<P!396QE8W0@82!D871E`%-E;&5C="!A(&=R;W5P('1O
M(&%D9`!396QE8W0@82!N97<@;W=N97(`4V5L96-T(&$@<V5R=F5R`%-E;&5C
M="!A('5S97(@=&\@861D`%-E;&5C="!A;&P`4V5L96-T(&%L;"!D871E(&-O
M;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T(&YO;F4`4V5L96-T
M('1H92!C:&%R86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W
M+B!9;W4@8V%N('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T
M97AT(&%R96$N`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T
M:&4@9&%T92!F;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@
M=&\@8VAA;F=E.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@
M=&AE('1I;64@9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`
M4V5L96-T('EO=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R
M960@;&%N9W5A9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N
M96=A;`!396YS;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O
M`%-E<FEA;"!.=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL
M86)L92X`4V5S<VEO;B!!9&UI;@!397-S:6]N($E$(&5X<&ER960N`%-E<W-I
M;VYS`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@=&\@<F5S970@>6]U
M<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N`%-E="!U<"!R96UO
M=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S<R!F<F]M('EO=7(@
M<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A9V4L('1I;65Z;VYE
M(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T=7`@87!P;&EC871I
M;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG+"!A;F0@;W1H97(@
M9&ES<&QA>2!O<'1I;VYS+@!3971U<`!3971U<"!U<&=R861E('-C<FEP=',@
M879A:6QA8FQE`%-E=F5R86P@;&]C871I;VYS('!O<W-I8FQE('=I=&@@=&AE
M('!A<F%M971E<CH@`%-E>6-H96QL97,`4VAO<'!I;F<`4VAO<G0@4W5M;6%R
M>0!3:&]U;&0@86-C97-S(&ME>7,@8F4@9&5F:6YE9"!F;W(@;6]S="!L:6YK
M<S\`4VAO=P!3:&]W(&1I9F9E<F5N8V5S(&)E='=E96X@8W5R<F5N=&QY('-A
M=F5D(&%N9"!T:&4@;F5W;'D@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN`%-H
M;W<@;&%S="!L;V=I;B!T:6UE('=H96X@;&]G9VEN9R!I;C\`4VAO=R!O<'1I
M;VX@=&\@:V5E<"!O<FEG:6YA;`!3:&]W('!I8VME<@!3:&]W('1A8FQE(&]P
M97)A=&EO;G,@;65N=2!B87(_`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE
M9G0_`%-H;W<@=&AE(%1A8FQE($-E;&P@4')O<&5R=&EE<R!D:6%L;V<`4VAO
M=R!T:&4@5&%B;&4@4')O<&5R=&EE<R!D:6%L;V<`4VAO=R!T:&4@5&%B;&4@
M4F]W(%!R;W!E<G1I97,@9&EA;&]G`%-H;W<@=&AE(&EM86=E('!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=7!L;V%D`%-H;W=E<G,`4VAO=V5R<R!%87)L>0!3
M:&]W97)S($QA=&4`4VAO=V5R<R!I;B!T:&4@5FEC:6YI='D`4VAR:6YK`%-H
M<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE
M('=A>2!F:7)S=`!3:65R<F$@3&5O;F4`4VEG;B!U<`!3:6=N871U<F4`4VEG
M;F%T=7)E($%L9V]R:71H;0!3:6YG87!O<F4`4VEZ90!3:VEP($UA:6YT96YA
M;F-E`%-L;W9A:VEA`%-L;W9E;FEA`%-N;W<`4VYO=R!3:&]W97(`4VYO=R!3
M:&]W97)S`%-N;W<@4VAO=V5R<R!%87)L>0!3;F]W(%-H;W=E<G,@3&%T90!3
M;F]W(&1E<'1H.B``4VYO=R!E<75I=F%L96YT(&EN('=A=&5R.B``4V]L;VUO
M;B!)<VQA;F1S`%-O;6%L:6$`4V]N9W,@)B!0;V5M<P!3;W)T(&]R9&5R('-E
M;&5C=&EO;@!3;W5R8V4@861D<F5S<P!3;W5T:"!!9G)I8V$`4V]U=&@@175R
M;W!E86X@*$E33RTX.#4Y+3,I`%-O=71H($=E;W)G:6$@86YD('1H92!3;W5T
M:"!386YD=VEC:"!)<VQA;F1S`%-O=71H97)N($AE;6ES<&AE<F4`4W!A8V4@
M8F5T=V5E;B!A9&IA8V5N="!C96QL<P!3<&%C92!B971W965N(&-O;G1E;G0@
M86YD(&)O<F1E<B!I;B!C96QL`%-P86-E<@!3<&%C:6YG`%-P86-I;F<@86YD
M('!A9&1I;F<`4W!A:6X`4W!A;0!3<&5C:6%L($-H87)A8W1E<B!);G!U=`!3
M<&QI="!C96QL`%-P;&ET(&-O;'5M;@!3<&QI="!R;W<`4W!O<G1S`%-R:2!,
M86YK80!3=&%N9&%R9`!3=&%R(%1R96L`4W1A<G0@>65A<@!3=&%T92!O<B!0
M<F]V:6YC90!3=&%T=7,`4W1O<F%G92!F;W)M870`4W1R965T($%D9')E<W,`
M4W1R:6ME=&AR;W5G:`!3=')I;F<@;&ES=`!3=')I<"!D;VUA:6X@9G)O;2!T
M:&4@861D<F5S<P!3='EL92!;0U-370!3=0!3=6)D:7)E8W1O<GD@(B5S(B!N
M;W0@9F]U;F0N`%-U8FIE8W0`4W5B;6ET`%-U8FUI='1E9"!R97%U97-T('1O
M(&%D9"`B)7,B('1O('1H92!S>7-T96TN(%EO=2!C86YN;W0@;&]G(&EN('5N
M=&EL('EO=7(@<F5Q=65S="!H87,@8F5E;B!A<'!R;W9E9"X`4W5B<V-R:7!T
M`%-U8V-E<W,`4W5C8V5S<V9U;&QY(&%D9&5D("(E<R(@=&\@=&AE('-Y<W1E
M;2X`4W5C8V5S<V9U;&QY(&-L96%R960@9&%T82!F;W(@=7-E<B`B)7,B(&9R
M;VT@=&AE('-Y<W1E;2X`4W5C8V5S<V9U;&QY(&1E;&5T960@(B5S(BX`4W5C
M8V5S<V9U;&QY(')E;6]V960@(B5S(B!F<F]M('1H92!S>7-T96TN`%-U8V-E
M<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N+B!296QO860@=&\@<V5E
M(&-H86YG97,N`%-U8V-E<W-F=6QL>2!S879E9"!B86-K=7`@8V]N9FEG=7)A
M=&EO;BX`4W5C8V5S<V9U;&QY('-A=F5D('1H92!B86-K=7`@8V]N9FEG=7)A
M=&EO;B!F:6QE("5S+@!3=6-C97-S9G5L;'D@=7!D871E9"`B)7,B`%-U8V-E
M<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E`%-U;B!3
M970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E.B``4W5N
M<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA;64`4W5R
M;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3=V5D96X`
M4W=I='IE<FQA;F0`4WEN8R!L;V<@9&5L971E9`!3>6YC34P`4WEN=&%X(&5R
M<F]R(&EN('-E87)C:"!T97)M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T
M;W)M`%0M4W1O<FT@86YD(%=I;F1Y`%0M4W1O<FUS`%0M4W1O<FUS($5A<FQY
M`%135B!F:6QE`%1A8FQE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@4V5T`%1A
M8FQE('!R;W!E<G1I97,`5&%I=V%N`%1A:7=A;BP@4')O=FEN8V4@;V8@0VAI
M;F$`5&%J:6MI<W1A;@!486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F`%1A
M<F=E=#H`5&%S:W,`5&5L97!H;VYE($YU;6)E<@!496UP(&9O<B!L87-T(&AO
M=7(Z(`!496UP97)A='5R90!496UP97)A='5R93H@`%1E;7!E<F%T=7)E/&)R
M("\^*"5S2&DE<R\E<TQO)7,I("9D96<[)7,`5&5M<&QA=&4@(B5S(B!N;W0@
M9F]U;F0N`%1E;7!L871E($%D;6EN:7-T<F%T:6]N`%1E>'0`5&5X="!/;FQY
M`%1E>'0@86QI9VX`5&5X='1O<`!4:`!4:&%I("A425,M-C(P*0!4:&%I;&%N
M9`!4:&4@1E10(&5X=&5N<VEO;B!I<R!N;W0@879A:6QA8FQE+@!4:&4@2&ES
M=&]R>2!S>7-T96T@:7,@9&ES86)L960N`%1H92!(;W)D92]+;VQA8B!I;G1E
M9W)A=&EO;B!E;F=I;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!)35-0
M(&QO9R!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960N`%1H92!-86EN=&5N86YC
M93HZ(&-L87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO
M;G,@=VEN9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A
M=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N
M<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE
M(&)O='1O;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N
M;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@
M=&AE(&1A=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D
M9&5D('1O('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I
M9VYA='5R92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE
M9"!M97-S86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE
M<B!N;W0@<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T
M:&4@9&%T86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P
M96-I9FEE9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E
M8W5R92!W96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A
M:6X@82`E<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S
M;VUE("5S('-E='1I;F=S+@!4:&4@9FEL92!C86YN;W0@8F4@8V]P:65D(&]N
M=&\@:71S96QF+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@
M8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@
M=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES
M<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!N=6UB97(@
M;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8RX`5&AE(&]P96YS<VP@;6]D=6QE
M(&ES(')E<75I<F5D(&9O<B!T:&4@2&]R9&5?0W)Y<'1?<VUI;64Z.B!C;&%S
M<RX`5&AE('!R969E<F5N8V4@(B5S(B!C;W5L9"!N;W0@8F4@<V%V960@8F5C
M875S92!I=',@9&%T82!E>&-E961E9"!T:&4@;6%X:6UU;2!A;&QO=V%B;&4@
M<VEZ90!4:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@
M*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN`%1H92!Q=6]T92!C
M:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BX`5&AE(')I
M9VAT(&%N9"!L969T('-I9&5S(&]N;'D`5&AE(')I9VAT+6AA;F0@<VED92!O
M;FQY`%1H92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E
M<BX`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S97)V
M97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T(&9O
M<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@<W!E8VEF:65D(')O=R`H)60I
M(&1O97,@;F]T(&5X:7-T+@!4:&4@<W!E8VEF:65D(')O=R!D;V5S(&YO="!E
M>&ES="X`5&AE('1E;7!O<F%R>2!F:6QE("(E<R(@9&]E<R!N;W0@97AI<W0N
M`%1H92!T97AT('EO=2!E;G1E<F5D(&1I9"!N;W0@;6%T8V@@=&AE('1E>'0@
M;VX@=&AE('-C<F5E;BX`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S(&]N;'D`
M5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@
M<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F:6QE(&-O
M=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K(&ES(&YO
M="!A=F%I;&%B;&4N`%1H96UE<R!D:7)E8W1O<GD@(B5S(B!N;W0@9F]U;F0N
M`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92X`5&AE<F4@87)E(&YO
M('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE9"!I;FQI;F4N`%1H97)E(&%R
M92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H:7,@9FEE;&0N(%EO=2!H879E
M(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U(&UU<W0@96YT97(@;&5S<R!T
M:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M(&%D9&EN9R`B)7,B('1O('1H
M92!S>7-T96TZ("5S`%1H97)E('=A<R!A('!R;V)L96T@8VQE87)I;F<@9&%T
M82!F;W(@=7-E<B`B)7,B(&9R;VT@=&AE('-Y<W1E;3H@`%1H97)E('=A<R!A
M('!R;V)L96T@<F5M;W9I;F<@(B5S(B!F<F]M('1H92!S>7-T96TZ(`!4:&5R
M92!W87,@82!P<F]B;&5M('5P9&%T:6YG("(E<R(Z("5S`%1H97)E('=A<R!A
M('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO
M861E9"X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H92!F:6QE('5P;&]A
M9#H@5&AE("5S('=A<R!L87)G97(@=&AA;B!T:&4@;6%X:6UU;2!A;&QO=V5D
M('-I>F4@*"5D(&)Y=&5S*2X`5&AE<F4@=V%S(&$@<')O8FQE;2!W:71H('1H
M92!F:6QE('5P;&]A9#H@5&AE("5S('=A<R!O;FQY('!A<G1I86QL>2!U<&QO
M861E9"X`5&AE<F4@=V%S(&%N(&5R<F]R(&1I<W!L87EI;F<@=&AI<R!M97-S
M86=E('!A<G0`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@8V]N
M=&%C="!D871A+@!4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!I
M0V%L96YD87(@9&%T82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EN('1H92!C;VYF
M:6=U<F%T:6]N(&9O<FTN(%!E<FAA<',@>6]U(&QE9G0@;W5T(&$@<F5Q=6ER
M960@9FEE;&0N`%1H97)E('=A<R!A;B!E<G)O<B!P97)F;W)M:6YG('1H92!S
M<&5C:69I960@861D<F5S<R!B;V]K(&9U;F-T:6]N+B!0;&5A<V4@=')Y(&%G
M86EN(&QA=&5R+@!4:&5R92!W87,@86X@97)R;W(@=7!D871I;F<@=&AE(&-O
M;G1A8W0@9&5T86EL<RX@4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BX`5&AI<R!)34%0('-E<G9E<B!D;V5S
M(&YO="!S=7!P;W)T('-H87)I;F<@9F]L9&5R<RX`5&AI<R!D;V5S(&YO="!A
M<'!E87(@=&\@8F4@82!V86QI9"!R87(@87)C:&EV92X`5&AI<R!D;V5S(&YO
M="!A<'!E87(@=&\@8F4@82!V86QI9"!Z:7`@9FEL92X`5&AI<R!D;V5S(&YO
M="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N`%1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('1H<F]U9V@@=&AE($-L:6-K
M871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O;2D@9V%T97=A>2P@=7-I;F<@
M=&AE($A45%`@05!)`%1H:7,@9')I=F5R(&%L;&]W<R!S96YD:6YG(&]F(&UE
M<W-A9V5S('1H<F]U9V@@=&AE(%=)3B`H:'1T<#HO+W=I;G!L8RYC;VTI(&=A
M=&5W87DL('5S:6YG('1H92!(5%10($%020!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!S;7,R96UA:6P@*&AT
M='`Z+R]S;7,R96UA:6PN8V]M*2!G871E=V%Y+"!U<VEN9R!T:&4@2%144"!!
M4$D`5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S<V%G97,@=FEA
M(%--5%`@=&AR;W5G:"!T:&4@5F]D869O;F4@271A;'D@9V%T97=A>2P@;VYL
M>2!T;R!6;V1A9F]N92!N=6UB97)S+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A
M8V-O=6YT('=I=&@@5F]D869O;F4@271A;'D@*&AT='`Z+R]W=W<N,3DP+FET
M*2X`5&AI<R!F:65L9"!I<R!R97%U:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL
M>2!C;VYT86EN(&EN=&5G97)S+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A
M:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY
M(&-O;G1A:6X@;V-T86P@=F%L=65S+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C
M;VUM82!O<B!S<&%C92!S97!A<F%T960@;&ES="!O9B!I;G1E9V5R<P!4:&ES
M(&9I96QD(&UU<W0@8F4@82!V86QI9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S
M="!C;VYT86EN(&$@8V]L;W(@8V]D92!I;B!T:&4@4D="($AE>"!F;W)M870L
M(&9O<B!E>&%M<&QE("<C,3(S-&%F)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y
M(&)E96X@<')O8V5S<V5D+@!4:&ES(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@
M1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL
M;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N9&5R<W1A;F1S('1H92!+
M;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L:7-T(&]F('-U8V@@96UA
M:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,`5&AI<R!M97-S86=E('=A<R!W
M<FET=&5N(&EN(&$@8VAA<F%C=&5R('-E="`H)7,I(&]T:&5R('1H86X@>6]U
M<B!O=VXN`%1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES
M('-E<G9E<B!C86XG="!U;F-O;7!R97-S('II<"!A;F0@9WII<"!F:6QE<RX`
M5&AI<R!S>7-T96T@:7,@8W5R<F5N=&QY(&1E86-T:79A=&5D+@!4:&ES('9A
M;'5E(&UU<W0@8F4@82!N=6UB97(N`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L
M;&5D(&9R;VT@86X@3W!T:6]N<R!W:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I
M;64`5&EM92!4<F%C:VEN9P!4:6UE(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4
M:6UO<BU,97-T90!4:71L90!4:71L92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C
M="!M=6QT:7!L92!I=&5M<RP@:&]L9"!D;W=N('1H92!#;VYT<F]L("A00RD@
M;W(@0V]M;6%N9"`H36%C*2!K97D@=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O
M9V=L92!(5$U,(%-O=7)C90!4;V=O`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`
M5&]O(&UA;GD@:6YV86QI9"!L;V=I;G,@9'5R:6YG('1H92!L87-T(&UI;G5T
M97,N`%1O<`!4;W`@9G)A;64@*%]T;W`I`%1R86YS;&%T:6]N<P!4<FEN:61A
M9"!A;F0@5&]B86=O`%1R=64@;W(@9F%L<V4`5'4`5'5N:7-I80!4=7)K97D`
M5'5R:VES:"`H25-/+3@X-3DM.2D`5'5R:VUE;FES=&%N`%1U<FMS(&%N9"!#
M86EC;W,@27-L86YD<P!4=79A;'4`5'EP92!Y;W5R(&-H;VEC93H@`%4N5BX@
M:6YD97@Z(`!54DP`55),(&9O<B!Y;W5R('-C<FEP="!D96QI=F5R>2!S=&%T
M=7,@<F5P;W)T`%523#H`56=A;F1A`%5K<F%I;F4`56YA8FQE('1O(&%C8V5S
M<R!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@861D(&5X=')A('5S97(@:6YF
M;W)M871I;VX@=VAE;B!S:6=N:6YG('5P+@!5;F%B;&4@=&\@8VAA;F=E('!E
M<FUI<W-I;VX@9F]R(%9&4R!F:6QE("(E<R(N`%5N86)L92!T;R!C:&%N9V4@
M<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!C:&%N
M9V4@=&\@)7,N`%5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@(B5S(BX`
M56YA8FQE('1O(&-H96-K(&9I;&4@<VEZ92!O9B`B)7,O)7,B+@!5;F%B;&4@
M=&\@8V]N;F5C="!T;R!344P@<V5R=F5R+@!5;F%B;&4@=&\@8V]N;F5C="!W
M:71H(%-33"X`56YA8FQE('1O(&-O<'D@5D93(&9I;&4N`%5N86)L92!T;R!C
M<F5A=&4@5D93(&1I<F5C=&]R>2`B)7,B+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GDN`%5N86)L92!T;R!C<F5A=&4@5D93(&9I;&4N`%5N86)L
M92!T;R!C<F5A=&4@5D93(&9O;&1E<B`B)7,B+@!5;F%B;&4@=&\@8W)E871E
M(&5M<'1Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5C;VUP<F5S<R!D871A+@!5
M;F%B;&4@=&\@9&5L971E("(E<R(L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M
M<'1Y+@!5;F%B;&4@=&\@9&5L971E("(E<R(Z("5S+@!5;F%B;&4@=&\@9&5L
M971E("5S+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>0!5;F%B;&4@=&\@
M9&5L971E(%9&4R!D:7)E8W1O<GD@<F5C=7)S:79E;'DN`%5N86)L92!T;R!D
M96QE=&4@5D93(&1I<F5C=&]R>2X`56YA8FQE('1O(&1E;&5T92!61E,@9&ER
M96-T;W)Y.B`E<RX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92`B)7,B+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!F:6QE+@!5;F%B;&4@=&\@9&5L971E(%9&
M4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@<F5C=7)S:79E
M;'DZ("5S+@!5;F%B;&4@=&\@9&5T97)M:6YE(&-U<G)E;G0@9&ER96-T;W)Y
M+@!5;F%B;&4@=&\@97AT<F%C="!C97)T:69I8V%T92!D971A:6QS`%5N86)L
M92!T;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+@!5;F%B;&4@=&\@;6]V
M92!61E,@9FEL92X`56YA8FQE('1O(&]P96X@5D93(&9I;&4@(B5S(BX`56YA
M8FQE('1O(&]P96X@5D93(&9I;&4@9F]R('=R:71I;F<N`%5N86)L92!T;R!O
M<&5N(%9&4R!F:6QE+@!5;F%B;&4@=&\@;W!E;B!C;VUP<F5S<V5D(&%R8VAI
M=F4N`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE
M9"DN`%5N86)L92!T;R!R96%D(%9&4R!F:6QE("AG971&:6QE4VEZ92@I(&9A
M:6QE9"DN`%5N86)L92!T;R!R96%D(&9I;&4Z(`!5;F%B;&4@=&\@<F5A9"!T
M:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@)7,@=&\@
M)7,Z(&1E<W1I;F%T:6]N(&9O;&1E<B!A;')E861Y(&5X:7-T<P!5;F%B;&4@
M=&\@<F5N86UE(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!R96YA;64@5D93
M(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RX`56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92X`56YA8FQE('1O(')U;B`G;6MI<V]F<R<N`%5N
M86)L92!T;R!T<F%N<VQA=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N86)L92!T
M;R!W<FET92!61E,@9FEL92`B)7,B+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I
M;&4@*&-O<'DH*2!F86EL960I+@!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@
M9&%T82X`56YA8FQE('1O('=R:71E(%9&4R!F:6QE+"!Q=6]T82!W:6QL(&)E
M(&5X8V5E9&5D+@!5;F1E<FQI;F4`56YD;R!#:&%N9V5S`%5N9&]E<R!Y;W5R
M(&QA<W0@86-T:6]N`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M;VX@8V]N;F5C=&EO;CH@`%5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z(`!5;F9I;&5D`%5N:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%
M;6ER871E<P!5;FET960@2VEN9V1O;0!5;FET960@4W1A=&5S`%5N:71E9"!3
M=&%T97,@36EN;W(@3W5T;'EI;F<@27-L86YD<P!5;FET<P!5;FMN;W=N`%5N
M:VYO=VX@87!I;7-G:60@*$%022!-97-S86=E($E$*2X`56YK;F]W;B!C;&EM
M<V=I9"`H0VQI96YT($UE<W-A9V4@240I+@!5;FMN;W=N(&QO8V%T:6]N('!R
M;W9I9&5D+@!5;FMN;W=N('5S97)N86UE(&]R('!A<W-W;W)D+@!5;FQI;FL@
M=&AE(&-U<G)E;G0@96QE;65N=`!5;FYA;65D`%5N<')I=FEL96=E9"!S8W)I
M<'1S(&-A;FYO="!A8V-E<W,@0W5T+T-O<'DO4&%S=&4@<')O9W)A;6%T:6-A
M;&QY(&9O<B!S96-U<FET>2!R96%S;VYS+B`@0VQI8VL@3TL@=&\@<V5E(&$@
M=&5C:&YI8V%L(&YO=&4@870@;6]Z:6QL82YO<F<@=VAI8V@@<VAO=W,@>6]U
M(&AO=R!T;R!A;&QO=R!A('-C<FEP="!T;R!A8V-E<W,@=&AE(&-L:7!B;V%R
M9"X`56YS970@8V]L;W(`56YS=7!P;W)T960@17AT96YS:6]N`%5P9&%T90!5
M<&1A=&4@)7,`57!D871E('5S97(`57!D871E9"`B)7,B+@!5<&=R861E('-C
M<FEP="!D96QE=&5D+@!5<&QO860`57!L;V%D960@86QL(&%P<&QI8V%T:6]N
M('-E='5P(&9I;&5S('1O('1H92!S97)V97(N`%5P<&5R(&QA=&EN(&QE='1E
M<G,`57!P97(@<F]M86X@;G5M8F5R<P!5<G5G=6%Y`%5S92!#=7)R96YT.B`E
M<P!5<V4@4U-,`%5S92!I9B!N86UE+W!A<W-W;W)D(&ES(&1I9F9E<F5N="!F
M;W(@24U34"!S97)V97(N`%5S97(`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E
M9"!F;W(@)7,N`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S
M97(@4F5G:7-T<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I
M<V%B;&5D(&9O<B!T:&ES('-I=&4N`%5S97(@86-C;W5N="!N;W0@9F]U;F0`
M57-E<FYA;64`57-E<FYA;64@(B5S(B!A;')E861Y(&5X:7-T<RX`57-E<FYA
M;64Z`%5S97)N86UE.B``57-E<G,@:6X@=&AE('-Y<W1E;3H`57IB96MI<W1A
M;@!61E,@9&ER96-T;W)Y(&1O97,@;F]T(&5X:7-T+@!686-A=&EO;@!686QI
M9"!L;V-A=&EO;G,@9F]U;F0@:6YC;'5D93H@`%9A;&ED:71Y`%9A;'5E(&EN
M(&UI;G5T97,@9G)O;2!N;W<N`%9A;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@
M;&5N9W1H(&]F("5S+@!686QU97,`5F%L=65S('1O('-E;&5C="!F<F]M`%9A
M;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<FEF:6-A=&EO;B!F86EL960@
M+2!T:&ES(&UE<W-A9V4@;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+@!6
M97)S:6]N`%9E<G-I;VX@0V]N=')O;`!697)T:6-A;"!A;&EG;@!697)T:6-A
M;"!P861D:6YG`%9E<G1I8V%L.@!697)Y($AI9V@`5FEE="!.86T`5FEE=&YA
M;65S92`H5DE30TE)*0!6:65W("5S`%9I97<@86X@97AT97)N86P@=V5B('!A
M9V4`5FEE=R!A<R`E<P!6:7)G:6X@27-L86YD<RP@0G)I=&ES:`!6:7)G:6X@
M27-L86YD<RP@52Y3+@!6:7-I8FEL:71Y`%9I<VEB:6QI='DZ(`!6;V1A9F]N
M92!)=&%L>2!V:6$@4TU44`!705).`%=!4DY)3D<A(2$@4D5-3U9%(%-#4DE0
M5"!-04Y504Q,62!&4D]-("5S+@!724X@=FEA($A45%``5V%L;&ES(&%N9"!&
M=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C87-T`%=E871H97(@9&%T
M82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`5V5B(%-I=&4`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE+"`E<P!797-T97)N("A)
M4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ-2D`5V5S=&5R;B!386AA
M<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@9&ES<&QA>2!A9G1E<B!L
M;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H87)A8W1E<C\`5VAA="!I
M<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&5R96ES($%U<W1R86QI82!M87``
M5VAI8V@@<&AA<V5S`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@
M4FEC:"!497AT(&5D:71O<BX`5VED=&@`5VED=&@@:6X@0U-3('5N:71S`%=I
M9'1H(&]F('1H92`E<R!M96YU(&]N('1H92!L969T("AT86ME<R!E9F9E8W0@
M;VX@;F5X="!L;V<M:6XI.@!7:61T:"!O9B!T:&4@=&%B;&4`5VED=&@@=6YI
M=`!7:61T:#H`5VEK:0!7:6YD`%=I;F0@16%R;'D`5VEN9"!S<&5E9"!I;B!K
M;F]T<P!7:6YD.@!7:6YD.B``5VES9&]M`%=I<VAL:7-T`%=O<FL`5V]R:R!!
M9&1R97-S`%=O<FL@4&AO;F4`5W)O;F<@;G5M8F5R(&]F(&9I96QD<R!I;B!L
M:6YE("5D+B!%>'!E8W1E9"`E9"P@9F]U;F0@)60N`%=R;VYG(&YU;6)E<B!O
M9B!F:65L9',N($5X<&5C=&5D("5D+"!F;W5N9"`E9"X`5W)O;F<@;V9F<V5T
M("5D('=H:6QE(')E861I;F<@82!61E,@9FEL92X`6"U2968`6#4P.78S($)A
M<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4`6#4P
M.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@4W5B:F5C="!+
M97D@261E;G1I9FEE<@!8-3`Y=C,@97AT96YS:6]N<P!960!965E9`%EA:&]O
M(2!M87``665A<FQY`%EE;65N`%EE<P!997,L($D@06=R964`66]U(&%R92!I
M;B!415A4($U/1$4N("!5<V4@=&AE(%L\/ET@8G5T=&]N('1O('-W:71C:"!B
M86-K('1O(%=94TE764<N`%EO=2!A<F4@;F]T(&%L;&]W960@=&\@8W)E871E
M(&UO<F4@=&AA;B`E9"!B;&]C:W,N`%EO=2!A<F4@;F]T(&%U=&AE;G1I8V%T
M960N`%EO=2!C86YN;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R
M(&9U;&P@;F%M92X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I;"!A
M9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE(&EM
M<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN("5S
M+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N=&5R
M(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET:"!A
M;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI;F<@
M<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9;W4@
M;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3:6=N
M=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U(&UU
M<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N9"!T
M:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@=VAE
M<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@<V5R
M=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M92!T
M;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O(&%D
M9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E+@!9
M;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO=2!M
M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U(&YE960@=&\@<')O
M=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<@!9;W5R("5S('-E<W-I;VX@
M:&%S(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!
M9&1R97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9
M;W5R($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E
M9VEN;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S
M96-U<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R
M(&%U=&AE;G1I8V%T:6]N(&)A8VME;F0@9&]E<R!N;W0@<W5P<&]R="!A9&1I
M;F<@=7-E<G,N($EF('EO=2!W:7-H('1O('5S92!(;W)D92!T;R!A9&UI;FES
M=&5R('5S97(@86-C;W5N=',L('EO=2!M=7-T('5S92!A(&1I9F9E<F5N="!A
M=71H96YT:6-A=&EO;B!B86-K96YD+@!9;W5R(&%U=&AE;G1I8V%T:6]N(&)A
M8VME;F0@9&]E<R!N;W0@<W5P<&]R="!L:7-T:6YG('5S97)S+"!O<B!T:&4@
M9F5A='5R92!H87,@8F5E;B!D:7-A8FQE9"!F;W(@<V]M92!O=&AE<B!R96%S
M;VXN`%EO=7(@8G)O=W-E<B!A<'!E87)S('1O(&AA=F4@8VAA;F=E9"!S:6YC
M92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C
M="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BX`66]U<B!B
M<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@=&AI<R!F96%T=7)E+@!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES('!R:6YT(&]P=&EO;BX@4')E
M<W,@0V]N=')O;"]#;VUM86YD("L@4"!T;R!P<FEN="X`66]U<B!C=7)R96YT
M('1I;64@>F]N93H`66]U<B!D969A=6QT(&ED96YT:71Y(&AA<R!B965N(&-H
M86YG960N`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z
M`%EO=7(@;&]G:6X@:&%S(&5X<&ER960N`%EO=7(@;F5W('!A<W-W;W)D(&9O
M<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O
M<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@
M:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S
M970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E
M;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@
M<&%S<W=O<F0@:&%S(&5X<&ER960N`%EO=7(@<F5M;W1E('-E<G9E<G,Z`%EU
M9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E(%%U
M;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!497AT
M("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@;V8@
M)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E(%)O
M=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@:6X`
M7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S:6]N
M<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S+BXN
M`%]5<V5R<P!A9&1R97-S(&)O;VL`861D<F5S<V5E('5N:VYO=VX`8V%L96YD
M87(`8V%L;0!C86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N
M(&EN<'5T`&-L:6-K(&AE<F4`8V]M;6%N9"!L:6YE('5S86=E(&5R<F]R`&-O
M;F9I9W5R871I;VX@97)R;W(`8W)I=&EC86P@<WES=&5M(&9I;&4@;6ES<VEN
M9P!D871A(&9O<FUA="!E<G)O<@!E9&ET`&5N=')Y(&YO="!F;W5N9`!F86QL
M:6YG`&9I;&4`9G)O;2!T:&4@)7,@*"5S*2!A="`E<R`E<P!G=7-T:6YG`&@Z
M`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EM;65D:6%T90!I;FQI;F4`:6YP=70O
M;W5T<'5T(&5R<F]R`&EN=&5R;F%L('-O9G1W87)E(&5R<F]R`&QI;F5S70!M
M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@;6%K:6YG($E33RX`;6T`;F%M
M90!N;W0@:6UP;&5M96YT960`;F]T('EE="!I;7!L96UE;G1E9`!N;W1E<&%D
M`'!E<F-E;G0`<&5R;6ES<VEO;B!D96YI960`<&EX96QS`')E;6]T92!E<G)O
M<B!I;B!P<F]T;V-O;`!R:7-I;F<`<V5R=FEC92!U;F%V86EL86)L90!S:&]W
M(&1I9F9E<F5N8V5S`'-M<S)E;6%I;"!V:6$@2%144`!S<P!S=&5A9'D`<WES
M=&5M(&5R<F]R`'1A<VL@;&ES=`!T96UP;W)A<GD@9F%I;'5R90!T>7!E('1H
M92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M`'5N:69I960`=6YN86UE9`!U
M<V5R('-E;&5C=`!V0V%R9`!W.@!W96%T:&5R+F-O;0!0<F]J96-T+4ED+59E
M<G-I;VXZ($AO<F1E(#,N,2XQ+6-V<PI297!O<G0M37-G:60M0G5G<RU4;SH@
M9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M0W)E871I;VXM1&%T93H@,C`P-BTP
M,RTQ,2`Q,CHS.2LP,3`P"E!/+5)E=FES:6]N+41A=&4Z(#(P,#8M,#,M,3$@
M,38Z-3(K,#$P,`I,87-T+51R86YS;&%T;W(Z($)R:6%N(%1R=65L<V5N(#QH
M;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^"DQA;F=U86=E+51E86TZ($1A
M;FES:"`\:3$X;D!L:7-T<RYH;W)D92YO<F<^"DU)344M5F5R<VEO;CH@,2XP
M"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA<G-E=#U)4T\M.#@U.2TQ
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*4&QU<F%L+49O<FUS
M.B!N<&QU<F%L<STR.R!P;'5R86P]*&X@(3T@,2D["@`@*"5S(&1A9V4@<VED
M96XI`"`H06-C97-S:V5Y("5S*0`@*&]M("5S(&1A9V4I`"`H:2!D86<I`"`H
M:2!M;W)G96XI`"`H:2!GY7(I`"!M960@`"(E<R(@97(@:6MK92!E="!K871A
M;&]G+@`B)7,B(&5R(&EN=&5T(&=Y;&1I9W0@=F%L9RX`(B5S(B!E<B!I:VME
M(&MO;F9I9W5R97)E="!I($AO<F1E<R!F;W)T96=N96QS92X`(B5S(B!T<N8M
M;W!B>6=G97(@:6MK92!F=6YD970N`"(E<R(@8FQE=B!T:6QF^&IE="!I(&=R
M=7!P92US>7-T96UE="X`(B5S(B!B;&5V('1I;&;X:F5T('1I;&QA9&5L<V5S
M+7-Y<W1E;65T+@`B)7,B(&)L978@:6MK92!D86YN970Z("5S+@`E+C)F34(@
M8G)U9W0@=60@868@)2XR9DU"('1I;&QA9'0@*"4N,F8E)2D`)60@)7,@;V<@
M)7,`)60@9&%G92!T:6P@9&ET(&MO9&5O<F0@=61L^&)E<BX`)60M9&%G<R!U
M9'-I9W0`)7,@+2!.;W1I=',`)7,@9FEN9V5R869T<GEK`"5S($M"`"5S(%9E
M9&QI9V5H;VQD96QS92`M($)E:W+F9G1E;'-E`"5S(&]P<^9T;FEN9P`E<R!O
M<'-K<FEV;FEN9P`E<R!B<G5G<V)E=&EN9V5L<V5R`"5S(&5K<VES=&5R97(@
M86QL97)E9&4N`"5S('9E9"`E<R`E<P`E<R!E<B!P87)A="!T:6P@870@=61F
M^')E(&1E('9E9&QI9V5H;VQD96QS97-H86YD;&EN9V5R+"!S;VT@97(@;6%R
M:V5R970@;F5D96YF;W(N("!3YG0@:&%K('5D(&9O<B!D92!H86YD;&EN9V5R
M+"!S;VT@9'4@^&YS:V5R('5D9OAR="!N=2X`)7,@:W+F=F5T`"5S(&UI;G5T
M=&5R`"5S(&EK:V4@9G5N9&5T+@`E<R!T:6P@)7,@868@)7,`)7-S(&%D<F5S
M<V5K87)T;W1E:P`E<W,@:V%L96YD97(`)7-S(&YO=&5S8FQO:P`E<W,@;W!G
M879E<@`E<SH@)7,`)7,Z($1E;FYE(&)E<VME9"!E<B!M=6QI9W9I<R!I:VME
M(&9R82!D96X@<&5R<V]N+"!S;VT@9&5N(&CF=F1E<B!A="!VYG)E(&9R82X@
M(%;F<B!V87)S;VT@;65D(&%T(&;X;&=E(&AE;G9I<VYI;F=E<B!E;&QE<B!F
M;W)S>6YE(&%F<V5N9&5R96X@;65D('!E<G-O;FQI9V4@:6YF;W)M871I;VYE
M<BX`+"!D:7-E="``+"!B;.9S96YD92`E<R`E<P`L('-K<FEF=&5N9&4@9G)A
M("5S('1I;"`E<P`M+2!VYFQG("TM`#$R+71I;65R<R!F;W)M870`,C0M=&EM
M97)S(&9O<FUA=``R-"!T:6UE<@`\1F]R96?E96YD92!D86<`16X@9&%T86)A
M<V4M8F%C:V5N9"!E<B!K<N9V970@9F]R(&1E;FYE(&)L;VLN`$1E<B!E<B!O
M<'-TY65T(&5N(&=R879E<F5N9&4@9F5J;`!%;B!O9F9E;G1L:6<@4$=0+6[X
M9VQE(&5R(&MRYG9E="!F;W(@870@:W)Y<'1E<F4@96X@8F5S:V5D+@!%;B!O
M9F9E;G1L:6<@4$=0+6[X9VQE(&5R(&MRYG9E="!F;W(@870@=F5R:69I8V5R
M92!E;B!S:6=N97)E="!B97-K960N`$5N(&]F9F5N=&QI9R!01U`M;OAG;&4L
M('!R:79A="!01U`M;OAG;&4@;V<@970@;/AS96X@97(@:W+F=F5T(&9O<B!A
M="!D96MR>7!T97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG(%!'4"UN^&=L
M92P@<')I=F%T(%!'4"UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V970L(&9O
M<B!A="!S:6=N97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG(%,O34E-12UN
M^&=L92P@<')I=F%T(%,O34E-12UN^&=L92!O9R!E="!L^'-E;B!E<B!K<N9V
M970L(&9O<B!A="!D96MR>7!T97)E(&5N(&)E<VME9"X`16X@;V9F96YT;&EG
M(%,O34E-12UN^&=L92P@<&5R<V]N;&EG(%,O34E-12UN^&=L92!O9R!L^'-E
M;B!E<B!K<N9V970@9F]R(&%T('-I9VYE<F4@96X@8F5S:V5D+@!%;B!O9F9E
M;G1L:6<@4R]-24U%+6[X9VQE(&5R(&MRYG9E="!F;W(@870@:W)Y<'1E<F4@
M96X@8F5S:V5D+@!&;W)M:61D86<@4VMY970`1F]R;6ED9&%G($QE="!296=N
M`$9O<FUI9&1A9R!296=N`$9O<FUI9&1A9R!">6=E<@!&;W)M:61D86<@4VYE
M8GEG97(`04TO4$T`05!)($E$`$]M(&1E;FYE('-K<FEB96YT`$]M+BXN`$%B
M<V)O='1O;0!!8G-M:61D;&4`061G86YG(&[F9W1E="!V960@9&%N;F5L<V4@
M868@5D93+6MA=&%L;V<N`$%D9V%N9R!NYF=T970@=F5D(&1A;FYE;'-E(&%F
M(%9&4RUF:6PN`$MO;G1O+6EN9F]R;6%T:6]N`$MO;G1O96YS(&MO9&5O<F0`
M2V]N=&\@:6YD969R;W-S970N`$MO;G1E<FEN9RX`5&EL9OAJ`%1I;&;X:B!U
M;F1E<F=R=7!P90!4:6QF^&H@=6YD97)O<F1N961E('1I;&QA9&5L<V4`5&EL
M9OAJ(&AE<CH`5&EL9OAJ(&YY(&=R=7!P90!4:6QF^&H@;GD@<F5T=&EG:&5D
M`%1I;&;X:B!U;F1E<F=R=7!P92!T:6P@(B5S(@!4:6QF^&H@96X@=6YD97)R
M971T:6=H960@=&EL("(E<R(`3W!R971T92!E;B!N>2!B<G5G97(Z`%1I;&;X
M:B!K;VQO;FYE`%1I;&;X:B!N>64@;65D;&5M;65R`$]P<F5T('!A<@!4:6QF
M^&H@)7,M;65N=65N('-O;2!E;B!-;WII;&QA(%-I9&5B87(`5&EL9OAJ('1I
M;"!A9')E<W-E:V%R=&]T96LZ`%1I;&;X:B!T:6P@;6ET(&%D<F5S<V5K87)T
M;W1E:P!/<')E="!B<G5G97(`2&%R('1I;&;X:F5T("(E<R(@=&EL('-Y<W1E
M;65T+"!M96X@:W5N;F4@:6MK92!T:6QF^&IE(&5K<W1R82!O<'-K<FEV;FEN
M9W-I;F9O<FUA=&EO;CH@)7,N`%1I;&;X:F5T("(E<R(@=&EL('-Y<W1E;65T
M+B!$=2!K86X@;&]G9V4@:6YD(&YU+@!/<')E='1E;'-E(&%F(&)R=6=E<F4@
M97(@<VSE970@9G)A`$%D<F5S<V4`061R97-S96MA<G1O=&5K`$%D;6EN:7-T
M<NER("T@:6YD<W1I;"!T:6QL861E;'-E<B!F;W(@86YD<F4@8G)U9V5R90!!
M9&UI;FES=')A=&EO;@!296ML86UE<@!!9F=H86YI<W1A;@!!;&)A;FEE;@!!
M;&=E<FEE=`!+86QD96YA=FX`3W!S=&EL;&EN9P!*=7-T97)I;F<Z`$%L;&4`
M06QL92#F9W1E9&4@8G)U9V5R90!!;&QE(&=R=7!P97(`06QL92!T:6QL861E
M;'-E<@!!;&QE(&9I<F4@<VED97(`5&EL;&%D(&UU;'1I<&QE(&%D<F5S<V5R
M`%1I;&QA9"!A;F=I=F5L<V4@868@;W)D;F5T(&QI<W1E='EP93\`16MS:7-T
M97)E<B!A;&QE<F5D90!!;'1E<FYA=&EV($E-4U`M;&]G:6X`06QT97)N871I
M=B!)35-0+6MO9&5O<F0`06QT97)N871I=B!)35-0+6)R=6=E<FYA=FX`1&EN
M(&4M;6%I;"UA9')E<W-E`$%L=&5R;F%T:79E('-K86)E;&]N97(`06QT97)N
M871I=B!T96MS=#H`06UE<FEK86YS:R!386UO80!$96X@=N9R9&DL(&1E<B!B
M;&5V(&%N9VEV970L('9A<B!I:VME(&=Y;&1I9RX`1&5R(&5R(&]P<W3E970@
M96X@=6ME;F1T(&9E:FPN`$%N9&]R<F$`06YG;VQA`$%N9W5I;&QA`$%N;VYY
M;6ES97)E;F1E('!R;WAY`$)E<W9A<@!3>61P;VQE;@!!;G1I9W5A(&%N9"!"
M87)B=61A`$%P<&QI:V%T:6]N`$%P<&QI:V%T:6]N<VQI<W1E`$%P<&QI:V%T
M:6]N(&5R('!A<F%T+@!0Y6;X<B!U;F1E<F1E;&EN9V5R`$=O9&ME;F0`0VER
M:V%S=/AR<F5L<V4`07!R:6P`07)A8FES:R`H5VEN9&]W<RTQ,C4V*0!!<FMI
M=BUF:6QS=/AR<F5L<V4`07)K:79N879N`$5R(&1U('-I:VME<B!PY2P@870@
M9'4@=FEL('-L971T92!O<'-K<FEV;FEN9W-A;FUO9&YI;F=E;B!F;W(@)7,@
M/P!%<B!D=2!S:6MK97(L(&%T(&1U(/AN<VME<B!A="!S;&5T=&4@(B5S(B!O
M9R!E;FAV97(@=6YD97)G<G5P<&4_`$%R9V5N=&EN80!!<FUE;FEE;@!!<FUE
M;G-K("A!4DU30TE)+3@I`$MU;G-T`$%R=6)A`$%S8V5N<VEO;OAE;@!!4T-)
M22!!<G0`07-I871I<VLO<W1I;&QE:&%V<W)E9VEO;@!3</AR9R!E9G1E<B!B
M96MRYF9T96QS92!F^'(@=61F^')E;'-E(&%F('9E9&QI9V5H;VQD96QS97-H
M86YD;&EN9V5R/P!4:6QD96P@:V]L;VYN97(`1F]R<_AG('#E(&%T('-L971T
M92!E;B!I:VME+65K<VES=&5R96YD92!G<G5P<&4N`$9O<G/X9R!PY2!A="!S
M;&5T=&4@96X@:6MK92UE:W-I<W1E<F5N9&4@=&EL;&%D96QS92X`1F]R<_AG
M('#E(&%T(.9N9')E(&5N(&EK:V4M96MS:7-T97)E;F1E('1I;&QA9&5L<V4N
M`$9O<G/X9R!PY2!A="#F;F1R92!E;B!I:VME+65K<VES=&5R96YD92!D96QI
M;F<N`$%T=')I8G5T=&5R`$%U9W5S=`!!=7-T<F%L:65N`-AS=')I9P!!=71H
M7V-Y<G-Q;#H@2W+F=F5T($E-05`M=61V:61D96QS92!I:VME(&9U;F1E="X`
M075T:%]C>7)U<SH@0F%C:V5N9"!H87(@:6MK92!D92!N^&1V96YD:6=E(&5V
M;F5R+@!!=71H7V-Y<G5S.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK:V4@
M9G5N9&5T+@!!=71H7V9T<#H@2W+F=F5T($944"UU9'9I9&1E;'-E(&EK:V4@
M9G5N9&5T+B!/=F5R<^9T(%!(4"!M960@+2UE;F%B;&4M9G1P+69L86=E="X`
M075T:%]I;6%P.B!+<N9V970@24U!4"UU9'9I9&1E;'-E(&EK:V4@9G5N9&5T
M+@!!=71H7VMR8C4Z($MRYG9E="!+4D(U+75D=FED9&5L<V4@:6MK92!F=6YD
M970N`$%U=&A?;&1A<#H@5&EL9OAJ96QS92!B<G5G97)E(&5R(&EK:V4@=6YD
M97)S=/AT=&5T(&9O<B!!8W1I=F4@1&ER96-T;W)Y`$%U=&A?;&1A<#H@4VQE
M=&YI;F<@868@8G)U9V5R92!E<B!I:VME('5N9&5R<W3X='1E="!V960@06-T
M:79E($1I<F5C=&]R>0!!=71H7VQD87`Z($MRYG9E="!,1$%0+75D=FED9&5L
M<V4@:6MK92!F=6YD970N`$%U=&A?;&1A<#H@2W5N;F4@:6MK92!T:6QF^&IE
M(&)R=6=E<B`E<RX@4V5R=F5R96X@<V%G9&4Z(`!!=71H7VQD87`Z($MA;B!I
M:VME('-L971T92!B<G5G97(@)7,`075T:%]L9&%P.B!+86X@:6MK92!O<&1A
M=&5R92!B<G5G97(@)7,`075T:%]L9&%P.B!/<&1A=&5R:6YG(&%F(&)R=6=E
M<F4@97(@:6MK92!U;F1E<G-T^'1T970@=F5D($%C=&EV92!$:7)E8W1O<GDN
M`$%U=&A?;6-A;#H@2W+F=F5T($U#04PM=61V:61D96QS92!I:VME(&9U;F1E
M="X`075T:%]S;6)A=71H.B!+<N9V970@4TU"05542"UU9'9I9&1E;'-E(&EK
M:V4@9G5N9&5T+@#&9W1N:6YG('9E9"!)34%0+7-E<G9E<B!F96IL961E+@#&
M9W1N:6YG(&9E:FQE9&4`QF=T;FEN9R!F96IL961E+B`E<P#&9W1N:6YG(&%F
M=FES="!A9B!2041)55,M<V5R=F5R+@#&9W1N:6YG(&]V97)F;W(@1E10+7-E
M<G9E<B!F96IL961E+@#&9W1N:6YG(&]V97)F;W(@4TU"+7-E<G9E<B!F96IL
M961E+@!&96QT97(@=&EL('+E9&EG:&5D.@!!<V5R8F%I9&IA;@!"3T9(+75N
M9'-K>6QD;FEN9V5R`$)A8VMG<F]U;F0`0F%G9W)U;F1S9F%R=F4`1.5R;&EG
M="!K97)B97)O<RUK;V1E;W)D+@!$Y7)L:6=T(&ME<F)E<F]S+6)R=6=E<FYA
M=FXN`$)A:&%M80!"86AR86EN`$)A;'1I:W5M("A)4T\M.#@U.2TQ,RD`0F%N
M9VQA9&5S:`!"87)B861O<P!"87-I<R!G<F%F:6MK871A;&]G("(E<R(@:6MK
M92!F=6YD970N`$)A<VES;&EN:64`2'9I9&5R=7-L86YD`$)E;&=I96X`0F5L
M:7IE`$)E;FEN`$)E<FUU9&$`0FAU=&%N`$;X9'-E;'-D86<`0FQO:R`B)7,B
M(&%F(&%P<&QI:V%T:6]N("(E<R(@:6MK92!F=6YD970N`$)L;VLM96=E;G-K
M86)E<@!";&]K='EP90!&960`0F]L:79I96X`0F]G;>9R:V5R`%)A;F0`4F%M
M;65T>6MK96QS93H`4F%N9&4`0F]S;FEE;B!O9R!(97)Z96=O=FEN80!"96=G
M90!";W1S=F%N80!"=6YD`$)O=79E=/AE;@!"<F%S:6QI96X`0G)I=&ES:RU)
M;F1I96X@3V-E86YO;7+E9&4`0G)U;F5I($1A<G5S<V%L86T`0G5L9V%R:65N
M`%!U;FMT;&ES=&4`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@
M9&ES=')I8G5T:6]N<W-T961E<@!#96QL92UE9V5N<VMA8F5R+BXN`$EN:71I
M86QI<V5R:6YG(&%F(&UI9&QE<G1I9&EG="!L86=E<B!I:VME(&;F<F1I9V=J
M;W)T+@!+86QE;F1E<@!6:6YD<W1I;&QE`$MA;6)O9&EA`$-A;65R;W5N`$MA
M;B!I:VME(&YU;'-T:6QL92!K;V1E;W)D(&%U=&]M871I<VL[(&MO;G1A:W0@
M9&EN(&%D;6EN:7-T<F%T;W(N`$MA;B!I:VME('-K<FEV92!T:6P@9FEL("(E
M<R(`2V%N(&EK:V4@:.5N9'1E<F4@96MS=&5R;F4@<V5S<VEO;G-HY6YD=&%G
M+@!+86X@:6MK92!F;W)B:6YD92!T:6P@24U!4"!S97)V97(N("5S`$MA;B!I
M:VME(.5B;F4@9FEL("(E<R(N`$-A;F%D80!!;FYU;&QE<@!!9F)R>60@<F5P
M;W)T97)I;F<@868@<')O8FQE;0!+86X@:6MK92!S;&5T=&4@9FEL("(E<R(N
M`$MA;B!I:VME(&9I;F1E(&5T(&UI9&QE<G1I9&EG="!K871A;&]G+@!+86X@
M:6MK92!F;W)T<^9T=&4@=61E;B`G=&%R9V5T1FEL92<M<&%R86UE=')E;BX`
M2V%N(&EK:V4@9FIE<FYE(&MA=&%L;V<@(B5S(BX`2V%N(&EK:V4@9FIE<FYE
M+"`E9"!B^')N(&5K<VES=&5R97(N`$MA;B!I:VME(&]M9F]R9&5L93L@86YT
M86QL970@868@<'5N:W1E<B!A;F=I=F5T('1I;"!O;69O<F1E;&EN9R!S=F%R
M97(@:6MK92!T:6P@9&5T(&]P8F5V87)E9&4@86YT86PN`$MA;B!I:VME(&1I
M<FEG97)E(&)E<VME9"!T:6P@86YG:79N92!N=6UM97(N`$MA<"!697)D90!"
M:6QL961T96MS=`!59&)Y9&5R`$MA=&5G;W)I97(@;V<@3>9R:V5R`$-A>6UA
M;OAE<FYE`$UO8FEL`$-E;&QE+65G96YS:V%B97(`0V5L;&5F;W)R:6YG.@!#
M96QL92UE9V5N<VMA8F5R`$-E;&QE+6UE;&QE;7)U;3H`36]B:6QT96QE9F]N
M`$ME;'1I<VL@*$E33RTX.#4Y+3$T*0!#96YT<NER`$1E;B!C96YT<F%L869R
M:6MA;G-K92!297!U8FQI:P!#96YT<F%L+65U<F]PYFES:R`H25-/+3@X-3DM
M,BD`0V5R=&EF:6MA="UD971A;&IE<@!#97)T:69I:V%T+65J97(`0V5R=&EF
M:6MA="UP;VQI=&EK:V5R`%1C:&%D`,9N9')E`,9N9')E(&1I="!K;V1E;W)D
M`$AE<B!K86X@9'4@YFYD<F4@9&5T(&YA=FX@;V<@9&5N(&%D<F5S<V4L('-O
M;2!A;F1R92!S97(L(&[E<B!D92!LYG-E<B!O9R!S=F%R97(@<.4@9&EN92!E
M+6UA:6PN`$MO9&5O<F1SYFYD<FEN9R!E<B!I:VME('5N9&5R<W3X='1E="!A
M9B!D96X@;G5VYG)E;F1E(&]P<^9T;FEN9RX@($MO;G1A:W0@9&EN(&%D;6EN
M:7-T<F%T;W(N`%1E9VX`2&%K(&QI;FL@868N+BX`0VAI;&4`2VEN80!3:6UP
M;&EF:6-E<F5T(&MI;F5S:7-K("A'0C(S,3(I`%1R861I=&EO;F5L="!K:6YE
M<VES:R`H0FEG-2D`5N9L9R!A<'!L:6MA=&EO;CH`5N9L9R!E="!K;V1E;W)D
M`%;F;&<@970@8G)U9V5R;F%V;@!6YFQG(&AV;W)D86X@9&%T;V5R('-K86P@
M=FES97,Z`%;F;&<@;&ES=&4M<W1I;"`H9F]R(&]R9&YE9&4@;&ES=&5R*0!*
M=6QE^&5N`$ML87-S961E9FEN:71I;VX@868@)7,@:6MK92!F=6YD970N`$ML
M87)T`$9J97)N($U33V9F:6-E+6]P;>9R:VYI;F=E<@!.=6QS=&EL(&9O<F5S
M</AR9W-E;`!296YS(&)R=6=E<B!U9#H@)7,`3G5L<W1I;"!B<G5G97(`5FES
M:R!B<G5G97)D871A('5D`%-E;B!O<&ML87)I;F<`2VQI:R!F;W(@870@9F]R
M='/F='1E`$-L:6-K871E;&P@=FEA($A45%``3'5K('9I;F1U90!3:WEE<@!3
M:WEE<B!T:61L:6=T`%-K>65T`$-O8V]S("A+965L:6YG*2#897)N90!&;VQD
M('-I9&5P86YE;"!S86UM96X`4V%M;65N9F]L9&5D92!R86YD90!+;VQU;6)I
M96X`1F%R=F4`1F%R=F5VYFQG97(`1F%R=F5V86QG`$MO;',Z`$MO;&]N;F5T
M:71L97(`5&5G;F5S97)I97(`2V]M;6%N9&\`2V]M;6%N9&]L:6YI90!+;VUM
M96YT87(`0V]M;6]N($YA;64`0V]M;W)E<FYE`$9I<FUA`$-O;7!U=&5R90!&
M;W)H;VQD`$)E=&EN9V5L<V5R`$MO;F9I9W5R871I;VYS9F]R<VME;&QE`$MO
M;F9I9W5R871I;VX@=&EL('-Y;FMR;VYI<V5R:6YG(&UE9"!01$%E<BP@4VUA
M<G1P:&]N97,@;V<@3W5T;&]O:RX`2V]N9FEG=7)A=&EO;F5N(&5R(&9O<N9L
M9&5T+@!+;VYF:6=U<NER("5S`$)E:W+F9G0@:V]D96]R9`!+;VYG;P!+;VYG
M;RP@1&5N(&1E;6]K<F%T:7-K92!R97!U8FQI:P!&;W)B:6YD96QS92!M:7-L
M>6MK961E<RX`1F]R8FEN9&5L<V4@;6ES;'EK:V5D97,Z(`!&;W)B:6YD96QS
M92!T:6P@;V9F96YT;&EG(&[X9VQE<V5R=F5R(&[F9W1E="X`1F]R8FEN9&5L
M<V4@=&EL(&]F9F5N=&QI9R!N^&=L97-E<G9E<B!NYF=T970N(,5R<V%G.B`E
M<R`H)7,I`$9O<F)I;F1E;'-E('1I;"!&5%`M<V5R=F5R(&UI<VQY:VME9&5S
M+@!+;VYT86MT97(`2V]N=&%K=&5R(&)L978@=&EL9OAJ970@=&EL(&1I="!A
M9')E<W-E:V%R=&]T96ME=`!);F1H;VQD<W1Y<&4@868@:V]M<')I;65R970@
M9FEL.B``26YD:&]L9"!A9B`B)7,B`$9O<G1SYG0`0V]O:R!)<VQA;F1S`%-M
MY6MA9V4`2V]P:65R`$MO<&EE<FEN9R!M:7-L>6MK961E<SH@)7,`2V]P:>ER
M(&UA<FME<FEN9P!'96)Y<B!)1`!#;W-T82!2:6-A`$5L9F5N8F5N<VMY<W1E
M;@!+=6YN92!I:VME(%!'4"UK<GEP=.ER92!B97-K960Z(`!+=6YN92!I:VME
M(%!'4"US:6=NZ7)E(&)E<VME9#H@`$MU;FYE(&EK:V4@4R]-24U%+6MR>7!T
M97)E(&)E<VME9"X`2W5N;F4@:6MK92!3+TU)344M<VEG;NER92!B97-K960N
M`$MU;FYE(&EK:V4@=&EL9OAJ92!K;VYT86MT+B`E<P!+=6YN92!I:VME(&MO
M8FQE('1I;"!,1$%0+7-E<G9E<BX`2W5N;F4@:6MK92!K;VYT<F]L;&5R(&)A
M;&%N8V4N("5S`$MU;FYE(&EK:V4@9F]R8FEN9&4@=&EL($Q$05`M<V5R=F5R
M+@!+=6YN92!I:VME(&9O<F)I;F1E('1I;"!S97)V97(@(B5S(B!V960@8G)U
M9R!A9B!&5%`Z("5S`$MU;FYE(&EK:V4@;W!R971T92!D:7-T<FEB=71I;VYS
M;&ES=&4N("5S`$MU;FYE(&EK:V4@9&5K<GEP=&5R92!01U`M9&%T83H@`$MU
M;FYE(&EK:V4@9&5K<GEP=&5R92!3+TU)344M9&%T82X`2W5N;F4@:6MK92!S
M;&5T=&4@:V]N=&%K="X@)7,`2W5N;F4@:6MK92!S;&5T=&4@9&ES=')I8G5T
M:6]N<VQI<W1E+B`E<P!+=6YN92!I:VME('-L971T92`\96T^<V-R:7!T/"]E
M;3X@(B5S(B!T:6P@;W!G<F%D97)I;F<@868@;W!SYG1N:6YG+@!+=6YN92!I
M:VME(&)E<W1E;6UE(&UO9'1A9V5R96YS(&4M;6%I;"UA9')E<W-E+@!+=6YN
M92!I:VME(&AE;G1E(&AE;&4@861R97-S96MA<G1O=&5K+@!+=6YN92!I:VME
M(&AE;G1E(&AE;&4@9&ES=')I8G5T:6]N<VQI<W1E+@!+=6YN92!I:VME(&AE
M;G1E(&9U;&1S=.9N9&EG(&9O<G1E9VYE;'-E(&]V97(@9&ES=')I8G5T:6]N
M<VQI<W1E<BX`2W5N;F4@:6MK92!H96YT92!S=')A=&5G:2`B)7,B+@!+=6YN
M92!I:VME(&UK9&ER("(E<R(N`$MU;FYE(&EK:V4@:&5N=&4@;V9F96YT;&EG
M(&[X9VQE(&9R82!N^&=L97-E<G9E<BX`2W5N;F4@:6MK92#E8FYE("(E<R(@
M9F]R('-K<FEV;FEN9RX`2W5N;F4@:6MK92#E8FYE("5S+@!+=6YN92!I:VME
M(.5B;F4@;6]D=6P@=&EL('9E9&QI9V5H;VQD96QS92`E<P!+=6YN92!I:VME
M(.5B;F4@:V%T86QO9R`B)7,B+@!+=6YN92!I:VME(&[E($Q$05`M<V5R=F5R
M96XN`$MU;FYE(&EK:V4@;.9S92`E<RX`2W5N;F4@:6MK92!N=6QS=&EL;&4@
M:V]D96]R9&5T(&9O<B!D96X@86YM;V1E9&4@8G)U9V5R+B`@3F]G;&4@96QL
M97(@86QL92!D971A;&IE<B!E<B!U:V]R<F5K=&4N(%!R^'8@:6=E;B!E;&QE
M<B!K;VYT86MT(&1I;B!A9&UI;FES=')A=&]R+"!H=FES(&1U(&AA<B!B96AO
M=B!F;W(@>61E<FQI9V5R92!H:N9L<"X`2W5N;F4@:6MK92!H96YT92!!0TP`
M2W5N;F4@:6MK92!H96YT92!A9')E<W-E:V%R=&]T96ME="X@)7,`2W5N;F4@
M:6MK92!H96YT92!D:7-T<FEB=71I;VYS;&ES=&4N("5S`$MU;FYE(&EK:V4@
M:&5N=&4@9&ES=')I8G5T:6]N<VQI<W1E<BX@)7,`2W5N;F4@:6MK92!H96YT
M92!S97)V97)S(&5V;F5R`$MU;FYE(&EK:V4@9V5N9&%N;F4@:V]N9FEG=7)A
M=&EO;BX`2W5N;F4@:6MK92!R;61I<B`B)7,B+@!+=6YN92!I:VME(&=E;6UE
M("5S+6MO;F9I9W5R871I;VX`2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M
M:V]N9FEG=7)A=&EO;BX`2W5N;F4@:6MK92!G96UM92!E;B!B86-K=7`M:V]N
M9FEG=7)A=&EO;CH@)7,`2W5N;F4@:6MK92!G96UM92!S8W)I<'0@=&EL(&]P
M9W)A9&5R:6YG(&%F(&]P<^9T;FEN9R!T:6PZ("(E<R(N`$MU;FYE(&EK:V4@
M9V5M;64@8F%C:W5P+6MO;F9I9W5R871I;VYS9FEL96X@)7,N`$MU;FYE(&EK
M:V4@9V5M;64@:V]N9FEG=7)A=&EO;G-F:6QE;B`E<RX@1'4@:V%N(&5N=&5N
M(&%N=F5N9&4@96X@868@;75L:6=H961E<FYE(&9O<B!A="!G96UM92!K;V1E
M;B!T:6QB86=E('#E("5S(&5L;&5R(&UA;G5E;'0@:V]P:65R92!K;V1E;B!N
M961E;F9O<B!T:6P@)7,N`$MU;FYE(&EK:V4@<_AG92!,1$%0+7-E<G9E<F5N
M+@!+=6YN92!I:VME(#QE;3YU;FQI;FL\+V5M/B`B)7,B+@!+=6YN92!I:VME
M(&]P9&%T97)E(&MO;G1A:W0N("5S`$MU;FYE(&EK:V4@;W!D871E<F4@9&ES
M=')I8G5T:6]N<VQI<W1E+B`E<P!+=6YN92!I:VME('-K<FEV92!K;VYF:6=U
M<F%T:6]N(&9O<B`B)7,B.B`E<P!+=6YN92!I:VME(&9I;F1E($UO>FEL;&$@
M4VED96)A<BX@1F]R=FES(&1I9R!O;2!A="!S:61E8F%R96X@97(@Y6)E;BX`
M2W5N;F4@:6MK92!G:79E(&)R=6=E<B`B)7,B(&;X;&=E;F1E(')E='1I9VAE
M9&5R('1I;"!M87!P96X@(B5S(CH@)7,`3W!T86QT('1E:W-T`$QA;F0`2W5R
M<V5R`$]P<F5T`$]P<F5T(&5N(&AE;G9I<VYI;F<`3W!R970@96X@;GD`3W!R
M970@=6YD97)M87!P90!3:V%B97)S(')E='1I9VAE9&5R`$MR961I=&MO<G0M
M;G5M;65R`$MR;V%T:65N`$-U8F$`3G5VYG)E;F1E(#0@9F%S97(`26YD97;F
M<F5N9&4@<V5S<VEO;@!!:W1U96P@=&ED`$YU=N9R96YD92!54DP@97(`3G5V
MYG)E;F1E(&)R=6=E<F4`06MT=65L="!V96IR`$YU=N9R96YD92!V96IR.B``
M06MT=65L('-T:6P`5&EL<&%S(&]P9V%V97(L(&1E<B!B;&EV97(@=61F^')T
M+"!NY7(@9'4@;&]G9V5R(&EN9"!I("5S+@!+;&EP`$ML:7`@=F%L9P!#>7!E
M<FX`2WER:6QL:7-K("A+3TDX+5(I`$MY<FEL;&ES:R`H5VEN9&]W<RTQ,C4Q
M*0!+>7)I;&QI<VLO56MR86EN<VL@*$M/23@M52D`5&IE:VMI970`1$0`1%-.
M("AS964@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD
M871A8F%S92YD8BYI;G1R;RUD<VXN<&AP*0!$86=L:6<`1&%T851R964@<W1I
M9FEN9&5R`$1A=&%B87-E+6]P<VQA9P!$871O`$UO9'1A9V5L<V5S9&%T;P!$
M871O=F%L9P!$86<`4VQE="!K;VQO;FYE`$1E8V5M8F5R`$1E8VEM86QT86P`
M36EN9'-K(&EN9')Y:VYI;F<`4W1A;F1A<F0`4W1A;F1A<F1F87)V90!3=&%N
M9&%R9"UI9&5N=&ET970`4W1A;F1A<F0M<VMA;`!$969I;FET:6]N97(`4VQE
M=`!3;&5T(&-E;&QE`%-L970@9W)U<'!E`%-L970@;&]G8F]G`%-L970@=&EL
M;&%D96QS97(`1FIE<FX@;V<@=61S;&5T(&)E<VME9&5R`%-L970@8V5L;&4`
M4VQE="!K;VQO;FYE`%-L970@96MS:7-T97)E;F1E+"!A;'1E<FYA=&EV92!S
M:V%B96QO;@!3;&5T(&)E<VME9&5R`%-L970@=&EL;&%D96QS97(@9F]R("(E
M<R(`4VQE="!T:6QL861E;'-E<B!F;W(@(B5S(B!O9R!A;&QE('5N9&5R;W)D
M;F5D92!T:6QL861E;'-E<C\`4VQE="!RYFMK90!3;&5T('9A;&=T92!I9&5N
M=&ET970`4VQE="!U;F1E<FUA<'!E<@!3;&5T(&1E;B!A:W1U96QL92!K;VQO
M;FYE`%-L970@9&5N(&%K='5E;&QE('+F:VME`$]P9W)A9&5R:6YG<W-C<FEP
M="`B)7,B('-L971T970N`$QE=F5R:6YG<W1I9'-P=6YK=`!$86YM87)K`$)E
M<VMR:78@<')O8FQE;65T`$)E<VMR:79E;'-E`$1E=&%L:F5R("AO9W/E(&D@
M2&]R9&4G<R!L;V=F:6PI.@!$971A;&IE<B!E<B!S:W)E=F5T('1I;"!L;V=B
M;V=E;B!A9B!H96YS>6X@=&EL(&%D;6EN:7-T<F%T;W)E;BX`561V:6ML:6YG
M`$1U9W!U;FMT`$1U9W!U;FMT(&9O<B!S:61S=&4@=&EM93H@`$1U9W!U;FMT
M.B``4F5T;FEN9R!V96YS=')E('1I;"!H^&IR90!2971N:6YG(&CX:G)E('1I
M;"!V96YS=')E`$MA=&%L;V<`5FES('1I9"!M960@,C0@=&EM97(_`$EN9'-T
M:6QL:6YG97(@9F]R('9I<VYI;F<`5FES('5D9'EB96YD92!V96IR=61S:6=T
M`%9I<R!V96IR=61S:6=T("A4048I`%9I<VYI;F=S9F]R;6%T`$]V97)D<F%G
M96QS97-N;W1I=',`1&II8F]U=&D`1F]R=')Y9"!S;&5T;FEN9P!$=2!MY2!I
M:VME(&MA;&1E(&UA:6YT96YA;F-E+G!H<"!D:7)E:W1E`$EN9&5H;VQD97(@
M9&5N(&;X<G-T92!RYFMK92!F96QT;F%V;F4_($AV:7,@:F$L(&UA<FOI<B!D
M96YN92!B;VMS.@!$96X@9&]M:6YI:V%N<VME(%)E<'5B;&EK`$1E;B!D;VUI
M;FEK86YS:V4@4F5P=6)L:6L`2&%R(&1U(&EK:V4@;F]G96X@:V]N=&\_($UE
M;&0@9&EG('1I;"X`2&5N=`!(96YT("5S`$AE;G0@9V5N97)E<F5T(&MO;F9I
M9W5R871I;VX@;F5D('-O;2!02%`M<V-R:7!T+@!2=6QL96=A<F1I;BUL:7-T
M90!-961I:V%M96YT97(`12UM86EL`$5-86EL+71I;"U335,@9V%T97=A>2UD
M<FEV97(L(&9O<B!O<&5R873X<F5R+"!S;VT@=61B>61E<B!D96YN92!S97)V
M:6-E+@!%4E(`17%U861O<@!2961I9V5R`,9N9')E(&)L;VL`QFYD<F4@9W)U
M<'!E`,9N9')E('1I;&QA9&5L<V4`QFYD<F4@=&EL;&%D96QS97(`QFYD<F4@
M=&EL;&%D96QS97(@9F]R("5S`,9N9')E('9A;&<@9F]R.@#&;F1R92!T:6QL
M861E;'-E<B!F;W(@(B5S(@#&;F1R92!T:6QL861E;'-E<B!F;W(@)7,`561D
M86YN96QS90#&9WEP=&5N`$5L(%-A;'9A9&]R`$5L96UE;G0N+BX`16T`94UA
M:6P`92UM86EL+6%D<F5S<V4`12UM86EL+6%D<F5S<V5R('-K86P@<&%S<V4N
M`$4M;6%I;"!M960@8F5K<N9F=&5L<V4`16UA:6PM=&\M4TU3($=A=&5W87D`
M4VUI;&5Y<P!4;VT@8F5S:V5D+@!);G1E="!R97-U;'1A="X`5&]M="!U9'1R
M>6L`06MT:7;I<B!I;F1SYG1T96QS92!A9B!B:6QL961E<B!F<F$@1F]T;V=A
M;&QE<FEE<B!I('1E:W-T/P!!:W1I=NER(&CX:G)E+6ML:6L@8V]N=&5X="UM
M96YU/P!3;'5T+>5R`$9O<G-T^'(@961I=&5R:6YG<W;F<FMT^&H`26YD=&%S
M="!E="!S:6MK97)H961S<W#X<F=S;>5L+"!S;VT@9'4@=FEL(&)L:79E('-P
M=7)G="P@;N5R(&1U(&AA<B!B<G5G(&9O<B!A="#F;F1R92!D:70@:V]D96]R
M9"P@9G@@)VAV860@97(@9&ET(&OF;&5D>7)S(&YA=FX_)SH`26YD=&%S="!5
M4DP@=&EL(&)I;&QE9"!H97(`26YD=&%S="!B;V=S=&%V97(@;F5D96YF;W(Z
M`,9K=F%T;W)I86P@1W5I;F5A`,9R:71R96$`1F5J;`!&96IL('9E9"!D86YN
M96QS92!A9B!B;&]K.B`E<P!&96IL('5N9&5R('-L971N:6YG(&%F('-Y;F,M
M:.9G=&4Z("5S`$9E:FP@=6YD97(@<VQE=&YI;F<@868@<WEN8R!L;V<Z("5S
M`$9E:FP@=6YD97(@:&5N=&YI;F<@868@:6YD:&]L9#H@)7,`1F5J;"!U;F1E
M<B!O<&1A=&5R:6YG(&%F(&MO9&5O<F0Z("5S`$9E:FP@9F]R8G5N9&5T(&UE
M9"!E+7!O<W0@8F5S:V5D+@!&96IL('5N9&5R('-K<FEV;FEN9R!A9B`B)7,B
M+@!%<W1L86YD`,9T:6]P:65N`$5T;FES:P!%=7)O<&$`2'9E<B!K=F%R=&5R
M`$AV97)T(#(N(&UI;G5T`$AV97(@:&%L=F4@;6EN=70`2'9E<B`U+B!M:6YU
M=`!!;'1I9"!V960@;&]G:6X`2'9E<B!H86QV92!T:6UE`$AV97(@;6EN=70`
M16MS96UP96QVYG)D:65R.@!59&;X<@!59'9I9`!&;VQD('-I9&5P86YE;"!U
M9`!&;W)V96YT961E("<I)P!&;W)V96YT961E(')E;G0@;W)D(&5L;&5R(&-I
M=&5R970@<_AG971E<FT`1F]RYFQD96QS97-D871O`$5K<W!O;F5N=`!&1RUF
M87)V90!&5%`M;&%G<FEN9R!A9B!O<'/F=&YI;F<`2W5N;F4@:6MK92#F;F1R
M92!I;F1S=&EL;&EN9V5R;F4N`$MU;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@
M=&EL($Q$05`@<V5R=F5R96XN`$MU;FYE(&EK:V4@9F]R8FEN9&4@=&EL(%--
M0BUS97)V97(N`$9E:FP@=6YD97(@:V]P:65R:6YG(&9R82`B)7,B+@!+=6YN
M92!I:VME(&MO<&EE<F4@=&EL("(E<R(N`$MU;FYE(&EK:V4@971A8FQE<F4@
M;GD@4T%33"UF;W)B:6YD96QS92X`2W5N;F4@:6MK92!F;'ET=&4@=&EL("(E
M<R(N`$MU;FYE(&EK:V4@:&5N=&4Z("5S`%-M=6MT`$9A;&ML86YD<_AE<FYE
M("A-86QV:6YA<RD`1N9R^&5R;F4`1/AD96QI9R!F96IL.@!&87@`1F%K<VEM
M:6QE<@!&96)R=6%R`$;X;&5S`$;X;&5S.B``1N4@8GEG97(`1N4@<VYE8GEG
M97(`1F5L=&UA=')I8V4`1FEG;&5T($-!4%1#2$$`1FEG;&5T('-K<FEF='-T
M>7!O9W)A9FD`1FEJ:0!&:6P`06YT86P@9FEL97(Z("5S(&9I;`!!;G1A;"!F
M:6QE<CH@)7,@9FEL97(`1FEL:.5N9'1E<FEN9P!&:6QN879N`$9I;'9A;&<`
M1FEL;&%G<FEN9P!&:6QL86=R:6YG(&EK:V4@=6YD97)S=/AT=&5T+@!&:6QT
M<F4`1FEN;&%N9`!&^')S=&4@:&%L=F1E;`!&^')S=&4@:W9A<G1A;`!&:6MS
MZ7(@<W3X<G)E;'-E<V9O<FAO;&0`1FQI<`!&;'ED96YD90!4Y6=E`$UA<'!E
M("5S(&5K<VES=&5R97(@:6MK90!4>7!O9W)A9FEF87)V90!-860`1F]R('=E
M8G!R;V=R86UM97(L('-O;2!I:VME('5N9&5R<W3X='1E<B!B:6QL961E<@!6
M96IR=61S:6=T("A4048I`%5D<VEG='-D86=E("AB96WF<FL@870@9&5N(')E
M='5R;F5R92!V96IR=61S:6=T('9E9'+X<F5R(&+E9&4@9&%G(&]G(&YA=#L@
M970@<W1O<G0@86YT86P@:&5R(&MA;B!R97-U;'1E<F4@:2!E;B!M96=E="!B
M<F5D(&)L;VLI`$=L96UT(&1I="!K;V1E;W)D/P!&;W)M=6QA<F5R`$]R9'-P
M<F]G`$5P:6=R86UT>7!E`$5P:6=R86UM97(`17!I9W)A;6UE<B`R`$9O<F$`
M5FED97)E<V5N9&5L<V4`1G)E`%)A;6UE<@!&<F%N:W)I9P!&<F%N:W)I9RP@
M365T<F]P;VQI=&%N`$9R86YS:R!'=7EA;F$`1G)A;G-K(%!O;'EN97-I96X`
M1G)A;G-K92!S>61L:6=E(%1E<G)I=&]R:65R`$9R80!&<F$`1G5L9"!B97-K
M<FEV96QS90!&=6QD;>5N90!&=6QD="!N879N`$=A8F]N`$=A;&QE<FD@:'9O
M<F9R82!B:6QL961E('-K86P@=&%G97,@9G)A`$=A;&QE<FDZ`$=A;6)I80!'
M96YE<NER("5S+6MO;F9I9W5R871I;VX`1V5N97)E<F5T(&MO9&4`1V5O<F=I
M96X`5'ES:VQA;F0`1VAA;F$`1VEB<F%L=&%R`$9O<FYA=FX`1W)U;F1LYF=G
M96YD92!I;F1S=&EL;&EN9V5R`%5D9OAR`$?V9&5L`$=O;V=L92!-87!S`$=O
M;V=L92US^&=N:6YG`$=RY71O;F5R`$=RYFME;FQA;F0`1W+F<VL@*$E33RTX
M.#4Y+3<I`$=R^&YL86YD`$=R96YA9&$`1W)U<'!E+6%D;6EN:7-T<F%T:6]N
M`$=R=7!P96YA=FYE(&WE(&EK:V4@=N9R92!T;VUM90!'<F]U<%]L9&%P.B!+
M86X@:6MK92!T:6QF^&IE(&=R=7!P92`E<RX@4V5R=F5R96X@;65L9&5R.B``
M1W)O=7!?;&1A<#H@2V%N(&EK:V4@<VQE='1E(&=R=7!P92`E<P!'<F]U<%]L
M9&%P.B!+86X@:6MK92!O<&1A=&5R92!G<G5P<&4@)7,`1W)U<'!E<@!'=6%D
M96QO=7!E`$=U86T`1W5A=&%M86QA`$=U97)N<V5Y`$?F<W1E=&EL;&%D96QS
M97(`1^9S=&5B;V<`1W5I;F5A`$=U:6YE82U":7-S874`1W5Y86YA`$A434P`
M2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@870@<VQE='1E(&1E;B!S:61S
M=&4@8V5L;&4@:2!RYFMK92X`2%1-3$%R96$@;N9G=&5R('#E(&9E:B!V:7,@
M870@<VQE='1E(&1E;B!S:61S=&4@:V]L;VYN92!I('1A8F5L+@!(5$U,07)E
M82!NYF=T97(@<.4@9F5J('9I<R!A="!S;&5T=&4@9&5N('-I9'-T92!RYFMK
M92!I('1A8F5L+@!(5%10+>9G=&YI;F<@:6MK92!F=6YD970N`$AA[W1I`$AA
M<V@M86QG;W)I=&UE`$1I<P!4;W!T96MS=`!/=F5R<VMR:69T97(`2&5A<F0@
M27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S`$MR869T:6<@=&]R9&5N`$AE
M8G)A:7-K("A)4T\M.#@U.2TX+4DI`$CX:F1E`$AJYFQP`$AJYFQP('1I;"!R
M961I9V5R:6YG<W;F<FMT^&H`2&KF;'!E<@!(96UI<V;F<F4`2&5R(&5R('-T
M87)T96X@868@9FEL96XZ`$CX:@!(:F5M`$AE;&QI9W/X("A6871I:V%N<W1A
M=&5N*0!(:F5M`%!R:79A="UA9')E<W-E`$AJ96UM96MA=&%L;V<`4')I=F%T
M+71E;&5F;VX`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$AO<F1E+TMO;&%B
M.B!59WEL9&EG("5S(%A-3"!D871A('#E=')U9F9E="!I(&)E<VME9"`E<P!(
M;W)D92]+;VQA8CH@26YG96X@8F5S:V5D('-V87)E<B!T:6P@;V)J96MT("5S
M`$AO<F1E+TMO;&%B.B!);G1E="!O8FIE:W0@868@='EP92`E<R!F=6YD970@
M:2!B97-K960@)7,`2&]R9&4O2V]L86(Z(%-L971T961E("5S("(E<R(`2&]R
M9&4O2V]L86(Z($EN=&5G<F%T:6]N<VUA<VMI;F5N(&MRYG9E<B!02%`M=61V
M:61D96QS92`G9&]M>&UL)P!(;W)D92]+;VQA8CH@2V%N(&EK:V4@9&%N;F4@
M;GET(%A-3"UT<N8@9F]R(&]B:F5K="`E<P!(;W)D92]+;VQA8CH@2V%N(&EK
M:V4@<VQE='1E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!+86X@:6MK92!I
M;F1H96YT92!-24U%+4E$(&9O<B!D96QE;B!A9B!T>7!E("5S`$AO<F1E+TMO
M;&%B.B!+86X@:6MK92!S>6YK<F]N:7-E<F4@)7,@(B5S(CH@)7,`2&]R9&4O
M2V]L86(Z($MA;B!I:VME('-Y;FMR;VYI<V5R92!D96QI;F=E<CH@)7,`2&]R
M9&4O2V]L86(Z(%5K96YD="!D96QI;F<@(B5S(@!686YD<F5T('-T<F5G`%9A
M;F1R970@9F]R`%9A;F1R970Z`$AV;W)D86X@8F%R(&1U(&1I9R!A9"!M960@
M870@:&%V;F4@:&5R/R`H26YD<F%P<&]R=.ER(2D`2'9O<B!M86YG92!K;VQO
M;FYE<B#X;G-K97(@9'4@870@<V%M;65N;.9G9V4_`$AV;W(@;6%N9V4@9F5L
M=&5R("AK;VQO;FYE<BD@97(@9&5R/P!(=F]R(&UA;F=E('+F:VME<B#X;G-K
M97(@9'4@870@<V%M;65N;.9G9V4_`$9U9W1I9VAE9`!&=6=T:6=H960Z(`!(
M=6UO<FES=&5R`%5N9V%R;@!/<')E='1E;'-E(&%F($E-05`M;6%P<&4@9F5J
M;&5D93H@)7,`4VQE=&YI;F<@868@24U!4"UM87!P92!F96IL961E.B`E<P!$
M969I;F5R:6YG(&%F(&MV;W1E(&9O<B!)34%0+6UA<'!E(&9E:FQE9&4Z("5S
M`$E0+6%D<F5S<V4`25`M861R97-S92!I:VME('1I;&?F;F=E;&EG92X`25`M
M861R97-S92!I:VME(&EN9&5N9F]R($-)1%(M8FQO:RX`25`@;&]C:V1O=VX@
M=FEO;&%T:6]N+@!);F1SYG0@<N9K:V4@9OAR`$ES;&%N9`!+=6X@:6MO;F5R
M`$EK;VYE<B!F;W(@)7,`26MO;F5R(&UE9"!T96MS=`!)9&5N=&ET971S;F%V
M;CH`2'9I<R!D96X@:6MK92!V:7-T(&MO<G)E:W0L("5S(&9O<B!A="#E8FYE
M(&1E;B!I(&5T(&YY="!V:6YD=64N`$AV:7,@9'4@:6MK92!S97(@;F]G96X@
M:6MO;F5R('9E9"!B<G5G(&%F($EN=&5R;F5T($5X<&QO<F5R('-K86P@9'4@
M;>5S:V4@:&%K:V4@9&5N;F4@8F]K<R!A9B!F;W(@870@<VSE(%!.1RUT<F%N
M<W!A<F5N<R!F<F$N`$AV:7,@9'4@<V5R(&1E;FYE(&)E<VME9"!I('-T961E
M="!F;W(@970@8FEL;&5D92P@<^4@=FEL(&1U(&EK:V4@:W5N;F4@<V4@9&5T
M(&D@9&EN(&YE="ULYG-E<B!E9G1E<B!O<&SF9VYI;F<N`$)I;&QE9"UF;W)H
MY6YD<W9I<VYI;F<Z`$)I;&QE9"U54DP`0FEL;&5D+5523#H`0FEL;&5D92!F
M<F$@9V%L;&5R:0!":6QL961E(&9R82!G86QL97)I.@!":6QL960M;W!LYF=N
M:6YG`$)I;&QE9&5R`$EM<&]R=&5R:6YG+"!T<FEN("5D`$EM<&]R=&5R961E
M(&9E;'1E<CH@)7,`26UP;W)T97)E9&4@9F5L=&5R.@!);F1SYG0@<N9K:V4@
M969T97(`1F5J;&%G=&EG(&AA;F1L:6YG<VMO9&4@86YG:79E="X`56MO<G)E
M:W0@8G)U9V5R;F%V;B!O9R]E;&QE<B!K;V1E;W)D+@!5:V]R<F5K="!B<G5G
M97)N879N(&5L;&5R(&%L=&5R;F%T:78@861R97-S92X@4'+X=B!I9V5N(&5L
M;&5R(&MO;G1A:W0@9&EN(&%D;6EN:7-T<F%T;W(L(&AV:7,@9'4@:&%R(&)R
M=6<@9F]R('ED97)L:6=E<F4@:&KF;'`N`$9O<OAG(&EN9')Y:VYI;F<`26YD
M:65N`$EN9&EV:61U96QL92!B<G5G97)E`$EN9&]N97-I96X`26YF;P!);F9O
M<FUA=&EO;@!);F9O<FUA=&EO;B!I:VME(&SF;F=E<F4@=&EL9^9N9V5L:6<`
M26YD<^9T(&MO;&]N;F4@969T97(`26YD<^9T(&)I;&QE9&4`26YD<^9T('1A
M8F5L`$EN9'/F="!W96(M:&5N=FES;FEN9P!);F1SYG0@:V]L;VYN92!F^'(`
M26YD<^9T(&5N(&YY(&MO;&]N;F4@969T97(@9&5N(&%K='5E;&QE`$EN9'/F
M="!E;B!N>2!K;VQO;FYE(&;X<B!D96X@86MT=65L;&4`26YD<^9T(&5N(&YY
M('+F:VME(&5F=&5R(&1E;B!A:W1U96QL90!);F1SYG0@96X@;GD@<N9K:V4@
M9OAR(&1E;B!A:W1U96QL90!);F1SYG0@96X@<&%R86=R868@969T97(@9&5T
M(&%K='5E;&QE('!U;FMT`$EN9'/F="!E;B!P87)A9W)A9B!F^'(@9&5T(&%K
M='5E;&QE('!U;FMT`$EN9'/F="!A;'1E<FYA=&EV('-K86)E;&]N`$EN9'1A
M<W0@96X@92UM86EL+6%D<F5S<V4L(&AV;W)T:6P@9'4@:V%N(&UO9'1A9V4@
M9&5T(&YY92!K;V1E;W)D.@!);F1SYG0@8V5L;&4@969T97(`26YD<^9T(&-E
M;&QE(&;X<@!);F1SYG0@:V]L;VYN92!E9G1E<@!);F1SYG0@:V]L;VYN92!F
M^'(`26YD<^9T(&)E<VME9&5R`$EN9'/F="!P87)A9W)A9B!E9G1E<@!);F1S
MYG0@<&%R86=R868@969T97(`26YD<^9T('+F:VME(&5F=&5R`$EN9'/F="!R
MYFMK92!F^'(`26YD=&%S="!D970@:W+F=F5D92!S=F%R('1I;"!S:6MK97)H
M961S<W#X<F=S;>5L970Z`$EN9'/F="_F;F1R92!B:6QL961E`$EN9'/F="_F
M;F1R92!H96YV:7-N:6YG`%5T:6QS='+F:VME;&EG(&MR961I="!T:6P@870@
M<V5N9&4@=&EL(&1I<W1R:6)U=&EO;G-L:7-T96XN`%5T:6QS='+F:VME;&EG
M92!K<F5D:70N`$AE;'1A;`!(96QT86QS;&ES=&4`56=Y;&1I9R!51$@N("A5
M<V5R($1A=&$@2&5A9&5R*2X`56=Y;&1I9V4@6DE0+61A=&$`56=Y;&1I9W0@
M87!P;&EK871I;VXN`%5G>6QD:6=T('-K<FEP="U)1"X`56=Y;&1I9V4@9&%T
M82!A9G-E;F1T+@!59WEL9&EG(&1E<W1I;F%T:6]N+@!59WEL9&EG="!F:6QF
M;W)M870`56=Y;&1I9R!L:6-E;G-N^&=L92X`56=Y;&1I9R!P;&%C97)I;F<@
M86YG:79E="X`56=Y;&1I9R!M<V=?='EP92X`56=Y;&1I9R!E;&QE<B!M86YG
M;&5N(&%P:5]I9"X`56=Y;&1I9V4@96QL97(@;6%N9VQE;F1E('!A<F%M971R
M92X`56=Y;&1I9V4@9F]RYFQD<F4M=&EL;&%D96QS97(N`%5G>6QD:6<@<&%R
M=&YE<BUI9"X`56=Y;&1I9R!P<F]D=6MT+6MO9&4N`%5G>6QD:6<@<')O=&]K
M;VPN`%5G>6QD:6<@;6]D=&%G97(Z("(E<R(`56=Y;&1I9W0@9&5L:6YG<V]B
M:F5K=`!59WEL9&EG(&]P<FEN9&5L<V5S861R97-S92X`56=Y;&1I9R!U;FEC
M;V1E+61A=&$N`$EN9&)O`$EN=F5R=.ER(&UA<FME<FEN9P!)<F%N+"!$96X@
M:7-L86UI<VL@<F5P=6)L:6L`27)A:P!)<FQA;F0`36%N`%-T961V:7,@=&]R
M9&5N`$ES<F%E;`!59'-T961E<@!)=&%L:65N<VL`271A;&EE;@!*86UA:6-A
M`$IA;G5A<@!*87!A;@!*87!A;G-K("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO
M<F1E;@!*=6QI`$IU;FD`2G5S=.ER`$-E;G1RZ7(`3&EG92!M87)G96YE<@!6
M96YS=')E:G5S=&5R970`2/AJ<F5J=7-T97)E=`!+87-A:VAS=&%N`$)E=F%R
M(&]R:6=I;F%L/P!+96YY80!+97)B97)O<R!S97)V97(@869V:7-T92!G;V1K
M96YD96QS92!A9B!I9&5N=&ET970N`$ME<FYE+3QE;3Y.97=B:65S/"]E;3X`
M3OAG;&4M<VMA8F5L<V4`3OAG;&4M9FEN9V5R869T<GEK`$[X9VQE;.9N9V1E
M`$[X9VQE='EP90!.^&=L96%N=F5N9&5L<V4`3OAG;&4@96MS:7-T97)E<B!A
M;&QE<F5D92!PY2!D96X@;V9F96YT;&EG92!N^&=L97-E<G9E<BX`0OAR;@!+
M:7)I8F%T:0!3>61K;W)E80!.;W)D:V]R96$`:V]R96%N<VL@*$550RU+4BD`
M2W5W86ET`$MI<F=I<VES=&%N`%5D9F]R;6YI;F<`4W!R;V<`3&%O<P!3:61S
M=&4@:&%L=F1E;`!3:61S=&4@:V]D96]R9'/F;F1R:6YG`%-I9'-T92!K=F%R
M=&%L`%-I9'-T(&]P9&%T97)E=#H`4VED<W1E(&QO9VEN.B`E<P!3:61S=&4@
M:6YD;&]G;FEN9SH@)7,@9G)A("5S`%-I9'-T92!L;V=I;CH@06QD<FEG`$QE
M=&QA;F0`3&]V`$QA>6]U=`!4;VT@=F5D(&EN9V5N(')A;6UE<@!,:6)A;F]N
M`%9E;G-T<F4`5F5N<W1R92!T;W!T96MS=`!696YS=')E(';F<F1I97(`3&5S
M;W1O`$YI=F5A=0!,:6)E<FEE;@!,:6)Y96X`3&EE8VAT96YS=&5I;@!3=/AV
M<F5G;@!,970@<F5G;@!,970@<F5G;B!T:61L:6=T`$QE="!R96=N('-E;G0`
M3&5T(&)Y9V4`3&5T(&)Y9V4@;65D('1O<F1E;@!,970@<VYE`$QE="!S;F4@
M8GEG90!6:71T:6=H960`2&5N=FES;FEN9P!&;W)B:6YD('!U;FMT97(@=&EL
M.@!&;W)B:6YD(&4M;6%I;"UA9')E<W-E;B!M960@:6YD<VMR:79N:6YG<W-I
M9&5N('9E9"!F<F5M=FES;FEN9P!(96YV:7-N:6YG97(`3&EN=7@M:VEK<P!,
M:7-T92`M(&)R=6=E<B!K86X@<V4@;6%P<&5N`$QI<W0@9&%T86)A<V5R`$]P
M;&ES=&YI;F<@868@:&KF;'!E96UN97(`3&ES="!T86)E;&QE<@!,:7-T92U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&ES=&YI;F<@868@
M<V5S<VEO;G,@9F5J;&5D93H@)7,`3&ES=&YI;F<@868@8G)U9V5R92!F96IL
M961E.B`E<P!6:7-N:6YG(&%F(&)R=6=E<F4@97(@<VSE970@9G)A+@!,:71T
M97)A='5R`$QI=&%U96X`2&5N=&5R+BXN`$QO:V%L('1I9#H`4F5G:6]N86QD
M871A(&]G('1I9`!3=&5D`$QO9R!I;F0`3&]G(&%F('1I9&QI9V5R92!S>6YK
M<F]N:7-E<FEN9W-S97-S:6]N97(`3&]G('5D`$QO9R!I;F0`3&]G:6XM;W!G
M879E<@!,;V<@:6YD(&9E:FQE9&4@9F]R9&D@9&ET(&)R=6=E<FYA=FX@96QL
M97(@:V]D96]R9"!B;&5V(&%N9VEV970@9F]R:V5R="X`3&]G:6YD(&UI<VQY
M:VME9&5S+@!,86YG('1E:W-T`$OF<FQI9VAE9`!,878`4VWE(&=RYG-K92!T
M96=N`%-MY2!L871I;G-K92!T96=N`%-MY2!R;VUE<G1A;`!,=7AE;6)O<F<`
M34T`34]41`!-4RU43D5&+6)I;&%G(&EN9&AO;&1T(&EN9V5N(&1A=&$N`$U3
M1P!-86-A;P!-86ME9&]N:65N+"!$96X@=&ED;&EG97)E(&IU9V]S;&%V:7-K
M92!R97!U8FQI:P!-861A9V%S:V%R`$UA9VD`12UM86EL`$4M;6%I;"UA9&UI
M;FES=')A=&]R`$1A;B!H96YV:7-N:6YG+BXN`$UA;&%W:0!-86QA>7-I80!-
M86QD:79E<FYE`$UA;&D`36%L=&$`2.5N9'3I<B!L:7-T96X@868@:V%T96=O
M<FEE<BP@<V]M(&1U('-K86P@;6%R:V5R92!E;6YE<B!M960L(&]G(&9A<G9E
M<FYE+"!D97(@<VMA;"!K;GET=&5S('1I;"!D:7-S92!K871E9V]R:65R+@!-
M87`R-"UK;W)T`$UA<%%U97-T+6MO<G0`2V]R=&SF9VYI;F<@9V5M="X`36%R
M=',`36%R9V5N`$UA<FOI<B!M960@4V5T+U5S970M9FQA9P!-87)KZ7(@;65D
M(&%N9')E(&9L86<@*&9X(%9I9W1I9R]"97-V87)E="D`36%R<VAA;&SX97)N
M90!-87)T:6YI<75E`$]V97)E;G-P87-S96YD92!F96QT97(`36%U<FET86YI
M96X`36%U<FET:75S`$UA>"!T:6QL861T(&MR961I="X`36%K<VEM=6T@8F5S
M:V5D+61E;&4@;W9E<G-K<F5D970N`$UA:W,N('1E;7`N('-I9'-T(#(T('1I
M;65R.B``36%K<RX@=&5M<"X@<VED<W1E(#8@=&EM97(Z(`!-86MS:6UU;2!A
M;G1A;"!A9B!P;W)T86QB;&]K:V4`36%K<VEM=6ULYFYG9&4`36%J`$UA>6]T
M=&4`365D:6-I;@!-961L96UM97(`365N=2UT:6QS=&%N9#H`1F]RZ6X@8V5L
M;&5R`$)E<VME9`!"97-K960@<W5C8V5S9G5L9'0@=F5R:69I8V5R970@;65D
M('5N9&5R<VMR:79E<F5N<R!C97)T:69I:V%T(&MU;FYE(&EK:V4@=F5R:69I
M8V5R97,N`$)E<VME9"!U9&SX8F5T+@!"97-K961T>7!E`$UE=&%R(%=E871H
M97(`365T87)B;&]K(&EK:V4@=&EL9^9N9V5L:6<N`$UE=&%R8FQO:R!I:VME
M('1I;&?F;F=E;&EG+B!$971A;&IE<B!E<B!B;&5V970@;F]T97)E="!T:6P@
M8G)U9R!F;W(@861M:6YI<W1R871O<F5N+@!-971A<D1"(&5R(&EK:V4@9F]R
M8G5N9&5T+@!-971O9&4`365T;V1E("(E<R(@97(@:6MK92!D969I;F5R970`
M365T;V1E(&EK:V4@9&5F:6YE9"X@365T;V1E(&MA;&1T.B`E<P!-Y6QE96YH
M960`365X:6-O`$UI:W)O;F5S:65N`$UI9'0`34E-12UT>7!E`$UI;BX@=&5M
M<"X@<VED<W1E(#(T('1I;65R.B``36EN+B!T96UP+B!S:61S=&4@-B!T:6UE
M<CH@`$UI;FEM=6T@:V]D96]R9'-A;&1E<B!E<B!E;F1N=2!I:VME('5D<W3E
M970`4W!E:FQE`$9O<G-K96QL:6=T`$UA;F=L97(@4$5!4BUP86MK92!(5%10
M7U)E<75E<W0N`$MO;F9I9W5R871I;VX@;6%N9VQE<BX@1'4@8FQI=F5R(&[X
M9'0@=&EL(&%T(&=E;F5R97)E(&1E;B!N=2P@:'9I<R!D=2#X;G-K97(@870@
M8G)U9V4@9&5N;F4@87!P;&EK871I;VXN`$UA;F=L97(@8F5S:V5D+6ED+@!-
M86YG;&5R(&MRYG9E="!014%2+7!A:VME($UA:6PN`$UA;F=L97(@<V5S<VEO
M;BU)1"X`36%N`$UO8FEL($4M<&]S=`!*YG9N`,9N9')I;F=S9&%T;P#&;F1R
M92!54DP`36]D=6QU<P!-;VQD;W9A`$UO;F%C;P!-;VYG;VQI96X`3>5N960@
M;V<@Y7(`3>5N961L:6<`36]N='-E<G)A=`!-Y6YE9F%S97(`1FQE<F4@9F5L
M=&5R(&9U;F1E="!I(&QI;FEE("5D(&5N9"!D970@9F]R=F5N=&5D92`E9"X`
M36%R;VMK;P!-97-T('-K>69R:70`365S="!S:WEE=`!-97-T('-K>65T(&]G
M(&)LYG-E;F1E`$UE<W0@<V]L`$9L>70@;F5D`$9L>70@=&EL('9E;G-T<F4`
M36]D(&CX:G)E`$9L>70@;W``1FQY="!N960`1FQY="!O<`!-;V-A;6)I<75E
M`$UU;'1I+6YI=F5A=2!R=6QL96=A<F1I;G-L:7-T97(`375L=&EM87`@54L@
M:V]R=`!-=6QT:7!L92!V86QG`$UI;B!K;VYT;P!-:6YE(&MO;G1O+6EN9F]R
M;6%T:6]N97(`36EN(%!O<G1A;`!-:6X@4&]R=&%L+75D9F]R;6YI;F<`37EA
M;FUA<@!.14HL(&IE9R!E<B!)2TM%(&5N:6<`3F%V;@!.86UI8FEA`$YA=7)U
M`$YE<&%L`$YE9&5R;&%N9&5N90!(;VQL86YD<VME($%N=&EL;&5R`$YE='-C
M87!E($)A<V4@55),`$YE='-C87!E($-!(%)E=F]C871I;VX@55),`$YE='-C
M87!E($-!('!O;&EC>2!54DP`3F5T<V-A<&4@4F5N97=A;"!54DP`3F5T<V-A
M<&4@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@4U-,('-E<G9E<B!N86UE`$YE
M='-C87!E(&-E<G1I9FEC871E(&-O;6UE;G0`3F5T<V-A<&4@8V5R=&EF:6-T
M92!T>7!E`$YE=';F<FL`06QD<FEG`$YY($MA;&5D;VYI96X`3GD@:V%T96=O
M<FD`3GEMY6YE`$YY="!B<G5G97)N879N("AV86QG9G)I="D`3F5W(%IE86QA
M;F0`3GET(&MO9&5O<F0`3GET(&MO9&5O<F0@=FEL('5D;/AB92!D96X@)7@N
M`$YY92!K;V1E;W)D(&5R(&EK:V4@96YS+@!.>70@=FEN9'5E("A?8FQA;FLI
M`$YY:&5D97(`3GEH961S9W)U<'!E<@!.YG-T90!.YG-T92`T(&9A<V5R`$[F
M<W1E('1I;'9A;&<`3N9S=&4^`$YI8V%R86=U80!.:6=E<@!.:6=E<FEA`$YA
M=`!.:75E`$YE:@!);F=E;B!T:6QGYFYG96QI9V4@:V]N9FEG=7)A=&EO;F1A
M=&$@870@=FES92!F;W)S:V5L;&4@9F]R+@!);F=E;B!T:6QGYFYG96QI9R!S
M=')A=&5G:2!T:6P@870@;&%V92!)4T\M8FEL;&5D97(N`$EN9V5N('-K<FEP
M="US:V%B96QO;BX`1&5R(&5K<VES=&5R97(@:6MK92!N;V=E;B!B;&]K('#E
M(&1E;B!F;W)E<W!U<F=T92!P;W-I=&EO;@!);F=E;B!K86QE;F1E<B!A;F=I
M=F5T('1I;"!-0T%,+>9G=&YI;F<N`$EN9V5N(.9N9')I;F<N`$1E<B!K86X@
M:6MK92!T:6QF^&IE<R!B^')N('1I;"!D96YN92!T:6QL861E;'-E+@!);F=E
M;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R("5S+@!)
M;F=E;B!K;VYF:6=U<F%T:6]N+6EN9F]R;6%T:6]N(&%N9VEV970@9F]R($94
M4"!61E,N`$EN9V5N(&MO;F9I9W5R871I;VXM:6YF;W)M871I;VX@86YG:79E
M="!F;W(@4U%,(%9&4RX`26YG96X@:V]N9FEG=7)A=&EO;BUI;F9O<FUA=&EO
M;B!A;F=I=F5T(&9O<B!344PM1FEL92!61E,N`$MR961I="!U9'3X;70N`$EN
M=&5T(&)E<W1E;6UE;'-E<W-T960@86YG:79E="X`26YG96X@9FEL('-E;F1T
M`$9A;F1T(&EN9V5N(&EK;VYE<BX`26YT970@<W1E9"!I;F1S=&EL;&5T+@!)
M;G1E="!S=&5D(&%N9VEV970N`$EN9V5N(&)E<VME9"!A;F=I=F5T+@!);G1E
M="!N879N(&%N9VEV970N`$EN=&5T(&YU;6UE<B!A;F=I=F5T+@!);F=E;B!A
M;G-T^&1E;&EG92!E<&EG<F%M;65R`$EN=&5T(&MO9&5O<F0@86YG:79E="!T
M:6P@8G)U9R!F;W(@2%144"WF9W1N:6YG+@!);G1E="!K;V1E;W)D(&%N9VEV
M970@=&EL(&)R=6<@9F]R($E-05`MYF=T;FEN9RX`26YT970@:V]D96]R9"!A
M;F=I=F5T('1I;"!B<G5G(&9O<B!+97)B97)O<RWF9W1N:6YG+@!);G1E="!K
M;V1E;W)D(&%N9VEV970@9F]R($QO9VEN9"WF9W1N:6YG+@!);G1E="!K;V1E
M;W)D(&%N9VEV971T('1I;"!005-35T0MYF=T;FEN9RX`26YT970@:V]D96]R
M9"!A;F=I=F5T(&9O<B!334(MYF=T;FEN9RX`4W1I('1I;"!/<&5N4U-,+6)I
M8FQI;W1E:V5T(&UA;F=L97(N("!/<&5N4U-,+6)I8FQI;W1E:V5T(&5R(&[X
M9'9E;F1I9W0@9F]R(&%T(&CE;F1T97)E(%!+0U,Q,BUD871A+@!);F=E;B!V
M96YT96YD92!O<'-K<FEV;FEN9V5R+@!+=F]T92!I:VME(&EN9'-T:6QL970N
M`$EN9V5N('-T<F5G97(`26YG96X@<VMI;&QE=&5G;B!A;F=I=F5T+@!);F=E
M;B!S:61E<@!);F=E;B!SY61A;B!F:6P`1&5R(&UA;F=L97(@970@;6ED;&5R
M=&ED:6=T(&MA=&%L;V<@=&EL(&UE;&QE;6QA9V5R+@!);G1E="!B<G5G97)N
M879N(&]G+V5L;&5R(&MO9&5O<F0@<V5N9'0N`$EN9V5N(&=Y;&1I9V4@6$U,
M+61A=&$@<F5T=7)N97)E=`!);F=E;B!VYG)D:65R`$]R:6=I;F%L(&MO;F9I
M9W5R871I;VX@;6%N9VQE<B!V97)S:6]N<VYU;6UE<BX@4F5G96YE<NER(&MO
M;F9I9W5R871I;VXN`$1I;B!K;VYF:6=U<F%T:6]N(&UA;F=L97(@=F5R<VEO
M;G-N=6UM97(N(%)E9V5N97+I<B!K;VYF:6=U<F%T:6]N+@!);F=E;@!);F=E
M;B`H8G)U9R!I;7!L:6-I="D`3F]R9&ES:R`H25-/+3@X-3DM,3`I`$YO<F9O
M;&L`3F]R9&QI9V4@:&%L=FMU9VQE`$YO<F1L:6=E($UA<FEA;F'X97(`3F]R
M9V4`26MK92!S96YE<F4@96YD`$EK:V4@9OAR`$EK:V4@;F]G970@:V%T86QO
M9P!):VME(&EM<&QE;65N=&5R970N`$EK:V4@:6YD<W1I;&QE=`!):VME('5N
M9&5R<W3X='1E="X`3F]T97(`26YT970@870@8G)O=W-E+"!V96YD('1I;&)A
M9V4N`$YO=F5M8F5R`%1A;`!!;G1A;"!T96=N`$%N=&%L(&MO;&]N;F5R`$%N
M=&%L('+F:VME<@!486P@:6MK92!A;F=I=F5T(&9O<B!O<&1A=&5R:6YG(&D@
M9&ES=')I8G5T:6]N<VQI<W1E+@!/2P!/8FIE:W0`3V)J96MT9&%N;F5R`$]K
M=&%L`$]K=&]B97(`06YS=/AD96YD92!F:6QT97(`2V]N=&]R`$=A;6UE;'0@
M;V<@;GET(&MO9&5O<F0@<VMA;"!VYG)E(&9O<G-K96QL:6=E+@!'86UM96QT
M(&MO9&5O<F0`1V%M;65L="!K;V1E;W)D(&5R(&EK:V4@:V]R<F5K="X`3VUA
M;@!$96QT92!M87!P97(@=6YD97)S=/AT=&5S(&MU;B!A9B!)34%0+7-E<G9E
M<F4N`$MU;B!A;G-T^&1E;&EG92!E<&EG<F%M;65R`$MU;B#I;B!E+7!O<W0M
M861R97-S92!T:6QL861T+@!%;B!D96QI;F=S(&5J97)S:V%B(&]G(&5J97)T
M:6QL861E;'-E<B!MY2!K=6X@YFYD<F4@868@96X@<WES=&5M861M:6YI<W1R
M871O<B!E;&QE<B!E:F5R96X@<V5L=@#%8F5N(&D@970@;GET('9I;F1U90!/
M<&5N4U-,+69E:FPZ($1A=&$@:W5N;F4@:6MK92!U9&1R86=E<R!F<F$@<VEG
M;F5R970@4R]-24U%+61E;"X`Q6)E;B!D96YN92!H96YV:7-N:6YG(&D@970@
M;GET('9I;F1U90!/<&5R871I=G-Y<W1E;0!);F1S=&EL;&EN9V5R`$EN9'-T
M:6QL:6YG97(@9F]R("5S`$]R9&YE="!L:7-T90!/<F=A;FES871I;VX`3W)G
M86YI<V%T;W)I<VL@96YH960`3W)G86YI<V5R:6YG`$]P<FEN9&5L:6<@87!P
M;&EK871I;VYS<VMA8F5L;VX`3W!R:6YD96QI9V4@<VMA8F5L;VYE<B!I("5S
M.@!!;F1E;@!!;F1E;B!I;F9O<FUA=&EO;@!%:F5R<F5T=&EG:&5D97(`4$%-
M+>9G=&YI;F<@97(@:6MK92!T:6QGYFYG96QI9V4N`%!%05(Z.DUA:6PM;6]T
M;W(`4$=0(&1I9VET86P@<VEG;F%T=7(`4$=0+6MR>7!T97)E="!D871A`$]F
M9F5N=&QI9R!01U`M;OAG;&4`4$=0+7-I9VYE<F5T+VMR>7!T97)E="!D871A
M`%!(4"UK;V1E`%!(4"US:V%L`$5F=&TN(&QE="!R96=N`$5F=&TN(')E9VX`
M169T;2X@8GEG97(`169T;2X@<VYE`$5F=&TN('-N96)Y9V5R`$5F=&TN('-O
M;`!%9G0N('1O<F1E;@!03U-)6"UU9'9I9&1E;'-E(&UA;F=L97(`4$A0+7-K
M86P`1F]R<FEN9P!086MI<W1A;@!086QA=0!086SF<W1I;F$`4&%N86UA`%!A
M<'5A($YY($=U:6YE80!087)A9W5A>0!$96QV:7-T('-K>65T`$MO9&5O<F0`
M2V]D96]R9"#F;F1R970N`$MO9&5O<F0@9F]R:V5R=`!+;V1E;W)D(&MRYG9E
M="!V960@4D%$2553+>9G=&YI;F<N`$MO9&5O<F0@;65D(&)E:W+F9G1E;'-E
M`$MO9&5O<F0Z`$MO9&5O<F0Z(`!+;V1E;W)D96YE('-K86P@=N9R92!E;G,N
M`$EN9'/F=`!);F1SYG0@9G)A('5D:VQI<'-H;VQD97(`4W1I`%9E;G1E;F1E
M(&]P<VMR:79N:6YG97(Z`$9O;&L`4')O8V5N=`!59&;X<B!V961L:6=E:&]L
M9&5L<V4`561F^'(@=F5D;&EG96AO;&1E;'-E('9E9"!L;V<@:6YD/P!4:6QL
M861E;'-E<@!4:6QL861E;'-E("(E<R(@:6MK92!S;&5T=&5T+@!4:6QL861E
M;'-E(&[F9W1E=`!4:6QL861E;'-E<@!4:6QL861E;'-E<RUA9&UI;FES=')A
M=&EO;@!0<F]F:6QE<@!097)U`$OF;&5D>7(`1FEL:7!P:6YE<FYE`%1E;&5F
M;VX`1F]T;W,`4&ET8V%I<FX`4')I:VME<@!"86YA;&ET971E<@!+;&EK(&D@
M96X@8V5L;&4`0F5K<N9F="!A="!D=2#X;G-K97(@870@<VQE='1E(&1E='1E
M(&5L96UE;G0Z`$)E:W+F9G0@870@9'4@^&YS:V5R(&%T(&%F;.9N:V4@9&5T
M=&4@96QE;65N="X`26YD=&%S="!E;B!MY6YE9"!O9R!E="#E<G-T86PN`$EN
M9'1A<W0@970@;F%V;B!T:6P@9&5N(&YY92!K871E9V]R:3H`26YD=&%S="!E
M;B!G>6QD:6<@25`M861R97-S92X`26YD=&%S="!E;B!G>6QD:6<@9&%T;RP@
M=&IE:R!A;G1A;&QE="!A9B!D86=E(&D@;>5N961E;BX`26YD=&%S="!E;B!G
M>6QD:6<@=&ED<V%N9VEV96QS92X`4VMR:78@=F5N;&EG<W0L(&AV860@<')O
M8FQE;65T(&?E<B!U9"!PY2!O9R!H=F%D(&1E<B!S:V5R+@!);F1T87-T('9E
M;FQI9W-T(&)R=6=E<FYA=FX@;V<@:V]D96]R9`!,YG,@9OAL9V5N9&4@=&5K
M<W0N($1U(%-+04P@=N9R92!E;FEG(&D@8F5T:6YG96QS97)N92!F;W(@870@
M8G)U9V4@<WES=&5M970N`$EN9'1A<W0@9&5T(&YY92!K871E9V]R:6YA=FXZ
M`%!O;&5N`%!O;&ET:6L`365N:6YG<VWE;&EN9V5R`%!O<G1U9V%L`%!L86-E
M<FEN9R!A9B!B:6QL961E=`!0;&%C97)I;F<@868@9&5N;F4@=&%B96P`4V5N
M9"!T:6P@9&5N;F4@;6%P<&4@*&EK:V4@9V5N;F5M='9U;F=E="!A9B!)34%0
M*0!.961B^'(@9V5N;F5M('-E;F5S="`E<R!T:6UE<CH@`$YE9&+X<CQB<B`O
M/F-H86YC90!0<F5F<U]L9&%P.B!+<N9V970@3$1!4"UU9'9I9&1E;"!I:VME
M(&9U;F1E="X`4')E9G-?<V5S<VEO;CH@2W+F=F5T('-E<W-I;VXM=61V:61D
M96QS92!I:VME(&9U;F1E="X`5')Y:P!4<GEK('9E9"!O=F5R9FQA9&5N.B``
M5')Y:SH@`$=L:6UT`$)E=')A9W0@8FEL;&5D970@:2!E="!N>70@=FEN9'5E
M`$9O<G)I9V4@=&EL=F%L9P!59'-K<FEV(&1O:W5M96YT`%!R:79A="!N^&=L
M90!0<F]B;&5M`%!R;V)L96UB97-K<FEV96QS90!0<F]J96MT97(`4W1I:V]R
M9'-T96MS=`!/9F9E;G1L:6=E(&[X9VQE`$]F9F5N=&QI9RUN^&=L92UA;&=O
M<FET;64`3V9F96YT;&EG(&[X9VQE(&EN9F]R;6%T:6]N`$]F9F5N=&QI9R]P
M<FEV870M;OAG;&5SYG0M9V5N97)E<FEN9R!M:7-L>6MK961E<RX`4'5E<G1O
M(%)I8V\`561R96YS(&)E<VME9&5R`%%A=&%R`$9O<F5S</AR9W-E;`!+=F]T
M90!/9F9E;G1L:6<@4E-!+6[X9VQE("@E9"!B:70I`$5N:V5L='9I<R!V86QG
M`%)E9VX`4F5G;B!T:61L:6=T`%)E9VX@<V5N=`!296=N8GEG97(`4F5G;B!O
M9R!S;F4`4VQU9`!4:6QFYFQD:6=T(&5P:6=R86T`1F]R:&]L9`!,YG,`3.9S
M(&)E<VME9&5R`%9I<FME;&EG('-L971T92`E<S\@1&5N;F4@;W!E<F%T:6]N
M(&MA;B!I:VME(&)L:79E(&]M9VIO<G0N`%9I<FME;&EG('-L971T92!D871A
M(&9O<B!B<G5G97(@)7,_($1E;FYE(&]P97)A=&EO;B!K86X@:6MK92!B;&EV
M92!O;6=J;W)T+@!/;6?X<B!D:6X@<VED<W1E(&AA;F1L:6YG`$]P9&%T97(`
M3W!F<FES:R!D>6YA;6ES:V4@;65N=2UE;&5M96YT97(Z`$=E;F]P9G)I<VL@
M<&]R=&%L=FES;FEN9SH`4F5G=6SF<G0@=61T<GEK`%)E;&%T:6]N<VSF<V5R
M`$=E;F]P9G)I<VL`3F]T97(`1FIE<FYE('-E<G9E<F4`1FIE<FX@55),("AH
M='1P.B\O=W=W+F5K<V5M<&5L+F1K+VAO<F1E*3H`4VQE=`!3;&5T(&)L;VL`
M1FIE<FX@:V]L;VYN90!3;&5T(&9O<FUA=&5R:6YG`%-L970@<&%R`$9J97)N
M(&QA9W)E="!S:W)I<'0@9G)A('-E<G9E<G,@;6ED;&5R=&ED:6=E(&MA=&%L
M;V<N`$9J97)N`$9J97)N(&1E='1E('!U;FMT(&9R82!D;VMU;65N=&5T`%-L
M970@8G)U9V5R`%-L970@8G)U9V5R.B`E<P!!;FUO9&YI;F<@:W5N;F4@:6MK
M92!B97-V87)E<RX@4F5T=7)N97)E="!F96IL:V]D93H@`$%N;6]D970@=&IE
M;F5S=&4@:W5N;F4@:6MK92!F:6YD97,N`$MRYG9E9&4@)R5S)R!E<B!I:VME
M(&%N9VEV970@:2`E<RUK;VYF:6=U<F%T:6]N+@!+<N9V970@(B5S(B!E<B!I
M:VME(&%N9VEV970@:2!61E,@:V]N9FEG=7)A=&EO;BX`2W+F=F5D92`B)7,B
M(&5R(&EK:V4@86YG:79E="!I(&MO;F9I9W5R871I;VYE;BX`2W+F=F5T(&9E
M;'0`3G5L<W1I;`!.=6QS=&EL(&MO9&5O<F0`3G5L<W1I;"!D:70@:V]D96]R
M9`!'96YS:V%B('-I9'-T92!F;W)E<W#X<F=S96P`4F5S=6QT871E<@!4:6QB
M86=E('1I;"!I;F1S=&EL;&EN9V5R;F4`1V5N=&%S="!N>70@:V]D96]R9`!2
M975N:6]N`$=E;F1A;B!K;VYF:6=U<F%T:6]N`$EN9'-T:6QL:6YG97(@9F]R
M(%)I8V@@5&5X="UR961I9V5R:6YG`$?E9&5R`$CX:G)E`$CX:G)E('1O<'1E
M:W-T`$CX:G)E(';F<F1I97(`4N9K:V4M96=E;G-K86)E<BXN+@!296=E;`!2
M=6WF;FEE;@!2;W3I<B`Q.#``4F]TZ7(@=F5N<W1R90!2;W3I<B!H^&IR90!2
MYFMK92UE9V5N<VMA8F5R`%+F:VME+65G96YS:V%B97(`4N9K:V5R.@!3=')E
M9V5R`%-T<F5G97(@=FEL(&]P='+F9&4@;65L;&5M('+F:VME<B!O9R!K;VQO
M;FYE<@!3=')E9V5R('9I;"!K=6X@;W!T<N9D92!M96QL96T@:V]L;VYN97(`
M4W1R96=E<B!V:6P@:W5N(&]P='+F9&4@;65L;&5M('+F:VME<@!59&;X<@!2
M=7-L86YD`%)W86YD80!+<GEP=&]G<F%F:7-K(%,O34E-12US:6=N871U<@!3
M+TU)344M<VEG;F5R970@8F5S:V5D`%-!4TPMYF=T;FEN9R!E<B!I:VME('1I
M;&?F;F=E;&EG+@!335,`4U%,+69O<G1O;&ME<@!344PM=61T<GEK(&9O<B!O
M<'-L86<@868@=N9R9&EE<@!34T@`4U5#0T53`%-13"UF;W)T;VQK97(`3/AR
M`%-K="X@2&5L96YA`%-K="X@2VET=',@;V<@3F5V:7,`4VMT+B!,=6-I80!3
M:W0N(%!I97)R92!O9R!-:7%U96QO;@!3:W0N(%9I;F-E;G0@;V<@1W)E;F%D
M:6YE<FYE`%-A;6UE(')A;6UE("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!3
M;V$@5&]M92!O9R!0<FEN8VEP90!3871E;&ET=61B>61E<@!3875D:6%R86)I
M96X`1V5M`$=E;2`B)7,B`$=E;2`B)7,B`$=E;6UE($EN9'-T:6QL:6YG97(`
M1V5M(&=E;F5R97)E="!K;VYF:6=U<F%T:6]N('-O;2!02%`M<VMR:7!T(&D@
M9&EN('-E<G9E<G,@;6ED;&5R=&ED:6=E(&MA=&%L;V<N`$=E;70@)7,M:V]N
M9FEG=7)A=&EO;BX`1V5M=&4@<VMR:7!T(&9O<B!O<&=R861E<FEN9R!A9B!O
M<'/F=&YI;F<@=&EL.B`B)7,B+@!3<')E9'0@=&]R9&5N`%9I9&5N<VMA8@!3
M^&<`4_AG96UA<VMI;F5R`%;F;&<@9FEL97(`5N9L9R!E;B!D871O`%;F;&<@
M96X@9W)U<'!E(&%T('1I;&;X:F4`5N9L9R!E;B!N>2!E:F5R`%;F;&<@96X@
M<V5R=F5R`%;F;&<@96X@8G)U9V5R(&%T('1I;&;X:F4`5N9L9R!A;&QE`%;F
M;&<@86QL92!D871O+6MO;7!O;F5N=&5R+@!6YFQG(&5T(&]B:F5K=`!6YFQG
M(&EN9V5N`%;F;&<@9&4@=&5G;B!D=2!H87(@8G)U9R!F;W(@9G)A(&MA<W-E
M<FYE(&YE9&5N9F]R+B!$92!K86X@<^4@:VQI<'!E<R!O9R!K;W!I97)E<R!F
M<F$@=&5X=&9E;'1E="X`5N9L9R!D871O+6%D<VMI;&QE<F5N.@!6YFQG(&1A
M=&]F;W)M870Z`%;F;&<@9&5N(&ED96YT:71E="P@<V]M(&1U('9I;"#F;F1R
M93H`5N9L9R!T:61S+6%D<VMI;&QE<F5N.@!6YFQG('1I9'-F;W)M870Z`%;F
M;&<@=&\@9F5L=&5R+"!D97(@<W9A<F5R('1I;"!H:6YA;F1E;BX`5N9L9R!D
M:6X@9F%R=F5S86UM96YSYG1N:6YG+@!6YFQG(&1I="!F;W)E=')U:VYE('-P
M<F]G.@!396YD('!R;V)L96UB97-K<FEV96QS90!396YD(%--4P!396YE9V%L
M`$;X;&5R.B``4V5P=&5M8F5R`%-E<F)I96X@;V<@36]N=&5N96=R;P!397)I
M96YU;6UE<@!397)V97(M9&%T82!F;W)K97)T(&5L;&5R(&EK:V4@=&EL9^9N
M9V5L:6<N`%-E<W-I;VYS861M:6YI<W1R871O<@!397-S:6]N+4E$('5D;/AB
M970N`%-E<W-I;VYE<@!-YFYG9&4`26YD<W1I;&QI;F=E<B!D97(@=&EL;&%D
M97(@9&EG(&%T(&YU;'-T:6QL92!D:70@:V]D96]R9"P@:'9I<R!D=2!N;V=E
M;G-I;F1E('-K=6QL92!G;&5M;64@9&5T+@!);F1S=&EL(&9J97)N92!S97)V
M97)E+"!S;VT@9'4@^&YS:V5R(&%T('1I;&?E(&9R82!D:6X@<&]R=&%L+@!)
M;F1S=&EL(&1I;B!F;W)E=')U:VYE('-P<F]G+2P@=&ED<WIO;F4M(&]G(&1A
M=&]V86QG+@!);F1S=&EL(&1I;F4@;W!S=&%R='-A<'!L:6MA=&EO;F5R+"!F
M87)V97-A;6UE;G/F=&YI;F<L('-I9&5O<&9R:7-K;FEN(&]G(&%N9')E('9I
M<VYI;F=S=&EL=F%L9RX`26YD<W1I;&QI;F<`4VMR:7!T<R!T:6P@;W!G<F%D
M97)I;F<@868@;W!SYG1N:6YG('1I;&?F;F=E;&EG90!&;&5R92!S=&5D97(@
M;75L:6<@;65D('!A<F%M971E<F5N.B``4V5Y8VAE;&QE<FYE`%-H;W!P:6YG
M`$MO<G0@;W!S=6UM97)I;F<`4VMA;"!H=7)T:6<M=&%S=&5R(&1E9FEN97)E
M<R!F;W(@9&4@9FQE<W1E(&AE;G9I<VYI;F=E<C\@*/<I`%9I<P!6:7,@9F]R
M<VME;&QE;F4@;65L;&5M(&1E;B!G96UT92!O9R!D96X@;GEL:6=T(&=E;F5R
M97)E9&4@:V]N9FEG=7)A=&EO;BX`5FES('1I9'-P=6YK="!F;W(@<V5N97-T
M92!T:6QG86YG('9E9"!PY6QO9VYI;F<_`%9I<R!M=6QI9VAE9"!F;W(@870@
M8F5H;VQD92!O<')I;F1E;&EG`%9I<R!S;G5P<&5R`%9I<R!486)E;&]P97)A
M=&EO;F5R+6MN87!P96X@:2!M96YU96X_`%9I<R`E<RUM96YU96X@=&EL('9E
M;G-T<F4_`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R('1A
M8F5L8V5L;&5N`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R
M('1A8F5L;&5N`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@9F]R
M('1A8F5L<N9K:V5N`%9I<R!D:6%L;V=V:6YD=64@;65D(&5G96YS:V%B97(@
M9F]R(&)I;&QE9&5T`%9I<R!A9G-E;F1T90!">6=E<@!">6=E<B!T:61L:6=T
M`$)Y9V5R('-E;G0`0GEG97(@:2!NYG)H961E;@!3:W)U;7``4VMR=6UP(&5L
M;&5R(&9L>70@;F%B;V)L;VMK92!A9B!V96IE;B!F^')S=`!3:65R<F$@3&5O
M;F4`4VMR:78@:6YD`%5N9&5R<VMR:69T`%-I9VYA='5R86QG;W)I=&UE`%-I
M;F=A<&]R90!3=/AR<F5L<V4`4W!R:6YG('9E9&QI9V5H;VQD96QS92!O=F5R
M`%-L;W9A:VEE=`!3;&]V96YI96X`4VYE`%-N96)Y9V4`4VYE8GEG97(`4VYE
M8GEG97(@=&ED;&EG=`!3;F5B>6=E<B!S96YT`%-N961Y8F1E.B``4VYEYFMV
M:79A;&5N="!I('9A;F0Z(`!386QO;6]N^&5R;F4`4V]M86QI80!386YG92!O
M9R!P;V5S:0!3;W)T97)I;F=S=F%L9P!!9G-E;F1E<F%D<F5S<V4`4WED869R
M:6MA`%-Y9&5U<F]PYFES:R`H25-/+3@X-3DM,RD`4WED($=E;W)G:6$@;V<@
M1&4@<WED;&EG92!386YD=VEC:/AE<@!3>61L:6=E(&AA;'9K=6=L90!,=69T
M(&UE;&QE;2!N86)O8V5L;&5R`$QU9G0@;65L;&5M(&EN9&AO;&0@;V<@<F%M
M;64@:2!C96QL90!-96QL96UR=6US=&%N9V5T`$UE;&QE;7)U;0!,=69T(&]G
M(&9O<G)I;F<`4W!A;FEE;@!3:VED='!O<W0`26YD=&%S=&YI;F<@9F]R('-P
M96-I86QK87)A:W1E<@!$96P@8V5L;&4`1&5L(&MO;&]N;F4`1&5L('+F:VME
M`%-P;W)T`%-R:2!,86YK80!3=&%N9&%R9`!3=&%R(%1R96L`0F5G>6YD96QS
M97/E<@!$96QS=&%T(&5L;&5R('!R;W9I;G,`4W1A='5S`$QA9W)I;F=S9F]R
M;6%T`%9E:@!'96YN96US=')E9VYI;F<`3&ES=&4@868@<W1R96YG90!&:F5R
M;B!D;VWF;F4@9G)A(&%D<F5S<V5N`%-T:6P@6T-34UT`4_AN`%5N9&5R:V%T
M86QO9R`B)7,B(&EK:V4@9G5N9&5T+@!%;6YE`$=O9&ME;F0`06YM;V1N:6YG
M(&]M(&%T('1I;&;X:F4@(B5S(B!T:6P@<WES=&5M(&%F<V5N9'0N("!$=2!K
M86X@:6MK92!L;V=G92!PY2!F^'(@9&EN(&%N;6]D;FEN9R!E<B!B;&5V970@
M86YE<FME;F1T+@!,878@<VMR:69T`%5D9OAR=``B)7,B(&)L978@=&EL9OAJ
M970@=&EL('-Y<W1E;65T+@!$871A(&9O<B!B<G5G97(@(B5S(B!B;&5V('-L
M971T970@9G)A('-Y<W1E;65T+@`B)7,B('-L971T970N`"(E<R(@<VQE='1E
M="!F<F$@<WES=&5M970N`$MO;F9I9W5R871I;VX@=&EL8F%G96;X<G0N($=E
M;FEN9&SF<R!F;W(@870@<V4@YFYD<FEN9V5R;F4N`%)E<V5R=F5K;VYF:6=U
M<F%T:6]N(&=E;70N`%)E<V5R=F5K;VYF:6=U<F%T:6]N9FEL("5S(&=E;70N
M`"(E<R(@;W!D871E<F5T+@`B)7,B('-K<F5V970N`%-U9&%N`$EN9&AO;&0`
M4V]L;W!G86YG`%-O;&YE9&=A;F<`4V]L<FEG=`!3;VQO<&=A;F<`4V]L;W!G
M86YG+W-O;&YE9&=A;F<`4V]L;W!G86YG.B``4V]L;F5D9V%N9P!3;VQN961G
M86YG.B``2.9V970@<VMR:69T`$AJYFQP`%-U<FEN86T`169T97)N879N`%-V
M86QB87)D(&]G($IA;B!-87EE;@!3=V%Z:6QA;F0`4W9E<FEG90!38VAW96EZ
M`%-Y;F,@;&]G('-L971T970`4WEN8TU,`%-Y;G1A:W-F96IL(&D@<_AG96QE
M9`!3>7)I96X`5&]R9&5N`%1O<F1E;B!O9R!V:6YD`%1O<F1E;@!4;W)D96X@
M=&ED;&EG=`!44U8M9FEL`%1A8F5L`%1A8F5L+65G96YS:V%B97(`5&%B96QM
MYFYG9&4`5&%B96PM96=E;G-K86)E<@!486EW86X`5&%I=V%N+"!$96X@:VEN
M97-I<VME('!R;W9I;G,`5&%D:FEK:7-T86X`5&%N>F%N:6$`3>5L.@!/<&=A
M=F5R`%1E;&5F;VYN=6UM97(`5&5M<"X@<VED<W1E('1I;64Z(`!496UP97)A
M='5R`%1E;7!E<F%T=7(Z(`!496UP97)A='5R/&)R("\^*"5S2/AJ)7,O)7-,
M878E<RD@)F1E9SLE<P!3:V%B96QO;B`B)7,B(&EK:V4@9G5N9&5T+@!3:V%B
M96QO;BUA9&UI;FES=')A=&EO;@!496MS=`!296X@=&5K<W0`5&5K<W0M:G5S
M=&5R:6YG`%1E:W-T+71O<`!4;W(`5&AA:2`H5$E3+38R,"D`5&AA:6QA;F0`
M1E10+75D=FED9&5L<V5N(&5R(&EK:V4@=&EL9^9N9V5L:6<N`$AI<W1O<FEK
M+7-Y<W1E;65T(&5R('-LY65T(&9R82X`2&]R9&4O2V]L86(M:6YT96=R871I
M;VYS;6]T;W)E;B!U;F1E<G-T^'1T97(@:6MK92`B)7,B`$E-4U`M;&]G9V5N
M(&MU;FYE(&EK:V4@:VQA<F?X<F5S+@!-86EN=&5N86YC93HZ+6ML87-S96X@
M8FQE=B!I:VME(&EN9&SF<W0`5&EL=F%L9W-V:6YD=65T(&5R(&)L979E="!L
M=6MK970N($%F<VQU='1E<BX`061M:6YI<W1R871O<F5N(&)L:79E<B!N^&1T
M('1I;"!A="!K;VYF:6=U<F5R92!E;B!P97)M86YE;G0@5&EL;&%D96QS97,M
M8F%C:V5N9"P@:'9I<R!D=2!V:6P@86YV96YD92!4:6QL861E;'-E<BX`2W5N
M('5N9&5R<VED96X`2V]N=&%K="U)1"UN=6UM97)E="!B;&5V(&EK:V4@86YG
M:79E="P@969T97)L861T('1O;70@96QL97(@8FQE=B!I:VME(&9U;F1E="!I
M(&1A=&%B87-E;BX`2V]N=&%K=&5N(&)L978@=&EL9OAJ970@=&EL(&1I="!A
M9')E<W-E:V%R=&]T96ME="X`1&5N(&SX<V=J;W)T92!01U`M<VEG;F%T=7(M
M8FQO:R!E<B!K<N9V970@9F]R(&%T(&MU;FYE('9E<FEF:6-E<F4@9&5N('-I
M9VYE<F5D92!B97-K960N`$1I<W1R:6)U=&EO;G-L:7-T92U)1"!E<B!E;G1E
M;B!I:VME(&%N9VEV970L('1O;70@96QL97(@:6MK92!F=6YD970@:2!D871A
M8F%S96XN`$1I<W1R:6)U=&EO;G-L:7-T96X@:6MK92!A;F=I=F5T+@!+<GEP
M=&5R:6YG<V9A8VEL:71E=&5R;F4@:W+F=F5R(&5N('-I:VME<B!W96(M9F]R
M8FEN9&5L<V4N`$9I;&5N("5S(&+X<B!I;F1E:&]L9&4@96X@)7,M:6YD<W1I
M;&QI;F<N`$9I;&5N("5S(&+X<B!I;F1E:&]L9&4@;F]G;&4@)7,M:6YD<W1I
M;&QI;F=E<BX`1FEL96X@:V%N(&EK:V4@:V]P:65R97,@;W9E;G#E('-I9W-E
M;'8N`$9I;&5N(&EN9&5H;VQD="!I;F=E;B!D871A+@!&^&QG96YD92!E<B!H
M;W9E9&5R;F4@9G)A(&1E;FYE(&UE<W-A9V4O<F9C.#(R+6)E<VME9"X`1G5L
M9'-KYG)M<W1I;'-T86YD('9I9&5S(&%T('9O;&1E('!R;V)L96UE<B!I($EN
M=&5R;F5T($5X<&QO<F5R(&=R=6YD970@8G)O=W-E<BUF96IL+"!S;VT@=FD@
M:6MK92!H87(@:W5N;F5T(&]M9^4N($1U('9I;"!M=6QI9W9I<R!O<&QE=F4@
M9F]R=F%N<VME9&4@=FES;FEN9V5R+"!M86YG96P@<.4@961I=&5R:6YG<V9U
M;FMT:6]N97(@;V<O96QL97(@=&EL9N9L9&EG92!B<F]W<V5R+6YE9&)R=60N
M($AV:7,@9&ET('-Y<W1E;2!E<B!7:6YD;W=S)FYB<W`[.7@@=FEL(&1U(&UE
M9"!H^&H@<V%N9'-Y;FQI9VAE9"!O<&QE=F4@)T=E;F5R96P@8F5S:WET=&5L
M<V5S9F5J;"<@;V<@=FEL(&)L:79E(&[X9'0@=&EL(&%T(&=E;G-T87)T92!M
M87-K:6YE;BY<;EQN1'4@97(@;G4@861V87)E="X@(%1R>6L@3TL@:'9I<R!D
M=2!S=&%D:6<@^&YS:V5R(&%T('!R^'9E="!F=6QD<VOF<FUS<F5D:6=E<FEN
M9RX`261E;G1I=&5T96X@(B5S(B!E<B!S;&5T=&5T+@!+=6X@=F5N<W1R92!S
M:61E+@!0;&%C97)I;F=E;B!A9B!';G501RUP<F]G<F%M;65T('-K86P@9VEV
M97,@=&EL($-R>7!T7W!G<#HZ+6ML87-S96XN`$)E<VME9&5N+"!S;VT@97(@
M<V5N9'0@9&5N("5S('1I;"`E<R!M960@96UN970@(B5S(B!E<B!B;&5V970@
M=FES="X*1&5T=&4@97(@:6YG96X@9V%R86YT:2!F;W(L(&%T(&)E<VME9&5N
M(')E;G0@9F%K=&ES:R!E<B!B;&5V970@;.9S="!E;&QE<B!F;W)S=.5E="X`
M3F%V;F5T+"!D97(@<VMA;"!B<G5G92P@;N5R(&1E<B!H96YV:7-E<R!T:6P@
M<VMR:79E<VED96X`06YT86QL970@868@9F5L=&5R('-K86P@=N9R92!E="!T
M86PN`&]P96YS<VPM;6]D=6QE="!E<B!K<N9V970@868@2&]R9&5?0W)Y<'1?
M<VUI;64Z.BUK;&%S<V5N+@!0<N9F97)E;F-E;B`B)7,B(&MU;FYE(&EK:V4@
M9V5M;65S(&9O<F1I(&1E;G,@9&%T82!O=F5R<VMR:61E<B!D96X@;6%K<VEM
M86QT('1I;&QA9'1E('-T^')R96QS90!0<F]G<F%M;65T+"!D97(@8G)U9V5S
M('1I;"!A="!B971R86=T92!D96YN92!D871A='EP92`H)7,I+"!B;&5V970@
M:6MK92!F=6YD970@<.4@<WES=&5M970N`$-I=&%T:6]N<W1E9VYE="!S:V%L
M(';F<F4@970@96YK96QT('1E9VXN`$MU;B!H^&IR92!O9R!V96YS=')E('-I
M9&4`2W5N('-I9&5N('1I;"!H^&IR90!!9'-K:6QL96QS97-T96=N970@<VMA
M;"!VYG)E(&5T(&5N:V5L="!T96=N+@!397)V97)E;B`B)7,B(&5R('-L971T
M970N`%-E<G9E<F5N("(E<R(@97(@9V5M="X`3W!S:W)I=FYI;F=S86YM;V1N
M:6YG96X@9F]R("5S(&5R('-L971T970N`$1E;B!A;F=I=FYE('+F:VME("@E
M9"D@96MS:7-T97)E<B!I:VME+@!$96X@86YG:79N92!RYFMK92!E:W-I<W1E
M<F5R(&EK:V4N`$1E;B!M:61L97)T:61I9V4@9FEL("(E<R(@9FEN9&5S(&EK
M:V4N`$1E;B!T96MS="P@<V]M(&1U(&EN9'1A<W1E9&4L('!A<W-E<B!I:VME
M('1I;"!T96MS=&5N('#E('-KYG)M96XN`$MU;B!T;W`@;V<@8G5N9`!+=6X@
M=&]P`$1E;B!A9G-E;F1T92!I;F9O<FUA=&EO;B!E<B!T86)T('-I9&5N('-I
M9'-T92!T<FEN+@!$96X@;W9E<F;X<G1E(&9I;"!K=6YN92!I:VME(&=E;6UE
M<RX`=V5A=&AE<BYC;VTM8FQO:VME;B!E<B!I:VME('1I;&?F;F=E;&EG+@!4
M96UA+6MA=&%L;V=E="`B)7,B(&EK:V4@9G5N9&5T+@!);F=E;B!T:6QV86QG
M('1I;"!RY61I9VAE9"X`1&5R(&9O<F5F:6YD97,@:6YG96X@9&5L92P@<V]M
M(&MA;B!V:7-E<R!I;F1L96IR970N`$1E<B!E<B!F;W(@;6%N9V4@=&5G;B!I
M(&1E='1E(&9E;'0N($1U(&AA<B!I;F1T87-T970@)7,@=&5G;CL@9'4@<VMA
M;"!I;F1T87-T92!M:6YD<F4@96YD("5S+@!$97(@;W!S=&]D(&5T('!R;V)L
M96T@=6YD97(@=&EL9OAJ96QS96X@868@)R5S)R!T:6P@<WES=&5M970Z("5S
M`$1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:F5R;F5L<V4@868@9&%T
M82!F;W(@8G)U9V5R("(E<R(@9G)A('-Y<W1E;65T.B``1&5R(&]P<W1O9"!E
M="!P<F]B;&5M('5N9&5R('-L971N:6YG(&%F("(E<R(@9G)A('-Y<W1E;65T
M.B``1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&]P9&%T97)I;F<@868@
M(B5S(CH@)7,`1&5R(&]P<W1O9"!E="!P<F]B;&5M('5N9&5R(&9I;&]V97)F
M^')S;&5N.B!);F=E;B`E<R!B;&5V(&]V97)F^')T+@!$97(@;W!S=&]D(&5T
M('!R;V)L96T@=6YD97(@9FEL;W9E<F;X<G-L96XZ("5S('9A<B!S=/AR<F4@
M96YD(&1E;B!M86MS:6UA;'0@=&EL;&%D=&4@<W3X<G)E;'-E("@E9"!B>71E
M<RDN`$1E<B!O<'-T;V0@970@<')O8FQE;2!U;F1E<B!F:6QO=F5R9OAR<VQE
M;CH@)7,@8FQE=B!K=6X@9&5L=FES="!O=F5R9OAR="X`1&5R(&]P<W1O9"!E
M;B!F96IL('5N9&5R('9I<VYI;F<@868@9&5N;F4@8F5S:V5D9&5L`$1E<B!O
M<'-T;V0@96X@9F5J;"!U;F1E<B!I;7!O<G1E<FEN9V5N(&%F(&MO;G1A:W1I
M;F9O<FUA=&EO;BX`1&5R(&]P<W1O9"!E;B!F96IL('5N9&5R(&EM<&]R=&5R
M:6YG96X@868@:4-A;&5N9&%R(&1A=&$N`$1E<B!O<'-T;V0@96X@9F5J;"!I
M(&MO;F9I9W5R871I;VYS9F]R;75L87)E;BX@3G5L:6=V:7,@:&%R(&1U('5D
M96QA9'0@970@:W+F=F5T(&9E;'0N`$1E<B!O<'-T;V0@970@<')O8FQE;2!U
M;F1E<B!U9&;X<F5L<V4@868@9&5N(&%N9VEV;F4@861R97-S96MA<G1O=&5K
M<V9U;FMT:6]N+B!0<OAV(&EG96XN`$1E<B!O<'-T;V0@96X@9F5J;"!U;F1E
M<B!O<&1A=&5R:6YG(&%F(&MO;G1A:W0M9&5T86QJ97)N92X@4'+X=B!I9V5N
M+@!$97(@;W!S=&]D(&5N(&9E:FP@=6YD97(@;W!D871E<FEN9R!A9B!D:7-T
M<FEB=71I;VYS;&ES=&5N+B!0<OAV(&EG96XN`$1E;FYE($E-05`M<V5R=F5R
M('5N9&5R<W3X='1E<B!I:VME(&1E;&EN9R!A9B!M87!P97(N`$1E='1E('1Y
M9&5R(&EK:V4@<.4@870@=N9R92!E="!G>6QD:6=T(')A<BUA<FMI=BX`1&5N
M;F4@='ED97(@:6MK92!PY2!A="!VYG)E(&5N(&=Y;&1I9R!Z:7`M9FEL+@!$
M971T92!T>61E<B!I:VME('#E(&%T(';F<F4@970@9WEL9&EG="!K;W)T;G5M
M;65R+@!$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD96QS92!A9B!B97-K
M961E<B!I9V5N;F5M($-L:6-K871E;&P@*&AT='`Z+R]C;&EC:V%T96QL+F-O
M;2D@861G86YG<W!U;FMT970@=F5D(&)R=6<@868@2%144"!!4$D`1&5N;F4@
M9')I=F5R('1I;&QA9&5R(&%F<V5N9&5L<V4@868@8F5S:V5D97(@:6=E;FYE
M;2!724X@*&AT='`Z+R]W:6YP;&,N8V]M*2!A9&=A;F=S<'5N:W1E="!V960@
M8G)U9R!A9B!(5%10($%020!$96YN92!D<FEV97(@=&EL;&%D97(@869S96YD
M96QS92!A9B!B97-K961E<B!I9V5N;F5M('-M<S)E;6%I;"`H:'1T<#HO+W-M
M<S)E;6%I;"YC;VTI(&%D9V%N9W-P=6YK=&5T('9E9"!B<G5G(&%F($A45%`@
M05!)`$1E;FYE(&1R:79E<B!T:6QL861E<B!A9G-E;F1E;'-E(&%F(&)E<VME
M9&5R('9I82!33510(&EG96YN96T@5F]D869O;F4@271A;&EE;B!A9&=A;F=S
M<'5N:W1E="P@9&]G(&MU;B!T:6P@5F]D869O;F4M;G5M<F4N($1E;B!K<N9V
M97(@96X@92UM86EL:V]N=&\@:&]S(%9O9&%F;VYE($ET86QI96X@*&AT='`Z
M+R]W=W<N,3DP+FET*2X`1&5T=&4@9F5L="!E<B!K<N9V970N`$1E='1E(&9E
M;'0@;>4@:W5N(&EN9&5H;VQD92!H96QT86PN`$1E='1E(&9E;'0@;>4@:W5N
M(&EN9&5H;VQD92!N=6UR92!O9R!K;VQO;BX`1&5T=&4@9F5L="!MY2!K=6X@
M:6YD96AO;&1E(&]K=&%L92!VYG)D:65R+@!$971T92!F96QT('-K86P@=N9R
M92!E;B!K;VUM82T@96QL97(@;65L;&5M<G5M<V%D<VMI;&1T(&QI<W1E(&%F
M(&AE;'1A;`!$971T92!F96QT('-K86P@=N9R92!E="!G>6QD:6=T(&YU;6UE
M<BX`1&5T=&4@9F5L="!S:V%L(&EN9&5H;VQD92!E;B!F87)V96MO9&4@:2!2
M1T(@:&5X+69O<FUA="P@9G@@)R,Q,C,T868G+@!$96YN92!F;W)M=6QA<B!E
M<B!A;&QE<F5D92!P<F]C97-S97)E="X`1&5T=&4@97(@)7,N`$1E='1E(&5R
M(&5T($MO;&%B($=R;W5P=V%R92UO8FIE:W0N($9O<B!A="!S92!D971T92!O
M8FIE:W0@:&%R(&1U(&)R=6<@9F]R(&5N(&4M;6%I;"UK;&EE;G0L('-O;2!F
M;W)S=.5R($MO;&%B($=R;W5P=V%R92UF;W)M871E="X@0F5S^&<@)7,@9F]R
M(&5N(&QI<W1E(&%F(&ML:65N=&5R+@!$96YN92!B97-K960@97(@<VMR979E
M="!M960@970@86YD970@=&5G;G/F="`H)7,I(&5N9"!D:70@96=E="X`5&%L
M;&5T('-K86P@=N9R92!M:6XN(#$N`$1E;FYE('-E<G9E<B!K86X@:6MK92!D
M96MO;7!R:6UE<F4@>FEP+2!O9R!G>FEP+69I;&5R+@!$971T92!S>7-T96T@
M97(@9&5A:W1I=F5R970N`$1E;FYE(';F<F1I('-K86P@=N9R92!E="!T86PN
M`$1E='1E('9I;F1U92!S:V%L(&MA;&1E<R!F<F$@970@5&EL=F%L9W-V:6YD
M=64`5&]R9&5N`%-A9V5R`%1I9`!4:61S;W!G^')E;'-E`%1I9'-F;W)M870`
M5&ED<W9A;&<`5&EM;W(M3&5S=&4`5&ET96P`5&ET;&4@*'1O;VQT:7`I.@!4
M:6P`1F]R(&%T(';F;&=E(&UU;'1I<&QE(&EN9&=A;F=E('-K86P@0W1R;"T@
M*%!#*2!E;&QE<B!#;VUM86YD("A-86,I+71A<W1E;B!H;VQD97,@;F5D92!M
M961E;G,@9&5R(&ML:6MK97,N`$D@1&%G`%-K:69T($A434PM:VEL9&4`5&]G
M;P!4;VME;&%U`$D@;6]R9V5N`%1O;F=A`$9O<B!M86YG92!U9WEL9&EG92!L
M;V=I;F0M9F]R<_AG(&D@;/AB970@868@9&4@<VED<W1E(&UI;G5T=&5R+@!4
M;W``5&]P(&9R86UE("A?=&]P*0!/=F5R<^9T=&5L<V5R`%1R:6YI9&%D(&]G
M(%1O8F%G;P!386YD(&5L;&5R(&9A;'-K`%1I<@!4=6YE<VEE;@!4>7)K:65T
M`%1Y<FMI<VL@*$E33RTX.#4Y+3DI`%1U<FMM96YI<W1A;@!4=7)K<R!O9R!#
M86EC;W,@V&5R;F4`5'5V86QU`%-K<FEV(&1I="!V86QG.B``52Y6+BUI;F1E
M:W,Z(`!54DP`55),(&9O<B!S:W)I<'0@=&EL(&UO9'1A9V5L<V4@868@<W1A
M='5S(')A<'!O<G1E;@!54DPZ`%5G86YD80!5:W)A:6YE`$MU;FYE(&EK:V4@
M=&EL9^4@5D93+6MA=&%L;V<N`$MA;B!I:VME('1I;&;X:F4@96MS=')A(&)R
M=6=E<B!I;F9O<FUA=&EO;B!U;F1E<B!O<'-K<FEV;FEN9RX`2V%N(&EK:V4@
MYFYD<F4@=&EL;&%D96QS97(@9F]R(%9&4RUF:6P@(B5S(BX`2V%N(&EK:V4@
MYFYD<F4@=&EL;&%D96QS97(@9F]R(%9&4RUF:6P@)7,O)7,N`$MA;B!I:VME
M('-K:69T92!T:6P@)7,N`$MA;B!I:VME('1J96MK92!F:6QS=/AR<F5L<V5N
M(&%F("(E<R(N`$MA;B!I:VME('1J96MK92!F:6QS=/AR<F5L<V5N(&%F("(E
M<R\E<R(N`$MU;FYE(&EK:V4@9N4@9F]R8FEN9&5L<V4@=&EL(%-13"!S97)V
M97)E;BX`2V%N(&EK:V4@9N4@9F]R8FEN9&5L<V4@;65D(%-33"X`2V%N(&EK
M:V4@:V]P:65R92!61E,M9FEL+@!+86X@:6MK92!D86YN92!61E,M:V%T86QO
M9R`B)7,B+@!+86X@:6MK92!D86YN92!61E,M:V%T86QO9RX`2V%N(&EK:V4@
M;&%V92!61E,M9FEL+@!+86X@:6MK92!O<')E='1E(%9&4RUM87!P92`B)7,B
M+@!+86X@:6MK92!L879E('1O;2!61E,M9FEL+@!+86X@:6MK92!D96MO;7!R
M:6UE<F4@9&%T82X`2V%N(&EK:V4@<VQE='1E("(E<R([(&MA=&%L;V=E="!E
M<B!I:VME('1O;70N`$MA;B!I:VME('-L971T92`B)7,B.B`E<RX`2V%N(&EK
M:V4@<VQE='1E("5S.R!K871A;&]G970@97(@:6MK92!T;VUT`$MA;B!I:VME
M('-L971T92!61E,M:V%T86QO9V5T(')E:W5R<VEV="X`2V%N(&EK:V4@<VQE
M='1E(%9&4RUK871A;&]G+@!+86X@:6MK92!S;&5T=&4@5D93+6MA=&%L;V<Z
M("5S+@!+86X@:6MK92!S;&5T=&4@5D93+69I;"`B)7,B+@!+86X@:6MK92!S
M;&5T=&4@5D93+69I;"X`2V%N(&EK:V4@<VQE='1E(%9&4RUM87!P92`B)7,B
M+@!+86X@:6MK92!S;&5T=&4@5D93(')E:W5R<VEV=#H@)7,N`$MA;B!I:VME
M(&)E<W1E;6UE(&%K='5E;'0@:V%T86QO9RX`2V%N(&EK:V4@=61D<F%G92!C
M97)T:69I:V%T+61E=&%L:F5R`$MA;B!I:VME(&EN9&SF<V4@9&5F:6YI=&EO
M;F5N(&%F("5S+@!+86X@:6MK92!F;'ET=&4@5D93+69I;"X`2V%N(&EK:V4@
MY6)N92!61E,M9FEL("(E<R(N`$MA;B!I:VME(.5B;F4@5D93+69I;"!T:6P@
M<VMR:79N:6YG+@!+86X@:6MK92#E8FYE(%9&4RUF:6PN`$MA;B!I:VME(.5B
M;F4@:V]M<')I;65R970@87)K:78N`$MA;B!I:VME(&SF<V4@5D93+69I;"`H
M9FEL97-I>F4H*2!F96IL961E*2X`2V%N(&EK:V4@;.9S92!61E,M9FEL("AG
M971&:6QE4VEZ92@I(&9E:FQE9&4I+@!+86X@:6MK92!LYG-E(&9I;#H@`$MA
M;B!I:VME(&SF<V4@=F9S<F]O="UK871A;&]G970N`$MA;B!I:VME(&]M9/AB
M92`E<R!T:6P@)7,Z(&WE;&UA<'!E;B!F:6YD97,@86QL97)E9&4`2V%N(&EK
M:V4@;VUD^&)E(%9&4RUK871A;&]G+@!+86X@:6MK92!O;63X8F4@5D93+6MA
M=&%L;V<Z("5S+@!+86X@:6MK92!O;63X8F4@5D93+69I;"`B)7,B+@!+86X@
M:6MK92!O;63X8F4@5D93+69I;"`E<R\E<RX`2V%N(&EK:V4@;VUD^&)E(%9&
M4RUF:6PN`$MA;B!I:VME(&%F=FEK;&4@)VUK:7-O9G,G+@!+=6YN92!I:VME
M(&]V97)SYG1T92!D971T92!7;W)D(&1O:W5M96YT`$MA;B!I:VME('-K<FEV
M92!61E,M9FEL("(E<R(N`$MA;B!I:VME('-K<FEV92!61E,M9FEL("AC;W!Y
M*"D@9F5J;&5D92DN`$MA;B!I:VME('-K<FEV92!61E,M9FEL9&%T82X`2V%N
M(&EK:V4@<VMR:79E(%9&4RUF:6P[(&MV;W1E;B!V:6P@8FQI=F4@;W9E<G-K
M<F5D970N`%5N9&5R;&EN:65R970`1F]R=')Y9"#F;F1R:6YG97(`3VUG^'(@
M9&EN('-I9'-T92!H86YD;&EN9P!5=F5N=&5T(')E86MT:6]N(&9R82!S97)V
M97(@<.4@9F]R8FEN9&5L<V5N.B``579E;G1E="!R96%K=&EO;B!F<F$@<V5R
M=F5R('#E.B``26MK92!A;F)R86=T`%5N:6-O9&4@*%541BTX*0!&;W)E;F5D
M92!!<F%B:7-K92!%;6ER871E<@!3=&]R8G)I='1A;FEE;@!54T$`55-!<R!U
M;F1E<F]R9&YE9&4@^&5R`$5N:&5D97(`56ME;F1T`%5K96YD="!A<&EM<V=I
M9"`H05!)($UE<W-A9V4@240I+@!5:V5N9'0@8VQI;7-G:60@*$-L:65N="!-
M97-S86=E($E$*2X`56ME;F1T('-T960@86YG:79E="X`56ME;F1T(&)R=6=E
M<FYA=FX@96QL97(@:V]D96]R9"X`2.9G="!A:W1U96QT(&5L96UE;G0@868N
M`$EK:V4@;F%V;F=I=F5T`%5P<FEV:6QI9V5R961E('-K<FEP=&5R(&MA;B!I
M:VME('1I;&?E(&ML:7!P92]K;W!I+VEN9'/F="!P<F]G<F%M;>9S<VEG="!A
M9B!S:6MK97)H961SY7)S86=E<BX@($ML:6L@3TL@9F]R(&%T('-E(&5N('1E
M:VYI<VL@;F]T92!H;W,@;6]Z:6QL82YO<F<L('-O;2!V:7-E<B!D:6<L(&AV
M;W)D86X@9'4@:V%N('1I;&QA9&4@970@<VMR:7!T(&%T('1I;&?E('5D:VQI
M<'-H;VQD97)E;BX`1F%R=F4@:6MK92!I;F1S=&EL;&5T`%5D=FED9&5L<V4@
M:6MK92!U;F1E<G-T^'1T970`3W!D873I<@!/<&1A=.ER("5S`$]P9&%TZ7(@
M8G)U9V5R`"(E<R(@;W!D871E<F5T+@!/<&=R861E<FEN9W,M9F]R97-K<FEF
M="!S;&5T=&5T+@!5<&QO860`3W!SYG1N:6YG<V9I;&5R('1I;"!A;&QE(&%P
M<&QI:V%T:6]N97(@;&%G="!O<"!PY2!S97)V97(N`%-T;W)E(&QA=&EN<VME
M(&)O9W-T879E<@!3=&]R92!R;VUE<G1A;`!5<G5G=6%Y`$%N=F5N9"!N=7;F
M<F5N9&4Z("5S`$)R=6<@4U-,`$)R=6<@:'9I<R!N879N+VMO9&5O<F0@97(@
M9F]R<VME;&QI9R!F;W(@24U34"US97)V97(N`$)R=6=E<@!"<G5G97(@)7,@
M:6MK92!B96UY;F1I9V5T('1I;"`E<RX`0G)U9V5R+6%D;6EN:7-T<F%T:6]N
M`$)R=6=E<FEN9'-T:6QL:6YG97(`0G)U9V5R+7)E9VES=')E<FEN9P!"<G5G
M97(M<F5G:7-T<F5R:6YG(&5R(&)L979E="!S;.5E="!F<F$@<.4@9&5T=&4@
M=V5B<W1E9"X`0G)U9V5R:V]N=&\@:6MK92!F=6YD970`0G)U9V5R;F%V;@!"
M<G5G97)N879N("(E<R(@9FEN9&5S(&%L;&5R961E+@!"<G5G97)N879N.@!"
M<G5G97)N879N.B``0G)U9V5R92!I('-Y<W1E;65T.@!5<V)E:VES=&%N`%9&
M4RUK871A;&]G(&5K<VES=&5R97(@:6MK92X`1F5R:64`1WEL9&EG92!F=6YD
M970@<W1E9&5R(&EN:VQU9&5R97(Z`$=Y;&1I9VAE9`!6YG)D:2!E<B!M:6YU
M='1E<B!F<F$@;G4N`%;F<F1I(&5R(&UE<F4@96YD(&1E;B!M86MS:6UA;&4@
M;.9N9V1E(&%F("5S+@!6YG)D:65R`%;F<F1I97(L(&1E<B!K86X@=N9L9V5S
M(&EB;&%N9'0`5F%N=6%T=0!3:VEF=&5N9&4`5F5N97IU96QA`$5F=&5R<'+X
M=FYI;F<@9F5J;&5D92`M(&1E<B!E<B!B;&5V970@<&EL;&5T('9E9"!D96YN
M92!B97-K960N`%9E<G-I;VX`5F5R<VEO;G-K;VYT<F]L`$QO9')E="!O<'-T
M:6QL:6YG`$QO9')E="!F;W)R:6YG`$QO9')E=#H`365G970@:/AJ`%9I971N
M86T`5FEE=&YA;65S:7-K("A625-#24DI`%9I<R`E<P!392!PY2!E:W-T97)N
M('=E8G-I9&4`5FES('-O;2`E<P!*;VUF<G7X97(L($)R:71I<VME`$IO;69R
M=?AE<BP@06UE<FEK86YS:V4`4WEN;&EG:&5D`%-Y;FQI9VAE9#H@`%9O9&%F
M;VYE($ET86QI96X@=FEA(%--5%``5T%23@!!1%9!4E-%3"$A(2!&2D523B!3
M0U))4%0@34%.545,5"!&4D$@)7,N`%=)3B!V:6$@2%144`!786QL:7,@;V<@
M1G5T=6YA`$%D=F%R<V5L`$]N<P!696IR=61S:6=T`%9E:G)I;F9O<FUA=&EO
M;B!S=&EL;&5T('1I;'+E9&EG:&5D(&%F`%=E871H97(N8V]M`%=E8@!796)S
M:71E`%5G96YT;&EG`%9E;&MO;6UE;@!696QK;VUM96X@=&EL("5S`%9E;&MO
M;6UE;BP@)7,`5F5S=&QI9R`H25-/+3@X-3DM,2D`5F5S=&QI9R`H25-/+3@X
M-3DM,34I`%9E<W1S86AA<F$`2'9I;&ME;B!A<'!L:6MA=&EO;B!S:V%L("5S
M('9I<V4@969T97(@;&]G:6YD/P!(=F%D(&5R('-E<&%R871O<G1E9VYE=#\`
M2'9A9"!E<B!C:71A=&EO;G-T96=N970_`%=H97)E:7,@075S=')A;&EE;BUK
M;W)T`$AV:6QK92!F87-E<@!(=FEL:V4@<&QU9VEN<R!S:V%L(&%K=&EV97)E
M<R!F;W(@4FEC:"!497AT+7;F<FMT^&IE="X`0G)E9&1E`$)R961D92!I($-3
M4RUE;FAE9&5R`$)R961D92!A9B`E<RUM96YU96X@=&EL('9E;G-T<F4@*&)L
M:79E<B!A:W1I=F5R970@=F5D(&[F<W1E(&QO9VEN9"DZ`$)R961D92!A9B!T
M86)E;&QE;@!"<F5D9&4M96YH960`0G)E9&1E.@!7:6MI`%9I;F0`0FSF<W0@
M=&ED;&EG=`!6:6YD:&%S=&EG:&5D(&D@:VYO8@!6:6YD.@!6:6YD.B``5FES
M9&]M`-AN<VME;&ES=&4`07)B96ID90!!9')E<W-E("AA<F)E:F1E*0!496QE
M9F]N("AA<F)E:F1E*0!&;W)K97)T(&%N=&%L(&9E;'1E<B!I(&QI;FEE("5D
M+B!&;W)V96YT961E("5D+"!F86YD="`E9"X`1F]R:V5R="!A;G1A;"!F96QT
M97(N($9O<G9E;G1E9&4@)60L(&9A;F1T("5D+@!&;W)K97)T(&9O<G-K>61N
M:6YG("5D('5N9&5R(&EN9&SF<VYI;F<@868@96X@5D93+69I;"X`6"U2968`
M6#4P.78S($)A<VEC($-O;G-T<F%I;G1S`%@U,#EV,R!%>'1E;F1E9"!+97D@
M57-A9V4`6#4P.78S(%-U8FIE8W0@06QT97)N871I=F4@3F%M90!8-3`Y=C,@
M4W5B:F5C="!+97D@261E;G1I9FEE<@!8-3`Y=C,@=61V:61D96QS97(`Q<4`
MQ<7%Q0!986AO;R$M:V]R=`#%<FQI9P!996UE;@!*80!*82P@:F5G(&5R(&5N
M:6<`1'4@8F5F:6YD97(@9&EG(&D@5$5+4U0@34]$55,N("!"<G5G(%L\/ETM
M:VYA<'!E;B!T:6P@870@<VMI9G1E('1I;&)A9V4@=&EL(%=94TE764<N`$1U
M(&AA<B!I:VME('1I;&QA9&5L<V4@=&EL(&%T(&]P<F5T=&4@;65R92!E;F0@
M)60@8FQO:VME+@!$=2!E<B!I:VME(.9G=&5T+@!$=2!K86X@:6MK92!H879E
M("=<)RUT96=N970@:2!D:70@9G5L9&4@;F%V;BX`1'4@:6YD=&%S=&5D92!I
M:VME(&5N(&=Y;&1I9R!E+7!O<W0M861R97-S92X`1F]R(&%T(&EM<&]R=&5R
M92!S:V%L(&1U('1I;&]R9&YE(&9E;'1E<B!F<F$@9&5N(&9I;"!D=2!I;7!O
M<G1E<F5R('1I;"!D92!T:6QS=F%R96YD92!F96QT97(@:2`E<RX`1'4@97(@
M8FQE=F5T(&QO9V=E="!U9"X`1'4@<VMA;"!I;F1T87-T92!E="!F=6YG97)E
M;F1E(&UO8FEL;G5M;65R.R!K=6X@8VEF<F4@;65D(&5T('9A;&=F<FD@)RLG
M(&9O<B!D96X@:6YT97)N871I;VYA;"!R971N:6YG<VMO9&4N`$1U('-K86P@
M:6YD=&%S=&4@96X@9WEL9&EG(';F<F1I+@!$=2!S:V%L(&MO;F9I9W5R97)E
M(&5N($1A=&%4<F5E+6)A8VME;F0@9F]R(&%T(&MU;FYE(&%N=F5N9&4@3W!S
M:W)I=FYI;F=E<BX`1'4@<VMA;"!K;VYF:6=U<F5R92!E;F0@5D93+6)A8VME
M;F0N`$1U(&)L:79E<B!N^&0@=&EL(&%T(&QA=F4@96X@<')O8FQE;6)E<VMR
M:79E;'-E+"!F^'(@9'4@:V%N('-E;F1E(&1E;B!I;F0N`$1U('-K86P@:6YD
M=&%S=&4@9&5N(%523"!H=F]R=&EL(&1E;FYE(&CF9W1E('-K86P@:&5N=FES
M90!$=2!S:V%L(';F;&=E(&1E;B!S97)V97(L('-O;2!S:V%L('-L971T97,N
M`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F:F5R
M;F4N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I;"!F
M:F5R;F4N`$1U('-K86P@86YG:79E(&)R=6=E<FYA=FYE="P@<V]M(&1U('9I
M;"!T:6QF^&IE+@!$=2!S:V%L(&%N9VEV92!B<G5G97)N879N970L('-O;2!D
M=2!V:6P@;W!D871E<F4N`$1U('-K86P@86YG:79E(&1E;B!H86YD;&EN9RP@
M<V]M('-K86P@=61F^')E<RX`1'4@<VMA;"!A;F=I=F4@970@;GET(&MA=&5G
M;W)I;F%V;BX`1'4@8FQI=F5R(&[X9'0@=&EL(&%T(&%N9VEV92!E="!I=&%L
M:65N<VME('1E;&5F;VYN=6UM97(`1&EN("5S('-E<W-I;VX@97(@=61L^&)E
M="X@3&]G('9E;FQI9W-T(&EN9"!I9V5N+@!$:6X@92UP;W-T+6%D<F5S<V4`
M1&EN($9R;VTZ(&%D<F5S<V4Z`$1I;F4@:6YF;W)M871I;VYE<@!$:6X@26YT
M97)N970M861R97-S92!E<B!S:VEF=&5T('-I9&5N(&)E9WEN9&5L<V5N(&%F
M(&1I;B`E<RUS97-S:6]N+B!&;W(@870@8F5S:WET=&4@9&EN('-I:VME<FAE
M9"!B;&EV97(@9'4@;OAD="!T:6P@870@;&]G9V4@:6YD(&EG96XN`$1I="!N
M879N`$1I;B#F9W1N:6YG<RUB86-K96YD('5N9&5R<W3X='1E<B!I:VME('1I
M;&;X:F5L<V5N(&%F(&)R=6=E<F4N($AV:7,@9'4@^&YS:V5R(&%T(&)R=6=E
M($AO<F1E('1I;"!A="!A9&UI;FES=')E<F4@8G)U9V5R:V]N=&DL(&)L:79E
M<B!D=2!N^&1T('1I;"!A="!B<G5G92!E;B!A;F1E;B#F9W1N:6YG<RUB86-K
M96YD+@!$:6X@875T;W)I<V%T:6]N<RUB86-K96YD('5N9&5R<W3X='1E<B!I
M:VME(&]P;&ES=&YI;F=E;B!A9B!B<G5G97)E(&5L;&5R(&5R(&1E;B!F=6YK
M=&EO;B!A9B!E;B!E;&QE<B!A;F1E;B!G<G5N9"!B;&5V970@<VSE970@9G)A
M+@!$:6X@8G)O=W-E<B!S>6YE<R!A="!VYG)E('-K:69T970@<VED96X@8F5G
M>6YD96QS96X@868@9&EN("5S+7-E<W-I;VXN($9O<B!A="!B97-K>71T92!D
M:6X@<VEK:V5R:&5D+"!S:V%L(&1U(&QO9V=E(&EN9"!I9V5N+@!$:6X@8G)O
M=W-E<B!U;F1E<G-T^'1T97(@:6MK92!D96YN92!F=6YK=&EO;F%L:71E="X`
M1&EN(&)R;W=S97(@=6YD97)S=/AT=&5R(&EK:V4@9&5N;F4@<')I;G0M;75L
M:6=H960N(%1R>6L@0W1R;"]#;VUM86YD("L@4"!F;W(@870@<')I;G1E+@!$
M:6X@86MT=65L;&4@=&ED<WIO;F4Z`$1I;B!F;W)V86QG=&4@:61E;G1I=&5T
M(&5R(.9N9')E="X`1&EN('-T86YD87)D+6ED96YT:71E=#H`1&ET(&9U;&1E
M(&YA=FXZ`$1I="!L;V=I;F0@97(@=61L^&)E="X`1&ET(&YY92!K;V1E;W)D
M(&9O<B`E<R!E<CH@)7,`1&EN92!T:6QV86QG(&5R(&)L979E="!O<&1A=&5R
M970@9F]R('9A<FEG:&5D96X@868@9&5N;F4@<V5S<VEO;BX`1&EN92!T:6QV
M86QG(&5R(&]P9&%T97)E="X`1&ET(&MO9&5O<F0@97(@8FQE=F5T(&YU;'-T
M:6QL970`1&ET(&MO9&5O<F0@97(@8FQE=F5T(&YU;'-T:6QL93L@:V]N=')O
M;&SI<B!D:6X@:6YD8F%K:V4@;V<@;&]G(&EN9"!M960@9&ET(&YY92!K;V1E
M;W)D+@!$:70@:V]D96]R9"!E<B!U9&SX8F5T+@!$:6YE(&9J97)N92!S97)V
M97)E.@!*=6=O<VQA=FEE;@!:8>]R90!:86UB:6$`6FEM8F%B=V4`6FEP<'D`
M6U-K:G5L(&-I=&5R970@=&5K<W1=`%M0<F]B;&5M8F5S:W)I=F5L<V5=`%M6
M:7,@8VET97)E="!T96MS="`M`%M6:7,@8VET97)E="!T96MS="`M("5S(&QI
M;FEE<ET`6VQI;FEE("5S('5D(&%F("5S70!!9&UI;FES=')A=&EO;@!#3$D`
M1&%T851R964`4VQE="!RYFMK90!'<G5P<&5R`$AJYFQP`$)I;&QE9"UE9V5N
M<VMA8F5R+BXN`$QO9R!I;F0`3&]G('5D`,9N9')I;F<@:&5N=FES;FEN9RXN
M+@!);F1S=&EL;&EN9V5R`%1I;&QA9&5L<V5R`%-L970@:&5N=FES;FEN9RXN
M+@!/<'/F=&YI;F<`5&%B96PM96=E;G-K86)E<BXN+@!"<G5G97)E`&%D<F5S
M<V5K87)T;W1E:P!A9')E<W-E;G0@=6ME;F1T`&MA;&5N9&5R`'9I;F1S=&EL
M;&4`:V%N(&EK:V4@9&%N;F4@=61D871A+69I;`!K86X@:6MK92#E8FYE(&EN
M9&1A=&$`:VQI:R!H97(`9F5J;"!V960@86YV96YD96QS92!A9B!K;VUM86YD
M;RUL:6YI90!K;VYF:6=U<F%T:6]N<V9E:FP`;6%N9VQE<B!K<FET:7-K('-Y
M<W1E;69I;`!F96IL(&D@9&%T869O<FUA=`!R961I9V5R`&EN9&=A;F<@:6MK
M92!F=6YD970`9F%L9&5N9&4`9FEL`&9R82`E<R`H)7,I(&UE9"`E<R`E<P!S
M=&]R;69U;&0`:#H`:&@`=6ME;F1T(&UA<VMI;FYA=FX`^&IE8FQI:VME;&EG
M=`!I;F1L96IR970`:6YD9&%T82]U9&1A=&$M9F5J;`!I;G1E<FX@<V]F='=A
M<F4M9F5J;`!L:6YI97)=`&UK:7-O9G,@9F5J;&MO9&4@)60@=6YD97(@9&%N
M;F5L<V4@868@25-/+@!M;0!N879N`&EK:V4@:6UP;&5M96YT97)E=`!E;F1N
M=2!I:VME(&EM<&QE;65N=&5R970`;F]T97-B;&]K`'!R;V-E;G0`=&EL;&%D
M96QS92!NYF=T970`<')I:VME<@!F96IL(&D@<')O=&]K;VP@9G)A(&9J97)N
M('-I9&4`<W1I9V5N9&4`=&IE;F5S=&4@=71I;&?F;F=E;&EG`'9I<R!F;W)S
M:V5L;&4`<VUS,F5M86EL('9I82!(5%10`'-S`'-T86)I;'0`<WES=&5M9F5J
M;`!O<&=A=F5L:7-T90!M:61L97)T:61I9R!F96IL=&EL<W1A;F0`:6YD=&%S
M="!K;V1E;W)D970@=&\@9V%N9V4@9F]R(&%T(&)E:W+F9G1E`'-A;6UE;G-M
M96QT970`=6YA=FYG:79E;@!B<G5G97)V86QG`'9#87)D`'<Z`'=E871H97(N
M8V]M````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M;V-A;&4O8G-?0D$O3$-?34534T%'15,`````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#0T`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]B<U]"02],0U]-15-304=%4R]H;W)D
M92YM;P``````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U-30S-R`Q,#4Q-30S
M-#$T,2`P,C,Q-S<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````WA($E0````"-`0``'````(0,```=`@``[!@```````!@(0``
M#@```&$A```-````<"$```@```!^(0``"P```(<A```,````DR$```0```"@
M(0``#````*4A```+````LB$```4```"^(0``*````,0A```(````[2$```H`
M``#V(0``%0````$B```2````%R(```L````J(@``"@```#8B```-````02(`
M``X```!/(@``$0```%XB```-````<"(```P```!^(@``#0```(LB```&````
MF2(```P```"@(@``#@```*TB```.````O"(```@```#+(@``&@```-0B```%
M````[R(``!$```#U(@``"`````<C```0````$",```\````A(P``"@```#$C
M```#````/",```D```!`(P``#P```$HC```*````6B,``"0```!E(P``%```
M`(HC```,````GR,``"P```"L(P``"P```-DC```'````Y2,```<```#M(P``
M`P```/4C```C````^2,``!0````=)```%P```#(D```7````2B0``!\```!B
M)```!0```((D```Y````B"0```8```#")```%````,DD```*````WB0```0`
M``#I)```!P```.XD```)````]B0```8`````)0``$0````<E```'````&24`
M`!8````A)0``!````#@E```(````/24```8```!&)0``#0```$TE```&````
M6R4``!X```!B)0``$0```($E```(````DR4```T```"<)0``#````*HE```'
M````MR4```,```"_)0```P```,,E```3````QR4```@```#;)0``"````.0E
M```(````[24``"````#V)0``!@```!<F```&````'B8``!4````E)@``%0``
M`#LF```4````428``!@```!F)@``'0```'\F```&````G28``%0```"D)@``
M!0```/DF```%````_R8``!L````%)P``&@```"$G```1````/"<``!$```!.
M)P``'````&`G```J````?2<``!````"H)P``!0```+DG```3````OR<``!``
M``#3)P``!P```.0G```'````["<```0```#T)P``#@```/DG```&````""@`
M``T````/*```$````!TH```2````+B@``"@```!!*```!0```&HH```$````
M<"@```@```!U*```!P```'XH```-````AB@``!````"4*```"P```*4H```&
M````L2@``!D```"X*```&````-(H```4````ZR@```L`````*0``"0````PI
M```6````%BD```\````M*0``%@```#TI```(````5"D```L```!=*0``!```
M`&DI```/````;BD``!````!^*0``%P```(\I```1````IRD```T```"Y*0``
M"0```,<I```@````T2D``!$```#R*0``!P````0J```%````#"H```<````2
M*@``"````!HJ```&````(RH```8````J*@``$````#$J```/````0BH``!``
M``!2*@``#P```&,J```+````<RH```\```!_*@``#````(\J```/````G"H`
M``@```"L*@``!P```+4J```$````O2H``!````#"*@```@```-,J```-````
MUBH``!(```#D*@``%0```/<J```$````#2L```4````2*P``!````!@K```,
M````'2L```H````J*P``"````#4K```)````/BL```4```!(*P``"@```$XK
M```9````62L``"D```!S*P``!P```)TK```*````I2L```P```"P*P``#P``
M`+TK```0````S2L```\```#>*P``!P```.XK```6````]BL```0````-+```
M!````!(L```'````%RP```@````?+```(````"@L```-````22P```X```!7
M+```%@```&8L```1````?2P```8```"/+````P```)8L```&````FBP```<`
M``"A+```!P```*DL```'````L2P``!8```"Y+```#0```-`L```%````WBP`
M`!X```#D+```"0````,M```*````#2T```P````8+0``#P```"4M```(````
M-2T```8````^+0``!P```$4M```+````32T``$<```!9+0``#0```*$M```)
M````KRT```H```"Y+0``:````,0M```%````+2X``!L````S+@``+P```$\N
M```0````?RX```H```"0+@``#P```)LN```*````JRX```D```"V+@```P``
M`,`N```'````Q"X```H```#,+@``"P```-<N```'````XRX```D```#K+@``
M!P```/4N```0````_2X```0````.+P``!P```!,O```%````&R\```T````A
M+P``#````"\O```(````/"\``!<```!%+P``"P```%TO```3````:2\```0`
M``!]+P``"@```((O```$````C2\```P```"2+P``"0```)\O```%````J2\`
M``<```"O+P``!0```+<O```$````O2\```(```#"+P``(0```,4O```$````
MYR\``!0```#L+P``"`````$P```'````"C```!`````2,```!P```",P```.
M````*S````4````Z,```$0```$`P```(````4C````8```!;,```!P```&(P
M```>````:C```"@```"),```"@```+(P```:````O3```!0```#8,```*```
M`.TP```J````%C$``!````!!,0``!P```%(Q```3````6C$```T```!N,0``
M'@```'PQ```4````FS$```X```"P,0``*@```+\Q```%````ZC$``!$```#P
M,0``!P````(R```4````"C(``!@````?,@``#````#@R```&````13(```\`
M``!,,@``)P```%PR```9````A#(``!\```">,@``$P```+XR```(````TC(`
M``<```#;,@``"````.,R```)````[#(``!4```#V,@``#0````PS```3````
M&C,```,````N,P``1@```#(S```_````>3,``#<```"Y,P``5P```/$S```%
M````230```H```!/-```#0```%HT```M````:#0```0```"6-```)0```)LT
M```?````P30``!T```#A-```!````/\T```0````!#4``!L````5-0``!P``
M`#$U```'````.34```0```!!-0``'P```$8U```G````9C4``",```".-0``
M'P```+(U```O````TC4``"$````"-@``'````"0V```Q````038```(```!S
M-@``%````'8V```,````BS8```<```"8-@``#P```*`V```4````L#8``!T`
M``#%-@``!P```.,V```R````ZS8``"$````>-P``#````$`W```1````33<`
M``@```!?-P``!P```&@W```'````<#<```8```!X-P``!P```'\W```-````
MAS<```L```"5-P``%````*$W```5````MC<```X```#,-P``+P```-LW```Q
M````"S@``#\````].```!@```'TX```#````A#@``#4```"(.```&0```+XX
M```P````V#@``!(````).0``$P```!PY```0````,#D``'D```!!.0``"0``
M`+LY```K````Q3D``!<```#Q.0``%@````DZ```/````(#H``!\````P.@``
M0````%`Z```?````D3H``!P```"Q.@``40```,XZ```4````(#L```H````U
M.P``!0```$`[```&````1CL```@```!-.P``!0```%8[```2````7#L``!``
M``!O.P``$P```(`[```=````E#L```\```"R.P``#P```,([```$````TCL`
M``D```#7.P``"P```.$[```'````[3L```4```#U.P``%````/L[```'````
M$#P```@````8/```#P```"$\```(````,3P```P````Z/```#P```$<\```&
M````5SP``!0```!>/```!@```',\```,````>CP```D```"'/```!P```)$\
M```%````F3P```L```"?/```=0$``*L\```0````(3X```T````R/@``"```
M`$`^```(````23X```<```!2/@```P```%H^```*````7CX```T```!I/@``
M!0```'<^```?````?3X```X```"=/@``"@```*P^```1````MSX```\```#)
M/@``"@```-D^```)````Y#X``!$```#N/@``#@`````_```*````#S\```L`
M```:/P``#0```"8_```)````-#\```8````^/P``#P```$4_```/````53\`
M``\```!E/P``!P```'4_```:````?3\```4```"8/P``#@```)X_```-````
MK3\``!@```"[/P``$@```-0_```-````YS\```4```#U/P``#````/L_```6
M````"$````P````?0```'P```"Q````0````3$````8```!=0```-@```&1`
M```*````FT````@```"F0```!0```*]````#````M4```"4```"Y0```%P``
M`-]````7````]T```"`````/00``'P```#!!```%````4$$``"L```!600``
M!@```()!```6````B4$```L```"@00``!0```*Q!```(````LD$```H```"[
M00```P```,9!```0````RD$```8```#;00``$P```.)!```#````]D$```<`
M``#Z00```P````)"```-````!D(```8````40@``)@```!M"```1````0D(`
M``@```!40@``$````%U"```,````;D(```<```![0@```P```(-"```#````
MAT(``!(```"+0@``"````)Y"```'````IT(```<```"O0@``)0```+="```&
M````W4(```@```#D0@``'````.U"```3````"D,``!4````>0P``&P```#1#
M```?````4$,```@```!P0P``40```'E#```$````RT,```0```#00P``(0``
M`-5#```<````]T,```\````41```&````"1$```B````/40``"L```!@1```
M#P```(Q$```&````G$0``!8```"C1```"@```+I$```&````Q40```D```#,
M1```!P```-9$```0````WD0```<```#O1```#````/=$```,````!$4``!8`
M```110``.P```"A%```&````9$4```4```!K10``"````'%%```*````>D4`
M``\```"%10``$0```)5%```*````IT4```8```"R10``'0```+E%```9````
MUT4``"0```#Q10``!````!9&```*````&T8``"0````F1@``#@```$M&```6
M````6D8```@```!Q1@``"P```'I&```(````AD8``!````"/1@``$````*!&
M```6````L48``!4```#(1@``#````-Y&```(````ZT8``"@```#T1@``%0``
M`!U'```(````,T<```8````\1P``"````$-'```(````3$<```<```!51P``
M!@```%U'```0````9$<```\```!U1P``$0```(5'```/````ET<``!$```"G
M1P``$````+E'```+````RD<``!4```#61P``!P```.Q'```'````]$<```(`
M``#\1P``#0```/]'```%````#4@```\````32```$@```"-(```8````-D@`
M``4```!/2```"````%5(```'````7D@```T```!F2```#@```'1(```(````
M@T@```D```",2```!0```)9(```)````G$@``!@```"F2```+````+](```&
M````[$@```H```#S2```"P```/Y(```0````"DD```\````;20``$````"M)
M```&````/$D``!8```!#20``!````%I)```$````7TD```D```!D20``!0``
M`&Y)```A````=$D```\```"620``$@```*9)```@````N4D``!4```#:20``
M!P```/!)```%````^$D```@```#^20``!0````=*```&````#4H```@````4
M2@``'````!U*```+````.DH```<```!&2@``)P```$Y*```%````=DH```L`
M``!\2@``$0```(A*```:````FDH```@```"U2@``"@```+Y*```%````R4H`
M``X```#/2@``4@```-Y*```5````,4L```H```!'2P``"@```%)+``!*````
M74L```0```"H2P``)0```*U+```W````TTL``!`````+3```"````!Q,```2
M````)4P```L````X3```"@```$1,```#````3TP```<```!33```#0```%M,
M```+````:4P```8```!U3```"````'Q,```(````A4P``!0```".3````P``
M`*-,```%````ITP```8```"M3```#P```+1,```/````Q$P```L```#43```
M(P```.!,```+````!$T``!4````030``!P```"9-```*````+DT```4````Y
M30``#P```#]-```)````3TT```4```!930``"````%]-```#````:$T```0`
M``!L30```@```'%-```H````=$T```<```"=30``%P```*5-```(````O4T`
M``<```#&30``$0```,Y-```&````X$T```P```#G30``!@```/1-```2````
M^TT```4````.3@``!0```!1.```(````&DX``!D````C3@``+0```#U.```'
M````:TX``"0```!S3@``$0```)A.```U````JDX``#4```#@3@``$````!9/
M```(````)T\```T````P3P``#@```#Y/```C````34\``!H```!Q3P``$```
M`(Q/```L````G4\```<```#*3P``#P```-)/```'````XD\``!D```#J3P``
M%0````10```.````&E````4````I4```$````"]0```L````0%```!0```!M
M4```&````()0```8````FU````L```"T4```!P```,!0```(````R%````D`
M``#14```$@```-M0```-````[E```!4```#\4```!P```!)1``!(````&E$`
M`$<```!C40``/````*M1``!B````Z%$```@```!+4@``!P```%12```+````
M7%(``"P```!H4@``!P```)52```O````G5(``"8```#-4@``%P```/12```(
M````#%,```\````54P``&P```"53```$````05,```@```!&4P``!0```$]3
M```G````55,``"8```!]4P``&@```*13```6````OU,``#$```#64P``+P``
M``A4```>````.%0``#0```!75````@```(Q4```3````CU0```\```"C5```
M#@```+-4```.````PE0``!H```#15```(P```.Q4```(````$%4``#@````9
M50``'P```%)5```1````<E4``!8```"$50``#@```)M5```)````JE4```H`
M``"T50``"````+]5```+````R%4``!$```#450``#P```.95```4````]E4`
M`!4````+5@``#@```"%6```L````,%8``$0```!=5@``2@```*)6```(````
M[58```(```#V5@``,P```/E6```C````+5<``#4```!15P``$@```(=7```2
M````FE<``!````"M5P``@````+Y7```(````/U@``"8```!(6```&````&]8
M```6````B%@``!,```"?6```'````+-8```R````T%@``!,````#60``%P``
M`!=9``!.````+UD``!8```!^60``"P```)59```$````H5D```<```"F60``
M"````*Y9```%````MUD``!<```"]60``$@```-59```9````Z%D``"0````"
M6@``#@```"=:```/````-EH```0```!&6@``"0```$M:```+````55H```8`
M``!A6@``!@```&A:```1````;UH```L```"!6@``!@```(U:```1````E%H`
M``<```"F6@``"````*Y:```/````MUH```<```#'6@``$@```,]:```*````
MXEH```8```#M6@``#@```/1:```)`````UL```4````-6P``"P```!-;```!
M````QP```&(!``````````````````"*````00$``!<```!C````#0```&D`
M```?````CP`````````7`0````````````#W````4@```"D!``"T````B0$`
M````````````"@$``*8```"#````OP```!\!``!F````C0$``*0`````````
M`````&T!``#\````:`$``)\`````````NP```+(``````````````*<```"+
M`````````$(!``!'````$@$`````````````60```'P!``!N`0``^P``````
M````````\````'4```#>````VP```/@```!_``````````````"4````+@``
M``(!``!P`0``?@````````!V`0``3````*@````L````-`$``-4`````````
M-@```%@!````````+P```%`!``!>`0````````````"J````2P$``'D````$
M``````````````!*````9P$``,L````C`0``6P$``&`!``!$`0``````````
M```@`0``H0`````````M`0```````#(```"7````-P$``-8````D`0```P``
M``````#I````'````%4`````````A0```!$!````````K@``````````````
M`P$``#4```#O````@0```)(```!8````:@$``*L`````````S0```#\!````
M``````````@````<`0``DP```&X```"(``````````````#Z````"0```*4`
M````````C`$``%D!````````0P$``#,`````````+0````````""`0``5@$`
M`'P`````````"@```,,`````````@@```$D!``">````````````````````
M`````%P!````````%@```'<```"L````UP```%8```":````:@````\!````
M````P````,H````X````U````.8`````````V@```(<```".````"P``````
M``",````<@```!$```!/`0``,0$``"\!```E`0``Q```````````````'0``
M``````!5`0`````````````&`0``+@$```````#K````V`````````"U````
M````````````````%`````````!&`0``D0```#,!``"<`````````#T```#/
M````>@````````")````=````#$`````````0@```"H````>`0``.P```&L!
M``!7````#@$``+P````V`0```````)T```#!````2P```/(````9````-0$`
M````````````4@$`````````````O@```*D````B````/@$``.0````G`0``
M`````%``````````\0```%T!``!^`0````````0!```6`0``P@```"4`````
M````@````'8``````````````.T````9`0``:````($!``#Y`````````-,`
M```.````<````!4```"Y````A@```'\!````````[@```.<````%````````
M`(8!``!(`````````#X````5`0``;P$``-T```"#`0``X`````````!.`0``
M)@```)L```"(`0````````````"]````&@$````````K`0``@`$``',!``#1
M````N@```)D```!S````&````#<`````````WP```$H!``"Q````.@``````
M``#_````/P````````"@`````````#D```!(`0``,````.$````Y`0``;```
M`-P```!3`0``"`$``.H````T````30```"D```!%````=P$``,P`````````
M20``````````````>0$``%H!``#9`````````#(!```\`0```````(T```"$
M`0``!P```'L```#H````A0$``!0!``"'`0``>`$``&$!````````````````
M````````T````!`!````````*P````P!````````&@````````!1````?0``
M```````;`````````"@!```\`````````%H````[`0``\P```&<`````````
M(@$````````%`0`````````````&````'@```(H!````````HP``````````
M`````````"P!```A`0``7````$`!``!@````=`$````````J`0``N````.P`
M```P`0``0````/T```!?`0``8@```'H!```8`0``E0``````````````80``
M`#T!``!K````6P````````!O`````````"<````+`0``M@```%T```!?````
M`````#@!``#U````$@````(```"P````MP```!,``````````````$P!``#2
M````3@```/X```!I`0``30$``)@```!R`0``00```&4```"B````Q0```!T!
M````````KP```$0````C````Y0```$,````/````;`$```````!C`0``D```
M`$8`````````LP````<!``#)````]@````````!D``````````````!'`0``
M````````````````#`````````#B`````````&8!``"M````?0$``'4!````
M````.@$``,X```!%`0``5`````````!3````)````'@```![`0``<0``````
M``#&``````$``!L!``!7`0``A`````T!``!1`0```````/0`````````$```
M`,@```!4`0``3P```"@```#C`````````"8!``"6`````````"$`````````
M(````&4!````````"0$``%X````!`0``9`$```````!Q`0``$P$``&T```"+
M`0```"`H)7,@9&%Y<R!A9V\I`"`H:6X@)7,@9&%Y<RD`("AT;V1A>2D`("AT
M;VUO<G)O=RD`("AY97-T97)D87DI`"!A="``)60@)7,@86YD("5S`"5S("T@
M3F]T:6-E`"5S($M"`"5S($UA:6YT96YA;F-E($]P97)A=&EO;G,@+2!#;VYF
M:7)M871I;VX`)7,@4V5T=7``)7,@4VEG;B!5<``E<R!497)M<R!O9B!!9W)E
M96UE;G0`)7,@86QR96%D>2!E>&ES=',N`"5S(&%T("5S("5S`"5S(&UI;G5T
M97,`)7,@;F]T(&9O=6YD+@`E<R!T;R`E<R!O9B`E<P`E<R=S($%D9')E<W,@
M0F]O:P`E<R=S($-A;&5N9&%R`"5S)W,@3F]T97!A9``E<R=S(%1A<VML:7-T
M`"5S.B`E<P`M+2!S96QE8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&
M;W)M870`,C0@:&]U<G,`02!F871A;"!E<G)O<B!H87,@;V-C=7)R960`04TO
M4$T`06)O=70@=&AI<R!E9&ET;W(`06)O=70N+BX`06-C;W5N="!087-S=V]R
M9`!!8V-O=6YT(&9R;WIE;BX`06-C;W5N=&EN9P!!9&0`061D($AE<F4Z`$%D
M9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!T:&4@)7,@365N=2!A<R!A
M($UO>FEL;&$@4VED96)A<@!!9&0@=&\@861D<F5S<R!B;V]K.@!!9&1R97-S
M($)O;VL`061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M=7-E<G,`069G:&%N:7-T86X`06QB86YI80!!;&=E<FEA`$%L;`!!;&QO=R!S
M971T:6YG(&]F(&]R9&5R960@;&ES="!T>7!E/P!!;'1E<FYA=&4@24U34"!,
M;V=I;@!!;'1E<FYA=&4@24U34"!087-S=V]R9`!!;'1E<FYA=&4@24U34"!5
M<V5R;F%M90!!;B!I;&QE9V%L('9A;'5E('=A<R!S<&5C:69I960N`$%P<FEL
M`$%S:R!F;W(@8V]N9FER;6%T:6]N(&)E9F]R92!D;VEN9R!M86EN=&5N86YC
M92!O<&5R871I;VYS/P!!=6=U<W0`0F%L=&EC("A)4T\M.#@U.2TQ,RD`0FQO
M8VL@5'EP90!";VQD`$)O;&EV:6$`0F]O:VUA<FMS`$)O<F1E<@!";W)D97(@
M=&AI8VMN97-S.@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T
M:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN82!&87-O`$)U<G5N9&D`0TU3
M`$-20P!#7V5L;"!0<F]P97)T:65S+BXN`$-A;&5N9&%R`$-A;6)O9&EA`$-A
M;65R;V]N`$-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z("5S`$-A;F%D
M80!#86YC96P`0V%N8V5L(%!R;V)L96T@4F5P;W)T`$-A=&5G;W)I97,@86YD
M($QA8F5L<P!#96QT:6,@*$E33RTX.#4Y+3$T*0!#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,`0V5N=')A;"!%=7)O<&5A;B`H25-/+3@X-3DM,BD`0VAA;F=E
M`$-H86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@
M=VAE;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&EL
M90!#:&EN80!#:&EN97-E(%-I;7!L:69I960@*$=",C,Q,BD`0VAI;F5S92!4
M<F%D:71I;VYA;"`H0FEG-2D`0VAO;W-E(&$@<&%S<W=O<F0`0VAO;W-E(&$@
M=7-E<FYA;64`0VAO;W-E(&AO=R!T;R!D:7-P;&%Y(&1A=&5S.@!#:&]O<V4@
M;&ES="!S='EL92!T>7!E("AF;W(@;W)D97)E9"!L:7-T<RD`0VAR:7-T;6%S
M($ES;&%N9`!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-O;&]U<B!S96QE
M8W1I;VX`0V]M;W)O<P!#;VUP86YY`$-O<'D`0V]P>2!S96QE8W1I;VX`0W)E
M871E`$-R96%T92!A(&QI;FL`0W)E871E(&$@;F5W(&]N90!#<F5A=&4@<W5B
M(&9O;&1E<G,`0W5S=&]M:7IE('1A<VMS('1O(')U;B!U<&]N(&QO9V]N('1O
M("5S+@!$86EL>0!$871E`$1E8V5M8F5R`$1E9F%U;'0`1&5F875L="!#;VQO
M<@!$969A=6QT($ED96YT:71Y`$1E9FEN:71I;VYS`$1E;&5T90!$96QE=&4@
M86YD('!U<F=E(&UE<W-A9V5S`$1E;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$
M97-C<FEB92!T:&4@4')O8FQE;0!$97-C<FEP=&EO;@!$:7)E8W1O<GD`1&ES
M<&QA>2`R-"UH;W5R('1I;65S/P!$:7-P;&%Y($]P=&EO;G,`1&ES<&QA>2!F
M;W)E8V%S="`H5$%&*0!$;W=N;&]A9`!$;W=N;&]A9"`E<P!%9&ET`$5D:70@
M4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R;6ES<VEO;G,@
M9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5M86EL($%D9')E<W,`16UO=&EC
M;VYS`$5N86)L92!R:6=H="!C;&EC:R!C;VYT97AT(&UE;G4_`$5Q=6%T;W)I
M86P@1W5I;F5A`$5R:71R96$`17)R;W(`17-T;VYI80!%=&AI;W!I80!%=&AN
M:6,`175R;W!E`$5V97)Y(#$U(&UI;G5T97,`179E<GD@,B!M:6YU=&5S`$5V
M97)Y(#,P('-E8V]N9',`179E<GD@-2!M:6YU=&5S`$5V97)Y($QO9VEN`$5V
M97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AA;7!L92!V86QU97,Z`$9E
M8G)U87)Y`$9I;'1E<G,`1G)O;0!&=6QL($1E<V-R:7!T:6]N`$=O`$=O;V=L
M92!396%R8V@`1W)E96L@*$E33RTX.#4Y+3<I`$AE8G)E=R`H25-/+3@X-3DM
M."U)*0!(96QP`$AO7VUE`$AO;64`2&]M92!!9&1R97-S`$AO;64@4&AO;F4`
M2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E`$E0($%D9')E<W,`25`@061D<F5S
M<R!N;W0@879A:6QA8FQE+@!)4"!!9&1R97-S(&YO="!W:71H:6X@86QL;W=E
M9"!#2412(&)L;V-K+@!)8V5L86YD`$EC;VYS($]N;'D`26-O;G,@9F]R("5S
M`$EC;VYS('=I=&@@=&5X=`!)9&5N=&ET>2=S(&YA;64Z`$EN<V5R="!M97-S
M86=E<P!*86YU87)Y`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2G5L>0!*=6YE
M`$QA7WEO=70`3&%N9W5A9V4`3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P
M=6)L:6,`3&%S="!5<&1A=&5D.@!,87-T(&QO9VEN.B`E<P!,87-T(&QO9VEN
M.B`E<R!F<F]M("5S`$QA<W0@;&]G:6XZ($YE=F5R`$QA='9I80!,87<`3&%Y
M;W5T`$QE8F%N;VX`3&5S;W1H;P!,:6)E<FEA`$QI8GEA;B!!<F%B($IA;6%H
M:7)I>6$`3&EE8VAT96YS=&5I;@!,:6YK<P!,:7-T("T@=7-E<B!C86X@<V5E
M('1H92!F;VQD97(`3&ET:'5A;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@
M`$QO8V%L92!A;F0@5&EM90!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I
M;B!487-K<P!,;V=I;B!F86EL960@8F5C875S92!Y;W5R('5S97)N86UE(&]R
M('!A<W-W;W)D('=A<R!E;G1E<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL
M960N`$QO;F<@=&5X=`!,=7AE;6)O=7)G`$UA;F%G92!T:&4@;&ES="!O9B!C
M871E9V]R:65S('EO=2!H879E('1O(&QA8F5L(&ET96US('=I=&@L(&%N9"!C
M;VQO<G,@87-S;V-I871E9"!W:71H('1H;W-E(&-A=&5G;W)I97,N`$UA<F-H
M`$UA<FL@=VET:"!3965N+U5N<V5E;B!F;&%G<P!-87)K('=I=&@@;W1H97(@
M9FQA9W,@*&4N9RX@26UP;W)T86YT+T%N<W=E<F5D*0!-87)S:&%L;"!)<VQA
M;F1S`$UA<G1I;FEQ=64`36%T8VAI;F<@9FEE;&1S`$UA=7)I=&%N:6$`36%U
M<FET:75S`$UA>0!-96UB97)S`$UE;G4@;6]D93H`365R9V4@8V5L;',`365S
M<V%G90!-:6UE(%1Y<&4`36]N=&AL>0!->2!0;W)T86P@3&%Y;W5T`$YA;64`
M3F5T=V]R:P!.979E<@!.97<@0V%L961O;FEA`$YE=R!#871E9V]R>0!.97<@
M36]O;@!.97<@57-E<FYA;64@*&]P=&EO;F%L*0!.97<@6F5A;&%N9`!.97<@
M=VEN9&]W("A?8FQA;FLI`$YE=W,`3F5W<V=R;W5P<P!.97AT`$YE>'0@;W!T
M:6]N<P!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.:75E`$YO`$YO
M('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;VYE`$YO<F1I8R`H
M25-/+3@X-3DM,3`I`$YO=F5M8F5R`$]C=&]B97(`3W!E<F%T:6YG(%-Y<W1E
M;0!/<'1I;VYS`$]P=&EO;G,@9F]R("5S`$]T:&5R`$]T:&5R($EN9F]R;6%T
M:6]N`%!A<W-W;W)D`%!E;W!L90!097)C96YT`%!E<F9O<FT@36%I;G1E;F%N
M8V4@3W!E<F%T:6]N<P!097)F;W)M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@
M;VX@;&]G:6X_`%!E<FUI<W-I;VX`4&5R;6ES<VEO;G,@061M:6YI<W1R871I
M;VX`4&5R<V]N86P@26YF;W)M871I;VX`4&QE87-E('!R;W9I9&4@82!S=6UM
M87)Y(&]F('1H92!P<F]B;&5M+@!0;W-T('1O('1H:7,@9F]L9&5R("AN;W0@
M96YF;W)C960@8GD@24U!4"D`4')E=FEO=7,@;W!T:6]N<P!0<F]B;&5M`%!R
M;V)L96T@1&5S8W)I<'1I;VX`4F5A9"!M97-S86=E<P!2969R97-H($1Y;F%M
M:6,@365N=2!%;&5M96YT<SH`4F5F<F5S:"!0;W)T86P@5FEE=SH`4F5M;W1E
M(%-E<G9E<G,`4F5M;W1E(%523"`H:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]H
M;W)D92DZ`%)E<V5T`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`4F5V97)T
M($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS`%-A=F4@
M3W!T:6]N<P!396%R8V@`4V5L96-T(&$@<V5R=F5R`%-E;&5C="!T:&4@:61E
M;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E.@!396QE8W0@>6]U<B!C;VQO<B!S
M8VAE;64N`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0
M<F]B;&5M(%)E<&]R=`!396YD(%--4P!396YE9V%L`%-E;G-O<CH@`%-E<'1E
M;6)E<@!397)B:6$@86YD($UO;G1E;F5G<F\`4V5R:6%L($YU;6)E<@!397-S
M:6]N($E$(&5X<&ER960N`%-E=`!3970@;W!T:6]N<R!T;R!A;&QO=R!Y;W4@
M=&\@<F5S970@>6]U<B!P87-S=V]R9"!I9B!Y;W4@979E<B!F;W)G970@:70N
M`%-E="!U<"!R96UO=&4@<V5R=F5R<R!T:&%T('EO=2!W86YT('1O(&%C8V5S
M<R!F<F]M('EO=7(@<&]R=&%L+@!3970@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4L('1I;65Z;VYE(&%N9"!D871E(&]P=&EO;G,N`%-E="!Y;W5R('-T87)T
M=7`@87!P;&EC871I;VXL(&-O;&]R('-C:&5M92P@<&%G92!R969R97-H:6YG
M+"!A;F0@;W1H97(@9&ES<&QA>2!O<'1I;VYS+@!3971U<`!397EC:&5L;&5S
M`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!L87-T(&QO9VEN('1I;64@=VAE
M;B!L;V=G:6YG(&EN/P!3:&]W('1A8FQE(&]P97)A=&EO;G,@;65N=2!B87(_
M`%-H;W<@=&AE("5S($UE;G4@;VX@=&AE(&QE9G0_`%-I>F4`4VMI<"!-86EN
M=&5N86YC90!3;W5T:"!%=7)O<&5A;B`H25-/+3@X-3DM,RD`4W5B:F5C=`!3
M=6-C97-S`%1E>'0`5&AA;FL@>6]U(&9O<B!U<VEN9R!T:&4@<WES=&5M+@!4
M:&4@3W!T:6]N<R!W:6YD;W<@:&%S(&-L;W-E9"X@17AI=&EN9RX`5&AE(&ED
M96YT:71Y("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE<F4@87)E(&YO(&]P
M=&EO;G,@879A:6QA8FQE+@!4:&5R92!W87,@86X@97)R;W(@9&ES<&QA>6EN
M9R!T:&ES(&UE<W-A9V4@<&%R=`!4:&ES(&YU;6)E<B!M=7-T(&)E(&%T(&QE
M87-T(&]N92X`5&AI<R!V86QU92!M=7-T(&)E(&$@;G5M8F5R+@!4:&ES('=I
M;F1O=R!M=7-T(&)E(&-A;&QE9"!F<F]M(&%N($]P=&EO;G,@=VEN9&]W`%1O
M`%1U<FMI<V@@*$E33RTX.#4Y+3DI`%5N9&\@0VAA;F=E<P!5;F9I;&5D`%5N
M:6-O9&4@*%541BTX*0!5;FET960@07)A8B!%;6ER871E<P!5;FMN;W=N('5S
M97)N86UE(&]R('!A<W-W;W)D+@!5;FYA;65D`%5S92!I9B!N86UE+W!A<W-W
M;W)D(&ES(&1I9F9E<F5N="!F;W(@24U34"!S97)V97(N`%5S97(@)7,@:7,@
M;F]T(&%U=&AO<FES960@9F]R("5S+@!5<V5R($]P=&EO;G,`57-E<B!296=I
M<W1R871I;VX`57-E<FYA;64`5FEE=R`E<P!787)N:6YG`%=E96ML>0!796QC
M;VUE`%=E;&-O;64@=&\@)7,`5V5L8V]M92P@)7,`5V5S=&5R;B`H25-/+3@X
M-3DM,2D`5V5S=&5R;B`H25-/+3@X-3DM,34I`%=E<W1E<FX@4V%H87)A`%=H
M870@87!P;&EC871I;VX@<VAO=6QD("5S(&1I<W!L87D@869T97(@;&]G:6X_
M`%=H:6-H('!L=6=I;G,@=&\@96YA8FQE(&9O<B!T:&4@4FEC:"!497AT(&5D
M:71O<BX`5VED=&@@;V8@=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S
M(&5F9F5C="!O;B!N97AT(&QO9RUI;BDZ`%EE87)L>0!997,`66]U(&-A;B!N
M;W0@:&%V92!T:&4@)UPG(&-H87)A8W1E<B!I;B!Y;W5R(&9U;&P@;F%M92X`
M66]U(&AA=F4@8F5E;B!L;V=G960@;W5T+@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!%;6%I;"!!9&1R
M97-S`%EO=7(@1G)O;3H@861D<F5S<SH`66]U<B!);F9O<FUA=&EO;@!9;W5R
M($EN=&5R;F5T($%D9')E<W,@:&%S(&-H86YG960@<VEN8V4@=&AE(&)E9VEN
M;FEN9R!O9B!Y;W5R("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U
M<FET>2P@>6]U(&UU<W0@;&]G:6X@86=A:6XN`%EO=7(@3F%M90!9;W5R(&)R
M;W=S97(@9&]E<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N`%EO=7(@8W5R
M<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L="!I9&5N=&ET>3H`66]U<B!F
M=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D(&9O<B`E<R!I<SH@)7,`66]U
M<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@
M;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T
M960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@<F5S970`66]U<B!P87-S=V]R
M9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U<B!E;6%I;"!A;F0@;&]G(&EN
M('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO=7(@<F5M;W1E('-E<G9E<G,Z
M`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II;6)A8G=E`%II<'!Y`%M(:61E
M(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O<G1=`%M3:&]W(%%U;W1E9"!4
M97AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E<R!L:6YE<UT`6VQI;F4@)7,@
M;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)`%]$871A5')E90!?1&5L971E
M(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0<F]P97)T:65S+BXN`%],;V<@
M:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN`%]/<'1I;VYS`%]097)M:7-S
M:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P`%]486)L92!0<F]P97)T:65S
M+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`=&%S:R!L:7-T`'5N;F%M960`=D-A
M<F0`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S:6]N.B!H;W)D92UB<PI2
M97!O<G0M37-G:60M0G5G<RU4;SH@9&5V0&QI<W1S+FAO<F1E+F]R9PI03U0M
M0W)E871I;VXM1&%T93H@,C`P-2TQ,"TQ."`Q-3HQ,BLP,C`P"E!/+5)E=FES
M:6]N+41A=&4Z(#(P,#4M,#<M,#$@,3,Z,S$K,#(P,`I,87-T+51R86YS;&%T
M;W(Z(%9E9')A;B!,:G5B;W9I8R`\=FQJ=6)O=FEC0'-M87)T;F5T+F)A/@I,
M86YG=6%G92U496%M.B!";W-N:6%N(#QL;VMA;$!L:6YU>"YO<F<N8F$^"DU)
M344M5F5R<VEO;CH@,2XP"D-O;G1E;G0M5'EP93H@=&5X="]P;&%I;CL@8VAA
M<G-E=#U)4T\M.#@U.2TR"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB
M:70*6"U'96YE<F%T;W(Z($M"86)E;"`Q+C$P"@`@*'!R:6IE("5S(&1A;F$I
M`"`H>F$@)7,@9&%N82D`("AD86YA<RD`("AS=71R82D`("AJ=>AE*0`@=2``
M)60@)7,@:2`E<P`E<R`M($YA<&]M96YA`"5S($M"`"5S(%-E<G9I<VYE(&]P
M97)A8VEJ92`M('!O='9R9&$`)7,@<&]D9;EA=F%N:F4`)7,@<')I:F%V80`E
M<R!U<VQO=FD@=6=O=F]R80`E<R!V9>8@<&]S=&]J:2X`)7,@=2`E<R`E<P`E
M<R!M:6YU=&$`)7,@;FEJ92!P<F]N8?!E;BX`)7,@>F$@)7,@;V0@)7,`)7,@
M861R97-A<@`E<R!K86QE;F1A<@`E<R!B:6QJ9;YN:6-A`"5S('IA9&%C:0`E
M<SH@)7,`+2T@:7IA8F5R:71E("TM`#$R+7-A=&YI(&9O<FUA=``R-"US871N
M:2!F;W)M870`,C0@<V%T80!$;[EL;R!J92!D;R!F871A;&YE(&=R9;EK90!!
M32]030!/(&]V;VT@961I=&]R=0!/('!R;V=R86UU+BXN`*EI9G)A(&MO<FES
M;FGH:V]G(&YA;&]G80!.86QO9R!J92!Z86UR>FYU="X`4F'H=6YO=F]D<W1V
M;P!$;V1A:@!$;V1A:B!O=F1J93H`1&]D86H@;F]V;V<@:V]R:7-N:6MA.@!$
M;V1A:B!K;VQO;G4`1&]D86H@)7,@;65N:2!U($UO>FEL;&$@4VED96)A<@!$
M;V1A:B!U(&%D<F5S87(Z`$EM96YI:P!!9&UI;FES=')I<F%N:F4@+2!P;V1E
MN6%V86YJ92!D;WIV;VQA(&1R=6=I:"!K;W)I<VYI:V$`069G86YI<W1A;@!!
M;&)A;FEJ80!!;+YI<@!3=F4`1&]Z=F]L:2!P<F%V;&IE;FIE(&YU;65R:7-A
M;FEH(&QI<W1I/P!!;'1E<FYA=&EV;FD@24U34"!L;V=I;@!!;'1E<FYA=&EV
M;F$@24U34""Y:69R80!!;'1E<FYA=&EV;F\@24U34"!K;W)I<VYIZ&MO(&EM
M90!5;F6Y96YA(&IE(&EL96=A;&YA('9R:6IE9&YO<W0N`$%P<FEL`%!I=&%J
M('!R:6IE(&]B879L:F%N:F$@<V5R=FES;FEH(&]P97)A8VEJ83\`075G=7-T
M`$)A;'1IZ&MI("A)4T\M.#@U.2TQ,RD`5G)S=&$@8FQO:V$`36%S;F\`0F]L
M:79I:F$`6F%B:6QJ9;EK90!2=6(`1&5B;&II;F$@<G5B;W9A.@!2=6)O=FD`
M0F]S;F$@:2!(97)C96=O=FEN80!/8F$`0F]C=F%N80!$;F\`0F]U=F5T(&]S
M=')V;P!"<F%Z:6P`0G)I=&%N<VMA($EN9&EJ<VMO+4]K96%N<VMA(%1E<FET
M;W)I:F$`0G)U;F5I($1A<G5S<V%L86T`0G5G87)S:V$`3&ES=&$@<V$@=&'H
M:V%M80!"=7)K:6YA($9A<V\`0G5R=6YD:0!#35,`0U)#`$]S;V)I;F4@YE]E
M;&EJ92XN+@!+86QE;F1A<@!+86UB;_!A`$MA;65R=6X`3F4@;6]G=2!S92!S
M<&]J:71I(&YA($E-05`@<V5R=F5R.B`E<P!+86YA9&$`3V1U<W1A;FD`3V1U
M<W1A;FD@;V0@<')I:F%V92!P<F]B;&5M80!+871E9V]R:6IE(&D@;WIN86ME
M`$ME;'1S:VD@*$E33RTX.#4Y+3$T*0!#96YT<F%L;F\M069R:>AK82!297!U
M8FQI:V$`0V5N=')A;&YO+65V<F]P<VMI("A)4T\M.#@U.2TR*0!0<F]M:F5N
M:0!0<F]M:6IE;FET92!I;64@:2!A9')E<W4@:V]J92!V:61E(&1R=6=I(&MA
M9&$@Z&ET86IU(&D@;V1G;W9A<F%J=2!N82!V8;EE('!O<G5K92X`R&EL90!+
M:6YA`$MI;F5S:VD@<&]J961N;W-T879L:F5N:2`H1T(R,S$R*0!+:6YE<VMI
M('1R861I8VEO;F%L;FD@*$)I9S4I`$EZ86)E<FET92"Y:69R=0!)>F%B97)I
M=&4@:V]R:7-N:>AK;R!I;64`27IA8F5R:71E(&MA:V\@<V4@<')I:V%Z=6IE
M(&1A='5M.@!)>F%B97)I=&4@=G)S='4@<W1I;&$@*'IA(&YU;65R:7-A;F4@
M;&ES=&4I`%5S:W*Y;FIE(&]S=')V;P!/Z&ES=&D`3^AI<W1I($U33V9F:6-E
M('1A9V]V90!)>F)O<B!B;VIE`$MO;6]R:0!+;VUP86YI:F$`2V]P:7)A:@!+
M;W!I<F%J(&EZ86)R86YO`$MR96ER86H`3F%P<F%V:2!L:6YK`$YA<')A=FD@
M;F]V:0!0<F%V;&IE;FIE('!O9"UF;VQD97)A`%!O9&5S:71E('IA9&%T:V4@
M:V]J:2#F92!S92!I>G9RN6%V871I(&YA:V]N('!R:6IA=F4@;F$@)7,N`$1N
M979N;P!$871U;0!$96-E;6)A<@!3=&%N9&%R9&YO`%-T86YD87)D;F$@8F]J
M80!$969A=6QT(&ED96YT:71E=`!$969I;FEC:6IE`$]B<FFY:0!"<FES86YJ
M92!I(&EZ8F%C:79A;FIE('!O<G5K80!/8G)IN6D@:7IA8G)A;FD@:61E;G1I
M=&5T`$]P:;EI=&4@<')O8FQE;64@=2!R861U('-A('=E8FUA:6QO;0!/<&ES
M`$1I<F5K=&]R:6H`4')I:V&^:2!V<FEJ96UE('4@,C0M<V%T;F]M(&9O<FUA
M='4_`$]P8VEJ92!P<FEK87IA`%!R:6MAOFD@<')O9VYO>G4@*%1!1BD`1&]W
M;FQO860`1&]W;FQO860@)7,`27IM:6IE;FD`27IM:6IE;FD@9&]Z=F]L=0!)
M>FUI:F5N:2!D;WIV;VQE`$EZ;6EJ96YI(&1O>G9O;&4@>F$@)7,`27IM:6IE
M;FET92!O<&-I:F4@>F$Z`$5M86EL(&%D<F5S80!3;6%J;&EJ:0!!:W1I=FER
M86H@:V]N=&5K<W0@;65N:2!N82!D97-N;VT@:VQI:W4_`$5K=F%T;W)I:F%L
M;F$@1W9I;F5J80!%<FET<F5J80!'<F6Y:V$`17-T;VYI:F$`171I;W!I:F$`
M171N:>AK:0!%=G)O<&$`4W9A:VEH(#$U(&UI;G5T80!3=F%K:6@@,B!M:6YU
M=&4`4W9A:VEH(#,P('-E:W5N9&D`4W9A:VEH(#4@;6EN=71A`$MO9"!S=F%K
M92!P<FEJ879E`%-V86MI:"!P;VQA('-A=&$`4W9A:VD@;6EN=70`5G)I:F5D
M;F]S=&D@<')I;6IE<FDZ`$9E8G)U87(`1FEL=&5R:0!/9`!$971A;&IA;B!O
M<&ES`$MR96YI`$=O;V=L92!P<F5T<F%G80!'<NAK:2`H25-/+3@X-3DM-RD`
M2&5B<F5J<VMI("A)4T\M.#@U.2TX+4DI`%!O;6_F`%!OZ%]E=&%K`%!OZ&5T
M86L`061R97-A("AK=>9I*0!496QE9F]N("AK=>9I*0!(;VYD=7)A<P!(;VYG
M($MO;F<`2&]R9&4`25`@861R97-A`$E0(&%D<F5S82!N:6IE(&1O<W1U<&YA
M+@!)4"!A9')E<V$@;FEJ92!D;WIV;VQJ96YA('5N=71A<B!#2412(&)L;VMA
M+@!)<VQA;F0`4V%M;R!I:V]N90!):V]N92!Z82`E<P!):V]N92!S82!T96MS
M=&]M`$EM92!I9&5N=&ET971A.@!$;V1A=F%N:F4@<&]R=6MA`$IA;G5A<@!*
M87!A;G-K:2`H25-/+3(P,C(M2E`I`$IU;&D`2G5N:0!285]S<&]R960`2F5Z
M:6L`3&%O($YA<F]D;F$@1&5M;VMR871S:V$@4F5P=6)L:6MA`%IA9&YJ82!I
M>FUJ96YA.@!:861N:F$@<')I:F%V83H@)7,`6F%D;FIA('!R:6IA=F$Z("5S
M('-A(&%D<F5S93H@)7,`6F%D;FIA('!R:6IA=F$Z($YI:V%D`$QA='9I:F$`
M6F%K;VX`4F%S<&]R960`3&EB86X`3&5S;W1O`$QI8F5R:6IA`$QI8FEJ<VMA
M($%R87!S:V$@1+YA;6%H:7)I:F$`3&EH=&5NN71A:FX`3&EN:V]V:0!,:7-T
M86YJ92`M(&MO<FES;FEK(&UOOF4@=FED:F5T:2!F;VQD97(`3&ET=F$`5>AI
M=&%V86TN+BX`3&]K86QN;R!V<FEJ96UE.B``3&]K86QN92!P;W-T879K92!I
M('9R:6IE;64`3&]K86-I:F$`4')I:F%V:2!S90!)>FQA>@!:861A8VD@<')I
M:F%V90!0<FEJ879A(&YI:F4@=7-P:F5L82X@3F%J=F5R;W9A=&YI:F4@:F4@
M<&]G<F6Y;F\@=6YE<V5N;R!K;W)I<VYIZ&MO(&EM92!I;&D@N6EF<F$N`%!R
M:6IA=F$@;FEJ92!U<W!J96QA+@!$=6=I('1E:W-T`$QU:W-E;6)U<F<`3F%P
M<F%V:71E(&MA=&5G;W)I:F4@<W1A=FMI(&D@>F$@<W9A:W4@;V0@;FII:"!O
M9')E9&ET92!O9&=O=F%R86IUYG4@8F]J=2X`36%R=`!/>FYAZ&%V86YJ92!K
M86\@<')OZ&ET86YO+VYE<')OZ&ET86YO`$]Z;F'H879A;FIE(&1R=6=I;2!O
M>FYA:V%M82`H;G!R+B!V8;YN;R!I;&D@;V1G;W9O<F5N;RD`36%RN6%L;W9A
M(&]S=')V80!-87)T:6YI:P!/9&=O=F%R86IUYF$@<&]L:F$`36%U<FET86YI
M:F$`36%U<FEC:6IU<P!-86H`R&QA;F]V:0!6<G-T82!M96YI:F$Z`%-P;VII
M('!O;&IA`%!O<G5K80!-:6UE('1I<`!-:F5S9>AN;P!287-P;W)E9"!M;V<@
M<&]R=&%L80!);64`37)EOF$`3FEK861A`$YO=F$@2V%L961O;FEJ80!.;W9A
M(&MA=&5G;W)I:F$`3F]V:2!M:F5S96,`3F]V;R!K;W)I<VYIZ&MO(&EM92`H
M;FEJ92!O8F%V97IN;RD`3F]V:2!:96QA;F0`3F]V:2!P<F]Z;W(@*%]P<F%Z
M86XI`$YO=F]S=&D`3F5W<RUG<G5P90!$86QJ90!3;&IE9&7F92!O<&-I:F4`
M3FEK87)A9W9A`$YI9V5R`$YI9V5R:6IA`$YOY@!.:75E`$YE`$YI:F4@<&]S
M;&%N;R!K;W)I<VYIZ&MO(&EM92!I+VEL:2"Y:69R82X`3FEJ961A;@!.;W)D
M:6IS:VD@*$E33RTX.#4Y+3$P*0!.;W9E;6)A<@!/:W1O8F%R`$]P97)A=&EV
M;FD@<VES=&5M`$]P8VEJ90!/<&-I:F4@>F$@)7,`3W-T86QO`$]S=&%L92!I
M;F9O<FUA8VEJ90"I:69R80!,:G5D:0!0<F]C96YA=`!)>G9RN6D@<V5R=FES
M;F4@;W!E<F%C:6IE`$EZ=G*Y:2!S97)V:7-N92!O<&5R86-I:F4@<')I;&EK
M;VT@;&]G:7)A;FIA/P!$;WIV;VQE`$%D;6EN:7-T<F%C:6IA(&1O>G9O;&$@
M*'!R:79I;&5G:6IA*0!,:>AN92!I;F9O<FUA8VEJ90!-;VQI;6\@9&%J=&4@
M:W)A=&%K(&]P:7,@=F&Y96<@<')O8FQE;6$@<V$@=V5B;6%I;&]M+@!3;&%N
M:F4@=2!O=F%J(&9O;&1E<B`H;FEJ92!P<FEN=?!E;F\@;V0@<W1R86YE($E-
M05!A*0!0<F5T:&]D;F4@;W!C:6IE`%!R;V)L96T_`$]P:7,@<')O8FQE;6$`
MR&ET86YJ92!P;W)U:V$`0;YU<FER86H@9&EN86UIZ&ME(&5L96UE;G1E(&UE
M;FEJ83H`0;YU<FER86H@<&_H971N=2!S=')A;FEC=3H`561A;&IE;FD@<V5R
M=F5R:0!59&%L:F5N:2!54DP@*&AT='`Z+R]W=W<N97AA;7!L92YC;VTO:&]R
M9&4I.@!0;VYIN71I`$YA>F%D(&YA(&]P8VEJ90!2975N:6]N`%9R871I('-T
M87)U(&MO;F9I9W5R86-I:G4`3W!C:6IE(&5D:71O<F$@=&5K<W1A`%-AZ'5V
M86H@;W!C:6IE`%1R8;YI`$EZ86)E<FET92!S97)V97(`27IA8F5R:71E(&ED
M96YT:71E="!K;VII(+YE;&ET92!P<F]M:6IE;FET:3H`27IA8F5R:71E(+EE
M;74@8F]J82X`27IA8F5R:71E(+YE;&IE;FD@:F5Z:6LZ`%!ON6%L:FD@<')I
M:F%V=2!P<F]B;&5M80!0;[EA;&II(%--4P!396YE9V%L`%-E;GIO<CH@`%-E
M<'1E;6)A<@!3<F)I:F$@:2!#<FYA($=O<F$`4V5R:6IS:VD@8G)O:@!)1"!S
M97-I:F4@:F4@:7-T96MA;RX`3V1A8F5R:0!0;V1E<VET92!O<&-I:F4@:V]J
M92!V86T@;VUO9W7F=6IU(&1A('!O;FFY=&ET92"Y:69R=2!A:V\@:F4@>F%B
M;W)A=FET92X`4&]D97-I=&4@=61A;&IE;F4@<V5R=F5R92!K;VII;6$@OF5L
M:71E('!R:7-T=7!I=&D@<'5T96T@=F&Y96<@<&]R=&%L82X`3V1A8F5R:71E
M(+YE;&IE;FD@:F5Z:6LL('9R96UE;G-K=2!Z;VYU(&D@<&]S=&%V:V4@>F$@
M9&%T=6TN`%!O9&5S:71E('-T87)T;G4@:V]M<&]N96YT=2P@N65M=2!B;VIA
M+"!O<W9J9;YA=F%N:F4@<W1R86YI8V4@:2!D<G5G92!O<&-I:F4@:V]J92!S
M92!T:>AU('!R:6MA>F$N`%!O<W1A=FME`%-E:KEE;&D`2W)A=&%K(&]P:7,`
M1&$@;&D@9&5F:6YI<V%T:2!P<FES='5P;F4@=&EP:V4@>F$@;&EN:V]V93\`
M4')I:V&^:0!0<FEK8;YI('9R:6IE;64@>F%D;FIE('!R:6IA=F4@;F%K;VX@
M;&]G:7)A;FIA/P!0<FEK8;YI(&UE;FD@>F$@;6%N:7!U;&%C:6IE('1A8F5L
M86UA/P!0<FEK8;YI("5S(&UE;FD@;&EJ979O/P!696QIZ&EN80!0<F5S:V_H
M:2!S97)V:7,`2G6^;F\M979R;W!S:VD@*$E33RTX.#4Y+3,I`%1E;6$`57-P
M:F6Y;F\`5&5K<W0`2'9A;&$@N71O(&MO<FES=&ET92!%;F5R9V]D871A('=E
M8FUA:6PN`%!R;WIO<B!Z82!O<&-I:F4@<V4@>F%T=F]R:6\N($EZ;&%Z:6TN
M`$ED96YT:71E="`B)7,B(&IE(&]B<FES86XN`$YE;6$@9&]S='5P;FEH(&]P
M8VEJ82X`1&5S:6QA('-E(&=R9;EK82!T;VMO;2!P<FEK87IA(&]V;V<@9&EJ
M96QA('!O<G5K90!6<FEJ961N;W-T(&]V;V<@8G)O:F$@;6]R82!N86IM86YJ
M92!I>FYO<VET:2`Q+@!/=F$@=G)I:F5D;F]S="!M;W)A(&)I=&D@8G)O:BX`
M3W9A:B!P<F]Z;W(@<V4@<VUI:F4@<&]Z:79A=&D@<V%M;R!I>B!P<F]Z;W)A
M($]P8VEJ90!:80!4=7)S:VD@*$E33RTX.#4Y+3DI`%!O;FFY=&D@:7IM:F5N
M90!.96MA=&5G;W)I<V%N;P!5;FEK;V0@*%541BTX*0!5:F5D:6YJ96YI($%R
M87!S:VD@16UI<F%T:0!.97!O>FYA=&\@:V]R:7-N:>AK;R!I;64@:6QI(+EI
M9G)A+@!"97II;65N:0!+;W)I<W1I=&4@;W9O(&%K;R!S92!I;64ON6EF<F$@
M<F%Z;&EK=6IU('IA($E-4U`@<V5R=F5R+@!+;W)I<VYI:R`E<R!N96UA(&1O
M>G9O;'4@>F$@)7,N`$MO<FES;FGH:V4@;W!C:6IE`%)E9VES=')A8VEJ82!K
M;W)I<VYI:V$`2V]R:7-N:>AK;R!I;64`4')I:V%Z("5S`%5P;WIO<F5N:F4`
M4V5D;6GH;F\`1&]B<F\@9&^Y;&D`1&]B<F\@9&^Y;&D@;F$@)7,`1&]B<F\@
M9&^Y;&DL("5S`%IA<&%D;FD@*$E33RTX.#4Y+3$I`%IA<&%D;FD@*$E33RTX
M.#4Y+3$U*0!:87!A9&YA(%-A:&%R80!+;VIU(&MO;7!O;F5N='4@YF4@)7,@
M<')I:V%Z871I(&YA:V]N('5L87IA/P!+;VIE(&1O9&%T:V4@OF5L:71E(&%K
M=&EV:7)A=&D@>F$@961I=&]R(&9O<FUA=&ER86YO9R`H<FEC:"D@=&5K<W1A
M+@"I:7)I;F$@)7,@;65N:6IA('-A(&QI:F5V92!S=')A;FEC92`H<W1U<&$@
M;F$@<VYA9W4@:V]D('-L:F5D9>9E('!R:6IA=F4I.@!';V1IN6YJ90!$80!.
M92!M;[YE('-A9'*^879A=&D@)UPG(&MA<F%K=&5R('4@='9O;2!P=6YO;2!I
M;65N=2X`3V1J879L:FEV86YJ92!J92!U<W!J9;EN;R!I>G9RN65N;RX`("5S
M('-E<VEJ82!J92!I<W1E:VQA+B!-;VQI;6\@9&$@<V4@<&]N;W9O('!R:6IA
M=FET92X`5F&Y82!E+6UA:6P@861R97-A`%9AN6$@1G)O;3H@861R97-A.@!6
M8;EE(&EN9F]R;6%C:6IE`%9AN6$@26YT97)N970@861R97-A(&IE('!R;VUI
M:F5N:F5N82!N86MO;B!P<FEJ879L:FEV86YJ82!N82`E<RX@1&$@8FD@=F&Y
M82!S:6=U<FYO<W0@8FEL82!S8>AU=F%N82P@;6]R871E('-E('!O;F]V;R!P
M<FEJ879I=&DN`%9AN64@:6UE`%9AN2!B<F]W<V5R(&YE('!O9'*^879A(&]V
M=2!M;V=UYFYO<W0N`%1R96YU=&YA('9R96UE;G-K82!Z;VYA.@!68;D@9&5F
M875L="!I9&5N=&ET970Z`%9AN64@:6UE(&D@<')E>FEM93H`5F&Y82!N;W9A
M(+EI9G)A('IA("5S(&IE.B`E<P!68;EE(&]P8VEJ92!S=2!S8>AU=F%N92!T
M;VMO;2!T<F%J86YJ82!O=F4@<V5S:6IE+@!/<&-I:F4@<W4@<V'H=79A;F4N
M`%9AN6$@N6EF<F$@:F4@<&]N:;ET96YA`%9AN6$@N6EF<F$@:F4@<&]N:;ET
M96YA+"!P<F]V:F5R:71E('9AN2!E+6UA:6P@:2!P<FEJ879I=&4@<V4@<V$@
M;F]V;VT@N6EF<F]M+@!68;EI('5D86QJ96YI('-E<G9E<FDZ`$IU9V]S;&%V
M:6IA`%IA:7(`6F%M8FEJ80!::6UB86)V90!::7!P>0!;4V%K<FEJ(&-I=&ER
M86YI('1E:W-T70!;4')I:F%V82!P<F]B;&5M85T`6U!R:6MAOFD@8VET:7)A
M;FD@=&5K<W0@+0!;4')I:V&^:2!C:71I<F%N:2!T96MS="`M("5S(')E9&]V
M85T`6W)E9"`E<R!O9"`E<UT`7T%D;6EN:7-T<F%C:6IA`%]#3$D`7T1A=&%4
M<F5E`%]/8G)IN6D@<F5D`%]'<G5P90!?4&]M;^8`7T]S;V)I;F4@<VQI:V4N
M+BX`7U!R:6IA=FD@<V4`7TEZ;&%Z`%])>FUI:F5N:2!L:6YK+BXN`%]/<&-I
M:F4`7T1O>G9O;&4`7U5K;&]N:2!L:6YK+BXN`%]0;V1E<VD`3W-O8FEN92!?
M=&%B96QE+BXN`%]+;W)I<VYI8VD`:6UE;FEK`&QI<W1A('IA9&%T86MA`&)E
M>B!I;65N80!V0V%R9`!W96%T:&5R+F-O;0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L;V-A;&4O8V%?15,O3$-?34534T%'15,`````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#4P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQO8V%L92]C85]%4R],0U]-15-304=%
M4R]H;W)D92YM;P``````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#,V,3(S,2`Q
M,#4Q-30S-#$T,2`P,C,Q-S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````WA($E0````#&!@``'````$PV```="0``?&P`````
M``#PD```#@```/&0```/`````)$```T````0D0``"````!Z1```+````)Y$`
M``P````SD0``!````$"1```8````19$```P```!>D0``$0```&N1```E````
M?9$```\```"CD0``"P```+.1```.````OY$```4```#.D0``*````-21```(
M````_9$```H````&D@``%0```!&2```2````)Y(```L````ZD@``#@```$:2
M```*````59(```T```!@D@``+@```&Z2```.````G9(``!$```"LD@``#0``
M`+Z2```,````S)(```T```#9D@``!@```.>2```/````[I(``!@```#^D@``
M#````!>3```;````)),```X```!`DP``#@```$^3```(````7I,```D```!G
MDP``+@```'&3```:````H),``#(```"[DP``.````.Z3``!4````)Y0``%$`
M``!\E```6@```,Z4``!7````*94``#0```"!E0``"0```+:5```-````P)4`
M``<```#.E0``"@```-:5```/````X94```4```#QE0``!@```/>5```1````
M_I4```@````0E@``"0```!F6```)````(Y8``"4````ME@``(````%.6```0
M````=)8```\```"%E@``"@```)66```#````H)8```\```"DE@``%````+26
M```)````R98```T```#3E@``$@```.&6```/````])8```H````$EP``#P``
M``^7```(````'Y<``"0````HEP``%````$V7```6````8I<```@```!YEP``
M'P```(*7```9````HI<```<```"\EP``#````,27```L````T9<```X```#^
MEP```P````V8```+````$9@```<````=F```!P```"68```%````+9@```4`
M```SF```"@```#F8```#````1)@``!<```!(F```"@```&"8```/````:Y@`
M``X```![F```&````(J8```C````HY@```X```#'F```%````-:8```7````
MZY@``!<````#F0``%P```!N9```3````,YD```\```!'F0``#@```%>9```?
M````9ID``!T```"&F0``!P```*29```&````K)D```@```"SF0``#P```+R9
M```&````S)D```H```#3F0``$P```-Z9```+````\ID``!````#^F0``%0``
M``^:```5````)9H```<````[F@``$````$.:```%````5)H``!4```!:F@``
M$0```'":```,````@IH``#L```"/F@``"0```,N:```'````U9H``!0```#=
MF@```P```/*:```%````]IH``!````#\F@``"0````V;```3````%YL``#D`
M```KFP``$@```&6;```G````>)L``"P```"@FP``*@```,V;```E````^)L`
M``H````>G```!@```"F<```)````,)P```<````ZG```+P```$*<```W````
M<IP``"X```"JG```50```-F<```M````+YT``"T```!=G0``+0```(N=``!`
M````N9T``",```#ZG0``(P```!Z>```M````0IX``#,```!PG@``%0```*2>
M```9````NIX``"D```#4G@``)````/Z>```H````(Y\``!$```!,GP``"@``
M`%Z?```,````:9\```H```!VGP``$````(&?```6````DI\``!8```"IGP``
M!P```,"?```'````R)\``!0```#0GP``"@```.6?```(````\)\```@```#Y
MGP``!P````*@```'````"J````8````2H```!0```!F@```'````'Z````8`
M```GH```"````"Z@```I````-Z````X```!AH```"@```'"@```$````>Z``
M``<```"`H```"0```(B@```&````DJ```!$```"9H```!P```*N@```6````
MLZ````0```#*H```"````,^@```&````V*````T```#?H```!@```.V@```>
M````]*```!$````3H0``(@```"6A```6````2*$```@```!?H0``#0```&BA
M```,````=J$```<```"#H0```P```(NA```#````CZ$``!<```"3H0``$P``
M`*NA```=````OZ$```@```#=H0``!````.:A```(````ZZ$```@```#TH0``
M00```/VA```@````/Z(```8```!@H@``!@```&>B```5````;J(``!@```"$
MH@``(@```)VB```N````P*(``!T```#OH@``(0````VC``!4````+Z,``"D`
M``"$HP``"@```*ZC```'````N:,``!4```#!HP``#@```->C```*````YJ,`
M``\```#QHP``#0````&D```/````#Z0```T````?I```"0```"VD```4````
M-Z0```8```!,I```&````%.D```=````;*0``!,```"*I```$0```)ZD```4
M````L*0```0```#%I```!@```,JD``!4````T:0```0````FI0``#@```"NE
M```%````.J4```4```!`I0``&P```$:E```:````8J4``!$```!]I0``$0``
M`(^E```<````H:4``"H```"^I0``$````.FE```A````^J4```4````<I@``
M$P```"*F```2````-J8```H```!)I@``#P```%2F```-````9*8``!$```!R
MI@``$P```(2F```,````F*8```8```"EI@``#````*RF```&````N:8``!<`
M``#`I@``$````-BF```1````Z:8```@```#[I@``!0````2G```,````"J<`
M`!`````7IP``!0```"BG```-````+J<```8````\IP``!P```$.G```-````
M2Z<```<```!9IP``"P```&&G```'````;:<```<```!UIP``%````'VG```)
M````DJ<```H```"<IP``&0```*>G```=````P:<```P```#?IP``$````.RG
M```%````_:<``"4````#J```$@```"FH```3````/*@``"L```!0J```.P``
M`'RH```@````N*@``#8```#9J```"````!"I```,````&:D```8````FJ0``
M!````"VI```/````,JD```X```!"J0``"@```%&I```-````7*D``"$```!J
MJ0``'@```(RI```9````JZD``!X```#%J0``&P```.2I```F`````*H``!X`
M```GJ@``'````$:J```F````8ZH``#,```"*J@``)@```+ZJ```K````Y:H`
M`#@````1JP``+P```$JK```2````>JL``"D```"-JP``$@```+>K``"B````
MRJL``!8```!MK```(P```(2L```H````J*P``"D```#1K```*````/NL```?
M````)*T``"````!$K0``)0```&6M```H````BZT``#````"TK0``D@```.6M
M```A````>*X``!P```":K@``)@```+>N``!!````WJX```P````@KP``!P``
M`"VO```'````-:\```8````]KP``#0```$2O```0````4J\``!(```!CKP``
M$P```':O```2````BJ\```<```"=KP``!````*6O```0````JJ\```P```"[
MKP``#@```,BO```/````UZ\``!,```#GKP``#0```/NO```H````";````,`
M```RL```#0```#:P```&````1+```!$```!+L```%P```%VP```;````=;``
M``X```"1L````@```*"P```%````H[```!````"IL```!````+JP```-````
MO[````X```#-L````P```-RP```.````X+````@```#OL```#P```/BP```/
M````"+$```<````8L0``#0```""Q```0````+K$```L````_L0``!@```$NQ
M```,````4K$``!$```!?L0``&0```'&Q```+````B[$```T```"7L0``(@``
M`*6Q```*````R+$``!@```#3L0``&0```.RQ```6````!K(```T````=L@``
M!P```"NR```4````,[(```L```!(L@``(@```%2R```O````=[(```L```"G
ML@``"0```+.R```9````O;(```L```#7L@``%P```..R```7````^[(```D`
M```3LP``%@```!VS```/````-+,``!8```!$LP``#@```%NS```8````:K,`
M``@```"#LP``#0```(RS```F````FK,``$,```#!LP``"`````6T```2````
M#K0```@````AM```"P```"JT```O````-K0```X```!FM```!0```'6T```&
M````>[0```,```""M```!P```(:T```$````CK0```H```"3M```"@```)ZT
M```/````J;0``!````"YM```%P```,JT```1````XK0``!<```#TM```"0``
M``RU```%````%K4```L````<M0``"@```"BU```"````,[4```4````VM0``
M#0```#RU```;````2K4``!<```!FM0``"0```'ZU```.````B+4```T```"7
MM0``$@```*6U```X````N+4``"````#QM0``"````!*V```.````&[8``'L`
M```JM@``&````*:V```1````O[8```<```#1M@``!0```-FV```9````W[8`
M``<```#YM@``"`````&W```&````"K<```8````1MP``$````!BW```/````
M*;<``!`````YMP``#P```$JW```+````6K<```\```!FMP``#````':W```/
M````@[<```<```"3MP``!@```)NW```.````HK<```P```"QMP``*````+ZW
M```/````Y[<```@```#WMP``"`````"X```3````";@``!X````=N```(0``
M`#RX```@````7K@``!D```!_N```%P```)FX```E````L;@``!<```#7N```
M%@```.^X```$````!KD``!L````+N0``#0```">Y```,````-;D```,```!"
MN0``"````$:Y```*````3[D```P```!:N0``"P```&>Y```0````<[D```P`
M``"$N0``!````)&Y```3````EKD``!0```"JN0``#````+^Y```)````S+D`
M``X```#6N0``"P```.6Y```;````\;D```<````-N@``!P```!6Z```*````
M';H```T````HN@``"0```#:Z```$````0+H```4```!%N@```P```$NZ```8
M````3[H```H```!HN@``!````'.Z```F````>+H```X```"?N@``?````*ZZ
M```5````*[L```4```!!NP``!P```$>[```,````3[L```@```!<NP``"@``
M`&6[```&````<+L```@```!WNP```@```("[```&````@[L```8```"*NP``
M%````)&[```-````IKL``!````"TNP``&P```,6[```$````X;L```D```#F
MNP``$````/"[```)`````;P```D````+O```!0```!6\```:````&[P```@`
M```VO```!@```#^\```9````1KP```X```!@O```!P```&^\```'````=[P`
M``4```!_O```"0```(6\```*````C[P```(```":O```!@```)V\```-````
MI+P```D```"RO```!@```+R\```2````P[P```D```#6O```!P```."\```4
M````Z+P``!T```#]O```!@```!N]```*````(KT```0````MO0``"0```#*]
M```(````/+T``!$```!%O0``"0```%>]```&````8;T```T```!HO0``!@``
M`':]```$````?;T``#D```""O0``/0```+R]```Z````^KT``!X````UO@``
M!0```%2^```.````6KX```0```!IO@``!@```&Z^```A````=;X``!4```"7
MO@``!@```*V^```$````M+X``!$```"YO@``!@```,N^```*````TKX``"(`
M``#=O@``!`````"_```%````!;\``!T````+OP``!````"F_```,````+K\`
M``H````[OP``"````$:_```)````3[\```4```!9OP``.@```%^_```P````
MFK\``#4```#+OP``*0````'```!'````*\```#@```!SP```*0```*S````_
M````UL```"X````6P0``+0```$7!```?````<\$```\```"3P0``$@```*/!
M```+````ML$``"8```#"P0``*0```.G!```D````$\(``"8````XP@``"```
M`%_"```*````:,(```D```!SP@``!P```'W"```@````A<(``"````"FP@``
M)@```,?"```*````[L(``!D```#YP@``*0```!/#```6````/<,``!(```!4
MPP``!P```&?#```*````;\,```P```!ZPP``#P```(?#```0````E\,``$``
M``"HPP``<````.G#``!F````6L0```X```#!Q```"0```-#$```*````VL0`
M`!(```#EQ```$P```/C$```,````#,4```8````9Q0``#P```"#%```2````
M,,4``!````!#Q0``$0```%3%```<````9L4``",```"#Q0``:@```*?%```/
M````$L8```4````BQ@``$````"C&```)````.<8```0```!#Q@``"P```$C&
M```:````5,8``!0```!OQ@``#````(3&```,````D<8```\```">Q@``%0``
M`*[&```I````Q,8``"H```#NQ@``)@```!G'```G````0,<``"D```!HQP``
M*@```)+'```9````O<<``$(```#7QP``$0```!K(```2````+,@``!,````_
MR```%````%/(```/````:,@``!8```!XR```%P```(_(```0````I\@``!$`
M``"XR```-````,K(```3````_\@``!(````3R0``-0```";)```4````7,D`
M``<```!QR0``#````'G)```@````ALD``!0```"GR0``$0```+S)```7````
MSLD``!P```#FR0``$P````/*```4````%\H``!H````LR@``$0```$?*```:
M````6<H``!X```!TR@``&@```)/*```3````KLH``!4```#"R@``$0```-C*
M```4````ZLH``!<```#_R@``%0```!?+```)````+<L``!D````WRP``!```
M`%'+```'````5LL```L```!>RP``$0```&K+```&````?,L```8```"#RP``
M!@```(K+```%````D<L```<```"7RP``!P```)_+```%````I\L``!8```"M
MRP``!@```,3+```&````R\L```0```#2RP``!````-?+```'````W,L```X`
M``#DRP``#````//+```,`````,P```T````-S```"@```!O,```.````)LP`
M``4````US```*````#O,```.````9,P```P```!SS```#P```(#,```*````
MD,P```@```";S```"0```*3,```K````KLP```0```#:S```"````-_,```F
M````Z,P``!(````/S0``#P```"+-```&````,LT```H````YS0``!P```$3-
M```(````3,T``"````!5S0``"0```';-```,````@,T```T```"-S0``#@``
M`)O-```6````JLT``!$```#!S0``!@```-/-```#````VLT```8```#>S0``
M&0```.7-```'````_\T```0````'S@``"P````S.```+````&,X```<````D
MS@``!P```"S.```6````-,X```T```!+S@``#0```%G.```*````9\X``!``
M``!RS@``#P```(/.```1````D\X``!<```"ES@``"@```+W.```1````R,X`
M``@```#:S@``!````./.```/````Z,X``#H```#XS@``!0```#//```,````
M.<\``!X```!&SP``#@```&7/```0````=,\```L```"%SP``#````)'/```)
M````GL\```<```"HSP``"@```+#/```)````N\\```X```#%SP``$````-3/
M```:````Y<\```H`````T```"0````O0```*````%=````P````@T```#P``
M`"W0```(````/=````8```!&T```!P```$W0```+````5=```$<```!AT```
M#0```*G0```)````M]````0```#!T````P```,;0```3````RM```!,```#>
MT```$P```/+0```*````!M$```(````1T0``!````!31```E````&=$```,`
M```_T0``!0```$/1```J````2=$```H```!TT0``!0```'_1```$````A=$`
M``H```"*T0``#0```)71```&````H]$```@```"JT0``"````+/1```$````
MO-$```4```#!T0``:````,?1```)````,-(```P````ZT@``!0```$?2```&
M````3=(``!L```!4T@``+P```'#2```0````H-(```H```"QT@``#P```+S2
M```*````S-(```D```#7T@``$P```.'2```;````]=(``!@````1TP``%P``
M`"K3```.````0M,```,```!1TP``!P```%73```(````7=,```<```!FTP``
M"@```&[3```+````>=,```<```"%TP``40```(W3```0````W],```P```#P
MTP``#0```/W3```:````"]0``$H````FU```&0```''4```&````B]0```8`
M``"2U```!@```)G4```?````H-0```8```#`U```"0```,?4```8````T=0`
M`!<```#JU```!@````+5```-````"=4``"(````7U0``5P```#K5```3````
MDM4``",```"FU0``$P```,K5```"````WM4```L```#AU0``"````.W5```-
M````]M4```H````$U@``!P````_6```4````%]8```8````LU@``"````#/6
M```.````/-8```<```!+U@``"@```%/6```+````7M8```<```!JU@``#```
M`'+6```-````?]8```P```"-U@``"0```)K6```)````I-8```H```"NU@``
M!P```+G6```)````P=8```<```#+U@``"@```-/6```;````WM8``!(```#Z
MU@``"@````W7```)````&-<``!`````BUP``!P```#/7```2````.]<```0`
M``!.UP``!P```%/7```%````6]<```4```!AUP``"P```&?7```4````<]<`
M`!$```"(UP``&@```)K7```6````M=<``!0```#,UP``%P```.'7```8````
M^=<``!P````2V```&0```"_8```'````2=@```4```!1V```#0```%?8```,
M````9=@```@```!RV```%P```'O8```+````D]@``!,```"?V```!````+/8
M```*````N-@```0```##V```#0```,C8```,````UM@```4```#CV```"0``
M`.G8```%````\]@```<```#YV```!0````'9```$````!]D```(````,V0``
M.`````_9```L````2-D``!(```!UV0``*0```(C9```R````LMD```H```#E
MV0``+````/#9```N````'=H``#,```!,V@``,P```(#:```X````M-H```\`
M``#MV@``&````/W:```0````%ML```\````GVP``$P```#?;```5````2]L`
M`!0```!AVP``$@```';;```4````B=L``!4```">VP``+0```+3;```M````
MXML``#$````0W```+@```$+<```O````<=P``"P```"AW```8@```,[<```3
M````,=T```T```!%W0``"````%/=```(````7-T```P```!EW0``*P```'+=
M```A````GMT``!H```#`W0``"0```-O=``!%````Y=T``$$````KW@``!```
M`&W>```3````<MX``!0```"&W@``#@```)O>```3````JMX``!@```"^W@``
M!@```-?>```)````WMX```H```#HW@``#P```//>```0`````]\```<````4
MWP``#@```!S?```%````*]\``!L````QWP``"````$W?```&````5M\``!0`
M``!=WP``$0```'+?```.````A-\``#@```"3WP```@```,S?```&````S]\`
M``X```#6WP``!0```.7?```'````Z]\```X```#SWP``!@````+@```$````
M">```"D````.X```%P```#C@```?````4.```%P```!PX```%````,W@```^
M````XN```!\````AX0``$````$'A```'````4N$```X```!:X0``#````&GA
M```,````=N$``!,```"#X0``"@```)?A```=````HN$``!D```#`X0``!0``
M`-KA```1````X.$``!$```#RX0``)`````3B```5````*>(``!(````_X@``
M#@```%+B```9````8>(```@```![X@``"0```(3B```-````CN(```H```"<
MX@``!P```*?B```/````K^(```8```"_X@``"P```,;B```*````TN(```<`
M``#=X@``"````.7B```%````[N(``!\```#TX@``!@```!3C```0````&^,`
M``@````LXP``#0```#7C```(````0^,``!(```!,XP``+````%_C```:````
MC.,```D```"GXP``"@```+'C```5````O.,```4```#2XP``%````-CC```$
M````[>,``!````#RXP``!@````/D```'````"N0``!X````2Y```*````#'D
M```*````6N0``!$```!EY```&@```'?D```4````DN0```0```"GY```!```
M`*SD```+````L>0```4```"]Y```!@```,/D```(````RN0```8```#3Y```
M"@```-KD```;````Y>0``#0````!Y0``-````#;E```@````:^4``"D```",
MY0``(````+;E``!!````U^4``!H````9Y@``*````#3F```I````7>8``"(`
M``"'Y@``!@```*KF```(````L>8```4```"ZY@``"````,#F```9````R>8`
M`!D```#CY@``*@```/WF```C````*.<``"X```!,YP``-````'OG```(````
ML.<``!<```"YYP``"@```-'G```'````W.<``"$```#DYP``$`````;H```.
M````%^@```L````FZ```!P```#+H```3````.N@```@```!.Z```"P```%?H
M```*````8^@``!0```!NZ```#P```(/H```R````D^@```L```#&Z```!0``
M`-+H```%````V.@``!<```#>Z```#P```/;H```$````!ND```H````+Z0``
M"0```!;I```+````(.D```T````LZ0``#````#KI```.````1^D```4```!6
MZ0``!````%SI```-````8>D``#(```!OZ0``10```*+I```7````Z.D``!X`
M````Z@``%````!_J```%````-.H``!0````ZZ@``!P```$_J```.````5^H`
M`"D```!FZ@``!@```)#J```,````E^H```T```"DZ@``$0```++J```+````
MQ.H``#8```#0Z@``"@````?K```B````$NL```L````UZP``#P```$'K```R
M````4>L``"4```"$ZP``#@```*KK```%````N>L```X```"_ZP``$P```,[K
M```'````XNL``!$```#JZP``!P```/SK```4````!.P``!@````9[```!P``
M`#+L```%````.NP```P```!`[```#````$WL```2````6NP```0```!M[```
M!P```'+L```*````>NP```L```"%[```#````)'L```.````GNP```X```"M
M[```!0```+SL```%````PNP``"X```#([```)@```/?L```C````'NT```,`
M``!"[0``$@```$;M```&````6>T``!X```!@[0``&````'_M```E````F.T`
M``T```"^[0``"0```,SM```#````UNT```<```#:[0``"@```.+M```"````
M[>T```P```#P[0``%0```/WM```+````$^X``!D````?[@``(````#GN```2
M````6NX```4```!M[@``"@```'/N```5````?NX``!(```"4[@``#````*?N
M```$````M.X```<```"Y[@``#````,'N``!2````SNX``!<````A[P``$@``
M`#GO```'````3.\```8```!4[P``#@```%OO```,````:N\```T```!W[P``
M%0```(7O```2````F^\```\```"N[P``%````+[O```;````T^\``!````#O
M[P``:0````#P```:````:O```!<```"%\```)P```)WP```:````Q?```!<`
M``#@\```&P```/CP```9````%/$``!\````N\0``$P```$[Q```(````8O$`
M``<```!K\0``"````'/Q```)````?/$``!4```"&\0``#0```)SQ```C````
MJO$``!,```#.\0```P```.+Q``!&````YO$``#\````M\@``-P```&WR``!7
M````I?(```4```#]\@``'P````/S```O````(_,```H```!3\P``"````%[S
M```-````9_,``"T```!U\P``!````*/S``!/````J/,``"4```#X\P``'```
M`![T```+````._0``!\```!']```'0```&?T```E````A?0``"````"K]```
M)````,ST```@````\?0```L````2]0``!P```![U```-````)O4```P````T
M]0``%P```$'U```&````6?4``#D```!@]0``#````)KU```'````I_4```D`
M``"O]0``$P```+GU```)````S?4```0```#7]0``$````-SU```(````[?4`
M``@```#V]0``!````/_U```+````!/8```P````0]@``$@```!WV```1````
M,/8```P```!"]@``&@```$_V```/````:O8```<```!Z]@``#0```(+V```4
M````D/8```X```"E]@``#````+3V```;````P?8``"P```#=]@``$P````KW
M```<````'O<``"@````[]P``!@```&3W```'````:_<``!,```!S]P``!0``
M`(?W```$````C?<``!<```"2]P``"@```*KW```,````M?<```D```#"]P``
M!@```,SW```)````T_<```@```#=]P``"0```.;W```*````\/<``!$```#[
M]P``!@````WX```.````%/@```X````C^```#0```#+X```+````0/@``!T`
M``!,^```"P```&KX```"````=O@```<```!Y^```!@```('X```)````B/@`
M``<```"2^```.P```)KX```H````UO@``#0```#_^```%0```#3Y```%````
M2OD```<```!0^0``"````%CY```'````8?D```4```!I^0``!P```&_Y```.
M````=_D```D```"&^0``!@```)#Y```(````E_D```L```"@^0``!P```*SY
M```(````M/D```<```"]^0``%@```,7Y```)````W/D```8```#F^0``"P``
M`.WY```<````^?D``!0````6^@``!P```"OZ```1````,_H```@```!%^@``
M"````$[Z```0````5_H``!````!H^@``!@```'GZ```9````@/H```H```":
M^@``'````*7Z```'````POH```4```#*^@``$````-#Z```4````X?H```L`
M``#V^@``#0````+[```7````$/L```0````H^P``"0```"W[```*````-_L`
M``<```!"^P```@```$K[```.````3?L```@```!<^P``(P```&7[```X````
MB?L``#$```#"^P``)P```/3[``!D````'/P``!0```"!_```50```);\```X
M````[/P``$H````E_0``6P```'#]```H````S/T``#@```#U_0``*````"[^
M```L````5_X``!L```"$_@``/@```*#^``"I`0``W_X``",```")``$`%P``
M`*T``0!(````Q0`!`(4````.`0$`,````)0!`0!!````Q0$!`%L````'`@$`
M20```&,"`0`=````K0(!`!@```#+`@$`(0```.0"`0`?````!@,!`"L````F
M`P$`)P```%(#`0`=````>@,!`!$```"8`P$`,P```*H#`0`E````W@,!`"<`
M```$!`$`'P```"P$`0`P````3`0!`&D```!]!`$`/0```.<$`0!E````)04!
M`$T```"+!0$`+P```-D%`0`N````"08!`#`````X!@$`5````&D&`0!:````
MO@8!`$@````9!P$`2@```&('`0`R````K0<!`"\```#@!P$`+````!`(`0`M
M````/0@!`'$```!K"`$`;P```-T(`0"S````30D!`!<````!"@$`)0```!D*
M`0`R````/PH!`"D```!R"@$`/@```)P*`0`B````VPH!`%(```#^"@$`)0``
M`%$+`0`+````=PL!`+$```"#"P$`10```#4,`0`A````>PP!`#````"=#`$`
M)0```,X,`0`<````]`P!`#$````1#0$`!P```$,-`0`'````2PT!``0```!3
M#0$`#0```%@-`0`+````9@T!``X```!R#0$`"P```($-`0`%````C0T!`!``
M``"3#0$``@```*0-`0!9````IPT!``4````!#@$`$@````<.`0`$````&@X!
M``<````?#@$`"````"<.`0`%````,`X!``,````V#@$`$````#H.`0`,````
M2PX!`!,```!8#@$`#0```&P.`0`"````>@X!``<```!]#@$`!@```(4.`0`4
M````C`X!``P```"A#@$`&````*X.`0`&````QPX!`!(```#.#@$`#````.$.
M`0`#````[@X!`"H```#R#@$`!````!T/`0`&````(@\!``<````I#P$`'P``
M`#$/`0`U````40\!`"X```"'#P$`+P```+8/`0`7````Y@\!`"````#^#P$`
M&P```!\0`0`8````.Q`!`"0```!4$`$`'P```'D0`0`:````F1`!`"$```"T
M$`$`(````-80`0`:````]Q`!`#(````2$0$`+P```$41`0`K````=1$!`!\`
M``"A$0$`(P```,$1`0`?````Y1$!`!H````%$@$`(0```"`2`0`E````0A(!
M`"8```!H$@$`)0```(\2`0`D````M1(!`!@```#:$@$`'0```/,2`0`D````
M$1,!`!@````V$P$`(@```$\3`0`L````<A,!`"\```"?$P$`%0```,\3`0`E
M````Y1,!`#P````+%`$`'P```$@4`0`C````:!0!`!\```",%`$`(````*P4
M`0`:````S10!`!@```#H%`$`)@````$5`0`>````*!4!`"D```!'%0$`'@``
M`'$5`0`Q````D!4!``D```#"%0$`#````,P5`0`7````V14!`"\```#Q%0$`
M)````"$6`0`'````1A8!``\```!.%@$`%````%X6`0`.````<Q8!``T```""
M%@$`)````)`6`0`%````M18!``<```"[%@$`(@```,,6`0`E````YA8!`!H`
M```,%P$`'0```"<7`0`:````11<!``<```!@%P$`QP```&@7`0`+````,!@!
M`!4````\&`$`!@```%(8`0`)````61@!``L```!C&`$`%P```&\8`0`&````
MAQ@!`#,```".&`$`$P```,(8`0`3````UA@!``<```#J&`$`#P```/(8`0`'
M`````AD!`#(````*&0$`(0```#T9`0`3````7QD!``P```!S&0$`$0```(`9
M`0`R````DAD!``@```#%&0$`"0```,X9`0`*````V!D!`!0```#C&0$`"@``
M`/@9`0`=`````QH!``@````A&@$`'P```"H:`0`(````2AH!`!H```!3&@$`
M)P```&X:`0`&````EAH!`!4```"=&@$`!P```+,:`0`(````NQH!``D```#$
M&@$`/P```,X:`0`'````#AL!``\````6&P$`#@```"8;`0`0````-1L!``D`
M``!&&P$`"0```%`;`0`(````6AL!`!,```!C&P$`!P```'<;`0`9````?QL!
M``H```"9&P$`%P```*0;`0`4````O!L!``H```#1&P$`#````-P;`0`7````
MZ1L!``0````!'`$`*@````8<`0`1````,1P!``<```!#'`$``@```$L<`0`0
M````3AP!`!@```!?'`$`"P```'@<`0`#````A!P!``@```"('`$`!@```)$<
M`0`'````F!P!``T```"@'`$`"P```*X<`0`4````NAP!`!4```#/'`$`#@``
M`.4<`0`O````]!P!`"`````D'0$`'````$4=`0`,````8AT!`#$```!O'0$`
M!0```*$=`0`2````IQT!`#\```"Z'0$`$@```/H=`0`*````#1X!``8````8
M'@$`!````!\>`0`$````)!X!``H````I'@$`$P```#0>`0`%````2!X!``8`
M``!.'@$`!@```%4>`0`$````7!X!``P```!A'@$`"@```&X>`0`%````>1X!
M`!@```!_'@$`&0```)@>`0`?````LAX!`!T```#2'@$`$0```/`>`0`"````
M`A\!``0````%'P$`"@````H?`0`&````%1\!``4````<'P$``P```"(?`0`,
M````)A\!`$4````S'P$`&@```'D?`0`H````E!\!`%,```"]'P$`&0```!$@
M`0!R````*R`!`"````">(`$`-0```+\@`0`A````]2`!`$4````7(0$`,```
M`%TA`0`H````CB$!`"D```"W(0$`)@```.$A`0`E````""(!`"@````N(@$`
M*````%<B`0`B````@"(!`#````"C(@$`$@```-0B`0`3````YR(!`!````#[
M(@$`>0````PC`0`)````AB,!`',```"0(P$`?`````0D`0`K````@20!`%0`
M``"M)`$`%P````(E`0`6````&B4!``\````Q)0$`'P```$$E`0!`````824!
M`!\```"B)0$`'````,(E`0!1````WR4!`!0````Q)@$`"@```$8F`0`%````
M428!``8```!7)@$`"````%XF`0`%````9R8!`!(```!M)@$`$````(`F`0`3
M````D28!`!T```"E)@$`#P```,,F`0`/````TR8!``0```#C)@$`"0```.@F
M`0`+````\B8!``<```#^)@$`!0````8G`0`4````#"<!``<````A)P$`"```
M`"DG`0`/````,B<!``@```!")P$`#````$LG`0`/````6"<!``8```!H)P$`
M%````&\G`0`&````A"<!``P```"+)P$`"````)@G`0`$````H2<!``H```"F
M)P$`!P```+$G`0`$````N2<!`!D```"^)P$``@```-@G`0`"````VR<!``D`
M``#>)P$`!@```.@G`0`&````[R<!`"<```#V)P$``@```!XH`0`$````(2@!
M``\````F*`$`$P```#8H`0`'````2B@!``<```!2*`$`!@```%HH`0`&````
M82@!`!````!H*`$`$@```'DH`0`"````C"@!``8```"/*`$`"0```)8H`0`B
M````H"@!``<```##*`$`!P```,LH`0`+````TR@!``4```#?*`$``@```.4H
M`0`+````Z"@!`%T!``#T*`$`#````%(J`0`2````7RH!``P```!R*@$`!@``
M`'\J`0`&````ABH!``8```"-*@$``@```)0J`0`8````ERH!``H```"P*@$`
M$0```+LJ`0`L````S2H!`!8```#Z*@$`"0```!$K`0`4````&RL!``4````P
M*P$`*@```#8K`0`2````82L!``H```!T*P$`&P```'\K`0`/````FRL!``L`
M``"K*P$`$````+<K`0`)````R"L!`!(```#2*P$`,P```.4K`0`.````&2P!
M`!@````H+`$`#````$$L`0`3````3BP!`!<```!B+`$`!@```'HL`0`/````
M@2P!`!4```"1+`$`$0```*<L`0`;````N2P!`!(```#5+`$`$@```.@L`0`(
M````^RP!``D````$+0$`.@````XM`0`B````22T!`#D```!L+0$`0P```*8M
M`0!E````ZBT!`&(```!0+@$`:P```+,N`0!H````'R\!`#L```"(+P$`#@``
M`,0O`0`3````TR\!``T```#G+P$`#P```/4O`0`6````!3`!``4````<,`$`
M"0```"(P`0`3````+#`!``T```!`,`$`&0```$XP`0`7````:#`!`"\```"`
M,`$`*@```+`P`0`6````VS`!`!````#R,`$`$`````,Q`0`&````%#$!`!D`
M```;,0$`(@```#4Q`0`5````6#$!`!(```!N,0$`'0```($Q`0`5````GS$!
M`!,```"U,0$`%````,DQ`0`2````WC$!`#(```#Q,0$`(````"0R`0`D````
M13(!`!````!J,@$`(@```'LR`0`J````GC(!``8```#),@$`$@```-`R`0!`
M````XS(!``T````D,P$`!P```#(S`0`*````.C,!``<```!%,P$`!P```$TS
M`0`%````53,!``<```!;,P$`"@```&,S`0`$````;C,!`!P```!S,P$`#@``
M`)`S`0`1````GS,!`!,```"Q,P$`%0```,4S`0`Y````VS,!``L````5-`$`
M%0```"$T`0`<````-S0!`!P```!4-`$`'@```'$T`0`7````D#0!`!````"H
M-`$`#P```+DT`0`C````R30!`"$```#M-`$`!P````\U`0`&````%S4!``@`
M```>-0$`%0```"<U`0`(````/34!``D```!&-0$`$0```%`U`0`)````8C4!
M`!0```!L-0$`%@```($U`0`J````F#4!``<```##-0$`#P```,LU`0`%````
MVS4!`!0```#A-0$`#P```/8U`0`.````!C8!`"H````5-@$`"0```$`V`0`'
M````2C8!`!(```!2-@$``P```&4V`0`%````:38!`!(```!O-@$`#````((V
M`0`9````CS8!`$$```"I-@$`%0```.LV`0`K`````3<!`#0````M-P$`,@``
M`&(W`0`U````E3<!``@```#+-P$`!0```-0W`0`)````VC<!``<```#D-P$`
M-P```.PW`0`V````)#@!`#8```!;.`$`8P```)(X`0`U````]C@!`#4````L
M.0$`-0```&(Y`0!/````F#D!`"X```#H.0$`,0```!<Z`0`U````23H!`#L`
M``!_.@$`*````+LZ`0`K````Y#H!`"X````0.P$`/````#\[`0`\````?#L!
M`!(```"Y.P$`"P```,P[`0`,````V#L!``0```#E.P$`#@```.H[`0`@````
M^3L!`"$````:/`$`!P```#P\`0`'````1#P!`!0```!,/`$`"P```&$\`0`(
M````;3P!``H```!V/`$`"P```($\`0`'````C3P!``8```"5/`$`!0```)P\
M`0`(````HCP!``8```"K/`$`"@```+(\`0`Q````O3P!`!,```#O/`$`#0``
M``,]`0`'````$3T!``<````9/0$`"0```"$]`0`'````*ST!`!$````S/0$`
M"````$4]`0`4````3CT!``8```!C/0$`"````&H]`0`(````<ST!``X```!\
M/0$`!@```(L]`0`F````DCT!`!$```"Y/0$`)P```,L]`0`0````\ST!``@`
M```$/@$`#@````T^`0`,````'#X!``<````I/@$``P```#$^`0`#````-3X!
M`!L````Y/@$`%P```%4^`0`_````;3X!``D```"M/@$`!0```+<^`0`(````
MO3X!``<```#&/@$`:@```,X^`0`Q````.3\!``8```!K/P$`"@```'(_`0`B
M````?3\!`"````"@/P$`)P```,$_`0`T````Z3\!`"4````>0`$`*@```$1`
M`0!P````;T`!`#0```#@0`$`"````!5!`0`(````'D$!`!8````G00$`#```
M`#Y!`0`-````2T$!`!0```!900$`$P```&Y!`0`7````@D$!`!4```":00$`
M#0```+!!`0`4````OD$!``<```#300$`&````-M!`0`;````]$$!`!8````0
M0@$`%@```"="`0`:````/D(!``0```!90@$`!@```%Y"`0!V````94(!``0`
M``#<0@$`%````.%"`0`$````]D(!``0```#[0@$`&@````!#`0`8````&T,!
M`!0````T0P$`%````$E#`0`D````7D,!`#D```"#0P$`$0```+U#`0`M````
MST,!``@```#]0P$`(0````9$`0`4````*$0!`!`````]1`$`'0```$Y$`0`7
M````;$0!`!,```"$1`$`$P```)A$`0`1````K$0!``8```"^1`$`%0```,5$
M`0`)````VT0!`!@```#E1`$`%P```/Y$`0`.````%D4!``@````E10$`!0``
M`"Y%`0`1````-$4!`!$```!&10$`"0```%A%`0`6````8D4!``8```!Y10$`
M!0```(!%`0`'````AD4!``D```".10$`"````)A%`0`'````H44!``D```"I
M10$`%P```+-%`0`*````RT4!``H```#610$`&P```.%%`0`E````_44!``P`
M```C1@$`&````#!&`0`%````248!`"````!/1@$`)0```'!&`0`E````ED8!
M`#D```"\1@$`1@```/9&`0`U````/4<!`$4```!S1P$`"0```+E'`0`*````
MPT<!``8```#.1P$`!@```-5'`0`8````W$<!``\```#U1P$`"@````5(`0`-
M````$$@!`"@````>2`$`*````$=(`0`@````<$@!`"D```"12`$`(````+M(
M`0`Q````W$@!`"D````.20$`)@```#A)`0`S````7TD!`#X```"320$`,@``
M`-))`0`U````!4H!`$0````[2@$`/0```(!*`0`7````ODH!`#H```#62@$`
M&````!%+`0#,````*DL!`!\```#W2P$`,0```!=,`0`T````24P!`#8```!^
M3`$`-@```+5,`0`H````[$P!`"<````530$`,@```#U-`0`U````<$T!`$@`
M``"F30$`H````.]-`0`F````D$X!`"D```"W3@$`-@```.%.`0!C````&$\!
M``P```!\3P$`!````(E/`0`&````CD\!``4```"53P$`#P```)M/`0`2````
MJT\!`!$```"^3P$`%````-!/`0`>````Y4\!``<````$4`$`!`````Q0`0`/
M````$5`!``P````A4`$`$````"Y0`0`,````/U`!`!````!,4`$`#````%U0
M`0!*````:E`!``@```"U4`$`%````+Y0`0`%````TU`!`!(```#94`$`&```
M`.Q0`0`;````!5$!``\````A40$``@```#%1`0`*````-%$!`!4````_40$`
M!````%51`0`2````6E$!`!````!M40$``P```'Y1`0`0````@E$!``@```"3
M40$`$````)Q1`0`0````K5$!``T```"^40$`$P```,Q1`0`8````X%$!``L`
M``#Y40$`"`````52`0`-````#E(!``\````<4@$`&P```"Q2`0`/````2%(!
M`!````!84@$`*@```&E2`0`-````E%(!`"(```"B4@$`&@```,52`0`7````
MX%(!`!(```#X4@$`"0````M3`0`5````%5,!``H````K4P$`+P```#93`0`W
M````9E,!``\```">4P$`#@```*Y3`0`B````O5,!`!````#@4P$`$@```/%3
M`0`3````!%0!``D````85`$`*@```")4`0`8````350!`!@```!F5`$`%P``
M`']4`0`7````EU0!``@```"O5`$`#@```+A4`0`H````QU0!`%0```#P5`$`
M"````$55`0`4````3E4!``L```!C50$`#@```&]5`0`[````?E4!`!(```"Z
M50$`!P```,U5`0`1````U54!``,```#G50$`!P```.M5`0`%````\U4!``H`
M``#Y50$`"@````16`0`,````#U8!``X````<5@$`%````"M6`0`1````0%8!
M`!0```!25@$`"````&=6`0`&````<%8!``L```!W5@$`"@```(-6`0`(````
MCE8!`!$```"75@$`$@```*E6`0`K````O%8!`"$```#H5@$`"@````I7`0`2
M````%5<!`!(````H5P$`&@```#M7`0!%````5E<!`#4```"<5P$`$P```-)7
M`0`0````YE<!`)0```#W5P$`(@```(Q8`0`1````KU@!``<```#!6`$`!0``
M`,E8`0`P````SU@!``<`````60$`!P````A9`0`%````$%D!``8````660$`
M#@```!U9`0`-````+%D!``X````Z60$`#0```$E9`0`4````5UD!``\```!L
M60$`"@```'Q9`0`1````AUD!``<```"960$`"0```*%9`0`9````JUD!``X`
M``#%60$`+P```-19`0`1````!%H!``@````66@$`$P```!]:`0`B````,UH!
M`"D```!66@$`+0```(!:`0`L````KEH!`!T```#;6@$`'````/E:`0`K````
M%EL!`"````!"6P$`&P```&-;`0`$````?UL!`!D```"$6P$`"P```)Y;`0`4
M````JEL!``,```"_6P$`!@```,-;`0`+````REL!``P```#66P$`#0```.-;
M`0`2````\5L!``\````$7`$`!````!1<`0`;````&5P!`!P````U7`$`#P``
M`%)<`0`.````8EP!`!$```!Q7`$`$@```(-<`0`:````EEP!``<```"Q7`$`
M"0```+E<`0`.````PUP!``P```#27`$`"@```-]<`0`(````ZEP!``P```#S
M7`$`!0````!=`0`9````!ET!`!`````@70$`!@```#%=`0`M````.%T!``X`
M``!F70$`E@```'5=`0`;````#%X!``H````H7@$`!````#->`0`.````.%X!
M``4```!'7@$`!P```$U>`0`&````55X!``P```!<7@$``P```&E>`0`%````
M;5X!``8```!S7@$`%````'I>`0`0````CUX!`!(```"@7@$`'````+->`0`&
M````T%X!``<```#77@$`$P```-]>`0`+````\UX!``L```#_7@$`!0````M?
M`0`H````$5\!``<````Z7P$`!@```$)?`0`<````25\!``P```!F7P$`!P``
M`'-?`0`(````>U\!``4```"$7P$`"0```(I?`0`+````E%\!``8```"@7P$`
M!0```*=?`0`/````K5\!`!````"]7P$`!@```,Y?`0`1````U5\!``H```#G
M7P$`!P```/)?`0`/````^E\!`"P````*8`$`!0```#=@`0`)````/6`!``0`
M``!'8`$`"0```$Q@`0`(````5F`!`!<```!?8`$`$P```'=@`0`&````BV`!
M``T```"28`$`!@```*!@`0`$````IV`!`#D```"L8`$`.P```.9@`0`X````
M(F$!`",```!;80$`!0```']A`0`1````A6$!``<```"780$`"0```)]A`0`;
M````J6$!`!4```#%80$`!@```-MA`0`%````XF$!`!P```#H80$`$0````5B
M`0`)````%V(!`!T````A8@$``P```#]B`0`%````0V(!`"8```!)8@$`!0``
M`'!B`0`1````=F(!`!(```"(8@$`"````)MB`0`)````I&(!``4```"N8@$`
M0P```+1B`0!'````^&(!`$8```!`8P$`,0```(=C`0!$````N6,!`$0```#^
M8P$`+P```$-D`0!4````<V0!`#(```#(9`$`-@```/MD`0`M````,F4!`!$`
M``!@90$`%0```')E`0`,````B&4!`"X```"590$`(````,1E`0`>````Y64!
M`!T````$9@$`!P```")F`0`(````*F8!``H````S9@$`!P```#YF`0`F````
M1F8!`"D```!M9@$`0````)=F`0`)````V&8!`!\```#B9@$`+P````)G`0`9
M````,F<!`!<```!,9P$`"````&1G`0`,````;6<!``P```!Z9P$`#P```(=G
M`0`0````EV<!`$````"H9P$`D0```.EG`0!M````>V@!`"(```#I:`$`$```
M``QI`0`1````'6D!`!0````O:0$`%0```$1I`0`4````6FD!``<```!O:0$`
M$@```'=I`0`1````BFD!`!````"<:0$`%P```*UI`0`T````Q6D!`"H```#Z
M:0$`E@```"5J`0`3````O&H!``4```#0:@$`$P```-9J`0`)````ZFH!``H`
M``#T:@$`"@```/]J`0`:````"FL!`!L````E:P$`$P```$%K`0`2````56L!
M`!,```!H:P$`&@```'QK`0`L````EVL!`"T```#$:P$`*0```/)K`0`K````
M'&P!`"L```!(;`$`+````'1L`0`:````H6P!`(0```"\;`$`&@```$%M`0`;
M````7&T!`!H```!X;0$`&P```)-M`0`1````KVT!`!H```#!;0$`&P```-QM
M`0`7````^&T!`!@````0;@$`+P```"EN`0`8````66X!`!@```!R;@$`1```
M`(MN`0`3````T&X!``P```#D;@$`&````/%N`0`M````"F\!`!0````X;P$`
M(P```$UO`0`J````<6\!`"0```"<;P$`(0```,%O`0`E````XV\!`"X````)
M<`$`&0```#AP`0`T````4G`!`#L```"'<`$`)````,-P`0`L````Z'`!`"$`
M```5<0$`&````#=Q`0`?````4'$!`!\```!P<0$`(0```)!Q`0`)````LG$!
M`!L```"\<0$`!````-AQ`0`'````W7$!``L```#E<0$`$@```/%Q`0`&````
M!'(!``<````+<@$`!P```!-R`0`&````&W(!``<````B<@$`!0```"IR`0`$
M````,'(!`!4````U<@$`!@```$MR`0`(````4G(!``8```!;<@$`!````&)R
M`0`*````9W(!`!0```!R<@$`'````(=R`0`7````I'(!`!4```"\<@$`"@``
M`-)R`0`;````W7(!``4```#Y<@$`,````/]R`0`.````,',!`!`````_<P$`
M&P```%!S`0`3````;',!``T```"`<P$`#0```(YS`0`W````G',!``0```#4
M<P$`"````-ES`0`G````XG,!`!,````*=`$`#@```!YT`0`&````+70!``P`
M```T=`$`!@```$%T`0`&````2'0!`"4```!/=`$`#@```'5T`0`,````A'0!
M`!8```"1=`$`%````*AT`0`:````O70!`!$```#8=`$`!P```.IT`0`$````
M\G0!``<```#W=`$`*@```/]T`0`%````*G4!``@````P=0$`$@```#EU`0`4
M````3'4!``<```!A=0$`!P```&EU`0`%````<74!``T```!W=0$`#````(5U
M`0`+````DG4!`!H```">=0$`%P```+EU`0`,````T74!`!8```#>=0$`#```
M`/5U`0`2`````G8!``@````5=@$`!@```!YV`0`8````)78!`$0````^=@$`
M"````(-V`0`,````C'8!`"<```"9=@$`&@```,%V`0`9````W'8!`!(```#V
M=@$`#`````EW`0`)````%G<!``<````@=P$`"@```"AW`0`)````,W<!``X`
M```]=P$`$````$QW`0`F````77<!``P```"$=P$`"````)%W`0`3````FG<!
M``P```"N=P$`#0```+MW`0`(````R7<!`!````#2=P$`!````.-W`0`9````
MZ'<!`&8````">`$`%@```&EX`0`*````@'@!``0```"+>`$`!````)!X`0`9
M````E7@!`!H```"O>`$`&P```,IX`0`)````YG@!``(```#P>`$`!````/-X
M`0`I````^'@!``,````B>0$`!0```"9Y`0`H````+'D!``H```!5>0$`!0``
M`&!Y`0`1````9GD!`!<```!X>0$`&@```)!Y`0`&````JWD!``@```"R>0$`
M"````+MY`0`$````Q'D!``4```#)>0$`?0```,]Y`0`*````37H!``T```!8
M>@$`!````&9Z`0`%````:WH!`"D```!Q>@$`-P```)MZ`0`.````TWH!``D`
M``#B>@$`%@```.QZ`0`*`````WL!``<````.>P$`%````!9[`0`R````*WL!
M`"T```!>>P$`+````(Q[`0`/````N7L!``0```#)>P$`!P```,Y[`0`(````
MUGL!``<```#?>P$`#@```.=[`0`3````]GL!``@````*?`$`8P```!-\`0`1
M````=WP!`!$```")?`$`#@```)M\`0`A````JGP!`%D```#,?`$`*@```"9]
M`0`&````47T!``8```!8?0$`!0```%]]`0`>````97T!``8```"$?0$`"@``
M`(M]`0`M````EGT!`"P```#$?0$`!P```/%]`0`+````^7T!`"T````%?@$`
M40```#-^`0`C````A7X!`#4```"I?@$`(````-]^`0`#`````'\!``P````$
M?P$`!P```!%_`0`/````&7\!`!`````I?P$`!0```#I_`0`6````0'\!``8`
M``!7?P$`"````%Y_`0`)````9W\!``L```!Q?P$`"@```'U_`0`,````B'\!
M``8```"5?P$`&0```)Q_`0`9````MG\!`!H```#0?P$`#P```.M_`0`2````
M^W\!`!`````.@`$`#P```!^``0`/````+X`!``\````_@`$`"````$^``0`R
M````6(`!`!$```"+@`$`#0```)V``0`-````JX`!`!8```"Y@`$`!P```-"`
M`0`7````V(`!``,```#P@`$`!P```/2``0`%````_(`!``4````"@0$`#0``
M``B!`0`5````%H$!`!0````L@0$`(@```$&!`0`C````9($!`!P```"(@0$`
M'````*6!`0`@````PH$!`"0```#C@0$`'P````B"`0`%````*((!``,````N
M@@$`#@```#*"`0`.````08(!``H```!0@@$`&P```%N"`0`,````=X(!`!D`
M``"$@@$`"0```)Z"`0`2````J((!``<```"[@@$`$````,."`0`0````U((!
M``@```#E@@$`"0```.Z"`0`%````^((!``<```#^@@$``P````:#`0`$````
M"H,!``(````/@P$`1````!*#`0`U````5X,!`!L```"-@P$`+P```*F#`0`_
M````V8,!``T````9A`$`+@```">$`0`W````5H0!`$````".A`$`0````,^$
M`0!'````$(4!`!````!8A0$`(0```&F%`0`;````BX4!`!D```"GA0$`'0``
M`,&%`0`?````WX4!`!X```#_A0$`&P```!Z&`0`>````.H8!`",```!9A@$`
M/````'V&`0`\````NH8!`$````#WA@$`/P```#B'`0`^````>(<!`#L```"W
MAP$`;````/.'`0`8````8(@!`",```!YB`$`#````)V(`0`+````JH@!`!@`
M``"VB`$`/0```,^(`0`Q````#8D!`",````_B0$`#````&.)`0!0````<(D!
M`$<```#!B0$``P````F*`0`1````#8H!`!0````?B@$`#P```#2*`0`.````
M1(H!`!@```!3B@$`!P```&R*`0`*````=(H!``@```!_B@$`$@```(B*`0`/
M````FXH!``H```"KB@$`"@```+:*`0`%````P8H!`"<```#'B@$`"````.^*
M`0`&````^(H!`!,```#_B@$`$@```!.+`0`/````)HL!`%<````VBP$`!P``
M`(Z+`0`'````EHL!`!0```">BP$`!0```+.+`0`'````N8L!`!0```#!BP$`
M!P```-:+`0`$````WHL!`#\```#CBP$`&````".,`0`N````/(P!`((```!K
MC`$`&@```.Z,`0!+````"8T!`"<```!5C0$`$````'V-`0`'````CHT!``P`
M``"6C0$`#P```*.-`0`,````LXT!`!0```#`C0$`$@```-6-`0`>````Z(T!
M`!L````'C@$`!0```"..`0`0````*8X!`!<````ZC@$`)@```%*.`0`5````
M>8X!`!8```"/C@$`$````*:.`0`?````MXX!``@```#7C@$`%@```.".`0`0
M````]XX!``\````(CP$`$````!B/`0`8````*8\!``P```!"CP$`$@```$^/
M`0`7````8H\!``D```!ZCP$`"````(2/`0`%````C8\!`!D```"3CP$`!@``
M`*V/`0`1````M(\!``@```#&CP$`%0```,^/`0`+````Y8\!`!8```#QCP$`
M.@````B0`0`;````0Y`!``P```!?D`$`#0```&R0`0`B````>I`!``@```"=
MD`$`&@```*:0`0`$````P9`!``\```#&D`$`!````-:0`0`+````VY`!`",`
M``#GD`$`/P````N1`0`&````2Y$!``X```!2D0$`&0```&&1`0`/````>Y$!
M``0```"+D0$`%````)"1`0`)````I9$!``<```"OD0$`!0```+>1`0`(````
MO9$!``8```#&D0$`!@```,V1`0`4````U)$!`"P```#ID0$`+P```!:2`0`:
M````1I(!`"D```!AD@$`'P```(N2`0`\````JY(!`!H```#HD@$`(P````.3
M`0`M````)Y,!`"4```!5DP$`!P```'N3`0`(````@Y,!``D```",DP$`"```
M`):3`0`<````GY,!`!L```"\DP$`+````-B3`0`P````!90!`#@````VE`$`
M0````&^4`0`'````L)0!`!H```"XE`$`"0```-.4`0`4````W90!`#4```#R
ME`$`#P```"B5`0`4````.)4!``P```!-E0$`"````%J5`0`7````8Y4!``D`
M``![E0$`#@```(65`0`,````E)4!`!D```"AE0$`&@```+N5`0!`````UI4!
M``L````7E@$`!0```".6`0`(````*98!`!D````RE@$`$````$R6`0`%````
M798!`!0```!CE@$`$0```'B6`0`&````BI8!``L```"1E@$`"````)V6`0`.
M````II8!``<```"UE@$`!@```+V6`0`4````Q)8!`$,```#9E@$`:````!V7
M`0`<````AI<!`"@```"CEP$`)0```,R7`0`1````\I<!`!8````$F`$`"@``
M`!N8`0`0````)I@!`"D````WF`$`"````&&8`0`-````:I@!`!````!XF`$`
M%@```(F8`0`3````H)@!`$$```"TF`$`"P```/:8`0`A`````ID!`!$````D
MF0$`%0```#:9`0!!````3)D!`"4```".F0$`$````+29`0`(````Q9D!`!@`
M``#.F0$`&````.>9`0`)`````)H!``\````*F@$`!@```!J:`0`9````(9H!
M`"0````[F@$`!P```&":`0`%````:)H!``\```!NF@$`$@```'Z:`0`8````
MD9H!``8```"JF@$`!P```+&:`0`)````N9H!`!(```##F@$`$````-::`0`5
M````YYH!`!4```#]F@$`!@```!.;`0`&````&IL!`#,````AFP$`)P```%6;
M`0`D````?9L!``@```"BFP$`#P```*N;`0`&````NYL!`"(```#"FP$`&@``
M`.6;`0`G`````)P!``\````HG`$`%@```#B<`0`#````3YP!``0```!3G`$`
M%@```%B<`0`#````;YP!``P```!SG`$`&0```("<`0`+````FIP!`!@```"F
MG`$`'@```+^<`0`3````WIP!``4```#RG`$`"@```/B<`0`3`````YT!`!8`
M```7G0$`#@```"Z=`0`$````/9T!``<```!"G0$`$````$J=`0!;````6YT!
M`"$```"WG0$`$P```-F=`0`'````[9T!``4```#UG0$`#P```/N=`0`6````
M"YX!`!0````BG@$`)@```#>>`0`=````7IX!`!<```!\G@$`*````)2>`0`I
M````O9X!`!8```#GG@$`=````/Z>`0`F````<Y\!`"$```":GP$`+P```+R?
M`0`E````[)\!`"`````2H`$`)P```#.@`0`D````6Z`!`!X```"`H`$`'P``
M`)^@`0`*````OZ`!``<```#*H`$`"````-*@`0`(````VZ`!`!,```#DH`$`
M#P```/B@`0`^````"*$!`"4```!'H0$`"````&VA`0!/````=J$!`$````#&
MH0$`20````>B`0!W````4:(!``P```#)H@$`,P```-:B`0`V````"J,!``H`
M``!!HP$`!P```$RC`0`*````5*,!`#\```!?HP$`!@```)^C`0`^````IJ,!
M`#D```#EHP$`)@```!^D`0`4````1J0!`#D```!;I`$`*P```)6D`0`Q````
MP:0!`"<```#SI`$`+P```!NE`0`H````2Z4!`!$```!TI0$`!P```(:E`0`6
M````CJ4!`!,```"EI0$`%````+FE`0`&````SJ4!`#````#5I0$`#`````:F
M`0`0````$Z8!``D````DI@$`%@```"ZF`0`(````1:8!``0```!.I@$`$```
M`%.F`0`*````9*8!``D```!OI@$`!@```'FF`0`,````@*8!``T```"-I@$`
M'````)NF`0`9````N*8!``X```#2I@$`'P```.&F`0`,`````:<!``<````.
MIP$`$````!:G`0`I````)Z<!``\```!1IP$`"@```&&G`0`8````;*<!`"P`
M``"%IP$`#0```+*G`0`=````P*<!`#(```#>IP$`"0```!&H`0`'````&Z@!
M`!,````CJ`$`!P```#>H`0`-````/Z@!`"$```!-J`$`#@```&^H`0`/````
M?J@!``P```".J`$`!P```)NH`0`)````HZ@!``D```"MJ`$`"0```+>H`0`+
M````P:@!`!$```#-J`$`!0```-^H`0`7````Y:@!`!$```#]J`$`!@````^I
M`0`1````%JD!`!X````HJ0$`"P```$>I`0`#````4ZD!``@```!7J0$`!0``
M`&"I`0`(````9JD!``0```!OJ0$`3@```'2I`0`Q````PZD!`#\```#UJ0$`
M'0```#6J`0`%````4ZH!``4```!9J@$`#P```%^J`0`-````;ZH!``H```!]
MJ@$`#P```(BJ`0`=````F*H!`!$```"VJ@$`#0```,BJ`0`.````UJH!``H`
M``#EJ@$`"P```/"J`0`'````_*H!``8````$JP$`%`````NK`0`+````(*L!
M``8````LJP$`!@```#.K`0`G````.JL!`!8```!BJP$`"````'FK`0`1````
M@JL!``D```"4JP$`"0```)ZK`0`3````J*L!`!,```"\JP$`!@```-"K`0`<
M````UZL!``L```#TJP$`'`````"L`0`)````':P!``<````GK`$`$0```"^L
M`0`D````0:P!``L```!FK`$`#0```'*L`0`;````@*P!``0```"<K`$`"@``
M`*&L`0`1````K*P!``X```"^K`$``P```,VL`0`3````T:P!``D```#EK`$`
M(@```.^L`0`X````$JT!`#<```!+K0$`-@```(.M`0!A````NJT!`!D````<
MK@$`<P```#:N`0`]````JJX!`%````#HK@$`>@```#FO`0`M````M*\!`$0`
M``#BKP$`+@```">P`0`S````5K`!`!H```"*L`$`3````*6P`0#C`0``\K`!
M`"````#6L@$`&````/>R`0!"````$+,!`'@```!3LP$`.````,RS`0!`````
M!;0!`&H```!&M`$`60```+&T`0`A````"[4!`!0````MM0$`'P```$*U`0`<
M````8K4!`"H```!_M0$`(@```*JU`0`E````S;4!`!@```#SM0$`-P````RV
M`0`E````1+8!`"<```!JM@$`'@```)*V`0`O````L;8!`%X```#AM@$`00``
M`$"W`0!C````@K<!`%,```#FMP$`.@```#JX`0`X````=;@!`#8```"NN`$`
M;````.6X`0!Q````4KD!`%P```#$N0$`70```"&Z`0`\````?[H!`"<```"\
MN@$`)P```.2Z`0`S````#+L!`($```!`NP$`?@```,*[`0#6````0;P!`!D`
M```8O0$`+@```#*]`0`W````8;T!`"T```"9O0$`3P```,>]`0`F````%[X!
M`%T````^O@$`(P```)R^`0`+````P+X!`.4```#,O@$`3P```+*_`0`I````
M`L`!`#8````LP`$`*@```&/``0`A````CL`!`#P```"PP`$``P```.W``0`'
M````\<`!``0```#YP`$`$````/[``0`-````#\$!`!$````=P0$`#@```"_!
M`0`%````/L$!`"(```!$P0$``0```&?!`0!K````:<$!``0```#5P0$`%0``
M`-K!`0`$````\,$!``<```#UP0$`!````/W!`0`%`````L(!``@````(P@$`
M&0```!'"`0`+````*\(!`!$````WP@$`#@```$G"`0`#````6,(!``<```!<
MP@$`!P```&3"`0`1````;,(!``P```!^P@$`%````(O"`0`&````H,(!`!H`
M``"GP@$`"@```,+"`0`#````S<(!`#P```#1P@$`!`````[#`0`&````$\,!
M``<````:PP$`)P```"+#`0`^````2L,!`#0```")PP$`-0```+[#`0`;````
M],,!`"@````0Q`$`(````#G$`0`A````6L0!`"H```!\Q`$`)0```*?$`0`@
M````S<0!`"@```#NQ`$`)@```!?%`0`E````/L4!`#<```!DQ0$`-0```)S%
M`0`\````TL4!`"@````/Q@$`+````#C&`0`H````9<8!`",```".Q@$`*P``
M`++&`0`S````WL8!`"T````2QP$`,@```$#'`0`J````<\<!`"````">QP$`
M)0```+_'`0`P````Y<<!`"`````6R`$`)@```#?(`0!'````7L@!`$````"F
MR`$`'P```.?(`0`O````!\D!`$\````WR0$`+P```(?)`0`S````M\D!`#$`
M``#KR0$`,@```!W*`0`L````4,H!`"$```!]R@$`+0```)_*`0`H````S<H!
M`$T```#VR@$`,````$3+`0!#````=<L!``H```"YRP$`$0```,3+`0`6````
MULL!`#X```#MRP$`,````"S,`0`/````7<P!``\```!MS`$`%P```'W,`0`*
M````E<P!``P```"@S`$`*P```*W,`0`'````V<P!``H```#AS`$`.P```.S,
M`0`\````*,T!`"L```!ES0$`)P```)'-`0`<````N<T!``D```#6S0$`!0$`
M`.#-`0`1````YLX!`!@```#XS@$`"P```!'/`0`.````'<\!`!0````LSP$`
M*P```$'/`0`(````;<\!`$@```!VSP$`&@```+_/`0`;````VL\!``<```#V
MSP$`%@```/[/`0`-````%=`!`$0````CT`$`*````&C0`0`7````D=`!`!``
M``"IT`$`$@```+K0`0`U````S=`!``P````#T0$`#0```!#1`0`.````'M$!
M`!0````MT0$`"@```$+1`0`=````3=$!``@```!KT0$`+````'31`0`(````
MH=$!`!\```"JT0$`*0```,K1`0`&````]-$!`!\```#[T0$`!P```!O2`0`(
M````(](!``D````LT@$`10```#;2`0`&````?-(!`!,```"#T@$`$@```)?2
M`0`2````JM(!``D```"]T@$`"````,?2`0`'````T-(!`!,```#8T@$`#@``
M`.S2`0`B````^](!`!0````>TP$`&````#/3`0`<````3-,!``L```!ITP$`
M#0```'73`0`A````@],!``L```"ETP$`+0```+'3`0`/````W],!``0```#O
MTP$``P```/33`0`2````^-,!`"H````+U`$`"P```#;4`0`#````0M0!``@`
M``!&U`$`#````$_4`0`*````7-0!``\```!GU`$`#@```'?4`0`7````AM0!
M`!@```">U`$`$0```+?4`0`Z````R=0!`"`````$U0$`'P```"75`0`,````
M1=4!`#````!2U0$`!P```(/5`0`:````B]4!`$0```"FU0$`$P```.O5`0`0
M````_]4!``@````0U@$`!````!G6`0`$````'M8!`!,````CU@$`&P```#?6
M`0`%````4]8!``8```!9U@$`!P```&#6`0`%````:-8!`!(```!NU@$`$P``
M`('6`0`%````E=8!`!L```";U@$`&P```+?6`0`@````T]8!`"<```#TU@$`
M$0```!S7`0`"````+M<!``0````QUP$`#@```#;7`0`)````1=<!``4```!/
MUP$``@```%77`0`.````6-<!`#P```!GUP$`%0```*37`0`O````NM<!`$\`
M``#JUP$`&````#K8`0!Z````4]@!`!\```#.V`$`.P```.[8`0`B````*MD!
M`#D```!-V0$`,````(?9`0`T````N-D!`#<```#MV0$`-P```"7:`0`Q````
M7=H!`#@```"/V@$`+0```,C:`0`H````]MH!`$<````?VP$`'````&?;`0`:
M````A-L!`!0```"?VP$`?0```+3;`0`-````,MP!`((```!`W`$`@````,/<
M`0`V````1-T!`%@```![W0$`%````-3=`0`9````Z=T!``P````#W@$`(P``
M`!#>`0!%````--X!`"0```!ZW@$`)````)_>`0!M````Q-X!`!$````RWP$`
M"@```$3?`0`%````3]\!``8```!5WP$`"````%S?`0`%````9=\!`!,```!K
MWP$`%@```'_?`0`4````EM\!`!\```"KWP$`$````,O?`0`-````W-\!``0`
M``#JWP$`#P```._?`0`.````_]\!``8````.X`$`!@```!7@`0`;````'.`!
M`!$````XX`$`!0```$K@`0`5````4.`!``@```!FX`$`"0```&_@`0`4````
M>>`!``T```".X`$`&@```)S@`0`(````M^`!`!(```#`X`$`!@```-/@`0`%
M````VN`!``H```#@X`$`"P```.O@`0`%````]^`!`!L```#]X`$``@```!GA
M`0`"````'.$!``@````?X0$`"````"CA`0`'````,>$!`#D````YX0$`!```
M`'/A`0`#````>.$!`!,```!\X0$`&@```)#A`0`-````J^$!``L```"YX0$`
M!@```,7A`0`+````S.$!`!,```#8X0$`&0```.SA`0`"````!N(!``@````)
MX@$`$0```!+B`0`U````).(!``@```!:X@$`"0```&/B`0`4````;>(!``4`
M``""X@$`!````(CB`0`+````C>(!``$```"^!0``@`4``-L%``!*!0``-P8`
M``````#'!0``#@8```````!6`@``5P,```\%``"9`@``&`,``"L!````````
MIP$```````!:!0```````$L```"%!@``J@```'H"``!6!```E``````````X
M`@``'08``%X"```````````````````^````'P$``!\```#4!0``G04``$,&
M``#"`@```````",&``"+!@``8@0``/H"```)`P``;@4``"$&``!B`0``*P``
M`%L#``#Z!```4@,``)\&```3!@``0`(``.T#```^`P````````0"``!^`@``
MV@$``*,%``#*`@``+P```!L$``#I````+@,``*D```"N!```X@0``&P"````
M````SP4``)P```!W`P``5`8```````!-!0``G0$```````!=`@```@(``'``
M``"Z!```5P$``````````````````.\"``"&!`````````````"V`0``604`
M`)P%``"[!0```````&X#``"!`````````-,!```6````4`8``,L%```J!0``
M``````<&```]!@````````````#0!0``=0,``%<```"<`0``Q@4``(0$```M
M`P``PP0````````-!@``-@```&8&``#S```````````#``"6````````````
M``#Q`@``M0$``(,!`````````````'(#``!1!```)00``(<#``#R`0``.P(`
M`%@#``"<`@```````-0```"V!````````%$```#\`P``00$``"`"``!*!```
M2@8``,4%``!T`0``XP4```````">`@```````````````````````,4"````
M```````````````Z````_`$```````#\!````````+P`````````2@(``&@"
M``!)`0``R0,```````#Y`@``8`$``-D!```<`@``````````````````W@(`
M````````````UP(````````%!0``!`0``)<%``#J!```A@4``"P````%!@``
MZP0``&X$``"6!0``#0```(D&``#N`P``00(``!@"````````O04``-,$````
M````.0$``)\%``#1`P``;`8``,P!`````````````&$%``!+!0``5```````
M```>!0``$@4``$P$``````````````````!B`@``WP4``&8`````````%08`
M`$H```##!@``=`0````````D!0``-0,````````2`0``[P````````!Q!@``
M`````%4$````````-P4````````(`P``Y0,``+P&``!$!```R04``#8&```%
M````CP8``(<&``!8!```WP(``,$$``!U!```9`8```````!$!@``&@0`````
M``#(!```>0,``"4&```:`P``I`$``#(!````````%````"D"```*!@``5`,`
M`!@!````````_0(``,$"``#R`P``M@````````#F````:P0`````````````
M>P$````````P`@``9`0```````"&!@``:P,```````!E!@``^`0``(@!````
M````"P````````!E````%@0``,$&``!.!``````````````*`P``[@(``.T%
M``#%!```J@4``#8!``#T`0``O@$`````````````)P4``'H$```.!```'@$`
M`"\$``"5`P``_0```,<$``"Z`@``B0$``/T$``#8````6@,```(#``"(!0``
M``````````!G!0``(0$``"8````W`0```````"@%``#H!````````,X%``#+
M!```9P$``-@#``"0`P```````````````````````,0&```2`@``'0(``+(`
M````````9`,``)L`````````D`$``!H"``!G!`````````````"]`0``.P4`
M`!4%``#%`P``204``/X$``"S````$P4``$8#``#M`@``U0(``'0%````````
MCP4```````!S`@``*P,```````"[`0``A`$```````````````````````!)
M`P``$`,`````````````^P$``-X$``"H`0```````"X&````````@0,`````
M````````/`(``)D$``#,!0```````!`"``#+`P``=````(8`````````````
M``8&`````````````&(&````````H`4``'8!``"J`P``N`(````````\`P``
M,P(``*\"`````````````&$!``"9!0``D`4``"L$```#!0```````(H"``#N
M````*00``'D$``#)````I0,```````!'!````````!T`````````ZP4``*\`
M```U!```G0```!$&``!``P``O00```````"%`@```````*4&```S````P@$`
M````````````60,``/$%``!+!@```````````````````````+X&``#E````
MA0$``(H%````````.`8``'8$``#F!0``0@$``'(```!.`0``:0$````````.
M`````````/L````L!```F0````````!W!```````````````````MP4`````
M``#,`````````,H!``#S`P``````````````````60``````````````R`,`
M`!8"``#!!0``9`4``#`$```/`P````````````"J!``````````````!`@``
M`````#X&``!7!@``W````.0%``!K!0``XP$``,@%````````"P,``"8$````
M`````````!D%```]````GP$``*$$``#@!0``$0(``````````````````+H#
M``#B`````````%8#````````LP$`````````````IP(```````"6!```#04`
M``````";!@``#0,``%X&``#/`@``"@(``,T```"&`P``7`,``),!``#V`P``
MG`,``%L%``!?!@``J`0``,\#``##````/@$`````````````*`$``-L"``#W
M`@``40$``'$#``#"!@```````'T"````````E`,```````"%!```#@(``%`%
M``!@!````````/$#````````70,``,\$```=`0``Z0(`````````````;P0`
M``````"]`@``=`,```````````````````````"5!0```````+`#````````
M>@$``/X%```C````7P0``$`&``!C````S0$``/H!``!/`P``LP4``.4%``![
M!@``\`4``/4"``!\`P``D00``+4`````````)````#D&``"T`@``UP4``-T"
M```;!@``&P4``)H```!"!@``<P0```````#P`P```````%4%``!%`@``T@0`
M`$D&```?!0```````(X```#T`P````````````#L!```=04``",$``#=!0``
M*P4``"$%``#L`P```````,P"``#A`````````$8"````````/`8```````!+
M`@``-@4`````````````UP$``!L````@`P``RP$``#,%```%!```60$`````
M```*!```+0(`````````````0P4`````````````N0,``.````!0`@``C@(`
M`.0$``!1!@```````/8"``!4`@``CP$``$@&``"_`@``Z@(``)(%```^`@``
M.@4``%@````0!@``;P```+L"``"S!```KP8``/T%``",!@``$04``)P$```K
M`@```````-8!````````/P8````````_`@``:@8``*L%``!:`@``V04``!X#
M````````&P$``#,$````````<@8`````````````*@8``)0"``#F`0``+P4`
M```````C`P````````````"R`P```````"4#````````&P(``+@#``",!```
MYP````````"\!```$P0````````4`P```````)L!```0````1@0````````P
M`P``!P```"`$``".!@`````````````[`0``U0,``"T!``!:!```B`,`````
M``"L`P``G08``"(```"#!@````````````#W`P```````(`&````````````
M`"`%``!R`@```````*D%`````````````'T!``!L````;`4``-0$``"(`@``
M-08``#L&``"$`P``:P```-8#``#A`P``Q`(```````#V!```@@8``&D&``#]
M`P``X`$``*H&``!M!@``>@4```,$``"H`@``,0,``&4!```6`P``4P$``"P!
M```(!```Q@0``&8%```/`````````-@%````````F`4``%("```N````&`0`
M`/8%````````)P(``,$#```_`0``/P``````````````"@$``,P#````````
M'P0```8"````````````````````````_P4`````````````^`4``+$$``!_
M````H0,``)`&```V!```CP(``,`&``!K`@``R0(``"\#````````@`0``"D!
M``#3!0``4`0``,4&```B!```M04``'\&``!5`P``K0,``(8!``#L`0``\@0`
M`"<$`````````````'0&``"D`@``I@0``.\!``"A!@``R00``-@"```I!@``
M10```&D%``#&!@``O@,```````"+`````````%D$``"D````-`(``*8"``"=
M`@``B00```````!.`@``F0$```````"=!```H````.(#``!N`@```````$D$
M``"!!````````/$$``"*`P```````$@!``"``@``4@8``/4!``#``@``JP(`
M``````!X`@``1@$`````````````+00``$<#```W`@````````````"_!```
M_````/@#``#F`@``_`(``#$```!1`P```````*$```#D`0``D`(```````#J
M`0``%@8`````````!```[00``.(%````````(@$``*`#````````HP8``(H!
M````````````````````````L`0``&L!``!4!0``@@```.$!``"I`P``*`0`
M`&\%````````E@,```````#B`0``&````&@&``"(````I@4`````````````
M(@4``,T"``#^````K@$``,($``""!```U`,```````!_`P```````'`%```R
M!@```````$@%````````L0``````````````P0$``+P%``#S`@``D@8```T!
M``!%`P``L08``.8#``!G`@``?P0````````'`P``VP````````#:!0``````
M``````"1!@``7`8`````````````.`$``!$$``#/`0``5P4``,H````!`P``
MC04``'D````^!```@@$``&<&````````7```````````````&0(``/(```!3
M!@```````,@!```N!0``H`8``%`!``#;`P``'`$```````"M!```7@````H%
M````````JP,``(,"````````!P0```````#A!```?0````8```"M`@``:@(`
M``````!]!0``<P,``*<&````````)`$````````$!@``"00``#$$``"M`0``
MJ`8``&X&``#I`P``Q@```(H```!9`@``>P4`````````````.@0``'L$``#W
M!```Z`,``*D$```2`````````+D$```T!```CP0``"<&``#?`0``@0(`````
M``#K`0``*0,``&\!````````E@8`````````````T0(``"(#``!Q````E0``
M`!@&``#C`@```````!,#``"%!0``U04``$,!`````````````/(%``!U`0``
M80```#(#```5````9`$```(````T!@``^00```````#^`@```````-P!``!$
M`@``````````````````<`,```````!M`0``H@,``/L$``"2`@``U0$`````
M````````GP(``%\"``"B!0``N````","``!A!@``&08``)L"``!3````````
M`&T%````````E@(``!X$`````@``8P4``!`%``"<!@``/P0``)`````P!@``
MM@8```````!4!```.@(``.P````,`@``^`$``+<#``")`@``K@```&````#A
M`@``:`````````!P`0``:@````````#-!0``C00``-<#``"T!@```P$`````
M``"D`P``V@(```$&````````Z@```+<````E`0``>`4``%,$``"C`@``````
M`"<!``#@!```2`(``&H%``#;`0```````.<!```L`@```````%<"``!'!@``
M`````",%``#Q````!0,``!$```"G````E08``!H&``"L!@```````'L"``!H
M`P``WP0``+`"``":!0``20(``)@$``"#!0``_@$```````"Y`0``````````
M```)`0```````',%``!8`0``&@4```````":`@``;@``````````````#`,`
M`)$"``#<!```+P(``/D#``"H````_@,``#("``"``0```````"`&``#<!0``
M```````````/`@```````)8!``!+`0``U@(`````````````Q@$`````````
M````3P$``&T#``!!!```)@(``'8#``!V````6@8``&$$````````4@0``*L`
M`````````````(X%``!C`P```````'@$``"A`0````````````!5!@``]04`
M``````#$!```?`0``````````````````)0&```\`````````&D"``"H!0``
MZ0$```````">!@``OP8``*X&``!L`0```````$4$````````S@(``'$%``#,
M!```*````'X%``#;!```!P4`````````````.`4``%\%``#Z`P``7@$`````
M`````````````$\```!$`P````````,```"-`@`````````````H`P``Z04`
M`!H```"8`0``"08``!(&``"T!0``,@0```````!F`0````````````#_````
M`````"@&``#S`0```````)L%``"]`P``9```````````````F@0```8#``#G
M`P``5`$```````"X!0``PP4``!<```#7````%P,``+@$``#G!```K@(``+0!
M``!#````,0(``-(!``"O!```3`$``'D&``"B````?P$``$D`````````B@8`
M`*L&```+`0``+P$``*8#``!O`@``T`,``$`!```P`````````!($````````
MPP,``+<$``!&`````````*0&``!W````"0(``+,&```)!0``608``+`&``#_
M`P``D0,``,8"````````1P```-P"``#_!```%P$``)H#``#X`@``50(``,4!
M```/`0```````"(&````````'@```/<!``"2`P``GP`````````-!```-`$`
M``````#G`@```````$<!``!F!```_P(``&D$``!J`P``2P0``/@`````````
MAP````````"$````I00``"8#``")````BP0````````5!```HP0``"<#``"I
M`@``/0,``*,!``!8!0``)0```,(%````````A@(````````R!0``Q`,``,,"
M`````````````$T&``"P`0``-@,``"H#```T!0``0`0``#L#````````'`4`
M````````````3@4``.@``````````````'L#``"\`P``[`4```L$````````
MY`(``!4!````!@``H`(``+,"``!U`@````````@%``!Y`0``$@,``$$%```4
M!```$P$````````Q`0```````#P%``"5`0```````,<#```6`0``EP(``.T`
M``">!0``"````',```#``P``H`$``*,``````````````-4```!,`@``Y00`
M``````"G!0``<@0``*\!``#P!```%`(``!<$```E!0``3P0``*T%``"Z!@``
M#0(````````%`0``N`$``#H!```M````8`(``,,!`````````````$\%``"/
M``````````````#(````I04`````````````\````#4%``#Y`0```````,D!
M````````,04``.X!``!8!@``]P4``)`$````````1`$```````#]`0``4P4`
M`&$#``"K!````````!@%``"L`@``(0```"`!``!3`@``0@0``*8&````````
MU@```+(%```4`0```````'D%``#1`0``+`8``&P$``!E!```TP````````#0
M!```!`,```````"R!```BP4``'8"```9!```70$``*P```"(!@``W0``````
M``!5`0```````'(!``"$`@``*`(``%\!```U`@``'````!8%``!7!```M0,`
M``(!``#-`P``Y`,`````````````1@4````````,`0``\`(``#P!``!X!@``
M0P(``#L$```.`0``+08``.@%````````.`0```````"U`@``6P$``"P%``!#
M`P``F@8```L&````````?08``!0%````````[0$`````````````EP$``'@!
M``!%!0``K`4``+0```#K`P``EP8``"D```"5!```````````````````````
M`%8&```O!@``H04``!P#``#C`````````$4&``#O`P``^P4```$!````````
M#`4```````!G`P```````-,#````````M@4```````"V`P```````-,"``!.
M`P```````-(%``!U````S00```````#5!```#@4`````````````OP4``'8%
M```"!@``NP8``#0```````````````````"+`P``N04``,8#````````OP$`
M`"H"``!#!```D@````````!Z!@```````/P%``!`````2@,`````````````
M*P8``#D%````````!@0``.,#``#9`````````)$```#U!````````%P%```(
M`0```@0``.@!```S!@````$``&8#``"'`@``QP(```````!3`P```````(0%
M``#N!0```````%T&````````1P4``*L!`````````````#X%``"^````3```
M`(`#```0!```'P,``,<!```Y`@``"P(``*T&``"1!0``P`0``+0$``!G````
M?`$``$T``````````````%X$````````,`4``"0&````````C`$`````````
M````!`4``!D#``"H`P``0`4``%``````````D0$``,````"5`@```````.`#
M```=!0``]````$P&````````$P(```````"B!````````+L`````````W@4`
M`!P&```D!```"@```%H```#W`````````!,```!\`@``%P4```8%``!W`@``
MM08``%L$``#`!0``BP$```0!``#7!```HP,``$$&``#I!```%P(``'$$``#0
M`````````'H#``!H`0``7P````````#J!0``'@8``````````````````"8%
M````````X04``'H```"8`P``@@4``"H$``!V!@``Q0```(T!``#?`P``@08`
M`'0"``#P`0````````````!.`````````+H%``"G`P``8P$``/8```"$!@``
M`````+\```#2````=08``#T"````````=P4``/("``!@`P``<`(````````E
M`@``80(``(,#``````````````````````````````````!X````V@,```P&
M````````%0,``.4!`````````````#P$``"7`P``Q`4```````!;!@``)@$`
M`"T%````````<0$``&D#``!;`````````#,!``"Z`0``^@4``(T```!X`P``
MEP````````"7!```\P4``(("``"T`P``L@8``,(#````````T@,````````!
M!0```````-8%``!E`P``-`,``),&``!!````\0$``.L````F!@``MP(``+L#
M``!O`P``RP(```\$``!>!0``7`(``(P``````````````$@$````````I0(`
M``<!````````-0````````!<`0``\P0````````9`0``OP,````````A`P``
MZP(```P```![````````````````````L````&(#````````:`0``,H#``!>
M`P``8@```+L$``#T!````@4```````!K!@```````*0%``!1`@```````.@"
M``!]`P``2@$``",!```]`0``W@```),#```D`@``D@$``,(````0`0``````
M`!D```"L`0``-P```)X$````````;00``"0#``"8!@``Q`$``!$#```B`@``
ML@(``',&``!2````1````+H```"3````W00```````!@!@``]`4``#D#````
M````BP(``#8"``!&!@``H@8``%(%``!"`P```````)0%``#L`@``]`(`````
M``"B`0``AP4``),$``!W`0``L`4``'X&``#6!```<P$``+P!``#<`P``2P,`
M``````!L`P``L0$```````"\`@``G@```&,&``#B`@``*04``)L$````````
M3P(````````]!```@````-H$````````CP,```````#F!```F@$``-$$``"@
M!```0@````D```!P!```T`$``(,$`````````````)($```.`P```````(P%
M`````````````"X$````````5@```)X!``"]!@``;0```/\!``#*!0``W0,`
M``\&````````F````*\#````````[@0``.H#````````+`,```````"I!@``
M0@4``$("````````W@,````````7!@``F08``%T%``!%`0```````*\%``#0
M`@`````````````U`0```P(``.\%``"%`P``!P(``'`&``"X!@``,`$``*H!
M``!E`@``700```````#$````50```!T#``!!`P``DP4``((#```@````````
M`+X"``#*!```1`4``)L#``!Q`@``8P(``&H!````````RP```#$&``#=`0``
MAP$``,$```!1!0``````````````````5@$``)0!``!F`@``G0,`````````
M````$0$``%8%``!2`0``904``&0"``"M`````````*8`````````6@$``&H$
M```_!0``GP,``````````````````&@%````````O0````````#G!0``````
M`&T"````````'P8```````"R`0``````````````````G@,``"H`````````
M`````(@$```_`P``6`(``,X```"A`@``````````````````;P8````````#
M!@``@04``%T````!!```%0(``*8!``"G!````````+,#``#(`@``>0(``-D#
M``#``0```````*4`````````-P0``-@!``!^````)P```!X"````````````
M`$X&``"Q`@``U`$``(<$``!C!````P,``'X!``!_`@``"P4``-@$``!I````
M!````*("```Y````!0(``+D&``"W`0```````($!````````&P,`````````
M````'00``$T!```R````C@$```````"I`0``M@(``%`#``!B!0``U`(``+$#
M``#/````A0```'X$````````DP(```````#9!```!@$``$T#````````"`8`
M`!0&``".`P``O@0``"H!``!-`@``C`,````````]!0``.00``-$`````````
M?00``%P$``")!0``3`,``-H````[```````````````A`@``K@,``"$$``!N
M`0``Y`````````!R!0```````)D#``#>`0``7P,```@"````````K`0``.4"
M`````````````'\%````````@P```"X!``#V`0``V0(``*4!``"D!`````4`
M`$P%``"4!`````````````"N!0```````/L"``"W!@``S@,``)@"```?`@``
MT@(``,X!```Z`P```````+$%```S`P``300``#@#``"?!```N0```(H$````
M````S@0``$@#```:`0``C08````````W`P```````*H"```X````WP```$<"
M``#O!```C`(``%L"``"-`P``QP```.,$``#U````^0````P$```Z!@``2```
M`'<&`````````````!P$````````M00``'P&``#@`@``T04```````")`P``
M^P,``+D"``!\````8`4```````#U`P```````"X"````````?`4`````````
M`````````/H```".!```^04```````!/!@````````````!^`P```"`H)7,@
M9&%Y<R!A9V\I`"`H06-C97-S:V5Y("5S*0`@*&EN("5S(&1A>7,I`"`H=&]D
M87DI`"`H=&]M;W)R;W<I`"`H>65S=&5R9&%Y*0`@870@`"(E<R(@:7,@;F]T
M(&$@9&ER96-T;W)Y+@`E9"`E<R!A;F0@)7,`)60@8GET97,@=W)I='1E;BX`
M)60@;V8@)60@96YT<FEE<R!M87)K960@87,@=7`M=&\M9&%T90`E9"UD87D@
M9F]R96-A<W0`)7,@+2!.;W1I8V4`)7,@1FEN9V5R<')I;G0`)7,@2T(`)7,@
M36%I;G1E;F%N8V4@3W!E<F%T:6]N<R`M($-O;F9I<FUA=&EO;@`E<R!3971U
M<``E<R!3:6=N(%5P`"5S(%1E<FUS(&]F($%G<F5E;65N=``E<R!A;')E861Y
M(&5X:7-T<RX`)7,@870@)7,@)7,`)7,@:7,@<F5Q=6ER960`)7,@;6EN=71E
M<P`E<R!N;W0@9F]U;F0N`"5S(&YO="!F;W5N9"X@4G5N("=T<F%N<VQA=&EO
M;B!E>'1R86-T)R!F:7)S="X`)7,@=&\@)7,@;V8@)7,`)7,G<R!!9&1R97-S
M($)O;VL`)7,G<R!#86QE;F1A<@`E<R=S($YO=&5P860`)7,G<R!487-K;&ES
M=``E<SH@)7,`+"!G=7-T:6YG("5S("5S`"P@=F%R:6%B;&4@9G)O;2`E<R!T
M;R`E<P`M+2!S96QE8W0@+2T`+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M`#$R($AO=7(@1F]R;6%T`#(T($AO=7(@1F]R;6%T`#(T(&AO=7)S`#Q0<F5V
M:6]U<P!!(&1A=&%B87-E(&)A8VME;F0@:7,@<F5Q=6ER960@9F]R('1H:7,@
M8FQO8VLN`$$@9F%T86P@97)R;W(@:&%S(&]C8W5R<F5D`$$@<'5B;&EC(%!'
M4"!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%!'4"!K97D@:7,@<F5Q=6ER960@=&\@=F5R:69Y(&$@<VEG;F5D(&UE
M<W-A9V4N`$$@<'5B;&EC(%!'4"!K97DL('!R:79A=&4@4$=0(&ME>2P@86YD
M('!A<W-P:')A<V4@87)E(')E<75I<F5D('1O(&1E8W)Y<'0@82!M97-S86=E
M+@!!('!U8FQI8R!01U`@:V5Y+"!P<FEV871E(%!'4"!K97DL(&%N9"!P87-S
M<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N(&$@;65S<V%G92X`02!P=6)L
M:6,@4R]-24U%(&ME>2P@<')I=F%T92!3+TU)344@:V5Y+"!A;F0@<&%S<W!H
M<F%S92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N`$$@<'5B
M;&EC(%,O34E-12!K97DL('!R:79A=&4@4R]-24U%(&ME>2P@86YD('!A<W-P
M:')A<V4@87)E(')E<75I<F5D('1O('-I9VX@82!M97-S86=E+@!!('!U8FQI
M8R!334E-12!K97D@:7,@<F5Q=6ER960@=&\@96YC<GEP="!A(&UE<W-A9V4N
M`$%-($-L;W5D<P!!32!,:6=H="!286EN`$%-(%)A:6X`04T@4VAO=V5R<P!!
M32!3;F]W(%-H;W=E<G,`04TO4$T`05!)($E$`$%B;W5T('1H:7,@961I=&]R
M`$%B;W5T+BXN`$%B<V)O='1O;0!!8G-M:61D;&4`06-C97-S(&1E;FEE9"!C
M<F5A=&EN9R!61E,@9&ER96-T;W)Y+@!!8V-E<W,@9&5N:65D(&-R96%T:6YG
M(%9&4R!F:6QE+@!!8V-O=6YT(%!A<W-W;W)D`$%C8V]U;G0@9G)O>F5N+@!!
M8V-O=6YT:6YG`$%D9`!!9&0@0VAI;&0@1W)O=7``061D($-H:6QD(%!E<FUI
M<W-I;VX`061D($AE<F4Z`$%D9"!.97<@1W)O=7``061D($YE=R!097)M:7-S
M:6]N`$%D9"!A(&YE=R!U<V5R.@!!9&0@8V]L=6UN`$%D9"!N97<@;65M8F5R
M<P!!9&0@<&%I<@!!9&0@=&AE("5S($UE;G4@87,@82!-;WII;&QA(%-I9&5B
M87(`061D('1O(&%D9')E<W,@8F]O:SH`061D('1O(&UY(&%D9')E<W,@8F]O
M:P!!9&0@=7-E<@!!9&1I;F<@;F5W(&9I;&5S('1O(')E<&]S:71O<GDZ`$%D
M9&EN9R!U<V5R<R!I<R!D:7-A8FQE9"X`061D<F5S<P!!9&1R97-S($)O;VL`
M061M:6YI<W1E<B`M('-E="!P97)M:7-S:6]N<R!F;W(@;W1H97(@=7-E<G,`
M061M:6YI<W1R871I;VX`061S`$%F9VAA;FES=&%N`$%L8F%N:6$`06QG97)I
M80!!;&EA<P!!;&EG;@!!;&EG;FUE;G0Z`$%L;`!!;&P@075T:&5N=&EC871E
M9"!5<V5R<P!!;&P@1W)O=7!S`$%L;"!097)M:7-S:6]N<P!!;&P@9F]U<B!S
M:61E<P!!;&QO=R!M=6QT:7!L92!A9&1R97-S97,`06QL;W<@<V5T=&EN9R!O
M9B!O<F1E<F5D(&QI<W0@='EP93\`06QR96%D>2!E>&ES=',`06QT97)N871E
M($E-4U`@3&]G:6X`06QT97)N871E($E-4U`@4&%S<W=O<F0`06QT97)N871E
M($E-4U`@57-E<FYA;64`06QT97)N871E(&5M86EL(&%D9')E<W,`06QT97)N
M871E('1E;7!L871E<P!!;'1E<FYA=&4@=&5X=#H`06UE<FEC86X@4V%M;V$`
M06X@:6QL96=A;"!V86QU92!W87,@<W!E8VEF:65D+@!!;B!U;FMN;W=N(&5R
M<F]R(&AA<R!O8V-U<F5D+@!!;F1O<G)A`$%N9V]L80!!;F=U:6QL80!!;F]N
M>6UO=7,@4')O>'D`06YS=V5R`$%N=&%R8W1I8V$`06YT:6=U82!A;F0@0F%R
M8G5D80!!<'!L:6-A=&EO;@!!<'!L:6-A=&EO;B!,:7-T`$%P<&QI8V%T:6]N
M(&ES(')E861Y+@!!<'!L>2!T;R!#:&EL9"!3:&%R97,`07!P<F]V90!!<'!R
M;WAI;6%T92!3:7IE`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F-H
M:79E($9I;&4@4VEZ90!!<F-H:79E($YA;64`07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<VEG;G5P(')E<75E<W0@9F]R("5S(#\`07)G
M96YT:6YA`$%R;65N:6$`07)M96YI86X@*$%235-#24DM."D`07)T`$%R=6)A
M`$%S8V5N<VEO;B!)<VQA;F0`07-C:6D@07)T`$%S:6$O4&%C:69I8R!296=I
M;VX`07-K(&9O<B!C;VYF:7)M871I;VX@8F5F;W)E(&1O:6YG(&UA:6YT96YA
M;F-E(&]P97)A=&EO;G,_`$%S<VEG;FUE;G0@8V]L=6UN<P!!='1E;7!T('1O
M(&1E;&5T92!A(&YO;BUE>&ES=&5N="!G<F]U<"X`071T96UP="!T;R!D96QE
M=&4@82!N;VXM97AI<W1E;G0@<&5R;6ES<VEO;BX`071T96UP="!T;R!E9&ET
M(&$@;F]N+65X:7-T96YT('!E<FUI<W-I;VXN`$%T=&5M<'0@=&\@961I="!A
M(&YO;BUE>&ES=&5N="!S:&%R92X`071T<FEB=71E<P!!=6=U<W0`075S=')A
M;&EA`$%U<W1R:6$`075T:%]C>7)S<6PZ(%)E<75I<F5D(&EM87`@97AT96YS
M:6]N(&YO="!F;W5N9"X`075T:%]C>7)U<SH@0F%C:V5N9"!D;V5S(&YO="!H
M879E(')E<75I<F5D(&-A<&%B:6QI=&5S+@!!=71H7V-Y<G5S.B!297%U:7)E
M9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?9G1P.B!297%U:7)E
M9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@=VET:"!T
M:&4@+2UE;F%B;&4M9G1P('-W:71C:"X`075T:%]I;6%P.B!297%U:7)E9"!)
M34%0(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&A?:W)B-3H@4F5Q=6ER960@
M:W)B-2!E>'1E;G-I;VX@;F]T(&9O=6YD+@!!=71H7VQD87`Z(%)E<75I<F5D
M($Q$05`@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]L9&%P.B!5;F%B;&4@
M=&\@861D('5S97(@)7,N(%1H:7,@:7,@=VAA="!T:&4@<V5R=F5R('-A:60Z
M(`!!=71H7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<P!!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<P!!=71H7VUC86PZ(%)E<75I
M<F5D($U#04P@97AT96YS:6]N(&YO="!F;W5N9"X`075T:%]S;6)A=71H.B!2
M97%U:7)E9"!S;6)A=71H(&5X=&5N<VEO;B!N;W0@9F]U;F0N`$%U=&AE;G1I
M8V%T:6]N(&9A:6QE9`!!=71H96YT:6-A=&EO;B!F86EL960N("5S`$%U=&AE
M;G1I8V%T:6]N(')E:F5C=&5D(&)Y(%)!1$E54R!S97)V97(N`$%U=&AE;G1I
M8V%T:6]N('1O($944"!S97)V97(@9F%I;&5D+@!!=71H96YT:6-A=&EO;B!T
M;R!T:&4@4TU"('-E<G9E<B!F86EL960N`$%V86EL86)L92!F:65L9',Z`$%Z
M97)B86EJ86X`0D]&2"!%>&-U<V5S`$)A8VMG<F]U;F0`0F%C:V=R;W5N9"!#
M;VQO<@!"860@:V5R8F5R;W,@<&%S<W=O<F0N`$)A9"!K97)B97)O<R!U<V5R
M;F%M92X`0F%H86UA<P!"86AR86EN`$)A;'1I8R`H25-/+3@X-3DM,3,I`$)A
M;F=L861E<V@`0F%R8F%D;W,`0F%S96QI;F4`0F5L87)U<P!"96QG:75M`$)E
M;&EZ90!"96YI;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";&]C:R`B)7,B
M(&]F(&%P<&QI8V%T:6]N("(E<R(@;F]T(&9O=6YD+@!";&]C:R!3971T:6YG
M<P!";&]C:R!4>7!E`$)O;&0`0F]L:79I80!";V]K;6%R:W,`0F]R9&5R`$)O
M<F1E<B!T:&EC:VYE<W,Z`$)O<F1E<G,`0F]S;FEA(&%N9"!(97)Z96=O=FEN
M80!";W1H`$)O='-W86YA`$)O='1O;0!";W5V970@27-L86YD`$)R87II;`!"
M<FET:7-H($EN9&EA;B!/8V5A;B!497)R:71O<GD`0G)U;F5I($1A<G5S<V%L
M86T`0G5I;&1I;F<@34\@9FEL97,@9F]R(&UO9'5L92`E<RXN+@!"=6EL9&EN
M9R!L;V-A;&4@)7,N+BX@`$)U;&=A<FEA`$)U;&QE=&5D($QI<W0`0G5R:VEN
M82!&87-O`$)U<G5N9&D`0TU3`$-20P!#4DP@1&ES=')I8G5T:6]N(%!O:6YT
M<P!#7V5L;"!0<F]P97)T:65S+BXN`$-A8VAE(&EN:70@=V%S(&YO="!C;VUP
M;&5T960N`$-A;&5N9&%R`$-A;&T`0V%M8F]D:6$`0V%M97)O;VX`0V%N(&YO
M="!R97-E="!P87-S=V]R9"!A=71O;6%T:6-A;&QY+"!C;VYT86-T('EO=7(@
M861M:6YI<W1R871O<BX`0V%N)W0@8V]N;F5C="!T;R!)34%0('-E<G9E<CH@
M)7,`0V%N861A`$-A;F-E;`!#86YC96P@4')O8FQE;2!297!O<G0`0V%N;F]T
M(&1E;&5T92!F:6QE("(E<R(N`$-A;FYO="!F:6YD(&$@=&5M<&]R87)Y(&1I
M<F5C=&]R>2X`0V%N;F]T('!R;V-E960@=VET:&]U="`G=&%R9V5T1FEL92<@
M<&%R86UE=&5R+@!#86YN;W0@<F5M;W9E(&1I<F5C=&]R>2`B)7,B+@!#86YN
M;W0@<F5M;W9E+"`E9"!C:&EL9')E;B!E>&ES="X`0V%N;F]T(')E;W)D97(L
M(&YU;6)E<B!O9B!E;G1R:65S('-U<'!L:65D(&9O<B!R96]R9&5R(&1O97,@
M;F]T(&UA=&-H(&YU;6)E<B!S=&]R960N`$-A;FYO="!R;W5T92!M97-S86=E
M('1O('-P96-I9FEE9"!N=6UB97(N`$-A<&4@5F5R9&4`0V%P=&EO;@!#871E
M9V]R:65S(&%N9"!,86)E;',`0V%Y;6%N($ES;&%N9',`0V5L;"!0:&]N90!#
M96QL(%!R;W!E<G1I97,`0V5L;"!P861D:6YG.@!#96QL('!R;W!E<G1I97,`
M0V5L;"!S<&%C:6YG.@!#96QL<&AO;F4`0V5L=&EC("A)4T\M.#@U.2TQ-"D`
M0V5N=&5R`$-E;G1R86P@069R:6-A;B!297!U8FQI8P!#96YT<F%L($5U<F]P
M96%N("A)4T\M.#@U.2TR*0!#97)T:69I8V%T92!$971A:6QS`$-E<G1I9FEC
M871E($]W;F5R`$-E<G1I9FEC871E(%!O;&EC:65S`$-H860`0VAA;F=E`$-H
M86YG92!T:&4@;F%M92!A;F0@861D<F5S<R!T:&%T('!E;W!L92!S964@=VAE
M;B!T:&5Y(')E860@86YD(')E<&QY('1O('EO=7(@96UA:6QS+@!#:&%R`$-H
M96-?:R!,:6YK+BXN`$-H:6QE`$-H:6YA`$-H:6YE<V4@4VEM<&QI9FEE9"`H
M1T(R,S$R*0!#:&EN97-E(%1R861I=&EO;F%L("A":6<U*0!#:&]O<V4@82!P
M87-S=V]R9`!#:&]O<V4@82!U<V5R;F%M90!#:&]O<V4@:&]W('1O(&1I<W!L
M87D@9&%T97,Z`$-H;V]S92!L:7-T('-T>6QE('1Y<&4@*&9O<B!O<F1E<F5D
M(&QI<W1S*0!#:')I<W1M87,@27-L86YD`$-L87-S(&1E9FEN:71I;VX@;V8@
M)7,@;F]T(&9O=6YD+@!#;&5A<@!#;&5A<B!-4T]F9FEC92!T86=S`$-L96%R
M(&]U="!U<V5R.B`E<P!#;&5A<B!U<V5R`$-L96%R('5S97(@9&%T80!#;&5A
M<FEN9R!,871E`$-L:6-K('1O($-O;G1I;G5E`$-L:6-K871E;&P@=FEA($A4
M5%``0VQO<V4@5VEN9&]W`$-L;W5D<P!#;&]U9',@16%R;'D`0VQO=61Y`$-O
M8V]S("A+965L:6YG*2!)<VQA;F1S`$-O;&QA<'-E(%-I9&5B87(`0V]L;&%P
M<V5D(&)O<F1E<G,`0V]L;VUB:6$`0V]L;W(`0V]L;W(@4&EC:V5R`$-O;&]U
M<B!S96QE8W1I;VX`0V]L<SH`0V]L=6UN('1I=&QE<P!#;VUI8W,`0V]M;6%N
M9`!#;VUM86YD(%-H96QL`$-O;6UE;G0`0V]M;6]N($YA;64`0V]M;W)O<P!#
M;VUP86YY`$-O;7!O<V4@365S<V%G92`H)7,I`$-O;7!U=&5R<P!#;VYD:71I
M;VYS`$-O;F9I9W5R871I;VX@1&EF9F5R96YC97,`0V]N9FEG=7)A=&EO;B!I
M<R!O=70@;V8@9&%T92X`0V]N9FEG=7)E("5S`$-O;F9I<FT@4&%S<W=O<F0`
M0V]N9V\`0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E<'5B;&EC(&]F('1H90!#
M;VYN96-T:6]N(&9A:6QE9"X`0V]N;F5C=&EO;B!F86EL960Z(`!#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N`$-O;FYE8W1I
M;VX@<F5F=7-E9"!T;R!T:&4@<'5B;&EC(&ME>7-E<G9E<BX@4F5A<V]N.B`E
M<R`H)7,I`$-O;FYE8W1I;VX@=&\@1E10('-E<G9E<B!F86EL960N`$-O;G1A
M8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B
M;V]K+@!#;VYT:6YU90!#;V]K($ES;&%N9',`0V]O:VEE`$-O<'D`0V]P>2!F
M86EL960Z("5S`$-O<'D@<V5L96-T:6]N`$-O<W1A(%)I8V$`0V]T92!D)TEV
M;VER90!#;W5L9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92X`0V]U;&0@
M;F]T(%,O34E-12!S:6=N(&UE<W-A9V4N`$-O=6QD(&YO="!A9&0@8V]N=&%C
M="X@)7,`0V]U;&0@;F]T(&)I;F0@=&\@3$1!4"!S97)V97(N`$-O=6QD(&YO
M="!C:&5C:R!B86QA;F-E+B`E<P!#;W5L9"!N;W0@8W)E871E(&1I<W1R:6)U
M=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5C<GEP="!3+TU)344@9&%T82X`
M0V]U;&0@;F]T(&1E;&5T92!C;VYT86-T+B`E<P!#;W5L9"!N;W0@9&5L971E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<P!#;W5L9"!N;W0@9&5T97)M:6YE('1H
M92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RX`0V]U;&0@;F]T(&9E=&-H
M(&-O;7!L971E(&%D9')E<W,@8F]O:RX`0V]U;&0@;F]T(&9E=&-H(&-O;7!L
M971E(&1I<W1R:6)U=&EO;B!L:7-T+@!#;W5L9"!N;W0@9F5T8V@@=&AE(&-O
M;7!L971E(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S+@!#;W5L9"!N;W0@
M;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R=F5R+@!#;W5L9"!N
M;W0@;W!E;B`E<RX`0V]U;&0@;F]T(&]P96X@36%I;G1E;F%N8V5?5&%S:R!M
M;V1U;&4@)7,`0V]U;&0@;F]T(')E860@)7,N`$-O=6QD(&YO="!R97-E="!T
M:&4@<&%S<W=O<F0@9F]R('1H92!R97%U97-T960@=7-E<BX@4V]M92!O<B!A
M;&P@;V8@=&AE(&1E=&%I;',@87)E(&YO="!C;W)R96-T+B!4<GD@86=A:6X@
M;W(@8V]N=&%C="!Y;W5R(&%D;6EN:7-T<F%T;W(@:68@>6]U(&YE960@9G5R
M=&AE<B!H96QP+@!#;W5L9"!N;W0@<F5T<FEE=F4@04-,`$-O=6QD(&YO="!R
M971R:65V92!A9&1R97-S(&)O;VLN("5S`$-O=6QD(&YO="!R971R:65V92!D
M:7-T<FEB=71I;VX@;&ES="X@)7,`0V]U;&0@;F]T(')E=')I979E(&1I<W1R
M:6)U=&EO;B!L:7-T<RX@)7,`0V]U;&0@;F]T(')E=')I979E('-E<G9E<B=S
M(&-A<&%B:6QI=&EE<P!#;W5L9"!N;W0@<F5V97)T(&-O;F9I9W5R871I;VXN
M`$-O=6QD(&YO="!S879E("5S(&-O;F9I9W5R871I;VXN`$-O=6QD(&YO="!S
M879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BX`0V]U;&0@;F]T('-A=F4@82!B
M86-K=7`@8V]N9FEG=6%T:6]N.B`E<P!#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RX`0V]U;&0@;F]T('-A=F4@=&AE
M(&-O;F9I9W5R871I;VX@9FEL92`E<RX@66]U(&-A;B!E:71H97(@=7-E(&]N
M92!O9B!T:&4@;W!T:6]N<R!T;R!S879E('1H92!C;V1E(&)A8VL@;VX@)7,@
M;W(@8V]P>2!M86YU86QL>2!T:&4@8V]D92!B96QO=R!T;R`E<RX`0V]U;&0@
M;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N`$-O=6QD(&YO="!U<&1A=&4@
M8V]N=&%C="X@)7,`0V]U;&0@;F]T('5P9&%T92!D:7-T<FEB=71I;VX@;&ES
M="X@)7,`0V]U;&1N)W0@9FEN9"!T:&4@36]Z:6QL82!3:61E8F%R+B!-86ME
M('-U<F4@=&AE('-I9&5B87(@:7,@;W!E;BX`0V]U;G1E9"!T97AT`$-O=6YT
M<GD`0V]U<G-E<P!#<F5A=&4`0W)E871E(&$@;&EN:P!#<F5A=&4@82!N97<@
M;VYE`$-R96%T92!S=6(@9F]L9&5R<P!#<F5A=&]R(%!E<FUI<W-I;VYS`$-R
M961I="!C87)D(&YU;6)E<@!#<F]A=&EA`$-U8F$`0W5R<F5N="`T(%!H87-E
M<P!#=7)R96YT(%1I;64`0W5R<F5N="!54DP@:7,`0W5R<F5N="!796%T:&5R
M`$-U<G)E;G0@8V]N9&ET:6]N.B``0W5R<F5N="!S='EL90!#=7-T;VUI>F4@
M=&%S:W,@=&\@<G5N('5P;VX@;&]G;VX@=&\@)7,N`$-U=`!#=70@<V5L96-T
M:6]N`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI8R`H5VEN9&]W
M<RTQ,C4Q*0!#>7)I;&QI8R]5:W)A:6YI86X@*$M/23@M52D`0WIE8V@@4F5P
M=6)L:6,`1$0`1&%I;'D`1&%T851R964@0G)O=W-E<@!$871E`$1A=&4@4F5C
M96EV960`1&%T92!S96QE8W1I;VX`1&%Y`$1E7VQE=&4@0V]L=6UN`$1E8V5M
M8F5R`$1E8VEM86P@;G5M8F5R<P!$96-R96%S92!);F1E;G0`1&5F875L=`!$
M969A=6QT($-O;&]R`$1E9F%U;'0@261E;G1I='D`1&5F:6YI=&EO;G,`1&5L
M971E`$1E;&5T92!'<F]U<`!$96QE=&4@4&5R;6ES<VEO;@!$96QE=&4@86YD
M('!U<F=E(&UE<W-A9V5S`$1E;&5T92!C96QL`$1E;&5T92!C;VQU;6X`1&5L
M971E(&5X:7-T:6YG(&%L=&5R;F%T92!T96UP;&%T90!$96QE=&4@<F]W`$1E
M;&5T92!S96QE8W1E9"!I9&5N=&ET>0!$96QE=&4@=&AE(&-U<G)E;G0@8V]L
M=6UN`$1E;&5T92!T:&4@8W5R<F5N="!R;W<`1&5L:79E<GD@=&EM90!$96YM
M87)K`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E<V-R:7!T:6]N`$1E=&%I;',@
M*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3H`1&5T86EL<R!H879E(&)E96X@
M;&]G9V5D(&9O<B!T:&4@861M:6YI<W1R871O<BX`1&5V96QO<&UE;G0`1&5W
M(%!O:6YT`$1E=R!0;VEN="!F;W(@;&%S="!H;W5R.B``1&5W('!O:6YT.B``
M1&ER96-T:6]N(&QE9G0@=&\@<FEG:'0`1&ER96-T:6]N(')I9VAT('1O(&QE
M9G0`1&ER96-T;W)Y`$1I<W!L87D@,C0M:&]U<B!T:6UE<S\`1&ES<&QA>2!/
M<'1I;VYS`$1I<W!L87D@9F]R96-A<W0@*%1!1BD`1&ES<&QA>2!F;W)M870`
M1&ES<&]S:71I;VX@3F]T:69I8V%T:6]N`$1J:6)O=71I`$1O(&YO="!D96QE
M=&4`1&\@;F]T(&1I<F5C=&QY(&%C8V5S<R!M86EN=&5N86YC92YP:'``1&]E
M<R!T:&4@9FER<W0@<F]W(&-O;G1A:6X@=&AE(&9I96QD(&YA;65S/R!)9B!Y
M97,L(&-H96-K('1H:7,@8F]X.@!$;VUI;FEC80!$;VUI;FEC86X@4F5P=6)L
M:6,`1&]W;FQO860`1&]W;FQO860@)7,`1&]W;FQO860@9V5N97)A=&5D(&-O
M;F9I9W5R871I;VX@87,@4$A0('-C<FEP="X`1')O<"!D;W=N(&QI<W0`1')U
M9W,`12U-86EL`$524@!%8W5A9&]R`$5D:70`161I="!";&]C:P!%9&ET($=R
M;W5P`$5D:70@4&5R;6ES<VEO;@!%9&ET(%!E<FUI<W-I;VYS`$5D:70@4&5R
M;6ES<VEO;G,@9F]R("5S`$5D:70@;W!T:6]N<R!F;W(Z`$5D:70@<&5R;6ES
M<VEO;G,@9F]R("5S`$5D=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;&5M
M96YT+BXN`$5M`$5M86EL`$5M86EL($%D9')E<W,`16UA:6P@861D<F5S<V5S
M(&UU<W0@;6%T8V@N`$5M86EL('=I=&@@8V]N9FER;6%T:6]N`$5M;W1I8V]N
M<P!%;7!T>2!M97-S86=E+@!%;7!T>2!R97-U;'0N`$5M<'1Y('-E87)C:"!T
M97)M<P!%;F%B;&4@:6YS97)T:6]N(&]F(&EM86=E<R!F<F]M(%!H;W1O($=A
M;&QE<FEE<R!I;B!T97AT/P!%;F%B;&4@<FEG:'0@8VQI8VL@8V]N=&5X="!M
M96YU/P!%;F0@>65A<@!%;FQA<F=E($5D:71O<@!%;G1E<B!A('-E8W5R:71Y
M('%U97-T:6]N('=H:6-H('EO=2!W:6QL(&)E(&%S:V5D(&EF('EO=2!N965D
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0L(&4N9RX@)W=H870@:7,@=&AE(&YA
M;64@;V8@>6]U<B!P970_)SH`16YT97(@=&AE(&EM86=E(%523"!H97)E`$5Q
M=6%T;W)I86P@1W5I;F5A`$5R:71R96$`17)R;W(`17)R;W(@=VET:"!E;6%I
M;"!M97-S86=E+@!%<W1O;FEA`$5T:&EO<&EA`$5T:&YI8P!%=7)O<&4`179E
M<GD@,34@;6EN=71E<P!%=F5R>2`R(&UI;G5T97,`179E<GD@,S`@<V5C;VYD
M<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G:6X`179E<GD@:&%L9B!H;W5R
M`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E<SH`17AE8W5T90!%>'!A;F0`
M17AP86YD(%-I9&5B87(`17AP96-T960@)RDG`$5X<&5C=&5D(&)A<F4@=V]R
M9"!O<B!Q=6]T960@<V5A<F-H('1E<FT`17AP:7)A=&EO;B!$871E`$5X<&]N
M96YT`$9'($-O;&]R`$944"!U<&QO860@;V8@<V5T=7``1F%I;&5D(')E=')I
M979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C;VYN96-T('1O($Q$05`@
M<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R+@!&86EL
M960@=&\@8V]P>2!F<F]M("(E<R(N`$9A:6QE9"!T;R!C;W!Y('1O("(E<R(N
M`$9A:6QE9"!T;R!C<F5A=&4@;F5W(%-!4TP@8V]N;F5C=&EO;BX`1F%I;&5D
M('1O(&UO=F4@=&\@(B5S(BX`1F%I;&5D('1O(')E=')I979E.B`E<P!&86ER
M`$9A;&ML86YD($ES;&%N9',@*$UA;'9I;F%S*0!&87)O92!)<VQA;F1S`$9A
M=&%L($5R<F]R.@!&87@`1F5B<G5A<GD`1F5E;',@3&EK90!&965L<R!L:6ME
M.B``1F5W(%-H;W=E<G,`1F5W(%-N;W<@4VAO=V5R<P!&:65L9"!M871R:7@`
M1FEJ:0!&:6QE($-O=6YT.B`E<R!F:6QE`$9I;&4@0V]U;G0Z("5S(&9I;&5S
M`$9I;&4@36%N86=E<@!&:6QE($YA;64`1FEL92!S96QE8W1I;VX`1FEL92!U
M<&QO860`1FEL92!U<&QO861S(&YO="!S=7!P;W)T960N`$9I;'1E<G,`1FEN
M;&%N9`!&:7)S="!(86QF`$9I<G-T(%%U87)T97(`1FEX(')A=&EO`$9L:7``
M1FQO870`1F]G`$9O;&1E<B`E<R!D;V5S(&YO="!E>&ES=`!&;VYT($-O;&]R
M`$9O;V0`1F]R(&)R;W=S97)S('1H870@9&]N)W0@<W5P<&]R="!I;6%G97,`
M1F]R96-A<W0@*%1!1BD`1F]R96-A<W0@1&%Y<R`H;F]T92!T:&%T('1H92!R
M971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y(&%N9"!N:6=H=#L@
M82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@:6X@82!W:61E(&)L
M;V-K*0!&;W)G;W0@>6]U<B!P87-S=V]R9#\`1F]R;7,`1F]R='5N90!&;W)T
M=6YE('1Y<&4`1F]R='5N97,`1F]R='5N97,@,@!&;W)U;7,`1F]R=V%R9',`
M1G(`1G)A;65S`$9R86YC90!&<F%N8V4L($UE=')O<&]L:71A;@!&<F5N8V@@
M1W5I86YA`$9R96YC:"!0;VQY;F5S:6$`1G)E;F-H(%-O=71H97)N(%1E<G)I
M=&]R:65S`$9R;VT`1G)O;2!T:&4@`$9U;&P@1&5S8W)I<'1I;VX`1G5L;"!-
M;V]N`$9U;&P@3F%M90!'86)O;@!'86QL97)Y('1O('1A:V4@:6UA9V4@9G)O
M;0!'86QL97)Y.@!'86UB:6$`1V5N97)A=&4@)7,@0V]N9FEG=7)A=&EO;@!'
M96YE<F%T960@0V]D90!'96]R9VEA`$=E<FUA;GD`1VAA;F$`1VEB<F%L=&%R
M`$=I=F5N($YA;64`1V\`1V]E9&5L`$=O;V=L92!396%R8V@`1W)A>7-C86QE
M`$=R965C90!'<F5E:R`H25-/+3@X-3DM-RD`1W)E96YL86YD`$=R96YA9&$`
M1W)O=7`@061M:6YI<W1R871I;VX`1W)O=7`@;F%M97,@;75S="!B92!N;VXM
M96UP='D`1W)O=7!S`$=U861E;&]U<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS
M97D`1W5E<W0@4&5R;6ES<VEO;G,`1W5E<W1B;V]K`$=U:6YE80!'=6EN96$M
M0FES<V%U`$=U>6%N80!(5$U,`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@
M=&\@9&5L971E('1H92!L87-T(&-E;&P@:6X@<F]W+@!(5$U,07)E82!C;W=A
M<F1L>2!R969U<V5S('1O(&1E;&5T92!T:&4@;&%S="!C;VQU;6X@:6X@=&%B
M;&4N`$A434Q!<F5A(&-O=V%R9&QY(')E9G5S97,@=&\@9&5L971E('1H92!L
M87-T(')O=R!I;B!T86)L92X`2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U
M;F0N`$AA:71I`$AA<V@M06QG;W)I=&AM`$AA>F4`2&5A9&5R`$AE87)D($ES
M;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<P!(96)R97<@*$E33RTX.#4Y+3@M
M22D`2&5I9VAT`$AE;'``2&5L<"!U<VEN9R!E9&ET;W(`2&5L<&5R`$AE;6ES
M<&AE<F4`2&5R92!I<R!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE.@!(:6=H
M`$AO7VUE`$AO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I`$AO;64`2&]M
M92!!9&1R97-S`$AO;64@4&AO;F4`2&]N9'5R87,`2&]N9R!+;VYG`$AO<F1E
M`$AO<F1E+TMO;&%B.B!);G9A;&ED("5S(%A-3"!D871A(&5N8V]U;G1E<F5D
M(&EN(&UE<W-A9V4@)7,`2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S
M<&]N9',@=&\@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!.;R!O8FIE8W0@;V8@
M='EP92`E<R!F;W5N9"!I;B!M97-S86=E("5S`$AO<F1E+TMO;&%B.B!3=6-C
M97-S9G5L;'D@<F5M;W9E9"`E<R`B)7,B`$AO<F1E+TMO;&%B.B!4:&4@:6YT
M96=R871I;VX@96YG:6YE(')E<75I<F5S('1H92`G9&]M>&UL)R!02%`@97AT
M96YS:6]N`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@8W)E871E(&YE=R!834P@
M=')E92!F;W(@;V)J96-T("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5M
M;W9E("5S("(E<R(Z("5S`$AO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE
M=F4@34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<P!(;W)D92]+;VQA
M8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S("(E<R(Z("5S`$AO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<P!(;W)D92]+
M;VQA8CH@56YK;F]W;B!S:&%R92`B)7,B`$AO<FEZ;VYT86P@4G5L90!(;W)I
M>F]N=&%L('!A9&1I;F<`2&]R:7IO;G1A;#H`2&]W(&1I9"!Y;W4@9V5T(&AE
M<F4_("A0;&5A<V4@<F5P;W)T(2D`2&]W(&UA;GD@8V]L=6UN<R!W;W5L9"!Y
M;W4@;&EK92!T;R!M97)G93\`2&]W(&UA;GD@9FEE;&1S("AC;VQU;6YS*2!A
M<F4@=&AE<F4_`$AO=R!M86YY(')O=W,@=V]U;&0@>6]U(&QI:V4@=&\@;65R
M9V4_`$AU;6ED:71Y`$AU;6ED:71Y.B``2'5M;W)I<W1S`$AU;F=A<GD`24U!
M4"!M86EL8F]X(&-R96%T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X(&1E
M;&5T:6]N(&9A:6QE9#H@)7,`24U!4"!M86EL8F]X('%U;W1A(&-R96%T:6]N
M(&9A:6QE9#H@)7,`25`@061D<F5S<P!)4"!!9&1R97-S(&YO="!A=F%I;&%B
M;&4N`$E0($%D9')E<W,@;F]T('=I=&AI;B!A;&QO=V5D($-)1%(@8FQO8VLN
M`$E0(&QO8VMD;W=N('9I;VQA=&EO;BX`25]N<V5R="!2;W<@0F5F;W)E`$EC
M96QA;F0`26-O;G,@3VYL>0!)8V]N<R!F;W(@)7,`26-O;G,@=VET:"!T97AT
M`$ED96YT:71Y)W,@;F%M93H`268@:70@:7,@;F]T(&1I<W!L87EE9"!C;W)R
M96-T;'DL("5S('1O(&]P96X@:70@:6X@82!N97<@=VEN9&]W+@!)9B!Y;W4@
M9&]N)W0@<V5E(&%N>2!I8V]N<R!U<VEN9R!);G1E<FYE="!%>'!L;W)E<BP@
M>6]U(&UA>2!N965D('1O(&-H96-K('1H:7,@8F]X('1O('1U<FX@;V9F(%!.
M1R!T<F%N<W!A<F5N8WDN`$EF('EO=2!S964@=&AI<R!M97-S86=E(&)U="!N
M;R!I;6%G92P@=&AE(&EM86=E('EO=2!W86YT('1O('5P;&]A9"!C86XG="!B
M92!D:7-P;&%Y960@8GD@>6]U<B!B<F]W<V5R+@!);6%G92!0<F5V:65W.@!)
M;6%G92!54DP`26UA9V4@55),.@!);6%G92!F<F]M(&=A;&QE<GD`26UA9V4@
M9G)O;2!G86QL97)Y.@!);6%G92!U<&QO860`26UA9V5S`$EM<&]R="P@4W1E
M<"`E9`!);7!O<G1E9"!F:65L9#H@)7,`26UP;W)T960@9FEE;&1S.@!);E]S
M97)T(%)O=R!!9G1E<@!);F-O<G)E8W0@86-T:6]N(&-O9&4@9VEV96XN`$EN
M8V]R<F5C="!U<V5R;F%M92!A;F0O;W(@<&%S<W=O<F0N`$EN8V]R<F5C="!U
M<V5R;F%M92!O<B!A;'1E<FYA=&4@861D<F5S<RX@5')Y(&%G86EN(&]R(&-O
M;G1A8W0@>6]U<B!A9&UI;FES=')A=&]R(&EF('EO=2!N965D(&9U<G1H97(@
M:&5L<"X`26YC<F5A<V4@26YD96YT`$EN9&EA`$EN9&EV:61U86P@57-E<G,`
M26YD;VYE<VEA`$EN9F\`26YF;W)M871I;VX`26YI=&EA;&EZ:6YG(&UO9'5L
M92`E<RXN+B``26YS97)T($-?;VQU;6X@069T97(`26YS97)T($EM86=E`$EN
M<V5R="!486)L90!);G-E<G0@5V5B($QI;FL`26YS97)T(%]#;VQU;6X@0F5F
M;W)E`$EN<V5R="!A(&YE=R!C;VQU;6X@869T97(@=&AE(&-U<G)E;G0@;VYE
M`$EN<V5R="!A(&YE=R!C;VQU;6X@8F5F;W)E('1H92!C=7)R96YT(&]N90!)
M;G-E<G0@82!N97<@<F]W(&%F=&5R('1H92!C=7)R96YT(&]N90!);G-E<G0@
M82!N97<@<F]W(&)E9F]R92!T:&4@8W5R<F5N="!O;F4`26YS97)T(&$@<&%R
M86=R87!H(&%F=&5R('1H92!C=7)R96YT(&YO9&4`26YS97)T(&$@<&%R86=R
M87!H(&)E9F]R92!T:&4@8W5R<F5N="!N;V1E`$EN<V5R="!A;'1E<FYA=&4@
M=&5M<&QA=&4`26YS97)T(&%N(&5M86EL(&%D9')E<W,@=&\@=VAI8V@@>6]U
M(&-A;B!R96-E:79E('1H92!N97<@<&%S<W=O<F0Z`$EN<V5R="!C96QL(&%F
M=&5R`$EN<V5R="!C96QL(&)E9F]R90!);G-E<G0@8V]L=6UN(&%F=&5R`$EN
M<V5R="!C;VQU;6X@8F5F;W)E`$EN<V5R="!M97-S86=E<P!);G-E<G0@<&%R
M86=R87!H(&%F=&5R`$EN<V5R="!P87)A9W)A<&@@8F5F;W)E`$EN<V5R="!R
M;W<@869T97(`26YS97)T(')O=R!B969O<F4`26YS97)T('1H92!R97%U:7)E
M9"!A;G-W97(@=&\@=&AE('-E8W5R:71Y('%U97-T:6]N.@!);G-E<G0O36]D
M:69Y($EM86=E`$EN<V5R="]-;V1I9GD@3&EN:P!);G-U9F9I8VEE;G0@8W)E
M9&ET('1O('-E;F0@=&\@=&AE(&1I<W1R:6)U=&EO;B!L:7-T+@!);G-U9F9I
M8VEE;G0@8W)E9&ET+@!);G1E9V5R`$EN=&5G97(@;&ES=`!);G9A;&ED(%5$
M2"X@*%5S97(@1&%T82!(96%D97(I+@!);G9A;&ED(&%P<&QI8V%T:6]N+@!)
M;G9A;&ED(&)A=&-H($E$+@!);G9A;&ED(&1A=&$@<W5B;6ET=&5D+@!);G9A
M;&ED(&1E<W1I;F%T:6]N(&%D9')E<W,N`$EN=F%L:60@9FEL92!F;W)M870`
M26YV86QI9"!L:6-E;G-E(&ME>2X`26YV86QI9"!L;V-A=&EO;B!P<F]V:61E
M9"X`26YV86QI9"!M<V=?='EP92X`26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"X`26YV86QI9"!O<B!M:7-S:6YG('!A<F%M971E<G,N`$EN=F%L:60@<&%R
M96YT('!E<FUI<W-I;VXN`$EN=F%L:60@<&%R=&YE<B!I9"X`26YV86QI9"!P
M<F]D=6-T(&-O9&4N`$EN=F%L:60@<')O=&]C;VPN`$EN=F%L:60@<VAA<F4@
M;V)J96-T`$EN=F%L:60@<V]U<F-E(&%D9')E<W,N`$EN=F%L:60@=6YI8V]D
M92!D871A+@!);G9E;G1O<GD`27)A;BP@27-L86UI8R!297!U8FQI8R!O9@!)
M<F%Q`$ER96QA;F0`27-L92!O9B!-86X`27-O;&%T960@5"U3=&]R;7,`27-R
M865L`$ES<W5E<@!)=&%L:6,`271A;'D`2F%M86EC80!*86YU87)Y`$IA<&%N
M`$IA<&%N97-E("A)4T\M,C`R,BU*4"D`2F5R<V5Y`$IO<F1A;@!*=6QY`$IU
M;F4`2G5S=&EF>0!*=7-T:69Y($-E;G1E<@!*=7-T:69Y($9U;&P`2G5S=&EF
M>2!,969T`$IU<W1I9GD@4FEG:'0`2V%Z86MH<W1A;@!+965P(&]R:6=I;F%L
M/P!+96YY80!+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN`$ME<FYE;"!.97=B:65S`$ME>2!#<F5A=&EO;@!+97D@1FEN9V5R<')I
M;G0`2V5Y($QE;F=T:`!+97D@5'EP90!+97D@57-A9V4`2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+@!+:61S`$MI<FEB871I
M`$MO<F5A+"!$96UO8W)A=&EC(%!E;W!L92=S(%)E<'5B;&EC(&]F`$MO<F5A
M+"!297!U8FQI8R!O9@!+;W)E86X@*$550RU+4BD`2W5W86ET`$MY<F=Y>G-T
M86X`3&%?>6]U=`!,86YG=6%G90!,86\@4&5O<&QE)W,@1&5M;V-R871I8R!2
M97!U8FQI8P!,87-T($AA;&8`3&%S="!1=6%R=&5R`$QA<W0@57!D871E9#H`
M3&%S="!L;V=I;CH@)7,`3&%S="!L;V=I;CH@)7,@9G)O;2`E<P!,87-T(&QO
M9VEN.B!.979E<@!,871V:6$`3&%W`$QA>6]U=`!,96%V92!E;7!T>2!F;W(@
M;F\@8F]R9&5R`$QE8F%N;VX`3&5F=`!,969T(&AE861E<@!,969T('9A;'5E
M<P!,97-O=&AO`$QI8F5R:6$`3&EB>6%N($%R86(@2F%M86AI<FEY80!,:65C
M:'1E;G-T96EN`$QI9VAT($1R:7IZ;&4`3&EG:'0@4F%I;@!,:6=H="!286EN
M($5A<FQY`$QI9VAT(%)A:6X@3&%T90!,:6=H="!286EN(%-H;W=E<@!,:6=H
M="!286EN('=I=&@@5&AU;F1E<@!,:6=H="!3;F]W`$QI9VAT(%-N;W<@4VAO
M=V5R`$QI;65R:6-K`$QI;FL`3&EN:R!P;VEN=',@=&\Z`$QI;FL@=&AE(&5M
M86EL(&%D9')E<W,@=&\@=&AE(&-O;7!O<V4@<&%G92!W:&5N(&1I<W!L87EI
M;F<`3&EN:W,`3&EN=7@@0V]O:VEE`$QI<W0@+2!U<V5R(&-A;B!S964@=&AE
M(&9O;&1E<@!,:7-T($1A=&%B87-E<P!,:7-T($AE;'`@5&]P:6-S`$QI<W0@
M5&%B;&5S`$QI<W0M07)C:&EV90!,:7-T+4AE;'``3&ES="U)9`!,:7-T+4]W
M;F5R`$QI<W0M4&]S=`!,:7-T+5-U8G-C<FEB90!,:7-T+55N<W5B<V-R:6)E
M`$QI<W1I;F<@=7-E<G,@:7,@9&ES86)L960N`$QI=&5R871U<F4`3&ET:'5A
M;FEA`$QO861I;F<N+BX`3&]C86P@=&EM93H@`$QO8V%L92!A;F0@5&EM90!,
M;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;B!487-K<P!,;V=I;B!F86EL
M960@8F5C875S92!Y;W5R('5S97)N86UE(&]R('!A<W-W;W)D('=A<R!E;G1E
M<F5D(&EN8V]R<F5C=&QY+@!,;V=I;B!F86EL960N`$QO;F<@=&5X=`!,;W9E
M`$QO=P!,;W=E<B!G<F5E:R!L971T97)S`$QO=V5R(&QA=&EN(&QE='1E<G,`
M3&]W97(@<F]M86X@;G5M8F5R<P!,=7AE;6)O=7)G`$U-`$U/5$0`35,M5$Y%
M1B!!='1A8VAM96YT(&-O;G1A:6YE9"!N;R!D871A+@!-4T<`36%C86\`36%C
M961O;FEA+"!4:&4@1F]R;65R(%EU9V]S;&%V(%)E<'5B;&EC(&]F`$UA9&%G
M87-C87(`36%G:6,`36%I;`!-86EL($%D;6EN`$UA:V4@;&EN7VLN+BX`36%L
M87=I`$UA;&%Y<VEA`$UA;&1I=F5S`$UA;&D`36%L=&$`36%N86=E('1H92!L
M:7-T(&]F(&-A=&5G;W)I97,@>6]U(&AA=F4@=&\@;&%B96P@:71E;7,@=VET
M:"P@86YD(&-O;&]R<R!A<W-O8VEA=&5D('=I=&@@=&AO<V4@8V%T96=O<FEE
M<RX`36%P,C0@;6%P`$UA<%%U97-T(&UA<`!-87)C:`!-87)G:6X`36%R:R!W
M:71H(%-E96XO56YS965N(&9L86=S`$UA<FL@=VET:"!O=&AE<B!F;&%G<R`H
M92YG+B!);7!O<G1A;G0O06YS=V5R960I`$UA<G-H86QL($ES;&%N9',`36%R
M=&EN:7%U90!-871C:&EN9R!F:65L9',`36%U<FET86YI80!-875R:71I=7,`
M36%X(&%L;&]W960@8W)E9&ET+@!-87@@;65S<V%G92!P87)T<R!E>&-E961E
M9"X`36%X('1E;7`@;&%S="`R-"!H;W5R<SH@`$UA>"!T96UP(&QA<W0@-B!H
M;W5R<SH@`$UA>&EM=6T@;&5N9W1H`$UA>0!-87EO='1E`$UE9&EC:6YE`$UE
M;6)E<G,`365N=2!M;V1E.@!-97)G92!C96QL<P!-97-S86=E`$UE<W-A9V4@
M5F5R:69I960@4W5C8V5S<V9U;&QY(&)U="!T:&4@<VEG;F5R)W,@8V5R=&EF
M:6-A=&4@8V]U;&0@;F]T(&)E('9E<FEF:65D+@!-97-S86=E(&5X<&ER960N
M`$UE<W-A9V4@='EP90!-971A<B!796%T:&5R`$UE=&%R(&)L;V-K(&YO="!A
M=F%I;&%B;&4N`$UE=&%R(&)L;V-K(&YO="!A=F%I;&%B;&4N($1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$UE=&%R
M1$(@:7,@;F]T(&-O;FYE8W1E9"X`365T:&]D`$UE=')I8P!-97AI8V\`36EC
M<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9@!-:61D;&4`36EM92!4>7!E
M`$UI;B!T96UP(&QA<W0@,C0@:&]U<G,Z(`!-:6X@=&5M<"!L87-T(#8@:&]U
M<G,Z(`!-:7)R;W(`36ES8V5L;&%N96]U<P!-:7-S:6YG(%!%05(@<&%C:V%G
M92!(5%107U)E<75E<W0N`$UI<W-I;F<@8V]N9FEG=7)A=&EO;BX@66]U(&AA
M=F4@=&\@9V5N97)A=&4@:70@;F]W(&EF('EO=2!W86YT('1O('5S92!T:&ES
M(&%P<&QI8V%T:6]N+@!-:7-S:6YG(&UE<W-A9V4@240N`$UI<W-I;F<@<F5Q
M=6ER960@4$5!4B!P86-K86=E($UA:6PN`$UI<W-I;F<@<V5S<VEO;B!)1"X`
M36\`36]B:6QE($UA:6P`36]D97)A=&4`36]D:69I960@1&%T90!-;V1I9GD@
M55),`$UO9'5L=7,`36]L9&]V82P@4F5P=6)L:6,@;V8`36]N86-O`$UO;F=O
M;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H;'D`36]N='-E<G)A=`!-;V]N(%!H
M87-E<P!-;W)O8V-O`$UO<W1L>2!#;&5A<@!-;W-T;'D@0VQO=61Y`$UO<W1L
M>2!3=6YN>0!-;W9E($1O=VX`36]V92!,969T`$UO=F4@4FEG:'0`36]V92!5
M<`!-;W9E(&1O=VX`36]V92!U<`!-;WIA;6)I<75E`$UU;'1I+6QE=F5L(&1R
M;W`@9&]W;B!L:7-T<P!-=6QT:7!L92!S96QE8W1I;VX`37D@06-C;W5N=`!-
M>2!0;W)T86P`37D@4&]R=&%L($QA>6]U=`!->6%N;6%R`$Y/+"!)($1O($Y/
M5"!!9W)E90!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`
M3F5T:&5R;&%N9',@06YT:6QL97,`3F5T<V-A<&4@0F%S92!54DP`3F5T<V-A
M<&4@0T$@4F5V;V-A=&EO;B!54DP`3F5T<V-A<&4@0T$@<&]L:6-Y(%523`!.
M971S8V%P92!296YE=V%L(%523`!.971S8V%P92!2979O8V%T:6]N(%523`!.
M971S8V%P92!34TP@<V5R=F5R(&YA;64`3F5T<V-A<&4@8V5R=&EF:6-A=&4@
M8V]M;65N=`!.971S8V%P92!C97)T:69I8V%T92!T>7!E`$YE='=O<FL`3F5V
M97(`3F5W($-A;&5D;VYI80!.97<@0V%T96=O<GD`3F5W($UO;VX`3F5W(%5S
M97)N86UE("AO<'1I;VYA;"D`3F5W(%IE86QA;F0`3F5W('=I;F1O=R`H7V)L
M86YK*0!.97=S`$YE=W-G<F]U<',`3F5X=`!.97AT(#0@4&AA<V5S`$YE>'0@
M;W!T:6]N<P!.97AT/@!.:6-A<F%G=6$`3FEG97(`3FEG97)I80!.:6=H=`!.
M:75E`$YO`$YO(&%V86EL86)L92!C;VYF:6=U<F%T:6]N(&1A=&$@=&\@<VAO
M=R!D:69F97)E;F-E<R!F;W(N`$YO(&%V86EL86)L92!S=')A=&5G>2!F;W(@
M;6%K:6YG($E33R!I;6%G97,N`$YO(&)A=&-H('1E;7!L871E+@!.;R!B;&]C
M:R!E>&ES=',@870@=&AE(')E<75E<W1E9"!P;W-I=&EO;@!.;R!C86QE;F1A
M<B!N86UE('!R;W9I9&5D(&9O<B!-0T%,(&%U=&AE;G1I8V%T:6]N+@!.;R!C
M:&%N9V4N`$YO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D
M(&9O<B`E<RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R($944"!61E,N`$YO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@
M<W!E8VEF:65D(&9O<B!344P@5D93+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R
M;6%T:6]N('-P96-I9FEE9"!F;W(@4U%,+49I;&4@5D93+@!.;R!C<F5D:70@
M;&5F="X`3F\@9&5S=&EN871I;VX@<W5P<&QI960N`$YO(&9I;&4@=7!L;V%D
M960`3F\@:6-O;G,@9F]U;F0N`$YO(&QO8V%T:6]N(&ES('-E="X`3F\@;&]C
M871I;VX@<')O=FED960N`$YO(&UE<W-A9V4@<W5P<&QI960N`$YO(&YA;64@
M<W!E8VEF:65D+@!.;R!N=6UB97(@<W!E8VEF:65D+@!.;R!O9F9E;G-I=F4@
M9F]R='5N97,`3F\@<&%S<W=O<F0@<')O=FED960@9F]R($A45%`@875T:&5N
M=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U=&AE
M;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2V5R8F5R;W,@
M875T:&5N=&EC871I;VXN`$YO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!,;V=I
M;B!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%!!
M4U-71"!A=71H96YT:6-A=&EO;BX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M(%--0B!A=71H96YT:6-A=&EO;BX`3F\@<&%T:"!T;R!T:&4@3W!E;E-33"!B
M:6YA<GD@<')O=FED960N(%1H92!/<&5N4U-,(&)I;F%R>2!I<R!N96-E<W-A
M<GD@=&\@=V]R:R!W:71H(%!+0U,@,3(@9&%T82X`3F\@<&5N9&EN9R!S:6=N
M=7!S+@!.;R!Q=6]T82!S970N`$YO(')U;&5S`$YO('-I9&5S`$YO('-U8V@@
M9FEL90!.;R!T96UP;W)A<GD@9&ER96-T;W)Y(&%V86EL86)L92!F;W(@8V%C
M:&4N`$YO('5S97)N86UE(&%N9"]O<B!P87-S=V]R9"!S96YT+@!.;R!V86QI
M9"!834P@9&%T82!R971U<FYE9`!.;R!V86QU97,`3F\@=F5R<VEO;B!F;W5N
M9"!I;B!O<FEG:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I
M9W5R871I;VXN`$YO('9E<G-I;VX@9F]U;F0@:6X@>6]U<B!C;VYF:6=U<F%T
M:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN`$YO;F4`3F]N92`H=7-E
M(&EM<&QI8VET*0!.;W)D:6,@*$E33RTX.#4Y+3$P*0!.;W)F;VQK($ES;&%N
M9`!.;W)T:&5R;B!(96UI<W!H97)E`$YO<G1H97)N($UA<FEA;F$@27-L86YD
M<P!.;W)W87D`3F]T($%F=&5R`$YO="!"969O<F4`3F]T(&$@9&ER96-T;W)Y
M`$YO="!I;7!L96UE;G1E9"X`3F]T('-E=`!.;W0@<W5P<&]R=&5D+@!.;W1E
M<P!.;W1H:6YG('1O(&)R;W=S92P@9V\@8F%C:RX`3F]V96UB97(`3G5M8F5R
M`$YU;6)E<B!O9B!C:&%R86-T97)S`$YU;6)E<B!O9B!C;VQU;6YS`$YU;6)E
M<B!O9B!R;W=S`$YU;6)E<G,@;F]T('-P96-I9FEE9"!F;W(@=7!D871I;F<@
M:6X@9&ES=')I8G5T:6]N(&QI<W0N`$]+`$]B:F5C=`!/8FIE8W0@0W)E871O
M<@!/8W1A;`!/8W1O8F5R`$]F9F5N<V4@9FEL=&5R`$]F9FEC90!/;6%N`$]N
M;'D@24U!4"!S97)V97)S('-U<'!O<G0@<VAA<F5D(&9O;&1E<G,N`$]N;'D@
M;V9F96YS:79E(&9O<G1U;F5S`$]N;'D@;VYE(&5M86EL(&%D9')E<W,@86QL
M;W=E9"X`3VYL>2!T:&4@;W=N97(@;W(@<WES=&5M(&%D;6EN:7-T<F%T;W(@
M;6%Y(&-H86YG92!O=VYE<G-H:7`@;W(@;W=N97(@<&5R;6ES<VEO;G,@9F]R
M(&$@<VAA<F4`3W!E;B!I;B!A(&YE=R!W:6YD;W<`3W!E;E-33"!E<G)O<CH@
M0V]U;&0@;F]T(&5X=')A8W0@9&%T82!F<F]M('-I9VYE9"!3+TU)344@<&%R
M="X`3W!E;G,@=&AI<R!L:6YK(&EN(&$@;F5W('=I;F1O=P!/<&5R871I;F<@
M4WES=&5M`$]P=&EO;G,`3W!T:6]N<R!F;W(@)7,`3W)D97)E9"!,:7-T`$]R
M9V%N:7-A=&EO;@!/<F=A;FES871I;VYA;"!5;FET`$]R9V%N:7II;F<`3W)I
M9VEN86P@87!P;&EC871I;VX@=&5M<&QA=&4`3W)I9VEN86P@=&5M<&QA=&5S
M(&EN("5S.@!/=&AE<@!/=&AE<B!);F9O<FUA=&EO;@!/=VYE<B!097)M:7-S
M:6]N<P!004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92X`4$=0
M($1I9VET86P@4VEG;F%T=7)E`%!'4"!%;F-R>7!T960@1&%T80!01U`@4'5B
M;&EC($ME>0!01U`@4VEG;F5D+T5N8W)Y<'1E9"!$871A`%!(4"!#;V1E`%!(
M4"!3:&5L;`!032!,:6=H="!286EN`%!-(%-H;W=E<G,`4$T@4VYO=P!032!3
M;F]W(%-H;W=E<G,`4$T@4W5N`%!-(%0M4W1O<FUS`%!?2%`@4VAE;&P`4&%D
M9&EN9P!086MI<W1A;@!086QA=0!086QE<W1I;FEA;B!497)R:71O<GDL($]C
M8W5P:65D`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<G1L
M>2!#;&]U9'D`4&%S<W=O<F0`4&%S<W=O<F0@:6YC;W)R96-T`%!A<W-W;W)D
M(')E<75I<F5D(&9O<B!2041)55,@875T:&5N=&EC871I;VXN`%!A<W-W;W)D
M('=I=&@@8V]N9FER;6%T:6]N`%!A<W-W;W)D.@!087-S=V]R9#H@`%!A<W-W
M;W)D<R!M=7-T(&UA=&-H+@!087-T90!087-T92!F<F]M(&-L:7!B;V%R9`!0
M871H`%!E;F1I;F<@4VEG;G5P<SH`4&5O<&QE`%!E<F-E;G0`4&5R9F]R;2!-
M86EN=&5N86YC92!/<&5R871I;VYS`%!E<F9O<FT@;6%I;G1E;F%N8V4@;W!E
M<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!097)M:7-S:6]N($1E;FEE
M9`!097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;@!097)S;VYA;"!);F9O<FUA
M=&EO;@!097)U`%!E=',`4&AI;&EP<&EN97,`4&AO;F4`4&AO=&]S`%!I=&-A
M:7)N`%!I>&5L<P!0;&%T:71U9&5S`%!L96%S92!C;&EC:R!I;G1O('-O;64@
M8V5L;`!0;&5A<V4@8V]N9FER;2!T:&%T('EO=2!W86YT('1O(')E;6]V92!T
M:&ES(&5L96UE;G0Z`%!L96%S92!C;VYF:7)M('1H870@>6]U('=A;G0@=&\@
M=6YL:6YK('1H:7,@96QE;65N="X`4&QE87-E(&5N=&5R(&$@;6]N=&@@86YD
M(&$@>65A<BX`4&QE87-E(&5N=&5R(&$@;F%M92!F;W(@=&AE(&YE=R!C871E
M9V]R>3H`4&QE87-E(&5N=&5R(&$@=F%L:60@25`@861D<F5S<RX`4&QE87-E
M(&5N=&5R(&$@=F%L:60@9&%T92P@8VAE8VL@=&AE(&YU;6)E<B!O9B!D87ES
M(&EN('1H92!M;VYT:"X`4&QE87-E(&5N=&5R(&$@=F%L:60@=&EM92X`4&QE
M87-E('!R;W9I9&4@82!S=6UM87)Y(&]F('1H92!P<F]B;&5M+@!0;&5A<V4@
M<')O=FED92!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9`!0;&5A<V4@='EP
M92!T:&4@;F5W(&-A=&5G;W)Y(&YA;64Z`%!O;&%N9`!0;VQI=&EC<P!0;VQL
M<P!0;W)T=6=A;`!0;W-I=&EO;FEN9R!O9B!T:&ES(&EM86=E`%!O<VET:6]N
M:6YG(&]F('1H:7,@=&%B;&4`4&]S="!T;R!T:&ES(&9O;&1E<B`H;F]T(&5N
M9F]R8V5D(&)Y($E-05`I`%!R96-I<&ET871I;VX@9F]R(&QA<W0@)7,@:&]U
M<BAS*3H@`%!R969S7VQD87`Z(%)E<75I<F5D($Q$05`@97AT96YS:6]N(&YO
M="!F;W5N9"X`4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO;B!E>'1E
M;G-I;VX@;F]T(&9O=6YD+@!0<F5S<W5R90!0<F5S<W5R92!A="!S96$@;&5V
M96PZ(`!0<F5S<W5R93H@`%!R979I97<`4')E=FEE=R!T:&4@:6UA9V4@:6X@
M82!N97<@=VEN9&]W`%!R979I;W5S(&]P=&EO;G,`4')I;G0@9&]C=6UE;G0`
M4')I=F%T92!+97D`4')O8FQE;0!0<F]B;&5M($1E<V-R:7!T:6]N`%!R;VIE
M8W1S`%!R;VUP="!T97AT`%!U8FQI8R!+97D`4'5B;&EC($ME>2!!;&=O<FET
M:&T`4'5B;&EC($ME>2!);F9O`%!U8FQI8R]0<FEV871E(&ME>7!A:7(@;F]T
M(&=E;F5R871E9"!S=6-C97-S9G5L;'DN`%!U97)T;R!2:6-O`%%A=&%R`%%U
M97)Y`%)302!0=6)L:6,@2V5Y("@E9"!B:70I`%)A9&EO('-E;&5C=&EO;@!2
M86EN`%)A:6X@16%R;'D`4F%I;B!,871E`%)A:6X@4VAO=V5R`%)A:6X@86YD
M(%-N;W<`4F%I;B!T;R!3;F]W`%)A;F1O;2!&;W)T=6YE`%)A=&EO`%)E860`
M4F5A9"!M97-S86=E<P!296%L;'D@9&5L971E("5S/R!4:&ES(&]P97)A=&EO
M;B!C86YN;W0@8F4@=6YD;VYE+@!296%L;'D@<F5M;W9E('5S97(@9&%T82!F
M;W(@=7-E<B`E<S\@5&AI<R!O<&5R871I;VX@8V%N;F]T(&)E('5N9&]N92X`
M4F5D;V5S('EO=7(@;&%S="!A8W1I;VX`4F5F<F5S:"!$>6YA;6EC($UE;G4@
M16QE;65N=',Z`%)E9G)E<V@@4&]R=&%L(%9I97<Z`%)E9V5X`%)E;&%T:6]N
M<VAI<"!"<F]W<V5R`%)E;6%R:W,`4F5M;W1E(%-E<G9E<G,`4F5M;W1E(%52
M3"`H:'1T<#HO+W=W=RYE>&5M<&QE+F5S+VAO<F1E*3H`4F5M;W9E`%)E;6]V
M92!";&]C:P!296UO=F4@8V]L=6UN`%)E;6]V92!F;W)M871T:6YG`%)E;6]V
M92!P86ER`%)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S97)V97(G<R!T96UP
M;W)A<GD@9&ER96-T;W)Y+@!296UO=F4@=&AE`%)E;6]V92!T:&ES(&YO9&4@
M9G)O;2!T:&4@9&]C=6UE;G0`4F5M;W9E('5S97(`4F5M;W9E('5S97(Z("5S
M`%)E<75E<W0@8V]U;&1N)W0@8F4@86YS=V5R960N(%)E='5R;F5D(&5R<F]R
M8V]D93H@`%)E<75E<W1E9"!S97)V:6-E(&-O=6QD(&YO="!B92!F;W5N9"X`
M4F5Q=6ER960@1FEE;&0`4F5S970`4F5S970@4&%S<W=O<F0`4F5S970@66]U
M<B!087-S=V]R9`!297-U;'1S`%)E='5R;B!T;R!/<'1I;VYS`%)E=6YI;VX`
M4F5V97)T($-O;F9I9W5R871I;VX`4FEC:"!497AT($5D:71O<B!/<'1I;VYS
M`%)I9&1L97,`4FEG:'0`4FEG:'0@:&5A9&5R`%)I9VAT('9A;'5E<P!2;U]W
M(%!R;W!E<G1I97,N+BX`4F]L90!2;VUA;FEA`%)O=&%T92`Q.#``4F]T871E
M($QE9G0`4F]T871E(%)I9VAT`%)O=R!0<F]P97)T:65S`%)O=R!P<F]P97)T
M:65S`%)O=W,Z`%)U;&5S`%)U;&5S('=I;&P@87!P96%R(&)E='=E96X@86QL
M(')O=W,@86YD(&-O;'5M;G,`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!C
M;VQU;6YS(&]N;'D`4G5L97,@=VEL;"!A<'!E87(@8F5T=V5E;B!R;W=S(&]N
M;'D`4G5N`%)U<W-I86X@1F5D97)A=&EO;@!2=V%N9&$`4R]-24U%($-R>7!T
M;V=R87!H:6,@4VEG;F%T=7)E`%,O34E-12!%;F-R>7!T960@365S<V%G90!3
M05-,(&%U=&AE;G1I8V%T:6]N(&ES(&YO="!A=F%I;&%B;&4N`%--4R!-97-S
M86=I;F<`4U%,(%-H96QL`%-32`!354-#15-3`%-?44P@4VAE;&P`4V$`4V%I
M;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I<P!386EN="!,=6-I80!3
M86EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT(%9I;F-E;G0@86YD('1H
M92!'<F5N861I;F5S`%-A;64@9G)A;64@*%]S96QF*0!386UO80!386X@36%R
M:6YO`%-A;R!4;VUE(&%N9"!0<FEN8VEP90!3871E;&QI=&4@4')O=FED97(`
M4V%U9&D@07)A8FEA`%-A=F4`4V%V92`E<P!3879E($]P=&EO;G,`4V%V92!G
M96YE<F%T960@8V]N9FEG=7)A=&EO;B!A<R!A(%!(4"!S8W)I<'0@=&\@>6]U
M<B!S97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+@!3879E9"`E<R!C;VYF
M:6=U<F%T:6]N+@!38V%T=&5R960@5"U3=&]R;7,`4V-I96YC90!396%R8V@`
M4V5A<F-H($5N9VEN97,`4V5L96-T($9I;&5S`%-E;&5C="!A(&1A=&4`4V5L
M96-T(&$@9W)O=7`@=&\@861D`%-E;&5C="!A(&YE=R!O=VYE<@!396QE8W0@
M82!S97)V97(`4V5L96-T(&$@=7-E<B!T;R!A9&0`4V5L96-T(&%L;"!D871E
M(&-O;7!O;F5N=',N`%-E;&5C="!A;B!O8FIE8W0`4V5L96-T('1H92!C:&%R
M86-T97)S('EO=2!N965D(&9R;VT@=&AE(&)O>&5S(&)E;&]W+B!9;W4@8V%N
M('1H96X@8V]P>2!A;F0@<&%S=&4@=&AE;2!F<F]M('1H92!T97AT(&%R96$N
M`%-E;&5C="!T:&4@9&%T92!D96QI;6ET97(Z`%-E;&5C="!T:&4@9&%T92!F
M;W)M870Z`%-E;&5C="!T:&4@:61E;G1I='D@>6]U('=A;G0@=&\@8VAA;F=E
M.@!396QE8W0@=&AE('1I;64@9&5L:6UI=&5R.@!396QE8W0@=&AE('1I;64@
M9F]R;6%T.@!396QE8W0@='=O(&UA=&-H:6YG(&9I96QD<RX`4V5L96-T('EO
M=7(@8V]L;W(@<V-H96UE+@!396QE8W0@>6]U<B!P<F5F97)R960@;&%N9W5A
M9V4Z`%-E;F0@4')O8FQE;2!297!O<G0`4V5N9"!335,`4V5N96=A;`!396YS
M;W(Z(`!397!T96UB97(`4V5R8FEA(&%N9"!-;VYT96YE9W)O`%-E<FEA;"!.
M=6UB97(`4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92X`4V5S
M<VEO;B!)1"!E>'!I<F5D+@!3970`4V5T(&]P=&EO;G,@=&\@86QL;W<@>6]U
M('1O(')E<V5T('EO=7(@<&%S<W=O<F0@:68@>6]U(&5V97(@9F]R9V5T(&ET
M+@!3970@=7`@<F5M;W1E('-E<G9E<G,@=&AA="!Y;W4@=V%N="!T;R!A8V-E
M<W,@9G)O;2!Y;W5R('!O<G1A;"X`4V5T('EO=7(@<')E9F5R<F5D(&QA;F=U
M86=E+"!T:6UE>F]N92!A;F0@9&%T92!O<'1I;VYS+@!3970@>6]U<B!S=&%R
M='5P(&%P<&QI8V%T:6]N+"!C;VQO<B!S8VAE;64L('!A9V4@<F5F<F5S:&EN
M9RP@86YD(&]T:&5R(&1I<W!L87D@;W!T:6]N<RX`4V5T=7``4V5T=7`@=7!G
M<F%D92!S8W)I<'1S(&%V86EL86)L90!3979E<F%L(&QO8V%T:6]N<R!P;W-S
M:6)L92!W:71H('1H92!P87)A;65T97(Z(`!397EC:&5L;&5S`%-H;W!P:6YG
M`%-H;W)T(%-U;6UA<GD`4VAO=6QD(&%C8V5S<R!K97ES(&)E(&1E9FEN960@
M9F]R(&UO<W0@;&EN:W,_`%-H;W<`4VAO=R!D:69F97)E;F-E<R!B971W965N
M(&-U<G)E;G1L>2!S879E9"!A;F0@=&AE(&YE=VQY(&=E;F5R871E9"!C;VYF
M:6=U<F%T:6]N+@!3:&]W(&QA<W0@;&]G:6X@=&EM92!W:&5N(&QO9V=I;F<@
M:6X_`%-H;W<@;W!T:6]N('1O(&ME97`@;W)I9VEN86P`4VAO=R!P:6-K97(`
M4VAO=R!T86)L92!O<&5R871I;VYS(&UE;G4@8F%R/P!3:&]W('1H92`E<R!-
M96YU(&]N('1H92!L969T/P!3:&]W('1H92!486)L92!#96QL(%!R;W!E<G1I
M97,@9&EA;&]G`%-H;W<@=&AE(%1A8FQE(%!R;W!E<G1I97,@9&EA;&]G`%-H
M;W<@=&AE(%1A8FQE(%)O=R!0<F]P97)T:65S(&1I86QO9P!3:&]W('1H92!I
M;6%G92!P<F]P97)T:65S(&1I86QO9P!3:&]W('5P;&]A9`!3:&]W97)S`%-H
M;W=E<G,@16%R;'D`4VAO=V5R<R!,871E`%-H;W=E<G,@:6X@=&AE(%9I8VEN
M:71Y`%-H<FEN:P!3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH
M<RD@;W5T(&]F('1H92!W87D@9FER<W0`4VEE<G)A($QE;VYE`%-I9VX@=7``
M4VEG;F%T=7)E`%-I9VYA='5R92!!;&=O<FET:&T`4VEN9V%P;W)E`%-I>F4`
M4VMI<"!-86EN=&5N86YC90!3;&]V86MI80!3;&]V96YI80!3;F]W`%-N;W<@
M4VAO=V5R`%-N;W<@4VAO=V5R<P!3;F]W(%-H;W=E<G,@16%R;'D`4VYO=R!3
M:&]W97)S($QA=&4`4VYO=R!D97!T:#H@`%-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@`%-O;&]M;VX@27-L86YD<P!3;VUA;&EA`%-O;F=S("8@4&]E;7,`
M4V]R="!O<F1E<B!S96QE8W1I;VX`4V]U<F-E(&%D9')E<W,`4V]U=&@@069R
M:6-A`%-O=71H($5U<F]P96%N("A)4T\M.#@U.2TS*0!3;W5T:"!'96]R9VEA
M(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@27-L86YD<P!3;W5T:&5R;B!(96UI
M<W!H97)E`%-P86-E(&)E='=E96X@861J86-E;G0@8V5L;',`4W!A8V4@8F5T
M=V5E;B!C;VYT96YT(&%N9"!B;W)D97(@:6X@8V5L;`!3<&%C97(`4W!A8VEN
M9P!3<&%C:6YG(&%N9"!P861D:6YG`%-P86EN`%-P86T`4W!E8VEA;"!#:&%R
M86-T97(@26YP=70`4W!L:70@8V5L;`!3<&QI="!C;VQU;6X`4W!L:70@<F]W
M`%-P;W)T<P!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A<B!4<F5K`%-T87)T('EE
M87(`4W1A=&4@;W(@4')O=FEN8V4`4W1A='5S`%-T;W)A9V4@9F]R;6%T`%-T
M<F5E="!!9&1R97-S`%-T<FEK971H<F]U9V@`4W1R:6YG(&QI<W0`4W1R:7`@
M9&]M86EN(&9R;VT@=&AE(&%D9')E<W,`4W1Y;&4@6T-34UT`4W4`4W5B:F5C
M=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5C8V5S<V9U;&QY(')E=F5R
M=&5D(&-O;F9I9W5R871I;VXN(%)E;&]A9"!T;R!S964@8VAA;F=E<RX`4W5C
M8V5S<V9U;&QY('-A=F5D(&)A8VMU<"!C;VYF:6=U<F%T:6]N+@!3=6-C97-S
M9G5L;'D@<V%V960@=&AE(&)A8VMU<"!C;VYF:6=U<F%T:6]N(&9I;&4@)7,N
M`%-U8V-E<W-F=6QL>2!W<F]T92`E<P!3=61A;@!3=6UM87)Y`%-U;B!2:7-E
M`%-U;B!3970`4W5N;GD`4W5N<FES90!3=6YR:7-E+U-U;G-E=`!3=6YR:7-E
M.B``4W5N<V5T`%-U;G-E=#H@`%-U<&5R<V-R:7!T`%-U<'!O<G0`4W5R:6YA
M;64`4W5R;F%M90!3=F%L8F%R9"!A;F0@2F%N($UA>65N`%-W87II;&%N9`!3
M=V5D96X`4W=I='IE<FQA;F0`4WEN=&%X(&5R<F]R(&EN('-E87)C:"!T97)M
M<P!3>7)I86X@07)A8B!297!U8FQI8P!4+5-T;W)M`%0M4W1O<FT@86YD(%=I
M;F1Y`%0M4W1O<FUS`%135B!F:6QE`%1A8FQE(%!R;W!E<G1I97,`5&%B;&4@
M<')O<&5R=&EE<P!486EW86X`5&%I=V%N+"!0<F]V:6YC92!O9B!#:&EN80!4
M86II:VES=&%N`%1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8`5&%R9V5T
M.@!487-K<P!496QE<&AO;F4@3G5M8F5R`%1E;7`@9F]R(&QA<W0@:&]U<CH@
M`%1E;7!E<F%T=7)E`%1E;7!E<F%T=7)E.B``5&5M<&QA=&4@061M:6YI<W1R
M871I;VX`5&5X=`!497AT($]N;'D`5&5X="!A;&EG;@!497AT=&]P`%1H`%1H
M86D@*%1)4RTV,C`I`%1H86EL86YD`%1H92!&5%`@97AT96YS:6]N(&ES(&YO
M="!A=F%I;&%B;&4N`%1H92!(;W)D92]+;VQA8B!I;G1E9W)A=&EO;B!E;F=I
M;F4@9&]E<R!N;W0@<W5P<&]R="`B)7,B`%1H92!-86EN=&5N86YC93HZ(&-L
M87-S(&1I9"!N;W0@;&]A9"!S=6-C97-S9G5L;'D`5&AE($]P=&EO;G,@=VEN
M9&]W(&AA<R!C;&]S960N($5X:71I;F<N`%1H92!A9&UI;FES=')A=&]R(&YE
M961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K
M96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RX`5&AE(&)O='1O
M;2!S:61E(&]N;'D`5&AE(&-O;G1A8W0@240@;G5M8F5R('=A<R!N;W0@<W!E
M8VEF:65D+"!L969T(&)L86YK(&]R('=A<R!N;W0@9F]U;F0@:6X@=&AE(&1A
M=&%B87-E+@!4:&4@8V]N=&%C="!W87,@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+@!4:&4@9&5T86-H960@4$=0('-I9VYA='5R
M92!B;&]C:R!I<R!R97%U:7)E9"!T;R!V97)I9GD@=&AE('-I9VYE9"!M97-S
M86=E+@!4:&4@9&ES=')I8G5T:6]N(&QI<W0@240@=V%S(&5I=&AE<B!N;W0@
M<W!E8VEF:65D+"!L969T(&)L86YK(&]R(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N`%1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"X`5&AE(&5N8W)Y<'1I;VX@9F5A='5R97,@<F5Q=6ER92!A('-E8W5R92!W
M96(@8V]N;F5C=&EO;BX`5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E
M<R!S971T:6YG+@!4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S
M('-E='1I;F=S+@!4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82X`5&AE(&9O
M;&QO=VEN9R!A<F4@=&AE(&AE861E<G,@9F]R('1H:7,@;65S<V%G92]R9F,X
M,C(@;65S<V%G92X`5&AE(&9U;&P@<V-R965N(&UO9&4@:7,@:VYO=VX@=&\@
M8V%U<V4@<')O8FQE;7,@=VET:"!);G1E<FYE="!%>'!L;W)E<BP@9'5E('1O
M(&)R;W=S97(@8G5G<R!T:&%T('=E('=E<F5N)W0@86)L92!T;R!W;W)K87)O
M=6YD+B`@66]U(&UI9VAT(&5X<&5R:65N8V4@9V%R8F%G92!D:7-P;&%Y+"!L
M86-K(&]F(&5D:71O<B!F=6YC=&EO;G,@86YD+V]R(')A;F1O;2!B<F]W<V5R
M(&-R87-H97,N("!)9B!Y;W5R('-Y<W1E;2!I<R!7:6YD;W=S(#EX(&ET)W,@
M=F5R>2!L:6ME;'D@=&AA="!Y;W4G;&P@9V5T(&$@)T=E;F5R86P@4')O=&5C
M=&EO;B!&875L="<@86YD(&YE960@=&\@<F5B;V]T+EQN7&Y9;W4@:&%V92!B
M965N('=A<FYE9"X@(%!L96%S92!P<F5S<R!/2R!I9B!Y;W4@<W1I;&P@=V%N
M="!T;R!T<GD@=&AE(&9U;&P@<V-R965N(&5D:71O<BX`5&AE(&ED96YT:71Y
M("(E<R(@:&%S(&)E96X@9&5L971E9"X`5&AE(&QE9G0M:&%N9"!S:61E(&]N
M;'D`5&AE(&QO8V%T:6]N(&]F('1H92!';G501R!B:6YA<GD@;75S="!B92!G
M:79E;B!T;R!T:&4@0W)Y<'1?<&=P.CH@8VQA<W,N`%1H92!M97-S86=E('-E
M;G0@;VX@)7,@=&\@)7,@=VET:"!S=6)J96-T("(E<R(@:&%S(&)E96X@9&ES
M<&QA>65D+@I4:&ES(&ES(&YO(&=U87)A;G1E92!T:&%T('1H92!M97-S86=E
M(&AA<R!B965N(')E860@;W(@=6YD97)S=&]O9"X`5&AE(&YA;64@=&\@=7-E
M('=H96X@;&EN:VEN9R!T;R!T:&4@8V]M<&]S92!P86=E`%1H92!O<&5N<W-L
M(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@=&AE($AO<F1E7T-R>7!T7W-M:6UE
M.CH@8VQA<W,N`%1H92!P<F5F97)E;F-E("(E<R(@8V]U;&0@;F]T(&)E('-A
M=F5D(&)E8V%U<V4@:71S(&1A=&$@97AC965D960@=&AE(&UA>&EM=6T@86QL
M;W=A8FQE('-I>F4`5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+@!4:&4@
M<FEG:'0@86YD(&QE9G0@<VED97,@;VYL>0!4:&4@<FEG:'0M:&%N9"!S:61E
M(&]N;'D`5&AE('-E<G9E<B`B)7,B(&AA<R!B965N(&1E;&5T960N`%1H92!S
M97)V97(@(B5S(B!H87,@8F5E;B!S879E9"X`5&AE('-I9VYU<"!R97%U97-T
M(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+@!4:&4@=&5M<&]R87)Y(&9I;&4@
M(B5S(B!D;V5S(&YO="!E>&ES="X`5&AE('1O<"!A;F0@8F]T=&]M('-I9&5S
M(&]N;'D`5&AE('1O<"!S:61E(&]N;'D`5&AE('5P;&]A9&5D(&1A=&$@=V%S
M(&QO<W0@<VEN8V4@=&AE('!R979I;W5S('-T97`N`%1H92!U<&QO861E9"!F
M:6QE(&-O=6QD(&YO="!B92!S879E9"X`5&AE('=E871H97(N8V]M(&)L;V-K
M(&ES(&YO="!A=F%I;&%B;&4N`%1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL
M86)L92X`5&AE<F4@87)E(&YO('!A<G1S('1H870@8V%N(&)E(&1I<W!L87EE
M9"!I;FQI;F4N`%1H97)E(&%R92!T;V\@;6%N>2!C:&%R86-T97)S(&EN('1H
M:7,@9FEE;&0N(%EO=2!H879E(&5N=&5R960@)7,@8VAA<F%C=&5R<SL@>6]U
M(&UU<W0@96YT97(@;&5S<R!T:&%N("5S+@!4:&5R92!W87,@82!P<F]B;&5M
M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!.;R`E<R!W87,@=7!L;V%D960N`%1H
M97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z(%1H92`E
M<R!W87,@;&%R9V5R('1H86X@=&AE(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E
M9"!B>71E<RDN`%1H97)E('=A<R!A('!R;V)L96T@=VET:"!T:&4@9FEL92!U
M<&QO860Z(%1H92`E<R!W87,@;VYL>2!P87)T:6%L;'D@=7!L;V%D960N`%1H
M97)E('=A<R!A;B!E<G)O<B!D:7-P;&%Y:6YG('1H:7,@;65S<V%G92!P87)T
M`%1H97)E('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T
M82X`5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@:4-A;&5N9&%R
M(&1A=&$N`%1H97)E('=A<R!A;B!E<G)O<B!I;B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B!097)H87!S('EO=2!L969T(&]U="!A(')E<75I<F5D(&9I96QD
M+@!4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF:65D
M(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L871E
M<BX`5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C;VYT86-T(&1E
M=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N`%1H97)E('=A<R!A;B!E
M<G)O<B!U<&1A=&EN9R!T:&4@9&ES=')I8G5T:6]N(&QI<W0N(%!L96%S92!T
M<GD@86=A:6X@;&%T97(N`%1H:7,@24U!4"!S97)V97(@9&]E<R!N;W0@<W5P
M<&]R="!S:&%R:6YG(&9O;&1E<G,N`%1H:7,@9&]E<R!N;W0@87!P96%R('1O
M(&)E(&$@=F%L:60@<F%R(&%R8VAI=F4N`%1H:7,@9&]E<R!N;W0@87!P96%R
M('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N`%1H:7,@9&]E<R!N;W0@<V5E;2!T
M;R!B92!A('9A;&ED(&-A<F0@;G5M8F5R+@!4:&ES(&1R:79E<B!A;&QO=W,@
M<V5N9&EN9R!O9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH
M='1P.B\O8VQI8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10
M($%020!4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O9B!M97-S86=E<R!T
M:')O=6=H('1H92!S;7,R96UA:6P@*&AT='`Z+R]S;7,R96UA:6PN8V]M*2!G
M871E=V%Y+"!U<VEN9R!T:&4@2%144"!!4$D`5&AI<R!D<FEV97(@86QL;W=S
M('-E;F1I;F<@;V8@;65S<V%G97,@=FEA(%--5%`@=&AR;W5G:"!T:&4@5F]D
M869O;F4@271A;'D@9V%T97=A>2P@;VYL>2!T;R!6;V1A9F]N92!N=6UB97)S
M+B!)="!R97%U:7)E<R!A;B!E;6%I;"!A8V-O=6YT('=I=&@@5F]D869O;F4@
M271A;'D@*&AT='`Z+R]W=W<N,3DP+FET*2X`5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"X`5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S+@!4
M:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O
M;&]N+@!4:&ES(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;V-T86P@=F%L=65S
M+@!4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<P!4:&ES(&9I96QD(&UU<W0@8F4@82!V86QI
M9"!N=6UB97(N`%1H:7,@9FEE;&0@;75S="!C;VYT86EN(&$@8V]L;W(@8V]D
M92!I;B!T:&4@4D="($AE>"!F;W)M870L(&9O<B!E>&%M<&QE("<C,3(S-&%F
M)RX`5&AI<R!F;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+@!4:&ES
M(&ES("5S+@!4:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@
M=FEE=R!T:&ES(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N
M="!T:&%T('5N9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T
M+B!&;W(@82!L:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES
M:70@)7,`5&AI<R!M97-S86=E('=A<R!W<FET=&5N(&EN(&$@8VAA<F%C=&5R
M('-E="`H)7,I(&]T:&5R('1H86X@>6]U<B!O=VXN`%1H:7,@;G5M8F5R(&UU
M<W0@8F4@870@;&5A<W0@;VYE+@!4:&ES('-E<G9E<B!C86XG="!U;F-O;7!R
M97-S('II<"!A;F0@9WII<"!F:6QE<RX`5&AI<R!S>7-T96T@:7,@8W5R<F5N
M=&QY(&1E86-T:79A=&5D+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1H:7,@=VEN9&]W(&UU<W0@8F4@8V%L;&5D(&9R;VT@86X@3W!T:6]N<R!W
M:6YD;W<`5&AU;F1E<@!4:6-K971S`%1I;64`5&EM92!4<F%C:VEN9P!4:6UE
M(&9O<FUA=`!4:6UE('-E;&5C=&EO;@!4:6UO<BU,97-T90!4:71L90!4:71L
M92`H=&]O;'1I<"DZ`%1O`%1O('-E;&5C="!M=6QT:7!L92!I=&5M<RP@:&]L
M9"!D;W=N('1H92!#;VYT<F]L("A00RD@;W(@0V]M;6%N9"`H36%C*2!K97D@
M=VAI;&4@8VQI8VMI;F<N`%1O9&%Y`%1O9V=L92!(5$U,(%-O=7)C90!4;V=O
M`%1O:V5L874`5&]M;W)R;W<`5&]N9V$`5&]P`%1O<"!F<F%M92`H7W1O<"D`
M5')A;G-L871I;VYS`%1R:6YI9&%D(&%N9"!4;V)A9V\`5')U92!O<B!F86QS
M90!4=0!4=6YI<VEA`%1U<FME>0!4=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K
M;65N:7-T86X`5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S`%1U=F%L=0!4>7!E
M('EO=7(@8VAO:6-E.B``52Y6+B!I;F1E>#H@`%523`!54DP@9F]R('EO=7(@
M<V-R:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0`55),.@!59V%N9&$`56MR
M86EN90!5;F%B;&4@=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T
M;R!A9&0@97AT<F$@=7-E<B!I;F9O<FUA=&EO;B!W:&5N('-I9VYI;F<@=7`N
M`%5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I;&4@(B5S
M(BX`56YA8FQE('1O(&-H86YG92!P97)M:7-S:6]N(&9O<B!61E,@9FEL92`E
M<R\E<RX`56YA8FQE('1O(&-H86YG92!T;R`E<RX`56YA8FQE('1O(&-O;FYE
M8W0@=&\@4U%,('-E<G9E<BX`56YA8FQE('1O(&-O;FYE8W0@=VET:"!34TPN
M`%5N86)L92!T;R!C;W!Y(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E871E(%9&
M4R!D:7)E8W1O<GD@(B5S(BX`56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T
M;W)Y+@!5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+@!5;F%B;&4@=&\@8W)E
M871E(%9&4R!F;VQD97(@(B5S(BX`56YA8FQE('1O(&-R96%T92!E;7!T>2!6
M1E,@9FEL92X`56YA8FQE('1O(&1E8V]M<')E<W,@9&%T82X`56YA8FQE('1O
M(&1E;&5T92`B)7,B+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2X`56YA
M8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='D`
M56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y(')E8W5R<VEV96QY+@!5
M;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN`%5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>3H@)7,N`%5N86)L92!T;R!D96QE=&4@5D93(&9I
M;&4@(B5S(BX`56YA8FQE('1O(&1E;&5T92!61E,@9FEL92X`56YA8FQE('1O
M(&1E;&5T92!61E,@9F]L9&5R("(E<R(N`%5N86)L92!T;R!D96QE=&4@5D93
M(')E8W5R<VEV96QY.B`E<RX`56YA8FQE('1O(&1E=&5R;6EN92!C=7)R96YT
M(&1I<F5C=&]R>2X`56YA8FQE('1O(&5X=')A8W0@8V5R=&EF:6-A=&4@9&5T
M86EL<P!5;F%B;&4@=&\@;&]A9"!T:&4@9&5F:6YI=&EO;B!O9B`E<RX`56YA
M8FQE('1O(&UO=F4@5D93(&9I;&4N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE
M("(E<R(N`%5N86)L92!T;R!O<&5N(%9&4R!F:6QE(&9O<B!W<FET:6YG+@!5
M;F%B;&4@=&\@;W!E;B!61E,@9FEL92X`56YA8FQE('1O(&]P96X@8V]M<')E
M<W-E9"!A<F-H:79E+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9FEL97-I
M>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!61E,@9FEL92`H9V5T1FEL
M95-I>F4H*2!F86EL960I+@!5;F%B;&4@=&\@<F5A9"!F:6QE.B``56YA8FQE
M('1O(')E860@=&AE('9F<W)O;W0@9&ER96-T;W)Y+@!5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',`56YA8FQE('1O(')E;F%M92!61E,@9&ER96-T;W)Y+@!5;F%B;&4@=&\@
M<F5N86UE(%9&4R!D:7)E8W1O<GDZ("5S+@!5;F%B;&4@=&\@<F5N86UE(%9&
M4R!F:6QE("(E<R(N`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N
M`%5N86)L92!T;R!R96YA;64@5D93(&9I;&4N`%5N86)L92!T;R!R=6X@)VUK
M:7-O9G,G+@!5;F%B;&4@=&\@=')A;G-L871E('1H:7,@5V]R9"!D;V-U;65N
M=`!5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@(B5S(BX`56YA8FQE('1O('=R
M:71E(%9&4R!F:6QE("AC;W!Y*"D@9F%I;&5D*2X`56YA8FQE('1O('=R:71E
M(%9&4R!F:6QE(&1A=&$N`%5N86)L92!T;R!W<FET92!61E,@9FEL92P@<75O
M=&$@=VEL;"!B92!E>&-E961E9"X`56YD97)L:6YE`%5N9&\@0VAA;F=E<P!5
M;F1O97,@>6]U<B!L87-T(&%C=&EO;@!5;F5X<&5C=&5D(')E<W!O;G-E(&9R
M;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ(`!5;F5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@<V5R=F5R('1O.B``56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI
M=&5D($%R86(@16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E
M<P!5;FET960@4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`
M56YK;F]W;@!5;FMN;W=N(&%P:6US9VED("A!4$D@365S<V%G92!)1"DN`%5N
M:VYO=VX@8VQI;7-G:60@*$-L:65N="!-97-S86=E($E$*2X`56YK;F]W;B!L
M;V-A=&EO;B!P<F]V:61E9"X`56YK;F]W;B!U<V5R;F%M92!O<B!P87-S=V]R
M9"X`56YL:6YK('1H92!C=7)R96YT(&5L96UE;G0`56YN86UE9`!5;G!R:79I
M;&5G960@<V-R:7!T<R!C86YN;W0@86-C97-S($-U="]#;W!Y+U!A<W1E('!R
M;V=R86UA=&EC86QL>2!F;W(@<V5C=7)I='D@<F5A<V]N<RX@($-L:6-K($]+
M('1O('-E92!A('1E8VAN:6-A;"!N;W1E(&%T(&UO>FEL;&$N;W)G('=H:6-H
M('-H;W=S('EO=2!H;W<@=&\@86QL;W<@82!S8W)I<'0@=&\@86-C97-S('1H
M92!C;&EP8F]A<F0N`%5N<V5T(&-O;&]R`%5N<W5P<&]R=&5D($5X=&5N<VEO
M;@!5<&1A=&4`57!D871E("5S`%5P9&%T92!U<V5R`%5P9W)A9&4@<V-R:7!T
M(&1E;&5T960N`%5P;&]A9`!5<&QO861E9"!A;&P@87!P;&EC871I;VX@<V5T
M=7`@9FEL97,@=&\@=&AE('-E<G9E<BX`57!P97(@;&%T:6X@;&5T=&5R<P!5
M<'!E<B!R;VUA;B!N=6UB97)S`%5R=6=U87D`57-E($-U<G)E;G0Z("5S`%5S
M92!34TP`57-E(&EF(&YA;64O<&%S<W=O<F0@:7,@9&EF9F5R96YT(&9O<B!)
M35-0('-E<G9E<BX`57-E<B`E<R!I<R!N;W0@875T:&]R:7-E9"!F;W(@)7,N
M`%5S97(@061M:6YI<W1R871I;VX`57-E<B!/<'1I;VYS`%5S97(@4F5G:7-T
M<F%T:6]N`%5S97(@4F5G:7-T<F%T:6]N(&AA<R!B965N(&1I<V%B;&5D(&9O
M<B!T:&ES('-I=&4N`%5S97)N86UE`%5S97)N86UE.@!5<V5R;F%M93H@`%5S
M97)S(&EN('1H92!S>7-T96TZ`%5Z8F5K:7-T86X`5D93(&1I<F5C=&]R>2!D
M;V5S(&YO="!E>&ES="X`5F%C871I;VX`5F%L:60@;&]C871I;VYS(&9O=6YD
M(&EN8VQU9&4Z(`!686QI9&ET>0!686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W
M+@!686QU92!I<R!O=F5R('1H92!M87AI;75M(&QE;F=T:"!O9B`E<RX`5F%L
M=65S`%9A;'5E<R!T;R!S96QE8W0@9G)O;0!686YU871U`%9A<FEA8FQE`%9E
M;F5Z=65L80!697)I9FEC871I;VX@9F%I;&5D("T@=&AI<R!M97-S86=E(&UA
M>2!H879E(&)E96X@=&%M<&5R960@=VET:"X`5F5R<VEO;@!697)S:6]N($-O
M;G1R;VP`5F5R=&EC86P@86QI9VX`5F5R=&EC86P@<&%D9&EN9P!697)T:6-A
M;#H`5F5R>2!(:6=H`%9I970@3F%M`%9I971N86UE<V4@*%9)4T-)22D`5FEE
M=R`E<P!6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E`%9I97<@87,@)7,`5FER
M9VEN($ES;&%N9',L($)R:71I<V@`5FER9VEN($ES;&%N9',L(%4N4RX`5FES
M:6)I;&ET>0!6:7-I8FEL:71Y.B``5F]D869O;F4@271A;'D@=FEA(%--5%``
M5T%23@!705).24Y'(2$A(%)%34]612!30U))4%0@34%.54%,3%D@1E)/32`E
M<RX`5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!790!796%T:&5R($9O<F5C
M87-T`%=E871H97(@9&%T82!P<F]V:61E9"!B>0!796%T:&5R+F-O;0!796(`
M5V5B(%-I=&4`5V5E:VQY`%=E;&-O;64`5V5L8V]M92!T;R`E<P!796QC;VUE
M+"`E<P!797-T97)N("A)4T\M.#@U.2TQ*0!797-T97)N("A)4T\M.#@U.2TQ
M-2D`5V5S=&5R;B!386AA<F$`5VAA="!A<'!L:6-A=&EO;B!S:&]U;&0@)7,@
M9&ES<&QA>2!A9G1E<B!L;V=I;C\`5VAA="!I<R!T:&4@9&5L:6UI=&5R(&-H
M87)A8W1E<C\`5VAA="!I<R!T:&4@<75O=&4@8VAA<F%C=&5R/P!7:&EC:"!P
M:&%S97,`5VAI8V@@<&QU9VEN<R!T;R!E;F%B;&4@9F]R('1H92!2:6-H(%1E
M>'0@961I=&]R+@!7:61T:`!7:61T:"!I;B!#4U,@=6YI=',`5VED=&@@;V8@
M=&AE("5S(&UE;G4@;VX@=&AE(&QE9G0@*'1A:V5S(&5F9F5C="!O;B!N97AT
M(&QO9RUI;BDZ`%=I9'1H(&]F('1H92!T86)L90!7:61T:"!U;FET`%=I9'1H
M.@!7:6MI`%=I;F0`5VEN9"!%87)L>0!7:6YD('-P965D(&EN(&MN;W1S`%=I
M;F0Z`%=I;F0Z(`!7:7-D;VT`5V]R:P!7;W)K($%D9')E<W,`5V]R:R!0:&]N
M90!8+5)E9@!8-3`Y=C,@0F%S:6,@0V]N<W1R86EN=',`6#4P.78S($5X=&5N
M9&5D($ME>2!5<V%G90!8-3`Y=C,@4W5B:F5C="!!;'1E<FYA=&EV92!.86UE
M`%@U,#EV,R!3=6)J96-T($ME>2!)9&5N=&EF:65R`%@U,#EV,R!E>'1E;G-I
M;VYS`%E9`%E965D`66%H;V\A(&UA<`!996%R;'D`665M96X`665S`%EE<RP@
M22!!9W)E90!9;W4@87)E(&EN(%1%6%0@34]$12X@(%5S92!T:&4@6SP^72!B
M=71T;VX@=&\@<W=I=&-H(&)A8VL@=&\@5UE325=91RX`66]U(&%R92!N;W0@
M875T:&5N=&EC871E9"X`66]U(&1I9"!N;W0@96YT97(@82!V86QI9"!E;6%I
M;"!A9&1R97-S+@!9;W4@9&ED;B=T(&UA<"!A;GD@9FEE;&1S(&9R;VT@=&AE
M(&EM<&]R=&5D(&9I;&4@=&\@=&AE(&-O<G)E<W!O;F1I;F<@9FEE;&1S(&EN
M("5S+@!9;W4@:&%V92!B965N(&QO9V=E9"!O=70N`%EO=2!H879E('1O(&5N
M=&5R(&$@=F%L:60@8V5L;'!H;VYE(&YU;6)E<BP@9&EG:71S(&]N;'D@=VET
M:"!A;B!O<'1I;VYA;"`G*R<@9F]R('1H92!I;G1E<FYA=&EO;F%L(&1I86QI
M;F<@<')E9FEX+@!9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A;'5E+@!9
M;W4@;75S="!C;VYF:6=U<F4@82!$871A5')E92!B86-K96YD('1O('5S92!3
M:6=N=7!S+@!9;W4@;75S="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"X`66]U
M(&UU<W0@9&5S8W)I8F4@=&AE('!R;V)L96T@8F5F;W)E('EO=2!C86X@<V5N
M9"!T:&4@<')O8FQE;2!R97!O<G0N`%EO=2!M=7-T(&5N=&5R('1H92!54DP@
M=VAE<F4@=&AI<R!L:6YK('!O:6YT<R!T;P!9;W4@;75S="!S96QE8W0@86X@
M<V5R=F5R('1O(&)E(&1E;&5T960N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!C;&5A<B!O=70N`%EO=2!M=7-T('-P96-I9GD@82!U<V5R;F%M
M92!T;R!R96UO=F4N`%EO=2!M=7-T('-P96-I9GD@=&AE('5S97)N86UE('1O
M(&%D9"X`66]U(&UU<W0@<W!E8VEF>2!T:&4@=7-E<FYA;64@=&\@=7!D871E
M+@!9;W4@;75S="!S<&5C:69Y('=H870@86-T:6]N('1O('!E<F9O<FTN`%EO
M=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92X`66]U<B`E<R!S97-S
M:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G:6X@86=A:6XN`%EO=7(@16UA
M:6P@061D<F5S<P!9;W5R($9R;VTZ(&%D9')E<W,Z`%EO=7(@26YF;W)M871I
M;VX`66]U<B!);G1E<FYE="!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H
M92!B96=I;FYI;F<@;V8@>6]U<B`E<R!S97-S:6]N+B!4;R!P<F]T96-T('EO
M=7(@<V5C=7)I='DL('EO=2!M=7-T(&QO9VEN(&%G86EN+@!9;W5R($YA;64`
M66]U<B!A=71H96YT:6-A=&EO;B!B86-K96YD(&1O97,@;F]T('-U<'!O<G0@
M;&ES=&EN9R!U<V5R<RP@;W(@=&AE(&9E871U<F4@:&%S(&)E96X@9&ES86)L
M960@9F]R('-O;64@;W1H97(@<F5A<V]N+@!9;W5R(&)R;W=S97(@87!P96%R
M<R!T;R!H879E(&-H86YG960@<VEN8V4@=&AE(&)E9VEN;FEN9R!O9B!Y;W5R
M("5S('-E<W-I;VXN(%1O('!R;W1E8W0@>6]U<B!S96-U<FET>2P@>6]U(&UU
M<W0@;&]G:6X@86=A:6XN`%EO=7(@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T
M('1H:7,@9F5A='5R92X`66]U<B!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@
M=&AI<R!P<FEN="!O<'1I;VXN(%!R97-S($-O;G1R;VPO0V]M;6%N9"`K(%`@
M=&\@<')I;G0N`%EO=7(@8W5R<F5N="!T:6UE('IO;F4Z`%EO=7(@9&5F875L
M="!I9&5N=&ET>3H`66]U<B!F=6QL(&YA;64Z`%EO=7(@;F5W('!A<W-W;W)D
M(&9O<B`E<R!I<SH@)7,`66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S97-S:6]N+@!9;W5R(&]P=&EO
M;G,@:&%V92!B965N('5P9&%T960N`%EO=7(@<&%S<W=O<F0@:&%S(&)E96X@
M<F5S970`66]U<B!P87-S=V]R9"!H87,@8F5E;B!R97-E="P@8VAE8VL@>6]U
M<B!E;6%I;"!A;F0@;&]G(&EN('=I=&@@>6]U<B!N97<@<&%S<W=O<F0N`%EO
M=7(@<F5M;W1E('-E<G9E<G,Z`%EU9V]S;&%V:6$`6F%I<F4`6F%M8FEA`%II
M;6)A8G=E`%II<'!Y`%M(:61E(%%U;W1E9"!497AT70!;4')O8FQE;2!297!O
M<G1=`%M3:&]W(%%U;W1E9"!497AT("T`6U-H;W<@475O=&5D(%1E>'0@+2`E
M<R!L:6YE<UT`6VQI;F4@)7,@;V8@)7-=`%]!9&UI;FES=')A=&EO;@!?0TQ)
M`%]$871A5')E90!?1&5L971E(%)O=P!?1W)O=7!S`%](96QP`%]);6%G92!0
M<F]P97)T:65S+BXN`%],;V<@:6X`7TQO9R!O=70`7TUO9&EF>2!,:6YK+BXN
M`%]/<'1I;VYS`%]097)M:7-S:6]N<P!?4F5M;W9E($QI;FLN+BX`7U-E='5P
M`%]486)L92!0<F]P97)T:65S+BXN`%]5<V5R<P!A9&1R97-S(&)O;VL`8V%L
M96YD87(`8V%L;0!C;&EC:R!H97)E`&9A;&QI;F<`9FEL90!F<F]M('1H92`E
M<R`H)7,I(&%T("5S("5S`&@Z`&AH`&EM;65D:6%T90!I;FQI;F4`;&EN97-=
M`&UK:7-O9G,@97)R;W(@8V]D92`E9"!W:&EL92!M86MI;F<@25-/+@!M;0!N
M86UE`&YO="!I;7!L96UE;G1E9`!N;W0@>65T(&EM<&QE;65N=&5D`&YO=&5P
M860`<&5R8V5N=`!P:7AE;',`<FES:6YG`'-H;W<@9&EF9F5R96YC97,`<VUS
M,F5M86EL('9I82!(5%10`'-S`'-T96%D>0!T87-K(&QI<W0`='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;0!U;FEF:65D`'5N;F%M960`=7-E
M<B!S96QE8W0`=D-A<F0`=SH`=V5A=&AE<BYC;VT`4')O:F5C="U)9"U697)S
M:6]N.B!(;W)D92`S+C`U"E)E<&]R="U-<V=I9"U"=6=S+51O.B!D979`;&ES
M=',N:&]R9&4N;W)G"E!/5"U#<F5A=&EO;BU$871E.B`R,#`V+3`U+3$Q(#$R
M.C4Q*S`R,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-BTP-RTQ-"`Q,3HP."LP
M,3`P"DQA<W0M5')A;G-L871O<CH@2F]R9&D@1VER86QT(#QP<F]J96-T92YK
M,D!U<&-N970N961U/@I,86YG=6%G92U496%M.B!#871A;&%N(#QD979`;&ES
M=',N:&]R9&4N;W)G/@I-24U%+59E<G-I;VXZ(#$N,`I#;VYT96YT+51Y<&4Z
M('1E>'0O<&QA:6X[(&-H87)S970]:7-O+3@X-3DM,0I#;VYT96YT+51R86YS
M9F5R+45N8V]D:6YG.B`X8FET"@`H9F$@)7,@9&EE<RD`("A#;&%U(&0G86-C
MZ7,@)7,I`"AE;B`E<R!D:65S*0`H879U:2D`*&1E;>`I`"AA:&ER*0!E;@`B
M)7,B(&YO(.ES('5N(&1I<F5C=&]R:2X`)60@)7,@:2`E<P`E9"!B>71E<R!E
M<V-R:71S+@`E9"!D92`E9"!E;G1R861E<R!M87)C861E<R!C;VT@86-T=6%L
M:71Z861E<P!P<F5V:7-I\R!P97(@86P@9&EA("5D`$%V[7,@+2`E<P!%;7!R
M96UT82!D86-T:6QA<B`E<P`E<R!+0@!/<&5R86-I;VYS(&1E(&UA;G1E;FEM
M96YT("5S("T@0V]N9FER;6%C:?,`0V]N9FEG=7)A8VGS(&1E("5S`$%L=&$@
M9&4@)7,`0V]N9&EC:6]N<R!D96P@8V]N=')A8W1E("5S`"5S(&IA(&5X:7-T
M96EX+@`E<R!E;B`E<R`E<P#)<R!N96-E<W-A<FD@)7,N`"5S(&UI;G5T<P!.
M;R!S)VAA('1R;V)A="`E<RX`)7,@;F\@=')O8F%T+B!%>&5C=71A("=T<F%N
M<VQA=&EO;B!E>'1R86-T)R!P<FEM97(N`"5S(&%L("5S(&1E("5S`$QL:6)R
M971A(&0G861R96-E<R!D92`E<P!!9V5N9&$@9&4@)7,`0FQO8R!D92!N;W1E
M<R!D92`E<P!,;&ES=&$@9&4@=&%S<75E<R!D92`E<P`E<SH@)7,`+"!V96YT
M\W,@)7,@)7,@`"P@=F%R:6%B;&4@9&4@)7,@82`E<P`M+2!S96QE8V-I;VYA
M<B`M+0`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T`9F]R;6%T(&1E(#$R
M(&AO<F5S`&9O<FUA="!D92`R-"!H;W)E<P`R-"!H;W)E<P`\06YT97)I;W(`
M4&5R(&$@87%U97-T(&)L;V,@97,@;F5C97-S:71A('5N(&UO=&]R(&1E(&)A
M<V5S(&1E(&1A9&5S+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@:7)R97!A<F%B
M;&4N`$5S(&YE8V5S<VET82!U;F$@8VQA=2!01U`@</IB;&EC82!P97(@>&EF
M<F%R('5N(&UI<W-A=&=E+@!%<R!N96-E<W-I=&$@=6YA(&-L874@4$=0('#Z
M8FQI8V$@<&5R('9E<FEF:6-A<B!U;B!M:7-S871G92!S:6=N870N`$5S(&YE
M8V5S<VET96X@=6YA(&-L874@4$=0('#Z8FQI8V$L('5N82!C;&%U(%!'4"!P
M<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!D97-X:69R87(@=6X@;6ES
M<V%T9V4N`$5S(&YE8V5S<VET96X@=6YA(&-L874@4$=0('#Z8FQI8V$L('5N
M82!C;&%U(%!'4"!P<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!S:6=N
M87(@=6X@;6ES<V%T9V4N`$5S(&YE8V5S<VET96X@=6YA(&-L874@4R]-24U%
M('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P<FEV861A(&D@=6YA(&-O;G1R
M87-E;GEA('!E<B!D97-X:69R87(@=6X@;6ES<V%T9V4N`$5S(&YE8V5S<VET
M96X@=6YA(&-L874@4R]-24U%('#Z8FQI8V$L('5N82!C;&%U(%,O34E-12!P
M<FEV861A(&D@=6YA(&-O;G1R87-E;GEA('!E<B!S:6=N87(@=6X@;6ES<V%T
M9V4N`$5S(&YE8V5S<VET82!U;F$@8VQA=2!334E-12!P^F)L:6-A('!E<B!X
M:69R87(@=6X@;6ES<V%T9V4N`$[Z=F]L<R!A;"!M873M`%!L=6IA(&9E8FQE
M(&%L(&UA=.T`4&QU:F$@86P@;6%T[0!2=6EX871S(&%L(&UA=.T`6.!F96-S
M(&1E(&YE=2!A;"!M873M+@!!32]030!)1"!D92!!4$D`4V]B<F4@87%U97-T
M(&5D:71O<@!%;B!Q=6%N="!A+BXN`$%L:6YE86-I\R!I;F9E<FEO<B!E>&%C
M=&$`06QI;F5A8VGS(&%L(&UI9R!E>&%C=&$`4R=H82!D96YE9V%T(&PG86-C
MZ7,@96X@8W)E87(@96P@9&ER96-T;W)I(%9&4RX`4R=H82!D96YE9V%T(&PG
M86-CZ7,@96X@8W)E87(@;"=A<GAI=2!61E,N`$-O;G1R87-E;GEA(&1E;"!C
M;VUP=&4`0V]M<'1E(&-O;F=E;&%T+@!#;VUP=&%B:6QI='IA8VGS`$%F96=I
M<@!!9F5G:7(@=6X@9W)U<"!D97-C96YD96YT`$%F96=I<B!U;F$@875T;W)I
M='IA8VGS(&1E<V-E;F1E;G0`069E9VER(&$@8V]N=&EN=6%C:?,Z`$%F96=I
M<B!U;B!N;W4@9W)U<`!!9F5G:7(@=6YA(&YO=F$@875T;W)I='IA8VGS(`!!
M9F5G:7(@=6X@;F]U('5S=6%R:3H`069E9VER('5N82!C;VQU;6YA+@!!9F5G
M:7(@;F]U<R!M96UB<F5S+@!!9F5G:7(@=6YA('!A<F5L;&$`069E9VER(&5L
M(&UE;OH@)7,@8V]M('5N82!B87)R82!L871E<F%L(&1E($UO>FEL;&$`069E
M9V5I>"!A(&QA(&QL:6)R971A(&0G861R96-E<SH`069E9V5I>"!A(&QA(&UE
M=F$@;&QI8G)E=&$@9"=A9')E8V5S`$%F96=I<B!U;B!U<W5A<FD`069E9VEN
M="!N;W5S(&9I='AE<G,@86P@<F5P;W-I=&]R:0!3)VAA(&EN:&%B:6QI=&%T
M(&PG;W!C:?,@9"=A9F5G:7(@=7-U87)I<RX`061R9>=A`$QL:6)R971A(&0G
M861R96-E<P!!9&UI;FES=')A9&]R("T@9&5F:6YE:7@@;&5S(&%U=&]R:71Z
M86-I;VYS('!E<B!A(&%L=')E<R!U<W5A<FES`$%D;6EN:7-T<F%C:?,`06YU
M;F-I<P!!9F=A;FES=&%N`$%L8N!N:6$`06QGZ')I80#`;&EE<P!!;&EN96%R
M`$%L:6YE86-I\SH`5&]T<P!4;W1S(&5L<R!U<W5A<FES(&%U=&5N=&EC871S
M`%1O=',@96QS(&=R=7!S`%1O=',@96QS('!E<FUI<V]S`%1O=',@<75A=')E
M(&-O<W1A=',`4&5R;65T(&UO;'1E<R!A9')E8V5S`$5S('!E<FUE="!L82!C
M;VYF:6=U<F%C:?,@9&5L('1I<'5S(&1E(&QL:7-T97,@;W)D96YA9&5S/P!*
M82!E>&ES=&5I>`!!8V/I<R!)35-0(&%L=&5R;F%T:74`0V]N=')A<V5N>6$@
M24U34"!A;'1E<FYA=&EV80!.;VT@9"=U<W5A<FD@24U34"!A;'1E<FYA=&EU
M`$%D<F7G82!E;&5C='+R;FEC82!A;'1E<FYA=&EV80!0;&%N=&EL;&5S(&%L
M=&5R;F%T:79E<P!497AT(&%L=&5R;F%T:74Z`%-A;6]A($%M97)I8V%N80!3
M)VAA(&5S<&5C:69I8V%T('5N('9A;&]R('!R;VAI8FET+@!3)VAA('!R;V1U
M[W0@=6X@97)R;W(@9&5S8V]N96=U="X`06YD;W)R80!!;F=O;&$`06YG=6EL
M;&$`4V5R=FED;W(@4')O>'D@86[R;FEM`%)E<W!O<W1A`$%N=.!R=&ED80!!
M;G1I9W5A(&D@0F%R8G5D80!!<&QI8V%C:?,`3&QI<W1A(&0G87!L:6-A8VEO
M;G,`3"=A<&QI8V%C:?,@Z7,@82!P=6YT+@!!<&QI8V%R(&$@<F5C=7)S;W,@
M8V]M<&%R=&ET<R!D97-C96YD96YT<RX`07!R;W9A<@!-:61A(&%P<F]X:6UA
M9&$`06)R:6P`07+@8FEC("A7:6YD;W=S+3$R-38`36ED82!D92!L)V%R>&EU
M`$YO;2!D92!L)V%R>&EU`%9O;&5U('-U<')I;6ER(&QA('-O;+=L:6-I='5D
M(&0G86QT82!A("5S/P!!<F=E;G1I;F$`07)MZ&YI80!!<FUE;FD@*$%235-#
M24DM."D`07)T`$%R=6)A`$EL;&$@9&4@;"=!<V-E;G-I\P!G<N!F:6,@05-#
M24D`4F5G:?,@9&5L(%!A8^UF:6,@87-IX'1I8P!6;VQE=2!C;VYF:7)M86-I
M\R!A8F%N<R!D)V5F96-T=6%R(&QE<R!O<&5R86-I;VYS(&1E(&UA;G1E;FEM
M96YT/P!#;VQU;6YE<R!D)V%S<VEG;F%C:?,`4R=H82!I;G1E;G1A="!S=7!R
M:6UI<B!U;B!G<G5P(&YO(&5X:7-T96YT+@!3)VAA(&EN=&5N=&%T('-U<')I
M;6ER('5N82!A=71O<FET>F%C:?,@;F\@97AI<W1E;G0N`%,G:&$@:6YT96YT
M870@961I=&%R('5N82!A=71O<FET>F%C:?,@;F\@97AI<W1E;G0N`%,G:&$@
M:6YT96YT870@961I=&%R('5N(')E8W5R<R!C;VUP87)T:70@;F\@97AI<W1E
M;G0N`$%T<FEB=71S`$%G;W-T`$%U<W1RX&QI80#`=7-T<FEA`$%U=&A?8WER
M<W%L.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS(&EM87`@;F5C97-SX')I
M82X`075T:%]C>7)U<SH@16P@;6]T;W(@;F\@=.D@;&5S(&-A<&%C:71A=',@
M;F5C97-SX')I97,N`$%U=&A?8WER=7,Z($YO(',G:&$@=')O8F%T(&PG97AT
M96YS:?,@24U!4"!N96-E<W/@<FEA+@!!=71H7V9T<#H@3F\@<R=H82!T<F]B
M870@;"=E>'1E;G-I\R!&5%`@;F5C97-SX')I82X@0V%L(&-O;7!I;&%R(%!(
M4"!A;6(@96P@8V]M;75T861O<B`M96YA8FQE+69T<"X`075T:%]I;6%P.B!.
M;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($E-05`@;F5C97-SX')I82X`075T
M:%]K<F(U.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS(&MR8C4@;F5C97-S
MX')I82X`075T:%]L9&%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($Q$
M05`@;F5C97-SX')I82X`075T:%]L9&%P.B!.;R!S)VAA('!O9W5T(&%F96=I
M<B!L)W5S=6%R:2`E<RX@06EX\B#I<R!E;"!Q=64@:&$@9&ET(&5L('-E<G9I
M9&]R.@!!=71H7VQD87`Z($YO(',G:&$@<&]G=70@<W5P<FEM:7(@;"=U<W5A
M<FD@)7,N`$%U=&]?;&1A<#H@3F\@<R=H82!P;V=U="!A8W1U86QI='IA<B!L
M)W5S=6%R:2`E<RX`075T;U]M8V%L.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N
M<VGS($U#04P@;F5C97-SX')I82X`075T:%]S;6)A=71H.B!.;R!S)VAA('1R
M;V)A="!L)V5X=&5N<VGS(%--0D%55$@@;F5C97-SX')I82X`4R=H82!P<F]D
M=>]T('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS+@!3)VAA('!R;V1U[W0@
M=6X@97)R;W(@96X@;"=A=71E;G1I8V%C:?,N("5S`$5L('-E<G9I9&]R(%)!
M1$E54R!H82!R96)U=&IA="!L)V%U=&5N=&EC86-I\RX`4R=H82!P<F]D=>]T
M('5N(&5R<F]R(&5N(&PG875T96YT:6-A8VGS(&%M8B!E;"!S97)V:61O<B!&
M5%`N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E;B!L)V%U=&5N=&EC86-I\R!A
M;6(@96P@<V5R=FED;W(@4TU"+@!#86UP<R!D:7-P;VYI8FQE<SH`07IE<F)A
M:61J86X`0D]&2"!%>&-U<V5S`$9O;G,`0V]L;W(@9&5L(&9O;G,`0V]N=')A
M<V5N>6$@2V5R8F5R;W,@:6YC;W)R96-T82X`3F]M(&0G=7-U87)I($ME<F)E
M<F]S(&EN8V]R<F5C=&4N`$)A:&%M97,`0F%H<F%I;@!"X&QT:6,@*$E33RTX
M.#4Y+3$S*0!"86YG;&$@1&5S:`!"87)B861O<P!,[6YI82!B87-E`$)I96QO
M<G+Z<VEA`$+H;&=I8V$`0F5L:7IE`$)E;NUN`$)E<FUU9&5S`$)H=71A;@!!
M;FEV97)S87)I`$YO(',G:&$@=')O8F%T(&5L(&)L;V,@(B5S(B!D92!L)V%P
M;&EC86-I\R`B)7,B("X`4&%RX&UE=')E<R!D96P@8FQO8P!4:7!U<R!D92!B
M;&]C`$YE9W)E=&$`0F]L[79I80!-87)C861O<G,`0V]N=&]R;@!'<G5I>"!D
M96P@8V]N=&]R;@!#;VYT;W)N<P!"\G-N:6$@:2!(97)C96=O=FEN80!!;6)D
M\W,`0F]T<W=A;F$`26YF97)I;W(`26QL82!D92!";W5V970`0G)A<VEL`%1E
M<G)I=&]R:2!O8V7@;FEC(&1E(&PGS6YD:6$@8G)I=.!N:6-A`$)R=6YE:2!$
M87)U<W-A;&%M`$-O;G1R=6EN="!F:71X97)S($U/('!E<B!A;"!M\F1U;"`E
M<RXN+@!#;VYS=')U:6YT("5S+BXN`$)U;&?@<FEA`$QL:7-T82!D92!P:6-S
M`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$--4P!#4D,`4'5N=',@9&4@9&ES=')I
M8G5C:?,@9&4@0U),`%!R;W!I971A=',@9&4@8V5LMVQA+BXN`$YO(',G:&$@
M9FEN86QI='IA="!E;"!P<F]CZ7,@9"=I;FEC:6%L:71Z86-I\R!D92!L82!M
M96WR<FEA(&-A=0!#86QE;F1A<FD`0V%L;6$`0V%M8F]D:F$`0V%M97)U;@#)
M<R!I;7!O<W-I8FQE(')E:6YI8VEA<B!L82!C;VYT<F%S96YY82!A=71O;>!T
M:6-A;65N="P@<&]S82=T(&5N(&-O;G1A8W1E(&%M8B!L)V%D;6EN:7-T<F%D
M;W(@9&5L('-I<W1E;6$N`,ES(&EM<&]S<VEB;&4@8V]N;F5C=&%R(&%M8B!E
M;"!S97)V:61O<B!)34%0.B`E<RX`0V%N863@`$-A;F-E;+=L87(`0V%N8V5L
MMVQA<B!L)VEN9F]R;64@9&4@<')O8FQE;65S+@!.;R!E<R!P;W0@97-B;W)R
M87(@;"=A<GAI=2`B)7,B+@!.;R!E<R!P;W0@=')O8F%R('5N(&1I<F5C=&]R
M:2!T96UP;W)A;"X`3F\@97,@<&]T(&-O;G1I;G5A<B!S96YS92!E;"!P87+@
M;65T<F4@)W1A<F=E=$9I;&4G+@!.;R!E<R!P;W0@97-B;W)R87(@96P@9&ER
M96-T;W)I("(E<R(N`$YO(&5S('!O="!E<V)O<G)A<BP@8V]N=.D@9&5S8V5N
M9&5N=',@)60N(`!.;R!E<R!P;W0@<F5O<F1E;F%R+"!E;"!N;VUB<F4@9"=E
M;G1R861E<R!Q=64@<R=H86X@9&4@<F5O<F1E;F%R(&YO(&-O:6YC:61E:7@@
M86UB(&QE<R!Q=64@:&D@:&$@96UM86=A='IE;6%D97,N`$YO(&5S('!O="!A
M9')EYV%R(&5L(&UI<W-A=&=E(&%L(&YO;6)R92!E<W!E8VEF:6-A="X`0V%P
M(%9E<F0`3&QE9V5N9&$`0V%T96=O<FEE<R!I(&5T:7%U971E<P!);&QE<R!#
M86EM86X`5&5LZ&9O;B!M\F)I;`!0<F]P:65T871S(&1E(&-E;+=L80!&87)C
M:6UE;G0@9&4@8V5LMVQA`%!R;W!I971A=',@9&4@;&$@8V5LMVQA`$5S<&%I
M870@96YT<F4@8V5LMVQE<P!496SH9F]N(&WR8FEL`$/H;'1I8R`H25-/+3@X
M-3DM,30I`$-E;G1R87(`4F5P^F)L:6-A($-E;G1R96%F<FEC86YA`$5U<F]P
M82!C96YT<F%L("A)4T\M.#@U.2TR*0!$971A;&QS(&1E;"!C97)T:69I8V%T
M`%1I='5L87(@9&5L(&-E<G1I9FEC870`4&]L[71I<75E<R!D92!C97)T:69I
M8V%C:?,`5'AA9`!$97-FZ7,`0V%N=FEE=2!E;"!N;VT@:2!L)V%D<F7G82!Q
M=64@<_-N('9I<VEB;&5S('%U86X@97,@;&QE9V5I>&5N(&\@97,@<F5S<&]N
M96X@96QS('9O<W1R97,@;6ES<V%T9V5S(&1E(&-O<G)E=2!E;&5C='+R;FEC
M+@!#:&%R`%9E<FEF:6-A(&PG96YL;&'G+BXN`%AI;&4`6&EN80!8:6[H<R!S
M:6UP;&EF:6-A="`H1T(R,S$R*0!8:6[H<R!T<F%D:6-I;VYA;"`H0FEG-2D`
M5')I82!U;F$@8V]N=')A<V5N>6$`5')I82!U;B!N;VT@9"=U<W5A<FD`5')I
M82!C;VT@=F]L<R!V:7-U86QI='IA<B!L97,@9&%T97,Z`%1R:6$@=6X@=&EP
M=7,@9"=E<W1I;"!D92!L;&ES=&$@*'!E<B!A(&QL:7-T97,@;W)D96YA9&5S
M*0!);&QA(&1E($-H<FES=&UA<P!.;R!S)VAA('1R;V)A="!L82!D969I;FEC
M:?,@9&4@8VQA<W-E(&1E("`E<RX`16QI;6EN87(`16QI;6EN82!L97,@971I
M<75E=&5S(&1E($U33V9F:6-E`$5S8F]R<F$@;"=U<W5A<FDZ("5S`$5S8F]R
M<F$@;"=U<W5A<FD`17-B;W)R82!L97,@9&%D97,@9&4@;"=U<W5A<FD`4R=A
M8VQA<FERX"!C87`@86P@=&%R9"X`4')E;6D@<&5R(&-O;G1I;G5A<@!#;&EC
M:V%T96QL('!E<B!(5%10`%1A;F-A(&QA(&9I;F5S=')A`$[Z=F]L<P!.^G9O
M;',@82!P<FEM97)A(&AO<F$`16YN=79O;&%T`$EL;&5S(&1E($-O8V]S("A+
M965L:6YG*0!2961U[W4@;&$@8F%R<F$@;&%T97)A;`!-87)G97,@<F5D=>]T
M<P!#;VSR;6)I80!#;VQO<@!396QE8W1O<B!D92!C;VQO<@!396QE8V-I\R!D
M92!C;VQO<@!#;VQU;6YE<SH`5.UT;VQS(&1E(&QE<R!C;VQU;6YE<P!#\FUI
M8W,`3W)D<F4`0V]N<V]L80!#;VUE;G1A<FD`3F]M(&-O;?H`0V]M;W)E<P!#
M;VUP86YY:6$`17-C<FEU(&5L(&UI<W-A=&=E("@E<RD`3W)D:6YA9&]R<P!#
M;VYD:6-I;VYS`$1I9F5RZ&YC:65S(&1E(&-O;F9I9W5R86-I\P!,82!C;VYF
M:6=U<F%C:?,@;F\@97-TX"!A8W1U86QI='IA9&$N`$-O;F9I9W5R82`E<P!#
M;VYF:7)M87(@;&$@8V]N=')A<V5N>6$`0V]N9V\`0V]N9V\L(%)E</IB;&EC
M82!$96UO8W+@=&EC82!D96P`3F\@Z7,@<&]S<VEB;&4@<F5A;&ET>F%R(&QA
M(&-O;FYE>&GS+@!.;R#I<R!P;W-S:6)L92!R96%L:71Z87(@;&$@8V]N;F5X
M:?,Z`%,G:&$@<F5B=71J870@;&$@8V]N;F5X:?,@86P@<V5R=FED;W(@9&4@
M8VQA=7,@</IB;&EQ=65S+@!3)VAA(')E8G5T:F%T(&QA(&-O;FYE>&GS(&%L
M('-E<G9I9&]R(&1E(&-L875S('#Z8FQI<75E<RX@4F'S.B`E<R`H)7,I`$YO
M(.ES('!O<W-I8FQE(')E86QI='IA<B!L82!C;VYN97AI\R!A;"!S97)V:61O
M<B!&5%`N`$5L<R!C;VYT86-T97,@<R=H86X@869E9VET(&-O<G)E8W1A;65N
M="!A(&QA('1E=F$@;&QI8G)E=&$@9"=A9')E8V5S+@!#;VYT:6YU87(`26QL
M97,@0V]O:P!'86QE=&$`0V]P:6%R`,ES(&EM<&]S<VEB;&4@8V]P:6%R.B`E
M<P!#;W!I87(@<V5L96-C:?,`0V]S=&$@4FEC80!#;W-T82!D)TEV;W)I`$YO
M(&5S('!O="!X:69R87(@96P@;6ES<V%T9V4@86UB(%,O34E-12X`3F\@97,@
M<&]T('-I9VYA<B!E;"!M:7-S871G92!A;6(@4R]-24U%+@!.;R!E<R!P;W0@
M869E9VER(&5L(&-O;G1A8W1E+B`E<P!.;R!E<R!P;W0@8V]N;F5C=&%R(&%M
M8B!E;"!S97)V:61O<B!,1$%0+@!.;R!E<R!P;W0@8V]M<')O=F%R(&5L('-A
M;&1O+B`E<P!.;R!S)VAA('!O9W5T(&-R96%R('5N82!L;&ES=&$@9&4@9&ES
M=')I8G5C:?,N("5S`$YO(',G:&$@<&]G=70@9&5S>&EF<F%R(&QE<R!D861E
M<R!3+TU)344N`$YO(',G:&$@<&]G=70@97-B;W)R87(@96P@8V]N=&%C=&4N
M("5S`$YO(',G:&$@<&]G=70@97-B;W)R87(@;&$@;&QI<W1A(&1E(&1I<W1R
M:6)U8VGS+B`E<P!.;R!S)VAA('!O9W5T(&1E=&5R;6EN87(@;"=A9')EYV$@
M96QE8W1R\FYI8V$@9&5L(&1E<W1I;F%T87)I+@!.;R!S)VAA('!O9W5T(')E
M8V]L;&ER('1O=&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S+@!.;R!S)VAA('!O
M9W5T(')E8V]L;&ER('1O=&$@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+@!.
M;R!S)VAA('!O9W5T(')E8V]L;&ER('1O=&$@;&$@;&QI<W1A(&1E(&QE<R!L
M;&ES=&5S(&1E(&1I<W1R:6)U8VGS+@!.;R!S)VAA('!O9W5T(&]B=&5N:7(@
M=6YA(&-L874@</IB;&EC82!D96P@<V5R=FED;W(@9&4@8VQA=7,N`$YO(',G
M:&$@<&]G=70@;V)R:7(@)7,N`$YO(',G:&$@<&]G=70@;V)R:7(@96P@;?)D
M=6P@9&4@=&%S<75E<R!D92!M86YT96YI;65N="`E<RX`3F\@<R=H82!P;V=U
M="!L;&5G:7(@)7,N`$YO(',G:&$@<&]G=70@<F5I;FEC:6%R(&QA(&-O;G1R
M87-E;GEA('!E<B!A(&PG=7-U87)I('-O;+=L:6-I=&%T+B!!;&=U;G,@9&5T
M86QL<R!O('1O=',@;F\@<_-N(&-O<G)E8W1E<RX@5&]R;F%R+6AO(&$@:6YT
M96YT87(@;RP@<&5R(&$@;>ES(&EN9F]R;6%C:?,L('!O<V$G="!E;B!C;VYT
M86-T92!A;6(@;"=A9&UI;FES=')A9&]R(&1E;"!S:7-T96UA+@!.;R!S)VAA
M('!O9W5T(')E8W5P97)A<B!L97,@04-,`$YO(',G:&$@<&]G=70@<F5C=7!E
M<F%R(&QA(&QL:6)R971A(&0G861R96-E<RX@)7,`3F\@<R=H82!P;V=U="!R
M96-U<&5R87(@;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<P!.;R!S)VAA
M('!O9W5T(')E8W5P97)A<B!L97,@;&QI<W1E<R!D92!D:7-T<FEB=6-I\RX@
M)7,`3F\@<R=H82!P;V=U="!R96-U<&5R87(@;&5S('!O<W-I8FEL:71A=',@
M9&5L('-E<G9I9&]R`$YO(',G:&$@<&]G=70@<F5S=&%U<F%R(&QA(&-O;F9I
M9W5R86-I\RX`3F\@<R=H82!P;V=U="!D97-A<B!L82!C;VYF:6=U<F%C:?,@
M)7,N`$YO(',G:&$@<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I\R!D92!S
M96=U<F5T870N`$YO(',G:&$@<&]G=70@9&5S87(@=6YA(&-O;F9I9W5R86-I
M\R!D92!S96=U<F5T870Z("5S`$YO(',G:&$@<&]G=70@9&5S87(@;&$@8_)P
M:6$@9&4@<V5G=7)E=&%T(&1E(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS("5S
M+@!.;R!S)VAA('!O9W5T(&1E<V%R(&PG87)X:74@9&4@8V]N9FEG=7)A8VGS
M("5S+B!0;W1S('5T:6QI='IA<B!U;F$@9&4@;&5S(&]P8VEO;G,@<&5R('1O
M<FYA<B!A(&1E<V%R(&5L(&-O9&D@96X@)7,@;R!BZ2!C;W!I87(@;6%N=6%L
M;65N="!E;"!C;V1I('-E9_QE;G0@96X@)7,N`$YO(',G:&$@<&]G=70@8V5R
M8V%R(&%L('-E<G9I9&]R($Q$05`N`$YO(',G:&$@<&]G=70@86-T=6%L:71Z
M87(@96P@8V]N=&%C=&4N("5S`$YO(',G:&$@<&]G=70@86-T=6%L:71Z87(@
M;&$@;&QI<W1A(&1E(&1I<W1R:6)U8VGS+B`E<P!.;R!S)VAA('!O9W5T(&QO
M8V%L:71Z87(@;&$@8F%R<F$@;&%T97)A;"!D92!-;WII;&QA+B!#;VUP<F]V
M82!Q=64@;&$@8F%R<F$@;&%T97)A;"!E<W1I9W5I(&]B97)T82X`5&5X="!C
M;VUP=&%T`%!A[7,`0W5R<V]S`$-R96%R`$-R96%R('5N(&5N;&QAYP!#<F5A
M<BUN92!U;B!D92!N;W4`0W)E87(@<W5B8V%R<&5T97,`4&5R;6ES;W,@9&5L
M(&-R96%D;W(`3OIM97)O(&1E(&QA('1A<F=E=&$@9&4@8W+H9&ET`$-R;^!C
M:6$`0W5B80`T(&9A<V5S(&%C='5A;',`5&5M<',@86-T=6%L`$5L(%523"!A
M8W1U86P@Z7,`5&5M<',@86-T=6%L`$-O;F1I8VGS(&%C='5A;#H`17-T:6P@
M86-T=6%L`%!E<G-O;F%L:71Z974@;&5S('1A<W%U97,@<75E(',G:&%N(&5X
M96-U=&%R('%U86X@<R=I;FEC:6$@;&$@<V5S<VGS(&$@)7,N`%)E=&%L;&%R
M`%)E=&%L;&%R(&QA('-E;&5C8VGS`%AI<')E`$-I<NULMVQI8R`H2T])."U2
M*0!#:7+M;+=L:6,@*%=I;F1O=W,M,3(U,2D`0VER[6RW;&EC+U5C<F'O;NAS
M("A+3TDX+54I`%)E</IB;&EC82!4>&5C80!$1`!$:>!R:6%M96YT`$YA=F5G
M861O<B!D92!$871A5')E90!$871A`%,G:&$@<F5B=70@;&$@9&%T80!396QE
M8V-I\R!D92!D871A`$1I80!3=7!R:6UI<B!C;VQU;6YA`$1E<V5M8G)E`$YO
M;6)R97,@9&5C:6UA;',`4F5D=>]U(&5L('-A9VYA=`!0<F5D971E<FUI;F%T
M`$-O;&]R('!R961E=&5R;6EN870`261E;G1I=&%T('!R961E=&5R;6EN861A
M`$1E9FEN:6-I;VYS`%-U<')I;6ER`%-U<')I;6ER(&=R=7``4W5P<FEM:7(@
M<&5R;>US`%-U<')I;6ER(&D@8G5I9&%R(&UI<W-A=&=E<P!3=7!R:6UI<B!C
M96RW;&$`4W5P<FEM:7(@8V]L=6UN80!3=7!R:6UI<B!L82!P;&%N=&EL;&$@
M86QT97)N871I=F$@97AI<W1E;G0`4W5P<FEM:7(@9FEL80!3=7!R:6UI<B!L
M82!I9&5N=&ET870@<V5L96-C:6]N861A`%-U<')I;6ER(&QA(&-O;'5M;F$@
M86-T=6%L`%-U<')I;6ER(&QA(&9I;&$@86-T=6%L`$AO<F$@9&4@;&QI=7)A
M;65N=`!$:6YA;6%R8V$`1&5S8W)I=FEU(&5L('!R;V)L96UA`$1E<V-R:7!C
M:?,`1&5T86QL<R`H=&%M8ND@86P@9FET>&5R(&1E(')E9VES=')E(&1E($AO
M<F1E*3H`16QS(&1E=&%L;',@:&%N(&5S=&%T(')E9VES=')A=',@<&5R(&$@
M;"=A9&UI;FES=')A9&]R+@!$97-E;G9O;'5P86UE;G0`4'5N="!D92!R;W-A
M9&$`4'5N="!D92!R;W-A9&$@9&4@;&$@9&%R<F5R82!H;W)A.@!0=6YT(&1E
M(')O<V%D83H@`$0G97-Q=65R<F$@82!D<F5T80!$92!D<F5T82!A(&5S<75E
M<G)A`$1I<F5C=&]R:0!6;VQS('9I<W5A;&ET>F%R+6AO(&5N(&9O<FUA="!D
M92`R-"!H;W)E<S\`3W!C:6]N<R!D92!V:7-U86QI='IA8VGS`$UO<W1R82!L
M82!P<F5V:7-I\R`H5$%&*0!&;W)M870@9&4@=FES=6%L:71Z86-I\P!.;W1I
M9FEC86-I\R!D92!R96-E<&-I\P!$:FEB;W5T:0!.;R!H;R!S=7!R:6UI=0!.
M;R!A8V-E9&EU(&1I<F5C=&%M96YT(&$@;6%I;G1E;F%N8V4N<&AP`$QA('!R
M:6UE<F$@9FEL82!C;VYTZ2!E;',@;F]M<R!D96QS(&-A;7!S/R!%;B!C87,@
M869I<FUA=&EU+"!A8W1I=F$@87%U97-T82!C87-E;&QA.@!$;VUI;FEC80!2
M97#Z8FQI8V$@1&]M:6YI8V%N80!$97-C87)R96=A<@!$97-C87)R96=A<B`E
M<P!$97-C87)R96=A<B!L82!C;VYF:6=U<F%C:?,@9V5N97)A9&$@8V]M('5N
M82!S97'\Z&YC:6$@4$A0+@!,;&ES=&$@9&5S<&QE9V%B;&4`1')O9W5E<P!#
M;W)R974@96QE8W1R\FYI8P!%4E(`17%U861O<@!%9&ET80!%9&ET82!B;&]C
M`$5D:71A(&=R=7``161I=&$@<&5R;>US`$5D:71A('!E<FUI<V]S`$5D:71A
M('!E<FUI<V]S(&1E("5S`$5D:71A(&]P8VEO;G,@9&4Z`$5D:71A('!E<FUI
M<V]S(&1E("5S`$5D=6-A8VGS`$5G:7!T90!%;"!386QV861O<@!%;&5M96YT
M+BXN`%%U861R873M`$-O<G)E=2!E;&5C='+R;FEC`$%D<F7G82!E;&5C='+R
M;FEC80!,97,@861R96-E<R!E;&5C='+R;FEQ=65S(&AA;B!D92!C;VEN8VED
M:7(N`$-O<G)E=2!E;&5C='+R;FEC(&%M8B!C;VYF:7)M86-I\P!%;6]T:6-O
M;F5S`$UI<W-A=&=E(&5N(&)L86YC+@!297-U;'1A="!E;B!B;&%N8RX`0G5I
M9&%R(&5L<R!T97)M97,@9&4@8V5R8V$`2&%B:6QI=&%R(&QA(&EN<V5R8VGS
M(&1E(&EM871G97,@9&4@;&5S(&=A;&5R:65S(&1E(&9O=&]S(&5N(&5L('1E
M>'0_`$AA8FEL:71A<B!E;"!M96[Z(&1E(&-O;G1E>'0@8VQI8V%N="!E;B!E
M;"!B;W3S(&1R970_`$%N>2!D92!F:6YA;&ET>F%C:?,`06UP;&EA<B!L)V5D
M:71O<@!);G1R;V1U[W4@=6YA('!R96=U;G1A(&1E('-E9W5R971A="!Q=64@
M<V4@=7,@9F]R;75L87+@('-I('5S(&-A;"!R96EN:6-I87(@;&$@8V]N=')A
M<V5N>6$L('!E<B!E>&5M<&QE("=C;VT@97,@9&EU(&5L('9O<W1R92!A;FEM
M86P@9&4@8V]M<&%N>6EA/R<Z`$EN=')O9'7O=2!A<77M(&5L(%523"!D92!L
M82!I;6%T9V4`1W5I;F5A($5Q=6%T;W)I86P`17)I=')E80!%<G)O<@!(:2!H
M82!H86=U="!U;B!E<G)O<B!A;6(@96P@;6ES<V%T9V4@96QE8W1R\FYI8RX`
M17-T\FYI80!%=&GR<&EA`,AT;FEC`$5U<F]P80!#861A(#$U(&UI;G5T<P!#
M861A(#(@;6EN=71S`$-A9&$@,S`@<V5G;VYS`$-A9&$@-2!M:6YU=',`0V%D
M82!I;FEC:2!D92!S97-S:?,`0V%D82!M:71J82!H;W)A`$-A9&$@;6EN=70`
M5F%L;W)S(&0G97AE;7!L93H`17AE8W5T80!%>'!A;F1E:7@`17AP86YD:7(@
M;&$@8F%R<F$@;&%T97)A;`!3)V5S<&5R879A("<I)P!3)V5S<&5R879A('5N
M('-O;"!M;W0@;R!U;B!T97)M92!D92!C97)C82!C:71A=`!$871A(&1E('9E
M;F-I;65N=`!%>'!O;F5N=`!#;VQO<B!D92!P<FEM97(@<&QA`$/@<G)E9V$@
M9&4@;&$@8V]N9FEG=7)A8VGS(&1E;"!&5%``R7,@:6UP;W-S:6)L92!R96-U
M<&5R87(@;&5S('!R969E<NAN8VEE<RX`R7,@:6UP;W-S:6)L92!C;VYN96-T
M87(@86UB(&5L('-E<G9I9&]R($Q$05`N`,ES(&EM<&]S<VEB;&4@8V]N;F5C
M=&%R(&%M8B!E;"!S97)V:61O<B!334(N`,ES(&EM<&]S<VEB;&4@8V]P:6%R
M(&1E("(E<R(N`,ES(&EM<&]S<VEB;&4@8V]P:6%R(&$@(B5S(BX`R7,@:6UP
M;W-S:6)L92!C<F5A<B!U;F$@;F]V82!C;VYN97AI\R!305-,+@#)<R!I;7!O
M<W-I8FQE('1R86YS9F5R:7(@82`B)7,B+@#)<R!I;7!O<W-I8FQE(')E8W5P
M97)A<CH@)7,`0VQA<@!);&QE<R!&86QK;&%N9"`H36%L=FEN97,I`$EL;&5S
M($;H<F]E`$5R<F]R(&ER<F5C=7!E<F%B;&4@`$9A>`!&96)R97(`4V4@<V5N
M="!C;VT`4V4@<V5N="!C;VTZ`%!O<75E<R!P;'5G97,`4&]C<R!XX&9E8W,@
M9&4@;F5U`$UA=')I=2!D96P@8V%M<`!&:6II`%)E8V]M<'1E(&0G87)X:75S
M.B!A<GAI=2`E<P!296-O;7!T92!D)V%R>&EU<SH@)7,@87)X:75S`$=E<W1O
M<B!D)V%R>&EU<P!.;VT@9&4@;"=A<GAI=0!396QE8V-I\R!D)V%R>&EU<P!#
MX')R96=A(&1E(&PG87)X:74`3F\@Z7,@<&5R;>AS('!E;FIA<B!A<GAI=7,`
M1FEL=')E<P!&:6YLX&YD:6$`4')I;65R82!M96ET870`4')I;65R('%U87)T
M`%)A\R!F:7AA(R,`26YV97)T:74`0V]M82!F;&]T86YT`$)O:7)A`$QA(&-A
M<G!E=&$@)7,@;F\@97AI<W1E:7@`0V]L;W(@9&4@;&$@9F]N=`!-96YJ87(`
M4&5R(&%L<R!N879E9V%D;W)S('%U92!N;R!A9&UE=&5N(&QE<R!I;6%T9V5S
M`%!R979I<VGS("A4048I`%!R979I<VGS('!E<B!A;',@9&EE<R`H=&EN9W5E
M=2!P<F5S96YT('%U92!L82!P<F5V:7-I\R!F86-I;&ET861A(&-O;7!RZ&X@
M96P@9&EA(&D@;&$@;FET.B!U;B!N;VUB<F4@96QE=F%T('!O9')I82!T96YI
M<B!C;VT@82!R97-U;'1A="!U;B!B;&]C(&%M<&QE+@!(974@;V)L:61A="!L
M82!C;VYT<F%S96YY83\`1F]R;75L87)I<P!$:71A`%1I<'5S(&1E(&1I=&5S
M`$1I=&5S`$1I=&5S(#(`1O)R=6US`%)E96YV:6%M96YT<P!$=BX`36%R8W,`
M1G)A;N=A`$9R86[G82!M971R;W!O;&ET86YA`$=U86EA;F$@1G)A;F-E<V$`
M4&]L:6[H<VEA($9R86YC97-A`%1E<G)I=&]R:7,@1G)A;F-E<V]S(&1E;"!3
M=60`1&5S(&1E`$1E<R!D96P`1&5S8W)I<&-I\R!C;VUP;&5T80!,;'5N82!P
M;&5N80!.;VT@8V]M<&QE=`!'86)O;@!,82!G86QE<FEA(&1E(&QA('%U86P@
M<R=E>'1R974@;&$@:6UA=&=E`$=A;&5R:6$`1^!M8FEA`$5S(&=E;F5R82!L
M82!C;VYF:6=U<F%C:?,@)7,`0V]D:2!G96YE<F%T`$=E\G)G:6$`06QE;6%N
M>6$`1VAA;F$`1VEB<F%L=&%R`$YO;2!D92!P:6QA`$%N87(@80!']F1E;`!#
M97)C82!A;"!';V]G;&4`17-C86QA(&1E(&=R:7-O<P!'<NAC:6$`1W)E8R`H
M25-/+3@X-3DM-RD`1W)E;FS@;F1I80!'<F%N861A`$=E<W1I\R!D92!G<G5P
M<P!%;',@;F]M<R!D92!G<G5P(&YO(&5S('!O9&5N(&1E:7AA<B!E;B!B;&%N
M8P!'<G5P<P!'=6%D86QU<&4`1W5A;0!'=6%T96UA;&$`1W5E<FYS97D`4&5R
M;6ES;W,@9&5L<R!V:7-I=&%N=',`3&QI8G)E(&1E('9I<VET86YT<P!'=6EN
M96$`1W5I;F5A($)I<W-A=0!'=7EA;F$`2%1-3`!(5$U,07)E82!N;R!P97)M
M970@<W5P<FEM:7(@;&$@9&%R<F5R82!C96RW;&$@9&4@;&$@9FEL82X`2%1-
M3$%R96$@;F\@<&5R;65T('-U<')I;6ER(&QA(&1A<G)E<F$@8V]L=6UN82!D
M92!L82!T875L82X`2%1-3$%R96$@;F\@<&5R;65T('-U<')I;6ER(&QA(&1A
M<G)E<F$@9FEL82!D92!L82!T875L82X`3F\@<R=H82!T<F]B870@;"=A=71E
M;G1I8V%C:?,@2%144"X`2&%I=.T`06QG;W)I<VUE(&1E(&AA<V@`0V%L:71J
M80!#87#G86QE<F$`26QL82!(96%R9"!I(&EL;&5S($UC1&]N86QD`$AE8G)E
M=2`H25-/+3@X-3DM."U)*0!!;.=A9&$`06IU9&$`06IU9&$@<&5R('5T:6QI
M='IA<B!L)V5D:71O<@!!<&QI8V%C:?,@9"=A:G5D80!(96UI<V9E<FD`07%U
M97-T(.ES(&PG:6YI8VD@9&5L(&9I='AE<CH`06QT`$EN:6-I`&QA(%-A;G1A
M(%-E=2`H0VEU=&%T($5S=&%T(&1E;"!6871I8^`I`$EN:6-I`$%D<F7G82!P
M87)T:6-U;&%R`%1E;.AF;VX@<&%R=&EC=6QA<@!(;VYD=7)E<P!(;VYG($MO
M;F<`2&]R9&4`2&]R9&4O2V]L86(Z(%,G:&%N('1R;V)A="!D861E<R!834P@
M)7,@;F\@=N!L:61E<R!E;B!E;"!M:7-S871G92`E<P!(;W)D92]+;VQA8CH@
M3F\@:&D@:&$@8V%P(&UI<W-A=&=E('%U92!E<R!C;W)R97-P;VYG=6D@86UB
M(&PG;V)J96-T92`E<P!(;W)D92]+;VQA8CH@3F\@<R=H82!T<F]B870@8V%P
M(&]B:F5C=&4@9&5L('1I<'5S("5S(&5N(&5L(&UI<W-A=&=E("5S`$AO<F1E
M+TMO;&%B.B`E<R`B)7,B(&AA(&5S=&%T(&5X=')E="!C;W)R96-T86UE;G0`
M2&]R9&4O2V]L86(Z($5L(&UO=&]R(&0G:6YT96=R86-I\R!N96-E<W-I=&$@
M;"=E>'1E;G-I\R!02%`@)V1O;7AM;"<`2&]R9&4O2V]L86(Z($YO(',G:&$@
M<&]G=70@8W)E87(@=6X@;F]U(&%R8G)E(%A-3"!P97(@82!L)V]B:F5C=&4@
M)7,`2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@97AT<F5U<F4@)7,@(B5S
M(CH@)7,`2&]R9&4O2V]L86(Z($YO(',G:&$@<&]G=70@<F5C=7!E<F%R(&PG
M:61E;G1I9FEC861O<B!-24U%('!E<B!A(&QA('!A<G0@9&5L('1I<'5S("5S
M`$AO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA<B`E<R(E
M<R(Z("5S`$AO<F1E+TMO;&%B.B!.;R!S)VAA('!O9W5T('-I;F-R;VYI='IA
M<B!L97,@<75O=&5S.B`E<P!(;W)D92]+;VQA8CH@17-P86D@9&ES<&]N:6)L
M92!D97-C;VYE9W5T("(E<R(`4F5G;&$@:&]R:71Z;VYT86P`1F%R8VEM96YT
M(&AO<FET>F]N=&%L`$AO<FET>F]N=&%L.@!#;VT@:&5U(&%R<FEB870@9FEN
M<R!A<77M/R`H1F5U+6YO<RUH;R!S86)E<B$I`%%U86YT97,@8V]L=6UN97,@
M=F]L974@<F5F;VYD<F4_`%%U86YT<R!C86UP<R`H8V]L=6UN97,I(&AI(&AA
M/P!1=6%N=&5S(&9I;&5S('9O;&5U(')E9F]N9')E/P!(=6UI=&%T`$AU;6ET
M870Z`$AU;6]R:7-T97,`2&]N9W)I80#)<R!I;7!O<W-I8FQE(&-R96%R(&QA
M(&+Z<W1I82!)34%0.B`E<P#)<R!I;7!O<W-I8FQE('-U<')I;6ER(&QA(&+Z
M<W1I82!)34%0.B`E<P#)<R!I;7!O<W-I8FQE(&-R96%R('5N(&5S<&%I(&1I
M<W!O;FEB;&4@<&5R(&$@;&$@8OIS=&EA($E-05`Z("5S`$%D<F7G82!)4`!,
M)V%D<F7G82!)4"!N;R!E<W3@(&1I<W!O;FEB;&4N`$PG861R9>=A($E0(&YO
M(&5S('1R;V)A(&5N(&5L(&)L;V,@0TE$4B!P97)MZ',N`%9I;VQA8VGS(&1E
M;"!B;&]Q=65I9R!)4"X`26YS97)I=2!U;F$@9FEL82!D86UU;G0`27-LX&YD
M:6$`3F]MZ7,@:6-O;F5S`$EC;VYE<R!D92`E<P!)8V]N97,@86UB('1E>'0`
M3F]M(&0G:61E;G1I=&%T.@!3:2!N;R!E<R!V:7-U86QI='IA(&-O<G)E8W1A
M;65N="P@;V)R:74@)7,@96X@=6YA(&YO=F$@9FEN97-T<F$N`%-I(&YO('9I
M<W5A;&ET>F5U(&-A<"!I8V]N82!M:71J86[G86YT(&PG26YT97)N970@17AP
M;&]R97(L(.ES('!O<W-I8FQE('%U92!HX&=I=2!D)V%C=&EV87(@87%U97-T
M('%U861R92!P97(@9&5S86-T:79A<B!L82!T<F%N<W!A<NAN8VEA(&1E(%!.
M1RX`4VD@=F5I974@87%U97-T(&UI<W-A=&=E(&5N(&QL;V,@9&4@;&$@:6UA
M=&=E+"!E;"!V;W-T<F4@;F%V96=A9&]R(&YO('!O="!M;W-T<F%R(&QA(&EM
M871G92!Q=64@=F]L974@<&5N:F%R+@!6:7-U86QI='IA8VGS('!RZ'9I82!D
M92!L82!I;6%T9V4Z`%523"!D92!L82!I;6%T9V4`55),(&1E(&QA(&EM871G
M93H`26UA=&=E(&1E(&QA(&=A;&5R:6$`26UA=&=E(&1E(&QA(&=A;&5R:6$Z
M`$/@<G)E9V$@9&4@;&$@:6UA=&=E`$EM871G97,`26UP;W)T86-I\RP@<&%S
M("5D`$-A;7`@:6UP;W)T870Z("5S`$-A;7!S(&EM<&]R=&%T<SH`26YS97)I
M=2!U;F$@9FEL82!A('-O=&$`16P@8V]D:2!D92!L)V%C8VGS('%U92!S)VAA
M(&9A8VEL:71A="#I<R!I;F-O<G)E8W1E+@!.;VT@9"=U<W5A<FD@:2]O(&-O
M;G1R87-E;GEE<R!I;F-O<G)E8W1E<RX`4R=H82!F86-I;&ET870@=6X@;F]M
M(&0G=7-U87)I(&\@=6YA(&%D<F7G82!A;'1E<FYA=&EV82!I;F-O<G)E8W1E
M<RX@5&]R;F5U+6AO(&$@:6YT96YT87(@;R!P;W-E=2UV;W,@96X@8V]N=&%C
M=&4@86UB(&PG861M:6YI<W1R861O<B!P97(@82!MZ7,@86IU9&$N`$%U9VUE
M;G1A<B!E;"!S86=N870`S6YD:6$`57-U87)I<R!I;F1I=FED=6%L<P!);F1O
M;NAS:6$`26YF;W)M86-I\P!);F9O<FUA8VGS`$EN:6-I86QI='IA;G0@;?)D
M=6P@)7,N+BX@`$EN<V5R96EX('5N82!C;VQU;6YA(&$@<V]T80!);G-E<F5I
M>"!U;F$@:6UA=&=E`$EN<V5R96EX('5N82!T875L80!);G-E<F5I>"!E;FQL
M8><@=V5B`$EN<V5R96EX(&QA(&-O;'5M;F$@9&%M=6YT`$EN<V5R96EX('5N
M82!N;W9A(&-O;'5M;F$@82!S;W1A(&1E(&PG86-T=6%L`$EN<V5R96EX('5N
M82!N;W9A(&-O;'5M;F$@82!S;V)R92!D92!L)V%C='5A;`!);G-E<F5I>"!U
M;F$@;F]V82!F:6QA(&$@<V]T82!D92!L)V%C='5A;`!);G-E<F5I>"!U;F$@
M;F]V82!F:6QA(&$@<V]B<F4@9&4@;"=A8W1U86P@`$EN<V5R96EX('5N('!A
M<N!G<F%F(&$@<V]T82!D96P@;F]D92!A8W1U86P`26YS97)E:7@@=6X@<&%R
MX&=R868@82!S;V)R92!D96P@;F]D92!A8W1U86P`26YS97)E:7@@;"=A;'1R
M82!P;&%N=&EL;&$`26YS97)E:7@@=6YA(&%D<F7G82!D92!C;W)R974@<&5R
M(')E8G)E(&QA(&YO=F$@8V]N=')A<V5N>6%);G-E<FEU('5N82!A9')EYV$@
M96QE8W1R\FYI8V$@82!L82!Q=6%L('!O9&5U(')E8G)E(&QA(&YO=F$@8V]N
M=')A<V5N>6$Z`$EN<V5R96EX('5N82!C96RW;&$@82!S;W1A`$EN<V5R96EX
M('5N82!C96RW;&$@82!S;V)R90!);G-E<FEU('5N82!C;VQU;6YA(&$@<V]T
M80!);G-E<FEU('5N82!C;VQU;6YA(&$@<V]B<F4`26YS97)I=2!M:7-S871G
M97,`26YS97)I=2!U;B!P87+@9W)A9B!A('-O=&$`26YS97)I=2!U;B!P87+@
M9W)A9B!A('-O8G)E`$EN<V5R:74@=6YA(&9I;&$@82!S;W1A`$EN<V5R:74@
M=6YA(&9I;&$@82!S;V)R90!);G-E<FEU(&QA(')E<W!O<W1A(&$@;&$@<')E
M9W5N=&$@9&4@<V5G=7)E=&%T.@!);G-E<FER+TUO9&EF:6-A<B!I;6%T9V4`
M26YS97)I<B]-;V1I9FEC87(@96YL;&'G`$YO(&1I<W!O<V5U(&1E('!R;W4@
M8W+H9&ET('!E<B!E;G9I87(M;&\@82!L82!L;&ES=&$@9&4@9&ES=')I8G5C
M:?,N`$-RZ&1I="!I;G-U9FEC:65N="X`3F]M8G)E(&5N=&5R`$QL:7-T82!D
M92!N;VUB<F5S(&5N=&5R<P!51$@@;F\@=N!L:61A+B`H0V%PYV%L97)A(&1E
M(&1A9&5S(&0G=7-U87)I*2X`07!L:6-A8VGS(&YO(';@;&ED82X`3"=I9&5N
M=&EF:6-A9&]R(&1E;"!L;W0@;F\@Z7,@=N!L:60`3&5S(&1A9&5S('%U92!S
M)VAA;B!T<F%MZ',@;F\@<_-N(';@;&ED97,N`$PG861R9>=A(&1E(&1E<W1I
M;F%C:?,@;F\@Z7,@=N!L:61A+@!%;"!F;W)M870@9&4@;"=A<GAI=2!N;R#I
M<R!VX&QI9"X`3&$@8VQA=2!D92!L82!L;&ECZ&YC:6$@;F\@Z7,@=N!L:61A
M+@!,82!U8FEC86-I\R!Q=64@:&5U('!R;W!O<F-I;VYA="!N;R#I<R!VX&QI
M9&$N`$5L('1I<'5S+6US9R!N;R#I<R!VX&QI9"X`36%N8V$@96P@87!I7VED
M(&\@96P@<75E(',G:&$@9F%C:6QI=&%T(&YO(.ES(';@;&ED+@!-86YQ=65N
M('!A<N!M971R97,@;R!E;',@<75E(',G:&%N(&9A8VEL:71A="!N;R!S\VX@
M=N!L:61S+@!,)V%U=&]R:71Z86-I\R!P871E<FYA(&YO(.ES(';@;&ED82X`
M16P@8V]D:2!D)VED96YT:69I8V%C:?,@9&4@<V]C:2!N;R#I<R!VX&QI9"X`
M16P@8V]D:2!D96P@<')O9'5C=&4@;F\@Z7,@=N!L:60N`$5L('!R;W1O8V]L
M(&YO(.ES(';@;&ED+@!,)V]B:F5C=&4@8V]M<&%R=&ET(&YO(.ES(';@;&ED
M`$PG861R9>=A(&0G;W)I9V5N(&YO(.ES(';@;&ED82X`3&5S(&1A9&5S(%5N
M:6-O9&4@;F\@<_-N(';@;&ED97,N`$EN=F5N=&%R:0!)<F%N+"!297#Z8FQI
M8V$@27-LX&UI8V$@9"<`27)A<0!)<FQA;F1A`$EL;&$@9&4@36%N`%1E;7!E
M<W1E<R!A[VQL861E<P!)<W)A96P`16UI<W-O<@!#=7)S:79A`$ETX&QI80!*
M86UA:6-A`$=E;F5R`$IA</,`2F%P;V[H<R`H25-/+3(P,#(M2E`I`$IE<G-E
M>0!*;W)DX&YI80!*=6QI;VP`2G5N>0!*=7-T:69I8V%R`$IU<W1I9FEC87(@
M86P@8V5N=')E`$IU<W1I9FEC87(@82!T;W1S(&1O<R!M87)G97,`2G5S=&EF
M:6-A<B!A(&PG97-Q=65R<F$`2G5S=&EF:6-A<B!A(&QA(&1R971A`$MA>F%K
M:'-T86X`5F]L974@8V]N<V5R=F%R(&PG;W)I9VEN86P_`$ME;GEA`$5L('-E
M<G9I9&]R($ME<F)E<F]S(&AA(')E8G5T:F%T(&PG875T96YT:6-A8VGS+@!+
M97)N96P@3F5W8FEE<P!#<F5A8VGS(&1E(&-L875S`$5M<')E;71A(&1I9VET
M86P@9&4@;&$@8VQA=0!,;VYG:71U9"!D92!L82!C;&%U`%1I<'5S(&1E(&-L
M874`VG,@9&4@;&$@8VQA=0!*82!E>&ES=&5I>"!U;F$@8VQA=2!E;B!E;"!S
M97)V:61O<B!D92!C;&%U<R!P^F)L:7%U97,N`$YO:7,`2VER:6)A=&D`0V]R
M96$L(%)E</IB;&EC82!$96UO8W+@=&EC82!0;W!U;&%R(&1E`$-O<F5A+"!2
M97#Z8FQI8V$@9&4`0V]R9>`@*$550RU+4BD`2W5W86ET`$MI<F=U:7II<W1A
M;@!&;W)M870`261I;VUA`%)E</IB;&EC82!$96UO8W+@=&EC82!0;W!U;&%R
M(&1E($QA;W,`1&%R<F5R82!M96ET870`1&%R<F5R('%U87)T`$1A<G)E<F$@
M86-T=6%L:71Z86-I\SH`1&%R<F5R82!C;VYN97AI\SH@)7,`1&%R<F5R82!C
M;VYN97AI\SH@)7,@9&4@)7,`1&%R<F5R82!C;VYN97AI\SH`3&5T\FYI80!,
M;&5I`$1I<W-E;GD`1&5I>&%R+6AO(&5N(&)L86YC('!E<B!E;&EM:6YA<B!E
M;"!C;VYT;W)N`$SM8F%N`$5S<75E<G)A`$-A<.=A;&5R82!E<W%U97)R80!6
M86QO<G,@9&4@;"=E<W%U97)R80!,97-O=&AO`$QI8NAR:6$`3.UB:6$`3&EE
M8VAT96YS=&5I;@!0;'5G:6T@9F5B;&4`4&QU:F$@9F5B;&4`4&QU:F$@9F5B
M;&4@82!P<FEM97)A(&AO<F$`4&QU:F$@9F5B;&4@8V%P(&%L('1A<F0`4G5I
M>&%T(&9E8FQE`%)U:7AA="!F96)L92!A;6(@=')O;G,`3F5V861A(&9E8FQE
M`%C@9F5C(&1E(&YE=2!F96)L90!,:6UE<FEC:P!%;FQL8><`16YL;&%CYV%R
M(&5L<R!P=6YT<R!A;6(Z`$5N;&QAYV%R(&PG861R9>=A(&5L96-T<O)N:6-A
M(&$@;&$@<.!G:6YA(&1E(')E9&%C=&%T('%U86X@97,@;6]S=')I`$5N;&QA
MYV]S`$=A;&5T82!,:6YU>`!,;&ES=&%R("T@3"=U<W5A<FD@<&]T('9E=7)E
M(&QA(&-A<G!E=&$`3&QI<W1A<B!L97,@8F%S97,@9&4@9&%D97,`3&QI<W1A
M(&1E;',@=&5M97,@9"=A:G5D80!,;&ES=&%R(&QE<R!T875L97,`3&ES="U!
M<F-H:79E`$QI<W0M2&5L<`!,:7-T+4ED`$QI<W0M3W=N97(`3&ES="U0;W-T
M`$QI<W0M4W5B<V-R:6)E`$QI<W0M56YS=6)S8W)I8F4`3&$@;&QI<W1A(&0G
M=7-U87)I<R!E<W3@(&EN:&%B:6QI=&%D82X`0FEB;&EO9W)A9FEA`$QI='7@
M;FEA`%,G97-TX"!C87)R96=A;G0N+BX`2&]R82!L;V-A;#H@`$ED:6]M82!I
M(&AO<F$`56)I8V%C:?,`26YI8VEA(&QA('-E<W-I\P!3=7)T`%1A<W%U97,@
M9"=I;FEC:2!D92!S97-S:?,`2&D@:&$@:&%G=70@=6X@97)R;W(@9&4@8V]N
M;F5X:?,@<&5R<77H(&AE=2!I;G1R;V1U[W0@:6YC;W)R96-T86UE;G0@96P@
M;F]M(&0G=7-U87)I(&\@;&$@8V]N=')A<V5N>6$N`$AA(&9A;&QA="!L82!C
M;VYN97AI\RX`5&5X="!L;&%R9P!!;6]R`$)A:7@`06QF86)E="!G<F5C(&5N
M(&UI;OIS8W5L80!!;&9A8F5T(&QL873M(&5N(&UI;OIS8W5L80!8:69R97,@
M<F]M86YE<R!E;B!M:6[Z<V-U;&$`3'5X96UB=7)G`$U-`$U/5$0`3"=A<GAI
M=2!A9&IU;G0@35,M5$Y%1B!N;R!C;VYT96YI82!D861E<RX`35-'`$UA8V%U
M`$UA8V5D\FYI82P@06YT:6=A(%)E</IB;&EC82!)=6=O<VQA=F$@9&4`36%D
M86=A<V-A<@!-X&=I8P!#;W)R974@96QE8W1R\FYI8P!!9&UI;FES=')A9&]R
M(&1E(&-O<G)E=0!3)V5S=.`@8W)E86YT('5N(&5N;&QAYRXN+@!-86QA=VD`
M36%LX&ES:6$`36%L9&EV97,`36%L:0!-86QT80!'97-T:6]N974@;&$@;&QI
M<W1A(&1E(&-A=&5G;W)I97,@86UB(&QE<R!Q=6%L<R!H974@9"=E=&EQ=65T
M87(@96QS(&5L96UE;G1S+"!I(&5L<R!C;VQO<G,@87-S;V-I871S(&%M8B!A
M<75E<W1E<R!C871E9V]R:65S+@!-87!A($UA<#(T`$UA<&$@36%P475E<W0`
M36%RYP!-87)G90!-87)C87(@86UB(&EN9&EC861O<G,@=FES:6)L97,O:6YV
M:7-I8FQE<P!-87)C87(@86UB(&%L=')E<R!I;F1I8V%D;W)S("AP+B!E+BP@
M:6UP;W)T86YT+W)E<W!O<W0I`$EL;&5S($UA<G-H86QL`$UA<G1I;FEC80!#
M86UP<R!Q=64@8V]I;F-I9&5I>&EN`$UA=7)I=.!N:6$`36%U<FEC:0!#<NAD
M:70@;>!X:6T@<&5R;>AS+@!3)VAA('-U<&5R870@96P@;F]M8G)E(&W@>&EM
M(&1E('!A<G1S(&1E(&UI<W-A=&=E+@!496UP97)A='5R82!MX'AI;6$@9&4@
M;&5S(&1A<G)E<F5S(#(T(&AO<F5S.B``5&5M<&5R871U<F$@;>!X:6UA(&1E
M(&QE<R!D87)R97)E<R`V(&AO<F5S.B``3&]N9VET=60@;>!X:6UA`$UA:6<`
M36%Y;W1T90!-961I8VEN80!-96UB<F5S`%1I<'5S(&1E(&UE;OHZ`%)E9F]N
M87(@;&5S(&-E;+=L97,`36ES<V%T9V4`16P@;6ES<V%T9V4@:&$@97-T870@
M=F5R:69I8V%T(&-O<G)E8W1A;65N="P@<&5R\B!N;R!S)VAA('!O9W5T('9E
M<FEF:6-A<B!E;"!C97)T:69I8V%T(&5L('-I9VYA;G0N`$UI<W-A=&=E(&-A
M9'5C870N`%1I<'5S(&1E(&UI<W-A=&=E`%1E;7!S(&1E($U%5$%2`$5L(&)L
M;V,@345405(@;F\@97-TX"!D:7-P;VYI8FQE+@!%;"!B;&]C($U%5$%2(&YO
M(&5S=.`@9&ES<&]N:6)L92X@16QS(&1E=&%L;',@:&%N(&5S=&%T(')E9VES
M=')A=',@<&5R(&$@;"=A9&UI;FES=')A9&]R+@!,82!B87-E(&1E(&1A9&5S
M($U%5$%2(&YO(&5S=.`@8V]N;F5C=&%D82X`3>AT;V1E`$WH=')I8P!-Z'AI
M8P!-:6-R;V[H<VEA+"!%<W1A=',@1F5D97)A=',@9&4`0V5N=')E`%1I<'5S
M($U)344`5&5M<&5R871U<F$@;>UN:6UA(&1E(&QE<R!D87)R97)E<R`R-"!H
M;W)E<SH@`%1E;7!E<F%T=7)A(&WM;FEM82!D92!L97,@9&%R<F5R97,@-B!H
M;W)E<SH@`%+H<&QI8V$`36ES8V5LMVQA;FD`1F%L=&$@;&$@<V]LMVQI8VET
M=60@2%144"!P97(@86P@<&%Q=65T(%!%05(N`$9A;'1A(&QA(&-O;F9I9W5R
M86-I\RX@3"=H974@9&4@9V5N97)A<B!A<F$@<VD@=F]L974@=71I;&ET>F%R
M(&%Q=65S=&$@87!L:6-A8VGS+@!&86QT82!L)VED96YT:69I8V%D;W(@9&5L
M(&UI<W-A=&=E+@!&86QT82!E;"!C;W)R974@96QE8W1R\FYI8R!D96P@<&%Q
M=65T(%!%05(@;F5C97-S87)I+@!&86QT82!L)VED96YT:69I8V%D;W(@9&4@
M<V5S<VGS+@!$;"X`0V]R<F5U(&WR8FEL`$UO9&5R870`1&%T82!M;V1I9FEC
M861A`$UO9&EF:6-A<B!L82!54DP`3?)D=6P`36]L9.!V:6$L(%)E</IB;&EC
M82!D90!-\FYA8V\`36]N9_)L:6$`365S(&D@86YY`$UE;G-U86QM96YT`$UO
M;G1S97)R870`1F%S97,@;'5N87)S`$UA<G)O8P!-86IO<FETX')I86UE;G0@
M9&5S8V]B97)T`$UA:F]R:73@<FEA;65N="!E;FYU=F]L870`36%J;W)I=.!R
M:6%M96YT(&%S<V]L96QL870`36]U<F4@8V%P(&%V86QL`$UO=7)E(&$@;"=E
M<W%U97)R80!-;W5R92!A(&QA(&1R971A`$UO=7)E(&-A<"!A;75N=`!-;W5R
M92!C87`@879A;&P`36]U<F4@8V%P(&%M=6YT`$UOYV%M8FEC`$QI<W1E<R!D
M97-P;&5G86)L97,@96YL;&'G861E<R!E;B!D:79E<G-O<R!N:79E;&QS`%-E
M;&5C8VGS(&WZ;'1I<&QE`$5L(&UE=2!C;VUP=&4`16P@;65U('!O<G1A;`!$
M:7-S96YY(&1E;"!M974@<&]R=&%L`$UY86YM87(`3D\L($Y/(&AI(&5S=&EC
M(&0G86-O<F0`3F]M`$YA;>UB:6$`3F%U<G4`3F5P86P`4&'O<V]S($)A:7AO
M<P!!;G1I;&QE<R!.965R;&%N9&5S97,`55),(&)A<V4@9&4@3F5T<V-A<&4`
M55),(&1E(')E=F]C86-I\R!D92!#02!D92!.971S8V%P90!54DP@9&4@<&]L
M[71I<75E<R!D92!#02!D92!.971S8V%P90!54DP@9&4@<F5N;W9A8VGS(&1E
M($YE='-C87!E`%523"!D92!R979O8V%C:?,@9&4@3F5T<V-A<&4`3F]M(&1E
M;"!S97)V:61O<B!34TP@9&4@3F5T<V-A<&4`0V]M96YT87)I(&1E;"!C97)T
M:69I8V%T(&1E($YE='-C87!E`%1I<'5S(&1E(&-E<G1I9FEC870@9&4@3F5T
M<V-A<&4`6&%R>&$`36%I`$YO=F$@0V%L963R;FEA`$YO=F$@8V%T96=O<FEA
M`$QL=6YA(&YO=F$`3F]U(&YO;2!D)W5S=6%R:2`H;W!C:6]N86PI`$YO=F$@
M6F5L86YD80!.;W9A(&9I;F5S=')A("A?96X@8FQA;F,I`$UI<W-A=&=E<P!'
M<G5P<R!D92!D:7-C=7-S:?,`4V5G_&5N=``T(&9A<V5S('-E9_QE;G1S`$]P
M8VEO;G,@<V5G_&5N=',`4V5G_&5N=#X`3FEC87)A9W5A`$[M9V5R`$YI9^AR
M:6$`3FET`$YI=64`3F\`3F\@97,@9&ES<&]S96X@9&4@9&%D97,@9&4@8V]N
M9FEG=7)A8VGS('!E<B!M;W-T<F%R(&QE<R!D:69E<NAN8VEE<RX`3F\@97,@
M9&ES<&]S82!D)W5N82!E<W1R873H9VEA('!E<B!C<F5A<B!I;6%T9V5S($E3
M3RX`3F\@:&D@:&$@<&QA;G1I;&QA(&1E(&QO=',N`$YO(&5X:7-T96EX(&-A
M<"!B;&]C(&5N(&QA('!O<VEC:?,@<V]LMVQI8VET861A`$YO(',G:&$@<')O
M<&]R8VEO;F%T('5N(&YO;2!D)V%G96YD82!P97(@82!L)V%U=&5N=&EC86-I
M\R!-0T%,+@!396YS92!C86YV:7,N`$YO(&5S('!O9&5N(&%F96=I<B!D97-C
M96YD96YT<R!A(&%Q=65S="!P97)M[7,`3F\@<R=H82!E<W!E8VEF:6-A="!L
M97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS('!E<B!A("5S+@!.;R!S)VAA(&5S
M<&5C:69I8V%T(&QE<R!D861E<R!D92!C;VYF:6=U<F%C:?,@<&5R(&$@1E10
M('!E<B!61E,N`$YO(',G:&$@97-P96-I9FEC870@;&5S(&1A9&5S(&1E(&-O
M;F9I9W5R86-I\R!P97(@82!344P@<&5R(%9&4RX`3F\@<R=H82!E<W!E8VEF
M:6-A="!L97,@9&%D97,@9&4@8V]N9FEG=7)A8VGS(&1E(%-13"!P97(@86P@
M9FET>&5R(%-13"X`3F\@<75E9&$@8W+H9&ET+@!.;R!S)VAA(&9A8VEL:71A
M="!U;F$@9&5S=&EN86-I\RX`3F\@<R=H82!C87)R96=A="!C87`@87)X:74N
M`$YO(',G:&$@=')O8F%T(&-A<"!I8V]N82X`3F\@<R=H82!D969I;FET('5N
M82!U8FEC86-I\RX`3F\@<R=H82!F86-I;&ET870@=6YA('5B:6-A8VGS+@!.
M;R!S)VAA(&EN=')O9'7O="!U;B!M:7-S871G92X`3F\@<R=H82!E<W!E8VEF
M:6-A="!U;B!N;VTN`$YO(',G:&$@97-P96-I9FEC870@=6YA('AI9G)A+@!.
M;R!E<R!P97)M971E;B!L97,@9&ET97,@;V9E;G-I=F5S+@!.;R!S)VAA(&EN
M=')O9'7O="!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E;G1I8V%C:?,@
M2%144"X`3F\@<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A
M(&PG875T96YT:6-A8VGS($E-05`N`$YO(',G:&$@:6YT<F]D=>]T('5N82!C
M;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!+97)B97)O<RX`3F\@
M<R=H82!I;G1R;V1U[W0@=6YA(&-O;G1R87-E;GEA('!E<B!A(&PG875T96YT
M:6-A8VGS(&0G:6YI8VDN`$YO(',G:&$@:6YT<F]D=>]T('5N82!C;VYT<F%S
M96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!005-35T0N`$YO(',G:&$@:6YT
M<F]D=>]T('5N82!C;VYT<F%S96YY82!P97(@82!L)V%U=&5N=&EC86-I\R!3
M34(N`$YO(',G:&$@:6YD:6-A="!L82!V:6$@9"=A8V/I<R!A;"!B:6YA<FD@
M3W!E;E-33"X@0V%L(&5L(&)I;F%R:2!/<&5N4U-,('!E<B!T<F5B86QL87(@
M86UB(&QE<R!D861E<R!02T-3(#$R+@!.;R!H:2!H82!A;'1E<R!P96YD96YT
M<RX`3F\@<R=H82!D969I;FET(&PG97-P86D@9&ES<&]N:6)L92X`4V5N<V4@
M<F5G;&5S`%-E;G-E(&-A<F5S`$YO(&5X:7-T96EX(&%Q=65S="!A<GAI=0!.
M;R!E<R!D:7-P;W-A(&1E(&-A<"!D:7)E8W1O<FD@=&5M<&]R86P@<&5R(&$@
M;&$@;65M\G)I82!C874N`$YO(&AE=2!E;G9I870@96P@;F]M(&0G=7-U87)I
M(&YI+V\@;&$@8V]N=')A<V5N>6$`3F\@<R=H86X@<F5T;W)N870@9&%D97,@
M6$U,(';@;&ED97,`4V5N<V4@=F%L;W)S`$YO(',G:&$@=')O8F%T(&QA('9E
M<G-I\R!E;B!L82!C;VYF:6=U<F%C:?,@;W)I9VEN86PN(%)E9V5N97)E=2!L
M82!C;VYF:6=U<F%C:?,N`$YO(',G:&$@=')O8F%T(&QA('9E<G-I\R!E;B!L
M82!C;VYF:6=U<F%C:?,N(%)E9V5N97)E=2!L82!C;VYF:6=U<F%C:?,N`$-A
M<`!#87`@*/IS(&EM<&SM8VET*0!.\G)D:6,@*$E33RTX.#4Y+3$P*0!);&QA
M(&1E($YO<F9O;&L`2&5M:7-F97)I(&YO<F0`26QL97,@36%R:6%N;F5S(&1E
M;"!.;W)D`$YO<G5E9V$`3F\@9&5S<'+I<P!.;R!A8F%N<P!.;R#I<R!U;B!D
M:7)E8W1O<FD`3F\@:6UP;&5M96YT870N`$YO(&1E9FEN:70`3F\@<&5R;>AS
M+@!.;W1E<P!.;R!H:2!H82!R97,@82!V:7-U86QI='IA<BP@<F5T<F]C961I
M=2X`3F]V96UB<F4`3F]M8G)E`$YO;6)R92!D92!C87+@8W1E<G,`3F]M8G)E
M(&1E(&-O;'5M;F5S`$YO;6)R92!D92!F:6QE<P!.;R!S)VAA;B!E<W!E8VEF
M:6-A="!N;VUB<F5S('%U92!H86=I;B!D92!S97(@86-T=6%L:71Z871S(&5N
M(&QA(&QL:7-T82!D92!D:7-T<FEB=6-I\RX`1"=A8V]R9`!/8FIE8W1E`$-R
M96%D;W(@9&4@;"=O8FIE8W1E`$]C=&%L`$]C='5B<F4`1FEL=')E(&0G:6YF
M<F%C8VEO;G,`3V9I8VEN80!/;6%N`$YO;>ES(&5L<R!S97)V:61O<G,@24U!
M4"!P97)M971E;B!L)_IS(&1E(&-A<G!E=&5S(&-O;7!A<G1I9&5S+@!.;VWI
M<R!M:7-S871G97,@;V9E;G-I=7,`3F]MZ7,@Z7,@<&5R;65S82!U;F$@^FYI
M8V$@861R9>=A(&5L96-T<O)N:6-A+@!.;VWI<R!E;"!P<F]P:65T87)I(&\@
M;"=A9&UI;FES=')A9&]R(&1E('-I<W1E;65S('!O="!C86YV:6%R(&QA('!R
M;W!I971A="!O(&5L<R!P97)M:7-O<R!D96P@<')O<&EE=&%R:2!P97(@82!R
M96-U<G-O<R!C;VUP87)T:71S`$]B<FEU(&5N('5N82!N;W9A(&9I;F5S=')A
M`$5R<F]R($]P96Y34TPZ(&YO(',G:&%N('!O9W5T(&5X=')E=7)E(&QE<R!D
M861E<R!D92!L82!P87)T(%,O34E-12!S:6=N861A+@!/8G)E(&%Q=65S="!E
M;FQL8><@96X@=6YA(&YO=F$@9FEN97-T<F$`4VES=&5M82!O<&5R871I=0!/
M<&-I;VYS`$]P8VEO;G,@9"<E<P!,;&ES=&$@;W)D96YA9&$`3W)G86YI='IA
M8VGS`%5N:71A="!O<F=A;FET>F%T:79A`%,G97-TX"!O<F=A;FET>F%N=`!0
M;&%N=&EL;&$@9"=A<&QI8V%C:?,@;W)I9VEN86P`4&QA;G1I;&QE<R!O<FEG
M:6YA;',@96X@)7,Z`$%L=')E`$%L=')A(&EN9F]R;6%C:?,`4&5R;6ES;W,@
M9&5L('!R;W!I971A<FD`3"=A=71E;G1I8V%C:?,@4$%-(&YO(&5S=.`@9&ES
M<&]N:6)L92X`4VEG;F%T=7)A(&1I9VET86P@4$=0`$1A9&5S('AI9G)A9&5S
M(&%M8B!01U``0VQA=2!01U`@</IB;&EC80!$861E<R!S:6=N861E<R]X:69R
M861E<R!A;6(@4$=0`$-O9&D@4$A0`$EN=.AR<')E="!D)V]R9')E<R!02%``
M4&QU9VEM<R!D92!T87)D80!0;'5G97,@9&4@=&%R9&$`3F5V861E<R!D92!T
M87)D80!8X&9E8W,@9&4@;F5U(&$@;&$@=&%R9&$`4V]L(&1E('1A<F1A`%1E
M;7!E<W1E<R!D92!T87)D80!);G3H<G!R970@9"=O<F1R97,@4%](4`!397!A
M<F%C:?,`4&%K:7-T86X`4&%L874`5&5R<FET;W)I('!A;&5S=.TL(&]C=7!A
M=`!086YA;>``4&%P=6$@3F]V82!'=6EN96$`4&%R86=U86D`4&%R8VEA;&UE
M;G0@96YN=79O;&%T`$-O;G1R87-E;GEA`$-O;G1R87-E;GEA(&EN8V]R<F5C
M=&$`0V%L(&EN=')O9'5I<B!U;F$@8V]N=')A<V5N>6$@<&5R(&$@;"=A=71E
M;G1I8V%C:?,@4D%$2553+@!#;VYT<F%S96YY82!A;6(@8V]N9FER;6%C:?,`
M0V]N=')A<V5N>6$Z`$-O;G1R87-E;GEA.B``3&5S(&-O;G1R87-E;GEE<R!H
M86X@9&4@8V]I;F-I9&ER+@!%;F=A;GAA<@!%;F=A;GAA<B!D96P@<&]R=&$M
M<F5T86QL<P!#86WM`$%L=&5S('!E;F1E;G1S.@!'96YT`%!E<F-E;G1A=&=E
M`%)E86QI='IA<B!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT`%9O;&5U(')E
M86QI='IA<B!O<&5R86-I;VYS(&1E(&UA;G1E;FEM96YT(&5N(&EN:6-I87(@
M;&$@<V5S<VGS/P!097)M[7,`4&5R;6ES(&1E;F5G870`061M:6YI<W1R861O
M<B!D92!P97)M:7-O<P!$861E<R!P97)S;VYA;',`4&5R^@!!;FEM86QS(&1E
M(&-O;7!A;GEI80!&:6QI<&EN97,`5&5LZ&9O;@!&;W1O<P!0:71C86ER;@!0
M[7AE;',`5/)P:6-S`$-L:6-A<B!E;B!U;F$@8V5LMVQA`$-O;F9I<FUA<B!Q
M=64@=F]L974@<W5P<FEM:7(@87%U97-T(&5L96UE;G0Z`$-O;F9I<FUA<B!Q
M=64@=F]L974@9&5S96YL;&'G87(@87%U97-T(&5L96UE;G0N`$EN=')O9'7O
M=2!U;B!M97,@:2!U;B!A;GDN`$EN=')O9'7O=2!U;B!N;VT@<&5R(&$@;&$@
M;F]V82!C871E9V]R:6$Z`$EN=')O9'7O=2!U;F$@861R9>=A($E0(';@;&ED
M82X`26YT<F]D=>]U('5N82!D871A(';@;&ED82P@8V]M<')O=F5U(&5L<R!D
M:65S('%U92!TZ2!E;"!M97,N`$EN=')O9'7O=2!U;F$@:&]R82!VX&QI9&$N
M`%!R;W!O<F-I;VYE=2!U;B!R97-U;2!D96P@<')O8FQE;6$N`%!R;W!O<F-I
M;VYE=2!E;"!N;VT@9"=U<W5A<FD@:2!L82!C;VYT<F%S96YY80!496-L96=E
M=2!E;"!N;VT@9&4@;&$@;F]V82!C871E9V]R:6$Z`%!O;/)N:6$`4&]L[71I
M8V$`16YQ=65S=&5S`%!O<G1U9V%L`$-O;+=L;V-A8VGS(&0G87%U97-T82!I
M;6%T9V4`0V]LMVQO8V%C:?,@9"=A<75E<W1A('1A=6QA`$5N=FEA<B!A(&%Q
M=65S=&$@8V%R<&5T82`H;F\@:&D@;V)L:6=A($E-05`I`%!R96-I<&ET86-I
M\R!D=7)A;G0@;&$@9&%R<F5R82`E<R!H;W)A(&\@:&]R97,Z(`!0<F5F<U]L
M9&%P.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS($Q$05`@<V]LMVQI8VET
M861A+@!0<F5F<U]S97-S:6]N.B!.;R!S)VAA('1R;V)A="!L)V5X=&5N<VGS
M(&1E('-E<W-I\R!S;VRW;&EC:71A9&$N`%!R97-S:?,`4')E<W-I\R!A;"!N
M:79E;&P@9&5L(&UA<CH`4')E<W-I\SH@`%9I<W5A;&ET>F%C:?,@<'+H=FEA
M`%9I<W5A;&ET>F%R('!RZ'9I86UE;G0@;&$@:6UA=&=E(&5N('5N82!N;W9A
M(&9I;F5S=')A`$]P8VEO;G,@<'+H=FEE<P!);7!R:6UI<B!E;"!D;V-U;65N
M=`!#;&%U('!R:79A9&$`4')O8FQE;6$`1&5S8W)I<&-I\R!D96P@<')O8FQE
M;6$`4')O:F5C=&5S`%1E>'0@:6YD:6-A9&]R`$-L874@</IB;&EC80!!;&=O
M<FES;64@9&4@8VQA=2!P^F)L:6-A`$EN9F]R;6%C:?,@9&4@8VQA=2!P^F)L
M:6-A`$YO(',G:&$@9V5N97)A="!C;W)R96-T86UE;G0@;&$@<&%R96QL82!D
M92!C;&%U<R!P^F)L:6-A+W!R:79A9&$`4'5E<G1O(%)I8V\`46%T87(`0V]N
M<W5L=&$`0VQA=2!P^F)L:6-A(%)302`H)60@8FET*0!";W3S(&1E('-E;&5C
M8VGS`%!L=6IA`%!L=6IA(&$@<')I;65R82!H;W)A`%!L=6IA(&-A<"!A;"!T
M87)D`%)U:7AA=`!0;'5J82!I(&YE=P!!:6=U86YE=0!$:71A(&%L96%T\G)I
M80!296QA8VGS`$QL96=I=0!,;&5G:74@96QS(&UI<W-A=&=E<P!#;VYF:7)M
M974@<75E('9O;&5U('-U<')I;6ER("5S/R!!<75E<W1A(&]P97)A8VGS(&YO
M(&5S('!O="!D97-F97(N`$-O;F9I<FUE=2!Q=64@=F]L974@<W5P<FEM:7(@
M;&5S(&1A9&5S(&1E(&PG=7-U87)I('!E<B!A(&PG=7-U87)I("5S/R!!<75E
M<W1A(&]P97)A8VGS(&YO(&5S('!O="!D97-F97(N`%1O<FYA(&$@9F5R(&QA
M(&1A<G)E<F$@86-C:?,`4F5F<F5S8V%R(&5L<R!E;&5M96YT<R!D96P@;65N
M^B!D:6[@;6EC<P!2969R97-C87(@;&$@=FES=6%L:71Z86-I\R!D96P@<&]R
M=&%L`$5X<')E<W-I\R!R96=U;&%R`$YA=F5G861O<B!D92!R96QA8VEO;G,`
M0V]M96YT87)I<P!397)V:61O<G,@<F5M;W1S`%523"!R96UO="`H:'1T<',Z
M+R]W=W<N97AE;7!L92YE<R]H;W)D92DZ`%-U<')I;6ER`%-U<')I;6ER(&)L
M;V,`4W5P<FEM:7(@8V]L=6UN80!3=7!R:6UI<B!L82!F;W)M871A8VGS`%-U
M<')I;6ER(&QA('!A<F5L;&$`4W5P<FEM:7(@;&$@<V5Q_.AN8VEA(&1E<V%D
M82!D96P@9&ER96-T;W)I('1E;7!O<F%L(&1E;"!S97)V:61O<BX`4W5P<FEM
M:7(@96P`4W5P<FEM:7(@87%U97-T(&YO9&4@9&5L(&1O8W5M96YT`%-U<')I
M;6ER(&PG=7-U87)I`%-U<')I;6ER(&PG=7-U87)I.B`E<P!.;R!S)VAA('!O
M9W5T(')E<W!O;F1R92!A(&QA('-O;+=L:6-I='5D+B!#;V1I(&0G97)R;W(@
M<F5T;W)N870Z(`!.;R!S)VAA('1R;V)A="!E;"!S97)V96D@<V]LMVQI8VET
M870N`$-A;7`@<V]LMVQI8VET870`4F5I;FEC:6$`4F5I;FEC:6%R(&QA(&-O
M;G1R87-E;GEA`%)E:6YI8VEA<B!L82!C;VYT<F%S96YY80!297-U;'1A=',`
M5&]R;F$@82!O<&-I;VYS`%)E=6YI\P!297-T875R87(@;&$@8V]N9FEG=7)A
M8VGS`$]P8VEO;G,@9&4@;"=E9&ET;W(@9&4@=&5X="!E;G)I<75I=`!%;FEG
M;65S`$1R971A`$-A<.=A;&5R82!D<F5T80!686QO<G,@9&4@;&$@9')E=&$`
M4')O<&EE=&%T<R!D92!L82!F:6QA+BXN`$9U;F-I\P!2;VUA;FEA`$=I<F%R
M(#$X,`!':7)A<B!A(&PG97-Q=65R<F$`1VER87(@82!L82!D<F5T80!0<F]P
M:65T871S(&1E(&QA(&9I;&$`4')O<&EE=&%T<R!D92!L82!F:6QA`$9I;&5S
M.@!296=L97,`07!A<F5I>&5R86X@<F5G;&5S(&5N=')E('1O=&5S(&QE<R!F
M:6QE<R!I(&-O;'5M;F5S`$%P87)E:7AE<F%N(')E9VQE<R!N;VWI<R!E;G1R
M92!C;VQU;6YE<P!!<&%R96EX97)A;B!R96=L97,@;F]MZ7,@96YT<F4@9FEL
M97,`17AE8W5T87(`1F5D97)A8VGS(%)U<W-A`%)W86YD80!3:6=N871U<F$@
M8W)I<'1O9W+@9FEC82!A;6(@4R]-24U%`$UI<W-A=&=E('AI9G)A="!A;6(@
M4R]-24U%`$PG875T96YT:6-A8VGS(%-!4TP@;F\@97-TX"!D:7-P;VYI8FQE
M+@!-:7-S871G97)I82!335,`26YTZ')P<F5T(&0G;W)D<F5S(%-13`!34T@`
MR%A)5`!);G3H<G!R970@9"=O<F1R97,@4U%,`$1S+@!386EN="!(96QE;F$`
M4V%I;G0@0VAR:7-T;W!H97(@:2!.979I<P!386EN="!,=6-I80!386EN="U0
M:65R<F4M970M36EQ=65L;VX`4V%I;G0@5FEN8V5N="!I(&QE<R!'<F5N861I
M;F5S`$UA=&5I>"!M87)C("A?<V5L9BD`4V%M;V$`4V%N($UA<FEN;P!386\@
M5&]MZ2!I(%!R[6YC:7!E`%!R;W9E[V1O<B!D92!S873H;+=L:70`07+@8FEA
M(%-A=61I=&$`1&5S80!$97-A("5S`$1E<V$@;&5S(&]P8VEO;G,`1&5S974@
M;&$@8V]N9FEG=7)A8VGS(&=E;F5R861A(&-O;2!U;F$@<V5Q_.AN8VEA(%!(
M4"!E;B!E;"!D:7)E8W1O<FD@=&5M<&]R86P@9&5L('-E<G9I9&]R+@!3)VAA
M(&1E<V%T(&QA(&-O;F9I9W5R86-I\R!D92`E<RX`5&5M<&5S=&5S(&1I<W!E
M<G-E<P!#:>AN8VEA`$-E<F-A`$UO=&]R<R!D92!C97)C80!396QE8V-I;VYA
M<B!E;',@87)X:75S`%-E;&5C8VEO;F%R('5N82!D871A`%-E;&5C8VEO;F%R
M('5N(&=R=7`@<75E('9U;&=U974@869E9VER`%-E;&5C8VEO;F5U('5N(&YO
M=2!P<F]P:65T87)I`%-E;&5C8VEO;F5U('5N('-E<G9I9&]R`%-E;&5C8VEO
M;F5U('5N('5S=6%R:2!Q=64@=G5L9W5E=2!A9F5G:7(`4V5L96-C:6]N974@
M=&]T<R!E;',@96QE;65N=',@9&4@;&$@9&%T82X`4V5L96-C:6]N974@=6X@
M;V)J96-T90!396QE8V-I;VYE=2!E;',@8V%RX&-T97)S('%U92!N96-E<W-I
M=&5U(&1E(&QE<R!C87-E;&QE<R!D92!S;W1A+B!0;V1E=2!C;W!I87(M;&]S
M(&D@96YG86YX87(M;&]S(&1E(&PGX')E82!D92!T97AT+@!396QE8V-I;VYA
M<B!E;"!D96QI;6ET861O<B!D92!L82!D871A.@!396QE8V-I;VYA<B!E;"!F
M;W)M870@9&4@;&$@9&%T83H`4V5L96-C:6]N87(@;&$@:61E;G1I=&%T('%U
M92!V;VQE=2!Q=64@8V%N=FEA<CH`4V5L96-C:6]N87(@96P@9&5L:6UI=&%D
M;W(@9&4@;"=H;W)A.@!396QE8V-I;VYA<B!E;"!F;W)M870@9&4@;"=H;W)A
M.@!396QE8V-I;VYA<B!D;W,@8V%M<',@<75E(&-O:6YC:61E:7AI;BX`4V5L
M96-C:6]N87(@;&$@8V]M8FEN86-I\R!D92!C;VQO<G,N`%-E;&5C8VEO;F%R
M(&PG:61I;VUA('!R969E<FET.@!%;G9I87(@;"=I;F9O<FUE(&1E;',@<')O
M8FQE;65S`$5N=FEA<B!335,`4V5N96=A;`!396YS;W(Z(`!3971E;6)R90!3
MZ')B:6$@:2!-;VYT96YE9W)O`$[Z;65R;R!D92!SZ')I90!,97,@9&%D97,@
M9&5L('-E<G9I9&]R('/S;B!I;F-O<G)E8W1E<R!O(&YO(&5S=&%N(&1I<W!O
M;FEB;&5S+@!(82!C861U8V%T(&PG:61E;G1I9FEC861O<B!D92!S97-S:?,N
M`$1E9FEN96EX`$1E9FEN96EX(&QE<R!O<&-I;VYS('%U92!U<R!P97)M971E
M;B!R96EN:6-I87(@;&$@8V]N=')A<V5N>6$@<VD@;6%I(&PG;V)L:61E=2X`
M1&5F:6YI=2!E;',@<V5R=FED;W)S(')E;6]T<R!A('%UZ"!V;VQE=2!A8V-E
M9&ER(&1E<R!D96P@<&]R=&%L+@!$969I;FEU(&5L('9O<W1R92!I9&EO;6$@
M<')E9F5R:70L(&QA('IO;F$@:&]RX')I82!I(&QE<R!O<&-I;VYS(&1E(&1A
M=&$N`$1E9FEN:74@;"=A<&QI8V%C:?,@9"=I;FEC:2P@;&$@8V]M8FEN86-I
M\R!D92!C;VQO<G,L(&5L(')E9G)E<V-A;65N="!D92!L97,@<.!G:6YE<R!I
M(&%L=')E<R!O<&-I;VYS(&1E('9I<W5A;&ET>F%C:?,N`$-O;F9I9W5R86-I
M\P!(:2!H82!S97'\Z&YC:65S(&0G86-T=6%L:71Z86-I\R!D92!L82!C;VYF
M:6=U<F%C:?,`2&D@:&$@9&EV97)S97,@=6)I8V%C:6]N<R!P;W-S:6)L97,@
M86UB(&5L('!A<N!M971R93H@`%-E>6-H96QL97,`0V]M<')E<P!297-U;2!B
M<F5U`%9O;&5U(&1E9FEN:7(@;&5S(&-L875S(&0G86-CZ7,@<&5R(&$@;&$@
M;6%J;W(@<&%R="!D)V5N;&QAYV]S/P!-;W-T<F$`36]S=')A(&QE<R!D:69E
M<NAN8VEE<R!E;G1R92!L82!C;VYF:6=U<F%C:?,@9&5S861A(&D@;&$@;F]V
M82X`5F]L974@=FES=6%L:71Z87(@;"=H;W)A(&1E(&QA(&1A<G)E<F$@<V5S
M<VGS(&5N(&EN:6-I87(_`$UO<W1R82!L)V]P8VGS(&1E(&-O;G-E<G9A<B!L
M)V]R:6=I;F%L`$UO<W1R82!E;"!C87!T=7)A9&]R`%9O;&5U('9I<W5A;&ET
M>F%R(&QA(&)A<G)A(&1E(&UE;OH@9"=O<&5R86-I;VYS(&1E('1A=6QA/P!6
M;VQE=2!V:7-U86QI='IA<B!E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$_`$UO
M<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!C96RW;&$@9&4@=&%U
M;&$`36]S=')A(&5L(&1IX&QE9R!D92!P<F]P:65T871S(&1E('1A=6QA`$UO
M<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!F:6QA(&1E('1A=6QA
M`$UO<W1R82!E;"!D:>!L96<@9&4@<')O<&EE=&%T<R!D92!I;6%T9V4`36]S
M=')A(&QA(&/@<G)E9V$`4G5I>&%T<P!2=6EX871S(&$@<')I;65R82!H;W)A
M`%)U:7AA=',@8V%P(&%L('1A<F0`4G5I>&%T<R!A(&QA(')O9&%L:6$`4F5D
M=>]U`%!R:6UE<B!R961U[W4@;R!A<&%R=&5U(&5L*',I(&)L;V,H<RD@9&5L
M(&-O<W1A=`!3:65R<F$@3&5O;F4`1&]N974M=F]S(&0G86QT80!3:6=N871U
M<F$`06QG;W)I<VUE(&1E('-I9VYA='5R80!3:6YG87!U<@!-:61A`$]M970@
M;6%N=&5N:6UE;G0`17-L;W;@<75I80!%<VQO=NAN:6$`3F5V861A`%C@9F5C
M(&1E(&YE=0!8X&9E8W,@9&4@;F5U`%C@9F5C<R!D92!N974@82!P<FEM97)A
M(&AO<F$`6.!F96-S(&1E(&YE=2!C87`@86P@=&%R9`!'<G5I>"!D92!N974Z
M(`!%<75I=F%L96YT(&1E(&QA(&YE=2!E;B!A:6=U83H@`$EL;&5S(%-A;&]M
M\P!3;VW@;&EA`$-A;N=O;G,@:2!P;V5M97,`4V5L96-C:?,@96X@96P@<V5N
M=&ET(&1E(&QA(&-L87-S:69I8V%C:?,`061R9>=A(&0G;W)I9V5N`%-U9"W@
M9G)I8V$`4W5D+65U<F]P974@*$E33RTX.#4Y+3,I`$=E\G)G:6$@9&5L(%-U
M9"!I(&QE<R!I;&QE<R!386YD=VEC:"!D96P@4W5D`$AE;6ES9F5R:2!S=60`
M17-P86D@96YT<F4@8V5LMVQE<R!A9&IA8V5N=',`17-P86D@96YT<F4@96P@
M8V]N=&EN9W5T(&D@96P@8V]N=&]R;B!D92!L82!C96RW;&$`17-P86EA9&]R
M`$5S<&%I870`17-P86EA="!I(&9A<F-I;65N=`!%<W!A;GEA`$-O<G)E=2!B
M<F]S<V$`17-C<FEP='5R82!D92!C87+@8W1E<G,@97-P96-I86QS`$1I=FED
M:7(@8V5LMVQA`$1I=FED:7(@8V]L=6UN80!$:79I9&ER(&9I;&$`17-P;W)T
M<P!3<FD@3&%N:V$`17-TX&YD87)D`%-T87(@5')E:P!!;GD@9"=I;FEC:0!%
M<W1A="!O('!R;W;M;F-I80!%<W1A=`!&;W)M870@9"=E;6UA9V%T>F5M871G
M90!!9')EYV$@<&%R=&EC=6QA<@!"87)R870`3&QI<W1A(&1E(&-A9&5N97,`
M16QI;6EN974@96P@9&]M:6YI(&1E(&PG861R9>=A`$5S=&EL(%M#4U-=`$1G
M+@!!<W-U;7!T90!%;G9I80!3=6+M;F1E>`#(>&ET`%,G:&$@<F5S=&%U<F%T
M(&-O<G)E8W1A;65N="!L82!C;VYF:6=U<F%C:?,N($%C='5A;&ET>F5U('!E
M<B!V975R92!E;',@8V%N=FES+@!3)VAA(&1E<V%T(&-O<G)E8W1A;65N="!L
M82!C;VYF:6=U<F%C:?,@9&4@8_)P:6$N`%,G:&$@9&5S870@8V]R<F5C=&%M
M96YT(&PG87)X:74@9&4@;&$@8V]N9FEG=7)A8VGS(&1E(&/R<&EA("5S+@!3
M)VAA(&5S8W)I="!C;W)R96-T86UE;G0@)R5S)P!3=61A;@!297-U;0!3;W)T
M:61A(&1E;"!S;VP`4&]S=&$@9&5L('-O;`!!<W-O;&5L;&%T`%-O<G1I9&$@
M9&5L('-O;`!3;W)T:61A(&1E;"!S;VPO4&]S=&$@9&5L('-O;`!3;W)T:61A
M(&1E;"!S;VPZ(`!0;W-T82!D96P@<V]L`%!O<W1A(&1E;"!S;VPZ`%-U<&5R
M[6YD97@`07-S:7-TZ&YC:6$`4W5R:6YA;0!#;V=N;VT`4W9A;&)A<F0@:2!*
M86X@36%Y96X`4W=A>FELX&YD:6$`4W7H8VEA`%-U[W-S80!%<G)O<B!D92!S
M:6YT87AI(&5N(&5L<R!T97)M97,@9&4@8V5R8V$`4F5P^F)L:6-A(,!R86(@
M4VER:6%N80!496UP97-T80!496UP97-T82!I('9E;G3S<P!496UP97-T97,`
M07)X:74@5%-6`%!R;W!I971A=',@9&4@=&%U;&$`4')O<&EE=&%T<R!D92!T
M875L80!486EW86X`5&%I=V%N+"!P<F]V[6YC:6$@9&4@;&$@6&EN80!4861J
M:6MI<W1A;@!486YZX&YI82P@4F5P^F)L:6-A(%5N:61A(&1E`$]B:F5C=&EU
M.@!487-Q=65S`$[Z;65R;R!D92!T96SH9F]N`%1E;7!E<F%T=7)A(&1U<F%N
M="!L82!D87)R97)A(&AO<F$Z(`!496UP97)A='5R80!496UP97)A='5R83H@
M`$%D;6EN:7-T<F%C:?,@9&4@<&QA;G1I;&QE<P!497AT`$YO;>ES('1E>'0`
M06QI;F5A8VGS(&1E('1E>'0`06QI;F5A="!A(&1A;'0`1&HN`%1A:6QA;F3H
M<R`H5$E3+38R,"D`5&%I;.!N9&EA`$PG97AT96YS:?,@1E10(&YO(&5S=.`@
M9&ES<&]N:6)L92X`16P@;6]T;W(@9"=I;G1E9W)A8VGS($AO<F1E+TMO;&%B
M(&YO('!E<FUE="!L)_IS(&1E("(E<R(`3&$@8VQA<W-E($UA:6YT96YA;F-E
M.CH@;F\@<R=H82!C87)R96=A="!C;W)R96-T86UE;G0C(P!3)VAA('1A;F-A
M="!L82!F:6YE<W1R82!D)V]P8VEO;G,N(%-O<G1I;G0@9&5L('-I<W1E;6$`
M4VD@=F]L974@=71I;&ET>F%R(&5L<R!P97)M:7-O<RP@;"=A9&UI;FES=')A
M9&]R(&AA(&1E(&-O;F9I9W5R87(@=6X@;6]T;W(@9&4@<&5R;6ES;W,@<&5R
M;6%N96YT+@!.;VWI<R!E;"!C;VYT;W)N(&EN9F5R:6]R`$5L(&[Z;65R;R!I
M9&5N=&EF:6-A9&]R(&1E;"!C;VYT86-T92!N;R!S)VAA(&5S<&5C:69I8V%T
M+"!S)VAA(&1E:7AA="!E;B!B;&%N8R!O(&YO(',G:&$@=')O8F%T(&$@;&$@
M8F%S92!D92!D861E<RX`4R=H82!A9F5G:70@8V]R<F5C=&%M96YT(&5L(&-O
M;G1A8W1E(&$@;&$@;&QI8G)E=&$@9"=A9')E8V5S+@!%<R!N96-E<W-I=&$@
M96P@8FQO8R!D92!S:6=N871U<F5S(%!'4"!S97!A<F%T('!E<B!V97)I9FEC
M87(@96P@;6ES<V%T9V4@<VEG;F%T+@!,)VED96YT:69I8V%D;W(@9&4@;&$@
M;&QI<W1A(&1E(&1I<W1R:6)U8VGS(&YO(',G:&$@97-P96-I9FEC870L(',G
M:&$@9&5I>&%T(&5N(&)L86YC(&\@;F\@<R=H82!T<F]B870@82!L82!B87-E
M(&1E(&1A9&5S+@!.;R!S)VAA(&5S<&5C:69I8V%T(&QA(&QL:7-T82!D92!D
M:7-T<FEB=6-I\RX`3&5S(&-A<F%C=&5R[7-T:7%U97,@9&5L('AI9G)A=&=E
M(&5X:6=E:7AE;B!U;F$@8V]N;F5X:?,@=V5B(&9I86)L92X`3"=A<GAI=2`E
M<R!H875R:6$@9&4@8V]N=&5N:7(@=6X@<&%RX&UE=')E("5S+@!,)V%R>&EU
M("5S(&AA=7)I82!D92!C;VYT96YI<B!A;&=U;G,@<&%RX&UE=')E<R`E<RX`
M3"=A<GAI=2!N;R!C;VYT96YI82!D861E<RX`02!C;VYT:6YU86-I\R!E<R!P
M<F5S96YT96X@;&5S(&-A<.=A;&5R97,@9"=A<75E<W0@;6ES<V%T9V4O;6ES
M<V%T9V4@<F9C.#(R+@!3)VAA(&-O;G-T871A="!Q=64@96P@;6]D92!D92!P
M86YT86QL82!C;VUP;&5T82!D\VYA('!R;V)L96UE<R!A;6(@26YT97)N970@
M17AP;&]R97(@82!C875S82!D)V5R<F]R<R!E;B!E;"!N879E9V%D;W(@<75E
M(&YO(&AE;2!P;V=U="!R97-O;&1R92X@4&]T('-E<B!Q=64@=FES=6%L:71Z
M974@8G)O<W-A+"!U<R!M86YQ=6EN(&9U;F-I;VYS(&5N(&PG961I=&]R(&DO
M;R!Q=64@96P@;F%V96=A9&]R('5S(&9A;&QI(&1E(&UA;F5R82!A;&5A=/)R
M:6$N(%-I('1E;FEU(&5L('-I<W1E;6$@5VEN9&]W<R`Y>"#I<R!M;VQT('!R
M;V)A8FQE('%U92!E<R!P<F]D=65I>&D@=6X@)V5R<F]R(&1E('!R;W1E8V-I
M\R!G96YE<F%L)R!I(&AA9W5E=2!D92!R96EN:6-I87(@9&4@;F]U+B!3:2P@
M=&]T(&D@87%U97-T(&%D=F5R=&EM96YT+"!E;F-A<F$@=F]L974@<')O=F%R
M(&PG961I=&]R(&1E('!A;G1A;&QA(&-O;7!L971A+"!P<F5M974@1"=A8V]R
M9"X`4R=H82!S=7!R:6UI="!L82!I9&5N=&ET870@(B5S(BX`3F]MZ7,@96P@
M8V]S=&%T(&5S<75E<G)E`$QA('5B:6-A8VGS(&1E;"!B:6YA<FD@1VYU4$<@
M<R=H82!D)VEN9&EC87(@82!L82!C;&%S<V4@0W)Y<'1?<&=P+@!3)VAA(&UO
M<W1R870@96P@;6ES<V%T9V4@96YV:6%T(&5L("5S(&$@)7,@86UB(&PG87-S
M=6UP=&4@(B5S(BX@06EX\B!N;R!G87)A;G1E:7@@<75E(',G:&%G:2!L;&5G
M:70@;R!E;G3H<R!E;"!M:7-S871G92X`16P@;F]M('%U92!S)VAA(&0G=71I
M;&ET>F%R(&5N(&5N;&QAYV%R(&%M8B!#<F5A<B!PX&=I;F$`17,@;F5C97-S
M:71A(&5L(&WR9'5L(&]P96YS<VP@<&5R(&$@;&$@8VQA<W-E($AO<F1E7T-R
M>7!T7W-M:6UE+@!.;R!S)VAA('!O9W5T(&1E<V%R(&QA('!R969E<NAN8VEA
M("(E<R(@<&5R<77H(&QA(&EN9F]R;6%C:?,@<75E(&-O;G1E;FEA('-U<&5R
M879A(&QA(&UI9&$@;>!X:6UA('!E<FUE<V$N`$YO(',G:&$@=')O8F%T(&5N
M(&5L('-I<W1E;6$@96P@<')O9W)A;6$@=7-A="!P97(@=FES=6%L:71Z87(@
M87%U97-T('1I<'5S(&1E(&1A9&5S("@E<RDN`$YO;>ES(&5L<R!C;W-T871S
M(&1R970@:2!E<W%U97)R90!.;VWI<R!E;"!C;W-T870@9')E=`!3)VAA('-U
M<')I;6ET(&5L('-E<G9I9&]R("(E<R(N`%,G:&$@9&5S870@96P@<V5R=FED
M;W(@(B5S(BX`4R=H82!E;&EM:6YA="!L82!S;VRW;&EC:71U9"!D)V%L=&$@
M9&4@)7,N`$YO(&5X:7-T96EX(&PG87)X:74@=&5M<&]R86P@(B5S(BX`3F]M
MZ7,@96QS(&-O<W1A=',@<W5P97)I;W(@:2!I;F9E<FEO<@!.;VWI<R!E;"!C
M;W-T870@<W5P97)I;W(`4R=H86X@<&5R9'5T(&QE<R!D861E<R!C87)R96=A
M9&5S(&1E<R!D96P@<&%S(&%N=&5R:6]R+@!.;R!S)VAA('!O9W5T(&1E<V%R
M(&PG87)X:74@8V%R<F5G870N`$5L(&)L;V,@=V5A=&AE<BYC;VT@;F\@97-T
MX"!D:7-P;VYI8FQE+@!.;R!H:2!H82!C87`@;W!C:?,@9&ES<&]N:6)L92X`
M3F\@:&D@:&$@8V%P('!A<G0@<75E(&5S('!U9W5I(&UO<W1R87(@96X@;.UN
M:6$`07%U97-T(&-A;7`@8V]N=.D@;6%S<V$@8V%RX&-T97)S+B!(974@:6YT
M<F]D=>]T("5S(&-A<N!C=&5R<R!I(&XG:&5U(&0G:6YT<F]D=6ER(&UE;GES
M(&1E("5S+@!(:2!H82!H86=U="!U;B!P<F]B;&5M82!E;B!C87)R96=A<B!L
M)V%R>&EU.B!N;R!S)VAA(&-A<G)E9V%T("5S+@!(:2!H82!H86=U="!U;B!P
M<F]B;&5M82!E;B!C87)R96=A<B!L)V%R>&EU.B!E;"`E<R!E<F$@<W5P97)I
M;W(@82!L82!M:61A(&W@>&EM82!P97)M97-A("@E(&)Y=&5S*2X`2&D@:&$@
M:&%G=70@=6X@<')O8FQE;6$@96X@8V%R<F5G87(@;"=A<GAI=3H@;F]MZ7,@
M<R=H82!C87)R96=A="!P87)C:6%L;65N="!E;"`E<RX`4R=H82!P<F]D=>]T
M('5N(&5R<F]R(&5N(&UO<W1R87(@87%U97-T82!P87)T(&1E;"!M:7-S871G
M90!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@:6UP;W)T87(@;&5S(&1A9&5S
M(&1E(&-O;G1A8W1E+@!3)VAA('!R;V1U[W0@=6X@97)R;W(@96X@:6UP;W)T
M87(@;&5S(&1A9&5S(&E#86QE;F1A<BX`4R=H82!P<F]D=>]T('5N(&5R<F]R
M(&5N(&5L(&9O<FUU;&%R:2!D92!C;VYF:6=U<F%C:?,N(%!O='-E<B!U<R!H
M974@9&5S8W5I9&%T(&0G96UP;&5N87(@=6X@8V%M<"!N96-E<W-A<FDN`%,G
M:&$@<')O9'7O="!U;B!E<G)O<B!E;B!E>&5C=71A<B!L82!F=6YC:?,@97-P
M96-I9FEC861A(&1E(&QA(&QL:6)R971A(&0G861R96-E<RX@5&]R;F5U+6AO
M(&$@:6YT96YT87(@;>ES('1A<F0N`%,G:&$@<')O9'7O="!U;B!E<G)O<B!E
M;B!A8W1U86QI='IA<B!E;',@9&5T86QL<R!D92!C;VYT86-T92X@5&]R;F5U
M+6AO(&$@:6YT96YT87(@;>ES('1A<F0N`%,G:&$@<')O9'7O="!U;B!E<G)O
M<B!E;B!A8W1U86QI='IA<B!L82!L;&ES=&$@9&4@9&ES=')I8G5C:?,N(%1O
M<FYE=2UH;R!A(&EN=&5N=&%R(&WI<R!T87)D+@!!<75E<W0@<V5R=FED;W(@
M24U!4"!N;R!P97)M970@;"?Z<R!D92!C87)P971E<R!C;VUP87)T:61E<RX`
M3F\@<V5M8FQA('%U92!S:6=U:2!U;B!A<GAI=2!R87(@=N!L:60N`$YO('-E
M;6)L82!Q=64@<VEG=6D@=6X@87)X:74@>FEP(';@;&ED+@!.;R!S96UB;&$@
M<75E(&%Q=65S="!N^FUE<F\@9&4@=&%R9V5T82!S:6=U:2!VX&QI9"X`07%U
M97-T(&-O;G1R;VQA9&]R('!E<FUE="!E;G9I87(@;6ES<V%T9V5S('!E<B!M
M:71JX"!D92!L82!P87-S87)E;+=L82!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI+"!U=&EL:71Z86YT(&QA($%022!(5%10`$%Q=65S="!C
M;VYT<F]L861O<B!P97)M970@96YV:6%R(&UI<W-A=&=E<R!P97(@;6ET:N`@
M9&4@;&$@<&%S<V%R96RW;&$@<VUS,F5M86EL("AH='1P.B\O<VUS,F5M86EL
M+F-O;2D@=71I;&ET>F%N="!L82!!4$D@2%144`!!<75E<W0@8V]N=')O;&%D
M;W(@<&5R;65T(&5N=FEA<B!M:7-S871G97,@<&5R('9I82!D92!33510(&$@
M=')A=NES(&1E(&QA('!A<W-A<F5LMVQA(%9O9&%F;VYE(&0G273@;&EA+"!N
M;VWI<R!A(&[Z;65R;W,@5F]D869O;F4N($-A;"!T96YI<B!U;B!C;VUP=&4@
M9&4@8V]R<F5U(&5L96-T<O)N:6,@86UB(%9O9&%F;VYE(&0G273@;&EA("AH
M='1P.B\O=W=W+C$Y,"YI="DN`,ES(&YE8V5S<V%R:2!A<75E<W0@8V%M<"X`
M07%U97-T(&-A;7`@;F]MZ7,@<&]T(&-O;G1E;FER(&YO;6)R97,@96YT97)S
M+@!!<75E<W0@8V%M<"!N;VWI<R!P;W0@8V]N=&5N:7(@;F]M8G)E<R!I(&5L
M<R!D;W,@<'5N=',N`$%Q=65S="!C86UP(&YO;>ES('!O="!C;VYT96YI<B!V
M86QO<G,@;V-T86QS+@!!<75E<W0@8V%M<"!H82!D92!S97(@=6YA(&QL:7-T
M82!D92!N;VUB<F5S(&5N=&5R<R!S97!A<F%T<R!P97(@8V]M97,@;R!E<W!A
M:7,N`$%Q=65S="!C86UP(&AA(&1E('-E<B!U;B!N^FUE<F\@=N!L:60N`$%Q
M=65S="!C86UP(&AA(&1E(&-O;G1E;FER('5N(&-O9&D@9&4@8V]L;W(@9&4@
M9F]R;6%T(%)'0B!H97AA9&5C:6UA;"P@<&5R(&5X96UP;&4@)R,Q,C,T868G
M+@!*82!S)VAA('!R;V-E<W-A="!A<75E<W0@9F]R;75L87)I+@!!:7CR(.ES
M("5S+@!!:7CR(.ES('5N(&]B:F5C=&4@9&4@2V]L86(@1W)O=7!W87)E+B!0
M97(@=FES=6%L:71Z87(@87%U97-T(&]B:F5C=&4L('5S(&-A;"!U;B!C;&EE
M;G0@9&4@8V]R<F5U(&5L96-T<O)N:6,@<75E(&%D;65T:2!E;"!F;W)M870@
M9&4@2V]L86(@1W)O=7!W87)E+B!097(@=&5N:7(@86-CZ7,@82!U;F$@;&QI
M<W1A(&0G87%U97-T<R!C;&EE;G1S(&1E(&-O<G)E=2!E;&5C='+R;FEC+"!V
M:7-I=&5U("5S`$%Q=65S="!M:7-S871G92!V82!S97(@97-C<FET(&%M8B!U
M;B!J;V,@9&4@8V%RX&-T97)S("@E<RD@9&EF97)E;G0@9&5L('9O<W1R92X`
M07%U97-T(&[Z;65R;R!H82!D92!S97(@8V]M(&$@;>UN:6T@=6X@,2X`07%U
M97-T('-E<G9I9&]R(&YO('!O="!D97-C;VUP<FEM:7(@87)X:75S('II<"!I
M(&=Z:7`N`$%Q=65S="!S:7-T96UA(&5S=.`@9&5S86-T:79A="!A8W1U86QM
M96YT+@!!<75E<W0@=F%L;W(@:&$@9&4@<V5R('5N(&[Z;65R;RX`07%U97-T
M82!F:6YE<W1R82!S)VAA(&1E(&-R:61A<B!D97,@9"=U;F$@9FEN97-T<F$@
M9"=O<&-I;VYS`%1R;P!4:7%U971S`$AO<F$`0V]N=')O;"!D92!T96UP<P!&
M;W)M870@:&]R87)I`%-E;&5C8VGS(&1E('1E;7!S`%1I;6]R($]R:65N=&%L
M`%3M=&]L`%3M=&]L("ARZ'1O;"!I;F1I8V%D;W(@9&4@9G5N8VGS*3H`00!0
M97(@<V5L96-C:6]N87(@9&EV97)S;W,@96QE;65N=',L(&UA;G1I;F=U974@
M<&ET:F%D82!L82!T96-L82!#;VYT<F]L("A00RD@;R!#;VUM86YD("A-86,I
M(&UE;G1R92!C;&EQ=65U+@!!=G5I`$-O;6UU=&5U(&QA(&9O;G0@2%1-3`!4
M;V=O`%1O:V5L874`1&5MX`!4;VYG80!3=7!E<FEO<@!-87)C('-U<&5R:6]R
M("A?<W5P97)I;W(I`%1R861U8V-I;VYS`%1R:6YI=&%T(&D@5&]B86=O`%9E
M<FET870@;R!F86QS`$1T+@!4=6[M<VEA`%1U<G%U:6$`5'5R8R`H25-/+3@X
M-3DM.2D`5'5R:VUE;FES=&%N`$EL;&5S(%1U<FMS(&D@0V%I8V]S`%1U=F%L
M=0!496-L96=E=2!L82!V;W-T<F$@;W!C:?,Z(`#-;F1E>"!55CH@`%523`!5
M4DP@9&5L('9O<W1R92!I;F9O<FUE(&1E(&PG97-T870@9&4@=')A;65S82!D
M92!L82!S97'\Z&YC:6$`55),.@!59V%N9&$`56-R8>]N80!.;R!S)VAA('!O
M9W5T(&%C8V5D:7(@86P@9&ER96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!A
M9F5G:7(@;>ES(&1A9&5S(&1E(&PG=7-U87)I(&5N(&5F96-T=6%R(&PG86QT
M82X`3F\@<R=H82!P;V=U="!C86YV:6%R(&5L('!E<FWM<R!D92!L)V%R>&EU
M(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@<&5R;>US(&1E
M(&PG87)X:74@5D93("5S+R5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@82`E
M<RX`3F\@<R=H82!P;V=U="!C;VYN96-T87(@86P@<V5R=FED;W(@4U%,+@!.
M;R!S)VAA('!O9W5T(&-O;FYE8W1A<B!A;6(@4U-,+@!.;R!S)VAA('!O9W5T
M(&-O<&EA<B!L)V%R>&EU(%9&4RX`3F\@<R=H82!P;V=U="!C<F5A<B!E;"!D
M:7)E8W1O<FD@5D93("(E<R(N`$YO(',G:&$@<&]G=70@8W)E87(@96P@9&ER
M96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!C<F5A<B!L)V%R>&EU(%9&4RX`
M3F\@<R=H82!P;V=U="!C<F5A<B!L82!C87)P971A(%9&4R`B)7,B+@!.;R!S
M)VAA('!O9W5T(&-R96%R('5N(&%R>&EU(%9&4R!B=6ET+@!.;R!S)VAA('!O
M9W5T(&1E<V-O;7!R:6UI<B!L97,@9&%D97,N`$YO(',G:&$@<&]G=70@<W5P
M<FEM:7(@(B5S(BP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I="X`3F\@<R=H
M82!P;V=U="!S=7!R:6UI<B`E<RP@96P@9&ER96-T;W)I(&YO(&5S=.`@8G5I
M="X`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!E;"!D:7)E8W1O<FD@5D93(&1E
M(&UA;F5R82!R96-U<G-I=F$N`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@96P@
M9&ER96-T;W)I(%9&4RX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!E;"!D:7)E
M8W1O<FD@5D93.B`E<RX`3F\@<R=H82!P;V=U="!S=7!R:6UI<B!L)V%R>&EU
M(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T('-U<')I;6ER(&PG87)X:74@5D93
M+@!.;R!S)VAA('!O9W5T('-U<')I;6ER(&QA(&-A<G!E=&$@5D93("(E<R(N
M`$YO(',G:&$@<&]G=70@<W5P<FEM:7(@5D93(&1E(&UA;F5R82!R96-U<G-I
M=F$Z("5S+@!.;R!S)VAA('!O9W5T(&1E=&5R;6EN87(@96P@9&ER96-T;W)I
M(&%C='5A;"X`3F\@<R=H82!P;V=U="!E>'1R975R92!E;',@9&5T86QL<R!D
M96P@8V5R=&EF:6-A="X`3F\@<R=H82!P;V=U="!C87)R96=A<B!L82!D969I
M;FEC:?,@9&4@)7,N`$YO(',G:&$@<&]G=70@;6]U<F4@;"=A<GAI=2!61E,N
M`$YO(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,@(B5S(BX`3F\@<R=H
M82!P;V=U="!O8G)I<B!L)V%R>&EU(%9&4R!P97(@97-C<FEU<F4M:&DN`$YO
M(',G:&$@<&]G=70@;V)R:7(@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@
M;V)R:7(@;"=A<GAI=2!C;VUP<FEM:70N`$YO(',G:&$@<&]G=70@;&QE9VER
M(&PG87)X:74@5D93("AL82!M:61A(&1E(&PG87)X:74H*2!H82!D;VYA="!E
M<G)O<BDN`$YO(',G:&$@<&]G=70@;&QE9VER(&PG87)X:74@5D93("AG971&
M:6QE4VEZ92@I(&AA(&1O;F%T(&5R<F]R*2X`3F\@<R=H82!P;V=U="!L;&5G
M:7(@;"=A<GAI=3H@+@!.;R!S)VAA('!O9W5T(&QL96=I<B!E;"!D:7)E8W1O
M<FD@87)R96P@9&4@5D93+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M
M(&1E("5S('!E<B`E<SH@;&$@8V%R<&5T82!D92!D97-T:6YA8VGS(&IA(&5X
M:7-T96EX`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I<F5C
M=&]R:2!61E,N`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E;"!N;VT@9&5L(&1I
M<F5C=&]R:2!61E,Z("5S+@!.;R!S)VAA('!O9W5T(&-A;G9I87(@96P@;F]M
M(&1E(&PG87)X:74@5D93("(E<R(N`$YO(',G:&$@<&]G=70@8V%N=FEA<B!E
M;"!N;VT@9&4@;"=A<GAI=2!61E,@)7,O)7,N`$YO(',G:&$@<&]G=70@8V%N
M=FEA<B!E;"!N;VT@9&4@;"=A<GAI=2!61E,N`$YO(',G:&$@<&]G=70@97AE
M8W5T87(@)VUK:7-O9G,G+@!.;R!S)VAA('!O9W5T('1R861U:7(@87%U97-T
M(&1O8W5M96YT(&1E(%=O<F0`3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R
M>&EU(%9&4R`B)7,B+@!.;R!S)VAA('!O9W5T(&5S8W)I=7)E(&PG87)X:74@
M5D93("@C<R=H82!P<F]D=>]T('5N(&5R<F]R(&5N(&-O<&EA<BUL;R@I(",I
M+@!.;R!S)VAA('!O9W5T(&5S8W)I=7)E(&QE<R!D861E<R!D92!L)V%R>&EU
M(%9&4RX`3F\@<R=H82!P;V=U="!E<V-R:75R92!L)V%R>&EU(%9&4RP@<V4@
M<W5P97)A<N`@;"=E<W!A:2!D:7-P;VYI8FQE+@!3=6)R871L;&%T`$1E<V;I
M<R!E;',@8V%N=FES`$1E<V;@(&QA(&1A<G)E<F$@86-C:?,`16P@<V5R=FED
M;W(@:&$@9&]N870@=6YA(')E<W!O<W1A(&EN97-P97)A9&$@96X@8V]N;F5C
M=&%R+7-E.B``16P@<V5R=FED;W(@:&$@9&]N870@=6YA(')E<W!O<W1A(&EN
M97-P97)A9&$@83H@`%-E;G-E(&-A=&5G;W)I80!5;FEC;V1E("A55$8M."D`
M56YI\R!D96QS($5M:7)A=',@P')A8G,`4F5G;F4@56YI=`!%<W1A=',@56YI
M=',`26QL97,@4&5R:6;H<FEQ=65S($UE;F]R<R!D96QS($5S=&%T<R!5;FET
M<P!5;FET871S`$1E<V-O;F5G=70`87!I;7-G:60@*&ED96YT:69I8V%D;W(@
M9&5L(&UI<W-A=&=E(&1E(&QA($%022D@9&5S8V]N96=U="X`0VQI;7-G:60@
M9&5S8V]N96=U="`H:61E;G1I9FEC861O<B!D96P@;6ES<V%T9V4@9&5L(&-L
M:65N="DN`%,G:&$@<')O<&]R8VEO;F%T('5N82!U8FEC86-I\R!D97-C;VYE
M9W5D82X`3F]M(&0G=7-U87)I(&\@8V]N=')A<V5N>6$@9&5S8V]N96=U=',N
M`$1E<V5N;&QAYV%R(&PG96QE;65N="!A8W1U86P`4V5N<V4@;F]M`$QE<R!S
M97'\Z&YC:65S('-E;G-E('!E<FUI<V]S(&YO('!O9&5N(&%C8V5D:7(@82!2
M971A;&QA<B]#;W!I87(O16YG86YX87(@9&4@;6%N97)A('!R;V=R86W@=&EC
M82!P97(@<F%O;G,@9&4@<V5G=7)E=&%T+B!#;&EQ=65U(&5N($0G86-O<F0@
M<&5R('9I<W5A;&ET>F%R('5N82!N;W1A('3H8VYI8V$@82!M;WII;&QA+F]R
M9R!Q=64@=7,@;6]S=')A(&-O;2!P;V1E=2!F97(@<75E('5N82!S97'\Z&YC
M:6$@86-C961E:7AI(&%L('!O<G1A+7)E=&%L;',N(`!%;&EM:6YA<B!E;"!C
M;VQO<@!%>'1E;G-I\R!N;R!I;7!L96UE;G1A9&$`06-T=6%L:71Z87(`06-T
M=6%L:71Z87(@)7,`06-T=6%L:71Z87(@;"=U<W5A<FD`4R=H82!S=7!R:6UI
M="!L82!S97'\Z&YC:6$@9"=A8W1U86QI='IA8VGS+@!#87)R96=A<@!3)VAA
M(&-A<G)E9V%T(&%L('-E<G9I9&]R('1O=',@96QS(&%R>&EU<R!D92!C;VYF
M:6=U<F%C:?,@9"=A<&QI8V%C:6]N<RX`06QF86)E="!L;&%T[2!E;B!M86KZ
M<V-U;&$`6&EF<F5S(')O;6%N97,@96X@;6%J^G-C=6QA`%5R=6=U86D`571I
M;&ET>F%R(&PG86-T=6%L.B`E<P!5=&EL:71Z87(@4U-,`%5T:6QI='IE=2!S
M:2!E;"!N;VT@;R!L82!C;VYT<F%S96YY82!S\VX@9&EF97)E;G1S(&%L('-E
M<G9I9&]R($E-4U`N`$PG=7-U87)I("5S(&YO(&5S=.`@875T;W)I='IA="!P
M97(@82`E<RX`061M:6YI<W1R86-I\R!D)W5S=6%R:7,`3W!C:6]N<R!D)W5S
M=6%R:0!296=I<W1R92!D)W5S=6%R:7,`16P@<F5G:7-T<F4@9"=U<W5A<FES
M(&0G87%U97-T(&QL;V,@97-TX"!I;FAA8FEL:71A="X`3F]M(&0G=7-U87)I
M`$YO;2!D)W5S=6%R:3H`3F]M(&0G=7-U87)I.B``57-U87)I<R!D96P@<VES
M=&5M83H`57IB96MI<W1A;@!%;"!D:7)E8W1O<FD@5D93(&YO(&5X:7-T96EX
M+@!!8G/H;F-I80!,97,@=6)I8V%C:6]N<R!VX&QI9&5S('%U92!S)VAA;B!T
M<F]B870@<_-N.@!686QI9&5S80!686QO<B!E;B!M:6YU=',@82!P87)T:7(@
M9"=A<F$N`$5L('9A;&]R('-U<&5R82!L82!L;VYG:71U9"!MX'AI;6$@9&4@
M)7,N`%9A;&]R<P!686QO<G,@<75E(',G:&%N('-E;&5C8VEO;F%R(&1E`%9A
M;G5A='4`5F%R:6%B;&4`5F5N9>=U96QA`$AA(&9A;&QA="!L82!V97)I9FEC
M86-I\SH@Z7,@<&]S<VEB;&4@<75E(',G:&%G:2!A;'1E<F%T(&5L(&UI<W-A
M=&=E+@!697)S:?,`0V]N=')O;"!D92!V97)S:6]N<P!!;&EN96%C:?,@=F5R
M=&EC86P`1F%R8VEM96YT('9E<G1I8V%L`%9E<G1I8V%L.@!-;VQT(&%L=`!6
M:65T;F%M`%9I971N86UI=&$@*%9)4T-)22D`5FES=6%L:71Z87(@)7,`5FES
M=6%L:71Z87(@=6YA('#@9VEN82!W96(@97AT97)N80!6:7-U86QI='IA<B!C
M;VT@82`E<P!);&QE<R!697)G97,@8G)I=.!N:7%U97,`26QL97,@5F5R9V5S
M(&YO<F0M86UE<FEC86YE<P!6:7-I8FEL:71A=`!6:7-I8FEL:71A=#H@`%9O
M9&%F;VYE(&0G273@;&EA('!E<B!V:6$@9&4@4TU44`!!1%9%4E3(3D-)00!!
M5LU3(2!%3$E-24Y!4B!,02!315'<R$Y#24$@34%.54%,345.5"!$12`E<RX`
M5V%L;&ES(&D@1G5T=6YA`$%V[7,`1&,N`%!R979I<VGS(&1E;"!T96UP<P!)
M;F9O<FUA8VGS(&UE=&5O<F]L\F=I8V$@<')O<&]R8VEO;F%D82!P97(`5V5A
M=&AE<BYC;VT`5V5B`$QL;V,@=V5B`%-E=&UA;F%L;65N=`!"96YV:6YG=71S
M`$)E;G9I;F=U=',@82`E<P!"96YV:6YG=71S+"`E<P!/8V-I9&5N=&%L("A)
M4T\M.#@U.2TQ*0!/8V-I9&5N=&%L("A)4T\M.#@U.2TQ-2D`4^!H87)A($]C
M8VED96YT86P`475I;F$@87!L:6-A8VGS(&AA=7)I82!D92!M;W-T<F%R("5S
M(&5N(&EN:6-I87(@;&$@<V5S<VGS/P!1=6EN(.ES(&5L(&-A<N!C=&5R(&1E
M;&EM:71A9&]R/P!1=6EN(.ES(&5L(&-A<N!C=&5R(&1E(&-I=&%C:?,_`%%U
M:6YE<R!F87-E<P!0;'5G:6YS(&AA8FEL:71A=',@9&4@;"=E9&ET;W(@9&4@
M=&5X="!E;G)I<75I="X`06UP;&%D80!!;7!L861A(&1E(&QE<R!U;FET871S
M($-34P!!;7!L861A(&1E;"!M96[Z("5S(&1E(&PG97-Q=65R<F$@*&1I<W!O
M;FEB;&4@96X@;&$@<')O<&5R82!S97-S:?,I.@!!;7!L861A(&1E(&QA('1A
M=6QA`%5N:71A="!D)V%M<&QA9&$`06UP;&%D83H`5VEK:0!696YT`%9E;G0@
M82!P<FEM97)A(&AO<F$`5F5L;V-I=&%T(&1E;"!V96YT(&5N(&YU<V]S`%9E
M;G0Z`%9E;G0Z(`!3879I97-A`$9E:6YA`$%D<F7G82!D92!L82!F96EN80!4
M96SH9F]N(&1E(&QA(&9E:6YA`%@M4F5F`$QI;6ET86-I;VYS(&+@<VEQ=65S
M(%@U,#EV,P#:<R!D92!L82!C;&%U(&5S=&5S82!X-3`Y=C,`3F]M(&%L=&5R
M;F%T:74@9"=A<W-U;7!T92!8-3`Y=C,`261E;G1I9FEC861O<B!D92!C;&%U
M(&0G87-S=6UP=&4@6#4P.78S`$5X=&5N<VEO;G,@6#4P.'8S`$%!`$%!04$`
M36%P82!D92!986AO;R$`06YU86QM96YT`$EE;65N`%/M`%/M+"!H;R!A8V-E
M<'1O`%-O=2!E;B!E;"!-3T1%(%1%6%0N(%5S974@96P@8F]T\R!;/#Y=('!E
M<B!T;W)N87(@82!765-)5UE'+@!.;R!E<W1E=2!A=71E;G1I8V%T<RX`3F\@
M:&5U(&EN=')O9'7O="!U;F$@861R9>=A(&5L96-T<O)N:6-A(';@;&ED82X`
M3F\@:&5U(&%S<V]C:6%T(&-A<"!C86UP(&1E(&PG87)X:74@:6UP;W)T870@
M86UB(&5L<R!C86UP<R!C;W)R97-P;VYE;G1S(&1E("5S+@!(974@<V]R=&ET
M(&1E(&QA('-E<W-I\RX`2&5U(&0G:6YT<F]D=6ER('5N(&[Z;65R;R!D92!T
M96SH9F]N(&WR8FEL(';@;&ED+"!N;VWI<R!D[6=I=',@86UB('5N("<K)R!O
M<&-I;VYA;"!P97(@86P@<')E9FEX(&1E('1R=6-A9&$@:6YT97)N86-I;VYA
M;"X`2&5U(&0G:6YT<F]D=6ER('5N('9A;&]R(';@;&ED+@!(974@9&4@8V]N
M9FEG=7)A<B!U;B!M;W1O<B!D92!$871A5')E92!P97(@=71I;&ET>F%R($%L
M=&5S+@!(974@9&4@8V]N9FEG=7)A<B!U;B!M;W1O<B!D92!61E,N`$AE=2!D
M92!D97-C<FEU<F4@96P@<')O8FQE;6$@86)A;G,@9"=E;G9I87(M;F4@;"=I
M;F9O<FUE+@!(974@9"=I;G1R;V1U:7(@96P@55),('%U92!A<75E<W0@96YL
M;&'G(&EN9&EC82X`2&5U(&1E('-E;&5C8VEO;F%R('5N('-E<G9I9&]R('%U
M92!V=6QG=65U(&5L:6UI;F%R+@!(974@9"=E<W!E8VEF:6-A<B!U;B!N;VT@
M9"=U<W5A<FD@<75E('9U;&=U974@97-B;W)R87(N`$AE=2!D)V5S<&5C:69I
M8V%R('5N(&YO;2!D)W5S=6%R:2!Q=64@=G5L9W5E=2!S=7!R:6UI<BX`2&5U
M(&0G97-P96-I9FEC87(@<75I;B!N;VT@9"=U<W5A<FD@=F]L974@869E9VER
M+@!(974@9"=E<W!E8VEF:6-A<B!E;"!N;VT@9"=U<W5A<FD@<75E('9O;&5U
M(&%C='5A;&ET>F%R+@!(974@9"=E<W!E8VEF:6-A<B!Q=6EN82!A8V-I\R!V
M;VQE=2!E>&5C=71A<BX`2&5U(&1E('1E8VQE:F%R('5N(&YO=2!N;VT@9&4@
M8V%T96=O<FEA+@!,82!V;W-T<F$@<V5S<VGS(&5N("5S(&AA(&5X<&ER870N
M(%-I('5S('!L874L(&EN:6-I974@=6YA(&YO=F$@<V5S<VGS+@!,82!V;W-T
M<F$@861R9>=A(&5L96-T<O)N:6-A`$QA('1E=F$@861R9>=A(&1E(')E<W!O
M<W1A`$QA('9O<W1R82!I;F9O<FUA8VGS`$QA('9O<W1R82!A9')EYV$@9"=)
M;G1E<FYE="!H82!C86YV:6%T(&1E<R!Q=64@:&5U(&-O;65NYV%T(&QA('-E
M<W-I\R`E<RX@4&5R(')A;VYS(&1E('-E9W5R971A="P@:&5U(&1E(')E:6YI
M8VEA<B!L82!S97-S:?,N`$5L('9O<W1R92!N;VT`16P@=F]S=')E(&UO=&]R
M(&0G875T96YT:6-A8VGS(&YO('!E<FUE="!Q=64@97,@;&QI<W1I;B!E;',@
M=7-U87)I<RP@;R!BZ2!P97(@86QG=6YA(')A\R!A<75E<W1A(&-A<F%C=&5R
M[7-T:6-A(&5S=.`@:6YH86)I;&ET861A+@!396UB;&$@<75E(&5L(&YA=F5G
M861O<B!H82!C86YV:6%T(&1E<R!Q=64@=F%U(&-O;65NYV%R(&QA('-E<W-I
M\R`E<RX@4&5R(')A;VYS(&1E('-E9W5R971A="P@:&5U(&1E('1O<FYA<B!A
M(&5N=')A<B!A;"!S:7-T96UA+@!%;"!V;W-T<F4@;F%V96=A9&]R(&YO(&%C
M8V5P=&$@87%U97-T82!C87)A8W1E<NUS=&EC82X`16P@=F]S=')E(&YA=F5G
M861O<B!N;R!P97)M970@87%U97-T82!O<&-I\R!D)VEM<')E<W-I\RX@4')E
M;6D@0V]N=')O;"`K(%`@<&5R(&EM<')I;6ER+@!:;VYA(&AO<N!R:6$@86-T
M=6%L.@!)9&5N=&ET870@<')E9&5T97)M:6YA9&$Z`$YO;2!C;VUP;&5T.@!,
M82!N;W9A(&-O;G1R87-E;GEA('!E<B!A("5S(.ES.B`E<P!,97,@;W!C:6]N
M<R!H86X@97-T870@86-T=6%L:71Z861E<R!P97(@82!L82!D=7)A9&$@9"=A
M<75E<W1A('-E<W-I\RX`3&5S(&]P8VEO;G,@:&%N(&5S=&%T(&%C='5A;&ET
M>F%D97,N`%,G:&$@<F5I;FEC:6%T(&QA('9O<W1R82!C;VYT<F%S96YY80!3
M)VAA(')E:6YI8VEA="!L82!V;W-T<F$@8V]N=')A<V5N>6$L(')E=FES82!E
M;"!C;W)R974@96QE8W1R\FYI8R!I(&EN:6-I82!L82!S97-S:?,@86UB(&QA
M(&YO=F$@8V]N=')A<V5N>6$N`%-E<G9I9&]R<R!R96UO=',Z`$EU9V]S;.!V
M:6$`6F%I<F4`6N!M8FEA`%II;6)A8G=E`%II<'!Y`%M/8W5L=&$@=&5X="!C
M:71A=%T`6TEN9F]R;64@9&5L('!R;V)L96UA70!;36]S=')A('1E>'0@8VET
M870@+0!;36]S=')A('1E>'0@8VET870@+2`E<R!L[6YI97-=`%ML[6YI82`E
M<R!D92`E<UT`7T%D;6YI<W1R86-I\P!?0TQ)`%]!<F)R92!D92!D861E<P!?
M4W5P<FEM:7(@9FEL80!?1W)U<',`7T%J=61A`%]0<F]P:65T871S(&1E(&QA
M(&EM871G92XN+@!?26YI8VEA(&QA('-E<W-I\P!?4W5R=`!?36]D:69I8V$@
M;"=E;FQL8><N+BX`7T]P8VEO;G,`7U!E<FUI<V]S`%]%;&EM:6YA(&PG96YL
M;&'G+BXN`%]#;VYF:6=U<F%C:?,`7U!R;W!I971A=',@9&4@;&$@=&%U;&$N
M+BX`7U5S=6%R:7,`;&QI8G)E=&$@9"=A9')E8V5S`&%G96YD80!C86QM80!0
M<F5M:2!A<77M`&5S=.`@8V%I96YT`&%R>&EU`&1E<R!D96P@)7,@*"5S*2!A
M(&QE<R`E<R`E<P!H.@!H:`!I;6UE9&EA=`!I;G-E<F5I>`!L[6YI97-=`%,G
M:&$@<')O9'7O="!U;B!C;V1I(&0G97)R;W(@)60@9&5L(&UK:7-O9G,@96X@
M8W)E87(@25-/+@`C;6TC`&YO;0!N;R!S)VAA(&EM<&QE;65N=&%T`&5N8V%R
M82!N;R!S)VAA(&EM<&QE;65N=&%T`&)L;V,@9&4@;F]T97,`<&5R8V5N=&%T
M9V4`<.UX96QS`&5S=.`@<'5J86YT`&UO<W1R87(@9&EF97+H;F-I97,`<VUS
M,F5M86EL('!E<B!V:6$@9&4@2%144`!S<P!C;VYS=&%N=`!L;&ES=&$@9&4@
M=&%S<75E<P!T96-L96=E=2!L82!C;VYT<F%S96YY82!D=65S('9E9V%D97,@
M<&5R(&-O;F9I<FUA<BUL80!U;FEF:6-A=`!S96YS92!N;VT`<V5L96-C:?,@
M9&4@;"=U<W5A<FD`=D-A<F0`=SHC(P!W96%T:&5R+F-O;0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQO8V%L92]A<E]362],0U]-15-304=%4P``````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T
M,2`P,C$U,3,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&]C86QE+V%R7U-9+TQ#
M7TU%4U-!1T53+VAO<F1E+FUO````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$V-#$T(#$P-3$U-#,T,30Q(#`R,S(S-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#>$@25`````'L````<````]`,``*<`
M``#,!P```````&@*```(````:0H```4```!R"@``"````'@*```'````@0H`
M``P```")"@``'P```)8*```Y````M@H``"D```#P"@``$0```!H+```6````
M+`L``!8```!#"P``"````%H+```(````8PL``!4```!L"P``"@```((+```,
M````C0L```8```":"P``!P```*$+```I````J0L```(```#3"P``!0```-8+
M```0````W`L``!0```#M"P``+P````(,```/````,@P``"8```!"#```!0``
M`&D,```-````;PP```4```!]#```$````(,,```0````E`P```\```"E#```
M"P```+4,```/````P0P```P```#1#```#P```-X,```>````[@P``"$````-
M#0``(````"\-```#````4`T```0```!4#0``!````%D-```,````7@T```H`
M``!K#0``!0```'8-```*````?`T```\```"'#0``$@```)<-```0````J@T`
M`"@```"[#0``"````.0-```0````[0T```8```#^#0``!P````4.```"````
M#0X```0````0#@``#P```!4.```*````)0X```<````P#@``!P```#@.```$
M````0`X```4```!%#@```@```$L.```S````3@X``#,```""#@``.````+8.
M```Q````[PX``"P````A#P``!0```$X/```"````5`\```<```!7#P``$0``
M`%\/```(````<0\``!X```!Z#P``!0```)D/```H````GP\``"D```#(#P``
M$P```/(/```+````!A```!$````2$```!````"00```,````*1```!H````V
M$```%P```%$0```7````:1```!L```"!$```'P```)T0```3````O1```!``
M``#1$```%P```.(0```'````^A````4````"$0``"0````@1```A````$A$`
M`!P````T$0``!0```%$1```#````5Q$``"\```!;$0``(````(L1```E````
MK!$``"````#2$0``)@```/,1```,````&A(```P````G$@``"````#02```'
M````/1(```8```!%$@``#0```$P2```+````6A(```P```!F$@``"@```',2
M```"````?A(```8```"!$@```P```(@2``!%````C!(``#````#2$@``$```
M``,3```?````%!,``!`````T$P``#P```$43```$````51,```4```!:$P``
M:`$``&`3```'````R10```P```#1%```"0```-X4```'````Z!0```L```#P
M%```&````/P4```F````%14``"T````\%0``$````&H5```?````>Q4``"$`
M``";%0``"P```+T5```%````R14``!4```#/%0``#0```.45```-````\Q4`
M``8````!%@``!@````@6```J````#Q8```L````Z%@``!````$86```0````
M2Q8```L```!<%@``'````&@6```,````A18``"D```"2%@``$0```+P6```-
M````SA8```,```#<%@``"P```.`6```+````[!8```H```#X%@``!P````,7
M```+````"Q<```@````7%P``$````"`7```?````,1<``!\```!1%P``'@``
M`'$7```$````D!<```@```"5%P``!P```)X7```,````IA<```L```"S%P``
M!0```+\7```+````Q1<```\```#1%P``%````.$7```1````]A<``"4````(
M&```!0```"X8```5````-!@```0```!*&```!````$\8```+````5!@```8`
M``!@&```#0```&<8```-````=1@```4```"#&```!@```(D8```%````D!@`
M``4```"6&````@```)P8```G````GQ@``"<```#'&```*0```.\8```@````
M&1D``!P````Z&0``!P```%<9```%````7QD```8```!E&0``#````&P9```+
M````>1D``!0```"%&0``!````)H9```<````GQD``"@```"\&0``"P```.49
M```,````\1D``!$```#^&0``!0```!`:```,````%AH``!4````C&@``$P``
M`#D:```1````31H``!0```!?&@``$@```'0:```8````AQH```P```"@&@``
M#P```*T:```(````O1H```<```#&&@``!@```,X:```C````U1H``!L```#Y
M&@``!0```!4;```/````&QL``"L````K&P``'0```%<;```?````=1L``"X`
M``"5&P``(@```,0;```2````YQL```\```#Z&P``#`````H<```%````%QP`
M``@````='```#P```"8<```-````-AP```L```!$'```"@```%`<```(````
M6QP```8```!D'````P```&L<```F````;QP``"T```"6'```"````,0<```1
M````S1P```\```#?'```$````.\<```%`````!T```4````&'0```0```&P`
M``!T````1P````D````P`````````$D`````````*0```&@```!<````90``
M`&(````G````5P````0````O`````````$$```!5````7@````````!`````
M*P```````````````````#8```!J````60```#$```!*````3P```%(`````
M`````````$(````:````"@`````````@````9@```#<``````````````%,`
M``!D````;@````4```!6````1@```'<````9`````````$L````/````````
M`!L```!4``````````````!S````;0````T`````````'P```!,````"````
M`````&\```!#`````````"(````+````<````!0````6````8P```"X```!I
M````80```!@```!(````+```````````````>0````8```!@````=@```#H`
M``!X````70```#\````[````3@```'$````1````3````#(````2````6@``
M``X````S````'0```&<`````````````````````````:P```%@`````````
M```````````C````$````%```````````````#4````<`````````$0````(
M```````````````X`````P`````````7````>@````P````\````/@``````
M```H`````````%L````M````)````````````````````$T`````````)0``
M```````>````10````<````A````7P```!4````T````=0````````![````
M/0```%$`````````<@```#D````F````*@``````````,C0@:&]U<G,`04TO
M4$T`061D('!A:7(`061D<F5S<P!!9&1R97-S($)O;VL`06X@:6QL96=A;"!V
M86QU92!W87,@<W!E8VEF:65D+@!!<VL@9F]R(&-O;F9I<FUA=&EO;B!B969O
M<F4@9&]I;F<@;6%I;G1E;F%N8V4@;W!E<F%T:6]N<S\`075T:&5N=&EC871I
M;VX@<F5J96-T960@8GD@4D%$2553('-E<G9E<BX`079A:6QA8FQE(&9I96QD
M<SH`0F%D(&ME<F)E<F]S('!A<W-W;W)D+@!"860@:V5R8F5R;W,@=7-E<FYA
M;64N`$)I<G1H9&%Y`$-A;&5N9&%R`$-A;F-E;"!0<F]B;&5M(%)E<&]R=`!#
M96QL(%!H;VYE`$-L;W-E(%=I;F1O=P!#;VUI8W,`0V]M<&%N>0!#;W5L9"!N
M;W0@;W!E;B!-86EN=&5N86YC95]487-K(&UO9'5L92`E<P!$1`!$86EL>0!$
M969A=6QT($ED96YT:71Y`$1E<V-R:6)E('1H92!0<F]B;&5M`$1E=&%I;',@
M:&%V92!B965N(&QO9V=E9"!F;W(@=&AE(&%D;6EN:7-T<F%T;W(N`$1I<W!L
M87D@3W!T:6]N<P!$;R!N;W0@9&ER96-T;'D@86-C97-S(&UA:6YT96YA;F-E
M+G!H<`!%;6%I;`!%;7!T>2!R97-U;'0N`$5R<F]R`$5V97)Y(#$U(&UI;G5T
M97,`179E<GD@,S`@<V5C;VYD<P!%=F5R>2`U(&UI;G5T97,`179E<GD@3&]G
M:6X`179E<GD@:&%L9B!H;W5R`$5V97)Y(&UI;G5T90!%>&%M<&QE('9A;'5E
M<SH`1F%I;&5D(')E=')I979I;F<@<')E9F5R96YC97,N`$9A:6QE9"!T;R!C
M;VYN96-T('1O($Q$05`@<V5R=F5R+@!&86EL960@=&\@8V]N;F5C="!T;R!3
M34(@<V5R=F5R+@!&87@`2&5L<`!(;VUE`$AO;64@061D<F5S<P!(;VUE(%!H
M;VYE`$AO<F1E`$EC;VYS($]N;'D`26-O;G,@=VET:"!T97AT`$EM<&]R=&5D
M(&9I96QD.B`E<P!);7!O<G1E9"!F:65L9',Z`$ME<F)E<F]S('-E<G9E<B!R
M96IE8W1E9"!A=71H96YT:6-A=&EO;BX`3&%N9W5A9V4`3&ES="!(96QP(%1O
M<&EC<P!,;V<@:6X`3&]G(&]U=`!-30!-86EL`$UA=&-H:6YG(&9I96QD<P!-
M96YU(&UO9&4Z`$UE<W-A9V4`36]N=&AL>0!.86UE`$YE=F5R`$YO`$YO(&-O
M;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B!&5%`@5D93
M+@!.;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F;W(@
M4U%,(%9&4RX`3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I
M960@9F]R(%-13"U&:6QE(%9&4RX`3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($ME<F)E<F]S(&%U=&AE;G1I8V%T:6]N+@!.;R!P87-S=V]R9"!P<F]V:61E
M9"!F;W(@4TU"(&%U=&AE;G1I8V%T:6]N+@!.;W1E<P!/2P!/<'1I;VYS`$]T
M:&5R($EN9F]R;6%T:6]N`%!A<W-W;W)D`%!E<F9O<FT@36%I;G1E;F%N8V4@
M3W!E<F%T:6]N<P!0:&]N90!0;&5A<V4@<')O=FED92!A('-U;6UA<GD@;V8@
M=&AE('!R;V)L96TN`%!L96%S92!P<F]V:61E('EO=7(@=7-E<FYA;64@86YD
M('!A<W-W;W)D`%!R;V)L96T@1&5S8W)I<'1I;VX`4F5M;W9E('!A:7(`4F5T
M=7)N('1O($]P=&EO;G,`4F]L90!3879E($]P=&EO;G,`4V5L96-T('1H92!D
M871E(&1E;&EM:71E<CH`4V5L96-T('1H92!D871E(&9O<FUA=#H`4V5L96-T
M('1H92!T:6UE(&9O<FUA=#H`4V5L96-T('1W;R!M871C:&EN9R!F:65L9',N
M`%-E;&5C="!Y;W5R('!R969E<G)E9"!L86YG=6%G93H`4V5N9"!0<F]B;&5M
M(%)E<&]R=`!3:VEP($UA:6YT96YA;F-E`%-P96-I86P@0VAA<F%C=&5R($EN
M<'5T`%-U8V-E<W,`5&%S:W,`5&5X="!/;FQY`%1H:7,@;G5M8F5R(&UU<W0@
M8F4@870@;&5A<W0@;VYE+@!4:&ES('9A;'5E(&UU<W0@8F4@82!N=6UB97(N
M`%1I=&QE`%523`!5;F%B;&4@=&\@8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&
M4R!F:6QE("5S+R5S+@!5;F%B;&4@=&\@8V]N;F5C="!T;R!344P@<V5R=F5R
M+@!5;F%B;&4@=&\@<F5A9"!T:&4@=F9S<F]O="!D:7)E8W1O<GDN`%5N86)L
M92!T;R!R96YA;64@5D93(&9I;&4@)7,O)7,N`%5N86)L92!T;R!T<F%N<VQA
M=&4@=&AI<R!7;W)D(&1O8W5M96YT`%5N9&\@0VAA;F=E<P!5<V5R($]P=&EO
M;G,`57-E<FYA;64`5V%R;FEN9P!7965K;'D`5V5L8V]M92!T;R`E<P!796QC
M;VUE+"`E<P!7;W)K($%D9')E<W,`5V]R:R!0:&]N90!960!996%R;'D`665S
M`%EO=2!M=7-T(&1E<V-R:6)E('1H92!P<F]B;&5M(&)E9F]R92!Y;W4@8V%N
M('-E;F0@=&AE('!R;V)L96T@<F5P;W)T+@!9;W5R("5S('-E<W-I;VX@:&%S
M(&5X<&ER960N(%!L96%S92!L;V=I;B!A9V%I;BX`66]U<B!);F9O<FUA=&EO
M;@!9;W5R(&]P=&EO;G,@:&%V92!B965N('5P9&%T960N`%M0<F]B;&5M(%)E
M<&]R=%T`6VQI;F4@)7,@;V8@)7-=`&YA;64`=D-A<F0`4')O:F5C="U)9"U6
M97)S:6]N.B!(3U)$12!V,BXP+C`*4F5P;W)T+4US9VED+4)U9W,M5&\Z(&1E
M=D!L:7-T<RYH;W)D92YO<F<*4$]4+4-R96%T:6]N+41A=&4Z(#(P,#4M,3`M
M,3@@,34Z,3(K,#(P,`I03RU2979I<VEO;BU$871E.B`R,#`S+3`T+3,P(#$R
M.C`P*S`R,#`*3&%S="U4<F%N<VQA=&]R.B!0;&%T:6YU;2!$979E;&]P;65N
M="!496%M(#QD979T96%M0'!L871I;G5M+7-Y+FYE=#X*3&%N9W5A9V4M5&5A
M;3H@07)A8FEC(#QI,3AN0&QI<W1S+FAO<F1E+F]R9SX*34E-12U697)S:6]N
M.B`Q+C`*0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[(&-H87)S970]0U`Q,C4V
M"D-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<Z(#AB:70*`#(T(-/'VLD`Y.7'
MT<?P+^'MX<?P`,/6W2#+Y,?&[0#'X=KDYL?D`,_=RM$@VN3'YNWD`,KC(,K-
MS^W/(-[MX\D@V^W1(./>R.;AR0#*P]_MSR#'X=CAR"#>R.$@Q^'(S\$@R-KC
MX>W'RB#'X=7MQ^3)OP#*XR#1W=8@Q^'*S=[>(./D(,?AY>;MR2#CY"#>R.$@
MQ^'CSL_C(-''S^WFTRX`Q^'-WN;A(,?AX\KFW=').@#?X>/)(./1YM$@V\C1
M(./>R.;AR2`HW^W1R.W1YM,I`,?3XR#'X>/3RL[/XR#;R-$@X][(YN$@*-_M
MT<CMT>;3*0#MYN,@Q^'C[>''SP##S.3/R0#%X=O'P2#'X<CAQ]L@VN0@X]3?
MX<D`Q^'EQ\K=(,?AS.;'X0#%V^''WB#'X>3'W=#)`-'3YN/'R@#'X=31W\D`
MX<?%X]_'Y.W)(.'=RLT@36%I;G1E;F%N8V5?5&%S:R#AX<C1[>/,("5S`.WF
MXR`M(-'>X^WD`.WFX^T`Q^'*S=[>(,?AQ]W*T<?6[0#4T<T@Q^'CU-_AR0#*
MXR#-W=D@Q^'*W<?5[>$@X>//[=$@Q^'DV<?C`,[MQ]''RB#'X=K1U@#AQR#*
MS\[A(./(Q]31R?`@Q>'L(,?AX^'=(&UA:6YT96YA;F-E+G!H<`#'X<C1[<\@
MQ^'%X=_*T>;D[0#AQ\KFS,\@Y,K'QLPN`,[8PP#?X2`Q-2#/WNW>R0#?X2`S
M,"#/WNW>R0#?X2`U(,_>[=[)`-_A(,_.YN$`W^$@Y-7=(-/'VLD`W^$@S][M
MWLD`P^/+X<D@VN'L(,?AWNWC.@#AQ\7CW\?D[<D@X>':R^;1(-KA["#'X<K=
MUNWAQ\HN`.''Q>/?Q^3MR2#AX<7*U<?A(,C'X>/.S^,@3$1!4"X`X<?%X]_'
MY.W)(.'AQ<K5Q^$@R,?AX\[/XR!334(N`-W'W],`Q^'CT\?:S\D`Q^'(S\?M
MR0#:Y.;'Y"#'X>/DTN$`Y<?*W2#'X>/DTN$`Y>;1S^T`P^W>YN3'RB#=WM@`
MP^W>YN3'RB#CVB#DU>;5`,?AS=[FX2#'X>/3RN;1S\DZ("5S`,?AS=[FX2#'
MX>/3RN;1S\DZ`,?AX\[/XR#?[='([='FTR#1W=8@Q^'*S=[>(./D(,?AY>;M
MR2X`Q^'AV\D`WL?&X\D@VN3'YNWD(,?AX]/'VL_)`,_.YN$`SM'FS`#4Y=$@
M+2#1WN/MY`#'X<C1[<\`X]C'R-[)(,?AS=[FX0#FUMH@Q^'CT-_1Q\HZ`-'3
MQ^')`-3ET>W'\`#'X<?3XP##R,_'\`#AQP#AQ\KFS,\@X]KAYN/'RB#-YN$@
MQ=K/Q\_'RB#'X=P@1E10(%9&4RX`X<?*YLS/(./:X>;CQ\H@S>;A(,7:S\?/
MQ\H@Q^'<(%-13"!61E,N`.''RN;,SR#CVN'FX\?*(,WFX2#%VL_'S\?*(./A
MW<?*(%-13"!61E,N`.''RN;,SR#?X>/)(./1YM$@X>'*S=[>(-_MT<CMT>;3
M`.''RN;,SR#?X>/)(./1YM$@X>'*S=[>(%--0CX`X^''S=G'R@#CYL?=W@#.
M[<?1Q\H`X]KAYN/'RB#"SM'L`-_AX\D@Q^'CT>;1`,KDW>W0(-KCX>W'RB#'
MX=7MQ^3)`.7'RMT`Q^'1S,?!(,K2YNW/Y,<@X^'.U2#'X>/4W^')+@#'X=',
MQ\$@RM+F[<_DQR#(Q]/C(,?AX]/*SL_C(.;?X>/)(,?AT]$N`-31S2#'X>/4
MW^')`,72X<D@Q^'+Y,?&[0#:YL_)(,7A["#'X<[MQ]''R@#'X<_FT0#-W=D@
MQ^'.[<?1Q\H`Q\[*T2#'X=WFQ]7A(.'ARL?1[<XZ`,?.RM$@RN33[=X@Q^'*
MQ]'MSCH`Q\[*T2#*Y-/MWB#'X>;>RCH`Q<[*T2#-WN'MY"#CRN/'R^'MY"X`
MQ<[*T2#AV\K?(,?AX]W6X<DZ`,/1T^$@RM[1[=''\"#(X]3?X<D@S=7AR@#%
MY>/A(,?AU>W'Y,D`Q<_.Q]$@S='FW2#.Q]7)`,KC(,CDS,?-`,?AX^7CQ\H`
MY-4@W=[8`.W,R"##Y"#MW^;D(.70QR#'X='>XR##W\C1(./D(,?AU=W1`.W,
MR"##Y"#*W^;D(.70Y2#'X=[MX\D@T=[C+@#'X>'>R`#:Y.;'Y"#'X<7DRM'D
M[<H`X<<@Q>/?Q^3MR2#ARMOM[=$@Q^'3X\?-[<?*(.'CX=T@5D93("5S+R5S
M+@#AQR#%X]_'Y.W)(.'AQ<K5Q^$@R./.S^,@4U%,+@#AQR#%X]_'Y.W)(.'>
MT<?!R2#CS.'/('9F<W)O;W0N`.''(,KFS,\@Q>/?Q^3MR2#ARMOM[=$@Q]/C
M("#CX=T@Q^'<(%9&4R`E<R\E<RX`V^W1(-['S]$@VN'L(,K1S./)(./3RN3/
M(,?AYM'/(.70QP#*T<?,VB#:Y"#'X<K;[>W1Q\H`SNW'T<?*(,?AX]/*SL_C
M`,?3XR#'X>/3RL[/XP#*Y,CMY0##T\CFVNW'\`##Y>''(,C?XR#%X>P@)7,`
MP^7AQR#FT^7AQR`E<P#:Y.;'Y"#'X=KCX0#EQ\K=(,?AVN/A`-/DR2`M(-?7
M`-/DYNW'\`#DVN,`[<S((-31S2#'X>/4W^')(-[(X2#'T=/'X2#*WM'MT<?P
M(,CEQRX`Q^3*Y<H@U>''S>W)(,?AQ\K5Q^$@)7,N(,?AT<S'P2#%VL?/R2#'
MX<_.YN$N`,CMQ^3'RM\Z`,KC(,K-S^W+(,?ASNW'T<?*`%O*WM'MT2#'X>/4
MW^')70!;Q^'3V-$@)7,@X^0@)7-=`,?AQ]/C`'9#87)D````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L;V-A;&4O:VU?2T@O
M3$-?34534T%'15,`````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q-#$@,#(Q-#8W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQO8V%L92]K;5]+2"],0U]-15-304=%4R]H;W)D92YM;P``````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#$Q,3<U,R`Q,#4Q-30S-#$T,2`P,C,R,30`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````WA($
ME0````!$`@``'````#P2```%`P``7"0```````!P,```#@```'$P```/````
M@#````@```"0,```"P```)DP```,````I3```!@```"R,```&P```,LP```,
M````YS````4```#T,```!0```/HP```&`````#$```P````',0``#@```!0Q
M```.````(S$```@````R,0``"0```#LQ```(````13$``!,```!.,0```P``
M`&(Q```(````9C$```<```!O,0``#````'<Q```.````A#$```L```"3,0``
M!P```)\Q```'````IS$```4```"O,0``!0```+4Q```#````NS$``!<```"_
M,0``#@```-<Q```'````YC$```8```#N,0``"````/4Q```*````_C$``!,`
M```),@``"P```!TR```%````*3(``!4````O,@``"0```$4R```'````3S(`
M``4```!7,@``"@```%TR```&````:#(```D```!O,@``!P```'DR```5````
M@3(```H```"7,@``"@```*(R```0````K3(```<```"^,@``!P```,8R```*
M````SC(```@```#9,@``!P```.(R```'````ZC(```8```#R,@``!0```/DR
M```'````_S(```8````',P``"`````XS```$````%S,```<````<,P``"0``
M`"0S```&````+C,```<````U,P``%@```#TS```$````5#,```@```!9,P``
M!@```&(S```-````:3,```8```!W,P``'@```'XS```1````G3,```@```"O
M,P``#````+@S```'````Q3,```,```#-,P``"````-$S```(````VC,```@`
M``#C,P``!@```.PS```&````\S,```H```#Z,P``!P````4T```'````#30`
M``X````5-```!@```"0T```8````*S0```0```!$-```!@```$DT```%````
M4#0```4```!6-```$````%PT```%````;30```L```!S-```#````'\T```7
M````C#0```@```"D-```!0```*TT```'````LS0```<```"[-```"P```,,T
M```'````SS0```<```#7-```"0```-\T```)````Z30```H```#S-```%0``
M`/XT```9````%#4```4````N-0``$@```#0U```(````1S4```@```!0-0``
M#````%DU```$````9C4```H```!K-0``!P```'8U```&````?C4```<```"%
M-0``!````(TU```,````DC4```T```"?-0``*````*TU```#````UC4```8`
M``#:-0``$0```.$U```7````\S4```X````+-@```@```!HV```%````'38`
M``0````C-@```P```"@V```(````+#8```\````U-@``!P```$4V```&````
M338```T```!4-@``"@```&(V```'````;38```L```!U-@``"P```($V```)
M````C38```@```"7-@``"````*`V```2````J38``!\```"\-@``"````-PV
M```,````Y38```8```#R-@``!P```/DV```$`````3<```D````&-P``!0``
M`!`W```+````%C<```4````B-P``#0```"@W```;````-C<```D```!2-P``
M$0```%PW```'````;C<```4```!V-P``!P```'PW```(````A#<```8```"-
M-P``$````)0W```0````I3<```\```"V-P``#P```,8W```,````UC<```<`
M``#C-P``!@```.LW```(````\C<``!L```#[-P``#0```!<X```#````)3@`
M``@````I.```!````#(X```$````-S@```D````\.```!P```$8X```'````
M3C@```0```!6.```!0```%LX```*````83@```4```!L.```!@```'(X```&
M````>3@```T```"`.```$````(XX```;````GS@```0```"[.```"0```,`X
M```%````RC@```8```#0.```!P```-<X```'````WS@```4```#G.```"0``
M`.TX```*````]S@```X````".0```@```!$Y```)````%#D```8````>.0``
M$@```"4Y```)````.#D```<```!".0``!@```$HY```*````43D```0```!<
M.0``"0```&$Y```&````:SD```T```!R.0``!@```(`Y```$````ASD```4`
M``",.0``!@```)(Y```'````F3D``"$```"A.0``!@```,,Y```$````RCD`
M``0```#/.0``'0```-0Y```$````\CD```P```#W.0``#@````0Z```*````
M$SH```@````>.@``"0```"<Z```'````,3H```H````Y.@``!P```$0Z```*
M````3#H```8```!7.@``#P```%XZ```%````;CH```D```!T.@``!````'XZ
M```+````@SH```P```"/.@``!P```)PZ```$````I#H```<```"I.@``!@``
M`+$Z```&````N#H```8```"_.@``!0```,8Z```'````S#H```<```#4.@``
M!0```-PZ```6````XCH```8```#Y.@``!``````[```$````!3L```<````*
M.P``"@```!([```%````'3L```H````C.P``"````"X[```(````-SL```\`
M``!`.P``!@```%`[```*````5SL```@```!B.P``(````&L[```&````C#L`
M``8```"3.P``!P```)H[```$````HCL```<```"G.P``!0```*\[```'````
MM3L``!8```"].P``#0```-0[```$````XCL```4```#G.P``"0```.T[```*
M````]SL```@````"/```!@````L\```'````$CP```4````:/```"P```"`\
M```$````+#P```,````Q/```"@```#4\```"````0#P```4```!#/```"@``
M`$D\```$````5#P```8```!9/```"````&`\```(````:3P```0```!R/```
M!0```'<\```%````?3P```8```"#/```$````(H\```*````FSP```H```"F
M/```"0```+$\```#````NSP```<```"_/```!P```,<\```'````SSP```8`
M``#7/```!@```-X\```&````Y3P```D```#L/```!@```/8\```-````_3P`
M``8````+/0``"````!(]```.````&ST```<````J/0``"@```#(]```'````
M/3T```D```!%/0``"0```$\]```*````63T```<```!D/0``"0```&P]```'
M````=CT```H```!^/0``!P```(D]```$````D3T```<```"6/0``!0```)X]
M```%````I#T```L```"J/0``%````+8]```'````RST```4```#3/0``#0``
M`-D]```1````YST```L```#Y/0``#`````4^```$````$CX```H````7/@``
M!````"(^```)````)SX```4````Q/@``!P```#<^```%````/SX```0```!%
M/@```@```$H^```$````33X```X```!2/@``&````&$^```&````>CX```4`
M``"!/@``"````(<^```&````D#X``!0```"7/@```@```*P^```&````KSX`
M``<```"V/@``!@```+X^```,````Q3X```0```#2/@``%````-<^```0````
M[#X```<```#]/@``!0````4_```'````"S\```@````3/P``!0```!P_```&
M````(C\``!`````I/P``"````#H_```(````0S\```D```!,/P``!0```%8_
M```$````7#\```8```!A/P``!P```&@_```H````<#\```H```"9/P``"P``
M`*0_```4````L#\```0```#%/P``"P```,H_```%````UC\```@```#</P``
M!@```.4_```&````[#\```@```#S/P``"````/P_```'````!4````@````-
M0```"@```!9````+````(4````4````M0```!0```#-````%````.4````0`
M```_0```!P```$1````-````3$````8```!:0```!P```&%````&````:4``
M``4```!P0```!P```'9````1````?D````<```"00```!0```)A````$````
MGD````<```"C0```"P```*M````,````MT````4```#$0````P```,I````2
M````SD````8```#A0````P```.A````,````[$```!4```#Y0```"P````]!
M```9````&T$``"`````U00``!0```%9!```*````7$$``!4```!G00``#```
M`'U!```$````BD$```P```"/00``!@```)Q!```.````HT$```T```"R00``
M"@```,!!```+````RT$```<```#700``"0```-]!```5````Z4$```T```#_
M00``"`````U"```#````%D(```4````:0@``"@```"!"```$````*T(```8`
M```P0@``#````#="```)````1$(```D```!.0@``!````%A"```(````74(`
M``@```!F0@``#P```&]"```'````?T(```P```"'0@``+````)1"```'````
MP4(```4```#)0@``!````,]"```)````U$(```@```#>0@``!@```.="```-
M````[D(```<```#\0@``!@````1#```)````"T,```<````50P``!0```!U#
M```'````(T,```L````K0P``!P```#=#```(````/T,``!8```!(0P``"0``
M`%]#```&````:4,```L```!P0P``%````'Q#```%````D4,``!````"70P``
M$````*A#```&````N4,```H```#`0P``!0```,M#```0````T4,```L```#B
M0P``!````.Y#```)````\T,```@```#]0P``+P````9$```$````-D0```L`
M```[1```!0```$=$```"````340```4```!01```!````%9$```'````6T0`
M``4```!C1````P```&E$```3````;40```<```"!1```!@```(E$```4````
MD$0```P```"E1```&````+)$```&````RT0```,```#21```!````-9$```&
M````VT0```<```#B1```"0```.I$```'````]$0```\```#\1```%`````Q%
M```.````(44```T````P10``)````#Y%```%````8T4```<```!I10``!P``
M`'%%```&````>44```8```"`10``!P```(=%```$````CT4``!,```"410``
M"````*A%```)````L44```H```"[10``"````,9%```&````ST4```<```#6
M10``"````-Y%```)````YT4```<```#Q10``#P```/E%```'````"48``!0`
M```11@``$0```"9&```'````.$8```,```!`1@``"````$1&```&````348`
M``<```!41@``#0```%Q&```.````:D8```4```!Y1@``!@```']&```(````
MAD8```P```"/1@``"@```)Q&```"````IT8```0```"J1@``!@```*]&```%
M````MD8```,```"\1@``"0```,!&```*````RD8```4```#51@``!@```-M&
M```(````XD8```@```#K1@``$0```/1&```9````!D<``!$````@1P``&```
M`#)'```3````2T<``!P```!?1P``$0```'Q'```/````CD<```(```">1P``
M$0```*%'```2````LT<``!<```#&1P```@```-Y'```$````X4<``!$```#F
M1P``!@```/A'```8````_T<``!,````82````@```"Q(```,````+T@``!$`
M```\2```#0```$Y(```'````7$@```4```!D2```)0$``&I(```M````D$D`
M`$4```"^20``&P````1*```A````($H``!X```!"2@``/0```&%*``!J````
MGTH``!(````*2P``!0```!U+```5````(TL```D````Y2P``%0```$-+```R
M````64L``#(```",2P``$P```+]+```*````TTL``!(```#>2P``,````/%+
M```2````(DP``#8````U3```&P```&Q,```M````B$P``"H```"V3```)P``
M`.%,```8````"4T``!X````B30``,````$%-```2````<DT``!@```"%30``
M0@```)Y-```H````X4T``!@````*3@``&P```"-.```>````/TX``"<```!>
M3@``/@```(9.```8````Q4X```P```#>3@``)````.M.```>````$$\``!(`
M```O3P``$@```$)/```;````54\```P```!Q3P``'@```'Y/```5````G4\`
M`($```"S3P``+0```#50```J````8U```#8```".4```&````,50```2````
MWE```"0```#Q4```&````!91```;````+U$``!X```!+40``%0```&I1```2
M````@%$``!@```"340``$@```*Q1```;````OU$```D```#;40``$@```.51
M```D````^%$```P````=4@``#P```"I2``!-````.E(``!L```"(4@``&P``
M`*12```)````P%(``!X```#*4@``&````.E2``!8`````E,``#P```!;4P``
M'@```)A3```J````MU,``!@```#B4P```P```/M3```8````_U,``!4````8
M5```&````"Y4```2````1U0``!(```!:5```$@```&U4```5````@%0``#``
M``"65```'@```,=4```2````YE0``%$```#Y5```"0```$M5```D````554`
M``P```!Z50``"0```(=5```M````D54```\```"_50``(0```,]5```>````
M\54``"H````05@``&````#M6```)````5%8``"$```!>5@``,P```(!6```D
M````M%8``!X```#95@``&P```/A6```>````%%<``!@````S5P``&````$Q7
M``!"````95<``%$```"H5P``%0```/I7``!*````$%@```@```!;6```#```
M`&18```5````<5@```\```"'6```'@```)=8```2````ME@``!(```#)6```
M%0```-Q8```/````\E@``#P````"60``0@```#]9``"Y````@ED```P````\
M6@``$@```$E:```A````7%H``"T```!^6@``+0```*Q:```"````VEH``!L`
M``#=6@``)P```/E:```,````(5L```P````N6P``,0```#M;```8````;5L`
M``P```"&6P``'@```)-;```>````LEL``!@```#16P``'@```.I;```8````
M"5P```8````B7```&P```"E<```8````15P``#P```!>7```40```)M<```/
M````[5P``"T```#]7```$@```"M=```;````/ET``!L```!:70``&P```'9=
M```8````DET``"<```"K70``$@```--=```P````YET``&@````77@``*@``
M`(!>```P````JUX``!@```#<7@``#P```/5>```8````!5\``!@````>7P``
M$@```#=?```O````2E\``#4```!Z7P``*0```+!?```Y````VE\``"0````4
M8```'@```#E@```2````6&```"H```!K8```0@```)9@```A````V6```!(`
M``#[8```$@````YA```;````(6$```\````]80``(0```$UA```/````;V$`
M`!L```!_80``$@```)MA```/````KF$``"T```"^80``)````.QA```,````
M$6(``!(````>8@``-P```#%B```S````:6(``$8```"=8@``!@```.1B```;
M````ZV(``!4````'8P``&````!UC```;````-F,``!X```!28P``$@```'%C
M```D````A&,``!@```"I8P``'@```,)C```&````X6,``#,```#H8P``#P``
M`!QD```<````+&0``!4```!)9```'@```%]D```/````?F0``"<```".9```
M$@```+9D```A````R60``!(```#K9```(0```/YD```;````(&4```0````\
M90``#````$%E```5````3F4``!(```!D90``30```'=E```2````Q64```\`
M``#890``#P```.AE``!1````^&4``!@```!*9@``*@```&-F```2````CF8`
M`"<```"A9@``'@```,EF```2````Z&8``!4```#[9@``(0```!%G```8````
M,V<``"$```!,9P``$@```&YG``!"````@6<```\```#$9P``'@```-1G```5
M````\V<``!4````):```)````!]H```;````1&@``!@```!@:```$@```'EH
M```>````C&@``!@```"K:```#P```,1H```5````U&@``!4```#J:```#```
M``!I```/````#6D``"`````=:0``&P```#YI```2````6FD``!(```!M:0``
M)P```(!I```G````J&D``!(```#0:0``)````.-I```S````"&H``!@````\
M:@``&P```%5J```8````<6H``"0```"*:@``#````*]J``!U````O&H``!@`
M```R:P``$@```$MK```/````7FL```\```!N:P``$@```'YK```2````D6L`
M`!L```"D:P``3P```,!K```A````$&P```D````R;```"0```#QL```;````
M1FP``"0```!B;```$@```(=L```)````FFP```D```"D;```"0```*YL```D
M````N&P``"T```#=;```"0````MM```>````%6T```(````T;0``$@```#=M
M```J````2FT``!4```!U;0``%0```(MM```8````H6T``!@```"Z;0``#P``
M`--M```5````XVT```P```#Y;0``&P````9N```2````(FX``!L````U;@``
M&P```%%N```8````;6X```P```"&;@``$@```)-N```2````IFX```D```"Y
M;@``(0```,-N```8````Y6X``!(```#^;@``%P```!%O```/````*6\``!4`
M```Y;P``%0```$]O```>````96\``"````"$;P``%0```*5O```;````NV\`
M`!4```#7;P``.0```.UO```V````)W```#8```!><```,````)5P```;````
MQG```!(```#B<```)````/5P```>````&G$```\````Y<0``%0```$EQ```,
M````7W$``!4```!L<0``&````()Q```M````FW$``!(```#)<0``"0```-QQ
M```G````YG$``"0````.<@``)P```#-R```V````6W(``!4```"2<@``*@``
M`*AR```5````TW(``"0```#I<@``%0````YS```A````)',```D```!&<P``
M"0```%!S```&````6G,```\```!A<P``(0```'%S``!%````DW,``!(```#9
M<P``#P```.QS```8````_',```D````5=```)P```!]T```5````1W0```\`
M``!==```#````&UT```;````>G0``#8```"6=```#P```,UT``!%````W70`
M`$(````C=0``%0```&9U```2````?'4``!(```"/=0``'@```*)U```/````
MP74``!@```#1=0``*@```.IU```A````%78``"<````W=@``+````%]V```;
M````C'8```\```"H=@``$@```+AV```/````RW8``&8```#;=@``$@```$)W
M```2````57<``#P```!H=P``$@```*5W```;````N'<``!@```#4=P``&P``
M`.UW```2````"7@``!(````<>```)````"]X```2````5'@``"0```!G>```
M$@```(QX```G````GW@``!L```#'>```#````.-X```2````\'@```P````#
M>0``"0```!!Y```J````&GD``$$```!%>0``)P```(=Y```G````KWD``!(`
M``#7>0``)P```.IY```5````$GH``#`````H>@``(0```%EZ```2````>WH`
M`!(```".>@``%0```*%Z```M````MWH``"T```#E>@``&@```!-[```,````
M+GL``"T````[>P``&````&E[```#````@GL``!X```"&>P``+````*5[```A
M````TGL``$0```#T>P``30```#E\```2````AWP``"$```":?```%0```+Q\
M```S````TGP``"0````&?0``,0```"M]```5````77T``"T```!S?0``,P``
M`*%]```G````U7T``"$```#]?0``'@```!]^```/````/GX``$0```!.?@``
M(0```)-^```,````M7X```\```#"?@``#P```-)^```5````XGX``!(```#X
M?@``$@````M_```>````'G\``!@````]?P``&P```%9_```,````<G\``!L`
M``!_?P``&P```)M_```D````MW\``!4```#<?P``-@```/)_``"`````*8``
M`!(```"J@```&````+V````J````UH```!L````!@0``'@```!V!```8````
M/($``"$```!5@0``&P```'>!```;````DX$``"T```"O@0``$@```-V!```2
M````\($``!(````#@@``)````!:"```2````.X(``!L```!.@@``1P```&J"
M```D````LH(``!4```#7@@``$@```.V"``!&`````(,```\```!'@P``/P``
M`%>#``!1````EX,``!4```#I@P``+0```/^#```8````+80``"0```!&A```
M'@```&N$```2````BH0``!@```"=A```!@```+:$``"1````O80``!L```!/
MA0``2P```&N%```8````MX4```8```#0A0``&````->%```2````\(4``!L`
M```#A@``%0```!^&```/````-88``$0```!%A@``&````(J&```/````HX8`
M`!P```"SA@``)````-"&```R````]88``!L````HAP```P```$2'```$````
M2(<``!X```!-AP``&P```&R'```S````B(<``"<```"\AP``'0```.2'```A
M`````H@``#`````DB```)P```%6(``!:````?8@```P```#8B```'@```.6(
M```A````!(D``#8````FB0``&P```%V)```D````>8D``!L```">B0``10``
M`+J)```M`````(H``#(````NB@``+0```&&*```5````CXH```\```"EB@``
M(0```+6*```,````UXH``"<```#DB@``#`````R+``!"````&8L```P```!<
MBP``1@```&F+```^````L(L``!(```#OBP``"0````*,```A````#(P``"0`
M```NC```)````%.,```_````>(P``"T```"XC```#P```.:,```0````]HP`
M`"H````'C0``2P```#*-``!1````?HT```(```#0C0``!````-.-```A````
MV(T```\```#ZC0``$P````J.```J````'HX``"0```!)C@``!@```&Z.```8
M````=8X``"$```".C@``#````+".``!4````O8X``%$````2CP``3@```&2/
M``!C````LX\``%0````7D```8````&R0``!+````S9```$(````9D0```@``
M`%R1``!(````7Y$``#<```"HD0``10```."1```(````)I(```\````OD@``
M10```#^2```2````A9(``%<```"8D@``.0```/"2```"````*I,``"H````M
MDP``.0```%B3```P````DI,``"$```##DP``!0```.63```!````1@```/,!
M``"X`````````#,!```!`0``_@```!T"``#6`0```````"D!```%`@``T@$`
M```````F`````````+,`````````3````+L```#8````DP```+,!```-`@``
M`````%0!``#F````D0```,8````R`@``Q0````````!1````4@$``!T!````
M`````````$4```#[````X@$```@"```C````)0(```````"G````@P$``)D`
M``#G`0``%@(``#\"``##`0```P$``*0!````````WP$``+````#`````60``
M``X"```Q`0````````````#5````QP```(\!``!``0```````.H!``"6````
M5@```````````````````!H"``"2````=`$``-$```""````[P```(`````M
M````F@$``.4!``#)````,@$``!T`````````TP```"@"``!W````]0$``/H`
M``"K````^0$`````````````=0$```````#L`0``R@````````#5`0``L0$`
M`#P!``"(````+P$``*(```!F`0``%P(``"8!````````1@$`````````````
MZP```"T!````````-P(``````````````````.\!````````E@$`````````
M````TP$``-`!``#R`````````(\`````````"@(``&H!```X`0``)`````X`
M````````N@$``*,`````````/@```'D!``````````````````#N````````
M`$D!``"U`````````#,```#?`````````)X`````````\`$``&\```!0`0``
MXP```)X!````````"````&T!``"(`0```````````````````````(L!``#X
M`````````+X````;`@```````'````!A````8`````L"``"'````"0```)L`
M`````````````'8````>`@``O0$```,````0`@```````&\!``#H`0``*@``
M`"\`````````K````%@!````````=0```"@!```/````=@$``'(```"?````
MT0$``&D```"R````_P```.T!``"C`0``Q`````P`````````1`$``*$!````
M`````````$T```!"`````````(0````U`@```````,$``````````````+0`
M``#A`0```````!\```"@`0```````+\!```P`@```````(H```"J````V0$`
M```````L`@``5````!X!``!#`0``N`$```````````````````````"[`0``
M`````)(!```G`````````.T```"7````I@```&`!``"D````.P$``/<````T
M````FP$``.`!```]`@```````&<````Y``````````````"8`0``$P$``,P!
M``"N`````````&0```"O````I0```,,```"Y`0``H@$``.0`````````.@(`
M``````",````4P$``(4!``!*````<0```#@```!A`0``6@````````!'````
M,P(``$H!````````[``````````<`0``%0(``#0"```$````,`$``#0!````
M````\0```*T```"\`0``V@``````````````````````````````Q@$``!<`
M``!,`0``I@$``)4```"K`0``*0```$L!```A`@``?0$``$@```!M````1`(`
M``````"!`0``=````.<````+`0``#`$``#P```!L`0```````#4````!`@``
M)`$``$T!````````V@$``!\!``"@````&@````````#W`0``-@$``)H`````
M``````````,"````````0@$``($````)`0``8@$``/X!``#(`0``)`(`````
M``#<`0``Y0`````````Z`0```````#8"``!<`0``(@```&X`````````C0``
M`%````#$`0``X@`````````L`0``%@```',!``"8`````````(,```!%`0``
M.P```&L```"J`0``0`(``,`!``"L`0``)P$``%4!```E`0``)@(````````*
M````_`$`````````````!P$``(`!``!;`0```````/H!````````S0``````
M``!\````1`````````#@````G````/0!```9````7P```%X!``#2````Z0$`
M`(P!``"Z````>`````````!.``````````````".`0``\P````L````5`0``
MV0```$L```"9`0``%P$``,H!``"W````J`$```````!W`0``*P(``)````!=
M````7````!D!```I`@``)P(````````2`````````),!``"'`0``\@$``#L"
M``!K`0``_```````````````@@$```8"``````````````8````9`@``````
M``````!;````$0(```````!?`0``7@```#D"```%`0``+````.D```#+````
M4P````````"5`0``$@$``/\!```/`0``[@$````"````````K0$``#(````U
M`0``SP```-`````<`@``.0$``%H!````````(P$``,X!``!.`0``^`$``$("
M``#Q`0``0P(`````````````<P``````````````+@```&(`````````````
M``H!````````VP```/4```#A````]````'D`````````^0``````````````
M`@$``%<!``"N`0```@```,(!``"G`0``Z`````````"1`0``A@```*D````]
M`0``$P(``,X`````````E````"`!```3````(P(``!@!````````XP$``#\!
M``!X`0``O@$```````````````````````#!`0``C0$```````#4`0``W@$`
M`.L!```$`@```````)T!``#,````B0````<"```4````50```+8!``"O`0``
M&`(``&0!````````90`````````P````60$``+(!```A`````````-<````%
M`````````%$!``!2````.@```"X!````````GP$``!0"``"Q````*P```*4!
M``!^`````````&,!`````````````,<!``#+`0``'P(``,D!````````W@``
M`'P!``#F`0``0P```+0!````````_0$````````1`````````+<!``!G`0``
MM0$```````"&`0``+0(```````!=`0``<@$``(L```#P````!@$``#P"````
M````V`$`````````````O0```,4!``#4````^P$``$$"````````Z@```*@`
M``"A````1P$``(D!```@````2`$`````````````U@````````!N`0``OP``
M`&4!````````*@(``#$"``!`````D`$```D"``#/`0```````"@`````````
M`````#\```#=````]@```"`"``!7````<0$``&D!```B`0``A`$`````````
M````$@(``)<!``"I`0``?@$``#<```!!`````````'`!````````&P```!`!
M``````````$``"("```O`@``00$``/T```".````(0$``!$!``"Y````:`$`
M`#@"```(`0``W0$``+P```!L````?0````T!```4`0``'@``````````````
M&@$``-L!``!)````>@$``#X!````````%0```!@````E````!P```'L!````
M````/0```&H```!Z````G0````````#(`````````%8!```0`````````&,`
M```-````*@$``"L!```"`@```````'\!```N`@```````#$`````````````
M`'L``````````````(H!``#7`0``P@````\"``"4`0``-P$``!8!````````
MW```````````````S0$``%@```!_````/@(``$\```"P`0``!`$``(4```!/
M`0````````X!```;`0``M@```#8`````````#`(``&@```"<`0``Y`$`````
M```<````]@$`````````````9@`````@*"5S(&1A>7,@86=O*0`@*$%C8V5S
M<VME>2`E<RD`("AT;V1A>2D`("AT;VUO<G)O=RD`("AY97-T97)D87DI`"(E
M<R(@:7,@;F]T(&$@9&ER96-T;W)Y+@`B)7,B(&ES(&YO="!A('9A;&ED(&-H
M;VEC92X`)60@)7,@86YD("5S`"5S($M"`"5S($U"`"5S.B`E<P`M+2!S96QE
M8W0@+2T`,3(@2&]U<B!&;W)M870`,C0@2&]U<B!&;W)M870`,C0@:&]U<G,`
M/%!R979I;W5S`$%B;W5T+BXN`$%C8V]U;G0@26YF;W)M871I;VX`061D`$%D
M9"!U<V5R`$%D9')E<W,`061D<F5S<R!";V]K`$%D;6EN:7-T<F%T:6]N`$%F
M9VAA;FES=&%N`$%L8F%N:6$`06QG97)I80!!;&EA<P!!;&EG;@!!;&P`06QT
M97)N871E(&5M86EL(&%D9')E<W,`06UE<FEC86X@4V%M;V$`06YD;W)R80!!
M;F=O;&$`06YG=6EL;&$`06YT87)C=&EC80!!;G1I9W5A(&%N9"!"87)B=61A
M`$%P<&QI8V%T:6]N`$%P<FEL`$%R86)I8R`H5VEN9&]W<RTQ,C4V*0!!<F=E
M;G1I;F$`07)M96YI80!!<G5B80!!='1R:6)U=&5S`$%U9W5S=`!!=7-T<F%L
M:6$`075S=')I80!!=71H96YT:6-A=&EO;B!F86EL960`07IE<F)A:6IA;@!"
M86-K9W)O=6YD`$)A8VMG<F]U;F0@0V]L;W(`0F%H86UA<P!"86AR86EN`$)A
M;F=L861E<V@`0F%R8F%D;W,`0F5L87)U<P!"96QG:75M`$)E;&EZ90!"96YI
M;@!"97)M=61A`$)H=71A;@!":7)T:&1A>0!";VQD`$)O;&EV:6$`0F]O:VUA
M<FMS`$)O<F1E<@!";W)D97)S`$)O<VYI82!A;F0@2&5R>F5G;W9I;F$`0F]T
M:`!";W1S=V%N80!";W1T;VT`0F]U=F5T($ES;&%N9`!"<F%Z:6P`0G)I=&ES
M:"!);F1I86X@3V-E86X@5&5R<FET;W)Y`$)R=6YE:2!$87)U<W-A;&%M`$)U
M;&=A<FEA`$)U<FMI;F$@1F%S;P!"=7)U;F1I`$-20P!#86QE;F1A<@!#86UB
M;V1I80!#86UE<F]O;@!#86YA9&$`0V%N8V5L`$-A<&4@5F5R9&4`0V%P=&EO
M;@!#87)R:65R`$-A>6UA;B!)<VQA;F1S`$-E;G1E<@!#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,`0VAA9`!#:&%N9V4`0VAI;&4`0VAI;F$`0VAR:7-T;6%S
M($ES;&%N9`!#;&5A<@!#;&5A<B!1=65R>0!#;&]S92!7:6YD;W<`0V]C;W,@
M*$ME96QI;F<I($ES;&%N9',`0V]L;VUB:6$`0V]L;W(`0V]M;6%N9`!#;VUM
M96YT`$-O;6UO;B!.86UE`$-O;6]R;W,`0V]M<&%N>0!#;VUP=71E<G,`0V]N
M9&ET:6]N`$-O;F1I=&EO;G,`0V]N9FER;2!%;6%I;"!!9&1R97-S`$-O;F9I
M<FT@;F5W(&5M86EL(&%D9')E<W,`0V]N9V\`0V]N;F5C=&EO;B!F86EL960N
M`$-O;G1A8W1S`$-O;G1I;G5E`$-O;VL@27-L86YD<P!#;W!Y`$-O<W1A(%)I
M8V$`0V]U;G1R>0!#<F5A=&4`0W)O871I80!#=6)A`$-U<G)E;G0@5&EM90!#
M=7)R96YT('-T>6QE`$-U<W1O;6EZ92!T87-K<R!T;R!R=6X@=7!O;B!L;V=O
M;B!T;R`E<RX`0W5T`$-Y<')U<P!#>7)I;&QI8R`H2T])."U2*0!#>7)I;&QI
M8R`H5VEN9&]W<RTQ,C4Q*0!#>F5C:"!297!U8FQI8P!$1`!$86EL>0!$871E
M`$1A>0!$96-E;6)E<@!$96-R96%S92!);F1E;G0`1&5F875L=`!$96QE=&4`
M1&5L971E(&-O;'5M;@!$96QE=&4@<F]W`$1E;FUA<FL`1&5S8W)I<'1I;VX`
M1&5V96QO<&UE;G0`1&ER96-T;W)Y`$1J:6)O=71I`$1O;6EN:6-A`$1O;6EN
M:6-A;B!297!U8FQI8P!$;VXG="!H879E(&%N(&%C8V]U;G0_(%-I9VX@=7`N
M`$1O=VYL;V%D`$1Y;F%M:6,@36%I;`!%+4UA:6P`16-U861O<@!%9&ET`$5D
M=6-A=&EO;@!%9WEP=`!%;"!386QV861O<@!%;6%I;`!%;6%I;"!!9&1R97-S
M`$5M86EL(&%D9')E<W-E<R!M=7-T(&UA=&-H+@!%;6]T:6-O;G,`17%U871O
M<FEA;"!'=6EN96$`17)I=')E80!%<G)O<@!%<W1O;FEA`$5T:&EO<&EA`$5U
M<F]P90!%=F5R>2`Q-2!M:6YU=&5S`$5V97)Y(#,P('-E8V]N9',`179E<GD@
M-2!M:6YU=&5S`$5V97)Y(&AA;&8@:&]U<@!%=F5R>2!M:6YU=&4`17AE8W5T
M90!%>'!A;F0`17AP;VYE;G0`1F%L:VQA;F0@27-L86YD<R`H36%L=FEN87,I
M`$9A<F]E($ES;&%N9',`1F%X`$9E8G)U87)Y`$9I:FD`1FEL90!&:6QE($YA
M;64`1FEL=&5R<P!&:6YL86YD`$9L:7``1FQO870`1F]N="!#;VQO<@!&;W)M
M<P!&<F%M97,`1G)A;F-E`$9R96YC:"!'=6EA;F$`1G)E;F-H(%!O;'EN97-I
M80!&<F5N8V@@4V]U=&AE<FX@5&5R<FET;W)I97,`1G)O;0!&=6QL($YA;64`
M1V%B;VX`1V%M8FEA`$=E;W)G:6$`1V5R;6%N>0!':&%N80!':6)R86QT87(`
M1VEV96X@3F%M90!';&]B86P@3W!T:6]N<P!';P!'<F%Y<V-A;&4`1W)E96-E
M`$=R965K("A)4T\M.#@U.2TW*0!'<F5E;FQA;F0`1W)E;F%D80!'<F]U<',`
M1W5A9&5L;W5P90!'=6%M`$=U871E;6%L80!'=6EN96$`1W5I;F5A+4)I<W-A
M=0!'=7EA;F$`2%1-3`!(86ET:0!(96%D97(`2&5A9&5R<P!(96%R9"!)<VQA
M;F0@86YD($UC1&]N86QD($ES;&%N9',`2&5I9VAT`$AE;'``2&EG:`!(;VQY
M(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*0!(;VUE`$AO;64@061D<F5S<P!(
M;VUE($1I<F5C=&]R>0!(;VUE(%!H;VYE`$AO;F1U<F%S`$AO;F<@2V]N9P!(
M=6YG87)Y`$E0($%D9')E<W,`26-E;&%N9`!)8V]N<R!/;FQY`$EM86=E<P!)
M;F-R96%S92!);F1E;G0`26YD:6$`26YD;VYE<VEA`$EN9F\`26YF;W)M871I
M;VX`26YS97)T(%1A8FQE`$EN=&5G97(`27)A<0!)<F5L86YD`$ES<F%E;`!)
M<W-U97(`271A;&EC`$ET86QY`$IA;6%I8V$`2F%N=6%R>0!*87!A;@!*87!A
M;F5S92`H25-/+3(P,C(M2E`I`$IO<F1A;@!*=6QY`$IU;F4`2G5S=&EF>0!+
M87IA:VAS=&%N`$ME;GEA`$ME>2!,96YG=&@`2V5Y(%1Y<&4`2VER:6)A=&D`
M2V]R96%N("A%54,M2U(I`$MU=V%I=`!+>7)G>7IS=&%N`$QA;F=U86=E`$QA
M;R!096]P;&4G<R!$96UO8W)A=&EC(%)E<'5B;&EC`$QA='9I80!,87EO=70`
M3&5B86YO;@!,969T`$QE<V]T:&\`3&5V96P`3&EB97)I80!,:6)Y86X@07)A
M8B!*86UA:&ER:7EA`$QI96-H=&5N<W1E:6X`3&EN:P!,:6YK<P!,:71H=6%N
M:6$`3&]A9&EN9RXN+@!,;V-A=&EO;@!,;V<@:6X`3&]G(&]U=`!,;V=I;@!,
M;V=I;B!487-K<P!,;W9E`$QO=P!,=7AE;6)O=7)G`$U-`$UA8V%O`$UA9&%G
M87-C87(`36%I;`!-86QA=VD`36%L87ES:6$`36%L9&EV97,`36%L:0!-86QT
M80!-87)C:`!-87)G:6X`36%R<VAA;&P@27-L86YD<P!-87)T:6YI<75E`$UA
M=7)I=&%N:6$`36%U<FET:75S`$UA>0!-87EO='1E`$UE;6)E<G,`365S<V%G
M90!-971H;V0`365X:6-O`$UI9&1L90!-:6UE(%1Y<&4`36ER<F]R`$UI<V-E
M;&QA;F5O=7,`36]N86-O`$UO;F=O;&EA`$UO;G1H(&%N9"!Y96%R`$UO;G1H
M;'D`36]N='-E<G)A=`!-;W)O8V-O`$UO=F4@1&]W;@!-;W9E($QE9G0`36]V
M92!2:6=H=`!-;W9E(%5P`$UO=F4@9&]W;@!-;W9E('5P`$UO>F%M8FEQ=64`
M37EA;FUA<@!.86UE`$YA;6EB:6$`3F%U<G4`3F5P86P`3F5T:&5R;&%N9',`
M3F5T:&5R;&%N9',@06YT:6QL97,`3F5T=V]R:P!.979E<@!.97<@0V%L961O
M;FEA`$YE=R!-97-S86=E('1O("5S`$YE=R!:96%L86YD`$YE=R!P87-S=V]R
M9`!.97=S`$YE=W-G<F]U<',`3F5X=`!.:6-A<F%G=6$`3FEG97(`3FEG97)I
M80!.:6=H=`!.:75E`$YO`$YO;F4`3F]R9F]L:R!)<VQA;F0`3F]R=&AE<FX@
M36%R:6%N82!)<VQA;F1S`$YO<G=A>0!.;W1E<P!.;W9E;6)E<@!.=6UB97(`
M3G5M8F5R(&]F(&-H87)A8W1E<G,`3TL`3V)J96-T`$]C=&]B97(`3V9F:6-E
M`$]L9"!P87-S=V]R9`!/;6%N`$]P96X@:6X@82!N97<@=VEN9&]W`$]P97)A
M=&EN9R!3>7-T96T`3W!T:6]N<P!/=&AE<@!0861D:6YG`%!A:VES=&%N`%!A
M;&%U`%!A;F%M80!087!U82!.97<@1W5I;F5A`%!A<F%G=6%Y`%!A<W-W;W)D
M`%!A<W-W;W)D.@!087-T90!0871H`%!E;W!L90!097)C96YT`%!E<F9O<FT@
M;6%I;G1E;F%N8V4@;W!E<F%T:6]N<R!O;B!L;V=I;C\`4&5R;6ES<VEO;@!0
M97)M:7-S:6]N<P!097)S;VYA;"!);F9O<FUA=&EO;@!097)U`%!H:6QI<'!I
M;F5S`%!H;VYE`%!I=&-A:7)N`%!I>&5L<P!0;VQA;F0`4&]R='5G86P`4')E
M<W-U<F4`4')E=FEE=P!0<F]J96-T<P!0=6)L:6,@2V5Y`%!U97)T;R!2:6-O
M`%%A=&%R`%%U97)Y`%%U;W1A`%)E860`4F5F<F5S:`!2969R97-H(')A=&4Z
M`%)E;&]A9`!296UA<FMS`%)E;6]V90!297-E=`!297-U;'1S`%)E='5R;B!T
M;R!/<'1I;VYS`%)E=6YI;VX`4FEG:'0`4F]L90!2;VUA;FEA`%)O=&%T92!,
M969T`%)O=&%T92!2:6=H=`!2;W=S.@!2=6X`4G5S<VEA;B!&961E<F%T:6]N
M`%)W86YD80!34T@`4V%I;G0@2&5L96YA`%-A:6YT($MI='1S(&%N9"!.979I
M<P!386EN="!,=6-I80!386EN="!0:65R<F4@86YD($UI<75E;&]N`%-A:6YT
M(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S`%-A;6]A`%-A;B!-87)I;F\`
M4V%O(%1O;64@86YD(%!R:6YC:7!E`%-A=61I($%R86)I80!3879E`%-A=F4@
M3W!T:6]N<P!396%R8V@`4V5A<F-H($5N9VEN97,`4V5L96-T(&$@9&%T90!3
M96QE8W0@86QL`%-E;&5C="!N;VYE`%-E;F5G86P`4V5P=&5M8F5R`%-E<F)I
M82!A;F0@36]N=&5N96=R;P!397)I86P@3G5M8F5R`%-E<W-I;VYS`%-E=`!3
M971U<`!397EC:&5L;&5S`%-H;W<`4VAR:6YK`%-I97)R82!,96]N90!3:6=N
M871U<F4`4VEN9V%P;W)E`%-I>F4`4VQO=F%K:6$`4VQO=F5N:6$`4V]L;VUO
M;B!)<VQA;F1S`%-O;6%L:6$`4V]U=&@@069R:6-A`%-O=71H($=E;W)G:6$@
M86YD('1H92!3;W5T:"!386YD=VEC:"!)<VQA;F1S`%-P86-I;F<`4W!A:6X`
M4W!A;0!3<FD@3&%N:V$`4W1A;F1A<F0`4W1A='5S`%-T<FEK971H<F]U9V@`
M4W5B:F5C=`!3=6)M:70`4W5B<V-R:7!T`%-U8V-E<W,`4W5D86X`4W5M;6%R
M>0!3=7!E<G-C<FEP=`!3=7!P;W)T`%-U<FEN86UE`%-V86QB87)D(&%N9"!*
M86X@36%Y96X`4W=A>FEL86YD`%-W961E;@!3=VET>F5R;&%N9`!3>7)I86X@
M07)A8B!297!U8FQI8P!486)L90!486)L92!0<F]P97)T:65S`%1A8FQE('!R
M;W!E<G1I97,`5&%I=V%N`%1A:FEK:7-T86X`5&%S:W,`5&5L97!H;VYE($YU
M;6)E<@!496UP97)A='5R90!497AT`%1E>'0@3VYL>0!4:&%I;&%N9`!4:&5R
M92!W87,@86X@97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R=`!4
M:6UE`%1I;64@9F]R;6%T`%1I=&QE`%1O`%1O9&%Y`%1O9V\`5&]K96QA=0!4
M;VYG80!4;W``5')I;FED860@86YD(%1O8F%G;P!4=6YI<VEA`%1U<FME>0!4
M=7)K:7-H("A)4T\M.#@U.2TY*0!4=7)K;65N:7-T86X`5'5R:W,@86YD($-A
M:6-O<R!)<VQA;F1S`%1U=F%L=0!54DP`55),.@!59V%N9&$`56MR86EN90!5
M;F1E<FQI;F4`56YF:6QE9`!5;FEC;V1E("A55$8M."D`56YI=&5D($%R86(@
M16UI<F%T97,`56YI=&5D($MI;F=D;VT`56YI=&5D(%-T871E<P!5;FET960@
M4W1A=&5S($UI;F]R($]U=&QY:6YG($ES;&%N9',`56YI=',`56YK;F]W;@!5
M;FYA;65D`%5P9&%T90!5<&QO860`57)U9W5A>0!5<V5R`%5S97(@061M:6YI
M<W1R871I;VX`57-E<FYA;64`57-E<FYA;64Z`%5Z8F5K:7-T86X`5F%L:61I
M='D`5F%L=65S`%9A;G5A='4`5F%R:6%B;&4`5F5N97IU96QA`%9E<G-I;VX`
M5F5R<VEO;B!#;VYT<F]L`%9I97<@)7,`5FER9VEN($ES;&%N9',L(%4N4RX`
M5V%L;&ES(&%N9"!&=71U;F$`5V%R;FEN9P!796(`5V5B(%-I=&4`5V5E:VQY
M`%=E;&-O;64`5V5L8V]M92!T;R`E<P!797-T97)N(%-A:&%R80!7:61T:`!7
M:61T:#H`5VES:&QI<W0`5V]R:R!!9&1R97-S`%=O<FL@4&AO;F4`65D`65E9
M60!996%R;'D`665M96X`665S`%EO=7(@3F%M90!9=6=O<VQA=FEA`%IA:7)E
M`%IA;6)I80!::6UB86)W90!?3&]G(&]U=`!A9&1R97-S964@=6YK;F]W;@!C
M86YN;W0@8W)E871E(&]U='!U="!F:6QE`&-A;FYO="!O<&5N(&EN<'5T`&-O
M;6UA;F0@;&EN92!U<V%G92!E<G)O<@!C;VYF:6=U<F%T:6]N(&5R<F]R`&-R
M:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<`9&%T82!F;W)M870@97)R;W(`
M96YT<GD@;F]T(&9O=6YD`&AH`&AO<W0@;F%M92!U;FMN;W=N`&EN<'5T+V]U
M='!U="!E<G)O<@!I;G1E<FYA;"!S;V9T=V%R92!E<G)O<@!M;0!N86UE`'!E
M<FUI<W-I;VX@9&5N:65D`'!I>&5L<P!R96UO=&4@97)R;W(@:6X@<')O=&]C
M;VP`<V5R=FEC92!U;F%V86EL86)L90!S<P!S>7-T96T@97)R;W(`=&5M<&]R
M87)Y(&9A:6QU<F4`=6YK;F]W;B!E<G)O<@!U;FYA;65D`'9#87)D`%!R;VIE
M8W0M260M5F5R<VEO;CH@24U0"E!/5"U#<F5A=&EO;BU$871E.B`R,#`T+3$R
M+3`X(#$P.C(X*S`Q,#`*4$\M4F5V:7-I;VXM1&%T93H@,C`P-2TP-BTQ-2`Q
M,3HU,RLP-S`P"DQA<W0M5')A;G-L871O<CH@3&5A;F<@0VAU;7-O8F5N(#QS
M;V)E;D!K:&UE<F]S+FEN9F\^"DQA;F=U86=E+51E86TZ($MH;65R(#QS=7!P
M;W)T0&MH;65R;W,N:6YF;SX*34E-12U697)S:6]N.B`Q+C`*0V]N=&5N="U4
M>7!E.B!T97AT+W!L86EN.R!C:&%R<V5T/75T9BTX"D-O;G1E;G0M5')A;G-F
M97(M16YC;V1I;F<Z(#AB:70*`"`H)7,@X9Z0X9^2X9Z$X9^#XH"+X9Z`X9Z3
MX9^2X9Z;X9Z$XH"+X9Z1X9^%*0`@*.&>@N&?DN&>FN&>MN&>E.&?B^*`B^&>
MA>&>N^&>A>*`B^&>E>&?DN&>F^&>O.&>G.*`B^&>@.&>MN&>C^&?BR`E<RD`
M("CAGI#AGY+AGH3AGX/B@(OAGI/AGX'AGX<I`"`HX9Z0X9^2X9Z$X9^#XH"+
MX9Z?X9^2X9ZBX9^"X9Z`*0`@*.&>F.&?DN&>G^&>M^&>F^&>F.&?B>&>M^&>
MB2D`(B5S(B#AGICAGK?AGI/B@(OAGICAGX+AGI/B@(OAGH?AGK;B@(OAGI#A
MGH_B@(OAGJ'AGK[AGIG"H.&?E``B)7,B(.&>F.&>M^&>D^*`B^&>F.&?@N&>
MD^*`B^&>A^&>MN*`B^&>A^&>F.&?DN&>FN&>ON&>G^*`B^&>C^&?DN&>FN&>
MN>&>F.&>C^&?DN&>FN&>O.&>G.*`B^&>H>&>ON&>F<*@X9^4`"5D("5S(.&>
MD^&>M^&>A"`E<P`E<R!+0@`E<R#AGICAGX'AGH#AGK;AGI3AGX,`)7,@X9^6
M("5S`"TM(.&>A^&?DN&>FN&>ON&>GR`M+0#AGI'AGY+AGIKAGH3AGXOAGI'A
MGY+AGIKAGK;AGID@X9^AX9^B(.&>F.&?B>&?A.&>A`#AGI'AGY+AGIKAGH3A
MGXOAGI'AGY+AGIKAGK;AGID@X9^BX9^D(.&>F.&?B>&?A.&>A`#AGZ+AGZ0@
MX9Z8X9^)X9^$X9Z$`#SAGICAGKOAGI,`X9ZBX9^&X9Z6X9ZXXH"++BXN`.&>
MEN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>HN&?AN&>EN&>N.&>@N&>CN&>D^&>
MN`#AGI3AGI/AGY+AGI#AGX+AGI@`X9Z4X9Z3X9^2X9Z0X9^"X9Z8XH"+XH"+
MXH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^`.&>HN&>MN&>G^&>F>&>
MBN&?DN&>B^&>MN&>DP#AGI_AGX#AGISAGI?AGX7B@(OAGJ+AGK;AGI_AGIGA
MGHKAGY+AGHOAGK;AGI,`X9Z`X9ZVX9Z:XH"+X9Z"X9^2X9Z:X9Z4X9^+XH"+
MX9Z"X9^2X9Z:X9Z$`.&>HN&>MN&>H.&?DN&>@N&>MN&>D^&>N.&>G^&?DN&>
MD.&>MN&>DP#AGJ+AGK;AGIOAGXOAGI3AGK;AGI/AGK@`X9ZBX9ZVX9Z;X9^+
MX9Z@X9^2X9Z?X9^!X9Z:X9ZX`.&>B.&?DN&>F.&?A.&?A^*`B^&>@.&?DN&>
MF^&?@N&>A.&>@.&?DN&>F^&>MN&>F0#AGH_AGICAGY+AGIKAGKGAGI@`X9Z1
MX9ZVX9^&X9Z$XH"+X9ZBX9Z?X9^+`.&>E.&?DN&>BN&>O.&>FN*`B^&>HN&>
MMN&>G^&>F>&>BN&?DN&>B^&>MN&>D^*`B^&>HN&?BN&>N.&>F.&?@N&>FP#A
MGI_AGK;AGICAGKSAGJ+AGK8@X9ZBX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>HN&>
MA.&?B^&>BN&>O.&>FN&?B>&>M@#AGJ+AGH3AGXOAGJ#AGY+AGH+AGX3AGJ'A
MGK8`X9ZBX9Z$X9^+X9Z@X9^2X9Z?X9^*X9ZXX9ZAX9ZV`.&>E^&>MN&>@N*`
MB^&>@>&>MN&>A.*`B^&>C^&?DN&>E.&>O.&>A`#AGJ+AGH3AGXOAGI'AGKCA
MGJ#AGY+AGH+AGK8@X9Z3X9ZWX9Z$(.&>E.&>MN&>E.&?BN&>N^&>F>&>BN&>
MM@#AGH#AGICAGY+AGICAGISAGK?AGI+AGK@`X9Z8X9^!X9Z?X9ZV`.&>HN&>
MMN&>FN&?B>&>MN&>E.&?BR`H5VEN9&]W<RTQ,C4V*0#AGJ+AGK;AGJ#AGY+A
MGI_AGH3AGXOAGI'AGKCAGI,`X9ZBX9ZVX9Z8X9^!X9Z3X9ZX`.&>HN&>MN&>
MFN&>O.&>E.&>M@#AGH+AGKOAGH[AGIOAGH#AGY+AGH'AGH[AGX@`X9Z?X9ZX
MX9Z@X9ZV`.&>HN&>O.&>G^&?DN&>C^&?DN&>FN&>MN&>F^&>N`#AGJ+AGKSA
MGI'AGY+AGIKAGKCAGI\`X9Z`X9ZVX9Z:XH"+X9Z5X9^2X9Z1X9^`X9Z$XH"+
MX9Z5X9^2X9Z1X9ZVX9Z/X9^+XH"+X9Z7X9ZVX9Z6XH"+X9Z/X9^2X9Z:X9ZY
MX9Z8XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z4X9ZVX9Z3XH"+X9Z4X9Z:X9ZV
MX9Z'X9^0X9Z9`.&>HN&>MN&>H.&?DN&>G^&?BN&?@N&>FN&>E.&?@N&>H.&?
MDN&>G^&>A.&?BP#AGI7AGY+AGI'AGX/B@(OAGH'AGK;AGH3B@(OAGH#AGY+A
MGIKAGX3AGID`X9Z6X9Z.X9^,XH"+X9Z5X9^2X9Z1X9^#XH"+X9Z!X9ZVX9Z$
MXH"+X9Z`X9^2X9Z:X9^$X9Z9`.&>E.&>MN&>H.&>MN&>F.&?B>&>MN&>GP#A
MGI3AGK;AGIKAGXGAGX+AGI,`X9Z4X9Z$X9^+X9Z`X9^2X9Z;X9ZVX9Z*X9^!
MX9Z?X9^2X9Z@`.&>E.&>MN&>FN&>E.&>MN&>BN&>O.&>GP#AGI3AGX'AGJ'A
MGK;AGIKAGKOAGI_AGY+AGI\`X9Z4X9^"X9Z;XH"+X9Z@X9^2X9Z?X9^*X9ZW
MX9Z``.&>E.&?@>&>F^&>N.&>H.&?DN&>GP#AGI3AGX'AGH[AGK;AGX;AGH0`
MX9Z4X9^*X9^!X9Z:X9Z8X9Z\X9Z*X9ZV`.&>E.&?BN&>O.&>C^&>MN&>DP#A
MGI#AGY+AGH3AGX/AGH#AGX;AGH[AGK[AGH\`X9Z*X9ZWX9Z/`.&>E.&>O.&>
MF^&>N.&>G.&>N`#AGH#AGI/AGY+AGIOAGX+AGH3B@(OAGH7AGX;AGH[AGK;A
MGX8`X9Z?X9^*X9Z[X9Z8`.&>G^&?BN&>N^&>F.*`BP#AGI3AGKSAGI_AGY+A
MGI/AGXKAGK@@X9Z3X9ZWX9Z$(.&>H.&>NN&>H.&?DN&>G^&?BN&?@>&>H.&?
MDN&>@N&?A.&>G.&>N.&>CN&>M@#AGI'AGK;AGX;AGH3B@(OAGI;AGKCAGIKB
M@(L`X9Z4X9Z[X9Z/X9Z?X9^2X9Z<X9ZVX9Z.X9ZV`.&>E.&>MN&>CP#AGH#A
MGX3AGX?B@(OAGI3AGXKAGKSAGISAGXGAGX(`X9Z4X9^2X9Z:X9^!X9Z?X9^*
MX9ZXX9Z;`.&>HN&>MN&>CN&>MN&>A>&>@.&?DN&>FN*`B^&>G^&>F.&>N^&>
MD>&?DN&>FN*`B^&>I>&>CN&?DN&>C.&>MB#AGJ+AGH3AGXOAGH+AGY+AGIOA
MGX'AGI\`X9Z4X9^2X9Z:X9^*X9Z[X9Z9X9Z.X9^!XH"+X9Z*X9ZVX9Z:X9^*
MX9Z[X9Z9X9Z?X9ZVX9ZAX9ZVX9Z8`.&>E.&?BN&>N^&>F^&>H.&?DN&>@N&>
MMN&>FN&>N`#AGI3AGXKAGKSAGIKAGH+AGKCAGH[AGK;AGJ#AGY+AGISAGK;A
MGI_AGKP`X9Z4X9^*X9Z\X9Z:X9Z[X9Z3X9Z,X9ZX`$-20P#AGI3AGY+AGIKA
MGH_AGK?AGI'AGK?AGI,`X9Z`X9Z8X9^2X9Z6X9Z[X9Z'X9ZV`.&>@.&>MN&>
MF.&?B>&>MN&>FN&>O.&>DP#AGH#AGK;AGH[AGK;AGHKAGK8`X9Z4X9^$X9^'
MX9Z4X9Z$X9^+`.&>@.&>MN&>E.&>G.&?@N&>F@#AGH7AGX;AGH[AGH3AGH?A
MGK[AGH0`X9Z<X9Z/X9^2X9Z0X9Z[XH"+X9Z*X9ZYX9Z`XH"+X9Z'X9Z)X9^2
MX9Z'X9Z\X9Z3`.&>@.&?A.&?A^*`B^&>@.&?@^&>F.&?B>&>MN&>DP#AGH#A
MGH[AGY+AGH_AGK;AGIL`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+
MXH"+X9ZBX9ZVX9Z@X9^2X9Z<X9^2X9Z:X9ZWX9Z`XH"+X9Z`X9Z.X9^2X9Z*
MX9ZVX9Z;`.&>AN&>MN&>B@#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI3AGY+A
MGH_AGKSAGIH`X9Z(X9ZXX9Z;X9ZX`.&>A>&>M^&>DP#AGH#AGX3AGX?B@(OA
MGH+AGY+AGIKAGKCAGI_AGY+AGH_AGICAGXGAGK;AGI\`X9Z'X9Z8X9^2X9Z:
MX9^'`.&>A^&>F.&?DN&>FN&?A^*`B^&>G^&?AN&>CN&>O>&>F@#AGI3AGK?A
MGI'B@(OAGI3AGH3AGY+AGJ+AGKWAGH4`X9Z`X9^$X9^'XH"+X9Z`X9Z\X9Z`
MX9Z\("CAGH/AGKCAGIOAGKCAGH0I`.&>@.&>O.&>H>&>N^&?AN&>E.&?BN&>
MN`#AGI;AGH[AGXP`X9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z4X9Z)X9^2X9Z'X9ZV
M`.&>G^&?@>&>A>&>@.&?DN&>C^&>N.*`B^*`B^&>HN&>DN&>M^&>E.&?DN&>
ME.&>MN&>F0#AGHCAGY+AGICAGX3AGX?B@(OAGI+AGICAGY+AGICAGH_AGK8`
MX9Z`X9Z[X9^&X9Z8X9^)X9Z\X9Z:X9^)X9Z\X9Z?`.&>@.&?DN&>FN&>N^&>
MF.&>H.&?BN&>N^&>DP#AGH#AGKOAGX;AGI;AGY+AGIGAGKSAGI'AGY#AGIH`
MX9Z;X9Z`X9^2X9Z!X9Z!X9Z.X9^2X9Z,`.&>F^&>@.&?DN&>@>&>@>&>CN&?
MDN&>C`#AGJ+AGX?AGJ+AGK;AGH3B@(OAGJ+AGK;AGI_AGIGAGHKAGY+AGHOA
MGK;AGI/B@(OAGJ+AGXKAGKCAGICAGX+AGIL`X9ZBX9^'X9ZBX9ZVX9Z$XH"+
MX9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*X9ZXX9Z8X9^"
MX9Z;XH"+X9Z0X9^2X9Z8X9ZX`.&>@.&>N^&>A.&>H.&?DN&>@N&?A`#AGH#A
MGK;AGIKB@(OAGH_AGI?AGY+AGH?AGK;AGI3AGXOB@(OAGI3AGK;AGI/B@(OA
MGI3AGIKAGK;AGH?AGY#AGIGB@(O"H.&?E`!#;VYT86-T<P#AGI3AGI/AGY+A
MGH\`X9Z`X9^$X9^'XH"+X9Z`X9Z\X9Z``.&>A>&>F.&?DN&>F^&>A`#AGH#A
MGKSAGI_AGY+AGH_AGK;AGIKAGKCAGH#AGK8`X9Z4X9^2X9Z:X9Z1X9^!X9Z?
M`.&>E.&>A.&?DN&>@.&>ON&>CP#AGH#AGY+AGIKAGKSAGJ+AGK;AGH\`X9Z"
MX9Z[X9Z9X9Z4X9ZV`.&>EN&?@>&>F^*`B^&>G.&?@>&>F^&>MN*`B^&>E.&>
MA>&?DN&>A>&>N^&>E.&?DN&>E.&>D^&?DN&>DP#AGIKAGH7AGI/AGK;AGI3A
MGY#AGI'AGY+AGICB@(OAGI3AGH7AGY+AGH7AGKOAGI3AGY+AGI3AGI/AGY+A
MGI/B@(L`X9Z4X9^2X9Z/X9Z\X9Z:XH"+X9Z7X9ZVX9Z:X9Z`X9ZWX9Z%X9^2
MX9Z%XH"+X9Z*X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z:X9Z/X9^+
MXH"+X9Z/X9ZVX9Z8XH"+X9Z4X9^&X9Z.X9Z$(.&>HN&>MN&>G^&?DN&>FN&?
MD.&>F>*`B^&>F^&>ON*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>F^*`B^&>D>&?
MA>*`BR`E<R#AGY0`X9Z`X9ZVX9Z/X9^+`.&>G^&?BN&>N.&>EN&>FN&?C0#A
MGI_AGXKAGKCAGIKAGKCAGIOAGKCAGH`@*$M/23@M4BD`XH"+XH"+X9Z?X9^*
MX9ZXX9Z:X9ZXX9Z;X9ZXX9Z`("A7:6YD;W=S+3$R-3$I`.&>G^&>MN&>DN&>
MMN&>FN&>CN*`B^&>FN&>BN&?DN&>B^*`B^&>AN&?@>&>@`!$1`#AGIKAGK;A
MGIOAGXOB@(OAGI#AGY+AGH3AGX,`X9Z`X9ZVX9Z;XH"+XH"+X9Z4X9Z:X9ZW
MX9Z%X9^!X9^2X9Z&X9Z1`.&>D.&?DN&>A.&?@P#AGI+AGY+AGI/AGKP`X9Z4
MX9Z3X9^2X9Z0X9Z9(.&>A>&>O.&>F^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?
MBP#AGIOAGX;AGI/AGK;AGX;AGHKAGK[AGI@`X9Z;X9Z[X9Z4XH"+`.&>F^&>
MN^&>E.*`B^&>A^&>O>&>FN*`B^&>B.&>F@#AGIOAGKOAGI3B@(OAGH?AGKWA
MGIKAGHKAGX'AGH``X9Z*X9ZVX9Z.X9ZZX9Z8X9^)X9ZVX9Z``.&>@.&>MN&>
MFN&>EN&>M^&>EN&>CN&?C.&>D^&>M@#B@(OAGJ+AGI?AGK?AGISAGHSAGY+A
MGHT`X9Z0X9Z/`.&>H.&?DN&>G^&?BN&>N.&>E.&>O.&>D>&>N`#AGHKAGKSA
MGICAGKCAGI/AGKCAGH#AGK8`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2
MX9Z+XH"+X9Z*X9Z\X9Z8X9ZXX9Z3X9ZXX9Z`X9^"X9Z3`.&>F.&>M^&>D^*`
MB^&>F.&>MN&>D^*`B^&>@N&>CN&>D^&>N,*@/R#AGI_AGKSAGICB@(OAGH7A
MGKOAGX?AGHCAGY+AGICAGX3AGX?"H.&?E`#AGI'AGK;AGHGAGIGAGH``X9Z?
MX9^&X9Z4X9Z[X9Z/X9^2X9Z:XH"+X9Z0X9ZVX9Z8X9Z<X9Z3X9^2X9Z/`.&>
MHN&?BN&>N.&>F.&?@N&>FP#AGJ+AGX'AGH#AGY+AGISAGK;AGHSAGY#AGIH`
MX9Z`X9^"XH"+X9Z?X9Z8X9^2X9Z:X9Z]X9Z;`.&>@.&>MN&>FN*`B^&>HN&>
ME.&?B^&>FN&?A@#AGJ+AGX'AGJ#AGY+AGI_AGXKAGKCAGI0`X9ZBX9^"X9Z;
MX9Z?X9ZVX9Z;X9^+X9Z<X9^)X9ZVX9Z,X9^0X9Z:`.&>HN&?BN&>N.&>F.&?
M@N&>FP#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGJ+AGXKAGKCA
MGICAGX+AGIL`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+X9ZBX9^*
MX9ZXX9Z8X9^"X9Z;XH"+X9Z/X9^2X9Z:X9Z\X9Z<XH"+X9Z/X9^"XH"+X9Z*
MX9Z\X9Z%X9Z"X9^2X9Z3X9ZVPJ#AGY0`X9Z?X9Z)X9^2X9Z)X9ZVXH"+X9ZB
MX9ZVX9Z:X9Z8X9^2X9Z8X9Z.X9^-`.&>H.&?DN&>@N&>N.&>CN&?@>*`B^&>
MHN&?@>&>@.&?DN&>G.&>MN&>D>&?D.&>F@#AGJ+AGX'AGIKAGKCAGI'AGY+A
MGIKAGK8`X9Z`X9^&X9Z@X9Z[X9Z?`.&>HN&?@>&>G^&?DN&>C^&>O.&>D^&>
MN`#AGJ+AGX'AGH_AGY+AGIGAGKSAGI;AGK@`X9ZBX9ZZX9Z:X9^)X9Z[X9Z4
M`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`BR#AGZ'AGZ4@X9Z3X9ZVX9Z1
MX9ZX`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`BR#AGZ/AGZ`@X9Z<X9ZW
MX9Z3X9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?BR#AGZ4@X9Z3
MX9ZVX9Z1X9ZX`.&>FN&?@.&>A.*`B^&>FN&>MN&>F^&?B^*`B^&>@.&>D^&?
MDN&>F^&?A^*`B^&>F.&?B>&?A.&>A`#AGIKAGX#AGH3B@(OAGIKAGK;AGIOA
MGXOAGI/AGK;AGI'AGK@`X9Z4X9^2X9Z:X9Z/X9ZWX9Z4X9Z/X9^2X9Z/X9ZW
M`.&>E.&>D^&?DN&>F^&>MN&>F0#AGJ+AGXKAGK?AGH7AGI_AGY+AGI3AGKSA
MGH[AGH3AGXOAGI_AGX+AGIL`X9Z`X9^$X9^'XH"+X9Z@X9^2X9Z<X9^)X9Z`
MX9ZAX9Z$X9^+("CAGICAGXGAGK;AGIOAGXOAGISAGKCAGH[AGK8I`.&>@.&?
MA.&?A^&>H.&?DN&>G.&>MN&>HN&?@>&>FN&>O`#AGI'AGKSAGIKAGI_AGK;A
MGIH`X9Z`X9Z[X9Z8X9^2X9Z7X9^(`.&>H.&?DN&>G.&>N.&>H.&?DN&>G^&?
MBN&>N`#AGJ_AGH#AGI_AGK;AGIH`X9Z(X9^2X9Z8X9^$X9^'XH"+X9ZOX9Z`
MX9Z?X9ZVX9Z:`.&>C^&>F.&?DN&>FN&>A`#AGJ#AGY+AGISAGK;AGX;AGH3A
MGJ'AGH3AGXL`X9Z/X9^2X9Z:X9ZAX9Z4X9^+`.&>D>&>G^&>E^&>MN&>@@#A
MGI;AGH[AGXSB@(OAGI;AGKOAGICAGY+AGI;B@(OAGJ+AGH#AGY+AGI_AGIH`
MX9Z?X9^&X9Z.X9Z[X9^&XH"+XH"+X9Z4X9^"X9Z4X9Z4X9Z1`.&>G^&?BN&>
MN^&>F`#AGI3AGK;AGIKAGK;AGX;AGH0`X9Z@X9^2X9Z"X9Z\X9ZBX9^*X9ZX
MX9Z9X9^)X9ZVX9Z.X9ZV(.&>E.&>MN&>FN&>MN&?AN&>A`#AGI3AGXGAGKSA
MGIOAGKCAGI/AGX'AGI_AGXKAGKCB@(OAGI3AGK;AGIKAGK;AGX;AGH0`X9ZB
MX9ZVX9Z.X9Z%X9Z`X9^2X9Z:XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\
MX9Z$(.&>E.&>MN&>FN&>MN&?AN&>A`#AGI;AGK@`X9Z(X9^2X9Z8X9^$X9^'
MXH"+X9Z6X9^!X9Z)`.&>H.&?DN&>@N&>MN&>E.&>N^&>A`#AGJ#AGY+AGH#A
MGK;AGX;AGI3AGXKAGK@`X9Z@X9^2X9Z?X9Z`X9Z@X9^2X9Z?X9^*X9ZX`.&>
MHN&>MN&>F^&?DN&>F^&>NN&>F.&?B>&>A.&?BP#AGJ#AGY+AGH#AGK;AGH[A
MGK8`X9Z@X9^2X9Z"X9ZXX9Z4X9^2X9Z:X9ZVX9Z;X9^+X9Z/X9ZV`.&>D^&>
MMN&>F.&>@>&?DN&>F^&>O>&>DP#AGH?AGICAGY+AGIKAGK[AGI_B@(OAGI_A
MGH#AGIL`X9Z1X9^%`.&>F.&>MN&>C^&?DN&>FN&>BN&?DN&>B^&>MN&>D^*`
MB^&>E.&?DN&>FN&>E>&?@>&?AP#AGH#AGY+AGIKAGK?AGH``X9Z`X9^2X9Z:
MX9ZWX9Z`("A)4T\M.#@U.2TW*0#AGH+AGY+AGIKAGKCAGJ'AGH3AGXL`X9Z@
MX9^2X9Z"X9^2X9Z:X9ZXX9Z.X9ZVX9Z*X9ZV`.&>@.&?DN&>FN&>N^&>F`#A
MGJ#AGY+AGH+AGKSAGJ+AGK;AGHKAGKKAGIOAGKSAGI3AGXGAGX$`X9Z@X9^2
MX9Z"X9ZVX9^&X9Z8`.&>H.&?DN&>@N&>MN&>C^&?@>&>F.&?B>&>MN&>H>&>
MM@#AGJ#AGY+AGH+AGKCAGH[AGX$`X9Z@X9^2X9Z"X9ZXX9Z.X9^!X9Z4X9^*
MX9ZXX9Z?X9^%`.&>H.&?DN&>@N&>N.&>F>&?B>&>MN&>CN&>M@!(5$U,`.&>
MH.&?@^&>D>&>N`#AGI3AGHOAGICAGH#AGI#AGK;B@(L`X9Z4X9Z+X9Z8X9Z`
MX9Z0X9ZV`.&>@.&?A.&?A^*`B^&>H.&?BN&>ON&>BB#AGI/AGK?AGH0@X9Z`
MX9^$X9^'XH"+X9Z8X9^)X9ZVX9Z`X9Z*X9Z\X9Z.X9ZVX9Z;X9^+`.&>@.&>
MF.&?DN&>EN&>G^&?BP#AGH?AGX;AGI/AGKWAGID`X9Z!X9^2X9Z6X9Z?X9^+
M`.&>H.&>O.&>F^&>N.&>G^&?BN&>N"`HX9Z:X9Z*X9^2X9Z+XH"+X9Z`X9^2
MX9Z:X9Z[X9Z$XH"+X9Z<X9^)X9ZVX9Z1X9ZXX9Z`X9Z$X9^+*0#AGH+AGX'A
MGJ#AGI'AGX;AGI;AGY#AGIH`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3
MXH"+X9Z5X9^2X9Z1X9^'`.&>D.&>C^&>E>&?DN&>D>&?AP#AGI'AGKSAGIKA
MGI_AGY#AGI;AGY+AGI'B@(OAGI7AGY+AGI'AGX<`X9Z@X9Z[X9Z$X9Z,X9Z\
MX9Z:X9^)X9ZVX9Z?X9^+`.&>H.&>N^&>A.&>@.&>N^&>A`#AGJ#AGKOAGH3A
MGH+AGY+AGIKAGK@`X9ZBX9ZVX9Z?X9Z9X9Z*X9^2X9Z+X9ZVX9Z3XH"+($E0
M`.&>HN&?BN&>N.&>G^&?DN&>F^&>A.&?BP#AGH_AGX+B@(OAGIKAGKSAGI3A
MGH_AGX;AGH[AGK;AGH0`X9Z:X9Z\X9Z4X9Z7X9ZVX9Z6`.&>E.&>A.&?DN&>
M@.&>ON&>D^*`B^&>@.&>MN&>FN*`B^&>A>&>O.&>F^*`B^&>E.&>D^&?DN&>
MD>&>MN&>C^&?BP#AGJ7AGH[AGY+AGHSAGK8`X9ZEX9Z.X9^2X9Z,X9Z\X9Z3
MX9^!X9Z?X9^*X9ZX`.&>EN&?D.&>C^&?C.&>F.&>MN&>DP#AGI;AGY#AGH_A
MGXSAGICAGK;AGI,`X9Z4X9Z)X9^2X9Z%X9Z\X9Z;XH"+X9Z/X9ZVX9Z:X9ZV
MX9Z$`.&>A>&?AN&>D^&>O>&>D^*`B^&>@N&>C^&?BP#AGJ+AGXKAGKCAGIKA
MGXGAGK;AGH#AGXL`X9ZBX9^`X9Z:X9ZAX9Z$X9^+`.&>HN&?BN&>N.&>G^&?
MDN&>FN&>MN&>HN&?@N&>FP#AGJ+AGY+AGI/AGH#B@(OAGH7AGX'AGHD`X9Z1
MX9^2X9Z:X9^!X9Z/`.&>HN&?BN&>N.&>C^&>MN&>F^&>N`#AGH7AGK;AGICA
MGXGAGX/AGH#AGK8`X9Z8X9Z`X9Z:X9ZV`.&>A^&>E.&?B>&>N^&>DP#B@(OA
MGH?AGI3AGXGAGKOAGI,@*$E33RTR,#(R+4I0*0#AGJ#AGY+AGI_AGXKAGH#A
MGHKAGK;AGI/AGK@`X9Z`X9Z`X9^2X9Z`X9Z*X9ZV`.&>F.&>M^&>D.&>N^&>
MD^&>M@#AGH_AGICAGY+AGIKAGKGAGICB@(OAGI_AGH3B@(OAGH'AGK;AGH0`
MX9Z`X9ZVX9Z@X9^2X9Z?X9ZVX9Z`X9^+X9Z?X9^2X9Z/X9Z$X9^+`.&>@.&?
M@N&>D^&>F>&?B>&>M@#AGI3AGY+AGIKAGISAGX+AGH3B@(OAGH#AGKSAGI/A
MGI_AGX0`X9Z4X9^2X9Z:X9Z7X9^!X9Z1XH"+X9Z"X9^2X9Z:X9ZVX9Z4X9^+
MXH"+X9Z%X9Z[X9Z%`.&>@N&>M^&>FN&>M^&>E.&>MN&>D>&>N`#B@(OAGH#A
MGKSAGIKAGXGAGX$@*$550RU+4BD`X9Z"X9Z[X9Z9XH"+X9Z<X9^)X9^"X9Z/
M`.&>@N&?@.&>FN&>H.&?DN&>@N&>N.&>G^&?DN&>C^&>A.&?BP#AGI?AGK;A
MGI_AGK8`X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9Z:X9Z*X9^2X9Z+XH"+X9Z4X9^2
MX9Z:X9Z'X9ZVX9Z2X9ZWX9Z4X9Z/X9^!X9Z9X9^2X9Z9XH"+X9Z4X9^2X9Z:
MX9Z'X9ZVX9Z8X9ZVX9Z3X9ZWX9Z/XH"+X9ZAX9ZVX9Z<`.&>H>&>MN&>C^&>
MG.&>N.&>F>&?B>&>M@#AGI3AGY+AGIOAGH3AGXOB@(L`X9Z;X9ZXX9Z4X9Z$
MX9^+`.&>AN&?DN&>G.&?@>&>A`#AGJ'AGX'AGI_AGKSAGH_AGKP`X9Z`X9Z8
MX9^2X9Z:X9ZWX9Z/`.&>F^&>N.&>E.&?@>&>FN&>N.&>F>&?B>&>M@#AGH7A
MGK;AGICAGXGAGK;AGJ+AGXKAGK?AGIKAGKCAGIGAGXGAGK;B@(OAGJ+AGK;A
MGIKAGXGAGK;AGI3AGXL@X9Z;X9ZXX9Z4X9^*X9ZX`.&>F^&>M^&>A>&>D>&?
M@>&>D^&>G^&?DN&>C^&?@N&>DP#AGH_AGX;AGHX`X9Z/X9^&X9Z.`.&>F^&>
MN.&>D>&>N^&>F>&>HN&>MN&>D^&>N`#AGH#AGX;AGI;AGKOAGH3B@(OAGI7A
MGY+AGI'AGKOAGH`N+BX`X9Z1X9ZXX9Z/X9ZVX9^&X9Z$`.&>A>&>O.&>FP#A
MGH7AGX'AGHD`X9Z%X9Z\X9Z;`.&>E^&>MN&>FN&>@.&>M^&>A>&?DN&>A>*`
MB^&>A>&>O.&>FP#AGI_AGX'AGH7AGH#AGY+AGH_AGKCB@(OAGI_AGY+AGIKA
MGJ'AGK;AGHGAGXL`X9Z1X9ZVX9Z4`.&>F^&>N^&>A>&>H.&?DN&>G^&?AN&>
ME.&>O>&>F@!-30#AGICAGXGAGK;AGH#AGK;AGIP`X9Z8X9^)X9ZVX9Z*X9ZV
MX9Z@X9^2X9Z`X9ZVX9Z?X9^2X9Z`X9ZVX9Z:`.&>G^&?AN&>E.&>N^&>C^&?
MDN&>F@#AGICAGXGAGK;AGJ'AGK;AGISAGX,`X9Z8X9^)X9ZVX9ZAX9^!X9Z?
MX9^*X9ZX`.&>F.&?B>&>MN&>F^&?B^&>C.&>N.&>G`#AGICAGXGAGK;AGIOA
MGK@`X9Z8X9^)X9ZVX9Z;X9^+X9Z/X9ZV`.&>F.&>N.&>D^&>M@#AGIKAGKGA
MGICB@(OAGI'AGX;AGI;AGY#AGIH`X9Z`X9^$X9^'($UA<G-H86QL`.&>F.&?
MB>&>MN&>FN&>D>&>N.&>D^&>N.&>@@#AGICAGXGAGKSAGIKAGKCAGH_AGK;A
MGI/AGK@`X9Z8X9^)X9Z\X9Z:X9ZXX9Z1X9Z[X9Z?`.&>I^&>G^&>E^&>M@#A
MGICAGX/AGJ+AGKSAGH_AGX$`X9Z?X9Z8X9ZVX9Z'X9ZWX9Z``.&>G^&>MN&>
MF@#AGISAGK?AGI+AGKCAGI_AGK;AGI_AGY+AGIKAGY+AGH\`X9Z8X9^)X9ZW
MX9Z%X9Z?X9^*X9ZWX9Z``.&>@.&>CN&?DN&>C^&>MN&>FP#AGI3AGY+AGIKA
MGI?AGX'AGI$@36EM90#AGH;AGY+AGIOAGKOAGX<`X9Z5X9^2X9Z?X9^!X9Z$
MX9^7XH"+`.&>F.&?B>&>O.&>CN&>MN&>@.&>O`#AGICAGXGAGKOAGH3AGJ#A
MGY+AGH+AGX3AGIOAGK@`X9Z!X9^"(.&>D^&>M^&>A"#AGH;AGY+AGI/AGK;A
MGX8`X9Z:X9ZVX9Z;X9^+XH"+X9Z!X9^"`.&>F.&?B>&>N^&>A.&>G^&?@>&>
MFN&?B>&>M@#AGICAGXGAGK;AGIKAGXGAGKOAGH``X9Z5X9^2X9Z;X9ZVX9Z?
MX9^+XH"+X9Z1X9ZXXH"+X9Z%X9Z[X9^'XH"+X9Z`X9^2X9Z:X9^$X9Z8`.&>
ME>&?DN&>F^&>MN&>G^&?B^*`B^&>D>&>N.*`B^&>D>&?A>*`B^&>AN&?DN&>
MG.&?@>&>A`#AGI7AGY+AGIOAGK;AGI_AGXOB@(OAGI'AGKCB@(OAGI'AGX7B
M@(OAGI_AGY+AGH_AGK;AGX8`X9Z5X9^2X9Z;X9ZVX9Z?X9^+XH"+X9Z1X9ZX
MXH"+X9ZAX9Z^X9Z$XH"+X9Z;X9Z^`.&>A>&>N^&?A^*`B^&>@.&?DN&>FN&?
MA.&>F`#AGJ'AGK[AGH3B@(OAGIOAGKX`X9Z8X9^)X9Z\X9Z@X9^2X9Z?X9ZV
MX9^&X9Z4X9^*X9ZWX9Z``.&>F.&>N.&>F>&?B>&>MN&>D^&?B^&>F.&?B>&>
MM@#AGHCAGY+AGICAGX3AGX<`X9Z.X9ZVX9Z8X9ZXX9Z4X9^*X9ZX`.&>CN&>
MO.&>FN&>NP#AGI/AGX'AGI3AGXGAGK;AGIOAGXL`XH"+X9Z@X9Z[X9Z;X9^2
MX9Z;X9Z$X9^+`.&>HN&>A.&?B^&>D>&>N.&>F>&?C>*`B^&>H.&>O.&>F^&?
MDN&>F^&>A.&?BP#AGI3AGH[AGY+AGH_AGK;AGHD`X9Z`X9Z[X9^&`.&>D^&>
MO.&>G.&?@N&>F^&>@.&>MN&>F^&?@>&>BN&>O.&>D^&>N`#AGI_AGK;AGIKB
M@(OAGI#AGY+AGICAGKCB@(OAGI'AGX4@)7,`X9Z3X9Z\X9Z<X9^"X9Z;X9Z@
MX9^*X9^2X9Z?X9^!X9ZAX9Z$X9^+`.&>EN&>MN&>@.&?DN&>F>*`B^&>G^&>
MF.&?DN&>A.&>MN&>C^&?B^*`B^&>D.&?DN&>F.&>N`#AGI;AGY#AGH_AGXSA
MGICAGK;AGI,`X9Z<X9^!X9Z1X9ZWX9Z`X9ZVXH"+X9Z6X9^0X9Z/X9^,X9Z8
MX9ZVX9Z3`.&>E.&>D^&?DN&>D>&>MN&>E.&?BP#AGI/AGKCAGH#AGK;AGIKA
MGXGAGK;AGJ#AGY+AGH+AGY#AGIH`X9Z3X9ZXX9Z@X9^2X9Z?X9^!X9Z:`.&>
MD^&>N.&>H.&?DN&>G^&?@>&>FN&>N.&>F>&?B>&>M@#AGIGAGI3AGXL`X9Z3
MX9ZXX9Z<`.&>D>&?@0#AGH+AGY+AGICAGK;AGI,`X9Z`X9^$X9^'XH"+X9Z.
MX9^)X9Z@X9^2X9Z<X9^)X9Z``.&>@.&?A.&?A^*`B^&>F.&?B>&>MN&>FN&?
M@.&>CN&>MN*`B^&>E^&>MN&>@N*`B^&>@>&>MN&>A.*`B^&>A^&>ON&>A`#A
MGI/AGY#AGIKAGISAGX+AGI\`X9Z%X9^&X9Z.X9ZVX9^&`.&>G.&>M^&>A>&?
MDN&>AN&>M^&>@.&>M@#AGIOAGX'AGH$`X9Z%X9^&X9Z3X9Z]X9Z3XH"+X9Z/
MX9Z]X9ZBX9Z`X9^2X9Z?X9Z:`.&>F>&>F^&?B^&>EN&?DN&>FN&>F`#AGISA
MGH_AGY+AGI#AGKL`X9Z/X9Z[X9Z;X9ZV`.&>@.&>MN&>FN&>M^&>F>&>MN&>
MF^&?D.&>F0#AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICAGY+AGH3AGK;AGH_A
MGXOB@(OAGH7AGK;AGI_AGXL`X9ZBX9Z\X9Z8X9^"X9Z3`.&>E.&>ON&>@.*`
MB^*`B^&>@.&?DN&>D^&>N^&>A.*`B^*`B^&>E.&>A.&?DN&>HN&>O>&>A>*`
MB^&>D.&?DN&>F.&>N`#AGI3AGY+AGIKAGI;AGY#AGI/AGY+AGI+B@(OAGI3A
MGY+AGIKAGH_AGK?AGI3AGH_AGY+AGH_AGK?AGH#AGK;AGIH`X9Z'X9Z8X9^2
MX9Z:X9Z^X9Z?XH"+`.&>E>&?DN&>G^&?@>&>A.&?EP#AGH7AGI/AGY+AGIOA
MGX3AGX<`X9Z4X9^)X9ZVX9Z"X9ZXX9Z?X9^2X9Z0X9ZVX9Z3`.&>E.&?B>&>
MMN&>H>&>O`#AGI3AGXGAGK;AGH[AGK;AGICAGXGAGK8`X9Z4X9^)X9ZVX9Z6
MX9Z\X9Z)X9Z\X9Z<X9Z@X9^2X9Z"X9ZXX9Z.X9^!`.&>E.&?B>&>MN&>FN&?
MB>&>MN&>H.&?DN&>@N&>MN&>F0#AGI;AGK;AGH#AGY+AGIGB@(OAGI_AGICA
MGY+AGH3AGK;AGH_AGXL`X9Z6X9ZVX9Z`X9^2X9Z9XH"+X9Z?X9Z8X9^2X9Z$
MX9ZVX9Z/X9^+PJ#AGY8`X9Z4X9ZWX9Z1X9Z7X9^2X9Z'X9ZVX9Z4X9^+`.&>
ME>&?DN&>F^&>O.&>G`#AGICAGI/AGKOAGI_AGY+AGI\`X9Z7X9ZVX9Z"X9Z:
MX9Z9`.&>DN&?DN&>G.&>ON*`B^&>E.&?DN&>FN&>C^&>M^&>E.&>C^&?DN&>
MC^&>M^&>@.&>MN&>FN*`B^&>C^&?AN&>H.&?@N&>D>&>MN&?AB#AGI;AGX'A
MGIOB@(OAGH7AGKSAGIL@/P#AGI_AGK?AGI'AGY+AGI+AGK<`X9Z?X9ZWX9Z1
MX9^2X9Z2X9ZW`.&>EN&?D.&>C^&?C.&>F.&>MN&>D^*`B^&>E>&?DN&>D>&>
MMN&>F^&?B^*`B^&>@>&?DN&>F^&>O>&>DP#AGI3AGXGAGX'AGIKAGXGAGKP`
MX9Z@X9^2X9Z<X9ZXX9Z;X9ZXX9Z6X9ZXX9Z3`.&>D>&>O.&>FN&>G^&?D.&>
MEN&?DN&>D0#AGI;AGKCAGH_AGH'AGK;AGIGAGIKAGK?AGI,`X9Z7X9ZXX9Z`
MX9Z?X9^"X9Z;`.&>E.&?B>&>O.&>H>&>O.&>B0#AGI;AGY#AGIKAGI'AGKOA
MGIGAGJ#AGY+AGH+AGK;AGIOAGXL`X9Z?X9Z8X9^2X9Z6X9ZVX9Z2`.&>F.&>
MON&>F^*`B^&>A^&>MN*`B^*`B^*`B^&>F.&>N^&>DP#AGH+AGICAGY+AGIKA
MGX3AGH0`X9Z`X9Z\X9Z3X9Z?X9^$XH"+X9Z?X9ZVX9Z2X9ZVX9Z:X9Z.X9^(
M`.&>EN&?D.&>FN&>C^&>O.&>FN&>N.&>@.&>O`#AGH#AGK;AGH_AGK8`X9Z?
MX9^&X9Z.X9Z]X9Z:XH"+`.&>@.&>O.&>C^&>M@#AGJ+AGK;AGI,`X9Z2X9^2
MX9Z<X9Z^XH"+X9ZRX9^2X9Z9XH"+X9Z?X9^2X9Z:X9Z?X9^+`.&>HN&>C^&?
MDN&>FN&>MN*`B^&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>G^&?DN&>
MFN&>G^&?B\*@X9^6`.&>E>&?DN&>D>&>N^&>@.*`B^&>H>&>ON&>A.*`B^&>
MG.&>M^&>B0#AGH#AGX;AGH[AGH_AGXOB@(OAGI_AGICAGY+AGH+AGK;AGIOA
MGXL`X9Z9X9Z`XH"+X9Z%X9^!X9Z)`.&>@.&?AN&>CN&>C^&?B^*`B^&>H>&>
MON&>A.*`B^&>G.&>M^&>B0#AGIOAGI'AGY+AGI+B@(OAGI7AGIL`X9Z/X9^2
MX9Z:X9ZAX9Z4X9^+XH"+X9Z1X9^%XH"+X9Z'X9Z8X9^2X9Z:X9Z^X9Z?`.&>
MFN&>N.&>HN&>N^&>F>&>D^&>N.&>F>&?B>&>N^&>A`#B@(OAGI_AGY+AGH_A
MGK;AGX8`X9Z/X9Z]X9Z3X9ZVX9Z1X9ZX`.&>FN&>O.&>F.&?B>&>MN&>D^&>
MN`#AGI3AGH3AGY+AGISAGK?AGIOB@(OAGI'AGX7B@(OAGH;AGY+AGISAGX'A
MGH0`X9Z4X9Z$X9^2X9Z<X9ZWX9Z;XH"+X9Z1X9^%XH"+X9Z?X9^2X9Z*X9ZV
MX9^&`.&>A^&>O>&>FN*`B^&>BN&?@>&>@,*@X9^6`.&>FN&>C^&?B^*`BP#A
MGI_AGJ#AGI;AGY#AGI/AGY+AGI+B@(OAGIKAGKOAGI_AGY+AGI_AGXKAGK@`
MX9Z:X9Z<X9^)X9ZVX9Z3X9^+X9Z*X9ZV`%-32`#AGI_AGH3AGXOB@(OAGJ#A
MGX'AGJ'AGX'AGH[AGK8`X9Z?X9Z$X9^+X9Z#X9ZXX9Z/(.&>D^&>M^&>A"#A
MGI/AGX'AGISAGKCAGI\`X9Z?X9Z$X9^+X9Z;X9Z\X9Z?X9^*X9ZXX9Z9X9^)
MX9ZV`.&>G^&>A.&?B^*`B^&>EN&?DN&>F>&?@N&>FB#AGI/AGK?AGH0@X9Z8
MX9ZXX9Z"X9Z[X9Z9X9ZBX9^!X9ZAX9Z[X9Z$`.&>G^&>A.&?B^&>G.&>MN&?
MAN&>A.&>G^&>A.&?BR#AGI/AGK?AGH0@XH"+X9Z@X9^2X9Z"X9^2X9Z:X9ZX
MX9Z.X9ZVX9Z,X9ZXX9Z3`.&>G^&>MN&>F.&>O.&>HN&>M@#AGI_AGK;AGI/A
MGXOAGICAGXGAGK;AGIKAGKCAGH[AGKP`4V%O(%1O;64@86YD(%!R:6YC:7!E
M`.&>HN&>MN&>FN&?B>&>MN&>E.&?B^*`B^&>E.&?BN&>N.&>G^&>MN&>HN&>
MO.&>C.&>N`#AGIKAGH#AGY+AGI_AGK;B@(OB@(OAGI'AGKOAGH#B@(OB@(L`
MX9Z:X9Z`X9^2X9Z?X9ZVXH"+X9Z1X9Z[X9Z`XH"+(.&>A^&>F.&?DN&>FN&>
MON&>GP#AGI_AGY+AGISAGX+AGH3AGIKAGH``X9Z8X9^)X9ZVX9Z?X9^*X9ZX
MX9Z3XH"+X9Z?X9^2X9Z<X9^"X9Z$X9Z:X9Z``.&>A^&?DN&>FN&>ON&>G^*`
MB^&>@.&>MN&>F^&>E.&>FN&>M^&>A>&?DN&>AN&?@>&>D0#AGH?AGY+AGIKA
MGK[AGI_B@(OAGI'AGK;AGX;AGH3AGJ+AGI_AGXL`X9Z'X9^2X9Z:X9Z^X9Z?
MXH"+X9Z"X9^2X9Z8X9ZVX9Z3`.&>G^&?@>&>CN&?@>&>H.&?DN&>@N&>MN&>
MF^&?BP#AGH#AGHGAGY+AGHGAGK8`X9Z?X9^"X9Z4X9^*X9ZX(.&>D^&>M^&>
MA"#AGICAGXGAGKOAGH3AGH_AGX'AGH[AGX'AGJ#AGY+AGH#AGY+AGIKAGKP`
MX9Z;X9^!X9Z!XH"+X9Z?X9Z8X9^2X9Z"X9ZVX9Z;X9^+`.&>G^&>F.&?D.&>
MF0#AGH#AGX;AGH[AGH_AGXL`X9Z*X9^&X9ZAX9Z^X9Z$`.&>G^&>N.&>G^&?
MDN&>H.&?@N&>FP#AGI3AGH3AGY+AGJ#AGK;AGHD`X9Z4X9Z$X9^2X9Z:X9Z]
MX9Z)`.&>G^&?@>&>FN&?B>&>MN&>H>&?@>&>HN&>O.&>DP#AGJ#AGH_AGY+A
MGI#AGIOAGX'AGH'AGK8`X9Z?X9ZYX9Z$X9^2X9Z@X9Z4X9Z[X9Z:X9ZX`.&>
MD>&?AN&>H.&?A@#AGI_AGY+AGIOAGKSAGISAGXGAGK;AGH+AGK@`X9Z?X9^2
MX9Z;X9Z\X9Z<X9^)X9ZVX9Z3X9ZX`.&>@.&?A.&?A^*`B^&>G^&>O.&>H>&>
MO.&>F.&?B>&>O.&>DP#AGI_AGKSAGICAGXGAGK;AGIOAGK@`X9ZBX9ZVX9Z@
MX9^2X9Z:X9ZWX9Z`XH"+XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$
M`.&>H.&?DN&>G^&>@.&>H.&?DN&>G^&?BN&>N.*`B^&>@>&>MN&>A.*`B^&>
MC^&?DN&>E.&>O.&>A"#AGI/AGK?AGH0@X9Z`X9^$X9^'X9Z?X9ZVX9^&X9Z$
MX9Z<X9ZWX9Z%XH"+X9Z!X9ZVX9Z$XH"+X9Z/X9^2X9Z4X9Z\X9Z$`.&>@N&>
MF.&?DN&>F^&>MN&>CP#AGJ+AGX'AGI_AGXGAGY+AGI3AGK;AGHD`X9Z?X9ZV
MX9Z:XH"+X9ZEX9Z/XH"+X9Z4X9ZVX9Z3XH"+X9Z`X9ZVX9Z:`.&>G^&?DN&>
MFN&>N.&>F^&>A.&?DN&>@.&>M@#AGH'AGY+AGI/AGK;AGH_B@(OAGH+AGX;A
MGIKAGKP`X9Z?X9^2X9Z0X9ZVX9Z3X9Z7X9ZVX9Z6`.&>E.&>D^&?DN&>D>&>
MMN&>C^&?B^*`B^&>AN&>O.&>CP#AGI3AGY+AGIKAGI+AGK;AGI/B@(OAGI3A
MGI$`X9Z*X9ZVX9Z`X9^+XH"+X9Z?X9^2X9Z3X9Z^`.&>HN&>@.&?DN&>G^&>
MFN*`B^&>C^&>O.&>A>*`B^&>@.&?DN&>FN&?A.&>F`#AGH?AGX3AGH+AGH?A
MGY#AGID`X9Z?X9^*X9Z\X9Z*X9Z$X9^+`.&>G^&>A.&?DN&>@>&?@>&>E`#A
MGJ+AGH#AGY+AGI_AGIKB@(OAGH_AGKSAGH7B@(OAGIOAGKX`X9Z"X9ZVX9^&
MX9Z1X9^2X9Z:`.&>G^&?BN&>O.&>FN&>N.&>CN&>MN&>F.&>N`#AGI_AGY+A
MGISAGK;AGIOAGXOAGI3AGK;AGH\@X9Z3X9ZWX9Z$(.&>H.&?DN&>G^&>A.&?
MB^&>F.&?B>&>MN&>F>&?@>&>DP#AGI_AGY+AGISAGK;AGJ#AGY+AGI_AGXKA
MGKCAGJ'AGH3AGXL`X9Z?X9^*X9Z[X9Z9X9ZBX9^"X9Z*`.&>G^&?DN&>G.&?
MBN&>N.&>GP#AGI_AGK;AGI+AGK;AGIKAGH[AGIKAGHKAGY+AGHOB@(OAGJ+A
MGK;AGIKAGXGAGK;AGI3AGXL@X9Z?X9^*X9ZXX9Z:X9ZX`.&>C^&>MN&>FN&>
MMN&>A`#AGIOAGH#AGY+AGH'AGH[AGXCB@(OAGI_AGICAGY+AGI3AGH_AGY+A
MGH_AGK?B@(OAGH_AGK;AGIKAGK;AGH0`X9Z;X9Z`X9^2X9Z!X9Z.X9^(XH"+
MX9Z?X9Z8X9^2X9Z4X9Z/X9^2X9Z/X9ZWXH"+X9Z:X9Z4X9Z?X9^+XH"+XH"+
MX9Z/X9ZVX9Z:X9ZVX9Z$`.&>C^&?@^&>G.&?B>&>MN&>D^&?BP#AGH_AGK;A
MGHKAGJ#AGY+AGI_AGXKAGKCAGH+AGKCAGI_AGY+AGH_AGH3AGXL`X9Z7X9ZV
MX9Z:X9Z`X9ZWX9Z%X9^2X9Z%`.&>F^&?@>&>@>*`B^&>D>&>O.&>FN&>G^&?
MD.&>EN&?DN&>D0#AGI_AGKCAGH_AGKOAGH[AGY+AGJ#AGI?AGK;AGI8`X9ZB
MX9Z/X9^2X9Z0X9Z4X9Z1`.&>C^&?@N&>HN&>C^&?DN&>D.&>E.&>D0#AGI#A
MGX,`X9Z8X9ZVX9Z3XH"+X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z8X9Z]X9Z9(.&>
M@.&?DN&>D^&>N^&>A.*`B^&>@.&>MN&>FN*`B^&>E.&>A.&?DN&>H.&>MN&>
MB>*`B^&>E>&?DN&>D^&?@N&>@.*`B^&>FN&>E.&>G^&?B^*`B^&>G^&>MN&>
MFN*`B^&>D^&?@>&?AP#AGI;AGX'AGIOB@(OAGISAGX'AGIOAGK;B@(L`X9Z1
MX9^2X9Z:X9Z$X9^+XH"+X9Z1X9^2X9Z:X9ZVX9Z9XH"+XH"+XH"+XH"+X9Z6
MX9^!X9Z;XH"+XH"+X9Z<X9^!X9Z;X9ZVXH"+`.&>A>&?AN&>CN&>A.*`B^&>
MA^&>ON&>A`#AGI'AGX4`X9Z0X9^2X9Z$X9^#XH"+X9Z3X9^!X9^'`.&>C^&>
MO.&>H.&?DN&>@N&?A`#AGH_AGKSAGH#AGX'AGJ'AGK;AGJ+AGXKAGKP`X9Z/
MX9Z[X9Z$X9Z@X9^2X9Z"X9^$`.&>@.&?AN&>EN&>O.&>FP#AGI'AGY+AGIKA
MGKCAGI/AGKCAGHKAGK;AGHH@X9Z3X9ZWX9Z$XH"+XH"+(.&>C^&>O.&>E.&>
MMN&>H.&?DN&>@N&?A`#AGI'AGKOAGIGAGH[AGX'AGI_AGXKAGK@`X9Z1X9Z]
MX9Z:X9Z"X9ZX`.&>D>&>O>&>FN&>@N&>N"`H25-/+3@X-3DM.2D`X9Z1X9Z]
MX9Z"X9Z8X9^!X9Z3X9ZXX9Z?X9^2X9Z/X9Z$X9^+`.&>@.&?A.&?A^*`B^&>
MD>&>O>&>@"#AGI/AGK?AGH3B@(L@X9Z`X9^#X9Z`X9Z\X9Z?`.&>D>&>N^&>
MF>&>G.&?B>&>MN&>F^&>N^&>F0!54DP`55),.@#AGJ+AGXKAGKSAGJ#AGY+A
MGH+AGH3AGXOAGHKAGK8`X9ZBX9^*X9Z[X9Z9X9Z`X9^2X9Z:X9^"X9Z3`.&>
M@N&>O.&>G^*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>@.&?DN&>FN&?
MA.&>F`#AGICAGK?AGI/B@(OAGI3AGK;AGI/B@(OAGIKAGX#AGI3AGH7AGX8`
MX9Z9X9Z\X9Z3X9ZXX9Z`X9Z\X9Z*("A55$8M."D`X9ZBX9ZVX9Z:X9^)X9ZV
MX9Z4X9^+XH"+X9Z:X9Z]X9Z8`.&>A>&>@.&?DN&>FN*`B^&>E^&>EN*`B^&>
MHN&>A.&?B^&>@N&?DN&>F^&?@>&>GP#AGI_AGJ#AGIKAGHKAGY+AGHOAGJ+A
MGK;AGICAGX'AGIKAGK?AGH``X9Z`X9^$X9^'XH"+X9Z&X9^2X9Z$X9ZVX9Z9
MX9^7XH"+X9Z:X9Z4X9Z?X9^+XH"+X9Z?X9Z@X9Z:X9Z*X9^2X9Z+XH"+X9ZB
MX9ZVX9Z8X9^!X9Z:X9ZWX9Z``.&>K^&>@.&>C^&>M@#AGICAGK?AGI/B@(OA
MGI_AGY+AGH+AGK;AGIOAGXL`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z(X9^2X9Z8
MX9^$X9^'`.&>DN&?DN&>G.&>ON*`B^&>LN&?DN&>F>*`B^&>D>&>MN&>D^&?
MB^*`B^&>G^&>F.&?D.&>F0#AGI7AGY+AGI'AGKOAGH#B@(OAGJ'AGK[AGH0`
MX9ZBX9^*X9Z[X9Z9X9Z:X9^)X9ZVX9Z@X9^2X9Z"X9ZVX9Z9`.&>HN&?DN&>
MD^&>@.*`B^&>E.&?DN&>FN&>O@#AGH#AGK;AGIKB@(OAGH+AGY+AGIKAGI3A
MGXOAGH+AGY+AGIKAGH3B@(OAGJ+AGY+AGI/AGH#B@(OAGI3AGY+AGIKAGKX`
MX9Z(X9^2X9Z8X9^$X9^'XH"+X9ZBX9^2X9Z3X9Z`XH"+X9Z4X9^2X9Z:X9Z^
M`.&>B.&?DN&>F.&?A.&?A^*`B^&>HN&?DN&>D^&>@.*`B^&>E.&?DN&>FN&>
MOL*@X9^6`.&>HN&?BN&>O.&>H.&?DN&>G^&>E.&?@>&>@N&>N.&>G^&?DN&>
MC^&>A.&?BP#AGI_AGKOAGI;AGIOAGI?AGK;AGI8`X9Z/X9Z8X9^2X9Z;X9^#
M`.&>G.&?B>&>MN&>D^&>N^&>F>&>HN&>MN&>D>&>N^&>F0#AGJ+AGI#AGX'A
MGIH`X9Z<X9^!X9Z.X9^!X9Z@X9^2X9Z?X9Z[X9Z9X9ZBX9^!X9ZAX9ZV`.&>
M@.&?AN&>CN&?@@#AGH#AGK;AGIKB@(OAGH_AGY+AGIKAGKWAGH_B@(OAGI;A
MGK?AGI/AGK?AGH_AGY+AGIGB@(OAGH#AGX;AGH[AGX(`X9Z8X9Z^X9Z;("5S
M`.&>@.&?A.&?A^*`B^&>G.&>N.&>A^&>N.&>DR#AGI_AGJ#AGIKAGHKAGY+A
MGHOB@(OAGJ+AGK;AGICAGX'AGIKAGK?AGH``X9Z<X9^)X9ZVX9Z;X9ZXX9Z?
M(.&>D^&>M^&>A"#AGJ#AGY+AGISAGXKAGKSB@(OAGI'AGKOAGIGAGH[AGK8`
MX9Z6X9^2X9Z:X9Z8X9ZVX9Z3`.&>G.&>M^&>E`#AGH_AGX;AGI3AGI/AGXOA
MGI3AGH[AGY+AGH_AGK;AGHD`X9Z:X9ZVX9Z;X9^+XH"+X9Z?X9Z4X9^2X9Z*
MX9ZVX9Z@X9^-`.&>G^&>O.&>F.*`B^&>G^&?DN&>G.&>MN&>@N&>F.&>D^&?
MC0#AGI_AGKSAGICB@(OAGI_AGY+AGISAGK;AGH+AGICAGI/AGXWB@(OAGICA
MGH#B@(OAGH#AGK;AGI/AGXL@)7,`X9Z?X9ZVX9Z@X9ZVX9Z:X9^)X9ZVXH"+
MX9Z!X9ZVX9Z$XH"+X9Z;X9ZWX9Z%`.&>D>&>D>&>N>&>A.*`BP#AGI'AGI'A
MGKGAGH0@X9^6`.&>E.&>B>&?DN&>A^&>N.*`B^&>E.&?DN&>FN&>MN&>D.&?
MDN&>D^&>M@#AGJ+AGK;AGI_AGIGAGHKAGY+AGHOAGK;AGI/B@(OAGH#AGI/A
MGY+AGIOAGX+AGH3B@(OAGI+AGY+AGISAGK[B@(OAGH#AGK;AGIH`X9Z1X9Z\
MX9Z:X9Z?X9^0X9Z6X9^2X9Z1XH"+XH"+XH"+X9Z`X9Z3X9^2X9Z;X9^"X9Z$
MXH"+XH"+XH"+X9Z2X9^2X9Z<X9Z^X9Z`X9ZVX9Z:`%E9`%E965D`X9Z4X9^2
MX9Z:X9Z%X9ZVX9^&X9Z&X9^2X9Z3X9ZVX9^&`.&>F>&?@>&>F.&?@N&>DP#A
MGI3AGK;AGI$OX9Z%X9ZVX9Z?`.&>B.&?DN&>F.&?A.&?A^*`B^&>FN&>E.&>
MG^&?B^&>HN&?DN&>D^&>@`#AGIGAGKSAGJ#AGY+AGH+AGX3AGI_AGY+AGIOA
MGK;AGISAGK@`X9Z?X9^#`.&>H.&?DN&>G^&>MN&?AN&>E.&?BN&>N`#AGJ#A
MGY+AGI_AGXKAGKCAGICAGI3AGK;AGISAGXGAGX$`7TSAGH7AGX'AGHD@`.&>
MF.&>M^&>D^*`B^&>G^&?DN&>@N&>MN&>F^&?B^*`B^&>HN&?DN&>D^&>@.*`
MB^&>D>&>D>&>O>&>F^*`B^&>G^&?AN&>E.&>N^&>C^&?DN&>F@#AGICAGK?A
MGI/B@(OAGJ+AGK;AGH7B@(OAGI3AGH3AGY+AGH#AGK[AGH_B@(OAGJ_AGH#A
MGI_AGK;AGIKB@(OAGIOAGI'AGY+AGI+AGI7AGIL`X9Z8X9ZWX9Z3XH"+X9ZB
MX9ZVX9Z%XH"+X9Z4X9Z^X9Z`XH"+X9Z6X9^0X9Z/X9^,X9Z8X9ZVX9Z3XH"+
MX9Z4X9Z)X9^2X9Z%X9Z\X9Z;`.&>@.&?AN&>H.&>N^&>G^*`B^&>@.&>MN&>
MFN*`B^&>E.&?DN&>FN&>ON*`B^&>E.&>D^&?DN&>D>&>MN&>C^&?B^*`B^&>
MEN&>MN&>@.&?DN&>F>&>E.&>B>&?DN&>A^&>M@#AGH#AGX;AGJ#AGKOAGI_B
M@(OAGH#AGK;AGIKB@(OAGH#AGX;AGH[AGH_AGXOB@(OAGIKAGH7AGI/AGK;A
MGI_AGICAGY+AGI;AGY#AGI/AGY+AGI(`X9Z4X9ZVX9Z/X9^+XH"+X9ZOX9Z`
MX9Z?X9ZVX9Z:XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3X9^2X9Z2XH"+X9Z?X9^&
MX9Z!X9ZVX9Z3X9^+XH"+X9Z4X9^&X9Z5X9Z[X9Z/`.&>@.&?AN&>H.&>N^&>
MG^*`B^&>D>&?DN&>FN&>A.&?B^&>D>&?DN&>FN&>MN&>F>*`B^&>D>&>M^&>
MD^&?DN&>D^&>D^&?D.&>F0#AGIKAGH#B@(OAGICAGK?AGI/B@(OAGH/AGK[A
MGHGB@(OAGI+AGK;AGH_AGKOB@(OAGI3AGHGAGY+AGH7AGKSAGIL`:&@`X9Z8
MX9ZWX9Z3XH"+X9Z?X9^2X9Z"X9ZVX9Z;X9^+XH"+X9Z(X9^2X9Z8X9^$X9^'
MXH"+X9Z8X9^)X9ZVX9Z?X9^*X9ZXX9Z3`.&>@.&?AN&>H.&>N^&>G^*`B^&>
ME.&>B>&?DN&>A>&?@>&>B2_AGI3AGHGAGY+AGH7AGKSAGIL`X9Z`X9^&X9Z@
MX9Z[X9Z?XH"+X9Z`X9Z8X9^2X9Z8X9Z<X9ZWX9Z2X9ZXXH"+X9Z!X9ZVX9Z$
MXH"+X9Z`X9^2X9Z:X9^%`.&>F"[AGI@N`.&>B.&?DN&>F.&?A.&?AP#AGI_A
MGK?AGI'AGY+AGI+AGK?B@(OAGH_AGY+AGIKAGKSAGISB@(OAGI3AGK;AGI/B
M@(OAGI3AGHKAGK?AGI_AGX'AGI(`X9Z7X9ZXX9Z`X9Z?X9^"X9Z;`.&>@.&?
MAN&>H.&>N^&>G^*`B^&>EN&>N.*`B^&>A>&>F.&?DN&>A.&>MN&>F>*`B^&>
M@.&?DN&>D^&>N^&>A.*`B^&>EN&>M^&>DN&>N.&>@.&>MN&>F@#AGICAGK?A
MGI/B@(OAGJ+AGK;AGH7B@(OAGIKAGH#B@(OAGI_AGX'AGISAGK;B@(OAGI3A
MGK;AGI,`<W,`X9Z`X9^&X9Z@X9Z[X9Z?XH"+X9Z4X9^2X9Z:X9Z6X9^0X9Z3
MX9^2X9Z2`.&>E.&>FN&>MN&>A^&?D.&>F>*`B^&>E.&>CN&?DN&>BN&?A.&?
MA^&>HN&>MN&>G^&>D^&?DN&>DP#AGICAGK?AGI/B@(OAGI_AGY+AGH+AGK;A
MGIOAGXOB@(OAGH#AGX;AGJ#AGKOAGI\`X9Z"X9^2X9Z8X9ZVX9Z3XH"+X9Z(
MX9^2X9Z8X9^$X9^'`'9#87)D`````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34P`````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$S-B`P,3<S-S$`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4`
M````````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,V(#`Q-S$P,P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O5&5X=```````````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S8@,#$W
M,34P`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834P`````````````````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$S-B`P,38V-C0`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+U9&4P``````````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,V(#`Q-C8V,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O0FQO8VL`````````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M,S<@,#$W,C4W`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D90``````
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$T,2`P,3<R-C$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TYE=```````````````````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q-C<T-@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O8F%S92YP:'``````````````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,T-C0@,3`U
M,34T,S0Q-#$@,#$W-S,Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!(;W)D92!B87-E(&EN8VQU<VEO
M;B!F:6QE+@H@*@H@*B!4:&ES(&9I;&4@8G)I;F=S(&EN(&%L;"!O9B!T:&4@
M9&5P96YD96YC:65S('1H870@2&]R9&4*("H@9G)A;65W;W)K+6QE=F5L('-C
M<FEP=',@=VEL;"!N965D+"!A;F0@<V5T<R!U<"!O8FIE8W1S('1H870@86QL
M"B`J('-C<FEP=',@=7-E+@H@*@H@*B!.;W1E.B!4:&ES(&)A<V4@9FEL92!D
M;V5S(%]N;W1?(&-H96-K(&%U=&AE;G1I8V%T:6]N+"!S;R!A<R!T;PH@*B!A
M=F]I9"!A;B!I;F9I;FET92!L;V]P(&]N('1H92!(;W)D92!L;V=I;B!P86=E
M+B!9;W4G;&P@;F5E9"!T;R!D;PH@*B!I="!Y;W5R<V5L9B!I;B!F<F%M97=O
M<FLM;&5V96P@<&%G97,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+V)A<V4N
M<&AP+'8@,2XT,"XQ,"XS(#(P,#8O,#$O,#$@,C$Z,CDZ,#4@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\O($-H96-K(&9O
M<B!A('!R:6]R(&1E9FEN:71I;VX@;V8@2$]21$5?0D%312`H<&5R:&%P<R!B
M>2!A;@HO+R!A=71O7W!R97!E;F1?9FEL92!D969I;FET:6]N(&9O<B!S:71E
M(&-U<W1O;6EZ871I;VXI+@II9B`H(61E9FEN960H)TA/4D1%7T)!4T4G*2D@
M>PH@("`@0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R\N+B<I.PI]"@HO+R!,;V%D('1H92!(;W)D92!&<F%M97=O<FL@8V]R
M92P@86YD('-E="!U<"!I;F-L=7-I;VX@<&%T:',N"G)E<75I<F5?;VYC92!(
M3U)$15]"05-%("X@)R]L:6(O8V]R92YP:'`G.PH*+R\@4F5G:7-T<GDN"B1S
M97-S:6]N7V-O;G1R;VP@/2!5=&EL.CIN;VY);G!U=%9A<B@G<V5S<VEO;E]C
M;VYT<F]L)RD["FEF("@D<V5S<VEO;E]C;VYT<F]L(#T]("=N;VYE)RD@>PH@
M("`@)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T;VXH2$]21$5?4T53
M4TE/3E].3TY%*3L*?2!E;'-E:68@*"1S97-S:6]N7V-O;G1R;VP@/3T@)W)E
M861O;FQY)RD@>PH@("`@)')E9VES=')Y(#T@)E)E9VES=')Y.CIS:6YG;&5T
M;VXH2$]21$5?4T534TE/3E]214%$3TY,62D["GT@96QS92!["B`@("`D<F5G
M:7-T<GD@/2`F4F5G:7-T<GDZ.G-I;F=L971O;B@I.PI]"FEF("AI<U]A*"@D
M<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"=H;W)D92<L("%D969I;F5D
M*"=!551(7TA!3D1,15(G*2DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("!I9B`H
M)'!U<VAE9"T^9V5T0V]D92@I(#T]("=P97)M:7-S:6]N7V1E;FEE9"<I('L*
M("`@("`@("!(;W)D93HZ875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H
M*3L*("`@('T*("`@($AO<F1E.CIF871A;"@D<'5S:&5D+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(&9A;'-E*3L*?0HD8V]N9B`]("8D1TQ/0D%,4ULG8V]N9B==
M.PI`9&5F:6YE*"=(3U)$15]414U03$%415,G+"`D<F5G:7-T<GDM/F=E="@G
M=&5M<&QA=&5S)RDI.PH*+R\@3F]T:69I8V%T:6]N(%-Y<W1E;2X*)&YO=&EF
M:6-A=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I;F=L971O;B@I.PHD;F]T:69I
M8V%T:6]N+3YA='1A8V@H)W-T871U<R<I.PH*+RH@4V5T('5P('1H92!M96YU
M+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*)&UE;G4@/2`F
M;F5W($UE;G4H*3L*"B\O($-O;7!R97-S(&]U='!U=`I(;W)D93HZ8V]M<')E
M<W-/=71P=70H*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U1E<W0N<&AP````````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4T-S,R(#$P-3$U-#,T
M,30Q(#`Q-S<T,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RHJ"B`J($1E9FEN92!(3U)$15]"05-%+"!I9B!I
M="!I<R!N;W0@86QR96%D>2!S970L(&%N9"!I;F-L=61E('1H92!M86EN"B`J
M($AO<F1E(&QI8G)A<GDL('-I;F-E('=E(')E<75I<F4@:70@9F]R('1H:7,@
M<&%C:V%G92!T;R!F=6YC=&EO;BX*("HO"FEF("@A9&5F:6YE9"@G2$]21$5?
M0D%312<I*2!["B`@("!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXG*3L*?0IR97%U:7)E7V]N8V4@2$]21$5?0D%312`N
M("<O;&EB+V-O<F4N<&AP)SL*"B\J*@H@*B!3970@=&AE('!A=&@@=&\@=&AE
M('1E;7!L871E<R!N965D960@9F]R('1E<W1I;F<@;W5T<'5T+@H@*B\*9&5F
M:6YE*"=415-47U1%35!,051%4R<L($A/4D1%7T)!4T4@+B`G+W1E;7!L871E
M<R]T97-T+R<I.PH*+RH@268@9V5T=&5X="!I<R!N;W0@;&]A9&5D+"!D969I
M;F4@82!D=6UM>2!?*"D@9G5N8W1I;VX@<V\@=&AA=`H@*B!I;F-L=61I;F<@
M86YY(&9I;&4@=VET:"!G971T97AT('-T<FEN9W,@=V]N)W0@8V%U<V4@82!F
M871A;"!E<G)O<BP*("H@8V%U<VEN9R!T97-T+G!H<"!T;R!R971U<FX@82!B
M;&%N:R!P86=E+B`J+PII9B`H(69U;F-T:6]N7V5X:7-T<R@G7R<I*2!["B`@
M("!F=6YC=&EO;B!?*"1S*2![(')E='5R;B`D<SL@?0I]"@HO*BH*("H@5&AE
M($AO<F1E7U1E<W0Z.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;G,@=7-E9"!I
M;B!T:&4@=&5S="!S8W)I<'1S"B`J('5S960@:6X@=&AE('9A<FEO=7,@87!P
M;&EC871I;VYS("AT97-T+G!H<"DN"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB
M+U1E<W0N<&AP+'8@,2XS,2XT+C$Y(#(P,#8O,#,O,C@@,3(Z,S$Z,3,@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAA<FQE<R!*+B!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E+F]R9SX*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A
M<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A=71H
M;W(@($)R96YT($HN($YO<F1Q=6ES="`\8FIN0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?5&5S=`H@*B\*8VQA<W,@2&]R9&5?5&5S="!["@H@("`@+RHJ"B`@("`@
M*B!!<G)A>2!T:&%T(&AO;&1S('1H92!L:7-T(&]F($AO<F1E(&%P<&QI8V%T
M:6]N<RX*("`@("`J("A,;V%D960@9G)O;2!C;VYF:6<O<F5G:7-T<GDN<&AP
M*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1A
M<'!L:6-A=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&5D
M(')E<W5L=',@;V8@9V5T07!P;&EC871I;VYS*"DN"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!O=71P=70@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%!(4"!V97)S:6]N(&]F('1H92!S
M>7-T96TN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]P:'!V97(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&5S="@I"B`@("!["B`@("`@("`@
M:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP
M:'`G.PH@("`@("`@(&MS;W)T*"1T:&ES+3YA<'!L:6-A=&EO;G,I.PH*("`@
M("`@("`O*B!3=&]R92!T:&4@4$A0('9E<G-I;VX@:6YF;W)M871I;VXN("HO
M"B`@("`@("`@)'1H:7,M/E]P:'!V97(@/2`D=&AI<RT^<W!L:7102%!697)S
M:6]N*'!H<'9E<G-I;VXH*2D["@H@("`@("`@("\J(%=E('=A;G0@=&\@8F4@
M87,@=F5R8F]S92!A<R!P;W-S:6)L92!H97)E+B`J+PH@("`@("`@(&5R<F]R
M7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@("`@("\J(%-E="!C:&%R86-T97(@
M96YC;V1I;F<N("HO"B`@("`@("`@:&5A9&5R*"=#;VYT96YT+71Y<&4Z('1E
M>'0O:'1M;#L@8VAA<G-E=#UU=&8M."<I.PH@("`@("`@(&AE861E<B@G5F%R
M>3H@06-C97!T+4QA;F=U86=E)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S92!02%`@=F5R<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1V97)S:6]N("!!(%!(4"US='EL92!V97)S:6]N('-T<FEN9R`H6"Y8+E@I
M+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@5&AE('!A<G-E9"!S=')I
M;F<N"B`@("`@*B`@("`@("`@("`@("`@($ME>7,Z("=M86IO<B<L("=M:6YO
M<B<L("=S=6)M:6YO<B<L("=C;&%S<R<*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W!L:7102%!697)S:6]N*"1V97)S:6]N*0H@("`@>PH@("`@("`@("\J($9I
M<G-T('!I8VL@;V9F(&UA:F]R('9E<G-I;VXL(&%N9"!L;W=E<BUC87-E('1H
M92!R97-T+B`J+PH@("`@("`@(&EF("@H<W1R;&5N*"1V97)S:6]N*2`^/2`S
M*2`F)B`H)'9E<G-I;VY;,5T@/3T@)RXG*2D@>PH@("`@("`@("`@("`D<&AP
M=F5R6R=M86IO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`P+"`S*3L*("`@("`@
M("`@("`@)'9E<G-I;VX@/2!S=6)S='(H<W1R=&]L;W=E<B@D=F5R<VEO;BDL
M(#,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P:'!V97);)VUA
M:F]R)UT@/2`D=F5R<VEO;CL*("`@("`@("`@("`@)'!H<'9E<ELG8VQA<W,G
M72`]("=U;FMN;W=N)SL*("`@("`@("`@("`@<F5T=7)N("1P:'!V97(["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'9E<G-I;VY;,%T@/3T@)RXG*2!["B`@
M("`@("`@("`@("1V97)S:6]N(#T@<W5B<W1R*"1V97)S:6]N+"`Q*3L*("`@
M("`@("!]"@H@("`@("`@("\J($YE>'0L(&1E=&5R;6EN92!I9B!T:&ES(&ES
M(#0N,&(@;W(@-"XP<F,[(&EF('-O+"!T:&5R92!I<R!N;PH@("`@("`@("`@
M(&UI;F]R+"!T:&4@<F5S="!I<R!T:&4@<W5B;6EN;W(L(&%N9"!C;&%S<R!I
M<R!S970@=&\@8F5T82X@*B\*("`@("`@("`D<R`]('-T<G-P;B@D=F5R<VEO
M;BP@)S`Q,C,T-38W.#DG*3L*("`@("`@("!I9B`H)',@/3T@,"D@>PH@("`@
M("`@("`@("`D<&AP=F5R6R=S=6)M:6YO<B==(#T@)'9E<G-I;VX["B`@("`@
M("`@("`@("1P:'!V97);)V-L87-S)UT@/2`G8F5T82<["B`@("`@("`@("`@
M(')E='5R;B`D<&AP=F5R.PH@("`@("`@('T*"B`@("`@("`@+RH@3W1H97)W
M:7-E+"!T:&ES(&ES(&YO;BUB971A.R`@=&AE(&YU;65R:6,@<&%R="!I<R!T
M:&4@;6EN;W(L"B`@("`@("`@("`@=&AE(')E<W0@:7,@96ET:&5R(&$@8VQA
M<W-I9FEC871I;VX@*&1E=BP@8W9S*2!O<B!A('-U8FUI;F]R"B`@("`@("`@
M("`@=F5R<VEO;B`H<F,\>#XL('!L/'@^*2X@*B\*("`@("`@("`D<&AP=F5R
M6R=M:6YO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`P+"`D<RD["B`@("`@("`@
M:68@*"AS=')L96XH)'9E<G-I;VXI(#X@)',I("8F"B`@("`@("`@("`@("@H
M)'9E<G-I;VY;)'-=(#T]("<N)RD@?'P@*"1V97)S:6]N6R1S72`]/2`G+2<I
M*2D@>PH@("`@("`@("`@("`D<RLK.PH@("`@("`@('T*("`@("`@("`D<&AP
M=F5R6R=S=6)M:6YO<B==(#T@<W5B<W1R*"1V97)S:6]N+"`D<RD["B`@("`@
M("`@:68@*"@D<&AP=F5R6R=S=6)M:6YO<B==(#T]("=C=G,G*2!\?`H@("`@
M("`@("`@("`H)'!H<'9E<ELG<W5B;6EN;W(G72`]/2`G9&5V)RD@?'P*("`@
M("`@("`@("`@*'-U8G-T<B@D<&AP=F5R6R=S=6)M:6YO<B==+"`P+"`R*2`]
M/2`G<F,G*2D@>PH@("`@("`@("`@("!U;G-E="@D<&AP=F5R6R=S=6)M:6YO
M<B==*3L*("`@("`@("`@("`@)'!H<'9E<ELG8VQA<W,G72`]("=D978G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'!H<'9E<ELG<W5B
M;6EN;W(G72D@>PH@("`@("`@("`@("`@("`@=6YS970H)'!H<'9E<ELG<W5B
M;6EN;W(G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!H<'9E<ELG
M8VQA<W,G72`]("=R96QE87-E)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<&AP=F5R.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@=&AE(&QI
M<W0@;V8@4$A0(&UO9'5L97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1M;V1L:7-T("!4:&4@;6]D=6QE(&QI<W0N"B`@("`@*B`\<')E/@H@("`@
M("H@2T59.B`@(&UO9'5L92!N86UE"B`@("`@*B!604Q513H@16ET:&5R('1H
M92!D97-C<FEP=&EO;B!O<B!A;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@
M96YT<FEE<SH*("`@("`J("`@("`@("`G9&5S8W)I<"<@("TM("!-;V1U;&4@
M1&5S8W)I<'1I;VX*("`@("`J("`@("`@("`G97)R;W(G("`@("TM("!%<G)O
M<B!-97-S86=E"B`@("`@*B`@("`@("`@)W!H<'9E<B<@("`M+2`@5&AE(%!(
M4"!V97)S:6]N(&%B;W9E('=H:6-H('1O(&1O('1H92!T97-T"B`@("`@*B`\
M+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P:'!-;V1U;&5#:&5C:R@D
M;6]D;&ES="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@
M)&]U='!U=%]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1M
M;V1L:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D97)R;W)?
M;7-G(#T@)&UO9%]T97-T(#T@)'-T871U<U]O=70@/2`D9F%T86P@/2!N=6QL
M.PH@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@("`@("`@("`@("`@("`D9&5S8W)I
M<"`]("1V86Q;)V1E<V-R:7`G73L*("`@("`@("`@("`@("`@("1F871A;"`]
M("%E;7!T>2@D=F%L6R=F871A;"==*3L*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=F%L6R=P:'!V97(G72D@)B8*("`@("`@("`@("`@("`@("`@("`H
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)'9A;%LG<&AP=F5R)UTI
M(#T]("TQ*2D@>PH@("`@("`@("`@("`@("`@("`@("1M;V1?=&5S="`]('1R
M=64["B`@("`@("`@("`@("`@("`@("`@)'-T871U<U]O=70@/2`G3B]!)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=F%L6R=E<G)O<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("1E<G)O<E]M
M<V<@/2`D=F%L6R=E<G)O<B==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1E<V-R:7`@/2`D=F%L
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-?;G5L;"@D<W1A
M='5S7V]U="DI('L*("`@("`@("`@("`@("`@("1M;V1?=&5S="`](&5X=&5N
M<VEO;E]L;V%D960H)&ME>2D["B`@("`@("`@("`@("`@("`D<W1A='5S7V]U
M="`]("1T:&ES+3Y?<W1A='5S*"1M;V1?=&5S="P@)&9A=&%L*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&5N=')Y6UT@/2`D9&5S8W)I<#L*("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D<W1A='5S7V]U=#L*"B`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D97)R;W)?;7-G*2`F)B`A)&UO9%]T97-T*2!["B`@
M("`@("`@("`@("`@("`D96YT<GE;72`]("1E<G)O<E]M<V<["B`@("`@("`@
M("`@("`@("!I9B`H(21F871A;"D@>PH@("`@("`@("`@("`@("`@("`@("1E
M;G1R>5M=(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N
M=')Y*3L*"B`@("`@("`@("`@(&EF("@D9F%T86P@)B8@(21M;V1?=&5S="D@
M>PH@("`@("`@("`@("`@("`@96-H;R`D;W5T<'5T.PH@("`@("`@("`@("`@
M("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@=&AE
M(&QI<W0@;V8@4$A0('-E='1I;F=S+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D;6]D;&ES="`@5&AE('-E='1I;F=S(&QI<W0N"B`@("`@*B`\8V]D
M93X*("`@("`J($M%63H@("!S971T:6YG(&YA;64*("`@("`J(%9!3%5%.B!!
M;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J("`@
M("`@("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@("`@
M("`@)W-E='1I;F<G("`M+2`@0F]O;&5A;B`M('-H;W5L9"!T:&4@<V5T=&EN
M9R!B92!O;B!O<B!O9F8*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE($A434P@;W5T<'5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P:'!3971T:6YG0VAE8VLH)'-E='1I;F=S7VQI<W0I"B`@("![
M"B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("!F;W)E86-H("@D<V5T
M=&EN9W-?;&ES="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&5N
M=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@)')E<W5L="`]("AI;FE?9V5T
M*"1K97DI(#T]("1V86Q;)W-E='1I;F<G72D["@H@("`@("`@("`@("`D96YT
M<GE;72`]("1K97D@+B`G("<@+B`H*"1V86Q;)W-E='1I;F<G72`]/3T@=')U
M92D@/R`G96YA8FQE9"<@.B`G9&ES86)L960G*3L*("`@("`@("`@("`@)&5N
M=')Y6UT@/2`D=&AI<RT^7W-T871U<R@D<F5S=6QT*3L*"B`@("`@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M=F%L6R=E<G)O<B==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W5T
M<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:R!T:&4@;&ES="!O9B!014%2(&UO9'5L97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P96%R7VQI<W0@(%1H92!014%2(&UO9'5L92!L
M:7-T+@H@("`@("H@/'!R93X*("`@("`J($M%63H@("!014%2(&-L87-S(&YA
M;64*("`@("`J(%9!3%5%.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@
M96YT<FEE<SH*("`@("`J("`@("`@("`G9&5P96YD<R<@("`M+2`@5&AI<R!M
M;V1U;&4@9&5P96YD<R!O;B!A;F]T:&5R(&UO9'5L90H@("`@("H@("`@("`@
M("=E<G)O<B<@("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@("`@("`@
M)V9U;F-T:6]N)R`@+2T@(%)E9F5R96YC92!T;R!F=6YC=&EO;B!T;R!R=6X@
M:68@;6]D=6QE(&ES(&9O=6YD"B`@("`@*B`@("`@("`@)W!A=&@G("`@("`@
M+2T@(%1H92!P871H('1O('1H92!014%2(&UO9'5L90H@("`@("H@("`@("`@
M("=R97%U:7)E9"<@("TM("!)<R!T:&ES(%!%05(@;6]D=6QE(')E<75I<F5D
M/R`H8F]O;&5A;BD*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%!%05)-;V1U;&5#:&5C:R@D<&5A<E]L:7-T*0H@("`@>PH@("`@("`@
M("1O=71P=70@/2`G)SL*"B`@("`@("`@+RH@5'5R;B!T<F%C:VEN9R!O9B!E
M<G)O<G,@;VXN("HO"B`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@
M,2D["@H@("`@("`@("\J(%!R:6YT('1H92!I;F-L=61E7W!A=&@N("HO"B`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H87)R87DH(CQS
M=')O;F<^4$5!4B!396%R8V@@4&%T:"`H4$A0)W,@:6YC;'5D95]P871H*3PO
M<W1R;VYG/B(L("<F;F)S<#L\='0^)R`N(&EN:5]G970H)VEN8VQU9&5?<&%T
M:"<I("X@)SPO='0^)RDI.PH*("`@("`@("`O*B!#:&5C:R!F;W(@4$5!4B!I
M;B!G96YE<F%L+B`J+PH@("`@("`@('L*("`@("`@("`@("`@)&5N=')Y(#T@
M87)R87DH*3L*("`@("`@("`@("`@)&5N=')Y6UT@/2`G4$5!4B<["B`@("`@
M("`@("`@($!I;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@
M)&5N=')Y6UT@/2`D=&AI<RT^7W-T871U<R@A:7-S970H)'!H<%]E<G)O<FUS
M9RDI.PH@("`@("`@("`@("!I9B`H:7-S970H)'!H<%]E<G)O<FUS9RDI('L*
M("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)T-H96-K('EO=7(@4$A0(&EN
M8VQU9&5?<&%T:"!S971T:6YG('1O(&UA:V4@<W5R92!I="!H87,@=&AE(%!%
M05(@;&EB<F%R>2!D:7)E8W1O<GDN)SL*("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@)'1H:7,M/E]O=71P=71,:6YE*"1E;G1R>2D["B`@("`@("`@("`@
M("`@("!I;FE?<F5S=&]R92@G=')A8VM?97)R;W)S)RD["B`@("`@("`@("`@
M("`@("!R971U<FX@)&]U='!U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;W5T<'5T("X]("1T:&ES+3Y?;W5T<'5T3&EN92@D96YT<GDI.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(&$@<F5C96YT(%!%05(@=F5R
M<VEO;BX@*B\*("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@("1N
M97=P96%R(#T@)'1H:7,M/FES4F5C96YT4$5!4B@I.PH@("`@("`@("1E;G1R
M>5M=(#T@)U)E8V5N="!014%2)SL*("`@("`@("`D96YT<GE;72`]("1T:&ES
M+3Y?<W1A='5S*"1N97=P96%R*3L*("`@("`@("!I9B`H(21N97=P96%R*2![
M"B`@("`@("`@("`@("1E;G1R>5M=(#T@)U1H:7,@=F5R<VEO;B!O9B!014%2
M(&ES(&YO="!R96-E;G0@96YO=6=H+B!3964@=&AE(#QA(&AR968](FAT='`Z
M+R]W=W<N:&]R9&4N;W)G+W!E87(O(CY(;W)D92!014%2('!A9V4\+V$^(&9O
M<B!D971A:6QS+B<["B`@("`@("`@?0H@("`@("`@("1O=71P=70@+CT@)'1H
M:7,M/E]O=71P=71,:6YE*"1E;G1R>2D["@H@("`@("`@("\J($=O('1H<F]U
M9V@@;6]D=6QE(&QI<W0N("HO"B`@("`@("`@)'-U8V-E961E9"`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)'!E87)?;&ES="!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*"B`@("`@("`@
M("`@("\J($EF('1H:7,@;6]D=6QE(&1E<&5N9',@;VX@86YO=&AE<B!M;V1U
M;&4@=&AA="!W90H@("`@("`@("`@("`@*B!H879E;B=T('-U8V-E<V9U;&QY
M(&9O=6YD+"!F86EL('1H92!T97-T+B`J+PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1V86Q;)V1E<&5N9',G72D@)B8@96UP='DH)'-U8V-E961E9%LD=F%L
M6R=D97!E;F1S)UU=*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&9A
M;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]($!I;F-L=61E7V]N8V4@)'9A;%LG<&%T:"==.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1E<G)O<E]M<V<@/2`D=F%L6R=E<G)O<B==.PH@
M("`@("`@("`@("!I9B`H)')E<W5L="`F)B!I<W-E="@D=F%L6R=F=6YC=&EO
M;B==*2D@>PH@("`@("`@("`@("`@("`@)&9U;F-?;W5T<'5T(#T@8V%L;%]U
M<V5R7V9U;F,H)'9A;%LG9G5N8W1I;VXG72D["B`@("`@("`@("`@("`@("!I
M9B`H)&9U;F-?;W5T<'5T*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L
M="`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("1E<G)O<E]M<V<@/2`D
M9G5N8U]O=71P=70["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&5N=')Y6UT@/2`D:V5Y.PH@("`@("`@("`@("`D96YT
M<GE;72`]("1T:&ES+3Y?<W1A='5S*"1R97-U;'0L("%E;7!T>2@D=F%L6R=R
M97%U:7)E9"==*2D["@H@("`@("`@("`@("!I9B`H)')E<W5L="D@>PH@("`@
M("`@("`@("`@("`@)'-U8V-E961E9%LD:V5Y72`]('1R=64["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86Q;
M)W)E<75I<F5D)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R7VUS
M9R`N/2`G(%1(25,@25,@02!215%525)%1"!-3T153$4A)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)&5R<F]R7VUS
M9SL*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L6R=R97%U:7)E9"==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@,3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E<W1O<F4@<')E=FEO=7,@=F%L=64@;V8@)W1R86-K7V5R
M<F]R<R<N("HO"B`@("`@("`@:6YI7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I
M.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K('1H92!L:7-T(&]F(')E<75I<F5D(&9I;&5S"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1F:6QE7VQI<W0@(%1H92!F:6QE(&QI<W0N
M"B`@("`@*B`\<')E/@H@("`@("H@2T59.B`@(&9I;&4@<&%T:`H@("`@("H@
M5D%,544Z(%1H92!E<G)O<B!M97-S86=E('1O('5S92`H;G5L;"!T;R!U<V4@
M9&5F875L="!M97-S86=E*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5Q=6ER961&:6QE0VAE8VLH)&9I;&5?;&ES="D*("`@('L*
M("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*"1F:6QE
M7VQI<W0@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1E;G1R>2`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'0@/2!F:6QE7V5X:7-T<R@G
M+B\G("X@)&ME>2D["@H@("`@("`@("`@("`D96YT<GE;72`]("1K97D["B`@
M("`@("`@("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T=7,H)')E<W5L="D[
M"@H@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R
M>5M=(#T@)U1H92!F:6QE(#QC;V1E/B<@+B`D:V5Y("X@)SPO8V]D93X@87!P
M96%R<R!T;R!B92!M:7-S:6YG+B!9;W4@<')O8F%B;'D@:G5S="!F;W)G;W0@
M=&\@8V]P>2`\8V]D93XG("X@)&ME>2`N("<N9&ES=#PO8V]D93X@;W9E<BX@
M5VAI;&4@>6]U(&1O('1H870L('1A:V4@82!L;V]K(&%T('1H92!S971T:6YG
M<R!A;F0@;6%K92!S=7)E('1H97D@87)E(&%P<')O<')I871E(&9O<B!Y;W5R
M('-I=&4N)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&5N=')Y6UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3Y?
M;W5T<'5T3&EN92@D96YT<GDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-P;&%Y<R!A;B!E
M<G)O<B!S8W)E96X@=VET:"!A(&QI<W0@;V8@86QL(&-O;F9I9W5R871I;VX@
M9FEL97,@=&AA=`H@("`@("H@87)E(&UI<W-I;F<L('1O9V5T:&5R('=I=&@@
M82!D97-C<FEP=&EO;B!W:&%T('1H97D@9&\@86YD(&AO=R!T:&5Y(&%R90H@
M("`@("H@8W)E871E9"X@268@82!F:6QE(&-A;B!B92!A=71O;6%T:6-A;&QY
M(&-R96%T960@9G)O;2!T:&4@9&5F875L=',L('1H96X*("`@("`J('=E(&1O
M('1H870@:6YS=&5A9"!A;F0@9&]N)W0@9&ES<&QA>2!A;B!E<G)O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@(%1H92!A<'!L
M:6-A=&EO;B!N86UE"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'!"87-E("`@
M(%1H92!P871H('1O('1H92!A<'!L:6-A=&EO;@H@("`@("H@0'!A<F%M(&%R
M<F%Y("`D9FEL97,@("`@("!!;B!A<G)A>2!W:71H('1H92`B<W1A;F1A<F0B
M(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9FEL97,@=&AA="!S:&]U;&0@8F4@8VAE8VME9"X@0W5R<F5N=&QY"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('-U<'!O<G1E9#H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@+2!C;VYF+G!H<`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`M('!R969S+G!H<`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&UI;65?9')I=F5R<RYP
M:'`*("`@("`J($!P87)A;2!A<G)A>2`D861D:71I;VYA;"`@06X@87-S;V-I
M871I=F4@87)R87D@8V]N=&%I;FEN9R!M;W)E(&9I;&5S("AA<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!K97ES*2!A;F0@97)R;W(@;65S
M<V%G92`H87,@=F%L=65S*2!I9B!T:&5Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1O;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VYF:6=&:6QE<TUI<W-I;F<H)&%P<"P@)&%P<$)A<V4L("1F:6QE<RP@
M)&%D9&ET:6]N86P@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%1R>2!T
M;R!L;V%D(&$@8F%S:6,@9G)A;65W;W)K(&EF('=E)W)E('1E<W1I;F<@86X@
M87!P(&]T:&5R('1H86X*("`@("`@("`@*B!T:&4@2&]R9&4@8F%S92!F:6QE
M<RX@*B\*("`@("`@("!I9B`H)&%P<"`A/2`G2&]R9&4G*2!["B`@("`@("`@
M("`@("1'3$]"04Q36R=R96=I<W1R>2==(#T@)E)E9VES=')Y.CIS:6YG;&5T
M;VXH*3L*("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/G!U<VA!
M<'`H)VAO<F1E)RP@9F%L<V4I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D9FEL97,I*2!["B`@("`@("`@("`@("1F:6QE<R`](&%R<F%Y
M*"1F:6QE<RD["B`@("`@("`@?0H@("`@("`@("1F:6QE<R`](&%R<F%Y7VUE
M<F=E*"1F:6QE<RP@87)R87E?:V5Y<R@D861D:71I;VYA;"DI.PH*("`@("`@
M("`O*B!4<GD@=&\@875T;RUC<F5A=&4@;6ES<VEN9R`N9&ES="!F:6QE<RX@
M*B\*("`@("`@("`D:6YD:6-E<R`](&%R<F%Y7VME>7,H)&9I;&5S*3L*("`@
M("`@("!F;W)E86-H("@D:6YD:6-E<R!A<R`D:6YD97@I('L*("`@("`@("`@
M("`@:68@*&ES7W)E861A8FQE*"1A<'!"87-E("X@)R]C;VYF:6<O)R`N("1F
M:6QE<ULD:6YD97A=*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&5S
M6R1I;F1E>%TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@:68@*$!F:6QE7V5X:7-T<R@D87!P0F%S92`N("<O8V]N9FEG+R<@+B`D
M9FEL97-;)&EN9&5X72`N("<N9&ES="<I("8F"B`@("`@("`@("`@("`@("`@
M("`@0&-O<'DH)&%P<$)A<V4@+B`G+V-O;F9I9R\G("X@)&9I;&5S6R1I;F1E
M>%T@+B`G+F1I<W0G+"`D87!P0F%S92`N("<O8V]N9FEG+R<@+B`D9FEL97-;
M)&EN9&5X72DI('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEL97-;
M)&EN9&5X72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\J(%)E='5R;B!I9B!W92!H879E(&YO(&UI<W-I
M;F<@9FEL97,@;&5F="X@*B\*("`@("`@("!I9B`H(6-O=6YT*"1F:6QE<RDI
M('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&1E
M<V-R:7!T:6]N<R`](&%R<F%Y7VUE<F=E*&%R<F%Y*`H@("`@("`@("`@("`G
M8V]N9BYP:'`G(#T^('-P<FEN=&8H)U1H:7,@:7,@=&AE(&UA:6X@)7,@8V]N
M9FEG=7)A=&EO;B!F:6QE+B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=)="!C;VYT86EN<R!P871H<R!A;F0@;W!T:6]N<R!F;W(@
M=&AE("5S("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-C<FEP=',N(%EO=2!N965D('1O(&QO9VEN(&%S(&%N("<@+@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%D;6EN:7-T<F%T;W(@86YD
M(&-R96%T92!T:&4@9FEL92!W:71H("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1H92!W96(@9G)O;G1E;F0@=6YD97(@(D%D;6EN
M:7-T<F%T:6]N(#T^("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U-E='5P(BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&%P<"P@)&%P<"P@)&%P<$)A<V4@+B`G+V-O;F9I9R<I+`H@("`@
M("`@("`@("`G<')E9G,N<&AP)R`]/B!S<')I;G1F*"=4:&ES(&9I;&4@8V]N
M=')O;',@=&AE(&1E9F%U;'0@<')E9F5R96YC97,@)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V9O<B`E<RP@86YD(&%L<V\@8V]N
M=')O;',@=VAI8V@@<')E9F5R96YC97,@)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97)S(&-A;B!A;'1E<BXG+"`D87!P*2P*
M("`@("`@("`@("`@)VUI;65?9')I=F5R<RYP:'`G(#T^('-P<FEN=&8H)U1H
M:7,@9FEL92!C;VYT<F]L<R!L;V-A;"!-24U%("<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9')I=F5R<R!F;W(@)7,L
M('-P96-I9FEC86QL>2!W:&%T("<@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G:VEN9',@;V8@9FEL97,@87)E('9I97=A
M8FQE(&%N9"]O<B`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1O=VYL;V%D86)L92XG+"`D87!P*2P*("`@("`@("`@
M("`@)V)A8VME;F1S+G!H<"<@/3X@<W!R:6YT9B@G5&AI<R!F:6QE(&-O;G1R
M;VQS('=H870@8F%C:V5N9',@87)E("<@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A=F%I;&%B;&4@9G)O;2`E<RXG+"`D87!P
M*2P*("`@("`@("`@("`@)W-O=7)C97,N<&AP)R`]/B!S<')I;G1F*"=4:&ES
M(&9I;&4@9&5F:6YE<R!T:&4@;&ES="!O9B!A=F%I;&%B;&4@)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V]U<F-E<R!F;W(@
M)7,N)RP@)&%P<"D*("`@("`@("`I+"`D861D:71I;VYA;"D["@H@("`@("`@
M("\J($EF('=E(&MN;W<@=&AE('5S97(@:7,@86X@861M:6XL(&=I=F4@=&AE
M;2!A(&1I<F5C="!L:6YK('1O"B`@("`@("`@("H@9V5N97)A=&4@8V]N9BYP
M:'`N($EN('1H92!F=71U<F4L('-H;W5L9"!W92!T<GD@9V5N97)A=&EN9PH@
M("`@("`@("`J(&$@8F%S:6,@8V]N9BYP:'`@875T;VUA9VEC86QL>2!H97)E
M/R`J+PH@("`@("`@(&EF("A!=71H.CII<T%D;6EN*"DI('L*("`@("`@("`@
M("`@)'-E='5P7W5R;"`]($AO<F1E.CIL:6YK*$AO<F1E.CIU<FPH)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R]A9&UI;B]S971U<"]C;VYF:6<N<&AP/V%P<#TG("X@4W1R:6YG.CIL;W=E
M<B@D87!P*2DI("X*("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T:6]N(%=E
M8B!);G1E<F9A8V4G("X@)SPO83XG.PH@("`@("`@("`@("`D9&5S8W)I<'1I
M;VYS6R=C;VYF+G!H<"==(#T*("`@("`@("`@("`@("`@('-P<FEN=&8H)U1H
M:7,@:7,@=&AE(&UA:6X@)7,@8V]N9FEG=7)A=&EO;B!F:6QE+B`G("X*("`@
M("`@("`@("`@("`@("`@("`@("`@)T=E;F5R871E(&ET(&)Y(&=O:6YG('1O
M('1H92`E<RXG+`H@("`@("`@("`@("`@("`@("`@("`@("`D87!P+"`D<V5T
M=7!?=7)L*3L*("`@("`@("!]"@H@("`@("`@("1T:71L92`]('-P<FEN=&8H
M)R5S(&ES(&YO="!P<F]P97)L>2!C;VYF:6=U<F5D)RP@)&%P<"D["B`@("`@
M("`@)&AE861E<B`]('-P<FEN=&8H)U-O;64@;V8@)7-<)W,@8V]N9FEG=7)A
M=&EO;B!F:6QE<R!A<F4@;6ES<VEN9R!O<B!U;G)E861A8FQE)RP@)&%P<"D[
M"B`@("`@("`@)&9O;W1E<B`]('-P<FEN=&8H)T-R96%T92!T:&5S92!F:6QE
M<R!F<F]M('1H96ER("YD:7-T('9E<G-I;VYS(&EN("5S(&%N9"!C:&%N9V4@
M=&AE;2!A8V-O<F1I;F<@=&\@>6]U<B!N965D<RXG+"`D87!P0F%S92`N("<O
M8V]N9FEG)RD["@H@("`@("`@(&5C:&\@/#P\($A%041%4@H\:'1M;#X*/&AE
M860^/'1I=&QE/B1T:71L93PO=&ET;&4^/"]H96%D/@H\8F]D>2!S='EL93TB
M8F%C:V=R;W5N9"UC;VQO<CH@=VAI=&4[(&-O;&]R.B!B;&%C:SLB/@H\:#$^
M)&AE861E<CPO:#$^"DA%041%4CL*"B`@("`@("`@9F]R96%C:"`H)&9I;&5S
M(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&5S8W)I<'1I
M;VYS6R1F:6QE72DI('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1D97-C<FEP=&EO;B`]("1D97-C<FEP
M=&EO;G-;)&9I;&5=.PH@("`@("`@("`@("!E8VAO(#P\/"!&24Q%"B`@("`\
M:#,^)&9I;&4\+V@S/CQP/B1D97-C<FEP=&EO;CPO<#X*1DE,13L*("`@("`@
M("!]"@H@("`@("`@(&5C:&\@/#P\($9/3U1%4@H*/&@R/B1F;V]T97(\+V@R
M/@H\+V)O9'D^"CPO:'1M;#X*1D]/5$52.PH@("`@("`@(&5X:70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@;&ES="!O9B!R97%U:7)E9"!(
M;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A<'!?;&ES="`@5&AE(&%P<&QI8V%T:6]N(&QI<W0N"B`@("`@*B`\<')E
M/@H@("`@("H@2T59.B`@(&%P<&QI8V%T:6]N(&YA;64*("`@("`J(%9!3%5%
M.B!!;B!A<G)A>2!W:71H('1H92!F;VQL;W=I;F<@96YT<FEE<SH*("`@("`J
M("`@("`@("`G97)R;W(G("`@("TM("!%<G)O<B!-97-S86=E"B`@("`@*B`@
M("`@("`@)W9E<G-I;VXG("`M+2`@5&AE(&UI;FEM=6T@=F5R<VEO;B!R97%U
M:7)E9`H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!(5$U,(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5Q
M=6ER961!<'!#:&5C:R@D87!P7VQI<W0I"B`@("!["B`@("`@("`@)&]U='!U
M="`]("<G.PH*("`@("`@("`D87!P<R`]("1T:&ES+3YA<'!L:6-A=&EO;DQI
M<W0H*3L*"B`@("`@("`@9F]R96%C:"`H)&%P<%]L:7-T(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`D96YT<GE;72`]("1K97D["@H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1A<'!S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D
M=&AI<RT^7W-T871U<RAF86QS92D["B`@("`@("`@("`@("`@("`D96YT<GE;
M72`]("1V86Q;)V5R<F]R)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`O*B!3=')I<"`G+6-V<R<@86YD($@S("AV97(I(&9R;VT@
M=F5R<VEO;B!S=')I;F<N("HO"B`@("`@("`@("`@("`@("`D87!P=F5R(#T@
M<W1R7W)E<&QA8V4H)RUC=G,G+"`G)RP@)&%P<'-;)&ME>5TM/G9E<G-I;VXI
M.PH@("`@("`@("`@("`@("`@)&%P<'9E<B`]('!R96=?<F5P;&%C92@G+T@S
M(%PH*"XJ*5PI+R<L("<D,2<L("1A<'!V97(I.PH@("`@("`@("`@("`@("`@
M:68@*'9E<G-I;VY?8V]M<&%R92@D=F%L6R=V97)S:6]N)UTL("1A<'!V97(I
M(#T]/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@)&5N=')Y6UT@/2`D=&AI
M<RT^7W-T871U<RAF86QS92D@+B`G("A(879E('9E<G-I;VXZ("<@+B`D87!P
M<ULD:V5Y72T^=F5R<VEO;B`N("<[($YE960@=F5R<VEO;CH@)R`N("1V86Q;
M)W9E<G-I;VXG72`N("<I)SL*("`@("`@("`@("`@("`@("`@("`D96YT<GE;
M72`]("1V86Q;)V5R<F]R)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1E;G1R>5M=(#T@)'1H:7,M/E]S=&%T=7,H
M=')U92D@+B`G("A697)S:6]N.B`G("X@)&%P<'-;)&ME>5TM/G9E<G-I;VX@
M+B`G*2<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V]U='!U=$QI;F4H)&5N=')Y*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@27,@=&AI<R!A("=R96-E;G0G('9E<G-I;VX@;V8@4$5!
M4C\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@5')U92!I9B!A(')E
M8V5N="!V97)S:6]N(&]F(%!%05(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M4F5C96YT4$5!4B@I"B`@("!["B`@("`@("`@0&EN8VQU9&5?;VYC92`G4$5!
M4BYP:'`G.PH@("`@("`@("1P96%R7VUE=&AO9',@/2!G971?8VQA<W-?;65T
M:&]D<R@G4$5!4B<I.PH@("`@("`@(')E='5R;B`H:7-?87)R87DH)'!E87)?
M;65T:&]D<RD@)B8*("`@("`@("`@("`@("`@("AI;E]A<G)A>2@G<F5G:7-T
M97)S:'5T9&]W;F9U;F,G+"`D<&5A<E]M971H;V1S*2!\?`H@("`@("`@("`@
M("`@("`@(&EN7V%R<F%Y*"=R96=I<W1E<E-H=71D;W=N1G5N8R<L("1P96%R
M7VUE=&AO9',I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/8G1A:6X@:6YF
M;W)M871I;VX@;VX@=&AE(%!(4"!V97)S:6]N+@H@("`@("H*("`@("`J($!R
M971U<FX@;V)J96-T('-T9$-L87-S("!43T1/"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%!H<%9E<G-I;VY);F9O<FUA=&EO;B@I"B`@("!["B`@("`@("`@
M)&]U='!U="`]("9N97<@<W1D0VQA<W,["B`@("`@("`@)'5R;"`]('5R;&5N
M8V]D92@D7U-%4E9%4ELG4$A07U-%3$8G72D["B`@("`@("`@)'9E<G-?8VAE
M8VL@/2!T<G5E.PH*("`@("`@("`D=&5S='-C<FEP="`]("1T:&ES+3YA<'!L
M:6-A=&EO;G-;)VAO<F1E)UU;)W=E8G)O;W0G72`N("<O=&5S="YP:'`G.PH@
M("`@("`@("1O=71P=70M/G!H<&EN9F\@/2`D=&5S='-C<FEP="`N("<_;6]D
M93UP:'!I;F9O)G5R;#TG("X@)'5R;#L*("`@("`@("`D;W5T<'5T+3YE>'1E
M;G-I;VYS(#T@)'1E<W1S8W)I<'0@+B`G/VUO9&4]97AT96YS:6]N<R9U<FP]
M)R`N("1U<FP["B`@("`@("`@)&]U='!U="T^=F5R<VEO;B`]('!H<'9E<G-I
M;VXH*3L*("`@("`@("`D;W5T<'5T+3YM86IO<B`]("1T:&ES+3Y?<&AP=F5R
M6R=M86IO<B==.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!H<'9E<ELG
M;6EN;W(G72DI('L*("`@("`@("`@("`@)&]U='!U="T^;6EN;W(@/2`D=&AI
M<RT^7W!H<'9E<ELG;6EN;W(G73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&AP=F5R6R=S=6)M:6YO<B==*2D@>PH@("`@("`@("`@
M("`D;W5T<'5T+3YS=6)M:6YO<B`]("1T:&ES+3Y?<&AP=F5R6R=S=6)M:6YO
M<B==.PH@("`@("`@('T*("`@("`@("`D;W5T<'5T+3YC;&%S<R`]("1T:&ES
M+3Y?<&AP=F5R6R=C;&%S<R==.PH*("`@("`@("`D;W5T<'5T+3YS=&%T=7-?
M8V]L;W(@/2`G<F5D)SL*("`@("`@("!I9B`H)&]U='!U="T^;6%J;W(@/"`G
M-"XS)RD@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%T=7,@/2`G5&AI<R!V
M97)S:6]N(&]F(%!(4"!I<R!N;W0@<W5P<&]R=&5D+B!9;W4@;F5E9"!T;R!U
M<&=R861E('1O(&$@;6]R92!R96-E;G0@=F5R<VEO;BXG.PH@("`@("`@("`@
M("`D=F5R<U]C:&5C:R`](&9A;'-E.PH@("`@("`@('T@96QS96EF("@H)&]U
M='!U="T^;6%J;W(@/3T@)S0N,R<I('Q\"B`@("`@("`@("`@("`@("`@("@D
M;W5T<'5T+3YM86IO<B`]/2`G-"XT)RD@?'P*("`@("`@("`@("`@("`@("`@
M*"1O=71P=70M/FUA:F]R(#T]("<U+C`G*2!\?`H@("`@("`@("`@("`@("`@
M("`H)&]U='!U="T^;6%J;W(@/3T@)S4N,2<I*2!["B`@("`@("`@("`@("1O
M=71P=70M/G-T871U<R`]("=9;W4@87)E(')U;FYI;F<@82!S=7!P;W)T960@
M=F5R<VEO;B!O9B!02%`N)SL*("`@("`@("`@("`@)&]U='!U="T^<W1A='5S
M7V-O;&]R(#T@)V=R965N)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D;W5T<'5T+3YS=&%T=7,@/2`G5V]W+"!A(&UY<W1I8V%L('9E<G-I;VX@
M;V8@4$A0(&9R;VT@=&AE(&9U='5R92X@3&5T(#QA(&AR968](FUA:6QT;SID
M979`;&ES=',N:&]R9&4N;W)G(CYD979`;&ES=',N:&]R9&4N;W)G/"]A/B!K
M;F]W('=H870@=F5R<VEO;B!Y;W4@:&%V92!S;R!W92!C86X@9FEX('1H:7,@
M<V-R:7!T+B<["B`@("`@("`@("`@("1O=71P=70M/G-T871U<U]C;VQO<B`]
M("=O<F%N9V4G.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D=F5R<U]C:&5C
M:RD@>PH@("`@("`@("`@("`D;W5T<'5T+3YV97)S:6]N7V-H96-K(#T@)TAO
M<F1E(')E<75I<F5S(%!(4"`T+C,N,"!O<B!G<F5A=&5R+B<["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($=E="!T:&4@87!P;&EC871I;VX@;&ES="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!,:7-T(&]F('-T9$-L87-S(&]B:F5C=',N"B`@("`@
M*B`@("`@("`@("`@("`@("!+15DZ(&%P<&QI8V%T:6]N(&YA;64*("`@("`J
M("`@("`@("`@("`@("`@($5,14U%3E0@)W9E<G-I;VXG.B!697)S:6]N(&]F
M(&%P<&QI8V%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("!%3$5-14Y4("=T
M97-T)SH@5&AE(&QO8V%T:6]N(&]F('1H92!T97-T('-C<FEP="`H:68@86YY
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;DQI<W0H*0H@("`@
M>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]A<'!O=71P=70I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%P<&]U='!U=#L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YA<'!L:6-A=&EO;G,@87,@)&UO
M9"`]/B`D9&5T*2!["B`@("`@("`@("`@(&EF("@H)&1E=%LG<W1A='5S)UT@
M(3T@)VAE861I;F<G*2`F)@H@("`@("`@("`@("`@("`@*"1D971;)W-T871U
M<R==("$]("=B;&]C:R<I("8F"B`@("`@("`@("`@("`@("!I<U]R96%D86)L
M92@D9&5T6R=F:6QE<F]O="==("X@)R]L:6(O=F5R<VEO;BYP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1D971;)V9I;&5R;V]T)UT@
M+B`G+VQI8B]V97)S:6]N+G!H<"<["B`@("`@("`@("`@("`@("`D=F5R<VEO
M;E]C;VYS=&%N="`](%-T<FEN9SHZ=7!P97(H)&UO9"D@+B`G7U9%4E-)3TXG
M.PH@("`@("`@("`@("`@("`@:68@*&1E9FEN960H)'9E<G-I;VY?8V]N<W1A
M;G0I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<'!O=71P=71;
M)&UO9%T@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?87!P;W5T<'5T6R1M;V1=+3YV97)S:6]N(#T@8V]N<W1A;G0H)'9E
M<G-I;VY?8V]N<W1A;G0I.PH@("`@("`@("`@("`@("`@("`@(&EF("@H)&UO
M9"`A/2`G:&]R9&4G*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!`:7-?
M<F5A9&%B;&4H)&1E=%LG9FEL97)O;W0G72`N("<O=&5S="YP:'`G*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%P<&]U='!U=%LD;6]D
M72T^=&5S="`]("1D971;)W=E8G)O;W0G72`N("<O=&5S="YP:'`G.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P;W5T
M<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T('1H92!R97-U;'1S
M(&]F(&$@<W1A='5S(&-H96-K+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("`@("`@
M5&AE(')E<W5L="!O9B!T:&4@<W1A='5S(&-H96-K+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)')E<75I<F5D("!7:&5T:&5R('1H92!C:&5C:V5D(&ET96T@
M:7,@<F5Q=6ER960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!(5$U,(&]F('1H92!R97-U;'0@;V8@=&AE('-T871U<R!C:&5C:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-T871U<R@D8F]O;"P@)')E<75I<F5D(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H)&)O;VPI('L*("`@("`@("`@("`@
M<F5T=7)N("<\9F]N="!C;VQO<CTB9W)E96XB/CQS=')O;F<^665S/"]S=')O
M;F<^/"]F;VYT/B<["B`@("`@("`@?2!E;'-E:68@*"1R97%U:7)E9"D@>PH@
M("`@("`@("`@("!R971U<FX@)SQF;VYT(&-O;&]R/2)R960B/CQS=')O;F<^
M3F\\+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@)SQF;VYT(&-O;&]R/2)O<F%N9V4B/CQS=')O;F<^3F\\
M+W-T<F]N9SX\+V9O;G0^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);G1E<FYA;"!O=71P=70@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E
M;G1R>2`@,R!E;&5M96YT(&%R<F%Y+@H@("`@("H@/'!R93X*("`@("`J(#%S
M="!V86QU93H@2&5A9&5R"B`@("`@*B`R;F0@=F%L=64Z(%1E<W0@4F5S=6QT
M"B`@("`@*B`S<F0@=F%L=64Z($5R<F]R(&UE<W-A9V4@*&EF('!R97-E;G0I
M"B`@("`@*B`T=&@@=F%L=64Z($5R<F]R(&QE=F5L("AI9B!P<F5S96YT*3H@
M,"`](&5R<F]R+"`Q(#T@=V%R;FEN9PH@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@($A434P@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;W5T<'5T3&EN92@D96YT<GDI"B`@("!["B`@("`@("`@
M)&]U='!U="`]("<\;&D^)R`N(&%R<F%Y7W-H:69T*"1E;G1R>2D@+B`G.B`G
M("X@87)R87E?<VAI9G0H)&5N=')Y*3L*("`@("`@("!I9B`H(65M<'1Y*"1E
M;G1R>2DI('L*("`@("`@("`@("`@)&US9R`](&%R<F%Y7W-H:69T*"1E;G1R
M>2D["B`@("`@("`@("`@("1O=71P=70@+CT@)SQB<B`O/CQF;VYT(&-O;&]R
M/2(G("X@*&5M<'1Y*"1E;G1R>2D@?'P@(6%R<F%Y7W-H:69T*"1E;G1R>2D@
M/R`G<F5D)R`Z("=O<F%N9V4G*2`N("<B/CQS=')O;F<^)R`N("1M<V<@+B`G
M/"]S=')O;F<^/"]F;VYT/B<@+B`B7&XB.PH@("`@("`@('T*("`@("`@("`D
M;W5T<'5T("X]("<\+VQI/B<@+B`B7&XB.PH*("`@("`@("!R971U<FX@)&]U
M='!U=#L*("`@('T*"GT*````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4N<&AP
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`Q-34R,#(@,3`U,34T,S0Q-#$@,#(P,#4V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@
M)TQO9RYP:'`G.PII;F-L=61E7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*"B\J
M*@H@*B!4:&4@2&]R9&4Z.B!C;&%S<R!P<F]V:61E<R!T:&4@9G5N8W1I;VYA
M;&ET>2!S:&%R960@8GD@86QL($AO<F1E"B`J(&%P<&QI8V%T:6]N<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4N<&AP+'8@,2XT.#DN
M,BXU-"`R,#`V+S`W+S,Q(#`X.C0Y.C0W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F]N(%!A
M<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J
M($!P86-K86=E($AO<F1E7T9R86UE=V]R:PH@*B\*8VQA<W,@2&]R9&4@>PH*
M("`@("\J*@H@("`@("H@3&]G<R!A(&UE<W-A9V4@=&\@=&AE(&=L;V)A;"!(
M;W)D92!L;V<@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&UE<W-A9V4@("`@($5I=&AE<B!A('-T<FEN9R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@("`@("!7:&%T
M(&9I;&4@=V%S('1H92!L;V<@9G5N8W1I;VX@8V%L;&5D(&9R;VT*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*&4N9RX@7U]&24Q%7U\I/PH@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&QI;F4@("`@("!7:&%T(&QI;F4@=V%S
M('1H92!L;V<@9G5N8W1I;VX@8V%L;&5D(&9R;VT*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*&4N9RX@7U],24Y%7U\I/PH@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'!R:6]R:71Y("!4:&4@<')I;W)I='D@;V8@=&AE(&UE
M<W-A9V4N($]N92!O9CH*("`@("`J(#QP<F4^"B`@("`@*B!014%27TQ/1U]%
M34521PH@("`@("H@4$5!4E],3T=?04Q%4E0*("`@("`J(%!%05)?3$]'7T-2
M250*("`@("`J(%!%05)?3$]'7T524@H@("`@("H@4$5!4E],3T=?5T%23DE.
M1PH@("`@("H@4$5!4E],3T=?3D]424-%"B`@("`@*B!014%27TQ/1U])3D9/
M"B`@("`@*B!014%27TQ/1U]$14)51PH@("`@("H@/"]P<F4^"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QO9TUE<W-A9V4H)&UE<W-A9V4L("1F:6QE+"`D;&EN
M92P@)'!R:6]R:71Y(#T@4$5!4E],3T=?24Y&3RD*("`@('L*("`@("`@("!G
M;&]B86P@)&-O;F8["@H@("`@("`@(&EF("@A)&-O;F9;)VQO9R==6R=E;F%B
M;&5D)UTI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1P<FEO<FET>2`^("1C;VYF6R=L;V<G75LG<')I;W)I='DG72D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D;&]G
M9V5R(#T@)DAO<F1E.CIG971,;V=G97(H*3L*("`@("`@("!I9B`H(6ES7V$H
M)&QO9V=E<BP@)TQO9R<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A0
M14%2.CIR86ES945R<F]R*"=!;B!E<G)O<B!H87,@;V-C=7)R960N($9U<G1H
M97)M;W)E+"!(;W)D92!E;F-O=6YT97)E9"!A;B!E<G)O<B!A='1E;7!T:6YG
M('1O(&QO9R!T:&ES(&5R<F]R+B!0;&5A<V4@8VAE8VL@>6]U<B!(;W)D92!L
M;V=G:6YG(&-O;F9I9W5R871I;VX@:6X@:&]R9&4O8V]N9FEG+V-O;F8N<&AP
M+B<I+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]A*"1M97-S86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("1U<V5R:6YF;R`]("1M97-S86=E+3YG9715<V5R26YF;R@I
M.PH@("`@("`@("`@("`D;65S<V%G92`]("1M97-S86=E+3YG971-97-S86=E
M*"D["B`@("`@("`@("`@(&EF("@A96UP='DH)'5S97)I;F9O*2D@>PH@("`@
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1U<V5R:6YF;RDI('L*("`@("`@
M("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!`:6UP;&]D92@G+"`G+"`D=7-E
M<FEN9F\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UE
M<W-A9V4@+CT@)SH@)R`N("1U<V5R:6YF;SL*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("AI<U]C86QL86)L92AA<G)A>2@D;65S<V%G92P@)V=E
M=$UE<W-A9V4G*2DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2`D;65S<V%G
M92T^9V5T365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@)&%P<"`](&ES
M<V5T*"1'3$]"04Q36R=R96=I<W1R>2==*2`_("1'3$]"04Q36R=R96=I<W1R
M>2==+3YG971!<'`H*2`Z("=H;W)D92<["B`@("`@("`@)&UE<W-A9V4@/2`G
M6R<@+B`D87!P("X@)UT@)R`N("1M97-S86=E("X@)R!;;VX@;&EN92`G("X@
M)&QI;F4@+B`G(&]F("(G("X@)&9I;&4@+B`G(ETG.PH*("`@("`@("`O*B!-
M86ME('-U<F4@=&\@;&]G(&EN('1H92!S>7-T96TG<R!L;V-A;&4N("HO"B`@
M("`@("`@)&QO8V%L92`]('-E=&QO8V%L92A,0U]424U%+"`P*3L*("`@("`@
M("!S971L;V-A;&4H3$-?5$E-12P@)T,G*3L*"B`@("`@("`@)&QO9V=E<BT^
M;&]G*"1M97-S86=E+"`D<')I;W)I='DI.PH*("`@("`@("`O*B!297-T;W)E
M(&]R:6=I;F%L(&QO8V%L92X@*B\*("`@("`@("!S971L;V-A;&4H3$-?5$E-
M12P@)&QO8V%L92D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T3&]G9V5R*"D*("`@('L*
M("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AE;7!T>2@D8V]N
M9ELG;&]G)UU;)V5N86)L960G72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<W1A=&EC("1L;V=C:&5C:SL*("`@
M("`@("!I9B`H(6ES<V5T*"1L;V=C:&5C:RDI('L*("`@("`@("`@("`@+R\@
M5')Y('1O(&UA:V4@<W5R92!T:&%T('=E(&-A;B!L;V<@;65S<V%G97,@<V]M
M96AO=RX*("`@("`@("`@("`@:68@*&5M<'1Y*"1C;VYF6R=L;V<G72D@?'P*
M("`@("`@("`@("`@("`@(&5M<'1Y*"1C;VYF6R=L;V<G75LG='EP92==*2!\
M?`H@("`@("`@("`@("`@("`@96UP='DH)&-O;F9;)VQO9R==6R=N86UE)UTI
M('Q\"B`@("`@("`@("`@("`@("!E;7!T>2@D8V]N9ELG;&]G)UU;)VED96YT
M)UTI('Q\"B`@("`@("`@("`@("`@("`A:7-S970H)&-O;F9;)VQO9R==6R=P
M87)A;7,G72DI('L*("`@("`@("`@("`@("`@($AO<F1E.CIF871A;"A014%2
M.CIR86ES945R<F]R*"=(;W)D92!I<R!N;W0@8V]R<F5C=&QY(&-O;F9I9W5R
M960@=&\@;&]G(&5R<F]R(&UE<W-A9V5S+B!9;W4@;75S="!C;VYF:6=U<F4@
M870@;&5A<W0@82!T97AT(&9I;&4@;&]G(&EN(&AO<F1E+V-O;F9I9R]C;VYF
M+G!H<"XG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!F86QS92D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&QO9V-H96-K(#T@=')U93L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"1C
M;VYF6R=L;V<G75LG='EP92==+"`D8V]N9ELG;&]G)UU;)VYA;64G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N9ELG
M;&]G)UU;)VED96YT)UTL("1C;VYF6R=L;V<G75LG<&%R86US)UTI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5S=')O>7,@86YY(&5X:7-T:6YG('-E<W-I
M;VX@;VX@;&]G:6X@86YD(&UA:V4@<W5R92!T;R!U<V4@82!N97<*("`@("`J
M('-E<W-I;VX@240L('1O(&%V;VED('-E<W-I;VX@9FEX871I;VX@:7-S=65S
M+B!3:&]U;&0@8F4@8V%L;&5D(&)E9F]R90H@("`@("H@8VAE8VMI;F<@82!L
M;V=I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0VQE86Y397-S:6]N*"D*
M("`@('L*("`@("`@("`O+R!-86ME('-U<F4@=&\@9F]R8V4@82!C;VUP;&5T
M96QY(&YE=R!S97-S:6]N($E$(&%N9"!C;&5A<@H@("`@("`@("\O(&%L;"!S
M97-S:6]N(&1A=&$N"B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V
M97)S:6]N*"DL("<T+C,N,R<I("$]/2`M,2D@>PH@("`@("`@("`@("!S97-S
M:6]N7W)E9V5N97)A=&5?:60H*3L*("`@("`@("`@("`@<V5S<VEO;E]U;G-E
M="@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!S97-S:6]N7V1E
M<W1R;WDH*3L*("`@("`@("`@("`@:68@*%5T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G<&]S:7@G*2D@>PH@("`@("`@("`@("`@("`@)&YE=U]S97-S:6]N7VED
M(#T@;60U*&UI8W)O=&EM92@I("X@<&]S:7A?9V5T<&ED*"DI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YE=U]S97-S:6]N7VED
M(#T@;60U*'5N:7%I9"AM=%]R86YD*"DL('1R=64I*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!S97-S:6]N7VED*"1N97=?<V5S<VEO;E]I9"D["@H@
M("`@("`@("`@("`O+R!297-T87)T('1H92!S97-S:6]N+"!I;F-L=61I;F<@
M<V5T=&EN9R!U<"!T:&4@<V5S<VEO;@H@("`@("`@("`@("`O+R!H86YD;&5R
M+@H@("`@("`@("`@("!(;W)D93HZ<V5T=7!397-S:6]N2&%N9&QE<B@I.PH@
M("`@("`@("`@("!`<V5S<VEO;E]S=&%R="@I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4F5S970@8V]O:VEE('1I;65O=71S+"!I9B!N96-E<W-A<GDN("HO
M"B`@("`@("`@:68@*"%E;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=S97-S:6]N
M)UU;)W1I;65O=70G72DI('L*("`@("`@("`@("`@)&%P<"`]("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YG971!<'`H*3L*("`@("`@("`@("`@:68@*%-E8W)E
M=#HZ8VQE87)+97DH)&%P<"DI('L*("`@("`@("`@("`@("`@(%-E8W)E=#HZ
M<V5T2V5Y*"1A<'`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(%-E8W)E
M=#HZ<V5T2V5Y*"=A=71H)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@06)O<G1S('=I=&@@82!F871A;"!E<G)O<BP@9&ES<&QA>6EN9R!D
M96)U9R!I;F9O<FUA=&EO;B!T;R!T:&4@=7-E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&5R<F]R("`@02!014%27T5R<F]R(&]B:F5C="!W:71H
M(&1E8G5G(&EN9F]R;6%T:6]N(&]R(&%N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@97)R;W(@;65S<V%G92X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1F:6QE("!4:&4@9FEL92!I;B!W:&EC:"!T:&4@97)R;W(@;V-C=7)E9"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("!4:&4@;&EN92!O;B!W:&EC
M:"!T:&4@97)R;W(@;V-C=7)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1L
M;V<@("!,;V<@=&AI<R!M97-S86=E('9I82!(;W)D93HZ;&]G365S<V%G92@I
M/PH@("`@("HO"B`@("!F=6YC=&EO;B!F871A;"@D97)R;W(L("1F:6QE+"`D
M;&EN92P@)&QO9R`]('1R=64I"B`@("!["B`@("`@("`@0&EN8VQU9&5?;VYC
M92`G2&]R9&4O075T:"YP:'`G.PH@("`@("`@($!I;F-L=61E7V]N8V4@)TAO
M<F1E+T-,22YP:'`G.PH*("`@("`@("`D861M:6X@/2!C;&%S<U]E>&ES=',H
M)T%U=&@G*2`F)B!!=71H.CII<T%D;6EN*"D["B`@("`@("`@)&-L:2`](&-L
M87-S7V5X:7-T<R@G2&]R9&5?0TQ))RD@)B8@2&]R9&5?0TQ).CIR=6YN:6YG
M1G)O;4-,22@I.PH*("`@("`@("`D97)R;W)T97AT(#T@)SQH,3XG("X@7R@B
M02!F871A;"!E<G)O<B!H87,@;V-C=7)R960B*2`N("<\+V@Q/B<["B`@("`@
M("`@:68@*&ES7V$H)&5R<F]R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("1I;F9O(#T@87)R87E?;65R9V4H87)R87DH)V9I;&4G(#T^("=C;VYF
M+G!H<"<L("=V87)I86)L92<@/3X@)R1C;VYF)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)&5R<F]R+3YG9715<V5R26YF;R@I
M*2D["@H@("`@("`@("`@("!S=VET8V@@*"1E<G)O<BT^9V5T0V]D92@I*2![
M"B`@("`@("`@("`@(&-A<V4@2$]21$5?15)23U)?1%))5D527T-/3D9)1U]-
M25-324Y'.@H@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H
M(DYO(&-O;F9I9W5R871I;VX@:6YF;W)M871I;VX@<W!E8VEF:65D(&9O<B`E
M<RXB*2P@)&EN9F];)VYA;64G72D@+B`G/&)R("\^)R`N"B`@("`@("`@("`@
M("`@("`@("`@<W!R:6YT9BA?*")4:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I
M;B!S;VUE("5S('-E='1I;F=S+B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G*2`N
M("<O8V]N9FEG+R<@+B`D:6YF;ULG9FEL92==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!R:6YT9B@B)7-;)R5S)UU;)W!A<F%M<R==(BP@)&EN
M9F];)W9A<FEA8FQE)UTL("1I;F9O6R=D<FEV97(G72DI.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E($A/4D1%7T524D]27T12
M259%4E]#3TY&24<Z"B`@("`@("`@("`@("`@("`D;65S<V%G92`]('-P<FEN
M=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO="!S<&5C:69I960@:6X@)7,@8V]N
M9FEG=7)A=&EO;BXB*2P@)&EN9F];)V9I96QD)UTL("1I;F9O6R=N86UE)UTI
M("X@)SQB<B`O/B<@+@H@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B
M5&AE(&9I;&4@)7,@<VAO=6QD(&-O;G1A:6X@82`E<R!S971T:6YG+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G9FEL97)O;W0G*2`N("<O8V]N9FEG+R<@+B`D:6YF;ULG9FEL
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@B)7-;
M)R5S)UU;)W!A<F%M<R==6R<E<R==(BP@)&EN9F];)W9A<FEA8FQE)UTL("1I
M;F9O6R=D<FEV97(G72P@)&EN9F];)V9I96QD)UTI*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@("1M97-S86=E(#T@)&5R<F]R+3YG971-97-S86=E*"D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&5R
M<F]R=&5X="`N/2`G/&@S/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1M97-S86=E
M*2`N("<\+V@S/B<["B`@("`@("`@?2!E;'-E:68@*&ES7V]B:F5C="@D97)R
M;W(I("8F(&UE=&AO9%]E>&ES=',H)&5R<F]R+"`G9V5T365S<V%G92<I*2![
M"B`@("`@("`@("`@("1E<G)O<G1E>'0@+CT@)SQH,SXG("X@:'1M;'-P96-I
M86QC:&%R<R@D97)R;W(M/F=E=$UE<W-A9V4H*2D@+B`G/"]H,SXG.PH@("`@
M("`@('T@96QS96EF("AI<U]S=')I;F<H)&5R<F]R*2D@>PH@("`@("`@("`@
M("`D97)R;W)T97AT("X]("<\:#,^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&5R
M<F]R*2`N("<\+V@S/B<["B`@("`@("`@?0H*("`@("`@("!I9B`H)&%D;6EN
M*2!["B`@("`@("`@("`@("1E<G)O<G1E>'0@+CT@)SQP/CQC;V1E/B<@+B!S
M<')I;G1F*%\H(EML:6YE("5S(&]F("5S72(I+"`D;&EN92P@)&9I;&4I("X@
M)SPO8V]D93X\+W`^)SL*("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D97)R
M;W(I*2!["B`@("`@("`@("`@("`@("`D97)R;W)T97AT("X]("<\:#,^)R`N
M(%\H(D1E=&%I;',@*&%L<V\@:6X@2&]R9&4G<R!L;V=F:6QE*3HB*2`N("<\
M+V@S/B<["B`@("`@("`@("`@("`@("`D97)R;W)T97AT("X]("<\<#X\<')E
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*%5T:6PZ.F)U9F9E<D]U='!U="@G=F%R
M7V1U;7`G+"`D97)R;W(I*2`N("<\+W!R93X\+W`^)SL*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("@D;&]G*2!["B`@("`@("`@("`@("1E<G)O
M<G1E>'0@+CT@)SQH,SXG("X@7R@B1&5T86EL<R!H879E(&)E96X@;&]G9V5D
M(&9O<B!T:&4@861M:6YI<W1R871O<BXB*2`N("<\+V@S/B<["B`@("`@("`@
M?0H*("`@("`@("`O+R!,;V<@=&AE(&5R<F]R('9I82!(;W)D93HZ;&]G365S
M<V%G92@I(&EF(')E<75E<W1E9"X*("`@("`@("!I9B`H)&QO9RD@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D97)R;W(L("1F:6QE+"`D;&EN
M92P@4$5!4E],3T=?14U%4D<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C
M;&DI('L*("`@("`@("`@("`@96-H;R!S=')I<%]T86=S*'-T<E]R97!L86-E
M*&%R<F%Y*"<\8G(@+SXG+"`G/'`^)RP@)SPO<#XG+"`G/&@Q/B<L("<\+V@Q
M/B<L("<\:#,^)RP@)SPO:#,^)RDL(")<;B(L("1E<G)O<G1E>'0I*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO(#P\/"!(5$U,"CQH=&UL
M/@H\:&5A9#X\=&ET;&4^2&]R9&4@.CH@1F%T86P@17)R;W(\+W1I=&QE/CPO
M:&5A9#X*/&)O9'D@<W1Y;&4](F)A8VMG<F]U;F0Z(V9F9CL@8V]L;W(Z(S`P
M,"(^)&5R<F]R=&5X=#PO8F]D>3X*/"]H=&UL/@I(5$U,.PH@("`@("`@('T*
M("`@("`@("!E>&ET.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!T:&4@
M:F%V87-C<FEP="!C;V1E('1O('1H92!O=71P=70@*&EF(&]U='!U="!H87,@
M86QR96%D>2!S=&%R=&5D*0H@("`@("H@;W(@=&\@=&AE(&QI<W0@;V8@<V-R
M:7!T(&9I;&5S('1O(&EN8VQU9&4@=FEA(&EN8VQU9&538W)I<'1&:6QE<R@I
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("`@(%1H92!F
M=6QL(&IA=F%S8W)I<'0@9FEL92!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("`@("`@5&AE(&%P<&QI8V%T:6]N(&YA;64N($1E9F%U;'1S('1O
M('1H92!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A
M<'!L:6-A=&EO;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D:7)E8W0@($EN
M8VQU9&4@=&AE(&9I;&4@9&ER96-T;'D@=VET:&]U="!P87-S:6YG(&ET"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:')O=6=H(&IA=F%S8W)I
M<'0N<&AP/PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&138W)I<'1&:6QE*"1F
M:6QE+"`D87!P(#T@;G5L;"P@)&1I<F5C="`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@<W1A=&EC("1I;F-L=61E
M9"`](&%R<F%Y*"D["@H@("`@("`@(&EF("AE;7!T>2@D87!P*2D@>PH@("`@
M("`@("`@("`D87!P(#T@)')E9VES=')Y+3YG971!<'`H*3L*("`@("`@("!]
M"@H@("`@("`@("\O(%-K:7`@86YY(&IS(&9I;&5S('1H870@:&%V92!S:6YC
M92!B965N(&1E<')E8V%T960N"B`@("`@("`@)&EG;F]R961?9FEL97,@/2!A
M<G)A>2@G:&]R9&4G(#T^(&%R<F%Y*"=T;V]L=&EP+FIS)R`]/B`Q*2D["B`@
M("`@("`@:68@*"%E;7!T>2@D:6=N;W)E9%]F:6QE<ULD87!P75LD9FEL95TI
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\O
M($1O;B=T(&EN8VQU9&4@<V-R:7!T<R!M=6QT:7!L92!T:6UE<RX*("`@("`@
M("!I9B`H(65M<'1Y*"1I;F-L=61E9%LD87!P75LD9FEL95TI*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@)&EN8VQU9&5D6R1A
M<'!=6R1F:6QE72`]('1R=64["@H@("`@("`@("\O($5X<&QI8VET;'D@8VAE
M8VL@9F]R(&$@;F]N+5!(4"!V97)S:6]N(&]F('1H92!S8W)I<'0N"B`@("`@
M("`@:68@*"$D9&ER96-T("8F(&9I;&5?97AI<W1S*"1F:6QE>S!](#T]("<O
M)R`_("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)&9I;&4@
M.B`D<F5G:7-T<GDM/F=E="@G:G-F<R<L("1A<'`I("X@)R\G("X@)&9I;&4I
M*2!["B`@("`@("`@("`@("1D:7)E8W0@/2!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@+R\@268@:&5A9&5R<R!H879E(&%L<F5A9'D@8F5E;B!S96YT+"!W
M92!N965D('1O(&]U='!U="!A"B`@("`@("`@+R\@/'-C<FEP=#X@=&%G(&1I
M<F5C=&QY+@H@("`@("`@(&EF("AO8E]G971?;&5N9W1H*"D@?'P@:&5A9&5R
M<U]S96YT*"DI('L*("`@("`@("`@("`@:68@*"1D:7)E8W0I('L*("`@("`@
M("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1F:6QE>S!](#T]("<O)R`_
M("1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)&%P<"D@+B`D9FEL92`Z("1R
M96=I<W1R>2T^9V5T*"=J<W5R:2<L("1A<'`I("X@)R\G("X@)&9I;&4I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'5R;"`]($AO
M<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M("<O<V5R=FEC97,O:F%V87-C<FEP="YP:'`G*3L*("`@("`@("`@("`@("`@
M("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@87)R87DH)V9I;&4G
M(#T^("1F:6QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G87!P)R`@/3X@)&%P<"DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5C:&\@)SQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(B!S<F,](B<@+B`D=7)L("X@)R(^/"]S8W)I<'0^)R`N(")<
M;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9VQO8F%L("1?:&]R
M9&5?<V-R:7!T7V9I;&5S.PH@("`@("`@("`@("`D7VAO<F1E7W-C<FEP=%]F
M:6QE<ULD87!P75M=(#T@87)R87DH)&9I;&4L("1D:7)E8W0I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($EN8VQU9&5S(&IA=F%S8W)I<'0@
M9FEL97,@=&AA="!W97)E(&YE961E9"!B969O<F4@86YY(&AE861E<G,@=V5R
M92!S96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F-L=61E4V-R:7!T1FEL
M97,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7VAO<F1E7W-C<FEP=%]F:6QE
M<RP@)')E9VES=')Y.PH*("`@("`@("`O*B!)9B!T:&5R92!I<R!N;R!J879A
M<V-R:7!T(&%V86EL86)L92P@=&AE<F4G<R!N;R!P;VEN="!I;B!I;F-L=61I
M;F<*("`@("`@("`@*B!T:&4@<F5S="!O9B!T:&4@9FEL97,N("HO"B`@("`@
M("`@:68@*"$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=J879A
M<V-R:7!T)RDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@+RH@061D(&=E;F5R86P@54D@:G,@;&EB<F%R>2X@*B\*("`@("`@
M("!(;W)D93HZ861D4V-R:7!T1FEL92@G:&]R9&4N:G,G+"`G:&]R9&4G+"!T
M<G5E*3L*("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S475I
M<FLH)W=I;F1O=V5D7V-O;G1R;VQS)RDI('L*("`@("`@("`@("`@+RH@1FEX
M97,@9F]R($E%('1H870@8V%N)W0@96%S:6QY(&)E(&1O;F4@=VET:&]U="!B
M<F]W<V5R"B`@("`@("`@("`@("`J(&1E=&5C=&EO;BX@*B\*("`@("`@("`@
M("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VAO<F1E+FEE+FIS)RP@)VAO<F1E
M)RP@=')U92D["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1?:&]R
M9&5?<V-R:7!T7V9I;&5S*2D@>PH@("`@("`@("`@("`D8F%S95]U<FP@/2!(
M;W)D93HZ=7)L*"1R96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@
M+B`G+W-E<G9I8V5S+VIA=F%S8W)I<'0N<&AP)RD["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1?:&]R9&5?<V-R:7!T7V9I;&5S(&%S("1A<'`@/3X@)&9I;&5S
M*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I;&4I
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1F:6QE6S%=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=7)L(#T@)&9I;&5;,%U[,'T@
M/3T@)R\G(#\@)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`D87!P*2`N("1F
M:6QE6S!=(#H@)')E9VES=')Y+3YG970H)VIS=7)I)RP@)&%P<"D@+B`G+R<@
M+B`D9FEL95LP73L*("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`G/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B('-R8STB)R`N($AO<F1E.CIU
M<FPH)'5R;"D@+B`B7"(^/"]S8W)I<'0^7&XB.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1U<FP@/2!5
M=&EL.CIA9&1087)A;65T97(H)&)A<V5?=7)L+"!A<G)A>2@G9FEL92<@/3X@
M)&9I;&5;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G87!P)R`@/3X@)&%P
M<"DI.PH@("`@("`@("`@("`@("`@("`@("`@("!E8VAO("<\<V-R:7!T('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2(G("X@)'5R;"`N(")<(CX\+W-C
M<FEP=#Y<;B(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@26YC;'5D97,@:F%V87-C<FEP="!F:6QE<R!T:&%T('=E<F4@;F5E
M9&5D(&)E9F]R92!A;GD@:&5A9&5R<R!W97)E('-E;G0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&EN;&EN95-C<FEP=$9I;&5S*"D*("`@('L*("`@("`@("!G
M;&]B86P@)%]H;W)D95]S8W)I<'1?9FEL97,L("1R96=I<W1R>3L*"B`@("`@
M("`@:68@*"%E;7!T>2@D7VAO<F1E7W-C<FEP=%]F:6QE<RDI('L*("`@("`@
M("`@("`@)&IS5W)A<'!E<B`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L
M("=H;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T+G!H<"<["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1?:&]R9&5?<V-R:7!T7V9I;&5S(&%S("1A<'`@
M/3X@)&9I;&5S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL97,@
M87,@)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1F
M:6QE6S%=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!`<F5A9&9I;&4H
M)&9I;&5;,%U[,'T@/3T@)R\G(#\@)')E9VES=')Y+3YG970H)V9I;&5R;V]T
M)RP@)&%P<"D@+B`D9FEL95LP72`Z("1R96=I<W1R>2T^9V5T*"=J<V9S)RP@
M)&%P<"D@+B`G+R<@+B`D9FEL95LP72D["B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D9FEL
M95LP73L*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER92`D:G-7<F%P
M<&5R.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($-H96-K<R!I9B!L:6YK('-H;W5L9"!B92!S:&]W;B!A;F0@<F5T=7)N('1H
M92!N97-C97-S87)Y(&-O9&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'1Y<&4@("`@("!4>7!E(&]F(&QI;FL@=&\@9&ES<&QA>0H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&%P<"`@("`@("!4:&4@;F%M92!O9B!T:&4@8W5R
M<F5N="!(;W)D92!A<'!L:6-A=&EO;BX*("`@("`J($!P87)A;2!B;V]L96%N
M("1O=F5R<FED92`@3W9E<G)I9&4@2&]R9&4@<V5T=&EN9W,_"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<F5F97)R97(@($EN8VQU9&4@=&AE(&-U<G)E;G0@
M<&%G92!A<R!T:&4@<F5F97)R97(@*'5R;#TI/PH@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@2%1-3"!T;R!C<F5A=&4@=&AE(&QI;FLN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<G9I8V5,:6YK*"1T>7!E+"`D87!P
M+"`D;W9E<G)I9&4@/2!F86QS92P@)')E9F5R<F5R(#T@=')U92D*("`@('L*
M("`@("`@("!I9B`H(4AO<F1E.CIS:&]W4V5R=FEC92@D='EP92D@)B8@(21O
M=F5R<FED92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@8V%S92`G:&5L
M<"<Z"B`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YH87-&
M96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@("`@($AO<F1E
M.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H;W)D92<L('1R=64I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1'
M3$]"04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N
M("<O<V5R=FEC97,O:&5L<"\G+"!T<G5E*3L*("`@("`@("`@("`@<F5T=7)N
M(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;6]D=6QE)RP@)&%P<"D["@H@
M("`@("`@(&-A<V4@)W!R;V)L96TG.@H@("`@("`@("`@("!R971U<FX@2&]R
M9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@
M)VAO<F1E)RD@+B`G+W-E<G9I8V5S+W!R;V)L96TN<&AP/W)E='5R;E]U<FP]
M)R`N('5R;&5N8V]D92A(;W)D93HZ<V5L9E5R;"AT<G5E+"!T<G5E+"!T<G5E
M*2DI.PH*("`@("`@("!C87-E("=L;V=O=70G.@H@("`@("`@("`@("!R971U
M<FX@2&]R9&4Z.G5R;"A!=71H.CIA9&1,;V=O=71087)A;65T97)S*"1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O
M;&]G:6XN<&AP)RP@05542%]214%33TY?3$]'3U54*2D["@H@("`@("`@(&-A
M<V4@)VQO9VEN)SH*("`@("`@("`@("`@<F5T=7)N($%U=&@Z.F=E=$QO9VEN
M4V-R965N*"<G+"`D<F5F97)R97(@/R!(;W)D93HZ<V5L9E5R;"AT<G5E*2`Z
M(&YU;&PI.PH*("`@("`@("!C87-E("=O<'1I;VYS)SH*("`@("`@("`@("`@
M9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!I9B`H*"1C;VYF6R=P<F5F<R==
M6R=D<FEV97(G72`A/2`G)RD@)B8@*"1C;VYF6R=P<F5F<R==6R=D<FEV97(G
M72`A/2`G;F]N92<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@2&]R9&4Z
M.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO
M<F1E)RD@+B`G+W-E<G9I8V5S+W!R969S+G!H<#]A<'`])R`N("1A<'`I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D='EP92`@5&AE('1Y<&4@;V8@;&EN:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&QI;FL@:7,@=&\@
M8F4@<VAO=VXN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H;W=397)V:6-E*"1T
M>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@:68@
M*&5M<'1Y*"1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)'1Y<&5=*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!S=VET
M8V@@*"1C;VYF6R=M96YU)UU;)VQI;FMS)UU;)'1Y<&5=*2!["B`@("`@("`@
M8V%S92`G86QL)SH*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@
M(&-A<V4@)VYE=F5R)SH*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH*("`@
M("`@("!C87-E("=A=71H96YT:6-A=&5D)SH*("`@("`@("`@("`@<F5T=7)N
M("AB;V]L*4%U=&@Z.F=E=$%U=&@H*3L*"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&1R:79E<B!P87)A;65T97)S(&9O<B!T
M:&4@<W!E8VEF:65D(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI
M>&5D("1B86-K96YD("!4:&4@8F%C:V5N9"!S>7-T96T@*&4N9RX@)W!R969S
M)RP@)V-A=&5G;W)I97,G+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`G8V]N=&%C=',G*2!B96EN9R!U<V5D+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!4:&4@=7-E9"!C;VYF:6=U<F%T:6]N(&%R<F%Y('=I;&P@
M8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)&)A8VME
M;F1=+B!)9B!A;B!A<G)A>2!G971S('!A<W-E9"P@:70@=VEL;`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!B92`D8V]N9ELD:V5Y,5U;)&ME>3)=
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@("!4:&4@='EP92!O9B!D
M<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I
M=F5R0V]N9FEG*"1B86-K96YD+"`D='EP92`]("=S<6PG*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@)&,@/2!N=6QL.PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D8F%C:V5N9"DI('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@("`D8R`]($AO
M<F1E7T%R<F%Y.CIG971%;&5M96YT*"1C;VYF+"`D8F%C:V5N9"D["B`@("`@
M("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF6R1B86-K96YD72DI('L*("`@("`@
M("`@("`@)&,@/2`D8V]N9ELD8F%C:V5N9%T["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-?;G5L;"@D8RD@)B8@:7-S970H)&-;)W!A<F%M<R==*2D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;F9;)'1Y<&5=*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y7VUE<F=E*"1C;VYF6R1T>7!E72P@)&-;
M)W!A<F%M<R==*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D8ULG<&%R86US)UT["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!I<W-E="@D8V]N9ELD='EP95TI(#\@)&-O
M;F9;)'1Y<&5=(#H@87)R87DH*3L*("`@('T*"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!61E,@9')I=F5R('!A<F%M971E<G,@9F]R('1H92!S<&5C
M:69I960@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@5D93('-Y<W1E;2!N86UE("AE+F<N("=I;6%G97,G+"`G9&]C
M=6UE;G1S)RD*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&)E:6YG('5S
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@
M=&AE(%9&4R!P87)A;65T97)S.R!T:&4@5D93(&1R:79E<B!I;B`G='EP92<*
M("`@("`J("`@("`@("`@("`@("`@(&%N9"!T:&4@8V]N;F5C=&EO;B!P87)A
M;65T97)S(&EN("=P87)A;7,G+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9716
M1E-#;VYF:6<H)&YA;64I"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*
M("`@("`@("!I9B`H(6ES<V5T*"1C;VYF6R1N86UE75LG='EP92==*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")9;W4@;75S
M="!C;VYF:6=U<F4@82!61E,@8F%C:V5N9"XB*2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)&-O;F9;)&YA;65=6R=T>7!E)UT@/3T@)VAO<F1E)RD@>PH@
M("`@("`@("`@("`D=F9S(#T@)&-O;F9;)W9F<R==.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1V9G,@/2`D8V]N9ELD;F%M95T["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'9F<ULG='EP92==(#T]("=S<6PG*2!["B`@("`@
M("`@("`@("1V9G-;)W!A<F%M<R==(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I
M9R@D;F%M92P@)W-Q;"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V
M9G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@86QL(&YE8V5S
M<V%R>2!P87)A;65T97)S(&9O<B!A(&1R:79E<B!C;VYF:6=U<F%T:6]N"B`@
M("`@*B!A<F4@<V5T(&%N9"!T:')O=W,@82!F871A;"!E<G)O<B!W:71H(&$@
M9&5T86EL960@97AP;&%I;F%T:6]N"B`@("`@*B!H;W<@=&\@9FEX('1H:7,L
M(&EF('-O;65T:&EN9R!I<R!M:7-S:6YG+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2!W
M:71H(&%L;"!P87)A;65T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("`@(%1H92!K97D@;F%M92`H:6X@=&AE(&-O;F9I9W5R871I;VX@87)R
M87DI(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&1R
M:79E<BX*("`@("`J($!P87)A;2!A<G)A>2`D9FEE;&1S("`@("!!;B!A<G)A
M>2!W:71H(&UA;F1A=&]R>2!P87)A;65T97(@;F%M97,@9F]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!D<FEV97(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@("`@5&AE(&-L96%R('1E>'0@;F%M92!O
M9B!T:&4@9')I=F5R+B!)9B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!S<&5C:69I960L('1H92!A<'!L:6-A=&EO;B!N86UE('=I;&P@
M8F4@=7-E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@("`@("!4:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE('1H870@<VAO=6QD(&-O;G1A:6X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&5S92!S971T:6YG<RX*("`@
M("`J($!P87)A;2!S=')I;F<@)'9A<FEA8FQE("!4:&4@;F%M92!O9B!T:&4@
M8V]N9FEG=7)A=&EO;B!V87)I86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M87-S97)T1')I=F5R0V]N9FEG*"1P87)A;7,L("1D<FEV97(L("1F:65L9',L
M("1N86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEL92`]("=C;VYF+G!H<"<L("1V87)I86)L92`]("<D8V]N9B<I"B`@
M("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+R\@1&]N
M)W0@9V5N97)A=&4@82!F871A;"!E<G)O<B!I9B!W92!F86EL(&1U<FEN9R!O
M<B!B969O<F4*("`@("`@("`O+R!296=I<W1R>2!I;G-T86YT:6%T:6]N+@H@
M("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@("`@("`@("`D;F%M
M92`](&ES<V5T*"1R96=I<W1R>2D@/R`D<F5G:7-T<GDM/F=E=$%P<"@I(#H@
M)UMU;FMN;W=N72<["B`@("`@("`@?0H@("`@("`@("1F:6QE<F]O="`](&ES
M<V5T*"1R96=I<W1R>2D@/R`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G*2`Z
M("<G.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I('Q\("%C;W5N
M="@D<&%R86US*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ
M<F%I<V5%<G)O<B@*("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B3F\@8V]N
M9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(I+"`D
M;F%M92D@+B`B7&Y<;B(@+@H@("`@("`@("`@("`@("`@<W!R:6YT9BA?*")4
M:&4@9FEL92`E<R!S:&]U;&0@8V]N=&%I;B!S;VUE("5S('-E='1I;F=S+B(I
M+`H@("`@("`@("`@("`@("`@("`@("1F:6QE<F]O="`N("<O8V]N9FEG+R<@
M+B`D9FEL92P*("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"(E<ULG)7,G
M75LG<&%R86US)UTB+"`D=F%R:6%B;&4L("1D<FEV97(I*2DL"B`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@9F]R96%C:"`H)&9I96QD<R!A<R`D9FEE;&0I('L*("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&%R86US6R1F:65L9%TI*2!["B`@("`@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<B@*("`@("`@("`@("`@
M("`@("`@("!S<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF
M:65D(&EN("5S(&-O;F9I9W5R871I;VXN(BDL("1F:65L9"P@)&YA;64I("X@
M(EQN7&XB("X*("`@("`@("`@("`@("`@("`@("!S<')I;G1F*%\H(E1H92!F
M:6QE("5S('-H;W5L9"!C;VYT86EN(&$@)7,@<V5T=&EN9RXB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)&9I;&5R;V]T("X@)R]C;VYF:6<O)R`N("1F
M:6QE+`H@("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"(E<ULG)7,G
M75LG<&%R86US)UU;)R5S)UTB+"`D=F%R:6%B;&4L("1D<FEV97(L("1F:65L
M9"DI*2P*("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A('-E<W-I;VXM:60M:69I960@=F5R<VEO;B!O9B`D=7)I
M+@H@("`@("H@268@82!F=6QL(%523"!I<R!R97%U97-T960L(&%L;"!P87)A
M;65T97(@<V5P87)A=&]R<R!G970@8V]N=F5R=&5D('1O"B`@("`@*B`B)B(L
M(&]T:&5R=VES92!T;R`B)F%M<#LB+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5R:2`@("`@("`@("`@("`@5&AE(%5222!T;R!B92!M;V1I9FEE
M9"X*("`@("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@("`@("`@("`@1V5N
M97)A=&4@82!F=6QL("AH='1P.B\O<V5R=F5R+W!A=&@O*0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!54DPN"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D87!P96YD7W-E<W-I;VX@(#`@/2!O;FQY(&EF(&YE961E
M9"P@,2`](&%L=V%Y<RP@+3$@/0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!N979E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(%523"!W:71H('1H92!S97-S:6]N(&ED(&%P<&5N9&5D("AI
M9B!N965D960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<FPH)'5R:2P@)&9U
M;&P@/2!F86QS92P@)&%P<&5N9%]S97-S:6]N(#T@,"P@)&9O<F-E7W-S;"`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D9F]R8V5?<W-L*2!["B`@("`@
M("`@("`@("1F=6QL(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M9G5L;"D@>PH@("`@("`@("`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R>2P@
M)&)R;W=S97(["@H@("`@("`@("`@("`O*B!3=&]R92!C;VYN96-T:6]N('!A
M<F%M971E<G,@:6X@;&]C86P@=F%R:6%B;&5S+B`J+PH@("`@("`@("`@("`D
M<V5R=F5R7VYA;64@/2`D8V]N9ELG<V5R=F5R)UU;)VYA;64G73L*("`@("`@
M("`@("`@)'-E<G9E<E]P;W)T(#T@)&-O;F9;)W-E<G9E<B==6R=P;W)T)UT[
M"@H@("`@("`@("`@("`D<')O=&]C;VP@/2`G:'1T<"<["B`@("`@("`@("`@
M(&EF("@D8V]N9ELG=7-E7W-S;"==(#T](#$I('L*("`@("`@("`@("`@("`@
M("1P<F]T;V-O;"`]("=H='1P<R<["B`@("`@("`@("`@('T@96QS96EF("@D
M8V]N9ELG=7-E7W-S;"==(#T](#(@)B8*("`@("`@("`@("`@("`@("`@("`@
M("1B<F]W<V5R+3YU<VEN9U-33$-O;FYE8W1I;VXH*2D@>PH@("`@("`@("`@
M("`@("`@)'!R;W1O8V]L(#T@)VAT='!S)SL*("`@("`@("`@("`@?2!E;'-E
M:68@*"1C;VYF6R=U<V5?<W-L)UT@/3T@,RD@>PH@("`@("`@("`@("`@("`@
M)'-E<G9E<E]P;W)T(#T@)R<["B`@("`@("`@("`@("`@("!I9B`H)&9O<F-E
M7W-S;"D@>PH@("`@("`@("`@("`@("`@("`@("1P<F]T;V-O;"`]("=H='1P
M<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($EF('5S:6YG(&YO;BUS=&%N9&%R9"!P;W)T<RP@861D('1H92!P
M;W)T('1O('1H92!54DPN("HO"B`@("`@("`@("`@(&EF("@A96UP='DH)'-E
M<G9E<E]P;W)T*2`F)@H@("`@("`@("`@("`@("`@*"@H)'!R;W1O8V]L(#T]
M("=H='1P)RD@)B8@*"1S97)V97)?<&]R="`A/2`X,"DI('Q\"B`@("`@("`@
M("`@("`@("`@*"@D<')O=&]C;VP@/3T@)VAT='!S)RD@)B8@*"1S97)V97)?
M<&]R="`A/2`T-#,I*2DI('L*("`@("`@("`@("`@("`@("1S97)V97)?;F%M
M92`N/2`G.B<@+B`D<V5R=F5R7W!O<G0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J(%-T;W)E('1H92!W96)R;V]T(&EN(&$@;&]C86P@=F%R:6%B
M;&4N("HO"B`@("`@("`@("`@("1W96)R;V]T(#T@)')E9VES=')Y+3YG970H
M)W=E8G)O;W0G*3L*"B`@("`@("`@("`@("1U<FP@/2`D<')O=&]C;VP@+B`G
M.B\O)R`N("1S97)V97)?;F%M93L*("`@("`@("`@("`@:68@*'-U8G-T<B@D
M=7)I+"`P+"`Q*2`A/2`G+R<I('L*("`@("`@("`@("`@("`@(&EF("AS=6)S
M='(H)'=E8G)O;W0L("TQ*2`]/2`G+R<I('L*("`@("`@("`@("`@("`@("`@
M("`D=7)L("X]("1W96)R;V]T("X@)'5R:3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5R;"`N/2`D=V5B<F]O="`N
M("<O)R`N("1U<FD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=7)L("X]("1U<FD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@)'5R
M:3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG8V]N
M9B==6R=S97-S:6]N)UU;)W5S95]O;FQY7V-O;VMI97,G72D@)B8*("`@("`@
M("`@("`@*"@D87!P96YD7W-E<W-I;VX@/3T@,2D@?'P*("`@("`@("`@("`@
M("@H)&%P<&5N9%]S97-S:6]N(#T](#`I("8F"B`@("`@("`@("`@("`@(6ES
M<V5T*"1?0T]/2TE%6W-E<W-I;VY?;F%M92@I72DI*2D@>PH@("`@("`@("`@
M("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL('-E<W-I;VY?;F%M
M92@I+"!S97-S:6]N7VED*"DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F
M=6QL*2!["B`@("`@("`@("`@("\J(%=E(&YE960@=&\@<G5N('1H92!R97!L
M86-E('1W:6-E+"!B96-A=7-E('=E(&]N;'D@8V%T8V@@979E<GD*("`@("`@
M("`@("`@("H@<V5C;VYD(&UA=&-H+B`J+PH@("`@("`@("`@("!R971U<FX@
M<')E9U]R97!L86-E*&%R<F%Y*"<O*#T_+BH_*29A;7`[*"XJ/STI+R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R\H/3\N*C\I
M)F%M<#LH+BH_/2DO)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R0Q)B0R)RP@)'5R;"D["B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T
M8V@H)R\]+BHF86UP.RXJ/2\G+"`D=7)L*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'5R;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M:'1M;&5N=&ET:65S*"1U<FPI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S97-S:6]N+6ED+6EF:65D('9E<G-I;VX@;V8@
M)'5R:2P@=7-I;F<@=&AE(&-U<G)E;G0*("`@("`J(&%P<&QI8V%T:6]N)W,@
M=V5B<F]O="!S971T:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5R:2`@("`@("`@("`@("`@5&AE(%5222!T;R!B92!M;V1I9FEE9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1F=6QL("`@("`@("`@("`@1V5N97)A=&4@
M82!F=6QL("AH='1P.B\O<V5R=F5R+W!A=&@O*0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!54DPN"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D87!P96YD7W-E<W-I;VX@(#`@/2!O;FQY(&EF(&YE961E9"P@,2`]
M(&%L=V%Y<RP@+3$@/0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N979E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('5R;"!W:71H('1H92!S97-S:6]N(&ED(&%P<&5N9&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A<'!L:6-A=&EO;E5R;"@D=7)I+"`D9G5L;"`](&9A
M;'-E+"`D87!P96YD7W-E<W-I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@D
M9G5L;"D@>PH@("`@("`@("`@("!R971U<FX@2&]R9&4Z.G5R;"@D=7)I+"`D
M9G5L;"P@)&%P<&5N9%]S97-S:6]N*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("AS=6)S='(H)'5R:2P@,"P@,2D@(3T@)R\G*2!["B`@("`@("`@("`@("1W
M96)R;V]T(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<I
M.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1W96)R;V]T+"`M,2D@(3T@)R\G
M*2!["B`@("`@("`@("`@("`@("`D=V5B<F]O="`N/2`G+R<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'5R:2`]("1W96)R;V]T("X@)'5R:3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!(;W)D93HZ=7)L*"1U<FDL("1F=6QL
M+"`D87!P96YD7W-E<W-I;VXI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A;B!E>'1E<FYA;"!L:6YK('!A<W-E9"!T:')O=6=H('1H92!D97)E
M9F5R<F5R('1O('-T<FEP('-E<W-I;VX*("`@("`J($E$<R!F<F]M('1H92!R
M969E<G)E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("!4
M:&4@97AT97)N86P@55),('1O(&QI;FL@=&\N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D=&%G("!)9B!T<G5E+"!A(&-O;7!L971E(#QA/B!T86<@:7,@<F5T
M=7)N960L(&]N;'D@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!U
M<FP@;W1H97)W:7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8V]R<F5C="!L:6YK('1O('1H92!D97)E9F5R<F5R('-C<FEP="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AT97)N86Q5<FPH)'5R;"P@)'1A9R`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7T-/3TM)15MS97-S:6]N
M7VYA;64H*5TI*2!["B`@("`@("`@("`@("1E>'0@/2`D=7)L.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1E>'0@/2!(;W)D93HZ=7)L*"1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<O<V5R=FEC97,O9V\N<&AP
M)RP@=')U92P@+3$I.PH*("`@("`@("`@("`@+RH@5V4@;75S="!M86ME('-U
M<F4@=&AE<F4@87)E(&YO("9A;7`G<R!I;B!T:&4@55),+B`J+PH@("`@("`@
M("`@("`D=7)L(#T@<')E9U]R97!L86-E*&%R<F%Y*"<O*#T_+BH_*29A;7`[
M*"XJ/STI+R<L("<O*#T_+BH_*29A;7`[*"XJ/STI+R<I+"`G)#$F)#(G+"`D
M=7)L*3L*("`@("`@("`@("`@)&5X="`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M97AT+"`G=7)L)RP@)'5R;"D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&%G
M*2!["B`@("`@("`@("`@("1E>'0@/2!(;W)D93HZ;&EN:R@D97AT+"`D=7)L
M+"`G)RP@)U]B;&%N:R<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&5X
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!54DP@=&\@8F4@
M=7-E9"!F;W(@9&]W;FQO861I;F<L('1H870@=&%K97,@:6YT;R!A8V-O=6YT
M(&%N>0H@("`@("H@<W!E8VEA;"!B<F]W<V5R('%U:7)K<R`H:2YE+B!)12=S
M(&)R;VME;B!F:6QE;F%M92!H86YD;&EN9RDN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M92!O9B!T:&4@9&]W
M;FQO860@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("!!
M;GD@861D:71I;VYA;"!P87)A;65T97)S(&YE961E9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)'5R;"`@("`@("!4:&4@55),('1O(&%L=&5R+B!)9B!N;VYE
M('!A<W-E9"!I;BP@=VEL;"!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@9FEL92`G=FEE=RYP:'`G(&QO8V%T960@:6X@=&AE(&-U
M<G)E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!M;V1U;&4G
M<R!B87-E(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&1O=VYL;V%D(%523"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&]W
M;FQO8615<FPH)&9I;&5N86UE+"`D<&%R86US(#T@87)R87DH*2P@)'5R;"`]
M(&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1B<F]W<V5R.PH*("`@("`@
M("`D:&]R9&5?=7)L(#T@9F%L<V4["@H@("`@("`@(&EF("AI<U]N=6QL*"1U
M<FPI*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@
M("`@("1U<FP@/2!5=&EL.CIA9&1087)A;65T97(H2&]R9&4Z.G5R;"@D<F5G
M:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]D
M;W=N;&]A9"\G*2P@)VUO9'5L92<L("1R96=I<W1R>2T^9V5T07!P*"DI.PH@
M("`@("`@("`@("`D:&]R9&5?=7)L(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@("\J($%D9"!P87)A;65T97)S+B`J+PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=V4@87)E('5S:6YG('1H92!D969A=6QT($AO<F1E(&1O=VYL;V%D(&QI
M;FLL(&%D9"!T:&4*("`@("`@("`@*B!F:6QE;F%M92!T;R!T:&4@96YD(&]F
M('1H92!54DPN($%L=&AO=6=H(&YO="!N96-E<W-A<GD@9F]R"B`@("`@("`@
M("H@;6%N>2!B<F]W<V5R<RP@=&AI<R!S:&]U;&0@86QL;W<@979E<GD@8G)O
M=W-E<B!T;R!D;W=N;&]A9`H@("`@("`@("`J(&-O<G)E8W1L>2X@*B\*("`@
M("`@("!I9B`H)&AO<F1E7W5R;"D@>PH@("`@("`@("`@("`D=7)L(#T@571I
M;#HZ861D4&%R86UE=&5R*"1U<FPL("=F;B<L("<O)R`N(')A=W5R;&5N8V]D
M92@D9FEL96YA;64I*3L*("`@("`@("!](&5L<V5I9B`H)&)R;W=S97(M/FAA
M<U%U:7)K*"=B<F5A:U]D:7-P;W-I=&EO;E]F:6QE;F%M92<I*2!["B`@("`@
M("`@("`@("\J(%-O;64@8G)O=W-E<G,@=VEL;"!O;FQY(&]B=&%I;B!T:&4@
M9FEL96YA;64@8V]R<F5C=&QY"B`@("`@("`@("`@("`J(&EF('1H92!E>'1E
M;G-I;VX@:7,@=&AE(&QA<W0@87)G=6UE;G0@:6X@=&AE('%U97)Y"B`@("`@
M("`@("`@("`J('-T<FEN9R!A;F0@<F5S="!O9B!T:&4@9FEL96YA;64@87!P
M96%R<R!I;B!T:&4*("`@("`@("`@("`@("H@4$%42%])3D9/(&5L96UE;G0N
M("HO"B`@("`@("`@("`@("1F:6QE;F%M92`](')A=W5R;&5N8V]D92@D9FEL
M96YA;64I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!W96)S97)V97(@240N
M("HO"B`@("`@("`@("`@("1S97)V97(@/2!(;W)D93HZ=V5B4V5R=F5R240H
M*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@;F%M92!A;F0@97AT96YS:6]N
M(&]F('1H92!F:6QE+B`@07!A8VAE(#(@9&]E<PH@("`@("`@("`@("`@*B!.
M3U0@<W5P<&]R="!0051(7TE.1D\@:6YF;W)M871I;VX@8F5I;F<@<&%S<V5D
M('1O('1H90H@("`@("`@("`@("`@*B!02%`@;6]D=6QE(&)Y(&1E9F%U;'0L
M('-O(&1I<V%B;&4@=&AA=`H@("`@("`@("`@("`@*B!F=6YC=&EO;F%L:71Y
M+B`J+PH@("`@("`@("`@("!I9B`H*"1S97)V97(@(3T@)V%P86-H93(G*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R<G!O<R@D9FEL96YA
M;64L("<N)RDI*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G+R<@
M+B!P<F5G7W)E<&QA8V4H)R]<+B\G+"`G)3)%)RP@<W5B<W1R*"1F:6QE;F%M
M92P@,"P@)'!O<RDI.PH@("`@("`@("`@("`@("`@("`@("1E>'0@/2!S=6)S
M='(H)&9I;&5N86UE+"`D<&]S*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G+R<@+B`D9FEL96YA;64[
M"B`@("`@("`@("`@("`@("`@("`@)&5X="`]("<G.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\J($5N=&5R('1H92!0051(7TE.1D\@
M:6YF;W)M871I;VXN("HO"B`@("`@("`@("`@("`@("!I9B`H*"1P;W,@/2!S
M=')P;W,H)'5R;"P@)S\G*2DI('L*("`@("`@("`@("`@("`@("`@("`D=7)L
M(#T@<W5B<W1R*"1U<FPL(#`L("1P;W,I("X@)&YA;64@+B!S=6)S='(H)'5R
M;"P@)'!O<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1U<FP@+CT@)&YA;64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J($%P<&5N9"!T:&4@97AT96YS
M:6]N+"!I9B!I="!E>&ES=',N("HO"B`@("`@("`@("`@(&EF("@H)'-E<G9E
M<B`]/2`G87!A8VAE,B<I('Q\("%E;7!T>2@D97AT*2D@>PH@("`@("`@("`@
M("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G9FY?97AT
M)RP@)R\G("X@)&9I;&5N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1U<FP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&%N(&%N8VAO<B!T86<@=VET:"!T:&4@<F5L979A;G0@<&%R86UE
M=&5R<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@("`@
M5&AE(&9U;&P@55),('1O(&)E(&QI;FME9"!T;RX*("`@("`J($!P87)A;2!S
M=')I;F<@)'1I=&QE("`@("`@5&AE(&QI;FL@=&ET;&4O9&5S8W)I<'1I;VXN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@("`@(%1H92!#4U,@8VQA
M<W,@;V8@=&AE(&QI;FLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G970@
M("`@(%1H92!W:6YD;W<@=&%R9V5T('1O('!O:6YT('1O+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VYC;&EC:R`@("!*879A4V-R:7!T(&%C=&EO;B!F;W(@
M=&AE("=O;F-L:6-K)R!E=F5N="X*("`@("`J($!P87)A;2!S=')I;F<@)'1I
M=&QE,B`@("`@5&AE(&QI;FL@=&ET;&4@*'1O;VQT:7`I("AD97!R96-A=&5D
M("T@:G5S=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!U<V4@
M)'1I=&QE*2X*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5S<VME>2`@5&AE
M(&%C8V5S<R!K97D@=&\@=7-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R
M:6)U=&5S("!!;GD@;W1H97(@;F%M92]V86QU92!P86ER<R!T;R!A9&0@=&\@
M=&AE(#QA/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T86<N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D97-C87!E("`@(%=H971H97(@=&\@
M97-C87!E('-P96-I86P@8VAA<F%C=&5R<R!I;B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&ET;&4@871T<FEB=71E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"`\82!H<F5F/B!T86<N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI;FLH)'5R;"P@)'1I=&QE(#T@)R<L
M("1C;&%S<R`]("<G+"`D=&%R9V5T(#T@)R<L("1O;F-L:6-K(#T@)R<L"B`@
M("`@("`@("`@("`@("`@("1T:71L93(@/2`G)RP@)&%C8V5S<VME>2`]("<G
M+"`D871T<FEB=71E<R`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("1E
M<V-A<&4@/2!T<G5E*0H@("`@>PH@("`@("`@('-T871I8R`D8VAA<G-E=#L*
M("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D
M8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E;7!T>2@D=&ET;&4R*2D@>PH@("`@("`@("`@("`D=&ET;&4@
M/2`D=&ET;&4R.PH@("`@("`@('T*"B`@("`@("`@)')E="`]("(\82!H<F5F
M/5PB)'5R;%PB(CL*("`@("`@("!I9B`H(65M<'1Y*"1O;F-L:6-K*2D@>PH@
M("`@("`@("`@("`D<F5T("X]("(@;VYC;&EC:SU<(B1O;F-L:6-K7"(B.PH@
M("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1C;&%S<RDI('L*("`@("`@
M("`@("`@)')E="`N/2`B(&-L87-S/5PB)&-L87-S7"(B.PH@("`@("`@('T*
M("`@("`@("!I9B`H(65M<'1Y*"1T87)G970I*2!["B`@("`@("`@("`@("1R
M970@+CT@(B!T87)G970]7"(D=&%R9V5T7"(B.PH@("`@("`@('T*("`@("`@
M("!I9B`H(65M<'1Y*"1T:71L92DI('L*("`@("`@("`@("`@:68@*"1E<V-A
M<&4I('L*("`@("`@("`@("`@("`@("1T:71L92`](&YL,F)R*$!H=&UL<W!E
M8VEA;&-H87)S*$!H=&UL<W!E8VEA;&-H87)S*"1T:71L92P@14Y47U%53U1%
M4RP@)&-H87)S970I+"!%3E1?455/5$53+"`D8VAA<G-E="DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1R970@+CT@)R!T:71L93TB)R`N("1T:71L
M92`N("<B)SL*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D86-C97-S
M:V5Y*2D@>PH@("`@("`@("`@("`D<F5T("X]("<@86-C97-S:V5Y/2(G("X@
M:'1M;'-P96-I86QC:&%R<R@D86-C97-S:V5Y*2`N("<B)SL*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1N86UE(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`D<F5T("X]("<@)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)&YA;64I("X@)STB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E
M*2`N("<B)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`B)')E=#XB.PH@
M("`@?0H*("`@("\J*@H@("`@("H@57-E<R!$3TT@5&]O;'1I<',@=&\@9&ES
M<&QA>2!T:&4@)W1I=&QE)R!A='1R:6)U=&4@9F]R"B`@("`@*B!(;W)D93HZ
M;&EN:R@I(&-A;&QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R
M;"`@("`@("`@5&AE(&9U;&P@55),('1O(&)E(&QI;FME9"!T;PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W1A='5S("`@("!4:&4@2F%V85-C<FEP="!M;W5S
M92UO=F5R('-T<FEN9PH@("`@("H@0'!A<F%M('-T<FEN9R`D8VQA<W,@("`@
M("!4:&4@0U-3(&-L87-S(&]F('1H92!L:6YK"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T87)G970@("`@(%1H92!W:6YD;W<@=&%R9V5T('1O('!O:6YT('1O
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VYC;&EC:R`@("!*879A4V-R:7!T
M(&%C=&EO;B!F;W(@=&AE("=O;F-L:6-K)R!E=F5N="X*("`@("`J($!P87)A
M;2!S=')I;F<@)'1I=&QE("`@("`@5&AE(&QI;FL@=&ET;&4@*'1O;VQT:7`I
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-C97-S:V5Y("!4:&4@86-C97-S
M(&ME>2!T;R!U<V4N"B`@("`@*B!`<&%R86T@87)R87D@("1A='1R:6)U=&5S
M($%N>2!O=&AE<B!N86UE+W9A;'5E('!A:7)S('1O(&%D9"!T;R!T:&4@/&$^
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('1A9RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@/&$@:')E9CX@=&%G
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YK5&]O;'1I<"@D=7)L+"`D<W1A
M='5S(#T@)R<L("1C;&%S<R`]("<G+"`D=&%R9V5T(#T@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D;VYC;&EC:R`]("<G+"`D=&ET;&4@/2`G)RP@
M)&%C8V5S<VME>2`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&%T
M=')I8G5T97,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D8VAA
M<G-E=#L*("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@
M("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D=&ET;&4I*2!["B`@("`@("`@("`@("1T
M:71L92`]("<F;'0[<')E)F=T.R<@+B!P<F5G7W)E<&QA8V4H87)R87DH)R]<
M;B\G+"`G+R@H/SPA/&)R*5QS>S$L?2@_/"%<+SXI*2]E;2<L("<O/&)R(%PO
M/CQB<B!<+SXO)RP@)R\\8G(@7"\^+R<I+"!A<G)A>2@G)RP@)W-T<E]R97!E
M870H(B9N8G-P.R(L('-T<FQE;B@B)#$B*2DG+"`G)FQT.V)R("\F9W0[("9L
M=#MB<B`O)F=T.R<L("<F;'0[8G(@+R9G=#LG*2P@;FPR8G(H0&AT;6QS<&5C
M:6%L8VAA<G,H0&AT;6QS<&5C:6%L8VAA<G,H)'1I=&QE+"!%3E1?455/5$53
M+"`D8VAA<G-E="DL($5.5%]154]415,L("1C:&%R<V5T*2DI("X@)R9L=#LO
M<')E)F=T.R<["B`@("`@("`@?0H@("`@("`@(')E='5R;B!(;W)D93HZ;&EN
M:R@D=7)L+"`D=&ET;&4L("1C;&%S<RP@)'1A<F=E="P@)&]N8VQI8VLL(&YU
M;&PL("1A8V-E<W-K97DL("1A='1R:6)U=&5S+"!F86QS92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%N8VAO<B!S97%U96YC92!W:71H
M('1H92!R96QE=F%N="!P87)A;65T97)S(&9O<B!A('=I9&=E=`H@("`@("H@
M=VET:"!A8V-E<W-K97D@86YD('1E>'0N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7)L("`@
M("`@5&AE(&9U;&P@55),('1O(&)E(&QI;FME9"!T;RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1T:71L92`@("!4:&4@;&EN:R!T:71L92]D97-C<FEP=&EO
M;BX*("`@("`J($!P87)A;2!S=')I;F<@("1C;&%S<R`@("!4:&4@0U-3(&-L
M87-S(&]F('1H92!L:6YK"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&%R9V5T
M("`@5&AE('=I;F1O=R!T87)G970@=&\@<&]I;G0@=&\N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D;VYC;&EC:R`@2F%V85-C<FEP="!A8W1I;VX@9F]R('1H
M92`G;VYC;&EC:R<@979E;G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&ET
M;&4R("`@5&AE(&QI;FL@=&ET;&4@*'1O;VQT:7`I("AD97!R96-A=&5D("T@
M:G5S="!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D=&ET
M;&4I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YO8VAE8VL@($1O;B=T(&-H
M96-K(&EF('1H92!A8V-E<W,@:V5Y(&%L<F5A9'D@:&%S(&)E96X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!U<V5D+B!$969A=6QT<R!T;R!F
M86QS92`H/2!C:&5C:RDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!F=6QL(#QA(&AR968^5&ET;&4\+V$^('-E<75E;F-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!W:61G970H)'5R;"P@)'1I=&QE(#T@)R<L("1C;&%S
M<R`]("=W:61G970G+"`D=&%R9V5T(#T@)R<L"B`@("`@("`@("`@("`@("`@
M("`@)&]N8VQI8VL@/2`G)RP@)'1I=&QE,B`]("<G+"`D;F]C:&5C:R`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1I=&QE,BDI('L*("`@
M("`@("`@("`@)'1I=&QE(#T@)'1I=&QE,CL*("`@("`@("!]"@H@("`@("`@
M("1A:R`]($AO<F1E.CIG971!8V-E<W-+97DH)'1I=&QE+"`D;F]C:&5C:RD[
M"@H@("`@("`@(')E='5R;B!(;W)D93HZ;&EN:R@D=7)L+"`G)RP@)&-L87-S
M+"`D=&%R9V5T+"`D;VYC;&EC:RP@)R<L("1A:RD@+B!(;W)D93HZ:&EG:&QI
M9VAT06-C97-S2V5Y*"1T:71L92P@)&%K*2`N("<\+V$^)SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!S97-S:6]N+6ED+6EF:65D('9E<G-I
M;VX@;V8@)%-#4DE05%].04U%(')E<W`N("102%!?4T5,1BX*("`@("`J"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D<V-R:7!T7W!A<F%M<R!);F-L=61E('-C
M<FEP="!P87)A;65T97)S(&QI:V4@455%4EE?4U1224Y'(&%N9"!0051(7TE.
M1D\_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;F]C86-H92`@("`@("!);F-L
M=61E(&$@;F]C86-H92!P87)A;65T97(@:6X@=&AE(%523#\*("`@("`J($!P
M87)A;2!B;V]L96%N("1F=6QL("`@("`@("`@(%)E='5R;B!A(&9U;&P@55),
M/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5Q=65S=&5D
M(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5L9E5R;"@D<V-R:7!T7W!A
M<F%M<R`](&9A;'-E+"`D;F]C86-H92`]('1R=64L("1F=6QL(#T@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("1F;W)C95]S<VP@/2!F86QS92D*("`@
M('L*("`@("`@("!I9B`H<W5B<W1R*'!H<%]S87!I7VYA;64H*2P@,"P@,RD@
M/3T@)V-G:2<I('L*("`@("`@("`@("`@+R\@5VAE;B!U<VEN9R!#1TD@4$A0
M+"!30U))4%1?3D%-12!M87D@8V]N=&%I;B!T:&4@<&%T:"!T;PH@("`@("`@
M("`@("`O+R!T:&4@4$A0(&)I;F%R>2!I;G-T96%D(&]F('1H92!S8W)I<'0@
M8F5I;F<@<G5N.R!U<V4*("`@("`@("`@("`@+R\@4$A07U-%3$8@:6YS=&5A
M9"X*("`@("`@("`@("`@)'5R;"`]("1?4T525D526R=02%!?4T5,1B==.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U<FP@/2!I<W-E="@D7U-%
M4E9%4ELG4T-225!47TY!344G72D@/PH@("`@("`@("`@("`@("`@)%]315)6
M15);)U-#4DE05%].04U%)UT@.@H@("`@("`@("`@("`@("`@)%]315)615);
M)U!(4%]314Q&)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-C<FEP=%]P
M87)A;7,I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D7U-%4E9%4ELG4$%4
M2%])3D9/)UTI*2!["B`@("`@("`@("`@("`@("`D=7)L("X]("1?4T525D52
M6R=0051(7TE.1D\G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1?4T525D526R=1545265]35%))3D<G72DI('L*("`@("`@("`@
M("`@("`@("1U<FP@+CT@)S\G("X@)%]315)615);)U%515)97U-44DE.1R==
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=7)L(#T@2&]R
M9&4Z.G5R;"@D=7)L+"`D9G5L;"P@,"P@)&9O<F-E7W-S;"D["@H@("`@("`@
M(&EF("@D;F]C86-H92D@>PH@("`@("`@("`@("!R971U<FX@571I;#HZ;F]C
M86-H955R;"@D=7)L*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'5R;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@8V]R<F5C=&QY+7!A=&AE9"!L:6YK('1O(&%N(&EM86=E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-R8R`@(%1H92!I;6%G
M92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86QT("`@5&5X="!D97-C
M<FEB:6YG('1H92!I;6%G92X*("`@("`J($!P87)A;2!M:7AE9"`@)&%T='(@
M($%N>2!A9&1I=&EO;F%L(&%T=')I8G5T97,@9F]R('1H92!I;6%G92!T86<N
M($-A;B!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@82!P<F4M8G5I
M;'0@<W1R:6YG(&]R(&%N(&%R<F%Y(&]F(&ME>2]V86QU92!P86ER<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@=&AA="!W:6QL(&)E(&%S<V5M8FQE
M9"!A;F0@:'1M;"UE;F-O9&5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER
M("`@5&AE(')O;W0@9W)A<&AI8W,@9&ER96-T;W)Y+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9G5L;"!I;6%G92!T86<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&EM9R@D<W)C+"`D86QT(#T@)R<L("1A='1R(#T@)R<L
M("1D:7(@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D8VAA<G-E=#L*
M("`@("`@("!I9B`H(6ES<V5T*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D
M8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@8G)O=W-E<B!D;V5S(&YO="!S=7!P;W)T(&EM86=E<RP@<VEM
M<&QY(')E='5R;B!T:&4@04Q4('1E>'0N("HO"B`@("`@("`@:68@*"$D1TQ/
M0D%,4ULG8G)O=W-E<B==+3YH87-&96%T=7)E*"=I;6%G97,G*2D@>PH@("`@
M("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H)&%L="P@14Y47T-/
M35!!5"P@)&-H87)S970I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@;F\@
M9&ER96-T;W)Y(&AA<R!B965N('-P96-I9FEE9"P@9V5T(&ET(&9R;VT@=&AE
M(')E9VES=')Y+B`J+PH@("`@("`@(&EF("@D9&ER(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@("1D:7(@
M/2`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"D["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!A(&1I<F5C=&]R>2!H87,@8F5E;B!P<F]V:61E9"P@<')E<&5N
M9"!I="!T;R!T:&4@:6UA9V4@<V]U<F-E+B`J+PH@("`@("`@(&EF("@A96UP
M='DH)&1I<BDI('L*("`@("`@("`@("`@)'-R8R`]("1D:7(@+B`G+R<@+B`D
M<W)C.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@86QL(&]F('1H92!T
M86<@871T<FEB=71E<RX@*B\*("`@("`@("`D871T<FEB=71E<R`](&%R<F%Y
M*"=S<F,G(#T^("1S<F,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M86QT)R`]/B`D86QT*3L*("`@("`@("!I9B`H:7-?87)R87DH)&%T='(I*2![
M"B`@("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?;65R9V4H)&%T=')I
M8G5T97,L("1A='1R*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1A
M='1R:6)U=&5S6R=T:71L92==*2D@>PH@("`@("`@("`@("`D871T<FEB=71E
M<ULG=&ET;&4G72`]("<G.PH@("`@("`@('T*"B`@("`@("`@)&EM9R`]("<\
M:6UG)SL*("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D871T<FEB
M=71E(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:6UG("X]("<@)R`N("1A
M='1R:6)U=&4@+B`G/2(G("X@*"1A='1R:6)U=&4@/3T@)W-R8R<@/R`D=F%L
M=64@.B!`:'1M;'-P96-I86QC:&%R<R@D=F%L=64L($5.5%]#3TU0050L("1C
M:&%R<V5T*2D@+B`G(B<["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@
M=7-E<B!S=7!P;&EE9"!A('!R92UB=6EL="!S=')I;F<@;V8@871T<FEB=71E
M<RP@861D('1H870N("HO"B`@("`@("`@:68@*&ES7W-T<FEN9R@D871T<BD@
M)B8@(65M<'1Y*"1A='1R*2D@>PH@("`@("`@("`@("`D:6UG("X]("<@)R`N
M("1A='1R.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N('1H92!C;&]S
M960@:6UA9V4@=&%G+B`J+PH@("`@("`@(')E='5R;B`D:6UG("X@)R`O/B<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!L;V-A=&EO
M;B!O9B!T:&4@<WES=&5M('1E;7!O<F%R>2!D:7)E8W1O<GDN($EF(&$@<W!E
M8VEF:6,*("`@("`J('-E='1I;F<@8V%N;F]T(&)E(&9O=6YD+"!I="!D969A
M=6QT<R!T;R`O=&UP+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!
M(&1I<F5C=&]R>2!N86UE('1H870@8V%N(&)E('5S960@9F]R('1E;7`@9FEL
M97,N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!O
M;F4@8V]U;&0@;F]T(&)E(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971496UP1&ER*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@("\J($EF(&]N92!H87,@8F5E;B!S<&5C:69I8V%L;'D@<V5T+"!T:&5N
M('5S92!T:&%T("HO"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG=&UP9&ER
M)UTI*2!["B`@("`@("`@("`@("1T;7`@/2`D8V]N9ELG=&UP9&ER)UT["B`@
M("`@("`@?0H*("`@("`@("`O*B!.97AT+"!T<GD@571I;#HZ9V5T5&5M<$1I
M<B@I+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@
M("`D=&UP(#T@571I;#HZ9V5T5&5M<$1I<B@I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@:70@:7,@<W1I;&P@96UP='DL('=E(&AA=F4@9F%I;&5D+"!S
M;R!R971U<FX@9F%L<V4["B`@("`@("`@("H@;W1H97)W:7-E(')E='5R;B!T
M:&4@9&ER96-T;W)Y(&1E=&5R;6EN960N("HO"B`@("`@("`@<F5T=7)N(&5M
M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D=&UP.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0W)E871E<R!A('1E;7!O<F%R>2!F:6QE;F%M92!F;W(@=&AE(&QI9F5T
M:6UE(&]F('1H92!S8W)I<'0L(&%N9`H@("`@("H@*&]P=&EO;F%L;'DI(')E
M9VES=&5R<R!I="!T;R!B92!D96QE=&5D(&%T(')E<75E<W0@<VAU=&1O=VXN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9FEX("`@4')E9FEX
M('1O(&UA:V4@=&AE('1E;7!O<F%R>2!N86UE(&UO<F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(')E8V]G;FEZ86)L92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1D96QE=&4@($1E;&5T92!T:&4@9FEL92!A="!T:&4@96YD
M(&]F('1H92!R97%U97-T/PH@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER("`@
M("`@1&ER96-T;W)Y('1O(&-R96%T92!T:&4@=&5M<&]R87)Y(&9I;&4@:6XN
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<V5C=7)E("!)9B!D96QE=&EN9R!F
M:6QE+"!S:&]U;&0@=V4@<V5C=7)E;'D@9&5L971E('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@9FEL93\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@(%)E='5R;G,@=&AE(&9U;&P@<&%T:"UN86UE('1O('1H
M92!T96UP;W)A<GD@9FEL92!O<@H@("`@("H@("`@("`@("`@("`@("`@("!F
M86QS92!I9B!A('1E;7!O<F%R>2!F:6QE(&-O=6QD(&YO="!B92!C<F5A=&5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1FEL92@D<')E9FEX(#T@
M)TAO<F1E)RP@)&1E;&5T92`]('1R=64L("1D:7(@/2`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("1S96-U<F4@/2!F86QS92D*("`@('L*("`@("`@
M("!I9B`H96UP='DH)&1I<BD@?'P@(6ES7V1I<B@D9&ER*2D@>PH@("`@("`@
M("`@("`D9&ER(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!5=&EL.CIG971496UP1FEL92@D<')E9FEX+"`D9&5L
M971E+"`D9&ER+"`D<V5C=7)E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T
M87)T<R!O=71P=70@8V]M<')E<W-I;VXL(&EF(')E<75E<W1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]M<')E<W-/=71P=70H*0H@("`@>PH@("`@("`@
M('-T871I8R`D<W1A<G1E9#L*"B`@("`@("`@:68@*&ES<V5T*"1S=&%R=&5D
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O
M*B!#;VUP<F5S<R!O=71P=70@:68@<F5Q=65S=&5D(&%N9"!P;W-S:6)L92X@
M*B\*("`@("`@("!I9B`H)$=,3T)!3%-;)V-O;F8G75LG8V]M<')E<W-?<&%G
M97,G72`F)@H@("`@("`@("`@("`A)$=,3T)!3%-;)V)R;W=S97(G72T^:&%S
M475I<FLH)V)U9V=Y7V-O;7!R97-S:6]N)RD@)B8*("`@("`@("`@("`@(2AB
M;V]L*6EN:5]G970H)WIL:6(N;W5T<'5T7V-O;7!R97-S:6]N)RD@)B8*("`@
M("`@("`@("`@(2AB;V]L*6EN:5]G970H)WIE;F1?86-C96QE<F%T;W(N8V]M
M<')E<W-?86QL)RD@)B8*("`@("`@("`@("`@:6YI7V=E="@G;W5T<'5T7VAA
M;F1L97(G*2`A/2`G;V)?9WIH86YD;&5R)RD@>PH@("`@("`@("`@("!I9B`H
M;V)?9V5T7VQE=F5L*"DI('L*("`@("`@("`@("`@("`@(&]B7V5N9%]C;&5A
M;B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]B7W-T87)T*"=O8E]G
M>FAA;F1L97(G*3L*("`@("`@("!]"@H@("`@("`@("1S=&%R=&5D(#T@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@;W5T<'5T
M(&-O;7!R97-S:6]N(&-A;B!B92!U<V5D+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!O=71P=70@8V]M<')E<W-I;VX@8V%N(&)E
M('5S960L(&9A;'-E(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@86QL
M;W=/=71P=71#;VUP<F5S<VEO;B@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]"<F]W<V5R+G!H<"<["B`@("`@("`@)&)R;W=S97(@/2`F
M0G)O=W-E<CHZ<VEN9VQE=&]N*"D["@H@("`@("`@("\J(%1U<FX@;V9F(&-O
M;7!R97-S:6]N(&9O<B!B=6=G>2!B<F]W<V5R<RX@*B\*("`@("`@("!I9B`H
M)&)R;W=S97(M/FAA<U%U:7)K*"=B=6=G>5]C;VUP<F5S<VEO;B<I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`H:6YI7V=E="@G>FQI8BYO=71P=71?8V]M<')E<W-I;VXG*2`]/2`G
M)R`F)@H@("`@("`@("`@("`@("`@:6YI7V=E="@G>F5N9%]A8V-E;&5R871O
M<BYC;VUP<F5S<U]A;&PG*2`]/2`G)R`F)@H@("`@("`@("`@("`@("`@:6YI
M7V=E="@G;W5T<'5T7VAA;F1L97(G*2`A/2`G;V)?9WIH86YD;&5R)RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!796(@<V5R=F5R(&)E
M:6YG('5S960N"B`@("`@*B!02%`@<W1R:6YG(&QI<W0@8G5I;'0@9G)O;2!T
M:&4@4$A0("=C;VYF:6=U<F4G('-C<FEP="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!W96(@<V5R=F5R(&ED96YT:69I8V%T:6]N('-T<FEN
M9RX*("`@("`J(#QP<F4^"B`@("`@*B`G86]L<V5R=F5R)R`]($%/3"!397)V
M97(*("`@("`J("=A<&%C:&4Q)R`@(#T@07!A8VAE(#$N>`H@("`@("H@)V%P
M86-H93(G("`@/2!!<&%C:&4@,BYX"B`@("`@*B`G8V%U9&EU;2<@("`]($-A
M=61I=6T*("`@("`J("=C9VDG("`@("`@(#T@56YK;F]W;B!S97)V97(@+2!0
M2%`@8G5I;'0@87,@0T=)('!R;V=R86T*("`@("`J("=C;&DG("`@("`@(#T@
M0V]M;6%N9"!,:6YE($EN=&5R9F%C92!B=6EL9`H@("`@("H@)V5M8F5D)R`@
M("`@/2!%;6)E9&1E9"!02%`*("`@("`J("=I<V%P:2<@("`@(#T@6F5U<R!)
M4T%020H@("`@("H@)VUI;'1E<B<@("`@/2!-:6QT97(*("`@("`J("=N<V%P
M:2<@("`@(#T@3E-!4$D*("`@("`J("=P:'1T<&0G("`@(#T@4$A45%!$"B`@
M("`@*B`G<&DS=V5B)R`@("`](%!I,U=E8@H@("`@("H@)W)O>&5N)R`@("`@
M/2!2;WAE;B]0:6ME"B`@("`@*B`G<V5R=FQE="<@("`](%-E<G9L970*("`@
M("`J("=T:'1T<&0G("`@(#T@=&AT='!D"B`@("`@*B`G='5X)R`@("`@("`]
M(%1U>`H@("`@("H@)W=E8FIA;65S)R`@/2!796)J86UE<PH@("`@("H@/"]P
M<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N('=E8E-E<G9E<DE$*"D*("`@('L*
M("`@("`@("`D<V5R=F5R(#T@<&AP7W-A<&E?;F%M92@I.PH*("`@("`@("!I
M9B`H)'-E<G9E<B`]/2`G87!A8VAE)RD@>PH@("`@("`@("`@("!R971U<FX@
M)V%P86-H93$G.PH@("`@("`@('T@96QS96EF("@H)'-E<G9E<B`]/2`G87!A
M8VAE,F9I;'1E<B<I('Q\"B`@("`@("`@("`@("`@("`@("@D<V5R=F5R(#T]
M("=A<&%C:&4R:&%N9&QE<B<I*2!["B`@("`@("`@("`@(')E='5R;B`G87!A
M8VAE,B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1S
M97)V97(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@/&QI;FL^('1A9W,@9F]R('1H92!#4U,@<W1Y;&5S:&5E=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2`D87!P("!4:&4@2&]R
M9&4@87!P;&EC871I;VXH<RDN"B`@("`@*B!`<&%R86T@;6EX960@)'1H96UE
M("`@("`@(%1H92!T:&5M92!T;R!U<V4[('-P96-I9GD@86X@96UP='D@=F%L
M=64@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T<FEE
M=F4@=&AE('1H96UE(&9R;VT@=7-E<B!P<F5F97)E;F-E<RP@86YD"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&9O<B!N;R!T:&5M
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1I;FAE<FET("`@26YH97)I="!(
M;W)D92UW:61E($-34S\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M/&QI;FL^('1A9W,@9F]R($-34R!S='EL97-H965T<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<W1Y;&5S:&5E=$QI;FLH)&%P<',@/2!N=6QL+"`D=&AE;64@
M/2`G)RP@)&EN:&5R:70@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@D=&AE
M;64@/3T]("<G("8F(&ES<V5T*"1'3$]"04Q36R=P<F5F<R==*2D@>PH@("`@
M("`@("`@("`D=&AE;64@/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H
M)W1H96UE)RD["B`@("`@("`@?0H*("`@("`@("`D<G1L(#T@:7-S970H)$=,
M3T)!3%-;)VYL<R==6R=R=&PG75LD1TQ/0D%,4ULG;&%N9W5A9V4G75TI.PH@
M("`@("`@("1C<W,@/2!A<G)A>2@I.PH*("`@("`@("`D=&AE;65S7V9S(#T@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE;65S9G,G+"`G:&]R9&4G
M*3L*("`@("`@("!I9B`H)&EN:&5R:70I('L*("`@("`@("`@("`@)'1H96UE
M<U]U<FD@/2!(;W)D93HZ=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H
M)W1H96UE<W5R:2<L("=H;W)D92<I+"!F86QS92P@+3$I.PH@("`@("`@("`@
M("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O<V-R965N+F-S<R<["B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1H96UE*2`F)@H@("`@("`@("`@("`@("`@
M9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O)R`N("1T:&5M92`N("<O<V-R
M965N+F-S<R<I*2!["B`@("`@("`@("`@("`@("`D8W-S6UT@/2`D=&AE;65S
M7W5R:2`N("<O)R`N("1T:&5M92`N("<O<V-R965N+F-S<R<["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D<G1L*2!["B`@("`@("`@("`@("`@
M("`D8W-S6UT@/2`D=&AE;65S7W5R:2`N("<O<G1L+F-S<R<["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1T:&5M92D@)B8*("`@("`@("`@("`@("`@
M("`@("!F:6QE7V5X:7-T<R@D=&AE;65S7V9S("X@)R\G("X@)'1H96UE("X@
M)R]R=&PN8W-S)RDI('L*("`@("`@("`@("`@("`@("`@("`D8W-S6UT@/2`D
M=&AE;65S7W5R:2`N("<O)R`N("1T:&5M92`N("<O<G1L+F-S<R<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A96UP='DH)&%P<',I*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)&%P<',I*2!["B`@("`@("`@("`@("`@("`D87!P<R`](&%R<F%Y*"1A
M<'!S*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&%P
M<',@87,@)&%P<"D@>PH@("`@("`@("`@("`@("`@:68@*"1I;FAE<FET("8F
M("1A<'`@/3T@)VAO<F1E)RD@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T:&5M
M97-?9G,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T:&5M97-F<R<L
M("1A<'`I.PH@("`@("`@("`@("`@("`@)'1H96UE<U]U<FD@/2!(;W)D93HZ
M=7)L*"1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H96UE<W5R:2<L("1A
M<'`I+"!F86QS92P@+3$I.PH@("`@("`@("`@("`@("`@:68@*&9I;&5?97AI
M<W1S*"1T:&5M97-?9G,@+B`G+W-C<F5E;BYC<W,G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@)R]S8W)E96XN8W-S
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)'1H96UE*2`F)@H@("`@("`@("`@("`@("`@("`@(&9I;&5?97AI<W1S
M*"1T:&5M97-?9G,@+B`G+R<@+B`D=&AE;64@+B`G+W-C<F5E;BYC<W,G*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@
M)R\G("X@)'1H96UE("X@)R]S8W)E96XN8W-S)SL*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("!I9B`H)')T;"D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&AE;65S7V9S("X@)R]R=&PN8W-S
M)RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-S<UM=(#T@)'1H96UE
M<U]U<FD@+B`G+W)T;"YC<W,G.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&5M92D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@9FEL95]E>&ES=',H)'1H96UE<U]F<R`N("<O
M)R`N("1T:&5M92`N("<O<G1L+F-S<R<I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1C<W-;72`]("1T:&5M97-?=7)I("X@)R\G("X@)'1H96UE("X@
M)R]R=&PN8W-S)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1H=&UL
M(#T@)R<["B`@("`@("`@9F]R96%C:"`H)&-S<R!A<R`D8W-S7VQI;FLI('L*
M("`@("`@("`@("`@)&AT;6P@+CT@)SQL:6YK(&AR968](B<@+B`D8W-S7VQI
M;FL@+B`G(B!R96P](G-T>6QE<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@
M+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!)12!03D<@=')A
M;G-P87)E;F-Y(&-O9&4@:68@;F5E9&5D+B`J+PH@("`@("`@(&EF("@D1TQ/
M0D%,4ULG8G)O=W-E<B==+3YH87-1=6ER:R@G<&YG7W1R86YS<&%R96YC>2<I
M("8F"B`@("`@("`@("`@("1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G
M86QP:&%?9FEL=&5R)RDI('L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU
M<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G:G-U<FDG+"`G:&]R9&4G
M*2`N("<O86QP:&%);6%G94QO861E<BYP:'`G+"!T<G5E+"`M,2D["B`@("`@
M("`@("`@("1H=&UL("X]("<\<W1Y;&4@='EP93TB=&5X="]C<W,B/B!I;6<@
M>R!B96AA=FEO<CH@=7)L*"(G("X@)'5R;"`N("<B*3L@?2`\+W-T>6QE/B<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D(&)R;W=S97(@<W!E8VEF:6,@
M<W1Y;&5S:&5E=',@:68@;F5E9&5D+B`J+PH@("`@("`@(&EF("@D1TQ/0D%,
M4ULG8G)O=W-E<B==+3YI<T)R;W=S97(H)VUS:64G*2`F)B`D1TQ/0D%,4ULG
M8G)O=W-E<B==+3YG971-86IO<B@I(#P@-RD@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/&QI;FL@:')E9CTB)R`N("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M970H)W1H96UE<W5R:2<L("=H;W)D92<I("X@)R]I939?;W)?;&5S<RYC<W,B
M(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X="]C<W,B("\^)R`N(")<;B([
M"B`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==+3YG9710;&%T
M9F]R;2@I(#T]("=M86,G*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G
M/&QI;FL@:')E9CTB)R`N("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1H
M96UE<W5R:2<L("=H;W)D92<I("X@)R]I935M86,N8W-S(B!R96P](G-T>6QE
M<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@+B`B7&XB.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D1TQ/0D%,4ULG8G)O=W-E<B==
M+3YI<T)R;W=S97(H)V]P97)A)RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQL:6YK(&AR968](B<@+B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T
M:&5M97-U<FDG+"`G:&]R9&4G*2`N("<O;W!E<F$N8W-S(B!R96P](G-T>6QE
M<VAE970B('1Y<&4](G1E>'0O8W-S(B`O/B<@+B`B7&XB.PH@("`@("`@('T*
M("`@("`@("!I9B`H)$=,3T)!3%-;)V)R;W=S97(G72T^:7-"<F]W<V5R*"=M
M;WII;&QA)RD@)B8*("`@("`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G72T^
M9V5T36%J;W(H*2`^/2`U("8F"B`@("`@("`@("`@('!R96=?;6%T8V@H)R]R
M=CHH+BHI7"DO)RP@)$=,3T)!3%-;)V)R;W=S97(G72T^9V5T06=E;G13=')I
M;F<H*2P@)')E=FES:6]N*2`F)@H@("`@("`@("`@("`D<F5V:7-I;VY;,5T@
M/#T@,2XT*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;&EN:R!H<F5F/2(G
M("X@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO
M<F1E)RD@+B`G+VUO>C$T+F-S<R(@<F5L/2)S='EL97-H965T(B!T>7!E/2)T
M97AT+V-S<R(@+SXG("X@(EQN(CL*("`@("`@("!]"B`@("`@("`@:68@*'-T
M<G!O<RAS=')T;VQO=V5R*"1'3$]"04Q36R=B<F]W<V5R)UTM/F=E=$%G96YT
M4W1R:6YG*"DI+"`G<V%F87)I)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<\;&EN:R!H<F5F/2(G("X@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F=E="@G=&AE;65S=7)I)RP@)VAO<F1E)RD@+B`G+W-A9F%R:2YC<W,B
M(')E;#TB<W1Y;&5S:&5E="(@='EP93TB=&5X="]C<W,B("\^)R`N(")<;B([
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971S(&$@8W5S=&]M('-E<W-I;VX@:&%N9&QE<B!U<"P@
M:68@=&AE<F4@:7,@;VYE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971U<%-E
M<W-I;VY(86YD;&5R*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@(&EN:5]S970H)W5R;%]R97=R:71E<BYT86=S)RP@,"D["B`@("`@
M("`@:68@*"%E;7!T>2@D8V]N9ELG<V5S<VEO;B==6R=U<V5?;VYL>5]C;V]K
M:65S)UTI*2!["B`@("`@("`@("`@(&EN:5]S970H)W-E<W-I;VXN=7-E7V]N
M;'E?8V]O:VEE<R<L(#$I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;VYF
M6R=C;V]K:64G75LG9&]M86EN)UTI("8F"B`@("`@("`@("`@("`@("!S=')P
M;W,H)&-O;F9;)W-E<G9E<B==6R=N86UE)UTL("<N)RD@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4V5S<VEO;B!C
M;V]K:65S('=I;&P@;F]T('=O<FL@=VET:&]U="!A($911$X@86YD('=I=&@@
M82!N;VXM96UP='D@8V]O:VEE(&1O;6%I;BXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@('-E<W-I;VY?<V5T7V-O;VMI95]P87)A;7,H)&-O;F9;)W-E
M<W-I;VXG75LG=&EM96]U="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;F9;)V-O;VMI92==6R=P871H)UTL("1C;VYF6R=C;V]K
M:64G75LG9&]M86EN)UTL("1C;VYF6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P
M*3L*("`@("`@("!S97-S:6]N7V-A8VAE7VQI;6ET97(H)&-O;F9;)W-E<W-I
M;VXG75LG8V%C:&5?;&EM:71E<B==*3L*("`@("`@("!S97-S:6]N7VYA;64H
M=7)L96YC;V1E*"1C;VYF6R=S97-S:6]N)UU;)VYA;64G72DI.PH*("`@("`@
M("`D='EP92`]("%E;7!T>2@D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG='EP
M92==*2`_("1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=T>7!E)UT@.B`G;F]N
M92<["@H@("`@("`@(&EF("@D='EP92`]/2`G97AT97)N86PG*2!["B`@("`@
M("`@("`@("1C86QL<R`]("1C;VYF6R=S97-S:6]N:&%N9&QE<B==6R=P87)A
M;7,G73L*("`@("`@("`@("`@<V5S<VEO;E]S971?<V%V95]H86YD;&5R*"1C
M86QL<ULG;W!E;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-A;&QS6R=C;&]S92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-A;&QS6R=R96%D)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V%L;'-;)W=R:71E)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%L;'-;)V1E<W1R
M;WDG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M86QL<ULG9V,G72D["B`@("`@("`@?2!E;'-E:68@*"1T>7!E("$]("=N;VYE
M)RD@>PH@("`@("`@("`@("!G;&]B86P@)%]S97-S:6]N7VAA;F1L97(["B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N
M<&AP)SL*("`@("`@("`@("`@)%]S97-S:6]N7VAA;F1L97(@/2`F4V5S<VEO
M;DAA;F1L97(Z.G-I;F=L971O;B@D8V]N9ELG<V5S<VEO;FAA;F1L97(G75LG
M='EP92==*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D7W-E<W-I;VY?:&%N
M9&QE<BD@)B8*("`@("`@("`@("`@("`@("%I<U]A*"1?<V5S<VEO;E]H86YD
M;&5R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!I;FE?<V5T
M*"=S97-S:6]N+G-A=F5?:&%N9&QE<B<L("=U<V5R)RD["B`@("`@("`@("`@
M("`@("!S97-S:6]N7W-E=%]S879E7VAA;F1L97(H87)R87DH)B1?<V5S<VEO
M;E]H86YD;&5R+"`G;W!E;B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE<BP@)V-L
M;W-E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)B1?<V5S<VEO;E]H86YD;&5R+"`G<F5A9"<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"8D7W-E
M<W-I;VY?:&%N9&QE<BP@)W=R:71E)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)B1?<V5S<VEO;E]H86YD;&5R
M+"`G9&5S=')O>2<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"8D7W-E<W-I;VY?:&%N9&QE<BP@)V=C)RDI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.F9A
M=&%L*%!%05(Z.G)A:7-E17)R;W(H)TAO<F1E(&ES('5N86)L92!T;R!C;W)R
M96-T;'D@<W1A<G0@=&AE(&-U<W1O;2!S97-S:6]N(&AA;F1L97(N)RDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!U;BUU<V5D
M(&%C8V5S<R!K97D@9G)O;2!T:&4@;&%B96P@9VEV96XN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@(%1H92!L86)E;"!T;R!C:&]O
M<V4@86X@86-C97-S(&ME>2!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&YO8VAE8VL@($1O;B=T(&-H96-K(&EF('1H92!A8V-E<W,@:V5Y(&%L<F5A
M9'D@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!U
M<V5D/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!('-I;F=L92!L
M;W=E<B!C87-E(&-H87)A8W1E<B!A8V-E<W,@:V5Y(&]R(&5M<'1Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@<W1R:6YG(&EF(&YO;F4@8V%N(&)E(&9O=6YD
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%C8V5S<TME>2@D;&%B96PL("1N
M;V-H96-K(#T@9F%L<V4L("1S:'5T9&]W;B`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\J(%1H92!A8V-E<W,@:V5Y<R!A;')E861Y('5S960@:6X@=&AI<R!P
M86=E("HO"B`@("`@("`@<W1A=&EC("1?=7-E9"`](&%R<F%Y*"D["@H@("`@
M("`@("\J(%1H92!L86)E;',@86QR96%D>2!U<V5D(&EN('1H:7,@<&%G92`J
M+PH@("`@("`@('-T871I8R`D7VQA8F5L<R`](&%R<F%Y*"D["@H@("`@("`@
M("\J(%-H=71D;W=N(&-A;&P@9F]R('1R86YS;&%T;W)S/R`J+PH@("`@("`@
M(&EF("@D<VAU=&1O=VXI('L*("`@("`@("`@("`@:68@*"%C;W5N="@D7VQA
M8F5L<RDI('L*("`@("`@("`@("`@("`@(')E='5R;CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<V-R:7!T(#T@8F%S96YA;64H)%]315)615);)U!(
M4%]314Q&)UTI.PH@("`@("`@("`@("`D;&%B96QS(#T@87)R87E?:V5Y<R@D
M7VQA8F5L<RD["B`@("`@("`@("`@('-O<G0H)&QA8F5L<RD["B`@("`@("`@
M("`@("1U<V5D(#T@87)R87E?:V5Y<R@D7W5S960I.PH@("`@("`@("`@("!S
M;W)T*"1U<V5D*3L*("`@("`@("`@("`@)')E;6%I;FEN9R`]('-T<E]R97!L
M86-E*"1U<V5D+"!A<G)A>2@I+"`G86)C9&5F9VAI:FML;6YO<'%R<W1U=G=X
M>7HG*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T%C8V5S<R!K
M97D@:6YF;W)M871I;VX@9F]R("<@+B`D<V-R:7!T+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G57-E9"!L
M86)E;',Z("<@+B!I;7!L;V1E*"<L)RP@)&QA8F5L<RDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=5<V5D
M(&ME>7,Z("<@+B!I;7!L;V1E*"<G+"`D=7-E9"DL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&<F5E(&ME
M>7,Z("<@+B`D<F5M86EN:6YG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!5<V4@86-C
M97-S(&ME>7,@870@86QL/R`J+PH@("`@("`@('-T871I8R`D;F]T<W5P<&]R
M=&5D.PH@("`@("`@(&EF("@A:7-S970H)&YO='-U<'!O<G1E9"DI('L*("`@
M("`@("`@("`@)&YO='-U<'!O<G1E9"`]("$D1TQ/0D%,4ULG8G)O=W-E<B==
M+3YH87-&96%T=7)E*"=A8V-E<W-K97DG*2!\?`H@("`@("`@("`@("`@("`@
M(21'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G=VED9V5T7V%C8V5S<VME
M>2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1N;W1S=7!P;W)T960@?'P@
M(7!R96=?;6%T8V@H)R]?*%M!+5IA+7I=*2\G+"`D;&%B96PL("1M871C:"DI
M('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@("`@("`D
M:V5Y(#T@)&UA=&-H6S%=.PH*("`@("`@("`O*B!(87,@=&AI<R!K97D@86QR
M96%D>2!B965N('5S960_("HO"B`@("`@("`@:68@*&ES<V5T*"1?=7-E9%MS
M=')T;VQO=V5R*"1K97DI72D@)B8*("`@("`@("`@("`@(2@D;F]C:&5C:R`F
M)B!I<W-E="@D7VQA8F5L<ULD;&%B96Q=*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@4V%V92!K97D@86YD(&QA
M8F5L+B`J+PH@("`@("`@("1?=7-E9%MS=')T;VQO=V5R*"1K97DI72`]('1R
M=64["B`@("`@("`@)%]L86)E;'-;)&QA8F5L72`]('1R=64["@H@("`@("`@
M(')E='5R;B`D:V5Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1R:7!S(&%N
M(&%C8V5S<R!K97D@9G)O;2!A(&QA8F5L+@H@("`@("H@1F]R(&UU;'1I8GET
M92!C:&%R<V5T('-T<FEN9W,@=&AE(&%C8V5S<R!K97D@9V5T<R!R96UO=F5D
M(&-O;7!L971E;'DL"B`@("`@*B!O=&AE<G=I<V4@;VYL>2!T:&4@=6YD97)S
M8V]R92!G971S(')E;6]V960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;&%B96P@(%1H92!L86)E;"!C;VYT86EN:6YG(&%N(&%C8V5S<R!K97DN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L86)E;"!W:71H
M('1H92!A8V-E<W,@:V5Y(&)E:6YG('-T<FEP<&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S=')I<$%C8V5S<TME>2@D;&%B96PI"B`@("!["B`@("`@("`@
M:6YC;'5D95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]N;',N<&AP)SL*
M("`@("`@("`D;75L=&EB>71E(#T@:7-S970H)$=,3T)!3%-;)VYL<R==6R=M
M=6QT:6)Y=&4G75M.3%,Z.F=E=$-H87)S970H=')U92E=*3L*"B`@("`@("`@
M<F5T=7)N('!R96=?<F5P;&%C92@G+U\H6T$M6F$M>ETI+R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;75L=&EB>71E("8F('!R96=?;6%T8V@H
M)R];7'@X,"U<>&9F72\G+"`D;&%B96PI(#\@)R<@.B`G7#$G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&QA8F5L*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($AI9VAL:6=H=',@86X@86-C97-S(&ME>2!I;B!A(&QA8F5L+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@("`@5&AE(&QA
M8F5L('1O('1O(&AI9VAL:6=H="!T:&4@86-C97-S(&ME>2!I;BX*("`@("`J
M($!P87)A;2!S=')I;F<@)&%C8V5S<TME>2`@5&AE(&%C8V5S<R!K97D@=&\@
M:&EG:&QI9VAT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M2%1-3"!V97)S:6]N(&]F('1H92!L86)E;"!W:71H('1H92!A8V-E<W,@:V5Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@:&EG:&QI9VAT960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&AI9VAL:6=H=$%C8V5S<TME>2@D;&%B96PL("1A8V-E
M<W-+97DI"B`@("!["B`@("`@("`@)'-T<FEP<&5D7VQA8F5L(#T@2&]R9&4Z
M.G-T<FEP06-C97-S:V5Y*"1L86)E;"D["@H@("`@("`@(&EF("AE;7!T>2@D
M86-C97-S2V5Y*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T<FEP<&5D7VQA
M8F5L.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=N
M;',G75LG;75L=&EB>71E)UU;3DQ3.CIG971#:&%R<V5T*'1R=64I72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1S=')I<'!E9%]L86)E;"`N("<H)R`N("<\
M<W!A;B!C;&%S<STB86-C97-S2V5Y(CXG("X*("`@("`@("`@("`@("`@('-T
M<G1O=7!P97(H)&%C8V5S<TME>2D@+B`G/"]S<&%N/B<@+B`G*2<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"=?
M)R`N("1A8V-E<W-+97DL("<\<W!A;B!C;&%S<STB86-C97-S2V5Y(CXG("X@
M)&%C8V5S<TME>2`N("<\+W-P86X^)RP@)&QA8F5L*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!A<'!R;W!R:6%T92`B
M86-C97-S:V5Y(B!A;F0@(G1I=&QE(B!A='1R:6)U=&5S(&9O<B!A;B!(5$U,
M"B`@("`@*B!T86<@86YD('1H92!G:79E;B!L86)E;"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("`@5&AE('1I=&QE(&]F(&%N($A4
M34P@96QE;65N=`H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YO8VAE8VL@($1O
M;B=T(&-H96-K(&EF('1H92!A8V-E<W,@:V5Y(&%L<F5A9'D@:&%S(&)E96X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!U<V5D/PH@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&ET;&4L(&%N9"!I9B!A<'!R
M;W!R:6%T92P@=&AE(&%C8V5S<VME>2!A='1R:6)U=&5S"B`@("`@*B`@("`@
M("`@("`@("`@("`@9F]R('1H92!E;&5M96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971!8V-E<W-+97E!;F14:71L92@D;&%B96PL("1N;V-H96-K(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)&%K(#T@2&]R9&4Z.F=E=$%C8V5S<TME
M>2@D;&%B96PL("1N;V-H96-K*3L*("`@("`@("`D871T<FEB=71E<R`]("=T
M:71L93TB)R`N($AO<F1E.CIS=')I<$%C8V5S<TME>2@D;&%B96PI.PH@("`@
M("`@(&EF("@A96UP='DH)&%K*2D@>PH@("`@("`@("`@("`D871T<FEB=71E
M<R`N/2!S<')I;G1F*%\H(B`H06-C97-S:V5Y("5S*2(I+"`D86LI.PH@("`@
M("`@("`@("`D871T<FEB=71E<R`N/2`G(B!A8V-E<W-K97D](B<@+B`D86L[
M"B`@("`@("`@?0H@("`@("`@("1A='1R:6)U=&5S("X]("<B)SL*("`@("`@
M("!R971U<FX@)&%T=')I8G5T97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@;&%B96P@96QE;65N="!I;F-L=61I;F<@86X@86-C97-S(&ME
M>2!F;W(@=7-A9V4@:6X@8V]N:G5C=&EO;@H@("`@("H@=VET:"!A(&9O<FT@
M9FEE;&0N(%5S97(@<')E9F5R96YC97,@<F5G87)D:6YG(&%C8V5S<R!K97ES
M(&%R92!R97-P96-T960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9F]R("`@(%1H92!F;W)M(&9I96QD)W,@:60@871T<FEB=71E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!L86)E;"!T97AT+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D86L@("`@(%1H92!A8V-E<W,@:V5Y('1O('5S92X@
M268@;G5L;"!A(&YE=R!A8V-E<W,@:V5Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=VEL;"!B92!G96YE<F%T960N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!H=&UL(&-O9&4@9F]R('1H92!L86)E;"!E;&5M
M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!L86)E;"@D9F]R+"`D;&%B96PL
M("1A:R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@
M("`@("`@:68@*&ES7VYU;&PH)&%K*2D@>PH@("`@("`@("`@("`D86L@/2!(
M;W)D93HZ9V5T06-C97-S:V5Y*"1L86)E;"P@,2D["B`@("`@("`@?0H@("`@
M("`@("1L86)E;"`]($AO<F1E.CIH:6=H;&EG:'1!8V-E<W-+97DH)&QA8F5L
M+"`D86LI.PH*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&QA8F5L(&9O<CTB
M)7,B)7,^)7,\+VQA8F5L/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<BP*("`@("`@("`@("`@("`@("`@("`@("`A96UP='DH)&%K*2`_("<@86-C
M97-S:V5Y/2(G("X@)&%K("X@)R(G(#H@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)&QA8F5L*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E9&ER96-T
M<R!T;R!T:&4@;6%I;B!(;W)D92!L;V=I;B!P86=E(&]N(&%U=&AE;G1I8V%T
M:6]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AE;G1I8V%T
M:6]N1F%I;'5R95)E9&ER96-T*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T-,22YP:'`G.PH@("`@("`@(&EF("A(;W)D95]#3$DZ.G)U
M;FYI;F=&<F]M0TQ)*"DI('L*("`@("`@("`@("`@)&-L:2`]("9(;W)D95]#
M3$DZ.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D8VQI+3YF871A;"A?*")9
M;W4@87)E(&YO="!A=71H96YT:6-A=&5D+B(I*3L*("`@("`@("!]"@H@("`@
M("`@("1U<FP@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T
M)RP@)VAO<F1E)RD@+B`G+VQO9VEN+G!H<"<["B`@("`@("`@)'5R;"`](%5T
M:6PZ.F%D9%!A<F%M971E<B@D=7)L+"!A<G)A>2@G=7)L)R`]/B!(;W)D93HZ
M<V5L9E5R;"AT<G5E*2P@)VYO<VED96)A<B<@/3X@,2DL(&YU;&PL(&9A;'-E
M*3L*("`@("`@("`D=7)L(#T@075T:#HZ861D3&]G;W5T4&%R86UE=&5R<R@D
M=7)L*3L*("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@2&]R9&4Z.G5R
M;"@D=7)L+"!T<G5E*2D["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%!R;W9I9&5S(&$@<W1A;F1A<F1I<V5D(&9U;F-T:6]N('1O(&-A
M;&P@82!(;W)D92!H;V]K+"!C:&5C:VEN9R!W:&5T:&5R"B`@("`@*B!A(&AO
M;VL@8V]N9FEG(&9I;&4@97AI<W1S(&%N9"!W:&5T:&5R('1H92!F=6YC=&EO
M;B!I='-E;&8@97AI<W1S+B!)9@H@("`@("H@=&AE<V4@='=O(&-O;F1I=&EO
M;G,@87)E(&YO="!S871I<V9I960@:70@=VEL;"!R971U<FX@=&AE('-P96-I
M9FEE9`H@("`@("H@=F%L=64@*&)Y(&1E9F%U;'0@82!014%2(&5R<F]R*2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H;V]K("!4:&4@9G5N8W1I
M;VX@=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`@)&%R9W,@($%N(&%R
M<F%Y(&]F(&%N>2!A<F=U;65N=',@=&\@<&%S<R!T;R!T:&4@:&]O:PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@9G5N8W1I;VXN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<'`@("!)9B!S<&5C:69I960@;&]O:R!F;W(@:&]O:W,@
M:6X@=&AE(&-O;F9I9R!D:7)E8W1O<GD*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@(&]F('1H:7,@87!P+@H@("`@("H@0'!A<F%M(&UI>&5D("1E<G)O
M<B`@5VAA="!T;R!R971U<FX@:68@)&%P<"]C;VYF:6<O:&]O:W,N<&AP(&]R
M("1H;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!D;V5S(&YO="!E
M>&ES="X@268@=&AI<R!I<R!T:&4@<W1R:6YG("=014%27T5R<F]R)PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@82!014%2(&5R<F]R(&]B:F5C="!I
M<R!R971U<FYE9"!I;G-T96%D+"!D971A:6QI;F<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@('1H92!F86EL=7)E+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($5I=&AE<B!T:&4@<F5S=6QT<R!O9B!T:&4@:&]O:R!O<B!0
M14%2(&5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A
M;&Q(;V]K*"1H;V]K+"`D87)G<R`](&%R<F%Y*"DL("1A<'`@/2`G:&]R9&4G
M+"`D97)R;W(@/2`G4$5!4E]%<G)O<B<I"B`@("!["B`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*("`@("`@("!S=&%T:6,@)&AO;VMS7VQO861E9#L*"B`@
M("`@("`@:68@*"%I<W-E="@D:&]O:W-?;&]A9&5D*2D@>PH@("`@("`@("`@
M("!I9B`H9FEL95]E>&ES=',H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@
M)&%P<"D@+B`G+V-O;F9I9R]H;V]K<RYP:'`G*2D@>PH@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A
M<'`I("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@("`@("1H
M;V]K<U]L;V%D960@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)&AO;VMS7VQO861E9"`](&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D:&]O:W-?;&]A9&5D("8F(&9U
M;F-T:6]N7V5X:7-T<R@D:&]O:RDI('L*("`@("`@("`@("`@<F5T=7)N(&-A
M;&Q?=7-E<E]F=6YC7V%R<F%Y*"1H;V]K+"`D87)G<RD["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-?<W1R:6YG*"1E<G)O<BD@)B8@<W1R8VUP*"1E<G)O
M<BP@)U!%05)?17)R;W(G*2`]/2`P*2!["B`@("`@("`@("`@("1E<G)O<B`]
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G2&]O:R`E<R!I;B!A<'!L:6-A
M=&EO;B`E<R!N;W0@8V%L;&5D+B<L("1H;V]K+"`D87!P*2D["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1E<G)O<BP@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<W!E8VEF:65D('!E<FUI<W-I;VX@9F]R('1H92!C=7)R96YT('5S97(N"B`@
M("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!E<FUI<W-I;VX@($$@<&5R;6ES<VEO;BP@8W5R<F5N
M=&QY(&]N;'D@)VUA>%]B;&]C:W,G+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!V86QU92!O9B!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VXN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I
M;VXI"B`@("!["B`@("`@("`@9VQO8F%L("1P97)M<SL*"B`@("`@("`@:68@
M*"$D<&5R;7,M/F5X:7-T<R@G:&]R9&4Z)R`N("1P97)M:7-S:6]N*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1A
M;&QO=V5D(#T@)'!E<FUS+3YG971097)M:7-S:6]N<R@G:&]R9&4Z)R`N("1P
M97)M:7-S:6]N*3L*("`@("`@("!I9B`H:7-?87)R87DH)&%L;&]W960I*2![
M"B`@("`@("`@("`@('-W:71C:"`H)'!E<FUI<W-I;VXI('L*("`@("`@("`@
M("`@8V%S92`G;6%X7V)L;V-K<R<Z"B`@("`@("`@("`@("`@("`D86QL;W=E
M9"`](&%R<F%Y7W)E9'5C92@D86QL;W=E9"P@8W)E871E7V9U;F-T:6]N*"<D
M82P@)&(G+"`G<F5T=7)N(&UA>"@D82P@)&(I.R<I+"`P*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&%L;&]W960["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O<')E9G,N<&AP````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3$T,S`@,3`U,34T,S0Q-#$@,#(P,3(V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+VQI8B]P<F5F<RYP:'`L=B`Q+C$Y+C0N,3`@,C`P-B\P,2\P,2`R,3HR
M.3HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@IF=6YC=&EO;B!H86YD;&5?<VAO=W-U;6UA<GES96QE
M8W0H)'5P9&%T960I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@)'-H;W=?
M<W5M;6%R:65S(#T@571I;#HZ9V5T1F]R;41A=&$H)W-H;W=?<W5M;6%R:65S
M)RD["B`@("!I9B`H(6ES7VYU;&PH)'-H;W=?<W5M;6%R:65S*2D@>PH@("`@
M("`@("1P<F5F<RT^<V5T5F%L=64H)W-H;W=?<W5M;6%R:65S)RP@)'-H;W=?
M<W5M;6%R:65S*3L*("`@("`@("`D=7!D871E9"`]('1R=64["B`@("!]"@H@
M("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC=&EO;B!H86YD;&5?=&AE;65S
M96QE8W0H)'5P9&%T960I"GL*("`@(&=L;V)A;"`D<')E9G,["@H@("`@)'1H
M96UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W1H96UE)RD["B`@("!I9B`H(6ES
M7VYU;&PH)'1H96UE*2D@>PH@("`@("`@("1P<F5F<RT^<V5T5F%L=64H)W1H
M96UE)RP@)'1H96UE*3L*("`@("`@("`D=7!D871E9"`]('1R=64["B`@("!]
M"@H@("`@<F5T=7)N("1U<&1A=&5D.PI]"@IF=6YC=&EO;B!H86YD;&5?8V%T
M96=O<GEM86YA9V5M96YT*"1U<&1A=&5D*0I["B`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+U!R969S+T-A=&5G;W)Y36%N86=E<BYP:'`G.PH@("`@)&--86YA
M9V5R(#T@)FYE=R!0<F5F<U]#871E9V]R>4UA;F%G97(H*3L*"B`@("`O*B!!
M;'=A>7,@<V%V92!C;VQO<G,@;V8@86QL(&-A=&5G;W)I97,N("HO"B`@("`D
M8V]L;W)S(#T@87)R87DH*3L*("`@("1C871E9V]R:65S(#T@)&--86YA9V5R
M+3YG970H*3L*("`@(&9O<F5A8V@@*"1C871E9V]R:65S(&%S("1C871E9V]R
M>2D@>PH@("`@("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG971&;W)M1&%T82@G
M8V]L;W)?)R`N(&)A<V4V-%]E;F-O9&4H)&-A=&5G;W)Y*2DI('L*("`@("`@
M("`@("`@)&-O;&]R<ULD8V%T96=O<GE=(#T@)&-O;&]R.PH@("`@("`@('T*
M("`@('T*("`@(&EF("@D8V]L;W(@/2!5=&EL.CIG971&;W)M1&%T82@G8V]L
M;W)?)R`N(&)A<V4V-%]E;F-O9&4H)U]D969A=6QT7R<I*2D@>PH@("`@("`@
M("1C;VQO<G-;)U]D969A=6QT7R==(#T@)&-O;&]R.PH@("`@?0H@("`@:68@
M*"1C;VQO<B`](%5T:6PZ.F=E=$9O<FU$871A*"=C;VQO<E\G("X@8F%S938T
M7V5N8V]D92@G7W5N9FEL961?)RDI*2!["B`@("`@("`@)&-O;&]R<ULG7W5N
M9FEL961?)UT@/2`D8V]L;W(["B`@("!]"B`@("`D8TUA;F%G97(M/G-E=$-O
M;&]R<R@D8V]L;W)S*3L*"B`@("`D86-T:6]N(#T@571I;#HZ9V5T1F]R;41A
M=&$H)V-!8W1I;VXG*3L*("`@("1C871E9V]R>2`](%5T:6PZ.F=E=$9O<FU$
M871A*"=C871E9V]R>2<I.PH*("`@('-W:71C:"`H)&%C=&EO;BD@>PH@("`@
M8V%S92`G861D)SH*("`@("`@("`D8TUA;F%G97(M/F%D9"@D8V%T96=O<GDI
M.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)W)E;6]V92<Z"B`@("`@("`@
M)&--86YA9V5R+3YR96UO=F4H)&-A=&5G;W)Y*3L*("`@("`@("!B<F5A:SL*
M"B`@("!D969A=6QT.@H@("`@("`@("\J(%-A=F4@8G5T=&]N+B`J+PH@("`@
M("`@("1U<&1A=&5D(#T@=')U93L*("`@('T*"B`@("!R971U<FX@)'5P9&%T
M960["GT*"B\J*@H@*B!$;R!A;GET:&EN9R!T:&%T('=E(&YE960@=&\@9&\@
M87,@82!R97-U;'0@;V8@8V5R=&%I;B!P<F5F97)E;F-E<PH@*B!C:&%N9VEN
M9RX*("HO"F9U;F-T:6]N('!R969S7V-A;&QB86-K*"D*>PH@("`@9VQO8F%L
M("1P<F5F<RP@)')E9VES=')Y+"`D;F]T:69I8V%T:6]N+"`D;FQS.PH*("`@
M(&EF("@D<')E9G,M/FES1&ER='DH)VQA;F=U86=E)RD@?'P*("`@("`@("`D
M<')E9G,M/FES1&ER='DH)W-H;W=?<VED96)A<B<I*2!["B`@("`@("`@:68@
M*"1P<F5F<RT^:7-$:7)T>2@G;&%N9W5A9V4G*2D@>PH@("`@("`@("`@("!.
M3%,Z.G-E=$QA;F<H)'!R969S+3YG971686QU92@G;&%N9W5A9V4G*2D["B`@
M("`@("`@("`@($Y,4SHZ<V5T5&5X=&1O;6%I;B@D<F5G:7-T<GDM/F=E=$%P
M<"@I+"`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G*2`N("<O;&]C86QE)RP@
M3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!3=')I;F<Z.G-E=$1E
M9F%U;'1#:&%R<V5T*$Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("!]"@H@
M("`@("`@("1U<FP@/2`D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D
M92<I.PH@("`@("`@(&EF("AS=6)S='(H)'5R;"P@+3$I("$]("<O)RD@>PH@
M("`@("`@("`@("`D=7)L("X]("<O)SL*("`@("`@("!]"B`@("`@("`@)'5R
M;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L("X@)VEN9&5X+G!H<"<L("=U
M<FPG+"!(;W)D93HZ<V5L9E5R;"AT<G5E*2D["B`@("`@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A;65S*2!W:6YD;W<N
M<&%R96YT+F9R86UE<RYL;V-A=&EO;B`](%PG)R`N(&%D9'-L87-H97,H2&]R
M9&4Z.G5R;"@D=7)L+"!T<G5E*2D@+B`G7"<[)RP@)VIA=F%S8W)I<'0G*3L*
M("`@('T*"B`@("!I9B`H)'!R969S+3YI<T1I<G1Y*"=S:61E8F%R7W=I9'1H
M)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"=I9B`H=VEN9&]W
M+G!A<F5N="`F)B!W:6YD;W<N<&%R96YT+F1O8W5M96YT+F=E=$5L96UE;G1"
M>4ED*%PG:&9<)RD@)B8@=VEN9&]W+G!A<F5N="YH;W)D95]M96YU("8F('=I
M;F1O=RYP87)E;G0N:&]R9&5?;65N=2YE>'!A;F1E9%-I9&5B87(N<VAO=VXH
M*2D@=VEN9&]W+G!A<F5N="YD;V-U;65N="YG971%;&5M96YT0GE)9"A<)VAF
M7"<I+F-O;',@/2!W:6YD;W<N<&%R96YT+FAO<F1E7VUE;G4N<G1L(#\@7"<J
M+"<@+B`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I9'1H)RD@+B`G7"<@
M.B!<)R<@+B`D<')E9G,M/F=E=%9A;'5E*"=S:61E8F%R7W=I9'1H)RD@+B`G
M+"I<)SLG+"`G:F%V87-C<FEP="<I.PH@("`@?0H*("`@(&EF("@D<')E9G,M
M/FES1&ER='DH)W1H96UE)RD@?'P*("`@("`@("`D<')E9G,M/FES1&ER='DH
M)VUE;G5?=FEE=R<I('Q\"B`@("`@("`@)'!R969S+3YI<T1I<G1Y*"=M96YU
M7W)E9G)E<VA?=&EM92<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"@G:68@*'=I;F1O=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE;G4I('=I;F1O
M=RYP87)E;G0N9G)A;65S+FAO<F1E7VUE;G4N;&]C871I;VXN<F5L;V%D*"D[
M)RP@)VIA=F%S8W)I<'0G*3L*("`@('T*?0H*+RH@07-S:6=N('9A<FEA8FQE
M<R!F;W(@<V5L96-T(&QI<W1S+B`J+PII9B`H(21P<F5F<RT^:7-,;V-K960H
M)W1I;65Z;VYE)RDI('L*("`@("1T:6UE>F]N95]O<'1I;VYS(#T@)'1Z.PH@
M("`@87)R87E?=6YS:&EF="@D=&EM97IO;F5?;W!T:6]N<RP@7R@B1&5F875L
M="(I*3L*?0II9B`H(21P<F5F<RT^:7-,;V-K960H)VEN:71I86Q?87!P;&EC
M871I;VXG*2D@>PH@("`@9VQO8F%L("1P97)M<SL*"B`@("`D:6YI=&EA;%]A
M<'!L:6-A=&EO;E]O<'1I;VYS(#T@87)R87DH*3L*("`@("1A<'!S(#T@)')E
M9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G86-T:79E)RDI.PH@("`@9F]R96%C
M:"`H)&%P<',@87,@)&$I('L*("`@("`@("!I9B`H9FEL95]E>&ES=',H)')E
M9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)&$I*2`F)@H@("`@("`@("`@("`H
M*"1P97)M<RT^97AI<W1S*"1A*2`F)B`H)'!E<FUS+3YH87-097)M:7-S:6]N
M*"1A+"!!=71H.CIG971!=71H*"DL(%!%4DU37U)%040I('Q\($%U=&@Z.FES
M061M:6XH*2DI('Q\"B`@("`@("`@("`@("`A)'!E<FUS+3YE>&ES=',H)&$I
M*2D@>PH@("`@("`@("`@("`D:6YI=&EA;%]A<'!L:6-A=&EO;E]O<'1I;VYS
M6R1A72`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&$I.PH@("`@("`@('T*
M("`@('T*("`@(&%S;W)T*"1I;FET:6%L7V%P<&QI8V%T:6]N7V]P=&EO;G,I
M.PI]"FEF("@A)'!R969S+3YI<TQO8VME9"@G=&AE;64G*2D@>PH@("`@)'1H
M96UE7V]P=&EO;G,@/2!A<G)A>2@I.PH@("`@)'1H96UE7V)A<V4@/2`D<F5G
M:7-T<GDM/F=E="@G=&AE;65S9G,G+"`G:&]R9&4G*3L*("`@("1D:"`]($!O
M<&5N9&ER*"1T:&5M95]B87-E*3L*("`@(&EF("@A)&1H*2!["B`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"@B5&AE;64@9&ER96-T;W)Y(&-A;B=T(&)E
M(&]P96YE9"(L("=H;W)D92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@
M("!W:&EL92`H*"1D:7(@/2!R96%D9&ER*"1D:"DI("$]/2!F86QS92D@>PH@
M("`@("`@("`@("!I9B`H)&1I<B`]/2`G+B<@?'P@)&1I<B`]/2`G+BXG('Q\
M("$@:7-?9&ER*"1T:&5M95]B87-E+B<O)RXD9&ER*2D@>PH@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&5M95]N86UE(#T@;G5L;#L*("`@("`@("`@("`@0&EN8VQU9&4@)'1H96UE
M7V)A<V4@+B`G+R<@+B`D9&ER("X@)R]I;F9O+G!H<"<["B`@("`@("`@("`@
M(&EF("@A96UP='DH)'1H96UE7VYA;64I*2!["B`@("`@("`@("`@("`@("`D
M=&AE;65?;W!T:6]N<ULD9&ER72`]("1T:&5M95]N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@(&%S;W)T*"1T:&5M95]O<'1I;VYS
M*3L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--
M3"YP:'``````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#0Q-C<R(#$P-3$U-#,T,30Q(#`R,#$V-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*:6YC;'5D95]O
M;F-E("=3>6YC34PO0V]M;6%N9"YP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+U-T871U<RYP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--3"]#
M;VUM86YD+T%L97)T+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+T-O;6UA
M;F0O4WEN8RYP:'`G.PII;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+T9I
M;F%L+G!H<"<["FEN8VQU9&5?;VYC92`G4WEN8TU,+U-Y;F,N<&AP)SL*:6YC
M;'5D95]O;F-E("=3>6YC34PO0F%C:V5N9"YP:'`G.PH*+RHJ"B`J(%1H92!3
M>6YC34Q?4WEN8TAD<B!A;F0@4WEN8TU,7U-Y;F-";V1Y(&-L87-S97,@<')O
M=FED97,*("H@82!3>6YC2&1R(&%N9"!3>6YC0F]D>2!I;B!3>6YC34P@4F5P
M<F5S96YT871I;VX@4')O=&]C;VPL('9E<G-I;VX*("H@,2XQ(#4N,BXR(&%N
M9"`U+C(N,RX@($UO<W0@;V8@=&AE('=O<FL@:7,@<&%S<V5D(&]N('1O"B`J
M(%-Y;F--3%]#;VUM86YD7T%L97)T(&%N9"!3>6YC34Q?0V]M;6%N9%]3>6YC
M+@H@*@H@*B!4:&5R92!A<F4@='=O(&=L;V)A;"!O8FIE8W1S('1H870@87)E
M('5S960@8GD@4WEN8TU,.@H@*B`Q*2`D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.@H@*B`@("!S97-S:6]N(&]B:F5C="!U<V5D('1O(&UA:6YT86EN('1H
M92!S=&%T92!B971W965N('1H92!I;F1I=FED=6%L"B`J("`@(%-Y;F--3"!M
M97-S86=E<RX*("H*("H@,BD@)$=,3T)!3%-;)V)A8VME;F0G70H@*B`@("!"
M86-K96YD('1O(&AA;F1L92!T:&4@8V]M;75N:6-A=&EO;B!W:71H('1H92!D
M871A<W1O<F4N($-U<G)E;G1L>2!T:&4*("H@("`@:&]R9&4@8F%C:V5N9"!I
M<R!T:&4@;VYL>2!B86-K96YD('!R;W9I9&5D+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]3>6YC34PO4WEN8TU,+G!H<"QV(#$N,C$N,3`N,3`@,C`P-B\P
M,2\P,2`R,3HR.#HS-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL<R`\86UI;&QS
M0'!Y<F%M:60V+F-O;3X*("H@0&%U=&AO<B`@2V%R<W1E;B!&;W5R;6]N="`\
M9F]U<FUO;G1`9VUX+F1E/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]N=&5N=$AA;F1L97(@
M>PH*("`@("\J*@H@("`@("H@3W5T<'5T($-O;G1E;G1(86YD;&5R('5S960@
M=&\@;W5T<'5T(%A-3"!E=F5N=',N"B`@("`@*@H@("`@("H@0'9A<B!O8FIE
M8W0*("`@("`J+PH@("`@=F%R("1?;W5T<'5T.PH*("`@("\J*@H@("`@("H@
M4W1A8VL@9F]R(&AO;&1I;F<@=&AE('AM;"!E;&5M96YT<R!D=7)I;F<@8W)E
M871I;VX@;V8@=&AE(&]B:F5C="!F<F]M"B`@("`@*B!T:&4@>&UL(&5V96YT
M(&9L;W<N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]3=&%C:R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]C:&%R<SL*"B`@("!F=6YC=&EO;B!S
M971/=71P=70H)B1O=71P=70I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=71P
M=70@/2`F)&]U='!U=#L*("`@('T*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*("`@("`@("`D=&AI
M<RT^7U-T86-K6UT@/2`D96QE;65N=#L*("`@('T*"B`@("!F=6YC=&EO;B!E
M;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7V-H87)S*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI
M<RT^7V-H87)S*3L*("`@("`@("!]"@H@("`@("`@(&%R<F%Y7W!O<"@D=&AI
M<RT^7U-T86-K*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1S
M='(I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G,I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8VAA<G,@/2`D=&AI<RT^7V-H87)S("X@
M)'-T<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V-H
M87)S(#T@)'-T<CL*("`@("`@("!]"B`@("!]"@I]"@H*+RHJ"B`J($1E9FEN
M960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N
M(#$N,2`U+C(N,@H@*@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y
M;F--3%]3>6YC34Q(9'(@97AT96YD<R!3>6YC34Q?0V]N=&5N=$AA;F1L97(@
M>PH*("`@("\J*@H@("`@("H@1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT
M871I;VX@4')O=&]C;VPL('9E<G-I;VX@,2XQ(#4N,2XY+B!5<V5R(&YA;64N
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M;&]C3F%M93L*"B`@("`O*BH*("`@("`J($1E9FEN960@:6X@4WEN8TU,(%)E
M<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S:6]N(#$N,2`U+C$N,3@*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S97-S
M:6]N240["@H@("`@+RHJ"B`@("`@*B!$969I;F5D(&EN(%-Y;F--3"!297!R
M97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;B`Q+C$N("!-=7-T(&)E(#$N
M,"`H,"D*("`@("`J(&]R(#$N,2`H,2DN"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?=F5R<VEO;CL*"B`@("`O*BH*("`@
M("`J($1E9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L
M+"!V97)S:6]N(#$N,2`U+C$N,3(*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]M<V=)1#L*"B`@("`O*BH*("`@("`J($1E
M9FEN960@:6X@4WEN8TU,(%)E<')E<V5N=&%T:6]N(%!R;W1O8V]L+"!V97)S
M:6]N(#$N,2`U+C$N,3`*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]T87)G97154DD["@H@("`@+RHJ"B`@("`@*B!$969I
M;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO
M;B`Q+C$@-2XQ+C$P+"`U+C$N,C`*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]S;W5R8V554DD["@H@("`@=F%R("1?8W)E
M9$1A=&$["@H@("`@=F%R("1?8W)E9$9O<FUA=#L*"B`@("!V87(@)%]C<F5D
M5'EP93L*"B`@("!V87(@)%]M87A-<V=3:7IE.PH*("`@(&9U;F-T:6]N(&=E
M=%-T871E1G)O;5-E<W-I;VXH)'-O=7)C955222P@)&QO8TYA;64L("1S97-S
M:6]N240I"B`@("!["B`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72`]("9N
M97<@4WEN8TU,7T)A8VME;F1?2&]R9&4H*3L*"B`@("`@("`@+R\@4F5L;V%D
M('1H92!(;W)D92!397-S:6]N2&%N9&QE<B!I9B!N96-E<W-A<GDN"B`@("`@
M("`@2&]R9&4Z.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*"B`@("`@("`@+R\@
M4WEN8TU,('!R;W1O8V]L(&1O97,@;F]T(')E<75I<F4@=&AE(&-L:65N="!T
M;R!S96YD('1H90H@("`@("`@("\O('5S97)N86UE(&]N(&%N>2!M97-S86=E
M<R!B=70@=&AE(&9I<G-T+B`@4V\@=6YF;W)T=6YA=&5L>0H@("`@("`@("\O
M('=E(&-A;B=T('5S92!I="!T;R!M86ME(&$@=6YI<75E('-E<W-I;VX@:60N
M"B`@("`@("`@<V5S<VEO;E]I9"@G<WEN8VUL)R`N('!R96=?<F5P;&%C92@G
M+UM>82UZ02U:,"TY72\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R<L("1S;W5R8V554DD@+B`D<V5S<VEO;DE$*2D[
M"B`@("`@("`@<V5S<VEO;E]S=&%R="@I.PH*("`@("`@("`O+R!)="!W;W5L
M9"!S965M(&UU;'1I<WEN8R!D;V5S(&YO="!S96YD('1H92!U<V5R(&YA;64@
M;VYC92!I=`H@("`@("`@("\O(&AA<R!B965N(&%U=&AO<FEZ960N($UA:V4@
M<W5R92!W92!H879E(&$@=F%L:60@<V5S<VEO;B!I9"X*("`@("`@("!S97-S
M:6]N7VED*"=S>6YC;6PG("X@<')E9U]R97!L86-E*"<O6UYA+7I!+5HP+3E=
M+R<L("<G+"`D<V]U<F-E55))("X@)'-E<W-I;VY)1"DI.PH@("`@("`@($!S
M97-S:6]N7W-T87)T*"D["@H@("`@("`@(&EF("@A:7-S970H)%]315-324].
M6R=3>6YC34PN<W1A=&4G72DI('L*("`@("`@("`@("`@+R\@0W)E871E(&$@
M;F5W('-T871E(&EF(&]N92!D;V5S(&YO="!A;')E861Y(&5X:7-T+@H@("`@
M("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=.97<@
M<V5S<VEO;B!C<F5A=&5D.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("X@<V5S<VEO;E]I9"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@("`@("1?4T534TE/3ELG4WEN8TU,+G-T871E)UT@/2`F;F5W(%-Y
M;F--3%]3=&%T92@D<V]U<F-E55))+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QO8TYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V5S<VEO;DE$*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=%
M>&ES=&EN9R!S97-S:6]N(&-O;G1I;G5E9#H@)PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N('-E<W-I;VY?:60H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)%]315-324].6R=3
M>6YC34PN<W1A=&4G73L*("`@('T*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*("`@("`@("!P87)E
M;G0Z.G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@
M("`@>PH@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*
M("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("\O(#PO4WEN8TAD<CX\+U-Y
M;F--3#X*("`@("`@("`@("`@+R\@1FEN9"!T:&4@<W1A=&4N"B`@("`@("`@
M("`@("1S=&%T92`]("1T:&ES+3YG9713=&%T949R;VU397-S:6]N*"1T:&ES
M+3Y?<V]U<F-E55))+"`D=&AI<RT^7VQO8TYA;64L("1T:&ES+3Y?<V5S<VEO
M;DE$*3L*"B`@("`@("`@("`@("1S=&%T92T^<V5T5F5R<VEO;B@D=&AI<RT^
M7W9E<G-I;VXI.PH@("`@("`@("`@("`D<W1A=&4M/G-E=$US9TE$*"1T:&ES
M+3Y?;7-G240I.PH@("`@("`@("`@("`D<W1A=&4M/G-E=%1A<F=E=%5222@D
M=&AI<RT^7W1A<F=E=%5222D["B`@("`@("`@("`@("1S=&%T92T^<V5T4&%S
M<W=O<F0H)'1H:7,M/E]C<F5D1&%T82D["B`@("`@("`@("`@("1S=&%T92T^
M<V5T5T)834PH:7-?82@D=&AI<RT^7V]U='!U="P@)UA-3%]70EA-3%]%;F-O
M9&5R)RDI.PH*("`@("`@("`@("`@+R\@4W1O<F4@;&]G:6X@;F%M92!I;B!S
M=&%T92!I9B!N;W0@86QR96%D>2!S970*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1S=&%T92T^7VQO8TYA;64I("8F("%E;7!T>2@D=&AI<RT^7VQO8TYA;64I
M*2!["B`@("`@("`@("`@("`@("`D<W1A=&4M/G-E=$QO8TYA;64H)'1H:7,M
M/E]L;V-.86UE*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?;6%X37-G4VEZ92DI('L*("`@("`@("`@("`@("`@("1S
M=&%T92T^<V5T36%X37-G4VEZ92@D=&AI<RT^7VUA>$US9U-I>F4I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<W1R(#T@)V%U=&AO<FEZ960])R`N
M("1S=&%T92T^:7-!=71H;W)I>F5D*"D@+@H@("`@("`@("`@("`@("`@)R!V
M97)S:6]N/2<@+B`D<W1A=&4M/F=E=%9E<G-I;VXH*2`N"B`@("`@("`@("`@
M("`@("`G(&US9VED/2<@+B`D<W1A=&4M/F=E=$US9TE$*"D@+@H@("`@("`@
M("`@("`@("`@)R!S;W5R8V4])R`N("1S=&%T92T^9V5T4V]U<F-E55))*"D@
M+@H@("`@("`@("`@("`@("`@)R!T87)G970])R`N("1S=&%T92T^9V5T5&%R
M9V5T55))*"D@+@H@("`@("`@("`@("`@("`@)R!U<V5R/2<@+B`D<W1A=&4M
M/F=E=$QO8TYA;64H*2`N"B`@("`@("`@("`@("`@("`G(&-H87)S970])R`N
M($Y,4SHZ9V5T0VAA<G-E="@I("X*("`@("`@("`@("`@("`@("<@=V)X;6P]
M)R`N("1S=&%T92T^:7-70EA-3"@I"@H@("`@("`@("`@("`@("`@.PH*("`@
M("`@("`@("`@)%]315-324].6R=3>6YC34PN<W1A=&4G72`]("1S=&%T93L*
M"B`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H
M)'-T<BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@
M("`@("`@("`@("`O+R!';W0@=&AE('-T871E.R!N;W<@=W)I=&4@;W5R(%-Y
M;F-(9'(@:&5A9&5R+@H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T4WEN8TAD
M<B@D=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G5F5R4')O
M=&\G*2!["B`@("`@("`@("`@("`@("`O+R`\+U9E<E!R;W1O/CPO4WEN8TAD
M<CX\+U-Y;F--3#X*("`@("`@("`@("`@("`@(&EF("AT<FEM*"1T:&ES+3Y?
M8VAA<G,I(#T]("=3>6YC34PO,2XQ)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=F5R<VEO;B`](#$["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F5R<VEO;B`](#`["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N
M="`]/2`G4V5S<VEO;DE$)RD@>PH@("`@("`@("`@("`@("`@+R\@/"]397-S
M:6]N240^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S97-S:6]N240@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)TUS9TE$)RD@>PH@("`@("`@
M("`@("`@("`@+R\@/"]-<V=)1#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUS9TE$(#T@:6YT=F%L*'1R:6TH)'1H:7,M
M/E]C:&%R<RDI.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@
M)T-R960G*2!["B`@("`@("`@("`@("`@("`O+R`\+T-R960^/"]3>6YC2&1R
M/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@)'1H:7,M/E]C<F5D1&%T82`]
M(&)A<V4V-%]D96-O9&4H)'1H:7,M/E]C<F5D1&%T82D["@H@("`@("`@("`@
M("`@("`@)'1M<"`](&5X<&QO9&4H)SHG+"`D=&AI<RT^7V-R961$871A*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]C3F%M92`]("1T;7!;,%T["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-R961$871A(#T@)'1M<%LQ73L*("`@
M("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3>6YC34PZ(')E8V5I
M=F5D(&-R961E;G1I86QS(&9O<B!U<V5R/2<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7VQO8TYA
M;64@+"`G8W)E9#TG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@)'1H:7,M/E]C<F5D1&%T82P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#,Z"B`@("`@("`@
M("`@(&EF("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O=7)C92<I('L*("`@("`@
M("`@("`@("`@("`@("`O+R`\+TQO8U5223X\+U-O=7)C93X\+U-Y;F-(9'(^
M/"]3>6YC34P^"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V55
M4DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U1A<F=E="<I('L*("`@("`@
M("`@("`@("`@("`@("`O+R`\+TQO8U5223X\+U1A<F=E=#X\+U-Y;F-(9'(^
M/"]3>6YC34P^"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T87)G9715
M4DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)TQO8TYA;64G*2![
M"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G4V]U
M<F-E)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO3&]C3F%M93X\+U-O
M=7)C93X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L;V-.86UE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*"1E;&5M96YT(#T]
M("=$871A)RD@>PH@("`@("`@("`@("`@("`@("`@("\O(#PO1&%T83X\+T-R
M960^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?4W1A8VM;,5T@/3T@)T-R960G*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C<F5D1&%T82`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N
M="`]/2`G36%X37-G4VEZ92<I('L*("`@("`@("`@("`@("`@("\O(#PO36%X
M37-G4VEZ93X\+TUE=&$^/"]3>6YC2&1R/CPO4WEN8TU,/@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]M87A-<V=3:7IE(#T@:6YT=F%L*"1T:&ES+3Y?8VAA
M<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E(#0Z"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K6S%=(#T]
M("=#<F5D)RD@>PH@("`@("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=&
M;W)M870G*2!["B`@("`@("`@("`@("`@("`@("`@+R\@/"]&;W)M870^/"]-
M971A/CPO0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C<F5D1F]R;6%T(#T@=')I;2@D=&AI<RT^7V-H87)S
M*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G5'EP
M92<I('L*("`@("`@("`@("`@("`@("`@("`O+R`\+U1Y<&4^/"]-971A/CPO
M0W)E9#X\+U-Y;F-(9'(^/"]3>6YC34P^"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C<F5D5'EP92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&]U='!U=%-Y;F-(9'(H
M)B1O=71P=70I"B`@("!["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@
M("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@
M("`@("`@("1U<FD@/2`D<W1A=&4M/F=E=%5222@I.PH@("`@("`@("1U<FE-
M971A(#T@)'-T871E+3YG97154DE-971A*"D["@H@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D=7)I+"`G4WEN8TAD<B<L("1A='1R<RD["@H@("`@
M("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G5F5R1%1$)RP@)&%T
M=')S*3L*("`@("`@("`D8VAA<G,@/2`H)'1H:7,M/E]V97)S:6]N(#T](#$I
M(#\@)S$N,2<@.B`G,2XP)SL*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C:&%R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G
M5F5R1%1$)RD["@H@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I
M+"`G5F5R4')O=&\G+"`D871T<G,I.PH@("`@("`@("1C:&%R<R`]("@D=&AI
M<RT^7W9E<G-I;VX@/3T@,2D@/R`G4WEN8TU,+S$N,2<@.B`G4WEN8TU,+S$N
M,"<["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U9E<E!R;W1O)RD["@H@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G4V5S<VEO;DE$
M)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES
M+3Y?<V5S<VEO;DE$*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1U
M<FDL("=397-S:6]N240G*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M
M96YT*"1U<FDL("=-<V=)1"<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^
M8VAA<F%C=&5R<R@D=&AI<RT^7VUS9TE$*3L*("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1U<FDL("=-<V=)1"<I.PH*("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'5R:2P@)U1A<F=E="<L("1A='1R<RD["B`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=,;V-54DDG+"`D871T<G,I
M.PH@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'1H:7,M/E]S;W5R8V55
M4DDI.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)TQO8U52
M22<I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D=7)I+"`G3&]C
M3F%M92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D
M<W1A=&4M/F=E=$QO8TYA;64H*2D["B`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D=7)I+"`G3&]C3F%M92<I.PH@("`@("`@("1O=71P=70M/F5N9$5L
M96UE;G0H)'5R:2P@)U1A<F=E="<I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'5R:2P@)U-O=7)C92<L("1A='1R<RD["B`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=,;V-54DDG+"`D871T<G,I.PH@
M("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'1H:7,M/E]T87)G97154DDI
M.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)TQO8U5222<I
M.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U-O=7)C92<I
M.PH*("`@("`@("`O*@H@("`@("`@($1O(&YO="!S96YD(%)E<W!54DD@16QE
M;65N="X@270G<R!O<'1I;VYA;"!A;F0@;6%Y(&)E(&UI<VQE861I;F<Z"B`@
M("`@("`@)'1H:7,M/E]T87)G97154DD@:7,@9&%T82!F<F]M('1H92!C;&EE
M;G0@86YD(&YO="!G=6%R86YT965D('1O(&)E"B`@("`@("`@=&AE(&-O<G)E
M8W0@55),(&9O<B!A8V-E<W,N($QE="!T:&4@8VQI96YT(&IU<W0@<W1A>2!W
M:71H('1H92!S86UE"B`@("`@("`@55),(&ET(&AA<R!U<V5D(&9O<B!T:&4@
M<')E=FEO=7,@<F5Q=65S="AS*2X*("`@("`@("`J+PH@("`@("`@("\O)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("=297-P55)))RP@)&%T=')S*3L*
M("`@("`@("`O+R1O=71P=70M/F-H87)A8W1E<G,H)'1H:7,M/E]T87)G9715
M4DDI.PH@("`@("`@("\O)&]U='!U="T^96YD16QE;65N="@D=7)I+"`G4F5S
M<%5222<I.PH*("`@("`@("`O*@H@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D=7)I+"`G365T82<L("1A='1R<RD["@H@("`@("`@("\O($1U;6UY
M($UA>"!-<W%3:7IE+"!T:&ES(&ES(&IU<W0@<'5T(&EN('1O(&UA:V4@=&AE
M('!A8VME=`H@("`@("`@("\O('=O<FLL(&ET(&ES(&YO="!A(')E86P@=F%L
M=64N"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1U<FE-971A+"`G
M36%X37-G4VEZ92<L("1A='1R<RD["B`@("`@("`@)&-H87)S(#T@)S4P,#`P
M)SL*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D=7)I365T82P@)TUA>$US9U-I>F4G
M*3L*"B`@("`@("`@+R\@1'5M;7D@36%X3V)J4VEZ92P@=&AI<R!I<R!J=7-T
M('!U="!I;B!T;R!M86ME('1H92!P86-K970*("`@("`@("`O+R!W;W)K+"!I
M="!I<R!N;W0@82!R96%L('9A;'5E+@H@("`@("`@("1O=71P=70M/G-T87)T
M16QE;65N="@D=7)I365T82P@)TUA>$]B:E-I>F4G+"`D871T<G,I.PH@("`@
M("`@("1C:&%R<R`]("<T,#`P,#`P)SL*("`@("`@("`D;W5T<'5T+3YC:&%R
M86-T97)S*"1C:&%R<RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D
M=7)I365T82P@)TUA>$]B:E-I>F4G*3L*"B`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D=7)I+"`G365T82<I.PH@("`@("`@("HO"@H@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'5R:2P@)U-Y;F-(9'(G*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!G9713;W5R8V554DDH*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W-O=7)C955223L*("`@('T*"B`@("!F=6YC=&EO;B!G971,
M;V-.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L;V-.86UE
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)1"@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<V5S<VEO;DE$.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=%9E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W9E<G-I;VX["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T37-G240H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUS9TE$.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%1A<F=E=%5222@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=&%R9V5T55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&]P87%U
M92@D;RD*("`@('L*("`@('T*"GT*"B\J*@H@*B!$969I;F5D(&EN(%-Y;F--
M3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO;B`Q+C$@-2XR+C,*
M("H*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?4WEN8TU,
M0F]D>2!E>'1E;F1S(%-Y;F--3%]#;VYT96YT2&%N9&QE<B!["@H@("`@=F%R
M("1?8W5R<F5N=$-M9$E$(#T@,3L*"B`@("!V87(@)%]C=7)R96YT0V]M;6%N
M9#L*"B`@("!V87(@)%]A8W1I;VY#;VUM86YD<R`](&9A;'-E.PH*("`@(&9U
M;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@
M("`@>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M
M96YT+"`D871T<G,I.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?
M4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`D<W1A=&4@
M/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@("`@("1T
M:&ES+3Y?86-T:6]N0V]M;6%N9',@/2!F86QS93L@+R\@<V\@9F%R+"!W92!H
M879E(&YO="!S965N(&-O;6UA;F1S('1H870@<F5Q=6ER92!A8W1I;VX@9G)O
M;2!O=7(@<VED90H*("`@("`@("`@("`@+R\@/%-Y;F--3#X\4WEN8T)O9'D^
M"B`@("`@("`@("`@("1U<FD@/2`D<W1A=&4M/F=E=%5222@I.PH@("`@("`@
M("`@("`D=&AI<RT^7V]U='!U="T^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M
M96YT+"`D871T<G,I.PH*("`@("`@("`@("`@+R\@4FEG:'0@;W5R('-T871U
M<R!A8F]U="!T:&4@:&5A9&5R+@H@("`@("`@("`@("`D<W1A='5S(#T@)FYE
M=R!3>6YC34Q?0V]M;6%N9%]3=&%T=7,H*"1S=&%T92T^:7-!=71H;W)I>F5D
M*"DI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%)%4U!/3E-%7T%55$A%3E1)0T%424].7T%#0T505$5$(#H@
M4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RP@)U-Y;F-(9'(G*3L*("`@
M("`@("`@("`@)'-T871U<RT^<V5T4V]U<F-E4F5F*"1S=&%T92T^9V5T4V]U
M<F-E55))*"DI.PH@("`@("`@("`@("`D<W1A='5S+3YS971487)G9712968H
M)'-T871E+3YG971487)G97154DDH*2D["B`@("`@("`@("`@("1S=&%T=7,M
M/G-E=$-M9%)E9B@P*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-M
M9$E$(#T@)'-T871U<RT^;W5T<'5T*"1T:&ES+3Y?8W5R<F5N=$-M9$E$+"`D
M=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E(#(Z"B`@("`@("`@("`@("\O(#Q3>6YC34P^/%-Y;F-";V1Y/CQ;0V]M
M;6%N9%T^"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0@/2!3
M>6YC34Q?0V]M;6%N9#HZ9F%C=&]R>2@D96QE;65N="D["B`@("`@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=$-O;6UA;F0M/G-T87)T16QE;65N="@D=7)I+"`D
M96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@("`@(&EF("@D96QE;65N="`A
M/2`G4W1A='5S)R`F)B`D96QE;65N="`A/2`G36%P)R`F)B`D96QE;65N="`A
M/2`G1FEN86PG*2!["B`@("`@("`@("`@("`@("`O+R!792=V92!G;W0@=&\@
M9&\@<V]M971H:6YG(2!4:&ES(&-A;B=T(&)E('1H92!L87-T"B`@("`@("`@
M("`@("`@("`O+R!P86-K970N"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%C
M=&EO;D-O;6UA;F1S(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@/%-Y
M;F--3#X\4WEN8T)O9'D^/$-O;6UA;F0^/"XN+CX*("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT0V]M;6%N9"T^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M
M96YT+"`D871T<G,I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D96QE;65N="D*
M("`@('L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI*2![
M"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`O+R`\+U-Y;F-";V1Y/CPO
M4WEN8TU,/@H@("`@("`@("`@("`D<W1A=&4@/2`F)%]315-324].6R=3>6YC
M34PN<W1A=&4G73L*"B`@("`@("`@("`@(&EF("@D<W1A=&4M/FAA<U!E;F1I
M;F=%;&5M96YT<R@I*2!["B`@("`@("`@("`@("`@("`O*B!S=&EL;"!S;VUE
M=&AI;F<@=&\@9&\Z(&1O;B=T(&-L;W-E('-E<W-I;VX@*B\*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?86-T:6]N0V]M;6%N9',@/2!T<G5E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-M9$E$(#T@4WEN
M8TU,7T-O;6UA;F1?1FEN86PZ.F]U='!U=$9I;F%L*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0VUD
M240L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YE
M;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]A8W1I;VY#;VUM86YD<RD@>PH@("`@("`@("`@("`@("`@+R\@
M5&AI<R!P86-K970@9&ED(&YO="!C;VYT86EN(&%N>2!R96%L(&%C=&EO;G,L
M(&IU<W0*("`@("`@("`@("`@("`@("\O('-T871U<R!A;F0@;6%P+B!4:&ES
M(&UE86YS('=E)W)E(&1O;F4N(%1H92!S97-S:6]N"B`@("`@("`@("`@("`@
M("`O+R!C86X@8F4@8VQO<V5D(&%N9"!T:&4@86YC:&]R<R!S879E9"!F;W(@
M=&AE(&YE>'0*("`@("`@("`@("`@("`@("\O('-Y;F,N"B`@("`@("`@("`@
M("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S86=E*"=S>6YC)R`N
M('-E<W-I;VY?:60H*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<@8V]M<&QE=&5D('-U8V-E<W-F=6QL>2$G
M("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R!3=&]R:6YG($-L:65N="U44R`G("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T871E+3Y?8VQI
M96YT06YC:&]R3F5X="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U])3D9/*3L*("`@("`@("`@("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM
M/G=R:71E4WEN8U-U;6UA<GDH"B`@("`@("`@("`@("`@("`@("`@)'-T871E
M+3YG9713>6YC261E;G1I9FEE<B@I+`H@("`@("`@("`@("`@("`@("`@("1S
M=&%T92T^7V-L:65N=$%N8VAO<DYE>'0L"B`@("`@("`@("`@("`@("`@("`@
M)'-T871E+3Y?<V5R=F5R06YC:&]R3F5X="D["B`@("`@("`@("`@("`@("`D
M;&]G(#T@)'-T871E+3YG971,;V<H*3L*("`@("`@("`@("`@("`@("1S(#T@
M)R<["B`@("`@("`@("`@("`@("!F;W)E86-H("@D;&]G(&%S("1K(#T^("1V
M*2!["B`@("`@("`@("`@("`@("`@("`@)',@+CT@(B`D:STD=B(["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N
M9"==+3YL;V=-97-S86=E*"=3=6UM87)Y.B<@+B`D<RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U])3D9/*3L*"B`@("`@("`@("`@("`@("`O+R!3
M97-S:6]N(&-A;B!B92!C;&]S960@:&5R92X*("`@("`@("`@("`@("`@('-E
M<W-I;VY?=6YS970H*3L*("`@("`@("`@("`@("`@('-E<W-I;VY?9&5S=')O
M>2@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)$=,
M3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G92@G4WEN8TU,.B!R971U<FX@
M;65S<V%G92!C;VUP;&5T960G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`O+R`\+UM#;VUM86YD
M73X\+U-Y;F-";V1Y/CPO4WEN8TU,/@H@("`@("`@("`@("`D=&AI<RT^7V-U
M<G)E;G1#;VUM86YD+3YE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*"B`@
M("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-M9$E$(#T@)'1H:7,M/E]C=7)R
M96YT0V]M;6%N9"T^;W5T<'5T*"1T:&ES+3Y?8W5R<F5N=$-M9$E$+"`D=&AI
M<RT^7V]U='!U="D["@H@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-U<G)E
M;G1#;VUM86YD*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("\O(#PO+BXN/CPO6T-O;6UA;F1=/CPO4WEN8T)O
M9'D^/"]3>6YC34P^"B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$-O;6UA
M;F0M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D
M=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R
M<R@D<W1R*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-U<G)E
M;G1#;VUM86YD*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G1#;VUM
M86YD+3YC:&%R86-T97)S*"1S='(I.PH@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B\N:'1A8V-E<W,`````````````````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`Q-B`Q,#4Q-30S-#$T,2`P,C`P-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````1&5N>2!F
M<F]M(&%L;`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O=F5R<VEO
M;BYP:'``````````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P-3(@,3`U,34T,S0Q-#$@,#(P-#<R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP(&1E9FEN92@G2$]2
M1$5?5D524TE/3B<L("<S+C$N,R<I(#\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+V-O<F4N<&AP````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(V
M(#$P-3$U-#,T,30Q(#`Q-S<T-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@2&]R9&4@07!P;&EC871I
M;VX@1G)A;65W;W)K(&-O<F4@<V5R=FEC97,@9FEL92X*("H*("H@5&AI<R!F
M:6QE('-E=',@=7`@86YY(&YE8V5S<V%R>2!I;F-L=61E('!A=&@@=F%R:6%B
M;&5S(&%N9"!I;F-L=61E<PH@*B!T:&4@;6EN:6UU;2!R97%U:7)E9"!(;W)D
M92!L:6)R87)I97,N"B`J"B`J("1(;W)D93H@:&]R9&4O;&EB+V-O<F4N<&AP
M+'8@,2XR-BXV+C<@,C`P-B\P,2\P-R`Q-CHT,#HR."!C:'5C:R!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*B!4=7)N(%!(4"!S
M='5F9B!O9F8@=&AA="!C86X@<F5A;&QY('-C<F5W('1H:6YG<R!U<"X@*B\*
M:6YI7W-E="@G;6%G:6-?<75O=&5S7W-Y8F%S92<L(#`I.PII;FE?<V5T*"=M
M86=I8U]Q=6]T97-?<G5N=&EM92<L(#`I.PH*+RH@56YS970@86QL('9A<FEA
M8FQE<R!P;W!U;&%T960@=&AR;W5G:"!R96=I<W1E<E]G;&]B86QS+B`J+PII
M9B`H:6YI7V=E="@G<F5G:7-T97)?9VQO8F%L<R<I*2!["B`@("!F;W)E86-H
M("AA<G)A>5]K97ES*"1?1T54*2!A<R`D:V5Y*2!["B`@("`@("`@=6YS970H
M)"1K97DI.PH@("`@?0H@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D7U!/4U0I
M(&%S("1K97DI('L*("`@("`@("!U;G-E="@D)&ME>2D["B`@("!]"B`@("!F
M;W)E86-H("AA<G)A>5]K97ES*"1?0T]/2TE%*2!A<R`D:V5Y*2!["B`@("`@
M("`@=6YS970H)"1K97DI.PH@("`@?0H@("`@9F]R96%C:"`H87)R87E?:V5Y
M<R@D7T5.5BD@87,@)&ME>2D@>PH@("`@("`@('5N<V5T*"0D:V5Y*3L*("`@
M('T*("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)%]315)615(I(&%S("1K97DI
M('L*("`@("`@("!U;G-E="@D)&ME>2D["B`@("!]"GT*"B\J($EF('1H92!(
M;W)D92!&<F%M97=O<FL@<&%C:V%G97,@87)E(&YO="!I;G-T86QL960@:6X@
M4$A0)W,@9VQO8F%L"B`J(&EN8VQU9&5?<&%T:"P@>6]U(&UU<W0@861D(&%N
M(&EN:5]S970H*2!C86QL(&AE<F4@=&\@861D('1H96ER(&QO8V%T:6]N('1O
M"B`J('1H92!I;F-L=61E7W!A=&@N("HO"FEN:5]S970H)VEN8VQU9&5?<&%T
M:"<L(&1I<FYA;64H7U]&24Q%7U\I("X@4$%42%]315!!4D%43U(@+B!I;FE?
M9V5T*"=I;F-L=61E7W!A=&@G*2D["@HO*B!014%2(&)A<V4@8VQA<W,N("HO
M"FEN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH*+RH@2&]R9&4@8V]R92!C;&%S
M<V5S+B`J+PII;F-L=61E7V]N8V4@)TAO<F1E+G!H<"<["FEN8VQU9&5?;VYC
M92`G2&]R9&4O4F5G:7-T<GDN<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92]3
M=')I;F<N<&AP)SL*:6YC;'5D95]O;F-E("=(;W)D92].3%,N<&AP)SL*:6YC
M;'5D95]O;F-E("=(;W)D92].;W1I9FEC871I;VXN<&AP)SL*:6YC;'5D95]O
M;F-E("=(;W)D92]!=71H+G!H<"<["FEN8VQU9&5?;VYC92`G2&]R9&4O0G)O
M=W-E<BYP:'`G.PII;F-L=61E7V]N8V4@)TAO<F1E+U!E<FUS+G!H<"<["@HO
M*B!"<F]W<V5R(&1E=&5C=&EO;B!O8FIE8W0N("HO"FEF("AC;&%S<U]E>&ES
M=',H)T)R;W=S97(G*2D@>PH@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN
M9VQE=&]N*"D["GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,N<&AP````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V-C8W-B`Q,#4Q
M-30S-#$T,2`P,3<T-S,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR
M97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*9&5F:6YE*"=61E-?455/5$%?3454
M4DE#7T)95$4G+"`Q*3L*9&5F:6YE*"=61E-?455/5$%?34544DE#7TM")RP@
M,BD["F1E9FEN92@G5D937U%53U1!7TU%5%))0U]-0B<L(#,I.PID969I;F4H
M)U9&4U]154]405]-151224-?1T(G+"`T*3L*"B\J*@H@*B!61E,@05!)(&9O
M<B!A8G-T<F%C=&5D(&9I;&4@<W1O<F%G92!A;F0@86-C97-S+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+G!H<"QV(#$N-CDN-"XQ-B`R,#`V
M+S`X+S`W(#`P.C,P.C$T(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5D93"B`J($!S:6YC92`@($AO
M<F1E(#(N,@H@*B\*8VQA<W,@5D93('L*"B`@("`O*BH*("`@("`J($AA<V@@
M8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!A9&1I=&EO;F%L(&-R961E
M;G1I86QS(')E<75I<F5D(&9O<B!T:&ES(%9&4R!B86-K96YD("AE>&%M<&QE
M.@H@("`@("H@1F]R($944"P@=V4@;F5E9"!A('5S97)N86UE(&%N9"!P87-S
M=V]R9"!T;R!L;V<@:6X@=&\@=&AE('-E<G9E<B!W:71H*2X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-R961E;G1I86QS
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@<&5R;6ES<VEO
M;G,@86YD(&EF('1H97D@8V%N(&)E(&-H86YG960@:6X@=&AI<R!61E,@8F%C
M:V5N9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!E<FUI<W-I;VYS(#T@87)R87DH"B`@("`@("`@)V]W;F5R)R`]/B!A
M<G)A>2@G<F5A9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C
M=71E)R`]/B!F86QS92DL"B`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@G<F5A
M9"<@/3X@9F%L<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F
M86QS92DL"B`@("`@("`@)V%L;"<@("`]/B!A<G)A>2@G<F5A9"<@/3X@9F%L
M<V4L("=W<FET92<@/3X@9F%L<V4L("=E>&5C=71E)R`]/B!F86QS92DI.PH*
M("`@("\J*@H@("`@("H@02!014%2($QO9R!O8FIE8W0N($EF('!R97-E;G0L
M('=I;&P@8F4@=7-E9"!T;R!L;V<@97)R;W)S(&%N9`H@("`@("H@:6YF;W)M
M871I;VYA;"!M97-S86=E<R!A8F]U="!61E,@86-T:79I='DN"B`@("`@*@H@
M("`@("H@0'9A<B!,;V<*("`@("`J+PH@("`@=F%R("1?;&]G9V5R(#T@;G5L
M;#L*"B`@("`O*BH*("`@("`J(%1H92!L;V<@;&5V96P@=&\@=7-E("T@;65S
M<V%G97,@=VET:"!A(&AI9VAE<B!L;V<@;&5V96P@=&AA;B!C;VYF:6=U<F5D
M"B`@("`@*B!H97)E('=I;&P@;F]T(&)E(&QO9V=E9"X@1&5F875L=',@=&\@
M;VYL>2!L;V=G:6YG(&5R<F]R<R!O<B!H:6=H97(N"B`@("`@*@H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VQO9TQE=F5L(#T@4$5!
M4E],3T=?15)2.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@<VEZ92P@
M:6X@8GET97,L(&]F('1H92!61E,@:71E;2X*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?=F9S4VEZ92`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO
M;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E,H)'!A<F%M
M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;
M)W5S97(G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG=7-E<B==(#T@)R<[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=V9G-?<75O
M=&%L:6UI="==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=V9G-?<75O=&%L
M:6UI="==(#T@+3$["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US6R=V9G-?<75O=&%R;V]T)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;
M)W9F<U]Q=6]T87)O;W0G72`]("<O)SL*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS('1H92!C<F5D96YT:6%L<R!T:&%T('=E(&AA=F4@8GD@8V%L;&EN
M9R!?8V]N;F5C="@I+"!T;R!S964@:68*("`@("`J('1H97)E(&ES(&$@=F%L
M:60@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S+"!014%27T5R<F]R(&1E<V-R:6)I;F<@=&AE('!R;V)L96T@
M:68@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!C<F5D96YT:6%L<R!A<F4@
M:6YV86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM#<F5D96YT:6%L
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N;F5C="@I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!C;VYF:6=U<F%T:6]N('!A<F%M
M971E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N
M(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@<&%R86UE=&5R(&YA;65S(&%S(&ME
M>7,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%!A<F%M<R@D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1N
M86UE(#T^("1V86QU92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULD
M;F%M95T@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!C;VYF:6=U<F%T:6]N('!A<F%M971E<G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('!A<F%M971E<B!T;R!R
M971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('!A<F%M
M971E<B!V86QU92!O<B!N=6QL(&EF(&ET(&1O97-N)W0@97AI<W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1N86UE*0H@("`@>PH@("`@("`@
M(')E='5R;B!I<W-E="@D=&AI<RT^7W!A<F%M<ULD;F%M95TI(#\@)'1H:7,M
M/E]P87)A;7-;)&YA;65=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J
M($QO9W,@82!M97-S86=E(&EF(&$@4$5!4B!,;V<@;V)J96-T(&ES(&%V86EL
M86)L92P@86YD('1H92!M97-S86=E)W,*("`@("`J('!R:6]R:71Y(&ES(&QO
M=V5R('1H86X@;W(@97%U86P@=&\@=&AE(&-O;F9I9W5R960@;&]G(&QE=F5L
M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("1M97-S86=E("`@5&AE
M(&UE<W-A9V4@=&\@8F4@;&]G9V5D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'!R:6]R:71Y("!4:&4@;65S<V%G92=S('!R:6]R:71Y+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](%!%05)?3$]'
M7T524BD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&]G9V5R
M*2!\?"`D<')I;W)I='D@/B`D=&AI<RT^7VQO9TQE=F5L*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1M97-S
M86=E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1U<V5R:6YF;R`]
M("1M97-S86=E+3YG9715<V5R26YF;R@I.PH@("`@("`@("`@("`D;65S<V%G
M92`]("1M97-S86=E+3YG971-97-S86=E*"D["B`@("`@("`@("`@(&EF("@D
M=7-E<FEN9F\I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=7-E
M<FEN9F\I*2!["B`@("`@("`@("`@("`@("`@("`@)'5S97)I;F9O(#T@:6UP
M;&]D92@G+"`G+"`D=7-E<FEN9F\I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&UE<W-A9V4@+CT@)SH@)R`N("1U<V5R:6YF;SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1O
M(&QO9R!I;B!T:&4@<WES=&5M)W,@;&]C86QE+B`J+PH@("`@("`@("1L;V-A
M;&4@/2!S971L;V-A;&4H3$-?5$E-12P@,"D["B`@("`@("`@<V5T;&]C86QE
M*$Q#7U1)344L("=#)RD["@H@("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H
M)&UE<W-A9V4L("1P<FEO<FET>2D["@H@("`@("`@("\J(%)E<W1O<F4@;W)I
M9VEN86P@;&]C86QE+B`J+PH@("`@("`@('-E=&QO8V%L92A,0U]424U%+"`D
M;&]C86QE*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(%!%05(@
M3&]G(&]B:F5C="!U<V5D('1O(&QO9R!I;F9O<FUA=&EO;F%L(&]R(&5R<F]R
M(&UE<W-A9V5S+@H@("`@("H*("`@("`J($!P87)A;2!,;V<@)B1L;V=G97(@
M(%1H92!,;V<@;V)J96-T('1O('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T3&]G9V5R*"8D;&]G9V5R+"`D;&]G3&5V96P@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D;&]G9V5R+"`G3&]G)RDI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L
M;V=G97(@/2`F)&QO9V=E<CL*("`@("`@("!I9B`H(6ES7VYU;&PH)&QO9TQE
M=F5L*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO9TQE=F5L(#T@)&QO9TQE
M=F5L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E
M<R!T:&4@<VEZ92!O9B!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@
M("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@5&AE(&9I;&4@<VEZ92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S:7IE(&]F
M(&$@9F]L9&5R"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O('1H
M92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M
M92!O9B!T:&4@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE('-I>F4@;V8@=&AE(&9O;&1E<BP@:6X@8GET97,L(&]R(%!%05)?
M17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T1F]L9&5R4VEZ92@D<&%T:"`](&YU;&PL
M("1N86UE(#T@;G5L;"D*("`@('L*("`@("`@("`D<VEZ92`](#`["B`@("`@
M("`@)')O;W0@/2`H*"%I<U]N=6QL*"1P871H*2D@/R`D<&%T:"`N("<O)R`Z
M("<G*2`N("1N86UE.PH@("`@("`@("1O8FIE8W1?;&ES="`]("1T:&ES+3YL
M:7-T1F]L9&5R*"1R;V]T+"!N=6QL+"!T<G5E+"!F86QS92P@=')U92D["B`@
M("`@("`@9F]R96%C:"`H)&]B:F5C=%]L:7-T(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'9A;%LG<W5B9&ER<R==*2D@>PH@
M("`@("`@("`@("`@("`@)'-I>F4@*ST@)'1H:7,M/F=E=$9O;&1E<E-I>F4H
M)')O;W0L("1K97DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&9I;&5S:7IE(#T@)'1H:7,M/G-I>F4H)')O;W0L("1K97DI.PH@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)&9I;&5S:7IE+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1F:6QE<VEZ93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S:7IE("L]("1F
M:6QE<VEZ93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@
M9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE
M('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M860H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T<FEE=F5S(&$@<&%R="!O9B!A(&9I;&4@9G)O;2!T:&4@
M5D93+B!087)T:6-U;&%R;'D@=7-E9G5L('=H96X*("`@("`J(')E861I;F<@
M;&%R9V4@9FEL97,@=VAI8V@@=V]U;&0@97AC965D('1H92!02%`@;65M;W)Y
M(&QI;6ET<R!I9B!T:&5Y"B`@("`@*B!W97)E('-T;W)E9"!I;B!A('-T<FEN
M9RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D<&%T:"`@("`@("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;F%M92`@("`@("!4:&4@9FEL
M96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;V9F
M<V5T("`@("!4:&4@;V9F<V5T(&]F('1H92!P87)T+B`H5&AE(&YE=R!O9F9S
M970@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F4@
M<W1O<F5D(&EN(&AE<F4I+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QE;F=T
M:"`@("`@5&AE(&QE;F=T:"!O9B!T:&4@<&%R="X@268@=&AE(&QE;F=T:"`]
M("TQ+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('=H
M;VQE('!A<G0@869T97(@=&AE(&]F9G-E="!I<R!R971R:65V960N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!M;W)E(&)Y=&5S(&%R
M92!G:79E;B!A<R!E>&ES=',@869T97(@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!G:79E;B!O9F9S970N($]N;'D@=&AE(&%V86EL
M86)L92!B>71E<R!A<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E860N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F5M86EN:6YG("!4
M:&4@8GET97,@=&AA="!A<F4@;&5F="P@869T97(@=&AE('!A<G0@=&AA=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:7,@<F5T<FEE=F5D
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%1H92!F:6QE(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861">71E4F%N9V4H)'!A=&@L("1N
M86UE+"`F)&]F9G-E="P@)&QE;F=T:"`]("TQ+"`F)')E;6%I;FEN9RD*("`@
M('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P
M<&]R=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I
M;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@
M=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R87)Y(&9I;&4@8V]N
M=&%I;FEN9R!T:&4@9&%T82!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)E('-T;W)E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T;7!&:6QE+"`D875T
M;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W(&1A
M=&$N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H
M92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@
M(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M871A("`@("`@("`@5&AE(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!B;V]L
M96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O
M<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!W<FET941A=&$H)'!A=&@L("1N86UE+"`D9&%T
M82P@)&%U=&]C<F5A=&4@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($UO=F5S(&$@9FEL92!T:')O=6=H('1H92!B86-K
M96YD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!O<FEG:6YA;"!F
M:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@
M=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T
M("!4:&4@9&5S=&EN871I;VX@9FEL92!N86UE+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H
M)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-O<&EE<R!A(&9I;&4@=&AR;W5G:"!T:&4@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@;W)I9VEN86P@9FEL
M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H
M92!O<FEG:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@
M5&AE(&YA;64@;V8@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;W!Y*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9FEL92!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@9&5L971E('1H92!F
M:6QE(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL
M96YA;64@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T949I;&4H)'!A=&@L
M("1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5N86UE<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4
M:&4@;VQD('!A=&@@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1O;&1N86UE("!4:&4@;VQD(&9I;&5N86UE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F5W<&%T:"`@5&AE(&YE=R!P871H(&]F('1H92!F:6QE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F5W;F%M92`@5&AE(&YE=R!F:6QE;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T
M:"P@)&YE=VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&EF(&$@9VEV96X@9FEL92!O<B!F;VQD97(@97AI<W1S
M(&EN(&$@9F]L9&5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@(%1H92!P871H('1O('1H92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@9FEL92!O<B!F;VQD97(@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@97AI<W1S+"!F86QS
M92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D<&%T
M:"P@)&YA;64I"B`@("!["B`@("`@("`@)&QI<W0@/2`D=&AI<RT^;&ES=$9O
M;&1E<B@D<&%T:"D["B`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!I<W-E="@D;&ES=%LD;F%M95TI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!F
M;VQD97(@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%R96YT(&9O
M;&1E<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F
M('1H92!N97<@9F]L9&5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T
M:"P@)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!=71O;6%T:6-A;&QY(&-R96%T97,@86YY(&YE8V5S<V%R>2!P87)E;G0@
M9&ER96-T;W)I97,@:6X@=&AE('-P96-I9FEE9`H@("`@("H@)'!A=&@N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE(%9&4R!P871H
M('1O(&%U=&]C<F5A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]C<F5A
M=&50871H*"1P871H*0H@("`@>PH@("`@("`@("1D:7)S(#T@97AP;&]D92@G
M+R<L("1P871H*3L*("`@("`@("!I9B`H:7-?87)R87DH)&1I<G,I*2!["B`@
M("`@("`@("`@("1C=7(@/2`G+R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M:7)S(&%S("1D:7(I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&1I
M<BDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YI<T9O;&1E
M<B@D8W5R+"`D9&ER*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D8W5R+"`D9&ER*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*"1C=7(@(3T@)R\G
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C=7(@+CT@)R\G.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8W5R("X]
M("1D:7(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0VAE8VMS(&EF(&$@9VEV96X@:71E;2!I<R!A(&9O;&1E<BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%R96YT(&9O;&1E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!I=&5M(&YA;64N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&ET(&ES
M(&$@9F]L9&5R+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D9F]L
M9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"!T<G5E
M+"!T<G5E*3L*("`@("`@("!R971U<FX@:7-S970H)&9O;&1E<DQI<W1;)&YA
M;65=*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!F;VQD97(@
M9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@(%1H92!P87)E;G0@
M9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE
M(&YA;64@;V8@=&AE(&9O;&1E<B!T;R!D96QE=&4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D<F5C=7)S:79E("!&;W)C92!A(')E8W5R<VEV92!D96QE=&4_
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&5L971E1F]L9&5R*"1P871H+"`D;F%M92P@)')E8W5R
M<VEV92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5C=7)S:79E;'D@<F5M;W9E(&%L;"!F:6QE<R!A;F0@<W5B9F]L
M9&5R<R!F<F]M('1H92!G:79E;@H@("`@("H@9F]L9&5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F('1H92!F;VQD
M97(@=&\@96UP='DN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@96UP='E&;VQD97(H)'!A=&@I"B`@
M("!["B`@("`@("`@+R\@1V5T(&%N9"!D96QE=&4@=&AE('-U8F9O;&1E<G,N
M"B`@("`@("`@)&QI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L
M;"P@=')U92P@=')U92D["B`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@
M('T*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D9F]L9&5R*2!["B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^9&5L971E1F]L9&5R*"1P871H+"`D
M9F]L9&5R6R=N86UE)UTL('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O
M+R!/;FQY(&9I;&5S(&%R92!L969T+"!G970@86YD(&1E;&5T92!T:&5M+@H@
M("`@("`@("1L:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@I.PH@("`@
M("`@(&EF("AI<U]A*"1L:7-T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D;&ES=#L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H
M)&QI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YD96QE=&5&:6QE*"1P871H+"`D9FEL95LG;F%M92==*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&9I;&4@;&ES="!O9B!T:&4@9&ER96-T;W)Y('!A<W-E
M9"!I;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@
M("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F:6QT97(@("`@("`@4W1R:6YG+VAA<V@@=&\@9FEL=&5R(&9I;&4O
M9&ER;F%M92!O;BX*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F:6QE<R`@
M(%-H;W<@9&]T9FEL97,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL
M>2`@("!3:&]W(&]N;'D@9&ER96-T;W)I97,_"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<F5C=7)S:79E("!2971U<FX@86QL(&1I<F5C=&]R>2!L979E;',@
M<F5C=7)S:79E;'D_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@1FEL
M92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R
M(#T@;G5L;"P@)&1O=&9I;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)&1I<F]N;'D@/2!F86QS92P@)')E8W5R<VEV92`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1L:7-T(#T@)'1H:7,M/E]L:7-T1F]L9&5R*"1P871H
M+"`D9FEL=&5R+"`D9&]T9FEL97,L("1D:7)O;FQY*3L*("`@("`@("!I9B`H
M(21R96-U<G-I=F4@?'P@:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&QI<W0["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D;&ES="!A<R`D;F%M92`]/B`D=F%L=65S*2!["B`@("`@("`@
M("`@(&EF("@D=F%L=65S6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@
M("`@("`@("`@)&QI<W1;)&YA;65=6R=S=6)D:7)S)UT@/2`D=&AI<RT^;&ES
M=$9O;&1E<B@D<&%T:"`N("<O)R`N("1N86UE+"`D9FEL=&5R+"`D9&]T9FEL
M97,L("1D:7)O;FQY+"`D<F5C=7)S:79E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A;B!A;B!U;G-O<G1E9"!F:6QE(&QI<W0@;V8@=&AE
M('-P96-I9FEE9"!D:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@
M<&%T:"!O9B!T:&4@9&ER96-T;W)Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1F
M:6QT97(@("`@("!3=')I;F<O:&%S:"!T;R!F:6QT97(@9FEL92]D:7)N86UE
M(&]N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I;&5S("!3:&]W(&1O
M=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N;'D@("!3:&]W
M(&]N;'D@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"P@
M)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A;'-E*0H@("`@>PH@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P;W)T960N(BDI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R<F5N="!W
M;W)K:6YG(&1I<F5C=&]R>2!O9B!T:&4@5D93(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C=7)R96YT('=O<FMI;F<@9&ER
M96-T;W)Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#=7)R96YT1&ER96-T
M;W)Y*"D*("`@('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('=H971H97(@;W(@;F]T(&$@9FEL96YA;64@;6%T
M8VAE<R!A;GD@9FEL=&5R(&5L96UE;G0N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@
M("`@(%-T<FEN9R]H87-H('1O(&)U:6QD('1H92!R96=U;&%R(&5X<')E<W-I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%-T<FEN9R!C;VYT86EN:6YG
M('1H92!F:6QE;F%M92!T;R!M871C:"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@;6%T8V@L(&9A;'-E(&]N(&YO(&UA=&-H+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9FEL=&5R36%T8V@H)&9I;'1E<BP@)&9I
M;&5N86UE*0H@("`@>PH@("`@("`@("1N86UE9FEL=&5R(#T@;G5L;#L*"B`@
M("`@("`@+R\@0G5I;&0@82!R96=E>'`@8F%S960@;VX@)&9I;'1E<BX*("`@
M("`@("!I9B`H)&9I;'1E<B`A/3T@;G5L;"D@>PH@("`@("`@("`@("`D;F%M
M969I;'1E<B`]("<O)SL*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1F:6QT
M97(I*2!["B`@("`@("`@("`@("`@("`D;VYC92`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&9I;'1E<B!A<R`D:71E;2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D;VYC92`A/3T@=')U92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;F%M969I;'1E<B`N/2`G*"<["B`@("`@("`@("`@
M("`@("`@("`@("`@("1O;F-E(#T@=')U93L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F%M969I;'1E
M<B`N/2`G?"@G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D;F%M969I;'1E<B`N/2`D:71E;2`N("<I)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1N86UE9FEL=&5R("X]("<H)R`N("1F:6QT97(@+B`G*2<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&YA;65F:6QT97(@+CT@)R\G.PH@("`@("`@
M('T*"B`@("`@("`@)&UA=&-H(#T@9F%L<V4["B`@("`@("`@:68@*"1N86UE
M9FEL=&5R("$]/2!N=6QL*2!["B`@("`@("`@("`@("1M871C:"`]('!R96=?
M;6%T8V@H)&YA;65F:6QT97(L("1F:6QE;F%M92D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&UA=&-H.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA
M;F=E<R!P97)M:7-S:6]N<R!F;W(@86X@:71E;2!O;B!T:&4@5D93+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@("`@("`@(%1H92!P87)E;G0@9F]L9&5R(&]F('1H92!I=&5M
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@5&AE(&YA;64@
M;V8@=&AE(&ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P97)M:7-S:6]N
M("!4:&4@<&5R;6ES<VEO;B!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAA;F=E4&5R
M;6ES<VEO;G,H)'!A=&@L("1N86UE+"`D<&5R;6ES<VEO;BD*("`@('L*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D
M+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S;W)T960@
M;&ES="!O9B!F;VQD97)S(&EN('1H92!S<&5C:69I960@9&ER96-T;W)Y+@H@
M("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y
M('1O(&=E="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!D:7)E8W1O<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I
M;'1E<B`@("`@("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX@
M9F]L9&5R;&ES="X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S
M("!);F-L=61E(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@1F]L9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&
M;VQD97)S*"1P871H(#T@)R<L("1F:6QT97(@/2!N=6QL+"`D9&]T9F]L9&5R
M<R`]('1R=64I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!L:7-T(&]F(&%D9&ET:6]N86P@8W)E9&5N=&EA;',@
M<F5Q=6ER960L(&EF(&%N>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!#<F5D96YT:6%L(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E
M<75I<F5D0W)E9&5N=&EA;',H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A
M>5]D:69F*"1T:&ES+3Y?8W)E9&5N=&EA;',L(&%R<F%Y7VME>7,H)'1H:7,M
M/E]P87)A;7,I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@
M87)R87D@<W!E8VEF>6EN9R!W:&%T('!E<FUI<W-I;VYS(&%R92!C:&%N9V5A
M8FQE(&9O<B!T:&ES"B`@("`@*B!61E,@:6UP;&5M96YT871I;VXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@0VAA;F=E86)L92!P97)M:7-I;VYS
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-;V1I9FEA8FQE4&5R;6ES<VEO
M;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!E<FUI<W-I;VYS
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!S=')I;F<@=&\@
M86QL(&QO=V5R8V%S92!C:&%R86-T97)S(&EG;F]R:6YG('1H92!C=7)R96YT
M"B`@("`@*B!L;V-A;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<W1R:6YG("!4:&4@<W1R:6YG('1O(&)E(&QO=V5R8V%S960*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN9R!W:71H(&QO=V5R8V%S
M92!C:&%R86-T97)S"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<G1O;&]W97(H
M)'-T<FEN9RD*("`@('L*("`@("`@("`D;&%N9W5A9V4@/2!S971L;V-A;&4H
M3$-?0U194$4L(#`I.PH@("`@("`@('-E=&QO8V%L92A,0U]#5%E012P@)V5N
M)RD["B`@("`@("`@)'-T<FEN9R`]('-T<G1O;&]W97(H)'-T<FEN9RD["B`@
M("`@("`@<V5T;&]C86QE*$Q#7T-465!%+"`D;&%N9W5A9V4I.PH@("`@("`@
M(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@8VAA<F%C=&5R("AN;W0@8GET92D@;&5N9W1H(&]F(&$@<W1R:6YG
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H92!S
M=')I;F<@=&\@<F5T=7)N('1H92!L96YG=&@@;V8N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4@=VAE;B!C86QC
M=6QA=&EN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<FEN9R=S(&QE;F=T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('-T<FEN9R=S(&QE;F=T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R
M;&5N*"1S=')I;F<L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H97AT96YS:6]N7VQO861E9"@G;6)S=')I;F<G*2D@>PH@("`@("`@("`@
M("!I9B`H:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1C
M:&%R<V5T(#T@)TE33RTX.#4Y+3$G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1R970@/2!`;6)?<W1R;&5N*"1S=')I;F<L("1C:&%R<V5T*3L*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D<F5T*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R970["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N('-T<FQE;B@D<W1R:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('-I>F4@;V8@=&AE(%9&4R!I=&5M+@H@("`@("H*("`@
M("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!S:7IE+"!I;B!B>71E<RP@;V8@=&AE(%9&4R!I=&5M+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G97161E-3:7IE*"D*("`@('L*("`@("`@
M("!I9B`H:7-?;G5L;"@D=&AI<RT^7W9F<U-I>F4I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?=F9S4VEZ92`]("1T:&ES+3YG971&;VQD97)3:7IE*"1T:&ES
M+3Y?<&%R86US6R=V9G-?<75O=&%R;V]T)UTI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]V9G-3:7IE.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&4@5D93('%U;W1A(&QI;6ET+@H@("`@("H*("`@("`J($!S
M:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<75O=&$@("!4:&4@;&EM:70@=&\@87!P;'DN"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;65T<FEC("!4:&4@;65T<FEC('1O(&UU;'1I<&QY('1H92!Q=6]T
M82!I;G1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9711=6]T82@D<75O=&$L
M("1M971R:6,@/2!61E-?455/5$%?34544DE#7T)95$4I"B`@("!["B`@("`@
M("`@<W=I=&-H("@D;65T<FEC*2!["B`@("`@("`@8V%S92!61E-?455/5$%?
M34544DE#7TM".@H@("`@("`@("`@("`D<75O=&$@*CT@<&]W*#(L(#$P*3L*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@5D937U%53U1!7TU%
M5%))0U]-0CH*("`@("`@("`@("`@)'%U;W1A("H]('!O=R@R+"`R,"D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9&4U]154]405]-1512
M24-?1T(Z"B`@("`@("`@("`@("1Q=6]T82`J/2!P;W<H,BP@,S`I.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=V9G-?<75O=&%L:6UI="==(#T@)'%U;W1A.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@5D93('%U;W1A(')O;W0N"B`@("`@*@H@("`@
M("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1I<B`@5&AE(')O;W0@9&ER96-T;W)Y(&9O<B!T:&4@<75O=&$@9&5T
M97)M:6YA=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T475O=&%2;V]T
M*"1D:7(I"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T
M87)O;W0G72`]("1D:7(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@<75O
M=&$@:6YF;W)M871I;VX@*'5S960O86QL;V-A=&5D*2P@:6X@8GET97,N"B`@
M("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($%N(&%S<V]C:6%T:79E(&%R<F%Y+@H@("`@("H@("`@
M("`@("`@("`@("`@)VQI;6ET)R`]($UA>&EM=6T@<75O=&$@86QL;W=E9`H@
M("`@("H@("`@("`@("`@("`@("`@)W5S86=E)R`]($-U<G)E;G1L>2!U<V5D
M('!O<G1I;VX@;V8@<75O=&$@*&EN(&)Y=&5S*0H@("`@("H@("`@("`@("`@
M("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%%U;W1A*"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)W9F<U]Q=6]T86QI;6ET)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO('%U;W1A('-E
M="XB*2D["B`@("`@("`@?0H*("`@("`@("`D=7-A9V4@/2`D=&AI<RT^9V5T
M5D934VEZ92@I.PH@("`@("`@(&EF("AI<U]A*"1U<V%G92P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'5S86=E.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G=7-A9V4G(#T^("1U
M<V%G92P@)VQI;6ET)R`]/B`D=&AI<RT^7W!A<F%M<ULG=F9S7W%U;W1A;&EM
M:70G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M
M:6YE<R!T:&4@;&]C871I;VX@;V8@=&AE('-Y<W1E;2!T96UP;W)A<GD@9&ER
M96-T;W)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@9&ER96-T;W)Y(&YA;64@=VAI
M8V@@8V%N(&)E('5S960@9F]R('1E;7`@9FEL97,N"B`@("`@*B`@("`@("`@
M("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!O;F4@8V]U;&0@;F]T(&)E(&9O
M=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5&5M<$1I<B@I"B`@("![
M"B`@("`@("`@)'1M<%]L;V-A=&EO;G,@/2!A<G)A>2@G+W1M<"<L("<O=F%R
M+W1M<"<L("=C.EQ7551E;7`G+"`G8SI<=&5M<"<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W<UQT96UP)RP@)V,Z7'=I;FYT
M7'1E;7`G*3L*"B`@("`@("`@+RH@5')Y(%!(4"=S('5P;&]A9%]T;7!?9&ER
M(&1I<F5C=&EV92X@*B\*("`@("`@("`D=&UP(#T@:6YI7V=E="@G=7!L;V%D
M7W1M<%]D:7(G*3L*"B`@("`@("`@+RH@3W1H97)W:7-E+"!T<GD@=&\@9&5T
M97)M:6YE('1H92!435!$25(@96YV:7)O;FUE;G0@=F%R:6%B;&4N("HO"B`@
M("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("1T;7`@/2!G
M971E;G8H)U1-4$1)4B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@
M<W1I;&P@8V%N;F]T(&1E=&5R;6EN92!A('9A;'5E+"!T:&5N(&-Y8VQE('1H
M<F]U9V@@82!L:7-T(&]F"B`@("`@("`@("H@<')E<V5T('!O<W-I8FEL:71I
M97,N("HO"B`@("`@("`@=VAI;&4@*&5M<'1Y*"1T;7`I("8F('-I>F5O9B@D
M=&UP7VQO8V%T:6]N<RDI('L*("`@("`@("`@("`@)'1M<%]C:&5C:R`](&%R
M<F%Y7W-H:69T*"1T;7!?;&]C871I;VYS*3L*("`@("`@("`@("`@:68@*$!I
M<U]D:7(H)'1M<%]C:&5C:RDI('L*("`@("`@("`@("`@("`@("1T;7`@/2`D
M=&UP7V-H96-K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!I="!I<R!S=&EL;"!E;7!T>2P@=V4@:&%V92!F86EL960L('-O(')E
M='5R;B!F86QS93L@;W1H97)W:7-E"B`@("`@("`@("H@<F5T=7)N('1H92!D
M:7)E8W1O<GD@9&5T97)M:6YE9"X@*B\*("`@("`@("!R971U<FX@96UP='DH
M)'1M<"D@/R!F86QS92`Z("1T;7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S(&$@=&5M<&]R87)Y(&9I;&4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<F]T96-T960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%)E
M='5R;G,@=&AE(&9U;&P@<&%T:"UN86UE('1O('1H92!T96UP;W)A<GD@9FEL
M92!O<@H@("`@("H@("`@("`@("`@("`@("`@("!F86QS92!I9B!A('1E;7!O
M<F%R>2!F:6QE(&-O=6QD(&YO="!B92!C<F5A=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T5&5M<$9I;&4H*0H@("`@>PH@("`@("`@("1T;7!?9&ER
M(#T@)'1H:7,M/E]G971496UP1&ER*"D["B`@("`@("`@:68@*&5M<'1Y*"1T
M;7!?9&ER*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D=&UP7V9I;&4@/2!T96UP;F%M*"1T;7!?9&ER+"`G=F9S
M)RD["@H@("`@("`@("\J($EF('1H92!F:6QE('=A<R!C<F5A=&5D+"!T:&5N
M(')E9VES=&5R(&ET(&9O<B!D96QE=&EO;B!A;F0*("`@("`@("`@*B!R971U
M<FXN("HO"B`@("`@("`@:68@*&5M<'1Y*"1T;7!?9FEL92DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D=&UP7V9I;&4["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0VAE8VMS('1H92!Q=6]T82!W:&5N('!R97!A<FEN9R!T;R!W
M<FET92!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@("!%:71H97(@)W-T<FEN
M9R<@;W(@)V9I;&4G+B`@268@)W-T<FEN9R<L("1D871A(&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&1A=&$@=&\@8F4@=W)I='1E;BX@
M($EF("=F:6QE)RP@)&1A=&$@:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9FEL96YA;64@8V]N=&%I;FEN9R!T:&4@9&%T82!T;R!B92!W
M<FET=&5N+@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&1A=&$@($5I=&AE<B!T
M:&4@9&%T82!O<B!T:&4@9FEL96YA;64@=&\@=&AE(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@4$5!4E]%<G)O<B!O;B!E<G)O<BP@=')U
M92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM1=6]T
M85=R:71E*"1M;V1E+"`F)&1A=&$I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?<&%R86US6R=V9G-?<75O=&%L:6UI="==("$]("TQ*2!["B`@("`@("`@
M("`@(&EF("@D;6]D92`]/2`G9FEL92<I('L*("`@("`@("`@("`@("`@("1F
M:6QE<VEZ92`]($!F:6QE<VEZ92@D9&%T82D["B`@("`@("`@("`@("`@("!I
M9B`H)&9I;&5S:7IE(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AF:6QE<VEZ92@I(&9A:6QE9"DN(BDI.PH@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9FEL
M97-I>F4@/2!S=')L96XH)&1A=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1V9G-S:7IE(#T@)'1H:7,M/F=E=%9&4U-I>F4H*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)'9F<W-I>F4L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=F9S<VEZ93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H*"1V9G-S:7IE("L@)&9I;&5S:7IE*2`^("1T:&ES+3Y?
M<&%R86US6R=V9G-?<75O=&%L:6UI="==*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4L('%U;W1A('=I;&P@8F4@97AC965D960N(BDI.PH@("`@("`@("`@
M("!](&5L<V5I9B`H)'1H:7,M/E]V9G-3:7IE("$]/2`P*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W9F<U-I>F4@*ST@)&9I;&5S:7IE.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@<75O=&$@=VAE;B!P<F5P87)I
M;F<@=&\@9&5L971E(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@=&AE(&9I;&4@:7,@;&]C871E9"!I;BX*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!014%27T5R<F]R(&]N(&5R<F]R+"!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C:&5C:U%U;W1A1&5L971E*"1P871H
M+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H*"1T:&ES+3Y?<&%R86US6R=V
M9G-?<75O=&%L:6UI="==("$]("TQ*2`F)@H@("`@("`@("`@("`A96UP='DH
M)'1H:7,M/E]V9G-3:7IE*2D@>PH@("`@("`@("`@("`D9FEL97-I>F4@/2`D
M=&AI<RT^<VEZ92@D<&%T:"P@)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?
M82@D9FEL97-I>F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R96%D(%9&
M4R!F:6QE("AS:7IE*"D@9F%I;&5D*2XB*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]V9G-3:7IE("T]("1F:6QE<VEZ93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@5D93(&EN<W1A;F-E
M(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%9&4R!S=6)C;&%S<R!T
M;R!R971U<FXN(%1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I
M<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1D<FEV97(I+B!4:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;V1E(&ES(&1Y;F%M:6-A
M;&QY(&EN8VQU9&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@5D93("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!61E,@
M:6YS=&%N8V4L(&]R(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN8VQU
M9&5?;VYC92`G5D93+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@("1C
M;&%S<R`]("=61E-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1V9G,@/2`F;F5W("1C;&%S
M<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F9S
M(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(I+"`D8VQA<W,I*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=F9S.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@5D93
M(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+B!)="!W:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO(%9&4R!I;G-T86YC92!W
M:71H('1H90H@("`@("H@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES
M=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT
M:7!L92!T>7!E<R!O9B!F:6QE(&)A8VME;F1S("AA;F0L('1H=7,L"B`@("`@
M*B!M=6QT:7!L92!61E,@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R
M(#T@)E9&4SHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX
M960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@5D93('-U8F-L87-S
M('1O(')E='5R;BX@5&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&ES(&)A<V5D(&]N('1H92!S=&]R86=E(&1R:79E<B`H)&1R:79E<BDN(%1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O9&4@:7,@9'EN86UI
M8V%L;'D@:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO
M;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@
M<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!61E,@(%1H92!C;VYC<F5T92!61E,@<F5F97)E;F-E+"!O
M<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I
M<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)E9&4SHZ9F%C=&]R>2@D9')I=F5R
M+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N
M8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O87!I+G!H<```````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-3(W
M-S4@,3`U,34T,S0Q-#$@,#$W-C`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!(;W)D92!E>'1E<FYA
M;"!!4$D@:6YT97)F86-E+@H@*@H@*B!4:&ES(&9I;&4@9&5F:6YE<R!(;W)D
M92=S(&5X=&5R;F%L($%022!I;G1E<F9A8V4N($]T:&5R"B`J(&%P<&QI8V%T
M:6]N<R!C86X@:6YT97)A8W0@=VET:"!(;W)D92!T:')O=6=H('1H:7,@05!)
M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]A<&DN<&AP+'8@,2XT,RXR+C4@
M,C`P-B\P-2\P-"`Q,SHR-SHR."!J86X@17AP("0*("H*("H@0'!A8VMA9V4@
M2&]R9&4*("HO"@HO*B!#;VUP;&5X('1Y<&5S+B`J+PHD7W1Y<&5S(#T@87)R
M87DH"B`@("`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<@/3X@87)R87DH87)R
M87DH)VET96TG(#T^("=S=')I;F<G*2DL"B`@("`G:&%S:$ET96TG(#T^(&%R
M<F%Y*"=K97DG(#T^("=S=')I;F<G+"`G=F%L=64G(#T^("=S=')I;F<G*2P*
M("`@("=H87-H)R`]/B!A<G)A>2AA<G)A>2@G:71E;2<@/3X@)WMU<FXZ:&]R
M9&5]:&%S:$ET96TG*2DL"B`@("`G:&%S:$AA<VA)=&5M)R`]/B!A<G)A>2@G
M:V5Y)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]/B`G>W5R;CIH;W)D97UH87-H
M)RDL"B`@("`G:&%S:$AA<V@G(#T^(&%R<F%Y*&%R<F%Y*"=I=&5M)R`]/B`G
M>W5R;CIH;W)D97UH87-H2&%S:$ET96TG*2DI.PH*+RH@3&ES=&EN9W,N("HO
M"B1?<V5R=FEC97-;)W!E<FUS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A
M<G)A>2@I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y
M)RD["@HD7W-E<G9I8V5S6R=A9&UI;E]L:7-T)UT@/2!A<G)A>2AT<G5E*3L*
M"B1?<V5R=FEC97-;)VQI<W1!<'!S)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]
M/B!A<G)A>2@G9FEL=&5R)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I
M+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)PHI.PH*
M)%]S97)V:6-E<ULG;&ES=$%027,G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^
M(&%R<F%Y*"DL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R
M87DG"BD["@HO*B!";&]C:W,N("HO"B1?<V5R=FEC97-;)V)L;V-K5&ET;&4G
M72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=A<'`G(#T^("=S=')I
M;F<G+"`G;F%M92<@/3X@)W-T<FEN9R<L("=P87)A;7,G(#T^("=[=7)N.FAO
M<F1E?6AA<V@G*2P*("`@("=T>7!E)R`]/B`G<W1R:6YG)PHI.PH*)%]S97)V
M:6-E<ULG8FQO8VM#;VYT96YT)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A
M<G)A>2@G87!P)R`]/B`G<W1R:6YG)RP@)VYA;64G(#T^("=S=')I;F<G+"`G
M<&%R86US)R`]/B`G>W5R;CIH;W)D97UH87-H)RDL"B`@("`G='EP92<@/3X@
M)W-T<FEN9R<**3L*"B1?<V5R=FEC97-;)V)L;V-K<R==(#T@87)R87DH"B`@
M("`G87)G<R<@/3X@87)R87DH*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D
M97UH87-H)PHI.PH*+RH@57-E<B!D871A+B`J+PHD7W-E<G9I8V5S6R=G9710
M<F5F97)E;F-E)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G87!P
M)R`]/B`G<W1R:6YG)RP@)W!R968G(#T^("=S=')I;F<G*2P*("`@("=T>7!E
M)R`]/B`G<W1R:6YG)PHI.PH*)%]S97)V:6-E<ULG<V5T4')E9F5R96YC92==
M(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)V%P<"<@/3X@)W-T<FEN
M9R<L("=P<F5F)R`]/B`G<W1R:6YG)RP@)W9A;'5E)R`]/B`G<W1R:6YG)RDL
M"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=R96UO
M=F55<V5R1&%T82==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W5S
M97(G(#T^("=S=')I;F<G*2P*("`@("=T>7!E)R`]/B`G8F]O;&5A;B<**3L*
M"B\J($=R;W5P<RX@*B\*)%]S97)V:6-E<ULG861D1W)O=7`G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RP@)W!A
M<F5N="<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI
M.PH*)%]S97)V:6-E<ULG<F5M;W9E1W)O=7`G72`](&%R<F%Y*`H@("`@)V%R
M9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@
M/3X@)V)O;VQE86XG"BD["@HO+R1?<V5R=FEC97-;)V=E=$=R;W5P<R==.R`_
M/S\*"B1?<V5R=FEC97-;)V%D9%5S97)4;T=R;W5P)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@G;F%M92<@/3X@)W-T<FEN9R<L("=U<V5R)R`]
M/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E
M<G9I8V5S6R=A9&15<V5R<U1O1W)O=7`G72`](&%R<F%Y*`H@("`@)V%R9W,G
M(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RP@)W5S97)S)R`]/B`G>W5R
M;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N
M)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<D9R;VU'<F]U<"==(#T@87)R
M87DH"B`@("`G87)G<R<@/3X@87)R87DH)VYA;64G(#T^("=S=')I;F<G+"`G
M=7-E<B<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI
M.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<G-&<F]M1W)O=7`G72`](&%R<F%Y
M*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=N86UE)R`]/B`G<W1R:6YG)RP@)W5S
M97)S)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y<&4G
M(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG;&ES=%5S97)S3V9'<F]U
M<"==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)VYA;64G(#T^("=S
M=')I;F<G*2P*("`@("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A
M>2<**3L*"B\J(%-H87)E<RX@*B\*)%]S97)V:6-E<ULG861D4VAA<F4G72`]
M(&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^("=S
M=')I;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)W-H87)E5&ET;&4G
M(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S=')I;F<G*2P*("`@("=T
M>7!E)R`]/B`G8F]O;&5A;B<**3L*"B1?<V5R=FEC97-;)W)E;6]V95-H87)E
M)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T)R`]
M/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y
M<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG;&ES=%-H87)E<T]F
M3W=N97(G72`](&%R<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O
M;W0G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S=')I;F<G*2P*("`@
M("=T>7!E)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<**3L*"B1?<V5R
M=FEC97-;)V%D9%5S97)097)M:7-S:6]N<R==(#T@87)R87DH"B`@("`G87)G
M<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA
M;64G(#T^("=S=')I;F<G+"`G=7-E<DYA;64G(#T^("=S=')I;F<G+"`G<&5R
M;6ES<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G
M='EP92<@/3X@)V)O;VQE86XG"BD["@HD7W-E<G9I8V5S6R=A9&1'<F]U<%!E
M<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA
M<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L
M("=G<F]U<$YA;64G(#T^("=S=')I;F<G+"`G<&5R;6ES<VEO;G,G(#T^("=[
M=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@/3X@)V)O;VQE
M86XG"BD["@HD7W-E<G9I8V5S6R=S9715<V5R4&5R;6ES<VEO;G,G72`](&%R
M<F%Y*`H@("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I
M;F<G+"`G<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)W5S97).86UE)R`]/B`G
M<W1R:6YG)RP@)W!E<FUI<W-I;VYS)R`]/B`G>W5R;CIH;W)D97US=')I;F=!
M<G)A>2<I+`H@("`@)W1Y<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E
M<ULG<V5T1W)O=7!097)M:7-S:6]N<R==(#T@87)R87DH"B`@("`G87)G<R<@
M/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G
M(#T^("=S=')I;F<G+"`G9W)O=7!.86UE)R`]/B`G<W1R:6YG)RP@)W!E<FUI
M<W-I;VYS)R`]/B`G>W5R;CIH;W)D97US=')I;F=!<G)A>2<I+`H@("`@)W1Y
M<&4G(#T^("=B;V]L96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E57-E<E!E
M<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@("=A<F=S)R`]/B!A<G)A>2@G<VAA
M<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H87)E3F%M92<@/3X@)W-T<FEN9R<L
M("=U<V5R3F%M92<@/3X@)W-T<FEN9R<I+`H@("`@)W1Y<&4G(#T^("=B;V]L
M96%N)PHI.PH*)%]S97)V:6-E<ULG<F5M;W9E1W)O=7!097)M:7-S:6]N<R==
M(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@
M)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G9W)O=7!.86UE
M)R`]/B`G<W1R:6YG)RDL"B`@("`G='EP92<@/3X@)V)O;VQE86XG"BD["@HD
M7W-E<G9I8V5S6R=L:7-T57-E<E!E<FUI<W-I;VYS)UT@/2!A<G)A>2@*("`@
M("=A<F=S)R`]/B!A<G)A>2@G<VAA<F52;V]T)R`]/B`G<W1R:6YG)RP@)W-H
M87)E3F%M92<@/3X@)W-T<FEN9R<L("=U<V5R3F%M92<@/3X@)W-T<FEN9R<I
M+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)PHI.PH*
M)%]S97)V:6-E<ULG;&ES=$=R;W5P4&5R;6ES<VEO;G,G72`](&%R<F%Y*`H@
M("`@)V%R9W,G(#T^(&%R<F%Y*"=S:&%R95)O;W0G(#T^("=S=')I;F<G+"`G
M<VAA<F5.86UE)R`]/B`G<W1R:6YG)RP@)V=R;W5P3F%M92<@/3X@)W-T<FEN
M9R<I+`H@("`@)W1Y<&4G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)PHI
M.PH*)%]S97)V:6-E<ULG;&ES=%5S97)S3V93:&%R92==(#T@87)R87DH"B`@
M("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O="<@/3X@)W-T<FEN9R<L("=S
M:&%R94YA;64G(#T^("=S=')I;F<G+"`G<&5R;6ES<VEO;G,G(#T^("=[=7)N
M.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G='EP92<@/3X@)WMU<FXZ:&]R
M9&5]<W1R:6YG07)R87DG"BD["@HD7W-E<G9I8V5S6R=L:7-T1W)O=7!S3V93
M:&%R92==(#T@87)R87DH"B`@("`G87)G<R<@/3X@87)R87DH)W-H87)E4F]O
M="<@/3X@)W-T<FEN9R<L("=S:&%R94YA;64G(#T^("=S=')I;F<G+"`G<&5R
M;6ES<VEO;G,G(#T^("=[=7)N.FAO<F1E?7-T<FEN9T%R<F%Y)RDL"B`@("`G
M='EP92<@/3X@)WMU<FXZ:&]R9&5]<W1R:6YG07)R87DG"BD["@H*+RH@3&ES
M=&EN9W,N("HO"F9U;F-T:6]N(%]H;W)D95]P97)M<R@I"GL*("`@("1P97)M
M<R`](&%R<F%Y*"D["@H@("`@)'!E<FUS6R=T<F5E)UU;)VAO<F1E)UU;)VUA
M>%]B;&]C:W,G72`](&9A;'-E.PH@("`@)'!E<FUS6R=T:71L92==6R=H;W)D
M93IM87A?8FQO8VMS)UT@/2!?*")-87AI;75M($YU;6)E<B!O9B!0;W)T86P@
M0FQO8VMS(BD["B`@("`D<&5R;7-;)W1Y<&4G75LG:&]R9&4Z;6%X7V)L;V-K
M<R==(#T@)VEN="<["@H@("`@<F5T=7)N("1P97)M<SL*?0H*9G5N8W1I;VX@
M7VAO<F1E7V%D;6EN7VQI<W0H*0I["B`@("!R971U<FX@87)R87DH)V-O;F9I
M9W5R871I;VXG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G;&EN
M:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO<V5T=7`O)RP*("`@("`@("`@
M("`@("`@("`@("`@)VYA;64G(#T^(%\H(E]3971U<"(I+`H@("`@("`@("`@
M("`@("`@("`@("`G:6-O;B<@/3X@)V-O;F9I9RYP;F<G*2P*("`@("`@("`@
M("`@("`@("`G=7-E<G,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO=7-E<BYP:'`G+`H@
M("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B7U5S97)S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("=I8V]N)R`]/B`G=7-E<BYP;F<G*2P*("`@
M("`@("`@("`@("`@("`G9W)O=7!S)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+V=R;W5P
M<RYP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B7T=R
M;W5P<R(I+`H@("`@("`@("`@("`@("`@("`@("`G:6-O;B<@/3X@)V=R;W5P
M+G!N9R<I+`H@("`@("`@("`@("`@("`@("=P97)M<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B`G)6%P<&QI8V%T:6]N)2]A
M9&UI;B]P97)M<R]I;F1E>"YP:'`G+`H@("`@("`@("`@("`@("`@("`@("`G
M;F%M92<@/3X@7R@B7U!E<FUI<W-I;VYS(BDL"B`@("`@("`@("`@("`@("`@
M("`@("=I8V]N)R`]/B`G<&5R;7,N<&YG)RDL"B`@("`@("`@("`@("`@("`@
M)V1A=&%T<F5E)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@)VQI
M;FLG(#T^("<E87!P;&EC871I;VXE+V%D;6EN+V1A=&%T<F5E+G!H<"<L"B`@
M("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")?1&%T851R964B*2P*
M("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=D871A=')E92YP;F<G
M*2P*("`@("`@("`@("`@("`@("`G<V5S<VEO;G,G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M
M:6XO<V5S<VEO;G,N<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^(%\H(E-E<W-I;VYS(BDL"B`@("`@("`@("`@("`@("`@("`@("=I8V]N
M)R`]/B`G=7-E<BYP;F<G*2P*("`@("`@("`@("`@("`@("`G<&AP<VAE;&PG
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`G;&EN:R<@/3X@)R5A
M<'!L:6-A=&EO;B4O861M:6XO<&AP<VAE;&PN<&AP)RP*("`@("`@("`@("`@
M("`@("`@("`@)VYA;64G(#T^(%\H(E!?2%`@4VAE;&PB*2P*("`@("`@("`@
M("`@("`@("`@("`@)VEC;VXG(#T^("=M:6UE+W!H<"YP;F<G*2P*("`@("`@
M("`@("`@("`@("`G<W%L<VAE;&PG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`G;&EN:R<@/3X@)R5A<'!L:6-A=&EO;B4O861M:6XO<W%L<VAE
M;&PN<&AP)RP*("`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E-?
M44P@4VAE;&PB*2P*("`@("`@("`@("`@("`@("`@("`@)VEC;VXG(#T^("=S
M<6PN<&YG)RDL"B`@("`@("`@("`@("`@("`@)V-M9'-H96QL)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^("<E87!P;&EC871I
M;VXE+V%D;6EN+V-M9'-H96QL+G!H<"<L"B`@("`@("`@("`@("`@("`@("`@
M("=N86UE)R`]/B!?*")?0TQ)(BDL"B`@("`@("`@("`@("`@("`@("`@("=I
M8V]N)R`]/B`G<VAE;&PN<&YG)RDL"B`@("`@("`@("`@("`@("`@*3L*?0H*
M9G5N8W1I;VX@7VAO<F1E7VQI<W1!<'!S*"1F:6QT97(@/2!N=6QL*0I["B`@
M("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!<'!S*"1F:6QT
M97(I.PI]"@IF=6YC=&EO;B!?:&]R9&5?;&ES=$%027,H*0I["B`@("!R971U
M<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI<W1!4$ES*"D["GT*"B\J($)L
M;V-K<RX@*B\*9G5N8W1I;VX@)E]H;W)D95]B;&]C:R@D87!P+"`D;F%M92P@
M)'!A<F%M<R`](&%R<F%Y*"DI"GL*("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C:RYP:'`G.PH@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]";&]C:R]#;VQL96-T:6]N+G!H<"<["@H@("`@)')E
M<W5L="`]("1R96=I<W1R>2T^<'5S:$%P<"@D87!P*3L*("`@(&EF("@A:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)')E<W5L="`]
M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K*"1A<'`L("1N86UE
M+"`D<&%R86US*3L*("`@("`@("`D<F5G:7-T<GDM/G!O<$%P<"@D87!P*3L*
M("`@('T*("`@(')E='5R;B`D<F5S=6QT.PI]"@IF=6YC=&EO;B!?:&]R9&5?
M8FQO8VM4:71L92@D87!P+"`D;F%M92P@)'!A<F%M<R`](&%R<F%Y*"DI"GL*
M("`@("1B;&]C:R`]("9?:&]R9&5?8FQO8VLH)&%P<"P@)&YA;64L("1P87)A
M;7,I.PH@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@<F5T=7)N("1B;&]C:RT^9V5T365S<V%G92@I.PH@("`@?0H@("`@
M<F5T=7)N("1B;&]C:RT^9V5T5&ET;&4H*3L*?0H*9G5N8W1I;VX@7VAO<F1E
M7V)L;V-K0V]N=&5N="@D87!P+"`D;F%M92P@)'!A<F%M<R`](&%R<F%Y*"DI
M"GL*("`@("1B;&]C:R`]("9?:&]R9&5?8FQO8VLH)&%P<"P@)&YA;64L("1P
M87)A;7,I.PH@("`@:68@*&ES7V$H)&)L;V-K+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@<F5T=7)N("1B;&]C:RT^9V5T365S<V%G92@I.PH@("`@?0H@
M("`@<F5T=7)N("1B;&]C:RT^9V5T0V]N=&5N="@I.PI]"@IF=6YC=&EO;B!?
M:&]R9&5?8FQO8VMS*"D*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]";&]C
M:R]#;VQL96-T:6]N+G!H<"<["B`@("`D8V]L;&5C=&EO;B`]("9(;W)D95]"
M;&]C:U]#;VQL96-T:6]N.CIS:6YG;&5T;VXH*3L*("`@(&EF("AI<U]A*"1C
M;VQL96-T:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1C
M;VQL96-T:6]N.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@)&-O;&QE
M8W1I;VXM/F=E=$)L;V-K<TQI<W0H*3L*("`@('T*?0H*+RH@57-E<B!D871A
M+B`J+PIF=6YC=&EO;B!?:&]R9&5?9V5T4')E9F5R96YC92@D87!P+"`D<')E
M9BD*>PH@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQO8610<F5F<R@D87!P
M*3L*("`@(')E='5R;B`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)'!R
M968I.PI]"@IF=6YC=&EO;B!?:&]R9&5?<V5T4')E9F5R96YC92@D87!P+"`D
M<')E9BP@)'9A;'5E*0I["B`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&]A
M9%!R969S*"1A<'`I.PH@("`@<F5T=7)N("1'3$]"04Q36R=P<F5F<R==+3YS
M971686QU92@D<')E9BP@)'9A;'5E*3L*?0H*9G5N8W1I;VX@7VAO<F1E7W)E
M;6]V955S97)$871A*"1U<V5R*0I["B`@("!G;&]B86P@)&-O;F8["@H@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]0<F5F<RYP:'`G.PH@("`@)'!R969S(#T@
M)E!R969S.CIS:6YG;&5T;VXH)&-O;F9;)W!R969S)UU;)V1R:79E<B==+"!N
M=6QL+"`D=7-E<BD["B`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'!R969S+3YC
M;&5A<B@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"GT*"B\J($=R;W5P<RX@*B\*"B\J*@H@*B!!9&1S(&$@9W)O
M=7`@=&\@=&AE(&=R;W5P<R!S>7-T96TN"B`J"B`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D
M<&%R96YT("!4:&4@9W)O=7`G<R!P87)E;G0G<R!N86UE+@H@*B\*9G5N8W1I
M;VX@7VAO<F1E7V%D9$=R;W5P*"1N86UE+"`D<&%R96YT(#T@;G5L;"D*>PH@
M("`@:68@*&5M<'1Y*"1P87)E;G0I*2!["B`@("`@("`@)'!A<F5N="`]($1!
M5$%44D5%7U)/3U0["B`@("!]"@H@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'
M<F]U<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D[
M"@H@("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/FYE=T=R;W5P*"1N
M86UE+"`D<&%R96YT*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R
M;B`D9W)O=7`["B`@("!]"@H@("`@<F5T=7)N("1G<F]U<',M/F%D9$=R;W5P
M*"1G<F]U<"D["GT*"B\J*@H@*B!296UO=F5S(&$@9W)O=7`@9G)O;2!T:&4@
M9W)O=7!S('-Y<W1E;2X*("H*("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&=R;W5P)W,@;F%M92X*("HO"F9U;F-T:6]N(%]H;W)D95]R96UO=F5'<F]U
M<"@D;F%M92D*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G
M.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@("`@:68@
M*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P*"1N86UE*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@
M("`@<F5T=7)N("1G<F]U<',M/G)E;6]V94=R;W5P*"1G<F]U<"P@=')U92D[
M"GT*"B\J*@H@*B!!9&1S(&$@=7-E<B!T;R!A(&=R;W5P+@H@*@H@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@9W)O=7`G<R!N86UE+@H@*B!`<&%R86T@
M<W1R:6YG("1U<V5R("!4:&4@=7-E<B!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?
M:&]R9&5?861D57-E<E1O1W)O=7`H)&YA;64L("1U<V5R*0I["B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D9W)O=7!S(#T@)D=R
M;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D9W)O=7`@/2`F)&=R
M;W5P<RT^9V5T1W)O=7`H)&YA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@<F5T=7)N("1G<F]U<#L*("`@('T*"B`@("!R971U<FX@)&=R;W5P+3YA
M9&15<V5R*"1U<V5R*3L*?0H*+RHJ"B`J($%D9',@;75L=&EP;&4@=7-E<G,@
M=&\@82!G<F]U<"X*("H*("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&=R
M;W5P)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y("1U<V5R<R`@5&AE('5S97)S
M('1O(&%D9"X*("HO"F9U;F-T:6]N(%]H;W)D95]A9&15<V5R<U1O1W)O=7`H
M)&YA;64L("1U<V5R<RD*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U
M<"YP:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@
M("`@:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P*"1N86UE
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@
M("!]"@H@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2!["B`@("`@("`@
M)&=R;W5P+3YA9&15<V5R*"1U<V5R+"!F86QS92D["B`@("!]"@H@("`@<F5T
M=7)N("1G<F]U<"T^<V%V92@I.PI]"@HO*BH*("H@4F5M;W9E<R!A('5S97(@
M9G)O;2!A(&=R;W5P+@H@*@H@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M9W)O=7`G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1U<V5R("!4:&4@=7-E
M<B!T;R!A9&0N"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<D9R;VU'
M<F]U<"@D;F%M92P@)'5S97(I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M1W)O=7`N<&AP)SL*("`@("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I
M.PH*("`@(&EF("AI<U]A*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D
M;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R;W5P
M.PH@("`@?0H*("`@(')E='5R;B`D9W)O=7`M/G)E;6]V955S97(H)'5S97(I
M.PI]"@HO*BH*("H@4F5M;W9E<R!M=6QT:7!L92!U<V5R<R!F<F]M(&$@9W)O
M=7`N"B`J"B`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!G<F]U<"=S(&YA
M;64N"B`J($!P87)A;2!A<G)A>2`D=7-E<G,@(%1H92!U<V5R<R!T;R!A9&0N
M"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<G-&<F]M1W)O=7`H)&YA
M;64L("1U<V5R<RD*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP
M:'`G.PH@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["@H@("`@
M:68@*&ES7V$H)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P*"1N86UE*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]
M"@H@("`@9F]R96%C:"`H)'5S97)S(&%S("1U<V5R*2!["B`@("`@("`@)&=R
M;W5P+3YR96UO=F55<V5R*"1U<V5R+"!F86QS92D["B`@("!]"@H@("`@<F5T
M=7)N("1G<F]U<"T^<V%V92@I.PI]"@HO*BH*("H@4F5T=7)N<R!A(&QI<W0@
M;V8@=7-E<G,@=&AA="!A<F4@<&%R="!O9B!T:&ES(&=R;W5P("AA;F0@;VYL
M>2!T:&ES(&=R;W5P*0H@*@H@*B!`<F5T=7)N(&%R<F%Y("!4:&4@=7-E<B!L
M:7-T+@H@*B\*9G5N8W1I;VX@7VAO<F1E7VQI<W15<V5R<T]F1W)O=7`H)&YA
M;64I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*("`@
M("1G<F]U<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH*("`@(&EF("AI<U]A
M*"1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D;F%M92DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@(')E
M='5R;B`D9W)O=7`M/FQI<W15<V5R<R@I.PI]"@HO*B!3:&%R97,N("HO"@HO
M*BH*("H@061D<R!A('-H87)E('1O('1H92!S:&%R97,@<WES=&5M+@H@*@H@
M*B!`<&%R86T@<W1R:6YG("1S:&%R95)O;W0@("!4:&4@;F%M92!O9B!T:&4@
M<VAA<F4@<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87!P;&EC871I;VX@=&AA="!T:&4@<VAA<F4@8F5L;VYG<R!T;RX*
M("H@0'!A<F%M('-T<FEN9R`D<VAA<F5.86UE("`@5&AE('-H87)E)W,@;F%M
M92X*("H@0'!A<F%M('-T<FEN9R`D<VAA<F54:71L92`@5&AE('-H87)E)W,@
M:'5M86X@<F5A9&%B;&4@=&ET;&4N"B`J($!P87)A;2!S=')I;F<@)'5S97).
M86UE("`@(%1H92!S:&%R92=S(&]W;F5R+@H@*B\*9G5N8W1I;VX@7VAO<F1E
M7V%D9%-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1S:&%R951I=&QE
M+"`D=7-E<DYA;64I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N
M<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z.G-I;F=L971O;B@D
M<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^
M;F5W4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@)'-H87)E+3YS970H)V]W;F5R
M)RP@)'5S97).86UE*3L*("`@("1S:&%R92T^<V5T*"=N86UE)RP@)'-H87)E
M5&ET;&4I.PH*("`@(')E='5R;B`D<VAA<F5S+3YA9&13:&%R92@D<VAA<F4I
M.PI]"@HO*BH*("H@4F5M;W9E<R!A('-H87)E(&9R;VT@=&AE('-H87)E<R!S
M>7-T96T@<&5R;6%N96YT;'DN"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E
M4F]O="`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87!P;&EC871I;VX@=&AA="!T
M:&4@<VAA<F4@8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA<F5.
M86UE("!4:&4@<VAA<F4G<R!N86UE+@H@*B\*9G5N8W1I;VX@7VAO<F1E7W)E
M;6]V95-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA;64I"GL*("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O4VAA<F4N<&AP)SL*("`@("1S:&%R97,@/2`F2&]R
M9&5?4VAA<F4Z.G-I;F=L971O;B@D<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?
M82@D<VAA<F4@/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H*
M("`@(')E='5R;B`D<VAA<F5S+3YR96UO=F53:&%R92@D<VAA<F4I.PI]"@HO
M*BH*("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@<VAA<F5S('1H870@)'5S
M97).86UE(&ES('1H92!O=VYE<B!O9BX*("H*("H@0'!A<F%M('-T<FEN9R`D
M<VAA<F52;V]T("!4:&4@;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG+B!T
M:&4*("H@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T
M:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1U
M<V5R3F%M92`@(%1H92!S:&%R92=S(&]W;F5R+@H@*@H@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@;&ES="!O9B!S:&%R97,N"B`J+PIF=6YC=&EO;B!?:&]R9&5?
M;&ES=%-H87)E<T]F3W=N97(H)'-H87)E4F]O="P@)'5S97).86UE*0I["B`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA<F5S
M(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@("`@
M)'-H87)E7VQI<W0@/2`F)'-H87)E<RT^;&ES=%-H87)E<R@D=7-E<DYA;64L
M(%!%4DU37U-(3U<L("1U<V5R3F%M92D["B`@("`D;7ES:&%R97,@/2!A<G)A
M>2@I.PH@("`@9F]R96%C:"`H)'-H87)E7VQI<W0@87,@)'-H87)E*2!["B`@
M("`@("`@)&UY<VAA<F5S6UT@/2`D<VAA<F4M/F=E=$YA;64H*3L*("`@('T*
M"B`@("!R971U<FX@)&UY<VAA<F5S.PI]"@HO*BH*("H@1VEV97,@82!U<V5R
M(&-E<G1A:6X@<')I=FEL96=E<R!F;W(@82!S:&%R92X*("H*("H@0'!A<F%M
M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E(')O
M;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P
M<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P87)A
M;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J($!P
M87)A;2!S=')I;F<@)'5S97).86UE("`@(%1H92!U<V5R)W,@;F%M92X*("H@
M0'!A<F%M(&%R<F%Y("1P97)M:7-S:6]N<R`@02!L:7-T(&]F('!E<FUI<W-I
M;VYS("AS:&]W+"!R96%D+"!E9&ET+"!D96QE=&4I+@H@*B\*9G5N8W1I;VX@
M7VAO<F1E7V%D9%5S97)097)M:7-S:6]N<R@D<VAA<F52;V]T+"`D<VAA<F5.
M86UE+"`D=7-E<DYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!E<FUI<W-I;VYS*0I["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+U-H87)E+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG
M;&5T;VXH)'-H87)E4F]O="D["@H@("`@:68@*&ES7V$H)'-H87)E(#T@)B1S
M:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*"B`@("`D<&5R;2`]("8D
M<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@(&9O<F5A8V@@*"1P97)M:7-S
M:6]N<R!A<R`D<&5R;6ES<VEO;BD@>PH@("`@("`@("1P97)M:7-S:6]N(#T@
M4W1R:6YG.CIU<'!E<B@D<&5R;6ES<VEO;BD["B`@("`@("`@:68@*&1E9FEN
M960H)U!%4DU37R<@+B`D<&5R;6ES<VEO;BDI('L*("`@("`@("`@("`@)'!E
M<FTM/F%D9%5S97)097)M:7-S:6]N*"1U<V5R3F%M92P@8V]N<W1A;G0H)U!%
M4DU37R<@+B`D<&5R;6ES<VEO;BDL(&9A;'-E*3L*("`@("`@("!]"B`@("!]
M"B`@("!R971U<FX@)'-H87)E+3YS971097)M:7-S:6]N*"1P97)M*3L*?0H*
M+RHJ"B`J($=I=F5S(&$@9W)O=7`@8V5R=&%I;B!P<FEV:6QE9V5S(&9O<B!A
M('-H87)E+@H@*@H@*B!`<&%R86T@<W1R:6YG("1S:&%R95)O;W0@("!4:&4@
M;F%M92!O9B!T:&4@<VAA<F4@<F]O="P@92YG+B!T:&4*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87!P;&EC871I;VX@=&AA="!T:&4@<VAA<F4@
M8F5L;VYG<R!T;RX*("H@0'!A<F%M('-T<FEN9R`D<VAA<F5.86UE("`@5&AE
M('-H87)E)W,@;F%M92X*("H@0'!A<F%M('-T<FEN9R`D9W)O=7!.86UE("`@
M5&AE(&=R;W5P)W,@;F%M92X*("H@0'!A<F%M(&%R<F%Y("1P97)M:7-S:6]N
M<R`@02!L:7-T(&]F('!E<FUI<W-I;VYS("AS:&]W+"!R96%D+"!E9&ET+"!D
M96QE=&4I+@H@*B\*9G5N8W1I;VX@7VAO<F1E7V%D9$=R;W5P4&5R;6ES<VEO
M;G,H)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VYS*0I[
M"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO
M<F1E7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["B`@("`D9W)O=7!S
M(#T@)D=R;W5P.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@
M/2`F)'-H87)E<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@:68@*&ES
M7V$H)&=R;W5P260@/2`D9W)O=7!S+3YG971'<F]U<$ED*"1G<F]U<$YA;64I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<$ED.PH@
M("`@?0H*("`@("1P97)M(#T@)B1S:&%R92T^9V5T4&5R;6ES<VEO;B@I.PH@
M("`@9F]R96%C:"`H)'!E<FUI<W-I;VYS(&%S("1P97)M:7-S:6]N*2!["B`@
M("`@("`@)'!E<FUI<W-I;VX@/2!3=')I;F<Z.G5P<&5R*"1P97)M:7-S:6]N
M*3L*("`@("`@("!I9B`H9&5F:6YE9"@G4$5235-?)R`N("1P97)M:7-S:6]N
M*2D@>PH@("`@("`@("`@("`D<&5R;2T^861D1W)O=7!097)M:7-S:6]N*"1G
M<F]U<$ED+"!C;VYS=&%N="@G4$5235-?)R`N("1P97)M:7-S:6]N*2P@9F%L
M<V4I.PH@("`@("`@('T*("`@('T*("`@(')E='5R;B`D<VAA<F4M/G-E=%!E
M<FUI<W-I;VXH)'!E<FTI.PI]"@IF=6YC=&EO;B!?:&]R9&5?<V5T57-E<E!E
M<FUI<W-I;VYS*"1S:&%R95)O;W0L("1S:&%R94YA;64L("1U<V5R3F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&5R;6ES<VEO
M;G,I"GL*?0H*9G5N8W1I;VX@7VAO<F1E7W-E=$=R;W5P4&5R;6ES<VEO;G,H
M)'-H87)E4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FUI<W-I;VYS*0I["GT*
M"B\J*@H@*B!296UO=F5S(&$@=7-E<B!F<F]M(&$@<VAA<F4N"B`J"B`J($!P
M87)A;2!S=')I;F<@)'-H87)E4F]O="`@(%1H92!N86UE(&]F('1H92!S:&%R
M92!R;V]T+"!E+F<N('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<'!L:6-A=&EO;B!T:&%T('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`
M<&%R86T@<W1R:6YG("1S:&%R94YA;64@("!4:&4@<VAA<F4G<R!N86UE+@H@
M*B!`<&%R86T@<W1R:6YG("1U<V5R3F%M92`@("!4:&4@=7-E<B=S(&YA;64N
M"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E57-E<E!E<FUI<W-I;VYS*"1S
M:&%R95)O;W0L("1S:&%R94YA;64L("1U<V5R3F%M92D*>PH@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D
M95]3:&%R93HZ<VEN9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A
M*"1S:&%R92`]("8D<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@
M("`@<F5T=7)N("1S:&%R92T^<F5M;W9E57-E<B@D=7-E<DYA;64I.PI]"@HO
M*BH*("H@4F5M;W9E<R!A(&=R;W5P(&9R;VT@82!S:&%R92X*("H*("H@0'!A
M<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE(&YA;64@;V8@=&AE('-H87)E
M(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E(&)E;&]N9W,@=&\N"B`J($!P
M87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H92!S:&%R92=S(&YA;64N"B`J
M($!P87)A;2!S=')I;F<@)&=R;W5P3F%M92`@(%1H92!G<F]U<"=S(&YA;64N
M"B`J+PIF=6YC=&EO;B!?:&]R9&5?<F5M;W9E1W)O=7!097)M:7-S:6]N<R@D
M<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D9W)O=7!.86UE*0I["B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+T=R;W5P+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E7U-H87)E
M.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["B`@("`D9W)O=7!S(#T@)D=R;W5P
M.CIS:6YG;&5T;VXH*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@/2`F)'-H87)E
M<RT^9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("!R971U<FX@)'-H87)E.PH@("`@?0H@("`@:68@*&ES7V$H)&=R;W5P
M260@/2`D9W)O=7!S+3YG971'<F]U<$ED*"1G<F]U<$YA;64I+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1G<F]U<$ED.PH@("`@?0H*("`@
M(')E='5R;B`D<VAA<F4M/G)E;6]V94=R;W5P*"1G<F]U<$ED*3L*?0H*+RHJ
M"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL('5S97(@<&5R;6ES<VEO;G,@
M;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@
M5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H
M87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@
M(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!S=')I;F<@)'5S97).86UE
M("`@(%1H92!U<V5R)W,@;F%M92X*("H*("H@0')E='5R;B!A<G)A>2`@06QL
M('5S97(@<&5R;6ES<VEO;G,@9F]R('1H:7,@<VAA<F4N"B`J+PIF=6YC=&EO
M;B!?:&]R9&5?;&ES=%5S97)097)M:7-S:6]N<R@D<VAA<F52;V]T+"`D<VAA
M<F5.86UE+"`D=7-E<DYA;64I"GL*("`@("1P97)M7VUA<"`](&%R<F%Y*%!%
M4DU37U-(3U<@/3X@)W-H;W<G+`H@("`@("`@("`@("`@("`@("`@("`@4$52
M35-?4D5!1"`]/B`G<F5A9"<L"B`@("`@("`@("`@("`@("`@("`@("!015)-
M4U]%1$E4(#T^("=E9&ET)RP*("`@("`@("`@("`@("`@("`@("`@(%!%4DU3
M7T1%3$5412`]/B`G9&5L971E)RD["@H@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]3:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D95]3:&%R93HZ<VEN
M9VQE=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A*"1S:&%R92`]("8D
M<VAA<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@("`@)'!E<FT@/2`F
M)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("`D<&5R;6ES<VEO;G,@/2`D
M<&5R;2T^9V5T57-E<E!E<FUI<W-I;VYS*"D["B`@("!I9B`H96UP='DH)'!E
M<FUI<W-I;VYS6R1U<V5R3F%M95TI*2!["B`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("!]"@H@("`@)'5S97)?<&5R;6ES<VEO;G,@/2!A<G)A>2@I.PH@
M("`@9F]R96%C:"`H87)R87E?:V5Y<RA097)M<SHZ:6YT96=E<E1O07)R87DH
M)'!E<FUI<W-I;VYS6R1U<V5R3F%M95TI*2!A<R`D<&5R;6ES<VEO;BD@>PH@
M("`@("`@("1U<V5R7W!E<FUI<W-I;VYS6UT@/2`D<&5R;5]M87!;)'!E<FUI
M<W-I;VY=.PH@("`@?0H*("`@(')E='5R;B`D=7-E<E]P97)M:7-S:6]N<SL*
M?0H*+RHJ"B`J(%)E='5R;G,@86X@87)R87D@;V8@86QL(&=R;W5P('!E<FUI
M<W-I;VYS(&]N(&$@<VAA<F4N"B`J"B`J($!P87)A;2!S=')I;F<@)'-H87)E
M4F]O="`@(%1H92!N86UE(&]F('1H92!S:&%R92!R;V]T+"!E+F<N('1H90H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!L:6-A=&EO;B!T:&%T
M('1H92!S:&%R92!B96QO;F=S('1O+@H@*B!`<&%R86T@<W1R:6YG("1S:&%R
M94YA;64@("!4:&4@<VAA<F4G<R!N86UE+@H@*B!`<&%R86T@<W1R:6YG("1G
M<F]U<$YA;64@("!4:&4@9W)O=7`G<R!N86UE+@H@*@H@*B!`<F5T=7)N(&%R
M<F%Y("!!;&P@9W)O=7`@<&5R;6ES<VEO;G,@9F]R('1H:7,@<VAA<F4N"B`J
M+PIF=6YC=&EO;B!?:&]R9&5?;&ES=$=R;W5P4&5R;6ES<VEO;G,H)'-H87)E
M4F]O="P@)'-H87)E3F%M92P@)&=R;W5P3F%M92D*>PH@("`@)'!E<FU?;6%P
M(#T@87)R87DH4$5235-?4TA/5R`]/B`G<VAO=R<L"B`@("`@("`@("`@("`@
M("`@("`@("!015)-4U]214%$(#T^("=R96%D)RP*("`@("`@("`@("`@("`@
M("`@("`@(%!%4DU37T5$250@/3X@)V5D:70G+`H@("`@("`@("`@("`@("`@
M("`@("`@4$5235-?1$5,151%(#T^("=D96QE=&4G*3L*"B`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U-H87)E+G!H<"<["B`@("`D<VAA<F5S(#T@)DAO<F1E
M7U-H87)E.CIS:6YG;&5T;VXH)'-H87)E4F]O="D["@H@("`@:68@*&ES7V$H
M)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E*"1S:&%R94YA;64I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@<F5T=7)N("1S:&%R93L*("`@('T*"B`@
M("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E<FUI<W-I;VXH*3L*("`@("1P97)M
M:7-S:6]N<R`]("1P97)M+3YG971'<F]U<%!E<FUI<W-I;VYS*"D["B`@("!I
M9B`H96UP='DH)'!E<FUI<W-I;VYS6R1G<F]U<$YA;65=*2D@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("1G<F]U<%]P97)M:7-S:6]N
M<R`](&%R<F%Y*"D["B`@("!F;W)E86-H("AA<G)A>5]K97ES*%!E<FUS.CII
M;G1E9V5R5&]!<G)A>2@D<&5R;6ES<VEO;G-;)&=R;W5P3F%M95TI*2!A<R`D
M<&5R;6ES<VEO;BD@>PH@("`@("`@("1G<F]U<%]P97)M:7-S:6]N<UM=(#T@
M)'!E<FU?;6%P6R1P97)M:7-S:6]N73L*("`@('T*"B`@("!R971U<FX@)&=R
M;W5P7W!E<FUI<W-I;VYS.PI]"@HO*BH*("H@4F5T=7)N<R!A(&QI<W0@;V8@
M=7-E<G,@=VAI8V@@:&%V92!H879E(&-E<G1A:6X@<&5R;6ES<VEO;G,@;VX@
M82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@5&AE
M(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H87)E
M(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@(%1H
M92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D<&5R;6ES<VEO;G,@
M($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@<F5A9"P@961I="P@9&5L
M971E*2X*("H*("H@0')E='5R;B!A<G)A>2`@3&ES="!O9B!U<V5R<R!W:71H
M('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N"B`J+PIF=6YC=&EO;B!?:&]R
M9&5?;&ES=%5S97)S3V93:&%R92@D<VAA<F52;V]T+"`D<VAA<F5.86UE+"`D
M<&5R;6ES<VEO;G,I"GL*("`@(')E<75I<F5?;VYC92`G2&]R9&4O4VAA<F4N
M<&AP)SL*("`@("1S:&%R97,@/2`F2&]R9&5?4VAA<F4Z.G-I;F=L971O;B@D
M<VAA<F52;V]T*3L*"B`@("!I9B`H:7-?82@D<VAA<F4@/2`F)'-H87)E<RT^
M9V5T4VAA<F4H)'-H87)E3F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("!R971U<FX@)'-H87)E.PH@("`@?0H*("`@("1P97)M(#T@,#L*("`@(&9O
M<F5A8V@@*"1P97)M:7-S:6]N<R!A<R`D<&5R;6ES<VEO;BD@>PH@("`@("`@
M("1P97)M:7-S:6]N(#T@4W1R:6YG.CIU<'!E<B@D<&5R;6ES<VEO;BD["B`@
M("`@("`@:68@*&1E9FEN960H)U!%4DU37R<@+B`D<&5R;6ES<VEO;BDI('L*
M("`@("`@("`@("`@)'!E<FT@)CT@8V]N<W1A;G0H)U!%4DU37R<@+B`D<&5R
M;6ES<VEO;BD["B`@("`@("`@?0H@("`@?0H*("`@(')E='5R;B`D<VAA<F4M
M/FQI<W15<V5R<R@D<&5R;2D["GT*"B\J*@H@*B!2971U<FYS(&$@;&ES="!O
M9B!G<F]U<',@=VAI8V@@:&%V92!H879E(&-E<G1A:6X@<&5R;6ES<VEO;G,@
M;VX@82!S:&%R92X*("H*("H@0'!A<F%M('-T<FEN9R`D<VAA<F52;V]T("`@
M5&AE(&YA;64@;V8@=&AE('-H87)E(')O;W0L(&4N9RX@=&AE"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N('1H870@=&AE('-H
M87)E(&)E;&]N9W,@=&\N"B`J($!P87)A;2!S=')I;F<@)'-H87)E3F%M92`@
M(%1H92!S:&%R92=S(&YA;64N"B`J($!P87)A;2!A<G)A>2`D<&5R;6ES<VEO
M;G,@($$@;&ES="!O9B!P97)M:7-S:6]N<R`H<VAO=RP@<F5A9"P@961I="P@
M9&5L971E*2X*("H*("H@0')E='5R;B!A<G)A>2`@3&ES="!O9B!G<F]U<',@
M=VET:"!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@*B\*9G5N8W1I;VX@
M7VAO<F1E7VQI<W1'<F]U<'-/9E-H87)E*"1S:&%R95)O;W0L("1S:&%R94YA
M;64L("1P97)M:7-S:6]N<RD*>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3
M:&%R92YP:'`G.PH@("`@)'-H87)E<R`]("9(;W)D95]3:&%R93HZ<VEN9VQE
M=&]N*"1S:&%R95)O;W0I.PH*("`@(&EF("AI<U]A*"1S:&%R92`]("8D<VAA
M<F5S+3YG9713:&%R92@D<VAA<F5.86UE*2P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]"@H@("`@)'!E<FT@/2`P.PH@
M("`@9F]R96%C:"`H)'!E<FUI<W-I;VYS(&%S("1P97)M:7-S:6]N*2!["B`@
M("`@("`@)'!E<FUI<W-I;VX@/2!3=')I;F<Z.G5P<&5R*"1P97)M:7-S:6]N
M*3L*("`@("`@("!I9B`H9&5F:6YE9"@G4$5235-?)R`N("1P97)M:7-S:6]N
M*2D@>PH@("`@("`@("`@("`D<&5R;2`F/2!C;VYS=&%N="@G4$5235-?)R`N
M("1P97)M:7-S:6]N*3L*("`@("`@("!]"B`@("!]"@H@("`@<F5T=7)N("1S
M:&%R92T^;&ES=$=R;W5P<R@D<&5R;2D["GT*````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TYE="]335,`````````````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30Q(#`Q
M-S0Q,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U``````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q-#$@,#$W-3$V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B].970O4TU3+G!H<```````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`R-3(Q-"`Q,#4Q-30S-#$T,2`P,C`R,#0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J($YE=%]335,@0VQA<W,*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO
M0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO3F5T7U--4R]335,N<&AP+'8@,2XQ,"XQ,"XQ,"`R,#`V+S`Q+S`Q(#(Q
M.C(X.C(X(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!.971?4TU3"B`J+PIC;&%S
M<R!.971?4TU3('L*"B`@("`O*BH*("`@("`J($$@:&%S:"!C;VYT86EN:6YG
M(&%N>2!P87)A;65T97)S(&9O<B!T:&4@8W5R<F5N="!G871E=V%Y(&1R:79E
M<BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@=F%R("1?875T:"`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!N965D960@9F]R('1H
M:7,@9V%T97=A>2!D<FEV97(N"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%]3
M35,H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A
M;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&QI<W0@;V8@879A:6QA8FQE(&=A=&5W87D@9')I=F5R<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B;&4@9')I
M=F5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1')I=F5R<R@I"B`@("![
M"B`@("`@("`@<W1A=&EC("1D<FEV97)S(#T@87)R87DH*3L*("`@("`@("!I
M9B`H(65M<'1Y*"1D<FEV97)S*2D@>PH@("`@("`@("`@("!R971U<FX@)&1R
M:79E<G,["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R<R`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@D9')I=F5R7V1I<B`](&]P96YD:7(H9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+U--4R\G*2D@>PH@("`@("`@("`@("!W:&EL92`H9F%L
M<V4@(3T]("@D9FEL92`](')E861D:7(H)&1R:79E<E]D:7(I*2D@>PH@("`@
M("`@("`@("`@("`@+RH@2&ED92!D;W0@9FEL97,@86YD(&YO;B`N<&AP(&9I
M;&5S+B`J+PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D9FEL92P@,"P@
M,2D@(3T@)RXG("8F('-U8G-T<B@D9FEL92P@+30I(#T]("<N<&AP)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1D<FEV97(@/2!S=6)S='(H)&9I;&4L(#`L
M("TT*3L*("`@("`@("`@("`@("`@("`@("`D9')I=F5R7VEN9F\@/2!.971?
M4TU3.CIG971'871E=V%Y26YF;R@D9')I=F5R*3L*("`@("`@("`@("`@("`@
M("`@("`D9')I=F5R<ULD9')I=F5R72`]("1D<FEV97)?:6YF;ULG;F%M92==
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&-L;W-E9&ER*"1D<FEV97)?9&ER*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D9')I=F5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M:6YF;W)M871I;VX@;VX@82!G871E=V%Y+"!S=6-H(&%S(&YA;64@86YD(&$@
M8G)I968@9&5S8W)I<'1I;VXL"B`@("`@*B!F<F]M('1H92!D<FEV97(@<W5B
M8VQA<W,@9V5T26YF;R@I(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($%N(&%R<F%Y(&]F(&5X=')A(&EN9F]R;6%T:6]N+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971'871E=V%Y26YF;R@D9V%T97=A>2D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN9F\@/2!A<G)A>2@I.PH@("`@("`@(&EF
M("AI<W-E="@D:6YF;ULD9V%T97=A>5TI*2!["B`@("`@("`@("`@(')E='5R
M;B`D:6YF;ULD9V%T97=A>5T["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E
M7V]N8V4@)TYE="]335,O)R`N("1G871E=V%Y("X@)RYP:'`G.PH@("`@("`@
M("1C;&%S<R`]("=.971?4TU37R<@+B`D9V%T97=A>3L*("`@("`@("`D:6YF
M;ULD9V%T97=A>5T@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA<W,L("=G
M971);F9O)RDI.PH*("`@("`@("!R971U<FX@)&EN9F];)&=A=&5W87E=.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!P87)A;65T97)S(&9O<B!A
M(&=A=&5W87D@9G)O;2!T:&4@9')I=F5R('-U8F-L87-S(&=E=%!A<F%M<R@I
M"B`@("`@*B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("!4:&4@;F%M92!O9B!T:&4@9V%T97=A>2!D<FEV97(@9F]R('=H:6-H('1O
M(')E='5R;B!T:&4*("`@("`J("`@("`@("`@("`@("`@('!A<F%M971E<G,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@97AT
M<F$@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=A=&5W
M87E087)A;7,H)&=A=&5W87DI"B`@("!["B`@("`@("`@<W1A=&EC("1P87)A
M;7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R1G871E
M=V%Y72DI('L*("`@("`@("`@("`@<F5T=7)N("1P87)A;7-;)&=A=&5W87E=
M.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=.970O4TU3+R<@
M+B`D9V%T97=A>2`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G3F5T7U--
M4U\G("X@)&=A=&5W87D["B`@("`@("`@)'!A<F%M<ULD9V%T97=A>5T@/2!C
M86QL7W5S97)?9G5N8RAA<G)A>2@D8VQA<W,L("=G971087)A;7,G*2D["@H@
M("`@("`@(')E='5R;B`D<&%R86US6R1G871E=V%Y73L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@<V5N9"!P87)A;65T97)S(&9O<B!A(&=A=&5W
M87D@9G)O;2!T:&4@9')I=F5R('-U8F-L87-S"B`@("`@*B!G971$969A=6QT
M4V5N9%!A<F%M<R@I9G5N8W1I;VXN(%1H97-E(&%R92!P87)A;65T97)S('=H
M:6-H(&%R92!A=F%I;&%B;&4*("`@("`J('1O('1H92!U<V5R(&1U<FEN9R!S
M96YD:6YG+"!S=6-H(&%S('-E='1I;F<@82!T:6UE(&9O<B!D96QI=F5R>2P@
M;W(@='EP90H@("`@("H@;V8@4TU3("AN;W)M86P@=&5X="!O<B!F;&%S:"DL
M(&]R('-O=7)C92!A9&1R97-S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE(&=A=&5W87D@9')I=F5R(&9O<B!W
M:&EC:"!T;R!R971U<FX@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!S96YD
M('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@;V8@879A:6QA8FQE('-E;F0@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T1&5F875L=%-E;F1087)A;7,H)&=A=&5W87DI"B`@
M("!["B`@("`@("`@<W1A=&EC("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@
M(&EF("AI<W-E="@D<&%R86US6R1G871E=V%Y72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1P87)A;7-;)&=A=&5W87E=.PH@("`@("`@('T*"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=.970O4TU3+R<@+B`D9V%T97=A>2`N("<N<&AP)SL*
M("`@("`@("`D8VQA<W,@/2`G3F5T7U--4U\G("X@)&=A=&5W87D["B`@("`@
M("`@)'!A<F%M<ULD9V%T97=A>5T@/2!C86QL7W5S97)?9G5N8RAA<G)A>2@D
M8VQA<W,L("=G971$969A=6QT4V5N9%!A<F%M<R<I*3L*"B`@("`@("`@<F5T
M=7)N("1P87)A;7-;)&=A=&5W87E=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M475E<GD@=&AE(&-U<G)E;G0@1V%T97=A>2!O8FIE8W0@=&\@9FEN9"!O=70@
M:68@:70@<W5P<&]R=',@=&AE(&=I=F5N"B`@("`@*B!C87!A8FEL:71Y+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A<&%B:6QI='D@(%1H92!C
M87!A8FEL:71Y('1O('1E<W0@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%=H971H97(@;W(@;F]T('1H92!C87!A8FEL:71Y(&ES('-U<'!O
M<G1E9"!O<B!A;GD@;W1H97(*("`@("`J("`@("`@("`@("`@("`@('9A;'5E
M('1H870@=&AE(&-A<&%B:6QI='D@=VES:&5S('1O(')E<&]R="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:&%S0V%P86)I;&ET>2@D8V%P86)I;&ET>2D*("`@
M('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3YC87!A8FEL:71I97-;)&-A
M<&%B:6QI='E=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-A<&%B
M:6QI=&EE<ULD8V%P86)I;&ET>5T["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($%U=&AE;G1I8V%T97,@
M86=A:6YS="!T:&4@9V%T97=A>2!I9B!R97%U:7)E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H96YT:6-A
M=&4H*0H@("`@>PH@("`@("`@("\J($1O(&%U=&AE;G1I8V%T:6]N(&9O<B!T
M:&ES(&=A=&5W87D@:68@9')I=F5R(')E<75I<F5S(&ET+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G875T:"<I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?875T:"`]("1T:&ES+3Y?875T:&5N=&EC871E*"D["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%U=&@["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@
M82!M97-S86=E('1O(&]N92!O<B!M;W)E(')E8VEP:65N=',N($AA;F1S(&]F
M9B!T:&4@86-T=6%L('-E;F1I;F<*("`@("`J('1O('1H92!G871E=V%Y(&1R
M:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@(%1H
M92!M97-S86=E('1O(&)E('-E;G0L('=H:6-H(&ES(&-O;7!O<V5D(&]F.@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`\<')E/@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@(&ED("`@+2!!('5N:7%U92!)1"!F;W(@
M=&AE(&UE<W-A9V4["B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&\@("`M($%N(&%R<F%Y(&]F(')E8VEP:65N=',["B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&5X="`M(%1H92!T97AT(&]F('1H92!M97-S
M86=E.PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`\+W!R93X*("`@
M("`J"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5N9"@F)&UE<W-A9V4I"B`@("!["B`@("`@("`@+RH@075T:&5N
M=&EC871E+B`J+PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3YA=71H96YT:6-A
M=&4H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]A=71H.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H
M92!R96-I<&EE;G1S(&%R92!I;B!A;B!A<G)A>2X@*B\*("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1M97-S86=E6R=T;R==*2D@>PH@("`@("`@("`@("`D;65S
M<V%G95LG=&\G72`](&%R<F%Y*"1M97-S86=E6R=T;R==*3L*("`@("`@("!]
M"@H@("`@("`@("\J($%R<F%Y('1O('-T;W)E(&5A8V@@<V5N9"X@*B\*("`@
M("`@("`D<V5N9',@/2!A<G)A>2@I.PH*("`@("`@("`O*B!)9B!G871E=V%Y
M('-U<'!O<G1S(&)A=&-H('-E;F1I;F<L('!R969E<F5N8V4@:7,@9VEV96X@
M=&\@=&AI<PH@("`@("`@("`J(&UE=&AO9"X@*B\*("`@("`@("!I9B`H)&UA
M>%]P97)?8F%T8V@@/2`D=&AI<RT^:&%S0V%P86)I;&ET>2@G8F%T8V@G*2D@
M>PH@("`@("`@("`@("`O*B!3<&QI="!U<"!T:&4@<F5C:7!I96YT<R!I;B!T
M:&4@;6%X(')E8VEP:65N=',@<&5R(&)A=&-H(&%S"B`@("`@("`@("`@("`J
M('-U<'!O<G1E9"!B>2!G871E=V%Y+B`J+PH@("`@("`@("`@("`D:4UA>"`]
M(&-O=6YT*"1M97-S86=E6R=T;R==*3L*("`@("`@("`@("`@)&)A=&-H97,@
M/2!C96EL*"1I36%X("\@)&UA>%]P97)?8F%T8V@I.PH*("`@("`@("`@("`@
M+RH@3&]O<"!T:')O=6=H('1H92!B871C:&5S(&%N9"!C;VUP;W-E(&UE<W-A
M9V5S('1O(&)E('-E;G0N("HO"B`@("`@("`@("`@(&9O<B`H)&(@/2`P.R`D
M8B`\("1B871C:&5S.R`D8BLK*2!["B`@("`@("`@("`@("`@("`D<F5C:7!I
M96YT<R`](&%R<F%Y7W-L:6-E*"1M97-S86=E6R=T;R==+"`H)&(@*B`D;6%X
M7W!E<E]B871C:"DL("1M87A?<&5R7V)A=&-H*3L*("`@("`@("`@("`@("`@
M("1R97-P;VYS92`]("1T:&ES+3Y?<V5N9"@D;65S<V%G92P@)')E8VEP:65N
M=',I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E8VEP:65N=',@87,@
M)')E8VEP:65N="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S<&]N
M<V5;)')E8VEP:65N=%U;,%T@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O*B!-97-S86=E('=A<R!S96YT+"!S=&]R92!R96UO=&4@:60N("HO
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96UO=&5?:60@/2`D<F5S<&]N
M<V5;)')E8VEP:65N=%U;,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G)O<B`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+RH@365S<V%G92!F86EL960L('-T;W)E
M(&5R<F]R(&-O9&4N("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1R96UO
M=&5?:60@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R;W(@
M/2`D<F5S<&]N<V5;)')E8VEP:65N=%U;,5T["B`@("`@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("`@("`O*B!3=&]R92!T:&4@<V5N9',N
M("HO"B`@("`@("`@("`@("`@("`@("`@)'-E;F1S6UT@/2!A<G)A>2@G;65S
M<V%G95]I9"<@/3X@)&UE<W-A9V5;)VED)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<F5M;W1E7VED)R`@/3X@)')E;6]T95]I
M9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96-I
M<&EE;G0G("`]/B`D<F5C:7!I96YT+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V5R<F]R)R`@("`@(#T^("1E<G)O<BD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O*B!.;R!B871C:"!S96YD:6YG(&%V86EL86)L92P@:G5S
M="!L;V]P('1H<F]U9V@@86QL(')E8VEP:65N=',*("`@("`@("`@("`@("H@
M86YD('-E;F0@82!M97-S86=E(&9O<B!E86-H(&]N92X@*B\*("`@("`@("`@
M("`@9F]R96%C:"`H)&UE<W-A9V5;)W1O)UT@87,@)')E8VEP:65N="D@>PH@
M("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]S96YD*"1M97-S
M86=E+"`D<F5C:7!I96YT*3L*("`@("`@("`@("`@("`@(&EF("@D<F5S<&]N
M<V5;,%T@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("\J($UE<W-A9V4@
M=V%S('-E;G0L('-T;W)E(')E;6]T92!I9"!I9B!A;GDN("HO"B`@("`@("`@
M("`@("`@("`@("`@)')E;6]T95]I9"`]("AI<W-E="@D<F5S<&]N<V5;,5TI
M(#\@)')E<W!O;G-E6S%=(#H@;G5L;"D["B`@("`@("`@("`@("`@("`@("`@
M)&5R<F]R(#T@;G5L;#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@+RH@365S<V%G92!F86EL960L('-T;W)E(&5R<F]R
M(&-O9&4N("HO"B`@("`@("`@("`@("`@("`@("`@)')E;6]T95]I9"`](&YU
M;&P["B`@("`@("`@("`@("`@("`@("`@)&5R<F]R(#T@)')E<W!O;G-E6S%=
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J(%-T;W)E
M('1H92!S96YD<RX@*B\*("`@("`@("`@("`@("`@("1S96YD<UM=(#T@87)R
M87DH)VUE<W-A9V5?:60G(#T^("1M97-S86=E6R=I9"==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W1E7VED)R`@/3X@)')E;6]T
M95]I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E8VEP
M:65N="<@(#T^("1R96-I<&EE;G0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=E<G)O<B<@("`@("`]/B`D97)R;W(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-E;F1S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@268@=&AE(&-U<G)E;G0@9')I=F5R(&AA<R!A(&-R
M961I="!C87!A8FEL:71Y+"!Q=65R:65S('1H92!G871E=V%Y(&9O<@H@("`@
M("H@82!C<F5D:70@8F%L86YC92!A;F0@<F5T=7)N<R!T:&4@=F%L=64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!686QU92!I;F1I8V%T:6YG
M(&%V86EL86)L92!C<F5D:70@;W(@;G5L;"!I9B!N;W0*("`@("`J("`@("`@
M("`@("`@("`@("`@<W5P<&]R=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971"86QA;F-E*"D*("`@('L*("`@("`@("`O*B!!=71H96YT:6-A=&4N("HO
M"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/F%U=&AE;G1I8V%T92@I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%U=&@[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!B86QA;F-E+B`J+PH@("`@
M("`@(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G8W)E9&ET)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T0F%L86YC92@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O
M;F-R971E($=A=&5W87D@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%1H92!T>7!E(&]F
M(&-O;F-R971E($=A=&5W87D@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!4:&ES(&ES(&)A<V5D(&]N('1H92!G
M871E=V%Y(&1R:79E<B`H)&1R:79E<BDN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@(%1H92!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U
M8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!.971?
M4TU3("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!'871E=V%Y(&EN<W1A
M;F-E(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@(&%N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@
M)TYE="]335,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S
M(#T@)TYE=%]335-?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1S;7,@/2`F;F5W("1C;&%S
M<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<VUS
M(#T@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-L87-S(&1E9FEN:71I
M;VX@;V8@)7,@;F]T(&9O=6YD+B(I+"`D9')I=F5R*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'-M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($YE
M=%]335,@:6YS=&%N8V4@8F%S960@;VX*("`@("`J("1D<FEV97(N"B`@("`@
M*@H@("`@("H@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I
M9B!N;R!.971?4TU3(&EN<W1A;F-E('=I=&@@=&AE('-A;64*("`@("`J('!A
M<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F3F5T7U--4SHZ
M<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E($YE=%]335,@<W5B8VQA<W,@=&\@
M<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!4:&4@:7,@
M8F%S960@;VX@=&AE(&=A=&5W87D@9')I=F5R("@D9')I=F5R*2X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L
M;'D@:6YC;'5D960N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R
M871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T
M:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!C<F5A=&5D(&-O;F-R971E($YE
M=%]335,@:6YS=&%N8V4L(&]R(&9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A
M;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E
M(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@
M("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F3F5T7U--4SHZ9F%C
M=&]R>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`N<&AP
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,S4Q-#<@,3`U,34T,S0Q-#$@,#(P,S(P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)TQO
M9RYP:'`G.PH*+R\@0V]N<W1A;G0@1&5F:6YI=&EO;G,*9&5F:6YE*"=)35-0
M7T]#5$547T-/54Y4)RP@(B\H>RDH6S`M.5U[,2Q]*2A<?20I+R(I.PID969I
M;F4H)TE-4U!?35535%]54T5?3$E415)!3"<L("(O6UQ772]I(BD["@HO*BH*
M("H@5&AE($YE=%])35-0(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&EN=&5R
M9F%C92!T;R!A;B!)35-0('-E<G9E<B`N"B`J"B`J(%)E<75I<F5D('!A<F%M
M971E<G,Z/'!R93X*("H@("`G<V5R=F5R)R`@2&]S=&YA;64@;V8@24U34"!S
M97)V97(N"B`J("`@)W!O<G0G("`@(%!O<G0@;V8@24U34"!S97)V97(N/"]P
M<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`N<&AP
M+'8@,2XQ,RXQ,"XQ.2`R,#`V+S`R+S$P(#`T.C4X.C(V('-E;'-K>2!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4G5B:6YS:WD@
M/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@
M0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-0('L*"B`@("`O
M*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG(&YA;64O25`@861D<F5S<R!O
M9B!)35-0(&AO<W0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1I;7-P7W-E<G9E<B`@("`@("`@("`@("`@("`]("=L;V-A
M;&AO<W0G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@<&]R
M="!F;W(@24U34"!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1I;7-P7W!O<G0@("`@("`@("`@("`@("`@("`]
M("<T,#8G.PH*("`@("\J*@H@("`@("H@0F]O;&5A;B!T;R!S970@:68@=V4@
M<VAO=6QD('=R:71E('1O(&$@;&]G+"!I9B!O;F4@:7,@<V5T('5P+@H@("`@
M("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)&QO9T5N
M86)L960@("`@("`@("`@("`@("`@(#T@=')U93L*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!B=69F97(@8V]N=&%I;FEN9R!T:&4@;&%S="!R87<@3D\@;W(@
M0D%$(')E<W!O;G-E(&9R;VT@=&AE"B`@("`@*B!S97)V97(N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1L87-T4F%W17)R
M;W(@("`@("`@("`@("`@(#T@)R<["@H@("`@+R\@4')I=F%T92!$96-L87)A
M=&EO;G,*("`@('9A<B`D7V-O;6UA;F10<F5F:7@@("`@("`@("`@("`@/2`G
M02<["B`@("!V87(@)%]C;VUM86YD0V]U;G0@("`@("`@("`@("`@(#T@,3L*
M("`@('9A<B`D7W1A9R`@("`@("`@("`@("`@("`@("`@("`@/2`G)SL*("`@
M('9A<B`D7W-T<F5A;2`@("`@("`@("`@("`@("`@("`@/2!N=6QL.PH@("`@
M=F%R("1?;&%S=$-O;6UA;F1486<@("`@("`@("`@("`]("=U;F1E9FEN960G
M.PH@("`@=F%R("1?;&]G9V5R("`@("`@("`@("`@("`@("`@("`](&YU;&P[
M"B`@("!V87(@)%]L;V=3970@("`@("`@("`@("`@("`@("`@(#T@;G5L;#L*
M("`@('9A<B`D7VQO9TQE=F5L("`@("`@("`@("`@("`@("`@/2!014%27TQ/
M1U])3D9/.PH@("`@=F%R("1?;&]G0G5F9F5R("`@("`@("`@("`@("`@("`@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@2&%S:"!C
M;VYT86EN:6YG('-E<G9E<B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!.971?24U34"@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%R86US*2`F)B`A96UP='DH)'!A<F%M<ULG<V5R=F5R)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3YI;7-P7W-E<G9E<B`]("1P87)A;7-;)W-E
M<G9E<B==.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A
M;7,I("8F("%E;7!T>2@D<&%R86US6R=P;W)T)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3YI;7-P7W!O<G0@/2`D<&%R86US6R=P;W)T)UT["B`@("`@("`@
M?0H*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F%T:6]N(&9U;F-T
M:6]N('1O(&)E(&-A;&QE9"!A9G1E<B!O8FIE8W0@:7,@<F5T=7)N960N("!4
M:&ES"B`@("`@*B!A;&QO=W,@97)R;W)S('1O(&]C8W5R(&%N9"!N;W0@8G)E
M86L@=&AE('-C<FEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!C;VYN96-T:6]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^:6US<$]P96XH*3L*"B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G=R:71E5&],
M;V<H)TEN:71I86QI>FEN9R!.971?24U34"!O8FIE8W0N)RP@7U]&24Q%7U\L
M(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TE.1D\I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@3&]G<R!O=70@;V8@=&AE('-E<G9E<B!A;F0@8VQO<V5S('1H92!)
M35-0('-T<F5A;0H@("`@("HO"B`@("!F=6YC=&EO;B!L;V=O=70H*0H@("`@
M>PH@("`@("`@("1T:&ES+3YW<FET951O3&]G*"=#;&]S:6YG($E-4U`@0V]N
M;F5C=&EO;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?24Y&3RD["B`@("`@("`@)&-O;6UA;F1?
M<W1R:6YG(#T@)TQ/1T]55"<["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YI
M;7-P4V5N9"@D8V]M;6%N9%]S=')I;F<I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@9F-L;W-E*"1T
M:&ES+3Y?<W1R96%M*3L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3Y?<W1R
M96%M*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F%W(&-A<&%B:6QI='D@
M<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@<F%W(&-A<&%B:6QI='D@<F5S<&]N<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-A<&%B:6QI='DH*0H@("`@>PH@("`@("`@("1C
M;VUM86YD7W-T<FEN9R`]("=#05!!0DE,2519)SL*("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/FEM<W!396YD*"1C;VUM86YD7W-T<FEN9RD["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/FEM<W!296-E:79E*"D["B`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7EPJ($-!4$%"24Q)5%DO(BP@
M)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@("`@("1C87!A8FEL
M:71Y(#T@<')E9U]R97!L86-E*"(O7EPJ($-!4$%"24Q)5%DO(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+"`D<V5R
M=F5R7W)E<W!O;G-E*3L*"B`@("`@("`@("`@("`@("`D<V5R=F5R7W)E<W!O
M;G-E(#T@)'1H:7,M/FEM<W!296-E:79E*"D[("\O3TL*"B`@("`@("`@("`@
M("`@("!I9B`H(21S97)V97)?<F5S<&]N<V4@/3T@)T]+)RD@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6US<$5R<F]R*"=$:60@;F]T
M(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E
M<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<FET951O3&]G*"=#
M05!!0DE,2519(&-O;7!L971E9"!/2R<L(%]?1DE,15]?+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/
M1U])3D9/*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-A<&%B:6QI
M='D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&%N($E-
M4U`@<V]C:V5T('=I=&@@=&AE('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;7-P3W!E;B@I"B`@("!["B`@
M("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D=&AI<RT^:6US<%]S97)V97(L("1T
M:&ES+3YI;7-P7W!O<G0I.PH@("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^:6US<$5R<F]R*"=#;VYN96-T:6]N('1O($E-
M4U`@:&]S="!F86EL960N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]S=')E86T@/2`D9G`["B`@("`@("`@)'-E<G9E<E]R97-P
M;VYS92`]("1T:&ES+3YI;7-P4F5C96EV92@I.PH@("`@("`@(&EF("@A<')E
M9U]M871C:"@B+UY<*B!/2R\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S
M<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@<V5N9"!A(&-O;6UA;F0@=&\@=&AE('-E
M<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]M;6%N9%1E
M>'0@5&5X="!T;R!S96YD('1O('1H92!S97)V97(N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D:6YC;'5D951A9R`@1&5T97)M:6YE<R!I9B!C;VUM86YD('1A
M9R!I<R!P<F5P96YD960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@)'-E;F1#
M4DQ&("`@1&5T97)M:6YE<R!I9B!#4DQ&(&ES(&%P<&5N9&5D+@H@("`@("H@
M0')E='5R;B!M:7AE9"`@(%1R=64@;VX@<W5C8V5S<R!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<W!396YD*"1C;VUM
M86YD5&5X="P@)&EN8VQU9&5486<]=')U92P@)'-E;F1#4DQ&/71R=64I"B`@
M("!["B`@("`@("`@)&-O;6UA;F1?=&5X="`]("<G.PH*("`@("`@("!I9B`H
M(21T:&ES+3Y?<W1R96%M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M:6US<$5R<F]R*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F86EL960N)RP@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M:6YC;'5D951A9RD@>PH@("`@("`@("`@("`D=&AI<RT^7W1A9R`]("1T:&ES
M+3Y?9V5T3F5X=$-O;6UA;F1486<H*3L*("`@("`@("`@("`@)&-O;6UA;F1?
M=&5X="`]("(D=&AI<RT^7W1A9R`B.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;6UA;F1?=&5X="`N/2`D8V]M;6%N9%1E>'0["@H@("`@("`@(&EF("@D<V5N
M9$-23$8I('L*("`@("`@("`@("`@)&-O;6UA;F1?=&5X="`N/2`B7')<;B([
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^=W)I=&54;TQO9R@G5&\Z("<@
M+B`D8V]M;6%N9%]T97AT+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!I
M9B`H(69P=71S*"1T:&ES+3Y?<W1R96%M+"`D8V]M;6%N9%]T97AT*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FEM<W!%<G)O<B@G0V]N;F5C=&EO
M;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5C96EV97,@82!S:6YG
M;&4@0U),1B!T97)M:6YA=&5D('-E<G9E<B!R97-P;VYS92!S=')I;F<*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("=.3R<L("="040G+"`G3TLG+"!R
M87<@<F5S<&]N<V4@;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6US<%)E8V5I=F4H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]S
M=')E86TI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI;7-P17)R;W(H
M)T-O;FYE8W1I;VX@=&\@24U34"!H;W-T(&9A:6QE9"XG+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@9F=E=',H
M)'1H:7,M/E]S=')E86TL(#4Q,BD["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^:6US<$5R<F]R*"=$:60@;F]T
M(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E
M<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`D;65T82`]('-T
M<F5A;5]G971?;65T85]D871A*"1T:&ES+3Y?<W1R96%M*3L*("`@("`@("!I
M9B`H)&UE=&%;)W1I;65D7V]U="==*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^:6US<$5R<F]R*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F86EL
M960N)R`N("<Z($-O;FYE8W1I;VX@=&EM960@;W5T(2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@=')I;2@D
M<F5S=6QT*3L*("`@("`@("`D=&AI<RT^=W)I=&54;TQO9R@G1G)O;3H@)R`N
M("1S97)V97)?<F5S<&]N<V4L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("\J(%!A<G-E(&]U="!T:&4@<F5S<&]N<V4Z"B`@("`@("`@("H@1FER<W0@
M;6%K92!S=7)E('1H870@=&AI<R!I<R!N;W0@9F]R(&$@<')E=FEO=7,@8V]M
M;6%N9"X*("`@("`@("`@*B!)9B!I="!I<RP@:70@;65A;G,@=V4@9&ED(&YO
M="!R96%D(&%L;"!T:&4@<V5R=F5R(')E<W!O;G-E<R!F<F]M"B`@("`@("`@
M("H@=&AE(&QA<W0@8V]M;6%N9"XN+G)E860@=&AE;2!N;W<L(&)U="!T:')O
M=R!A;B!E<G)O<BX@*B\*("`@("`@("!W:&EL92`H<')E9U]M871C:"@B+UXB
M("X@)'1H:7,M/E]L87-T0V]M;6%N9%1A9PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("XB+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@
M("1S97)V97)?<F5S<&]N<V4@/0H@("`@("`@("`@("`@("`@=')I;2AF9V5T
M<R@D=&AI<RT^7W-T<F5A;2P@-3$R*2D["B`@("`@("`@("`@("1T:&ES+3YI
M;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N
M<V4@9G)O;2!T:&4@<V5R=F5R+B<@+B`B.B`D<V5R=F5R7W)E<W!O;G-E(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@)&-U<G)E;G1486<@/2`D=&AI<RT^
M7W1A9SL*("`@("`@("!I9B`H<')E9U]M871C:"@B+UXB("X@)&-U<G)E;G14
M86<@+B`B($Y/+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@
M("1T:&ES+3YL87-T4F%W17)R;W(@/2`D<V5R=F5R7W)E<W!O;G-E.PH@("`@
M("`@("`@("!R971U<FX@)TY/)SL*("`@("`@("!]"@H@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"(O7B(@+B`D8W5R<F5N=%1A9R`N("(@0D%$+R(L("1S97)V
M97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@("1T:&ES+3YI;7-P17)R;W(H
M)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U
M97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("1T:&ES
M+3YL87-T4F%W17)R;W(@/2`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@("`@
M("!R971U<FX@)T)!1"<["B`@("`@("`@?0H*("`@("`@("!I9B`H<')E9U]M
M871C:"@B+UXB("X@)&-U<G)E;G1486<@+B`B($]++R(L("1S97)V97)?<F5S
M<&]N<V4I*2!["B`@("`@("`@("`@(')E='5R;B`G3TLG.PH@("`@("`@('T*
M"B`@("`@("`@+RH@268@:70@=V%S(&YO="!A("=.3R<L("="040G(&]R("=/
M2R<@<F5S<&]N<V4L"B`@("`@("`@("H@=&AE;B!I="=S('5P('1O('1H92!C
M86QL:6YG(&9U;F-T:6]N('1O(&1E8VED90H@("`@("`@("`J('=H870@=&\@
M9&\@=VET:"!I="X@*B\*("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!#4DQ&('1E<FUI
M;F%T960@<F5S<&]N<V4@9G)O;2!S97)V97(@86YD('-P;&ET<R!I="!I;G1O
M"B`@("`@*B!A;B!A<G)A>2!D96QI;6ET960@8GD@82`\<W!A8V4^+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@<F5S=6QT(&9R;VT@97AP;&]D92@I
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971397)V97)297-P;VYS94-H=6YK
M<R@I"B`@("!["B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]"B`@("`@("`@
M("`@('1R:6TH9F=E=',H)'1H:7,M/E]S=')E86TL(#4Q,BDI.PH@("`@("`@
M("1C:'5N:W,@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R97-P;VYS92D["B`@
M("`@("`@<F5T=7)N("1C:'5N:W,["B`@("!]"@H@("`@+RH*("`@("`J(%)E
M8V5I=F5S(&9I>&5D(&YU;6)E<B!O9B!B>71E<R!F<F]M($E-4U`@<V]C:V5T
M+B!5<V5D('=H96X*("`@("`J('-E<G9E<B!R971U<FYS(&$@<W1R:6YG(&QI
M=&5R86PN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QE;F=T:"`@
M3G5M8F5R(&]F(&)Y=&5S('1O(')E860@9G)O;2!S;V-K970N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1E>'0@;V8@<W1R:6YG(&QI=&5R86PN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8V5I=F53=')I;F=,:71E<F%L*"1L
M96YG=&@I"B`@("!["B`@("`@("`@)'1E;7`@/2!T<FEM*&9R96%D*"1T:&ES
M+3Y?<W1R96%M+"`D;&5N9W1H*2D["B`@("`@("`@)'1H:7,M/G=R:71E5&],
M;V<H)T9R;VU[?3H@)R`N("1T96UP+"!?7T9)3$5?7RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@(')E='5R;B`D=&5M<#L*("`@('T*"B`@("`O*BH*("`@("`J($EN8W)E
M;65N=',@=&AE($E-4U`@8V]M;6%N9"!T86<@=&]K96XN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<F5T=7)N('-T<FEN9R!.97AT
M(&-O;6UA;F0@=&%G+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3F5X=$-O
M;6UA;F1486<H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&%S=$-O;6UA;F14
M86<@/2`D=&AI<RT^7W1A9R`_("1T:&ES+3Y?=&%G(#H@)W5N9&5F:6YE9"<[
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]M;6%N9%!R969I>"`N('-P<FEN
M=&8H)R4P-&0G+"`D=&AI<RT^7V-O;6UA;F1#;W5N="LK*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@82!S=')I;F<@;F5E9',@=&\@
M8F4@<75O=&5D(&)E9F]R92!S96YD:6YG('1O('1H92!S97)V97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG("!3=')I;F<@=&\@8F4@
M=&5S=&5D+@H@("`@("H@0')E='5R;B!S=')I;F<@3W)I9VEN86P@<W1R:6YG
M('%U;W1E9"!I9B!N965D960N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E
M4W!A8V5D4W1R:6YG*"1S=')I;F<I"B`@("!["B`@("`@("`@:68@*'-T<G!O
M<R@D<W1R:6YG+"`G("<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@)R(G("X@)'-T<FEN9R`N("<B)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!286ES97,@86X@24U34"!E<G)O<BX@($)A<VEC86QL>2P@
M;VYL>2!W<FET97,*("`@("`J(&5R<F]R(&]U="!T;R!T:&4@:&]R9&4@;&]G
M9FEL92!A;F0@<F5T=7)N<R!014%27T5R<F]R"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D97)R("`@($5I=&AE<B!014%27T5R<F]R(&]B:F5C="!O
M<B!T97AT('1O('=R:71E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&9I;&4@("!&:6QE(&YA;64@=VAE<F4@97)R;W(@;V-C=7)E9"X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1L:6YE("!,:6YE(&YU;6)E<B!W:&5R92!E<G)O
M<B!O8V-U<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;7-P17)R;W(H)&5R
M<B`]("<G+"`D9FEL93U?7T9)3$5?7RP@)&QI;F4]7U],24Y%7U\I"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`D;&]G7W1E>'0@/2`D97)R+3YG971-97-S86=E*"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&QO9U]T97AT(#T@)&5R<CL*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YW<FET951O3&]G*"1L;V=?=&5X="P@
M)&9I;&4L("1L:6YE+"!014%27TQ/1U]%4E(I.PH@("`@("`@(&EF("AI<U]A
M*"1E<G(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1E
M<G(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)&5R<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@5W)I=&5S(&$@;65S<V%G92!T;R!T:&4@24U34"!L;V=F:6QE+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@(%1E>'0@=&\@
M=W)I=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E5&],;V<H)&UE<W-A
M9V4L("1F:6QE(#T@7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@
M("1L:6YE(#T@7U],24Y%7U\L("1P<FEO<FET>2`](%!%05)?3$]'7TE.1D\I
M"B`@("!["B`@("`@("`@:68@*"@D=&AI<RT^;&]G16YA8FQE9"D@)B8@*"1T
M:&ES+3Y?;&]G4V5T*2D@>PH@("`@("`@("`@("!I9B`H)'!R:6]R:71Y(#X@
M)'1H:7,M/E]L;V=,979E;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&]G365S<V%G92`]("=;:6US
M<%T@)R`N("1M97-S86=E("X@)R!;;VX@;&EN92`G("X@)&QI;F4@+B`G(&]F
M("(G("X@)&9I;&4@+B`G(ETG.PH@("`@("`@("`@("`D=&AI<RT^7VQO9V=E
M<BT^;&]G*"1L;V=-97-S86=E+"`D<')I;W)I='DI.PH@("`@("`@('T@96QS
M96EF("@H(21T:&ES+3Y?;&]G4V5T*2`F)B`H)'1H:7,M/FQO9T5N86)L960I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&]G0G5F9F5R6UT@/2!A<G)A>2@G
M;65S<V%G92<@(#T^("1M97-S86=E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9FEL92<@
M("`@(#T^("1F:6QE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VQI;F4G("`@("`]/B`D;&EN90H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W($QO9R!O8FIE8W0@8F%S960@
M;VX@)'!A<F%M<PH@("`@("H*("`@("`J($!P87)A;2`@87)R87D@("1P87)A
M;7,@3&]G(&]B:F5C="!P87)A;65T97)S+@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&]G9V5R*"1P87)A;7,I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]L;V=,979E;"`]("1P87)A;7-;)W!R:6]R:71Y
M)UT["B`@("`@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@D<&%R86US
M6R=T>7!E)UTL("1P87)A;7-;)VYA;64G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;7-;)VED96YT)UTL("1P87)A;7-;)W!A
M<F%M<R==*3L*("`@("`@("`D=&AI<RT^7VQO9U-E="`]('1R=64["@H@("`@
M("`@(&EF("AI<U]A*"1L;V=G97(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)'1H:7,M/FQO9T5N86)L960@/2!F86QS93L*("`@("`@("`@("`@
M<F5T=7)N("1L;V=G97(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]L;V=G97(@/2`F)&QO9V=E<CL*("`@("`@("`@("`@)'1H:7,M
M/FQO9T5N86)L960@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7W=R:71E
M3&]G0G5F9F5R*"D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E<R!O=70@8V]N=&5N=',@
M;V8@)%]L;V="=69F97(@=&\@;&]G(&9I;&4N("!!;&QO=W,@;65S<V%G97,*
M("`@("`J('1O(&)E(&QO9V=E9"!D=7)I;F<@:6YI=&EA;&EZ871I;VX@;V8@
M;V)J96-T(&)E9F]R92!,;V<@;V)J96-T(&ES"B`@("`@*B!I;G-T86YT:6%T
M960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]W<FET94QO9T)U9F9E<B@I"B`@("!["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@8V]U;G0H)'1H:7,M/E]L;V="=69F97(I.R`D:2LK
M*2!["B`@("`@("`@("`@("1T:&ES+3YW<FET951O3&]G*"1T:&ES+3Y?;&]G
M0G5F9F5R6R1I75LG;65S<V%G92==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VQO9T)U9F9E<ELD:5U;)V9I;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V="=69F97);)&E=
M6R=L:6YE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&]G0G5F9F5R6R1I75LG<')I;W)I='DG72D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@8W)E871E(&$@3F5T7TE-
M4U`@;V)J96-T(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*B!-=7-T(&)E(&-A
M;&QE9"!A<R`D:6US<"`]("9.971?24U34#HZ9F%C=&]R>2@D9')I=F5R+"`D
M<&%R86US*3L*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D9')I=F5R
M(%1Y<&4@;V8@3F5T7TE-4U`@;V)J96-T('1O(')E='5R;BX*("`@("`J($!P
M87)A;2`@;6EX960@("1P87)A;7,@($%N>2!P87)A;65T97)S(&YE961E9"!B
M>2!T:&4@3F5T7TE-4U`@;V)J96-T+@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE(')E<75E<W1E9"!.971?24U34"!O8FIE8W0@;W(@4$5!4E]%<G)O<B!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M
M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R:79E<BD@?'P@)&1R
M:79E<B`]/2`G;F]N92<I('L*("`@("`@("`@("`@)&EM<W`@/2`F;F5W($YE
M=%])35-0*"1P87)A;7,I.PH@("`@("`@("`@("!R971U<FX@)&EM<W`["B`@
M("`@("`@?0H*("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+TE-4U`O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L
M87-S(#T@)TYE=%])35-07R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D:6US<"`]("9N97<@
M)&-L87-S*"1P87)A;7,I.PH@("`@("`@("`@("!R971U<FX@)&EM<W`["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@;&]A9"!T:&4@9&5F
M:6YI=&EO;B!O9B`E<RXB*2P@)&-L87-S*2DL(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@<F5T=7)N(&$@3F5T7TE-4U`@;V)J96-T(&)A<V5D(&]N("1D<FEV97(N
M("!/;FQY"B`@("`@*B!C<F5A=&5S(&$@;F5W(&]B:F5C="!I9B!O;F4@=VET
M:"!T:&4@<V%M92!P87)A;65T97)S(&%L<F5A9'D*("`@("`J(&1O97-N)W0@
M97AI<W0N"B`@("`@*B!-=7-T(&)E(&-A;&QE9"!A<R`D:6US<"`]("9.971?
M24U34#HZ<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,I.PH@("`@("H*("`@
M("`J($!P87)A;2`@<W1R:6YG("1D<FEV97(@5'EP92!O9B!.971?24U34"!O
M8FIE8W0@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M("!M:7AE9"`@)'!A<F%M
M<R!!;GD@<&%R86UE=&5R<R!N965D960@8GD@=&AE($YE=%])35-0(&]B:F5C
M="X*("`@("`J($!R971U<FX@;6EX960@(%)E9F5R96YC92!T;R!T:&4@3F5T
M7TE-4U`@;V)J96-T(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US*0H@
M("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF("@A
M:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R
M:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H
M(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@
M("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F3F5T7TE-4U`Z.F9A8W1O<GDH
M)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T,2`P,C`T,3<`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0
M+T)O;VLN<&AP````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,34R,#,U(#$P-3$U-#,T,30Q(#`R,3(P-@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M("=.970O24U34"]!=71H+G!H<"<["@HO*BH*("H@4W1R:6YG(&]F('-U<'!O
M<G1E9"!!0TP@<FEG:'1S+@H@*B\*9&5F:6YE*"=)35-07T%#3%]224=(5%,G
M+"`G;')W8V1A)RD["@HO*BH*("H@3F5T7TE-4U!?0F]O:R!#;&%S<R`M('!R
M;W9I9&5S(&%P:2!F;W(@9&5A;&EN9R!W:71H($E-4U`*("H@861D<F5S<R!B
M;V]K<RX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U
M<V5R;F%M92<@("`@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@<V5R=F5R
M(&%S+@H@*B`@("=P87-S=V]R9"<@("`@(%!A<W-W;W)D(&9O<B!C=7)R96YT
M('5S97(N"B`J("`@)V%U=&A?;65T:&]D)R`@5&AE(&%U=&AE;G1I8V%T:6]N
M(&UE=&AO9"!T;R!U<V4@=&\@;&]G:6XN"B`J("`@)W-E<G9E<B<@("`@("`@
M5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R="<@
M("`@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P<F4^"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O0F]O:RYP:'`L
M=B`Q+C$V+C(N,C(@,C`P-B\P,2\P,2`R,3HR.#HR."!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B
M:6YS:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K
M86=E($YE=%])35-0"B`J+PIC;&%S<R!.971?24U34%]";V]K('L*"B`@("`O
M*BH*("`@("`J(%-O<G0@;W)D97(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1S;W)T(#T@)V%S8V5N9"<["@H@("`@+RHJ
M"B`@("`@*B!.971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!.
M971?24U34`H@("`@("HO"B`@("!V87(@)%]I;7-P.PH*("`@("\J*@H@("`@
M("H@4&%R86UE=&5R(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]P87)A;7,["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<B!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R!(87-H(&-O;G1A:6YI;F<@24U34"!P87)A;65T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!.971?24U34%]";V]K*"1P87)A;7,I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@
M("\J*@H@("`@("H@26YI=&EA;&EZ871I;VX@9G5N8W1I;VX@=&\@8F4@8V%L
M;&5D(&%F=&5R(&]B:F5C="!I<R!R971U<FYE9"X*("`@("`J(%1H:7,@86QL
M;W=S(&5R<F]R<R!T;R!O8V-U<B!A;F0@;F]T(&)R96%K('1H92!S8W)I<'0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:6YI="@I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VEM<W`I
M*2!["B`@("`@("`@("`@("1A=71H(#T@)DYE=%])35-07T%U=&@Z.G-I;F=L
M971O;B@D=&AI<RT^7W!A<F%M<ULG875T:%]M971H;V0G72D["B`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"`]("1A=71H+3YA=71H96YT:6-A=&4H)'1H:7,M
M/E]P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]I;7-P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?:6US<"T^
M=W)I=&54;TQO9R@G3F5T7TE-4U!?0F]O:R!I;FET:6%L:7IE9"XG+"!?7T9)
M3$5?7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&-O;G1A:6YI
M;F<@=&AE(&YA;65S(&]F(&%L;"!T:&4@861D<F5S<R!B;V]K<PH@("`@("H@
M879A:6QA8FQE('1O('1H92!L;V=G960@:6X@=7-E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D($%R<F%Y(&]F(&%D9')E<W,@8F]O:R!N86UE<R!O
M<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!9&1R97-S
M0F]O:TQI<W0H*0H@("`@>PH@("`@("`@("1C;VUM86YD7W-T<FEN9R`]("=!
M1$1215-30D]/2R`J)SL*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)&-O;6UA;F1?<W1R:6YG*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"=014%27T5R<F]R)RDI('L*("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T-O;FYE8W1I;VX@=&\@24U34"!H
M;W-T(&9A:6QE9"XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@271E<F%T92!T:')O=6=H('1H92!R97-P;VYS92!A;F0@<&]P
M=6QA=&4@86X@87)R87D@;V8*("`@("`@("`@*B!A9&1R97-S(&)O;VL@;F%M
M97,N("HO"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("!I9B`H:7-?82@D<V5R=F5R7W)E
M<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T*("`@("`@("`D86)O;VMS(#T@
M87)R87DH*3L*"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8V@H(B]>7"H@041$
M4D534T)/3TLO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@
M+RH@268@=&AI<R!I<R!A;B!!1$1215-30D]/2R!R97-P;VYS92P@=&AE;B!T
M:&ES('=I;&P@97AP;&]D92!A<R!S;SH*("`@("`@("`@("`@("H@6S!=(&%N
M9"!;,5T@8V%N(&)E(&1I<V-A<F1E9`H@("`@("`@("`@("`@*B!;,ET@/2!A
M='1R:6)U=&5S"B`@("`@("`@("`@("`J(%LS72`](&1E;&EM:71E<@H@("`@
M("`@("`@("`@*B!;-%T@/2!A9&1R97-S(&)O;VL@;F%M90H@("`@("`@("`@
M("`@*B\*"B`@("`@("`@("`@("\J($9I<G-T+"!C:&5C:R!F;W(@82![?2`J
M+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"A)35-07T]#5$547T-/54Y4
M+"`D<V5R=F5R7W)E<W!O;G-E+"`D=&5M<$%R<F%Y*2D@>PH@("`@("`@("`@
M("`@("`@)&%B;V]K<UM=(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG
M3&ET97)A;"@D=&5M<$%R<F%Y6S)=*3L*("`@("`@("`@("`@("`@("\J($=E
M="!T:&4@0U),1B!A="!E;F0@;V8@041$4D534T)/3TL@<F5S<&]N<V4*("`@
M("`@("`@("`@("`@("`J('1H870@=&AE('M](&1O97,@;F]T(&EN8VQU9&4N
M("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I
M;F=,:71E<F%L*#(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'!A<G1S(#T@97AP;&]D92@G("<L("1S97)V97)?<F5S<&]N<V4I
M.PH@("`@("`@("`@("`@("`@)&YU;5!A<G1S(#T@8V]U;G0H)'!A<G1S*3L*
M("`@("`@("`@("`@("`@("1N86UE(#T@)'!A<G1S6S1=.PH@("`@("`@("`@
M("`@("`@)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D["B`@("`@
M("`@("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2)<(B(I('L*("`@("`@("`@
M("`@("`@("`@("`D;F%M92`](&QT<FEM*"1N86UE+"`B7"(B*3L*("`@("`@
M("`@("`@("`@("`@("!F;W(@*"1I(#T@-3L@)&D@/"`D;G5M4&%R=',[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@+CT@)R`G("X@
M)'!A<G1S6R1I73L*("`@("`@("`@("`@("`@("`@("`@("`@)&QA<W1#:&%R
M(#T@<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M(#$L
M(#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&QA<W1#:&%R(#T]
M(")<(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@
M<G1R:6TH)&YA;64L(")<(B(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D86)O;VMS6UT@/2`D;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV
M92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S97)V97)?<F5S<&]N<V4@
M(3T@)T]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N
M<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=!1$12
M15-30D]/2R!C;VUM86YD($]++B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TE.1D\I
M.PH@("`@("`@(')E='5R;B`D86)O;VMS.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG('1H92!N86UE<R!T:&%T
M(&UA=&-H("1S96%R8V@*("`@("`J(&-R:71E<F$@:6X@=&AE(&%D9')E<W,@
M8F]O:R!N86UE9"`D86)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D86)O;VL@($%D9')E<W,@8F]O:R!N86UE('1O('-E87)C:"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<V5A<F-H("!396%R8V@@8W)I=&5R:6$@:6X@=&AE
M(&9O<FT@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("=F:65L9$YA
M;64G(#T^("=S96%R8VA497)M)R`H;6%Y(&EN8VQU9&4@*B!W:6QD(&-A<F0I
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@07)R87D@;V8@;F%M97,@
M;V8@=&AE(&5N=')I97,@=&AA="!M871C:"!O<B!014%27T5R<F]R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S96%R8V@H)&%B;V]K+"`D<V5A<F-H*0H@("`@
M>PH@("`@("`@("\O268@;F\@9FEE;&0@/3X@=F%L=64@<&%I<G,L(&%S<W5M
M92!W92!A<F4@<V5A<F-H:6YG(&YA;64N"B`@("`@("`@)&-R:71E<FEA(#T@
M87)R87DH*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S96%R8V@I*2!["B`@
M("`@("`@("`@("1C<FET97)I85LG;F%M92==(#T@)'-E87)C:#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8W)I=&5R:6$@/2`D<V5A<F-H.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H)U-%05)#2$%$1%)%4U,@)RP@=')U92P@9F%L<V4I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!$;R!W
M92!N965D('1O('-E;F0@=&AE(&%B;V]K(&YA;64@87,@>WT@/PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K
M*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T
M<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E
M*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+"`D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US
M<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N
M9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%]?1DE,15]?+%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R]3=&%R="!P87)S:6YG('1H92!S96%R8V@@87)R87DN"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1A8F]O
M:R(L(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("1C;W5N="`](&-O=6YT*"1C<FET97)I82D[
M"B`@("`@("`@)&-U<G)E;G0@/2`Q.PH@("`@("`@(&9O<F5A8V@@*"1C<FET
M97)I82!A<R`D<V5A<F-H7V9I96QD(#T^("1S96%R8V@I('L*("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B`D<V5A<F-H
M7V9I96QD("(L(&9A;'-E+"!F86QS92D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!(
M;W<@86)O=70@=&AE('-E87)C:"!T97)M(&%S(&$@>WTN"B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)'-E87)C
M:"DI('L*("`@("`@("`@("`@("`@("1B:5-E87)C:"`]('-P<FEN=&8H(GLE
M9'TB+"!S=')L96XH)'-E87)C:"DI.PH*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:5-E87)C:"P@9F%L<V4L
M('1R=64I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+"`D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O
M;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D<V5A<F-H+"!F86QS92P@)&-U<G)E;G0@/3T@)&-O=6YT*3L*
M("`@("`@("`@("`@("`@("1C=7)R96YT*RL["B`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!/;FQY('-E
M;F0@=&AE($-R3&8@:68@=&AI<R!I<R!T:&4@;&%S="!F:65L9"]S96%R8V@@
M871O;2X*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!396YD*"<B)R`N("1S96%R8V@@+B`G(B<L(&9A;'-E+"`D8W5R<F5N
M="`]/2`D8V]U;G0I.PH@("`@("`@("`@("`@("`@)&-U<G)E;G0K*SL*("`@
M("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@1V5T('1H92!R97-P;VYS92X*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("1A8F]O
M:TYA;65S(#T@07)R87DH*3L*"B`@("`@("`@=VAI;&4@*'!R96=?;6%T8V@H
M(B]>7"H@4T5!4D-(041$4D534R\B+"`D<V5R=F5R7W)E<W!O;G-E*2D@>PH@
M("`@("`@("`@("`D8VAO<'!E9%]R97-P;VYS92`]"B`@("`@("`@("`@("`@
M("!P<F5G7W)E<&QA8V4H(B]>7"H@4T5!4D-(041$4D534R\B+"`G)RP@)'-E
M<G9E<E]R97-P;VYS92D["@H@("`@("`@("`@("`O+R!'970@<FED(&]F(&%N
M>2!L:6YG97)I;F<@<75O=&5S+@H@("`@("`@("`@("`D8VAO<'!E9%]R97-P
M;VYS92`]('!R96=?<F5P;&%C92@B+UPB+R(L("<G+"`D8VAO<'!E9%]R97-P
M;VYS92D["@H@("`@("`@("`@("`O+R!296UO=F4@86YY(&QI;F=E<FEN9R!W
M:&ET92!S<&%C92!I;B!F<F]N="!O;FQY+@H@("`@("`@("`@("`D=&5M<"`]
M(&QT<FEM*"1C:&]P<&5D7W)E<W!O;G-E*3L*"B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"(O*'LI*%LP+3E=>S$L?2DH7'TD*2\B+"`D=&5M<"P@)'1E
M;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1D871A4VEZ92`]("1T96UP
M07)R87E;,ET["B`@("`@("`@("`@("`@("`D=&5M<"`]("1T:&ES+3Y?:6US
M<"T^<F5C96EV95-T<FEN9TQI=&5R86PH)&1A=&%3:7IE*3L*"B`@("`@("`@
M("`@("`@("`O*B!'970@=&AE($-23$8@<VEN8V4@>WT@9&]E<R!N;W0@:6YC
M;'5D92!I="X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^<F5C
M96EV95-T<FEN9TQI=&5R86PH,BD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1A8F]O:TYA;65S6UT@/2`D=&5M<#L*"B`@("`@("`@("`@("\O($=E
M="!T:&4@;F5X="!R97-P;VYS92!L:6YE(&9R;VT@=&AE('-E<G9E<BX*("`@
M("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US
M<%)E8V5I=F4H*3L*("`@("`@("!]"@H@("`@("`@("\O(%-H;W5L9"!C:&5C
M:R!F;W(@3TL@;W(@0D%$(&AE<F4@:G5S="!T;R!B92!C97)T86EN+@H@("`@
M("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A<V4@
M)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%
M<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R
M(')E<75E<W0N)R`N("`B.B`D8V]M;6%N9%]T97AT(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["@H@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B
M;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)R`N("(Z("(@+B`D=&AI<RT^
M7VEM<W`M/FQA<W1287=%<G)O<BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!4:&ES(&%L;&]W<R!F;W(@;F\@<F5S=6QT<R`J
M+PH@("`@("`@(&EF("AC;W5N="@D86)O;VM.86UE<RD@/"`Q*2!["B`@("`@
M("`@("`@(')E='5R;B`D86)O;VM.86UE<SL*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3Y?:6US<"T^=W)I=&54;TQO9R@G4T5!4D-(041$4D534R!C;VUM
M86YD($]+)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!014%27TQ/1U])3D9/*3L*"B`@("`@("`@+R\@
M1&5T97)M:6YE('1H92!S;W)T(&1I<F5C=&EO;B!A;F0@<&5R9F]R;2!T:&4@
M<V]R="X*("`@("`@("!S=VET8V@@*"1T:&ES+3YS;W)T*2!["B`@("`@("`@
M8V%S92`G87-C96YD)SH*("`@("`@("`@("`@<V]R="@D86)O;VM.86UE<RD[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=D97-C96YD)SH*
M("`@("`@("`@("`@<G-O<G0H)&%B;V]K3F%M97,I.PH@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D86)O;VM.86UE<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87-S;V-I871I=F4@
M87)R87D@;V8@82!S:6YG;&4@861D<F5S<R!B;V]K(&5N=')Y+@H@("`@("H@
M3F]T92!T:&%T('1H97)E('=I;&P@86QW87ES(&)E(&$@)VYA;64G(&9I96QD
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("`@("`@($YA
M;64@;V8@=&AE(&%D9')E<W,@8F]O:R!T;R!S96%R8V@N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1E;G1R>4YA;64@("=N86UE)R!A='1R:6)U=&4@;V8@=&AE
M(&5N=')Y('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!!<G)A>2!C;VYT86EN:6YG(&5N=')Y(&]R(%!%05)?17)R;W(@;VX@9F%I
M;'5R92`O(&YO(&UA=&-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%;G1R
M>2@D86)O;VLL("1E;G1R>4YA;64I"B`@("!["B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)T9%5$-(041$4D534R`G+"!T<G5E
M+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!
M3"P@)&%B;V]K*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B
M>R5D?2(L('-T<FQE;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M
M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U3
M4%]-55-47U5315],251%4D%,+"`D96YT<GE.86UE*2D@>PH@("`@("`@("`@
M("`D8FE.86UE(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D96YT<GE.86UE
M*2D["@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D8FE.86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED
M(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E
M<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4V5N9"@D96YT<GE.86UE+"!F86QS92P@=')U92D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H(EPB)&5N=')Y3F%M95PB(BP@9F%L<V4L
M('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-E<G9E<E]R97-P;VYS
M92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@<W=I
M=&-H("@D<V5R=F5R7W)E<W!O;G-E*2!["B`@("`@("`@8V%S92`G0D%$)SH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4
M:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@<F5Q=65S
M="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@(&-A<V4@)TY/)SH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=.
M;R!E;G1R>2!I;B!T:&ES(&%D9')E<W,@8F]O:R!M871C:&5S('EO=7(@<75E
M<GDN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M("\O($=E="!T:&4@9&%T82!I;B!A;B!A<W-O8VEA=&EV92!A<G)A>2X*("`@
M("`@("`D96YT<GD@/2`D=&AI<RT^7W!A<G-E1F5T8VA!9&1R97-S4F5S<&]N
M<V4H)'-E<G9E<E]R97-P;VYS92D["@H@("`@("`@("\O1V5T('1H92!N97AT
M('-E<G9E<B!R97-P;VYS92`M+2!T:&ES("IS:&]U;&0J(&)E('1H92!/2R!R
M97-P;VYS92X*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!I9B`H)'-E<G9E<E]R97-P
M;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@("\O(%5N97AP96-T960@<F5S
M<&]N<V4@=&AR;W<@97)R;W(@8G5T('-T:6QL(&-O;G1I;G5E(&]N+@H@("`@
M("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RQ?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]I;7-P+3YW<FET951O3&]G*"=&151#2$%$1%)%4U,@8V]M<&QE=&5D($]+
M)RP@7U]&24Q%7U\L(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T=7)N("1E
M;G1R>3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@861D
M<F5S<R!B;V]K+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K
M3F%M92!&54Q,62!154%,249)140@;F%M92!S=6-H("=J9&]E+F-L:65N=',G
M(&5T8RXN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@5')U92!O;B!S
M=6-C97-S("\@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C<F5A=&5!9&1R97-S0F]O:R@D86)O;VM.86UE*0H@("`@>PH@
M("`@("`@("1C;VUM86YD7W1E>'0@/2`G0U)%051%041$4D534T)/3TL@)SL*
M"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,
M+"`D86)O;VM.86UE*2D@>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT
M9B@B>R5D?2(L('-T<FQE;B@D86)O;VM.86UE*2D["@H@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T97AT
M("X@)&)I0F]O:RP@=')U92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N
M;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P
M;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O:TYA;64L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M
M/FEM<W!396YD*"1C;VUM86YD7W1E>'0@+B`D86)O;VM.86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<G5E+"!T
M<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S97)V97)?<F5S<&]N<V4@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@:68@*&ES
M7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@("`@("!]"@H@("`@
M("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A<V4@
M)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=#
M4D5!5$5!1$1215-30D]/2R!C;VUP;&5T960@3TLG+"!?7T9)3$5?7RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?+"!0
M14%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@("`@
M("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R\@0V]U;&0@;F]T(&-R96%T
M92!A8F]O:RX*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R
M(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S
M92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO
M=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`O+R!3;VUE=&AI;F<@=6YE>'!E8W1E9"X*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$
M:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE
M('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&%N(&%D9')E<W,@8F]O:R!C;VUP
M;&5T96QY(0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K3F%M
M92!.86UE(&]F(&%D9')E<W,@8F]O:R!T;R!D96QE=&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@+R!014%27T5R<F]R
M(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E061D<F5S
M<T)O;VLH)&%B;V]K3F%M92D*("`@('L*("`@("`@("`D8V]M;6%N9%]T97AT
M(#T@)T1%3$5414%$1%)%4U-"3T]+("<["@H@("`@("`@("\O($-H96-K(&YE
M960@9F]R('M]+@H@("`@("`@(&EF("AP<F5G7VUA=&-H*$E-4U!?35535%]5
M4T5?3$E415)!3"P@)&%B;V]K3F%M92DI('L*("`@("`@("`@("`@)&)I0F]O
M:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&%B;V]K3F%M92DI.PH*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&-O
M;6UA;F1?=&5X="`N("1B:4)O;VLL('1R=64L('1R=64I.PH@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R
M;W(H)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A
M=&EO;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1A8F]O:TYA
M;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]T97AT("X@)&%B;V]K3F%M
M92P@=')U92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R
M7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@
M("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@("`@
M("`@?0H*("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*("`@
M("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^=W)I
M=&54;TQO9R@G1$5,151%041$4D534T)/3TL@8V]M<&QE=&5D($]+)RP@7U]&
M24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH*("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@("\O($-O=6QD
M(&YO="!$14Q%5$4@86)O;VLN"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E
M<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@
M("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R(&1I9"!N;W0@=6YD
M97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@+R\@4V]M971H:6YG('5N
M97AP96-T960N"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N)RP@7U]&24Q%7U\L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE<R!A;B!A9&1R97-S
M(&)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VM/;&1.
M86UE($]L9"!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86)O;VM.97=.
M86UE($YE=R!A9&1R97-S(&)O;VL@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D(%1R=64@+R!014%27T5R<F]R"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F%M94%D9')E<W-";V]K*"1A8F]O:T]L9$YA;64L("1A8F]O:TYE
M=TYA;64I"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)U)%3D%-14%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VM/
M;&1.86UE*2D@>PH@("`@("`@("`@("`D8FE/;&1.86UE(#T@<W!R:6YT9B@B
M>R5D?2(L('-T<FQE;B@D86)O;VM/;&1.86UE*2D["@H@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D8FE/;&1.86UE+"!F
M86QS92P@=')U92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K3VQD3F%M92`B+"!F86QS92P@
M9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*
M("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL
M("1A8F]O:TYE=TYA;64I*2!["B`@("`@("`@("`@("1B:4YE=TYA;64@/2!S
M<')I;G1F*")[)61](BP@<W1R;&5N*"1A8F]O:TYE=TYA;64I*3L*"B`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4YE
M=TYA;64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@0U),
M1B!S:6YC92!L87-T('!A<G0N"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)&%B;V]K3F5W3F%M92P@9F%L<V4L('1R=64I.PH@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O
M+R!'970@<V5R=F5R(')E<W!O;G-E+@H@("`@("`@("1S97)V97)?<F5S<&]N
M<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W
M:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@(&-A<V4@)TY/)SH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)
M35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G0D%$)SH*
M("`@("`@("`@("`@+R\@4WEN=&%X('!R;V)L96TN"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R
M(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RD["@H@("`@("`@
M(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O
M3&]G*")!9&1R97-S(&)O;VL@)&%B;V]K3VQD3F%M92!S=6-C97-S9G5L;'D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&%N9V5D
M('1O("1A8F]O:TYE=TYA;64B+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&
M3RD["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H
M)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T
M:&4@<V5R=F5R+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@86X@861D<F5S<R!B;V]K(&5N=')Y
M('1O(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A8F]O:R`@("`@3F%M92!O9B!A9&1R97-S(&)O;VL@=&\@861D(&5N
M=')Y('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;G1R>4EN9F\@($%D9')E
M<W,@8F]O:R!E;G1R>2!I;F9O<FUA=&EO;B`M"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE<F4@35535"!B92!A(&9I96QD("=N86UE)R!C
M;VYT86EN:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M(&5N=')Y(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4<G5E
M(&]N('-U8V-E<W,@+R!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%D9$5N=')Y*"1A8F]O:RP@)&5N=')Y26YF;RD*("`@
M('L*("`@("`@("`D8V]M;6%N9%]T97AT(#T@)R<["@H@("`@("`@(&EF("AG
M9714>7!E*"1E;G1R>4EN9F\I("$]("=A<G)A>2<I('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*$E-4U!?0D%$7T%21U5-
M14Y4+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@3&]C:R!T:&4@96YT<GD@:68@:70@86QR96%D>2!E>&ES=',N"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YL;V-K16YT<GDH)&%B;V]K+"`D96YT<GE)
M;F9O6R=N86UE)UTI.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N
M9"@G4U1/4D5!1$1215-3("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@5&%K92!C87)E
M(&]F('1H92!N86UE+@H@("`@("`@("1E;G1R>4YA;64@/2`D96YT<GE);F9O
M6R=N86UE)UT["@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O
M;VLI*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@
M<W1R;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&%B;V]K
M("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O($1O('=E(&YE960@>WT@
M9F]R(&5N=')Y(&YA;64@87,@=V5L;#\*("`@("`@("!I9B`H<')E9U]M871C
M:"A)35-07TU54U1?55-%7TQ)5$5204PL("1E;G1R>4YA;64I*2!["B`@("`@
M("`@("`@("1B:6YA;64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1E;G1R
M>4YA;64I*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D
M8FEN86UE+"!F86QS92P@=')U92D["B`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^:6US<%)E8V5I=F4H*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@D96YT<GE.86UE+"!F86QS92P@9F%L<V4I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(EPB
M)&5N=')Y3F%M95PB("(L(&9A;'-E+"!F86QS92D["B`@("`@("`@?0H*("`@
M("`@("!W:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C:"@D96YT<GE)
M;F9O*2D@>PH@("`@("`@("`@("`O+R!$;R!N;W0@<V5N="!T:&4@:V5Y(&YA
M;64@)VYA;64G+@H@("`@("`@("`@("!I9B`H)&ME>2`A/2`G;F%M92<I('L*
M("`@("`@("`@("`@("`@("\O(%!R;W1E8W0@9G)O;2!E>'1R86YE;W5S('=H
M:71E('-P86-E"B`@("`@("`@("`@("`@("`D=F%L=64@/2!T<FEM*"1V86QU
M92D["@H@("`@("`@("`@("`@("`@+R\@1F]R('-O;64@<F5A<V]N+"!T86)S
M('-E96T@=&\@8G)E86L@=&AI<RX*("`@("`@("`@("`@("`@("1V86QU92`]
M('!R96=?<F5P;&%C92@B+UQT+R(L(")<;EQR(BP@)'9A;'5E*3L*"B`@("`@
M("`@("`@("`@("`O+R!#:&5C:R!T;R!S964@:68@=V4@;F5E9"![?0H@("`@
M("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%
M4D%,+"`D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@)&-O;6UA;F1?
M=&5X="`N/2`D:V5Y("X@<W!R:6YT9B@B('LE9'TB+"!S=')L96XH)'9A;'5E
M*2D["@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H)&-O;6UA;F1?=&5X="P@9F%L<V4L('1R=64I.PH@("`@("`@("`@("`@
M("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!2
M96-E:79E*"D["B`@("`@("`@("`@("`@("`@("`@)&-O;6UA;F1?=&5X="`]
M("<G.R`O+T-L96%R('1H92!C;VUM86YD7W1E>'0@8G5F9F5R"@H@("`@("`@
M("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7W)E<W!O;G-E
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@97AP96-T960@
M<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`@("`@+R\@4V5N9"!T:&4@<W1R:6YG(&]F(&]C=&5T<R!A;F0@
M8F4@<W5R92!.3U0@=&\*("`@("`@("`@("`@("`@("`@("`O+R!E;F0@=VET
M:"!#4DQ&+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H)'9A;'5E+"!F86QS92P@9F%L<V4I.PH*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@268@=V4@87)E(&AE
M<F4L('1H96X@=V4@9&\@;F]T(&YE960@=&\@<V5N9"!A"B`@("`@("`@("`@
M("`@("`@("`@+R\@>WTN"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M(EPB(B`N("1V86QU92`N(")<(B(["B`@("`@("`@("`@("`@("`@("`@)&-O
M;6UA;F1?=&5X="`N/2`D:V5Y("X@)R`G("X@)'9A;'5E("X@)R`G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`O+R!396YD(&%N>71H:6YG('1H870@:7,@;&5F="!O9B!T:&4@8V]M;6%N
M9"X*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1C;VUM86YD7W1E
M>'0L(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@
M)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!S=VET8V@@
M*"1S97)V97)?<F5S<&]N<V4I('L*("`@("`@("!C87-E("=.3R<Z"B`@("`@
M("`@("`@("\O4V]R<GDN+BYC86YN;W0@9&\@:70N"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G24U34"!S97)V97(@:7,@
M=6YA8FQE('1O('!E<F9O<FT@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T)!1"<Z"B`@("`@("`@("`@("\O
M4V]R<GDN+BYD:60@;F]T('5N9&5R<W1A;F0@>6]U"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AE($E-4U`@<V5R=F5R
M(&1I9"!N;W0@=6YD97)S=&%N9"!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-E<G9E<E]R97-P
M;VYS92`A/2`G3TLG*2!["B`@("`@("`@("`@("\O($-Y<G5S+4E-4U`@<V5R
M=F5R('-E;F1S(&$@1D540TA!1$1215-3(%)E<W!O;G-E(&AE<F4N"B`@("`@
M("`@("`@("\O($1O(&]T:&5R<S\@("`@(%1H:7,@=V%S(&YO="!I;B!T:&4@
M4D9#+@H@("`@("`@("`@("`D9'5M;7E?87)R87D@/0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)S949E=&-H061D<F5S<U)E<W!O;G-E*"1S97)V97)?
M<F5S<&]N<V4I.PH*("`@("`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1T
M:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*3L*"B`@("`@("`@("`@('-W:71C
M:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@("`@("!C87-E("=.3R<Z
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R
M;W(H)TE-4U`@<V5R=F5R(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q
M=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!C87-E
M("="040G.@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD
M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7RD["B`@("`@
M("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^=W)I=&54;TQO9R@G4U1/4D5!1$1215-3($-O;7!L971E9"!S=6-C97-S
M9G5L;'DN)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH*("`@
M("`@("`@("`@("`@("\O=V4@=V5R92!S=6-C97-S9G5L+BXN<V\@<F5L96%S
M92!T:&4@;&]C:R!O;B!T:&4@96YT<GD*("`@("`@("`@("`@("`@(&EF("@A
M)'1H:7,M/G5N;&]C:T5N=')Y*"1A8F]O:RP@)&5N=')Y26YF;ULG;F%M92==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("\O8V]U;&0@;F]T(')E;&5A<V4@
M;&]C:PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M
M/FEM<W!%<G)O<B@G5&AA="!A9&1R97-S(&)O;VL@96YT<GD@:7,@;&]C:V5D
M(&]R(')E860@;VYL>2!F;W(@=&AE(&-U<G)E;G0@=7-E<BXG+"!?7T9)3$5?
M7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!A8F]O:R!E;G1R
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:R`@("`@3F%M
M92!O9B!A9&1R97-S(&)O;VL@8V]N=&%I;FEN9R!E;G1R>2X*("`@("`J($!P
M87)A;2!S=')I;F<@)&)O;VM%;G1R>2!.86UE(&]F(&5N=')Y('1O(&1E;&5T
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@;VX@<W5C8V5S
M<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5L971E16YT<GDH)&%B;V]K+"`D8F]O:T5N=')Y*0H@("`@>PH@("`@
M("`@("\O(%-T87)T('1H92!C;VUM86YD+@H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7VEM<W`M/FEM<W!396YD*"=$14Q%5$5!1$1215-3("<L('1R=64L
M(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+R\@3F5E9"![?2!F;W(@8F]O:R!N86UE/PH@("`@("`@(&EF
M("AP<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K*2D@
M>PH@("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE
M;B@D86)O;VLI*3L*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E
M;F0H)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*"%P
M<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["@H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T
M(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N
M<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*"B`@("`@
M("`@+R](;W<@8F]U="!F;W(@=&AE(&5N=')Y(&YA;64_"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D8F]O:T5N=')Y
M*2D@>PH@("`@("`@("`@("`D8FE%;G1R>2`]('-P<FEN=&8H(GLE9'TB+"!S
M=')L96XH)&)O;VM%;G1R>2DI.PH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P
M+3YI;7-P4V5N9"@D8FE%;G1R>2P@9F%L<V4L('1R=64I.PH*("`@("`@("`@
M("`@:68@*"%P<F5G7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H
M)T1I9"!N;W0@<F5C96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO
M;B!R97-P;VYS92!F<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("`@("`@?0H*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8F]O:T5N=')Y(#T@)'1H:7,M/E]I;7-P+3YQ=6]T95-P86-E
M9%-T<FEN9R@D8F]O:T5N=')Y*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?:6US<"T^:6US<%-E;F0H)&)O;VM%;G1R>2P@9F%L<V4L('1R=64I.PH@
M("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!2
M96-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@
M>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@+R]3;W)R>2XN8V%N
M;F]T(&1O(&ET"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM
M<W!%<G)O<B@G24U34"!S97)V97(@:7,@=6YA8FQE('1O('!E<F9O<FT@>6]U
M<B!R97%U97-T+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@8V%S
M92`G0D%$)SH*("`@("`@("`@("`@+R]$;R!N;W0@:VYO=R!W:&%T('EO=7(@
M=&%L:VEN9R!A8F]U=`H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P
M+3YI;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A
M;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U],24Y%7U\I.PH@("`@("`@
M(&-A<V4@)T]+)SH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YW<FET951O
M3&]G*"=$14Q%5$4@0V]M<&QE=&5D('-U8V-E<W-F=6QL>2XG+"!?7T9)3$5?
M7RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.
M15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M86-Q=6ER92!A('-E;6%P:&]R92!O;B!T:&4@861D<F5S<R!B;V]K(&5N=')Y
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%B;V]K("`@("!!9&1R
M97-S(&)O;VL@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]O:T5N=')Y
M($YA;64@;V8@96YT<GD@=&\@;&]C:PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@=')U92!O<B!A<G)A>2!O;B!S=6-C97-S(&%N9"!014%27T5R<F]R
M(&]N(&9A:6QU<F4*("`@("`J("`@("`@("`@("`@("`@*'-E<G9E<B!D97!E
M;F1I;F<I"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO8VM%;G1R>2@D86)O;VLL
M("1B;V]K16YT<GDI"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6US<"T^:6US<%-E;F0H)TQ/0TL@041$4D534T)/3TL@)RP@=')U92P@9F%L
M<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@
M("`@("`O+R!$;R!W92!N965D(&$@<W1R:6YG(&QI=&5R86P_"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VLI
M*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@<W1R
M;&5N*"1A8F]O:RDI.PH*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P
M4V5N9"@D8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO
M="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O
M;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A;'-E*3L*"B`@("`@
M("`@+R\@5VAA="!A8F]U="!T:&4@96YT<GD@;F%M93\*("`@("`@("!I9B`H
M<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1B;V]K16YT<GDI
M*2!["B`@("`@("`@("`@("1B:45N=')Y(#T@<W!R:6YT9B@B>R5D?2(L('-T
M<FQE;B@D8F]O:T5N=')Y*2D["@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M
M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D["@H@("`@("`@("`@
M("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G
M1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N
M(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1B;V]K16YT<GDL(&9A;'-E+"!T<G5E*3L*"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R>2`]("1T:&ES+3Y?
M:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R>2D["B`@("`@("`@
M("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1B;V]K16YT<GDB+"!F86QS
M92P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E
M(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!D;R![
M"@H@("`@("`@("`@("!S=VET8V@@*"1S97)V97)?<F5S<&]N<V4I('L*"B`@
M("`@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G5&AA="!A9&1R97-S(&)O;VL@96YT
M<GD@:7,@;&]C:V5D(&]R(')E860@;VYL>2!F;W(@=&AE(&-U<G)E;G0@=7-E
M<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(&-A<V4@
M)T)!1"<Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI
M;7-P17)R;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@
M>6]U<B!R97%U97-T+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?3$E.15]?*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R]#:&5C:R!T;R!S964@:68@=&AI<R!I
M<R!A($9%5$-(041$4D534R!R97-O;G-E"B`@("`@("`@("`@("1D=6UM>2`]
M("1T:&ES+3Y?<&%R<V5&971C:$%D9')E<W-297-P;VYS92@D<V5R=F5R7W)E
M<W!O;G-E*3L*"B`@("`@("`@("`@(&EF("@D9'5M;7DI('L*("`@("`@("`@
M("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!2
M96-E:79E*"D["B`@("`@("`@("`@('T*"B`@("`@("`@?2!W:&EL92`H)'-E
M<G9E<E]R97-P;VYS92`A/2`G3TLG*3L*"B`@("`@("`@)'1H:7,M/E]I;7-P
M+3YW<FET951O3&]G*"),3T-+($%$1%)%4U-"3T]+(&]N("1A8F]O:R`D8F]O
M:T5N=')Y($]+(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*"B`@("`@("`@
M+R\@4F5T=7)N(&5I=&AE<B!T<G5E(&]R('1H92!&151#2$%$1%)%4U,@<F5S
M<&]N<V4@:68@:70@97AI<W1S+@H@("`@("`@(&EF("@A)&1U;6UY*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D9'5M;7D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@56YL;V-K<R!A('!R979I;W5S;'D@;&]C:V5D(&%D9')E<W,@
M8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8F]O:R`@("`@
M3F%M92!O9B!A9&1R97-S(&)O;VL@8V]N=&%I;FEN9R!L;V-K960@96YT<GDN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;V]K16YT<GD@3F%M92!O9B!E;G1R
M>2!T;R!U;FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!4<G5E
M(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=6YL;V-K16YT<GDH)&%B;V]K+"`D8F]O:T5N=')Y*0H@
M("`@>PH@("`@("`@("\O(%-T87)T('-E;F1I;F<@8V]M;6%N9"X*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G54Y,3T-+($%$
M1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@>WT@9F]R(&)O;VL@;F%M
M93\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$52
M04PL("1A8F]O:RDI('L*("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H
M(GLE9'TB+"!S=')L96XH)&%B;V]K*2D["@H@("`@("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@
M("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU
M871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"(D86)O;VL@(BP@9F%L<V4L(&9A
M;'-E*3L*"B`@("`@("`@+R](;W<@8F]U="!F;W(@96YT<GD@;F%M93\*("`@
M("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1B
M;V]K16YT<GDI*2!["B`@("`@("`@("`@("1B:45N=')Y/7-P<FEN=&8H(GLE
M9'TB+"!S=')L96XH)&)O;VM%;G1R>2DI.PH@("`@("`@("`@("`D=&AI<RT^
M7VEM<W`M/FEM<W!396YD*"1B:45N=')Y+"!F86QS92P@=')U92D["@H@("`@
M("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%
M<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN
M=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"1B;V]K16YT<GDL(&9A;'-E+"!T<G5E*3L*
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)O;VM%;G1R>2`]("1T
M:&ES+3Y?:6US<"T^<75O=&53<&%C9613=')I;F<H)&)O;VM%;G1R>2D["B`@
M("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H(B1B;V]K16YT<GDB
M+"!F86QS92P@=')U92D["B`@("`@("`@?0H*("`@("`@("`D<F5S<&]N<V4@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W:71C
M:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)TE-4U`@<V5R=F5R
M(&ES('5N86)L92!T;R!P97)F;W)M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH*("`@("`@("!C87-E("="040G.@H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)U1H92!)35-0('-E
M<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R97%U97-T+B<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["@H@("`@("`@(&-A<V4@)T]+)SH*("`@("`@("`@
M("`@)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*")53DQ/0TL@041$4D534T)/
M3TL@;VX@)&%B;V]K("1B;V]K16YT<GD@3TLB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U])3D9/*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@06-C97-S($-O;G1R;VP@3&ES="`H
M04-,*2`@365T:&]D<RX*("`@("`J"B`@("`@*B!4:&4@9F]L;&]W:6YG(&-H
M87)A8W1E<G,@87)E(')E8V]G;FEZ960@04-,(&-H87)A8W1E<G,Z(&QR=V-D
M80H@("`@("H@;"`M(")L;V]K=7`B("`H<V5E('1H92!N86UE(&%N9"!E>&ES
M=&5N8V4@;V8@=&AE(&%D9')E<W,@8F]O:RD*("`@("`J('(@+2`B<F5A9"(@
M("`@*'-E87)C:"!A;F0@<F5T<FEE=F4@861D<F5S<V5S(&9R;VT@861D<F5S
M<R!B;V]K*0H@("`@("H@=R`M(")W<FET92(@("`H8W)E871E+V5D:70@;F5W
M(&%D9')E<W,@8F]O:R!E;G1R:65S("T@;F]T(&1E;&5T92D*("`@("`J(&,@
M+2`B8W)E871E(B`@*&-R96%T92!N97<@861D<F5S<R!B;V]K<R!U;F1E<B!T
M:&4@8W5R<F5N="!A9&1R97-S(&)O;VLI"B`@("`@*B!D("T@(F1E;&5T92(@
M("AD96QE=&4@96YT<FEE<R!O<B!E;G1I<F4@8F]O:RD*("`@("`J(&$@+2`B
M861M:6XB("`@*'-E="!!0TP@;&ES=',@9F]R('1H:7,@861D<F5S<R!B;V]K
M("T@=7-U86QL>2!O;FQY"B`@("`@*B`@("`@("`@("`@("`@(&%L;&]W960@
M9F]R('1H92!O=VYE<B!O9B!T:&4@861D<F5S<R!B;V]K*0H@("`@("H*("`@
M("`J(&5X86UP;&5S.@H@("`@("H@(")L<B(@=V]U;&0@8F4@<F5A9"!O;FQY
M(&9O<B!T:&%T('5S97(*("`@("`J("`B;')W(B!W;W5L9"!B92!R96%D+W=R
M:71E"B`@("`@*B\*"B`@("`O*BH*("`@("`J(%-E=',@86X@06-C97-S($-O
M;G1R;VP@3&ES="!F;W(@86X@86)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D86)O;VL@3F%M92!O9B!A9&1R97-S(&)O;VLN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I9&5N="!.86UE(&]F('5S97(@9F]R('1H:7,@86-L
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D86-L("`@86-L(&9O<B!T:&ES('5S
M97(O8F]O:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@;VX@
M<W5C8V5S<R`O(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T04-,*"1A8F]O:RP@)&ED96YT+"`D86-L*0H@("`@>PH@
M("`@("`@("\O(%9E<FEF>2!T:&%T("1A8VP@;&]O:W,@9V]O9"X*("`@("`@
M("!I9B`H<')E9U]M871C:"@B+UM>(B`N($E-4U!?04-,7U))1TA44R`N(")=
M+R(L("1A8VPI*2!["B`@("`@("`@("`@("\O97)R;W(N+BYA8VP@;&ES="!C
M;VYT86EN960@=6YR96-O9VEN>F5D(&]P=&EO;G,*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*$E-4U!?0D%$7T%21U5-14Y4
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0F5G:6X@<V5N9&EN9R!C;VUM86YD+@H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7VEM<W`M/FEM<W!396YD*"=3151!0TP@041$4D534T)/3TL@)RP@=')U
M92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`O+R![?2!F;W(@8F]O:R!N86UE/PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&%B;V]K*2D@>PH@
M("`@("`@("`@("`D8FE";V]K(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D
M86)O;VLI*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@D
M8FE";V]K+"!F86QS92P@=')U92D["@H@("`@("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H(B]>7"LO(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E(&5X<&5C=&5D(&-O;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R
M;VT@24U34"!S97)V97(N)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("!]"@H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI
M;7-P4V5N9"@B)&%B;V]K("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O
M('M](&9O<B!I9&5N=#\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU5
M4U1?55-%7TQ)5$5204PL("1I9&5N="DI('L*("`@("`@("`@("`@)&)I261E
M;G0@/2!S<')I;G1F*")[)61](BP@<W1R;&5N*"1I9&5N="DI.PH@("`@("`@
M("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1B:4ED96YT+"!F86QS92P@
M=')U92D["@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US
M<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E:79E(&5X<&5C=&5D(&-O
M;6UA;F0@8V]N=&EN=6%T:6]N(')E<W!O;G-E(&9R;VT@24U34"!S97)V97(N
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B)&ED96YT
M("(L(&9A;'-E+"!F86QS92D["@H@("`@("`@("\O($YO=R!F:6YI<V@@=7`@
M=VET:"!T:&4@86-T=6%L($%#3"X*("`@("`@("`D=&AI<RT^7VEM<W`M/FEM
M<W!396YD*"1A8VPL(&9A;'-E+"!T<G5E*3L*("`@("`@("`D<F5S<&]N<V4@
M/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('-W:71C
M:"`H)')E<W!O;G-E*2!["B`@("`@("`@8V%S92`G3D\G.@H@("`@("`@("`@
M("`O+R!#;W5L9"!N;W0@<V5T($%#3"X*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@
M=&\@<&5R9F]R;2!Y;W5R(')E<75E<W0N)RQ?7T9)3$5?7RP@7U],24Y%7U\I
M.PH*("`@("`@("!C87-E("="040G.@H@("`@("`@("`@("`O+R!"860@<WEN
M=&%X+@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R
M;W(H)U1H92!)35-0('-E<G9E<B!D:60@;F]T('5N9&5R<W1A;F0@>6]U<B!R
M97%U97-T+B<L7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S92`G
M3TLG.@H@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],;V<H(D%#
M3"!S970@9F]R("1I9&5N="!O;B`D86)O;VLB+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@+R\@1&\@;F]T(&MN;W<@=VAY('=E
M('=O=6QD(&UA:V4@:70@9&]W;B!H97)E+@H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV92!T:&4@
M97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M=')I979E<R!A;B!A9&1R97-S(&)O;VLG<R!!0TPN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D86)O;VL@3F%M92!O9B!A9&1R97-S(&)O;VL@=&\@
M<F5T<FEE=F4@86-L(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(&%R<F%Y(&-O;G1A:6YI;F<@86-L(&9O<B!E=F5R>2!U<V5R('=I=&@@86-C
M97-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&%D9')E<W,@8F]O
M:R!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%#3"@D86)O;VLI"B`@("!["B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?:6US<"T^:6US<%-E;F0H)T=%5$%#3"!!1$1215-30D]/2R`G+"!T
M<G5E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\O('M](&9O<B!B;V]K(&YA;64_"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VLI*2![
M"B`@("`@("`@("`@("1B:4YA;64@/2!S<')I;G1F*")[)61](BP@<W1R;&5N
M*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!396YD
M*"1B:4YA;64L(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E
M8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@
M9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H)&%B;V]K+"!F86QS92P@=')U92D["@H@("`@("`@("\O($=E
M="!R97-U;'1S+@H@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^
M:6US<%)E8V5I=F4H*3L*"B`@("`@("`@<W=I=&-H("@D<F5S<&]N<V4I('L*
M("`@("`@("!C87-E("=.3R<Z"B`@("`@("`@("`@("\O($-O=6QD(&YO="!C
M;VUP;&5T93\*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y;W5R
M(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@8V%S
M92`G0D%$)SH*("`@("`@("`@("`@+R\@1&\@;F]T(&MN;W<@=VAA="!Y;W4@
M<V%I9"$*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD('EO=7(@
M<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@268@=V4@87)E(&AE<F4L('=E(&YE960@=&\@<F5C96EV92!T
M:&4@*B!!0TP@4F5S<&]N<V5S+@H@("`@("`@(&1O('L*("`@("`@("`@("`@
M+RH@1V5T(&%N(&%R<F%Y(&]F(')E<W!O;G-E<RX*("`@("`@("`@("`@("H@
M5&AE(%LS72!E;&5M96YT('-H;W5L9"!B92!T:&4@861D<F5S<R!B;V]K(&YA
M;64*("`@("`@("`@("`@("H@6S1=(&%N9"!;-5T@=VEL;"!B92!U<V5R+V=R
M;W5P(&YA;64@86YD('!E<FUI<W-I;VYS("HO"@H@("`@("`@("`@("`O+W1H
M92!B;V]K(&YA;64@;6EG:'0@8F4@82!L:71E<F%L"B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*$E-4U!?3T-4151?0T]53E0L("1R97-P;VYS92P@)'1E
M;7!!<G)A>2DI('L*("`@("`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]I
M;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@D=&5M<$%R<F%Y6S)=*3L*("`@
M("`@("`@("`@("`@("\O1V5T('1H92!R97-T"B`@("`@("`@("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R`G+"`D
M<F5S<&]N<V4I.PH*("`@("`@("`@("`@+R\@4'5S:"!T:&4@87)R87D@:68@
M8F]O:R!W87,@82!L:71E<F%L"B`@("`@("`@("`@(&EF("@D9&%T82D@>PH@
M("`@("`@("`@("`@("`@87)R87E?=6YS:&EF="@D<&%R=',L("<@)RP@)R`G
M+"`G("<L("<@)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@061D
M<F5S<R!B;V]K(&YA;64@<75O=&5D/PH@("`@("`@("`@("`D;G5M4&%R=',@
M/2!C;W5N="@D<&%R=',I.PH@("`@("`@("`@("`D;F%M92`]("1P87)T<ULS
M73L*("`@("`@("`@("`@)&9I<G-T04-,261X(#T@-#L*("`@("`@("`@("`@
M)&9I<G-T0VAA<B`]('-U8G-T<B@D;F%M92P@,"P@,2D["B`@("`@("`@("`@
M(&EF("@D9FER<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`T.R`D:2`\("1N=6U087)T<SL@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D<&%R='-;)&E=+"!S=')L
M96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@("`D
M9FER<W1!0TQ)9'@K*SL*("`@("`@("`@("`@("`@("`@("!I9B`H)&QA<W1#
M:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@)&9I<G-T04-,261X
M.R`D:2`\(&-O=6YT*"1P87)T<RD[("1I("L](#(I('L*("`@("`@("`@("`@
M("`@("1R97-U;'1S6R1P87)T<ULD:5U=(#T@)'!A<G1S6R1I*S%=.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7VEM
M<W`M/FEM<W!296-E:79E*"D["@H@("`@("`@('T@=VAI;&4@*'!R96=?;6%T
M8V@H(B]>7"H@04-,($%$1%)%4U-"3T]++R(L("1R97-P;VYS92DI.PH*("`@
M("`@("`O+R!(;W!E9G5L;'D@=V4@8V%N(')E8V5I=F4@86X@3TL@<F5S<&]N
M<V4@:&5R90H@("`@("`@(&EF("@D<F5S<&]N<V4@(3T@)T]+)RD@>PH@("`@
M("`@("`@("`O+R!3;VUE('=E:7)D('!R;V)L96T*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@
M=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US
M<"T^=W)I=&54;TQO9R@B1T5404-,(&]N("1A8F]O:R!C;VUP;&5T960N(BP@
M7U]&24Q%7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("!R971U<FX@)')E<W5L
M=',["@H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!!0TP@96YT
M<GD@9F]R(&%N(&%D9')E<W,@8F]O:RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A8F]O:R!.86UE(&]F('1H92!A9&1R97-S(&)O;VLN"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9&5N="!.86UE(&]F(&5N=')Y('1O(')E;6]V
M92!A8VP@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@=')U92!O
M;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E;&5T94%#3"@D86)O;VLL("1I9&5N="D*("`@('L*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@G1$5,151%
M04-,($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@1&\@=V4@;F5E
M9"!L:71E<F%L(&9O<B!A9&1R97-S(&)O;VL@;F%M93\*("`@("`@("!I9B`H
M<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)5$5204PL("1A8F]O:RDI('L*
M("`@("`@("`@("`@)&)I0F]O:R`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH
M)&%B;V]K*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H
M)&)I0F]O:RP@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"(O7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"DI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C
M96EV92!E>'!E8W1E9"!C;VUM86YD(&-O;G1I;G5A=&EO;B!R97-P;VYS92!F
M<F]M($E-4U`@<V5R=F5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?0H*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H(B1A8F]O:R`B+"!F86QS92P@9F%L<V4I.PH*("`@("`@("`O
M+R!,:71E<F%L(&9O<B!I9&5N="!N86UE/PH@("`@("`@(&EF("AP<F5G7VUA
M=&-H*$E-4U!?35535%]54T5?3$E415)!3"P@)&ED96YT*2D@>PH@("`@("`@
M("`@("`D8FE)9&5N="`]('-P<FEN=&8H(GLE9'TB+"!S=')L96XH)&ED96YT
M*2D["B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&)I261E
M;G0L(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A<')E9U]M871C
M:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@
M97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)
M35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^:6US<%-E;F0H)&ED
M96YT+"!F86QS92P@=')U92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]I;7-P+3YI;7-P4V5N9"@B7"(D:61E;G1<(B(L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("\O($=E="!R97-U;'1S+@H@
M("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!2
M96-E:79E*"D["@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@
M>PH@("`@("`@(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@
M<&5R9F]R;2!Y;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M"B`@("`@("`@8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U
M;F1E<G-T86YD('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH*("`@("`@("!C87-E("=/2R<Z"B`@("`@("`@("`@("1T:&ES+3Y?:6US
M<"T^=W)I=&54;TQO9R@B1$5,151%1"!!0TP@9F]R("1I9&5N="!O;B`D86)O
M;VLB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]I;7-P+3YI;7-P17)R;W(H)T1I9"!N;W0@<F5C96EV
M92!T:&4@97AP96-T960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@86X@04-,('-T<FEN9R!C;VYT86EN:6YG('1H92!R:6=H
M=',@9F]R('1H92!C=7)R96YT('5S97(*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A8F]O:R!.86UE(&]F(&%D9')E<W,@8F]O:R!T;R!R971R:65V
M92!A8VPN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!A8VP@;V8@8W5R
M<F5N="!U<V5R(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@;7E2:6=H=',H)&%B;V]K*0H@("`@>PH@("`@("`@("1D
M871A(#T@)R<["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^:6US
M<%-E;F0H)TU94DE'2%13($%$1%)%4U-"3T]+("<L('1R=64L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M:68@*'!R96=?;6%T8V@H24U34%]-55-47U5315],251%4D%,+"`D86)O;VLI
M*2!["B`@("`@("`@("`@("1B:4)O;VL@/2!S<')I;G1F*")[)61](BP@<W1R
M;&5N*"1A8F]O:RDI.PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/FEM<W!3
M96YD*"1B:4)O;VLL(&9A;'-E+"!T<G5E*3L*"B`@("`@("`@("`@(&EF("@A
M<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T
M(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I;VX@<F5S<&]N
M<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM
M<W`M/FEM<W!396YD*"1A8F]O:RP@9F%L<V4L('1R=64I.PH@("`@("`@("1S
M97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D[
M"@H@("`@("`@('-W:71C:"`H)'-E<G9E<E]R97-P;VYS92D@>PH@("`@("`@
M(&-A<V4@)TY/)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=)35-0('-E<G9E<B!I<R!U;F%B;&4@=&\@<&5R9F]R;2!Y
M;W5R(')E<75E<W0N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@
M8V%S92`G0D%$)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^
M:6US<$5R<F]R*"=4:&4@24U34"!S97)V97(@9&ED(&YO="!U;F1E<G-T86YD
M('EO=7(@<F5Q=65S="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7EPJ($U94DE'2%13($%$
M1%)%4U-"3T]++R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7VEM<W`M/FEM<W!%<G)O<B@G1&ED(&YO="!R96-E
M:79E('1H92!E>'!E8W1E9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R![?2!F
M;W(@=&AE(&%B;V]K(&YA;64_"B`@("`@("`@:68@*'!R96=?;6%T8V@H24U3
M4%]/0U1%5%]#3U5.5"P@)'-E<G9E<E]R97-P;VYS92P@)'1E;7!!<G)A>2DI
M('L*("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7VEM<W`M/G)E8V5I=F53
M=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@("`@("`O+R!'
M970@=&AE(')E<W0N"B`@("`@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D
M=&AI<RT^7VEM<W`M/FEM<W!296-E:79E*"D["B`@("`@("`@?0H*("`@("`@
M("`D<&%R=',@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R97-P;VYS92D["@H@
M("`@("`@("\O(%!U<V@@=&AE(&%R<F%Y(&EF('=E(&AA9"!A('M]"B`@("`@
M("`@:68@*"1D871A*2!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)'!A
M<G1S+"`G("<L("<@)RP@)R`G+"`G("<I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@475O=&5D(&%D9')E<W,@8F]O:R!N86UE/PH@("`@("`@("1N=6U087)T
M<R`](&-O=6YT*"1P87)T<RD["B`@("`@("`@)&YA;64@/2`D<&%R='-;,UT[
M"B`@("`@("`@)&9I<G-T04-,261X(#T@-#L*("`@("`@("`D9FER<W1#:&%R
M(#T@<W5B<W1R*"1N86UE+"`P+"`Q*3L*("`@("`@("!I9B`H)&9I<G-T0VAA
M<B`]/2`B7"(B*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`T.R`D:2`\("1N
M=6U087)T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&QA<W1#:&%R(#T@
M<W5B<W1R*"1P87)T<ULD:5TL('-T<FQE;B@D<&%R='-;)&E=*2`M(#$L(#$I
M.PH@("`@("`@("`@("`@("`@)&9I<G-T04-,261X*RL["B`@("`@("`@("`@
M("`@("!I9B`H)&QA<W1#:&%R(#T](")<(B(I('L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&%C;"`]("1P87)T<ULD9FER<W1!0TQ)9'A=
M.PH@("`@("`@("1S97)V97)?<F5S<&]N<V4@/2`D=&AI<RT^7VEM<W`M/FEM
M<W!296-E:79E*"D["@H@("`@("`@(&EF("@D<V5R=F5R7W)E<W!O;G-E("$]
M("=/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US
M<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@=&AE(&5X<&5C=&5D(')E<W!O;G-E
M(&9R;VT@=&AE('-E<G9E<BXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],
M;V<H(DU94DE'2%13(&]N("1A8F]O:R!C;VUP;&5T960N(BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@("`@("!R971U<FX@)&%C;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!L;V<@
M:6YF;W)M871I;VX@:6X@=&AE($YE=%])35-0(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@(&%R<F%Y("!,;V<@<&%R86UE=&5R<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O
M<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G97(H
M)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]I;7-P
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YS971,;V=G
M97(H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE($E-4U`@;&]G(&-O=6QD(&YO
M="!B92!I;FET:6%L:7IE9"XB*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4&%R<V5S(&$@24U34"!F971C:&%D9')E<W,@<F5S<&]N<V4@
M=&5X="!S=')I;F<@:6YT;PH@("`@("H@:V5Y+79A;'5E('!A:7)S"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@('-T<FEN
M9R`@)'-E<G9E<E]R97-P;VYS92!4:&4@<F%W(&9E=&-H861D<F5S<R!R97-P
M;VYS92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@061D<F5S<R!B
M;V]K(&5N=')Y(&EN9F]R;6%T:6]N(&%S(&ME>3T^=F%L=64@<&%I<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]P87)S949E=&-H061D<F5S<U)E<W!O;G-E
M*"1S97)V97)?<F5S<&]N<V4I"B`@("!["B`@("`@("`@)&%B;V]K(#T@)R<[
M"@H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*B!&151#2$%$1%)%4U,@
M+R(L("1S97)V97)?<F5S<&]N<V4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M:6US<"T^=W)I=&54;TQO9R@G6T524D]272!$:60@;F]T(')E8V5I=F4@82!&
M151#2$%$1%)%4U,@<F5S<&]N<V4@9G)O;2!S97)V97(N)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*"B`@("`@("`@("`@("1T:&ES+3Y?:6US<"T^
M97AI=$-O9&4@/2`G1&ED(&YO="!R96-E:79E('1H92!E>'!E8W1E9"!R97-P
M;VYS92!F<F]M('1H92!S97)V97(N)SL*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@3D]415,*("`@("`@("`@*B!0
M87)S92!O=70@=&AE('-E<G9E<B!R97-P;VYS92!S=')I;F<*("`@("`@("`@
M*@H@("`@("`@("`J($%F=&5R(&-H;W!I;F<@;V9F('1H92!S97)V97(@8V]M
M;6%N9"!R97-P;VYS92!T86=S(&%N9`H@("`@("`@("`J(&5X<&QO9&4H*2=I
M;F<@=&AE('-E<G9E<E]R97-P;VYS92!S=')I;F<*("`@("`@("`@*B!T:&4@
M)'!A<G1S(&%R<F%Y(&-O;G1A:6YS('1H92!C:'5N:W,@;V8@=&AE('-E<G9E
M<B!R971U<FYE9"!D871A+@H@("`@("`@("`J"B`@("`@("`@("H@5&AE('!R
M961I9FEN960@)VYA;64G(&9I96QD('-T87)T<R!I;B`D<&%R='-;,5TN"B`@
M("`@("`@("H@5&AE('-E<G9E<B!S:&]U;&0@<F5T=7)N(&%N>2!S:6YG;&4@
M:71E;2!O9B!D871A"B`@("`@("`@("H@=&AA="!C;VYT86EN<R!S<&%C97,@
M=VET:&EN(&ET(&%S(&$@9&]U8FQE('%U;W1E9"!S=')I;F<N"B`@("`@("`@
M("H@4V\@=V4@8V%N(&EN=&5R<')E="!T:&4@97AI<W1E;F-E(&]F(&$@9&]U
M8FQE('%U;W1E(&%T('1H92!B96=I;FYI;F<*("`@("`@("`@*B!O9B!A(&-H
M=6YK('1O(&UE86X@=&AA="!T:&4@;F5X="!C:'5N:RAS*2!A<F4@<&%R="!O
M9@H@("`@("`@("`J('1H92!S86UE('9A;'5E+B`@02!D;W5B;&4@<75O=&4@
M870@=&AE(&5N9"!O9B!A(&-H=6YK('-I9VYI9FEE<R!T:&4*("`@("`@("`@
M*B!E;F0@;V8@=&AA="!V86QU92!A;F0@=&AE(&-H=6YK(&9O;&QO=VEN9R!T
M:&%T(&-A;B!B92!I;G1E<G!R971E9`H@("`@("`@("`J(&%S(&$@:V5Y(&YA
M;64N"B`@("`@("`@("H*("`@("`@("`@*B!792!A;'-O(&YE960@=&\@=V%T
M8V@@9F]R('1H92!S97)V97(@<F5T=7)N:6YG(&$@>WT@<F5S<&]N<V4@9F]R
M('1H90H@("`@("`@("`J('9A;'5E(&]F('1H92!K97D@87,@=V5L;"X@*B\*
M"B`@("`@("`@+R\@5V%S('1H92!A9&1R97-S(&)O;VL@;F%M92!A("![?3\*
M("`@("`@("!I9B`H<')E9U]M871C:"@B+RA>7"H@1D540TA!1$1215-3("DH
M>RDH6S`M.5U[,2Q]*2A<?20I+R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'-E<G9E<E]R97-P;VYS92P@)'1E;7!!<G)A>2DI('L*("`@("`@("`@("`@
M)&%B;V]K(#T@)'1H:7,M/E]I;7-P+3YR96-E:79E4W1R:6YG3&ET97)A;"@D
M=&5M<$%R<F%Y6S-=*3L*("`@("`@("`@("`@)&-H;W!P961?<F5S<&]N<V4@
M/2!T<FEM*"1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+R\@5&%K92!O9F8@=&AE('-T=69F(&9R
M;VT@=&AE(&)E9VEN;FEN9R!O9B!T:&4@<F5S<&]N<V4*("`@("`@("`@("`@
M)&-H;W!P961?<F5S<&]N<V4@/2!T<FEM*'!R96=?<F5P;&%C92@B+UY<*B!&
M151#2$%$1%)%4U,@+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R<L("1S97)V97)?<F5S<&]N<V4I*3L*
M("`@("`@("!]"@H@("`@("`@("1P87)T<R`](&5X<&QO9&4H)R`G+"`D8VAO
M<'!E9%]R97-P;VYS92D["B`@("`@("`@+RH@268@861D<F5S(&)O;VL@=V%S
M('-E;G0@87,@82![?2!T:&5N('=E(&UU<W0@)W!U<V@G(&$@8FQA;FL*("`@
M("`@("`@*B!V86QU92!T;R!T:&4@<W1A<G0@;V8@=&AI<R!A<G)A>2!S;R!T
M:&4@<F5S="!O9B!T:&4@<F]U=&EN90H@("`@("`@("`J('=I;&P@=V]R:R!W
M:71H('1H92!C;W)R96-T(&EN9&5X97,N("HO"B`@("`@("`@(&EF("@A96UP
M='DH)&%B;V]K*2D@>PH@("`@("`@("`@("!A<G)A>5]U;G-H:69T*"1P87)T
M<RP@)R`G*3L*("`@("`@("!]"@H@("`@("`@("\O(%=A<R!T:&4@861D<F5S
M<R!B;V]K(&YA;64@<75O=&5D/PH@("`@("`@("1N=6U/9E!A<G1S(#T@8V]U
M;G0H)'!A<G1S*3L*("`@("`@("`D;F%M92`]("1P87)T<ULP73L*("`@("`@
M("`D9FER<W1.86UE261X(#T@,3L*("`@("`@("`D9FER<W1#:&%R(#T@<W5B
M<W1R*"1N86UE+"`P+"`Q*3L*("`@("`@("!I9B`H)&9I<G-T0VAA<B`]/2)<
M(B(I('L*("`@("`@("`@("`@9F]R("@D:2`](#$[("1I(#P@)&YU;4]F4&%R
M=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T
M<B@D<&%R='-;)&E=+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+"`Q*3L*("`@
M("`@("`@("`@("`@("1F:7)S=$YA;65)9'@K*SL*("`@("`@("`@("`@("`@
M(&EF("@D;&%S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`O+R!.;W<@<W1A<G0@=V]R:VEN9R!O;B!T:&4@96YT
M<GD@;F%M90H@("`@("`@("1N86UE(#T@)'!A<G1S6R1F:7)S=$YA;65)9'A=
M.PH@("`@("`@("1F:7)S=$-H87(@/2!S=6)S='(H)&YA;64L,"PQ*3L*"B`@
M("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF('1H92!F:7)S="!C:&%R(&]F('1H
M92!N86UE('-T<FEN9R!I<R!A(&1O=6)L92!Q=6]T90H@("`@("`@("\O('-O
M('=E(&MN;W<@:68@=V4@:&%V92!T;R!E>'1R86-T(&UO<F4@;V8@=&AE(&YA
M;64N"B`@("`@("`@:68@*"1F:7)S=$-H87(@/3T@(EPB(BD@>PH@("`@("`@
M("`@("`D;F%M92`](&QT<FEM*"1N86UE+"`B7"(B*3L*("`@("`@("`@("`@
M9F]R("@D:2`]("1F:7)S=$YA;65)9'@@*R`Q.R`D:2`\("1N=6U/9E!A<G1S
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D;F%M92`N/2`@)R`G("X@)'!A
M<G1S6R1I73L*("`@("`@("`@("`@("`@("1L87-T0VAA<B`]('-U8G-T<B@D
M<&%R='-;)&E=+"!S=')L96XH)'!A<G1S6R1I72D@+2`Q+#$I.PH@("`@("`@
M("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`B7"(B*2!["B`@("`@("`@("`@
M("`@("`@("`@)&YA;64@/2!R=')I;2@D;F%M92P@(EPB(BD["B`@("`@("`@
M("`@("`@("`@("`@)&YE>'1+97D@/2`D:2`K(#$["B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@+R\@0VAE8VL@9F]R('M]"B`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]<>RA<9"LI7'TO)RP@)&YA;64L("1M871C:&5S*2D@>PH@
M("`@("`@("`@("`D;F%M92`]("1T:&ES+3Y?:6US<"T^<F5C96EV95-T<FEN
M9TQI=&5R86PH)&UA=&-H97-;,5TI.PH@("`@("`@("`@("`D<F5S<&]N<V4]
M)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("`D<&%R
M=',@/2!E>'!L;V1E*"<@)RP@)')E<W!O;G-E*3L*("`@("`@("`@("`@)&YU
M;4]F4&%R=',@/2!C;W5N="@D<&%R=',I.PH@("`@("`@("`@("`D;F5X=$ME
M>2`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@268@;VYL
M>2!O;F4@8VAU;FL@9F]R("=N86UE)R!T:&5N('=E(&IU<W0@:&%V92!T;R!P
M;VEN=`H@("`@("`@("`@("`O+R!T;R!T:&4@;F5X="!C:'5N:R!I;B!T:&4@
M87)R87DN+BYW:&EC:"!W:6QL(&AO<&5F=6QL>0H@("`@("`@("`@("`O+R!B
M92`G,B<*("`@("`@("`@("`@)&YE>'1+97D@/2`D9FER<W1.86UE261X("L@
M,3L*("`@("`@("!]"@H@("`@("`@("1L87-T0VAA<B`]("<G.PH@("`@("`@
M("1E;G1R>5LG;F%M92==(#T@)&YA;64["@H@("`@("`@("\O(%-T87)T('!A
M<G-I;F<@=&AE(')E<W0@;V8@=&AE(')E<W!O;G-E+@H@("`@("`@(&9O<B`H
M)&D@/2`D;F5X=$ME>3L@)&D@/"`D;G5M3V9087)T<SL@)&D@*ST@,BD@>PH@
M("`@("`@("`@("`D:V5Y(#T@)'!A<G1S6R1I73L*("`@("`@("`@("`@+RH@
M0VAE8VL@9F]R('M]("HO"B`@("`@("`@("`@(&EF("A`<')E9U]M871C:"A)
M35-07T]#5$547T-/54Y4+"`D<&%R='-;)&DK,5TL("1T96UP07)R87DI*2![
M"B`@("`@("`@("`@("`@("`D<V5R=F5R7V1A=&$@/2`D=&AI<RT^7VEM<W`M
M/G)E8V5I=F53=')I;F=,:71E<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@
M("`@("`@("`@)&5N=')Y6R1K97E=(#T@)'-E<G9E<E]D871A.PH*("`@("`@
M("`@("`@("`@("\J(%)E860@86YY(')E;6%I;FEN9R!D871A(&9R;VT@=&AE
M('-T<F5A;2!A;F0@<F5S970*("`@("`@("`@("`@("`@("`J('1H92!C;W5N
M=&5R('9A<FEA8FQE<R!S;R!T:&4@;&]O<"!W:6QL(&-O;G1I;G5E"B`@("`@
M("`@("`@("`@("`@*B!C;W)R96-T;'DN($YO=&4@=V4@<V5T("1I("!T;R`M
M,B!B96-A=7-E(&ET('=I;&P*("`@("`@("`@("`@("`@("`J(&)E(&EN8W)E
M;65N=&5D(&)Y(#(@8F5F;W)E('1H92!L;V]P('=I;&P@<G5N(&%G86EN("HO
M"B`@("`@("`@("`@("`@("`D<&%R=',@/2`D=&AI<RT^7VEM<W`M/F=E=%-E
M<G9E<E)E<W!O;G-E0VAU;FMS*"D["B`@("`@("`@("`@("`@("`D:2`]("TR
M.PH@("`@("`@("`@("`@("`@)&YU;4]F4&%R=',@/2!C;W5N="@D<&%R=',I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@3F]T
M(&$@<W1R:6YG(&QI=&5R86P@<F5S<&]N<V4*("`@("`@("`@("`@("`@($`D
M96YT<GE;)&ME>5T@/2`D<&%R='-;)&D@*R`Q73L*("`@("`@("`@("`@("`@
M("`O+R!#:&5C:R!T;R!S964@:68@=&AE('9A;'5E('-T87)T960@=VET:"!A
M(&1O=6)L90H@("`@("`@("`@("`@("`@("\O('%U;W1E+B`@5V4@86QS;R!N
M965D('1O(&-H96-K(&EF('1H92!L87-T(&-H87(@:7,@80H@("`@("`@("`@
M("`@("`@("\O('%U;W1E('1O(&UA:V4@<W5R92!W92!214%,3%D@:&%V92!T
M;R!C:&5C:R!T:&4@;F5X=`H@("`@("`@("`@("`@("`@("\O(&5L96UE;G1S
M(&9O<B!A(&-L;W-I;F<@<75O=&4N"B`@("`@("`@("`@("`@("!I9B`H*$!S
M=6)S='(H)'!A<G1S6R1I("L@,5TL(#`L(#$I(#T]("<B)RD@)B8*("`@("`@
M("`@("`@("`@("`@("`H<W5B<W1R*"1P87)T<ULD:2`K(#%=+`H@("`@("`@
M("`@("`@("`@("`@("!S=')L96XH)'!A<G1S6R1I("L@,5TI("T@,2P@,2D@
M(3T@)R(G*2D@>PH*("`@("`@("`@("`@("`@("`@("!D;R!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1N97AT16QE;65N="`]("1P87)T<ULD:2LR73L*
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=A<R!T:&ES(&5L96UE;G0@
M=&AE(&QA<W0@;VYE/PH@("`@("`@("`@("`@("`@("`@("`@("`D;&%S=$-H
M87(@/2!S=6)S='(H)&YE>'1%;&5M96YT+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1N97AT16QE;65N="D@
M+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R1K97E=
M("X]("<@)R`N("1N97AT16QE;65N=#L*"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O($Y/5RP@=V4@8V%N(&-H96-K('1H92!L87-T0VAA<BX*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`G(B<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!#:&5C:R!T;R!S964@:68@=&AE(&YE>'0@96QE;65N="!I<R!T:&4*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(&QA<W0@;VYE+B!)9B!S;RP@
M=&AE(&1O(&QO;W`@=VEL;"!T97)M:6YA=&4N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&]N92`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&QA<W1#:&%R(#T@<W5B<W1R*"1P87)T<ULD:2LS72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=')L96XH)'!A<G1S6R1I*S-=*2`M(#$L,2D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?2!W:&EL92`H)&QA<W1#:&%R("$]("<B)RD[
M"@H@("`@("`@("`@("`@("`@("`@("\O($1O('=E(&YE960@=&\@861D('1H
M92!F:6YA;"!E;&5M96YT+"!O<B!W97)E"B`@("`@("`@("`@("`@("`@("`@
M+R\@=&AE<F4@;VYL>2!T=V\@=&]T86P_"B`@("`@("`@("`@("`@("`@("`@
M:68@*"$D9&]N92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;F5X=$5L
M96UE;G0@/2`D<&%R='-;)&DK,ET["B`@("`@("`@("`@("`@("`@("`@("`@
M("1E;G1R>5LD:V5Y72`N/2`G("<@+B`D;F5X=$5L96UE;G0["B`@("`@("`@
M("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("`@("`O+R!296UO=F4@=&AE('%U;W1E<R!S96YT
M(&)A8VL@=&\@=7,@9G)O;2!T:&4@<V5R=F5R+@H@("`@("`@("`@("`@("`@
M("`@(&EF("AS=6)S='(H)&5N=')Y6R1K97E=+"`P+"`Q*2`]/2`G(B<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5N=')Y6R1K97E=(#T@<W5B<W1R
M*"1E;G1R>5LD:V5Y72P@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('-T<FQE;B@D96YT<GE;)&ME>5TI("T@,BD[
M"B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I
M9B`H<W5B<W1R*"1E;G1R>5LD:V5Y72P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<FQE;B@D96YT<GE;)&ME>5TI("T@,2P@,2D@/3T@)R(G
M*2!["@H@("`@("`@("`@("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@/2!S
M=6)S='(H)&5N=')Y6R1K97E=+"`P+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1E;G1R>5LD:V5Y72D@
M+2`R*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1E;G1R
M>3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="])35-0+U5T:6QS+G!H
M<```````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-C$Q
M(#$P-3$U-#,T,30Q(#`R,30P-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@3F5T7TE-4U!?571I;',Z
M.@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?24U34"])35-0+U5T:6QS
M+G!H<"QV(#$N,RXQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\
M;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`
M<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?571I;',@>PH*
M("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!R971R:65V92!T
M:&4@;F%M97,@;V8@86QL('1H92!A9&1R97-S(&)O;VMS"B`@("`@*B!T:&%T
M('1H92!U<V5R(&AA<R!A8V-E<W,@=&\L(&%L;VYG('=I=&@@=&AE(&%C;"!F
M;W(@=&AO<V4*("`@("`J(&)O;VMS+B`@1F]R(&EN9F]R;6%T:6]N(&%B;W5T
M('1H92`D<V5R=F5R26YF;R!A<G)A>2!S964*("`@("`J('1U<F)A+V-O;F9I
M9R]S;W5R8V5S+G!H<"!A<R!T:&ES(&ES('1H92!C9F=3;W5R8V5S6UT@96YT
M<GD@9F]R"B`@("`@*B!T:&4@861D<F5S<R!B;V]K<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'-E<G9E<DEN9F\@($EN9F]R;6%T:6]N(&%B;W5T
M('1H92!S97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M86YD('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@26YF;W)M871I;VX@86)O=70@86QL('1H92!A9&1R97-S(&)O;VMS
M(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%L;$)O
M;VMS*"1S97)V97));F9O*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M3F5T+TE-4U`N<&AP)SL*("`@("`@("`D9F]U;F1$969A=6QT(#T@9F%L<V4[
M"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@("`@("`@("1I;7-P(#T@
M)DYE=%])35-0.CIS:6YG;&5T;VXH)T)O;VLG+"`D<V5R=F5R26YF;ULG<&%R
M86US)UTI.PH@("`@("`@("1R97-U;'0@/2`D:6US<"T^:6YI="@I.PH*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&)O
M;VMS(#T@)&EM<W`M/F=E=$%D9')E<W-";V]K3&ES="@I.PH@("`@("`@(&EF
M("AI<U]A*"1B;V]K<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&)O;VMS.PH@("`@("`@('T*"B`@("`@("`@)&)#;W5N="`](&-O
M=6YT*"1B;V]K<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)#;W5N
M=#L@)&DK*RD@>PH@("`@("`@("`@("`D;F5W0F]O:R`]("1S97)V97));F9O
M.PH@("`@("`@("`@("!I9B`H)&)O;VMS6R1I72`A/2`D<V5R=F5R26YF;ULG
M<&%R86US)UU;)W5S97)N86UE)UTI('L*("`@("`@("`@("`@("`@("1N97="
M;V]K6R=T:71L92==(#T@)TE-4U!?)R`N("1B;V]K<ULD:5T["B`@("`@("`@
M("`@("`@("`D;F5W0F]O:ULG<&%R86US)UU;)VYA;64G72`]("1B;V]K<ULD
M:5T["B`@("`@("`@("`@("`@("`D;F5W0F]O:ULG<&%R86US)UU;)VES7W)O
M;W0G72`](&9A;'-E.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A<F%M
M<R==6R=M>5]R:6=H=',G72`]("1I;7-P+3YM>5)I9VAT<R@D8F]O:W-;)&E=
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F;W5N
M9$1E9F%U;'0@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&YE=T)O;VM;)W!A
M<F%M<R==6R=M>5]R:6=H=',G72`]("1I;7-P+3YM>5)I9VAT<R@D8F]O:W-;
M)&E=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT<UM=(#T@
M)&YE=T)O;VL["B`@("`@("`@?0H@("`@("`@("\J($EF('1H97)E(&ES(&YO
M(&1E9F%U;'0@861D<F5S<R!B;V]K("AN86UE9"!U<V5R;F%M92D@=&AE;B!W
M92!S:&]U;&0@8W)E871E(&]N92X@*B\*("`@("`@("!I9B`H(21F;W5N9$1E
M9F%U;'0I('L*("`@("`@("`@("`@)')E<W5L="`]("1I;7-P+3YC<F5A=&5!
M9&1R97-S0F]O:R@D<V5R=F5R26YF;ULG<&%R86US)UU;)W5S97)N86UE)UTI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M3&]G:6X@=&\@24U34"!H;W-T(&9A:6QE9"XG("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<Z($1E9F%U;'0@861D<F5S<R!B
M;V]K(&ES(&UI<W-I;F<@86YD(&-O=6QD(&YO="!B92!C<F5A=&5D+B<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%5T:6QI='D@9G5N8W1I;VX@=&\@
M;6%K92!I="!E87-I97(@9F]R(&-L:65N="!A<'!L:6-A=&EO;G,@=&\@9&5L
M971E"B`@("`@*B!A9&1R97-S(&)O;VMS('=I=&AO=70@:&%V:6YG('1O(&-R
M96%T92!I;7-P(&1R:79E<G,N("!4:&4@)'-O=7)C92!A<G)A>0H@("`@("H@
M:7,@82!H;W)D92]T=7)B82!S='EL92`D8V9G4V]U<F-E<R!E;G1R>2!F;W(@
M=&AE(&%D9')E<W,@8F]O:R!B96EN9PH@("`@("H@9&5L971E9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'-O=7)C92`@26YF;W)M871I;VX@86)O
M=70@=&AE(&%D9')E<W,@8F]O:R!B96EN9R!D96QE=&5D+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%27T5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T94)O
M;VLH)'-O=7)C92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE="])
M35-0+G!H<"<["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O
M;B@G0F]O:R<L("1S;W5R8V5;)W!A<F%M<R==*3L*("`@("`@("`D<F5S=6QT
M(#T@)&EM<W`M/FEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)&EM<W`M/F1E;&5T94%D9')E
M<W-";V]K*"1S;W5R8V5;)W!A<F%M<R==6R=N86UE)UTI.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@571I;&ET>2!F=6YC=&EO;B!T;R!H
M96QP(&-L:65N=',@8W)E871E(&YE=R!A9&1R97-S(&)O;VMS('=I=&AO=70@
M:&%V:6YG"B`@("`@*B!T;R!C<F5A=&4@86X@:6US<"!D<FEV97(@:6YS=&%N
M8V4@9FER<W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W5R8V4@
M("`@26YF;W)M871I;VX@86)O=70@=&AE('5S97(G<R!D969A=6QT($E-4U`*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%D9')E<W,@8F]O:RX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YE=TYA;64@(%1H92!N86UE(&]F('1H
M92!N97<@861D<F5S<R!B;V]K+B`@3F]T92!T:&%T('1H:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&ES(&%U=&]M871I8V%L;'D@<75A;&EF
M:65D('=I=&@@=&AE('5S97(G<R!N86UE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("!S;R!S:&]U;&0@;F]T(&)E('!A<W-E9"!A<R!A(&9U;&QY
M('%U86QI9FEE9"!)35-0"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!A9&1R97-S(&)O;VL@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!T<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("`@9G5N8W1I;VX@8W)E871E0F]O:R@D<V]U<F-E+"`D
M;F5W3F%M92D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE="])35-0
M+G!H<"<["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@G
M0F]O:R<L("1S;W5R8V5;)W!A<F%M<R==*3L*("`@("`@("`D<F5S=6QT(#T@
M)&EM<W`M/FEN:70H*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@("`@("`D;F%M92`]("1S;W5R8V5;)W!A<F%M<R==6R=U<V5R
M;F%M92==("X@)RXG("X@)&YE=TYA;64["B`@("`@("`@)')E<W5L="`]("1I
M;7-P+3YC<F5A=&5!9&1R97-S0F]O:R@D;F%M92D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O3F5T+TE-4U`O3W!T:6]N<RYP:'``````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34U-C(@,3`U,34T,S0Q
M-#$@,#(Q-S4R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TYE="])35-0+T%U=&@N<&AP
M)SL*"B\J*@H@*B!.971?24U34%]/<'1I;VYS($-L87-S("T@<')O=FED97,@
M86X@:6YT97)F86-E('1O($E-4U`@<V5R=F5R+6)A<V5D"B`J(&]P=&EO;G,@
M<W1O<F%G92X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@
M("=U<V5R;F%M92<@("`@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@<V5R
M=F5R(&%S+@H@*B`@("=P87-S=V]R9"<@("`@(%!A<W-W;W)D(&9O<B!C=7)R
M96YT('5S97(N"B`J("`@)V%U=&A?;65T:&]D)R`@5&AE(&%U=&AE;G1I8V%T
M:6]N(&UE=&AO9"!T;R!U<V4@=&\@;&]G:6XN"B`J("`@)W-E<G9E<B<@("`@
M("`@5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*("H@("`G<&]R
M="<@("`@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O3W!T:6]N
M<RYP:'`L=B`Q+C,N,BXQ-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(X(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4G5B:6YS:WD@
M/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K0&AO<F1E+F]R9SX*("H@
M0'!A8VMA9V4@3F5T7TE-4U`*("HO"F-L87-S($YE=%])35-07T]P=&EO;G,@
M>PH*("`@("\J*@H@("`@("H@3F5T7TE-4U`@;V)J96-T+@H@("`@("H*("`@
M("`J($!V87(@3F5T7TE-4U`*("`@("`J+PH@("`@=F%R("1?:6US<#L*"B`@
M("`O*BH*("`@("`J(%!A<F%M971E<B!L:7-T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!)35-0('!A<F%M
M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%])35-07T]P=&EO;G,H
M)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L:7IA=&EO;B!F=6YC
M=&EO;B!T;R!B92!C86QL960@869T97(@;V)J96-T(&ES(')E='5R;F5D+@H@
M("`@("H@5&AI<R!A;&QO=W,@97)R;W)S('1O(&]C8W5R(&%N9"!N;W0@8G)E
M86L@=&AE('-C<FEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I;FET*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?:6US<"DI('L*("`@("`@("`@("`@)&%U=&@@/2`F3F5T7TE-
M4U!?075T:#HZ<VEN9VQE=&]N*"1T:&ES+3Y?<&%R86US6R=A=71H7VUE=&AO
M9"==*3L*("`@("`@("`@("`@)'1H:7,M/E]I;7-P(#T@)&%U=&@M/F%U=&AE
M;G1I8V%T92@D=&AI<RT^7W!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-?82@D=&AI<RT^7VEM<W`L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<#L*("`@("`@("!]"B`@("`@("`@
M)'1H:7,M/E]I;7-P+3YW<FET951O3&]G*"=.971?24U34%]/<'1I;VYS(&EN
M:71I86QI>F5D+B<L(%]?1DE,15]?+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@
M<V5N9',@82!'150@8V]M;6%N9"!T;R!)35-0('-E<G9E<B!A;F0@<F5T<FEE
M=F5S('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D;W!T
M:6]N3F%M92!.86UE(&]F(&]P=&EO;B!T;R!R971R:65V92X@06-C97!T<R`G
M*B<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%S('=I;&0@
M8V%R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!<W-O8VEA=&EV
M92!A<G)A>2!C;VYT86EN:6YG(&]P=&EO;CT^=F%L=64@<&%I<G,@;W(*("`@
M("`J("`@("`@("`@("`@("`@(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E="@D;W!T:6]N3F%M92D*("`@('L*("`@("`@("`D;W!T:6]N
M<R`](&%R<F%Y*"D["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US<"T^
M:6US<%-E;F0H(D=%5"`D;W!T:6]N3F%M92(L('1R=64L('1R=64I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D<V5R
M=F5R7W)E<W!O;G-E(#T@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH@
M("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N<V4["B`@
M("`@("`@?0H*("`@("`@("!W:&EL92`H<')E9U]M871C:"@B+UY<*B!/4%1)
M3TXO(BP@)'-E<G9E<E]R97-P;VYS92DI('L*("`@("`@("`@("`@+RH@1FER
M<W0L(&-H96-K(&9O<B!A('M]+B`J+PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"A)35-07T]#5$547T-/54Y4+"`D<V5R=F5R7W)E<W!O;G-E+"`D=&5M
M<$%R<F%Y*2D@>PH@("`@("`@("`@("`@("`@)'1E;7`@/2!E>'!L;V1E*"<@
M)RP@)'-E<G9E<E]R97-P;VYS92D["B`@("`@("`@("`@("`@("`D;W!T:6]N
M<ULD=&5M<%LR75T@/2`D=&AI<RT^7VEM<W`M/G)E8V5I=F53=')I;F=,:71E
M<F%L*"1T96UP07)R87E;,ETI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1E;7`@/2!E>'!L;V1E*"<@)RP@)'-E<G9E<E]R97-P
M;VYS92D["B`@("`@("`@("`@("`@("`D;W!T:6]N<ULD=&5M<%LR75T@/2!T
M<FEM*"1T96UP6S-=*3L*("`@("`@("`@("`@("`@("1I(#T@,SL*("`@("`@
M("`@("`@("`@("1L87-T0VAA<B`]("(B.PH@("`@("`@("`@("`@("`@)&YE
M>'1%;&5M96YT(#T@=')I;2@D=&5M<%LS72D["@H@("`@("`@("`@("`@("`@
M+RH@5V%S('1H92!V86QU92!Q=6]T960@86YD('-P86-E9#\@*B\*("`@("`@
M("`@("`@("`@(&EF("@H<W5B<W1R*"1N97AT16QE;65N="PP+#$I(#T]("<B
M)RD@)B8*("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1N97AT16QE;65N
M="QS=')L96XH)&YE>'1%;&5M96YT*2`M(#$L(#$I("$]("<B)RDI('L*("`@
M("`@("`@("`@("`@("`@("!D;R!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1N97AT16QE;65N="`]("1T96UP6R1I*S%=.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;&%S=$-H87(@/2!S=6)S='(H)&YE>'1%;&5M96YT+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N
M*"1N97AT16QE;65N="D@+2`Q+"`Q*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;G-;)'1E;7!;,EU=("X]("<@)R`N("1N97AT16QE;65N=#L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1L87-T0VAA<B`]/2`G(B<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D;VYE(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;&%S=$-H87(@/2!S=6)S='(H)'1E;7!;)&DK,ETL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R;&5N*"1T96UP6R1I*S)=*2`M(#$L(#$I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("`@("!]('=H:6QE("@D;&%S=$-H87(@(3T@
M)R(G*3L*"B`@("`@("`@("`@("`@("`@("`@:68@*"$D9&]N92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;F5X=$5L96UE;G0@/2`D=&5M<%LD:2LQ
M73L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G-;)'1E;7!;,EU=
M("X]("<@)R`N("1N97AT16QE;65N=#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'-E<G9E<E]R97-P;VYS92`]("1T:&ES+3Y?:6US<"T^:6US<%)E8V5I=F4H
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S97)V97)?
M<F5S<&]N<V4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@D<V5R=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@
M=&AE(&5X<&5C=&5D(')E<W!O;G-E(&9R;VT@=&AE('-E<G9E<BXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:6US
M<"T^=W)I=&54;TQO9R@G1T54(&-O;6UA;F0@3TLN)RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N("1O<'1I
M;VYS.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@<V5T<R!A;B!O
M<'1I;VX@=F%L=64@;VX@=&AE($E-4U`@<V5R=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&]P=&EO;DYA;64@($YA;64@;V8@;W!T:6]N('1O
M('-E="X*("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO;E9A;'5E(%9A;'5E
M('1O(&%S<VEG;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%1R=64@
M;W(@4$5!4E]%<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T*"1O<'1I
M;VY.86UE+"`D;W!T:6]N5F%L=64I"B`@("!["B`@("`@("`@+RH@4V5N9"!T
M:&4@8F5G:6YN:6YG(&]F('1H92!C;VUM86YD+B`J+PH@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*")3150@)&]P=&EO;DYA;64@
M(BP@=')U92P@9F%L<V4I.PH*("`@("`@("`O*B!396YD("1O<'1I;VY686QU
M92!A<R!A(&QI=&5R86P@>WT_("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M24U34%]-55-47U5315],251%4D%,+"`D;W!T:6]N5F%L=64I*2!["B`@("`@
M("`@("`@("1B:59A;'5E(#T@<W!R:6YT9B@B>R5D?2(L('-T<FQE;B@D;W!T
M:6]N5F%L=64I*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6US
M<"T^:6US<%-E;F0H)&)I5F%L=64L(&9A;'-E+"!T<G5E*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A<')E9U]M871C:"@B+UY<*R\B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;7-P+3YI;7-P4F5C96EV92@I*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6US<"T^:6US<$5R
M<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU
M871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($YO=R!S96YD('1H92!R97-T(&]F('1H92!C;VUM86YD+B`J+PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEM<W!396YD*"1O<'1I;VY6
M86QU92P@9F%L<V4L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@)'1H:7,M
M/E]I;7-P+3YI;7-P4F5C96EV92@I.PH*("`@("`@("!I9B`H:7-?82@D<V5R
M=F5R7W)E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<V5R=F5R7W)E<W!O;G-E.PH@("`@("`@('T@96QS96EF("@D<V5R
M=F5R7W)E<W!O;G-E("$]("=/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@;W!T:6]N(&-O=6QD(&YO="!B
M92!S970@;VX@=&AE($E-4U`@<V5R=F5R+B<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VEM<W`M/G=R:71E5&],
M;V<H)U-%5"!C;VUM86YD($]++B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@;&]G(&EN9F]R;6%T:6]N(&EN('1H92!.
M971?24U34"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@(%1H92!L;V<@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@4$5!4E]%<G)O<B!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V=G97(H)'!A<F%M<RD*
M("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]I;7-P*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P+3YS971,;V=G97(H)'!A<F%M
M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:6US<"T^:6US<$5R<F]R*"=4:&4@24U34"!L;V<@8V]U;&0@;F]T(&)E
M(&EN:71I86QI>F5D+B<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!L;V=O=70H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6US<"T^;&]G;W5T
M*"D["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O3F5T+TE-4U`O075T:"YP:'``````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3$P-3<@,3`U,34T,S0Q-#$@,#(Q,C$S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@)TYE="])35-0+G!H<"<["@HO*BH*("H@5&AE($YE=%])
M35-07T%U=&@@8VQA<W,@86)S=')A8W0@8VQA<W,@9F]R($E-4U`@875T:&5N
M=&EC871I;VXN"B`J"B`J(%)E<75I<F5D(%!A<F%M971E<G,Z/'!R93X*("H@
M("`G=7-E<FYA;64G("!5<V5R;F%M92!T;R!L;V=O;B!T;R!)35-0('-E<G9E
M<B!A<RX*("H@("`G<&%S<W=O<F0G("!087-S=V]R9"!F;W(@8W5R<F5N="!U
M<V5R+@H@*B`@("=S97)V97(G("`@(%1H92!H;W-T;F%M92!O9B!T:&4@24U3
M4"!S97)V97(N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;V8@=&AE($E-
M4U`@<V5R=F5R+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].971?
M24U34"])35-0+T%U=&@N<&AP+'8@,2XX+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC
M:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`
M:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T
M7TE-4U!?075T:"!["B`@("`O*BH*("`@("`J($-L87-S('9A<FEA8FQE('1O
M(&AO;&0@=&AE(')E<W5L=&EN9R!.971?24U34"!O8FIE8W0*("`@("`J"B`@
M("`@*B!`=F%R($YE=%])35-0"B`@("`@*B\*("`@('9A<B`D7VEM<W`["@H@
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@;&]G:6X@=&\@24U34"!S97)V
M97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@
M("!087)A;65T97)S(&9O<B!.971?24U34`H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&QO9VEN("`@("`@("!3:&]U;&0@=V4@<F5M86EN(&QO9V=E9"!I;B!A
M9G1E<B!A=71H/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@("`@
M("`@("`@("`@4F5T=7)N<R!A($YE=%])35-0(&]B:F5C="!C;VYN96-T960@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE($E-
M4U`@<V5R=F5R(&EF(&QO9VEN(&ES('1R=64@86YD"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('-U8V-E<W-F=6PN("!2971U<FYS(&)O
M;VQE86X@=')U92!I9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=6-C97-S9G5L(&%N9"!L;V=I;B!I<R!F86QS92X@4F5T=7)N<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27T5R<F]R
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9A=71H96YT:6-A
M=&4H)'!A<F%M<RP@)&QO9VEN(#T@=')U92D*("`@('L*("`@("`@("`D=&AI
M<RT^7VEM<W`@/2`F)'1H:7,M/E]A=71H96YT:6-A=&4H)'!A<F%M<RD["@H@
M("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6US<"P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D;&]G:6XI('L*("`@("`@("`@("`@)'1H:7,M/E]I
M;7-P+3YL;V=O=70H*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]I;7-P.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO;BX@
M4')O=FED97,@86-T=6%L(&%U=&AE;G1I8V%T:6]N"B`@("`@*B!C;V1E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!A
M<G)A>2`@("1P87)A;7,@("`@("!087)A;65T97)S(&9O<B!.971?24U34%]!
M=71H(&1R:79E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@
M("`@("`@("`@(%)E='5R;G,@3F5T7TE-4U`@;V)J96-T(&-O;FYE8W1E9"!T
M;R!S97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@<W5C8V5S<V9U;"P@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("H@
M0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N=&EC871E
M*"1P87)A;7,I"B`@("!["@H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@='EP92!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J($!R971U<FX@<W1R:6YG(%1Y<&4@;V8@24U34%]!=71H
M(&1R:79E<B!I;G-T86YC90H@("`@("HO"B`@("!F=6YC=&EO;B!G971$<FEV
M97)4>7!E*"D*("`@('L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)C92!A
M(&QO9V]U="!F<F]M('1H92!U;F1E<FQY:6YG($E-4U`@<W1R96%M+@H@("`@
M("H*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T*"D*("`@('L*"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T
M92!.971?24U34%]!=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(*("`@
M("`J($UU<W0@8F4@8V%L;&5D(&%S("9.971?24U34%]!=71H.CIF86-T;W)Y
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D9')I=F5R(%1Y<&4@
M;V8@3F5T7TE-4U!?075T:"!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&-R96%T960@3F5T7TE-4U!?075T
M:"!S=6)C;&%S<R!O<B!014%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9F%C=&]R>2@D9')I=F5R*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B
M87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I
M('Q\("AS=')C;7`H)&1R:79E<BP@)VYO;F4G*2`]/2`P*2D@>PH@("`@("`@
M("`@("`D875T:"`]("9N97<@24U34%]!=71H*"D["B`@("`@("`@("`@(')E
M='5R;B`D875T:#L*("`@("`@("!]"@H@("`@("`@(&EF("AF:6QE7V5X:7-T
M<RAD:7)N86UE*%]?1DE,15]?*2`N("<O075T:"\G("X@)&1R:79E<B`N("<N
M<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]!=71H+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M('T*"B`@("`@("`@)&-L87-S(#T@)TYE=%])35-07T%U=&A?)R`N("1D<FEV
M97(["@H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@
M("`@("`@("`D875T:"`]("9N97<@)&-L87-S*"D["B`@("`@("`@("`@(')E
M='5R;B`D875T:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D
M93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!L;V%D('1H92!D969I;FET:6]N(&]F("5S+B(I+"`D8VQA<W,I*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!.971?24U34%]!
M=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*B!7:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&]B:F5C="!I9B!O;F4@=VET:"!T:&4@<V%M92!P
M87)A;65T97)S(&%L<F5A9'D*("`@("`J(&1O97,@;F]T(&5X:7-T+@H@("`@
M("H@375S="!B92!C86QL960@;&EK93H@)'9A<B`]("9.971?24U34%]!=71H
M.CIS:6YG;&5T;VXH)V1R:79E<E]T>7!E)RD["B`@("`@*@H@("`@("H@0'!A
M<F%M("!S=')I;F<@)&1R:79E<B!4>7!E(&]F($E-4U!?075T:"!S=6)C;&%S
M<R!T;R!R971U<FXN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@4F5F
M97)E;F-E('1O($E-4U!?075T:"!S=6)C;&%S<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)G-I;F=L971O;B@D9')I=F5R*0H@("`@>PH@("`@("`@('-T871I
M8R`D:6YS=&%N8V5S.PH@("`@("`@("\J($-H96-K(&9O<B!A;GD@:6UT97-T
M(&1R:79E<B!I;G-T86YC97,@86YD(&MI;&P@=&AE;2X*("`@("`@("`@("!/
M=&AE<G=I<V4L('1H92!S;V-K970@=VEL;"!H86YG(&)E='=E96X@<F5Q=65S
M=',@9G)O;0H@("`@("`@("`@('-E<&5R871E(&1R:79E<G,@*&%N($%U=&@@
M<F5Q=65S="!A;F0@86X@3W!T:6]N<R!R97%U97-T*2XJ+PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D:6YS=&%N8V5S*2D@>PH@("`@("`@("`@("!F;W)E86-H
M("@D:6YS=&%N8V5S(&%S("1O8FHI('L*("`@("`@("`@("`@("`@(&EF("@D
M;V)J+3YG971$<FEV97)4>7!E*"D@/3T@)VEM=&5S="<I('L*("`@("`@("`@
M("`@("`@("`@("`D;V)J+3YL;V=O=70H*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA
M<G)A>2@D9')I=F5R*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S
M6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N
M871U<F5=(#T@)DYE=%])35-07T%U=&@Z.F9A8W1O<GDH)&1R:79E<BD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M73L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TYE="])35-0+T%U=&@O:6UT97-T+G!H<```````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-C(U(#$P-3$U-#,T,30Q(#`R,C4S
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@5&AE($YE=%])35-07T%U=&A?:6UT97-T(&-L87-S(&9O
M<B!)35-0(&%U=&AE;G1I8V%T:6]N+@H@*@H@*B!297%U:7)E9"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)W5S97)N86UE)R`@("`@("`@57-E<FYA;64@=&\@
M;&]G;VX@=&\@24U34"!S97)V97(@87,N"B`J("`@)W!A<W-W;W)D)R`@("`@
M("`@4&%S<W=O<F0@9F]R(&-U<G)E;G0@=7-E<BX*("H@("`G<V5R=F5R)R`@
M("`@("`@("!4:&4@:&]S=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@
M("=P;W)T)R`@("`@("`@("`@(%1H92!P;W)T(&]F('1H92!)35-0('-E<G9E
M<BX*("H@("`G<V]C:V5T)R`@("`@("`@("!4:&4@;F%M960@<V]C:V5T('1O
M('5S92!F;W(@8V]N;F5C=&EO;@H@*B`@("=C;VUM86YD)R`@("`@("`@(%!A
M=&@@=&\@=&AE(&EM=&5S="!C;VUM86YD(&]N(&QO8V%L:&]S=`H@*B`@("=A
M=71H7VUE8VAA;FES;2<@($%U=&AE;G1I8V%T:6]N(&UE=&AO9"!T;R!U<V4@
M=VET:"!I;71E<W0\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T
M7TE-4U`O24U34"]!=71H+VEM=&5S="YP:'`L=B`Q+C$R+C(N-"`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V("`@("`@3&EA;2!(;V5K96YG82`\;&EA;7)`=6UI8V@N961U/@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4G5B:6YS:WD@/&UR=6)I;G-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($QI86T@
M2&]E:V5N9V$@/&QI86UR0'5M:6-H+F5D=3X*("H@0&%U=&AO<B`@36EC:&%E
M;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.
M971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?075T:%]I;71E<W0@97AT96YD
M<R!.971?24U34%]!=71H('L*"B`@("`O*BH*("`@("`J(%!R:79A=&4@875T
M:&5N=&EC871I;VX@9G5N8W1I;VXN("!0<F]V:61E<R!A8W1U86P*("`@("`J
M(&%U=&AE;G1I8V%T:6]N(&-O9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<&%R86T@(&UI>&5D("`D<&%R86US($AA<V@@;V8@
M24U34"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M($YE=%])35-0(&]B:F5C="!C;VYN96-T960@=&\@<V5R=F5R(&EF('-U8V-E
M<W-F=6PL"B`@("`@*B`@("`@("`@("`@("`@("!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?875T:&5N=&EC871E*"1P
M87)A;7,I"B`@("!["B`@("`@("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L
M971O;B@G;F]N92<L("1P87)A;7,I.PH@("`@("`@("1C;VUM86YD(#T@)R<[
M"B`@("`@("`@)&5R<F]R7W)E='5R;B`]("<G.PH*("`@("`@("!I9B`H<W1R
M=&]L;W=E<B@D<&%R86US6R=A=71H7VUE8VAA;FES;2==*2`]/2`G9W-S87!I
M)R`F)@H@("`@("`@("`@("!I<W-E="@D7U-%4E9%4ELG2U)"-4-#3D%-12==
M*2D@>PH@("`@("`@("`@("`@("`@)&-O;6UA;F0@+CT@)TM20C5#0TY!344]
M)R`N("1?4T525D526R=+4D(U0T-.04U%)UT["B`@("`@("`@?0H*("`@("`@
M("`D8V]M;6%N9"`N/2`G("<@("`@+B`D<&%R86US6R=C;VUM86YD)UTN"B`@
M("`@("`@("`@("`@("`@("`@)R`M;2`G("X@)'!A<F%M<ULG875T:%]M96-H
M86YI<VTG72`N"B`@("`@("`@("`@("`@("`@("`@)R`M=2`G("X@97-C87!E
M<VAE;&QA<F<H)'!A<F%M<ULG=7-E<FYA;64G72D@+@H@("`@("`@("`@("`@
M("`@("`@("<@+6$@)R`N(&5S8V%P97-H96QL87)G*"1P87)A;7-;)W5S97)N
M86UE)UTI("X*("`@("`@("`@("`@("`@("`@("`G("UW("<@+B!E<V-A<&5S
M:&5L;&%R9R@D<&%R86US6R=P87-S=V]R9"==*2X*("`@("`@("`@("`@("`@
M("`@("`G("UP("<@+B`D<&%R86US6R=P;W)T)UT@+@H@("`@("`@("`@("`@
M("`@("`@("<@+5@@)R`N("1P87)A;7-;)W-O8VME="==("X*("`@("`@("`@
M("`@("`@("`@("`G("<@("`@+B`D<&%R86US6R=S97)V97(G73L*"B`@("`@
M("`@)&-O;FY?871T96UP=',@/2`P.PH@("`@("`@('=H:6QE("@D8V]N;E]A
M='1E;7!T<RLK(#P@-"D@>PH@("`@("`@("`@("`D871T96UP=',@/2`P.PH@
M("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1P87)A;7-;)W-O8VME="==
M*2D@>PH@("`@("`@("`@("`@("`@97AE8R@D8V]M;6%N9"`N("<@/B`O9&5V
M+VYU;&P@,CXF,2<I.PH@("`@("`@("`@("`@("`@<VQE97`H,2D["B`@("`@
M("`@("`@("`@("!W:&EL92`H(69I;&5?97AI<W1S*"1P87)A;7-;)W-O8VME
M="==*2D@>PH@("`@("`@("`@("`@("`@("`@('5S;&5E<"@R,#`P,#`I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D871T96UP=',K*R`^(#4I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<F]R7W)E='5R;B`]("<Z($YO('-O
M8VME="!A9G1E<B`Q,"!S96-O;F1S(&]F('1R>6EN9R$G.PH@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D9G`@/2!`9G-O8VMO<&5N*"1P87)A;7-;)W-O8VME="==+"`P+"`D97)R
M;W)?;G5M8F5R+"`D97)R;W)?<W1R:6YG+"`S,"D["B`@("`@("`@("`@("1E
M<G)O<E]R971U<FX@/2`D97)R;W)?<W1R:6YG.PH@("`@("`@("`@("!I9B`H
M)&9P*2!B<F5A:SL*("`@("`@("`@("`@=6YL:6YK*"1P87)A;7-;)W-O8VME
M="==*3L*"B`@("`@("`@?0H@("`@("`@("\O1F%I;'5R93\*("`@("`@("!I
M9B`H(65M<'1Y*"1E<G)O<E]R971U<FXI*2!["B`@("`@("`@("`@(')E='5R
M;B`D:6US<"T^:6US<$5R<F]R*"=#;VYN96-T:6]N('1O($E-4U`@:&]S="!F
M86EL960N)R`N("<Z("<@+B`D97)R;W)?<F5T=7)N+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*("`@("`@("`O+U-U8V-E<W,*("`@("`@("`D
M:6US<"T^7W-T<F5A;2`]("1F<#L*("`@("`@("!R971U<FX@)&EM<W`["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&;W)C92!A(&QO9V]U="!C;VUM86YD('1O
M('1H92!I;7-P('-T<F5A;2X*("`@("`J"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QO9V]U="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I;7-P+3YL;V=O=70H
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1R:79E<B!T
M>7!E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@='EP92!O
M9B!T:&ES($E-4U!?075T:"!D<FEV97(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$1R:79E<E1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G:6UT97-T
M)SL*("`@('T*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B].970O24U34"]!=71H+V-R86U?;60U+G!H<```````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S(P,B`Q,#4Q-30S-#$T,2`P,C(V
M-S<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!.971?24U34%]!=71H7V-R86U?;60U(&-L87-S
M(&9O<B!)35-0(&%U=&AE;G1I8V%T:6]N+@H@*@H@*B!297%U:7)E9"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)W5S97)N86UE)R`@57-E<FYA;64@=&\@;&]G
M;VX@=&\@24U34"!S97)V97(@87,N"B`J("`@)W!A<W-W;W)D)R`@4&%S<W=O
M<F0@9F]R(&-U<G)E;G0@=7-E<BX*("H@("`G<V5R=F5R)R`@("!4:&4@:&]S
M=&YA;64@;V8@=&AE($E-4U`@<V5R=F5R+@H@*B`@("=P;W)T)R`@("`@(%1H
M92!P;W)T(&]F('1H92!)35-0('-E<G9E<BX\+W!R93X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO3F5T7TE-4U`O24U34"]!=71H+V-R86U?;60U+G!H<"QV
M(#$N-BXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,C@@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN
M<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G
M92!.971?24U34`H@*B\*8VQA<W,@3F5T7TE-4U!?075T:%]C<F%M7VUD-2!E
M>'1E;F1S($YE=%])35-07T%U=&@@>PH*("`@("\J*@H@("`@("H@4')I=F%T
M92!A=71H96YT:6-A=&EO;B!F=6YC=&EO;BX@(%!R;W9I9&5S(&%C='5A;`H@
M("`@("H@875T:&5N=&EC871I;VX@8V]D92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;6EX960@)'!A<F%M<R!(87-H
M(&]F($E-4U`@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D($YE=%])35-0(&]B:F5C="!C;VYN96-T960@=&\@<V5R=F5R(&EF('-U
M8V-E<W-F=6PL"B`@("`@*B`@("`@("`@("`@("`@(%!%05)?17)R;W(@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A=71H96YT:6-A=&4H
M)'!A<F%M<RD*("`@('L*("`@("`@("`D:6US<"`]("9.971?24U34#HZ<VEN
M9VQE=&]N*"=N;VYE)RP@)'!A<F%M<RD["B`@("`@("`@)')E<W5L="`]("1I
M;7-P+3YI;FET*"D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("1U<V5R260@/2`D<&%R86US6R=U<V5R;F%M92==.PH@
M("`@("`@("1C<F5D96YT:6%L<R`]("1P87)A;7-;)W!A<W-W;W)D)UT["B`@
M("`@("`@)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@G05542$5.5$E#051%
M($-204TM340U)RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\J($=E="!R97-P;VYS92!A;F0@9&5C;V1E(&ET+B!.
M;W1E('1H870@=V4@<F5M;W9E('1H92`Q<W0@,@H@("`@("`@("`J(&-H87)A
M8W1E<G,@9G)O;2!T:&4@<F5S<&]N<V4@=&\@9V5T(')I9"!O9B!T:&4@)RLG
M"B`@("`@("`@("H@8V]N=&EN=6%T:6]N(&-H87)A8W1E<B!A;F0@=&AE('-P
M86-E('1H870@:7,@<V5N="!A<R!P87)T"B`@("`@("`@("H@;V8@=&AE($-2
M04TM340U(')E<W!O;G-E("AA="!L96%S="!O;B!C>7)U<RUI;7-P9"DN("HO
M"B`@("`@("`@)'-E<G9E<E]R97-P;VYS92`]("1I;7-P+3YI;7-P4F5C96EV
M92@I.PH@("`@("`@(&EF("AI<U]A*"1S97)V97)?<F5S<&]N<V4L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S97)V97)?<F5S<&]N
M<V4["B`@("`@("`@?0H*("`@("`@("`D<V5R=F5R7W)E<W!O;G-E(#T@8F%S
M938T7V1E8V]D92AT<FEM*'-U8G-T<B@D<V5R=F5R7W)E<W!O;G-E+"`R*2DI
M.PH*("`@("`@("`O*B!"=6EL9"!A;F0@8F%S938T(&5N8V]D92!T:&4@<F5S
M<&]N<V4@=&\@=&AE(&-H86QL86YG92X@*B\*("`@("`@("`D<F5S<&]N<V5?
M=&]?<V5N9"`]("1U<V5R260@+B`G("<@+B`D=&AI<RT^7VAM86,H)&-R961E
M;G1I86QS+"`D<V5R=F5R7W)E<W!O;G-E*3L*("`@("`@("`D8V]M;6%N9%]S
M=')I;F<@/2!B87-E-C1?96YC;V1E*"1R97-P;VYS95]T;U]S96YD*3L*"B`@
M("`@("`@+RH@4V5N9"!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@)')E<W5L
M="`]("1I;7-P+3YI;7-P4V5N9"@D8V]M;6%N9%]S=')I;F<L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]("1I;7-P+3YI;7-P4F5C96EV92@I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E<W5L="`A
M/2`G3TLG*2!["B`@("`@("`@("`@(')E='5R;B`D:6US<"T^:6US<$5R<F]R
M*"=,;V=I;B!T;R!)35-0(&AO<W0@9F%I;&5D+B<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1I
M;7-P.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)&0R`R,3`T
M($A-04,@:6UP;&5M96YT871I;VXN($5L:6UI;F%T97,@=&AE(')E;&EA;F-E
M(&]N(&UH87-H+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H@0'!A<F%M("!S=')I;F<@("1K97D@("`@5&AE($A-04,@:V5Y+@H@("`@
M("H@0'!A<F%M("!S=')I;F<@("1D871A("`@5&AE(&1A=&$@=&\@:&%S:"!W
M:71H('1H92!K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!-1#4@2$U!0RX*("`@("`J+PH@("`@9G5N8W1I;VX@7VAM86,H)&ME>2P@
M)&1A=&$I"B`@("!["B`@("`@("`@+RH@0GET92!L96YG=&@@9F]R(&UD-2X@
M*B\*("`@("`@("`D8B`](#8T.PH*("`@("`@("!I9B`H<W1R;&5N*"1K97DI
M(#X@)&(I('L*("`@("`@("`@("`@)&ME>2`]('!A8VLH)T@J)RP@;60U*"1K
M97DI*3L*("`@("`@("!]"@H@("`@("`@("1K97D@/2!S=')?<&%D*"1K97DL
M("1B+"!C:'(H,'@P,"DI.PH@("`@("`@("1I<&%D(#T@<W1R7W!A9"@G)RP@
M)&(L(&-H<B@P>#,V*2D["B`@("`@("`@)&]P860@/2!S=')?<&%D*"<G+"`D
M8BP@8VAR*#!X-6,I*3L*("`@("`@("`D:U]I<&%D(#T@)&ME>2!>("1I<&%D
M.PH@("`@("`@("1K7V]P860@/2`D:V5Y(%X@)&]P860["B`@("`@("`@<F5T
M=7)N(&UD-2@D:U]O<&%D("X@<&%C:R@G2"HG+"!M9#4H)&M?:7!A9"`N("1D
M871A*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1F]R8V4@82!L;V=O=70@
M8V]M;6%N9"!T;R!T:&4@:6US<"!S=')E86TN"B`@("`@*@H@("`@("HO"B`@
M("!F=6YC=&EO;B!L;V=O=70H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6US
M<"T^;&]G;W5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&1R:79E<B!T>7!E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@=&AE
M('1Y<&4@;V8@=&AI<R!)35-07T%U=&@@9')I=F5R"B`@("`@*B\*("`@("!F
M=6YC=&EO;B!G971$<FEV97)4>7!E*"D*("`@("!["B`@("`@("`@(')E='5R
M;B`G8W)A;5]M9#4G.PH@("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B].970O24U34"]!=71H+W!L
M86EN=&5X="YP:'``````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S0R
M,2`Q,#4Q-30S-#$T,2`P,C,R,C,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J(%1H92!.971?24U34%]!
M=71H7W!L86EN=&5X="!C;&%S<R!F;W(@24U34"!A=71H96YT:6-A=&EO;BX*
M("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=U<V5R;F%M
M92<@(%5S97)N86UE('1O(&QO9V]N('1O($E-4U`@<V5R=F5R(&%S+@H@*B`@
M("=P87-S=V]R9"<@(%!A<W-W;W)D(&9O<B!C=7)R96YT('5S97(N"B`J("`@
M)W-E<G9E<B<@("`@5&AE(&AO<W1N86UE(&]F('1H92!)35-0('-E<G9E<BX*
M("H@("`G<&]R="<@("`@("!4:&4@<&]R="!O9B!T:&4@24U34"!S97)V97(N
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%])35-0+TE-4U`O
M075T:"]P;&%I;G1E>'0N<&AP+'8@,2XW+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC
M:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`
M:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!.971?24U34`H@*B\*8VQA<W,@3F5T
M7TE-4U!?075T:%]P;&%I;G1E>'0@97AT96YD<R!.971?24U34%]!=71H('L*
M"B`@("`O*BH*("`@("`J(%!R:79A=&4@875T:&5N=&EC871I;VX@9G5N8W1I
M;VXN("!0<F]V:61E<R!A8W1U86P*("`@("`J(&%U=&AE;G1I8V%T:6]N(&-O
M9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@(&UI>&5D("`D<&%R86US($AA<V@@;V8@24U34"!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($YE=%])35-0(&]B:F5C="!C
M;VYN96-T960@=&\@<V5R=F5R(&EF('-U8V-E<W-F=6PL"B`@("`@*B`@("`@
M("`@("`@("`@("!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?875T:&5N=&EC871E*"1P87)A;7,I"B`@("!["B`@("`@
M("`@)&EM<W`@/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@G;F]N92<L("1P87)A
M;7,I.PH@("`@("`@("1R97-U;'0@/2`D:6US<"T^:6YI="@I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`@)'5S97))
M9"`]("1P87)A;7-;)W5S97)N86UE)UT["B`@("`@("`@("1C<F5D96YT:6%L
M<R`]("1P87)A;7-;)W!A<W-W;W)D)UT["@H@("`@("`@("\J(%-T87)T('1H
M92!C;VUM86YD+B`J+PH@("`@("`@("1R97-U;'0@/2`D:6US<"T^:6US<%-E
M;F0H)TQ/1TE.("<L('1R=64L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@57-E<FYA;64@87,@82![
M?3\@*B\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)
M5$5204PL("1U<V5R260I*2!["B`@("`@("`@("`@("1B:55S97(@/2!S<')I
M;G1F*"=[)61])RP@<W1R;&5N*"1U<V5R260I*3L*("`@("`@("`@("`@)')E
M<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8FE5<V5R+"!F86QS92P@=')U92D[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H(B]>7"LO(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I;7-P+3YI;7-P4F5C96EV92@I
M*2D@>PH*("`@("`@("`@("`@("`@(')E='5R;B`D:6US<"T^:6US<$5R<F]R
M*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C;VYT:6YU871I
M;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M("1I;7-P+3YI;7-P4V5N9"@D=7-E<DED("X@)R`G+"!F86QS92P@9F%L<V4I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@
M("`O*B!$;VXG="!W86YT('1O(&QO9R!T:&4@<&%S<W=O<F0A("HO"B`@("`@
M("`@)&QO9U9A;'5E(#T@)&EM<W`M/FQO9T5N86)L960["B`@("`@("`@)&EM
M<W`M/FQO9T5N86)L960@/2!F86QS93L*"B`@("`@("`@+RH@4&%S<R!A<R![
M?3\@*B\*("`@("`@("!I9B`H<')E9U]M871C:"A)35-07TU54U1?55-%7TQ)
M5$5204PL("1C<F5D96YT:6%L<RDI('L*("`@("`@("`@("`@)&)I4&%S<R`]
M('-P<FEN=&8H)WLE9'TG+"!S=')L96XH)&-R961E;G1I86QS*2D["B`@("`@
M("`@("`@("1R97-U;'0@/2`D:6US<"T^:6US<%-E;F0H)&)I4&%S<RP@9F%L
M<V4L('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O
M7EPK+R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6US<"T^:6US
M<%)E8V5I=F4H*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:6US<"T^
M:6US<$5R<F]R*"=$:60@;F]T(')E8V5I=F4@97AP96-T960@8V]M;6%N9"!C
M;VYT:6YU871I;VX@<F5S<&]N<V4@9G)O;2!)35-0('-E<G9E<BXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]("1I;7-P+3YI;7-P4V5N9"@D8W)E9&5N=&EA;',L(&9A;'-E
M+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5S=&]R92!T:&4@;&]G9VEN9R!B;V]L96%N+B`J+PH@
M("`@("`@("1I;7-P+3YL;V=%;F%B;&5D(#T@)&QO9U9A;'5E.PH*("`@("`@
M("`D<V5R=F5R7W)E<W!O;G-E(#T@)&EM<W`M/FEM<W!296-E:79E*"D["B`@
M("`@("`@:68@*&ES7V$H)'-E<G9E<E]R97-P;VYS92P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<G9E<E]R97-P;VYS93L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D<V5R=F5R7W)E<W!O;G-E("$]("=/2R<I
M('L*("`@("`@("`@("`@<F5T=7)N("1I;7-P+3YI;7-P17)R;W(H)TQO9VEN
M('1O($E-4U`@:&]S="!F86EL960N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6US<#L*("`@('T*"B`@("`O
M*BH*("`@("`J($9O<F-E(&$@;&]G;W5T(&-O;6UA;F0@=&\@=&AE(&EM<W`@
M<W1R96%M+@H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G;W5T*"D*
M("`@('L*("`@("`@("`D=&AI<RT^7VEM<W`M/FQO9V]U="@I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!D<FEV97(@='EP90H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG('1H92!T>7!E(&]F('1H:7,@24U34%]!
M=71H(&1R:79E<@H@("`@("HO"B`@("`@9G5N8W1I;VX@9V5T1')I=F5R5'EP
M92@I"B`@("`@>PH@("`@("`@("!R971U<FX@)W!L86EN=&5X="<["B`@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B].970O4TU3+W-M<S)E;6%I;%]H='1P+G!H<```````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`V,C4S,2`Q,#4Q-30S-#$T,2`P,C,Q-#(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J($YE=%]335-?<VUS,F5M86EL7VAT='`@0VQA<W,@:6UP;&5M96YT<R!T
M:&4@2%144"!!4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@<VUS,F5M86EL("AW
M=W<N<VUS,F5M86EL+F-O;2D@4TU3(&=A=&5W87DN"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3
M+W-M<S)E;6%I;%]H='1P+G!H<"QV(#$N,C,N,3`N,3`@,C`P-B\P,2\P,2`R
M,3HR.#HR.2!J86X@17AP("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@
M/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!.971?4TU3"B`J+PIC;&%S
M<R!.971?4TU37W-M<S)E;6%I;%]H='1P(&5X=&5N9',@3F5T7U--4R!["@H@
M("`@=F%R("1?8F%S95]U<FP@/2`G:&]R9&4N<VUS,F5M86EL+F-O;2]H;W)D
M92\G.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S
M+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@
M;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X@
M4&]S<VEB;&4@=F%L=65S(&%R93H\<')E/@H@("`@("H@("!A=71H("`@("`@
M("`M(%1H92!G871E=V%Y(')E<75I<F5S(&%U=&AE;G1I8V%T:6]N(&)E9F]R
M92!S96YD:6YG.PH@("`@("H@("!B871C:"`@("`@("`M($)A=&-H('-E;F1I
M;F<@:7,@<W5P<&]R=&5D.PH@("`@("H@("!M=6QT:2`@("`@("`M(%-E;F1I
M;F<@;V8@;65S<V%G97,@=&\@;75L=&EP;&4@<F5C:7!I96YT<R!I<R!S=7!P
M;W)T960["B`@("`@*B`@(')E8V5I=F4@("`@("T@5VAE=&AE<B!T:&ES(&1R
M:79E<B!I<R!C87!A8FQE(&]F(')E8V5I=FEN9R!335,["B`@("`@*B`@(&-R
M961I="`@("`@("T@27,@=7-E(&]F('1H92!G871E=V%Y(&)A<V5D(&]N(&-R
M961I=',["B`@("`@*B`@(&%D9')E<W-B;V]K("T@07)E(&=A=&5W87D@861D
M<F5S<V)O;VMS('-U<'!O<G1E9#L*("`@("`J("`@;&ES=',@("`@("`@+2!'
M871E=V%Y('-U<'!O<G0@9F]R(&1I<W1R:6)U=&EO;B!L:7-T<RX*("`@("`J
M(#PO<')E/@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G875T:"<@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8F%T8V@G("`@
M("`@(#T^(#$P,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUU
M;'1I)R`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<F5C96EV92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8W)E9&ET)R`@("`@(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=A9&1R97-S8F]O:R<@/3X@=')U92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W1S)R`@("`@("`]
M/B!T<G5E*3L*"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R!T
M:&4@86-T=6%L('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1M97-S86=E("!4:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!A
M;F0@:71S('-E;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&%R
M86UE=&5R<RX*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@5&AE(&1E
M<W1I;F%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<G)A>2!W:71H('1H92!S=6-C97-S('-T871U<R!A;F0@861D:71I
M;VYA;`H@("`@("H@("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S96YD*"8D;65S<V%G92P@)'1O*0H@("`@>PH@
M("`@("`@("\J(%-E="!U<"!T:&4@<V5N9&EN9R!U<FPN("HO"B`@("`@("`@
M)'5R;"`]('-P<FEN=&8H)W!O<W1M<V<N<&AP/W5S97)N86UE/25S)G!A<W-W
M;W)D/25S)FUE<W-A9V4])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R
M;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@
M("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D;65S<V%G
M95LG=&5X="==*2D["@H@("`@("`@("\J($-H96-K(&EF('-O=7)C92!F<F]M
M(&ES('-E="X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E6R=S96YD
M7W!A<F%M<R==6R=F<F]M)UTI*2!["B`@("`@("`@("`@("1U<FP@+CT@)R9O
M<FEG/2<@+B!U<FQE;F-O9&4H)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)V9R
M;VTG72D["B`@("`@("`@?0H@("`@("`@("\J($-H96-K(&EF(&UE<W-A9V4@
M='EP92!I<R!F;&%S:"X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E
M6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==*2`F)@H@("`@("`@("`@("`D
M;65S<V%G95LG<V5N9%]P87)A;7,G75LG;7-G7W1Y<&4G72`]/2`G4TU37T9,
M05-()RD@>PH@("`@("`@("`@("`D=7)L("X]("<F9FQA<V@],2<["B`@("`@
M("`@?0H@("`@("`@("\J($-H96-K(&EF(&1E;&EV97)Y(')E<&]R="!U<FP@
M:&%S(&)E96X@<V5T+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)V1E;&EV97)Y7W)E<&]R="==*2D@>PH@("`@("`@("`@("`D=7)L
M("X]("<F9&QU<FP])R`N('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG9&5L
M:79E<GE?<F5P;W)T)UTI("X*("`@("`@("`@("`@("`@("`@("`G<F5P;W)T
M8V]D93TE8V]D929D97-T:6YA=&EO;FYU;6)E<CTE9&5S="<["B`@("`@("`@
M?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@<F5C:7!I96YT<R!A;F0@9&\@
M<V]M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K:6YG+B`J+PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D=&\I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T;R!A
M<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O7BXJ/SP_7"L_*%QD>S<L?2DH/GPD*2\G+"`D=F%L+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@("`@("`@("`D=&];)&ME>5T@/2`D;6%T8VAE
M<ULQ73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@+RH@1DE8344Z(%-I;&5N=&QY(&1R;W`@8F%D(')E8VEP:65N=',N
M(%1H:7,@<VAO=6QD(&)E"B`@("`@("`@("`@("`@("`@("`@("H@;&]G9V5D
M(&%N9"]O<B!R97!O<G1E9"X@*B\*("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D=&];)&ME>5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T;R`](&EM<&QO9&4H)RPG+"`D=&\I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_
M7"L_*%QD>S<L?2DH/GPD*2\G+"`D=&\L("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`@("`@)'1O(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH,"P@<W!R:6YT9BA?
M*"));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(BDL("1T;RDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!!<'!E;F0@=&AE(')E8VEP
M:65N=',@;V8@=&AI<R!M97-S86=E(&%N9"!C86QL('1H92!U<FPN("HO"B`@
M("`@("`@)'5R;"`N/2`G)G1O7VYU;3TG("X@)'1O.PH@("`@("`@("1R97-P
M;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*#`L("1R97-P;VYS92T^9V5T365S<V%G92@I*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%!A<G-E('1H92!R97-P;VYS92P@8VAE8VL@9F]R
M(&YE=R!L:6YE<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@("`@("`@("H@<F5C
M:7!I96YT<RX@*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1R
M97-P;VYS92D["B`@("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*"B`@("`@
M("`@:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@("`@("`@("\J($UU
M;'1I<&QE(')E8VEP:65N=',N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1L
M:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@)'!A<G1S(#T@97AP
M;&]D92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@)')E8VEP:65N
M="`]('1R:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D;&EN
M97-;,%T@/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@("`@("`@("`@("1R
M97-P;VYS95LD<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N
M<V5;)')E8VEP:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@+RH@4VEN9VQE(')E8VEP:65N="X@*B\*("`@("`@("`@("`@
M:68@*"1L:6YE<ULP72`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@("`@
M("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E6R1T;UT@/2!A
M<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@8W5R<F5N="!C<F5D:70@8F%L86YC92!O;B!T:&4@
M9V%T97=A>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C<F5D:70@8F%L86YC92!A
M=F%I;&%B;&4@;VX@=&AE(&=A=&5W87DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971"86QA;F-E*"D*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R
M;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S
M=&US9RYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/6-R961I="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R
M86US6R=U<V5R)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D
M92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI.PH@("`@("`@("1R97-P
M;VYS92`]("1T:&ES+3Y?8V%L;%523"@D=7)L*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-P;VYS93L*("`@("`@("!]"@H@("`@("`@("\J(%1R>2!S<&QI
M='1I;F<@=7`@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1L:6YE<R`](&5X
M<&QO9&4H)STG+"`D<F5S<&]N<V4I.PH*("`@("`@("!I9B`H)&QI;F5S6S!=
M(#T]("=!45--4RU#4D5$250G*2!["B`@("`@("`@("`@(')E='5R;B`D;&EN
M97-;,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YG971%<G)O<B@D;&EN97-;,%TL(%\H(D-O=6QD(&YO="!C:&5C:R!B
M86QA;F-E+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&$@8V]N=&%C="!T;R!T:&4@9V%T97=A>2=S(&%D9')E<W-B;V]K
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N
M86UE(&9O<B!T:&ES(&-O;G1A8W0*("`@("`J($!P87)A;2!I;G1E9V5R("1N
M=6UB97(@(%1H92!C;VYT86-T)W,@<&AO;F4@;G5M8F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!R96UO=&4@8V]N=&%C="!)1"!O;B!S
M=6-C97-S(&]R(%!%05(@17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;G1A8W0H)&YA
M;64L("1N=6UB97(I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@
M86YD(&-A;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1C
M;VYT86-T<RYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/4%$1$-/
M3E1!0U0F;F%M93TE<R9N=6UB97(])7,G+`H@("`@("`@("`@("`@("`@("`@
M("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@
M("`@("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A
M<W-W;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M;F%M92DL"B`@("`@("`@("`@("`@("`@("`@("`@)&YU;6)E<BD["B`@("`@
M("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@
M(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0VAE8VL@:68@=&AE<F4@=V%S(&%N(&5R<F]R(')E<W!O;G-E+B`J+PH@("`@
M("`@(&EF("AS=6)S='(H)')E<W!O;G-E+"`P+"`Q-RD@(3T@)T%14TU3+4-/
M3E1!0U1)1$]+)RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R
M<F]R*"1R97-P;VYS92P@7R@B0V]U;&0@;F]T(&%D9"!C;VYT86-T+B`E<R(I
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%-P;&ET('5P('1H92!R97-P;VYS
M92X@*B\*("`@("`@("`D;&EN97,@/2!E>'!L;V1E*"<L/2<L("1R97-P;VYS
M92D["B`@("`@("`@<F5T=7)N("1L:6YE<ULQ73L*("`@('T*"B`@("`O*BH*
M("`@("`J(%5P9&%T97,@82!C;VYT86-T(&EN('1H92!G871E=V%Y)W,@861D
M<F5S<V)O;VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@
M("`@5&AE(&-O;G1A8W0G<R!)1"!O;B!T:&4@9V%T97=A>2X*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N86UE(&9O<B!T:&ES(&-O;G1A
M8W0*("`@("`J($!P87)A;2!I;G1E9V5R("1N=6UB97(@(%1H92!C;VYT86-T
M)W,@<&AO;F4@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('5P9&%T94-O;G1A8W0H)&ED+"`D;F%M92P@
M)&YU;6)E<BD*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@
M8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O;G1A
M8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]55!$051%0T].
M5$%#5"9I9#TE<R9N86UE/25S)FYU;6)E<CTE<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M
M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED+`H@
M("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D;F%M92DL"B`@("`@
M("`@("`@("`@("`@("`@("`@)&YU;6)E<BD["B`@("`@("`@)')E<W!O;G-E
M(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R
M97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AE(')E
M<W!O;G-E+B`J+PH@("`@("`@(&EF("@D<F5S<&]N<V4@/3T@)T%14TU3+4]+
M)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$5R<F]R*"1R97-P;VYS
M92P@7R@B0V]U;&0@;F]T('5P9&%T92!C;VYT86-T+B`E<R(I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@8V]N=&%C="!I
M;B!T:&4@9V%T97=A>2=S(&%D9')E<W-B;V]K+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1I9"`@5&AE(&-O;G1A8W0G<R!)1"!O;B!T:&4@9V%T
M97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96QE=&5#;VYT86-T*"1I9"D*("`@('L*("`@("`@("`O*B!3
M970@=7`@=&AE('5R;"!A;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@
M<W!R:6YT9B@G<&]S=&-O;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R
M9#TE<R9C;60]1$5,151%0T].5$%#5"9I9#TE<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@
M("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M
M<ULG<&%S<W=O<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED*3L*
M("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@
M("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!087)S92!T:&4@<F5S<&]N<V4N("HO"B`@("`@("`@:68@*"1R97-P
M;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@9&5L971E(&-O;G1A
M8W0N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9E
M=&-H97,@=&AE(&5N=&ER92!A9&1R97-S(&)O;VL@9G)O;2!T:&4@9V%T97=A
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!<G)A>2!O9B!C;VYT
M86-T<R!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J("`@("`@("`@("`@("`@($9O<FUA="!O9B!T:&4@<F5T=7)N960@8V]N
M=&%C=',@:7,@9F]R(&5X86UP;&4Z/&-O9&4^"B`@("`@*B`@("`@("`@("`@
M("`@("`@("!A<G)A>2@\=6YI<75E:60^(#T^(&%R<F%Y*"=N86UE)R`@(#T^
M(#QN86UE/BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VYU;6)E<B<@/3X@/&YU;6)E<CXI+`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@/'5N:7%U96ED/B`]/B!A<G)A>2@G
M;F%M92<@("`]/B`\;F%M93XL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=N=6UB97(G(#T^(#QN=6UB97(^
M*2D["B`@("`@*B`\+V-O9&4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%D
M9')E<W-";V]K*"D*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A
M;F0@8V%L;"!I="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&-O
M;G1A8W1S+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]1T54041$
M4D534T)/3TLG+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D92@D
M=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@
M("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*3L*("`@
M("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@
M("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@
M("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#$Y*2`A/2`G05%335,M
M041$4D534T)/3TM/2R<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG
M971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R971R:65V92!A9&1R
M97-S(&)O;VLN("5S(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@
M=&AE(')E<W!O;G-E(&%N9"!C;VYS=')U8W0@=&AE(&%R<F%Y+B`J+PH@("`@
M("`@(&QI<W0H)')E<W!O;G-E+"`D8V]N=&%C='-?<W1R*2`](&5X<&QO9&4H
M)RPG+"`D<F5S<&]N<V4L(#(I.PH*("`@("`@("`O*B!#:&5C:R!T:&%T('1H
M92!F=6QL(&%D9')E<W,@8F]O:R!L:7-T(&AA<R!B965N(')E8V5I=F5D+B`J
M+PH@("`@("`@("1L96YG=&@@/2!S=6)S='(H)')E<W!O;G-E+"`Q.2D["B`@
M("`@("`@:68@*'-T<FQE;B@D8V]N=&%C='-?<W1R*2`A/2`D;&5N9W1H*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD
M(&YO="!F971C:"!C;VUP;&5T92!A9&1R97-S(&)O;VLN(BDI.PH@("`@("`@
M('T*("`@("`@("`D8V]N=&%C='-?;&EN97,@/2!E>'!L;V1E*")<;B(L("1C
M;VYT86-T<U]S='(I.PH@("`@("`@("1C;VYT86-T<R`](&%R<F%Y*"D["B`@
M("`@("`@+RH@3&]O<"!T:')O=6=H(&QI;F5S(&%N9"!P:6-K(&]U="!T:&4@
M9FEE;&1S+"!M86ME('-U<F4@=&AA="!T:&4@(B(*("`@("`@("`@*B!A<F4@
M;F]T(&EN8VQU9&5D(&EN('1H92!V86QU97,L('-O(&=E="!T:&4@;&EN92!L
M97-S(#$@8VAA<B!O;B!E86-H"B`@("`@("`@("H@96YD(&%N9"!S<&QI="!F
M;W(@(BPB+B`J+PH@("`@("`@(&9O<F5A8V@@*"1C;VYT86-T<U]L:6YE<R!A
M<R`D;&EN92D@>PH@("`@("`@("`@("!L:7-T*"1I9"P@)&YA;64L("1N=6UB
M97(I(#T@97AP;&]D92@G(BPB)RP@<W5B<W1R*"1L:6YE+"`Q+"`M,2DI.PH@
M("`@("`@("`@("`D8V]N=&%C='-;)&ED72`](&%R<F%Y*"=N86UE)R`]/B`D
M;F%M92P@)VYU;6)E<B<@/3X@)&YU;6)E<BD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&-O;G1A8W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E
M871E<R!A(&YE=R!D:7-T<FEB=71I;VX@;&ES="!O;B!T:&4@9V%T97=A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@($%N(&%R8FET
M<F%R>2!N86UE(&9O<B!T:&4@;F5W(&QI<W0N"B`@("`@*B!`<&%R86T@87)R
M87D@)&YU;6)E<G,@($$@<VEM<&QE(&%R<F%Y(&]F(&YU;6)E<G,@=&\@861D
M('1O('1H92!L:7-T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($=A
M=&5W87D@240@9F]R('1H92!C<F5A=&5D(&QI<W0@;VX@<W5C8V5S<R!O<B!0
M14%2($5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0W)E871E*"1N86UE+"`D;G5M8F5R
M<RD*("`@('L*("`@("`@("`O*B!3970@=7`@=&AE('5R;"!A;F0@8V%L;"!I
M="X@*B\*("`@("`@("`D=7)L(#T@<W!R:6YT9B@G<&]S=&1I<W1R:6)U=&EO
M;BYP:'`_=7-E<FYA;64])7,F<&%S<W=O<F0])7,F8VUD/4%$1$1)4U1,25-4
M)FYA;64])7,F;G5M;&ES=#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O
M<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@=7)L96YC;V1E*"1N86UE
M*2P*("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L)RP@)&YU;6)E
M<G,I*3L*("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R
M;"D["B`@("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N
M<V4N("HO"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#$V*2`A
M/2`G05%335,M1$E35$E414U)1"<I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!C<F5A=&4@
M9&ES=')I8G5T:6]N(&QI<W0N("5S(BDI.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!G970@=&AE(&1I<W1R:6)U=&EO
M;B!L:7-T($E$+B`J+PH@("`@("`@(&QI<W0H)')E<W!O;G-E+"`D:60I(#T@
M97AP;&]D92@G/2<L("1R97-P;VYS92D["@H@("`@("`@("\J(%1/1$\Z(&1O
M('=E(&YE960@=&\@8VAE8VL@=&AE(&QE;F=T:"!O9B!T:&4@:60@<W1R:6YG
M/R`J+PH*("`@("`@("!R971U<FX@)&ED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5L971E<R!A(&1I<W1R:6)U=&EO;B!L:7-T(&9R;VT@=&AE(&=A=&5W
M87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!G871E
M=V%Y($E$(&9O<B!T:&4@;&ES="!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(%!%05(@17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$1E;&5T92@D
M:60I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A;&P@
M:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1D:7-T<FEB=71I
M;VXN<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U$14Q%5$5$25-4
M3$E35"9D:7-T:60])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@
M("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("1I9"D["B`@("`@("`@)')E<W!O
M;G-E(#T@)'1H:7,M/E]C86QL55),*"1U<FPI.PH@("`@("`@(&EF("AI<U]A
M*"1R97-P;VYS92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W!O;G-E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@<F5S
M<&]N<V4N("HO"B`@("`@("`@:68@*"1R97-P;VYS92`]/2`G05%335,M3TLG
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E
M+"!?*")#;W5L9"!N;W0@9&5L971E(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(I
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S(&$@
M9&ES=')I8G5T:6]N(&QI<W0@;VX@=&AE(&=A=&5W87DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@("`@("`@5&AE(&=A=&5W87D@240@9F]R
M('1H92!L:7-T('1O('5P9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("`@(%1H92!A<F)I=')A<GD@;F%M92!O9B!T:&4@;&ES="X@268@9&EF
M9F5R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F<F]M('1H
M92!O<FEG:6YA;"!N86UE('1H870@=&AE(&QI<W0@=V%S(&-R96%T960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('5N9&5R+"!T:&4@;&ES="!W
M:6QL(&)E(')E;F%M960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N=6UB97)S
M("!4:&4@;F5W(&QI<W0@;V8@;G5M8F5R<R!I;B!T:&4@;&ES="X@268@;&5F
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DL('1H92!R
M97-U;'0@=VEL;"!B92!T:&4@<V%M92!A<R!C86QL:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@;&ES=%)E;F%M92@I(&9U;F-T:6]N
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QI<W15<&1A=&4H)&ED+"`D;F%M92P@)&YU;6)E<G,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N9"!C86QL(&ET
M+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T9&ES=')I8G5T:6]N
M+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]55!$051%3$E35$Y!
M344F9&ES=&ED/25S)FYA;64])7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@
M("`@("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W
M;W)D)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("1I9"P*("`@("`@("`@
M("`@("`@("`@("`@("!U<FQE;F-O9&4H)&YA;64I*3L*"B`@("`@("`@+RH@
M0VAE8VL@:68@=&AE(&QI<W0@;G5M8F5R<R!N965D('5P9&%T:6YG+B`J+PH@
M("`@("`@(&EF("@A96UP='DH)&YU;6)E<G,I*2!["B`@("`@("`@("`@("1U
M<FP@+CT@)R9N=6UB97)S/2<@+B!I;7!L;V1E*"<L)RP@)&YU;6)E<G,I.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/E]C86QL55),
M*"1U<FPI.PH@("`@("`@(&EF("AI<U]A*"1R97-P;VYS92P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0VAE8VL@<F5S<&]N<V4N("HO"B`@("`@("`@:68@
M*"1R97-P;VYS92`]/2`G05%335,M3TLG*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^9V5T17)R;W(H)')E<W!O;G-E+"!?*")#;W5L9"!N;W0@=7!D871E
M(&1I<W1R:6)U=&EO;B!L:7-T+B`E<R(I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296YA;65S(&$@9&ES=')I8G5T:6]N(&QI<W0@;VX@
M=&AE(&=A=&5W87DN($1O97,@;F]T:&EN9R!O=&AE<B!T:&%N"B`@("`@*B!C
M86QL:6YG('1H92!L:7-T57!D871E*"D@9G5N8W1I;VX@=VET:"!J=7-T('1H
M92`D:60@86YD("1N86UE"B`@("`@*B!V87)I86)L97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D:60@("`@5&AE(&=A=&5W87D@240@9F]R('1H
M92!L:7-T('1O('5P9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!N97<@87)B:71R87)Y(&YA;64@9F]R('1H92!L:7-T+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!014%2
M($5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W12
M96YA;64H)&ED+"`D;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/FQI<W15<&1A=&4H)&ED+"`D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!&971C:&5S(&$@;&ES=&EN9R!O9B!A=F%I;&%B;&4@9&ES=')I8G5T:6]N
M(&QI<W1S(&]N('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@06X@87)R87D@;V8@;&ES=',@;VX@<W5C8V5S<R!O<B!014%2($5R
M<F]R(&]N(&9A:6QU<F4N"B`@("`@*B`@("`@("`@("`@("`@("!&;W)M870@
M;V8@=&AE(')E='5R;F5D(&QI<W1S(&ES(&9O<B!E>&%M<&QE.CQC;V1E/@H@
M("`@("H@("`@("`@("`@("`@("`@("`@87)R87DH/'5N:7%U96ED/B`]/B!A
M<G)A>2@G;F%M92<@("`]/B`\;F%M93XI+`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@/'5N:7%U96ED/B`]/B!A<G)A>2@G;F%M92<@("`]/B`\
M;F%M93XI*3L*("`@("`J(#PO8V]D93X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3&ES=',H*0H@("`@>PH@("`@("`@("\J(%-E="!U<"!T:&4@=7)L(&%N
M9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=P;W-T9&ES
M=')I8G5T:6]N+G!H<#]U<V5R;F%M93TE<R9P87-S=V]R9#TE<R9C;60]1T54
M0T]-4$%#5$Q)4U0G+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N8V]D
M92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@
M("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*3L*
M("`@("`@("`D<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@
M("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!#:&5C:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO
M"B`@("`@("`@:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#(R*2`A/2`G05%3
M35,M1$E35%))0E5424].3$E35"<I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YG971%<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R971R:65V
M92!D:7-T<FEB=71I;VX@;&ES=',N("5S(BDI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4&%R<V4@=&AE(')E<W!O;G-E(&%N9"!C;VYS=')U8W0@=&AE(&%R
M<F%Y+B`J+PH@("`@("`@(&QI<W0H)')E<W!O;G-E+"`D;&ES='-?<W1R*2`]
M(&5X<&QO9&4H)RPG+"`D<F5S<&]N<V4L(#(I.PH*("`@("`@("`O*B!#:&5C
M:R!T:&%T('1H92!F=6QL(&QI<W0@;V8@9&ES=')I8G5T:6]N(&QI<W1S(&AA
M<R!B965N(')E8V5I=F5D+B`J+PH@("`@("`@("1L96YG=&@@/2!S=6)S='(H
M)')E<W!O;G-E+"`R,BD["B`@("`@("`@:68@*'-T<FQE;B@D;&ES='-?<W1R
M*2`A/2`D;&5N9W1H*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D-O=6QD(&YO="!F971C:"!T:&4@8V]M<&QE=&4@;&ES="!O
M9B!D:7-T<FEB=71I;VX@;&ES=',N(BDI.PH@("`@("`@('T*("`@("`@("`D
M;&ES='-?;&EN97,@/2!E>'!L;V1E*")<;B(L("1L:7-T<U]S='(I.PH@("`@
M("`@("1L:7-T<R`](&%R<F%Y*"D["B`@("`@("`@+RH@3&]O<"!T:')O=6=H
M(&QI;F5S(&%N9"!P:6-K(&]U="!T:&4@9FEE;&1S+"!M86ME('-U<F4@=&AA
M="!T:&4@(B(*("`@("`@("`@*B!A<F4@;F]T(&EN8VQU9&5D(&EN('1H92!V
M86QU97,L('-O(&=E="!T:&4@;&EN92!L97-S(#$@8VAA<B!O;B!E86-H"B`@
M("`@("`@("H@96YD(&%N9"!S<&QI="!F;W(@(BPB+B`J+PH@("`@("`@(&9O
M<F5A8V@@*"1L:7-T<U]L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("!L
M:7-T*"1I9"P@)&YA;64L("1C;W5N="D@/2!E>'!L;V1E*"<B+"(G+"!S=6)S
M='(H)&QI;F4L(#$L("TQ*2D["B`@("`@("`@("`@("1L:7-T<ULD:61=(#T@
M87)R87DH)VYA;64G("`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8V]U;G0G(#T^("1C;W5N="D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&QI<W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@1F5T
M8VAE<R!A('-P96-I9FEC(&1I<W1R:6)U=&EO;B!L:7-T(&9R;VT@=&AE(&=A
M=&5W87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@5&AE($E$(&]F
M('1H92!D:7-T<FEB=71I;VX@;&ES="!T;R!F971C:"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!!;B!A<G)A>2!O9B!N=6UB97)S(&EN('1H92!L
M:7-T(&]N('-U8V-E<W,@;W(@4$5!4B!%<G)O<@H@("`@("H@("`@("`@("`@
M("`@("`@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&ES
M="@D:60I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!U<FP@86YD(&-A
M;&P@:70N("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)W!O<W1D:7-T<FEB
M=71I;VXN<&AP/W5S97)N86UE/25S)G!A<W-W;W)D/25S)F-M9#U'151.54U"
M15)35TE42$E$)F1I<W1I9#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M=7)L96YC;V1E*"1T:&ES+3Y?<&%R86US6R=U<V5R)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@('5R;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O
M<F0G72DL"B`@("`@("`@("`@("`@("`@("`@("`@)&ED*3L*("`@("`@("`D
M<F5S<&]N<V4@/2`D=&AI<RT^7V-A;&Q54DPH)'5R;"D["B`@("`@("`@:68@
M*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S<&]N<V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C
M:R!I9B!T:&5R92!W87,@86X@97)R;W(@<F5S<&]N<V4N("HO"B`@("`@("`@
M:68@*'-U8G-T<B@D<F5S<&]N<V4L(#`L(#(R*2`A/2`G05%335,M1$E35%))
M0E5424].3$E35"<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%
M<G)O<B@D<F5S<&]N<V4L(%\H(D-O=6QD(&YO="!R971R:65V92!D:7-T<FEB
M=71I;VX@;&ES="X@)7,B*2D["B`@("`@("`@?0H*("`@("`@("`O*B!087)S
M92!T:&4@<F5S<&]N<V4@86YD(&-O;G-T<G5C="!T:&4@87)R87DN("HO"B`@
M("`@("`@;&ES="@D<F5S<&]N<V4L("1L:7-T7W-T<BD@/2!E>'!L;V1E*"<L
M)RP@)')E<W!O;G-E+"`R*3L*"B`@("`@("`@+RH@0VAE8VL@=&AA="!T:&4@
M9G5L;"!L:7-T(&]F(&1I<W1R:6)U=&EO;B!L:7-T<R!H87,@8F5E;B!R96-E
M:79E9"X@*B\*("`@("`@("`D;&5N9W1H(#T@<W5B<W1R*"1R97-P;VYS92P@
M,C(I.PH@("`@("`@(&EF("AS=')L96XH)&QI<W1?<W1R*2`A/2`D;&5N9W1H
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O
M=6QD(&YO="!F971C:"!C;VUP;&5T92!D:7-T<FEB=71I;VX@;&ES="XB*2D[
M"B`@("`@("`@?0H@("`@("`@("1L:7-T7W-T<B`]('1R:6TH)&QI<W1?<W1R
M*3L*("`@("`@("!L:7-T*"1C;W5N="P@)&YU;6)E<G,I(#T@97AP;&]D92@G
M(BPB)RP@)&QI<W1?<W1R*3L*"B`@("`@("`@+RH@5$]$3SH@06YY=&AI;F<@
M=7-E9G5L('1H870@8V%N(&)E(&1O;F4@=VET:"!T:&4@8V]U;G0@;V8@;G5M
M8F5R<R!A=`H@("`@("`@("`J('1H92!S=&%R=#\@*B\*("`@("`@("`D8V]U
M;G0@/2!S=6)S='(H)&-O=6YT+"`Q*3L*"B`@("`@("`@+RH@17AP;&]D92!T
M:&4@;&ES="!O9B!N=6UB97)S(&EN=&\@86X@87)R87D@86YD(')E='5R;BX@
M*B\*("`@("`@("`D;G5M8F5R<R`]('-U8G-T<B@D;G5M8F5R<RP@,"P@+3$I
M.PH@("`@("`@(')E='5R;B!E>'!L;V1E*"<L)RP@)&YU;6)E<G,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@261E;G1I9FEE<R!T:&ES(&=A=&5W87D@9')I
M=F5R(&%N9"!R971U<FYS(&$@8G)I968@9&5S8W)I<'1I;VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@9')I=F5R(&EN9F\N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9F\H*0H@("`@>PH@("`@("`@("1I
M;F9O6R=N86UE)UT@/2!?*")S;7,R96UA:6P@=FEA($A45%`B*3L*("`@("`@
M("`D:6YF;ULG9&5S8R==(#T@7R@B5&AI<R!D<FEV97(@86QL;W=S('-E;F1I
M;F<@;V8@;65S<V%G97,@=&AR;W5G:"!T:&4@<VUS,F5M86EL("AH='1P.B\O
M<VUS,F5M86EL+F-O;2D@9V%T97=A>2P@=7-I;F<@=&AE($A45%`@05!)(BD[
M"@H@("`@("`@(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R('1H:7,@9V%T
M97=A>2!D<FEV97(N(%1H92!S971T86)L90H@("`@("H@<&%R86UE=&5R<R!F
M;W(@=&AI<R!G871E=V%Y(&%R93H\<')E/@H@("`@("H@("`M('5S97(@("`@
M("`@("`@("`M(%1H92!U<V5R;F%M92!F;W(@875T:&5N=&EC871I;VX@;VX@
M=&AE(&=A=&5W87D["B`@("`@*B`@("T@<&%S<W=O<F0@("`@("`@("T@5&AE
M('!A<W-W;W)D(&9O<B!A=71H96YT:6-A=&EO;B!O;B!T:&4@9V%T97=A>3L*
M("`@("`J("`@+2!S<VP@("`@("`@("`@("`@+2!7:&5T:&5R(&]R(&YO="!T
M;R!U<V4@4U-,(&9O<B!C;VUM=6YI8V%T:6]N('=I=&@*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@9V%T97=A>2X*("`@("`J("`@+2!D96QI
M=F5R>5]R97!O<G0@+2!!(%523"!F;W(@82!S8W)I<'0@=VAI8V@@=V]U;&0@
M86-C97!T(&1E;&EV97)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M<F5P;W)T(&9R;VT@=&AE(&=A=&5W87DN"B`@("`@*B`\+W!R93X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;7,H*0H@("`@
M>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("1P87)A;7-;
M)W5S97(G72`@("`@/2!A<G)A>2@G;&%B96PG(#T^(%\H(E5S97)N86UE(BDL
M("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@("1P87)A;7-;)W!A<W-W;W)D
M)UT@/2!A<G)A>2@G;&%B96PG(#T^(%\H(E!A<W-W;W)D(BDL("=T>7!E)R`]
M/B`G=&5X="<I.PH@("`@("`@("1P87)A;7-;)W-S;"==("`@("`@/2!A<G)A
M>2@G;&%B96PG("`@(#T^(%\H(E5S92!34TPB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`@("`]/B`G8F]O;&5A;B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E
M9"<@/3X@9F%L<V4I.PH@("`@("`@("1P87)A;7-;)V1E;&EV97)Y7W)E<&]R
M="==(#T@87)R87DH)VQA8F5L)R`@("`]/B!?*")54DP@9F]R('EO=7(@<V-R
M:7!T(&1E;&EV97)Y('-T871U<R!R97!O<G0B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@("`@/3X@)W1E
M>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E<75I<F5D)R`]/B!F86QS92D["@H*("`@("`@("!R971U<FX@)'!A
M<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M
M971E<G,@=&AA="!C86X@8F4@<V5T(&%S(&1E9F%U;'0@9F]R('-E;F1I;F<@
M;65S<V%G97,*("`@("`J('5S:6YG('1H:7,@9V%T97=A>2!D<FEV97(@86YD
M(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<&%R86UE=&5R<R!T:&%T(&-A
M;B!B92!S970@87,@9&5F875L="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1&5F875L=%-E;F1087)A;7,H*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@I.PH@("`@("`@("1P87)A;7-;)V9R;VTG72`](&%R<F%Y*`H@("`@
M("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G=&5X="<I.PH*("`@("`@("`D<&%R86US6R=D
M96QI=E]T:6UE)UT@/2!A<G)A>2@*("`@("`@("`@("`@)VQA8F5L)R`]/B!?
M*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G96YU
M;2<L"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*&%R<F%Y*"=N;W<G
M(#T^(%\H(FEM;65D:6%T92(I+"`G=7-E<B<@/3X@7R@B=7-E<B!S96QE8W0B
M*2DI*3L*"B`@("`@("`@)'1Y<&5S(#T@87)R87DH)U--4U]415A4)R`]/B`G
M4TU37U1%6%0G+"`G4TU37T9,05-()R`]/B`G4TU37T9,05-()RD["B`@("`@
M("`@)'!A<F%M<ULG;7-G7W1Y<&4G72`](&%R<F%Y*`H@("`@("`@("`@("`G
M;&%B96PG(#T^(%\H(DUE<W-A9V4@='EP92(I+`H@("`@("`@("`@("`G='EP
M92<@/3X@)VUU;'1I96YU;2<L"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R
M<F%Y*"1T>7!E<RDI.PH*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@9F]R('-E
M;F1I;F<@;65S<V%G97,@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<BP*("`@
M("`J(&1I<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N(%1H97-E(&%R
M92!F:6QT97)E9"!O=70@=7-I;F<@=&AE"B`@("`@*B!D969A=6QT('9A;'5E
M<R!S970@=7`@=VAE;B!C<F5A=&EN9R!T:&4@9V%T97=A>2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T
M97)S+@H@("`@("H@0'1O9&\@(%=O=6QD(&)E(&YI8V4@=&\@=7-E(&$@=&EM
M92]D871E('-E='5P(')A=&AE<B!T:&%N(&UI;G5T97,@9G)O;0H@("`@("H@
M("`@("`@(&YO=R!F;W(@=&AE(&1E;&EV97)Y('1I;64N(%5P;&]A9"!F:65L
M9"!F;W(@<FEN9W1O;F5S+VQO9V]S/PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M971396YD4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1P87)A;7-;)V9R;VTG72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG9G)O
M;2==(#T@87)R87DH"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O
M=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E
M>'0G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<&%R86US6R=D96QI=E]T
M:6UE)UT@/3T@)W5S97(G*2!["B`@("`@("`@("`@("1P87)A;7-;)V1E;&EV
M7W1I;64G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?
M*")$96QI=F5R>2!T:6UE(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@
M)VEN="<L"B`@("`@("`@("`@("`@("`G9&5S8R<@/3X@7R@B5F%L=64@:6X@
M;6EN=71E<R!F<F]M(&YO=RXB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M8V]U;G0H)'!A<F%M<ULG;7-G7W1Y<&4G72D@/B`Q*2!["B`@("`@("`@("`@
M("1P87)A;7-;)VUS9U]T>7!E)UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("=L86)E;"<@/3X@7R@B365S<V%G92!T>7!E(BDL"B`@("`@("`@("`@("`@
M("`G='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@("`@("`@)W!A<F%M<R<@
M/3X@87)R87DH)'!A<F%M<ULG;7-G7W1Y<&4G72DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P87)A;7-;)VUS9U]T>7!E)UT@/2`D<&%R86US
M6R=M<V=?='EP92==6S!=.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P
M87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG
M(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R(&-O9&4N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4:&4@97)R;W(@8V]D92!T;R!L
M;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("!!;B!E>&ES
M=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R86ES92!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05(@17)R;W(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE<W-A9V4@8V]R<F5S<&]N9&EN
M9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@("`@*B`@("`@("`@("`@("`@
M("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E>&ES=&EN9R!E<G)O<B!T97AT
M+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C:R!W:&EC:"!O9B!T:&5S92!A
M<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R:6T@9&]W;B!T:&4*("`@("`J
M("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%<G)O<B@D
M97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@("!["B`@("`@("`@)&5R<F]R
M(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A>2!O9B!E<G)O
M<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*("`@("`@("`D
M97)R;W)S(#T@87)R87DH"B`@("`@("`@("`@("=!45--4RU.3T%55$A$151!
M24Q3)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA;64@86YD+V]R('!A<W-W;W)D
M('-E;G0N(BDL"B`@("`@("`@("`@("=!45--4RU!551(15)23U(G("`@("`@
M("`@("`@/3X@7R@B26YC;W)R96-T('5S97)N86UE(&%N9"]O<B!P87-S=V]R
M9"XB*2P*("`@("`@("`@("`@)T%14TU3+4Y/35-')R`@("`@("`@("`@("`@
M("`]/B!?*").;R!M97-S86=E('-U<'!L:65D+B(I+`H@("`@("`@("`@("`G
M05%335,M3D]$15-4)R`@("`@("`@("`@("`@(#T^(%\H(DYO(&1E<W1I;F%T
M:6]N('-U<'!L:65D+B(I+`H@("`@("`@("`@("`G05%335,M3D]#4D5$250G
M("`@("`@("`@("`@(#T^(%\H(DEN<W5F9FEC:65N="!C<F5D:70N(BDL"B`@
M("`@("`@("`@("=!45--4RU.3TY!345355!03$E%1"<@("`@("`@/3X@7R@B
M3F\@;F%M92!S<&5C:69I960N(BDL"B`@("`@("`@("`@("=!45--4RU.3TY5
M34)%4E-54%!,245$)R`@("`@/3X@7R@B3F\@;G5M8F5R('-P96-I9FEE9"XB
M*2P*("`@("`@("`@("`@)T%14TU3+4%$1%)%4U-"3T]+15)23U(G("`@("`]
M/B!?*")4:&5R92!W87,@86X@97)R;W(@<&5R9F]R;6EN9R!T:&4@<W!E8VEF
M:65D(&%D9')E<W,@8F]O:R!F=6YC=&EO;BX@4&QE87-E('1R>2!A9V%I;B!L
M871E<BXB*2P*("`@("`@("`@("`@)T%14TU3+4-/3E1!0U1)1$524D]2)R`@
M("`@("`]/B!?*")4:&4@8V]N=&%C="!)1"!N=6UB97(@=V%S(&YO="!S<&5C
M:69I960L(&QE9G0@8FQA;FL@;W(@=V%S(&YO="!F;W5N9"!I;B!T:&4@9&%T
M86)A<V4N(BDL"B`@("`@("`@("`@("=!45--4RU#3TY404-455!$051%15)2
M3U(G("`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!C
M;VYT86-T(&1E=&%I;',N(%!L96%S92!T<GD@86=A:6X@;&%T97(N(BDL"B`@
M("`@("`@("`@("=!45--4RU$25-4241%4E)/4B<@("`@("`@("`@/3X@7R@B
M5&AE(&1I<W1R:6)U=&EO;B!L:7-T($E$('=A<R!E:71H97(@;F]T('-P96-I
M9FEE9"P@;&5F="!B;&%N:R!O<B!N;W0@9F]U;F0@:6X@=&AE(&1A=&%B87-E
M+B(I+`H@("`@("`@("`@("`G05%335,M3D]$25-43$E35%-54%!,245$)R`@
M(#T^(%\H(E1H92!D:7-T<FEB=71I;VX@;&ES="!W87,@;F]T('-P96-I9FEE
M9"XB*2P*("`@("`@("`@("`@)T%14TU3+4E.4U5&1DE#245.5$-2141)5%,G
M("`]/B!?*"));G-U9F9I8VEE;G0@8W)E9&ET('1O('-E;F0@=&\@=&AE(&1I
M<W1R:6)U=&EO;B!L:7-T+B(I+`H@("`@("`@("`@("`G05%335,M3D].54U"
M15),25-44U504$Q)140G(#T^(%\H(DYU;6)E<G,@;F]T('-P96-I9FEE9"!F
M;W(@=7!D871I;F<@:6X@9&ES=')I8G5T:6]N(&QI<W0N(BDL"B`@("`@("`@
M("`@("=!45--4RU$25-43$E35%501$%414524D]2)R`@/3X@7R@B5&AE<F4@
M=V%S(&%N(&5R<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@
M4&QE87-E('1R>2!A9V%I;B!L871E<BXB*2D["@H@("`@("`@(&EF("AE;7!T
M>2@D97)R;W)?=&5X="DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<G-;
M)&5R<F]R73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*"1E<G)O<E]T97AT+"`D97)R;W)S
M6R1E<G)O<ETI*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M;R!T:&4@:'1T<"!C86QL('5S:6YG(&$@=7)L('!A<W-E9"!T;R!T:&4@9G5N
M8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4:&4@=7)L('1O(&-A;&PN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<W!O;G-E(&]N('-U
M8V-E<W,@;W(@4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?8V%L;%523"@D=7)L*0H@("`@>PH@("`@("`@("1O<'1I;VYS
M6R=M971H;V0G72`]("=03U-4)SL*("`@("`@("`D;W!T:6]N<ULG=&EM96]U
M="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG86QL;W=2961I<F5C=',G72`]
M('1R=64["@H@("`@("`@("1U<FP@/2`H96UP='DH)'1H:7,M/E]P87)A;7-;
M)W-S;"==*2`_("=H='1P.B\O)R`Z("=H='1P<SHO+R<I("X@)'1H:7,M/E]B
M87-E7W5R;"`N("1U<FP["@H@("`@("`@(&EF("@A0&EN8VQU9&5?;VYC92`G
M2%144"]297%U97-T+G!H<"<I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B36ES<VEN9R!014%2('!A8VMA9V4@2%144%]297%U
M97-T+B(I*3L*("`@("`@("!]"B`@("`@("`@)&AT='`@/2`F;F5W($A45%!?
M4F5Q=65S="@D=7)L+"`D;W!T:6]N<RD["B`@("`@("`@0"1H='1P+3YS96YD
M4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T<"T^9V5T4F5S<&]N<V5#;V1E
M*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P96X@)7,N(BDL("1U<FPI*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1T<"T^9V5T4F5S<&]N<V5"
M;V1Y*"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O=F]D869O
M;F5I=&%L>5]S;71P+G!H<```````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R
M,3,P(#$P-3$U-#,T,30Q(#`R-#$P-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@3F5T7U--4U]V;V1A
M9F]N96ET86QY7W-M='`@0VQA<W,@:6UP;&5M96YT<R!T:&4@4TU44"!!4$D@
M9F]R(&%C8V5S<VEN9R!T:&4*("H@5F]D869O;F4@271A;'D@4TU3(&=A=&5W
M87DN(%5S92!O9B!T:&ES(&=A=&5W87D@<F5Q=6ER97,@86X@96UA:6P@86-C
M;W5N=`H@*B!W:71H(%9O9&%F;VYE($ET86QY("AW=W<N,3DP+FET*2X*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA='1E;R!:86UB96QL
M:2`\;6UZ86UB94!H;W1M86EL+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TYE=%]335,O4TU3+W9O9&%F;VYE:71A;'E?<VUT
M<"YP:'`L=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP
M("0*("H*("H@0&%U=&AO<B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M
M/@H@*B!`875T:&]R($UA='1E;R!:86UB96QL:2`\;6UZ86UB94!H;W1M86EL
M+F-O;3X*("H@0'!A8VMA9V4@3F5T7U--4PH@*B\*8VQA<W,@3F5T7U--4U]V
M;V1A9F]N96ET86QY7W-M='`@97AT96YD<R!.971?4TU3('L*"B`@("`O*BH*
M("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@
M9')I=F5R(&-A;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@("H@:70@
M<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE('9A;'5E
M<R!A<F4Z/'!R93X*("`@("`J("`@875T:"`@("`@("`@+2!4:&4@9V%T97=A
M>2!R97%U:7)E(&%U=&AE;G1I8V%T:6]N(&)E9F]R92!S96YD:6YG.PH@("`@
M("H@("!B871C:"`@("`@("`M($)A=&-H('-E;F1I;F<@:7,@<W5P<&]R=&5D
M.PH@("`@("H@("!M=6QT:2`@("`@("`M(%-E;F1I;F<@;V8@;65S<V%G97,@
M=&\@;75L=&EP;&4@<F5C:7!I96YT<R!I<R!S=7!P;W)T960["B`@("`@*B`@
M(')E8V5I=F4@("`@("T@5VAE=&AE<B!T:&ES(&1R:79E<B!I<R!C87!A8FQE
M(&]F(')E8V5I=FEN9R!335,["B`@("`@*B`@(&-R961I="`@("`@("T@27,@
M=7-E(&]F('1H92!G871E=V%Y(&)A<V5D(&]N(&-R961I=',["B`@("`@*B`@
M(&%D9')E<W-B;V]K("T@07)E(&=A=&5W87D@861D<F5S<V)O;VMS('-U<'!O
M<G1E9#L*("`@("`J("`@;&ES=',@("`@("`@+2!'871E=V%Y('-U<'!O<G0@
M9F]R(&1I<W1R:6)U=&EO;B!L:7-T<RX*("`@("`J(#PO<')E/@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I
M97,@/2!A<G)A>2@G875T:"<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8F%T8V@G("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;75L=&DG("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5C96EV
M92<@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8W)E9&ET)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;&ES=',G("`@("`@(#T^(&9A;'-E*3L*
M"B`@("`O*BH*("`@("`J(%1H:7,@9G5N8W1I;VX@9&]E<R!T:&4@86-T=6%L
M('-E;F1I;F<@;V8@=&AE(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1M97-S86=E
M("!4:&4@87)R87D@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!A;F0@:71S('-E
M;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R<RX*
M("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@5&AE(&1E<W1I;F%T:6]N
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!W:71H('1H92!S=6-C97-S('-T871U<R!A;F0@861D:71I;VYA;`H@("`@
M("H@("`@("`@("`@("`@("`@:6YF;W)M871I;VXN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S96YD*"8D;65S<V%G92P@)'1O*0H@("`@>PH@("`@("`@(&EF
M("@A0&EN8VQU9&5?;VYC92`G36%I;"YP:'`G*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(DUI<W-I;F<@<F5Q=6ER960@4$5!
M4B!P86-K86=E($UA:6PN(BDI.PH@("`@("`@('T*("`@("`@("`D;6%I;&5R
M(#T@36%I;#HZ9F%C=&]R>2@G;6%I;"<I.PH*("`@("`@("`O*B!3:6YC92!T
M:&ES(&]N;'D@=V]R:W,@9F]R($ET86QI86X@;G5M8F5R<RP@=&AI<R!I<R!H
M87)D8V]D960N("HO"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>+BH_/#\H
M7"L_,SDI/RA<9'LQ,'TI/C\O)RP@)'1O+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@)&AE861E<G-;)T9R;VTG72`]("1T:&ES+3Y?<&%R86US6R=U<V5R
M)UT["B`@("`@("`@("`@("1T;R`]("1M871C:&5S6S)=("X@)T!S;7,N=F]D
M869O;F4N:70G.PH@("`@("`@("`@("`D<F5S=6QT(#T@)&UA:6QE<BT^<V5N
M9"@D=&\L("1H96%D97)S+"`D;65S<V%G95LG=&5X="==*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L("1R97-U;'0M/F=E=$UE<W-A9V4H
M*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U
M<FX@87)R87DH,2P@;G5L;"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH,"P@7R@B66]U(&YE960@
M=&\@<')O=FED92!A;B!)=&%L:6%N('!H;VYE(&YU;6)E<B(I*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9&5N=&EF:65S('1H:7,@9V%T
M97=A>2!D<FEV97(@86YD(')E='5R;G,@82!B<FEE9B!D97-C<FEP=&EO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!D<FEV97(@
M:6YF;RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;R@I"B`@("!["B`@
M("`@("`@)&EN9F];)VYA;64G72`](%\H(E9O9&%F;VYE($ET86QY('9I82!3
M3510(BD["B`@("`@("`@)&EN9F];)V1E<V,G72`](%\H(E1H:7,@9')I=F5R
M(&%L;&]W<R!S96YD:6YG(&]F(&UE<W-A9V5S('9I82!33510('1H<F]U9V@@
M=&AE(%9O9&%F;VYE($ET86QY(&=A=&5W87DL(&]N;'D@=&\@5F]D869O;F4@
M;G5M8F5R<RX@270@<F5Q=6ER97,@86X@96UA:6P@86-C;W5N="!W:71H(%9O
M9&%F;VYE($ET86QY("AH='1P.B\O=W=W+C$Y,"YI="DN(BD["@H@("`@("`@
M(')E='5R;B`D:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(')E<75I<F5D('!A<F%M971E<G,@9F]R('1H:7,@9V%T97=A>2!D<FEV
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<F5Q
M=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R
M86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@
M("`D<&%R86US6R=U<V5R)UT@("`@("`@/2!A<G)A>2@G;&%B96PG("`]/B!?
M*")5<V5R;F%M92(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@(#T^("=T97AT)RD["@H@("`@("`@(')E='5R;B`D
M<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R
M86UE=&5R<R!T:&%T(&-A;B!B92!S970@87,@9&5F875L="!F;W(@<V5N9&EN
M9R!M97-S86=E<PH@("`@("H@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<B!A
M;F0@9&ES<&QA>65D('=H96X@<V5N9&EN9R!M97-S86=E<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!P87)A;65T97)S('1H870@
M8V%N(&)E('-E="!A<R!D969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$969A=6QT4V5N9%!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A
M;65T97)S(&9O<B!S96YD:6YG(&UE<W-A9V5S('5S:6YG('1H:7,@9V%T97=A
M>2!D<FEV97(L"B`@("`@*B!D:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A
M9V5S+B!4:&5S92!A<F4@9FEL=&5R960@;W5T('5S:6YG('1H90H@("`@("H@
M9&5F875L="!V86QU97,@<V5T('5P('=H96X@8W)E871I;F<@=&AE(&=A=&5W
M87DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@<F5Q
M=6ER960@<&%R86UE=&5R<RX*("`@("`J($!T;V1O("!7;W5L9"!B92!N:6-E
M('1O('5S92!A('1I;64O9&%T92!S971U<"!R871H97(@=&AA;B!M:6YU=&5S
M(&9R;VT*("`@("`J("`@("`@("!N;W<@9F]R('1H92!D96QI=F5R>2!T:6UE
M+B!5<&QO860@9FEE;&0@9F]R(')I;F=T;VYE<R]L;V=O<S\*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4V5N9%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@
M("`@(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!A;B!E<G)O<B!C;V1E
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1E<G)O<B`@5&AE(&5R
M<F]R(&-O9&4@=&\@;&]O:R!U<"X*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@("`@06X@97AI<W1I;F<@97)R;W(@=&5X="!T;R!U<V4@=&\@<F%I<V4@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!014%2($5R<F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@=&5X='5A;"!M97-S86=E
M(&-O<G)E<W!O;F1I;F<@=&\@=&AE(&5R<F]R(&-O9&4@;W(@80H@("`@("H@
M("`@("`@("`@("`@("`@4$5!4B!%<G)O<B!I9B!P87-S960@86X@97AI<W1I
M;F<@97)R;W(@=&5X="X*("`@("`J"B`@("`@*B!`=&]D;R`@0VAE8VL@=VAI
M8V@@;V8@=&AE<V4@87)E(&%C='5A;&QY(')E<75I<F5D(&%N9"!T<FEM(&1O
M=VX@=&AE"B`@("`@*B`@("`@("`@;&ES="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T17)R;W(H)&5R<F]R+"`D97)R;W)?=&5X="`]("<G*0H@("`@>PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TYE="]335,O8VQI8VMA=&5L;%]H='1P+G!H<```````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,Q,3(W(#$P-3$U-#,T,30Q(#`R,S,U
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@3F5T7U--4U]C;&EC:V%T96QL7VAT='`@0VQA<W,@:6UP
M;&5M96YT<R!T:&4@2%144"!!4$D@9F]R(&%C8V5S<VEN9R!T:&4*("H@0VQI
M8VMA=&5L;"`H=W=W+F-L:6-K871E;&PN8V]M*2!335,@9V%T97=A>2X*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B
M;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M3F5T7U--4R]335,O8VQI8VMA=&5L;%]H='1P+G!H<"QV(#$N,3,N,3`N.2`R
M,#`V+S`X+S`W(#`P.C0R.C,P(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@3F5T
M7U--4PH@*B\*8VQA<W,@3F5T7U--4U]C;&EC:V%T96QL7VAT='`@97AT96YD
M<R!.971?4TU3('L*"B`@("!V87(@)%]S97-S:6]N7VED(#T@;G5L;#L*("`@
M('9A<B`D7V)A<V5?=7)L(#T@)VAT='`Z+R]A<&DN8VQI8VMA=&5L;"YC;VTO
M:'1T<"\G.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET
M:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:"!O<&5R
M871I;VYS"B`@("`@*B!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG
M="X@4&]S<VEB;&4@=F%L=65S(&%R93H\<')E/@H@("`@("H@("!A=71H("`@
M("`@("`M(%1H92!G871E=V%Y(')E<75I<F4@875T:&5N=&EC871I;VX@8F5F
M;W)E('-E;F1I;F<["B`@("`@*B`@(&)A=&-H("`@("`@("T@0F%T8V@@<V5N
M9&EN9R!I<R!S=7!P;W)T960["B`@("`@*B`@(&UU;'1I("`@("`@("T@4V5N
M9&EN9R!O9B!M97-S86=E<R!T;R!M=6QT:7!L92!R96-I<&EE;G1S(&ES('-U
M<'!O<G1E9#L*("`@("`J("`@<F5C96EV92`@("`@+2!7:&5T:&5R('1H:7,@
M9')I=F5R(&ES(&-A<&%B;&4@;V8@<F5C96EV:6YG(%--4SL*("`@("`J("`@
M8W)E9&ET("`@("`@+2!)<R!U<V4@;V8@=&AE(&=A=&5W87D@8F%S960@;VX@
M8W)E9&ET<SL*("`@("`J("`@861D<F5S<V)O;VL@+2!!<F4@9V%T97=A>2!A
M9&1R97-S8F]O:W,@<W5P<&]R=&5D.PH@("`@("H@("!L:7-T<R`@("`@("`M
M($=A=&5W87D@<W5P<&]R="!F;W(@9&ES=')I8G5T:6]N(&QI<W1S+@H@("`@
M("H@/"]P<F4^"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A=71H)R`@("`@("`@/3X@
M=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A=&-H)R`@
M("`@("`]/B`Q,#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M=6QT:2<@("`@("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E8V5I=F4G("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-R961I="<@("`@("`]/B!T<G5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G861D<F5S<V)O;VLG(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES=',G("`@("`@
M(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($%U=&AE;G1I8V%T92!A="!T
M:&4@9V%T97=A>2!A;F0@<V5T(&$@<V5S<VEO;B!I9"!I9B!S=6-C97-S9G5L
M+B!#86-H:6YG"B`@("`@*B!I<R!U<V5D('1O(&UI;FEM:7-E('1H92!H='1P
M(&-A;&QS(&9O<B!S=6)S97%U96YT(&UE<W-A9V5S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H*0H@("`@>PH@("`@
M("`@("\J(%=E(&AA=F4@86QR96%D>2!A=71H96YT:6-A=&5D('-O(')E='5R
M;B!T<G5E+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]S97-S:6]N
M7VED*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@
M("`@("`@("\J(%-E="!U<"!T:&4@:'1T<"!A=71H96YT:6-A=&EO;B!U<FPN
M("HO"B`@("`@("`@)'5R;"`]('-P<FEN=&8H)V%U=&@_=7-E<CTE<R9P87-S
M=V]R9#TE<R9A<&E?:60])7,G+`H@("`@("`@("`@("`@("`@("`@("`@('5R
M;&5N8V]D92@D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2P*("`@("`@("`@("`@
M("`@("`@("`@("!U<FQE;F-O9&4H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A
M<&E?:60G72D["@H@("`@("`@("\J($1O('1H92!(5%10(&%U=&AE;G1I8V%T
M:6]N(&%N9"!G970@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1R97-P;VYS
M92`]($YE=%]335-?8VQI8VMA=&5L;%]H='1P.CI?8V%L;%523"@D=7)L*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")!=71H96YT:6-A=&EO;B!F86EL960N("5S(BDL("1R97-P;VYS92T^9V5T
M365S<V%G92@I*2D["B`@("`@("`@?0H*("`@("`@("`O*B!3<&QI="!U<"!T
M:&4@<F5S<&]N<V4N("HO"B`@("`@("`@)')E<W!O;G-E(#T@97AP;&]D92@G
M.B<L("1R97-P;VYS92D["B`@("`@("`@:68@*"1R97-P;VYS95LP72`]/2`G
M3TLG*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5S<VEO;E]I9"`]('1R:6TH
M)')E<W!O;G-E6S%=*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971%<G)O
M<B@D<F5S<&]N<V5;,5TL(%\H(D%U=&AE;G1I8V%T:6]N(&9A:6QE9"X@)7,B
M*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC
M=&EO;B!D;V5S('1H92!A8W1U86P@<V5N9&EN9R!O9B!T:&4@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&UE<W-A9V4@(%1H92!A<G)A>2!C;VYT86EN:6YG('1H
M92!M97-S86=E(&%N9"!I=',@<V5N9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!P87)A;65T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@
M("`@("!4:&4@9&5S=&EN871I;VX@<W1R:6YG+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%R<F%Y('=I=&@@=&AE('-U8V-E<W,@<W1A='5S
M(&%N9"!A9&1I=&EO;F%L"B`@("`@*B`@("`@("`@("`@("`@("!I;F9O<FUA
M=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E;F0H)B1M97-S86=E+"`D
M=&\I"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H92!H='1P('-E;F1I;F<@
M=7)L+B`J+PH@("`@("`@("1U<FP@/2!S<')I;G1F*"=S96YD;7-G/W-E<W-I
M;VY?:60])7,F=&5X=#TE<R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S97-S:6]N7VED+`H@("`@("`@("`@("`@("`@("`@("`@('5R;&5N
M8V]D92@D;65S<V%G95LG=&5X="==*2D["@H@("`@("`@("1R97%?9F5A="`]
M(#`["B`@("`@("`@:68@*"%E;7!T>2@D;65S<V%G95LG<V5N9%]P87)A;7,G
M75LG9G)O;2==*2D@>PH@("`@("`@("`@("`O*B!)9B!S;W5R8V4@9G)O;2!I
M<R!S970L(')E<75I<F4@:70@9F]R('1R86YS:70@9V%T97=A>7,@86YD(&%P
M<&5N9`H@("`@("`@("`@("`@("!T;R!U<FPN("HO"B`@("`@("`@("`@("1R
M97%?9F5A="`]*R`Q-CL*("`@("`@("`@("`@)'5R;"`N/2`G)F9R;VT])R`N
M('5R;&5N8V]D92@D;65S<V%G95LG<V5N9%]P87)A;7,G75LG9G)O;2==*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D;65S<V%G95LG<V5N9%]P
M87)A;7,G75LG;7-G7W1Y<&4G72D@)B8*("`@("`@("`@("`@)&UE<W-A9V5;
M)W-E;F1?<&%R86US)UU;)VUS9U]T>7!E)UT@/3T@)U--4U]&3$%32"<I('L*
M("`@("`@("`@("`@+RH@268@;65S<V%G92!T>7!E(&ES(&9L87-H+"!R97%U
M:7)E(&ET(&9O<B!T<F%N<VET(&=A=&5W87ES+B`J+PH@("`@("`@("`@("`D
M<F5Q7V9E870@/2L@-3$R.PH@("`@("`@("`@("`D=7)L("X]("<F;7-G7W1Y
M<&4])R`N("1M97-S86=E6R=S96YD7W!A<F%M<R==6R=M<V=?='EP92==.PH@
M("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1R97%?9F5A="DI('L*("`@
M("`@("`@("`@+RH@268@9F5A='5R97,@:&%V92!B965N(')E<75I<F5D+"!A
M9&0@=&\@=7)L+B`J+PH@("`@("`@("`@("`D=7)L("X]("<F<F5Q7V9E870]
M)R`N("1R97%?9F5A=#L*("`@("`@("!]"@H@("`@("`@("\J($%P<&5N9"!T
M:&4@<F5C:7!I96YT<R!O9B!T:&ES(&UE<W-A9V4@86YD(&-A;&P@=&AE('5R
M;"X@*B\*("`@("`@("!F;W)E86-H("@D=&\@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_7"L_*%QD>S<L
M?2DH/GPD*2\G+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@
M("1T;ULD:V5Y72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+RH@1DE8344Z(%-I;&5N=&QY(&1R;W`@8F%D
M(')E8VEP:65N=',N(%1H:7,@<VAO=6QD(&)E(&QO9V=E9`H@("`@("`@("`@
M("`@("`@("H@86YD+V]R(')E<&]R=&5D+B`J+PH@("`@("`@("`@("`@("`@
M=6YS970H)'1O6R1K97E=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("`D=&\@/2!I;7!L;V1E*"<L)RP@)'1O*3L*("`@("`@("`D=7)L("X]
M("<F=&\])R`N("1T;SL*("`@("`@("`D<F5S<&]N<V4@/2!T<FEM*"1T:&ES
M+3Y?8V%L;%523"@D=7)L*2D["@H@("`@("`@("\J(%5G;'D@<&%R<VEN9R!O
M9B!T:&4@<F5S<&]N<V4L(&)U="!T:&%T)W,@:&]W(&ET(&-O;65S(&)A8VLN
M("HO"B`@("`@("`@)&QI;F5S(#T@97AP;&]D92@B7&XB+"`D<F5S<&]N<V4I
M.PH@("`@("`@("1R97-P;VYS92`](&%R<F%Y*"D["@H@("`@("`@(&EF("AC
M;W5N="@D;&EN97,I(#X@,2D@>PH@("`@("`@("`@("!F;W)E86-H("@D;&EN
M97,@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@("1P87)T<R`](&5X<&QO
M9&4H)U1O.B<L("1L:6YE*3L*("`@("`@("`@("`@("`@("1R96-I<&EE;G0@
M/2!T<FEM*"1P87)T<ULQ72D["B`@("`@("`@("`@("`@("`D;W5T8V]M92`]
M(&5X<&QO9&4H)SHG+"`D<&%R='-;,%TI.PH@("`@("`@("`@("`@("`@)')E
M<W!O;G-E6R1R96-I<&EE;G1=(#T@87)R87DH*"1O=71C;VUE6S!=(#T]("=)
M1"<@/R`Q(#H@,"DL("1O=71C;VUE6S%=*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J(%-I;F=L92!R96-I<&EE;G0N
M("HO"B`@("`@("`@("`@("1O=71C;VUE(#T@97AP;&]D92@G.B<L("1L:6YE
M<ULP72D["B`@("`@("`@("`@("1R97-P;VYS95LD=&]=(#T@87)R87DH*"1O
M=71C;VUE6S!=(#T]("=)1"<@/R`Q(#H@,"DL("1O=71C;VUE6S%=*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S<&]N<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT(&-R961I="!B86QA;F-E
M(&]N('1H92!G871E=V%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-R961I="!B
M86QA;F-E(&%V86EL86)L92!O;B!T:&4@9V%T97=A>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E=$)A;&%N8V4H*0H@("`@>PH@("`@("`@("\J(%-E="!U
M<"!T:&4@=7)L(&%N9"!C86QL(&ET+B`J+PH@("`@("`@("1U<FP@/2!S<')I
M;G1F*"=G971B86QA;F-E/W-E<W-I;VY?:60])7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5S<VEO;E]I9"D["B`@("`@("`@)')E<W!O
M;G-E(#T@=')I;2@D=&AI<RT^7V-A;&Q54DPH)'5R;"DI.PH*("`@("`@("`O
M*B!4<GD@<W!L:71T:6YG('5P('1H92!R97-P;VYS92X@*B\*("`@("`@("`D
M;&EN97,@/2!E>'!L;V1E*"<])RP@)')E<W!O;G-E*3L*"B`@("`@("`@+RH@
M4W!L:70@=7`@=&AE(')E<W!O;G-E+B`J+PH@("`@("`@("1R97-P;VYS92`]
M(&5X<&QO9&4H)SHG+"`D<F5S<&]N<V4I.PH@("`@("`@(&EF("@D<F5S<&]N
M<V5;,%T@/3T@)T-R961I="<I('L*("`@("`@("`@("`@<F5T=7)N('1R:6TH
M)')E<W!O;G-E6S%=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F=E=$5R<F]R*"1R97-P;VYS95LQ72P@7R@B0V]U;&0@
M;F]T(&-H96-K(&)A;&%N8V4N("5S(BDI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($ED96YT:69I97,@=&AI<R!G871E=V%Y(&1R:79E<B!A
M;F0@<F5T=7)N<R!A(&)R:65F(&1E<V-R:7!T:6]N+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($%R<F%Y(&]F(&1R:79E<B!I;F9O+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971);F9O*"D*("`@('L*("`@("`@("`D:6YF;ULG
M;F%M92==(#T@7R@B0VQI8VMA=&5L;"!V:6$@2%144"(I.PH@("`@("`@("1I
M;F9O6R=D97-C)UT@/2!?*")4:&ES(&1R:79E<B!A;&QO=W,@<V5N9&EN9R!O
M9B!M97-S86=E<R!T:')O=6=H('1H92!#;&EC:V%T96QL("AH='1P.B\O8VQI
M8VMA=&5L;"YC;VTI(&=A=&5W87DL('5S:6YG('1H92!(5%10($%022(I.PH*
M("`@("`@("!R971U<FX@)&EN9F\["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!R97%U:7)E9"!P87)A;65T97)S(&9O<B!T:&ES(&=A=&5W
M87D@9')I=F5R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y
M(&]F(')E<75I<F5D('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%!A<F%M<R@I"B`@("!["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[
M"B`@("`@("`@)'!A<F%M<ULG=7-E<B==("`@("`](&%R<F%Y*"=L86)E;"<@
M/3X@7R@B57-E<FYA;64B*2P@)W1Y<&4G(#T^("=T97AT)RD["B`@("`@("`@
M)'!A<F%M<ULG<&%S<W=O<F0G72`](&%R<F%Y*"=L86)E;"<@/3X@7R@B4&%S
M<W=O<F0B*2P@)W1Y<&4G(#T^("=T97AT)RD["B`@("`@("`@)'!A<F%M<ULG
M87!I7VED)UT@("`](&%R<F%Y*"=L86)E;"<@/3X@7R@B05!)($E$(BDL("=T
M>7!E)R`]/B`G=&5X="<I.PH*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@=&AA
M="!C86X@8F4@<V5T(&%S(&1E9F%U;'0@9F]R('-E;F1I;F<@;65S<V%G97,*
M("`@("`J('5S:6YG('1H:7,@9V%T97=A>2!D<FEV97(@86YD(&1I<W!L87EE
M9"!W:&5N('-E;F1I;F<@;65S<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@07)R87D@;V8@<&%R86UE=&5R<R!T:&%T(&-A;B!B92!S970@
M87,@9&5F875L="X*("`@("`J($!T;V1O("!3970@=7`@8F%T8V@@9FEE;&1S
M+W!A<F%M<RP@=V]U;&0@8F4@;FEC92!T;R!H879E(')I;F=T;VYE+VQO9V\*
M("`@("`J("`@("`@("!S=7!P;W)T('1O;RP@<75E=64@8VAO:6-E+"!U;FEC
M;V1E(&-H;VEC92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F875L=%-E
M;F1087)A;7,H*0H@("`@>PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@
M("`@("`@("1P87)A;7-;)V9R;VTG72`](&%R<F%Y*`H@("`@("`@("`@("`G
M;&%B96PG(#T^(%\H(E-O=7)C92!A9&1R97-S(BDL"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G=&5X="<I.PH*("`@("`@("`D<&%R86US6R=D96QI=E]T:6UE
M)UT@/2!A<G)A>2@*("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")$96QI=F5R
M>2!T:6UE(BDL"B`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@
M("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*&%R<F%Y*"=N;W<G(#T^(%\H(FEM
M;65D:6%T92(I+"`G=7-E<B<@/3X@7R@B=7-E<B!S96QE8W0B*2DI*3L*"B`@
M("`@("`@)'1Y<&5S(#T@87)R87DH)U--4U]415A4)R`]/B`G4TU37U1%6%0G
M+"`G4TU37T9,05-()R`]/B`G4TU37T9,05-()RD["B`@("`@("`@)'!A<F%M
M<ULG;7-G7W1Y<&4G72`](&%R<F%Y*`H@("`@("`@("`@("`G;&%B96PG(#T^
M(%\H(DUE<W-A9V4@='EP92(I+`H@("`@("`@("`@("`G='EP92<@/3X@)VUU
M;'1I96YU;2<L"B`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"1T>7!E
M<RDI.PH*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@9F]R('-E;F1I;F<@;65S
M<V%G97,@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<BP*("`@("`J(&1I<W!L
M87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N(%1H97-E(&%R92!F:6QT97)E
M9"!O=70@=7-I;F<@=&AE"B`@("`@*B!D969A=6QT('9A;'5E<R!S970@9F]R
M('1H92!G871E=V%Y+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R
M<F%Y(&]F(')E<75I<F5D('!A<F%M971E<G,N"B`@("`@*B!`=&]D;R`@5V]U
M;&0@8F4@;FEC92!T;R!U<V4@82!T:6UE+V1A=&4@<V5T=7`@<F%T:&5R('1H
M86X@;6EN=71E<R!F<F]M"B`@("`@*B`@("`@("`@;F]W(&9O<B!T:&4@9&5L
M:79E<GD@=&EM92X@57!L;V%D(&9I96QD(&9O<B!R:6YG=&]N97,O;&]G;W,_
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E;F1087)A;7,H)'!A<F%M<RD*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG9G)O;2==*2D@>PH@
M("`@("`@("`@("`D<&%R86US6R=F<F]M)UT@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("=L86)E;"<@/3X@7R@B4V]U<F-E(&%D9')E<W,B*2P*("`@("`@
M("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1P87)A;7-;)V1E;&EV7W1I;64G72`]/2`G=7-E<B<I('L*("`@
M("`@("`@("`@)'!A<F%M<ULG9&5L:79?=&EM92==(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`G;&%B96PG(#T^(%\H(D1E;&EV97)Y('1I;64B*2P*("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@
M("=D97-C)R`]/B!?*")686QU92!I;B!M:6YU=&5S(&9R;VT@;F]W+B(I*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D<&%R86US6R=M<V=?='EP
M92==*2`^(#$I('L*("`@("`@("`@("`@)'!A<F%M<ULG;7-G7W1Y<&4G72`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")-97-S86=E
M('1Y<&4B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@
M("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@D<&%R86US6R=M<V=?
M='EP92==*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M
M<ULG;7-G7W1Y<&4G72`]("1P87)A;7-;)VUS9U]T>7!E)UU;,%T["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@86X@
M97)R;W(@8V]D92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D97)R
M;W(@(%1H92!E<G)O<B!C;V1E('1O(&QO;VL@=7`N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("`@($%N(&5X:7-T:6YG(&5R<F]R('1E>'0@=&\@=7-E
M('1O(')A:7-E(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4B!%<G)O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!('1E>'1U
M86P@;65S<V%G92!C;W)R97-P;VYD:6YG('1O('1H92!E<G)O<B!C;V1E(&]R
M(&$*("`@("`J("`@("`@("`@("`@("`@(%!%05(@17)R;W(@:68@<&%S<V5D
M(&%N(&5X:7-T:6YG(&5R<F]R('1E>'0N"B`@("`@*@H@("`@("H@0'1O9&\@
M($-H96-K('=H:6-H(&]F('1H97-E(&%R92!A8W1U86QL>2!R97%U:7)E9"!A
M;F0@=')I;2!D;W=N('1H90H@("`@("H@("`@("`@(&QI<W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$5R<F]R*"1E<G)O<BP@)&5R<F]R7W1E>'0@/2`G
M)RD*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@9V5T(&]N;'D@=&AE
M(&YU;6)E<B!A="!T:&4@<W1A<G0@;V8@86X@97)R;W(N("HO"B`@("`@("`@
M;&ES="@D97)R;W(I(#T@97AP;&]D92@G+"<L("1E<G)O<BD["B`@("`@("`@
M)&5R<F]R(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O*B!!;B!A<G)A>2!O
M9B!E<G)O<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T97=A>2X@*B\*("`@
M("`@("`D97)R;W)S(#T@87)R87DH)S`P,2<@/3X@7R@B075T:&5N=&EC871I
M;VX@9F%I;&5D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<P,#(G(#T^
M(%\H(E5N:VYO=VX@=7-E<FYA;64@;W(@<&%S<W=O<F0N(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("<P,#,G(#T^(%\H(E-E<W-I;VX@240@97AP:7)E
M9"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S`P-"<@/3X@7R@B06-C
M;W5N="!F<F]Z96XN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<P,#4G
M(#T^(%\H(DUI<W-I;F<@<V5S<VEO;B!)1"XB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)S`P-R<@/3X@7R@B25`@;&]C:V1O=VX@=FEO;&%T:6]N+B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G,3`Q)R`]/B!?*"));G9A;&ED
M(&]R(&UI<W-I;F<@<&%R86UE=&5R<RXB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@)S$P,B<@/3X@7R@B26YV86QI9"!51$@N("A5<V5R($1A=&$@2&5A
M9&5R*2XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$P,R<@/3X@7R@B
M56YK;F]W;B!A<&EM<V=I9"`H05!)($UE<W-A9V4@240I+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G,3`T)R`]/B!?*")5;FMN;W=N(&-L:6US9VED
M("A#;&EE;G0@365S<V%G92!)1"DN(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("<Q,#4G(#T^(%\H(DEN=F%L:60@9&5S=&EN871I;VX@861D<F5S<RXB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$P-B<@/3X@7R@B26YV86QI
M9"!S;W5R8V4@861D<F5S<RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M)S$P-R<@/3X@7R@B16UP='D@;65S<V%G92XB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)S$P."<@/3X@7R@B26YV86QI9"!O<B!M:7-S:6YG(&%P:5]I
M9"XB*2P*("`@("`@("`@("`@("`@("`@("`@("`@)S$P.2<@/3X@7R@B36ES
M<VEN9R!M97-S86=E($E$+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M,3$P)R`]/B!?*")%<G)O<B!W:71H(&5M86EL(&UE<W-A9V4N(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("<Q,3$G(#T^(%\H(DEN=F%L:60@<')O=&]C
M;VPN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,3(G(#T^(%\H(DEN
M=F%L:60@;7-G7W1Y<&4N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<Q
M,3,G(#T^(%\H(DUA>"!M97-S86=E('!A<G1S(&5X8V5E9&5D+B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G,3$T)R`]/B!?*")#86YN;W0@<F]U=&4@
M;65S<V%G92!T;R!S<&5C:69I960@;G5M8F5R+B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G,3$U)R`]/B!?*")-97-S86=E(&5X<&ER960N(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("<Q,38G(#T^(%\H(DEN=F%L:60@=6YI
M8V]D92!D871A+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G,C`Q)R`]
M/B!?*"));G9A;&ED(&)A=&-H($E$+B(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G,C`R)R`]/B!?*").;R!B871C:"!T96UP;&%T92XB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)S,P,2<@/3X@7R@B3F\@8W)E9&ET(&QE9G0N
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<S,#(G(#T^(%\H(DUA>"!A
M;&QO=V5D(&-R961I="XB*2D["@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?
M=&5X="DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*"1E<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T
M<"!C86QL('5S:6YG(&$@=7)L('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7)L("!4:&4@=7)L('1O(&-A;&PN"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(')E<W!O;G-E(&]N('-U8V-E<W,@;W(@
M4$5!4B!%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V%L;%523"@D=7)L*0H@("`@>PH@("`@("`@("1O<'1I;VYS6R=M971H;V0G
M72`]("='150G.PH@("`@("`@("1O<'1I;VYS6R=T:6UE;W5T)UT@/2`U.PH@
M("`@("`@("1O<'1I;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U93L*"B`@
M("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=(5%10+U)E<75E<W0N<&AP)RD@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")-:7-S
M:6YG(%!%05(@<&%C:V%G92!(5%107U)E<75E<W0N(BDI.PH@("`@("`@('T*
M("`@("`@("`D:'1T<"`]("9N97<@2%144%]297%U97-T*"1T:&ES+3Y?8F%S
M95]U<FP@+B`D=7)L+"`D;W!T:6]N<RD["B`@("`@("`@0"1H='1P+3YS96YD
M4F5Q=65S="@I.PH@("`@("`@(&EF("@D:'1T<"T^9V5T4F5S<&]N<V5#;V1E
M*"D@(3T@,C`P*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*'-P<FEN=&8H7R@B0V]U;&0@;F]T(&]P96X@)7,N(BDL("1U<FPI*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1T<"T^9V5T4F5S<&]N<V5"
M;V1Y*"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TYE="]335,O9V5N97)I8U]S;71P+G!H<```
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-C0R(#$P-3$U-#,T
M,30Q(#`R,C8V-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@1V5N97)I8R!E+6UA:6P@8F%S960@4TU3
M(&1R:79E<@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V(%=E8E-P<F]C:V5T
M<RP@3$Q#"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!4:&ES(&1R:79E<B!I;G1E<F9A
M8V5S('=I=&@@=&AE(&5M86EL+71O+7-M<R!G871E=V%Y<R!P<F]V:61E9"!B
M>2!M86YY"B`J(&-A<G)I97)S+"!P87)T:6-U;&%R;'D@=&AO<V4@8F%S960@
M:6X@=&AE(%4N4RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3F5T7U--4R]3
M35,O9V5N97)I8U]S;71P+G!H<"QV(#$N."XR+C0@,C`P-B\P-R\Q,R`P.#HU
M-SHT-2!J86X@17AP("0*("H*("H@0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@
M*B!`<&%C:V%G92`@("!.971?4TU3"B`J($!A=71H;W(@("`@($EA;B!%=7)E
M(#QI975R94!P:'`N;F5T/@H@*B!`<VEN8V4@("`@("!(;W)D92`S+C$*("H@
M0'-I;F-E("`@("`@3F5T7U--4R`P+C`N,@H@*B\*8VQA<W,@3F5T7U--4U]G
M96YE<FEC7W-M='`@97AT96YD<R!.971?4TU3('L*"B`@("`O*BH*("`@("`J
M($-A<&%B:6QI=&EE<R!O9B!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R
M87DH"B`@("`@("`@)V%U=&@G("`@("`@("`]/B!F86QS92P*("`@("`@("`G
M8F%T8V@G("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=M=6QT:2<@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)W)E8V5I=F4G("`@("`]/B!F86QS92P*("`@
M("`@("`G8W)E9&ET)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=A9&1R97-S
M8F]O:R<@/3X@9F%L<V4L"B`@("`@("`@)VQI<W1S)R`@("`@("`]/B!F86QS
M90H@("`@*3L*"B`@("`O*BH*("`@("`J($1R:79E<B!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH"B`@
M("`@("`@)V-A<G)I97(G("`@("`]/B!N=6QL+`H@("`@("`@("=M86EL0F%C
M:V5N9"<@/3X@)VUA:6PG+`H@("`@("`@("=M86EL4&%R86US)R`@/3X@87)R
M87DH*2P*("`@("`@("`G;6%I;$AE861E<G,G(#T^(&%R<F%Y*"D*("`@("D[
M"@H@("`@+RHJ"B`@("`@*B!#87)R:65R(&5M86EL(&UA<"X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7V-A<G)I97)S(#T@87)R87DH"B`@("`@("`@
M+RH@52Y3+B!C87)R:65R<RX@*B\*("`@("`@("`G871T)R`@("`@("`@("`]
M/B`G)7-`;6UO9&4N8V]M)RP*("`@("`@("`G8VEN9W5L87(G("`@("`]/B`G
M)7-`;6UO9&4N8V]M)RP*("`@("`@("`G=F5R:7IO;B<@("`@("`]/B`G)7-`
M=G1E>'0N8V]M)RP*("`@("`@("`G8F]O<W0G("`@("`@("`]/B`G)7-`;7EB
M;V]S=&UO8FEL92YC;VTG+`H@("`@("`@("=C96QL=6QA<F]N92<@(#T^("<E
M<T!M>6-E;&QO;F4N;F5T)RP*("`@("`@("`G8VEN8WEB96QL)R`@("`]/B`G
M)7-`9V]C8G<N8V]M)RP*("`@("`@("`G<W!R:6YT)R`@("`@("`]/B`G)7-`
M;65S<V%G:6YG+G-P<FEN='!C<RYC;VTG+`H@("`@("`@("=T;6]B:6QE7W5S
M)R`@(#T^("<E<T!T;6]M86EL+F-O;2<L"B`@("`@("`@)W-U;F-O;2<@("`@
M("`@/3X@)R5S0'1M<RYS=6YC;VTN8V]M)RP*("`@("`@("`G86ER8V5L)R`@
M("`@("`]/B`G)7-`86ER<VUS+F-O;2<L"B`@("`@("`@)V%I<G1E;"<@("`@
M("`@/3X@)R5S0&%I<G1E;&UA:6PN8V]M)RP*("`@("`@("`G8G!L;6]B:6QE
M)R`@("`]/B`G)7-`8G!L;6]B:6QE+F-O;2<L"B`@("`@("`@)V)E;&QM;V)I
M;&ET>2<@/3X@)R5S0'1X="YB96QL;6]B:6QI='DN8V$G+`H@("`@("`@("=B
M;'5E9W)A<W,G("`@(#T^("<E<T!S;7,N8FQU96-E;&PN8V]M)RP*("`@("`@
M("`G8V5L;&9O<F-E)R`@("`]/B`G)7-`8V5L9F]R8V4N8V]M)RP*("`@("`@
M("`G8V5L;'5L87)O;F4G("`]/B`G)7-`;7EC96QL;VYE+FYE="<L"B`@("`@
M("`@+RH@1V5R;6%N(&-A<G)I97)S+B`J+PH@("`@("`@("=E<&QU<R<@("`@
M("`@/3X@)R5S0'-M<VUA:6PN97!L=7,N9&4G+`H@("`@("`@("=T;6]B:6QE
M7V1E)R`@/3X@)R5S0'0M;6]B:6QE+7-M<RYD92<L"B`@("`@("`@)W9O9&%F
M;VYE7V1E)R`]/B`G)7-`=F]D869O;F4M<VUS+F1E)RP*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!)9&5N=&EF:65S('1H:7,@9')I=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($1R:79E<B!I;F9O+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971);F9O*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH
M"B`@("`@("`@("`@("=N86UE)R`]/B!?*")%;6%I;"UT;RU335,@1V%T97=A
M>2(I+`H@("`@("`@("`@("`G9&5S8R<@/3X@7R@B14UA:6PM=&\M4TU3(&=A
M=&5W87D@9')I=F5R+"!F;W(@8V%R<FEE<G,@=VAI8V@@<')O=FED92!T:&ES
M('-E<G9I8V4N(BD*("`@("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!R97%U:7)E9"!P87)A;65T97)S+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%R<F%Y(&]F(')E<75I<F5D('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G8V%R<FEE<B<@("`@(#T^(&%R
M<F%Y*"=L86)E;"<@/3X@7R@B0V%R<FEE<B(I+"`G='EP92<@/3X@)W1E>'0G
M*2P*("`@("`@("`@("`@)VUA:6Q"86-K96YD)R`]/B!A<G)A>2@G;&%B96PG
M(#T^(%\H(E!%05(Z.DUA:6P@8F%C:V5N9"(I+"`G='EP92<@/3X@)W1E>'0G
M*0H@("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396YD<R!T:&4@
M;65S<V%G92X*("`@("`J"B`@("`@*B!9;W4@;6%Y(&%L<V\@<W!E8VEF>2!T
M:&4@8V%R<FEE<B!W:71H('1H92`G8V%R<FEE<B<@:V5Y(&]F('1H92!M97-S
M86=E"B`@("`@*B!T;R!A=F]I9"!C<F5A=&EN9R!A(&YE=R!I;G-T86YC92!F
M;W(@96%C:"!C87)R:65R+"!O<B!F:61D;&EN9R!W:71H('1H90H@("`@("H@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@($UE<W-A9V4@=&\@
M<V5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)'1O("`@("`@1&5S=&EN871I
M;VX@<&AO;F4@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y('=I=&@@=&AE('-U8V-E<W,@<W1A='5S(&%N9"!A9&1I=&EO
M;F%L"B`@("`@*B`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W-E;F0H)B1M97-S86=E+"`D=&\I"B`@("!["B`@
M("`@("`@)')E<W!O;G-E(#T@87)R87DH*3L*("`@("`@("`D9&5S=&5M86EL
M(#T@)'1H:7,M/E]G971$97-T*"1T;RD["B`@("`@("`@<F5Q=6ER95]O;F-E
M("=-86EL+G!H<"<["B`@("`@("`@)&T@/2!-86EL.CIF86-T;W)Y*"1T:&ES
M+3Y?<&%R86US6R=M86EL0F%C:V5N9"==+"`D=&AI<RT^7W!A<F%M<ULG;6%I
M;%!A<F%M<R==*3L*"B`@("`@("`@:68@*&ES<V5T*"1M97-S86=E6R=C87)R
M:65R)UTI*2!["B`@("`@("`@("`@("1D97-T(#T@)'1H:7,M/E]G971$97-T
M*"1T;RP@)&UE<W-A9V5;)V-A<G)I97(G72D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&1E<W0@/2`D=&AI<RT^7V=E=$1E<W0H)'1O*3L*("`@
M("`@("!]"@H@("`@("`@("1R97,@/28@)&TM/G-E;F0H)&1E<W0L("1T:&ES
M+3Y?<&%R86US6R=M86EL2&5A9&5R<R==+"`D;65S<V%G95LG=&5X="==*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@("`@
M("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y*#`L("1R97,M/F=E=$UE<W-A9V4H
M*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W!O;G-E6R1T
M;UT@/2!A<G)A>2@Q+"!N=6QL*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1E
M<W1I;F%T:6]N(&4M;6%I;"!A9&1R97-S+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!H;VYE("!0:&]N92!N=6UB97(@=&\@<V5N9"!T;RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1&5S=&EN871I;VX@861D<F5S
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$1E<W0H)'!H;VYE+"`D8V%R
M<FEE<B`](&YU;&PI"B`@("!["B`@("`@("`@)&-A<G)I97(@/2!I<U]N=6QL
M*"1C87)R:65R*2`_("1T:&ES+3Y?<&%R86US6R=C87)R:65R)UT@.B`D8V%R
M<FEE<CL*("`@("`@("!R971U<FX@<W!R:6YT9B@D=&AI<RT^7V-A<G)I97)S
M6R1C87)R:65R72P*("`@("`@("`@("`@("`@("`@("`@("!P<F5G7W)E<&QA
M8V4H)R];7C`M.5TO)RP@)R<L("1P:&]N92DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@861D<F5S<R!T96UP;&%T92!F;W(@82!C87)R
M:65R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A<G)I97(@($-A
M<G)I97(@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!9&1R
M97-S('1E;7!L871E(&]R(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!9&1R97-S5&5M<&QA=&4H)&-A<G)I97(I"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V-A<G)I97)S6R1C87)R:65R72DI('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]C87)R:65R<ULD8V%R<FEE<ET["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&$@8V%R<FEE<B!T;R!T:&4@;&ES="X*("`@("`J"B`@("`@
M*B!!9&1R97-S('1E;7!L871E<R!N965D('1O(&)E(&EN('1H92!F;W)M(&]F
M(&%N(&5M86EL(&%D9')E<W,L('=I=&@@80H@("`@("H@)R5S)R!R97!R97-E
M;G1I;F<@=&AE('!L86-E('=H97)E('1H92!D97-T:6YA=&EO;B!P:&]N92!N
M=6UB97(@9V]E<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!#87)R:65R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9&1R("!!
M9&1R97-S('1E;7!L871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1#87)R
M:65R*"1N86UE+"`D861D<BD*("`@('L*("`@("`@("`D=&AI<RT^7V-A<G)I
M97)S6R1N86UE72`]("1A9&1R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(&QI<W0@;V8@<&%R86UE=&5R<R!S<&5C:69I8R!F;W(@=&AI<R!D
M<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2!$969A=6QT('-E
M;F1I;F<@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&5F
M875L=%-E;F1087)A;7,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TYE
M="]335,O=VEN7VAT='`N<&AP````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#(R,S$W(#$P-3$U-#,T,30Q(#`R,C`T,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M3F5T7U--4U]W:6Y?:'1T<"!#;&%S<R!I;7!L96UE;G1S('1H92!(5%10($%0
M22!F;W(@86-C97-S:6YG('1H92!724X*("H@*'=W=RYW:6YP;&,N8V]M*2!3
M35,@9V%T97=A>2X*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$
M:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO3F5T7U--4R]335,O=VEN7VAT='`N<&AP+'8@,2XY
M+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(X.C(Y(&IA;B!%>'`@)`H@*@H@*B!`875T
M:&]R($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E
M($YE=%]335,*("HO"F-L87-S($YE=%]335-?=VEN7VAT='`@97AT96YD<R!.
M971?4TU3('L*"B`@("!V87(@)%]B87-E7W5R;"`]("=G871E=V%Y,RYG;S)M
M;V)I;&4N;F5T.C$P,#,P+V=A=&5W87DO=C,O9V%T97=A>2YA<W!X)SL*"B`@
M("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA
M="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@@;W!E<F%T:6]N<PH@("`@
M("H@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N(%!O<W-I8FQE
M('9A;'5E<R!A<F4Z/'!R93X*("`@("`J("`@875T:"`@("`@("`@+2!4:&4@
M9V%T97=A>2!R97%U:7)E<R!A=71H96YT:6-A=&EO;B!B969O<F4@<V5N9&EN
M9SL*("`@("`J("`@8F%T8V@@("`@("`@+2!"871C:"!S96YD:6YG(&ES('-U
M<'!O<G1E9#L*("`@("`J("`@;75L=&D@("`@("`@+2!396YD:6YG(&]F(&UE
M<W-A9V5S('1O(&UU;'1I<&QE(')E8VEP:65N=',@:7,@<W5P<&]R=&5D.PH@
M("`@("H@("!R96-E:79E("`@("`M(%=H971H97(@=&AI<R!D<FEV97(@:7,@
M8V%P86)L92!O9B!R96-E:79I;F<@4TU3.PH@("`@("H@("!C<F5D:70@("`@
M("`M($ES('5S92!O9B!T:&4@9V%T97=A>2!B87-E9"!O;B!C<F5D:71S.PH@
M("`@("H@("!A9&1R97-S8F]O:R`M($%R92!G871E=V%Y(&%D9')E<W-B;V]K
M<R!S=7!P;W)T960["B`@("`@*B`@(&QI<W1S("`@("`@("T@1V%T97=A>2!S
M=7!P;W)T(&9O<B!D:7-T<FEB=71I;VX@;&ES=',N"B`@("`@*B`\+W!R93X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P
M86)I;&ET:65S(#T@87)R87DH)V%U=&@G("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A=&-H)R`@("`@("`]/B`Q
M,#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M=6QT:2<@("`@
M("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M8V5I=F4G("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V-R961I="<@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V%D9')E<W-B;V]K)R`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W1S)R`@("`@("`]/B!F86QS
M92D["@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N(&1O97,@=&AE(&%C
M='5A;"!S96YD:6YG(&]F('1H92!M97-S86=E+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S
M<V%G92`@5&AE(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@86YD(&ET
M<R!S96YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E
M<G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;R`@("`@(%1H92!D97-T:6YA
M=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@
M87)R87D@=VET:"!T:&4@<W5C8V5S<R!S=&%T=7,@86YD(&%D9&ET:6]N86P*
M("`@("`J("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<V5N9"@F)&UE<W-A9V4L("1T;RD*("`@('L*("`@("`@
M("`O*B!3=&%R="!T:&4@6$U,+B`J+PH@("`@("`@("1X;6P@/2`G/%--4TU%
M4U-!1T4^/%1%6%0^)R`N("1M97-S86=E6R=T97AT)UT@+B`G/"]415A4/B<[
M"@H@("`@("`@("\J($-H96-K(&EF('-O=7)C92!F<F]M(&ES('-E="X@*B\*
M("`@("`@("!I9B`H(65M<'1Y*"1M97-S86=E6R=S96YD7W!A<F%M<R==6R=F
M<F]M)UTI*2!["B`@("`@("`@("`@("1X;6P@+CT@)SQ33U520T5?041$4CXG
M("X@)&UE<W-A9V5;)W-E;F1?<&%R86US)UU;)V9R;VTG72`N("<\+U-/55)#
M15]!1$12/B<["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@
M<F5C:7!I96YT<R!A;F0@9&\@<V]M92!M:6YI;6%L('9A;&ED:71Y(&-H96-K
M:6YG+B`J+PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&\I*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1T;R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BXJ/SP_*%PK/UQD>S<L?2DH/GPD
M*2\G+"`D=F%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("`@("`D
M=&];)&ME>5T@/2`D;6%T8VAE<ULQ73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@+RH@268@82!R96-I<&EE;G0@:7,@
M:6YV86QI9"!S=&]P(&%L;"!F=7)T:&5R('-E;F1I;F<N("HO"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L('-P<FEN=&8H7R@B26YV86QI
M9"!R96-I<&EE;G0Z(%PB)7-<(B(I+"`D=F%L*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T;R`](&EM<&QO9&4H
M)SPO1$535$E.051)3TY?041$4CX\1$535$E.051)3TY?041$4CXG+"`D=&\I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"<O7BXJ/SP_*%PK/UQD>S<L?2DH/GPD*2\G+"`D=&\L("1M871C:&5S*2D@
M>PH@("`@("`@("`@("`@("`@)'1O(#T@)&UA=&-H97-;,5T["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH,"P@
M<W!R:6YT9BA?*"));G9A;&ED(')E8VEP:65N=#H@7"(E<UPB(BDL("1T;RDI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1X;6P@+CT@)SQ$
M15-424Y!5$E/3E]!1$12/B<@+B`D=&\@+B`G/"]$15-424Y!5$E/3E]!1$12
M/B<["@H@("`@("`@("\J(%1/1$\Z(%-H;W5L9"!W92!H879E('-O;65T:&EN
M9R!M;W)E(&EN=&5L;&EG96YT/R!#;W5L9"!A8W1U86QL>0H@("`@("`@("`J
M(&)E('!A<G0@;V8@<V5N9"!P87)A;65T97)S+B`J+PH@("`@("`@("1X;6P@
M+CT@)SQ44D%.4T%#5$E/3DE$/B<@+B!T:6UE*"D@+B`G/"]44D%.4T%#5$E/
M3DE$/B<["@H@("`@("`@("\J(%1/1$\Z($%D9"!S;VUE(&5X=')A('1A9W,L
M(&IU<W0@=&%C:V5D(&]N(&9O<B!N;W<N("HO"B`@("`@("`@)'AM;"`N/2`G
M/%194$5)1#XR/"]465!%240^/%-%4E9)0T5)1#XQ/"]315)624-%240^/"]3
M35--15-304=%/B<["@H@("`@("`@("\J(%-E;F0@=&AI<R!M97-S86=E+B`J
M+PH@("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?<&]S="@D>&UL*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S<&]N<V4L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L("1R97-P;VYS92T^9V5T365S<V%G
M92@I*3L*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H92!R97-P;VYS
M92P@8VAE8VL@9F]R(&YE=R!L:6YE<R!I;B!C87-E(&]F(&UU;'1I<&QE"B`@
M("`@("`@("H@<F5C:7!I96YT<RX@*B\*("`@("`@("`D;&EN97,@/2!E>'!L
M;V1E*")<;B(L("1R97-P;VYS92D["B`@("`@("`@)')E<W!O;G-E(#T@87)R
M87DH*3L*"B`@("`@("`@:68@*&-O=6YT*"1L:6YE<RD@/B`Q*2!["B`@("`@
M("`@("`@("\J($UU;'1I<&QE(')E8VEP:65N=',N("HO"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@("`@("`@
M)'!A<G1S(#T@97AP;&]D92@G5&\Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@
M("`@)')E8VEP:65N="`]('1R:6TH)'!A<G1S6S%=*3L*("`@("`@("`@("`@
M("`@(&EF("@D;&EN97-;,%T@/3T@)T%14TU3+4]+)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1R97-P;VYS95LD<F5C:7!I96YT72`](&%R<F%Y*#$L(&YU
M;&PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D<F5S<&]N<V5;)')E8VEP:65N=%T@/2!A<G)A>2@P+"`D;&EN97-;
M,%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@+RH@4VEN9VQE(')E8VEP:65N="X@*B\*
M("`@("`@("`@("`@:68@*"1L:6YE<ULP72`]/2`G05%335,M3TLG*2!["B`@
M("`@("`@("`@("`@("`D<F5S<&]N<V5;)'1O72`](&%R<F%Y*#$L(&YU;&PI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O
M;G-E6R1T;UT@/2!A<G)A>2@P+"`D;&EN97-;,%TI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@261E;G1I9FEE<R!T:&ES(&=A=&5W87D@9')I=F5R
M(&%N9"!R971U<FYS(&$@8G)I968@9&5S8W)I<'1I;VXN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@07)R87D@;V8@9')I=F5R(&EN9F\N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$EN9F\H*0H@("`@>PH@("`@("`@("1I;F9O
M6R=N86UE)UT@/2!?*")724X@=FEA($A45%`B*3L*("`@("`@("`D:6YF;ULG
M9&5S8R==(#T@7R@B5&AI<R!D<FEV97(@86QL;W=S('-E;F1I;F<@;V8@;65S
M<V%G97,@=&AR;W5G:"!T:&4@5TE.("AH='1P.B\O=VEN<&QC+F-O;2D@9V%T
M97=A>2P@=7-I;F<@=&AE($A45%`@05!)(BD["@H@("`@("`@(')E='5R;B`D
M:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E<75I
M<F5D('!A<F%M971E<G,@9F]R('1H:7,@9V%T97=A>2!D<FEV97(N(%1H92!S
M971T86)L90H@("`@("H@<&%R86UE=&5R<R!F;W(@=&AI<R!G871E=V%Y(&%R
M93H*("`@("`J("`@+2!U<V5R("`@("`@("`@("`@+2!4:&4@=7-E<FYA;64@
M9F]R(&%U=&AE;G1I8V%T:6]N(&]N('1H92!G871E=V%Y.PH@("`@("H@("`M
M('!A<W-W;W)D("`@("`@("`M(%1H92!P87-S=V]R9"!F;W(@875T:&5N=&EC
M871I;VX@;VX@=&AE(&=A=&5W87D["B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@07)R87D@;V8@<F5Q=6ER960@<&%R86UE=&5R<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%R86US*"D*("`@('L*("`@("`@("`D<&%R86US
M(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6R=U<V5R)UT@("`@(#T@87)R
M87DH)VQA8F5L)R`]/B!?*")5<V5R;F%M92(I+"`G='EP92<@/3X@)W1E>'0G
M*3L*("`@("`@("`D<&%R86US6R=P87-S=V]R9"==(#T@87)R87DH)VQA8F5L
M)R`]/B!?*")087-S=V]R9"(I+"`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@
M("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!P87)A;65T97)S('1H870@8V%N(&)E('-E="!A<R!D969A=6QT
M(&9O<B!S96YD:6YG(&UE<W-A9V5S"B`@("`@*B!U<VEN9R!T:&ES(&=A=&5W
M87D@9')I=F5R(&%N9"!D:7-P;&%Y960@=VAE;B!S96YD:6YG(&UE<W-A9V5S
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%R<F%Y(&]F('!A<F%M
M971E<G,@=&AA="!C86X@8F4@<V5T(&%S(&1E9F%U;'0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$1E9F%U;'1396YD4&%R86US*"D*("`@('L*("`@("`@
M("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("`D<&%R86US6R=F<F]M)UT@
M/2!A<G)A>2@*("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")3;W5R8V4@861D
M<F5S<R(I+`H@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*"B`@("`@
M("`@)'!A<F%M<ULG8V]S=%]I9"==(#T@87)R87DH"B`@("`@("`@("`@("=L
M86)E;"<@/3X@7R@B0V]S="!)1"(I+`H@("`@("`@("`@("`G='EP92<@/3X@
M)VEN="<I.PH*("`@("`@("!R971U<FX@)'!A<F%M<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('!A<F%M971E<G,@9F]R('-E;F1I;F<@
M;65S<V%G97,@=7-I;F<@=&AI<R!G871E=V%Y(&1R:79E<BP*("`@("`J(&1I
M<W!L87EE9"!W:&5N('-E;F1I;F<@;65S<V%G97,N(%1H97-E(&%R92!F:6QT
M97)E9"!O=70@=7-I;F<@=&AE"B`@("`@*B!D969A=6QT('9A;'5E<R!S970@
M=7`@=VAE;B!C<F5A=&EN9R!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!<G)A>2!O9B!R97%U:7)E9"!P87)A;65T97)S+@H@
M("`@("H@0'1O9&\@(%=O=6QD(&)E(&YI8V4@=&\@=7-E(&$@=&EM92]D871E
M('-E='5P(')A=&AE<B!T:&%N(&UI;G5T97,@9G)O;0H@("`@("H@("`@("`@
M(&YO=R!F;W(@=&AE(&1E;&EV97)Y('1I;64N(%5P;&]A9"!F:65L9"!F;W(@
M<FEN9W1O;F5S+VQO9V]S/PH@("`@("HO"B`@("!F=6YC=&EO;B!G971396YD
M4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;)V9R;VTG72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG9G)O;2==(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(E-O=7)C92!A
M9&1R97-S(BDL"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=C;W-T7VED
M)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)V1E;&EV7W1I;64G72`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*")#;W-T($E$(BDL
M"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)VEN="<I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F(&%N(&5R<F]R
M(&-O9&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5R<F]R("!4
M:&4@97)R;W(@8V]D92!T;R!L;V]K('5P+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@("!!;B!E>&ES=&EN9R!E<G)O<B!T97AT('1O('5S92!T;R!R
M86ES92!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(@17)R
M;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@02!T97AT=6%L(&UE
M<W-A9V4@8V]R<F5S<&]N9&EN9R!T;R!T:&4@97)R;W(@8V]D92!O<B!A"B`@
M("`@*B`@("`@("`@("`@("`@("!014%2($5R<F]R(&EF('!A<W-E9"!A;B!E
M>&ES=&EN9R!E<G)O<B!T97AT+@H@("`@("H*("`@("`J($!T;V1O("!#:&5C
M:R!W:&EC:"!O9B!T:&5S92!A<F4@86-T=6%L;'D@<F5Q=6ER960@86YD('1R
M:6T@9&]W;B!T:&4*("`@("`J("`@("`@("!L:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971%<G)O<B@D97)R;W(L("1E<G)O<E]T97AT(#T@)R<I"B`@
M("!["B`@("`@("`@)&5R<F]R(#T@=')I;2@D97)R;W(I.PH*("`@("`@("`O
M*B!!;B!A<G)A>2!O9B!E<G)O<B!C;V1E<R!R971U<FYE9"!B>2!T:&4@9V%T
M97=A>2X@*B\*("`@("`@("`D97)R;W)S(#T@87)R87DH"B`@("`@("`@("`@
M("=!45--4RU.3T%55$A$151!24Q3)R`@("`@("`@/3X@7R@B3F\@=7-E<FYA
M;64@86YD+V]R('!A<W-W;W)D('-E;G0N(BDL"B`@("`@("`@("`@("=!45--
M4RU$25-43$E35%501$%414524D]2)R`@/3X@7R@B5&AE<F4@=V%S(&%N(&5R
M<F]R('5P9&%T:6YG('1H92!D:7-T<FEB=71I;VX@;&ES="X@4&QE87-E('1R
M>2!A9V%I;B!L871E<BXB*2D["@H@("`@("`@(&EF("AE;7!T>2@D97)R;W)?
M=&5X="DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<G-;)&5R<F]R73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*"1E<G)O<E]T97AT+"`D97)R;W)S6R1E<G)O<ETI
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;R!T:&4@:'1T
M<"!C86QL('5S:6YG(&$@=7)L('!A<W-E9"!T;R!T:&4@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D>&UL("!4:&4@6$U,(&EN9F]R;6%T:6]N('!A<W-E9"!T
M;R!T:&4@9V%T97=A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M:&4@<F5S<&]N<V4@;VX@<W5C8V5S<R!O<B!014%2($5R<F]R(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P;W-T*"1X;6PI"B`@("!["B`@
M("`@("`@)&]P=&EO;G-;)VUE=&AO9"==(#T@)U!/4U0G.PH@("`@("`@("1O
M<'1I;VYS6R=T:6UE;W5T)UT@/2`U.PH@("`@("`@("1O<'1I;VYS6R=A;&QO
M=U)E9&ER96-T<R==(#T@=')U93L*"B`@("`@("`@+RH@5W)A<"!T:&4@>&UL
M('=I=&@@=&AE('-T86YD87)D('1A9W,N("HO"B`@("`@("`@)'AM;"`]("<\
M/WAM;"!V97)S:6]N/2(Q+C`B('-T86YD86QO;F4](FYO(C\^/"%$3T-465!%
M(%=)3E]$14Q)5D5265\R7U--4R!365-414T@(G=I;F)O=6YD7VUE<W-A9V5S
M7W8Q+F1T9"(^/%=)3E]$14Q)5D5265\R7U--4SXG("X@)'AM;"`N("<\+U=)
M3E]$14Q)5D5265\R7U--4SXG.PH*("`@("`@("!I9B`H(4!I;F-L=61E7V]N
M8V4@)TA45%`O4F5Q=65S="YP:'`G*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DUI<W-I;F<@4$5!4B!P86-K86=E($A45%!?
M4F5Q=65S="XB*2D["B`@("`@("`@?0H@("`@("`@("1H='1P(#T@)FYE=R!(
M5%107U)E<75E<W0H)'1H:7,M/E]B87-E7W5R;"P@)&]P=&EO;G,I.PH*("`@
M("`@("`O*B!!9&0@=&AE(&%U=&AE;G1I8V%T:6]N('9A;'5E<R!T;R!03U-4
M+B`J+PH@("`@("`@("1H='1P+3YA9&10;W-T1&%T82@G57-E<B<L("1T:&ES
M+3Y?<&%R86US6R=U<V5R)UTI.PH@("`@("`@("1H='1P+3YA9&10;W-T1&%T
M82@G4&%S<W=O<F0G+"`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["@H@
M("`@("`@("\J($%D9"!T:&4@6$U,(&%N9"!S96YD('1H92!R97%U97-T+B`J
M+PH@("`@("`@("1H='1P+3YA9&10;W-T1&%T82@G5TE.7UA-3"<L("1X;6PI
M.PH@("`@("`@($`D:'1T<"T^<V5N9%)E<75E<W0H*3L*("`@("`@("!I9B`H
M)&AT='`M/F=E=%)E<W!O;G-E0V]D92@I("$](#(P,"D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO
M="!O<&5N("5S+B(I+"`D=&AI<RT^7V)A<V5?=7)L*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&AT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I;&4`````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$S-R`P,C`T-S4`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T1A=&$`````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,W(#`R,#$S-P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1W)A<&@`````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S<@,#(P
M,S(W`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F]U<```````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$S-R`P,C`S-C(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TEM86=E````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,W(#`R,#,Q,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4&5R;7,`````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M,S<@,#(P,S4T`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S
M:6]N2&%N9&QE<@``````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S-R`P,C(R,#<`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;@``````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,W(#`R,3<Q-``@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4```````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q,S<@,#(P,#$T`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]0<F5F<P``````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-R`P,C`S-#4`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FT`````````````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,W(#`R
M,#$W,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&]K96X`````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q,S<@,#(P,S0V`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-R`P,C`P,34`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0`````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,30P(#`R,#(P-``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5')E
M90``````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q-#`@,#(P,34W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]#<GEP=```````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,"`P,C`S-C$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,30P(#`R,3`U,P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O5D,`````````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#`@,#$W-3<P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92].3%,`````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,"`P
M,3<W,30`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&%4<F5E
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,30P(#`R,#<U,0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O0VEP:&5R````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#`@,#(P-#<R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]24$,`````````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$T,"`P,3<W,#0`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-1
M3```````````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,30P(#`Q-S<Q-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O0G)O=W-E<@``````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#`@,#(P-S`S
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]%9&ET;W(`````````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T,"`P,C`U,#8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-A8VAE````````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30P(#`R,#(V,P`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VL`````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q-#`@
M,#(P,S$R`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H````
M````````````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$T,"`P,C`Q-C$`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+VE#86QE;F1A<@``````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30P(#`R,3$T,@`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54D`````````````````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q-#`@,#$W-3<U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M8VAE9'5L97(`````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$T,"`P,C$Q-S8`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TAE;'`N<&AP````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,V-3$W(#$P-3$U-#,T,30P(#`R,#<U
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J(%)A=R!H96QP(&EN('1H92!S=')I;F<N"B`J+PID969I
M;F4H)TA%3%!?4T]54D-%7U)!5R<L(#`I.PH*+RHJ"B`J($AE;'`@=&5X="!I
M<R!I;B!A(&9I;&4N"B`J+PID969I;F4H)TA%3%!?4T]54D-%7T9)3$4G+"`Q
M*3L*"B\J*@H@*B!4:&4@2&5L<#HZ(&-L87-S('!R;W9I9&5S(&%N(&EN=&5R
M9F%C92!T;R!T:&4@;VYL:6YE(&AE;'`@<W5B<WES=&5M+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R](;W)D92](;W)D92](96QP+G!H<"QV(#$N-C@N."XQ
M."`R,#`V+S`S+S`R(#`U.C(W.C,U('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO
M<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7T9R86UE=V]R:PH@*B\*8VQA<W,@2&5L<"!["@H@("`@+RHJ"B`@("`@
M*B!(86YD;&4@9F]R('1H92!834P@<&%R<V5R(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W!A<G-E<B`]
M(#`["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8G5F9F5R('1O(&AO;&0@=&AE
M(%A-3"!H96QP('-O=7)C92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]B=69F97(@/2`G)SL*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!C;VYT86EN:6YG('1H92!)1"!O9B!T:&4@<F5Q=65S=&5D(&AE
M;'`@96YT<GDN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?<F5Q16YT<GD@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN
M9R!C;VYT86EN:6YG('1H92!)1"!O9B!T:&4@8W5R<F5N="!H96QP(&5N=')Y
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7V-U<D5N=')Y(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I
M;FEN9R!T:&4@9F]R;6%T=&5D(&]U='!U="X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]O=71P=70@/2`G)SL*"B`@("`O
M*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('=E)W)E(&EN
M<VED92!A(#QH96QP/B!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?:6Y(96QP(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!W92=R92!I;G-I
M9&4@=&AE(')E<75E<W1E9"!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?:6Y";&]C:R`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=V4G<F4@
M:6YS:61E(&$@/'1I=&QE/B!B;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?:6Y4:71L92`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&%N(&EN9&5X(&]F(&%L;"!O
M9B!T:&4@:&5L<"!E;G1R:65S+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?96YT<FEE<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@8VAA<G-E="!O9B!T:&4@
M6$U,(&1A=&$@<V]U<F-E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7V-H87)S970@/2`G:7-O+3@X-3DM,2<["@H@("`@
M+RHJ"B`@("`@*B!(87-H(&]F('5S97(M9&5F:6YE9"!F=6YC=&EO;B!H86YD
M;&5R<R!F;W(@=&AE(%A-3"!E;&5M96YT<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VAA;F1L97)S(#T@87)R87DH"B`@
M("`@("`@)VAE;'`G("`@("`]/B`@)U]H96QP2&%N9&QE<B<L"B`@("`@("`@
M)V5N=')Y)R`@("`]/B`@)U]E;G1R>4AA;F1L97(G+`H@("`@("`@("=T:71L
M92<@("`@/3X@("=?=&ET;&5(86YD;&5R)RP*("`@("`@("`G:&5A9&EN9R<@
M(#T^("`G7VAE861I;F=(86YD;&5R)RP*("`@("`@("`G<&%R82<@("`@(#T^
M("`G7W!A<F%(86YD;&5R)RP*("`@("`@("`G<F5F)R`@("`@(#T^("`G7W)E
M9DAA;F1L97(G+`H@("`@("`@("=E<F5F)R`@("`@/3X@("=?97)E9DAA;F1L
M97(G+`H@("`@("`@("=H<F5F)R`@("`@/3X@("=?:')E9DAA;F1L97(G+`H@
M("`@("`@("=B)R`@("`@("`@/3X@("=?8DAA;F1L97(G+`H@("`@("`@("=I
M)R`@("`@("`@/3X@("=?:4AA;F1L97(G+`H@("`@("`@("=P<F4G("`@("`@
M/3X@("=?<')E2&%N9&QE<B<L"B`@("`@("`@)W1I<"<@("`@("`]/B`@)U]T
M:7!(86YD;&5R)RP*("`@("`@("`G=V%R;B<@("`@(#T^("`G7W=A<FY(86YD
M;&5R)PH@("`@*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-O=7)C92`@5&AE('-O=7)C92!O
M9B!T:&4@6$U,(&AE;'`@9&%T82P@8F%S960@;VX@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!(14Q07U-/55)#15\J(&-O;G-T86YT<RX*
M("`@("`J($!P87)A;2!S=')I;F<@)&%R9R`@("`@(%-O=7)C92UD97!E;F1E
M;G0@87)G=6UE;G0@9F]R('1H:7,@2&5L<`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N($AE
M;'`H)'-O=7)C92P@)&%R9R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L
M("1L86YG=6%G92P@)&YL<SL*"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)WAM;"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A0
M14%2.CIR86ES945R<F]R*"=4:&4@6$U,(&9U;F-T:6]N<R!A<F4@;F]T(&%V
M86EL86)L92X@4F5B=6EL9"!02%`@=VET:"`M+7=I=&@M>&UL+B<I+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?8VAA<G-E="`](&ES<V5T*"1N;'-;)V-H87)S971S)UU;)&QA;F=U
M86=E72D@/R`D;FQS6R=C:&%R<V5T<R==6R1L86YG=6%G95T@.B`G25-/+3@X
M-3DM,2<["@H@("`@("`@("\J(%!O<'5L871E("1T:&ES+3Y?8G5F9F5R(&)A
M<V5D(&]N("1S;W5R8V4N("HO"B`@("`@("`@<W=I=&-H("@D<V]U<F-E*2![
M"B`@("`@("`@8V%S92!(14Q07U-/55)#15]205<Z"B`@("`@("`@("`@("1T
M:&ES+3Y?8G5F9F5R(#T@)&%R9SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@2$5,4%]33U520T5?1DE,13H*("`@("`@("`@("`@:68@*$!F
M:6QE7V5X:7-T<R@D87)G6S!=*2`F)B!`9FEL97-I>F4H)&%R9ULP72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8G5F9F5R(#T@9FEL95]G971?8V]N
M=&5N=',H)&%R9ULP72D["B`@("`@("`@("`@('T@96QS96EF("A`9FEL95]E
M>&ES=',H)&%R9ULQ72D@)B8@0&9I;&5S:7IE*"1A<F=;,5TI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V)U9F9E<B`](&9I;&5?9V5T7V-O;G1E;G1S
M*"1A<F=;,5TI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]B=69F97(@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H
M:7,M/E]B=69F97(@/2`G)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!(5$U,(&QI
M;FL@=&AA="!W:6QL('!O<"!U<"!A(&AE;'`@=VEN9&]W(&9O<B!T:&4*("`@
M("`J(')E<75E<W1E9"!T;W!I8RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M;V1U;&4@(%1H92!N86UE(&]F('1H92!C=7)R96YT($AO<F1E(&UO
M9'5L92X*("`@("`J($!P87)A;2!S=')I;F<@)'1O<&EC("`@5&AE(&AE;'`@
M=&]P:6,@=&\@8F4@9&ES<&QA>65D+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@2%1-3"!T;R!C<F5A=&4@=&AE(&AE;'`@;&EN:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&EN:R@D;6]D=6QE+"`D=&]P:6,I"B`@("![
M"B`@("`@("`@9VQO8F%L("1C;VYF+"`D<F5G:7-T<GDL("1B<F]W<V5R.PH*
M("`@("`@("!I9B`H(4AO<F1E.CIS:&]W4V5R=FEC92@G:&5L<"<I*2!["B`@
M("`@("`@("`@(')E='5R;B`G)FYB<W`[)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=P;W!U<"YJ<R<L("=H
M;W)D92<I.PH@("`@("`@('T*"B`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH
M)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O<V5R=FEC
M97,O:&5L<"\G+"!T<G5E*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL(&%R<F%Y*"=M;V1U;&4G(#T^("1M;V1U;&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&]P
M:6,G(#T^("1T;W!I8RDI.PH@("`@("`@("1H=&UL(#T@2&]R9&4Z.FQI;FLH
M)'5R;"P@7R@B2&5L<"(I+"`G)RP@)VAO<F1E:&5L<'=I;B<L("=P;W!U<"AT
M:&ES+FAR968I.R!R971U<FX@9F%L<V4[)RD["@H@("`@("`@(')E='5R;B`D
M:'1M;"`N($AO<F1E.CII;6<H)VAE;'`N<&YG)RP@7R@B2&5L<"(I+"`G=VED
M=&@](C$V(B!H96EG:'0](C$V(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI("X@)SPO83XG.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE
M86YS('5P('1H92!(96QP(&-L87-S(')E<V]U<F-E<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P
M*"D*("`@('L*("`@("`@("`D=&AI<RT^7V)U9F9E<B`]("<G.PH@("`@("`@
M(')E='5R;B!X;6Q?<&%R<V5R7V9R964H)'1H:7,M/E]P87)S97(I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3&]O:W,@=7`@=&AE(')E<75E<W1E9"!E;G1R
M>2!I;B!T:&4@6$U,(&AE;'`@8G5F9F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&5N=')Y("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@96YT<GD@
M240N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO;VMU<"@D96YT<GDI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]O=71P=70@/2`G)SL*("`@("`@("`D=&AI<RT^
M7W)E<45N=')Y(#T@4W1R:6YG.CIU<'!E<B@D96YT<GDI.PH@("`@("`@(&EF
M("@A)'1H:7,M/E]P87)S97(I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET
M*"D["B`@("`@("`@?0H@("`@("`@('AM;%]P87)S92@D=&AI<RT^7W!A<G-E
M<BP@)'1H:7,M/E]B=69F97(L('1R=64I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(&AA<V@@;V8@86QL(&]F('1H92!T;W!I8W,@:6X@=&AI
M<R!H96QP(&)U9F9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!(
M87-H(&]F(&%L;"!O9B!T:&4@=&]P:6-S(&EN('1H:7,@8G5F9F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T;W!I8W,H*0H@("`@>PH@("`@("`@(&EF("@A
M)'1H:7,M/E]P87)S97(I('L*("`@("`@("`@("`@)'1H:7,M/E]I;FET*"D[
M"B`@("`@("`@?0H@("`@("`@('AM;%]P87)S92@D=&AI<RT^7W!A<G-E<BP@
M)'1H:7,M/E]B=69F97(L('1R=64I.PH*("`@("`@("!R971U<FX@)'1H:7,M
M/E]E;G1R:65S.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES<&QA>2!T:&4@
M8V]N=&5N=',@;V8@=&AE(&9O<FUA='1E9"!O=71P=70@8G5F9F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("!E8VAO
M("1T:&ES+3Y?;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&EA
M;'IE<R!T:&4@6$U,('!A<G-E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@
M=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?:6YI="@I"B`@("!["B`@("`@("`@+RH@0W)E871E(&$@
M;F5W('!A<G-E<B!A;F0@<V5T(&ET<R!D969A=6QT('!R;W!E<G1I97,N("HO
M"B`@("`@("`@)'1H:7,M/E]P87)S97(@/2!X;6Q?<&%R<V5R7V-R96%T92@I
M.PH@("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES+3Y?<&%R<V5R+"`D=&AI
M<RD["B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1T:&ES+3Y?<&%R
M<V5R+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH@("`@("`@
M('AM;%]S971?96QE;65N=%]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7W-T
M87)T16QE;65N="<L("=?96YD16QE;65N="<I.PH@("`@("`@('AM;%]S971?
M8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]D969A
M=6QT2&%N9&QE<B<I.PH*("`@("`@("!R971U<FX@*"1T:&ES+3Y?<&%R<V5R
M("$](#`I.PH@("`@?0H*("`@("\J*@H@("`@("H@57-E<BUD969I;F5D(&9U
M;F-T:6]N(&-A;&QB86-K(&9O<B!S=&%R="!E;&5M96YT<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T("1P87)S97(@($AA;F1L92!T;R!T:&4@<&%R<V5R(&EN<W1A;F-E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&ES
M(%A-3"!E;&5M96YT+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("!,
M:7-T(&]F('1H:7,@96QE;65N="=S(&%T=')I8G5T97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]S=&%R=$5L96UE;G0H)'!A<G-E<BP@)&YA;64L("1A='1R
M<RD*("`@('L*("`@("`@("`O*B!#86QL('1H92!A<W-I9VYE9"!H86YD;&5R
M(&9O<B!T:&ES(&5L96UE;G0L(&EF(&]N92!I<PH@("`@("`@("`J(&%V86EL
M86)L92X@*B\*("`@("`@("!I9B`H:6Y?87)R87DH)&YA;64L(&%R<F%Y7VME
M>7,H)'1H:7,M/E]H86YD;&5R<RDI*2!["B`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC*&%R<F%Y*"8D=&AI<RP@)'1H:7,M/E]H86YD;&5R<ULD;F%M95TI
M+"!T<G5E+"`D871T<G,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%5S97(M9&5F:6YE9"!F=6YC=&EO;B!C86QL8F%C:R!F;W(@96YD(&5L
M96UE;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!O8FIE8W0@)'!A<G-E<B`@2&%N9&QE('1O('1H92!P
M87)S97(@:6YS=&%N8V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M(%1H92!N86UE(&]F('1H:7,@6$U,(&5L96UE;G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]E;F1%;&5M96YT*"1P87)S97(L("1N86UE*0H@("`@>PH@("`@
M("`@("\J($-A;&P@=&AE(&%S<VEG;F5D(&AA;F1L97(@9F]R('1H:7,@96QE
M;65N="P@:68@;VYE(&ES(&%V86EL86)L92X@*B\*("`@("`@("!I9B`H:6Y?
M87)R87DH)&YA;64L(&%R<F%Y7VME>7,H)'1H:7,M/E]H86YD;&5R<RDI*2![
M"B`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RP@)'1H
M:7,M/E]H86YD;&5R<ULD;F%M95TI+"!F86QS92D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@57-E<BUD969I;F5D(&9U;F-T:6]N(&-A;&QB
M86-K(&9O<B!C:&%R86-T97(@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("1P87)S97(@
M($AA;F1L92!T;R!T:&4@<&%R<V5R(&EN<W1A;F-E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T82`@("!3=')I;F<@;V8@8VAA<F%C=&5R(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D969A=6QT2&%N9&QE<B@D<&%R<V5R+"`D
M9&%T82D*("`@('L*("`@("`@("`D9&%T82`](%-T<FEN9SHZ8V]N=F5R=$-H
M87)S970H)&1A=&$L('9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@
M)S(G+"`G/"<I(#\@)'1H:7,M/E]C:&%R<V5T(#H@)U541BTX)RD["B`@("`@
M("`@:68@*"1T:&ES+3Y?:6Y4:71L92D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V5N=')I97-;)'1H:7,M/E]C=7)%;G1R>5T@+CT@)&1A=&$["B`@("`@("`@
M?0H@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO
M8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@:'1M;'-P96-I
M86QC:&%R<R@D9&%T82D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QH96QP/B!T86<N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE
M=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A
M='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<R`H3F]T
M('5S960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&5L<$AA;F1L97(H)'-T
M87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:6Y(96QP(#T@)'-T87)T5&%G(#\@('1R=64@.B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\
M96YT<GD^('1A9RX*("`@("`J($%T=')I8G5T97,Z(&ED"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES
M(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@
M("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V5N=')Y2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"$D<W1A<G1486<I('L*("`@("`@
M("`@("`@)'1H:7,M/E]I;D)L;V-K(#T@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&ED(#T@4W1R:6YG.CIU<'!E<B@D871T<G-;)VED
M)UTI.PH@("`@("`@("`@("`D=&AI<RT^7V-U<D5N=')Y(#T@)&ED.PH@("`@
M("`@("`@("`D=&AI<RT^7V5N=')I97-;)&ED72`]("<G.PH@("`@("`@("`@
M("`D=&AI<RT^7VEN0FQO8VL@/2`H)&ED(#T]("1T:&ES+3Y?<F5Q16YT<GDI
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT
M(&AA;F1L97(@9F]R('1H92`\=&ET;&4^('1A9RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M<W1A<G1486<@($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS
M=&%N8V4@:7,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=&%R="!T86<N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')S("`@("`@($%D
M9&ET:6]N86P@96QE;65N="!A='1R:6)U=&5S("A.;W0@=7-E9"DN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]T:71L94AA;F1L97(H)'-T87)T5&%G+"`D871T
M<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6Y4:71L92`]
M("1S=&%R=%1A9SL*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@)'1H
M:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]
M("1S=&%R=%1A9R`_("<\:#$^)R`Z("<\+V@Q/B<["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE
M(#QH96%D:6YG/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L
M96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@
M("H@0'!A<F%M("!A<G)A>2`D871T<G,@("`@("!!9&1I=&EO;F%L(&5L96UE
M;G0@871T<FEB=71E<R`H3F]T('5S960I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?:&5A9&EN9TAA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^
M7VEN0FQO8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T
M87)T5&%G(#\@)SQH,CXG(#H@)SPO:#(^)SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/'!A
M<F$^('1A9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<W1A<G1486<@($)O;VQE86X@:6YD
M:6-A=&EN9R!W:&5T:&5R('1H:7,@:6YS=&%N8V4@:7,@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S=&%R="!T86<N"B`@("`@*B!`<&%R
M86T@87)R87D@)&%T=')S("`@("`@($%D9&ET:6]N86P@96QE;65N="!A='1R
M:6)U=&5S("A.;W0@=7-E9"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)A
M2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D<W1A<G1486<@/R`G
M/'`^)R`Z("<\+W`^)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!834P@96QE;65N="!H86YD;&5R(&9O<B!T:&4@/')E9CX@=&%G+@H@("`@
M("H@4F5Q=6ER960@871T<FEB=71E<SH@14Y44EDL($U/1%5,10H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@
M=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@
M("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]R969(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@)B8@
M)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@(&EF("@D<W1A<G1486<@
M)B8@:7-S970H)&%T=')S6R=M;V1U;&4G72D@)B8@:7-S970H)&%T=')S6R=E
M;G1R>2==*2D@>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A
M<F%M971E<BA(;W)D93HZ<V5L9E5R;"@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<VAO=R<@/3X@)V5N=')Y
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VUO9'5L92<@/3X@)&%T=')S6R=M;V1U;&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O<&EC
M)R`@/3X@)&%T=')S6R=E;G1R>2==*2D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V]U='!U="`N/2!(;W)D93HZ;&EN:R@D=7)L*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]("<\
M+V$^)SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\97)E9CX@=&%G
M+@H@("`@("H@4F5Q=6ER960@96QE;65N=',Z(%523`H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N
M("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@=&AI<R!I
M;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<G,@("`@("`@
M061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]E<F5F2&%N9&QE<B@D<W1A<G1486<L("1A='1R<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(96QP("8F("1T:&ES
M+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("!I9B`H)'-T87)T5&%G*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!(;W)D93HZ;&EN:R@D
M871T<G-;)W5R;"==+"!N=6QL+"`G)RP@)U]B;&%N:R<I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@
M)SPO83XG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QH<F5F/B!T
M86<N"B`@("`@*B!297%U:7)E9"!E;&5M96YT<SH@=7)L+"!A<'`N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE
M<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R
M<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7VAR969(86YD;&5R*"1S=&%R=%1A9RP@)&%T=')S
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I;DAE;'`@
M)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@(&EF("@D<W1A<G14
M86<I('L*("`@("`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@
M("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G
M=V5B<F]O="<L("1A='1R<ULG87!P)UTI("X@)R\G("X@)&%T=')S6R=U<FPG
M72D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!(;W)D93HZ
M;&EN:R@D=7)L+"!N=6QL+"`G)RP@)U]B;&%N:R<I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)SPO
M83XG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE("9L=#MB)F=T.R!T
M86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I
M;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E
M<R`H3F]T('5S960I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8DAA;F1L97(H
M)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@)SQS=')O;F<^
M)R`Z("<\+W-T<F]N9SXG.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`F;'0[:29G=#L@=&%G
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!B;V]L96%N("1S=&%R=%1A9R`@0F]O;&5A;B!I;F1I8V%T:6YG
M('=H971H97(@=&AI<R!I;G-T86YC92!I<R!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T87)T('1A9RX*("`@("`J($!P87)A;2!A<G)A
M>2`D871T<G,@("`@("`@061D:71I;VYA;"!E;&5M96YT(&%T=')I8G5T97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I2&%N9&QE<B@D<W1A<G1486<L("1A
M='1R<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?:6Y(
M96QP("8F("1T:&ES+3Y?:6Y";&]C:RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7V]U='!U="`N/2`D<W1A<G1486<@/R`G/&5M/B<@.B`G/"]E;3XG.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L
M97(@9F]R('1H92`F;'0[<')E)F=T.R!T86<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T
M87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A
M;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1A
M<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I
M=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W!R94AA;F1L97(H)'-T87)T5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN
M0FQO8VLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'-T87)T
M5&%G(#\@)SQP<F4^)R`Z("<\+W!R93XG.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%A-3"!E;&5M96YT(&AA;F1L97(@9F]R('1H92`\=&EP
M/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC
M871I;F<@=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB
M=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1I<$AA;F1L97(H)'-T87)T
M5&%G+"`D871T<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7VEN2&5L<"`F)B`D=&AI<RT^7VEN0FQO8VLI('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@)'-T87)T5&%G(#\@)SQE;2!C;&%S<STB:&5L
M<%1I<"(^)R`Z("<\+V5M/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@6$U,(&5L96UE;G0@:&%N9&QE<B!F;W(@=&AE(#QW87)N/B!T86<N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'-T87)T5&%G("!";V]L96%N(&EN9&EC871I;F<@
M=VAE=&AE<B!T:&ES(&EN<W1A;F-E(&ES(&$*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1A<G0@=&%G+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A='1R<R`@("`@("!!9&1I=&EO;F%L(&5L96UE;G0@871T<FEB=71E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W=A<FY(86YD;&5R*"1S=&%R=%1A9RP@
M)&%T=')S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]I
M;DAE;'`@)B8@)'1H:7,M/E]I;D)L;V-K*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T<'5T("X]("1S=&%R=%1A9R`_("<\96T@8VQA<W,](FAE;'!787)N
M(CXG(#H@)SPO96T^)SL*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]5=&EL+G!H<```````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V-S(V,2`Q,#4Q-30S-#$T,"`P
M,C$P,#$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"B\J*@H@*B!%<G)O<B!C;V1E(&9O<B!A(&UI<W-I;F<@9')I
M=F5R(&-O;F9I9W5R871I;VXN"B`J+PID969I;F4H)TA/4D1%7T524D]27T12
M259%4E]#3TY&24=?34E34TE.1R<L(#$I.PH*+RHJ"B`J($5R<F]R(&-O9&4@
M9F]R(&%N(&EN8V]M<&QE=&4@9')I=F5R(&-O;F9I9W5R871I;VXN"B`J+PID
M969I;F4H)TA/4D1%7T524D]27T12259%4E]#3TY&24<G+"`R*3L*"B\J*@H@
M*B!4:&4@571I;#HZ(&-L87-S('!R;W9I9&5S(&=E;F5R86QL>2!U<V5F=6P@
M;65T:&]D<R!O9B!D:69F97)E;G0@:VEN9',N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U5T:6PO571I;"YP:'`L=B`Q+C,X-"XV+C$W(#(P,#8O,#4O,#4@
M,38Z,#(Z,3(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M571I;`H@*B\*8VQA<W,@571I;"!["@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&%N(&]B:F5C="=S(&-L;VYE+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE
M8W0@)B1O8FH@(%1H92!O8FIE8W0@=&\@8VQO;F4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!O8FIE8W0@(%1H92!C;&]N960@;V)J96-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F8VQO;F5/8FIE8W0H)B1O8FHI"B`@("!["B`@("`@("`@
M+RH@0VQO;FEN9R!D;V5S("IN;W0J(&-U<G)E;G1L>2!W;W)K(&EF('5S:6YG
M(%!(4"`U+@H@("`@("`@("`J(%1H:7,@:7,@82!K;F]W;B!02%`@:7-S=64Z
M(&AT='`Z+R]B=6=S+G!H<"YN970O8G5G+G!H<#]I9#TR-S(V.`H@("`@("`@
M("`J(%1H97)E9F]R92P@=V]R:R!A<F]U;F0@=&AI<R!I<W-U92!B>2!U<VEN
M9R!T:&4@4$A0(#0*("`@("`@("`@*B!S97)I86QI>F4O=6YS97)I86QI>F4@
M8VQO;F4@:&%C:RX@*B\*("`@("`@("`O*@H@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H>F5N9%]V97)S:6]N*"DL("<R)RP@)SXG*2D@>PH@("`@("`@
M("`@("!R971U<FX@8VQO;F4H)&]B:BD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&YE=T]B:B`]("1O8FH["B`@("`@("`@("`@(')E='5R;B`D
M;F5W3V)J.PH@("`@("`@('T*("`@("`@("`J+PH@("`@("`@("1R970@/2!U
M;G-E<FEA;&EZ92AS97)I86QI>F4H)&]B:BDI.PH@("`@("`@(')E='5R;B`D
M<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5F9F5R<R!T:&4@;W5T<'5T
M(&9R;VT@82!F=6YC=&EO;B!C86QL+"!L:6ME(')E861F:6QE*"D@;W(*("`@
M("`J(&AI9VAL:6=H=%]S=')I;F<H*2P@=&AA="!P<FEN=',@=&AE(&]U='!U
M="!D:7)E8W1L>2P@<V\@=&AA="!I;G-T96%D(&ET"B`@("`@*B!C86X@8F4@
M<F5T=7)N960@87,@82!S=')I;F<@86YD('5S960N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9G5N8W1I;VX@(%1H92!F=6YC=&EO;B!T;R!R=6XN
M"B`@("`@*B!`<&%R86T@;6EX960@)&%R9S$@("`@("`@1FER<W0@87)G=6UE
M;G0@=&\@)&9U;F-T:6]N*"DN"B`@("`@*B!`<&%R86T@;6EX960@)&%R9S(@
M("`@("`@4V5C;VYD(&%R9W5M96YT('1O("1F=6YC=&EO;B@I+@H@("`@("H@
M0'!A<F%M(&UI>&5D("1A<F<N+BX@("`@("XN+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1A<F=.("`@("`@($YT:"!A<F=U;65N="!T;R`D9G5N8W1I;VXH*2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]U='!U="!O9B!T
M:&4@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U9F9E<D]U='!U
M="@I"B`@("!["B`@("`@("`@:68@*&9U;F-?;G5M7V%R9W,H*2`]/2`P*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M)&EN8VQU9&4@/2!F86QS93L*("`@("`@("`D87)G<R`](&9U;F-?9V5T7V%R
M9W,H*3L*("`@("`@("`D9G5N8W1I;VX@/2!A<G)A>5]S:&EF="@D87)G<RD[
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1F=6YC=&EO;BDI('L*("`@("`@("`@
M("`@:68@*"%I<U]C86QL86)L92@D9G5N8W1I;VXI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V5I9B`H*"1F=6YC=&EO;B`]/2`G:6YC;'5D92<I('Q\"B`@("`@("`@("`@
M("`@("`@("@D9G5N8W1I;VX@/3T@)VEN8VQU9&5?;VYC92<I('Q\"B`@("`@
M("`@("`@("`@("`@("@D9G5N8W1I;VX@/3T@)W)E<75I<F4G*2!\?`H@("`@
M("`@("`@("`@("`@("`H)&9U;F-T:6]N(#T]("=R97%U:7)E7V]N8V4G*2D@
M>PH@("`@("`@("`@("`D:6YC;'5D92`]('1R=64["B`@("`@("`@?2!E;'-E
M:68@*"%F=6YC=&EO;E]E>&ES=',H)&9U;F-T:6]N*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!O8E]S=&%R="@I
M.PH@("`@("`@(&EF("@D:6YC;'5D92D@>PH@("`@("`@("`@("`D9FEL92`]
M(&EM<&QO9&4H)RPG+"`D87)G<RD["B`@("`@("`@("`@('-W:71C:"`H)&9U
M;F-T:6]N*2!["B`@("`@("`@("`@(&-A<V4@)VEN8VQU9&4G.@H@("`@("`@
M("`@("`@("`@:6YC;'5D92`D9FEL93L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G:6YC;'5D95]O;F-E)SH*("`@("`@("`@
M("`@("`@(&EN8VQU9&5?;VYC92`D9FEL93L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G<F5Q=6ER92<Z"B`@("`@("`@("`@
M("`@("!R97%U:7)E("1F:6QE.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=R97%U:7)E7V]N8V4G.@H@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("1F:6QE.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8U]A<G)A>2@D9G5N8W1I;VXL("1A<F=S*3L*("`@("`@
M("!]"B`@("`@("`@)&]U='!U="`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@
M("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("!R971U<FX@)&]U='!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@:68@82!V86QU
M92!H87,@8F5E;B!S970@8GD@=&AE('-C<FEP="!A;F0@;F]T(&)Y($=%5"P*
M("`@("`J(%!/4U0L(&]R(&-O;VMI92!I;G!U="X@5&AE('9A;'5E(&)E:6YG
M(&-H96-K960@35535"!B92!I;B!T:&4@9VQO8F%L"B`@("`@*B!S8V]P92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87)N86UE("!4:&4@=F%R
M:6%B;&4@;F%M92!T;R!C:&5C:RX*("`@("`J($!P87)A;2!M:7AE9"`D9&5F
M875L="`@($1E9F%U;'0@=F%L=64@:68@=&AE('9A<FEA8FQE(&ES;B=T('!R
M97-E;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&]R('=A<R!S
M<&5C:69I960@8GD@=&AE('5S97(N($1E9F%U;'1S('1O(&YU;&PN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!`<VEN8V4@2&]R9&4@,RXQ"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@)&1E9F%U;'0@:68@=&AE('9A
M<B!I<R!I;B!U<V5R(&EN<'5T(&]R(&YO="!P<F5S96YT+`H@("`@("H@("`@
M("`@("`@("`@("`@=&AE('9A<FEA8FQE('9A;'5E(&]T:&5R=VES92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@;F]N26YP=71687(H)'9A<FYA;64L("1D969A
M=6QT(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]'151;)'9A
M<FYA;65=*2!\?`H@("`@("`@("`@("!I<W-E="@D7U!/4U1;)'9A<FYA;65=
M*2!\?`H@("`@("`@("`@("!I<W-E="@D7T-/3TM)15LD=F%R;F%M95TI*2![
M"B`@("`@("`@("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@:7-S970H)$=,3T)!3%-;)'9A<FYA;65=
M*2`_("1'3$]"04Q36R1V87)N86UE72`Z("1D969A=6QT.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!N86UE/79A;'5E('!A:7(@
M=&\@=&AE(&5N9"!O9B!A;B!54DPL('1A:VEN9R!C87)E(&]F('=H971H97(*
M("`@("`J('1H97)E(&%R92!E>&ES=&EN9R!P87)A;65T97)S(&%N9"!W:&5T
M:&5R('1O('5S92`_+"`F(&]R("9A;7`[(&%S('1H90H@("`@("H@9VQU92X@
M($%L;"!D871A('=I;&P@8F4@=7)L96YC;V1E9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<FP@("`@("`@5&AE(%523"!T;R!M;V1I9GD*("`@
M("`J($!P87)A;2!M:7AE9"`D<&%R86UE=&5R("!%:71H97(@=&AE(&YA;64]
M=F%L=64@<&%I<B!T;R!A9&0*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`H1$504D5#051%1"D@+6]R+0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@('1H92!N86UE('9A;'5E("UO<BT*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!A;B!A<G)A>2!O9B!N86UE+W9A;'5E('!A:7)S
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("`@($EF('-P96-I9FEE
M9"P@=&AE('9A;'5E('!A<G0@*"1P87)A;65T97(@:7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&5N(&%S<W5M960@=&\@:G5S="!B92!T
M:&4@<&%R86UE=&5R(&YA;64I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&5N
M8V]D92`@($EF('1R=64L(&%N9"!W92!D;VXG="!H879E(&%R9W5M96YT('-E
M<&%R871O<G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!Y970L
M('1H92!A<F=U;65N="!S97!A<F%T;W(@9V5T<R!E;F-O9&5D+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@55),+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1087)A;65T97(H)'5R;"P@)'!A<F%M971E
M<BP@)'9A;'5E(#T@;G5L;"P@)&5N8V]D92`]('1R=64I"B`@("!["B`@("`@
M("`@<W1A=&EC("1T<F%N<VQA=&EO;E]T86)L93L*"B`@("`@("`@:68@*"%I
M<W-E="@D=')A;G-L871I;VY?=&%B;&4I*2!["B`@("`@("`@("`@("1T<F%N
M<VQA=&EO;E]T86)L92`](&%R<F%Y7V9L:7`H9V5T7VAT;6Q?=')A;G-L871I
M;VY?=&%B;&4H2%1-3%]%3E1)5$E%4RDI.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)'!A<F%M971E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1U
M<FP["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=&\@:&%V92!A
M;B!A<G)A>2X@*B\*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;65T97(I
M*2!["B`@("`@("`@("`@("1A9&0@/2!A<G)A>2@D<&%R86UE=&5R(#T^("1V
M86QU92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%D9"`]("1P
M87)A;65T97(["B`@("`@("`@?0H*("`@("`@("`D87)G(#T@)&5N8V]D92`_
M("<F86UP.R<@.B`G)B<["B`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1U
M<FPL("<_)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D9VQU92`]("<_
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#:&5C:R!I9B!T
M:&4@87)G=6UE;G0@<V5P87)A=&]R(&AA<R!B965N(&%L<F5A9'D*("`@("`@
M("`@("`@("H@:'1M;&5N=&ET:65S+6EZ960@:6X@=&AE(%523"X@*B\*("`@
M("`@("`@("`@)'%U97)Y(#T@<W5B<W1R*"1U<FPL("1P;W,@*R`Q*3L*("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\]+BH_)F%M<#LN*C\]+R<L("1Q
M=65R>2DI('L*("`@("`@("`@("`@("`@("1A<F<@/2`G)F%M<#LG.PH@("`@
M("`@("`@("`@("`@)'%U97)Y(#T@<W1R='(H)'%U97)Y+"`D=')A;G-L871I
M;VY?=&%B;&4I.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G
M+STN*C\F+BH_/2\G+"`D<75E<GDI*2!["B`@("`@("`@("`@("`@("`D87)G
M(#T@)R8G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P86ER<R`](&5X
M<&QO9&4H)&%R9RP@)'%U97)Y*3L*("`@("`@("`@("`@)'!A<F%M<R`](&%R
M<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1P86ER<R!A<R`D<&%I<BD@
M>PH@("`@("`@("`@("`@("`@)'!A:7(@/2!E>'!L;V1E*"<])RP@)'!A:7(L
M(#(I.PH@("`@("`@("`@("`@("`@)'!A<F%M<ULD<&%I<ELP75T@/2!C;W5N
M="@D<&%I<BD@/3T@,B`_("1P86ER6S%=(#H@)R<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&=L=64@/2`D87)G.PH@("`@("`@('T*"B`@("`@("`@
M)'5R;%]P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1A9&0@
M87,@)'!A<F%M971E<B`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@*"%I
M<W-E="@D<&%R86US6R1P87)A;65T97)=*2D@>PH@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=F%L=64@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=7)L7W!A<F%M<UM=(#T@=7)L96YC;V1E*"1P87)A;65T97(I("X@
M)UM=/2<@+B!U<FQE;F-O9&4H)'9A;"D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=7)L7W!A<F%M<UM=(#T@=7)L96YC;V1E*"1P87)A;65T97(I("X@)STG
M("X@=7)L96YC;V1E*"1V86QU92D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D=7)L7W!A
M<F%M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1U<FP@+B`D9VQU92`N(&EM
M<&QO9&4H)&%R9RP@)'5R;%]P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;6]V97,@;F%M93UV86QU92!P86ER<R!F<F]M(&$@55),
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("!4:&4@55),
M('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!M:7AE9"`D<F5M;W9E("!%:71H
M97(@82!S:6YG;&4@<&%R86UE=&5R('1O(')E;6]V92!O<B!A;B!A<G)A>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]F('!A<F%M971E<G,@=&\@
M<F5M;W9E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@55),+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5087)A;65T
M97(H)'5R;"P@)')E;6]V92D*("`@('L*("`@("`@("!S=&%T:6,@)'1R86YS
M;&%T:6]N7W1A8FQE.PH*("`@("`@("!I9B`H(6ES<V5T*"1T<F%N<VQA=&EO
M;E]T86)L92DI('L*("`@("`@("`@("`@)'1R86YS;&%T:6]N7W1A8FQE(#T@
M87)R87E?9FQI<"AG971?:'1M;%]T<F%N<VQA=&EO;E]T86)L92A(5$U,7T5.
M5$E42453*2D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?87)R87DH)')E
M;6]V92DI('L*("`@("`@("`@("`@)')E;6]V92`](&%R<F%Y*"1R96UO=F4I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&EM;65D:6%T96QY(&EF
M('1H97)E(&%R92!N;R!P87)A;65T97)S('1O(')E;6]V92X@*B\*("`@("`@
M("!I9B`H*"1P;W,@/2!S=')P;W,H)'5R;"P@)S\G*2D@/3T](&9A;'-E*2![
M"B`@("`@("`@("`@(')E='5R;B`D=7)L.PH@("`@("`@('T*"B`@("`@("`@
M)&5N=&ET:65S(#T@9F%L<V4["B`@("`@("`@;&ES="@D=7)L+"`D<75E<GDI
M(#T@97AP;&]D92@G/R<L("1U<FPL(#(I.PH*("`@("`@("`O*B!#:&5C:R!I
M9B!T:&4@87)G=6UE;G0@<V5P87)A=&]R(&AA<R!B965N(&%L<F5A9'D*("`@
M("`@("`@*B!H=&UL96YT:71I97,M:7IE9"!I;B!T:&4@55),+B`J+PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O/2XJ/R9A;7`[+BH_/2\G+"`D<75E<GDI
M*2!["B`@("`@("`@("`@("1E;G1I=&EE<R`]('1R=64["B`@("`@("`@("`@
M("1Q=65R>2`]('-T<G1R*"1Q=65R>2P@)'1R86YS;&%T:6]N7W1A8FQE*3L*
M("`@("`@("!]"@H@("`@("`@("\J($=E="!T:&4@;&ES="!O9B!P87)A;65T
M97)S+B`J+PH@("`@("`@("1P86ER<R`](&5X<&QO9&4H)R8G+"`D<75E<GDI
M.PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@
M*"1P86ER<R!A<R`D<&%I<BD@>PH@("`@("`@("`@("`D<&%I<B`](&5X<&QO
M9&4H)STG+"`D<&%I<BP@,BD["B`@("`@("`@("`@("1P87)A;7-;)'!A:7);
M,%U=(#T@8V]U;G0H)'!A:7(I(#T](#(@/R`D<&%I<ELQ72`Z("<G.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4F5M;W9E('1H92!P87)A;65T97)S+B`J+PH@
M("`@("`@(&9O<F5A8V@@*"1R96UO=F4@87,@)'!A<F%M*2!["B`@("`@("`@
M("`@('5N<V5T*"1P87)A;7-;)'!A<F%M72D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6-O=6YT*"1P87)A;7,I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=7)L.PH@("`@("`@('T*"B`@("`@("`@+RH@1FQA='1E;B!A<G)A>7,N"B`@
M("`@("`@("H@1DE8344Z('-H;W5L9"!H86YD;&4@;6]R92!T:&%N(&]N92!A
M<G)A>2!L979E;"!S;VUE:&]W+B`J+PH@("`@("`@("1A9&0@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'9A;"!A<R`D=BD@>PH@("`@("`@("`@("`@("`@
M("`@("1A9&1;72`]("1K97D@+B`G6UT])R`N("1V.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%D
M9%M=(#T@)&ME>2`N("<])R`N("1V86P["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1Q=65R>2`](&EM<&QO9&4H)R8G+"`D861D*3L*("`@
M("`@("!I9B`H)&5N=&ET:65S*2!["B`@("`@("`@("`@("1Q=65R>2`](&AT
M;6QE;G1I=&EE<R@D<75E<GDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1U<FP@+B`G/R<@+B`D<75E<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@=7)L('=I=&@@=&AE("=N;V-A8VAE)R!P87)A;65T97(@861D
M960L(&EF('1H92!B<F]W<V5R(&ES"B`@("`@*B!B=6=G>2!A;F0@8V%C:&5S
M(&]L9"!54DQS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@
M5&AE(%523"!T;R!M;V1I9GDN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R97%U97-T960@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!N
M;V-A8VAE57)L*"1U<FPI"B`@("!["B`@("`@("`@<W1A=&EC("1R86YD7VYU
M;3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"<F]W<V5R+G!H<"<[
M"B`@("`@("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["@H@
M("`@("`@("\J(%=E(&UA>2!N965D('1O('-E="!A(&1U;6UY('!A<F%M971E
M<B`G;F]C86-H92<@<VEN8V4@<V]M90H@("`@("`@("`J(&)R;W=S97)S(&1O
M(&YO="!A;'=A>7,@:&]N;W(@=&AE("=N;RUC86-H92<@:&5A9&5R+B`J+PH@
M("`@("`@(&EF("@D8G)O=W-E<BT^:&%S475I<FLH)V-A8VAE7W-A;65?=7)L
M)RDI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D<F%N9%]N=6TI*2!["B`@
M("`@("`@("`@("`@("`D<F%N9%]N=6T@/2!B87-E7V-O;G9E<G0H;6EC<F]T
M:6UE*"DL(#$P+"`S-BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T
M=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`G;F]C86-H92<L("1R86YD
M7VYU;2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1U
M<FP["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&AI9&1E;B!F;W)M(&EN<'5T(&-O;G1A:6YI;F<@=&AE('-E<W-I;VX@;F%M
M92!A;F0@:60N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%P<&5N
M9%]S97-S:6]N("`P(#T@;VYL>2!I9B!N965D960L(#$@/2!A;'=A>7,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!H:61D96X@9F]R;2!I
M;G!U="P@:68@;F5E9&5D+W)E<75E<W1E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9F]R;4EN<'5T*"1A<'!E;F1?<V5S<VEO;B`](#`I"B`@("!["B`@("`@
M("`@:68@*"1A<'!E;F1?<V5S<VEO;B`]/2`Q('Q\"B`@("`@("`@("`@("%I
M<W-E="@D7T-/3TM)15MS97-S:6]N7VYA;64H*5TI*2!["B`@("`@("`@("`@
M(')E='5R;B`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N(&AT;6QS
M<&5C:6%L8VAA<G,H<V5S<VEO;E]N86UE*"DI("X@)R(@=F%L=64](B<@+B!H
M=&UL<W!E8VEA;&-H87)S*'-E<W-I;VY?:60H*2D@+B`B7"(@+SY<;B(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%!R:6YT<R!A(&AI9&1E;B!F;W)M
M(&EN<'5T(&-O;G1A:6YI;F<@=&AE('-E<W-I;VX@;F%M92!A;F0@:60N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%P<&5N9%]S97-S:6]N("`P
M(#T@;VYL>2!I9B!N965D960L(#$@/2!A;'=A>7,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!F;W)M26YP=70H)&%P<&5N9%]S97-S:6]N(#T@,"D*("`@('L*
M("`@("`@("!E8VAO(%5T:6PZ.F9O<FU);G!U="@D87!P96YD7W-E<W-I;VXI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@268@;6%G:6-?<75O=&5S7V=P8R!I
M<R!I;B!U<V4L(')U;B!S=')I<'-L87-H97,H*2!O;B`D=F%R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)B1V87(@(%1H92!S=')I;F<@=&\@=6XM
M<75O=&4L(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@)'9A<BP@;6EN=7,@86YY(&UA9VEC('%U;W1E<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&ES<&5L36%G:6-1=6]T97,H)B1V87(I"B`@("!["B`@
M("`@("`@<W1A=&EC("1M86=I8U]Q=6]T97,["@H@("`@("`@(&EF("@A:7-S
M970H)&UA9VEC7W%U;W1E<RDI('L*("`@("`@("`@("`@)&UA9VEC7W%U;W1E
M<R`](&=E=%]M86=I8U]Q=6]T97-?9W!C*"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&UA9VEC7W%U;W1E<RD@>PH@("`@("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1V87(I*2!["B`@("`@("`@("`@("`@("`D=F%R(#T@<W1R:7!S;&%S
M:&5S*"1V87(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@87)R87E?=V%L:R@D=F%R+"!A<G)A>2@G571I;"<L("=D:7-P96Q-86=I
M8U%U;W1E<R<I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1V87(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S(&$@9F]R
M;2!V87)I86)L92!F<F]M($=%5"!O<B!03U-4(&1A=&$L('-T<FEP<&5D(&]F
M(&UA9VEC('%U;W1E<R!I9@H@("`@("H@;F5C97-S87)Y+B!)9B!T:&4@=F%R
M:6%B;&4@:7,@<V]M96AO=R!S970@:6X@8F]T:"!T:&4@1T54(&1A=&$@86YD
M('1H90H@("`@("H@4$]35"!D871A+"!T:&4@=F%L=64@9G)O;2!T:&4@4$]3
M5"!D871A('=I;&P@8F4@<F5T=7)N960@86YD('1H92!'150*("`@("`J('9A
M;'5E('=I;&P@8F4@:6=N;W)E9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1V87(@("`@("!4:&4@;F%M92!O9B!T:&4@9F]R;2!V87)I86)L92!T
M;R!L;V]K(&9O<BX*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@(%1H
M92!V86QU92!T;R!R971U<FX@:68@=&AE('9A<FEA8FQE(&ES(&YO=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AE<F4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!C;&5A;F5D(&9O<FT@=F%R:6%B;&4L
M(&]R("1D969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&;W)M1&%T
M82@D=F%R+"`D9&5F875L="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N
M("@H)'9A;"`](%5T:6PZ.F=E=%!O<W0H)'9A<BDI("$]/2!N=6QL*0H@("`@
M("`@("`@("`_("1V86P@.B!5=&EL.CIG971'970H)'9A<BP@)&1E9F%U;'0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!A(&9O<FT@=F%R:6%B;&4@
M9G)O;2!'150@9&%T82P@<W1R:7!P960@;V8@;6%G:6,@<75O=&5S(&EF"B`@
M("`@*B!N96-E<W-A<GDN(%1H:7,@9G5N8W1I;VX@=VEL;"!.3U0@<F5T=7)N
M(&$@4$]35"!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1V87(@("`@("!4:&4@;F%M92!O9B!T:&4@9F]R;2!V87)I86)L92!T;R!L
M;V]K(&9O<BX*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@(%1H92!V
M86QU92!T;R!R971U<FX@:68@=&AE('9A<FEA8FQE(&ES(&YO=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE<F4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!C;&5A;F5D(&9O<FT@=F%R:6%B;&4L(&]R
M("1D969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'970H)'9A<BP@
M)&1E9F%U;'0@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-S970H
M)%]'151;)'9A<ETI*0H@("`@("`@("`@("`_(%5T:6PZ.F1I<W!E;$UA9VEC
M475O=&5S*"1?1T546R1V87)=*0H@("`@("`@("`@("`Z("1D969A=6QT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!A(&9O<FT@=F%R:6%B;&4@9G)O
M;2!03U-4(&1A=&$L('-T<FEP<&5D(&]F(&UA9VEC('%U;W1E<R!I9@H@("`@
M("H@;F5C97-S87)Y+B!4:&ES(&9U;F-T:6]N('=I;&P@3D]4(')E='5R;B!A
M($=%5"!V87)I86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V
M87(@("`@("!4:&4@;F%M92!O9B!T:&4@9F]R;2!V87)I86)L92!T;R!L;V]K
M(&9O<BX*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'0@(%1H92!V86QU
M92!T;R!R971U<FX@:68@=&AE('9A<FEA8FQE(&ES(&YO=`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE<F4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!C;&5A;F5D(&9O<FT@=F%R:6%B;&4L(&]R("1D
M969A=6QT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710;W-T*"1V87(L("1D
M969A=6QT(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@*&ES<V5T*"1?
M4$]35%LD=F%R72DI"B`@("`@("`@("`@(#\@571I;#HZ9&ES<&5L36%G:6-1
M=6]T97,H)%]03U-46R1V87)=*0H@("`@("`@("`@("`Z("1D969A=6QT.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;&]C871I;VX@
M;V8@=&AE('-Y<W1E;2!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!!(&1I<F5C=&]R>2!N86UE('=H:6-H(&-A
M;B!B92!U<V5D(&9O<B!T96UP(&9I;&5S+@H@("`@("H@("`@("`@("`@("`@
M("`@(%)E='5R;G,@9F%L<V4@:68@;VYE(&-O=6QD(&YO="!B92!F;W5N9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$1I<B@I"B`@("!["B`@("`@
M("`@+RH@1FER<W0L('1R>2!02%`G<R!U<&QO861?=&UP7V1I<B!D:7)E8W1I
M=F4N("HO"B`@("`@("`@)'1M<"`](&EN:5]G970H)W5P;&]A9%]T;7!?9&ER
M)RD["@H@("`@("`@("\J($]T:&5R=VES92P@=')Y('1O(&1E=&5R;6EN92!T
M:&4@5$U01$E2(&5N=FER;VYM96YT"B`@("`@("`@("H@=F%R:6%B;&4N("HO
M"B`@("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@("1T;7`@
M/2!G971E;G8H)U1-4$1)4B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@
M=V4@<W1I;&P@8V%N;F]T(&1E=&5R;6EN92!A('9A;'5E+"!T:&5N(&-Y8VQE
M('1H<F]U9V@@80H@("`@("`@("`J(&QI<W0@;V8@<')E<V5T('!O<W-I8FEL
M:71I97,N("HO"B`@("`@("`@)'1M<%]L;V-A=&EO;G,@/2!A<G)A>2@G+W1M
M<"<L("<O=F%R+W1M<"<L("=C.EQ7551E;7`G+"`G8SI<=&5M<"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G8SI<=VEN9&]W<UQT96UP)RP@
M)V,Z7'=I;FYT7'1E;7`G*3L*("`@("`@("!W:&EL92`H96UP='DH)'1M<"D@
M)B8@8V]U;G0H)'1M<%]L;V-A=&EO;G,I*2!["B`@("`@("`@("`@("1T;7!?
M8VAE8VL@/2!A<G)A>5]S:&EF="@D=&UP7VQO8V%T:6]N<RD["B`@("`@("`@
M("`@(&EF("A`:7-?9&ER*"1T;7!?8VAE8VLI*2!["B`@("`@("`@("`@("`@
M("`D=&UP(#T@)'1M<%]C:&5C:SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@268@:70@:7,@<W1I;&P@96UP='DL('=E(&AA=F4@9F%I
M;&5D+"!S;R!R971U<FX@9F%L<V4["B`@("`@("`@("H@;W1H97)W:7-E(')E
M='5R;B!T:&4@9&ER96-T;W)Y(&1E=&5R;6EN960N("HO"B`@("`@("`@<F5T
M=7)N(&5M<'1Y*"1T;7`I(#\@9F%L<V4@.B`D=&UP.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A('1E;7!O<F%R>2!F:6QE;F%M92!F;W(@=&AE
M(&QI9F5T:6UE(&]F('1H92!S8W)I<'0L(&%N9`H@("`@("H@*&]P=&EO;F%L
M;'DI(')E9VES=&5R(&ET('1O(&)E(&1E;&5T960@870@<F5Q=65S="!S:'5T
M9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F:7@@("!0
M<F5F:7@@=&\@;6%K92!T:&4@=&5M<&]R87)Y(&YA;64@;6]R90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5C;V=N:7IA8FQE+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1E;&5T92`@1&5L971E('1H92!F:6QE(&%T('1H
M92!E;F0@;V8@=&AE(')E<75E<W0_"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M:7(@("`@("!$:7)E8W1O<GD@=&\@8W)E871E('1H92!T96UP;W)A<GD@9FEL
M92!I;BX*("`@("`J($!P87)A;2!B;V]L96%N("1S96-U<F4@($EF(&1E;&5T
M:6YG(&9I;&4L('-H;W5L9"!W92!S96-U<F5L>2!D96QE=&4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE/PH@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`@4F5T=7)N<R!T:&4@9G5L;"!P871H+6YA;64@
M=&\@=&AE('1E;7!O<F%R>2!F:6QE+@H@("`@("H@("`@("`@("`@("`@("`@
M("!2971U<FYS(&9A;'-E(&EF(&$@=&5M<"!F:6QE(&-O=6QD(&YO="!B92!C
M<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971496UP1FEL92@D<')E
M9FEX(#T@)R<L("1D96QE=&4@/2!T<G5E+"`D9&ER(#T@)R<L("1S96-U<F4@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&1I<BD@?'P@(6ES
M7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("`D=&UP7V1I<B`](%5T:6PZ.F=E
M=%1E;7!$:7(H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&UP
M7V1I<B`]("1D:7(["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1M
M<%]D:7(I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1T;7!?9FEL92`]('1E;7!N86TH)'1M<%]D:7(L("1P<F5F
M:7@I.PH*("`@("`@("`O*B!)9B!T:&4@9FEL92!W87,@8W)E871E9"P@=&AE
M;B!R96=I<W1E<B!I="!F;W(@9&5L971I;VX@86YD(')E='5R;B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D=&UP7V9I;&4I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&1E
M;&5T92D@>PH@("`@("`@("`@("`@("`@571I;#HZ9&5L971E0713:'5T9&]W
M;B@D=&UP7V9I;&4L('1R=64L("1S96-U<F4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D=&UP7V9I;&4["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A('1E;7!O<F%R>2!D:7)E8W1O<GD@
M:6X@=&AE('-Y<W1E;2=S('1E;7!O<F%R>2!D:7)E8W1O<GDN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&1E;&5T92`@($1E;&5T92!T:&4@=&5M
M<&]R87)Y(&1I<F5C=&]R>2!A="!T:&4@96YD(&]F"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AE(')E<75E<W0_"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T96UP7V1I<B`@57-E('1H:7,@=&5M<&]R87)Y(&1I<F5C=&]R
M>2!A<R!T:&4@9&ER96-T;W)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=VAE<F4@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GD@=VEL;"!B92!C
M<F5A=&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%T
M:&YA;64@=&\@=&AE(&YE=R!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("H@
M("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@9&ER96-T;W)Y(&YO
M="!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5496UP1&ER
M*"1D96QE=&4@/2!T<G5E+"`D=&5M<%]D:7(@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1T96UP7V1I<BDI('L*("`@("`@("`@("`@)'1E
M;7!?9&ER(#T@571I;#HZ9V5T5&5M<$1I<B@I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&5M<'1Y*"1T96UP7V1I<BDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H92!F:7)S="`X
M(&-H87)A8W1E<G,@;V8@82!R86YD;VT@<W1R:6YG('1O('5S92!A<R!A('1E
M;7!O<F%R>0H@("`@("`@("`@(&1I<F5C=&]R>2!N86UE+B`J+PH@("`@("`@
M(&1O('L*("`@("`@("`@("`@)'1E;7!?9&ER("X]("<O)R`N('-U8G-T<BAB
M87-E7V-O;G9E<G0H;71?<F%N9"@I("X@;6EC<F]T:6UE*"DL(#$P+"`S-BDL
M(#`L(#@I.PH@("`@("`@('T@=VAI;&4@*&9I;&5?97AI<W1S*"1T96UP7V1I
M<BDI.PH*("`@("`@("`D;VQD7W5M87-K(#T@=6UA<VLH,#`P,"D["B`@("`@
M("`@:68@*"%M:V1I<B@D=&5M<%]D:7(L(#`W,#`I*2!["B`@("`@("`@("`@
M("1T96UP7V1I<B`](&9A;'-E.PH@("`@("`@('T@96QS96EF("@D9&5L971E
M*2!["B`@("`@("`@("`@(%5T:6PZ.F1E;&5T94%T4VAU=&1O=VXH)'1E;7!?
M9&ER*3L*("`@("`@("!]"B`@("`@("`@=6UA<VLH)&]L9%]U;6%S:RD["@H@
M("`@("`@(')E='5R;B`D=&5M<%]D:7(["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!C86YO;FEC86P@<&%T:"!O9B!T:&4@<W1R:6YG+B`@
M3&EK92!02%`G<R!B=6EL="UI;@H@("`@("H@<F5A;'!A=&@H*2!E>&-E<'0@
M=&AE(&1I<F5C=&]R>2!N965D(&YO="!E>&ES="!O;B!T:&4@;&]C86P@<V5R
M=F5R+@H@("`@("H*("`@("`J($%L9V]R:71H:6T@;&]O<V5L>2!B87-E9"!O
M;B!C;V1E(&9R;VT@=&AE(%!E<FP@1FEL93HZ4W!E8SHZ56YI>"!M;V1U;&4*
M("`@("`J("AV97)S:6]N(#$N-2DN"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,"XU"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M02!F:6QE('!A=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C86YO;FEC86QI>F5D(&9I;&4@<&%T:"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A;%!A=&@H)'!A=&@I"B`@("!["B`@("`@("`@+RH@4W1A;F1A<F1I
M>F4@;VX@54Y)6"!D:7)E8W1O<GD@<V5P87)A=&]R<RX@*B\*("`@("`@("!I
M9B`H<W5B<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<I('L*("`@("`@("`@
M("`@)'!A=&@@/2!S=')?<F5P;&%C92@G7%PG+"`G+R<L("1P871H*3L*("`@
M("`@("!]"@H@("`@("`@("\J('AX+R\O+WAX("T^('AX+WAX"B`@("`@("`@
M("H@>'@O+B\N+WAX("T^('AX+WAX("HO"B`@("`@("`@)'!A=&@@/2!P<F5G
M7W)E<&QA8V4H87)R87DH(GPO*WPB+"`B0"@O7"XI*R@O?%Q:*#\A7&XI*4`B
M*2P@87)R87DH)R\G+"`G+R<I+"`D<&%T:"D["@H@("`@("`@("\J("XO>'@@
M+3X@>'@@*B\*("`@("`@("!I9B`H)'!A=&@@(3T@)RXO)RD@>PH@("`@("`@
M("`@("`D<&%T:"`]('!R96=?<F5P;&%C92@B?%XH7"XO*2M\(BP@)R<L("1P
M871H*3L*("`@("`@("!]"@H@("`@("`@("\J("\N+B\N+B]X>"`M/B!X>"`J
M+PH@("`@("`@("1P871H(#T@<')E9U]R97!L86-E*")\7B\H7"Y<+B\_*2M\
M(BP@)R\G+"`D<&%T:"D["@H@("`@("`@("\J('AX+R`M/B!X>"`J+PH@("`@
M("`@(&EF("@D<&%T:"`A/2`G+R<I('L*("`@("`@("`@("`@)'!A=&@@/2!P
M<F5G7W)E<&QA8V4H(GPO7%HH/R%<;BE\(BP@)R<L("1P871H*3L*("`@("`@
M("!]"@H@("`@("`@("\J("]X>"\N+B`M/B`O("HO"B`@("`@("`@=VAI;&4@
M*'-T<G!O<R@D<&%T:"P@)R\N+B<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`D<&%T:"`]('!R96=?<F5P;&%C92@B?"];7B]=*R]<+EPN?"(L("<G+"`D
M<&%T:"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@96UP='DH)'!A=&@I
M(#\@)R\G(#H@)'!A=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S
M(&=I=F5N(&5L96UE;G1S(&%T(')E<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@
M("`@("H@268@8V%L;&5D('=I=&@@82!F:6QE;F%M92!W:6QL(&1E;&5T92!T
M:&%T(&9I;&4@870@<F5Q=65S="!S:'5T9&]W;CL@:68*("`@("`J(&-A;&QE
M9"!W:71H(&$@9&ER96-T;W)Y('=I;&P@<F5M;W9E('1H870@9&ER96-T;W)Y
M(&%N9"!A;&P@9FEL97,@:6X@=&AA=`H@("`@("H@9&ER96-T;W)Y(&%T(')E
M<75E<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@268@8V%L;&5D('=I=&@@
M;F\@87)G=6UE;G1S+"!R971U<FX@86QL(&5L96UE;G1S('1O(&)E(&1E;&5T
M960@*'1H:7,*("`@("`J('-H;W5L9"!O;FQY(&)E(&1O;F4@8GD@571I;#HZ
M7V1E;&5T94%T4VAU=&1O=VXI+@H@("`@("H*("`@("`J(%1H92!F:7)S="!T
M:6UE(&ET(&ES(&-A;&QE9"P@:70@:6YI=&EA;&EZ97,@=&AE(&%R<F%Y(&%N
M9"!R96=I<W1E<G,*("`@("`J(%5T:6PZ.E]D96QE=&5!=%-H=71D;W=N*"D@
M87,@82!S:'5T9&]W;B!F=6YC=&EO;B`M(&YO(&YE960@=&\@9&\@<V\*("`@
M("`J(&UA;G5A;&QY+@H@("`@("H*("`@("`J(%1H92!S96-O;F0@<&%R86UE
M=&5R(&%L;&]W<R!T:&4@=6YR96=I<W1E<FEN9R!O9B!P<F5V:6]U<VQY(')E
M9VES=&5R960*("`@("`J(&5L96UE;G1S+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&9I;&5N86UE("`@5&AE(&9I;&5N86UE('1O(&)E(&1E;&5T
M960@870@=&AE(&5N9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5Q=65S="X*("`@("`J($!P87)A;2!B;V]L96%N("1R96=I
M<W1E<B`@268@=')U92P@=&AE;B!R96=I<W1E<B!T:&4@96QE;65N="!F;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5L971I;VXL(&]T
M:&5R=VES92P@=6YR96=I<W1E<B!I="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1S96-U<F4@("`@268@9&5L971I;F<@9FEL92P@<VAO=6QD('=E('-E8W5R
M96QY(&1E;&5T90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@9FEL93\*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E0713:'5T9&]W
M;B@D9FEL96YA;64@/2!F86QS92P@)')E9VES=&5R(#T@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-E8W5R92`](&9A;'-E*0H@("`@
M>PH@("`@("`@('-T871I8R`D9&ER<RP@)&9I;&5S+"`D<V5C=7)E9&5L.PH*
M("`@("`@("`O*B!);FET:6%L:7IA=&EO;B!O9B!V87)I86)L97,@86YD('-H
M=71D;W=N(&9U;F-T:6]N<RX@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D9&ER
M<RDI('L*("`@("`@("`@("`@)&1I<G,@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<V5C=7)E9&5L(#T@
M87)R87DH*3L*("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I
M;VXH87)R87DH)U5T:6PG+"`G7V1E;&5T94%T4VAU=&1O=VXG*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&9I;&5N86UE*2!["B`@("`@("`@("`@(&EF
M("@D<F5G:7-T97(I('L*("`@("`@("`@("`@("`@(&EF("A`:7-?9&ER*"1F
M:6QE;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`D9&ER<ULD9FEL96YA
M;65=(#T@=')U93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&9I;&5S6R1F:6QE;F%M95T@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1S96-U<F4I('L*("`@
M("`@("`@("`@("`@("`@("`D<V5C=7)E9&5L6R1F:6QE;F%M95T@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@=6YS970H)&1I<G-;)&9I;&5N86UE72D["B`@("`@("`@
M("`@("`@("!U;G-E="@D9FEL97-;)&9I;&5N86UE72D["B`@("`@("`@("`@
M("`@("!U;G-E="@D<V5C=7)E9&5L6R1F:6QE;F%M95TI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"1D:7)S+"`D9FEL97,L("1S96-U<F5D96PI.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1E;&5T97,@<F5G:7-T97)E9"!F:6QE<R!A="!R
M97%U97-T('-H=71D;W=N+@H@("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@
M<VAO=6QD(&YE=F5R(&)E(&-A;&QE9"!M86YU86QL>3L@:70@:7,@<F5G:7-T
M97)E9"!A<R!A"B`@("`@*B!S:'5T9&]W;B!F=6YC=&EO;B!B>2!5=&EL.CID
M96QE=&5!=%-H=71D;W=N*"D@86YD(&-A;&QE9"!A=71O;6%T:6-A;&QY"B`@
M("`@*B!A="!T:&4@96YD(&]F('1H92!R97%U97-T+B!)="!W:6QL(')E=')I
M979E('1H92!L:7-T(&]F(&9O;&1E<G,@86YD"B`@("`@*B!F:6QE<R!T;R!D
M96QE=&4@9G)O;2!5=&EL.CID96QE=&5!=%-H=71D;W=N*"DG<R!S=&%T:6,@
M87)R87DL(&%N9"!T:&5N"B`@("`@*B!I=&5R871E('1H<F]U9V@L(&1E;&5T
M:6YG(&9O;&1E<G,@<F5C=7)S:79E;'DN"B`@("`@*@H@("`@("H@0V]N=&%I
M;G,@8V]D92!F<F]M(&=P9U]F=6YC=&EO;G,N<&AP+@H@("`@("H@0V]P>7)I
M9VAT("AC*2`R,#`R+3(P,#,@0G)A=F5R;V-K(%9E;G1U<F5S"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D
M96QE=&5!=%-H=71D;W=N*"D*("`@('L*("`@("`@("`D<F5G:7-T97)E9"`]
M(%5T:6PZ.F1E;&5T94%T4VAU=&1O=VXH*3L*("`@("`@("`D9&ER<R`]("1R
M96=I<W1E<F5D6S!=.PH@("`@("`@("1F:6QE<R`]("1R96=I<W1E<F5D6S%=
M.PH@("`@("`@("1S96-U<F4@/2`D<F5G:7-T97)E9%LR73L*"B`@("`@("`@
M9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE(#T^("1V86PI('L*("`@("`@("`@
M("`@+RH@1&5L971E(&9I;&5S("HO"B`@("`@("`@("`@(&EF("@D=F%L("8F
M($!F:6QE7V5X:7-T<R@D9FEL92DI('L*("`@("`@("`@("`@("`@("\J(%-H
M;W5L9"!W92!S96-U<F5L>2!D96QE=&4@=&AE(&9I;&4@8GD@;W9E<G=R:71I
M;F<@=&AE"B`@("`@("`@("`@("`@("`@("!D871A('=I=&@@82!R86YD;VT@
M<W1R:6YG/R`J+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1S96-U<F5;
M)&9I;&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("1R86YD;VU?<W1R(#T@
M)R<["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@9FEL
M97-I>F4H)&9I;&4I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R86YD;VU?<W1R("X](&-H<BAM=%]R86YD*#`L(#(U-2DI.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D9G`@/2!F;W!E
M;B@D9FEL92P@)W(K)RD["B`@("`@("`@("`@("`@("`@("`@9G=R:71E*"1F
M<"P@)')A;F1O;5]S='(I.PH@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@0'5N;&EN
M:R@D9FEL92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1D:7)S(&%S("1D:7(@/3X@)'9A;"D@>PH@("`@("`@("`@("`O
M*B!$96QE=&4@9&ER96-T;W)I97,@*B\*("`@("`@("`@("`@:68@*"1V86P@
M)B8@0&9I;&5?97AI<W1S*"1D:7(I*2!["B`@("`@("`@("`@("`@("`O*B!-
M86ME('-U<F4@9&ER96-T;W)Y(&ES(&5M<'1Y+B`J+PH@("`@("`@("`@("`@
M("`@)&1I<E]C;&%S<R`](&1I<B@D9&ER*3L*("`@("`@("`@("`@("`@('=H
M:6QE("AF86QS92`A/3T@*"1E;G1R>2`]("1D:7)?8VQA<W,M/G)E860H*2DI
M('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&5N=')Y("$]("<N)R`F)B`D
M96YT<GD@(3T@)RXN)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("!`=6YL
M:6YK*"1D:7(@+B`G+R<@+B`D96YT<GDI.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D:7)?8VQA
M<W,M/F-L;W-E*"D["B`@("`@("`@("`@("`@("!`<FUD:7(H)&1I<BD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M=71P=71S(&IA=F%S8W)I<'0@8V]D92!T;R!C;&]S92!T:&4@8W5R<F5N="!W
M:6YD;W<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]D92`@06YY
M(&%D9'1I;VYA;"!J879A<V-R:7!T(&-O9&4@=&\@<G5N(&)E9F]R90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@8VQO<VEN9R!T:&4@=VEN9&]W+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;&]S95=I;F1O=TI3*"1C;V1E(#T@)R<I
M"B`@("!["B`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S
M8W)I<'0B/B<@+B`D8V]D92`N"B`@("`@("`@("`@("=W:6YD;W<N8VQO<V4H
M*3L\+W-C<FEP=#XG.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%C:&5S('1H
M92!R97-U;'0@;V8@97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO;B!N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@27,@=&AE(&5X=&5N<VEO;B!L;V%D960_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5X=&5N<VEO;D5X:7-T<R@D97AT*0H@("`@
M>PH@("`@("`@('-T871I8R`D8V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1C86-H95LD97AT72DI('L*("`@("`@("`@("`@)&-A8VAE
M6R1E>'1=(#T@97AT96YS:6]N7VQO861E9"@D97AT*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D8V%C:&5;)&5X=%T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!4<FEE<R!T;R!L;V%D(&$@4$A0(&5X=&5N<VEO;BP@8F5H879I;F<@
M8V]R<F5C=&QY(&9O<B!A;&P@;W!E<F%T:6YG"B`@("`@*B!S>7-T96US+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO
M;B!T;R!L;V%D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I9B!T:&4@97AT96YS:6]N(&ES(&YO=R!L;V%D960L(&9A;'-E(&EF(&YO
M="X*("`@("`J("`@("`@("`@("`@("`@("`@5')U92!C86X@;65A;B!T:&%T
M('1H92!E>'1E;G-I;VX@=V%S(&%L<F5A9'D@;&]A9&5D+`H@("`@("H@("`@
M("`@("`@("`@("`@("!/4B!W87,@;&]A9&5D(&1Y;F%M:6-A;&QY+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V%D17AT96YS:6]N*"1E>'0I"B`@("!["B`@
M("`@("`@+RH@268@)&5X="!I<R!A;')E861Y(&QO861E9"P@;W5R('=O<FL@
M:7,@9&]N92X@*B\*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S
M*"1E>'0I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4V5E(&EF('=E(&-A;B!C86QL(&1L*"D@870@86QL+"!B
M>2!T:&4@8W5R<F5N="!I;FD@<V5T=&EN9W,N("HO"B`@("`@("`@:68@*"AI
M;FE?9V5T*"=E;F%B;&5?9&PG*2`A/2`Q*2!\?"`H:6YI7V=E="@G<V%F95]M
M;V1E)RD@/3T@,2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=7
M24XG*2!["B`@("`@("`@("`@("1S=69F:7@@/2`G9&QL)SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!S=VET8V@@*%!(4%]/4RD@>PH@("`@("`@
M("`@("!C87-E("=(4"U56"<Z"B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@
M)W-L)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G04E8)SH*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G82<["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T]36"<Z"B`@
M("`@("`@("`@("`@("`D<W5F9FEX(#T@)V)U;F1L92<["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`D<W5F9FEX(#T@)W-O)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N($!D;"@D97AT("X@)RXG("X@)'-U9F9I>"D@?'P@
M0&1L*"=P:'!?)R`N("1E>'0@+B`G+B<@+B`D<W5F9FEX*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K<R!I9B!A;&P@;F5C97-S87)Y('!A<F%M971E
M<G,@9F]R(&$@9')I=F5R)W,@8V]N9FEG=7)A=&EO;B!A<F4@<V5T"B`@("`@
M*B!A;F0@<F5T=7)N<R!A(%!%05)?17)R;W(@:68@<V]M971H:6YG(&ES(&UI
M<W-I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!4
M:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2!W:71H(&%L;"!P87)A;65T97)S+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1F:65L9',@("!!;B!A<G)A>2!W:71H(&UA
M;F1A=&]R>2!P87)A;65T97(@;F%M97,@9F]R('1H:7,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@9')I=F5R+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("!4:&4@8VQE87(@=&5X="!N86UE(&]F('1H92!D<FEV97(N
M($EF(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I
M960L('1H92!A<'!L:6-A=&EO;B!N86UE('=I;&P@8F4@=7-E9"X*("`@("`J
M($!P87)A;2!A<G)A>2`D:6YF;R`@("`@02!H87-H(&-O;G1A:6YI;F<@9&5T
M86EL960@:6YF;W)M871I;VX@86)O=70@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&1R:79E<BX@5VEL;"!B92!P87-S960@87,@=&AE('5S
M97));F9O('1O('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!0
M14%27T5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E<G1$<FEV97)#
M;VYF:6<H)'!A<F%M<RP@)&9I96QD<RP@)&YA;64L("1I;F9O(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D:6YF;R`](&%R<F%Y7VUE<F=E*"1I;F9O+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W!A<F%M<R<@/3X@
M)'!A<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F
M:65L9',G(#T^("1F:65L9',L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@/3X@)&YA;64I*3L*"B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<&%R86US*2!\?"`A8V]U;G0H)'!A<F%M<RDI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIT:')O=T5R<F]R*'-P<FEN=&8H7R@B3F\@8V]N9FEG=7)A=&EO
M;B!I;F9O<FUA=&EO;B!S<&5C:69I960@9F]R("5S+B(I+"`D;F%M92DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($A/4D1%7T524D]2
M7T12259%4E]#3TY&24=?34E34TE.1RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F\I.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)&9I96QD<R!A<R`D9FEE;&0I('L*("`@("`@("`@("`@:68@*"%I
M<W-E="@D<&%R86US6R1F:65L9%TI*2!["B`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIT:')O=T5R<F]R*'-P<FEN=&8H7R@B4F5Q=6ER960@7"(E<UPB(&YO
M="!S<&5C:69I960@:6X@8V]N9FEG=7)A=&EO;BXB*2P@)&9I96QD+"`D;F%M
M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M3U)$15]%4E)/4E]$4DE615)?0T].1DE'+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F\I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&9O<FUA
M="!S=')I;F<@=&\@8F4@=7-E9"!B>2!S=')F=&EM92@I+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@02!F;W)M870@<W1R:6YG(&%S
M('5S960@8GD@9&%T92@I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!!(&9O<FUA="!S=')I;F<@87,@<VEM:6QA<B!A<R!P;W-S:6)L92!T;R`D
M9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D871E,G-T<F9T:6UE*"1F
M;W)M870I"B`@("!["B`@("`@("`@)&1A=&53>6UB;VQS(#T@87)R87DH)V$G
M+"`G02<L("=D)RP@)T0G+"`G1B<L("=G)RP@)T<G+"`G:"<L("=()RP@)VDG
M+"`G:B<L("=L)RP@)VTG+"`G32<L("=N)RP@)W(G+"`G<R<L("=4)RP@)W<G
M+"`G5R<L("=Y)RP@)UDG+"`G>B<L("=M+V0O62<L("=-)RP@(EQN(BP@)V<Z
M:2!A)RP@)T<Z:2<L(")<="(L("=(.FDZ<R<L("<E)RD["B`@("`@("`@)'-T
M<F9T:6UE4WEM8F]L<R`](&%R<F%Y*"<E<"<L("<E<"<L("<E9"<L("<E82<L
M("<E0B<L("<E22<L("<E2"<L("<E22<L("<E2"<L("<E32<L("<E92<L("<E
M02<L("<E;2<L("<E8B<L("<E;2<L("<E82P@)64@)6(@)5D@)50@)5HG+"`G
M)5,G+"`G)5HG+"`G)7<G+"`G)58G+"`G)7DG+"`G)5DG+"`G)6HG+"`G)40G
M+"`G)6@G+"`G)6XG+"`G)7(G+"`G)5(G+"`G)70G+"`G)50G+"`G)24G*3L*
M"B`@("`@("`@)')E<W5L="`]("<G.PH@("`@("`@(&9O<B`H)'!O<R`](#`[
M("1P;W,@/"!S=')L96XH)&9O<FUA="D[*2!["B`@("`@("`@("`@(&9O<B`H
M)'-Y;6)O;"`](#`[("1S>6UB;VP@/"!C;W5N="@D9&%T95-Y;6)O;',I.R`D
M<WEM8F]L*RLI('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&9O<FUA
M="P@)&1A=&53>6UB;VQS6R1S>6UB;VQ=+"`D<&]S*2`]/3T@)'!O<RD@>PH@
M("`@("`@("`@("`@("`@("`@("1R97-U;'0@+CT@)'-T<F9T:6UE4WEM8F]L
M<ULD<WEM8F]L73L*("`@("`@("`@("`@("`@("`@("`D<&]S("L]('-T<FQE
M;B@D9&%T95-Y;6)O;'-;)'-Y;6)O;%TI.PH@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E(#(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)')E<W5L="`N/2!S=6)S='(H)&9O<FUA="P@)'!O<RP@
M,2D["B`@("`@("`@("`@("1P;W,K*SL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(&9O<FUA="!S=')I;F<@=&\@8F4@=7-E9"!B>2!D871E*"DN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!!(&9O<FUA="!S=')I;F<@
M87,@=7-E9"!B>2!S=')F=&EM92@I+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!!(&9O<FUA="!S=')I;F<@87,@<VEM:6QA<B!A<R!P;W-S:6)L
M92!T;R`D9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')F=&EM93)D
M871E*"1F;W)M870I"B`@("!["B`@("`@("`@)&1A=&53>6UB;VQS(#T@87)R
M87DH)V$G+"`G02<L("=D)RP@)T0G+"`G1B<L("=G)RP@)T<G+"`G:"<L("=(
M)RP@)VDG+"`G:B<L("=L)RP@)VTG+"`G32<L("=N)RP@)W(G+"`G<R<L("=4
M)RP@)W<G+"`G5R<L("=Y)RP@)UDG+"`G>B<L("=M+V0O62<L("=-)RP@(EQN
M(BP@)V<Z:2!A)RP@)T<Z:2<L(")<="(L("=(.FDZ<R<L("<E)RD["B`@("`@
M("`@)'-T<F9T:6UE4WEM8F]L<R`](&%R<F%Y*"<E<"<L("<E<"<L("<E9"<L
M("<E82<L("<E0B<L("<E22<L("<E2"<L("<E22<L("<E2"<L("<E32<L("<E
M92<L("<E02<L("<E;2<L("<E8B<L("<E;2<L("<E82P@)64@)6(@)5D@)50@
M)5HG+"`G)5,G+"`G)5HG+"`G)7<G+"`G)58G+"`G)7DG+"`G)5DG+"`G)6HG
M+"`G)40G+"`G)6@G+"`G)6XG+"`G)7(G+"`G)5(G+"`G)70G+"`G)50G+"`G
M)24G*3L*"B`@("`@("`@<F5T=7)N('-T<E]R97!L86-E*"1S=')F=&EM95-Y
M;6)O;',L("1D871E4WEM8F]L<RP@)&9O<FUA="D["B`@("!]"@I]"@II9B`H
M(69U;F-T:6]N7V5X:7-T<R@G7R<I*2!["B`@("!F=6YC=&EO;B!?*"1S=')I
M;F<I"B`@("!["B`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("!]"@H@("`@
M9G5N8W1I;VX@8FEN9'1E>'1D;VUA:6XH*0H@("`@>PH@("`@?0H*("`@(&9U
M;F-T:6]N('1E>'1D;VUA:6XH*0H@("`@>PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]3
M8VAE9'5L97(N<&AP````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`Q-34R-R`Q,#4Q-30S-#$T,"`P,C(P,#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4N<&AP)SL*<F5Q=6ER95]O;F-E("=61E,N<&AP)SL*"B\J*@H@
M*B!(;W)D95]38VAE9'5L97(*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V-H
M961U;&5R+U-C:&5D=6QE<BYP:'`L=B`Q+C(S+C$P+C@@,C`P-2\Q,B\P,2`Q
M-3HR-SHR,R!C:'5C:R!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]38VAE
M9'5L97(*("HO"F-L87-S($AO<F1E7U-C:&5D=6QE<B!["@H@("`@+RHJ"B`@
M("`@*B!.86UE(&]F('1H92!S;&5E<"!F=6YC=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S;&5E<#L*"B`@("`O
M*BH*("`@("`J($%D:G5S=&UE;G0@9F%C=&]R('1O('-L965P(&EN(&UI8W)O
M<V5C;VYD<RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?<VQE97!?861J.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@1FEG=7)E<R!O=70@:&]W('=E(&-A;B!B97-T
M('-L965P('=I=&@@;6EC<F]S96-O;F0@<')E8VES:6]N"B`@("`@*B!B87-E
M9"!O;B!W:&%T('!L871F;W)M('=E)W)E(')U;FYI;F<@;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7U-C:&5D=6QE<B@I"B`@("!["B`@("`@("`@
M:68@*'-U8G-T<BA02%!?3U,L(#`L(#,I(#T]("=724XG*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<VQE97`@/2`G<VQE97`G.PH@("`@("`@("`@("`D=&AI
M<RT^7W-L965P7V%D:B`](#$P,#`P,#`["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/E]S;&5E<"`]("=U<VQE97`G.PH@("`@("`@("`@
M("`D=&AI<RT^7W-L965P7V%D:B`](#$["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@36%I;B!L;V]P+V%C=&EO;B!F=6YC=&EO;BX*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<G5N*"D*
M("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%!R97-E<G9E('1H92!I;G1E
M<FYA;"!S=&%T92!O9B!T:&4@<V-H961U;&5R(&]B:F5C="!T:&%T('=E(&%R
M90H@("`@("H@<&%S<V5D+"!A;F0@<V%V92!I="!T;R!T:&4@2&]R9&4@5D93
M(&)A8VME;F0N($AO<F1E7U-C:&5D=6QE<@H@("`@("H@;V)J96-T<R!S:&]U
M;&0@9&5F:6YE(%]?<VQE97`H*2!A;F0@7U]W86ME=7`H*2!S97)I86QI>F%T
M:6]N"B`@("`@*B!C86QL8F%C:W,@9F]R(&%N>71H:6YG('1H870@;F5E9',@
M=&\@8F4@9&]N92!A="!O8FIE8W0*("`@("`J('-E<FEA;&EZ871I;VX@;W(@
M9&5S97)I86QI>F%T:6]N("T@:&%N9&QI;F<@9&%T86)A<V4*("`@("`J(&-O
M;FYE8W1I;VYS+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)&ED("!!;B!I9"!T;R!U;FEQ=65L>2!I9&5N=&EF>2!T:&ES('-C:&5D=6QE
M<B!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&]T:&5R<R!O9B!T
M:&4@<V%M92!C;&%S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE
M*"1I9"`]("<G*0H@("`@>PH@("`@("`@("1V9G,@/2`F5D93.CIS:6YG;&5T
M;VXH)$=,3T)!3%-;)V-O;F8G75LG=F9S)UU;)W1Y<&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($AO<F1E.CIG971$<FEV97)#;VYF:6<H
M)W9F<R<L("1'3$]"04Q36R=C;VYF)UU;)W9F<R==6R=T>7!E)UTI*3L*("`@
M("`@("!I9B`H:7-?82@D=F9S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1V9G,L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1V9G,M/G=R:71E1&%T82@G
M+FAO<F1E+W-C:&5D=6QE<B<L(%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T
M:&ES*2D@+B`D:60L('-E<FEA;&EZ92@D=&AI<RDL('1R=64I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E<W1O<F4@82!(;W)D95]38VAE9'5L97(@;V)J96-T(&9R
M;VT@=&AE(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1C
M;&%S<R`@("`@5&AE(&YA;64@;V8@=&AE($AO<F1E7U-C:&5D=6QE<B!O8FIE
M8W0@=&\@<F5S=&]R92X*("`@("`J($!P87)A;2!S=')I;F<@("1I9"`@("`@
M("`@06X@:60@=&\@=6YI<75E;'D@:61E;G1I9GD@=&AI<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S8VAE9'5L97(@9G)O;2!O=&AE<G,@
M;V8@=&AE('-A;64@8VQA<W,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T
M;W-A=F4@($%U=&]M871I8V%L;'D@<W1O<F4@*'-E<FEA;&EZ92D@=&AE(')E
M='5R;F5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C
M="!A="!S8W)I<'0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0'-E92!(;W)D
M95]38VAE9'5L97(Z.G-E<FEA;&EZ92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9U;G-E<FEA;&EZ92@D8VQA<W,L("1I9"`]("<G+"`D875T;W-A=F4@/2!T
M<G5E*0H@("`@>PH@("`@("`@("\O($YE960@82!L;W=E<F-A<V4@=F5R<VEO
M;B!O9B!T:&4@8VQA<W-N86UE+"!A;F0@82!D969A=6QT"B`@("`@("`@+R\@
M:6YS=&%N8V4@;V8@=&AE('-C:&5D=6QE<B!O8FIE8W0@:6X@8V%S92!W92!C
M86XG="!R971R:65V90H@("`@("`@("\O(&]N92X*("`@("`@("`D8VQA<W,@
M/2!S=')T;VQO=V5R*"1C;&%S<RD["B`@("`@("`@)'-C:&5D=6QE<B`]("9N
M97<@)&-L87-S.PH*("`@("`@("`D=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1'
M3$]"04Q36R=C;VYF)UU;)W9F<R==6R=T>7!E)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=V9G,G
M+"`D1TQ/0D%,4ULG8V]N9B==6R=V9G,G75LG='EP92==*2D["B`@("`@("`@
M:68@*&ES7V$H)'9F<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@D=F9S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A
M=&$@/2`D=F9S+3YR96%D*"<N:&]R9&4O<V-H961U;&5R)RP@)&-L87-S("X@
M)&ED*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1D871A
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TE.1D\I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-C:&5D=6QE<B`]($!U
M;G-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@("`@("`@("!I9B`H(21S8VAE
M9'5L97(I('L*("`@("`@("`@("`@("`@("`@("`D<V-H961U;&5R(#T@)FYE
M=R`D8VQA<W,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D875T;W-A=F4I('L*("`@("`@("`@("`@
M<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1S8VAE9'5L97(L
M("=S97)I86QI>F4G*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-C
M:&5D=6QE<CL*("`@('T*"B`@("`O*BH*("`@("`J(%!L871F;W)M+6EN9&5P
M96YD86YT('-L965P("1M<V5C(&UI8W)O<V5C;VYD<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;7-E8R`@36EC<F]S96-O;F1S('1O('-L965P
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;&5E<"@D;7-E8RD*("`@('L*("`@
M("`@("!C86QL7W5S97)?9G5N8R@D=&AI<RT^7W-L965P+"`D;7-E8R`O("1T
M:&ES+3Y?<VQE97!?861J*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<B!I;G-T
M86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]38VAE
M9'5L97(@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL
M;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E
M<ELP72]L:6(O2&]R9&5?4V-H961U;&5R+R!F;W(@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@:6UP;&5M96YT871I;VX@;F%M
M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A
M=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!(;W)D95]38VAE9'5L97(@(%1H92!N97=L>2!C<F5A
M=&5D(&-O;F-R971E($AO<F1E7U-C:&5D=6QE<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A
M<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV
M97(I*2!["B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@
M("`@("`D9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@
M("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M
M<'1Y*"1D<FEV97(I('Q\("AS=')C;7`H)&1R:79E<BP@)VYO;F4G*2`]/2`P
M*2D@>PH@("`@("`@("`@("`D<V-H961U;&5R(#T@)FYE=R!(;W)D95]38VAE
M9'5L97(H*3L*("`@("`@("`@("`@<F5T=7)N("1S8VAE9'5L97(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@
M(&EN8VQU9&5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE
M<F]O="<L("1A<'`I("X@)R]L:6(O4V-H961U;&5R+R<@+B`D9')I=F5R("X@
M)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+U-C:&5D=6QE<B\G("X@)&1R:79E<B`N("<N<&AP
M)RDI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]38VAE9'5L97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@57-E(&EN8VQU9&5?;VYC92!H
M97)E('1O(&%V;VED(&$@9F%T86P@97)R;W(@:68@=&AE"B`@("`@("`@("`@
M("\O(&-L87-S(&ES;B=T(&9O=6YD+@H@("`@("`@("`@("!`:6YC;'5D95]O
M;F-E("=(;W)D92]38VAE9'5L97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?0H@("`@("`@("1C;&%S<R`]("=(;W)D95]38VAE9'5L97)?)R`N
M("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2![
M"B`@("`@("`@("`@("1S8VAE9'5L97(@/2`F;F5W("1C;&%S<R@D<&%R86US
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<V-H961U;&5R(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L
M87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'-C:&5D=6QE<CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7U-C
M:&5D=6QE<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@
M=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@
M2&]R9&5?4V-H961U;&5R(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE
M=&5R<PH@("`@("H@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4
M:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE('-C:&5D=6QE<G,@*&%N
M9"P@=&AU<RP@;75L=&EP;&4*("`@("`J($AO<F1E7U-C:&5D=6QE<B!I;G-T
M86YC97,I(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO
M9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&]R9&5?4V-H961U;&5R
M.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1R
M:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R('-U
M8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O;G1A
M:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@
M82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@
M2&]R9&5?4V-H961U;&5R("!4:&4@8V]N8W)E=&4@2&]R9&5?4V-H961U;&5R
M(')E9F5R96YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@("1S:6=N
M871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@
M("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9(;W)D95]3
M8VAE9'5L97(Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]%9&ET;W(N<&AP````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S<Q-2`Q,#4Q
M-30S-#$T,"`P,C$S,3``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J($5D:71O<B!#;&%S<PH@*@H@*B!4
M:&4@161I=&]R.CH@<&%C:V%G92!P<F]V:61E<R!A;B!R=&4@961I=&]R(&9O
M<B!T:&4@2&]R9&4*("H@07!P;&EC871I;VX@1G)A;65W;W)K+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]%9&ET;W(O161I=&]R+G!H<"QV(#$N."XQ,"XX
M(#(P,#8O,#$O,#$@,C$Z,C@Z,30@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@3G5N;R!,;W5R96ER;R`\;G5N;T!C;RYS87!O+G!T/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@3G5N;R!,;W5R96ER;R`\;G5N
M;T!C;RYS87!O+G!T/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?161I=&]R"B`J+PIC;&%S<R!(;W)D95]%9&ET;W(@>PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M($AO<F1E7T5D:71O<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R971E
M($AO<F1E7T5D:71O<B!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C
M;VYC<F5T92!(;W)D95]%9&ET;W(@<W5B8VQA<W,@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FXN($EF("1D<FEV97(@:7,@86X@87)R
M87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:6X@)&1R:79E<ELP72]L:6(O1')I=F5R+R!F;W(@=&AE('-U8F-L
M87-S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6UP;&5M96YT871I
M;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N
M9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!(;W)D95]%9&ET;W(@(%1H92!N97=L>2!C
M<F5A=&5D(&-O;F-R971E($AO<F1E7T5D:71O<B!I;G-T86YC92P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2![
M"B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D
M9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV
M97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R
M:79E<BD@?'P@)&1R:79E<B`]/2`G;F]N92<I('L*("`@("`@("`@("`@)&5D
M:71O<B`]("9N97<@2&]R9&5?161I=&]R*"1P87)A;7,I.PH@("`@("`@("`@
M("!R971U<FX@)&5D:71O<CL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N
M=6QL*"1P87)A;7,I("8F(&-L87-S7V5X:7-T<R@G2&]R9&4G*2D@>PH@("`@
M("`@("`@("`D<&%R86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G961I
M=&]R)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1A<'`I*2!["B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D87!P*2`N("<O;&EB+T5D:71O<B\G("X@)&1R:79E<B`N("<N<&AP)SL*
M("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]%9&ET;W(O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O161I
M=&]R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+T5D:71O<B\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(
M;W)D95]%9&ET;W)?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1E9&ET;W(@/2`F;F5W("1C
M;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M961I=&]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O
M9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&5D:71O<CL*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO
M<F1E7T5D:71O<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@
M270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@
M;F\@2&]R9&5?161I=&]R(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE
M=&5R<R!C=7)R96YT;'D*("`@("`J(&5X:7-T<RX*("`@("`J"B`@("`@*B!4
M:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(&-A8VAE(&)A8VME;F1S
M("AA;F0L('1H=7,L"B`@("`@*B!M=6QT:7!L92!(;W)D95]%9&ET;W(@:6YS
M=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@)'9A<B`]("9(;W)D95]%
M9&ET;W(Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E($AO<F1E7T5D:71O<B!S
M=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI
M8B]%9&ET;W(O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H
M<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I
M;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@
M<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R
M9&4@,BXR"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]%9&ET;W(@(%1H
M92!C;VYC<F5T92!(;W)D95]%9&ET;W(@<F5F97)E;F-E+"!O<B!F86QS92!O
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!N
M=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T
M86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU
M;&PH)'!A<F%M<RD@)B8@8VQA<W-?97AI<W1S*"=(;W)D92<I*2!["B`@("`@
M("`@("`@("1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=C86-H
M92<L("1D<FEV97(I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]
M('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@
M:68@*"%A<G)A>5]K97E?97AI<W1S*"1S:6=N871U<F4L("1I;G-T86YC97,I
M*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R
M9&5?161I=&]R.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]-96YU+G!H<```````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`R-#8V,2`Q,#4Q-30S-#$T,"`P,C`W-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"F1E9FEN92@G
M2$]21$5?345.55]03U-?3$%35"<L(#DY.2D["@ID969I;F4H)TA/4D1%7TU%
M3E5?34%32U].3TY%)RP@("`@(#`I.PID969I;F4H)TA/4D1%7TU%3E5?34%3
M2U](14Q0)RP@("`@(#$I.PID969I;F4H)TA/4D1%7TU%3E5?34%32U],3T=)
M3B<L("`@(#(I.PID969I;F4H)TA/4D1%7TU%3E5?34%32U]04D5&4R<L("`@
M(#0I.PID969I;F4H)TA/4D1%7TU%3E5?34%32U]04D]"3$5-)RP@(#@I.PID
M969I;F4H)TA/4D1%7TU%3E5?34%32U]!3$PG+"`@("`@,34I.PH*+RHJ"B`J
M(%1H92!-96YU.CH@8VQA<W,@<')O=FED97,@<W1A;F1A<F1I>F5D(&UE=&AO
M9',@9F]R(&-R96%T:6YG(&UE;G5S(&EN"B`J($AO<F1E(&%P<&QI8V%T:6]N
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O365N=2YP
M:'`L=B`Q+C,U+C(N,3$@,C`P-B\P-R\R,"`P-#HS,3HR-R!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N
M(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?1G)A;65W;W)K"B`J+PIC
M;&%S<R!-96YU('L*"B`@("`O*BH*("`@("`J($UE;G4@87)R87DN"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]M96YU(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($UA<VL@9&5F:6YI;F<@=VAA="!G
M96YE<F%L($AO<F1E(&QI;FMS(&%R92!S:&]W;B!I;B!T:&ES($UE;G4N"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VUA
M<VL["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F
M=6YC=&EO;B!-96YU*"1M87-K(#T@2$]21$5?345.55]-05-+7T%,3"D*("`@
M('L*("`@("`@("`O*B!-96YU:71E;2!M87-K+B`J+PH@("`@("`@("1T:&ES
M+3Y?;6%S:R`]("1M87-K.PH*("`@("`@("`O*B!,;V-A=&EO;B!O9B!T:&4@
M;65N=69I;&4N("HO"B`@("`@("`@)'1H:7,M/E]M96YU9FEL92`]("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RD@+B`G+V-O;F9I9R]M
M96YU+G!H<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@:71E;2!T
M;R!T:&4@;65N=2!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<FP@("`@("`@(%-T<FEN9R!C;VYT86EN:6YG('1H92!V86QU92!F;W(@
M=&AE(&AY<&5R;&EN:RX*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@
M("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&QA8F5L(&9O<B!T:&ES(&UE;G4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:71E;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)&EC;VX@("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&9I;&5N86UE(&]F('1H92!I;6%G90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I8V]N('1O(&1I<W!L87D@9F]R('1H:7,@;65N=2!I
M=&5M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6-O;E]P871H("!)9B!T:&4@
M:6-O;B!L:79E<R!I;B!A(&YO;BUD969A=6QT(&1I<F5C=&]R>2P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAE<F4@:7,@:70_"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T87)G970@("`@($EF('1H92!L:6YK(&YE961S
M('1O(&]P96X@:6X@86YO=&AE<B!F<F%M92!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!W:6YD;W<L('=H870@:7,@:71S(&YA;64_"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1O;F-L:6-K("`@($]N8VQI8VL@:F%V87-C
M<FEP="P@:68@9&5S:7)E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S
M("`@("`@0U-3(&-L87-S(&9O<B!T:&4@;65N=2!I=&5M+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&ED("A.3U0@9W5A<F%N=&5E9"!T
M;R!B92!A;B!A<G)A>2!I;F1E>"D@;V8@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&ET96T@:G5S="!A9&1E9"!T;R!T:&4@;65N=2X*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D*"1U<FPL("1T97AT+"`D:6-O;B`]("<G+"`D:6-O
M;E]P871H(#T@;G5L;"P*("`@("`@("`@("`@("`@("`D=&%R9V5T(#T@)R<L
M("1O;F-L:6-K(#T@;G5L;"P@)&-L87-S(#T@;G5L;"D*("`@('L*("`@("`@
M("`D<&]S(#T@8V]U;G0H)'1H:7,M/E]M96YU*3L*("`@("`@("!I9B`H(21P
M;W,@?'P@*"1P;W,@+2`Q("$](&UA>"AA<G)A>5]K97ES*"1T:&ES+3Y?;65N
M=2DI*2D@>PH@("`@("`@("`@("`D<&]S(#T@8V]U;G0H)'1H:7,M/E]M96YU
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;65N=5LD<&]S72`]"B`@
M("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W5R;"<@/3X@)'5R
M;"P*("`@("`@("`@("`@("`@("=T97AT)R`]/B`D=&5X="P*("`@("`@("`@
M("`@("`@("=I8V]N)R`]/B`D:6-O;BP*("`@("`@("`@("`@("`@("=I8V]N
M7W!A=&@G(#T^("1I8V]N7W!A=&@L"B`@("`@("`@("`@("`@("`G=&%R9V5T
M)R`]/B`D=&%R9V5T+`H@("`@("`@("`@("`@("`@)V]N8VQI8VLG(#T^("1O
M;F-L:6-K+`H@("`@("`@("`@("`@("`@)V-L87-S)R`]/B`D8VQA<W,*("`@
M("`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N("1P;W,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@86X@:71E;2!T;R!T:&4@;65N=2!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@("`@(%-T<FEN9R!C
M;VYT86EN:6YG('1H92!V86QU92!F;W(@=&AE(&AY<&5R;&EN:RX*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@
M=&AE(&QA8F5L(&9O<B!T:&ES(&UE;G4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&EC;VX@
M("`@("`@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9I;&5N86UE(&]F('1H92!I
M;6%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I8V]N('1O
M(&1I<W!L87D@9F]R('1H:7,@;65N=2!I=&5M+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:6-O;E]P871H("!)9B!T:&4@:6-O;B!L:79E<R!I;B!A(&YO;BUD
M969A=6QT(&1I<F5C=&]R>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=VAE<F4@:7,@:70_"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G
M970@("`@($EF('1H92!L:6YK(&YE961S('1O(&]P96X@:6X@86YO=&AE<B!F
M<F%M92!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!W:6YD
M;W<L('=H870@:7,@:71S(&YA;64_"B`@("`@*B!`<&%R86T@<W1R:6YG("1O
M;F-L:6-K("`@($]N8VQI8VL@:F%V87-C<FEP="P@:68@9&5S:7)E9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-L87-S("`@("`@0U-3(&-L87-S(&9O<B!T
M:&4@;65N=2!I=&5M+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE(&ED("A.3U0@9W5A<F%N=&5E9"!T;R!B92!A;B!A<G)A>2!I;F1E>"D@
M;V8@=&AE(&ET96T*("`@("`J("`@("`@("`@("`@("`@("`@:G5S="!A9&1E
M9"!T;R!T:&4@;65N=2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D07)R87DH
M)&ET96TI"B`@("!["B`@("`@("`@)'!O<R`](&-O=6YT*"1T:&ES+3Y?;65N
M=2D["B`@("`@("`@:68@*"$D<&]S('Q\("@D<&]S("T@,2`A/2!M87@H87)R
M87E?:V5Y<R@D=&AI<RT^7VUE;G4I*2DI('L*("`@("`@("`@("`@)'!O<R`]
M(&-O=6YT*"1T:&ES+3Y?;65N=2D["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VUE;G5;)'!O<UT@/2`D:71E;3L*"B`@("`@("`@<F5T=7)N("1P;W,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4&]S:71I;VXH)&ED+"`D<&]S*0H@
M("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]M96YU6R1I9%TI('Q\
M(&ES<V5T*"1T:&ES+3Y?;65N=5LD<&]S72DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)&ET96T@/2`D=&AI<RT^
M7VUE;G5;)&ED73L*("`@("`@("!U;G-E="@D=&AI<RT^7VUE;G5;)&ED72D[
M"B`@("`@("`@)'1H:7,M/E]M96YU6R1P;W-=(#T@)&ET96T["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!U;F]R9&5R960@;&ES="!R97!R97-E;G1I;F<@=&AE(&QI<W0@;V8@;65N
M=2!I=&5M<RX@4W1Y;&EN9PH@("`@("H@:7,@9&]N92!T:')O=6=H($-34RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@06X@=6YO<F1E<F5D(&QI
M<W0@;V8@;65N=2!E;&5M96YT<R!T:&%T(&-A;B!B92!E;G1I<F5L>0H@("`@
M("H@("`@("`@("`@("`@("`@('-T>6QE9"!W:71H($-34RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5N9&5R*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O
M;F8L("1R96=I<W1R>2P@)'!R969S.PH*("`@("`@("`D9W)A<&AI8W,@/2`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I.PH@("`@("`@("1A<'`@
M/2`D<F5G:7-T<GDM/F=E=$%P<"@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]M
M87-K("$]/2!(3U)$15]-14Y57TU!4TM?3D].12D@>PH@("`@("`@("`@("`O
M*B!!9&0@86YY(&-U<W1O;2!M96YU(&ET96US+B`J+PH@("`@("`@("`@("`D
M=&AI<RT^861D4VET94QI;FMS*"D["@H@("`@("`@("`@("`O*B!!9&0@86YY
M(&%P<"!M96YU(&ET96US+B`J+PH@("`@("`@("`@("`D=&AI<RT^861D07!P
M3&EN:W,H*3L*("`@("`@("!]"@H@("`@("`@("\J($%D9"!S971T:6YG<R!L
M:6YK+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y5
M7TU!4TM?4%)%1E,@)B8@)'5R;"`]($AO<F1E.CIG971397)V:6-E3&EN:R@G
M;W!T:6]N<R<L("1A<'`I*2!["B`@("`@("`@("`@("1T:&ES+3YA9&0H)'5R
M;"P@7R@B7T]P=&EO;G,B*2P@)W!R969S+G!N9R<L("1G<F%P:&EC<RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!!9&0@<')O8FQE;2!L:6YK+B`J+PH@("`@
M("`@(&EF("@D=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?4%)/0DQ%
M32`F)B`D<')O8FQE;5]L:6YK(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=P
M<F]B;&5M)RP@)&%P<"DI('L*("`@("`@("`@("`@)'1H:7,M/F%D9"@D<')O
M8FQE;5]L:6YK+"!?*")0<F]B;&5M(BDL("=P<F]B;&5M+G!N9R<L("1G<F%P
M:&EC<RD["B`@("`@("`@?0H*("`@("`@("`O*B!!9&0@:&5L<"!L:6YK+B`J
M+PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O2&5L<"YP:'`G.PH@("`@
M("`@(&EF("@D=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?2$5,4"`F
M)B`D:&5L<%]L:6YK(#T@2&]R9&4Z.F=E=%-E<G9I8V5,:6YK*"=H96QP)RP@
M)&%P<"DI('L*("`@("`@("`@("`@)'1H:7,M/F%D9"@D:&5L<%]L:6YK+"!?
M*")(96QP(BDL("=H96QP7VEN9&5X+G!N9R<L("1G<F%P:&EC<RP@)VAE;'`G
M+"`G<&]P=7`H=&AI<RYH<F5F*3L@<F5T=7)N(&9A;'-E.R<I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@3&]G:6XO3&]G;W5T+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7VUA<VL@)B!(3U)$15]-14Y57TU!4TM?3$]'24XI('L*("`@("`@
M("`@("`@+RH@268@=&AE('-I9&5B87(@:7-N)W0@86QW87ES('-H;W=N+"!B
M=70@:7,@<V]M971I;65S"B`@("`@("`@("`@("`J('-H;W=N+"!T:&5N(&QO
M9V]U="!L:6YK<R!S:&]U;&0@8F4@=&\@=&AE('!A<F5N=`H@("`@("`@("`@
M("`@*B!F<F%M92X@*B\*("`@("`@("`@("`@)&%U=&A?=&%R9V5T(#T@;G5L
M;#L*("`@("`@("`@("`@:68@*"1C;VYF6R=M96YU)UU;)V%L=V%Y<R==('Q\
M("1P<F5F<RT^9V5T5F%L=64H)W-H;W=?<VED96)A<B<I*2!["B`@("`@("`@
M("`@("`@("`D875T:%]T87)G970@/2`G7W!A<F5N="<["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("A!=71H.CIG971!=71H*"DI('L*("`@("`@
M("`@("`@("`@(&EF("@D;&]G;W5T7VQI;FL@/2!(;W)D93HZ9V5T4V5R=FEC
M94QI;FLH)VQO9V]U="<L("1A<'`L("$D<')E9G,M/F=E=%9A;'5E*"=S:&]W
M7W-I9&5B87(G*2DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D
M*"1L;V=O=71?;&EN:RP@7R@B7TQO9R!O=70B*2P@)VQO9V]U="YP;F<G+"`D
M9W)A<&AI8W,L("1A=71H7W1A<F=E="P@;G5L;"P@)U]?;F]S96QE8W1I;VXG
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&EF("@D;&]G:6Y?;&EN:R`]($AO<F1E.CIG971397)V
M:6-E3&EN:R@G;&]G:6XG+"`D87!P*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&0H)&QO9VEN7VQI;FLL(%\H(E],;V<@:6XB*2P@)VQO9VEN
M+G!N9R<L("1G<F%P:&EC<RP@)&%U=&A?=&%R9V5T+"!N=6QL+"`G7U]N;W-E
M;&5C=&EO;B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!.;R!N965D('1O(')E='5R;B!A;B!E;7!T
M>2!L:7-T(&EF('1H97)E(&%R92!N;R!M96YU"B`@("`@("`@("H@:71E;7,N
M("HO"B`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7VUE;G4I*2!["B`@("`@
M("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J(%-O<G0@
M=&\@;6%T8V@@97AP;&EC:71L>2!S970@<&]S:71I;VYS+B`J+PH@("`@("`@
M(&MS;W)T*"1T:&ES+3Y?;65N=2D["B`@("`@("`@:68@*"%E;7!T>2@D1TQ/
M0D%,4ULG;FQS)UU;)W)T;"==6R1'3$]"04Q36R=L86YG=6%G92==72DI("![
M"B`@("`@("`@("`@("1T:&ES+3Y?;65N=2`](&%R<F%Y7W)E=F5R<V4H)'1H
M:7,M/E]M96YU*2`["B`@("`@("`@?0H*("`@("`@("`D;65N=5]V:65W(#T@
M)'!R969S+3YG971686QU92@G;65N=5]V:65W)RD["B`@("`@("`@)&]U='!U
M="`]("<\=6P^)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VUE;G4@87,@
M)&TI('L*("`@("`@("`@("`@+RH@271E;2!C;&%S<R!A;F0@<V5L96-T960@
M:6YD:6-A=&EO;BX@*B\*("`@("`@("`@("`@:68@*"%I<W-E="@D;5LG8VQA
M<W,G72DI('L*("`@("`@("`@("`@("`@("\J(%1R>2!T;R!M871C:"!T:&4@
M:71E;2=S('!A=&@@86=A:6YS="!T:&4@8W5R<F5N=`H@("`@("`@("`@("`@
M("`@("H@<V-R:7!T(&9I;&5N86UE(&%S('=E;&P@87,@;W1H97(@<&]S<VEB
M;&4@55),<R!T;PH@("`@("`@("`@("`@("`@("H@=&AI<R!S8W)I<'0N("HO
M"B`@("`@("`@("`@("`@("!I9B`H365N=3HZ:7-396QE8W1E9"@D;5LG=7)L
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&U;)V-L87-S)UT@/2`G8W5R
M<F5N="<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF
M("@D;5LG8VQA<W,G72`]/3T@)U]?;F]S96QE8W1I;VXG*2!["B`@("`@("`@
M("`@("`@("!U;G-E="@D;5LG8VQA<W,G72D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($EC;VXN("HO"B`@("`@("`@("`@("1I8V]N(#T@)R<[
M"B`@("`@("`@("`@(&EF("@D;65N=5]V:65W(#T]("=I8V]N)R!\?"`D;65N
M=5]V:65W(#T]("=B;W1H)RD@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;5LG:6-O;E]P871H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&U;
M)VEC;VY?<&%T:"==(#T@;G5L;#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1I8V]N(#T@2&]R9&4Z.FEM9R@D;5LG:6-O;B==+"!(;W)D
M93HZ<W1R:7!!8V-E<W-+97DH)&U;)W1E>'0G72DL("<G+"`D;5LG:6-O;E]P
M871H)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!,:6YK+B`J
M+PH@("`@("`@("`@("`D86-C97-S:V5Y(#T@2&]R9&4Z.F=E=$%C8V5S<TME
M>2@D;5LG=&5X="==*3L*("`@("`@("`@("`@)&QI;FL@/2!(;W)D93HZ;&EN
M:R@D;5LG=7)L)UTL("1M96YU7W9I97<@/3T@)VEC;VXG(#\@)&U;)W1E>'0G
M72`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T
M*"1M6R=C;&%S<R==*2`_("1M6R=C;&%S<R==(#H@)R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:7-S970H)&U;)W1A<F=E="==*2`_("1M
M6R=T87)G970G72`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&ES<V5T*"1M6R=O;F-L:6-K)UTI(#\@)&U;)V]N8VQI8VLG72`Z("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+"`D86-C97-S
M:V5Y*3L*"B`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B7&X\;&D^
M)7,E<SQB<B`O/B5S/"]A/CPO;&D^(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1L:6YK+"`D:6-O;BP@*"1M96YU7W9I97<@(3T@)VEC;VXG
M*2`_($AO<F1E.CIH:6=H;&EG:'1!8V-E<W-+97DH)&U;)W1E>'0G72P@)&%C
M8V5S<VME>2D@.B`G)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U
M='!U="`N("<\+W5L/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!;GD@;&EN
M:W,@=&\@;W1H97(@2&]R9&4@87!P;&EC871I;VYS(&1E9FEN960@:6X@86X@
M87!P;&EC871I;VXG<R!C;VYF:6<*("`@("`J(&9I;&4@8GD@=&AE("1C;VYF
M6R=M96YU)UU;)V%P<',G72!A<G)A>2!A<F4@861D960@=&\@=&AE(&UE;G4@
M87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$%P<$QI;FMS*"D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8L("1R96=I<W1R>3L*"B`@("`@("`@
M:68@*&ES<V5T*"1C;VYF6R=M96YU)UU;)V%P<',G72D@)B8@:7-?87)R87DH
M)&-O;F9;)VUE;G4G75LG87!P<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H
M("@D8V]N9ELG;65N=2==6R=A<'!S)UT@87,@)&%P<"D@>PH@("`@("`@("`@
M("`@("`@:68@*"1R96=I<W1R>2T^9V5T*"=S=&%T=7,G+"`D87!P*2`A/2`G
M:6YA8W1I=F4G("8F("1R96=I<W1R>2T^:&%S4&5R;6ES<VEO;B@D87!P+"!0
M15)-4U]32$]7*2D@>PH@("`@("`@("`@("`@("`@("`@("1U<FP@/2`D<F5G
M:7-T<GDM/F=E=$EN:71I86Q086=E*"1A<'`I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-?82@D=7)L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H2&]R9&4Z.G5R;"@D=7)L*2P@
M)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2P@)')E9VES=')Y+3YG970H
M)VEC;VXG+"`D87!P*2P@)R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9"!A;GD@;W1H97(@;&EN:W,@9F]U;F0@:6X@
M)'1H:7,M/E]M96YU9FEL92!T;R!B92!I;F-L=61E9"!I;B!T:&4*("`@("`J
M(&UE;G4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%-I=&5,:6YK<R@I"B`@
M("!["B`@("`@("`@:68@*$!I<U]R96%D86)L92@D=&AI<RT^7VUE;G5F:6QE
M*2D@>PH@("`@("`@("`@("!I;F-L=61E("1T:&ES+3Y?;65N=69I;&4["B`@
M("`@("`@("`@(&EF("AI<W-E="@D7VUE;G4I("8F(&ES7V%R<F%Y*"1?;65N
M=2DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1?;65N=2!A<R`D;65N
M=6ET96TI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^861D07)R87DH
M)&UE;G5I=&5M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S964@
M:68@=&AE(&-U<G)E;G0@=7)L(&UA=&-H97,@=&AE(&=I=F5N('5R;"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&=I=F5N
M(%523"!I<R!T:&4@8W5R<F5N="!L;V-A=&EO;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@:7-396QE8W1E9"@D=7)L*0H@("`@>PH@("`@("`@("1S97)V97)?
M=7)L(#T@<&%R<V5?=7)L*"1?4T525D526R=02%!?4T5,1B==*3L*("`@("`@
M("`D8VAE8VM?=7)L(#T@<&%R<V5?=7)L*"1U<FPI.PH*("`@("`@("`O*B!4
M<GD@=&\@;6%T8V@@=&AE(&ET96TG<R!P871H(&%G86EN<W0@=&AE(&-U<G)E
M;G0@<V-R:7!T"B`@("`@("`@("`@9FEL96YA;64@87,@=V5L;"!A<R!O=&AE
M<B!P;W-S:6)L92!54DQS('1O('1H:7,@<V-R:7!T+B`J+PH@("`@("`@(&EF
M("AI<W-E="@D8VAE8VM?=7)L6R=P871H)UTI("8F"B`@("`@("`@("`@("@H
M)&-H96-K7W5R;%LG<&%T:"==(#T]("1S97)V97)?=7)L6R=P871H)UTI('Q\
M"B`@("`@("`@("`@("`H)&-H96-K7W5R;%LG<&%T:"==("X@)VEN9&5X+G!H
M<"<@/3T@)'-E<G9E<E]U<FQ;)W!A=&@G72D@?'P*("`@("`@("`@("`@("@D
M8VAE8VM?=7)L6R=P871H)UT@+B`G+VEN9&5X+G!H<"<@/3T@)'-E<G9E<E]U
M<FQ;)W!A=&@G72DI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1R964N<&AP````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,V-C<S(#$P-3$U-#,T,30P(#`R,#<V
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J($1I<W!L87D@97AT<F$@8V]L=6UN<R!T;R!T:&4@;&5F
M="!O9B!T:&4@;6%I;B!T<F5E+@H@*B\*9&5F:6YE*"=(3U)$15]44D5%7T58
M5%)!7TQ%1E0G+"`P*3L*"B\J*@H@*B!$:7-P;&%Y(&5X=')A(&-O;'5M;G,@
M=&\@=&AE(')I9VAT(&]F('1H92!M86EN('1R964N"B`J+PID969I;F4H)TA/
M4D1%7U12145?15A44D%?4DE'2%0G+"`Q*3L*"B\J*@H@*B!4:&4@<')E8V5D
M:6YG('1E>'0L(&)E9F]R92!T:&4@2&]R9&5?5')E92!I;G-T86YC92!N86UE
M+"!U<V5D(&9O<@H@*B!C;VQL87!S92]E>'!A;F0@<W5B;6ES<VEO;G,N"B`J
M+PID969I;F4H)TA/4D1%7U12145?5$]'1TQ%)RP@)VAT7W1O9V=L95\G*3L*
M"B\J*@H@*B!4:&4@2&]R9&5?5')E93HZ(&-L87-S('!R;W9I9&5S(&$@=')E
M92!V:65W(&]F(&AI97)A<F-H:6-A;"!I;F9O<FUA=&EO;BX@270*("H@86QL
M;W=S(&9O<B!E>'!A;F1I;F<O8V]L;&%P<VEN9R!O9B!B<F%N8VAE<R!A;F0@
M;6%I;G1A:6YS('1H96ER('-T871E+B!)=`H@*B!C86X@=V]R:R!T;V=E=&AE
M<B!W:71H('1H92!(;W)D95]4<F5E(&IA=F%S8W)I<'0@8VQA<W,@=&\@86-H
M:65V92!T:&ES(&EN"B`J($1(5$U,(&]N('-U<'!O<G1E9"!B<F]W<V5R<RX*
M("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-87)K;R!$:G5K:6,@/&UA<FMO
M0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO5')E92]4<F5E+G!H<"QV(#$N-#8N-BXQ,2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C0P(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA
M<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]4<F5E"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?5')E92!["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;F%M92!O9B!T:&ES(&EN<W1A;F-E+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEN<W1A;F-E(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($AA<V@@=VET:"!H96%D97(@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]H96%D97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06X@87)R
M87D@8V]N=&%I;FEN9R!A;&P@=&AE('1R964@;F]D97,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]N;V1E<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@=&]P+6QE=F5L(&YO9&5S(&EN('1H
M92!T<F5E+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?<F]O=%]N;V1E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!+
M965P(&-O=6YT(&]F(&AO=R!M86YY(&5X=')A(&-O;'5M;G,@=&AE<F4@87)E
M(&]N('1H92!L969T('-I9&4*("`@("`J(&]F('1H92!N;V1E+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]E>'1R85]C
M;VQS7VQE9G0@/2`P.PH*("`@("\J*@H@("`@("H@2V5E<"!C;W5N="!O9B!H
M;W<@;6%N>2!E>'1R82!C;VQU;6YS('1H97)E(&%R92!O;B!T:&4@<FEG:'0@
M<VED90H@("`@("H@;V8@=&AE(&YO9&4N"B`@("`@*@H@("`@("H@0'9A<B!I
M;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7V5X=')A7V-O;'-?<FEG:'0@/2`P
M.PH*("`@("\J*@H@("`@("H@3W!T:6]N('9A;'5E<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A
M>2@G;&EN97,G(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@4W1O<F5S('1H
M92!S;W)T:6YG(&-R:71E<FEA('1E;7!O<F%R:6QY+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-O<G1#<FET97)I83L*
M"B`@("`O*BH*("`@("`J(%5S92!S97-S:6]N('1O('-T;W)E(&-A8VAE9"!4
M<F5E(&1A=&$_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7W5S97-E<W-I;VX@/2!T<G5E.PH*("`@("\J*@H@("`@("H@
M4VAO=6QD('1H92!T<F5E(&)E(')E;F1E<F5D('-T871I8V%L;'D_"B`@("`@
M*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7W-T871I
M8R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?5')E90H@("`@("H@
M:6YS=&%N8V4@8F%S960@;VX@)&YA;64@86YD("1R96YD97)E<BX@270@=VEL
M;"!O;FQY(&-R96%T92!A"B`@("`@*B!N97<@:6YS=&%N8V4@:68@;F\@2&]R
M9&5?5')E92!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,*("`@
M("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@("`D=F%R(#T@)DAO<F1E
M7U1R964Z.G-I;F=L971O;B@D;F%M95LL("1R96YD97)E<ETI.PH@("`@("H*
M("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1N
M86UE("`@("`@0'-E92!(;W)D95]4<F5E.CIF86-T;W)Y+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<F5N9&5R97(@($!S964@2&]R9&5?5')E93HZ9F%C=&]R
M>2X*("`@("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R`@("!`<V5E($AO<F1E
M7U1R964Z.F9A8W1O<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]4
M<F5E("!4:&4@8V]N8W)E=&4@2&]R9&5?5')E92!R969E<F5N8V4L(&]R(%!%
M05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&YA;64L("1R96YD
M97)E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC
M("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D:60@/2`D;F%M92`N
M("<Z)R`N("1R96YD97)E<B`N("<Z)R`N('-E<FEA;&EZ92@D<&%R86US*3L*
M("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)&ED72DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<ULD:61=(#T@)DAO<F1E7U1R964Z.F9A8W1O<GDH
M)&YA;64L("1R96YD97)E<BP@)'!A<F%M<RD["B`@("`@("`@("`@(&EF("@A
M)&EN<W1A;F-E<ULD:61=+3YI<U-U<'!O<G1E9"@I*2!["B`@("`@("`@("`@
M("`@("`D<F5N9&5R97(@/2!(;W)D95]4<F5E.CIF86QL8F%C:R@D<F5N9&5R
M97(I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E;F1E<F5R+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R96YD
M97)E<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R
M;B!(;W)D95]4<F5E.CIS:6YG;&5T;VXH)&YA;64L("1R96YD97)E<BP@)'!A
M<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6YS=&%N8V5S6R1I9%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]4<F5E(&EN<W1A;F-E
M+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("`@5&AE(&YA;64@;V8@=&AI<R!T<F5E(&EN<W1A
M;F-E+@H@("`@("H@0'!A<F%M(&UI>&5D("`D<F5N9&5R97(@(%1H92!T>7!E
M(&]F(&-O;F-R971E($AO<F1E7U1R964@<W5B8VQA<W,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FXN(%1H:7,@:7,@8F%S960@
M;VX@=&AE(')E;F1E<FEN9R!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`H)')E;F1E<F5R*2X@5&AE(&-O9&4@:7,@9'EN86UI8V%L
M;'D@:6YC;'5D960N"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("`@
M06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@8V]N<W1R=6-T;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N965D<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N($AO<F1E7U1R964@(%1H92!N97=L>2!C<F5A=&5D(&-O
M;F-R971E($AO<F1E7U1R964@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9F86-T;W)Y*"1N86UE+"`D<F5N9&5R97(L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%)E<75I<F4@=&AE(')E;F1E
M<F5R(&QI8BX@*B\*("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+U1R964O)R`N("1R96YD97)E<B`N("<N<&AP)SL*"B`@("`@
M("`@)&-L87-S(#T@)TAO<F1E7U1R965?)R`N("1R96YD97)E<CL*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)'1R
M964@/2`F;F5W("1C;&%S<R@D;F%M92P@)'!A<F%M<RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1R964@/2!014%2.CIR86ES945R<F]R*'-P
M<FEN=&8H7R@B7"(E<UPB('1R964@<F5N9&5R97(@;F]T(&9O=6YD+B(I+"`D
M<F5N9&5R97(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=')E93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1R>2!T;R!F86QL(&)A8VL@=&\@82!S
M:6UP;&5R(')E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;B!S=')I;F<@
M)')E;F1E<F5R("!4:&4@<F5N9&5R97(@=&AA="!W92!C86XG="!H86YD;&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@?"!014%27T5R<F]R("!4
M:&4@;F5X="!B97-T(')E;F1E<F5R+"!O<B!A;B!E<G)O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B!W92=V92!R=6X@;W5T(&]F
M(')E;F1E<F5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9F%L;&)A8VLH)')E
M;F1E<F5R*0H@("`@>PH@("`@("`@('-W:71C:"`H)')E;F1E<F5R*2!["B`@
M("`@("`@8V%S92`G:F%V87-C<FEP="<Z"B`@("`@("`@("`@(')E='5R;B`G
M:'1M;"<["@H@("`@("`@(&-A<V4@)VAT;6PG.@H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;W5T(&]F(')E;F1E<F5R<R<I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@
M=&AI<R!T<F5E(&EN<W1A;F-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&%R
M86US("!!9&1I=&EO;F%L('!A<F%M971E<G,N"B`@("`@*B`\<')E/@H@("`@
M("H@)VYO<V5S<VEO;B<@("TM("`H8F]O;&5A;BD@268@=')U92P@9&\@;F]T
M('-T;W)E('1R964@9&%T82!I;B!S97-S:6]N+@H@("`@("H@/"]P<F4^"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7U1R964H)&YA;64L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6YS=&%N8V4@/2`D
M;F%M93L*("`@("`@("`D=&AI<RT^7W5S97-E<W-I;VX@/2!E;7!T>2@D<&%R
M86US6R=N;W-E<W-I;VXG72D["@H@("`@("`@("\J(%-E="!U<"!T:&4@<V5S
M<VEO;B!F;W(@;&%T97(@=&\@<V%V92!T<F5E('-T871E<RX@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]U<V5S97-S:6]N("8F"B`@("`@("`@("`@("%I<W-E
M="@D7U-%4U-)3TY;)VAO<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E72DI
M('L*("`@("`@("`@("`@)%]315-324].6R=H;W)D95]T<F5E)UU;)'1H:7,M
M/E]I;G-T86YC95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;F1E<G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'-T871I8R`@268@=')U92!T:&4@=')E92!N;V1E<R!C
M86XG="!B92!E>'!A;F1E9"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;&QA<'-E9"!A;F0@=&AE('1R964@9V5T<R!R96YD97)E9"!E
M>'!A;F1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R5')E92@D<W1A
M=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@96-H;R`D=&AI<RT^9V5T5')E
M92@D<W1A=&EC*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@86X@;W!T
M:6]N+@H@("`@("H@079A:6QA8FQE(&]P=&EO;G,Z"B`@("`@*B`\<')E/@H@
M("`@("H@("!A;'1E<FYA=&4@("`@+2T@($%L=&5R;F%T92!S:&%D:6YG(&EN
M('1H92!T86)L93\@*&)O;VQE86XI"B`@("`@*B`@(&AI9&5(96%D97)S("`M
M+2`@1&]N)W0@<F5N9&5R(&%N>2!(5$U,(&9O<B!T:&4@:&5A9&5R(')O=RP@
M:G5S="!U<V4@=&AE('=I9'1H<RX*("`@("`J("`@8VQA<W,@("`@("`@("TM
M("!4:&4@8VQA<W,@=&\@=7-E(&9O<B!T:&4@=&%B;&4N("AS=')I;F<I"B`@
M("`@*B`@(&QI;F5S("`@("`@("`M+2`@4VAO=R!T<F5E(&QI;F5S/R`H8F]O
M;&5A;BD*("`@("`J("`@;75L=&EL:6YE("`@("TM("!$;R!T:&4@;F]D92!L
M86)E;',@8V]N=&%I;B!L:6YE8G)E86MS/R`H8F]O;&5A;BD*("`@("`J(#PO
M<')E/@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;W!T:6]N("!4:&4@
M;W!T:6]N(&YA;64@+6]R+2!A;B!A<G)A>2!O9B!O<'1I;VX@;F%M92]V86QU
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('!A:7)S+@H@("`@("H@
M0'!A<F%M(&UI>&5D("1V86P@("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N*"1O<'1I;VYS+"`D=F%L=64@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&]P=&EO;G,I
M*2!["B`@("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)&]P=&EO;G,@/3X@
M)'9A;'5E*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1O<'1I;VYS
M(&%S("1O<'1I;VX@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;W!T:6]N<ULD;W!T:6]N72`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'971S(&%N(&]P=&EO;B=S('9A;'5E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO;B`@(%1H92!N86UE(&]F('1H
M92!O<'1I;VX@=&\@9F5T8V@N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:'1M
M;"`@("!4<G5E(&]R(&9A;'-E('=H971H97(@=&\@9F]R;6%T('1H92!R971U
M<FX@=F%L=64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&EN(&AT
M;6PN($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&5F875L="`@02!D969A=6QT('9A;'5E('1O('5S92!I;B!C87-E(&YO;F4@
M:7,@<V5T(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(')E<75E<W1E9"!O<'1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971/<'1I;VXH)&]P=&EO;BP@)&AT;6P@/2!F86QS92P@)&1E9F%U;'0@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1V86QU92`](&YU;&P["@H@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=*2`F)B`A:7-?;G5L
M;"@D9&5F875L="DI('L*("`@("`@("`@("`@+RH@4F5Q=65S=&5D(&]P=&EO
M;B!H87,@;F]T(&)E96X@8G5T('1H97)E(&ES(&$*("`@("`@("`@("`@("H@
M9&5F875L="X@*B\*("`@("`@("`@("`@)'9A;'5E(#T@)&1E9F%U;'0["B`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N
M72DI('L*("`@("`@("`@("`@+RH@4F5Q=65S=&5D(&]P=&EO;B!H87,@8F5E
M;B!S970L(&=E="!I=',@=F%L=64N("HO"B`@("`@("`@("`@("1V86QU92`]
M("1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N73L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D:'1M;"`F)B`A:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@("`@
M("\J($9O<FUA="!V86QU92!F;W(@:'1M;"!O=71P=70N("HO"B`@("`@("`@
M("`@("1V86QU92`]('-P<FEN=&8H)R`E<STB)7,B)RP@)&]P=&EO;BP@)'9A
M;'5E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F]D92!T;R!T:&4@;F]D92!T<F5E
M(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1I9"`@("`@
M("`@("`@5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)'!A<F5N="`@("`@("!4:&4@<&%R96YT)W,@=6YI<75E(&YO9&4@:60N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;&%B96P@("`@("`@(%1H92!T97AT
M(&QA8F5L(&9O<B!T:&4@;F]D92X*("`@("`J($!P87)A;2!S=')I;F<@("1I
M;F1E;G0@("`@("`@1&5P<F5C871E9"P@=&AI<R!I<R!C86QC=6QA=&5D(&%U
M=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8F%S960@;VX@=&AE('!A<F5N="!N;V1E+@H@("`@("H@0'!A<F%M(&)O
M;VQE86X@)&5X<&%N9&5D("`@("!)<R!T:&ES(&QE=F5L(&5X<&%N9&5D(&]R
M(&YO="X*("`@("`J($!P87)A;2!A<G)A>2`@("1P87)A;7,@("`@("`@06YY
M(&]T:&5R('!A<F%M971E<G,@=&\@<V5T("A`<V5E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9$YO9&5087)A;7,H*2!F;W(@9G5L
M;"!D971A:6QS*2X*("`@("`J($!P87)A;2!A<G)A>2`@("1E>'1R85]R:6=H
M="`@06YY(&]T:&5R(&-O;'5M;G,@=&\@9&ES<&QA>2!T;R!T:&4@<FEG:'0@
M;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1R
M964N"B`@("`@*B!`<&%R86T@87)R87D@("`D97AT<F%?;&5F="`@($%N>2!O
M=&AE<B!C;VQU;6YS('1O(&1I<W!L87D@=&\@=&AE(&QE9G0@;V8*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE('1R964N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$YO9&4H)&ED+"`D<&%R96YT+"`D;&%B96PL
M("1I;F1E;G0L("1E>'!A;F1E9"`]('1R=64L"B`@("`@("`@("`@("`@("`@
M("`@("1P87)A;7,@/2!A<G)A>2@I+"`D97AT<F%?<FEG:'0@/2!A<G)A>2@I
M+`H@("`@("`@("`@("`@("`@("`@("`D97AT<F%?;&5F="`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=L86)E;"==(#T@
M)&QA8F5L.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5S97-S:6]N*2!["B`@
M("`@("`@("`@("1S97-S:6]N7W-T871E(#T@)%]315-324].6R=H;W)D95]T
M<F5E)UU;)'1H:7,M/E]I;G-T86YC95T["B`@("`@("`@("`@("1T;V=G;&5?
M:60@/2!5=&EL.CIG971&;W)M1&%T82A(3U)$15]44D5%7U1/1T=,12`N("1T
M:&ES+3Y?:6YS=&%N8V4I.PH@("`@("`@("`@("!I9B`H)&ED(#T]("1T;V=G
M;&5?:60I('L*("`@("`@("`@("`@("`@("\J(%=E(&AA=F4@82!U<FP@=&]G
M9VQE(')E<75E<W0@9F]R('1H:7,@;F]D92X@*B\*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<V5S<VEO;E]S=&%T95LG97AP86YD960G75LD:61=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\J(%5S92!S97-S:6]N('-T871E(&EF
M(&ET(&ES('-E="X@*B\*("`@("`@("`@("`@("`@("`@("`D97AP86YD960@
M/2`H(21S97-S:6]N7W-T871E6R=E>'!A;F1E9"==6R1I9%TI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O*B!/=&AE
M<G=I<V4@=7-E('=H870@=V%S('!A<W-E9"!T:')O=6=H('1H90H@("`@("`@
M("`@("`@("`@("`@("`J(&9U;F-T:6]N+B`J+PH@("`@("`@("`@("`@("`@
M("`@("1E>'!A;F1E9"`]("@A)&5X<&%N9&5D*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`O*B!3879E('1H:7,@<W1A=&4@=&\@<V5S
M<VEO;BX@*B\*("`@("`@("`@("`@("`@("1?4T534TE/3ELG:&]R9&5?=')E
M92==6R1T:&ES+3Y?:6YS=&%N8V5=6R=E>'!A;F1E9"==6R1I9%T@/2`D97AP
M86YD960["B`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<V5S<VEO;E]S
M=&%T95LG97AP86YD960G75LD:61=*2D@>PH@("`@("`@("`@("`@("`@+RH@
M268@=V4@:&%V92!A('-A=F5D('-E<W-I;VX@<W1A=&4@=7-E(&ET+B`J+PH@
M("`@("`@("`@("`@("`@)&5X<&%N9&5D(#T@)'-E<W-I;VY?<W1A=&5;)V5X
M<&%N9&5D)UU;)&ED73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]N;V1E<ULD:61=6R=E>'!A;F1E9"==(#T@)&5X<&%N9&5D
M.PH*("`@("`@("`O*B!)9B!A;GD@<&%R86US(&EN8VQU9&5D(&AE<F4@861D
M('1H96T@;F]W+B`J+PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<RDI('L*
M("`@("`@("`@("`@)'1H:7,M/F%D9$YO9&5087)A;7,H)&ED+"`D<&%R86US
M*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(&%N>2!E>'1R82!C;VQU;6YS
M(&EN8VQU9&5D(&AE<F4@861D('1H96T@;F]W+B`J+PH@("`@("`@(&EF("@A
M96UP='DH)&5X=')A7W)I9VAT*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D
M3F]D945X=')A*"1I9"P@2$]21$5?5%)%15]%6%1205]224=(5"P@)&5X=')A
M7W)I9VAT*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D97AT<F%?
M;&5F="DI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$YO9&5%>'1R82@D:60L
M($A/4D1%7U12145?15A44D%?3$5&5"P@)&5X=')A7VQE9G0I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F5N="DI('L*("`@("`@("`@
M("`@:68@*"%I;E]A<G)A>2@D:60L("1T:&ES+3Y?<F]O=%]N;V1E<RDI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F]O=%]N;V1E<UM=(#T@)&ED.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?;F]D97-;)'!A<F5N=%U;)V-H:6QD<F5N)UTI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1P87)E;G1=6R=C:&EL
M9')E;B==(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(6EN7V%R<F%Y*"1I9"P@)'1H:7,M/E]N;V1E<ULD<&%R96YT75LG8VAI
M;&1R96XG72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)'!A
M<F5N=%U;)V-H:6QD<F5N)UU;72`]("1I9#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@861D:71I;VYA;"!P
M87)A;65T97)S('1O(&$@;F]D92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9"`@("`@5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N>2!O=&AE<B!P87)A;65T97)S('1O('-E="X*
M("`@("`J(#QP<F4^"B`@("`@*B!C;&%S<R`@("`@+2T@($-34R!C;&%S<R!T
M;R!U<V4@=VET:"!T:&ES(&YO9&4*("`@("`J(&EC;VX@("`@("`M+2`@26-O
M;B!T;R!D:7-P;&%Y(&YE>'0@;F]D90H@("`@("H@:6-O;F%L="`@("TM("!!
M;'0@=&5X="!T;R!U<V4@9F]R('1H92!I8V]N"B`@("`@*B!I8V]N9&ER("`@
M+2T@($EC;VX@9&ER96-T;W)Y"B`@("`@*B!I8V]N;W!E;B`@+2T@($EC;VX@
M=&\@:6YD:6-A=&4@=&AI<R!N;V1E(&%S(&5X<&%N9&5D"B`@("`@*B!O;F-L
M:6-K("`@+2T@($]N8VQI8VL@979E;G0@871T86-H960@=&\@=&AI<R!N;V1E
M"B`@("`@*B!U<FP@("`@("`@+2T@(%523"!T;R!L:6YK('1H92!N;V1E('1O
M"B`@("`@*B!U<FQC;&%S<R`@+2T@($-34R!C;&%S<R!F;W(@=&AE(&YO9&4G
M<R!54DP*("`@("`J('1A<F=E="`@("`M+2`@5&%R9V5T(&9O<B!T:&4@)W5R
M;"<@;&EN:PH@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$YO9&5087)A;7,H)&ED+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@("1A
M;&QO=V5D(#T@87)R87DH"B`@("`@("`@("`@("=C;&%S<R<L("=I8V]N)RP@
M)VEC;VYA;'0G+"`G:6-O;F1I<B<L("=I8V]N;W!E;B<L"B`@("`@("`@("`@
M("=O;F-L:6-K)RP@)W5R;"<L("=U<FQC;&%S<R<L("=T87)G970G+`H@("`@
M("`@("D["@H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M7VED
M(#T^("1P87)A;5]V86PI('L*("`@("`@("`@("`@+RH@4V5T(&]N;'D@86QL
M;W=E9"!A;F0@;F]N+6YU;&P@<&%R86US+B`J+PH@("`@("`@("`@("!I9B`H
M:6Y?87)R87DH)'!A<F%M7VED+"`D86QL;W=E9"D@)B8@(6ES7VYU;&PH)'!A
M<F%M7W9A;"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED
M75LD<&%R86U?:61=(#T@)'!A<F%M7W9A;#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@97AT<F$@8V]L=6UN
M<R!T;R!B92!D:7-P;&%Y960@=&\@=&AE('-I9&4@;V8@=&AE(&YO9&4N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&ED("`@("!4:&4@=6YI<75E
M(&YO9&4@:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VED92`@(%=H:6-H
M('-I9&4@=&\@<&QA8V4@=&AE(&5X=')A(&-O;'5M;G,@;VXN"B`@("`@*B!`
M<&%R86T@87)R87D@("`D97AT<F$@($5X=')A(&-O;'5M;G,@=&\@9&ES<&QA
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D3F]D945X=')A*"1I9"P@)'-I
M9&4L("1E>'1R82D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1E>'1R
M82DI('L*("`@("`@("`@("`@)&5X=')A(#T@87)R87DH)&5X=')A*3L*("`@
M("`@("!]"@H@("`@("`@("1C;VQ?8V]U;G0@/2!C;W5N="@D97AT<F$I.PH*
M("`@("`@("!S=VET8V@@*"1S:61E*2!["B`@("`@("`@8V%S92!(3U)$15]4
M4D5%7T585%)!7TQ%1E0Z"B`@("`@("`@("`@("1T:&ES+3Y?;F]D97-;)&ED
M75LG97AT<F$G75M(3U)$15]44D5%7T585%)!7TQ%1E1=(#T@)&5X=')A.PH@
M("`@("`@("`@("!I9B`H)&-O;%]C;W5N="`^("1T:&ES+3Y?97AT<F%?8V]L
M<U]L969T*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V5X=')A7V-O;'-?
M;&5F="`]("1C;VQ?8V]U;G0["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@2$]21$5?5%)%15]%6%1205]224=(5#H*
M("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=E>'1R82==6TA/4D1%
M7U12145?15A44D%?4DE'2%1=(#T@)&5X=')A.PH@("`@("`@("`@("!I9B`H
M)&-O;%]C;W5N="`^("1T:&ES+3Y?97AT<F%?8V]L<U]R:6=H="D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]E>'1R85]C;VQS7W)I9VAT(#T@)&-O;%]C
M;W5N=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T<R!T:&4@=')E92!B>2!T
M:&4@<W!E8VEF:65D(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8W)I=&5R:6$@(%1H92!N;V1E('!R;W!E<G1Y('1O('-O
M<G0@8GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:60@("`@("`@57-E9"!I
M;G1E<FYA;&QY(&9O<B!R96-U<G-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-O<G0H)&-R:71E<FEA+"`D:60@/2`M,2D*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;F]D97-;)&ED75LG8VAI;&1R96XG72DI('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C<FET
M97)I82`]/2`G:V5Y)RD@>PH@("`@("`@("`@("!K<V]R="@D=&AI<RT^7VYO
M9&5S6R1I9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?<V]R=$-R:71E<FEA(#T@)&-R:71E<FEA.PH@("`@
M("`@("`@("!U<V]R="@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UTL
M(&%R<F%Y*"1T:&ES+"`G7W-O<G0G*2D["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7VYO9&5S6R1I9%U;)V-H:6QD<F5N)UT@87,@)&-H
M:6QD*2!["B`@("`@("`@("`@("1T:&ES+3YS;W)T*"1C<FET97)I82P@)&-H
M:6QD*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!(96QP97(@
M;65T:&]D(&9O<B!S;W)T*"D@=&\@8V]M<&%R92!T=V\@=')E92!E;&5M96YT
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-O<G0H)&$L("1B*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]N;V1E<ULD85U;)'1H:7,M/E]S;W)T0W)I=&5R:6%=*2D@
M>PH@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7VYO9&5S6R1B75LD=&AI<RT^7W-O<G1#<FET97)I
M85TI*2!["B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('-T<F-O;&PH)'1H:7,M/E]N;V1E<ULD85U;)'1H:7,M/E]S
M;W)T0W)I=&5R:6%=+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;F]D97-;)&)=6R1T:&ES+3Y?<V]R=$-R:71E<FEA72D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AE('-P96-I9FEE9"!N;V1E
M(&ES(&-U<G)E;G1L>2!E>'!A;F1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&ED("!4:&4@=6YI<75E(&YO9&4@:60N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@;F]D92!I
M<R!E>'!A;F1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%>'!A;F1E9"@D
M:60I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D97-;)&ED
M72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F]D97-;)&ED75LG
M97AP86YD960G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!C;VQU;6X@:&5A9&5R<R!T;R!T
M:&4@=')E92!T86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&AE
M861E<B`@06X@87)R87D@8V]N=&%I;FEN9R!H87-H97,@=VET:"!H96%D97(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX@5&AE
M(&9O;&QO=VEN9R!K97ES(&%R92!A;&QO=V5D.@H@("`@("H@/'!R93X*("`@
M("`J(&AT;6P@("TM(%1H92!(5$U,(&-O;G1E;G0@;V8@=&AE(&AE861E<B!C
M96QL"B`@("`@*B!W:61T:"`M+2!4:&4@=VED=&@@;V8@=&AE(&AE861E<B!C
M96QL"B`@("`@*B!A;&EG;B`M+2!4:&4@86QI9VYM96YT(&EN<VED92!T:&4@
M:&5A9&5R(&-E;&P*("`@("`J(&-L87-S("TM(%1H92!#4U,@8VQA<W,@;V8@
M=&AE(&AE861E<B!C96QL"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T2&5A9&5R*"1H96%D97(I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]H96%D97(@/2`D:&5A9&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!I;F1E;G0@;&5V96P@9F]R(&5A8V@@;F]D92!I;B!T:&4@=')E92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD26YD96YT<R@D;F]D97,L("1I
M;F1E;G0@/2`P*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1N;V1E<R!A<R`D
M:60I('L*("`@("`@("`@("`@)'1H:7,M/E]N;V1E<ULD:61=6R=I;F1E;G0G
M72`]("1I;F1E;G0["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N
M;V1E<ULD:61=6R=C:&EL9')E;B==*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]B=6EL9$EN9&5N=',H)'1H:7,M/E]N;V1E<ULD:61=6R=C:&EL9')E
M;B==+"`D:6YD96YT("L@,2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]397)I86QI>F4N<&AP````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,C$Q-R`Q,#4Q-30S-#$T,"`P
M,C(P,#(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"F1E9FEN92@G4T5224%,25I%7U5.2TY/5TXG+"`M,2D["F1E
M9FEN92@G4T5224%,25I%7TY/3D4G+"`P*3L*9&5F:6YE*"=315))04Q)6D5?
M5T1$6"<L(#$I.PID969I;F4H)U-%4DE!3$E:15]"6DE0)RP@,BD["F1E9FEN
M92@G4T5224%,25I%7TE-05`X)RP@,RD["F1E9FEN92@G4T5224%,25I%7TE-
M05!55$8W)RP@-"D["F1E9FEN92@G4T5224%,25I%7TE-05!55$8X)RP@-2D[
M"F1E9FEN92@G4T5224%,25I%7T)!4TE#)RP@-BD["F1E9FEN92@G4T5224%,
M25I%7T=:7T1%1DQ!5$4G+"`W*3L*9&5F:6YE*"=315))04Q)6D5?1UI?0T]-
M4%)%4U,G+"`X*3L*9&5F:6YE*"=315))04Q)6D5?1UI?14Y#3T0G+"`Y*3L*
M9&5F:6YE*"=315))04Q)6D5?0D%3138T)RP@,3`I.PID969I;F4H)U-%4DE!
M3$E:15]344Q834PG+"`Q,2D["F1E9FEN92@G4T5224%,25I%7U)!5R<L(#$R
M*3L*9&5F:6YE*"=315))04Q)6D5?55),)RP@,3,I.PID969I;F4H)U-%4DE!
M3$E:15]55$8W)RP@,30I.PH*+RHJ(%5S92!315))04Q)6D5?551&-R!A;F0@
M4T5224%,25I%7T)!4TE#('-T86-K960N("`J+PID969I;F4H)U-%4DE!3$E:
M15]55$8W7T)!4TE#)RP@,34I.PH*"B\J*@H@*B!4:&4@4V5R:6%L:7IE.CH@
M8VQA<W,@<')O=FED97,@=F%R:6]U<R!M971H;V1S(&]F(&5N8V%P<W5L871I
M;F<@9&%T82X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5R:6%L:7IE+U-E
M<FEA;&EZ92YP:'`L=B`Q+C(U+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HS-"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!3=&5P:&%N92!(
M=71H97(@/'-H=71H97)`8FEG9F]O="YC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N
M8V]M/@H@*B!`<VEN8V4@("!(;W)D92`R+C`*("H@0'!A8VMA9V4@2&]R9&5?
M4V5R:6%L:7IE"B`J+PIC;&%S<R!(;W)D95]397)I86QI>F4@>PH*("`@("\J
M*@H@("`@("H@4V5R:6%L:7IE(&$@=F%L=64N"B`@("`@*@H@("`@("H@4V5E
M('1H92!L:7-T(&]F(&-O;G-T86YT<R!A="!T:&4@=&]P(&]F('1H92!F:6QE
M(&9O<B!T:&4@<V5R:6%L:7II;F<*("`@("`J('1E8VAN:7%U97,@=&AA="!C
M86X@8F4@=7-E9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@
M("`@5&AE(&1A=&$@=&\@8F4@<V5R:6%L:7IE9"X*("`@("`J($!P87)A;2!M
M:7AE9"`D;6]D92`@("!4:&4@;6]D92!O9B!S97)I86QI>F%T:6]N+B!#86X@
M8F4@96ET:&5R(&$@<VEN9VQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@;6]D92!O<B!A<G)A>2!O9B!M;V1E<RX@($EF(&%R<F%Y+"!W:6QL(&)E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V5R:6%L:7IE9"!I;B!T
M:&4@;W)D97(@<')O=FED960N"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M
M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@<V5R:6%L:7IA=&EO
M;B!M971H;V0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<FEA;&EZ
M960@9&%T82X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ
M92@D9&%T82P@)&UO9&4@/2!A<G)A>2A315))04Q)6D5?0D%324,I+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1M;V1E
M*2D@>PH@("`@("`@("`@("`D;6]D92`](&%R<F%Y*"1M;V1E*3L*("`@("`@
M("!]"@H@("`@("`@("\J(%)E='5R;B!N;W<@:68@;F\@9&%T82X@*B\*("`@
M("`@("!I9B`H96UP='DH)&1A=&$I("8F("%I<U]A<G)A>2@D9&%T82DI('L*
M("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4&%R<V4@=&AR;W5G:"!T:&4@;&ES="!O9B!S97)I86QI>FEN9R!M;V1E
M<RX@*B\*("`@("`@("!F;W)E86-H("@D;6]D92!A<R`D=F%L*2!["B`@("`@
M("`@("`@("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@;6]D92!I<R!S=7!P
M;W)T960N("HO"B`@("`@("`@("`@(&EF("@A2&]R9&5?4V5R:6%L:7IE.CIH
M87-#87!A8FEL:71Y*"1V86PI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G56YS=7!P;W)T960@<V5R:6%L:7IA=&EO;B!T
M>7!E)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@2&]R9&5?4V5R:6%L
M:7IE.CI?<V5R:6%L:7IE*"1D871A+"`D=F%L+"`D<&%R86US*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!397)I
M86QI>F4@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)B1D871A("`@("`@("`@("`@5&AE
M(&1A=&$@=&\@8F4@<V5R:6%L:7IE9"X*("`@("`J($!P87)A;2!M:7AE9"`D
M;6]D92`@("`@("`@("`@("!4:&4@;6]D92!O9B!S97)I86QI>F%T:6]N+B!#
M86X@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E
M:71H97(@82!S:6YG;&4@;6]D92!O<B!A<G)A>2!O9B!M;V1E<RX*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!A<G)A>2P@=VEL
M;"!B92!S97)I86QI>F5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&]R9&5R('!R;W9I9&5D+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1P87)A;7,@($%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AE
M('-E<FEA;&EZ871I;VX@;65T:&]D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=6ER97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S97)I86QI
M>F4H)B1D871A+"`D;6]D92P@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@
M("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@4T5224%,25I%7TY/
M3D4Z"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:
M15]"6DE0.@H@("`@("`@("`@("`D9&%T82`](&)Z8V]M<')E<W,H)&1A=&$L
M(#DL(#,P*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T52
M24%,25I%7U=$1%@Z"B`@("`@("`@("`@("1D871A(#T@=V1D>%]S97)I86QI
M>F5?=F%L=64H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M8V%S92!315))04Q)6D5?24U!4#@Z"B`@("`@("`@("`@("1D871A(#T@:6UA
M<%\X8FET*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@4T5224%,25I%7TE-05!55$8W.@H@("`@("`@("`@("`D9&%T82`](&EM
M87!?=71F-U]E;F-O9&4H)&1A=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92!315))04Q)6D5?24U!4%541C@Z"B`@("`@("`@("`@("1D
M871A(#T@:6UA<%]U=&8X*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@4T5224%,25I%7T=:7T1%1DQ!5$4Z"B`@("`@("`@("`@
M("1D871A(#T@9WID969L871E*"1D871A+"`Y*3L*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7T)!4TE#.@H@("`@("`@("`@
M("`D9&%T82`]('-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]#3TU04D534SH*("`@("`@
M("`@("`@)&1A=&$@/2!G>F-O;7!R97-S*"1D871A+"`Y*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7T)!4T4V-#H*("`@
M("`@("`@("`@)&1A=&$@/2!B87-E-C1?96YC;V1E*"1D871A*3L*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7T=:7T5.0T]$
M.@H@("`@("`@("`@("`D9&%T82`](&=Z96YC;V1E*"1D871A+"`Y*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T5224%,25I%7U)!5SH*
M("`@("`@("`@("`@)&1A=&$@/2!R87=U<FQE;F-O9&4H)&1A=&$I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?55),.@H@
M("`@("`@("`@("`D9&%T82`]('5R;&5N8V]D92@D9&%T82D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]344Q834PZ"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@("`@("`@
M)'-Q;#)X;6P@/2`F;F5W('AM;%]S<6PR>&UL*"D["B`@("`@("`@("`@("1D
M871A(#T@)'-Q;#)X;6PM/F=E=%A-3"@D9&%T82D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]55$8W.@H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH@("`@("`@("`@
M("`D9&%T82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1A=&$L("1P87)A
M;7,L("=U=&8M-R<I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92!315))04Q)6D5?551&-U]"05-)0SH*("`@("`@("`@("`@2&]R9&5?4V5R
M:6%L:7IE.CI?<V5R:6%L:7IE*"1D871A+"!315))04Q)6D5?551&-RP@)'!A
M<F%M<RD["B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W-E<FEA;&EZ
M92@D9&%T82P@4T5224%,25I%7T)!4TE#+"`D<&%R86US*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@56YS
M97)I86QI>F4@82!V86QU92X*("`@("`J"B`@("`@*B!3964@=&AE(&QI<W0@
M;V8@8V]N<W1A;G1S(&%T('1H92!T;W`@;V8@=&AE(&9I;&4@9F]R('1H92!S
M97)I86QI>FEN9PH@("`@("H@=&5C:&YI<75E<R!T:&%T(&-A;B!B92!U<V5D
M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@("`@("`@("`@
M("!4:&4@9&%T82!T;R!B92!U;G-E<FEA;&EZ960N"B`@("`@*B!`<&%R86T@
M;6EX960@)&UO9&4@("`@5&AE(&UO9&4@;V8@=6YS97)I86QI>F%T:6]N+B`@
M0V%N(&)E(&5I=&AE<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M<VEN9VQE(&UO9&4@;W(@87)R87D@;V8@;6]D97,N("!)9B!A<G)A>2P@=VEL
M;"!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('5N<V5R:6%L:7IE
M9"!I;B!T:&4@;W)D97(@<')O=FED960N"B`@("`@*B!`<&%R86T@;6EX960@
M)'!A<F%M<R`@06YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!T:&4@=6YS97)I
M86QI>F%T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;65T:&]D
M(')E<75I<F5S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M=6YS97)I86QI>F5D(&1A=&$N"B`@("`@*B`@("`@("`@("`@("`@("`@4F5T
M=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!U;G-E<FEA;&EZ92@D9&%T82P@)&UO9&4@/2!315))04Q)6D5?0D%324,L
M("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH
M)&UO9&4I*2!["B`@("`@("`@("`@("1M;V1E(#T@87)R87DH)&UO9&4I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&YO=R!I9B!N;R!D871A+B`J
M+PH@("`@("`@(&EF("AE;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@<F5T
M=7)N("1D871A.PH@("`@("`@('T*"B`@("`@("`@+RH@4&%R<V4@=&AR;W5G
M:"!T:&4@;&ES="!O9B!U;G-E<FEA;&EZ:6YG(&UO9&5S+B`J+PH@("`@("`@
M(&9O<F5A8V@@*"1M;V1E(&%S("1V86PI('L*("`@("`@("`@("`@+RH@0VAE
M8VL@=&\@;6%K92!S=7)E('1H92!M;V1E(&ES('-U<'!O<G1E9"X@*B\*("`@
M("`@("`@("`@:68@*"%(;W)D95]397)I86QI>F4Z.FAA<T-A<&%B:6QI='DH
M)'9A;"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=5;G-U<'!O<G1E9"!U;G-E<FEA;&EZ871I;VX@='EP92<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@($AO<F1E7U-E<FEA;&EZ93HZ7W5N<V5R
M:6%L:7IE*"1D871A+"`D=F%L+"`D<&%R86US*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5;G-E<FEA;&EZ92!D
M871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`F)&1A=&$@("!4:&4@9&%T82!T;R!B92!U;G-E
M<FEA;&EZ960N"B`@("`@*B!`<&%R86T@;6EX960@)&UO9&4@("`@5&AE(&UO
M9&4@;V8@=6YS97)I86QI>F%T:6]N+B!#86X@8F4@96ET:&5R(&$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!S:6YG;&4@;6]D92!O<B!A<G)A>2!O
M9B!M;V1E<RX@($EF(&%R<F%Y+"!W:6QL(&)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@=6YS97)I86QI>F5D(&EN('1H92!O<F1E<B!P<F]V:61E
M9"X*("`@("`J($!P87)A;2!M:7AE9"`D<&%R86US("!!;GD@861D:71I;VYA
M;"!P87)A;65T97)S('1H92!U;G-E<FEA;&EZ871I;VX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!M971H;V0@<F5Q=6ER97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]U;G-E<FEA;&EZ92@F)&1A=&$L("1M;V1E+"`D<&%R86US
M(#T@;G5L;"D*("`@('L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@
M("`@8V%S92!315))04Q)6D5?3D].13H*("`@("`@("!C87-E(%-%4DE!3$E:
M15]344Q834PZ"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%-%
M4DE!3$E:15]205<Z"B`@("`@("`@("`@("1D871A(#T@<F%W=7)L9&5C;V1E
M*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T52
M24%,25I%7U523#H*("`@("`@("`@("`@)&1A=&$@/2!U<FQD96-O9&4H)&1A
M=&$I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)
M6D5?5T1$6#H*("`@("`@("`@("`@)&1A=&$@/2!W9&1X7V1E<V5R:6%L:7IE
M*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@4T52
M24%,25I%7T):25`Z"B`@("`@("`@("`@("1D871A(#T@8GID96-O;7!R97-S
M*"1D871A+"!F86QS92D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E(%-%4DE!3$E:15])34%0551&-SH*("`@("`@("`@("`@)&1A=&$@/2!I
M;6%P7W5T9C=?9&5C;V1E*"1D871A*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@4T5224%,25I%7T)!4TE#.@H@("`@("`@("`@("`D9&%T
M82`]($!U;G-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]$149,051%.@H@("`@("`@("`@
M("`D9&%T82`](&=Z:6YF;&%T92@D9&%T82D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]"05-%-C0Z"B`@("`@("`@("`@
M("1D871A(#T@8F%S938T7V1E8V]D92@D9&%T82D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]#3TU04D534SH*("`@
M("`@("`@("`@)&1A=&$@/2!G>G5N8V]M<')E<W,H)&1A=&$I.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!315))04Q)6D5?551&-SH*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@
M("`@("`@("`@)&1A=&$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D871A
M+"`G=71F+3<G+"`D<&%R86US*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@4T5224%,25I%7U541C=?0D%324,Z"B`@("`@("`@("`@($AO
M<F1E7U-E<FEA;&EZ93HZ7W5N<V5R:6%L:7IE*"1D871A+"!315))04Q)6D5?
M0D%324,L("1P87)A;7,I.PH@("`@("`@("`@("!(;W)D95]397)I86QI>F4Z
M.E]U;G-E<FEA;&EZ92@D9&%T82P@4T5224%,25I%7U541C<L("1P87)A;7,I
M.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:R!W:&5T:&5R(&]R(&YO="!A('-E<FEA;&EZ871I;VX@
M;65T:&]D(&ES('-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D;6]D92`@5&AE('-E<FEA;&EZ871I;VX@;65T:&]D+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!S=7!P;W)T960L(&9A
M;'-E(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S0V%P86)I;&ET
M>2@D;6]D92D*("`@('L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@
M("`@8V%S92!315))04Q)6D5?0EI)4#H*("`@("`@("`@("`@<F5T=7)N(%5T
M:6PZ.F5X=&5N<VEO;D5X:7-T<R@G8GHR)RD["@H@("`@("`@(&-A<V4@4T52
M24%,25I%7U=$1%@Z"B`@("`@("`@("`@(')E='5R;B!5=&EL.CIE>'1E;G-I
M;VY%>&ES=',H)W=D9'@G*3L*"B`@("`@("`@8V%S92!315))04Q)6D5?24U!
M4%541C<Z"B`@("`@("`@8V%S92!315))04Q)6D5?24U!4%541C@Z"B`@("`@
M("`@8V%S92!315))04Q)6D5?24U!4#@Z"B`@("`@("`@("`@(')E='5R;B!5
M=&EL.CIE>'1E;G-I;VY%>&ES=',H)VEM87`G*3L*"B`@("`@("`@8V%S92!3
M15))04Q)6D5?1UI?1$5&3$%413H*("`@("`@("!C87-E(%-%4DE!3$E:15]'
M6E]#3TU04D534SH*("`@("`@("!C87-E(%-%4DE!3$E:15]'6E]%3D-/1#H*
M("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>FQI
M8B<I.PH*("`@("`@("!C87-E(%-%4DE!3$E:15]344Q834PZ"B`@("`@("`@
M("`@(')E='5R;B!`:6YC;'5D95]O;F-E("=834PO<W%L,GAM;"YP:'`G.PH*
M("`@("`@("!C87-E(%-%4DE!3$E:15].3TY%.@H@("`@("`@(&-A<V4@4T52
M24%,25I%7T)!4TE#.@H@("`@("`@(&-A<V4@4T5224%,25I%7T)!4T4V-#H*
M("`@("`@("!C87-E(%-%4DE!3$E:15]205<Z"B`@("`@("`@8V%S92!315))
M04Q)6D5?55),.@H@("`@("`@(&-A<V4@4T5224%,25I%7U541C<Z"B`@("`@
M("`@8V%S92!315))04Q)6D5?551&-U]"05-)0SH*("`@("`@("`@("`@<F5T
M=7)N('1R=64["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M1&%T82YP:'``````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,S0U-C$@,3`U,34T,S0Q-#`@,#(P-S,R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL*"B\O($EM<&]R="!C;VYS=&%N=',*+RHJ($EM<&]R
M="!A;')E861Y(&UA<'!E9"!C<W8@9&%T82X@("`@("`@("HO(&1E9FEN92@G
M24U03U)47TU!4%!%1"<L(#$I.PHO*BH@36%P(&1A=&4@86YD('1I;64@96YT
M<FEE<R!O9B!C<W8@9&%T82X@*B\@9&5F:6YE*"=)35!/4E1?1$%4151)344G
M+"`R*3L*+RHJ($EM<&]R="!G96YE<FEC($-35B!D871A+B`@("`@("`@("`@
M("`@("HO(&1E9FEN92@G24U03U)47T-35B<L(#,I.PHO*BH@26UP;W)T($U3
M($]U=&QO;VL@9&%T82X@("`@("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/
M4E1?3U543$]/2R<L(#0I.PHO*BH@26UP;W)T('9#86QE;F1A<B]I0V%L96YD
M87(@9&%T82X@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?24-!3$5.1$%2)RP@
M-2D["B\J*B!);7!O<G0@=D-A<F1S+B`@("`@("`@("`@("`@("`@("`@("`@
M("`J+R!D969I;F4H)TE-4$]25%]60T%21"<L(#8I.PHO*BH@26UP;W)T(&=E
M;F5R:6,@='-V(&1A=&$N("`@("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/
M4E1?5%-6)RP@-RD["B\J*B!);7!O<G0@375L8F5R<GD@861D<F5S<R!B;V]K
M(&1A=&$@("`@("`J+R!D969I;F4H)TE-4$]25%]-54Q"15)262<L(#@I.PHO
M*BH@26UP;W)T(%!I;F4@861D<F5S<R!B;V]K(&1A=&$N("`@("`@("`@*B\@
M9&5F:6YE*"=)35!/4E1?4$E.12<L(#DI.PHO*BH@26UP;W)T(&9I;&4N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*B\@9&5F:6YE*"=)35!/4E1?1DE,
M12<L(#$Q*3L*+RHJ($EM<&]R="!D871A+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("HO(&1E9FEN92@G24U03U)47T1!5$$G+"`Q,BD["@HO+R!%>'!O
M<G0@8V]N<W1A;G1S"B\J*B!%>'!O<G0@9V5N97)I8R!#4U8@9&%T82X@*B\@
M9&5F:6YE*"=%6%!/4E1?0U-6)RP@,3`P*3L*+RHJ($5X<&]R="!I0V%L96YD
M87(@9&%T82X@("`J+R!D969I;F4H)T584$]25%])0T%,14Y$05(G+"`Q,#$I
M.PHO*BH@17AP;W)T('9#87)D<RX@("`@("`@("`@("HO(&1E9FEN92@G15A0
M3U)47U9#05)$)RP@,3`R*3L*+RHJ($5X<&]R="!44U8@9&%T82X@("`@("`@
M("`J+R!D969I;F4H)T584$]25%]44U8G+"`Q,#,I.PHO*BH@17AP;W)T($]U
M=&QO;VL@0U-6(&1A=&$N("HO(&1E9FEN92@G15A03U)47T]55$Q/3TM#4U8G
M+"`Q,#0I.PH*+RHJ"B`J($%B<W1R86-T(&-L87-S('1O(&AA;F1L92!D:69F
M97)E;G0@:VEN9',@;V8@1&%T82!F;W)M871S(&%N9"!T;PH@*B!H96QP(&1A
M=&$@97AC:&%N9V4@8F5T=V5E;B!(;W)D92!A<'!L:6-A=&EO;G,@86YD(&5X
M=&5R;F%L('-O=7)C97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T1A=&$O
M1&%T82YP:'`L=B`Q+C@P+C$P+C$R(#(P,#8O,#@O,#@@,3<Z,34Z,C(@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R
M9&5?1&%T82!E>'1E;F1S(%!%05(@>PH*("`@('9A<B`D7V5X=&5N<VEO;CL*
M("`@('9A<B`D7V-O;G1E;G14>7!E(#T@)W1E>'0O<&QA:6XG.PH*("`@("\J
M*@H@("`@("H@02!L:7-T(&]F('=A<FYI;F=S(')A:7-E9"!D=7)I;F<@=&AE
M(&QA<W0@;W!E<F%T:6]N+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S
M+C$*("`@("`J+PH@("`@=F%R("1?=V%R;FEN9W,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@4W1U8B!T;R!I;7!O<G0@<&%S<V5D(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&EM<&]R=$1A=&$H*0H@("`@>PH@("`@?0H*("`@
M("\J*@H@("`@("H@4W1U8B!T;R!R971U<FX@97AP;W)T960@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1&%T82@I"B`@("!["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3='5B('1O(&EM<&]R="!A(&9I;&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&EM<&]R=$9I;&4H)&9I;&5N86UE+"`D:&5A9&5R(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT
M<R@D9FEL96YA;64I.PH@("`@("`@(')E='5R;B`D=&AI<RT^:6UP;W)T1&%T
M82@D9&%T82P@)&AE861E<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3='5B
M('1O(&5X<&]R="!D871A('1O(&$@9FEL92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@97AP;W)T1FEL92@I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M<FEE<R!T;R!D971E<FUI;F4@=&AE(&5X<&5C=&5D(&YE=VQI;F4@8VAA<F%C
M=&5R(&)A<V5D(&]N('1H90H@("`@("H@<&QA=&9O<FT@:6YF;W)M871I;VX@
M<&%S<V5D(&)Y('1H92!B<F]W<V5R)W,@86=E;G0@:&5A9&5R+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9W5E<W-E9"!E>'!E8W1E9"!N
M97=L:6YE(&-H87)A8W1E<G,L(&5I=&AE<B!<;BP@7'(*("`@("`J("`@("`@
M("`@("`@("`@("!O<B!<<EQN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.
M97=L:6YE*"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)R
M;W=S97(N<&AP)SL*("`@("`@("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG
M;&5T;VXH*3L*"B`@("`@("`@<W=I=&-H("@D8G)O=W-E<BT^9V5T4&QA=&9O
M<FTH*2D@>PH@("`@("`@(&-A<V4@)W=I;B<Z"B`@("`@("`@("`@(')E='5R
M;B`B7')<;B(["@H@("`@("`@(&-A<V4@)VUA8R<Z"B`@("`@("`@("`@(')E
M='5R;B`B7'(B.PH*("`@("`@("!C87-E("=U;FEX)SH*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!R971U<FX@(EQN(CL*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T1FEL96YA;64H)&)A<V5N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`D8F%S96YA;64@+B`G+B<@+B`D=&AI<RT^7V5X=&5N
M<VEO;CL*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!W87)N:6YG<R!T
M:&%T(&AA=F4@8F5E;B!R86ES960@9'5R:6YG('1H92!L87-T"B`@("`@*B!O
M<&5R871I;VXN"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@*'!O<W-I8FQY(&5M<'1Y*2!L
M:7-T(&]F('=A<FYI;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W87)N:6YG
M<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=V%R;FEN9W,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!(;W)D95]$871A(&EN<W1A;F-E(&)A<V5D(&]N("1F;W)M870N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1F;W)M870@(%1H92!T>7!E(&]F
M(&-O;F-R971E($AO<F1E7T1A=&$@<W5B8VQA<W,@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FXN($EF("1F;W)M870@:7,@86X@87)R
M87DL('1H96X@=V4@=VEL;"!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@:6X@)&9O<FUA=%LP72]L:6(O1&%T82\@9F]R('1H92!S=6)C;&%S
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N
M(&YA;65D("1F;W)M871;,5TN<&AP+@H@("`@("H*("`@("`J($!R971U<FX@
M2&]R9&5?1&%T82`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?
M1&%T82!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T
M;W)Y*"1F;W)M870I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1F;W)M
M870I*2!["B`@("`@("`@("`@("1A<'`@/2`D9F]R;6%T6S!=.PH@("`@("`@
M("`@("`D9F]R;6%T(#T@)&9O<FUA=%LQ73L*("`@("`@("!]"@H@("`@("`@
M("1F;W)M870@/2!B87-E;F%M92@D9F]R;6%T*3L*"B`@("`@("`@:68@*&5M
M<'1Y*"1F;W)M870I('Q\("AS=')C;7`H)&9O<FUA="P@)VYO;F4G*2`]/2`P
M*2D@>PH@("`@("`@("`@("`D9&%T82`])B!N97<@2&]R9&5?1&%T82@I.PH@
M("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@
M)R]L:6(O1&%T82\G("X@)&9O<FUA="`N("<N<&AP)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T1A=&$O)R`N
M("1F;W)M870@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@("1C;&%S<R`]
M("=(;W)D95]$871A7R<@+B`D9F]R;6%T.PH@("`@("`@(&EF("AC;&%S<U]E
M>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D9&%T82`])B!N97<@)&-L
M87-S*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A=&$@/2!0
M14%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA
M<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E
M='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7T1A=&$@:6YS
M=&%N8V4*("`@("`J(&)A<V5D(&]N("1F;W)M870N($ET('=I;&P@;VYL>2!C
M<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?1&%T80H@("`@("H@
M:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E
M>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M
M=6QT:7!L92!D871A('-O=7)C97,@*&%N9"P@=&AU<RP@;75L=&EP;&4*("`@
M("`J($AO<F1E7T1A=&$@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R
M(#T@)DAO<F1E7T1A=&$Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9F]R;6%T("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D
M95]$871A('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;BX*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T1A=&$@
M(%1H92!C;VYC<F5T92!(;W)D95]$871A(')E9F5R96YC92P@;W(@9F%L<V4@
M;VX@86X*("`@("`J("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&9O<FUA="D*("`@('L*("`@
M("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92@D
M9F]R;6%T*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA
M='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@
M/2`F2&]R9&5?1&%T83HZ9F%C=&]R>2@D9F]R;6%T*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*
M("`@("\J*@H@("`@("H@36%P<R!A(&1A=&4O=&EM92!S=')I;F<@=&\@86X@
M87-S;V-I871I=F4@87)R87DN"B`@("`@*@H@("`@("H@5&AE(&UE=&AO9"!S
M:6=N871U<F4@:&%S(&-H86YG960@:6X@2&]R9&4@,RXQ+C,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&%T92`@(%1H92!D871E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M='EP92`@($]N92!O9B`G9&%T92<L("=T:6UE)R!O<B`G9&%T971I;64G+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1W;RUD:6UE;G-I;VYA;"!A
M<G)A>2!W:71H(&%D9&ET:6]N86P@:6YF;W)M871I;VX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!A8F]U="!T:&4@9F]R;6%T=&EN9RX@4&]S<VEB
M;&4@:V5Y<R!A<F4Z/'!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!D96QI;6ET97(@+2T@5&AE(&-H87)A8W1E<B!T:&%T('-E<&5R871E<R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9&EF9F5R96YT(&1A=&4O=&EM92!P87)T<RX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!F;W)M870@+2T@268@)V%M<&TG(&%N9"`D9&%T92!C;VYT
M86EN<R!A('1I;64@=V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87-S=6UE('1H870@:70@:7,@:6X@04TO4$T@9F]R;6%T+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]R9&5R("TM($EF("1T>7!E
M(&ES("=D871E=&EM92<@=&AE(&]R9&5R(&]F('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1A>2!A;F0@=&EM92!P87)T<SH@
M+3$@*'1I;65S=&%M<"DL(#`*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`H9&%Y+W1I;64I+"`Q("AT:6UE+V1A>2DN"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D:V5Y("`@5&AE(&ME>2!T;R!U<V4@9F]R("1P87)A
M;7,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D871E(&]R
M('1I;64@:6X@25-/(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@;6%P
M1&%T92@D9&%T92P@)'1Y<&4L("1P87)A;7,L("1K97DI"B`@("!["B`@("`@
M("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@(&-A<V4@)V1A=&4G.@H@("`@
M("`@(&-A<V4@)VUO;G1H9&%Y)SH*("`@("`@("!C87-E("=M;VYT:&1A>7EE
M87(G.@H@("`@("`@("`@("`D9&%T97,@/2!E>'!L;V1E*"1P87)A;7-;)V1E
M;&EM:71E<B==6R1K97E=+"`D9&%T92D["B`@("`@("`@("`@(&EF("AC;W5N
M="@D9&%T97,I("$](#,I('L*("`@("`@("`@("`@("`@(')E='5R;B`D9&%T
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6YD97@@/2!A<G)A>5]F
M;&EP*&5X<&QO9&4H)R\G+"`D<&%R86US6R=F;W)M870G75LD:V5Y72DI.PH@
M("`@("`@("`@("!R971U<FX@)&1A=&5S6R1I;F1E>%LG>65A<B==72`N("<M
M)R`N("1D871E<ULD:6YD97A;)VUO;G1H)UU=("X@)RTG("X@)&1A=&5S6R1I
M;F1E>%LG;61A>2==73L*"B`@("`@("`@8V%S92`G=&EM92<Z"B`@("`@("`@
M("`@("1D871E<R`](&5X<&QO9&4H)'!A<F%M<ULG9&5L:6UI=&5R)UU;)&ME
M>5TL("1D871E*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1D871E<RD@/"`R
M('Q\(&-O=6YT*"1D871E<RD@/B`S*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&1A=&4["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1P87)A
M;7-;)V9O<FUA="==6R1K97E=(#T]("=A;7!M)RD@>PH@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<RAS=')T;VQO=V5R*"1D871E<UMC;W5N="@D9&%T97,I
M+3%=*2P@)W!M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"1D871E<ULP72`A/3T@)S$R)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%T97-;,%T@*ST@,3(["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D871E<ULP72`]/2`G,3(G*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1A=&5S6S!=(#T@)S`G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&5S6V-O=6YT*"1D871E
M<RD@+2`Q72`]('-P<FEN=&8H)R4P,F0G+"`D9&%T97-;8V]U;G0H)&1A=&5S
M*2TQ72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1D871E
M<ULP72`N("<Z)R`N("1D871E<ULQ72`N("AC;W5N="@D9&%T97,I(#T](#,@
M/R`H)SHG("X@)&1A=&5S6S)=*2`Z("<Z,#`G*3L*"B`@("`@("`@8V%S92`G
M9&%T971I;64G.@H@("`@("`@("`@("!S=VET8V@@*"1P87)A;7-;)V]R9&5R
M)UU;)&ME>5TI('L*("`@("`@("`@("`@8V%S92`M,3H*("`@("`@("`@("`@
M("`@(')E='5R;B`H<W1R:6YG*2AI;G0I)&1A=&4@/3T@)&1A=&4*("`@("`@
M("`@("`@("`@("`@("`_(&1A=&4H)UDM;2UD($@Z:3IS)RP@)&1A=&4I"B`@
M("`@("`@("`@("`@("`@("`@.B`D9&%T93L*("`@("`@("`@("`@8V%S92`P
M.@H@("`@("`@("`@("`@("`@;&ES="@D9&%Y+"`D=&EM92D@/2!E>'!L;V1E
M*"<@)RP@)&1A=&4L(#(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@("`@;&ES="@D=&EM92P@)&1A
M>2D@/2!E>'!L;V1E*"<@)RP@)&1A=&4L(#(I.PH@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T92`]("1T:&ES
M+3YM87!$871E*"1D87DL("=D871E)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G9&5L:6UI=&5R)R`]/B`D<&%R86US6R=D
M87E?9&5L:6UI=&5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9O<FUA="<@/3X@)'!A<F%M<ULG9&%Y7V9O<FUA="==
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y*3L*
M("`@("`@("`@("`@)'1I;64@/2`D=&AI<RT^;6%P1&%T92@D=&EM92P@)W1I
M;64G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=D96QI;6ET97(G(#T^("1P87)A;7-;)W1I;65?9&5L:6UI=&5R)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9O<FUA
M="<@/3X@)'!A<F%M<ULG=&EM95]F;W)M870G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&ME>2D["B`@("`@("`@("`@(')E='5R
M;B`D9&%T92`N("<@)R`N("1T:6UE.PH*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!486ME<R!A;&P@;F5C97-S87)Y(&%C=&EO;G,@9F]R('1H
M92!G:79E;B!I;7!O<G0@<W1E<"P@<&%R86UE=&5R<R!A;F0*("`@("`J(&9O
M<FT@=F%L=65S(&%N9"!R971U<FYS('1H92!N97AT(&YE8V5S<V%R>2!S=&5P
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VX@(%1H92!C
M=7)R96YT('-T97`N($]N92!O9B!T:&4@24U03U)47RH@8V]N<W1A;G1S+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;2`@("`@06X@87-S;V-I871I=F4@
M87)R87D@8V]N=&%I;FEN9R!N965D960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('!A<F%M971E<G,@9F]R('1H92!C=7)R96YT('-T97`N"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!N97AT('-T
M97`@87,@86X@:6YT96=E<B!C;VYS=&%N="!O<B!I;7!O<G1E9`H@("`@("H@
M("`@("`@("`@("`@("`@9&%T82!S970@869T97(@=&AE(&9I;F%L('-T97`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'13=&5P*"1A8W1I;VXL("1P87)A
M;2`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@1FER<W0@<W1E<"X@*B\*
M("`@("`@("!I9B`H:7-?;G5L;"@D86-T:6]N*2D@>PH@("`@("`@("`@("`D
M7U-%4U-)3TY;)VEM<&]R=%]D871A)UT@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!R971U<FX@24U03U)47T9)3$4["B`@("`@("`@?0H*("`@("`@("!S=VET
M8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@
M("`@("`@("`O*B!386YI=&EZ92!U<&QO861E9"!F:6QE+B`J+PH@("`@("`@
M("`@("`D:6UP;W)T7V9O<FUA="`](%5T:6PZ.F=E=$9O<FU$871A*"=I;7!O
M<G1?9F]R;6%T)RD["B`@("`@("`@("`@("1C:&5C:U]U<&QO860@/2!"<F]W
M<V5R.CIW87-&:6QE57!L;V%D960H)VEM<&]R=%]F:6QE)RP@)'!A<F%M6R=F
M:6QE7W1Y<&5S)UU;)&EM<&]R=%]F;W)M871=*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&-H96-K7W5P;&]A9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1C:&5C:U]U<&QO860["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1?1DE,15-;)VEM<&]R=%]F:6QE)UU;)W-I>F4G
M72`\/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")4:&4@9FEL92!C;VYT86EN960@;F\@9&%T82XB*2D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==
M6R=F;W)M870G72`]("1I;7!O<G1?9F]R;6%T.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92!)35!/4E1?34%04$5$.@H@("`@("`@("`@("`D
M9&%T84ME>7,@/2!5=&EL.CIG971&;W)M1&%T82@G9&%T84ME>7,G+"`G)RD[
M"B`@("`@("`@("`@("1A<'!+97ES(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P
M<$ME>7,G+"`G)RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D9&%T84ME>7,I
M('Q\(&5M<'1Y*"1A<'!+97ES*2D@>PH@("`@("`@("`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H7R@B66]U(&1I9&XG="!M87`@86YY(&9I96QD<R!F
M<F]M('1H92!I;7!O<G1E9"!F:6QE('1O('1H92!C;W)R97-P;VYD:6YG(&9I
M96QD<R!I;B`E<RXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E9VES=')Y+3YG970H)VYA;64G*2DI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1D871A2V5Y<R`](&5X<&QO9&4H
M(EQT(BP@)&1A=&%+97ES*3L*("`@("`@("`@("`@)&%P<$ME>7,@/2!E>'!L
M;V1E*")<="(L("1A<'!+97ES*3L*("`@("`@("`@("`@)&UA<"`](&%R<F%Y
M*"D["B`@("`@("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1A<'!+97ES(&%S("1K97D@/3X@)&%P<"D@>PH@("`@("`@
M("`@("`@("`@)&UA<%LD9&%T84ME>7-;)&ME>5U=(#T@)&%P<#L*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<&%R86U;)W1I;65?9FEE;&1S)UTI("8F
M"B`@("`@("`@("`@("`@("`@("`@:7-S970H)'!A<F%M6R=T:6UE7V9I96QD
M<R==6R1A<'!=*2D@>PH@("`@("`@("`@("`@("`@("`@("1D871E<ULD9&%T
M84ME>7-;)&ME>5U=6R=T>7!E)UT@/2`D<&%R86U;)W1I;65?9FEE;&1S)UU;
M)&%P<%T["B`@("`@("`@("`@("`@("`@("`@)&1A=&5S6R1D871A2V5Y<ULD
M:V5Y75U;)W9A;'5E<R==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@
M("`D:2`](#`["B`@("`@("`@("`@("`@("`@("`@+RH@0G5I;&0@86X@97AA
M;7!L92!A<G)A>2!O9B!U<"!T;R`Q,"!D871E+W1I;64@9FEE;&1S+B`J+PH@
M("`@("`@("`@("`@("`@("`@('=H:6QE("@D:2`\(&-O=6YT*"1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9&%T82==*2`F)B!C;W5N="@D9&%T97-;)&1A
M=&%+97ES6R1K97E=75LG=F%L=65S)UTI(#P@,3`I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)VEM<&]R=%]D871A
M)UU;)V1A=&$G75LD:5U;)&1A=&%+97ES6R1K97E=72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871E<ULD9&%T84ME>7-;)&ME>5U=6R=V
M86QU97,G75M=(#T@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UU;
M)&E=6R1D871A2V5Y<ULD:V5Y75T["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=M87`G72`]("1M
M87`["B`@("`@("`@("`@(&EF("AC;W5N="@D9&%T97,I(#X@,"D@>PH@("`@
M("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871E<R==
M(#T@)&1A=&5S.PH@("`@("`@("`@("`@("`@<F5T=7)N($E-4$]25%]$051%
M5$E-13L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FYE>'13=&5P*$E-4$]25%]$051!+"`D<&%R86TI.PH*("`@("`@("!C87-E
M($E-4$]25%]$051%5$E-13H*("`@("`@("!C87-E($E-4$]25%]$051!.@H@
M("`@("`@("`@("!I9B`H)&%C=&EO;B`]/2!)35!/4E1?1$%4151)344I('L*
M("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@G9&5L:6UI=&5R)R`]
M/B!5=&EL.CIG971&;W)M1&%T82@G9&5L:6UI=&5R)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V9O<FUA="<@/3X@571I;#HZ9V5T1F]R
M;41A=&$H)V9O<FUA="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=O<F1E<B<@/3X@571I;#HZ9V5T1F]R;41A=&$H)V]R9&5R)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1A>5]D96QI;6ET97(G
M(#T^(%5T:6PZ.F=E=$9O<FU$871A*"=D87E?9&5L:6UI=&5R)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1A>5]F;W)M870G(#T^(%5T
M:6PZ.F=E=$9O<FU$871A*"=D87E?9F]R;6%T)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1I;65?9&5L:6UI=&5R)R`]/B!5=&EL.CIG
M971&;W)M1&%T82@G=&EM95]D96QI;6ET97(G*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=&EM95]F;W)M870G(#T^(%5T:6PZ.F=E=$9O
M<FU$871A*"=T:6UE7V9O<FUA="<I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T
M82==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B5&AE('5P;&]A9&5D(&1A=&$@=V%S(&QO<W0@<VEN8V4@=&AE('!R
M979I;W5S('-T97`N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\J
M($)U:6QD('1H92!R97-U;'0@9&%T82!S970@87,@86X@87-S;V-I871I=F4@
M87)R87DN("HO"B`@("`@("`@("`@("1D871A(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A
M)UT@87,@)')O=RD@>PH@("`@("`@("`@("`@("`@)&1A=&%?<F]W(#T@87)R
M87DH*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?4T53
M4TE/3ELG:6UP;W)T7V1A=&$G75LG;6%P)UU;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1M87!P961?:V5Y(#T@)%]315-324].6R=I;7!O
M<G1?9&%T82==6R=M87`G75LD:V5Y73L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1A8W1I;VX@/3T@24U03U)47T1!5$5424U%("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`A96UP='DH)'9A;"D@)B8*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&ES<V5T*"1P87)A;5LG=&EM95]F:65L9',G
M72D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1P87)A
M;5LG=&EM95]F:65L9',G75LD;6%P<&5D7VME>5TI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/FUA<$1A=&4H)'9A;"P@
M)'!A<F%M6R=T:6UE7V9I96QD<R==6R1M87!P961?:V5Y72P@)'!A<F%M<RP@
M)&ME>2D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&%?<F]W6R1?4T534TE/3ELG:6UP;W)T7V1A=&$G
M75LG;6%P)UU;)&ME>5U=(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T85M=(#T@
M)&1A=&%?<F]W.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M9&%T83L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@
M=&AE('-E<W-I;VX@9&%T82!U<"!A;F0@<F5M;W9E<R!A;GD@=7!L;V%D960@
M86YD(&UO=F5D"B`@("`@*B!F:6QE<RX@268@82!F=6YC=&EO;B!C86QL960@
M(E]C;&5A;G5P*"DB(&5X:7-T<RP@=&AI<R!G971S"B`@("`@*B!C86QL960@
M=&]O+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($EF(%]C;&5A;G5P
M*"D@=V%S(&-A;&QE9"P@=&AE(')E='5R;B!V86QU92!O9B!T:&ES(&-A;&PN
M"B`@("`@*B`@("`@("`@("`@("`@("!4:&ES('-H;W5L9"!B92!T:&4@=F%L
M=64@;V8@=&AE(&9I<G-T(&EM<&]R="!S=&5P+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&5A;G5P*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-3
M24].6R=I;7!O<G1?9&%T82==6R=F:6QE7VYA;64G72DI('L*("`@("`@("`@
M("`@0'5N;&EN:R@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M
M92==*3L*("`@("`@("!]"B`@("`@("`@)%]315-324].6R=I;7!O<G1?9&%T
M82==(#T@87)R87DH*3L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?
M8VQE86YU<"<I*2!["B`@("`@("`@("`@(')E='5R;B!?8VQE86YU<"@I.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O1&%T92YP:'``````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,S,U,S,@,3`U,34T,S0Q-#`@,#(P-S,T
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@ID969I;F4H)TA/4D1%7T1!5$5?4U5.1$%9)RP@("`@,"D["F1E9FEN
M92@G2$]21$5?1$%415]-3TY$05DG+"`@("`Q*3L*9&5F:6YE*"=(3U)$15]$
M051%7U1515-$05DG+"`@(#(I.PID969I;F4H)TA/4D1%7T1!5$5?5T5$3D53
M1$%9)RP@,RD["F1E9FEN92@G2$]21$5?1$%415]42%524T1!62<L("`T*3L*
M9&5F:6YE*"=(3U)$15]$051%7T92241!62<L("`@(#4I.PID969I;F4H)TA/
M4D1%7T1!5$5?4T%455)$05DG+"`@-BD["@ID969I;F4H)TA/4D1%7T1!5$5?
M34%32U]354Y$05DG+"`@("`Q*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?
M34].1$%9)RP@("`@,BD["F1E9FEN92@G2$]21$5?1$%415]-05-+7U1515-$
M05DG+"`@(#0I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]7141.15-$05DG
M+"`X*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?5$A54E-$05DG+"`Q-BD[
M"F1E9FEN92@G2$]21$5?1$%415]-05-+7T92241!62<L("`@,S(I.PID969I
M;F4H)TA/4D1%7T1!5$5?34%32U]305154D1!62<L(#8T*3L*9&5F:6YE*"=(
M3U)$15]$051%7TU!4TM?5T5%2T1!65,G+"`V,BD["F1E9FEN92@G2$]21$5?
M1$%415]-05-+7U=%14M%3D0G+"`@-C4I.PID969I;F4H)TA/4D1%7T1!5$5?
M34%32U]!3$Q$05E3)RP@,3(W*3L*"F1E9FEN92@G2$]21$5?1$%415]-05-+
M7U-%0T].1"<L("`@(#$I.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]-24Y5
M5$4G+"`@("`R*3L*9&5F:6YE*"=(3U)$15]$051%7TU!4TM?2$]54B<L("`@
M("`@-"D["F1E9FEN92@G2$]21$5?1$%415]-05-+7T1!62<L("`@("`@(#@I
M.PID969I;F4H)TA/4D1%7T1!5$5?34%32U]-3TY42"<L("`@(#$V*3L*9&5F
M:6YE*"=(3U)$15]$051%7TU!4TM?645!4B<L("`@("`S,BD["F1E9FEN92@G
M2$]21$5?1$%415]-05-+7T%,3%!!4E13)RP@-C,I.PH*+RHJ"B`J($AO<F1E
M($1A=&4@=W)A<'!E<B]L;V=I8R!C;&%S<RP@:6YC;'5D:6YG('-O;64@8V%L
M8W5L871I;VX*("H@9G5N8W1I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]$871E+T1A=&4N<&AP+'8@,2XX+C$P+C<@,C`P-B\P-2\P-"`P,SHT,CHS
M,B!S96QS:WD@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?1&%T90H@*B\*
M8VQA<W,@2&]R9&5?1&%T92!["@H@("`@+RHJ"B`@("`@*B!996%R"B`@("`@
M*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D>65A<CL*
M"B`@("`O*BH*("`@("`J($UO;G1H"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D;6]N=&@["@H@("`@+RHJ"B`@("`@*B!$
M87D*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1M9&%Y.PH*("`@("\J*@H@("`@("H@2&]U<@H@("`@("H*("`@("`J($!V
M87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)&AO=7(@/2`P.PH*("`@("\J
M*@H@("`@("H@36EN=71E"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B\*("`@('9A<B`D;6EN(#T@,#L*"B`@("`O*BH*("`@("`J(%-E8V]N
M9`H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@
M)'-E8R`](#`["@H@("`@+RHJ"B`@("`@*B!"=6EL9"!A(&YE=R!D871E(&]B
M:F5C="X@268@)&1A=&4@8V]N=&%I;G,@9&%T92!P87)T<RP@=7-E('1H96T*
M("`@("`J('1O(&EN:71I86QI>F4@=&AE(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?1&%T92@D9&%T92`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D871E*2!\?"!I<U]O8FIE8W0H)&1A=&4I*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1D871E(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1K97DL(&%R<F%Y*"=Y
M96%R)RP@)VUO;G1H)RP@)VUD87DG+"`G:&]U<B<L("=M:6XG+"`G<V5C)RDI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`H:6YT*21V
M86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H(6ES7VYU;&PH)&1A=&4I*2!["B`@("`@("`@("`@("\O($UA
M=&-H(%E965DM34TM1$0@2$@Z34TZ4U,@86YD(%E965E-341$2$A-35-3+@H@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<9'LT?2DM/RA<9'LR?2DM
M/RA<9'LR?2D@/RA<9'LR?2DZ/RA<9'LR?2DZ/RA<9'LR?2DO)RP@)&1A=&4L
M("1P87)T<RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YY96%R(#T@*&EN
M="DD<&%R='-;,5T["B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`H
M:6YT*21P87)T<ULR73L*("`@("`@("`@("`@("`@("1T:&ES+3YM9&%Y(#T@
M*&EN="DD<&%R='-;,UT["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`]
M("AI;G0I)'!A<G1S6S1=.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUI;B`]
M("AI;G0I)'!A<G1S6S5=.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E8R`]
M("AI;G0I)'!A<G1S6S9=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@+R\@5')Y(&%S(&$@=&EM97-T86UP+@H@("`@("`@("`@("`@
M("`@)'!A<G1S(#T@0&=E=&1A=&4H)&1A=&4I.PH@("`@("`@("`@("`@("`@
M:68@*"1P87)T<RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YY96%R
M(#T@)'!A<G1S6R=Y96%R)UT["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FUO;G1H(#T@)'!A<G1S6R=M;VXG73L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;61A>2`]("1P87)T<ULG;61A>2==.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YH;W5R(#T@)'!A<G1S6R=H;W5R<R==.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YM:6X@/2`D<&%R='-;)VUI;G5T97,G73L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5C(#T@)'!A<G1S6R=S96-O;F1S
M)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('5N:7@@=&EM97-T
M86UP(')E<')E<V5N=&%T:6]N(&]F('1H:7,@9&%T92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@($$@=6YI>"!T:6UE<W1A;7`N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1I;65S=&%M<"@I"B`@("!["B`@("`@("`@<F5T=7)N
M($!M:W1I;64H)'1H:7,M/FAO=7(L("1T:&ES+3YM:6XL("1T:&ES+3YS96,L
M("1T:&ES+3YM;VYT:"P@)'1H:7,M/FUD87DL("1T:&ES+3YY96%R*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@=6YI>"!T:6UE<W1A;7`@
M<F5P<F5S96YT871I;VX@;V8@=&AI<R!D871E+"`Q,CHP,&%M+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@02!U;FEX('1I;65S=&%M<"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9&%T97-T86UP*"D*("`@('L*("`@("`@("!R
M971U<FX@0&UK=&EM92@P+"`P+"`P+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YM
M9&%Y+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3&5A<%EE87(H)'EE87(I"B`@
M("!["B`@("`@("`@:68@*'-T<FQE;B@D>65A<BD@(3T@-"!\?"!P<F5G7VUA
M=&-H*"<O7$0O)RP@)'EE87(I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H*"1Y96%R("4@-"`]/2`P
M("8F("1Y96%R("4@,3`P("$](#`I('Q\("1Y96%R("4@-#`P(#T](#`I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%Y(&]F('1H92!Y
M96%R("@Q+3,V-BD@=&AA="!C;W)R97-P;VYD<R!T;R!T:&4*("`@("`J(&9I
M<G-T(&1A>2!O9B!T:&4@9VEV96X@=V5E:RX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D=V5E:R`@5&AE('=E96L@;V8@=&AE('EE87(@=&\@9FEN
M9"!T:&4@9FER<W0@9&%Y(&]F+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'EE
M87(@(%1H92!Y96%R('1O(&-A;&-U;&%T92!F;W(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@9&%Y(&]F('1H92!Y96%R(&]F('1H92!F
M:7)S="!D87D@;V8@=&AE(&=I=F5N('=E96LN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9I<G-T1&%Y3V97965K*"1W965K+"`D>65A<BD*("`@('L*("`@("`@
M("`D:F%N,2`]("9N97<@2&]R9&5?1&%T92AA<G)A>2@G>65A<B<@/3X@)'EE
M87(L("=M;VYT:"<@/3X@,2P@)VUD87DG(#T^(#$I*3L*("`@("`@("`D<W1A
M<G0@/2`D:F%N,2T^9&%Y3V97965K*"D["B`@("`@("`@:68@*"1S=&%R="`^
M($A/4D1%7T1!5$5?5$A54E-$05DI('L*("`@("`@("`@("`@)'-T87)T("T]
M(#<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`H*"1W965K("H@-RD@+2`H
M-R`K("1S=&%R="DI("L@,3L*("`@('T*"B`@("`O*BH*("`@("`J($!S=&%T
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&%Y<TEN36]N=&@H)&UO;G1H+"`D
M>65A<BD*("`@('L*("`@("`@("!I9B`H)&UO;G1H(#T](#(I('L*("`@("`@
M("`@("`@:68@*$AO<F1E7T1A=&4Z.FES3&5A<%EE87(H)'EE87(I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@,CD["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!R971U<FX@,C@["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V5I9B`H)&UO;G1H(#T](#0@?'P@)&UO;G1H(#T](#8@?'P@
M)&UO;G1H(#T](#D@?'P@)&UO;G1H(#T](#$Q*2!["B`@("`@("`@("`@(')E
M='5R;B`S,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M,S$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!D87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DL(#8@/2!3871U<F1A>2D@
M;V8@=&AI<PH@("`@("H@;V)J96-T)W,@9&%T92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(@(%1H92!D87D@;V8@=&AE('=E96LN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1A>4]F5V5E:R@I"B`@("!["B`@("`@("`@:68@*"1T
M:&ES+3YM;VYT:"`^(#(I('L*("`@("`@("`@("`@)&UO;G1H(#T@)'1H:7,M
M/FUO;G1H("T@,CL*("`@("`@("`@("`@)'EE87(@/2`D=&AI<RT^>65A<CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]N=&@@/2`D=&AI<RT^
M;6]N=&@@*R`Q,#L*("`@("`@("`@("`@)'EE87(@/2`D=&AI<RT^>65A<B`M
M(#$["B`@("`@("`@?0H*("`@("`@("`D9&%Y(#T@*&9L;V]R*"@Q,R`J("1M
M;VYT:"`M(#$I("\@-2D@*PH@("`@("`@("`@("`@("`@)'1H:7,M/FUD87D@
M*R`H)'EE87(@)2`Q,#`I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@D>65A
M<B`E(#$P,"D@+R`T*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@
M+R`Q,#`I("\@-"D@+2`R("H*("`@("`@("`@("`@("`@(&9L;V]R*"1Y96%R
M("\@,3`P*2`K(#<W*3L*"B`@("`@("`@<F5T=7)N("AI;G0I*"1D87D@+2`W
M("H@9FQO;W(H)&1A>2`O(#<I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&1A>2!N=6UB97(@;V8@=&AE('EE87(@*#`@=&\@,S8U+S,V
M-BDN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@9&%Y(&]F
M('1H92!Y96%R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D87E/9EEE87(H*0H@
M("`@>PH@("`@("`@("1M;VYT:%1O=&%L<R`](&%R<F%Y*#`L(#,Q+"`U.2P@
M.3`L(#$R,"P@,34Q+"`Q.#$L(#(Q,BP@,C0S+"`R-S,L(#,P-"P@,S,T*3L*
M("`@("`@("`D9&%Y3V9996%R(#T@)'1H:7,M/FUD87D@*R`D;6]N=&A4;W1A
M;'-;)'1H:7,M/FUO;G1H("T@,5T["B`@("`@("`@:68@*$AO<F1E7T1A=&4Z
M.FES3&5A<%EE87(H)'1H:7,M/GEE87(I("8F("1T:&ES+3YM;VYT:"`^(#(I
M('L*("`@("`@("`@("`@)&1A>4]F665A<BLK.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1D87E/9EEE87(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('=E96L@;V8@=&AE('EE87(L(&9I<G-T($UO;F1A>2!I<R!F:7)S
M="!D87D@;V8@9FER<W0*("`@("`J('=E96LN"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R("!4:&4@=V5E:R!N=6UB97(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('=E96M/9EEE87(H*0H@("`@>PH@("`@("`@(')E='5R;B!D871E
M*"=7)RP@)'1H:7,M/G1I;65S=&%M<"@I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!T:&4@;G5M8F5R(&]F('=E96MS(&EN('1H92!G:79E;B!Y
M96%R("@U,B!O<B`U,RDN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'EE87(@(%1H92!Y96%R('1O(&-O=6YT('1H92!N=6UB97(@;V8@=V5E:W,@
M:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("1N=6U7965K<R`@
M("`@(%1H92!N=6UB97(@;V8@=V5E:W,@:6X@)'EE87(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('=E96MS26Y996%R*"1Y96%R*0H@("`@>PH@("`@("`@("\O
M($9I;F0@=&AE(&QA<W0@5&AU<G-D87D@;V8@=&AE('EE87(N"B`@("`@("`@
M)&1A>2`](#,Q.PH@("`@("`@('=H:6QE("AD871E*"=W)RP@;6MT:6UE*#`L
M(#`L(#`L(#$R+"`D9&%Y+"`D>65A<BDI("$]($A/4D1%7T1!5$5?5$A54E-$
M05DI('L*("`@("`@("`@("`@)&1A>2TM.PH@("`@("`@('T*"B`@("`@("`@
M)&1A=&4@/2`F;F5W($AO<F1E7T1A=&4H87)R87DH)WEE87(G(#T^("1Y96%R
M+"`G;6]N=&@G(#T^(#$R+"`G;61A>2<@/3X@)&1A>2DI.PH@("`@("`@(')E
M='5R;B`D9&%T92T^=V5E:T]F665A<B@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T('1H92!D871E(&]F('1H:7,@;V)J96-T('1O('1H92`D;G1H('=E
M96MD87D@;V8@)'=E96MD87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'=E96MD87D@(%1H92!D87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DL
M(&5T8RDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;G1H("`@("`@5&AE("1N
M=&@@)'=E96MD87D@=&\@<V5T('1O("AD969A=6QT<R!T;R`Q*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3G1H5V5E:V1A>2@D=V5E:V1A>2P@)&YT:"`]
M(#$I"B`@("!["B`@("`@("`@:68@*"1W965K9&%Y(#P@2$]21$5?1$%415]3
M54Y$05D@?'P@)'=E96MD87D@/B!(3U)$15]$051%7U-!5%521$%9*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YM9&%Y(#T@,3L*("`@("`@("`D9FER<W0@/2`D=&AI<RT^9&%Y3V97
M965K*"D["B`@("`@("`@:68@*"1W965K9&%Y(#P@)&9I<G-T*2!["B`@("`@
M("`@("`@("1T:&ES+3YM9&%Y(#T@."`K("1W965K9&%Y("T@)&9I<G-T.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YM9&%Y(#T@)'=E
M96MD87D@+2`D9FER<W0@*R`Q.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M;61A>2`K/2`W("H@)&YT:"`M(#<["@H@("`@("`@("1T:&ES+3YC;W)R96-T
M*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&1U;7`H)'!R969I>"`]("<G*0H@("`@>PH@("`@("`@(&5C:&\@*"1P<F5F
M:7@@/R`D<')E9FEX("X@)SH@)R`Z("<G*2`N("1T:&ES+3YY96%R("X@)RTG
M("X@)'1H:7,M/FUO;G1H("X@)RTG("X@)'1H:7,M/FUD87D@+B`B/&)R("\^
M7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&1A=&4@8W5R<F5N
M=&QY(')E<')E<V5N=&5D(&)Y('1H:7,@;V)J96-T(&$@=F%L:60@9&%T93\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%9A;&ED:71Y+"!C;W5N
M=&EN9R!L96%P('EE87)S+"!E=&,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M5F%L:60H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^>65A<B`\(#`@?'P@
M)'1H:7,M/GEE87(@/B`Y.3DY*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&-H96-K9&%T92@D=&AI<RT^
M;6]N=&@L("1T:&ES+3YM9&%Y+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;W)R96-T(&%N>2!O=F5R+2!O<B!U;F1E<F9L;W=S(&EN
M(&%N>2!O9B!T:&4@9&%T92=S(&UE;6)E<G,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&UA<VL@(%=E(&UA>2!N;W0@=V%N="!T;R!C;W)R96-T
M('-O;64@;W9E<F9L;W=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W)R96-T
M*"1M87-K(#T@2$]21$5?1$%415]-05-+7T%,3%!!4E13*0H@("`@>PH@("`@
M("`@(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?34%32U]314-/3D0I('L*("`@
M("`@("`@("`@=VAI;&4@*"1T:&ES+3YS96,@/"`P*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^;6EN+2T["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5C
M("L](#8P.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE("@D=&AI
M<RT^<V5C(#X@-3DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YM:6XK*SL*
M("`@("`@("`@("`@("`@("1T:&ES+3YS96,@+3T@-C`["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?
M34%32U]-24Y55$4I('L*("`@("`@("`@("`@=VAI;&4@*"1T:&ES+3YM:6X@
M/"`P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<BTM.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FUI;B`K/2`V,#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!W:&EL92`H)'1H:7,M/FUI;B`^(#4Y*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^:&]U<BLK.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUI
M;B`M/2`V,#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@
M*"1M87-K("8@2$]21$5?1$%415]-05-+7TA/55(I('L*("`@("`@("`@("`@
M=VAI;&4@*"1T:&ES+3YH;W5R(#P@,"D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUD87DM+3L*("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R("L](#(T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('=H:6QE("@D=&AI<RT^:&]U
M<B`^(#(S*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;61A>2LK.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/FAO=7(@+3T@,C0["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?34%3
M2U]-3TY42"D@>PH@("`@("`@("`@("!W:&EL92`H)'1H:7,M/FUO;G1H(#X@
M,3(I('L*("`@("`@("`@("`@("`@("1T:&ES+3YY96%R*RL["B`@("`@("`@
M("`@("`@("`D=&AI<RT^;6]N=&@@+3T@,3(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@=VAI;&4@*"1T:&ES+3YM;VYT:"`\(#$I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YY96%R+2T["B`@("`@("`@("`@("`@("`D=&AI<RT^
M;6]N=&@@*ST@,3(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@D;6%S:R`F($A/4D1%7T1!5$5?34%32U]$05DI('L*("`@("`@("`@
M("`@=VAI;&4@*"1T:&ES+3YM9&%Y(#X@2&]R9&5?1&%T93HZ9&%Y<TEN36]N
M=&@H)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YM9&%Y("T]($AO<F1E7T1A=&4Z.F1A>7-);DUO;G1H*"1T
M:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUO;G1H*RL["B`@("`@("`@("`@("`@("`D=&AI<RT^8V]R<F5C="A(
M3U)$15]$051%7TU!4TM?34].5$@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@('=H:6QE("@D=&AI<RT^;61A>2`\(#$I('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YM;VYT:"TM.PH@("`@("`@("`@("`@("`@)'1H:7,M/F-O<G)E
M8W0H2$]21$5?1$%415]-05-+7TU/3E1(*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YM9&%Y("L]($AO<F1E7T1A=&4Z.F1A>7-);DUO;G1H*"1T:&ES+3YM
M;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0V]M<&%R92!T:&ES(&1A=&4@=&\@86YO
M=&AE<B!D871E(&]B:F5C="!T;R!S964@=VAI8V@@;VYE(&ES"B`@("`@*B!G
M<F5A=&5R("AL871E<BDN($%S<W5M97,@=&AA="!T:&4@9&%T97,@87)E(&EN
M('1H92!S86UE"B`@("`@*B!T:6UE>F]N92X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&1A=&4@(%1H92!D871E('1O(&-O;7!A<F4@=&\N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`]/2`@,"!I9B!T:&4@9&%T97,@
M87)E(&5Q=6%L"B`@("`@*B`@("`@("`@("`@("`@("`@(#X]("`Q(&EF('1H
M:7,@9&%T92!I<R!G<F5A=&5R("AL871E<BD*("`@("`J("`@("`@("`@("`@
M("`@("`@/#T@+3$@:68@=&AE(&]T:&5R(&1A=&4@:7,@9W)E871E<B`H;&%T
M97(I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!A<F5$871E*"1D871E*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T92P@)TAO<F1E7T1A=&4G*2D@
M>PH@("`@("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T92@D9&%T92D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/GEE87(@(3T@)&1A=&4M
M/GEE87(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YY96%R("T@)&1A
M=&4M/GEE87(["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YM;VYT:"`A/2`D
M9&%T92T^;6]N=&@I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM;VYT
M:"`M("1D871E+3YM;VYT:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUD87D@+2`D9&%T92T^;61A>3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E('1H:7,@=&\@86YO=&AE
M<B!D871E(&]B:F5C="!B>2!T:6UE+"!T;R!S964@=VAI8V@@;VYE"B`@("`@
M*B!I<R!G<F5A=&5R("AL871E<BDN($%S<W5M97,@=&AA="!T:&4@9&%T97,@
M87)E(&EN('1H92!S86UE"B`@("`@*B!T:6UE>F]N92X*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)&1A=&4@(%1H92!D871E('1O(&-O;7!A<F4@=&\N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`]/2`@,"!I9B!T:&4@
M9&%T97,@87)E(&5Q=6%L"B`@("`@*B`@("`@("`@("`@("`@("`@(#X]("`Q
M(&EF('1H:7,@9&%T92!I<R!G<F5A=&5R("AL871E<BD*("`@("`J("`@("`@
M("`@("`@("`@("`@/#T@+3$@:68@=&AE(&]T:&5R(&1A=&4@:7,@9W)E871E
M<B`H;&%T97(I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;7!A<F54:6UE*"1D
M871E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T92P@)TAO<F1E7T1A
M=&4G*2D@>PH@("`@("`@("`@("`D9&%T92`]("9N97<@2&]R9&5?1&%T92@D
M9&%T92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/FAO=7(@(3T@
M)&1A=&4M/FAO=7(I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YH;W5R
M("T@)&1A=&4M/FAO=7(["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YM:6X@
M(3T@)&1A=&4M/FUI;BD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUI
M;B`M("1D871E+3YM:6X["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YS96,@+2`D9&%T92T^<V5C.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($-O;7!A<F4@=&AI<R!T;R!A;F]T:&5R(&1A
M=&4@;V)J96-T+"!I;F-L=61I;F<@=&EM97,L('1O('-E90H@("`@("H@=VAI
M8V@@;VYE(&ES(&=R96%T97(@*&QA=&5R*2X@07-S=6UE<R!T:&%T('1H92!D
M871E<R!A<F4@:6X@=&AE"B`@("`@*B!S86UE('1I;65Z;VYE+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9&%T92`@5&AE(&1A=&4@=&\@8V]M<&%R
M92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#T]("`P(&EF
M('1H92!D871E<R!A<F4@97%U86P*("`@("`J("`@("`@("`@("`@("`@("`@
M/CT@(#$@:68@=&AI<R!D871E(&ES(&=R96%T97(@*&QA=&5R*0H@("`@("H@
M("`@("`@("`@("`@("`@("`\/2`M,2!I9B!T:&4@;W1H97(@9&%T92!I<R!G
M<F5A=&5R("AL871E<BD*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M<&%R941A
M=&54:6UE*"1D871E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9&%T92P@
M)TAO<F1E7T1A=&4G*2D@>PH@("`@("`@("`@("`D9&%T92`]("9N97<@2&]R
M9&5?1&%T92@D9&%T92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1I9F8@
M/2`D=&AI<RT^8V]M<&%R941A=&4H)&1A=&4I*2!["B`@("`@("`@("`@(')E
M='5R;B`D9&EF9CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F-O;7!A<F54:6UE*"1D871E*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('1I;64@;V9F<V5T(&9O<B!L;V-A
M;"!T:6UE('IO;F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-O
M;&]N("!0;&%C92!A(&-O;&]N(&)E='=E96X@:&]U<G,@86YD(&UI;G5T97,_
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1I;65Z;VYE(&]F9G-E
M="!A<R!A('-T<FEN9R!I;B!T:&4@9F]R;6%T("M(2#I-32X*("`@("`J+PH@
M("`@9G5N8W1I;VX@='I/9F9S970H)&-O;&]N(#T@=')U92D*("`@('L*("`@
M("`@("`D<V5C<R`](&1A=&4H)UHG+"`D=&AI<RT^=&EM97-T86UP*"DI.PH*
M("`@("`@("!I9B`H)'-E8W,@/"`P*2!["B`@("`@("`@("`@("1S:6=N(#T@
M)RTG.PH@("`@("`@("`@("`D<V5C<R`]("TD<V5C<SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<VEG;B`]("<K)SL*("`@("`@("!]"B`@("`@
M("`@)&-O;&]N(#T@)&-O;&]N(#\@)SHG(#H@)R<["B`@("`@("`@)&UI;G,@
M/2!I;G1V86PH*"1S96-S("L@,S`I("\@-C`I.PH@("`@("`@(')E='5R;B!S
M<')I;G1F*"<E<R4P,F0E<R4P,F0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("1S:6=N+"`D;6EN<R`O(#8P+"`D8V]L;VXL("1M:6YS("4@-C`I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1F]R;6%T('1I;64@:6X@25-/+3@V,#$@9F]R
M;6%T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$871E(&%N9"!T
M:6UE(&EN($E33RTX-C`Q(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-O.#8P,41A=&54:6UE*"D*("`@('L*("`@("`@("`D='IO9F8@/2`D=&AI
M<RT^='I/9F9S970H*3L*("`@("`@("`D9&%T92`]("1T:&ES+3YY96%R("X@
M)RTG("X@)'1H:7,M/FUO;G1H("X@)RTG("X@)'1H:7,M/FUD87D["B`@("`@
M("`@)'1I;64@/2`D=&AI<RT^:&]U<B`N("<Z)R`N("1T:&ES+3YM:6X@+B`G
M.B<@+B`D=&AI<RT^<V5C.PH*("`@("`@("!R971U<FX@)&1A=&4@+B`G5"<@
M+B`D=&EM92`N("1T>F]F9CL*("`@('T*"B`@("`O*BH*("`@("`J($9O<FUA
M="!T:6UE(&EN(%)&0R`R.#(R(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@1&%T92!A;F0@=&EM92!I;B!21D,@,C@R,B!F;W)M870N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')F8S(X,C)$871E5&EM92@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&1A=&4H)T0L(&H@32!9($@Z:3IS("<L("1T:&ES
M+3YT:6UE<W1A;7`H*2D@+B`D=&AI<RT^='I/9F9S970H9F%L<V4I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1F]R;6%T('1I;64@:6X@4D9#(#,S,SD@9F]R
M;6%T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!$871E(&%N9"!T
M:6UE(&EN(%)&0R`S,S,Y(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F9C,S,S.41A=&54:6UE*"D*("`@('L*("`@("`@("!R971U<FX@9&%T92@G
M62UM+61<5$@Z:2<L("1T:&ES+3YT:6UE<W1A;7`H*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&;W)M870@=&EM92!T;R!S=&%N9&%R9"`G8W1I;64G(&9O
M<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@1&%T92!A;F0@
M=&EM92X*("`@("`J+PH@("`@9G5N8W1I;VX@8U1I;64H)'1I;64@/2!F86QS
M92D*("`@('L*("`@("`@("!R971U<FX@9&%T92@G1"!-(&H@2#II.G,@62<L
M("1T:&ES+3YT:6UE<W1A;7`H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M;W)M870@9&%T92!A;F0@=&EM92!U<VEN9R!S=')F=&EM92@I(&9O<FUA="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@<W1R9G1I;64H*2!F;W)M
M871T960@9&%T92!A;F0@=&EM92X*("`@("`J+PH@("`@9G5N8W1I;VX@<W1R
M9G1I;64H)&9O<FUA="D*("`@('L*("`@("`@("!R971U<FX@<W1R9G1I;64H
M)&9O<FUA="P@)'1H:7,M/G1I;65S=&%M<"@I*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U-E8W)E="YP:'``````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$S,C(P(#$P-3$U-#,T,30P(#`R,3(W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE(%-E8W)E=#HZ(&-L87-S('!R;W9I9&5S(&%N($%022!F
M;W(@96YC<GEP=&EN9R!A;F0@9&5C<GEP=&EN9PH@*B!S;6%L;"!P:65C97,@
M;V8@9&%T82!W:71H('1H92!U<V4@;V8@82!S:&%R960@:V5Y+@H@*@H@*B!4
M:&4@4V5C<F5T.CH@9G5N8W1I;VYS('5S92!T:&4@2&]R9&4@0VEP:&5R.CH@
M8VQA<W,@:68@;6-R>7!T(&ES(&YO=`H@*B!A=F%I;&%B;&4N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U-E8W)E="]396-R970N<&AP+'8@,2XT-2XQ,"XW
M(#(P,#8O,#,O,#(@,#4Z,C4Z,3`@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]396-R970*("HO"F-L87-S(%-E8W)E="!["@H@
M("`@+RHJ"B`@("`@*B!486ME(&$@<VUA;&P@<&EE8V4@;V8@9&%T82!A;F0@
M96YC<GEP="!I="!W:71H(&$@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ME>2`@("`@(%1H92!K97D@=&\@=7-E(&9O<B!E;F-R>7!T:6]N
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G92`@5&AE('!L86EN=&5X
M="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8VEP:&5R=&5X="!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M92@D:V5Y+"`D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H571I;#HZ97AT
M96YS:6]N17AI<W1S*"=M8W)Y<'0G*2D@>PH@("`@("`@("`@("`D=&0@/2!`
M;6-R>7!T7VUO9'5L95]O<&5N*$U#4EE05%]'3U-4+"`G)RP@34-265!47TU/
M1$5?14-"+"`G)RD["B`@("`@("`@("`@(&EF("@D=&0I('L*("`@("`@("`@
M("`@("`@("1I=B`]($!M8W)Y<'1?8W)E871E7VEV*&UC<GEP=%]E;F-?9V5T
M7VEV7W-I>F4H)'1D*2P@34-265!47U)!3D0I.PH@("`@("`@("`@("`@("`@
M0&UC<GEP=%]G96YE<FEC7VEN:70H)'1D+"`D:V5Y+"`D:78I.PH@("`@("`@
M("`@("`@("`@)&5N8W)Y<'1E9%]D871A(#T@0&UC<GEP=%]G96YE<FEC*"1T
M9"P@)&UE<W-A9V4I.PH@("`@("`@("`@("`@("`@0&UC<GEP=%]G96YE<FEC
M7V1E:6YI="@D=&0I.PH*("`@("`@("`@("`@("`@(')E='5R;B`D96YC<GEP
M=&5D7V1A=&$["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('-T
M871I8R`D8VEP:&5R0V%C:&4@/2!A<G)A>2@I.PH@("`@("`@("1C86-H94ED
M>"`](&UD-2@D:V5Y*3L*"B`@("`@("`@:68@*"%I<W-E="@D8VEP:&5R0V%C
M:&5;)&-A8VAE261X72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]#:7!H97(N<&AP)SL*"B`@("`@("`@("`@("1C:7!H97)#86-H95LD
M8V%C:&5)9'A=(#T@)DAO<F1E7T-I<&AE<CHZ9F%C=&]R>2@G8FQO=V9I<V@G
M*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/G-E=$)L
M;V-K36]D92@G;V9B-C0G*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C
M86-H94ED>%TM/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8VEP:&5R0V%C:&5;)&-A8VAE261X72T^96YC<GEP="@D;65S<V%G
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@;65S<V%G92!E
M;F-R>7!T960@=VET:"!396-R970Z.G=R:71E*"DN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:V5Y("`@("`@5&AE(&ME>2!T;R!U<V4@9F]R(&1E
M8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!4:&4@
M8VEP:&5R=&5X="!M97-S86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<&QA:6YT97AT(&UE<W-A9V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E860H)&ME>2P@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@:68@
M*%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;6-R>7!T)RDI('L*("`@("`@("`@
M("`@)'1D(#T@0&UC<GEP=%]M;V1U;&5?;W!E;BA-0U)94%1?1T]35"P@)R<L
M($U#4EE05%]-3T1%7T5#0BP@)R<I.PH@("`@("`@("`@("!I9B`H)'1D*2![
M"B`@("`@("`@("`@("`@("`D:78@/2!`;6-R>7!T7V-R96%T95]I=BAM8W)Y
M<'1?96YC7V=E=%]I=E]S:7IE*"1T9"DL($U#4EE05%]204Y$*3L*("`@("`@
M("`@("`@("`@($!M8W)Y<'1?9V5N97)I8U]I;FET*"1T9"P@)&ME>2P@)&EV
M*3L*("`@("`@("`@("`@("`@("1D96-R>7!T961?9&%T82`]($!M9&5C<GEP
M=%]G96YE<FEC*"1T9"P@)&-I<&AE<G1E>'0I.PH@("`@("`@("`@("`@("`@
M0&UC<GEP=%]G96YE<FEC7V1E:6YI="@D=&0I.PH*("`@("`@("`@("`@("`@
M("\O(%-T<FEP('!A9&1I;F<@8VAA<F%C=&5R<RX*("`@("`@("`@("`@("`@
M(')E='5R;B!R=')I;2@D9&5C<GEP=&5D7V1A=&$L(")<,"(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&-I<&AE<D-A8VAE
M.PH@("`@("`@("1C86-H94ED>"`](&UD-2@D:V5Y*3L*"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D8VEP:&5R0V%C:&4I('Q\("%I<W-E="@D8VEP:&5R0V%C
M:&5;)&-A8VAE261X72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]#:7!H97(N<&AP)SL*"B`@("`@("`@("`@("1C:7!H97)#86-H95LD
M8V%C:&5)9'A=(#T@)DAO<F1E7T-I<&AE<CHZ9F%C=&]R>2@G8FQO=V9I<V@G
M*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C86-H94ED>%TM/G-E=$)L
M;V-K36]D92@G;V9B-C0G*3L*("`@("`@("`@("`@)&-I<&AE<D-A8VAE6R1C
M86-H94ED>%TM/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8VEP:&5R0V%C:&5;)&-A8VAE261X72T^9&5C<GEP="@D8VEP:&5R
M=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!A('-E8W)E
M="!K97D@*&9O<B!E;F-R>7!T:6]N*2P@96ET:&5R('5S:6YG(&$@<F%N9&]M
M"B`@("`@*B!M9#4@<W1R:6YG(&%N9"!S=&]R:6YG(&ET(&EN(&$@8V]O:VEE
M(&EF('1H92!U<V5R(&AA<R!C;V]K:65S"B`@("`@*B!E;F%B;&5D+"!O<B!M
M=6YG:6YG('-O;64@:VYO=VX@=F%L=65S(&EF('1H97D@9&]N)W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y;F%M92`@5&AE(&YA;64@;V8@
M=&AE(&ME>2!T;R!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!S96-R970@:V5Y('1H870@:&%S(&)E96X@9V5N97)A=&5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971+97DH)&ME>6YA;64@/2`G9V5N97)I8R<I
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D=&EM96]U
M="`]("1C;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72`_('1I;64H*2`K("1C
M;VYF6R=S97-S:6]N)UU;)W1I;65O=70G72`Z(#`["@H@("`@("`@(&EF("AI
M<W-E="@D7T-/3TM)15LD8V]N9ELG<V5S<VEO;B==6R=N86UE)UU=*2D@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)%]#3T]+245;)&ME>6YA;64@+B`G7VME
M>2==*2D@>PH@("`@("`@("`@("`@("`@)&ME>2`]("1?0T]/2TE%6R1K97EN
M86UE("X@)U]K97DG73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1K97D@/2!M9#4H;71?<F%N9"@I*3L*("`@("`@("`@("`@("`@
M("1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72`]("1K97D["B`@("`@("`@
M("`@("`@("!`<V5T8V]O:VEE*"1K97EN86UE("X@)U]K97DG+"`D:V5Y+"`D
M=&EM96]U="P@)&-O;F9;)V-O;VMI92==6R=P871H)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;VYF6R=C;V]K:64G75LG9&]M86EN)UTL("1C
M;VYF6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1K97D@/2!S97-S:6]N7VED
M*"D["B`@("`@("`@("`@($!S971C;V]K:64H)&ME>6YA;64@+B`G7VME>2<L
M("1K97DL("1T:6UE;W5T+"`D8V]N9ELG8V]O:VEE)UU;)W!A=&@G72P*("`@
M("`@("`@("`@("`@("`@("`@("`D8V]N9ELG8V]O:VEE)UU;)V1O;6%I;B==
M+"`D8V]N9ELG=7-E7W-S;"==(#T](#$@/R`Q(#H@,"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&ME>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!A('-E8W)E="!K97DL(&5I=&AE<B!F<F]M(&$@8V]O:VEE+"!O<B!I
M9B!T:&4@8V]O:VEE"B`@("`@*B!I<VXG="!T:&5R92P@87-S=6UE('=E(&%R
M92!U<VEN9R!A(&UU;F=E9"!V97)S:6]N(&]F(&$@:VYO=VX*("`@("`J(&)A
M<V4@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y;F%M
M92`@5&AE(&YA;64@;V8@=&AE(&ME>2!T;R!G970N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!S96-R970@:V5Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971+97DH)&ME>6YA;64@/2`G9V5N97)I8R<I"B`@("!["B`@
M("`@("`@<W1A=&EC("1K97EC86-H92`](&%R<F%Y*"D["@H@("`@("`@(&EF
M("@A:7-S970H)&ME>6-A8VAE6R1K97EN86UE72DI('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@
M("`@("`@("`@("`@("1K97EC86-H95LD:V5Y;F%M95T@/2`D7T-/3TM)15LD
M:V5Y;F%M92`N("=?:V5Y)UT["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!G;&]B86P@)&-O;F8["B`@("`@("`@("`@("`@("`D:V5Y
M8V%C:&5;)&ME>6YA;65=(#T@<V5S<VEO;E]I9"@I.PH@("`@("`@("`@("`@
M("`@0'-E=&-O;VMI92@D:V5Y;F%M92`N("=?:V5Y)RP@)&ME>6-A8VAE6R1K
M97EN86UE72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9;)W-E
M<W-I;VXG75LG=&EM96]U="==(#\@=&EM92@I("L@)&-O;F9;)W-E<W-I;VXG
M75LG=&EM96]U="==(#H@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;F9;)V-O;VMI92==6R=P871H)UTL("1C;VYF6R=C;V]K:64G75LG9&]M
M86EN)UTL("1C;VYF6R=U<V5?<W-L)UT@/3T@,2`_(#$@.B`P*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1K97EC86-H95LD
M:V5Y;F%M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@82!S96-R
M970@:V5Y(&5N=')Y(&9R;VT@=&AE(&-U<G)E;G0@8V]O:VEE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ME>6YA;64@(%1H92!N86UE(&]F('1H
M92!K97D@=&\@8VQE87(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF(&ME>2!E>&ES=&5D+"!F86QS92!I9B!N;W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-L96%R2V5Y*"1K97EN86UE(#T@)V=E;F5R:6,G*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D7T-/3TM)15LD1TQ/0D%,4ULG8V]N
M9B==6R=S97-S:6]N)UU;)VYA;64G75TI("8F"B`@("`@("`@("`@(&ES<V5T
M*"1?0T]/2TE%6R1K97EN86UE("X@)U]K97DG72DI('L*("`@("`@("`@("`@
M=6YS970H)%]#3T]+245;)&ME>6YA;64@+B`G7VME>2==*3L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O0TQ)+G!H<```````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,C,T,C0@,3`U,34T,S0Q-#`@,#(P-#8T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!(;W)D95]#3$DZ.B!!4$D@9F]R(&)A<VEC(&-O;6UA;F0M;&EN92!F
M=6YC=&EO;F%L:71Y+V-H96-K<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M0TQ)+T-,22YP:'`L=B`Q+C0R+C8N,3,@,C`P-B\P-2\S,2`Q,CHS,3HP,"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#3$D*
M("HO"F-L87-S($AO<F1E7T-,22!["@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@
M<G5N;FEN9R!O;B!A(&-O;G-O;&4_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L
M96%N"B`@("`@*B\*("`@('9A<B`D7V-O;G-O;&4["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;F5W;&EN92!S=')I;F<@=&\@=7-E+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VYE=VQI;F4["@H@("`@+RHJ
M"B`@("`@*B!4:&4@:6YD96YT('-T<FEN9R!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6YD96YT.PH*("`@
M("\J*@H@("`@("H@5&AE('-T<FEN9R!T;R!M87)K('1H92!B96=I;FYI;F<@
M;V8@8F]L9"!T97AT+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7V)O;&1?<W1A<G0@/2`G)SL*"B`@("`O*BH*("`@("`J
M(%1H92!S=')I;F<@=&\@;6%R:R!T:&4@96YD(&]F(&)O;&0@=&5X="X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]B;VQD
M7V5N9"`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('-T<FEN9W,@=&\@;6%R
M:R!T:&4@8F5G:6YN:6YG(&]F(&-O;&]U<F5D('1E>'0N"B`@("`@*B\*("`@
M('9A<B`D7W)E9%]S=&%R="`@("`]("<G.PH@("`@=F%R("1?9W)E96Y?<W1A
M<G0@(#T@)R<["B`@("!V87(@)%]Y96QL;W=?<W1A<G0@/2`G)SL*("`@('9A
M<B`D7V)L=65?<W1A<G0@("`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('-T
M<FEN9W,@=&\@;6%R:R!T:&4@96YD(&]F(&-O;&]U<F5D('1E>'0N"B`@("`@
M*B\*("`@('9A<B`D7W)E9%]E;F0@("`@("`]("<G.PH@("`@=F%R("1?9W)E
M96Y?96YD("`@(#T@)R<["B`@("!V87(@)%]Y96QL;W=?96YD("`@/2`G)SL*
M("`@('9A<B`D7V)L=65?96YD("`@("`]("<G.PH*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-I;F=L92!I;G-T86YC92!O9B!T:&4@2&]R9&5?0TQ)(&-L
M87-S+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E.PH@("`@("`@(&EF("@A:7-S970H
M)&EN<W1A;F-E*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V4@/2!N97<@2&]R
M9&5?0TQ)*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D:6YS=&%N8V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E8W0@=&AE(&-U<G)E;G0@96YV
M:7)O;FUE;G0@*'=E8B!S97)V97(@;W(@8V]N<V]L92D@86YD('-E=',*("`@
M("`J(&EN=&5R;F%L('9A;'5E<R!A8V-O<F1I;F=L>2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?0TQ)*"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O
M;G-O;&4@/2`D=&AI<RT^<G5N;FEN9T9R;VU#3$DH*3L*"B`@("`@("`@:68@
M*"1T:&ES+3Y?8V]N<V]L92D@>PH@("`@("`@("`@("`D=&AI<RT^7VYE=VQI
M;F4@/2`B7&XB.PH@("`@("`@("`@("`D=&AI<RT^7VEN9&5N="`@/2`G("`@
M("<["@H@("`@("`@("`@("`D=&5R;2`](&=E=&5N=B@G5$5232<I.PH@("`@
M("`@("`@("!I9B`H)'1E<FTI('L*("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"<O7BAX=&5R;7QV=#(R,'QL:6YU>"DO)RP@)'1E<FTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;VQD7W-T87)T("`@/2`B7'@Q
M8ELQ;2(["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R961?<W1A<G0@
M("`@/2`B7'@Q8ELP,3LS,6TB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9W)E96Y?<W1A<G0@(#T@(EQX,6);,#$[,S)M(CL*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7WEE;&QO=U]S=&%R="`](")<>#%B6S`Q.S,S;2([
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]B;'5E7W-T87)T("`@/2`B
M7'@Q8ELP,3LS-&TB.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8F]L
M9%]E;F0@/2`D=&AI<RT^7W)E9%]E;F0@/2`D=&AI<RT^7V=R965N7V5N9"`]
M("1T:&ES+3Y?>65L;&]W7V5N9"`]("1T:&ES+3Y?8FQU95]E;F0@/2`B7'@Q
M8ELP;2(["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G
M+UYV=#$P,"\G+"`D=&5R;2DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V)O;&1?<W1A<G0@/2`B7'@Q8ELQ;2(["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]B;VQD7V5N9"`@(#T@(EQX,6);,&TB.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]N97=L:6YE(#T@)SQB<B`O/B<["B`@("`@("`@("`@
M("1T:&ES+3Y?:6YD96YT("`]('-T<E]R97!E870H)R9N8G-P.R<L(#0I.PH*
M("`@("`@("`@("`@)'1H:7,M/E]B;VQD7W-T87)T("`@/2`G/'-T<F]N9SXG
M.PH@("`@("`@("`@("`D=&AI<RT^7V)O;&1?96YD("`@("`]("<\+W-T<F]N
M9SXG.PH@("`@("`@("`@("`D=&AI<RT^7W)E9%]S=&%R="`@("`]("<\<W!A
M;B!S='EL93TB8V]L;W(Z<F5D(CXG.PH@("`@("`@("`@("`D=&AI<RT^7V=R
M965N7W-T87)T("`]("<\<W!A;B!S='EL93TB8V]L;W(Z9W)E96XB/B<["B`@
M("`@("`@("`@("1T:&ES+3Y?>65L;&]W7W-T87)T(#T@)SQS<&%N('-T>6QE
M/2)C;VQO<CIY96QL;W<B/B<["B`@("`@("`@("`@("1T:&ES+3Y?8FQU95]S
M=&%R="`@(#T@)SQS<&%N('-T>6QE/2)C;VQO<CIB;'5E(CXG.PH@("`@("`@
M("`@("`D=&AI<RT^7W)E9%]E;F0@/2`D=&AI<RT^7V=R965N7V5N9"`]("1T
M:&ES+3Y?>65L;&]W7V5N9"`]("1T:&ES+3Y?8FQU95]E;F0@/2`G/"]S<&%N
M/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4')I;G1S("1T
M97AT(&]N(&$@<VEN9VQE(&QI;F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'1E>'0@(%1H92!T97AT('1O('!R:6YT+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'!R92`@($EF('1R=64@=&AE(&QI;F5B<F5A:R!I<R!P<FEN
M=&5D(&)E9F]R90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!T
M97AT(&EN<W1E860@;V8@869T97(@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E;&XH)'1E>'0@/2`G)RP@)'!R92`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&EF("@D<')E*2!["B`@("`@("`@("`@(&5C:&\@)'1H:7,M/E]N97=L
M:6YE("X@)'1E>'0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H
M;R`D=&5X="`N("1T:&ES+3Y?;F5W;&EN93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!I;F1E;G1E9"!S=')I;F<N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@
M:6YD96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;F1E;G0H)'1E>'0I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6YD96YT("X@)'1E>'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8F]L9"!V97)S:6]N(&]F
M("1T97AT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H
M92!T97AT('1O(&)O;&0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)O;&0H)'1E
M>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F]L9%]S=&%R="`N
M("1T97AT("X@)'1H:7,M/E]B;VQD7V5N9#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!R960@=F5R<VEO;B!O9B`D=&5X="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!P<FEN="!I
M;B!R960N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E9"@D=&5X="D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R961?<W1A<G0@+B`D=&5X="`N("1T
M:&ES+3Y?<F5D7V5N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!G<F5E;B!V97)S:6]N(&]F("1T97AT+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O('!R:6YT(&EN(&=R965N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G<F5E;B@D=&5X="D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]G<F5E;E]S=&%R="`N("1T97AT("X@)'1H:7,M
M/E]G<F5E;E]E;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M8FQU92!V97)S:6]N(&]F("1T97AT+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%1H92!T97AT('1O('!R:6YT(&EN(&)L=64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&)L=64H)'1E>'0I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8FQU95]S=&%R="`N("1T97AT("X@)'1H:7,M/E]B;'5E
M7V5N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!Y96QL;W<@
M=F5R<VEO;B!O9B`D=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@=&5X="!T;R!P<FEN="!I;B!Y96QL;W<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('EE;&QO=R@D=&5X="D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]Y96QL;W=?<W1A<G0@+B`D=&5X="`N("1T:&ES+3Y?>65L
M;&]W7V5N9#L*("`@('T*"B`@("`O*BH*("`@("`J($1I<W!L87ES(&$@;65S
M<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E=F5N="`@5&AE
M(&UE<W-A9V4@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@
M(%1H92!T>7!E(&]F(&UE<W-A9V4Z("=C;&DN97)R;W(G+"`G8VQI+G=A<FYI
M;F<G+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=C;&DN<W5C8V5S
M<R<L(&]R("=C;&DN;65S<V%G92<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UE
M<W-A9V4H)&UE<W-A9V4L("1T>7!E(#T@)V-L:2YM97-S86=E)RD*("`@('L*
M("`@("`@("`D;65S<V%G92`]('=O<F1W<F%P*"1M97-S86=E+"`V."P@(EQN
M("`@("`@("`@("`B+"!T<G5E*3L*"B`@("`@("`@<W=I=&-H("@D='EP92D@
M>PH@("`@("`@(&-A<V4@)V-L:2YE<G)O<B<Z"B`@("`@("`@("`@("1T>7!E
M7VUE<W-A9V4@/2`D=&AI<RT^<F5D*"=;($524D]2(2!=("<I.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8VQI+G=A<FYI;F<G.@H@("`@
M("`@("`@("`D='EP95]M97-S86=E(#T@)'1H:7,M/GEE;&QO=R@G6R`@5T%2
M3B`@72`G*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V-L
M:2YS=6-C97-S)SH*("`@("`@("`@("`@)'1Y<&5?;65S<V%G92`]("1T:&ES
M+3YG<F5E;B@G6R`@($]+("`@72`G*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)V-L:2YM97-S86=E)SH*("`@("`@("`@("`@)'1Y<&5?
M;65S<V%G92`]("1T:&ES+3YB;'5E*"=;("!)3D9/("!=("<I.PH@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YW<FET96QN
M*"1T>7!E7VUE<W-A9V4@+B`D;65S<V%G92D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$:7-P;&%Y<R!A(&9A=&%L(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W(@(%1H92!E<G)O<B!T97AT('1O
M(&1I<W!L87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&9A=&%L*"1E<G)O<BD*
M("`@('L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D*"<]/3T]
M/3T]/3T]/3T]/3T]/3T]/2<I*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@I
M.PH@("`@("`@("1T:&ES+3YW<FET96QN*"1T:&ES+3YR960H7R@B1F%T86P@
M17)R;W(Z(BDI*3L*("`@("`@("`D=&AI<RT^=W)I=&5L;B@D=&AI<RT^<F5D
M*"1E<G)O<BDI.PH@("`@("`@("1T:&ES+3YW<FET96QN*"D["B`@("`@("`@
M)'1H:7,M/G=R:71E;&XH)'1H:7,M/G)E9"@G/3T]/3T]/3T]/3T]/3T]/3T]
M/3TG*2D["B`@("`@("`@97AI=#L*("`@('T*"B`@("`O*BH*("`@("`J(%!R
M;VUP=',@9F]R(&$@=7-E<B!R97-P;VYS92X*("`@("`J"B`@("`@*B!`=&]D
M;R!(;W)D92`T.B!S=VET8V@@)&-H;VEC97,@86YD("1D969A=6QT"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')O;7!T("!4:&4@;65S<V%G92!T
M;R!D:7-P;&%Y('=H96X@<')O;7!T:6YG('1H92!U<V5R+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1C:&]I8V5S("!4:&4@8VAO:6-E<R!A=F%I;&%B;&4@=&\@
M=&AE('5S97(@;W(@;G5L;"!F;W(@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!T97AT(&EN<'5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5F
M875L="!4:&4@9&5F875L="!V86QU92!I9B!N;R!V86QU92!S<&5C:69I960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!R97-P
M;VYS92!T;R!T:&4@<')O;7!T+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F]M
M<'0H)'!R;VUP="P@)&-H;VEC97,@/2!N=6QL+"`D9&5F875L="`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"1D969A=6QT("$]/2!N=6QL*2!["B`@("`@
M("`@("`@("1P<F]M<'0@+CT@)R!;)R`N("1D969A=6QT("X@)UTG.PH@("`@
M("`@('T*"B`@("`@("`@+R\@36%I;B!E=F5N="!L;V]P('1O(&-A<'1U<F4@
M=&]P(&QE=F5L(&-O;6UA;F0N"B`@("`@("`@=VAI;&4@*'1R=64I('L*("`@
M("`@("`@("`@+R\@4')I;G0@;W5T('1H92!P<F]M<'0@;65S<V%G92X*("`@
M("`@("`@("`@)'1H:7,M/G=R:71E;&XH)'!R;VUP="`N("<@)RP@(6ES7V%R
M<F%Y*"1C:&]I8V5S*2D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D8VAO
M:6-E<RD@)B8@(65M<'1Y*"1C:&]I8V5S*2D@>PH@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&-H;VEC97,@87,@)&ME>2`]/B`D8VAO:6-E*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G=R:71E;&XH)'1H:7,M/FEN9&5N="@G
M*"<@+B`D=&AI<RT^8F]L9"@D:V5Y*2`N("<I("<@+B`D8VAO:6-E*2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^=W)I=&5L
M;BA?*")4>7!E('EO=7(@8VAO:6-E.B`B*2P@=')U92D["B`@("`@("`@("`@
M("`@("!`;V)?9FQU<V@H*3L*"B`@("`@("`@("`@("`@("`O+R!'970@=&AE
M('5S97(@8VAO:6-E+@H@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@=')I
M;2AF9V5T<RA35$1)3BDI.PH@("`@("`@("`@("`@("`@:68@*"1R97-P;VYS
M92`]/3T@)R<@)B8@)&1E9F%U;'0@(3T](&YU;&PI('L*("`@("`@("`@("`@
M("`@("`@("`D<F5S<&]N<V4@/2`D9&5F875L=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8VAO:6-E<ULD<F5S<&]N
M<V5=*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S<&]N<V4[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YW<FET96QN*'-P<FEN=&8H7R@B7"(E<UPB(&ES(&YO="!A('9A
M;&ED(&-H;VEC92XB*2P@)')E<W!O;G-E*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N
M<V4@/2!T<FEM*&9G971S*%-41$E.*2D["B`@("`@("`@("`@("`@("!I9B`H
M)')E<W!O;G-E(#T]/2`G)R`F)B`D9&5F875L="`A/3T@;G5L;"D@>PH@("`@
M("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1D969A=6QT.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N("1R97-P;VYS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!E=F5R>71H:6YG('1H870@
M:7,@<V5N="!T:')O=6=H('-T86YD87)D(&EN<'5T(&%N9"!R971U<FYS(&ET
M"B`@("`@*B!A<R!A('-I;F=L92!S=')I;F<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!C;VYT96YT<R!O9B!T:&4@<W1A;F1A<F0@:6YP
M=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E8613=&1I;B@I"B`@("!["B`@
M("`@("`@)&EN(#T@)R<["B`@("`@("`@=VAI;&4@*"%F96]F*%-41$E.*2D@
M>PH@("`@("`@("`@("`D:6X@+CT@9F=E=',H4U1$24XL(#$P,C0I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&EN.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0TQ)('-C<FEP=',@<VAO=6QD;B=T('1I;65O=70L('-O('1R>2!T;R!S
M970@=&AE('1I;64@;&EM:70@=&\*("`@("`J(&YO;F4N($%L<V\@:6YI=&EA
M;&EZ92!A(&9E=R!V87)I86)L97,@:6X@)%]315)615(@=&AA="!A<F5N)W0@
M<')E<V5N=`H@("`@("H@9G)O;2!T:&4@0TQ)+@H@("`@("H*("`@("`J($!S
M=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@
M("`@+RH@4G5N(&-O;G-T<G5C=&]R(&YO=R!B96-A=7-E(&ET(')E<75I<F5S
M("1?4T525D526R=315)615)?3D%-12==('1O"B`@("`@("`@("H@8F4@96UP
M='D@:68@8V%L;&5D('=I=&@@82!#1TD@4T%022X@*B\*("`@("`@("`D8VQI
M(#T@)DAO<F1E7T-,23HZ<VEN9VQE=&]N*"D["@H@("`@("`@($!S971?=&EM
M95]L:6UI="@P*3L*("`@("`@("!O8E]I;7!L:6-I=%]F;'5S:"AT<G5E*3L*
M("`@("`@("!I;FE?<V5T*"=H=&UL7V5R<F]R<R<L(&9A;'-E*3L*("`@("`@
M("`D7U-%4E9%4ELG2%144%](3U-4)UT@/2`G,3(W+C`N,"XQ)SL*("`@("`@
M("`D7U-%4E9%4ELG4T525D527TY!344G72`]("<Q,C<N,"XP+C$G.PH@("`@
M("`@("1?4T525D526R=315)615)?4$]25"==(#T@)R<["B`@("`@("`@)%]3
M15)615);)U)%34]415]!1$12)UT@/2`G)SL*("`@("`@("`D7U-%4E9%4ELG
M4$A07U-%3$8G72`](&ES<V5T*"1A<F=V*2`_("1A<F=V6S!=(#H@)R<["B`@
M("`@("`@:68@*"%D969I;F5D*"=35$1)3B<I*2!["B`@("`@("`@("`@(&1E
M9FEN92@G4U1$24XG+"!F;W!E;B@G<&AP.B\O<W1D:6XG+"`G<B<I*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"%D969I;F5D*"=35$1/550G*2D@>PH@("`@
M("`@("`@("!D969I;F4H)U-41$]55"<L(&9O<&5N*"=P:'`Z+R]S=&1O=70G
M+"`G<B<I*3L*("`@("`@("!]"B`@("`@("`@:68@*"%D969I;F5D*"=35$1%
M4E(G*2D@>PH@("`@("`@("`@("!D969I;F4H)U-41$524B<L(&9O<&5N*"=P
M:'`Z+R]S=&1E<G(G+"`G<B<I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!-86ME('-U<F4@=V4G<F4@8F5I;F<@8V%L;&5D(&9R;VT@=&AE
M(&-O;6UA;F0@;&EN92P@86YD(&YO="!V:6$*("`@("`J('1H92!W96(N"B`@
M("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!I9B!W92!A<F4L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<G5N;FEN9T9R;VU#3$DH*0H@("`@>PH@("`@("`@
M("1S87!I(#T@<&AP7W-A<&E?;F%M92@I.PH@("`@("`@(&EF("@D<V%P:2`]
M/2`G8VQI)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'-A<&D@/3T@)V-G:2<@)B8@
M96UP='DH)%]315)615);)U-%4E9%4E].04U%)UTI.PH@("`@("`@('T*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O0V%C:&4N<&AP````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,30P,3$@,3`U,34T,S0Q-#`@,#(Q,#4P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@2&]R9&5?0V%C:&4Z.B!C;&%S<R!P<F]V:61E<R!A(&-O;6UO;B!A
M8G-T<F%C=&5D(&EN=&5R9F%C92!I;G1O"B`J('1H92!V87)I;W5S(&-A8VAI
M;F<@8F%C:V5N9',N("!)="!A;'-O('!R;W9I9&5S(&9U;F-T:6]N<R!F;W(*
M("H@8VAE8VMI;F<@:6XL(')E=')I979I;F<L(&%N9"!F;'5S:&EN9R!A(&-A
M8VAE+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#86-H92]#86-H92YP:'`L
M=B`Q+C,Q+C$P+C$Q(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?0V%C
M:&4*("HO"F-L87-S($AO<F1E7T-A8VAE('L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C="!A(&YE=R!(;W)D95]#86-H92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<B!A<G)A>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0V%C:&4H)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@+RH@3VYL>2!D;R!G87)B86=E(&-O;&QE8W1I
M;VX@:68@87-K960@9F]R+"!A;F0@=&AE;B!O;FQY(#$E(&]F('1H90H@("`@
M("`@("`J('1I;64@=V4@8W)E871E(&%N(&]B:F5C="X@*B\*("`@("`@("!I
M9B`H(65M<'1Y*"1P87)A;7-;)V=C)UTI("8F"B`@("`@("`@("`@("AR86YD
M*#`L(#DY*2`]/2`P*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1O1T,H)'!A
M<F%M<ULG9V,G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T<FEE=F4@82!C86-H960@;V)J96-T(&%N9"!R971U
M<FX@:70@=&\@=&AE"B`@("`@*B!C86QL97(N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@
M("!/8FIE8W0@240@=&\@<75E<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;&EF971I;64@($QI9F5T:6UE(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@
M9F%L<V4@:68@;F]N92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E="@D:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O('-T
M;W)E(&%N(&]B:F5C="!I;B!T:&4@8V%C:&4N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@3V)J
M96-T($E$('5S960@87,@=&AE(&-A8VAI;F<@:V5Y+@H@("`@("H@0'!A<F%M
M(&UI>&5D("`D9&%T82`@1&%T82!T;R!S=&]R92!I;B!T:&4@8V%C:&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D
M:V5Y+"`D9&%T82D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&1I<F5C=&QY(&]U='!U="!A
M(&-A8VAE9"!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&ME>2`@("`@("!/8FIE8W0@240@
M=&\@<75E<GDN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EF971I;64@($QI
M9F5T:6UE(&]F('1H92!O8FIE8W0@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N
M92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D:V5Y
M+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!A(&=I=F5N(&ME>2!E
M>&ES=',@:6X@=&AE(&-A8VAE+"!V86QI9"!F;W(@=&AE(&=I=F5N"B`@("`@
M*B!L:69E=&EM92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D:V5Y("`@("`@($-A8VAE(&ME>2!T;R!C
M:&5C:RX*("`@("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@3&EF971I
M;64@;V8@=&AE(&ME>2!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@17AI<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!E
M>&ES=',H)&ME>2P@)&QI9F5T:6UE(#T@,2D*("`@('L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!I<F4@86YY(&5X
M:7-T:6YG(&1A=&$@9F]R('1H92!G:79E;B!K97DN"B`@("`@*@H@("`@("H@
M0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!#
M86-H92!K97D@=&\@97AP:7)E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E>'!I<F4H)&ME>2D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($1O(&%N>2!G87)B86=E(&-O;&QE8W1I;VX@
M;F5E9&5D(&9O<B!T:&4@9')I=F5R+@H@("`@("H*("`@("`J($!P<FEV871E
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'-E8W,@(%1H92!M:6YI;75M(&%M;W5N="!O9B!T:6UE("AI
M;B!S96-O;F1S*2!R97%U:7)E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&)E9F]R92!A(&-A8VAE(&ET96T@:7,@<F5M;W9E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V1O1T,H)'-E8W,I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]#
M86-H92!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(
M;W)D95]#86-H92!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W
M92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D
M9')I=F5R6S!=+VQI8B]#86-H92\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D
M<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N9FEG=7)A=&EO;B!O<B!C;VYN96-T:6]N('!A
M<F%M971E<G,@82!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#
M86-H92`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@2&]R9&5?0V%C:&4@
M:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!F86QS
M92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R
M:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A<'`@/2`D9')I=F5R
M6S!=.PH@("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E<ELQ73L*("`@("`@
M("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@
M("`@("!I9B`H96UP='DH)&1R:79E<BD@?'P@)&1R:79E<B`]/2`G;F]N92<I
M('L*("`@("`@("`@("`@)&-A8VAE(#T@)FYE=R!(;W)D95]#86-H92@D<&%R
M86US*3L*("`@("`@("`@("`@<F5T=7)N("1C86-H93L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)&%P<"DI('L*("`@("`@("`@("`@:6YC;'5D
M95]O;F-E("1A<'`@+B`G+VQI8B]#86-H92\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&
M24Q%7U\I("X@)R]#86-H92\G("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@
M("`@("`@("`@:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#
M86-H92\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!`:6YC;'5D95]O;F-E("=(;W)D92]#86-H92\G("X@)&1R
M:79E<B`N("<N<&AP)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(
M;W)D95]#86-H95\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&-A8VAE(#T@)FYE=R`D8VQA
M<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A
M8VAE(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G
M("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&-A8VAE.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?
M0V%C:&4*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N($ET('=I
M;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4*("`@("`J(&EF(&YO($AO
M<F1E7T-A8VAE(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C
M=7)R96YT;'D*("`@("`J(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H
M;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE(&-A8VAE(&)A8VME;F1S("AA;F0L
M('1H=7,L"B`@("`@*B!M=6QT:7!L92!(;W)D95]#86-H92!I;G-T86YC97,I
M(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T
M(&)E(&EN=F]K960@87,Z"B`@("`@*B`D=F%R(#T@)DAO<F1E7T-A8VAE.CIS
M:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R
M("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]#86-H92!S=6)C;&%S<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R
M:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#86-H92\@
M9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A
M9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M
M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0V%C:&4@
M(%1H92!C;VYC<F5T92!(;W)D95]#86-H92!R969E<F5N8V4L(&]R(&9A;'-E
M(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R
M<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH
M)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("AE;7!T>2@D:6YS=&%N
M8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=(#T@)DAO<F1E7T-A8VAE.CIF86-T;W)Y*"1D<FEV97(L("1P
M87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;
M)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S+G!H<```````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8P-S`V(#$P-3$U-#,T,30P(#`R
M,3$T,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RHJ"B`J(%!R969E<F5N8V4@:7,@861M:6YI<W1R871I=F5L
M>2!L;V-K960N"B`J+PID969I;F4H)U]04D5&7TQ/0TM%1"<L(#$I.PH*+RHJ
M"B`J(%!R969E<F5N8V4@:7,@<VAA<F5D(&%M;VYG<W0@87!P;&EC871I;VYS
M+@H@*B\*9&5F:6YE*"=?4%)%1E]32$%2140G+"`R*3L*"B\J*@H@*B!0<F5F
M97)E;F-E('9A;'5E(&AA<R!B965N(&-H86YG960N"B`J+PID969I;F4H)U]0
M4D5&7T1)4E19)RP@-"D["@HO*BH*("H@4')E9F5R96YC92!V86QU92!I<R!T
M:&4@87!P;&EC871I;VX@9&5F875L="X*("HO"F1E9FEN92@G7U!2149?1$5&
M055,5"<L(#@I.PH*+RHJ"B`J(%1H92!0<F5F<SHZ(&-L87-S('!R;W9I9&5S
M(&$@8V]M;6]N(&%B<W1R86-T960@:6YT97)F86-E(&EN=&\@=&AE"B`J('9A
M<FEO=7,@<')E9F5R96YC97,@<W1O<F%G92!M961I=6US+B`@270@86QS;R!I
M;F-L=61E<R!A;&P@;V8@=&AE"B`J(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN
M9RP@<W1O<FEN9RP@86YD(&-H96-K:6YG('!R969E<F5N8V4@=F%L=65S+@H@
M*@H@*B!43T1/.B!D;V-U;65N="!T:&4@9F]R;6%T(&]F('1H92`D7W!R969S
M(&AA<V@@:&5R90H@*@H@*B`D7W!R969S6RIP<F5F(&YA;64J72`](&%R<F%Y
M*`H@*B`@("`@)W9A;'5E)R`@/3X@*D1E9F%U;'0@=F%L=64J+`H@*B`@("`@
M)VQO8VME9"<@/3X@*F)O;VQE86XJ+`H@*B`@("`@)W-H87)E9"<@/3X@*F)O
M;VQE86XJ+`H@*B`@("`@)W1Y<&4G("`@/3X@)V-H96-K8F]X)PH@*B`@("`@
M("`@("`@("`@("`@)W1E>'0G"B`J("`@("`@("`@("`@("`@("`G<&%S<W=O
M<F0G"B`J("`@("`@("`@("`@("`@("`G=&5X=&%R96$G"B`J("`@("`@("`@
M("`@("`@("`G<V5L96-T)PH@*B`@("`@("`@("`@("`@("`@)VYU;6)E<B<*
M("H@("`@("`@("`@("`@("`@("=I;7!L:6-I="<*("H@("`@("`@("`@("`@
M("`@("=S<&5C:6%L)PH@*B`@("`@("`@("`@("`@("`@)VQI;FLG("T@5&AE
M<F4@;75S="!B92!A(&9I96QD(&YA;65D(&5I=&AE<B`G=7)L)PH@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@*&EN=&5R;F%L(&%P<&QI8V%T:6]N(&QI
M;FLI(&]R("=X=7)L)PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@*&5X
M=&5R;F%L(&%P<&QI8V%T:6]N(&QI;FLI(&EF('1H:7,@='EP92!I<R!U<V5D
M+@H@*B`@("`@("`@("`@("`@("`@)V5N=6TG"B`J("`@("`G96YU;2<@("`]
M/B!43T1/+`H@*B`@("`@)V1E<V,G("`@/3X@7R@J1&5S8W)I<'1I;VX@<W1R
M:6YG*BDL"B`J("`@("`G:&5L<"<@("`]/B`J3F%M92!O9B!T:&4@96YT<GD@
M:6X@=&AE(%A-3"!H96QP(&9I;&4J"B`J("D["B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U!R969S+U!R969S+G!H<"QV(#$N,3,W+C$P+C(W(#(P,#8O,#<O
M,#,@,3<Z,S@Z,3$@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J
M+PIC;&%S<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!(87-H(&AO;&1I;F<@
M86QL(&]F('1H92!U<V5R)W,@<')E9F5R96YC97,N($5A8V@@<')E9F5R96YC
M92!I<PH@("`@("H@:71S96QF(&$@:&%S:"P@<V\@=&AI<R!W:6QL('5L=&EM
M871E;'D@8F4@;75L=&DM9&EM96YS:6]N86PN"B`@("`@*@H@("`@("H@6RIP
M<F5F(&YA;64J72`]/B!!<G)A>2@*("`@("`J("`@("!;9%T@(#T^("`J9&5F
M875L="!V86QU92H*("`@("`J("`@("!;;5T@(#T^("`J<')E9B!M87-K*@H@
M("`@("H@("`@(%MV72`@/3X@("IP<F5F('9A;'5E*@H@("`@("H@*0H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?<')E9G,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@=&AI
M<R!S8V]P92X@5&AI<R!I<R!U<V5D('1O"B`@("`@*B!M86EN=&%I;B!T:&4@
M87!P;&EC871I;VX@<V-O<&4@8F5T=V5E;B!S971S(&]F('!R969E<F5N8V5S
M+B!">0H@("`@("H@9&5F875L="P@86QL('!R969E<F5N8V5S(&)E;&]N9R!T
M;R!T:&4@(F=L;V)A;"(@*$AO<F1E*2!S8V]P92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S8V]P92`]("=H;W)D92<[
M"@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@8W5R<F5N
M="!U<V5R;F%M92X@5&AI<R!I;F1I8V%T97,@=&AE(&]W;F5R(&]F('1H90H@
M("`@("H@<')E9F5R96YC97,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?=7-E<B`]("<G.PH*("`@("\J*@H@("`@("H@
M0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@<')E9F5R96YC92!C86-H:6YG
M('-H;W5L9"!B92!U<V5D+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("HO"B`@("!V87(@)%]C86-H:6YG(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!(87-H(&AO;&1I;F<@<')E9F5R96YC97,@=VET:"!H;V]K(&9U;F-T
M:6]N<R!D969I;F5D+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?:&]O:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M2&%V92!W92!R=6X@:&]O:R!F=6YC=&EO;G,@>65T/PH@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]H;V]K<T-A;&QE9"`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!$969A=6QT(&-O;G-T<G5C=&]R("AM
M=7-T(&)E(&-A;&QE9"!F<F]M(&5A8V@@97AT96YD:6YG(&-L87-S(&EN('1H
M96ER"B`@("`@*B!C;VYS=')U8W1O<G,@=FEA('!A<F5N=#HZ4')E9G,H*2DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%!R969S*"D*("`@('L*("`@("`@("`D
M=&AI<RT^7W-H=71D;W=N*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C:&%R<V5T('5S960@8GD@=&AE(&-O;F-R971E('!R969E<F5N
M8V4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('!R969E<F5N8V4@8F%C:V5N9"=S(&-H87)S970N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@(')E='5R;B!.3%,Z
M.F=E=$-H87)S970H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@
M=&AE('-E<W-I;VXM8F%S960@<')E9F5R96YC97,@8V%C:&4@*&EF(&%V86EL
M86)L92DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE
M('!R969E<F5N8V4@=&\@=7!D871E+B`@268@96UP='DL('=I;&P@=7!D871E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&4@96YT:7)E(&-A8VAE
M('=I=&@@=&AE(&-U<G)E;G0@<V5T(&]F('!R969S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C86-H955P9&%T92@D<')E9B`](&YU;&PI"B`@("!["B`@("`@
M("`@+RH@4F5T=7)N(&EM;65D:6%T96QY(&EF(&-A8VAI;F<@:7,@9&ES86)L
M960N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V-A8VAI;F<I('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1?
M4T534TE/3ELG<')E9G-?8V%C:&4G72DI('L*("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)'!R968I*2!["B`@("`@("`@("`@("`@("`D<')E9G,@/2`D=&AI
M<RT^7W!R969S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'!R969S(#T@87)R87DH)'!R968@/3X@)'1H:7,M/E]P<F5F<ULD<')E
M9ETI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!0;&%C92!E86-H
M('!R969E<F5N8V4@:6X@=&AE(&-A8VAE(&%C8V]R9&EN9R!T;R!I=',*("`@
M("`@("`@("`@("H@<V-O<&4N("HO"B`@("`@("`@("`@(&9O<F5A8V@@*"1P
M<F5F<R!A<R`D;F%M92`]/B`D<')E9BD@>PH@("`@("`@("`@("`@("`@)%]3
M15-324].6R=P<F5F<U]C86-H92==6R1T:&ES+3YG97138V]P92@D;F%M92E=
M6R1N86UE72`]("1P<F5F.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@5')I97,@=&\@9FEN9"!T:&4@<F5Q=65S=&5D
M('!R969E<F5N8V5S(&EN('1H92!C86-H92X@268@=&AE>2!E>&ES="P*("`@
M("`J('5P9&%T92!T:&4@)'!R969S(&AA<V@@=VET:"!T:&4@8V%C:&5D('9A
M;'5E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V%C:&5,;V]K=7`H*0H@("`@>PH@("`@("`@("\J(%)E='5R;B!I;6UE
M9&EA=&5L>2!I9B!C86-H:6YG(&ES(&1I<V%B;&5D+B`J+PH@("`@("`@(&EF
M("@A)'1H:7,M/E]C86-H:6YG*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)W!R
M969S7V-A8VAE)UU;)VAO<F1E)UTI("8F"B`@("`@("`@("`@(&ES<V5T*"1?
M4T534TE/3ELG<')E9G-?8V%C:&4G75LD=&AI<RT^7W-C;W!E72DI('L*"B`@
M("`@("`@("`@("\J(%)E<W1O<F4@9VQO8F%L('!R969E<F5N8V5S+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^7W!R969S(#T@87)R87E?;65R9V4H)'1H:7,M
M/E]P<F5F<RP@)%]315-324].6R=P<F5F<U]C86-H92==6R=H;W)D92==+"`D
M7U-%4U-)3TY;)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI.PH*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W('!R
M969E<F5N8V4@96YT<GD@=&\@=&AE("1P<F5F<R!H87-H+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!R968@("!4:&4@;F%M92!O9B!T:&4@<')E
M9F5R96YC92!T;R!A9&0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86P@("`@
M5&AE(&EN:71I86P@=F%L=64@;V8@=&AE('!R969E<F5N8V4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;6%S:R`@5&AE(&EN:71I86P@8FET;6%S:R!O9B!T
M:&4@<')E9F5R96YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D*"1P<F5F
M+"`D=F%L(#T@)R<L("1M87-K(#T@,"D*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]P<F5F<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F5F<ULD<')E9ET@/2!A<G)A>2@G=B<@/3X@)'9A;"P@)VTG(#T^("1M87-K
M+"`G9"<@/3X@)'9A;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5M;W9E<R!A('!R969E<F5N8V4@96YT<GD@9G)O;2!T:&4@)'!R969S
M(&AA<V@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE
M(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@<F5M;W9E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F4H)'!R968I"B`@("!["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1T:&ES+3Y?<')E9G,I*2!["B`@("`@("`@("`@("1S8V]P92`]
M("1T:&ES+3YG97138V]P92@D<')E9BD["B`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?<')E9G-;)'!R969=*3L*("`@("`@("`@("`@=6YS970H)%]315-3
M24].6R=P<F5F<U]C86-H92==6R1S8V]P95U;)'!R969=*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!G:79E;B!P<F5F97)E
M;F-E<R`H)'!R968I('1O('1H92!S<&5C:69I960@=F%L=64*("`@("`J("@D
M=F%L*2P@:68@=&AE('!R969E<F5N8V4@:7,@;6]D:69I86)L92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("`@("`@5&AE(&YA;64@;V8@
M=&AE('!R969E<F5N8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F%L("`@("`@(%1H92!N97<@=F%L=64@9F]R('1H:7,@<')E9F5R96YC
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E('1H
M92!P<F5F97)E;F-E('9A;'5E(&=E=',@8V]N=F5R=&5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@8W5R<F5N="!C:&%R<V5T
M('1O('1H92!B86-K96YD)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!C:&%R<V5T+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!I9B!T:&4@=F%L=64@=V%S('-U8V-E<W-F=6QL>2!S970L(&9A;'-E
M(&]N(&$*("`@("`J("`@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T5F%L=64H)'!R968L("1V86PL("1C;VYV97)T
M(#T@=')U92D*("`@('L*("`@("`@("`O*B!%>&ET(&5A<FQY(&EF('1H:7,@
M<')E9F5R96YC92!I<R!L;V-K960@;W(@9&]E<VXG="!E>&ES="X@*B\*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<')E9G-;)'!R969=*2!\?"`D=&AI
M<RT^:7-,;V-K960H)'!R968I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W-E=%9A;'5E
M*"1P<F5F+"`D=F%L+"!T<G5E+"`D8V]N=F5R="D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7U]S970H)&YA;64L("1V86QU92D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/G-E=%9A;'5E*"1N86UE+"`D=F%L=64I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@9VEV96X@<')E9F5R96YC97,@*"1P<F5F
M*2!T;R!T:&4@<W!E8VEF:65D('9A;'5E"B`@("`@*B`H)'9A;"DL('=H971H
M97(@;W(@;F]T('1H92!P<F5F97)E;F-E(&ES('5S97(M;6]D:69I86)L92P@
M=6YS970*("`@("`J('1H92!D969A=6QT(&)I="P@86YD('-E="!T:&4@9&ER
M='D@8FET+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!R968@("`@(%1H92!N86UE(&]F
M('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@("`J($!P87)A;2!S=')I
M;F<@("1V86P@("`@("!4:&4@;F5W('9A;'5E(&9O<B!T:&ES('!R969E<F5N
M8V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER='D@("`@5')U92!I9B!W
M92!S:&]U;&0@;6%R:R!T:&4@;F5W('9A;'5E(&%S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@9&ER='D@*&-H86YG960I+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&-O;G9E<G0@($EF('1R=64@=&AE('!R969E<F5N8V4@
M=F%L=64@9V5T<R!C;VYV97)T960*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!F<F]M('1H92!C=7)R96YT(&-H87)S970@=&\@=&AE(&)A8VME
M;F0G<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-H87)S970N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!V
M86QU92!W87,@<W5C8V5S<V9U;&QY('-E="P@9F%L<V4@;VX@80H@("`@("H@
M("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<V5T5F%L=64H)'!R968L("1V86PL("1D:7)T>2`]('1R=64L("1C;VYV
M97)T(#T@=')U92D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@(&EF("@D8V]N=F5R="D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M
M/F-O;G9E<G14;T1R:79E<B@D=F%L+"!.3%,Z.F=E=$-H87)S970H*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@<')E9F5R96YC92=S('9A;'5E
M(&ES(&%L<F5A9'D@97%U86P@=&\@)'9A;"P@9&]N)W0*("`@("`@("`@*B!B
M;W1H97(@8VAA;F=I;F<@:70N($-H86YG:6YG(&ET('=O=6QD('-E="!T:&4@
M(F1I<G1Y(B!B:70L"B`@("`@("`@("H@8V%U<VEN9R!A;B!U;FYE8V5S<V%R
M>2!U<&1A=&4@;&%T97(@;VX@:6X@=&AE('-T;W)A9V4*("`@("`@("`@*B!R
M;W5T:6YE+B`J+PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R969S6R1P
M<F5F72D@)B8*("`@("`@("`@("`@*"@D=&AI<RT^7W!R969S6R1P<F5F75LG
M=B==(#T]("1V86PI("8F"B`@("`@("`@("`@("`A)'1H:7,M/FES1&5F875L
M="@D<')E9BDI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF('1H92!V86QU92!E>&-E
M961S('1H92!A;&QO=V%B;&4@<W1O<F%G90H@("`@("`@("`J(&QI;6ET+B`J
M+PH@("`@("`@(&EF("AI<W-E="@D8V]N9ELG<')E9G,G75LG;6%X<VEZ92==
M*2D@>PH@("`@("`@("`@("!I9B`H<W1R;&5N*"1V86PI(#X@)&-O;F9;)W!R
M969S)UU;)VUA>'-I>F4G72D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("1N
M;W1I9FEC871I;VX["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&YO=&EF
M:6-A=&EO;BDI('L*("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B5&AE('!R969E<F5N8V4@7"(E<UPB(&-O=6QD
M(&YO="!B92!S879E9"!B96-A=7-E(&ET<R!D871A(&5X8V5E9&5D('1H92!M
M87AI;75M(&%L;&]W86)L92!S:7IE(BDL("1P<F5F*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M*B!!<W-I9VX@=&AE(&YE=R!V86QU92P@=6YS970@=&AE(")D969A=6QT(B!B
M:70L(&%N9"!S970@=&AE"B`@("`@("`@("`@(F1I<G1Y(B!B:70N("HO"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<')E9G-;)'!R969=6R=M)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-;)'!R969=6R=M)UT@/2`P.PH@
M("`@("`@('T*("`@("`@("`D=&AI<RT^7W!R969S6R1P<F5F75LG=B==(#T@
M)'9A;#L*("`@("`@("`D=&AI<RT^<V5T1&5F875L="@D<')E9BP@9F%L<V4I
M.PH@("`@("`@(&EF("@D9&ER='DI('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$1I<G1Y*"1P<F5F+"!T<G5E*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3YC86-H955P9&%T92@D<')E9BD["@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@;V8@=&AE
M(')E<75E<W1E9"!P<F5F97)E;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!R968@("`@("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T
M;R!R971R:65V92X*("`@("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)
M9B!T<G5E('1H92!P<F5F97)E;F-E('9A;'5E(&=E=',@8V]N=F5R=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@8F%C:V5N
M9"=S(&-H87)S970@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!C:&%R<V5T+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=F%L=64@;V8@=&AE('!R969E<F5N8V4L(&YU;&P@:68@
M:70@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L
M=64H)'!R968L("1C;VYV97)T(#T@=')U92D*("`@('L*("`@("`@("!S=&%T
M:6,@)&-H87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*
M("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]P<F5F<ULD
M<')E9EU;)W8G72DI(#\*("`@("`@("`@("`@*"1C;VYV97)T(#\*("`@("`@
M("`@("`@("1T:&ES+3YC;VYV97)T1G)O;41R:79E<B@D=&AI<RT^7W!R969S
M6R1P<F5F75LG=B==+"`D8VAA<G-E="D@.@H@("`@("`@("`@("`@)'1H:7,M
M/E]P<F5F<ULD<')E9EU;)W8G72D@.@H@("`@("`@("`@("!N=6QL.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]?9V5T*"1N86UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T5F%L=64H)&YA;64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@36]D:69I97,@=&AE(")L;V-K960B(&)I="!F;W(@=&AE(&=I=F5N
M('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9B`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*("`@
M("`J($!P87)A;2!B;V]L96%N("1B;V]L("!4:&4@;F5W(&)O;VQE86X@=F%L
M=64@9F]R('1H92`B;&]C:V5D(B!B:70N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$QO8VME9"@D<')E9BP@)&)O;VPI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]S971-87-K*"1P<F5F+"`D8F]O;"P@7U!2149?3$]#2T5$*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T871E(&]F('1H92`B;&]C
M:V5D(B!B:70@9F]R('1H92!G:79E;B!P<F5F97)E;F-E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F
M97)E;F-E('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5&AE(&)O;VQE86X@<W1A=&4@;V8@)'!R968G<R`B;&]C:V5D(B!B:70N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3&]C:V5D*"1P<F5F*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7TQ/
M0TM%1"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;V1I9FEE<R!T:&4@(G-H
M87)E9"(@8FET(&9O<B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O
M;VP@(%1H92!N97<@8F]O;&5A;B!V86QU92!F;W(@=&AE(")S:&%R960B(&)I
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4VAA<F5D*"1P<F5F+"`D8F]O
M;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$UA<VLH)'!R968L("1B;V]L
M+"!?4%)%1E]32$%2140I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@<W1A=&4@;V8@=&AE(")S:&%R960B(&)I="!F;W(@=&AE(&=I=F5N
M('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9B`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@8VAE8VLN"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4:&4@8F]O;&5A;B!S=&%T92!O
M9B`D<')E9B=S(")S:&%R960B(&)I="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-3:&%R960H)'!R968I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9V5T36%S:R@D<')E9BP@7U!2149?4TA!4D5$*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($UO9&EF:65S('1H92`B9&ER='DB(&)I="!F;W(@=&AE(&=I=F5N
M('!R969E<F5N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E
M9B`@("`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E('1O(&UO9&EF>2X*
M("`@("`J($!P87)A;2!B;V]L96%N("1B;V]L("`@("!4:&4@;F5W(&)O;VQE
M86X@=F%L=64@9F]R('1H92`B9&ER='DB(&)I="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T1&ER='DH)'!R968L("1B;V]L*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<V5T36%S:R@D<')E9BP@)&)O;VPL(%]04D5&7T1)4E19*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T871E(&]F('1H92`B
M9&ER='DB(&)I="!F;W(@=&AE(&=I=F5N('!R969E<F5N8V4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4:&4@8F]O;&5A;B!S=&%T92!O9B`D<')E9B=S(")D:7)T>2(@8FET
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T1I<G1Y*"1P<F5F*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7T1)
M4E19*3L*("`@('T*"B`@("`O*BH*("`@("`J($UO9&EF:65S('1H92`B9&5F
M875L="(@8FET(&9O<B!T:&4@9VEV96X@<')E9F5R96YC92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R
M969E<F5N8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O
M;VP@(%1H92!N97<@8F]O;&5A;B!V86QU92!F;W(@=&AE(")D969A=6QT(B!B
M:70N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)'!R968L("1B
M;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T36%S:R@D<')E9BP@)&)O
M;VPL(%]04D5&7T1%1D%53%0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@9&5F875L="!V86QU92!O9B!T:&4@9VEV96X@<')E9F5R96YC
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("!4:&4@;F%M
M92!O9B!T:&4@<')E9F5R96YC92!T;R!G970@=&AE(&1E9F%U;'0@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@("`@(%1H92!P<F5F97)E
M;F-E)W,@9&5F875L="!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1&5F875L="@D<')E9BD*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y*"1T
M:&ES+3Y?<')E9G-;)'!R969=6R=D)UTI(#\*("`@("`@("`@("`@)'1H:7,M
M/E]P<F5F<ULD<')E9EU;)V0G72`Z"B`@("`@("`@("`@("<G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!T:&4@8W5R<F5N="!P<F5F
M97)E;F-E('9A;'5E(&ES('1H92!D969A=6QT"B`@("`@*B!V86QU92!F<F]M
M('!R969S+G!H<"!O<B!A('5S97(@9&5F:6YE9"!V86QU90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!R968@(%1H92!N86UE(&]F('1H92!P<F5F
M97)E;F-E('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;B`@5')U92!I9B!T:&4@<')E9F5R96YC92!I<R!T:&4@87!P;&EC871I;VX@
M9&5F875L=`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-$969A=6QT*"1P<F5F*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V=E=$UA<VLH)'!R968L(%]04D5&7T1%1D%53%0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@=F%L=64@9F]R(&$@
M9VEV96X@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F("`@5&AE(&YA;64@;V8@
M=&AE('!R969E<F5N8V4@=&\@;6]D:69Y+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&)O;VP@(%1H92!N97<@8F]O;&5A;B!V86QU92!F;W(@=&AE(")D969A
M=6QT(B!B:70N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6%S:R`@5&AE(&UA
M<VL@=&\@861D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T36%S:R@D<')E
M9BP@)&)O;VPL("1M87-K*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!R969S6R1P<F5F72DI('L*("`@("`@("`@("`@:68@*"1B;V]L("$]
M("1T:&ES+3Y?9V5T36%S:R@D<')E9BP@)&UA<VLI*2!["B`@("`@("`@("`@
M("`@("!I9B`H)&)O;VPI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!R969S6R1P<F5F75LG;2==('P]("1M87-K.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!R969S6R1P
M<F5F75LG;2==("8]('XD;6%S:SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@
M=&AE(&)O;VQE86X@<W1A=&4@9F]R(&$@9VEV96X@;6%S:RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P<F5F("`@5&AE(&YA;64@;V8@=&AE('!R969E<F5N8V4@=&\@;6]D
M:69Y+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@(%1H92!M87-K('1O
M(&=E="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1H92!B;V]L
M96%N('-T871E(&9O<B!T:&4@9VEV96X@;6%S:RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V=E=$UA<VLH)'!R968L("1M87-K*0H@("`@>PH@("`@("`@(')E
M='5R;B!I<W-E="@D=&AI<RT^7W!R969S6R1P<F5F75LG;2==*2`_("@D=&AI
M<RT^7W!R969S6R1P<F5F75LG;2==("8@)&UA<VLI(#H@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AE(&-U<G)E
M;G0@<')E9F5R96YC92!I<R!E;7!T>2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P<F5F("!4:&4@;F%M92!O9B!T:&4@<')E9F5R96YC92!T;R!C
M:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('!R969E<F5N8V4@:7,@96UP='DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES16UP='DH)'!R968I"B`@("!["B`@("`@("`@<F5T=7)N(&5M<'1Y*"1T
M:&ES+3Y?<')E9G-;)'!R969=6R=V)UTI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@<V-O<&4@;V8@=&AE(&=I=F5N('!R969E<F5N8V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')E9B`@5&AE(&YA;64@
M;V8@=&AE('!R969E<F5N8V4@=&\@97AA;6EN92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('-C;W!E(&]F('1H92`D<')E9BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4V-O<&4H)'!R968I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YI<U-H87)E9"@D<')E9BDI('L*("`@("`@("`@("`@<F5T
M=7)N("=H;W)D92<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<V-O<&4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&$@;&ES="!O9B`B9&ER='DB('!R969E<F5N8V5S+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!L:7-T(&]F(")D:7)T>2(@<')E9F5R96YC97,@
M:6X@)'1H:7,M/E]P<F5F<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<G1Y
M4')E9G,H*0H@("`@>PH@("`@("`@("1D:7)T>5]P<F5F<R`](&%R<F%Y*"D[
M"@H@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]P<F5F<RD@
M87,@)'!R968I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YI<T1I<G1Y*"1P
M<F5F*2D@>PH@("`@("`@("`@("`@("`@)&1I<G1Y7W!R969S6UT@/2`D<')E
M9CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D
M:7)T>5]P<F5F<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!T
M:&4@9&5F875L="!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5T<FEE=F4H*0H@("`@>PH@("`@("`@("\J($QO860@9&5F875L=',@=&\@
M;6%K92!S=7)E('=E(&AA=F4@86QL('!R969E<F5N8V5S+B`J+PH@("`@("`@
M("1T:&ES+3Y?<V5T1&5F875L=',H)VAO<F1E)RD["B`@("`@("`@)'1H:7,M
M/E]S971$969A=6QT<R@D=&AI<RT^7W-C;W!E*3L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N('=I
M;&P@8F4@<G5N(&%T('1H92!E;F0@;V8@979E<GD@<F5Q=65S="!A<R!A('-H
M=71D;W=N"B`@("`@*B!F=6YC=&EO;B`H<F5G:7-T97)E9"!B>2!T:&4@4')E
M9G,Z.B!C;VYS=')U8W1O<BDN("!!;&P@<')E9G,@=VET:"!T:&4*("`@("`J
M(&1I<G1Y(&)I="!S970@=VEL;"!B92!S879E9"!T;R!T:&4@<W1O<F%G92!B
M86-K96YD(&%T('1H:7,@=&EM93L@=&AU<RP*("`@("`J('1H97)E(&ES(&YO
M(&YE960@=&\@;6%N=6%L;'D@8V%L;"`D<')E9G,M/G-T;W)E*"D@979E<GD@
M=&EM92!A"B`@("`@*B!P<F5F97)E;F-E(&ES(&-H86YG960N"B`@("`@*@H@
M("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('-T;W)E*"D*
M("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@9G5N8W1I;VX@<')O=FED97,@8V]M;6]N(&-L96%N=7`@9G5N
M8W1I;VYS(&9O<B!A;&P@;V8@=&AE(&1R:79E<@H@("`@("H@:6UP;&5M96YT
M871I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1A;&P@($-L
M96%N('5P(&%L;"!(;W)D92!P<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@8VQE86YU<"@D86QL(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@
M4F5M;W9E('1H:7,@<V-O<&4@9G)O;2!T:&4@<')E9F5R96YC97,@8V%C:&4L
M(&EF(&ET"B`@("`@("`@("`@97AI<W1S+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D7U-%4U-)3TY;)W!R969S7V-A8VAE)UU;)'1H:7,M/E]S8V]P95TI*2![
M"B`@("`@("`@("`@('5N<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G75LD
M=&AI<RT^7W-C;W!E72D["B`@("`@("`@?0H*("`@("`@("`O*B!097)F;W)M
M(&$@2&]R9&4M=VED92!C;&5A;G5P/R`J+PH@("`@("`@(&EF("@D86QL*2![
M"B`@("`@("`@("`@("\J($1E<W1R;WD@=&AE(&-O;G1E;G1S(&]F('1H92!P
M<F5F97)E;F-E<R!H87-H+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W!R969S
M(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J($1E<W1R;WD@=&AE(&-O;G1E
M;G1S(&]F('1H92!P<F5F97)E;F-E<R!C86-H92X@*B\*("`@("`@("`@("`@
M:68@*&ES<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G72DI('L*("`@("`@
M("`@("`@("`@('5N<V5T*"1?4T534TE/3ELG<')E9G-?8V%C:&4G72D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;&5A<G,@86QL('!R969E<F5N8V5S(&9R;VT@=&AE(&)A8VME;F0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`D=&AI<RT^
M8VQE86YU<"AT<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S
M(&$@=F%L=64@9G)O;2!T:&4@9')I=F5R)W,@8VAA<G-E="!T;R!T:&4@<W!E
M8VEF:65D(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1V
M86QU92`@("`@02!V86QU92!T;R!C;VYV97)T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@8V]N=F5R="!T;RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]N=F5R=&5D('9A;'5E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T1G)O;41R:79E<B@D=F%L
M=64L("1C:&%R<V5T*0H@("`@>PH@("`@("`@(')E='5R;B`D=F%L=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A('9A;'5E(&9R;VT@=&AE
M('-P96-I9FEE9"!C:&%R<V5T('1O('1H92!D<FEV97(G<R!C:&%R<V5T+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@($$@=F%L=64@=&\@
M8V]N=F5R="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C
M:&%R<V5T('1O(&-O;G9E<G0@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@8V]N=F5R=&5D('9A;'5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;VYV97)T5&]$<FEV97(H)'9A;'5E+"`D8VAA<G-E="D*("`@('L*
M("`@("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4&]P=6QA=&5S('1H92`D<')E9G,@:&%S:"!W:71H(&YE=R!E;G1R:65S(&%N
M9"!E>'1E<FYA;&QY(&1E9FEN960*("`@("`J(&1E9F%U;'0@=F%L=65S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI8V%T
M:6]N('1O(&QO860@9&5F875L=',@9F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<V5T1&5F875L=',H)&%P<"D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH@("`@("`@("1F:6QE;F%M92`]("1R96=I<W1R>2T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<O<')E9G,N<&AP)SL*"B`@("`@
M("`@+RH@16YS=7)E('1H870@=&AE(&1E9F%U;'1S(&9R;VT@=&AI<R!F:6QE
M(&%R92!O;FQY(')E860@;VYC92X*("`@("`@("`@("!!;'-O+"!M86ME('-U
M<F4@=V4@8V%N(')E860@=&AI<R!F:6QE+B`J+PH@("`@("`@(&EF("@A0&ES
M7W)E861A8FQE*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5A9"!T:&4@8V]N9FEG=7)A=&EO;B!F
M:6QE+B!4:&4@)%]P<F5F<R!A<G)A>2P@=VAI8V@@=VEL;"!B90H@("`@("`@
M("`@(&EN(&QO8V%L('-C;W!E+"!I<R!A<W-U;65D('1O(&AO;&0@=&AE(&1E
M9F%U;'0@=F%L=65S+B`J+PH@("`@("`@(&EN8VQU9&4@)&9I;&5N86UE.PH@
M("`@("`@(&9O<F5A8V@@*"1?<')E9G,@87,@)'!R968@/3X@)'!V86QS*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<'9A;'-;)W9A;'5E)UTI("8F"B`@
M("`@("`@("`@("`@("!I<W-E="@D<'9A;'-;)VQO8VME9"==*2`F)@H@("`@
M("`@("`@("`@("`@:7-S970H)'!V86QS6R=S:&%R960G72D@)B8*("`@("`@
M("`@("`@("`@("@D<'9A;'-;)W1Y<&4G72`A/2`G;&EN:R<I("8F"B`@("`@
M("`@("`@("`@("`H)'!V86QS6R=T>7!E)UT@(3T@)W-P96-I86PG*2D@>PH@
M("`@("`@("`@("`@("`@)'!R968@/2!S=')?<F5P;&%C92@G+B<L("=?)RP@
M)'!R968I.PH@("`@("`@("`@("`@("`@)&UA<VL@/2`P.PH@("`@("`@("`@
M("`@("`@:68@*"1P=F%L<ULG;&]C:V5D)UTI('L*("`@("`@("`@("`@("`@
M("`@("`D;6%S:R!\/2!?4%)%1E],3T-+140["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H)'!V86QS6R=S:&%R960G72!\?"`D87!P
M(#T]("=H;W)D92<I('L*("`@("`@("`@("`@("`@("`@("`D;6%S:R!\/2!?
M4%)%1E]32$%2140["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D;6%S:R`F/2!^7U!2149?1$E25%D["B`@("`@("`@("`@("`@("`D;6%S
M:R!\/2!?4%)%1E]$149!54Q4.PH*("`@("`@("`@("`@("`@("1T:&ES+3YA
M9&0H)'!R968L("1P=F%L<ULG=F%L=64G72P@)&UA<VLI.PH@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D<'9A;'-;)VAO;VLG72DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-E=$AO;VLH)'!R968I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!5
M<&1A=&4@=&AE('!R969E<F5N8V5S(&-A8VAE('=I=&@@=&AE(&1E9F%U;'1S
M+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4&5R9F]R;7,@<VAU=&1O=VX@86-T:79I=&EE<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-H=71D;W=N*"D*("`@('L*("`@("`@("!R96=I<W1E<E]S:'5T9&]W
M;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=S=&]R92<I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9"`D<')E9B!T;R!T:&4@;&ES="!O9B!P<F5F97)E
M;F-E<R!W:71H(&AO;VL@9G5N8W1I;VYS+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R968@(%1H92!P<F5F97)E;F-E('=I=&@@82!H;V]K+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<V5T2&]O:R@D<')E9BD*("`@('L*("`@
M("`@("`D=&AI<RT^7VAO;VMS6UT@/2`D<')E9CL*("`@('T*"B`@("`O*BH*
M("`@("`J($%F=&5R('!R969E<F5N8V5S(&AA=F4@8F5E;B!L;V%D960L('-E
M="!A;GD@;&]C:V5D(&]R(&5M<'1Y"B`@("`@*B!P<F5F97)E;F-E<R!T:&%T
M(&AA=F4@:&]O:W,@=&\@=&AE(')E<W5L="!O9B!T:&4@:&]O:RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-A;&Q(;V]K<R@I"B`@("!["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1T:&ES+3Y?:&]O:W-#86QL960I*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?:&]O:W-#86QL
M960@/2!T<G5E.PH*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?:&]O:W,I
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["B`@("`@("`@:6YC;'5D95]O;F-E("1R96=I<W1R
M>2T^9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C;VYF:6<O:&]O:W,N
M<&AP)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAO;VMS(&%S("1P<F5F
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-,;V-K960H)'!R968I('Q\
M"B`@("`@("`@("`@("`@("`A)'1H:7,M/F=E=%9A;'5E*"1P<F5F*2!\?`H@
M("`@("`@("`@("`@("`@)'1H:7,M/FES1&5F875L="@D<')E9BDI('L*("`@
M("`@("`@("`@("`@("1F=6YC(#T@)U]P<F5F<U]H;V]K7R<@+B`D<')E9CL*
M("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)&9U;F,I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971686QU92@D<')E9BP@
M)&9U;F,H)'1H:7,M/E]U<V5R*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!0<F5F<R!I;G-T86YC92!B87-E
M9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I
M=F5R("`@("!4:&4@='EP92!O9B!C;VYC<F5T92!0<F5F<R!S=6)C;&%S<R!T
M;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@268@
M)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL@:6X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R6S!=+VQI8B]0
M<F5F<R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@(%1H92!S8V]P92!F
M;W(@=&AI<R!S970@;V8@<')E9F5R96YC97,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(@=VAO(&]W;G,@
M=&AI<R!S970@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!P
M<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4
M:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A
M9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!O<B!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S
M<R!M:6=H="!N965D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@
M(%-H;W5L9"!C86-H:6YG(&)E('5S960_"B`@("`@*@H@("`@("H@0')E='5R
M;B!0<F5F<R`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@4')E9G,@:6YS
M=&%N8V4L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'-C
M;W!E(#T@)VAO<F1E)RP@)'5S97(@/2`G)RP@)'!A<W-W;W)D(#T@)R<L"B`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86US(#T@;G5L;"P@)&-A8VAI;F<@
M/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@
M>PH@("`@("`@("`@("`D87!P(#T@)&1R:79E<ELP73L*("`@("`@("`@("`@
M)&1R:79E<B`]("1D<FEV97);,5T["B`@("`@("`@?0H*("`@("`@("`O*B!!
M='1E;7!T('1O(')E9VES=&5R("AC86-H92D@=&AE("1P<F5F<R!H87-H(&EN
M('-E<W-I;VX@<W1O<F%G92X@*B\*("`@("`@("!I9B`H)&-A8VAI;F<I('L*
M("`@("`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)W!R969S7V-A8VAE
M)UTI*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)W!R969S7V-A8VAE
M)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D9')I=F5R(#T@8F%S96YA;64H)&1R:79E<BD["B`@("`@("`@:68@*&5M
M<'1Y*"1D<FEV97(I('Q\("1D<FEV97(@/3T@)VYO;F4G*2!["B`@("`@("`@
M("`@("1D<FEV97(@/2`G<V5S<VEO;B<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@
M2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G<')E9G,G+"`D9')I=F5R*3L*("`@
M("`@("!]"@H@("`@("`@("\J($EF("1P87)A;7-;)W5S97)?:&]O:R==(&ES
M(&1E9FEN960L('5S92!I="!T;R!R971R:65V92!T:&4@=F%L=64@=&\*("`@
M("`@("`@*B!U<V4@9F]R('1H92!U<V5R;F%M92`H)'1H:7,M/E]U<V5R*2X@
M3W1H97)W:7-E+"!J=7-T('5S92!T:&4@=F%L=64*("`@("`@("`@*B!P87-S
M960@:6X@=&AE("1U<V5R('!A<F%M971E<BX@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1P87)A;7-;)W5S97)?:&]O:R==*2`F)@H@("`@("`@("`@("!F=6YC
M=&EO;E]E>&ES=',H)'!A<F%M<ULG=7-E<E]H;V]K)UTI*2!["B`@("`@("`@
M("`@("1U<V5R(#T@8V%L;%]U<V5R7V9U;F,H)'!A<F%M<ULG=7-E<E]H;V]K
M)UTL("1U<V5R*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&%P
M<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R96=I
M<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]0<F5F<R\G
M("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H9FEL95]E
M>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U!R969S+R<@+B`D9')I=F5R
M("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+U!R969S+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R
M9&4O4')E9G,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@
M("`@("`D8VQA<W,@/2`G4')E9G-?)R`N("1D<FEV97(["B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1P<F5F<R`]
M("9N97<@)&-L87-S*"1U<V5R+"`D<&%S<W=O<F0L("1S8V]P92P@)'!A<F%M
M<RP@)&-A8VAI;F<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M<F5F<R`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@
M)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P<F5F<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E(%!R969S
M(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+B!)="!W:6QL(&]N
M;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO(%!R969S(&EN<W1A;F-E
M"B`@("`@*B!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X
M:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU
M;'1I<&QE('!R969E<F5N8V4@<V]U<F-E<R`H86YD+"!T:'5S+`H@("`@("H@
M;75L=&EP;&4@4')E9G,@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R
M(#T@)E!R969S.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D9')I=F5R("`@("!4:&4@='EP92!O9B!C;VYC<F5T92!0<F5F<R!S
M=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO
M;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R
M6S!=+VQI8B]0<F5F<R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV
M97);,5TN<&AP+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@(%1H
M92!S8V]P92!F;W(@=&AI<R!S970@;V8@<')E9F5R96YC97,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(@
M=VAO(&]W;G,@=&AI<R!S970@;V8*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!P<F5F97)E;F-E<RX*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("1U<V5R+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN
M:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!O<B!C;VYN96-T:6]N('!A<F%M971E<G,@
M82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&-A8VAI;F<@(%-H;W5L9"!C86-H:6YG(&)E('5S960_"B`@("`@*@H@("`@
M("H@0')E='5R;B!0<F5F<R`@5&AE(&-O;F-R971E(%!R969S(')E9F5R96YC
M92P@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9S:6YG;&5T;VXH)&1R:79E<BP@)'-C;W!E(#T@)VAO<F1E)RP@)'5S97(@
M/2`G)RP@)'!A<W-W;W)D(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7,@/2!N=6QL+"`D8V%C:&EN9R`]('1R=64I"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@2&]R
M9&4Z.F=E=$1R:79E<D-O;F9I9R@G<')E9G,G+"`D9')I=F5R*3L*("`@("`@
M("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&1R
M:79E<BP@)'5S97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC
M97-;)'-I9VYA='5R95T@/2`F4')E9G,Z.F9A8W1O<GDH)&1R:79E<BP@)'-C
M;W!E+"`D=7-E<BP@)'!A<W-W;W)D+"`D<&%R86US+"`D8V%C:&EN9RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M73L*("`@('T*"GT*````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]!=71H+G!H<```````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#$R-#$R,"`Q,#4Q-30S-#$T,"`P,C`W-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!P87)A;65T97(@;F%M92!F;W(@=&AE(&QO9V]U="!R
M96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7U!!4D%-)RP@)VQO9V]U
M=%]R96%S;VXG*3L*"B\J*@H@*B!4:&4@<&%R86UE=&5R(&YA;64@9F]R('1H
M92!L;V=O=70@;65S<V%G92!U<V5D('=I=&@@='EP90H@*B!!551(7U)%05-/
M3E]-15-304=%+@H@*B\*9&5F:6YE*"=!551(7U)%05-/3E]-4T=?4$%204TG
M+"`G;&]G;W5T7VUS9R<I.PH*+RHJ"B`J(%1H92`G8F%D;&]G:6XG(')E87-O
M;BX*("H*("H@5&AE(&9O;&QO=VEN9R`G<F5A<V]N<R<@9F]R('1H92!L;V=O
M=70@<V-R965N(&%R92!R96-O9VYI>F5D.@H@*B`\<')E/@H@*B`@("=B861L
M;V=I;B<@("`M+2`@0F%D('5S97)N86UE(&%N9"]O<B!P87-S=V]R9`H@*B`@
M("=B<F]W<V5R)R`@("`M+2`@02!B<F]W<V5R(&-H86YG92!W87,@9&5T96-T
M960*("H@("`G9F%I;&5D)R`@("`@+2T@($QO9VEN(&9A:6QE9`H@*B`@("=L
M;V=O=70G("`@("`M+2`@3&]G;W5T(&1U92!T;R!U<V5R(')E<75E<W0*("H@
M("`G;65S<V%G92<@("`@+2T@($QO9V]U="!W:71H(&-U<W1O;2!M97-S86=E
M(&EN($%55$A?4D5!4T].7TU31U]005)!30H@*B`@("=S97-S:6]N)R`@("`M
M+2`@3&]G;W5T(&1U92!T;R!S97-S:6]N(&5X<&ER871I;VX*("H@("`G<V5S
M<VEO;FEP)R`@+2T@($QO9V]U="!D=64@=&\@8VAA;F=E(&]F($E0(&%D9')E
M<W,@9'5R:6YG('-E<W-I;VX*("H@/"]P<F4^"B`J+PID969I;F4H)T%55$A?
M4D5!4T].7T)!1$Q/1TE.)RP@)V)A9&QO9VEN)RD["@HO*BH*("H@5&AE("=B
M<F]W<V5R)R!R96%S;VXN"B`J+PID969I;F4H)T%55$A?4D5!4T].7T)23U=3
M15(G+"`G8G)O=W-E<B<I.PH*+RHJ"B`J(%1H92`G9F%I;&5D)R!R96%S;VXN
M"B`J+PID969I;F4H)T%55$A?4D5!4T].7T9!24Q%1"<L("=F86EL960G*3L*
M"B\J*@H@*B!4:&4@)V5X<&ER960G(')E87-O;BX*("HO"F1E9FEN92@G0554
M2%]214%33TY?15A025)%1"<L("=E>'!I<F5D)RD["@HO*BH*("H@5&AE("=L
M;V=O=70G(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?3$]'3U54
M)RP@)VQO9V]U="<I.PH*+RHJ"B`J(%1H92`G;65S<V%G92<@<F5A<V]N+@H@
M*B\*9&5F:6YE*"=!551(7U)%05-/3E]-15-304=%)RP@)VUE<W-A9V4G*3L*
M"B\J*@H@*B!4:&4@)W-E<W-I;VXG(')E87-O;BX*("HO"F1E9FEN92@G0554
M2%]214%33TY?4T534TE/3B<L("=S97-S:6]N)RD["@HO*BH*("H@5&AE("=S
M97-S:6]N:7`G(')E87-O;BX*("HO"F1E9FEN92@G05542%]214%33TY?4T53
M4TE/3DE0)RP@)W-E<W-I;VYI<"<I.PH*+RHJ"B`J(%1H92!!=71H.CH@8VQA
M<W,@<')O=FED97,@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@:6YT
M;R!T:&4@=F%R:6]U<PH@*B!B86-K96YD<R!F;W(@=&AE($AO<F1E(&%U=&AE
M;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T
M:"]!=71H+G!H<"QV(#$N,30R+C$P+C(S(#(P,#8O,#@O,30@,#(Z-#@Z-#@@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@
M*B\*8VQA<W,@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C
M87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H
M:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I
M="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A
M=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=R;W5P
M<R<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@
M("H@2&%S:"!C;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@5&AE(&-R961E;G1I86QS(&-U<G)E;G1L>2!B
M96EN9R!A=71H96YT:6-A=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]A=71H0W)E9&5N=&EA;',@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@;F%M92!O9B!T:&4@8V]N8W)E=&4@075T:"!I;7!L
M96UE;G1A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M($%U=&@@:6UP;&5M96YT871I;VX@;F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1')I=F5R*"D*("`@('L*("`@("`@("!R971U<FX@<W1R7W)E<&QA
M8V4H)V%U=&A?)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9',@;W5T(&EF(&$@<V5T(&]F
M(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"P@86YD(&EF(')E<75E<W1E
M9"P*("`@("`J(&UA<FL@=&AE('5S97(@87,@;&]G9V5D(&EN(&EN('1H92!C
M=7)R96YT('-E<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A
M;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!C:&5C
M:RX*("`@("`J($!P87)A;2!B;V]L96%N("1L;V=I;B`@("`@(%=H971H97(@
M=&\@;&]G('1H92!U<V5R(&EN+B!)9B!F86QS92P@=V4G;&P*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]N;'D@=&5S="!T:&4@8W)E9&5N
M=&EA;',@86YD('=O;B=T(&UO9&EF>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&-U<G)E;G0@<V5S<VEO;BX@1&5F875L=',@=&\@
M=')U92X*("`@("`J($!P87)A;2!S=')I;F<@)')E86QM("`@("`@(%1H92!A
M=71H96YT:6-A=&EO;B!R96%L;2!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L
M<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AE;G1I8V%T
M92@D=7-E<DED+"`D8W)E9&5N=&EA;',L("1L;V=I;B`]('1R=64L("1R96%L
M;2`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@
M("`D875T:"`](&9A;'-E.PH@("`@("`@("1U<V5R260@/2!T<FEM*"1U<V5R
M260I.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=P<F5A
M=71H96YT:6-A=&4G72DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E($A/
M4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]P<F5A=71H96YT:6-A
M=&4G*2D@>PH@("`@("`@("`@("`@("`@:68@*"%C86QL7W5S97)?9G5N8R@G
M7VAO<F1E7VAO;VM?<')E875T:&5N=&EC871E)RP@)'5S97))9"P@)&-R961E
M;G1I86QS+"`D<F5A;&TI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?9V5T075T:$5R<F]R*"D@(3T@05542%]214%33TY?34534T%'12D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O
M<BA!551(7U)%05-/3E]&04E,140I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-T
M;W)E('1H92!C<F5D96YT:6%L<R!B96EN9R!C:&5C:V5D('-O('1H870@<W5B
M8VQA<W-E<R!C86X@;6]D:69Y"B`@("`@("`@("H@=&AE;2!I9B!N96-E<W-A
M<GD@*&QI:V4@=')A;G-P87)E;G0@875T:"!D;V5S*2X@*B\*("`@("`@("`D
M=&AI<RT^7V%U=&A#<F5D96YT:6%L<R`](&%R<F%Y*`H@("`@("`@("`@("`G
M=7-E<DED)R`]/B`D=7-E<DED+`H@("`@("`@("`@("`G8W)E9&5N=&EA;',G
M(#T^("1C<F5D96YT:6%L<RP*("`@("`@("`@("`@)W)E86QM)R`]/B`D<F5A
M;&TL"B`@("`@("`@("`@("=C:&%N9V5297%U97-T960G(#T^(&9A;'-E"B`@
M("`@("`@*3L*"B`@("`@("`@:68@*"1A=71H96YT:6-A=&5D(#T@)'1H:7,M
M/E]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*2D@>PH@("`@
M("`@("`@("!I9B`H:7-?82@D875T:&5N=&EC871E9"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W!O
M<W1A=71H96YT:6-A=&4G72DI('L*("`@("`@("`@("`@("`@(&EN8VQU9&5?
M;VYC92!(3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@
M("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)U]H;W)D95]H;V]K7W!O
M<W1A=71H96YT:6-A=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A
M8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7W!O<W1A=71H96YT:6-A=&4G
M+"`D=7-E<DED+"`D8W)E9&5N=&EA;',L("1R96%L;2DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?9V5T075T:$5R<F]R*"D@(3T@
M05542%]214%33TY?34534T%'12D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?1D%)3$5$
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I
M9B`H)&QO9VEN*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T075T:"@D
M=&AI<RT^7V%U=&A#<F5D96YT:6%L<ULG=7-E<DED)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%U=&A#<F5D96YT:6%L<ULG
M8W)E9&5N=&EA;',G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?875T:$-R961E;G1I86QS6R=R96%L;2==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A=71H0W)E9&5N=&EA;'-;
M)V-H86YG95)E<75E<W1E9"==*3L*("`@("`@("`@("`@("`@("1A=71H(#T@
M=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF
M("@A)'1H:7,M/E]C:&5C:U-E<W-I;VY)4"@I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?4T534TE/
M3DE0*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES+3Y?8VAE8VM"<F]W<V5R4W1R
M:6YG*"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]"4D]74T52*3L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D875T:"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D875T:#L*("`@('T*"B`@("`O*BH*("`@("`J($9O
M<FUA=',@82!P87-S=V]R9"!U<VEN9R!T:&4@8W5R<F5N="!E;F-R>7!T:6]N
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@
M(%1H92!P;&%I;G1E>'0@<&%S<W=O<F0@=&\@96YC<GEP="X*("`@("`J($!P
M87)A;2!S=')I;F<@)'-A;'0@("`@("`@("`@(%1H92!S86QT('1O('5S92!T
M;R!E;F-R>7!T('1H92!P87-S=V]R9"X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($EF(&YO="!P<F5S96YT+"!A(&YE=R!S86QT('=I
M;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&=E
M;F5R871E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&5N8W)Y<'1I;VX@("`@
M(%1H92!K:6YD(&]F('!A<W=O<F0@96YC<GEP=&EO;B!T;R!U<V4N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!M
M9#4M:&5X+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-H;W=?96YC<GEP="`@
M4V]M92!P87-S=V]R9"!S>7-T96US('!R97!E;F0@=&AE(&MI;F0@;V8*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5N8W)Y<'1I;VX@
M=&\@=&AE(&-R>7!T960@<&%S<W=O<F0@*'M32$%]+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@971C*2X@1&5F875L=',@=&\@9F%L
M<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T
M960@<&%S<W=O<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-R>7!T9610
M87-S=V]R9"@D<&QA:6YT97AT+"`D<V%L="`]("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1E;F-R>7!T:6]N(#T@)VUD-2UH97@G+"`D
M<VAO=U]E;F-R>7!T(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@1V5T('1H
M92!S86QT('1O('5S92X@*B\*("`@("`@("`D<V%L="`]($%U=&@Z.F=E=%-A
M;'0H)&5N8W)Y<'1I;VXL("1S86QT+"`D<&QA:6YT97AT*3L*"B`@("`@("`@
M+RH@16YC<GEP="!T:&4@<&%S<W=O<F0N("HO"B`@("`@("`@<W=I=&-H("@D
M96YC<GEP=&EO;BD@>PH@("`@("`@(&-A<V4@)W!L86EN)SH*("`@("`@("`@
M("`@<F5T=7)N("1P;&%I;G1E>'0["@H@("`@("`@(&-A<V4@)VUS860G.@H@
M("`@("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@G(B<@
M+B`D<&QA:6YT97AT("X@)R(G+"`G25-/+3@X-3DM,2<L("=55$8M,39,12<I
M.PH*("`@("`@("!C87-E("=S:&$G.@H@("`@("`@("`@("`D96YC<GEP=&5D
M(#T@8F%S938T7V5N8V]D92AM:&%S:"A-2$%32%]32$$Q+"`D<&QA:6YT97AT
M*2D["B`@("`@("`@("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>U-(
M07TG("X@)&5N8W)Y<'1E9"`Z("1E;F-R>7!T960["@H@("`@("`@(&-A<V4@
M)V-R>7!T)SH*("`@("`@("!C87-E("=C<GEP="UD97,G.@H@("`@("`@(&-A
M<V4@)V-R>7!T+6UD-2<Z"B`@("`@("`@8V%S92`G8W)Y<'0M8FQO=V9I<V@G
M.@H@("`@("`@("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0@/R`G>V-R>7!T
M?2<@.B`G)RD@+B!C<GEP="@D<&QA:6YT97AT+"`D<V%L="D["@H@("`@("`@
M(&-A<V4@)VUD-2UB87-E-C0G.@H@("`@("`@("`@("`D96YC<GEP=&5D(#T@
M8F%S938T7V5N8V]D92AM:&%S:"A-2$%32%]-1#4L("1P;&%I;G1E>'0I*3L*
M("`@("`@("`@("`@<F5T=7)N("@D<VAO=U]E;F-R>7!T*2`_("=[340U?2<@
M+B`D96YC<GEP=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G<W-H
M82<Z"B`@("`@("`@("`@("1E;F-R>7!T960@/2!B87-E-C1?96YC;V1E*&UH
M87-H*$U(05-(7U-(03$L("1P;&%I;G1E>'0@+B`D<V%L="D@+B`D<V%L="D[
M"B`@("`@("`@("`@(')E='5R;B`H)'-H;W=?96YC<GEP="D@/R`G>U-32$%]
M)R`N("1E;F-R>7!T960@.B`D96YC<GEP=&5D.PH*("`@("`@("!C87-E("=S
M;60U)SH*("`@("`@("`@("`@)&5N8W)Y<'1E9"`](&)A<V4V-%]E;F-O9&4H
M;6AA<V@H34A!4TA?340U+"`D<&QA:6YT97AT("X@)'-A;'0I("X@)'-A;'0I
M.PH@("`@("`@("`@("!R971U<FX@*"1S:&]W7V5N8W)Y<'0I(#\@)WM3340U
M?2<@+B`D96YC<GEP=&5D(#H@)&5N8W)Y<'1E9#L*"B`@("`@("`@8V%S92`G
M87!R;60U)SH*("`@("`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D<&QA:6YT
M97AT*3L*("`@("`@("`@("`@)&-O;G1E>'0@/2`D<&QA:6YT97AT("X@)R1A
M<'(Q)"<@+B`D<V%L=#L*("`@("`@("`@("`@)&)I;F%R>2`]($%U=&@Z.E]B
M:6XH;60U*"1P;&%I;G1E>'0@+B`D<V%L="`N("1P;&%I;G1E>'0I*3L*"B`@
M("`@("`@("`@(&9O<B`H)&D@/2`D;&5N9W1H.R`D:2`^(#`[("1I("T](#$V
M*2!["B`@("`@("`@("`@("`@("`D8V]N=&5X="`N/2!S=6)S='(H)&)I;F%R
M>2P@,"P@*"1I(#X@,38@/R`Q-B`Z("1I*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@9F]R("@D:2`]("1L96YG=&@[("1I(#X@,#L@)&D@/CX](#$I
M('L*("`@("`@("`@("`@("`@("1C;VYT97AT("X]("@D:2`F(#$I(#\@8VAR
M*#`I(#H@)'!L86EN=&5X='LP?3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1C;VYT97AT*2D["@H@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#`P.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`D;F5W(#T@*"1I("8@,2D@/R`D<&QA:6YT97AT(#H@<W5B
M<W1R*"1B:6YA<GDL(#`L,38I.PH@("`@("`@("`@("`@("`@:68@*"1I("4@
M,RD@>PH@("`@("`@("`@("`@("`@("`@("1N97<@+CT@)'-A;'0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)&D@)2`W*2!["B`@
M("`@("`@("`@("`@("`@("`@)&YE=R`N/2`D<&QA:6YT97AT.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&YE=R`N/2`H)&D@)B`Q*2`_
M('-U8G-T<B@D8FEN87)Y+"`P+"`Q-BD@.B`D<&QA:6YT97AT.PH@("`@("`@
M("`@("`@("`@)&)I;F%R>2`]($%U=&@Z.E]B:6XH;60U*"1N97<I*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'`@/2!A<G)A>2@I.PH@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`U.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`D:R`]("1I("L@-CL*("`@("`@("`@("`@("`@("1J(#T@)&D@*R`Q
M,CL*("`@("`@("`@("`@("`@(&EF("@D:B`]/2`Q-BD@>PH@("`@("`@("`@
M("`@("`@("`@("1J(#T@-3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1P6UT@/2!!=71H.CI?=&]!4%)-1#4H*&]R9"@D8FEN87)Y6R1I
M72D@/#P@,38I('P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*&]R9"@D8FEN87)Y6R1K72D@/#P@."D@?`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`H;W)D*"1B:6YA<GE;)&I=*2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#4I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@)R1A<'(Q)"<@+B`D
M<V%L="`N("<D)R`N(&EM<&QO9&4H)R<L("1P*2`N($%U=&@Z.E]T;T%04DU$
M-2AO<F0H)&)I;F%R>5LQ,5TI+"`S*3L*"B`@("`@("`@8V%S92`G;60U+6AE
M>"<Z"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("@D<VAO
M=U]E;F-R>7!T*2`_("=[340U?2<@+B!M9#4H)'!L86EN=&5X="D@.B!M9#4H
M)'!L86EN=&5X="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-A;'0@9F]R('1H92!A<'!R;W!R:6%T92!K:6YD(&]F('!A
M<W-W;W)D(&5N8W)Y<'1I;VXN"B`@("`@*B!/<'1I;VYA;&QY('1A:V5S(&$@
M<V5E9"!A;F0@82!P;&%I;G1E>'0@<&%S<W=O<F0L('1O(&5X=')A8W0@=&AE
M('-E960*("`@("`J(&]F(&%N(&5X:7-T:6YG('!A<W-W;W)D+"!O<B!F;W(@
M96YC<GEP=&EO;B!T>7!E<R!T:&%T('5S92!T:&4@<&QA:6YT97AT"B`@("`@
M*B!I;B!T:&4@9V5N97)A=&EO;B!O9B!T:&4@<V%L="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1E;F-R>7!T:6]N("!4:&4@:VEN9"!O9B!P87-W
M;W)D(&5N8W)Y<'1I;VX@=&\@=7-E+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@1&5F875L=',@=&\@;60U+6AE>"X*("`@("`J($!P87)A
M;2!S=')I;F<@)'-E960@("`@("`@(%1H92!S965D('1O(&=E="!T:&4@<V%L
M="!F<F]M("AP<F]B86)L>2!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!P<F5V:6]U<VQY(&=E;F5R871E9"!P87-S=V]R9"DN($1E9F%U
M;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G96YE
M<F%T:6YG(&$@;F5W('-E960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I
M;G1E>'0@("!4:&4@<&QA:6YT97AT('!A<W-W;W)D('1H870@=V4G<F4@9V5N
M97)A=&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@82!S
M86QT(&9O<BX@1&5F875L=',@=&\@;F]N92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&=E;F5R871E9"!O<B!E>'1R86-T960@<V%L="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V%L="@D96YC<GEP=&EO;B`]("=M
M9#4M:&5X)RP@)'-E960@/2`G)RP@)'!L86EN=&5X="`]("<G*0H@("`@>PH@
M("`@("`@("\O($5N8W)Y<'0@=&AE('!A<W-W;W)D+@H@("`@("`@('-W:71C
M:"`H)&5N8W)Y<'1I;VXI('L*("`@("`@("!C87-E("=C<GEP="<Z"B`@("`@
M("`@8V%S92`G8W)Y<'0M9&5S)SH*("`@("`@("`@("`@:68@*"1S965D*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*'!R96=?<F5P;&%C92@G
M?%Y[8W)Y<'1]?&DG+"`G)RP@)'-E960I+"`P+"`R*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!S=6)S='(H;60U*&UT
M7W)A;F0H*2DL(#`L(#(I.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@
M)V-R>7!T+6UD-2<Z"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)WQ>>V-R>7!T
M?7QI)RP@)R<L("1S965D*2P@,"P@,3(I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("<D,20G("X@<W5B<W1R*&UD-2AM
M=%]R86YD*"DI+"`P+"`X*2`N("<D)SL*("`@("`@("`@("`@?0H*("`@("`@
M("!C87-E("=C<GEP="UB;&]W9FES:"<Z"B`@("`@("`@("`@(&EF("@D<V5E
M9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E<&QA
M8V4H)WQ>>V-R>7!T?7QI)RP@)R<L("1S965D*2P@,"P@,38I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("<D,B0G("X@
M<W5B<W1R*&UD-2AM=%]R86YD*"DI+"`P+"`Q,BD@+B`G)"<["B`@("`@("`@
M("`@('T*"B`@("`@("`@8V%S92`G<W-H82<Z"B`@("`@("`@("`@(&EF("@D
M<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<BAP<F5G7W)E
M<&QA8V4H)WQ>>U-32$%]?"<L("<G+"`D<V5E9"DL("TR,"D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@;6AA<VA?:V5Y
M9V5N7W,R:RA-2$%32%]32$$Q+"`D<&QA:6YT97AT+"!S=6)S='(H<&%C:R@G
M:"HG+"!M9#4H;71?<F%N9"@I*2DL(#`L(#@I+"`T*3L*("`@("`@("`@("`@
M?0H*("`@("`@("!C87-E("=S;60U)SH*("`@("`@("`@("`@:68@*"1S965D
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@<W5B<W1R*'!R96=?<F5P;&%C
M92@G?%Y[4TU$-7U\)RP@)R<L("1S965D*2P@+3$V*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!M:&%S:%]K97EG96Y?
M<S)K*$U(05-(7TU$-2P@)'!L86EN=&5X="P@<W5B<W1R*'!A8VLH)V@J)RP@
M;60U*&UT7W)A;F0H*2DI+"`P+"`X*2P@-"D["B`@("`@("`@("`@('T*"B`@
M("`@("`@8V%S92`G87!R;60U)SH*("`@("`@("`@("`@+RH@-C0@8VAA<F%C
M=&5R<R!T:&%T(&%R92!V86QI9"!F;W(@05!2340U('!A<W-W;W)D<RX@*B\*
M("`@("`@("`@("`@)$%04DU$-2`]("<N+S`Q,C,T-38W.#E!0D-$149'2$E*
M2TQ-3D]045)35%565UA96F%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ)SL*
M"B`@("`@("`@("`@(&EF("@D<V5E9"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N('-U8G-T<BAP<F5G7W)E<&QA8V4H)R]>7"1A<'(Q7"0H+GLX?2DN*B\G
M+"`G7%PQ)RP@)'-E960I+"`P+"`X*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S86QT(#T@)R<["B`@("`@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@
M("`@)'-A;'0@+CT@)$%04DU$-7MR86YD*#`L(#8S*7T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@)'-A;'0["B`@("`@("`@
M("`@('T*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A
M(')A;F1O;2P@:&]P969U;&QY('!R;VYO=6YC96%B;&4L('!A<W-W;W)D+B!4
M:&ES(&-A;B!B92!U<V5D"B`@("`@*B!W:&5N(')E<V5T=&EN9R!A=71O;6%T
M:6-A;&QY(&$@=7-E<B=S('!A<W-W;W)D+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG($$@<F%N9&]M('!A<W-W;W)D"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E;E)A;F1O;5!A<W-W;W)D*"D*("`@('L*("`@("`@("`D=F]W96QS
M("`@(#T@)V%E:6]U>2<["B`@("`@("`@)&-O;G-T86YT<R`]("=B8V1F9VAJ
M:VQM;G!Q<G-T=G=X>B<["B`@("`@("`@)&YU;6)E<G,@("`]("<P,3(S-#4V
M-S@Y)SL*"B`@("`@("`@+RH@06QT97)N871E(&-O;G-T86YT(&%N9"!V;W=E
M;"!R86YD;VT@8VAA<G,@=VET:"!T=V\@<F%N9&]M(&YU;6)E<G,*("`@("`@
M("`@*B!A="!T:&4@96YD+B!4:&ES('-H;W5L9"!P<F]D=6-E(&$@9F%I<FQY
M('!R;VYO=6YC96%B;&4@<&%S<W=O<F0N("HO"B`@("`@("`@)&-H87)S6S!=
M(#T@<W5B<W1R*"1C;VYS=&%N=',L(&UT7W)A;F0H,"P@<W1R;&5N*"1C;VYS
M=&%N=',I("T@,2DL(#$I.PH@("`@("`@("1C:&%R<ULQ72`]('-U8G-T<B@D
M=F]W96QS+"!M=%]R86YD*#`L('-T<FQE;B@D=F]W96QS*2`M(#$I+"`Q*3L*
M("`@("`@("`D8VAA<G-;,ET@/2!S=6)S='(H)&-O;G-T86YT<RP@;71?<F%N
M9"@P+"!S=')L96XH)&-O;G-T86YT<RD@+2`Q*2P@,2D["B`@("`@("`@)&-H
M87)S6S-=(#T@<W5B<W1R*"1V;W=E;',L(&UT7W)A;F0H,"P@<W1R;&5N*"1V
M;W=E;',I("T@,2DL(#$I.PH@("`@("`@("1C:&%R<ULT72`]('-U8G-T<B@D
M8V]N<W1A;G1S+"!M=%]R86YD*#`L('-T<FQE;B@D8V]N<W1A;G1S*2`M(#$I
M+"`Q*3L*("`@("`@("`D8VAA<G-;-5T@/2!S=6)S='(H)&YU;6)E<G,L(&UT
M7W)A;F0H,"P@<W1R;&5N*"1N=6UB97)S*2`M(#$I+"`Q*3L*("`@("`@("`D
M8VAA<G-;-ET@/2!S=6)S='(H)&YU;6)E<G,L(&UT7W)A;F0H,"P@<W1R;&5N
M*"1N=6UB97)S*2`M(#$I+"`Q*3L*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H
M)R<L("1C:&%R<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<V5T
M(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))
M9"`@("`@(%1H92!U<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%5P9&%T97,@82!S970@;V8@875T:&5N
M=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@(%1H
M92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@
M("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D
M96YT:6%L<R`@(%1H92!N97<@8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A
M=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W5N<W5P<&]R=&5D)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5T(&]F(&%U=&AE
M;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S
M97))9"!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED
M*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=U;G-U
M<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@0V%L;',@86QL(&%P
M<&QI8V%T:6]N<R<@<F5M;W9E57-E<B!!4$D@;65T:&]D<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L
M971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;6]V955S97)$871A*"1U<V5R260I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@9F]R96%C:"`H
M)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G;F]T;V]L8F%R)RP@)VAI9&1E
M;B<L("=A8W1I=F4G+"`G861M:6XG*2D@87,@)&%P<"D@>PH@("`@("`@("`@
M("!I9B`H)')E9VES=')Y+3YH87--971H;V0H)W)E;6]V955S97)$871A)RP@
M)&%P<"DI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D
M<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)&%P<"P@)W)E;6]V955S97)$871A
M)RP@87)R87DH)'5S97))9"DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W1S(&%L;"!U<V5R<R!I;B!T
M:&4@<WES=&5M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)W5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&5C:W,@:68@)'5S97))9"!E>&ES=',@:6X@=&AE('-Y<W1E;2X*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R260@57-E<B!)1"!F;W(@=VAI8V@@=&\@8VAE8VL*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T("1U
M<V5R260@86QR96%D>2!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X
M:7-T<R@D=7-E<DED*0H@("`@>PH@("`@("`@(')E='5R;B!I;E]A<G)A>2@D
M=7-E<DED+"`D=&AI<RT^;&ES=%5S97)S*"DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!&:6YD<R!O=70@:68@
M=&AE(&-L:65N="!M871C:&5S(&%N(&%L;&]W960@25`*("`@("`J(&)L;V-K
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO
M=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&EF('1H97)E(&ES(&$@<V5S<VEO;B!W:71H('9A;&ED(&%U=&@@
M:6YF;W)M871I;VXN(&9O<B!T:&4*("`@("`J('-P96-I9FEE9"!U<V5R+B!)
M9B!T:&5R92!I<VXG="P@8G5T('1H92!C;VYF:6=U<F5D($%U=&@@9')I=F5R
M('-U<'!O<G1S"B`@("`@*B!T<F%N<W!A<F5N="!A=71H96YT:6-A=&EO;BP@
M=&AE;B!W92!T<GD@=&AA="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1R96%L;2`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM('1O(&-H96-K+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@
M=&AE('5S97(@:7,@875T:&5N=&EC871E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-!=71H96YT:6-A=&5D*"1R96%L;2`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1?4T534TE/3ELG7U]A=71H)UTI*2!["B`@("`@("`@
M("`@(&EF("@A96UP='DH)%]315-324].6R=?7V%U=&@G75LG875T:&5N=&EC
M871E9"==*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y*"1?4T534TE/3ELG
M7U]A=71H)UU;)W5S97))9"==*2`F)@H@("`@("`@("`@("`@("`@*"1?4T53
M4TE/3ELG7U]A=71H)UU;)W)E86QM)UT@/3T@)')E86QM*2D@>PH@("`@("`@
M("`@("`@("`@:68@*"%!=71H.CI?8VAE8VM397-S:6]N25`H*2D@>PH@("`@
M("`@("`@("`@("`@("`@($%U=&@Z.E]S971!=71H17)R;W(H05542%]214%3
M3TY?4T534TE/3DE0*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(4%U=&@Z.E]C:&5C:T)R
M;W=S97)3=')I;F<H*2D@>PH@("`@("`@("`@("`@("`@("`@($%U=&@Z.E]S
M971!=71H17)R;W(H05542%]214%33TY?0E)/5U-%4BD["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M5')Y('1R86YS<&%R96YT(&%U=&AE;G1I8V%T:6]N(&YO=RX*("`@("`@("`D
M875T:"`]("9!=71H.CIS:6YG;&5T;VXH)$=,3T)!3%-;)V-O;F8G75LG875T
M:"==6R=D<FEV97(G72D["B`@("`@("`@:68@*"1A=71H+3YH87-#87!A8FEL
M:71Y*"=T<F%N<W!A<F5N="<I("8F"B`@("`@("`@("`@("1A=71H+3YT<F%N
M<W!A<F5N="@I*2!["B`@("`@("`@("`@(')E='5R;B!!=71H.CII<T%U=&AE
M;G1I8V%T960H)')E86QM*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E
M;G1L>2!L;V=G960@:6X@=7-E<BP@:68@=&AE<F4@:7,@;VYE+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R260@;V8@=&AE(&-U<G)E
M;G0@=7-E<BP@;W(@9F%L<V4@:68@;F\@=7-E<B!I<PH@("`@("H@("`@("`@
M("`@("`@("`@;&]G9V5D(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!
M=71H*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].6R=?7V%U
M=&@G72DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)U]?
M875T:"==6R=A=71H96YT:6-A=&5D)UTI("8F"B`@("`@("`@("`@("`@("`A
M96UP='DH)%]315-324].6R=?7V%U=&@G75LG=7-E<DED)UTI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)%]315-324].6R=?7V%U=&@G75LG=7-E<DED
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!W:&5T:&5R('1H
M92!A=71H96YT:6-A=&EO;B!B86-K96YD(')E<75E<W1E9"!A('!A<W-W;W)D
M(&-H86YG92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5VAE=&AE
M<B!T:&4@8F%C:V5N9"!R97%U97-T960@82!P87-S=V]R9"!C:&%N9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES4&%S<W=O<F1#:&%N9V5297%U97-T960H
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%4U-)3TY;)U]?875T:"==
M*2`F)@H@("`@("`@("`@("`A96UP='DH)%]315-324].6R=?7V%U=&@G75LG
M875T:&5N=&EC871E9"==*2`F)@H@("`@("`@("`@("`A96UP='DH)%]315-3
M24].6R=?7V%U=&@G75LG8VAA;F=E4F5Q=65S=&5D)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8W5R96YT
M;'D@;&]G9V5D+6EN('5S97(@=VET:&]U="!A;GD@9&]M86EN(&EN9F]R;6%T
M:6]N"B`@("`@*B`H92YG+BP@8F]B0&5X86UP;&4N8V]M('=O=6QD(&)E(')E
M='5R;F5D(&%S("=B;V(G*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@=7-E<B!)1"!O9B!T:&4@8W5R<F5N="!U<V5R+"!O<B!F86QS92!I
M9B!N;R!U<V5R"B`@("`@*B`@("`@("`@("`@("`@("!I<R!L;V=G960@:6XN
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)A<F5!=71H*"D*("`@('L*("`@
M("`@("`D=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("!I9B`H)'5S
M97(I('L*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D=7-E<BP@)T`G*3L*
M("`@("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=7-E<B`]('-U8G-T<B@D=7-E<BP@,"P@)'!O<RD["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7-E<CL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1O;6%I;B!O9B!C=7)R96YT
M;'D@;&]G9V5D+6EN('5S97(@*&4N9RXL(&)O8D!E>&%M<&QE+F-O;0H@("`@
M("H@=V]U;&0@8F4@<F5T=7)N960@87,@)V5X86UP;&4N8V]M)RDN"B`@("`@
M*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,"XV"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&1O;6%I;B!S=69F:7@@;V8@=&AE(&-U<G)E;G0@
M=7-E<BP@;W(@9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%U=&A$
M;VUA:6XH*0H@("`@>PH@("`@("`@(&EF("@D=7-E<B`]($%U=&@Z.F=E=$%U
M=&@H*2D@>PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1U<V5R+"`G0"<I
M.PH@("`@("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!S=6)S='(H)'5S97(L("1P;W,@*R`Q*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<F5Q=65S=&5D(&-R961E
M;G1I86P@9F]R('1H92!C=7)R96YT;'D@;&]G9V5D(&EN('5S97(L(&EF"B`@
M("`@*B!P<F5S96YT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-R
M961E;G1I86P@(%1H92!C<F5D96YT:6%L('1O(')E=')I979E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!R97%U97-T960@8W)E9&5N=&EA
M;"P@;W(@9F%L<V4@:68@;F\@=7-E<B!I<PH@("`@("H@("`@("`@("`@("`@
M("`@;&]G9V5D(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#<F5D96YT
M:6%L*"1C<F5D96YT:6%L*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)%]3
M15-324].6R=?7V%U=&@G72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1?4T53
M4TE/3ELG7U]A=71H)UU;)V%U=&AE;G1I8V%T960G72DI('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]396-R970N<&AP)SL*("`@("`@("`@
M("`@)&-R961E;G1I86QS(#T@0'5N<V5R:6%L:7IE*%-E8W)E=#HZ<F5A9"A3
M96-R970Z.F=E=$ME>2@G875T:"<I+"`D7U-%4U-)3TY;)U]?875T:"==6R=C
M<F5D96YT:6%L<R==*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1C<F5D96YT:6%L<RD@)B8*("`@("`@("`@("`@:7-S970H)&-R961E;G1I
M86QS6R1C<F5D96YT:6%L72DI('L*("`@("`@("`@("`@<F5T=7)N("1C<F5D
M96YT:6%L<ULD8W)E9&5N=&EA;%T["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E=',@=&AE(')E<75E<W1E9"!C<F5D96YT:6%L(&9O<B!T:&4@
M8W5R<F5N=&QY(&QO9V=E9"!I;B!U<V5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&-R961E;G1I86P@(%1H92!C<F5D96YT:6%L('1O('-E="X*
M("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@("`@(%1H92!V86QU92!T
M;R!S970@=&AE(&-R961E;G1I86P@=&\N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$-R961E;G1I86PH)&-R961E;G1I86PL("1V86QU92D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1?4T534TE/3ELG7U]A=71H)UTI("8F"B`@("`@
M("`@("`@("%E;7!T>2@D7U-%4U-)3TY;)U]?875T:"==6R=A=71H96YT:6-A
M=&5D)UTI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5C
M<F5T+G!H<"<["B`@("`@("`@("`@("1C<F5D96YT:6%L<R`]($!U;G-E<FEA
M;&EZ92A396-R970Z.G)E860H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@)%]3
M15-324].6R=?7V%U=&@G75LG8W)E9&5N=&EA;',G72DI.PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&-R961E;G1I86QS*2D@>PH@("`@("`@("`@("`@
M("`@)&-R961E;G1I86QS6R1C<F5D96YT:6%L72`]("1V86QU93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<R`]
M(&%R<F%Y*"1C<F5D96YT:6%L(#T^("1V86QU92D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)%]315-324].6R=?7V%U=&@G75LG8W)E9&5N=&EA;',G
M72`](%-E8W)E=#HZ=W)I=&4H4V5C<F5T.CIG971+97DH)V%U=&@G*2P@<V5R
M:6%L:7IE*"1C<F5D96YT:6%L<RDI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E=',@82!V87)I86)L92!I;B!T:&4@<V5S<VEO;B!S87EI
M;F<@=&AA="!A=71H;W)I>F%T:6]N(&AA<R!S=6-C965D960L"B`@("`@*B!N
M;W1E('=H:6-H('5S97))9"!W87,@875T:&]R:7IE9"P@86YD(&YO=&4@=VAE
M;B!T:&4@;&]G:6X@=&]O:R!P;&%C92X*("`@("`J"B`@("`@*B!)9B!A('5S
M97(@;F%M92!H;V]K('=A<R!D969I;F5D(&EN('1H92!C;VYF:6=U<F%T:6]N
M+"!I="!G971S(&%P<&QI960*("`@("`J('1O('1H92!U<V5R260@870@=&AI
M<R!P;VEN="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M("`@("`@("`@("!4:&4@=7-E<DED('=H;R!H87,@8F5E;B!A=71H;W)I>F5D
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@("`@("`@5&AE
M(&-R961E;G1I86QS(&]F('1H92!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<F5A;&T@("`@("`@("`@("`@5&AE(&%U=&AE;G1I8V%T:6]N(')E86QM
M('1O('5S92X*("`@("`J($!P87)A;2!B;V]L96%N("1C:&%N9V5297%U97-T
M960@(%=H971H97(@=&\@<F5Q=65S="!T:&%T('1H92!U<V5R(&-H86YG90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE:7(@
M<&%S<W=O<F0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%U=&@H)'5S97))
M9"P@)&-R961E;G1I86QS+"`D<F5A;&T@/2!N=6QL+"`D8VAA;F=E4F5Q=65S
M=&5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'5S97))9"`]('1R:6TH)'5S
M97))9"D["B`@("`@("`@)'5S97))9"`]($%U=&@Z.F%D9$AO;VLH)'5S97))
M9"D["@H@("`@("`@("\J($EF('=E)W)E(&%L<F5A9'D@<V5T('=I=&@@=&AI
M<R!U<V5R260L(&1O;B=T(&-O;G1I;G5E+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D7U-%4U-)3TY;)U]?875T:"==6R=U<V5R260G72D@)B8*("`@("`@("`@
M("`@)%]315-324].6R=?7V%U=&@G75LG=7-E<DED)UT@/3T@)'5S97))9"D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!#
M;&5A<B!A;GD@97AI<W1I;F<@:6YF;RX@*B\*("`@("`@("`D=&AI<RT^8VQE
M87)!=71H*"1R96%L;2D["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M4V5C<F5T+G!H<"<["B`@("`@("`@)&-R961E;G1I86QS(#T@4V5C<F5T.CIW
M<FET92A396-R970Z.F=E=$ME>2@G875T:"<I+"!S97)I86QI>F4H)&-R961E
M;G1I86QS*2D["@H@("`@("`@(&EF("@A96UP='DH)')E86QM*2D@>PH@("`@
M("`@("`@("`D=7-E<DED("X]("=`)R`N("1R96%L;3L*("`@("`@("!]"@H@
M("`@("`@("1?4T534TE/3ELG7U]A=71H)UT@/2!A<G)A>2@*("`@("`@("`@
M("`@)V%U=&AE;G1I8V%T960G(#T^('1R=64L"B`@("`@("`@("`@("=U<V5R
M260G(#T^("1U<V5R260L"B`@("`@("`@("`@("=C<F5D96YT:6%L<R<@/3X@
M)&-R961E;G1I86QS+`H@("`@("`@("`@("`G<F5A;&TG(#T^("1R96%L;2P*
M("`@("`@("`@("`@)W1I;65S=&%M<"<@/3X@=&EM92@I+`H@("`@("`@("`@
M("`G<F5M;W1E7V%D9'(G(#T^(&ES<V5T*"1?4T525D526R=214U/5$5?041$
M4B==*2`_("1?4T525D526R=214U/5$5?041$4B==(#H@;G5L;"P*("`@("`@
M("`@("`@)V)R;W=S97(G(#T^("1'3$]"04Q36R=B<F]W<V5R)UTM/F=E=$%G
M96YT4W1R:6YG*"DL"B`@("`@("`@("`@("=C:&%N9V5297%U97-T960G(#T^
M("1C:&%N9V5297%U97-T960*("`@("`@("`I.PH*("`@("`@("`O*B!296QO
M860@<')E9F5R96YC97,@9F]R('1H92!N97<@=7-E<BX@*B\*("`@("`@("`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^;&]A9%!R969S*"D["B`@("`@("`@3DQ3
M.CIS971,86YG*"1'3$]"04Q36R=P<F5F<R==+3YG971686QU92@G;&%N9W5A
M9V4G*2D["@H@("`@("`@("\J($9E=&-H('1H92!U<V5R)W,@;&%S="!L;V=I
M;B!T:6UE+B`J+PH@("`@("`@("1O;&1?;&]G:6X@/2!`=6YS97)I86QI>F4H
M)$=,3T)!3%-;)W!R969S)UTM/F=E=%9A;'5E*"=L87-T7VQO9VEN)RDI.PH*
M("`@("`@("`O*B!$:7-P;&%Y(&ET+"!I9B!W92!H879E(&$@;F]T:69I8V%T
M:6]N(&]B:F5C="!A;F0@=&AE"B`@("`@("`@("H@<VAO=U]L87-T7VQO9VEN
M('!R969E<F5N8V4@:7,@86-T:79E+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTI("8F("1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G<VAO=U]L87-T7VQO9VEN)RDI('L*("`@("`@("`@("`@
M:68@*&5M<'1Y*"1O;&1?;&]G:6Y;)W1I;64G72DI('L*("`@("`@("`@("`@
M("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"A?*"),87-T(&QO
M9VEN.B!.979E<B(I+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1O;&1?;&]G:6Y;
M)VAO<W0G72DI('L*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T
M:69I8V%T:6]N)UTM/G!U<V@H<W!R:6YT9BA?*"),87-T(&QO9VEN.B`E<R(I
M+"!S=')F=&EM92@G)6,G+"`D;VQD7VQO9VEN6R=T:6UE)UTI*2P@)VAO<F1E
M+FUE<W-A9V4G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*'-P
M<FEN=&8H7R@B3&%S="!L;V=I;CH@)7,@9G)O;2`E<R(I+"!S=')F=&EM92@G
M)6,G+"`D;VQD7VQO9VEN6R=T:6UE)UTI+"`D;VQD7VQO9VEN6R=H;W-T)UTI
M+"`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!3970@=&AE('5S97(G<R!L
M87-T7VQO9VEN(&EN9F]R;6%T:6]N+@H@("`@("`@("1H;W-T(#T@96UP='DH
M)%]315)615);)TA45%!?6%]&3U)705)$141?1D]2)UTI"B`@("`@("`@("`@
M(#\@)%]315)615);)U)%34]415]!1$12)UT*("`@("`@("`@("`@.B`D7U-%
M4E9%4ELG2%144%]87T9/4E=!4D1%1%]&3U(G73L*("`@("`@("`D;&%S=%]L
M;V=I;B`](&%R<F%Y*"=T:6UE)R`]/B!T:6UE*"DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G:&]S="<@/3X@0&=E=&AO<W1B>6%D9'(H)&AO<W0I
M*3L*("`@("`@("`D1TQ/0D%,4ULG<')E9G,G72T^<V5T5F%L=64H)VQA<W1?
M;&]G:6XG+"!S97)I86QI>F4H)&QA<W1?;&]G:6XI*3L*"B`@("`@("`@:68@
M*"1C:&%N9V5297%U97-T960I('L*("`@("`@("`@("`@)$=,3T)!3%-;)VYO
M=&EF:6-A=&EO;B==+3YP=7-H*%\H(EEO=7(@<&%S<W=O<F0@:&%S(&5X<&ER
M960N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:&]R9&4N;65S<V%G92<I.PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/FAA<T-A<&%B:6QI='DH)W5P9&%T92<I*2!["B`@("`@("`@("`@("`@("`O
M*B!!(&)I="!O9B!A(&ML=61G92X@(%523"!I<R!S970@9G)O;2!T:&4@;&]G
M:6X@<V-R965N+"!B=70*("`@("`@("`@("`@("`@("`J('=E(&%R96XG="!C
M;VUP;&5T96QY(&-E<G1A:6X@=V4@9V]T(&AE<F4@9G)O;2!T:&4@;&]G:6X*
M("`@("`@("`@("`@("`@("`J('-C<F5E;BX@(%-O(&%N>2!S8W)E96X@=VAI
M8V@@8V%L;',@<V5T075T:"@I('=H:6-H(&AA<R!A"B`@("`@("`@("`@("`@
M("`@*B!U<FP@=VEL;"!E;F0@=7`@9V]I;F<@=&AE<F4N("!3:&]U;&0@8F4@
M3TLN("HO"B`@("`@("`@("`@("`@("`D=7)L7W!A<F%M(#T@571I;#HZ9V5T
M1F]R;41A=&$H)W5R;"<I.PH*("`@("`@("`@("`@("`@(&EF("@D=7)L7W!A
M<F%M*2!["B`@("`@("`@("`@("`@("`@("`@)'5R;"`]($AO<F1E.CIU<FPH
M571I;#HZ<F5M;W9E4&%R86UE=&5R*"1U<FQ?<&%R86TL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-E<W-I;VY?;F%M92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T<G5E*3L*("`@("`@("`@("`@("`@("`@("`D<F5T
M=7)N7W1O(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L
M("=H;W)D92<I("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R]I;F1E>"YP:'`G.PH@("`@("`@("`@("`@("`@("`@("1R971U<FY?=&\@
M/2!5=&EL.CIA9&1087)A;65T97(H)')E='5R;E]T;RP@)W5R;"<L("1U<FPI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N7W1O(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG
M72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`G+VEN9&5X+G!H<"<I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I
M;VY5<FPH)W-E<G9I8V5S+V-H86YG97!A<W-W;W)D+G!H<"<I.PH@("`@("`@
M("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M<F5T=7)N7W1O)R`]/B`D<F5T=7)N7W1O*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@9F%L<V4I.PH*("`@("`@
M("`@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D=7)L*3L*("`@("`@
M("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@86YY(&%U=&AE;G1I8V%T:6]N('1O
M:V5N<R!I;B!T:&4@8W5R<F5N="!S97-S:6]N+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)')E86QM("!4:&4@875T:&5N=&EC871I;VX@<F5A;&T@
M=&\@8VQE87(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R075T:"@D<F5A
M;&T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)')E86QM*2`F
M)B!I<W-E="@D7U-%4U-)3TY;)U]?875T:"==6R1R96%L;5TI*2!["B`@("`@
M("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)')E86QM72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)')E86QM75LG875T
M:&5N=&EC871E9"==(#T@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1?4T534TE/3ELG7U]A=71H)UTI*2!["B`@("`@("`@("`@("1?4T534TE/
M3ELG7U]A=71H)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("`D7U-%4U-)3TY;
M)U]?875T:"==6R=A=71H96YT:6-A=&5D)UT@/2!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J(%)E;6]V92!T:&4@=7-E<B=S(&-A8VAE9"!P<F5F97)E
M;F-E<R!I9B!T:&5Y(&%R92!P<F5S96YT+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D1TQ/0D%,4ULG<F5G:7-T<GDG72DI('L*("`@("`@("`@("`@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/G5N;&]A9%!R969S*"D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@27,@=&AE(&-U<G)E;G0@=7-E<B!A;B!A9&UI
M;FES=')A=&]R/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!E<FUI
M<W-I;VX@($%L;&]W('5S97)S('=I=&@@=&AI<R!P97)M:7-S:6]N(&%D;6EN
M(&%C8V5S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@
M=&AE(&-U<G)E;G0@8V]N=&5X="X*("`@("`J($!P87)A;2!I;G1E9V5R("1P
M97)M;&5V96P@(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!T;R!C:&5C:R!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("A015)-4U]%
M1$E4+"!015)-4U]$14Q%5$4L(&5T8RDN($1E9F%U;'1S"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T;R!015)-4U]%1$E4+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@("`@5&AE('5S97(@=&\@8VAE8VLN
M($1E9F%U;'1S('1O($%U=&@Z.F=E=$%U=&@H*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H:7,@:7,@86X@861M
M:6X@=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!9&UI;B@D<&5R;6ES
M<VEO;B`](&YU;&PL("1P97)M;&5V96P@/2!N=6QL+"`D=7-E<B`](&YU;&PI
M"B`@("!["B`@("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("!I9B`H)'5S
M97(@/3T](&YU;&PI('L*("`@("`@("`@("`@)'5S97(@/2!!=71H.CIG971!
M=71H*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H0&ES7V%R<F%Y*"1C;VYF
M6R=A=71H)UU;)V%D;6EN<R==*2D@>PH@("`@("`@("`@("!I9B`H)'5S97(@
M)B8@:6Y?87)R87DH)'5S97(L("1C;VYF6R=A=71H)UU;)V%D;6EN<R==*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?;G5L;"@D<&5R;6ES<VEO;BDI
M('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)'!E<FUL979E;"DI('L*("`@
M("`@("`@("`@("`@("1P97)M;&5V96P@/2!015)-4U]%1$E4.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG<&5R;7,G72T^
M:&%S4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5S97(L("1P97)M;&5V96PI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@07!P;&EE<R!A(&AO;VL@9&5F:6YE9"!B>2!T:&4@9G5N
M8W1I;VX@7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0H*2!T;PH@("`@("H@
M=&AE(&=I=F5N('5S97(@;F%M92!I9B!T:&ES(&9U;F-T:6]N(&5X:7-T<R!A
M;F0@=7-E<B!H;V]K<R!A<F4@96YA8FQE9"X*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!S:&]U;&0@8F4@8V%L;&5D(&EF(&$@8F%C:V5N9"=S('5S97(@
M;F%M92!N965D<R!T;R!B90H@("`@("H@8V]N=F5R=&5D('1O(&$@*'5N:7%U
M92D@2&]R9&4@=7-E<B!N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97))9"`@5&AE(&]R:6=I;F%L('5S97(@;F%M92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97(@;F%M92!W:71H('1H92!H
M;V]K(&%P<&QI960@=&\@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$AO
M;VLH)'5S97))9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W5S97)N86UE)UTI*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G7W5S97)N86UE7VAO;VM?9G)O;6)A8VME;F0G*2D@>PH@("`@("`@("`@
M("`@("`@)'5S97))9"`](&-A;&Q?=7-E<E]F=6YC*"=?=7-E<FYA;65?:&]O
M:U]F<F]M8F%C:V5N9"<L("1U<V5R260I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'5S97))9#L*("`@('T*"B`@("`O*BH*
M("`@("`J($%P<&QI97,@82!H;V]K(&1E9FEN960@8GD@=&AE(&9U;F-T:6]N
M(%]U<V5R;F%M95]H;V]K7W1O8F%C:V5N9"@I('1O"B`@("`@*B!T:&4@9VEV
M96X@=7-E<B!N86UE(&EF('1H:7,@9G5N8W1I;VX@97AI<W1S(&%N9"!U<V5R
M(&AO;VMS(&%R92!E;F%B;&5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D
M('-H;W5L9"!B92!C86QL960@:68@82!(;W)D92!U<V5R(&YA;64@;F5E9',@
M=&\@8F4@8V]N=F5R=&5D"B`@("`@*B!T;R!A(&)A8VME;F0G<R!U<V5R(&YA
M;64@;W(@9&ES<&QA>65D('1O('1H92!U<V5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'5S97))9"`@5&AE($AO<F1E('5S97(@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('5S97(@;F%M92!W:71H
M('1H92!H;V]K(&%P<&QI960@=&\@:70N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V94AO;VLH)'5S97))9"D*("`@('L*("`@("`@("!G;&]B86P@)&-O
M;F8["@H@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO;VMS)UU;)W5S97)N
M86UE)UTI*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G7W5S97)N86UE7VAO;VM?=&]B86-K96YD)RDI('L*("`@
M("`@("`@("`@("`@("1U<V5R260@/2!C86QL7W5S97)?9G5N8R@G7W5S97)N
M86UE7VAO;VM?=&]B86-K96YD)RP@)'5S97))9"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7-E<DED.PH@("`@?0H*("`@
M("\J*@H@("`@("H@475E<FEE<R!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T
M;R!F:6YD(&]U="!I9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A
M<&%B:6QI='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I
M;&ET>2`@5&AE(&-A<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I
M;&ET>2!I<R!S=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A
M<&%B:6QI='DH)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<F5T=7)N("%E
M;7!T>2@D=&AI<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE(&QO9VEN
M('-C<F5E;B!F;W(@=&AE(&-U<G)E;G0@875T:&5N=&EC871I;VX*("`@("`J
M(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H
M92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,;V=I;E-C<F5E;B@D87!P(#T@
M)VAO<F1E)RP@)'5R;"`]("<G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U
M=&@G75LG9')I=F5R)UTI.PH@("`@("`@(')E='5R;B`D875T:"T^7V=E=$QO
M9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@;F%M960@<&%R86UE=&5R(&9O<B!T:&4@8W5R<F5N="!A
M=71H(&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A
M;2`@5&AE('!A<F%M971E<B!T;R!F971C:"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('!A<F%M971E<B=S('9A;'5E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T
M=7)N(&ES<V5T*"1T:&ES+3Y?<&%R86US6R1P87)A;5TI(#\@)'1H:7,M/E]P
M87)A;7-;)'!A<F%M72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N86UE(&]F('1H92!A=71H96YT:6-A=&EO;B!P<F]V:61E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@(%5S960@
M8GD@<F5C=7)S:79E(&-A;&QS('=H96X@=6YT86YG;&EN9R!C;VUP;W-I=&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@875T:"X*("`@("`J($!P
M87)A;2!A<G)A>2`@)'!A<F%M<R`@57-E9"!B>2!R96-U<G-I=F4@8V%L;',@
M=VAE;B!U;G1A;F=L:6YG(&-O;7!O<VET90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!A=71H+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;F%M92!O9B!T:&4@9')I=F5R(&-U<G)E;G1L>2!P<F]V:61I;F<*
M("`@("`J("`@("`@("`@("`@("`@("!A=71H96YT:6-A=&EO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4')O=FED97(H)&1R:79E<B`](&YU;&PL("1P
M87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@
M("`@("`@:68@*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@)&1R
M:79E<B`]("1C;VYF6R=A=71H)UU;)V1R:79E<B==.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?;G5L;"@D<&%R86US*2D@>PH@("`@("`@("`@("`D<&%R
M86US(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G875T:"<L"B`@("`@("`@
M("`@("`@("!I<U]A<G)A>2@D9')I=F5R*2`_("1D<FEV97);,5T@.B`D9')I
M=F5R*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9')I=F5R(#T]("=A<'!L
M:6-A=&EO;B<I('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1P87)A;7-;
M)V%P<"==*2`_("1P87)A;7-;)V%P<"==(#H@)V%P<&QI8V%T:6]N)SL*("`@
M("`@("!](&5L<V5I9B`H)&1R:79E<B`]/2`G8V]M<&]S:71E)RD@>PH@("`@
M("`@("`@("!I9B`H*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R
M0GE087)A;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'!A<F%M<RDI("8F"B`@
M("`@("`@("`@("`@("`A96UP='DH)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I
M;E]D<FEV97)=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N($%U=&@Z.F=E
M=%!R;W9I9&5R*"1P87)A;7-;)V1R:79E<G,G75LD;&]G:6Y?9')I=F5R75LG
M9')I=F5R)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:7-S970H)'!A<F%M<ULG9')I=F5R<R==6R1L;V=I;E]D<FEV97)=
M6R=P87)A;7,G72D@/R`D<&%R86US6R=D<FEV97)S)UU;)&QO9VEN7V1R:79E
M<EU;)W!A<F%M<R==(#H@;G5L;"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@<F5T=7)N("=C;VUP;W-I=&4G.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B`D9')I=F5R.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&QO9V]U="!R96%S;VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@3VYE(&]F('1H92!L;V=O=70@<F5A<V]N
M<R`H<V5E('1H92!!551(7TQ/1T]55%\J"B`@("`@*B`@("`@("`@("`@("`@
M("!C;VYS=&%N=',@9F]R('1H92!V86QI9"!R96%S;VYS*2X@(%)E='5R;G,@
M;G5L;"!I9B!T:&5R90H@("`@("H@("`@("`@("`@("`@("`@:7,@;F\@;&]G
M;W5T(')E87-O;B!P<F5S96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,
M;V=O=71296%S;VXH*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,
M4ULG7U]A=71H97)R;W(G75LG='EP92==*2D@>PH@("`@("`@("`@("!R971U
M<FX@)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)W1Y<&4G73L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@571I;#HZ9V5T1F]R;41A=&$H
M05542%]214%33TY?4$%204TI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE('-T871U<R!S=')I;F<@=&\@=7-E(&9O<B!L
M;V=O=70@;65S<V%G97,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!L;V=O=70@<F5A<V]N('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T3&]G;W5T4F5A<V]N4W1R:6YG*"D*("`@('L*("`@("`@("!S=VET
M8V@@*$%U=&@Z.F=E=$QO9V]U=%)E87-O;B@I*2!["B`@("`@("`@8V%S92!!
M551(7U)%05-/3E]315-324]..@H@("`@("`@("`@("`D=&5X="`]('-P<FEN
M=&8H7R@B66]U<B`E<R!S97-S:6]N(&AA<R!E>'!I<F5D+B!0;&5A<V4@;&]G
M:6X@86=A:6XN(BDL("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)VYA;64G
M*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E($%55$A?4D5!
M4T].7U-%4U-)3TY)4#H*("`@("`@("`@("`@)'1E>'0@/2!S<')I;G1F*%\H
M(EEO=7(@26YT97)N970@061D<F5S<R!H87,@8VAA;F=E9"!S:6YC92!T:&4@
M8F5G:6YN:6YG(&]F('EO=7(@)7,@<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R
M('-E8W5R:71Y+"!Y;W4@;75S="!L;V=I;B!A9V%I;BXB*2P@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E="@G;F%M92<I*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@05542%]214%33TY?0E)/5U-%4CH*("`@("`@("`@
M("`@)'1E>'0@/2!S<')I;G1F*%\H(EEO=7(@8G)O=W-E<B!A<'!E87)S('1O
M(&AA=F4@8VAA;F=E9"!S:6YC92!T:&4@8F5G:6YN:6YG(&]F('EO=7(@)7,@
M<V5S<VEO;BX@5&\@<')O=&5C="!Y;W5R('-E8W5R:71Y+"!Y;W4@;75S="!L
M;V=I;B!A9V%I;BXB*2P@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G;F%M
M92<I*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@05542%]2
M14%33TY?3$]'3U54.@H@("`@("`@("`@("`D=&5X="`](%\H(EEO=2!H879E
M(&)E96X@;&]G9V5D(&]U="XB*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@05542%]214%33TY?1D%)3$5$.@H@("`@("`@("`@("`D=&5X
M="`](%\H(DQO9VEN(&9A:6QE9"XB*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@05542%]214%33TY?0D%$3$]'24XZ"B`@("`@("`@("`@
M("1T97AT(#T@7R@B3&]G:6X@9F%I;&5D(&)E8V%U<V4@>6]U<B!U<V5R;F%M
M92!O<B!P87-S=V]R9"!W87,@96YT97)E9"!I;F-O<G)E8W1L>2XB*3L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@05542%]214%33TY?15A0
M25)%1#H*("`@("`@("`@("`@)'1E>'0@/2!?*")9;W5R(&QO9VEN(&AA<R!E
M>'!I<F5D+B(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!!
M551(7U)%05-/3E]-15-304=%.@H@("`@("`@("`@("!I9B`H:7-S970H)$=,
M3T)!3%-;)U]?875T:&5R<F]R)UU;)VUS9R==*2D@>PH@("`@("`@("`@("`@
M("`@)'1E>'0@/2`D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG;7-G)UT["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&5X="`](%5T
M:6PZ.F=E=$9O<FU$871A*$%55$A?4D5!4T].7TU31U]005)!32D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("1T97AT(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5N97)A=&5S('1H92!C;W)R96-T('!A<F%M971E<G,@=&\@
M<&%S<R!T;R!T:&4@9VEV96X@;&]G;W5T(%523"X*("`@("`J"B`@("`@*B!)
M9B!N;R!R96%S;VXO;7-G(&ES('!A<W-E9"!I;BP@=7-E('1H92!C=7)R96YT
M(&=L;V)A;"!A=71H96YT:6-A=&EO;@H@("`@("H@97)R;W(@;65S<V%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@("`@(%1H92!54DP@
M=&\@<F5D:7)E8W0@=&\N"B`@("`@*B!`<&%R86T@<W1R:6YG("1R96%S;VX@
M(%1H92!R96%S;VX@9F]R(&QO9V]U="X*("`@("`J($!P87)A;2!S=')I;F<@
M)&US9R`@("`@268@<F5A<V]N(&ES($%55$A?4D5!4T].7TU%4U-!1T4L('1H
M92!M97-S86=E('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1I
M<W!L87D@=&\@=&AE('5S97(N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@
M9F]R;6%T=&5D(%523`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,;V=O=710
M87)A;65T97)S*"1U<FPL("1R96%S;VX@/2!N=6QL+"`D;7-G(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D<F5A<V]N*2D@>PH@("`@("`@
M("`@("`D<F5A<V]N(#T@075T:#HZ9V5T3&]G;W5T4F5A<V]N*"D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)')E87-O;BD@>PH@("`@("`@("`@("`D=7)L
M(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL($%55$A?4D5!4T].7U!!4D%-
M+"`D<F5A<V]N+"!F86QS92D["B`@("`@("`@("`@(&EF("@D<F5A<V]N(#T]
M($%55$A?4D5!4T].7TU%4U-!1T4I('L*("`@("`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1M<V<I*2!["B`@("`@("`@("`@("`@("`@("`@)&US9R`]($%U
M=&@Z.F=E=$QO9V]U=%)E87-O;E-T<FEN9R@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M=7)L+"!!551(7U)%05-/3E]-4T=?4$%204TL("1M<V<L(&9A;'-E*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<FP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!54DD@;V8@=&AE(&QO
M9VEN('-C<F5E;B!F;W(@=&AI<R!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D87!P("!4:&4@87!P;&EC871I;VX@=&\@=7-E+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7)L("!4:&4@55),('1O(')E9&ER96-T('1O
M(&%F=&5R(&QO9VEN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@;&]G:6X@<V-R965N(%5222X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=$QO9VEN4V-R965N*"1A<'`@/2`G:&]R9&4G+"`D=7)L(#T@)R<I"B`@("![
M"B`@("`@("`@)&QO9VEN(#T@2&]R9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T*"=W96)R;V]T)RP@)&%P<"D@+B`G+VQO9VEN+G!H<"<L('1R
M=64I.PH@("`@("`@(&EF("@A96UP='DH)'5R;"DI('L*("`@("`@("`@("`@
M)&QO9VEN(#T@571I;#HZ861D4&%R86UE=&5R*"1L;V=I;BP@)W5R;"<L("1U
M<FPI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QO9VEN.PH@("`@?0H*
M("`@("\J*@H@("`@("H@075T:&5N=&EC871I;VX@<W1U8BX*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@1F%L<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]A=71H96YT:6-A=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&5R<F]R(&UE
M<W-A9V4@9F]R(&%N(&EN=F%L:60@875T:&5N=&EC871I;VXN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@5&AE('1Y<&4@;V8@97)R;W(@*$%55$A?4D5!4T].(&-O
M;G-T86YT*2X*("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@(%1H92!E<G)O
M<B!M97-S86=E+W)E87-O;B!F;W(@:6YV86QI9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@875T:&5N=&EC871I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S971!=71H17)R;W(H)'1Y<&4L("1M<V<@/2!N=6QL*0H@("`@>PH@
M("`@("`@("1'3$]"04Q36R=?7V%U=&AE<G)O<B==(#T@87)R87DH*3L*("`@
M("`@("`D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG='EP92==(#T@)'1Y<&4[
M"B`@("`@("`@)$=,3T)!3%-;)U]?875T:&5R<F]R)UU;)VUS9R==(#T@)&US
M9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&5R<F]R('1Y
M<&4@9F]R(&%N(&EN=F%L:60@875T:&5N=&EC871I;VX@;W(@9F%L<V4@;VX@
M97)R;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"!%<G)O<B!T>7!E(&]R(&9A;'-E(&]N(&5R
M<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971!=71H17)R;W(H*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U]A=71H97)R;W(G75LG
M='EP92==*2D@>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]?875T
M:&5R<F]R)UU;)W1Y<&4G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%P<')O
M<')I871E(&%U=&AE;G1I8V%T:6]N(&1R:79E<BP@:68@86YY+"!S96QE8W1I
M;F<@8GD@=&AE"B`@("`@*B!S<&5C:69I960@<&%R86UE=&5R+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@("`@("`@("`@5&AE('!A<F%M971E<B!N86UE+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@("`@("!4:&4@<&%R86UE=&5R
M(&QI<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97)P87)A;7,@($$@
M;&ES="!O9B!P87)A;65T97)S('1O('!A<W,@=&\@=&AE(&1R:79E<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;B!V86QU92!O<B!C86QL
M960@=7-E<B!F=6YC(&]R(&YU;&P@:68@=6YA=F%I;&%B;&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V=E=$1R:79E<D)Y4&%R86TH)&YA;64L("1P87)A;7,L
M("1D<FEV97)P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R1N86UE72D@)B8*("`@("`@("`@("`@9G5N8W1I;VY?
M97AI<W1S*"1P87)A;7-;)&YA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@
M8V%L;%]U<V5R7V9U;F-?87)R87DH)'!A<F%M<ULD;F%M95TL("1D<FEV97)P
M87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!097)F;W)M<R!C:&5C:R!O;B!S97-S:6]N('1O
M('-E92!I9B!)4"!!9&1R97-S(&AA<R!C:&%N9V5D('-I;F-E('1H90H@("`@
M("H@;&%S="!A8V-E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF($E0($%D
M9')E<W,@:7,@=&AE('-A;64@*&]R('1H92!C:&5C:R!I<PH@("`@("H@("`@
M("`@("`@("`@("`@("!D:7-A8FQE9"DL(&9A;'-E(&EF('1H92!A9&1R97-S
M(&AA<R!C:&%N9V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM397-S
M:6]N25`H*0H@("`@>PH@("`@("`@(')E='5R;B`H96UP='DH)$=,3T)!3%-;
M)V-O;F8G75LG875T:"==6R=C:&5C:VEP)UTI('Q\"B`@("`@("`@("`@("`@
M("`H:7-S970H)%]315-324].6R=?7V%U=&@G75LG<F5M;W1E7V%D9'(G72D@
M)B8@)%]315-324].6R=?7V%U=&@G75LG<F5M;W1E7V%D9'(G72`]/2`D7U-%
M4E9%4ELG4D5-3U1%7T%$1%(G72DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4&5R9F]R;7,@8VAE8VL@;VX@<V5S<VEO;B!T;R!S964@:68@8G)O=W-E<B!S
M=')I;F<@:&%S(&-H86YG960@<VEN8V4*("`@("`J('1H92!L87-T(&%C8V5S
M<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@8G)O=W-E<B!S=')I;F<@:7,@
M=&AE('-A;64L(&9A;'-E(&EF('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("!S=')I;F<@:&%S(&-H86YG960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M:&5C:T)R;W=S97)3=')I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`H96UP
M='DH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=C:&5C:V)R;W=S97(G72D@
M?'P*("`@("`@("`@("`@("`@("1?4T534TE/3ELG7U]A=71H)UU;)V)R;W=S
M97(G72`]/2`D1TQ/0D%,4ULG8G)O=W-E<B==+3YG971!9V5N=%-T<FEN9R@I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1O(&%L;&]W960@
M-C0@8VAA<F%C=&5R<R!F;W(@05!2340U('!A<W-W;W)D<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=F%L=64*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N=`H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("`D=F%L=64@8V]N=F5R=&5D('1O
M('1H92`V-"!-1#4@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W1O05!2340U*"1V86QU92P@)&-O=6YT*0H@("`@>PH@("`@("`@("\J(#8T
M(&-H87)A8W1E<G,@=&AA="!A<F4@=F%L:60@9F]R($%04DU$-2!P87-S=V]R
M9',N("HO"B`@("`@("`@)$%04DU$-2`]("<N+S`Q,C,T-38W.#E!0D-$149'
M2$E*2TQ-3D]045)35%565UA96F%B8V1E9F=H:6IK;&UN;W!Q<G-T=79W>'EZ
M)SL*"B`@("`@("`@)&%P<FUD-2`]("<G.PH@("`@("`@("1C;W5N="`](&%B
M<R@D8V]U;G0I.PH@("`@("`@('=H:6QE("@M+21C;W5N="D@>PH@("`@("`@
M("`@("`D87!R;60U("X]("1!4%)-1#5;)'9A;'5E("8@,'@S9ET["B`@("`@
M("`@("`@("1V86QU92`^/CT@-CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1A<')M9#4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!H97AA
M9&5C:6UA;"!S=')I;F<@=&\@8FEN87)Y(&1A=&$N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:&5X("!(97@@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M0FEN87)Y(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B:6XH)&AE>"D*
M("`@('L*("`@("`@("`D8FEN(#T@)R<["B`@("`@("`@)&QE;F=T:"`]('-T
M<FQE;B@D:&5X*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&5N9W1H
M.R`D:2`K/2`R*2!["B`@("`@("`@("`@("1T;7`@/2!S<V-A;F8H<W5B<W1R
M*"1H97@L("1I+"`R*2P@)R5X)RD["B`@("`@("`@("`@("1B:6X@+CT@8VAR
M*&%R<F%Y7W-H:69T*"1T;7`I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1B:6X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!C;VYC<F5T92!!=71H(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E
M(&]F(&-O;F-R971E($%U=&@@<W5B8VQA<W,@=&\@<F5T=7)N+B!4:&ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@:7,@8F%S960@;VX@=&AE('-T
M;W)A9V4@9')I=F5R("@D9')I=F5R*2X@5&AE(&-O9&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@
M)&1R:79E<B!I<R!A;B!A<G)A>2P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!T:&5N('=E('=I;&P@;&]O:R!I;B`D9')I=F5R6S!=+VQI8B]!=71H
M+R!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA
M<W,@:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!!=71H("!4:&4@
M;F5W;'D@8W)E871E9"!C;VYC<F5T92!!=71H(&EN<W1A;F-E+"!O<B!F86QS
M92!O;B!A;@H@("`@("H@("`@("`@("`@("`@("!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@
M("`@("`@("1A<'`@/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R
M(#T@)&1R:79E<ELQ73L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B
M87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*&5M<'1Y*"1D<FEV97(I
M('Q\("@D9')I=F5R(#T]("=N;VYE)RDI('L*("`@("`@("`@("`@)&%U=&@@
M/2`F;F5W($%U=&@H*3L*("`@("`@("`@("`@<F5T=7)N("1A=71H.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V%U=&@G
M+"`D9')I=F5R*3L*("`@("`@("!]"@H@("`@("`@(&EN:5]S970H)W1R86-K
M7V5R<F]R<R<L(#$I.PH@("`@("`@("1I;F-L=61E7V5R<F]R(#T@)R<["B`@
M("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!`:6YC;'5D
M95]O;F-E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@
M)&%P<"D@+B`G+VQI8B]!=71H+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E
M+T%U=&@O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<W-E="@D<&AP7V5R<F]R;7-G*2D@>PH@("`@("`@("`@("`D:6YC
M;'5D95]E<G)O<B`]("1P:'!?97)R;W)M<V<["B`@("`@("`@?0H@("`@("`@
M(&EN:5]R97-T;W)E*"=T<F%C:U]E<G)O<G,G*3L*"B`@("`@("`@)&-L87-S
M(#T@)T%U=&A?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1A=71H(#T@)FYE=R`D8VQA<W,H
M)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&%U=&@@
M/2!014%2.CIR86ES945R<F]R*"=!=71H($1R:79E<B`H)R`N("1C;&%S<R`N
M("<I(&YO="!F;W5N9"<@+B`H)&EN8VQU9&5?97)R;W(@/R`G.B`G("X@)&EN
M8VQU9&5?97)R;W(@.B`G)RD@+B`G+B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1A=71H.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@075T:"!I;G-T
M86YC92!B87-E9"!O;@H@("`@("H@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R
M96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!!=71H(&EN<W1A;F-E('=I=&@*
M("`@("`J('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*
M("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE
M(&%U=&AE;G1I8V%T:6]N('-O=7)C97,@*&%N9"P@=&AU<RP*("`@("`J(&UU
M;'1I<&QE($%U=&@@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@
M)D%U=&@Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!=71H('-U8F-L87-S
M('1O(')E='5R;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@5&AI
M<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(@*"1D<FEV97(I+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!4:&4@8V]D92!I<R!D>6YA
M;6EC86QL>2!I;F-L=61E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A
M=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T
M:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@075T:"`@5&AE(&-O;F-R971E($%U=&@@<F5F97)E
M;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("AI<U]N=6QL*"1P87)A;7,I*2!["B`@("`@("`@("`@("1P87)A;7,@
M/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=A=71H)RP*("`@("`@("`@("`@
M("`@(&ES7V%R<F%Y*"1D<FEV97(I(#\@)&1R:79E<ELQ72`Z("1D<FEV97(I
M.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA
M<G)A>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*&5M<'1Y*"1I
M;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC
M97-;)'-I9VYA='5R95T@/2`F075T:#HZ9F%C=&]R>2@D9')I=F5R+"`D<&%R
M86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O2&ES=&]R>2YP
M:'``````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C8T
M,C4@,3`U,34T,S0Q-#`@,#(Q-3(R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&ES=&]R>3HZ
M(&-L87-S('!R;W9I9&5S(&$@;65T:&]D(&]F('1R86-K:6YG(&-H86YG97,@
M:6X@2&]R9&4*("H@;V)J96-T<RP@<W1O<F5D(&EN(&$@4U%,('1A8FQE+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R](:7-T;W)Y+TAI<W1O<GDN<&AP+'8@
M,2XR."XR+C$T(#(P,#8O,#4O,#,@,C$Z-#8Z,3,@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,BXQ"B`J($!P86-K86=E($AO<F1E7TAI<W1O<GD*("HO"F-L87-S($AO<F1E
M7TAI<W1O<GD@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A($1"(&EN
M<W1A;F-E('1O(&UA;F%G92!T:&4@:&ES=&]R>2X*("`@("`J"B`@("`@*B!`
M=F%R($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@
M071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@
M2&ES=&]R>2!I;G-T86YC92X*("`@("`J($ET('=I;&P@;VYL>2!C<F5A=&4@
M82!N97<@:6YS=&%N8V4@:68@;F\@2&ES=&]R>2!I;G-T86YC90H@("`@("H@
M8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M
M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F2&ES=&]R>3HZ<VEN9VQE=&]N
M*"D*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7TAI<W1O<GD@(%1H92!C
M;VYC<F5T92!(:7-T;W)Y(')E9F5R96YC92P@;W(@9F%L<V4@;VX@86X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D
M:&ES=&]R>3L*"B`@("`@("`@:68@*"%I<W-E="@D:&ES=&]R>2DI('L*("`@
M("`@("`@("`@)&AI<W1O<GD@/2`F;F5W($AO<F1E7TAI<W1O<GDH*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:&ES=&]R>3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(
M;W)D95](:7-T;W)Y*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@(&EF("AE;7!T>2@D8V]N9ELG<W%L)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?9&(@/2!014%2.CIR86ES945R<F]R*%\H(E1H92!(:7-T;W)Y
M('-Y<W1E;2!I<R!D:7-A8FQE9"XB*2D["B`@("`@("`@?0H*("`@("`@("!R
M97%U:7)E7V]N8V4@)T1"+G!H<"<["B`@("`@("`@)'1H:7,M/E]D8B`]("9$
M0CHZ8V]N;F5C="@D8V]N9ELG<W%L)UTI.PH*("`@("`@("`O*B!3970@1$(@
M<&]R=&%B:6QI='D@;W!T:6]N<RX@*B\*("`@("`@("!I9B`H:7-?82@D=&AI
M<RT^7V1B+"`G1$)?8V]M;6]N)RDI('L*("`@("`@("`@("`@<W=I=&-H("@D
M=&AI<RT^7V1B+3YP:'!T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L
M)SH*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R
M=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)4
M04))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E465]25%))32D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG
M+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%
M4E)/4E,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@3&]G<R!A;B!E=F5N="!T;R!A;B!I=&5M)W,@:&ES=&]R>2!L
M;V<N(%1H92!I=&5M(&UU<W0@8F4@=6YI<75E;'D*("`@("`J(&ED96YT:69I
M960@8GD@)&=U:60N($%N>2!O=&AE<B!D971A:6QS(&%B;W5T('1H92!E=F5N
M="!A<F4@<&%S<V5D(&EN"B`@("`@*B`D871T<FEB=71E<RX@4W1A;F1A<F0@
M<W5G9V5S=&5D(&%T=')I8G5T97,@87)E.@H@("`@("H*("`@("`J("`@)W=H
M;R<@/3X@5&AE(&ED(&]F('1H92!U<V5R('1H870@<&5R9F]R;65D('1H92!A
M8W1I;VX@*'=I;&P@8F4@861D960*("`@("`J("`@("`@("`@("`@875T;VUA
M=&EC86QL>2!I9B!N;W0@<')E<V5N="DN"B`@("`@*@H@("`@("H@("`G=',G
M(#T^(%1I;65S=&%M<"!O9B!T:&4@86-T:6]N("AT:&ES('=I;&P@8F4@861D
M960@875T;VUA=&EC86QL>2!I9@H@("`@("H@("`@("`@("`@(&ET(&ES(&YO
M="!P<F5S96YT*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G=6ED
M("`@("`@("`@("`@5&AE('5N:7%U92!I9&5N=&EF:65R(&]F('1H92!E;G1R
M>2!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%D
M9"!T;RX*("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@("`@("!4
M:&4@:&%S:"!O9B!N86UE(#T^('9A;'5E(&5N=')I97,@=&AA=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E<V-R:6)E('1H:7,@
M979E;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5P;&%C94%C=&EO;B`@
M268@)&%T=')I8G5T97-;)V%C=&EO;B==(&ES(&%L<F5A9'D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P<F5S96YT(&EN('1H92!I
M=&5M)W,@:&ES=&]R>2!L;V<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=7!D871E('1H870@96YT<GD@:6YS=&5A9"!O9B!C<F5A
M=&EN9R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;F5W(&]N92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%
M<G)O<B`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D9W5I9"P@)&%T=')I8G5T97,@
M/2!A<G)A>2@I+"`D<F5P;&%C94%C=&EO;B`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(["B`@("`@("`@?0H*("`@("`@
M("`D:&ES=&]R>2`]("8D=&AI<RT^9V5T2&ES=&]R>2@D9W5I9"D["B`@("`@
M("`@:68@*"$D:&ES=&]R>2!\?"!I<U]A*"1H:7-T;W)Y+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:&ES=&]R>3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AE;7!T>2@D871T<FEB=71E<ULG=VAO)UTI*2!["B`@
M("`@("`@("`@("1A='1R:6)U=&5S6R=W:&\G72`]($%U=&@Z.F=E=$%U=&@H
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1A='1R:6)U=&5S6R=T
M<R==*2D@>PH@("`@("`@("`@("`D871T<FEB=71E<ULG=',G72`]('1I;64H
M*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E('=A;G0@=&\@<F5P;&%C
M92!A;B!E;G1R>2!W:71H('1H92!S86UE(&%C=&EO;BP@=')Y(&%N9"!F:6YD
M"B`@("`@("`@("H@;VYE+B!4<F%C:R!W:&5T:&5R(&]R(&YO="!W92!S=6-C
M965D(&EN("1D;VYE+"!S;R!W92!K;F]W('=H971H97(*("`@("`@("`@*B!O
M<B!N;W0@=&\@861D('1H92!E;G1R>2!L871E<BX@*B\*("`@("`@("`D9&]N
M92`](&9A;'-E.PH@("`@("`@(&EF("@D<F5P;&%C94%C=&EO;B`F)B`A96UP
M='DH)&%T=')I8G5T97-;)V%C=&EO;B==*2D@>PH@("`@("`@("`@("`D8V]U
M;G0@/2!C;W5N="@D:&ES=&]R>2T^9&%T82D["B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D:&ES=&]R>2T^9&%T85LD:5U;)V%C=&EO;B==*2`F)@H@
M("`@("`@("`@("`@("`@("`@("1H:7-T;W)Y+3YD871A6R1I75LG86-T:6]N
M)UT@/3T@)&%T=')I8G5T97-;)V%C=&EO;B==*2!["@H@("`@("`@("`@("`@
M("`@("`@("1V86QU97,@/2!A<G)A>2@D871T<FEB=71E<ULG=',G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;
M)W=H;R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M<W-E="@D871T<FEB=71E<ULG9&5S8R==*2`_("1A='1R:6)U=&5S6R=D97-C
M)UT@.B!N=6QL*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T<FEB
M=71E<ULG=',G72D["B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%T=')I
M8G5T97-;)W=H;R==*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D871T
M<FEB=71E<ULG9&5S8R==*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D
M871T<FEB=71E<ULG86-T:6]N)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D871T<FEB=71E<RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L
M=65S6UT@/2!S97)I86QI>F4H)&%T=')I8G5T97,I.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M97-;72`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1V86QU97-;72`]("1H:7-T;W)Y+3YD871A6R1I75LG:60G
M73L*"B`@("`@("`@("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1B+3YQ=65R
M>2@G55!$051%(&AO<F1E7VAI<W1O<FEE<R!3150@:&ES=&]R>5]T<R`](#\L
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!H
M:7-T;W)Y7W=H;R`](#\L)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R!H:7-T;W)Y7V1E<V,@/2`_+"<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@:&ES=&]R>5]E>'1R82`]
M(#\@5TA%4D4@:&ES=&]R>5]I9"`](#\G+"`D=F%L=65S*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'(["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1D;VYE(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@=V4G<F4@;F]T
M(')E<&QA8VEN9R!B>2!A8W1I;VXL(&]R(&EF('=E(&1I9&XG="!F:6YD(&%N
M(&5N=')Y('1O"B`@("`@("`@("H@<F5P;&%C92P@:6YS97)T(&$@;F5W(')O
M=RX@*B\*("`@("`@("!I9B`H(21D;VYE*2!["B`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>2@D=&AI<RT^7V1B+3YN97AT260H)VAO<F1E7VAI<W1O<FEE
M<R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=U:60L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB=71E<ULG=',G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R=W:&\G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1A='1R:6)U=&5S
M6R=D97-C)UTI(#\@)&%T=')I8G5T97-;)V1E<V,G72`Z(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D871T<FEB=71E<ULG86-T
M:6]N)UTI(#\@)&%T=')I8G5T97-;)V%C=&EO;B==(#H@;G5L;"D["B`@("`@
M("`@("`@('5N<V5T*"1A='1R:6)U=&5S6R=T<R==*3L*("`@("`@("`@("`@
M=6YS970H)&%T=')I8G5T97-;)W=H;R==*3L*("`@("`@("`@("`@=6YS970H
M)&%T=')I8G5T97-;)V1E<V,G72D["B`@("`@("`@("`@('5N<V5T*"1A='1R
M:6)U=&5S6R=A8W1I;VXG72D["B`@("`@("`@("`@(&EF("@D871T<FEB=71E
M<RD@>PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@<V5R:6%L:7IE*"1A
M='1R:6)U=&5S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1V86QU97-;72`](&YU;&P["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1R(#T@)'1H:7,M/E]D8BT^<75E<GDH)TE.4T525"!)3E1/(&AO<F1E
M7VAI<W1O<FEE<R`H:&ES=&]R>5]I9"P@;V)J96-T7W5I9"P@:&ES=&]R>5]T
M<RP@:&ES=&]R>5]W:&\L(&AI<W1O<GE?9&5S8RP@:&ES=&]R>5]A8W1I;VXL
M(&AI<W1O<GE?97AT<F$I)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_+"`_*2<L("1V86QU97,I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!(:7-T;W)Y3V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@
M=&AE(&YA;65D(&AI<W1O<GD*("`@("`J(&5N=')Y+"!W:71H('1H92!D871A
M(')E=')I979E9"!A<'!R;W!R:6%T96QY+B`D875T;V-R96%T92!H87,*("`@
M("`J(&YO(&%F9F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G
M=6ED("`@("`@("`@5&AE(&YA;64@;V8@=&AE(&AI<W1O<GD@96YT<GD@=&\@
M<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@
M1&5P<F5C871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$AI<W1O<GDH
M)&=U:60L("1A=71O8W)E871E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1F86QS92`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971!;&PH
M)U-%3$5#5"`J($923TT@:&]R9&5?:&ES=&]R:65S(%=(15)%(&]B:F5C=%]U
M:60@/2`_)RP@87)R87DH)&=U:60I+"!$0E]&151#2$U/1$5?05-33T,I.PH@
M("`@("`@("1H:7-T;W)Y(#T@)FYE=R!(:7-T;W)Y3V)J96-T*"1G=6ED+"`D
M<F]W<RD["B`@("`@("`@<F5T=7)N("1H:7-T;W)Y.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9',@:&ES=&]R>2!O8FIE8W1S(&)Y('1I;65S=&%M<"P@
M86YD(&]P=&EO;F%L;'D@9FEL=&5R(&]N(&]T:&5R"B`@("`@*B!F:65L9',@
M87,@=V5L;"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;7`@("`@
M(%1H92!C;VUP87)I<V]N(&]P97)A=&]R("@\+"`^+"`\/2P@/CTL(&]R(#TI
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K('1H92!T
M:6UE<W1A;7!S('=I=&@N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=',@("`@
M(%1H92!T:6UE<W1A;7`@=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1F:6QT97)S("!!;B!A<G)A>2!O9B!A9&1I=&EO;F%L("A!
M3D1E9"D@8W)I=&5R:6$N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M($5A8V@@87)R87D@=F%L=64@<VAO=6QD(&)E(&%N(&%R<F%Y('=I=&@@,PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!E;G1R:65S.@H@("`@("H@
M/'!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("=O<"<@("`@
M+2!T:&4@;W!E<F%T;W(@=&\@8V]M<&%R92!T:&ES(&9I96QD"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VET:"X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("=F:65L9"<@+2!T:&4@:&ES=&]R
M>2!F:65L9"!B96EN9R!C;VUP87)E9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("AI+F4N("=A8W1I;VXG*2X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@+2!T:&4@=F%L=64@=&\@
M8VAE8VL@9F]R("AI+F4N("=A9&0G*2X*("`@("`J(#PO<')E/@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%R96YT("!4:&4@<&%R96YT(&AI<W1O<GD@=&\@
M<W1A<G0@<V5A<F-H:6YG(&%T+B!)9B!N;VXM96UP='DL"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('=I;&P@8F4@<V5A<F-H960@9F]R('=I=&@@
M82!,24M%("<D<&%R96YT.B4G(&-L875S92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!H:7-T;W)Y(&]B:F5C="!I9',L(&]R
M(&%N(&5M<'1Y(&%R<F%Y(&EF"B`@("`@*B`@("`@("`@("`@("`@("!N;VYE
M(&UA=&-H960@=&AE(&-R:71E<FEA+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971">51I;65S=&%M<"@D8VUP+"`D=',L("1F:6QT97)S(#T@87)R87DH*2P@
M)'!A<F5N="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@=&EM97-T86UP
M('1E<W0N("HO"B`@("`@("`@)'=H97)E(#T@87)R87DH(FAI<W1O<GE?=',@
M)&-M<"`D=',B*3L*"B`@("`@("`@+RH@061D(&%D9&ET:6]N86P@9FEL=&5R
M<RP@:68@=&AE<F4@87)E(&%N>2X@*B\*("`@("`@("!I9B`H)&9I;'1E<G,I
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E<G,@87,@)&9I;'1E<BD@
M>PH@("`@("`@("`@("`@("`@)'=H97)E6UT@/2`G:&ES=&]R>5\G("X@)&9I
M;'1E<ELG9FEE;&0G72`N("<@)R`N("1F:6QT97);)V]P)UT@+B`G("<@+B`D
M=&AI<RT^7V1B+3YQ=6]T92@D9FEL=&5R6R=V86QU92==*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1P87)E;G0I('L*("`@("`@
M("`@("`@)'=H97)E6UT@/2`G;V)J96-T7W5I9"!,24M%("<@+B`D=&AI<RT^
M7V1B+3YQ=6]T92@D<&%R96YT("X@)SHE)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D8BT^9V5T07-S;V,H)U-%3$5#5"!$25-424Y#
M5"!O8FIE8W1?=6ED+"!H:7-T;W)Y7VED($923TT@:&]R9&5?:&ES=&]R:65S
M(%=(15)%("<@+B!I;7!L;V1E*"<@04Y$("<L("1W:&5R92DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T<R!T:&4@=&EM97-T86UP(&]F('1H92!M;W-T
M(')E8V5N="!C:&%N9V4@=&\@)&=U:60N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9W5I9"`@("!4:&4@;F%M92!O9B!T:&4@:&ES=&]R>2!E;G1R
M>2!T;R!R971R:65V92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO;B`@
M06X@86-T:6]N.B`G861D)RP@)VUO9&EF>2<L("=D96QE=&4G+"!E=&,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=&EM97-T86UP+"!O
M<B`P(&EF(&YO(&UA=&-H:6YG(&5N=')Y(&ES(&9O=6YD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971!8W1I;VY4:6UE<W1A;7`H)&=U:60L("1A8W1I;VXI
M"B`@("!["B`@("`@("`@+RH@5&AI<R!I;7!L96UE;G1A=&EO;B!S=&EL;"!W
M;W)K<RP@8G5T('=E('-H;W5L9"!B92!A8FQE('1O"B`@("`@("`@("H@9V5T
M(&UU8V@@9F%S=&5R(&YO=R!W:71H(&$@4T5,14-4($U!6"AH:7-T;W)Y7W1S
M*0H@("`@("`@("`J("XN+B!Q=65R>2X@*B\*("`@("`@("`D:&ES=&]R>2`]
M("8D=&AI<RT^9V5T2&ES=&]R>2@D9W5I9"D["B`@("`@("`@:68@*"$D:&ES
M=&]R>2!\?"!I<U]A*"1H:7-T;W)Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@)&QA<W0@/2`P
M.PH@("`@("`@(&EF("AI<U]A<G)A>2@D:&ES=&]R>2T^9&%T82DI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)&AI<W1O<GDM/F1A=&$@87,@)&5N=')Y*2![
M"B`@("`@("`@("`@("`@("!I9B`H)&5N=')Y6R=A8W1I;VXG72`]/2`D86-T
M:6]N("8F("1E;G1R>5LG=',G72`^("1L87-T*2!["B`@("`@("`@("`@("`@
M("`@("`@)&QA<W0@/2`D96YT<GE;)W1S)UT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&%S
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!O;F4@;W(@;6]R92!H
M:7-T;W)Y(&5N=')I97,@8GD@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&YA;65S("!4:&4@:&ES=&]R>2!E;G1R:65S('1O(')E;6]V92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0GE.86UE<R@D;F%M97,I"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D:61S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D;F%M97,@
M87,@)&YA;64I('L*("`@("`@("`@("`@)&ED<UM=(#T@)'1H:7,M/E]D8BT^
M<75O=&4H)&YA;64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&(M/G%U97)Y*"=$14Q%5$4@1E)/32!H;W)D95]H:7-T;W)I97,@5TA%
M4D4@;V)J96-T7W5I9"!)3B`H)R`N(&EM<&QO9&4H)RPG+"`D:61S*2`N("<I
M)RD["B`@("!]"@I]"@HO*BH*("H@0VQA<W,@9F]R('!R97-E;G1I;F<@2&ES
M=&]R>2!I;F9O<FUA=&EO;BX*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@
M*B!`<&%C:V%G92!(;W)D95](:7-T;W)Y"B`J+PIC;&%S<R!(:7-T;W)Y3V)J
M96-T('L*"B`@("!V87(@)'5I9#L*("`@('9A<B`D9&%T82`](&%R<F%Y*"D[
M"@H@("`@9G5N8W1I;VX@2&ES=&]R>4]B:F5C="@D=6ED+"`D9&%T82`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/G5I9"`]("1U:60["@H@("`@
M("`@(&EF("@A)&1A=&$@?'P@:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D9&%T82!A<R`D<F]W*2!["B`@("`@("`@("`@("1H:7-T;W)Y(#T@
M87)R87DH)V%C=&EO;B<@/3X@)')O=ULG:&ES=&]R>5]A8W1I;VXG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)')O=ULG:&ES
M=&]R>5]D97-C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=H
M;R<@/3X@)')O=ULG:&ES=&]R>5]W:&\G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G:60G(#T^("1R;W=;)VAI<W1O<GE?:60G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=',G(#T^("1R;W=;)VAI<W1O<GE?
M=',G72D["B`@("`@("`@("`@(&EF("@D<F]W6R=H:7-T;W)Y7V5X=')A)UTI
M('L*("`@("`@("`@("`@("`@("1E>'1R82`]($!U;G-E<FEA;&EZ92@D<F]W
M6R=H:7-T;W)Y7V5X=')A)UTI.PH@("`@("`@("`@("`@("`@:68@*"1E>'1R
M82D@>PH@("`@("`@("`@("`@("`@("`@("1H:7-T;W)Y(#T@87)R87E?;65R
M9V4H)&AI<W1O<GDL("1E>'1R82D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F1A=&%;72`]("1H:7-T;W)Y
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971$871A*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/F1A=&$["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O36%I;G1E
M;F%N8V4N<&AP````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-C,P,C8@,3`U,34T,S0Q-#`@,#(R,S`Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@1&\@=&%S:R!Y
M96%R;'D@*$9I<G-T(&QO9VEN(&%F=&5R+V]N($IA;G5A<GD@,2DN"B`J+PID
M969I;F4H)TU!24Y414Y!3D-%7UE%05),62<L(#$I.PH*+RHJ"B`J($1O('1A
M<VL@;6]N=&AL>2`H1FER<W0@;&]G:6X@869T97(O;VX@9FER<W0@;V8@;6]N
M=&@I+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#15]-3TY42$Q9)RP@,BD["@HO
M*BH*("H@1&\@=&%S:R!W965K;'D@*$9I<G-T(&QO9VEN(&%F=&5R+V]N(&$@
M4W5N9&%Y*2X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?5T5%2TQ9)RP@,RD[
M"@HO*BH*("H@1&\@=&%S:R!D86EL>2`H1FER<W0@;&]G:6X@;V8@=&AE(&1A
M>2DN"B`J+PID969I;F4H)TU!24Y414Y!3D-%7T1!24Q9)RP@-"D["@HO*BH*
M("H@1&\@=&%S:R!E=F5R>2!L;V=I;BX*("HO"F1E9FEN92@G34%)3E1%3D%.
M0T5?159%4EDG+"`U*3L*"B\J*@H@*B!$;R!T87-K(&]N(&9I<G-T(&QO9VEN
M(&]N;'DN"B`J+PID969I;F4H)TU!24Y414Y!3D-%7T9)4E-47TQ/1TE.)RP@
M-BD["@HO*BH*("H@0V]N9FER;6%T:6]N+7-T>6QE(&]U='!U="!F;W(@;6%I
M;G1E;F%N8V4@<&%G92X*("HO"F1E9FEN92@G34%)3E1%3D%.0T5?3U544%54
M7T-/3D9)4DTG+"`W*3L*"B\J*@H@*B!!9W)E96UE;G0M<W1Y;&4@;W5T<'5T
M(&9O<B!M86EN=&5N86YC92!P86=E+@H@*B\*9&5F:6YE*"=-04E.5$5.04Y#
M15]/5510551?04=2144G+"`X*3L*"B\J*@H@*B!.;W1I8V4M<W1Y;&4@;W5T
M<'5T(&9O<B!M86EN=&5N86YC92!P86=E+@H@*B\*9&5F:6YE*"=-04E.5$5.
M04Y#15]/5510551?3D]424-%)RP@.2D["@HO*BH*("H@5&AE(&YA;64@;V8@
M=&AE(%523"!P87)A;65T97(@=&AA="!I;F1I8V%T97,@=&AA="!T:&4@;6%I
M;G1E;F%N8V4@=&%S:W,@87)E"B`J(&-O;7!L971E9"X*("HO"F1E9FEN92@G
M34%)3E1%3D%.0T5?1$].15]005)!32<L("=M86EN=&5N86YC95]D;VYE)RD[
M"@HO*B!);G1E<G9A;',@:&%S:"`M('5S960@=&\@8G5I;&0@<V5L96-T('1A
M8FQE<R!I;B!P<F5F97)E;F-E<R!M96YU+B`J+PHD:6YT97)V86QS(#T@87)R
M87DH*3L*)&EN=&5R=F%L<UM-04E.5$5.04Y#15]914%23%E=("`](%\H(EEE
M87)L>2(I.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7TU/3E1(3%E=(#T@7R@B
M36]N=&AL>2(I.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7U=%14M,65T@(#T@
M7R@B5V5E:VQY(BD["B1I;G1E<G9A;'-;34%)3E1%3D%.0T5?1$%)3%E=("`@
M/2!?*")$86EL>2(I.PHD:6YT97)V86QS6TU!24Y414Y!3D-%7T5615)972`@
M(#T@7R@B179E<GD@3&]G:6XB*3L*)$=,3T)!3%-;)VEN=&5R=F%L<R==(#T@
M)B1I;G1E<G9A;',["@HO*BH*("H@5&AE($UA:6YT96YA;F-E.CH@8VQA<W,@
M<')O=FED97,@82!S970@;V8@;65T:&]D<R!F;W(@9&5A;&EN9R!W:71H"B`J
M(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@<G5N('5P;VX@;&]G:6X@=&\@2&]R
M9&4@87!P;&EC871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-86EN
M=&5N86YC92]-86EN=&5N86YC92YP:'`L=B`Q+C4R+C$P+C$S(#(P,#8O,#$O
M,#$@,C$Z,C@Z,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P
M,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,2XS+C4*("H@0'!A8VMA9V4@2&]R9&5?36%I;G1E;F%N8V4*
M("HO"F-L87-S($UA:6YT96YA;F-E('L*"B`@("`O*BH*("`@("`J($AA<V@@
M:&]L9&EN9R!M86EN=&5N86YC92!P<F5F97)E;F-E(&YA;65S+@H@("`@("H@
M4WEN=&%X.B`@4%)%1DY!344@/3X@:6YT97)V86P*("`@("`J(%9A;&ED(&EN
M=&5R=F%L<R!A<F4Z($U!24Y414Y!3D-%7UE%05),62P@34%)3E1%3D%.0T5?
M34].5$A,62P*("`@("`J("`@("`@("`@("`@("`@("`@("`@($U!24Y414Y!
M3D-%7U=%14M,62P@34%)3E1%3D%.0T5?1$%)3%DL"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!-04E.5$5.04Y#15]%5D5262P@($U!24Y414Y!3D-%
M7T9)4E-47TQ/1TE."B`@("`@*B!/<&5R871I;VYS('=I;&P@8F4@<G5N(&EN
M('1H92!O<F1E<B!T:&5Y(&%P<&5A<B!I;B!T:&4@87)R87D@+0H@("`@("H@
M("!-04M%(%-54D4@1E5.0U1)3TY3($%212!)3B!42$4@0T]24D5#5"!/4D1%
M4B$*("`@("`J($]P97)A=&EO;G,@8V%N(&%P<&5A<B!M;W)E('1H86X@;VYC
M92`M('1H97D@=VEL;"!O;FQY(&)E(')U;B!O;F-E('!E<@H@("`@("H@("!L
M;V=I;B!T:&]U9V@@*'1H92!O<&5R871I;VX@=VEL;"!R=6X@=&AE(&9I<G-T
M('1I;64@:70@:7,@<V5E;B!I;@H@("`@("H@("!T:&4@87)R87DI+@H@("`@
M("H*("`@("`J(%1H:7,@87)R87D@<VAO=6QD(&)E(&9I;&QE9"!I;B!F;W(@
M96%C:"!(;W)D92!M;V1U;&4@=&AA="!E>'1E;F1S"B`@("`@*B`@('1H92!-
M86EN=&5N86YC92!C;&%S<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D;6%I;G1?=&%S:W,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@54Y)6"!T:6UE<W1A;7`@;V8@=&AE(&QA<W0@;6%I;G1E;F%N
M8V4@<G5N(&9O<B!U<V5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("HO"B`@("!V87(@)%]L87-T4G5N(#T@,#L*"B`@("`O*BH*("`@("`J
M(%1H92!-86EN=&5N86YC95]487-K;&ES="!O8FIE8W0@9F]R('1H:7,@;&]G
M:6XN"B`@("`@*@H@("`@("H@0'9A<B!-86EN=&5N86YC95]487-K;&ES=`H@
M("`@("HO"B`@("!V87(@)%]T87-K;&ES=#L*"B`@("`O*BH*("`@("`J($%R
M<F%Y('1O('-T;W)E($UA:6YT96YA;F-E7U1A<VL@;V)J96-T<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1A<VM#86-H
M92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U
M<FX@82!C;VYC<F5T92!-86EN=&5N86YC95\J(&]B:F5C="!B87-E9"!O;B!T
M:&4@;6]D=6QE"B`@("`@*B!N86UE('!A<W-E9"!I;G1O(&ET+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UO9'5L92`@5&AE(&YA;64@;V8@=&AE
M($AO<F1E(&UO9'5L92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M02!H87-H(&-O;G1A:6YI;F<@861D:71I;VYA;"!D871A(&YE961E9"!B>2!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N<W1R=6-T;W(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!-86EN=&5N86YC92`@5&AE($UA:6YT
M96YA;F-E(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9F86-T;W)Y*"1M;V1U;&4L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J
M(%-P87=N('1H92!R96QE=F%N="!D<FEV97(L(&%N9"!R971U<FX@:70@*&]R
M(&9A;'-E(&]N(&9A:6QU<F4I+B`J+PH@("`@("`@(&EN8VQU9&5?;VYC92`D
M<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D;6]D=6QE*2`N("<O;&EB+TUA
M:6YT96YA;F-E+R<@+B`D;6]D=6QE("X@)RYP:'`G.PH@("`@("`@("1C;&%S
M<R`]("=-86EN=&5N86YC95\G("X@)&UO9'5L93L*("`@("`@("!I9B`H8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&UA:6YT96YA;F-E
M(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&UA:6YT96YA;F-E(#T@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&UA:6YT96YA;F-E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG('1H92!F;VQL;W=I;F<@96YT<FEE
M<SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G;&%S=%]M86EN=&5N
M86YC92<@/3X@5&AE(&QA<W0@=&EM92!M86EN=&5N86YC92!W87,@<G5N("AU
M;FEX('1I;65S=&%M<"DN"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6YT96YA
M;F-E*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\J(%-E="!T
M:&4@8VQA<W,@=F%R:6%B;&4@)%]L87-T4G5N+B`J+PH@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R=L87-T7VUA:6YT96YA;F-E)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?;&%S=%)U;B`]("1P87)A;7-;)VQA<W1?;6%I;G1E;F%N
M8V4G73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<F5T<FEE=F5487-K
M;&ES="@I.PH@("`@("`@("1T:&ES+3Y?<VAU=&1O=VXH*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O(&UA:6YT96YA;F-E(&]P97)A=&EO;G,@;F5E9&5D
M(&9O<B!T:&ES(&QO9VEN+B`@5&AI<R!F=6YC=&EO;@H@("`@("H@=VEL;"!G
M96YE<F%T92!T:&4@;&ES="!O9B!T87-K<R!T;R!P97)F;W)M(&1U<FEN9R!T
M:&ES(&QO9VEN"B`@("`@*B!A;F0@=VEL;"!R961I<F5C="!T;R!T:&4@;6%I
M;G1E;F%N8V4@<&%G92!I9B!N96-E<W-A<GDN("!4:&ES"B`@("`@*B!I<R!T
M:&4@9G5N8W1I;VX@=&AA="!S:&]U;&0@8F4@8V%L;&5D(&9R;VT@=&AE(&%P
M<&QI8V%T:6]N('5P;VX*("`@("`J(&QO9VEN+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R=6Y-86EN=&5N86YC92@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@
M=&\@<V5E(&EF('=E(&%R92!F:6YI<VAE9"!W:71H(&UA:6YT96YA;F-E"B`@
M("`@("`@("H@;W!E<F%T:6]N<RX@*B\*("`@("`@("!I9B`H(55T:6PZ.F=E
M=$9O<FU$871A*$U!24Y414Y!3D-%7T1/3D5?4$%204TI*2!["B`@("`@("`@
M("`@("\J($1E=&5R;6EN92!I9B!W92!S:&]U;&0@<F5D:7)E8W0@=&\@=&AE
M(&UA:6YT96YA;F-E('!A9V4N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7VYE961-86EN=&5N86YC95!A9V4H*2`A/3T@;G5L;"D@>PH@("`@("`@("`@
M("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1T:&ES+3Y?9V5T36%I;G1E
M;F%N8V554DPH*2P@=')U92D["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!&:6YA;&QY+"!R=6X@
M86YY('1A<VMS('1H870@;F5E9"!T;R!B92!E>&5C=71E9"X@*B\*("`@("`@
M("`D=&AI<RT^7V1O36%I;G1E;F%N8V5487-K<R@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&\@=&AE(&YE8V5S<V%R>2!M86EN=&5N86YC92!T87-K<R!F
M;W(@=&AI<R!L;V%D:6YG(&]F('1H92!M86EN=&5N86YC90H@("`@("H@<&%G
M92X@(%1H:7,@:7,@=&AE(&9U;F-T:6]N('1H870@:7,@8V%L;&5D(&9R;VT@
M=&AE(&UA:6YT96YA;F-E('!A9V4*("`@("`J(&5V97)Y('1I;64@:70@:7,@
M;&]A9&5D+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&1I
M<W!L87D@<F5Q=6ER960@9F]R('1H92!M86EN=&5N86YC92!P86=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R=6Y-86EN=&5N86YC95!A9V4H*0H@("`@>PH@
M("`@("`@("\J(%-H;W5L9"!W92!R=6X@86YY('1A<VMS/R`J+PH@("`@("`@
M("1T:&ES+3Y?9&]-86EN=&5N86YC951A<VMS*"D["@H@("`@("`@("\J($=E
M="!T:&4@;&ES="!O9B!T87-K<R!W92!N965D('1O(&1I<W!L87D@=&\@=&AE
M('5S97(N("HO"B`@("`@("`@)'1A<VM?;F\@/2`D=&AI<RT^7VYE961-86EN
M=&5N86YC95!A9V4H*3L*("`@("`@("`D=&%S:W,@/2`D=&AI<RT^7W1A<VML
M:7-T+3YG971,:7-T*"D["@H@("`@("`@("\J(%)E;6]V92`G;F5W9FQA9R<@
M9G)O;2!F:7)S="!T87-K+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]T87-K
M;&ES="T^<')O8V5S<V5D*'1R=64I*2!["B`@("`@("`@("`@(&EF("AC;W5N
M="@D=&%S:W,I*2!["B`@("`@("`@("`@("`@("!R97-E="@D=&%S:W,I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^<V5T3F5W4&%G92AK
M97DH)'1A<VMS*2P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES7VYU;&PH)'1A<VM?;F\I*2!["B`@("`@("`@("`@
M("1T87-K<R`](&%R<F%Y7W-L:6-E*"1T87-K<RP@,"P@)'1A<VM?;F\@*R`Q
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("AC;W5N="@D=&%S:W,I*2!["B`@
M("`@("`@("`@(')E<V5T*"1T87-K<RD["B`@("`@("`@("`@("1A8W1I;VX@
M/2`D=&%S:W-;:V5Y*"1T87-K<RE=6R=D:7-P;&%Y)UT["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&%C=&EO;B`](&YU;&P["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@87)R87DH)&%C=&EO;BP@87)R87E?:V5Y<R@D=&%S
M:W,I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN9F]R
M;6%T:6]N86P@=&5X="!M97-S86=E(&]N('=H870@=&AE(&]P97)A=&EO;B!I
M<PH@("`@("H@86)O=70@=&\@9&\N($%L<V\@:6YD:6-A=&5S('=H971H97(@
M=&AE(&)O>"!S:&]U;&0@8F4@8VAE8VME9`H@("`@("H@8GD@9&5F875L="!O
M<B!N;W0N($]P97)A=&EO;G,@=&AA="!H879E(&)E96X@;&]C:V5D(&)Y('1H
M90H@("`@("H@861M:6X@=VEL;"!R971U<FX@;G5L;"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P<F5F("!.86UE(&]F('1H92!O<&5R871I;VX@
M=&\@9V5T(&EN9F]R;6%T:6]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("`Q<W0@96QE;65N="`M($1E<V-R:7!T:6]N(&]F('=H870@=&AE
M(&]P97)A=&EO;B!I<R!A8F]U=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T;R!D;R!D=7)I;F<@=&AI<R!L;V=I;BX*("`@("`J("`@
M("`@("`@("`@("`@(#)N9"!E;&5M96YT("T@5VAE=&AE<B!T:&4@<')E9F5R
M96YC92!I<R!S970@=&\@;VX@;W(@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!I;F9O36%I;G1E;F%N8V4H)'!R968I"B`@("!["B`@("`@("`@9VQO8F%L
M("1P<F5F<SL*"B`@("`@("`@+RH@268@=&AE('!R969E<F5N8V4@:&%S(&)E
M96X@;&]C:V5D(&)Y('1H92!A9&UI;BP@9&\@;F]T('-H;W<*("`@("`@("`@
M("!T:&4@=7-E<BX@*B\*("`@("`@("!I9B`H)'!R969S+3YI<TQO8VME9"@D
M<')E9BDI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)&UO9"`]("8D=&AI<RT^7VQO861-;V1U;&4H)'!R968I.PH@("`@("`@
M(')E='5R;B!A<G)A>2@D;6]D+3YD97-C<FEB94UA:6YT96YA;F-E*"DL("1P
M<F5F<RT^9V5T5F%L=64H)'!R968I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X<&]R="!V87)I86)L92!N86UE<R!T;R!U<V4@9F]R(&-R96%T:6YG('-E
M;&5C="!T86)L97,@:6X@=&AE"B`@("`@*B!P<F5F97)E;F-E<R!M96YU+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F('9A<FEA
M8FQE(&YA;65S('1O(&)E(&EM<&]R=&5D(&EN=&\@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("!P<F5F<RYP:'`@;F%M97-P86-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!E>'!O<G1);G1E<G9A;%!R969S*"D*("`@('L*("`@("`@("!G
M;&]B86P@)'!R969S.PH*("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH
M*3L*"B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^;6%I;G1?
M=&%S:W,I(&%S("1V86PI('L*("`@("`@("`@("`@:68@*"$D<')E9G,M/FES
M3&]C:V5D*"1V86P@+B`G7VEN=&5R=F%L)RDI('L*("`@("`@("`@("`@("`@
M("1R971U<FY?87)R87E;72`]("1V86P@+B`G7VEN=&5R=F%L7V]P=&EO;G,G
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M='5R;E]A<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U="!H:61D
M96X@9F]R(&5L96UE;G1S(&9O<B!T:&4@4$]35"!F;W)M('1O(&5N<W5R92!T
M:&4@8V%L;&EN9PH@("`@("H@<V-R:7!T(&AA<R!T:&4@<V%M92!03U-4(&5L
M96UE;G1S(&%S('=H96X@=&AE(&UA:6YT96YA;F-E(&]P97)A=&EO;G,*("`@
M("`J(&9I<G-T(')U;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&9O<FT@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&]S=$1A
M=&$H*0H@("`@>PH@("`@("`@("1T97AT(#T@)R<["@H@("`@("`@(&EF("@H
M)&1A=&$@/2`D=&AI<RT^7W1A<VML:7-T+3YG9710;W-T1&%T82@I*2D@>PH@
M("`@("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D;F%M92`]/B`D=F%L*2![
M"B`@("`@("`@("`@("`@("`D=&5X="`N/2`G/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&YA;64I("X@)R(@=F%L
M=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1V86PI("X@)R(@+SXG("X@(EQN
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!54DP@;F5E
M9&5D(&9O<B!T:&4@;6%I;G1E;F%N8V4@9F]R;2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(%523"!T;R!R961I<F5C="!T;RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T36%I;G1E;F%N8V5&;W)M55),*"D*("`@('L*
M("`@("`@(&EF("@D=&AI<RT^7VYE961-86EN=&5N86YC95!A9V4H*2`A/3T@
M;G5L;"D@>PH@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V=E=$UA:6YT96YA
M;F-E55),*"D["B`@("`@("!](&5L<V4@>PH@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V=E=$EN:71I86Q086=E55),*"D["B`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&5S('1H92!L:7-T(&]F(&UA:6YT96YA;F-E
M(&]P97)A=&EO;G,@=&AA="!A<F4@879A:6QA8FQE"B`@("`@*B!F;W(@=&AI
M<R!S97-S:6]N("AS=&]R960@:6X@82!-86EN=&5N86YC95]487-K;&ES="!O
M8FIE8W0I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF(&QI<W0@
M=V%S(&-R96%T960N"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF
M(&YO="`H92YG+B!L:7-T(&%L<F5A9'D@97AI<W1S*2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-R96%T951A<VM,:7-T*"D*("`@('L*("`@("`@("!G;&]B
M86P@)'!R969S.PH*("`@("`@("`O*B!#<F5A=&4@82!N97<@36%I;G1E;F%N
M8V5?5&%S:VQI<W0@;V)J96-T+B`J+PH@("`@("`@("1T:&ES+3Y?=&%S:VQI
M<W0@/2`F;F5W($UA:6YT96YA;F-E7U1A<VML:7-T*"D["@H@("`@("`@("\J
M($-R96%T92!T:6UE(&]B:F5C=',@9F]R('1O9&%Y)W,@9&%T92!A;F0@;&%S
M="!L;V=I;B!D871E+B`J+PH@("`@("`@("1L87-T7V1A=&4@/2!G971D871E
M*"1T:&ES+3Y?;&%S=%)U;BD["B`@("`@("`@)&-U<E]D871E("`](&=E=&1A
M=&4H*3L*"B`@("`@("`@+RH@1V\@=&AR;W5G:"!E86-H(&ET96T@:6X@)&UA
M:6YT7W1A<VMS(&%N9"!D971E<FUI;F4@:68@=V4@;F5E9"!T;PH@("`@("`@
M("`@(')U;B!I="!D=7)I;F<@=&AI<R!M86EN=&5N86YC92!R=6XN("HO"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/FUA:6YT7W1A<VMS(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("`O*B!3:VEP(&ET96T@:68@:70@86QR96%D
M>2!A<'!E87)S(&EN('1H92!T87-K<R!L:7-T+B`J+PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]T87-K;&ES="T^:6Y,:7-T*"1K97DI*2!["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH@1&5T97)M:6YE('1H92!C;W)R96-T(&EN=&5R=F%L(&9O<B!T:&4@:71E
M;2X@*B\*("`@("`@("`@("`@:68@*"@D:6YT97)V86P@/2`D<')E9G,M/F=E
M=%9A;'5E*"1K97D@+B`G7VEN=&5R=F%L)RDI*2!["B`@("`@("`@("`@("`@
M("`D=F%L(#T@)&EN=&5R=F%L.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D861D5&%S:R`](&9A;'-E.PH*("`@("`@("`@("`@+RH@1DE24U0@3$]'
M24X@3U!%4D%424].4R`J+PH@("`@("`@("`@("`O*B!)9B`D7VQA<W12=6X@
M:7,@96UP='D@*#T@,"DL('1H:7,@:7,@=&AE(&9I<G-T('1I;64@=&AE('5S
M97(*("`@("`@("`@("`@("`@:&%S(&QO9V=E9"!I;BX@1&]N)W0@<G5N(&%N
M>2!O=&AE<B!M86EN=&5N86YC92!O<&5R871I;VYS(&]N"B`@("`@("`@("`@
M("`@('1H92!F:7)S="!L;V=I;BX@*B\*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3Y?;&%S=%)U;BDI('L*("`@("`@("`@("`@("`@(&EF("@D=F%L
M(#T]($U!24Y414Y!3D-%7T9)4E-47TQ/1TE.*2!["B`@("`@("`@("`@("`@
M("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O*B!914%23%E?3U!%4D%424].4R`J
M+PH@("`@("`@("`@("!E;'-E:68@*"@D=F%L(#T]($U!24Y414Y!3D-%7UE%
M05),62D@)B8*("`@("`@("`@("`@("`@("`@("`H)&-U<E]D871E6R=Y96%R
M)UT@/B`D;&%S=%]D871E6R=Y96%R)UTI*2!["B`@("`@("`@("`@("`@("`D
M861D5&%S:R`]('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($U/3E1(3%D@3U!%4D%424].4R`J+PH@("`@("`@("`@("!E;'-E:68@*"@D
M=F%L(#T]($U!24Y414Y!3D-%7TU/3E1(3%DI("8F"B`@("`@("`@("`@("`@
M("`@("`@*"@D8W5R7V1A=&5;)WEE87(G72`^("1L87-T7V1A=&5;)WEE87(G
M72D@?'P@*"1C=7)?9&%T95LG;6]N)UT@/B`D;&%S=%]D871E6R=M;VXG72DI
M*2!["B`@("`@("`@("`@("`@("`D861D5&%S:R`]('1R=64["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J(%=%14M,62!/4$52051)3TY3("HO"B`@
M("`@("`@("`@(&5L<V5I9B`H*"1V86P@/3T@34%)3E1%3D%.0T5?5T5%2TQ9
M*2`F)@H@("`@("`@("`@("`@("`@("`@("@H)&-U<E]D871E6R=W9&%Y)UT@
M/"`D;&%S=%]D871E6R=W9&%Y)UTI('Q\("@H=&EM92@I("T@-C`T.#`P*2`^
M("1T:&ES+3Y?;&%S=%)U;BDI*2!["B`@("`@("`@("`@("`@("`D861D5&%S
M:R`]('1R=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($1!24Q9
M($]015)!5$E/3E,@*B\*("`@("`@("`@("`@96QS96EF("@H)'9A;"`]/2!-
M04E.5$5.04Y#15]$04E,62D@)B8*("`@("`@("`@("`@("`@("`@("`H*"1C
M=7)?9&%T95LG>65A<B==(#X@)&QA<W1?9&%T95LG>65A<B==*2!\?"`H)&-U
M<E]D871E6R=Y9&%Y)UT@/B`D;&%S=%]D871E6R=Y9&%Y)UTI*2D@>PH@("`@
M("`@("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!%5D5262!,3T=)3B!/4$52051)3TY3("HO"B`@("`@
M("`@("`@(&5L<V5I9B`H)'9A;"`]/2!-04E.5$5.04Y#15]%5D5262D@>PH@
M("`@("`@("`@("`@("`@)&%D9%1A<VL@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("\J(%-K:7`@=&AE('1A<VL@:68@86YY(&]F('1H92!F
M;VQL;W=I;F<Z"B`@("`@("`@("`@("`@("L@5&AI<R!T87-K(&1O97,@;F]T
M(&YE960@=&\@8F4@<G5N(&EN('1H:7,@;&]G:6X*("`@("`@("`@("`@("`@
M*R!4:&ES('1A<VL@:7,@;F]T('-E="!I;B!T:&4@<')E9F5R96YC97,@*B\*
M("`@("`@("`@("`@:68@*"$D861D5&%S:R!\?"`A)'!R969S+3YG971686QU
M92@D:V5Y*2D@8V]N=&EN=64["@H@("`@("`@("`@("`O*B!,;V%D('1H92!T
M87-K(&UO9'5L92!N;W<N("HO"B`@("`@("`@("`@("1M;V0@/2`F)'1H:7,M
M/E]L;V%D36]D=6QE*"1K97DI.PH*("`@("`@("`@("`@+RH@1&5T97)M:6YE
M(&EF('1H:7,@=&%S:R!H87,@86QR96%D>2!B965N(&-O;F9I<FUE9"]S970@
M=FEA('-O;64*("`@("`@("`@("`@("`@<V]R="!O9B!A9&UI;B!S971T:6YG
M+B!!;'-O+"!I9B!T:&4@=7-E<B]A9&UI;B!H87,@<V5T('1H90H@("`@("`@
M("`@("`@("`G8V]N9FER;5]M86EN=&5N86YC92<@9FQA9RP@<VMI<"!C;VYF
M:7)M871I;VXN("HO"B`@("`@("`@("`@("1C;VYF:7)M960@/2!F86QS93L*
M("`@("`@("`@("`@:68@*"1P<F5F<RT^:7-,;V-K960H)&ME>2D@?'P*("`@
M("`@("`@("`@("`@("$D<')E9G,M/F=E=%9A;'5E*"=C;VYF:7)M7VUA:6YT
M96YA;F-E)RDI('L*("`@("`@("`@("`@("`@("1C;VYF:7)M960@/2!T<G5E
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!9&0@=&AE('1A<VL@
M=&\@=&AE('1A<VML:7-T+B`J+PH@("`@("`@("`@("`D=&AI<RT^7W1A<VML
M:7-T+3YA9&1487-K*"1K97DL("1C;VYF:7)M960L("1M;V0M/F=E=$1I<W!L
M87E4>7!E*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO
M860@;6]D=6QE("AI9B!N;W0@86QR96%D>2!L;V%D960I+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&UO9&YA;64@($YA;64@;V8@=&AE(&UO9'5L92!T;R!L;V%D+@H@("`@
M("H*("`@("`J($!R971U<FX@36%I;G1E;F%N8V5?5&%S:R`@02!R969E<F5N
M8V4@=&\@=&AE(')E<75E<W1E9"!M;V1U;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9?;&]A9$UO9'5L92@D;6]D;F%M92D*("`@('L*("`@("`@("!G;&]B
M86P@)')E9VES=')Y.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=&%S
M:T-A8VAE6R1M;V1N86UE72DI('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E
M("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1T:&ES+3Y?=&%S:VQI<W0M
M/F=E=$UO9'5L92@I*2`N("<O;&EB+TUA:6YT96YA;F-E+U1A<VLO)R`N("1M
M;V1N86UE("X@)RYP:'`G.PH@("`@("`@("`@("`D8VQA<W,@/2`G36%I;G1E
M;F%N8V5?5&%S:U\G("X@)&UO9&YA;64["B`@("`@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]T
M87-K0V%C:&5;)&UO9&YA;65=(#T@)FYE=R`D8VQA<W,["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!O<&5N($UA:6YT96YA
M;F-E7U1A<VL@;6]D=6QE("5S(BDL("1C;&%S<RDI+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]T87-K0V%C:&5;)&UO9&YA;65=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5T('1H92!54DP@9F]R('1H92!I;FET:6%L('!A9V4N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!54DP@9F]R('1H92!I;FET:6%L('!A9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971);FET:6%L4&%G95523"@I"B`@("![
M"B`@("`@("`@<F5T=7)N(%5T:6PZ.F%D9%!A<F%M971E<B@D=&AI<RT^7W1A
M<VML:7-T+3YG971487)G970H*2P@87)R87DH34%)3E1%3D%.0T5?1$].15]0
M05)!32`]/B`Q+"`G9&]M86EN=&5N86YC92<@/3X@,2DL(&YU;&PL(&9A;'-E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@55),(&9O<B!T:&4@
M;6%I;G1E;F%N8V4@<&%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(%523"!F;W(@
M=&AE(&UA:6YT96YA;F-E('!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971-86EN=&5N86YC95523"@I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@+RH@5V4@;F5E9"!T;R!P87-S('1H92!C86-H92!)
M1"!A;F0@)VUO9'5L92<@<&%R86UE=&5R<RX@*B\*("`@("`@("`D=7)L(#T@
M2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I
M("X@)R]S97)V:6-E<R]M86EN=&5N86YC92YP:'`G+"!T<G5E*3L*("`@("`@
M("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL(&%R<F%Y*"=M;V1U
M;&4G(#T^("1T:&ES+3Y?=&%S:VQI<W0M/F=E=$UO9'5L92@I+"`G9&]M86EN
M=&5N86YC92<@/3X@,2DL(&YU;&PL(&9A;'-E*3L*"B`@("`@("`@<F5T=7)N
M("1U<FP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296=I<W1E<B!T:&4@<VAU
M=&1O=VX@9G5N8W1I;VX@9F]R('-T;W)I;F<@=&AE(&UA:6YT96YA;F-E"B`@
M("`@*B!T87-K;&ES="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7W-H=71D;W=N*"D*("`@('L*("`@("`@
M("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?
M8V%C:&5487-K;&ES="<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A8VAE
M('1H92!M86EN=&5N86YC92!T87-K;&ES="!B971W965N('!A9V4@<F5Q=65S
M=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C86-H951A<VML:7-T*"D*("`@('L*("`@("`@("`D7U-%
M4U-)3TY;)VAO<F1E7VUA:6YT96YA;F-E7W1A<VML:7-T)UT@/2!S97)I86QI
M>F4H)'1H:7,M/E]T87-K;&ES="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V97,@82!C86-H960@;6%I;G1E;F%N8V4@=&%S:VQI<W0@;W(@;6%K
M97,@<W5R92!O;F4@:7,*("`@("`J(&-R96%T960N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]R971R:65V
M951A<VML:7-T*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].
M6R=H;W)D95]M86EN=&5N86YC95]T87-K;&ES="==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W1A<VML:7-T(#T@=6YS97)I86QI>F4H)%]315-324].6R=H
M;W)D95]M86EN=&5N86YC95]T87-K;&ES="==*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7V-R96%T951A<VML:7-T*"D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T92!A;&P@8V]N9FER
M;65D('1A<VMS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9&]-86EN=&5N86YC951A<VMS*"D*("`@('L*
M("`@("`@("`D=&%S:W,@/2`D=&AI<RT^7W1A<VML:7-T+3YG971,:7-T*"D[
M"@H@("`@("`@(&9O<F5A8V@@*"1T87-K<R!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@:68@*"1V86Q;)VYE=W!A9V4G72D@>PH@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?=&%S:VQI<W0M/G!R;V-E<W-E9"@I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^<V5T3F5W4&%G
M92@D:V5Y+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E;'-E:68@*"1V86Q;)V-O;F9I
M<FUE9"==('Q\"B`@("`@("`@("`@("`@("`@("`@("!5=&EL.CIG971&;W)M
M1&%T82@D:V5Y("X@)U]C;VYF:7)M)RDI('L*("`@("`@("`@("`@("`@("\J
M(%!E<F9O<FT@;6%I;G1E;F%N8V4@:68@8V]N9FER;65D+B`J+PH@("`@("`@
M("`@("`@("`@)&UO9"`]("8D=&AI<RT^7VQO861-;V1U;&4H)&ME>2D["B`@
M("`@("`@("`@("`@("`D;6]D+3YD;TUA:6YT96YA;F-E*"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]T87-K;&ES="T^<F5M;W9E5&%S
M:R@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E)W9E('-U8V-E
M<W-F=6QL>2!C;VUP;&5T960@979E<GD@=&%S:R!I;B!T:&4@;&ES="`H;W(*
M("`@("`@("`@*B!S:VEP<&5D(&ET*2P@<F5C;W)D(&YO=R!A<R!T:&4@;&%S
M="!T:6UE(&UA:6YT96YA;F-E('=A<PH@("`@("`@("`J(')U;BX@*B\*("`@
M("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?=&%S:VQI<W0M/F=E=$QI<W0H*2DI
M('L*("`@("`@("`@("`@)$=,3T)!3%-;)W!R969S)UTM/G-E=%9A;'5E*"=L
M87-T7VUA:6YT96YA;F-E)RP@=&EM92@I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$;R!A;GD@;V8@=&AE('1A<VMS(')E<75I<F4@=&AE
M(&UA:6YT96YA;F-E('!A9V4_"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@:V5Y(&]F
M('1H92!T87-K('1H870@<F5Q=6ER97,@=&AE(&UA:6YT96YA;F-E"B`@("`@
M*B`@("`@("`@("`@("`@("`@('!A9V4N(%)E='5R;G,@;G5L;"!I9B!T:&4@
M;6%I;G1E;F%N8V4@<&%G92!I<R!N;PH@("`@("H@("`@("`@("`@("`@("`@
M("!L;VYG97(@;F5E9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;F5E9$UA
M:6YT96YA;F-E4&%G92@I"B`@("!["B`@("`@("`@)&D@/2`P.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?=&%S:VQI<W0M/F=E=$QI<W0H*2!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`@("`@:68@*"1V86Q;)VYE=W!A9V4G72D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@A96UP='DH)'9A;%LG<')O8V5S<R==*2`F)@H@("`@
M("`@("`@("`@("`@(55T:6PZ.F=E=$9O<FU$871A*"=D;VUA:6YT96YA;F-E
M)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%S:VQI<W0M/G-E=$YE
M=U!A9V4H)&ME>2P@=')U92D["B`@("`@("`@("`@("`@("!R971U<FX@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*?0H*+RHJ"B`J(%1H92!-86EN
M=&5N86YC95]487-K;&ES=#HZ(&-L87-S(&ES('5S960@=&\@<W1O<F4@=&AE
M(&QI<W0@;V8@;6%I;G1E;F%N8V4*("H@=&%S:W,@=&AA="!N965D('1O(&)E
M(')U;B!D=7)I;F<@=&AI<R!L;V=I;BX*("H*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?36%I;G1E;F%N8V4*
M("HO"F-L87-S($UA:6YT96YA;F-E7U1A<VML:7-T('L*"B`@("`O*BH*("`@
M("`J(%1H92!(;W)D92!M;V1U;&4@<G5N;FEN9R!T:&4@;6%I;G1E;F%N8V4@
M=&%S:W,N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?;6]D=6QE.PH*("`@("\J*@H@("`@("H@5&AE(%523"!O9B!T:&4@
M=V5B('!A9V4@=&\@;&]A9"!A9G1E<B!M86EN=&5N86YC92!I<R!C;VUP;&5T
M92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]T87)G970["@H@("`@+RHJ"B`@("`@*B!03U-4(&1A=&$@9F]R('1H92!C
M86QL:6YG('-C<FEP="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!O<W1D871A.PH*("`@("\J*@H@("`@("H@5&AE(&QI
M<W0@;V8@=&%S:W,@=&\@<G5N(&1U<FEN9R!T:&ES(&QO9VEN+@H@("`@("H*
M("`@("`J($M%63H@("`@5&%S:R!N86UE"B`@("`@*B!604Q513H@($%R<F%Y
M(#T^("@*("`@("`J("`@("`@("`@("`G8V]N9FER;65D)R`@/3X@(&)O;VQE
M86XL"B`@("`@*B`@("`@("`@("`@)V1I<W!L87DG("`@(#T^("!I;G1E9V5R
M+`H@("`@("H@("`@("`@("`@("=N97=P86=E)R`@("`]/B`@8F]O;&5A;BP*
M("`@("`J("`@("`@("`@("`G<')O8V5S<R<@("`@/3X@(&)O;VQE86X*("`@
M("`J("`@("`@("`@*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?=&%S:W,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M26YT97)N86P@9FQA9R!F;W(@861D5&%S:R@I+@H@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]A9&1&;&%G(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!(87,@=&AE('1A<VML:7-T(&)E96X@<')O8V5S
M<V5D('EE=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?<')O8V5S<V5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@36%I;G1E;F%N8V5?
M5&%S:VQI<W0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@
M("`@("`@("1T:&ES+3Y?;6]D=6QE(#T@)')E9VES=')Y+3YG971!<'`H*3L*
M("`@("`@("`D=&AI<RT^7W1A<F=E="`]($AO<F1E.CIS96QF57)L*'1R=64I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('1A<VL@=&\@=&AE('1A
M<VML:7-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@
M("`@(%1H92!N86UE(&]F('1H92!T87-K('1O('!E<F9O<FTN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D8V]N9FER;65D("!(87,@=&AE('1A<VL@8F5E;B!C
M;VYF:7)M960_"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ES<&QA>2`@("!4
M:&4@9&ES<&QA>2!T>7!E(&]F('1H92!T87-K+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1487-K*"1K97DL("1C;VYF:7)M960L("1D:7-P;&%Y*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?=&%S:W-;)&ME>5T@/2!A<G)A>2@I.PH@("`@
M("`@("1T:&ES+3Y?=&%S:W-;)&ME>5U;)V-O;F9I<FUE9"==(#T@)&-O;F9I
M<FUE9#L*("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=D:7-P;&%Y)UT@
M/2`D9&ES<&QA>3L*"B`@("`@("`@:68@*"@D9&ES<&QA>2`]/2!-04E.5$5.
M04Y#15]/5510551?04=2144I('Q\"B`@("`@("`@("`@("@D9&ES<&QA>2`]
M/2!-04E.5$5.04Y#15]/5510551?3D]424-%*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W1A<VMS6R1K97E=6R=N97=P86=E)UT@/2!T<G5E.PH@("`@("`@
M("`@("`D=&AI<RT^7V%D9$9L86<@/2!F86QS93L*("`@("`@("!](&5L<V5I
M9B`H*"1C;VYF:7)M960@/3T@9F%L<V4I("8F("@A)'1H:7,M/E]A9&1&;&%G
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1A<VMS6R1K97E=6R=N97=P86=E
M)UT@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V%D9$9L86<@/2!T<G5E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?=&%S:W-;
M)&ME>5U;)VYE=W!A9V4G72`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE(&YE=W!A9V4@9FQA9R!F;W(@82!T87-K
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<VL@(%1H92!N86UE
M(&]F('1H92!T87-K('1O(&%L=&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FQA9R`@2&]W('1O('-E="!T:&4@9FQA9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T3F5W4&%G92@D=&%S:RP@)&9L86<I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YI;DQI<W0H)'1A<VLI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M=&%S:W-;)'1A<VM=6R=N97=P86=E)UT@/2`D9FQA9SL*("`@("`@("`@("`@
M)'1H:7,M/E]T87-K<ULD=&%S:UU;)W!R;V-E<W,G72`]("$D9FQA9SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S('1H92!T87-K
M(&9R;VT@=&AE('1A<VML:7-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1A<VL@(%1H92!N86UE(&]F('1H92!T87-K('1O(&%L=&5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96UO=F5487-K*"1T87-K*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^:6Y,:7-T*"1T87-K*2D@>PH@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7W1A<VMS6R1T87-K72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@27,@=&AI<R!T87-K(&%L<F5A9'D@:6X@=&AE('1A
M<VML:7-T/PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A<VL@(%1H
M92!N86UE(&]F('1H92!T87-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5VAE=&AE<B!T:&4@=&%S:R!I<R!A;')E861Y(&EN('1H92!T87-K
M;&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@:6Y,:7-T*"1T87-K*0H@("`@
M>PH@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W1A<VMS6R1T87-K72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@=&%S
M:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@
M=&%S:W,@=&AA="!S=&EL;"!N965D('1O(&)E(&1O;F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$QI<W0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7W1A<VMS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!(
M;W)D92!M;V1U;&4@=&AE('1A<VMS(&%R92!R=6YN:6YG('5N9&5R+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2&]R9&4@;6]D=6QE(&YA
M;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UO9'5L92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;6]D=6QE.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!03U-4(&1A=&$N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE(%!/4U0@9&%T82!F<F]M('1H92!I;FET:6%L(%52
M3"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&]S=$1A=&$H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!O<W1D871A.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!54DP@;V8@=&AE('=E8B!P86=E('1O(&QO
M860@869T97(@;6%I;G1E;F%N8V4@:7,@8V]M<&QE=&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!T87)G970@55),+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971487)G970H*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W1A<F=E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',O9&ES
M<&QA>7,@=&AE(&9L86<@=&\@<VAO=R!T:&%T('1A<VML:7-T(&AA<R!B965N
M('!R;V-E<W-E9"!A=`H@("`@("H@;&5A<W0@;VYC92X*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<V5T("!3970@=&AE(&9L86<_"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!(87,@=&AE('1A<VML:7-T(&)E96X@
M<')O8V5S<V5D(&)E9F]R93\*("`@("`J+PH@("`@9G5N8W1I;VX@<')O8V5S
M<V5D*"1S970@/2!F86QS92D*("`@('L*("`@("`@("`D<F5T=F%L=64@/2`D
M=&AI<RT^7W!R;V-E<W-E9#L*("`@("`@("!I9B`H)'-E="D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R;V-E<W-E9"`]('1R=64["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5T=F%L=64["B`@("!]"@I]"@HO*BH*("H@06)S=')A
M8W0@8VQA<W,@=&\@86QL;W<@9F]R(&UO9'5L87)I>F%T:6]N(&]F('-P96-I
M9FEC(&UA:6YT96YA8V4@=&%S:W,N"B`J"B`J($9O<B!T:&ES(&5X<&QA;F%T
M:6]N+"!T:&4@<W!E8VEF:6,@2&]R9&4@87!P;&EC871I;VX@>6]U('=A;G0@
M=&\@8W)E871E"B`J(&UA:6YT96YA;F-E(&%C=&EO;G,@9F]R('=I;&P@8F4@
M;&%B96QE9"!(3U)$14%04"X*("H*("H@5&\@861D(&$@;F5W(&UA:6YT96YA
M;F-E('1A<VLL('EO=2!N965D('1O(&1O('1H92!F;VQL;W=I;F<Z"B`J(%LQ
M72!!9&0@<')E9F5R96YC92!T;R`B2$]21$5!4%`O8V]N9FEG+W!R969S+G!H
M<"(@9FEL92X*("H@("`@("A4:&4@;F%M92!O9B!T:&ES('!R969E<F5N8V4@
M=VEL;"!B92!R969E<G)E9"!T;R!A<R!04D5&3D%-12D*("H@("`@(%1H:7,@
M<')E9F5R96YC92!S:&]U;&0@8F4@;V8@='EP92`G8VAE8VMB;W@G("AI+F4N
M(#$@/2!O;CL@,"`](&]F9BDN"B`J("`@("!;3W!T:6]N86PZ72`@061D(&$@
M<')E9F5R96YC92!I;B!P<F5F<RYP:'`@;V8@=&AE(&YA;64*("H@("`@("`@
M("`@("`@("`@("`G4%)%1DY!345?:6YT97)V86PG('1O(&%L;&]W('1H92!U
M<V5R('1O('-E="!T:&4@:6YT97)V86PN"B`J("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G('9A;'5E('-H;W5L9"!B92!S970@=&\@=&AE('9A;'5E<R!O
M9B!T:&4@:6YT97)V86P*("H@("`@("`@("`@("`@("`@("!C;VYS=&%N=',@
M86)O=F4N"B`J("`@("`@("`@("`@("`@("`@268@=&AI<R!P<F5F97)E;F-E
M(&1O97-N)W0@97AI<W0L('1H92!D969A=6QT(&EN=&5R=F%L"B`J("`@("`@
M("`@("`@("`@("`@=7-E9"!W:6QL(&)E('1H92!O;F4@=&AA="!A<'!E87)S
M(&EN("1M86EN=%]T87-K<RX*("H@6S)=($-R96%T92!A(&1I<F5C=&]R>2!N
M86UE9"`B2$]21$5!4%`O;&EB+TUA:6YT96YA;F-E(BX*("H@6S-=($-R96%T
M92!A(&-L87-S(&5N=&ET;&5D($UA:6YT96YA;F-E7TA/4D1%05!0('1H870@
M97AT96YD<R!T:&4*("H@("`@($UA:6YT96YA;F-E(&-L87-S+@H@*B`@("`@
M5&AI<R!C;&%S<R!S:&]U;&0@8V]N=&%I;B!O;FQY('1H92!A<'!L:6-A=&EO
M;B!S<&5C:69I8R!D969I;FET:6]N<R!O9@H@*B`@("`@)&UA:6YT7W1A<VMS
M("AS964@86)O=F4@9F]R(&1E<V-R:7!T:6]N*2X*("H@("`@(%-A=F4@=&AI
M<R!F:6QE(&%S(")(3U)$14%04"]L:6(O36%I;G1E;F%N8V4O2$]21$5!4%`N
M<&AP(BX*("H@6S1=($-R96%T92!A(&1I<F5C=&]R>2!T:71L960@(DA/4D1%
M05!0+VQI8B]-86EN=&5N86YC92]487-K(BX*("H@6S5=($-R96%T92!M;V1U
M;&5S(&EN($A/4D1%05!0+VQI8B]-86EN=&5N86YC92]487-K(&YA;65D("=0
M4D5&3D%-12YP:'`G"B`J("`@("!T:&%T(&5X=&5N9"!T:&4@36%I;G1E;F%N
M8V5?5&%S:R!C;&%S<RX*("H@("`@(%1H92!C;&%S<R!S:&]U;&0@8F4@;F%M
M960@36%I;G1E;F%N8V5?5&%S:U]04D5&3D%-12X*("H@("`@(%1H92!C;&%S
M<R!S:&]U;&0@9&5C;&%R92!T:&4@9F]L;&]W:6YG('1W;R!M971H;V1S.@H@
M*B`@("`@("`G9&]-86EN=&5N86YC92<@+2!4:&ES(&ES('1H92!F=6YC=&EO
M;B!T:&%T(&ES(')U;B!T;R!D;R!T:&4*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<W!E8VEF:65D(&UA:6YT96YA;F-E(&]P97)A=&EO;BX*("H@("`@
M("`@)V1E<V-R:6)E36%I;G1E;F%N8V4G("T@5&AI<R!F=6YC=&EO;B!S971S
M('1H92!P<F5F97)E;F-E('1E>'0*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@86YD('1E>'0@=&\@8F4@=7-E9"!O;B!T:&4@8V]N9FER;6%T
M:6]N"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!A9V4N("!3
M:&]U;&0@<F5T=7)N(&$@9&5S8W)I<'1I;VX@;V8@=VAA=`H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!Y;W5R("=D;TUA:6YT96YA;F-E)R!F
M=6YC=&EO;B!I<R!A8F]U="!T;R!D;RX*("H@("`@($YE:71H97(@9G5N8W1I
M;VX@<F5Q=6ER97,@86YY('!A<F%M971E<G,@<&%S<V5D(&EN+@H@*@H@*B!4
M:&5R92!A<F4@,R!D:69F97)E;G0@='EP97,@;V8@;6%I;G1E;F%N8V4@*'-E
M="!V:6$@)%]D:7-P;&%Y7W1Y<&4I.@H@*B!;,5T@34%)3E1%3D%.0T5?3U54
M4%547T-/3D9)4DT*("H@("`@($5A8V@@;W5T<'5T(&9R;VT@9&5S8W)I8F5-
M86EN=&5N86YC92@I('=I;&P@:&%V92!A(&-H96-K8F]X(&%S<V]C:6%T960*
M("H@("`@('=I=&@@:70N($9O<B!E86-H(&-H96-K8F]X('-E;&5C=&5D+"!D
M;TUA:6YT96YA;F-E*"D@9F]R('1H870@=&%S:R!W:6QL"B`J("`@("!B92!R
M=6XN($UO<F4@=&AA;B`Q(&-O;F9I<FUA=&EO;B!M97-S86=E(&-A;B!B92!D
M:7-P;&%Y960@;VX@=&AE"B`J("`@("!M86EN=&5N86YC92!P86=E(&%T(&]N
M8V4N"B`J"B`J(%LR72!-04E.5$5.04Y#15]/5510551?04=2144*("H@("`@
M(%1H92!O=71P=70@9G)O;2!D97-C<FEB94UA:6YT96YA;F-E*"D@<VAO=6QD
M(&)E('1E>'0@87-K:6YG('1H92!U<V5R('1O"B`J("`@("!A9W)E92]D:7-A
M9W)E92!T;R!S<&5C:69I960@=&5R;7,N($EF("=Y97,G(&ES('-E;&5C=&5D
M+"!T:&4@4$]35`H@*B`@("`@=F%R:6%B;&4@)V%G<F5E)R!W:6QL(&)E('-E
M="X@268@)VYO)R!I<R!S96QE8W1E9"P@=&AE(%!/4U0@=F%R:6%B;&4*("H@
M("`@("=N;W1?86=R964G('=I;&P@8F4@<V5T+B!);B!E:71H97(@8V%S92P@
M9&]-86EN=&5N86YC92@I('=I;&P@04Q705E3(&)E"B`J("`@("!R=6XN"B`J
M("`@("`J(%1H:7,@<W1Y;&4@=VEL;"!B92!D:7-P;&%Y960@;VX@:71S(&]W
M;BP@<V5P87)A=&4@;6%I;G1E;F%N8V4@<&%G92X@*@H@*@H@*B!;,UT@34%)
M3E1%3D%.0T5?3U544%547TY/5$E#10H@*B`@("`@5&AE(&]U='!U="!F<F]M
M(&1E<V-R:6)E36%I;G1E;F%N8V4H*2!S:&]U;&0@8F4@86YY(&YO;BUI;G1E
M<F%C=&EV92!T97AT"B`J("`@("!D97-I<F5D+B!4:&5R92!W:6QL(&)E(&$@
M<VEN9VQE("=#;&EC:R!T;R!#;VYT:6YU92<@8G5T=&]N(&)E;&]W('1H:7,*
M("H@("`@('1E>'0N(&1O36%I;G1E;F%N8V4H*2!W:6QL($%,5T%94R!B92!R
M=6XN"B`J("`@("`J(%1H:7,@<W1Y;&4@=VEL;"!B92!D:7-P;&%Y960@;VX@
M:71S(&]W;BP@<V5P87)A=&4@;6%I;G1E;F%N8V4@<&%G92X@*@H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,2TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#$N,RXU"B`J($!P86-K86=E($AO
M<F1E7TUA:6YT96YA;F-E"B`J+PIC;&%S<R!-86EN=&5N86YC95]487-K('L*
M"B`@("`O*BH*("`@("`J(%1H92!S='EL92!O9B!T:&4@;6%I;G1E;F%N8V4@
M<&%G92!O=71P=70N"B`@("`@*B!0;W-S:6)L92!V86QU97,Z($U!24Y414Y!
M3D-%7T]55%!55%]#3TY&25)-+`H@("`@("H@("`@("`@("`@("`@("`@("!-
M04E.5$5.04Y#15]/5510551?04=2144L"B`@("`@*B`@("`@("`@("`@("`@
M("`@($U!24Y414Y!3D-%7T]55%!55%].3U1)0T4*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?9&ES<&QA>5]T>7!E(#T@
M34%)3E1%3D%.0T5?3U544%547T-/3D9)4DT["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!-86EN=&5N86YC95]4
M87-K*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($1O(&UA:6YT96YA
M;F-E(&]P97)A=&EO;B`H:68@:70@:&%S(&)E96X@8V]N9FER;65D*2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&UA:6YT
M96YA;F-E(&]P97)A=&EO;B!W87,@<W5C8V5S<V9U;"!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O36%I
M;G1E;F%N8V4H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!D97-C<FEP=&EO;B!I;F9O<FUA=&EO
M;B!F;W(@=&AE(&UA:6YT96YA;F-E('!A9V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@($1E<V-R:7!T:6]N('1H870@=VEL;"!B92!D:7-P;&%Y
M960@;VX@=&AE(&UA:6YT96YA;F-E"B`@("`@*B`@("`@("`@("`@("`@("`@
M8V]N9FER;6%T:6]N('!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<V-R
M:6)E36%I;G1E;F%N8V4H*0H@("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1E<VER960@;W5T<'5T
M('1Y<&4@9F]R('1H92!M86EN=&5N86YC92!P86=E+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@1&5S:7)E9"!O=71P=70@='EP92!F;W(@=&AE
M(&UA:6YT96YA;F-E(&-O;F9I<FUA=&EO;@H@("`@("H@("`@("`@("`@("`@
M("`@("!P86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$:7-P;&%Y5'EP
M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ES<&QA>5]T>7!E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I
M;VY(86YD;&5R+G!H<```````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#$W-S$R(#$P-3$U-#,T,30P(#`R,S`P,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@4V5S<VEO;DAA
M;F1L97(Z.B!D969I;F5S(&%N($%022!F;W(@:6UP;&5M96YT:6YG(&-U<W1O
M;2!S97-S:6]N"B`J(&AA;F1L97)S(&9O<B!02%`N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+G!H<"QV
M(#$N,3,N,3`N,3$@,C`P-B\P-R\Q-"`P.#HU-#HU.2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD
M;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<B!["@H@("`@+RHJ"B`@("`@
M*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@
M4V5S<VEO;DAA;F1L97(@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%-E<W-I;VY(86YD;&5R
M*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S
M('1O(')E='5R;B!A(&-O;F-R971E(%-E<W-I;VY(86YD;&5R(&EN<W1A;F-E
M(&)A<V5D(&]N"B`@("`@*B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4V5S<VEO
M;DAA;F1L97(@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!
M(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@
M<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@
M4V5S<VEO;DAA;F1L97(@:6YS=&%N8V4L(&]R"B`@("`@*B`@("`@("`@("`@
M("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@("1A<'`@
M/2`D9')I=F5R6S!=.PH@("`@("`@("`@("`D9')I=F5R(#T@)&1R:79E<ELQ
M73L*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I
M=F5R*3L*("`@("`@("!I9B`H)&1R:79E<B`]/2`G;65M8V%C:&5D)RD@>PH@
M("`@("`@("`@("`O+R!4<F%P(&9O<B!O;&0@9')I=F5R(&YA;64N"B`@("`@
M("`@("`@("1D<FEV97(@/2`G;65M8V%C:&4G.PH@("`@("`@('T*"B`@("`@
M("`@)&-L87-S(#T@)U-E<W-I;VY(86YD;&5R7R<@+B`D9')I=F5R.PH@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O
M;F-E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P
M<"D@+B`G+VQI8B]397-S:6]N2&%N9&QE<B\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EN8VQU
M9&5?;VYC92`G2&]R9&4O4V5S<VEO;DAA;F1L97(O)R`N("1D<FEV97(@+B`G
M+G!H<"<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("!I9B`H:7-?;G5L
M;"@D<&%R86US*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("=(
M;W)D92YP:'`G.PH@("`@("`@("`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG
M971$<FEV97)#;VYF:6<H)W-E<W-I;VYH86YD;&5R)RP@)&1R:79E<BD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&AA;F1L97(@/2!N97<@)&-L87-S
M*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H86YD
M;&5R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI=&EO;B!O9B`G
M("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&AA;F1L97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!397-S
M:6]N2&%N9&QE<@H@("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@
M270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@
M;F\@4V5S<VEO;DAA;F1L97(@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A
M;65T97)S"B`@("`@*B!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9397-S
M:6]N2&%N9&QE<CHZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D<FEV97(@(%-E92!397-S:6]N2&%N9&QE<CHZ9F%C=&]R>2@I
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!3964@4V5S<VEO;DAA
M;F1L97(Z.F9A8W1O<GDH*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@8W)E871E9"!C;VYC<F5T92!397-S:6]N2&%N9&QE<B!I;G-T86YC
M92P@;W(@9F%L<V4*("`@("`J("`@("`@("`@("`@("`@(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A
M;7,@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S(#T@
M87)R87DH*3L*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A
M>2@D9')I=F5R+"`D<&%R86US*2D["B`@("`@("`@:68@*&5M<'1Y*"1I;G-T
M86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;
M)'-I9VYA='5R95T@/2`F4V5S<VEO;DAA;F1L97(Z.F9A8W1O<GDH)&1R:79E
M<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A
M;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@("`J($]P96X@
M=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B
M<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V%V95]P871H
M("`@("!4:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE8W0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N86UE(&]F('1H92!S
M97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&]P96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M92D*("`@('L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E
M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E860@=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA
M<B!S97-S:6]N(&ED96YT:69I97(@9G)O;2!T:&4*("`@("`J(%-E<W-I;VY(
M86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT
M:69I97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S
M:6]N(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!S=7!P
M;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO
M;B!D871A('1O('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE('-E<W-I;VX@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W
M<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A('!A<G1I
M8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E
M;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*").;W0@<W5P<&]R=&5D+B(I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M
M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!A
M8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AL:69E
M=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@
M;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X;&EF971I
M;64@/2`S,#`I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B3F]T('-U<'!O<G1E9"XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$971E<FUI;F5S(&EF(&$@<V5S<VEO;B!B96QO;F=S('1O(&%N(&%U=&AE
M;G1I8V%T960@=7-E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H
M92!S97-S:6]N(&1A=&$@:71S96QF+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)')E='5R;E]U<V5R("!)9B!T<G5E+"!R971U<FX@=&AE('5S97(@<V5S<VEO
M;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQS=')I;F<@
M(%1R=64@;W(@=&AE('5S97(G<R!S97-S:6]N(&1A=&$@:68@=&AE('-E<W-I
M;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&)E;&]N9W,@=&\@
M86X@875T:&5N=&EC871E9"!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M:7-!=71H96YT:6-A=&5D*"1S97-S:6]N7V1A=&$L("1R971U<FY?9&%T82`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<V5S<VEO;E]D871A
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!W:&EL92`H)'-E<W-I;VY?9&%T82D@>PH@("`@("`@("`@("`D=F%R
M<R`](&5X<&QO9&4H)WPG+"`D<V5S<VEO;E]D871A+"`R*3L*("`@("`@("`@
M("`@)&1A=&$@/2!U;G-E<FEA;&EZ92@D=F%R<ULQ72D["B`@("`@("`@("`@
M(&EF("@D=F%R<ULP72`]/2`G7U]A=71H)RD@>PH@("`@("`@("`@("`@("`@
M:68@*&5M<'1Y*"1D871A*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@A96UP='DH)&1A=&%;)V%U=&AE;G1I8V%T960G72DI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E='5R;E]D871A(#\@)&1A=&$@.B!T<G5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S97-S:6]N7V1A=&$@
M/2!S=6)S='(H)'-E<W-I;VY?9&%T82P@<W1R;&5N*"1V87)S6S!=*2`K('-T
M<FQE;BAS97)I86QI>F4H)&1A=&$I*2`K(#$I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@=&AE('9A;&ED('-E<W-I
M;VX@:61E;G1I9FEE<G,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I
M;VX@:61E;G1I9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I
M;VY)1',H*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DYO="!S=7!P;W)T960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5T97)M:6YE('1H92!N=6UB97(@;V8@8W5R<F5N=&QY(&QO9V=E9"!I;B!U
M<V5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($$@8V]U;G0@
M;V8@;&]G9V5D(&EN('5S97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N
M=$%U=&AE;G1I8V%T9615<V5R<R@I"B`@("!["B`@("`@("`@)&-O=6YT(#T@
M,#L*"B`@("`@("`@)'-E<W-I;VYS(#T@)'1H:7,M/F=E=%-E<W-I;VY)1',H
M*3L*("`@("`@("!I9B`H:7-?82@D<V5S<VEO;G,L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1S97-S:6]N<R!A<R`D:60I('L*("`@("`@("`@
M("`@)&1A=&$@/2`D=&AI<RT^<F5A9"@D:60I.PH@("`@("`@("`@("!I9B`H
M(6ES7V$H)&1A=&$L("=014%27T5R<F]R)RD@)B8*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:7-!=71H96YT:6-A=&5D*"1D871A*2D@>PH@("`@("`@("`@
M("`@("`@)&-O=6YT*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8V]U;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@;&ES="!O9B!C=7)R96YT;'D@;&]G9V5D(&EN('5S97)S+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!L;V=G960@:6X@
M=7-E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!=71H96YT:6-A=&5D
M57-E<G,H)&1A=&4@/2!F86QS92D*("`@('L*("`@("`@("`D=7-E<G,@/2!A
M<G)A>2@I.PH*("`@("`@("`D<V5S<VEO;G,@/2`D=&AI<RT^9V5T4V5S<VEO
M;DE$<R@I.PH@("`@("`@(&EF("AI<U]A*"1S97-S:6]N<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@("`@
M('T*"B`@("`@("`@9F]R96%C:"`H)'-E<W-I;VYS(&%S("1I9"D@>PH@("`@
M("`@("`@("`D9&%T82`]("1T:&ES+3YR96%D*"1I9"D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^7VES075T:&5N=&EC871E9"@D9&%T82P@=')U92D["B`@
M("`@("`@("`@(&EF("@D9&%T82`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("1U<V5R(#T@)&1A=&%;)W5S97))9"==.PH@("`@("`@("`@("`@("`@
M:68@*"1D871E*2!["B`@("`@("`@("`@("`@("`@("`@)'5S97(@/2!D871E
M*"=R)RP@)&1A=&%;)W1I;65S=&%M<"==*2`N("<@("<@+B`D=7-E<CL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1U<V5R<UM=(#T@)'5S
M97(["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=7-E<G,["B`@("!]"@I]"@``````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]&;W)M+G!H<```````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#,R-#8U,B`Q,#4Q-30S-#$T,"`P,C`W-C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J($AO<F1E7T9O<FT@36%S=&5R($-L87-S+@H@*@H@*B!4:&4@
M2&]R9&5?1F]R;3HZ('!A8VMA9V4@<')O=FED97,@9F]R;2!R96YD97)I;F<L
M('9A;&ED871I;VXL(&%N9`H@*B!O=&AE<B!F=6YC=&EO;F%L:71Y(&9O<B!T
M:&4@2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]&;W)M+T9O<FTN<&AP+'8@,2XS,#8N,BXT."`R,#`V+S`T
M+S(V(#$U.C4R.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR
M,#`V(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M
M/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]B
M97)T($4N($-O>6QE(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC
M;&%S<R!(;W)D95]&;W)M('L*"B`@("!V87(@)%]N86UE(#T@)R<["B`@("!V
M87(@)%]T:71L92`]("<G.PH@("`@=F%R("1?97AT<F$@/2`G)SL*("`@('9A
M<B`D7W9A<G,["B`@("!V87(@)%]S=6)M:70@/2!A<G)A>2@I.PH@("`@=F%R
M("1?<F5S970@/2!F86QS93L*("`@('9A<B`D7V5R<F]R<R`](&%R<F%Y*"D[
M"B`@("!V87(@)%]S=6)M:71T960@/2!N=6QL.PH@("`@=F%R("1?<V5C=&EO
M;G,@/2!A<G)A>2@I.PH@("`@=F%R("1?;W!E;E]S96-T:6]N(#T@;G5L;#L*
M("`@('9A<B`D7V-U<G)E;G1396-T:6]N(#T@87)R87DH*3L*("`@('9A<B`D
M7W9A<FEA8FQE<R`](&%R<F%Y*"D["B`@("!V87(@)%]H:61D96Y687)I86)L
M97,@/2!A<G)A>2@I.PH@("`@=F%R("1?=7-E1F]R;51O:V5N(#T@=')U93L*
M("`@('9A<B`D7V%U=&]F:6QL960@/2!F86QS93L*("`@('9A<B`D7V5N8W1Y
M<&4@/2!N=6QL.PH@("`@=F%R("1?:&5L<"`](&9A;'-E.PH*("`@(&9U;F-T
M:6]N($AO<F1E7T9O<FTH)B1V87)S+"`D=&ET;&4@/2`G)RP@)&YA;64@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@
M("`@("`@("`D;F%M92`](%-T<FEN9SHZ;&]W97(H9V5T7V-L87-S*"1T:&ES
M*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W9A<G,@/2`F)'9A<G,[
M"B`@("`@("`@)'1H:7,M/E]T:71L92`]("1T:71L93L*("`@("`@("`D=&AI
M<RT^7VYA;64@/2`D;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1F;W)M+"`F)'9A<G,L("1T:71L92`]("<G+"`D;F%M92`](&YU;&PI
M"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@("`@("1S
M:6=N871U<F4@/2!S97)I86QI>F4H87)R87DH)&9O<FTL("1V87)S+"`D=&ET
M;&4L("1N86UE*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1F
M;W)M*2D@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72`]("9N97<@)&9O<FTH)'9A<G,L("1T:71L92P@)&YA;64I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E72`]("9N97<@2&]R9&5?1F]R;2@D=F%R<RP@)'1I=&QE+"`D;F%M
M92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*("`@(&9U;F-T:6]N('-E
M=%9A<G,H)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<R`]("8D
M=F%R<SL*("`@('T*"B`@("!F=6YC=&EO;B!G9714:71L92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=&ET;&4["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T5&ET;&4H)'1I=&QE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&ET
M;&4@/2`D=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T17AT<F$H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V5X=')A.PH@("`@?0H*("`@
M(&9U;F-T:6]N('-E=$5X=')A*"1E>'1R82D*("`@('L*("`@("`@("`D=&AI
M<RT^7V5X=')A(#T@)&5X=')A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$YA
M;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VYA;64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3971S(&]R(&=E=',@=VAE=&AE<B!T:&4@9F]R
M;2!S:&]U;&0@8F4@=F5R:69I960@8GD@=&]K96YS+@H@("`@("H@5&]K96YS
M(&%R92!U<V5D('1O('9E<FEF>2!T:&%T(&$@9F]R;2!I<R!O;FQY('-U8FUI
M='1E9"!O;F-E+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1T;VME
M;B`@268@<W!E8VEF:65D+"!S971S('=H971H97(@=&\@=7-E(&9O<FT@=&]K
M96YS+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!F
M;W)M('1O:V5N<R!A<F4@8F5I;F<@=7-E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7-E5&]K96XH)'1O:V5N(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)'1O:V5N*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W5S949O
M<FU4;VME;B`]("1T;VME;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=7-E1F]R;51O:V5N.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M('1H92!R96YD97)E<B!F;W(@=&AI<R!F;W)M+"!E:71H97(@82!C=7-T;VT@
M<F5N9&5R97(@;W(@=&AE"B`@("`@*B!S=&%N9&%R9"!O;F4N"B`@("`@*@H@
M("`@("H@5&\@=7-E(&$@8W5S=&]M(&9O<FT@<F5N9&5R97(L('EO=7(@9F]R
M;2!C;&%S<R!N965D<R!T;PH@("`@("H@;W9E<G)I9&4@=&AI<R!F=6YC=&EO
M;CH*("`@("`J(#QC;V1E/@H@("`@("H@9G5N8W1I;VX@)F=E=%)E;F1E<F5R
M*"D*("`@("`J('L*("`@("`J("`@("`D<B`]("9N97<@0W5S=&]M1F]R;5)E
M;F1E<F5R*"D["B`@("`@*B`@("`@<F5T=7)N("1R.PH@("`@("H@?0H@("`@
M("H@/"]C;V1E/@H@("`@("H*("`@("`J("XN+B!W:&5R92!#=7-T;VU&;W)M
M4F5N9&5R97(@:7,@=&AE(&-L87-S;F%M92!O9B!T:&4@8W5S=&]M"B`@("`@
M*B!R96YD97)E<B!C;&%S<RP@=VAI8V@@<VAO=6QD(&5X=&5N9"!(;W)D95]&
M;W)M7U)E;F1E<F5R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!(&AA<V@@;V8@<F5N9&5R97(M<W!E8VEF:6,@<&%R86UE=&5R<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="!(;W)D95]&;W)M7U)E;F1E
M<F5R("!4:&4@9F]R;2!R96YD97)E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E=%)E;F1E<F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH@("`@
M("`@("1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@D<&%R
M86US*3L*("`@("`@("!R971U<FX@)')E;F1E<F5R.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9G9714>7!E*"1T>7!E+"`D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D='EP95]C;&%S<R`]("=(;W)D95]&;W)M7U1Y<&5?)R`N
M("1T>7!E.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1T>7!E7V-L87-S
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@
M("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9B@G3F]N97AI<W1A;G0@8VQA<W,@(B5S(B!F;W(@9FEE;&0@='EP92`B)7,B
M)RP@)'1Y<&5?8VQA<W,L("1T>7!E*2DL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@?0H@("`@("`@("1T>7!E7V]B(#T@)FYE=R`D='EP95]C;&%S
M<R@I.PH@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D='EP
M95]O8BP@)VEN:70G*2P@)'!A<F%M<RD["B`@("`@("`@<F5T=7)N("1T>7!E
M7V]B.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-E8W1I;VXH)'-E8W1I;VX@
M/2`G)RP@)&1E<V,@/2`G)RP@)&EM86=E(#T@)R<L("1E>'!A;F1E9"`]('1R
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]C=7)R96YT4V5C=&EO;B`]("1S
M96-T:6]N.PH@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]S96-T:6]N<RD@
M)B8@(21T:&ES+3YG971/<&5N4V5C=&EO;B@I*2!["B`@("`@("`@("`@("1T
M:&ES+3YS971/<&5N4V5C=&EO;B@D<V5C=&EO;BD["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=D97-C)UT@/2`D9&5S
M8SL*("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG97AP86YD
M960G72`]("1E>'!A;F1E9#L*("`@("`@("`D=&AI<RT^7W-E8W1I;VYS6R1S
M96-T:6]N75LG:6UA9V4G72`]("1I;6%G93L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971396-T:6]N1&5S8R@D<V5C=&EO;BD*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]S96-T:6]N<ULD<V5C=&EO;EU;)V1E<V,G73L*("`@('T*
M"B`@("!F=6YC=&EO;B!G971396-T:6]N26UA9V4H)'-E8W1I;VXI"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5C=&EO;G-;)'-E8W1I;VY=6R=I
M;6%G92==.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$]P96Y396-T:6]N*"1S
M96-T:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=?7V9O
M<FU/<&5N4V5C=&EO;B<L("1S96-T:6]N*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971/<&5N4V5C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?=F%R<RT^9V5T*"=?7V9O<FU/<&5N4V5C=&EO;B<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=%-E8W1I;VY%>'!A;F1E9%-T871E*"1S96-T:6]N+"`D
M8F]O;&5A;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D8F]O;&5A;BD@
M>PH@("`@("`@("`@("`O*B!/;FQY('1H92!B;V]L96%N('9A;'5E(&ES(')E
M<75I<F5D+B`J+PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S96-T:6]N
M<ULD<V5C=&EO;EU;)V5X<&%N9&5D)UT["B`@("`@("`@?0H*("`@("`@("`O
M*B!.965D('1O(')E='5R;B!T:&4@=F%L=65S(&9O<B!U<V4@:6X@<W1Y;&5S
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-E8W1I;VYS6R1S96-T:6]N75LG
M97AP86YD960G72D@>PH@("`@("`@("`@("!R971U<FX@)V)L;V-K)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)VYO;F4G.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F%D9%9A<FEA8FQE*"1H=6UA;DYA;64L("1V87).86UE+"`D
M='EP92P@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M96%D;VYL>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^:6YS97)T5F%R:6%B;&5"969O<F4H;G5L
M;"P@)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D+"`D<F5A
M9&]N;'DL("1D97-C<FEP=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B`F:6YS97)T5F%R:6%B
M;&5"969O<F4H)&)E9F]R92P@)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E
M9"P@)')E861O;FQY(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<V-R:7!T:6]N(#T@;G5L;"P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)'1Y<&4@/2`F)'1H:7,M/F=E=%1Y<&4H
M)'1Y<&4L("1P87)A;7,I.PH@("`@("`@("1V87(@/2`F;F5W($AO<F1E7T9O
M<FU?5F%R:6%B;&4H)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5D
M+"`D<F5A9&]N;'DL("1D97-C<FEP=&EO;BD["@H@("`@("`@("\J(%-E="!T
M:&4@9F]R;2!O8FIE8W0@<F5F97)E;F-E(&EN('1H92!V87(N("HO"B`@("`@
M("`@)'9A<BT^<V5T1F]R;4]B*"1T:&ES*3L*"B`@("`@("`@:68@*"1V87(M
M/F=E=%1Y<&5.86UE*"D@/3T@)V5N=6TG("8F"B`@("`@("`@("`@(&-O=6YT
M*"1V87(M/F=E=%9A;'5E<R@I*2`]/2`Q*2!["B`@("`@("`@("`@("1V86QS
M(#T@87)R87E?:V5Y<R@D=F%R+3YG971686QU97,H*2D["B`@("`@("`@("`@
M("1T:&ES+3Y?=F%R<RT^861D*"1V87(M/G9A<DYA;64L("1V86QS6S!=*3L*
M("`@("`@("`@("`@)'9A<BT^7V%U=&]F:6QL960@/2!T<G5E.PH@("`@("`@
M('T@96QS96EF("@D=F%R+3YG9714>7!E3F%M92@I(#T]("=F:6QE)R!\?`H@
M("`@("`@("`@("`@("`@("`D=F%R+3YG9714>7!E3F%M92@I(#T]("=I;6%G
M92<I('L*("`@("`@("`@("`@)'1H:7,M/E]E;F-T>7!E(#T@)VUU;'1I<&%R
M="]F;W)M+61A=&$G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;BDI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;B`]("=?7V)A<V4G.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&ES7VYU;&PH)&)E9F]R92DI('L*("`@("`@("`@("`@)'1H:7,M/E]V
M87)I86)L97-;)'1H:7,M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N=6T@/2`P.PH@("`@("`@
M("`@("!W:&EL92`H:7-S970H)'1H:7,M/E]V87)I86)L97-;)'1H:7,M/E]C
M=7)R96YT4V5C=&EO;EU;)&YU;5TI("8F"B`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N75LD;G5M
M72T^9V5T5F%R3F%M92@I("$]("1B969O<F4I('L*("`@("`@("`@("`@("`@
M("1N=6TK*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I;VY=6R1N
M=6U=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;EU;72`]("8D=F%R.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]V87)I86)L97-;)'1H
M:7,M/E]C=7)R96YT4V5C=&EO;ET@/2!A<G)A>5]M97)G92@*("`@("`@("`@
M("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA8FQE<ULD=&AI
M<RT^7V-U<G)E;G1396-T:6]N72P@,"P@)&YU;2DL"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH)B1V87(I+`H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W-L:6-E*"1T:&ES+3Y?=F%R:6%B;&5S6R1T:&ES+3Y?8W5R<F5N=%-E8W1I
M;VY=+"`D;G5M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=F%R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M('9A<FEA8FQE(&9R;VT@=&AE(&9O<FTN"B`@("`@*@H@("`@("H@07,@;VYL
M>2!V87)I86)L97,@8V%N(&)E('!A<W-E9"!B>2!R969E<F5N8V4L('EO=2!N
M965D('1O(&-A;&P@=&AI<PH@("`@("H@;65T:&]D('1H:7,@=V%Y(&EF('=A
M;G0@=&\@<&%S<R!A('9A<FEA8FQE(&YA;64Z"B`@("`@*B`\8V]D93X*("`@
M("`J("1F;W)M+3YR96UO=F5687)I86)L92@D=F%R(#T@)W9A<FYA;64G*3L*
M("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R
M;5]687)I86)L97QS=')I;F<@)'9A<B`@16ET:&5R('1H92!V87)I86)L92=S
M(&YA;64@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@=F%R:6%B;&4@=&\@<F5M;W9E(&9R;VT@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AE('9A<FEA8FQE('=A<R!F;W5N9"`H86YD(&1E;&5T960I+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96UO=F5687)I86)L92@F)'9A<BD*("`@('L*("`@
M("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?=F%R:6%B;&5S*2!A
M<R`D<V5C=&EO;BD@>PH@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES
M*"1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N72D@87,@)&DI('L*("`@("`@
M("`@("`@("`@(&EF("@H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L
M92<I("8F("1T:&ES+3Y?=F%R:6%B;&5S6R1S96-T:6]N75LD:5T@/3T]("1V
M87(I('Q\"B`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3Y?=F%R:6%B;&5S
M6R1S96-T:6]N75LD:5TM/F=E=%9A<DYA;64H*2`]/2`D=F%R*2D@>PH@("`@
M("`@("`@("`@("`@("`@("\O(%-L:6-E(&]U="!T:&4@=F%R:6%B;&4@=&\@
M8F4@<F5M;W9E9"X*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A<FEA
M8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72`](&%R<F%Y7VUE<F=E*`H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A
M<FEA8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@,"P@)&DI+`H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]S;&EC92@D=&AI<RT^7W9A<FEA
M8FQE<ULD=&AI<RT^7V-U<G)E;G1396-T:6]N72P@)&D@*R`Q*2D["@H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9A9&1(:61D96XH)&AU;6%N3F%M92P@)'9A<DYA;64L("1T>7!E
M+"`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("1R96%D;VYL
M>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M='EP92`]("8D=&AI<RT^9V5T5'EP92@D='EP92P@)'!A<F%M<RD["B`@("`@
M("`@)'9A<B`]("9N97<@2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE
M+"`D=F%R3F%M92P@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5Q=6ER960L("1R96%D;VYL>2P@)&1E<V-R:7!T
M:6]N*3L*("`@("`@("`D=F%R+3YH:61E*"D["B`@("`@("`@)'1H:7,M/E]H
M:61D96Y687)I86)L97-;72`]("8D=F%R.PH@("`@("`@(')E='5R;B`D=F%R
M.PH@("`@?0H*("`@(&9U;F-T:6]N("9G971687)I86)L97,H)&9L870@/2!T
M<G5E+"`D=VET:$AI9&1E;B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D
M9FQA="D@>PH@("`@("`@("`@("`D=F%R<R`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?=F%R:6%B;&5S(&%S("1S96-T:6]N*2![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<V5C=&EO;B!A<R`D=F%R*2![
M"B`@("`@("`@("`@("`@("`@("`@)'9A<G-;72`]("1V87(["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1W:71H
M2&ED9&5N*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI
M9&1E;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@
M)'9A<G-;72`]("1V87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N("1V87)S.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A<FEA8FQE<SL*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T0G5T=&]N<R@D<W5B;6ET+"`D
M<F5S970@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)'-U8FUI="`]/3T@
M=')U92!\?"!I<U]N=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S=6)M:70I*2![
M"B`@("`@("`@("`@("\J($1E9F%U;'0@=&\@)U-U8FUI="<N("HO"B`@("`@
M("`@("`@("1S=6)M:70@/2!A<G)A>2A?*")3=6)M:70B*2D["B`@("`@("`@
M?2!E;'-E:68@*"%I<U]A<G)A>2@D<W5B;6ET*2D@>PH@("`@("`@("`@("`O
M*B!$969A=6QT('1O(&%R<F%Y(&EF(&YO="!P87-S960N("HO"B`@("`@("`@
M("`@("1S=6)M:70@/2!A<G)A>2@D<W5B;6ET*3L*("`@("`@("!]"B`@("`@
M("`@+RH@3VYL>2!I9B`D<F5S970@:7,@<W1R:6-T;'D@=')U92!I;G-E<G0@
M9&5F875L="`G4F5S970G+B`J+PH@("`@("`@(&EF("@D<F5S970@/3T]('1R
M=64I('L*("`@("`@("`@("`@)')E<V5T(#T@7R@B4F5S970B*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET(#T@)'-U8FUI=#L*("`@("`@
M("`D=&AI<RT^7W)E<V5T(#T@)')E<V5T.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&%P<&5N9$)U='1O;G,H)'-U8FUI="D*("`@('L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1S=6)M:70I*2!["B`@("`@("`@("`@("1S=6)M:70@/2!A<G)A
M>2@D<W5B;6ET*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<W5B;6ET
M(#T@87)R87E?;65R9V4H)'1H:7,M/E]S=6)M:70L("1S=6)M:70I.PH@("`@
M?0H*("`@(&9U;F-T:6]N('!R97-E<G9E5F%R0GE0;W-T*"8D=F%R<RP@)'9A
M<FYA;64L("1A;'1?=F%R;F%M92`]("<G*0H@("`@>PH@("`@("`@("1V86QU
M92`]("1V87)S+3YG971%>&ES=',H)'9A<FYA;64L("1W87-S970I.PH*("`@
M("`@("`O*B!)9B!A;B!A;'1E<FYA=&4@;F%M92!I<R!G:79E;B!U;F1E<B!W
M:&EC:"!T;R!P<F5S97)V92!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H)&%L
M=%]V87)N86UE*2!["B`@("`@("`@("`@("1V87)N86UE(#T@)&%L=%]V87)N
M86UE.PH@("`@("`@('T*"B`@("`@("`@:68@*"1W87-S970I('L*("`@("`@
M("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S="@D=F%R;F%M92P@)'9A
M;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!R97-E<G9E5F%R0GE0
M;W-T*"1V87)N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S
M("1I9"`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R97-E
M<G9E5F%R0GE0;W-T*"1V87)N86UE("X@)ULG("X@)&ED("X@)UTG+"`D=F%L
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1V87)N86UE(#T@:'1M;'-P96-I86QC:&%R<R@D=F%R;F%M92D["B`@("`@
M("`@("`@("1V86QU92`](&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*3L*("`@
M("`@("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E
M<R(@=F%L=64](B5S(B`O/B<@+B`B7&XB+`H@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`D=F%L=64I.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!O<&5N*"8D<F5N9&5R97(L("8D=F%R
M<RP@)&%C=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y<&4I("8F("%I<U]N
M=6QL*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@("`@)&5N8W1Y<&4@
M/2`D=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@("`@("1R96YD97)E
M<BT^;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^7VYA;64L("1E;F-T
M>7!E*3L*("`@("`@("`D<F5N9&5R97(M/FQI<W1&;W)M5F%R<R@D=&AI<RD[
M"@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N86UE*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!R97-E<G9E5F%R0GE0;W-T*"=F;W)M;F%M92<L("1T
M:&ES+3Y?;F%M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]U
M<V5&;W)M5&]K96XI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]4;VME;BYP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7W!R97-E<G9E5F%R
M0GE0;W-T*"=?7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE+"!(;W)D95]4
M;VME;CHZ9V5N97)A=&5)9"@D=&AI<RT^7VYA;64I*3L*("`@("`@("!]"@H@
M("`@("`@("\J($QO;W`@=&AR;W5G:"!V87)S(&%N9"!C:&5C:R!F;W(@86YY
M('-P96-I86P@8V%S97,@=&\@<')E<V5R=F4N("HO"B`@("`@("`@)'9A<FEA
M8FQE<R`]("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H
M("@D=F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@+RH@4')E<V5R
M=F4@=F%L=64@:68@8VAA;F=E(&AA<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@
M("`@("`@("!I9B`H)'9A<BT^9V5T3W!T:6]N*"=T<F%C:V-H86YG92<I*2![
M"B`@("`@("`@("`@("`@("`D=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D
M=F%R<RP@)'9A<FYA;64L("=?7V]L9%\G("X@)'9A<FYA;64I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI
M9&1E;E9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP
M<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@8VQO<V4H)B1R96YD97)E
M<BD*("`@('L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"D["B`@("!]"@H@
M("`@9G5N8W1I;VX@<F5N9&5R06-T:79E*"8D<F5N9&5R97(L("8D=F%R<RP@
M)&%C=&EO;BP@)&UE=&AO9"`]("=G970G+"`D96YC='EP92`](&YU;&PL("1F
M;V-U<R`]('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&5N8W1Y
M<&4I("8F("%I<U]N=6QL*"1T:&ES+3Y?96YC='EP92DI('L*("`@("`@("`@
M("`@)&5N8W1Y<&4@/2`D=&AI<RT^7V5N8W1Y<&4["B`@("`@("`@?0H@("`@
M("`@("1R96YD97)E<BT^;W!E;B@D86-T:6]N+"`D;65T:&]D+"`D=&AI<RT^
M9V5T3F%M92@I+"`D96YC='EP92D["B`@("`@("`@)')E;F1E<F5R+3YL:7-T
M1F]R;59A<G,H)'1H:7,I.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M;F%M92DI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S
M="@G9F]R;6YA;64G+"`D=&AI<RT^7VYA;64I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3Y?=7-E1F]R;51O:V5N*2!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O5&]K96XN<&AP)SL*("`@("`@("`@("`@)'1H
M:7,M/E]P<F5S97)V959A<D)Y4&]S="@G7U]F;W)M5&]K96Y?)R`N("1T:&ES
M+3Y?;F%M92P@2&]R9&5?5&]K96XZ.F=E;F5R871E260H)'1H:7,M/E]N86UE
M*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]S96-T
M:6]N<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]P<F5S97)V959A<D)Y4&]S
M="@G7U]F;W)M3W!E;E-E8W1I;VXG+"`D=&AI<RT^9V5T3W!E;E-E8W1I;VXH
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=F%R<R!A
M;F0@8VAE8VL@9F]R(&%N>2!S<&5C:6%L(&-A<V5S('1O"B`@("`@("`@("H@
M<')E<V5R=F4N("HO"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG9716
M87)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V
M87(I('L*("`@("`@("`@("`@+RH@4')E<V5R=F4@=F%L=64@:68@8VAA;F=E
M(&AA<R!T;R!B92!T<F%C:V5D+B`J+PH@("`@("`@("`@("!I9B`H)'9A<BT^
M9V5T3W!T:6]N*"=T<F%C:V-H86YG92<I*2!["B`@("`@("`@("`@("`@("`D
M=F%R;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64L("=?
M7V]L9%\G("X@)'9A<FYA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAI9&1E;E9A<FEA8FQE<R!A<R`D
M=F%R*2!["B`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D
M=F%R<RP@)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"@H@("`@("`@
M("1R96YD97)E<BT^8F5G:6Y!8W1I=F4H)'1H:7,M/F=E=%1I=&QE*"DL("1T
M:&ES+3YG971%>'1R82@I*3L*("`@("`@("`D<F5N9&5R97(M/G)E;F1E<D9O
M<FU!8W1I=F4H)'1H:7,L("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/G-U
M8FUI="@D=&AI<RT^7W-U8FUI="P@)'1H:7,M/E]R97-E="D["B`@("`@("`@
M)')E;F1E<F5R+3YE;F0H*3L*("`@("`@("`D<F5N9&5R97(M/F-L;W-E*"1F
M;V-U<RD["B`@("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R26YA8W1I=F4H)B1R
M96YD97)E<BP@)'9A<G,I"B`@("!["B`@("`@("`@)')E;F1E<F5R+3YB96=I
M;DEN86-T:79E*"1T:&ES+3YG9714:71L92@I+"`D=&AI<RT^9V5T17AT<F$H
M*2D["B`@("`@("`@)')E;F1E<F5R+3YR96YD97)&;W)M26YA8W1I=F4H)'1H
M:7,L("1V87)S*3L*("`@("`@("`D<F5N9&5R97(M/F5N9"@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('!R97-E<G9E*"1V87)S*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^7W5S949O<FU4;VME;BD@>PH@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?
M<')E<V5R=F5687)">5!O<W0H)U]?9F]R;51O:V5N7R<@+B`D=&AI<RT^7VYA
M;64L($AO<F1E7U1O:V5N.CIG96YE<F%T94ED*"1T:&ES+3Y?;F%M92DI.PH@
M("`@("`@('T*"B`@("`@("`@)'9A<FEA8FQE<R`]("1T:&ES+3YG971687)I
M86)L97,H*3L*("`@("`@("!F;W)E86-H("@D=F%R:6%B;&5S(&%S("1V87(I
M('L*("`@("`@("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).86UE*"D[
M"@H@("`@("`@("`@("`O*B!3879E('9A;'5E(&]F(&EN9&EV:61U86P@8V]M
M<&]N96YT<RX@*B\*("`@("`@("`@("`@<W=I=&-H("@D=F%R+3YG9714>7!E
M3F%M92@I*2!["B`@("`@("`@("`@(&-A<V4@)W!A<W-W;W)D8V]N9FER;2<Z
M"B`@("`@("`@("`@(&-A<V4@)V5M86EL8V]N9FER;2<Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE
M("X@)UMO<FEG:6YA;%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S
M97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6V-O;F9I<FU=)RD[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VUO
M;G1H>65A<B<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^<')E<V5R=F5687)"
M>5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMM;VYT:%TG*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA
M;64@+B`G6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)VUO;G1H9&%Y>65A<B<Z"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<')E<V5R=F5687)">5!O<W0H)'9A<G,L("1V87)N86UE("X@)UMM
M;VYT:%TG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F5S97)V959A<D)Y
M4&]S="@D=F%R<RP@)'9A<FYA;64@+B`G6V1A>5TG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP<F5S97)V959A<D)Y4&]S="@D=F%R<RP@)'9A<FYA;64@
M+B`G6WEE87)=)RD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V
M87)S+"`D=F%R;F%M92D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?:&ED9&5N5F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@
M)'1H:7,M/G!R97-E<G9E5F%R0GE0;W-T*"1V87)S+"`D=F%R+3YG971687).
M86UE*"DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!U;G-E=%9A
M<G,H)B1V87)S*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YG9716
M87)I86)L97,H*2!A<R`D=F%R*2!["B`@("`@("`@("`@("1V87)S+3YR96UO
M=F4H)'9A<BT^9V5T5F%R3F%M92@I*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$;V5S('1H92!A8W1I;VX@;V8@=F%L:61A=&EN9R!T:&4@
M9F]R;2P@8VAE8VMI;F<@:68@:70@<F5A;&QY(&AA<R!B965N"B`@("`@*B!S
M=6)M:71T960@8GD@8V%L;&EN9R!I<U-U8FUI='1E9"@I(&%N9"!I9B!T<G5E
M(&1O97,@86YY(&]N4W5B;6ET*"D*("`@("`J(&-A;&QS(&9O<B!V87(@='EP
M97,@:6X@=&AE(&9O<FTN(%1H92!?<W5B;6ET=&5D('9A<B!I<R!T:&5N(')E
M8VAE8VME9"X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?5F%R:6%B;&5S
M("1V87)S"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("`@("`@("1C86Y!=71O
M9FEL;"`@0V%N('1H92!F;W)M(&)E('9A;&ED('=I=&AO=70*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B96EN9R!S=6)M
M:71T960_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H92!F;W)M(&ES('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!V86QI
M9&%T92@F)'9A<G,L("1C86Y!=71O1FEL;"`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\J($=E="!S=6)M:71T960@<W1A='5S+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^:7-3=6)M:71T960H*2!\?"`D8V%N075T;T9I;&PI('L*("`@("`@
M("`@("`@+RH@1F]R;2!W87,@<W5B;6ET=&5D(&]R(&-A;B!A=71O9FEL;#L@
M8VAE8VL@9F]R(&%N>2!V87)I86)L90H@("`@("`@("`@("`@*B!T>7!E<R<@
M;VY3=6)M:70H*2X@*B\*("`@("`@("`@("`@)'1H:7,M/F]N4W5B;6ET*"1V
M87)S*3L*"B`@("`@("`@("`@("\J(%)E8VAE8VL@<W5B;6ET=&5D('-T871U
M<RX@*B\*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-3=6)M:71T960H*2`F
M)B`A)&-A;D%U=&]&:6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O*B!&;W)M(&AA<R!N;W0@8F5E;B!S=6)M:71T960[(')E='5R;B!F86QS
M92X@*B\*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)&UE<W-A9V4@/2`G)SL*("`@("`@("`D=&AI<RT^7V%U=&]F:6QL
M960@/2!T<G5E.PH*("`@("`@("!I9B`H)'1H:7,M/E]U<V5&;W)M5&]K96XI
M('L*("`@("`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U1O:V5N+G!H<"<["B`@("`@("`@("`@(&EF("AI
M<W-E="@D8V]N9ELG=&]K96XG72DI('L*("`@("`@("`@("`@("`@("\J($EF
M('1H97)E(&ES(&$@8V]N9FEG=7)E9"!T;VME;B!S>7-T96TL('-E="!I="!U
M<"X@*B\*("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4
M;VME;CHZ<VEN9VQE=&]N*"1C;VYF6R=T;VME;B==6R=D<FEV97(G72P@2&]R
M9&4Z.F=E=$1R:79E<D-O;F9I9R@G=&]K96XG+"`D8V]N9ELG=&]K96XG75LG
M9')I=F5R)UTI*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\J($1E9F%U;'0@=&\@=&AE(&9I;&4@<WES=&5M(&EF(&YO(&-O;F9I
M9RX@*B\*("`@("`@("`@("`@("`@("1T;VME;E-O=7)C92`]("9(;W)D95]4
M;VME;CHZ<VEN9VQE=&]N*"=F:6QE)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"$D=&]K96Y3;W5R8V4M/G9E<FEF>2@D=F%R<RT^9V5T*"=?
M7V9O<FU4;VME;E\G("X@)'1H:7,M/E]N86UE*2DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==(#T@7R@B5&AI<R!F
M;W)M(&AA<R!A;')E861Y(&)E96X@<')O8V5S<V5D+B(I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&AI<RT^9V5T5F%R
M:6%B;&5S*"D@87,@)'9A<BD@>PH@("`@("`@("`@("`D=&AI<RT^7V%U=&]F
M:6QL960@/2`D=F%R+3Y?875T;V9I;&QE9"`F)B`D=&AI<RT^7V%U=&]F:6QL
M960["B`@("`@("`@("`@(&EF("@A)'9A<BT^=F%L:61A=&4H)'9A<G,L("1M
M97-S86=E*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<G-;)'9A
M<BT^9V5T5F%R3F%M92@I72`]("1M97-S86=E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]A=71O9FEL;&5D*2!["B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?97)R;W)S6R=?7V9O<FU4;VME;B==
M*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:&ED9&5N
M5F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@:68@*"$D=F%R+3YV
M86QI9&%T92@D=F%R<RP@)&UE<W-A9V4I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V5R<F]R<ULD=F%R+3YG971687).86UE*"E=(#T@)&UE<W-A9V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^:7-686QI9"@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L96%R5F%L:61A
M=&EO;B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O<G,@/2!A<G)A>2@I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5R<F]R*"1V87(I"B`@("!["B`@
M("`@("`@:68@*&ES7V$H)'9A<BP@)TAO<F1E7T9O<FU?5F%R:6%B;&4G*2D@
M>PH@("`@("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]("1V87(["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V5R<F]R<ULD;F%M
M95TI(#\@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#H@;G5L;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!S971%<G)O<B@D=F%R+"`D;65S<V%G92D*("`@('L*("`@
M("`@("!I9B`H:7-?82@D=F%R+"`G2&]R9&5?1F]R;5]687)I86)L92<I*2![
M"B`@("`@("`@("`@("1N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@)'9A<CL*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/E]E<G)O<G-;)&YA;65=(#T@)&UE<W-A9V4[
M"B`@("!]"@H@("`@9G5N8W1I;VX@8VQE87)%<G)O<B@D=F%R*0H@("`@>PH@
M("`@("`@(&EF("AI<U]A*"1V87(L("=(;W)D95]&;W)M7U9A<FEA8FQE)RDI
M('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R+3YG971687).86UE*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YA;64@/2`D=F%R.PH@("`@
M("`@('T*("`@("`@("!U;G-E="@D=&AI<RT^7V5R<F]R<ULD;F%M95TI.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H*0H@("`@>PH@("`@("`@(')E
M='5R;B`H)'1H:7,M/E]A=71O9FEL;&5D('Q\(&-O=6YT*"1T:&ES+3Y?97)R
M;W)S*2`]/2`P*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>&5C=71E*"8D=F%R
M<RD*("`@('L*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G5V%R;FEN9SH@
M2&]R9&5?1F]R;3HZ97AE8W5T92@I(&-A;&QE9"P@<VAO=6QD(&)E(&]V97)R
M:61D96XG+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!F:65L9"!V86QU97,@
M;V8@=&AE('-U8FUI='1E9"!F;W)M+@H@("`@("H*("`@("`J($!P87)A;2!6
M87)I86)L97,@)'9A<G,@(%1H92!687)I86)L97,@;V)J96-T+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1I;F9O("`@("`@07)R87D@=&\@8F4@9FEL;&5D('=I
M=&@@=&AE('-U8FUI='1E9"!F:65L9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);F9O
M*"8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5T26YF
M;T9R;VU687)I86)L97,H)'1H:7,M/F=E=%9A<FEA8FQE<R@I+"`D=F%R<RP@
M)&EN9F\I.PH@("`@("`@("1T:&ES+3Y?9V5T26YF;T9R;VU687)I86)L97,H
M)'1H:7,M/E]H:61D96Y687)I86)L97,L("1V87)S+"`D:6YF;RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!&971C:"!T:&4@9FEE;&0@=F%L=65S(&9R;VT@
M82!G:79E;B!A<G)A>2!O9B!V87)I86)L97,N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`D=F%R
M:6%B;&5S("!!;B!A<G)A>2!O9B!(;W)D95]&;W)M7U9A<FEA8FQE(&]B:F5C
M=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9F5T8V@@
M9G)O;2X*("`@("`J($!P87)A;2!O8FIE8W0@)'9A<G,@("`@("`@5&AE(%9A
M<FEA8FQE<R!O8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@("1I;F9O("`@
M("`@(%1H92!A<G)A>2!T;R!B92!F:6QL960@=VET:"!T:&4@<W5B;6ET=&5D
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&9I96QD('9A;'5E
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$EN9F]&<F]M5F%R:6%B;&5S
M*"1V87)I86)L97,L("8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(&9O
M<F5A8V@@*"1V87)I86)L97,@87,@)'9A<BD@>PH@("`@("`@("`@("!I9B`H
M)'9A<BT^:7-!<G)A>59A;"@I*2!["B`@("`@("`@("`@("`@("`D=F%R+3YG
M971);F9O*"1V87)S+"`D=F%L=65S*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=F%L=65S*2D@>PH@("`@("`@("`@("`@("`@("`@("1V87).
M86UE(#T@<W1R7W)E<&QA8V4H)UM=)RP@)R<L("1V87(M/F=E=%9A<DYA;64H
M*2D["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D
M:2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I
M75LD=F%R3F%M95T@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@
M("`@("`@("`@(&EF("A(;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D=F%R
M+3YG971687).86UE*"DL("1B87-E+"`D:V5Y<RDI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R1B87-E72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)&)A<V5=(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@
M/2`F)&EN9F];)&)A<V5=.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AC
M;W5N="@D:V5Y<RDI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`]
M(&%R<F%Y7W-H:69T*"1K97ES*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&]I;G1E<ELD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R1K97E=(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]I;G1E<B`]("8D<&]I;G1E<ELD:V5Y73L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T26YF;R@D=F%R<RP@
M)'!O:6YT97(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=F%R+3YG971);F9O*"1V87)S+"`D:6YF;ULD=F%R+3YG
M971687).86UE*"E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!H87-(96QP*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]H96QP.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!I9B!T:&ES(&9O<FT@:&%S(&)E96X@<W5B
M;6ET=&5D(&]R(&YO="X@268@=&AE(&-L87-S"B`@("`@*B!V87(@7W-U8FUI
M='1E9"!I<R!N=6QL('1H96X@:70@=VEL;"!C:&5C:R!F;W(@=&AE('!R97-E
M;F-E(&]F"B`@("`@*B!T:&4@9F]R;6YA;64@:6X@=&AE(&9O<FT@=F%R:6%B
M;&5S+@H@("`@("H*("`@("`J($]T:&5R(&5V96YT<R!C86X@97AP;&EC:71L
M>2!S970@=&AE(%]S=6)M:71T960@=F%R:6%B;&4@=&\*("`@("`J(&9A;'-E
M('1O(&EN9&EC871E(&$@9F]R;2!S=6)M:70@8G5T(&YO="!F;W(@86-T=6%L
M('!O<W1I;F<@;V8*("`@("`J(&1A=&$@*&5G+B!O;D-H86YG92!E=F5N=',@
M=&\@=7!D871E('1H92!D:7-P;&%Y(&]F(&9I96QD<RDN"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R(&9A;'-E(&EN9&EC871I;F<@
M:68@=&AE(&9O<FT@:&%S(&)E96X*("`@("`J("`@("`@("`@("`@("`@("`@
M<W5B;6ET=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U-U8FUI='1E9"@I
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]S=6)M:71T960I
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W9A<G,M/F=E="@G9F]R;6YA
M;64G*2`]/2`D=&AI<RT^9V5T3F%M92@I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-U8FUI='1E9"`]('1R=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-U8FUI='1E9"`](&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M
M/E]S=6)M:71T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@
M=&AE<F4@:7,@86YY=&AI;F<@=&\@9&\@;VX@=&AE('-U8FUI<W-I;VX@;V8@
M=&AE(&9O<FT@8GD*("`@("`J(&QO;W!I;F<@=&AR;W5G:"!E86-H('9A<FEA
M8FQE)W,@;VY3=6)M:70H*2!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@2&]R9&5?5F%R:6%B;&5S("1V87)S"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&]N4W5B;6ET*"8D=F%R<RD*("`@('L*("`@("`@("`O*B!,;V]P('1H<F]U
M9V@@86QL('9A<G,@86YD(&-H96-K(&EF('1H97)E)W,@86YY=&AI;F<@=&\@
M9&\@;VX*("`@("`@("`@*B!S=6)M:70N("HO"B`@("`@("`@)'9A<FEA8FQE
M<R`]("1T:&ES+3YG971687)I86)L97,H*3L*("`@("`@("!F;W)E86-H("@D
M=F%R:6%B;&5S(&%S("1V87(I('L*("`@("`@("`@("`@)'9A<BT^='EP92T^
M;VY3=6)M:70H)'9A<BP@)'9A<G,I.PH@("`@("`@("`@("`O*B!)9B!C:&%N
M9V5S('1O('9A<B!B96EN9R!T<F%C:V5D(&1O;B=T(')E9VES=&5R('1H92!F
M;W)M(&%S"B`@("`@("`@("`@("`J('-U8FUI='1E9"!I9B!O;&0@=F%L=64@
M86YD(&YE=R!V86QU92!D:69F97(N("HO"B`@("`@("`@("`@(&EF("@D=F%R
M+3YG971/<'1I;VXH)W1R86-K8VAA;F=E)RDI('L*("`@("`@("`@("`@("`@
M("1V87)N86UE(#T@)'9A<BT^9V5T5F%R3F%M92@I.PH@("`@("`@("`@("`@
M("`@:68@*"%I<U]N=6QL*"1V87)S+3YG970H)V9O<FUN86UE)RDI("8F"B`@
M("`@("`@("`@("`@("`@("`@)'9A<G,M/F=E="@D=F%R;F%M92D@(3T@)'9A
M<G,M/F=E="@G7U]O;&1?)R`N("1V87)N86UE*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<W5B;6ET=&5D(#T@9F%L<V4["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%>'!L:6-I=&QY('-E=',@=&AE('-T871E(&]F('1H92!F;W)M
M('-U8FUI="X*("`@("`J"B`@("`@*B!!;B!E=F5N="!C86X@;W9E<G)I9&4@
M=&AE(&%U=&]M871I8R!D971E<FUI;F%T:6]N(&]F('1H92!S=6)M:70@<W1A
M=&4*("`@("`J(&EN('1H92!I<U-U8FUI='1E9"@I(&9U;F-T:6]N+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1S=&%T92`@5VAE=&AE<B!T;R!S
M970@=&AE('-T871E(&]F('1H92!F;W)M(&%S(&)E:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('-U8FUI='1E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T4W5B;6ET=&5D*"1S=&%T92`]('1R=64I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]S=6)M:71T960@/2`D<W1A=&4["B`@("!]"@I]"@HO*BH*
M("H@2&]R9&5?1F]R;5]4>7!E($-L87-S"B`J"B`J($!A=71H;W(@(%)O8F5R
M="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M/@H@*B!`<&%C
M:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@(&9U;F-T:6]N($AO<F1E7T9O<FU?5'EP92@I"B`@("!["B`@("!]"@H@
M("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@
M;VY3=6)M:70H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H
M)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@
M("`@)&UE<W-A9V4@/2`G/'-T<F]N9SY%<G)O<CH\+W-T<F]N9SX@2&]R9&5?
M1F]R;5]4>7!E.CII<U9A;&ED*"D@8V%L;&5D("T@<VAO=6QD(&)E(&]V97)R
M:61D96X\8G(@+SXG.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G9714>7!E3F%M92@I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*("`@("`@("!R971U<FX@<W1R
M7W)E<&QA8V4H)VAO<F1E7V9O<FU?='EP95\G+"`G)RP@4W1R:6YG.CIL;W=E
M<BAG971?8VQA<W,H)'1H:7,I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5F%L=65S*"D*("`@('L*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@
M('L*("`@("`@("`D:6YF;R`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@
M('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S<&%C97(@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A
M8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I
M"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O
M=71;)VYA;64G72`](%\H(E-P86-E<B(I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?=V5A=&AE<F1O
M=&-O;2!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?<F5G
M97@["B`@("!V87(@)%]S:7IE.PH@("`@=F%R("1?;6%X;&5N9W1H.PH*("`@
M("\J*@H@("`@("H@5&AE(&EN:71I86QI<V%T:6]N(&9U;F-T:6]N(&9O<B!T
M:&4@=&5X="!V87)I86)L92!T>7!E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E9V5X("`@
M("`@($%N>2!V86QI9"!02%`@4$-212!P871T97)N('-Y;G1A>"!T:&%T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!N965D<R!T;R!B92!M
M871C:&5D(&9O<B!T:&4@9FEE;&0@=&\@8F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G-I9&5R960@=F%L:60N($EF(&QE9G0@96UP
M='D@=F%L:61I='D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('=I;&P@8F4@8VAE8VME9"!O;FQY(&9O<B!R97%U:7)E9"!F:65L9',*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('=H971H97(@=&AE>2!A
M<F4@96UP='D@;W(@;F]T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@268@=7-I;F<@=&AI<R!R96=E>"!T97-T(&ET(&ES(&%D=FES86)L
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\@96YT97(@
M82!D97-C<FEP=&EO;B!F;W(@=&AI<R!F:65L9"!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=V%R;B!T:&4@=7-E<B!W:&%T(&ES(&5X
M<&5C=&5D+"!A<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&=E;F5R871E9"!E<G)O<B!M97-S86=E(&ES('%U:71E(&=E;F5R:6,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%N9"!W:6QL(&YO
M="!G:79E(&%N>2!I;F1I8V%T:6]N('=H97)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@<F5G97@@9F%I;&5D+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'-I>F4@("`@("`@5&AE('-I>F4@;V8@=&AE(&EN<'5T
M(&9I96QD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QE;F=T:"`@5&AE
M(&UA>"!N=6UB97(@;V8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6YI="@D<F5G97@@/2`G)RP@)'-I>F4@/2`T,"P@)&UA>&QE;F=T:"`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]R96=E>"`@("`@/2`D<F5G
M97@["B`@("`@("`@)'1H:7,M/E]S:7IE("`@("`@/2`D<VEZ93L*("`@("`@
M("`D=&AI<RT^7VUA>&QE;F=T:"`]("1M87AL96YG=&@["B`@("!]"@H@("`@
M9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S
M<V%G92D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;6%X;&5N
M9W1H*2`F)B!3=')I;F<Z.FQE;F=T:"@D=F%L=64I(#X@)'1H:7,M/E]M87AL
M96YG=&@I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A
M;'5E(&ES(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI
M<RT^7VUA>&QE;F=T:"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G4V5R=FEC97,O5V5A=&AE
M<BYP:'`G.PH@("`@("`@("1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E
M871H97(Z.G-E<G9I8V4H)U=E871H97)$;W1#;VTG*3L*("`@("`@("`D=V5A
M=&AE<D1O=$-O;2T^<V5T06-C;W5N=$1A=&$H)SQ087)T;F5R240^)RP@)SQ,
M:6-E;G-E2V5Y/B<I.PH@("`@("`@("1S96%R8V@@/2`D=V5A=&AE<D1O=$-O
M;2T^<V5A<F-H3&]C871I;VXH)'9A;'5E*3L*"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1S96%R8V@I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5F%L
M:60@;&]C871I;VYS(&9O=6YD(&EN8VQU9&4Z("(I("X@:6UP;&]D92@G+"`G
M+"`D<V5A<F-H*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T@96QS96EF("AI<U]A*"1S96%R8V@L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D<V5A<F-H+3YG971-97-S86=E*"D["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<VEZ93L*("`@('T*"B`@("!F=6YC=&EO;B!G971-87A,96YG=&@H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUA>&QE;F=T:#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O
M=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B5V5A
M=&AE<BYC;VTB*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH
M"B`@("`@("`@("`@("=R96=E>"<@("`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@
M7R@B4F5G97@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`G<VEZ92<@("`@("`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@
M("`@("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B36%X:6UU
M;2!L96YG=&@B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@*3L*("`@("`@("!R971U<FX@
M)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VAE861E
M<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-6
M86QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@
M("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B2&5A9&5R(BD["B`@("`@("`@
M<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP
M95]D97-C<FEP=&EO;B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@
M9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S
M<V%G92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@
M/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B1&5S8W)I
M<'1I;VXB*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*+RHJ
M"B`J(%-I;7!L>2!R96YD97)S(&ET<R!R87<@=F%L=64@:6X@8F]T:"!A8W1I
M=F4@86YD(&EN86-T:79E(')E;F1E<FEN9RX*("HO"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]H=&UL(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F
M=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S
M86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`]
M(&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")(5$U,(BD[
M"B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E
M7T9O<FU?5'EP95]N=6UB97(@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@('9A<B`D7V9R86-T:6]N.PH*("`@(&9U;F-T:6]N(&EN:70H)&9R86-T
M:6]N(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7V9R86-T:6]N(#T@
M)&9R86-T:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@
M*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H<W1R
M:6YG*2AD;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("AE;7!T
M>2@D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@+RH@268@;6%T8VAE9"P@=&AE;B!T:&ES(&ES(&$@8V]R
M<F5C="!N=6UE<FEC('9A;'5E+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"1T:&ES+3Y?9V5T5F%L:61A=&EO;E!A='1E<FXH*2P@)'9A;'5E*2D@>PH@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M
M97-S86=E(#T@7R@B5&AI<R!F:65L9"!M=7-T(&)E(&$@=F%L:60@;G5M8F5R
M+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO
M;B!?9V5T5F%L:61A=&EO;E!A='1E<FXH*0H@("`@>PH@("`@("`@('-T871I
M8R`D<&%T=&5R;B`]("<G.PH@("`@("`@(&EF("@A96UP='DH)'!A='1E<FXI
M*2!["B`@("`@("`@("`@(')E='5R;B`D<&%T=&5R;CL*("`@("`@("!]"@H@
M("`@("`@("\J($=E="!C=7)R96YT(&QO8V%L92!I;F9O<FUA=&EO;BX@*B\*
M("`@("`@("`D;&EN9F\@/2!.3%,Z.F=E=$QO8V%L94EN9F\H*3L*"B`@("`@
M("`@+RH@0G5I;&0@=&AE('!A='1E<FXN("HO"B`@("`@("`@)'!A='1E<FX@
M/2`G*"TI/R<["@H@("`@("`@("\J($]N;'D@8VAE8VL@=&AO=7-A;F1S('-E
M<&%R871O<G,@:68@;&]C86QE(&AA<R!A;GDN("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D;&EN9F];)VUO;E]T:&]U<V%N9'-?<V5P)UTI*2!["B`@("`@("`@
M("`@("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R96-T('1H;W5S86YD<R!S
M97!A<F%T;W)S("AI9B!A;GDI+B`J+PH@("`@("`@("`@("`D<&%T=&5R;B`N
M/2`G*"A<9"LI?"@H7&1[,"PS?3\I*%LG("X@)&QI;F9O6R=M;VY?=&AO=7-A
M;F1S7W-E<"==("X@)UU<9'LS?2DJ/RDI)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O*B!.;R!L;V-A;&4@=&AO=7-A;F1S('-E<&%R871O<BP@
M8VAE8VL@9F]R(&]N;'D@9&EG:71S+B`J+PH@("`@("`@("`@("`D<&%T=&5R
M;B`N/2`G*%QD*RDG.PH@("`@("`@('T*("`@("`@("`O*B!)9B!N;R!D96-I
M;6%L('!O:6YT('-P96-I9FEE9"!D969A=6QT('1O(&1O="X@*B\*("`@("`@
M("!I9B`H96UP='DH)&QI;F9O6R=M;VY?9&5C:6UA;%]P;VEN="==*2D@>PH@
M("`@("`@("`@("`D;&EN9F];)VUO;E]D96-I;6%L7W!O:6YT)UT@/2`G+B<[
M"B`@("`@("`@?0H@("`@("`@("\J(%)E9V5X('1O(&-H96-K(&9O<B!C;W)R
M96-T(&1E8VEM86QS("AI9B!A;GDI+B`J+PH@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7V9R86-T:6]N*2D@>PH@("`@("`@("`@("`D9G)A8W1I;VX@/2`G
M*B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9R86-T:6]N(#T@
M)WLP+"<@+B`D=&AI<RT^7V9R86-T:6]N("X@)WTG.PH@("`@("`@('T*("`@
M("`@("`D<&%T=&5R;B`N/2`G*%LG("X@)&QI;F9O6R=M;VY?9&5C:6UA;%]P
M;VEN="==("X@)UTH7&0G("X@)&9R86-T:6]N("X@)RDI/R<["@H@("`@("`@
M("\J(%!U="!T;V=E=&AE<B!T:&4@=VAO;&4@<F5G97@@<&%T=&5R;BX@*B\*
M("`@("`@("`D<&%T=&5R;B`]("<O7B<@+B`D<&%T=&5R;B`N("<D+R<["@H@
M("`@("`@(')E='5R;B`D<&%T=&5R;CL*("`@('T*"B`@("!F=6YC=&EO;B!G
M971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D
M=F%L=64@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@
M("`@)&QI;F9O(#T@3DQ3.CIG971,;V-A;&5);F9O*"D["B`@("`@("`@)'9A
M;'5E(#T@<W1R7W)E<&QA8V4H)&QI;F9O6R=M;VY?=&AO=7-A;F1S7W-E<"==
M+"`G)RP@)'9A;'5E*3L*("`@("`@("`D:6YF;R`]('-T<E]R97!L86-E*"1L
M:6YF;ULG;6]N7V1E8VEM86Q?<&]I;G0G72P@)RXG+"`D=F%L=64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@
M("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?
M*").=6UB97(B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*
M8VQA<W,@2&]R9&5?1F]R;5]4>7!E7VEN="!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D
M=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-2
M97%U:7)E9"@I("8F(&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I*&EN="DD
M=F%L=64@(3T]("1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E
M*2!\?"!P<F5G7VUA=&-H*"<O7ELP+3E=*R0O)RP@)'9A;'5E*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S
M86=E(#T@7R@B5&AI<R!F:65L9"!M87D@;VYL>2!C;VYT86EN(&EN=&5G97)S
M+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A
M>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B26YT96=E<B(I.PH@
M("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?;V-T86P@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@
M(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE
M<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F
M)B!E;7!T>2@D=F%L=64I("8F("@H<W1R:6YG*2AI;G0I)'9A;'5E("$]/2`D
M=F%L=64I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L
M9"!I<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M
M871C:"@G+UY;,"TW72LD+R<L("1V86QU92DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@;6%Y(&]N;'D@8V]N=&%I;B!O8W1A;"!V86QU97,N(BD["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")/8W1A;"(I.PH@("`@("`@(')E
M='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?
M:6YT3&ES="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I
M;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E
M<75I<F5D*"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I
M96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G
M7VUA=&-H*"<O7ELP+3D@+%TK)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?
M*")4:&ES(&9I96QD(&UU<W0@8F4@82!C;VUM82!O<B!S<&%C92!S97!A<F%T
M960@;&ES="!O9B!I;G1E9V5R<R(I.PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD
M('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@
M("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==
M(#T@7R@B26YT96=E<B!L:7-T(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*
M("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]T97AT(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]R96=E>#L*("`@('9A<B`D
M7W-I>F4["B`@("!V87(@)%]M87AL96YG=&@["@H@("`@+RHJ"B`@("`@*B!4
M:&4@:6YI=&EA;&ES871I;VX@9G5N8W1I;VX@9F]R('1H92!T97AT('9A<FEA
M8FQE('1Y<&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5G97@@("`@("`@06YY('9A;&ED
M(%!(4"!00U)%('!A='1E<FX@<WEN=&%X('1H870*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&YE961S('1O(&)E(&UA=&-H960@9F]R('1H
M92!F:65L9"!T;R!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N<VED97)E9"!V86QI9"X@268@;&5F="!E;7!T>2!V86QI9&ET>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!B92!C:&5C
M:V5D(&]N;'D@9F]R(')E<75I<F5D(&9I96QD<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=VAE=&AE<B!T:&5Y(&%R92!E;7!T>2!O<B!N
M;W0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!U<VEN
M9R!T:&ES(')E9V5X('1E<W0@:70@:7,@861V:7-A8FQE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T;R!E;G1E<B!A(&1E<V-R:7!T:6]N
M(&9O<B!T:&ES(&9I96QD('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!W87)N('1H92!U<V5R('=H870@:7,@97AP96-T960L(&%S('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9V5N97)A=&5D
M(&5R<F]R(&UE<W-A9V4@:7,@<75I=&4@9V5N97)I8PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@86YD('=I;&P@;F]T(&=I=F4@86YY(&EN
M9&EC871I;VX@=VAE<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!R96=E>"!F86EL960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<VEZ92`@("`@("!4:&4@<VEZ92!O9B!T:&4@:6YP=70@9FEE;&0N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D;6%X;&5N9W1H("!4:&4@;6%X(&YU;6)E<B!O
M9B!C:&%R86-T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!I;FET*"1R96=E
M>"`]("<G+"`D<VEZ92`](#0P+"`D;6%X;&5N9W1H(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W)E9V5X("`@("`]("1R96=E>#L*("`@("`@("`D
M=&AI<RT^7W-I>F4@("`@("`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?;6%X
M;&5N9W1H(#T@)&UA>&QE;F=T:#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@("1V86QI9"`]('1R=64["@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]M87AL96YG=&@I("8F(%-T<FEN9SHZ;&5N9W1H*"1V86QU92D@/B`D
M=&AI<RT^7VUA>&QE;F=T:"D@>PH@("`@("`@("`@("`D=F%L:60@/2!F86QS
M93L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*%\H(E9A;'5E(&ES
M(&]V97(@=&AE(&UA>&EM=6T@;&5N9W1H(&]F("5S+B(I+"`D=&AI<RT^7VUA
M>&QE;F=T:"D["B`@("`@("`@?2!E;'-E:68@*"1V87(M/FES4F5Q=6ER960H
M*2`F)B!E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@("`@("`D=F%L
M:60@/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["@H@("`@("`@("`@("!I
M9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4
M:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E:68@*"%E;7!T>2@D=&AI<RT^7W)E9V5X*2D@>PH@("`@("`@
M("`@("`D=F%L:60@/2!P<F5G7VUA=&-H*"1T:&ES+3Y?<F5G97@L("1V86QU
M92D["@H@("`@("`@("`@("!I9B`H(21V86QI9"D@>PH@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/2!?*")9;W4@:&%V92!T;R!E;G1E<B!A('9A;&ED('9A
M;'5E+B(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'9A;&ED.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T36%X3&5N9W1H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]M87AL96YG=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@
M("`D86)O=71;)VYA;64G72`](%\H(E1E>'0B*3L*("`@("`@("`D86)O=71;
M)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R96=E>"<@("`@(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4F5G97@B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@
M("`@("`G<VEZ92<@("`@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]
M/B`G:6YT)RDL"B`@("`@("`@("`@("=M87AL96YG=&@G(#T^(&%R<F%Y*"=L
M86)E;"<@/3X@7R@B36%X:6UU;2!L96YG=&@B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G:6YT)RDL"B`@("`@("`@
M*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R
M9&5?1F]R;5]4>7!E7W-T<FEN9VQI<W0@97AT96YD<R!(;W)D95]&;W)M7U1Y
M<&5?=&5X="!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA
M;64G72`](%\H(E-T<FEN9R!L:7-T(BD["B`@("`@("`@)&%B;W5T6R=P87)A
M;7,G72`](&%R<F%Y*`H@("`@("`@("`@("`G<F5G97@G("`@("`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(E)E9V5X(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2P*("`@("`@("`@("`@
M)W-I>F4G("`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:7IE(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN
M="<I+`H@("`@("`@("`@("`G;6%X;&5N9W1H)R`]/B!A<G)A>2@G;&%B96PG
M(#T^(%\H(DUA>&EM=6T@;&5N9W1H(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("D["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]C96QL<&AO;F4@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*
M("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F
M)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U93L*"B`@("`@
M("`@:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=F%L
M:60@/2!S=')L96XH=')I;2@D=F%L=64I*2`^(#`["B`@("`@("`@("`@(&EF
M("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(E1H
M:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L:60@/2!P<F5G7VUA=&-H*"<O
M7EPK/UM<9"@I7"U<+R!=*B0O)RP@)'9A;'5E*3L*("`@("`@("`@("`@:68@
M*"$D=F%L:60I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B66]U
M(&AA=F4@=&\@96YT97(@82!V86QI9"!C96QL<&AO;F4@;G5M8F5R+"!D:6=I
M=',@;VYL>2!W:71H(&%N(&]P=&EO;F%L("<K)R!F;W(@=&AE(&EN=&5R;F%T
M:6]N86P@9&EA;&EN9R!P<F5F:7@N(BD["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R
M87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D-E;&QP:&]N92(I
M.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(;W)D
M95]&;W)M7U1Y<&5?:7!A9&1R97-S(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E
M7W1E>'0@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L("8D=F%R<RP@
M)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)'9A;&ED(#T@=')U
M93L*"B`@("`@("`@:68@*'-T<FQE;BAT<FEM*"1V86QU92DI(#X@,"D@>PH@
M("`@("`@("`@("`D:7`@/2!E>'!L;V1E*"<N)RP@)'9A;'5E*3L*("`@("`@
M("`@("`@)'9A;&ED(#T@*&-O=6YT*"1I<"D@/3T@-"D["B`@("`@("`@("`@
M(&EF("@D=F%L:60I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I<"!A
M<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?;G5M97)I
M8R@D<&%R="D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/B`R
M-34@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<G0@/"`P*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H
M(E!L96%S92!E;G1E<B!A('9A;&ED($E0(&%D9')E<W,N(BD["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V5I9B`H)'9A<BT^:7-297%U:7)E9"@I*2![
M"B`@("`@("`@("`@("1V86QI9"`](&9A;'-E.PH@("`@("`@("`@("`D;65S
M<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@G
M;F%M92<@/3X@7R@B25`@061D<F5S<R(I*3L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]L;VYG5&5X="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP
M95]T97AT('L*"B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?8V]L<SL*("`@
M('9A<B`D7VAE;'!E<B`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@:6YI="@D
M<F]W<R`](#@L("1C;VQS(#T@.#`L("1H96QP97(@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^7W)O=W,@/2`D<F]W<SL*("`@("`@("`D=&AI<RT^7V-O
M;',@/2`D8V]L<SL*("`@("`@("`D=&AI<RT^7VAE;'!E<B`]("1H96QP97([
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4F]W<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F]W<SL*("`@('T*"B`@("!F=6YC=&EO;B!G971#
M;VQS*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VQS.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&AA<TAE;'!E<B@D;W!T:6]N(#T@)R<I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VXI*2!["B`@("`@("`@("`@("\J
M($YO(&]P=&EO;B!S<&5C:69I960L(&-H96-K(&EF(&%N>2!H96QP97)S(&AA
M=F4@8F5E;@H@("`@("`@("`@("`@*B!A8W1I=F%T960N("HO"B`@("`@("`@
M("`@(')E='5R;B`A96UP='DH)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T@
M96QS96EF("AE;7!T>2@D=&AI<RT^7VAE;'!E<BDI('L*("`@("`@("`@("`@
M+RH@3F\@:&5L<&5R<R!A8W1I=F%T960@870@86QL+"!R971U<FX@9F%L<V4N
M("HO"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!#:&5C:R!I9B!G:79E;B!H96QP97(@:&%S(&)E
M96X@86-T:79A=&5D+B`J+PH@("`@("`@("`@("!R971U<FX@:6Y?87)R87DH
M)&]P=&EO;BP@)'1H:7,M/E]H96QP97(I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O
M=70@/2!A<G)A>2@I.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B3&]N
M9R!T97AT(BD["B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@
M("`@("`@("`@("`G<F]W<R<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU
M;6)E<B!O9B!R;W=S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@("`]/B!A
M<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C;VQU;6YS(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)VEN="<I+`H@
M("`@("`@("`@("`G:&5L<&5R)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DAE
M;'!E<B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@
M(#T^("=B;V]L96%N)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O
M=70["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8V]U;G1E9%1E
M>'0@97AT96YD<R!(;W)D95]&;W)M7U1Y<&5?;&]N9U1E>'0@>PH*("`@('9A
M<B`D7V-H87)S.PH*("`@(&9U;F-T:6]N(&EN:70H)')O=W,@/2!N=6QL+"`D
M8V]L<R`](&YU;&PL("1C:&%R<R`](#$P,#`I"B`@("!["B`@("`@("`@<&%R
M96YT.CII;FET*"1R;W=S+"`D8V]L<RD["B`@("`@("`@)'1H:7,M/E]C:&%R
M<R`]("1C:&%R<SL*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R
M+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@("1V
M86QI9"`]('1R=64["@H@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"DI
M('L*("`@("`@("`@("`@)&QE;F=T:"`](%-T<FEN9SHZ;&5N9W1H*'1R:6TH
M)'9A;'5E*2D["@H@("`@("`@("`@("!I9B`H)&QE;F=T:"`\/2`P*2!["B`@
M("`@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1L96YG=&@@/B`D=&AI<RT^7V-H87)S*2![
M"B`@("`@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@("`@("`@
M("`@("1M97-S86=E(#T@<W!R:6YT9BA?*")4:&5R92!A<F4@=&]O(&UA;GD@
M8VAA<F%C=&5R<R!I;B!T:&ES(&9I96QD+B!9;W4@:&%V92!E;G1E<F5D("5S
M(&-H87)A8W1E<G,[('EO=2!M=7-T(&5N=&5R(&QE<W,@=&AA;B`E<RXB*2P@
M4W1R:6YG.CIL96YG=&@H=')I;2@D=F%L=64I*2P@)'1H:7,M/E]C:&%R<RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L
M:60["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAA<G,H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-H87)S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")#;W5N=&5D('1E>'0B
M*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@
M("`@("=R;W=S)R`@/3X@87)R87DH)VQA8F5L)R`]/B!?*").=6UB97(@;V8@
M<F]W<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@
M/3X@)VEN="<I+`H@("`@("`@("`@("`G8V]L<R<@(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B3G5M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@
M)V-H87)S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!C:&%R
M86-T97)S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G
M("`]/B`G:6YT)RD*("`@("`@("`I.PH@("`@("`@(')E='5R;B`D86)O=70[
M"B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?861D<F5S<R!E>'1E
M;F1S($AO<F1E7T9O<FU?5'EP95]L;VYG5&5X="!["@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D%D9')E<W,B*3L*("`@
M("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=R
M;W=S)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(DYU;6)E<B!O9B!R;W=S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G
M*2P*("`@("`@("`@("`@)V-O;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B
M3G5M8F5R(&]F(&-O;'5M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)VEN="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V9I;&4@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V
M87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D=7!L;V%D
M960@/2!"<F]W<V5R.CIW87-&:6QE57!L;V%D960H)'9A<BT^9V5T5F%R3F%M
M92@I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A9&5D+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`]("1U<&QO861E
M9"T^9V5T365S<V%G92@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L
M("8D:6YF;RD*("`@('L*("`@("`@("`D;F%M92`]("1V87(M/F=E=%9A<DYA
M;64H*3L*("`@("`@("`D=7!L;V%D960@/2!"<F]W<V5R.CIW87-&:6QE57!L
M;V%D960H)&YA;64I.PH@("`@("`@(&EF("@D=7!L;V%D960@/3T]('1R=64I
M('L*("`@("`@("`@("`@)&EN9F];)VYA;64G72`]("1?1DE,15-;)&YA;65=
M6R=N86UE)UT["B`@("`@("`@("`@("1I;F9O6R=T>7!E)UT@/2`D7T9)3$53
M6R1N86UE75LG='EP92==.PH@("`@("`@("`@("`D:6YF;ULG=&UP7VYA;64G
M72`]("1?1DE,15-;)&YA;65=6R=T;7!?;F%M92==.PH@("`@("`@("`@("`D
M:6YF;ULG9FEL92==(#T@)%]&24Q%4ULD;F%M95U;)W1M<%]N86UE)UT["B`@
M("`@("`@("`@("1I;F9O6R=E<G)O<B==(#T@)%]&24Q%4ULD;F%M95U;)V5R
M<F]R)UT["B`@("`@("`@("`@("1I;F9O6R=S:7IE)UT@/2`D7T9)3$536R1N
M86UE75LG<VEZ92==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH)VYA
M;64G(#T^(%\H(D9I;&4@=7!L;V%D(BDI.PH@("`@?0H*?0H*8VQA<W,@2&]R
M9&5?1F]R;5]4>7!E7VEM86=E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*
M"B`@("`O*BH*("`@("`J($AA<R!A(&9I;&4@8F5E;B!U<&QO861E9"!O;B!T
M:&ES(&9O<FT@<W5B;6ET/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@
M("`@("HO"B`@("!V87(@)%]U<&QO861E9"`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!3:&]W('1H92!U<&QO860@8G5T=&]N/PH@("`@("H*("`@("`J($!V
M87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7W5P;&]A9"`]('1R
M=64["@H@("`@+RHJ"B`@("`@*B!3:&]W('1H92!O<'1I;VX@=&\@=7!L;V%D
M(&%L<V\@;W)I9VEN86P@;F]N+6UO9&EF:65D(&EM86=E/PH@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W7VME97!O
M<FEG/2!F86QS93L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!T
M:&4@<')E=FEO=7-L>2!U<&QO861E9"!I;6%G92!I;F9O+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG(#T@87)R87DH
M*3L*"B`@("!F=6YC=&EO;B!I;FET*"1S:&]W7W5P;&]A9"`]('1R=64L("1S
M:&]W7VME97!O<FEG(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M:&]W7W5P;&]A9"`@(#T@)'-H;W=?=7!L;V%D.PH@("`@("`@("1T:&ES+3Y?
M<VAO=U]K965P;W)I9R`]("1S:&]W7VME97!O<FEG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&]N4W5B;6ET*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@
M+RH@1V5T('1H92!U<&QO860N("HO"B`@("`@("`@)'1H:7,M/E]G9715<&QO
M860H)'9A<G,L("1V87(I.PH*("`@("`@("`O*B!)9B!T:&ES('=A<R!D;VYE
M('1H<F]U9V@@=&AE('5P;&]A9"!B=71T;VX@;W9E<G)I9&4@=&AE('-U8FUI
M='1E9`H@("`@("`@("`J('9A;'5E(&]F('1H92!F;W)M+B`J+PH@("`@("`@
M(&EF("@D=F%R<RT^9V5T*"=?9&]?)R`N("1V87(M/F=E=%9A<DYA;64H*2DI
M('L*("`@("`@("`@("`@)'9A<BT^9F]R;2T^<V5T4W5B;6ET=&5D*&9A;'-E
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D
M9FEE;&0@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["@H@("`@
M("`@("\J($=E="!T:&4@=7!L;V%D+B`J+PH@("`@("`@("1T:&ES+3Y?9V5T
M57!L;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@("`@+RH@5&AE('5P;&]A9"!G
M96YE<F%T960@82!014%2($5R<F]R+B`J+PH@("`@("`@(&EF("AI<U]A*"1T
M:&ES+3Y?=7!L;V%D960L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M+RH@3F]T(')E<75I<F5D(&%N9"!N;R!I;6%G92!U<&QO860@871T96UP=&5D
M+B`J+PH@("`@("`@("`@("!I9B`H(21V87(M/FES4F5Q=6ER960H*2`F)B!E
M;7!T>2@D9FEE;&1;)VEM9R==*2`F)@H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]U<&QO861E9"T^9V5T0V]D92@I(#T](#0I('L*("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M*"1T:&ES+3Y?=7!L;V%D960M/F=E=$-O9&4H*2`]/2!54$Q/041?15)27TY/
M7T9)3$4I("8F"B`@("`@("`@("`@("`@("!E;7!T>2@D9FEE;&1;)VEM9R==
M*2D@>PH@("`@("`@("`@("`@("`@+RH@3F]T:&EN9R!U<&QO861E9"!A;F0@
M;F\@;VQD97(@=7!L;V%D+B`J+PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y
M*"1F:65L9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@("`O*B!.;W1H:6YG
M('5P;&]A9&5D(&)U="!O;&1E<B!U<&QO860@<')E<V5N="X@*B\*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@+RH@4V]M92!O=&AE<B!E<G)O<B!M97-S86=E+B`J
M+PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7W5P;&]A9&5D
M+3YG971-97-S86=E*"D["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@
M)B1I;F9O*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@=7!L;V%D+B`J+PH@
M("`@("`@("1T:&ES+3Y?9V5T57!L;V%D*"1V87)S+"`D=F%R*3L*"B`@("`@
M("`@+RH@1V5T(&EM86=E('!A<F%M<R!S=&]R960@:6X@=&AE(&AI9&1E;B!F
M:65L9"X@*B\*("`@("`@("`D=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R
M<RD["B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7VEM9SL*("`@("`@("!I9B`H
M96UP='DH)&EN9F];)V9I;&4G72DI('L*("`@("`@("`@("`@=6YS970H)&EN
M9F];)V9I;&4G72D["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@
M("`@("`@:68@*"1T:&ES+3Y?<VAO=U]K965P;W)I9RD@>PH@("`@("`@("`@
M("`D:6YF;ULG:V5E<%]O<FEG)UT@/2`A96UP='DH)'9A;'5E6R=K965P7V]R
M:6<G72D["B`@("`@("`@?0H*("`@("`@("`O*B!3970@=&AE('5P;&]A9&5D
M('9A;'5E("AE:71H97(@=')U92!O<B!014%27T5R<F]R*2X@*B\*("`@("`@
M("`D:6YF;ULG=7!L;V%D960G72`]("8D=&AI<RT^7W5P;&]A9&5D.PH*("`@
M("`@("`O*B!)9B!A(&UO9&EF:65D(&9I;&4@97AI<W1S(&UO=F4@:70@;W9E
M<B!T:&4@;W)I9VEN86PN("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=U]K
M965P;W)I9R`F)B`D:6YF;ULG:V5E<%]O<FEG)UTI('L*("`@("`@("`@("`@
M+RH@4F5Q=65S=&5D('1H92!S879I;F<@;V8@;W)I9VEN86P@9FEL92!A;'-O
M+B`J+PH@("`@("`@("`@("`D:6YF;ULG;W)I9U]F:6QE)UT@/2!(;W)D93HZ
M9V5T5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@
M("`@)&EN9F];)V9I;&4G72`]($AO<F1E.CIG971496UP1&ER*"D@+B`G+VUO
M9%\G("X@)&EN9F];)V9I;&4G73L*("`@("`@("`@("`@+RH@0VAE8VL@:68@
M82!M;V1I9FEE9"!F:6QE(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D:6YF;ULG9FEL92==*2D@>PH@("`@("`@
M("`@("`@("`@)&EN9F];)V9I;&4G72`]("1I;F9O6R=O<FEG7V9I;&4G73L*
M("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R=O<FEG7V9I;&4G72D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3
M879I;F<@;V8@;W)I9VEN86P@;F]T(')E<75I<F5D+B`J+PH@("`@("`@("`@
M("`D;6]D7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R]M;V1?)R`N
M("1I;F9O6R=F:6QE)UT["B`@("`@("`@("`@("1I;F9O6R=F:6QE)UT@/2!(
M;W)D93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)&EN9F];)V9I;&4G73L*"B`@
M("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D;6]D7V9I;&4I*2!["B`@("`@
M("`@("`@("`@("`O*B!5;FQI;FL@9FER<W0@*&AA<R!T;R!B92!D;VYE(&]N
M(%=I;F1O=W,@;6%C:&EN97,_*2`J+PH@("`@("`@("`@("`@("`@=6YL:6YK
M*"1I;F9O6R=F:6QE)UTI.PH@("`@("`@("`@("`@("`@<F5N86UE*"1M;V1?
M9FEL92P@)&EN9F];)V9I;&4G72D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!U<&QO860@86YD('-E
M=',@=7`@=&AE('5P;&]A9"!D871A(&%R<F%Y+B!%:71H97(*("`@("`J(&9E
M=&-H97,@86X@=7!L;V%D(&1O;F4@=VET:"!T:&ES('-U8FUI="!O<B!R971R
M:65S('-T;W)E9`H@("`@("H@=7!L;V%D(&EN9F\N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]G9715<&QO860H)B1V87)S+"`F)'9A<BD*("`@('L*("`@("`@
M("`O*B!$;VXG="!B;W1H97(@=VET:"!T:&ES(&9U;F-T:6]N(&EF(&%L<F5A
M9'D@8V%L;&5D(&%N9"!S970*("`@("`@("`@*B!U<"!V87)S+B`J+PH@("`@
M("`@(&EF("@A96UP='DH)'1H:7,M/E]I;6<I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@9FEL
M92!H87,@8F5E;B!U<&QO861E9"X@*B\*("`@("`@("`D=F%R;F%M92`]("1V
M87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`D=&AI<RT^7W5P;&]A9&5D(#T@
M0G)O=W-E<CHZ=V%S1FEL955P;&]A9&5D*"1V87)N86UE("X@)UMN97==)RD[
M"@H@("`@("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D(#T]/2!T<G5E*2!["B`@
M("`@("`@("`@("\J($$@9FEL92!H87,@8F5E;B!U<&QO861E9"!O;B!T:&ES
M('-U8FUI="X@4V%V92!T;R!T96UP(&1I<B!F;W(*("`@("`@("`@("`@("H@
M<')E=FEE=R!W;W)K+B`J+PH@("`@("`@("`@("`D=&AI<RT^7VEM9ULG='EP
M92==(#T@)'1H:7,M/F=E=%5P;&]A9&5D1FEL951Y<&4H)'9A<FYA;64@+B`G
M6VYE=UTG*3L*"B`@("`@("`@("`@("\J($=E="!T:&4@;W1H97(@<&%R=',@
M;V8@=&AE('5P;&]A9"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]!<G)A>2YP:'`G.PH@("`@("`@("`@("!(;W)D95]!<G)A>3HZ9V5T
M07)R87E087)T<R@D=F%R;F%M92`N("=;;F5W72<L("1B87-E+"`D:V5Y<RD[
M"@H@("`@("`@("`@("`O*B!'970@=&AE('1E;7!O<F%R>2!F:6QE(&YA;64N
M("HO"B`@("`@("`@("`@("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A
M>2@D8F%S92P@)W1M<%]N86UE)RDL("1K97ES*3L*("`@("`@("`@("`@)'1H
M:7,M/E]I;6=;)V9I;&4G72`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?
M1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@("`@+RH@1V5T('1H92!A
M8W1U86P@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H/2!A
M<G)A>5]M97)G92AA<G)A>2@D8F%S92P@)VYA;64G*2P@)&ME>7,I.PH@("`@
M("`@("`@("`D=&AI<RT^7VEM9ULG;F%M92==(#T@2&]R9&5?07)R87DZ.F=E
M=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["@H@("`@("`@("`@("`O
M*B!'970@=&AE(&9I;&4@<VEZ92X@*B\*("`@("`@("`@("`@)&ME>7-?<&%T
M:#T@87)R87E?;65R9V4H87)R87DH)&)A<V4L("=S:7IE)RDL("1K97ES*3L*
M("`@("`@("`@("`@)'1H:7,M/E]I;6=;)W-I>F4G72`]($AO<F1E7T%R<F%Y
M.CIG971%;&5M96YT*"1?1DE,15,L("1K97ES7W!A=&@I.PH*("`@("`@("`@
M("`@+RH@1V5T(&%N>2!E>&ES=&EN9R!V86QU97,@9F]R('1H92!I;6%G92!U
M<&QO860@9FEE;&0N("HO"B`@("`@("`@("`@("1U<&QO860@/2`D=F%R<RT^
M9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@("`@("1U<&QO861;
M)VEM9R==(#T@0'5N<V5R:6%L:7IE*"1U<&QO861;)VEM9R==*3L*"B`@("`@
M("`@("`@("\J($=E="!T:&4@=&5M<"!F:6QE(&EF(&%L<F5A9'D@;VYE('5P
M;&]A9&5D+"!O=&AE<G=I<V4@8W)E871E(&$*("`@("`@("`@("`@("H@;F5W
M('1E;7!O<F%R>2!F:6QE+B`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1U
M<&QO861;)VEM9R==6R=F:6QE)UTI*2!["B`@("`@("`@("`@("`@("`D=&UP
M7V9I;&4@/2!(;W)D93HZ9V5T5&5M<$1I<B@I("X@)R\G("X@)'5P;&]A9%LG
M:6UG)UU;)V9I;&4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T;7!?9FEL92`]($AO<F1E.CIG971496UP1FEL92@G2&]R9&4G
M+"!F86QS92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($UO=F4@
M=&AE(&)R;W=S97(@8W)E871E9"!T96UP(&9I;&4@=&\@=&AE(&YE=R!T96UP
M(&9I;&4N("HO"B`@("`@("`@("`@(&UO=F5?=7!L;V%D961?9FEL92@D=&AI
M<RT^7VEM9ULG9FEL92==+"`D=&UP7V9I;&4I.PH@("`@("`@("`@("`D=&AI
M<RT^7VEM9ULG9FEL92==(#T@8F%S96YA;64H)'1M<%]F:6QE*3L*"B`@("`@
M("`@("`@("\J(%-T;W)E('1H92!U<&QO861E9"!I;6%G92!F:6QE(&1A=&$@
M=&\@=&AE(&AI9&1E;B!F:65L9"X@*B\*("`@("`@("`@("`@)'5P;&]A9%LG
M:6UG)UT@/2!S97)I86QI>F4H)'1H:7,M/E]I;6<I.PH@("`@("`@("`@("`D
M=F%R<RT^<V5T*"1V87(M/F=E=%9A<DYA;64H*2P@)'5P;&]A9"D["B`@("`@
M("`@?2!E;'-E:68@*"1T:&ES+3Y?=7!L;V%D960I('L*("`@("`@("`@("`@
M+RH@1FEL92!H87,@;F]T(&)E96X@=7!L;V%D960N("HO"B`@("`@("`@("`@
M("1U<&QO860@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7W5P;&]A9&5D+3YG971#;V1E*"D@/3T@
M-"`F)B`A96UP='DH)'5P;&]A9%LG:6UG)UTI*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VEM9R`]($!U;G-E<FEA;&EZ92@D=7!L;V%D6R=I;6<G72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T57!L;V%D961&:6QE5'EP92@D9FEE;&0I"B`@("!["B`@("`@("`@+RH@
M1V5T(&%N>2!I;F1E>"!O;B!T:&4@9FEE;&0@;F%M92X@*B\*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@)&EN9&5X
M(#T@2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)&9I96QD+"`D8F%S92P@
M)&ME>7,I.PH*("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@("`@("\J
M($EN9&5X('!R97-E;G0L(&9E=&-H('1H92!M:6UE('1Y<&4@=F%R('1O(&-H
M96-K+B`J+PH@("`@("`@("`@("`D:V5Y<U]P871H(#T@87)R87E?;65R9V4H
M87)R87DH)&)A<V4L("=T>7!E)RDL("1K97ES*3L*("`@("`@("`@("`@)'1Y
M<&4@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P
M871H*3L*("`@("`@("`@("`@)&ME>7-?<&%T:#T@87)R87E?;65R9V4H87)R
M87DH)&)A<V4L("=T;7!?;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("1T
M;7!?;F%M92`]($AO<F1E7T%R<F%Y.CIG971%;&5M96YT*"1?1DE,15,L("1K
M97ES7W!A=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO
M(&EN9&5X+"!S:6UP;&4@<V5T('5P(&]F('9A<G,@=&\@8VAE8VLN("HO"B`@
M("`@("`@("`@("1T>7!E(#T@)%]&24Q%4ULD9FEE;&1=6R=T>7!E)UT["B`@
M("`@("`@("`@("1T;7!?;F%M92`]("1?1DE,15-;)&9I96QD75LG=&UP7VYA
M;64G73L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D='EP92D@?'P@
M*"1T>7!E(#T]("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG*2D@>PH@("`@
M("`@("`@("`O*B!4>7!E('=A<VXG="!S970@;VX@=7!L;V%D+"!T<GD@86YA
M;&ES:6YG('1H92!U<&QO860N("HO"B`@("`@("`@("`@(&=L;V)A;"`D8V]N
M9CL*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TUA9VEC
M+G!H<"<["B`@("`@("`@("`@(&EF("@A*"1T>7!E(#T@34E-15]-86=I8SHZ
M86YA;'EZ949I;&4H)'1M<%]N86UE+"!I<W-E="@D8V]N9ELG;6EM92==6R=M
M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@.B!N=6QL
M*2DI('L*("`@("`@("`@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@("`@
M("`@("`@("`@("`O*B!'970@=&AE(&YA;64@=F%L=64N("HO"B`@("`@("`@
M("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y*"1B
M87-E+"`G;F%M92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@)&YA
M;64@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D:V5Y<U]P
M871H*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@5V]R:R!O=70@=&AE('1Y
M<&4@9G)O;2!T:&4@9FEL92!N86UE+B`J+PH@("`@("`@("`@("`@("`@("`@
M("1T>7!E(#T@34E-15]-86=I8SHZ9FEL96YA;654;TU)344H)&YA;64I.PH*
M("`@("`@("`@("`@("`@("`@("`O*B!3970@=&AE('1Y<&4N("HO"B`@("`@
M("`@("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE<F=E*&%R<F%Y
M*"1B87-E+"`G='EP92<I+"`D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@
M2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"P@
M)'1Y<&4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`O*B!7;W)K(&]U="!T:&4@='EP92!F<F]M('1H92!F:6QE(&YA
M;64N("HO"B`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC
M.CIF:6QE;F%M951O34E-12@D7T9)3$536R1F:65L9%U;)VYA;64G72D["@H@
M("`@("`@("`@("`@("`@("`@("\J(%-E="!T:&4@='EP92X@*B\*("`@("`@
M("`@("`@("`@("`@("`D7T9)3$536R1F:65L9%U;)W1Y<&4G72`]($U)345?
M36%G:6,Z.F9I;&5N86UE5&]-24U%*"1?1DE,15-;)&9I96QD75LG;F%M92==
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3&]A9',@86YY(&5X:7-T:6YG(&EM86=E(&1A=&$@:6YT;R!T:&4@:6UA9V4@
M9FEE;&0N(%)E<75I<F5S('1H870@=&AE"B`@("`@*B!A<G)A>2`D:6UA9V4@
M<&%S<V5D('1O(&ET(&-O;G1A:6YS('1H92!S=')U8W1U<F4Z"B`@("`@*B`@
M("1I;6%G95LG;&]A9"==6R=F:6QE)UT@+2!T:&4@9FEL96YA;64@;V8@=&AE
M(&EM86=E.PH@("`@("H@("`D:6UA9V5;)VQO860G75LG9&%T82==("T@=&AE
M(')A=R!I;6%G92!D871A+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D:6UA9V4@(%1H92!I;6%G
M92!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO861);6%G941A=&$H
M)B1I;6%G92D*("`@('L*("`@("`@("`O*B!.;R!E>&ES=&EN9R!I;6%G92!D
M871A('1O(&QO860N("HO"B`@("`@("`@:68@*"%I<W-E="@D:6UA9V5;)VQO
M860G72DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4V%V92!T:&4@9&%T82!T;R!T:&4@=&5M<"!D:7(N("HO"B`@("`@
M("`@)'1M<%]F:6QE(#T@2&]R9&4Z.F=E=%1E;7!$:7(H*2`N("<O)R`N("1I
M;6%G95LG;&]A9"==6R=F:6QE)UT["B`@("`@("`@:68@*"1F9"`](&9O<&5N
M*"1T;7!?9FEL92P@)W<G*2D@>PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D
M:6UA9V5;)VQO860G75LG9&%T82==*3L*("`@("`@("`@("`@9F-L;W-E*"1F
M9"D["B`@("`@("`@?0H*("`@("`@("`D:6UA9V5;)VEM9R==(#T@<V5R:6%L
M:7IE*&%R<F%Y*"=F:6QE)R`]/B`D:6UA9V5;)VQO860G75LG9FEL92==*2D[
M"B`@("`@("`@=6YS970H)&EM86=E6R=L;V%D)UTI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`]
M(&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*"));6%G92!U
M<&QO860B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@
M("`@("`@("`@("=S:&]W7W5P;&]A9"<@("`]/B!A<G)A>2@G;&%B96PG(#T^
M(%\H(E-H;W<@=7!L;V%D(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G='EP92<@(#T^("=B;V]L96%N)RDL"B`@("`@("`@("`@
M("=S:&]W7VME97!O<FEG)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-H;W<@
M;W!T:6]N('1O(&ME97`@;W)I9VEN86PB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2D["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]B;V]L96%N(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@
M>PH@("`@("`@("1I;F9O(#T@4W1R:6YG.CIL;W=E<B@D=F%R<RT^9V5T*"1V
M87(M/F=E=%9A<DYA;64H*2DI(#T]("=O;B<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R
M87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E1R=64@;W(@9F%L
M<V4B*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@
M2&]R9&5?1F]R;5]4>7!E7VQI;FL@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@
M>PH*("`@(&9U;F-T:6]N(&EN:70H)'9A;'5E<RD*("`@('L*("`@("`@("`D
M=&AI<RT^=F%L=65S(#T@)'9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!I
M<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@
M>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@
M("`@("`@("`@)VYA;64G(#T^(%\H(DQI;FLB*2P*("`@("`@("`@("`@)W!A
M<F%M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`G=7)L)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(DQI;FL@55),
M(BDL"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RDL"B`@
M("`@("`@("`@("`@("`G=&5X="<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@)VQA8F5L)R`]/B!?*"),:6YK('1E>'0B*2P*("`@("`@("`@("`@
M("`@("`@("`G='EP92<@/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=T
M87)G970G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=L86)E;"<@
M/3X@7R@B3&EN:R!T87)G970B*2P*("`@("`@("`@("`@("`@("`@("`G='EP
M92<@/3X@)W1E>'0G*2P*("`@("`@("`@("`@("`@("=O;F-L:6-K)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`G;&%B96PG(#T^(%\H(D]N8VQI
M8VL@979E;G0B*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E
M>'0G*2P*("`@("`@("`@("`@("`@("=T:71L92<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK('1I=&QE(&%T=')I
M8G5T92(I+`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G=&5X="<I
M+`H@("`@("`@("`@("`@("`@)V%C8V5S<VME>2<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)VQA8F5L)R`]/B!?*"),:6YK(&%C8V5S<R!K97DB
M*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G*2DI.PH@
M("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V5M86EL(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]A;&QO=U]M=6QT:2`](&9A
M;'-E.PH@("`@=F%R("1?<W1R:7!?9&]M86EN(#T@9F%L<V4["B`@("!V87(@
M)%]L:6YK7V-O;7!O<V4@/2!F86QS93L*("`@('9A<B`D7VQI;FM?;F%M92`]
M(&YU;&P["@H@("`@9G5N8W1I;VX@:6YI="@D86QL;W=?;75L=&D@/2!F86QS
M92P@)'-T<FEP7V1O;6%I;B`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`D
M;&EN:U]C;VUP;W-E(#T@9F%L<V4L("1L:6YK7VYA;64@/2!N=6QL*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?86QL;W=?;75L=&D@/2`D86QL;W=?;75L=&D[
M"B`@("`@("`@)'1H:7,M/E]S=')I<%]D;VUA:6X@/2`D<W1R:7!?9&]M86EN
M.PH@("`@("`@("1T:&ES+3Y?;&EN:U]C;VUP;W-E(#T@)&QI;FM?8V]M<&]S
M93L*("`@("`@("`D=&AI<RT^7VQI;FM?;F%M92`]("1L:6YK7VYA;64["B`@
M("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L
M=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U
M:7)E9"@I("8F(&5M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@)&UE<W-A
M9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=F%L
M=64I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G36%I;"]21D,X,C(N
M<&AP)SL*("`@("`@("`@("`@)'!A<G-E<B`]("9N97<@36%I;%]21D,X,C(H
M*3L*("`@("`@("`@("`@)'!A<G-E9%]E;6%I;"`]("1P87)S97(M/G!A<G-E
M061D<F5S<TQI<W0H)'9A;'5E+"!F86QS92P@=')U92D["@H@("`@("`@("`@
M("!I9B`H:7-?82@D<&%R<V5D7V5M86EL+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D;65S<V%G92`]("1P87)S961?96UA:6PM/F=E=$UE
M<W-A9V4H*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H*"$D=&AI<RT^7V%L;&]W7VUU;'1I
M*2`F)B!C;W5N="@D<&%R<V5D7V5M86EL*2`^(#$I('L*("`@("`@("`@("`@
M("`@("1M97-S86=E(#T@7R@B3VYL>2!O;F4@96UA:6P@861D<F5S<R!A;&QO
M=V5D+B(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AE;7!T>2@D<&%R<V5D7V5M86EL6S!=
M+3YM86EL8F]X*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")9
M;W4@9&ED(&YO="!E;G1E<B!A('9A;&ED(&5M86EL(&%D9')E<W,N(BD["B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R
M<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")%;6%I;"(I.PH@
M("`@("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@
M)V%L;&]W7VUU;'1I)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D%L;&]W(&UU
M;'1I<&QE(&%D9')E<W-E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@
M)W-T<FEP7V1O;6%I;B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3=')I<"!D
M;VUA:6X@9G)O;2!T:&4@861D<F5S<R(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G='EP92<@/3X@)V)O;VQE86XG*2P*("`@("`@
M("`@("`@)VQI;FM?8V]M<&]S92<@/3X@87)R87DH)VQA8F5L)R`]/B!?*"),
M:6YK('1H92!E;6%I;"!A9&1R97-S('1O('1H92!C;VUP;W-E('!A9V4@=VAE
M;B!D:7-P;&%Y:6YG(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`]/B`G8F]O;&5A;B<I+`H@("`@("`@("`@("`G;&EN
M:U]N86UE)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E1H92!N86UE('1O('5S
M92!W:&5N(&QI;FMI;F<@=&\@=&AE(&-O;7!O<V4@<&%G92(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)W1E>'0G
M*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO
M<F1E7T9O<FU?5'EP95]M871R:7@@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@
M>PH*("`@('9A<B`D7V-O;',["B`@("!V87(@)%]R;W=S.PH@("`@=F%R("1?
M;6%T<FEX.PH@("`@=F%R("1?;F5W7VEN<'5T.PH*("`@("\J*@H@("`@("H@
M26YI=&EA;&EZ97,@=&AE('9A<FEA8FQE+@H@("`@("H*("`@("`J($!E>&%M
M<&QE"B`@("`@*B!I;FET*&%R<F%Y*"=#;VQU;6X@02<L("=#;VQU;6X@0B<I
M+`H@("`@("H@("`@("!A<G)A>2@Q(#T^("=2;W<@3VYE)RP@,B`]/B`G4F]W
M(#(G+"`S(#T^("=2;W<@,R<I+`H@("`@("H@("`@("!A<G)A>2AA<G)A>2AT
M<G5E+"!T<G5E+"!F86QS92DL"B`@("`@*B`@("`@("`@("`@(&%R<F%Y*'1R
M=64L(&9A;'-E+"!T<G5E*2P*("`@("`J("`@("`@("`@("`@87)R87DH9F%S
M;&4L('1R=64L(&9A;'-E*2DL"B`@("`@*B`@("`@(&%R<F%Y*"=2;W<@-"<L
M("=2;W<@-2<I*3L*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-O;',@
M("`@("`@("`@("`@("!!(&QI<W0@;V8@8V]L=6UN(&AE861E<G,N"B`@("`@
M*B!`<&%R86T@87)R87D@)')O=W,@("`@("`@("`@("`@("!!(&AA<V@@=VET
M:"!R;W<@241S(&%S('1H92!K97ES(&%N9"!R;W<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&QA8F5L<R!A<R!T:&4@=F%L=65S
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1M871R:7@@("`@("`@("`@("`@02!T
M=V\@9&EM96YS:6]N86P@:&%S:"!W:71H('1H92!F:65L9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=F%L=65S+@H@("`@("H@
M0'!A<F%M(&)O;VQE86Y\87)R87D@)&YE=U]I;G!U="`@268@=')U92P@82!F
M<F5E('1E>'0@9FEE;&0@=&\@861D(&$@;F5W"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R;W<@:7,@9&ES<&QA>65D(&]N('1H
M92!T;W`L(&$@<V5L96-T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B;W@@:68@=&AI<R!P87)A;65T97(@:7,@82!V86QU92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6YI="@D8V]L<RP@)')O=W,@/2!A<G)A
M>2@I+"`D;6%T<FEX(#T@87)R87DH*2P@)&YE=U]I;G!U="`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?8V]L<R`@("`@("`]("1C;VQS.PH@("`@
M("`@("1T:&ES+3Y?<F]W<R`@("`@("`]("1R;W=S.PH@("`@("`@("1T:&ES
M+3Y?;6%T<FEX("`@("`]("1M871R:7@["B`@("`@("`@)'1H:7,M/E]N97=?
M:6YP=70@(#T@)&YE=U]I;G!U=#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U9A
M;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@>PH@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O
M;',H*2`@("`@>R!R971U<FX@)'1H:7,M/E]C;VQS.R!]"B`@("!F=6YC=&EO
M;B!G9712;W=S*"D@("`@('L@<F5T=7)N("1T:&ES+3Y?<F]W<SL@?0H@("`@
M9G5N8W1I;VX@9V5T36%T<FEX*"D@("![(')E='5R;B`D=&AI<RT^7VUA=')I
M>#L@?0H@("`@9G5N8W1I;VX@9V5T3F5W26YP=70H*2![(')E='5R;B`D=&AI
M<RT^7VYE=U]I;G!U=#L@?0H*("`@(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S
M+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R
M<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@:68@*"%E;7!T
M>2@D=F%L=65S6R=N)UU;)W(G72D@)B8@:7-S970H)'9A;'5E<ULG;B==6R=V
M)UTI*2!["B`@("`@("`@("`@("1N97=?<F]W(#T@)'9A;'5E<ULG;B==6R=R
M)UT["B`@("`@("`@("`@("1V86QU97-;)W(G75LD;F5W7W)O=UT@/2`D=F%L
M=65S6R=N)UU;)W8G73L*("`@("`@("`@("`@=6YS970H)'9A;'5E<ULG;B==
M*3L*("`@("`@("!]"@H@("`@("`@("1I;F9O(#T@*&ES<V5T*"1V86QU97-;
M)W(G72D@/R`D=F%L=65S6R=R)UT@.B!A<G)A>2@I*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH
M*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D9I96QD(&UA=')I>"(I
M.PH@("`@("`@("1A8F]U=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@
M("`@)V-O;',G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B0V]L=6UN('1I=&QE
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M<W1R:6YG;&ES="<I*3L*("`@("`@("!R971U<FX@)&%B;W5T.PH@("`@?0H*
M?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V5M86EL0V]N9FER;2!E>'1E;F1S
M($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I
M9B`H)'9A<BT^:7-297%U:7)E9"@I("8F(&5M<'1Y*"1V86QU95LG;W)I9VEN
M86PG72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)'9A;'5E6R=O<FEG:6YA;"==("$]("1V
M86QU95LG8V]N9FER;2==*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B
M16UA:6P@861D<F5S<V5S(&UU<W0@;6%T8V@N(BD["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S
M97(@/2`F;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("1P87)S961?
M96UA:6P@/2`D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1V86QU95LG;W)I
M9VEN86PG72P@9F%L<V4L('1R=64I.PH*("`@("`@("`@("`@:68@*&-O=6YT
M*"1P87)S961?96UA:6PI(#X@,2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A
M9V4@/2!?*")/;FQY(&]N92!E;6%I;"!A9&1R97-S(&%L;&]W960N(BD["B`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1P87)S961?96UA:6Q;,%TM/FUA:6QB;W@I
M*2!["B`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H(EEO=2!D:60@;F]T
M(&5N=&5R(&$@=F%L:60@96UA:6P@861D<F5S<RXB*3L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@
M("`@("`D86)O=71;)VYA;64G72`](%\H(D5M86EL('=I=&@@8V]N9FER;6%T
M:6]N(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S
M($AO<F1E7T9O<FU?5'EP95]P87-S=V]R9"!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D
M=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T<G5E
M.PH*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@
M("`@("1V86QI9"`]('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,#L*"B`@("`@
M("`@("`@(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S<V%G
M92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L:60["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B
M;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(E!A
M<W-W;W)D(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L
M87-S($AO<F1E7T9O<FU?5'EP95]P87-S=V]R9$-O;F9I<FT@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@
M*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=65;)V]R:6=I;F%L
M)UTI*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I
M<R!R97%U:7)E9"XB*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1V86QU95LG;W)I9VEN86PG72`A/2`D=F%L
M=65;)V-O;F9I<FTG72D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H(E!A
M<W-W;W)D<R!M=7-T(&UA=&-H+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@)B1V87(L("8D:6YF;RD*("`@
M('L*("`@("`@("`D=F%L=64@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA
M;64H*2D["B`@("`@("`@)&EN9F\@/2`D=F%L=65;)V]R:6=I;F%L)UT["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@
M("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`]
M(%\H(E!A<W-W;W)D('=I=&@@8V]N9FER;6%T:6]N(BD["B`@("`@("`@<F5T
M=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]E
M;G5M(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]V86QU
M97,["B`@("!V87(@)%]P<F]M<'0["@H@("`@9G5N8W1I;VX@:6YI="@D=F%L
M=65S+"`D<')O;7!T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W9A
M;'5E<R`]("1V86QU97,["@H@("`@("`@(&EF("@D<')O;7!T(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')O;7!T(#T@7R@B+2T@<V5L96-T
M("TM(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F]M<'0@/2`D<')O;7!T.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@
M("`@>PH@("`@("`@(&EF("@D=F%R+3YI<U)E<75I<F5D*"D@)B8@)'9A;'5E
M(#T]("<G("8F("%I<W-E="@D=&AI<RT^7W9A;'5E<ULD=F%L=65=*2D@>PH@
M("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!I<W-E
M="@D=&AI<RT^7W9A;'5E<ULD=F%L=65=*2!\?`H@("`@("`@("`@("`H)'1H
M:7,M/E]P<F]M<'0@)B8@96UP='DH)'9A;'5E*2DI('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H
M(DEN=F%L:60@9&%T82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=%!R;VUP="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<')O;7!T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O
M=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@
M("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T
M6R=N86UE)UT@/2!?*")$<F]P(&1O=VX@;&ES="(I.PH@("`@("`@("1A8F]U
M=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@
M87)R87DH)VQA8F5L)R`]/B!?*")686QU97,@=&\@<V5L96-T(&9R;VTB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R
M:6YG;&ES="<I+`H@("`@("`@("`@("`G<')O;7!T)R`]/B!A<G)A>2@G;&%B
M96PG(#T^(%\H(E!R;VUP="!T97AT(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@)W1E>'0G*2D["B`@("`@("`@<F5T=7)N
M("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]M;&5N
M=6T@97AT96YD<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W9A;'5E
M<SL*("`@('9A<B`D7W!R;VUP=',["@H@("`@9G5N8W1I;VX@:6YI="@F)'9A
M;'5E<RP@)'!R;VUP=',@/2!N=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M=F%L=65S(#T@)B1V86QU97,["@H@("`@("`@(&EF("@D<')O;7!T<R`]/3T@
M=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;VUP=',@/2!A<G)A>2A?
M*"(M+2!S96QE8W0@+2TB*2P@7R@B+2T@<V5L96-T("TM(BDI.PH@("`@("`@
M('T@96QS96EF("@A:7-?87)R87DH)'!R;VUP=',I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<')O;7!T<R`](&%R<F%Y*"1P<F]M<'1S+"`D<')O;7!T<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P<F]M<'1S
M(#T@)'!R;VUP=',["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&]N
M4W5B;6ET*"8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@)'9A;'5E(#T@)'9A<G,M
M/F=E="@D=F%R;F%M92D["@H@("`@("`@(&EF("@D=F%L=65;)S$G72`A/2`D
M=F%L=65;)V]L9"==*2!["B`@("`@("`@("`@("1V87(M/F9O<FTM/G-E=%-U
M8FUI='1E9"AF86QS92D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&ES5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@
M("!["B`@("`@("`@:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B`H96UP='DH
M)'9A;'5E6R<Q)UTI('Q\(&5M<'1Y*"1V86QU95LG,B==*2DI('L*("`@("`@
M("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(6-O=6YT*"1T:&ES+3Y?=F%L=65S*2!\?"!I<W-E="@D=&AI<RT^
M7W9A;'5E<ULD=F%L=65;)S$G75TI('Q\"B`@("`@("`@("`@("@A96UP='DH
M)'1H:7,M/E]P<F]M<'1S*2`F)B!E;7!T>2@D=F%L=65;)S$G72DI*2!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE
M<W-A9V4@/2!?*"));G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(I.PH@("`@("`@
M(')E='5R;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;'5E<SL*("`@('T*
M"B`@("!F=6YC=&EO;B!G9710<F]M<'1S*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]P<F]M<'1S.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$EN
M9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@>PH@("`@("`@("1I;F9O
M(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@(')E
M='5R;B`D:6YF;ULG,B==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@
M("`@)&%B;W5T6R=N86UE)UT@/2!?*")-=6QT:2UL979E;"!D<F]P(&1O=VX@
M;&ES=',B*3L*("`@("`@("`D86)O=71;)W!A<F%M<R==(#T@87)R87DH"B`@
M("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L
M=65S('1O('-E;&5C="!F<F]M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2P*("`@("`@("`@("`@
M)W!R;VUP="<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")0<F]M<'0@=&5X="(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T
M97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S
M<R!(;W)D95]&;W)M7U1Y<&5?;75L=&EE;G5M(&5X=&5N9',@2&]R9&5?1F]R
M;5]4>7!E7V5N=6T@>PH*("`@('9A<B`D<VEZ92`](#4["@H@("`@9G5N8W1I
M;VX@:6YI="@D=F%L=65S+"`D<VEZ92`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1S:7IE*2D@>PH@("`@("`@("`@("`D=&AI<RT^<VEZ
M92`]("AI;G0I)'-I>F4["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.FEN
M:70H)'9A;'5E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I
M9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D
M=F%L=64@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^
M:7-686QI9"@D=F%R+"`D=F%R<RP@)'9A;"P@)&UE<W-A9V4I*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1V86QU92D@)B8@*"AS=')I;F<I
M*&EN="DD=F%L=64@(3T]("1V86QU92DI('L*("`@("`@("`@("`@:68@*"1V
M87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@
M/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!I
M<W-E="@D=&AI<RT^7W9A;'5E<ULD=F%L=65=*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E(#T@7R@B
M26YV86QI9"!D871A('-U8FUI='1E9"XB*3L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA
M;64G72`](%\H(DUU;'1I<&QE('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U
M=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@
M87)R87DH)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@
M("`@("`@("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M:6YT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S
M<R!(;W)D95]&;W)M7U1Y<&5?<F%D:6\@97AT96YD<R!(;W)D95]&;W)M7U1Y
M<&5?96YU;2!["@H@("`@+RH@16YT:7)E;'D@:6UP;&5M96YT960@8GD@2&]R
M9&5?1F]R;5]4>7!E7V5N=6T[(&IU<W0@82!D:69F97)E;G0*("`@("`J('9I
M97<N("HO"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@)&%B;W5T(#T@87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G
M72`](%\H(E)A9&EO('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U=%LG<&%R
M86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R87DH
M)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I*3L*("`@("`@("!R
M971U<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E
M7W-E="!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R("1?=F%L
M=65S.PH@("`@=F%R("1?8VAE8VM!;&P@/2!F86QS93L*"B`@("!F=6YC=&EO
M;B!I;FET*"8D=F%L=65S+"`D8VAE8VM!;&P@/2!F86QS92D*("`@('L*("`@
M("`@("`D=&AI<RT^7W9A;'5E<R`]("1V86QU97,["B`@("`@("`@)'1H:7,M
M/E]C:&5C:T%L;"`]("1C:&5C:T%L;#L*("`@('T*"B`@("!F=6YC=&EO;B!I
M<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@("`@
M>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W9A;'5E<RD@/3T@,"!\?"!C
M;W5N="@D=F%L=64I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:71E;2D@
M>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=F%L=65S6R1I=&5M
M72DI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]('1R=64["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1E<G)O<BDI('L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G92`](%\H(DEN=F%L:60@
M9&%T82!S=6)M:71T960N(BD["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=%9A;'5E<R@I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=F%L=65S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@
M("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")3970B*3L*("`@("`@("`D86)O
M=71;)W!A<F%M<R==(#T@87)R87DH"B`@("`@("`@("`@("=V86QU97,G(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B5F%L=65S(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2D["B`@
M("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O
M<FU?5'EP95]D871E(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V
M87(@)%]F;W)M870["@H@("`@9G5N8W1I;VX@:6YI="@D9F]R;6%T(#T@)R5A
M("5D("5")RD*("`@('L*("`@("`@("`D=&AI<RT^7V9O<FUA="`]("1F;W)M
M870["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S
M+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("`D=F%L:60@/2!T
M<G5E.PH*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@
M("`@("`@("1V86QI9"`]('-T<FQE;BAT<FEM*"1V86QU92DI(#X@,#L*"B`@
M("`@("`@("`@(&EF("@A)'9A;&ED*2!["B`@("`@("`@("`@("`@("`D;65S
M<V%G92`]('-P<FEN=&8H7R@B)7,@:7,@<F5Q=6ER960B*2P@)'9A<BT^9V5T
M2'5M86Y.86UE*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'9A;&ED.PH@("`@?0H*("`@("\J*@H@("`@("H@0'-T871I
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971!9V\H)'1I;65S=&%M<"D*("`@
M('L*("`@("`@("!R97%U:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G.PH@("`@
M("`@("1D:69F9&%Y<R`]($1A=&5?0V%L8SHZ9&%T941I9F8H9&%T92@G:B<L
M("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9&%T92@G;B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T92@G62<L("1T:6UE<W1A
M;7`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9&%T92@G:B<I+"!D871E*"=N)RDL(&1A=&4H)UDG*2D["@H@("`@("`@("\J
M($%N(&5R<F]R(&]C8W5R960N("HO"B`@("`@("`@:68@*"1D:69F9&%Y<R`]
M/2`M,2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@
M("`D86=O(#T@)&1I9F9D87ES("H@1&%T95]#86QC.CIC;VUP87)E1&%T97,H
M9&%T92@G:B<L("1T:6UE<W1A;7`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D871E*"=N)RP@)'1I;65S
M=&%M<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&1A=&4H)UDG+"`D=&EM97-T86UP*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&%T
M92@G:B<I+"!D871E*"=N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1A=&4H)UDG*2D["B`@("`@("`@
M:68@*"1A9V\@/"`M,2D@>PH@("`@("`@("`@("!R971U<FX@<W!R:6YT9BA?
M*"(@*"5S(&1A>7,@86=O*2(I+"`D9&EF9F1A>7,I.PH@("`@("`@('T@96QS
M96EF("@D86=O(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R;B!?*"(@*'EE
M<W1E<F1A>2DB*3L*("`@("`@("!](&5L<V5I9B`H)&%G;R`]/2`P*2!["B`@
M("`@("`@("`@(')E='5R;B!?*"(@*'1O9&%Y*2(I.PH@("`@("`@('T@96QS
M96EF("@D86=O(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N(%\H(B`H=&]M
M;W)R;W<I(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M('-P<FEN=&8H7R@B("AI;B`E<R!D87ES*2(I+"`D9&EF9F1A>7,I.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971&;W)M871T9614:6UE*"1T
M:6UE<W1A;7`L("1F;W)M870@/2!N=6QL+"`D<VAO=V%G;R`]('1R=64I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1F;W)M870I*2!["B`@("`@("`@("`@
M("1F;W)M870@/2`D=&AI<RT^7V9O<FUA=#L*("`@("`@("!]"B`@("`@("`@
M:68@*"%E;7!T>2@D=&EM97-T86UP*2D@>PH@("`@("`@("`@("!R971U<FX@
M<W1R9G1I;64H)&9O<FUA="P@)'1I;65S=&%M<"D@+B`H)'-H;W=A9V\@/R!(
M;W)D95]&;W)M7U1Y<&5?9&%T93HZ9V5T06=O*"1T:6UE<W1A;7`I(#H@)R<I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U
M="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")$871E(BDI
M.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W1I;64@97AT96YD
M<R!(;W)D95]&;W)M7U1Y<&4@>PH*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V
M87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M:68@*"1V87(M/FES4F5Q=6ER960H*2`F)B!E;7!T>2@D=F%L=64I("8F("@H
M<W1R:6YG*2AD;W5B;&4I)'9A;'5E("$]/2`D=F%L=64I*2!["B`@("`@("`@
M("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&5M<'1Y*"1V86QU92D@?'P@<')E9U]M871C:"@G+UY;,"TR73];,"TY
M73I;,"TU75LP+3E=)"\G+"`D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES
M(&9I96QD(&UA>2!O;FQY(&-O;G1A:6X@;G5M8F5R<R!A;F0@=&AE(&-O;&]N
M+B(I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("!R971U<FX@87)R87DH
M)VYA;64G(#T^(%\H(E1I;64B*2D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&
M;W)M7U1Y<&5?:&]U<DUI;G5T95-E8V]N9"!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@=F%R("1?<VAO=U]S96-O;F1S.PH*("`@(&9U;F-T:6]N
M(&EN:70H)'-H;W=?<V5C;VYD<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<VAO=U]S96-O;F1S(#T@)'-H;W=?<V5C;VYD<SL*("`@('T*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@("1T:6UE(#T@)'9A<G,M/F=E="@D=F%R
M+3YG971687).86UE*"DI.PH@("`@("`@(&EF("@A)'1H:7,M/E]S:&]W7W-E
M8V]N9',@)B8@(6ES<V5T*"1T:6UE6R=S96-O;F0G72DI('L*("`@("`@("`@
M("`@)'1I;65;)W-E8V]N9"==(#T@,#L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)'1H:7,M/F5M<'1Y5&EM94%R<F%Y*"1T:6UE*2`F)B`A)'1H:7,M/F-H
M96-K=&EM92@D=&EM95LG:&]U<B==+"`D=&EM95LG;6EN=71E)UTL("1T:6UE
M6R=S96-O;F0G72DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")0;&5A
M<V4@96YT97(@82!V86QI9"!T:6UE+B(I.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YE;7!T>51I;65!<G)A
M>2@D=&EM92D@)B8@)'9A<BT^:7-297%U:7)E9"@I*2!["B`@("`@("`@("`@
M("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U:7)E9"XB*3L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@8VAE8VMT:6UE*"1H;W5R
M+"`D;6EN=71E+"`D<V5C;VYD*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)&AO=7(I('Q\("1H;W5R(#T]("<G('Q\("@D:&]U<B`\(#`@?'P@)&AO=7(@
M/B`R,RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!I9B`H(6ES<V5T*"1M:6YU=&4I('Q\("1M:6YU=&4@/3T@)R<@
M?'P@*"1M:6YU=&4@/"`P('Q\("1M:6YU=&4@/B`V,"DI('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T
M*"1S96-O;F0I('Q\("1S96-O;F0@/3T]("<G('Q\("@D<V5C;VYD(#P@,"!\
M?"`D<V5C;VYD(#X@-C`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!T:6UE('-U<'!L:65D(&%S(&$@2&]R9&5?
M1&%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&EM
M95]I;B`@1&%T92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R
M=&5D(&)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&
M;W)M(&%N9"!(;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A
M;7`@65E964U-1$1(2$U-4U,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!53DE8(&5P;V-H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A
M=&4@(%1H92!T:6UE(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M5&EM94]B*"1T:6UE7VEN*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O1&%T92YP:'`G.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1I;65?
M:6XI*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/F5M<'1Y5&EM94%R<F%Y
M*"1T:6UE7VEN*2D@>PH@("`@("`@("`@("`@("`@)'1I;65?:6X@/2!S<')I
M;G1F*"<Q.3<P+3`Q+3`Q("4P,F0Z)3`R9#HE,#)D)RP@)'1I;65?:6Y;)VAO
M=7(G72P@)'1I;65?:6Y;)VUI;G5T92==+"`D=&EM95]I;ELG<V5C;VYD)UTI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@;F5W
M($AO<F1E7T1A=&4H)'1I;65?:6XI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N('1H92!T:6UE('-U<'!L:65D('-P;&ET('5P(&EN=&\@86X@87)R
M87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&EM95]I;B`@5&EM
M92!I;B!O;F4@;V8@=&AE('1H<F5E(&9O<FUA=',@<W5P<&]R=&5D(&)Y"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]&;W)M(&%N9"!(
M;W)D95]$871E("A)4T\@9F]R;6%T"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!965E9+4U-+41$($A(.DU-.E-3+"!T:6UE<W1A;7`@65E964U-
M1$1(2$U-4U,@86YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!5
M3DE8(&5P;V-H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A
M>2!W:71H('1H<F5E(&5L96UE;G1S("T@:&]U<BP@;6EN=71E(&%N9"!S96-O
M;F1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:6UE4&%R=',H)'1I;65?
M:6XI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:6UE7VEN*2D@>PH@
M("`@("`@("`@("`O*B!4:&ES(&ES('!R;V)A8FQY(&$@9F%I;&5D(&ES5F%L
M:60@:6YP=70@<V\@:G5S="!R971U<FX@=&AE"B`@("`@("`@("`@("`J('!A
M<G1S(&%S('1H97D@87)E+B`J+PH@("`@("`@("`@("!R971U<FX@)'1I;65?
M:6X["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:6UE7VEN*2D@>PH@("`@
M("`@("`@("`O*B!4:&ES(&ES(&IU<W0@86X@96UP='D@9FEE;&0@<V\@<F5T
M=7)N(&5M<'1Y('!A<G1S+B`J+PH@("`@("`@("`@("!R971U<FX@87)R87DH
M)VAO=7(G(#T^("<G+"`G;6EN=71E)R`]/B`G)RP@)W-E8V]N9"<@/3X@)R<I
M.PH@("`@("`@('T*("`@("`@("`D=&EM92`]("1T:&ES+3YG9714:6UE3V(H
M)'1I;65?:6XI.PH@("`@("`@(')E='5R;B!A<G)A>2@G:&]U<B<@/3X@)'1I
M;64M/FAO=7(L"B`@("`@("`@("`@("`@("`@("`@("=M:6YU=&4G(#T^("1T
M:6UE+3YM:6XL"B`@("`@("`@("`@("`@("`@("`@("=S96-O;F0G(#T^("1T
M:6UE+3YS96,I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5M<'1Y5&EM94%R<F%Y
M*"1T:6UE*0H@("`@>PH@("`@("`@(')E='5R;B`H:7-?87)R87DH)'1I;64I
M("8F(&5M<'1Y*"1T:6UE6R=H;W5R)UTI("8F(&5M<'1Y*"1T:6UE6R=M:6YU
M=&4G72D@)B8@96UP='DH)'1I;65;)W-E8V]N9"==*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L9"!T>7!E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=N86UE)R`]/B!?*")4:6UE('-E;&5C=&EO;B(I*3L*("`@('T*
M"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]M;VYT:%EE87(@97AT96YD<R!(
M;W)D95]&;W)M7U1Y<&4@>PH*("`@('9A<B`D7W-T87)T7WEE87(["B`@("!V
M87(@)%]E;F1?>65A<CL*"B`@("!F=6YC=&EO;B!I;FET*"1S=&%R=%]Y96%R
M(#T@;G5L;"P@)&5N9%]Y96%R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'-T87)T7WEE87(I*2!["B`@("`@("`@("`@("1S=&%R=%]Y96%R
M(#T@,3DR,#L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1E;F1?>65A
M<BDI('L*("`@("`@("`@("`@)&5N9%]Y96%R(#T@9&%T92@G62<I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]S=&%R=%]Y96%R(#T@)'-T87)T7WEE
M87(["B`@("`@("`@)'1H:7,M/E]E;F1?>65A<B`]("1E;F1?>65A<CL*("`@
M('T*"B`@("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU
M92P@)B1M97-S86=E*0H@("`@>PH@("`@("`@(&EF("@A)'9A<BT^:7-297%U
M:7)E9"@I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D=F%R<RT^9V5T*"1T:&ES+3YG971-;VYT:%9A<B@D
M=F%R*2D@?'P*("`@("`@("`@("`@(21V87)S+3YG970H)'1H:7,M/F=E=%EE
M87)687(H)'9A<BDI*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4&QE
M87-E(&5N=&5R(&$@;6]N=&@@86YD(&$@>65A<BXB*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T36]N=&A687(H)'9A<BD*("`@('L*
M("`@("`@("!R971U<FX@)'9A<BT^9V5T5F%R3F%M92@I("X@)UMM;VYT:%TG
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%EE87)687(H)'9A<BD*("`@('L*
M("`@("`@("!R971U<FX@)'9A<BT^9V5T5F%R3F%M92@I("X@)UMY96%R72<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F:65L
M9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")-;VYT:"!A;F0@>65A
M<B(I+`H@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=%]Y96%R)R`]/B!A<G)A
M>2@G;&%B96PG(#T^(%\H(E-T87)T('EE87(B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=S
M=')I;F=L:7-T)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G96YD7WEE
M87(G("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")%;F0@>65A<B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@)W-T<FEN9VQI<W0G*2DI.PH@("`@?0H*?0H*8VQA<W,@2&]R
M9&5?1F]R;5]4>7!E7VUO;G1H1&%Y665A<B!E>'1E;F1S($AO<F1E7T9O<FU?
M5'EP92!["@H@("`@=F%R("1?<W1A<G1?>65A<CL*("`@('9A<B`D7V5N9%]Y
M96%R.PH@("`@=F%R("1?<&EC:V5R.PH@("`@=F%R("1?9F]R;6%T7VEN(#T@
M;G5L;#L*("`@('9A<B`D7V9O<FUA=%]O=70@/2`G)7@G.PH*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!D871E('-U<'!L:65D(&%S(&$@2&]R9&5?1&%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T
M7WEE87(@(%1H92!F:7)S="!A=F%I;&%B;&4@>65A<B!F;W(@:6YP=70N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D96YD7WEE87(@("`@5&AE(&QA<W0@879A
M:6QA8FQE('EE87(@9F]R(&EN<'5T+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'!I8VME<B`@("`@($1O('=E('-H;W<@=&AE($1(5$U,(&-A;&5N9&%R/PH@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&9O<FUA=%]I;B`@(%1H92!F;W)M870@
M=&\@=7-E('=H96X@<V5N9&EN9R!T:&4@9&%T90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<B!S=&]R86=E+B!$969A=6QT<R!T;R!5
M;FEX(&5P;V-H+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%-I;6EL87(@=&\@=&AE('-T<F9T:6UE*"D@9G5N8W1I;VXN"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D9F]R;6%T7V]U="`@5&AE(&9O<FUA="!T;R!U<V4@
M=VAE;B!D:7-P;&%Y:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1A=&4N(%-I;6EL87(@=&\@=&AE('-T<F9T:6UE*"D@9G5N
M8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H)'-T87)T7WEE87(@
M/2`G)RP@)&5N9%]Y96%R(#T@)R<L("1P:6-K97(@/2!T<G5E+`H@("`@("`@
M("`@("`@("`@("`D9F]R;6%T7VEN(#T@;G5L;"P@)&9O<FUA=%]O=70@/2`G
M)7@G*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<W1A<G1?>65A<BDI('L*
M("`@("`@("`@("`@)'-T87)T7WEE87(@/2!D871E*"=9)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D96YD7WEE87(I*2!["B`@("`@("`@("`@
M("1E;F1?>65A<B`](&1A=&4H)UDG*2`K(#$P.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]S=&%R=%]Y96%R(#T@)'-T87)T7WEE87(["B`@("`@("`@
M)'1H:7,M/E]E;F1?>65A<B`]("1E;F1?>65A<CL*("`@("`@("`D=&AI<RT^
M7W!I8VME<B`]("1P:6-K97(["B`@("`@("`@)'1H:7,M/E]F;W)M871?:6X@
M/2`D9F]R;6%T7VEN.PH@("`@("`@("1T:&ES+3Y?9F]R;6%T7V]U="`]("1F
M;W)M871?;W5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES5F%L:60H)B1V87(L
M("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@)&1A
M=&4@/2`D=F%R<RT^9V5T*"1V87(M/F=E=%9A<DYA;64H*2D["B`@("`@("`@
M)&5M<'1Y(#T@)'1H:7,M/F5M<'1Y1&%T94%R<F%Y*"1D871E*3L*"B`@("`@
M("`@:68@*"1E;7!T>2`]/2`Q("8F("1V87(M/FES4F5Q=6ER960H*2D@>PH@
M("`@("`@("`@("`D;65S<V%G92`](%\H(E1H:7,@9FEE;&0@:7,@<F5Q=6ER
M960N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L
M<V5I9B`H)&5M<'1Y(#T](#`@)B8@(6-H96-K9&%T92@D9&%T95LG;6]N=&@G
M72P@)&1A=&5;)V1A>2==+"`D9&%T95LG>65A<B==*2D@>PH@("`@("`@("`@
M("`D;65S<V%G92`](%\H(E!L96%S92!E;G1E<B!A('9A;&ED(&1A=&4L(&-H
M96-K('1H92!N=6UB97(@;V8@9&%Y<R!I;B!T:&4@;6]N=&@N(BD["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V5I9B`H)&5M<'1Y
M(#T]("TQ*2!["B`@("`@("`@("`@("1M97-S86=E(#T@7R@B4V5L96-T(&%L
M;"!D871E(&-O;7!O;F5N=',N(BD["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&5M<'1Y1&%T94%R<F%Y*"1D871E*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&1A=&4I*2!["B`@("`@("`@("`@(')E='5R;B!E
M;7!T>2@D9&%T92D["B`@("`@("`@?0H*("`@("`@("`D96UP='D@/2`P.PH@
M("`@("`@("\J($-H96-K(&5A8V@@9&%T92!A<G)A>2!C;VUP;VYE;G0N("HO
M"B`@("`@("`@9F]R96%C:"`H)&1A=&4@87,@)&ME>2`]/B`D=F%L*2!["B`@
M("`@("`@("`@(&EF("AE;7!T>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@
M)&5M<'1Y*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M($-H96-K('-T871E(&]F(&5M<'1Y+B`J+PH@("`@("`@(&EF("@D96UP='D@
M/3T@,"D@>PH@("`@("`@("`@("`O*B!)9B!N;R!E;7!T>2!P87)T<R!R971U
M<FX@,"X@*B\*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?2!E;'-E
M:68@*"1E;7!T>2`]/2`S*2!["B`@("`@("`@("`@("\J($EF(&%L;"!E;7!T
M>2!P87)T<R!R971U<FX@,2X@*B\*("`@("`@("`@("`@<F5T=7)N(#$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@268@<V]M92!E;7!T>2!P
M87)T<R!R971U<FX@+3$N("HO"B`@("`@("`@("`@(')E='5R;B`M,3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&1A=&4@
M<W5P<&QI960@<W!L:70@=7`@:6YT;R!A;B!A<G)A>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D871E7VEN("!$871E(&EN(&]N92!O9B!T:&4@
M=&AR964@9F]R;6%T<R!S=7!P;W)T960@8GD*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@($AO<F1E7T9O<FT@86YD($AO<F1E7T1A=&4@*$E33R!F
M;W)M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%E965DM34TM
M1$0@2$@Z34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@86YD(%5.25@@97!O8V@I('!L=7,@
M=&AE(&9O=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%R<F%Y('=I=&@@=&AR964@96QE;65N=',@+2!Y96%R+"!M;VYT
M:"!A;F0@9&%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$871E4&%R=',H
M)&1A=&5?:6XI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D871E7VEN
M*2D@>PH@("`@("`@("`@("`O*B!4:&ES(&ES('!R;V)A8FQY(&$@9F%I;&5D
M(&ES5F%L:60@:6YP=70@<V\@:G5S="!R971U<FX*("`@("`@("`@("`@("H@
M=&AE('!A<G1S(&%S('1H97D@87)E+B`J+PH@("`@("`@("`@("!R971U<FX@
M)&1A=&5?:6X["B`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1D871E7VEN*2D@
M>PH@("`@("`@("`@("`O*B!4:&ES(&ES(&IU<W0@86X@96UP='D@9FEE;&0@
M<V\@<F5T=7)N(&5M<'1Y('!A<G1S+B`J+PH@("`@("`@("`@("!R971U<FX@
M87)R87DH)WEE87(G(#T^("<G+"`G;6]N=&@G(#T^("<G+"`G9&%Y)R`]/B`G
M)RD["B`@("`@("`@?0H*("`@("`@("`D9&%T92`]("1T:&ES+3YG971$871E
M3V(H)&1A=&5?:6XI.PH@("`@("`@(')E='5R;B!A<G)A>2@G>65A<B<@/3X@
M)&1A=&4M/GEE87(L"B`@("`@("`@("`@("`@("`@("`@("=M;VYT:"<@/3X@
M)&1A=&4M/FUO;G1H+`H@("`@("`@("`@("`@("`@("`@("`G9&%Y)R`]/B`D
M9&%T92T^;61A>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&1A=&4@<W5P<&QI960@87,@82!(;W)D95]$871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871E7VEN("!$871E(&EN(&]N92!O
M9B!T:&4@=&AR964@9F]R;6%T<R!S=7!P;W)T960@8GD*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@($AO<F1E7T9O<FT@86YD($AO<F1E7T1A=&4@
M*$E33R!F;W)M870*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%E9
M65DM34TM1$0@2$@Z34TZ4U,L('1I;65S=&%M<"!965E934U$1$A(34U34PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@86YD(%5.25@@97!O8V@I
M('!L=7,@=&AE(&9O=7)T:"!965E9+4U-+41$+@H@("`@("H*("`@("`J($!R
M971U<FX@1&%T92`@5&AE(&1A=&4@;V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971$871E3V(H)&1A=&5?:6XI"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]$871E+G!H<"<["@H@("`@("`@(&EF("AI<U]A<G)A
M>2@D9&%T95]I;BDI('L*("`@("`@("`@("`@+RH@268@<&%S<V5D(&%N(&%R
M<F%Y(&-H86YG92!I="!T;R!T:&4@25-/(&9O<FUA="X@*B\*("`@("`@("`@
M("`@:68@*"1T:&ES+3YE;7!T>41A=&5!<G)A>2@D9&%T95]I;BD@/3T@,"D@
M>PH@("`@("`@("`@("`@("`@)&1A=&5?:6X@/2!S<')I;G1F*"<E,#1D+24P
M,F0M)3`R9"`P,#HP,#HP,"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1A=&5?:6Y;)WEE87(G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T95]I;ELG;6]N=&@G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T95]I;ELG9&%Y)UTI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>
M7&1[-'TM7&1[,GTM7&1[,GTD+R<L("1D871E7VEN*2D@>PH@("`@("`@("`@
M("`O*B!&:7@@=&AE(&1A=&4@:68@:70@:7,@=&AE('-H;W)T96YE9"!)4T\N
M("HO"B`@("`@("`@("`@("1D871E7VEN(#T@)&1A=&5?:6X@+B`G(#`P.C`P
M.C`P)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!N97<@2&]R9&5?1&%T
M92@D9&%T95]I;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&1A=&4@<W5P<&QI960@87,@82!(;W)D95]$871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871E("!%:71H97(@86X@86QR96%D
M>2!S970@=7`@2&]R9&5?1&%T92!O8FIE8W0@;W(@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@<W1R:6YG(&1A=&4@:6X@;VYE(&]F('1H92!T:')E
M92!F;W)M871S('-U<'!O<G1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@8GD@2&]R9&5?1F]R;2!A;F0@2&]R9&5?1&%T92`H25-/(&9O<FUA=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@65E962U-32U$1"!(2#I-33I3
M4RP@=&EM97-T86UP(%E965E-341$2$A-35-3(&%N9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@54Y)6"!E<&]C:"D@<&QU<R!T:&4@9F]U<G1H(%E9
M65DM34TM1$0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D
M871E(&9O<FUA='1E9"!A8V-O<F1I;F<@=&\@=&AE("1F;W)M871?;W5T"B`@
M("`@*B`@("`@("`@("`@("`@("`@<&%R86UE=&5R('=H96X@<V5T=&EN9R!U
M<"!T:&4@;6]N=&AD87EY96%R(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!F;W)M871$871E*"1D871E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M9&%T92P@)T1A=&4G*2D@>PH@("`@("`@("`@("`D9&%T92`]("1T:&ES+3YG
M971$871E3V(H)&1A=&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D
M871E+3YS=')F=&EM92@D=&AI<RT^7V9O<FUA=%]O=70I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@26YS97)T('1H92!D871E(&EN<'5T('1H<F]U9V@@=&AE
M(&9O<FT@:6YT;R`D:6YF;R!A<G)A>2P@:6X@=&AE(&9O<FUA=`H@("`@("H@
M<W!E8VEF:65D(&)Y('1H92`D9F]R;6%T7VEN('!A<F%M971E<B!W:&5N('-E
M='1I;F<@=7`@;6]N=&AD87EY96%R"B`@("`@*B!F:65L9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@
M("!["B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W9A;&ED871E06YD1F]R;6%T
M*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@)'9A<BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!686QI9&%T92]F;W)M870@82!D871E('-U8FUI<W-I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T94%N9$9O<FUA="@D=F%L=64L
M("8D=F%R*0H@("`@>PH@("`@("`@("\J($EF(&%N>2!C;VUP;VYE;G0@:7,@
M96UP='D@8V]N<VED97(@:70@82!B860@9&%T92!A;F0@<F5T=7)N('1H90H@
M("`@("`@("`J(&1E9F%U;'0N("HO"B`@("`@("`@:68@*"1T:&ES+3YE;7!T
M>41A=&5!<G)A>2@D=F%L=64I(#T](#$I('L*("`@("`@("`@("`@<F5T=7)N
M("1V87(M/F=E=$1E9F%U;'0H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D9&%T92`]("1T:&ES+3YG971$871E3V(H)'9A;'5E*3L*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9F]R;6%T7VEN(#T]/2!N=6QL*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&1A=&4M/G1I;65S=&%M<"@I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871E+3YS
M=')F=&EM92@D=&AI<RT^7V9O<FUA=%]I;BD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U
M="!F:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=N86UE)R`]/B!?*")$871E('-E
M;&5C=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("=S=&%R=%]Y96%R)R`]
M/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-T87)T('EE87(B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@
M(#T^("=I;G0G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("=E;F1?>65A
M<B<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(D5N9"!Y96%R(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G:6YT)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`G<&EC
M:V5R)R`@("`@/3X@87)R87DH)VQA8F5L)R`]/B!?*")3:&]W('!I8VME<B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=T>7!E)R`@/3X@)V)O;VQE86XG*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("=F;W)M871?:6XG("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-T
M;W)A9V4@9F]R;6%T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)V9O<FUA=%]O=70G(#T^(&%R<F%Y*"=L86)E
M;"<@/3X@7R@B1&ES<&QA>2!F;W)M870B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT
M)RDI*3L*("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]C;VQO<E!I
M8VME<B!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@
M:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@
M('L*("`@("`@("!I9B`H)'9A<BT^:7-297%U:7)E9"@I("8F(&5M<'1Y*"1V
M86QU92DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD
M(&ES(')E<75I<F5D+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'9A;'5E*2!\?"!P<F5G7VUA
M=&-H*"<O7B,H6S`M.6$M>ETI>S9])"]I)RP@)'9A;'5E*2D@>PH@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@("1M97-S86=E
M(#T@7R@B5&AI<R!F:65L9"!M=7-T(&-O;G1A:6X@82!C;VQO<B!C;V1E(&EN
M('1H92!21T(@2&5X(&9O<FUA="P@9F]R(&5X86UP;&4@)R,Q,C,T868G+B(I
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I
M.PH@("`@("`@("1A8F]U=%LG;F%M92==(#T@7R@B0V]L;W5R('-E;&5C=&EO
M;B(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC;&%S<R!(
M;W)D95]&;W)M7U1Y<&5?<V]R=&5R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E
M('L*"B`@("!V87(@)%]I;G-T86YC93L*("`@('9A<B`D7W9A;'5E<SL*("`@
M('9A<B`D7W-I>F4["B`@("!V87(@)%]H96%D97(["@H@("`@9G5N8W1I;VX@
M:6YI="@D=F%L=65S+"`D<VEZ92`](#@L("1H96%D97(@/2`G)RD*("`@('L*
M("`@("`@("!S=&%T:6,@)&AO<F1E7W-O<G1E<E]I;G-T86YC92`](#`["@H@
M("`@("`@("\J($=E="!T:&4@;F5X="!P<F]G<F5S<VEV92!I;G-T86YC92!C
M;W5N="!F;W(@=&AE(&AO<F1E"B`@("`@("`@("H@<V]R=&5R('-O('1H870@
M;75L=&EP;&4@<V]R=&5R<R!C86X@8F4@=7-E9"!O;B!O;F4@<&%G92X@*B\*
M("`@("`@("`D:&]R9&5?<V]R=&5R7VEN<W1A;F-E*RL["B`@("`@("`@)'1H
M:7,M/E]I;G-T86YC92`]("=H;W)D95]S;W)T97)?)R`N("1H;W)D95]S;W)T
M97)?:6YS=&%N8V4["B`@("`@("`@)'1H:7,M/E]V86QU97,@/2`D=F%L=65S
M.PH@("`@("`@("1T:&ES+3Y?<VEZ92`@(#T@)'-I>F4["B`@("`@("`@)'1H
M:7,M/E]H96%D97(@/2`D:&5A9&5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES
M5F%L:60H)B1V87(L("8D=F%R<RP@)'9A;'5E+"`F)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5F%L=65S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]V86QU97,[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4VEZ92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<VEZ93L*("`@('T*"B`@("!F=6YC=&EO;B!G971(
M96%D97(H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]H96%D
M97(I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VAE861E<CL*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=$]P=&EO;G,H)&ME>7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1H=&UL
M(#T@)R<["B`@("`@("`@:68@*"1T:&ES+3Y?:&5A9&5R*2!["B`@("`@("`@
M("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(B/B<@+B!H=&UL<W!E8VEA
M;&-H87)S*"1T:&ES+3Y?:&5A9&5R*2`N("<\+V]P=&EO;CXG.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&5M<'1Y*"1K97ES*2D@>PH@("`@("`@("`@("`D
M:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]V86QU97,I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1K97ES(#T@97AP;&]D92@B7'0B+"`D:V5Y
M<ULG87)R87DG72D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1K97ES
M(&%S("1S;%]K97DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I;VX@
M=F%L=64](B<@+B`D<VQ?:V5Y("X@)R(^)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)'1H:7,M/E]V86QU97-;)'-L7VME>5TI("X@)SPO;W!T:6]N/B<["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5T26YF;R@F)'9A<G,L("8D=F%R+"`F)&EN9F\I"B`@("!["B`@("`@
M("`@)'9A;'5E(#T@)'9A<G,M/F=E="@D=F%R+3YG971687).86UE*"DI.PH@
M("`@("`@("1I;F9O(#T@97AP;&]D92@B7'0B+"`D=F%L=65;)V%R<F%Y)UTI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE
M;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@
M("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N86UE
M)UT@/2!?*")3;W)T(&]R9&5R('-E;&5C=&EO;B(I.PH@("`@("`@("1A8F]U
M=%LG<&%R86US)UT@/2!A<G)A>2@*("`@("`@("`@("`@)W9A;'5E<R<@/3X@
M87)R87DH)VQA8F5L)R`]/B!?*")686QU97,B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@
M("`@("`@("`G<VEZ92<@("`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E-I>F4B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M:6YT)RDL"B`@("`@("`@("`@("=H96%D97(G(#T^(&%R<F%Y*"=L86)E;"<@
M/3X@7R@B2&5A9&5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T>7!E)R`@/3X@)W1E>'0G*2D["B`@("`@("`@<F5T=7)N("1A8F]U=#L*
M("`@('T*"GT*"F-L87-S($AO<F1E7T9O<FU?5'EP95]S96QE8W1&:6QE<R!E
M>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M=&5X="!T;R!U<V4@:6X@=&AE(&QI;FLN"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?;&EN:U]T97AT.PH*("`@("\J*@H@
M("`@("H@5&AE('-T>6QE('1O('5S92!F;W(@=&AE(&QI;FLN"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?;&EN:U]S='EL
M93L*"B`@("`O*BH*("`@("`J("!#<F5A=&4@=&AE(&QI;FL@=VET:"!A;B!I
M8V]N(&EN<W1E860@;V8@=&5X=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?:6-O;CL*"B`@("`O*BH*("`@("`J($-O
M;G1A:6YS(&=O;&QE;2!S96QE8W1F:6QE('-E;&5C=&EO;DE$"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V5L96-T:60[
M"@H@("`@9G5N8W1I;VX@:6YI="@D;&EN:U]T97AT(#T@;G5L;"P@)&QI;FM?
M<W1Y;&4@/2`G)RP@)&EC;VX@/2!F86QS92P*("`@("`@("`@("`@("`@("`@
M)'-E;&5C=&ED(#T@)R<I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&QI
M;FM?=&5X="DI('L*("`@("`@("`@("`@)&QI;FM?=&5X="`](%\H(E-E;&5C
M="!&:6QE<R(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQI;FM?=&5X
M="`]("1L:6YK7W1E>'0["B`@("`@("`@)'1H:7,M/E]L:6YK7W-T>6QE(#T@
M)&QI;FM?<W1Y;&4["B`@("`@("`@)'1H:7,M/E]I8V]N(#T@)&EC;VX["B`@
M("`@("`@)'1H:7,M/E]S96QE8W1I9"`]("1S96QE8W1I9#L*("`@('T*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$EN9F\H)B1V87)S+"`F)'9A<BP@)B1I;F9O*0H@("`@
M>PH@("`@("`@("1V86QU92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*("`@
M("`@("`D:6YF;R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=F:6QE
M<R]S96QE8W1L:7-T4F5S=6QT<R<L(&%R<F%Y*"1V86QU92D@*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("!["B`@("`@("`@)&%B;W5T(#T@
M87)R87DH*3L*("`@("`@("`D86)O=71;)VYA;64G72`](%\H(D9I;&4@<V5L
M96-T:6]N(BD["B`@("`@("`@<F5T=7)N("1A8F]U=#L*("`@('T*"GT*"F-L
M87-S($AO<F1E7T9O<FU?5'EP95]A<W-I9VX@97AT96YD<R!(;W)D95]&;W)M
M7U1Y<&4@>PH*("`@('9A<B`D7VQE9G1686QU97,["B`@("!V87(@)%]R:6=H
M=%9A;'5E<SL*("`@('9A<B`D7VQE9G1(96%D97(["B`@("!V87(@)%]R:6=H
M=$AE861E<CL*("`@('9A<B`D7W-I>F4["B`@("!V87(@)%]W:61T:#L*"B`@
M("!F=6YC=&EO;B!I;FET*"1L969T5F%L=65S+"`D<FEG:'1686QU97,L("1L
M969T2&5A9&5R(#T@)R<L"B`@("`@("`@("`@("`@("`@("1R:6=H=$AE861E
M<B`]("<G+"`D<VEZ92`](#@L("1W:61T:"`]("<R,#!P>"<I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]L969T5F%L=65S(#T@)&QE9G1686QU97,["B`@("`@
M("`@)'1H:7,M/E]R:6=H=%9A;'5E<R`]("1R:6=H=%9A;'5E<SL*("`@("`@
M("`D=&AI<RT^7VQE9G1(96%D97(@/2`D;&5F=$AE861E<CL*("`@("`@("`D
M=&AI<RT^7W)I9VAT2&5A9&5R(#T@)')I9VAT2&5A9&5R.PH@("`@("`@("1T
M:&ES+3Y?<VEZ92`]("1S:7IE.PH@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D
M=VED=&@["B`@("!]"@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V
M87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971686QU97,H)'-I9&4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1S:61E(#\@)'1H:7,M/E]R:6=H=%9A;'5E
M<R`Z("1T:&ES+3Y?;&5F=%9A;'5E<SL*("`@('T*"B`@("!F=6YC=&EO;B!S
M971686QU97,H)'-I9&4L("1V86QU97,I"B`@("!["B`@("`@("`@:68@*"1S
M:61E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<FEG:'1686QU97,@/2`D=F%L
M=65S.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;&5F
M=%9A;'5E<R`]("1V86QU97,["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$AE861E<B@D<VED92D*("`@('L*("`@("`@("!R971U<FX@)'-I
M9&4@/R`D=&AI<RT^7W)I9VAT2&5A9&5R(#H@)'1H:7,M/E]L969T2&5A9&5R
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-I>F4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W-I>F4["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M5VED=&@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W=I9'1H.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$]P=&EO;G,H)'-I9&4L("1F;W)M;F%M
M92D*("`@('L*("`@("`@("`D:'1M;"`]("<G.PH@("`@("`@("1H96%D97(@
M/2!F86QS93L*("`@("`@("!I9B`H)'-I9&4I('L*("`@("`@("`@("`@)'9A
M;'5E<R`]("1T:&ES+3Y?<FEG:'1686QU97,["B`@("`@("`@("`@(&EF("@A
M96UP='DH)'1H:7,M/E]R:6=H=$AE861E<BDI('L*("`@("`@("`@("`@("`@
M("1V86QU97,@/2!A<G)A>2@G)R`]/B`D=&AI<RT^7W)I9VAT2&5A9&5R*2`K
M("1V86QU97,["B`@("`@("`@("`@("`@("`D:&5A9&5R<R`]('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L
M=65S(#T@)'1H:7,M/E]L969T5F%L=65S.PH@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?;&5F=$AE861E<BDI('L*("`@("`@("`@("`@("`@("1V
M86QU97,@/2!A<G)A>2@G)R`]/B`D=&AI<RT^7VQE9G1(96%D97(I("L@)'9A
M;'5E<SL*("`@("`@("`@("`@("`@("1H96%D97)S(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=F%L=65S(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO
M;B!V86QU93TB)R`N("1K97D@+B`G(B<["B`@("`@("`@("`@(&EF("@D:&5A
M9&5R<RD@>PH@("`@("`@("`@("`@("`@)&AE861E<G,@/2!F86QS93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<@
M;VYD8FQC;&EC:STB2&]R9&5?1F]R;5]!<W-I9VXN;6]V92A<)R<@+B`D9F]R
M;6YA;64@+@H@("`@("`@("`@("`@)UPG+"`G("X@*&EN="DD<VED92`N("<I
M.R(G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<^)R`N
M("1V86P@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!G971);F9O*"8D=F%R<RP@
M)B1V87(L("8D:6YF;RD*("`@('L*("`@("`@("`D=F%L=64@/2`D=F%R<RT^
M9V5T*"1V87(M/F=E=%9A<DYA;64H*2`N("=?7W9A;'5E<R<I.PH@("`@("`@
M(&EF("AS=')P;W,H)'9A;'5E+"`B7'1<="(I(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("`D;&5F="`]("1V86QU93L*("`@("`@("`@("`@)')I9VAT(#T@
M)R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@D;&5F="P@
M)')I9VAT*2`](&5X<&QO9&4H(EQT7'0B+"`D=F%L=64I.PH@("`@("`@('T*
M("`@("`@("!I9B`H96UP='DH)&QE9G0I*2!["B`@("`@("`@("`@("1I;F9O
M6R=L969T)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1I;F9O6R=L969T)UT@/2!E>'!L;V1E*")<="(L("1L969T*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1R:6=H="DI('L*("`@("`@("`@
M("`@)&EN9F];)W)I9VAT)UT@/2!A<G)A>2@I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1I;F9O6R=R:6=H="==(#T@97AP;&]D92@B7'0B+"`D
M<FEG:'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!I;F9O(&%B;W5T(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%B;W5T*"D*("`@('L*("`@("`@("`D86)O=70@/2!A<G)A>2@I.PH@("`@
M("`@("1A8F]U=%LG;F%M92==(#T@7R@B07-S:6=N;65N="!C;VQU;6YS(BD[
M"B`@("`@("`@)&%B;W5T6R=P87)A;7,G72`](&%R<F%Y*`H@("`@("`@("`@
M("`G;&5F=%9A;'5E<R<@/3X@87)R87DH)VQA8F5L)R`]/B!?*"),969T('9A
M;'5E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y
M<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@("`G<FEG:'1686QU
M97,G(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B4FEG:'0@=F%L=65S(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`G
M<W1R:6YG;&ES="<I+`H@("`@("`@("`@("`G;&5F=$AE861E<B<@/3X@87)R
M87DH)VQA8F5L)R`]/B!?*"),969T(&AE861E<B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@
M("`@("=R:6=H=$AE861E<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")2:6=H
M="!H96%D97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("=S:7IE)R`@(#T^
M(&%R<F%Y*"=L86)E;"<@/3X@7R@B4VEZ92(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("=I;G0G*2P*("`@("`@("`@("`@
M)W=I9'1H)R`@(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B5VED=&@@:6X@0U-3
M('5N:71S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP
M92<@(#T^("=T97AT)RDI.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]
M"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y<&5?8W)E9&ET8V%R9"!E>'1E;F1S
M($AO<F1E7T9O<FU?5'EP92!["@H@("`@9G5N8W1I;VX@:7-686QI9"@F)'9A
M<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G92D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'9A;'5E*2`F)B`D=F%R+3YI<U)E<75I<F5D*"DI('L*("`@
M("`@("`@("`@)&UE<W-A9V4@/2!?*")4:&ES(&9I96QD(&ES(')E<75I<F5D
M+B(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(65M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@+RH@9V5T
M0V%R9%1Y<&4H*2!W:6QL(&%L<V\@=F5R:69Y('1H92!C:&5C:W-U;2X@*B\*
M("`@("`@("`@("`@)'1Y<&4@/2`D=&AI<RT^9V5T0V%R9%1Y<&4H)'9A;'5E
M*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]/2!F86QS92!\?"`D='EP92`]
M/2`G=6YK;F]W;B<I('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@7R@B
M5&AI<R!D;V5S(&YO="!S965M('1O(&)E(&$@=F%L:60@8V%R9"!N=6UB97(N
M(BD["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$-H96-K<W5M*"1C8VYU;2D*("`@('L*("`@("`@("`D
M;&5N(#T@<W1R;&5N*"1C8VYU;2D["B`@("`@("`@:68@*"%I<U]L;VYG*"1L
M96X@+R`R*2D@>PH@("`@("`@("`@("`D=V5I9VAT(#T@,CL*("`@("`@("`@
M("`@)&1I9VET(#T@)&-C;G5M6S!=.PH@("`@("`@('T@96QS96EF("AI<U]L
M;VYG*"1L96X@+R`R*2D@>PH@("`@("`@("`@("`D=V5I9VAT(#T@,3L*("`@
M("`@("`@("`@)&1I9VET(#T@)&-C;G5M6S!=("H@,CL*("`@("`@("!]"B`@
M("`@("`@:68@*"1D:6=I="`^(#DI('L*("`@("`@("`@("`@)&1I9VET(#T@
M)&1I9VET("T@.3L*("`@("`@("!]"B`@("`@("`@)&D@/2`Q.PH@("`@("`@
M("1C:&5C:W-U;2`]("1D:6=I=#L*("`@("`@("!W:&EL92`H)&D@/"`D;&5N
M*2!["B`@("`@("`@("`@(&EF("@D8V-N=6U;)&E=("$]("<@)RD@>PH@("`@
M("`@("`@("`@("`@)&1I9VET(#T@)&-C;G5M6R1I72`J("1W96EG:'0["B`@
M("`@("`@("`@("`@("`D=V5I9VAT(#T@*"1W96EG:'0@/3T@,2D@/R`R(#H@
M,3L*("`@("`@("`@("`@("`@(&EF("@D9&EG:70@/B`Y*2!["B`@("`@("`@
M("`@("`@("`@("`@)&1I9VET(#T@)&1I9VET("T@.3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1C:&5C:W-U;2`K/2`D9&EG:70["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8VAE8VMS=6T["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M0V%R9%1Y<&4H)&-C;G5M*0H@("`@>PH@("`@("`@("1S=6T@/2`D=&AI<RT^
M9V5T0VAE8VMS=6TH)&-C;G5M*3L*("`@("`@("`D;"`]('-T<FQE;B@D8V-N
M=6TI.PH*("`@("`@("`O+R!38W)E96X@8VAE8VMS=6TN"B`@("`@("`@:68@
M*"@D<W5M("4@,3`I("$](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(%9I<V$N"B`@("`@
M("`@:68@*"@H)&P@/3T@,38I('Q\("@D;"`]/2`Q,RDI("8F"B`@("`@("`@
M("`@("@D8V-N=6U;,%T@/3T@-"DI('L*("`@("`@("`@("`@<F5T=7)N("=V
M:7-A)SL*("`@("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!-87-T97)#
M87)D+@H@("`@("`@(&EF("@H)&P@/3T@,38I("8F"B`@("`@("`@("`@("@D
M8V-N=6U;,%T@/3T@-2D@)B8*("`@("`@("`@("`@*"1C8VYU;5LQ72`^/2`Q
M*2`F)@H@("`@("`@("`@("`H)&-C;G5M6S%=(#P](#4I*2!["B`@("`@("`@
M("`@(')E='5R;B`G;6%S=&5R8V%R9"<["B`@("`@("`@?0H*("`@("`@("`O
M+R!#:&5C:R!F;W(@06UE>"X*("`@("`@("!I9B`H*"1L(#T](#$U*2`F)@H@
M("`@("`@("`@("`H)&-C;G5M6S!=(#T](#,I("8F"B`@("`@("`@("`@("@H
M)&-C;G5M6S%=(#T](#0I('Q\("@D8V-N=6U;,5T@/3T@-RDI*2!["B`@("`@
M("`@("`@(')E='5R;B`G86UE>"<["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!F;W(@1&ES8V]V97(@*$YO=G5S*2X*("`@("`@("!I9B`H<W1R;&5N
M*"1C8VYU;2D@/3T@,38@)B8*("`@("`@("`@("`@<W5B<W1R*"1C8VYU;2P@
M,"P@-"D@/3T@)S8P,3$G*2!["B`@("`@("`@("`@(')E='5R;B`G9&ES8V]V
M97(G.PH@("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9V]T('1H:7,@9F%R
M+"!T:&5N(&YO(&-A<F0@;6%T8VAE9"X*("`@("`@("!R971U<FX@)W5N:VYO
M=VXG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&EN9F\@86)O=70@
M9FEE;&0@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@("`@
M>PH@("`@("`@("1A8F]U="`](&%R<F%Y*"D["B`@("`@("`@)&%B;W5T6R=N
M86UE)UT@/2!?*")#<F5D:70@8V%R9"!N=6UB97(B*3L*("`@("`@("!R971U
M<FX@)&%B;W5T.PH@("`@?0H*?0H*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7V]B
M<F]W<V5R(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!F=6YC=&EO
M;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M97-S86=E*0H@
M("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@("1A8F]U="`](&%R<F%Y
M*"D["B`@("`@("`@)&%B;W5T6R=N86UE)UT@/2!?*")296QA=&EO;G-H:7`@
M0G)O=W-E<B(I.PH@("`@("`@(')E='5R;B`D86)O=70["B`@("!]"@I]"@IC
M;&%S<R!(;W)D95]&;W)M7U1Y<&5?9&)L;V]K=7`@97AT96YD<R!(;W)D95]&
M;W)M7U1Y<&5?96YU;2!["@H@("`@9G5N8W1I;VX@:6YI="@D9'-N+"`D<W%L
M+"`D<')O;7!T(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M)T1"+G!H<"<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@
M)&1B(#T@)D1".CIC;VYN96-T*"1D<VXI.PH@("`@("`@(&EF("@A:7-?82@D
M9&(L("=014%27T5R<F]R)RDI('L*"B`@("`@("`@("`@("\O(%-E="!$0B!P
M;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@("`@("!S=VET8V@@*"1D8BT^
M<&AP='EP92D@>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@
M("`@("`@("`D9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)4
M04))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$
M0E]03U)404))3$E465]25%))32D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("1D8BT^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1C;VP@/2`F)&1B+3YG971#;VPH)'-Q;"D["B`@("`@("`@
M("`@(&EF("@A:7-?82@D8V]L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@
M("`@("`@("`@("`D=F%L=65S(#T@2&]R9&5?07)R87DZ.F-O;6)I;F4H)&-O
M;"P@)&-O;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<&%R
M96YT.CII;FET*"1V86QU97,L("1P<F]M<'0I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N(&EN9F\@86)O=70@9FEE;&0@='EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@86)O=70H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A
M>2@*("`@("`@("`@("`@)VYA;64G(#T^(%\H(D1A=&%B87-E($QO;VMU<"(I
M+`H@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*("`@("`@("`@("`@
M("`@("=D<VXG(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B1%-.("AS964@:'1T
M<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO<&%C:V%G92YD871A8F%S92YD
M8BYI;G1R;RUD<VXN<&AP*2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)W-Q
M;"<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")344P@<W1A=&5M96YT(&9O<B!V
M86QU92!L;V]K=7!S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G='EP92<@(#T^("=T97AT)RDL"B`@("`@("`@("`@("`@("`G<')O;7!T
M)R`]/B!A<G)A>2@G;&%B96PG(#T^(%\H(E!R;VUP="!T97AT(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT
M)RDI"B`@("`@("`@("`@("D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M
M7U1Y<&5?9FEG;&5T(&5X=&5N9',@2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V
M87(@)%]T97AT.PH@("`@=F%R("1?9F]N=#L*"B`@("!F=6YC=&EO;B!I;FET
M*"1T97AT+"`D9F]N="D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D
M=&5X=#L*("`@("`@("`D=&AI<RT^7V9O;G0@/2`D9F]N=#L*("`@('T*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=F%L=64I("8F("1V
M87(M/FES4F5Q=6ER960H*2D@>PH@("`@("`@("`@("`D;65S<V%G92`](%\H
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("A3=')I;F<Z.FQO=V5R
M*"1V86QU92D@(3T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^7W1E>'0I*2!["B`@
M("`@("`@("`@("1M97-S86=E(#T@7R@B5&AE('1E>'0@>6]U(&5N=&5R960@
M9&ED(&YO="!M871C:"!T:&4@=&5X="!O;B!T:&4@<V-R965N+B(I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!G971&;VYT*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]F;VYT.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=%1E>'0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1E
M>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@:6YF;R!A8F]U="!F
M:65L9"!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8F]U="@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`G;F%M92<@/3X@
M7R@B1FEG;&5T($-!4%1#2$$B*2P*("`@("`@("`@("`@)W!A<F%M<R<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`G=&5X="<@/3X@87)R87DH)VQA8F5L
M)R`]/B!?*")497AT(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`]/B`G=&5X="<I+`H@("`@("`@("`@("`@("`@)V9O;G0G
M(#T^(&%R<F%Y*"=L86)E;"<@/3X@7R@B1FEG;&5T(&9O;G0B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^("=T97AT)RDI
M"B`@("`@("`@("`@("D["B`@("!]"@I]"@IC;&%S<R!(;W)D95]&;W)M7U1Y
M<&5?:6YV86QI9"!E>'1E;F1S($AO<F1E7T9O<FU?5'EP92!["@H@("`@=F%R
M("1M97-S86=E.PH*("`@(&9U;F-T:6]N(&EN:70H)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@)'1H:7,M/FUE<W-A9V4@/2`D;65S<V%G93L*("`@('T*"B`@
M("!F=6YC=&EO;B!I<U9A;&ED*"8D=F%R+"`F)'9A<G,L("1V86QU92P@)B1M
M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*
M"B\J*@H@*B!4:&ES(&-L87-S(')E<')E<V5N=',@82!S:6YG;&4@9F]R;2!V
M87)I86)L92!T:&%T(&UA>2!B92!R96YD97)E9"!A<R!O;F4@;W(*("H@;6]R
M92!F;W)M(&9I96QD<RX*("H*("H@0&%U=&AO<B`@4F]B97)T($4N($-O>6QE
M(#QR;V)E<G1E8V]Y;&5`:&]T;6%I;"YC;VT^"B`J($!P86-K86=E($AO<F1E
M7T9O<FT*("HO"F-L87-S($AO<F1E7T9O<FU?5F%R:6%B;&4@>PH*("`@("\J
M*@H@("`@("H@5&AE(&9O<FT@:6YS=&%N8V4@=&AI<R!V87)I86)L92!I<R!A
M<W-I9VYE9"!T;RX*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7T9O<FT*("`@
M("`J+PH@("`@=F%R("1F;W)M.PH*("`@("\J*@H@("`@("H@02!S:&]R="!D
M97-C<FEP=&EO;B!O9B!T:&ES('9A<FEA8FQE)W,@<'5R<&]S92X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&AU;6%N3F%M
M93L*"B`@("`O*BH*("`@("`J(%1H92!I;G1E<FYA;&QY('5S960@;F%M92X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'9A
M<DYA;64["@H@("`@+RHJ"B`@("`@*B!!('M`;&EN:R!(;W)D95]&;W)M7U1Y
M<&5](&EN<W1A;F-E+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?1F]R;5]4
M>7!E"B`@("`@*B\*("`@('9A<B`D='EP93L*"B`@("`O*BH*("`@("`J(%=H
M971H97(@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA8FQE+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)')E<75I<F5D.PH*
M("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&ES(&ES(&$@<F5A9&]N;'D@=F%R
M:6%B;&4N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@
M('9A<B`D<F5A9&]N;'D["@H@("`@+RHJ"B`@("`@*B!!(&QO;F<@9&5S8W)I
M<'1I;VX@;V8@=&AE('9A<FEA8FQE)W,@<'5R<&]S92P@<W!E8VEA;"!I;G-T
M<G5C=&EO;G,L(&5T8RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)&1E<V-R:7!T:6]N.PH*("`@("\J*@H@("`@("H@5&AE
M('9A<FEA8FQE(&AE;'`@=&5X="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)&AE;'`["@H@("`@+RHJ"B`@("`@*B!7:&5T
M:&5R('1H:7,@:7,@86X@87)R87D@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V%R<F%Y5F%L.PH*("`@
M("\J*@H@("`@("H@5&AE(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@("H@
M0'9A<B!M:7AE9`H@("`@("HO"B`@("!V87(@)%]D969686QU92`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!!('M`;&EN:R!(;W)D95]&;W)M7T%C=&EO;GT@
M:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'9A<B!(;W)D95]&;W)M7T%C=&EO
M;@H@("`@("HO"B`@("!V87(@)%]A8W1I;VX["@H@("`@+RHJ"B`@("`@*B!7
M:&5T:&5R('1H:7,@=F%R:6%B;&4@:7,@9&ES86)L960N"B`@("`@*@H@("`@
M("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V1I<V%B;&5D(#T@
M9F%L<V4["@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'9A
M<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V%U=&]F:6QL960@/2!F86QS
M93L*"B`@("`O*BH*("`@("`J(%=H971H97(@=&AI<R!I<R!A(&AI9&1E;B!V
M87)I86)L92X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?:&ED9&5N(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!43T1/
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O
M<'1I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AU;6%N
M3F%M92`@("`@($$@<VAO<G0@9&5S8W)I<'1I;VX@;V8@=&AE('9A<FEA8FQE
M)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!U<G!O
M<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V87).86UE("`@("`@("!4:&4@
M:6YT97)N86QL>2!U<V5D(&YA;64N"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R
M;5]4>7!E("1T>7!E("!!('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5](&EN<W1A
M;F-E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E<75I<F5D("`@("`@5VAE
M=&AE<B!T:&ES(&ES(&$@<F5Q=6ER960@=F%R:6%B;&4N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D<F5A9&]N;'D@("`@("!7:&5T:&5R('1H:7,@:7,@82!R
M96%D;VYL>2!V87)I86)L92X*("`@("`J($!P87)A;2!S=')I;F<@)&1E<V-R
M:7!T:6]N("`@($$@;&]N9R!D97-C<FEP=&EO;B!O9B!T:&4@=F%R:6%B;&4G
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<'5R<&]S
M92P@<W!E8VEA;"!I;G-T<G5C=&EO;G,L(&5T8RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@2&]R9&5?1F]R;5]687)I86)L92@D:'5M86Y.86UE+"`D=F%R3F%M
M92P@)B1T>7!E+"`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R96%D;VYL>2`](&9A;'-E+"`D9&5S8W)I<'1I;VX@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3YH=6UA;DYA;64@("`]("1H=6UA
M;DYA;64["B`@("`@("`@)'1H:7,M/G9A<DYA;64@("`@(#T@)'9A<DYA;64[
M"B`@("`@("`@)'1H:7,M/G1Y<&4@("`@("`@(#T@)B1T>7!E.PH@("`@("`@
M("1T:&ES+3YR97%U:7)E9"`@("`]("1R97%U:7)E9#L*("`@("`@("`D=&AI
M<RT^<F5A9&]N;'D@("`@/2`D<F5A9&]N;'D["B`@("`@("`@)'1H:7,M/F1E
M<V-R:7!T:6]N(#T@)&1E<V-R:7!T:6]N.PH@("`@("`@("1T:&ES+3Y?87)R
M87E686P@("`]("AS=')P;W,H)'9A<DYA;64L("=;72<I("$]/2!F86QS92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-I9VX@=&AI<R!V87)I86)L92!T
M;R!T:&4@<W!E8VEF:65D(&9O<FTN"B`@("`@*@H@("`@("H@0'!A<F%M($AO
M<F1E7T9O<FT@)&9O<FT@(%1H92!F;W)M(&EN<W1A;F-E('1O(&%S<VEG;B!T
M:&ES('9A<FEA8FQE('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971&;W)M
M3V(H)B1F;W)M*0H@("`@>PH@("`@("`@("1T:&ES+3YF;W)M(#T@)B1F;W)M
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&1E9F%U;'0@=F%L=64@
M9F]R('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("1V86QU92`@02!V87)I86)L92!V86QU92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T1&5F875L="@D=F%L=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]D
M969686QU92`]("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AI<R!V87)I86)L92=S(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AI<R!V87)I86)L92=S(&1E9F%U;'0@=F%L
M=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1E9E9A;'5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@07-S:6=N<R!A;B!A8W1I;VX@=&\@=&AI<R!V87)I86)L92X*
M("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D
M=B`]("8D9F]R;2T^861D5F%R:6%B;&4H)TUY(%9A<FEA8FQE)RP@)W9A<C$G
M+"`G=&5X="<L(&9A;'-E*3L*("`@("`J("1A8W1I;VX@/2`F2&]R9&5?1F]R
M;5]!8W1I;VXZ.F9A8W1O<GDH)W-U8FUI="<I.PH@("`@("H@)'8M/G-E=$%C
M=&EO;B@D86-T:6]N*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`
M<&%R86T@2&]R9&5?1F]R;5]!8W1I;VX@)&%C=&EO;B`@02![0&QI;FL@2&]R
M9&5?1F]R;5]!8W1I;VY](&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971!8W1I;VXH)&%C=&EO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V%C
M=&EO;B`]("1A8W1I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('=H971H97(@=&AI<R!V87)I86)L92!H87,@86X@871T86-H960@86-T:6]N
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES
M('9A<FEA8FQE(&AA<R!A;B!A='1A8VAE9"!A8W1I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&AA<T%C=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("%I
M<U]N=6QL*"1T:&ES+3Y?86-T:6]N*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($UA:V5S('1H:7,@82!H:61D96X@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&AI9&4H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&ED9&5N(#T@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T
M:&ES(&ES(&$@:&ED9&5N('9A<FEA8FQE+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&$@:&ED9&5N('9A<FEA8FQE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<TAI9&1E;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:&ED9&5N.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&ES86)L97,@=&AI<R!V87)I86)L92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&ES86)L92@I"B`@("!["B`@("`@("`@)'1H:7,M/E]D:7-A8FQE9"`]('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@=&AI
M<R!V87)I86)L92!I<R!D:7-A8FQE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AI<R!V87)I86)L92!I<R!D:7-A8FQE9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-$:7-A8FQE9"@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9&ES86)L960["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE('-H;W)T(&1E<V-R:7!T:6]N(&]F('1H:7,@=F%R
M:6%B;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($$@<VAO<G0@
M9&5S8W)I<'1I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T2'5M86Y.86UE
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FAU;6%N3F%M93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&EN=&5R;F%L;'D@=7-E
M9"!V87)I86)L92!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&ES('9A<FEA8FQE)W,@:6YT97)N86P@;F%M92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T5F%R3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YV87).86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&ES('9A<FEA8FQE)W,@='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO
M<F1E7T9O<FU?5'EP92`@5&AI<R!V87)I86)L92=S('M`;&EN:R!(;W)D95]&
M;W)M7U1Y<&5]"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS
M=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G9714>7!E*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G1Y<&4["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!N86UE(&]F('1H:7,@=F%R:6%B;&4G<R!T>7!E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&ES('9A<FEA8FQE
M)W,@('M`;&EN:R!(;W)D95]&;W)M7U1Y<&5](&YA;64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%1Y<&5.86UE*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G1Y<&4M/F=E=%1Y<&5.86UE*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('=H971H97(@=&AI<R!I<R!A(')E<75I<F5D('9A<FEA
M8FQE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&ES(&ES(&$@<F5Q=6ER960@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES4F5Q=6ER960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M<F5Q=6ER960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H
M97(@=&AI<R!I<R!A(')E861O;FQY('9A<FEA8FQE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&$@<F5A9&]N;'D@=F%R
M:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES4F5A9&]N;'DH*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5A9&]N;'D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!P;W-S:6)L92!V86QU97,@;V8@=&AI
M<R!V87)I86)L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M<&]S<VEB;&4@=F%L=65S(&]F('1H:7,@=F%R:6%B;&4@;W(@;G5L;"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L=65S*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/G1Y<&4M/F=E=%9A;'5E<R@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@=F%R:6%B;&4@:&%S(&$@
M;&]N9R!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AI<R!V87)I86)L92!H87,@82!L;VYG(&1E<V-R:7!T
M:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!H87-$97-C<FEP=&EO;B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^9&5S8W)I<'1I;VXI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&ES('9A<FEA8FQE
M)W,@;&]N9R!D97-C<FEP=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AI<R!V87)I86)L92=S(&QO;F<@9&5S8W)I<'1I;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1E<V-R:7!T:6]N*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/F1E<V-R:7!T:6]N.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!W:&5T:&5R('1H:7,@:7,@86X@87)R87D@=F%R:6%B
M;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M:7,@86X@87)R87D@=F%R:6%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES
M07)R87E686PH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%R<F%Y
M5F%L.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W:&5T:&5R('1H
M:7,@=F%R:6%B;&4@:7,@=&\@=7!L;V%D(&$@9FEL92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=F%R:6%B;&4@:7,@=&\@=7!L
M;V%D(&$@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-5<&QO860H*0H@
M("`@>PH@("`@("`@(')E='5R;B`H)'1H:7,M/G1Y<&4M/F=E=%1Y<&5.86UE
M*"D@/3T@)V9I;&4G*3L*("`@('T*"B`@("`O*BH*("`@("`J($%S<VEG;G,@
M82!H96QP('1E>'0@=&\@=&AI<R!V87)I86)L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1H96QP("!4:&4@=F%R:6%B;&4@:&5L<"!T97AT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971(96QP*"1H96QP*0H@("`@>PH@("`@
M("`@("1T:&ES+3YF;W)M+3Y?:&5L<"`]('1R=64["B`@("`@("`@)'1H:7,M
M/FAE;'`@/2`D:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=VAE=&AE<B!T:&ES('9A<FEA8FQE(&AA<R!S;VUE(&AE;'`@=&5X="!A<W-I
M9VYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M=&AI<R!V87)I86)L92!H87,@82!H96QP('1E>'0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&AA<TAE;'`H*0H@("`@>PH@("`@("`@(')E='5R;B`A96UP='DH
M)'1H:7,M/FAE;'`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@:&5L<"!T97AT(&]F('1H:7,@=F%R:6%B;&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H:7,@=F%R:6%B;&4G<R!H96QP('1E>'0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$AE;'`H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^:&5L<#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M82!V87)I86)L92!O<'1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;W!T:6]N("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@;6EX
M960@)'9A;"`@("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T3W!T:6]N*"1O<'1I;VXL("1V86PI"B`@("!["B`@("`@
M("`@)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=(#T@)'9A;#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@82!V87)I86)L92!O<'1I;VXG<R!V86QU
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<'1I;VX@(%1H92!O
M<'1I;VX@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@
M("`@(%1H92!O<'1I;VXG<R!V86QU92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T3W!T:6]N*"1O<'1I;VXI"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72D@/R`D=&AI<RT^7V]P=&EO;G-;
M)&]P=&EO;ET@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4')O8V5S
M<V5S('1H92!S=6)M:71T960@=F%L=64@;V8@=&AI<R!V87)I86)L92!A8V-O
M<F1I;F<@=&\@=&AE(')U;&5S(&]F"B`@("`@*B!T:&4@=F%R:6%B;&4@='EP
M92X*("`@("`J"B`@("`@*B!`<&%R86T@5F%R:6%B;&5S("1V87)S("!4:&4@
M>T!L:6YK(%9A<FEA8FQE<WT@:6YS=&%N8V4@;V8@=&AE('-U8FUI='1E9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;2X*("`@("`J($!P
M87)A;2!M:7AE9"`D:6YF;R`@("`@($$@=F%R:6%B;&4@<&%S<V5D(&)Y(')E
M9F5R96YC92!T:&%T('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&%S<VEG;F5D('1H92!P<F]C97-S960@=F%L=64@;V8@=&AE('-U
M8FUI='1E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=F%R:6%B
M;&4@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1&5P96YD
M:6YG(&]N('1H92!V87)I86)L92!T>7!E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971);F9O*"8D=F%R<RP@)B1I;F9O*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^='EP92T^9V5T26YF;R@D=F%R<RP@)'1H:7,L("1I;F9O*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=VAE=&AE<B!T:&ES('9A
M<FEA8FQE(&EF(&ET(&AA9"!T:&4@(G1R86-K8VAA;F=E(B!O<'1I;VX@<V5T
M"B`@("`@*B!H87,@86-T=6%L;'D@8F5E;B!C:&%N9V5D+@H@("`@("H*("`@
M("`J($!P87)A;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B
M;&5S?2!I;G-T86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)M+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@3G5L;"!I9B!T:&ES('9A<FEA8FQE(&1O97-N)W0@:&%V92!T
M:&4@(G1R86-K8VAA;F=E(@H@("`@("H@("`@("`@("`@("`@("`@("!O<'1I
M;VX@<V5T(&]R('1H92!F;W)M('=A<VXG="!S=6)M:71T960@>65T+B!!(&)O
M;VQE86X*("`@("`J("`@("`@("`@("`@("`@("`@:6YD:6-A=&EN9R!W:&5T
M:&5R('1H92!V87)I86)L92!W87,@8VAA;F=E9"!O=&AE<G=I<V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=A<T-H86YG960H)B1V87)S*0H@("`@>PH@("`@
M("`@(&EF("@A)'1H:7,M/F=E=$]P=&EO;B@G=')A8VMC:&%N9V4G*2D@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@)&]L
M9"`]("1V87)S+3YG970H)U]?;VQD7R<@+B`D=&AI<RT^9V5T5F%R3F%M92@I
M*3L*("`@("`@("!I9B`H:7-?;G5L;"@D;VQD*2D@>PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O;&0@(3T@
M)'9A<G,M/F=E="@D=&AI<RT^9V5T5F%R3F%M92@I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%9A;&ED871E<R!T:&ES('9A<FEA8FQE+@H@("`@("H*("`@
M("`J($!P87)A;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B
M;&5S?2!I;G-T86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;65S<V%G92`@02!V87)I86)L92!P87-S960@8GD@<F5F97)E;F-E('1H870@
M=VEL;"!B90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@87-S:6=N
M960@82!D97-C<FEP=&EV92!E<G)O<B!M97-S86=E(&EF"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!V86QI9&%T:6]N(&9A:6QE9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('9A<FEA8FQE
M('9A;&ED871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&4H)B1V
M87)S+"`F)&UE<W-A9V4I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?87)R
M87E686PI('L*("`@("`@("`@("`@)'9A;',@/2`D=&AI<RT^9V5T5F%L=64H
M)'9A<G,I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1V86QS*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3YR97%U:7)E9"D@>PH@("`@("`@
M("`@("`@("`@("`@("1M97-S86=E(#T@7R@B5&AI<R!F:65L9"!I<R!R97%U
M:7)E9"XB*3L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86QS(&%S("1I(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`@("`@:68@*"1V86QU92`]/3T@;G5L;"`F)B`D=&AI<RT^
M<F5Q=6ER960I('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`](%\H
M(E1H:7,@9FEE;&0@:7,@<F5Q=6ER960N(BD["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YT>7!E+3YI<U9A;&ED*"1T
M:&ES+"`D=F%R<RP@)'9A;'5E+"`D;65S<V%G92DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1V86QU92`]("1T:&ES+3YG971686QU92@D
M=F%R<RD["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^='EP92T^:7-686QI
M9"@D=&AI<RP@)'9A<G,L("1V86QU92P@)&UE<W-A9V4I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!S=6)M:71T960@;W(@9&5F875L="!V86QU92!O9B!T:&ES
M('9A<FEA8FQE+@H@("`@("H@268@86X@86-T:6]N(&ES(&%T=&%C:&5D('1O
M('1H:7,@=F%R:6%B;&4L('1H92!V86QU92!W:6QL(&=E="!P87-S960@=&\*
M("`@("`J('1H92!A8W1I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!687)I86)L97,@)'9A<G,@(%1H92![0&QI;FL@5F%R:6%B;&5S?2!I;G-T
M86YC92!O9B!T:&4@<W5B;6ET=&5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("`@
M268@=&AE('9A<FEA8FQE(&ES(&%N(&%R<F%Y('9A<FEA8FQE+"!T:&ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!S<&5C:69I97,@=&AE(&%R
M<F%Y(&5L96UE;G0@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!V87)I86)L92!O<B!E;&5M96YT('9A;'5E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971686QU92@F)'9A<G,L("1I;F1E>"`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?87)R87E686PI('L*("`@("`@
M("`@("`@)&YA;64@/2!S=')?<F5P;&%C92@G6UTG+"`G)RP@)'1H:7,M/G9A
M<DYA;64I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE(#T@
M)'1H:7,M/G9A<DYA;64["B`@("`@("`@?0H@("`@("`@("1V86QU92`]("1V
M87)S+3YG971%>&ES=',H)&YA;64L("1W87-S970I.PH*("`@("`@("!I9B`H
M(21W87-S970I('L*("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/F=E=$1E
M9F%U;'0H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7V%R<F%Y
M5F%L("8F("%I<U]N=6QL*"1I;F1E>"DI('L*("`@("`@("`@("`@:68@*"$D
M=V%S<V5T("8F("%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@
M("`D<F5T=7)N(#T@)'9A;'5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)')E='5R;B`](&ES<V5T*"1V86QU95LD:6YD97A=*2`_
M("1V86QU95LD:6YD97A=(#H@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R971U<FX@/2`D=F%L=64["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/FAA<T%C=&EO;B@I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?86-T:6]N+3YS971686QU97,H)'9A<G,L("1R971U
M<FXL("1T:&ES+3Y?87)R87E686PI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1R971U<FX["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+TMO;&%B+G!H<```````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,38U-#`U(#$P-3$U-#,T,30P(#`R,3$Q,P`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`H*+RHJ
M(%=E(')E<75I<F4@=&AE(&)A<V4@2&]R9&4@;&EB<F%R>2X@*B\*<F5Q=6ER
M95]O;F-E("=(;W)D92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-H87)E
M+G!H<"<["@HO*BH@5V4@;F5E9"!T:&4@4W1R:6YG("8@3DQ3(&QI8G)A<FEE
M<R!F;W(@8VAA<F%C=&5R('-E="!C;VYV97)S:6]N<RP@971C+B`J+PIR97%U
M:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PIR97%U:7)E7V]N8V4@)TAO
M<F1E+TY,4RYP:'`G.PH*+RHJ(%=E(&YE960@=&AE($AO<F1E($U)344@;&EB
M<F%R>2!T;R!D96%L('=I=&@@34E-12!M97-S86=E<RP@;V)V:6]U<VQY(#HM
M*2X@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O34E-12]087)T+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O34E-12]-97-S86=E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O34E-
M12](96%D97)S+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O34E-12]3=')U
M8W1U<F4N<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?2V]L86(@;&EB<F%R>2!R
M97%U:7)E<R!V97)S:6]N(#X](#$N,"XS(&]F($YE=%])34%0("AI+F4N(&$@
M=F5R<VEO;@H@*B!T:&%T(&EN8VQU9&5S('-U<'!O<G0@9F]R('1H92!!3DY/
M5$%414U/4D4@24U!4"!E>'1E;G-I;VXI+B!4:&4@;&%T97-T"B`J('9E<G-I
M;VX@;V8@3F5T7TE-05`@8V%N(&)E(&]B=&%I;F5D(&9R;VT@:'1T<#HO+W!E
M87(N<&AP+FYE="]G970O3F5T7TE-05`*("HO"G)E<75I<F5?;VYC92`G3F5T
M+TE-05`N<&AP)SL*"B\J*@H@*B!4:&4@8VAA<F%C=&5R('-E<75E;F-E('5S
M960@8GD@82`H2V]L86(I($-Y<G5S($E-05`@<V5R=F5R('1O('-E<&%R871E
M(&QI;F5S"B`J('=I=&AI;B!A(&UE<W-A9V4N"B`J+PID969I;F4H)TM/3$%"
M7TY%5TQ)3D4G+"`B7')<;B(I.PH*+RHJ"B`J(%1H92!C:&%R86-T97(@=7-E
M9"!T;R!D96QI;6ET('-U8F9O;&1E<G,@=VET:&EN(&$@*$MO;&%B*2!#>7)U
M<R!F;VQD97(*("H@:&EE<F%R8VAY+@H@*B\*9&5F:6YE*"=+3TQ!0E]&3TQ$
M15)?1$5,24TG+"`G+R<I.PH*+RHJ"B`J(%1H92!R;V]T(&]F('1H92!+;VQA
M8B!A;FYO=&%T:6]N(&AI97)A<F-H>2P@=7-E9"!O;B!T:&4@=F%R:6]U<R!)
M34%0(&9O;&1E<@H@*B!T:&%T(&%R92!U<V5D(&)Y($MO;&%B(&-L:65N=',N
M"B`J+PID969I;F4H)TM/3$%"7T%.3D]47U)/3U0G+"`G+W9E;F1O<B]K;VQA
M8B\G*3L*"B\J*@H@*B!4:&4@86YN;W1A=&EO;BP@87,@9&5F:6YE9"!B>2!T
M:&4@2V]L86(@9F]R;6%T('-P96,L('1H870@:7,@=7-E9"!T;R!S=&]R90H@
M*B!I;F9O<FUA=&EO;B!A8F]U="!W:&%T(&=R;W5P=V%R92!F;W)M870@=&AE
M(&9O;&1E<B!C;VYT86EN<RX*("HO"F1E9FEN92@G2T],04)?04Y.3U1?1D],
M1$527U194$4G+"!+3TQ!0E]!3DY/5%]23T]4("X@)V9O;&1E<BUT>7!E)RD[
M"@HO*BH*("H@02!(;W)D92US<&5C:69I8R!A;FYO=&%T:6]N('1H870@<W1O
M<F5S('1H92!5240@;V8@=&AE($AO<F1E('-H87)E('1H870*("H@8V]R<F5S
M<&]N9',@=&\@=&AE($E-05`@9F]L9&5R+B!4:&ES(&ES('5S960@:6X@=&AE
M('-Y;F-H<F]N:7-A=&EO;B!P<F]C97-S"B`J(&]F('1H92!)34%0(&9O;&1E
M<B!L:7-T(&%N9"!T:&4@2&]R9&4@<VAA<F4@;&ES="X*("HO"F1E9FEN92@G
M2T],04)?04Y.3U1?4TA!4D5?54E$)RP@2T],04)?04Y.3U1?4D]/5"`N("=H
M+7-H87)E+75I9"<I.PH*+RHJ"B`J(%1H92!8+2!H96%D97(@=7-E9"!T;R!S
M=&]R92!A(&-O<'D@;V8@=&AE($MO;&%B(&]B:F5C="!T>7!E('-T<FEN9R!F
M;W(@=&AE"B`J(&]B:F5C="!T>7!E('1H870@:7,@8V]N=&%I;F5D('=I=&AI
M;B!T:&4@96UA:6P@;65S<V%G92X*("HO"F1E9FEN92@G2T],04)?2$5!1$52
M7U194$4G+"`G6"U+;VQA8BU4>7!E)RD["@HO*BH*("H@06X@:6YD97@@:6YT
M;R!T:&4@)%]315-324].(&%R<F%Y('=H:6-H(&ES('5S960@=&\@8V%C:&4@
M=VAA="!A<'!L:6-A=&EO;@H@*B!W87,@;&%S="!S>6YC:')O;FES960[('1H
M:7,@<')E=F5N=',@=7,@9G)O;2!C;VYT:6YU;W5S;'D@<F4M<WEN8VAR;VYI
M<VEN9PH@*B!O;B!E=F5R>2!P86=E(&QO860@=VET:&EN(&$@<VEN9VQE(&%P
M<&QI8V%T:6]N+@H@*B\*9&5F:6YE*"=+3TQ!0E],05-47U-93D-(141?05!0
M)RP@)VMO;&%B7VQA<W1?<WEN8VAE9%]A<'`G*3L*"B\J*@H@*B!!;B!I;F1E
M>"!I;G1O('1H92`D7U-%4U-)3TX@87)R87D@=VAI8V@@:7,@=7-E9"!T;R!C
M86-H92!A(&UA<'!I;F<@;V8@<VAA<F4*("H@54E$<R!T;R!)34%0(&9O;&1E
M<G,[('1H:7,@:7,@=7-E9"!B>2!T:&4@=F%R:6]U<R!A<'!L:6-A=&EO;B!D
M<FEV97)S('=H96X*("H@;W!E;FEN9R!A('-P96-I9FEC('-H87)E+"!I;B!O
M<F1E<B!T;R!K;F]W('=H870@=&AE(&-O<G)E<W!O;F1I;F<@24U!4`H@*B!F
M;VQD97(@=&AA="!M=7-T(&)E(&]P96YE9"!I<RX*("HO"F1E9FEN92@G2T],
M04)?4TA!4D5?34%0)RP@)VMO;&%B7W-H87)E7VUA<"<I.PH*+RHJ"B`J(%1H
M92!P<F5F:7@@9F]R(&%L;"!+;VQA8B!G<F]U<'=A<F4@;V)J96-T(&UI;64@
M='EP92!S=')I;F=S+B!%86-H(&]B:F5C=`H@*B!T>7!E(&AA<R!T:&ES('-T
M<FEN9R!I;B!C;VUM;VXL('=I=&@@82!S=69F:7@@;V8@92YG+B`G;F]T92<L
M("=E=F5N="<L(&5T8RX*("H@=&\@:6YD:6-A=&4@=VAA="!T:&4@<W!E8VEF
M:6,@2V]L86(@9W)O=7!W87)E(&9O<FUA="!I<RX*("HO"F1E9FEN92@G2T],
M04)?34E-15]465!%7U!2149)6"<L("=A<'!L:6-A=&EO;B]X+79N9"YK;VQA
M8BXG*3L*"B\J*@H@*B!4:&4@<W1R:6YG('5S960@=&\@:61E;G1I9GD@=&AE
M($AO<F1E+TMO;&%B(&EN=&5G<F%T:6]N(&5N9VEN92!I;B!V87)I;W5S"B`J
M('!L86-E<R`H92YG+B!I;B!+;VQA8B!O8FIE8W1S(&=E;F5R871E9"!B>2!T
M:&4@;&EB<F%R>2DN"B`J+PID969I;F4H)TM/3$%"7U!23T150U1?240G+"`G
M:&]R9&4O:V]L86(O,2XP)RD["@HO*BH*("H@5&AE($AO<F1E7TMO;&%B(&QI
M8G)A<GD@:7,@8F]T:"!A;B!O8FIE8W0@=7-E9"!B>2!A<'!L:6-A=&EO;B!D
M<FEV97)S('1O"B`J(&-O;6UU;FEC871E('=I=&@@82!+;VQA8B!S97)V97(L
M(&%S('=E;&P@87,@82!U=&EL:71Y(&QI8G)A<GD@<')O=FED:6YG"B`J('-E
M=F5R86P@9G5N8W1I;VYS('1O(&AE;'`@:6X@=&AE($E-05`@9F]L9&5R(#PM
M/B!(;W)D92!3:&%R92!S>6YC:')O;FES871I;VX*("H@<')O8V5S<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO2V]L86(O2V]L86(N<&AP+'8@,2XR-BXQ
M,"XQ-B`R,#`V+S`W+S$W(#`Y.C,P.C4P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]H;W)D92YO
M<F<O*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U87)T($)I;F=E
M(#QO;6EC<F]N0&UI9VAT>2YC;RYZ83X*("H@0'!A8VMA9V4@2&]R9&5?2V]L
M86(*("HO"F-L87-S($MO;&%B('L*"B\O($-L87-S(&EN=&5R9F%C90H*("`@
M("\J*@H@("`@("H@5&AE(&-U<G)E;G0@87!P;&EC871I;VX@=&AA="!T:&ES
M($MO;&%B(&]B:F5C="!I;G-T86YC92!I<R!C871E<FEN9R!T;RX*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A<'`["@H@
M("`@+RHJ"B`@("`@*B!/=7(@3F5T7TE-05`@;V)J96-T+"!U<V5D('1O(&-O
M;6UU;FEC871E('=I=&@@=&AE($-Y<G5S('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`=F%R($YE=%])34%0"B`@("`@*B\*("`@('9A<B`D7VEM87`@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@02!C86-H960@=F5R<VEO;B!O9B!+;VQA8CHZ
M9V5T07!P0V]N<W1S*"1T:&ES+3Y?87!P*2!T:&%T(&ES('5S960@:6X*("`@
M("`J('-E=F5R86P@;V8@=&AE($MO;&%B.CH@9G5N8W1I;VYS+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!P7V-O;G-T
M<SL*"B`@("`O*BH*("`@("`J($$@<VAO<G1C=70@=&\@)'1H:7,M/E]A<'!?
M8V]N<W1S6R=M:6UE7W1Y<&5?<W5F9FEX)UT*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]O8FIE8W1?='EP93L*"B`@("`O
M*BH*("`@("`J(%1H92!F=6QL(&UI;64@='EP92!S=')I;F<@;V8@=&AE(&-U
M<G)E;G0@2V]L86(@;V)J96-T(&9O<FUA="!W92=R90H@("`@("H@9&5A;&EN
M9R!W:71H+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7VUI;65?='EP93L*"B`@("`O*BH*("`@("`J(%1H92`H96YC;V1E
M9"D@;F%M92!O9B!T:&4@24U!4"!F;VQD97(@=&AA="!C;W)R97-P;VYD<R!T
M;R!T:&4@8W5R<F5N=`H@("`@("H@<VAA<F4N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9F]L9&5R.PH*("`@("\J*@H@
M("`@("H@5&AE($U)345?365S<V%G92!O8FIE8W0@=&AA="!C;VYT86EN<R!T
M:&4@8W5R<F5N=&QY(&QO861E9"!M97-S86=E+B!4:&ES"B`@("`@*B!I<R!U
M<V5D('=H96X@=7!D871I;F<@86X@;V)J96-T+"!I;B!O<F1E<B!T;R!P<F5S
M97)V92!E=F5R>71H:6YG(&5L<V4*("`@("`J('=I=&AI;B!T:&4@;65S<V%G
M92!T:&%T('=E(&1O;B=T(&MN;W<@:&]W('1O(&AA;F1L92X*("`@("`J"B`@
M("`@*B!`=F%R($U)345?365S<V%G90H@("`@("HO"B`@("!V87(@)%]M97-S
M86=E.PH*("`@("\J*@H@("`@("H@06X@87)R87D@8V]N=&%I;FEN9R`D7VUE
M<W-A9V4G<R!H96%D97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?:&5A9&5R<SL*"B`@("`O*BH*("`@("`J(%1H92!-
M24U%(&ED96YT:69I97(@;V8@=&AE($MO;&%B(&=R;W5P=V%R92!O8FIE8W0@
M=VET:&EN("1T:&ES+3Y?;65S<V%G92X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]M:6UE7VED.PH*("`@("\J*@H@("`@
M("H@5&AE("A+;VQA8BD@54E$(&]F("1T:&ES+3Y?;65S<V%G92X*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]U:60["@H@
M("`@+RHJ"B`@("`@*B!4:&4@1&]M1&]C=6UE;G0@;V)J96-T('1H870@8V]N
M=&%I;G,@=&AE(%A-3"!$3TT@=')E92!O9B!T:&4@8W5R<F5N=&QY"B`@("`@
M*B!L;V%D960@9W)O=7!W87)E(&]B:F5C="X@5V4@8V%C:&4@=&AI<R!H97)E
M('1O(&5N<W5R92!P<F5S97)V871I;VX@;V8*("`@("`J('5N:VYO=VX@9FEE
M;&1S('=H96X@<F4M<V%V:6YG('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'9A<B!$;VU$;V-U;65N=`H@("`@("HO"B`@("!V87(@)%]X;6P["@H@("`@
M+RHJ"B`@("`@*B!4:&4@24U!4"!M97-S86=E(&YU;6)E<B!O9B`D=&AI<RT^
M7VUE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D7VUS9U]N;SL*"B`@("!F=6YC=&EO;B!G9715240H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W5I9#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971-:6UE5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;6EM95]T>7!E.PH@("`@?0H*("`@(&9U;F-T:6]N($MO;&%B*"D*("`@
M('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D=&AI<RT^
M7V%P<"`]("1R96=I<W1R>2T^9V5T07!P*"D["B`@("!]"@H@("`@9G5N8W1I
M;VX@;W!E;B@D<VAA<F5?=6ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)V1O;7AM
M;"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(DAO<F1E+TMO;&%B.B!4:&4@:6YT96=R871I;VX@96YG:6YE(')E<75I<F5S
M('1H92`G9&]M>&UL)R!02%`@97AT96YS:6]N(BDI.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]A<'!?8V]N<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T
M<R@D=&AI<RT^7V%P<"D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]A<'!?
M8V]N<W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V%P<%]C;VYS=',["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7V]B:F5C=%]T>7!E(#T@)'1H:7,M/E]A<'!?8V]N<W1S6R=M:6UE7W1Y<&5?
M<W5F9FEX)UT["B`@("`@("`@)'1H:7,M/E]M:6UE7W1Y<&4@/2!+3TQ!0E]-
M24U%7U194$5?4%)%1DE8("X@)'1H:7,M/E]O8FIE8W1?='EP93L*"B`@("`@
M("`@)&-U<G)E;G1?=7-E<B`]($%U=&@Z.F=E=$%U=&@H*3L*("`@("`@("`D
M;F1X(#T@<W1R<&]S*"1C=7)R96YT7W5S97(L("=`)RD["B`@("`@("`@)'5S
M97(@/2`D;F1X(#T]/2!F86QS92`_("1C=7)R96YT7W5S97(@.B!S=6)S='(H
M)&-U<G)E;G1?=7-E<BP@,"P@)&YD>"D["B`@("`@("`@)&1O;6%I;B`]('-T
M<G-T<B@D8W5R<F5N=%]U<V5R+"`G0"<I.PH*("`@("`@("`D<VAA<F5?;6%P
M(#T@2V]L86(Z.F=E=%-H87)E36%P*"D["B`@("`@("`@:68@*&5M<'1Y*"1S
M:&%R95]M87!;)'-H87)E7W5I9%TI*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"B`@("`@("`@)&9O;&1E<B`]("1S:&%R95]M87!;
M)'-H87)E7W5I9%T["@H@("`@("`@("\O(%1R86YS;&%T92!R96UO=&4M<WEN
M=&%X(&9O;&1E<G,@=&AA="!W92!O=VX@=&\@;&]C86PM<WEN=&%X('-O('1H
M870*("`@("`@("`O+R!W92!C86X@;W!E;B!T:&5M('!R;W!E<FQY"B`@("`@
M("`@<')E9U]M871C:"@B.W5S97(O*%M>+UTK*2\H6UY`72LI*$`N*BD_.R(L
M("1F;VQD97(L("1M871C:&5S*3L*"B`@("`@("`@)'5S97)?9&]M86EN(#T@
M:7-S970H)&UA=&-H97-;,UTI(#\@)&UA=&-H97-;,UT@.B`D9&]M86EN.PH@
M("`@("`@(&EF("@D;6%T8VAE<ULQ72`]/2`D=7-E<B`F)B`D=7-E<E]D;VUA
M:6X@/3T@)&1O;6%I;BD@>PH@("`@("`@("`@("`D9F]L9&5R(#T@(DE.0D]8
M+R1M871C:&5S6S)=(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M9F]L9&5R(#T@(G5S97(O)&UA=&-H97-;,5TO)&UA=&-H97-;,ETB.PH@("`@
M("`@("`@("!I9B`H)'5S97)?9&]M86EN("$]("1D;VUA:6XI('L*("`@("`@
M("`@("`@("`@("1F;VQD97(@+CT@)'5S97)?9&]M86EN.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9O;&1E<B`]("1F;VQD
M97(["@H@("`@("`@("1T:&ES+3Y?:6UA<"`](&YE=R!.971?24U!4"@D8V]N
M9ELG:V]L86(G75LG:6UA<"==6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;
M)VEM87`G75LG<&]R="==*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6UA<"T^;&]G:6XH)&-U<G)E;G1?=7-E<BP@075T:#HZ9V5T0W)E9&5N=&EA
M;"@G<&%S<W=O<F0G*2P@9F%L<V4L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6UA<"T^<V5L96-T36%I;&)O>"@D=&AI<RT^7V9O;&1E<BD["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]I;6%P+3YD:7-C;VYN96-T*"D["B`@("`@("`@("`@("1T:&ES
M+3Y?:6UA<"`](&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&9I;F1/8FIE8W0H)'5I9"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YS96%R8V@H
M(E-50DI%0U0@7"(D=6ED7"(B*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1R97-U;'0I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M2&]R9&4O2V]L86(Z($YO(&UE<W-A9V4@8V]R<F5S<&]N9',@=&\@;V)J96-T
M("5S(BDL("1U:60I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M=6QT6S!=.PH@("`@?0H*("`@(&9U;F-T:6]N(&QI<W1/8FIE8W1S*"D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/E]I;6%P+3YS96%R8V@H)TA%041%4B`B)R`N($M/3$%"7TA%041%
M4E]465!%("X@)R(@(B<@+B`D=&AI<RT^7VUI;65?='EP92`N("<B)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@9FEN9$]B:F5C=',H)&-R:71E<FEA*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7VEM87`M/G-E87)C:"@D8W)I=&5R:6$I.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&QI<W1/8FIE8W1S26Y&;VQD97(H)&9O;&1E<BD*("`@('L*("`@
M("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("\O($-O;FYE8W0@=&\@=&AE
M($E-05`@<V5R=F5R"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O
M;F9;)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==
M6R=I;6%P)UU;)W!O<G0G72D["@H@("`@("`@("\O($QO9VEN('5S:6YG('1H
M92!C=7)R96YT($AO<F1E(&-R961E;G1I86QS"B`@("`@("`@)')E<W5L="`]
M("1I;6%P+3YL;V=I;BA!=71H.CIG971!=71H*"DL($%U=&@Z.F=E=$-R961E
M;G1I86PH)W!A<W-W;W)D)RDL(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G56YA8FQE('1O(&%U=&AE;G1I8V%T92!W:71H
M('1H92!+;VQA8B!)34%0('-E<G9E<B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@+R\@4V5L96-T(&UA:6QB;W@@=&\@<V5A<F-H(&EN"B`@("`@("`@)')E
M<W5L="`]("1I;6%P+3YS96QE8W1-86EL8F]X*"1F;VQD97(I.PH@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?:6UA
M<"T^<V5A<F-H*"=(14%$15(@(B<@+B!+3TQ!0E](14%$15)?5%E012`N("<B
M("(G("X@)'1H:7,M/E]M:6UE7W1Y<&4@+B`G(B<I.PH@("`@("`@("1I;6%P
M+3YD:7-C;VYN96-T*"D["@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M?0H*("`@("\O(%1/1$\Z('=R:71E(&$@9G5N8W1I;VX@=&AA="!I<R!A8FQE
M('1O(&QO;VL@=&AR;W5G:"!A;&P@9F]L9&5R<PH@("`@+R\@;V8@=&AE('1Y
M<&4@=V4G<F4@:6YT97)E<W1E9"!I;BP@;&]O:VEN9R!F;W(@86X@;V)J96-T
M('=I=&@@80H@("`@+R\@<W!E8VEF:6,@54E$+B!4:&ES(&ES(&YE961E9"!F
M;W(@=&AE(&=E=$)Y1U5)1"@I(&9U;F-T:6]N<R!I;@H@("`@+R\@=&AE('9A
M<FEO=7,@87!P;&EC871I;VX@9')I=F5R<RX*"B`@("!F=6YC=&EO;B!M;W9E
M3V)J96-T*"1U:60L("1N97=?<VAA<F4I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?:6UA<"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@)&US9U]N;R`]("1T:&ES+3YF:6YD3V)J
M96-T*"1U:60I.PH@("`@("`@(&EF("AI<U]A*"1M<V=?;F\L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1M<V=?;F\["B`@("`@("`@
M?0H*("`@("`@("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D[
M"B`@("`@("`@:68@*&5M<'1Y*"1S:&%R95]M87!;)&YE=U]S:&%R95TI*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H
M7R@B2&]R9&4O2V]L86(Z(%5N:VYO=VX@<VAA<F4@7"(E<UPB(BDL("1N97=?
M<VAA<F4I*3L*("`@("`@("!]"@H@("`@("`@("1N97=?9F]L9&5R(#T@)'-H
M87)E7VUA<%LD;F5W7W-H87)E73L*"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?:6UA<"T^8V]P>4UE<W-A9V5S*"1N97=?9F]L9&5R+"`D;7-G7VYO*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?:6UA<"T^9&5L971E365S<V%G97,H)&US9U]N
M;RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7VEM87`M/F5X<'5N9V4H*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!R96UO=F5/8FIE8W1S*"1O8FIE8W1S+"`D:7-?;7-G;F\@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1O8FIE8W1S*2D@>PH@("`@("`@("`@("`D
M;V)J96-T<R`](&%R<F%Y*"1O8FIE8W1S*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@D:7-?;7-G;F\@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1N97=?
M;V)J96-T<R`](&%R<F%Y*"D["@H@("`@("`@("`@("!F;W)E86-H("@D;V)J
M96-T<R!A<R`D;V)J96-T*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F9I;F1/8FIE8W0H)&]B:F5C="D["B`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@)&YE=U]O8FIE8W1S6UT@/2`D<F5S=6QT.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D;V)J96-T<R`]("1N97=?;V)J96-T
M<SL*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M
M/F1E;&5T94UE<W-A9V5S*"1O8FIE8W1S*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M:6UA<"T^97AP=6YG92@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC
M=&EO;B!R96UO=F5!;&Q/8FIE8W1S*"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I;6%P+3YD
M96QE=&5-97-S86=E<R@D=&AI<RT^;&ES=$]B:F5C=',H*2D["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N("9L;V%D3V)J96-T*"1U:60L("1I
M<U]M<V=N;R`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7VEM87`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D:7-?;7-G;F\@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1U:60@/2`D=&AI<RT^9FEN9$]B:F5C="@D=6ED*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)'5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1U:60["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?:&5A9&5R<R`]("1T:&ES+3Y?:6UA<"T^9V5T
M4&%R<V5D2&5A9&5R<R@D=6ED*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^
M7VAE861E<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D;65S<V%G95]T97AT(#T@
M)'1H:7,M/E]I;6%P+3YG971-97-S86=E<R@D=6ED*3L*("`@("`@("!I9B`H
M:7-?82@D;65S<V%G95]T97AT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D;65S<V%G95]T97AT.PH@("`@("`@('T*"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1M97-S86=E7W1E>'0I*2!["B`@("`@("`@("`@("1M
M97-S86=E7W1E>'0@/2!A<G)A>5]S:&EF="@D;65S<V%G95]T97AT*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?;7-G7VYO(#T@)'5I9#L*("`@("`@
M("`D=&AI<RT^7VUE<W-A9V4@/2`F34E-15]3=')U8W1U<F4Z.G!A<G-E5&5X
M=$U)345-97-S86=E*"1M97-S86=E7W1E>'0I.PH*("`@("`@("`D<&%R=',@
M/2`D=&AI<RT^7VUE<W-A9V4M/F-O;G1E;G14>7!E36%P*"D["B`@("`@("`@
M:68@*"@D=&AI<RT^7VUI;65?:60@/2!A<G)A>5]S96%R8V@H)'1H:7,M/E]M
M:6UE7W1Y<&4L("1P87)T<RDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`D
M<&%R="`]("1T:&ES+3Y?;65S<V%G92T^9V5T4&%R="@D=&AI<RT^7VUI;65?
M:60I.PH@("`@("`@("`@("`D=&5X="`]("1P87)T+3YT<F%N<V9E<D1E8V]D
M92@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z($YO(&]B:F5C
M="!O9B!T>7!E("5S(&9O=6YD(&EN(&UE<W-A9V4@)7,B*2P@)'1H:7,M/E]M
M:6UE7W1Y<&4L("1U:60I*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M>&UL(#T@0&1O;7AM;%]O<&5N7VUE;2@D=&5X="P@1$]-6$U,7TQ/041?4$%2
M4TE.1R!\"B`@("`@("`@("`@($1/35A-3%],3T%$7T-/35!,151%7T%45%)3
M('P@1$]-6$U,7TQ/041?4U5"4U1)5%5415]%3E1)5$E%4R!\"B`@("`@("`@
M("`@($1/35A-3%],3T%$7T1/3E1?2T5%4%]"3$%.2U,L("1E<G)O<BD["B`@
M("`@("`@:68@*"%E;7!T>2@D97)R;W(I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z($EN
M=F%L:60@)7,@6$U,(&1A=&$@96YC;W5N=&5R960@:6X@;65S<V%G92`E<R(I
M+"`D=&AI<RT^7V]B:F5C=%]T>7!E+"`D=6ED*2D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7W5I9"`]("1T:&ES+3YG971686PH)W5I9"<I.PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7WAM;"T^9&]C=6UE;G1?96QE;65N="@I.PH@
M("`@?0H*("`@(&9U;F-T:6]N("9N97=/8FIE8W0H)'5I9"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]I;6%P*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VUS9U]N
M;R`]("TQ.PH*("`@("`@("`D=&AI<RT^7VUE<W-A9V4@/2!N97<@34E-15]-
M97-S86=E*"D["@H@("`@("`@("1K;VQA8E]T97AT(#T@<W!R:6YT9BA?*")4
M:&ES(&ES(&$@2V]L86(@1W)O=7!W87)E(&]B:F5C="X@5&\@=FEE=R!T:&ES
M(&]B:F5C="!Y;W4@=VEL;"!N965D(&%N(&5M86EL(&-L:65N="!T:&%T('5N
M9&5R<W1A;F1S('1H92!+;VQA8B!'<F]U<'=A<F4@9F]R;6%T+B!&;W(@82!L
M:7-T(&]F('-U8V@@96UA:6P@8VQI96YT<R!P;&5A<V4@=FES:70@)7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT='`Z+R]W=W<N:V]L
M86(N;W)G+VMO;&%B,BUC;&EE;G1S+FAT;6PG*3L*"B`@("`@("`@)'!A<G0@
M/2!N97<@34E-15]087)T*"=T97AT+W!L86EN)RP@4W1R:6YG.CIW<F%P*"1K
M;VQA8E]T97AT+"`W-BP@2T],04)?3D573$E.12P@3DQ3.CIG971#:&%R<V5T
M*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("`@("`@)'!A<G0M/G-E=%1R86YS9F5R16YC;V1I;F<H
M)W%U;W1E9"UP<FEN=&%B;&4G*3L*("`@("`@("`D=&AI<RT^7VUE<W-A9V4M
M/F%D9%!A<G0H)'!A<G0I.PH*("`@("`@("`D<&%R="`](&YE=R!-24U%7U!A
M<G0H)'1H:7,M/E]M:6UE7W1Y<&4L("<G+"!.3%,Z.F=E=$-H87)S970H*2D[
M"B`@("`@("`@)'!A<G0M/G-E=%1R86YS9F5R16YC;V1I;F<H)W%U;W1E9"UP
M<FEN=&%B;&4G*3L*("`@("`@("`D=&AI<RT^7VUE<W-A9V4M/F%D9%!A<G0H
M)'!A<G0I.PH*("`@("`@("`D<&%R=',@/2`D=&AI<RT^7VUE<W-A9V4M/F-O
M;G1E;G14>7!E36%P*"D["B`@("`@("`@:68@*"@D=&AI<RT^7VUI;65?:60@
M/2!A<G)A>5]S96%R8V@H)'1H:7,M/E]M:6UE7W1Y<&4L("1P87)T<RDI(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(DAO<F1E+TMO;&%B.B!5;F%B;&4@=&\@<F5T<FEE=F4@
M34E-12!)1"!F;W(@=&AE('!A<G0@;V8@='EP92`E<R(I+"`D=&AI<RT^7VUI
M;65?='EP92DI.PH@("`@("`@('T*"B`@("`@("`@)&AE861E<G,@/2!N97<@
M34E-15](96%D97)S*"D["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G
M1G)O;2<L($%U=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@)&AE861E<G,M/F%D
M9$AE861E<B@G5&\G+"!!=71H.CIG971!=71H*"DI.PH@("`@("`@("1H96%D
M97)S+3YA9&1(96%D97(H)U-U8FIE8W0G+"`D=6ED*3L*("`@("`@("`D:&5A
M9&5R<RT^861D2&5A9&5R*"=5<V5R+4%G96YT)RP@2T],04)?4%)/1%5#5%])
M1"D["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G4F5P;'DM5&\G+"`G
M)RD["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<B@G1&%T92<L(&1A=&4H
M)W(G*2D["B`@("`@("`@)&AE861E<G,M/F%D9$AE861E<BA+3TQ!0E](14%$
M15)?5%E012P@)'1H:7,M/E]M:6UE7W1Y<&4I.PH@("`@("`@("1H96%D97)S
M+3YA9&1-24U%2&5A9&5R<R@D=&AI<RT^7VUE<W-A9V4I.PH*("`@("`@("`D
M=&AI<RT^7VAE861E<G,@/2`D:&5A9&5R<RT^=&]!<G)A>2@I.PH*("`@("`@
M("`D=&AI<RT^7WAM;"`](&1O;7AM;%]O<&5N7VUE;2@*("`@("`@("`@("`@
M)SP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^)R`N"B`@
M("`@("`@("`@("<\)R`N("1T:&ES+3Y?;V)J96-T7W1Y<&4@+B`G('9E<G-I
M;VX](C$N,"(^)R`N"B`@("`@("`@("`@("<\=6ED/B<@+B`D=6ED("X@)SPO
M=6ED/B<@+@H@("`@("`@("`@("`G/&)O9'D^/"]B;V1Y/B<@+@H@("`@("`@
M("`@("`G/&-A=&5G;W)I97,^/"]C871E9V]R:65S/B<@+@H@("`@("`@("`@
M("`G/&-R96%T:6]N+61A=&4^)R`N($MO;&%B.CIE;F-O9&5$871E5&EM92@I
M("X@)SPO8W)E871I;VXM9&%T93XG("X*("`@("`@("`@("`@)SQS96YS:71I
M=FET>3YP=6)L:6,\+W-E;G-I=&EV:71Y/B<@+@H@("`@("`@("`@("`G/"\G
M("X@)'1H:7,M/E]O8FIE8W1?='EP92`N("<^)RP*("`@("`@("`@("`@1$]-
M6$U,7TQ/041?4$%24TE.1R!\($1/35A-3%],3T%$7T-/35!,151%7T%45%)3
M('P*("`@("`@("`@("`@1$]-6$U,7TQ/041?4U5"4U1)5%5415]%3E1)5$E%
M4R!\($1/35A-3%],3T%$7T1/3E1?2T5%4%]"3$%.2U,L"B`@("`@("`@("`@
M("1E<G)O<@H@("`@("`@("D["B`@("`@("`@:68@*"%E;7!T>2@D97)R;W(I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!C<F5A=&4@;F5W(%A-3"!T
M<F5E(&9O<B!O8FIE8W0@)7,B*2P@)'5I9"DI.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]U:60@/2`D=6ED.PH*("`@("`@("!R971U<FX@)'1H:7,M
M/E]X;6PM/F1O8W5M96YT7V5L96UE;G0H*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!S879E3V)J96-T*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/E]I;6%P*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^<V5T5F%L*"=L87-T+6UO9&EF:6-A=&EO;BUD
M871E)RP@2V]L86(Z.F5N8V]D941A=&54:6UE*"DI.PH@("`@("`@("1T:&ES
M+3YS971686PH)W!R;V1U8W0M:60G+"!+3TQ!0E]04D]$54-47TE$*3L*"B`@
M("`@("`@)'!A<G0@/2!N97<@34E-15]087)T*"1T:&ES+3Y?;6EM95]T>7!E
M+"`D=&AI<RT^7WAM;"T^9'5M<%]M96TH=')U92DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`D
M<&%R="T^<V5T5')A;G-F97)%;F-O9&EN9R@G<75O=&5D+7!R:6YT86)L92<I
M.PH@("`@("`@("1T:&ES+3Y?;65S<V%G92T^86QT97)087)T*"1T:&ES+3Y?
M;6EM95]I9"P@)'!A<G0I.PH*("`@("`@("!I9B`H)'1H:7,M/E]M<V=?;F\@
M(3T@+3$I('L*("`@("`@("`@("`@)'1H:7,M/G)E;6]V94]B:F5C=',H)'1H
M:7,M/E]M<V=?;F\L('1R=64I.PH@("`@("`@('T*"B`@("`@("`@)&AE861E
M<G,@/2!N97<@34E-15](96%D97)S*"D["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]H96%D97)S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D
M:&5A9&5R<RT^861D2&5A9&5R*"1K97DL("1V86PI.PH@("`@("`@('T*"B`@
M("`@("`@)&UE<W-A9V4@/2!+;VQA8CHZ:V]L86).97=L:6YE<R@D:&5A9&5R
M<RT^=&]3=')I;F<H*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUE<W-A9V4M/G1O4W1R:6YG*&9A;'-E*2D[
M"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM87`M/F%P<&5N9$UE<W-A
M9V4H)&UE<W-A9V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7VUS9U]N;R`]("1T:&ES+3YF:6YD3V)J
M96-T*"1T:&ES+3Y?=6ED*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VUS
M9U]N;RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]M<V=?;F\["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("!F=6YC=&EO;B`F9V5T0W5R<F5N=$]B:F5C="@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?>&UL+3YD;V-U;65N=%]E;&5M96YT
M*"D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$5L96TH)&YA;64L("8D<&%R
M96YT*0H@("`@>PH@("`@("`@("1E;&5M96YT<R`]("8D=&AI<RT^9V5T06QL
M16QE;7,H)&YA;64L("1P87)E;G0I.PH*("`@("`@("!I9B`H96UP='DH)&5L
M96UE;G1S*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&5L96UE;G1S6S!=.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9G971!;&Q%;&5M<R@D;F%M92P@)B1P87)E;G0I"B`@("!["B`@
M("`@("`@<F5T=7)N("1P87)E;G0M/F=E=%]E;&5M96YT<U]B>5]T86=N86UE
M*"1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4F]O=$5L96TH)&YA
M;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YG971%;&5M*"1N86UE
M+"`D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B`F9V5T06QL4F]O=$5L96US*"1N86UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T06QL16QE;7,H)&YA;64L("1T:&ES+3YG971#=7)R
M96YT3V)J96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;$5L96TH)&YA
M;64L("8D<&%R96YT*0H@("`@>PH@("`@("`@("1E;&5M96YT(#T@)B1T:&ES
M+3YG971%;&5M*"1N86UE+"`D<&%R96YT*3L*("`@("`@("!I9B`H)&5L96UE
M;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<&%R96YT+3YR96UO=F5?8VAI;&0H)&5L96UE
M;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;$%L;$5L96US*"1N86UE+"`F
M)'!A<F5N="D*("`@('L*("`@("`@("`D96QE;65N=',@/2`F)'1H:7,M/F=E
M=$%L;$5L96US*"1N86UE+"`D<&%R96YT*3L*("`@("`@("!F;W(@*"1I(#T@
M,"P@)&H@/2!C;W5N="@D96QE;65N=',I.R`D:2`\("1J.R`D:2LK*2!["B`@
M("`@("`@("`@("1P87)E;G0M/G)E;6]V95]C:&EL9"@D96QE;65N='-;)&E=
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M9G5N8W1I;VX@9&5L06QL4F]O=$5L96US*"1N86UE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^9&5L06QL16QE;7,H)&YA;64L("1T:&ES+3YG971#
M=7)R96YT3V)J96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;%)O;W1%
M;&5M*"8D96QE;65N="D*("`@('L*("`@("`@("!I9B`H)&5L96UE;G0@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@("1R;V]T(#T@)B1T:&ES+3YG971#=7)R96YT3V)J96-T*"D["B`@("`@
M("`@<F5T=7)N("1R;V]T+3YR96UO=F5?8VAI;&0H)&5L96UE;G0I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&=E=$5L96U686PH)B1P87)E;G0L("1N86UE+"`D
M9&5F875L="`](#`I"B`@("!["B`@("`@("`@:68@*"1P87)E;G0@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!]
M"@H@("`@("`@("1E;&5M96YT(#T@)B1T:&ES+3YG971%;&5M*"1N86UE+"`D
M<&%R96YT*3L*("`@("`@("!I9B`H)&5L96UE;G0@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B`D9&5F875L=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D96QE;65N="T^9V5T7V-O;G1E;G0H*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971%;&5M4W1R*"8D<&%R96YT+"`D;F%M92P@)&1E9F%U;'0@
M/2`G)RD*("`@('L*("`@("`@("!I9B`H)'!A<F5N="`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N("1D969A=6QT.PH@("`@("`@('T*"B`@("`@
M("`@)&5L96UE;G0@/2`F)'1H:7,M/F=E=$5L96TH)&YA;64L("1P87)E;G0I
M.PH@("`@("`@(&EF("@D96QE;65N="`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N("1D969A=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&5L96UE;G0M/F=E=%]C;VYT96YT
M*"DL("=U=&8M."<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%9A;"@D;F%M
M92P@)&1E9F%U;'0@/2`P*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9V5T16QE;59A;"@D=&AI<RT^9V5T0W5R<F5N=$]B:F5C="@I+"`D;F%M92P@
M)&1E9F%U;'0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-T<B@D;F%M92P@
M)&1E9F%U;'0@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E
M=$5L96U3='(H)'1H:7,M/F=E=$-U<G)E;G1/8FIE8W0H*2P@)&YA;64L("1D
M969A=6QT*3L*("`@('T*"B`@("!F=6YC=&EO;B`F:6YI=$5L96TH)&YA;64L
M("8D<&%R96YT*0H@("`@>PH@("`@("`@(&EF("@D<&%R96YT(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`D<&%R96YT(#T@)'1H:7,M/F=E=$-U<G)E;G1/
M8FIE8W0H*3L*("`@("`@("!]"@H@("`@("`@("1E;&5M96YT(#T@)'1H:7,M
M/F=E=$5L96TH)&YA;64L("1P87)E;G0I.PH*("`@("`@("!I9B`H)&5L96UE
M;G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1E;&5M96YT(#T@)'!A<F5N
M="T^87!P96YD7V-H:6QD*"1T:&ES+3Y?>&UL+3YC<F5A=&5?96QE;65N="@D
M;F%M92DI.PH@("`@("`@('T*"B`@("`@("`@)&-H:6QD<F5N(#T@)&5L96UE
M;G0M/F-H:6QD7VYO9&5S*"D["B`@("`@("`@9F]R96%C:"`H)&-H:6QD<F5N
M(&%S("1C:&EL9"D@>PH@("`@("`@("`@("!I9B`H)&-H:6QD+3YN;V1E7W1Y
M<&4H*2`]/2!834Q?5$585%].3T1%*2!["B`@("`@("`@("`@("`@("`D96QE
M;65N="T^<F5M;W9E7V-H:6QD*"1C:&EL9"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D96QE;65N=#L*("`@('T*"B`@("!F
M=6YC=&EO;B`F:6YI=%)O;W1%;&5M*"1N86UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^:6YI=$5L96TH)&YA;64L("1T:&ES+3YG971#=7)R96YT
M3V)J96-T*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N("9A<'!E;F1%;&5M*"1N
M86UE+"`F)'!A<F5N="D*("`@('L*("`@("`@("!R971U<FX@)'!A<F5N="T^
M87!P96YD7V-H:6QD*"1T:&ES+3Y?>&UL+3YC<F5A=&5?96QE;65N="@D;F%M
M92DI.PH@("`@?0H*("`@(&9U;F-T:6]N("9A<'!E;F12;V]T16QE;2@D;F%M
M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F%P<&5N9$5L96TH)&YA
M;64L("1T:&ES+3YG971#=7)R96YT3V)J96-T*"DI.PH@("`@?0H*("`@(&9U
M;F-T:6]N("9S971%;&5M5F%L*"8D<&%R96YT+"`D;F%M92P@)'9A;'5E(#T@
M)R<I"B`@("!["B`@("`@("`@)&5L96UE;G0@/2`F)'1H:7,M/FEN:71%;&5M
M*"1N86UE+"`D<&%R96YT*3L*("`@("`@("`D96QE;65N="T^<V5T7V-O;G1E
M;G0H)'9A;'5E*3L*"B`@("`@("`@<F5T=7)N("1E;&5M96YT.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9S971%;&5M4W1R*"8D<&%R96YT+"`D;F%M92P@)'9A
M;'5E(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS971%;&5M
M5F%L*"1P87)E;G0L("1N86UE+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V
M86QU92P@3DQ3.CIG971#:&%R<V5T*"DL("=U=&8M."<I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B`F<V5T5F%L*"1N86UE+"`D=F%L=64@/2`G)RD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G-E=$5L96U686PH)'1H:7,M/F=E=$-U
M<G)E;G1/8FIE8W0H*2P@)&YA;64L("1V86QU92D["B`@("!]"@H@("`@9G5N
M8W1I;VX@)G-E=%-T<B@D;F%M92P@)'9A;'5E(#T@)R<I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971%;&5M4W1R*"1T:&ES+3YG971#=7)R96YT
M3V)J96-T*"DL("1N86UE+"`D=F%L=64I.PH@("`@?0H*+R\@571I;&ET>2!L
M:6)R87)Y(&EN=&5R9F%C90H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-T
M<FEN9R!C;VYT86EN:6YG('1H92!C=7)R96YT(%540R!D871E(&EN('1H92!F
M;W)M870*("`@("`J('!R97-C<FEB960@8GD@=&AE($MO;&%B($9O<FUA="!3
M<&5C:69I8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8W5R<F5N="!55$,@9&%T92!I;B!T:&4@9F]R;6%T("=965E9+4U-+41$
M)RX*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E1&%T92@D9&%T92`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@D9&%T92`]/3T@,"D@>PH@("`@("`@
M("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-T<F9T
M:6UE*"<E62TE;2TE9"<L("1D871E(#T]/2!F86QS92`_('1I;64H*2`Z("1D
M871E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!53DE8('1I
M;65S=&%M<"!C;W)R97-P;VYD:6YG('1H92!G:79E;B!D871E('-T<FEN9R!W
M:&EC:"!I<R!I;@H@("`@("H@=&AE(&9O<FUA="!P<F5S8W)I8F5D(&)Y('1H
M92!+;VQA8B!&;W)M870@4W!E8VEF:6-A=&EO;BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871E("!4:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N
M(&]F('1H92!D871E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M5&AE('5N:7@@=&EM97-T86UP(&-O<G)E<W!O;F1I;F<@=&\@)&1A=&4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D941A=&4H)&1A=&4I"B`@("!["B`@
M("`@("`@:68@*&5M<'1Y*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@
M,#L*("`@("`@("!]"@H@("`@("`@(&QI<W0H)'EE87(L("1M;VYT:"P@)&1A
M>2D@/2!E>'!L;V1E*"<M)RP@)&1A=&4I.PH@("`@("`@(')E='5R;B!M:W1I
M;64H,"P@,"P@,"P@)&UO;G1H+"`D9&%Y+"`D>65A<BD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-U
M<G)E;G0@551#(&1A=&4@86YD('1I;64@:6X@=&AE(&9O<FUA=`H@("`@("H@
M<')E<V-R:6)E9"!B>2!T:&4@2V]L86(@1F]R;6%T(%-P96-I9FEC871I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("`@5&AE(&-U<G)E;G0@
M551#(&1A=&4@86YD('1I;64@:6X@=&AE(&9O<FUA=`H@("`@("H@("`@("`@
M("`@("`@("`@("`@)UE965DM34TM1$14:&@Z;6TZ<W-:)RP@=VAE<F4@=&AE
M(%0@86YD(%H@87)E(&QI=&5R86P*("`@("`J("`@("`@("`@("`@("`@("`@
M(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D941A=&54
M:6UE*"1D871E=&EM92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D9&%T
M971I;64@/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!G;7-T<F9T:6UE*"<E62TE;2TE9%0E2#HE33HE
M4UHG+"`D9&%T971I;64@/3T](&9A;'-E(#\@=&EM92@I(#H@)&1A=&5T:6UE
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!53DE8('1I;65S
M=&%M<"!C;W)R97-P;VYD:6YG('1H92!G:79E;B!D871E+71I;64@<W1R:6YG
M('=H:6-H"B`@("`@*B!I<R!I;B!T:&4@9F]R;6%T('!R97-C<FEB960@8GD@
M=&AE($MO;&%B($9O<FUA="!3<&5C:69I8V%T:6]N+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&5T:6UE("!4:&4@<W1R:6YG(')E<')E<V5N
M=&%T:6]N(&]F('1H92!D871E("8@=&EM92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN=&5G97(@(%1H92!U;FEX('1I;65S=&%M<"!C;W)R97-P;VYD:6YG
M('1O("1D871E=&EM92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E1&%T
M951I;64H)&1A=&5T:6UE*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D9&%T
M971I;64I*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@
M("`@("`@;&ES="@D>65A<BP@)&UO;G1H+"`D9&%Y+"`D:&]U<BP@)&UI;G5T
M92P@)'-E8V]N9"D*("`@("`@("`@("`@/2!S<V-A;F8H)&1A=&5T:6UE+"`G
M)60M)60M)614)60Z)60Z)61:)RD["B`@("`@("`@<F5T=7)N(&=M;6MT:6UE
M*"1H;W5R+"`D;6EN=71E+"`D<V5C;VYD+"`D;6]N=&@L("1D87DL("1Y96%R
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!53DE8('1I;65S
M=&%M<"!C;W)R97-P;VYD:6YG('1H92!G:79E;B!D871E(&]R(&1A=&4M=&EM
M90H@("`@("H@<W1R:6YG('=H:6-H(&ES(&EN(&5I=&AE<B!F;W)M870@<')E
M<V-R:6)E9"!B>2!T:&4@2V]L86(@1F]R;6%T"B`@("`@*B!3<&5C:69I8V%T
M:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&4@(%1H92!S
M=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&1A=&4@*"8@=&EM92DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@=6YI>"!T:6UE<W1A
M;7`@8V]R<F5S<&]N9&EN9R!T;R`D9&%T92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5C;V1E1&%T94]R1&%T951I;64H)&1A=&4I"B`@("!["B`@("`@("`@
M:68@*&5M<'1Y*"1D871E*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`H<W1R;&5N*"1D871E*2`]/2`Q,"`_
M($MO;&%B.CID96-O9&5$871E*"1D871E*2`Z($MO;&%B.CID96-O9&5$871E
M5&EM92@D9&%T92DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E8V]D949U;&Q$
M87E$871E*"1D871E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D9&%T92DI
M('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@*'-T<FQE;B@D9&%T92D@/3T@,3`@/R!+;VQA8CHZ9&5C;V1E1&%T
M92@D9&%T92DK,C0J-C`J-C`@.B!+;VQA8CHZ9&5C;V1E1&%T951I;64H)&1A
M=&4I*3L*("`@('T*"B`@("!F=6YC=&EO;B!P97)C96YT86=E5&]";V]L96%N
M*"1P97)C96YT86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D<&5R8V5N=&%G
M92`]/2`Q,#`@/R`G,2<@.B`G,"<["B`@("!]"@H@("`@9G5N8W1I;VX@8F]O
M;&5A;E1O4&5R8V5N=&%G92@D8F]O;&5A;BD*("`@('L*("`@("`@("!R971U
M<FX@)&)O;VQE86X@/R`G,3`P)R`Z("<P)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G1S(&$@<W1R:6YG(&EN('1H92!C=7)R96YT(&-H87)A8W1E
M<B!S970@=&\@86X@24U!4"!55$8M-R!S=')I;F<L"B`@("`@*B!S=6ET86)L
M92!F;W(@=7-E(&%S('1H92!N86UE(&]F(&%N($E-05`@9F]L9&5R+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!T97AT(&EN('1H
M92!C=7)R96YT(&-H87)A8W1E<B!S970@=&\@8V]N=F5R="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@("`D;F%M92!E;F-O9&5D(&EN('1H92!)
M34%0('9A<FEA=&EO;B!O9B!55$8M-RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YC;V1E26UA<$9O;&1E<DYA;64H)&YA;64I"B`@("!["B`@("`@("`@<F5T
M=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&YA;64L($Y,4SHZ9V5T0VAA
M<G-E="@I+"`G551&-RU)34%0)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T<R!A('-T<FEN9R!I;B!T:&4@24U!4"!V87)I871I;VX@;V8@551&
M+3<@:6YT;R!A('-T<FEN9R!I;B!T:&4*("`@("`J(&-U<G)E;G0@8VAA<F%C
M=&5R('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@=&5X="!I;B!)34%0(%541BTW('1O(&-O;G9E<G0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@("`@)&YA;64@96YC;V1E9"!I;B!T:&4@8W5R
M<F5N="!C:&%R86-T97(@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O
M9&5);6%P1F]L9&5R3F%M92@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;F%M92P@)U541C<M24U!4"<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@86QL(&YE=VQI;F5S("AI
M;B!$3U,L($U!0R`F(%5.25@@9F]R;6%T*2!I;B!T:&4@<W!E8VEF:65D('1E
M>'0*("`@("`J('1O('5N:7@M<W1Y;&4@*$Q&*2!F;W)M870N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@=&\@8V]N=F5R
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@)'1E>'0@=VET:"!A
M;&P@;F5W;&EN97,@<F5P;&%C960@8GD@3$8N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('5N:7A.97=L:6YE<R@D=&5X="D*("`@('L*("`@("`@("!R971U<FX@
M<')E9U]R97!L86-E*"(O7')<;GQ<;GQ<<B]S(BP@(EQN(BP@)'1E>'0I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@86QL(&YE=VQI;F5S("AI
M;B!$3U,L($U!0R`F(%5.25@@9F]R;6%T*2!I;B!T:&4@<W!E8VEF:65D('1E
M>'0*("`@("`J('1O($MO;&%B("A#>7)U<RD@9F]R;6%T+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT('1O(&-O;G9E<G0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@("1T97AT('=I=&@@86QL
M(&YE=VQI;F5S(')E<&QA8V5D(&)Y($M/3$%"7TY%5TQ)3D4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&MO;&%B3F5W;&EN97,H)'1E>'0I"B`@("!["B`@("`@
M("`@<F5T=7)N('!R96=?<F5P;&%C92@B+UQR7&Y\7&Y\7'(O<R(L($M/3$%"
M7TY%5TQ)3D4L("1T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('5N9F]L9&5D(')E<')E<V5N=&%T:6]N(&]F('1H92!G:79E;B!T
M97AT+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T
M97AT('1O('5N9F]L9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('5N9F]L9&5D(')E<')E<V5N=&%T:6]N(&]F("1T97AT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!U;F9O;&1497AT*"1T97AT*0H@("`@>PH@("`@("`@
M(')E='5R;B!P<F5G7W)E<&QA8V4H(B]<<EQN6R!<=%TK+R(L("(B+"`D=&5X
M="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F
M(&%P<&QI8V%T:6]N+7-P96-I9FEC(&-O;G-T86YT<RP@=&AA="!A<F4@=7-E
M9"!I;@H@("`@("H@82!G96YE<FEC(&UA;FYE<B!T:')O=6=H;W5T('1H92!L
M:6)R87)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE
M(&%P<&QI8V%T:6]N('=H;W-E(&-O;G-T86YT<R!T;R!Q=65R>2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!;B!A<G)A>2!O9B!A<'!L:6-A=&EO
M;BUS<&5C:69I8R!C;VYS=&%N=',@:68@)&%P<"!I<R!A"B`@("`@*B`@("`@
M("`@("`@("`@("!S=7!P;W)T960@87!P;&EC871I;VXL(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@:68@)&%P<"!I<PH@("`@("H@("`@("`@("`@("`@("`@
M;F]T('-U<'!O<G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T07!P0V]N
M<W1S*"1A<'`I"B`@("!["B`@("`@("`@<W=I=&-H("@D87!P*2!["B`@("`@
M("`@8V%S92`G;6YE;6\G.@H@("`@("`@("`@("!R971U<FX@87)R87DH"B`@
M("`@("`@("`@("`@("`G;6EM95]T>7!E7W-U9F9I>"<@("`@("`]/B`G;F]T
M92<L"B`@("`@("`@("`@("`@("`G9&5F875L=%]F;VQD97)?;F%M92<@("`]
M/B!?*").;W1E<R(I+`H@("`@("`@("`@("`@("`@)W-H87)E7VYA;64G("`@
M("`@("`@("`@/3X@7R@B;F]T97!A9"(I+`H@("`@("`@("`@("`@("`@)V1E
M9F%U;'1?<VAA<F5?;F%M92<@("`@/3X@7R@B)7,G<R!.;W1E<&%D(BDL"B`@
M("`@("`@("`@("D["@H@("`@("`@(&-A<V4@)VMR;VYO;&ET:"<Z"B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("=M:6UE7W1Y
M<&5?<W5F9FEX)R`@("`@(#T^("=E=F5N="<L"B`@("`@("`@("`@("`@("`G
M9&5F875L=%]F;VQD97)?;F%M92<@("`]/B!?*")#86QE;F1A<B(I+`H@("`@
M("`@("`@("`@("`@)W-H87)E7VYA;64G("`@("`@("`@("`@/3X@7R@B8V%L
M96YD87(B*2P*("`@("`@("`@("`@("`@("=D969A=6QT7W-H87)E7VYA;64G
M("`@(#T^(%\H(B5S)W,@0V%L96YD87(B*2P*("`@("`@("`@("`@*3L*"B`@
M("`@("`@8V%S92`G='5R8F$G.@H@("`@("`@("`@("!R971U<FX@87)R87DH
M"B`@("`@("`@("`@("`@("`G;6EM95]T>7!E7W-U9F9I>"<@("`@("`]/B`G
M8V]N=&%C="<L"B`@("`@("`@("`@("`@("`G9&5F875L=%]F;VQD97)?;F%M
M92<@("`]/B!?*")#;VYT86-T<R(I+`H@("`@("`@("`@("`@("`@)W-H87)E
M7VYA;64G("`@("`@("`@("`@/3X@7R@B861D<F5S<R!B;V]K(BDL"B`@("`@
M("`@("`@("`@("`G9&5F875L=%]S:&%R95]N86UE)R`@("`]/B!?*"(E<R=S
M($%D9')E<W,@0F]O:R(I+`H@("`@("`@("`@("`I.PH*("`@("`@("!C87-E
M("=N86<G.@H@("`@("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@
M("`@("`G;6EM95]T>7!E7W-U9F9I>"<@("`@("`]/B`G=&%S:R<L"B`@("`@
M("`@("`@("`@("`G9&5F875L=%]F;VQD97)?;F%M92<@("`]/B!?*")487-K
M<R(I+`H@("`@("`@("`@("`@("`@)W-H87)E7VYA;64G("`@("`@("`@("`@
M/3X@7R@B=&%S:R!L:7-T(BDL"B`@("`@("`@("`@("`@("`G9&5F875L=%]S
M:&%R95]N86UE)R`@("`]/B!?*"(E<R=S(%1A<VML:7-T(BDL"B`@("`@("`@
M("`@("D["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B5&AE($AO<F1E+TMO;&%B(&EN
M=&5G<F%T:6]N(&5N9VEN92!D;V5S(&YO="!S=7!P;W)T(%PB)7-<(B(I+"`D
M87!P*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A;B!)34%0($%#3"!S=')I;F<@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV
M96X@2&]R9&4@<&5R;6ES<VEO;G,*("`@("`J('9A;'5E+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1P97)M<R`@5&AE($AO<F1E('!E<FUI<W-I
M;VYS('9A;'5E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]W;F5R("!7:6QL
M('1H92!!0TP@<W1R:6YG(&)E('5S960@9F]R('1H92!F;VQD97(@;W=N97(_
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(%1H:7,@:6YC;'5D97,@
M=&AE("=A)R!R:6=H=',@:6X@=&AE($%#3"!S=')I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!)34%0($%#3"!S=')I;F<@8V]R<F5S
M<&]N9&EN9R!T;R`D<&5R;7,@86YD("1O=VYE<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<&5R;7-4;T%#3"@D<&5R;7,L("1O=VYE<B`]('1R=64I"B`@("![
M"B`@("`@("`@)')E<W5L="`]("1O=VYE<B`_("=A)R`Z("<G.PH@("`@("`@
M(&EF("@D<&5R;7,@)B!015)-4U]32$]7*2!["B`@("`@("`@("`@("1R97-U
M;'0@+CT@)VPG.PH@("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS("8@4$52
M35-?4D5!1"D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("=R)SL*("`@("`@
M("!]"B`@("`@("`@:68@*"1P97)M<R`F(%!%4DU37T5$250I('L*("`@("`@
M("`@("`@)')E<W5L="`N/2`G:7-W8R<["B`@("`@("`@?0H@("`@("`@(&EF
M("@D<&5R;7,@)B!015)-4U]$14Q%5$4I('L*("`@("`@("`@("`@)')E<W5L
M="`N/2`G9"<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!(;W)D92!P97)M:7-S
M:6]N<R!V86QU92!C;W)R97-P;VYD:6YG('1O('1H92!G:79E;B!)34%0($%#
M3`H@("`@("H@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&%C;%]S=')I;F<@(%1H92!)34%0($%#3"!S=')I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@2&]R9&4@<&5R;6ES<VEO;G,@=F%L
M=64@8V]R<F5S<&]N9&EN9R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`D
M86-L7W-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@86-L5&]097)M<R@D
M86-L7W-T<FEN9RD*("`@('L*("`@("`@("`D<F5S=6QT(#T@,#L*"B`@("`@
M("`@9F]R("@D:2`](#`L("1J(#T@<W1R;&5N*"1A8VQ?<W1R:6YG*3L@)&D@
M/"`D:CL@)&DK*RD@>PH@("`@("`@("`@("!S=VET8V@@*"1A8VQ?<W1R:6YG
M6R1I72D@>PH@("`@("`@("`@("!C87-E("=L)SH*("`@("`@("`@("`@("`@
M("1R97-U;'0@?#T@4$5235-?4TA/5SL*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G<B<Z"B`@("`@("`@("`@("`@("`D<F5S
M=6QT('P](%!%4DU37U)%040["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)VDG.@H@("`@("`@("`@("`@("`@)')E<W5L="!\
M/2!015)-4U]%1$E4.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=D)SH*("`@("`@("`@("`@("`@("1R97-U;'0@?#T@4$52
M35-?1$5,151%.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A;B!A<W-O8VEA=&EV92!A<G)A>2!O
M=70@;V8@86X@24U!4"!!0TP@;&ES="!A<R!R971U<FYE9"!B>2!T:&4*("`@
M("`J($YE=%])34%0(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&%C;"`@5&AE($E-05`@04-,(&%R<F%Y+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@($%N(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@
M:V5Y<R!A<F4@:6YD:79I9'5A;"!U<V5R<PH@("`@("H@("`@("`@("`@("`@
M("`@86YD('1H92!V86QU97,@=&AE($%#3"!S=')I;F<@9F]R('1H92!S<&5C
M:69I8R!U<V5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A8VQ4;T%R<F%Y*"1A
M8VPI"B`@("!["B`@("`@("`@:68@*&ES7V$H)&%C;"P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&%C;#L*("`@("`@("!]"@H@("`@
M("`@("1R97-U;'0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1A8VP@
M87,@)'5S97(I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]G<F]U
M<#HH+BLI+R<L("1U<V5R6R=54T52)UTL("1M871C:&5S*2D@>PH@("`@("`@
M("`@("`@("`@+RH@3&]O:R!U<"!A;F0@97AP86YD(&=R;W5P<RX@*B\*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O1W)O=7`N<&AP)SL*
M("`@("`@("`@("`@("`@("1G<F]U<"`]("9'<F]U<#HZ<VEN9VQE=&]N*"D[
M"B`@("`@("`@("`@("`@("`D9VED(#T@)&=R;W5P+3YG971'<F]U<$ED*"1M
M871C:&5S6S%=*3L*("`@("`@("`@("`@("`@("1U<V5R<R`]("1G<F]U<"T^
M;&ES=%5S97)S*"1G:60I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'5S
M97)S(&%S("1U*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L=%LD=5T@
M/2`D=7-E<ELG4DE'2%13)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT6R1U<V5R6R=5
M4T52)UU=(#T@)'5S97);)U))1TA44R==.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G9713:&%R94UA<"@I"B`@("!["B`@("`@("`@<F5T=7)N(&5M<'1Y
M*"1?4T534TE/3EM+3TQ!0E]32$%215]-05!=*0H@("`@("`@("`@/R!A<G)A
M>2@I"B`@("`@("`@("`Z('5N<V5R:6%L:7IE*"1?4T534TE/3EM+3TQ!0E]3
M2$%215]-05!=*3L*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%R94UA<"@D
M<VAA<F5?;6%P*0H@("`@>PH@("`@("`@("1?4T534TE/3EM+3TQ!0E]32$%2
M15]-05!=(#T@<V5R:6%L:7IE*"1S:&%R95]M87`I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('5P9&%T94UA<'!E9%-H87)E*"8D<VAA<F5?;6%P+"`D<VAA<F5?
M=6ED+"`D:6UA<%]F;VQD97(I"B`@("!["B`@("`@("`@)'-H87)E7VUA<%LD
M<VAA<F5?=6ED72`]("1I;6%P7V9O;&1E<CL*("`@('T*"B`@("!F=6YC=&EO
M;B!G9713:&%R94UA<'!I;F<H)B1S:&%R95]M87`L("1S:&%R95]U:60L("1D
M;F5?<F5S=6QT(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N(&5M<'1Y*"1S
M:&%R95]M87!;)'-H87)E7W5I9%TI(#\@)&1N95]R97-U;'0@.B`D<VAA<F5?
M;6%P6R1S:&%R95]U:61=.PH@("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94UA
M<'!E9%-H87)E*"8D<VAA<F5?;6%P+"`D<VAA<F5?=6ED*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D<VAA<F5?;6%P6R1S:&%R95]U:61=*2D@>PH@("`@
M("`@("`@("!U;G-E="@D<VAA<F5?;6%P6R1S:&%R95]U:61=*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3>6YC:')O;FES97,@=&AE(%!E
M<FUS(&]F(&$@2&]R9&4@<VAA<F4@=&\@=&AE($%#3"!O9B!A;B!)34%0(&9O
M;&1E<BP*("`@("`J(&-R96%T:6YG('1H92!F;VQD97(@:68@;F5C97-S87)Y
M+B!)="!A;'-O('-E=',@=&AE(&YE8V5S<V%R>2!A;FYO=&%T:6]N<PH@("`@
M("H@:6YD:6-A=&EN9R!W:&%T(&=R;W5P=V%R92!F;W)M870@='EP92!I<R!C
M;VYT86EN960@=VET:&EN('1H92!F;VQD97(L"B`@("`@*B!A;F0@=VAA="!(
M;W)D92!S:&%R92!I="!C;W)R97-P;VYD<R!T;RX*("`@("`J"B`@("`@*B!`
M<&%R86T@;V)J96-T("1I;6%P("`@02!R969E<F5N8V4@=&\@82!.971?24U!
M4"!O8FIE8W0@=&AA="!I<R!A;')E861Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8V]N;F5C=&5D(&%N9"!A=71H96YT:6-A=&5D('1O('1H92!C
M;W)R96-T('-E<G9E<BX*("`@("`J($!P87)A;2!O8FIE8W0@)'-H87)E("!!
M(')E9F5R96YC92!T;R!T:&4@2&]R9&4@<VAA<F4@;V)J96-T('1H870@=V4@
M87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6YT97)E<W1E9"!I
M;BX*("`@("`J($!P87)A;2!S=')I;F<@)&%P<%]C;VYS=',@($$@<F5F97)E
M;F-E('1O('1H92!R97-U;'0@;V8@82!G971!<'!#;VYS=',H*0H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%L;"!F;W(@=&AE(&-U<G)E
M;G0@2&]R9&4@87!P;&EC871I;VXN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@2&]R9&4O2V]L86(@:6YT96=R871I;VXM<W5P<&]R=&5D(&%P<"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,L
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<WEN8VAR;VYI<V53:&%R92@F)&EM87`L("8D<VAA<F4L("8D
M87!P7V-O;G-T<RD*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@
M("`@(&EF("AE;7!T>2@D<VAA<F4I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@<VAA<F4@;V)J96-T(BDI.PH@
M("`@("`@('T*"B`@("`@("`@)'-H87)E7W5I9"`]("1S:&%R92T^9V5T3F%M
M92@I.PH@("`@("`@("1O=VYE<B`]("1S:&%R92T^9V5T*"=O=VYE<B<I.PH@
M("`@("`@("1D969A=6QT(#T@)'-H87)E7W5I9"`]/2`D;W=N97(["@H@("`@
M("`@("1N9'@@/2!S=')P;W,H)&]W;F5R+"`G0"<I.PH@("`@("`@("1U<V5R
M(#T@)&YD>"`]/3T@9F%L<V4@/R`D;W=N97(@.B!S=6)S='(H)&]W;F5R+"`P
M+"`D;F1X*3L*("`@("`@("`D9&]M86EN(#T@<W1R<W1R*"1O=VYE<BP@)T`G
M*3L*"B`@("`@("`@)&9O;&1E<E]T>7!E(#T@)&%P<%]C;VYS='-;)VUI;65?
M='EP95]S=69F:7@G72`N("@D9&5F875L="`_("<N9&5F875L="<@.B`G)RD[
M"B`@("`@("`@)&9O;&1E<E]N86UE(#T@(G5S97(O)'5S97(O(B`N("@D9&5F
M875L="`_("1A<'!?8V]N<W1S6R=D969A=6QT7V9O;&1E<E]N86UE)UT@.B`D
M<VAA<F4M/F=E="@G;F%M92<I*2`N("1D;VUA:6X["B`@("`@("`@+R]+;VQA
M8CHZ96YC;V1E26UA<$9O;&1E<DYA;64H)&1E9F%U;'0@/R`D87!P7V-O;G-T
M<ULG9&5F875L=%]F;VQD97)?;F%M92==(#H@)'-H87)E+3YG970H)VYA;64G
M*2D["B`@("`@("`@:68@*&ES7V$H)&9O;&1E<E]N86UE+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R7VYA;64["B`@("`@
M("`@?0H*("`@("`@("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P
M*"D["@H@("`@("`@("1O;&1?9F]L9&5R(#T@2V]L86(Z.F=E=%-H87)E36%P
M<&EN9R@D<VAA<F5?;6%P+"`D<VAA<F5?=6ED*3L*"B`@("`@("`@)')E<W5L
M="`]("1I;6%P+3YM86EL8F]X17AI<W0H)&9O;&1E<E]N86UE*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*"1F
M;VQD97)?;F%M92`A/2`D;VQD7V9O;&1E<BD@>PH@("`@("`@("`@("!I9B`H
M)')E<W5L="`F)B`D;VQD7V9O;&1E<BD@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@<F5N
M86UE("5S('1O("5S.B!D97-T:6YA=&EO;B!F;VQD97(@86QR96%D>2!E>&ES
M=',B*2P@)&9O;&1E<E]N86UE+"`D;VQD7V9O;&1E<BDI.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&]L9%]F;VQD97(I('L*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D:6UA<"T^<F5N86UE36%I;&)O>"@D;VQD7V9O
M;&1E<BP@)&9O;&1E<E]N86UE*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E:68@*"1R97-U;'0@/3T](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)&EM87`M/F-R96%T94UA:6QB;W@H)&9O;&1E<E]N
M86UE*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@1W)A;G0@=&AE($-Y<G5S($%D;6EN:7-T<F%T;W(@8W)E
M871E("8@9&5L971E(&%C8V5S<R`H;F5E9&5D"B`@("`@("`@+R\@9F]R('1H
M92!A9&UI;G5S97(@=&\@9&5L971E('1H92!M86EL8F]X('=H96X@<F5M;W9I
M;F<@<VAA<F5S*0H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^<V5T04-,*"1F
M;VQD97)?;F%M92P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R
M)UTL("=C9"<I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`D86-L(#T@2V]L86(Z.F%C;%1O07)R87DH)&EM87`M/F=E
M=$%#3"@D9F]L9&5R7VYA;64I*3L*("`@("`@("!I9B`H:7-?82@D86-L+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D86-L.PH@("`@
M("`@('T*"B`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N
M*"D["B`@("`@("`@)'!E<FU?;&ES="`]("1P97)M+3YG9715<V5R4&5R;6ES
M<VEO;G,H*3L*"B`@("`@("`@9F]R96%C:"`H)'!E<FU?;&ES="!A<R`D=7-E
M<B`]/B`D=7-E<E]P97)M<RD@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)&EM
M87`M/G-E=$%#3"@D9F]L9&5R7VYA;64L("1U<V5R+"!+;VQA8CHZ<&5R;7-4
M;T%C;"@D=7-E<E]P97)M<RP@)'5S97(@/3T@)&]W;F5R*2D["B`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!U;G-E="@D86-L6R1U<V5R72D["B`@("`@("`@?0H*("`@("`@
M("`O+R!-86ME('-U<F4@=V4@9&]N)W0@9&5L971E('1H92!C=7)R96YT('5S
M97(@;W(@=&AE($-Y<G5S"B`@("`@("`@+R\@061M:6YI<W1R871O<B!F<F]M
M('1H92!F;VQD97(G<R!!0TPL(&]R(&5L<V4@=V4G;&P@8F4@;&]C:V5D(&]U
M=`H@("`@("`@('5N<V5T*"1A8VQ;)&]W;F5R72D["B`@("`@("`@=6YS970H
M)&%C;%LD8V]N9ELG:V]L86(G75LG:6UA<"==6R=A9&UI;G5S97(G75TI.PH*
M("`@("`@("!F;W)E86-H("@D86-L(&%S("1U<V5R(#T^("1U<V5R7V%C;"D@
M>PH@("`@("`@("`@("`D<F5S=6QT(#T@)&EM87`M/F1E;&5T94%#3"@D9F]L
M9&5R7VYA;64L("1U<V5R*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R97-U
M;'0@/2`D:6UA<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]&3TQ$15)?
M5%E012P@87)R87DH)W9A;'5E+G-H87)E9"<@/3X@)&9O;&1E<E]T>7!E*2P@
M)&9O;&1E<E]N86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YS971!;FYO=&%T:6]N
M*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@87)R87DH)W9A;'5E+G-H87)E9"<@
M/3X@)'-H87)E7W5I9"DL("1F;VQD97)?;F%M92D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@($MO;&%B.CIU<&1A=&5-
M87!P9613:&%R92@D<VAA<F5?;6%P+"`D<VAA<F5?=6ED+"`D9F]L9&5R7VYA
M;64I.PH@("`@("`@($MO;&%B.CIS9713:&%R94UA<"@D<VAA<F5?;6%P*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@=7!D
M871E4VAA<F4H)B1S:&%R92D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y+"`D;F]T:69I8V%T:6]N.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y
M+3YG971!<'`H*3L*("`@("`@("!I9B`H87)R87E?<V5A<F-H*"1A<'`L(&%R
M<F%Y*"=M;F5M;R<L("=N86<G+"`G='5R8F$G+"`G:W)O;F]L:71H)RDI(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H96UP='DH)%]315-324].6TM/
M3$%"7TQ!4U1?4UE.0TA%1%]!4%!=*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A<'`@/2`D
M7U-%4U-)3TY;2T],04)?3$%35%]364Y#2$5$7T%04%T["B`@("`@("`@?0H*
M("`@("`@("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H)&%P
M<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]C;VYS=',L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)')E<W5L="`]($MO;&%B.CI?=7!D871E4VAA<F4H)'-H87)E+"`D
M87!P7V-O;G-T<RD["B`@("`@("`@)&ED(#T@)'-H87)E+3YG970H)VYA;64G
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")(
M;W)D92]+;VQA8CH@56YA8FQE('1O('-Y;F-H<F]N:7-E("5S(%PB)7-<(CH@
M)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1A<'!?8V]N<W1S6R=S:&%R95]N86UE)UTL("1I9"P@)')E<W5L="T^9V5T
M365S<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!?=7!D871E4VAA
M<F4H)B1S:&%R92P@)B1A<'!?8V]N<W1S*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D8V]N9CL*"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;
M)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I
M;6%P)UU;)W!O<G0G72D["@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G
M:6XH)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL("1C;VYF
M6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L<V4L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]($MO;&%B.CIS>6YC:')O;FES95-H87)E*"1I;6%P+"`D<VAA
M<F4L("1A<'!?8V]N<W1S*3L*"B`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H
M*3L*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I
M;VX@<F5M;W9E4VAA<F4H)B1S:&%R92D*("`@('L*("`@("`@("!G;&]B86P@
M)')E9VES=')Y+"`D;F]T:69I8V%T:6]N.PH*("`@("`@("`D87!P(#T@)')E
M9VES=')Y+3YG971!<'`H*3L*"B`@("`@("`@+R\@5V4@;VYL>2!R96UO=F4@
M<VAA<F5S(&EF($MO;&%B(&EN=&5G<F%T:6]N(&ES(&5N86)L960L(&%N9"!I
M9B!W92=V90H@("`@("`@("\O('!R979I;W5S;'D@<WEN8VAR;VYI<V5D('1H
M92!S:&%R97,@;&ES="`H:2YE+B!W92!K;F]W('=H870@24U!4`H@("`@("`@
M("\O(&9O;&1E<B!C;W)R97-P;VYD<R!T;R!T:&4@9VEV96X@<VAA<F4I+@H@
M("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=E
M;F%B;&5D)UTI('Q\"B`@("`@("`@("`@("@A96UP='DH)%]315-324].6TM/
M3$%"7TQ!4U1?4UE.0TA%1%]!4%!=*2`F)@H@("`@("`@("`@("`@)%]315-3
M24].6TM/3$%"7TQ!4U1?4UE.0TA%1%]!4%!=("$]("1A<'`I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1A<'!?
M8V]N<W1S(#T@2V]L86(Z.F=E=$%P<$-O;G-T<R@D87!P*3L*("`@("`@("!I
M9B`H:7-?82@D87!P7V-O;G-T<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@2V]L86(Z.E]R96UO=F53:&%R92@D<VAA<F4I.PH@("`@("`@("1I9"`]
M("1S:&%R92T^9V5T*"=N86UE)RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z(%5N86)L92!T;R!R96UO
M=F4@)7,@7"(E<UPB.B`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&%P<%]C;VYS='-;)W-H87)E7VYA;64G72P@)&ED
M+"`D<F5S=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!](&5L<V5I9B`H)')E<W5L="`]/3T@=')U92D@>PH@("`@("`@("`@
M("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B2&]R9&4O2V]L86(Z
M(%-U8V-E<W-F=6QL>2!R96UO=F5D("5S(%PB)7-<(B(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%P<%]C;VYS='-;)W-H
M87)E7VYA;64G72P@)&ED*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96UO=F53:&%R92@F)'-H87)E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N
M9CL*"B`@("`@("`@:68@*&5M<'1Y*"1S:&%R92DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!S:&%R92!O8FIE
M8W0B*2D["B`@("`@("`@?0H*("`@("`@("`D<VAA<F5?=6ED(#T@)'-H87)E
M+3YG971.86UE*"D["@H@("`@("`@("1S:&%R95]M87`@/2!+;VQA8CHZ9V5T
M4VAA<F5-87`H*3L*"B`@("`@("`@)&9O;&1E<B`]($MO;&%B.CIG9713:&%R
M94UA<'!I;F<H)'-H87)E7VUA<"P@)'-H87)E7W5I9"D["B`@("`@("`@:68@
M*&5M<'1Y*"1F;VQD97(I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;
M)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I
M;6%P)UU;)W!O<G0G72D["@H@("`@("`@("1R97-U;'0@/2`D:6UA<"T^;&]G
M:6XH)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M:6YU<V5R)UTL("1C;VYF
M6R=K;VQA8B==6R=I;6%P)UU;)V%D;6EN<'<G72P@9F%L<V4L(&9A;'-E*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)')E<W5L="`]("1I;6%P+3YD96QE=&5-86EL8F]X*"1F;VQD97(I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`D:6UA
M<"T^9&ES8V]N;F5C="@I.PH*("`@("`@("!+;VQA8CHZ<F5M;W9E36%P<&5D
M4VAA<F4H)'-H87)E7VUA<"P@)'-H87)E7W5I9"D["@H@("`@("`@($MO;&%B
M.CIS9713:&%R94UA<"@D<VAA<F5?;6%P*3L*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@9G5N8W1I;VX@<WEN8VAR;VYI<V53:&%R97,H)B1S
M:&%R97,L("1A<'`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)V5N86)L960G72D@?'P*("`@("`@("`@("`@
M87)R87E?<V5A<F-H*"1A<'`L(&%R<F%Y*"=M;F5M;R<L("=N86<G+"`G='5R
M8F$G+"`G:W)O;F]L:71H)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("`O+R!4=7)B82!D;V5S;B=T('5S
M92!S:&%R97,L('-O('=E(&IU<W0@8W)E871E(&$@9'5M;7D@<VAA<F4@;&ES
M="`F"B`@("`@("`@+R\@9&5F875L="!S:&%R92!H97)E('1O(&UA:V4@<W5R
M92!T:&4@9F]L;&]W:6YG(&-O9&4@=V]R:W,N"B`@("`@("`@:68@*&5M<'1Y
M*"1S:&%R97,I("8F("1A<'`@/3T@)W1U<F)A)RD@>PH@("`@("`@("`@("`D
M<VAA<F5S(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)&%P<"D["@H@("`@
M("`@("`@("`D87!P7V-O;G-T<R`]($MO;&%B.CIG971!<'!#;VYS=',H)&%P
M<"D["@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y
M+G!H<"<["B`@("`@("`@("`@("1I9&5N=&ET>2`]("9)9&5N=&ET>3HZ<VEN
M9VQE=&]N*"D["B`@("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG9716
M86QU92@G9G5L;&YA;64G*3L*("`@("`@("`@("`@:68@*'1R:6TH)&YA;64I
M(#T]("<G*2!["B`@("`@("`@("`@("`@("`D;F%M92`]($%U=&@Z.G)E;6]V
M94AO;VLH075T:#HZ9V5T075T:"@I*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<VAA<F4@/2`F)'-H87)E<RT^;F5W4VAA<F4H075T:#HZ9V5T075T
M:"@I*3L*("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"!S<')I;G1F
M*"1A<'!?8V]N<W1S6R=D969A=6QT7W-H87)E7VYA;64G72P@)&YA;64I*3L*
M("`@("`@("`@("`@)'-H87)E<RT^861D4VAA<F4H)'-H87)E*3L*("`@("`@
M("!]"@H@("`@("`@("\O($-H96-K(&EF('=E)W9E(&%L<F5A9'D@<WEN8VAR
M;VYI<V5D('1H92!)34%0(&9O;&1E<B!L:7-T.R!I9B!W92!H879E"B`@("`@
M("`@+R\@=&AE;B!E>&ET(&5A<FQY+B!&;VQD97(@<WEN8VAR;VYI<V%T:6]N
M(&ES(&1O;F4@;VX@87!P;&EC871I;VX*("`@("`@("`O+R!S=&%R='5P("T@
M=&AI<R!I;F-L=61E<R!S=VET8VAI;F<@8F5T=V5E;B!A<'!L:6-A=&EO;G,@
M87,@=V5L;"!A<PH@("`@("`@("\O('5P;VX@:6YI=&EA;"!L;V=I;BX*("`@
M("`@("!I9B`H(65M<'1Y*"1?4T534TE/3EM+3TQ!0E],05-47U-93D-(141?
M05!072D@)B8*("`@("`@("`@("`@)%]315-324].6TM/3$%"7TQ!4U1?4UE.
M0TA%1%]!4%!=(#T]("1A<'`I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@
M("`@('T*"B`@("`@("`@9VQO8F%L("1N;W1I9FEC871I;VX["@H@("`@("`@
M("1R97-U;'0@/2!+;VQA8CHZ7W-Y;F-H4VAA<F5S*"1S:&%R97,I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(DAO<F1E+TMO
M;&%B.B!5;F%B;&4@=&\@<WEN8VAR;VYI<V4@<VAA<F5S.B`E<R(I+"`D<F5S
M=6QT+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3>6YC:')O;FES97,@=&AE($E-05`@
M9F]L9&5R(&QI<W0@86YD('1H92!(;W)D92!S:&%R92!L:7-T+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@82!S=6-C97-S9G5L('-Y
M;F-H<F]N:7-A=&EO;BP@9F%L<V4@=VAE;B!A"B`@("`@*B`@("`@("`@("`@
M("`@("!S>6YC:')O;FES871I;VX@:7,@;F]T(')E<75I<F5D("AI+F4N(&UU
M;'1I<&QE('!A9V4@;&]A9',*("`@("`J("`@("`@("`@("`@("`@(&EN(&$@
M<VEN9VQE(&%P<&QI8V%T:6]N*2P@;W(@82!014%27T5R<F]R(&]B:F5C="!O
M;@H@("`@("H@("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-Y;F-H4VAA<F5S*"8D<VAA<F5S*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GDL("1C;VYF.PH*("`@("`@("`D87!P(#T@)')E
M9VES=')Y+3YG971!<'`H*3L*"B`@("`@("`@+R\@3W1H97)W:7-E('=E(&YE
M960@=&\@;6%P('1H92!C=7)R96YT($E-05`@9F]L9&5R(&QI<W0@=&\@=&AE
M"B`@("`@("`@+R\@87!P;&EC871I;VYS('-H87)E(&QI<W0N"@H@("`@("`@
M("\O($UA:V4@<W5R92!T:&ES(&ES(&)E:6YG(&-A;&QE9"!F<F]M(&$@:VYO
M=VX@87!P;&EC871I;VX*("`@("`@("`D87!P7V-O;G-T<R`]($MO;&%B.CIG
M971!<'!#;VYS=',H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]C;VYS
M=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?
M8V]N<W1S.PH@("`@("`@('T*"B`@("`@("`@+R\@0V]N;F5C="!T;R!T:&4@
M24U!4"!S97)V97(*("`@("`@("`D:6UA<"`](&YE=R!.971?24U!4"@D8V]N
M9ELG:V]L86(G75LG:6UA<"==6R=S97)V97(G72P@)&-O;F9;)VMO;&%B)UU;
M)VEM87`G75LG<&]R="==*3L*"B`@("`@("`@+R\@3&]G:6X@=7-I;F<@=&AE
M(&-U<G)E;G0@2&]R9&4@8W)E9&5N=&EA;',*("`@("`@("`D8W5R<F5N=%]U
M<V5R(#T@075T:#HZ9V5T075T:"@I.PH@("`@("`@("1N9'@@/2!S=')P;W,H
M)&-U<G)E;G1?=7-E<BP@)T`G*3L*("`@("`@("`D=7-E<B`]("1N9'@@/3T]
M(&9A;'-E(#\@)&-U<G)E;G1?=7-E<B`Z('-U8G-T<B@D8W5R<F5N=%]U<V5R
M+"`P+"`D;F1X*3L*("`@("`@("`D9&]M86EN(#T@<W1R<W1R*"1C=7)R96YT
M7W5S97(L("=`)RD["B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D
M8W5R<F5N=%]U<V5R+"!!=71H.CIG971#<F5D96YT:6%L*"=P87-S=V]R9"<I
M+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@?0H*("`@("`@("`O+R!/8G1A:6X@82!L:7-T(&]F(&%L;"!F;VQD
M97)S('1H92!C=7)R96YT('5S97(@:&%S(&%C8V5S<R!T;PH@("`@("`@("1F
M;VQD97)?;&ES="`]("1I;6%P+3YG971-86EL8F]X97,H*3L*("`@("`@("!I
M9B`H:7-?82@D9F]L9&5R7VQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1F;VQD97)?;&ES=#L*("`@("`@("!]"@H@("`@("`@
M("\O(%=E)W)E(&]N;'D@:6YT97)E<W1E9"!I;B!T:&4@9F]L9&5R<R!O9B!T
M:&4@<W!E8VEF:6,@<F5S;W5R8V4@='EP90H@("`@("`@("\O(&9O<B!T:&4@
M8W5R<F5N="!A<'!L:6-A=&EO;BP@<V\@9FEL=&5R(&]U="!T:&4@<F5S=`H@
M("`@("`@("1L;V-A;%]F;VQD97)S(#T@87)R87DH*3L*("`@("`@("`D<F5M
M;W1E7V9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1F;VQD
M97)?;&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@("`@("1A;FYO=&%T:6]N
M(#T@)&EM87`M/F=E=$%N;F]T871I;VXH2T],04)?04Y.3U1?1D],1$527U19
M4$4L("=V86QU92YS:&%R960G+"`D9F]L9&5R*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&%N;F]T871I;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D86YN;W1A=&EO;CL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@+R\@268@=&AE<F4@:7,@;F\@86YN;W1A=&EO;B!T:&5N('=E
M('1R96%T(&ET(&%S(&$@<W1A;F1A<F0@;6%I;`H@("`@("`@("`@("`O+R!F
M;VQD97(@*&DN92X@=V4@:6=N;W)E(&ET*2X*("`@("`@("`@("`@:68@*&5M
M<'1Y*"1A;FYO=&%T:6]N*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($EF('1H92!F;VQD97(@
M:7,@;V8@=&AE(&-O<G)E8W0@='EP92!T:&5N('=E(&%D9"!I="!T;R!O=7(@
M;&ES=`H@("`@("`@("`@("`O+R!O9B!F;VQD97)S('1H870@<VAO=6QD(&-O
M<G)E<W!O;F0@=&\@82!S:&%R92X@2&5R92!W92!G970@86YY"B`@("`@("`@
M("`@("\O(&]T:&5R(&%D9&ET:6]N86P@:6YF;W)M871I;VX@=V4@;6%Y(&YE
M960L('-U8V@@87,@=VAE=&AE<B!T:&4*("`@("`@("`@("`@+R\@9F]L9&5R
M('=A<R!P<F5V:6]U<VQY(&UA<'!E9"!T;R!A('-H87)E+"!I=',@04-,+"!I
M=',@;W=N97(@*&EF"B`@("`@("`@("`@("\O(&ET(&ES(&$@<VAA<F5D(&9O
M;&1E<BD@86YD(&ET<R!D:7-P;&%Y(&YA;64N"B`@("`@("`@("`@("1T>7!E
M(#T@97AP;&]D92@G+B<L("1A;FYO=&%T:6]N*3L*("`@("`@("`@("`@:68@
M*"1T>7!E6S!=(#T]("1A<'!?8V]N<W1S6R=M:6UE7W1Y<&5?<W5F9FEX)UTI
M('L*("`@("`@("`@("`@("`@("1A8VP@/2!+;VQA8CHZ86-L5&]!<G)A>2@D
M:6UA<"T^9V5T04-,*"1F;VQD97(I*3L*("`@("`@("`@("`@("`@(&EF("AI
M<U]A*"1A8VPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)&%C;#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`O+R!3:VEP('1H92!#>7)U<R!!9&UI;FES=')A=&]R"B`@("`@("`@
M("`@("`@("!U;G-E="@D86-L6R1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)V%D
M;6EN=7-E<B==72D["@H@("`@("`@("`@("`@("`@)'-H87)E7W5I9"`]("1I
M;6%P+3YG971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47U-(05)%7U5)1"P@)W9A
M;'5E+G-H87)E9"<L("1F;VQD97(I.PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)'-H87)E7W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<VAA<F5?=6ED.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@('!R96=?;6%T8V@H(CLH24Y"3UA\=7-E<B\H6UXO
M72LI*2\H6UY`72LI*$`N*BD_.R(L("1F;VQD97(L("1M871C:&5S*3L*"B`@
M("`@("`@("`@("`@("`D9&5F875L="`]("@A96UP='DH)'1Y<&5;,5TI("8F
M("1T>7!E6S%=(#T]("=D969A=6QT)RD["@H@("`@("`@("`@("`@("`@:68@
M*"1M871C:&5S6S%=(#T]("=)3D)/6"<I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&1E9F%U;'0I('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1I9&5N=&ET>2T^
M9V5T5F%L=64H)V9U;&QN86UE)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AT<FEM*"1N86UE*2`]/2`G)RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YA;64@/2!!=71H.CIR96UO=F5(;V]K*"1C=7)R96YT7W5S
M97(I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@<W!R:6YT9B@D87!P7V-O;G-T<ULG9&5F875L
M=%]S:&%R95]N86UE)UTL("1N86UE*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O;&1E<B`]("1A<'!?8V]N<W1S6R=D969A=6QT7V9O;&1E<E]N86UE
M)UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`D9F]L9&5R(#T@2V]L86(Z.F1E8V]D94EM
M87!&;VQD97).86UE*"1M871C:&5S6S-=*3L*("`@("`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@("`@("1F;VQD97(@/2`B=7-E<B\D=7-E
M<B\D9F]L9&5R)&1O;6%I;B(["@H@("`@("`@("`@("`@("`@("`@("1L;V-A
M;%]F;VQD97)S6R1F;VQD97)=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("=S:&%R95]U:60G("`@("`]/B`D<VAA<F5?=6ED+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G86-L)R`@("`@("`@("`@/3X@)&%C;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@("`@("`@(#T^("1N86UE
M+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@("`@("`@/3X@
M)&1E9F%U;'0L"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'5S97)?9&]M86EN
M(#T@:7-S970H)&UA=&-H97-;-%TI(#\@)&UA=&-H97-;-%T@.B`D9&]M86EN
M.PH@("`@("`@("`@("`@("`@("`@("1F;VQD97(@/2!I<W-E="@D;6%T8VAE
M<ULT72D@/R`D9F]L9&5R(#H@)&9O;&1E<B`N("1U<V5R7V1O;6%I;CL*("`@
M("`@("`@("`@("`@("`@("`D;W=N97(@/2`D;6%T8VAE<ULR72`N("1U<V5R
M7V1O;6%I;CL*("`@("`@("`@("`@("`@("`@("!I9B`H)&1E9F%U;'0I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])
M9&5N=&ET>2YP:'`G.PH@("`@("`@("`@("`@("`@("`@("`@("`D:61E;G1I
M='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1O=VYE<BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)&ED96YT:71Y+3YG9716
M86QU92@G9G5L;&YA;64G*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'1R:6TH)&YA;64I(#T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F%M92`]($%U=&@Z.G)E;6]V94AO;VLH)&]W;F5R*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92`]('-P<FEN=&8H)&%P<%]C;VYS='-;)V1E9F%U;'1?<VAA<F5?;F%M
M92==+"`D;F%M92D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!+;VQA8CHZ9&5C;V1E26UA
M<$9O;&1E<DYA;64H)&UA=&-H97-;,UTI.PH@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@)')E;6]T95]F;VQD97)S6R1F;VQD
M97)=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=S:&%R95]U
M:60G("`@("`]/B`D<VAA<F5?=6ED+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G86-L)R`@("`@("`@("`@/3X@)&%C;"P*("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G("`@("`@("`@(#T^("1N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G9&5F875L="<@("`@("`@/3X@)&1E9F%U;'0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("=O=VYE<B<@("`@("`@("`]/B`D;W=N97(L
M"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@5V4@;F]W(&UA<"!T
M:&4@<F5M86EN:6YG(&9O;&1E<B!L:7-T('1O('1H92!C=7)R96YT(&%P<&QI
M8V%T:6]N<PH@("`@("`@("\O('-H87)E(&QI<W0L('1O('-Y;F-H($AO<F1E
M('=I=&@@;W1H97(@2V]L86(@8VQI96YT<R!T:&%T(&UA>2!H879E"B`@("`@
M("`@+R\@<')E=FEO=7-L>2!M;V1I9FEE9"!T:&4@9W)O=7!W87)E(&9O;&1E
M<G,*"B`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`D:6UA
M<"`](&YE=R!.971?24U!4"@D8V]N9ELG:V]L86(G75LG:6UA<"==6R=S97)V
M97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG<&]R="==*3L*"B`@("`@
M("`@)')E<W5L="`]("1I;6%P+3YL;V=I;B@D8V]N9ELG:V]L86(G75LG:6UA
M<"==6R=A9&UI;G5S97(G72P@)&-O;F9;)VMO;&%B)UU;)VEM87`G75LG861M
M:6YP=R==+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("`O+R!43T1/.B!S964@:68@=&AE<F4@
M:7,@82!M;W)E(&%C8W5R871E('=A>2!O9B!L:7-T:6YG(&%L;"!S:&%R97,@
M=&AA=`H@("`@("`@("\O(&%R92!A8V-E<W-I8FQE+"!R96=A<F1L97-S(&]F
M('=H870@<&5R;6ES<VEO;G,@=&AE('5S97(@:&%S("AI+F4N(&EF"B`@("`@
M("`@+R\@=&AE('5S97(@:&%S(&%T(&QE87-T(&]N92!P97)M:7-S:6]N(&QE
M=F5L('1O('1H92!S:&%R92P@=&AE('-H87)E"B`@("`@("`@+R\@<VAO=6QD
M(&)E(&EN(&]N92!O9B!T:&5S92!L:7-T<RDN"B`@("`@("`@)&QO8V%L7W-H
M87)E<R`]("1S:&%R97,M/FQI<W13:&%R97,H)&-U<G)E;G1?=7-E<BP@4$52
M35-?4TA/5RP@)&-U<G)E;G1?=7-E<BD["B`@("`@("`@)&%L;%]S:&%R97,@
M/2`D<VAA<F5S+3YL:7-T4VAA<F5S*"1C=7)R96YT7W5S97(L(%!%4DU37U-(
M3U<I.PH@("`@("`@("1R96UO=&5?<VAA<F5S(#T@87)R87E?9&EF9E]A<W-O
M8R@D86QL7W-H87)E<RP@)&QO8V%L7W-H87)E<RD["B`@("`@("`@2V]L86(Z
M.G-E=%-H87)E36%P*&%R<F%Y*"DI.PH@("`@("`@("1S:&%R95]M87`@/2!A
M<G)A>2@I.PH*("`@("`@("`O+R!.;W<@<WEN8VAR;VYI<V4@=&AE(&9O;&1E
M<B!L:7-T('=I=&@@=&AE('-H87)E(&QI<W0*("`@("`@("!F;W)E86-H("@D
M;&]C86Q?9F]L9&5R<R!A<R`D9F]L9&5R(#T^("1A='1R<RD@>PH@("`@("`@
M("`@("!I9B`H96UP='DH)&%T=')S6R=S:&%R95]U:60G72DI('L*("`@("`@
M("`@("`@("`@("\O($YO('-H87)E(&-O<G)E<W!O;F1S('1O('1H:7,@9F]L
M9&5R+"!S;R!C<F5A=&4@;VYE"B`@("`@("`@("`@("`@("`D=6ED(#T@96UP
M='DH)&%T=')S6R=D969A=6QT)UTI(#\@;60U*&UI8W)O=&EM92@I*2`Z("1C
M=7)R96YT7W5S97(["B`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H87)E
M<RT^;F5W4VAA<F4H)'5I9"D["B`@("`@("`@("`@("`@("`D<VAA<F4M/G-E
M="@G;F%M92<L("1A='1R<ULG;F%M92==*3L*("`@("`@("`@("`@("`@("1S
M:&%R97,M/F%D9%-H87)E*"1S:&%R92D["@H@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1I;6%P+3YS971!;FYO=&%T:6]N*$M/3$%"7T%.3D]47U-(05)%
M7U5)1"P@87)R87DH)W9A;'5E+G-H87)E9"<@/3X@)'5I9"DL("1F;VQD97(I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@($MO;&%B.CIU<&1A
M=&5-87!P9613:&%R92@D<VAA<F5?;6%P+"`D=6ED+"`D9F]L9&5R*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($]T:&5R=VES
M92!T:&5R92!I<R!A('-H87)E(&-O<G)E<W!O;F1I;F<@=&\@=&AI<R!F;VQD
M97(*("`@("`@("`@("`@("`@(&EF("@A)'-H87)E<RT^97AI<W1S*"1A='1R
M<ULG<VAA<F5?=6ED)UTI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@268@
M:70G<R!N;W0@<')E<V5N="!F;W(@=VAA=&5V97(@<F5A<V]N+"!C<F5A=&4@
M:70*("`@("`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H87)E<RT^;F5W
M4VAA<F4H)&%T=')S6R=S:&%R95]U:60G72D["B`@("`@("`@("`@("`@("`@
M("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;)VYA;64G72D["B`@("`@
M("`@("`@("`@("`@("`@)'-H87)E<RT^861D4VAA<F4H)'-H87)E*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@
M3W1H97)W:7-E(&-H96-K('1H870@:70@:7,@;F%M960@8V]R<F5C=&QY"B`@
M("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1L;V-A;%]S:&%R97-;)&%T
M=')S6R=S:&%R95]U:60G75T["B`@("`@("`@("`@("`@("`@("`@:68@*"1S
M:&%R92T^9V5T*"=N86UE)RD@(3T@)&%T=')S6R=N86UE)UTI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-H87)E+3YS970H)VYA;64G+"`D871T<G-;
M)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@($MO;&%B.CIU<&1A=&5-87!P9613:&%R
M92@D<VAA<F5?;6%P+"`D871T<G-;)W-H87)E7W5I9"==+"`D9F]L9&5R*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-U<G)E;G1?=7-E<G,@/2`D
M<VAA<F4M/FQI<W15<V5R<R@I.PH*("`@("`@("`@("`@)'!E<FT@/2`F)'-H
M87)E+3YG971097)M:7-S:6]N*"D["B`@("`@("`@("`@("1M=7-T7W-A=F4@
M/2!F86QS93L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R<ULG86-L)UT@
M87,@)'5S97(@/3X@)&%C;"D@>PH@("`@("`@("`@("`@("`@)'!E<FUS(#T@
M2V]L86(Z.F%C;%1O4&5R;7,H)&%C;"D["B`@("`@("`@("`@("`@("!I9B`H
M)'!E<FUS("$]("1'3$]"04Q36R=P97)M<R==+3YG971097)M:7-S:6]N<R@D
M<&5R;2P@)'5S97(I*2!["B`@("`@("`@("`@("`@("`@("`@)'!E<FTM/F%D
M9%5S97)097)M:7-S:6]N*"1U<V5R+"`D<&5R;7,L(&9A;'-E*3L*("`@("`@
M("`@("`@("`@("`@("`D;75S=%]S879E(#T@=')U93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1N9'@@/2!A<G)A>5]S96%R8V@H)'5S
M97(L("1C=7)R96YT7W5S97)S*3L*("`@("`@("`@("`@("`@(&EF("@D;F1X
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1C=7)R
M96YT7W5S97)S6R1N9'A=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&-U<G)E;G1?=7-E<G,@87,@
M)'5S97(I('L*("`@("`@("`@("`@("`@(&EF("@D1TQ/0D%,4ULG<&5R;7,G
M72T^9V5T4&5R;6ES<VEO;G,H)'!E<FTL("1U<V5R*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I
M;VXH)'5S97(L(%!%4DU37T%,3"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M("`@("1M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&UU<W1?<V%V92D@>PH@("`@
M("`@("`@("`@("`@)'-H87)E+3YS971097)M:7-S:6]N*"1P97)M+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D<VAA<F4M/G-A=F4H*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D871T<G-;)W-H87)E7W5I
M9"==*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&QO8V%L7W-H87)E<ULD
M871T<G-;)W-H87)E7W5I9"==72D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@=6YS970H)&QO8V%L7W-H87)E<ULD8W5R<F5N=%]U<V5R72D[
M"@H@("`@("`@("\O(%5P9&%T92!S:&%R97,@=&AA="!A<F4@;F]T(&]W;F5D
M(&)Y('1H92!C=7)R96YT('5S97(@*&]N;'D@:68@=&AE<F4*("`@("`@("`O
M+R!A<F4@<VAA<F5D(&9O;&1E<G,@86-C97-S:6)L92!T;R!T:&4@8W5R<F5N
M="!U<V5R*0H@("`@("`@(&EF("@A96UP='DH)')E;6]T95]F;VQD97)S*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D<F5M;W1E7V9O;&1E<G,@87,@)&9O
M;&1E<B`]/B`D871T<G,I('L*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M871T<G-;)W-H87)E7W5I9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("1U
M:60@/2!E;7!T>2@D871T<G-;)V1E9F%U;'0G72D@/R!M9#4H;6EC<F]T:6UE
M*"DI(#H@)&%T=')S6R=O=VYE<B==.PH@("`@("`@("`@("`@("`@("`@("1S
M:&%R92`]("8D<VAA<F5S+3YN97=3:&%R92@D=6ED*3L*("`@("`@("`@("`@
M("`@("`@("`D<VAA<F4M/G-E="@G;W=N97(G+"`D871T<G-;)V]W;F5R)UTI
M.PH@("`@("`@("`@("`@("`@("`@("1S:&%R92T^<V5T*"=N86UE)RP@)&%T
M=')S6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@("1S:&%R97,M/F%D
M9%-H87)E*"1S:&%R92D["@H@("`@("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D:6UA<"T^<V5T06YN;W1A=&EO;BA+3TQ!0E]!3DY/5%]32$%215]5240L
M(&%R<F%Y*"=V86QU92YS:&%R960G(#T^("1U:60I+"`D9F]L9&5R*3L*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R95]M87`L("1U:60L("1F
M;VQD97(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(21S:&%R97,M/F5X:7-T<R@D871T<G-;)W-H87)E7W5I
M9"==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<VAA<F4@/2`F)'-H
M87)E<RT^;F5W4VAA<F4H)&%T=')S6R=S:&%R95]U:60G72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1S:&%R92T^<V5T*"=O=VYE<B<L("1A='1R<ULG
M;W=N97(G72D["B`@("`@("`@("`@("`@("`@("`@("`@("1S:&%R92T^<V5T
M*"=N86UE)RP@)&%T=')S6R=N86UE)UTI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<VAA<F5S+3YA9&13:&%R92@D<VAA<F4I.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(%1H
M92!S:&%R92!E>&ES=',@9VQO8F%L;'DL(&)U="!M87D@;F]T('EE="!B92!L
M:7-T960*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1R96UO
M=&5?<VAA<F5S6R1A='1R<ULG<VAA<F5?=6ED)UU=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-H87)E(#T@)B1S:&%R97,M/F=E=%-H87)E
M*"1A='1R<ULG<VAA<F5?=6ED)UTI.PH@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H87)E
M(#T@)B1R96UO=&5?<VAA<F5S6R1A='1R<ULG<VAA<F5?=6ED)UU=.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D<VAA<F4M/F=E="@G;F%M92<I("$]("1A='1R<ULG;F%M92==*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<VAA<F4M/G-E="@G;F%M
M92<L("1A='1R<ULG;F%M92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M2V]L86(Z.G5P9&%T94UA<'!E9%-H87)E*"1S:&%R95]M87`L("1A='1R<ULG
M<VAA<F5?=6ED)UTL("1F;VQD97(I.PH@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1C=7)R96YT7W5S97)S(#T@)'-H87)E+3YL:7-T57-E
M<G,H*3L*"B`@("`@("`@("`@("`@("`D<&5R;2`]("8D<VAA<F4M/F=E=%!E
M<FUI<W-I;VXH*3L*("`@("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!F86QS
M93L*"B`@("`@("`@("`@("`@("!F;W)E86-H("@D871T<G-;)V%C;"==(&%S
M("1U<V5R(#T^("1A8VPI('L*("`@("`@("`@("`@("`@("`@("`D<&5R;7,@
M/2!+;VQA8CHZ86-L5&]097)M<R@D86-L*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'!E<FUS("$]("1'3$]"04Q36R=P97)M<R==+3YG971097)M:7-S
M:6]N<R@D<&5R;2P@)'5S97(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P97)M+3YA9&15<V5R4&5R;6ES<VEO;B@D=7-E<BP@)'!E<FUS+"!F86QS
M92D["B`@("`@("`@("`@("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M;F1X(#T@87)R87E?<V5A<F-H*"1U<V5R+"`D8W5R<F5N=%]U<V5R<RD["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1N9'@@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1C=7)R96YT7W5S97)S6R1N9'A=
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&-U<G)E;G1?=7-E<G,@87,@)'5S
M97(I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)$=,3T)!3%-;)W!E<FUS
M)UTM/F=E=%!E<FUI<W-I;VYS*"1P97)M+"`D=7-E<BD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R
M;6ES<VEO;B@D=7-E<BP@4$5235-?04Q,+"!F86QS92D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1M=7-T7W-A=F4@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M9B`H)&UU<W1?<V%V92D@>PH@("`@("`@("`@("`@("`@("`@("1S:&%R92T^
M<V5T4&5R;6ES<VEO;B@D<&5R;2P@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M("`@("1S:&%R92T^<V%V92@I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&EF("@A96UP='DH)&%T=')S6R=S:&%R95]U:60G72DI('L*
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D<F5M;W1E7W-H87)E<ULD871T
M<G-;)W-H87)E7W5I9"==72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O($9I;F%L;'DL(')E;6]V92!A
M;GD@97AT<F$@<VAA<F5S('=E(&UA>2!H879E("AT:&5S92!W97)E(&]N8V4@
M9F]L9&5R<PH@("`@("`@("\O('1H870@=V5R92!S=6)S97%U96YT;'D@9&5L
M971E9"!B>2!A;F]T:&5R($MO;&%B(&-L:65N="DN(%1H:7,@:7,@;VYL>0H@
M("`@("`@("\O(&1O;F4@9F]R('-H87)E<R!T:&%T('1H92!C=7)R96YT('5S
M97(@;W=N<RP@:2YE+B!S:&%R97,@=&AA="!W97)E"B`@("`@("`@+R\@<W5B
M9F]L9&5R<R!O9B!T:&4@8W5R<F5N="!U<V5R<R<@24Y"3U@N"B`@("`@("`@
M9F]R96%C:"`H)&QO8V%L7W-H87)E<R!A<R`D<VAA<F4I('L*("`@("`@("`@
M("`@)')E<W5L="`]("1S:&%R97,M/G)E;6]V95-H87)E*"1S:&%R92D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!&;W(@<F5M;W1E('-H87)E<RP@=V4@
M<VEM<&QY(')E;6]V92!T:&4@8W5R<F5N="!U<V5R(&9R;VT@=&AE('-H87)E
M<PH@("`@("`@("\O('!E<FUI<W-I;VYS(&QI<W0N"B`@("`@("`@9F]R96%C
M:"`H)')E;6]T95]S:&%R97,@87,@)'5I9"`]/B`D<VAA<F4I('L*("`@("`@
M("`@("`@)'!E<FT@/2`F)'-H87)E+3YG971097)M:7-S:6]N*"D["B`@("`@
M("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R;6ES<VEO;B@D8W5R<F5N=%]U
M<V5R+"!015)-4U]!3$PL(&9A;'-E*3L*("`@("`@("`@("`@)'-H87)E+3YS
M971097)M:7-S:6]N*"1P97)M+"!F86QS92D["B`@("`@("`@("`@("1S:&%R
M92T^<V%V92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@06YD('=E)W)E(&1O
M;F4A($1I<V-O;FYE8W0@9G)O;2!)34%0+"!S970@=&AE(&QA<W0@<WEN8V@G
M960@87!P"B`@("`@("`@+R\@9FQA9R!T;R!T:&4@8W5R<F5N="!A<'!L:6-A
M=&EO;BP@86YD('5P9&%T92!T:&4@<VAA<F4@;6%P+@H@("`@("`@("1I;6%P
M+3YD:7-C;VYN96-T*"D["@H@("`@("`@("1?4T534TE/3EM+3TQ!0E],05-4
M7U-93D-(141?05!072`]("1A<'`["B`@("`@("`@2V]L86(Z.G-E=%-H87)E
M36%P*"1S:&%R95]M87`I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&=R;W5P=V%R92!T>7!E(&]F
M('1H92!G:79E;B!)34%0(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M;V)J96-T("1M86EL8F]X("!4:&4@;6%I;&)O>"!O9B!I;G1E<F5S="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!('-T<FEN9R!I;F1I8V%T:6YG
M('1H92!G<F]U<'=A<F4@='EP92!O9B`D;6%I;&)O>"!O<@H@("`@("H@("`@
M("`@("`@("`@("`@8F]O;&5A;B`B9F%L<V4B(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971-86EL8F]X5'EP92@D;6%I;&)O>"D*("`@('L*
M("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@("1T>7!E(#T@9F%L<V4[
M"@H@("`@("`@("\O($-O;FYE8W0@=&\@=&AE($E-05`@<V5R=F5R"B`@("`@
M("`@)&EM87`@/2!N97<@3F5T7TE-05`H)&-O;F9;)VMO;&%B)UU;)VEM87`G
M75LG<V5R=F5R)UTL("1C;VYF6R=K;VQA8B==6R=I;6%P)UU;)W!O<G0G72D[
M"@H@("`@("`@("\O($QO9VEN('5S:6YG('1H92!C=7)R96YT($AO<F1E(&-R
M961E;G1I86QS"B`@("`@("`@)')E<W5L="`]("1I;6%P+3YL;V=I;BA!=71H
M.CIG971!=71H*"DL($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RDL
M(&9A;'-E+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M56YA8FQE('1O(&%U=&AE;G1I8V%T92!W:71H('1H92!+;VQA8B!)34%0('-E
M<G9E<B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@)&EM87`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@<F5T
M=7)N("1T>7!E.PH@("`@("`@('T*"B`@("`@("`@+R\@3V)T86EN('1H92!G
M<F]U<'=A<F4@86YN;W1A=&EO;B!O9B`D;6%I;&)O>`H@("`@("`@("1A;FYO
M=&%T:6]N(#T@)&EM87`M/F=E=$%N;F]T871I;VXH2T],04)?04Y.3U1?1D],
M1$527U194$4L("=V86QU92YS:&%R960G+"`D;6%I;&)O>"D["B`@("`@("`@
M:68@*"%I<U]A*"1A;FYO=&%T:6]N+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T
M>2@D86YN;W1A=&EO;BDI('L*("`@("`@("`@("`@)'1Y<&4@/2!E>'!L;V1E
M*"<N)RP@)&%N;F]T871I;VXI.PH@("`@("`@("`@("!I9B`H*"%E;7!T>2@D
M='EP95LQ72D@)B8@)'1Y<&5;,5T@/3T@)V1E9F%U;'0G*2!\?"`H96UP='DH
M)'1Y<&5;,5TI*2D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP95LP
M73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&EM87`M/F1I
M<V-O;FYE8W0H*3L*"B`@("`@("`@<F5T=7)N("1T>7!E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&$@;&ES="!O9B!A;&P@24U!4"!F;VQD97)S
M("AI;F-L=61I;F<@=&AE:7(@9W)O=7!W87)E('1Y<&4I('1H870*("`@("`J
M('1H92!C=7)R96YT('5S97(@:&%S(&%C8V-E<W,@=&\N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@87)R87DH)&9O;&1E<FYA
M;64L("1F;VQD97)T>7!E*2!I=&5M<R`H96UP='D*("`@("`J("`@("`@("`@
M("`@("`@(&]N(&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O
M;&1E<G,H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@
M)&9O;&1E<G,@/2!A<G)A>2@I.PH*("`@("`@("`O+R!#;VYN96-T('1O('1H
M92!)34%0('-E<G9E<@H@("`@("`@("1I;6%P(#T@;F5W($YE=%])34%0*"1C
M;VYF6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==+"`D8V]N9ELG:V]L86(G
M75LG:6UA<"==6R=P;W)T)UTI.PH*("`@("`@("`O+R!,;V=I;B!U<VEN9R!T
M:&4@8W5R<F5N="!(;W)D92!C<F5D96YT:6%L<PH@("`@("`@("1R97-U;'0@
M/2`D:6UA<"T^;&]G:6XH075T:#HZ9V5T075T:"@I+"!!=71H.CIG971#<F5D
M96YT:6%L*"=P87-S=V]R9"<I+"!F86QS92P@9F%L<V4I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)U5N86)L92!T;R!A=71H96YT:6-A=&4@=VET
M:"!T:&4@2V]L86(@24U!4"!S97)V97(G+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@("1I;6%P+3YD:7-C;VYN96-T
M*"D["B`@("`@("`@("`@(')E='5R;B`D9F]L9&5R<SL*("`@("`@("!]"@H@
M("`@("`@("\O($]B=&%I;B!A(&QI<W0@;V8@86QL(&9O;&1E<G,@=&AE(&-U
M<G)E;G0@=7-E<B!H87,@86-C97-S('1O"B`@("`@("`@)&9O;&1E<E]L:7-T
M(#T@)&EM87`M/F=E=$UA:6QB;WAE<R@I.PH@("`@("`@(&EF("AI<U]A*"1F
M;VQD97)?;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G56YA8FQE('1O(&]B=&%I;B!)34%0(&9O;&1E<B!L
M:7-T)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@
M("`@("`@("`D:6UA<"T^9&ES8V]N;F5C="@I.PH@("`@("`@("`@("!R971U
M<FX@)&9O;&1E<G,["B`@("`@("`@?0H*("`@("`@("`O+R!)=&5R871E(&]V
M97(@86QL('1H92!F;VQD97)S(&]B=&%I;FEN9R!T:&5I<B!G<F]U<'=A<F4@
M='EP97,*("`@("`@("!F;W)E86-H("@D9F]L9&5R7VQI<W0@87,@)&9O;&1E
M<BD@>PH@("`@("`@("`@("`D9F]L9&5R='EP92`]("=M86EL)SL*"B`@("`@
M("`@("`@("1A;FYO=&%T:6]N(#T@)&EM87`M/F=E=$%N;F]T871I;VXH2T],
M04)?04Y.3U1?1D],1$527U194$4L("=V86QU92YS:&%R960G+"`D9F]L9&5R
M*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1A;FYO=&%T:6]N+"`G4$5!4E]%
M<G)O<B<I("8F("%E;7!T>2@D86YN;W1A=&EO;BDI('L*("`@("`@("`@("`@
M("`@("1T>7!E(#T@97AP;&]D92@G+B<L("1A;FYO=&%T:6]N*3L*("`@("`@
M("`@("`@("`@(&EF("@H(65M<'1Y*"1T>7!E6S%=*2`F)B`D='EP95LQ72`]
M/2`G9&5F875L="<I('Q\("AE;7!T>2@D='EP95LQ72DI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&9O;&1E<G1Y<&4@/2`D='EP95LP73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9O;&1E<G-;
M72`](&%R<F%Y*"1F;VQD97(L("1F;VQD97)T>7!E*3L*("`@("`@("!]"@H@
M("`@("`@("1I;6%P+3YD:7-C;VYN96-T*"D["@H@("`@("`@(')E='5R;B`D
M9F]L9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1R:6=G97)S('1H92!F
M<F5E8G5S>2!U<&1A=&4@9F]R('1H92!G:79E;B!S:&%R92!U:60N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@=7!D871E('=A<R!S
M=6-C97-S9G5L;"P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T<FEG9V5R1G)E94)U<WE5<&1A=&4H)'-H87)E7W5I9"D*("`@('L*
M("`@("`@("`D<VAA<F5?;6%P(#T@2V]L86(Z.F=E=%-H87)E36%P*"D["B`@
M("`@("`@:68@*&5M<'1Y*"1S:&%R95]M87!;)'-H87)E7W5I9%TI*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1F
M;VQD97)?<&%T:"`]("1S:&%R95]M87!;)'-H87)E7W5I9%T["@H@("`@("`@
M("\O($E-05`@<&%T:"!I<R!E:71H97(@+TE.0D]8+SQP871H/D!D;VUA:6X@
M;W(@+W5S97(O<V]M96]N92\\<&%T:#Y`9&]M86EN"B`@("`@("`@+R\@<W1R
M:7`@9&]M86EN"B`@("`@("`@)&5N9"`]('-T<G)P;W,H)&9O;&1E<E]P871H
M+"`G0"<I.PH@("`@("`@("1F;VQD97(@/2!S=6)S='(H)&9O;&1E<E]P871H
M+"`P+"`D96YD*3L*"B`@("`@("`@:68@*"$D9F]L9&5R6S!=(#T]("<O)RD@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M("1S96-O;F1?<VQA<V@@/2!S=')P;W,H)&9O;&1E<BP@)R\G+"`Q*3L*("`@
M("`@("!I9B`H)'-E8V]N9%]S;&%S:"`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<FYC
M;7`H)&9O;&1E<BP@)R])3D)/6"\G+"`W*2`]/2`P*2!["B`@("`@("`@("`@
M("1F;VQD97(@/2!!=71H.CIG971!=71H*"DN<W5B<W1R*"1F;VQD97(L("1S
M96-O;F1?<VQA<V@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M;VQD97(@/2!S=6)S='(H)&9O;&1E<BP@)'-E8V]N9%]S;&%S:"`K(#$I.PH@
M("`@("`@('T*("`@("`@("`D=7)L(#T@)VAT='!S.B\O)R`N("1'3$]"04Q3
M6R=C;VYF)UU;)VMO;&%B)UU;)VEM87`G75LG<V5R=F5R)UT@+B`G+V9R965B
M=7-Y+W1R:6=G97(O)R`N("1F;VQD97(@+B`G+G!F8B<["@H@("`@("`@("\O
M(&YO=R!S=&%R="!T:&4@<F5Q=65S=`H@("`@("`@(')E<75I<F5?;VYC92`G
M2%144"]297%U97-T+G!H<"<["B`@("`@("`@)&AT='`@/2!N97<@2%144%]2
M97%U97-T*"1U<FPL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=M971H;V0G(#T^("='150G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=&EM96]U="<@/3X@-2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%L;&]W4F5D:7)E8W1S
M)R`]/B!T<G5E*2D["B`@("`@("`@)&AT='`M/G-E=$)A<VEC075T:"A!=71H
M.CIG971!=71H*"DL($%U=&@Z.F=E=$-R961E;G1I86PH)W!A<W-W;W)D)RDI
M.PH*("`@("`@("!`)&AT='`M/G-E;F1297%U97-T*"D["B`@("`@("`@:68@
M*"1H='1P+3YG971297-P;VYS94-O9&4H*2`A/2`R,#`I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@
M=&\@=')I9V=E<B!F<F5E+V)U<WD@=7!D871E(&9O<B`E<R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96UA:6PI*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]$871A5')E92YP:'``````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#$T,S4T,"`Q,#4Q-30S-#$T,"`P,C$U-3``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!,:7-T(&5V97)Y(&]B:F5C="!I;B!A;B!A<G)A>2P@<VEM:6QA<B!T;R!0
M14%2+VAT;6PO;65N=2YP:'`N"B`J+PID969I;F4H)T1!5$%44D5%7T9/4DU!
M5%]44D5%)RP@,2D["@HO*BH*("H@1V5T(&$@9G5L;"!L:7-T("T@86X@87)R
M87D@;V8@:V5Y<RX*("HO"F1E9FEN92@G1$%40512145?1D]234%47T9,050G
M+"`R*3L*"B\J*@H@*B!4:&4@<F]O="!E;&5M96YT("AT;W`M;&5V96P@<&%R
M96YT*2!O9B!E86-H($1A=&%4<F5E(&=R;W5P+@H@*B\*9&5F:6YE*"=$051!
M5%)%15]23T]4)RP@+3$I.PH*+RHJ"B`J($)U:6QD(&$@;F]R;6%L('-E;&5C
M="!Q=65R>2X*("HO"F1E9FEN92@G1$%40512145?0E5)3$1?4T5,14-4)RP@
M,"D["@HO*BH*("H@0G5I;&0@82!C;W5N="!O;FQY('%U97)Y+@H@*B\*9&5F
M:6YE*"=$051!5%)%15]"54E,1%]#3U5.5"<L(#$I.PH*+RHJ"B`J(%1H92!$
M871A5')E93HZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R86-T960@
M:6YT97)F86-E(&EN=&\@=&AE"B`J('9A<FEO=7,@8F%C:V5N9',@9F]R('1H
M92!(;W)D92!$871A5')E92!S>7-T96TN"B`J"B`J($$@<&EE8V4@;V8@9&%T
M82!I<R!J=7-T(&$@=&ET;&4@=&AA="!I<R!S879E9"!I;B!T:&4@<&%G92!F
M;W(@=&AE(&YU;&P*("H@9')I=F5R(&]R(&-A;B!B92!S879E9"!I;B!A(&1A
M=&%B87-E('1O(&)E(&%C8V5S<V5D(&9R;VT@979E<GEW:&5R92X@179E<GD*
M("H@<W1O<F5D(&]B:F5C="!M=7-T(&AA=F4@82!D:69F97)E;G0@;F%M92`H
M:6YS:61E(&5A8V@@9W)O=7!I9"DN"B`J"B`J(%)E<75I<F5D('9A;'5E<R!F
M;W(@)'!A<F%M<SH\<')E/@H@*B`@("=G<F]U<"<@+2T@1&5F:6YE(&5A8V@@
M9W)O=7`@;V8@;V)J96-T<R!W92!W86YT('1O(&)U:6QD+CPO<')E/@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]$871A5')E92]$871A5')E92YP:'`L=B`Q
M+C$U,2XR+C$X(#(P,#8O,#<O,3,@,#@Z-3@Z-#0@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#,@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R
M0&)I9V9O;W0N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M
M/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7T1A
M=&%4<F5E"B`J+PIC;&%S<R!$871A5')E92!["@H@("`@+RHJ"B`@("`@*B!!
M<G)A>2!O9B!A;&P@9&%T83H@:6YD97AE9"!B>2!I9"X@5&AE(&9O<FUA="!I
M<SH@87)R87DH:60@/3X*("`@("`J("=N86UE)R`]/B!N86UE+"`G<&%R96YT
M)R`]/B!P87)E;G0I+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?9&%T82`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!
M(&AA<V@@=&AA="!C86X@8F4@=7-E9"!T;R!M87`@82!F=6QL(&]B:F5C="!N
M86UE"B`@("`@*B`H<&%R96YT.F-H:6QD.F]B:F5C="D@=&\@=&AA="!O8FIE
M8W0G<R!U;FEQ=64@240N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]N86UE36%P(#T@87)R87DH*3L*"B`@("`@+RHJ"B`@
M("`@*B!!8W1U86P@871T<FEB=71E('-O<G1I;F<@:&%S:"X*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W-O<G1(87-H(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I
M9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN
M96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(%=E(&%L=V%Y<R!N965D("=G<F]U
M<"<L(&$@<W1R:6YG('1H870@9&5F:6YE<R!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!P<F5F:7@@9F]R(&5A8V@@<V5T(&]F(&AI97)A<F-H
M:6-A;"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E92@D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P
M87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<&%R86UE
M=&5R(&]F('1H:7,@1&%T851R964@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&%R86T@(%1H92!P87)A;65T97(@=&\@<F5T=7)N
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!P87)A;65T97(G
M<R!V86QU92!O<B!N=6QL(&EF(&ET(&1O97-N)W0@97AI<W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*("`@('L*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/E]P87)A;7-;)'!A<F%M72D@/R`D=&AI<RT^
M7W!A<F%M<ULD<&%R86U=(#H@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V97,@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&]B:F5C="`@5&AE(&]B:F5C="!T;R!R96UO=F4N"B`@("`@*B!`<&%R
M86T@)&9O<F-E("`@("`@("`@($9O<F-E(')E;6]V86P@;V8@979E<GD@8VAI
M;&0@;V)J96-T/PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F4H)&]B:F5C
M="P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&]B
M:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@)&]B:F5C
M="`]("1O8FIE8W0M/F=E=$YA;64H*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A)'1H:7,M/F5X:7-T<R@D;V)J96-T*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D;V)J96-T("X@)R!D;V5S(&YO="!E>&ES
M="<I.PH@("`@("`@('T*"B`@("`@("`@)&-H:6QD<F5N(#T@)'1H:7,M/F=E
M=$YU;6)E<D]F0VAI;&1R96XH)&]B:F5C="D["B`@("`@("`@:68@*"1C:&EL
M9')E;BD@>PH@("`@("`@("`@("`O*B!43T1/.B!R96UO=F4@8VAI;&1R96X@
M:68@)&9O<F-E(#T]('1R=64@*B\*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86YN;W0@<F5M;W9E+"`E9"!C:&EL
M9')E;B!E>&ES="XB*2P@8V]U;G0H)&-H:6QD<F5N*2DI.PH@("`@("`@('T*
M"B`@("`@("`@)&ED(#T@)'1H:7,M/F=E=$ED*"1O8FIE8W0I.PH@("`@("`@
M("1P:60@/2`D=&AI<RT^9V5T4&%R96YT*"1O8FIE8W0I.PH@("`@("`@("1O
M<F1E<B`]("1T:&ES+3Y?9&%T85LD:61=6R=O<F1E<B==.PH@("`@("`@('5N
M<V5T*"1T:&ES+3Y?9&%T85LD:61=*3L*("`@("`@("!U;G-E="@D=&AI<RT^
M7VYA;65-87!;)&ED72D["@H@("`@("`@("\O(%-H:69T(&1O=VX@=&AE(&]R
M9&5R('!O<VET:6]N<RX*("`@("`@("`D=&AI<RT^7W)E;W)D97(H)'!I9"P@
M)&]R9&5R*3L*"B`@("`@("`@<F5T=7)N("1I9#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V97,@86QL($1A=&%4<F5E(&]B:F5C=',@;W=N960@8GD@
M82!C97)T86EN('5S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=7-E<B`@02!U<V5R(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M955S97)$871A*"1U<V5R*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=N;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-;W9E(&%N(&]B:F5C="!T;R!A(&YE=R!P87)E;G0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1O8FIE8W0@("`@("!4:&4@;V)J96-T('1O
M(&UO=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P87)E;G0@(%1H92!N
M97<@<&%R96YT(&]B:F5C="X@1&5F875L=',@=&\@=&AE(')O;W0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&UO=F4H)&]B:F5C="P@)&YE=W!A<F5N="`](&YU
M;&PI"B`@("!["B`@("`@("`@)&-I9"`]("1T:&ES+3YG971)9"@D;V)J96-T
M*3L*("`@("`@("!I9B`H:7-?82@D8VED+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H)T]B
M:F5C="!T;R!M;W9E(&1O97,@;F]T(&5X:7-T.B`E<R<L("1C:60M/F=E=$UE
M<W-A9V4H*2DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1N
M97=P87)E;G0I*2!["B`@("`@("`@("`@("1P:60@/2`D=&AI<RT^9V5T260H
M)&YE=W!A<F5N="D["B`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*'-P<FEN=&8H)TYE=R!P87)E;G0@9&]E<R!N;W0@97AI<W0Z("5S
M)RP@)'!I9"T^9V5T365S<V%G92@I*2D["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<&ED(#T@1$%40512145?4D]/5#L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9&%T85LD8VED75LG<&%R96YT
M)UT@/2`D<&ED.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H86YG92!A;B!O8FIE8W0G<R!N86UE+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`@)&]L9%]O8FIE8W0@("`@("`@5&AE(&]L9"!O
M8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?;V)J96-T7VYA;64@
M(%1H92!N97<@;V)J96-T(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E
M;F%M92@D;VQD7V]B:F5C="P@)&YE=U]O8FIE8W1?;F%M92D*("`@('L*("`@
M("`@("`O*B!#:&5C:R!W:&5T:&5R('1H92!O8FIE8W0@97AI<W1S(&%T(&%L
M;"`J+PH@("`@("`@(&EF("@A)'1H:7,M/F5X:7-T<R@D;VQD7V]B:F5C="DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&]L9%]O
M8FIE8W0@+B`G(&1O97,@;F]T(&5X:7-T)RD["B`@("`@("`@?0H*("`@("`@
M("`O*B!#:&5C:R!F;W(@9'5P;&EC871E<R`M(&=E="!P87)E;G0@86YD(&-R
M96%T92!N97<@;V)J96-T"B`@("`@("`@("H@;F%M92`J+PH@("`@("`@("1P
M87)E;G0@/2`D=&AI<RT^9V5T3F%M92@D=&AI<RT^9V5T4&%R96YT*"1O;&1?
M;V)J96-T*2D["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)'!A<F5N="`N
M("<Z)R`N("1N97=?;V)J96-T7VYA;64I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=$=7!L:6-A=&4@;F%M92`G("X@)&YE=U]O
M8FIE8W1?;F%M92D["B`@("`@("`@?0H*("`@("`@("`O*B!297!L86-E('1H
M92!O;&0@;F%M92!W:71H('1H92!N97<@;VYE(&EN('1H92!C86-H92`J+PH@
M("`@("`@("1O;&1?;V)J96-T7VED(#T@)'1H:7,M/F=E=$ED*"1O;&1?;V)J
M96-T*3L*("`@("`@("`D=&AI<RT^7V1A=&%;)&]L9%]O8FIE8W1?:61=6R=N
M86UE)UT@/2`D;F5W7V]B:F5C=%]N86UE.PH*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG97,@=&AE(&]R9&5R(&]F
M('1H92!C:&EL9')E;B!O9B!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9G5L;"!I9"!P871H(&]F('1H92!P
M87)E;G0@;V)J96-T+@H@("`@("H@0'!A<F%M(&UI>&5D("1O<F1E<B`@("!)
M9B!A;B!A<G)A>2!I="!S<&5C:69I97,@=&AE(&YE=R!P;W-I=&EO;G,@9F]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&%L;"!C:&EL9"!O8FIE
M8W1S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!)9B!A;B!I;G1E
M9V5R(&%N9"`D8VED(&ES('-P96-I9FEE9"P@=&AE('!O<VET:6]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@('=H97)E('1H92!C:&EL9"!S<&5C
M:69I960@8GD@)&-I9"!I<R!I;G-E<G1E9"X@268*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@)&-I9"!I<R!N;W0@<W!E8VEF:65D+"!T:&4@<&]S
M:71I;VX@9V5T<R!D96QE=&5D+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!C875S:6YG('1H92!F;VQL;W=I;F<@<&]S:71I;VYS('1O('-H:69T
M('5P+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@("!3964@)&]R9&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96]R9&5R*"1P87)E;G1S+"`D;W)D
M97(@/2!N=6QL+"`D8VED(#T@;G5L;"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VAA;F=E(&]R9&5R(&]F(&-H:6QD<F5N(&]F(&%N(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P:60@("`@(%1H
M92!P87)E;G0@;V)J96-T(&ED('-T<FEN9R!P871H+@H@("`@("H@0'!A<F%M
M(&UI>&5D("1O<F1E<B`@("!3<&5C:69I8R!N97<@;W)D97(@<&]S:71I;VX@
M;W(@86X@87)R87D@8V]N=&%I;FEN9PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@;F5W('!O<VET:6]N<R!F;W(@=&AE(&=I=F5N('!A<F5N
M="X*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@("`@268@<')O=FED960@
M:6YD:6-A=&5S(&EN<V5R=&EO;B!O9B!A(&YE=R!C:&EL9"!T;PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@<&%R96YT('1O(&%V;VED(&EN
M8W)E;65N=&EN9R!I="!W:&5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@('-H:69T:6YG('5P(&%L;"!O=&AE<B!C:&EL9')E;B=S(&]R9&5R+B!)
M9B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<')O=FED960@
M:6YD:6-A=&5S(&1E;&5T:6]N+"!S;R!S:&EF="!A;&P@;W1H97(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@<&]S:71I;VYS(&1O=VX@;VYE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<F5O<F1E<B@D<&ED+"`D;W)D97(@/2!N
M=6QL+"`D8VED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1O<F1E<BD@)B8@(6ES7VYU;&PH)&]R9&5R*2D@>PH@("`@("`@("`@("`O
M+R!3:6YG;&4@=7!D871E("AA9&0O9&5L*2X*("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)&-I9"DI('L*("`@("`@("`@("`@("`@("\O($YO(&ED(&=I=F5N
M('-O('-H=69F;&4@9&]W;BX*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?9&%T82!A<R`D8U]K97D@/3X@)&-?=F%L*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?9&%T85LD8U]K97E=6R=P87)E;G0G72`]
M/2`D<&ED"B`@("`@("`@("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?9&%T
M85LD8U]K97E=6R=O<F1E<B==(#X@)&]R9&5R*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&%T85LD8U]K97E=6R=O<F1E<B==+2T["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@5V4@:&%V92!A;B!I
M9"!S;R!S:'5F9FQE('5P+@H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]D871A(&%S("1C7VME>2`]/B`D8U]V86PI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&-?:V5Y("$]("1C:60@("8F("1T:&ES+3Y?9&%T85LD
M8U]K97E=6R=P87)E;G0G72`]/2`D<&ED"B`@("`@("`@("`@("`@("`@("`@
M("`@("8F("1T:&ES+3Y?9&%T85LD8U]K97E=6R=O<F1E<B==(#X]("1O<F1E
M<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&-?
M:V5Y75LG;W)D97(G72LK.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("AI
M<U]A<G)A>2@D;W)D97(I("8F(&-O=6YT*"1O<F1E<BDI('L*("`@("`@("`@
M("`@+R\@375L=&D@=7!D871E+@H@("`@("`@("`@("!F;W)E86-H("@D;W)D
M97(@87,@)&]R9&5R7W!O<VET:6]N(#T^("1C:60I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&%T85LD8VED75LG;W)D97(G72`]("1O<F1E<E]P;W-I
M=&EO;CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($5X<&QI8VET;'D@<V5T('1H92!O<F1E<B!F;W(@82!D871A=')E
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("!4:&4@9&%T871R964@;V)J96-T
M(&ED('1O(&-H86YG92X*("`@("`J($!P87)A;2!I;G1E9V5R("1O<F1E<B`@
M5&AE(&YE=R!O<F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W)D97(H
M)&ED+"`D;W)D97(I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1Y;F%M:6-A;&QY(&1E=&5R;6EN97,@=&AE(&]B:F5C="!C;&%S<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1H92!S970@
M;V8@871T<FEB=71E<R!T:&%T(&-O;G1A:6X@=&AE(&-L87-S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EN9F]R;6%T:6]N+B!$969A=6QT
M<R!T;R!$871A5')E94]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E
M9FEN94]B:F5C=$-L87-S*"1A='1R:6)U=&5S*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1C;&%S<R`]("=$871A5')E94]B
M:F5C="<["B`@("`@("`@:68@*"%I<U]A<G)A>2@D871T<FEB=71E<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1C;&%S<SL*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@
M(&EF("@D871T<ELG;F%M92==(#T]("=$871A5')E92<I('L*("`@("`@("`@
M("`@("`@(&EF("@D871T<ELG:V5Y)UT@/3T@)V]B:F5C=$-L87-S)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("1A='1R6R=V86QU92==.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1A='1R6R=K97DG72`]/2`G;V)J96-T5'EP92<I('L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@97AP;&]D92@G+R<L("1A='1R6R=V
M86QU92==*3L*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`D<F5G:7-T
M<GDM/F-A;&Q">5!A8VMA9V4H)')E<W5L=%LP72P@)V1E9FEN94-L87-S)RP@
M87)R87DH)W1Y<&4G(#T^("1R97-U;'1;,5TI*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;&%S<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!$871A5')E94]B:F5C="`H;W(@<W5B8VQA
M<W,I(&]B:F5C="!O9B!T:&4@9&%T82!I;B!T:&4*("`@("`J(&]B:F5C="!D
M969I;F5D(&)Y("1O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;V)J96-T("!4:&4@;V)J96-T('1O(&9E=&-H.B`G<&%R96YT.G-U8BUP
M87)E;G0Z;F%M92<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<R`@(%-U
M8F-L87-S(&]F($1A=&%4<F5E3V)J96-T('1O('5S92X@1&5F875L=',@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE8W0N
M($YU;&P@9F]R8V5S('1H92!D<FEV97(@=&\@;&]O:PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!I;G1O('1H92!A='1R:6)U=&5S('1A8FQE('1O
M(&1E=&5R;6EN92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M<W5B8VQA<W,@=&\@=7-E+B!)9B!N;VYE(&ES(&9O=6YD(&ET('5S97,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@1&%T851R965/8FIE8W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9G971/8FIE8W0H)&]B:F5C="P@)&-L87-S
M(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*("`@("`@("!I9B`H96UP='DH
M)&]B:F5C="DI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@G3F\@;V)J96-T(')E<75E<W1E9"XG*3L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&]A9"@D
M;V)J96-T*3L*("`@("`@("!I9B`H(21T:&ES+3YE>&ES=',H)&]B:F5C="DI
M('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@D;V)J
M96-T("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H*("`@("`@("`D=7-E7V%T=')I8G5T97,@/2!I<U]N
M=6QL*"1C;&%S<RD@?'P@:7-?8V%L;&%B;&4H87)R87DH)&-L87-S+"`G7V9R
M;VU!='1R:6)U=&5S)RDI.PH@("`@("`@(&EF("@D=7-E7V%T=')I8G5T97,I
M('L*("`@("`@("`@("`@)&%T=')I8G5T97,@/2`D=&AI<RT^9V5T071T<FEB
M=71E<R@D=&AI<RT^9V5T260H)&]B:F5C="DI.PH@("`@("`@("`@("!I9B`H
M:7-?82@D871T<FEB=71E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H:7-?;G5L;"@D8VQA<W,I*2!["B`@("`@("`@("`@("`@
M("`D8VQA<W,@/2`D=&AI<RT^7V1E9FEN94]B:F5C=$-L87-S*"1A='1R:6)U
M=&5S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!0
M14%2.CIR86ES945R<F]R*"1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@
M("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)&1A
M=&%/8B`]("9N97<@)&-L87-S*"1O8FIE8W0I.PH@("`@("`@("1D871A3V(M
M/G-E=$1A=&%4<F5E*"1T:&ES*3L*("`@("`@("`O*B!)9B!T:&4@8VQA<W,@
M:&%S(&$@7V9R;VU!='1R:6)U=&5S(&UE=&AO9"P@;&]A9"!D871A(&9R;VT*
M("`@("`@("`@*B!T:&4@871T<FEB=71E<R!B86-K96YD+B`J+PH@("`@("`@
M(&EF("@D=7-E7V%T=')I8G5T97,I('L*("`@("`@("`@("`@)&1A=&%/8BT^
M7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!/=&AE<G=I<V4@;&]A9"!I="!F<F]M('1H92!O
M;&0@9&%T82!S=&]R86=E(&9I96QD+B`J+PH@("`@("`@("`@("`D9&%T84]B
M+3YS971$871A*"1T:&ES+3YG971$871A*"1T:&ES+3YG971)9"@D;V)J96-T
M*2DI.PH@("`@("`@('T*"B`@("`@("`@)&1A=&%/8BT^<V5T3W)D97(H)'1H
M:7,M/F=E=$]R9&5R*"1O8FIE8W0I*3L*("`@("`@("!R971U<FX@)&1A=&%/
M8CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!$871A5')E94]B
M:F5C="`H;W(@<W5B8VQA<W,I(&]B:F5C="!O9B!T:&4@9&%T82!I;B!T:&4*
M("`@("`J(&]B:F5C="!W:71H('1H92!)1"`D:60N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&ED("`@($%N(&]B:F5C="!I9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-L87-S("!3=6)C;&%S<R!O9B!$871A5')E94]B:F5C
M="!T;R!U<V4N($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@1&%T851R965/8FIE8W0N($YU;&P@9F]R8V5S('1H92!D<FEV97(@
M=&\@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN=&\@=&AE
M(&%T=')I8G5T97,@=&%B;&4@=&\@9&5T97)M:6YE('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@('-U8F-L87-S('1O('5S92X@268@;F]N92!I
M<R!F;W5N9"!I="!U<V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M1&%T851R965/8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971/8FIE
M8W1">4ED*"1I9"P@)&-L87-S(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*
M("`@("`@("!I9B`H96UP='DH)&ED*2D@>PH@("`@("`@("`@("`D;V)J96-T
M(#T@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@:60@<F5Q=65S=&5D+B<I.PH@("`@
M("`@("`@("!R971U<FX@)&]B:F5C=#L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7VQO861">4ED*"1I9"D["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1U<V5?871T<FEB=71E
M<R`](&ES7VYU;&PH)&-L87-S*2!\?"!I<U]C86QL86)L92AA<G)A>2@D8VQA
M<W,L("=?9G)O;4%T=')I8G5T97,G*2D["B`@("`@("`@:68@*"1U<V5?871T
M<FEB=71E<RD@>PH@("`@("`@("`@("`D871T<FEB=71E<R`]("1T:&ES+3YG
M971!='1R:6)U=&5S*"1I9"D["B`@("`@("`@("`@(&EF("AI<U]A*"1A='1R
M:6)U=&5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&%T=')I8G5T97,["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("AI<U]N=6QL*"1C;&%S<RDI('L*("`@("`@("`@("`@("`@("1C;&%S<R`]
M("1T:&ES+3Y?9&5F:6YE3V)J96-T0VQA<W,H)&%T=')I8G5T97,I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@
M("`@)&YA;64@/2`D=&AI<RT^9V5T3F%M92@D:60I.PH@("`@("`@("1D871A
M3V(@/2`F;F5W("1C;&%S<R@D;F%M92D["B`@("`@("`@)&1A=&%/8BT^<V5T
M1&%T851R964H)'1H:7,I.PH@("`@("`@("\J($EF('1H92!C;&%S<R!H87,@
M82!?9G)O;4%T=')I8G5T97,@;65T:&]D+"!L;V%D(&1A=&$@9G)O;0H@("`@
M("`@("`J('1H92!A='1R:6)U=&5S(&)A8VME;F0N("HO"B`@("`@("`@:68@
M*"1U<V5?871T<FEB=71E<RD@>PH@("`@("`@("`@("`D9&%T84]B+3Y?9G)O
M;4%T=')I8G5T97,H)&%T=')I8G5T97,I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\J($]T:&5R=VES92!L;V%D(&ET(&9R;VT@=&AE(&]L9"!D
M871A('-T;W)A9V4@9FEE;&0N("HO"B`@("`@("`@("`@("1D871A3V(M/G-E
M=$1A=&$H)'1H:7,M/F=E=$1A=&$H)&ED*2D["B`@("`@("`@?0H*("`@("`@
M("`D9&%T84]B+3YS971/<F1E<B@D=&AI<RT^9V5T3W)D97(H)&YA;64I*3L*
M("`@("`@("!R971U<FX@)&1A=&%/8CL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@86X@87)R87D@;V8@1&%T851R965/8FIE8W0@*&]R('-U8F-L
M87-S*2!O8FIE8W1S"B`@("`@*B!C;W)R97-P;VYD:6YG('1O('1H92!O8FIE
M8W1S(&EN("1I9',L('=I=&@@=&AE(&]B:F5C=`H@("`@("H@;F%M97,@87,@
M=&AE(&ME>7,@;V8@=&AE(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D:61S("`@("!!;B!A<G)A>2!O9B!O8FIE8W0@:61S+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VQA<W,@(%-U8F-L87-S(&]F($1A=&%4<F5E3V)J
M96-T('1O('5S92X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!$871A5')E94]B:F5C="X@3G5L;"!F;W)C97,@=&AE(&1R:79E
M<B!T;R!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6YT;R!T
M:&4@871T<FEB=71E<R!T86)L92!T;R!D971E<FUI;F4@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@=7-E+B!)9B!N;VYE
M(&ES(&9O=6YD(&ET('5S97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!$871A5')E94]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$]B
M:F5C=',H)&ED<RP@)&-L87-S(#T@)T1A=&%4<F5E3V)J96-T)RD*("`@('L*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]L;V%D0GE)9"@D:61S*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&1E
M9FEN94-L87-S(#T@:7-?;G5L;"@D8VQA<W,I.PH@("`@("`@("1A='1R:6)U
M=&5S(#T@:7-?;G5L;"@D8VQA<W,I('Q\(&ES7V-A;&QA8FQE*&%R<F%Y*"1C
M;&%S<RP@)U]F<F]M071T<FEB=71E<R<I*3L*"B`@("`@("`@:68@*"1A='1R
M:6)U=&5S*2!["B`@("`@("`@("`@("1D871A(#T@)'1H:7,M/F=E=$%T=')I
M8G5T97,H)&ED<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^9V5T1&%T82@D:61S*3L*("`@("`@("!]"@H@("`@("`@
M("1O8FIE8W1S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D:61S(&%S
M("1I9"D@>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3YG971.86UE*"1I
M9"D["B`@("`@("`@("`@(&EF("@A96UP='DH)&YA;64I("8F("%E;7!T>2@D
M9&%T85LD:61=*2D@>PH@("`@("`@("`@("`@("`@:68@*"1D969I;F5#;&%S
M<RD@>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<R`]("1T:&ES+3Y?9&5F
M:6YE3V)J96-T0VQA<W,H)&1A=&%;)&ED72D["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72`]("9N97<@)&-L87-S
M*"1N86UE*3L*("`@("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^<V5T
M1&%T851R964H)'1H:7,I.PH@("`@("`@("`@("`@("`@:68@*"1A='1R:6)U
M=&5S*2!["B`@("`@("`@("`@("`@("`@("`@)&]B:F5C='-;)&YA;65=+3Y?
M9G)O;4%T=')I8G5T97,H)&1A=&%;)&ED72D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^
M<V5T1&%T82@D9&%T85LD:61=*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1O8FIE8W1S6R1N86UE72T^<V5T3W)D97(H)'1H:7,M/F=E
M=$]R9&5R*"1N86UE*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D;V)J96-T<SL*("`@('T*"B`@("`O*BH*("`@("`J($5X
M<&]R="!A(&QI<W0@;V8@;V)J96-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M8V]N<W1A;G0@)&9O<FUA="`@("`@($9O<FUA="!O9B!T:&4@97AP;W)T"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`@)'-T87)T;&5A9B`@(%1H92!N86UE(&]F
M('1H92!L96%F(&9R;VT@=VAI8V@@=V4@<W1A<G0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&5X<&]R="!T<F5E+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@("1R96QO860@("`@("!292UL;V%D('1H92!R97%U
M97-T960@8VAU;FL_($1E9F%U;'1S('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E("AO;FQY('=H870@:7,@8W5R<F5N=&QY
M(&QO861E9"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("`@)')O;W1N86UE("`@
M(%1H92!L86)E;"!T;R!U<V4@9F]R('1H92!R;V]T(&5L96UE;G0N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O($1!
M5$%44D5%7U)/3U0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)&UA>&1E<'1H
M("`@(%1H92!M87AI;75M(&YU;6)E<B!O9B!L979E;',@=&\@<F5T=7)N+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T
M;R!$051!5%)%15]23T]4+"!W:&EC:"!I<R!N;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!L:6UI="X*("`@("`J($!P87)A;2!B;V]L
M96%N("`D;&]A9%1R964@("`@3&]A9"!A('1R964@<W1A<G1I;F<@870@)')O
M;W0L(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E<75E<W1E9"!L979E;"!A;F0@9&ER96-T('!A<F5N=',_"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M('-I;F=L92!L979E;"X*("`@("`J($!P87)A;2!S=')I;F<@("`D<V]R=&)Y
M7VYA;64@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@("1S;W)T8GE?:V5Y("!!='1R:6)U=&4@:V5Y
M('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("`D
M9&ER96-T:6]N("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!T<F5E(')E<')E<V5N=&%T
M:6]N(&]F('1H92!O8FIE8W1S+"!O<B!A(%!%05)?17)R;W(*("`@("`J("`@
M("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E="@D9F]R;6%T+"`D<W1A<G1L96%F(#T@1$%40512145?4D]/5"P@)')E
M;&]A9"`](&9A;'-E+`H@("`@("`@("`@("`@("`@("1R;V]T;F%M92`]($1!
M5$%44D5%7U)/3U0L("1M87AD97!T:"`]("TQ+"`D;&]A9%1R964@/2!F86QS
M92P*("`@("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D<V]R
M=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@
M("\J(%-E="!S;W)T:6YG(&AA<V@@*B\*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'-O<G1B>5]N86UE*2!\?"`A:7-?;G5L;"@D<V]R=&)Y7VYA;64I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<V]R=$AA<V@@/2!$871A5')E93HZ<V]R=$AA
M<V@H)'-T87)T;&5A9BP@)'-O<G1B>5]N86UE+"`D<V]R=&)Y7VME>2P@)&1I
M<F5C=&EO;BD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7VQO860H)'-T
M87)T;&5A9BP@)&QO8614<F5E+"`D<F5L;V%D+"`D<V]R=&)Y7VYA;64L("1S
M;W)T8GE?:V5Y+"`D9&ER96-T:6]N*3L*("`@("`@("`D;W5T(#T@87)R87DH
M*3L*"B`@("`@("`@<W=I=&-H("@D9F]R;6%T*2!["B`@("`@("`@8V%S92!$
M051!5%)%15]&3U)-051?5%)%13H*("`@("`@("`@("`@)'-T87)T:60@/2`D
M=&AI<RT^9V5T260H)'-T87)T;&5A9BP@)&UA>&1E<'1H*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)'-T87)T:60L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<W1A<G1I9#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R964H)&]U="P@)'-T
M87)T:60L("1M87AD97!T:"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E($1!5$%44D5%7T9/4DU!5%]&3$%4.@H@("`@("`@("`@("`D<W1A
M<G1I9"`]("1T:&ES+3YG971)9"@D<W1A<G1L96%F*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)'-T87)T:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<W1A<G1I9#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;$QI<W0H)&]U="P@)'-T87)T
M:60L("1M87AD97!T:"D["B`@("`@("`@("`@(&EF("@A96UP='DH)&]U=%M$
M051!5%)%15]23T]472DI('L*("`@("`@("`@("`@("`@("1O=71;1$%40512
M145?4D]/5%T@/2`D<F]O=&YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=.;W0@<W5P<&]R=&5D)RD["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]S;W)T2&%S:"DI('L*
M("`@("`@("`@("`@+RH@4F5S970@<V]R=&EN9R!H87-H+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^7W-O<G1(87-H(#T@;G5L;#L*("`@("`@("`@("`@+RH@
M4F5V97)S92!S:6YC92!T:&4@871T<FEB=71E('-O<G1I;F<@8V]M8FEN960@
M=VET:"!T<F5E('5P+7=A<F0*("`@("`@("`@("`@("H@<V]R=&EN9R!P<F]D
M=6-E<R!A(')E=F5R<V5D(&]B:F5C="!O<F1E<BX@*B\*("`@("`@("`@("`@
M)&]U="`](&%R<F%Y7W)E=F5R<V4H)&]U="P@=')U92D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&]U=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O
M=6YT<R!O8FIE8W1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M87)T;&5A9B`@5&AE(&YA;64@;V8@=&AE(&QE868@9G)O;2!W:&EC:"!W92!S
M=&%R=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!C;W5N=&EN
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!N=6UB97(@
M;V8@=&AE(&]B:F5C=',@8F5L;W<@)'-T87)T;&5A9BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]U;G0H)'-T87)T;&5A9B`]($1!5$%44D5%7U)/3U0I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]U;G0H)'-T87)T;&5A9BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@871T<FEB=71E('-O<G0@
M:&%S:`H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D<F]O="`@("`@("`@(%1H92!N86UE(&]F
M('1H92!L96%F(&9R;VT@=VAI8V@@=V4@<W1A<G0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&AE(&5X<&]R="!T<F5E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M92!T
M;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R
M=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C
M=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M
M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M(%1H92!S;W)T(&AA<V@*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$AA<V@H
M)')O;W0L("1S;W)T8GE?;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`P*0H@("`@
M>PH@("`@("`@(')E='5R;B!S<')I;G1F*"<E<RTE<RTE<RTE<R<L("1R;V]T
M+"`D<V]R=&)Y7VYA;64L("1S;W)T8GE?:V5Y+"`D9&ER96-T:6]N*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A(&QI<W0@;V8@;V)J96-T<R!J
M=7-T(&QI:V4@9V5T*"D@86)O=F4L(&)U="!U<V5S(&%N"B`@("`@*B!O8FIE
M8W0@:60@=&\@9F5T8V@@=&AE(&QI<W0@;V8@;V)J96-T<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@8V]N<W1A;G0@)&9O<FUA="`@("!&;W)M870@;V8@=&AE
M(&5X<&]R="X*("`@("`J($!P87)A;2!S=')I;F<@("1S=&%R=&QE868@(%1H
M92!I9"!O9B!T:&4@;&5A9B!F<F]M('=H:6-H('=E('-T87)T('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@97AP;W)T('1R964N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D<F5L;V%D("`@("!296QO860@=&AE(')E
M<75E<W1E9"!C:'5N:S\@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9A;'-E("AO;FQY('=H870@:7,@8W5R<F5N=&QY
M(&QO861E9"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F]O=&YA;64@("!4
M:&4@;&%B96P@=&\@=7-E(&9O<B!T:&4@<F]O="!E;&5M96YT+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@1$%40512
M145?4D]/5"X*("`@("`J($!P87)A;2!I;G1E9V5R("1M87AD97!T:"`@(%1H
M92!M87AI;75M(&YU;6)E<B!O9B!L979E;',@=&\@<F5T=7)N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R`M,2P@=VAI
M8V@@:7,@;F\@;&EM:70N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5&AE('1R964@<F5P<F5S96YT871I;VX@;V8@=&AE(&]B:F5C=',L(&]R(&$@
M4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("`@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0GE)9"@D9F]R;6%T+"`D<W1A<G1L
M96%F(#T@1$%40512145?4D]/5"P@)')E;&]A9"`](&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`D<F]O=&YA;64@/2!$051!5%)%15]23T]4+"`D;6%X
M9&5P=&@@/2`M,2D*("`@('L*("`@("`@("`D=&AI<RT^7VQO861">4ED*"1S
M=&%R=&QE868I.PH@("`@("`@("1O=70@/2!A<G)A>2@I.PH*("`@("`@("!S
M=VET8V@@*"1F;W)M870I('L*("`@("`@("!C87-E($1!5$%44D5%7T9/4DU!
M5%]44D5%.@H@("`@("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R
M964H)&]U="P@)'-T87)T;&5A9BP@)&UA>&1E<'1H*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@1$%40512145?1D]234%47T9,050Z"B`@
M("`@("`@("`@("1T:&ES+3Y?97AT<F%C=$%L;$QE=F5L3&ES="@D;W5T+"`D
M<W1A<G1L96%F+"`D;6%X9&5P=&@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1O=71;1$%40512145?4D]/5%TI*2!["B`@("`@("`@("`@("`@("`D;W5T
M6T1!5$%44D5%7U)/3U1=(#T@)')O;W1N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F]T('-U<'!O<G1E9"<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&$@;&ES="!O9B!A;&P@9W)O=7!S("AR;V]T(&YO
M9&5S*2!O9B!T:&4@9&%T82!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!T:&4@9W)O=7`@241S"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$=R;W5P<R@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E=')I979E(&1A=&$@9F]R(&%N(&]B:F5C="!F<F]M('1H92!D871A=')E
M95]D871A(&9I96QD+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@:60@=&\@
M9F5T8V@L(&]R(&%N(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$1A=&$H)&-I9"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@26UP;W)T(&$@;&ES="!O9B!O8FIE8W1S+B!5<V5D(&)Y
M(&1R:79E<G,@=&\@<&]P=6QA=&4@=&AE(&EN=&5R;F%L"B`@("`@*B`D7V1A
M=&$@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&1A=&$@
M("`@(%1H92!D871A('1O(&EM<&]R="X*("`@("`J($!P87)A;2!S=')I;F<@
M("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!C;VYV97)T('1H92!O8FIE8W0@
M;F%M92!F<F]M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H)&1A=&$L("1C
M:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("`D8VED<R`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&ED(#T^("1C870I('L*("`@
M("`@("`@("`@:68@*"%I<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@
M("`@("`@)&-A=%LQ72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-A=%LQ
M72P@)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C:61S
M6R1C871;,%U=(#T@)&-A=%LQ73L*("`@("`@("`@("`@)&-P87)E;G1S6R1C
M871;,%U=(#T@)&-A=%LR73L*("`@("`@("`@("`@)&-O<F1E<G-;)&-A=%LP
M75T@/2`D8V%T6S-=.PH@("`@("`@("`@("`D<V]R9&5R<ULD8V%T6S!=72`]
M("1I9#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C:61S(&%S("1I
M9"`]/B`D;F%M92D@>PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG
M;F%M92==(#T@)&YA;64["B`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD:61=
M6R=O<F1E<B==(#T@)&-O<F1E<G-;)&ED73L*("`@("`@("`@("`@:68@*"%I
M<U]N=6QL*"1T:&ES+3Y?<V]R=$AA<V@I*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1A=&%;)&ED75LG<V]R=&5R)UU;)'1H:7,M/E]S;W)T2&%S:%T@
M/2`D<V]R9&5R<ULD:61=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A96UP='DH)&-P87)E;G1S6R1I9%TI*2!["B`@("`@("`@("`@("`@("`D
M<&%R96YT<R`](&5X<&QO9&4H)SHG+"!S=6)S='(H)&-P87)E;G1S6R1I9%TL
M(#$I*3L*("`@("`@("`@("`@("`@("1P87(@/2`D<&%R96YT<UMC;W5N="@D
M<&%R96YT<RD@+2`Q73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD
M:61=6R=P87)E;G0G72`]("1P87(["@H@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7VYA;65-87!;)'!A<ETI*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@268@=V4G=F4@86QR96%D>2!L;V%D960@=&AE(&1I<F5C="!P
M87)E;G0@;V8*("`@("`@("`@("`@("`@("`@("`O+R!T:&ES(&]B:F5C="P@
M=7-E('1H870@=&\@9FEN9"!T:&4@9G5L;"!N86UE+@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;F%M94UA<%LD:61=(#T@)'1H:7,M/E]N86UE36%P
M6R1P87)=("X@)SHG("X@)&YA;64["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("\O($]T:&5R=VES92P@<G5N('1H<F]U
M9V@@<&%R96YT<R!O;F4@8GD@;VYE('1O"B`@("`@("`@("`@("`@("`@("`@
M+R\@8G5I;&0@:70@=7`N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N
M86UE36%P6R1I9%T@/2`G)SL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<&%R96YT<R!A<R`D<&%R240I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%E;7!T>2@D8VED<ULD<&%R241=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@+CT@)SHG("X@
M)&-I9'-;)'!A<DE$73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VYA;65-87!;)&ED72`]('-U8G-T<B@D=&AI<RT^7VYA;65-87!;)&ED72P@
M,2D@+B`G.B<@+B`D;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&%T85LD:61=
M6R=P87)E;G0G72`]($1!5$%44D5%7U)/3U0["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VYA;65-87!;)&ED72`]("1N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($5X=')A8W0@;VYE(&QE=F5L(&]F(&1A=&$@9F]R(&$@<&%R96YT
M(&QE868L('-O<G1E9"!F:7)S="!B>0H@("`@("H@=&AE:7(@;W)D97(@86YD
M('1H96X@8GD@;F%M92X@5&AI<R!F=6YC=&EO;B!I<R!A('=A>2!T;R!G970@
M80H@("`@("H@8V]L;&5C=&EO;B!O9B`D;&5A9B=S(&-H:6QD<F5N+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&QE868@($YA;64@;V8@=&AE('!A
M<F5N="!F<F]M('=H:6-H('1O('-T87)T+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X=')A8W1/;F5,979E
M;"@D;&5A9B`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@("`@("`@)&]U="`]
M(&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]D871A(&%S("1I
M9"`]/B`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H)'9A;'-;)W!A<F5N="==
M(#T]("1L96%F*2!["B`@("`@("`@("`@("`@("`D;W5T6R1I9%T@/2`D=F%L
M<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU
M;&PH)'1H:7,M/E]S;W)T2&%S:"DI('L*("`@("`@("`@("`@=6%S;W)T*"1O
M=70L(&%R<F%Y*"1T:&ES+"`G7V-M<"<I*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!U87-O<G0H)&]U="P@87)R87DH)'1H:7,L("=?8VUP4V]R
M=&5D)RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T(&%L;"!L979E;',@;V8@9&%T82P@
M<W1A<G1I;F<@9G)O;2!A(&=I=F5N('!A<F5N=`H@("`@("H@;&5A9B!I;B!T
M:&4@9&%T871R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O=70@
M("`@("`@("!4:&ES(&ES(&%N(&ET97)A=&EN9R!F=6YC=&EO;BP@<V\@)&]U
M="!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@
M8GD@<F5F97)E;F-E('1O(&-O;G1A:6X@=&AE(')E<W5L="X*("`@("`J($!P
M87)A;2!S=')I;F<@("1P87)E;G0@("`@5&AE(&YA;64@;V8@=&AE('!A<F5N
M="!F<F]M('=H:6-H('1O(&)E9VEN+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&UA>&1E<'1H("!-87@@;V8@;&5V96QS(&]F(&1E<'1H('1O(&-H96-K+@H@
M("`@("H*("`@("`J($!N;W1E($EF(&YO=&AI;F<@:7,@<F5T=7)N960@=&AA
M="!M96%N<R!T:&5R92!I<R!N;R!C:&EL9"P@8G5T"B`@("`@*B!D;VXG="!F
M;W)G970@=&\@861D('1H92!P87)E;G0@:68@86YY('-U8G-E<75E;G0@;W!E
M<F%T:6]N<R!A<F4*("`@("`J(')E<75I<F5D(0H@("`@("HO"B`@("!F=6YC
M=&EO;B!?97AT<F%C=$%L;$QE=F5L5')E92@F)&]U="P@)'!A<F5N="`]($1!
M5$%44D5%7U)/3U0L("1M87AD97!T:"`]("TQ*0H@("`@>PH@("`@("`@(&EF
M("@D;6%X9&5P=&@@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D;W5T6R1P87)E;G1=(#T@=')U93L*"B`@
M("`@("`@)&L@/2`D=&AI<RT^7V5X=')A8W1/;F5,979E;"@D<&%R96YT*3L*
M("`@("`@("!F;W)E86-H("@D:R!A<R`D;V)J96-T(#T^("1V*2!["B`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)&]U=%LD<&%R96YT72DI('L*("`@("`@
M("`@("`@("`@("1O=71;)'!A<F5N=%T@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1O=71;)'!A<F5N=%U;)&]B:F5C=%T@/2!T<G5E
M.PH@("`@("`@("`@("`D=&AI<RT^7V5X=')A8W1!;&Q,979E;%1R964H)&]U
M=%LD<&%R96YT72P@)&]B:F5C="P@)&UA>&1E<'1H("T@,2D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@17AT<F%C="!A;&P@;&5V96QS(&]F
M(&1A=&$L('-T87)T:6YG(&9R;VT@86YY('!A<F5N="!I;@H@("`@("H@=&AE
M('1R964N"B`@("`@*@H@("`@("H@4F5T=7)N960@87)R87D@9F]R;6%T.B!A
M<G)A>2AP87)E;G0@/3X@87)R87DH8VAI;&0@/3X@=')U92DI"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1O=70@("`@("`@("!4:&ES(&ES(&%N(&ET
M97)A=&EN9R!F=6YC=&EO;BP@<V\@)&]U="!I<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!P87-S960@8GD@<F5F97)E;F-E('1O(&-O;G1A
M:6X@=&AE(')E<W5L="X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@
M("`@5&AE(&YA;64@;V8@=&AE('!A<F5N="!F<F]M('=H:6-H('1O(&)E9VEN
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&1E<'1H("!-87@@;G5M8F5R
M(&]F(&QE=F5L<R!O9B!D97!T:"!T;R!C:&5C:RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V5X=')A8W1!;&Q,979E;$QI<W0H)B1O=70L("1P87)E;G0@/2!$
M051!5%)%15]23T]4+"`D;6%X9&5P=&@@/2`M,2D*("`@('L*("`@("`@("!I
M9B`H)&UA>&1E<'1H(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@+R\@5&AI<R!I<R!R961U;F1A;G0@;6]S
M="!O9B!T:&4@=&EM92P@<V\@;6%K92!S=7)E('=E(&YE960@=&\*("`@("`@
M("`O+R!D;R!I="X*("`@("`@("!I9B`H96UP='DH)&]U=%LD<&%R96YT72DI
M('L*("`@("`@("`@("`@)&]U=%LD<&%R96YT72`]("1T:&ES+3YG971.86UE
M*"1P87)E;G0I.PH@("`@("`@('T*"B`@("`@("`@)&L@/2!A<G)A>5]K97ES
M*"1T:&ES+3Y?97AT<F%C=$]N94QE=F5L*"1P87)E;G0I*3L*("`@("`@("!F
M;W)E86-H("@D:R!A<R`D;V)J96-T*2!["B`@("`@("`@("`@("1O=71;)&]B
M:F5C=%T@/2`D=&AI<RT^9V5T3F%M92@D;V)J96-T*3L*("`@("`@("`@("`@
M)'1H:7,M/E]E>'1R86-T06QL3&5V96Q,:7-T*"1O=70L("1O8FIE8W0L("1M
M87AD97!T:"`M(#$I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!C:&EL9"=S(&1I<F5C="!P87)E;G0@240N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("1C:&EL9"`@16ET:&5R('1H92!O8FIE8W0L
M(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!P871H(&5L96UE;G1S+"!O<B!T:&4@;V)J96-T(&YA;64@9F]R
M('=H:6-H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T;R!L;V]K('5P
M('1H92!P87)E;G0G<R!)1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G
M97(@(%1H92!U;FEQ=64@240@;V8@=&AE('!A<F5N="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&%R96YT*"1C:&EL9"D*("`@('L*("`@("`@("!I9B`H
M:7-?82@D8VAI;&0L("=$871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@
M("1C:&EL9"`]("1C:&EL9"T^9V5T3F%M92@I.PH@("`@("`@('T*("`@("`@
M("`D:60@/2`D=&AI<RT^9V5T260H)&-H:6QD*3L*("`@("`@("!I9B`H:7-?
M82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I
M9#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)&ED
M75LG<&%R96YT)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82`D8VAI
M;&0G<R!D:7)E8W0@<&%R96YT($E$+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1C:&EL9$ED("!'970@=&AE('!A<F5N="!O9B!T:&ES(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!U;FEQ=64@
M240@;V8@=&AE('!A<F5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R
M96YT0GE)9"@D8VAI;&1)9"D*("`@('L*("`@("`@("`D=&AI<RT^7VQO861"
M>4ED*"1C:&EL9$ED*3L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]D
M871A6R1C:&EL9$ED72D@/PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&-H
M:6QD261=6R=P87)E;G0G72`Z"B`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R
M;W(H)&-H:6QD260@+B`G(&YO="!F;W5N9"<I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&$@;&ES="!O9B!P87)E;G1S(&%L;"!T:&4@=V%Y('5P('1O
M('1H92!R;V]T(&]B:F5C="!F;W(*("`@("`J("1C:&EL9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@("`D8VAI;&0@("!4:&4@;F%M92!O9B!T:&4@
M8VAI;&0*("`@("`J($!P87)A;2!B;V]L96%N("1G971I9',@($EF('1R=64L
M(')E='5R;B!P87)E;G0@241S.R!O=&AE<G=I<V4L(')E='5R;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@;F%M97,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@6V-H:6QD72!;<&%R96YT72!I;B!A('1R964@9F]R
M;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971087)E;G1S*"1C:&EL9"P@
M)&=E=&ED<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1P:60@/2`D=&AI<RT^
M9V5T4&%R96YT*"1C:&EL9"D["B`@("`@("`@:68@*&ES7V$H)'!I9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G4&%R96YT<R!N;W0@9F]U;F0Z("<@+B`D<&ED+3YG971-97-S86=E
M*"DI.PH@("`@("`@('T*("`@("`@("`D<&YA;64@/2`D=&AI<RT^9V5T3F%M
M92@D<&ED*3L*("`@("`@("!I9B`H)&=E=&ED<RD@>PH@("`@("`@("`@("`D
M<&%R96YT<R`](&%R<F%Y*"1P:60@/3X@=')U92D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'!A<F5N=',@/2!A<G)A>2@D<&YA;64@/3X@=')U
M92D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'!I9"`A/2!$051!5%)%15]2
M3T]4*2!["B`@("`@("`@("`@(&EF("@D9V5T:61S*2!["B`@("`@("`@("`@
M("`@("`D<&%R96YT<ULD<&ED72`]("1T:&ES+3YG971087)E;G1S*"1P;F%M
M92P@)&=E=&ED<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<&%R96YT<ULD<&YA;65=(#T@)'1H:7,M/F=E=%!A<F5N=',H)'!N
M86UE+"`D9V5T:61S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1P87)E;G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@;&ES="!O9B!P87)E;G1S(&%L;"!T:&4@=V%Y('5P('1O('1H92!R;V]T
M(&]B:F5C="!F;W(*("`@("`J("1C:&EL9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D8VAI;&1)9"`@5&AE(&ED(&]F('1H92!C:&EL9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R96YT<R`@("!4:&4@87)R87DL(&%S('=E
M(&)U:6QD(&ET('5P+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@
M9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@<&%R96YT<R!O9B`D8VAI;&0L"B`@
M("`@*B`@("`@("`@("`@("`@("!H87-H960@:6X@)&ED(#T^("1N86UE(&9O
M<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R96YT3&ES="@D8VAI
M;&1)9"P@)'!A<F5N=',@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P:60@
M/2`D=&AI<RT^9V5T4&%R96YT0GE)9"@D8VAI;&1)9"D["B`@("`@("`@:68@
M*&ES7V$H)'!I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4&%R96YT<R!N;W0@9F]U;F0Z("<@+B`D
M<&ED+3YG971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1P
M:60@(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D<&%R96YT<ULD
M<&ED72`]("1T:&ES+3YG971.86UE*"1P:60I.PH@("`@("`@("`@("`D<&%R
M96YT<R`]("1T:&ES+3YG971087)E;G1,:7-T*"1P:60L("1P87)E;G1S*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R96YT<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!A('!A<F5N="!)1"!S=')I;F<@*&ED.F-I9"!F
M;W)M870I(&9O<B!T:&4@<W!E8VEF:65D(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@;6EX960@)&]B:F5C="`@5&AE(&]B:F5C="!T;R!R971U<FX@
M82!P87)E;G0@<W1R:6YG(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9WQ014%27T5R<F]R("!4:&4@240@(G!A=&@B('1O('1H92!P87)E;G0@
M;V)J96-T(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!0
M14%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A<F5N=$ED4W1R:6YG*"1O8FIE8W0I"B`@("!["B`@("`@("`@)'!T<F5E
M(#T@)'1H:7,M/F=E=%!A<F5N=',H)&]B:F5C="P@=')U92D["B`@("`@("`@
M:68@*&ES7V$H)'!T<F5E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<'1R964["B`@("`@("`@?0H*("`@("`@("`D<&ED<R`]("<G
M.PH@("`@("`@('=H:6QE("@H;&ES="@D:60L("1P87)E;G0I(#T@96%C:"@D
M<'1R964I*2`F)B!I<U]A<G)A>2@D<&%R96YT*2D@>PH@("`@("`@("`@("`D
M<&ED<R`]("<Z)R`N("1I9"`N("1P:61S.PH@("`@("`@("`@("`D<'1R964@
M/2`D<&%R96YT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P:61S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!N=6UB97(@;V8@8VAI;&1R
M96X@86X@;V)J96-T(&AA<RP@;VYL>2!C;W5N=&EN9R!I;6UE9&EA=&4*("`@
M("`J(&-H:6QD<F5N+"!N;W0@9W)A;F1C:&EL9')E;BP@971C+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D<&%R96YT("!%:71H97(@=&AE(&]B:F5C
M="!O<B!T:&4@;F%M92!F;W(@=VAI8V@@=&\@8V]U;G0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T:&4@8VAI;&1R96XL(&1E9F%U;'1S('1O('1H
M92!R;V]T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@*$1!5$%44D5%
M7U)/3U0I+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971.=6UB97)/9D-H:6QD<F5N*"1P87)E;G0@/2!$
M051!5%)%15]23T]4*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1P87)E;G0L
M("=$871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1P87)E;G0@/2`D
M<&%R96YT+3YG971.86UE*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M;&]A9"@D<&%R96YT*3L*("`@("`@("`D;W5T(#T@)'1H:7,M/E]E>'1R86-T
M3VYE3&5V96PH)'1H:7,M/F=E=$ED*"1P87)E;G0I*3L*("`@("`@("!R971U
M<FX@:7-?87)R87DH)&]U="D@/R!C;W5N="@D;W5T*2`Z(#`["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:R!I9B!A;B!O8FIE8W0@97AI<W1S(&]R(&YO
M="X@5&AE(')O;W0@96QE;65N="!$051!5%)%15]23T]4(&%L=V%Y<R!E>&ES
M=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1O8FIE8W0@(%1H92!N
M86UE(&]F('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&EF('1H92!O8FIE8W0@97AI<W1S+"!F86QS92!O=&AE<G=I
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D;V)J96-T*0H@("`@
M>PH@("`@("`@(&EF("AE;7!T>2@D;V)J96-T*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1O8FIE
M8W0L("=$871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1O8FIE8W0@
M/2`D;V)J96-T+3YG971.86UE*"D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R
M<F%Y*"1O8FIE8W0I*2!["B`@("`@("`@("`@("1O8FIE8W0@/2!I;7!L;V1E
M*"<Z)RP@)&]B:F5C="D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&]B:F5C
M="`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T*"B`@("`@("`@)&ED36%P(#T@87)R87E?9FQI<"@D=&AI
M<RT^7VYA;65-87`I.PH@("`@("`@(&EF("AI<W-E="@D:61-87!;)&]B:F5C
M=%TI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]L;V%D*"1O8FIE8W0I.PH@("`@("`@("1I9$UA<"`]
M(&%R<F%Y7V9L:7`H)'1H:7,M/E]N86UE36%P*3L*("`@("`@("!R971U<FX@
M:7-S970H)&ED36%P6R1O8FIE8W1=*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@;F%M92!O9B!A;B!O8FIE8W0@9G)O;2!I=',@:60N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("!4:&4@:60@9F]R('=H:6-H
M('1O(&QO;VL@=7`@=&AE(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@D:60I"B`@("![
M"B`@("`@("`@+RH@268@;F\@:60@;W(@:68@:60@:7,@82!014%2(&5R<F]R
M+"!R971U<FX@;G5L;"X@*B\*("`@("`@("!I9B`H96UP='DH)&ED*2!\?"!I
M<U]A*"1I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J($EF(&-H96-K:6YG(&YA;64@
M;V8@<F]O="P@<F5T=7)N($1!5$%44D5%7U)/3U0N("HO"B`@("`@("`@:68@
M*"1I9"`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@(')E='5R;B!$
M051!5%)%15]23T]4.PH@("`@("`@('T*"B`@("`@("`@+RH@268@9F]U;F0@
M:6X@=&AE(&YA;64@;6%P+"!R971U<FX@=&AE(&YA;64N("HO"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?;F%M94UA<%LD:61=*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]N86UE36%P6R1I9%T["B`@("`@("`@?0H*("`@
M("`@("`O*B!.;W0@9F]U;F0@:6X@;F%M92!M87`L('1R>2!L;V%D:6YG('1H
M:7,@:60@:6YT;R!T:&4@;F%M90H@("`@("`@("`J(&UA<"X@*B\*("`@("`@
M("`D=&AI<RT^7VQO861">4ED*"1I9"D["@H@("`@("`@("\J($EF(&ED(&QO
M861E9"!R971U<FX@=&AE(&YA;64L(&]T:&5R=VES92!R971U<FX@;G5L;"X@
M*B\*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]N86UE36%P6R1I9%TI
M(#\*("`@("`@("`@("`@)'1H:7,M/E]N86UE36%P6R1I9%T@.@H@("`@("`@
M("`@("!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!I9"!O
M9B!A;B!O8FIE8W0@9G)O;2!I=',@;F%M92X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@)&YA;64@($5I=&AE<B!T:&4@;V)J96-T+"!A;B!A<G)A>2!C
M;VYT86EN:6YG('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("!P871H
M(&5L96UE;G1S+"!O<B!T:&4@;V)J96-T(&YA;64@9F]R('=H:6-H"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@('1O(&QO;VL@=7`@=&AE(&ED+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$ED*"1N86UE*0H@("`@>PH@("`@("`@("\J($-H96-K(&EF("1N86UE
M(&ES(&YO="!A('-T<FEN9RX@*B\*("`@("`@("!I9B`H:7-?82@D;F%M92P@
M)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@("`@+RH@1&%T851R965/
M8FIE8W0L(&=E="!T:&4@<W1R:6YG(&YA;64N("HO"B`@("`@("`@("`@("1N
M86UE(#T@)&YA;64M/F=E=$YA;64H*3L*("`@("`@("!](&5L<V5I9B`H:7-?
M87)R87DH)&YA;64I*2!["B`@("`@("`@("`@("\J(%!A=&@@87)R87DL(&EM
M<&QO9&4@=&\@9V5T('1H92!S=')I;F<@;F%M92X@*B\*("`@("`@("`@("`@
M)&YA;64@/2!I;7!L;V1E*"<Z)RP@)&YA;64I.PH@("`@("`@('T*"B`@("`@
M("`@+RH@268@8VAE8VMI;F<@:60@;V8@<F]O="P@<F5T=7)N($1!5$%44D5%
M7U)/3U0N("HO"B`@("`@("`@:68@*"1N86UE(#T]($1!5$%44D5%7U)/3U0I
M('L*("`@("`@("`@("`@<F5T=7)N($1!5$%44D5%7U)/3U0["B`@("`@("`@
M?0H*("`@("`@("`O*B!#:&5C:R!I9B!T:&4@;F%M92!A8W1U86QL>2!E>&ES
M=',L(&EF(&YO="!R971U<FX@82!014%2"B`@("`@("`@("H@97)R;W(N("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^97AI<W1S*"1N86UE*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D;F%M92`N("<@9&]E<R!N
M;W0@97AI<W0G*3L*("`@("`@("!]"@H@("`@("`@("\J($9L:7`@=&AE(&YA
M;64@;6%P('1O(&QO;VL@=7`@=&AE(&ED('5S:6YG('1H92!N86UE(&%S(&ME
M>2X@*B\*("`@("`@("`D:61-87`@/2!A<G)A>5]F;&EP*"1T:&ES+3Y?;F%M
M94UA<"D["B`@("`@("`@<F5T=7)N("1I9$UA<%LD;F%M95T["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE(&]R9&5R('!O<VET:6]N(&]F(&%N(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&-H:6QD("!%:71H
M97(@=&AE(&]B:F5C="!O<B!T:&4@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@;V)J96-T)W,@;W)D97(@<&]S:71I;VX@;W(@82!0
M14%2(&5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$]R9&5R*"1C:&EL9"D*("`@('L*("`@("`@("!I9B`H:7-?82@D8VAI;&0L
M("=$871A5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("1C:&EL9"`]("1C
M:&EL9"T^9V5T3F%M92@I.PH@("`@("`@('T*("`@("`@("`D:60@/2`D=&AI
M<RT^9V5T260H)&-H:6QD*3L*("`@("`@("!I9B`H:7-?82@D:60L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7V1A=&%;)&ED75LG;W)D
M97(G72D@/PH@("`@("`@("`@("`D=&AI<RT^7V1A=&%;)&ED75LG;W)D97(G
M72`Z"B`@("`@("`@("`@(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M97!L86-E(&%L;"!O8V-U<F5N8V5S(&]F("<Z)R!I;B!A;B!O8FIE8W0@;F%M
M92!W:71H("<N)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@;F%M92!O9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@96YC;V1E9"!N86UE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;F-O9&5.86UE*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!S
M=')?<F5P;&%C92@G.B<L("<N)RP@)&YA;64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T('1H92!S:&]R="!N86UE(&]F(&%N(&]B:F5C="P@<F5T=7)N
M<R!O;FQY('1H92!L87-T('!O<G1I;VX@;V8@=&AE"B`@("`@*B!F=6QL(&YA
M;64N($9O<B!D:7-P;&%Y('!U<G!O<V5S(&]N;'DN"B`@("`@*@H@("`@("H@
M0'-T871I8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!N86UE(&]F('1H92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!O8FIE8W0G<R!S:&]R="!N86UE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9713:&]R=$YA;64H)&YA;64I"B`@("!["B`@("`@("`@+RH@
M268@=&AE<F4@87)E('-E=F5R86P@8V]M<&]N96YT<R!T;R!T:&4@;F%M92P@
M97AP;&]D92!A;F0@9V5T('1H90H@("`@("`@("`J(&QA<W0@;VYE+"!O=&AE
M<G=I<V4@:G5S="!R971U<FX@=&AE(&YA;64N("HO"B`@("`@("`@:68@*'-T
M<G!O<R@D;F%M92P@)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&YA
M;64@/2!E>'!L;V1E*"<Z)RP@)&YA;64I.PH@("`@("`@("`@("`D;F%M92`]
M(&%R<F%Y7W!O<"@D;F%M92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!T<F5E('-O
M<G1E9"!B>2!T:&4@<W!E8VEF:65D(&%T=')I8G5T92!N86UE(&%N9"]O<B!K
M97DN"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'-I
M;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')O
M;W0@("`@("`@("!7:&EC:"!P;W)T:6]N(&]F('1H92!T<F5E('1O('-O<G0N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@
M=&\@86QL(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8614<F5E
M("`@(%-O<G0@=&AE('1R964@<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=65S
M=&5D(&QE=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!S:6YG;&4@;&5V96PN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W)T8GE?;F%M92`@071T<FEB=71E
M(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T
M:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@(%-O<G0@
M9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M;W)T9614<F5E*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@)'-O<G1B>5]N
M86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B
M>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D<R!A;B!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1O8FIE
M8W0@("`@("`@(%1H92!O8FIE8W0@=&\@861D("AS=')I;F<@;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$871A5')E94]B:F5C="DN
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:61?87-?;F%M92`@5')U92!O<B!F
M86QS92!T;R!I;F1I8V%T92!I9B!O8FIE8W0@240@:7,@=&\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B92!U<V5D(&%S(&]B:F5C="!N
M86UE+B!5<V5D(&EN('-I='5A=&EO;G,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!W:&5R92!T:&5R92!I<R!N;R!A=F%I;&%B;&4@=6YI
M<75E(&EN<'5T(&9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]B:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)&]B
M:F5C="P@)&ED7V%S7VYA;64@/2!F86QS92D*("`@('L*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T('-U<'!O<G1E9"<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`@)&YA;64@(%1H92!S:&]R="!O8FIE8W0@;F%M92X*
M("`@("`J($!P87)A;2!I;G1E9V5R("`D:60@("`@5&AE(&YE=R!O8FIE8W0G
M<R!U;FEQ=64@240N"B`@("`@*B!`<&%R86T@:6YT96=E<B`@)'!I9"`@(%1H
M92!U;FEQ=64@240@;V8@=&AE(&]B:F5C="=S('!A<F5N="X*("`@("`J($!P
M87)A;2!I;G1E9V5R("`D;W)D97(@5&AE(&]R9&5R:6YG(&1A=&$@9F]R('1H
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V%D9"@D;F%M92P@)&ED+"`D<&ED+"`D;W)D
M97(@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7V1A=&%;)&ED72`](&%R
M<F%Y*"=N86UE)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P87)E;G0G(#T^("1P:60L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;W)D97(G(#T^("1O<F1E<BD["B`@("`@("`@
M)'1H:7,M/E]N86UE36%P6R1I9%T@/2`D;F%M93L*"B`@("`@("`@+RH@4VAI
M9G0@86QO;F<@=&AE(&]R9&5R('!O<VET:6]N<RX@*B\*("`@("`@("`D=&AI
M<RT^7W)E;W)D97(H)'!I9"P@)&]R9&5R+"`D:60I.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&1A=&$@
M9F]R(&%N(&]B:F5C="!F<F]M('1H92!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S"B`@("`@*B!T86)L92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B!\(&%R<F%Y("1C:60@(%1H92!O
M8FIE8W0@:60@=&\@9F5T8V@L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&]R(&%N(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(&]F(&%T=')I8G5T97,L(&]R
M(&$@;75L=&DM;&5V96P@:&%S:`H@("`@("H@("`@("`@("`@("`@("`@;V8@
M;V)J96-T(&ED<R`]/B!T:&5I<B!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971!='1R:6)U=&5S*"1C:60I"B`@("!["B`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO="!S=7!P;W)T960G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU;6)E<B!O9B!O8FIE8W1S
M(&UA=&-H:6YG(&$@<V5T(&]F(&%T=')I8G5T92!C<FET97)I82X*("`@("`J
M"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<V5E(&)U:6QD071T
M<FEB=71E475E<GDH*0H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1C
M<FET97)I82`@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P87)A
M;2!S=')I;F<@("1P87)E;G0@("`@(%1H92!P87)E;G0@;F]D92!T;R!S=&%R
M="!S96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,
M979E;',@(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D:7)E8W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F
M("1P87)E;G0_($1E9F%U;'1S('1O(&%L;"!L979E;',N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D<F5S=')I8W0@("!/;FQY(')E='5R;B!A='1R:6)U=&5S
M('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%T=')I8G5T95]N86UE(&]R(&%T=')I8G5T95]I9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]U;G1">4%T=')I8G5T97,H)&-R:71E<FEA+"`D<&%R
M96YT(#T@1$%40512145?4D]/5"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A;&Q,979E;',@/2!T<G5E+"`D<F5S=')I8W0@/2`G;F%M92<I
M"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)VYO="!S
M=7!P;W)T960G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S
M970@;V8@;V)J96-T(&ED<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@
M8W)I=&5R:6$N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0'-E92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@("`D8W)I=&5R:6$@("`@(%1H92!A<G)A>2!O9B!C<FET
M97)I82X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@("`@5&AE
M('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL(&QE=F5L
M<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U;'1S('1O
M(&%L;"!L979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S=')I8W0@
M("`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U=&5?;F%M
M92!O<B!A='1R:6)U=&5?:60N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O
M;2`@("`@("`@(%1H92!O8FIE8W0@=&\@<W1A<G0@=&\@9F5T8VAI;F<*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C;W5N="`@("`@("`@5&AE(&YU;6)E<B!O
M9B!O8FIE8W1S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R
M=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*
M("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E
M(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN
M9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971">4%T=')I8G5T97,H)&-R:71E
M<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/5"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D86QL3&5V96QS(#T@=')U92P@)')E<W1R:6-T(#T@
M)VYA;64G+"`D9G)O;2`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O=6YT(#T@,"P@)'-O<G1B>5]N86UE(#T@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E
M8W1I;VX@/2`P*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=N;W0@<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M;W)T<R!)1',@8GD@871T<FEB=71E('9A;'5E<RX@241S('=I=&AO=70@871T
M<FEB=71E<R!W:6QL(&)E(&%D9&5D('1O"B`@("`@*B!T:&4@96YD(&]F('1H
M92!S;W)T960@;&ES="X*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'5N;W)D97)E9%]I9',@($%R<F%Y(&]F
M(&ED<R!T;R!S;W)T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?;F%M
M92`@("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@
M*B!`<&%R86T@87)R87D@)'-O<G1B>5]K97D@("`@($%T=')I8G5T92!K97D@
M=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1D:7)E
M8W1I;VX@("`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`P("T@87-C96YD:6YG"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`M(&1E<V-E;F1I;F<*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!3;W)T960@:61S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S;W)T0GE!='1R:6)U=&5S*"1U;F]R9&5R961?:61S
M+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@
M("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;W0@<W5P
M<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE(&1A
M=&$@:6X@86X@;V)J96-T+B!$;V5S(&YO="!C:&%N9V4@=&AE(&]B:F5C="=S
M"B`@("`@*B!P87)E;G0@;W(@;F%M92P@:G5S="!S97)I86QI>F5D(&1A=&$@
M;W(@871T<FEB=71E<RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@1&%T851R964@)&]B:F5C="`@02!$871A5')E92!O
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T941A=&$H)&]B:F5C
M="D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G;F]T
M('-U<'!O<G1E9"<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!T=V\@
M;V)J96-T<R!B>2!T:&5I<B!O<F1E<B!F:65L9"P@86YD(&EF('1H870@:7,@
M=&AE('-A;64L"B`@("`@*B!A;'!H86)E=&EC86QL>2`H8V%S92!I;G-E;G-I
M=&EV92D@8GD@;F%M92X*("`@("`J"B`@("`@*B!9;W4@;F5V97(@8V%L;"!T
M:&ES(&9U;F-T:6]N.R!I="=S('5S960@:6X@=6%S;W)T*"D@8V%L;',N($1O
M"B`@("`@*B!.3U0@=7-E('5S;W)T*"D[('EO=2=L;"!L;W-E(&ME>2`]/B!V
M86QU92!A<W-O8VEA=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1A("!4:&4@9FER<W0@;V)J96-T"B`@("`@*B!`<&%R86T@87)R87D@)&(@
M(%1H92!S96-O;F0@;V)J96-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("`Q(&EF("1A('-H;W5L9"!B92!F:7)S="P*("`@("`J("`@("`@("`@
M("`@("`@("`M,2!I9B`D8B!S:&]U;&0@8F4@9FER<W0L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(#`@:68@=&AE>2!A<F4@96YT:7)E;'D@97%U86PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;7`H)&$L("1B*0H@("`@>PH@("`@("`@
M(&EF("@D85LG;W)D97(G72`^("1B6R=O<F1E<B==*2!["B`@("`@("`@("`@
M(')E='5R;B`Q.PH@("`@("`@('T@96QS96EF("@D85LG;W)D97(G72`\("1B
M6R=O<F1E<B==*2!["B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@<W1R8V%S96-M<"@D85LG;F%M
M92==+"`D8ELG;F%M92==*3L*("`@("`@("!]"B`@("!]"@H@("`@("\J*@H@
M("`@("H@4V]R=',@='=O(&]B:F5C=',@8GD@=&AE:7(@<V]R=&5R(&AA<V@@
M9FEE;&0N"B`@("`@*@H@("`@("H@66]U(&YE=F5R(&-A;&P@=&AI<R!F=6YC
M=&EO;CL@:70G<R!U<V5D(&EN('5A<V]R="@I(&-A;&QS+B!$;R!.3U0@=7-E
M"B`@("`@*B!U<V]R="@I.R!Y;W4G;&P@;&]S92!K97D@/3X@=F%L=64@87-S
M;V-I871I;VYS+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&$@(%1H92!F:7)S="!O8FIE8W0*
M("`@("`J($!P87)A;2!A<G)A>2`D8B`@5&AE('-E8V]N9"!O8FIE8W0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@:68@)&$@<VAO=6QD(&)E
M(&9I<G-T+`H@("`@("H@("`@("`@("`@("`@("`@("TQ(&EF("1B('-H;W5L
M9"!B92!F:7)S="P*("`@("`J("`@("`@("`@("`@("`@("`@,"!I9B!T:&5Y
M(&%R92!E;G1I<F5L>2!E<75A;"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-M
M<%-O<G1E9"@D82P@)&(I"B`@("!["B`@("`@("`@:68@*"1A6R=S;W)T97(G
M75LD=&AI<RT^7W-O<G1(87-H72`\("1B6R=S;W)T97(G75LD=&AI<RT^7W-O
M<G1(87-H72D@>PH@("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!$
M871A5')E92!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!$871A5')E92!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@5&AI<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D
M<FEV97(@*"1D<FEV97(I+B!4:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D9')I=F5R
M(&ES(&%N(&%R<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H
M96X@=V4@=VEL;"!L;V]K(&EN("1D<FEV97);,%TO;&EB+T1A=&%4<F5E+R!F
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@<W5B8VQA<W,@
M:6UP;&5M96YT871I;VX@;F%M960@)&1R:79E<ELQ72YP:'`N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D
M9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI
M9VAT(&YE960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@2&5R92P@
M=V4@;F5E9"`G9W)O=7`G(#T@82!S=')I;F<@=&AA="!D969I;F5S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@=&]P+6QE=F5L(&=R;W5P<R!O9B!O
M8FIE8W1S+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R964@(%1H92!N
M97=L>2!C<F5A=&5D(&-O;F-R971E($1A=&%4<F5E(&EN<W1A;F-E+"!O<B!F
M86QS90H@("`@("H@("`@("`@("`@("`@("`@("`@;VX@86X@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@
M/2!N=6QL*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I
M=F5R*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A=&%T
M<F5E)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH
M)&1R:79E<BDI('L*("`@("`@("`@("`@)&1R:79E<B`]("=N=6QL)SL*("`@
M("`@("!]"@H@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O1&%T851R964O
M)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@)&-L87-S(#T@)T1A=&%4
M<F5E7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L
M87-S*2D@>PH@("`@("`@("`@("`D9'0@/2`F;F5W("1C;&%S<R@D<&%R86US
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9'0@/2!014%2.CIR
M86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G
M(&YO="!F;W5N9"XG*3L*("`@("`@("!]"B`*("`@("`@("!R971U<FX@)&1T
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@1&%T851R964@:6YS=&%N8V4@8F%S
M960@;VX*("`@("`J("1D<FEV97(N"B`@("`@*@H@("`@("H@270@=VEL;"!O
M;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!$871A5')E92!I;G-T
M86YC92!W:71H('1H92!S86UE"B`@("`@*B!P87)A;65T97)S(&-U<G)E;G1L
M>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I
M9B!M=6QT:7!L92!$871A5')E92!S;W5R8V5S("AA;F0L('1H=7,L(&UU;'1I
M<&QE"B`@("`@*B!$871A5')E92!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z
M("1V87(@/2`F1&%T851R964Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9')I=F5R("!4>7!E(&]F(&-O;F-R971E($1A=&%4
M<F5E('-U8F-L87-S('1O(')E='5R;BP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!B87-E9"!O;B!S=&]R86=E(&1R:79E<B`H)&1R:79E<BDN(%1H
M92!C;V1E(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9'EN86UI
M8V%L;'D@:6YC;'5D960N($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("!L;V]K(&EN("1D<FEV97);
M,%TO;&EB+T1A=&%4<F5E+R!F;W(@<W5B8VQA<W,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=
M+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($1A=&%4<F5E("!4:&4@8V]N8W)E=&4@1&%T851R964@<F5F97)E;F-E+"!O
M<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I
M;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T
M86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES7VYU;&PH)'!A<F%M<RDI('L*("`@
M("`@("`@("`@)'!A<F%M<R`]($AO<F1E.CIG971$<FEV97)#;VYF:6<H)V1A
M=&%T<F5E)RP@)&1R:79E<BD["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T
M=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F1&%T851R964Z
M.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*"B\J
M*@H@*B!#;&%S<R!T:&%T(&-A;B!B92!E>'1E;F1E9"!T;R!S879E(&%R8FET
M<F%R>2!I;F9O<FUA=&EO;B!A<R!P87)T(&]F(&$@<W1O<F5D"B`J(&]B:F5C
M="X*("H*("H@0&%U=&AO<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I
M9V9O;W0N8V]M/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E
M($AO<F1E7T1A=&%4<F5E"B`J+PIC;&%S<R!$871A5')E94]B:F5C="!["@H@
M("`@+RHJ"B`@("`@*B!4:&ES(&]B:F5C="=S($1A=&%4<F5E(&EN<W1A;F-E
M+@H@("`@("H*("`@("`J($!V87(@1&%T851R964*("`@("`J+PH@("`@=F%R
M("1D871A=')E93L*"B`@("`O*BH*("`@("`J($ME>2UV86QU92!H87-H('1H
M870@=VEL;"!B92!S97)I86QI>F5D+@H@("`@("H*("`@("`J($!S964@9V5T
M1&%T82@I"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9&%T
M82`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@=6YI<75E(&YA;64@
M;V8@=&AI<R!O8FIE8W0N"B`@("`@*B!4:&5S92!N86UE<R!H879E('1H92!S
M86UE(')E<75I<F5M96YT<R!A<R!O=&AE<B!O8FIE8W0@;F%M97,@+2!T:&5Y
M(&UU<W0*("`@("`J(&)E('5N:7%U92P@971C+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D;F%M93L*"B`@("`O*BH*("`@
M("`J($EF('1H:7,@;V)J96-T(&AA<R!O<F1E<FEN9R!D871A+"!S=&]R92!I
M="!H97)E+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)&]R9&5R(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($1A=&%4<F5E
M3V)J96-T(&-O;G-T<G5C=&]R+@H@("`@("H@2G5S="!S971S('1H92`D;F%M
M92!P87)A;65T97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&]B:F5C="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A
M5')E94]B:F5C="@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^<V5T3F%M
M92@D;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92![0&QI
M;FL@1&%T851R965](&EN<W1A;F-E('5S960@=&\@<F5T<FEE=F4@=&AI<R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E("1D871A=')E
M92`@02![0&QI;FL@1&%T851R965](&EN<W1A;F-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971$871A5')E92@F)&1A=&%T<F5E*0H@("`@>PH@("`@("`@
M("1T:&ES+3YD871A=')E92`]("8D9&%T871R964["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!N86UE(&]F('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG(%1H92!O8FIE8W0@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YN86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@
M;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!.3U1%.B!5<V4@
M=VET:"!C875T:6]N+B!4:&ES(&UA>2!T:')O=R!O=70@;V8@<WEN8R!T:&4@
M8V%C:&5D(&1A=&%T<F5E"B`@("`@*B!T86)L97,@:68@;F]T('5S960@<')O
M<&5R;'DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&YA;64@=&\@<V5T('1H:7,@;V)J96-T)W,@;F%M92!T;RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T3F%M92@D;F%M92D*("`@('L*("`@("`@("`D=&AI
M<RT^;F%M92`]("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@<VAO<G0@;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J($9O<B!D:7-P
M;&%Y('!U<G!O<V5S(&]N;'DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!O8FIE8W0G<R!S:&]R="!N86UE+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9713:&]R=$YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B!$871A
M5')E93HZ9V5T4VAO<G1.86UE*"1T:&ES+3YN86UE*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E=',@=&AE($E$(&]F('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;V)J96-T)W,@240N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$ED*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F1A=&%T<F5E+3YG971)9"@D=&AI<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!D871A(&%R<F%Y+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!I;G1E<FYA;"!D871A(&%R<F%Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971$871A*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!D
M871A(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@5&AE(&1A
M=&$@87)R87D@=&\@<W1O<F4@:6YT97)N86QL>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T1&%T82@D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^9&%T
M82`]("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;W)D
M97(@;V8@=&AI<R!O8FIE8W0@:6X@:71S(&]B:F5C="!C;VQL96-T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1O<F1E<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971/<F1E<B@D;W)D97(I"B`@("!["B`@("`@("`@)'1H
M:7,M/F]R9&5R(#T@)&]R9&5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&ES(&]B:F5C="=S('!A<F5N="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;&%S<R`@(%-U8F-L87-S(&]F($1A=&%4<F5E3V)J96-T
M('1O('5S92X@1&5F875L=',@=&\*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@1&%T851R965/8FIE8W0N($YU;&P@9F]R8V5S('1H92!D<FEV97(@
M=&\@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;G1O('1H
M92!A='1R:6)U=&5S('1A8FQE('1O(&1E=&5R;6EN92!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@=7-E+B!)9B!N;VYE
M(&ES(&9O=6YD(&ET('5S97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@1&%T851R965/8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A
M5')E94]B:F5C="`@5&AI<R!O8FIE8W0G<R!P87)E;G0*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F=E=%!A<F5N="@D8VQA<W,@/2`G1&%T851R965/8FIE8W0G
M*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES+3YD871A=')E92T^9V5T4&%R
M96YT*"1T:&ES*3L*("`@("`@("!I9B`H:7-?82@D:60L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD871A=')E92T^9V5T3V)J96-T0GE)9"@D:60L
M("1C;&%S<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8VAI
M;&0@;V8@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("`@("`@(%1H92!C:&EL9"=S(&YA;64N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D875T;V-R96%T92`@268@=')U92!A;F0@;F\@8VAI;&0@
M=VET:"!T:&4@9VEV96X@;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&5X:7-T<RP@;VYE(&=E=',@8W)E871E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=$-H:6QD*"1N86UE+"`D875T;V-R96%T92`]('1R
M=64I"B`@("!["B`@("`@("`@)&YA;64@/2`D=&AI<RT^9V5T4VAO<G1.86UE
M*"D@+B`G.B<@+B`D;F%M93L*"B`@("`@("`@+RH@268@=&AE(&-H:6QD('-H
M;W5L9&XG="!G970@8W)E871E9"P@=V4@9&]N)W0@8VAE8VL@9F]R(&ET<PH@
M("`@("`@("`J(&5X:7-T86YC92!T;R!R971U<FX@=&AE(")N;W0@9F]U;F0B
M(&5R<F]R(&]F"B`@("`@("`@("H@9V5T3V)J96-T*"DN("HO"B`@("`@("`@
M:68@*"$D875T;V-R96%T92!\?"`D=&AI<RT^9&%T871R964M/F5X:7-T<R@D
M;F%M92DI('L*("`@("`@("`@("`@)&-H:6QD(#T@)B1T:&ES+3YD871A=')E
M92T^9V5T3V)J96-T*"1N86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D8VAI;&0@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1N86UE*3L*("`@
M("`@("`@("`@)&-H:6QD+3YS971$871A5')E92@D=&AI<RT^9&%T871R964I
M.PH@("`@("`@("`@("`D=&AI<RT^9&%T871R964M/F%D9"@D8VAI;&0I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C:&EL9#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-A=F5S(&%N>2!C:&%N9V5S('1O('1H:7,@;V)J96-T('1O
M('1H92!B86-K96YD('!E<FUA;F5N=&QY+B!.97<@;V)J96-T<PH@("`@("H@
M87)E(&%D9&5D(&EN<W1E860N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N?%!%05)?17)R;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V%V92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YD871A=')E92T^97AI<W1S*"1T:&ES*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F1A=&%T<F5E+3YU<&1A=&5$871A*"1T:&ES*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F1A=&%T<F5E
M+3YA9&0H)'1H:7,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($1E;&5T92!T:&ES(&]B:F5C="!F<F]M('1H92!B86-K96YD('!E<FUA;F5N
M=&QY+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R
M("!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E;&5T92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A=')E
M92T^<F5M;W9E*"1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@
M;VYE(&]F('1H92!A='1R:6)U=&5S(&]F('1H92!O8FIE8W0L(&]R(&YU;&P@
M:68@:70@:7-N)W0@9&5F:6YE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A='1R:6)U=&4@(%1H92!A='1R:6)U=&4@=&\@9V5T+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!V86QU92!O9B!T:&4@871T<FEB
M=71E+"!O<B!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)&%T=')I
M8G5T92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/F1A=&%;
M)&%T=')I8G5T95TI"B`@("`@("`@("`@(#\@)'1H:7,M/F1A=&%;)&%T=')I
M8G5T95T*("`@("`@("`@("`@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!O;F4@;V8@=&AE(&%T=')I8G5T97,@;V8@=&AE(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R:6)U=&4@(%1H92!A
M='1R:6)U=&4@=&\@<V5T+@H@("`@("H@0'!A<F%M(&UI>&5D("1V86QU92`@
M("`@("!4:&4@=F%L=64@9F]R("1A='1R:6)U=&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E="@D871T<FEB=71E+"`D=F%L=64I"B`@("!["B`@("`@("`@
M)'1H:7,M/F1A=&%;)&%T=')I8G5T95T@/2`D=F%L=64["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O4&5R;7,N<&AP````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,S$R,C4@,3`U,34T,S0Q-#`@,#(Q,30Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*BH@17AI<W1E;F-E(&]F(&]B:F5C="!I<R!K;F]W;B`M(&]B:F5C="!I
M<R!S:&]W;B!T;R!U<V5R+B`J+PID969I;F4H)U!%4DU37U-(3U<G+"`R*3L*
M"B\J*B!#;VYT96YT<R!O9B!T:&4@;V)J96-T(&-A;B!B92!R96%D+B`J+PID
M969I;F4H)U!%4DU37U)%040G+"`T*3L*"B\J*B!#;VYT96YT<R!O9B!T:&4@
M;V)J96-T(&-A;B!B92!E9&ET960N("HO"F1E9FEN92@G4$5235-?141)5"<L
M(#@I.PH*+RHJ(%1H92!O8FIE8W0@8V%N(&)E(&1E;&5T960N("HO"F1E9FEN
M92@G4$5235-?1$5,151%)RP@,38I.PH*+RHJ"B`J($$@8FET;6%S:R!O9B!A
M;&P@<&]S<VEB;&4@<&5R;6ES<VEO;B!V86QU97,N(%5S969U;"!F;W(*("H@
M<F5M;W9E6'AX4&5R;6ES<VEO;B@I+"!U;G-E=%!E<FTH*2P@971C+@H@*B\*
M9&5F:6YE*"=015)-4U]!3$PG+"!015)-4U]32$]7('P@4$5235-?4D5!1"!\
M(%!%4DU37T5$250@?"!015)-4U]$14Q%5$4I.PH*+RHJ"B`J(%1H92!097)M
M<SHZ(&-L87-S('!R;W9I9&5S('1H92!(;W)D92!P97)M:7-S:6]N<R!S>7-T
M96TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!E<FUS+U!E<FUS+G!H<"QV
M(#$N.#`N,3`N.2`R,#`V+S`U+S`U(#`T.C`X.C4Y('-E;'-K>2!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U
M=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7U!E<FUS"B`J+PIC;&%S
M<R!097)M<R!["@H@("`@+RHJ"B`@("`@*B!#86-H97,@:6YF;W)M871I;VX@
M86)O=70@87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!L:6-A=&EO;E!E<FUI
M<W-I;VYS.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@879A:6QA8FQE
M('!E<FUI<W-I;VYS(&9O<B!A(&=I=F5N(&QE=F5L+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I
M;&%B;&4@<&5R;6ES<VEO;G,@86YD('1H96ER('1I=&QE<R!O<@H@("`@("H@
M("`@("`@("`@("`@("`@9F%L<V4@:68@;F]T('-U8B!P97)M:7-S:6]N<R!E
M>&ES="!F;W(@=&AI<R!L979E;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M079A:6QA8FQE*"1N86UE*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T
M<GD["@H@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@
M+RH@3F\@;F%M92!P87-S960L('-O('1O<"!L979E;"!P97)M:7-S:6]N<R!A
M<F4@<F5Q=65S=&5D+B!4:&5S90H@("`@("`@("`@("`@*B!C86X@;VYL>2!B
M92!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@("`@("1A<'!S(#T@)')E9VES
M=')Y+3YL:7-T07!P<RAA<G)A>2@G;F]T;V]L8F%R)RP@)V%C=&EV92<L("=H
M:61D96XG*2P@=')U92D["B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME
M>7,H)&%P<',I(&%S("1A<'`I('L*("`@("`@("`@("`@("`@("1A<'!S6R1A
M<'!=(#T@)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2`N("<@*"<@+B`D
M87!P("X@)RDG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&%S;W)T*"1A
M<'!S*3L*("`@("`@("`@("`@<F5T=7)N("1A<'!S.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\J($YA;64@:&%S(&)E96X@<&%S<V5D+"!E>'!L
M;V1E('1H92!N86UE('1O(&=E="!A;&P@=&AE(&QE=F5L<R!I;@H@("`@("`@
M("`@("`@*B!P97)M:7-S:6]N(&)E:6YG(')E<75I<W1E9"P@=VET:"!T:&4@
M87!P(&%S('1H92!F:7)S="!L979E;"X@*B\*("`@("`@("`@("`@)&QE=F5L
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1L979E;',@/2!E>'!L;V1E*"<Z
M)RP@)&YA;64I.PH*("`@("`@("`@("`@+RH@1FER<W0@;&5V96P@:7,@86QW
M87ES(&%P<"X@*B\*("`@("`@("`@("`@)&%P<"`]("1L979E;'-;,%T["@H@
M("`@("`@("`@("`O*B!2971U<FX@96UP='D@:68@;F\@87!P(&1E9FEN960@
M05!)(&UE=&AO9"!F;W(@<')O=FED:6YG"B`@("`@("`@("`@("`J('!E<FUI
M<W-I;VX@:6YF;W)M871I;VXN("HO"B`@("`@("`@("`@(&EF("@A)')E9VES
M=')Y+3YH87--971H;V0H)W!E<FUS)RP@)&%P<"DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+RH@0V%L;"!T:&4@87!P)W,@<&5R;6ES<VEO;B!F=6YC=&EO;B!T;R!R971U
M<FX@=&AE('!E<FUI<W-I;VYS"B`@("`@("`@("`@("`J('-P96-I9FEC('1O
M('1H:7,@87!P+B`J+PH@("`@("`@("`@("`D<&5R;7,@/2`D=&AI<RT^9V5T
M07!P;&EC871I;VY097)M:7-S:6]N<R@D87!P*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)'!E<FUS+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'!E<FUS.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@("\J
M($=E="!T:&4@<&%R="!O9B!T:&4@87!P)W,@<&5R;6ES<VEO;G,@8F%S960@
M;VX@=&AE('!E<FUI<W-I;VX*("`@("`@("`@("`@("H@;F%M92!R97%U97-T
M960N("HO"B`@("`@("`@("`@("1C:&EL9')E;B`]($AO<F1E7T%R<F%Y.CIG
M971%;&5M96YT*"1P97)M<ULG=')E92==+"`D;&5V96QS*3L*("`@("`@("`@
M("`@:68@*"1C:&EL9')E;B`]/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@
M("%I<U]A<G)A>2@D8VAI;&1R96XI('Q\"B`@("`@("`@("`@("`@("`A8V]U
M;G0H)&-H:6QD<F5N*2D@>PH@("`@("`@("`@("`@("`@+RH@3F\@87)R87D@
M;V8@8VAI;&1R96X@879A:6QA8FQE(&9O<B!T:&ES('!E<FUI<W-I;VX@;F%M
M92X@*B\*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'!E<FUS7VQI<W0@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W)E86-H("@D8VAI;&1R96X@87,@)'!E<FU?:V5Y(#T^("1P
M97)M7W9A;"D@>PH@("`@("`@("`@("`@("`@)'!E<FUS7VQI<W1;)'!E<FU?
M:V5Y72`]("1P97)M<ULG=&ET;&4G75LD;F%M92`N("<Z)R`N("1P97)M7VME
M>5T["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1P97)M<U]L
M:7-T.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE('-H;W)T(&YA;64@;V8@86X@;V)J96-T+"!T:&4@;&%S="!P;W)T:6]N
M(&]F('1H92!F=6QL(&YA;64N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!O
M8FIE8W0G<R!S:&]R="!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M:&]R=$YA;64H)&YA;64I"B`@("!["B`@("`@("`@+RH@268@=&AE<F4@87)E
M('-E=F5R86P@8V]M<&]N96YT<R!T;R!T:&4@;F%M92P@97AP;&]D92!A;F0*
M("`@("`@("`@*B!G970@=&AE(&QA<W0@;VYE+"!O=&AE<G=I<V4@:G5S="!R
M971U<FX@=&AE(&YA;64N("HO"B`@("`@("`@:68@*'-T<G!O<R@D;F%M92P@
M)SHG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1M<"`](&5X<&QO9&4H
M)SHG+"`D;F%M92D["B`@("`@("`@("`@(')E='5R;B!A<G)A>5]P;W`H)'1M
M<"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1N86UE
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N(&$@<&5R
M;6ES<VEO;B!N86UE+"!R971U<FYS('1H92!T:71L92!F;W(@=&AA="!P97)M
M:7-S:6]N(&)Y"B`@("`@*B!L;V]K:6YG(&ET('5P(&EN('1H92!A<'!L:6-A
M=&EO;G,G<R!P97)M:7-S:6]N(&%P:2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@<&5R;6ES<VEO;G,G<R!N86UE+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&ET;&4@9F]R('1H92!P97)M
M:7-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714:71L92@D;F%M92D*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D;&5V
M96QS(#T@97AP;&]D92@G.B<L("1N86UE*3L*("`@("`@("!I9B`H8V]U;G0H
M)&QE=F5L<RD@/3T@,2D@>PH@("`@("`@("`@("!R971U<FX@)')E9VES=')Y
M+3YG970H)VYA;64G+"`D;F%M92D@+B`G("@G("X@)&YA;64@+B`G*2<["B`@
M("`@("`@?0H@("`@("`@("1P97)M(#T@87)R87E?<&]P*"1L979E;',I.PH*
M("`@("`@("`O*B!&:7)S="!L979E;"!I<R!A;'=A>7,@87!P+B`J+PH@("`@
M("`@("1A<'`@/2`D;&5V96QS6S!=.PH*("`@("`@("`O*B!2971U<FX@96UP
M='D@:68@;F\@87!P(&1E9FEN960@05!)(&UE=&AO9"!F;W(@<')O=FED:6YG
M('!E<FUI<W-I;VX*("`@("`@("`@*B!I;F9O<FUA=&EO;BX@*B\*("`@("`@
M("!I9B`H(21R96=I<W1R>2T^:&%S365T:&]D*"=P97)M<R<L("1A<'`I*2![
M"B`@("`@("`@("`@(')E='5R;B!097)M<SHZ9V5T4VAO<G1.86UE*"1N86UE
M*3L*("`@("`@("!]"@H@("`@("`@("1A<'!?<&5R;7,@/2`D=&AI<RT^9V5T
M07!P;&EC871I;VY097)M:7-S:6]N<R@D87!P*3L*"B`@("`@("`@<F5T=7)N
M(&ES<V5T*"1A<'!?<&5R;7-;)W1I=&QE)UU;)&YA;65=*0H@("`@("`@("`@
M("`_("1A<'!?<&5R;7-;)W1I=&QE)UU;)&YA;65=("X@)R`H)R`N($1A=&%4
M<F5E.CIG9713:&]R=$YA;64H)&YA;64I("X@)RDG"B`@("`@("`@("`@(#H@
M1&%T851R964Z.F=E=%-H;W)T3F%M92@D;F%M92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T('!E<FUI<W-I;VYS
M(&EM<&QE;65N=&5D(&)Y(&%N(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J
M($!S:6YC92!(;W)D92`S+C$*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A<'`@($%N(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@2&%S:"!W:71H('!E<FUI<W-I;VYS(&EN9F]R;6%T:6]N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!<'!L:6-A=&EO;E!E<FUI<W-I
M;VYS*"1A<'`I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V%P
M<&QI8V%T:6]N4&5R;6ES<VEO;G-;)&%P<%TI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?87!P;&EC871I;VY097)M:7-S:6]N<ULD87!P72`]("1'3$]"04Q3
M6R=R96=I<W1R>2==+3YC86QL0GE086-K86=E*"1A<'`L("=P97)M<R<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?87!P;&EC871I;VY0
M97)M:7-S:6]N<ULD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@82!N97<@<&5R;6ES<VEO;G,@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%!E<FUI<W-I;VYS("!!(&YE=R!P97)M:7-S
M:6]N<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N("9N97=097)M:7-S
M:6]N*"1N86UE*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@4&5R;6ES<VEO;B!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T
M:&4@;F%M960@<&5R;6ES<VEO;BP*("`@("`J('=I=&@@=&AE('5S97)S(&%N
M9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!P
M97)M:7-S:6]N('1O(')E=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T4&5R;6ES<VEO;B@D;F%M92D*("`@('L*("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")4:&4@861M:6YI<W1R871O<B!N965D<R!T;R!C
M;VYF:6=U<F4@82!P97)M86YE;G0@4&5R;6ES<VEO;G,@8F%C:V5N9"!I9B!Y
M;W4@=V%N="!T;R!U<V4@4&5R;6ES<VEO;G,N(BDI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(%!E<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O
M;F1I;F<@=&\@=&AE(&=I=F5N('5N:7%U92!)1"P@=VET:`H@("`@("H@=&AE
M('5S97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ
M=64@240@;V8@=&AE('!E<FUI<W-I;VX@=&\@<F5T<FEE=F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9G971097)M:7-S:6]N0GE)9"@D8VED*0H@("`@>PH@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES
M=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S
M:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB
M*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<&5R;6ES<VEO;B!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B!4:&4@<&5R;6ES<VEO;B!M=7-T
M(&9I<G-T"B`@("`@*B!B92!C<F5A=&5D('=I=&@@4&5R;3HZ;F5W4&5R;6ES
M<VEO;B@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D
M960@=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@4&5R;6ES<VEO;B`D<&5R;2`@5&AE(&YE=R!P
M97)M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&5R;6ES<VEO
M;B@F)'!E<FTI"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B5&AE(&%D;6EN:7-T<F%T;W(@;F5E9',@=&\@8V]N9FEG=7)E(&$@
M<&5R;6%N96YT(%!E<FUI<W-I;VYS(&)A8VME;F0@:68@>6]U('=A;G0@=&\@
M=7-E(%!E<FUI<W-I;VYS+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V97,@82!P97)M:7-S:6]N(&9R;VT@=&AE('!E<FUI<W-I;VYS('-Y<W1E
M;2!P97)M86YE;G1L>2X*("`@("`J"B`@("`@*B!`<&%R86T@4&5R;6ES<VEO
M;B`D<&5R;2`@5&AE('!E<FUI<W-I;VX@=&\@<F5M;W9E+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&9O<F-E("`@($9O<F-E('1O(')E;6]V92!E=F5R>2!C
M:&EL9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E4&5R;6ES<VEO;B@F
M)'!E<FTL("1F;W)C92`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O
M(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF
M('EO=2!W86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6YD<R!O=70@=VAA="!R:6=H=',@=&AE(&=I=F5N('5S
M97(@:&%S('1O('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D<&5R;6ES<VEO;B`@5&AE(&9U;&P@<&5R;6ES<VEO;B!N86UE(&]F
M('1H92!O8FIE8W0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8VAE8VL@=&AE('!E<FUI<W-I;VYS(&]F+"!O<B!T:&4@4&5R;6ES<VEO
M;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@(%1H92!U<V5R('1O(&-H
M96-K(&9O<BX@1&5F875L=',@=&\@=&AE(&-U<G)E;G0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=7-E<BX*("`@("`J($!P87)A;2!S=')I
M;F<@)&-R96%T;W(@("`@5&AE('5S97(@=VAO(&-R96%T960@=&AE(&5V96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($$@8FET;6%S:R!O9B!P
M97)M:7-S:6]N<R!T:&4@=7-E<B!H87,L(&9A;'-E(&EF('1H97)E"B`@("`@
M*B`@("`@("`@("`@("`@("!A<F4@;F]N92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VXL("1U<V5R(#T@;G5L;"P@
M)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I
M9W5R92!A('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W
M86YT('1O('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!U;FEQ=64@:61E;G1I9FEE<B!O9B!T:&ES('!E
M<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUI<W-I;VX@)'!E
M<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N(&]B:F5C="!T;R!G970@=&AE($E$
M(&]F+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE('5N:7%U
M92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&5R;6ES<VEO;DED*"1P
M97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E1H92!A9&UI;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A
M('!E<FUA;F5N="!097)M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O
M('5S92!097)M:7-S:6]N<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&
M:6YD<R!O=70@:68@=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<FEG:'1S
M('1O('1H92!G:79E;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N('1O(&-H96-K+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97(@("`@("`@(%1H92!U<V5R('1O
M(&-H96-K(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@
M("!4:&4@<&5R;6ES<VEO;B!L979E;"!N965D960@9F]R(&%C8V5S<RX*("`@
M("`J($!P87)A;2!S=')I;F<@("1C<F5A=&]R("`@("!4:&4@8W)E871O<B!O
M9B!T:&4@979E;G0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@:68@=&AE('5S97(@:&%S('1H92!S<&5C:69I960@<&5R;6ES<VEO;G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'!E<FUI<W-I
M;VXL("1U<V5R+"`D<&5R;2P@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K
M<R!I9B!A('!E<FUI<W-I;VX@97AI<W1S(&EN('1H92!S>7-T96TN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI
M<W-I;VX@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H92!P97)M:7-S:6]N(&5X:7-T<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@97AI<W1S*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L
M:7-T(&]F('!A<F5N="!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C:&EL9"`@5&AE(&YA;64@;V8@=&AE(&-H:6QD('1O(')E
M=')I979E('!A<F5N=',@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($$@:&%S:"!W:71H(&%L;"!P87)E;G1S(&EN(&$@=')E92!F;W)M870N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F5N=',H)&-H:6QD*0H@("`@
M>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!A9&UI
M;FES=')A=&]R(&YE961S('1O(&-O;F9I9W5R92!A('!E<FUA;F5N="!097)M
M:7-S:6]N<R!B86-K96YD(&EF('EO=2!W86YT('1O('5S92!097)M:7-S:6]N
M<RXB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!P97)M
M:7-S:6]N<R!O9B!T:&4@<WES=&5M(&EN(&$@=')E92!F;W)M870N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H('=I=&@@86QL('!E<FUI
M<W-I;VYS(&EN(&$@=')E92!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%1R964H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!H87-H(&]F('1H92!A=F%I
M;&%B;&4@<&5R;6ES<VEO;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@5&AE(&%V86EL86)L92!P97)M:7-S:6]N<R!A<R!A(&AA<V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!E<FUS07)R87DH*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>2A015)-4U]32$]7(#T^(%\H(E-H;W<B*2P*("`@("`@
M("`@("`@("`@("`@("`@4$5235-?4D5!1"`]/B!?*")296%D(BDL"B`@("`@
M("`@("`@("`@("`@("`@(%!%4DU37T5$250@/3X@7R@B161I="(I+`H@("`@
M("`@("`@("`@("`@("`@("!015)-4U]$14Q%5$4@/3X@7R@B1&5L971E(BDI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:6YT96=E<B!V86QU
M92!O9B!P97)M:7-S:6]N<R!R971U<FYS(&%N(&%R<F%Y"B`@("`@*B!R97!R
M97-E;G1A=&EO;B!O9B!T:&4@:6YT96=E<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D:6YT("!4:&4@:6YT96=E<B!R97!R97-E;G1A=&EO;B!O
M9B!P97)M:7-S:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YT96=E<E1O
M07)R87DH)&EN="D*("`@('L*("`@("`@("!S=&%T:6,@)&%R<F%Y(#T@87)R
M87DH*3L*("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1I;G1=*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&%R<F%Y6R1I;G1=.PH@("`@("`@('T*"B`@("`@
M("`@)&%R<F%Y6R1I;G1=(#T@87)R87DH*3L*"B`@("`@("`@+RH@1V5T('1H
M92!A=F%I;&%B;&4@<&5R;7,@87)R87DN("HO"B`@("`@("`@)'!E<FUS(#T@
M4&5R;7,Z.F=E=%!E<FUS07)R87DH*3L*"B`@("`@("`@+RH@3&]O<"!T:')O
M=6=H(&5A8V@@<&5R;2!A;F0@8VAE8VL@:68@:71S('9A;'5E(&ES(&EN8VQU
M9&5D(&EN('1H90H@("`@("`@("`J(&EN=&5G97(@<F5P<F5S96YT871I;VXN
M("HO"B`@("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1V86P@/3X@)&QA8F5L
M*2!["B`@("`@("`@("`@(&EF("@D:6YT("8@)'9A;"D@>PH@("`@("`@("`@
M("`@("`@)&%R<F%Y6R1I;G1=6R1V86Q=(#T@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A<G)A>5LD:6YT73L*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R
M971E(%!E<FUS(&EN<W1A;F-E(&)A<V5D(&]N("1D<FEV97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!T:&4@
M8V]N8W)E=&4@4&5R;7,@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@=&\@<F5T=7)N+B`@5&AE(&-L87-S(&YA;64@:7,@8F%S960@
M;VX@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('!E<FUS(&1R
M:79E<B`H)&1R:79E<BDN("!4:&4@8V]D92!I<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%!E<FUS?&)O;VQE86X@(%1H92!N97=L>2!C<F5A=&5D
M(&-O;F-R971E(%!E<FUS(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<B`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7VYU;&PH)&1R:79E<BDI('L*("`@("`@("`@("`@)'!E<FUS
M(#T@)FYE=R!097)M<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EN8VQU9&5?;VYC92`G2&]R9&4O4&5R;7,O)R`N("1D<FEV97(@+B`G+G!H
M<"<["B`@("`@("`@("`@("1C;&%S<R`]("=097)M<U\G("X@)&1R:79E<CL*
M("`@("`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@
M("`@("`@("`@("`D<&5R;7,@/2`F;F5W("1C;&%S<R@I.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!E<FUS(#T@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&5R;7,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R
M969E<F5N8V4@=&\@82!C;VYC<F5T92!097)M<R!I;G-T86YC92X*("`@("`J
M($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@4&5R
M;7,@:6YS=&%N8V4*("`@("`J(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@
M)E!E<FUS.CIS:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!R971U<FX@4&5R
M;7-\8F]O;&5A;B`@5&AE(&-O;F-R971E(%!E<FT@<F5F97)E;F-E+"!O<B!F
M86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O
M;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1P97)M.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1P97)M*2D@>PH@("`@("`@("`@("`D<&5R;2`]("9097)M<SHZ
M9F%C=&]R>2@A96UP='DH)$=,3T)!3%-;)V-O;F8G75LG9&%T871R964G75LG
M9')I=F5R)UTI(#\@)V1A=&%T<F5E)R`Z(&YU;&PI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1P97)M.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O36]B:6QE+G!H<```````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#<P-S,@,3`U,34T,S0Q-#`@
M,#(Q,C8W`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL95]C87)D(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L
M96UE;G0@>PH*("`@('9A<B`D7VYA;64["B`@("!V87(@)%]T:71L93L*("`@
M('9A<B`D7V9O<FT["B`@("!V87(@)%]E;&5M96YT<R`](&%R<F%Y*"D["B`@
M("!V87(@)%]S;V9T:V5Y<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M("!4:&4@;F%M92!O9B!T:&ES(&-A<F0N($-A;B!B92!U<V5D(&EN(&%N8VAO
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&QI;FMS+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&ET;&4@($EF(&$@<W1R:6YG(&ES('!R;W9I9&5D
M(&AE<F4L(&ET('=I;&P@8F4@9&ES<&QA>65D"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@:6X@=&AE($A434P@=&ET;&4@8F%R+"!R97-P96-T:79E
M;'D@<V]M97=H97)E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(%=!4"!D:7-P;&%Y+B!5<VEN9R!A('1I=&QE('EO=2!W:6QL(&YO<FUA
M;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:&%V92!T;R!S<&5N
M9"!O;F4@;V8@>6]U<B!F97<@;&EN97,@;VX@>6]U<B!705`*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!D:7-P;&%Y+B!#;VYS:61E<B!T:&%T('-O
M;64@5T%0('!H;VYE<R]31$LG<R!A;F0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!H86YD:&5L9"!D979I8V5S(&1O;B=T(&1I<W!L87D@=&AE('1I
M=&QE(&%T(&%L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE
M7V-A<F0H)&YA;64@/2!N=6QL+"`D=&ET;&4@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@("`@("1T:&ES+3Y?=&ET
M;&4@/2`D=&ET;&4["B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9"@F)&5L96UE
M;G0I"B`@("!["B`@("`@("`@<W1A=&EC("1L:6YK<V5T061D960["@H@("`@
M("`@(&EF("@A:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]E;&5M96YT
M)RDI('L*("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M26YV86QI9"!E;&5M96YT+B<I.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@('T@96QS96EF("AI<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B
M:6QE7W1E>'0G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT
M+"`G2&]R9&5?36]B:6QE7W1A8FQE)RD@?'P*("`@("`@("`@("`@("`@("`@
M:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]I;6%G92<I('Q\"B`@("`@
M("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?;&EN
M:R<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D
M95]-;V)I;&5?<&AO;F4G*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E
M;&5M96YT+"`G2&]R9&5?36]B:6QE7W)U;&4G*2D@>PH@("`@("`@("`@("`D
M8FQO8VL@/2`F;F5W($AO<F1E7TUO8FEL95]B;&]C:R@D96QE;65N="D["B`@
M("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;72`]("8D8FQO8VL["B`@("`@
M("`@?2!E;'-E:68@*&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?8FQO
M8VLG*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F)&5L
M96UE;G0["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&5L96UE;G0L("=(;W)D
M95]-;V)I;&5?9F]R;2<I*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]F;W)M*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@G0V%R9',@;6%Y(&]N;'D@8V]N=&%I;B!O;F4@1F]R;2!E
M;&5M96YT+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V5L96UE;G1S6UT@/2`F
M)&5L96UE;G0["B`@("`@("`@("`@("1T:&ES+3Y?9F]R;2`]("8D96QE;65N
M=#L*("`@("`@("!](&5L<V5I9B`H:7-?82@D96QE;65N="P@)TAO<F1E7TUO
M8FEL95]L:6YK<V5T)RDI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;&EN
M:W-E=$%D9&5D*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@G0V%R9',@;6%Y(&]N;'D@8V]N=&%I;B!O;F4@3&EN:W-E
M="!E;&5M96YT+B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D8FQO8VL@/2`F;F5W($AO<F1E
M7TUO8FEL95]B;&]C:R@D96QE;65N="D["B`@("`@("`@("`@("1T:&ES+3Y?
M96QE;65N='-;72`]("8D8FQO8VL["B`@("`@("`@("`@("1L:6YK<V5T061D
M960@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E<G)O
M<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@96QE;65N="!M=7-T(&)E(&EN
M<VED92!A;B!A<'!R;W!R:6%T92!C;VYT86EN97(@96QE;65N="XG*3L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D96QE;65N=#L*("`@('T*"B`@("!F=6YC=&EO;B!S;V9T:V5Y*"1U
M<FPL("1L86)E;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-O9G1K97ES6UT@
M/2!A<G)A>2@G=7)L)R`]/B`D=7)L+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=L86)E;"<@/3X@)&QA8F5L*3L*("`@('T*"GT*"B\J
M*@H@*B!(;W)D95]-;V)I;&4Z.@H@*@H@*B!(;W)D92!!4$D@9F]R(&=E;F5R
M871I;F<@36]B:6QE(&-O;G1E;G0N($EN8VQU9&5S(&YU;65R;W5S('5T:6QI
M='D*("H@9G5N8W1I;VYS+"!G96YE<F%L:7IE9"!E;&5M96YT(&-L87-S97,L
M(&%N9"!R96YD97)E<G,@9F]R(&UA<FMU<`H@*B!L86YG=6%G97,@:6YC;'5D
M:6YG(%=-3"P@2$1-3"P@86YD($-(5$U,+@H@*@H@*B!4:&ES(&-L87-S(&ES
M('1H92!T;W`@;&5V96P@8VQA<W,@;V8@86QL($AO<F1E7TUO8FEL92!C;&%S
M<V5S+B!9;W5R"B`J('!A9V4@<VAO=6QD(&-O;G-I<W0@;V8@97AA8W1L>2!O
M;F4@2&]R9&5?36]B:6QE(&]B:F5C="X@07!P<F]P<FEA=&4*("H@;6%R:W5P
M("T@26UO9&4L(%=-3"P@2$1-3"P@971C+B`M(&ES(&=E;F5R871E9"!B>2!T
M:&4@87!P<F]P<FEA=&4*("H@<F5N9&5R97(@;V)J96-T"B`J"B`J($1O(&YO
M="!O=F5R<W1U9F8@2&]R9&5?36]B:6QE(&]B:F5C=',N(%)E;65M8F5R('1H
M870@82!L;W0@;V8@5T%0"B`J(&-L:65N=',@8V%N;F]T(&AA;F1L92!M;W)E
M('1H86X@86)O=70@,30P,"!B>71E<R!O9B!C;VUP:6QE9"!D871A+@H@*@H@
M*B!%>&%M<&QE<SH*("H*("H@)&UY4&%G92`](&YE=R!(;W)D95]-;V)I;&4H
M*3L*("H@)&UY4&%G92`](&YE=R!(;W)D95]-;V)I;&4H)TUY(%=!4"!P86=E
M)RD["B`J("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"<G+"`G8V5N=&5R
M)RD["B`J"B`J("\O($UO<F4@<W1U9F8*("H*("H@)&UY4&%G92T^861D*"1M
M>51E>'0I.PH@*@H@*B`O+R!-;W)E(&ET96US"B`J"B`J("1M>5!A9V4M/G)E
M;F1E<B@I.PH@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-;V)I;&4O36]B:6QE
M+G!H<"QV(#$N,S(N,3`N.2`R,#`V+S`V+S(V(#`V.C(W.C(S('-E;'-K>2!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL92!E>'1E;F1S($AO<F1E7TUO8FEL95]C87)D('L*
M"B`@("!V87(@)%]T:71L93L*("`@('9A<B`D7V5L96UE;G1S(#T@87)R87DH
M*3L*("`@('9A<B`D7V-A<F1S(#T@87)R87DH*3L*("`@('9A<B`D7V1E8G5G
M(#T@9F%L<V4["@H@("`@+R\@1&5C:61E('=H971H97(@=&AE('-I;75L871O
M<B!D979I8V4@:7,@=&\@8F4@=7-E9"X@3VYL>2!A9F9E8W1S"B`@("`O+R!(
M5$U,(&)R;W=S97(@;W5T<'5T+@H@("`@=F%R("1?<VEM=6QA=&]R(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1I=&QE("!)9B!A('-T<FEN9R!I<R!P<F]V:61E
M9"!H97)E+"!I="!W:6QL(&)E(&1I<W!L87EE9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&EN('1H92!(5$U,('1I=&QE(&)A<BP@<F5S<&5C=&EV
M96QY('-O;65W:&5R92!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M('1H92!705`@9&ES<&QA>2X@57-I;F<@82!T:71L92!Y;W4@=VEL;"!N;W)M
M86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&AA=F4@=&\@<W!E
M;F0@;VYE(&]F('EO=7(@9F5W(&QI;F5S(&]N('EO=7(@5T%0"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@9&ES<&QA>2X@0V]N<VED97(@=&AA="!S
M;VUE(%=!4"!P:&]N97,O4T1+)W,@86YD"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@:&%N9&AE;&0@9&5V:6-E<R!D;VXG="!D:7-P;&%Y('1H92!T
M:71L92!A="!A;&PN"B`@("`@*B!`<&%R86T@<W1R:6YG("1A9V5N="`@268@
M<W!E8VEF:65D+"!U<V4@:6YS=&5A9"!O9B!(5%107U5315)?04=%3E0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL92@D=&ET;&4@/2!N=6QL
M+"`D86=E;G0@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D
M=&ET;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4[
M"B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T)R;W=S
M97(N<&AP)SL*("`@("`@("`D8G)O=W-E<B`]("9"<F]W<V5R.CIS:6YG;&5T
M;VXH)&%G96YT*3L*"B`@("`@("`@:68@*"1B<F]W<V5R+3YH87-&96%T=7)E
M*"=H=&UL)RDI('L*("`@("`@("`@("`@)&UL(#T@)VAT;6PG.PH@("`@("`@
M('T@96QS96EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G=VUL)RDI('L*("`@
M("`@("`@("`@)&UL(#T@)W=M;"<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&UL(#T@)VAT;6PG.PH@("`@("`@('T*"B`@("`@("`@<F5Q=6ER
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]-;V)I;&4O4F5N9&5R97(N
M<&AP)SL*("`@("`@("`D=&AI<RT^7W)E;F1E<F5R(#T@)DAO<F1E7TUO8FEL
M95]296YD97)E<CHZ<VEN9VQE=&]N*"1M;"P@)&)R;W=S97(I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9A9&0H)B1E;&5M96YT*0H@("`@>PH@("`@("`@(&EF
M("AI<U]A*"1E;&5M96YT+"`G2&]R9&5?36]B:6QE7V-A<F0G*2D@>PH@("`@
M("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@
M("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)UEO=2!C86YN
M;W0@;6EX($AO<F1E7TUO8FEL95]C87)D<R!A;F0@;W1H97(@96QE;65N=',@
M870@=&AE(&1E8VL@;&5V96PN)RD["B`@("`@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7W5S
M:6YG0V%R9',@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V-A<F1S6UT@
M/2`F)&5L96UE;G0["@H@("`@("`@("`@("!R971U<FX@)&5L96UE;G0["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M8V%R9',I*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES
M945R<F]R*"=9;W4@8V%N;F]T(&UI>"!(;W)D95]-;V)I;&5?8V%R9',@86YD
M(&]T:&5R(&5L96UE;G1S(&%T('1H92!D96-K(&QE=F5L+B<I.PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@<F5T=7)N('!A<F5N=#HZ861D*"1E;&5M96YT*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8W1I=F%T97,@=&AE(&)U:6QT+6EN
M(&1E=FEC92!S:6UU;&%T;W(@;VX@8FEG<V-R965N(&)R;W=S97)S+@H@("`@
M("H@5&AE(&1E=FEC92!S:6UU;&%T;W(@:7,@;VYL>2!F=6QL>2UF=6YC=&EO
M;F%L(&EN($EN=&5R;F5T"B`@("`@*B!%>'!L;W)E<BP@8F5C875S92!T:&4@
M;&%Y;W5T(')E<75I<F5S(&$@<V-R;VQL86)L92!T86)L90H@("`@("H@96QE
M;65N="X@3W1H97(@8G)O=W-E<G,@=VEL;"!F86EL('1O('-H;W<@8V]N=&5N
M="!O;B!P86=E<PH@("`@("H@;&]N9V5R('1H86X@82!S:6YG;&4@<V-R965N
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<V53:6UU;&%T;W(H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<VEM=6QA=&]R(#T@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($-R96%T97,@=&AE('!A9V4@:6X@=&AE(&%P<')O<')I871E
M(&UA<FMU<"!L86YG=6%G92X@1&5P96YD:6YG"B`@("`@*B!O;B!T:&4@<F5N
M9&5R97(@='EP92P@2%1-3"`H<'5R92!(5$U,+"!H86YD:&5L9&9R:65N9&QY
M($%V86YT1V\*("`@("`J($A434PL(&DM;6]D92!C2%1-3"P@34U,*2P@5TU,
M(&]R($A$34P@8V]D92!I<R!C<F5A=&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^7W)E;F1E<F5R+3YR
M96YD97(H)'1H:7,I.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E
M7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@
M(&9U;F-T:6]N($AO<F1E7TUO8FEL95]E;&5M96YT*"D*("`@('L*("`@('T*
M"B`@("!F=6YC=&EO;B!G970H)&%T=')I8G5T92D*("`@('L*("`@("`@("`D
M871T<B`]("=?)R`N("1A='1R:6)U=&4["B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3XD871T<BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3XD871T
M<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T*"1A='1R:6)U=&4L
M("1V86QU92D*("`@('L*("`@("`@("`D871T<B`]("=?)R`N("1A='1R:6)U
M=&4["B`@("`@("`@)'1H:7,M/B1A='1R(#T@)'9A;'5E.PH@("`@?0H*?0H*
M+RHJ"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?
M36]B:6QE7V9O<FU%;&5M96YT(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE
M;G0@>PH*("`@('9A<B`D7VYA;64["B`@("!V87(@)%]V86QU93L*("`@('9A
M<B`D7VQA8F5L.PH@("`@=F%R("1?<VEZ93L*("`@('9A<B`D7VUA>&QE;F=T
M:#L*("`@('9A<B`D7W1Y<&4["B`@("!V87(@)%]F;W)M870["B`@("!V87(@
M)%]M;V1E.PH*("`@("\J*@H@("`@("H@4V5T(&EN<'5T(&UO9&4O:7-T>6QE
M(&9O<B!J87!A;F5S92!-34PO:2UM;V1E(&1E=FEC97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6]D92`@26YP=70@;6]D92P@;VYE(&]F.@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@)V%L<&AA)R`H9&5F875L="D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("=K871A:V%N82<*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("=H:7)A9V%N82<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("=N=6UE<FEC)PH@("`@("HO"B`@("!F=6YC=&EO
M;B!S971-;V1E*"1M;V1E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6]D92`]
M("1M;V1E.PH*("`@("`@("`O+R!-87`@=&AE(&UO9&4@:6YT;R!A;B!A<'!R
M;W!R:6%T92!F;W)M870@<W1R:6YG+"!U<V5D(&9O<@H@("`@("`@("\O(%=-
M3"!A;F0@2$1-3"X@268@82!F;W)M870@<W1R:6YG('=A<R!P<F]V:61E9"!E
M87)L:65R+"!I=`H@("`@("`@("\O('=I;&P@8F4@;W9E<G=R:71T96XN"B`@
M("`@("`@<W=I=&-H("@D;6]D92D@>PH@("`@("`@(&-A<V4@)VAI<F%G86YA
M)SH*("`@("`@("!C87-E("=K871A:V%N82<Z"B`@("`@("`@("`@("1T:&ES
M+3Y?9F]R;6%T(#T@)RI-)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)V%L<&AA)SH*("`@("`@("`@("`@)'1H:7,M/E]F;W)M870@/2`G
M*FTG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;G5M97)I
M8R<Z"B`@("`@("`@("`@("1T:&ES+3Y?9F]R;6%T(#T@)RI.)SL*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@
M8VQA<W,@9&5F:6YE<R!A(&9O<FT@=VET:"!V87)I;W5S('!O<W-I8FQE(&EN
M<'5T(&5L96UE;G1S+B!4:&4*("H@:6YP=70@96QE;65N=',@:&%V92!T;R!B
M92!D969I;F5D(&%S('-E<&%R871E(&]B:F5C=',@86YD(&%R90H@*B!L:6YK
M960@=&\@=&AE(&9O<FT@=VET:"!A('-P96-I86P@(F%D9"(@9G5N8W1I;VXN
M($]N92!(;W)D95]-;V)I;&4*("H@;V)J96-T(&-A;B!C;VYT86EN(&]N;'D@
M;VYE($AO<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z
M"B`J"B`J("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"XN+BD["B`J"B`J
M("1M>49O<FT@/2!N97<@2&]R9&5?36]B:6QE7V9O<FTH(B]M>6YE>'1P86=E
M+G=M;"(I.PH@*B`D;7E497AT(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*"XN
M+BD["B`J("1M>49O<FTM/F%D9"@D;7E497AT*3L*("H@)&UY26YP=70@/2!N
M97<@2&]R9&5?36]B:6QE7VEN<'5T*"XN+BD["B`J("1M>49O<FTM/F%D9"@D
M;7E);G!U="D["B`J("1M>5-U8FUI="`](&YE=R!(;W)D95]-;V)I;&5?<W5B
M;6ET*"XN+BD["B`J("1M>49O<FTM/F%D9"@D;7E3=6)M:70I.PH@*@H@*B`D
M;7E086=E+3YA9&0H)&UY1F]R;2D["B`J"B`J("1M>5!A9V4M/G)E;F1E<B@I
M.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]T97AT"B`J($!S964@2&]R9&5?
M36]B:6QE7VEM86=E"B`J($!S964@2&]R9&5?36]B:6QE7W1A8FQE"B`J($!S
M964@2&]R9&5?36]B:6QE7VEN<'5T"B`J($!S964@2&]R9&5?36]B:6QE7W1E
M>'1A<F5A"B`J($!S964@2&]R9&5?36]B:6QE7W-E;&5C=`H@*B!`<V5E($AO
M<F1E7TUO8FEL95]R861I;PH@*B!`<V5E($AO<F1E7TUO8FEL95]C:&5C:V)O
M>`H@*B!`<V5E($AO<F1E7TUO8FEL95]S=6)M:70*("H@0'-E92!(;W)D95]-
M;V)I;&5?<G5L90H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL95]F;W)M(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L
M96UE;G0@>PH*("`@('9A<B`D7W5R;#L*("`@('9A<B`D7VUE=&AO9#L*("`@
M('9A<B`D7V5L96UE;G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@
M("`@($%D9')E<W,@=VAE<F4@=&AE('5S97(@:6YP=70@:7,@<V5N="!T;RX*
M("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@("`G<&]S="<@*&1E9F%U
M;'0I(&]R("=G970G+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-E<W-I;VX@
M(%!R97-E<G9E('1H92!S97-I;VX@:60@:6X@=&AE(&9O<FT_($1E9F%U;'1S
M('1O('1R=64N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]F
M;W)M*"1U<FPL("1M971H;V0@/2`G<&]S="<L("1S97-S:6]N(#T@=')U92D*
M("`@('L*("`@("`@("`D=&AI<RT^7W5R;"`]("1U<FP["B`@("`@("`@)'1H
M:7,M/E]M971H;V0@/2`D;65T:&]D.PH*("`@("`@("!I9B`H)'-E<W-I;VX@
M)B8@(6%R<F%Y7VME>5]E>&ES=',H<V5S<VEO;E]N86UE*"DL("1?0T]/2TE%
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D*&YE=R!(;W)D95]-;V)I;&5?
M:&ED9&5N*'-E<W-I;VY?;F%M92@I+"!S97-S:6]N7VED*"DI*3L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9"@F)&9O<FU%;&5M96YT*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO
M8FEL95]S=6)M:70G*2D@>PH@("`@("`@("`@("`D9F]R;45L96UE;G0M/E]F
M;W)M(#T@)B1T:&ES.PH@("`@("`@("`@("`D8FQO8VL@/2`F;F5W($AO<F1E
M7TUO8FEL95]B;&]C:R@D9F]R;45L96UE;G0I.PH@("`@("`@("`@("`D=&AI
M<RT^7V5L96UE;G1S6UT@/2`F)&)L;V-K.PH@("`@("`@('T@96QS96EF("AI
M<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO8FEL95]H:61D96XG*2!\?`H@
M("`@("`@("`@("`@("`@("!I<U]A*"1F;W)M16QE;65N="P@)TAO<F1E7TUO
M8FEL95]B;&]C:R<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?96QE;65N='-;
M72`]("8D9F]R;45L96UE;G0["B`@("`@("`@?2!E;'-E:68@*&ES7V$H)&9O
M<FU%;&5M96YT+"`G2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT)RD@?'P*("`@
M("`@("`@("`@("`@("`@:7-?82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I
M;&5?=&5X="<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&9O<FU%;&5M
M96YT+"`G2&]R9&5?36]B:6QE7W1A8FQE)RD@?'P*("`@("`@("`@("`@("`@
M("`@:7-?82@D9F]R;45L96UE;G0L("=(;W)D95]-;V)I;&5?<G5L92<I('Q\
M"B`@("`@("`@("`@("`@("`@(&ES7V$H)&9O<FU%;&5M96YT+"`G2&]R9&5?
M36]B:6QE7VEM86=E)RDI('L*("`@("`@("`@("`@)&)L;V-K(#T@)FYE=R!(
M;W)D95]-;V)I;&5?8FQO8VLH)&9O<FU%;&5M96YT*3L*("`@("`@("`@("`@
M)'1H:7,M/E]E;&5M96YT<UM=(#T@)B1B;&]C:SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=3<&5C
M:69I960@96QE;65N="!C86YN;W0@8F4@:6YS:61E(&$@9F]R;2XG*3L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D9F]R;45L96UE;G0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&5F
M875L=',H*0H@("`@>PH@("`@("`@("1D969A=6QT<R`](&%R<F%Y*"D["B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]E;&5M96YT<R!A<R`D=F%L*2!["B`@
M("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'9A;"DI
M*2!["B`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]H:61D96XG.@H@
M("`@("`@("`@("`@("`@)&1E9F%U;'1S6UT@/2!A<G)A>2@G;F%M92<@/3X@
M)'9A;"T^9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=V86QU92<@/3X@)'9A;"T^9V5T*"=V86QU92<I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&ED9&5N)R`]/B!T
M<G5E*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G:&]R9&5?;6]B:6QE7V)L;V-K)SH*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1V86PM/E]E;&5M96YT<R!A<R`D8G9A;"D@>PH@("`@("`@("`@("`@
M("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&)V86PI*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]C:&5C
M:V)O>"<Z"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D8G9A;"T^:7-#
M:&5C:V5D*"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D969A
M=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG970H)VYA;64G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7VEN
M<'5T)SH*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?
M=&5X=&%R96$G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO
M8FEL95]S96QE8W0G.@H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]R861I;R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1D969A
M=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG970H)VYA;64G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1B=F%L+3YG970H)W9A;'5E)RDI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("1D969A=6QT<UM=(#T@87)R87DH)VYA;64G(#T^("1B=F%L+3YG970H)VYA
M;64G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=F%L=64G(#T^("1B=F%L+3YG970H)W9A;'5E)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAI9&1E;B<@
M/3X@=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&%B;&4G.@H@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D8G9A;"T^7W)O=W,@
M87,@)')O=RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)')O=RT^7V-O;'5M;G,@87,@)&-O;"D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H
M)&-O;"DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G:&]R9&5?;6]B:6QE7V-H96-K8F]X)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1C;VPM/FES0VAE8VME9"@I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5F875L
M='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE)RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=V86QU92<@/3X@)&)V86PM/F=E="@G=F%L=64G*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]I
M;G!U="<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?<V5L96-T)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?
M<F%D:6\G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5F875L='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^9V5T*"=N86UE
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T*"=V86QU92<I
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VAO<F1E
M7VUO8FEL95]H:61D96XG.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5F875L='-;72`](&%R<F%Y*"=N86UE)R`]/B`D8G9A;"T^
M9V5T*"=N86UE)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D8G9A;"T^9V5T
M*"=V86QU92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H:61D96XG(#T^('1R=64I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&5F875L
M=',["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1V5T5F%R<R@I"B`@("!["B`@
M("`@("`@+R\@1&5T97)M:6YE(&%L;"!E;&5M96YT<R!T:&%T(&AA=F4@=&\@
M8F4@<W5B;6ET=&5D+@H@("`@("`@("1G971V87)S(#T@87)R87DH*3L*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V5L96UE;G1S(&%S("1V86PI('L*("`@
M("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*&=E=%]C;&%S<R@D=F%L*2DI
M('L*("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE7V)L;V-K)SH*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1V86PM/E]E;&5M96YT<R!A<R`D8G9A
M;"D@>PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG
M971?8VQA<W,H)&)V86PI*2D@>PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VAO<F1E7VUO8FEL95]I;G!U="<Z"B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G:&]R9&5?;6]B:6QE7VAI9&1E;B<Z"B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G:&]R9&5?;6]B:6QE7W1E>'1A<F5A)SH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=H;W)D95]M;V)I;&5?<V5L96-T)SH*("`@("`@("`@("`@
M("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?8VAE8VMB;W@G.@H@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]R861I;R<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1G971V87)S6UT@/2`D8G9A;"T^9V5T*"=N
M86UE)RD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&%B;&4G.@H@("`@
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D8G9A;"T^7W)O=W,@87,@
M)')O=RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)')O=RT^7V-O;'5M;G,@87,@)&-O;"D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-W:71C:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&-O
M;"DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M:&]R9&5?;6]B:6QE7VEN<'5T)SH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?:&ED9&5N)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E("=H;W)D95]M;V)I;&5?=&5X
M=&%R96$G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)VAO<F1E7VUO8FEL95]S96QE8W0G.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)VAO<F1E7VUO8FEL95]C:&5C:V)O>"<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G:&]R9&5?;6]B:6QE
M7W)A9&EO)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&=E='9A<G-;72`]("1C;VPM/F=E="@G;F%M92<I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9V5T=F%R<SL*("`@('T*
M"GT*"B\J*@H@*B!4:&ES(&-L87-S(&AO;&1S('1E>'0M;&5V96P@96QE;65N
M=',@9F]R('5S92!I;B!(;W)D95]-;V)I;&4@;W(*("H@2&]R9&5?36]B:6QE
M7V9O<FT@;V)J96-T<RX*("H*("H@17AA;7!L97,Z"B`J"B`J("1B;&]C:R`]
M(&YE=R!(;W)D95]-;V)I;&5?8FQO8VLH(DAE;&QO(%=!4"$B*3L*("H@)'1E
M>'0@/2!N97<@2&]R9&5?36]B:6QE7W1E>'0H(E=E;&-O;64@=&\@2&]R9&5?
M36]B:6QE(BP@)V(G*3L*("H@)&)L;V-K+3YA9&0H)'1E>'0I.PH@*@H@*B!`
M<V5E($AO<F1E7TUO8FEL90H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J
M"B`J($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B
M:6QE7V)L;V-K(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@
M('9A<B`D7V5L96UE;G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D96QE;65N
M=',@($%N>2!E;&5M96YT<R`H82!S:6YG;&4@;VYE(&]R(&%N(&%R<F%Y*2!T
M;R!F:6QL('1H:7,@8FQO8VL@=VET:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?36]B:6QE7V)L;V-K*"8D96QE;65N=',I"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1E;&5M96YT<RDI('L*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D96QE;65N=',I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M861D*"1E;&5M96YT<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D96QE;65N=',@87,@)&5L96UE;G0I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1E;&5M96YT*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B`F861D*"8D96QE;65N="D*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?96QE;65N="<I*2!["B`@
M("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@
M96QE;65N="XG*3L*("`@("`@("!](&5L<V5I9B`H:7-?82@D96QE;65N="P@
M)TAO<F1E7TUO8FEL95]T97AT)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?
M82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]T86)L92<I('Q\"B`@("`@("`@
M("`@("`@("`@(&ES7V$H)&5L96UE;G0L("=(;W)D95]-;V)I;&5?:6UA9V4G
M*2!\?`H@("`@("`@("`@("`@("`@("!I<U]A*"1E;&5M96YT+"`G2&]R9&5?
M36]B:6QE7V9O<FU%;&5M96YT)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?
M82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]L:6YK)RD@?'P*("`@("`@("`@
M("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E7TUO8FEL95]L:6YK<V5T
M)RD@?'P*("`@("`@("`@("`@("`@("`@:7-?82@D96QE;65N="P@)TAO<F1E
M7TUO8FEL95]P:&]N92<I('Q\"B`@("`@("`@("`@("`@("`@(&ES7V$H)&5L
M96UE;G0L("=(;W)D95]-;V)I;&5?<G5L92<I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?96QE;65N='-;72`]("8D96QE;65N=#L*("`@("`@("`@("`@<F5T
M=7)N("1E;&5M96YT.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E
M<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H92!E;&5M96YT(&ES(&YO="!A
M;&QO=V5D(&EN<VED92!A(&)L;V-K+B<I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@:6YS
M97)T<R!P;&%I;B!T97AT(&EN=&\@82!(;W)D95]-;V)I;&5?8FQO8VL@;W(@
M80H@*B!(;W)D95]-;V)I;&5?<F]W(&]B:F5C="X*("H*("H@17AA;7!L97,Z
M"B`J"B`J("1M>51E>'0Q(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*")(96QL
M;R!705`A(BD["B`J("1M>51E>'0R(#T@;F5W($AO<F1E7TUO8FEL95]T97AT
M*")796QC;VUE('1O($AO<F1E7TUO8FEL92(L("=B)RD["B`J("1M>51E>'0S
M(#T@;F5W($AO<F1E7TUO8FEL95]T97AT*")';V]D($UO<FYI;F<B+"!A<G)A
M>2@G8B<L("=B:6<G*2D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V)L;V-K
M"B`J($!S964@2&]R9&5?36]B:6QE7W)O=PH@*@H@*B!`<&%C:V%G92!(;W)D
M95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]T97AT(&5X=&5N9',@
M2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W1E>'0@/2`G)SL*
M("`@('9A<B`D7V%T=')I8G5T97,@/2!A<G)A>2@I.PH@("`@=F%R("1?;&EN
M96)R96%K<R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@5&AE('1E>'0@8V]N
M=&5N="!O9B!T:&4@96QE;65N="X*("`@("`J($!P87)A;2!A<G)A>2`D871T
M<FEB=71E<R`@5&5X="!A='1R:6)U=&5S+B!!;GD@;V8Z"B`@("`@*B`@("=B
M)PH@("`@("H@("`G=2<*("`@("`J("`@)VDG"B`@("`@*B`@("=B:6<G"B`@
M("`@*B`@("=S;6%L;"<*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B
M:6QE7W1E>'0H)'1E>'0L("1A='1R:6)U=&5S(#T@87)R87DH*2D*("`@('L*
M("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1A='1R:6)U=&5S*2D@>PH@("`@("`@("`@("`D871T<FEB=71E
M<R`](&%R<F%Y*"1A='1R:6)U=&5S*3L*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/E]A='1R:6)U=&5S(#T@)&%T=')I8G5T97,["B`@("!]"@I]"@HO*BH*
M("H@5&AI<R!C;&%S<R!A;&QO=W,@=&\@:6YS97)T(&)I=&UA<"!I;6%G97,@
M:6YT;R!A($AO<F1E7TUO8FEL95]B;&]C:RP*("H@2&]R9&5?36]B:6QE7V9O
M<FT@;W(@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0N"B`J"B`J($5X86UP;&5S
M.@H@*@H@*B`D:6UA9V4@/2!N97<@2&]R9&5?36]B:6QE7VEM86=E*"<O<&%T
M:"]T;R]I;6%G92YW8FUP)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G:&5I9VAT)R`]/B`Q,#`L("=W:61T:"<@/3X@,3`P
M*2D["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V)L;V-K"B`J($!S964@2&]R
M9&5?36]B:6QE7V9O<FT*("H@0'-E92!(;W)D95]-;V)I;&5?<F]W"B`J"B`J
M($!P86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE
M7VEM86=E(&5X=&5N9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A
M<B`D7W-R8R`]("<G.PH@("`@=F%R("1?871T<FEB=71E<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W)C("`@("`@("!4:&4@<V]U<F-E(&QO8V%T:6]N(&]F('1H92!I
M;6%G92X*("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@26UA9V4@
M871T<FEB=71E<RX@06YY(&]F.@H@("`@("H@("`G86QI9VXG"B`@("`@*B`@
M("=A;'0G"B`@("`@*B`@("=H96EG:'0G"B`@("`@*B`@("=H<W!A8V4G"B`@
M("`@*B`@("=V<W!A8V4G"B`@("`@*B`@("=W:61T:"<*("`@("`J("`@)V-L
M87-S)PH@("`@("H@("`G:60G"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7TUO8FEL95]I;6%G92@D<W)C+"`D871T<FEB=71E<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S<F,@/2`D<W)C.PH@("`@("`@("1T:&ES
M+3Y?871T<FEB=71E<R`]("1A='1R:6)U=&5S.PH@("`@?0H*?0H*+RHJ"B`J
M(%1H:7,@8VQA<W,@86QL;W=S('1O(&EN<V5R="!T86)L97,@:6YT;R!A($AO
M<F1E7TUO8FEL92!O<@H@*B!(;W)D95]-;V)I;&5?9F]R;2!O8FIE8W0N"B`J
M"B`J($5X86UP;&5S.@H@*@H@*B`D;7E486)L92`](&YE=R!(;W)D95]-;V)I
M;&5?=&%B;&4H*3L*("H*("H@)')O=S$@/2!N97<@2&]R9&5?36]B:6QE7W)O
M=R@I.PH@*B`D<F]W,2T^861D*"1I;6%G93$I.PH@*B`D<F]W,2T^861D*"1T
M97AT,2D["B`J("1M>51A8FQE+3YA9&0H)')O=S$I.PH@*@H@*B`D<F]W,B`]
M(&YE=R!(;W)D95]-;V)I;&5?<F]W*"D["B`J("1R;W<R+3YA9&0H)&EM86=E
M,BD["B`J("1R;W<R+3YA9&0H)'1E>'0R*3L*("H@)&UY5&%B;&4M/F%D9"@D
M<F]W,BD["B`J"B`J("1M>41E8VLM/F%D9"@D;7E486)L92D["B`J"B`J($!S
M964@2&]R9&5?36]B:6QE"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H@
M0'-E92!(;W)D95]-;V)I;&5?<F]W"B`J"B`J($!P86-K86=E($AO<F1E7TUO
M8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W1A8FQE(&5X=&5N9',@2&]R
M9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7W)O=W,@/2!A<G)A>2@I
M.PH@("`@=F%R("1?8F]R9&5R(#T@;G5L;#L*("`@('9A<B`D7W!A9&1I;F<@
M/2!N=6QL.PH@("`@=F%R("1?<W!A8VEN9R`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&$@2&]R9&5?36]B:6QE7W)O=R!O8FIE8W0@=&\@2&]R9&5?
M36]B:6QE7W1A8FQE+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I
M;&5?<F]W("1R;W<@(%1H92!R;W<@;V)J96-T('1O(&%D9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F%D9"@F)')O=RD*("`@('L*("`@("`@("!I9B`H(6ES
M7V$H)')O=RP@)TAO<F1E7TUO8FEL95]R;W<G*2D@>PH@("`@("`@("`@("`D
M97)R;W(@/2!014%2.CIR86ES945R<F]R*"=2;W=S(&UU<W0@8F4@2&]R9&5?
M36]B:6QE7W)O=R!O8FIE8W1S+B<I.PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]R;W=S6UT@/2`F)')O
M=SL*("`@("`@("!R971U<FX@)')O=SL*("`@('T*"GT*"B\J*@H@*B!4:&ES
M(&-L87-S(&1E9FEN97,@=&AE(')O=W,@=&AA="!A($AO<F1E7TUO8FEL95]T
M86)L92!O8FIE8W0*("H@8V]N<VES=',@;V8N"B`J"B`J($5X86UP;&5S.@H@
M*@H@*B`D:6UA9V4Q(#T@;F5W($AO<F1E7TUO8FEL95]I;6%G92@B;7E?:6UA
M9V4N=V)M<"(L(")M>5]I;6%G92YP;F<B+"`B.BTI(BD["B`J("1T97AT,2`]
M(&YE=R!(;W)D95]-;V)I;&5?=&5X="@B;7D@=&5X="(I.PH@*B`D<F]W,2`]
M(&YE=R!(;W)D95]-;V)I;&5?<F]W*"D["B`J("1R;W<Q+3YA9&0H)&EM86=E
M,2D["B`J("1R;W<Q+3YA9&0H*3L*("H@)')O=S$M/F%D9"@D=&5X=#$I.PH@
M*@H@*B!`<V5E($AO<F1E7TUO8FEL95]T86)L90H@*B!`<V5E($AO<F1E7TUO
M8FEL95]T97AT"B`J($!S964@2&]R9&5?36]B:6QE7VEM86=E"B`J($!S964@
M2&]R9&5?36]B:6QE7VQI;FL*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE
M"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?<F]W(&5X=&5N9',@2&]R9&5?36]B
M:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7V-O;'5M;G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@061D<R!A(&-O;'5M;B!E;&5M96YT('1O(&$@2&]R
M9&5?36]B:6QE7W)O=R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M($AO
M<F1E7TUO8FEL95]E;&5M96YT("1C96QL16QE;65N="`@0V%N(&)E(&$@2&]R
M9&5?36]B:6QE7W1E>'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]B:F5C="P@82!(;W)D95]-;V)I;&5?:6UA
M9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]B:F5C="P@82!(;W)D95]-;V)I;&5?;&EN:PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T
M(&]R(&YU;&PN(%1H92!L871T97(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(')E<W5L=',@:6X@86X@96UP='D@
M8V5L;"X*("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@D8V5L;$5L96UE;G0@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]O8FIE8W0H)&-E;&Q%;&5M
M96YT*2D@>PH@("`@("`@("`@("!I9B`H(6ES7V$H)&-E;&Q%;&5M96YT+"`G
M2&]R9&5?36]B:6QE7W1E>'0G*2`F)@H@("`@("`@("`@("`@("`@(6ES7V$H
M)&-E;&Q%;&5M96YT+"`G2&]R9&5?36]B:6QE7VQI;FLG*2`F)@H@("`@("`@
M("`@("`@("`@(6ES7V$H)&-E;&Q%;&5M96YT+"`G2&]R9&5?36]B:6QE7VEM
M86=E)RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E
M17)R;W(H)U1A8FQE(&-E;&QS(&-A;B!O;FQY(&-O;G1A:6X@=&5X="P@;&EN
M:W,L(&]R(&EM86=E<RXG*3L*("`@("`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]C;VQU;6YS
M6UT@/2`F)&-E;&Q%;&5M96YT.PH@("`@("`@("`@("!R971U<FX@)&-E;&Q%
M;&5M96YT.PH@("`@("`@('T@96QS96EF("@A:7-?;G5L;"@D8V5L;$5L96UE
M;G0I*2!["B`@("`@("`@("`@("1T(#T@)FYE=R!(;W)D95]-;V)I;&5?=&5X
M="@D8V5L;$5L96UE;G0I.PH@("`@("`@("`@("`D=&AI<RT^7V-O;'5M;G-;
M72`]("8D=#L*("`@("`@("`@("`@<F5T=7)N("1T.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?8V]L=6UN<UM=(#T@)B1C96QL16QE
M;65N=#L*("`@("`@("`@("`@<F5T=7)N("1C96QL16QE;65N=#L*("`@("`@
M("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0V]L=6UN0V]U;G0H*0H@("`@
M>PH@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V-O;'5M;G,I.PH@("`@
M?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@82!T97AT(&EN<'5T
M(&9I96QD(&EN(&$@2&]R9&5?36]B:6QE7V9O<FT@;V)J96-T+@H@*@H@*B!%
M>&%M<&QE<SH*("H*("H@)&UY26YP=70Q(#T@;F5W($AO<F1E7TUO8FEL95]I
M;G!U="@G8VED)RP@)R<L("=#=7-T;VUE<B!)1"<I.PH@*@H@*B`D;7E);G!U
M=#(@/2!N97<@2&]R9&5?36]B:6QE7VEN<'5T*"=C:60G+"`G)RP@)T-U<W1O
M;65R($E$)RP@)RI.)RD["B`J("1M>4EN<'5T,BT^<V5T7W-I>F4H-BD["B`J
M("1M>4EN<'5T,BT^<V5T7VUA>&QE;F=T:"@V*3L*("H*("H@)&UY26YP=70S
M(#T@;F5W($AO<F1E7TUO8FEL95]I;G!U="@G<'<G+"`G)RP@)U!A<W-W;W)D
M)RP@)RI.)RD["B`J("1M>4EN<'5T,RT^<V5T7W-I>F4H."D["B`J("1M>4EN
M<'5T,RT^<V5T7VUA>&QE;F=T:"@X*3L*("H@)&UY26YP=70S+3YS971?='EP
M92@G<&%S<W=O<F0G*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&5?9F]R;0H@
M*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO
M8FEL95]I;G!U="!E>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="![
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@5F%R:6%B;&4@:6X@=VAI8V@@=&AE(&EN
M<'5T(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@(&1E<W1I;F%T:6]N(%523"X*("`@("`J($!P87)A;2!S=')I;F<@)'9A
M;'5E("`@26YI=&EA;"!V86QU92!T:&%T('=I;&P@8F4@<')E<V5N=&5D(&EN
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;G!U="!F:65L
M9"X*("`@("`J($!P87)A;2!S=')I;F<@)&QA8F5L("`@1&5S8W)I8F5S('EO
M=7(@:6YP=70@9FEE;&0@;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9F]R;6%T("!);G!U="!F;W)M870@8V]D92!A8V-O<F1I;F<@
M=&\@=&AE(%=!4"!S=&%N9&%R9"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@06QL;W=S('1H92!705`@=7-E<B!C;&EE;G0@92YG+B!T;R!I;G!U
M="!O;FQY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&1I9VET<R!A
M;F0@;F\@8VAA<F%C=&5R<RX@3VX@86X@2%1-3"!G96YE<F%T960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@<&%G92!T:&ES(&9O<FUA="!H87,@
M;F\@<VEG;FEF:6-A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-
M;V)I;&5?:6YP=70H)&YA;64L("1V86QU92P@)&QA8F5L(#T@)R<L("1F;W)M
M870@/2`G*DTG*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE
M.PH@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("`@("`@)'1H
M:7,M/E]L86)E;"`]("1L86)E;#L*("`@("`@("`D=&AI<RT^7V9O<FUA="`]
M("1F;W)M870["B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)W1E>'0G.PH@("`@
M("`@("1T:&ES+3Y?;6]D92`]("=A;'!H82<["B`@("!]"@I]"@HO*BH*("H@
M5&AI<R!C;&%S<R!P<F]V:61E<R!A;B!I;G!U="!T97AT87)E82!I;B!A($AO
M<F1E7TUO8FEL95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J
M("1M>4%R96$Q(#T@;F5W($AO<F1E7TUO8FEL95]T97AT87)E82@G9F(G+"`G
M)RP@)T9E961B86-K)RD["B`J("1M>4%R96$R(#T@;F5W($AO<F1E7TUO8FEL
M95]T97AT87)E82@G;7-G)RP@)T5N=&5R(&UE<W-A9V4@:&5R92`N+BXG+"`G
M365S<V%G92<L(#0P+"`U*3L*("H*("H@0'-E92!(;W)D95]-;V)I;&5?9F]R
M;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E
M7TUO8FEL95]T97AT87)E82!E>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE
M;65N="!["@H@("`@=F%R("1?<F]W<SL*("`@('9A<B`D7V-O;',["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@5F%R:6%B;&4@:6X@=VAI8V@@=&AE(&EN<'5T(&ES
M('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&5S
M=&EN871I;VX@55),+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@($EN
M:71I86P@=F%L=64@=&AA="!W:6QL(&)E('!R97-E;G1E9"!I;B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!T97AT87)E82X*("`@("`J($!P
M87)A;2!S=')I;F<@)&QA8F5L("!$97-C<FEB97,@>6]U<B!T97AT87)E82!O
M;B!T:&4@<W5R9F5R)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S
M8W)E96XO9&ES<&QA>2X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W=S("!2
M;W=S+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;',@($-O;'5M;G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]T97AT87)E82@D;F%M
M92P@)'9A;'5E+"`D;&%B96PL("1R;W=S(#T@,RP@)&-O;',@/2`Q-BD*("`@
M('L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI
M<RT^7W9A;'5E(#T@)'9A;'5E.PH@("`@("`@("1T:&ES+3Y?;&%B96P@/2`D
M;&%B96P["B`@("`@("`@)'1H:7,M/E]R;W=S(#T@)')O=W,["B`@("`@("`@
M)'1H:7,M/E]C;VQS(#T@)&-O;',["B`@("`@("`@)'1H:7,M/E]M;V1E(#T@
M)V%L<&AA)SL*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S
M(&$@<V5L96-T(&5L96UE;G0@:6X@82!(;W)D95]-;V)I;&5?9F]R;2!O8FIE
M8W0N"B`J($ET(&%L;&]W<R!T;R!C<F5A=&4@;W!T:6UI>F5D(%=-3"!F;W(@
M5T%0(&1E=FEC97,@=VAI8V@@87)E(&-A<&%B;&4*("H@=&\@:6YT97)P<F5T
M92!T:&4@3W!E;G=A=F4@1U5)(&5X=&5N<VEO;G,@9F]R(%=-3"`Q+C,N($%L
M;"!O=&AE<@H@*B!734P@9&5V:6-E<R!R96-E:79E(%=-3"`Q+C$@8V]M<&%T
M:6)L92!M87)K=7`@8V]D92P@=VAI8V@@:7,@<75I=&4*("H@<VEM:6QA<B!T
M;R!T:&4@;6%R:W5P(&-O9&4@8W)E871E9"!B>2!T:&4@2&]R9&5?36]B:6QE
M7W)A9&EO(&-L87-S+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY4V5L96-T
M(#T@;F5W($AO<F1E7TUO8FEL95]S96QE8W0H)V-O;&]R)RD["B`J("1M>5-E
M;&5C="T^861D*"=";'5E)RP@)V(G*3L*("H@)&UY4V5L96-T+3YA9&0H)U)E
M9"<L("=R)RP@=')U92D["B`J("1M>5-E;&5C="T^861D*"=996QL;W<G+"`G
M>2<I.PH@*@H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P86-K
M86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W-E;&5C
M="!E>'1E;F1S($AO<F1E7TUO8FEL95]F;W)M16QE;65N="!["@H@("`@=F%R
M("1?='EP93L*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!687)I86)L92!I;B!W:&EC:"!T:&4@:6YF;W)M871I;VX@
M86)O=70@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!S96QE8W1E
M9"!O<'1I;VX@:7,@<V5N="!T;R!T:&4@9&5S=&EN871I;VX@55),+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D='EP92`@5'EP92!O9B!S96QE8W0@87)E83H*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("=P;W!U<"<Z('!O<'5P('1H
M92!W:&]L92!S96QE8W1I;VX@;&ES=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@)W-P:6XG.B`@<F]T871E(&]P=&EO;G,@;VX@82!705`@9&5V:6-E
M('-C<F5E;B`H3U<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#$N,R!'54D@;VYL>2DN"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7TUO8FEL95]S96QE8W0H)&YA;64L("1T>7!E(#T@)W!O<'5P)RD*("`@('L*
M("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^
M7W1Y<&4@/2`D='EP93L*("`@("`@("`D=&AI<RT^7W9A;'5E(#T@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J($%D9',@;VYE(&]P=&EO;B!T;R!A($AO
M<F1E7TUO8FEL95]S96QE8W0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&QA8F5L("`@("`@("`@1&5S8W)I8F5S('1H92!O<'1I;VX@
M;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=F%L=64@("`@("`@("!686QU92!S96YT(&EN('1H92`B;F%M92(@=F%R:6%B
M;&4L(&EF('1H:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:7,@=&AE(&]P=&EO;B!S96QE8W1E9"X*("`@("`J($!P87)A;2!B;V]L
M96%N("1I<U]S96QE8W1E9"`@06QL;W=E9"!V86QU97,@87)E('1R=64@;W(@
M9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@D;&%B96PL("1V86QU
M92P@)&ES7W-E;&5C=&5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS6UT@/2!A<G)A>2@G;&%B96PG(#T^("1L86)E;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E
M*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]V86QU92D@?'P@)&ES
M7W-E;&5C=&5D*2!["B`@("`@("`@("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L
M=64["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O
M=FED97,@82!R861I;R!B=71T;VX@96QE;65N="!I;B!A($AO<F1E7TUO8FEL
M95]F;W)M(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J("1M>5)A9&EO
M(#T@;F5W($AO<F1E7TUO8FEL95]R861I;R@G8V]U;G1R>2<I.PH@*B`D;7E2
M861I;RT^861D*"=&:6YL86YD)RP@)T8G*3L*("H@)&UY4F%D:6\M/F%D9"@G
M1V5R;6%N>2<L("=')RP@=')U92D["B`J("1M>5)A9&EO+3YA9&0H)U-W961E
M;B<L("=3)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@
M0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?
M<F%D:6\@97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@
M('9A<B`D7V)U='1O;G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!6
M87)I86)L92!I;B!W:&EC:"!T:&4@:6YF;W)M871I;VX@86)O=70@=&AE('!R
M97-S960@8G5T=&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I<R!S
M96YT('1O('1H92!D97-T:6YA=&EO;B!54DPN"B`@("`@*B\*("`@(&9U;F-T
M:6]N($AO<F1E7TUO8FEL95]R861I;R@D;F%M92D*("`@('L*("`@("`@("`D
M=&AI<RT^7VYA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7W9A;'5E(#T@
M;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@;VYE(')A9&EO(&)U
M='1O;B!T;R!A($AO<F1E7TUO8FEL95]R861I;R!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@("`@("`@($1E<V-R:6)E<R!T
M:&4@<F%D:6]B=71T;VX@;VX@=&AE('-U<F9E<B=S"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<V-R965N+V1I<W!L87DN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1V86QU92`@("`@("`@5F%L=64@<V5N="!I;B!T:&4@
M(FYA;64B('9A<FEA8FQE+"!I9B!T:&ES"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G5T=&]N(&ES('-E;&5C=&5D+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&ES7V-H96-K960@($%L;&]W960@=F%L=65S(&%R92!T
M<G5E(&]R(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H)&QA8F5L
M+"`D=F%L=64L("1I<U]C:&5C:V5D(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]B=71T;VYS6UT@/2!A<G)A>2@G;&%B96PG(#T^("1L86)E;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@
M)'9A;'5E*3L*"B`@("`@("`@:68@*"$D=&AI<RT^7W9A;'5E('Q\("@D:7-?
M8VAE8VME9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]V86QU92`]("1V86QU
M93L*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!P<F]V
M:61E<R!A('-I;F=L92!C:&5C:V)O>"!E;&5M96YT(&EN(&$@2&]R9&5?36]B
M:6QE7V9O<FT@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY0VAE
M8VMB;W@@/2!N97<@2&]R9&5?36]B:6QE7V-H96-K8F]X*"=A9VUT)RP@)WEE
M<R<L("=)(&%G<F5E)RD["B`J("1M>4-H96-K8F]X(#T@;F5W($AO<F1E7TUO
M8FEL95]C:&5C:V)O>"@G86=M="<L("=Y97,G+"`G22!A9W)E92<L(&9A;'-E
M*3L*("H@)&UY0VAE8VMB;W@@/2!N97<@2&]R9&5?36]B:6QE7V-H96-K8F]X
M*"=A9VUT)RP@)WEE<R<L("=)(&%G<F5E)RP@=')U92D["B`J"B`J($!N;W1E
M(%1H92!F:7)S="!A;F0@<V5C;VYD(&5X86UP;&5S(&%R92!I9&5N=&EC86PN
M"B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*("H@0'!A8VMA9V4@
M2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?8VAE8VMB;W@@
M97AT96YD<R!(;W)D95]-;V)I;&5?9F]R;45L96UE;G0@>PH*("`@('9A<B`D
M7V-H96-K960["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("!687)I86)L92!I;B!W
M:&EC:"`B=F%L=64B(&ES('-E;G0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@9&5S=&EN871I;VX@55),+"!I9B!T:&4@8F]X(&ES
M(&-H96-K960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@("`@4V5E
M(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("`@1&5S8W)I
M8F5S('1H92!C:&5C:V)O>"!O;B!T:&4@<W5R9F5R)W,*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!S8W)E96XO9&ES<&QA>2X*("`@("`J($!P
M87)A;2!B;V]L96%N("1C:&5C:V5D("!!;&QO=V5D('9A;'5E<R!A<F4@=')U
M92!O<B!F86QS92X*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE
M7V-H96-K8F]X*"1N86UE+"`D=F%L=64L("1L86)E;"P@)&-H96-K960@/2!F
M86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7VYA;64@(#T@)&YA;64["B`@
M("`@("`@)'1H:7,M/E]V86QU92`]("1V86QU93L*("`@("`@("`D=&AI<RT^
M7VQA8F5L(#T@)&QA8F5L.PH@("`@("`@("1T:&ES+3Y?8VAE8VME9"`]("1C
M:&5C:V5D.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0VAE8VME9"@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAE8VME9#L*("`@('T*"GT*"B\J
M*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&AI9&1E;B!E;&5M96YT<R!I;B!(
M;W)D95]-;V)I;&5?9F]R;2!O8FIE8W1S+@H@*@H@*B!%>&%M<&QE<SH*("H*
M("H@)&AI9&1E;B`](&YE=R!(;W)D95]-;V)I;&5?:&ED9&5N*"=I;G1E<FYA
M;%]R969E<F5N8V4G+"`G,#@Q-30W,3$G*3L*("H*("H@0'-E92!(;W)D95]-
M;V)I;&5?9F]R;0H@*@H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L
M87-S($AO<F1E7TUO8FEL95]H:61D96X@97AT96YD<R!(;W)D95]-;V)I;&5?
M9F]R;45L96UE;G0@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@5F%R:6%B;&4@:6X@
M=VAI8V@@)'9A;'5E(&ES('-E;G0@=&\@=&AE(&1E<W1I;F%T:6]N(%523"X*
M("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!3964@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@2&]R9&5?36]B:6QE7VAI9&1E;B@D;F%M92P@)'9A
M;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@
M("`@("1T:&ES+3Y?=F%L=64@/2`D=F%L=64["B`@("!]"@I]"@HO*BH*("H@
M5&AI<R!C;&%S<R!P<F]V:61E<R!A('-U8FUI="!B=71T;VX@9F]R(&$@2&]R
M9&5?36]B:6QE7V9O<FT@;V)J96-T+B!/;F4*("H@2&]R9&5?36]B:6QE7V9O
M<FT@;V)J96-T(&-A;B!C;VYT86EN(&]N;'D@;VYE($AO<F1E7TUO8FEL95]S
M=6)M:70@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H@)&UY4W5B;6ET(#T@
M)FYE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"=3=6)M:70G*3L*("H@)&UY4W5B
M;6ET(#T@)FYE=R!(;W)D95]-;V)I;&5?<W5B;6ET*"=3=6)M:70G+"`G=7-E
M<E]P<F5S<V5D)RD["B`J"B`J($!S964@2&]R9&5?36]B:6QE7V9O<FT*("H*
M("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I
M;&5?<W5B;6ET(&5X=&5N9',@2&]R9&5?36]B:6QE7V9O<FU%;&5M96YT('L*
M"B`@("!V87(@)%]F;W)M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@5VAA="=S('=R
M:71T96X@;VX@=&AE(&)U='1O;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("!687)I86)L92!I;B!W:&EC:"`B;&%B96PB(&ES('-E;G0@=&\@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&5S=&EN871I;VX@55),
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?<W5B;6ET*"1L
M86)E;"P@)&YA;64@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7VQA8F5L
M(#T@)&QA8F5L.PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@("`@
M?0H*?0H*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@82!L:6YK(&EN(&$@
M2&]R9&5?36]B:6QE+"!(;W)D95]-;V)I;&5?;&EN:W-E="!O<@H@*B!(;W)D
M95]-;V)I;&5?=&%B;&4@;V)J96-T+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@
M)&UY4&%G92`](&YE=R!(;W)D95]-;V)I;&4H+BXN*3L*("H*("H@)&UY3&EN
M:R`](&YE=R!(;W)D95]-;V)I;&5?;&EN:R@G0V]N=&EN=64G+"`G+VUY;F5X
M='!A9V4N=VUL)RD["B`J("1M>5!A9V4M/F%D9"@D;7E,:6YK*3L*("H*("H@
M0'-E92!(;W)D95]-;V)I;&4*("H@0'-E92!(;W)D95]-;V)I;&5?;&EN:W-E
M=`H@*B!`<V5E($AO<F1E7TUO8FEL95]T86)L90H@*@H@*B!`<&%C:V%G92!(
M;W)D95]-;V)I;&4*("HO"F-L87-S($AO<F1E7TUO8FEL95]L:6YK(&5X=&5N
M9',@2&]R9&5?36]B:6QE7V5L96UE;G0@>PH*("`@('9A<B`D7VQA8F5L.PH@
M("`@=F%R("1?=7)L.PH@("`@=F%R("1?=&ET;&4["B`@("!V87(@)%]A8V-E
M<W-K97D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&QA8F5L("!$97-C<FEB97,@=&AE(&QI;FL@
M;VX@=&AE('-U<F9E<B=S('-C<F5E;B]D:7-P;&%Y+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7)L("`@($YE>'0@9&5S=&EN871I;VX@861D<F5S<RX@3553
M5"!B92!V86QI9"!834P@*"9A;7`[(&EN<W1E860@;V8@)BP@971C+BDN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T:71L92`@268@82!S=')I;F<@:7,@<')O
M=FED960@:&5R92P@:70@=VEL;"!B92!D:7-P;&%Y960*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!I;B!T:&4@2%1-3"!B<F]W<V5R('-T871U<R!B
M87(@9'5R:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(DUO=7-E
M3W9E<B(L(')E<W!E8W1I=F5L>2!S;VUE=VAE<F4@;VX@=&AE(%=!4`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(&1I<W!L87DN($EN(&]R9&5R('1O
M('=O<FL@=V5L;"!W:71H(&$@8G)O860@<F%N9V4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!O9B!U<V5R(&%G96YT<RP@:V5E<"!Y;W5R('1I=&QE
M('5N9&5R(#8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C:&%R86-T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]-;V)I;&5?;&EN:R@D
M;&%B96PL("1U<FPL("1T:71L92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;&%B96P@/2`D;&%B96P["B`@("`@("`@)'1H:7,M/E]U<FP@/2`D=7)L
M.PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D=&ET;&4["@H@("`@("`@("\O
M($YO(&%C8V5S<VME>2!A<W-I9VYE9"!B>2!D969A=6QT.R!C86X@8F4@87-S
M:6=N960@;&%T97(*("`@("`@("`O+R!F<F]M(&$@2&]R9&5?36]B:6QE7VQI
M;FMS970@;V)J96-T(&EF(')E<75I<F5D+@H@("`@("`@("1T:&ES+3Y?86-C
M97-S:V5Y(#T@;G5L;#L*("`@('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S('!R
M;W9I9&5S(&$@<&AO;F4@;G5M8F5R(&EN(&$@2&]R9&5?36]B:6QE(&]B:F5C
M="X@268@<W5P<&]R=&5D(&)Y"B`J('1H96ER(&UO8FEL92!D979I8V4L('5S
M97)S(&-A;B!E<W1A8FQI<V@@82!V;VEC92!C;VYN96-T:6]N('1O('1H90H@
M*B!S<&5C:69I960@;G5M8F5R+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@)&UY
M4&AO;F4@/2`F;F5W($AO<F1E7TUO8FEL95]P:&]N92@G,3(S+30U-C<X)RP@
M)T-!3$PG*3L*("H@)&UY4&%G92T^861D*"1M>5!H;VYE*3L*("H*("H@0'-E
M92!(;W)D95]-;V)I;&4*("H*("H@0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J
M+PIC;&%S<R!(;W)D95]-;V)I;&5?<&AO;F4@97AT96YD<R!(;W)D95]-;V)I
M;&5?96QE;65N="!["@H@("`@=F%R("1?;&%B96P["B`@("!V87(@)%]N=6UB
M97(["B`@("!V87(@)%]T:71L93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&AO;F5?;G5M8F5R
M("!0:&]N92!N=6UB97(@=&\@9&EA;"X*("`@("`J($!P87)A;2!S=')I;F<@
M)'1I=&QE("`@("`@("`@268@82!S=')I;F<@:7,@<')O=FED960@:&5R92P@
M=&AE(&-A;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G5T=&]N(&]N(&$@5T%0+TA$34P@9&5V:6-E('=I;&P@8F4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96YA8FQE9"X@26X@;W)D97(@
M=&\@=V]R:R!W96QL('=I=&@*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@82!B<F]A9"!R86YG92!O9B!U<V5R(&%G96YT<RP@:V5E<"!Y
M;W5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I=&QE
M('5N9&5R(#8@8VAA<F%C=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R
M9&5?36]B:6QE7W!H;VYE*"1P:&]N95]N=6UB97(L("1T:71L92`]("<G*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?;&%B96P@/2`D<&AO;F5?;G5M8F5R.PH@
M("`@("`@("1T:&ES+3Y?;G5M8F5R(#T@<')E9U]R97!L86-E*"=\7$1\)RP@
M)R<L("1P:&]N95]N=6UB97(I.PH@("`@("`@("1T:&ES+3Y?=&ET;&4@/2`D
M=&ET;&4["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S<R!D969I;F5S(&$@
M<V5T(&]F(&QI;FMS+B!4:&4@;&EN:W,@:&%V92!T;R!B92!D969I;F5D(&%S
M"B`J('-E<&%R871E($AO<F1E7TUO8FEL95]L:6YK(&]B:F5C=',@86YD(&%R
M92!A='1A8VAE9"!T;R!T:&4@;&EN:W-E=`H@*B!W:71H(&$@<W!E8VEA;"`B
M861D(B!F=6YC=&EO;BX@($9O<B!705`@9&5V:6-E<R!B<F]W<V5R+61E<&5N
M9&5N=`H@*B!734P@8V]D92!W:6QL(&)E(&-R96%T960N($]N(&%L;"!54"UB
M<F]W<V5R+6)A<V5D(%=!4"!D979I8V5S"B`J(&QI;FMS971S(&%L;&]W(&5A
M<VEE<B!N879I9V%T:6]N('1H<F]U9V@@5TU,(&1E8VMS(&)Y('5S:6YG('1H
M90H@*B`B;VYP:6-K(B!734P@;W!T:6]N(&%N9"!T:&5R969O<F4@87)E(&EM
M<')O=FEN9R!T:&4@(G5S86)I;&ET>2(@;V8*("H@86X@87!P;&EC871I;VXN
M($EN<W1E860@;V8@<&%I;F9U;&QY(&YA=FEG871I;F<@=&AR;W5G:"!T:&4@
M;&EN:W,*("H@(G-P;W)T<RT^9F]O=&)A;&PM/G)E<W5L=',M/G1O9&%Y(B!T
M:&4@;6]B:6QE('5S97(@92YG+B!C86X@<')E<W,*("H@(C(T,S$B(&]N('1H
M92!K97EP860@=&\@96YT97(@:&ES(&9A=F]R:71E(&1E8VLN($9O<B!A;&P@
M;W1H97(@5T%0"B`J(&1E=FEC97,@;F]R;6%L(#QA/B!T86=S(&%R92!C<F5A
M=&5D+B!/;F4@2&]R9&5?36]B:6QE(&]B:F5C="!C86X*("H@8V]N=&%I;B!O
M;FQY(&]N92!L:6YK<V5T(&]B:F5C="X*("H*("H@17AA;7!L97,Z"B`J"B`J
M("1M>5!A9V4@/2!N97<@2&]R9&5?36]B:6QE*"XN+BD["B`J"B`J("1M>4QI
M;FMS970@/2!N97<@2&]R9&5?36]B:6QE7VQI;FMS970H*3L*("H@)&UY3&EN
M:S$@/2!N97<@2&]R9&5?36]B:6QE7VQI;FLH(E!H;VYE8F]O:R(L("(O=V%P
M+W!H;VYE8F]O:RYW;6PB*3L*("H@)&UY3&EN:W-E="T^861D*"1M>4QI;FLQ
M*3L*("H@)&UY3&EN:S(@/2!N97<@2&]R9&5?36]B:6QE7VQI;FLH(D1A=&5"
M;V]K(BP@(B]W87`O9&%T96)O;VLN=VUL(BD["B`J("1M>4QI;FMS970M/F%D
M9"@D;7E,:6YK,BD["B`J"B`J("1M>5!A9V4M/F%D9"@D;7E,:6YK<V5T*3L*
M("H*("H@)&UY4&%G92T^<F5N9&5R*"D["B`J"B`J($!S964@2&]R9&5?36]B
M:6QE7VQI;FL*("H@0'-E92!(;W)D95]-;V)I;&4*("H*("H@0'!A8VMA9V4@
M2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?;&EN:W-E="!E
M>'1E;F1S($AO<F1E7TUO8FEL95]E;&5M96YT('L*"B`@("!V87(@)%]E;&5M
M96YT<SL*"B`@("`O*BH*("`@("`J($%D9',@82!(;W)D95]-;V)I;&5?;&EN
M:R!O8FIE8W0@=&\@2&]R9&5?36]B:6QE7VQI;FMS970N"B`@("`@*@H@("`@
M("H@0'!A<F%M($AO<F1E7TUO8FEL95]L:6YK("1L:6YK("!4:&4@;&EN:R!O
M8FIE8W0@=&\@861D+@H@("`@("H*("`@("`J($!S964@2&]R9&5?36]B:6QE
M7VQI;FL*("`@("`J+PH@("`@9G5N8W1I;VX@)F%D9"@F)&QI;FLI"B`@("![
M"B`@("`@("`@:68@*"%I<U]A*"1L:6YK+"`G2&]R9&5?36]B:6QE7VQI;FLG
M*2D@>PH@("`@("`@("`@("`D97)R;W(@/2!014%2.CIR86ES945R<F]R*"=,
M:6YK<R!M=7-T(&)E($AO<F1E7TUO8FEL95]L:6YK(&]B:F5C=',N)RD["B`@
M("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7V5L96UE;G1S6UT@/2`F)&QI;FL["B`@("`@("`@)&QI;FLM/G-E
M="@G86-C97-S:V5Y)RP@8V]U;G0H)'1H:7,M/E]E;&5M96YT<RDI.PH*("`@
M("`@("!R971U<FX@)&QI;FL["B`@("!]"@I]"@HO*BH*("H@5&AI<R!C;&%S
M<R!W:6QL(&-A=7-E(&$@:&]R:7IO;G1A;"!R=6QE('1O(&)E(&1R87=N(&%C
M<F]S<R!T:&4@<V-R965N+B`@66]U"B`J(&-A;B!U<V4@:70@=&\@<V5P87)A
M=&4@=&5X="!P87)A9W)A<&AS(&EN($AO<F1E7TUO8FEL92!O<B!(;W)D95]-
M;V)I;&5?9F]R;0H@*B!O8FIE8W1S+@H@*@H@*B!%>&%M<&QE<SH*("H*("H@
M)&UY1&5F875L=%)U;&4@/2!N97<@2&]R9&5?36]B:6QE7W)U;&4H*3L*("H@
M)&UY4W!E8VEA;%)U;&4@/2!N97<@2&]R9&5?36]B:6QE7W)U;&4H)S8P)2<L
M(#0I.PH@*@H@*B`D;7E086=E+3YA9&0H)&UY1&5F875L=%)U;&4I.PH@*@H@
M*B`D;7E086=E+3YA9&0H)&UY4W!E8VEA;%)U;&4I.PH@*@H@*B!`<V5E($AO
M<F1E7TUO8FEL90H@*B!`<V5E($AO<F1E7TUO8FEL95]F;W)M"B`J"B`J($!P
M86-K86=E($AO<F1E7TUO8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7W)U
M;&4@97AT96YD<R!(;W)D95]-;V)I;&5?96QE;65N="!["@H@("`@=F%R("1?
M=VED=&@["B`@("!V87(@)%]S:7IE.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@(%!E
M<F-E;G1A9V4@;V8@<V-R965N('=I9'1H(&]R(&%B<V]L=71E('9A;'5E(&EN
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&YU;6)E<B!O9B!P:7AE
M;',@*&4N9RX@(C4P)2(L(#$P,"DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<VEZ92`@($AE:6=H="!O9B!T:&4@;&EN92!T;R!B92!D<F%W;B!I;B!P:7AE
M;',N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TUO8FEL95]R=6QE*"1W
M:61T:"`]("<G+"`D<VEZ92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M=VED=&@@/2`D=VED=&@["B`@("`@("`@)'1H:7,M/E]S:7IE(#T@)'-I>F4[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]24$,N<&AP````````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`R,#$P,R`Q,#4Q-30S-#$T,"`P,C`T-S``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!(;W)D95]24$,Z.B!C;&%S<R!P<F]V:61E<R!A('-E="!O9B!S97)V97(@
M86YD(&-L:65N="!M971H;V1S(&9O<@H@*B!24$,@8V]M;75N:6-A=&EO;BX*
M("H*("H@5$]$3SH*("H@+2!);G1R;W-P96-T:6]N(&1O8W5M96YT871I;VX@
M86YD(&UE=&AO9"!S:6=N871U<F5S+@H@*@H@*B!%6$%-4$Q%.@H@*B`\8V]D
M93X*("H@)')E<W!O;G-E(#T@2&]R9&5?4E!#.CIR97%U97-T*"=X;6QR<&,G
M+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT='`Z+R]L
M;V-A;&AO<W0Z.#`O:&]R9&4O<G!C+G!H<"<*("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=C;VYT86-T<RYS96%R8V@G+`H@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH87)R87DH)VIA;B<I+"!A
M<G)A>2@G;&]C86QS<6PG*2P*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=N86UE)RP@)V5M86EL)RDI+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W5S97(G(#T^($%U
M=&@Z.F=E=$%U=&@H*2P*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P87-S)R`]/B!!=71H.CIG971#<F5D96YT:6%L*"=P87-S
M=V]R9"<I*2D["B`J(#PO8V]D93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4E!#+U)00RYP:'`L=B`Q+C<N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,S(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(;W)D
M95]24$,@>PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!W92!N965D(&%N(&%U
M=&AO<FEZ960@=7-E<B!O<B!N;W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<F]T96-T960*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]A=71H;W)I>F4@/2!T<G5E.PH*("`@("\J*@H@("`@("H@4E!#('-E<G9E
M<B!C;VYS=')U8W1O<@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H@0')E='5R;B!O8FIE8W0@("!!;B!24$,@<V5R=F5R(&EN<W1A;F-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]24$,H*0H@("`@>PH@("`@
M("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&%R<F%Y*"1T:&ES+"`G
M<VAU=&1O=VXG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=7`@
M=&AE(%)00R!S97)V97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-H=71D;W=N*"D*("`@('L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K(&%U=&AE;G1I8V%T:6]N+B!$:69F97)E;G0@8F%C
M:V5N9',@;6%Y(&AA;F1L90H@("`@("H@875T:&5N=&EC871I;VX@:6X@9&EF
M9F5R96YT('=A>7,N(%1H92!B87-E(&-L87-S(&EM<&QE;65N=&%T:6]N"B`@
M("`@*B!C:&5C:W,@9F]R($A45%`@075T:&5N=&EC871I;VX@86=A:6YS="!T
M:&4@2&]R9&4@875T:"!S971U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%)E='5R;G,@=')U92!I9B!A=71H96YT:6-A=&EO;B!I<R!S=6-C
M97-S9G5L+@H@("`@("H@("`@("`@("`@("`@("`@("!3:&]U;&0@<V5N9"!A
M<'!R;W!R:6%T92`B;F]T(&%U=&AO<FEZ960B(&AE861E<G,*("`@("`J("`@
M("`@("`@("`@("`@("`@;W(@;W1H97(@<F5S<&]N<V4@8V]D97,O8F]D>2!I
M9B!A=71H(&9A:6QS+`H@("`@("H@("`@("`@("`@("`@("`@("!A;F0@=&%K
M92!C87)E(&]F(&5X:71I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&AO
M<FEZ92@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V%U=&AO<FEZ92D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D1TQ/0D%,4ULG8V]N9B==6R=A
M=71H)UU;)V1R:79E<B==*3L*"B`@("`@("`@:68@*&ES<V5T*"1?4T525D52
M6R=02%!?05542%]54T52)UTI*2!["B`@("`@("`@("`@("1U<V5R(#T@)%]3
M15)615);)U!(4%]!551(7U5315(G73L*("`@("`@("`@("`@)'!A<W,@/2`D
M7U-%4E9%4ELG4$A07T%55$A?4%<G73L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-S970H)'5S97(I"B`@("`@("`@("`@('Q\("$D875T:"T^875T:&5N
M=&EC871E*"1U<V5R+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1P87-S*2DI('L*
M("`@("`@("`@("`@:&5A9&5R*"=75U<M075T:&5N=&EC871E.B!"87-I8R!R
M96%L;3TB2&]R9&4@4E!#(B<I.PH@("`@("`@("`@("!H96%D97(H)TA45%`O
M,2XP(#0P,2!5;F%U=&AO<FEZ960G*3L*("`@("`@("`@("`@96-H;R`G-#`Q
M(%5N875T:&]R:7IE9"<["B`@("`@("`@("`@(&5X:70["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@<F5Q=65S="!B;V1Y(&EN<'5T+B!$:69F97)E;G0@4E!#(&)A8VME
M;F1S(&-A;B!O=F5R<FED90H@("`@("H@=&AI<R!T;R!R971U<FX@86X@;W!E
M;B!S=')E86T@=&\@<&AP.B\O<W1D:6XL(&9O<B!I;G-T86YC92`M"B`@("`@
M*B!W:&%T979E<B!I<R!E87-I97-T('1O(&AA;F1L92!I;B!T:&4@9V5T4F5S
M<&]N<V4H*2!M971H;V0N"B`@("`@*@H@("`@("H@5&AE(&)A<V4@8VQA<W,@
M:6UP;&5M96YT871I;VX@;&]O:W,@9F]R("1(5%107U)!5U]03U-47T1!5$$@
M86YD"B`@("`@*B!R971U<FYS('1H870@:68@:70G<R!A=F%I;&%B;&4[(&]T
M:&5R=VES92P@:70@<F5T=7)N<R!T:&4*("`@("`J(&-O;G1E;G1S(&]F('!H
M<#HO+W-T9&EN+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!I
M;G!U="`M(&$@<W1R:6YG("AD969A=6QT*2P@82!F:6QE:&%N9&QE+"!E=&,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN<'5T*"D*("`@('L*("`@("`@
M("!I9B`H:7-S970H)$=,3T)!3%-;)TA45%!?4D%77U!/4U1?1$%402==*2D@
M>PH@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)TA45%!?4D%77U!/4U1?
M1$%402==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!I
M;7!L;V1E*")<<EQN(BP@9FEL92@G<&AP.B\O:6YP=70G*2D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E<W0@
M=&\@=&AE('-E<G9E<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@(%1H92!R87<@<F5Q=65S="!S=')I;F<N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!834P@96YC;V1E
M9"!R97-P;VYS92!F<F]M('1H92!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%)E<W!O;G-E*"1R97%U97-T*0H@("`@>PH@("`@("`@(')E='5R
M;B!?*")N;W0@:6UP;&5M96YT960B*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@0V]N=&5N="U4>7!E(&]F('1H92!R97-P;VYS92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@0V]N=&5N="U4>7!E
M(&]F('1H92!24$,@<F5S<&]N<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%)E<W!O;G-E0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G
M=&5X="]X;6PG.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&%N(%)0
M0R!R97%U97-T(&%N9"!S96YD<R!I="!T;R!T:&4@4E!#('-E<G9E<BX*("`@
M("`J"B`@("`@*B!4:&ES('-T871I8V%L;'D@8V%L;&5D(&UE=&AO9"!I<R!A
M8W1U86QL>2!T:&4@4E!#(&-L:65N="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D<FEV97(@("`@5&AE('!R;W1O8V]L(&1R:79E<B!T;R!U<V4N
M($-U<G)E;G1L>2`G<V]A<"<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!A;F0@)WAM;')P8R<@87)E(&%V86EL86)L92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'5R;"`@("`@("!4:&4@<&%T:"!T;R!T:&4@4E!#('-E<G9E
M<B!O;B!T:&4@8V%L;&5D(&AO<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M971H;V0@("`@5&AE(&UE=&AO9"!T;R!C86QL+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!N96-E<W-A
M<GD@<&%R86UE=&5R<R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@;65T:&]D(&-A;&PN"B`@("`@*B!`<&%R86T@)&]P=&EO;G,@
M("`@("`@("`@07-S;V-I871I=F4@87)R87D@;V8@<&%R86UE=&5R<R!D97!E
M;F1I;F<@;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M<V5L96-T960@<')O=&]C;VP@9')I=F5R+@H@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@("`@("`@("`@("!4:&4@<F5T=7)N960@<F5S=6QT(&9R;VT@
M=&AE(&UE=&AO9"!O<B!A(%!%05(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!E<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5Q=65S="@D9')I=F5R+"`D=7)L+"`D;65T:&]D+"`D<&%R
M86US(#T@;G5L;"P@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1A
M<'`L("1D<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@("`@("1D
M<FEV97(@/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*"%E;7!T
M>2@D87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)&%P<"`N("<O
M;&EB+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I
M9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]24$,O)R`N
M("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O4E!#+R<@+B`D9')I=F5R("X@)RYP
M:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N
M8V4@)TAO<F1E+U)00R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]
M"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7U)00U\G("X@)&1R:79E<CL*("`@
M("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&-A;&Q?=7-E<E]F=6YC*&%R<F%Y*"1C;&%S<RP@)W)E<75E<W0G
M*2P@)'5R;"P@)&UE=&AO9"P@)'!A<F%M<RP@)&]P=&EO;G,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@
M9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M=7)N(&$@8V]N8W)E=&4@4E!#('-E<G9E<B!I;G-T86YC92!B87-E9"!O;@H@
M("`@("H@)&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R
M:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@4E!#('-U8F-L87-S('1O(')E
M='5R;BX@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D9')I=F5R
M(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:R!I;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("1D<FEV97);,%TO;&EB+U)00R\@9F]R('1H
M92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE
M;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C;&%S<R!M:6=H="!N
M965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?4E!#("!4:&4@;F5W
M;'D@8W)E871E9"!C;VYC<F5T92!(;W)D95]24$,@<V5R=F5R(&EN<W1A;F-E
M+`H@("`@("H@("`@("`@("`@("`@("`@("`@(&]R(&$@4$5!4E]%<G)O<B!O
M;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R
M:79E<BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1D<FEV97(I*2!["B`@("`@("`@("`@(&QI<W0H)&%P<"P@)&1R:79E
M<BD@/2`D9')I=F5R.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A
M<V5N86UE*"1D<FEV97(I.PH*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2![
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`D87!P("X@)R]L:6(O4E!#+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E
M>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)00R\G("X@)&1R:79E<B`N
M("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]24$,O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O
M4E!#+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D
M8VQA<W,@/2`G2&]R9&5?4E!#7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D<G!C(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@("1R<&,@
M/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D
M8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<G!C.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@4E!#('-E<G9E<@H@
M("`@("H@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY
M(&-R96%T92!A(&YE=R!I;G-T86YC90H@("`@("H@:68@;F\@4E!#('-E<G9E
M<B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R<F5N=&QY
M"B`@("`@*B!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@
M=7-E9"!I9B!M=6QT:7!L92!24$,@<V5R=F5R<R`H86YD('1H=7,L(&UU;'1I
M<&QE(%)00PH@("`@("H@<V5R=F5R(&EN<W1A;F-E<RD@87)E(')E<75I<F5D
M+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A
M<SH@)'9A<B`]("9(;W)D95]24$,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T
M92!24$,@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C
M;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N
M"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]24$,@(%1H92!C;VYC<F5T
M92!(;W)D95]24$,@<V5R=F5R(')E9F5R96YC92P@;W(@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;VX@86X@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R:79E<BP@)'!A<F%M<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,["@H@("`@
M("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T
M=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@
M("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)'-I9VYA='5R92P@)&EN<W1A
M;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]
M("9(;W)D95]24$,Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<RD["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]60RYP:'``
M````````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S
M-#4P-R`Q,#4Q-30S-#$T,"`P,C`S-S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%-O<G1I;F<@;W!T
M:6]N<PH@*B\*9&5F:6YE*"=60U]33U)47TY/3D4G+"`P*3L@("`@("`@("\O
M(&1O;B=T('-O<G0*9&5F:6YE*"=60U]33U)47T%'12<L(#$I.R`@("`@("`@
M("\O('-O<G0@8GD@86=E"F1E9FEN92@G5D-?4T]25%].04U%)RP@,BD[("`@
M("`@("`O+R!S;W)T(&)Y(&9I;&5N86UE"F1E9FEN92@G5D-?4T]25%]2158G
M+"`S*3L@("`@("`@("`O+R!S;W)T(&)Y(')E=FES:6]N(&YU;6)E<@ID969I
M;F4H)U9#7U-/4E1?05542$]2)RP@-"D[("`@("`@+R\@<V]R="!B>2!A=71H
M;W(@;F%M90H*9&5F:6YE*"=60U]33U)47T%30T5.1$E.1R<L(#`I.R`@("\O
M(&%S8V5N9&EN9R!O<F1E<@ID969I;F4H)U9#7U-/4E1?1$530T5.1$E.1R<L
M(#$I.R`@+R\@9&5S8V5N9&EN9R!O<F1E<@H*9&5F:6YE*"=60U]724Y$3U=3
M)RP@<W5B<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<I.PH*+RHJ"B`J(%9E
M<G-I;VX@0V]N=')O;"!G96YE<F%L:7IE9"!L:6)R87)Y+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]60R]60RYP:'`L=B`Q+C$R+C@N,3(@,C`P-B\P-2\S
M,2`Q-SHP-CHS-R!S96QS:WD@17AP("0*("H*("H@0'!A8VMA9V4@5D,*("HO
M"F-L87-S(%9#('L*"B`@("`O*BH*("`@("`J(%1H92!S;W5R8V4@<F]O="!O
M9B!T:&4@<F5P;W-I=&]R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<V]U
M<F-E<F]O=#L*"B`@("`O*BH*("`@("`J($AA<V@@=VET:"!T:&4@;&]C871I
M;VYS(&]F(&%L;"!N96-E<W-A<GD@8FEN87)I97,N"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A=&AS(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J($AA<V@@8V%C:&EN9R!T:&4@<&%R<V5D('5S97)S(&9I;&4N
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W5S97)S.PH*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!S;W5R8V4@<F]O="!F;W(@=&AI
M<R!R97!O<VET;W)Y+"!W:71H(&YO('1R86EL:6YG("\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@4V]U<F-E(')O;W0@9F]R('1H:7,@<F5P;W-I
M=&]R>2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V]U<F-E<F]O="@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V]U<F-E<F]O=#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&QO8V%T:6]N(&]F('1H92!S<&5C
M:69I960@8FEN87)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)I
M;F%R>2`@06X@97AT97)N86P@<')O9W)A;2!N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;GQS=')I;F<@(%1H92!L;V-A=&EO;B!O9B!T:&4@
M97AT97)N86P@<')O9W)A;2!O<B!F86QS92!I9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@:70@=V%S;B=T('-P96-I9FEE9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%T:"@D8FEN87)Y*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A=&AS6R1B:6YA<GE=*2D@>PH@("`@("`@("`@
M("!I9B`H5D-?5TE.1$]74RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%T:'-;)&)I;F%R>5T["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@:7-?97AE8W5T86)L92@D=&AI<RT^7W!A
M=&AS6R1B:6YA<GE=*2`_("1T:&ES+3Y?<&%T:'-;)&)I;F%R>5T@.B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V4@=&AE('5S97)S(&9I
M;&4L(&EF('!R97-E;G0@:6X@=&AE('-O=7)C92!R;V]T+"!A;F0@<F5T=7)N
M"B`@("`@*B!A(&AA<V@@8V]N=&%I;FEN9R!T:&4@<F5Q=6ES:71E(&EN9F]R
M;6%T:6]N+"!K97EE9"!O;B!T:&4*("`@("`J('5S97)N86UE+"!A;F0@=VET
M:"!T:&4@)V1E<V,G+"=N86UE)RP@86YD("=M86EL)R!V86QU97,@:6YS:61E
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQA<G)A>2`@1F%L<V4@
M:68@=&AE(&9I;&4@:7,@;F]T('!R97-E;G0L(&]T:&5R=VES90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97)S('!O<'5L871E
M9"!W:71H('1H92!D871A"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5S97)S
M*"1U<V5R<V9I;&4I"B`@("!["B`@("`@("`@+RH@0VAE8VL@=&AA="!W92!H
M879E;B=T(&%L<F5A9'D@<&%R<V5D('5S97)S+B`J+PH@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W5S97)S*2`F)B!I<U]A<G)A>2@D=&AI<RT^7W5S97)S
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]U<V5R<SL*("`@("`@
M("!]"@H@("`@("`@(&EF("@A0&ES7V9I;&4H)'5S97)S9FEL92D@?'P@(2@D
M9FP@/2!`9F]P96XH)'5S97)S9FEL92P@5D-?5TE.1$]74R`_("=R8B<@.B`G
M<B<I*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7W5S97)S(#T@87)R87DH*3L*"B`@("`@("`@+RH@
M1&ES8V%R9"!T:&4@9FER<W0@;&EN92P@<VEN8V4@:70G;&P@8F4@=&AE(&AE
M861E<B!I;F9O+B`J+PH@("`@("`@(&9G971S*"1F;"P@-#`Y-BD["@H@("`@
M("`@("\J(%!A<G-E('1H92!R97-T(&]F('1H92!L:6YE<R!I;G1O(&$@:&%S
M:"P@:V5Y960@;VX*("`@("`@("`@*B!U<V5R;F%M92X@*B\*("`@("`@("!W
M:&EL92`H)&QI;F4@/2!F9V5T<R@D9FPL(#0P.38I*2!["B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7EQS*B0O)RP@)&QI;F4I*2!["B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H)R]>*%QW*RE<<RLH+BLI7',K*%M<=UPN7"U<7UTK
M0%M<=UPN7"U<7UTK*5QS*R@N*BDD+R<L("1L:6YE+"`D<F5G<RDI('L*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=&AI<RT^7W5S97)S6R1R96=S6S%=75LG;F%M92==(#T@=')I;2@D
M<F5G<ULR72D["B`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)')E9W-;,5U=
M6R=M86EL)UT@/2!T<FEM*"1R96=S6S-=*3L*("`@("`@("`@("`@)'1H:7,M
M/E]U<V5R<ULD<F5G<ULQ75U;)V1E<V,G72`]('1R:6TH)')E9W-;-%TI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=7-E<G,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T
M92!60R!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!6
M0R!S=6)C;&%S<R!T;R!R971U<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@5&AE(&-O9&4@:7,@9'EN86UI8V%L;'D@:6YC;'5D960N"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&]R("!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%9#("!4:&4@;F5W;'D@8W)E871E
M9"!C;VYC<F5T92!60R!I;G-T86YC92P@;W(@4$5!4E]%<G)O<B!O;@H@("`@
M("H@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@:6YC;'5D95]O;F-E("=60R\G("X@)&1R:79E<B`N("<N<&AP)SL*
M("`@("`@("`D8VQA<W,@/2`G5D-?)R`N("1D<FEV97(["B`@("`@("`@:68@
M*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1V8R`](&YE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9C(#T@4$5!4CHZ<F%I<V5%<G)O<B@D8VQA<W,@+B`G(&YO="!F;W5N
M9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F,["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@
M=&\@82!C;VYC<F5T92!60R!I;G-T86YC92!B87-E9`H@("`@("H@;VX@)&1R
M:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N
M;R!60PH@("`@("H@:6YS=&%N8V4@=VET:"!T:&4@<V%M92!P87)A;65T97)S
M(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@("`@("H@5&AI<R!S:&]U;&0@
M8F4@=7-E9"!I9B!M=6QT:7!L92!T>7!E<R!O9B!F:6QE(&)A8VME;F1S("AA
M;F0L"B`@("`@*B!T:'5S+"!M=6QT:7!L92!60R!I;G-T86YC97,I(&%R92!R
M97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN
M=F]K960@87,Z("1V87(@/2`F5D,Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H92!T>7!E(&]F(&-O;F-R971E
M(%9#('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!4:&4@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@;W(@<&%R86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!60R`@5&AE(&-O;F-R971E(%9#
M(')E9F5R96YC92P@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@
M("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@("`@)&EN
M<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D<VEG;F%T
M=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*3L*("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2!60SHZ9F%C=&]R
M>2@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:6YS=&%N8V5S6R1S:6=N871U<F5=.PH@("`@?0H*?0H*+RHJ"B`J($!P
M86-K86=E(%9#"B`J+PIC;&%S<R!60U]$:69F('L*"B`@("`O*BH*("`@("`J
M($]B=&%I;B!A('1R964@8V]N=&%I;FEN9R!I;F9O<FUA=&EO;B!A8F]U="!T
M:&4@8VAA;F=E<R!B971W965N"B`@("`@*B!T=V\@<F5V:7-I;VYS+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<F%W("!!;B!A<G)A>2!O9B!L:6YE
M<R!O9B!T:&4@<F%W('5N:69I960@9&EF9BP*("`@("`J("`@("`@("`@("`@
M("`@("`@("!N;W)M86QL>2!O8G1A:6YE9"!T:')O=6=H(%9#7T1I9F8Z.F=E
M="@I+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J"B`@("`@
M*B!`=&]D;R!D;V-U;65N="!T:&ES('1H;W)O=6=H;'DL(&%S('1H92!F;W)M
M870@:7,@82!B:70@8V]M<&QE>"X*("`@("`J+PH@("`@9G5N8W1I;VX@:'5M
M86Y296%D86)L92@D<F%W*0H@("`@>PH@("`@("`@("1R970@/2!A<G)A>2@I
M.PH*("`@("`@("`O*B!(;VQD('1H92!L969T(&%N9"!R:6=H="!C;VQU;6YS
M(&]F(&QI;F5S(&9O<B!C:&%N9V4*("`@("`@("`@*B!B;&]C:W,N("HO"B`@
M("`@("`@)&-O;',@/2!A<G)A>2AA<G)A>2@I+"!A<G)A>2@I*3L*("`@("`@
M("`D<W1A=&4@/2`G96UP='DG.PH*("`@("`@("`O*B!)=&5R871E('1H<F]U
M9V@@979E<GD@;&EN92!O9B!T:&4@9&EF9BX@*B\*("`@("`@("!F;W)E86-H
M("@D<F%W(&%S("1L:6YE*2!["B`@("`@("`@("`@("\J($QO;VL@9F]R(&$@
M:&5A9&5R('=H:6-H(&EN9&EC871E<R!T:&4@<W1A<G0@;V8@82!D:69F"B`@
M("`@("`@("`@("`J(&-H=6YK+B`J+PH@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UY`0"!<+2A;,"TY72LI+BI<*RA;,"TY72LI+BI`0"@N*BDO)RP@
M)&QI;F4L("1R96=S*2D@>PH@("`@("`@("`@("`@("`@+RH@4'5S:"!A;GD@
M<')E=FEO=7,@:&5A9&5R(&EN9F]R;6%T:6]N('1O('1H92!R971U<FX*("`@
M("`@("`@("`@("`@("`J('-T86-K+B`J+PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D871A*2D@>PH@("`@("`@("`@("`@("`@("`@("1R971;72`]
M("1D871A.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A
M=&$@/2!A<G)A>2@G='EP92<@/3X@)VAE861E<B<L("=O;&1L:6YE)R`]/B`D
M<F5G<ULQ72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYE=VQI
M;F4G(#T^("1R96=S6S)=+"`G8V]N=&5N=',G/B!A<G)A>2@I*3L*("`@("`@
M("`@("`@("`@("1D871A6R=F=6YC=&EO;B==(#T@:7-S970H)')E9W-;,UTI
M(#\@)')E9W-;,UT@.B`G)SL*("`@("`@("`@("`@("`@("1S=&%T92`]("=D
M=6UP)SL*("`@("`@("`@("`@?2!E;'-E:68@*"1S=&%T92`A/2`G96UP='DG
M*2!["B`@("`@("`@("`@("`@("`O*B!792!A<F4@:6X@82!C:'5N:RP@<V\@
M<W!L:70@;W5T('1H92!A8W1I;VX@*"LO+2D*("`@("`@("`@("`@("`@("`J
M(&%N9"!T:&4@;&EN92X@*B\*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H
M)R]>*%M<*UPM(%TI*"XJ*2\G+"`D;&EN92P@)')E9W,I.PH@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1R96=S*2`^(#(I('L*("`@("`@("`@("`@("`@
M("`@("`D86-T:6]N(#T@)')E9W-;,5T["B`@("`@("`@("`@("`@("`@("`@
M)&-O;G1E;G0@/2`D<F5G<ULR73L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&%C=&EO;B`]("<@)SL*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N="`]("<G.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@(&EF("@D86-T:6]N(#T]("<K)RD@>PH@("`@("`@
M("`@("`@("`@("`@("\J(%1H:7,@:7,@:G5S="!A;B!A9&1I=&EO;B!L:6YE
M+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("@D<W1A=&4@/3T@)V1U;7`G
M('Q\("1S=&%T92`]/2`G861D)RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`O*B!3=&%R="!A9&1I;F<@=&\@=&AE(&%D9&ET:6]N('-T86-K+B`J+PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]L<ULP75M=(#T@)&-O;G1E;G0[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=A9&0G.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("\J(%1H:7,@:7,@:6YS:61E(&$@8VAA;F=E(&)L;V-K+"!S;R!S=&%R
M=`H@("`@("`@("`@("`@("`@("`@("`@("`@*B!A8V-U;75L871I;F<@;&EN
M97,N("HO"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=C:&%N
M9V4G.PH@("`@("`@("`@("`@("`@("`@("`@("`D8V]L<ULQ75M=(#T@)&-O
M;G1E;G0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1A8W1I;VX@/3T@)RTG*2!["B`@("`@("`@("`@("`@("`@
M("`@+RH@5&AI<R!I<R!A(')E;6]V86P@;&EN92X@*B\*("`@("`@("`@("`@
M("`@("`@("`D<W1A=&4@/2`G<F5M;W9E)SL*("`@("`@("`@("`@("`@("`@
M("`D8V]L<ULP75M=(#T@)&-O;G1E;G0["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($%N(&5M<'1Y(&)L;V-K('=I
M=&@@;F\@86-T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H
M)'-T871E*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G861D)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R
M<F%Y*"=T>7!E)R`]/B`G861D)RP@)VQI;F5S)R`]/B`D8V]L<ULP72D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=R96UO=F4G.@H@("`@("`@("`@("`@("`@("`@("`@("`O
M*B!792!H879E('-O;64@<F5M;W9A;"!L:6YE<R!P96YD:6YG(&EN(&]U<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@*B!S=&%C:RP@<V\@9FQU<V@@=&AE
M;2X@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E;G1S
M)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G<F5M;W9E)RP@)VQI;F5S)R`]/B`D
M8V]L<ULP72D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@("`@("!C87-E("=C:&%N9V4G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`O*B!792!H879E(&)O=&@@<F5M;W9E(&%N9"!A9&1I=&EO
M;B!L:6YE<RP@<V\*("`@("`@("`@("`@("`@("`@("`@("`@("H@=&AI<R!I
M<R!A(&-H86YG92!B;&]C:RX@*B\*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;)V-O;G1E;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G8VAA;F=E
M)RP@)V]L9"<@/3X@)&-O;'-;,%TL("=N97<G(#T^("1C;VQS6S%=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("1C;VQS(#T@87)R87DH87)R87DH
M*2P@87)R87DH*2D["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V-O;G1E
M;G1S)UU;72`](&%R<F%Y*"=T>7!E)R`]/B`G96UP='DG+"`G;&EN92<@/3X@
M)&-O;G1E;G0I.PH@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=D=6UP
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@2G5S="!F;'5S:"!A;GD@<F5M86EN:6YG(&5N=')I97,@
M:6X@=&AE(&-O;'5M;G,@<W1A8VLN("HO"B`@("`@("`@<W=I=&-H("@D<W1A
M=&4I('L*("`@("`@("!C87-E("=A9&0G.@H@("`@("`@("`@("`D9&%T85LG
M8V]N=&5N=',G75M=(#T@87)R87DH)W1Y<&4G(#T^("=A9&0G+"`G;&EN97,G
M(#T^("1C;VQS6S!=*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W)E;6]V92<Z"B`@("`@("`@("`@("\J(%=E(&AA=F4@<V]M92!R96UO
M=F%L(&QI;F5S('!E;F1I;F<@:6X@;W5R('-T86-K+"!S;PH@("`@("`@("`@
M("`@*B!F;'5S:"!T:&5M+B`J+PH@("`@("`@("`@("`D9&%T85LG8V]N=&5N
M=',G75M=(#T@87)R87DH)W1Y<&4G(#T^("=R96UO=F4G+"`G;&EN97,G(#T^
M("1C;VQS6S!=*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)V-H86YG92<Z"B`@("`@("`@("`@("\J(%=E(&AA=F4@8F]T:"!R96UO=F4@
M86YD(&%D9&ET:6]N(&QI;F5S+"!S;R!T:&ES(&ES(&$*("`@("`@("`@("`@
M("H@8VAA;F=E(&)L;V-K+B`J+PH@("`@("`@("`@("`D9&%T85LG8V]N=&5N
M=',G75M=(#T@87)R87DH)W1Y<&4G(#T^("=C:&%N9V4G+"`G;VQD)R`]/B`D
M8V]L<ULP72P@)VYE=R<@/3X@)&-O;'-;,5TI.PH@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D9&%T82DI('L*("`@
M("`@("`@("`@)')E=%M=(#T@)&1A=&$["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E=#L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!60PH@*B\*
M8VQA<W,@5D-?1FEL92!["@H@("`@=F%R("1R97`["B`@("!V87(@)&1I<CL*
M("`@('9A<B`D;F%M93L*("`@('9A<B`D;&]G<SL*("`@('9A<B`D<F5V<SL*
M("`@('9A<B`D:&5A9#L*("`@('9A<B`D<75I8VML;V<["B`@("!V87(@)'-Y
M;7)E=CL*("`@('9A<B`D<F5V<WEM.PH@("`@=F%R("1B<F%N8VAE<SL*"B`@
M("!F=6YC=&EO;B!S971297!O<VET;W)Y*"1R97`I"B`@("!["B`@("`@("`@
M)'1H:7,M/G)E<"`]("1R97`["B`@("!]"@I]"@HO*BH*("H@5D,@<&%T8VAS
M970@8VQA<W,N"B`J"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U]0871C
M:'-E="!["@H@("`@=F%R("1?<F5P.PH@("`@=F%R("1?<&%T8VAS971S(#T@
M87)R87DH*3L*"B`@("!F=6YC=&EO;B!S971297!O<VET;W)Y*"1R97`I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]R97`@/2`D<F5P.PH@("`@?0H*?0H*+RHJ
M"B`J(%9#(')E=FES:6]N<R!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@
M36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R
M("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C
M:V%G92!60PH@*B\*8VQA<W,@5D-?4F5V:7-I;VX@>PH*("`@("\J*@H@("`@
M("H@5F%L:61A=&EO;B!F=6YC=&EO;B!T;R!E;G-U<F4@=&AA="!A(')E=FES
M:6]N(&YU;6)E<B!I<R!O9B!T:&4*("`@("`J(')I9VAT(&9O<FTN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L("!686QU92!T;R!C:&5C:RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@:70@:7,@
M82!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:60H
M)'9A;"D*("`@('L*("`@("`@("!R971U<FX@)'9A;"`F)B!P<F5G7VUA=&-H
M*"<O7EM<9%PN72LD+R<L("1V86PI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1VEV96X@82!R979I<VEO;B!N=6UB97(L(')E;6]V92!A(&=I=F5N(&YU;6)E
M<B!O9B!P;W)T:6]N<R!F<F]M"B`@("`@*B!I="X@1F]R(&5X86UP;&4L(&EF
M('=E(')E;6]V92`R('!O<G1I;VYS(&]F(#$N,BXS+C0L('=E(&%R90H@("`@
M("H@;&5F="!W:71H(#$N,BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1V86P@("`@("!);G!U="!R979I<VEO;@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&%M;W5N="`@3G5M8F5R(&]F('!O<G1I;VYS('1O('-T<FEP"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-T<FEP<&5D(')E=FES:6]N(&YU
M;6)E<@H@("`@("HO"B`@("!F=6YC=&EO;B!S=')I<"@D=F%L+"`D86UO=6YT
M*0H@("`@>PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1V86PI
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@
M("`@)'!O<R`](#`["B`@("`@("`@=VAI;&4@*"1A;6]U;G0M+2`^(#`@)B8@
M*"1P;W,@/2!S=')R<&]S*"1V86PL("<N)RDI("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D=F%L(#T@<W5B<W1R*"1V86PL(#`L("1P;W,I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'!O<R`A/3T@9F%L<V4@/R`D=F%L(#H@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@<VEZ92!O9B!A(')E=FES
M:6]N(&YU;6)E<B!I<R!T:&4@;G5M8F5R(&]F('!O<G1I;VYS(&ET(&AA<RX*
M("`@("`J($9O<B!E>&%M<&QE+"`Q+#(N,RXT(&ES(&]F('-I>F4@-"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86P@(%)E=FES:6]N(&YU;6)E
M<B!T;R!D971E<FUI;F4@<VEZ92!O9@H@("`@("H*("`@("`J($!R971U<FX@
M:6YT96=E<B`@4VEZ92!O9B!R979I<VEO;B!N=6UB97(*("`@("`J+PH@("`@
M9G5N8W1I;VX@<VEZ96]F*"1V86PI"B`@("!["B`@("`@("`@:68@*"%60U]2
M979I<VEO;CHZ=F%L:60H)'9A;"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AS=6)S=')?8V]U;G0H
M)'9A;"P@)RXG*2`K(#$I.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@
M82!V86QI9"!R979I<VEO;B!N=6UB97(L('1H:7,@=VEL;"!R971U<FX@=&AE
M(')E=FES:6]N"B`@("`@*B!N=6UB97(@9G)O;2!W:&EC:"!I="!B<F%N8VAE
M9"X@268@:70@8V%N;F]T(&)E(&1E=&5R;6EN960L('1H96X*("`@("`J(&9A
M;'-E(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'9A;"`@4F5V:7-I;VX@;G5M8F5R+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG?&)O;VQE86X@($)R86YC:"!P;VEN="!R979I<VEO;BP@;W(@9F%L
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)R86YC:%!O:6YT*"1V86PI"B`@
M("!["B`@("`@("`@+RH@0VAE8VL@:68@=V4@:&%V92!A('9A;&ED(')E=FES
M:6]N(&YU;6)E<B`J+PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED
M*"1V86PI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J($EF(&ET<R!O;B!T:&4@=')U;FLL(&]R(&ES(&%N(&]D
M9"!S:7IE+"!R970@9F%L<V4@*B\*("`@("`@("!I9B`H5D-?4F5V:7-I;VXZ
M.G-I>F5O9B@D=F%L*2`\(#,@?'P@*%9#7U)E=FES:6]N.CIS:7IE;V8H)'9A
M;"D@)2`R*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`O*B!3=')I<"!O9F8@='=O(')E=FES:6]N('!O<G1I;VYS
M+"!A;F0@<F5T=7)N(&ET("HO"B`@("`@("`@<F5T=7)N(%9#7U)E=FES:6]N
M.CIS=')I<"@D=F%L+"`R*3L*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N
M('1W;R!35DX@<F5V:7-I;VX@;G5M8F5R<RP@=&AI<R!F:6=U<F5S(&]U="!W
M:&EC:"!O;F4@:7,*("`@("`J(&=R96%T97(@=&AA;B!T:&4@;W1H97(@8GD@
M<W1E<'!I;F<@86QO;F<@=&AE(&1E8VEM86P@<&]I;G1S"B`@("`@*B!U;G1I
M;"!A(&1I9F9E<F5N8V4@:7,@9F]U;F0L(&%T('=H:6-H('!O:6YT(&$@<VEG
M;B!C;VUP87)I<V]N"B`@("`@*B!O9B!T:&4@='=O(&ES(')E='5R;F5D+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E=C$@(%!E<FEO9"!D96QI
M;6ET960@<F5V:7-I;VX@;G5M8F5R"B`@("`@*B!`<&%R86T@<W1R:6YG("1R
M978R("!396-O;F0@<&5R:6]D(&1E;&EM:71E9"!R979I<VEO;B!N=6UB97(*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#$@:68@=&AE(&9I<G-T
M(&ES(&=R96%T97(L("TQ(&EF('1H92!S96-O;F0@:68@9W)E871E<BP*("`@
M("`J("`@("`@("`@("`@("`@("`@86YD(#`@:68@=&AE>2!A<F4@97%U86P*
M("`@("`J+PH@("`@9G5N8W1I;VX@8VUP*"1R978Q+"`D<F5V,BD*("`@('L*
M("`@("`@("!R971U<FX@=F5R<VEO;E]C;VUP87)E*"1R978Q+"`D<F5V,BD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QO9VEC86P@<F5V
M:7-I;VX@8F5F;W)E('1H:7,@;VYE+B!.;W)M86QL>2P@=&AI<PH@("`@("H@
M=VEL;"!B92!T:&4@<F5V:7-I;VX@;6EN=7,@;VYE+"!B=70@:6X@=&AE(&-A
M<V4@;V8@82!N97<*("`@("`J(&)R86YC:"P@=V4@<W1R:7`@;V9F('1H92!L
M87-T('1W;R!D96-I;6%L('!L86-E<R!T;R!R971U<FX@=&AE"B`@("`@*B!O
M<FEG:6YA;"!B<F%N8V@@<&]I;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5V("!2979I<VEO;B!N=6UB97(@=&\@9&5C<F5M96YT+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG?&)O;VQE86X@(%)E=FES:6]N(&YU
M;6)E<BP@;W(@9F%L<V4@:68@;F]N92!C;W5L9"!B90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@9&5T97)M:6YE9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E=B@D<F5V*0H@("`@>PH@("`@("`@("1L87-T7V1O="`]('-T
M<G)P;W,H)')E=BP@)RXG*3L*("`@("`@("`D=F%L(#T@<W5B<W1R*"1R978L
M("LK)&QA<W1?9&]T*3L*"B`@("`@("`@:68@*"TM)'9A;"`^(#`I('L*("`@
M("`@("`@("`@<F5T=7)N('-U8G-T<B@D<F5V+"`P+"`D;&%S=%]D;W0I("X@
M)'9A;#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&%S=%]D;W0M
M+3L*("`@("`@("`@("`@=VAI;&4@*"TM)&QA<W1?9&]T*2!["B`@("`@("`@
M("`@("`@("!I9B`H)')E=ELD;&%S=%]D;W1=(#T]("<N)RD@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`@<W5B<W1R*"1R978L(#`L("1L87-T7V1O
M="D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E=ELD;&%S=%]D;W1=
M(#T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A(')E=FES:6]N(&YU;6)E<B!O
M9B!T:&4@9F]R;2!X+GDN,"YZ+"!T:&ES(')E;6%P<R!I=`H@("`@("H@:6YT
M;R!T:&4@87!P<F]P<FEA=&4@8G)A;F-H(&YU;6)E<BP@=VAI8V@@:7,@>"YY
M+GH*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R978@($5V96XM9&EG
M:70@<F5V:7-I;VX@;G5M8F5R(&]F(&$@8G)A;F-H"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@($]D9"UD:6=I="!"<F%N8V@@;G5M8F5R"B`@("`@
M*B\*("`@(&9U;F-T:6]N('1O0G)A;F-H*"1R978I"B`@("!["B`@("`@("`@
M+RH@0VAE8VL@:68@=V4@:&%V92!A('9A;&ED(')E=FES:6]N(&YU;6)E<B`J
M+PH@("`@("`@(&EF("@A5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF
M("@H)&5N9"`]('-T<G)P;W,H)')E=BP@)RXG*2D@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R
M979;)&5N9%T@/2`P.PH@("`@("`@(&EF("@H)&5N9#(@/2!S=')R<&]S*"1R
M978L("<N)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@<W5B
M<W1R*"1R978L("LK)&5N9"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M<W5B<W1R7W)E<&QA8V4H)')E=BP@)RXG+"`D96YD,BP@*"1E;F0M)&5N9#(K
M,2DI.PH@("`@?0H*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]497AT+G!H<```````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C<T-R`Q,#4Q-30S-#$T,"`P,C$P,#8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!497AT.CH@8VQA<W,@<')O=FED97,@8V]M;6]N(&UE=&AO9',@
M9F]R(&UA;FEP=6QA=&EN9R!T97AT+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R](;W)D92](;W)D92]497AT+G!H<"QV(#$N,BXQ,"XU(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S
M<R!497AT('L*"B`@("`O*BH*("`@("`J($-O;G9E<G0@82!L:6YE(&]F('1E
M>'0@=&\@9&ES<&QA>2!P<F]P97)L>2!I;B!(5$U,+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!S=')I;F<@;V8@=&5X="!T;R!C
M;VYV97)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-
M3"UC;VUP;&EA;G0@8V]N=F5R=&5D('1E>'0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AT;6Q3<&%C97,H)'1E>'0@/2`G)RD*("`@('L*("`@("`@("!S=&%T
M:6,@)&-H87)S970["B`@("`@("`@:68@*"%I<W-E="@D8VAA<G-E="DI('L*
M("`@("`@("`@("`@)&-H87)S970@/2!.3%,Z.F=E=$-H87)S970H*3L*("`@
M("`@("!]"@H@("`@("`@("1T97AT(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'1E
M>'0L($5.5%]#3TU0050L("1C:&%R<V5T*3L*("`@("`@("`D=&5X="`]('-T
M<E]R97!L86-E*")<="(L("<F;F)S<#L@)FYB<W`[("9N8G-P.R`F;F)S<#L@
M)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R`@)RP@
M)R9N8G-P.R`G+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C
M92@G("`G+"`G("9N8G-P.R<L("1T97AT*3L*"B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4V%M92!A<R!H=&UL4W!A8V5S
M*"D@8G5T(&-O;G9E<G1S(&%L;"!S<&%C97,@=&\@)FYB<W`["B`@("`@*@H@
M("`@("H@0'-E92!H=&UL4W!A8V5S*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("!4:&4@<W1R:6YG(&]F('1E>'0@=&\@8V]N=F5R="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434PM8V]M<&QI
M86YT(&-O;G9E<G1E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!H=&UL
M06QL4W!A8V5S*"1T97AT(#T@)R<I"B`@("!["B`@("`@("`@)'1E>'0@/2!4
M97AT.CIH=&UL4W!A8V5S*"1T97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R
M97!L86-E*"<@)RP@)R9N8G-P.R<L("1T97AT*3L*"B`@("`@("`@<F5T=7)N
M("1T97AT.PH@("`@?0H*?0H`````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-H87)E+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#<U,3`S(#$P
M-3$U-#,T,30P(#`R,3$R,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]$871A
M5')E92YP:'`G.PH*+RHJ"B`J($AO<F1E7U-H87)E.CH@<')O=FED97,@86X@
M:6YT97)F86-E('1O(&%L;"!S:&%R97,@82!U<V5R(&UI9VAT(&AA=F4N("!)
M=',*("H@;65T:&]D<R!T86ME(&-A<F4@;V8@86YY('-I=&4M<W!E8VEF:6,@
M<F5S=')I8W1I;VYS(&-O;F9I9W5R960@:6X@:6X@=&AE"B`J(&%P<&QI8V%T
M:6]N)W,@<')E9G,N<&AP(&%N9"!C;VYF+G!H<"!F:6QE<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4VAA<F4O4VAA<F4N<&AP+'8@,2XQ,3$N,BXR,"`R
M,#`V+S`U+S`T(#$S.C(U.C(Y(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($IO96P@5F%N9&%L(#QJ=F%N9&%L0&EN9F]T96-K+G%C+F-A
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($EN9F]T96-K($EN=&5R;F5T(#QW
M96)M87-T97)`:6YF;W1E8VLN<6,N8V$^"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I;F9O
M=&5C:RYQ8RYC83X*("H@0&%U=&AO<B`@36EK92!#;V-H<F%M92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]3:&%R90H@*B\*8VQA<W,@2&]R9&5?4VAA<F4@>PH*
M("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A($1A=&%4<F5E(&EN<W1A;F-E
M('1O(&UA;F%G92]S=&]R92!S:&%R97,*("`@("`J"B`@("`@*B!`=F%R($1A
M=&%4<F5E"B`@("`@*B\*("`@('9A<B`D7V1A=&%T<F5E.PH*("`@("\J*@H@
M("`@("H@5&AE(&%P<&QI8V%T:6]N('=E)W)E(&UA;F%G:6YG('-H87)E<R!F
M;W(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?87!P.PH*("`@("\J*@H@("`@("H@5&AE('-U8F-L87-S(&]F($1A=&%4
M<F5E3V)J96-T('1O(&EN<W1A;G1I871E('-H87)E<R!A<RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S:&%R94]B:F5C
M="`]("=$871A5')E94]B:F5C=%]3:&%R92<["@H@("`@+RHJ"B`@("`@*B!!
M(&-A8VAE(&]F(&%L;"!S:&%R97,@=&AA="!H879E(&)E96X@<F5T<FEE=F5D
M+"!S;R!W92!D;VXG="!H:70@=&AE"B`@("`@*B!B86-K96YD(&%G86EN(&%N
M9"!A9V%I;B!F;W(@=&AE;2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7V-A8VAE(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($-A8VAE('5S960@9F]R(&QI<W13:&%R97,H*2X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQI<W1C86-H92`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!(&QI<W0@;V8@;V)J96-T<R!T:&%T
M('=E)W)E(&-U<G)E;G1L>2!S;W)T:6YG+"!F;W(@<F5F97)E;F-E(&1U<FEN
M9R!T:&4*("`@("`J('-O<G1I;F<@86QG;W)I=&AM+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<V]R=$QI<W0["@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@
M82!C;VYC<F5T92!(;W)D95]3:&%R92!I;G-T86YC92X@270*("`@("`J('=I
M;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?4VAA
M<F4@:6YS=&%N8V4@8W5R<F5N=&QY"B`@("`@*B!E>&ES=',N"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.@H@("`@("H@
M("`\8V]D93XD=F%R(#T@)DAO<F1E7U-H87)E.CIS:6YG;&5T;VXH)&%P<"D[
M/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE
M(&%P<&QI8V%T:6]N<R!T:&%T('1H92!S:&%R97,@<F5L871E<R!T;RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U-H87)E("!4:&4@8V]N8W)E=&4@
M4VAA<F4@<F5F97)E;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D87!P*0H@("`@>PH@("`@("`@
M('-T871I8R`D<VAA<F5S.PH*("`@("`@("!I9B`H(6ES<V5T*"1S:&%R97-;
M)&%P<%TI*2!["B`@("`@("`@("`@("1S:&%R97-;)&%P<%T@/2!N97<@2&]R
M9&5?4VAA<F4H)&%P<"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-H
M87)E<ULD87!P73L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&%P<&QI
M8V%T:6]N('1H870@=&AE('-H87)E<R!B96QO;F<@=&\N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U-H87)E*"1A<'`I"B`@("!["B`@("`@("`@9VQO
M8F%L("1C;VYF+"`D<F5G:7-T<GD["@H@("`@("`@(&EF("AE;7!T>2@D8V]N
M9ELG9&%T871R964G75LG9')I=F5R)UTI*2!["B`@("`@("`@("`@($AO<F1E
M.CIF871A;"@G66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N
M9"!T;R!U<V4@4VAA<F5S+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`D9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R
M:79E<B==.PH@("`@("`@("1T:&ES+3Y?87!P(#T@)&%P<#L*("`@("`@("`D
M=&AI<RT^7V1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS:6YG;&5T;VXH"B`@("`@
M("`@("`@("1D<FEV97(L"B`@("`@("`@("`@(&%R<F%Y7VUE<F=E*$AO<F1E
M.CIG971$<FEV97)#;VYF:6<H)V1A=&%T<F5E)RP@)&1R:79E<BDL(&%R<F%Y
M*"=G<F]U<"<@/3X@)VAO<F1E+G-H87)E<RXG("X@)&%P<"DI"B`@("`@("`@
M*3L*"B`@("`@("`@2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:&%R
M95]I;FET)RP@87)R87DH)'1H:7,L("1A<'`I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE($1A=&%4<F5E(&EN<W1A;F-E('5S960@=&\@
M;6%N86=E('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A
M5')E92`@5&AI<R!S:&%R92=S($1A=&%4<F5E(&EN<W1A;F-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F9V5T1&%T851R964H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%T<F5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C="!C;W)R97-P
M;VYD:6YG('1O('1H92!G:79E;B!S:&%R90H@("`@("H@;F%M92P@=VET:"!T
M:&4@9&5T86EL<R!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@<VAA
M<F4@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E
M94]B:F5C=%]3:&%R92`@5&AE(')E<75E<W1E9"!S:&%R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=%-H87)E*"1N86UE*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V-A8VAE6R1N86UE72DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8V%C:&5;)&YA;65=.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]C86-H95LD;F%M95T@/2`F)'1H:7,M/E]D871A=')E92T^
M9V5T3V)J96-T*"1N86UE+"`D=&AI<RT^7W-H87)E3V)J96-T*3L*("`@("`@
M("!I9B`H(6ES7V$H)'1H:7,M/E]C86-H95LD;F%M95TL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD;F%M95TM/G-E=%-H
M87)E3V(H)'1H:7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V%C:&5;)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A($1A=&%4<F5E3V)J96-T7U-H87)E(&]B:F5C="!C;W)R97-P;VYD:6YG
M('1O('1H92!G:79E;B!U;FEQ=64*("`@("`J($E$+"!W:71H('1H92!D971A
M:6QS(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-I9"`@5&AE(&ED(&]F('1H92!S:&%R92!T;R!R971R
M:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N($1A=&%4<F5E3V)J96-T7U-H
M87)E("!4:&4@<F5Q=65S=&5D('-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T4VAA<F5">4ED*"1C:60I"B`@("!["B`@("`@("`@)'-H87)E(#T@
M)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T0GE)9"@D8VED+"`D=&AI<RT^
M7W-H87)E3V)J96-T*3L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1S:&%R92T^<V5T4VAA<F5/8B@D
M=&AI<RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<VAA<F4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&]F($1A=&%4<F5E
M3V)J96-T7U-H87)E(&]B:F5C=',@8V]R<F5S<&]N9&EN9R!T;R!T:&4*("`@
M("`J(&=I=F5N('-E="!O9B!U;FEQ=64@241S+"!W:71H('1H92!D971A:6QS
M(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D8VED<R`@5&AE(&%R<F%Y(&]F(&ED<R!T;R!R971R:65V92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<F5Q=65S=&5D('-H
M87)E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%-H87)E<R@D8VED<RD*
M("`@('L*("`@("`@("`D<VAA<F5S(#T@)'1H:7,M/E]D871A=')E92T^9V5T
M3V)J96-T<R@D8VED<RP@)'1H:7,M/E]S:&%R94]B:F5C="D["B`@("`@("`@
M:68@*&ES7V$H)'-H87)E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'-H87)E<SL*("`@("`@("!]"@H@("`@("`@("1K97ES(#T@
M87)R87E?:V5Y<R@D<VAA<F5S*3L*("`@("`@("!F;W)E86-H("@D:V5Y<R!A
M<R`D:V5Y*2!["B`@("`@("`@("`@(&EF("AI<U]A*"1S:&%R97-;)&ME>5TL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<VAA
M<F5S6R1K97E=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^
M7V-A8VAE6R1K97E=(#T@)B1S:&%R97-;)&ME>5T["B`@("`@("`@("`@("1S
M:&%R97-;)&ME>5TM/G-E=%-H87)E3V(H)'1H:7,I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1S:&%R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@;F5W('-H87)E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@<VAA<F4G<R!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@1&%T851R965/8FIE8W1?4VAA<F4@($$@;F5W('-H87)E
M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=U-H87)E*"1N86UE
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U-H87)E(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y)RD["B`@("`@("`@?0H@("`@("`@("1S:&%R92`]("9N
M97<@)'1H:7,M/E]S:&%R94]B:F5C="@D;F%M92D["B`@("`@("`@)'-H87)E
M+3YS971$871A5')E92@D=&AI<RT^7V1A=&%T<F5E*3L*("`@("`@("`D<VAA
M<F4M/G-E=%-H87)E3V(H)'1H:7,I.PH@("`@("`@("1S:&%R92T^<V5T*"=O
M=VYE<B<L($%U=&@Z.F=E=$%U=&@H*2D["@H@("`@("`@(')E='5R;B`D<VAA
M<F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<VAA<F4@=&\@=&AE
M('-H87)E<R!S>7-T96TN(%1H92!S:&%R92!M=7-T(&9I<G-T(&)E(&-R96%T
M960@=VET:`H@("`@("H@2&]R9&5?4VAA<F4Z.FYE=U-H87)E*"DL(&%N9"!H
M879E(&%N>2!I;FET:6%L(&1E=&%I;',@861D960@=&\@:70L"B`@("`@*B!B
M969O<F4@=&AI<R!F=6YC=&EO;B!I<R!C86QL960N"B`@("`@*@H@("`@("H@
M0'!A<F%M($1A=&%4<F5E3V)J96-T7U-H87)E("1S:&%R92`@5&AE(&YE=R!S
M:&%R92!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%
M05)?17)R;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D4VAA<F4H)'-H87)E*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?82@D<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=3:&%R97,@;75S="!B
M92!$871A5')E94]B:F5C=%]3:&%R92!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T
M(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@)'!E<FT@/2`F)$=,3T)!
M3%-;)W!E<FUS)UTM/FYE=U!E<FUI<W-I;VXH)'-H87)E+3YG971.86UE*"DI
M.PH@("`@("`@(&EF("AI<U]A*"1P97)M+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<&5R;3L*("`@("`@("!]"@H@("`@("`@("\J
M($=I=F4@=&AE(&]W;F5R(&9U;&P@86-C97-S("HO"B`@("`@("`@)'!E<FTM
M/F%D9%5S97)097)M:7-S:6]N*"1S:&%R92T^9V5T*"=O=VYE<B<I+"!015)-
M4U]32$]7+"!F86QS92D["B`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S
M:6]N*"1S:&%R92T^9V5T*"=O=VYE<B<I+"!015)-4U]214%$+"!F86QS92D[
M"B`@("`@("`@)'!E<FTM/F%D9%5S97)097)M:7-S:6]N*"1S:&%R92T^9V5T
M*"=O=VYE<B<I+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@)'!E<FTM
M/F%D9%5S97)097)M:7-S:6]N*"1S:&%R92T^9V5T*"=O=VYE<B<I+"!015)-
M4U]$14Q%5$4L(&9A;'-E*3L*"B`@("`@("`@)'-H87)E+3YS971097)M:7-S
M:6]N*"1P97)M+"!F86QS92D["@H@("`@("`@("1R97-U;'0@/2!(;W)D93HZ
M8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-H87)E7V%D9"<L(&%R<F%Y*"1S:&%R
M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4G
M+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)'-H87)E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!S:&%R92!F<F]M
M('1H92!S:&%R97,@<WES=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J
M($!P87)A;2!$871A5')E94]B:F5C=%]3:&%R92`D<VAA<F4@(%1H92!S:&%R
M92!T;R!R96UO=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%
M05)?17)R;W(@(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5M;W9E4VAA<F4H)'-H87)E*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?82@D<VAA<F4L("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=3:&%R97,@;75S
M="!B92!$871A5')E94]B:F5C=%]3:&%R92!O8FIE8W1S(&]R(&5X=&5N9"!T
M:&%T(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]($AO
M<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VAA<F5?<F5M;W9E)RP@87)R
M87DH)'-H87)E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=H;W)D92<L(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/G)E
M;6]V92@D<VAA<F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O
M('-E92!I9B!A('-H87)E(&AA<R!A;GD@8VAI;&0@<VAA<F5S+@H@("`@("H*
M("`@("`J($!P87)A;2!$871A5')E94]B:F5C=%]3:&%R92`D<VAA<F4@(%1H
M92!S:&%R92!T;R!C:&5C:R!F;W(@8VAI;&1R96XN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@<VAA<F4@
M:&%S(&-H:6QD('-H87)E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@:&%S0VAI
M;&1R96XH)'-H87)E*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D<VAA<F4L
M("=$871A5')E94]B:F5C=%]3:&%R92<I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=3:&%R97,@;75S="!B92!$871A5')E94]B
M:F5C=%]3:&%R92!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("AB;V]L*21T:&ES+3Y?9&%T871R
M964M/F=E=$YU;6)E<D]F0VAI;&1R96XH)'-H87)E*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S:&%R92=S(&1I<F5C="!P87)E;G0@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E("!'970@
M=&AE('!A<F5N="!O9B!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!R971U
M<FX@1&%T851R965/8FIE8W1?4VAA<F4@(%1H92!P87)E;G0@<VAA<F4L(&EF
M(&ET(&5X:7-T<RX*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!A<F5N="@D
M8VAI;&0I"B`@("!["B`@("`@("`@)&ED(#T@)'1H:7,M/E]D871A=')E92T^
M9V5T4&%R96YT*"1C:&EL9"D["B`@("`@("`@:68@*&ES7V$H)&ED+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(21I9"!\?"`H)&ED(#T]($1!5$%44D5%7U)/3U0I
M*2!["B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U!A
M<F5N="!D;V5S(&YO="!E>&ES="XG*3L*("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T4VAA
M<F5">4ED*"1I9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!)1"!O9B!A('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E
M94]B:F5C=%]3:&%R92`@5&AE('-H87)E('1O(')E='5R;B!T:&4@240@;V8N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@<VAA<F4G<R!)
M1"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%-H87)E260H)'-H87)E*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%T<F5E+3YG971)9"@D<VAA<F4M/F=E=$YA;64H*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!5=&EL:71Y(&9U;F-T:6]N('1O(&)E('5S
M960@=VET:"!U87-O<G0H*2!F;W(@<V]R=&EN9R!A<G)A>7,@;V8*("`@("`J
M($AO<F1E7U-H87)E(&]B:F5C=',N"B`@("`@*B!%>&%M<&QE.CQC;V1E/@H@
M("`@("H@=6%S;W)T*"1L:7-T+"!A<G)A>2@G2&]R9&5?4VAA<F4G+"`G7W-O
M<G13:&%R97,G*2D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S;W)T4VAA<F5S
M*"1A+"`D8BD*("`@('L*("`@("`@("`D85!A<G1S(#T@97AP;&]D92@G.B<L
M("1A+3YG971.86UE*"DI.PH@("`@("`@("1B4&%R=',@/2!E>'!L;V1E*"<Z
M)RP@)&(M/F=E=$YA;64H*2D["@H@("`@("`@("1M:6X@/2!M:6XH8V]U;G0H
M)&%087)T<RDL(&-O=6YT*"1B4&%R=',I*3L*("`@("`@("`D:61!(#T@)R<[
M"B`@("`@("`@)&ED0B`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1M:6X[("1I*RLI('L*("`@("`@("`@("`@:68@*"1I9$$I('L*("`@("`@
M("`@("`@("`@("1I9$$@+CT@)SHG.PH@("`@("`@("`@("`@("`@)&ED0B`N
M/2`G.B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&ED02`N/2`D85!A
M<G1S6R1I73L*("`@("`@("`@("`@)&ED0B`N/2`D8E!A<G1S6R1I73L*"B`@
M("`@("`@("`@(&EF("@D:61!("$]("1I9$(I('L*("`@("`@("`@("`@("`@
M("1C=7)!(#T@:7-S970H)'1H:7,M/E]S;W)T3&ES=%LD:61!72D@/R`D=&AI
M<RT^7W-O<G1,:7-T6R1I9$%=+3YG970H)VYA;64G*2`Z("<G.PH@("`@("`@
M("`@("`@("`@)&-U<D(@/2!I<W-E="@D=&AI<RT^7W-O<G1,:7-T6R1I9$)=
M*2`_("1T:&ES+3Y?<V]R=$QI<W1;)&ED0ETM/F=E="@G;F%M92<I(#H@)R<[
M"B`@("`@("`@("`@("`@("!R971U<FX@<W1R;F%T8V%S96-M<"@D8W5R02P@
M)&-U<D(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@8V]U;G0H)&%087)T<RD@/B!C;W5N="@D8E!A<G1S*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K<R!I9B!A('-H87)E(&5X:7-T<R!I;B!T:&4@
M<WES=&5M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-H87)E("!4
M:&4@<VAA<F4@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&EF('1H92!S:&%R92!E>&ES=',L(&9A;'-E(&]T:&5R=VES
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@97AI<W1S*"1S:&%R92D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E92T^97AI<W1S*"1S:&%R
M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;W5N="!O
M9B!A;&P@<VAA<F5S('1H870@)'5S97)I9"!H87,@86-C97-S('1O+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1U<V5R:60@("`@("!4:&4@=7-E
M<FED(&]F('1H92!U<V5R('1O(&-H96-K(&%C8V5S<R!F;W(N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<&5R;2`@("`@("`@5&AE(&QE=F5L(&]F('!E<FUI
M<W-I;VYS(')E<75I<F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I
M8G5T97,@(%)E<W1R:6-T('1H92!S:&%R97,@8V]U;G1E9"!T;R!T:&]S90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&UA=&-H:6YG("1A
M='1R:6)U=&5S+B!!;B!A<G)A>2!O9@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%T=')I8G5T92]V86QU97,@<&%I<G,@;W(@82!S:&%R
M92!O=VYE<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5S
M97)N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'!A<F5N="`@("`@(%1H
M92!P87)E;G0@<VAA<F4@=&\@<W1A<G0@<V5A<F-H:6YG(&%T+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@(%)E='5R;B!A;&P@;&5V96QS
M+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C:&EL9')E;B!O9B`D<&%R96YT/R!$969A=6QT<R!T;R!A
M;&P@;&5V96QS+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@3G5M
M8F5R(&]F('-H87)E<R!T:&4@=7-E<B!H87,@86-C97-S('1O+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;W5N=%-H87)E<R@D=7-E<FED+"`D<&5R;2`](%!%
M4DU37U-(3U<L("1A='1R:6)U=&5S(#T@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("1P87)E;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS
M(#T@=')U92D*("`@('L*("`@("`@("`D:V5Y(#T@<V5R:6%L:7IE*&%R<F%Y
M*"1T:&ES+3Y?87!P+"`D=7-E<FED+"`D<&5R;2P@)&%T=')I8G5T97,L("1P
M87)E;G0L("1A;&Q,979E;',L("=C;W5N="<I*3L*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]L:7-T8V%C:&5;)&ME>5TI*2!["B`@("`@("`@("`@("1C
M<FET97)I82`]("1T:&ES+3YG9713:&%R94-R:71E<FEA*"1U<V5R:60L("1P
M97)M+"`D871T<FEB=71E<RD["B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&-A
M8VAE6R1K97E=(#T@)'1H:7,M/E]D871A=')E92T^8V]U;G1">4%T=')I8G5T
M97,H)&-R:71E<FEA+"`D<&%R96YT+"`D86QL3&5V96QS+"`G:60G*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VQI<W1C86-H95LD:V5Y
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@
M86QL('-H87)E<R!T:&%T("1U<V5R:60@:&%S(&%C8V5S<R!T;RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=7-E<FED("`@("`@(%1H92!U<V5R
M:60@;V8@=&AE('5S97(@=&\@8VAE8VL@86-C97-S(&9O<BX*("`@("`J($!P
M87)A;2!I;G1E9V5R("1P97)M("`@("`@("`@5&AE(&QE=F5L(&]F('!E<FUI
M<W-I;VYS(')E<75I<F5D+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I
M8G5T97,@("!297-T<FEC="!T:&4@<VAA<F5S(&-O=6YT960@=&\@=&AO<V4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;6%T8VAI;F<@
M)&%T=')I8G5T97,N($%N(&%R<F%Y(&]F"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%T=')I8G5T92]V86QU97,@<&%I<G,@;W(@82!S
M:&%R92!O=VYE<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!U<V5R;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@
M("`@5&AE('!A<F5N="!S:&%R92!T;R!S=&%R="!S96%R8VAI;F<@870N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D86QL3&5V96QS("`@(%)E='5R;B!A;&P@
M;&5V96QS+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A<F5N=#\@1&5F875L
M=',@=&\@86QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&QE=F5L<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M("`@("`@("`@
M5&AE('-H87)E('1O('-T87)T(&QI<W1I;F<@870N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D8V]U;G0@("`@("`@(%1H92!N=6UB97(@;V8@<VAA<F5S('1O
M(')E='5R;BX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?;F%M92`@
M071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'-O<G1B>5]K97D@("!!='1R:6)U=&4@:V5Y('1O('5S
M92!F;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E8W1I
M;VX@("`@4V]R="!D:7)E8W1I;VXZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#$@+2!D97-C96YD:6YG"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5&AE('-H87)E<R!T:&4@=7-E<B!H87,@
M86-C97-S('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B`F;&ES=%-H87)E<R@D
M=7-E<FED+"`D<&5R;2`](%!%4DU37U-(3U<L("1A='1R:6)U=&5S(#T@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0@/2!$051!5%)%
M15]23T]4+"`D86QL3&5V96QS(#T@=')U92P@)&9R;VT@/2`P+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O=6YT(#T@,"P@)'-O<G1B>5]N86UE(#T@
M;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1I<F5C=&EO;B`](#`I"B`@("!["B`@("`@("`@)&ME>2`]('-E
M<FEA;&EZ92AA<G)A>2@D=&AI<RT^7V%P<"P@)'5S97)I9"P@)'!E<FTL("1A
M='1R:6)U=&5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F5N="P@)&%L;$QE=F5L<RP@)&9R;VTL("1C;W5N="P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S;W)T8GE?;F%M92P@)'-O<G1B>5]K97DL
M("1D:7)E8W1I;VXI*3L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]L:7-T
M8V%C:&5;)&ME>5TI*2!["B`@("`@("`@("`@("1C<FET97)I82`]("1T:&ES
M+3YG9713:&%R94-R:71E<FEA*"1U<V5R:60L("1P97)M+"`D871T<FEB=71E
M<RD["B`@("`@("`@("`@("1S:&%R96QI<W0@/2`D=&AI<RT^7V1A=&%T<F5E
M+3YG971">4%T=')I8G5T97,H"B`@("`@("`@("`@("`@("`D8W)I=&5R:6$L
M("1P87)E;G0L("1A;&Q,979E;',L("=I9"<L("1F<F]M+"`D8V]U;G0L"B`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64L("1S;W)T8GE?:V5Y+"`D9&ER
M96-T:6]N*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-H87)E;&ES="P@)U!%
M05)?17)R;W(G*2!\?"`A8V]U;G0H)'-H87)E;&ES="DI('L*("`@("`@("`@
M("`@("`@("\J($EF('=E(&=O="!B86-K(&%N(&5R<F]R(&]R(&%N(&5M<'1Y
M(&%R<F%Y+"!P87-S(&ET(&)A8VL@=&\*("`@("`@("`@("`@("`@("`J('1H
M92!C86QL97(N("HO"B`@("`@("`@("`@("`@("!R971U<FX@)'-H87)E;&ES
M=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36%K92!S=7)E(&=E
M=%-H87)E<R@I(&1I9&XG="!R971U<FX@86X@97)R;W(N("HO"B`@("`@("`@
M("`@("1S:&%R97,@/2`F)'1H:7,M/F=E=%-H87)E<RAA<G)A>5]K97ES*"1S
M:&%R96QI<W0I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-H87)E<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S:&%R97,[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;&ES=&-A8VAE
M6R1K97E=(#T@)B1S:&%R97,["B`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI
M<W0@/2`D=&AI<RT^7VQI<W1C86-H95LD:V5Y73L*("`@("`@("`@("`@=6%S
M;W)T*"1T:&ES+3Y?;&ES=&-A8VAE6R1K97E=+"!A<G)A>2@D=&AI<RP@)U]S
M;W)T4VAA<F5S)RDI.PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T(#T@
M;G5L;#L*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!(;W)D93HZ8V%L
M;$AO;VLH)U]H;W)D95]H;V]K7W-H87)E7VQI<W0G+"!A<G)A>2@D=7-E<FED
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FTL("1A
M='1R:6)U=&5S+"`D=&AI<RT^7VQI<W1C86-H95LD:V5Y72DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4G+"!F86QS92D["B`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7VQI<W1C86-H95LD:V5Y73L*("`@('T*"B`@("`O*BH*
M("`@("`J($QI<W1S("IA;&PJ('-H87)E<R!F;W(@=&AE(&-U<G)E;G0@87!P
M+W-H87)E+"!R96=A<F1L97-S(&]F"B`@("`@*B!P97)M:7-S:6]N<RX@5&AI
M<R!I<R!F;W(@861M:6X@9G5N8W1I;VYA;&ET>2!A;F0@<V-R:7!T:6YG('1O
M;VQS+"!A;F0*("`@("`J('-H;W5L9&XG="!B92!C86QL960@9G)O;2!U<V5R
M+6QE=F5L(&-O9&4A"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!A
M<F5N="`@4W1A<G0@=&AE(&QI<W1I;F<@870@82!C97)T86EN('!O:6YT(&EN
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=')E92X@1&5F
M875L=',@=&\@1$%40512145?4D]/5"P@=&AE(')O;W0N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06QL('-H87)E<R!F;W(@=&AE(&-U<G)E;G0@
M87!P+W-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL4VAA<F5S
M*"1P87)E;G0@/2!$051!5%)%15]23T]4*0H@("`@>PH@("`@("`@("1S:&%R
M96QI<W0@/2`D=&AI<RT^7V1A=&%T<F5E+3YG970H1$%40512145?1D]234%4
M7T9,050L("1P87)E;G0L('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1S:&%R
M96QI<W0L("=014%27T5R<F]R)RD@?'P@(6-O=6YT*"1S:&%R96QI<W0I*2![
M"B`@("`@("`@("`@("\O($EF('=E(&=O="!B86-K(&%N(&5R<F]R(&]R(&%N
M(&5M<'1Y(&%R<F%Y+"!J=7-T(')E='5R;B!I="X*("`@("`@("`@("`@<F5T
M=7)N("1S:&%R96QI<W0["B`@("`@("`@?0H@("`@("`@('5N<V5T*"1S:&%R
M96QI<W1;)'!A<F5N=%TI.PH*("`@("`@("`D<VAA<F5S(#T@)B1T:&ES+3YG
M9713:&%R97,H87)R87E?:V5Y<R@D<VAA<F5L:7-T*2D["B`@("`@("`@:68@
M*&ES7V$H)'-H87)E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'-H87)E<SL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V]R
M=$QI<W0@/2`D<VAA<F5S.PH@("`@("`@('5A<V]R="@D<VAA<F5S+"!A<G)A
M>2@D=&AI<RP@)U]S;W)T4VAA<F5S)RDI.PH@("`@("`@("1T:&ES+3Y?<V]R
M=$QI<W0@/2!N=6QL.PH*("`@("`@("!R971U<FX@)'-H87)E<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@8W)I=&5R:6$@
M9F]R('%U97)Y:6YG('-H87)E<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D=7-E<FED("`@("`@5&AE('5S97)I9"!O9B!T:&4@=7-E<B!T;R!C
M:&5C:R!A8V-E<W,@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FT@
M("`@("`@(%1H92!L979E;"!O9B!P97)M:7-S:6]N<R!R97%U:7)E9"X*("`@
M("`J($!P87)A;2!M:7AE9"`@("1A='1R:6)U=&5S("!297-T<FEC="!T:&4@
M<VAA<F5S(')E='5R;F5D('1O('1H;W-E('=H;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&AA=F4@=&AE<V4@871T<FEB=71E('9A;'5E
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8W)I=&5R:6$@
M=')E92!F;W(@9F5T8VAI;F<@=&AI<R!U<V5R)W,@<VAA<F5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G9713:&%R94-R:71E<FEA*"1U<V5R:60L("1P97)M
M(#T@4$5235-?4TA/5RP@)&%T=')I8G5T97,@/2!N=6QL*0H@("`@>PH@("`@
M("`@(&EF("@A96UP='DH)'5S97)I9"DI('L*("`@("`@("`@("`@)&-R:71E
M<FEA(#T@87)R87DH"B`@("`@("`@("`@("`@("`G3U(G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("\O("AO=VYE<B`]/2`D=7-E<FED*0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`G04Y$)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G
M(#T^("=O=VYE<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<])RP@)W1E<W0G(#T^
M("1U<V5R:60I*2DL"@H@("`@("`@("`@("`@("`@("`@("\O("AN86UE(#T]
M('!E<FU?=7-E<G,@86YD(&ME>2`]/2`D=7-E<FED(&%N9"!V86P@)B`D<&5R
M;2D*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L
M("=T97-T)R`]/B`G<&5R;5]U<V5R<R<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G:V5Y)RP@)V]P)R`]/B`G/2<L
M("=T97-T)R`]/B`D=7-E<FED*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:65L9"<@/3X@)W9A;'5E)RP@)V]P)R`]/B`G)B<L("=T
M97-T)R`]/B`D<&5R;2DI*2P*"B`@("`@("`@("`@("`@("`@("`@+R\@*&YA
M;64@/3T@<&5R;5]C<F5A=&]R(&%N9"!V86P@)B`D<&5R;2D*("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)T%.
M1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9FEE;&0G(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G
M<&5R;5]C<F5A=&]R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)R8G+"`G=&5S="<@
M/3X@)'!E<FTI*2DL"@H@("`@("`@("`@("`@("`@("`@("\O("AN86UE(#T]
M('!E<FU?9&5F875L="!A;F0@=F%L("8@)'!E<FTI"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=!3D0G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I
M96QD)R`]/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?
M9&5F875L="<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I96QD)R`]/B`G=F%L=64G+"`G;W`G(#T^("<F)RP@)W1E<W0G(#T^("1P
M97)M*2DI*2D["@H@("`@("`@("`@("`O+R!)9B!T:&4@=7-E<B!H87,@86YY
M(&=R;W5P(&UE;6)E<G-H:7!S+"!C:&5C:R!F;W(@=&AO<V4@86QS;RX*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]'<F]U<"YP:'`G.PH@("`@
M("`@("`@("`D9W)O=7`@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH@("`@("`@
M("`@("`D9W)O=7!S(#T@)&=R;W5P+3YG971'<F]U<$UE;6)E<G-H:7!S*"1U
M<V5R:60L('1R=64I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&=R;W5P<RP@
M)U!%05)?17)R;W(G*2`F)B!C;W5N="@D9W)O=7!S*2D@>PH@("`@("`@("`@
M("`@("`@+R\@*&YA;64@/3T@<&5R;5]G<F]U<',@86YD(&ME>2!I;B`H)&=R
M;W5P<RD@86YD('9A;"`F("1P97)M*0H@("`@("`@("`@("`@("`@)&-R:71E
M<FEA6R=/4B==6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G04Y$
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I
M96QD)R`]/B`G;F%M92<L("=O<"<@/3X@)STG+"`G=&5S="<@/3X@)W!E<FU?
M9W)O=7!S)RDL"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L
M9"<@/3X@)VME>2<L("=O<"<@/3X@)TE.)RP@)W1E<W0G(#T^(&%R<F%Y7VME
M>7,H)&=R;W5P<RDI+`H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)R8G+"`G=&5S="<@/3X@)'!E
M<FTI*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D8W)I=&5R:6$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=!3D0G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G
M(#T^("=N86UE)RP@)V]P)R`]/B`G/2<L("=T97-T)R`]/B`G<&5R;5]G=65S
M="<I+`H@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=V
M86QU92<L("=O<"<@/3X@)R8G+"`G=&5S="<@/3X@)'!E<FTI*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)&%T=')I8G5T97,I*2!["B`@
M("`@("`@("`@("\O($)U:6QD(&%T=')I8G5T92]K97D@9FEL=&5R+@H@("`@
M("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`@("`@)&-R:71E<FEA(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@)T%.1"<@/3X@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C<FET97)I82P*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G2D])3B<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T%.1"<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G;W`G(#T^("<])RP@)W1E<W0G
M(#T^("1K97DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)STG+"`G=&5S
M="<@/3X@)'9A;'5E*2DI*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E:68@*"%E;7!T>2@D871T<FEB=71E<RDI('L*("`@("`@("`@("`@+R\@
M4F5S=')I8W0@=&\@<VAA<F5S(&]W;F5D(&)Y('1H92!U<V5R('-P96-I9FEE
M9"!I;B!T:&4*("`@("`@("`@("`@+R\@)&%T=')I8G5T97,@<W1R:6YG+@H@
M("`@("`@("`@("`D8W)I=&5R:6$@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("=!3D0G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("1C<FET97)I
M82P*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@)TI/24XG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I96QD)R`]/B`G;F%M92<L("=O<"<@/3X@)STG
M+"`G=&5S="<@/3X@)V]W;F5R)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G9FEE;&0G(#T^("=V86QU92<L("=O<"<@/3X@)STG+"`G
M=&5S="<@/3X@)&%T=')I8G5T97,I*2DI*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D8W)I=&5R:6$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/
M"B`@("`@*@H@("`@("H@0'-E92!097)M<SHZ9V5T4&5R;6ES<VEO;G,*("`@
M("`J"B`@("`@*B!`<&%R86T@5$]$3PH@("`@("H@0'!A<F%M(%1/1$\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&5R;6ES<VEO;G,H)'-H87)E+"`D=7-E<B`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*"%I<U]A*"1S:&%R92P@)T1A=&%4<F5E3V)J96-T7U-H87)E
M)RDI('L*("`@("`@("`@("`@)'-H87)E(#T@)B1T:&ES+3YG9713:&%R92@D
M<VAA<F4I.PH@("`@("`@('T*"B`@("`@("`@)'!E<FT@/2`F)'-H87)E+3YG
M971097)M:7-S:6]N*"D["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=P97)M
M<R==+3YG971097)M:7-S:6]N<R@D<&5R;2P@)'5S97(I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@261E;G1I='D@9F]R(&$@<&%R=&EC
M=6QA<B!S:&%R92!O=VYE<BX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)'-H87)E("!4:&4@<VAA<F4@=&\@9F5T8V@@=&AE($ED96YT:71Y(&9O<B`M
M(&5I=&AE<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@('-T<FEN
M9R!N86UE+"!O<B!T:&4@1&%T851R965/8FIE8W1?4VAA<F4@;V)J96-T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<')E9F5R96YC92=S
M('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T261E;G1I='E">5-H
M87)E*"1S:&%R92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)'-H87)E+"`G
M1&%T851R965/8FIE8W1?4VAA<F4G*2D@>PH@("`@("`@("`@("`D<VAA<F4@
M/2`D=&AI<RT^9V5T4VAA<F4H)'-H87)E*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)'-H87)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92])9&5N=&ET>2YP:'`G.PH@("`@("`@("1O
M=VYE<B`]("1S:&%R92T^9V5T*"=O=VYE<B<I.PH@("`@("`@(')E='5R;B`D
M<F5T(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH)VYO;F4G+"`D;W=N97(I.PH@
M("`@?0H*?0H*+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R965/8FIE
M8W0@8VQA<W,@9F]R('-T;W)I;F<@4VAA<F4@:6YF;W)M871I;VX@:6X@=&AE
M"B`J($1A=&%4<F5E(&1R:79E<BX@268@>6]U('=A;G0@=&\@<W1O<F4@<W!E
M8VEA;&EZ960@4VAA<F4@:6YF;W)M871I;VXL('EO=0H@*B!S:&]U;&0@97AT
M96YD('1H:7,@8VQA<W,@:6YS=&5A9"!O9B!E>'1E;F1I;F<@1&%T851R965/
M8FIE8W0@9&ER96-T;'DN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]3:&%R90H@*B\*8VQA<W,@1&%T851R965/
M8FIE8W1?4VAA<F4@97AT96YD<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ
M"B`@("`@*B!4:&4@2&]R9&5?4VAA<F4@;V)J96-T('=H:6-H('1H:7,@<VAA
M<F4@8V%M92!F<F]M("T@;F5E9&5D(&9O<@H@("`@("H@=7!D871I;F<@9&%T
M82!I;B!T:&4@8F%C:V5N9"!T;R!M86ME(&-H86YG97,@<W1I8VLL(&5T8RX*
M("`@("`J"B`@("`@*B!`=F%R($AO<F1E7U-H87)E"B`@("`@*B\*("`@('9A
M<B`D7W-H87)E3V(["@H@("`@+RHJ"B`@("`@*B!4:&4@1&%T851R965/8FIE
M8W1?4VAA<F4@8V]N<W1R=6-T;W(N($IU<W0@;6%K97,@<W5R92!T;R!C86QL
M('1H92!P87)E;G0*("`@("`J(&-O;G-T<G5C=&]R('-O('1H870@=&AE('-H
M87)E)W,@;F%M92!I<R!S970@<')O<&5R;'DN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:60@(%1H92!I9"!O9B!T:&4@<VAA<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N($1A=&%4<F5E3V)J96-T7U-H87)E*"1I9"D*("`@('L*
M("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T*"1I9"D["B`@("`@("`@
M:68@*&ES7VYU;&PH)'1H:7,M/F1A=&$I*2!["B`@("`@("`@("`@("1T:&ES
M+3YD871A(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!<W-O8VEA=&5S(&$@4VAA<F4@;V)J96-T('=I=&@@=&AI<R!S:&%R
M92X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?4VAA<F4@)'-H87)E3V(@
M(%1H92!3:&%R92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-H
M87)E3V(H)B1S:&%R94]B*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VAA<F5/
M8B`]("8D<VAA<F5/8CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AI<R!S:&%R92=S('!A<F5N="!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!$871A5')E94]B:F5C=%]3:&%R92`@5&AE('!A<F5N="!S:&%R92P@
M:68@:70@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4&%R96YT
M*"D*("`@('L*("`@("`@("`D<&%R96YT(#T@)'1H:7,M/E]S:&%R94]B+3YG
M971087)E;G0H)'1H:7,I.PH@("`@("`@(')E='5R;B`D<&%R96YT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1VEV97,@82!U<V5R(&$@8V5R=&%I;B!P<FEV
M:6QE9V4@9F]R('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=7-E<FED("`@("`@(%1H92!U<V5R:60@;V8@=&AE('5S97(N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<&5R;6ES<VEO;B`@02!015)-4U\J(&-O
M;G-T86YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R4&5R;6ES<VEO
M;B@D=7-E<FED+"`D<&5R;6ES<VEO;BD*("`@('L*("`@("`@("`D<&5R;2`]
M("8D=&AI<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@("1P97)M+3YA9&15
M<V5R4&5R;6ES<VEO;B@D=7-E<FED+"`D<&5R;6ES<VEO;BP@9F%L<V4I.PH@
M("`@("`@("1T:&ES+3YS971097)M:7-S:6]N*"1P97)M*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;6]V97,@82!C97)T86EN('!R:79I;&5G92!F;W(@
M82!U<V5R(&9R;VT@=&AI<R!S:&%R92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R:60@("`@("`@5&AE('5S97)I9"!O9B!T:&4@=7-E<BX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S:6]N("!!(%!%4DU37RH@
M8V]N<W1A;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97)097)M
M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("1P
M97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM
M/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R:60L("1P97)M:7-S:6]N+"!F
M86QS92D["B`@("`@("`@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1VEV97,@82!G<F]U<"!C97)T86EN('!R
M:79I;&5G97,@9F]R('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9W)O=7`@("`@("`@(%1H92!G<F]U<"!T;R!A9&0@<&5R;6ES
M<VEO;G,@9F]R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!E<FUI<W-I;VX@
M($$@4$5235-?*B!C;VYS=&%N="X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@)'!E<FUI<W-I;VXI"B`@("!["B`@
M("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@("`@
M("`D<&5R;2T^861D1W)O=7!097)M:7-S:6]N*"1G<F]U<"P@)'!E<FUI<W-I
M;VXL(&9A;'-E*3L*("`@("`@("`D=&AI<RT^<V5T4&5R;6ES<VEO;B@D<&5R
M;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@8V5R=&%I;B!P
M<FEV:6QE9V4@9G)O;2!A(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&=R;W5P("`@("`@("`@5&AE(&=R;W5P('1O(')E;6]V92!P97)M
M:7-S:6]N<R!F<F]M+@H@("`@("H@0'!A<F%M(&-O;G-T86YT("1P97)M:7-S
M:6]N("!!(%!%4DU37RH@8V]N<W1A;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L("1P97)M:7-S:6]N*0H@
M("`@>PH@("`@("`@("1P97)M(#T@)B1T:&ES+3YG971097)M:7-S:6]N*"D[
M"B`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P4&5R;6ES<VEO;B@D9W)O=7`L
M("1P97)M:7-S:6]N+"!F86QS92D["B`@("`@("`@)'1H:7,M/G-E=%!E<FUI
M<W-I;VXH)'!E<FTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O
M('-E92!I9B!A('5S97(@:&%S(&$@9VEV96X@<&5R;6ES<VEO;BX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R:60@("`@("`@5&AE('5S97)I
M9"!O9B!T:&4@=7-E<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M:7-S
M:6]N("!!(%!%4DU37RH@8V]N<W1A;G0@=&\@=&5S="!F;W(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C<F5A=&]R("`@("`@5&AE(&-R96%T;W(@;V8@=&AE
M(&5V96YT+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE
M<B!O<B!N;W0@)'5S97)I9"!H87,@)'!E<FUI<W-I;VXN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&AA<U!E<FUI<W-I;VXH)'5S97)I9"P@)'!E<FUI<W-I;VXL
M("1C<F5A=&]R(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)'5S97)I9"`]
M/2`D=&AI<RT^9V5T*"=O=VYE<B<I*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=P97)M
M<R==+3YH87-097)M:7-S:6]N*"1T:&ES+3YG971097)M:7-S:6]N*"DL("1U
M<V5R:60L("1P97)M:7-S:6]N+"`D8W)E871O<BD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F5S(&$@=7-E<B!F<F]M('1H:7,@<VAA<F4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FED("!4:&4@=7-E<FED(&]F
M('1H92!U<V5R('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M
M;W9E57-E<B@D=7-E<FED*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!A;&P@
M)'5S97)I9"=S('!E<FUI<W-I;VYS+B`J+PH@("`@("`@("1P97)M(#T@)B1T
M:&ES+3YG971097)M:7-S:6]N*"D["B`@("`@("`@)'!E<FTM/G)E;6]V955S
M97)097)M:7-S:6]N*"1U<V5R:60L(%!%4DU37U-(3U<L(&9A;'-E*3L*("`@
M("`@("`D<&5R;2T^<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97)I9"P@4$52
M35-?4D5!1"P@9F%L<V4I.PH@("`@("`@("1P97)M+3YR96UO=F55<V5R4&5R
M;6ES<VEO;B@D=7-E<FED+"!015)-4U]%1$E4+"!F86QS92D["B`@("`@("`@
M)'!E<FTM/G)E;6]V955S97)097)M:7-S:6]N*"1U<V5R:60L(%!%4DU37T1%
M3$5412P@9F%L<V4I.PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5T4&5R;6ES
M<VEO;B@D<&5R;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@
M9W)O=7`@9G)O;2!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1G<F]U<$ED("!4:&4@9W)O=7`@=&\@<F5M;W9E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96UO=F5'<F]U<"@D9W)O=7!)9"D*("`@('L*("`@
M("`@("`O*B!296UO=F4@86QL("1G<F]U<$ED)W,@<&5R;6ES<VEO;G,N("HO
M"B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E<FUI<W-I;VXH*3L*("`@
M("`@("`D<&5R;2T^<F5M;W9E1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"!0
M15)-4U]32$]7+"!F86QS92D["B`@("`@("`@)'!E<FTM/G)E;6]V94=R;W5P
M4&5R;6ES<VEO;B@D9W)O=7!)9"P@4$5235-?4D5!1"P@9F%L<V4I.PH@("`@
M("`@("1P97)M+3YR96UO=F5'<F]U<%!E<FUI<W-I;VXH)&=R;W5P260L(%!%
M4DU37T5$250L(&9A;'-E*3L*("`@("`@("`D<&5R;2T^<F5M;W9E1W)O=7!0
M97)M:7-S:6]N*"1G<F]U<$ED+"!015)-4U]$14Q%5$4L(&9A;'-E*3L*("`@
M("`@("!R971U<FX@)'1H:7,M/G-E=%!E<FUI<W-I;VXH)'!E<FTI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!C;VYT86EN:6YG
M(&%L;"!T:&4@=7-E<FED<R!O9B!T:&4@=7-E<G,@=VET:"!A8V-E<W,@=&\*
M("`@("`J('1H:7,@<VAA<F4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'!E<FU?;&5V96P@($QI<W0@;VYL>2!U<V5R<R!W:71H('1H:7,@<&5R
M;6ES<VEO;B!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!$969A=6QT<R!T;R!A;&P@=7-E<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@5&AE('5S97)S('=I=&@@86-C97-S('1O('1H:7,@<VAA
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@D<&5R;5]L979E
M;"`](&YU;&PI"B`@("!["B`@("`@("`@)'!E<FT@/2`F)'1H:7,M/F=E=%!E
M<FUI<W-I;VXH*3L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D<&5R;2T^
M9V5T57-E<E!E<FUI<W-I;VYS*"1P97)M7VQE=F5L*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y(&-O;G1A:6YI;F<@86QL('1H
M92!G<F]U<&ED<R!O9B!T:&4@9W)O=7!S('=I=&@@86-C97-S"B`@("`@*B!T
M;R!T:&ES('-H87)E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1P
M97)M7VQE=F5L("!,:7-T(&]N;'D@=7-E<G,@=VET:"!T:&ES('!E<FUI<W-I
M;VX@;&5V96PN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1&5F875L=',@=&\@86QL('5S97)S+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%1H92!)1',@;V8@=&AE(&=R;W5P<R!W:71H(&%C8V5S<R!T;R!T
M:&ES('-H87)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T1W)O=7!S*"1P
M97)M7VQE=F5L(#T@;G5L;"D*("`@('L*("`@("`@("`D<&5R;2`]("8D=&AI
M<RT^9V5T4&5R;6ES<VEO;B@I.PH@("`@("`@(')E='5R;B!A<G)A>5]K97ES
M*"1P97)M+3YG971'<F]U<%!E<FUI<W-I;VYS*"1P97)M7VQE=F5L*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0'!A<F%M
M(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@(%1/1$\*("`@
M("`J"B`@("`@*B!`<F5T=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T4&5R;6ES<VEO;B@F)'!E<FTL("1U<&1A=&4@/2!T<G5E*0H@("`@>PH@
M("`@("`@("1T:&ES+3YD871A6R=P97)M)UT@/2`D<&5R;2T^9V5T1&%T82@I
M.PH@("`@("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!E<FUI<W-I;VXH
M*0H@("`@>PH@("`@("`@("1P97)M(#T@)FYE=R!$871A5')E94]B:F5C=%]0
M97)M:7-S:6]N*"1T:&ES+3YG971.86UE*"DI.PH@("`@("`@("1P97)M+3YD
M871A(#T@:7-S970H)'1H:7,M/F1A=&%;)W!E<FTG72D@/R`D=&AI<RT^9&%T
M85LG<&5R;2==(#H@87)R87DH*3L*"B`@("`@("`@<F5T=7)N("1P97)M.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1F]R8V5S(&%L;"!C:&EL9')E;B!O9B!T
M:&ES('-H87)E('1O(&EN:&5R:70@=&AE('!E<FUI<W-I;VYS('-E="!O;B!T
M:&ES"B`@("`@*B!S:&%R92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1/1$\*
M("`@("`J+PH@("`@9G5N8W1I;VX@:6YH97)I=%!E<FUI<W-I;VYS*"D*("`@
M('L*("`@("`@("`D<&5R;2`]("8D=&AI<RT^9V5T4&5R;6ES<VEO;B@I.PH@
M("`@("`@("1C:&EL9')E;B`]("1T:&ES+3Y?<VAA<F5/8BT^;&ES=$%L;%-H
M87)E<R@D=&AI<RT^9V5T3F%M92@I*3L*("`@("`@("!I9B`H:7-?82@D8VAI
M;&1R96XL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C
M:&EL9')E;CL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C:&EL9')E
M;B!A<R`D8VAI;&0I('L*("`@("`@("`@("`@)&-H:6QD+3YS971097)M:7-S
M:6]N*"1P97)M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V%V97,@86YY(&-H86YG97,@=&\@=&AI
M<R!O8FIE8W0@=&\@=&AE(&)A8VME;F0@<&5R;6%N96YT;'DN($YE=R!O8FIE
M8W1S"B`@("`@*B!A<F4@861D960@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@?"!014%27T5R<F]R("!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H*0H@("`@>PH@("`@
M("`@("1R97-U;'0@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-H
M87)E7VUO9&EF>2<L(&%R<F%Y*"1T:&ES*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=H;W)D92<L(&9A;'-E*3L*("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('!A<F5N
M=#HZ<V%V92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P<R!T:&ES(&]B
M:F5C="=S(&%T=')I8G5T97,@9G)O;2!T:&4@9&%T82!A<G)A>2!I;G1O(&$@
M9F]R;6%T('1H870@=V4*("`@("`J(&-A;B!S=&]R92!I;B!T:&4@871T<FEB
M=71E<R!S=&]R86=E(&)A8VME;F0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<F]T96-T960*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<&5R;7-O
M;FQY("!/;FQY('!R;V-E<W,@<&5R;6ES<VEO;G,_($QE=',@<W5B8VQA<W-E
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W9E<G)I9&4@
M<&%R="!O9B!T:&ES(&UE=&AO9"!W:&EL92!H86YD;&EN9PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE:7(@861D:71I;VYA;"!A='1R
M:6)U=&5S('-E<&5R871E;'DN"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@5&AE(&%T=')I8G5T97,@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]T;T%T=')I8G5T97,H)'!E<FUS;VYL>2`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\O($1E9F%U;'0@=&\@;F\@871T<FEB=71E<RX*("`@("`@("`D871T
M<FEB=71E<R`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD
M871A(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D:V5Y
M(#T]("=P97)M)RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E
M(&%S("1T>7!E(#T^("1P97)M<RD@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D<&5R;7,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1P97)M<R!A<R`D;65M8F5R(#T^("1P97)M*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D871T<FEB=71E<UM=(#T@87)R87DH
M)VYA;64G(#T^("=P97)M7R<@+B`D='EP92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`D;65M
M8F5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=V86QU92<@/3X@)'!E<FTI.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE
M)R`]/B`G<&5R;5\G("X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:V5Y)R`]/B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU92<@
M/3X@)'!E<FUS*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@A)'!E<FUS;VYL>2D@>PH@
M("`@("`@("`@("`@("`@)&%T=')I8G5T97-;72`](&%R<F%Y*"=N86UE)R`]
M/B`D:V5Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=K97DG(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@5&%K97,@:6X@82!L:7-T(&]F(&%T=')I8G5T97,@9G)O
M;2!T:&4@8F%C:V5N9"!A;F0@;6%P<R!I="!T;R!O=7(*("`@("`J(&EN=&5R
M;F%L(&1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@("!4
M:&4@;&ES="!O9B!A='1R:6)U=&5S(&9R;VT@=&AE(&)A8VME;F0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("AA='1R:6)U=&4@;F%M92P@
M:V5Y+"!A;F0@=F%L=64I+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!E<FUS
M;VYL>2`@3VYL>2!P<F]C97-S('!E<FUI<W-I;VYS/R!,971S('-U8F-L87-S
M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]V97)R:61E
M('!A<G0@;V8@=&AI<R!M971H;V0@=VAI;&4@:&%N9&QI;F<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H96ER(&%D9&ET:6]N86P@871T
M<FEB=71E<R!S97!E<F%T96QY+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9G)O
M;4%T=')I8G5T97,H)&%T=')I8G5T97,L("1P97)M<V]N;'D@/2!F86QS92D*
M("`@('L*("`@("`@("`O+R!);FET:6%L:7IE(&1A=&$@87)R87DN"B`@("`@
M("`@)'1H:7,M/F1A=&%;)W!E<FTG72`](&%R<F%Y*"D["@H@("`@("`@(&9O
M<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@("`@("`@(&EF
M("AS=6)S='(H)&%T=');)VYA;64G72P@,"P@-"D@/3T@)W!E<FTG*2!["B`@
M("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1A='1R6R=K97DG72DI('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LG<&5R;2==6W-U8G-T<B@D
M871T<ELG;F%M92==+"`U*5U;)&%T=');)VME>2==72`]("1A='1R6R=V86QU
M92==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%T85LG<&5R;2==6W-U8G-T<B@D871T<ELG;F%M92==
M+"`U*5T@/2`D871T<ELG=F%L=64G73L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?2!E;'-E:68@*"$D<&5R;7-O;FQY*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^9&%T85LD871T<ELG;F%M92==72`]("1A='1R6R=V86QU
M92==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344N<&AP````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8W,38V(#$P-3$U-#,T,30P
M(#`R,#8Q-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RH@5V4@;F5E9"!T;R`H=6YF;W)T=6YA=&5L>2D@:&%R
M9"!C;V1E('1H97-E(&-O;G-T86YT<R!B96-A=7-E('1H97D@<F5S:61E(&EN
M"B`J('1H92!I;6%P(&UO9'5L92P@=VAI8V@@:7,@;F]T(')E<75I<F5D(&9O
M<B!(;W)D92X*("H@5&AE<V4@8V]N<W1A;G1S(&%R92!F;W5N9"!I;B!T:&4@
M55<M:6UA<"!C+6-L:65N="!D:7-T<FEB=71I;VXZ"B`J("`@9G1P.B\O9G1P
M+F-A8RYW87-H:6YG=&]N+F5D=2]I;6%P+PH@*B!4:&4@8V]N<W1A;G1S(&%P
M<&5A<B!I;B!T:&4@9FEL92!I;F-L=61E+VUA:6PN:"`J+PIR97%U:7)E7V]N
M8V4@)TAO<F1E+U5T:6PN<&AP)SL*:68@*"%5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H)VEM87`G*2D@>PH@("`@+RH@4')I;6%R>2!B;V1Y('1Y<&5S("HO"B`@
M("!D969I;F4H)U194$5415A4)RP@,"D["B`@("!D969I;F4H)U194$5-54Q4
M25!!4E0G+"`Q*3L*("`@(&1E9FEN92@G5%E014U%4U-!1T4G+"`R*3L*("`@
M(&1E9FEN92@G5%E014%04$Q)0T%424].)RP@,RD["B`@("!D969I;F4H)U19
M4$5!541)3R<L(#0I.PH@("`@9&5F:6YE*"=465!%24U!1T4G+"`U*3L*("`@
M(&1E9FEN92@G5%E0159)1$5/)RP@-BD["B`@("!D969I;F4H)U194$5/5$A%
M4B<L(#@I.PH*("`@("\J($)O9'D@96YC;V1I;F=S("HO"B`@("!D969I;F4H
M)T5.0S="250G+"`P*3L*("`@(&1E9FEN92@G14Y#.$))5"<L(#$I.PH@("`@
M9&5F:6YE*"=%3D-"24Y!4EDG+"`R*3L*("`@(&1E9FEN92@G14Y#0D%3138T
M)RP@,RD["B`@("!D969I;F4H)T5.0U%53U1%1%!224Y404),12<L(#0I.PH@
M("`@9&5F:6YE*"=%3D-/5$A%4B<L(#4I.PI]"@HO*BH*("H@3VQD97(@=F5R
M<VEO;G,@;V8@4$A0)W,@:6UA<"!E>'1E;G-I;VX@9&]N)W0@9&5F:6YE(%19
M4$5-3T1%3"X*("HO"FEF("@A9&5F:6YE9"@G5%E014U/1$5,)RDI('L*("`@
M(&1E9FEN92@G5%E014U/1$5,)RP@-RD["GT*"B\J*@H@*B!2971U<FX@82!C
M;V1E(&9O<B!T>7!E*"DO96YC;V1I;F<H*2X*("HO"F1E9FEN92@G34E-15]#
M3T1%)RP@,2D["@HO*BH*("H@4F5T=7)N(&$@<W1R:6YG(&9O<B!T>7!E*"DO
M96YC;V1I;F<H*2X*("HO"F1E9FEN92@G34E-15]35%))3D<G+"`R*3L*"@HO
M*BH*("H@5&AE($U)344Z.B!C;&%S<R!P<F]V:61E<R!M971H;V1S(&9O<B!D
M96%L:6YG('=I=&@@34E-12!S=&%N9&%R9',N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TU)344O34E-12YP:'`L=B`Q+C$S.2XT+C(P(#(P,#8O,#,O,C0@
M,#0Z,CDZ-3(@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R
M9&5?34E-10H@*B\*8VQA<W,@34E-12!["@H@("`@+RHJ"B`@("`@*B!!(&QI
M<W1I;F<@;V8@=&AE(&%L;&]W960@34E-12!T>7!E<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6EM95]T>7!E<R`](&%R
M<F%Y*`H@("`@("`@(%194$5415A4(#T^("=T97AT)RP*("`@("`@("!465!%
M355,5$E005)4(#T^("=M=6QT:7!A<G0G+`H@("`@("`@(%194$5-15-304=%
M(#T^("=M97-S86=E)RP*("`@("`@("!465!%05!03$E#051)3TX@/3X@)V%P
M<&QI8V%T:6]N)RP*("`@("`@("!465!%055$24\@/3X@)V%U9&EO)RP*("`@
M("`@("!465!%24U!1T4@/3X@)VEM86=E)RP*("`@("`@("!465!%5DE$14\@
M/3X@)W9I9&5O)RP*("`@("`@("!465!%34]$14P@/3X@)VUO9&5L)RP*("`@
M("`@("!465!%3U1(15(@/3X@)V]T:&5R)PH@("`@*3L*"B`@("`O*BH*("`@
M("`J($$@;&ES=&EN9R!O9B!T:&4@86QL;W=E9"!-24U%(&5N8V]D:6YG<RX*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D;6EM
M95]E;F-O9&EN9W,@/2!A<G)A>2@*("`@("`@("!%3D,W0DE4(#T^("<W8FET
M)RP*("`@("`@("!%3D,X0DE4(#T^("<X8FET)RP*("`@("`@("!%3D-"24Y!
M4ED@/3X@)V)I;F%R>2<L"B`@("`@("`@14Y#0D%3138T(#T^("=B87-E-C0G
M+`H@("`@("`@($5.0U%53U1%1%!224Y404),12`]/B`G<75O=&5D+7!R:6YT
M86)L92<L"B`@("`@("`@14Y#3U1(15(@/3X@)W5N:VYO=VXG"B`@("`I.PH*
M("`@("\J*@H@("`@("H@1FEL=&5R(&9O<B!21D,X,C(N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1R9F,X,C)?9FEL=&5R
M(#T@(B@I/#Y`+#LZ7%Q<(EM=7#%<,EPS7#1<-5PV7#=<,3!<,3%<,3)<,3-<
M,31<,35<,39<,3=<,C!<,C%<,C)<,C-<,C1<,C5<,C9<,C=<,S!<,S%<,S)<
M,S-<,S1<,S5<,S9<,S=<,3<W(CL*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@:68@82!S=')I;F<@8V]N=&%I;G,@."UB:70@8VAA<F%C=&5R<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@(%1H92!S=')I;F<@
M=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&EF(&ET(&1O97,L(&9A;'-E(&EF(&ET(&1O97-N)W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&ES.&)I="@D<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R
M;B`H:7-?<W1R:6YG*"1S=')I;F<I("8F('!R96=?;6%T8V@H)R];7'@X,"U<
M>&9F72\G+"`D<W1R:6YG*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-O
M9&5S(&$@<W1R:6YG(&-O;G1A:6YI;F<@;F]N+4%30TE)(&-H87)A8W1E<G,@
M86-C;W)D:6YG('1O(%)&0R`R,#0W+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@("`@(%1H92!T97AT('1O(&5N8V]D92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@<V5T(&]F('1H
M92!T97AT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X
M="P@96YC;V1E9"!O;FQY(&EF(&ET(&-O;G1A:6YS(&YO;BU!4T-)20H@("`@
M("H@("`@("`@("`@("`@("`@(&-H87)A8W1E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5N8V]D92@D=&5X="P@)&-H87)S970@/2!N=6QL*0H@("`@>PH@
M("`@("`@("\J(%)E='5R;B!I9B!N;W1H:6YG(&YE961S('1O(&)E(&5N8V]D
M960N("HO"B`@("`@("`@:68@*"%-24U%.CII<SAB:70H)'1E>'0I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"@H@("`@("`@(&EF
M("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@)&-H87)S
M970@/2!3=')I;F<Z.FQO=V5R*"1C:&%R<V5T*3L*("`@("`@("`D;&EN92`]
M("<G.PH*("`@("`@("`O*B!'970@=&AE(&QI<W0@;V8@96QE;65N=',@:6X@
M=&AE('-T<FEN9RX@*B\*("`@("`@("`D<VEZ92`]('!R96=?;6%T8VA?86QL
M*"<O*%M>7'-=*RDH6UQS72HI+R<L("1T97AT+"`D;6%T8VAE<RP@4%)%1U]3
M151?3U)$15(I.PH*("`@("`@("!F;W)E86-H("@D;6%T8VAE<R!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`@("`@:68@*$U)344Z.FES.&)I="@D=F%L
M6S%=*2D@>PH@("`@("`@("`@("`@("`@:68@*"@H)&ME>2`K(#$I(#P@)'-I
M>F4I("8F"B`@("`@("`@("`@("`@("`@("`@34E-13HZ:7,X8FET*"1M871C
M:&5S6R1K97D@*R`Q75LQ72DI('L*("`@("`@("`@("`@("`@("`@("`D;&EN
M92`N/2!-24U%.CI?96YC;V1E*"1V86Q;,5T@+B`D=F%L6S)=+"`D8VAA<G-E
M="D@+B`G("<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1L:6YE("X]($U)344Z.E]E;F-O9&4H)'9A;%LQ72P@)&-H
M87)S970I("X@)'9A;%LR73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YE("X]("1V86Q;,5T@
M+B`D=F%L6S)=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@<G1R:6TH)&QI;F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YT
M97)N86P@<F5C=7)S:79E(&9U;F-T:6]N('1O(%)&0R`R,#0W(&5N8V]D92!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("!4:&4@=&5X="!T;R!E
M;F-O9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA
M<F%C=&5R('-E="!O9B!T:&4@=&5X="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('1E>'0L(&5N8V]D960@;VYL>2!I9B!I="!C;VYT86EN
M<R!N;VXM05-#24D*("`@("`J("`@("`@("`@("`@("`@("!C:&%R86-T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC;V1E*"1T97AT+"`D8VAA<G-E
M="D*("`@('L*("`@("`@("`D8VAA<E]L96X@/2!S=')L96XH)&-H87)S970I
M.PH@("`@("`@("1T>'1?;&5N(#T@<W1R;&5N*"1T97AT*2`J(#(["@H@("`@
M("`@("\J(%)&0R`R,#0W(%LR72!S=&%T97,@=&AA="!N;R!E;F-O9&5D('=O
M<F0@8V%N(&)E(&UO<F4@=&AA;B`W-0H@("`@("`@("`@(&-H87)A8W1E<G,@
M;&]N9RX@268@;&]N9V5R+"!Y;W4@;75S="!S<&QI="!T:&4@=V]R9"X@*B\*
M("`@("`@("!I9B`H*"1T>'1?;&5N("L@)&-H87)?;&5N("L@-RD@/B`W-2D@
M>PH@("`@("`@("`@("`D<&]S(#T@:6YT=F%L*"@V."`M("1C:&%R7VQE;BD@
M+R`R*3L*("`@("`@("`@("`@<F5T=7)N($U)344Z.E]E;F-O9&4H<W5B<W1R
M*"1T97AT+"`P+"`D<&]S*2P@)&-H87)S970I("X@)R`G("X@34E-13HZ7V5N
M8V]D92AS=6)S='(H)'1E>'0L("1P;W,I+"`D8VAA<G-E="D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<]/R<@+B`D8VAA<G-E="`N
M("<_8C\G("X@=')I;2AB87-E-C1?96YC;V1E*"1T97AT*2D@+B`G/STG.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5N8V]D97,@82!L:6YE
M('9I82!Q=6]T960M<')I;G1A8FQE(&5N8V]D:6YG+@H@("`@("H@5W)A<',@
M;&EN97,@870@-S8@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!E;F-O9&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1E;VP@("!4:&4@14],('-E<75E;F-E('1O('5S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('%U;W1E9"UP<FEN=&%B
M;&4@96YC;V1E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E
M9%!R:6YT86)L945N8V]D92@D=&5X="P@)&5O;"D*("`@('L*("`@("`@("`D
M;W5T<'5T(#T@)R<["@H@("`@("`@(&9O<F5A8V@@*'!R96=?<W!L:70H(B]<
M<C]<;B\B+"`D=&5X="D@87,@)&QI;F4I('L*("`@("`@("`@("`@+RH@5V4@
M;F5E9"!T;R!G;R!C:&%R86-T97(@8GD@8VAA<F%C=&5R('1H<F]U9V@@=&AE
M(&QI;F4N("HO"B`@("`@("`@("`@("1L96YG=&@@/2!S=')L96XH)&QI;F4I
M.PH@("`@("`@("`@("`D8W5R<F5N=%]L:6YE(#T@)R<["B`@("`@("`@("`@
M("1C=7)R96YT7VQE;F=T:"`](#`["@H@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D;&5N9W1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D8VAA
M<B`]('-U8G-T<B@D;&EN92P@)&DL(#$I.PH@("`@("`@("`@("`@("`@)&%S
M8VEI(#T@;W)D*"1C:&%R*3L*"B`@("`@("`@("`@("`@("`O*B!3<&%C97,@
M;W(@=&%B<R!A="!T:&4@96YD(&]F('1H92!L:6YE(&%R92!.3U0@86QL;W=E
M9"X*("`@("`@("`@("`@("`@("`J($%L<V\L($-H87)A8W1E<G,@:6X@05-#
M24D@8F5L;W<@,S(@;W(@86)O=F4@,3(V($%.1"`V,0H@("`@("`@("`@("`@
M("`@("H@;75S="!B92!E;F-O9&5D+B`J+PH@("`@("`@("`@("`@("`@:68@
M*"@H*"1A<V-I:2`]/3T@.2D@?'P@*"1A<V-I:2`]/3T@,S(I*2`F)B`H)&D@
M/3T@*"1L96YG=&@@+2`Q*2DI('Q\"B`@("`@("`@("`@("`@("`@("`@*"@D
M87-C:6D@/"`S,BD@?'P@*"1A<V-I:2`^(#$R-BD@?'P@*"1A<V-I:2`]/3T@
M-C$I*2D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%R(#T@)STG("X@4W1R
M:6YG.CIU<'!E<BAS<')I;G1F*"<E,#)S)RP@9&5C:&5X*"1A<V-I:2DI*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!,:6YE<R!M
M=7-T(&)E(#<V(&-H87)A8W1E<G,@;W(@;&5S<RX@*B\*("`@("`@("`@("`@
M("`@("1C:&%R7VQE;F=T:"`]('-T<FQE;B@D8VAA<BD["B`@("`@("`@("`@
M("`@("`D8W5R<F5N=%]L96YG=&@@*ST@)&-H87)?;&5N9W1H.PH@("`@("`@
M("`@("`@("`@:68@*"1C=7)R96YT7VQE;F=T:"`^(#<V*2!["B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2`D8W5R<F5N=%]L:6YE("X@)STG("X@
M)&5O;#L*("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]L:6YE(#T@)R<[
M"B`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?;&5N9W1H(#T@)&-H87)?
M;&5N9W1H.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&-U
M<G)E;G1?;&EN92`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D;W5T<'5T("X]("1C=7)R96YT7VQI;F4@+B`D96]L.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%;F-O9&5S(&$@<W1R:6YG(&-O;G1A:6YI;F<@96UA:6P@861D<F5S<V5S
M(&%C8V]R9&EN9R!T;R!21D,@,C`T-RX*("`@("`J"B`@("`@*B!4:&ES(&1I
M9F9E<G,@9G)O;2!-24U%.CIE;F-O9&4H*2!B96-A=7-E(&ET(&ME97!S(&5M
M86EL(&%D9')E<W-E<R!L96=A;"P*("`@("`J(&]N;'D@96YC;V1I;F<@=&AE
M('!E<G-O;F%L(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&%D9')E<W-E<R`@5&AE(&5M86EL(&%D9')E<W-E<R!T;R!E;F-O
M9&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("`@(%1H92!C:&%R
M86-T97(@<V5T(&]F('1H92!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&5F<V5R=F5R("!4:&4@9&5F875L="!D;VUA:6X@=&\@87!P96YD('1O(&UA
M:6QB;WAE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E
M>'0L(&5N8V]D960@;VYL>2!I9B!I="!C;VYT86EN<R!N;VXM87-C:6D*("`@
M("`J("`@("`@("`@("`@("`@("!C:&%R86-T97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!E;F-O9&5!9&1R97-S*"1A9&1R97-S97,L("1C:&%R<V5T(#T@
M;G5L;"P@)&1E9G-E<G9E<B`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1A9&1R97-S97,I*2!["B`@("`@("`@("`@("1A9&1R7V%R<B`]
M("1A9&1R97-S97,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@
M<&%R<V5!9&1R97-S3&ES="@I(&1O97,@;F]T('!R;V-E<W,@=&AE(&YU;&P@
M96YT<GD*("`@("`@("`@("`@("H@)W5N9&ES8VQO<V5D+7)E8VEP:65N=',Z
M.R<@8V]R<F5C=&QY+B`J+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+W5N9&ES8VQO<V5D+7)E8VEP:65N=',Z7',J.R]I)RP@=')I;2@D861D<F5S
M<V5S*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D861D<F5S<V5S.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO
M4D9#.#(R+G!H<"<["B`@("`@("`@("`@("1P87)S97(@/2`F;F5W($UA:6Q?
M4D9#.#(R*"D["B`@("`@("`@("`@("1A9&1R7V%R<B`]("1P87)S97(M/G!A
M<G-E061D<F5S<TQI<W0H)&%D9')E<W-E<RP@)&1E9G-E<G9E<BP@=')U92P@
M9F%L<V4I.PH@("`@("`@("`@("!I9B`H:7-?82@D861D<E]A<G(L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D861D<E]A<G([
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T97AT(#T@)R<[
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1A9&1R7V%R<BDI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)&%D9')?87)R(&%S("1A9&1R*2!["B`@("`@("`@("`@
M("`@("`O+R!#:&5C:R!F;W(@9W)O=7!S+@H@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D861D<BT^9W)O=7!N86UE*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T97AT("X]($U)344Z.F5N8V]D92@D861D<BT^9W)O=7!N86UE+"`D
M8VAA<G-E="D@+B`G.B`G("X@34E-13HZ96YC;V1E061D<F5S<R@D861D<BT^
M861D<F5S<V5S*2`N("<[)SL*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)&%D9'(M/G!E<G-O;F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("1P
M97)S;VYA;"`]("<G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H*'-U8G-T<B@D861D<BT^<&5R<V]N86PL(#`L
M(#$I(#T]("<B)RD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@*'-U8G-T
M<B@D861D<BT^<&5R<V]N86PL("TQ*2`]/2`G(B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A9&1R+3YP97)S;VYA;"`]('-U8G-T<B@D861D<BT^
M<&5R<V]N86PL(#$L("TQ*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)'!E<G-O;F%L(#T@34E-13HZ96YC;V1E*"1A9&1R
M+3YP97)S;VYA;"P@)&-H87)S970I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@:68@*'-T<FQE;B@D=&5X="D@(3T@,"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T97AT("X]("<L("<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D=&5X="`N/2!-24U%.CIT<FEM16UA:6Q!9&1R
M97-S*$U)344Z.G)F8S@R,E=R:71E061D<F5S<R@D861D<BT^;6%I;&)O>"P@
M)&%D9'(M/FAO<W0L("1P97)S;VYA;"DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96-O9&5S(&%N(%)&0R`R,#0W+65N8V]D960@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@("`@(%1H92!T97AT
M('1O(&1E8V]D92X*("`@("`J($!P87)A;2!S=')I;F<@)'1O7V-H87)S970@
M(%1H92!C:&%R<V5T('1H870@=&AE('1E>'0@<VAO=6QD(&)E(&1E8V]D960*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96-O9&4H)'-T<FEN9RP@)'1O7V-H87)S970@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@H)'!O<R`]('-T<G!O<R@D<W1R
M:6YG+"`G/3\G*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D
M<W1R:6YG.PH@("`@("`@('T*"B`@("`@("`@+RH@5&%K92!O=70@86YY('-P
M86-E<R!B971W965N(&UU;'1I<&QE(&5N8V]D960@=V]R9',N("HO"B`@("`@
M("`@)'-T<FEN9R`]('!R96=?<F5P;&%C92@G?%P_/5QS/5P_?"<L("<_/3T_
M)RP@)'-T<FEN9RD["@H@("`@("`@("\J(%-A=F4@86YY('!R96-E9&EN9R!T
M97AT+B`J+PH@("`@("`@("1P<F5C961I;F<@/2!S=6)S='(H)'-T<FEN9RP@
M,"P@)'!O<RD["@H@("`@("`@("1S96%R8V@@/2!S=6)S='(H)'-T<FEN9RP@
M)'!O<R`K(#(I.PH@("`@("`@("1D,2`]('-T<G!O<R@D<V5A<F-H+"`G/R<I
M.PH@("`@("`@(&EF("@D9#$@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E
M='5R;B`D<W1R:6YG.PH@("`@("`@('T*"B`@("`@("`@)&-H87)S970@/2!S
M=6)S='(H)'-T<FEN9RP@)'!O<R`K(#(L("1D,2D["B`@("`@("`@)'-E87)C
M:"`]('-U8G-T<B@D<V5A<F-H+"`D9#$@*R`Q*3L*"B`@("`@("`@)&0R(#T@
M<W1R<&]S*"1S96%R8V@L("<_)RD["B`@("`@("`@:68@*"1D,B`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("`@("`@?0H*
M("`@("`@("`D96YC;V1I;F<@/2!S=6)S='(H)'-E87)C:"P@,"P@)&0R*3L*
M("`@("`@("`D<V5A<F-H(#T@<W5B<W1R*"1S96%R8V@L("1D,B`K(#$I.PH*
M("`@("`@("`D96YD(#T@<W1R<&]S*"1S96%R8V@L("<_/2<I.PH@("`@("`@
M(&EF("@D96YD(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D96YD(#T@<W1R
M;&5N*"1S96%R8V@I.PH@("`@("`@('T*"B`@("`@("`@)&5N8V]D961?=&5X
M="`]('-U8G-T<B@D<V5A<F-H+"`P+"`D96YD*3L*("`@("`@("`D<F5S="`]
M('-U8G-T<B@D<W1R:6YG+"`H<W1R;&5N*"1P<F5C961I;F<@+B`D8VAA<G-E
M="`N("1E;F-O9&EN9R`N("1E;F-O9&5D7W1E>'0I("L@-BDI.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1T;U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`D=&]?
M8VAA<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@
M("`@<W=I=&-H("@D96YC;V1I;F<I('L*("`@("`@("!C87-E("=1)SH*("`@
M("`@("!C87-E("=Q)SH*("`@("`@("`@("`@)&5N8V]D961?=&5X="`]('-T
M<E]R97!L86-E*"=?)RP@)R`G+"`D96YC;V1E9%]T97AT*3L*("`@("`@("`@
M("`@)&1E8V]D960@/2!P<F5G7W)E<&QA8V4H)R\]*%LP+3EA+69=>S)]*2]I
M92<L("=C:'(H,'A<,2DG+"`D96YC;V1E9%]T97AT*3L*("`@("`@("`@("`@
M)&1E8V]D960@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D96-O9&5D+"`D
M8VAA<G-E="P@)'1O7V-H87)S970I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@8V%S92`G0B<Z"B`@("`@("`@8V%S92`G8B<Z"B`@("`@("`@("`@
M("1D96-O9&5D(#T@8F%S938T7V1E8V]D92@D96YC;V1E9%]T97AT*3L*("`@
M("`@("`@("`@)&1E8V]D960@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1D
M96-O9&5D+"`D8VAA<G-E="P@)'1O7V-H87)S970I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)&1E8V]D960@
M/2`G/3\G("X@)&-H87)S970@+B`G/R<@+B`D96YC;V1I;F<@+B`G/R<@+B`D
M96YC;V1E9%]T97AT("X@)S\])SL*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'!R96-E9&EN9R`N("1D96-O9&5D("X@
M34E-13HZ9&5C;V1E*"1R97-T+"`D=&]?8VAA<G-E="D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$96-O9&5S(&%N(%)&0R`R,C,Q+65N8V]D960@<W1R:6YG
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H92!E
M;G1I<F4@<W1R:6YG('1O(&1E8V]D92P@:6YC;'5D:6YG('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R(&YA;64N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T:&%T('1H
M92!T97AT('-H;W5L9"!B92!D96-O9&5D('1O+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!D96-O9&5D('1E>'0L(&]R('1H92!O<FEG:6YA
M;"!S=')I;F<@:68@:70@=V%S(&YO=`H@("`@("H@("`@("`@("`@("`@("`@
M96YC;V1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E4D9#,C(S,2@D
M<W1R:6YG+"`D=&]?8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"@D<&]S(#T@<W1R<&]S*"1S=')I;F<L("<J)RDI(#T]/2!F86QS92D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(6ES<V5T*"1T;U]C:&%R<V5T*2D@>PH@("`@("`@("`@("`D=&]?8VAA
M<G-E="`]($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@("`@('T*"B`@("`@("`@
M)&%T=')I8G5T92`]('-U8G-T<B@D<W1R:6YG+"`P+"`D<&]S*3L*("`@("`@
M("`D8VAA<G-E="`]("1L86YG(#T@;G5L;#L*("`@("`@("`D;W5T<'5T(#T@
M)R<["@H@("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R('-E="!A;F0@;&%N
M9W5A9V4@=7-E9"!I;B!T:&4@96YC;V1I;F<L(&EF"B`@("`@("`@("H@86YY
M+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7EM>/5TK7"I</2A;7B==
M*BDG*%M>)UTJ*2<O(BP@)'-T<FEN9RP@)&UA=&-H97,I*2!["B`@("`@("`@
M("`@("1C:&%R<V5T(#T@)&UA=&-H97-;,5T["B`@("`@("`@("`@("1L86YG
M(#T@)&UA=&-H97-;,ET["B`@("`@("`@("`@("1S=')I;F<@/2!S=')?<F5P
M;&%C92@D8VAA<G-E="`N("(G(B`N("1L86YG("X@(B<B+"`G)RP@)'-T<FEN
M9RD["B`@("`@("`@?0H*("`@("`@("`D;&EN97,@/2!P<F5G7W-P;&ET*"<O
M)R`N('!R96=?<75O=&4H)&%T=')I8G5T92D@+B`G*#\Z7"I<9"DJ+R<L("1S
M=')I;F<I.PH@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1L:6YE+"`G*CTG*3L*("`@("`@
M("`@("`@:68@*"1P;W,@/3T](#`I('L*("`@("`@("`@("`@("`@("1L:6YE
M(#T@<W5B<W1R*"1L:6YE+"`R*3L*("`@("`@("`@("`@("`@("1L:6YE(#T@
M<W1R7W)E<&QA8V4H)U\G+"`G)3(P)RP@)&QI;F4I.PH@("`@("`@("`@("`@
M("`@)&QI;F4@/2!S=')?<F5P;&%C92@G/2<L("<E)RP@)&QI;F4I.PH@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!U<FQD96-O9&4H)&QI;F4I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QI;F4@/2!S=6)S
M='(H)&QI;F4L(#$I.PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4D9#(#(R
M,S$@=7-E<R!Q=6]T960@<')I;G1A8FQE(&5N8V]D:6YG+B`J+PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@)&]U='!U
M="`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&]U='!U="P@)&-H87)S970L
M("1T;U]C:&%R<V5T*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A
M>2@*("`@("`@("`@("`@)V%T=')I8G5T92<@/3X@)&%T=')I8G5T92P*("`@
M("`@("`@("`@)W9A;'5E)R`]/B`D;W5T<'5T"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($EF(&%N(&5M86EL(&%D9')E<W,@:&%S(&YO('!E
M<G-O;F%L(&EN9F]R;6%T:6]N+"!G970@<FED(&]F(&%N>2!A;F=L90H@("`@
M("H@8G)A8VME=',@*#P^*2!A<F]U;F0@:70N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D861D<F5S<R`@5&AE(&%D9')E<W,@=&\@=')I;2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1R:6UM960@861D<F5S
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=')I;45M86EL061D<F5S<R@D861D
M<F5S<RD*("`@('L*("`@("`@("`D861D<F5S<R`]('1R:6TH)&%D9')E<W,I
M.PH*("`@("`@("!I9B`H*'-U8G-T<B@D861D<F5S<RP@,"P@,2D@/3T@)SPG
M*2`F)B`H<W5B<W1R*"1A9&1R97-S+"`M,2D@/3T@)SXG*2D@>PH@("`@("`@
M("`@("`D861D<F5S<R`]('-U8G-T<B@D861D<F5S<RP@,2P@+3$I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1A9&1R97-S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0G5I;&1S(&%N(%)&0R`X,C(@8V]M<&QI86YT(&5M86EL(&%D
M9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@
M($UA:6QB;W@@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&AO<W0@("`@
M("!$;VUA:6X@;F%M92!O9B!M86EL8F]X)W,@:&]S="X*("`@("`J($!P87)A
M;2!S=')I;F<@)'!E<G-O;F%L("!097)S;VYA;"!N86UE('!H<F%S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O<G)E8W1L>2!E<V-A
M<&5D(&%N9"!Q=6]T960*("`@("`J("`@("`@("`@("`@("`@("`B)'!E<G-O
M;F%L(#PD;6%I;&)O>$`D:&]S=#XB('-T<FEN9RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F9C.#(R5W)I=&5!9&1R97-S*"1M86EL8F]X+"`D:&]S="`](&YU
M;&PL("1P97)S;VYA;"`]("<G*0H@("`@>PH@("`@("`@("1A9&1R97-S(#T@
M)R<["@H@("`@("`@(&EF("@A96UP='DH)'!E<G-O;F%L*2D@>PH@("`@("`@
M("`@("`D=F%R<R`](&=E=%]C;&%S<U]V87)S*"=-24U%)RD["B`@("`@("`@
M("`@("1A9&1R97-S("X]($U)344Z.E]R9F,X,C)%;F-O9&4H)'!E<G-O;F%L
M+"`D=F%R<ULG<F9C.#(R7V9I;'1E<B==("X@)RXG*3L*("`@("`@("`@("`@
M)&%D9')E<W,@+CT@)R`\)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?
M;G5L;"@D:&]S="DI('L*("`@("`@("`@("`@)&%D9')E<W,@+CT@34E-13HZ
M7W)F8S@R,D5N8V]D92@D;6%I;&)O>"D["B`@("`@("`@("`@(&EF("AS=6)S
M='(H)&AO<W0L(#`L(#$I("$]("=`)RD@>PH@("`@("`@("`@("`@("`@)&%D
M9')E<W,@+CT@)T`G("X@)&AO<W0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@A96UP='DH)'!E<G-O;F%L*2D@>PH@("`@("`@("`@
M("`D861D<F5S<R`N/2`G/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&%D9')E<W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!L;V1E<R!A(%)&
M0R`X,C(@<W1R:6YG+"!I9VYO<FEN9R!A(&1E;&EM:71E<B!I9B!P<F5C961E
M9"!B>2!A(")<(@H@("`@("H@8VAA<F%C=&5R+"!O<B!I9B!D96QI;6ET97(@
M:7,@:6YS:61E('-I;F=L92!O<B!D;W5B;&4@<75O=&5S+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-T<B`@("`@("`@5&AE(%)&0R`X,C(@<W1R
M:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5L:6UI=&5R("!4:&4@9&5L
M:6UT97(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&5X<&QO
M9&5D('-T<FEN9R!I;B!A;B!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F9C.#(R17AP;&]D92@D<W1R+"`D9&5L:6UI=&5R*0H@("`@>PH@("`@("`@
M("1A<G(@/2!A<G)A>2@I.PH@("`@("`@("1M871C:"`](#`["B`@("`@("`@
M)'%U;W1E<R`](&%R<F%Y*"<B)RP@(B<B*3L*("`@("`@("`D:6Y?<75O=&4@
M/2!N=6QL.PH@("`@("`@("1I;E]G<F]U<"`](&9A;'-E.PH@("`@("`@("1P
M<F5V(#T@;G5L;#L*"B`@("`@("`@:68@*&5M<'1Y*"1S='(I*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@D<W1R*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI;E]A<G)A>2@D<W1R>S!]+"`D<75O=&5S*2D@>PH@("`@("`@("`@
M("`D:6Y?<75O=&4@/2`D<W1R>S!].PH@("`@("`@('T@96QS96EF("@D<W1R
M>S!](#T]("<Z)RD@>PH@("`@("`@("`@("`D:6Y?9W)O=7`@/2!T<G5E.PH@
M("`@("`@('T@96QS96EF("@D<W1R>S!](#T]("1D96QI;6ET97(I('L*("`@
M("`@("`@("`@)&%R<EM=(#T@)R<["B`@("`@("`@("`@("1M871C:"`](#$[
M"B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"!S=')L96XH
M)'-T<BD[("1I*RLI('L*("`@("`@("`@("`@)&-H87(@/2`D<W1R>R1I?3L*
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1C:&%R+"`D<75O=&5S*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1P<F5V("$]/2`G7%PG*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1I;E]Q=6]T92`]/3T@)&-H87(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN7W%U;W1E(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-?;G5L;"@D:6Y?<75O=&4I*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;E]Q=6]T92`]("1C:&%R.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E:68@*"1I;E]G<F]U<"D@>PH@("`@("`@("`@("`@("`@:68@
M*"1C:&%R(#T]("<[)RD@>PH@("`@("`@("`@("`@("`@("`@("1A<G);72`]
M('-U8G-T<B@D<W1R+"`D;6%T8V@L("1I("T@)&UA=&-H("L@,2D["B`@("`@
M("`@("`@("`@("`@("`@)&UA=&-H(#T@)&D@*R`Q.PH@("`@("`@("`@("`@
M("`@("`@("1I;E]G<F]U<"`](&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V5I9B`H)&-H87(@/3T@)SHG*2!["B`@("`@("`@
M("`@("`@("`D:6Y?9W)O=7`@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&-H87(@/3T@)&1E;&EM:71E<B`F)@H@("`@("`@("`@("`@("`@("`@
M("`@)'!R978@(3T]("=<7"<@)B8*("`@("`@("`@("`@("`@("`@("`@(&ES
M7VYU;&PH)&EN7W%U;W1E*2D@>PH@("`@("`@("`@("`@("`@)&%R<EM=(#T@
M<W5B<W1R*"1S='(L("1M871C:"P@)&D@+2`D;6%T8V@I.PH@("`@("`@("`@
M("`@("`@)&UA=&-H(#T@)&D@*R`Q.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1P<F5V(#T@)&-H87(["B`@("`@("`@?0H*("`@("`@("!I9B`H)&UA
M=&-H("$]("1I*2!["B`@("`@("`@("`@("\J(%1H92!S=')I;F<@96YD960@
M=VET:&]U="!A("1D96QI;6ET97(N("HO"B`@("`@("`@("`@("1A<G);72`]
M('-U8G-T<B@D<W1R+"`D;6%T8V@L("1I("T@)&UA=&-H*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D87)R.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5&%K97,@86X@861D<F5S<R!O8FIE8W0L(&%S(')E='5R;F5D(&)Y(&EM87!?
M:&5A9&5R*"D@9F]R(&5X86UP;&4L(&%N9`H@("`@("H@9F]R;6%T<R!I="!A
M<R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!/8FIE8W0@9F]R;6%T(&9O<B!T
M:&4@861D<F5S<R`B2F]H;B!$;V4@/&IO:&Y?9&]E0&5X86UP;&4N8V]M/B(@
M:7,Z"B`@("`@*B`\<')E/@H@("`@("H@("`D;V)J96-T+3YP97)S;VYA;"`]
M(%!E<G-O;F%L(&YA;64@*")*;VAN($1O92(I"B`@("`@*B`@("1O8FIE8W0M
M/FUA:6QB;W@@(#T@5&AE('5S97(G<R!M86EL8F]X("@B:F]H;E]D;V4B*0H@
M("`@("H@("`D;V)J96-T+3YH;W-T("`@("`](%1H92!H;W-T('1H92!M86EL
M8F]X(&ES(&]N("@B97AA;7!L92YC;VTB*0H@("`@("H@/"]P<F4^"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1O8B`@(%1H92!A9&1R97-S(&]B
M:F5C="!T;R!B92!T=7)N960@:6YT;R!A('-T<FEN9RX*("`@("`J($!P87)A
M;2!M:7AE9"`D9FEL=&5R("!!('5S97)`97AA;7!L92YC;VT@<W1Y;&4@8F%R
M92!A9&1R97-S('1O(&EG;F]R92X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!%:71H97(@<VEN9VQE('-T<FEN9R!O<B!A;B!A<G)A>2!O9B!S=')I
M;F=S+B`@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@861D
M<F5S<R!M871C:&5S("1F:6QT97(L(&%N(&5M<'1Y('-T<FEN9R!W:6QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8F4@<F5T=7)N960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@861D<F5S
M<R`H17AA;7!L93H@2F]H;B!$;V4*("`@("`J("`@("`@("`@("`@("`@("`\
M:F]H;E]D;V5`97AA;7!L92YC;VT^*2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D<D]B:F5C=#)3=')I;F<H)&]B+"`D9FEL=&5R(#T@)R<I"B`@("!["B`@
M("`@("`@+RH@268@=&AE('!E<G-O;F%L(&YA;64@:7,@<V5T+"!D96-O9&4@
M:70N("HO"B`@("`@("`@)&]B+3YP97)S;VYA;"`](&ES<V5T*"1O8BT^<&5R
M<V]N86PI(#\@34E-13HZ9&5C;V1E*"1O8BT^<&5R<V]N86PI(#H@)R<["@H@
M("`@("`@("\J($EF(&)O=&@@=&AE(&UA:6QB;W@@86YD('1H92!H;W-T(&%R
M92!E;7!T>2P@<F5T=7)N(&%N(&5M<'1Y"B`@("`@("`@("`@<W1R:6YG+B`@
M268@=V4@:G5S="!L970@=&AI<R!C87-E(&9A;&P@=&AR;W5G:"P@=&AE(&-A
M;&P@=&\*("`@("`@("`@("!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H*2!W
M:6QL(&5N9"!U<"!R971U<FX@:G5S="!A("=`)RP@=VAI8V@*("`@("`@("`@
M("!I<R!U;F1E<VER86)L92X@*B\*("`@("`@("!I9B`H96UP='DH)&]B+3YM
M86EL8F]X*2`F)B!E;7!T>2@D;V(M/FAO<W0I*2!["B`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!T:&5S
M92!T=V\@=F%R:6%B;&5S(&AA=F4@<V]M92!S;W)T(&]F('9A;'5E+B`J+PH@
M("`@("`@(&EF("@A:7-S970H)&]B+3YM86EL8F]X*2D@>PH@("`@("`@("`@
M("`D;V(M/FUA:6QB;W@@/2`G)SL*("`@("`@("!](&5L<V5I9B`H)&]B+3YM
M86EL8F]X(#T]("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S)RD@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H
M)&]B+3YH;W-T*2D@>PH@("`@("`@("`@("`D;V(M/FAO<W0@/2`G)SL*("`@
M("`@("!]"@H@("`@("`@("\J($9I;'1E<B!O=70@=6YW86YT960@861D<F5S
M<V5S(&)A<V5D(&]N('1H92`D9FEL=&5R('-T<FEN9RX@*B\*("`@("`@("!I
M9B`H)&9I;'1E<BD@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QT
M97(I*2!["B`@("`@("`@("`@("`@("`D9FEL=&5R(#T@87)R87DH)&9I;'1E
M<BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&9I;'1E
M<B!A<R`D9BD@>PH@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)&8L
M("1O8BT^;6%I;&)O>"`N("=`)R`N("1O8BT^:&]S="D@/3T@,"D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N('1H
M92!T<FEM;65D+"!F;W)M871T960@96UA:6P@861D<F5S<RX@*B\*("`@("`@
M("!R971U<FX@34E-13HZ=')I;45M86EL061D<F5S<RA-24U%.CIR9F,X,C)7
M<FET94%D9')E<W,H)&]B+3YM86EL8F]X+"`D;V(M/FAO<W0L("1O8BT^<&5R
M<V]N86PI*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%N(&%R<F%Y
M(&]F(&%D9')E<W,@;V)J96-T<RP@87,@<F5T=7)N960@8GD@:6UA<%]H96%D
M97)I;F9O*"DL"B`@("`@*B!F;W(@97AA;7!L92P@86YD('!A<W-E<R!E86-H
M(&]F('1H96T@=&AR;W5G:"!-24U%.CIA9&1R3V)J96-T,E-T<FEN9R@I+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D861D<F5S<V5S("!4:&4@87)R
M87D@;V8@861D<F5S<R!O8FIE8W1S+@H@("`@("H@0'!A<F%M(&UI>&5D("1F
M:6QT97(@("`@($$@=7-E<D!E>&%M<&QE+F-O;2!S='EL92!B87)E(&%D9')E
M<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I9VYO<F4N
M("!)9B!A;GD@861D<F5S<R!M871C:&5S("1F:6QT97(L(&ET"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@=VEL;"!N;W0@8F4@:6YC;'5D960@
M:6X@=&AE(&9I;F%L('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@06QL(&]F('1H92!A9&1R97-S97,@:6X@82!C;VUM82UD96QI;6ET
M960@<W1R:6YG+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@=&AE
M(&5M<'1Y('-T<FEN9R!O;B!E<G)O<B]N;R!A9&1R97-S97,@9F]U;F0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9')!<G)A>3)3=')I;F<H)&%D9')E<W-E
M<RP@)&9I;'1E<B`]("<G*0H@("`@>PH@("`@("`@("1A9&1R3&ES="`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@A:7-?87)R87DH)&%D9')E<W-E<RDI('L*
M("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)&%D9')E<W-E<R!A<R`D861D<BD@>PH@("`@("`@("`@("`D=F%L
M(#T@34E-13HZ861D<D]B:F5C=#)3=')I;F<H)&%D9'(L("1F:6QT97(I.PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1V86PI*2!["B`@("`@("`@("`@("`@
M("`D8F%R94%D9'(@/2!3=')I;F<Z.FQO=V5R*$U)344Z.F)A<F5!9&1R97-S
M*"1V86PI*3L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&%D9'),:7-T
M6R1B87)E061D<ETI*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9'),:7-T
M6R1B87)E061D<ET@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)&%D9'),:7-T
M*2D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&EM<&QO9&4H)RP@)RP@)&%D9'),:7-T*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!B
M87)E(&%D9')E<W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D
M<F5S<R`@("!4:&4@861D<F5S<R!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D969S97)V97(@(%1H92!D969A=6QT(&1O;6%I;B!T;R!A<'!E;F0@
M=&\@;6%I;&)O>&5S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&UU;'1I<&QE
M("!3:&]U;&0@=V4@<F5T=7)N(&UU;'1I<&QE(')E<W5L=',_"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@268@)&UU;'1I<&QE(&ES(&9A;'-E+"!R
M971U<FYS('1H92!M86EL8F]X0&AO<W0@92UM86EL"B`@("`@*B`@("`@("`@
M("`@("`@("!A9&1R97-S+B`@268@)&UU;'1I<&QE(&ES('1R=64L(')E='5R
M;G,@86X@87)R87D@;V8*("`@("`J("`@("`@("`@("`@("`@('1H97-E(&%D
M9')E<W-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8F%R94%D9')E<W,H)&%D
M9')E<W,L("1D969S97)V97(@/2!N=6QL+"`D;75L=&EP;&4@/2!F86QS92D*
M("`@('L*("`@("`@("`D861D<F5S<TQI<W0@/2!A<G)A>2@I.PH*("`@("`@
M("`O*B!5<V4@8G5I;'0M:6X@24U!4"!F=6YC=&EO;B!O;FQY(&EF(&%V86EL
M86)L92!A;F0@:68@;F]T('!A<G-I;F<*("`@("`@("`@*B!D:7-T<FEB=71I
M;VX@;&ES=',@8F5C875S92!I="!D;V5S;B=T('!A<G-E(&1I<W1R:6)U=&EO
M;B!L:7-T<PH@("`@("`@("`J('!R;W!E<FQY+B`J+PH@("`@("`@(&EF("A5
M=&EL.CIE>'1E;G-I;VY%>&ES=',H)VEM87`G*2`F)B!S=')P;W,H)&%D9')E
M<W,L("<Z)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1F<F]M(#T@:6UA
M<%]R9F,X,C)?<&%R<V5?861R;&ES="@D861D<F5S<RP@)&1E9G-E<G9E<BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=-
M86EL+U)&0S@R,BYP:'`G.PH@("`@("`@("`@("`D<&%R<V5R(#T@;F5W($UA
M:6Q?4D9#.#(R*"D["B`@("`@("`@("`@("1F<F]M(#T@)'!A<G-E<BT^<&%R
M<V5!9&1R97-S3&ES="@D861D<F5S<RP@)&1E9G-E<G9E<BP@9F%L<V4L(&9A
M;'-E*3L*("`@("`@("`@("`@:68@*&ES7V$H)&9R;VTL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;75L=&EP;&4@/R!A<G)A
M>2@I(#H@)R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1F<F]M(&%S("1E;G1R>2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)&5N=')Y+3YM86EL8F]X*2`F)@H@("`@("`@("`@("`@("`@)&5N=')Y
M+3YM86EL8F]X("$]("=U;F1I<V-L;W-E9"UR96-I<&EE;G1S)R`F)@H@("`@
M("`@("`@("`@("`@)&5N=')Y+3YM86EL8F]X("$]("=53D584$5#5$5$7T1!
M5$%?049415)?041$4D534R<I('L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D96YT<GDM/FAO<W0I*2!["B`@("`@("`@("`@("`@("`@("`@)&%D9')E
M<W-,:7-T6UT@/2`D96YT<GDM/FUA:6QB;W@@+B`G0"<@+B`D96YT<GDM/FAO
M<W0["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1A9&1R97-S3&ES=%M=(#T@)&5N=')Y+3YM86EL8F]X.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&UU;'1I<&QE(#\@)&%D9')E<W-,:7-T(#H@87)R87E?<&]P*"1A
M9&1R97-S3&ES="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@86YD
M(&5S8V%P97,@=&AE(&=I=F5N('-T<FEN9R!I9B!N96-E<W-A<GDN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<W1R("`@("!4:&4@<W1R:6YG('1O(&)E('%U;W1E9"!A;F0@
M97-C87!E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I;'1E<B`@02!L:7-T
M(&]F(&-H87)A8W1E<G,@=&AA="!M86ME(&ET(&YE8V5S<V%R>2!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!Q=6]T92!T:&4@<W1R:6YG(&EF
M('1H97D@;V-C=7(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C;W)R96-T;'D@<75O=&5D(&%N9"!E<V-A<&5D('-T<FEN9RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W)F8S@R,D5N8V]D92@D<W1R+"`D9FEL=&5R(#T@
M)R<I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1F:6QT97(I*2!["B`@("`@
M("`@("`@("1V87)S(#T@9V5T7V-L87-S7W9A<G,H)TU)344G*3L*("`@("`@
M("`@("`@)&9I;'1E<B`]("1V87)S6R=R9F,X,C)?9FEL=&5R)UT@+B`G("<[
M"B`@("`@("`@?0H*("`@("`@("`O+R!3=')I<"!D;W5B;&4@<75O=&5S(&EF
M('1H97D@87)E(&%R;W5N9"!T:&4@<W1R:6YG(&%L<F5A9'DN"B`@("`@("`@
M:68@*'-U8G-T<B@D<W1R+"`P+"`Q*2`]/2`G(B<@)B8@<W5B<W1R*"1S='(L
M("TQ*2`]/2`G(B<I('L*("`@("`@("`@("`@)'-T<B`]('-U8G-T<B@D<W1R
M+"`Q+"`M,2D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R8W-P;B@D<W1R
M+"`D9FEL=&5R*2`A/2!S=')L96XH)'-T<BDI('L*("`@("`@("`@("`@)'-T
M<B`]('-T<E]R97!L86-E*"=<(B<L("<B)RP@)'-T<BD["B`@("`@("`@("`@
M(')E='5R;B`G(B<@+B!S=')?<F5P;&%C92@G(B<L("=<7"(G+"!S=')?<F5P
M;&%C92@G7%PG+"`G7%Q<7"<L("1S='(I*2`N("<B)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@)'-T<CL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!-24U%('1Y<&4@9F]R('1H
M92!G:79E;B!I;G!U="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN
M<'5T("`@("!%:71H97(@=&AE($U)344@8V]D92!O<B!T>7!E('-T<FEN9RX*
M("`@("`J($!P87)A;2!I;G1E9V5R("1F;W)M870@($EF($U)345?0T]$12P@
M<F5T=7)N(&-O9&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!)
M9B!-24U%7U-44DE.1RP@<F5T=7)N<R!L;W=E<F-A<V4@<W1R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%-E92!A8F]V92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@='EP92@D:6YP=70L("1F;W)M870@/2!N=6QL*0H@("`@
M>PH@("`@("`@(')E='5R;B!-24U%.CI?9V5T0V]D92@D:6YP=70L("1F;W)M
M870L("=M:6UE7W1Y<&5S)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!-24U%(&5N8V]D:6YG(&9O<B!T:&4@9VEV96X@:6YP=70N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1I;G!U="`@("`@16ET:&5R('1H
M92!-24U%(&-O9&4@;W(@96YC;V1I;F<@<W1R:6YG+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&9O<FUA="`@268@34E-15]#3T1%+"!R971U<FX@8V]D92X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($EF($U)345?4U1224Y'
M+"!R971U<FYS(&QO=V5R8V%S92!S=')I;F<N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!)9B!N;W0@<V5T+"!R971U<FYS('1H92!O<'!O<VET
M92!V86QU92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!3964@86)O
M=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8V]D:6YG*"1I;G!U="P@)&9O
M<FUA="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N($U)344Z.E]G971#
M;V1E*"1I;G!U="P@)&9O<FUA="P@)VUI;65?96YC;V1I;F=S)RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@34E-12!E;F-O9&EN9R]T>7!E
M(&1A=&$@9G)O;2!T:&4@:6YT97)N86P@87)R87ES+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M:6YP=70@("`@16ET:&5R('1H92!-24U%(&-O9&4@;W(@96YC;V1I;F<@<W1R
M:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!)9B!-24U%7T-/
M1$4L(')E='5R;G,@8V]D92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@268@34E-15]35%))3D<L(')E='5R;G,@;&]W97)C87-E('-T<FEN9RX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@268@;G5L;"P@<F5T=7)N
M<R!T:&4@;W!P<&]S:71E('9A;'5E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M='EP92`@("!4:&4@;F%M92!O9B!T:&4@:6YT97)N86P@87)R87DN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@4V5E(&%B;W9E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T0V]D92@D:6YP=70L("1F;W)M870L("1T>7!E*0H@
M("`@>PH@("`@("`@("1N=6UE<FEC(#T@:7-?;G5M97)I8R@D:6YP=70I.PH@
M("`@("`@(&EF("@A)&YU;65R:6,I('L*("`@("`@("`@("`@)&EN<'5T(#T@
M4W1R:6YG.CIL;W=E<B@D:6YP=70I.PH@("`@("`@('T*"B`@("`@("`@<W=I
M=&-H("@D9F]R;6%T*2!["B`@("`@("`@8V%S92!-24U%7T-/1$4Z"B`@("`@
M("`@("`@(&EF("@D;G5M97)I8RD@<F5T=7)N("1I;G!U=#L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@34E-15]35%))3D<Z"B`@("`@("`@
M("`@(&EF("@A)&YU;65R:6,I(')E='5R;B`D:6YP=70["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@)'9A<G,@/2!G971?8VQA<W-?
M=F%R<R@G34E-12<I.PH*("`@("`@("!I9B`H)&YU;65R:6,I('L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1V87)S6R1T>7!E75LD:6YP=71=*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1V87)S6R1T>7!E75LD:6YP=71=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"@D
M<V5A<F-H(#T@87)R87E?<V5A<F-H*"1I;G!U="P@)'9A<G-;)'1Y<&5=*2DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<V5A<F-H.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E<R!A($UE<W-A9V4M240@<W1R:6YG(&-O
M;F9O<FUI;F<@=&\@4D9#(#(X,C(@6S,N-BXT72!A;F0@=&AE"B`@("`@*B!S
M=&%N9&%R9',@;W5T;&EN960@:6X@)V1R869T+6EE=&8M=7-E9F]R+6UE<W-A
M9V4M:60M,#$N='AT)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!!
M(&UE<W-A9V4@240@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE
M<F%T94UE<W-A9V5)1"@I"B`@("!["B`@("`@("`@<F5T=7)N("<\)R`N(&1A
M=&4H)UEM9$AI<R<I("X@)RXG("X*("`@("`@("`@("`@<W5B<W1R*&)A<V5?
M8V]N=F5R="AM:6-R;W1I;64H*2`N(&UT7W)A;F0H*2P@,3`L(#,V*2P@+3$V
M*2`N"B`@("`@("`@("`@("=`)R`N("1?4T525D526R=315)615)?3D%-12==
M("X@)SXG.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!P<F]P97(@;&EN
M96)R96%K<R!T;R!A(&AE861E<B!S=')I;F<N"B`@("`@*B!21D,@,C@R,B!;
M,BXR+C-=('-A>7,@=&AA="!H96%D97)S(%-(3U5,1"!B92!W<F%P<&5D(&%T
M(#<X(&-H87)A8W1E<G,N"B`@("`@*B!(;W=E=F5R+"!S:6YC92!W92!M87D@
M8F4@9&5A;&EN9R!W:71H('%U;W1E9"!T97AT('1H870@8V]N=&%I;G,@<W!A
M8V5S+`H@("`@("H@<W1R:6-T('=R87!P:6YG(&%T(#<X(&-H87)A8W1E<G,@
M;6%Y(&%D9"!U;G=A;G1E9"!N97=L:6YE<R!A;F0@=&%B<R!T;PH@("`@("H@
M=&AE('%U;W1E9"!P87)A;65T97(N("!4:&4@8V]R<F5C="!W87D@=&\@9V5T
M(&%R;W5N9"!T:&ES(&ES('1O(&5N8V]D90H@("`@("H@<&%R865T97)S(&%C
M8V]R9&EN9R!T;R!21D,@,C(S,2X@($AO=V5V97(L('-I;F-E(&UO<W0@;6%I
M;&5R<R!D;R!N;W0*("`@("`J('-E96T@=&\@<W5P<&]R="!T:&ES+"!W92!W
M:6QL(&EN<W1E860@<VEM<&QY('5S92!L;VYG(&QI;F5S+B`@4D9#(#(X,C(*
M("`@("`J('-A>7,@:&5A9&5R<R!32$]53$0@;VYL>2!B92`W."!C:&%R86-T
M97)S(&$@;&EN92P@8G5T(&%L<V\@<V%Y<R!T:&%T"B`@("`@*B!A(&AE861E
M<B!L:6YE($U54U0@;F]T(&)E(&UO<F4@=&AA;B`Y.3@@8VAA<F%C=&5R<RX@
M(%1H97)E9F]R92P@=&AE"B`@("`@*B!C;VUP<F]M:7-E(&ES('1O('!U="!E
M86-H('!A<F%M971E<B!O;B!A('-E<&%R871E(&QI;F4@86YD(&-H;W`@:70*
M("`@("`J(&]N;'D@:68@:70@:7,@;&]N9V5R('1H86X@.3DX(&-H87)A8W1E
M<G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@
M:&5A9&5R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@(%1H
M92!T97AT(&]F('1H92!H96%D97(@9FEE;&0N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E;VP@("`@(%1H92!%3TP@<W1R:6YG('1O('5S92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&AE861E<B!T97AT+"!W:71H(&QI
M;F5B<F5A:W,@:6YS97)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R87!(
M96%D97)S*"1H96%D97(L("1T97AT+"`D96]L(#T@(EQR7&XB*0H@("`@>PH@
M("`@("`@("1H96%D97(@/2!R=')I;2@D:&5A9&5R*3L*"B`@("`@("`@+RH@
M4F5M;W9E(&%N>2!E>&ES=&EN9R!L:6YE8G)E86MS+B`J+PH@("`@("`@("1T
M97AT(#T@<')E9U]R97!L86-E*"(O7'(_7&Y<<S\O(BP@)R`G+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2`D:&5A9&5R("X@)SH@)R`N(')T<FEM*"1T97AT
M*3L*"B`@("`@("`@)&5O;&QE;F=T:"`]('-T<FQE;B@D96]L*3L*("`@("`@
M("`D:&5A9&5R7VQO=V5R(#T@<W1R=&]L;W=E<B@D:&5A9&5R*3L*"B`@("`@
M("`@:68@*"@D:&5A9&5R7VQO=V5R("$]("=C;VYT96YT+71Y<&4G*2`F)@H@
M("`@("`@("`@("`H)&AE861E<E]L;W=E<B`A/2`G8V]N=&5N="UD:7-P;W-I
M=&EO;B<I*2!["B`@("`@("`@("`@("\J(%=R87`@=&AE(&QI;F4N("HO"B`@
M("`@("`@("`@("1L:6YE(#T@=V]R9'=R87`H)'1E>'0L(#<U+"`D96]L("X@
M(EQT(BD["@H@("`@("`@("`@("`O*B!-86ME('-U<F4@=&AE<F4@87)E(&YO
M(&5M<'1Y(&QI;F5S+B`J+PH@("`@("`@("`@("`D;&EN92`]('!R96=?<F5P
M;&%C92@G+R<@+B`D96]L("X@(EQT7',J(B`N("1E;VP@+B`B7'0O(BP@)R\G
M("X@)&5O;"`N(")<="\B+"`D;&EN92D["@H@("`@("`@("`@("!R971U<FX@
M<W5B<W1R*"1L:6YE+"!S=')L96XH)&AE861E<BD@*R`R*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%-P;&ET('1H92!L:6YE(&)Y('1H92!21D,@<&%R86UE
M=&5R('-E<&%R871O<B`G.R<N("HO"B`@("`@("`@)'!A<F%M<R`]('!R96=?
M<W!L:70H(B]<<RH[7',J+R(L("1T97AT*3L*"B`@("`@("`@)&QI;F4@/2`G
M)SL*("`@("`@("`D;&5N9W1H(#T@,3`P,"`M("1E;VQL96YG=&@["B`@("`@
M("`@)'!A<F%M8V]U;G0@/2!C;W5N="@D<&%R86US*3L*"B`@("`@("`@9F]R
M96%C:"`H)'!A<F%M<R!A<R`D8V]U;G0@/3X@)'9A;"D@>PH@("`@("`@("`@
M("`O*B!)9B!L;VYG97(@=&AA;B!21D,@86QL;W=S+"!T:&5N('-I;7!L>2!C
M:&]P(&]F9B!T:&4@97AC97-S+B`J+PH@("`@("`@("`@("`D;6]R97!A<F%M
M<R`]("@H)&-O=6YT("L@,2D@(3T@)'!A<F%M8V]U;G0I.PH@("`@("`@("`@
M("`D;6%X;&5N9W1H(#T@)&QE;F=T:"`M("@A96UP='DH)&QI;F4I(#\@,2`Z
M(#`I("T@*"@D;6]R97!A<F%M<RD@/R`Q(#H@,"D["B`@("`@("`@("`@(&EF
M("AS=')L96XH)'9A;"D@/B`D;6%X;&5N9W1H*2!["B`@("`@("`@("`@("`@
M("`D=F%L(#T@<W5B<W1R*"1V86PL(#`L("1M87AL96YG=&@I.PH*("`@("`@
M("`@("`@("`@("\J($EF('=E(&AA=F4@86X@;W!E;FEN9R!Q=6]T92P@861D
M(&$@8VQO<VEN9R!Q=6]T92!A9G1E<@H@("`@("`@("`@("`@("`@("H@8VAO
M<'!I;F<@=&AE(')E<W0@;V8@=&AE('1E>'0N("HO"B`@("`@("`@("`@("`@
M("!I9B`H<W1R<&]S*"1V86PL("<B)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@)'9A;"`]('-U8G-T<B@D=F%L+"`P+"`M,2D["B`@("`@
M("`@("`@("`@("`@("`@)'9A;"`N/2`G(B<["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1L:6YE
M*2D@>PH@("`@("`@("`@("`@("`@)&QI;F4@+CT@(EQT(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D;&EN92`N/2`D=F%L("X@*"@D;6]R97!A<F%M
M<RD@/R`G.R<@.B`G)RD@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('-U8G-T<B@D;&EN92P@<W1R;&5N*"1H96%D97(I("L@,BP@*"1E;VQL
M96YG=&@@*B`M,2DI.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%R<F%Y+G!H<```````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$W,3(S(#$P-3$U-#,T,30P(#`R,3$S,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($AO<F1E7T%R<F%Y.CH@8VQA<W,@<')O=FED97,@=F%R:6]U<R!M971H;V1S
M(&9O<B!A<G)A>2!M86YI<'5L871I;VXN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U5T:6PO07)R87DN<&AP+'8@,2XR-BXR+C@@,C`P-B\P,2\P,2`R,3HR
M.#HT,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC
M:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@
M*B!`875T:&]R("!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`
M875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?571I;`H@*B\*8VQA
M<W,@2&]R9&5?07)R87D@>PH*("`@("\J*@H@("`@("H@4')E<&%R92!A(&QI
M<W0@;V8@861D<F5S<V5S(&9O<B!S=&]R86=E+@H@("`@("H@3F%M96QY+"!T
M<FEM<R!A;F0@;&]W97)C87-E<R!A;&P@861D<F5S<V5S(&%N9"!T:&5N('-O
M<G0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A9&1R("!4:&4@;&ES
M="!O9B!A9&1R97-S97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M5&AE(&QI<W0@;V8@861D<F5S<V5S+"!P<F5P87)E9"!F;W(@<W1O<F%G92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')E<&%R94%D9')E<W-,:7-T*"1A9&1R
M*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!A;GD@97AT<F$@<W!A8V4@:6X@
M=&AE(&%D9')E<W,@86YD(&UA:V4@:70@;&]W97)C87-E+B`J+PH@("`@("`@
M("1A9&1R(#T@87)R87E?;6%P*"=T<FEM)RP@)&%D9'(I.PH@("`@("`@("1A
M9&1R(#T@87)R87E?;6%P*&%R<F%Y*"=3=')I;F<G+"`G;&]W97(G*2P@)&%D
M9'(I.PH*("`@("`@("`O*B!296UO=F4@9'5P;&EC871E(&5N=')I97,N("HO
M"B`@("`@("`@)&%D9'(@/2!A<G)A>5]U;FEQ=64H)&%D9'(I.PH*("`@("`@
M("`O*B!3;W)T('1H92!L:7-T+B`J+PH@("`@("`@('5S;W)T*"1A9&1R+"!A
M<G)A>2@G2&]R9&5?07)R87DG+"`G<V]R=$%D9')E<W-,:7-T)RDI.PH*("`@
M("`@("!R971U<FX@)&%D9'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!U<V5D(&)Y('5S;W)T*"D@=&\@<V]R="!A;B!A9&1R97-S(&QI<W0N
M"B`@("`@*B!E+F<N('5S;W)T*"1F;V\L(&%R<F%Y*"=(;W)D95]!<G)A>2<L
M("=S;W)T061D<F5S<TQI<W0G*2D["B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D82`@061D<F5S<R`C,2X*("`@("`J($!P87)A;2!S=')I;F<@)&(@
M($%D9')E<W,@(S(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`M
M,2P@,"P@;W(@,2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$%D9')E<W-,
M:7-T*"1A+"`D8BD*("`@('L*("`@("`@("`D82`](&5X<&QO9&4H)T`G+"`D
M82D["B`@("`@("`@)&(@/2!E>'!L;V1E*"=`)RP@)&(I.PH*("`@("`@("`O
M*B!/;F4@;V8@=&AE(&%D9')E<W-E<R!D;V5S;B=T(&AA=F4@82!H;W-T(&YA
M;64N("HO"B`@("`@("`@:68@*&5M<'1Y*"1A6S!=*2D@>PH@("`@("`@("`@
M("!A<G)A>5]S:&EF="@D82D["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D8ELP72DI('L*("`@("`@("`@("`@87)R87E?<VAI9G0H)&(I.PH@("`@
M("`@('T*("`@("`@("!I9B`H8V]U;G0H)&$I("$](&-O=6YT*"1B*2D@>PH@
M("`@("`@("`@("!R971U<FX@*&-O=6YT*"1A*2`^(&-O=6YT*"1B*2D["B`@
M("`@("`@?0H*("`@("`@("`O*B!4:&4@861D<F5S<V5S(&AA=F4@9&EF9F5R
M96YT(&AO<W1N86UE(&]R(&YO="!H;W-T;F%M92!A;F0*("`@("`@("`@("!D
M:69F97)E;G0@;6%I;&)O>"!N86UE<RX@*B\*("`@("`@("!I9B`H)&%;*&-O
M=6YT*"1A*2`M(#$I72`A/2`D8ELH8V]U;G0H)&(I("T@,2E=*2!["B`@("`@
M("`@("`@(')E='5R;B!S=')C;7`H)&%;*&-O=6YT*"1A*2`M(#$I72P@)&);
M*&-O=6YT*"1B*2`M(#$I72D["B`@("`@("`@?0H*("`@("`@("`O*B!#;VUP
M87)E(&UA:6QB;W@@;F%M97,N("HO"B`@("`@("`@<F5T=7)N('-T<F-M<"@D
M85LP72P@)&);,%TI.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R=',@86X@
M87)R87D@;VX@82!S<&5C:69I960@:V5Y+B!)9B!T:&4@:V5Y(&1O97,@;F]T
M(&5X:7-T+`H@("`@("H@9&5F875L=',@=&\@=&AE(&9I<G-T(&ME>2!O9B!T
M:&4@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R87D@
M("`@("`@5&AE(&%R<F%Y('1O(&)E('-O<G1E9"P@<&%S<V5D(&)Y(')E9F5R
M96YC92X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@(%1H92!K
M97D@8GD@=VAI8V@@=&\@<V]R="X@268@;F]T('-P96-I9FEE9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE;B!T:&4@9FER<W0@:V5Y
M(&ES('5S960N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("!3
M;W)T(&1I<F5C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#`@/2!A<V-E;F1I;F<@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,2`](&1E<V-E;F1I;F<*("`@("`J($!P87)A
M;2!B;V]L96%N("1A<W-O8VEA=&4@($ME97`@:V5Y('9A;'5E(&%S<V]C:6%T
M:6]N/PH@("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>5-O<G0H)B1A<G)A>2P@
M)&ME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P+"`D87-S;V-I871E(#T@=')U
M92D*("`@('L*("`@("`@("`O*B!2971U<FX@:68@=&AE(&%R<F%Y(&ES(&5M
M<'1Y+B`J+PH@("`@("`@(&EF("AE;7!T>2@D87)R87DI*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($EF(&YO(&ME>2!T
M;R!S;W)T(&)Y(&ES('-P96-I9FEE9"P@=7-E('1H92!F:7)S="!K97DN("HO
M"B`@("`@("`@:68@*&ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)&ME
M>7,@/2!A<G)A>5]K97ES*&5A8V@H)&%R<F%Y*2D["B`@("`@("`@("`@("1K
M97D@/2`D:V5Y<ULP73L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T
M:&4@9G5N8W1I;VX@=&AA="!W:6QL(&)E('5S960@=&\@<V]R="!T:&4@:V5Y
M<RX@*B\*("`@("`@("!I9B`H)&1I<F5C=&EO;BD@>PH@("`@("`@("`@("`D
M9G5N8W1I;VX@/2!S<')I;G1F*"=R971U<FX@<W1R8V]L;"A3=')I;F<Z.FQO
M=V5R*"1B6UPG)3$D<UPG72P@=')U92DL(%-T<FEN9SHZ;&]W97(H)&%;7"<E
M,21S7"==+"!T<G5E*2D[)RP@)&ME>2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&9U;F-T:6]N(#T@<W!R:6YT9B@G<F5T=7)N('-T<F-O;&PH
M4W1R:6YG.CIL;W=E<B@D85M<)R4Q)'-<)UTL('1R=64I+"!3=')I;F<Z.FQO
M=V5R*"1B6UPG)3$D<UPG72P@=')U92DI.R<L("1K97DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0V%L;"!T:&4@87!P<F]P<FEA=&4@<V]R="!F=6YC=&EO
M;BX@*B\*("`@("`@("!I9B`H)&%S<V]C:6%T92D@>PH@("`@("`@("`@("!U
M87-O<G0H)&%R<F%Y+"!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L("1F=6YC
M=&EO;BDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5S;W)T*"1A
M<G)A>2P@8W)E871E7V9U;F-T:6]N*"<D82P@)&(G+"`D9G5N8W1I;VXI*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!(5$U,
M('1Y<&4@87)R87D@9FEE;&0@(F5X86UP;&5;:V5Y,5U;:V5Y,EU;:V5Y,UTB
M(&)R96%K<R!U<`H@("`@("H@=&AE(&ME>7,@<V\@=&AA="!T:&5Y(&-O=6QD
M(&)E('5S960@=&\@<F5F97)E;F-E(&$@<F5G=6QA<B!02%`@87)R87DN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@(%1H92!F:65L9"!N
M86UE('1O(&)E(&5X86UI;F5D+@H@("`@("H@0'!A<F%M('-T<FEN9R`F)&)A
M<V4@(%-E="!T;R!T:&4@8F%S92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("8D:V5Y<R`@(%-E="!T;R!T:&4@;&ES="!O9B!K97ES+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-E<W,L(&9A;'-E
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!<G)A>5!A<G1S
M*"1F:65L9"P@)B1B87-E+"`F)&ME>7,I"B`@("!["B`@("`@("`@:68@*'!R
M96=?;6%T8V@H)WPH6UY<6UTJ*2@H7%M;7EQ;7%U=*EQ=*2LI?"<L("1F:65L
M9"P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("1B87-E(#T@)&UA=&-H97-;
M,5T["B`@("`@("`@("`@("1K97ES(#T@97AP;&]D92@G75LG+"`D;6%T8VAE
M<ULR72D["B`@("`@("`@("`@("1K97ES6S!=(#T@<W5B<W1R*"1K97ES6S!=
M+"`Q*3L*("`@("`@("`@("`@)&ME>7-;8V]U;G0H)&ME>7,I("T@,5T@/2!S
M=6)S='(H)&ME>7-;8V]U;G0H)&ME>7,I("T@,5TL(#`L('-T<FQE;B@D:V5Y
M<UMC;W5N="@D:V5Y<RD@+2`Q72D@+2`Q*3L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5S:6YG(&%N
M(&%R<F%Y(&]F(&ME>7,@:71A<F%T92!T:')O=6=H('1H92!A<G)A>2!F;VQL
M;W=I;F<@=&AE"B`@("`@*B!K97ES('1O(&9I;F0@=&AE(&9I;F%L(&ME>2!V
M86QU92X@268@82!V86QU92!I<R!P87-S960@=&AE;B!S970*("`@("`J('1H
M870@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R87D@
M(%1H92!A<G)A>2!T;R!B92!U<V5D+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D
M:V5Y<R`@(%1H92!K97D@<&%T:"!T;R!F;VQL;W<@87,@86X@87)R87DN"B`@
M("`@*B!`<&%R86T@87)R87D@)'9A;'5E("`@268@<V5T('1H92!T87)G970@
M96QE;65N="!W:6QL(&AA=F4@=&AI<R!V86QU92!S970*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T;R!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!4:&4@9FEN86P@=F%L=64@;V8@=&AE(&ME>2!P871H+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971%;&5M96YT*"8D87)R87DL("8D:V5Y<RP@
M)'9A;'5E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)&ME>7,I
M*2!["B`@("`@("`@("`@("1K97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@
M("`@("`@("`@(&EF("AI<W-E="@D87)R87E;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@2&]R9&5?07)R87DZ.F=E=$5L96UE;G0H)&%R<F%Y
M6R1K97E=+"`D:V5Y<RP@)'9A;'5E*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L
M=64I*2!["B`@("`@("`@("`@("`@("`D87)R87D@/2`D=F%L=64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1A<G)A>3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5C=&%N9VQE(&]F
M(&$@='=O+61I;65N<VEO;F%L(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`F)&%R<F%Y("`@(%1H92!A<G)A>2!T;R!E>'1R86-T('1H92!R
M96-T86YG;&4@9G)O;2X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@("`@
M(%1H92!S=&%R="!R;W<@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1C;VP@("`@(%1H92!S=&%R="!C;VQU;6X@;V8@=&AE(')E
M8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H
M96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!E>'1R86-T960@<F5C=&%N9VQE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T4F5C=&%N9VQE*"8D87)R87DL
M("1R;W<L("1C;VPL("1H96EG:'0L("1W:61T:"D*("`@('L*("`@("`@("`D
M<F5C(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1Y(#T@)')O=SL@)'D@/"`D
M<F]W("L@)&AE:6=H=#L@)'DK*RD@>PH@("`@("`@("`@("`D<F5C6UT@/2!A
M<G)A>5]S;&EC92@D87)R87E;)'E=+"`D8V]L+"`D=VED=&@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)')E8SL*("`@('T*"B`@("`O*BH*("`@("`J
M($=I=F5N(&%N(&%R<F%Y+"!R971U<FYS(&%N(&%S<V]C:6%T:79E(&%R<F%Y
M('=I=&@@96%C:"!E;&5M96YT(&ME>0H@("`@("H@9&5R:79E9"!F<F]M(&ET
M<R!V86QU92X*("`@("`J($9O<B!E>&%M<&QE.@H@("`@("H@("!A<G)A>2@P
M(#T^("=F;V\G+"`Q(#T^("=B87(G*0H@("`@("H@=V]U;&0@8F5C;VUE.@H@
M("`@("H@("!A<G)A>2@G9F]O)R`]/B`G9F]O)RP@)V)A<B<@/3X@)V)A<B<I
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A>2`@06X@87)R87D@
M;V8@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R
M<F%Y('=I=&@@:V5Y<R!T:&4@<V%M92!A<R!V86QU97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('9A;'5E<U1O2V5Y<R@D87)R87DI"B`@("!["B`@("`@("`@
M)&UA<'!E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`D;6%P<&5D6R1V86QU95T@/2`D=F%L
M=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;6%P<&5D.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A;B!A<G)A>2!B>2!U<VEN9R!O;F4@
M87)R87D@9F]R(&ME>7,@86YD(&%N;W1H97(@9F]R"B`@("`@*B!I=',@=F%L
M=65S+B!/;FQY(&5X:7-T<R!I;B!02%`U+"!S;R!W92!C86QL(&%R<F%Y7V-O
M;6)I;F4@:68@:70*("`@("`J(&5X:7-T<R!A;F0@;W1H97)W:7-E(&5M=6QA
M=&4@:70N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1K97ES("`@($ME
M>2!A<G)A>2X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("!686QU92!A
M<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&86QS92!I9B!T
M:&5R92!A<F4@;F\@96QE;65N=',L(&]R('1H92!C;VUB:6YE9"!A<G)A>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]M8FEN92@D:V5Y<RP@)'9A;'5E<RD*
M("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=A<G)A>5]C;VUB
M:6YE)RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7V-O;6)I;F4H)&ME
M>7,L("1V86QU97,I.PH@("`@("`@('T*"B`@("`@("`@)'-I>F4@/2!C;W5N
M="@D:V5Y<RD["B`@("`@("`@:68@*"@D<VEZ92`A/2!C;W5N="@D=F%L=65S
M*2D@?'P@*"1S:7IE(#T](#`I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)'@@/2`P.R`D>"`\("1S:7IE
M.R`D>"LK*2!["B`@("`@("`@("`@("1A<G)A>5LD:V5Y<ULD>%U=(#T@)'9A
M;'5E<ULD>%T["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D87)R87D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]4;VME;BYP:'``````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S4P,2`Q,#4Q-30S-#$T,"`P
M,C$Q,S``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J(%1H
M92!(;W)D95]4;VME;CHZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R
M86-T960@:6YT97)F86-E(&EN=&\@=&AE"B`J('9A<FEO=7,@=&]K96X@9V5N
M97)A=&EO;B!M961I=6US+B!)="!A;'-O(&EN8VQU9&5S(&%L;"!O9B!T:&4*
M("H@9G5N8W1I;VYS(&9O<B!R971R:65V:6YG+"!S=&]R:6YG+"!A;F0@8VAE
M8VMI;F<@=&]K96YS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4;VME;B]4
M;VME;BYP:'`L=B`Q+C,S+C8N."`R,#`V+S`T+S$Y(#(Q.C$T.C`U(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA
M>$!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E
M("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U1O:V5N"B`J+PIC;&%S
M<R!(;W)D95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(87-H(&]F('!A<F%M
M971E<G,@;F5C97-S87)Y('1O('5S92!T:&4@8VAO<V5N(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A
M;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7U1O:V5N*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@?0H*("`@(&9U
M;F-T:6]N(&5N8V]D95)E;6]T94%D9')E<W,H*0H@("`@>PH@("`@("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG4D5-3U1%7T%$1%(G72DI('L*("`@("`@("`@
M("`@<F5T=7)N(&)A<V4V-%]E;F-O9&4H)%]315)615);)U)%34]415]!1$12
M)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@82!C
M;VYN96-T:6]N(&ED(&%N9"!R971U<FYS(&ET+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'-E960@($$@=6YI<75E($E$('1O(&)E(&EN8VQU9&5D
M(&EN('1H92!T;VME;BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&EF
M(&ET(&YE961S('1O(&)E(&UO<F4@=6YI<75E('1H86X@=&EM92`H:6X@<V5C
M;VYD<RD*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&%N9"!T:&4@<F5M
M;W1E($E0+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&=E
M;F5R871E9"!I9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E;F5R
M871E260H)'-E960@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@;60U*'1I
M;64H*2`N("==6R<@+B`D<V5E9"`N("==6R<@+B!(;W)D95]4;VME;CHZ96YC
M;V1E4F5M;W1E061D<F5S<R@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!I9B!T:&4@9VEV96X@=&]K96X@:&%S(&)E96X@<')E=FEO=7-L>2!U
M<V5D+B!&:7)S=`H@("`@("H@<'5R9V5S(&%L;"!E>'!I<F5D('1O:V5N<RX@
M5&AE;B!R971R:65V97,@8W5R<F5N="!T;VME;G,@9F]R"B`@("`@*B!T:&4@
M9VEV96X@:7`@861D<F5S<RX@268@=&AE('-P96-I9FEE9"!T;VME;B!W87,@
M;F]T(&9O=6YD+`H@("`@("H@861D<R!I="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T;VME;B`@5&AE('9A;'5E(&]F('1H92!T;VME;B!T;R!C
M:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@("`@("`@5')U
M92!I9B!T:&4@=&]K96X@:&%S(&YO="!B965N('5S960L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!V97)I9GDH)'1O:V5N*0H@("`@>PH@("`@("`@("1T:&ES
M+3YP=7)G92@I.PH@("`@("`@("1E>&ES=',@/2`D=&AI<RT^97AI<W1S*"1T
M;VME;BD["B`@("`@("`@:68@*&ES7V$H)&5X:7-T<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5X:7-T<SL*("`@("`@("!](&5L
M<V5I9B`H)&5X:7-T<RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YA9&0H
M)'1O:V5N*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&ES(&%N(&%B<W1R86-T(&UE=&AO9"!T:&%T('-H;W5L9"!B92!O=F5R<FED
M9&5N(&)Y(&$*("`@("`J('-U8F-L87-S(&EM<&QE;65N=&%T:6]N+B!4:&4@
M8F%S92!I;7!L96UE;G1A=&EO;B!A;&QO=W,@86QL"B`@("`@*B!T;VME;B!V
M86QU97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI
M<R!I<R!A;B!A8G-T<F%C="!M971H;V0@=&AA="!S:&]U;&0@8F4@;W9E<G)I
M9&1E;B!B>2!A"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;BX@5&AE
M(&)A<V4@:6UP;&5M96YT871I;VX@86QL;W=S(&%L;`H@("`@("H@=&]K96X@
M=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H*0H@("`@>PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!I
M<R!A;B!A8G-T<F%C="!M971H;V0@=&AA="!S:&]U;&0@8F4@;W9E<G)I9&1E
M;B!B>2!A"B`@("`@*B!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;BX@5&AE(&)A
M<V4@:6UP;&5M96YT871I;VX@86QL;W=S(&%L;`H@("`@("H@=&]K96X@=F%L
M=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!P=7)G92@I"B`@("!["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T
M<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]4;VME;B!I;G-T86YC92!B
M87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D
M9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]4;VME;B!S=6)C
M;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@
M268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]4
M;VME;B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E<G,@82!S=6)C
M;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?
M5&]K96X@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($AO<F1E7U1O:V5N
M(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@9F%L
M<V4@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D
M<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI
M<U]A<G)A>2@D9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1A<'`L("1D
M<FEV97(I(#T@)&1R:79E<CL*("`@("`@("!]"@H@("`@("`@("1D<FEV97(@
M/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*"%E;7!T>2@D87!P
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)&%P<"`N("<O;&EB+U1O
M:V5N+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`
M9FEL95]E>&ES=',H9&ER;F%M92A?7T9)3$5?7RD@+B`G+U1O:V5N+R<@+B`D
M9')I=F5R("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP
M:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E7V]N
M8V4@)TAO<F1E+U1O:V5N+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@
M('T*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7U1O:V5N7R<@+B`D9')I=F5R
M.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@
M("`@("`D=&]K96X@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&]K96X@/2`F;F5W($AO<F1E7U1O:V5N
M*"1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T;VME;CL*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E
M9F5R96YC92!T;R!A(&-O;F-R971E($AO<F1E7U1O:V5N(&EN<W1A;F-E(&)A
M<V5D"B`@("`@*B!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($ET('=I;&P@
M;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@2&]R9&5?5&]K96X@
M:6YS=&%N8V4@=VET:"!T:&4*("`@("`J('-A;64@<&%R86UE=&5R<R!C=7)R
M96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S
M960@:68@;75L=&EP;&4@='EP97,@;V8@=&]K96X@9V5N97)A=&]R<R`H86YD
M+"!T:'5S+`H@("`@("H@;75L=&EP;&4@2&]R9&5?5&]K96X@:6YS=&%N8V5S
M*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S
M="!B92!I;G9O:V5D(&%S.@H@("`@("H@/&-O9&4^)'9A<B`]("9(;W)D95]4
M;VME;CHZ<VEN9VQE=&]N*"D[/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]4
M;VME;B!S=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL
M(&QO;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R
M6S!=+VQI8B]4;VME;B\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);
M,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!C;VYN96-T:6]N('!A<F%M971E
M<G,@82!S=6)C;&%S<R!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U
M<FX@2&]R9&5?5&]K96X@(%1H92!C;VYC<F5T92!(;W)D95]4;VME;B!R969E
M<F5N8V4L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I
M=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@
M)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97,I*2![
M"B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I.PH@("`@("`@('T*
M"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D9')I=F5R
M+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)DAO<F1E7U1O:V5N.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA
M='5R95T["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+TEM86=E+G!H<```````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,U,S<T(#$P-3$U-#,T,30P(#`R,3$P
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]5=&EL+G!H<"<["@HO*BH*("H@
M5&AI<R!C;&%S<R!D969I;F5S('1H92!(;W)D95]);6%G93HZ($%022P@86YD
M(&%L<V\@<')O=FED97,@<V]M90H@*B!U=&EL:71Y(&9U;F-T:6]N<RP@<W5C
M:"!A<R!G96YE<F%T:6YG(&AI9VAL:6=H=',@;V8@82!C;VQO<BX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO26UA9V4O26UA9V4N<&AP+'8@,2XS.2XQ,"XQ
M,R`R,#`V+S`Q+S`Q(#(Q.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]);6%G90H@*B\*8VQA<W,@2&]R9&5?26UA9V4@>PH*
M("`@("\J*@H@("`@("H@0W5R<F5N="!C;VQO<BX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]R9V(@/2`G9F8P,#`P)SL*
M"B`@("`O*BH*("`@("`J($)A8VMG<F]U;F0@8V]L;W(N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F%C:V=R;W5N9"`]
M("=W:&ET92<["@H@("`@+RHJ"B`@("`@*B!/8G-E<G9E<G,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O8G-E<G9E<G,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%P86)I;&ET97,@;V8@=&AI
M<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@5&AE(&-U<G)E;G0@:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D871A(#T@)R<["@H@("`@+RHJ
M"B`@("`@*B!4:&4@8W5R<F5N="!I;6%G92!I9"X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I9"`]("<G.PH*("`@("\J
M*@H@("`@("H@5&AE(&-U<G)E;G0@=VED=&@@;V8@=&AE(&EM86=E(&1A=&$N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7W=I9'1H(#T@,#L*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&AE:6=H
M="!O9B!T:&4@:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J+PH@("`@=F%R("1?:&5I9VAT(#T@,#L*"B`@("`O*BH*("`@
M("`J($$@9&ER96-T;W)Y(&9O<B!T96UP;W)A<GD@9FEL97,N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&UP9&ER.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<F=B("!4:&4@8F%S92!C;VQO<B!F;W(@9V5N97)A=&5D
M('!I>&5L<R]I;6%G97,N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM
M86=E*"1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/E]T;7!D:7(@/2`D
M<&%R86US6R=T96UP)UT["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)W=I
M9'1H)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?=VED=&@@/2`D<&%R86US
M6R=W:61T:"==.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'!A<F%M
M<ULG:&5I9VAT)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:&5I9VAT(#T@
M)'!A<F%M<ULG:&5I9VAT)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP
M='DH)'!A<F%M<ULG<F=B)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F=B
M(#T@)'!A<F%M<ULG<F=B)UT["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?
M8F%C:V=R;W5N9"`](&ES<V5T*"1P87)A;7-;)V)A8VMG<F]U;F0G72D@/R`D
M<&%R86US6R=B86-K9W)O=6YD)UT@.B`G=VAI=&4G.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&=E=$-A<&%B:6QI=&EE<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V%P86)I;&ET:65S.PH@("`@?0H*("`@(&9U;F-T:6]N(&AA
M<T-A<&%B:6QI='DH)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<F5T=7)N
M(&EN7V%R<F%Y*"1C87!A8FEL:71Y+"`D=&AI<RT^7V-A<&%B:6QI=&EE<RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T3&EN:R@D=7)L+"`D=&ET;&4@/2`G
M)RD*("`@('L*("`@("`@("!R971U<FX@2&]R9&4Z.FEM9R@D=7)L+"`D=&ET
M;&4L("<G+"`G)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!I
M;6%G92!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!H96%D97)S*"D*
M("`@('L*("`@("`@("!H96%D97(H)T-O;G1E;G0M='EP93H@)R`N("1T:&ES
M+3YG971#;VYT96YT5'EP92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A
M;&-U;&%T92!A(&QI9VAT97(@*&]R(&1A<FME<BD@=F5R<VEO;B!O9B!A(&-O
M;&]R+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;VQO<B`@($%N($A434P@8V]L;W(L(&4N9RXZ("-F9F9F
M8V,N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F86-T;W(@(%1/1$\*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!M;V1I9FEE9"!(5$U,(&-O;&]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE#;VQO<B@D8V]L;W(L("1F
M86-T;W(@/2`P>#$Q*0H@("`@>PH@("`@("`@("1R(#T@:&5X9&5C*'-U8G-T
M<B@D8V]L;W(L(#$L(#(I*2`K("1F86-T;W(["B`@("`@("`@)&<@/2!H97AD
M96,H<W5B<W1R*"1C;VQO<BP@,RP@,BDI("L@)&9A8W1O<CL*("`@("`@("`D
M8B`](&AE>&1E8RAS=6)S='(H)&-O;&]R+"`U+"`R*2D@*R`D9F%C=&]R.PH*
M("`@("`@("`D<B`](&UI;BAM87@H)'(L(#`I+"`R-34I.PH@("`@("`@("1G
M(#T@;6EN*&UA>"@D9RP@,"DL(#(U-2D["B`@("`@("`@)&(@/2!M:6XH;6%X
M*"1B+"`P*2P@,C4U*3L*"B`@("`@("`@<F5T=7)N("<C)R`N('-T<E]P860H
M9&5C:&5X*"1R*2P@,BP@)S`G+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD
M96-H97@H)&<I+"`R+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?<&%D*&1E
M8VAE>"@D8BDL(#(L("<P)RP@4U127U!!1%],1494*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-A;&-U;&%T92!A(&UO<F4@:6YT96YS92!V97)S:6]N(&]F
M(&$@8V]L;W(N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&-O;&]R("`@06X@2%1-3"!C;VQO<BP@92YG+CH@
M(V9F9F9C8RX*("`@("`J($!P87)A;2!S=')I;F<@)&9A8W1O<B`@5$]$3PH@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&UO<F4@:6YT96YS92!(
M5$U,(&-O;&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W)E26YT96YS94-O
M;&]R*"1C;VQO<BP@)&9A8W1O<B`](#!X,3$I"B`@("!["B`@("`@("`@)'(@
M/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@,2P@,BDI.PH@("`@("`@("1G(#T@
M:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#,L(#(I*3L*("`@("`@("`D8B`](&AE
M>&1E8RAS=6)S='(H)&-O;&]R+"`U+"`R*2D["@H@("`@("`@(&EF("@D<B`^
M/2`D9R`F)B`D<B`^/2`D8BD@>PH@("`@("`@("`@("`D9R`]("1G("\@)'([
M"B`@("`@("`@("`@("1B(#T@)&(@+R`D<CL*"B`@("`@("`@("`@("1R("L]
M("1F86-T;W(["B`@("`@("`@("`@("1G(#T@9FQO;W(H)&<@*B`D<BD["B`@
M("`@("`@("`@("1B(#T@9FQO;W(H)&(@*B`D<BD["B`@("`@("`@?2!E;'-E
M:68@*"1G(#X]("1R("8F("1G(#X]("1B*2!["B`@("`@("`@("`@("1R(#T@
M)'(@+R`D9SL*("`@("`@("`@("`@)&(@/2`D8B`O("1G.PH*("`@("`@("`@
M("`@)&<@*ST@)&9A8W1O<CL*("`@("`@("`@("`@)'(@/2!F;&]O<B@D<B`J
M("1G*3L*("`@("`@("`@("`@)&(@/2!F;&]O<B@D8B`J("1G*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<B`]("1R("\@)&(["B`@("`@("`@
M("`@("1G(#T@)&<@+R`D8CL*"B`@("`@("`@("`@("1B("L]("1F86-T;W([
M"B`@("`@("`@("`@("1R(#T@9FQO;W(H)'(@*B`D8BD["B`@("`@("`@("`@
M("1G(#T@9FQO;W(H)&<@*B`D8BD["B`@("`@("`@?0H*("`@("`@("`D<B`]
M(&UI;BAM87@H)'(L(#`I+"`R-34I.PH@("`@("`@("1G(#T@;6EN*&UA>"@D
M9RP@,"DL(#(U-2D["B`@("`@("`@)&(@/2!M:6XH;6%X*"1B+"`P*2P@,C4U
M*3L*"B`@("`@("`@<F5T=7)N("<C)R`N('-T<E]P860H9&5C:&5X*"1R*2P@
M,BP@)S`G+"!35%)?4$%$7TQ%1E0I("X@<W1R7W!A9"AD96-H97@H)&<I+"`R
M+"`G,"<L(%-44E]0041?3$5&5"D@+B!S=')?<&%D*&1E8VAE>"@D8BDL(#(L
M("<P)RP@4U127U!!1%],1494*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&)R:6=H=&YE<W,@;V8@82!C;VQO<BX*("`@("`J"B`@("`@
M*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@
M($%N($A434P@8V]L;W(L(&4N9RXZ("-F9F9F8V,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@8G)I9VAT;F5S<R!O;B!A('-C86QE(&]F
M(#`@=&\@,C4U+@H@("`@("HO"B`@("!F=6YC=&EO;B!B<FEG:'1N97-S*"1C
M;VQO<BD*("`@('L*("`@("`@("`D<B`](&AE>&1E8RAS=6)S='(H)&-O;&]R
M+"`Q+"`R*2D["B`@("`@("`@)&<@/2!H97AD96,H<W5B<W1R*"1C;VQO<BP@
M,RP@,BDI.PH@("`@("`@("1B(#T@:&5X9&5C*'-U8G-T<B@D8V]L;W(L(#4L
M(#(I*3L*"B`@("`@("`@<F5T=7)N(')O=6YD*"@H)'(@*B`R.3DI("L@*"1G
M("H@-3@W*2`K("@D8B`J(#$Q-"DI("\@,3`P,"D["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T4D="*"1C;VQO<FYA;64I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]);6%G92]R9V(N<&AP)SL*
M("`@("`@("!R971U<FX@:7-S970H)$=,3T)!3%-;)VAO<F1E7VEM86=E7W)G
M8E]C;VQO<G,G75LD8V]L;W)N86UE72D@/PH@("`@("`@("`@("`D1TQ/0D%,
M4ULG:&]R9&5?:6UA9V5?<F=B7V-O;&]R<R==6R1C;VQO<FYA;65=(#H*("`@
M("`@("`@("`@87)R87DH,"P@,"P@,"D["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T2&5X0V]L;W(H)&-O;&]R;F%M92D*("`@('L*("`@("`@("!R97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TEM86=E+W)G8BYP:'`G.PH@
M("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG:&]R9&5?:6UA9V5?<F=B7V-O
M;&]R<R==6R1C;VQO<FYA;65=*2D@>PH@("`@("`@("`@("!L:7-T*"1R+"`D
M9RP@)&(I(#T@)$=,3T)!3%-;)VAO<F1E7VEM86=E7W)G8E]C;VQO<G,G75LD
M8V]L;W)N86UE73L*("`@("`@("`@("`@<F5T=7)N("<C)R`N('-T<E]P860H
M9&5C:&5X*&UI;B@D<BP@,C4U*2DL(#(L("<P)RP@4U127U!!1%],1494*2`N
M('-T<E]P860H9&5C:&5X*&UI;B@D9RP@,C4U*2DL(#(L("<P)RP@4U127U!!
M1%],1494*2`N('-T<E]P860H9&5C:&5X*&UI;B@D8BP@,C4U*2DL(#(L("<P
M)RP@4U127U!!1%],1494*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)V)L86-K)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$<F%W(&$@<VAA<&5D('!O:6YT(&%T('1H92!S<&5C:69I960@*'@L
M>2D@<&]I;G0N(%5S969U;"!F;W(*("`@("`J('-C871T97(@9&EA9W)A;7,L
M(&1E8G5G('!O:6YT<RP@971C+B!$<F%W<R!S<75A<F5S+"!C:7)C;&5S+`H@
M("`@("H@9&EA;6]N9',L(&%N9"!T<FEA;F=L97,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'@@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE
M('!O:6YT('1O(&)R=7-H+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@
M(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE('!O:6YT('1O(&)R=7-H+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@(%1H92!C;VQO<B!T;R!B<G5S:"!T
M:&4@<&]I;G0@=VET:"X*("`@("`J($!P87)A;2!S=')I;F<@)'-H87!E("!7
M:&%T(&)R=7-H('1O('5S93\@1&5F875L=',@=&\@82!S<75A<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&)R=7-H*"1X+"`D>2P@)&-O;&]R(#T@)V)L86-K
M)RP@)'-H87!E(#T@)W-Q=6%R92<I"B`@("!["B`@("`@("`@<W=I=&-H("@D
M<VAA<&4I('L*("`@("`@("!C87-E("=T<FEA;F=L92<Z"B`@("`@("`@("`@
M("1V97)T<ULP72`](&%R<F%Y*"=X)R`]/B`D>"`K(#,L("=Y)R`]/B`D>2`K
M(#,I.PH@("`@("`@("`@("`D=F5R='-;,5T@/2!A<G)A>2@G>"<@/3X@)'@L
M("=Y)R`]/B`D>2`M(#,I.PH@("`@("`@("`@("`D=F5R='-;,ET@/2!A<G)A
M>2@G>"<@/3X@)'@@+2`S+"`G>2<@/3X@)'D@*R`S*3L*("`@("`@("`@("`@
M)'1H:7,M/G!O;'EG;VXH)'9E<G1S+"`D8V]L;W(L("1C;VQO<BD["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=C:7)C;&4G.@H@("`@("`@
M("`@("`D=&AI<RT^8VER8VQE*"1X+"`D>2P@,RP@)&-O;&]R+"`D8V]L;W(I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G9&EA;6]N9"<Z
M"B`@("`@("`@("`@("1V97)T<ULP72`](&%R<F%Y*"=X)R`]/B`D>"`M(#,L
M("=Y)R`]/B`D>2D["B`@("`@("`@("`@("1V97)T<ULQ72`](&%R<F%Y*"=X
M)R`]/B`D>"P@)WDG(#T^("1Y("L@,RD["B`@("`@("`@("`@("1V97)T<ULR
M72`](&%R<F%Y*"=X)R`]/B`D>"`K(#,L("=Y)R`]/B`D>2D["B`@("`@("`@
M("`@("1V97)T<ULS72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y("T@
M,RD["B`@("`@("`@("`@("1T:&ES+3YP;VQY9V]N*"1V97)T<RP@)&-O;&]R
M+"`D8V]L;W(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G
M<W%U87)E)SH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI<RT^
M<F5C=&%N9VQE*"1X("T@,BP@)'D@+2`R+"`T+"`T+"`D8V]L;W(L("1C;VQO
M<BD["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9"!A;B!O8G-E<G9E<B!T;R!T:&ES(&EM86=E+B!4:&4@
M;V)S97)V97(@=VEL;"!B92!N;W1I9FEE9`H@("`@("H@=VAE;B!T:&4@:6UA
M9V4G<R!C:&%N9V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1/8G-E<G9E
M<B@D;65T:&]D+"`F)&]B:F5C="D*("`@('L*("`@("`@("`D=&AI<RT^7V]B
M<V5R=F5R<UM=(#T@87)R87DH)&UE=&AO9"P@)B1O8FIE8W0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3&5T(&]B<V5R=F5R<R!K;F]W('1H870@<V]M971H
M:6YG(&AA<'!E;F5D('=O<G1H(&%C=&EN9R!O;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F]T:69Y3V)S97)V97)S*"D*("`@('L*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7V]B<V5R=F5R<RD[("LK)&DI('L*
M("`@("`@("`@("`@)&]B:B`]("8D=&AI<RT^7V]B<V5R=F5R<ULD:5U;,5T[
M"B`@("`@("`@("`@("1M971H;V0@/2`D=&AI<RT^7V]B<V5R=F5R<ULD:5U;
M,%T["B`@("`@("`@("`@("1O8FHM/B1M971H;V0H)'1H:7,I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G92!D871A
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]D871A(#T@)R<["B`@("`@("`@)'1H:7,M/E]I9"`]("<G.PH@
M("`@("`@("1T:&ES+3Y?=VED=&@@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?
M:&5I9VAT(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7V)A8VMG<F]U;F0@/2`G
M=VAI=&4G.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!H96EG:'0@
M86YD('=I9'1H(&]F('1H92!C=7)R96YT(&EM86=E(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@06X@:&%S:"!W:71H("=W:61T:"<@8V]N
M=&%I;FEN9R!T:&4@=VED=&@L"B`@("`@*B`@("`@("`@("`@("`@("`G:&5I
M9VAT)R!C;VYT86EN:6YG('1H92!H96EG:'0@;V8@=&AE(&EM86=E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971$:6UE;G-I;VYS*"D*("`@('L*("`@("`@
M("`D=&UP(#T@)'1H:7,M/G1O1FEL92@I.PH@("`@("`@("1D971A:6QS(#T@
M0&=E=&EM86=E<VEZ92@D=&UP*3L*("`@("`@("!U;FQI;FLH)'1M<"D["@H@
M("`@("`@(')E='5R;B!A<G)A>2@G=VED=&@G(#T^("1D971A:6QS6S!=+`H@
M("`@("`@("`@("`@("`@("`@("`G:&5I9VAT)R`]/B`D9&5T86EL<ULQ72D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D('1H92!I;6%G92!D871A(&9R
M;VT@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@
M("`@("`@("`@06X@87)B:71R87)Y(&ED(&9O<B!T:&4@:6UA9V4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I;6%G95]D871A("!4:&4@9&%T82!T;R!U<V4@
M9F]R('1H92!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&]A9%-T<FEN
M9R@D:60L("1I;6%G95]D871A*0H@("`@>PH@("`@("`@(&EF("@D:60@(3T@
M)'1H:7,M/E]I9"D@>PH@("`@("`@("`@("`D=&AI<RT^<F5S970H*3L*("`@
M("`@("`@("`@)'1H:7,M/E]D871A(#T@)&EM86=E7V1A=&$["B`@("`@("`@
M("`@("1T:&ES+3Y?:60@/2`D:60["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@3&]A9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@9FEL92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&9U;&P@
M<&%T:"!A;F0@9FEL96YA;64@=&\@=&AE(&9I;&4@=&\@;&]A9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('1H92!I;6%G92!D871A(&9R;VTN
M(%1H92!F:6QE;F%M92!W:6QL(&%L<V\@8F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!U<V5D(&9O<B!T:&4@:6UA9V4@:60N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@4$5!4B!%<G)O<B!I9B!F:6QE(&1O97,@
M;F]T(&5X:7-T(&]R(&-O=6QD(&YO="!B92!L;V%D960*("`@("`J("`@("`@
M("`@("`@("`@(&]T:&5R=VES92!.54Q,(&EF('-U8V-E<W-F=6P@;W(@86QR
M96%D>2!L;V%D960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO861&:6QE*"1F
M:6QE;F%M92D*("`@('L*("`@("`@("!I9B`H)&9I;&5N86UE("$]("1T:&ES
M+3Y?:60I('L*("`@("`@("`@("`@)'1H:7,M/G)E<V5T*"D["B`@("`@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U1H92!I;6%G92!F:6QE
M("<@+B`D:6UA9V4@+B`G(&1O97,@;F]T(&5X:7-T+B<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1A=&$@/2!F:6QE7V=E=%]C
M;VYT96YT<R@D9FEL96YA;64I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VED(#T@)&9I;&5N86UE.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO="!L
M;V%D('1H92!I;6%G92!F:6QE("<@+B`D:6UA9V4I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('1O1FEL92@D9&%T82`]
M(&9A;'-E*0H@("`@>PH@("`@("`@("1T;7`@/2!5=&EL.CIG971496UP1FEL
M92@G:6UG)RP@9F%L<V4L("1T:&ES+3Y?=&UP9&ER*3L*("`@("`@("`D9G`@
M/2!`9F]P96XH)'1M<"P@)W=B)RD["B`@("`@("`@9G=R:71E*"1F<"P@)&1A
M=&$@/R`D9&%T82`Z("1T:&ES+3YR87<H*2D["B`@("`@("`@9F-L;W-E*"1F
M<"D["B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$:7-P;&%Y('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@("`D=&AI<RT^:&5A9&5R<R@I
M.PH@("`@("`@(&5C:&\@)'1H:7,M/G)A=R@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@<F%W(&1A=&$@9F]R('1H:7,@:6UA9V4N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-O;G9E<G0@($EF('1R=64L
M('1H92!I;6%G92!D871A('=I;&P@8F4@<F5T=7)N960@:6X@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@=&%R9V5T(&9O<FUA="P@:6YD
M97!E;F1E;G1L>2!F<F]M(&%N>2!I;6%G90H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]P97)A=&EO;G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R87<@:6UA9V4@9&%T82X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F%W*"1C;VYV97)T(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M;B!X+'D@<&%I<B!O;B!C:7)C;&4L(&%S<W5M:6YG(&-E;G1E<B!I<R`P+#`N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&1O=6)L92`D9&5G<F5E<R`@("!4:&4@9&5G<F5E<R!O9B!A<F,@
M=&\@9V5T('1H92!P;VEN="!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M9&EA;65T97(@(%1H92!D:6%M971E<B!O9B!T:&4@8VER8VQE+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@("AX(&-O;W)D:6YA=&4L('D@8V]O<F1I
M;F%T92D@;V8@=&AE('!O:6YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VER
M8VQE4&]I;G0H)&1E9W)E97,L("1D:6%M971E<BD*("`@('L*("`@("`@("`O
M+R!!=F]I9"!P<F]B;&5M<R!W:71H(&1O=6)L97,N"B`@("`@("`@)&1E9W)E
M97,@*ST@,"XP,#`Q.PH*("`@("`@("!R971U<FX@87)R87DH8V]S*&1E9S)R
M860H)&1E9W)E97,I*2`J("@D9&EA;65T97(@+R`R*2P*("`@("`@("`@("`@
M("`@("`@("`@<VEN*&1E9S)R860H)&1E9W)E97,I*2`J("@D9&EA;65T97(@
M+R`R*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@<&]I;G0@8V]O<F1I
M;F%T97,@870@=&AE(&QI;6ET<R!O9B!A;B!A<F,N($]N;'D@=F%L:60@9F]R
M"B`@("`@*B!A;F=L97,@*"1E;F0@+2`D<W1A<G0I(#P](#0U(&1E9W)E97,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R=&EN9R!A
M;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1E;F0@("`@5&AE(&5N9&EN
M9R!A;F=L92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<W1A
M<G0@<&]I;G0L(&5N9"!P;VEN="P@86YD(&%N8VAO<B!P;VEN="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%R8U!O:6YT<R@D<BP@)'-T87)T+"`D96YD*0H@
M("`@>PH@("`@("`@("\O(%-T87)T('!O:6YT+@H@("`@("`@("1P='-;)W@Q
M)UT@/2`D<B`J(&-O<RAD96<R<F%D*"1S=&%R="DI.PH@("`@("`@("1P='-;
M)WDQ)UT@/2`D<B`J('-I;BAD96<R<F%D*"1S=&%R="DI.PH*("`@("`@("`O
M+R!%;F0@<&]I;G0N"B`@("`@("`@)'!T<ULG>#(G72`]("1R("H@8V]S*&1E
M9S)R860H)&5N9"DI.PH@("`@("`@("1P='-;)WDR)UT@/2`D<B`J('-I;BAD
M96<R<F%D*"1E;F0I*3L*"B`@("`@("`@+R\@06YC:&]R('!O:6YT+@H@("`@
M("`@("1A,R`]("@D<W1A<G0@*R`D96YD*2`O(#(["B`@("`@("`@)'(S(#T@
M)'(@+R!C;W,H9&5G,G)A9"@H)&5N9"`M("1S=&%R="D@+R`R*2D["B`@("`@
M("`@)'!T<ULG>#,G72`]("1R,R`J(&-O<RAD96<R<F%D*"1A,RDI.PH@("`@
M("`@("1P='-;)WDS)UT@/2`D<C,@*B!S:6XH9&5G,G)A9"@D83,I*3L*"B`@
M("`@("`@<F5T=7)N("1P=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D95]);6%G92!I;G-T86YC
M92!B87-E9"!O;B`D9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D9')I=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]);6%G92!S
M=6)C;&%S<R!T;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;BX@5&AI<R!I<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`H)&1R:79E<BDN(%1H92!C;V1E(&ES
M(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L
M;V]K(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP
M72]L:6(O26UA9V4O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=
M+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7TEM86=E?&)O;VQE86X@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R
M971E($AO<F1E7TEM86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EN<W1A;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1D<FEV97(I*2![
M"B`@("`@("`@("`@(&QI<W0H)&%P<"P@)&1R:79E<BD@/2`D9')I=F5R.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G
M9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+TEM86=E+R<@+B`D9')I=F5R("X@
M)RYP:'`G.PH@("`@("`@('T@96QS96EF("A`9FEL95]E>&ES=',H9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+TEM86=E+R<@+B`D9')I=F5R("X@)RYP:'`G*2D@
M>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+TEM86=E+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+TEM86=E+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("`D8VQA<W,@
M/2`G2&]R9&5?26UA9V5?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1I;6%G92`]("9N97<@
M)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1I;6%G92`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@
M;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;6%G93L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E($AO
M<F1E7TEM86=E(&EN<W1A;F-E(&)A<V5D"B`@("`@*B!O;B`D9')I=F5R+B!)
M="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO($AO<F1E
M7TEM86=E"B`@("`@*B!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M971E
M<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L
M9"!B92!U<V5D(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&EM86=E(')E;F1E<F5R
M<R`H86YD+"!T:'5S+`H@("`@("H@;75L=&EP;&4@2&]R9&5?26UA9V4@:6YS
M=&%N8V5S*2!A<F4@<F5Q=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H
M;V0@;75S="!B92!I;G9O:V5D(&%S.B`D=F%R(#T@)DAO<F1E7TEM86=E.CIS
M:6YG;&5T;VXH*0H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R
M("!4:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]);6%G92!S=6)C;&%S<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@5&AI<R!I
M<R!B87-E9"!O;B!T:&4@<W1O<F%G92!D<FEV97(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`H)&1R:79E<BDN(%1H92!C;V1E(&ES(&1Y;F%M:6-A
M;&QY(&EN8VQU9&5D+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L;V]K(&EN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@)&1R:79E<ELP72]L:6(O26UA
M9V4O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=+G!H<"X*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!A
M;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S(&$@<W5B8VQA
M<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7TEM
M86=E?&)O;VQE86X@(%1H92!C;VYC<F5T92!(;W)D95]);6%G92!R969E<F5N
M8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A
M;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1D<FEV97(L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF("@A:7-S970H)&EN<W1A
M;F-E<RDI('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@
M("`@("`@?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y
M*"1D<FEV97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T
M86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;
M)'-I9VYA='5R95T@/2`F2&]R9&5?26UA9V4Z.F9A8W1O<GDH)&1R:79E<BP@
M)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O:4-A;&5N9&%R+G!H<```````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`Q,S`U,#0@,3`U,34T,S0Q-#`@,#(Q-S,U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!`
M<&%C:V%G92!(;W)D95]I0V%L96YD87(*("HO"@HO*BH*("H@4W1R:6YG('!A
M8VMA9V4*("HO"FEN8VQU9&5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO
M*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG(&E#86QE;F1A<B!F:6QE<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<BYP:'`L
M=B`Q+C4W+C0N,S0@,C`P-B\P."\P-2`Q,SHT,SHT-R!K87)S=&5N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD
M87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<B!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@<&%R96YT("AC;VYT86EN:6YG*2!I0V%L96YD87(@;V)J96-T+@H@
M("`@("H*("`@("`J($!V87(@2&]R9&5?:4-A;&5N9&%R"B`@("`@*B\*("`@
M('9A<B`D7V-O;G1A:6YE<B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5&AE
M(&YA;64O=F%L=64@<&%I<G,@;V8@871T<FEB=71E<R!F;W(@=&AI<R!O8FIE
M8W0@*%5)1"P*("`@("`J($144U1!4E0L(&5T8RXI+B!7:&EC:"!A<F4@<')E
M<V5N="!D97!E;F1S(&]N('1H92!O8FIE8W0@86YD(&]N"B`@("`@*B!W:&%T
M(&MI;F0@;V8@8V]M<&]N96YT(&ET(&ES+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?871T<FEB=71E<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!!;GD@8VAI;&1R96X@*&-O;G1A:6YE9"D@:4-A
M;&5N9&%R(&-O;7!O;F5N=',@;V8@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C;VUP;VYE;G1S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($%C8V]R9&EN9R!T;R!21D,@,C0R
M-2P@=V4@<VAO=6QD(&%L=V%Y<R!U<V4@0U),1BUT97)M:6YA=&5D(&QI;F5S
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7VYE=VQI;F4@/2`B7')<;B(["@H@("`@+RHJ"B`@("`@*B!I0V%L96YD87(@
M9F]R;6%T('9E<G-I;VX@*&1I9F9E<F5N="!B96AA=FEO<B!F;W(@,2XP(&%N
M9"`R+C`*("`@("`J(&5S<&5C:6%L;'D@=VET:"!R96-U<G)I;F<@979E;G1S
M*2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]V97)S:6]N.PH*("`@(&9U;F-T:6]N($AO<F1E7VE#86QE;F1A<B@D=F5R
M<VEO;B`]("<R+C`G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F5R<VEO;B`]
M("1V97)S:6]N.PH@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)U9%4E-)
M3TXG+"`D=F5R<VEO;BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M82!R969E<F5N8V4@=&\@82!N97<@8V]M<&]N96YT+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("`@("`@("`@)'1Y<&4@("`@("`@5&AE('1Y<&4@
M;V8@8V]M<&]N96YT('1O(')E='5R;@H@("`@("H@0'!A<F%M($AO<F1E7VE#
M86QE;F1A<B`D8V]N=&%I;F5R("!!(&-O;G1A:6YE<B!T:&%T('1H:7,@8V]M
M<&]N96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('=I;&P@8F4@87-S;V-I871E9"!W:71H+@H@("`@("H*("`@("`J($!R
M971U<FX@;V)J96-T("!2969E<F5N8V4@=&\@82!(;W)D95]I0V%L96YD87)?
M*B!O8FIE8W0@87,@<W!E8VEF:65D+@H@("`@("H*("`@("`J($!S=&%T:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=T-O;7!O;F5N="@D='EP92P@)B1C
M;VYT86EN97(I"B`@("!["B`@("`@("`@)'1Y<&4@/2!3=')I;F<Z.FQO=V5R
M*"1T>7!E*3L*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?:4-A;&5N9&%R7R<@
M+B`D='EP93L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I*2![
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R9&4O:4-A;&5N9&%R+R<@
M+B`D='EP92`N("<N<&AP)SL*("`@("`@("!]"B`@("`@("`@:68@*&-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1C;VUP;VYE;G0@/2!N
M97<@)&-L87-S*"D["B`@("`@("`@("`@(&EF("@D8V]N=&%I;F5R("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@)&-O;7!O;F5N="T^7V-O;G1A:6YE
M<B`]("8D8V]N=&%I;F5R.PH@("`@("`@("`@("`@("`@+R\@57-E('9E<G-I
M;VX@;V8@8V]N=&%I;F5R+"!N;W0@9&5F875L="!S970@8GD@8V]M<&]N96YT
M"B`@("`@("`@("`@("`@("`O+R!C;VYS=')U8W1O<BX*("`@("`@("`@("`@
M("`@("1C;VUP;VYE;G0M/E]V97)S:6]N(#T@)&-O;G1A:6YE<BT^7W9E<G-I
M;VX["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!3:&]U;&0@<F5T=7)N(&%N(&1U;6UY('@M=6YK;F]W;B!T>7!E(&-L
M87-S(&AE<F4N"B`@("`@("`@("`@("1C;VUP;VYE;G0@/2!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D8V]M<&]N96YT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!T:&4@=F%L=64@;V8@86X@871T<FEB=71E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@(%1H92!N86UE
M(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU
M92`@("!4:&4@=F%L=64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@($%R<F%Y(&-O;G1A:6YI;F<@86YY(&%D9&ET
M:6]N('!A<F%M971E<G,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&ES(&%T=')I8G5T92X*("`@("`J($!P87)A;2!B;V]L96%N("1A
M<'!E;F0@(%1R=64@=&\@87!P96YD('1H92!A='1R:6)U=&4L($9A;'-E('1O
M(')E<&QA8V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F
M:7)S="!M871C:&EN9R!A='1R:6)U=&4@9F]U;F0N"B`@("`@*B!`<&%R86T@
M87)R87D@)'9A;'5E<R`@("!!<G)A>2!R97!R97-E;G1A=&EO;B!O9B`D=F%L
M=64N("!&;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-O;6UA
M+W-E;6EC;VQO;B!S97!E<F%T960@;&ES=',@;V8@=F%L=65S+B`@268*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&YO="!S970@=7-E("1V86QU
M92!A<R!S:6YG;&4@87)R87D@96QE;65N="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T071T<FEB=71E*"1N86UE+"`D=F%L=64L("1P87)A;7,@/2!A<G)A
M>2@I+"`D87!P96YD(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F%L=65S(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@36%K92!S=7)E
M('=E('5P9&%T92!T:&4@:6YT97)N86P@9F]R;6%T('9E<G-I;VX@:68*("`@
M("`@("`O+R!S971!='1R:6)U=&4H)U9%4E-)3TXG+"`N+BXI(&ES(&-A;&QE
M9"X*("`@("`@("!I9B`H)&YA;64@/3T@)U9%4E-)3TXG*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?=F5R<VEO;B`]("1V86QU93L*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?8V]N=&%I;F5R("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C;VYT86EN97(M/E]V97)S:6]N(#T@)'9A;'5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21V86QU97,I('L*
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1V86QU92D["B`@("`@("`@
M?0H@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@(&EF("@A)&%P<&5N
M9"D@>PH@("`@("`@("`@("`D:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]A
M='1R:6)U=&5S*3L*("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME
M>2D@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?871T<FEB=71E<ULD
M:V5Y75LG;F%M92==(#T](%-T<FEN9SHZ=7!P97(H)&YA;64I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1K97E=6R=P87)A
M;7,G72`]("1P87)A;7,["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M='1R:6)U=&5S6R1K97E=6R=V86QU92==(#T@)'9A;'5E.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG=F%L=65S)UT@
M/2`D=F%L=65S.PH@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D87!P96YD
M('Q\("$D9F]U;F0I('L*("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S
M6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=N86UE)R`@("`@(#T^(%-T
M<FEN9SHZ=7!P97(H)&YA;64I+`H@("`@("`@("`@("`@("`@)W!A<F%M<R<@
M("`@/3X@)'!A<F%M<RP*("`@("`@("`@("`@("`@("=V86QU92<@("`@(#T^
M("1V86QU92P*("`@("`@("`@("`@("`@("=V86QU97,G("`@(#T^("1V86QU
M97,*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('!A<F%M971E<BAS*2!F;W(@86X@*&%L<F5A9'D@97AI<W1I
M;F<I(&%T=')I8G5T92X@(%1H90H@("`@("H@<&%R86UE=&5R('-E="!I<R!M
M97)G960@:6YT;R!T:&4@97AI<W1I;F<@<V5T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%R<F%Y(&-O;G1A:6YI
M;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!F;W(*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!T:&ES(&%T=')I8G5T92X*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!I9B!N;R!A='1R
M:6)U=&4@)&YA;64@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9710
M87)A;65T97(H)&YA;64L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("1K97ES(#T@87)R87E?:V5Y<R@D=&AI<RT^7V%T=')I8G5T97,I.PH@
M("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y75LG;F%M92==(#T]("1N86UE
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;
M)W!A<F%M<R==(#T*("`@("`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D
M=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W!A<F%M<R==+"`D<&%R86US*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@=&AE('9A;'5E(&]F(&%N(&%T=')I8G5T92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@;F%M92!O9B!T
M:&4@871T<FEB=71E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!A<F%M<R`@
M4F5T=7)N('1H92!P87)A;65T97)S(&9O<B!T:&ES(&%T=')I8G5T92!I;G-T
M96%D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!O9B!I=',@=F%L
M=64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`H;V)J96-T*2`@4$5!
M4E]%<G)O<B!I9B!T:&4@871T<FEB=71E(&1O97,@;F]T(&5X:7-T+@H@("`@
M("H@("`@("`@("`@("`@("`H<W1R:6YG*2`@5&AE('9A;'5E(&]F('1H92!A
M='1R:6)U=&4N"B`@("`@*B`@("`@("`@("`@("`@("AA<G)A>2D@("!4:&4@
M<&%R86UE=&5R<R!F;W(@=&AE(&%T=')I8G5T92!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@;75L=&EP;&4@=F%L=65S(&9O<B!A;B!A='1R
M:6)U=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T92@D;F%M
M92P@)'!A<F%M<R`](&9A;'-E*0H@("`@>PH@("`@("`@("1R97-U;'0@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A
M<R`D871T<FEB=71E*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N
M86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(&EF("@D<&%R86US
M*2!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L=%M=(#T@)&%T=')I8G5T
M95LG<&%R86US)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-U;'1;72`]("1A='1R:6)U=&5;)W9A;'5E)UT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@:68@*"%C;W5N="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T%T=')I8G5T92`B)R`N("1N86UE("X@)R(@3F]T($9O
M=6YD)RD["B`@("`@("`@?2!I9B`H8V]U;G0H)')E<W5L="D@/3T@,2`F)B`A
M)'!A<F%M<RD@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=%LP73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!V86QU97,@
M;V8@86X@871T<FEB=71E(&%S(&%N(&%R<F%Y+B`@375L=&EP;&4@=F%L=65S
M"B`@("`@*B!A<F4@<&]S<VEB;&4@9'5E('1O.@H@("`@("H*("`@("`J("!A
M*2!M=6QT:7!L8V4@;V-C=7)E;F-E<R!O9B`G;F%M92<*("`@("`J("!B*2`H
M=6YS96-A<&0I(&-O;6UA('-E<&5R871E9"!L:7-T<RX*("`@("`J"B`@("`@
M*B!3;R!F;W(@82!V8V%R9"!L:6ME(")+15DZ82QB7&Y+15DZ8R(@9V5T071T
M<FEB=71E<U9A;'5E<R@G2T59)RD*("`@("`J('=I;&P@<F5T=7)N(&%R<F%Y
M*"=A)RPG8B<L)V,G*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M;F%M92`@("!4:&4@;F%M92!O9B!T:&4@871T<FEB=71E+@H@("`@("H@0')E
M='5R;B!M:7AE9"`H;V)J96-T*2`@4$5!4E]%<G)O<B!I9B!T:&4@871T<FEB
M=71E(&1O97,@;F]T(&5X:7-T+@H@("`@("H@("`@("`@("`@("`@("`H87)R
M87DI("`@375L=&EP;&4@=F%L=65S(&9O<B!A;B!A='1R:6)U=&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T959A;'5E<R@D;F%M92D*("`@
M('L*("`@("`@("`D<F5S=6QT(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@("`@
M("`@("!I9B`H)&%T=')I8G5T95LG;F%M92==(#T]("1N86UE*2!["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@87)R87E?;65R9V4H)&%T=')I8G5T95LG
M=F%L=65S)UTL("1R97-U;'0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("@A8V]U;G0H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)T%T=')I8G5T92`B)R`N("1N86UE("X@
M)R(@3F]T($9O=6YD)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@
M;V8@86X@871T<FEB=71E+"!O<B!A('-P96-I9FEE9"!D969A=6QT('9A;'5E
M"B`@("`@*B!I9B!T:&4@871T<FEB=71E(&1O97,@;F]T(&5X:7-T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@5&AE(&YA;64@;V8@
M=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A;2!M:7AE9"`D9&5F875L="`@
M5VAA="!T;R!R971U<FX@:68@=&AE(&%T=')I8G5T92!S<&5C:69I960@8GD*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@9&]E<R!N;W0@
M97AI<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`H<W1R:6YG*2!4
M:&4@=F%L=64@;V8@)&YA;64N"B`@("`@*B`@("`@("`@("`@("`@("AM:7AE
M9"D@("1D969A=6QT(&EF("1N86UE(&1O97,@;F]T(&5X:7-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5$969A=6QT*"1N86UE+"`D9&5F
M875L="`]("<G*0H@("`@>PH@("`@("`@("1V86QU92`]("1T:&ES+3YG971!
M='1R:6)U=&4H)&YA;64I.PH@("`@("`@(')E='5R;B!I<U]A*"1V86QU92P@
M)U!%05)?17)R;W(G*2`_("1D969A=6QT(#H@)'9A;'5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5M;W9E(&%L;"!O8V-U<F5N8V5S(&]F(&%N(&%T=')I
M8G5T92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@
M;F%M92!O9B!T:&4@871T<FEB=71E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96UO=F5!='1R:6)U=&4H)&YA;64I"B`@("!["B`@("`@("`@)&ME>7,@/2!A
M<G)A>5]K97ES*"1T:&ES+3Y?871T<FEB=71E<RD["B`@("`@("`@9F]R96%C
M:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]A
M='1R:6)U=&5S6R1K97E=6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y72D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M871T<FEB=71E<R!F;W(@86QL('1A9W,@;W(@9F]R(&$@9VEV96X@=&%G+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A9R`@4F5T=7)N(&%T=')I
M8G5T97,@9F]R('1H:7,@=&%G+"!O<B!A;&P@871T<FEB=71E<R!I9@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!N;W0@9VEV96XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@8V]N=&%I;FEN9R!A;&P@=&AE
M(&%T=')I8G5T97,@86YD('1H96ER('1Y<&5S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971!;&Q!='1R:6)U=&5S*"1T86<@/2!F86QS92D*("`@('L*("`@
M("`@("!I9B`H)'1A9R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?871T<FEB=71E<SL*("`@("`@("!]"B`@("`@("`@)')E<W5L
M="`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U
M=&5S(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@:68@*"1A='1R:6)U
M=&5;)VYA;64G72`]/2`D=&%G*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT
M6UT@/2`D871T<FEB=71E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&$@=D-A;&5N9&%R(&-O;7!O;F5N="`H96<@=D5V96YT+"!V5&EM97IO;F4L
M(&5T8RXI+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]I0V%L96YD87(@
M)&-O;7!O;F5N="`@0V]M<&]N96YT("AS=6)C;&%S<RD@=&\@861D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&1#;VUP;VYE;G0H)&-O;7!O;F5N="D*("`@
M('L*("`@("`@("!I9B`H:7-?82@D8V]M<&]N96YT+"`G2&]R9&5?:4-A;&5N
M9&%R)RDI('L*("`@("`@("`@("`@)&-O;7!O;F5N="T^7V-O;G1A:6YE<B`]
M("8D=&AI<SL*("`@("`@("`@("`@)'1H:7,M/E]C;VUP;VYE;G1S6UT@/2`F
M)&-O;7!O;F5N=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V92!A;&P@=&AE(&-O;7!O;F5N=',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@07)R87D@;V8@2&]R9&5?:4-A;&5N9&%R(&]B:F5C=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;7!O;F5N=',H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V-O;7!O;F5N=',["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=V8V%L
M96YD87(G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C;&%S
M<V5S("AE;G1R>2!T>7!E<RD@=V4@:&%V92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!(87-H('=I=&@@8VQA<W,@;F%M97,@2&]R9&5?:4-A;&5N
M9&%R7WAX>"!A<R!K97ES"B`@("`@*B`@("`@("`@("`@("`@("!A;F0@;G5M
M8F5R(&]F(&-O;7!O;F5N=',@;V8@=&AI<R!C;&%S<R!A<R!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T0V]M<&]N96YT0VQA<W-E<R@I"B`@("![
M"B`@("`@("`@)'(@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?8V]M<&]N96YT<R!A<R`D8RD@>PH@("`@("`@("`@("`D8VX@/2!S=')T
M;VQO=V5R*&=E=%]C;&%S<R@D8RDI.PH@("`@("`@("`@("!I9B`H96UP='DH
M)');)&-N72DI('L*("`@("`@("`@("`@("`@("1R6R1C;ET@/2`Q.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)');)&-N72LK.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@8V]M<&]N96YT<R!I;B!T
M:&ES(&-O;G1A:6YE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M($YU;6)E<B!O9B!C;VUP;VYE;G1S(&EN('1H:7,@8V]N=&%I;F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#;VUP;VYE;G1#;W5N="@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&-O=6YT*"1T:&ES+3Y?8V]M<&]N96YT<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971R:65V92!A('-P96-I9FEC(&-O;7!O;F5N
M="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61X("!4:&4@:6YD
M97@@;V8@=&AE(&]B:F5C="!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("`@("AB;V]L96%N*2!&86QS92!I9B!T:&4@:6YD97@@
M9&]E<R!N;W0@97AI<W0N"B`@("`@*B`@("`@("`@("`@("`@("`@("A(;W)D
M95]I0V%L96YD87)?*BD@5&AE(')E<75E<W1E9"!C;VUP;VYE;G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-O;7!O;F5N="@D:61X*0H@("`@>PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7V-O;7!O;F5N='-;)&ED>%TI*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;7!O;F5N='-;)&ED>%T["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QO8V%T97,@=&AE(&9I<G-T
M(&-H:6QD(&-O;7!O;F5N="!O9B!T:&4@<W!E8VEF:65D(&-L87-S+"!A;F0*
M("`@("`J(')E='5R;G,@82!R969E<F5N8V4@=&\@=&AI<R!C;VUP;VYE;G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@5&AE('1Y<&4@
M;V8@8V]M<&]N96YT('1O(&9I;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`H8F]O;&5A;BD@1F%L<V4@:68@;F\@<W5B8V]M<&]N96YT(&]F('1H
M92!S<&5C:69I960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-L
M87-S(&5X:7-T<RX*("`@("`J("`@("`@("`@("`@("`@*$AO<F1E7VE#86QE
M;F1A<E\J*2!!(')E9F5R96YC92!T;R!T:&4@<F5Q=65S=&5D(&-O;7!O;F5N
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F9I;F1#;VUP;VYE;G0H)&-H:6QD
M8VQA<W,I"B`@("!["B`@("`@("`@)&-H:6QD8VQA<W,@/2`G2&]R9&5?:4-A
M;&5N9&%R7R<@+B!3=')I;F<Z.FQO=V5R*"1C:&EL9&-L87-S*3L*("`@("`@
M("`D:V5Y<R`](&%R<F%Y7VME>7,H)'1H:7,M/E]C;VUP;VYE;G1S*3L*("`@
M("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@(&EF
M("AI<U]A*"1T:&ES+3Y?8V]M<&]N96YT<ULD:V5Y72P@)&-H:6QD8VQA<W,I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VUP;VYE;G1S
M6R1K97E=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@=&AE(&E#
M86QE;F1A<B!O8FIE8W0@*')E<V5T<R!T:&4@8V]M<&]N96YT<R!A;F0@871T
M<FEB=71E<PH@("`@("H@87)R87ES*2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8VQE87(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]M<&]N96YT<R`](&%R
M<F%Y*"D["B`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S(#T@87)R87DH*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!I9B!E;G1R>2!I<R!V8V%L
M96YD87(@,2XP+"!V8V%R9"`R+C$@;W(@=FYO=&4@,2XQ+@H@("`@("H*("`@
M("`J(%1H97-E("=O;&0G(&9O<FUA=',@87)E(&1E9FEN960@8GD@=W=W+FEM
M8RYO<F<N(%1H92`G;F5W)R`H;F]N+6]L9"D*("`@("`J(&9O<FUA=',@:6-A
M;&5N9&%R(#(N,"!A;F0@=F-A<F0@,RXP(&%R92!D969I;F5D(&EN(')F8S(T
M,C8@86YD(')F8S(T-#4*("`@("`J(')E<W!E8W1I=F5L>2X*("`@("`J"B`@
M("`@*B!`<VEN8V4@2&]R9&4@,RXQ+C(*("`@("`J+PH@("`@9G5N8W1I;VX@
M:7-/;&1&;W)M870H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;G1A
M:6YE<B`A/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8V]N=&%I;F5R+3YI<T]L9$9O<FUA="@I.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F=E=%1Y<&4H*2`]/2`G=F-A<F0G*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W9E<G-I;VX@/"`S(#\@=')U92`Z(&9A;'-E.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F=E=%1Y<&4H*2`]/2`G=DYO
M=&4G*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9E<G-I;VX@/"`R
M(#\@=')U92`Z(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/E]V97)S:6]N(#X](#(I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($5X<&]R="!A<R!V0V%L96YD87(@9F]R;6%T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@("\O
M($1E9F%U;'0@=F%L=65S+@H@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;
M)U!23T1)1"==(#T@)RTO+U1H92!(;W)D92!0<F]J96-T+R](;W)D95]I0V%L
M96YD87(@3&EB<F%R>2<@+B`H9&5F:6YE9"@G2$]21$5?5D524TE/3B<I(#\@
M)RP@2&]R9&4@)R`N(&-O;G-T86YT*"=(3U)$15]615)324].)RD@.B`G)RD@
M+B`G+R]%3B<["B`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG34542$]$
M)UT@/2`G4%5"3$E32"<["@H@("`@("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T
M=')I8G5T97,@87,@)&YA;64@/3X@)&1E9F%U;'1?=F%L=64I('L*("`@("`@
M("`@("`@:68@*&ES7V$H)'1H:7,M/F=E=&%T=')I8G5T92@D;F%M92DL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R
M:6)U=&4H)&YA;64L("1D969A=6QT7W9A;'5E*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H
M)U9#04Q%3D1!4B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T('1H
M:7,@96YT<GD@87,@82!H87-H(&%R<F%Y('=I=&@@=&%G(&YA;65S(&%S(&ME
M>7,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!A<F%M<TEN2V5Y
M<PH@("`@("H@("`@("`@("`@("`@("`@268@9F%L<V4L('1H92!O<&5R871I
M;VX@8V%N(&)E('%U:71E(&QO<W-Y(&%S('1H90H@("`@("H@("`@("`@("`@
M("`@("`@<&%R86UE=&5R<R!A<F4@:6=N;W)E9"!W:&5N(&)U:6QD:6YG('1H
M92!A<G)A>2!K97ES+@H@("`@("H@("`@("`@("`@("`@("`@4V\@:68@>6]U
M(&5X<&]R="!A('9C87)D('=I=&@*("`@("`J("`@("`@("`@("`@("`@($Q!
M0D5,.U194$4]5T]22SIF;V\*("`@("`J("`@("`@("`@("`@("`@($Q!0D5,
M.U194$4]2$]-13IB87(*("`@("`J("`@("`@("`@("`@("`@('1H92!R97-U
M;'1I;F<@:&%S:"!C;VYT86EN<R!O;FQY(&]N92!L86)E;"!F:65L9"$*("`@
M("`J("`@("`@("`@("`@("`@($EF('-E="!T;R!T<G5E+"!A<G)A>2!K97ES
M(&QO;VL@;&EK92`G3$%"14P[5%E013U73U)+)PH@("`@("H@0')E='5R;B!A
M<G)A>2`@02!H87-H(&%R<F%Y('=I=&@@=&%G(&YA;65S(&%S(&ME>7,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O2&%S:"@D<&%R86US26Y+97ES(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)&AA<V@@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D82D@('L*("`@("`@("`@
M("`@)&L@/2`D85LG;F%M92==.PH@("`@("`@("`@("!I9B`H)'!A<F%M<TEN
M2V5Y<R`F)B!I<U]A<G)A>2@D85LG<&%R86US)UTI*2!["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D85LG<&%R86US)UT@87,@)'`@/3X@)'8I('L*("`@
M("`@("`@("`@("`@("`@("`D:R`N/2`B.R1P/21V(CL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:&%S:%LD:UT@/2`D
M85LG=F%L=64G73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:&%S:#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A('-T<FEN9R!C;VYT86EN
M:6YG('9#86QE;F1A<B!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("`@(%1H92!D871A('1O('!A<G-E+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8F%S92`@("`@5&AE('1Y<&4@;V8@=&AE(&)A<V4@;V)J96-T
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&5N8V]D:6YG
M(&-H87)S970@9F]R("1T97AT+B!$969A=6QT<R!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@=71F+3@N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D8VQE87(@("!)9B!T<G5E(&-L96%R<R!T:&4@:4-A;"!O8FIE8W0@8F5F
M;W)E('!A<G-I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W-F=6P@:6UP;W)T+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1T97AT+"`D8F%S
M92`]("=60T%,14Y$05(G+"`D8VAA<G-E="`]("=U=&8M."<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8VQE87(@/2!T<G5E*0H@("`@>PH@("`@
M("`@(&EF("@D8VQE87(I('L*("`@("`@("`@("`@)'1H:7,M/F-L96%R*"D[
M"B`@("`@("`@?0H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*$)%1TE..B<@
M+B`D8F%S92`N("=<<C]<;C\I*%M<5UQW72HI*$5.1#HG("X@)&)A<V4@+B`G
M7'(_7&X_*2]I)RP@)'1E>'0L("1M871C:&5S*2D@>PH@("`@("`@("`@("`D
M=D-A;"`]("1M871C:&5S6S)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O(%1E>'0@:7-N)W0@96YC;&]S960@:6X@0D5'24XZ5D-!3$5.1$%2
M"B`@("`@("`@("`@("\O("XN($5.1#I60T%,14Y$05(N(%=E)VQL('1R>2!T
M;R!P87)S92!I="!A;GEW87DN"B`@("`@("`@("`@("1V0V%L(#T@)'1E>'0[
M"B`@("`@("`@?0H*("`@("`@("`O+R!!;&P@<W5B8V]M<&]N96YT<RX*("`@
M("`@("`D;6%T8VAE<R`](&YU;&P["B`@("`@("`@:68@*'!R96=?;6%T8VA?
M86QL*"<O0D5'24XZ*%M<5UQW72HI*%QR7&Y\7')\7&XI*%M<5UQW72HI14Y$
M.EPQ*%QR7&Y\7')\7&XI+U5I)RP@)'9#86PL("1M871C:&5S*2D@>PH@("`@
M("`@("`@("!F;W)E86-H("@D;6%T8VAE<ULP72!A<R`D:V5Y(#T^("1D871A
M*2!["B`@("`@("`@("`@("`@("`D='EP92`]('1R:6TH)&UA=&-H97-;,5U;
M)&ME>5TI.PH@("`@("`@("`@("`@("`@)&-O;7!O;F5N="`]("9(;W)D95]I
M0V%L96YD87(Z.FYE=T-O;7!O;F5N="@D='EP92P@)'1H:7,I.PH@("`@("`@
M("`@("`@("`@:68@*"1C;VUP;VYE;G0@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T
M;R!C<F5A=&4@;V)J96-T(&9O<B!T>7!E("1T>7!E(BD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D8V]M<&]N96YT+3YP87)S979#86QE
M;F1A<B@D9&%T82D["@H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$-O;7!O
M;F5N="@D8V]M<&]N96YT*3L*"B`@("`@("`@("`@("`@("`O+R!296UO=F4@
M9G)O;2!T:&4@=D-A;&5N9&%R(&1A=&$N"B`@("`@("`@("`@("`@("`D=D-A
M;"`]('-T<E]R97!L86-E*"1D871A+"`G)RP@)'9#86PI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!5;F9O;&0@86YY(&9O;&1E9"!L
M:6YE<RX*("`@("`@("`D=D-A;"`]('!R96=?<F5P;&%C92@G+UM<<EQN72M;
M(%QT72\G+"`G)RP@)'9#86PI.PH*("`@("`@("`O+R!5;F9O;&0@(G%U;W1E
M9"!P<FEN=&%B;&4B(&9O;&1E9"!L:6YE<R!L:6ME.@H@("`@("`@("\O("!"
M3T19.T5.0T]$24Y'/5%53U1%1"U04DE.5$%"3$4Z/0H@("`@("`@("\O("!A
M;F]T:&5R/3(P;&EN93T*("`@("`@("`O+R`@;&%S=#TR,&QI;F4*("`@("`@
M("!W:&EL92`H<')E9U]M871C:%]A;&PH)R]>*%M>.ETK.UQS*D5.0T]$24Y'
M/5%53U1%1"U04DE.5$%"3$4H+BH]7'(_7&XI*R@N*EM>/5TI/UQR/UQN*2]M
M52<L("1V0V%L+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)&UA=&-H97-;,5T@87,@)',I('L*("`@("`@("`@("`@("`@("1R(#T@<')E
M9U]R97!L86-E*"<O/5QR/UQN+R<L("<G+"`D<RD["B`@("`@("`@("`@("`@
M("`D=D-A;"`]('-T<E]R97!L86-E*"1S+"`D<BP@)'9#86PI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!087)S92!T:&4@<F5M86EN
M:6YG(&%T=')I8G5T97,N"B`@("`@("`@:68@*'!R96=?;6%T8VA?86QL*"<O
M*"XJ*3HH6UY<<EQN72HI6UQR7&Y=*R\G+"`D=D-A;"P@)&UA=&-H97,I*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1M871C:&5S6S!=(&%S("1A='1R:6)U
M=&4I('L*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R\H6UX[7CI=*BDH
M*#M;7CI=*BD_*3HH6UY<<EQN72HI6UQR7&Y=*B\G+"`D871T<FEB=71E+"`D
M<&%R=',I.PH@("`@("`@("`@("`@("`@)'1A9R`](%-T<FEN9SHZ=7!P97(H
M)'!A<G1S6S%=*3L*("`@("`@("`@("`@("`@("1V86QU92`]("1P87)T<ULT
M73L*("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PH*("`@("`@
M("`@("`@("`@("\O(%!A<G-E('!A<F%M971E<G,N"B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1P87)T<ULR72DI('L*("`@("`@("`@("`@("`@("`@
M("!P<F5G7VUA=&-H7V%L;"@G+SLH*%M>.SU=*BDH/2A;7CM=*BDI/RDO)RP@
M)'!A<G1S6S)=+"`D<&%R86U?<&%R=',I.PH@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1P87)A;5]P87)T<ULR72!A<R`D:V5Y(#T^("1P87)A;4YA
M;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M5F%L=64@/2`D
M<&%R86U?<&%R='-;-%U;)&ME>5T["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7-;4W1R:6YG.CIU<'!E<B@D<&%R86U.86UE*5T@/2`D<&%R86U6
M86QU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@+R\@0VAA<G-E="!A;F0@96YC;V1I;F<@:&%N
M9&QI;F<N"B`@("`@("`@("`@("`@("!I9B`H*&ES<V5T*"1P87)A;7-;)T5.
M0T]$24Y')UTI"B`@("`@("`@("`@("`@("`@("`@("8F(%-T<FEN9SHZ=7!P
M97(H)'!A<F%M<ULG14Y#3T1)3D<G72D@/3T@)U%53U1%1"U04DE.5$%"3$4G
M*0H@("`@("`@("`@("`@("`@("`@('Q\(&ES<V5T*"1P87)A;7-;)U%53U1%
M1"U04DE.5$%"3$4G72DI('L*"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@<75O=&5D7W!R:6YT86)L95]D96-O9&4H)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("`O+R!1=6]T960@<')I;G1A8FQE(&ES(&YO<FUA;&QY(&5N
M8V]D960@87,@=71F+3@N"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1P87)A;7-;)T-(05)3150G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1P
M87)A;7-;)T-(05)3150G72D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="@D=F%L=64L("=U=&8M."<I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D<&%R
M86US6R=#2$%24T54)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1P87)A;7-;)T-(
M05)3150G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("\O($%S('!E<B!21D,@,C(W.2P@87-S=6UE(%541C@@:68@
M=V4@9&]N)W0@:&%V92!A;@H@("`@("`@("`@("`@("`@("`@("\O(&5X<&QI
M8VET(&-H87)S970@<&%R86UE=&5R+@H@("`@("`@("`@("`@("`@("`@("1V
M86QU92`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;'5E+"`D8VAA<G-E
M="D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@<W=I=&-H
M("@D=&%G*2!["B`@("`@("`@("`@("`@("`O+R!$871E(&9I96QD<RX*("`@
M("`@("`@("`@("`@(&-A<V4@)T-/35!,151%1"<Z"B`@("`@("`@("`@("`@
M("!C87-E("=#4D5!5$5$)SH*("`@("`@("`@("`@("`@(&-A<V4@)TQ!4U0M
M34]$249)140G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R
M:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&54:6UE*"1V86QU92DL("1P
M87)A;7,I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&-A<V4@)T)$05DG.@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941A=&4H)'9A;'5E
M*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`G1%1%3D0G.@H@("`@("`@("`@("`@("`@8V%S
M92`G1%135$%25"<Z"B`@("`@("`@("`@("`@("!C87-E("=$5%-404U0)SH*
M("`@("`@("`@("`@("`@(&-A<V4@)T1512<Z"B`@("`@("`@("`@("`@("!C
M87-E("=!04Q!4DTG.@H@("`@("`@("`@("`@("`@8V%S92`G4D5#55)214Y#
M12U)1"<Z"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;
M)U9!3%5%)UTI("8F("1P87)A;7-;)U9!3%5%)UT@/3T@)T1!5$4G*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A
M9RP@)'1H:7,M/E]P87)S941A=&4H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$%T=')I8G5T92@D=&%G+"`D=&AI<RT^7W!A<G-E1&%T
M951I;64H)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)U1224='15(G.@H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%R86US6R=604Q512==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G1$%412U424U%)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D
M=&%G+"`D=&AI<RT^7W!A<G-E1&%T951I;64H)'9A;'5E*2P@)'!A<F%M<RD[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"1T86<L("1T
M:&ES+3Y?<&%R<V5$=7)A=&EO;B@D=F%L=64I+"`D<&%R86US*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U
M=&4H)'1A9RP@)'1H:7,M/E]P87)S941U<F%T:6]N*"1V86QU92DL("1P87)A
M;7,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!#;VUM82!S97!E<F%T960@
M9&%T97,N"B`@("`@("`@("`@("`@("!C87-E("=%6$1!5$4G.@H@("`@("`@
M("`@("`@("`@8V%S92`G4D1!5$4G.@H@("`@("`@("`@("`@("`@("`@("1D
M871E<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@<')E9U]M871C
M:%]A;&PH)R\L*%M>+%TJ*2\G+"`G+"<@+B`D=F%L=64L("1V86QU97,I.PH*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=65S6S%=(&%S("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;72`]("1T
M:&ES+3Y?<&%R<V5$871E*"1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A
M9RP@:7-S970H)&1A=&5S6S!=*2`_("1D871E<ULP72`Z(&YU;&PL("1P87)A
M;7,L('1R=64L("1D871E<RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("`@("`@+R\@1'5R871I;VX@9FEE;&1S+@H@("`@("`@
M("`@("`@("`@8V%S92`G1%52051)3TXG.@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@)'1H:7,M/E]P87)S941U<F%T
M:6]N*"1V86QU92DL("1P87)A;7,I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@("\O(%!E<FEO9"!O9B!T:6UE(&9I96QD
M<RX*("`@("`@("`@("`@("`@(&-A<V4@)T92145"55-9)SH*("`@("`@("`@
M("`@("`@("`@("`D<&5R:6]D<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@<')E9U]M871C:%]A;&PH)R\L*%M>+%TJ*2\G+"`G+"<@+B`D=F%L
M=64L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V
M86QU97-;,5T@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P97)I;V1S6UT@/2`D=&AI<RT^7W!A<G-E4&5R:6]D*"1V86QU92D["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"1T86<L(&ES<V5T*"1P97)I;V1S6S!=*2`_("1P
M97)I;V1S6S!=(#H@;G5L;"P@)'!A<F%M<RP@=')U92P@)'!E<FEO9',I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O
M(%540R!O9F9S970@9FEE;&1S+@H@("`@("`@("`@("`@("`@8V%S92`G5%I/
M1D93151&4D]-)SH*("`@("`@("`@("`@("`@(&-A<V4@)U1:3T9&4T545$\G
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A
M9RP@)'1H:7,M/E]P87)S955T8T]F9G-E="@D=F%L=64I+"`D<&%R86US*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O
M+R!);G1E9V5R(&9I96QD<RX*("`@("`@("`@("`@("`@(&-A<V4@)U!%4D-%
M3E0M0T]-4$Q%5$4G.@H@("`@("`@("`@("`@("`@8V%S92`G4%))3U))5%DG
M.@H@("`@("`@("`@("`@("`@8V%S92`G4D5014%4)SH*("`@("`@("`@("`@
M("`@(&-A<V4@)U-%455%3D-%)SH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T071T<FEB=71E*"1T86<L(&EN='9A;"@D=F%L=64I+"`D<&%R86US
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`O+R!'96\@9FEE;&1S+@H@("`@("`@("`@("`@("`@8V%S92`G1T5/)SH*
M("`@("`@("`@("`@("`@("`@("`D9FQO871S(#T@97AP;&]D92@G.R<L("1V
M86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=L871I='5D92==
M(#T@9FQO871V86PH)&9L;V%T<ULP72D["B`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E6R=L;VYG:71U9&4G72`](&9L;V%T=F%L*"1F;&]A='-;,5TI.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@
M)'9A;'5E+"`D<&%R86US*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("`O+R!296-U<G-I;VX@9FEE;&1S+@H@("`@("`@
M("`@("`@("`@8V%S92`G15A254Q%)SH*("`@("`@("`@("`@("`@(&-A<V4@
M)U)254Q%)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB
M=71E*"1T86<L('1R:6TH)'9A;'5E*2P@)'!A<F%M<RD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@+R\@0412+"!A;F0@
M3B!A<F4@;&ES=',@<V5P97)A=&5D(&)Y('5N97-C87!E9`H@("`@("`@("`@
M("`@("`@+R\@<V5M:6-O;&]N<R!W:71H(&$@<W!E8VEF:6,@;G5M8F5R(&]F
M('-L;W1S+@H@("`@("`@("`@("`@("`@8V%S92`G0412)SH*("`@("`@("`@
M("`@("`@(&-A<V4@)TXG.@H@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M('1R:6TH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`O+R!!<R!O9B!R
M9F,@,C0R-B`R+C0N,B!S96UI8V]L;VXL(&-O;6UA+"!A;F0*("`@("`@("`@
M("`@("`@("`@("`O+R!C;VQO;B!M=7-T(&)E(&5S8V%P960@*&-O;6UA(&ES
M('5N97-C87!E9"!A9G1E<@H@("`@("`@("`@("`@("`@("`@("\O('-P;&ET
M=&EN9R!B96QO=RDN"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R
M7W)E<&QA8V4H87)R87DH)UQ<;B<L("=<7#LG+"`G7%PZ)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M
M/E]N97=L:6YE+"`G.R<L("<Z)RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*"B`@("`@("`@("`@("`@("`@
M("`@+R\@4W!L:70@8GD@=6YE<V-A<&5D('-E;6EC;VQO;G,Z"B`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<R`]('!R96=?<W!L:70H)R\H/SPA7%Q<7"D[
M+R<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W1R
M7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("`@("`D=F%L=65S(#T@<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E
M<RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D
M=&%G+"!T<FEM*"1V86QU92DL("1P87)A;7,L('1R=64L("1V86QU97,I.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("\O
M($]21R!I<R!A(&QI<W0@<V5P97)A=&5D(&)Y('5N97-C87!E9"!S96UI8V]L
M;VYS(&)U=`H@("`@("`@("`@("`@("`@+R\@=VET:"!N;R!E;7!T>2!V86QU
M97,N"B`@("`@("`@("`@("`@("!C87-E("=/4D<G.@H@("`@("`@("`@("`@
M("`@("`@("1V86QU92`]('1R:6TH)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("`@("`O+R!!<R!O9B!R9F,@,C0R-B`R+C0N,B!S96UI8V]L;VXL(&-O;6UA
M+"!A;F0*("`@("`@("`@("`@("`@("`@("`O+R!C;VQO;B!M=7-T(&)E(&5S
M8V%P960@*&-O;6UA(&ES('5N97-C87!E9"!A9G1E<@H@("`@("`@("`@("`@
M("`@("`@("\O('-P;&ET=&EN9R!B96QO=RDN"B`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H87)R87DH)UQ<;B<L("=<7#LG+"`G
M7%PZ)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)'1H:7,M/E]N97=L:6YE+"`G.R<L("<Z)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*"B`@
M("`@("`@("`@("`@("`@("`@+R\@4W!L:70@8GD@=6YE<V-A<&5D('-E;6EC
M;VQO;G,Z"B`@("`@("`@("`@("`@("`@("`@)'9A;'5E<R`]('!R96=?<W!L
M:70H)R\H/SPA7%Q<7"D[+R<L("1V86QU92P@+3$L(%!214=?4U!,251?3D]?
M14U05%DI.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L
M86-E*"=<7#LG+"`G.R<L("1V86QU92D["B`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E<R`]('-T<E]R97!L86-E*"=<7#LG+"`G.R<L("1V86QU97,I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)'1A9RP@
M=')I;2@D=F%L=64I+"`D<&%R86US+"!T<G5E+"`D=F%L=65S*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`O+R!3=')I
M;F<@9FEE;&1S+@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/FES3VQD1F]R;6%T*"DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@=F-A;&5N9&%R(#$N,"!A;F0@=F-A<F0@
M,BXQ(&]N;'D@97-C87!E('-E;6EC;VQO;G,*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@86YD('5S92!U;F5S8V%P960@<V5M:6-O;&]N<R!T;R!C<F5A
M=&4@;&ES=',N"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]('1R
M:6TH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@4W!L:70@
M8GD@=6YE<V-A<&5D('-E;6EC;VQO;G,Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU97,@/2!P<F5G7W-P;&ET*"<O*#\\(5Q<7%PI.R\G+"`D=F%L
M=64I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P
M;&%C92@G7%P[)RP@)SLG+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=65S(#T@<W1R7W)E<&QA8V4H)UQ<.R<L("<[)RP@)'9A;'5E
M<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U
M=&4H)'1A9RP@=')I;2@D=F%L=64I+"`D<&%R86US+"!T<G5E+"`D=F%L=65S
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=64@/2!T<FEM*"1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@("`@("\O($%S(&]F(')F8R`R-#(V(#(N-"XR('-E;6EC;VQO
M;BP@8V]M;6$L(&%N9`H@("`@("`@("`@("`@("`@("`@("`@("`O+R!C;VQO
M;B!M=7-T(&)E(&5S8V%P960@*&-O;6UA(&ES('5N97-C87!E9"!A9G1E<@H@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!S<&QI='1I;F<@8F5L;W<I+@H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92AA
M<G)A>2@G7%QN)RP@)UQ<.R<L("=<7#HG*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)'1H:7,M/E]N97=L
M:6YE+"`G.R<L("<Z)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V86QU92D["@H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!3<&QI="!B>2!U;F5S8V%P960@8V]M;6%S.@H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L=65S(#T@<')E9U]S<&QI="@G+R@_/"%<7%Q<
M*2PO)RP@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@<W1R7W)E<&QA8V4H)UQ<+"<L("<L)RP@)'9A;'5E*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E<R`]('-T<E]R97!L86-E*"=<7"PG+"`G
M+"<L("1V86QU97,I.PH*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$%T=')I8G5T92@D=&%G+"!T<FEM*"1V86QU92DL("1P87)A;7,L('1R
M=64L("1V86QU97,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!%>'!O<G0@=&AI<R!C;VUP;VYE;G0@:6X@=D-A;"!F
M;W)M870N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F%S92`@5&AE
M('1Y<&4@;V8@=&AE(&)A<V4@;V)J96-T+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!V0V%L(&9O<FUA="!D871A+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?97AP;W)T=D1A=&$H)&)A<V4@/2`G5D-!3$5.1$%2)RD*("`@('L*
M("`@("`@("`D<F5S=6QT(#T@)T)%1TE..B<@+B!3=')I;F<Z.G5P<&5R*"1B
M87-E*2`N("1T:&ES+3Y?;F5W;&EN93L*"B`@("`@("`@+R\@5D524TE/3B!I
M<R!N;W0@86QL;W=E9"!F;W(@96YT<FEE<R!E;F-L;W-E9"!I;B!60T%,14Y$
M05(O24-!3$5.1$%2+`H@("`@("`@("\O(&%S(&ET(&ES('!A<G0@;V8@=&AE
M(&5N8VQO<VEN9R!60T%,14Y$05(O24-!3$5.1$%2+B!3964@<F9C,C0T-0H@
M("`@("`@(&EF("@D8F%S92`A/3T@)U9%5D5.5"<@)B8@)&)A<V4@(3T]("=6
M5$]$3R<@)B8@)&)A<V4@(3T]("=604Q!4DTG("8F"B`@("`@("`@("`@("1B
M87-E("$]/2`G5DI/55).04PG("8F("1B87-E("$]/2`G5D92145"55-9)RD@
M>PH@("`@("`@("`@("`O+R!%;G-U<F4@=&AA="!V97)S:6]N(&ES('1H92!F
M:7)S="!A='1R:6)U=&4N"B`@("`@("`@("`@("1R97-U;'0@+CT@)U9%4E-)
M3TXZ)R`N("1T:&ES+3Y?=F5R<VEO;B`N("1T:&ES+3Y?;F5W;&EN93L*("`@
M("`@("!]"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S
M("1A='1R:6)U=&4I('L*("`@("`@("`@("`@)&YA;64@/2`D871T<FEB=71E
M6R=N86UE)UT["B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G5D524TE/3B<I
M('L*("`@("`@("`@("`@("`@("\O($%L<F5A9'D@9&]N92X*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<&%R86US7W-T<B`]("<G.PH@("`@("`@("`@("`D<&%R86US(#T@)&%T=')I
M8G5T95LG<&%R86US)UT["B`@("`@("`@("`@(&EF("@D<&%R86US*2!["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;5]N86UE
M(#T^("1P87)A;5]V86QU92D@>PH@("`@("`@("`@("`@("`@("`@("\O(%-K
M:7`@0TA!4E-%5"!F;W(@:4-A;&5N9&%R(#(N,"!D871A+"!N;W0*("`@("`@
M("`@("`@("`@("`@("`O+R!A;&QO=V5D+@H@("`@("`@("`@("`@("`@("`@
M(&EF("@D<&%R86U?;F%M92`]/2`G0TA!4E-%5"<@)B8@(21T:&ES+3YI<T]L
M9$9O<FUA="@I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D
M<&%R86US7W-T<B`N/2`B.R1P87)A;5]N86UE/21P87)A;5]V86QU92(["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1V
M86QU92`]("1A='1R:6)U=&5;)W9A;'5E)UT["B`@("`@("`@("`@('-W:71C
M:"`H)&YA;64I('L*("`@("`@("`@("`@+R\@1&%T92!F:65L9',N"B`@("`@
M("`@("`@(&-A<V4@)T-/35!,151%1"<Z"B`@("`@("`@("`@(&-A<V4@)T-2
M14%4140G.@H@("`@("`@("`@("!C87-E("=$0U)%051%1"<Z"B`@("`@("`@
M("`@(&-A<V4@)TQ!4U0M34]$249)140G.@H@("`@("`@("`@("`@("`@)'9A
M;'5E(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D=F%L=64I.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=$5$5.1"<Z"B`@
M("`@("`@("`@(&-A<V4@)T144U1!4E0G.@H@("`@("`@("`@("!C87-E("=$
M5%-404U0)SH*("`@("`@("`@("`@8V%S92`G1%5%)SH*("`@("`@("`@("`@
M8V%S92`G04%,05)-)SH*("`@("`@("`@("`@8V%S92`G4D5#55)214Y#12U)
M1"<Z"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG5D%,544G
M72DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<ULG5D%,544G
M72`]/2`G1$%412<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@)'1H:7,M/E]E>'!O<G1$871E*"1V86QU92D["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D
M=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`O+R!#;VUM82!S97!E<F%T960@9&%T97,N"B`@
M("`@("`@("`@(&-A<V4@)T581$%412<Z"B`@("`@("`@("`@(&-A<V4@)U)$
M051%)SH*("`@("`@("`@("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&1A=&4I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG5D%,544G72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A;7-;)U9!3%5%)UT@
M/3T@)T1!5$4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M97-;72`]("1T:&ES+3Y?97AP;W)T1&%T92@D9&%T92D["B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("@D<&%R86US6R=604Q512==(#T]("=0
M15))3T0G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;
M72`]("1T:&ES+3Y?97AP;W)T4&5R:6]D*"1D871E*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D871E<UM=(#T@)'1H:7,M/E]E>'!O<G1$871E5&EM92@D9&%T92D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&%T97-;72`]
M("1T:&ES+3Y?97AP;W)T1&%T951I;64H)&1A=&4I.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V
M86QU92`](&EM<&QO9&4H)RPG+"`D9&%T97,I.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=44DE'1T52)SH*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=604Q512==*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D<&%R86US6R=604Q512==(#T]("=$051%+51)
M344G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES
M+3Y?97AP;W)T1&%T951I;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H)'!A<F%M<ULG5D%,544G72`]/2`G1%52051)3TXG*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP
M;W)T1'5R871I;VXH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V
M86QU92`]("1T:&ES+3Y?97AP;W)T1'5R871I;VXH)'9A;'5E*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@+R\@1'5R871I;VX@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=$55)!
M5$E/3B<Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V5X<&]R
M=$1U<F%T:6]N*"1V86QU92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("\O(%!E<FEO9"!O9B!T:6UE(&9I96QD<RX*("`@("`@("`@
M("`@8V%S92`G1E)%14)54UDG.@H@("`@("`@("`@("`@("`@)'9A;'5E7W-T
M<B`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S("1P
M97)I;V0I('L*("`@("`@("`@("`@("`@("`@("`D=F%L=65?<W1R("X](&5M
M<'1Y*"1V86QU95]S='(I(#\@)R<@.B`G+"<["B`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E7W-T<B`N/2`D=&AI<RT^7V5X<&]R=%!E<FEO9"@D<&5R:6]D
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1V86QU92`]
M("1V86QU95]S='(["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("\O(%540R!O9F9S970@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=4
M6D]&1E-%5$923TTG.@H@("`@("`@("`@("!C87-E("=46D]&1E-%5%1/)SH*
M("`@("`@("`@("`@("`@("1V86QU92`]("1T:&ES+3Y?97AP;W)T571C3V9F
M<V5T*"1V86QU92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("\O($EN=&5G97(@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=015)#
M14Y4+4-/35!,151%)SH*("`@("`@("`@("`@8V%S92`G4%))3U))5%DG.@H@
M("`@("`@("`@("!C87-E("=215!%050G.@H@("`@("`@("`@("!C87-E("=3
M15%514Y#12<Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`B)'9A;'5E(CL*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@1V5O(&9I
M96QD<RX*("`@("`@("`@("`@8V%S92`G1T5/)SH*("`@("`@("`@("`@("`@
M("1V86QU92`]("1V86QU95LG;&%T:71U9&4G72`N("<L)R`N("1V86QU95LG
M;&]N9VET=61E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("\O(%)E8W5R<F5N8V4@9FEE;&1S+@H@("`@("`@("`@("!C87-E("=%
M6%)53$4G.@H@("`@("`@("`@("!C87-E("=24E5,12<Z"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O($%T=&5N9&%N8V4*("`@("`@
M("`@("`@8V%S92`G051414Y$144G.@H@("`@("`@("`@("`@("`@+R\@2W)O
M;F]L:71H(&-R96%T97,@871T96YD964@9FEE;&0@:6X@=F-A;&5N9&%R,BXP
M(&9O<FUA="X*("`@("`@("`@("`@("`@("\O($-O;G9E<G0@=&\@=F-A;&5N
M9&%R,2XP(&EF(&YE8V5S<V%R>2X*("`@("`@("`@("`@("`@("\O($5X86UP
M;&4@;V8@,2XP('-T>6QE.@H@("`@("`@("`@("`@("`@+R\@051414Y$144[
M4D],13U/5TY%4CM35$%455,]0T].1DE2345$.DIO:&X@4VUI=&@@/&IS;6ET
M:$!H;W-T,2YC;VT^"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES3VQD
M1F]R;6%T*"DI('L*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!P<F5G
M7W)E<&QA8V4H)R]-04E,5$\Z+R<L("<G+"`D=F%L=64I.PH@("`@("`@("`@
M("`@("`@("`@("1V86QU92`]("`D=F%L=64@+B`G(#PG("X@)'9A;'5E("X@
M)SXG.PH@("`@("`@("`@("`@("`@("`@("1P87)A;7-?<W1R(#T@<W1R7W)E
M<&QA8V4H)U!!4E135$%4/2<L("=35$%455,])RP@)'!A<F%M<U]S='(I.PH@
M("`@("`@("`@("`@("`@("`@("1P87)A;7-?<W1R(#T@<W1R7W)E<&QA8V4H
M)U-405154SU.145$4RU!0U1)3TXG+"`G4U1!5%53/4Y%1413($%#5$E/3B<L
M("1P87)A;7-?<W1R*3L*("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T
M<B`]('-T<E]R97!L86-E*"=23TQ%/5)%42U005)424-)4$%.5"<L("=%6%!%
M0U0]4D5154E212<L("1P87)A;7-?<W1R*3L*("`@("`@("`@("`@("`@("`@
M("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=23TQ%/4]05"U005)424-)
M4$%.5"<L("=%6%!%0U0]4D5154535"<L("1P87)A;7-?<W1R*3L*("`@("`@
M("`@("`@("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=23TQ%
M/4Y/3BU005)424-)4$%.5"<L("=%6%!%0U0]1EE))RP@)'!A<F%M<U]S='(I
M.PH@("`@("`@("`@("`@("`@("`@("1P87)A;7-?<W1R(#T@<W1R7W)E<&QA
M8V4H)U)35E`]5%)512<L("=24U90/5E%4R<L("1P87)A;7-?<W1R*3L*("`@
M("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`]('-T<E]R97!L86-E*"=2
M4U90/49!3%-%)RP@)U)35E`]3D\G+"`D<&%R86US7W-T<BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M9&5F875L=#H*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-/;&1&;W)M
M870H*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D871T
M<FEB=71E6R=V86QU97,G72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("8F(&-O=6YT*"1A='1R:6)U=&5;)W9A;'5E<R==*3XQ*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1V86QU97,@/2`D871T<FEB=71E6R=V86QU97,G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1N86UE(#T]("=.)R!\
M?"`D;F%M92`]/2`G0412)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&=L=64@/2`G.R<["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9VQU92`]("<L)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=65S("`]('-T<E]R97!L86-E*&%R<F%Y*"<[)RDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=<7#LG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E<RD["B`@("`@("`@("`@("`@("`@("`@("`@("1V
M86QU92`](&EM<&QO9&4H)&=L=64L("1V86QU97,I.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("\J('9C
M87)D(#(N,2!A;F0@=F-A;&5N9&%R(#$N,"!E<V-A<&4@;VYL>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@*B!S96UI8V]L;VYS("HO"B`@("`@("`@("`@
M("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*&%R<F%Y*"<[)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=<7#LG*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1N86UE(#T]("=35$%455,G*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O('9C86QE;F1A<B`Q+C`@:&%S
M(%-405154SI.145$4R!!0U1)3TX@=VAI;&4@,BXP(&AA<PH@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!35$%455,Z3D5%1%,M04-424].+@H@("`@("`@
M("`@("`@("`@("`@("`@("`D=F%L=64@/2!S=')?<F5P;&%C92@G3D5%1%,M
M04-424].)RP@)TY%1413($%#5$E/3B<L("1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("\O(%1E>'0@8V]N=&%I
M;FEN9R!N97=L:6YE<R!O<B!!4T-)22`^/2`Q,C<@;75S="!B92!"05-%-C0*
M("`@("`@("`@("`@("`@("`@("`O+R!O<B!154]4140M4%))3E1!0DQ%(&5N
M8V]D960N($-U<G)E;G1L>2!W92!U<V4*("`@("`@("`@("`@("`@("`@("`O
M+R!154]4140M4%))3E1!0DQ%(&%S(&1E9F%U;'0N"B`@("`@("`@("`@("`@
M("`@("`@+R\@1DE8344Z(&1E86P@=VET:"!B87-E-C0@96YC;V1I;F=S(0H@
M("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O6UY<>#(P+5QX
M-T9=+R(L("1V86QU92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("8F
M(&5M<'1Y*"1P87)A;7-;)T5.0T]$24Y')UTI*2`@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%R86US6R=%3D-/1$E.1R==(#T@)U%53U1%1"U04DE.
M5$%"3$4G.PH@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US7W-T<B`N
M/2`G.T5.0T]$24Y'/5%53U1%1"U04DE.5$%"3$4G.PH@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!!9&0@0TA!4E-%5"!A<R!W96QL+B!!="!L96%S="!T
M:&4@<WEN=&AE<VES(&-L:65N=`H@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!G971S(&-O;F9U<V5D(&]T:&5R=VES90H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H96UP='DH)'!A<F%M<ULG0TA!4E-%5"==*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULG0T%24T54)UT@/2!.3%,Z
M.F=E=$-H87)S970H*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7-?<W1R("X]("<[0TA!4E-%5#TG("X@)'!A<F%M<ULG0T%24T54)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D871T<FEB=71E6R=V86QU97,G72D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("8F(&-O=6YT*"1A='1R:6)U=&5;)W9A
M;'5E<R==*3XQ*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU97,@
M/2`D871T<FEB=71E6R=V86QU97,G73L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1N86UE(#T]("=.)R!\?"`D;F%M92`]/2`G0412)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&=L=64@/2`G.R<["B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9VQU92`]("<L)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S(#T@<W1R7W)E<&QA
M8V4H87)R87DH)SLG+"`G.B<L("<L)RP@)TU!24Q43UQ<.B<I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M7%P[)RP@)UQ<.B<L("=<7"PG+"`G34%)3%1/.B<I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65S*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@:6UP;&]D92@D9VQU92P@
M)'9A;'5E<RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@07,@;V8@<F9C(#(T,C8@,BXT+C(@<V5M
M:6-O;&]N+"!C;VUM82P@86YD(&-O;&]N"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O(&UU<W0@8F4@97-C87!E9"X@17AC;'5D92!-04E,5$\Z('1H;W5G
M:"X@5&AI<R!I<R!A"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&AA8VLA
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E
M*&%R<F%Y*"<[)RP@)SHG+"`G+"<L("=-04E,5$]<7#HG*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)UQ<
M.R<L("=<7#HG+"`G7%PL)RP@)TU!24Q43SHG*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D<&%R86US6R=%3D-/1$E.1R==*2`F)@H@("`@("`@("`@("`@("`@
M)'!A<F%M<ULG14Y#3T1)3D<G72`]/2`G455/5$5$+5!224Y404),12<@)B8@
M<W1R;&5N*'1R:6TH)'9A;'5E*2D@/B`P*2!["B`@("`@("`@("`@("`@("`O
M*B!Q=6]T9610<FEN=&%B;&5%;F-O9&4@9&]E<R!N;W0@97-C87!E($-23$9S
M+"!B=70@<W1R86YG90H@("`@("`@("`@("`@("`@("H@96YO=6=H('-I;F=L
M92!,1G,N('-O(&-O;G9E<G0@979E<GET:&EN9R!T;R!,1B!O;FQY(&%N9`H@
M("`@("`@("`@("`@("`@("H@<F5P;&%C92!A9G1E<G=A<F1S+B`J+PH@("`@
M("`@("`@("`@("`@)'9A;'5E(#T@<W1R7W)E<&QA8V4H(EQR(BP@)R<L("1V
M86QU92D["B`@("`@("`@("`@("`@("`D<F5S=6QT("X]("(D;F%M921P87)A
M;7-?<W1R.CTB("X@)'1H:7,M/E]N97=L:6YE"B`@("`@("`@("`@("`@("`@
M("`@+B!S=')?<F5P;&%C92@G/3!!)RP@)STP1#TP02<L("1T:&ES+3Y?<75O
M=&5D4')I;G1A8FQE16YC;V1E*"1V86QU92DI"B`@("`@("`@("`@("`@("`@
M("`@+B`D=&AI<RT^7VYE=VQI;F4["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D871T<E]S=')I;F<@/2`B)&YA;64D<&%R86US7W-T
M<CHD=F%L=64B.PH@("`@("`@("`@("`@("`@)')E<W5L="`N/2`D=&AI<RT^
M7V9O;&1,:6YE*"1A='1R7W-T<FEN9RD@+B`D=&AI<RT^7VYE=VQI;F4["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?8V]M<&]N96YT<R!A<R`D8V]M<&]N96YT*2!["B`@("`@("`@("`@("1R
M97-U;'0@+CT@)&-O;7!O;F5N="T^97AP;W)T=D-A;&5N9&%R*"D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E<W5L="`N("=%3D0Z)R`N("1B87-E
M("X@)'1H:7,M/E]N97=L:6YE.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R
M<V4@82!55$,@3V9F<V5T(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<&%R<V55=&-/9F9S970H)'1E>'0I"B`@("!["B`@("`@("`@)&]F9G-E="`]
M(&%R<F%Y*"D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H7"M\+2DH6S`M
M.5U[,GTI*%LP+3E=>S)]*2A;,"TY77LR?2D_+R<L("1T97AT+"`D=&EM95!A
M<G1S*2D@>PH@("`@("`@("`@("`D;V9F<V5T6R=A:&5A9"==("`]("AB;V]L
M*2@D=&EM95!A<G1S6S%=(#T]("<K)RD["B`@("`@("`@("`@("1O9F9S971;
M)VAO=7(G72`@(#T@:6YT=F%L*"1T:6UE4&%R='-;,ETI.PH@("`@("`@("`@
M("`D;V9F<V5T6R=M:6YU=&4G72`](&EN='9A;"@D=&EM95!A<G1S6S-=*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:6UE4&%R='-;-%TI*2!["B`@("`@
M("`@("`@("`@("`D;V9F<V5T6R=S96-O;F0G72`](&EN='9A;"@D=&EM95!A
M<G1S6S1=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&]F
M9G-E=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@17AP;W)T(&$@
M551#($]F9G-E="!F:65L9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X<&]R
M=%5T8T]F9G-E="@D=F%L=64I"B`@("!["B`@("`@("`@)&]F9G-E="`]("1V
M86QU95LG86AE860G72`_("<K)R`Z("<M)SL*("`@("`@("`D;V9F<V5T("X]
M('-P<FEN=&8H)R4P,F0E,#)D)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E6R=H;W5R)UTL("1V86QU95LG;6EN=71E)UTI.PH@("`@("`@
M(&EF("AI<W-E="@D=F%L=65;)W-E8V]N9"==*2D@>PH@("`@("`@("`@("`D
M;V9F<V5T("X]('-P<FEN=&8H)R4P,F0G+"`D=F%L=65;)W-E8V]N9"==*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V9F<V5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4&%R<V4@82!4:6UE(%!E<FEO9"!F:65L9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W!A<G-E4&5R:6]D*"1T97AT*0H@("`@>PH@("`@
M("`@("1P97)I;V1087)T<R`](&5X<&QO9&4H)R\G+"`D=&5X="D["@H@("`@
M("`@("1S=&%R="`]("1T:&ES+3Y?<&%R<V5$871E5&EM92@D<&5R:6]D4&%R
M='-;,%TI.PH*("`@("`@("!I9B`H)&1U<F%T:6]N(#T@)'1H:7,M/E]P87)S
M941U<F%T:6]N*"1P97)I;V1087)T<ULQ72DI('L*("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"=S=&%R="<@/3X@)'-T87)T+"`G9'5R871I;VXG(#T^("1D
M=7)A=&EO;BD["B`@("`@("`@?2!E;'-E:68@*"1E;F0@/2`D=&AI<RT^7W!A
M<G-E1&%T951I;64H)'!E<FEO9%!A<G1S6S%=*2D@>PH@("`@("`@("`@("!R
M971U<FX@87)R87DH)W-T87)T)R`]/B`D<W1A<G0L("=E;F0G(#T^("1E;F0I
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A(%1I
M;64@4&5R:6]D(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T
M4&5R:6]D*"1V86QU92D*("`@('L*("`@("`@("`D<&5R:6]D(#T@)'1H:7,M
M/E]E>'!O<G1$871E5&EM92@D=F%L=65;)W-T87)T)UTI.PH@("`@("`@("1P
M97)I;V0@+CT@)R\G.PH@("`@("`@(&EF("AI<W-E="@D=F%L=65;)V1U<F%T
M:6]N)UTI*2!["B`@("`@("`@("`@("1P97)I;V0@+CT@)'1H:7,M/E]E>'!O
M<G1$=7)A=&EO;B@D=F%L=65;)V1U<F%T:6]N)UTI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P97)I;V0@+CT@)'1H:7,M/E]E>'!O<G1$871E
M5&EM92@D=F%L=65;)V5N9"==*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1P97)I;V0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087)S97,@82!$871E
M5&EM92!F:65L9"!I;G1O(&$@=6YI>"!T:6UE<W1A;7`N"B`@("`@*@H@("`@
M("H@0'1O9&\@5&AI<R!F=6YC=&EO;B!S:&]U;&0@8F4@;6]V960@=&\@2&]R
M9&5?1&%T92!A;F0@;6%D92!P=6)L:6,N"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]P87)S941A=&54:6UE*"1T97AT*0H@("`@>PH@
M("`@("`@("1D871E4&%R=',@/2!E>'!L;V1E*"=4)RP@)'1E>'0I.PH@("`@
M("`@(&EF("AC;W5N="@D9&%T95!A<G1S*2`A/2`R("8F("%E;7!T>2@D=&5X
M="DI('L*("`@("`@("`@("`@+R\@3F]T(&$@9&%T971I;64@9FEE;&0@8G5T
M(&UA>2!B92!J=7-T(&$@9&%T92!F:65L9"X*("`@("`@("`@("`@:68@*"$D
M9&%T92`]($AO<F1E7VE#86QE;F1A<CHZ7W!A<G-E1&%T92@D=&5X="DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D9&%T93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R971U<FX@0&=M;6MT:6UE*#`L(#`L(#`L("1D871E6R=M
M;VYT:"==+"`D9&%T95LG;61A>2==+"`D9&%T95LG>65A<B==*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)&1A=&4@/2!(;W)D95]I0V%L96YD87(Z.E]P
M87)S941A=&4H)&1A=&5087)T<ULP72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1D871E.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:6UE(#T@2&]R9&5?
M:4-A;&5N9&%R.CI?<&%R<V54:6UE*"1D871E4&%R='-;,5TI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&EM93L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&EM95LG>F]N92==(#T]("=55$,G*2!["B`@("`@("`@("`@(')E='5R;B!`
M9VUM:W1I;64H)'1I;65;)VAO=7(G72P@)'1I;65;)VUI;G5T92==+"`D=&EM
M95LG<V5C;VYD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&5;)VUO;G1H)UTL("1D871E6R=M9&%Y)UTL("1D871E6R=Y96%R)UTI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!`;6MT:6UE*"1T
M:6UE6R=H;W5R)UTL("1T:6UE6R=M:6YU=&4G72P@)'1I;65;)W-E8V]N9"==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T95LG;6]N=&@G72P@
M)&1A=&5;)VUD87DG72P@)&1A=&5;)WEE87(G72D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@17AP;W)T(&$@1&%T951I;64@9FEE;&0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]E>'!O<G1$871E5&EM92@D=F%L=64I"B`@
M("!["B`@("`@("`@)'1E;7`@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-?
M;V)J96-T*"1V86QU92D@)B8@(6ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@
M("`@("`@)'1Z(#T@9&%T92@G3R<L("1V86QU92D["B`@("`@("`@("`@("14
M6D]F9G-E="`]("@S-C`P("H@<W5B<W1R*"1T>BP@,"P@,RDI("L@*#8P("H@
M<W5B<W1R*&1A=&4H)T\G+"`D=F%L=64I+"`S+"`R*2D["B`@("`@("`@("`@
M("1V86QU92`M/2`D5%I/9F9S970["@H@("`@("`@("`@("`D=&5M<%LG>F]N
M92==("`@/2`G551#)SL*("`@("`@("`@("`@)'1E;7!;)WEE87(G72`@(#T@
M9&%T92@G62<L("1V86QU92D["B`@("`@("`@("`@("1T96UP6R=M;VYT:"==
M("`](&1A=&4H)VXG+"`D=F%L=64I.PH@("`@("`@("`@("`D=&5M<%LG;61A
M>2==("`@/2!D871E*"=J)RP@)'9A;'5E*3L*("`@("`@("`@("`@)'1E;7!;
M)VAO=7(G72`@(#T@9&%T92@G1R<L("1V86QU92D["B`@("`@("`@("`@("1T
M96UP6R=M:6YU=&4G72`](&1A=&4H)VDG+"`D=F%L=64I.PH@("`@("`@("`@
M("`D=&5M<%LG<V5C;VYD)UT@/2!D871E*"=S)RP@)'9A;'5E*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9&%T94]B(#T@;F5W($AO<F1E7T1A
M=&4H)'9A;'5E*3L*("`@("`@("`@("`@<F5T=7)N($AO<F1E7VE#86QE;F1A
M<CHZ7V5X<&]R=$1A=&54:6UE*"1D871E3V(M/G1I;65S=&%M<"@I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!(;W)D95]I0V%L96YD87(Z.E]E>'!O
M<G1$871E*"1T96UP*2`N("=4)R`N($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R
M=%1I;64H)'1E;7`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@
M5&EM92!F:65L9"X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]P87)S951I;64H)'1E>'0I"B`@("!["B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\H6S`M.5U[,GTI*%LP+3E=>S)]*2A;,"TY77LR?2DH
M6BD_+R<L("1T97AT+"`D=&EM95!A<G1S*2D@>PH@("`@("`@("`@("`D=&EM
M95LG:&]U<B==(#T@:6YT=F%L*"1T:6UE4&%R='-;,5TI.PH@("`@("`@("`@
M("`D=&EM95LG;6EN=71E)UT@/2!I;G1V86PH)'1I;65087)T<ULR72D["B`@
M("`@("`@("`@("1T:6UE6R=S96-O;F0G72`](&EN='9A;"@D=&EM95!A<G1S
M6S-=*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:6UE4&%R='-;-%TI*2![
M"B`@("`@("`@("`@("`@("`D=&EM95LG>F]N92==(#T@)U540R<["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&EM95LG>F]N92==
M(#T@)TQO8V%L)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)'1I;64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R=',@
M82!4:6UE(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T5&EM
M92@D=F%L=64I"B`@("!["B`@("`@("`@)'1I;64@/2!S<')I;G1F*"<E,#)D
M)3`R9"4P,F0G+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;)VAO
M=7(G72P@)'9A;'5E6R=M:6YU=&4G72P@)'9A;'5E6R=S96-O;F0G72D["B`@
M("`@("`@:68@*"1V86QU95LG>F]N92==(#T]("=55$,G*2!["B`@("`@("`@
M("`@("1T:6UE("X]("=:)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:6UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S(&$@1&%T92!F:65L
M9"X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]P87)S941A=&4H)'1E>'0I"B`@("!["B`@("`@("`@)'!A<G1S(#T@97AP
M;&]D92@G5"<L("1T97AT*3L*("`@("`@("!I9B`H8V]U;G0H)'!A<G1S*2`]
M/2`R*2!["B`@("`@("`@("`@("1T97AT(#T@)'!A<G1S6S!=.PH@("`@("`@
M('T*"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7BA<9'LT?2DM/RA<9'LR
M?2DM/RA<9'LR?2DD+R<L("1T97AT+"`D;6%T8V@I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A
M>2@G>65A<B<@/3X@)&UA=&-H6S%=+`H@("`@("`@("`@("`@("`@("`@("`G
M;6]N=&@G(#T^("1M871C:%LR72P*("`@("`@("`@("`@("`@("`@("`@)VUD
M87DG(#T^("1M871C:%LS72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!O
M<G0@82!$871E(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T
M1&%T92@D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES7V]B:F5C="@D=F%L
M=64I*2!["B`@("`@("`@("`@("1V86QU92`](&%R<F%Y*"=Y96%R)R`]/B`D
M=F%L=64M/GEE87(L("=M;VYT:"<@/3X@)'9A;'5E+3YM;VYT:"P@)VUD87DG
M(#T^("1V86QU92T^;61A>2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S
M<')I;G1F*"<E,#1D)3`R9"4P,F0G+"`D=F%L=65;)WEE87(G72P@)'9A;'5E
M6R=M;VYT:"==+"`D=F%L=65;)VUD87DG72D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!087)S92!A($1U<F%T:6]N(%9A;'5E(&9I96QD+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<&%R<V5$=7)A=&EO;B@D=&5X="D*("`@('L*("`@("`@
M("!I9B`H<')E9U]M871C:"@G+RA;*UT_?%LM72E0*"A;,"TY72M7*7PH6S`M
M.5TK1"E\*2A4*"A;,"TY72M(*7PH6S`M.5TK32E\*%LP+3E=*U,I*2LI/R\G
M+"!T<FEM*"1T97AT*2P@)&1U<G9A;'5E*2D@>PH@("`@("`@("`@("`O+R!7
M965K<RX*("`@("`@("`@("`@)&1U<F%T:6]N(#T@-R`J(#@V-#`P("H@:6YT
M=F%L*"1D=7)V86QU95LS72D["@H@("`@("`@("`@("!I9B`H8V]U;G0H)&1U
M<G9A;'5E*2`^(#0I('L*("`@("`@("`@("`@("`@("\O($1A>7,N"B`@("`@
M("`@("`@("`@("`D9'5R871I;VX@*ST@.#8T,#`@*B!I;G1V86PH)&1U<G9A
M;'5E6S1=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H8V]U;G0H
M)&1U<G9A;'5E*2`^(#4I('L*("`@("`@("`@("`@("`@("\O($AO=7)S+@H@
M("`@("`@("`@("`@("`@)&1U<F%T:6]N("L](#,V,#`@*B!I;G1V86PH)&1U
M<G9A;'5E6S==*3L*"B`@("`@("`@("`@("`@("`O+R!-:6YS+@H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D=7)V86QU95LX72DI('L*("`@("`@("`@
M("`@("`@("`@("`D9'5R871I;VX@*ST@-C`@*B!I;G1V86PH)&1U<G9A;'5E
M6SA=*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!3
M96-S+@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D=7)V86QU95LY72DI
M('L*("`@("`@("`@("`@("`@("`@("`D9'5R871I;VX@*ST@:6YT=F%L*"1D
M=7)V86QU95LY72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("\O(%-I9VXN"B`@("`@("`@("`@(&EF("@D9'5R=F%L
M=65;,5T@/3T@(BTB*2!["B`@("`@("`@("`@("`@("`D9'5R871I;VX@*CT@
M+3$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B`D9'5R871I
M;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5X<&]R="!A(&1U
M<F%T:6]N('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?97AP;W)T1'5R
M871I;VXH)'9A;'5E*0H@("`@>PH@("`@("`@("1D=7)A=&EO;B`]("<G.PH@
M("`@("`@(&EF("@D=F%L=64@/"`P*2!["B`@("`@("`@("`@("1V86QU92`J
M/2`M,3L*("`@("`@("`@("`@)&1U<F%T:6]N("X]("<M)SL*("`@("`@("!]
M"B`@("`@("`@)&1U<F%T:6]N("X]("=0)SL*"B`@("`@("`@)'=E96MS(#T@
M9FQO;W(H)'9A;'5E("\@*#<@*B`X-C0P,"DI.PH@("`@("`@("1V86QU92`]
M("1V86QU92`E("@W("H@.#8T,#`I.PH@("`@("`@(&EF("@D=V5E:W,I('L*
M("`@("`@("`@("`@)&1U<F%T:6]N("X]("1W965K<R`N("=7)SL*("`@("`@
M("!]"@H@("`@("`@("1D87ES(#T@9FQO;W(H)'9A;'5E("\@*#@V-#`P*2D[
M"B`@("`@("`@)'9A;'5E(#T@)'9A;'5E("4@*#@V-#`P*3L*("`@("`@("!I
M9B`H)&1A>7,I('L*("`@("`@("`@("`@)&1U<F%T:6]N("X]("1D87ES("X@
M)T0G.PH@("`@("`@('T*"B`@("`@("`@:68@*"1V86QU92D@>PH@("`@("`@
M("`@("`D9'5R871I;VX@+CT@)U0G.PH*("`@("`@("`@("`@)&AO=7)S(#T@
M9FQO;W(H)'9A;'5E("\@,S8P,"D["B`@("`@("`@("`@("1V86QU92`]("1V
M86QU92`E(#,V,#`["B`@("`@("`@("`@(&EF("@D:&]U<G,I('L*("`@("`@
M("`@("`@("`@("1D=7)A=&EO;B`N/2`D:&]U<G,@+B`G2"<["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1M:6YS(#T@9FQO;W(H)'9A;'5E("\@-C`I
M.PH@("`@("`@("`@("`D=F%L=64@/2`D=F%L=64@)2`V,#L*("`@("`@("`@
M("`@:68@*"1M:6YS*2!["B`@("`@("`@("`@("`@("`D9'5R871I;VX@+CT@
M)&UI;G,@+B`G32<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M=F%L=64I('L*("`@("`@("`@("`@("`@("1D=7)A=&EO;B`N/2`D=F%L=64@
M+B`G4R<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D9'5R871I;VX["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&9O;&1E9"!V97)S:6]N(&]F(&$@;&EN92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V9O;&1,:6YE*"1L:6YE*0H@("`@>PH@("`@("`@("1L:6YE(#T@<')E
M9U]R97!L86-E*"(O7')<;GQ<;GQ<<B\B+"`G7&XG+"`D;&EN92D["B`@("`@
M("`@:68@*'-T<FQE;B@D;&EN92D@/B`W-2D@>PH@("`@("`@("`@("`D9F]L
M9&5D;&EN92`]("<G.PH@("`@("`@("`@("!W:&EL92`H(65M<'1Y*"1L:6YE
M*2D@>PH@("`@("`@("`@("`@("`@)&UA>$QI;F4@/2!S=6)S='(H)&QI;F4L
M(#`L(#<U*3L*("`@("`@("`@("`@("`@("1C=710;VEN="`](&UA>"@V,"P@
M;6%X*'-T<G)P;W,H)&UA>$QI;F4L("<[)RDL('-T<G)P;W,H)&UA>$QI;F4L
M("<Z)RDI("L@,2D["@H@("`@("`@("`@("`@("`@)&9O;&1E9&QI;F4@+CT@
M*&5M<'1Y*"1F;VQD961L:6YE*2D@/PH@("`@("`@("`@("`@("`@("`@('-U
M8G-T<B@D;&EN92P@,"P@)&-U=%!O:6YT*2`Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]N97=L:6YE("X@)R`G("X@<W5B<W1R*"1L:6YE+"`P+"`D
M8W5T4&]I;G0I.PH*("`@("`@("`@("`@("`@("1L:6YE(#T@*'-T<FQE;B@D
M;&EN92D@/#T@)&-U=%!O:6YT*2`_("<G(#H@<W5B<W1R*"1L:6YE+"`D8W5T
M4&]I;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9F]L
M9&5D;&EN93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!A;B`X8FET('-T<FEN9R!T;R!A
M('%U;W1E9"UP<FEN=&%B;&4@<W1R:6YG(&%C8V]R9&EN9PH@("`@("H@=&\@
M4D9#,C`T-2P@<V5C=&EO;B`V+C<N"B`@("`@*@H@("`@("H@57-E<R!I;6%P
M7SAB:70@:68@879A:6QA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&EN<'5T("!4:&4@<W1R:6YG('1O(&)E(&5N8V]D960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960M<')I;G1A8FQE(&5N
M8V]D960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75O=&5D4')I
M;G1A8FQE16YC;V1E*"1I;G!U="`]("<G*0H@("`@>PH@("`@("`@("\O($EF
M(&EM87!?.&)I="@I(&ES(&%V86EL86)L92P@=7-E(&ET+@H@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)VEM87!?.&)I="<I*2!["B`@("`@("`@("`@
M(')E='5R;B!I;6%P7SAB:70H)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%)A=&AE<B!D=6UB(')E<&QA8VUE;G0Z(&IU<W0@96YC;V1E(&5V97)Y
M=&AI;F<N"B`@("`@("`@)&AE>"`](&%R<F%Y*"<P)RP@)S$G+"`G,B<L("<S
M)RP@)S0G+"`G-2<L("<V)RP@)S<G+"`G."<L("<Y)RP*("`@("`@("`@("`@
M("`@("`@("`@)T$G+"`G0B<L("=#)RP@)T0G+"`G12<L("=&)RD["@H@("`@
M("`@("1O=71P=70@/2`G)SL*("`@("`@("`D;&5N(#T@<W1R;&5N*"1I;G!U
M="D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;CL@*RLD:2D@>PH@
M("`@("`@("`@("`D8R`]('-U8G-T<B@D:6YP=70L("1I+"`Q*3L*("`@("`@
M("`@("`@)&1E8R`](&]R9"@D8RD["B`@("`@("`@("`@("1O=71P=70@+CT@
M)STG("X@)&AE>%MF;&]O<B@D9&5C("\@,38I72`N("1H97A;9FQO;W(H)&1E
M8R`E(#$V*5T["B`@("`@("`@("`@(&EF("@H)&D@*R`Q*2`E(#(U(#T](#`I
M('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@(CU<<EQN(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&5M<&QA=&4N<&AP````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P-3(U-C<@,3`U,34T,S0Q-#`@,#(Q-C0R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!(
M;W)D92!496UP;&%T92!S>7-T96TN($%D87!T960@9G)O;2!B5&5M<&QA=&4@
M8GD@0G)I86X@3&]Z:65R"B`J(#QB<FEA;D!M87-S87-S:2YN970^+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]496UP;&%T92]496UP;&%T92YP:'`L=B`Q
M+C,X+C$P+C$P(#(P,#8O,#8O,3,@,#,Z-30Z,#,@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5M<&QA=&4*("HO"F-L87-S($AO
M<F1E7U1E;7!L871E('L*"B`@("`O*BH*("`@("`J($]P=&EO;B!V86QU97,N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O
M<'1I;VYS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($1I<F5C=&]R>2!T
M:&%T('1E;7!L871E<R!S:&]U;&0@8F4@<F5A9"!F<F]M+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)A<V5P871H(#T@
M)R<["@H@("`@+RHJ"B`@("`@*B!297-E="!T96UP;&%T92!V87)I86)L97,@
M869T97(@<&%R<VEN9S\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?<F5S971687)S(#T@=')U93L*"B`@("`O*BH*("`@
M("`J(%1A9R`H<V-A;&%R*2!V86QU97,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]S8V%L87)S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($QO;W`@=&%G('9A;'5E<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%R<F%Y<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#;&]O<"!T86<@=F%L=65S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%R<F%Y<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!)9B!T86<@=F%L=65S+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:69S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($YA;64@;V8@8V%C:&5D('1E;7!L871E
M(&9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?=&5M<&QA=&5&:6QE(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-A
M8VAE9"!S;W5R8V4@;V8@=&5M<&QA=&4@9FEL92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T96UP;&%T92`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX@0V%N('-E="!T:&4@=&5M
M<&QA=&4@8F%S92!P871H(&%N9"!W:&5T:&5R(&]R(&YO=`H@("`@("H@=&\@
M9')O<"!T96UP;&%T92!V87)I86)L97,@869T97(@82!P87)S:6YG(&$@=&5M
M<&QA=&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&)A<V5P871H
M("`@5&AE(&1I<F5C=&]R>2!W:&5R92!T96UP;&%T97,@87)E(')E860@9G)O
M;2X*("`@("`J($!P87)A;2!B;V]L96%N("1R97-E=%9A<G,@($1R;W`@=&5M
M<&QA=&4@=F%R<R!A9G1E<B!P87)S:6YG(&$@=&5M<&QA=&4_"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7U1E;7!L871E*"1B87-E<&%T:"`](&YU;&PL
M("1R97-E=%9A<G,@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D8F%S97!A=&@I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8F%S97!A=&@@
M/2`D8F%S97!A=&@["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?<F5S9716
M87)S(#T@*&)O;VPI)')E<V5T5F%R<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@86X@;W!T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&]P=&EO;B`@5&AE(&]P=&EO;B!N86UE+@H@("`@("H@0'!A<F%M(&UI>&5D
M("`D=F%L("`@("!4:&4@;W!T:6]N)W,@=F%L=64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$]P=&EO;B@D;W!T:6]N+"`D=F%L*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?;W!T:6]N<ULD;W!T:6]N72`]("1V86P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@=&AE('1E;7!L871E(&-O;G1E;G1S('1O(&$@<W1R
M:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E;7!L871E("!4
M:&4@=&5M<&QA=&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&5M
M<&QA=&4H)'1E;7!L871E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=&5M<&QA
M=&4@/2`D=&5M<&QA=&4["B`@("`@("`@)'1H:7,M/E]T96UP;&%T949I;&4@
M/2`G<W1R:6YG)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@
M;W!T:6]N)W,@=F%L=64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;W!T:6]N("!4:&4@;W!T:6]N(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&]P=&EO;B=S('9A;'5E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971/<'1I;VXH)&]P=&EO;BD*("`@('L*("`@("`@("!R971U<FX@
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R1O<'1I;VY=*2`_("1T:&ES+3Y?;W!T
M:6]N<ULD;W!T:6]N72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S(&$@=&%G+"!L;V]P+"!O<B!I9B!V87)I86)L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG?&%R<F%Y("1T86<@("!%:71H97(@=&AE('1A9R!N
M86UE(&]R(&$@:&%S:"!W:71H('1A9R!N86UE<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87,@:V5Y<R!A;F0@=&%G('9A;'5E<R!A<R!V
M86QU97,N"B`@("`@*B!`<&%R86T@;6EX960@("`@("`@("1V87(@("!4:&4@
M=F%L=64@=&\@<F5P;&%C92!T:&4@=&%G('=I=&@N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`@("`@("1I<TEF("!)<R!T:&ES(&9O<B!A;B`\:68Z/B!T86<_
M("A$969A=6QT.B!N;RDN"B`@("`@*B\*("`@(&9U;F-T:6]N('-E="@D=&%G
M+"`D=F%R+"`D:7-)9B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&%G*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&%G(&%S("1T
M5&%G(#T^("1T5F%R*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T*"1T
M5&%G+"`D=%9A<BP@)&ES268I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E:68@*&ES7V%R<F%Y*"1V87(I('Q\(&ES7V]B:F5C="@D=F%R*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V%R<F%Y<ULD=&%G72`]("1V87(["B`@("`@
M("`@("`@(&EF("@D:7-)9BD@>PH@("`@("`@("`@("`@("`@+R\@2G5S="!S
M=&]R92!T:&4@<V%M92!V87)I86)L92!T:&%T('=E('-T;W)E9"!I;@H@("`@
M("`@("`@("`@("`@+R\@)'1H:7,M/E]A<G)A>7,@+2!I9B!W92!D;VXG="!M
M;V1I9GD@:70L(%!(4"=S"B`@("`@("`@("`@("`@("`O+R!R969E<F5N8V4@
M8V]U;G1I;F<@96YS=7)E<R!W92=R92!N;W0@=7-I;F<@86YY"B`@("`@("`@
M("`@("`@("`O+R!A9&1I=&EO;F%L(&UE;6]R>2!H97)E+@H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I9G-;)'1A9UT@/2`D=F%R.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S8V%L87)S
M6R1T86==(#T@)'9A<CL*("`@("`@("`@("`@:68@*"1I<TEF*2!["B`@("`@
M("`@("`@("`@("`O+R!*=7-T('-T;W)E('1H92!S86UE('9A<FEA8FQE('1H
M870@=V4@<W1O<F5D(&EN"B`@("`@("`@("`@("`@("`O+R`D=&AI<RT^7W-C
M86QA<G,@+2!I9B!W92!D;VXG="!M;V1I9GD@:70L(%!(4"=S"B`@("`@("`@
M("`@("`@("`O+R!R969E<F5N8V4@8V]U;G1I;F<@96YS=7)E<R!W92=R92!N
M;W0@=7-I;F<@86YY"B`@("`@("`@("`@("`@("`O+R!A9&1I=&EO;F%L(&UE
M;6]R>2!H97)E+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]I9G-;)'1A9UT@
M/2`D=F%R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=F%L=64@;V8@82!T86<@;W(@;&]O<"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T86<@(%1H92!T86<@;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=&%G('9A;'5E
M(&]R(&YU;&P@:68@=&AE('1A9R!H87-N)W0@8F5E;B!S970@>65T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G970H)'1A9RD*("`@('L*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]A<G)A>7-;)'1A9UTI*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7V%R<F%Y<ULD=&%G73L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<V-A;&%R<ULD=&%G72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<V-A;&%R<ULD=&%G73L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S
M('9A;'5E<R!F;W(@82!C;&]O<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T86<@("!4:&4@;F%M92!O9B!T:&4@8VQO;W`N"B`@("`@*B!`<&%R
M86T@87)R87D@)&%R<F%Y("!4:&4@=F%L=65S(&9O<B!T:&4@8VQO;W`N"B`@
M("`@*B!`<&%R86T@87)R87D@)&-A<V5S("!4:&4@8V%S97,@*'1E<W0@=F%L
M=65S*2!F;W(@=&AE(&-L;V]P<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M0VQO;W`H)'1A9RP@)&%R<F%Y+"`D8V%S97,I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]C87)R87ES6R1T86==(#T@87)R87DH"B`@("`@("`@("`@("=A<G)A
M>2<@/3X@)&%R<F%Y+`H@("`@("`@("`@("`G8V%S97,G(#T^("1C87-E<PH@
M("`@("`@("D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E=',@=&AE('1E
M;7!L871E('9A<FEA8FQE<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<V-A;&%R<R`@4F5S970@<V-A;&%R("AB87-I8R!T86<I('9A<FEA8FQE
M<S\*("`@("`J($!P87)A;2!B;V]L96%N("1A<G)A>7,@("!297-E="!L;V]P
M('9A<FEA8FQE<S\*("`@("`J($!P87)A;2!B;V]L96%N("1C87)R87ES("!2
M97-E="!C;&]O<"!V87)I86)L97,_"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M:69S("`@("`@4F5S970@:68@=F%R:6%B;&5S/PH@("`@("HO"B`@("!F=6YC
M=&EO;B!R97-E=%9A<G,H)'-C86QA<G,L("1A<G)A>7,L("1C87)R87ES+"`D
M:69S*0H@("`@>PH@("`@("`@(&EF("@D<V-A;&%R<R`]/3T@=')U92D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W-C86QA<G,@/2!A<G)A>2@I.PH@("`@("`@
M('T*("`@("`@("!I9B`H)&%R<F%Y<R`]/3T@=')U92D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V%R<F%Y<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@
M(&EF("@D8V%R<F%Y<R`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-A<G)A>7,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H)&EF
M<R`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^7VEF<R`](&%R<F%Y
M*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@
M;&ES="!O9B!B;&]C:W,@<')E<V5N="!I;B!T:&4@=&5M<&QA=&4@<V]U<F-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@
M9FEL92!T;R!F971C:"!T:&4@=&5M<&QA=&4@9G)O;2X*("`@("`J($!R971U
M<FX@;6EX960@($%N(&%R<F%Y(&]F(&%P<&QI8V%T:6]N<RP@;W(@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T0FQO
M8VMS*"D*("`@('L*("`@("`@("`D8FQO8VMS(#T@87)R87DH*3L*("`@("`@
M("!I9B`H<')E9U]M871C:%]A;&PH)SQB;&]C:SHH6V$M>D$M6C`M.5]=*SI;
M82UZ02U:,"TY7UTK*3XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1E;7!L871E+"`D;6%T8VAE<RP@4%)%1U]3151?3U)$15(I*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1M871C:&5S(&%S("1M871C:"D@>PH@
M("`@("`@("`@("`@("`@)&)L;V-K<UM=(#T@)&UA=&-H6S%=.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L;V-K<SL*("`@
M('T*"B`@("`O*BH*("`@("`J($9E=&-H97,@82!T96UP;&%T92!F<F]M('1H
M92!S<&5C:69I960@9FEL92!A;F0@<F5T=7)N('1H92!P87)S960*("`@("`J
M(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N
M86UE("!4:&4@9FEL92!T;R!F971C:"!T:&4@=&5M<&QA=&4@9G)O;2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!T96UP;&%T
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8V@H)&9I;&5N86UE*0H@("`@
M>PH@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3Y?9V5T5&5M<&QA=&4H)&9I
M;&5N86UE*3L*("`@("`@("!I9B`H:7-?82@D8V]N=&5N=',L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT<SL*("`@("`@
M("!]"@H@("`@("`@("\O(%!A<G-E(&%N9"!R971U<FX@=&AE(&-O;G1E;G1S
M+@H@("`@("`@(')E='5R;B`D=&AI<RT^<&%R<V4H)&-O;G1E;G1S*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A;&P@=F%R:6%B;&5S+W1A9W,@
M:6X@=&AE('1E;7!L871E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;G1E;G1S("!4:&4@=6YP87)S960@=&5M<&QA=&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@=&5M<&QA=&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!A<G-E*"1C;VYT96YT<R`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"$D8V]N=&5N=',I('L*("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@)'1H:7,M/E]T96UP;&%T93L*("`@("`@("!]"@H@("`@("`@("\O
M(%!R;V-E<W,@:69S+@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I9G,I
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?:69S(&%S("1T86<@
M/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2`D=&AI
M<RT^7W!A<G-E268H)'1A9RP@)&-O;G1E;G1S*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+R\@4')O8V5S<R!T86=S+@H@("`@("`@("1S
M96%R8V@@/2!A<G)A>2@I.PH@("`@("`@("1R97!L86-E(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W-C86QA<G,@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@)'-E87)C:%M=(#T@)'1H:7,M/E]G9714
M86<H)&ME>2D["B`@("`@("`@("`@("1R97!L86-E6UT@/2`D=F%L=64["B`@
M("`@("`@?0H@("`@("`@(&EF("AC;W5N="@D<V5A<F-H*2D@>PH@("`@("`@
M("`@("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@D<V5A<F-H+"`D<F5P;&%C
M92P@)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%!R;V-E<W,@
M;&]O<',@86YD(&%R<F%Y<RX*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V%R
M<F%Y<R!A<R`D:V5Y(#T^("1A<G)A>2D@>PH@("`@("`@("`@("`D8V]N=&5N
M=',@/2`D=&AI<RT^7W!A<G-E3&]O<"@D:V5Y+"`D87)R87DL("1C;VYT96YT
M<RD["B`@("`@("`@?0H*("`@("`@("`O+R!0<F]C97-S(&-L;V]P<RX*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V-A<G)A>7,@87,@)&ME>2`]/B`D87)R
M87DI('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94-L
M;V]P*"1K97DL("1A<G)A>2P@)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@
M("`@("\O(%!A<G-E(&=E='1E>'0@=&%G<RP@:68@=&AE(&]P=&EO;B!I<R!E
M;F%B;&5D+@H@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=G971T97AT
M)RDI('L*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P87)S94=E
M='1E>'0H)&-O;G1E;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%!A<G-E
M(&5M8F5D9&5D(&)L;V-K<PH@("`@("`@(&EF("@D=&AI<RT^9V5T3W!T:6]N
M*"=B;&]C:W,G*2D@>PH@("`@("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^
M7W!A<G-E0FQO8VMS*"1C;VYT96YT<RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!297-E="!T96UP;&%T92!D871A('5N;&5S<R!W92=R92!S=7!P;W-E9"!T
M;R!K965P(&ET"B`@("`@("`@+R\@87)O=6YD+@H@("`@("`@(&EF("@D=&AI
M<RT^7W)E<V5T5F%R<RD@>PH@("`@("`@("`@("`D=&AI<RT^<F5S971687)S
M*&9A;'-E+"!T<G5E+"!T<G5E+"!F86QS92D["B`@("`@("`@?0H*("`@("`@
M("`O+R!2971U<FX@<&%R<V5D('1E;7!L871E+@H@("`@("`@(')E='5R;B`D
M8V]N=&5N=',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&9U;&P@
M<W1A<G0@86YD(&5N9"!T86=S(&9O<B!A(&YA;65D('1A9RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T86<*("`@("`J($!P87)A;2!S=')I;F<@)&1I<F5C=&EV92`@5&AE
M(&MI;F0@;V8@=&%G("T@=&%G+"!I9BP@;&]O<"P@8VQO;W`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@)V(G(#T^(%-T87)T('1A9RX*("`@("`J
M("`@("`@("`@("`@("`@("=E)R`]/B!%;F0@=&%G+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?9V5T5&%G<R@D=&%G+"`D9&ER96-T:79E*0H@("`@>PH@("`@
M("`@(')E='5R;B!A<G)A>2@G8B<@/3X@)SPG("X@)&1I<F5C=&EV92`N("<Z
M)R`N("1T86<@+B`G/B<L"B`@("`@("`@("`@("`@("`@("`@("=E)R`]/B`G
M/"\G("X@)&1I<F5C=&EV92`N("<Z)R`N("1T86<@+B`G/B<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1F]R;6%T<R!A('-C86QA<B!T86<@*&1E9F%U;'0@
M9F]R;6%T(&ES(#QT86<Z;F%M93XI+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1A9R`@5&AE
M(&YA;64@;V8@=&AE('1A9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&9U;&P@=&%G('=I=&@@=&AE(&-U<G)E;G0@<W1A<G0O96YD(&1E
M;&EM:71E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971486<H)'1A9RD*
M("`@('L*("`@("`@("!R971U<FX@)SQT86<Z)R`N("1T86<@+B`G("\^)SL*
M("`@('T*"B`@("`O*BH*("`@("`J($5X=')A8W1S(&$@<&]R=&EO;B!O9B!A
M('1E;7!L871E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D="`@("`@("`@("`@5&AE('1A9R!T
M;R!E>'1R86-T+B!(87-H(&9O<FUA="!I<SH*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=%LG8B==("T@5&AE('-T87)T('1A9PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T6R=E)UT@+2!4:&4@
M96YD('1A9PH@("`@("H@0'!A<F%M('-T<FEN9R`F)&-O;G1E;G1S("!4:&4@
M=&5M<&QA=&4@=&\@97AT<F%C="!F<F]M+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9V5T4W1A=&5M96YT*"1T+"`F)&-O;G1E;G1S*0H@("`@>PH@("`@("`@
M("\O($QO8V%T92!T:&4@<W1A=&5M96YT+@H@("`@("`@("1P;W,@/2!S=')P
M;W,H)&-O;G1E;G1S+"`D=%LG8B==*3L*("`@("`@("!I9B`H)'!O<R`]/3T@
M9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)'1A9U]L96YG=&@@/2!S=')L96XH)'1;)V(G72D["B`@("`@
M("`@)&9P;W,@/2`D<&]S("L@)'1A9U]L96YG=&@["B`@("`@("`@)&QP;W,@
M/2!S=')P;W,H)&-O;G1E;G1S+"`D=%LG92==*3L*("`@("`@("`D;&5N9W1H
M(#T@)&QP;W,@+2`D9G!O<SL*"B`@("`@("`@+R\@17AT<F%C="`F(')E='5R
M;B!T:&4@<W1A=&5M96YT+@H@("`@("`@(')E='5R;B!S=6)S='(H)&-O;G1E
M;G1S+"`D9G!O<RP@)&QE;F=T:"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S97,@9V5T=&5X="!T86=S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;G1E;G1S("!4:&4@=6YP87)S960@8V]N=&5N="!O9B!T:&4@9FEL
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!A<G-E9"!C
M;VYT96YT<R!O9B!T:&4@9V5T=&5X="!B;&]C:W,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]P87)S94=E='1E>'0H)&-O;G1E;G1S*0H@("`@>PH@("`@("`@
M("\O($=E="!T:&4@=&%G<R`F(&QO;W`N"B`@("`@("`@)'0@/2!A<G)A>2@G
M8B<@/3X@)SQG971T97AT/B<L"B`@("`@("`@("`@("`@("`@("`G92<@/3X@
M)SPO9V5T=&5X=#XG*3L*("`@("`@("!W:&EL92`H)'1E>'0@/2`D=&AI<RT^
M7V=E=%-T871E;65N="@D="P@)&-O;G1E;G1S*2D@>PH@("`@("`@("`@("`D
M8V]N=&5N=',@/2!S=')?<F5P;&%C92@D=%LG8B==("X@)'1E>'0@+B`D=%LG
M92==+"!?*"1T97AT*2P@)&-O;G1E;G1S*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1C;VYT96YT<SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E
M<R!B;&]C:R!T86=S+@H@("`@("H*("`@("`J($AE<F4@=V4@<&%R<V4@8FQO
M8VL@=&%G<R!I;B!T:&4@9F]R;3H*("`@("`J"B`@("`@*B`@/&)L;V-K.F%P
M<#IN86UE/@H@("`@("H@("`\<&%R86TZ9F]O/F9O;R!P87)A;65T97(G<R!V
M86QU93PO<&%R86TZ9F]O/@H@("`@("H@("`\<&%R86TZ8F%R/F)A<B!P87)A
M;65T97(G<R!V86QU93PO<&%R86TZ8F%R/@H@("`@("H@("`\<V5R:6%L.F)A
M>CYS.C(Q.B)B87H@<&%R86UE=&5R)W,@=F%L=64B.SPO<V5R:6%L.F)A>CX*
M("`@("`J("`\+V)L;V-K.F%P<#IN86UE/@H@("`@("H*("`@("`J("XN+B!A
M;F0@<F5P;&%C92!T:&5M('=I=&@@<F5N9&5R960@87!P;&EC871I;VX@8FQO
M8VMS+@H@("`@("H*("`@("`J($)L;V-K('!A<F%M971E<G,@87)E('!R;W9I
M9&5D('=I=&@@=&AE(&YE<W1E9"`B<&%R86TZ9F]O(B!A;F0*("`@("`J(")S
M97)I86PZ9F]O(B!T86=S+B`@5&AE('-E<FEA;"US='EL92!T86=S('1A:V4@
M82!S97)I86QI>F5D(%!(4`H@("`@("H@=F%L=64L('-O('EO=2!C86X@=7-E
M(&ET('1O('!R;W9I9&4@87)R87DL(&)O;VQE86XL(&%N9"!C;VUP;&5X"B`@
M("`@*B!T>7!E('!A<F%M971E<G,N("!4:&4@<&%R86TM<W1Y;&4@=&%G<R!P
M<F]V:61E('-T<FEN9R!P87)A;65T97)S+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E
M;G1S("!4:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE(&9I;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@
M;V8@=&AE(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94)L;V-K
M<R@D8V]N=&5N=',I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C
M92@G(3QB;&]C:SHH6V$M>D$M6E\P+3E=*RDZ*%MA+7I!+5I?,"TY72LI/B@N
M*C\I)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"]B;&]C:SHH
M6V$M>D$M6E\P+3E=*RDZ*%MA+7I!+5I?,"TY72LI/B%S92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`B7"1T:&ES+3Y?<&%R<V5";&]C:R@G7%PQ
M)RP@)UQ<,B<L("=<7#,G*2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]N=&5N=',I.PH@("`@?0H*("`@("\J*@H@("`@("H@2&%N9&QE('1H
M92!C;VYT96YT<R!O9B!O;F4@8FQO8VL@=&%G+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5";&]C
M:R@D87!P+"`D;F%M92P@)&-O;G1E;G1S*0H@("`@>PH@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*"B`@("`@("`@+R\@
M56YD;R!P<F5G7W)E<&QA8V4H*2!E;F-O9&EN9R!S=')A;F=E;F5S<RX*("`@
M("`@("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@G7%PB)RP@)R(G+"`D8V]N
M=&5N=',I.PH*("`@("`@("`O+R!&:6YD(&)L;V-K)W,@<&%R86UE=&5R<RX*
M("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@("!I9B`H<')E9U]M
M871C:%]A;&PH)R$\<&%R86TZ*%MA+7I!+5I?,"TY72LI/B@N*C\I)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<\+W!A<F%M.BA;82UZ02U:7S`M
M.5TK*3XA<R<L("1C;VYT96YT<RP@)&UA=&-H97,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%!214=?4T547T]21$52*2D@>PH@("`@("`@("`@("!F
M;W)E86-H("@D;6%T8VAE<R!A<R`D;6%T8V@I('L*("`@("`@("`@("`@("`@
M("1P87)A;7-;)&UA=&-H6S%=72`](&AT;6Q?96YT:71Y7V1E8V]D92@D;6%T
M8VA;,ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("AP
M<F5G7VUA=&-H7V%L;"@G(3QS97)I86PZ*%MA+7I!+5I?,"TY72LI/B@N*C\I
M)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("<\+W-E<FEA;#HH6V$M
M>D$M6E\P+3E=*RD^(7,G+"`D8V]N=&5N=',L("1M871C:&5S+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!04D5'7U-%5%]/4D1%4BDI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&UA=&-H97,@87,@)&UA=&-H*2!["B`@("`@("`@
M("`@("`@("`D<&%R86US6R1M871C:%LQ75T@/2!U;G-E<FEA;&EZ92AH=&UL
M7V5N=&ET>5]D96-O9&4H)&UA=&-H6S)=*2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O($-O;G-T<G5C="!T:&4@8FQO8VLN"B`@("`@
M("`@)&)L;V-K(#T@)DAO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ.F=E=$)L;V-K
M*"1A<'`L("1N86UE+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D8FQO
M8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)')E<W5L="`]("<\
M<W1R;VYG/B<@+B!S<')I;G1F*%\H(D5R<F]R(&-R96%T:6YG(&)L;V-K.B`E
M<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B
M;&]C:RT^9V5T365S<V%G92@I*2`N("<\+W-T<F]N9SXG.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`D8FQO8VLM/F=E=$-O;G1E
M;G0H*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]("<\<W1R;VYG/B<@
M+B!S<')I;G1F*%\H(D5R<F]R(&=E='1I;F<@8V]N=&5N=#H@)7,B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L
M="T^9V5T365S<V%G92@I*2`N("<\+W-T<F]N9SXG.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!A<G-E<R!A(&=I=F5N(&EF('-T871E;65N="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T86<@("`@("`@5&AE(&YA;64@;V8@=&AE(&EF(&)L;V-K
M('1O('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@(%1H
M92!U;G!A<G-E9"!C;VYT96YT<R!O9B!T:&4@:68@8FQO8VLN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N=&5N=',@;V8@
M=&AE(&EF(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5)9B@D
M=&%G+"`D8V]N=&5N=',L("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@("\O
M($=E="!T:&4@=&%G<R`F(&EF('-T871E;65N="X*("`@("`@("`D="`]("1T
M:&ES+3Y?9V5T5&%G<R@D=&%G+"`G:68G*3L*("`@("`@("`D970@/2`D=&AI
M<RT^7V=E=%1A9W,H)'1A9RP@)V5L<V4G*3L*"B`@("`@("`@+R\@97AP;&]D
M92!T:&4@=&%G+"!S;R!W92!H879E('1H92!C;W)R96-T(&ME>7,@9F]R('1H
M92!A<G)A>0H@("`@("`@(&EF("AI<W-E="@D:V5Y*2D@>PH@("`@("`@("`@
M("!L:7-T*"1T9RP@)&LI(#T@97AP;&]D92@G+B<L("1T86<I.PH@("`@("`@
M('T*("`@("`@("!W:&EL92`H*"1I9B`]("1T:&ES+3Y?9V5T4W1A=&5M96YT
M*"1T+"`D8V]N=&5N=',I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@+R\@
M0VAE8VL@9F]R(&5L<V4@<W1A=&5M96YT+@H@("`@("`@("`@("!I9B`H)&5L
M<V4@/2`D=&AI<RT^7V=E=%-T871E;65N="@D970L("1I9BDI('L*("`@("`@
M("`@("`@("`@("\O(%!R;V-E<W,@=&AE(&EF('-T871E;65N="X*("`@("`@
M("`@("`@("`@(&EF("@H:7-S970H)&ME>2D@)B8@)'1H:7,M/E]I9G-;)'1G
M75LD:V5Y75LD:UTI('Q\"B`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1T
M:&ES+3Y?:69S6R1T86==*2`F)B`D=&AI<RT^7VEF<ULD=&%G72DI('L*("`@
M("`@("`@("`@("`@("`@("`D<F5P;&%C92`]('-T<E]R97!L86-E*"1E=%LG
M8B==("X@)&5L<V4@+B`D971;)V4G72P@)R<L("1I9BD["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R97!L86-E(#T@
M)&5L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`O+R!0<F]C97-S('1H92!I9B!S=&%T96UE;G0N
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&ME>2DI('L*("`@("`@("`@
M("`@("`@("`@("`D<F5P;&%C92`]("1T:&ES+3Y?:69S6R1T9UU;)&ME>5U;
M)&M=(#\@)&EF(#H@;G5L;#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)')E<&QA8V4@/2`D=&AI<RT^7VEF<ULD=&%G
M72`_("1I9B`Z(&YU;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\O(%!A<G-E('1H92!T96UP;&%T92X*("`@("`@
M("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1;)V(G72`N("1I9B`N
M("1T6R=E)UTL("1R97!L86-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4F5T=7)N('!A<G-E9"!T96UP;&%T92X*("`@("`@("!R971U<FX@)&-O;G1E
M;G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4&%R<V5S('1H92!G:79E;B!A
M<G)A>2!F;W(@86YY(&QO;W!S(&]R(&]T:&5R('5S97,@;V8@=&AE(&%R<F%Y
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1A9R`@("`@("!4:&4@;F%M92!O9B!T:&4@;&]O
M<"!T;R!P87)S92X*("`@("`J($!P87)A;2!A<G)A>2`@)&%R<F%Y("`@("!4
M:&4@=F%L=65S(&9O<B!T:&4@;&]O<"X*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;G1E;G1S("!4:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE(&QO;W`N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)S960@8V]N
M=&5N=',@;V8@=&AE(&QO;W`N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S
M94QO;W`H)'1A9RP@)&%R<F%Y+"`D8V]N=&5N=',I"B`@("!["B`@("`@("`@
M+R\@1V5T('1H92!T86=S("8@;&]O<"X*("`@("`@("`D="`]("1T:&ES+3Y?
M9V5T5&%G<R@D=&%G+"`G;&]O<"<I.PH@("`@("`@("1L;V]P(#T@)'1H:7,M
M/E]G9713=&%T96UE;G0H)'0L("1C;VYT96YT<RD["@H@("`@("`@("\O(%-E
M92!I9B!W92!H879E(&$@9&EV:61E<BX*("`@("`@("`D;"`]("1T:&ES+3Y?
M9V5T5&%G<R@D=&%G+"`G9&EV:61E<B<I.PH@("`@("`@("1D:79I9&5R(#T@
M)'1H:7,M/E]G9713=&%T96UE;G0H)&PL("1L;V]P*3L*("`@("`@("`D8V]N
M=&5N=',@/2!S=')?<F5P;&%C92@D;%LG8B==("X@)&1I=FED97(@+B`D;%LG
M92==+"`G)RP@)&-O;G1E;G1S*3L*"B`@("`@("`@+R\@4')O8V5S<R!T:&4@
M87)R87DN"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D<&%R<V5D(#T@)R<[
M"B`@("`@("`@("`@("1F:7)S="`]('1R=64["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1V86QU92D@?'P@:7-?;V)J96-T*"1V86QU92DI
M('L*("`@("`@("`@("`@("`@("`@("`D:2`]("1L;V]P.PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1K97DI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D:V5Y,B`]/B`D=F%L
M=64R*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1V86QU93(I("8F("%I<U]O8FIE8W0H)'9A;'5E,BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!297!L86-E(&%S<V]C:6%T
M:79E(&%R<F%Y('1A9W,N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%A7W1A9R`]("1T86<@+B`G+B<@+B`D:V5Y,CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:2`]('-T<E]R97!L86-E*"1T:&ES+3Y?
M9V5T5&%G*"1A85]T86<I+"`D=F%L=64R+"`D:2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D=&%G+"`G+B<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@H)'!O<R`A/3T@
M9F%L<V4I("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("%E;7!T>2@D=&AI<RT^7VEF<UMS=6)S='(H)'1A9RP@,"P@)'!O<RE=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEF<ULD86%?=&%G72`]("1V86QU93(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I(#T@)'1H:7,M/E]P87)S94EF*"1A85]T86<L
M("1I*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]I9G-;)&%A7W1A9UTI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VAE
M8VL@=&\@<V5E(&EF(&ET)W,@82!N97-T960@;&]O<"X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:2`]("1T:&ES+3Y?<&%R<V5,;V]P*"1T
M86<@+B`G+B<@+B`D:V5Y,BP@)'9A;'5E,BP@)&DI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1I(#T@
M<W1R7W)E<&QA8V4H)'1H:7,M/E]G971486<H)'1A9RDL("1K97DL("1I*3L*
M("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]S=')I;F<H)&ME>2D@)B8@
M(6ES7V%R<F%Y*"1V86QU92D@)B8@(6ES7V]B:F5C="@D=F%L=64I*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'1H
M:7,M/E]G971486<H)'1A9R`N("<N)R`N("1K97DI+"`D=F%L=64L("1C;VYT
M96YT<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1V
M86QU92D@)B8@(6ES7V]B:F5C="@D=F%L=64I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&D@/2!S=')?<F5P;&%C92@D=&AI<RT^7V=E=%1A9R@D=&%G("X@
M)R<I+"`D=F%L=64L("1L;V]P*3L*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&D@/2!N=6QL.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\O(%!A<G-E(&-O;F1I=&EO;G,@:6X@
M=&AE(&%R<F%Y+@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7VEF<ULD=&%G75LD:V5Y72D@)B8@:7-?87)R87DH)'1H:7,M/E]I9G-;)'1A
M9UU;)&ME>5TI("8F("1T:&ES+3Y?:69S6R1T86==6R1K97E=*2!["B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I9G-;)'1A9UU;)&ME
M>5T@87,@)&-486<@/3X@)&-686QU92D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:2`]("1T:&ES+3Y?<&%R<V5)9B@D=&%G("X@)RXG("X@)&-486<L
M("1I+"`D:V5Y*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`@("`@+R\@061D('1H92!P87)S960@:71E
M<F%T:6]N+@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I*2D@>PH@("`@
M("`@("`@("`@("`@("`@("\O($EF(&ET)W,@;F]T('1H92!F:7)S="!T:6UE
M('1H<F]U9V@L('!R969I>"!T:&4*("`@("`@("`@("`@("`@("`@("`O+R!L
M;V]P(&1I=FED97(L(&EF('1H97)E(&ES(&]N92X*("`@("`@("`@("`@("`@
M("`@("!I9B`H(21F:7)S="D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M:2`]("1D:79I9&5R("X@)&D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1P87)S960@+CT@<G1R:6TH)&DI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O($YO(&QO;F=E<B!T:&4@
M9FER<W0@=&EM92!T:')O=6=H+@H@("`@("`@("`@("`@("`@)&9I<G-T(#T@
M9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%)E<&QA8V4@
M=&AE('!A<G-E9"!P:65C97,@;V8@=&AE('1E;7!L871E+@H@("`@("`@("`@
M("`D8V]N=&5N=',@/2!S=')?<F5P;&%C92@D=%LG8B==("X@)&QO;W`@+B`D
M=%LG92==+"`D<&%R<V5D+"`D8V]N=&5N=',I.PH@("`@("`@('T@=VAI;&4@
M*"1L;V]P(#T@)'1H:7,M/E]G9713=&%T96UE;G0H)'0L("1C;VYT96YT<RDI
M.PH*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&%R<V5S('1H92!G:79E;B!C87-E(&QO;W`@*&-L;V]P*2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T86<@("`@("`@5&AE(&YA;64@;V8@=&AE(&-L;V]P('1O
M('!A<G-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D87)R87D@("`@(%1H92!V
M86QU97,@9F]R('1H92!C;&]O<"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;G1E;G1S("!4:&4@=6YP87)S960@8V]N=&5N=',@;V8@=&AE(&-L;V]P+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<&%R<V5D(&-O;G1E
M;G1S(&]F('1H92!C;&]O<"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E
M0VQO;W`H)'1A9RP@)&%R<F%Y+"`D8V]N=&5N=',I"B`@("!["B`@("`@("`@
M+R\@1V5T('1H92!T86=S("8@8VQO;W`N"B`@("`@("`@)'0@/2`D=&AI<RT^
M7V=E=%1A9W,H)'1A9RP@)V-L;V]P)RD["@H@("`@("`@('=H:6QE("@D;&]O
M<"`]("1T:&ES+3Y?9V5T4W1A=&5M96YT*"1T+"`D8V]N=&5N=',I*2!["B`@
M("`@("`@("`@("\O(%-E="!U<"!T:&4@8V%S97,N"B`@("`@("`@("`@("1A
M<G)A>5LG8V%S97,G75M=(#T@)V1E9F%U;'0G.PH@("`@("`@("`@("`D8V%S
M95]C;VYT96YT(#T@87)R87DH*3L*"B`@("`@("`@("`@("\O($=E="!T:&4@
M8V%S92!S=')I;F=S+@H@("`@("`@("`@("!F;W)E86-H("@D87)R87E;)V-A
M<V5S)UT@87,@)&-A<V4I('L*("`@("`@("`@("`@("`@("1C=&%G<ULD8V%S
M95T@/2`D=&AI<RT^7V=E=%1A9W,H)&-A<V4L("=C87-E)RD["B`@("`@("`@
M("`@("`@("`D8V%S95]C;VYT96YT6R1C87-E72`]("1T:&ES+3Y?9V5T4W1A
M=&5M96YT*"1C=&%G<ULD8V%S95TL("1L;V]P*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@4')O8V5S<R!T:&4@8VQO;W`N"B`@("`@("`@("`@
M("1P87)S960@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y6R=A
M<G)A>2==(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?;G5M97)I8R@D:V5Y*2`F)B`H:7-?87)R87DH)'9A;'5E*2!\?"!I
M<U]O8FIE8W0H)'9A;'5E*2DI('L*("`@("`@("`@("`@("`@("`@("`O+R!3
M970@=7`@=&AE(&-A<V5S+@H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=F%L=65;)V-A<V4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-U<G)E;G1?8V%S92`]("1V86QU95LG8V%S92==.PH@("`@("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R
M96YT7V-A<V4@/2`G9&5F875L="<["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1V86QU95LG8V%S92==*3L*("`@
M("`@("`@("`@("`@("`@("`D:2`]("1C87-E7V-O;G1E;G1;)&-U<G)E;G1?
M8V%S95T["@H@("`@("`@("`@("`@("`@("`@("\O($QO;W`@=&AR;W5G:"!E
M86-H('9A;'5E+@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU
M92!A<R`D:V5Y,B`]/B`D=F%L=64R*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D=F%L=64R*2!\?"!I<U]O8FIE8W0H)'9A;'5E
M,BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I(#T@)'1H:7,M
M/E]P87)S94QO;W`H)'1A9R`N("<N)R`N("1K97DR+"`D=F%L=64R+"`D:2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:2`]('-T<E]R97!L86-E*"1T:&ES+3Y?9V5T
M5&%G*"1T86<@+B`G+B<@+B`D:V5Y,BDL("1V86QU93(L("1I*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!!9&0@=&AE('!A
M<G-E9"!I=&5R871I;VXN"B`@("`@("`@("`@("`@("`D<&%R<V5D("X](')T
M<FEM*"1I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4&%R<V4@
M=&AE(&-L;V]P+@H@("`@("`@("`@("`D8V]N=&5N=',@/2!S=')?<F5P;&%C
M92@D=%LG8B==("X@)&QO;W`@+B`D=%LG92==+"`D<&%R<V5D+"`D8V]N=&5N
M=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;VYT96YT<SL*("`@
M('T*"B`@("`O*BH*("`@("`J($9E=&-H('1H92!C;VYT96YT<R!O9B!A('1E
M;7!L871E(&EN=&\@)'1H:7,M/E]T96UP;&%T93L@8V%C:&4*("`@("`J('1H
M92!F:6QE;F%M92!I;B`D=&AI<RT^7W1E;7!L871E1FEL92X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE;F%M92`@3&]C871I;VX@;V8@=&5M<&QA=&4@9FEL92!O;B!D
M:7-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]A9&5D
M('1E;7!L871E(&-O;G1E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9714
M96UP;&%T92@D9FEL96YA;64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D9FEL96YA;64I("8F("@D9FEL96YA;64@(3T@)'1H:7,M/E]T
M96UP;&%T949I;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?=&5M<&QA=&4@
M/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES
M+3Y?=&5M<&QA=&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W1E
M;7!L871E.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T('1H92!C;VYT96YT
M<R!O9B!T:&4@9FEL92X*("`@("`@("`D9FEL92`]("1T:&ES+3Y?8F%S97!A
M=&@@+B`D9FEL96YA;64["B`@("`@("`@)&-O;G1E;G1S(#T@0&9I;&5?9V5T
M7V-O;G1E;G1S*"1F:6QE*3L*("`@("`@("!I9B`H)&-O;G1E;G1S(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")496UP;&%T92!<(B5S7"(@;F]T(&9O=6YD+B(I+"`D9FEL92DI.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]T96UP;&%T92`]("1C;VYT96YT<SL*
M("`@("`@("`D=&AI<RT^7W1E;7!L871E1FEL92`]("1F:6QE;F%M93L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=&5M<&QA=&4["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+G!H<```````
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,T,S$P(#$P
M-3$U-#,T,30P(#`R,3$Q,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E(&=R87!H:6YG
M('-U:71E+@H@*@H@*B!0<F]V:61E<R!A('-E="!O9B!G<F%P:"!B86-K96YD
M<R!A;F0@;65T:&]D<R!F;W(@8W)E871I;F<@9W)A<&AS(&%S"B`J($A434P@
M=&%B;&5S+"!35D<@:6UA9V5S+"!E=&,N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T=R87!H+T=R87!H+G!H<"QV(#$N,C<N,3`N-R`R,#`V+S`Q+S`Q(#(Q
M.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'
M<F%P:`H@*B\*8VQA<W,@2&]R9&5?1W)A<&@@>PH*("`@("\J*@H@("`@("H@
M5&AE($AO<F1E7TEM86=E(&EN<W1A;F-E('1H870@=V4@87)E(&1R87=I;F<@
M=&AE(&=R87!H('1O+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D
M"B`@("`@*B!`=F%R($AO<F1E7TEM86=E"B`@("`@*B\*("`@('9A<B`D:6UG
M.PH*("`@('9A<B`D7V=R87!H<R`](&%R<F%Y*"D["@H@("`@=F%R("1?:&5I
M9VAT.PH@("`@=F%R("1?=VED=&@["@H@("`@=F%R("1?=&ET;&4@/2`G)SL*
M"B`@("!V87(@)%]B86-K9W)O=6YD(#T@)VQI9VAT9W)A>2<["B`@("!V87(@
M)%]T:71L949O;G0@/2`G<V%N<RUS97)I9B<["B`@("!V87(@)%]L86)E;$9O
M;G0@/2`G<V%N<RUS97)I9B<["B`@("!V87(@)%]A>&ES1F]N="`]("=M;VYO
M<W!A8V4G.PH*("`@('9A<B`D7W!A9&1I;F=,969T(#T@-C`["B`@("!V87(@
M)%]P861D:6YG0F]T=&]M(#T@-#`["B`@("!V87(@)%]P861D:6YG5&]P(#T@
M,S`["B`@("!V87(@)%]P861D:6YG4FEG:'0@/2`R,#L*"B`@("!V87(@)%]O
M9F9S971'<FED6"`](#`["@H@("`@=F%R("1?:6UG5'EP92`]("=G9"<["@H@
M("`@=F%R("1?9&%T82`](&%R<F%Y*"=X)R`]/B!A<G)A>2@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("=Y)R`]/B!A<G)A>2@I*3L*"B`@("!V87(@)%]T
M;7!D:7(["@H@("`@=F%R("1?<&QO=',@/2!A<G)A>2@I.PH@("`@=F%R("1?
M8VAA<G1S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:"@D
M<&%R86US*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'!A<F%M<ULG=&5M
M<"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1M<&1I<B`]("1P87)A;7-;
M)W1E;7`G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)'!A<F%M
M<ULG=VED=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]W:61T:"`]("1P
M87)A;7-;)W=I9'1H)UT["B`@("`@("`@("`@("1T:&ES+3Y?:&5I9VAT(#T@
M)'!A<F%M<ULG:&5I9VAT)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M
M<'1Y*"1P87)A;7-;)VEM9U1Y<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]I;6=4>7!E(#T@)'!A<F%M<ULG:6UG5'EP92==.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B`F861D4&QO="@D<&QO=%1Y<&4L("1P;&]T4&%R
M86US*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7V-H87)T<RDI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TUI>&EN
M9R!O9B!#:&%R=',@86YD(%!L;W1S(&ES(&YO="!A;&QO=V5D+B<I.PH@("`@
M("`@('T*"B`@("`@("`@)'!L;W14>7!E(#T@8F%S96YA;64H)'!L;W14>7!E
M*3L*("`@("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]'<F%P:"]0;&]T+R<@+B`D<&QO=%1Y<&4@+B`G+G!H<"<["@H@("`@("`@
M("1C;&%S<R`]("=(;W)D95]'<F%P:%]0;&]T7R<@+B`D<&QO=%1Y<&4["B`@
M("`@("`@:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@
M("1P;&]T(#T@)FYE=R`D8VQA<W,H)'1H:7,L("1P;&]T4&%R86US*3L*("`@
M("`@("`@("`@)'1H:7,M/E]P;&]T<UM=(#T@)B1P;&]T.PH@("`@("`@("`@
M("!R971U<FX@)'!L;W0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!L;W0@='EP92!N;W0@9F]U;F0G
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@)F%D9$-H87)T*"1C
M:&%R=%1Y<&4L("1C:&%R=%!A<F%M<RD*("`@('L*("`@("`@("!I9B`H8V]U
M;G0H)'1H:7,M/E]P;&]T<RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)TUI>&EN9R!O9B!#:&%R=',@86YD(%!L;W1S(&ES(&YO
M="!A;&QO=V5D+B<I.PH@("`@("`@('T*"B`@("`@("`@)&-H87)T5'EP92`]
M(&)A<V5N86UE*"1C:&%R=%1Y<&4I.PH@("`@("`@($!I;F-L=61E7V]N8V4@
M9&ER;F%M92A?7T9)3$5?7RD@+B`G+T=R87!H+T-H87)T+R<@+B`D8VAA<G14
M>7!E("X@)RYP:'`G.PH*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1W)A<&A?
M0VAA<G1?)R`N("1C:&%R=%1Y<&4["B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1C:&%R="`]("9N97<@)&-L87-S
M*"1T:&ES+"`D8VAA<G1087)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^7V-H
M87)T<UM=(#T@)B1C:&%R=#L*("`@("`@("`@("`@<F5T=7)N("1C:&%R=#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G0VAA<G0@='EP92!N;W0@9F]U;F0G*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@861D6$1A=&$H)&1A=&$I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]D871A6R=X)UT@/2`D9&%T83L*("`@('T*"B`@("!F=6YC
M=&EO;B!A9&191&%T82@D9&%T82P@)&YA;64@/2`G)RD*("`@('L*("`@("`@
M("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@;60U
M*'-E<FEA;&EZ92@D9&%T82DI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M7V1A=&%;)WDG75LD;F%M95T@/2`D9&%T83L*("`@("`@("!R971U<FX@)&YA
M;64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T*"1P87)A;2D*("`@('L*("`@
M("`@("`D:V5Y(#T@)U\G("X@)'!A<F%M.PH@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^)&ME>2D@/R`D=&AI<RT^)&ME>2`Z(&YU;&P["B`@("!]"@H@
M("`@9G5N8W1I;VX@<V5T*"1P87)A;2P@)'9A;'5E*0H@("`@>PH@("`@("`@
M("1K97D@/2`G7R<@+B`D<&%R86T["B`@("`@("`@)'1H:7,M/B1K97D@/2`D
M=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86-H92!T:&4@:6UA9V4@
M86YD(')E='5R;B!A(&QI;FL@=&\@=FEE=R!I="!O=70@;V8@=&AE(&-A8VAE
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-P;&%Y*"D*("`@('L*("`@("`@
M("!G;&]B86P@)&-O;F8L("1R96=I<W1R>3L*("`@("`@("!R97%U:7)E7V]N
M8V4@)TAO<F1E+T-A8VAE+G!H<"<["B`@("`@("`@)&-A8VAE(#T@)DAO<F1E
M7T-A8VAE.CIS:6YG;&5T;VXH)&-O;F9;)V-A8VAE)UU;)V1R:79E<B==+"!(
M;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=C86-H92<L("1C;VYF6R=C86-H92==
M6R=D<FEV97(G72DI.PH*("`@("`@("`D=&AI<RT^:6YI=&EA;&EZ92@I.PH*
M("`@("`@("`D8VED(#T@;60U*'-E<FEA;&EZ92@D=&AI<RDI.PH@("`@("`@
M("1C86-H92T^<V5T*"1C:60L('-E<FEA;&EZ92AA<G)A>2@G9&%T82<@/3X@
M)'1H:7,M/F1R87<H9F%L<V4I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G8W1Y<&4G(#T^("1T:&ES+3YI;6<M/F=E=$-O
M;G1E;G14>7!E*"DI*2D["@H@("`@("`@("1U<FP@/2!(;W)D93HZ=7)L*"1R
M96=I<W1R>2T^9V5T*"=W96)R;V]T)RP@)VAO<F1E)RD@+B`G+W-E<G9I8V5S
M+V-A8VAE=FEE=RYP:'`G*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R
M86UE=&5R*"1U<FPL("=C:60G+"`D8VED*3L*"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YI;6<M/F=E=$QI;FLH)'5R;"P@)'1H:7,M/E]T:71L92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!0<F]C97-S(&%L;"!O9B!T:&4@9&%T82!S971S
M(&%N9"!S970@9W)A<&@@<')O<&5R=&EE<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:6YI=&EA;&EZ92@D;6EN62`](&9A;'-E+"`D<W1E<$QA8F5L<UD@/2!F
M86QS92D*("`@('L*("`@("`@("`O+R!,;V%D(&$@2&]R9&5?26UA9V4@8V%N
M=F%S('1O(&1R87<@;VXN"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])
M;6%G92YP:'`G.PH@("`@("`@("1T:&ES+3YI;6<@/2`F2&]R9&5?26UA9V4Z
M.F9A8W1O<GDH)'1H:7,M/E]I;6=4>7!E+"!A<G)A>2@G:&5I9VAT)R`]/B`D
M=&AI<RT^7VAE:6=H="P@)W=I9'1H)R`]/B`D=&AI<RT^7W=I9'1H+"`G=&5M
M<"<@/3X@)'1H:7,M/E]T;7!D:7(I*3L*"B`@("`@("`@+R\@5&]T86P@:6UA
M9V4@86YD(&=R87!H(&%R96$@9&EM96YS:6]N<RX*("`@("`@("`D=VED=&@@
M/2`D=&AI<RT^7W=I9'1H("T@,3L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M
M/E]H96EG:'0@+2`Q.PH*("`@("`@("`D=&AI<RT^7V=R87!H5&]P(#T@)'1H
M:7,M/E]P861D:6YG5&]P.PH@("`@("`@("1T:&ES+3Y?9W)A<&A";W1T;VT@
M/2`D=&AI<RT^7VAE:6=H="`M(#$@+2`H)'1H:7,M/E]P861D:6YG5&]P("L@
M)'1H:7,M/E]P861D:6YG0F]T=&]M*3L*("`@("`@("`D=&AI<RT^7V=R87!H
M3&5F="`]("1T:&ES+3Y?<&%D9&EN9TQE9G0["B`@("`@("`@)'1H:7,M/E]G
M<F%P:%)I9VAT(#T@)'1H:7,M/E]W:61T:"`M("1T:&ES+3Y?<&%D9&EN9U)I
M9VAT("T@,3L*("`@("`@("`D=&AI<RT^7V=R87!H2&5I9VAT(#T@)'1H:7,M
M/E]G<F%P:$)O='1O;2`M("1T:&ES+3Y?9W)A<&A4;W`["B`@("`@("`@)'1H
M:7,M/E]G<F%P:%=I9'1H(#T@)'1H:7,M/E]G<F%P:%)I9VAT("T@)'1H:7,M
M/E]G<F%P:$QE9G0["@H@("`@("`@("1T:&ES+3Y?9W)I9%@@/2!M:6XH8V]U
M;G0H)'1H:7,M/E]D871A6R=X)UTI+"!R;W5N9"@D=&AI<RT^7V=R87!H5VED
M=&@@+R`T,"DI.PH@("`@("`@(&EF("@A)'1H:7,M/E]G<FED6"D@>PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(&1A=&$N)RD["B`@("`@("`@
M?0H*("`@("`@("`O+R!&:6YD('1H92!R86YG92!O9B!A;&P@>2!V86QU97,N
M"B`@("`@("`@)'ED871A(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V=R
M:619(#T@,#L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&%;)WDG72!A
M<R`D9&%T82D@>PH@("`@("`@("`@("`D=&AI<RT^7V=R:619(#T@;6%X*"1T
M:&ES+3Y?9W)I9%DL(&-O=6YT*"1D871A*2D["B`@("`@("`@("`@("1Y9&%T
M82`](&%R<F%Y7VUE<F=E*"1Y9&%T82P@)&1A=&$I.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]M87A8(#T@8V]U;G0H)'1H:7,M/E]D871A6R=X)UTI
M.PH@("`@("`@(&QI<W0H)'1H:7,M/E]M:6Y9+"`D=&AI<RT^7VUA>%DI(#T@
M)'1H:7,M/E]F:6YD4F%N9V4H)'ED871A*3L*("`@("`@("!I9B`H)&UI;ED@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?;6EN62`]("1M:6Y9
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]D:69F62`]("1T:&ES+3Y?
M;6%X62`M("1T:&ES+3Y?;6EN63L*"B`@("`@("`@+R\@0V%L8W5L871E('1H
M92!N=6UB97(@;V8@62!G<FED;&EN97,@*&%N9"!T:'5S+"!L86)E;',I('1O
M"B`@("`@("`@+R\@<VAO=RX@5')Y('1O(&UA:V4@<W5R92!W92!D;VXG="!E
M;F0@=7`@=VET:"!T;V\@9&5N<V4@80H@("`@("`@("\O(&=R:60L(&)U="!A
M;'-O(&UA:V4@<W5R92!T:&%T('=E(&AA=F4@82!F97<@9W)I9"!L:6YE<R!T
M;PH@("`@("`@("\O(&)R96%K('5P('-M86QL(&1A=&%S971S+@H@("`@("`@
M(&EF("@D<W1E<$QA8F5L<UD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?9W)I9%D@/2!M87@H;6EN*"1T:&ES+3Y?9W)I9%DL(&9L;V]R*"1T
M:&ES+3Y?9W)A<&A(96EG:'0@+R`S,"DI+"!F;&]O<B@D=&AI<RT^7V=R87!H
M2&5I9VAT("\@-C`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7V=R:619(#T@9FQO;W(H*"1T:&ES+3Y?;6%X62`M("1T:&ES+3Y?
M;6EN62D@+R`D<W1E<$QA8F5L<UDI.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"@D=&AI<RT^7VUA>%D@+2`D=&AI<RT^7VUI;EDI(#T](#`I('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=.;R!R86YG92!T;R!G<F%P:"X@0VAE
M8VL@9&%T82XG*3L*("`@("`@("!]"@H@("`@("`@("\O($9O<FUA="!T97AT
M(&9O<B!L86)E;&EN9R!T:&4@62!A>&ES+@H@("`@("`@(&EF("@D<W1E<$QA
M8F5L<UD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1D96QT84QA8F5L<UD@
M/2`H)'1H:7,M/E]M87A9("T@)'1H:7,M/E]M:6Y9*2`O("@D=&AI<RT^7V=R
M:619*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&5L=&%,86)E
M;'-9(#T@)'-T97!,86)E;'-9.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P]("1T:&ES+3Y?9W)I9%D[("1I*RLI('L*("`@("`@("`@
M("`@)'1E>'0@/2`D=&AI<RT^7VUI;ED@*R`H)&1E;'1A3&%B96QS62`J("1I
M*3L*("`@("`@("`@("`@)'1H:7,M/E]L86)E;'-96R1I72`](&YU;6)E<E]F
M;W)M870H)'1E>'0L(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]L86)E;'-9*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(N<&AP)SL*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)TYO(%D@87AI<R!D871A+B<I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M0V%L8W5L871E('1H92!S<&%C:6YG(&9O<B!T:6-K<R!A;F0@9W)I9"!L:6YE
M<RX*("`@("`@("`D9&5N;VUI;F%T;W(@/2`D=&AI<RT^7VUA>%@@+2`Q("L@
M*#(@*B`D=&AI<RT^7V]F9G-E=$=R:618*3L*("`@("`@("!I9B`H)&1E;F]M
M:6YA=&]R(#T](#`I('L*("`@("`@("`@("`@)&1E;F]M:6YA=&]R(#T@,3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]F86-T;W)8(#T@)'1H:7,M/E]G
M<F%P:%=I9'1H("\@)&1E;F]M:6YA=&]R.PH@("`@("`@("1T:&ES+3Y?9F%C
M=&]R62`]("1T:&ES+3Y?9W)A<&A(96EG:'0@+R`D=&AI<RT^7V1I9F99.PH*
M("`@("`@("`D9&5N;VUI;F%T;W(@/2`D=&AI<RT^7V=R:618("T@,2`K(#(@
M*B`D=&AI<RT^7V]F9G-E=$=R:618.PH@("`@("`@(&EF("@D9&5N;VUI;F%T
M;W(@/3T@,"D@>PH@("`@("`@("`@("`D9&5N;VUI;F%T;W(@/2`Q.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7V1E;'1A5&EC:W-8(#T@*"1T:&ES+3Y?
M9W)A<&A7:61T:"`O("1D96YO;6EN871O<BD@+R`D=&AI<RT^7V9A8W1O<E@[
M"B`@("`@("`@:68@*"1S=&5P3&%B96QS62`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@)'1H:7,M/E]D96QT851I8VMS62`]("@D=&AI<RT^7V=R87!H2&5I
M9VAT("\@)'1H:7,M/E]G<FED62D@+R`D=&AI<RT^7V9A8W1O<ED["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]D96QT851I8VMS62`]
M("1S=&5P3&%B96QS63L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&1R87<H)&1I<W!L87D@/2!T<G5E+"`D
M;6EN62`](&9A;'-E+"`D9&5L=&%,86)E;'-9(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YI;FET:6%L:7IE*"1M:6Y9+"`D9&5L
M=&%,86)E;'-9*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M('T*"B`@("`@("`@)'!L;W1S(#T@8V]U;G0H)'1H:7,M/E]P;&]T<RD["B`@
M("`@("`@)&-H87)T<R`](&-O=6YT*"1T:&ES+3Y?8VAA<G1S*3L*"B`@("`@
M("`@:68@*"1P;&]T<RD@>PH@("`@("`@("`@("`D=&AI<RT^9')A=T)A8VMG
M<F]U;F0H*3L*("`@("`@("`@("`@)'1H:7,M/F1R87=4:71L92@I.PH@("`@
M("`@("`@("`D=&AI<RT^9')A=T=R:618*"D["B`@("`@("`@("`@("1T:&ES
M+3YD<F%W1W)I9%DH*3L*("`@("`@("`@("`@)'1H:7,M/F1R87=0;&]T0F]X
M*"D["B`@("`@("`@("`@("1T:&ES+3YD<F%W3&%B96QS6"@I.PH@("`@("`@
M("`@("`D=&AI<RT^9')A=TQA8F5L<UDH*3L*"B`@("`@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\("1P;&]T<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P;&]T<ULD:5TM/F1R87<H)'1H:7,M/E]M:6Y9*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("@D8VAA<G1S*2!["B`@("`@("`@
M("`@("1T:&ES+3YD<F%W5&ET;&4H*3L*"B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\("1C:&%R=',[("1I*RLI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAA<G1S6R1I72T^9')A=R@I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&1I<W!L87D@/R`D=&AI<RT^:6UG+3YD
M:7-P;&%Y*"D@.B`D=&AI<RT^:6UG+3YR87<H*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!D<F%W0F%C:V=R;W5N9"@I"B`@("!["B`@("`@("`@)'1H:7,M/FEM
M9RT^<F5C=&%N9VQE*#`L(#`L("1T:&ES+3Y?=VED=&@@+2`Q+"`D=&AI<RT^
M7VAE:6=H="`M(#$L("=B;&%C:R<L("1T:&ES+3Y?8F%C:V=R;W5N9"D["B`@
M("`@("`@)'1H:7,M/FEM9RT^<F5C=&%N9VQE*"1T:&ES+3Y?9W)A<&A,969T
M+"`D=&AI<RT^7V=R87!H5&]P+"`D=&AI<RT^7V=R87!H5VED=&@L("1T:&ES
M+3Y?9W)A<&A(96EG:'0L("=B;&%C:R<L("=W:&ET92<I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=R!A(&)O>"!A<F]U;F0@=&AE('!L;W0@87)E82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9')A=U!L;W1";W@H*0H@("`@>PH@("`@
M("`@("1T:&ES+3YI;6<M/G)E8W1A;F=L92@D=&AI<RT^7V=R87!H3&5F="P@
M)'1H:7,M/E]G<F%P:%1O<"P@)'1H:7,M/E]G<F%P:%=I9'1H+"`D=&AI<RT^
M7V=R87!H2&5I9VAT+"`G8FQA8VLG*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1R87=S(&=R:60@;&EN97,@9G)O;2!T;W`@=&\@8F]T=&]M(&]N('1H92!I
M;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@9')A=T=R:618*"D*("`@('L*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^7V=R:618.R`D:2LK
M*2!["B`@("`@("`@("`@("1X(#T@)'1H:7,M/G1R86YS;&%T95@H)'1H:7,M
M/E]D96QT851I8VMS6"`J("1I*3L*("`@("`@("`@("`@)'1H:7,M/FEM9RT^
M9&%S:&5D3&EN92@D>"P@)'1H:7,M/E]G<F%P:%1O<"P@)'@L("1T:&ES+3Y?
M9W)A<&A";W1T;VTL("=G<F%Y)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1')A=W,@9W)I9"!L:6YE<R!F<F]M(&QE9G0@=&\@<FEG:'0@
M;VX@=&AE(&EM86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D<F%W1W)I9%DH
M*0H@("`@>PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\/2`D=&AI<RT^7V=R
M:619.R`D:2LK*2!["B`@("`@("`@("`@("1Y(#T@)'1H:7,M/G1R86YS;&%T
M95DH)'1H:7,M/E]M:6Y9("L@)'1H:7,M/E]D96QT851I8VMS62`J("1I*3L*
M("`@("`@("`@("`@)'1H:7,M/FEM9RT^9&%S:&5D3&EN92@D=&AI<RT^7V=R
M87!H3&5F="P@)'DL("1T:&ES+3Y?9W)A<&A2:6=H="P@)'DL("=G<F%Y)RD[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!T:&4@=&ET
M;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R87=4:71L92@I"B`@("!["B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W1I=&QE*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^:6UG+3YT97AT*"1T:&ES+3Y?=&ET;&4L("1T:&ES+3Y?9W)A
M<&A,969T("L@*"1T:&ES+3Y?9W)A<&A7:61T:"`O(#(I("T@*"AS=')L96XH
M)'1H:7,M/E]T:71L92D@+R`R*2`J(#<I+"`D=&AI<RT^7V=R87!H5&]P("T@
M,C`L("1T:&ES+3Y?=&ET;&5&;VYT*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$<F%W<R!T:&4@87AI<R!T86<@=&5X="!O=71S:61E('1H
M92!P;&]T=&EN9R!A<F5A(&]N('1H92!X"B`@("`@*B!A>&ES+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D<F%W3&%B96QS6"@I"B`@("!["B`@("`@("`@+R\@
M1')A=R!8(&%X:7,@;&%B96PN"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7WAL86)E;"DI('L*("`@("`@("`@("`@)'@@/2`D=&AI<RT^7V=R87!H3&5F
M="`K("@D=&AI<RT^7V=R87!H5VED=&@@+R`R*2`M("AS=')L96XH)'1H:7,M
M/E]X;&%B96PI("H@,RD["B`@("`@("`@("`@("1Y(#T@)'1H:7,M/E]G<F%P
M:$)O='1O;2`K(#4P.PH@("`@("`@("`@("`D=&AI<RT^:6UG+3YT97AT*"1T
M:&ES+3Y?>&QA8F5L+"`D>"P@)'DL("1T:&ES+3Y?;&%B96Q&;VYT*3L*("`@
M("`@("!]"@H@("`@("`@("1L87-T6"`](#`["B`@("`@("`@)&UI;D1I9F8@
M/2`R,#L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&%;)W@G72!A<R`D
M:2`]/B`D=&5X="D@>PH@("`@("`@("`@("`D>"`]("1T:&ES+3YT<F%N<VQA
M=&58*"1I*3L*("`@("`@("`@("`@:68@*"1X("T@)&QA<W18(#X]("1M:6Y$
M:69F*2!["B`@("`@("`@("`@("`@("`D;&%S=%@@/2`D>#L*("`@("`@("`@
M("`@("`@("1T:&ES+3YI;6<M/G1E>'0H)'1E>'0L("1X("T@-2P@)'1H:7,M
M/E]G<F%P:$)O='1O;2`K("AS=')L96XH)'1E>'0I("H@-RDL("1T:&ES+3Y?
M87AI<T9O;G0L("=B;&%C:R<L("TY,"D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^:6UG+3YL:6YE*"1X+"`D=&AI<RT^7V=R87!H0F]T=&]M("L@,BP@)'@L
M("1T:&ES+3Y?9W)A<&A";W1T;VT@+2`R*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S('1H92!A>&ES('1A
M9R!T97AT(&]U='-I9&4@=&AE('!L;W1T:6YG(&%R96$@;VX@=&AE('D*("`@
M("`J(&%X:7,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R87=,86)E;'-9*"D*
M("`@('L*("`@("`@("`O+R!$<F%W(%D@87AI<R!L86)E;"X*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?>6QA8F5L*2D@>PH@("`@("`@("`@("`D>2`]
M("1T:&ES+3Y?9W)A<&A4;W`@*R`H)'1H:7,M/E]G<F%P:$AE:6=H="`O(#(I
M("L@*"AS=')L96XH)'1H:7,M/E]Y;&%B96PI("\@,BD@*B`U*3L*("`@("`@
M("`@("`@)'1H:7,M/FEM9RT^=&5X="@D=&AI<RT^7WEL86)E;"P@-2P@)'DL
M("1T:&ES+3Y?;&%B96Q&;VYT+"`G8FQA8VLG+"`M.3`I.PH@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L86)E;'-9(&%S("1I(#T^("1L
M86)E;"D@>PH@("`@("`@("`@("`D>2`]("1T:&ES+3YT<F%N<VQA=&59*"1T
M:&ES+3Y?;6EN62`K("1I("H@)'1H:7,M/E]D96QT851I8VMS62D["B`@("`@
M("`@("`@("1T:&ES+3YI;6<M/G1E>'0H)&QA8F5L+"`D=&AI<RT^7V=R87!H
M3&5F="`M("AS=')L96XH)&QA8F5L*2`J(#<I+"`D>2`M(#4L("1T:&ES+3Y?
M87AI<T9O;G0I.PH@("`@("`@("`@("`D=&AI<RT^:6UG+3YL:6YE*"1T:&ES
M+3Y?9W)A<&A,969T("T@,BP@)'DL("1T:&ES+3Y?9W)A<&A,969T("L@,BP@
M)'DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@82!P
M86ER(&]F("AX+'DI(&=R87!H(&-O;W)D:6YA=&5S(&%N9"!R971U<FX@=&AE
M"B`@("`@*B!S8W)E96XM<&EX96P@8V]O<F1I;F%T97,@9F]R('1H96TN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("8D>"`@("`@5&AE('@@<&]S:71I
M;VX@:6X@=V]R;&0@8V]O<F1I;F%T97,N"B`@("`@*B!`<&%R86T@9FQO870@
M)B1Y("`@("!4:&4@>2!P;W-I=&EO;B!I;B!W;W)L9"!C;V]R9&EN871E<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-L871E*"8D>"P@)B1Y*0H@("`@
M>PH@("`@("`@("1X(#T@)'1H:7,M/G1R86YS;&%T95@H)'@I.PH@("`@("`@
M("1Y(#T@)'1H:7,M/G1R86YS;&%T95DH)'DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@5')A;G-L871E('1H92!X(&-O;W)D:6YA=&4@;V8@82!P;VEN="!O
M;B!T:&4@<&QO="!T;R!S8W)E96X*("`@("`J(&-O;W)D:6YA=&5S+@H@("`@
M("H*("`@("`J($!P87)A;2!F;&]A="`D>"`@5&AE('@@=V]R;&0@*'!L;W0I
M(&-O;W)D:6YA=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('1R86YS;&%T95@H
M)'@I"B`@("!["B`@("`@("`@<F5T=7)N("@H)'@@*R`D=&AI<RT^7V]F9G-E
M=$=R:618*2`J("1T:&ES+3Y?9F%C=&]R6"D@*R`D=&AI<RT^7V=R87!H3&5F
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1R86YS;&%T92!T:&4@>2!C;V]R
M9&EN871E(&]F(&$@<&]I;G0@;VX@=&AE('!L;W0@=&\@<V-R965N"B`@("`@
M*B!C;V]R9&EN871E<RX*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'D@
M(%1H92!Y('=O<FQD("AP;&]T*2!C;V]R9&EN871E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!T<F%N<VQA=&59*"1Y*0H@("`@>PH@("`@("`@(&EF("@D>2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G<F%P:$)O='1O;2`M("@H
M)'D@+2`D=&AI<RT^7VUI;EDI("H@)'1H:7,M/E]F86-T;W)9*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]G<F%P:$)O
M='1O;3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD('1H
M92!M:6YI;75M(&%N9"!M87AI;75M('9A;'5E<R!F;W(@82!S970@;V8@9&%T
M82X*("`@("`J"B`@("`@*B!4:&4@)')E<V]L=71I;VX@=F%R:6%B;&4@:7,@
M=7-E9"!F;W(@<F]U;F1I;F<@;6%X:6UU;2!A;F0*("`@("`J(&UI;FEM=6T@
M=F%L=65S+B!)9B!M87AI;75M('9A;'5E(&ES(#@V-#4@=&AE;CH*("`@("`J
M"B`@("`@*B!)9B`D<F5S;VQU=&EO;B!I<R`P+"!T:&5N(&UA>&EM=6T@=F%L
M=64@8F5C;VUE<R`Y,#`P+@H@("`@("H@268@)')E<V]L=71I;VX@:7,@,2P@
M=&AE;B!M87AI;75M('9A;'5E(&)E8V]M97,@.#<P,"X*("`@("`J($EF("1R
M97-O;'5T:6]N(&ES(#(L('1H96X@;6%X:6UU;2!V86QU92!B96-O;65S(#@V
M-3`N"B`@("`@*B!)9B`D<F5S;VQU=&EO;B!I<R`S+"!T:&5N(&UA>&EM=6T@
M=F%L=64@8F5C;VUE<R`X-C0U+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`@)&1A=&$@("`@("`@("!4:&4@1&%T87-E="!T;R!F:6YD('1H92!R86YG
M92!F;W(N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;6EN("`@("`@("`@36EN
M:6UU;2!V86QU92!T;R!S=&%R="!A="X@5&AE(&QO=V5S="!N=6UB97(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@9&%T87-E
M="!I<R!U<V5D(&EF(&ET)W,@;&]W97(N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D;6%X("`@("`@("`@36%X:6UU;2!V86QU92!T;R!S=&%R="!A="X@5&AE
M(&AI9VAE<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M=6UB97(@:6X@=&AE(&1A=&%S970@:7,@=7-E9"!I9B!I="=S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:&EG:&5R+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)')E<V]L=71I;VX@(%1H92!R97-O;'5T:6]N('1O('5S
M92!F;W(@=&AE(')A;F=E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!M:6YI;75M(&%N9"!M87AI;75M('9A;'5E<R!F;W(@=&AE(')A;F=E
M+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]F:6YD4F%N9V4H)&1A=&$L("1M:6X@/2`P+"`D;6%X(#T@,"P@)')E<V]L
M=71I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&1A=&$I*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G;6EN)R`]/B`P+"`G;6%X)R`]
M/B`P*3L*("`@("`@("!]"@H@("`@("`@("1D871A6UT@/2`D;6%X.PH@("`@
M("`@("1D871A6UT@/2`D;6EN.PH@("`@("`@("1M87@@/2!M87@H)&1A=&$I
M.PH@("`@("`@("1M:6X@/2!M:6XH)&1A=&$I.PH*("`@("`@("!I9B`H)&UA
M>"`]/2`P*2!["B`@("`@("`@("`@("1F86-T;W(@/2`Q.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(&EF("@D;6%X(#P@,"D@>PH@("`@("`@("`@
M("`@("`@)&9A8W1O<B`]("UP;W<H,3`L("AF;&]O<BAL;V<Q,"AA8G,H)&UA
M>"DI*2`K("1R97-O;'5T:6]N*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D9F%C=&]R(#T@<&]W*#$P+"`H9FQO;W(H;&]G,3`H
M86)S*"1M87@I*2D@+2`D<F5S;VQU=&EO;BDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`D;6%X(#T@)&9A8W1O<B`J($!C96EL*"1M87@@
M+R`D9F%C=&]R*3L*("`@("`@("`D;6EN(#T@)&9A8W1O<B`J($!F;&]O<B@D
M;6EN("\@)&9A8W1O<BD["@H@("`@("`@(')E='5R;B!A<G)A>2@D;6EN+"`D
M;6%X*3L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U-13"YP:'``````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#,T,S<W(#$P-3$U-#,T,30P(#`R,#4R-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AI
M<R!I<R!A('5T:6QI='D@8VQA<W,L(&5V97)Y(&UE=&AO9"!I<R!S=&%T:6,N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-13"]344PN<&AP+'8@,2XS,"XR
M+C$W(#(P,#8O,#0O,3D@,#,Z-#DZ-#D@8F5N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U(&1I
M9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,BXR"B`J($!P86-K86=E($AO<F1E7U-13`H@*B\*8VQA<W,@2&]R9&5?4U%,
M('L*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!B;V]L96%N(&5X<')E<W-I
M;VX@=7-I;F<@=&AE('-P96-I9FEE9"!O<&5R871O<BX@57-E<PH@("`@("H@
M9&%T86)A<V4M<W!E8VEF:6,@8V%S=&EN9RP@:68@;F5C97-S87)Y+@H@("`@
M("H*("`@("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@
M9&%T86)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&AS("`@
M(%1H92!C;VQU;6X@;W(@97AP<F5S<VEO;B!T;R!T97-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;W`@("`@(%1H92!O<&5R871O<BX*("`@("`J($!P87)A
M;2!S=')I;F<@)')H<R`@("!4:&4@8V]M<&%R:7-O;B!V86QU92X*("`@("`J
M($!P87)A;2!B;V]L96%N("1B:6YD("!)9B!T<G5E+"!T:&4@;65T:&]D(')E
M='5R;G,@=&AE('%U97)Y(&%N9"!A(&QI<W0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!O9B!V86QU97,@<W5I=&%B;&4@9F]R(&)I;F1I;F<@87,@
M86X@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!3
M44P@=&5S="!F<F%G;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&1#
M;&%U<V4H)B1D8F@L("1L:',L("1O<"P@)')H<RP@)&)I;F0@/2!F86QS92D*
M("`@('L*("`@("`@("!S=VET8V@@*"1O<"D@>PH@("`@("`@(&-A<V4@)WPG
M.@H@("`@("`@(&-A<V4@)R8G.@H@("`@("`@("`@("!S=VET8V@@*"1D8F@M
M/G!H<'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@
M("`@("`@("`@+R\@3VYL>2!09U-13"`W+C,K('5N9&5R<W1A;F1S(%-13#DY
M("=324U)3$%2(%1/)SL@=7-E"B`@("`@("`@("`@("`@("`O+R!^(&9O<B!G
M<F5A=&5R(&)A8VMW87)D<R!C;VUP871I8FEL:71Y+@H@("`@("`@("`@("`@
M("`@)'%U97)Y(#T@)T-!4T4@5TA%3B!#05-4*"5S($%3(%9!4D-(05(I('X@
M7"=>+3];,"TY72LD7"<@5$A%3B`H0T%35"@E<R!!4R!)3E1%1T52*2`E<R`E
M<RD@/#X@,"!%3%-%($9!3%-%($5.1"<["B`@("`@("`@("`@("`@("!I9B`H
M)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH<W!R
M:6YT9BA(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)'%U97)Y*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D95]344PZ
M.F5S8V%P95!R97!A<F4H)&QH<RDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1L
M:',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;W`I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<_)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"AI;G0I)')H<RDI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("1L:',L("1O<"P@*&EN="DD<FAS
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-A<V4@)V]C:3@G
M.@H@("`@("`@("`@("`@("`@+R\@3W)A8VQE('5S97,@)B!F;W(@=F%R:6%B
M;&5S+B!792!N965D('1O('5S92!T:&4@8FET86YD"B`@("`@("`@("`@("`@
M("`O+R!F=6YC=&EO;B!T:&%T(&ES(&%V86EL86)L92P@8G5T(&UA>2!B92!U
M;G-U<'!O<G1E9"X*("`@("`@("`@("`@("`@("1Q=65R>2`]("=B:71A;F0H
M)7,L("5S*2`]("5S)SL*("`@("`@("`@("`@("`@(&EF("@D8FEN9"D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E
M7U-13#HZ97-C87!E4')E<&%R92@D<75E<GDI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E
M<&%R92@D;&AS*2P@)S\G+"`G/R<I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@H:6YT*21R:',L("AI;G0I)')H<RDI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@<W!R:6YT9B@D<75E<GDL("1L:',L("AI;G0I)')H<RP@*&EN="DD<FAS
M*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-A<V4@)VUS<W%L
M)SH*("`@("`@("`@("`@("`@("\O($U34U%,(&UU<W0@:&%V92!A('9A;&ED
M(&)O;VQE86X@97AP<F5S<VEO;@H@("`@("`@("`@("`@("`@)'%U97)Y(#T@
M)RA#05-%(%=(14X@25-.54U%4DE#*"5S*2`](#$@5$A%3B`H)7,@)B`E<RD@
M14Q312`E<R!%3D0I(#T@)7,G.PH@("`@("`@("`@("`@("`@:68@*"1B:6YD
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*'-P<FEN=&8H
M2&]R9&5?4U%,.CIE<V-A<&50<F5P87)E*"1Q=65R>2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?4U%,.CIE<V-A
M<&50<F5P87)E*"1L:',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;&AS*2P@
M)S\G+"`G/R<L("<_)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"AI;G0I)')H<RP@*&EN="DD<FAS("T@,2P@*&EN="DD<FAS
M*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!S<')I;G1F*"1Q=65R>2P@)&QH<RP@)&QH<RP@*&EN="DD
M<FAS+"`H:6YT*21R:',@+2`Q+"`H:6YT*21R:',I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@8V%S92`G;V1B8R<Z"B`@("`@("`@("`@("`@
M("`O+R!/1$)#(&UU<W0@:&%V92!A('9A;&ED(&)O;VQE86X@97AP<F5S<VEO
M;@H@("`@("`@("`@("`@("`@)'%U97)Y(#T@)R@E<R`F("5S*2`]("5S)SL*
M("`@("`@("`@("`@("`@(&EF("@D8FEN9"D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!A<G)A>2AS<')I;G1F*$AO<F1E7U-13#HZ97-C87!E4')E
M<&%R92@D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;&AS*2P@)S\G
M+"`G/R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@H:6YT*21R:',L("AI;G0I)')H<RDI.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@D<75E
M<GDL("1L:',L("AI;G0I)')H<RP@*&EN="DD<FAS*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I
M9B`H)&)I;F0I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M)&QH<R`N("<@)R`N($AO<F1E7U-13#HZ97-C87!E4')E<&%R92@D;W`I("X@
M)R`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M*&EN="DD<FAS*2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D;&AS("X@)R`G("X@)&]P("X@)R`G("X@
M*&EN="DD<FAS.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@(&-A<V4@)WXG.@H@("`@("`@("`@("!I9B`H)&1B:"T^<&AP='EP
M92`]/2`G;7ES<6PG*2!["B`@("`@("`@("`@("`@("`D;W`@/2`G4D5'15A0
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&)I;F0I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;&AS("X@)R`G("X@)&]P("X@
M)R`_)RP@87)R87DH)')H<RDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1L:',@+B`G("<@+B`D;W`@+B`G("<@+B`D
M<FAS.PH@("`@("`@("`@("!]"@H@("`@("`@(&-A<V4@)TE.)SH*("`@("`@
M("`@("`@:68@*"1B:6YD*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)')H<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M)&QH<R`N("<@24X@*#\G("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)')H
M<RD@+2`Q*2`N("<I)RP@)')H<RD["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("\O(%=E(&YE960@=&\@8FEN9"!E86-H
M(&UE;6)E<B!O9B!T:&4@24X@8VQA=7-E"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V5P87)A=&5L>2!T;R!E;G-U<F4@<')O<&5R('%U;W1I;F<N"B`@("`@
M("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D<FAS+"`P+"`Q*2`]/2`G*"<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)')H<R`]('-U8G-T<B@D<FAS
M+"`Q*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@:68@*'-U8G-T<B@D<FAS+"`M,2D@/3T@)RDG*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R:',@/2!S=6)S='(H)')H<RP@,"P@+3$I.PH@("`@
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@)&ED<R`]
M('!R96=?<W!L:70H)R]<<RHL7',J+R<L("1R:',I.PH*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@87)R87DH)&QH<R`N("<@24X@*#\G("X@<W1R7W)E
M<&5A="@G+"`_)RP@8V]U;G0H)&ED<RD@+2`Q*2`N("<I)RP@)&ED<RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)')H<RDI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)&QH<R`N("<@24X@)R`N(&EM<&QO9&4H)RP@)RP@)')H
M<RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D;&AS("X@)R!)3B`G("X@)')H<SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("!C87-E("=,24M%)SH*("`@
M("`@("`@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)W!G<W%L)RD@>PH@("`@
M("`@("`@("`@("`@)'%U97)Y(#T@)R5S($E,24M%("5S)SL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1Q=65R>2`]("=,3U=%4B@E
M<RD@3$E+12!,3U=%4B@E<RDG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D8FEN9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*'-P
M<FEN=&8H)'%U97)Y+"!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&QH<RDL
M("<_)RDL(&%R<F%Y*"<E)R`N("1R:',@+B`G)2<I*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"1Q=65R
M>2P@)&QH<RP@)&1B:"T^<75O=&4H)R4G("X@)')H<R`N("<E)RDI.PH@("`@
M("`@("`@("!]"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&EF("@D
M8FEN9"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1L:',@+B`G
M("<@+B!(;W)D95]344PZ.F5S8V%P95!R97!A<F4H)&]P*2`N("<@/R<L(&%R
M<F%Y*"1R:',I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D;&AS("X@)R`G("X@)&]P("X@)R`G("X@)&1B:"T^<75O
M=&4H)')H<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!%<V-A<&5S(&%L;"!C:&%R86-T97)S(&EN(&$@<W1R:6YG
M('1H870@87)E('!L86-E:&]L9&5R<R!F;W(@=&AE"B`@("`@*B!P<F5P87)E
M+V5X96-U=&4@;65T:&]D<R!O9B!T:&4@1$(@<&%C:V%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@02!S=')I;F<@=&\@97-C87!E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]R<F5C=&QY
M(&5S8V%P960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&50
M<F5P87)E*"1Q=65R>2D*("`@('L*("`@("`@("!R971U<FX@<')E9U]R97!L
M86-E*"<O6S\A)ETO)RP@)UQ<7%PD,"<L("1Q=65R>2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@<F5A9$)L;V(H)B1D8F@L("1T86)L92P@)&9I96QD+"`D8W)I
M=&5R:6$I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=9;W4@;75S
M="!S<&5C:69Y('1H92!F971C:"!C<FET97)I82<I.PH@("`@("`@('T*"B`@
M("`@("`@)'=H97)E(#T@)R<["@H@("`@("`@('-W:71C:"`H)&1B:"T^9&)S
M>6YT87@I('L*("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@9F]R
M96%C:"`H)&-R:71E<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@("`@
M("`@("`D=VAE<F4@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'=H97)E("X]("1K97D@+B`G($E3($Y53$PG.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F4@
M+CT@)&ME>2`N("<@/2`G("X@)&1B:"T^<75O=&4H)'9A;'5E*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-T871E
M;65N="`]($]#25!A<G-E*"1D8F@M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"=314Q%0U0@)7,@1E)/
M32`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F:65L9"P@)'1A8FQE+"`D=VAE<F4I*3L*("`@("`@
M("`@("`@3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@("`@("`@:68@
M*$]#249E=&-H26YT;R@D<W1A=&5M96YT+"`D;&]B*2D@>PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1L;V);,%TM/FQO860H*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!014%2.CIR86ES
M945R<F]R*"=5;F%B;&4@=&\@;&]A9"!344P@1&%T82<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1W:&5R92`N/2`G($%.1"`G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@+B`G(#T@)R`N
M("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)')E<W5L="`]("1D8F@M/F=E=$]N92AS<')I;G1F*"=314Q%0U0@)7,@
M1E)/32`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEE;&0L("1T86)L92P@)'=H97)E*2D["@H@
M("`@("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@("`@("`@
M("`@(&-A<V4@)W!G<W%L)SH*("`@("`@("`@("`@("`@("1R97-U;'0@/2!P
M86-K*"=()R`N('-T<FQE;B@D<F5S=6QT*2P@)')E<W5L="D["B`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@:6YS97)T
M0FQO8B@F)&1B:"P@)'1A8FQE+"`D9FEE;&0L("1D871A+"`D871T<FEB=71E
M<RD*("`@('L*("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@("`@("`D
M=F%L=65S(#T@87)R87DH*3L*"B`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y
M;G1A>"D@>PH@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@("`@("`@("!F;W)E
M86-H("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@
M("`@("`@("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@("`@("`@("`@("1V
M86QU97-;72`]("1D8F@M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE087)S92@D9&)H+3YC;VYN
M96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W!R
M:6YT9B@G24Y315)4($E.5$\@)7,@*"5S+"`E<RDG("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R!604Q515,@*"5S+"!%
M35!465]"3$]"*"DI(%)%5%523DE.1R`E<R!)3E1/(#IB;&]B)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L
M;V1E*"<L("<L("1F:65L9',I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEE;&0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)'9A;'5E<RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M:65L9"DI.PH*("`@("`@("`@("`@)&QO8B`]($]#24YE=T1E<V-R:7!T;W(H
M)&1B:"T^8V]N;F5C=&EO;BD["B`@("`@("`@("`@($]#24)I;F1">4YA;64H
M)'-T871E;65N="P@)SIB;&]B)RP@)&QO8BP@+3$L(%-13%1?0DQ/0BD["B`@
M("`@("`@("`@($]#245X96-U=&4H)'-T871E;65N="P@3T-)7T1%1D%53%0I
M.PH@("`@("`@("`@("`D;&]B+3YS879E*"1D871A*3L*("`@("`@("`@("`@
M)')E<W5L="`]($]#24-O;6UI="@D9&)H+3YC;VYN96-T:6]N*3L*("`@("`@
M("`@("`@)&QO8BT^9G)E92@I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M
M96YT*"1S=&%T96UE;G0I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L="`_
M('1R=64@.B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N($5R<F]R)RD["@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U
M=&5S(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D9FEE
M;&1S6UT@/2`D:V5Y.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A
M;'5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=)3E-%4E0@24Y43R`E<R`H)7,L("5S*2!604Q515,@*"5S*2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&9I96QD<RDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<_)R`N('-T<E]R97!E870H)RP@/R<L(&-O
M=6YT*"1V86QU97,I*2D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*
M"B`@("`@("`@<W=I=&-H("@D9&)H+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A
M<V4@)VUS<W%L)SH*("`@("`@("!C87-E("=P9W-Q;"<Z"B`@("`@("`@("`@
M("1V86QU97-;72`](&)I;C)H97@H)&1A=&$I.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'9A;'5E<UM=(#T@
M)&1A=&$["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T
M(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!(;W)D95]344PZ.FEN<V5R=$)L
M;V(H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@=7!D871E0FQO8B@F)&1B:"P@)'1A8FQE+"`D
M9FEE;&0L("1D871A+"`D=VAE<F4L("1A;'-O=7!D871E*0H@("`@>PH@("`@
M("`@("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1V86QU97,@/2!A<G)A
M>2@I.PH*("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@("`@
M("`@8V%S92`G;V-I."<Z"B`@("`@("`@("`@("1W:&5R97-T<FEN9R`]("<G
M.PH@("`@("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME>2`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E<W1R:6YG
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`G($%.
M1"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H97)E
M<W1R:6YG("X]("1K97D@+B`G(#T@)R`N("1D8F@M/G%U;W1E*"1V86QU92D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%T96UE;G0@/2!/0TE0
M87)S92@D9&)H+3YC;VYN96-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<W!R:6YT9B@G4T5,14-4("5S($923TT@)7,@5TA%4D4@
M)7,@1D]2(%501$%412<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=VAE<F5S=')I;F<I*3L*"B`@("`@
M("`@("`@($]#245X96-U=&4H)'-T871E;65N="P@3T-)7T1%1D%53%0I.PH@
M("`@("`@("`@("!/0TE&971C:$EN=&\H)'-T871E;65N="P@)&QO8BD["B`@
M("`@("`@("`@("1L;V);,%TM/G-A=F4H)&1A=&$I.PH@("`@("`@("`@("`D
M<F5S=6QT(#T@3T-)0V]M;6ET*"1D8F@M/F-O;FYE8W1I;VXI.PH@("`@("`@
M("`@("`D;&]B6S!=+3YF<F5E*"D["B`@("`@("`@("`@($]#249R9653=&%T
M96UE;G0H)'-T871E;65N="D["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT
M(#\@=')U92`Z(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@17)R;W(G*3L*
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'5P9&%T97-T<FEN9R`]
M("<G.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&%L<V]U<&1A=&4@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&ME>2`N("<@/2`_
M+"`G.PH@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)'9A;'5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@+CT@)&9I96QD
M("X@)R`](#\G.PH@("`@("`@("`@("!S=VET8V@@*"1D8F@M/F1B<WEN=&%X
M*2!["B`@("`@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@("`@("`@8V%S
M92`G<&=S<6PG.@H@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@8FEN,FAE
M>"@D9&%T82D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D=F%L=65S6UT@/2`D9&%T83L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'=H97)E<W1R:6YG(#T@)R<[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1W:&5R92!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=VAE<F5S=')I;F<I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG("X]("<@04Y$
M("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VAE<F5S
M=')I;F<@+CT@)&ME>2`N("<@/2`_)SL*("`@("`@("`@("`@("`@("1V86QU
M97-;72`]("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R!72$5212`E<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8FQE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1U<&1A=&5S=')I;F<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'=H97)E<W1R:6YG*3L*("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T
M(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!(;W)D95]344PZ.G5P9&%T94)L
M;V(H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@
M<F5T=7)N("1D8F@M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!"=6EL9"!A;B!344P@4T54(&-L875S92X*("`@("`J
M"B`@("`@*B!4:&ES(&9U;F-T:6]N('1A:V5S(&%N(&%R<F%Y(&EN('1H92!F
M;W)M(&-O;'5M;B`]/B!V86QU92!A;F0@<F5T=7)N<PH@("`@("H@86X@4U%,
M(%-%5"!C;&%U<V4@*'=I=&AO=70@=&AE(%-%5"!K97EW;W)D*2!W:71H('1H
M92!V86QU97,@<')O<&5R;'D*("`@("`J('%U;W1E9"X@($9O<B!E>&%M<&QE
M+"!T:&4@9F]L;&]W:6YG.@H@("`@("H*("`@("`J("`@("`@87)R87DH)V9O
M;R<@/3X@,2P*("`@("`J("`@("`@("`@("`@)V)A<B<@/3X@)VAE;&QO)RD*
M("`@("`J"B`@("`@*B!W;W5L9"!R97-U;'0@:6X@=&AE(&9R86=M96YT.@H@
M("`@("H*("`@("`J("`@("`@9F]O(#T@,2P@8F%R(#T@)VAE;&QO)PH@("`@
M("H*("`@("`J($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@
M9&%T86)A<V4@;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@
M(%1H92!A<G)A>2!O9B!C;VQU;6X@/3X@=F%L=64@<&%I<G,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!344P@4T54(&9R86=M96YT+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&5686QU97,H)B1D8F@L("1V86QU
M97,I"B`@("!["B`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)'9A;'5E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`D<F5T6UT@/2`D:V5Y("X@)R`]("<@+B`H)'9A;'5E(#T]/2!N=6QL(#\@
M)TY53$PG(#H@)&1B:"T^<75O=&4H)'9A;'5E*2D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!I;7!L;V1E*"<L("<L("1R970I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0G5I;&0@86X@4U%,($E.4T525"]604Q515,@8VQA=7-E+@H@
M("`@("H*("`@("`J(%1H:7,@9G5N8W1I;VX@=&%K97,@86X@87)R87D@:6X@
M=&AE(&9O<FT@8V]L=6UN(#T^('9A;'5E(&%N9"!R971U<FYS"B`@("`@*B!A
M;B!344P@9G)A9VUE;G0@<W!E8VEF>6EN9R!T:&4@8V]L=6UN(&YA;65S(&%N
M9"!I;G-E<G0@=F%L=65S+"!W:71H"B`@("`@*B!T:&4@=F%L=65S('!R;W!E
M<FQY('%U;W1E9"X@($9O<B!E>&%M<&QE+"!T:&4@9F]L;&]W:6YG.@H@("`@
M("H*("`@("`J("`@("`@87)R87DH)V9O;R<@/3X@,2P*("`@("`J("`@("`@
M("`@("`@)V)A<B<@/3X@)VAE;&QO)RD*("`@("`J"B`@("`@*B!W;W5L9"!R
M97-U;'0@:6X@=&AE(&9R86=M96YT.@H@("`@("H*("`@("`J("`@("`@*"!F
M;V\L(&)A<B`I(%9!3%5%4R`H(#$L("=H96QL;R<@*0H@("`@("H*("`@("`J
M($!P87)A;2!$0B`D9&)H("`@("`@("!4:&4@4$5!4CHZ1$(@9&%T86)A<V4@
M;V)J96-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1V86QU97,@(%1H92!A<G)A
M>2!O9B!C;VQU;6X@/3X@=F%L=64@<&%I<G,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!344P@9G)A9VUE;G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&EN<V5R=%9A;'5E<R@F)&1B:"P@)'9A;'5E<RD*("`@('L*("`@
M("`@("`D8V]L=6UN<R`](&%R<F%Y*"D["B`@("`@("`@)'9A;',@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)&ME>2`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@)&-O;'5M;G-;72`]("1K97D["B`@("`@("`@
M("`@("1V86QS6UT@/2`D=F%L=64@/3T](&YU;&P@/R`G3E5,3"<@.B`D9&)H
M+3YQ=6]T92@D=F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)R@@
M)R`N(&EM<&QO9&4H)RP@)RP@)&-O;'5M;G,I("X@)R`I(%9!3%5%4R`H("<@
M+B!I;7!L;V1E*"<L("<L("1V86QS*2`N("<@*2<["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U-T<FEN9RYP:'``````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0T-S$V(#$P-3$U-#,T,30P(#`R,3,S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==(#T@)VES
M;RTX.#4Y+3$G.PH*+RHJ"B`J(%1H92!3=')I;F<Z.B!C;&%S<R!P<F]V:61E
M<R!S=&%T:6,@;65T:&]D<R!F;W(@8VAA<G-E="!A;F0@;&]C86QE('-A9F4*
M("H@<W1R:6YG(&UA;FEP=6QA=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO571I;"]3=')I;F<N<&AP+'8@,2XT,RXV+C$S(#(P,#8O,#,O,3,@,#DZ
M-#8Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N
M(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]5=&EL"B`J+PIC
M;&%S<R!3=')I;F<@>PH*("`@("\J*@H@("`@("H@0V%C:&5S('1H92!R97-U
M;'0@;V8@97AT96YS:6]N7VQO861E9"@I(&-A;&QS+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO;B!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@27,@=&AE(&5X=&5N<VEO;B!L
M;V%D960_"B`@("`@*@H@("`@("H@0'-E92!5=&EL.CIE>'1E;G-I;VY%>&ES
M=',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!E>'1E;G-I;VY%>&ES=',H)&5X
M="D*("`@('L*("`@("`@("!S=&%T:6,@)&-A8VAE(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*"%I<W-E="@D8V%C:&5;)&5X=%TI*2!["B`@("`@("`@("`@
M("1C86-H95LD97AT72`](&5X=&5N<VEO;E]L;V%D960H)&5X="D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1E>'1=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T<R!A(&1E9F%U;'0@8VAA<G-E="!T:&%T('1H92!3
M=')I;F<Z.B!M971H;V1S('=I;&P@=7-E(&EF(&YO;F4@:7,*("`@("`J(&5X
M<&QI8VET96QY('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4@87,@=&AE(&1E9F%U
M;'0@;VYE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$969A=6QT0VAA<G-E
M="@D8VAA<G-E="D*("`@('L*("`@("`@("`D1TQ/0D%,4ULG7TA/4D1%7U-4
M4DE.1U]#2$%24T54)UT@/2`D8VAA<G-E=#L*("`@("`@("!I9B`H4W1R:6YG
M.CIE>'1E;G-I;VY%>&ES=',H)VUB<W1R:6YG)RD@)B8*("`@("`@("`@("`@
M9G5N8W1I;VY?97AI<W1S*"=M8E]R96=E>%]E;F-O9&EN9R<I*2!["B`@("`@
M("`@("`@($!M8E]R96=E>%]E;F-O9&EN9R@D8VAA<G-E="D["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R=',@82!S=')I;F<@9G)O
M;2!O;F4@8VAA<G-E="!T;R!A;F]T:&5R+@H@("`@("H*("`@("`J(%=O<FMS
M(&]N;'D@:68@96ET:&5R('1H92!I8V]N=B!O<B!T:&4@;6)S=')I;F<@97AT
M96YS:6]N"B`@("`@*B!A<F4@<')E<V5N="!A;F0@8F5S="!I9B!B;W1H(&%R
M92!A=F%I;&%B;&4N"B`@("`@*B!4:&4@;W)I9VEN86P@<W1R:6YG(&ES(')E
M='5R;F5D(&EF(&-O;G9E<G-I;VX@9F%I;&5D(&]R(&YO;F4*("`@("`J(&]F
M('1H92!E>'1E;G-I;VYS('=E<F4@879A:6QA8FQE+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`D:6YP=70@(%1H92!D871A('1O(&)E(&-O;G9E<G1E
M9"X@268@)&EN<'5T(&ES(&%N(&%N(&%R<F%Y+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&%R<F%Y)W,@=F%L=65S(&=E="!C;VYV97)T960@
M<F5C=7)S:79E;'DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<F]M("!4:&4@
M<W1R:6YG)W,@8W5R<F5N="!C:&%R<V5T+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&\@("`@5&AE(&-H87)S970@=&\@8V]N=F5R="!T:&4@<W1R:6YG('1O
M+B!)9B!N;W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@('-P96-I9FEE
M9"P@=&AE(&=L;V)A;"!V87)I86)L90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@)%](3U)$15]35%))3D=?0TA!4E-%5"!W:6QL(&)E('5S960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYV97)T960@<W1R
M:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T0VAA<G-E="@D:6YP
M=70L("1F<F]M+"`D=&\@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($=E="!T
M:&4@=7-E<B=S(&1E9F%U;'0@8VAA<F%C=&5R('-E="!I9B!N;VYE('!A<W-E
M9"!I;BX@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D=&\I*2!["B`@("`@("`@
M("`@("1T;R`]("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G73L*
M("`@("`@("!]"@H@("`@("`@("\J($EF('1H92!F<F]M(&%N9"!T;R!C:&%R
M86-T97(@<V5T<R!A<F4@:61E;G1I8V%L+"!R971U<FX@;F]W+B`J+PH@("`@
M("`@("1F<F]M(#T@4W1R:6YG.CIL;W=E<B@D9G)O;2D["B`@("`@("`@)'1O
M(#T@4W1R:6YG.CIL;W=E<B@D=&\I.PH@("`@("`@(&EF("@D9G)O;2`]/2`D
M=&\I('L*("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<U]A<G)A>2@D:6YP=70I*2!["B`@("`@("`@("`@("1T
M;7`@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D:6YP=70@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D=&UP6U-T<FEN9SHZ
M7V-O;G9E<G1#:&%R<V5T*"1K97DL("1F<F]M+"`D=&\I72`](%-T<FEN9SHZ
M8V]N=F5R=$-H87)S970H)'9A;"P@)&9R;VTL("1T;RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<U]O8FIE8W0H)&EN<'5T*2D@>PH@("`@("`@("`@("`D=F%R<R`]
M(&=E=%]O8FIE8W1?=F%R<R@D:6YP=70I.PH@("`@("`@("`@("!F;W)E86-H
M("@D=F%R<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@("1I
M;G!U="T^)&ME>2`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'9A;"P@)&9R
M;VTL("1T;RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1I
M;G!U=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<W1R:6YG*"1I;G!U
M="DI('L*("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!3=')I;F<Z.E]C;VYV97)T0VAA<G-E="@D:6YP=70L
M("1F<F]M+"`D=&\I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YT97)N86P@
M9G5N8W1I;VX@=7-E9"!T;R!D;R!C:&%R<V5T(&-O;G9E<G-I;VXN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("1I;G!U="`@4V5E(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H*2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&9R;VT@(%-E92!3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"DN"B`@("`@*B!`<&%R86T@<W1R:6YG("1T;R`@("!3964@
M4W1R:6YG.CIC;VYV97)T0VAA<G-E="@I+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8V]N=F5R=&5D('-T<FEN9RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-O;G9E<G1#:&%R<V5T*"1I;G!U="P@)&9R;VTL("1T;RD*
M("`@('L*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@("\J(%5S92!U
M=&8X7UME;GQD95UC;V1E*"D@:68@<&]S<VEB;&4N("HO"B`@("`@("`@)&9R
M;VU?8VAE8VL@/2`H*"1F<F]M(#T]("=I<V\M.#@U.2TQ)RD@?'P@*"1F<F]M
M(#T]("=U<RUA<V-I:2<I*3L*("`@("`@("!I9B`H)&9R;VU?8VAE8VL@)B8@
M*"1T;R`]/2`G=71F+3@G*2D@>PH@("`@("`@("`@("!R971U<FX@=71F.%]E
M;F-O9&4H)&EN<'5T*3L*("`@("`@("!]"@H@("`@("`@("1T;U]C:&5C:R`]
M("@H)'1O(#T]("=I<V\M.#@U.2TQ)RD@?'P@*"1T;R`]/2`G=7,M87-C:6DG
M*2D["B`@("`@("`@:68@*"@D9G)O;2`]/2`G=71F+3@G*2`F)B`D=&]?8VAE
M8VLI('L*("`@("`@("`@("`@<F5T=7)N('5T9CA?9&5C;V1E*"1I;G!U="D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!&:7)S="!T<GD@:6-O;G8@=VET:"!T
M<F%N<VQI=&5R871I;VXN("HO"B`@("`@("`@:68@*"@D9G)O;2`A/2`G=71F
M-RUI;6%P)RD@)B8*("`@("`@("`@("`@*"1T;R`A/2`G=71F-RUI;6%P)RD@
M)B8*("`@("`@("`@("`@4W1R:6YG.CIE>'1E;G-I;VY%>&ES=',H)VEC;VYV
M)RDI('L*("`@("`@("`@("`@+RH@5V4@;F5E9"!T;R!T86-K(&%N(&5X=')A
M(&-H87)A8W1E<B!T96UP;W)A<FEL>2!B96-A=7-E"B`@("`@("`@("`@("`J
M(&]F(&$@8G5G(&EN(&EC;VYV*"D@:68@=&AE(&QA<W0@8VAA<F%C=&5R(&ES
M(&YO="!A(#<*("`@("`@("`@("`@("H@8FET($%30TE)(&-H87)A8W1E<BX@
M*B\*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@
M("`@("`@("`@("1O=71P=70@/2!`:6-O;G8H)&9R;VTL("1T;R`N("<O+U12
M04Y33$E4)RP@)&EN<'5T("X@)W@G*3L*("`@("`@("`@("`@)&]U='!U="`]
M("AI<W-E="@D<&AP7V5R<F]R;7-G*2D@/R!F86QS92`Z("!3=')I;F<Z.G-U
M8G-T<B@D;W5T<'5T+"`P+"`M,2P@)'1O*3L*("`@("`@("`@("`@:6YI7W)E
M<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M3F5X="!T<GD@;6)S=')I;F<N("HO"B`@("`@("`@:68@*"$D;W5T<'5T("8F
M(%-T<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@
M("`@("`@("1O=71P=70@/2!`;6)?8V]N=F5R=%]E;F-O9&EN9R@D:6YP=70L
M("1T;RP@)&9R;VTI.PH@("`@("`@('T*"B`@("`@("`@+RH@070@;&%S="!T
M<GD@:6UA<%]U=&8W7UME;GQD95UC;V1E(&EF(&%P<')O<')I871E+B`J+PH@
M("`@("`@(&EF("@A)&]U='!U="`F)B!3=')I;F<Z.F5X=&5N<VEO;D5X:7-T
M<R@G:6UA<"<I*2!["B`@("`@("`@("`@(&EF("@D9G)O;5]C:&5C:R`F)B`H
M)'1O(#T]("=U=&8W+6EM87`G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M($!I;6%P7W5T9C=?96YC;V1E*"1I;G!U="D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"@D9G)O;2`]/2`G=71F-RUI;6%P)RD@)B8@)'1O7V-H
M96-K*2!["B`@("`@("`@("`@("`@("!R971U<FX@0&EM87!?=71F-U]D96-O
M9&4H)&EN<'5T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("@A)&]U='!U="D@/R`D:6YP=70@.B`D;W5T<'5T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@36%K97,@82!S=')I;F<@;&]W97)C87-E+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1S=')I;F<@("!4:&4@<W1R:6YG
M('1O(&)E(&-O;G9E<G1E9"X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V-A
M;&4@("!)9B!T<G5E('1H92!S=')I;F<@=VEL;"!B92!C;VYV97)T960@8F%S
M960@;VX@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&=I=F5N
M(&-H87)S970L(&QO8V%L92!I;F1E<&5N9&5N="!E;'-E+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&-H87)S970@($EF("1L;V-A;&4@:7,@=')U92P@=&AE
M(&-H87)S970@=&\@=7-E('=H96X*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!C;VYV97)T:6YG+B!)9B!N;W0@<')O=FED960@=&AE(&-U<G)E
M;G0@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('-T<FEN9R!W:71H(&QO=V5R8V%S92!C:&%R86-T97)S"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QO=V5R*"1S=')I;F<L("1L;V-A;&4@/2!F86QS92P@)&-H
M87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@('-T871I8R`D;&]W97)S.PH*
M("`@("`@("!I9B`H)&QO8V%L92D@>PH@("`@("`@("`@("`O*B!4:&4@97AI
M<W1E;F-E(&]F(&UB7W-T<G1O;&]W97(H*2!D97!E;F1S(&]N('1H92!P;&%T
M9F]R;2X@*B\*("`@("`@("`@("`@:68@*%-T<FEN9SHZ97AT96YS:6]N17AI
M<W1S*"=M8G-T<FEN9R<I("8F"B`@("`@("`@("`@("`@("!F=6YC=&EO;E]E
M>&ES=',H)VUB7W-T<G1O;&]W97(G*2D@>PH@("`@("`@("`@("`@("`@:68@
M*&ES7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@)&-H
M87)S970@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T(#T@0&UB7W-T
M<G1O;&]W97(H)'-T<FEN9RP@)&-H87)S970I.PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D<F5T*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B!S=')T;VQO=V5R*"1S=')I;F<I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%I<W-E="@D;&]W97)S*2D@>PH@("`@("`@("`@("`D
M;&]W97)S(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D;&]W97)S6R1S=')I;F==*2D@>PH@("`@("`@("`@("`D;&%N9W5A9V4@
M/2!S971L;V-A;&4H3$-?0U194$4L(#`I.PH@("`@("`@("`@("!S971L;V-A
M;&4H3$-?0U194$4L("=E;E]54R<I.PH@("`@("`@("`@("`D;&]W97)S6R1S
M=')I;F==(#T@<W1R=&]L;W=E<B@D<W1R:6YG*3L*("`@("`@("`@("`@<V5T
M;&]C86QE*$Q#7T-465!%+"`D;&%N9W5A9V4I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1L;W=E<G-;)'-T<FEN9UT["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-86ME<R!A('-T<FEN9R!U<'!E<F-A<V4N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@8F4@8V]N
M=F5R=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8V%L92`@($EF('1R
M=64@=&AE('-T<FEN9R!W:6QL(&)E(&-O;G9E<G1E9"!B87-E9"!O;B!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@9VEV96X@8VAA<G-E="P@
M;&]C86QE(&EN9&5P96YD96YT(&5L<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D8VAA<G-E="`@268@)&QO8V%L92!I<R!T<G5E+"!T:&4@8VAA<G-E="!T
M;R!U<V4@=VAE;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G9E<G1I;F<N($EF(&YO="!P<F]V:61E9"!T:&4@8W5R<F5N="!C:&%R<V5T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<W1R:6YG('=I
M=&@@=7!P97)C87-E(&-H87)A8W1E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@
M=7!P97(H)'-T<FEN9RP@)&QO8V%L92`](&9A;'-E+"`D8VAA<G-E="`](&YU
M;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1U<'!E<G,["@H@("`@("`@(&EF
M("@D;&]C86QE*2!["B`@("`@("`@("`@("\J(%1H92!E>&ES=&5N8V4@;V8@
M;6)?<W1R=&]U<'!E<B@I(&1E<&5N9',@;VX@=&AE"B`@("`@("`@("`@("`J
M('!L871F;W)M+B`J+PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=M8E]S=')T;W5P<&5R)RDI('L*("`@("`@("`@("`@("`@(&EF("AI<U]N
M=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%R<V5T
M(#T@)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E="`]($!M8E]S=')T;W5P
M<&5R*"1S=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)')E="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@<W1R=&]U<'!E<B@D<W1R:6YG*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-S970H)'5P<&5R<RDI('L*("`@("`@("`@("`@)'5P<&5R
M<R`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'5P
M<&5R<ULD<W1R:6YG72DI('L*("`@("`@("`@("`@)&QA;F=U86=E(#T@<V5T
M;&]C86QE*$Q#7T-465!%+"`P*3L*("`@("`@("`@("`@<V5T;&]C86QE*$Q#
M7T-465!%+"`G96Y?55,G*3L*("`@("`@("`@("`@)'5P<&5R<ULD<W1R:6YG
M72`]('-T<G1O=7!P97(H)'-T<FEN9RD["B`@("`@("`@("`@('-E=&QO8V%L
M92A,0U]#5%E012P@)&QA;F=U86=E*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=7!P97)S6R1S=')I;F==.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A('-T<FEN9R!W:71H('1H92!F:7)S="!L971T97(@8V%P:71A
M;&EZ960@:68@:70@:7,*("`@("`J(&%L<&AA8F5T:6,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@8F4@
M8V%P:71A;&EZ960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;&]C86QE("`@
M268@=')U92!T:&4@<W1R:6YG('=I;&P@8F4@8V]N=F5R=&5D(&)A<V5D(&]N
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G:79E;B!C:&%R
M<V5T+"!L;V-A;&4@:6YD97!E;F1E;G0@96QS92X*("`@("`J($!P87)A;2!S
M=')I;F<@("1C:&%R<V5T("!4:&4@8VAA<G-E="!T;R!U<V4L(&1E9F%U;'1S
M('1O(&-U<G)E;G0@8VAA<G-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&-A<&ET86QI>F5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@=6-F:7)S="@D<W1R:6YG+"`D;&]C86QE(#T@9F%L<V4L("1C:&%R
M<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&QO8V%L92D@>PH@("`@
M("`@("`@("`D9FER<W0@/2!3=')I;F<Z.G-U8G-T<B@D<W1R:6YG+"`P+"`Q
M+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF("A3=')I;F<Z.FES06QP:&$H
M)&9I<G-T+"`D8VAA<G-E="DI('L*("`@("`@("`@("`@("`@("1S=')I;F<@
M/2!3=')I;F<Z.G5P<&5R*"1F:7)S="P@=')U92P@)&-H87)S970I("X@4W1R
M:6YG.CIS=6)S='(H)'-T<FEN9RP@,2P@;G5L;"P@)&-H87)S970I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T<FEN
M9R`](%-T<FEN9SHZ=7!P97(H<W5B<W1R*"1S=')I;F<L(#`L(#$I+"!F86QS
M92D@+B!S=6)S='(H)'-T<FEN9RP@,2D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<W1R:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!P
M87)T(&]F(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@8F4@8V]N=F5R=&5D+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'-T87)T("`@5&AE('!A<G0G<R!S=&%R="!P;W-I
M=&EO;BP@>F5R;R!B87-E9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1L96YG
M=&@@(%1H92!P87)T)W,@;&5N9W1H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L8W5L871I;F<@
M=&AE('!A<G0G<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&]S
M:71I;VX@86YD(&QE;F=T:"P@9&5F875L=',@=&\@8W5R<F5N=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@8VAA<G-E="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN9R=S('!A<G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-U8G-T<B@D<W1R:6YG+"`D<W1A<G0L("1L96YG=&@@
M/2!N=6QL+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*%-T
M<FEN9SHZ97AT96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@
M("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@
M)&-H87)S970@/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&QE;F=T
M:"DI('L*("`@("`@("`@("`@("`@("1L96YG=&@@/2!3=')I;F<Z.FQE;F=T
M:"@D<W1R:6YG+"`D8VAA<G-E="D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)')E="`]($!M8E]S=6)S='(H)'-T<FEN9RP@)'-T87)T+"`D;&5N9W1H
M+"`D8VAA<G-E="D["B`@("`@("`@("`@(&EF("@A96UP='DH)')E="DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("AI<U]N=6QL*"1L96YG=&@I*2!["B`@("`@
M("`@("`@("1L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<W1R:6YG*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('-U8G-T<B@D<W1R:6YG+"`D<W1A<G0L
M("1L96YG=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8VAA<F%C=&5R("AN;W0@8GET92D@;&5N9W1H(&]F(&$@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@5&AE('-T<FEN9R!T
M;R!R971U<FX@=&AE(&QE;F=T:"!O9BX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-H87)S970@5&AE(&-H87)S970@=&\@=7-E('=H96X@8V%L8W5L871I;F<@
M=&AE('-T<FEN9R=S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&QE
M;F=T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-T<FEN
M9R=S('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QE;F=T:"@D<W1R:6YG
M+"`D8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH
M)&-H87)S970I*2!["B`@("`@("`@("`@("1C:&%R<V5T(#T@)$=,3T)!3%-;
M)U](3U)$15]35%))3D=?0TA!4E-%5"==.PH@("`@("`@('T*("`@("`@("`D
M8VAA<G-E="`](%-T<FEN9SHZ;&]W97(H)&-H87)S970I.PH@("`@("`@(&EF
M("@D8VAA<G-E="`]/2`G=71F+3@G('Q\("1C:&%R<V5T(#T]("=U=&8X)RD@
M>PH@("`@("`@("`@("!R971U<FX@<W1R;&5N*'5T9CA?9&5C;V1E*"1S=')I
M;F<I*3L*("`@("`@("!]"B`@("`@("`@:68@*%-T<FEN9SHZ97AT96YS:6]N
M17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@("1R970@/2!`;6)?
M<W1R;&5N*"1S=')I;F<L("1C:&%R<V5T*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D<F5T*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('-T<FQE;B@D
M<W1R:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YU
M;65R:6,@<&]S:71I;VX@;V8@=&AE(&9I<G-T(&]C8W5R<F5N8V4@;V8@)&YE
M961L90H@("`@("H@:6X@=&AE("1H87ES=&%C:R!S=')I;F<N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:&%Y<W1A8VL@(%1H92!S=')I;F<@=&\@
M<V5A<F-H('1H<F]U9V@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N965D;&4@
M("`@5&AE('-T<FEN9R!T;R!S96%R8V@@9F]R+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&]F9G-E="`@($%L;&]W<R!T;R!S<&5C:69Y('=H:6-H(&-H87)A
M8W1E<B!I;B!H87ES=&%C:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('1O('-T87)T('-E87)C:&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@
M)&-H87)S970@("!4:&4@8VAA<G-E="!T;R!U<V4@=VAE;B!S96%R8VAI;F<@
M9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("1N965D
M;&4@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE
M('!O<VET:6]N(&]F(&9I<G-T(&]C8W5R<F5N8V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!O<R@D:&%Y<W1A8VLL("1N965D;&4L("1O9F9S970@/2`P+"`D
M8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@:68@*%-T<FEN9SHZ97AT
M96YS:6]N17AI<W1S*"=M8G-T<FEN9R<I*2!["B`@("`@("`@("`@(&EF("AI
M<U]N=6QL*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@)&-H87)S970@
M/2`D1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D[
M"B`@("`@("`@("`@("1R970@/2!`;6)?<W1R<&]S*"1H87ES=&%C:RP@)&YE
M961L92P@)&]F9G-E="P@)&-H87)S970I.PH@("`@("`@("`@("!I;FE?<F5S
M=&]R92@G=')A8VM?97)R;W)S)RD["B`@("`@("`@("`@(&EF("@A:7-S970H
M)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5T
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=')P
M;W,H)&AA>7-T86-K+"`D;F5E9&QE+"`D;V9F<V5T*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@<&%D9&5D('1O(&$@8V5R=&%I
M;B!L96YG=&@@=VET:"!A;F]T:&5R('-T<FEN9RX*("`@("`J"B`@("`@*B!4
M:&ES(&UE=&AO9"!B96AA=F5S(&5X86-T;'D@;&EK92!S=')?<&%D(&)U="!I
M<R!M=6QT:6)Y=&4@<V%F92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I;G!U="`@("!4:&4@<W1R:6YG('1O(&)E('!A9&1E9"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1L96YG=&@@(%1H92!L96YG=&@@;V8@=&AE(')E<W5L
M=&EN9R!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P860@("`@("!4
M:&4@<W1R:6YG('1O('!A9"!T:&4@:6YP=70@<W1R:6YG('=I=&@N($UU<W0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&)E(&EN('1H92!S86UE
M(&-H87)S970@;&EK92!T:&4@:6YP=70@<W1R:6YG+@H@("`@("H@0'!A<F%M
M(&-O;G-T("1T>7!E("`@("`@5&AE('!A9&1I;F<@='EP92X@3VYE(&]F(%-4
M4E]0041?3$5&5"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(%-4
M4E]0041?4DE'2%0L(&]R(%-44E]0041?0D]42"X*("`@("`J($!P87)A;2!S
M=')I;F<@)&-H87)S970@(%1H92!C:&%R<V5T(&]F('1H92!I;G!U="!A;F0@
M=&AE('!A9&1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<FEN9W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P861D
M960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!P860H)&EN<'5T+"`D
M;&5N9W1H+"`D<&%D(#T@)R`G+"`D='EP92`](%-44E]0041?4DE'2%0L"B`@
M("`@("`@("`@("`@("`@)&-H87)S970@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1M8E]L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D:6YP=70L("1C:&%R<V5T
M*3L*("`@("`@("`D<V)?;&5N9W1H(#T@<W1R;&5N*"1I;G!U="D["B`@("`@
M("`@)'!A9%]L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D<&%D+"`D8VAA<G-E
M="D["@H@("`@("`@("\J(%)E='5R;B!I9B!W92!A;')E861Y(&AA=F4@=&AE
M(&QE;F=T:"X@*B\*("`@("`@("!I9B`H)&UB7VQE;F=T:"`^/2`D;&5N9W1H
M*2!["B`@("`@("`@("`@(')E='5R;B`D:6YP=70["B`@("`@("`@?0H*("`@
M("`@("`O*B!3:&]R=&-U="!F;W(@<VEN9VQE(&)Y=&4@<W1R:6YG<RX@*B\*
M("`@("`@("!I9B`H)&UB7VQE;F=T:"`]/2`D<V)?;&5N9W1H("8F("1P861?
M;&5N9W1H(#T]('-T<FQE;B@D<&%D*2D@>PH@("`@("`@("`@("!R971U<FX@
M<W1R7W!A9"@D:6YP=70L("1L96YG=&@L("1P860L("1T>7!E*3L*("`@("`@
M("!]"@H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E(%-4
M4E]0041?3$5&5#H*("`@("`@("`@("`@)&QE9G0@/2`D;&5N9W1H("T@)&UB
M7VQE;F=T:#L*("`@("`@("`@("`@)&]U='!U="`](%-T<FEN9SHZ<W5B<W1R
M*'-T<E]R97!E870H)'!A9"P@8V5I;"@D;&5F="`O("1P861?;&5N9W1H*2DL
M(#`L("1L969T+"`D8VAA<G-E="D@+B`D:6YP=70["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@(&-A<V4@4U127U!!1%]"3U1(.@H@("`@("`@("`@("`D
M;&5F="`](&9L;V]R*"@D;&5N9W1H("T@)&UB7VQE;F=T:"D@+R`R*3L*("`@
M("`@("`@("`@)')I9VAT(#T@8V5I;"@H)&QE;F=T:"`M("1M8E]L96YG=&@I
M("\@,BD["B`@("`@("`@("`@("1O=71P=70@/2!3=')I;F<Z.G-U8G-T<BAS
M=')?<F5P96%T*"1P860L(&-E:6PH)&QE9G0@+R`D<&%D7VQE;F=T:"DI+"`P
M+"`D;&5F="P@)&-H87)S970I("X*("`@("`@("`@("`@("`@("1I;G!U="`N
M"B`@("`@("`@("`@("`@("!3=')I;F<Z.G-U8G-T<BAS=')?<F5P96%T*"1P
M860L(&-E:6PH)')I9VAT("\@)'!A9%]L96YG=&@I*2P@,"P@)')I9VAT+"`D
M8VAA<G-E="D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@4U12
M7U!!1%]224=(5#H*("`@("`@("`@("`@)')I9VAT(#T@)&QE;F=T:"`M("1M
M8E]L96YG=&@["B`@("`@("`@("`@("1O=71P=70@/2`D:6YP=70@+B!3=')I
M;F<Z.G-U8G-T<BAS=')?<F5P96%T*"1P860L(&-E:6PH)')I9VAT("\@)'!A
M9%]L96YG=&@I*2P@,"P@)')I9VAT+"`D8VAA<G-E="D["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!7<F%P<R!T:&4@=&5X="!O9B!A(&UE<W-A
M9V4N"B`@("`@*@H@("`@("H@0'1O9&\@36%K92!M=6QT:6)Y=&4M<V%V92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@("`@("!3=')I
M;F<@8V]N=&%I;FEN9R!T:&4@=&5X="!T;R!W<F%P+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&QE;F=T:"`@("`@5W)A<"`D=&5X="!A="!T:&ES(&YU;6)E
M<B!O9B!C:&%R86-T97)S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8G)E86M?
M8VAA<B`@0VAA<F%C=&5R*',I('1O('5S92!W:&5N(&)R96%K:6YG(&QI;F5S
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@0VAA<F%C=&5R
M('-E="!T;R!U<V4@=VAE;B!B<F5A:VEN9R!L:6YE<RX*("`@("`J($!P87)A
M;2!B;V]L96%N("1Q=6]T92`@("`@($EG;F]R92!L:6YE<R!T:&%T(&%R92!W
M<F%P<&5D('=I=&@@=&AE("<^)PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8VAA<F%C=&5R("A21D,@,C8T-BD_($EF('1R=64L('=E(&1O
M;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F4@
M86YY('!A9&1I;F<@=VAI=&5S<&%C92!A="!T:&4@96YD(&]F"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@<W1R:6YG+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!3=')I;F<@8V]N=&%I;FEN9R!T:&4@
M=W)A<'!E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<F%P*"1T97AT
M+"`D;&5N9W1H(#T@.#`L("1B<F5A:U]C:&%R(#T@(EQN(BP@)&-H87)S970@
M/2!N=6QL+`H@("`@("`@("`@("`@("`@("`D<75O=&4@/2!F86QS92D*("`@
M('L*("`@("`@("`D<&%R86=R87!H<R`](&%R<F%Y*"D["@H@("`@("`@(&9O
M<F5A8V@@*'!R96=?<W!L:70H)R]<<C]<;B\G+"`D=&5X="D@87,@)&EN<'5T
M*2!["B`@("`@("`@("`@(&EF("@D<75O=&4@)B8@*'-T<G!O<R@D:6YP=70L
M("<^)RD@/3T](#`I*2!["B`@("`@("`@("`@("`@("`D;&EN92`]("1I;G!U
M=#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J(%=E
M(&YE960@=&\@:&%N9&QE('1H92!5<V5N970M<W1Y;&4@<VEG;F%T=7)E(&QI
M;F4*("`@("`@("`@("`@("`@("`J('-E<&%R871E;'D[('-I;F-E('1H92!S
M<&%C92!A9G1E<B!T:&4@='=O(&1A<VAE<R!I<PH@("`@("`@("`@("`@("`@
M("H@4D5154E2140L('=E(&1O;B=T('=A;G0@=&\@=')I;2!T:&4@;&EN92X@
M*B\*("`@("`@("`@("`@("`@(&EF("@D:6YP=70@(3T@)RTM("<I('L*("`@
M("`@("`@("`@("`@("`@("`D:6YP=70@/2!R=')I;2@D:6YP=70I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QI;F4@/2!W;W)D=W)A
M<"@D:6YP=70L("1L96YG=&@L("1B<F5A:U]C:&%R*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'!A<F%G<F%P:'-;72`]("1L:6YE.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)&)R96%K7V-H87(L("1P87)A
M9W)A<&AS*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I
M9B!T:&4@979E<GD@8VAA<F%C=&5R(&EN('1H92!P87)A;65T97(@:7,@86X*
M("`@("`J(&%L<&AA8F5T:6,@8VAA<F%C=&5R+B!4:&ES(&UE=&AO9"!D;V5S
M;B=T('=O<FL@=VET:"!A;GD@8VAA<G-E=`H@("`@("H@;W1H97(@=&AA;B!T
M:&4@8W5R<F5N="!C:&%R<V5T('EE="X*("`@("`J"B`@("`@*B!`<&%R86T@
M)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@=&5S="X*("`@("`J($!P87)A;2`D
M8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H96X@=&5S=&EN9R!T:&4@
M<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T:&4@<&%R86UE=&5R('=A<R!A;'!H86)E=&EC(&]N;'DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES06QP:&$H)'-T<FEN9RP@)&-H87)S970@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("A3=')I;F<Z.F5X=&5N<VEO;D5X:7-T<R@G
M;6)S=')I;F<G*2D@>PH@("`@("`@("`@("`D;VQD7V-H87)S970@/2!M8E]R
M96=E>%]E;F-O9&EN9R@I.PH@("`@("`@("`@("!I9B`H)&-H87)S970@(3T@
M)&]L9%]C:&%R<V5T*2!["B`@("`@("`@("`@("`@("!`;6)?<F5G97A?96YC
M;V1I;F<H)&-H87)S970I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A
M;'!H82`]("%M8E]E<F5G7VUA=&-H*"=;7ELZ86QP:&$Z75TG+"`D<W1R:6YG
M*3L*("`@("`@("`@("`@:68@*"1C:&%R<V5T("$]("1O;&1?8VAA<G-E="D@
M>PH@("`@("`@("`@("`@("`@0&UB7W)E9V5X7V5N8V]D:6YG*"1O;&1?8VAA
M<G-E="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1A;'!H
M83L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!C='EP95]A;'!H82@D<W1R
M:6YG*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=')U92!I9B!E
M=F5R>2!C:&%R86-T97(@:6X@=&AE('!A<F%M971E<B!I<R!A(&QO=V5R8V%S
M90H@("`@("H@;&5T=&5R(&EN('1H92!C=7)R96YT(&QO8V%L92X*("`@("`J
M"B`@("`@*B!`<&%R86T@)'-T<FEN9R`@(%1H92!S=')I;F<@=&\@=&5S="X*
M("`@("`J($!P87)A;2`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@=7-E('=H
M96X@=&5S=&EN9R!T:&4@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!I9B!T:&4@<&%R86UE=&5R('=A<R!L;W=E<F-A<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES3&]W97(H)'-T<FEN9RP@)&-H87)S
M970@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B`H*%-T<FEN9SHZ;&]W
M97(H)'-T<FEN9RP@=')U92P@)&-H87)S970I(#T]/2`D<W1R:6YG*2`F)@H@
M("`@("`@("`@("`@("`@4W1R:6YG.CII<T%L<&AA*"1S=')I;F<L("1C:&%R
M<V5T*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1R=64@:68@
M979E<GD@8VAA<F%C=&5R(&EN('1H92!P87)A;65T97(@:7,@86X*("`@("`J
M('5P<&5R8V%S92!L971T97(@:6X@=&AE(&-U<G)E;G0@;&]C86QE+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<FEN9R`@(%1H92!S=')I;F<@
M=&\@=&5S="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C
M:&%R<V5T('1O('5S92!W:&5N('1E<W1I;F<@=&AE('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE('!A<F%M971E
M<B!W87,@=7!P97)C87-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<U5P<&5R
M*"1S=')I;F<L("1C:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!R971U
M<FX@*"A3=')I;F<Z.G5P<&5R*"1S=')I;F<L('1R=64L("1C:&%R<V5T*2`]
M/3T@)'-T<FEN9RD@)B8*("`@("`@("`@("`@("`@(%-T<FEN9SHZ:7-!;'!H
M82@D<W1R:6YG+"`D8VAA<G-E="DI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4&5R9F]R;7,@82!M=6QT:6)Y=&4@<V%F92!R96=E>"!M871C:"!S96%R8V@@
M;VX@=&AE('1E>'0@<')O=FED960N"B`@("`@*@H@("`@("H@0'-I;F-E($AO
M<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("`@
M(%1H92!T97AT('1O('-E87)C:"X*("`@("`J($!P87)A;2!A<G)A>2`D<F5G
M97@@("`@(%1H92!R96=U;&%R(&5X<')E<W-I;VYS('1O('5S92P@=VET:&]U
M="!P97)L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!R96=E>"!D
M96QI;6ET97)S("AE+F<N("<O)R!O<B`G?"<I+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A8W1E<B!S970@;V8@=&AE('1E>'0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&UA=&-H97,@87)R
M87D@9G)O;2!T:&4@9FER<W0@<F5G97@@=&AA="!M871C:&5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96=E>$UA=&-H*"1T97AT+"`D<F5G97@L("1C:&%R
M<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T
M*2D@>PH@("`@("`@("`@("`D<F5G97@@/2!3=')I;F<Z.F-O;G9E<G1#:&%R
M<V5T*"1R96=E>"P@)&-H87)S970L("=U=&8M."<I.PH@("`@("`@("`@("`D
M=&5X="`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'1E>'0L("1C:&%R<V5T
M+"`G=71F+3@G*3L*("`@("`@("!]"@H@("`@("`@("1M871C:&5S(#T@87)R
M87DH*3L*("`@("`@("!F;W)E86-H("@D<F5G97@@87,@)'9A;"D@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+R<@+B`D=F%L("X@)R]U)RP@)'1E
M>'0L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH)&-H87)S
M970I*2!["B`@("`@("`@("`@("1M871C:&5S(#T@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D;6%T8VAE<RP@)W5T9BTX)RP@)&-H87)S970I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1M871C:&5S.PH@("`@?0H*?0H`````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].;W1I9FEC871I;VXN
M<&AP````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S`S,B`Q
M,#4Q-30S-#$T,"`P,C(U,#$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%1H92!.;W1I9FEC871I;VXZ
M.B!C;&%S<R!P<F]V:61E<R!A('-U8FIE8W0M;V)S97)V97(@<&%T=&5R;B!F
M;W(*("H@<F%I<VEN9R!A;F0@<VAO=VEN9R!M97-S86=E<R!O9B!D:69F97)E
M;G0@='EP97,@86YD('1O(&1I9F9E<F5N=`H@*B!L:7-T96YE<G,N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXN
M<&AP+'8@,2XT-BXR+C$Q(#(P,#8O,#$O,3@@,34Z,3DZ,#$@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!3
M8VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N
M,0H@*B!`<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO
M=&EF:6-A=&EO;B!["@H@("`@+RHJ"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@
M86QL(&%T=&%C:&5D(&QI<W1E;F5R(&]B:F5C=',N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE('-E<W-I;VX@
M=F%R:6%B;&4@=VAE<F4@=V4@<W1O<F4@=&AE(&UE<W-A9V5S+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-T86-K(#T@
M)VAO<F1E365S<V%G95-T86-K<R<["@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@<F5F97)E;F-E('1O('1H92!G;&]B86P@3F]T:69I8V%T:6]N(&]B:F5C
M="P@;VYL>0H@("`@("H@8W)E871I;F<@:70@:68@:70@9&]E<VXG="!A;')E
M861Y(&5X:7-T+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@
M:6YV;VME9"!A<SH*("`@("`J("`@)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC
M871I;VXZ.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<W1A8VL@(%1H92!N86UE(&]F('1H92!M97-S86=E('-T86-K('1O('5S
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N($YO=&EF:6-A=&EO;B`@5&AE($AO
M<F1E($YO=&EF:6-A=&EO;B!I;G-T86YC92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D<W1A8VL@/2`G:&]R9&5-97-S86=E4W1A8VMS)RD*
M("`@('L*("`@("`@("!S=&%T:6,@)&YO=&EF:6-A=&EO;B`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@A:7-S970H)&YO=&EF:6-A=&EO;ELD<W1A8VM=*2D@
M>PH@("`@("`@("`@("`D;F]T:69I8V%T:6]N6R1S=&%C:UT@/2!N97<@3F]T
M:69I8V%T:6]N*"1S=&%C:RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&YO=&EF:6-A=&EO;ELD<W1A8VM=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M26YI=&EA;&EZ92!T:&4@;F]T:69I8V%T:6]N('-Y<W1E;2P@<V5T('5P(&%N
M>2!N965D960@<V5S<VEO;@H@("`@("H@=F%R:6%B;&5S+"!E=&,N(%-H;W5L
M9"!N979E<B!B92!C86QL960@97AC97!T(&)Y"B`@("`@*B`F3F]T:69I8V%T
M:6]N.CIS:6YG;&5T;VXH*3L*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=&%C:R`@5&AE(&YA;64@;V8@=&AE(&UE<W-A9V4@<W1A8VL@=&\@=7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VXH)'-T86-K(#T@
M)VAO<F1E365S<V%G95-T86-K<R<I"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M=&%C:R`]("1S=&%C:SL*"B`@("`@("`@+RH@36%K92!S=7)E('1H92!M97-S
M86=E('-T86-K(&ES(')E9VES=&5R960@:6X@=&AE('-E<W-I;VXL"B`@("`@
M("`@("H@86YD(&]B=&%I;B!A(&=L;V)A;"US8V]P92!R969E<F5N8V4@=&\@
M:70N("HO"B`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]S
M=&%C:UTI*2!["B`@("`@("`@("`@("1?4T534TE/3ELD=&AI<RT^7W-T86-K
M72`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5G:7-T97)S(&$@;&ES=&5N97(@=VET:"!T:&4@;F]T:69I8V%T:6]N(&]B
M:F5C="!A;F0@:6YC;'5D97,*("`@("`J('1H92!N96-E<W-A<GD@;&EB<F%R
M>2!F:6QE(&1Y;F%M:6-A;&QY+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1R:79E<B`@5&AE(&YA;64@;V8@=&AE(&QI<W1E;F5R('1O(&%T=&%C
M:"X@5&AE<V4@;F%M97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M;75S="!B92!U;FEQ=64[(&9U<G1H97(@;&ES=&5N97)S('=I=&@@=&AE('-A
M;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@;F%M92!W:6QL(&)E
M(&EG;F]R960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S
M:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A
M;65T97)S(&$@;&ES=&5N97(@9')I=F5R(&UI9VAT"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&YE960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;&%S<R`@(%1H92!C;&%S<R!N86UE(&9R;VT@=VAI8V@@=&AE(&1R:79E<B!W
M87,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N=&EA=&5D
M(&EF(&YO="!T:&4@9&5F875L="!O;F4N($EF(&=I=F5N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@('EO=2!H879E('1O(&EN8VQU9&4@=&AE(&QI
M8G)A<GD@9FEL92!C;VYT86EN:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@('1H:7,@8VQA<W,@>6]U<G-E;&8N(%1H:7,@:7,@=7-E9G5L(&EF
M('EO=2!W86YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!L
M:7-T96YE<B!D<FEV97(@=&\@8F4@;W9E<G)I9&5N(&)Y(&%N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&%P<&QI8V%T:6]N)W,@:6UP;&5M96YT
M871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N("9A='1A8V@H)&QI<W1E;F5R
M+"`D<&%R86US(#T@87)R87DH*2P@)&-L87-S(#T@;G5L;"D*("`@('L*("`@
M("`@("`D;&ES=&5N97(@/2!B87-E;F%M92@D;&ES=&5N97(I.PH@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE
M<ET["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8VQA<W,I*2![
M"B`@("`@("`@("`@($!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+TYO=&EF:6-A=&EO;B],:7-T96YE<B\G("X@)&QI<W1E;F5R("X@)RYP
M:'`G.PH@("`@("`@("`@("`D8VQA<W,@/2`G3F]T:69I8V%T:6]N7TQI<W1E
M;F5R7R<@+B`D;&ES=&5N97(["B`@("`@("`@?0H@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E
M;F5R<ULD;&ES=&5N97)=(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@
M("`@("`@(&EF("@A:7-S970H)%]315-324].6R1T:&ES+3Y?<W1A8VM=6R1L
M:7-T96YE<ETI*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M
M/E]S=&%C:UU;)&QI<W1E;F5R72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE
M<ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9B@G3F]T:69I8V%T:6]N(&QI<W1E;F5R("5S
M(&YO="!F;W5N9"XG+"`D;&ES=&5N97(I*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F4@82!L:7-T96YE<B!F<F]M('1H92!N;W1I
M9FEC871I;VX@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L
M:7-T;F5R("!4:&4@;F%M92!O9B!T:&4@;&ES=&5N97(@=&\@9&5T86-H+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D971A8V@H)&QI<W1E;F5R*0H@("`@>PH@
M("`@("`@("1L:7-T96YE<B`](&)A<V5N86UE*"1L:7-T96YE<BD["B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N97)=*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*"=.;W1I9FEC871I;VX@;&ES=&5N97(@)7,@;F]T(&9O=6YD+B<L("1L:7-T
M96YE<BDI.PH@("`@("`@('T*"B`@("`@("`@)&QI<W0@/2`D=&AI<RT^7VQI
M<W1E;F5R<ULD;&ES=&5N97)=.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?;&ES
M=&5N97)S6R1L:7-T96YE<ETI.PH@("`@("`@('5N<V5T*"1?4T534TE/3ELD
M=&AI<RT^7W-T86-K75LD;&ES="T^9V5T3F%M92@I72D["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@86X@979E;G0@
M=&\@=&AE($AO<F1E(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@5&AE
M(&5V96YT('1Y<&4@<&%R86UE=&5R('-H;W5L9"!B96=I;B!W:71H("=H;W)D
M92XG('5N;&5S<R!T:&4*("`@("`J(&%P<&QI8V%T:6]N(&1E9FEN97,@:71S
M(&]W;B!.;W1I9FEC871I;VY?3&ES=&5N97(@<W5B8VQA<W,@=&AA=`H@("`@
M("H@:&%N9&QE<R!A9&1I=&EO;F%L(&-O9&5S+@H@("`@("H*("`@("`J($!P
M87)A;2!M:7AE9"`D979E;G0@("!.;W1I9FEC871I;VY?179E;G0@;V)J96-T
M(&]R(&UE<W-A9V4@<W1R:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'1Y
M<&4@(%1H92!T>7!E(&]F(&UE<W-A9V4Z("=H;W)D92YE<G)O<B<L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G=A<FYI;F<G+"`G:&]R
M9&4N<W5C8V5S<R<L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M)VAO<F1E+FUE<W-A9V4G+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F;&%G<R`@
M($%R<F%Y(&]F(&]P=&EO;F%L(&9L86=S('1H870@=VEL;"!B92!P87-S960@
M=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5G:7-T97)E
M9"!L:7-T96YE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<V@H)&5V96YT
M+"`D='EP92`](&YU;&PL("1F;&%G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@:68@*"%I<U]A*"1E=F5N="P@)TYO=&EF:6-A=&EO;E]%=F5N="<I("8F
M"B`@("`@("`@("`@("%I<U]A*"1E=F5N="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`O*B!4<F%N<W!A<F5N=&QY(&-R96%T92!A($YO=&EF:6-A
M=&EO;E]%=F5N="!O8FIE8W0@86YD"B`@("`@("`@("`@("`J('-E="!T:&4@
M;65S<V%G92!A='1R:6)U=&4N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O3F]T:69I8V%T:6]N+T5V96YT+G!H
M<"<["B`@("`@("`@("`@("1E=F5N="`]("9N97<@3F]T:69I8V%T:6]N7T5V
M96YT*"1E=F5N="D["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1E=F5N
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M>7!E*2D@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`G:&]R9&4N97)R;W(G
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"1E=F5N="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1Y<&4I*2!["B`@("`@
M("`@("`@("1T>7!E(#T@)VAO<F1E+FUE<W-A9V4G.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]L:7-T96YE<G,@87,@)&QI<W1E;F5R
M*2!["B`@("`@("`@("`@(&EF("@D;&ES=&5N97(M/FAA;F1L97,H)'1Y<&4I
M*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]S=&%C:UU;
M)&QI<W1E;F5R+3YG971.86UE*"E=6UT@/0H@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=T>7!E)R`]/B`D='EP92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8VQA<W,G(#T^(&=E=%]C;&%S<R@D979E;G0I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("=E=F5N="<@/3X@<V5R:6%L:7IE*"1E=F5N="DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)V9L86=S)R`]/B!S97)I86QI
M>F4H)&9L86=S*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!087-S97,@=&AE(&UE<W-A9V4@<W1A8VL@=&\@86QL
M(&QI<W1E;F5R<R!A;F0@87-K<R!T:&5M('1O"B`@("`@*B!H86YD;&4@=&AE
M:7(@;65S<V%G97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1O<'1I
M;VYS("!!;B!A<G)A>2!C;VYT86EN:6YG(&1I<W!L87D@;W!T:6]N<R!F;W(@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W1E;F5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F]T:69Y*"1O<'1I;VYS(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=L:7-T96YE
M<G,G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)VQI<W1E;F5R<R==(#T@
M87)R87E?:V5Y<R@D=&AI<RT^7VQI<W1E;F5R<RD["B`@("`@("`@?2!E;'-E
M:68@*"%I<U]A<G)A>2@D;W!T:6]N<ULG;&ES=&5N97)S)UTI*2!["B`@("`@
M("`@("`@("1O<'1I;VYS6R=L:7-T96YE<G,G72`](&%R<F%Y*"1O<'1I;VYS
M6R=L:7-T96YE<G,G72D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1O
M<'1I;VYS6R=L:7-T96YE<G,G72!A<R`D;&ES=&5N97(I('L*("`@("`@("`@
M("`@)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R72T^;F]T:69Y*"1?4T53
M4TE/3ELD=&AI<RT^7W-T86-K75LD=&AI<RT^7VQI<W1E;F5R<ULD;&ES=&5N
M97)=+3YG971.86UE*"E=+"`D;W!T:6]N<RD["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N=6UB97(@;V8@;F]T:69I8V%T
M:6]N(&UE<W-A9V5S(&EN('1H92!S=&%C:RX*("`@("`J"B`@("`@*B!`875T
M:&]R($1A=FED(%5L979I=&-H(#QD879I9'5`979E<GED;G,N;F5T/@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&UY7VQI<W1E;F5R("!4:&4@;F%M
M92!O9B!T:&4@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!4:&4@;G5M8F5R(&]F(&UE<W-A9V5S(&EN('1H92!S=&%C:RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]U;G0H)&UY7VQI<W1E;F5R(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D;7E?;&ES=&5N97(I*2!["B`@
M("`@("`@("`@("1C;W5N="`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?;&ES=&5N97)S(&%S("1L:7-T96YE<BD@>PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N
M97(M/F=E=$YA;64H*5TI*2!["B`@("`@("`@("`@("`@("`@("`@)&-O=6YT
M("L](&-O=6YT*"1?4T534TE/3ELD=&AI<RT^7W-T86-K75LD;&ES=&5N97(M
M/F=E=$YA;64H*5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B`D8V]U;G0["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N($!C;W5N="@D7U-%4U-)3TY;)'1H:7,M/E]S
M=&%C:UU;)'1H:7,M/E]L:7-T96YE<G-;)&UY7VQI<W1E;F5R72T^9V5T3F%M
M92@I72D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O5F%R:6%B;&5S+G!H<```````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,34U-C0@,3`U,34T,S0Q-#`@,#(Q-S<S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]!<G)A>2YP:'`G.PH*+RHJ"B`J(%9A<FEA8FQE<SHZ(&-L87-S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]5=&EL+U9A<FEA8FQE<RYP:'`L=B`Q+C@N
M,3`N-B`R,#`V+S`S+S(X(#$R.C,Q.C$R(&IA;B!%>'`@)`H@*@H@*B!`875T
M:&]R("!2;V)E<G0@12X@0V]Y;&4@/')O8F5R=&5C;WEL94!H;W1M86EL+F-O
M;3X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!P86-K86=E($AO<F1E7U5T:6P*("HO"F-L87-S(%9A<FEA8FQE
M<R!["@H@("`@=F%R("1?=F%R<SL*("`@('9A<B`D7V5X<&5C=&5D5F%R:6%B
M;&5S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!687)I86)L97,H)'9A<G,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1V87)S*2D@
M>PH@("`@("`@("`@("`D=F%R<R`](%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S
M*"1?4D5154535"D["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=F%R
M<ULG7V9O<FUV87)S)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?97AP96-T
M961687)I86)L97,@/2!`=6YS97)I86QI>F4H)'9A<G-;)U]F;W)M=F%R<R==
M*3L*("`@("`@("`@("`@=6YS970H)'9A<G-;)U]F;W)M=F%R<R==*3L*("`@
M("`@("!]"B`@("`@("`@)'1H:7,M/E]V87)S(#T@)'9A<G,["B`@("!]"@H@
M("`@9G5N8W1I;VX@)F=E=$1E9F%U;'1687)I86)L97,H*0H@("`@>PH@("`@
M("`@("1V87)S(#T@)FYE=R!687)I86)L97,H571I;#HZ9&ES<&5L36%G:6-1
M=6]T97,H)%]215%515-4*2D["B`@("`@("`@<F5T=7)N("1V87)S.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&5X:7-T<R@D=F%R;F%M92D*("`@('L*("`@("`@
M("!I9B`H8V]U;G0H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RD@)B8*("`@
M("`@("`@("`@)'1H:7,M/E]E>&ES=',H)'1H:7,M/E]E>'!E8W1E9%9A<FEA
M8FQE<RP@)'9A<FYA;64L(&9A;'-E*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AI<W1S
M*"1T:&ES+3Y?=F%R<RP@)'9A<FYA;64L(&9A;'-E*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!G970H)'9A<FYA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]G
M971%>&ES=',H)'1H:7,M/E]V87)S+"`D=F%R;F%M92P@)'9A;'5E*3L*("`@
M("`@("!R971U<FX@)'9A;'5E.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5X
M:7-T<R@D=F%R;F%M92P@)B1E>&ES=',I"B`@("!["B`@("`@("`@)&5X:7-T
M<R`]("1T:&ES+3Y?9V5T17AI<W1S*"1T:&ES+3Y?=F%R<RP@)'9A<FYA;64L
M("1V86QU92D["B`@("`@("`@<F5T=7)N("1V86QU93L*("`@('T*"B`@("!F
M=6YC=&EO;B!S970H)'9A<FYA;64L("1V86QU92D*("`@('L*("`@("`@("`D
M:V5Y<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"%(;W)D95]!<G)A>3HZ9V5T
M07)R87E087)T<R@D=F%R;F%M92P@)&)A<V4L("1K97ES*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W9A<G-;)'9A<FYA;65=(#T@)'9A;'5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&ME>7,L("1B
M87-E*3L*("`@("`@("`@("`@)'!L86-E(#T@)B1T:&ES+3Y?=F%R<SL*"B`@
M("`@("`@("`@('=H:6QE("AC;W5N="@D:V5Y<RDI('L*("`@("`@("`@("`@
M("`@("1K97D@/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1P;&%C95LD:V5Y72DI('L*("`@("`@("`@("`@("`@
M("`@("`D<&QA8V5;)&ME>5T@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'!L86-E(#T@)B1P;&%C95LD:V5Y73L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)'!L86-E(#T@)'9A;'5E.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!M97)G92@D=F%R<RD*("`@('L*
M("`@("`@("!F;W)E86-H("@D=F%R<R!A<R`D=F%R;F%M92`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@)'1H:7,M/G-E="@D=F%R;F%M92P@)'9A;'5E*3L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D*"1V87)N86UE+"`D
M=F%L=64I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)'9A<FYA
M;64I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/E]V87)S6R1V87)N86UE72`]("1V86QU93L*("`@('T*
M"B`@("!F=6YC=&EO;B!R96UO=F4H)'9A<FYA;64I"B`@("!["B`@("`@("`@
M2&]R9&5?07)R87DZ.F=E=$%R<F%Y4&%R=',H)'9A<FYA;64L("1B87-E+"`D
M:V5Y<RD["B`@("`@("`@:68@*"%I<U]N=6QL*"1B87-E*2D@>PH@("`@("`@
M("`@("`D<'1R(#T@)B1T:&ES+3Y?=F%R<ULD8F%S95T["B`@("`@("`@("`@
M("1E;F0@/2!C;W5N="@D:V5Y<RD@+2`Q.PH@("`@("`@("`@("!F;W)E86-H
M("@D:V5Y<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'!T<ELD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D
M96YD(#T]("1K97DI('L*("`@("`@("`@("`@("`@("`@("!A<G)A>5]S<&QI
M8V4H)'!T<BP@87)R87E?<V5A<F-H*"1V86PL(&%R<F%Y7VME>7,H)'!T<BDI
M+"`Q*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'!T<B`]("8D<'1R6R1V86Q=.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]V87)S6R1V87)N86UE72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@1FEN9"!O=70@=VAE=&AE<B!O<B!N;W0@)'9A<FYA
M;64@=V%S('-E="!I;B`D87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&%R<F%Y("`@
M("`@("`@("`@("`@("`@(%1H92!A<G)A>2!T;R!S96%R8V@@:6X@*'5S=6%L
M;'D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!E:71H97(@)'1H:7,M/E]V87)S(&]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!E8W1E
M9%9A<FEA8FQE<RDN"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=F%R;F%M92`@
M("`@("`@("`@("`@("`@5&AE(&YA;64@;V8@=&AE('9A<FEA8FQE('1O(&QO
M;VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F;W(N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8VAE8VM%>'!E8W1E
M9%9A<FEA8FQE<R`@268@=V4@9&]N)W0@9FEN9"`D=F%R;F%M92P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:&]U
M;&0@=V4@8VAE8VL*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S('1O('-E
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF('-H;W5L9"!H879E(&5X:7-T960@*&QI:V4@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H96-K8F]X
M(&]R('-E;&5C="!M=6QT:7!L92DN"B`@("`@*@H@("`@("H@0')E='5R;B`@
M5VAE=&AE<B!O<B!N;W0@=&AE('9A<FEA8FQE('=A<R!S970@*&]R+"!I9B!W
M92=V92!C:&5C:V5D"B`@("`@*B`@("`@("`@("`D=&AI<RT^7V5X<&5C=&5D
M5F%R:6%B;&5S+"!S:&]U;&0@:&%V92!B965N('-E="DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]E>&ES=',H)&%R<F%Y+"`D=F%R;F%M92P@)&-H96-K17AP
M96-T961687)I86)L97,@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V=E=$5X:7-T<R@D87)R87DL("1V87)N86UE+"`D=F%L=64L("1C
M:&5C:T5X<&5C=&5D5F%R:6%B;&5S*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($9E=&-H('1H92!R97%U97-T960@=F%R:6%B;&4@*"1V87)N86UE*2!I;G1O
M("1V86QU92P@86YD(')E='5R;@H@("`@("H@=VAE=&AE<B!O<B!N;W0@=&AE
M('9A<FEA8FQE('=A<R!S970@:6X@)&%R<F%Y+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@("1A
M<G)A>2`@("`@("`@("`@("`@("`@("!4:&4@87)R87D@=&\@<V5A<F-H(&EN
M("AU<W5A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@96ET:&5R("1T:&ES+3Y?=F%R<R!O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M97AP96-T961687)I86)L97,I+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'9A
M<FYA;64@("`@("`@("`@("`@("`@(%1H92!N86UE(&]F('1H92!V87)I86)L
M92!T;R!L;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R+@H@("`@("H@0'!A<F%M(&UI>&5D("`F)'9A;'5E
M("`@("`@("`@("`@("`@("`@("1V87)N86UE)W,@=F%L=64@9V5T<R!A<W-I
M9VYE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1O+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1H:7,@=F%R:6%B;&4N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`@268@=V4@9&]N)W0@9FEN
M9"`D=F%R;F%M92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!S:&]U;&0@=V4@8VAE8VL*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5X<&5C
M=&5D5F%R:6%B;&5S('1O('-E90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF(&ET('-H;W5L9"!H879E(&5X:7-T
M960@*&QI:V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A(&-H96-K8F]X(&]R('-E;&5C="!M=6QT:7!L92DN"B`@
M("`@*@H@("`@("H@0')E='5R;B`@5VAE=&AE<B!O<B!N;W0@=&AE('9A<FEA
M8FQE('=A<R!S970@*&]R+"!I9B!W92=V92!C:&5C:V5D"B`@("`@*B`@("`@
M("`@("`D=&AI<RT^7V5X<&5C=&5D5F%R:6%B;&5S+"!S:&]U;&0@:&%V92!B
M965N('-E="DN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971%>&ES=',H)&%R
M<F%Y+"`D=F%R;F%M92P@)B1V86QU92P@)&-H96-K17AP96-T961687)I86)L
M97,@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("A(;W)D95]!<G)A>3HZ9V5T
M07)R87E087)T<R@D=F%R;F%M92P@)&)A<V4L("1K97ES*2D@>PH@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1A<G)A>5LD8F%S95TI*2!["B`@("`@("`@("`@
M("`@("`D=F%L=64@/2!N=6QL.PH@("`@("`@("`@("`@("`@+R\@268@=V4G
M<F4@<W5P<&]S960@=&\@8VAE8VL@)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE
M<RP@9&\@<V\L"B`@("`@("`@("`@("`@("`O+R!B=70@;6%K92!S=7)E(&YO
M="!T;R!C:&5C:R!I="!A9V%I;BX*("`@("`@("`@("`@("`@(')E='5R;B`D
M8VAE8VM%>'!E8W1E9%9A<FEA8FQE<R`_("1T:&ES+3Y?97AI<W1S*"1T:&ES
M+3Y?97AP96-T961687)I86)L97,L("1V87)N86UE+"!F86QS92D@.B!F86QS
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S96%R
M8VAS<&%C92`]("8D87)R87E;)&)A<V5=.PH@("`@("`@("`@("`@("`@=VAI
M;&4@*&-O=6YT*"1K97ES*2D@>PH@("`@("`@("`@("`@("`@("`@("1K97D@
M/2!A<G)A>5]S:&EF="@D:V5Y<RD["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<V5A<F-H<W!A8V5;)&ME>5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1V86QU92`](&YU;&P["B`@("`@("`@("`@("`@("`@("`@
M("`@("\O($EF('=E)W)E('-U<'!O<V5D('1O(&-H96-K"B`@("`@("`@("`@
M("`@("`@("`@("`@("\O("1T:&ES+3Y?97AP96-T961687)I86)L97,L(&1O
M('-O+"!B=70@;6%K90H@("`@("`@("`@("`@("`@("`@("`@("`O+R!S=7)E
M(&YO="!T;R!C:&5C:R!I="!A9V%I;BX*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1C:&5C:T5X<&5C=&5D5F%R:6%B;&5S(#\@)'1H:7,M/E]E
M>&ES=',H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@)'9A<FYA;64L(&9A
M;'-E*2`Z(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D<V5A<F-H<W!A8V4@/2`F)'-E87)C:'-P86-E6R1K97E=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M)'-E87)C:'-P86-E.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F%L
M=64@/2!I<W-E="@D87)R87E;)'9A<FYA;65=*2`_("1A<G)A>5LD=F%R;F%M
M95T@.B!N=6QL.PH@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'9A;'5E*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@
M96QS96EF("@D8VAE8VM%>'!E8W1E9%9A<FEA8FQE<RD@>PH@("`@("`@("`@
M("`@("`@+R\@268@=V4G<F4@<W5P<&]S960@=&\@8VAE8VL*("`@("`@("`@
M("`@("`@("\O("1T:&ES+3Y?97AP96-T961687)I86)L97,L(&1O('-O+"!B
M=70@;6%K92!S=7)E(&YO=`H@("`@("`@("`@("`@("`@+R\@=&\@8VAE8VL@
M:70@86=A:6XN"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E>&ES
M=',H)'1H:7,M/E]E>'!E8W1E9%9A<FEA8FQE<RP@)'9A<FYA;64L(&9A;'-E
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]N9FEG+G!H
M<```````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q-#<Q
M,3(@,3`U,34T,S0Q-#`@,#(Q,C8S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E
M+T9O<FTN<&AP)SL*"B\J*@H@*B!4:&4@0V]N9FEG.CH@<&%C:V%G92!P<F]V
M:61E<R!A(&9R86UE=V]R:R!F;W(@;6%N86=I;F<@=&AE"B`J(&-O;F9I9W5R
M871I;VX@;V8@2&]R9&4@87!P;&EC871I;VYS+"!W<FET:6YG(&-O;F8N<&AP
M(&9I;&5S(&9R;VT*("H@8V]N9BYX;6P@<V]U<F-E(&9I;&5S+"!G96YE<F%T
M:6YG('5S97(@:6YT97)F86-E<RP@971C+@H@*@H@*B!4:&4@2&]R9&5?0V]N
M9FEG7TYO9&4@1$]-(&-L87-S97,@86YD('-U8F-L87-S97,*("H@*$AO<F1E
M7T-O;F9I9U]$;V-U;65N="P@2&]R9&5?0V]N9FEG7T5L96UE;G0I(&%R92!S
M:6UP;'D@;6%S<V%G960*("H@9G)O;2!C;V1E('=R:71T96X@8GD@=&\@96UU
M;&%T92!02%`T)W,@1$]-6$U,(&5X=&5N<VEO;B!W:71H(%!(4#4G<PH@*B!$
M3TT@<W5P<&]R="X@3VYL>2!C:&%N9V5S(&%R92!N86UI;F<@86YD('-Y;G1A
M8W1I8R!S=6=A<B](;W)D90H@*B!C;V1I;F<@<W1A;F1A<F1S.R!A;&P@8W)E
M9&ET(&=O97,@=&\@06QE>&%N9')E(&%N9"!T:&4@8V]D92!I<R!U<V5D"B`J
M('=I=&@@:&ES('!E<FUI<W-I;VXN($AI<R!O<FEG:6YA;"!C;V1E(&-A;B!B
M92!F;W5N9"!A=#H*("H*("H@("!H='1P.B\O86QE>&%N9')E+F%L87!E=&ET
M92YN970O9&]C+6%L97@O9&]M>&UL+7!H<#0M<&AP-2\*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO2&]R9&4O2&]R9&4O0V]N9FEG+G!H<"QV(#$N.#`N,BXR
M-B`R,#`V+S`V+S`Q(#(S.C0T.C,R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]&<F%M97=O<FL*("HO"F-L87-S($AO<F1E7T-O;F9I
M9R!["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@8V]N9FEG=7)E
M9"!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]A<'`["@H@("`@+RHJ"B`@("`@*B!4:&4@6$U,('1R
M964@;V8@=&AE(&-O;F9I9W5R871I;VX@9FEL92!T<F%V97)S960@=&\@86X*
M("`@("`J(&%S<V]C:6%T:79E(&%R<F%Y+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?>&UL0V]N9FEG5')E92`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!O9B!T:&4@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]P:'!#;VYF:6<["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8V]N=&5N="!O9B!T:&4@;VQD(&-O;F9I9W5R871I;VX@9FEL92X*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]O
M;&1#;VYF:6<["@H@("`@+RHJ"B`@("`@*B!4:&4@;6%N=6%L(&-O;F9I9W5R
M871I;VX@:6X@9G)O;G0@;V8@=&AE(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W!R94-O;F9I9SL*"B`@("`O*BH*("`@("`J(%1H92!M86YU86P@8V]N9FEG
M=7)A=&EO;B!A9G1E<B!T:&4@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<&]S
M=$-O;F9I9SL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT("1C;VYF(&%R
M<F%Y(&]F('1H92!C;VYF:6=U<F5D(&%P<&QI8V%T:6]N+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=$-O;F9I
M9R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@0U93('9E<G-I;VX@
M=&%G(&]F('1H92!C;VYF+GAM;"!F:6QE('=H:6-H('=I;&P@8F4@8V]P:65D
M(&EN=&\@=&AE"B`@("`@*B!C;VYF+G!H<"!F:6QE+@H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W9E<G-I;VY486<@/2`G
M)SL*"B`@("`O*BH*("`@("`J(%1H92!L:6YE(&UA<FMI;F<@=&AE(&)E9VEN
M(&]F('1H92!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C;VYF:6="96=I;B`]
M("(O*B!#3TY&24<@4U1!4E0N($1/($Y/5"!#2$%.1T4@04Y95$A)3D<@24X@
M3U(@049415(@5$A)4R!,24Y%+B`J+UQN(CL*"B`@("`O*BH*("`@("`J(%1H
M92!L:6YE(&UA<FMI;F<@=&AE(&5N9"!O9B!T:&4@9V5N97)A=&5D(&-O;F9I
M9W5R871I;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?8V]N9FEG16YD(#T@(B\J($-/3D9)1R!%3D0N($1/($Y/5"!#
M2$%.1T4@04Y95$A)3D<@24X@3U(@0D5&3U)%(%1(25,@3$E.12X@*B]<;B([
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1A<'`@(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO
M;B!T;R!B92!C;VYF:6=U<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D
M95]#;VYF:6<H)&%P<"D*("`@('L*("`@("`@("`D=&AI<RT^7V%P<"`]("1A
M<'`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!T:&4@87!P;&EC871I
M;VXG<R!C;VYF+GAM;"!F:6QE(&%N9"!B=6EL9',@86X@87-S;V-I871I=F4@
M87)R87D*("`@("`J(&9R;VT@:71S(%A-3"!T<F5E+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D8W5S=&]M7V-O;F8@("!!;GD@<V5T=&EN9W,@=&AA
M="!S:&%L;"!B92!I;F-L=61E9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A
M>2!R97!R97-E;G1I;F<@=&AE(&-O;F9I9W5R871I;VX@=')E92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5A9%A-3$-O;F9I9R@D8W5S=&]M7V-O;F8@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?>&UL0V]N
M9FEG5')E92D@?'P@)&-U<W1O;5]C;VYF*2!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@("`@("`@9VQO8F%L
M("1R96=I<W1R>3L*("`@("`@("`@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E
M="@G9FEL97)O;W0G+"`D=&AI<RT^7V%P<"D@+B`G+V-O;F9I9R<["@H@("`@
M("`@("`@("!I9B`H)&-U<W1O;5]C;VYF*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-U<G)E;G1#;VYF:6<@/2`D8W5S=&]M7V-O;F8["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!&971C:"!T:&4@8W5R
M<F5N="!C;VYF+G!H<"!C;VYT96YT<RX@*B\*("`@("`@("`@("`@("`@($!E
M=F%L*"1T:&ES+3YG97102%!#;VYF:6<H*2D["B`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&-O;F8I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R96YT0V]N9FEG(#T@)&-O;F8["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J($QO860@=&AE($1/32!O8FIE
M8W0N("HO"B`@("`@("`@("`@("1D;V,@/2!(;W)D95]#;VYF:6=?1&]C=6UE
M;G0Z.F9A8W1O<GDH)'!A=&@@+B`G+V-O;F8N>&UL)RD["@H@("`@("`@("`@
M("`O*B!#:&5C:R!I9B!T:&5R92!I<R!A($-64R!V97)S:6]N('1A9R!A;F0@
M<W1O<F4@:70N("HO"B`@("`@("`@("`@("1N;V1E(#T@)&1O8RT^9FER<W1?
M8VAI;&0H*3L*("`@("`@("`@("`@=VAI;&4@*"%E;7!T>2@D;F]D92DI('L*
M("`@("`@("`@("`@("`@(&EF("@D;F]D92T^='EP92`]/2!834Q?0T]-345.
M5%].3T1%*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R]<)"XJ/V-O;F9<+GAM;"QV("XJ/R`N*EPD+R<L("1N;V1E+3YN;V1E7W9A
M;'5E*"DL("1M871C:"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]V97)S:6]N5&%G(#T@)&UA=&-H6S!=("X@(EQN(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&YO9&4@/2`D;F]D
M92T^;F5X=%]S:6)L:6YG*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J(%!A<G-E('1H92!C;VYF:6<@9FEL92X@*B\*("`@("`@("`@("`@)'1H
M:7,M/E]X;6Q#;VYF:6=4<F5E(#T@87)R87DH*3L*("`@("`@("`@("`@)')O
M;W0@/2`D9&]C+3YR;V]T*"D["B`@("`@("`@("`@(&EF("@D<F]O="T^:&%S
M7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M<V5,979E;"@D=&AI<RT^7WAM;$-O;F9I9U1R964L("1R;V]T+3YC:&EL9%]N
M;V1E<R@I+"`G)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7WAM;$-O;F9I9U1R964["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!F:6QE(&-O;G1E;G0@;V8@=&AE(&-U<G)E
M;G0@8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@=6YP87)S960@8V]N9FEG=7)A=&EO;B!F:6QE(&-O;G1E
M;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!(4$-O;F9I9R@I"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]O;&1#;VYF:6<I*2!["B`@
M("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["B`@("`@("`@("`@("1P871H
M(#T@)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@)'1H:7,M/E]A<'`I("X@
M)R]C;VYF:6<G.PH@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)'!A=&@@
M+B`G+V-O;F8N<&AP)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;VQD
M0V]N9FEG(#T@9FEL95]G971?8V]N=&5N=',H)'!A=&@@+B`G+V-O;F8N<&AP
M)RD["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;VQD0V]N
M9FEG*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;VQD0V]N9FEG
M(#T@<')E9U]R97!L86-E*"<O/%P_<&AP7&X_+R<L("<G+"`D=&AI<RT^7V]L
M9$-O;F9I9RD["B`@("`@("`@("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D
M=&AI<RT^7V]L9$-O;F9I9RP@)'1H:7,M/E]C;VYF:6="96=I;BD["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E0V]N9FEG(#T@<W5B<W1R*"1T
M:&ES+3Y?;VQD0V]N9FEG+"`P+"`D<&]S*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O;&1#;VYF:6<@/2!S=6)S='(H)'1H:7,M/E]O;&1#
M;VYF:6<L("1P;W,I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T:&ES+3Y?;VQD0V]N9FEG+"`D
M=&AI<RT^7V-O;F9I9T5N9"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1P
M;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&]S=$-O;F9I9R`]('-U8G-T<B@D=&AI<RT^7V]L9$-O;F9I9RP@)'!O
M<R`K('-T<FQE;B@D=&AI<RT^7V-O;F9I9T5N9"DI.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V]L9$-O;F9I9R`]('-U8G-T<B@D=&AI<RT^
M7V]L9$-O;F9I9RP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]O;&1#;VYF:6<@/2`G)SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]O;&1#;VYF:6<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&-O;G1E;G0@
M;V8@=&AE(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@
M("H*("`@("`J($!P87)A;2!687)I86)L97,@)&9O<FUV87)S("!4:&4@<')O
M8V5S<V5D(&-O;F9I9W5R871I;VX@9F]R;2!D871A+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1C=7-T;VU?8V]N9B`@($%N>2!S971T:6YG<R!T:&%T('-H86QL
M(&)E(&EN8VQU9&5D(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&=E;F5R871E9"!C;VYF:6=U<F%T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!O9B!T:&4@9V5N97)A
M=&5D(&-O;F9I9W5R871I;VX@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5N97)A=&502%!#;VYF:6<H)&9O<FUV87)S+"`D8W5S=&]M7V-O;F8@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1T:&ES+3YR96%D6$U,0V]N9FEG*"1C=7-T
M;VU?8V]N9BD["B`@("`@("`@)'1H:7,M/F=E=%!(4$-O;F9I9R@I.PH*("`@
M("`@("`D=&AI<RT^7W!H<$-O;F9I9R`]("(\/W!H<%QN(CL*("`@("`@("`D
M=&AI<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7W!R94-O;F9I9SL*("`@("`@
M("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`D=&AI<RT^7V-O;F9I9T)E9VEN.PH@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]V97)S:6]N5&%G*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W!H<$-O;F9I9R`N/2`G+R\@)R`N("1T:&ES+3Y?
M=F5R<VEO;E1A9SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]G96YE<F%T
M95!(4$-O;F9I9R@D=&AI<RT^7WAM;$-O;F9I9U1R964L("<G+"`D9F]R;79A
M<G,I.PH@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("1T:&ES+3Y?8V]N
M9FEG16YD.PH@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("1T:&ES+3Y?
M<&]S=$-O;F9I9SL*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&AP0V]N9FEG
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S('1H92!C;VYF:6=U
M<F%T:6]N(&9I;&4@:71E;7,@9F]R(&$@<&%R="!O9B!T:&4@8V]N9FEG=7)A
M=&EO;@H@("`@("H@=')E92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'-E8W1I;VX@($%N(&%S
M<V]C:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('!A<G0@;V8@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@('1R879E<G-E9"!834P@8V]N
M9FEG=7)A=&EO;B!T<F5E('1H870@<VAO=6QD(&)E"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@('!R;V-E<W-E9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'!R969I>"`@02!C;VYF:6=U<F%T:6]N('!R969I>"!D971E<FUI;FEN
M9R!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P
M;W-I=&EO;B!I;G-I9&4@=&AE(&-O;F9I9W5R871I;VX@9FEL92X@5&AI<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!P<F5F:7@@=VEL;"!B92!T
M<F%N<VQA=&5D('1O(&ME>7,@;V8@=&AE("1C;VYF"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y(&EN('1H92!G96YE<F%T960@8V]N9FEG
M=7)A=&EO;B!F:6QE+@H@("`@("H@0'!A<F%M(%9A<FEA8FQE<R`D9F]R;79A
M<G,@(%1H92!P<F]C97-S960@8V]N9FEG=7)A=&EO;B!F;W)M(&1A=&$N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G96YE<F%T95!(4$-O;F9I9R@D<V5C=&EO
M;BP@)'!R969I>"P@)&9O<FUV87)S*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)'-E8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1S96-T:6]N(&%S("1N86UE(#T^("1C
M;VYF:6=I=&5M*2!["B`@("`@("`@("`@("1P<F5F:7AE9&YA;64@/2!E;7!T
M>2@D<')E9FEX*2`_("1N86UE(#H@)'!R969I>"`N("=\)R`N("1N86UE.PH@
M("`@("`@("`@("`D8V]N9FEG;F%M92`]('-T<E]R97!L86-E*"=\)RP@)U]?
M)RP@)'!R969I>&5D;F%M92D["B`@("`@("`@("`@("1Q=6]T92`]("%I<W-E
M="@D8V]N9FEG:71E;5LG<75O=&4G72D@?'P@)&-O;F9I9VET96U;)W%U;W1E
M)UT@(3T](&9A;'-E.PH@("`@("`@("`@("!I9B`H)&-O;F9I9VET96T@/3T@
M)W!L86-E:&]L9&5R)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P:'!#
M;VYF:6<@+CT@)R1C;VYF6UPG)R`N('-T<E]R97!L86-E*"=\)RP@)UPG75M<
M)R<L("1P<F5F:7@I("X@(B==(#T@87)R87DH*3M<;B(["B`@("`@("`@("`@
M('T@96QS96EF("AI<W-E="@D8V]N9FEG:71E;5LG<W=I=&-H)UTI*2!["B`@
M("`@("`@("`@("`@("`D=F%L(#T@)&9O<FUV87)S+3YG971%>&ES=',H)&-O
M;F9I9VYA;64L("1W87-S970I.PH@("`@("`@("`@("`@("`@:68@*"$D=V%S
M<V5T*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;"`](&ES<V5T*"1C;VYF
M:6=I=&5M6R=D969A=6QT)UTI(#\@)&-O;F9I9VET96U;)V1E9F%U;'0G72`Z
M(&YU;&P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&-O;F9I9VET96U;)W-W:71C:"==6R1V86Q=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1V86QU92`]("1V86P["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1Q=6]T92`F)B`D=F%L=64@(3T@)W1R=64G("8F("1V86QU92`A
M/2`G9F%L<V4G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M("(G(B`N("1V86QU92`N("(G(CL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G96YE<F%T95!(4$-O;F9I9R@D
M8V]N9FEG:71E;5LG<W=I=&-H)UU;)'9A;%U;)V9I96QD<R==+"`D<')E9FEX
M+"`D9F]R;79A<G,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)&-O;F9I9VET96U;)U]T>7!E)UTI*2!["B`@("`@
M("`@("`@("`@("`D=F%L(#T@)&9O<FUV87)S+3YG971%>&ES=',H)&-O;F9I
M9VYA;64L("1W87-S970I.PH@("`@("`@("`@("`@("`@:68@*"$D=V%S<V5T
M*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;"`](&ES<V5T*"1C;VYF:6=I
M=&5M6R=D969A=6QT)UTI(#\@)&-O;F9I9VET96U;)V1E9F%U;'0G72`Z(&YU
M;&P["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'1Y<&4@
M/2`D8V]N9FEG:71E;5LG7W1Y<&4G73L*("`@("`@("`@("`@("`@('-W:71C
M:"`H)'1Y<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I96YU;2<Z
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86PI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1E;F-V86QS(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;"!A<R`D=BD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5N8W9A;'-;72`]("1T:&ES
M+3Y?<75O=&4H)'8I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("1A<G)A>79A;"`]("(G(B`N(&EM<&QO9&4H
M)UPG+"!<)R<L("1E;F-V86QS*2`N("(G(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1A<G)A>79A;"`]/2`B)R<B*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D87)R87EV86P@/2`G)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1A<G)A>79A;"`]("<G.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`G87)R
M87DH)R`N("1A<G)A>79A;"`N("<I)SL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=B;V]L96%N)SH*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?8F]O;"@D=F%L*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=F%L=64@/2`D=F%L(#\@)W1R=64G(#H@)V9A;'-E
M)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=64@/2`H)'9A;"`]/2`G;VXG*2`_("=T<G5E)R`Z
M("=F86QS92<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W-T<FEN9VQI
M<W0G.@H@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!E>'!L;V1E*"<L
M)RP@)'9A;"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M=F%L=65S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2`B
M87)R87DH)R(@+B`D=&AI<RT^7W%U;W1E*'1R:6TH)'9A;'5E<RDI("X@(B<I
M(CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D96YC=F%L<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'8I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1E;F-V86QS6UT@/2`D=&AI<RT^7W%U;W1E
M*'1R:6TH)'8I*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`D87)R87EV86P@/2`B)R(@+B!I;7!L;V1E*"=<
M)RP@7"<G+"`D96YC=F%L<RD@+B`B)R(["B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D87)R87EV86P@/3T@(B<G(BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R<F%Y=F%L(#T@)R<["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V%R
M<F%Y*"<@+B`D87)R87EV86P@+B`G*2<["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)VEN="<Z"B`@("`@("`@("`@("`@("`@("`@:68@*"1V86P@(3T]
M("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU92`]("AI;G0I
M)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;V-T86PG.@H@("`@
M("`@("`@("`@("`@("`@("1V86QU92`]('-P<FEN=&8H)S`E;R<L(&]C=&1E
M8R@D=F%L*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G:&5A9&5R)SH*("`@("`@("`@("`@("`@(&-A<V4@
M)V1E<V-R:7!T:6]N)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@(&EF
M("@D=F%L("$]("<G*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M92`]("1V86P["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<75O=&4@
M)B8@)'9A;'5E("$]("=T<G5E)R`F)B`D=F%L=64@(3T@)V9A;'-E)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@(B<B("X@)'1H
M:7,M/E]Q=6]T92@D=F%L=64I("X@(B<B.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]G96YE<F%T95!(4$-O;F9I
M9R@D8V]N9FEG:71E;2P@)'!R969I>&5D;F%M92P@)&9O<FUV87)S*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU92DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&AP0V]N9FEG("X]("<D8V]N9EM<
M)R<@+B!S=')?<F5P;&%C92@G7U\G+"`G7"==6UPG)RP@)&-O;F9I9VYA;64I
M("X@)UPG72`]("<@+B`D=F%L=64@+B`B.UQN(CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!U;G-E="@D=F%L=64I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%!A<G-E<R!O;F4@;&5V96P@;V8@=&AE(&-O;F9I9W5R
M871I;VX@6$U,('1R964@:6YT;R!T:&4@87-S;V-I871I=F4*("`@("`J(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE('1R879E<G-E9"!C;VYF:6=U<F%T:6]N('1R
M964N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("8D8V]N9B`@("`@5&AE(&%L<F5A9'D@97AI<W1I
M;F<@87)R87D@=VAE<F4@=&AE('!R;V-E<W-E9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,('1R964@<&]R=&EO;B!S:&]U;&0@8F4@87!P
M96YD960@=&\N"B`@("`@*B!`<&%R86T@87)R87D@)&-H:6QD<F5N("!!;B!A
M<G)A>2!C;VYT86EN:6YG('1H92!834P@;F]D97,@;V8@=&AE(&QE=F5L"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!T:&%T('-H;W5L9"!B92!P
M87)S960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C='@@("`@("!!('-T<FEN
M9R!R97!R97-E;G1I;F<@=&AE(&-U<G)E;G0@<&]S:71I;VX*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("AC;VYT97AT('!R969I>"D@:6YS:61E
M('1H92!C;VYF:6=U<F%T:6]N(%A-3`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E3&5V
M96PH)B1C;VYF+"`D8VAI;&1R96XL("1C='@I"B`@("!["B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]497AT+T9I;'1E<BYP:'`G.PH*("`@("`@("!F
M;W)E86-H("@D8VAI;&1R96X@87,@)&YO9&4I('L*("`@("`@("`@("`@:68@
M*"1N;V1E+3YT>7!E("$](%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1N
M86UE(#T@)&YO9&4M/F=E=%]A='1R:6)U=&4H)VYA;64G*3L*("`@("`@("`@
M("`@)&1E<V,@/2!497AT7T9I;'1E<CHZ9FEL=&5R*"1N;V1E+3YG971?871T
M<FEB=71E*"=D97-C)RDL("=L:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@
M/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I*3L*("`@("`@("`@("`@)')E<75I
M<F5D(#T@(2@D;F]D92T^9V5T7V%T=')I8G5T92@G<F5Q=6ER960G*2`]/2`G
M9F%L<V4G*3L*("`@("`@("`@("`@)'%U;W1E(#T@(2@D;F]D92T^9V5T7V%T
M=')I8G5T92@G<75O=&4G*2`]/2`G9F%L<V4G*3L*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D8W1X*2D@>PH@("`@("`@("`@("`@("`@)&-U<F-T>"`]("1C
M='@@+B`G?"<@+B`D;F%M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1C=7)C='@@/2`D;F%M93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@<W=I=&-H("@D;F]D92T^=&%G;F%M92D@>PH@("`@("`@("`@
M("!C87-E("=C;VYF:6=D97-C<FEP=&EO;B<Z"B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G9&5S
M8W)I<'1I;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^(%1E>'1?1FEL=&5R.CIF:6QT97(H)'1H:7,M/E]D969A
M=6QT*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2DL
M("=L:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E
M<FYA;%5R;"<I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)V-O;F9I9VAE861E<B<Z"B`@("`@("`@("`@("`@("!I9B`H
M96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!M
M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G:&5A9&5R
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C
M)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E
M3VYL>51E>'0H)&YO9&4I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)V-O;F9I9W-W:71C:"<Z"B`@("`@("`@("`@("`@
M("`D=F%L=65S(#T@)'1H:7,M/E]G9713=VET8VA686QU97,H)&YO9&4L("1C
M='@I.PH@("`@("`@("`@("`@("`@:68@*"1Q=6]T92D@>PH@("`@("`@("`@
M("`@("`@("`@("1D969A=6QT(#T@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L
M("1T:&ES+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2D["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT(#T@
M)'1H:7,M/E]D969A=6QT4F%W*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N
M;'E497AT*"1N;V1E*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H)&1E9F%U;'0@/3T]("<G*2!["B`@("`@("`@("`@("`@("`@
M("`@)&1E9F%U;'0@/2!K97DH)'9A;'5E<RD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H:7-?8F]O;"@D9&5F875L="DI('L*("`@
M("`@("`@("`@("`@("`@("`D9&5F875L="`]("1D969A=6QT(#\@)W1R=64G
M(#H@)V9A;'-E)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1C;VYF6R1N86UE72`](&%R<F%Y*"=D97-C)R`]/B`D9&5S8RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=VET8V@G(#T^("1V
M86QU97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M9&5F875L="<@/3X@)&1E9F%U;'0I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=C;VYF:6=E;G5M)SH*("`@("`@("`@("`@
M("`@("1V86QU97,@/2`D=&AI<RT^7V=E=$5N=6U686QU97,H)&YO9&4I.PH@
M("`@("`@("`@("`@("`@:68@*"1Q=6]T92D@>PH@("`@("`@("`@("`@("`@
M("`@("1D969A=6QT(#T@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L("1T:&ES
M+3Y?9V5T3F]D94]N;'E497AT*"1N;V1E*2D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1D969A=6QT(#T@)'1H:7,M
M/E]D969A=6QT4F%W*"1C=7)C='@L("1T:&ES+3Y?9V5T3F]D94]N;'E497AT
M*"1N;V1E*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&1E9F%U;'0@/3T]("<G*2!["B`@("`@("`@("`@("`@("`@("`@)&1E
M9F%U;'0@/2!K97DH)'9A;'5E<RD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!I9B`H:7-?8F]O;"@D9&5F875L="DI('L*("`@("`@("`@
M("`@("`@("`@("`D9&5F875L="`]("1D969A=6QT(#\@)W1R=64G(#H@)V9A
M;'-E)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;VYF
M6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)V5N=6TG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D<F5Q
M=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<75O=&4G(#T^("1Q=6]T92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=V86QU97,G(#T^("1V86QU97,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@
M)&1E9F%U;'0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E("=C;VYF:6=L:7-T)SH*("`@("`@("`@("`@("`@("1D969A=6QT
M(#T@)'1H:7,M/E]D969A=6QT*"1C=7)C='@L(&YU;&PI.PH@("`@("`@("`@
M("`@("`@:68@*"1D969A=6QT(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@
M("`@("`@)&1E9F%U;'0@/2`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D
M92D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&1E9F%U
M;'0I*2!["B`@("`@("`@("`@("`@("`@("`@)&1E9F%U;'0@/2!I;7!L;V1E
M*"<L("<L("1D969A=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"=?='EP92<@/3X@)W-T<FEN
M9VQI<W0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)&1E<V,L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)&1E9F%U
M;'0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M("=C;VYF:6=M=6QT:65N=6TG.@H@("`@("`@("`@("`@("`@)'9A;'5E<R`]
M("1T:&ES+3Y?9V5T16YU;59A;'5E<R@D;F]D92D["B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["B`@("`@("`@("`@
M("`@("`D8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=M=6QT:65N
M=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M<75I<F5D)R`]/B`D<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=F%L=65S)R`]/B`D=F%L=65S+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G
M(#T^($AO<F1E7T%R<F%Y.CIV86QU97-4;TME>7,H)'1H:7,M/E]D969A=6QT
M*"1C=7)C='@L(&5X<&QO9&4H)RPG+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X
M="@D;F]D92DI*2DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=C;VYF:6=P87-S=V]R9"<Z"B`@("`@("`@("`@("`@("`D
M8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=P87-S=V]R9"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G
M(#T^("1R97%U:7)E9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`D9&5S8RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H
M)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E3VYL>51E>'0H)&YO9&4I*2D["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I
M9W-T<FEN9R<Z"B`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95T@/2!A<G)A
M>2@G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U
M;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO
M9&5/;FQY5&5X="@D;F]D92DI*3L*("`@("`@("`@("`@("`@(&EF("@D8V]N
M9ELD;F%M95U;)V1E9F%U;'0G72`]/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("`D8V]N9ELD;F%M95U;)V1E9F%U;'0G72`]("=F86QS92<["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&-O;F9;)&YA;65=6R=D969A=6QT
M)UT@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("`@("`D8V]N9ELD;F%M
M95U;)V1E9F%U;'0G72`]("=T<G5E)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8V]N9FEG
M8F]O;&5A;B<Z"B`@("`@("`@("`@("`@("`D9&5F875L="`]("1T:&ES+3Y?
M9V5T3F]D94]N;'E497AT*"1N;V1E*3L*("`@("`@("`@("`@("`@(&EF("AE
M;7!T>2@D9&5F875L="D@?'P@)&1E9F%U;'0@/3T]("=F86QS92<I('L*("`@
M("`@("`@("`@("`@("`@("`D9&5F875L="`](&9A;'-E.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9&5F875L="`]
M('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N
M9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=B;V]L96%N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@
M)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W5R
M8W1X+"`D9&5F875L="DI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=C;VYF:6=I;G1E9V5R)SH*("`@("`@("`@("`@("`@
M("1V86QU97,@/2`D=&AI<RT^7V=E=$5N=6U686QU97,H)&YO9&4I.PH@("`@
M("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH)U]T>7!E)R`]/B`G
M:6YT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@)')E<75I<F5D+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@)'9A;'5E<RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`D9&5S8RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT
M)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-U<F-T>"P@)'1H:7,M/E]G971.;V1E
M3VYL>51E>'0H)&YO9&4I*2D["B`@("`@("`@("`@("`@("!I9B`H)&YO9&4M
M/F=E=%]A='1R:6)U=&4H)V]C=&%L)RD@/3T@)W1R=64G("8F"B`@("`@("`@
M("`@("`@("`@("`@)&-O;F9;)&YA;65=6R=D969A=6QT)UT@(3T@)R<I('L*
M("`@("`@("`@("`@("`@("`@("`D8V]N9ELD;F%M95U;)U]T>7!E)UT@/2`G
M;V-T86PG.PH@("`@("`@("`@("`@("`@("`@("1C;VYF6R1N86UE75LG9&5F
M875L="==(#T@<W!R:6YT9B@G,"5O)RP@)'1H:7,M/E]D969A=6QT*"1C=7)C
M='@L(&]C=&1E8R@D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D92DI*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)V-O;F9I9W!H<"<Z"B`@("`@("`@("`@("`@("`D
M8V]N9ELD;F%M95T@/2!A<G)A>2@G7W1Y<&4G(#T^("=P:'`G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B`D
M<F5Q=6ER960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<75O=&4G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E<V,G(#T^("1D97-C+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F
M875L=%)A=R@D8W5R8W1X+"`D=&AI<RT^7V=E=$YO9&5/;FQY5&5X="@D;F]D
M92DI*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G8V]N9FEG<W%L)SH*("`@("`@("`@("`@("`@("1C;VYF6R1N;V1E+3YG
M971?871T<FEB=71E*"=S=VET8VAN86UE)RE=(#T@)'1H:7,M/E]C;VYF:6=3
M44PH)&-T>"P@)&YO9&4I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=C;VYF:6=V9G,G.@H@("`@("`@("`@("`@("`@)&-O
M;F9;)&YO9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C:&YA;64G*5T@/2`D=&AI
M<RT^7V-O;F9I9U9&4R@D8W1X+"`D;F]D92D["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W-E8W1I;VXG.@H@("`@
M("`@("`@("`@("`@)&-O;F9;)&YA;65=(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("1C=7(@/2`F)&-O;F9;)&YA;65=.PH@("`@("`@("`@("`@("`@
M:68@*"1N;V1E+3YH87-?8VAI;&1?;F]D97,H*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D8W5R+"`D;F]D92T^8VAI;&1?
M;F]D97,H*2P@)&-U<F-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;F9I9W1A8B<Z
M"B`@("`@("`@("`@("`@("`D:V5Y(#T@;60U*&UI8W)O=&EM92@I*3L*("`@
M("`@("`@("`@("`@("1C;VYF6R1K97E=(#T@87)R87DH)W1A8B<@/3X@)&YA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C
M)R`]/B`D9&5S8RD["B`@("`@("`@("`@("`@("!I9B`H)&YO9&4M/FAA<U]C
M:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)S94QE=F5L*"1C;VYF+"`D;F]D92T^8VAI;&1?;F]D97,H*2P@)&-T>"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)V-O;F9I9W!L86-E:&]L9&5R)SH*("`@("`@("`@
M("`@("`@("1C;VYF6VUD-2AM:6-R;W1I;64H*2E=(#T@)W!L86-E:&]L9&5R
M)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@("1C;VYF6R1N86UE72`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`D8W5R(#T@)B1C;VYF6R1N86UE73L*("`@("`@("`@
M("`@("`@(&EF("@D;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&5V96PH)&-U<BP@)&YO9&4M
M/F-H:6QD7VYO9&5S*"DL("1C=7)C='@I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C;VYF:6=U<F%T
M:6]N('1R964@9F]R(&%N(%-13"!B86-K96YD(&-O;F9I9W5R871I;VX@=&\*
M("`@("`J(')E<&QA8V4@82`\8V]N9FEG<W%L/B!T86<N"B`@("`@*B!3=6)N
M;V1E<R!W:6QL(&)E('!A<G-E9"!A;F0@861D960@=&\@8F]T:"!T:&4@2&]R
M9&4@9&5F875L=',@86YD('1H90H@("`@("H@0W5S=&]M(&-O;F9I9W5R871I
M;VX@<&%R=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W1X("`@("`@("`@5&AE(&-O;G1E
M>'0@;V8@=&AE(#QC;VYF:6=S<6P^('1A9RX*("`@("`J($!P87)A;2!$;VU.
M;V1E("1N;V1E("`@("`@(%1H92!$;VU.;V1E(')E<')E<V5N=&%T:6]N(&]F
M('1H92`\8V]N9FEG<W%L/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&%G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W=I=&-H;F%M92`@
M268@1&]M3F]D92!I<R!N;W0@<V5T+"!T:&4@=F%L=64@;V8@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T86<G<R!S=VET8VAN86UE
M(&%T=')I8G5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!344P@8V]N9FEG=7)A=&EO;B!T
M<F5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N9FEG4U%,*"1C='@L("1N
M;V1E(#T@;G5L;"P@)'-W:71C:&YA;64@/2`G9')I=F5R8V]N9FEG)RD*("`@
M('L*("`@("`@("`D<&5R<VES=&5N="`](&%R<F%Y*`H@("`@("`@("`@("`G
M7W1Y<&4G(#T^("=B;V]L96%N)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]
M/B!F86QS92P*("`@("`@("`@("`@)V1E<V,G(#T^("=297%U97-T('!E<G-I
M<W1E;G0@8V]N;F5C=&EO;G,_)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^
M("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQP97)S:7-T96YT)RP@9F%L<V4I
M*3L*("`@("`@("`D:&]S='-P96,@/2!A<G)A>2@*("`@("`@("`@("`@)U]T
M>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U
M92P*("`@("`@("`@("`@)V1E<V,G(#T^("=$871A8F%S92!S97)V97(O:&]S
M="<L"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H
M)&-T>"`N("=\:&]S='-P96,G+"`G)RDI.PH@("`@("`@("1U<V5R;F%M92`]
M(&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@
M("`@("`@)W)E<75I<F5D)R`]/B!T<G5E+`H@("`@("`@("`@("`G9&5S8R<@
M/3X@)U5S97)N86UE('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%S)RP*
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X
M("X@)WQU<V5R;F%M92<L("<G*2D["B`@("`@("`@)'!A<W-W;W)D(#T@87)R
M87DH"B`@("`@("`@("`@("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@
M("`G<F5Q=6ER960G(#T^(&9A;'-E+`H@("`@("`@("`@("`G9&5S8R<@/3X@
M)U!A<W-W;W)D('1O(&-O;FYE8W0@=VET:"<L"B`@("`@("`@("`@("=D969A
M=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<&%S<W=O<F0G+"`G
M)RDI.PH@("`@("`@("1D871A8F%S92`](&%R<F%Y*`H@("`@("`@("`@("`G
M7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!T
M<G5E+`H@("`@("`@("`@("`G9&5S8R<@/3X@)T1A=&%B87-E(&YA;64@=&\@
M=7-E)RP*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L
M="@D8W1X("X@)WQD871A8F%S92<L("<G*2D["B`@("`@("`@)'-O8VME="`]
M(&%R<F%Y*`H@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@
M("`@("`@)W)E<75I<F5D)R`]/B!F86QS92P*("`@("`@("`@("`@)V1E<V,G
M(#T^("=,;V-A=&EO;B!O9B!53DE8('-O8VME="<L"B`@("`@("`@("`@("=D
M969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<V]C:V5T)RP@
M)R<I*3L*("`@("`@("`D<&]R="`](&%R<F%Y*`H@("`@("`@("`@("`G7W1Y
M<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E
M+`H@("`@("`@("`@("`G9&5S8R<@/3X@)U!O<G0@=&AE($1"(&ES(')U;FYI
M;F<@;VXL(&EF(&YO;BUS=&%N9&%R9"<L"B`@("`@("`@("`@("=D969A=6QT
M)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\<&]R="<L(&YU;&PI*3L*
M("`@("`@("`D<')O=&]C;VP@/2!A<G)A>2@*("`@("`@("`@("`@)V1E<V,G
M(#T^("=(;W<@<VAO=6QD('=E(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E/R<L
M"B`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T
M>"`N("=\<')O=&]C;VPG+"`G=6YI>"<I+`H@("`@("`@("`@("`G<W=I=&-H
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("=U;FEX)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U5.25@@4V]C:V5T<R<L
M"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=S;V-K970G(#T^("1S;V-K970I*2P*("`@
M("`@("`@("`@("`@("=T8W`G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("=D97-C)R`]/B`G5$-0+TE0)RP*("`@("`@("`@("`@("`@("`@("`G
M9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!O
M<G0G(#T^("1P;W)T*2DI*3L*("`@("`@("`D;7ES<6Q?<')O=&]C;VP@/2`D
M<')O=&]C;VP["B`@("`@("`@)&UY<W%L7W!R;W1O8V]L6R=S=VET8V@G75LG
M=&-P)UU;)V9I96QD<R==6R=P;W)T)UU;)V1E9F%U;'0G72`]("1T:&ES+3Y?
M9&5F875L="@D8W1X("X@)WQP;W)T)RP@,S,P-BD["B`@("`@("`@)&-H87)S
M970@/2!A<G)A>2@*("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@
M("`@("`@("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@)V1E
M<V,G(#T^("=);G1E<FYA;&QY('5S960@8VAA<G-E="<L"B`@("`@("`@("`@
M("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\8VAA<G-E
M="<L("=I<V\M.#@U.2TQ)RDI.PH*("`@("`@("`D;V-I.%]F:65L9',@/2!A
M<G)A>2@*("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT
M+`H@("`@("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@
M("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0I.PH@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)V]C:5]C;VYN96-T)RDI('L*("`@("`@("`@("`@
M)&]C:3A?9FEE;&1S6R=D871A8F%S92==(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@("`@("=R97%U
M:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("=D97-C)R`]/B`G1&%T
M86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0@<&%R86UE=&5R)RP*("`@("`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N
M("=\9&%T86)A<V4G+"`G:&]R9&4G*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&]C:3A?9FEE;&1S6R=H;W-T<W!E8R==(#T@87)R87DH"B`@
M("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@
M("`@("=R97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("=D97-C
M)R`]/B`G1&%T86)A<V4@;F%M92!O<B!%87-Y($-O;FYE8W0@<&%R86UE=&5R
M)RP*("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U
M;'0H)&-T>"`N("=\:&]S='-P96,G+"`G:&]R9&4G*2D["B`@("`@("`@?0H@
M("`@("`@("1O8VDX7V9I96QD<ULG8VAA<G-E="==(#T@)&-H87)S970["@H@
M("`@("`@("1C=7-T;VU?9FEE;&1S(#T@87)R87DH"B`@("`@("`@("`@("=R
M97%U:7)E9"<@/3X@=')U92P*("`@("`@("`@("`@)V1E<V,G(#T^("=7:&%T
M(&1A=&%B87-E(&)A8VME;F0@<VAO=6QD('=E('5S93\G+`H@("`@("`@("`@
M("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?'!H<'1Y
M<&4G+"`G9F%L<V4G*2P*("`@("`@("`@("`@)W-W:71C:"<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`G9F%L<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("=D97-C)R`]/B`G6TYO;F5=)RP*("`@("`@("`@("`@("`@
M("`@("`G9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@("`@("`@("`@("`@("=D
M8F%S92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^
M("=D0F%S92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T
M97AT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G06)S;VQU=&4@<&%T:"!T;R!T:&4@9&%T86)A<V4@9FEL92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D
M969A=6QT*"1C='@@+B`G?&1A=&%B87-E)RP@)R<I*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)VUO9&4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U]T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!M;V1E('1O(&]P96X@=&AE
M(&9I;&4@=VET:"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F%L
M=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`P(#T^("=296%D($]N;'DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#(@/3X@)U)E860@5W)I=&4G*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N
M("=\;6]D92<L(#(I*2P*"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R
M<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)VEB87-E)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T9I<F5B
M:7)D+TEN=&5R0F%S92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=D8G-Y;G1A>"<@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G
M(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C
M)R`]/B`G5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O('5S92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VEB87-E)R`]
M/B`G26YT97)"87-E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9FER96)I<F0G(#T^("=&:7)E8FER9"<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X
M("X@)WQD8G-Y;G1A>"<L("=F:7)E8FER9"<I*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W
M;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`G9&%T86)A<V4G(#T^("1D
M871A8F%S92P*("`@("`@("`@("`@("`@("`@("`@("`@)V)U9F9E<G,G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]
M/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]
M/B`G5&AE(&YU;6)E<B!O9B!D871A8F%S92!B=69F97)S('1O(&%L;&]C871E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@
M/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?&)U9F9E<G,G+"!N=6QL*2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("=D:6%L96-T)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@)VEN="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)U1H92!D
M969A=6QT(%-13"!D:6%L96-T(&9O<B!A;GD@<W1A=&5M96YT(&5X96-U=&5D
M('=I=&AI;B!A(&-O;FYE8W1I;VXN)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@
M+B`G?&1I86QE8W0G+"!N=6QL*2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("=R;VQE)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=?='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^("=2;VQE)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G
M?')O;&4G+"!N=6QL*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R
M<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)V9B<W%L)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T9R;VYT
M8F%S92<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]/B`D<&5R
M<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)VAO<W1S<&5C)R`]
M/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R;F%M
M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`G<&%S
M<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M)V1A=&%B87-E)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@
M)VEF>"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^
M("=);F9O<FUI>"<L"B`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S:7-T96YT)R`]
M/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@)W5S97)N
M86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("=P
M87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G9&%T86)A<V4G(#T^("1D871A8F%S92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)V-H87)S970G(#T^("1C:&%R<V5T*2DL"B`@("`@("`@("`@("`@
M("`G;7-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G
M(#T^("=M4U%,)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I<W1E;G0G(#T^
M("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`G:&]S='-P
M96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@("`@("`@)W5S
M97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G<&]R="<@/3X@)'!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@("`@("`@("`@
M("=M<W-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)V1E<V,G
M(#T^("=-4R!344P@4V5R=F5R)RP*("`@("`@("`@("`@("`@("`@("`G9FEE
M;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W!E<G-I
M<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&]R="<@/3X@)'!O<G0L"B`@("`@("`@("`@("`@
M("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@
M("`@("`@("`@("=M>7-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^("=->5-13"<L"B`@("`@("`@("`@("`@("`@("`@)V9I
M96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=P97)S
M:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@("`@("`@("`@
M("`@)VAO<W1S<&5C)R`]/B`D:&]S='-P96,L"B`@("`@("`@("`@("`@("`@
M("`@("`@("=U<V5R;F%M92<@/3X@)'5S97)N86UE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%S<W=O<F0G(#T^("1P87-S=V]R9"P*("`@("`@("`@
M("`@("`@("`@("`@("`@)W!R;W1O8V]L)R`]/B`D;7ES<6Q?<')O=&]C;VPL
M"B`@("`@("`@("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B
M87-E+`H@("`@("`@("`@("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H
M87)S970I*2P*("`@("`@("`@("`@("`@("=M>7-Q;&DG(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G37E344P@*&UY<W%L:2DG
M+`H@("`@("`@("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<&5R<VES=&5N="<@/3X@)'!E<G-I<W1E
M;G0L"B`@("`@("`@("`@("`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)&AO
M<W1S<&5C+`H@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA;64G(#T^
M("1U<V5R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@)W!A<W-W;W)D
M)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@("`@("`@("`@("`@("`@("=P;W)T
M)R`]/B`D<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@)W-O8VME="<@
M/3X@)'-O8VME="P*("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E
M)R`]/B`D9&%T86)A<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R
M<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@)V]C:3@G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G3W)A8VQE
M)RP*("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B`D;V-I.%]F:65L
M9',I+`H@("`@("`@("`@("`@("`@)V]D8F,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("=D97-C)R`]/B`G3T1"0R<L"B`@("`@("`@("`@("`@
M("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("=P97)S:7-T96YT)R`]/B`D<&5R<VES=&5N="P*("`@("`@("`@("`@
M("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G:&]S='-P96,G(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T133B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C='@@+B`G?&AO<W1S<&5C)RP@)R<I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)V1B<WEN=&%X)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=?='EP92<@/3X@)V5N=6TG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=4:&4@9&%T86)A<V4@
M<WEN=&%X('9A<FEA;G0@=&\@=7-E)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<W%L.3(G(#T^("=344PY,B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%C8V5S<R<@/3X@)T%C8V5S<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1B,B<@/3X@)T1"
M,B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-O;&ED)R`]
M/B`G4V]L:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M879I<VEO;B<@/3X@)TYA=FES:6]N)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;7-S<6PG(#T^("=-4R!344P@4V5R=F5R)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<WEB87-E)R`]/B`G4WEB87-E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;7ES<6PG(#T^
M("=->5-13"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUY
M<W%L:2<@/3X@)TUY4U%,("AM>7-Q;&DI)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD8G-Y;G1A
M>"<L("=S<6PY,B<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V-U<G-O
M<B<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G7W1Y
M<&4G(#T^("=E;G5M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M97-C)R`]/B`G0W5R<V]R('1Y<&4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W%U;W1E)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R97%U:7)E9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;G5L;"<@/3X@)TYO;F4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=344Q?0U527T1%1D%53%0G(#T^("=$
M969A=6QT)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G4U%,
M7T-54E]54T5?1%))5D52)R`]/B`G57-E($1R:79E<B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U-13%]#55)?55-%7T]$0D,G(#T^("=5
M<V4@3T1"0R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-1
M3%]#55)?55-%7TE&7TY%141%1"<@/3X@)U5S92!)9B!.965D960G*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`D=&AI<RT^
M7V1E9F%U;'0H)&-T>"`N("=\8W5R<V]R)RP@;G5L;"DI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G8VAA<G-E="<@/3X@)&-H87)S970I*2P*("`@("`@
M("`@("`@("`@("=P9W-Q;"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^("=0;W-T9W)E4U%,)RP*("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M)W!E<G-I<W1E;G0G(#T^("1P97)S:7-T96YT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G:&]S='-P96,G(#T^("1H;W-T<W!E8RP*("`@("`@("`@("`@
M("`@("`@("`@("`@)W5S97)N86UE)R`]/B`D=7-E<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'!A<W-W;W)D+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G<')O=&]C;VPG(#T^("1P<F]T;V-O;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`D9&%T86)A
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA
M<G-E="DI+`H@("`@("`@("`@("`@("`@)W-Q;&ET92<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=344QI=&4G+`H@("`@("`@
M("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`G9&%T86)A<V4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T%B<V]L=71E('!A=&@@
M=&\@=&AE(&1A=&%B87-E(&9I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQD
M871A8F%S92<L("<G*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=M;V1E
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?='EP
M92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M<V,G(#T^("=4:&4@;6]D92!T;R!O<&5N('1H92!F:6QE('=I=&@G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("1T:&ES+3Y?
M9&5F875L="@D8W1X("X@)WQM;V1E)RP@)S`V-#0G*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=C:&%R<V5T)R`]/B`D8VAA<G-E="DI+`H@("`@("`@
M("`@("`@("`@)W-Y8F%S92<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)V1E<V,G(#T^("=3>6)A<V4G+`H@("`@("`@("`@("`@("`@("`@("=F
M:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G<&5R
M<VES=&5N="<@/3X@)'!E<G-I<W1E;G0L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=H;W-T<W!E8R<@/3X@)&AO<W1S<&5C+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G=7-E<FYA;64G(#T^("1U<V5R;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A<W-W;W)D)R`]/B`D<&%S<W=O<F0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=D871A8F%S92<@/3X@)&1A=&%B87-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`G87!P;F%M92<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G7W1Y<&4G(#T^("=T97AT)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G07!P;&EC871I
M;VX@3F%M92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER
M960G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^("1T:&ES+3Y?9&5F875L="@D8W1X("X@)WQA<'!N86UE)RP@
M)R<I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("1C
M:&%R<V5T*2DI*3L*"B`@("`@("`@:68@*&ES<V5T*"1N;V1E*2`F)B`D;F]D
M92T^9V5T7V%T=')I8G5T92@G8F%S96-O;F9I9R<I(#T]("=T<G5E)RD@>PH@
M("`@("`@("`@("!R971U<FX@)&-U<W1O;5]F:65L9',["B`@("`@("`@?0H*
M("`@("`@("`D8V]N9FEG(#T@87)R87DH"B`@("`@("`@("`@("=D97-C)R`]
M/B`G1')I=F5R(&-O;F9I9W5R871I;VXG+`H@("`@("`@("`@("`G9&5F875L
M="<@/3X@)'1H:7,M/E]D969A=6QT*"1C='@@+B`G?"<@+B`H:7-S970H)&YO
M9&4I(#\@)&YO9&4M/F=E=%]A='1R:6)U=&4H)W-W:71C:&YA;64G*2`Z("1S
M=VET8VAN86UE*2P@)VAO<F1E)RDL"B`@("`@("`@("`@("=S=VET8V@G(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VAO<F1E)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TAO<F1E(&1E9F%U;'1S)RP*
M("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]/B!A<G)A>2@I*2P*("`@
M("`@("`@("`@("`@("=C=7-T;VTG(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=D97-C)R`]/B`G0W5S=&]M('!A<F%M971E<G,G+`H@("`@("`@
M("`@("`@("`@("`@("=F:65L9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("!M9#4H;6EC<F]T:6UE*"DI(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G9&5S8W)I<'1I;VXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E<V,G(#T^("=!;GD@
M<&%R86UE=&5R<R!T:&%T('1H92!S=&]R86=E(&1R:79E<B!N965D<RXG*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)W!H<'1Y<&4G(#T^("1C=7-T;VU?
M9FEE;&1S*2DI*3L*"B`@("`@("`@:68@*&ES<V5T*"1N;V1E*2`F)B`D;F]D
M92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@)&-U<B`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,979E;"@D8W5R+"`D
M;F]D92T^8VAI;&1?;F]D97,H*2P@)&-T>"D["B`@("`@("`@("`@("1C;VYF
M:6=;)W-W:71C:"==6R=H;W)D92==6R=F:65L9',G72`](&%R<F%Y7VUE<F=E
M*"1C;VYF:6=;)W-W:71C:"==6R=H;W)D92==6R=F:65L9',G72P@)&-U<BD[
M"B`@("`@("`@("`@("1C;VYF:6=;)W-W:71C:"==6R=C=7-T;VTG75LG9FEE
M;&1S)UT@/2!A<G)A>5]M97)G92@D8V]N9FEG6R=S=VET8V@G75LG8W5S=&]M
M)UU;)V9I96QD<R==+"`D8W5R*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8V]N9FEG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8V]N9FEG=7)A=&EO;B!T<F5E(&9O<B!A(%9&4R!B86-K96YD(&-O;F9I9W5R
M871I;VX@=&\*("`@("`J(')E<&QA8V4@82`\8V]N9FEG=F9S/B!T86<N"B`@
M("`@*B!3=6)N;V1E<R!W:6QL(&)E('!A<G-E9"!A;F0@861D960@=&\@8F]T
M:"!T:&4@2&]R9&4@9&5F875L=',@86YD('1H90H@("`@("H@0W5S=&]M(&-O
M;F9I9W5R871I;VX@<&%R=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W1X("`@(%1H92!C
M;VYT97AT(&]F('1H92`\8V]N9FEG=F9S/B!T86<N"B`@("`@*B!`<&%R86T@
M1&]M3F]D92`D;F]D92`@5&AE($1O;4YO9&4@<F5P<F5S96YT871I;VX@;V8@
M=&AE(#QC;VYF:6=V9G,^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M=&%G+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%S<V]C:6%T
M:79E(&%R<F%Y('=I=&@@=&AE(%9&4R!C;VYF:6=U<F%T:6]N('1R964N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYF:6=61E,H)&-T>"P@)&YO9&4I"B`@
M("!["B`@("`@("`@)'-Q;"`]("1T:&ES+3Y?8V]N9FEG4U%,*"1C='@@+B`G
M?'!A<F%M<R<I.PH@("`@("`@("1C;VYF:6<@/0H@("`@("`@("`@("!A<G)A
M>2@*("`@("`@("`@("`@("`@("=D97-C)R`]/B`G5VAA="!61E,@9')I=F5R
M('-H;W5L9"!W92!U<V4_)RP*("`@("`@("`@("`@("`@("=D969A=6QT)R`]
M/B`D=&AI<RT^7V1E9F%U;'0H)&-T>"`N("=\)R`N("1N;V1E+3YG971?871T
M<FEB=71E*"=S=VET8VAN86UE)RDL("=H;W)D92<I+`H@("`@("`@("`@("`@
M("`@)W-W:71C:"<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)VYO
M;F4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@
M/3X@)TYO;F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`G9FEE;&1S)R`]
M/B!A<G)A>2@I*2P*("`@("`@("`@("`@("`@("`@("`G:&]R9&4G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)TAO<F1E
M(&1E9F%U;'1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@
M/3X@87)R87DH*2DL"B`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G9&5S8R<@/3X@)T9I;&5S
M(&]N('1H92!L;V-A;"!S>7-T96TG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G9FEE;&1S)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=P87)A;7,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=V9G-R;V]T)R`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U]T>7!E)R`]/B`G=&5X="<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G5VAE
M<F4@;VX@=&AE(')E86P@9FEL97-Y<W1E;2!S:&]U;&0@2&]R9&4@=7-E(&%S
M(')O;W0@;V8@=&AE('9I<G1U86P@9FEL97-Y<W1E;3\G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)'1H:7,M
M/E]D969A=6QT*"1C='@@+B`G?'!A<F%M<WQV9G-R;V]T)RP@)R]T;7`G*2DI
M*2DL"B`@("`@("`@("`@("`@("`@("`@)W-Q;"<@/3X@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=D97-C)R`]/B`G4U%,(&1A=&%B87-E)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@)V9I96QD<R<@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9')I=F5R8V]N9FEG
M)R`]/B`D<W%L*2DI*2D["@H@("`@("`@("1C87-E<R`]("1T:&ES+3Y?9V5T
M4W=I=&-H5F%L=65S*"1N;V1E+"`D8W1X("X@)WQP87)A;7,G*3L*("`@("`@
M("!F;W)E86-H("@D8V%S97,@87,@)&-A<V4@/3X@)&9I96QD<RD@>PH@("`@
M("`@("`@("!I9B`H:7-S970H)&-O;F9I9ULG<W=I=&-H)UU;)&-A<V5=*2D@
M>PH@("`@("`@("`@("`@("`@)&-O;F9I9ULG<W=I=&-H)UU;)&-A<V5=6R=F
M:65L9',G75LG<&%R86US)UT@/2!A<G)A>5]M97)G92@D8V]N9FEG6R=S=VET
M8V@G75LD8V%S95U;)V9I96QD<R==6R=P87)A;7,G72P@)&9I96QD<ULG9FEE
M;&1S)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&-O;F9I9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!C
M97)T86EN('9A;'5E(&9R;VT@=&AE(&-U<G)E;G0@8V]N9FEG=7)A=&EO;B!A
M<G)A>2!O<@H@("`@("H@82!D969A=6QT('9A;'5E+"!I9B!N;W0@9F]U;F0N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8W1X("`@("!!('-T<FEN9R!R97!R97-E;G1I;F<@
M=&AE(&ME>2!O9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N9FEG=7)A=&EO;B!A<G)A>2!T;R!R971U<FXN"B`@("`@*B!`<&%R86T@
M;6EX960@)&1E9F%U;'0@(%1H92!D969A=6QT('9A;'5E('1O(')E='5R;B!I
M9B!T:&4@:V5Y('=A<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!F;W5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@
M=&AE('9A;'5E(&]F('1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y)W,@<F5Q=65S
M=&5D"B`@("`@*B`@("`@("`@("`@("`@("!K97D@;W(@=&AE(&1E9F%U;'0@
M=F%L=64@:68@=&AE(&ME>2!W87-N)W0@9F]U;F0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]D969A=6QT*"1C='@L("1D969A=6QT*0H@("`@>PH@("`@("`@
M("1C='@@/2!E>'!L;V1E*"=\)RP@)&-T>"D["B`@("`@("`@)'!T<B`]("1T
M:&ES+3Y?8W5R<F5N=$-O;F9I9SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!C;W5N="@D8W1X*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1P=');)&-T>%LD:5U=*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D
M969A=6QT.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)'!T<B`]("1P=');)&-T>%LD:5U=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]S=')I;F<H)'!T<BDI('L*("`@("`@("`@("`@
M<F5T=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'!T<BP@)VES;RTX.#4Y
M+3$G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'!T
M<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M8V5R=&%I;B!V86QU92!F<F]M('1H92!C=7)R96YT(&-O;F9I9W5R871I;VX@
M9FEL92!O<@H@("`@("H@82!D969A=6QT('9A;'5E+"!I9B!N;W0@9F]U;F0N
M"B`@("`@*B!)="!D;V5S($Y/5"!R971U<FX@=&AE(&%C='5A;"!V86QU92P@
M8G5T('1H92!02%`@97AP<F5S<VEO;B!A<R!U<V5D"B`@("`@*B!I;B!T:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-T>"`@("`@02!S
M=')I;F<@<F5P<F5S96YT:6YG('1H92!K97D@;V8@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;F9I9W5R871I;VX@87)R87D@=&\@<F5T
M=7)N+@H@("`@("H@0'!A<F%M(&UI>&5D("1D969A=6QT("!4:&4@9&5F875L
M="!V86QU92!T;R!R971U<FX@:68@=&AE(&ME>2!W87-N)W0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@9F]U;F0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@16ET:&5R('1H92!V86QU92!O9B!T:&4@8V]N9FEG=7)A
M=&EO;B!F:6QE)W,@<F5Q=65S=&5D"B`@("`@*B`@("`@("`@("`@("`@("!K
M97D@;W(@=&AE(&1E9F%U;'0@=F%L=64@:68@=&AE(&ME>2!W87-N)W0@9F]U
M;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D969A=6QT4F%W*"1C='@L("1D
M969A=6QT*0H@("`@>PH@("`@("`@("1C='@@/2!E>'!L;V1E*"=\)RP@)&-T
M>"D["B`@("`@("`@)'!A='1E<FX@/2`G+UY<)&-O;F9<6UPG)R`N(&EM<&QO
M9&4H(B=<75Q;)R(L("1C='@I("X@)UPG7%T@/2`H+BHI.R0O;2<["B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)'!A='1E<FXL("1T:&ES+3YG97102%!#;VYF
M:6<H*2P@)&UA=&-H97,I*2!["B`@("`@("`@("`@(')E='5R;B`D;6%T8VAE
M<ULQ73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D969A=6QT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N="!O9B!A;&P@
M=&5X="!N;V1E(&-H:6QD<F5N(&]F('1H92!S<&5C:69I960@;F]D92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@1&]M3F]D92`D;F]D92`@02!$;VU.;V1E(&]B:F5C="!W:&]S92!T97AT
M(&YO9&4@8VAI;&1R96X@=&\@<F5T=7)N+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8V]N8V%T96YA=&5D('9A;'5E<R!O9B!A;&P@=&5X
M="!N;V1E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$YO9&5/;FQY5&5X
M="@D;F]D92D*("`@('L*("`@("`@("`D=&5X="`]("<G.PH@("`@("`@(&EF
M("@A)&YO9&4M/FAA<U]C:&EL9%]N;V1E<R@I*2!["B`@("`@("`@("`@(')E
M='5R;B`D;F]D92T^9V5T7V-O;G1E;G0H*3L*("`@("`@("!]"B`@("`@("`@
M9F]R96%C:"`H)&YO9&4M/F-H:6QD7VYO9&5S*"D@87,@)'1N;V1E*2!["B`@
M("`@("`@("`@(&EF("@D=&YO9&4M/G1Y<&4@/3T@6$U,7U1%6%1?3D]$12D@
M>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)'1N;V1E+3YC;VYT96YT.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')I;2@D
M=&5X="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%S<V]C
M:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@86QL('!O<W-I8FQE('9A;'5E<R!O
M9B!T:&4*("`@("`J('-P96-I9FEE9"`\8V]N9FEG96YU;3X@=&%G+@H@("`@
M("H@5&AE(&ME>7,@8V]N=&%I;B!T:&4@86-T=6%L(&5N=6T@=F%L=65S('=H
M:6QE('1H92!V86QU97,@8V]N=&%I;B!T:&5I<@H@("`@("H@8V]R<F5S<&]N
M9&EN9R!D97-C<FEP=&EO;G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO9&4@(%1H92!$
M;VU.;V1E(')E<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG96YU;3X@=&%G
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=VAO<V4@=F%L=65S('-H
M;W5L9"!B92!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H(&%L;"!P;W-S:6)L92!E;G5M
M('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$5N=6U686QU97,H
M)&YO9&4I"B`@("!["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@
M("`@:68@*"$D;F]D92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@
M*"1N;V1E+3YC:&EL9%]N;V1E<R@I(&%S("1V;F]D92D@>PH@("`@("`@("`@
M("!I9B`H)'9N;V1E+3YT>7!E(#T](%A-3%]%3$5-14Y47TY/1$4@)B8*("`@
M("`@("`@("`@("`@("1V;F]D92T^=&%G;F%M92`]/2`G=F%L=65S)RD@>PH@
M("`@("`@("`@("`@("`@:68@*"$D=FYO9&4M/FAA<U]C:&EL9%]N;V1E<R@I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=FYO9&4M
M/F-H:6QD7VYO9&5S*"D@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1V86QU92T^='EP92`]/2!834Q?14Q%345.5%].3T1%*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=64M/G1A9VYA;64@/3T@
M)V-O;F9I9W-P96-I86PG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]H86YD;&53<&5C:6%L<R@D=F%L=64I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'9A;'5E+3YT86=N86UE
M(#T]("=V86QU92<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M97AT(#T@)'9A;'5E+3YG971?8V]N=&5N="@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<V,@/2`D=F%L=64M/F=E=%]A='1R:6)U=&4H)V1E
M<V,G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH
M)&1E<V,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M;'5E<ULD=&5X=%T@/2`D9&5S8SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9A;'5E<ULD=&5X=%T@/2`D=&5X=#L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'9A;'5E<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@82!M=6QT:61I;65N<VEO;F%L(&%S<V]C:6%T
M:79E(&%R<F%Y(')E<')E<V5N=&EN9R!T:&4@<W!E8VEF:65D"B`@("`@*B`\
M8V]N9FEG<W=I=&-H/B!T86<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@)B1N;V1E("!4:&4@
M1&]M3F]D92!R97!R97-E;G1A=&EO;B!O9B!T:&4@/&-O;F9I9W-W:71C:#X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&%G('1O('!R;V-E<W,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@
M87)R87D@<F5P<F5S96YT:6YG('1H92!N;V1E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?9V5T4W=I=&-H5F%L=65S*"8D;F]D92P@)&-U<F-T>"D*("`@('L*
M("`@("`@("!I9B`H(21N;V1E+3YH87-?8VAI;&1?;F]D97,H*2D@>PH@("`@
M("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&YO9&4M/F-H:6QD
M7VYO9&5S*"D@87,@)&-A<V4I('L*("`@("`@("`@("`@:68@*"1C87-E+3YT
M>7!E(#T](%A-3%]%3$5-14Y47TY/1$4I('L*("`@("`@("`@("`@("`@("1N
M86UE(#T@)&-A<V4M/F=E=%]A='1R:6)U=&4H)VYA;64G*3L*("`@("`@("`@
M("`@("`@("1V86QU97-;)&YA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@("1V86QU97-;)&YA;65=6R=D97-C)UT@/2`D8V%S92T^9V5T7V%T=')I
M8G5T92@G9&5S8R<I.PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD;F%M95U;
M)V9I96QD<R==(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&EF("@D8V%S
M92T^:&%S7V-H:6QD7VYO9&5S*"DI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<G-E3&5V96PH)'9A;'5E<ULD;F%M95U;)V9I96QD<R==+"`D
M8V%S92T^8VAI;&1?;F]D97,H*2P@)&-U<F-T>"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1V
M86QU97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%S<V]C
M:6%T:79E(&%R<F%Y(&-O;G1A:6YI;F<@=&AE('!O<W-I8FQE('9A;'5E<R!O
M9B!A"B`@("`@*B`\8V]N9FEG<W!E8VEA;#X@=&%G(&%S('5S960@:6YS:61E
M(&]F(&5N=6T@8V]N9FEG=7)A=&EO;G,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M($1O;4YO9&4@)&YO9&4@
M(%1H92!$;VU.;V1E(')E<')E<V5N=&%T:6]N(&]F('1H92`\8V]N9FEG<W!E
M8VEA;#X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T86<N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87-S;V-I871I=F4@87)R87D@
M=VET:"!T:&4@<&]S<VEB;&4@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?:&%N9&QE4W!E8VEA;',H)&YO9&4I"B`@("!["B`@("`@("`@<W=I=&-H
M("@D;F]D92T^9V5T7V%T=')I8G5T92@G;F%M92<I*2!["B`@("`@("`@8V%S
M92`G;&ES="UH;W)D92UA<'!S)SH*("`@("`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!<G)A>2YP
M:'`G.PH@("`@("`@("`@("`D87!P<R`]($AO<F1E7T%R<F%Y.CIV86QU97-4
M;TME>7,H)')E9VES=')Y+3YL:7-T07!P<RAA<G)A>2@G:&ED9&5N)RP@)VYO
M=&]O;&)A<B<L("=A8W1I=F4G*2DI.PH@("`@("`@("`@("!A<V]R="@D87!P
M<RD["B`@("`@("`@("`@(')E='5R;B`D87!P<SL*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)VQI<W0M:&]R9&4M;&%N9W5A9V5S)SH*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y7VUA<"AC<F5A=&5?9G5N8W1I;VXH)R1V
M86PG+"`G<F5T=7)N('!R96=?<F5P;&%C92AA<G)A>2@B+R8C>"A;,"TY82UF
M77LT?2D[+VEE(BP@(B\H)EM>.UTK.RDO92(I+"!A<G)A>2@B4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="AP86-K*%PB2"I<(BP@7"(D,5PB*2P@7")U8W,M,EPB
M+"!<(B<@+B!.3%,Z.F=E=$-H87)S970H*2`N("=<(BDB+"`B4W1R:6YG.CIC
M;VYV97)T0VAA<G-E="AH=&UL7V5N=&ET>5]D96-O9&4H7"(D,5PB+"!%3E1?
M0T]-4$%4+"!<(FES;RTX.#4Y+3%<(BDL(%PB:7-O+3@X-3DM,5PB+"!<(B<@
M+B!.3%,Z.F=E=$-H87)S970H*2`N("=<(BDB*2P@)'9A;"D[)RDL("1'3$]"
M04Q36R=N;',G75LG;&%N9W5A9V5S)UTI.PH@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@8V%S92`G;&ES="UB;&]C:W,G.@H@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*("`@("`@
M("`@("`@)&-O;&QE8W1I;VX@/2`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ
M<VEN9VQE=&]N*"=P;W)T86PG*3L*("`@("`@("`@("`@<F5T=7)N("1C;VQL
M96-T:6]N+3YG971";&]C:W-,:7-T*"D["@H@("`@("`@(&-A<V4@)VQI<W0M
M8VQI96YT+69I96QD<R<Z"B`@("`@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD[
M"B`@("`@("`@("`@("1F(#T@87)R87DH*3L*("`@("`@("`@("`@:68@*"1R
M96=I<W1R>2T^:&%S365T:&]D*"=C;&EE;G1S+V=E=$-L:65N=%-O=7)C92<I
M*2!["B`@("`@("`@("`@("`@("`D861D<F5S<V)O;VL@/2`D<F5G:7-T<GDM
M/F-A;&PH)V-L:65N=',O9V5T0VQI96YT4V]U<F-E)RD["B`@("`@("`@("`@
M("`@("`D9FEE;&1S(#T@)')E9VES=')Y+3YC86QL*"=C;&EE;G1S+V9I96QD
M<R<L(&%R<F%Y*"1A9&1R97-S8F]O:RDI.PH@("`@("`@("`@("`@("`@:68@
M*"%I<U]A*"1F:65L9',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D9FEE;&1S(&%S("1F:65L9"D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D9ELD9FEE;&1;)VYA;64G75T@/2`D9FEE;&1;
M)VQA8F5L)UT["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9CL*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R
M87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-P96-I
M9FEE9"!S=')I;F<@=VET:"!E<V-A<&5D('-I;F=L92!Q=6]T97,*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1S=')I;F<@($$@<W1R:6YG('1O(&5S8V%P92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-P96-I9FEE9"!S=')I;F<@=VET
M:"!S:6YG;&4@<75O=&5S(&)E:6YG(&5S8V%P960N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]Q=6]T92@D<W1R:6YG*0H@("`@>PH@("`@("`@(')E='5R;B!S
M=')?<F5P;&%C92@B)R(L(")<)R(L("1S=')I;F<I.PH@("`@?0H*?0H*+RHJ
M"B`J($$@2&]R9&5?1F]R;3HZ(&9O<FT@=&AA="!I;7!L96UE;G1S(&$@=7-E
M<B!I;G1E<F9A8V4@9F]R('1H92!C;VYF:6<*("H@<WES=&5M+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T9R86UE=V]R
M:PH@*B\*8VQA<W,@0V]N9FEG1F]R;2!E>'1E;F1S($AO<F1E7T9O<FT@>PH*
M("`@("\J*@H@("`@("H@1&]N)W0@=7-E(&9O<FT@=&]K96YS(&9O<B!T:&4@
M8V]N9FEG=7)A=&EO;B!F;W)M("T@=VAI;&4*("`@("`J(&=E;F5R871I;F<@
M8V]N9FEG=7)A=&EO;B!I;F9O+"!T:&EN9W,@;&EK92!T:&4@5&]K96X@<WES
M=&5M"B`@("`@*B!M:6=H="!N;W0@=V]R:R!C;W)R96-T;'DN(%1H:7,@<V%V
M97,@<V]M92!H96%D86-H97,N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N
M"B`@("`@*B\*("`@('9A<B`D7W5S949O<FU4;VME;B`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@0V]N=&%I;G,@=&AE($AO<F1E7T-O;F9I9R!O8FIE8W0@
M=&AA="!T:&ES(&9O<FT@<F5P<F5S96YT<RX*("`@("`J"B`@("`@*B!`=F%R
M($AO<F1E7T-O;F9I9PH@("`@("HO"B`@("!V87(@)%]X;6Q#;VYF:6<["@H@
M("`@+RHJ"B`@("`@*B!#;VYT86EN<R!T:&4@5F%R:6%B;&5S(&]B:F5C="!O
M9B!T:&ES(&9O<FTN"B`@("`@*@H@("`@("H@0'9A<B!687)I86)L97,*("`@
M("`J+PH@("`@=F%R("1?=F%R<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!687)I86)L97,@)B1V87)S("!4
M:&4@5F%R:6%B;&5S(&]B:F5C="!O9B!T:&ES(&9O<FTN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<'`@("`@("`@("`@("`@5&AE(&YA;64@;V8@=&AE(&%P
M<&QI8V%T:6]N('1H870@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;F9I9W5R871I;VX@9F]R;2!I<R!F;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($-O;F9I9T9O<FTH)B1V87)S+"`D87!P*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?1F]R;2@D=F%R<RD["@H@("`@("`@
M("1T:&ES+3Y?>&UL0V]N9FEG(#T@)FYE=R!(;W)D95]#;VYF:6<H)&%P<"D[
M"B`@("`@("`@)'1H:7,M/E]V87)S(#T@)B1V87)S.PH@("`@("`@("1C;VYF
M:6<@/2`D=&AI<RT^7WAM;$-O;F9I9RT^<F5A9%A-3$-O;F9I9R@I.PH@("`@
M("`@("1T:&ES+3YA9&1(:61D96XH)R<L("=A<'`G+"`G=&5X="<L('1R=64I
M.PH@("`@("`@("1T:&ES+3Y?8G5I;&1687)I86)L97,H)&-O;F9I9RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@=&AE(&9O<FT@8F%S960@;VX@
M=&AE('-P96-I9FEE9"!L979E;"!O9B!T:&4@8V]N9FEG=7)A=&EO;B!T<F5E
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D8V]N9FEG("`@5&AE('!O<G1I;VX@;V8@=&AE(&-O
M;F9I9W5R871I;VX@=')E92!F;W(@=&AA=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@9F]R;2!F:65L9',@<VAO=6QD(&)E(&-R96%T960N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F5F:7@@($$@<W1R:6YG(')E<')E
M<V5N=&EN9R!T:&4@8W5R<F5N="!P;W-I=&EO;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!I;G-I9&4@=&AE(&-O;F9I9W5R871I;VX@=')E92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD5F%R:6%B;&5S*"1C;VYF:6<L
M("1P<F5F:7@@/2`G)RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C
M;VYF:6<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@
M("`@9F]R96%C:"`H)&-O;F9I9R!A<R`D;F%M92`]/B`D8V]N9FEG:71E;2D@
M>PH@("`@("`@("`@("`D<')E9FEX961N86UE(#T@96UP='DH)'!R969I>"D@
M/R`D;F%M92`Z("1P<F5F:7@@+B`G?"<@+B`D;F%M93L*("`@("`@("`@("`@
M)'9A<FYA;64@/2!S=')?<F5P;&%C92@G?"<L("=?7R<L("1P<F5F:7AE9&YA
M;64I.PH@("`@("`@("`@("`D9&5S8W)I<'1I;VX@/2!N=6QL.PH@("`@("`@
M("`@("!I9B`H)&-O;F9I9VET96T@/3T@)W!L86-E:&]L9&5R)RD@>PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D8V]N9FEG:71E;5LG=&%B)UTI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T4V5C=&EO;B@D8V]N9FEG:71E;5LG=&%B)UTL("1C;VYF:6=I
M=&5M6R=D97-C)UTI.PH@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&-O
M;F9I9VET96U;)W-W:71C:"==*2D@>PH@("`@("`@("`@("`@("`@)'-E;&5C
M=&5D(#T@)'1H:7,M/E]V87)S+3YG971%>&ES=',H)'9A<FYA;64L("1W87-S
M970I.PH@("`@("`@("`@("`@("`@)'9A<E]P87)A;7,@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@)'-E;&5C=%]O<'1I;VX@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@:68@*&ES7V)O;VPH)&-O;F9I9VET96U;)V1E9F%U;'0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D8V]N9FEG:71E;5LG9&5F875L="==
M(#T@)&-O;F9I9VET96U;)V1E9F%U;'0G72`_("=T<G5E)R`Z("=F86QS92<[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M8V]N9FEG:71E;5LG<W=I=&-H)UT@87,@)&]P=&EO;B`]/B`D8V%S92D@>PH@
M("`@("`@("`@("`@("`@("`@("1V87)?<&%R86US6R1O<'1I;VY=(#T@)&-A
M<V5;)V1E<V,G73L*("`@("`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;B`]
M/2`D8V]N9FEG:71E;5LG9&5F875L="==*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1S96QE8W1?;W!T:6]N(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A)'=A<W-E="D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-E;&5C=&5D(#T@)&]P=&EO;CL*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1V(#T@)B1T:&ES+3YA9&1687)I86)L
M92@D8V]N9FEG:71E;5LG9&5S8R==+"`D=F%R;F%M92P@)V5N=6TG+"!T<G5E
M+"!F86QS92P@;G5L;"P@87)R87DH)'9A<E]P87)A;7,L("1S96QE8W1?;W!T
M:6]N*2D["B`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G
M9&5F875L="<L("1C;VYF:6=I=&5M*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1V+3YS971$969A=6QT*"1C;VYF:6=I=&5M6R=D969A=6QT)UTI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'9?86-T:6]N(#T@)DAO
M<F1E7T9O<FU?06-T:6]N.CIF86-T;W)Y*"=R96QO860G*3L*("`@("`@("`@
M("`@("`@("1V+3YS971!8W1I;VXH)'9?86-T:6]N*3L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<V5L96-T960I("8F(&ES<V5T*"1C;VYF:6=I=&5M
M6R=S=VET8V@G75LD<V5L96-T961=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8G5I;&1687)I86)L97,H)&-O;F9I9VET96U;)W-W:71C:"==
M6R1S96QE8W1E9%U;)V9I96QD<R==+"`D<')E9FEX*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF:6=I=&5M
M6R=?='EP92==*2D@>PH@("`@("`@("`@("`@("`@)')E<75I<F5D(#T@*&ES
M<V5T*"1C;VYF:6=I=&5M6R=R97%U:7)E9"==*2D@/R`D8V]N9FEG:71E;5LG
M<F5Q=6ER960G72`Z('1R=64["B`@("`@("`@("`@("`@("`D='EP92`]("1C
M;VYF:6=I=&5M6R=?='EP92==.PH@("`@("`@("`@("`@("`@+R\@1DE8344Z
M(&UU;'1I96YU;2!F:65L9',@8V%N('=E;&P@8F4@<F5Q=6ER960L(&UE86YI
M;F<@=&AA=`H@("`@("`@("`@("`@("`@+R\@>6]U(&YE960@=&\@<V5L96-T
M(&%T(&QE87-T(&]N92!E;G1R>2X@0VAA;F=I;F<@=&AI<R!B969O<F4*("`@
M("`@("`@("`@("`@("\O($AO<F1E(#0N,"!W;W5L9"!B<F5A:R!A(&QO="!O
M9B!C;VYF:6=U<F%T:6]N(&9I;&5S('1H;W5G:"X*("`@("`@("`@("`@("`@
M(&EF("@D='EP92`]/2`G;75L=&EE;G5M)R!\?"`D='EP92`]/2`G:&5A9&5R
M)R!\?`H@("`@("`@("`@("`@("`@("`@("1T>7!E(#T]("=D97-C<FEP=&EO
M;B<I('L*("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER960@/2!F86QS93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@D='EP92`]
M/2`G;75L=&EE;G5M)R!\?"`D='EP92`]/2`G96YU;2<I('L*("`@("`@("`@
M("`@("`@("`@("`D=F%R7W!A<F%M<R`](&%R<F%Y*"1C;VYF:6=I=&5M6R=V
M86QU97,G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1V87)?<&%R86US(#T@87)R87DH*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&AP)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)W1E>'0G.PH@("`@("`@("`@
M("`@("`@("`@("1D97-C<FEP=&EO;B`]("=%;G1E<B!A('9A;&ED(%!(4"!E
M>'!R97-S:6]N+B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`D=B`]("8D=&AI<RT^861D5F%R:6%B;&4H)&-O;F9I9VET96U;)V1E<V,G
M72P@)'9A<FYA;64L("1T>7!E+"`D<F5Q=6ER960L(&9A;'-E+"`D9&5S8W)I
M<'1I;VXL("1V87)?<&%R86US*3L*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D8V]N9FEG:71E;5LG9&5F875L="==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1V+3YS971$969A=6QT*"1C;VYF:6=I=&5M6R=D969A=6QT)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]B=6EL9%9A<FEA8FQE<R@D8V]N9FEG:71E;2P@
M)'!R969I>&5D;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@I]"@IC;&%S<R!(;W)D95]#;VYF:6=?1&]C=6UE;G0@97AT96YD<R!(;W)D
M95]#;VYF:6=?3F]D92!["@H@("`@9G5N8W1I;VX@9F%C=&]R>2@D9FEL92D*
M("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D;VUX;6Q?;W!E
M;E]F:6QE)RDI('L*("`@("`@("`@("`@<F5T=7)N(&1O;7AM;%]O<&5N7V9I
M;&4H)&9I;&4I.PH@("`@("`@('T@96QS96EF("AV97)S:6]N7V-O;7!A<F4H
M<&AP=F5R<VEO;B@I+"`G-2<L("<^/2<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D9&]C(#T@;F5W($AO<F1E7T-O;F9I9U]$;V-U;65N="@D9FEL92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"=$3TT@
M<W5P<&]R="!N;W0@<')E<V5N="XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!(;W)D95]#;VYF:6=?1&]C
M=6UE;G0H)&9I;&5N86UE*0H@("`@>PH@("`@("`@("1T:&ES+3YN;V1E(#T@
M;F5W($1/341O8W5M96YT*"D["B`@("`@("`@)'1H:7,M/FYO9&4M/FQO860H
M)&9I;&5N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!R;V]T*"D*("`@('L*
M("`@("`@("!R971U<FX@)')O;W0@/2!N97<@2&]R9&5?0V]N9FEG7T5L96UE
M;G0H)'1H:7,M/FYO9&4M/F1O8W5M96YT16QE;65N="D["B`@("!]"@I]"@IC
M;&%S<R!(;W)D95]#;VYF:6=?3F]D92!["@H@("`@=F%R("1N;V1E.PH*("`@
M(&9U;F-T:6]N($AO<F1E7T-O;F9I9U].;V1E*"1A1&]M3F]D92D@>R1T:&ES
M+3YN;V1E/21A1&]M3F]D93M]"@H@("`@9G5N8W1I;VX@7U]G970H)&YA;64I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D;F%M92D@>PH@("`@("`@(&-A<V4@
M)W1Y<&4G.@H@("`@("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/FYO9&54
M>7!E.PH*("`@("`@("!C87-E("=T86=N86UE)SH*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YN;V1E+3YT86=.86UE.PH*("`@("`@("!C87-E("=C;VYT
M96YT)SH*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YN;V1E+3YT97AT0V]N
M=&5N=#L*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!C:&EL9%]N;V1E
M<R@I"B`@("!["B`@("`@("`@)&YO9&5,:7-T(#T@)'1H:7,M/FYO9&4M/F-H
M:6QD3F]D97,["B`@("`@("`@)&YO9&53970@/2!A<G)A>2@I.PH@("`@("`@
M(&EF("AI<W-E="@D;F]D94QI<W0I*2!["B`@("`@("`@("`@("1I(#T@,#L*
M("`@("`@("`@("`@=VAI;&4@*"1N;V1E(#T@)&YO9&5,:7-T+3YI=&5M*"1I
M*2D@>PH@("`@("`@("`@("`@("`@)&YO9&53971;72`](&YE=R!(;W)D95]#
M;VYF:6=?16QE;65N="@D;F]D92D["B`@("`@("`@("`@("`@("`D:2LK.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;F]D95-E
M=#L*("`@('T*"B`@("!F=6YC=&EO;B!F:7)S=%]C:&EL9"@I"B`@("!["B`@
M("`@("`@<F5T=7)N(&YE=R!(;W)D95]#;VYF:6=?16QE;65N="@D=&AI<RT^
M;F]D92T^9FER<W1#:&EL9"D["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T7V-O
M;G1E;G0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F]D92T^=&5X
M=$-O;G1E;G0["B`@("!]"@H@("`@9G5N8W1I;VX@:&%S7V-H:6QD7VYO9&5S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FYO9&4M/FAA<T-H:6QD
M3F]D97,H*3L*("`@('T*"B`@("!F=6YC=&EO;B!N97AT7W-I8FQI;F<H*0H@
M("`@>PH@("`@("`@(')E='5R;B!N97<@2&]R9&5?0V]N9FEG7T5L96UE;G0H
M)'1H:7,M/FYO9&4M/FYE>'13:6)L:6YG*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!N;V1E7W9A;'5E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FYO
M9&4M/FYO9&5686QU93L*("`@('T*"GT*"F-L87-S($AO<F1E7T-O;F9I9U]%
M;&5M96YT(&5X=&5N9',@2&]R9&5?0V]N9FEG7TYO9&4@>PH*("`@(&9U;F-T
M:6]N(&=E=%]A='1R:6)U=&4H)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YN;V1E+3YG971!='1R:6)U=&4H)&YA;64I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O1W)O=7`N<&AP````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-3`U,S0@,3`U,34T,S0Q-#`@
M,#(Q,34S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O2&ES=&]R>2YP:'`G.PH*+RHJ"B`J(%1H
M92!'<F]U<#HZ(&-L87-S('!R;W9I9&5S('1H92!(;W)D92!G<F]U<',@<WES
M=&5M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F]U<"]'<F]U<"YP:'`L
M=B`Q+C8W+C(N,34@,C`P-B\P-R\Q-R`Q-#HT,#HQ.2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!3=&5P:&%N92!(=71H97(@/'-H=71H
M97)`8FEG9F]O="YC;VT^"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!3=&5P:&%N92!(=71H97(@/'-H=71H97)`8FEG9F]O="YC
M;VT^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?
M1W)O=7`*("HO"F-L87-S($=R;W5P('L*"B`@("`O*BH*("`@("`J(%!O:6YT
M97(@=&\@82!$871A5')E92!I;G-T86YC92!T;R!M86YA9V4@=&AE(&1I9F9E
M<F5N="!G<F]U<',N"B`@("`@*@H@("`@("H@0'9A<B!$871A5')E90H@("`@
M("HO"B`@("!V87(@)%]D871A=')E93L*"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($=R;W5P*"D*("`@('L*("`@
M("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("AE;7!T>2@D8V]N9ELG
M9&%T871R964G75LG9')I=F5R)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"@G66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T
M;R!U<V4@1W)O=7!S+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`D9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E
M<B==.PH@("`@("`@("1T:&ES+3Y?9&%T871R964@/2`F1&%T851R964Z.G-I
M;F=L971O;B@D9')I=F5R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]M97)G92A(;W)D93HZ9V5T1')I
M=F5R0V]N9FEG*"=D871A=')E92<L("1D<FEV97(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G9W)O=7`G(#T^("=H;W)D92YG<F]U<',G*2DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&$@;F5W(&=R;W5P(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@(%1H92!G<F]U<"=S
M(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E;G0@(%1H92!G<F]U
M<"=S('!A<F5N="=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A
M5')E94]B:F5C=%]'<F]U<"`@02!N97<@9W)O=7`@;V)J96-T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F;F5W1W)O=7`H)&YA;64L("1P87)E;G0@/2!$051!
M5%)%15]23T]4*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D;F%M92DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1W)O=7`@
M;F%M97,@;75S="!B92!N;VXM96UP='DB*2D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'!A<F5N="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@
M("1N86UE(#T@)'1H:7,M/F=E=$=R;W5P3F%M92@D<&%R96YT*2`N("<Z)R`N
M($1A=&%4<F5E.CIE;F-O9&5.86UE*"1N86UE*3L*("`@("`@("!]"@H@("`@
M("`@("1G<F]U<"`]("9N97<@1&%T851R965/8FIE8W1?1W)O=7`H)&YA;64I
M.PH@("`@("`@("1G<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@
M<F5T=7)N("1G<F]U<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A
M($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C="!C;W)R97-P;VYD:6YG('1O
M('1H92!N86UE9`H@("`@("H@9W)O=7`L('=I=&@@=&AE('5S97)S(&%N9"!O
M=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@5&AE(&YA;64@;V8@=&AE(&=R;W5P
M('1O(')E=')I979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O=7`H
M)&YA;64I"B`@("!["B`@("`@("`@+RH@8V%C:&4@;V8@<')E=FEO=7,@<F5T
M<FEE=F5D(&=R;W5P<R`J+PH@("`@("`@('-T871I8R`D9W)O=7!#86-H93L*
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9W)O=7!#86-H92DI('L*("`@("`@
M("`@("`@)&=R;W5P0V%C:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%I<W-E="@D9W)O=7!#86-H95LD;F%M95TI*2!["B`@("`@("`@
M("`@("1G<F]U<$-A8VAE6R1N86UE72`]("1T:&ES+3Y?9&%T871R964M/F=E
M=$]B:F5C="@D;F%M92P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RD["B`@("`@
M("`@("`@(&EF("@A:7-?82@D9W)O=7!#86-H95LD;F%M95TL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("1G<F]U<$-A8VAE6R1N86UE72T^
M<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D9W)O=7!#86-H95LD;F%M95T["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE
M8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@9VEV96X*("`@("`J('5N:7%U92!)
M1"P@=VET:"!T:&4@=7-E<G,@86YD(&]T:&5R(&1A=&$@<F5T<FEE=F5D"B`@
M("`@*B!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C:60@(%1H92!U;FEQ=64@240@;V8@=&AE(&=R;W5P('1O(')E=')I
M979E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T1W)O=7!">4ED*"1C:60I
M"B`@("!["B`@("`@("`@)&=R;W5P(#T@)'1H:7,M/E]D871A=')E92T^9V5T
M3V)J96-T0GE)9"@D8VED+"`G1&%T851R965/8FIE8W1?1W)O=7`G*3L*("`@
M("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1G<F]U<"T^<V5T1W)O=7!/8B@D=&AI<RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'
M970@82!G;&]B86QL>2!U;FEQ=64@240@9F]R(&$@9W)O=7`N"B`@("`@*@H@
M("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G<F]U<"`@5&AE
M(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!($=5240@
M<F5F97)R:6YG('1O("1G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1U5)1"@D9W)O=7`I"B`@("!["B`@("`@("`@<F5T=7)N("=H;W)D93IG<F]U
M<#HG("X@)'1H:7,M/F=E=$=R;W5P260H)&=R;W5P*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9"!A(&=R;W5P('1O('1H92!G<F]U<',@<WES=&5M+B!4
M:&4@9W)O=7`@;75S="!F:7)S="!B90H@("`@("H@8W)E871E9"!W:71H($=R
M;W5P.CIN97='<F]U<"@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@
M("`@("H@861D960@=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A
M;&QE9"X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?1W)O
M=7`@)&=R;W5P("!4:&4@;F5W(&=R;W5P(&]B:F5C="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@861D1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B
M92!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T
M(&-L87-S+B<I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D871A=')E92T^861D*"1G<F]U<"D["B`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($QO9R!T:&4@861D:71I;VX@
M;V8@=&AE(&=R;W5P(&EN('1H92!H:7-T;W)Y(&QO9RX@*B\*("`@("`@("`D
M:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@
M("`D;&]G(#T@)&AI<W1O<GDM/FQO9R@D=&AI<RT^9V5T1U5)1"@D9W)O=7`I
M+"!A<G)A>2@G86-T:6]N)R`]/B`G861D)RDL('1R=64I.PH@("`@("`@(&EF
M("AI<U]A*"1L;V<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1L;V<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E('5P9&%T960@9&%T82`M('5S
M97)S+"!E=&,N("T@;V8@82!G<F]U<"!T;R!T:&4@8F%C:V5N9"!S>7-T96TN
M"B`@("`@*@H@("`@("H@0'!A<F%M($1A=&%4<F5E3V)J96-T7T=R;W5P("1G
M<F]U<"`@5&AE(&=R;W5P('1O('5P9&%T92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=7!D871E1W)O=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$
M871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L
M87-S+B<I.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M871A=')E92T^=7!D871E1&%T82@D9W)O=7`I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V<@=&AE('5P9&%T
M92!O9B!T:&4@9W)O=7`@=7-E<G,@;VX@=&AE(&AI<W1O<GD@;&]G+B`J+PH@
M("`@("`@("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I
M.PH@("`@("`@("1G=6ED(#T@)'1H:7,M/F=E=$=5240H)&=R;W5P*3L*("`@
M("`@("!F;W)E86-H("@D9W)O=7`M/F=E=$%U9&ET3&]G*"D@87,@)'5S97))
M9"`]/B`D86-T:6]N*2!["B`@("`@("`@("`@("1H:7-T;W)Y+3YL;V<H)&=U
M:60L(&%R<F%Y*"=A8W1I;VXG(#T^("1A8W1I;VXL("=U<V5R)R`]/B`D=7-E
M<DED*2P@=')U92D["B`@("`@("`@?0H@("`@("`@("1G<F]U<"T^8VQE87)!
M=61I=$QO9R@I.PH*("`@("`@("`O*B!,;V<@=&AE(&=R;W5P(&UO9&EF:6-A
M=&EO;BX@*B\*("`@("`@("`D:&ES=&]R>2T^;&]G*"1G=6ED+"!A<G)A>2@G
M86-T:6]N)R`]/B`G;6]D:69Y)RDL('1R=64I.PH@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E('1H92!N86UE
M(&]F(&$@9W)O=7`@=VET:&]U="!C:&%N9VEN9R!I=',@8V]N=&5N=',@;W(*
M("`@("`J('=H97)E(&ET(&ES(&EN('1H92!G<F]U<',@:&EE<F%R8VAY+@H@
M("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B:F5C=%]'<F]U<"`D9W)O
M=7`@(%1H92!G<F]U<"!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N97=.86UE("`@("`@("`@("`@("!4:&4@9W)O=7`G<R!N97<@;F%M92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE1W)O=7`H)&=R;W5P+"`D;F5W
M3F%M92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&=R;W5P+"`G1&%T851R
M965/8FIE8W1?1W)O=7`G*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@8F4@1&%T851R965/8FIE8W1?1W)O
M=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&%T871R964M/G)E;F%M92@D
M9W)O=7`L("1N97=.86UE*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*"B`@("`@("`@+RH@2&ES=&]R>2!,;V<@=&AE(&YA;64@8VAA
M;F=E(&]F('1H92!G<F]U<"X@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D
M95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@("`@("`D:&ES=&]R>2T^;&]G
M*"1T:&ES+3YG971'54E$*"1G<F]U<"DL(&%R<F%Y*"=A8W1I;VXG(#T^("=R
M96YA;64G*2P@=')U92D["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!G<F]U<"!F<F]M('1H92!G<F]U
M<',@<WES=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P87)A;2!$
M871A5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U<"!T;R!R96UO
M=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@("`@("`@("`@("`@
M("!&;W)C92!T;R!R96UO=F4@979E<GD@8VAI;&0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;6]V94=R;W5P*"1G<F]U<"P@)&9O<F-E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T
M7T=R;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T=R;W5P<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C
M=',@;W(@97AT96YD('1H870@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@
M("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG;&5T;VXH*3L*("`@
M("`@("`D:&ES=&]R>2T^;&]G*"1T:&ES+3YG971'54E$*"1G<F]U<"DL(&%R
M<F%Y*"=A8W1I;VXG(#T^("=D96QE=&4G*2P@=')U92D["@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YR96UO=F4H)&=R;W5P+"`D9F]R8V4I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&YA;64@;V8@
M82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED("!4
M:&4@:60@;V8@=&AE(&=R;W5P('1O(')E=')I979E('1H92!N86UE(&9O<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&=R;W5P)W,@;F%M
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!.86UE*"1G:60I"B`@
M("!["B`@("`@("`@:68@*&ES7V$H)&=I9"P@)T1A=&%4<F5E3V)J96-T7T=R
M;W5P)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M
M/F=E=$YA;64H)&=I9"T^9V5T260H*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$YA;64H)&=I
M9"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4W1R:7!S(&%L
M;"!P87)E;G0@<F5F97)E;F-E<R!O9F8@;V8@=&AE(&=I=F5N(&=R;W5P(&YA
M;64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9W)O=7`@($YA;64@
M;V8@=&AE(&=R;W5P+@H@("`@("H*("`@("`J($!R971U<FX@5&AE(&YA;64@
M;V8@=&AE(&=R;W5P('=I=&AO=70@<&%R96YT<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1W)O=7!3:&]R=$YA;64H)&=R;W5P*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG9713:&]R=$YA;64H)&=R;W5P
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!)1"!O9B!A
M(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!4
M:&4@9W)O=7`@=&\@<F5T<FEE=F4@=&AE($E$(&9O<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(@(%1H92!G<F]U<"=S($E$+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971'<F]U<$ED*"1G<F]U<"D*("`@('L*("`@("`@("!I
M9B`H:7-?82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971)9"@D9W)O
M=7`M/F=E=$YA;64H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$ED*"1G<F]U<"D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@82!G<F]U<"!E
M>&ES=',@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1G<F]U<"`@5&AE(&=R;W5P('1O(&-H96-K+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9W)O=7`@97AI<W1S+"!F
M86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D
M9W)O=7`I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M
M/F5X:7-T<R@D9W)O=7`I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@
M;&ES="!O9B!T:&4@<&%R96YT<R!O9B!A(&-H:6QD(&=R;W5P+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1G:60@5&AE(&ED(&]F('1H92!C:&EL
M9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$=R;W5P4&%R96YT<R@D9VED*0H@("`@>PH@("`@
M("`@("1N86UE(#T@)'1H:7,M/F=E=$=R;W5P3F%M92@D9VED*3L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT<R@D;F%M92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE('-I;F=L92!P87)E
M;G0@;V8@=&AE(&=I=F5N(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1G:60@(%1H92!$871A5')E92!)1"!O9B!T:&4@8VAI;&0@9W)O
M=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!T:&4@<&%R96YT(&]F('1H92!G
M:79E;B!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1W)O=7!087)E
M;G0H)&=I9"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D871A=')E
M92T^9V5T4&%R96YT0GE)9"@D9VED*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!A(&QI<W0@;V8@<&%R96YT<R!A;&P@=&AE('=A>2!U<"!T;R!T:&4@
M<F]O="!O8FIE8W0@9F]R("1G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9VED("!4:&4@:60@;V8@=&AE(&=R;W5P+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($$@9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@
M<&%R96YT<R!O9B`D9W)O=7`L"B`@("`@*B`@("`@("`@("`@("`@("!H87-H
M960@:6X@)&ED(#T^("1N86UE(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1W)O=7!087)E;G1,:7-T*"1G:60I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&%T871R964M/F=E=%!A<F5N=$QI<W0H)&=I9"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P
M+"!I;B!T:&4@9F]R;6%T(&-I9"`]/B!G<F]U<&YA;64N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')E9G)E<V@@($EF('1R=64L('1H92!C86-H
M960@=F%L=64@:7,@:6=N;W)E9"!A;F0@=&AE(&=R;W5P"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@;&ES="!I<R!R969R97-H960@9G)O;2!T
M:&4@9W)O=7`@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!#240@/3X@9W)O=7!N86UE(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&QI<W1'<F]U<',H)')E9G)E<V@@/2!F86QS92D*("`@('L*("`@("`@("!S
M=&%T:6,@)&=R;W5P<SL*"B`@("`@("`@:68@*"1R969R97-H('Q\(&ES7VYU
M;&PH)&=R;W5P<RDI('L*("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES+3Y?
M9&%T871R964M/F=E="A$051!5%)%15]&3U)-051?1DQ!5"P@1$%40512145?
M4D]/5"P@=')U92D["B`@("`@("`@("`@('5N<V5T*"1G<F]U<'-;1$%40512
M145?4D]/5%TI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1G<F]U<',[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S
M97(@=&AA="!I<R!A('!A<G0@;V8@=&AI<R!G<F]U<"!/3DQ9+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1G:60@(%1H92!)1"!O9B!T:&4@9W)O
M=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE('5S97(@;&ES
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"1G:60I"B`@("![
M"B`@("`@("`@)&=R;W5P3V(@/2`F)'1H:7,M/F=E=$=R;W5P0GE)9"@D9VED
M*3L*("`@("`@("!I9B`H:7-?82@D9W)O=7!/8BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&=R;W5P3V(["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES<V5T*"1G<F]U<$]B+3YD871A6R=U<V5R<R==*2!\?`H@
M("`@("`@("`@("`A:7-?87)R87DH)&=R;W5P3V(M/F1A=&%;)W5S97)S)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)&=R;W5P3V(M/F1A=&%;)W5S97)S
M)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R
M>2!U<V5R('1H870@:7,@<&%R="!O9B!T:&4@<W!E8VEF:65D(&=R;W5P"B`@
M("`@*B!A;F0@86YY(&]F(&ET<R!S=6)G<F]U<',N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&=R;W5P("!4:&4@240@;V8@=&AE('!A<F5N="!G
M<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]M<&QE
M=&4@=7-E<B!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T06QL57-E
M<G,H)&=I9"D*("`@('L*("`@("`@("`O+R!'970@82!L:7-T(&]F(&5V97)Y
M(&=R;W5P('1H870@:7,@82!S=6(M9W)O=7`@;V8@)&=R;W5P+@H@("`@("`@
M("1G<F]U<',@/2`D=&AI<RT^7V1A=&%T<F5E+3YG970H1$%40512145?1D]2
M34%47T9,050L("1T:&ES+3YG971'<F]U<$YA;64H)&=I9"DL('1R=64I.PH@
M("`@("`@(&EF("AI<U]A*"1G<F]U<',L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1G<F]U<',["B`@("`@("`@?0H*("`@("`@("`D
M9W)O=7!S(#T@87)R87E?:V5Y<R@D9W)O=7!S*3L*("`@("`@("`D=7-E<G,@
M/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1G<F]U<',@87,@)&=R;W5P
M260I('L*("`@("`@("`@("`@)'5S97)S(#T@87)R87E?;65R9V4H)'5S97)S
M+"`D=&AI<RT^;&ES=%5S97)S*"1G<F]U<$ED*2D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!A<G)A>5]V86QU97,H87)R87E?9FQI<"AA<G)A>5]F;&EP
M*"1U<V5R<RDI*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@
M;V8@979E<GD@9W)O=7`@=&AA="`D=7-E<B!I<R!I;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G
M970@9W)O=7!S(&9O<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E;G1'
M<F]U<',@($%L<V\@<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G<F]U<',_
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL
M(&=R;W5P<R!T:&4@=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<R`](&9A
M;'-E*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF
M("AE;7!T>2@D8V%C:&5;)'5S97)=*2D@>PH@("`@("`@("`@("`D8W)I=&5R
M:6$@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=!3D0G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:65L9"<@/3X@)VYA;64G+"`G
M;W`G(#T^("<])RP@)W1E<W0G(#T^("=U<V5R)RDL"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH)V9I96QD)R`]/B`G:V5Y)RP@)V]P)R`]/B`G/2<L("=T
M97-T)R`]/B`D=7-E<BDI*3L*("`@("`@("`@("`@)&=R;W5P<R`]("1T:&ES
M+3Y?9&%T871R964M/F=E=$)Y071T<FEB=71E<R@D8W)I=&5R:6$I.PH*("`@
M("`@("`@("`@:68@*&ES7V$H)&=R;W5P<RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)&=R;W5P<RP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E)/4BD["B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@D<&%R96YT1W)O=7!S*2!["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9W)O=7!S(&%S("1I9"`]/B`D9RD@>PH@("`@("`@("`@("`@("`@("`@
M("1P87)E;G1S(#T@)'1H:7,M/E]D871A=')E92T^9V5T4&%R96YT3&ES="@D
M:60I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P87)E;G1S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<&%R96YT<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P<R`K/2`D<&%R96YT<SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-A8VAE6R1U<V5R72`]
M("1G<F]U<',["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1U
M<V5R73L*("`@('T*"B`@("`O*BH*("`@("`J(%-A>2!I9B!A('5S97(@:7,@
M82!M96UB97(@;V8@82!G<F]U<"!O<B!N;W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=7-E<B`@("`@("`@5&AE(&YA;64@;V8@=&AE('5S97(N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9VED("`@("`@("!4:&4@240@;V8@
M=&AE(&=R;W5P+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-U8F=R;W5P<R`@
M4F5T=7)N('1R=64@:68@=&AE('5S97(@:7,@:6X@86YY('-U8F=R;W5P<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@9W)O=7`@=VET
M:"!)1"`D9VED+"!A;'-O+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A
M;@H@("`@("HO"B`@("!F=6YC=&EO;B!U<V5R27-);D=R;W5P*"1U<V5R+"`D
M9VED+"`D<W5B9W)O=7!S(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(21T
M:&ES+3YE>&ES=',H)'1H:7,M/F=E=$=R;W5P3F%M92@D9VED*2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS96EF("@D<W5B
M9W)O=7!S*2!["B`@("`@("`@("`@("1G<F]U<',@/2`D=&AI<RT^9V5T1W)O
M=7!-96UB97)S:&EP<R@D=7-E<BP@=')U92D["B`@("`@("`@("`@(&EF("AI
M<U]A*"1G<F]U<',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"1G<F]U<',L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("%E;7!T>2@D
M9W)O=7!S6R1G:61=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=7-E<G,@/2`D=&AI<RT^;&ES=%5S97)S*"1G:60I.PH@("`@("`@("`@("!I
M9B`H:7-?82@D=7-E<G,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@($AO<F1E.CIL;V=-97-S86=E*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!I;E]A<G)A
M>2@D=7-E<BP@)'5S97)S*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!$871A5')E92!L979E;"!O9B!T:&4@9VEV96X@
M9W)O=7`N(#`@:7,@<F5T=7)N960@9F]R"B`@("`@*B!A;F0@;V)J96-T(&1I
M<F5C=&QY(&)E;&]W($1!5$%44D5%7U)/3U0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&=I9"`@5&AE($1A=&%4<F5E($E$(&]F('1H92!G<F]U
M<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1H92!$871A5')E92!L979E;"!O
M9B!T:&4@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QE=F5L*"1G
M:60I"B`@("!["B`@("`@("`@)&YA;64@/2`D=&AI<RT^7V1A=&%T<F5E+3YG
M971.86UE*"1G:60I.PH@("`@("`@(')E='5R;B!S=6)S=')?8V]U;G0H)&YA
M;64L("<Z)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R
M971U<FX@82!C;VYC<F5T92!'<F]U<"!I;G-T86YC92!B87-E9"!O;B`D9')I
M=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@
M='EP92!O9B!C;VYC<F5T92!'<F]U<"!S=6)C;&%S<R!T;R!R971U<FXN"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@
M86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U8F-L
M87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!'<F]U<"`@
M5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@1W)O=7`@:6YS=&%N8V4L(&]R
M(&$*("`@("`J("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R(#T@)R<L("1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1D<FEV
M97(@/2!B87-E;F%M92@D9')I=F5R*3L*"B`@("`@("`@:68@*$!F:6QE7V5X
M:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O1W)O=7`O)R`N("1D<FEV97(@
M+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O1W)O=7`O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R
M9&4O1W)O=7`O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@?0H@("`@
M("`@("1C;&%S<R`]("='<F]U<%\G("X@)&1R:79E<CL*("`@("`@("!I9B`H
M8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&=R;W5P(#T@
M)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&=R;W5P(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0VQA<W,@9&5F:6YI
M=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N)RD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N8W)E
M=&4@1W)O=7`@:6YS=&%N8V4N"B`@("`@*B!)="!W:6QL(&]N;'D@8W)E871E
M(&$@;F5W(&EN<W1A;F-E(&EF(&YO($=R;W5P(&EN<W1A;F-E"B`@("`@*B!C
M=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU
M<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9'<F]U<#HZ<VEN9VQE=&]N*"D*
M("`@("`J"B`@("`@*B!`<F5T=7)N($=R;W5P("!4:&4@8V]N8W)E=&4@1W)O
M=7`@<F5F97)E;F-E+"!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@I"B`@("!["B`@("`@("`@<W1A=&EC
M("1G<F]U<#L*"B`@("`@("`@:68@*"%I<W-E="@D9W)O=7`I*2!["B`@("`@
M("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O075T:"YP:'`G.PH@("`@("`@("`@("`D875T:"`]("9!=71H
M.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH@("`@("`@
M("`@("!I9B`H)&%U=&@M/FAA<T-A<&%B:6QI='DH)V=R;W5P<R<I*2!["B`@
M("`@("`@("`@("`@("`D9W)O=7`@/2`F1W)O=7`Z.F9A8W1O<GDH)&%U=&@M
M/F=E=$1R:79E<B@I+"`D875T:"D["B`@("`@("`@("`@('T@96QS96EF("@A
M96UP='DH)&-O;F9;)V=R;W5P)UU;)V1R:79E<B==*2`F)B`D8V]N9ELG9W)O
M=7`G75LG9')I=F5R)UT@(3T@)V1A=&%T<F5E)RD@>PH@("`@("`@("`@("`@
M("`@)&=R;W5P(#T@)D=R;W5P.CIF86-T;W)Y*"1C;VYF6R=G<F]U<"==6R=D
M<FEV97(G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D9W)O=7`@/2!N97<@1W)O=7`H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1G<F]U<#L*("`@('T*"GT*"B\J*@H@*B!%
M>'1E;G-I;VX@;V8@=&AE($1A=&%4<F5E3V)J96-T(&-L87-S(&9O<B!S=&]R
M:6YG($=R;W5P(&EN9F]R;6%T:6]N"B`J(&EN('1H92!#871E9V]R:65S(&1R
M:79E<BX@268@>6]U('=A;G0@=&\@<W1O<F4@<W!E8VEA;&EZ960@1W)O=7`*
M("H@:6YF;W)M871I;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@8VQA<W,@
M:6YS=&5A9"!O9B!E>'1E;F1I;F<*("H@1&%T851R965/8FIE8W0@9&ER96-T
M;'DN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@2&]R
M9&5?1W)O=7`*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7T=R;W5P(&5X=&5N
M9',@1&%T851R965/8FIE8W0@>PH*("`@("\J*@H@("`@("H@5&AE($=R;W5P
M(&]B:F5C="!W:&EC:"!T:&ES(&=R;W5P(&ES(&%S<V]C:6%T960@=VET:"`M
M(&YE961E9`H@("`@("H@9F]R('5P9&%T:6YG(&1A=&$@:6X@=&AE(&)A8VME
M;F0@=&\@;6%K92!C:&%N9V5S('-T:6-K+"!E=&,N"B`@("`@*@H@("`@("H@
M0'9A<B!'<F]U<`H@("`@("HO"B`@("!V87(@)%]G<F]U<$]B.PH*("`@("\J
M*@H@("`@("H@5&AI<R!V87)I86)L92!C86-H97,@=&AE('5S97)S(&%D9&5D
M(&]R(')E;6]V960@9G)O;2!T:&4@9W)O=7`*("`@("`J(&9O<B!(:7-T;W)Y
M(&QO9V=I;F<@;V8@=7-E<BUG<F]U<',@<F5L871I;VYS:&EP+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?875D:71,;V<@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T
M7T=R;W5P(&-O;G-T<G5C=&]R+B!*=7-T(&UA:V5S('-U<F4@=&\@8V%L;`H@
M("`@("H@=&AE('!A<F5N="!C;VYS=')U8W1O<B!S;R!T:&%T('1H92!G<F]U
M<"=S(&YA;64@:7,@<V5T"B`@("`@*B!P<F]P97)L>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@9W)O=7`N
M"B`@("`@*B\*("`@(&9U;F-T:6]N($1A=&%4<F5E3V)J96-T7T=R;W5P*"1N
M86UE*0H@("`@>PH@("`@("`@('!A<F5N=#HZ1&%T851R965/8FIE8W0H)&YA
M;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@07-S;V-I871E<R!A($=R;W5P
M(&]B:F5C="!W:71H('1H:7,@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M
M($=R;W5P("1G<F]U<$]B("!4:&4@1W)O=7`@;V)J96-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971'<F]U<$]B*"8D9W)O=7!/8BD*("`@('L*("`@("`@
M("`D=&AI<RT^7V=R;W5P3V(@/2`F)&=R;W5P3V(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&971C:"!T:&4@240@;V8@=&AI<R!G<F]U<`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG(%1H92!G<F]U<"=S($E$"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$ED*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]G<F]U<$]B+3YG971'<F]U<$ED*"1T:&ES*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-A=F4@86YY(&-H86YG97,@=&\@=&AI<R!O8FIE8W0@=&\@=&AE
M(&)A8VME;F0@<&5R;6%N96YT;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N('-A
M=F4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/G5P
M9&%T94=R;W5P*"1T:&ES*3L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S
M(&$@=7-E<B!T;R!T:&ES(&=R;W5P+"!A;F0@;6%K97,@<W5R92!T:&%T('1H
M92!B86-K96YD(&ES"B`@("`@*B!U<&1A=&5D(&%S('=E;&PN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@5&AE('5S97(@=&\@861D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R;F%M92P@)'5P
M9&%T92`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S
M)UU;)'5S97)N86UE72`](#$["B`@("`@("`@)'1H:7,M/E]A=61I=$QO9ULD
M=7-E<FYA;65=(#T@)V%D9%5S97(G.PH@("`@("`@(&EF("@D=7!D871E("8F
M("1T:&ES+3Y?9W)O=7!/8BT^97AI<W1S*"1T:&ES+3YG971.86UE*"DI*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!U<V5R(&9R;VT@=&AI
M<R!G<F]U<"P@86YD(&UA:V5S('-U<F4@=&AA="!T:&4@8F%C:V5N9`H@("`@
M("H@:7,@=7!D871E9"!A<R!W96QL+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97)N86UE(%1H92!U<V5R('1O(')E;6]V92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<FYA;64L("1U<&1A=&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R<R==
M6R1U<V5R;F%M95TI.PH@("`@("`@("1T:&ES+3Y?875D:71,;V=;)'5S97)N
M86UE72`]("=D96QE=&55<V5R)SL*("`@("`@("!I9B`H)'5P9&%T92D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@
M=&AA="!I<R!A('!A<G0@;V8@=&AI<R!G<F]U<`H@("`@("H@*&%N9"!O;FQY
M('1H:7,@9W)O=7`I"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE
M('5S97(@;&ES=`H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/FQI<W15<V5R
M<R@D=&AI<RT^9V5T260H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!A('!A<G0@;V8@=&AI<R!G
M<F]U<"!A;F0*("`@("`J(&%N>2!O9B!I="=S('-U8F=R;W5P<PH@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!C;VUP;&5T92!U<V5R(&QI<W0*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%L;%5S97)S*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]G<F]U<$]B+3YL:7-T06QL57-E<G,H)'1H
M:7,M/F=E=$ED*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&%L;"!T
M:&4@=7-E<G,@<F5C96YT;'D@861D960@;W(@<F5M;W9E9"!F<F]M('1H92!G
M<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T075D:71,;V<H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V%U9&ET3&]G.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VQE87)S('1H92!A=61I="!L;V<N(%1O(&)E(&-A;&QE
M9"!A9G1E<B!G<F]U<"!U<&1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M96%R075D:71,;V<H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?875D:71,;V<@
M/2!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P('1H:7,@;V)J
M96-T)W,@871T<FEB=71E<R!F<F]M('1H92!D871A(&%R<F%Y(&EN=&\@82!F
M;W)M870*("`@("`J('1H870@=V4@8V%N('-T;W)E(&EN('1H92!A='1R:6)U
M=&5S('-T;W)A9V4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@871T<FEB=71E<R!A<G)A>2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W1O071T<FEB=71E<R@I"B`@("!["B`@("`@("`@+R\@1&5F875L="!T
M;R!N;R!A='1R:6)U=&5S+@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87DH
M*3L*"B`@("`@("`@+R\@3&]O<"!T:')O=6=H(&%L;"!U<V5R<RP@:68@86YY
M+@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9&%T85LG=7-E<G,G72D@)B8@
M:7-?87)R87DH)'1H:7,M/F1A=&%;)W5S97)S)UTI("8F(&-O=6YT*"1T:&ES
M+3YD871A6R=U<V5R<R==*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI
M<RT^9&%T85LG=7-E<G,G72!A<R`D=7-E<B`]/B`D86-T:79E*2!["B`@("`@
M("`@("`@("`@("`D871T<FEB=71E<UM=(#T@87)R87DH)VYA;64G(#T^("=U
M<V5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:V5Y)R`]/B`D=7-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F%L=64G(#T^("1A8W1I=F4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1A='1R:6)U=&5S6UT@/2!A<G)A>2@G;F%M92<@
M/3X@)V5M86EL)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VME
M>2<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V86QU
M92<@/3X@)'1H:7,M/F=E="@G96UA:6PG*2D["@H@("`@("`@(')E='5R;B`D
M871T<FEB=71E<SL*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@:6X@82!L
M:7-T(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@8F%C:V5N9"!A;F0@;6%P(&ET
M('1O(&]U<@H@("`@("H@:6YT97)N86P@9&%T82!A<G)A>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1H92!L:7-T(&]F(&%T
M=')I8G5T97,@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8F%C:V5N9"`H871T<FEB=71E(&YA;64L(&ME>2P@86YD('9A;'5E
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9R;VU!='1R:6)U=&5S*"1A='1R
M:6)U=&5S*0H@("`@>PH@("`@("`@("\O($EN:71I86QI>F4@9&%T82!A<G)A
M>2X*("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G72`](&%R<F%Y*"D["@H@
M("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R*2!["B`@("`@
M("`@("`@(&EF("@D871T<ELG;F%M92==(#T]("=U<V5R)RD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F1A=&%;)W5S97)S)UU;)&%T=');)VME>2==72`]
M("1A='1R6R=V86QU92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F1A=&%;)&%T=');)VYA;64G75T@/2`D871T<ELG
M=F%L=64G73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O0VEP:&5R+G!H<```````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8P-#0@,3`U,34T,S0Q-#`@,#(Q,C8V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2&]R9&5?0VEP:&5R.CH@8VQA<W,@<')O=FED97,@
M82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@=&\*("H@=F%R:6]U<R!#
M:7!H97)S(&9O<B!E;F-R>7!T:6]N(&]F(&%R8FET<F%R>2!L96YG=&@@<&EE
M8V5S(&]F(&1A=&$N"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(N<&AP+'8@
M,2XQ-BXQ,BXX(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J
M($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#
M:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8FQO8VL@;6]D92!F;W(@=&AE(&-I<&AE<B!C:&%I;FEN9PH@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)L;V-K
M36]D92`]("=#0D,G.PH*("`@("\J*@H@("`@("H@5&AE(&EN:71I86QI>F%T
M:6]N('9E8W1O<@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7VEV(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M8FQO8VL@;6]D92!F;W(@8VEP:&5R(&-H86EN:6YG+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&)L;V-K36]D92`@5&AE(&YE=R!B;&]C:VUO9&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$)L;V-K36]D92@D8FQO8VM-;V1E
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8FQO8VM-;V1E(#T@)&)L;V-K36]D
M93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@258N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:78@(%1H92!N97<@258N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$E6*"1I=BD*("`@('L*("`@("`@("`D=&AI<RT^
M7VEV(#T@)&EV.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P;&%I;G1E>'0@
M(%1H92!D871A('1O(&5N8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!E;F-R>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@96YC<GEP="@D<&QA:6YT97AT*0H@("`@>PH@("`@("`@(')E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O0VEP:&5R+T)L;V-K36]D92YP
M:'`G.PH@("`@("`@("1B;&]C:TUO9&4@/2`F2&]R9&5?0VEP:&5R7T)L;V-K
M36]D93HZ9F%C=&]R>2@D=&AI<RT^7V)L;V-K36]D92D["B`@("`@("`@:68@
M*"%I<U]N=6QL*"1T:&ES+3Y?:78I*2!["B`@("`@("`@("`@("1B;&]C:TUO
M9&4M/G-E=$E6*"1T:&ES+3Y?:78I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1B;&]C:TUO9&4M/F5N8W)Y<'0H)'1H:7,L("1P;&%I;G1E>'0I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A('-T<FEN9RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97)T97AT("!4:&4@9&%T82!T
M;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M9&5C<GEP=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'0H
M)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]#:7!H97(O0FQO8VM-;V1E+G!H<"<["B`@("`@
M("`@)&)L;V-K36]D92`]("9(;W)D95]#:7!H97)?0FQO8VM-;V1E.CIF86-T
M;W)Y*"1T:&ES+3Y?8FQO8VM-;V1E*3L*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'1H:7,M/E]I=BDI('L*("`@("`@("`@("`@)&)L;V-K36]D92T^<V5T258H
M)'1H:7,M/E]I=BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L;V-K
M36]D92T^9&5C<GEP="@D=&AI<RP@)&-I<&AE<G1E>'0I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@2&]R
M9&5?0VEP:&5R(&EN<W1A;F-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&-I<&AE<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0VEP:&5R
M('-U8F-L87-S('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(')E
M='5R;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@02!H87-H(&-O
M;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@<&%R86UE=&5R<R!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('-U8F-L87-S(&UI9VAT(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!(;W)D95]#:7!H97(@(%1H92!N97=L>2!C
M<F5A=&5D(&-O;F-R971E($AO<F1E7T-I<&AE<B!I;G-T86YC92P*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!O<B!014%27T5R<F]R(&]N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D8VEP:&5R+"`D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("`D9')I=F5R(#T@8F%S96YA;64H
M)&-I<&AE<BD["@H@("`@("`@(&EF("A`9FEL95]E>&ES=',H9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+T-I<&AE<B\G("X@)&-I<&AE<B`N("<N<&AP)RDI('L*
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]#:7!H97(O)R`N("1C:7!H97(@+B`G+G!H<"<["B`@("`@("`@?0H*("`@
M("`@("`D8VQA<W,@/2`G2&]R9&5?0VEP:&5R7R<@+B`D8VEP:&5R.PH@("`@
M("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D
M8VEP:&5R(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&-I<&AE<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L
M87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C:7!H97(["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U)E9VES=')Y+G!H<```````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,3$Q-S(S(#$P-3$U-#,T,30P(#`R,38V
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ($1O(&YO="!S=&%R="!A('-E<W-I;VXN("HO"F1E9FEN92@G
M2$]21$5?4T534TE/3E].3TY%)RP@,2D["@HO*BH@1&\@;F]T('=R:71E(&-H
M86YG97,@=&\@<V5S<VEO;BX@*B\*9&5F:6YE*"=(3U)$15]315-324].7U)%
M041/3DQ9)RP@,BD["@HO*BH*("H@5&AE(%)E9VES=')Y.CH@8VQA<W,@<')O
M=FED97,@82!S970@;V8@;65T:&]D<R!F;W(@8V]M;75N:6-A=&EO;@H@*B!B
M971W965N($AO<F1E(&%P<&QI8V%T:6]N<R!A;F0@:V5E<&EN9R!T<F%C:R!O
M9B!A<'!L:6-A=&EO;@H@*B!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R](;W)D92](;W)D92]296=I<W1R>2YP
M:'`L=B`Q+C(T,RXR+C(R(#(P,#8O,#4O,#0@,C(Z,S4Z,C8@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@2F]N(%!A
M<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!
M;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]&
M<F%M97=O<FL*("HO"F-L87-S(%)E9VES=')Y('L*"B`@("`O*BH*("`@("`J
M($AA<V@@<W1O<FEN9R!A;&P@;V8@=&AE(&MN;W=N('-E<G9I8V5S(&%N9"!C
M86QL8F%C:W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]A<&E#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!(
M87-H('-T;W)I;F<@86QL(&MN;W=N(&1A=&$@='EP97,N"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T>7!E0V%C:&4@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@2&%S:"!S=&]R:6YG(&%L;"!O9B!T
M:&4@<F5G:7-T97)E9"!I;G1E<F9A8V5S('1H870@87!P;&EC871I;VYS"B`@
M("`@*B!P<F]V:61E+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?:6YT97)F86-E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!(87-H('-T;W)I;F<@:6YF;W)M871I;VX@;VX@96%C:"!R96=I<W1R
M>2UA=V%R92!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D87!P;&EC871I;VYS(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J(%-T86-K(&]F(&EN+75S92!A<'!L:6-A=&EO;G,N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A<'!3
M=&%C:R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!1=6EC:R!P;VEN=&5R
M('1O('1H92!C=7)R96YT(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1!<'`@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@)'!R969S(&]B:F5C=',*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!R969S
M0V%C:&4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@87!P
M;&EC871I;VX@8V]N9FEG=7)A=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]C;VYF0V%C:&4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@07)E('=E('5S:6YG(')E9VES=')Y(&-A8VAI;F<_
M"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?=7-E8V%C:&4@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%5P9&%T92!T
M:&5S92!C86-H92!E;G1R:65S(&]N('-H=71D;W=N+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U<&1A=&5C86-H92`]
M(&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@=&AE<V4@;71I;64@
M96YT<FEE<R!O;B!S:'5T9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D*("`@("`J+PH@("`@=F%R("1?=7!D871E;71I;64@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@1&]N)W0@=7!D871E(&-A8VAE(&%T(&5N9"!O9B!R
M97%U97-T/PH@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7VYO8V%C:&4@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!R969E<F5N8V4@=&\@=&AE(&=L;V)A;"!296=I<W1R>2!O8FIE
M8W0L(&]N;'D*("`@("`J(&-R96%T:6YG(&ET(&EF(&ET(&1O97-N)W0@86QR
M96%D>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E
M(&EN=F]K960@87,Z("1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5S<VEO;E]F;&%G
M<R`@06YY('-E<W-I;VX@9FQA9W,N"B`@("`@*@H@("`@("H@0')E='5R;B!2
M96=I<W1R>2`@5&AE($AO<F1E(%)E9VES=')Y(&EN<W1A;F-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1S97-S:6]N7V9L86=S(#T@,"D*
M("`@('L*("`@("`@("!S=&%T:6,@)')E9VES=')Y.PH*("`@("`@("!I9B`H
M(6ES<V5T*"1R96=I<W1R>2DI('L*("`@("`@("`@("`@)')E9VES=')Y(#T@
M;F5W(%)E9VES=')Y*"1S97-S:6]N7V9L86=S*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D<F5G:7-T<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&4@82!N97<@<F5G:7-T<GD@:6YS=&%N8V4N(%-H;W5L9"!N979E<B!B
M92!C86QL960@97AC97!T"B`@("`@*B!B>2`F4F5G:7-T<GDZ.G-I;F=L971O
M;B@I+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1S97-S:6]N7V9L
M86=S("!!;GD@<V5S<VEO;B!F;&%G<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@4F5G:7-T<GDH)'-E<W-I
M;VY?9FQA9W,@/2`P*0H@("`@>PH@("`@("`@("\J($EM<&]R="!A;F0@9VQO
M8F%L($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!V86QU97,N("HO"B`@("`@("`@
M)'1H:7,M/FEM<&]R=$-O;F9I9R@G:&]R9&4G*3L*"B`@("`@("`@+RH@4W1A
M<G0@82!S97-S:6]N+B`J+PH@("`@("`@(&EF("@D<V5S<VEO;E]F;&%G<R`F
M($A/4D1%7U-%4U-)3TY?3D].12D@>PH@("`@("`@("`@("`O*B!.979E<B!S
M=&%R="!A('-E<W-I;VX@:68@=&AE('-E<W-I;VX@9FQA9W,@:6YC;'5D90H@
M("`@("`@("`@("`@("!(3U)$15]315-324].7TY/3D4N("HO"B`@("`@("`@
M("`@("1?4T534TE/3B`](&%R<F%Y*"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@2&]R9&4Z.G-E='5P4V5S<VEO;DAA;F1L97(H*3L*("`@("`@
M("`@("`@0'-E<W-I;VY?<W1A<G0H*3L*("`@("`@("`@("`@:68@*"1S97-S
M:6]N7V9L86=S("8@2$]21$5?4T534TE/3E]214%$3TY,62D@>PH@("`@("`@
M("`@("`@("`@+RH@0VQO<V4@=&AE('-E<W-I;VX@:6UM961I871E;'D@<V\@
M;F\@8VAA;F=E<R!C86X@8F4*("`@("`@("`@("`@("`@("`@(&UA9&4@8G5T
M('9A;'5E<R!A<F4@<W1I;&P@879A:6QA8FQE+B`J+PH@("`@("`@("`@("`@
M("`@0'-E<W-I;VY?=W)I=&5?8VQO<V4H*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E8V%C:&4@/2!T<G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!);FET:6%L:7IE
M('1H92!L;V-A;&EZ871I;VX@<F]U=&EN97,@86YD('9A<FEA8FQE<RX@*B\*
M("`@("`@("!.3%,Z.G-E=$QA;F<H*3L*("`@("`@("!.3%,Z.G-E=%1E>'1D
M;VUA:6XH)VAO<F1E)RP@2$]21$5?0D%312`N("<O;&]C86QE)RP@3DQ3.CIG
M971#:&%R<V5T*"DI.PH@("`@("`@(%-T<FEN9SHZ<V5T1&5F875L=$-H87)S
M970H3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@("`D<F5G7VUT:6UE(#T@
M9FEL96UT:6UE*$A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP:'`G
M*3L*"B`@("`@("`@+RH@3&]A9"!R96=I<W1R>2!I;F9O<FUA=&EO;B!F<F]M
M('1H92!S97-S:6]N+"!I9B!A=F%I;&%B;&4N("HO"B`@("`@("`@:68@*"%E
M;7!T>2@D7U-%4U-)3TY;)U]R96=I<W1R>6-A8VAE)UTI("8F"B`@("`@("`@
M("`@("@D7U-%4U-)3TY;)U]R96=I<W1R>6UT:6UE)UU;)W)E9VES=')Y+G!H
M<"==(#T]("1R96=?;71I;64I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1?
M4T534TE/3ELG7W)E9VES=')Y8V%C:&4G72!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;#L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%)E860@=&AE
M(')E9VES=')Y(&-O;F9I9W5R871I;VX@9FEL92X@*B\*("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]R96=I<W1R>2YP
M:'`G.PH*("`@("`@("`@("`@+RH@4W1O<"!S>7-T96T@:68@2&]R9&4@:7,@
M:6YA8W1I=F4N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^87!P;&EC871I
M;VYS6R=H;W)D92==6R=S=&%T=7,G72`]/2`G:6YA8W1I=F4G*2!["B`@("`@
M("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B5&AI<R!S>7-T96T@:7,@8W5R
M<F5N=&QY(&1E86-T:79A=&5D+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!38V%N(&9O<B!A;&P@05!)
M<R!P<F]V:61E9"!B>2!E86-H(&%P<"P@86YD('-E="!O=&AE<@H@("`@("`@
M("`@("`@*B!C;VUM;VX@9&5F875L=',@;&EK92!T96UP;&%T97,@86YD(&=R
M87!H:6-S+B`J+PH@("`@("`@("`@("`D87!P3&ES="`](&%R<F%Y7VME>7,H
M)'1H:7,M/F%P<&QI8V%T:6]N<RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1A
M<'!,:7-T(&%S("1A<'!.86UE*2!["B`@("`@("`@("`@("`@("`D87!P(#T@
M)B1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<$YA;65=.PH@("`@("`@("`@("`@
M("`@:68@*"@D87!P6R=S=&%T=7,G72`]/2`G:&5A9&EN9R<I('Q\"B`@("`@
M("`@("`@("`@("`@("`@*"1A<'!;)W-T871U<R==(#T]("=I;F%C=&EV92<I
M('Q\"B`@("`@("`@("`@("`@("`@("`@*"1A<'!;)W-T871U<R==(#T]("=A
M9&UI;B<@)B8@(4%U=&@Z.FES061M:6XH*2DI('L*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D87!P6R=P<F]V:61E<R==*2D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D87!P6R=P<F]V:61E<R==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D87!P6R=P<F]V:61E
M<R==(&%S("1I;G1E<F9A8V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT97)F86-E72`]("1A<'!.86UE
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;G1E<F9A8V5S6R1A<'!;)W!R;W9I9&5S)UU=(#T@)&%P<$YA;64["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D87!P6R=T96UP;&%T97,G72D@)B8@:7-S970H
M)&%P<%LG9FEL97)O;W0G72DI('L*("`@("`@("`@("`@("`@("`@("`D87!P
M6R=T96UP;&%T97,G72`]("1A<'!;)V9I;&5R;V]T)UT@+B`G+W1E;7!L871E
M<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1A<'!;)VIS=7)I)UTI("8F(&ES<V5T*"1A<'!;)W=E8G)O;W0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D87!P6R=J<W5R:2==(#T@)&%P<%LG
M=V5B<F]O="==("X@)R]J<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1A<'!;)VIS9G,G72D@)B8@:7-S970H)&%P
M<%LG9FEL97)O;W0G72DI('L*("`@("`@("`@("`@("`@("`@("`D87!P6R=J
M<V9S)UT@/2`D87!P6R=F:6QE<F]O="==("X@)R]J<R<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1A<'!;)W1H96UE
M<W5R:2==*2`F)B!I<W-E="@D87!P6R=W96)R;V]T)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&%P<%LG=&AE;65S=7)I)UT@/2`D87!P6R=W96)R;V]T
M)UT@+B`G+W1H96UE<R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1A<'!;)W1H96UE<V9S)UTI("8F(&ES<V5T*"1A
M<'!;)V9I;&5R;V]T)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&%P<%LG
M=&AE;65S9G,G72`]("1A<'!;)V9I;&5R;V]T)UT@+B`G+W1H96UE<R<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($-L96%R(&]U="!T:&4@05!)("8@5'EP92!C86-H97,L(&EF('1H97D@97AI
M<W1S+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V%P:4-A8VAE(#T@)'1H:7,M
M/E]T>7!E0V%C:&4@/2!A<G)A>2@I.PH*("`@("`@("`@("`@)'1H:7,M/E]C
M86-H959A<G,H87)R87DH)V%P<&QI8V%T:6]N<R<L("=?:6YT97)F86-E<R<L
M("=?87!I0V%C:&4G+"`G7W1Y<&5#86-H92<I+"!A<G)A>2@G<F5G:7-T<GDN
M<&AP)R`]/B`D<F5G7VUT:6UE*2D["B`@("`@("`@?0H*("`@("`@("`O*B!#
M<F5A=&4@=&AE(&=L;V)A;"!097)M<R!O8FIE8W0N("HO"B`@("`@("`@)$=,
M3T)!3%-;)W!E<FUS)UT@/2`F4&5R;7,Z.G-I;F=L971O;B@I.PH*("`@("`@
M("`O*B!!='1A8V@@:F%V87-C<FEP="!N;W1I9FEC871I;VX@;&ES=&5N97(N
M("HO"B`@("`@("`@)&YO=&EF:6-A=&EO;B`]("9.;W1I9FEC871I;VXZ.G-I
M;F=L971O;B@I.PH@("`@("`@("1N;W1I9FEC871I;VXM/F%T=&%C:"@G:F%V
M87-C<FEP="<I.PH*("`@("`@("`O*B!296=I<W1E<B!A8V-E<W,@:V5Y(&QO
M9V=E<B!F;W(@=')A;G-L871O<G,N("HO"B`@("`@("`@:68@*$`D1TQ/0D%,
M4ULG8V]N9B==6R=L;V=?86-C97-S:V5Y<R==*2!["B`@("`@("`@("`@(')E
M9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*&-R96%T95]F=6YC=&EO;B@G)RP@
M)TAO<F1E.CIG971!8V-E<W-+97DH;G5L;"P@;G5L;"P@=')U92D[)RDI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A(&QI<W0@;V8@
M=F%R:6%B;&4@;F%M97,@86YD(&UO9&EF:6-A=&EO;B!T:6UE<R!T;R!B92!C
M86-H960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1V87)S("`@($$@;&ES="!O9B!V87)I86)L
M92!N86UE<R!T;R!B92!C86-H960N"B`@("`@*B!`<&%R86T@87)R87D@)&UT
M:6UE<R`@02!L:7-T(&]F(&9I;&4@;6]D:69I8V%I;VX@=&EM97,@=&\@8F4@
M8V%C:&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%C:&5687)S*"1V87)S
M(#T@87)R87DH*2P@)&UT:6UE<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M<W1A=&EC("1R96=C86-H97-H=71D;W=N(#T@9F%L<V4["@H@("`@("`@(&EF
M("@D=&AI<RT^7W5S96-A8VAE*2!["B`@("`@("`@("`@("1T:&ES+3Y?=7!D
M871E8V%C:&4@/2!A<G)A>5]M97)G92@D=&AI<RT^7W5P9&%T96-A8VAE+"`D
M=F%R<RD["B`@("`@("`@("`@("1T:&ES+3Y?=7!D871E;71I;64@/2!A<G)A
M>5]M97)G92@D=&AI<RT^7W5P9&%T96UT:6UE+"`D;71I;65S*3L*("`@("`@
M("`@("`@:68@*"$D<F5G8V%C:&5S:'5T9&]W;BD@>PH@("`@("`@("`@("`@
M("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH)B1T:&ES+"`G
M7W-H=71D;W=N8V%C:&4G*2D["B`@("`@("`@("`@("`@("`D<F5G8V%C:&5S
M:'5T9&]W;B`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3=&]R97,@8V%C:&5A8FQE(&UE;6)E<B!V87)I
M86)L97,@:6X@=&AE('-E<W-I;VX@870@<VAU=&1O=VXN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:'5T
M9&]W;F-A8VAE*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)%]315-324].
M*2`F)B!!=71H.CIG971!=71H*"D@)B8@(21T:&ES+3Y?;F]C86-H92D@>PH@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG7W)E9VES=')Y8V%C
M:&4G72DI('L*("`@("`@("`@("`@("`@("1?4T534TE/3ELG7W)E9VES=')Y
M8V%C:&4G72`](&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y7W5N:7%U92@D=&AI<RT^7W5P9&%T96-A8VAE*2!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I<W1R
M>6-A8VAE)UU;)'9A;%T@/2`D=&AI<RT^)'9A;#L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*"%I<W-E="@D7U-%4U-)3TY;)U]R96=I<W1R>6UT
M:6UE)UTI*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)U]R96=I<W1R
M>6UT:6UE)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!F;W)E86-H("AA<G)A>5]U;FEQ=64H)'1H:7,M/E]U<&1A=&5M=&EM92D@
M87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;
M)U]R96=I<W1R>6UT:6UE)UU;)&ME>5T@/2`D=F%L.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0VQE87(@=&AE(')E
M9VES=')Y(&-A8VAE+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*
M("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87)#86-H92@I"B`@("!["B`@("`@
M("`@=6YS970H)%]315-324].6R=?<F5G:7-T<GEC86-H92==*3L*("`@("`@
M("`D=&AI<RT^7VYO8V%C:&4@/2!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1FEL;',@=&AE(')E9VES=')Y)W,@05!)(&-A8VAE('=I=&@@=&AE(&%V
M86EL86)L92!S97)V:6-E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V9I;&Q!4$E#86-H92@I"B`@("![
M"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V%P:4-A8VAE*2D@>PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@
M87)R87DH)V%C=&EV92<L("=N;W1O;VQB87(G+"`G:&ED9&5N)RD["B`@("`@
M("`@:68@*$%U=&@Z.FES061M:6XH*2D@>PH@("`@("`@("`@("`D<W1A='5S
M6UT@/2`G861M:6XG.PH@("`@("`@('T*("`@("`@("`D87!P<R`]("1T:&ES
M+3YL:7-T07!P<R@D<W1A='5S*3L*("`@("`@("!F;W)E86-H("@D87!P<R!A
M<R`D87!P*2!["B`@("`@("`@("`@("1?<V5R=FEC97,@/2`D7W1Y<&5S(#T@
M;G5L;#L*("`@("`@("`@("`@)&%P:2`]("1T:&ES+3YG970H)V9I;&5R;V]T
M)RP@)&%P<"D@+B`G+VQI8B]A<&DN<&AP)SL*("`@("`@("`@("`@:68@*&ES
M7W)E861A8FQE*"1A<&DI*2!["B`@("`@("`@("`@("`@("!I;F-L=61E7V]N
M8V4@)&%P:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1?<V5R=FEC97,I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%P:4-A
M8VAE6R1A<'!=(#T@87)R87DH*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?87!I0V%C:&5;)&%P<%T@/2`D7W-E<G9I
M8V5S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7W1Y
M<&5S*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)%]T>7!E<R!A<R`D
M='EP92`]/B`D<&%R86US*2!["B`@("`@("`@("`@("`@("`@("`@+RH@4')E
M9FEX(&YO;BU(;W)D92!T>7!E<R!W:71H('1H92!A<'!L:6-A=&EO;@H@("`@
M("`@("`@("`@("`@("`@("`J(&YA;64N("HO"B`@("`@("`@("`@("`@("`@
M("`@)'!R969I>"`]("1A<'`@/3T@)VAO<F1E)R`_("<G(#H@(B1[87!P?5\B
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?='EP94-A8VAE6R1P<F5F
M:7@@+B`D='EP95T@/2`D<&%R86US.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-A8VAE5F%R
M<RAA<G)A>2@G7V%P:4-A8VAE)RP@)U]T>7!E0V%C:&4G*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@82!L:7-T(&]F('1H92!I;G-T86QL960@
M86YD(')E9VES=&5R960@87!P;&EC871I;VYS+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`@("1F:6QT97(@("`@("!!;B!A<G)A>2!O9B!T:&4@<W1A
M='5S97,@=&AA="!S:&]U;&0@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FYE9"X@1&5F875L=',@=&\@;F]N+6AI9&1E;BX*
M("`@("`J($!P87)A;2!B;V]L96%N("1A<W-O8R`@("`@("!!<W-O8VEA=&EV
M92!A<G)A>2!W:71H(&%P<"!N86UE<R!A<R!K97ES+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N(&QE=F5L('1O
M(&-H96-K(&9O<B!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!L:7-T+B!$969A=6QT<R!T;R!015)-4U]32$]7+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($QI<W0@;V8@87!P<R!R96=I<W1E<F5D
M('=I=&@@2&]R9&4N($EF(&YO"B`@("`@*B`@("`@("`@("`@("`@("!A<'!L
M:6-A=&EO;G,@87)E(&1E9FEN960@<F5T=7)N<R!A;B!E;7!T>2!A<G)A>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$%P<',H)&9I;'1E<B`](&YU;&PL
M("1A<W-O8R`](&9A;'-E+"`D<&5R;6ES<VEO;B`](%!%4DU37U-(3U<I"B`@
M("!["B`@("`@("`@)&%P<',@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<U]N
M=6QL*"1F:6QT97(I*2!["B`@("`@("`@("`@("1F:6QT97(@/2!A<G)A>2@G
M;F]T;V]L8F%R)RP@)V%C=&EV92<I.PH@("`@("`@('T*"B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/F%P<&QI8V%T:6]N<R!A<R`D87!P(#T^("1P87)A;7,I
M('L*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1P87)A;7-;)W-T871U<R==
M+"`D9FEL=&5R*2`F)@H@("`@("`@("`@("`@("`@*&1E9FEN960H)T%55$A?
M2$%.1$Q%4B<I('Q\("1T:&ES+3YH87-097)M:7-S:6]N*"1A<'`L("1P97)M
M:7-S:6]N*2DI('L*("`@("`@("`@("`@("`@("1A<W-O8R`_("1A<'!S6R1A
M<'!=(#T@)&%P<"`Z("1A<'!S6UT@/2`D87!P.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&%P<',["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&%L;"!A=F%I;&%B;&4@<F5G:7-T<GD@05!)<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@05!)(&QI<W0N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!4$ES*"D*("`@('L*("`@("`@("!S
M=&%T:6,@)&%P:7,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D87!I<RD@>PH@
M("`@("`@("`@("!R971U<FX@)&%P:7,["B`@("`@("`@?0H*("`@("`@("!F
M;W)E86-H("AA<G)A>5]K97ES*"1T:&ES+3Y?:6YT97)F86-E<RD@87,@)&EN
M=&5R9F%C92D@>PH@("`@("`@("`@("!`;&ES="@D87!I+"`I(#T@97AP;&]D
M92@G+R<L("1I;G1E<F9A8V4I.PH@("`@("`@("`@("`D87!I<UM=(#T@)&%P
M:3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>5]U;FEQ=64H)&%P
M:7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;&P@;V8@=&AE
M(&%V86EL86)L92!R96=I<W1R>2!M971H;V1S+"!O<B!A;'1E<FYA=&5L>0H@
M("`@("H@;VYL>2!T:&]S92!F;W(@82!S<&5C:69I960@05!)+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%P:2`@1&5F:6YE<R!T:&4@05!)(&9O
M<B!W:&EC:"!T:&4@;65T:&]D<R!S:&%L;"!B90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@;65T:&]D(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI
M<W1-971H;V1S*"1A<&D@/2!N=6QL*0H@("`@>PH@("`@("`@("1M971H;V1S
M(#T@87)R87DH*3L*"B`@("`@("`@)'1H:7,M/E]F:6QL05!)0V%C:&4H*3L*
M"B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^87!P;&EC871I
M;VYS*2!A<R`D87!P*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M87!P;&EC871I;VYS6R1A<'!=6R=P<F]V:61E<R==*2D@>PH@("`@("`@("`@
M("`@("`@)'!R;W9I9&5S(#T@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG
M<')O=FED97,G73L*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'!R
M;W9I9&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("1P<F]V:61E<R`](&%R
M<F%Y*"1P<F]V:61E<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<')O=FED97,@/2!A<G)A>2@I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D<')O=FED
M97,@87,@)&UE=&AO9"D@>PH@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D
M;65T:&]D+"`G+R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1A<&DI('Q\"B`@("`@("`@("`@("`@("`@("`@("`@
M("AS=6)S='(H)&UE=&AO9"P@,"P@<W1R;&5N*"1A<&DI*2`]/2`D87!I*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D;65T:&]D<UM=(#T@)&UE=&AO
M9#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H:7-?;G5L;"@D87!I*2!\?"`H)&UE=&AO9"`]/2`D87!I*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V%P:4-A8VAE
M6R1A<'!=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("AA
M<G)A>5]K97ES*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%TI(&%S("1S97)V:6-E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65T:&]D<UM=(#T@
M)&UE=&AO9"`N("<O)R`N("1S97)V:6-E.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R
M87E?=6YI<75E*"1M971H;V1S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86QL(&]F('1H92!A=F%I;&%B;&4@<F5G:7-T<GD@9&%T82!T>7!E
M<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&%T82!T>7!E
M(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W14>7!E<R@I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]F:6QL05!)0V%C:&4H*3L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]T>7!E0V%C:&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@;65T:&]D)W,@<VEG;F%T=7)E+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&9U;&P@;F%M92!O9B!T:&4@;65T
M:&]D('1O(&-H96-K(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!!('1W;R!D:6UE;G-I;VYA;"!A<G)A>2X@5&AE(&9I<G-T(&5L96UE;G0@
M8V]N=&%I;G,@86X*("`@("`J("`@("`@("`@("`@("`@(&%R<F%Y('=I=&@@
M=&AE('!A<F%M971E<B!N86UE<RP@=&AE('-E8V]N9"!O;F4@=&AE(')E='5R
M;@H@("`@("H@("`@("`@("`@("`@("`@='EP92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4VEG;F%T=7)E*"1M971H;V0I"B`@("!["B`@("`@("`@:68@
M*"$H)&%P<"`]("1T:&ES+3YH87--971H;V0H)&UE=&AO9"DI*2!["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9FEL
M;$%024-A8VAE*"D["@H@("`@("`@($!L:7-T*"P@)&9U;F-T:6]N*2`](&5X
M<&QO9&4H)R\G+"`D;65T:&]D*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]A<&E#86-H95LD87!P75LD9G5N8W1I;VY=6R=T>7!E)UTI("8F"B`@("`@
M("`@("`@(&ES<V5T*"1T:&ES+3Y?87!I0V%C:&5;)&%P<%U;)&9U;F-T:6]N
M75LG87)G<R==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)'1H:7,M
M/E]A<&E#86-H95LD87!P75LD9G5N8W1I;VY=6R=A<F=S)UTL("1T:&ES+3Y?
M87!I0V%C:&5;)&%P<%U;)&9U;F-T:6]N75LG='EP92==*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@86X@:6YT97)F
M86-E(&ES(&EM<&QE;65N=&5D(&)Y(&%N(&%C=&EV92!A<'!L:6-A=&EO;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I;G1E<F9A8V4@(%1H92!I
M;G1E<F9A8V4@=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!A<'!L:6-A=&EO;B!I;7!L96UE;G1I;F<@)&EN=&5R9F%C
M92!I9B!W92!H879E(&ET+`H@("`@("H@("`@("`@("`@("`@("`@9F%L<V4@
M:68@=&AE(&EN=&5R9F%C92!I<R!N;W0@:6UP;&5M96YT960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&AA<TEN=&5R9F%C92@D:6YT97)F86-E*0H@("`@>PH@
M("`@("`@(')E='5R;B`A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E
M<F9A8V5=*2`_"B`@("`@("`@("`@("1T:&ES+3Y?:6YT97)F86-E<ULD:6YT
M97)F86-E72`Z"B`@("`@("`@("`@(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5T97)M:6YE(&EF(&$@;65T:&]D(&AA<R!B965N(')E9VES=&5R
M960@=VET:"!T:&4@<F5G:7-T<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;65T:&]D("!4:&4@9G5L;"!N86UE(&]F('1H92!M971H;V0@=&\@
M8VAE8VL@9F]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("!/;FQY
M(&-H96-K('1H:7,@87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&%P<&QI8V%T:6]N(&EM<&QE;65N=&EN9R`D;65T:&]D
M(&EF('=E(&AA=F4@:70L"B`@("`@*B`@("`@("`@("`@("`@("!F86QS92!I
M9B!T:&4@;65T:&]D(&1O97-N)W0@97AI<W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AA<TUE=&AO9"@D;65T:&]D+"`D87!P(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D87!P*2D@>PH@("`@("`@("`@("!`;&ES="@D
M:6YT97)F86-E+"`D8V%L;"D@/2!E>'!L;V1E*"<O)RP@)&UE=&AO9"D["B`@
M("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H
M;V1=*2D@>PH@("`@("`@("`@("`@("`@)&%P<"`]("1T:&ES+3Y?:6YT97)F
M86-E<ULD;65T:&]D73L*("`@("`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D
M=&AI<RT^7VEN=&5R9F%C97-;)&EN=&5R9F%C95TI*2!["B`@("`@("`@("`@
M("`@("`D87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&-A;&P@/2`D;65T:&]D.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]F:6QL05!)0V%C:&4H*3L*"B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI
M<RT^7V%P:4-A8VAE6R1A<'!=6R1C86QL72D@/R`D87!P(#H@9F%L<V4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&AO;VL@8V]R<F5S<&]N
M9&EN9R!T;R!T:&4@9&5F875L="!P86-K86=E('1H870*("`@("`J('!R;W9I
M9&5S('1H92!F=6YC=&EO;F%L:71Y(')E<75E<W1E9"!B>2!T:&4@)&UE=&AO
M9`H@("`@("H@<&%R86UE=&5R+B`D;65T:&]D(&ES(&$@<W1R:6YG(&-O;G-I
M<W1I;F<@;V8*("`@("`J(")P86-K86=E='EP92]M971H;V1N86UE(BX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@(%1H92!M971H;V0@
M=&\@8V%L;"X*("`@("`J($!P87)A;2!A<G)A>2`D87)G<R`@("`@07)G=6UE
M;G1S('1O('1H92!M971H;V0N"B`@("`@*@H@("`@("H@0')E='5R;B`@5$]$
M3PH@("`@("H@("`@("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86QL*"1M971H;V0L("1A<F=S(#T@
M87)R87DH*2D*("`@('L*("`@("`@("!`;&ES="@D:6YT97)F86-E+"`D8V%L
M;"D@/2!E>'!L;V1E*"<O)RP@)&UE=&AO9"D["@H@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=*2D@>PH@("`@("`@("`@
M("`D87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=.PH@("`@("`@
M('T@96QS96EF("@A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A
M8V5=*2D@>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S
M6R1I;G1E<F9A8V5=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=4:&4@;65T:&]D("(G("X@)&UE=&AO
M9"`N("<B(&ES(&YO="!D969I;F5D(&EN('1H92!(;W)D92!296=I<W1R>2XG
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^8V%L;$)Y4&%C
M:V%G92@D87!P+"`D8V%L;"P@)&%R9W,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@3W5T<'5T('1H92!H;V]K(&-O<G)E<W!O;F1I;F<@=&\@=&AE('-P96-I
M9FEC('!A8VMA9V4@;F%M960N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D87!P("`@5&AE(&%P<&QI8V%T:6]N(&)E:6YG(&-A;&QE9"X*("`@("`J
M($!P87)A;2!S=')I;F<@)&-A;&P@(%1H92!M971H;V0@=&\@8V%L;"X*("`@
M("`J($!P87)A;2!A<G)A>2`D87)G<R`@($%R9W5M96YT<R!T;R!T:&4@;65T
M:&]D+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@("`@
M("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V%L;$)Y4&%C:V%G92@D87!P+"`D8V%L;"P@)&%R9W,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("\J($YO=&4Z(&-A;&QI;F<@:&%S365T
M:&]D*"D@;6%K97,@<W5R92!T:&%T('=E)W9E(&-A8VAE9`H@("`@("`@("`J
M("1A<'`G<R!S97)V:6-E<R!A;F0@:6YC;'5D960@=&AE($%022!F:6QE+"!S
M;R!W92!D;VXG="!T<GD*("`@("`@("`@*B!T;R!D;R!I="!A9V%I;B!E>'!L
M:6-I=&QY(&EN('1H:7,@;65T:&]D+B`J+PH@("`@("`@(&EF("@A)'1H:7,M
M/FAA<TUE=&AO9"@D8V%L;"P@)&%P<"DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@G5&AE(&UE=&AO9"`B)7,B(&ES
M(&YO="!D969I;F5D(&EN('1H92!!4$D@9F]R("5S+B<L("1C86QL+"`D87!P
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D('1H92!!4$D@;F]W+B`J
M+PH@("`@("`@(&EF("@A96UP='DH)%]315-324].6R=?<F5G:7-T<GEC86-H
M92==6R=?87!I0V%C:&4G72DI('L*("`@("`@("`@("`@)&%P:2`]("1T:&ES
M+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]A<&DN<&AP)SL*("`@
M("`@("`@("`@:68@*&ES7W)E861A8FQE*"1A<&DI*2!["B`@("`@("`@("`@
M("`@("!I;F-L=61E7V]N8V4@)&%P:3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&9U;F-T:6]N(&%C
M='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("`D9G5N8W1I;VX@/2`G7R<@+B`D
M87!P("X@)U\G("X@)&-A;&P["B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES
M=',H)&9U;F-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G5&AE(&9U;F-T:6]N(&EM<&QE;65N=&EN9R`G("X@)&-A;&P@
M+B`G("@G("X@)&9U;F-T:6]N("X@)RD@:7,@;F]T(&1E9FEN960@:6X@)R`N
M("1A<'`@+B`G7"=S($%022XG*3L*("`@("`@("!]"@H@("`@("`@("1C:&5C
M:U!E<FUS(#T@:7-S970H)'1H:7,M/E]A<&E#86-H95LD87!P75LD8V%L;%U;
M)V-H96-K<&5R;7,G72D@/PH@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A<&E#86-H95LD87!P75LD8V%L;%U;)V-H96-K<&5R;7,G72`Z('1R=64[
M"@H@("`@("`@("\J(%-W:71C:"!A<'!L:6-A=&EO;B!C;VYT97AT<R!N;W<L
M(&EF(&YE8V5S<V%R>2P@8F5F;W)E"B`@("`@("`@("H@:6YC;'5D:6YG(&%N
M>2!F:6QE<R!W:&EC:"!M:6=H="!D;R!I="!F;W(@=7,N(%)E='5R;B!A;@H@
M("`@("`@("`J(&5R<F]R(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL
M<RX@*B\*("`@("`@("`D<'5S:&5D(#T@)'1H:7,M/G!U<VA!<'`H)&%P<"P@
M)&-H96-K4&5R;7,I.PH@("`@("`@(&EF("AI<U]A*"1P=7-H960L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1P=7-H960["B`@("`@
M("`@?0H*("`@("`@("`D<F5S(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH)&9U
M;F-T:6]N+"`D87)G<RD["@H@("`@("`@("\J($EF('=E(&-H86YG960@87!P
M;&EC871I;VX@8V]N=&5X="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*("`@("`@
M("`@*B!C86QL+"!U;F1O('1H870@8VAA;F=E(&YO=RX@*B\*("`@("`@("!I
M9B`H)'!U<VAE9"`]/3T@=')U92D@>PH@("`@("`@("`@("`D=&AI<RT^<&]P
M07!P*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@:&]O:R!C;W)R97-P;VYD:6YG
M('1O('1H92!D969A=6QT('!A8VMA9V4@=&AA=`H@("`@("H@<')O=FED97,@
M=&AE(&9U;F-T:6]N86QI='D@<F5Q=65S=&5D(&)Y('1H92`D;65T:&]D"B`@
M("`@*B!P87)A;65T97(N("1M971H;V0@:7,@82!S=')I;F<@8V]N<VES=&EN
M9R!O9@H@("`@("H@(G!A8VMA9V5T>7!E+VUE=&AO9&YA;64B+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&UE=&AO9"!T;R!L
M:6YK('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@("!!<F=U;65N
M=',@=&\@=&AE(&UE=&AO9"X*("`@("`J($!P87)A;2!M:7AE9"`D97AT<F$@
M("`@17AT<F$L(&YO;BUS=&%N9&%R9"!A<F=U;65N=',@=&\@=&AE(&UE=&AO
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N("!43T1/"B`@("`@*B`@("`@("`@
M("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QI;FLH)&UE=&AO9"P@)&%R9W,@/2!A<G)A>2@I+"`D97AT<F$@
M/2`G)RD*("`@('L*("`@("`@("!`;&ES="@D:6YT97)F86-E+"`D8V%L;"D@
M/2!E>'!L;V1E*"<O)RP@)&UE=&AO9"D["@H@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=*2D@>PH@("`@("`@("`@("`D
M87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1M971H;V1=.PH@("`@("`@('T@
M96QS96EF("@A96UP='DH)'1H:7,M/E]I;G1E<F9A8V5S6R1I;G1E<F9A8V5=
M*2D@>PH@("`@("`@("`@("`D87!P(#T@)'1H:7,M/E]I;G1E<F9A8V5S6R1I
M;G1E<F9A8V5=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=4:&4@;65T:&]D("(G("X@)&UE=&AO9"`N
M("<B(&ES(&YO="!D969I;F5D(&EN('1H92!(;W)D92!296=I<W1R>2XG*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^;&EN:T)Y4&%C:V%G
M92@D87!P+"`D8V%L;"P@)&%R9W,L("1E>'1R82D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!/=71P=70@=&AE(&AO;VL@8V]R<F5S<&]N9&EN9R!T;R!T:&4@
M<W!E8VEF:6,@<&%C:V%G92!N86UE9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A<'`@("!4:&4@87!P;&EC871I;VX@8F5I;F<@8V%L;&5D+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8V%L;"`@5&AE(&UE=&AO9"!T;R!L:6YK
M('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@07)G=6UE;G1S('1O
M('1H92!M971H;V0N"B`@("`@*B!`<&%R86T@;6EX960@)&5X=')A("!%>'1R
M82P@;F]N+7-T86YD87)D(&%R9W5M96YT<R!T;R!T:&4@;65T:&]D+@H@("`@
M("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@("`@("`@(%)E='5R
M;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&EN:T)Y4&%C:V%G92@D87!P+"`D8V%L;"P@)&%R9W,@/2!A<G)A>2@I+"`D
M97AT<F$@/2`G)RD*("`@('L*("`@("`@("`O*B!.;W1E.B!C86QL:6YG(&AA
M<TUE=&AO9"!M86ME<R!S=7)E('1H870@=V4G=F4@8V%C:&5D("1A<'`G<PH@
M("`@("`@("`J('-E<G9I8V5S(&%N9"!I;F-L=61E9"!T:&4@05!)(&9I;&4L
M('-O('=E(&1O;B=T('1R>2!T;R!D;PH@("`@("`@("`J(&ET(&ET(&%G86EN
M(&5X<&QI8VET;'D@:6X@=&AI<R!M971H;V0N("HO"B`@("`@("`@:68@*"$D
M=&AI<RT^:&%S365T:&]D*"1C86QL+"`D87!P*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5&AE(&UE=&AO9"`B)R`N("1C86QL
M("X@)R(@:7,@;F]T(&1E9FEN960@:6X@)R`N("1A<'`@+B`G7"=S($%022XG
M*3L*("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!T:&4@;&EN:R!I
M<R!D969I;F5D+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V%P:4-A
M8VAE6R1A<'!=6R1C86QL75LG;&EN:R==*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5&AE(&QI;FL@)R`N("1C86QL("X@)R!I
M<R!N;W0@9&5F:6YE9"!I;B`G("X@)&%P<"`N("=<)W,@05!)+B<I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@26YI=&EA;"!L:6YK('9A;'5E+B`J+PH@("`@
M("`@("1L:6YK(#T@)'1H:7,M/E]A<&E#86-H95LD87!P75LD8V%L;%U;)VQI
M;FLG73L*"B`@("`@("`@+RH@1FEL;"!I;B!H=&UL+65N8V]D960@87)G=6UE
M;G1S+B`J+PH@("`@("`@(&9O<F5A8V@@*"1A<F=S(&%S("1K97D@/3X@)'9A
M;"D@>PH@("`@("`@("`@("`D;&EN:R`]('-T<E]R97!L86-E*"<E)R`N("1K
M97D@+B`G)2<L(&AT;6QE;G1I=&EE<R@D=F%L*2P@)&QI;FLI.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P
M75LG=V5B<F]O="==*2D@>PH@("`@("`@("`@("`D;&EN:R`]('-T<E]R97!L
M86-E*"<E87!P;&EC871I;VXE)RP@)'1H:7,M/F=E="@G=V5B<F]O="<L("1A
M<'`I+"`D;&EN:RD["B`@("`@("`@?0H*("`@("`@("`O*B!297!L86-E(&AT
M;6QE;F-O9&5D(&%R9W5M96YT<R!T:&%T(&AA=F5N)W0@8F5E;B!S<&5C:69I
M960@=VET:`H@("`@("`@("`@(&%N(&5M<'1Y('-T<FEN9R`H=&AI<R!I<R!W
M:&5R92!T:&4@9&5F875L="!W;W5L9"!B92!S=6)S=&ET=71E9`H@("`@("`@
M("`@(&EN(&$@<W1R:6-T97(@<F5G:7-T<GD@:6UP;&5M96YT871I;VXI+B`J
M+PH@("`@("`@("1L:6YK(#T@<')E9U]R97!L86-E*"=\)2XK)7Q5)RP@)R<L
M("1L:6YK*3L*"B`@("`@("`@+RH@1FEL;"!I;B!U<FQE;F-O9&5D(&%R9W5M
M96YT<RX@*B\*("`@("`@("!F;W)E86-H("@D87)G<R!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@)&QI;FL@/2!S=')?<F5P;&%C92@G?"<@+B!3
M=')I;F<Z.FQO=V5R*"1K97DI("X@)WPG+"!U<FQE;F-O9&4H)'9A;"DL("1L
M:6YK*3L*("`@("`@("!]"@H@("`@("`@("\J($%P<&5N9"!A;GD@97AT<F$L
M(&YO;BUS=&%N9&%R9"!A<F=U;65N=',N("HO"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1E>'1R82DI('L*("`@("`@("`@("`@)&5X=')A7V%R9W,@/2`G)SL*
M("`@("`@("`@("`@9F]R96%C:"`H)&5X=')A(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@)&5X=')A7V%R9W,@+BT@)R8G("X@=7)L96YC
M;V1E*"1K97DI("X@)STG("X@=7)L96YC;V1E*"1V86PI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5X=')A7V%R9W,@
M/2`D97AT<F$["B`@("`@("`@?0H@("`@("`@("1L:6YK(#T@<W1R7W)E<&QA
M8V4H)WQE>'1R87PG+"`D97AT<F%?87)G<RP@)&QI;FLI.PH*("`@("`@("`O
M*B!297!L86-E(&AT;6PM96YC;V1E9"!A<F=U;65N=',@=&AA="!H879E;B=T
M(&)E96X@<W!E8VEF:65D('=I=&@*("`@("`@("`@("!A;B!E;7!T>2!S=')I
M;F<@*'1H:7,@:7,@=VAE<F4@=&AE(&1E9F%U;'0@=V]U;&0@8F4@<W5B<W1I
M='5T960*("`@("`@("`@("!I;B!A('-T<FEC=&5R(')E9VES=')Y(&EM<&QE
M;65N=&%T:6]N*2X@*B\*("`@("`@("`D;&EN:R`]('!R96=?<F5P;&%C92@G
M?%Q\+BM<?'Q5)RP@)R<L("1L:6YK*3L*"B`@("`@("`@<F5T=7)N("1L:6YK
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C92!A;GD@)6%P<&QI8V%T
M:6]N)2!S=')I;F=S('=I=&@@=&AE(&9I;&5S>7-T96T@<&%T:"!T;R!T:&4*
M("`@("`J(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A=&@@(%1H92!A<'!L:6-A=&EO;B!S=')I;F<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A<'`@("!4:&4@87!P;&EC871I;VX@8F5I;F<@8V%L;&5D
M+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@("`J("`@("`@("`@
M(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@87!P;&EC871I;VY&:6QE4&%T:"@D<&%T:"P@)&%P<"`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&%P<"DI('L*("`@("`@("`@
M("`@)&%P<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P72DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E9VES
M=')Y+B(I+"`D87!P*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<W1R
M7W)E<&QA8V4H)R5A<'!L:6-A=&EO;B4G+"`D=&AI<RT^87!P;&EC871I;VYS
M6R1A<'!=6R=F:6QE<F]O="==+"`D<&%T:"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!297!L86-E(&%N>2`E87!P;&EC871I;VXE('-T<FEN9W,@=VET:"!T
M:&4@=V5B('!A=&@@=&\@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!A<'!L:6-A=&EO;B!S=')I;F<N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("!4:&4@87!P;&EC871I;VX@
M8F5I;F<@8V%L;&5D+@H@("`@("H*("`@("`J($!R971U<FX@(%1/1$\*("`@
M("`J("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@87!P;&EC871I;VY796)0871H*"1P871H+"`D
M87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1A<'`I*2![
M"B`@("`@("`@("`@("1A<'`@/2`D=&AI<RT^7V-U<G)E;G1!<'`["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H)R5A<'!L:6-A=&EO
M;B4G+"`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=W96)R;V]T)UTL("1P
M871H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@8W5R<F5N="!A
M<'!L:6-A=&EO;BP@861D:6YG(&ET('1O('1H92!T;W`@;V8@=&AE($AO<F1E
M"B`@("`@*B!A<'!L:6-A=&EO;B!S=&%C:RX@268@=&AI<R!I<R!T:&4@9FER
M<W0@87!P;&EC871I;VX@=&\@8F4*("`@("`J('!U<VAE9"P@<F5T<FEE=F4@
M<V5S<VEO;B!I;F9O<FUA=&EO;B!A<R!W96QL+@H@("`@("H*("`@("`J('!U
M<VA!<'`H*2!A;'-O(')E861S('1H92!A<'!L:6-A=&EO;B=S(&-O;F9I9W5R
M871I;VX@9FEL92!A;F0*("`@("`J('-E=',@=7`@:71S(&=L;V)A;"`D8V]N
M9B!H87-H+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1A<'`@("`@
M("`@("!4:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VX@=&\@<'5S:"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1C:&5C:U!E<FUS("!-86ME('-U<F4@=&AA
M="!T:&4@8W5R<F5N="!U<V5R(&AA<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('!E<FUI<W-I;VYS('1O('1H92!A<'!L:6-A=&EO;B!B
M96EN9R!L;V%D960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!$969A=6QT<R!T;R!T<G5E+B!3:&]U;&0@3TY,62!B92!D:7-A8FQE9"!B
M>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-Y<W1E;2!S
M8W)I<'1S("AC<F]N(&IO8G,L(&5T8RXI(&%N9"!S8W)I<'1S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AA="!H86YD;&4@;&]G:6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO
M="!T:&4@7V%P<%-T86-K('=A<R!M;V1I9FEE9"X*("`@("`J("`@("`@("`@
M("`@("`@("`@4F5T=7)N(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!U<VA!<'`H)&%P<"P@)&-H96-K4&5R;7,@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("@D87!P(#T]("1T:&ES+3Y?8W5R<F5N=$%P
M<"D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!"86EL(&]U="!I9B!A<'!L:6-A=&EO;B!I<R!N;W0@<')E<V5N
M="!O<B!I;F%C=&EV92X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YA
M<'!L:6-A=&EO;G-;)&%P<%TI('Q\"B`@("`@("`@("`@("1T:&ES+3YA<'!L
M:6-A=&EO;G-;)&%P<%U;)W-T871U<R==(#T]("=I;F%C=&EV92<@?'P*("`@
M("`@("`@("`@*"1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P<%U;)W-T871U<R==
M(#T]("=A9&UI;B<@)B8@(4%U=&@Z.FES061M:6XH*2DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*"1A<'`@+B`G(&ES(&YO="!A8W1I=F%T960G+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@
M<&5R;6ES<VEO;G,@8VAE8VMI;F<@:7,@<F5Q=65S=&5D+"!R971U<FX@86X@
M97)R;W(@:68*("`@("`@("`@*B!T:&4@8W5R<F5N="!U<V5R(&1O97,@;F]T
M(&AA=F4@<F5A9"!P97)M<R!T;R!T:&4*("`@("`@("`@*B!A<'!L:6-A=&EO
M;B!B96EN9R!L;V%D960N(%=E(&%L;&]W(&%C8V5S<SH*("`@("`@("`@*@H@
M("`@("`@("`J("`M(%1O(&%L;"!A9&UI;G,N"B`@("`@("`@("H@("T@5&\@
M86QL(&%U=&AE;G1I8V%T960@=7-E<G,@:68@;F\@<&5R;6ES<VEO;B!I<R!S
M970@;VX@)&%P<"X*("`@("`@("`@*B`@+2!4;R!A;GEO;F4@=VAO(&ES(&%L
M;&]W960@8GD@86X@97AP;&EC:70@04-,(&]N("1A<'`N("HO"B`@("`@("`@
M:68@*"1C:&5C:U!E<FUS("8F("$D=&AI<RT^:&%S4&5R;6ES<VEO;B@D87!P
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=5
M<V5R("5S(&1O97,@;F]T(&AA=F4@4D5!1"!P97)M:7-S:6]N(&9O<B`E<R<L
M($%U=&@Z.F=E=$%U=&@H*2P@)&%P<"DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(E5S97(@)7,@:7,@;F]T(&%U=&AO<FES960@
M9F]R("5S+B(I+"!!=71H.CIG971!=71H*"DL("1T:&ES+3YA<'!L:6-A=&EO
M;G-;)&%P<%U;)VYA;64G72DL("=P97)M:7-S:6]N7V1E;FEE9"<I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@26UP;W)T('1H:7,@87!P;&EC871I;VXG<R!C
M;VYF:6=U<F%T:6]N('9A;'5E<RX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T
M:&ES+3YI;7!O<G1#;VYF:6<H)&%P<"D["B`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1S
M=6-C97-S.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A9"!P<F5F97)E;F-E
M<R!A9G1E<B!T:&4@8V]N9FEG=7)A=&EO;B!H87,@8F5E;B!L;V%D960@=&\*
M("`@("`@("`@*B!M86ME('-U<F4@=&AE('!R969S(&9I;&4@:&%S(&%L;"!T
M:&4@:6YF;W)M871I;VX@:70@;F5E9',N("HO"B`@("`@("`@)'1H:7,M/FQO
M8610<F5F<R@D87!P*3L*"B`@("`@("`@+RH@4F5S970@=&AE(&QA;F=U86=E
M(&EN(&-A<V4@=&AE<F4@:7,@82!D:69F97)E;G0@;VYE"B`@("`@("`@("H@
M<V5L96-T960@:6X@=&AE('!R969E<F5N8V5S+B`J+PH@("`@("`@("1L86YG
M=6%G92`]("<G.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!R969S0V%C
M:&5;)&%P<%TI("8F"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?<')E9G-#
M86-H95LD87!P72T^7W!R969S6R=L86YG=6%G92==*2D@>PH@("`@("`@("`@
M("`D;&%N9W5A9V4@/2`D=&AI<RT^7W!R969S0V%C:&5;)&%P<%TM/F=E=%9A
M;'5E*"=L86YG=6%G92<I.PH@("`@("`@('T*("`@("`@("!.3%,Z.G-E=$QA
M;F<H)&QA;F=U86=E*3L*("`@("`@("!.3%,Z.G-E=%1E>'1D;VUA:6XH)&%P
M<"P@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG9FEL97)O;W0G72`N("<O
M;&]C86QE)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@(%-T<FEN9SHZ
M<V5T1&5F875L=$-H87)S970H3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@
M("`O*B!/;F-E('=E(&MN;W<@979E<GET:&EN9R!S=6-C965D960@86YD(&ES
M(&EN(&$@8V]N<VES=&5N=`H@("`@("`@("`J('-T871E(&%G86EN+"!P=7-H
M('1H92!N97<@87!P;&EC871I;VX@;VYT;R!T:&4@<W1A8VLN("HO"B`@("`@
M("`@)'1H:7,M/E]A<'!3=&%C:UM=(#T@)&%P<#L*("`@("`@("`D=&AI<RT^
M7V-U<G)E;G1!<'`@/2`D87!P.PH*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!T:&4@8W5R<F5N="!A<'`@9G)O
M;2!T:&4@87!P;&EC871I;VX@<W1A8VLL('-E='1I;F<@=&AE(&-U<G)E;G0*
M("`@("`J(&%P<"!T;R!W:&EC:&5V97(@87!P('=A<R!C=7)R96YT(&)E9F]R
M92!T:&ES(&]N92!T;V]K(&]V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!N86UE(&]F('1H92!A<'!L:6-A=&EO;B!T:&%T('=A<R!P
M;W!P960N"B`@("`@*B\*("`@(&9U;F-T:6]N('!O<$%P<"@I"B`@("!["B`@
M("`@("`@+RH@4&]P('1H92!C=7)R96YT(&%P<&QI8V%T:6]N(&]F9B!O9B!T
M:&4@<W1A8VLN("HO"B`@("`@("`@)'!R979I;W5S(#T@87)R87E?<&]P*"1T
M:&ES+3Y?87!P4W1A8VLI.PH*("`@("`@("`O*B!);7!O<G0@=&AE(&YE=R!A
M8W1I=F4@87!P;&EC871I;VXG<R!C;VYF:6=U<F%T:6]N('9A;'5E<PH@("`@
M("`@("`J(&%N9"!S970@=&AE(&=E='1E>'0@9&]M86EN(&%N9"!T:&4@<')E
M9F5R<F5D(&QA;F=U86=E+B`J+PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=$%P
M<"`](&-O=6YT*"1T:&ES+3Y?87!P4W1A8VLI(#\@96YD*"1T:&ES+3Y?87!P
M4W1A8VLI(#H@;G5L;#L*("`@("`@("!I9B`H)'1H:7,M/E]C=7)R96YT07!P
M*2!["B`@("`@("`@("`@("1T:&ES+3YI;7!O<G1#;VYF:6<H)'1H:7,M/E]C
M=7)R96YT07!P*3L*("`@("`@("`@("`@)'1H:7,M/FQO8610<F5F<R@D=&AI
M<RT^7V-U<G)E;G1!<'`I.PH@("`@("`@("`@("`D;&%N9W5A9V4@/2`D1TQ/
M0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)VQA;F=U86=E)RD["B`@("`@("`@
M("`@(&EF("AI<W-E="@D;&%N9W5A9V4I*2!["B`@("`@("`@("`@("`@("!.
M3%,Z.G-E=$QA;F<H)&QA;F=U86=E*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!.3%,Z.G-E=%1E>'1D;VUA:6XH)'1H:7,M/E]C=7)R96YT07!P+"`D
M=&AI<RT^87!P;&EC871I;VYS6R1T:&ES+3Y?8W5R<F5N=$%P<%U;)V9I;&5R
M;V]T)UT@+B`G+VQO8V%L92<L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@
M("`@("`@4W1R:6YG.CIS971$969A=6QT0VAA<G-E="A.3%,Z.F=E=$-H87)S
M970H*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!R979I;W5S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!C=7)R96YT(&%P<&QI
M8V%T:6]N("T@=&AE(&%P<"!A="!T:&4@=&]P(&]F('1H92!A<'!L:6-A=&EO
M;@H@("`@("H@<W1A8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C=7)R96YT(&%P<&QI8V%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971!<'`H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-U<G)E
M;G1!<'`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!P97)M:7-S:6]N
M<R!O;B!A;B!A<'!L:6-A=&EO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%=H971H97(@;W(@;F]T(&%C8V5S<R!I<R!A;&QO=V5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1A<'`L("1P97)M:7-S
M:6]N(#T@4$5235-?4D5!1"D*("`@('L*("`@("`@("!R971U<FX@075T:#HZ
M:7-!9&UI;B@I('Q\"B`@("`@("`@("`@("@D1TQ/0D%,4ULG<&5R;7,G72T^
M97AI<W1S*"1A<'`I"B`@("`@("`@("`@("`_("1'3$]"04Q36R=P97)M<R==
M+3YH87-097)M:7-S:6]N*"1A<'`L($%U=&@Z.F=E=$%U=&@H*2P@)'!E<FUI
M<W-I;VXI"B`@("`@("`@("`@("`Z("AB;V]L*4%U=&@Z.F=E=$%U=&@H*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!T:&4@8V]N9FEG=7)A=&EO
M;B!V86QU97,@9F]R('1H92!G:79E;B!A<'!L:6-A=&EO;B!A;F0@:6UP;W)T
M<PH@("`@("H@=&AE;2!I;G1O('1H92!G;&]B86P@)&-O;F8@=F%R:6%B;&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@;F%M92!O
M9B!T:&4@87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&EM<&]R=$-O;F9I9R@D87!P*0H@("`@>PH@
M("`@("`@("\J($1O;B=T(&UA:V4@8V]N9FEG(&9I;&5S(&=L;V)A;"`D<F5G
M:7-T<GD@=&AE;7-E;'9E<RX@*B\*("`@("`@("!G;&]B86P@)')E9VES=')Y
M.PH*("`@("`@("`O*B!#86-H92!C;VYF:6<@=F%L=65S('-O('1H870@=V4@
M9&]N)W0@<F4M<F5A9"!F:6QE<R!O;B!E=F5R>0H@("`@("`@("`J('!O<$%P
M<"@I(&-A;&PN("HO"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-O;F9#
M86-H95LD87!P72DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V-O;F9#86-H95LG:&]R9&4G72DI('L*("`@("`@("`@("`@("`@("1C;VYF
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@
M("`@("`@("`@("`D<W5C8V5S<R`](&EN8VQU9&4@2$]21$5?0D%312`N("<O
M8V]N9FEG+V-O;F8N<&AP)SL*("`@("`@("`@("`@("`@("1E<G)O<G,@/2!O
M8E]G971?8V]N=&5N=',H*3L*("`@("`@("`@("`@("`@(&]B7V5N9%]C;&5A
M;B@I.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D97)R;W)S*2D@>PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&
M86EL960@=&\@:6UP;W)T($AO<F1E(&-O;F9I9W5R871I;VXZ("<@+B!S=')I
M<%]T86=S*"1E<G)O<G,I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM<&]R="!(;W)D
M92!C;VYF:6=U<F%T:6]N+B<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("\J($EN:71I86P@2&]R9&4M=VED92!S971T:6YG<RX@*B\*
M"B`@("`@("`@("`@("`@("`O*B!3970@=&AE(&5R<F]R(')E<&]R=&EN9R!L
M979E;"!I;B!A8V-O<F1A;F-E('=I=&@*("`@("`@("`@("`@("`@("`J('1H
M92!C;VYF:6<@<V5T=&EN9W,N("HO"B`@("`@("`@("`@("`@("!E<G)O<E]R
M97!O<G1I;F<H)&-O;F9;)V1E8G5G7VQE=F5L)UTI.PH*("`@("`@("`@("`@
M("`@("\J(%-E="!T:&4@;6%X:6UU;2!E>&5C=71I;VX@=&EM92!I;B!A8V-O
M<F1A;F-E('=I=&@*("`@("`@("`@("`@("`@("`J('1H92!C;VYF:6<@<V5T
M=&EN9W,N("HO"B`@("`@("`@("`@("`@("!`<V5T7W1I;65?;&EM:70H)&-O
M;F9;)VUA>%]E>&5C7W1I;64G72D["@H@("`@("`@("`@("`@("`@+RH@4V5T
M('1H92!U;6%S:R!A8V-O<F1I;F<@=&\@8V]N9FEG('-E='1I;F=S+B`J+PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=U;6%S:R==*2D@>PH@
M("`@("`@("`@("`@("`@("`@('5M87-K*"1C;VYF6R=U;6%S:R==*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1C;VYF(#T@)'1H:7,M/E]C;VYF0V%C:&5;)VAO<F1E)UT["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D87!P("$]/2`G:&]R9&4G
M*2!["B`@("`@("`@("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`@
M("`@)'-U8V-E<W,@/2!I;F-L=61E("1T:&ES+3YA<'!L:6-A=&EO;G-;)&%P
M<%U;)V9I;&5R;V]T)UT@+B`G+V-O;F9I9R]C;VYF+G!H<"<["B`@("`@("`@
M("`@("`@("`D97)R;W)S(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@
M("`@("`@("!O8E]E;F1?8VQE86XH*3L*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)&5R<F]R<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM<&]R="!A<'!L:6-A=&EO
M;B!C;VYF:6=U<F%T:6]N(&9O<B`G("X@)&%P<"`N("<Z("<@+B!S=')I<%]T
M86=S*"1E<G)O<G,I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&EM<&]R="!A<'!L:6-A
M=&EO;B!C;VYF:6=U<F%T:6]N(&9O<B`G("X@)&%P<"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?8V%C
M:&5687)S*&%R<F%Y*"=?8V]N9D-A8VAE)RDI.PH*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYF0V%C:&5;)&%P<%T@/2`F)&-O;F8["B`@("`@("`@?0H*("`@
M("`@("`D1TQ/0D%,4ULG8V]N9B==(#T@)B1T:&ES+3Y?8V]N9D-A8VAE6R1A
M<'!=.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@3&]A9',@=&AE('!R969E<F5N8V5S(&9O<B!T:&4@8W5R<F5N="!U<V5R
M(&9O<B!T:&4@8W5R<F5N="!A<'!L:6-A=&EO;@H@("`@("H@86YD(&EM<&]R
M=',@=&AE;2!I;G1O('1H92!G;&]B86P@)'!R969S('9A<FEA8FQE+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&%P<"`@5&AE(&YA;64@;V8@=&AE
M(&%P<&QI8V%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V%D4')E9G,H
M)&%P<"`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1P<F5F<U]D969A
M=6QT(#T@9F%L<V4["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4')E
M9G,N<&AP)SL*"B`@("`@("`@:68@*"1A<'`@/3T](&YU;&PI('L*("`@("`@
M("`@("`@)&%P<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@
M("`@("`@("\J($EF('1H97)E(&ES(&YO(&QO9V=E9"!I;B!U<V5R+"!R971U
M<FX@86X@96UP='D@4')E9G,Z.@H@("`@("`@("`J(&]B:F5C="!W:71H(&IU
M<W0@9&5F875L="!P<F5F97)E;F-E<RX@*B\*("`@("`@("!I9B`H(4%U=&@Z
M.F=E=$%U=&@H*2D@>PH@("`@("`@("`@("`D<')E9G,@/2`F4')E9G,Z.F9A
M8W1O<GDH)W-E<W-I;VXG+"`D87!P+"`G)RP@)R<L(&YU;&PL(&9A;'-E*3L*
M("`@("`@("`@("`@)'!R969S+3YR971R:65V92@I.PH@("`@("`@("`@("`D
M=&AI<RT^7W!R969S0V%C:&5;)&%P<%T@/2`F)'!R969S.PH@("`@("`@("`@
M("`D1TQ/0D%,4ULG<')E9G,G72`]("8D=&AI<RT^7W!R969S0V%C:&5;)&%P
M<%T["B`@("`@("`@("`@("1P<F5F<U]D969A=6QT(#T@=')U93L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@0V%C:&4@<')E
M9G,@;V)J96-T<R!S;R!T:&%T('=E(&1O;B=T(')E+6QO860@=&AE;2!O;B!E
M=F5R>0H@("`@("`@("`J('!O<$%P<"@I(&-A;&PN("HO"B`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!R969S0V%C:&5;)&%P<%TI('Q\"B`@("`@("`@
M("`@("%E;7!T>2@D<')E9G-?9&5F875L="DI('L*("`@("`@("`@("`@)'!R
M969S(#T@)E!R969S.CIF86-T;W)Y*"1'3$]"04Q36R=C;VYF)UU;)W!R969S
M)UU;)V1R:79E<B==+"`D87!P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@075T:#HZ9V5T075T:"@I+"!!=71H.CIG971#<F5D96YT
M:6%L*"=P87-S=V]R9"<I*3L*("`@("`@("`@("`@)'!R969S+3YR971R:65V
M92@I.PH@("`@("`@("`@("`D=&AI<RT^7W!R969S0V%C:&5;)&%P<%T@/2`F
M)'!R969S.PH@("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)W!R969S)UT@
M/2`F)'1H:7,M/E]P<F5F<T-A8VAE6R1A<'!=.PH@("`@?0H*("`@("\J*@H@
M("`@("H@56YL;V%D('!R969E<F5N8V5S(&9R;VT@86X@87!P;&EC871I;VX@
M;W(@*&EF(&YO(&%P<&QI8V%T:6]N(&ES"B`@("`@*B!S<&5C:69I960I(&9R
M;VT@04Q,(&%P<&QI8V%T:6]N<RX@57-E9G5L('=H96X@82!U<V5R(&AA<R!L
M;V=G960*("`@("`J(&]U="!B=70@>6]U(&YE960@=&\@8V]N=&EN=64@;VX@
M=&AE('-A;64@<&%G92P@971C+@H@("`@("H*("`@("`J($%F=&5R('5N;&]A
M9&EN9RP@:68@=&AE<F4@:7,@86X@87!P;&EC871I;VX@;VX@=&AE(&%P<"!S
M=&%C:R!T;PH@("`@("H@;&]A9"!P<F5F97)E;F-E<R!F<F]M+"!T:&5N('=E
M(')E;&]A9"!A(&9R97-H('-E="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U;FQO860@<')E9G)E;F-E
M<R!F;W(N($EF(&YU;&PL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@($%,
M3"!P<F5F97)E;F-E<R!A<F4@<F5S970N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('5N;&]A9%!R969S*"1A<'`@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@D
M87!P(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G-#86-H
M92`](&%R<F%Y*"D["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?
M<')E9G-#86-H95LD87!P72DI('L*("`@("`@("`@("`@=6YS970H)'1H:7,M
M/E]P<F5F<T-A8VAE6R1A<'!=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]C
M=7)R96YT07!P*2!["B`@("`@("`@("`@("1T:&ES+3YL;V%D4')E9G,H*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(')E
M<75E<W1E9"!C;VYF:6=U<F%T:6]N('!A<F%M971E<B!F;W(@=&AE('-P96-I
M9FEE9`H@("`@("H@87!P;&EC871I;VXN($EF(&YO(&%P<&QI8V%T:6]N(&ES
M('-P96-I9FEE9"P@=&AE('9A;'5E(&]F"B`@("`@*B`D=&AI<RT^7V-U<G)E
M;G1!<'`@*'1H92!C=7)R96YT(&%P<&QI8V%T:6]N*2!I<R!U<V5D+B!(;W=E
M=F5R+`H@("`@("H@:68@=&AE('!A<F%M971E<B!I<R!N;W0@<')E<V5N="!F
M;W(@=&AA="!A<'!L:6-A=&EO;BP@=&AE"B`@("`@*B!(;W)D92UW:61E('9A
M;'5E(&ES('5S960@:6YS=&5A9"X@268@=&AA="!I<R!N;W0@<')E<V5N="P@
M=V4*("`@("`J(')E='5R;B!N=6QL+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A<F%M971E<B`@5&AE(&-O;F9I9W5R871I;VX@=F%L=64@=&\@
M<F5T<FEE=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@(%1H
M92!A<'!L:6-A=&EO;B!T;R!G970@=&AE('9A;'5E(&9O<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E<75E<W1E9"!P87)A;65T97(L
M(&]R(&YU;&P@:68@:70@:7,@;F]T('-E="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T*"1P87)A;65T97(L("1A<'`@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]N=6QL*"1A<'`I*2!["B`@("`@("`@("`@("1A<'`@/2`D=&AI
M<RT^7V-U<G)E;G1!<'`["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LD<&%R86UE=&5R72DI('L*("`@
M("`@("`@("`@)'!V86P@/2`D=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R1P
M87)A;65T97)=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D
M<&%R86UE=&5R(#T]("=I8V]N)RD@>PH@("`@("`@("`@("`@("`@)'!V86P@
M/2`D=&AI<RT^7V=E=$EC;VXH)&%P<"D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<'9A;"`](&ES<V5T*"1T:&ES+3YA<'!L:6-A
M=&EO;G-;)VAO<F1E)UU;)'!A<F%M971E<ETI(#\@)'1H:7,M/F%P<&QI8V%T
M:6]N<ULG:&]R9&4G75LD<&%R86UE=&5R72`Z(&YU;&P["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@D<&%R86UE=&5R(#T]("=N86UE
M)RD@>PH@("`@("`@("`@("!R971U<FX@7R@D<'9A;"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1P=F%L.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O('=O<FL@;W5T(&%N(&%P
M<&QI8V%T:6]N)W,@9W)A<&AI8W,@55))+"!T86MI;F<@:6YT;R!A8V-O=6YT
M"B`@("`@*B!A;GD@=&AE;65S(&1I<F5C=&]R:65S('1H870@;6%Y(&)E('-E
M="!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A
M<'!L:6-A=&EO;B!F;W(@=VAI8V@@=&\@9V5T('1H92!I;6%G90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!D:7)E8W1O<GDN($EF(&)L86YK('=I;&P@
M9&5F875L="!T;R!C=7)R96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@:6UA9V4@9&ER96-T;W)Y('5R:2!P871H+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971);6%G941I<B@D87!P(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)&%P<"DI('L*("`@("`@("`@("`@)&%P<"`]("1T:&ES+3Y?
M8W5R<F5N=$%P<#L*("`@("`@("!]"@H@("`@("`@('-T871I8R`D:6UG7V1I
M<B`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1I;6=?9&ER6R1A<'!=
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&EM9U]D:7);)&%P<%T["B`@("`@
M("`@?0H*("`@("`@("`O*B!4:&ES(&ES('1H92!D969A=6QT(&QO8V%T:6]N
M(&9O<B!T:&4@9W)A<&AI8W,N("HO"B`@("`@("`@)&EM9U]D:7);)&%P<%T@
M/2`D=&AI<RT^9V5T*"=T:&5M97-U<FDG+"`D87!P*2`N("<O9W)A<&AI8W,G
M.PH*("`@("`@("!S=&%T:6,@)'1H96UE7VEC;VYS.PH*("`@("`@("`O*B!&
M:6=U<F4@;W5T(&EF('1H:7,@:7,@9V]I;F<@=&\@8F4@;W9E<G)I9&1E;B!B
M>2!A;GD@=&AE;64*("`@("`@("`@*B!S971T:6YG<RX@*B\*("`@("`@("!I
M9B`H:7-S970H)$=,3T)!3%-;)W!R969S)UTI("8F"B`@("`@("`@("`@("@D
M=&AE;64@/2`D1TQ/0D%,4ULG<')E9G,G72T^9V5T5F%L=64H)W1H96UE)RDI
M("8F"B`@("`@("`@("`@("AI<W-E="@D=&AE;65?:6-O;G,I('Q\"B`@("`@
M("`@("`@("`H*$!I;F-L=61E("1T:&ES+3YG970H)W1H96UE<V9S)RP@)VAO
M<F1E)RD@+B`G+R<@+B`D=&AE;64@+B`G+VEN9F\N<&AP)RD@)B8*("`@("`@
M("`@("`@("!I<W-E="@D=&AE;65?:6-O;G,I*2D@)B8*("`@("`@("`@("`@
M:6Y?87)R87DH)&%P<"P@)'1H96UE7VEC;VYS*2D@>PH@("`@("`@("`@("`D
M:6UG7V1I<ELD87!P72`]("1T:&ES+3YG970H)W1H96UE<W5R:2<L("1A<'`I
M("X@)R\G("X@)'1H96UE("X@)R]G<F%P:&EC<R<["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&EM9U]D:7);)&%P<%T["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!P871H('1O(&%N(&%P<&QI8V%T:6]N)W,@:6-O
M;BP@<F5S<&5C=&EN9R!W:&5T:&5R('1H90H@("`@("H@8W5R<F5N="!T:&5M
M92!H87,@:71S(&]W;B!I8V]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A
M<'!L:6-A=&EO;B!F;W(@=VAI8V@@=&\@9V5T('1H92!I8V]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5T26-O;B@D87!P*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T26UA9V5$:7(H)&%P<"D@+B`G+R<@+B`D87!P("X@
M)RYP;F<G.PH@("`@?0H*("`@("\J*@H@("`@("H@475E<GD@=&AE(&EN:71I
M86P@<&%G92!F;W(@86X@87!P;&EC871I;VX@+2!T:&4@=V5B<F]O="P@:68@
M=&AE<F4@:7,@;F\*("`@("`J(&EN:71I86Q?<&%G92!S970L(&%N9"!T:&4@
M:6YI=&EA;%]P86=E+"!I9B!I="!I<R!S970N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D87!P("!4:&4@;F%M92!O9B!T:&4@87!P;&EC871I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%523"!P;VEN=&EN9R!T
M;R!T:&4@:6YI=&%L('!A9V4@;V8@=&AE(&%P<&QI8V%T:6]N+@H@("`@("H@
M("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T26YI=&EA;%!A9V4H)&%P<"`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)&%P<"DI('L*("`@("`@
M("`@("`@)&%P<"`]("1T:&ES+3Y?8W5R<F5N=$%P<#L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P72DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")<(B5S7"(@:7,@;F]T(&-O;F9I9W5R960@:6X@=&AE($AO<F1E(%)E
M9VES=')Y+B(I+"`D87!P*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M=&AI<RT^87!P;&EC871I;VYS6R1A<'!=6R=W96)R;V]T)UT@+B`G+R<@+B`H
M:7-S970H)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG:6YI=&EA;%]P86=E
M)UTI(#\@)'1H:7,M/F%P<&QI8V%T:6]N<ULD87!P75LG:6YI=&EA;%]P86=E
M)UT@.B`G)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<VEN8V4@2&]R9&4@
M,RXQ"B`@("`@*B\*("`@(&9U;F-T:6]N(%]?9V5T*"1A<&DI"B`@("!["B`@
M("`@("`@:68@*&EN7V%R<F%Y*"1A<&DL("1T:&ES+3YL:7-T05!)<R@I*2D@
M>PH@("`@("`@("`@("!R971U<FX@;F5W(%)E9VES=')Y0V%L;&5R*"1T:&ES
M+"`D87!I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]N
M92!S:&]U;&0@;F5V97(@8F4@8V%L;&5D(&]N(%)E9VES=')Y(&]B:F5C=',N
M($EF(&ET(&ES+"!D:64N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N
M,0H@("`@("HO"B`@("!F=6YC=&EO;B!?7V-L;VYE*"D*("`@('L*("`@("`@
M("!(;W)D93HZ9F%T86PH)U)E9VES=')Y(&]B:F5C=',@<VAO=6QD(&YE=F5R
M(&)E(&-L;VYE9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*?0H*
M+RHJ"B`J($!P86-K86=E($AO<F1E7T9R86UE=V]R:PH@*B!`<VEN8V4@2&]R
M9&4@,RXQ"B`J+PIC;&%S<R!296=I<W1R>4-A;&QE<B!["@H@("`@=F%R("1R
M96=I<W1R>3L*("`@('9A<B`D87!I.PH*("`@(&9U;F-T:6]N(%]?8V]N<W1R
M=6-T*"1R96=I<W1R>2P@)&%P:2D*("`@('L*("`@("`@("`D=&AI<RT^<F5G
M:7-T<GD@/2`D<F5G:7-T<GD["B`@("`@("`@)'1H:7,M/F%P:2`]("1A<&D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7U]C86QL*"1M971H;V0L("1A<F=S*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F5G:7-T<GDM/F-A;&PH)'1H
M:7,M/F%P:2`N("<O)R`N("1M971H;V0L("1A<F=S*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S+G!H<```
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-3(W(#$P
M-3$U-#,T,30P(#`R,38U-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-O;7!R97-S
M.CH@8VQA<W,@<')O=FED97,@86X@05!)(&9O<B!V87)I;W5S(&-O;7!R97-S
M:6]N"B`J('1E8VAN:7%U97,@=&AA="!C86X@8F4@=7-E9"!B>2!(;W)D92!A
M<'!L:6-A=&EO;G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-O;7!R97-S
M+T-O;7!R97-S+G!H<"QV(#$N-RXQ,BXQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#
M;VUP<F5S<R!["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@
M82!C;VYC<F5T92!(;W)D95]#;VUP<F5S<R!I;G-T86YC92!B87-E9"!O;B`D
M9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4
M:&4@='EP92!O9B!C;VYC<F5T92!(;W)D95]#;VUP<F5S<R!S=6)C;&%S<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R
M:79E<B!I<R!A;B!A<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#;VUP<F5S
M<R\@9F]R('1H92!S=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&EM<&QE;65N=&%T:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E
M9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7T-O;7!R97-S("!4:&4@
M;F5W;'D@8W)E871E9"!C;VYC<F5T92!(;W)D95]#;VUP<F5S<PH@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@:6YS=&%N8V4L(&]R(&9A;'-E(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I
M=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@;&ES="@D87!P+"`D9')I
M=F5R*2`]("1D<FEV97(["B`@("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@
M8F%S96YA;64H)&1R:79E<BD["@H@("`@("`@(&EF("@A96UP='DH)&%P<"DI
M('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1A<'`@+B`G+VQI8B]#;VUP
M<F5S<R\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H
M0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]#;VUP<F5S<R\G
M("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#;VUP<F5S<R\G("X@)&1R:79E
M<B`N("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC
M;'5D95]O;F-E("=(;W)D92]#;VUP<F5S<R\G("X@)&1R:79E<B`N("<N<&AP
M)SL*("`@("`@("!]"@H@("`@("`@("1C;&%S<R`]("=(;W)D95]#;VUP<F5S
M<U\G("X@)&1R:79E<CL*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S
M<RDI('L*("`@("`@("`@("`@)&-O;7!R97-S(#T@)FYE=R`D8VQA<W,H)'!A
M<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;7!R97-S
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O;7!R97-S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@
M<F5F97)E;F-E('1O(&$@8V]N8W)E=&4@2&]R9&5?0V]M<')E<W,@:6YS=&%N
M8V4*("`@("`J(&)A<V5D(&]N("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A
M=&4@82!N97<@:6YS=&%N8V4@:68@;F\*("`@("`J($AO<F1E7T-O;7!R97-S
M(&EN<W1A;F-E('=I=&@@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R96YT;'D@
M97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV
M;VME9"!A<SH*("`@("`J("`@)'9A<B`]("9(;W)D95]#;VUP<F5S<SHZ<VEN
M9VQE=&]N*"D["B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@
M(%-E92!(;W)D95]#;VUP<F5S<SHZ9F%C=&]R>2@I+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@(%-E92!(;W)D95]#;VUP<F5S<SHZ9F%C=&]R>2@I
M+@H@("`@("H*("`@("`J($!R971U<FX@2&]R9&5?0V]M<')E<W,@(%1H92!C
M;VYC<F5T92!(;W)D95]#;VUP<F5S<R!R969E<F5N8V4L(&]R(&9A;'-E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!O;B!A;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`]
M(&%R<F%Y*"D["@H@("`@("`@("1S:6=N871U<F4@/2!M9#4H<V5R:6%L:7IE
M*&%R<F%Y*"1D<FEV97(L("1P87)A;7,I*2D["B`@("`@("`@:68@*"%I<W-E
M="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS
M=&%N8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7T-O;7!R97-S.CIF86-T;W)Y
M*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@4&%R86UE=&5R(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!(
M;W)D95]#;VUP<F5S<R@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;7!R97-S('1H92!D871A+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!C;VUP<F5S
M<RX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<G)A>2!O9B!A
M<F=U;65N=',@;F5E9&5D('1O(&-O;7!R97-S('1H92!D871A+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!C;VUP<F5S<V5D(&1A=&$N"B`@
M("`@*B`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUP<F5S<R@D9&%T
M82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D)RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$96-O;7!R97-S('1H92!D871A+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!D96-O;7!R97-S+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y(&]F(&%R9W5M
M96YT<R!N965D960@=&\@9&5C;VUP<F5S<R!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!D871A+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@(%1H92!D96-O;7!R97-S960@9&%T82X*("`@("`J("`@("`@("`@("`@
M("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1E8V]M<')E<W,H)&1A=&$L("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=5;G-U<'!O<G1E9"<I.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TY,4RYP:'``````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#0P,S8T(#$P-3$U-#,T,30Q(#`R,#4Q-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($Y,4SHZ(&-L87-S('!R;W9I9&5S($YA=&EV92!,86YG=6%G92!3=7!P
M;W)T+B!4:&ES(&EN8VQU9&5S(&-O;6UO;@H@*B!M971H;V1S(&9O<B!H86YD
M;&EN9R!L86YG=6%G92!D971E8W1I;VX@86YD('-E;&5C=&EO;BP@=&EM97IO
M;F5S+"!A;F0*("H@:&]S=&YA;64M/F-O=6YT<GD@;&]O:W5P<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO3DQ3+TY,4RYP:'`L=B`Q+C@R+C0N,3,@,C`P
M-B\P,2\R-"`P-SHU,#HR-B!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R
M9SX*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TY,4PH@*B\*8VQA<W,@3DQ3('L*"B`@("`O*BH*("`@("`J
M(%-E;&5C=',@=&AE(&UO<W0@<')E9F5R<F5D(&QA;F=U86=E(&9O<B!T:&4@
M8W5R<F5N="!C;&EE;G0@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('-E;&5C=&5D(&QA;F=U86=E(&%B8G)E=FEA=&EO;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5L96-T*"D*("`@('L*("`@("`@("!G
M;&]B86P@)&YL<RP@)'!R969S.PH*("`@("`@("`D;&%N9R`](%5T:6PZ.F=E
M=$9O<FU$871A*"=N97=?;&%N9R<I.PH*("`@("`@("`O*B!&:7)S="P@8VAE
M8VL@:68@;&%N9W5A9V4@<')E9B!I<R!L;V-K960@86YD+"!I9B!S;RP@<V5T
M(&ET('1O(&ET<PH@("`@("`@("`@('9A;'5E("HO"B`@("`@("`@:68@*&ES
M<V5T*"1P<F5F<RD@)B8@)'!R969S+3YI<TQO8VME9"@G;&%N9W5A9V4G*2D@
M>PH@("`@("`@("`@("`D;&%N9W5A9V4@/2`D<')E9G,M/F=E=%9A;'5E*"=L
M86YG=6%G92<I.PH@("`@("`@("\J($-H96-K(&EF('1H92!U<V5R('-E;&5C
M=&5D(&$@;&%N9W5A9V4@9G)O;2!T:&4@;&]G:6X@<V-R965N("HO"B`@("`@
M("`@?2!E;'-E:68@*"%E;7!T>2@D;&%N9RDI('L*("`@("`@("`@("`@)&QA
M;F=U86=E(#T@)&QA;F<["B`@("`@("`@+RH@0VAE8VL@:68@=V4@:&%V92!A
M(&QA;F=U86=E('-E="!I;B!A(&-O;VMI92`J+PH@("`@("`@('T@96QS96EF
M("AI<W-E="@D7U-%4U-)3TY;)VAO<F1E7VQA;F=U86=E)UTI*2!["B`@("`@
M("`@("`@("1L86YG=6%G92`]("1?4T534TE/3ELG:&]R9&5?;&%N9W5A9V4G
M73L*("`@("`@("`O*B!5<V4@<VET92UW:61E(&1E9F%U;'0L(&EF(&]N92!I
M<R!D969I;F5D("HO"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D;FQS6R=D
M969A=6QT<R==6R=L86YG=6%G92==*2D@>PH@("`@("`@("`@("`D;&%N9W5A
M9V4@/2`D;FQS6R=D969A=6QT<R==6R=L86YG=6%G92==.PH@("`@("`@("\J
M(%1R>2!B<F]W<V5R+6%C8V5P=&5D(&QA;F=U86=E<RX@*B\*("`@("`@("!]
M(&5L<V5I9B`H(65M<'1Y*"1?4T525D526R=(5%107T%#0T505%],04Y'54%'
M12==*2D@>PH@("`@("`@("`@("`O*B!4:&4@8G)O=W-E<B!S=7!P;&EE<R!A
M(&QI<W0L('-O(')E='5R;B!T:&4@9FER<W0@=F%L:60@;VYE+B`J+PH@("`@
M("`@("`@("`D8G)O=W-E<E]L86YG<R`](&5X<&QO9&4H)RPG+"`D7U-%4E9%
M4ELG2%144%]!0T-%4%1?3$%.1U5!1T4G72D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1B<F]W<V5R7VQA;F=S(&%S("1L86YG*2!["B`@("`@("`@("`@("`@
M("`O*B!3=')I<"!Q=6%L:71Y('9A;'5E(&9O<B!L86YG=6%G92`J+PH@("`@
M("`@("`@("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1L86YG+"`G.R<I*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D;&%N9R`]('-U8G-T
M<B@D;&%N9RP@,"P@)'!O<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D;&%N9R`]($Y,4SHZ7VUA<"AT<FEM*"1L86YG*2D["B`@("`@
M("`@("`@("`@("!I9B`H3DQ3.CII<U9A;&ED*"1L86YG*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1L86YG=6%G92`]("1L86YG.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@+RH@26X@8V%S92!N;R!F=6QL(&UA=&-H+"!S879E(&)E<W0@9W5E<W,@
M8F%S960@;VX@<')E9FEX("HO"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1P87)T:6%L7VQA;F<I("8F"B`@("`@("`@("`@("`@("`@("`@3DQ3.CII
M<U9A;&ED*$Y,4SHZ7VUA<"AS=6)S='(H)&QA;F<L(#`L(#(I*2DI('L*("`@
M("`@("`@("`@("`@("`@("`D<&%R=&EA;%]L86YG(#T@3DQ3.CI?;6%P*'-U
M8G-T<B@D;&%N9RP@,"P@,BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1L86YG=6%G
M92DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T:6%L7VQA;F<I*2![
M"B`@("`@("`@("`@("`@("`D;&%N9W5A9V4@/2`D<&%R=&EA;%]L86YG.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@3F\@9&EC
M92!A=71O+61E=&5C=&EN9RP@9&5F875L="!T;R!54R!%;F=L:7-H+B`J+PH@
M("`@("`@("`@("`@("`@)&QA;F=U86=E(#T@)V5N7U53)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&)A<V5N86UE*"1L86YG
M=6%G92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!L86YG=6%G
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86YG("!4:&4@;&%N
M9W5A9V4@86)B<F5V:6%T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,
M86YG*"1L86YG(#T@;G5L;"D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@
M2$]21$5?0D%312`N("<O8V]N9FEG+VYL<RYP:'`G.PH*("`@("`@("!I9B`H
M96UP='DH)&QA;F<I('Q\("%.3%,Z.FES5F%L:60H)&QA;F<I*2!["B`@("`@
M("`@("`@("1L86YG(#T@3DQ3.CIS96QE8W0H*3L*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG;&%N9W5A9V4G72DI('L*("`@("`@
M("`@("`@:68@*"1'3$]"04Q36R=L86YG=6%G92==(#T]("1L86YG*2!["B`@
M("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^8VQE87)#86-H
M92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D1TQ/0D%,
M4ULG;&%N9W5A9V4G72`]("1L86YG.PH@("`@("`@("1?4T534TE/3ELG:&]R
M9&5?;&%N9W5A9V4G72`]("1L86YG.PH*("`@("`@("`O*B!&:7)S="!T<GD@
M;&%N9W5A9V4@=VET:"!T:&4@8W5R<F5N="!C:&%R<V5T+B`J+PH@("`@("`@
M("1L86YG7V-H87)S970@/2`D;&%N9R`N("<N)R`N($Y,4SHZ9V5T0VAA<G-E
M="@I.PH@("`@("`@(&EF("@D;&%N9U]C:&%R<V5T("$]('-E=&QO8V%L92A,
M0U]!3$PL("1L86YG7V-H87)S970I*2!["B`@("`@("`@("`@("\J($YE>'0@
M=')Y(&QA;F=U86=E('=I=&@@:71S(&1E9F%U;'0@8VAA<G-E="X@*B\*("`@
M("`@("`@("`@9VQO8F%L("1N;',["B`@("`@("`@("`@("1C:&%R<V5T(#T@
M(65M<'1Y*"1N;'-;)V-H87)S971S)UU;)&QA;F==*2`_("1N;'-;)V-H87)S
M971S)UU;)&QA;F==(#H@)TE33RTX.#4Y+3$G.PH@("`@("`@("`@("`D;&%N
M9U]C:&%R<V5T(#T@)&QA;F<@+B`G+B<@+B`D8VAA<G-E=#L*("`@("`@("`@
M("`@3DQ3.CI?8V%C:&5D0VAA<G-E="@P+"`D8VAA<G-E="D["B`@("`@("`@
M("`@(&EF("@D;&%N9U]C:&%R<V5T("$]('-E=&QO8V%L92A,0U]!3$PL("1L
M86YG7V-H87)S970I*2!["B`@("`@("`@("`@("`@("`O*B!!="!L87-T('1R
M>2!L86YG=6%G92!S;VQE;'DN("HO"B`@("`@("`@("`@("`@("`D;&%N9U]C
M:&%R<V5T(#T@)&QA;F<["B`@("`@("`@("`@("`@("!S971L;V-A;&4H3$-?
M04Q,+"`D;&%N9U]C:&%R<V5T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!`<'5T96YV*"=,04Y'/2<@+B`D;&%N9U]C:&%R<V5T*3L*("`@
M("`@("!`<'5T96YV*"=,04Y'54%'13TG("X@)&QA;F=?8VAA<G-E="D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!G971T97AT(&1O;6%I;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@("`@("`@(%1H92!A
M<'!L:6-A=&EO;B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&ER96-T
M;W)Y("!4:&4@9&ER96-T;W)Y('=H97)E('1H92!A<'!L:6-A=&EO;B=S"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@($Q#7TU%4U-!1T53(&1I
M<F5C=&]R>2!R97-I9&5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E
M="`@("!4:&4@8VAA<G-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5&5X
M=&1O;6%I;B@D87!P+"`D9&ER96-T;W)Y+"`D8VAA<G-E="D*("`@('L*("`@
M("`@("!B:6YD=&5X=&1O;6%I;B@D87!P+"`D9&ER96-T;W)Y*3L*("`@("`@
M("!T97AT9&]M86EN*"1A<'`I.PH*("`@("`@("`O*B!4:&4@97AI<W1E;F-E
M(&]F('1H:7,@9G5N8W1I;VX@9&5P96YD<R!O;B!T:&4@<&QA=&9O<FTN("HO
M"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G8FEN9%]T97AT9&]M86EN
M7V-O9&5S970G*2D@>PH@("`@("`@("`@("!.3%,Z.E]C86-H961#:&%R<V5T
M*#`L(&)I;F1?=&5X=&1O;6%I;E]C;V1E<V5T*"1A<'`L("1C:&%R<V5T*2D[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(6AE861E<G-?<V5N="@I*2!["B`@
M("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+VAT;6P[(&-H
M87)S970])R`N("1C:&%R<V5T*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AE('-U<'!L:65D(&QA;F=U
M86=E(&ES('9A;&ED+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA
M;F=U86=E("!4:&4@86)B<F5V:6%T960@;F%M92!O9B!T:&4@;&%N9W5A9V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!L
M86YG=6%G92!I<R!V86QI9"P@9F%L<V4@:68@:70G<R!N;W0*("`@("`J("`@
M("`@("`@("`@("`@("`@=F%L:60@;W(@=6YK;F]W;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-686QI9"@D;&%N9W5A9V4I"B`@("!["B`@("`@("`@<F5T
M=7)N("%E;7!T>2@D1TQ/0D%,4ULG;FQS)UU;)VQA;F=U86=E<R==6R1L86YG
M=6%G95TI.PH@("`@?0H*("`@("\J*@H@("`@("H@36%P<R!L86YG=6%G97,@
M=VET:"!C;VUM;VX@='=O+6QE='1E<B!C;V1E<R`H<W5C:"!A<R!N;"D@=&\@
M=&AE"B`@("`@*B!F=6QL(&=E='1E>'0@8V]D92`H:6X@=&AI<R!C87-E+"!N
M;%].3"DN(%)E='5R;G,@=&AE(&QA;F=U86=E"B`@("`@*B!U;FUO9&EF:65D
M(&EF(&ET(&ES;B=T(&%N(&%L:6%S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&QA;F=U86=E
M("!4:&4@;&%N9W5A9V4@8V]D92!T;R!M87`N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!M87!P960@;&%N9W5A9V4@8V]D92X*("`@("`J
M+PH*("`@(&9U;F-T:6]N(%]M87`H)&QA;F=U86=E*0H@("`@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@H@("`@("`@("1A
M;&EA<V5S(#T@)B1'3$]"04Q36R=N;',G75LG86QI87-E<R==.PH*("`@("`@
M("`O+R!4<F%N<VQA=&4@=&AE("1L86YG=6%G92!T;R!G970@8G)O861E<B!M
M871C:&5S+@H@("`@("`@("\O("AE9RX@9&4M1$4@<VAO=6QD(&UA=&-H(&1E
M7T1%*0H@("`@("`@("1T<F%N<U]L86YG(#T@<W1R7W)E<&QA8V4H)RTG+"`G
M7R<L("1L86YG=6%G92D["B`@("`@("`@)&QA;F=?<&%R=',@/2!E>'!L;V1E
M*"=?)RP@)'1R86YS7VQA;F<I.PH@("`@("`@("1T<F%N<U]L86YG(#T@4W1R
M:6YG.CIL;W=E<B@D;&%N9U]P87)T<ULP72D["B`@("`@("`@:68@*&ES<V5T
M*"1L86YG7W!A<G1S6S%=*2D@>PH@("`@("`@("`@("`D=')A;G-?;&%N9R`N
M/2`G7R<@+B!3=')I;F<Z.G5P<&5R*"1L86YG7W!A<G1S6S%=*3L*("`@("`@
M("!]"@H@("`@("`@("\O(%-E92!I9B!W92!G970@82!M871C:"!F;W(@=&AI
M<PH@("`@("`@(&EF("@A96UP='DH)&%L:6%S97-;)'1R86YS7VQA;F==*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&%L:6%S97-;)'1R86YS7VQA;F==.PH@
M("`@("`@('T*"B`@("`@("`@+R\@268@=V4@9V5T('1H870@9F%R(&1O=VXL
M('1H92!L86YG=6%G92!C86YN;W0@8F4@9F]U;F0N"B`@("`@("`@+R\@4F5T
M=7)N("1T<F%N<U]L86YG+@H@("`@("`@(')E='5R;B`D=')A;G-?;&%N9SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)S970@9F]R
M('1H92!C=7)R96YT(&QA;F=U86=E+@H@("`@("H*("`@("`J($!P87)A;2!B
M;V]L96%N("1O<FEG:6YA;"`@268@=')U92!R971U<FYS('1H92!O<FEG:6YA
M;"!C:&%R<V5T(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("!T<F%N<VQA=&EO;BP@=&AE(&%C='5A;&QY('5S960@;VYE(&]T:&5R
M=VES92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-H87)A
M8W1E<B!S970@=&AA="!S:&]U;&0@8F4@=7-E9"!W:71H('1H92!C=7)R96YT
M"B`@("`@*B`@("`@("`@("`@("`@("`@;&]C86QE('-E='1I;F=S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T*"1O<FEG:6YA;"`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;&%N9W5A9V4L("1N;',["@H@("`@
M("`@("\J($=E="!C86-H960@<F5S=6QT<RX@*B\*("`@("`@("`D8V%C:&5+
M97D@/2!I;G1V86PH)&]R:6=I;F%L*3L*("`@("`@("`D8VAA<G-E="`]($Y,
M4SHZ7V-A8VAE9$-H87)S970H)&-A8VAE2V5Y*3L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&-H87)S970I*2!["B`@("`@("`@("`@(')E='5R;B`D8VAA<G-E
M=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D;W)I9VEN86PI('L*("`@("`@
M("`@("`@)&-H87)S970@/2!E;7!T>2@D;FQS6R=C:&%R<V5T<R==6R1L86YG
M=6%G95TI(#\@)TE33RTX.#4Y+3$G(#H@)&YL<ULG8VAA<G-E=',G75LD;&%N
M9W5A9V5=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G2&]R9&4O0G)O=W-E<BYP:'`G.PH@("`@("`@("`@("`D8G)O=W-E
M<B`]("9"<F]W<V5R.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@("`@(&EF("@D
M8G)O=W-E<BT^:&%S1F5A='5R92@G=71F)RD@)B8*("`@("`@("`@("`@("`@
M("A5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VEC;VYV)RD@?'P*("`@("`@("`@
M("`@("`@("!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VUB<W1R:6YG)RDI*2![
M"B`@("`@("`@("`@("`@("`D8VAA<G-E="`]("=55$8M."<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]N=6QL*"1C:&%R<V5T
M*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]($Y,4SHZ9V5T17AT97)N86Q#
M:&%R<V5T*"D["B`@("`@("`@?0H*("`@("`@("!.3%,Z.E]C86-H961#:&%R
M<V5T*"1C86-H94ME>2P@)&-H87)S970I.PH@("`@("`@(')E='5R;B`D8VAA
M<G-E=#L*("`@('T*"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R
M96YT(&-H87)S970@;V8@=&AE(&5N=FER;VYM96YT"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!C:&%R86-T97(@<V5T('1H870@<VAO=6QD
M(&)E('5S960@=VET:"!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@
M("`@(&QO8V%L92!S971T:6YG<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M17AT97)N86Q#:&%R<V5T*"D*("`@('L*("`@("`@("!G;&]B86P@)&QA;F=U
M86=E+"`D;FQS.PH*("`@("`@("`O*B!'970@8V%C:&5D(')E<W5L=',N("HO
M"B`@("`@("`@)&-H87)S970@/2!.3%,Z.E]C86-H961#:&%R<V5T*#(I.PH@
M("`@("`@(&EF("@A:7-?;G5L;"@D8VAA<G-E="DI('L*("`@("`@("`@("`@
M<F5T=7)N("1C:&%R<V5T.PH@("`@("`@('T*"B`@("`@("`@)&QA;F=?8VAA
M<G-E="`]('-E=&QO8V%L92A,0U]!3$PL(#`I.PH@("`@("`@(&EF("AS=')P
M;W,H)&QA;F=?8VAA<G-E="P@)SLG*2`]/3T@9F%L<V4@)B8*("`@("`@("`@
M("`@<W1R<&]S*"1L86YG7V-H87)S970L("<O)RD@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@("1L86YG7V-H87)S970@/2!E>'!L;V1E*"<N)RP@)&QA;F=?
M8VAA<G-E="D["B`@("`@("`@("`@(&EF("@H8V]U;G0H)&QA;F=?8VAA<G-E
M="D@/3T@,BD@)B8@(65M<'1Y*"1L86YG7V-H87)S971;,5TI*2!["B`@("`@
M("`@("`@("`@("!.3%,Z.E]C86-H961#:&%R<V5T*#(L("1L86YG7V-H87)S
M971;,5TI.PH@("`@("`@("`@("`@("`@<F5T=7)N("1L86YG7V-H87)S971;
M,5T["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H
M(65M<'1Y*"1N;'-;)V-H87)S971S)UU;)&QA;F=U86=E72DI(#\@)&YL<ULG
M8VAA<G-E=',G75LD;&%N9W5A9V5=(#H@)TE33RTX.#4Y+3$G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!O<B!R971U<FYS('1H92!C:&%R<V5T('5S
M960@=6YD97(@8V5R=&%I;B!C;VYD:71I;VYS+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I
M;F1E>"`@(%1H92!)1"!O9B!A(&-A8VAE('-L;W0N(#`@9F]R('1H92!522!C
M:&%R<V5T+"`Q"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@
M=&AE('1R86YS;&%T:6]N(&-H87)S970@86YD(#(@9F]R('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@97AT97)N86P@8VAA<G-E="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&-H87)S970@($EF('-P96-I9FEE9"P@=&AI
M<R!C:&%R<V5T('=I;&P@8F4@<W1O<F5D(&EN('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@9VEV96X@8V%C:&4@<VQO="X@3W1H97)W:7-E
M('1H92!C;VYT96YT(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<W!E8VEF:65D(&-A8VAE('-L;W0@=VEL;"!B92!R971U<FYE9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-A8VAE9$-H87)S970H)&EN9&5X+"`D
M8VAA<G-E="`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1C86-H93L*
M"B`@("`@("`@:68@*"%I<W-E="@D8V%C:&4I*2!["B`@("`@("`@("`@("1C
M86-H92`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&-H87)S
M970@/3T@;G5L;"D@>PH@("`@("`@("`@("!R971U<FX@:7-S970H)&-A8VAE
M6R1I;F1E>%TI(#\@)&-A8VAE6R1I;F1E>%T@.B!N=6QL.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1C86-H95LD:6YD97A=(#T@)&-H87)S970[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M8VAA<G-E="!T;R!U<V4@9F]R(&]U=&=O:6YG(&5M86EL<RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969E<G)E9"!C:&%R<V5T(&9O
M<B!O=71G;VEN9R!M86EL<R!B87-E9"!O;@H@("`@("H@("`@("`@("`@("`@
M("`@('1H92!U<V5R)W,@<')E9F5R96YC97,@86YD('1H92!C=7)R96YT(&QA
M;F=U86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%;6%I;$-H87)S970H
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1L86YG=6%G92P@)&YL
M<SL*"B`@("`@("`@)&-H87)S970@/2`D<')E9G,M/F=E=%9A;'5E*"=S96YD
M:6YG7V-H87)S970G*3L*("`@("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-H87)S970["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!I<W-E="@D;FQS6R=E;6%I;',G75LD;&%N9W5A9V5=*2`_
M("1N;'-;)V5M86EL<R==6R1L86YG=6%G95T@.@H@("`@("`@("`@("`@("`H
M:7-S970H)&YL<ULG8VAA<G-E=',G75LD;&%N9W5A9V5=*2`_("1N;'-;)V-H
M87)S971S)UU;)&QA;F=U86=E72`Z("=)4T\M.#@U.2TQ)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:R!T;R!S964@:68@8VAA<F%C=&5R('-E="!I
M<R!V86QI9"!F;W(@:'1M;'-P96-I86QC:&%R<R@I(&-A;&QS+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R86-T97(@
M<V5T('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M27,@8VAA<G-E="!V86QI9"!F;W(@=&AE(&-U<G)E;G0@<WES=&5M/PH@("`@
M("HO"B`@("!F=6YC=&EO;B!C:&5C:T-H87)S970H)&-H87)S970I"B`@("![
M"B`@("`@("`@<W1A=&EC("1C:&5C:SL*"B`@("`@("`@:68@*&ES7VYU;&PH
M)&-H87)S970I('Q\(&5M<'1Y*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-H
M96-K6R1C:&%R<V5T72DI('L*("`@("`@("`@("`@<F5T=7)N("1C:&5C:ULD
M8VAA<G-E=%T["B`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D8VAE8VLI*2![
M"B`@("`@("`@("`@("1C:&5C:R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`D=F%L:60@/2!T<G5E.PH*("`@("`@("!I;FE?<V5T*"=T<F%C:U]E
M<G)O<G,G+"`Q*3L*("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@G)RP@14Y4
M7T-/35!!5"P@)&-H87)S970I.PH@("`@("`@(&EF("AI<W-E="@D<&AP7V5R
M<F]R;7-G*2D@>PH@("`@("`@("`@("`D=F%L:60@/2!F86QS93L*("`@("`@
M("!]"B`@("`@("`@:6YI7W)E<W1O<F4H)W1R86-K7V5R<F]R<R<I.PH*("`@
M("`@("`D8VAE8VM;)&-H87)S971=(#T@)'9A;&ED.PH*("`@("`@("!R971U
M<FX@)'9A;&ED.PH@("`@?0H*("`@+RHJ"B`@("`@*B!3971S('1H92!C:&%R
M<V5T+@H@("`@("H@26X@9V5N97)A;"P@=&AE(&%P<&QI960@8VAA<G-E="!I
M<R!A=71O;6%T:6-A;&QY(&1E=&5R;6EN960@8GD@8G)O=W-E<@H@("`@("H@
M;&%N9W5A9V4@86YD(&)R;W=S97(@8V%P86)I;&ET:65S(&%N9"!T:&5R92=S
M(&YO(&YE960@=&\@;6%N=6%L;'D@8V%L;`H@("`@("H@<V5T0VAA<G-E="X@
M2&]W979E<B!F;W(@:&5A9&QE<W,@*%)00RD@;W!E<F%T:6]N<R!T:&4@8VAA
M<G-E="!M87D@8F4*("`@("`J('-E="!M86YU86QL>2!T;R!E;G-U<F4@8V]R
M<F5C="!C:&%R86-T97(@8V]N=F5R<VEO;B!I;B!T:&4@8F%C:V5N9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:&%R<V5T("!)9B!S<&5C:69I
M960L('1H:7,@8VAA<G-E="!W:6QL(&)E('-T;W)E9"!I;B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&=I=F5N(&-A8VAE('-L;W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("`@5&AE($E$(&]F
M(&$@8V%C:&4@<VQO="X@,"!F;W(@=&AE(%5)(&-H87)S970L(#$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O<B!T:&4@=')A;G-L871I;VX@
M8VAA<G-E="!A;F0@,B!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!E>'1E<FYA;"!C:&%R<V5T+B!$969A=6QT<R!T;R`P.B!T:&ES
M(&ES('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@8VAA<G-E
M="!R971U<FYE9"!B>2!G971#:&%R<V5T(&%N9"!U<V5D(&9O<@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=F5R<VEO;BX*("`@("`J+PH*
M("`@(&9U;F-T:6]N('-E=$-H87)S970H)&-H87)S970L)&EN9&5X(#T@,"D*
M("`@('L*("`@("`@("!.3%,Z.E]C86-H961#:&%R<V5T*"1I;F1E>"P@)&-H
M87)S970I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@8W5R<F5N
M="!T:6UE>F]N92P@:68@879A:6QA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S9714:6UE6F]N92@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*
M"B`@("`@("`@)'1Z(#T@)'!R969S+3YG971686QU92@G=&EM97IO;F4G*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1T>BDI('L*("`@("`@("`@("`@0'!U=&5N
M=B@G5%H])R`N("1T>BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T('1H92!L;V-A;&4@:6YF;R!R971U<FYE9"!B>2!L;V-A;&5C;VYV
M*"DL(&)U="!C86-H92!I="P@=&\*("`@("`J(&%V;VED(')E<&5A=&5D(&-A
M;&QS+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!R97-U;'1S
M(&]F(&QO8V%L96-O;G8H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]C
M86QE26YF;R@I"B`@("!["B`@("`@("`@<W1A=&EC("1L8U]I;F9O.PH*("`@
M("`@("!I9B`H(6ES<V5T*"1L8U]I;F9O*2D@>PH@("`@("`@("`@("`D;&-?
M:6YF;R`](&QO8V%L96-O;G8H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;&-?:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@;&%N
M9W5A9V4@:6YF;R!R971U<FYE9"!B>2!N;%]L86YG:6YF;R@I+"!B=70@8V%C
M:&4@:70L('1O"B`@("`@*B!A=F]I9"!R97!E871E9"!C86QL<RX*("`@("`J
M"B`@("`@*B!`<VEN8V4@2&]R9&4@,RXQ"B`@("`@*@H@("`@("H@0'!A<F%M
M(&-O;G-T("1I=&5M("!4:&4@;&%N9VEN9F\@:71E;2!T;R!R971U<FXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(')E<W5L=',@;V8@;FQ?
M;&%N9VEN9F\H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&%N9TEN9F\H
M)&ET96TI"B`@("!["B`@("`@("`@<W1A=&EC("1N;%]I;F9O(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*"%I<W-E="@D;FQ?:6YF;ULD:71E;5TI*2!["B`@
M("`@("`@("`@("1N;%]I;F9O6R1I=&5M72`](&YL7VQA;F=I;F9O*"1I=&5M
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;FQ?:6YF;ULD:71E;5T[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@8V]U;G1R>2!I;F9O<FUA=&EO
M;B!F<F]M(&$@:&]S=&YA;64@;W(@25`@861D<F5S<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1H;W-T("!4:&4@:&]S=&YA;64@;W(@25`@861D
M<F5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!/;B!S=6-C97-S
M+"!R971U<FX@86X@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&5N=')I97,Z
M"B`@("`@*B`@("`@("`@("`@("`@("`G8V]D92<@(#T^("!#;W5N=')Y($-O
M9&4*("`@("`J("`@("`@("`@("`@("`@("=N86UE)R`@/3X@($-O=6YT<GD@
M3F%M90H@("`@("H@("`@("`@("`@("`@("`@3VX@9F%I;'5R92P@<F5T=7)N
M(&9A;'-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;W5N=')Y0GE(;W-T
M*"1H;W-T*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@
M+RH@3&ES="!O9B!G96YE<FEC(&1O;6%I;G,@=&AA="!W92!K;F]W(&ES(&YO
M="!I;B!T:&4@8V]U;G1R>2!43$0*("`@("`@("`@("!L:7-T+B!3964Z(&AT
M='`Z+R]W=W<N:6%N82YO<F<O9W1L9"]G=&QD+FAT;2`J+PH@("`@("`@("1G
M96YE<FEC(#T@87)R87DH"B`@("`@("`@("`@("=A97)O)RP@)V)I>B<L("=C
M;VTG+"`G8V]O<"<L("=E9'4G+"`G9V]V)RP@)VEN9F\G+"`G:6YT)RP@)VUI
M;"<L"B`@("`@("`@("`@("=M=7-E=6TG+"`G;F%M92<L("=N970G+"`G;W)G
M)RP@)W!R;R<*("`@("`@("`I.PH*("`@("`@("`D8VAE8VM(;W-T(#T@)&AO
M<W0["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7&0K7"Y<9"M<+EQD*UPN
M7&0K)"\G+"`D:&]S="DI('L*("`@("`@("`@("`@)&-H96-K2&]S="`]($!G
M971H;W-T8GEA9&1R*"1H;W-T*3L*("`@("`@("!]"@H@("`@("`@("\J($=E
M="!T:&4@5$Q$(&]F('1H92!H;W-T;F%M92X@*B\*("`@("`@("`D<&]S(#T@
M<W1R<G!O<R@D8VAE8VM(;W-T+"`G+B<I.PH@("`@("`@(&EF("@D<&]S(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@("1D;VUA:6X@/2!3=')I;F<Z.FQO=V5R*'-U8G-T<B@D8VAE
M8VM(;W-T+"`D<&]S("L@,2DI.PH*("`@("`@("`O*B!4<GD@;&]O:W5P('9I
M82!43$0@9FER<W0N("HO"B`@("`@("`@:68@*"%I;E]A<G)A>2@D9&]M86EN
M+"`D9V5N97)I8RDI('L*("`@("`@("`@("`@<F5Q=6ER92`G2&]R9&4O3DQ3
M+W1L9"YP:'`G.PH@("`@("`@("`@("!I9B`H:7-S970H)'1L9%LD9&]M86EN
M72DI('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@G8V]D92<@/3X@
M)&1O;6%I;BP@)VYA;64G(#T^("1T;&1;)&1O;6%I;ETI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O*B!4<GD@1V5O25`@;&]O:W5P(&YE
M>'0N("HO"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG9V5O:7`G75LG9&%T
M869I;&4G72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92].
M3%,O1V5O25`N<&AP)SL*("`@("`@("`@("`@)&=E;VEP(#T@)DY,4U]'96])
M4#HZ<VEN9VQE=&]N*"1C;VYF6R=G96]I<"==6R=D871A9FEL92==*3L*("`@
M("`@("`@("`@)&ED(#T@)&=E;VEP+3YC;W5N=')Y261">4YA;64H)&-H96-K
M2&]S="D["B`@("`@("`@("`@(&EF("@A96UP='DH)&ED*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"=C;V1E)R`]/B!3=')I;F<Z.FQO=V5R
M*"1'3$]"04Q36R='14])4%]#3U5.5%)97T-/1$53)UU;)&ED72DL("=N86UE
M)R`]/B`D1TQ/0D%,4ULG1T5/25!?0T]53E1265].04U%4R==6R1I9%TI.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@2&]R9&4@:6UA9V4@
M;&EN:R!T;R!T:&4@8V]U;G1R>2!F;&%G+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&AO<W0@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:6UA9V4@55),+"!O
M<B!T:&4@96UP='D@<W1R:6YG(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G96YE<F%T949L86=);6%G94)Y2&]S="@D:&]S="D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D9&%T82`]($Y,4SHZ
M9V5T0V]U;G1R>4)Y2&]S="@D:&]S="D["B`@("`@("`@:68@*"1D871A("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`D:6UG(#T@)&1A=&%;)V-O9&4G72`N
M("<N<&YG)SL*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1R96=I<W1R
M>2T^9V5T*"=T:&5M97-F<R<L("=H;W)D92<I("X@)R]G<F%P:&EC<R]F;&%G
M<R\G("X@)&EM9RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!(;W)D93HZ
M:6UG*"1I;6<L("1D871A6R=N86UE)UTL(&%R<F%Y*"=T:71L92<@/3X@)&1A
M=&%;)VYA;64G72DL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@
M+B`G+V9L86=S)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!R971U<FX@)ULG("X@)&1A=&%;)VYA;64G72`N("==)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!E:71H97(@82!S<&5C:69I8R!O<B!A
M;&P@25-/+3,Q-C8@8V]U;G1R>2!N86UE<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C;V1E("!4:&4@25-/(#,Q-C8@8V]U;G1R>2!C;V1E+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($EF(&$@8V]U;G1R>2!C;V1E
M(&AA<R!B965N(')E<75E<W1E9"!W:6QL(')E='5R;B!T:&4*("`@("`J("`@
M("`@("`@("`@("`@(&-O<G)E<W!O;F1I;F<@8V]U;G1R>2!N86UE+B!)9B!E
M;7!T>2!W:6QL(')E='5R;B!A;@H@("`@("H@("`@("`@("`@("`@("`@87)R
M87D@;V8@86QL('1H92!C;W5N=')Y(&-O9&5S(&%N9"!T:&5I<B!N86UE<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$-O=6YT<GE)4T\H)&-O9&4@/2`G
M)RD*("`@('L*("`@("`@("!S=&%T:6,@)&-O=6YT<FEE<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*&5M<'1Y*"1C;W5N=')I97,I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O3DQ3+V-O=6YT<FEE<RYP:'`G.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&-O9&4I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8V]U;G1R:65S.PH@("`@("`@('T@96QS96EF("AI<W-E="@D
M8V]U;G1R:65S6R1C;V1E72DI('L*("`@("`@("`@("`@<F5T=7)N("1C;W5N
M=')I97-;)&-O9&5=.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y
M<'0N<&AP````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3(U-S<@,3`U,34T,S0Q-#$@,#(Q,38V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R
M9&5?0W)Y<'0Z.B!C;&%S<R!P<F]V:61E<R!A;B!!4$D@9F]R('9A<FEO=7,@
M8W)Y<'1O9W)A<&AI8PH@*B!S>7-T96US('5S960@8GD@2&]R9&4@87!P;&EC
M871I;VYS+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#<GEP="]#<GEP="YP
M:'`L=B`Q+C(W+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HQ,B!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L
M=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E
M92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@
M*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]#<GEP=`H@*B\*8VQA<W,@2&]R9&5?0W)Y<'0@>PH*("`@("\J
M*@H@("`@("H@5&AE('1E;7!O<F%R>2!D:7)E8W1O<GD@=&\@=7-E+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1E;7!D
M:7(["@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC
M<F5T92!(;W)D95]#<GEP="!I;G-T86YC92!B87-E9"!O;B`D9')I=F5R+@H@
M("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O
M9B!C;VYC<F5T92!(;W)D95]#<GEP="!S=6)C;&%S<R!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;BX@268@)&1R:79E<B!I<R!A;B!A
M<G)A>2P@=&AE;B!W92!W:6QL(&QO;VL*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;B`D9')I=F5R6S!=+VQI8B]#<GEP="\@9F]R('1H92!S=6)C
M;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T
M:6]N(&YA;65D("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L(&-O
M;F9I9W5R871I;VX@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!P
M87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N($AO<F1E7T-R>7!T("!4:&4@;F5W;'D@8W)E871E9"!C;VYC
M<F5T92!(;W)D95]#<GEP="!I;G-T86YC92P@;W(*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@
M("`@("`@;&ES="@D87!P+"`D9')I=F5R*2`]("1D<FEV97(["B`@("`@("`@
M?0H*("`@("`@("`O*B!2971U<FX@82!B87-E($AO<F1E7T-R>7!T(&]B:F5C
M="!I9B!N;R!D<FEV97(@:7,@<W!E8VEF:65D+B`J+PH@("`@("`@("1D<FEV
M97(@/2!B87-E;F%M92@D9')I=F5R*3L*("`@("`@("!I9B`H96UP='DH)&1R
M:79E<BD@?'P@*'-T<F-M<"@D9')I=F5R+"`G;F]N92<I(#T](#`I*2!["B`@
M("`@("`@("`@("1C<GEP="`]("9N97<@2&]R9&5?0W)Y<'0H*3L*("`@("`@
M("`@("`@<F5T=7)N("1C<GEP=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M96UP='DH)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"
M04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI
M8B]#<GEP="\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I
M9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]#<GEP="\G
M("X@)&1R:79E<B`N("<N<&AP)RDI('L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]#<GEP="\G("X@)&1R:79E<B`N
M("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D
M95]O;F-E("=(;W)D92]#<GEP="\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@
M("`@("!]"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7T-R>7!T7R<@+B`D9')I
M=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@
M("`@("`@("`D8W)Y<'0@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8W)Y<'0@/2!014%2.CIR86ES945R
M<F]R*"=#;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F
M;W5N9"XG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8W)Y<'0["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E
M<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D95]#<GEP="!I;G-T86YC90H@("`@
M("H@8F%S960@;VX@)&1R:79E<BX@270@=VEL;"!O;FQY(&-R96%T92!A(&YE
M=R!I;G-T86YC92!I9B!N;PH@("`@("H@2&]R9&5?0W)Y<'0@:6YS=&%N8V4@
M=VET:"!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@
M("`@*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!C
M<GEP=&\@8F%C:V5N9',@*&%N9"P@=&AU<RP*("`@("`J(&UU;'1I<&QE($AO
M<F1E7T-R>7!T(&EN<W1A;F-E<RD@87)E(')E<75I<F5D+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH@)'9A<B`]("9(
M;W)D95]#<GEP=#HZ<VEN9VQE=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@
M;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?0W)Y
M<'0@<W5B8VQA<W,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FXN($EF("1D<FEV97(@:7,@86X@87)R87DL('1H96X@=V4@=VEL;"!L
M;V]K"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@:6X@)&1R:79E<ELP
M72]L:6(O0W)Y<'0O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I=F5R6S%=
M+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A;65T97)S
M(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7T-R>7!T("!4:&4@8V]N8W)E=&4@2&]R9&5?0W)Y<'0@<F5F97)E
M;F-E+"!O<B!F86QS92!O;B!A;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R
M:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<W1A=&EC
M("1I;G-T86YC97,["@H@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI
M('L*("`@("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@
M?0H*("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1D<FEV
M97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;
M)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA
M='5R95T@/2`F2&]R9&5?0W)Y<'0Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M
M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG
M;F%T=7)E73L*("`@('T*"B`@("`O*BH*("`@("`J($]U='!U=',@97)R;W(@
M;65S<V%G92!I9B!W92!A<F4@;F]T('5S:6YG(&$@<V5C=7)E(&-O;FYE8W1I
M;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!014%27T5R<F]R("!2971U<FYS
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@:68@=&AE<F4@:7,@;F\@<V5C=7)E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E<75I<F5396-U<F5#;VYN96-T:6]N*"D*("`@('L*
M("`@("`@("!G;&]B86P@)&)R;W=S97(["@H@("`@("`@(&EF("@A)&)R;W=S
M97(M/G5S:6YG4U-,0V]N;F5C=&EO;B@I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E1H92!E;F-R>7!T:6]N(&9E871U<F5S
M(')E<75I<F4@82!S96-U<F4@=V5B(&-O;FYE8W1I;VXN(BDI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@=&AE(')E<75E<W1E
M9"!D871A+@H@("`@("H@5&AI<R!M971H;V0@<VAO=6QD(&)E('!R;W9I9&5D
M(&)Y(&%L;"!C;&%S<V5S('1H870@97AT96YD($AO<F1E7T-R>7!T+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!E
M;F-R>7!T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y
M(&]F(&%R9W5M96YT<R!N965D960@=&\@96YC<GEP="!T:&4@9&%T82X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@96YC<GEP=&5D(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)&1A=&$L("1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E8W)Y<'0@=&AE(')E<75E<W1E9"!D871A+@H@
M("`@("H@5&AI<R!M971H;V0@<VAO=6QD(&)E('!R;W9I9&5D(&)Y(&%L;"!C
M;&%S<V5S('1H870@97AT96YD($AO<F1E7T-R>7!T+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&$@("!4:&4@9&%T82!T;R!D96-R>7!T+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N(&%R<F%Y(&]F(&%R9W5M
M96YT<R!N965D960@=&\@9&5C<GEP="!T:&4@9&%T82X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@9&5C<GEP=&5D(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1E8W)Y<'0H)&1A=&$L("1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*
M("`@("`J($-R96%T92!A('1E;7!O<F%R>2!F:6QE('1H870@=VEL;"!B92!D
M96QE=&5D(&%T('1H92!E;F0@;V8@=&AI<PH@("`@("H@<')O8V5S<RX*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D9&5S8W)I<"`@1&5S8W)I<'1I;VX@<W1R:6YG('1O('5S
M92!I;B!F:6QE;F%M92X*("`@("`J($!P87)A;2!B;V]L96%N("1D96QE=&4@
M("!$96QE=&4@=&AE(&9I;&4@875T;VUA=&EC86QL>3\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@1FEL96YA;64@;V8@82!T96UP;W)A<GD@9FEL
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T951E;7!&:6QE*"1D97-C
M<FEP(#T@)VAO<F1E+6-R>7!T)RP@)&1E;&5T92`]('1R=64I"B`@("!["B`@
M("`@("`@<F5T=7)N(%5T:6PZ.F=E=%1E;7!&:6QE*"1D97-C<FEP+"`D9&5L
M971E+"`D=&AI<RT^7W1E;7!D:7(L('1R=64I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VLN<&AP````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(W,C<@,3`U,34T,S0Q-#$@
M,#(Q,3$T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@86)S=')A8W0@2&]R9&5?0FQO8VLZ.B!C
M;&%S<R!R97!R97-E;G1S(&$@<VEN9VQE(&)L;V-K('=I=&AI;@H@*B!T:&4@
M0FQO8VMS(&9R86UE=V]R:RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO
M8VLO0FQO8VLN<&AP+'8@,2XS,RXQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,#@@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:R!["@H@("`@+RHJ
M"B`@("`@*B!";&]C:R!S<&5C:69I8R!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($%P<&QI8V%T:6]N('1H870@=&AI<R!B
M;&]C:R!O<FEG:6YA=&5D(&9R;VTN"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?87!P.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y?&)O;VQE86X@
M)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(&)L;V-K(&YE961S+B!)9B!F
M86QS92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!D969A=6QT('!A<F%M971E<B!W:6QL(&)E('5S960N"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7T)L;V-K*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@
M>PH@("`@("`@(&EF("@D<&%R86US(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`D<&%R86US(#T@)'1H:7,M/F=E=%!A<F%M<R@I.PH@("`@("`@("`@("!F
M;W)E86-H("@D<&%R86US(&%S("1N86UE(#T^("1P87)A;2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)&YA;65=(#T@)'!A<F%M6R=D969A
M=6QT)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@87!P;&EC871I;VX@=&AA
M="!T:&ES(&)L;V-K(&)E;&]N9W,@=&\N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!A<'!L:6-A=&EO;B!N86UE+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971!<'`H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V%P<#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86YY('-E='1A
M8FQE('!A<F%M971E<G,@9F]R('1H:7,@8FQO8VLN(%1H:7,@:7,@80H@("`@
M("H@<W1A=&EC(&UE=&AO9"X@270@9&]E<R`J;F]T*B!R969E<F5N8V4@)'1H
M:7,M/E]P87)A;7,[('1H870@:7,*("`@("`J(&9O<B!R=6YT:6UE('!A<F%M
M971E<G,@*'1H92!C:&]I8V5S(&UA9&4@9G)O;2!T:&5S92!O<'1I;VYS*2X*
M("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(&)L;V-K)W,@8V]N9FEG=7)A8FQE('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI8V%T
M:6]N(&-O;G1E>'1S+"!I9B!N96-E<W-A<GDN(%)E='5R;B!A;B!E<G)O<@H@
M("`@("`@("`J(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL<RX@*B\*
M("`@("`@("`D87!P7W!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@D=&AI
M<RT^7V%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]P=7-H960L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?<'5S:&5D+3YG
M971-97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@)'1H
M:7,M/E]P87)A;7,H*3L*"B`@("`@("`@+RH@268@=V4@8VAA;F=E9"!A<'!L
M:6-A=&EO;B!C;VYT97AT(&EN('1H92!C;W5R<V4@;V8@=&AI<PH@("`@("`@
M("`J(&-A;&PL('5N9&\@=&AA="!C:&%N9V4@;F]W+B`J+PH@("`@("`@(&EF
M("@D87!P7W!U<VAE9"`]/3T@=')U92D@>PH@("`@("`@("`@("`D<F5G:7-T
M<GDM/G!O<$%P<"@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A
M;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T97AT('1O
M(&=O(&EN('1H92!T:71L92!O9B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J
M(%1H:7,@9G5N8W1I;VX@:&%N9&QE<R!T:&4@8VAA;F=I;F<@;V8@8W5R<F5N
M="!A<'!L:6-A=&EO;B!A<PH@("`@("H@;F5E9&5D('-O(&-O9&4@:7,@97AE
M8W5T960@:6X@=&AE('-C;W!E(&]F('1H92!A<'!L:6-A=&EO;B!T:&4*("`@
M("`J(&)L;V-K(&]R:6=I;F%T960@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&)L;V-K)W,@=&ET;&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1I=&QE*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH*("`@("`@("`O*B!3=VET8V@@87!P;&EC871I;VX@8V]N=&5X=',L
M(&EF(&YE8V5S<V%R>2X@4F5T=7)N(&%N(&5R<F]R"B`@("`@("`@("H@:6UM
M961I871E;'D@:68@<'5S:$%P<"@I(&9A:6QS+B`J+PH@("`@("`@("1A<'!?
M<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P*"1T:&ES+3Y?87!P*3L*("`@
M("`@("!I9B`H:7-?82@D87!P7W!U<VAE9"P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&%P<%]P=7-H960M/F=E=$UE<W-A9V4H*3L*
M("`@("`@("!]"@H@("`@("`@("1T:71L92`]("1T:&ES+3Y?=&ET;&4H*3L*
M"B`@("`@("`@+RH@268@=V4@8VAA;F=E9"!A<'!L:6-A=&EO;B!C;VYT97AT
M(&EN('1H92!C;W5R<V4@;V8@=&AI<PH@("`@("`@("`J(&-A;&PL('5N9&\@
M=&AA="!C:&%N9V4@;F]W+B`J+PH@("`@("`@(&EF("@D87!P7W!U<VAE9"`]
M/3T@=')U92D@>PH@("`@("`@("`@("`D<F5G:7-T<GDM/G!O<$%P<"@I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:71L93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G0@9F]R('1H:7,@8FQO8VLN
M"B`@("`@*@H@("`@("H@5&AI<R!F=6YC=&EO;B!H86YD;&5S('1H92!C:&%N
M9VEN9R!O9B!C=7)R96YT(&%P<&QI8V%T:6]N(&%S"B`@("`@*B!N965D960@
M<V\@8V]D92!I<R!E>&5C=71E9"!I;B!T:&4@<V-O<&4@;V8@=&AE(&%P<&QI
M8V%T:6]N('1H90H@("`@("H@8FQO8VL@;W)I9VEN871E9"!F<F]M+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8FQO8VLG<R!C;VYT96YT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYT96YT*"D*("`@('L*("`@
M("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O*B!3=VET8V@@87!P
M;&EC871I;VX@8V]N=&5X=',L(&EF(&YE8V5S<V%R>2X@4F5T=7)N(&%N(&5R
M<F]R"B`@("`@("`@("H@:6UM961I871E;'D@:68@<'5S:$%P<"@I(&9A:6QS
M+B`J+PH@("`@("`@("1A<'!?<'5S:&5D(#T@)')E9VES=')Y+3YP=7-H07!P
M*"1T:&ES+3Y?87!P*3L*("`@("`@("!I9B`H:7-?82@D87!P7W!U<VAE9"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&%P<%]P=7-H
M960M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@("1C;VYT96YT
M(#T@)'1H:7,M/E]C;VYT96YT*"D["@H@("`@("`@("\J($EF('=E(&-H86YG
M960@87!P;&EC871I;VX@8V]N=&5X="!I;B!T:&4@8V]U<G-E(&]F('1H:7,*
M("`@("`@("`@*B!C86QL+"!U;F1O('1H870@8VAA;F=E(&YO=RX@*B\*("`@
M("`@("!I9B`H)&%P<%]P=7-H960@/3T]('1R=64I('L*("`@("`@("`@("`@
M)')E9VES=')Y+3YP;W!!<'`H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D8V]N=&5N=#L*("`@('T*"B`@("!F=6YC=&EO;B!B=6EL9%1R964H)B1T
M<F5E+"`D:6YD96YT(#T@,"P@)'!A<F5N="`](&YU;&PI"B`@("!["B`@("`@
M("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@+RH@4W=I=&-H(&%P<&QI
M8V%T:6]N(&-O;G1E>'1S+"!I9B!N96-E<W-A<GDN(%)E='5R;B!A;B!E<G)O
M<@H@("`@("`@("`J(&EM;65D:6%T96QY(&EF('!U<VA!<'`H*2!F86EL<RX@
M*B\*("`@("`@("`D87!P7W!U<VAE9"`]("1R96=I<W1R>2T^<'5S:$%P<"@D
M=&AI<RT^7V%P<"D["B`@("`@("`@:68@*&ES7V$H)&%P<%]P=7-H960L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<'!?<'5S:&5D
M+3YG971-97-S86=E*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V)U
M:6QD5')E92@D=')E92P@)&EN9&5N="P@)'!A<F5N="D["@H@("`@("`@("\J
M($EF('=E(&-H86YG960@87!P;&EC871I;VX@8V]N=&5X="!I;B!T:&4@8V]U
M<G-E(&]F('1H:7,*("`@("`@("`@*B!C86QL+"!U;F1O('1H870@8VAA;F=E
M(&YO=RX@*B\*("`@("`@("!I9B`H)&%P<%]P=7-H960@/3T]('1R=64I('L*
M("`@("`@("`@("`@)')E9VES=')Y+3YP;W!!<'`H*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T:71L92!T;R!G;R!I
M;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8FQO8VL@=&ET;&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]T:71L92@I"B`@("!["B`@("`@("`@<F5T=7)N
M("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE
M=&5R<R!N965D960@8GD@8FQO8VLN"B`@("`@*@H@("`@("H@0&%B<W1R86-T
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&)L;V-K)W,@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H:7,@8FQO8VLG<R!C;VYT96YT+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8FQO8VLG<R!C;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=&5N
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&ES(&)L;V-K)W,@8V]N=&5N="X*("`@("`J"B`@
M("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&)L;V-K)W,@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U
M:6QD5')E92@F)'1R964L("1I;F1E;G0@/2`P+"`D<&%R96YT(#T@;G5L;"D*
M("`@('L*("`@('T*"GT*````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M3$1!4"YP:'``````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#4Q,S,@,3`U,34T,S0Q-#$@,#(P-3<S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES
M(&ES(&$@=71I;&ET>2!C;&%S<RP@979E<GD@;65T:&]D(&ES('-T871I8RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO3$1!4"],1$%0+G!H<"QV(#$N-2XQ
M,BXQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C(S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N
M8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*
M("H@0'!A8VMA9V4@2&]R9&5?3$1!4`H@*B\*8VQA<W,@2&]R9&5?3$1!4"![
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!B;V]L96%N(&5X<')E<W-I;VX@
M=7-I;F<@=&AE('-P96-I9FEE9"!O<&5R871O<BX*("`@("`J"B`@("`@*B!`
M<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&AS("!4:&4@
M871T<FEB=71E('1O('1E<W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1O<"`@
M(%1H92!O<&5R871O<BX*("`@("`J($!P87)A;2!S=')I;F<@)')H<R`@5&AE
M(&-O;7!A<FES;VX@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!,1$%0('-E87)C:"!F<F%G;65N="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8G5I;&1#;&%U<V4H)&QH<RP@)&]P+"`D<FAS*0H@("`@>PH@("`@
M("`@('-W:71C:"`H)&]P*2!["B`@("`@("`@8V%S92`G3$E+12<Z"B`@("`@
M("`@("`@(')E='5R;B!E;7!T>2@D<FAS*2`_"B`@("`@("`@("`@("`@("!S
M<')I;G1F*"<H)7,]*BDG+"`D;&AS*2`Z"B`@("`@("`@("`@("`@("!S<')I
M;G1F*"<H)7,]*B5S*BDG+"`D;&AS+"!(;W)D95],1$%0.CIQ=6]T92@D<FAS
M*2D["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B!S<')I
M;G1F*"<H)7,E<R5S*2<L("1L:',L("1O<"P@2&]R9&5?3$1!4#HZ<75O=&4H
M)')H<RDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($5S8V%P
M92!C:&%R86-T97)S('=I=&@@<W!E8VEA;"!M96%N:6YG(&EN($Q$05`@<V5A
M<F-H97,N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-L875S92`@5&AE('-T<FEN9R!T;R!E<V-A<&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E<V-A<&5D('-T<FEN
M9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<75O=&4H)&-L875S92D*("`@('L*
M("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H87)R87DH)UQ<)RP@("`G*"<L
M("`G*2<L("`G*B<L("`B7#`B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)UQ<-6,G+"`G7"@G+"`G7"DG+"`G7"HG+"`B7%PP,"(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQA=7-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1A:V4@86X@87)R87D@;V8@1$X@96QE;65N=',@86YD
M('!R;W!E<FQY('%U;W1E(&ET(&%C8V]R9&EN9R!T;R!21D,*("`@("`J(#$T
M.#4N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R=',@($%N(&%R<F%Y(&]F('1U<&QE<R!C;VYT86EN:6YG
M('1H92!A='1R:6)U=&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&YA
M;64@86YD('1H870@871T<FEB=71E)W,@=F%L=64@=VAI8V@@;6%K90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@=7`@=&AE($1.+B!%>&%M<&QE.@H@
M("`@("H*("`@("`J("`@("1P87)T<R`](&%R<F%Y*#`@/3X@87)R87DH)V-N
M)RP@)TIO:&X@4VUI=&@G*2P*("`@("`J("`@("`@("`@("`@("`@("`@(#$@
M/3X@87)R87DH)V1C)RP@)V5X86UP;&4G*2P*("`@("`J("`@("`@("`@("`@
M("`@("`@(#(@/3X@87)R87DH)V1C)RP@)V-O;2<I*3L*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R;W!E<FQY('%U;W1E9"!S=')I;F<@
M1$XN"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E1$XH)'!A<G1S*0H@("`@
M>PH@("`@("`@("1D;B`]("<G.PH@("`@("`@("1C;W5N="`](&-O=6YT*"1P
M87)T<RD["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK
M*2!["B`@("`@("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@
M("1D;B`N/2`G+"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1N("X]
M("1P87)T<ULD:5U;,%T@+B`G/2<["@H@("`@("`@("`@("`O+R!3964@:68@
M=V4@;F5E9"!T;R!Q=6]T92!T:&4@=F%L=64N"B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EQS?%QS)'Q<<UQS?%LL*STB7')<;CP^(SM=+R<L("1P
M87)T<ULD:5U;,5TI*2!["B`@("`@("`@("`@("`@("`D9&X@+CT@)R(G("X@
M<W1R7W)E<&QA8V4H)R(G+"`G7%PB)RP@)'!A<G1S6R1I75LQ72D@+B`G(B<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&X@+CT@
M)'!A<G1S6R1I75LQ73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1D;CL*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])9&5N=&ET>2YP:'``````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,3<T,R`Q,#4Q
M-30S-#$T,2`P,C$V-3(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@
M86X@:6YT97)F86-E('1O(&%L;"!I9&5N=&ET:65S(&$@=7-E<B!M:6=H="!H
M879E+B!)=',*("H@;65T:&]D<R!T86ME(&-A<F4@;V8@86YY('-I=&4M<W!E
M8VEF:6,@<F5S=')I8W1I;VYS(&-O;F9I9W5R960@:6X@<')E9G,N<&AP"B`J
M(&%N9"!C;VYF+G!H<"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O
M261E;G1I='DN<&AP+'8@,2XQ+C(N,B`R,#`V+S`V+S(X(#(P.C4R.C4S(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,N-0H@*B!`<&%C:V%G92!(;W)D95])9&5N=&ET>0H@*B\*8VQA
M<W,@261E;G1I='D@>PH*("`@("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN
M9R!A;&P@=&AE('5S97(G<R!I9&5N=&ET:65S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:61E;G1I=&EE<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!!('!O:6YT97(@=&\@=&AE('5S97(G<R!S
M=&%N9&%R9"!I9&5N=&ET>2X*("`@("`J(%1H:7,@;VYE(&ES('5S960@8GD@
M=&AE(&UE=&AO9',@<F5T=7)N:6YG('9A;'5E<R!I9B!N;R!O=&AE<B!O;F4@
M:7,*("`@("`J('-P96-I9FEE9"X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G
M97(*("`@("`J+PH@("`@=F%R("1?9&5F875L="`](#`["@H@("`@+RHJ"B`@
M("`@*B!4:&4@=7-E<B!W:&]S92!I9&5N=&ET:65S('1H97-E(&%R92X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]U<V5R
M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@86QL
M(&]F('1H92!P<F]P97)T:65S(&EN('1H:7,@:61E;G1I='DN"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P<F]P97)T:65S
M(#T@87)R87DH)VED)RP@)V9U;&QN86UE)RP@)V9R;VU?861D<B<I.PH*("`@
M("\J*@H@("`@("H@4F5F97)E;F-E('1O('1H92!P<F5F<R!O8FIE8W0@=&AA
M="!T:&ES($ED96YT:71Y('!O:6YT<R!T;RX*("`@("`J"B`@("`@*B!`=F%R
M(%!R969S"B`@("`@*B\*("`@('9A<B`D7W!R969S.PH*("`@("\J*@H@("`@
M("H@4F5A9',@86QL('1H92!U<V5R)W,@:61E;G1I=&EE<R!F<F]M('1H92!P
M<F5F<R!O8FIE8W0@;W(@8G5I;&1S(&$@;F5W"B`@("`@*B!I9&5N=&ET>2!F
M<F]M('1H92!S=&%N9&%R9"!V86QU97,@9VEV96X@:6X@<')E9G,N<&AP+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@($EF('-P96-I9FEE
M9"P@=V4@<F5A9"!A;F]T:&5R('5S97(G<R!I9&5N=&ET:65S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("!I;G-T96%D(&]F('1H92!C=7)R96YT('5S
M97(N"B`@("`@*B\*("`@(&9U;F-T:6]N($ED96YT:71Y*"1U<V5R(#T@;G5L
M;"D*("`@('L*("`@("`@("`D=&AI<RT^7W5S97(@/2`D=7-E<CL*("`@("`@
M("!I9B`H*&ES7VYU;&PH)'5S97(I('Q\("1U<V5R(#T]($%U=&@Z.F=E=$%U
M=&@H*2D@)B8*("`@("`@("`@("`@:7-S970H)$=,3T)!3%-;)W!R969S)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<')E9G,@/2`F)$=,3T)!3%-;)W!R
M969S)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]P
M<F5F<R`]("90<F5F<SHZ<VEN9VQE=&]N*"1'3$]"04Q36R=C;VYF)UU;)W!R
M969S)UU;)V1R:79E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E=$%P
M<"@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'5S97(L("<G+"!N=6QL+"!F86QS92D["B`@("`@("`@("`@("1T
M:&ES+3Y?<')E9G,M/G)E=')I979E*"D["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(2@D=&AI<RT^7VED96YT:71I97,@/2!`=6YS97)I86QI>F4H)'1H:7,M
M/E]P<F5F<RT^9V5T5F%L=64H)VED96YT:71I97,G+"!F86QS92DI*2D@>PH@
M("`@("`@("`@("`O*B!#;VYV97)T(&ED96YT:71I97,@9G)O;2!T:&4@;VQD
M(&9O<FUA="X@*B\*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S(#T@
M=6YS97)I86QI>F4H)'1H:7,M/E]P<F5F<RT^9V5T5F%L=64H)VED96YT:71I
M97,G*2D["B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T:&ES+3Y?:61E
M;G1I=&EE<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET:65S(#T@
M)'1H:7,M/E]P<F5F<RT^8V]N=F5R=$9R;VU$<FEV97(H)'1H:7,M/E]I9&5N
M=&ET:65S+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^<V5T1&5F875L="@D=&AI<RT^7W!R969S+3YG971686QU92@G
M9&5F875L=%]I9&5N=&ET>2<I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T97,@82!D969A=6QT(&ED96YT:71Y(&EF(&YO;F4@97AI<W1S('EE="!A
M;F0@<V5T<R!T:&4@<')E9F5R96YC97,*("`@("`J('5P(&EF('1H92!I9&5N
M=&ET:65S(&%R92!L;V-K960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]I9&5N=&ET
M:65S*2!\?"`H8V]U;G0H)'1H:7,M/E]I9&5N=&ET:65S*2`\/2`P*2D@>PH@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!R;W!E<G1I97,@87,@)&ME
M>2D@>PH@("`@("`@("`@("`@("`@)&ED96YT:71Y6R1K97E=(#T@)'1H:7,M
M/E]P<F5F<RT^9V5T5F%L=64H)&ME>2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1I9&5N=&ET>5LG:60G72DI('L*("`@("`@("`@
M("`@("`@("1I9&5N=&ET>5LG:60G72`](%\H(D1E9F%U;'0@261E;G1I='DB
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=&ET
M:65S(#T@87)R87DH)&ED96YT:71Y*3L*("`@("`@("`@("`@)'1H:7,M/G9E
M<FEF>2@P*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7W!R969S
M+3YI<TQO8VME9"@G9&5F875L=%]I9&5N=&ET>2<I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?<')O<&5R=&EE<R!A<R`D:V5Y*2!["B`@("`@
M("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^9V5T5F%L=64H)&ME>2D["B`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1V86QU92`](&EM<&QO9&4H(EQN(BP@)'9A;'5E*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E
M9G,M/G-E=%9A;'5E*"1K97DL("1V86QU92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!R969S+3YS971$:7)T>2@D:V5Y+"!F86QS92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3879E<R!A
M;&P@:61E;G1I=&EE<R!I;B!T:&4@<')E9G,@8F%C:V5N9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V%V92@I"B`@("!["B`@("`@("`@)&ED96YT:71I97,@
M/2`D=&AI<RT^7VED96YT:71I97,["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I
M9&5N=&ET:65S*2D@>PH@("`@("`@("`@("`D:61E;G1I=&EE<R`]("1T:&ES
M+3Y?<')E9G,M/F-O;G9E<G14;T1R:79E<B@D:61E;G1I=&EE<RP@3DQ3.CIG
M971#:&%R<V5T*"DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]P<F5F
M<RT^<V5T5F%L=64H)VED96YT:71I97,G+"!S97)I86QI>F4H)&ED96YT:71I
M97,I+"!F86QS92D["B`@("`@("`@)'1H:7,M/E]P<F5F<RT^<V5T5F%L=64H
M)V1E9F%U;'1?:61E;G1I='DG+"`D=&AI<RT^7V1E9F%U;'0I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D<R!A(&YE=R!E;7!T>2!I9&5N=&ET>2!T;R!T
M:&4@87)R87D@;V8@:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!P;VEN=&5R('1O('1H92!C<F5A=&5D(&ED96YT:71Y
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9"@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]I9&5N=&ET:65S6UT@/2!A<G)A>2@I.PH@("`@("`@(')E='5R;B!C
M;W5N="@D=&AI<RT^7VED96YT:71I97,I("T@,3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E;6]V97,@86X@:61E;G1I='D@9G)O;2!T:&4@87)R87D@;V8@
M:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61E
M;G1I='D@(%1H92!P;VEN=&5R('1O('1H92!I9&5N=&ET>2!T;R!B92!R96UO
M=F5D"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(')E;6]V960@
M:61E;G1I='D*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E*"1I9&5N=&ET
M>2D*("`@('L*("`@("`@("`D9&5L971E9"`](&%R<F%Y7W-P;&EC92@D=&AI
M<RT^7VED96YT:71I97,L("1I9&5N=&ET>2P@,2D["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]I9&5N=&ET:65S(&%S("1I9"`]/B`D;G5L;"D@>PH@("`@
M("`@("`@("!I9B`H)'1H:7,M/G-E=$1E9F%U;'0H)&ED*2D@>PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("!R971U<FX@)&1E;&5T960["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<&]I;G1E<B!T;R!T:&4@
M8W5R<F5N="!D969A=6QT(&ED96YT:71Y+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@5&AE('!O:6YT97(@=&\@=&AE(&-U<G)E;G0@9&5F875L
M="!I9&5N=&ET>0H@("`@("HO"B`@("!F=6YC=&EO;B!G971$969A=6QT*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]D969A=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T<R!T:&4@8W5R<F5N="!D969A=6QT(&ED96YT
M:71Y+@H@("`@("H@268@=&AE(&ED96YT:71Y(&1O97-N)W0@97AI<W0L('1H
M92!O;&0@9&5F875L="!I9&5N=&ET>2!S=&%Y<R!T:&4@<V%M92X*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61E;G1I='D@(%1H92!P;VEN=&5R
M('1O('1H92!N97<@9&5F875L="!I9&5N=&ET>0H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL
M=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)&ED96YT:71Y
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VED96YT:71I97-;
M)&ED96YT:71Y72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D969A=6QT(#T@
M)&ED96YT:71Y.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('!R;W!E<G1Y(&9R;VT@
M;VYE(&]F('1H92!I9&5N=&ET:65S+B!)9B!T:&ES('9A;'5E(&1O97-N)W0*
M("`@("`J(&5X:7-T(&]R(&ES(&QO8VME9"P@=&AE('!R;W!E<G1Y(&ES(')E
M=')I979E9"!F<F]M('1H92!P<F5F<R!B86-K96YD+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@("`@("`@5&AE('!R;W!E<G1Y('1O(')E
M=')I979E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED96YT:71Y("!4:&4@
M:61E;G1I='D@=&\@<F5T<FEE=F4@=&AE('!R;W!E<G1Y(&9R;VTN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E(&]F('1H92!P<F]P
M97)T>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)&ME>2P@)&ED
M96YT:71Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1I9&5N
M=&ET>2D@?'P@(6ES<V5T*"1T:&ES+3Y?:61E;G1I=&EE<ULD:61E;G1I='E=
M*2D@>PH@("`@("`@("`@("`D:61E;G1I='D@/2`D=&AI<RT^7V1E9F%U;'0[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?:61E;G1I
M=&EE<ULD:61E;G1I='E=6R1K97E=*2!\?"`D=&AI<RT^7W!R969S+3YI<TQO
M8VME9"@D:V5Y*2D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]P<F5F
M<RT^9V5T5F%L=64H)&ME>2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'9A;"`]("1T:&ES+3Y?:61E;G1I=&EE<ULD:61E;G1I='E=6R1K97E=
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1V86P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&%N(&%R<F%Y('=I=&@@=&AE('-P96-I9FEE
M9"!P<F]P97)T>2!F<F]M(&%L;"!E>&ES=&EN9PH@("`@("H@:61E;G1I=&EE
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!P<F]P
M97)T>2!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@87)R87D@=VET:"!T:&4@=F%L=65S(&9R;VT@86QL(&ED96YT:71I
M97,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06QL*"1K97DI"B`@("!["B`@
M("`@("`@)&QI<W0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?:61E;G1I=&EE<R!A<R`D:61E;G1I='D@/3X@)&YU;&PI('L*("`@("`@
M("`@("`@)&QI<W1;)&ED96YT:71Y72`]("1T:&ES+3YG971686QU92@D:V5Y
M+"`D:61E;G1I='DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&QI<W0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@<')O<&5R='D@=VET:"!A
M('-P96-I9FEE9"!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1K97D@("`@("`@(%1H92!P<F]P97)T>2!T;R!S970*("`@("`J($!P87)A
M;2!M:7AE9"`D=F%L("`@("`@("`@5&AE('9A;'5E('1O('=H:6-H('1H92!P
M<F]P97)T>2!S:&]U;&0@8F4@<V5T"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M:61E;G1I='D@(%1H92!I9&5N=&ET>2!T;R!S970@=&AE('!R;W!E<G1Y(&EN
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!F86EL=7)E("AP<F]P97)T>2!W87,@;&]C:V5D*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971686QU92@D:V5Y+"`D=F%L+"`D:61E
M;G1I='D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&ED96YT
M:71Y*2D@>PH@("`@("`@("`@("`D:61E;G1I='D@/2`D=&AI<RT^7V1E9F%U
M;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?<')E9G,M/FES
M3&]C:V5D*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:61E;G1I=&EE
M<ULD:61E;G1I='E=6R1K97E=(#T@)'9A;#L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=')U92!I9B!A;&P@<')O<&5R=&EE<R!A<F4@;&]C:V5D(&%N9"!T:&5R969O
M<F4@;F]T:&EN9R!I;B!T:&4*("`@("`J(&ED96YT:71I97,@8V%N(&)E(&-H
M86YG960N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M(&%L;"!P<F]P97)T:65S(&%R92!L;V-K960L(&9A;'-E(&]T:&5R=VES90H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<TQO8VME9"@I"B`@("!["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]P<F]P97)T:65S(&%S("1K97DI('L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7W!R969S+3YI<TQO8VME9"@D:V5Y*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=')U92!I9B!T:&4@9VEV96X@861D<F5S<R!B96QO
M;F=S('1O(&]N92!O9B!T:&4@:61E;G1I=&EE<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ED96YT:71Y(&ME>2!T;R!S96%R
M8V@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU92`@5&AE('9A;'5E('1O
M('-E87)C:"!F;W(@:6X@)&ME>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@:68@=&AE("1V86QU92!W87,@9F]U;F0@:6X@)&ME>2X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:&%S5F%L=64H)&ME>2P@)'9A;'5E02D*
M("`@('L*("`@("`@("`D;&ES="`]("1T:&ES+3YG971!;&PH)&ME>2D["B`@
M("`@("`@9F]R96%C:"`H)&QI<W0@87,@)'9A;'5E0BD@>PH@("`@("`@("`@
M("!I9B`H<W1R<&]S*%-T<FEN9SHZ;&]W97(H)'9A;'5E02DL(%-T<FEN9SHZ
M;&]W97(H)'9A;'5E0BDI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@5F5R:69I97,@
M86YD('-A;FET:7IE<R!A;&P@:61E;G1I='D@<')O<&5R=&EE<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:61E;G1I='D@(%1H92!I9&5N=&ET
M>2!T;R!V97)I9GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L?&]B:F5C
M="`@5')U92!I9B!T:&4@<')O<&5R=&EE<R!A<F4@=F%L:60@;W(@82!014%2
M7T5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!W:71H(&%N(&5R
M<F]R(&1E<V-R:7!T:6]N(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=F5R:69Y*"1I9&5N=&ET>2`](&YU;&PI"B`@("!["B`@("`@("`@:68@
M*"%I<W-E="@D:61E;G1I='DI*2!["B`@("`@("`@("`@("1I9&5N=&ET>2`]
M("1T:&ES+3Y?9&5F875L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H
M:7,M/F=E=%9A;'5E*"=I9"<L("1I9&5N=&ET>2DI('L*("`@("`@("`@("`@
M)'1H:7,M/G-E=%9A;'5E*"=I9"<L(%\H(E5N;F%M960B*2P@)&ED96YT:71Y
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%)&0R`R.#(R(%LS+C(N-5T@9&]E
M<R!N;W0@86QL;W<@=&AE("=<)R!C:&%R86-T97(@=&\@8F4@=7-E9"!I;B!T
M:&4*("`@("`@("`@*B!P97)S;VYA;"!P;W)T:6]N(&]F(&%N(&4M;6%I;"!S
M=')I;F<N("HO"B`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^9V5T5F%L=64H
M)V9U;&QN86UE)RP@)&ED96YT:71Y*2P@)UQ<)RD@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(EEO=2!C86YN
M;W0@:&%V92!T:&4@)UQ<)R!C:&%R86-T97(@:6X@>6]U<B!F=6QL(&YA;64N
M(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'96YE<F%T97,@=&AE(&9R;VT@861D<F5S<R!T;R!U
M<V4@9F]R('1H92!D969A=6QT(&ED96YT:71Y+@H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("1F=6QL;F%M92`@26YC;'5D92!T:&4@9G5L;&YA;64@
M:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!D969A=6QT(&9R;VT@861D<F5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T1&5F875L=$9R;VU!9&1R97-S*"1F=6QL;F%M92`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1F<F]M7V%D9'(@/2`G)SL*"B`@("`@("`@:68@*"1F=6QL
M;F%M92D@>PH@("`@("`@("`@("`D;F%M92`]("1T:&ES+3YG971686QU92@G
M9G5L;&YA;64G*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D;F%M92DI('L*
M("`@("`@("`@("`@("`@("1F<F]M7V%D9'(@/2`D;F%M92`N("<@)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&%D9'(@/2`D=&AI<RT^
M9V5T5F%L=64H)V9R;VU?861D<B<I.PH@("`@("`@(&EF("AE;7!T>2@D861D
M<BDI('L*("`@("`@("`@("`@)&%D9'(@/2!!=71H.CIG971!=71H*"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&9R;VU?861D<B`N("<\)R`N("1A
M9&1R("X@)SXG.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@8V]N8W)E=&4@261E;G1I='D@:6YS=&%N8V4@8F%S960@;VX@
M)'1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1T>7!E("`@5&AE
M('1Y<&4@;V8@8V]N8W)E=&4@261E;G1I='D@<W5B8VQA<W,@=&\@<F5T=7)N
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@5&AI<R!I<R!B87-E9"!O
M;B!T:&4@<W1O<F%G92!D<FEV97(@*"1T>7!E*2X@5&AE"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("!C;V1E(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D
M+B!)9B`D='EP92!I<R!A;B!A<G)A>2P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@('1H96X@=V4@=VEL;"!L;V]K(&EN("1T>7!E6S!=+VQI8B])9&5N
M=&ET>2\@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&4@<W5B
M8VQA<W,@:6UP;&5M96YT871I;VX@;F%M960@)'1Y<&5;,5TN<&AP+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@268@<W!E8VEF:65D+"!W92!R96%D
M(&%N;W1H97(@=7-E<B=S(&ED96YT:71I97,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@(&EN<W1E860@;V8@=&AE(&-U<G)E;G0@=7-E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N($ED96YT:71Y("!4:&4@;F5W;'D@8W)E871E9"!C
M;VYC<F5T92!)9&5N=&ET>2!I;G-T86YC92P@;W(@9F%L<V4*("`@("`J("`@
M("`@("`@("`@("`@("`@(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC
M=&EO;B`F9F%C=&]R>2@D='EP92`]("=N;VYE)RP@)'5S97(@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D='EP92DI('L*("`@("`@("`@
M("`@)&%P<"`]("1T>7!E6S!=.PH@("`@("`@("`@("`D='EP92`]("1T>7!E
M6S%=.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&$@8F%S92!)9&5N
M=&ET>2!O8FIE8W0@:68@;F\@9')I=F5R(&ES('-P96-I9FEE9"X@*B\*("`@
M("`@("`D='EP92`](&)A<V5N86UE*"1T>7!E*3L*("`@("`@("!I9B`H96UP
M='DH)'1Y<&4I('Q\("AS=')C;7`H)'1Y<&4L("=N;VYE)RD@/3T@,"DI('L*
M("`@("`@("`@("`@)&EN<W1A;F-E(#T@)FYE=R!)9&5N=&ET>2@D=7-E<BD[
M"B`@("`@("`@("`@("1I;G-T86YC92T^:6YI="@I.PH@("`@("`@("`@("!R
M971U<FX@)&EN<W1A;F-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T
M>2@D87!P*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+TED
M96YT:71Y+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@("!](&5L<V5I9B`H
M0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R])9&5N=&ET>2\G
M("X@)'1Y<&4@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O261E;G1I='DO)R`N("1T>7!E("X@
M)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@($!I;F-L=61E
M7V]N8V4@)TAO<F1E+TED96YT:71Y+R<@+B`D='EP92`N("<N<&AP)SL*("`@
M("`@("!]"B`@("`@("`@)&-L87-S(#T@)TED96YT:71Y7R<@+B`D='EP93L*
M("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@
M("`@)&EN<W1A;F-E(#T@)FYE=R`D8VQA<W,H)'5S97(I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#
M;&%S<R!D969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG
M*3L*("`@("`@("!]"@H@("`@("`@("1I;G-T86YC92T^:6YI="@I.PH@("`@
M("`@(')E='5R;B`D:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!)
M9&5N=&ET>2!I;G-T86YC92!B87-E9"!O;@H@("`@("H@)'1Y<&4N($ET('=I
M;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@;F\@261E;G1I='D@
M:6YS=&%N8V4@=VET:`H@("`@("H@=&AE('-A;64@<&%R86UE=&5R<R!C=7)R
M96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E('5S
M960@:68@;75L=&EP;&4@='EP97,@;V8@:61E;G1I=&EE<R`H86YD+"!T:'5S
M+`H@("`@("H@;75L=&EP;&4@261E;G1I='D@:6YS=&%N8V5S*2!A<F4@<F5Q
M=6ER960N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O
M:V5D(&%S.B`D=F%R(#T@)DED96YT:71Y.CIS:6YG;&5T;VXH*0H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D='EP92`@(%1H92!T>7!E(&]F(&-O;F-R
M971E($ED96YT:71Y('-U8F-L87-S('1O(')E='5R;BX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@(%1H:7,@:7,@8F%S960@;VX@=&AE('-T;W)A9V4@
M9')I=F5R("@D='EP92DN(%1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@8V]D92!I<R!D>6YA;6EC86QL>2!I;F-L=61E9"X@268@)'1Y<&4@:7,@
M86X@87)R87DL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!T:&5N('=E
M('=I;&P@;&]O:R!I;B`D='EP95LP72]L:6(O261E;G1I='DO(&9O<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@=&AE('-U8F-L87-S(&EM<&QE;65N
M=&%T:6]N(&YA;65D("1T>7!E6S%=+G!H<"X*("`@("`J($!P87)A;2!S=')I
M;F<@)'5S97(@($EF('-P96-I9FEE9"P@=V4@<F5A9"!A;F]T:&5R('5S97(G
M<R!I9&5N=&ET:65S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I;G-T
M96%D(&]F('1H92!C=7)R96YT('5S97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!)9&5N=&ET>2`@5&AE(&-O;F-R971E($ED96YT:71Y(')E9F5R96YC92P@
M;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S
M:6YG;&5T;VXH)'1Y<&4@/2`G;F]N92<L("1U<V5R(#T@;G5L;"D*("`@('L*
M("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T
M*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A
M>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ
M92AA<G)A>2@D='EP92P@)'5S97(I*3L*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@("1I;G-T86YC
M97-;)'-I9VYA='5R95T@/2`F261E;G1I='DZ.F9A8W1O<GDH)'1Y<&4L("1U
M<V5R*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S6R1S
M:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N
M3V)J96-T<RYP:'``````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M-34R-B`Q,#4Q-30S-#$T,2`P,C,P,3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]3
M97-S:6]N3V)J96-T<SHZ(&-L87-S('!R;W9I9&5S(&$@=V%Y(&9O<B!S=&]R
M:6YG(&1A=&$*("H@*'5S=6%L;'DL(&)U="!N;W0@;F5C97-S87)I;'DL(&]B
M:F5C=',I(&EN('1H92!C=7)R96YT('5S97(G<PH@*B!S97-S:6]N+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]397-S:6]N3V)J96-T<R]397-S:6]N3V)J
M96-T<RYP:'`L=B`Q+C8N,3(N."`R,#`V+S`Q+S`Q(#(Q.C(X.C,U(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=7$*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN
M8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?4V5S<VEO;D]B:F5C
M=',*("HO"F-L87-S($AO<F1E7U-E<W-I;VY/8FIE8W1S('L*"B`@("`O*BH*
M("`@("`J(%1H92!L:7-T(&]F(&]I9',@=&\@<')U;F4@870@=&AE(&5N9"!O
M9B!A(')E<75E<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P<G5N94QI<W0@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(&YA;64@;V8@=&AE('-T;W)E+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VYA;64@/2`G:&]R9&5?<V5S<VEO;E]O
M8FIE8W1S)SL*"B`@("`O*BH*("`@("`J($%L;&]W('-T;W)E*"D@=&\@;W9E
M<G=R:71E(&-U<G)E;G0@;V)J96-T<S\*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1?;W9E<G=R:71E(#T@9F%L<V4["@H@
M("`@+RHJ"B`@("`@*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@;V)J96-T<R!T
M:&%T('1H92!S=&]R92!S:&]U;&0@:&]L9"X*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?<VEZ92`](#(P.PH*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L($AO
M<F1E7U-E<W-I;VY/8FIE8W1S(&]B:F5C="P*("`@("`J(&]N;'D@8W)E871I
M;F<@:70@:68@:70@9&]E<VXG="!A;')E861Y(&5X:7-T+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&UU<W0@8F4@:6YV;VME9"!A<SH*("`@("`J("`@
M)&]B:F5C='-T;W)E(#T@)DAO<F1E7U-E<W-I;VY/8FIE8W1S.CIS:6YG;&5T
M;VXH*3L*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U-E<W-I;VY/8FIE
M8W1S("!4:&4@2&]R9&5?4V5S<VEO;D]B:F5C=',@:6YS=&%N8V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T
M871I8R`D;V)J96-T.PH*("`@("`@("!I9B`H(6ES<V5T*"1O8FIE8W0I*2![
M"B`@("`@("`@("`@("1O8FIE8W0@/2!N97<@2&]R9&5?4V5S<VEO;D]B:F5C
M=',H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;V)J96-T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97(@87)R87DN"B`@
M("`@*B`\<')E/@H@("`@("H@3W!T:6]N86P@4&%R86UE=&5R<SH*("`@("`J
M("=N86UE)R`@+2T@(%1H92!N86UE(&]F('1H92!S97-S:6]N('9A<FEA8FQE
M('1O('-T;W)E('1H92!O8FIE8W1S(&EN+@H@("`@("H@)W-I>F4G("`M+2`@
M5&AE(&UA>&EM=6T@<VEZ92!O9B!T:&4@*&YO;BUP<G5N86)L92D@;V)J96-T
M('-T;W)E+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7U-E<W-I;VY/8FIE8W1S*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("AI<W-E="@D<&%R86US6R=N86UE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?;F%M92`]("1P87)A;7-;)VYA;64G73L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=S:7IE)UTI("8F(&ES7VEN
M="@D<&%R86US6R=S:7IE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VEZ
M92`]("1P87)A;7-;)W-I>F4G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!7<F%P<&5R(&%R;W5N9"!S=&]R92!T:&%T('=I;&P@<F5T=7)N
M('1H92!O:60@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`<V5E('-T;W)E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@("!4:&4@9&%T82!T
M;R!S=&]R92!I;B!T:&4@<V5S<VEO;B!S=&]R92X*("`@("`J($!P87)A;2!B
M;V]L96%N("1P<G5N92`@268@9F%L<V4L('1H:7,@;V)J96-T('=I;&P@;F]T
M(&)E('!R=6YE9"!F<F]M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("!S=&]R92!I9B!T:&4@;6%X:6UU;2!S=&]R92!S:7IE(&ES(&5X8V5E
M9&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@340U('-T
M<FEN9R!R97!R97-E;G1I;F<@=&AE(&]B:F5C="=S($E$+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S=&]R94]I9"@D9&%T82P@)'!R=6YE(#T@=')U92D*("`@
M('L*("`@("`@("`D;VED(#T@)'1H:7,M/F]I9"@D9&%T82D["B`@("`@("`@
M)'1H:7,M/G-T;W)E*"1O:60L("1D871A+"`D<')U;F4I.PH@("`@("`@(')E
M='5R;B`D;VED.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<W1O<F4@86X@;V)J96-T(&EN('1H92!S97-S:6]N('-T;W)E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&]I9"`@("`@3V)J96-T($E$('5S960@
M87,@=&AE('-T;W)A9V4@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A
M("`@("!4:&4@9&%T82!T;R!S=&]R92!I;B!T:&4@<V5S<VEO;B!S=&]R92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1P<G5N92`@268@9F%L<V4L('1H:7,@
M;V)J96-T('=I;&P@;F]T(&)E('!R=6YE9"!F<F]M('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!S=&]R92!I9B!T:&4@;6%X:6UU;2!S=&]R
M92!S:7IE(&ES(&5X8V5E9&5D+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S=&]R92@D;VED+"`D9&%T82P@)'!R=6YE(#T@
M=')U92D*("`@('L*("`@("`@("`O*B!3970@=7`@;V)J96-T(&YO=RX@*B\*
M("`@("`@("`D9&%T84]B:F5C="`](&%R<F%Y*"D["B`@("`@("`@)&1A=&%/
M8FIE8W1;)V1A=&$G72`]('-E<FEA;&EZ92@D9&%T82D["B`@("`@("`@)&1A
M=&%/8FIE8W1;)W!R=6YE)UT@/2`D<')U;F4["@H@("`@("`@(&EF("@A:7-S
M970H)%]315-324].6R1T:&ES+3Y?;F%M95TI*2!["B`@("`@("`@("`@("1?
M4T534TE/3ELD=&AI<RT^7VYA;65=(#T@87)R87DH*3L*("`@("`@("`@("`@
M)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72`](#`["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]O=F5R=W)I=&4@?'P@(6ES<V5T
M*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1O:61=*2D@>PH@("`@("`@("`@
M("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD;VED72`]("1D871A3V)J96-T
M.PH@("`@("`@("`@("!I9B`H)'!R=6YE*2!["B`@("`@("`@("`@("`@("`D
M7U-%4U-)3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==*RL["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-H96-K(&9O<B!P<G5N86)L
M92!/:61S+B`J+PH@("`@("`@("1T:&ES+3Y?<')U;F5/:61S*"D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@3W9E<G=R
M:71E<R!A(&-U<G)E;G0@96QE;65N="!I;B!T:&4@;V)J96-T('-T;W)E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]I9"`@("`@3V)J96-T($E$
M('5S960@87,@=&AE('-T;W)A9V4@:V5Y+@H@("`@("H@0'!A<F%M(&UI>&5D
M("1D871A("`@("!4:&4@9&%T82!T;R!S=&]R92!I;B!T:&4@<V5S<VEO;B!S
M=&]R92X*("`@("`J($!P87)A;2!B;V]L96%N("1P<G5N92`@268@9F%L<V4L
M('1H:7,@;V)J96-T('=I;&P@;F]T(&)E('!R=6YE9"!F<F]M('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("!S=&]R92!I9B!T:&4@;6%X:6UU
M;2!S=&]R92!S:7IE(&ES(&5X8V5E9&5D+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!O=F5R=W)I=&4H)&]I9"P@)&1A=&$L
M("1P<G5N92`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=F5R=W)I
M=&4@/2!T<G5E.PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/G-T;W)E*"1O
M:60L("1D871A+"`D<')U;F4I.PH@("`@("`@("1T:&ES+3Y?;W9E<G=R:71E
M(#T@9F%L<V4["B`@("`@("`@<F5T=7)N("1S=6-C97-S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEV92!A;B!O8FIE8W0@9G)O
M;2!T:&4@<W1O<F4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VED
M("`@3V)J96-T($E$('1O('%U97)Y+@H@("`@("H@0'!A<F%M(&5N=6T@)'1Y
M<&4@("`@3D]4(%53140*("`@("`J($!P87)A;2!I;G1E9V5R("1V86P@($Y/
M5"!54T5$"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<75E
M<W1E9"!O8FIE8W0L(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9Q=65R>2@D;VED+"`D='EP92`](&YU;&PL("1V86P@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)%]315-324].6R1T:&ES
M+3Y?;F%M95TI('Q\"B`@("`@("`@("`@("AI<U]N=6QL*"1O:60I('Q\("%I
M<W-E="@D7U-%4U-)3TY;)'1H:7,M/E]N86UE75LD;VED72DI*2!["B`@("`@
M("`@("`@("1O8FIE8W0@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;V)J96-T(#T@=6YS97)I86QI>F4H)%]315-324].6R1T:&ES
M+3Y?;F%M95U;)&]I9%U;)V1A=&$G72D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D;V)J96-T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@
M<')U;F4@9FQA9R!O;B!A('-T;W)E(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1O:60@("`@(%1H92!O8FIE8W0@240N"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D<')U;F4@(%1R=64@=&\@86QL;W<@<')U;FEN9RP@
M9F%L<V4@9F]R(&YO('!R=6YI;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=%!R=6YE1FQA9R@D;VED+"`D<')U;F4I"B`@("!["B`@("`@("`@:68@*&ES
M<V5T*"1?4T534TE/3ELD=&AI<RT^7VYA;65=6R1O:61=*2`F)@H@("`@("`@
M("`@("`H)%]315-324].6R1T:&ES+3Y?;F%M95U;)&]I9%U;)W!R=6YE)UT@
M(3T@)'!R=6YE*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N
M86UE75LD;VED75LG<')U;F4G72`]("1P<G5N93L*("`@("`@("`@("`@:68@
M*"1P<G5N92D@>PH@("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?
M;F%M95U;)U]?<')U;F4G72LK.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G
M72TM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5N97)A=&5S(&%N($])1"!F;W(@86X@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D9&%T82`@5&AE(&1A=&$@=&\@<W1O<F4@
M:6X@=&AE('-T;W)E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("1O
M:60@($%N(&]B:F5C="!)1"!T;R!U<V4@87,@=&AE('-T;W)A9V4@:V5Y+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!O:60H)&1A=&$I"B`@("!["B`@("`@("`@
M<F5T=7)N(&UD-2AS97)I86QI>F4H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E;F5R871E('1H92!L:7-T(&]F('!R=6YA8FQE(&]I9',N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P<G5N94]I9',H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T
M:&ES+3Y?<')U;F5,:7-T*2`F)@H@("`@("`@("`@("!I<W-E="@D7U-%4U-)
M3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==*2`F)@H@("`@("`@("`@("`H
M)%]315-324].6R1T:&ES+3Y?;F%M95U;)U]?<')U;F4G72`^("1T:&ES+3Y?
M<VEZ92DI('L*("`@("`@("`@("`@)'1H:7,M/E]P<G5N94QI<W0@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!F;W)E86-H("@D7U-%4U-)3TY;)'1H:7,M/E]N
M86UE72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@D
M=F%L6R=P<G5N92==*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M<G5N94QI<W1;72`]("1K97D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH
M87)R87DH)B1T:&ES+"`G7W!R=6YE)RDI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%!R=6YE(&]L9"!S=&]R92!E;G1R:65S(&%T(')E<75E
M<W0@<VAU=&1O=VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]P<G5N92@I"B`@("!["B`@("`@("`@)'!R
M=6YE3VED<R`](&%R<F%Y7W-L:6-E*"1T:&ES+3Y?<')U;F5,:7-T+"`P+"`D
M7U-%4U-)3TY;)'1H:7,M/E]N86UE75LG7U]P<G5N92==("T@)'1H:7,M/E]S
M:7IE*3L*("`@("`@("!F;W)E86-H("@D<')U;F5/:61S(&%S("1V86PI('L*
M("`@("`@("`@("`@=6YS970H)%]315-324].6R1T:&ES+3Y?;F%M95U;)'9A
M;%TI.PH@("`@("`@('T*("`@("`@("`D7U-%4U-)3TY;)'1H:7,M/E]N86UE
M75LG7U]P<G5N92==("T](&-O=6YT*"1P<G5N94]I9',I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]"<F]W<V5R+G!H<```````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$Q,#8P-B`Q,#4Q-30S-#$T
M,2`P,C$U,#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<[
M"@HO*BH*("H@5&AE($)R;W=S97(Z.B!C;&%S<R!P<F]V:61E<R!C87!A8FEL
M:71Y(&EN9F]R;6%T:6]N(&9O<B!T:&4@8W5R<F5N=`H@*B!W96(@8VQI96YT
M+@H@*@H@*B!"<F]W<V5R(&ED96YT:69I8V%T:6]N(&ES('!E<F9O<FUE9"!B
M>2!E>&%M:6YI;F<@=&AE($A45%!?55-%4E]!1T5.5`H@*B!E;G9I<F]N;65N
M="!V87)I86)L92!P<F]V:61E9"!B>2!T:&4@=V5B('-E<G9E<BX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO0G)O=W-E<B]"<F]W<V5R+G!H<"QV(#$N,34S
M+C(N-#<@,C`P-B\P-R\Q-R`P.3HU,CHP,"!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]"<F]W<V5R"B`J+PIC;&%S<R!"<F]W<V5R('L*
M"B`@("`O*BH*("`@("`J($UA:F]R('9E<G-I;VX@;G5M8F5R+@H@("`@("H*
M("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M86IO<E9E
M<G-I;VX@/2`P.PH*("`@("\J*@H@("`@("H@36EN;W(@=F5R<VEO;B!N=6UB
M97(N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A
M<B`D7VUI;F]R5F5R<VEO;B`](#`["@H@("`@+RHJ"B`@("`@*B!"<F]W<V5R
M(&YA;64N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?8G)O=W-E<B`]("<G.PH*("`@("\J*@H@("`@("H@1G5L;"!U<V5R
M(&%G96YT('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)%]A9V5N="`]("<G.PH*("`@("\J*@H@("`@("H@3&]W
M97(M8V%S92!U<V5R(&%G96YT('-T<FEN9RX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]L;W=E<D%G96YT(#T@)R<["@H@
M("`@+RHJ"B`@("`@*B!(5%107T%#0T505"!S=')I;F<*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]A8V-E<'0@/2`G)SL*
M"B`@("`O*BH*("`@("`J(%!L871F;W)M('1H92!B<F]W<V5R(&ES(')U;FYI
M;F<@;VXN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?<&QA=&9O<FT@/2`G)SL*"B`@("`O*BH*("`@("`J($MN;W=N(')O
M8F]T<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W)O8F]T<R`](&%R<F%Y*`H@("`@("`@("\J(%1H92!M;W-T(&-O;6UO
M;B!O;F5S+B`J+PH@("`@("`@("=';V]G;&5B;W0G+`H@("`@("`@("=M<VYB
M;W0G+`H@("`@("`@("=3;'5R<"<L"B`@("`@("`@)UEA:&]O)RP*("`@("`@
M("`O*B!4:&4@<F5S="!A;'!H86)E=&EC86QL>2X@*B\*("`@("`@("`G87!P
M:64G+`H@("`@("`@("=!<F%C:&YO:61E82<L"B`@("`@("`@)T%R8VAI=&5X
M=%-P:61E<B<L"B`@("`@("`@)T%S:R!*965V97,G+`H@("`@("`@("="+6PM
M:2UT+7HM0F]T)RP*("`@("`@("`G0F%I9'5S<&ED97(G+`H@("`@("`@("="
M96-O;65";W0G+`H@("`@("`@("=C9F5T8V@G+`H@("`@("`@("=#;VYV97)A
M0W)A=VQE<B<L"B`@("`@("`@)T5X=')A8W1O<E!R;R<L"B`@("`@("`@)T9!
M4U0M5V5B0W)A=VQE<B<L"B`@("`@("`@)T9$4T4@<F]B;W0G+`H@("`@("`@
M("=F:61O)RP*("`@("`@("`G9FEN9&QI;FMS)RP*("`@("`@("`G1G)A;F-I
M<R<L"B`@("`@("`@)V=E8VMO8F]T)RP*("`@("`@("`G1VEG86)O="<L"B`@
M("`@("`@)T=I<F%F86)O="<L"B`@("`@("`@)V=R=6(M8VQI96YT)RP*("`@
M("`@("`G1W5L;&EV97(G+`H@("`@("`@("=(5%1R86-K)RP*("`@("`@("`G
M:6%?87)C:&EV97(G+`H@("`@("`@("=I0T-R87=L97(G+`H@("`@("`@("=)
M;F9O4V5E:R<L"B`@("`@("`@)VMI;FIA8F]T)RP*("`@("`@("`G2TE4+49I
M<F5B86QL)RP*("`@("`@("`G;&%R8FEN)RP*("`@("`@("`G3$5)02<L"B`@
M("`@("`@)VQM<W!I9&5R)RP*("`@("`@("`G;'=P+71R:79I86PG+`H@("`@
M("`@("=,>6-O<U]3<&ED97(G+`H@("`@("`@("=-961I87!A<G1N97)S+4=O
M;V=L92<L"B`@("`@("`@)TUU<V-A=$9E<G)E="<L"B`@("`@("`@)TYA=F5R
M0F]T)RP*("`@("`@("`G3VUN:45X<&QO<F5R7T)O="<L"B`@("`@("`@)W!O
M;'EB;W0G+`H@("`@("`@("=0;VUP;W,G+`H@("`@("`@("=2=69U<T)O="<L
M"B`@("`@("`@)U-C;V]T97(G+`H@("`@("`@("=3965K8F]T)RP*("`@("`@
M("`G<W!R;V]S92<L"B`@("`@("`@)U1E;VUA)RP*("`@("`@("`G5&AE4W5"
M;W0G+`H@("`@("`@("=4=7)N:71I;D)O="<L"B`@("`@("`@)U5L=')A<V5E
M:R<L"B`@("`@("`@)U9I;VQA0F]T)RP*("`@("`@("`G=F]Y86=E<B<L"B`@
M("`@("`@)W=E8F)A;F1I="<L"B`@("`@("`@)W=W=RYA;&UA9&5N+FEB;2YC
M;VTO8W,O8W)A=VQE<B<L"B`@("`@("`@)WEA8WDG+`H@("`@("`@("=:>4)O
M<F<G+`H@("`@*3L*"B`@("`O*BH*("`@("`J($ES('1H:7,@82!M;V)I;&4@
M8G)O=W-E<C\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@
M("`@=F%R("1?;6]B:6QE(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!&96%T
M=7)E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VAT;6PG("`@("`@(#T^
M('1R=64L"B`@("`@("`@)VAD;6PG("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("=W;6PG("`@("`@("`]/B!F86QS92P*("`@("`@("`G:6UA9V5S)R`@("`@
M/3X@=')U92P*("`@("`@("`G:69R86UE<R<@("`@/3X@9F%L<V4L"B`@("`@
M("`@)V9R86UE<R<@("`@(#T^('1R=64L"B`@("`@("`@)W1A8FQE<R<@("`@
M(#T^('1R=64L"B`@("`@("`@)VIA=F$G("`@("`@(#T^('1R=64L"B`@("`@
M("`@)VIA=F%S8W)I<'0G(#T^('1R=64L"B`@("`@("`@)V1O;2<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("=U=&8G("`@("`@("`]/B!F86QS92P*("`@
M("`@("`G<G1E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VAO;65P86=E
M)R`@(#T^(&9A;'-E+`H@("`@("`@("=A8V-E<W-K97DG("`]/B!F86QS92P*
M("`@("`@("`G;W!T9W)O=7`G("`@/3X@9F%L<V4L"B`@("`@("`@)WAM;&AT
M='!R97$G(#T^(&9A;'-E+`H@("`@("`@("=C:71E)R`@("`@("`]/B!F86QS
M92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!1=6ER:W,*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W%U:7)K<R`](&%R<F%Y
M*`H@("`@("`@("=A=F]I9%]P;W!U<%]W:6YD;W=S)R`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@)V)R96%K7V1I<W!O<VET:6]N7VAE861E<B<@("`]/B!F
M86QS92P*("`@("`@("`G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA;64G(#T^
M(&9A;'-E+`H@("`@("`@("=B<F]K96Y?;75L=&EP87)T7V9O<FTG("`@("`@
M/3X@9F%L<V4L"B`@("`@("`@)V)U9V=Y7V-O;7!R97-S:6]N)R`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`G8V%C:&5?<V%M95]U<FPG("`@("`@("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=C86-H95]S<VQ?9&]W;FQO861S)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@)V1O=6)L95]L:6YE8G)E86M?=&5X
M=&%R96$G("`]/B!F86QS92P*("`@("`@("`G96UP='E?9FEL95]I;G!U=%]V
M86QU92<@("`@(#T^(&9A;'-E+`H@("`@("`@("=M=7-T7V-A8VAE7V9O<FUS
M)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYO7V9I;&5N86UE7W-P
M86-E<R<@("`@("`@("`]/B!F86QS92P*("`@("`@("`G;F]?:&ED9&5N7V]V
M97)F;&]W7W1A8FQE<R<@(#T^(&9A;'-E+`H@("`@("`@("=O=U]G=6E?,2XS
M)R`@("`@("`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W!N9U]T<F%N
M<W!A<F5N8WDG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G<V-R;VQL
M8F%R7VEN7W=A>2<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S8W)O
M;&Q?=&1S)R`@("`@("`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W=I
M;F1O=V5D7V-O;G1R;VQS)R`@("`@("`@("`]/B!F86QS92P*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!,:7-T(&]F('9I97=A8FQE(&EM86=E($U)344@<W5B
M='EP97,N"B`@("`@*B!4:&ES(&QI<W0@;V8@=FEE=V%B;&4@:6UA9V5S('=O
M<FMS(&9O<B!)12!A;F0@3F5T<V-A<&4O36]Z:6QL82X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VEM86=E<R`](&%R<F%Y
M*"=J<&5G)RP@)V=I9B<L("=P;F<G+"`G<&IP96<G+"`G>"UP;F<G+"`G8FUP
M)RD["@H@("`@+RHJ"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E
M;F-E('1O('1H92!G;&]B86P@0G)O=W-E<B!O8FIE8W0L(&]N;'D@8W)E871I
M;F<@:70*("`@("`J(&EF(&ET(&1O97-N)W0@86QR96%D>2!E>&ES="X*("`@
M("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z/'!R
M93X*("`@("`J("`@)&)R;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*%LD
M=7-E<D%G96YT6RP@)&%C8V5P=%U=*3L\+W!R93X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R06=E;G0@(%1H92!B<F]W<V5R('-T<FEN9R!T
M;R!P87)S92X*("`@("`J($!P87)A;2!S=')I;F<@)&%C8V5P="`@("`@5&AE
M($A45%!?04-#15!4('-E='1I;F=S('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($)R;W=S97(@(%1H92!"<F]W<V5R(&]B:F5C="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D=7-E<D%G96YT(#T@;G5L;"P@)&%C
M8V5P="`](&YU;&PI"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC97,[
M"@H@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@("`@("`@
M("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("`D
M<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1U<V5R06=E;G0L("1A8V-E
M<'0I*3L*("`@("`@("!I9B`H96UP='DH)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`](&YE
M=R!"<F]W<V5R*"1U<V5R06=E;G0L("1A8V-E<'0I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&4@82!B<F]W<V5R(&EN<W1A;F-E("A#;VYS
M=')U8W1O<BDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<D%G
M96YT("!4:&4@8G)O=W-E<B!S=')I;F<@=&\@<&%R<V4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A8V-E<'0@("`@(%1H92!(5%107T%#0T505"!S971T:6YG
M<R!T;R!U<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N($)R;W=S97(H)'5S97)!
M9V5N="`](&YU;&PL("1A8V-E<'0@/2!N=6QL*0H@("`@>PH@("`@("`@("1T
M:&ES+3YM871C:"@D=7-E<D%G96YT+"`D86-C97!T*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%!A<G-E<R!T:&4@=7-E<B!A9V5N="!S=')I;F<@86YD(&EN
M:71I=&EA;&EZ97,@=&AE(&]B:F5C="!W:71H"B`@("`@*B!A;&P@=&AE(&MN
M;W=N(&9E871U<F5S(&%N9"!Q=6ER:W,@9F]R('1H92!G:79E;B!B<F]W<V5R
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)!9V5N="`@5&AE
M(&)R;W=S97(@<W1R:6YG('1O('!A<G-E+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D86-C97!T("`@("!4:&4@2%144%]!0T-%4%0@<V5T=&EN9W,@=&\@=7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!M871C:"@D=7-E<D%G96YT(#T@;G5L
M;"P@)&%C8V5P="`](&YU;&PI"B`@("!["B`@("`@("`@+R\@4V5T(&]U<B!A
M9V5N="!S=')I;F<N"B`@("`@("`@:68@*&ES7VYU;&PH)'5S97)!9V5N="DI
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=(5%107U5315)?
M04=%3E0G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?86=E;G0@/2!T
M<FEM*"1?4T525D526R=(5%107U5315)?04=%3E0G72D["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V%G96YT
M(#T@)'5S97)!9V5N=#L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L;W=E
M<D%G96YT(#T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^7V%G96YT*3L*"B`@("`@
M("`@+R\@4V5T(&]U<B!A8V-E<'0@<W1R:6YG+@H@("`@("`@(&EF("AI<U]N
M=6QL*"1A8V-E<'0I*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%
M4ELG2%144%]!0T-%4%0G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M86-C97!T(#T@4W1R:6YG.CIL;W=E<BAT<FEM*"1?4T525D526R=(5%107T%#
M0T505"==*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%C8V5P="`](%-T<FEN9SHZ;&]W97(H)&%C8V5P
M="D["B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!F;W(@551&('-U<'!O
M<G0N"B`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=(5%107T%#0T505%]#
M2$%24T54)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U
M=&8G+"!S=')P;W,H4W1R:6YG.CIL;W=E<B@D7U-%4E9%4ELG2%144%]!0T-%
M4%1?0TA!4E-%5"==*2P@)W5T9B<I("$]/2!F86QS92D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?86=E;G0I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<V5T4&QA=&9O<FTH*3L*"B`@("`@("`@("`@(&EF("AS
M=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G;6]B:6QE97AP;&]R97(G*2`A
M/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^7VQO
M=V5R06=E;G0L("=O<&5N=V%V92<I("$]/2!F86QS92!\?`H@("`@("`@("`@
M("`@("`@<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V]P97)A(&UI;FDG
M*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@('-T<G!O<R@D=&AI<RT^
M7VQO=V5R06=E;G0L("=O<&5R86UI;FDG*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=F<F%M97,G+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP
M="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G
M879O:61?<&]P=7!?=VEN9&]W<R<I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M;V)I;&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M
M871C:"@G?$]P97)A6R\@72A;,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D
M=F5R<VEO;BDI('L*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971"
M<F]W<V5R*"=O<&5R82<I.PH@("`@("`@("`@("`@("`@("`@("`@;&ES="@D
M=&AI<RT^7VUA:F]R5F5R<VEO;BP@)'1H:7,M/E]M:6YO<E9E<G-I;VXI(#T@
M97AP;&]D92@G+B<L("1V97)S:6]N6S%=*3L*("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@=')U92D["B`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)VYO7V9I;&5N
M86UE7W-P86-E<R<I.PH*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VUA
M:F]R5F5R<VEO;B`^/2`W*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$9E871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U<"<I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G9&]U8FQE7VQI;F5B<F5A
M:U]T97AT87)E82<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?;&]W97)!9V5N="P@)V5L86EN92\G
M*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D
M=&AI<RT^7VQO=V5R06=E;G0L("=P86QM<V]U<F-E)RD@(3T](&9A;'-E('Q\
M"B`@("`@("`@("`@("`@("`@("`@("!S=')P;W,H)'1H:7,M/E]L;W=E<D%G
M96YT+"`G9&EG:71A;"!P871H<R<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$)R;W=S97(H)W!A;&TG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=I;6%G97,G+"!F86QS92D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G9G)A;65S)RP@9F%L<V4I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I
M<'0G+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH
M)V%V;VED7W!O<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"AP<F5G
M7VUA=&-H*"=\35-)12`H6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E
M<G-I;VXI*2!\?`H@("`@("`@("`@("`@("`@("`@("`@*'!R96=?;6%T8V@H
M)WQ);G1E<FYE="!%>'!L;W)E<B\H6S`M.2Y=*RE\)RP@)'1H:7,M/E]A9V5N
M="P@)'9E<G-I;VXI*2D@>PH*("`@("`@("`@("`@("`@("1T:&ES+3YS971"
M<F]W<V5R*"=M<VEE)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I
M<FLH)V-A8VAE7W-S;%]D;W=N;&]A9',G*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3YS9711=6ER:R@G8V%C:&5?<V%M95]U<FPG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS9711=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?9FEL96YA
M;64G*3L*"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V97)S:6]N6S%=
M+"`G+B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H
M)'1H:7,M/E]M86IO<E9E<G-I;VXL("1T:&ES+3Y?;6EN;W)697)S:6]N*2`]
M(&5X<&QO9&4H)RXG+"`D=F5R<VEO;ELQ72D["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%J;W)697)S
M:6]N(#T@)'9E<G-I;VY;,5T["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M:6YO<E9E<G-I;VX@/2`P.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("\J($E%("@\(#<I(&]N(%=I;F1O=W,@9&]E<R!N;W0@<W5P
M<&]R="!A;'!H82!T<F%N<W!A<F5N8WD@:6X*("`@("`@("`@("`@("`@("`J
M(%!.1R!I;6%G97,N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1T:&ES+3Y?
M;6%J;W)697)S:6]N(#P@-RD@)B8*("`@("`@("`@("`@("`@("`@("!P<F5G
M7VUA=&-H*"<O=VEN9&]W<R]I)RP@)'1H:7,M/E]A9V5N="DI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)W!N9U]T<F%N<W!A<F5N
M8WDG*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!)
M12`V("AP<F4M4U`Q*2!A;F0@-2XU("AP<F4M4U`Q*2!H879E(&)U9V=Y(&-O
M;7!R97-S:6]N+@H@("`@("`@("`@("`@("`@("H@5&AE('9E<G-I;VYS(&%F
M9F5C=&5D(&%R92!A<R!F;VQL;W=S.@H@("`@("`@("`@("`@("`@("H@-BXP
M,"XR-#8R+C`P,#`@($EN=&5R;F5T($5X<&QO<F5R(#8@4'5B;&EC(%!R979I
M97<@*$)E=&$I"B`@("`@("`@("`@("`@("`@*B`V+C`P+C(T-SDN,#`P-B`@
M26YT97)N970@17AP;&]R97(@-B!0=6)L:6,@4')E=FEE=R`H0F5T82D*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4F5F<F5S:`H@("`@
M("`@("`@("`@("`@("H@-BXP,"XR-C`P+C`P,#`@($EN=&5R;F5T($5X<&QO
M<F5R(#8@*%=I;F1O=W,@6%`I"B`@("`@("`@("`@("`@("`@*B`U+C4P+C,X
M,C4N,3,P,"`@26YT97)N970@17AP;&]R97(@-2XU($1E=F5L;W!E<B!0<F5V
M:65W("A"971A*0H@("`@("`@("`@("`@("`@("H@-2XU,"XT,#,P+C(T,#`@
M($EN=&5R;F5T($5X<&QO<F5R(#4N-2`F($EN=&5R;F5T(%1O;VQS($)E=&$*
M("`@("`@("`@("`@("`@("`J(#4N-3`N-#$S-"XP,3`P("!);G1E<FYE="!%
M>'!L;W)E<B`U+C4@9F]R(%=I;F1O=W,@364@*#0N.3`N,S`P,"D*("`@("`@
M("`@("`@("`@("`J(#4N-3`N-#$S-"XP-C`P("!);G1E<FYE="!%>'!L;W)E
M<B`U+C4*("`@("`@("`@("`@("`@("`J(#4N-3`N-#,P."XR.3`P("!);G1E
M<FYE="!%>'!L;W)E<B`U+C4@061V86YC960@4V5C=7)I='D@4')I=F%C>2!"
M971A"B`@("`@("`@("`@("`@("`@*@H@("`@("`@("`@("`@("`@("H@4V5E
M.@H@("`@("`@("`@("`@("`@("H@/3T]/0H@("`@("`@("`@("`@("`@("H@
M:'1T<#HO+W-U<'!O<G0N;6EC<F]S;V9T+F-O;2]K8B\Q-C0U,SD["B`@("`@
M("`@("`@("`@("`@*B!H='1P.B\O<W5P<&]R="YM:6-R;W-O9G0N8V]M+V1E
M9F%U;'0N87-P>#]S8VED/6MB.V5N+75S.U$S,3(T.38I"B`@("`@("`@("`@
M("`@("`@*B!H='1P.B\O<W5P<&]R="YM:6-R;W-O9G0N8V]M+V1E9F%U;'0N
M87-P>#]S8VED/6MB.V5N+75S.U$S,3,W,3(*("`@("`@("`@("`@("`@("`J
M+PH@("`@("`@("`@("`@("`@)&EE7W9E<G,@/2`D=&AI<RT^9V5T245697)S
M:6]N*"D["B`@("`@("`@("`@("`@("`D8G5G9WE?;&ES="`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("<V+#`P+#(T-C(L,#`P,"<L("<V+#`P+#(T
M-SDL,#`P-B<L("<V+#`P+#(V,#`L,#`P,"<L"B`@("`@("`@("`@("`@("`@
M("`@)S4L-3`L,S@R-2PQ,S`P)RP@)S4L-3`L-#`S,"PR-#`P)RP@)S4L-3`L
M-#$S-"PP,3`P)RP*("`@("`@("`@("`@("`@("`@("`G-2PU,"PT,3,T+#`V
M,#`G+"`G-2PU,"PT,S`X+#(Y,#`G"B`@("`@("`@("`@("`@("`I.PH@("`@
M("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1I95]V97)S*2`F)B!I;E]A<G)A
M>2@D:65?=F5R<RP@)&)U9V=Y7VQI<W0I*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%%U:7)K*"=B=6=G>5]C;VUP<F5S<VEO;B<I.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J(%-O;64@2&%N9&AE
M;&1S(&AA=F4@=&AE:7(@<V-R965N(')E<V]L=71I;VX@:6X@=&AE"B`@("`@
M("`@("`@("`@("`@*B!U<V5R(&%G96YT('-T<FEN9RP@=VAI8V@@=V4@8V%N
M('5S92!T;R!L;V]K(&9O<@H@("`@("`@("`@("`@("`@("H@;6]B:6QE(&%G
M96YT<RX@*B\*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O.R`H
M,3(P>#$V,'PR-#!X,C@P?#(T,'@S,C!\,S(P>#,R,"E<*2\G+"`D=&AI<RT^
M7V%G96YT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE
M(#T@=')U93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!S
M=VET8V@@*"1T:&ES+3Y?;6%J;W)697)S:6]N*2!["B`@("`@("`@("`@("`@
M("!C87-E(#<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)VIA=F%S8W)I<'0G+"`Q+C0I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=D;VTG*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T1F5A='5R92@G:69R86UE<R<I.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1F5A='5R92@G<G1E)RD["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAO;65P86=E)RD["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U
M<"<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X
M;6QH='1P<F5Q)RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("`@("`@8V%S92`V.@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=71F)RD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W)T92<I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H;VUE<&%G92<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=A8V-E
M<W-K97DG*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R
M92@G;W!T9W)O=7`G*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G>&UL:'1T<')E<2<I.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS9711=6ER:R@G<V-R;VQL8F%R7VEN7W=A>2<I.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YS9711=6ER:R@G8G)O:V5N7VUU;'1I<&%R=%]F
M;W)M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=W
M:6YD;W=E9%]C;VYT<F]L<R<I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@(&-A<V4@-3H*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/F=E=%!L871F;W)M*"D@/3T@)VUA8R<I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I
M<'0G+"`Q+C(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G;W!T9W)O=7`G*3L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!-4TE%(#4@9F]R(%=I
M;F1O=W,N"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T
M=7)E*"=J879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=$9E871U<F4H)V1O;2<I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&UL:'1T<')E<2<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]M:6YO<E9E<G-I;VX@
M/CT@-2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)W)T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=%%U:7)K*"=W:6YD;W=E9%]C;VYT<F]L<R<I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I9G)A;65S)RD[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H;VUE
M<&%G92<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E
M*"=A8V-E<W-K97DG*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]M:6YO<E9E<G-I;VX@/3T@-2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T475I<FLH)V)R96%K7V1I<W!O<VET:6]N7VAE861E<B<I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)R
M;VME;E]M=6QT:7!A<G1?9F]R;2<I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C
M87-E(#0Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H
M)VIA=F%S8W)I<'0G+"`Q+C(I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=A8V-E<W-K97DG*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]M:6YO<E9E<G-I;VX@/B`P*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=U=&8G*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`S.@H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XQ*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V;VED7W!O<'5P7W=I;F1O
M=W,G*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)WQ!3E1&
M<F5S8V\O*%LP+3E=*RE\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G9G)E<V-O)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP
M="<L(#$N,2D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V%V
M;VED7W!O<'5P7W=I;F1O=W,G*3L*("`@("`@("`@("`@?2!E;'-E:68@*'-T
M<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=A=F%N=&=O)RD@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G879A;G1G
M;R<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M;V)I;&4@/2!T<G5E.PH@
M("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?$MO;G%U97)O<B\H
M6S`M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BD@?'P*("`@("`@
M("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)WQ3869A<FDO*%LP+3E=*RE<
M+C\H6S`M.5TK*3]\)RP@)'1H:7,M/E]A9V5N="P@)'9E<G-I;VXI*2!["B`@
M("`@("`@("`@("`@("`O+R!+;VYQ=65R;W(@86YD($%P<&QE)W,@4V%F87)I
M(&)O=&@@=7-E('1H92!+2%1-3`H@("`@("`@("`@("`@("`@+R\@<F5N9&5R
M:6YG(&5N9VEN92X*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R
M*"=K;VYQ=65R;W(G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER
M:R@G96UP='E?9FEL95]I;G!U=%]V86QU92<I.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E=%%U:7)K*"=N;U]H:61D96Y?;W9E<F9L;W=?=&%B;&5S)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:F]R5F5R<VEO;B`]("1V97)S
M:6]N6S%=.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V97)S:6]N6S)=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6EN;W)697)S:6]N
M(#T@)'9E<G-I;VY;,ET["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G4V%F87)I)RD@(3T]
M(&9A;'-E("8F"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M86IO<E9E
M<G-I;VX@/CT@-C`I('L*("`@("`@("`@("`@("`@("`@("`O+R!3869A<FDN
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)W5T9B<I
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A
M<V-R:7!T)RP@,2XT*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]M86IO<E9E<G-I;VX@/B`Q,C4@?'P*("`@("`@("`@("`@("`@
M("`@("`@("`@*"1T:&ES+3Y?;6%J;W)697)S:6]N(#T](#$R-2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M:6YO<E9E<G-I;VX@/CT@
M,2DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)V%C8V5S<VME>2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G>&UL:'1T<')E<2<I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@+R\@2V]N<75E<F]R+@H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XQ*3L*("`@("`@("`@("`@
M("`@("`@("!S=VET8V@@*"1T:&ES+3Y?;6%J;W)697)S:6]N*2!["B`@("`@
M("`@("`@("`@("`@("`@8V%S92`S.@H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971&96%T=7)E*"=I9G)A;65S)RD["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?
M;6%T8V@H)WQ-;WII;&QA+RA;,"TY+ETK*7PG+"`D=&AI<RT^7V%G96YT+"`D
M=F5R<VEO;BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R
M*"=M;WII;&QA)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH
M)VUU<W1?8V%C:&5?9F]R;7,G*3L*"B`@("`@("`@("`@("`@("!L:7-T*"1T
M:&ES+3Y?;6%J;W)697)S:6]N+"`D=&AI<RT^7VUI;F]R5F5R<VEO;BD@/2!E
M>'!L;V1E*"<N)RP@)'9E<G-I;VY;,5TI.PH@("`@("`@("`@("`@("`@<W=I
M=&-H("@D=&AI<RT^7VUA:F]R5F5R<VEO;BD@>PH@("`@("`@("`@("`@("`@
M8V%S92`U.@H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T4&QA
M=&9O<FTH*2`]/2`G=VEN)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V5T475I<FLH)V)R96%K7V1I<W!O<VET:6]N7V9I;&5N86UE)RD[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@,2XT*3L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G9&]M)RD["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)V%C8V5S<VME>2<I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=O<'1G<F]U
M<"<I.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=X
M;6QH='1P<F5Q)RD["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)V-I=&4G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G?')V.B@N*BE<*7PG+"`D=&AI<RT^7V%G96YT+"`D<F5V:7-I;VXI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5V:7-I;VY;,5T@
M/CT@,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)VEF<F%M97,G*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E=FES:6]N6S%=(#X]
M(#$N,RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)W)T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(#$N,RD["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%%U:7)K*"=B=6=G>5]C;VUP<F5S
M<VEO;B<I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VIA=F%S8W)I<'0G
M+"`Q*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I<FLH)V)U
M9V=Y7V-O;7!R97-S:6]N)RD["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("AP<F5G
M7VUA=&-H*"=\3'EN>"\H6S`M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R
M<VEO;BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=L
M>6YX)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:6UA
M9V5S)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U
M<F4H)V9R86UE<R<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%%U:7)K*"=A=F]I9%]P;W!U<%]W:6YD;W=S)RD["B`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"=\3&EN:W,@7"@H6S`M
M.5TK*7PG+"`D=&AI<RT^7V%G96YT+"`D=F5R<VEO;BDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=L:6YK<R<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEM86=E<R<L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=F<F%M97,G+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C
M<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS9711=6ER
M:R@G879O:61?<&]P=7!?=VEN9&]W<R<I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H<')E9U]M871C:"@G?$AO=$IA=F$O*%LP+3E=*RE\)RP@)'1H:7,M/E]A
M9V5N="P@)'9E<G-I;VXI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T
M0G)O=W-E<B@G:&]T:F%V82<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)VIA=F%S8W)I<'0G+"!F86QS92D["B`@("`@("`@("`@('T@
M96QS96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)U50+R<I("$]/2!F86QS
M92!\?`H@("`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1T:&ES+3Y?86=E
M;G0L("=54"Y")RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`@("`@
M("!S=')P;W,H)'1H:7,M/E]A9V5N="P@)U50+DPG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=U<"<I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP
M="<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E
M*"=H9&UL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G
M=VUL)RD["@H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7V%G
M96YT+"`G1U5))RD@(3T](&9A;'-E("8F"B`@("`@("`@("`@("`@("`@("`@
M<W1R<&]S*"1T:&ES+3Y?86=E;G0L("=54"Y,:6YK)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("`@("`@+RH@5&AE(&1E=FEC92!A8V-E<'1S($]P
M96YW879E($=522!E>'1E;G-I;VYS(&9O<@H@("`@("`@("`@("`@("`@("`@
M("`J(%=-3"`Q+C,N($YO;BU54"Y,:6YK(&=A=&5W87ES('-O;65T:6UE<R!H
M879E"B`@("`@("`@("`@("`@("`@("`@("H@<')O8FQE;7,L('-O(&5X8VQU
M9&4@=&AE;2X@*B\*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T475I
M<FLH)V]W7V=U:5\Q+C,G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G6&EI;F\O)RD@(3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G>&EI
M;F\G*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL
M)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@
M("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)U!A;&US
M8V%P92\G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS
M971"<F]W<V5R*"=P86QM<V-A<&4G*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD;6PG*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@
M*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G3F]K:6$G*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=N;VMI82<I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS
M92D["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G>&AT;6PG*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@
M("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7V%G96YT+"`G17)I8W-S
M;VXG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"
M<F]W<V5R*"=E<FEC<W-O;B<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H
M)'1H:7,M/E]L;W=E<D%G96YT+"`G=V%P)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T0G)O=W-E<B@G=V%P)RD["B`@("`@("`@
M("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:'1M;"<L(&9A;'-E*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=J879A<V-R:7!T)RP@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAD
M;6PG*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=W;6PG
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L
M("=D;V-O;6\G*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@("`@
M('-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=P;W)T86QM;6TG*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=I
M;6]D92<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VEM
M86=E<R<L(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE
M(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?86=E
M;G0L("=";&%C:T)E<G)Y)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T0G)O=W-E<B@G8FQA8VMB97)R>2<I.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$9E871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A
M;'-E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL
M)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@
M("`@("`@('T@96QS96EF("AS=')P;W,H)'1H:7,M/E]A9V5N="P@)TU/5"TG
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W
M<V5R*"=M;W1O<F]L82<I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$9E
M871U<F4H)VAT;6PG+"!F86QS92D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M<V5T1F5A='5R92@G:F%V87-C<FEP="<L(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS971&96%T=7)E*"=H9&UL)RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^<V5T1F5A='5R92@G=VUL)RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7VUO8FEL92`]('1R=64["B`@("`@("`@("`@('T@96QS96EF("AS
M=')P;W,H)'1H:7,M/E]L;W=E<D%G96YT+"`G:BTG*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YS971"<F]W<V5R*"=M;6PG*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;6]B:6QE(#T@=')U93L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA=&-H('1H
M92!P;&%T9F]R;2!O9B!T:&4@8G)O=W-E<BX*("`@("`J"B`@("`@*B!4:&ES
M(&ES(&$@<')E='1Y('-I;7!L:7-T:6,@:6UP;&5M96YT871I;VXL(&)U="!I
M="=S(&EN=&5N9&5D"B`@("`@*B!T;R!L970@=7,@=&5L;"!W:&%T(&QI;F4@
M8G)E86MS('1O('-E;F0L('-O(&ET)W,@9V]O9"!E;F]U9V@*("`@("`J(&9O
M<B!I=',@<'5R<&]S92X*("`@("`J"B`@("`@*B!`<VEN8V4@2&]R9&4@,BXR
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S9710;&%T9F]R;2@I"B`@("!["B`@
M("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7VQO=V5R06=E;G0L("=W:6YD)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&QA=&9O<FT@/2`G
M=VEN)SL*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1T:&ES+3Y?;&]W97)!
M9V5N="P@)VUA8R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W!L871F;W)M(#T@)VUA8R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]P;&%T9F]R;2`]("=U;FEX)SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&-U<G)E;G1L>2!M871C:&5D
M('!L871F;W)M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M=7-E<B=S('!L871F;W)M+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`R
M+C(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&QA=&9O<FTH*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!L871F;W)M.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@8W5R<F5N="!B<F]W<V5R+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&)R;W=S97(@(%1H92!B<F]W<V5R('1O('-E
M="!A<R!C=7)R96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971"<F]W<V5R
M*"1B<F]W<V5R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("1B
M<F]W<V5R.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('1H
M92!G:79E;B!B<F]W<V5R(&ES('1H92!S86UE(&%S('1H92!C=7)R96YT+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)R;W=S97(@(%1H92!B<F]W
M<V5R('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M27,@=&AE(&=I=F5N(&)R;W=S97(@=&AE('-A;64@87,@=&AE(&-U<G)E;G0_
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES0G)O=W-E<B@D8G)O=W-E<BD*("`@
M('L*("`@("`@("!R971U<FX@*"1T:&ES+3Y?8G)O=W-E<B`]/3T@)&)R;W=S
M97(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&\@=V4@8V]N<VED97(@=&AE
M(&-U<G)E;G0@8G)O=W-E<B!T;R!B92!A(&UO8FEL92!D979I8V4_"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('=E(&1O+"!F86QS
M92!I9B!W92!D;VXG="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7--;V)I;&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUO8FEL93L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE(&)R;W=S97(@:7,@
M82!R;V)O="!O<B!N;W0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF(&)R;W=S97(@:7,@82!K;F]W;B!R;V)O="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-2;V)O="@I"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]R;V)O=',@87,@)')O8F]T*2!["B`@("`@("`@("`@(&EF("AS
M=')P;W,H)'1H:7,M/E]A9V5N="P@)')O8F]T*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E('1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!C=7)R96YT(&)R;W=S97(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$)R;W=S97(H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V)R;W=S97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V92!T:&4@8W5R<F5N="!B<F]W<V5R)W,@;6%J;W(@=F5R<VEO;BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C=7)R96YT(&)R
M;W=S97(G<R!M86IO<B!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971-86IO<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%J;W)6
M97)S:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&-U
M<G)E;G0@8G)O=W-E<B=S(&UI;F]R('9E<G-I;VXN"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@8W5R<F5N="!B<F]W<V5R)W,@;6EN;W(@
M=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T36EN;W(H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUI;F]R5F5R<VEO;CL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!C=7)R96YT(&)R;W=S97(G
M<R!V97)S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M8W5R<F5N="!B<F]W<V5R)W,@=F5R<VEO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;6%J;W)697)S:6]N("X@)RXG("X@)'1H:7,M/E]M:6YO<E9E<G-I;VX["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&P@8G)O=W-E<B!A
M9V5N="!S=')I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!B<F]W<V5R(&%G96YT('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T06=E;G13=')I;F<H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V%G96YT.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('5N:7%U92!B96AA
M=FEO<B!F;W(@=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1Q=6ER:R`@5&AE(&)E:&%V:6]R('1O('-E="X*("`@
M("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!3<&5C:6%L(&)E:&%V:6]R('!A
M<F%M971E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T475I<FLH)'%U:7)K
M+"`D=F%L=64@/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<75I<FMS
M6R1Q=6ER:UT@/2`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:R!U;FEQ=64@8F5H879I;W(@9F]R('1H92!C=7)R96YT(&)R;W=S97(N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75I<FL@(%1H92!B96AA=FEO
M<B!T;R!C:&5C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@($1O
M97,@=&AE(&)R;W=S97(@:&%V92!T:&4@8F5H879I;W(@<V5T/PH@("`@("HO
M"B`@("!F=6YC=&EO;B!H87-1=6ER:R@D<75I<FLI"B`@("!["B`@("`@("`@
M<F5T=7)N("%E;7!T>2@D=&AI<RT^7W%U:7)K<ULD<75I<FM=*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E=')I979E('5N:7%U92!B96AA=FEO<B!F;W(@
M=&AE(&-U<G)E;G0@8G)O=W-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1Q=6ER:R`@5&AE(&)E:&%V:6]R('1O(')E=')I979E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=F%L=64@9F]R('1H92!R97%U
M97-T960@8F5H879I;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U:7)K
M*"1Q=6ER:RD*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]Q
M=6ER:W-;)'%U:7)K72D*("`@("`@("`@("`@("`@/R`D=&AI<RT^7W%U:7)K
M<ULD<75I<FM="B`@("`@("`@("`@("`@(#H@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!C87!A8FEL:71I97,@9F]R('1H92!C=7)R96YT(&)R
M;W=S97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F5A='5R92`@
M5&AE(&-A<&%B:6QI='D@=&\@<V5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=F%L=64@("`@4W!E8VEA;"!C87!A8FEL:71Y('!A<F%M971E<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T1F5A='5R92@D9F5A='5R92P@)'9A;'5E(#T@
M=')U92D*("`@('L*("`@("`@("`D=&AI<RT^7V9E871U<F5S6R1F96%T=7)E
M72`]("1V86QU93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K('1H92!C
M=7)R96YT(&)R;W=S97(@8V%P86)I;&ET:65S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9E871U<F4@(%1H92!C87!A8FEL:71Y('1O(&-H96-K
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@1&]E<R!T:&4@8G)O
M=W-E<B!H879E('1H92!C87!A8FEL:71Y('-E=#\*("`@("`J+PH@("`@9G5N
M8W1I;VX@:&%S1F5A='5R92@D9F5A='5R92D*("`@('L*("`@("`@("!R971U
M<FX@(65M<'1Y*"1T:&ES+3Y?9F5A='5R97-;)&9E871U<F5=*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E=')I979E('1H92!C=7)R96YT(&)R;W=S97(@
M8V%P86)I;&ET>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F96%T
M=7)E("!4:&4@8V%P86)I;&ET>2!T;R!R971R:65V92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('9A;'5E(&]F('1H92!R97%U97-T960@
M8V%P86)I;&ET>2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F5A='5R92@D
M9F5A='5R92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M/E]F
M96%T=7)E<ULD9F5A='5R95TI"B`@("`@("`@("`@("`@(#\@)'1H:7,M/E]F
M96%T=7)E<ULD9F5A='5R95T*("`@("`@("`@("`@("`@.B!N=6QL.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF('=E(&%R92!U<VEN9R!A
M('-E8W5R92`H4U-,*2!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!U<VEN9R!34TPL(&9A;'-E(&EF(&YO="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=7-I;F=34TQ#;VYN96-T:6]N*"D*("`@
M('L*("`@("`@("!R971U<FX@*"AI<W-E="@D7U-%4E9%4ELG2%144%,G72D@
M)B8*("`@("`@("`@("`@("`@("`H)%]315)615);)TA45%!3)UT@/3T@)V]N
M)RDI('Q\"B`@("`@("`@("`@("`@("!G971E;G8H)U-33%]04D]43T-/3%]6
M15)324].)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<V5R=F5R('!R;W1O8V]L(&EN('5S92!O;B!T:&4@8W5R<F5N="!S97)V97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5%10('-E<G9E
M<B!P<F]T;V-O;"!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(
M5%104')O=&]C;VPH*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%4E9%
M4ELG4T525D527U!23U1/0T],)UTI*2!["B`@("`@("`@("`@(&EF("@H)'!O
M<R`]('-T<G)P;W,H)%]315)615);)U-%4E9%4E]04D]43T-/3"==+"`G+R<I
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D7U-%4E9%4ELG
M4T525D527U!23U1/0T],)UTL("1P;W,@*R`Q*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$971E<FUI;F4@:68@9FEL97,@8V%N(&)E('5P;&]A9&5D('1O
M('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!)
M9B!U<&QO861S(&%L;&]W960L(')E='5R;G,@=&AE(&UA>&EM=6T@<VEZ92!O
M9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@=7!L;V%D(&EN(&)Y=&5S
M+B`@4F5T=7)N<R`P(&EF('5P;&]A9',@87)E(&YO=`H@("`@("H@("`@("`@
M("`@("`@("`@("!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!A;&QO
M=T9I;&55<&QO861S*"D*("`@('L*("`@("`@("!I9B`H:6YI7V=E="@G9FEL
M95]U<&QO861S)RDI('L*("`@("`@("`@("`@:68@*"@D9&ER(#T@:6YI7V=E
M="@G=7!L;V%D7W1M<%]D:7(G*2D@)B8*("`@("`@("`@("`@("`@("%I<U]W
M<FET86)L92@D9&ER*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(#`["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&9I;&5S:7IE(#T@:6YI7V=E="@G
M=7!L;V%D7VUA>%]F:6QE<VEZ92<I.PH@("`@("`@("`@("!S=VET8V@@*'-T
M<G1O;&]W97(H<W5B<W1R*"1F:6QE<VEZ92P@+3$L(#$I*2D@>PH@("`@("`@
M("`@("!C87-E("=K)SH*("`@("`@("`@("`@("`@("1F:6QE<VEZ92`](&EN
M='9A;"AF;&]A='9A;"@D9FEL97-I>F4I("H@,3`R-"D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@
M("`@("`@)&9I;&5S:7IE(#T@:6YT=F%L*&9L;V%T=F%L*"1F:6QE<VEZ92D@
M*B`Q,#(T("H@,3`R-"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D9FEL97-I>F4@/2!I
M;G1V86PH)&9I;&5S:7IE*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1P;W-T<VEZ92`](&EN:5]G970H)W!O
M<W1?;6%X7W-I>F4G*3L*("`@("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R
M*'-U8G-T<B@D<&]S='-I>F4L("TQ+"`Q*2DI('L*("`@("`@("`@("`@8V%S
M92`G:R<Z"B`@("`@("`@("`@("`@("`D<&]S='-I>F4@/2!I;G1V86PH9FQO
M871V86PH)'!O<W1S:7IE*2`J(#$P,C0I.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=M)SH*("`@("`@("`@("`@("`@("1P
M;W-T<VEZ92`](&EN='9A;"AF;&]A='9A;"@D<&]S='-I>F4I("H@,3`R-"`J
M(#$P,C0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@)'!O<W1S:7IE(#T@:6YT=F%L*"1P
M;W-T<VEZ92D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@;6EN*"1F:6QE<VEZ92P@)'!O<W1S:7IE
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&EF('1H
M92!F:6QE('=A<R!U<&QO861E9"!O<B!N;W0N("!)9B!N;W0L('=I;&P@<F5T
M=7)N('1H90H@("`@("H@87!P<F]P<FEA=&4@97)R;W(@;65S<V%G92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@5&AE(&YA;64@;V8@
M=&AE(&9I96QD(&-O;G1A:6YI;F<@=&AE('5P;&]A9&5D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("!4:&4@9FEL92!D97-C<FEP=&EO;B!S=')I;F<@=&\@=7-E(&EN
M('1H92!E<G)O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&UE<W-A
M9V4N("!$969A=6QT.B`G9FEL92<N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]N(&5R<F]R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!W87-&:6QE57!L;V%D960H)&9I96QD+"`D
M;F%M92`](&YU;&PI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<["@H@("`@("`@(&EF("AI<U]N=6QL*"1N86UE*2D@>PH@("`@("`@
M("`@("`D;F%M92`](%\H(F9I;&4B*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A*"1U<&QO8613:7IE(#T@0G)O=W-E<CHZ86QL;W=&:6QE57!L;V%D<R@I
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")&
M:6QE('5P;&]A9',@;F]T('-U<'!O<G1E9"XB*2D["B`@("`@("`@?0H*("`@
M("`@("`O*B!'970@86YY(&EN9&5X(&]N('1H92!F:65L9"!N86UE+B`J+PH@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O07)R87DN<&AP)SL*("`@("`@
M("`D:6YD97@@/2!(;W)D95]!<G)A>3HZ9V5T07)R87E087)T<R@D9FEE;&0L
M("1B87-E+"`D:V5Y<RD["@H@("`@("`@(&EF("@D:6YD97@I('L*("`@("`@
M("`@("`@+RH@26YD97@@<')E<V5N="P@9F5T8V@@=&AE(&5R<F]R('9A<B!T
M;R!C:&5C:RX@*B\*("`@("`@("`@("`@)&ME>7-?<&%T:"`](&%R<F%Y7VUE
M<F=E*&%R<F%Y*"1B87-E+"`G97)R;W(G*2P@)&ME>7,I.PH@("`@("`@("`@
M("`D97)R;W(@/2!(;W)D95]!<G)A>3HZ9V5T16QE;65N="@D7T9)3$53+"`D
M:V5Y<U]P871H*3L*"B`@("`@("`@("`@("\J($EN9&5X('!R97-E;G0L(&9E
M=&-H('1H92!T;7!?;F%M92!V87(@=&\@8VAE8VLN("HO"B`@("`@("`@("`@
M("1K97ES7W!A=&@@/2!A<G)A>5]M97)G92AA<G)A>2@D8F%S92P@)W1M<%]N
M86UE)RDL("1K97ES*3L*("`@("`@("`@("`@)'1M<%]N86UE(#T@2&]R9&5?
M07)R87DZ.F=E=$5L96UE;G0H)%]&24Q%4RP@)&ME>7-?<&%T:"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@3F\@:6YD97@L('-I;7!L92!S
M970@=7`@;V8@=F%R<R!T;R!C:&5C:RX@*B\*("`@("`@("`@("`@:68@*"%I
M<W-E="@D7T9)3$536R1F:65L9%TI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!F:6QE('5P;&]A9&5D(BDL(%50
M3$]!1%]%4E)?3D]?1DE,12D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&5R<F]R(#T@)%]&24Q%4ULD9FEE;&1=6R=E<G)O<B==.PH@("`@("`@("`@
M("`D=&UP7VYA;64@/2`D7T9)3$536R1F:65L9%U;)W1M<%]N86UE)UT["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1?1DE,15,I('Q\("@D97)R
M;W(@/3T@55!,3T%$7T524E].3U]&24Q%*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1H97)E('=A<R!A('!R
M;V)L96T@=VET:"!T:&4@9FEL92!U<&QO860Z($YO("5S('=A<R!U<&QO861E
M9"XB*2P@)&YA;64I+"!54$Q/041?15)27TY/7T9)3$4I.PH@("`@("`@('T@
M96QS96EF("@H)&5R<F]R(#T](%503$]!1%]%4E)?3TLI("8F(&ES7W5P;&]A
M9&5D7V9I;&4H)'1M<%]N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!](&5L<V5I9B`H*"1E<G)O<B`]/2!54$Q/041?15)27TE.
M25]325I%*2!\?`H@("`@("`@("`@("`@("`@("`H)&5R<F]R(#T](%503$]!
M1%]%4E)?1D]235]325I%*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@=VET
M:"!T:&4@9FEL92!U<&QO860Z(%1H92`E<R!W87,@;&%R9V5R('1H86X@=&AE
M(&UA>&EM=6T@86QL;W=E9"!S:7IE("@E9"!B>71E<RDN(BDL("1N86UE+"`D
M=7!L;V%D4VEZ92DL("1E<G)O<BD["B`@("`@("`@?2!E;'-E:68@*"1E<G)O
M<B`]/2!54$Q/041?15)27U!!4E1)04PI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")4:&5R92!W87,@82!P<F]B
M;&5M('=I=&@@=&AE(&9I;&4@=7!L;V%D.B!4:&4@)7,@=V%S(&]N;'D@<&%R
M=&EA;&QY('5P;&]A9&5D+B(I+"`D;F%M92DL("1E<G)O<BD["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:&5A9&5R<R!F
M;W(@82!B<F]W<V5R(&1O=VYL;V%D+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@;V8@=&AE(&1O=VYL;V%D
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8U1Y<&4@("`@(%1H92!C;VYT96YT
M+71Y<&4@9&5S8W)I<'1I;VX@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D:6YL:6YE("`@5')U92!I9B!I;FQI;F4L(&9A;'-E(&EF(&%T
M=&%C:&UE;G0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C3&5N9W1H("`@5&AE
M(&-O;G1E;G0M;&5N9W1H(&]F('1H:7,@9FEL92X*("`@("`J"B`@("`@*B!`
M<VEN8V4@2&]R9&4@,BXR"B`@("`@*B\*("`@(&9U;F-T:6]N(&1O=VYL;V%D
M2&5A9&5R<R@D9FEL96YA;64@/2`G=6YK;F]W;B<L("1C5'EP92`](&YU;&PL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN;&EN92`](&9A;'-E
M+"`D8TQE;F=T:"`](&YU;&PI"B`@("!["B`@("`@("`@+RH@4F5M;W9E(&QI
M;F5B<F5A:W,@9G)O;2!F:6QE(&YA;65S+B`J+PH@("`@("`@("1F:6QE;F%M
M92`]('-T<E]R97!L86-E*&%R<F%Y*")<<EQN(BP@(EQR(BP@(EQN(BDL("<@
M)RP@)&9I;&5N86UE*3L*"B`@("`@("`@+RH@4V]M92!B<F]W<V5R<R!D;VXG
M="!L:6ME('-P86-E<R!I;B!T:&4@9FEL96YA;64N("HO"B`@("`@("`@:68@
M*"1T:&ES+3YH87-1=6ER:R@G;F]?9FEL96YA;65?<W!A8V5S)RDI('L*("`@
M("`@("`@("`@)&9I;&5N86UE(#T@<W1R='(H)&9I;&5N86UE+"`G("<L("=?
M)RD["B`@("`@("`@?0H*("`@("`@("`O*B!-4TE%(&1O97-N)W0@;&EK92!M
M=6QT:7!L92!P97)I;V1S(&EN('1H92!F:6QE(&YA;64N($-O;G9E<G0*("`@
M("`@("`@("!A;&P@<&5R:6]D<R`H97AC97!T('1H92!L87-T(&]N92D@=&\@
M=6YD97)S8V]R97,N("HO"B`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H
M)VUS:64G*2D@>PH@("`@("`@("`@("!I9B`H*"1P;W,@/2!S=')R<&]S*"1F
M:6QE;F%M92P@)RXG*2DI('L*("`@("`@("`@("`@("`@("1F:6QE;F%M92`]
M('-T<G1R*'-U8G-T<B@D9FEL96YA;64L(#`L("1P;W,I+"`G+B<L("=?)RD@
M+B!S=6)S='(H)&9I;&5N86UE+"`D<&]S*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@0V]N=&5N="U4>7!E+T-O;G1E;G0M1&ES<&]S
M:71I;VX@2&5A9&5R+B`J+PH@("`@("`@(&EF("@D:6YL:6YE*2!["B`@("`@
M("`@("`@(&EF("@A:7-?;G5L;"@D8U1Y<&4I*2!["B`@("`@("`@("`@("`@
M("!H96%D97(H)T-O;G1E;G0M5'EP93H@)R`N('1R:6TH)&-4>7!E*2D["B`@
M("`@("`@("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M<VEE)RDI
M('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L
M:6-A=&EO;B]X+6US9&]W;FQO860G*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A
M=&EO;B]O8W1E="US=')E86TG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!H96%D97(H)T-O;G1E;G0M1&ES<&]S:71I;VXZ(&EN;&EN93L@9FEL96YA
M;64](B<@+B`D9FEL96YA;64@+B`G(B<I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@
M("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L:6-A=&EO
M;B]X+6US9&]W;FQO860G*3L*("`@("`@("`@("`@?2!E;'-E:68@*"%I<U]N
M=6QL*"1C5'EP92DI('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N
M="U4>7!E.B`G("X@=')I;2@D8U1Y<&4I*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!A<'!L
M:6-A=&EO;B]O8W1E="US=')E86TG*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G8G)E86M?9&ES<&]S:71I;VY?
M:&5A9&5R)RDI('L*("`@("`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U$
M:7-P;W-I=&EO;CH@9FEL96YA;64](B<@+B`D9FEL96YA;64@+B`G(B<I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:&5A9&5R*"=#
M;VYT96YT+41I<W!O<VET:6]N.B!A='1A8VAM96YT.R!F:6QE;F%M93TB)R`N
M("1F:6QE;F%M92`N("<B)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($-O;G1E;G0M3&5N9W1H($AE861E<BX@*B\*("`@("`@("!I
M9B`H(6ES7VYU;&PH)&-,96YG=&@I*2!["B`@("`@("`@("`@(&AE861E<B@G
M0V]N=&5N="U,96YG=&@Z("<@+B`D8TQE;F=T:"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!/=F5R=W)I=&4@4')A9VUA.B!A;F0@;W1H97(@8V%C:&EN9R!H
M96%D97)S(&9O<B!)12X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<U%U:7)K
M*"=C86-H95]S<VQ?9&]W;FQO861S)RDI('L*("`@("`@("`@("`@:&5A9&5R
M*"=%>'!I<F5S.B`P)RD["B`@("`@("`@("`@(&AE861E<B@G0V%C:&4M0V]N
M=')O;#H@;75S="UR979A;&ED871E)RD["B`@("`@("`@("`@(&AE861E<B@G
M4')A9VUA.B!P=6)L:6,G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$971E<FUI;F5S(&EF(&$@8G)O=W-E<B!C86X@9&ES<&QA>2!A(&=I
M=F5N($U)344@='EP92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M:6UE='EP92`@5&AE($U)344@='EP92!T;R!C:&5C:RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(&)R;W=S97(@8V%N(&1I
M<W!L87D@=&AE($U)344@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-6
M:65W86)L92@D;6EM971Y<&4I"B`@("!["B`@("`@("`@)&UI;65T>7!E(#T@
M4W1R:6YG.CIL;W=E<B@D;6EM971Y<&4I.PH@("`@("`@(&QI<W0H)'1Y<&4L
M("1S=6)T>7!E*2`](&5X<&QO9&4H)R\G+"`D;6EM971Y<&4I.PH*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?86-C97!T*2D@>PH@("`@("`@("`@("`D
M=VEL9&-A<F1?;6%T8V@@/2!F86QS93L*"B`@("`@("`@("`@(&EF("AS=')P
M;W,H)'1H:7,M/E]A8V-E<'0L("1M:6UE='EP92D@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D=&AI<RT^7V%C8V5P="P@)RHO*B<I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'=I;&1C87)D7VUA=&-H(#T@
M=')U93L*("`@("`@("`@("`@("`@(&EF("@D='EP92`A/2`G:6UA9V4G*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(&EM86=E+VIP
M96<@86YD(&EM86=E+W!J<&5G("IA<'!E87(J('1O(&)E('1H92!S86UE"B`@
M("`@("`@("`@("`J(&5N=&ET>2P@8G5T($UO>FEL;&$@9&]E<VXG="!S965M
M('1O('=A;G0@=&\@86-C97!T('1H90H@("`@("`@("`@("`@*B!L871T97(N
M("!&;W(@;W5R('!U<G!O<V5S+"!W92!W:6QL('1R96%T('1H96T@=&AE"B`@
M("`@("`@("`@("`J('-A;64N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8*("`@("`@("`@("`@("`@("@D;6EM
M971Y<&4@/3T@)VEM86=E+W!J<&5G)RD@)B8*("`@("`@("`@("`@("`@("AS
M=')P;W,H)'1H:7,M/E]A8V-E<'0L("=I;6%G92]J<&5G)RD@(3T](&9A;'-E
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@A)'=I;&1C87)D7VUA=&-H*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A)'1H:7,M/FAA<T9E871U<F4H)VEM86=E<R<I
M('Q\("@D='EP92`A/2`G:6UA9V4G*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:6Y?87)R87DH)'-U
M8G1Y<&4L("1T:&ES+3Y?:6UA9V5S*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($5S8V%P92!C:&%R86-T97)S(&EN(&IA=F%S8W)I<'0@8V]D92!I9B!T:&4@
M8G)O=W-E<B!R97%U:7)E<R!I="X*("`@("`J("4R,RP@)3(V+"!A;F0@)3)"
M("AF;W(@<V]M92!B<F]W<V5R<RD@86YD("4R-R!N965D('1O(&)E(&5S8V%P
M960@;W(*("`@("`J(&5L<V4@:F%V87-C<FEP="!W:6QL(&EN=&5R<')E="!I
M="!A<R!A('-I;F=L92!Q=6]T92P@<&]U;F0@<VEG;BP@;W(*("`@("`J(&%M
M<&5R<V%N9"!A;F0@<F5F=7-E('1O('=O<FLN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]D92`@5&AE($I3(&-O9&4@=&\@97-C87!E+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@97-C87!E9"!C;V1E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!E<V-A<&5*4T-O9&4H)&-O9&4I"B`@("![
M"B`@("`@("`@)&9R;VT@/2`D=&\@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M)'1H:7,M/FES0G)O=W-E<B@G;7-I92<I('Q\"B`@("`@("`@("`@("@D=&AI
M<RT^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8@*"1T:&ES+3YG971-86IO<B@I
M(#X](#4I*2!\?`H@("`@("`@("`@("`D=&AI<RT^:7-"<F]W<V5R*"=K;VYQ
M=65R;W(G*2D@>PH@("`@("`@("`@("`D9G)O;2`](&%R<F%Y*"<E,C,G+"`G
M)3(V)RP@)R4R0B<I.PH@("`@("`@("`@("`D=&\@/2!A<G)A>2AU<FQE;F-O
M9&4H)R4R,R<I+"!U<FQE;F-O9&4H)R4R-B<I+"!U<FQE;F-O9&4H)R4R0B<I
M*3L*("`@("`@("!]"B`@("`@("`@)&9R;VU;72`]("<E,C<G.PH@("`@("`@
M("1T;UM=(#T@)UPE,C<G.PH*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H
M)&9R;VTL("1T;RP@)&-O9&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!)12!V97)S:6]N(&EN('1H92!S97-S:6]N+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'9E<B`@5&AE($E%(%9E<G-I;VX@<W1R:6YG+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971)159E<G-I;VXH)'9E<BD*("`@('L*
M("`@("`@("`D7U-%4U-)3TY;)U]?8G)O=W-E<B==(#T@87)R87DH"B`@("`@
M("`@("`@("=I95]V97)S:6]N)R`]/B`D=F5R"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@244@=F5R<VEO;B!S=&]R960@
M:6X@=&AE('-E<W-I;VXL(&EF(&%V86EL86)L92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4:&4@244@5F5R<VEO;B!S=')I;F<@;W(@;G5L;"!I
M9B!N;R!S=')I;F<@:7,@<W1O<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971)159E<G-I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E="@D7U-%
M4U-)3TY;)U]?8G)O=W-E<B==6R=I95]V97)S:6]N)UTI(#\@)%]315-324].
M6R=?7V)R;W=S97(G75LG:65?=F5R<VEO;B==(#H@;G5L;#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O4V-H961U;&5R+V-R;VXN<&AP````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C8T,C`@,3`U,34T,S0Q-#`@
M,#(R-S,S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U-C:&5D=6QE<BYP:'`G
M.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J($AO
M<F1E7U-C:&5D=6QE<E]C<F]N.CH@4V]R="!O9B!A(&-R;VX@<F5P;&%C96UE
M;G0@:6X@82!02%`@8VQI"B`J('-C<FEP="X*("H*("H@1&%T92!3>6YT87@@
M17AA;7!L97,N"B`J"B`J(%)E;65M8F5R.@H@*B`@("T@5VAI=&5S<&%C92`H
M<W!A8V4L('1A8BP@;F5W;&EN92D@9&5L:6UI=&5D(&9I96QD<PH@*B`@("T@
M4VEN9VQE('9A;'5E<RP@<V5T<RP@<F%N9V5S+"!W:6QD8V%R9',*("H*("H@
M4T5#3TY$("`@34E.551%("`@("`@("`@("`@("!(3U52("`@("`@("!$05D@
M("`@($U/3E1("B`J("H@("`@("`@("H@("`@("`@("`@("`@("`@("`@*B`@
M("`@("`@("`@*B`@("`@("`J("`@("`@("AE=F5R>2!S96-O;F0I"B`J(#`L
M,S`@("`@("H@("`@("`@("`@("`@("`@("`@*B`@("`@("`@("`@*B`@("`@
M("`J("`@("`@("AE=F5R>2`S,"!S96-O;F1S*0H@*B`P("`@("`@("`P+#$P
M+#(P+#,P+#0P+#4P("`@("H@("`@("`@("`@("H@("`@("`@*B`@("`@("`H
M979E<GD@,3`@;6EN=71E<RD*("H@,"`@("`@("`@,"`@("`@("`@("`@("`@
M("`@("`J("`@("`@("`@("`J("`@("`@("H@("`@("`@*&)E9VEN;FEN9R!O
M9B!E=F5R>2!H;W5R*0H@*B`P("`@("`@("`P("`@("`@("`@("`@("`@("`@
M(#`L-BPQ,BPQ."`@("H@("`@("`@*B`@("`@("`H870@;6ED;FEG:'0L(#9A
M;2P@;F]O;BP@-G!M*0H@*B`P("`@("`@("`P("`@("`@("`@("`@("`@("`@
M(#`@("`@("`@("`@(#$M-R9&<FD@*B`@("`@("`H;6ED;FEG:'0L(&9I<G-T
M($9R:2!O9B!T:&4@;6]N=&@I"B`J(#`@("`@("`@(#`@("`@("`@("`@("`@
M("`@("`@,"`@("`@("`@("`@,2TW(49R:2`J("`@("`@("AM:61N:6=H="P@
M9FER<W0@36]N+51H=2Q3870M4W5N(&]F('1H92!M;VYT:"D*("H*("H*("H@
M17AA;7!L92!U<V%G93H*("H*("H@0'-E=%]T:6UE7VQI;6ET*#`I.PH@*B!R
M97%U:7)E7V]N8V4@)TAO<F1E+U-C:&5D=6QE<BYP:'`G.PH@*B`D8W)O;B`]
M("9(;W)D95]38VAE9'5L97(Z.G-I;F=L971O;B@G8W)O;B<I.PH@*@H@*B`O
M+R!2=6X@=&AI<R!C;VUM86YD(&5V97)Y(#4@;6EN=71E<RX*("H@)&-R;VXM
M/F%D9%1A<VLH)W!E<FP@<V]M97-C<FEP="YP;"<L("<P(#`L-2PQ,"PQ-2PR
M,"PR-2PS,"PS-2PT,"PT-2PU,"PU-2`J("H@*B<I.PH@*@H@*B`O+R!2=6X@
M=&AI<R!C;VUM86YD(&UI9&YI9VAT(&]F('1H92!F:7)S="!&<FED87D@;V8@
M;V1D(&YU;6)E<F5D(&UO;G1H<RX*("H@)&-R;VXM/F%D9%1A<VLH)W!H<"`M
M<2!S;VUE<V-R:7!T+G!H<"<L("<P(#`@,"`Q+3<F1G)I(#$L,RPU+#<L.2PQ
M,2<I.PH@*@H@*B`O+R!!;'-O(')U;B!T:&ES(&-O;6UA;F0@;6ED;FEG:'0@
M;V8@=&AE('-E8V]N9"!4:'5R<V1A>2!A;F0@4V%T=7)D87D@;V8@=&AE(&5V
M96X@;G5M8F5R960@;6]N=&AS+@H@*B`D8W)O;BT^861D5&%S:R@G<&AP("UQ
M('-O;65S8W)I<'0N<&AP)RP@)S`@,"`P(#@M,34F5&AU+#@M,34F4V%T(#(L
M-"PV+#@L,3`L,3(G*3L*("H*("H@)&-R;VXM/G)U;B@I.PH@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]38VAE9'5L97(O4V-H961U;&5R+V-R;VXN<&AP+'8@
M,2XQ,RXQ,"XS(#(P,#4O,3`O,3@@,3$Z,#$Z,C8@:F%N($5X<"`D"B`J"B`J
M($!A=71H;W(@(%)Y86X@1FQY;FX@/')Y86Y`<GEA;F9L>6YN+F-O;3X*("H@
M0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($!P86-K86=E($AO<F1E7U-C:&5D=6QE<@H@*B\*8VQA<W,@2&]R9&5?4V-H
M961U;&5R7V-R;VX@97AT96YD<R!(;W)D95]38VAE9'5L97(@>PH*("`@('9A
M<B`D7W1A<VMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($5V97)Y('1I
M;64@82!T87-K(&ES(&%D9&5D(&ET('=I;&P@9V5T(&$@9G)E<V@@=6ED(&5V
M96X@:68*("`@("`J(&EM;65D:6%T96QY(')E;6]V960N"B`@("`@*B\*("`@
M('9A<B`D7V-O=6YT97(@/2`Q.PH*("`@(&9U;F-T:6]N(&%D9%1A<VLH)&-M
M9"P@)')U;&5S*0H@("`@>PH@("`@("`@("1D<R`]("9N97<@2&]R9&5?4V-H
M961U;&5R7V-R;VY$871E*"1R=6QE<RD["@H@("`@("`@("1T:&ES+3Y?8V]U
M;G1E<BLK.PH*("`@("`@("`D=&AI<RT^7W1A<VMS6UT@/0H@("`@("`@("`@
M("!A<G)A>2@*("`@("`@("`@("`@("`@("=U:60G(#T^("1T:&ES+3Y?8V]U
M;G1E<BP*("`@("`@("`@("`@("`@("=R=6QE<R<@/3X@)&1S+`H@("`@("`@
M("`@("`@("`@)V-M9"<@/3X@)&-M9`H@("`@("`@("`@("`I.PH*("`@("`@
M("!R971U<FX@)'1H:7,M/E]C;W5N=&5R.PH@("`@?0H*("`@(&9U;F-T:6]N
M(')E;6]V951A<VLH)'5I9"D*("`@('L*("`@("`@("`D8V]U;G0@/2!C;W5N
M="@D=&AI<RT^7W1A<VMS*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D
M8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=&%S:W-;
M)W5I9"==(#T]("1U:60I('L*("`@("`@("`@("`@("`@("1F;W5N9"`]("1I
M.PH@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1T:&ES+3Y?=&%S:W,L
M("1I*3L*("`@("`@("`@("`@("`@(')E='5R;B`D:3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@("`@9G5N
M8W1I;VX@<G5N*"D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?
M=&%S:W,I*2!["B`@("`@("`@("`@(&5X:70H(F-R;VYD.B!.;W1H:6YG('1O
M('-C:&5D=6QE.R!E>&ET:6YG+EQN(BD["B`@("`@("`@?0H*("`@("`@("!W
M:&EL92`H=')U92D@>PH@("`@("`@("`@("`D="`]('1I;64H*3L*"B`@("`@
M("`@("`@("\O($-H96-K(&5A8V@@=&%S:RX*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]T87-K<R!A<R`D=&%S:RD@>PH@("`@("`@("`@("`@("`@
M:68@*"1T87-K6R=R=6QE<R==+3YN;W=-871C:&5S*"DI('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<G5N8VUD*"1T87-K*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@5V%I="!U;G1I
M;"!T:&4@;F5X="!S96-O;F0N"B`@("`@("`@("`@('=H:6QE("AT:6UE*"D@
M/3T@)'0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS;&5E<"@Q,#`P,#`I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(')U;F-M9"@F)'1A<VLI"B`@("!["B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)TAO<F1E7U-C:&5D=6QE<E]#<F]N.CIR=6YC;60H*3H@)R`N("1T87-K
M6R=C;60G72`N("<@<G5N(&)Y("<@+B`D=&%S:ULG=6ED)UTL(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?24Y&3RD["B`@("`@("`@<F5T=7)N('-H
M96QL7V5X96,H)'1A<VM;)V-M9"==*3L*("`@('T*"GT*"B\J*@H@*B!`<&%C
M:V%G92!(;W)D95]38VAE9'5L97(*("HO"F-L87-S($AO<F1E7U-C:&5D=6QE
M<E]C<F]N1&%T92!["@H@("`@=F%R("1L96=A;$1A>7,@/2!A<G)A>2@G34].
M)RP@)U1512<L("=7140G+"`G5$A5)RP@)T9222<L("=3050G+"`G4U5.)RD[
M"@H@("`@=F%R("1S96,["B`@("!V87(@)&UI;CL*("`@('9A<B`D:&]U<CL*
M("`@('9A<B`D9&%Y.PH@("`@=F%R("1M;VYT:#L*"B`@("!F=6YC=&EO;B!(
M;W)D95]38VAE9'5L97)?8W)O;D1A=&4H)')A=RD*("`@('L*("`@("`@("`D
M=&AI<RT^<&%R<V4H4W1R:6YG.CIU<'!E<B@D<F%W*2D["B`@("!]"@H@("`@
M9G5N8W1I;VX@;F]W36%T8VAE<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YS8VAE9'5L961!="AT:6UE*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N
M('-C:&5D=6QE9$%T*"1T<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1T
M<R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D=',@/2!T:6UE*"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`H)'1H:7,M/FUO;G1H36%T8VAE<R@D=',I
M("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^;6]N=&A-871C:&5S*"1T<RD@
M)B8*("`@("`@("`@("`@("`@("1T:&ES+3YD87E-871C:&5S*"1T<RD@)B8*
M("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R36%T8VAE<R@D=',I("8F"B`@
M("`@("`@("`@("`@("`D=&AI<RT^;6EN36%T8VAE<R@D=',I("8F"B`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5C36%T8VAE<R@D=',I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!M;VYT:$UA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^;6]N=&@@/3T@)RHG*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U<G)E;G1M;VYT:"`]("<M)R`N
M(&1A=&4H)VXG+"`D=',I("X@)RTG.PH*("`@("`@("!R971U<FX@*&)O;VPI
M<W1R<&]S*"1T:&ES+3YM;VYT:"P@)&-U<G)E;G1M;VYT:"D["B`@("!]"@H@
M("`@9G5N8W1I;VX@9&%Y36%T8VAE<R@D=',I"B`@("!["B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^9&%Y6R=V86QU92==*2`F)B`D=&AI<RT^9&%Y6R=V
M86QU92==(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1C=7)R96YT9&%Y;G5M(#T@)RTG("X@9&%T92@G
M:B<L("1T<RD@+B`G+2<["B`@("`@("`@)&-U<G)E;G1D87ET>'0@/2!3=')I
M;F<Z.G5P<&5R*&1A=&4H)T0G*2D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YD87D@87,@)&1A>2D@>PH@("`@("`@("`@("!I9B`H0'-T<G!O<R@D9&%Y
M6R=N;W0G72P@)&-U<G)E;G1D87ET>'0I(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)'8Q(#T@*$!S=')P;W,H)&1A>5LG=F%L=64G72P@)&-U<G)E
M;G1D87EN=6TI("$]/2!F86QS92D["B`@("`@("`@("`@("`@("`D=C(@/2`H
M0'-T<G!O<R@D9&%Y6R=A;F0G72P@)&-U<G)E;G1D87ET>'0I("$]/2!F86QS
M92D["@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9&%Y6R=A;F0G72D@
M)B8@*"1V,2`F)B`D=C(I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H96UP='DH)&1A>5LG
M86YD)UTI("8F("1V,2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@
M:&]U<DUA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&]U
M<B`]/2`G*B<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`D8W5R<F5N=&AO=7(@/2`G+2<@+B!D871E*"=')RP@)'1S
M*2`N("<M)SL*"B`@("`@("`@<F5T=7)N("AS=')P;W,H)'1H:7,M/FAO=7(L
M("1C=7)R96YT:&]U<BD@(3T](&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!M:6Y-871C:&5S*"1T<RD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/FUI
M;B`]/2`G*B<I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`D8W5R<F5N=&UI;B`]("<M)R`N(&EN='9A;"AD871E*"=I
M)RP@)'1S*2D@+B`G+2<["@H@("`@("`@(')E='5R;B`H<W1R<&]S*"1T:&ES
M+3YM:6XL("1C=7)R96YT;6EN*2`A/3T@9F%L<V4I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-E8TUA=&-H97,H)'1S*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^<V5C(#T]("<J)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1C=7)R96YT<V5C(#T@)RTG("X@:6YT=F%L*&1A
M=&4H)W,G+"`D=',I*2`N("<M)SL*"B`@("`@("`@<F5T=7)N("AS=')P;W,H
M)'1H:7,M/G-E8RP@)&-U<G)E;G1S96,I("$]/2!F86QS92D["B`@("!]"@H@
M("`@9G5N8W1I;VX@<&%R<V4H)'-T<BD*("`@('L*("`@("`@("`D<R`](&%R
M<F%Y*"D["@H@("`@("`@(&QI<W0H)'-;)W-E8R==+"`D<ULG;6EN)UTL("1S
M6R=H;W5R)UTL("1S6R=D87DG72P@)'-;)VUO;G1H)UTI(#T@<')E9U]S<&QI
M="@G?%M<;EQT(%TK?"<L("1S='(I.PH*("`@("`@("!F;W)E86-H("@D<R!A
M<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1V+"`G*B<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'-;)&M=(#T@87)R87DH
M)RHG*3L*("`@("`@("`@("`@?2!E;'-E:68@*"$D=&AI<RT^9V5N97)A;&QY
M1&5C96YT4WEN=&%X*"1V*2D@>PH@("`@("`@("`@("`@("`@9&EE*"));&QE
M9V%L('-Y;G1A>"!I;B`G)'8G7&XB*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S6R1K72`](&5X<&QO9&4H)RPG+"`D<ULD:UTI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'-;)W-E
M8R==6S!=(#T]("<J)RD@>PH@("`@("`@("`@("`D=&AI<RT^<V5C(#T@)RHG
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\('-I>F5O9B@D<ULG<V5C)UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;)W-E8R==6R1I72DI('L*("`@("`@
M("`@("`@("`@("`@("`D<ULG<V5C)UU;)&E=(#T@)'1H:7,M/F5X<&%N9%)A
M;F=E*"1T:&ES+3YR86YG959A;',H)'-;)W-E8R==6R1I72DI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YS
M96,@/2`G+2<@+B!J;VEN*"<M)RP@)'-;)W-E8R==*2`N("<M)SL*("`@("`@
M("!]"@H@("`@("`@(&EF("@D<ULG;6EN)UU;,%T@/3T@)RHG*2!["B`@("`@
M("`@("`@("1T:&ES+3YM:6X@/2`G*B<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1S6R=M:6XG72D[
M("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-286YG92@D
M<ULG;6EN)UU;)&E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1S6R=M:6XG
M75LD:5T@/2`D=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D
M<ULG;6EN)UU;)&E=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/FUI;B`]("<M)R`N(&IO:6XH)RTG+"`D
M<ULG;6EN)UTI("X@)RTG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S6R=H
M;W5R)UU;,%T@/3T@)RHG*2!["B`@("`@("`@("`@("1T:&ES+3YH;W5R(#T@
M)RHG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\('-I>F5O9B@D<ULG:&]U<B==*3L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<U)A;F=E*"1S6R=H;W5R)UU;)&E=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1S6R=H;W5R)UU;)&E=(#T@)'1H:7,M/F5X
M<&%N9%)A;F=E*"1T:&ES+3YR86YG959A;',H)'-;)VAO=7(G75LD:5TI*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^:&]U<B`]("<M)R`N(&IO:6XH)RTG+"`D<ULG:&]U<B==*2`N("<M
M)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D<ULG9&%Y)UU;,%T@/3T@)RHG
M*2!["B`@("`@("`@("`@("1T:&ES+3YD87D@/2`G*B<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1S
M6R=D87DG72D[("1I*RLI('L*("`@("`@("`@("`@("`@("1T;7`@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`@("`@:68@*"@D8VAA<B`]("1T:&ES+3YI<T-O
M;F0H)'-;)V1A>2==6R1I72DI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D8VAA<B`]/2`G)B<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@;&ES="@D=&UP6R=V86QU92==+"`D=&UP6R=A;F0G72D@/2!E>'!L
M;V1E*"1C:&%R+"`D<ULG9&%Y)UU;)&E=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YI<U)A;F=E*"1T;7!;)V%N9"==*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1M<%LG86YD)UT@/2`D=&AI<RT^
M97AP86YD4F%N9V4H)'1H:7,M/G)A;F=E5F%L<R@D=&UP6R=A;F0G72DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D=&UP6R=V
M86QU92==+"`D=&UP6R=N;W0G72D@/2!E>'!L;V1E*"1C:&%R+"`D<ULG9&%Y
M)UU;)&E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI
M<U)A;F=E*"1T;7!;)VYO="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1M<%LG;F]T)UT@/2`D=&AI<RT^97AP86YD4F%N9V4H)'1H:7,M
M/G)A;F=E5F%L<R@D=&UP6R=N;W0G72DI.PH@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@87)R87DH)W9A
M;'5E)R`]/B`D<ULG9&%Y)UU;)&E=*3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("`D<ULG9&%Y)UU;)&E=(#T@)'1M<#L*"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FES4F%N9V4H)'-;)V1A>2==6R1I75LG=F%L
M=64G72DI('L*("`@("`@("`@("`@("`@("`@("`D<ULG9&%Y)UU;)&E=6R=V
M86QU92==(#T@)'1H:7,M/F5X<&%N9%)A;F=E*"1T:&ES+3YR86YG959A;',H
M)'-;)V1A>2==6R1I75LG=F%L=64G72DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^9&%Y(#T@)'-;)V1A
M>2==.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S6R=M;VYT:"==6S!=(#T]
M("<J)RD@>PH@("`@("`@("`@("`D=&AI<RT^;6]N=&@@/2`G*B<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ
M96]F*"1S6R=M;VYT:"==*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YI<U)A;F=E*"1S6R=M;VYT:"==6R1I72DI('L*("`@("`@("`@
M("`@("`@("`@("`D<ULG;6]N=&@G75LD:5T@/2`D=&AI<RT^97AP86YD4F%N
M9V4H)'1H:7,M/G)A;F=E5F%L<R@D<ULG;6]N=&@G75LD:5TI*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M;6]N=&@@/2`G+2<@+B!J;VEN*"<M)RP@)'-;)VUO;G1H)UTI("X@)RTG.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F0H)',I"B`@("![
M"B`@("`@("`@:68@*'-T<G!O<R@D<RP@)R8G*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N("<F)SL*("`@("`@("!](&5L<V5I9B`H<W1R<&]S
M*"1S+"`G(2<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)R$G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-286YG92@D<RD*("`@
M('L*("`@("`@("!R971U<FX@<')E9U]M871C:"@G+UY<=RM<+5QW*R\G+"`D
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-#;VYD4F%N9V4H)',I"B`@("![
M"B`@("`@("`@<F5T=7)N("AI<T-O;F0H)',I("8F(&ES4F%N9V4H)',I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!I<T-O;F1686PH)',I"B`@("!["B`@("`@
M("`@<F5T=7)N("AI<T-O;F0H)',I("8F("%I<U)A;F=E*"1S*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@<F%N9V5686QS*"1S*0H@("`@>PH@("`@("`@(')E
M='5R;B!E>'!L;V1E*"<M)RP@)',I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X
M<&%N9%)A;F=E*"1L+"`D:"`]("<G*0H@("`@>PH@("`@("`@("\O($5X<&%N
M9"!R86YG92!F<F]M(#$M-2`M/B`G+3$M,BTS+30M-2TG+@H@("`@("`@(&EF
M("AI<U]A<G)A>2@D;"DI('L*("`@("`@("`@("`@)&@@/2`D;%LQ73L*("`@
M("`@("`@("`@)&P@/2`D;%LP73L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&AI<RT^:7-$:6=I="@D;"DI('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M:7-$:6=I="@D:"DI('L*("`@("`@("`@("`@("`@(&1I92@B26YV86QI9"!V
M86QU92`G)&@G(&EN(')A;F=E("<D;"TD:"<B*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@0W5R<F5N=&QY('1H97)E(&ES(&YO('!O<W-I8FQE
M(')E87-O;B!T;R!N965D('1O(&1O(&$*("`@("`@("`@("`@+R\@<F%N9V4@
M8F5Y;VYD(#`M-3D@9F]R(&%N>71H:6YG+@H@("`@("`@("`@("!I9B`H)&P@
M/"`P*2!["B`@("`@("`@("`@("`@("`D;"`](#`["B`@("`@("`@("`@('T@
M96QS96EF("@D;"`^(#4Y*2!["B`@("`@("`@("`@("`@("`D;"`](#4Y.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&@@/"`P*2!["B`@("`@
M("`@("`@("`@("`D:"`](#`["B`@("`@("`@("`@('T@96QS96EF("@D:"`^
M(#4Y*2!["B`@("`@("`@("`@("`@("`D:"`](#4Y.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H)&P@/B`D:"D@>PH@("`@("`@("`@("`@("`@
M)'1M<"`]("1L.PH@("`@("`@("`@("`@("`@)&P@/2`D:#L*("`@("`@("`@
M("`@("`@("1H(#T@)'1M<#L*("`@("`@("`@("`@("`@('5N<V5T*"1T;7`I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!&;W(@<V]M92!R96%S
M;VX@<F%N9V4H*2!D;V5S;B=T('=O<FL@=R]O('1H92!E>'!L:6-I=`H@("`@
M("`@("`@("`O+R!I;G1V86PH*2!C86QL<RX*("`@("`@("`@("`@<F5T=7)N
M("<M)R`N(&IO:6XH)RTG+"!R86YG92AI;G1V86PH)&PI+"!I;G1V86PH)&@I
M*2D@+B`G+2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@26YV
M86QI9"X*("`@("`@("`@("`@9&EE*"));G9A;&ED('9A;'5E("<D;"<@:6X@
M<F%N9V4@)R1L+21H)R(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!D87E686QU92@D<RD*("`@('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!C;W5N="@D=&AI<RT^;&5G86Q$87ES*3L@)&DK*RD@>PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/FQE9V%L1&%Y<ULD:5T@/3T@)',I('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("TQ.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES1&EG:70H
M)',I"B`@("!["B`@("`@("`@<F5T=7)N('!R96=?;6%T8V@H)R]>7&0K)"\G
M+"`D<RD["B`@("!]"@H@("`@9G5N8W1I;VX@:7-!;'!H82@D<RD*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/FES3&5G86Q$87DH)',I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&ES3&5G86Q$87DH)',I"B`@("!["B`@("`@("`@<F5T
M=7)N(&EN7V%R<F%Y*"1S+"`D=&AI<RT^;&5G86Q$87ES*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!G96YE<F%L;'E$96-E;G13>6YT87@H)',I"B`@("!["B`@
M("`@("`@<F5T=7)N("@D<R`]/2`G*B<@?'P*("`@("`@("`@("`@("`@('!R
M96=?;6%T8V@H)R]>7&0K*"U<9"LI/RA;(29=6T$M6EPJ72LH+5M!+5I<*ETK
M*3\I/R@L7&0K*"U<9"LI/RA;(29=6T$M6EPJ72LH+5M!+5I<*ETK*3\I/RDJ
M)"\G+"`D<RDI.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(`````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M-#`@,#(R,#$T`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]522]7
M:61G970N<&AP````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-#,U,B`Q,#4Q-30S-#$T,"`P,C$V,30`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D
M95]525]7:61G970Z.B!C;&%S<R!P<F]V:61E<R!B87-E(&9U;F-T:6]N86QI
M='D@9F]R(&]T:&5R($AO<F1E"B`J(%5)(&5L96UE;G1S+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]522]522]7:61G970N<&AP+'8@,2XW+C$P+C@@,C`P
M-B\P-B\R,"`P.3HP.#HT-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0'-I;F-E("`@2&]R9&5?54D@,"XP+C$*
M("H@0'!A8VMA9V4@2&]R9&5?54D*("HO"F-L87-S($AO<F1E7U5)7U=I9&=E
M="!["@H@("`@+RHJ"B`@("`@*B!!;GD@=F%R:6%B;&5S('1H870@<VAO=6QD
M(&)E('!R97-E<G9E9"!I;B!A;&P@;V8@=&AE('=I9&=E="=S"B`@("`@*B!L
M:6YK<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W!R97-E<G9E(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!N
M86UE(&]F('1H:7,@=VED9V5T+B`@5&AI<R!I<R!U<V5D(&%S('1H92!B87-E
M;F%M92!F;W(@=F%R:6%B;&5S"B`@("`@*B!W92!A8V-E<W,@86YD(&UA;FEP
M=6QA=&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?;F%M93L*"B`@("`O*BH*("`@("`J($$@<F5F97)E;F-E('1O(&$@
M5F%R:6%B;&5S.CH@;V)J96-T('1H:7,@=VED9V5T('=I;&P@=7-E(&%N9`H@
M("`@("H@;6%N:7!U;&%T92X*("`@("`J"B`@("`@*B!`=F%R(%9A<FEA8FQE
M<PH@("`@("HO"B`@("!V87(@)%]V87)S.PH*("`@("\J*@H@("`@("H@06X@
M87)R87D@;V8@;F%M92`]/B!V86QU92!P86ER<R!W:&EC:"!C;VYF:6=U<F4@
M:&]W('1H:7,@=VED9V5T"B`@("`@*B!B96AA=F5S+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V]N9FEG.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T(&$@;F5W(%5)(%=I9&=E="!I;G1E<F9A8V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@(%1H92!N
M86UE(&]F('1H92!V87)I86)L92!W:&EC:"!W:6QL('1R86-K('1H:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!522!W:61G970G<R!S=&%T
M92X*("`@("`J($!P87)A;2!687)I86)L97,@)B1V87)S("!!(%9A<FEA8FQE
M<SHZ(&]B:F5C="X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9FEG("`@("!4
M:&4@=VED9V5T)W,@8V]N9FEG=7)A=&EO;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@2&]R9&5?54E?5VED9V5T*"1N86UE+"`F)'9A<G,L("1C;VYF:6<@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M92`]("1N86UE.PH@
M("`@("`@("1T:&ES+3Y?=F%R<R`]("8D=F%R<SL*("`@("`@("`D=&AI<RT^
M7V-O;F9I9R`]("1C;VYF:6<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-T
M<G5C="!(;W)D95]525]7:61G970Z.B!T;R!P<F5S97)V92!A('9A<FEA8FQE
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'9A<B`@(%1H92!N86UE
M(&]F('1H92!V87)I86)L92!T;R!P<F5S97)V92X*("`@("`J($!P87)A;2!M
M:7AE9"`D=F%L=64@(%1H92!V86QU92!O9B!T:&4@=F%R:6%B;&4@=&\@<')E
M<V5R=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R97-E<G9E*"1V87(L("1V
M86QU92D*("`@('L*("`@("`@("`D=&AI<RT^7W!R97-E<G9E6R1V87)=(#T@
M)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&10<F5S97)V960H)&QI;FLI"B`@
M("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P<F5S97)V92!A<R`D=F%R
M3F%M92`]/B`D=F%R5F%L=64I('L*("`@("`@("`@("`@)&QI;FL@/2!5=&EL
M.CIA9&1087)A;65T97(H)&QI;FLL("1V87).86UE+"`D=F%R5F%L=64I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&QI;FL["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296YD97(@=&AE('=I9&=E="X*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1A=&$@(%1H92!W
M:61G970G<R!S=&%T92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD
M97(H*2![?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]522]486)S+G!H<```````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-C8R,"`Q,#4Q-30S-#$T,"`P,C$R-C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O5VED9V5T+G!H<"<[
M"@HO*BH*("H@5&AE($AO<F1E7U5)7U1A8G,Z.B!C;&%S<R!M86YA9V5S(&%N
M9"!R96YD97)S(&$@=&%B+6QI:V4@:6YT97)F86-E+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]522]522]486)S+G!H<"QV(#$N,C<N-BXQ,"`R,#`V+S`V
M+S(P(#`Y.C`X.C0U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR
M,#`S(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE0&AO=&UA:6PN8V]M
M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E
M;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<VEN8V4@
M("!(;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA
M<W,@2&]R9&5?54E?5&%B<R!E>'1E;F1S($AO<F1E7U5)7U=I9&=E="!["@H@
M("`@+RHJ"B`@("`@*B!4:&4@87)R87D@;V8@=&%B<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1A8G,@/2!A<G)A>2@I
M.PH*("`@("\J*@H@("`@("H@061D(&$@=&%B('1O('1H92!I;G1E<F9A8V4N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@("`@5&AE('1E
M>'0@=VAI8V@@87!P96%R<R!O;B!T:&4@=&%B+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;&EN:R`@("`@5&AE('1A<F=E="!P86=E+@H@("`@("H@0'!A<F%M
M(&UI>&5D("`D<&%R86US("`@16ET:&5R(&$@<W1R:6YG('9A;'5E('1O('-E
M="!T:&4@=&%B('9A<FEA8FQE('1O+`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@;W(@82!H87-H(&]F('!A<F%M971E<G,N($EF(&%N(&%R<F%Y
M+"!T:&4@=&%B('9A<FEA8FQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!C86X@8F4@<V5T(&)Y('1H92`G=&%B;F%M92<@:V5Y+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A9&1486(H)'1I=&QE+"`D;&EN:RP@)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US
M*2D@>PH@("`@("`@("`@("`D<&%R86US(#T@87)R87DH)W1A8FYA;64G(#T^
M("1P87)A;7,I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1A8G-;72`]
M(&%R<F%Y7VUE<F=E*&%R<F%Y*"=T:71L92<@/3X@)'1I=&QE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG(#T^
M("1L:6YK+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1A8FYA;64G(#T^(&YU;&PI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971R:65V92!T:&4@=&ET;&4@;V8@=&AE('1A8B!W:71H('1H92!S
M<&5C:69I960@;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M86)N86UE("!4:&4@;F%M92!O9B!T:&4@=&%B+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=&%B)W,@=&ET;&4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1I=&QE1G)O;4%C=&EO;B@D=&%B;F%M92D*("`@('L*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7W1A8G,@87,@)'1A8BD@>PH@("`@("`@
M("`@("!I9B`H)'1A8ELG=&%B;F%M92==(#T]("1T86)N86UE*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1A8ELG=&ET;&4G73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296YD97)S('1H92!T86)S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&%C=&EV95]T86(@($EF('-P96-I9FEE9"P@=&AE(&YA
M;64@;V8@=&AE(&%C=&EV92!T86(N($EF"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!N;W0L('1H92!A8W1I=F4@=&%B(&ES(&1E=&5R;6EN
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%U=&]M871I
M8V%L;'DN"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D86-T:79E7W1A
M8B`](&YU;&PI"B`@("!["B`@("`@("`@)&AT;6P@/2`B/&1I=B!C;&%S<SU<
M(G1A8G-E=%PB/CQU;#Y<;B(["@H@("`@("`@("1F:7)S="`]('1R=64["B`@
M("`@("`@)&%C=&EV92`]("1?4T525D526R=02%!?4T5,1B==("X@)'1H:7,M
M/E]V87)S+3YG970H)'1H:7,M/E]N86UE*3L*"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]T86)S(&%S("1T86(I('L*("`@("`@("`@("`@)&QI;FL@/2`D
M=&AI<RT^7V%D9%!R97-E<G9E9"@D=&%B6R=L:6YK)UTI.PH@("`@("`@("`@
M("!I9B`H(6ES7VYU;&PH)'1H:7,M/E]N86UE*2`F)B`A:7-?;G5L;"@D=&%B
M6R=T86)N86UE)UTI*2!["B`@("`@("`@("`@("`@("`D;&EN:R`](%5T:6PZ
M.F%D9%!A<F%M971E<B@D;&EN:RP@)'1H:7,M/E]N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A8ELG=&%B;F%M
M92==*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-L87-S(#T@)R<[
M"B`@("`@("`@("`@(&EF("@H(6ES7VYU;&PH)&%C=&EV95]T86(I("8F("1A
M8W1I=F5?=&%B(#T]("1T86);)W1A8FYA;64G72D@?'P*("`@("`@("`@("`@
M("`@("@D86-T:79E(#T]("1T86);)VQI;FLG72`N("1T86);)W1A8FYA;64G
M72DI('L*("`@("`@("`@("`@("`@("1C;&%S<R`]("<@8VQA<W,](F%C=&EV
M951A8B(G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T86);)W1A<F=E="==*2D@>PH@("`@("`@("`@("`@("`@)'1A8ELG=&%R
M9V5T)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&%B6R=O;F-L:6-K)UTI*2!["B`@("`@("`@("`@("`@("`D=&%B
M6R=O;F-L:6-K)UT@/2`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&%C8V5S<VME>2`]($AO<F1E.CIG971!8V-E<W-+97DH)'1A8ELG=&ET;&4G
M72D["@H@("`@("`@("`@("`D:'1M;"`N/2`G/&QI)R`N("1C;&%S<R`N("<^
M)R`N"B`@("`@("`@("`@("`@("!(;W)D93HZ;&EN:R@D;&EN:RP@)R<L("<G
M+"`D=&%B6R=T87)G970G72P@)'1A8ELG;VYC;&EC:R==+"!N=6QL+"`D86-C
M97-S:V5Y*2`N"B`@("`@("`@("`@("`@("!(;W)D93HZ:&EG:&QI9VAT06-C
M97-S2V5Y*'-T<E]R97!L86-E*"<@)RP@)R9N8G-P.R<L("1T86);)W1I=&QE
M)UTI+"`D86-C97-S:V5Y*2`N"B`@("`@("`@("`@("`@("`B/"]A/B`\+VQI
M/EQN(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N("(\+W5L
M/CPO9&EV/CQB<B!C;&%S<SU<(F-L96%R7"(@+SY<;B(["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O54DO3&%N9W5A9V4N<&AP````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,R-#`@,3`U,34T,S0Q-#`@,#(R,3`W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@2&]R9&5?54E?3&%N9W5A9V4Z.B!C;&%S<R!P<F]V:61E<R!A
M('=I9&=E="!F;W(@8VAA;F=I;F<@=&AE"B`J(&-U<G)E;G1L>2!S96QE8W1E
M9"!L86YG=6%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO54DO54DO3&%N
M9W5A9V4N<&AP+'8@,2XU+C$P+C<@,C`P-B\P-B\R,"`P.3HP.#HT-2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI
M8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0'-I;F-E("`@2&]R9&5?54D@,"XP+C$*("H@0'!A8VMA9V4@2&]R9&5?54D*
M("HO"F-L87-S($AO<F1E7U5)7TQA;F=U86=E('L*"B`@("`O*BH*("`@("`J
M(%)E;F1E<B!T:&4@;&%N9W5A9V4@<V5L96-T:6]N+@H@("`@("H*("`@("`J
M($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1F;W)M
M("!2971U<FX@=&AE('-E;&5C=&EO;B!B;W@@87,@86X@8V]M<&QE=&4@<W1A
M;F1A;&]N90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&9O<FTN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!(5$U,('-E;&5C=&EO
M;B!B;W@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@I"B`@("!["B`@
M("`@("`@)&AT;6P@/2`G)SL*("`@("`@("!I9B`H(21'3$]"04Q36R=P<F5F
M<R==+3YI<TQO8VME9"@G;&%N9W5A9V4G*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ861D4V-R:7!T1FEL92@G;&%N9W5A9V4N:G,G+"`G:&]R9&4G*3L*("`@
M("`@("`@("`@)%]315-324].6R=H;W)D95]L86YG=6%G92==(#T@3DQ3.CIS
M96QE8W0H*3L*("`@("`@("`@("`@)&AT;6P@/2!S<')I;G1F*"<\9F]R;2!N
M86UE/2)L86YG=6%G92(@86-T:6]N/2(E<R(^)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($AO<F1E.CIU<FPH)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]L86YG=6%G
M92YP:'`G+"!F86QS92P@+3$I*3L*("`@("`@("`@("`@)&AT;6P@+CT@)SQI
M;G!U="!T>7!E/2)H:61D96XB(&YA;64](G5R;"(@=F%L=64](B<@+B!`:'1M
M;'-P96-I86QC:&%R<RA(;W)D93HZ<V5L9E5R;"AF86QS92P@9F%L<V4L('1R
M=64I*2`N("<B("\^)SL*("`@("`@("`@("`@)&AT;6P@+CT@)SQS96QE8W0@
M;F%M93TB;F5W7VQA;F<B(&]N8VAA;F=E/2)D;V-U;65N="YL86YG=6%G92YS
M=6)M:70H*2(^)SL*("`@("`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)VYL
M<R==6R=L86YG=6%G97,G72!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@
M("`@("`@("1S96P@/2`H)&ME>2`]/2`D7U-%4U-)3TY;)VAO<F1E7VQA;F=U
M86=E)UTI(#\@)R!S96QE8W1E9#TB<V5L96-T960B)R`Z("<G.PH@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@(CQO<'1I;VX@=F%L=64]7"(D:V5Y7"(D<V5L
M/B1V86P\+V]P=&EO;CXB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H
M=&UL("X]("<\+W-E;&5C=#X\+V9O<FT^)SL*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1H=&UL.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U5)+U9A<E)E;F1E<F5R+G!H<```````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$P,C(Q(#$P-3$U-#,T,30P(#`R,C8P,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@8VQA<W,@<')O=FED97,@8F%S
M92!F=6YC=&EO;F%L:71Y(&9O<@H@*B!O=&AE<B!(;W)D92!522!E;&5M96YT
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO54DO54DO5F%R4F5N9&5R97(N
M<&AP+'8@,2XQ,BXQ,"XQ,"`R,#`V+S`V+S(P(#`Y.C`X.C0U(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`<VEN
M8V4@("!(;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*
M8VQA<W,@2&]R9&5?54E?5F%R4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@
M4&%R86UE=&5R<R!W:&EC:"!C:&%N9V4@=&AI<R!R96YD97)E<B=S(&)E:&%V
M:6]R+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<&%R86US.PH*("`@("\J*@H@("`@("H@0VAA<G-E="!T;R!U<V4@9F]R
M(&]U='!U="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C:&%R<V5T.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A
M(&YE=R!R96YD97)E<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@5&AE(&YA;64@;V8@=&AE('9A<FEA8FQE('=H:6-H('=I;&P@=')A
M8VL@=&AI<R!520H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('=I9&=E
M="=S('-T871E+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]525]687)2
M96YD97)E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("`@("`@)'1H:7,M/E]C:&%R<V5T
M(#T@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@:6YS=&%N
M8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV97(@(%1H:7,@
M:7,@=&AE(')E;F1E<F5R('-U8F-L87-S('=E('=I;&P@:6YS=&%N=&EA=&4N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@268@86X@87)R87D@:7,@
M<&%S<V5D+"!T:&4@9FER<W0@96QE;65N="!I<R!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!L:6)R87)Y('!A=&@@86YD('1H92!S96-O;F0@
M96QE;65N="!I<R!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@;F%M92X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!087)A
M;65T97)S('-P96-I9FEC('1O('1H92!S=6)C;&%S<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N($AO<F1E7U5)7U9A<E)E;F1E<F5R("!!($AO<F1E7U5)7U9A
M<E)E;F1E<F5R.CH@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@("`@("`@("`@)&%P
M<"`]("1D<FEV97);,%T["B`@("`@("`@("`@("1D<FEV97(@/2`D9')I=F5R
M6S%=.PH@("`@("`@('T*"B`@("`@("`@)&1R:79E<B`](&)A<V5N86UE*"1D
M<FEV97(I.PH*("`@("`@("!I9B`H(65M<'1Y*"1A<'`I*2!["B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=F
M:6QE<F]O="<L("1A<'`I("X@)R]L:6(O54DO5F%R4F5N9&5R97(O)R`N("1D
M<FEV97(@+B`G+G!H<"<["B`@("`@("`@?2!E;'-E:68@*$!F:6QE7V5X:7-T
M<RAD:7)N86UE*%]?1DE,15]?*2`N("<O5F%R4F5N9&5R97(O)R`N("1D<FEV
M97(@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G
M+G!H<"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?
M;VYC92`G2&]R9&4O54DO5F%R4F5N9&5R97(O)R`N("1D<FEV97(@+B`G+G!H
M<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?54E?5F%R
M4F5N9&5R97)?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1V<B`]("9N97<@)&-L87-S*"1P
M87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V<B`](%!%
M05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S
M<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1V<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!(;W)D95]5
M25]687)296YD97)E<CHZ(&EN<W1A;F-E+"!C;VYS=')U8W1I;F<@;VYE('=I
M=&@@=&AE"B`@("`@*B!S<&5C:69I960@<&%R86UE=&5R<R!I9B!N96-E<W-A
M<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4:&ES
M(&ES('1H92!R96YD97)E<B!S=6)C;&%S<R!W92!W:6QL"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&EN<W1A;G1I871E+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("!087)A;65T97)S('-P96-I9FEC('1O('1H92!S
M=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E7U5)7U9A<E)E
M;F1E<F5R("!!($AO<F1E7U5)7U9A<E)E;F1E<F5R.CH@<W5B8VQA<W,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN<W1A;F-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE=&]N*"1D<FEV97(L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@
M("`@("`@(&EF("AI<U]N=6QL*"1D<FEV97(I*2!["B`@("`@("`@("`@("1C
M;&%S<R`]("=(;W)D95]525]687)296YD97)E<B<["B`@("`@("`@?0H@("`@
M("`@("1K97D@/2!S97)I86QI>F4H87)R87D@*"1D<FEV97(L("1P87)A;7,I
M*3L*("`@("`@("!I9B`H(6ES<V5T*"1C86-H95LD:V5Y72DI('L*("`@("`@
M("`@("`@)&-A8VAE6R1K97E=(#T@)DAO<F1E7U5)7U9A<E)E;F1E<F5R.CIF
M86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&-A8VAE6R1K97E=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N
M9&5R<R!A('9A<FEA8FQE+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]&
M;W)M("8D9F]R;2`@("`@("`@("`@4F5F97)E;F-E('1O(&$@2&]R9&5?1F]R
M;2!I;G-T86YC92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W(@;G5L;"!I9B!N;VYE(&ES(&%V86EL86)L92X*("`@("`J
M($!P87)A;2!(;W)D95]&;W)M7U9A<FEA8FQE("8D=F%R("`@4F5F97)E;F-E
M('1O(&$@2&]R9&5?1F]R;5]687)I86)L92X*("`@("`J($!P87)A;2!687)I
M86)L97,@)B1V87)S("`@("`@("`@("`@02!687)I86)L97,@:6YS=&%N8V4N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:7-);G!U="`@("`@("`@("`@(%=H
M971H97(@=&AI<R!I<R!A;B!I;G!U="!F:65L9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R*"8D9F]R;2P@)B1V87(L("8D=F%R<RP@)&ES26YP=70@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&ES26YP=70I('L*("`@("`@
M("`@("`@)'-T871E(#T@)TEN<'5T)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<W1A=&4@/2`G1&ES<&QA>2<["B`@("`@("`@?0H@("`@("`@
M("1M971H;V0@/2`B7W)E;F1E<E9A<B1[<W1A=&5]7R(@+B`D=F%R+3YT>7!E
M+3YG9714>7!E3F%M92@I.PH@("`@("`@(&EF("@A0&UE=&AO9%]E>&ES=',H
M)'1H:7,L("1M971H;V0I*2!["B`@("`@("`@("`@("1M971H;V0@/2`B7W)E
M;F1E<E9A<B1[<W1A=&5]1&5F875L="(["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D=&AI<RT^)&UE=&AO9"@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1FEN:7-H97,@<F5N9&5R:6YG(&%F=&5R(&%L
M;"!F:65L9',@87)E(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R16YD*"D*("`@('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O54DO4&%G
M97(N<&AP````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#<U-C8@,3`U,34T,S0Q-#`@,#(Q-#0Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+U=I9&=E="YP:'`G.PH*+RHJ"B`J(%1H92!(
M;W)D95]525]086=E<CHZ('!R;W9I9&5S(&QI;FMS('1O(&EN9&EV:61U86P@
M<&%G97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U5)+U5)+U!A9V5R+G!H
M<"QV(#$N-RXQ,"XX(#(P,#8O,#8O,C`@,#DZ,#@Z,C8@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F]E;"!686YD86P@/&IV86YD86Q`
M:6YF;W1E8VLN<6,N8V$^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!"
M96X@0VAA=F5T(#QB96Y`8VAA=F5T+FYE=#X*("H@0&%U=&AO<B`@2F]E;"!6
M86YD86P@/&IV86YD86Q`:6YF;W1E8VLN<6,N8V$^"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA<W,@
M2&]R9&5?54E?4&%G97(@97AT96YD<R!(;W)D95]525]7:61G970@>PH*("`@
M(&9U;F-T:6]N($AO<F1E7U5)7U!A9V5R*"1N86UE+"`F)'9A<G,L("1C;VYF
M:6<I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D8V]N9FEG6R=P86=E7VQI
M;6ET)UTI*2!["B`@("`@("`@("`@("1C;VYF:6=;)W!A9V5?;&EM:70G72`]
M(#$P.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1C;VYF:6=;)W!E
M<G!A9V4G72DI('L*("`@("`@("`@("`@)&-O;F9I9ULG<&5R<&%G92==(#T@
M,3`P.PH@("`@("`@('T*("`@("`@("!P87)E;G0Z.DAO<F1E7U5)7U=I9&=E
M="@D;F%M92P@)'9A<G,L("1C;VYF:6<I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5N9&5R('1H92!P86=E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@2%1-3"!C;V1E(&-O;G1A:6YI;F<@82!C96YT97)E9"!T86)L92!W
M:71H('1H92!P86=E<@H@("`@("H@("`@("!L:6YK<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N9&5R*"D*("`@('L*("`@("`@("!G;&]B86P@)'!R969S
M+"`D<F5G:7-T<GDL("1C;VYF.PH*("`@("`@("`D;G5M(#T@)'1H:7,M/E]C
M;VYF:6=;)VYU;2==.PH@("`@("`@("1U<FP@/2`D=&AI<RT^7V-O;F9I9ULG
M=7)L)UT["B`@("`@("`@)'!A9V5?;&EM:70@/2`D=&AI<RT^7V-O;F9I9ULG
M<&%G95]L:6UI="==.PH@("`@("`@("1P97)P86=E(#T@)'1H:7,M/E]C;VYF
M:6=;)W!E<G!A9V4G73L*"B`@("`@("`@)&-U<G)E;G1?<&%G92`]("1T:&ES
M+3Y?=F%R<RT^9V5T*"1T:&ES+3Y?;F%M92D["@H@("`@("`@("\O($9I9W5R
M92!O=70@:&]W(&UA;GD@<&%G97,@=&AE<F4@=VEL;"!B92X*("`@("`@("`D
M<&%G97,@/2`H)&YU;2`O("1P97)P86=E*3L*("`@("`@("!I9B`H:7-?:6YT
M96=E<B@D<&%G97,I*2!["B`@("`@("`@("`@("1P86=E<RTM.PH@("`@("`@
M('T*("`@("`@("`D<&%G97,@/2`H:6YT*21P86=E<SL*"B`@("`@("`@+R\@
M4F5T=7)N(&YO=&AI;F<@:68@=&AE<F4@:7,@;VYL>2!O;F4@<&%G92X*("`@
M("`@("!I9B`H)'!A9V5S(#T](#`@?'P@)&YU;2`]/2`P*2!["B`@("`@("`@
M("`@(')E='5R;B`G)SL*("`@("`@("!]"@H@("`@("`@("1H=&UL(#T@)SQD
M:78@8VQA<W,](G!A9V5R(CXG.PH*("`@("`@("`O+R!#<F5A=&4@=&AE("<\
M/"!0<F5V)R!L:6YK(&EF('=E(&%R92!N;W0@;VX@=&AE(&9I<G-T('!A9V4N
M"B`@("`@("`@)&QI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)'1H
M:7,M/E]N86UE+"`D8W5R<F5N=%]P86=E("T@,2D["B`@("`@("`@)&QI;FL@
M/2`D=&AI<RT^7V%D9%!R97-E<G9E9"@D;&EN:RD["B`@("`@("`@:68@*"1C
M=7)R96YT7W!A9V4@/B`P*2!["B`@("`@("`@("`@("1H=&UL("X]($AO<F1E
M.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN:RDL("<G+"`G<')E
M=B<I("X@:'1M;'-P96-I86QC:&%R<RA?*"(\4')E=FEO=7,B*2D@+B`G/"]A
M/B<["B`@("`@("`@?0H*("`@("`@("`O+R!&:6=U<F4@;W5T('1H92!T;W`@
M)B!B;W1T;VT@9&ES<&QA>2!L:6UI=',N"B`@("`@("`@)&)O='1O;2`](&UA
M>"@P+"`D8W5R<F5N=%]P86=E("T@*"1P86=E7VQI;6ET("\@,BD@*R`Q*3L*
M("`@("`@("`D=&]P(#T@)&)O='1O;2`K("1P86=E7VQI;6ET("T@,3L*("`@
M("`@("!I9B`H)'1O<"`M(#$@/B`D<&%G97,I('L*("`@("`@("`@("`@)&)O
M='1O;2`M/2`H)'1O<"`M(#$I("T@)'!A9V5S.PH@("`@("`@("`@("`D=&]P
M(#T@)'!A9V5S("L@,3L*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!B
M;W1T;VT@)UMX+7E=)R!L:6YK(&EF(&YE8V5S<V%R>2X*("`@("`@("`D;&EN
M:R`]("1T:&ES+3Y?861D4')E<V5R=F5D*%5T:6PZ.F%D9%!A<F%M971E<B@D
M=7)L+"`D=&AI<RT^7VYA;64L("1B;W1T;VT@+2`Q*2D["B`@("`@("`@:68@
M*"1B;W1T;VT@/B`P*2!["B`@("`@("`@("`@("1H=&UL("X]("<@)R`N($AO
M<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN:RDL("<G+"`G
M<')E=E)A;F=E)RD@+B`G6R<@+B`H)&)O='1O;2`]/2`Q(#\@)&)O='1O;2`Z
M("<Q+2<@+B`D8F]T=&]M*2`N("==/"]A/B<["B`@("`@("`@?0H*("`@("`@
M("`O+R!#<F5A=&4@;&EN:W,@=&\@:6YD:79I9'5A;"!P86=E<R!B971W965N
M(&QI;6ET<RX*("`@("`@("!F;W(@*"1I(#T@)&)O='1O;3L@)&D@/#T@)'1O
M<"`F)B`D:2`\/2`D<&%G97,[("LK)&DI('L*("`@("`@("`@("`@:68@*"1I
M(#T]("1C=7)R96YT7W!A9V4I('L*("`@("`@("`@("`@("`@("1H=&UL("X]
M("<@/'-T<F]N9SXH)R`N("@D:2`K(#$I("X@)RD\+W-T<F]N9SXG.PH@("`@
M("`@("`@("!](&5L<V5I9B`H)&D@/CT@,"`F)B`D:2`\/2`D<&%G97,I('L*
M("`@("`@("`@("`@("`@("1L:6YK(#T@)'1H:7,M/E]A9&10<F5S97)V960H
M571I;#HZ861D4&%R86UE=&5R*"1U<FPL("1T:&ES+3Y?;F%M92P@)&DI*3L*
M("`@("`@("`@("`@("`@("1H=&UL("X]("<@)R`N($AO<F1E.CIL:6YK*$AO
M<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN:RDI("X@*"1I("L@,2D@+B`G/"]A
M/B<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-R96%T
M92!T;W`@)UMX+7E=)R!L:6YK(&EF(&YE8V5S<V%R>2X*("`@("`@("!I9B`H
M)'1O<"`\("1P86=E<RD@>PH@("`@("`@("`@("`D;&EN:R`]("1T:&ES+3Y?
M861D4')E<V5R=F5D*%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`D=&AI<RT^
M7VYA;64L("1T;W`@*R`Q*2D["B`@("`@("`@("`@("1H=&UL("X]("<@)R`N
M($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN:RDL("<G
M+"`G;F5X=%)A;F=E)RD@+B`G6R<@+@H@("`@("`@("`@("`@("`@*"1T;W`@
M*R`R(#T]("1P86=E<R`K(#$@/R`D<&%G97,@*R`Q(#H@*"1T;W`@*R`R*2`N
M("<M)R`N("@D<&%G97,@*R`Q*2D@+B`G73PO83XG.PH@("`@("`@('T*"B`@
M("`@("`@+R\@0W)E871E('1H92`G3F5X=#X^)R!L:6YK(&EF('=E(&%R92!N
M;W0@;VX@=&AE(&QA<W0@<&%G92X*("`@("`@("!I9B`H)&-U<G)E;G1?<&%G
M92`\("1P86=E<RD@>PH@("`@("`@("`@("`D;&EN:R`]("1T:&ES+3Y?861D
M4')E<V5R=F5D*%5T:6PZ.F%D9%!A<F%M971E<B@D=7)L+"`D=&AI<RT^7VYA
M;64L("1C=7)R96YT7W!A9V4@*R`Q*2D["B`@("`@("`@("`@("1H=&UL("X]
M("<@)R`N($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@D;&EN
M:RDL("<G+"`G;F5X="<I("X@:'1M;'-P96-I86QC:&%R<RA?*").97AT/B(I
M*2`N("<\+V$^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;"`N
M("<\+V1I=CXG.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O54DO5F%R4F5N9&5R97(O:'1M;"YP:'``````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`R,#$U-C4@,3`U,34T,S0Q-#`@,#(S-38Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4:&4@2&]R9&5?54E?5F%R4F5N9&5R97)?:'1M;#HZ(&-L87-S
M(')E;F1E<G,@=F%R:6%B;&5S('1O($A434PN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U5)+U5)+U9A<E)E;F1E<F5R+VAT;6PN<&AP+'8@,2XY."XR+C(X
M(#(P,#8O,#@O,38@,3(Z,3<Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($Q)0T5.4T4@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+@H@*@H@*B!`<VEN8V4@("!(
M;W)D95]522`P+C`N,0H@*B!`<&%C:V%G92!(;W)D95]520H@*B\*8VQA<W,@
M2&]R9&5?54E?5F%R4F5N9&5R97)?:'1M;"!E>'1E;F1S($AO<F1E7U5)7U9A
M<E)E;F1E<F5R('L*"B`@("!V87(@)%]O;DQO861*4R`](&%R<F%Y*"D["@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T1&5F875L="@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("<\<W1R;VYG/E=A
M<FYI;F<Z/"]S=')O;F<^(%5N:VYO=VX@=F%R:6%B;&4@='EP92`G("X*("`@
M("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5'EP94YA;64H
M*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;G5M8F5R*"8D9F]R;2P@)B1V87(L
M("8D=F%R<RD*("`@('L*("`@("`@("`D=F%L=64@/2`D=F%R+3YG971686QU
M92@D=F%R<RD["B`@("`@("`@:68@*&ES<V5T*"1V87(M/G1Y<&4M/E]F<F%C
M=&EO;BDI('L*("`@("`@("`@("`@)'9A;'5E(#T@<W!R:6YT9B@G)3`Q+B<@
M+B`D=F%R+3YT>7!E+3Y?9G)A8W1I;VX@+B`G9B<L("1V86QU92D["B`@("`@
M("`@?0H@("`@("`@("1L:6YF;R`]($Y,4SHZ9V5T3&]C86QE26YF;R@I.PH@
M("`@("`@("\J($]N;'D@:68@=&AE<F4@:7,@82!M;VY?9&5C:6UA;%]P;VEN
M="!D;R!T:&4*("`@("`@("`@*B!S=6)S=&ET=71I;VXN("HO"B`@("`@("`@
M:68@*"%E;7!T>2@D;&EN9F];)VUO;E]D96-I;6%L7W!O:6YT)UTI*2!["B`@
M("`@("`@("`@("1V86QU92`]('-T<E]R97!L86-E*"<N)RP@)&QI;F9O6R=M
M;VY?9&5C:6UA;%]P;VEN="==+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@
M("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA
M;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R
M971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C4B(&YA
M;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E+`H@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BD*("`@("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5F%R26YP=71?:6YT*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S
M*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E
M>'0B('-I>F4](C4B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD*
M("`@("`@("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71?;V-T86PH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T
M5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@
M("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@<VEZ93TB
M-2(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@
M("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F
M*"<P)6\G+"!O8W1D96,H)'9A<BT^9V5T5F%L=64H)'9A<G,I*2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F
M;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)687));G!U=%]I;G1L:7-T*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H
M87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4]
M(G1E>'0B(&YA;64](B5S(B!I9#TB)7,B('9A;'5E/2(E<R(E<R`O/B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BD*("`@("`@
M("`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP
M=71?=&5X="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@
M)&UA>&QE;F=T:"`]("1V87(M/G1Y<&4M/F=E=$UA>$QE;F=T:"@I.PH@("`@
M("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B
M(&ED/2(E<R(@<VEZ93TB)7,B('9A;'5E/2(E<R(@)7,E<R5S("\^)RP*("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M+3YT>7!E+3YG9713:7IE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87(M/FES1&ES86)L960H*2`_("<@9&ES86)L960](F1I<V%B;&5D(B`G
M(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)&UA>&QE;F=T
M:"D@/R`G)R`Z("<@;6%X;&5N9W1H/2(G("X@)&UA>&QE;F=T:"`N("<B)RP*
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP
M=',H)&9O<FTL("1V87(I"B`@("`@("`@("`@("`@("D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W=E871H97)D;W1C;VTH)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)E;F1E<E9A<DEN<'5T7W1E>'0H)&9O<FTL("1V87(L("1V87)S*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?<W1R:6YG;&ES="@F
M)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@
M/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN
M=&8H)SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(V,"(@;F%M93TB)7,B(&ED
M/2(E<R(@=F%L=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R
M+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E
M="DL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY3
M8W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]C96QL<&AO;F4H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@<VEZ93TB,34B
M('9A;'5E/2(E<R(@)7,E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@
M)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^
M9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/FES1&ES86)L960H*2`_
M("<@9&ES86)L960](F1I<V%B;&5D(B`G(#H@)R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R
M*0H@("`@("`@("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687));G!U=%]I<&%D9')E<W,H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A
M<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@
M;F%M93TB)7,B(&ED/2(E<R(@<VEZ93TB,38B('9A;'5E/2(E<R(@)7,E<R`O
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%
M3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@
M("`@("`@("1V87(M/FES1&ES86)L960H*2`_("<@9&ES86)L960](F1I<V%B
M;&5D(B`G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G
M971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*0H@("`@("`@("`@("`@("`I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]F:6QE*"8D
M9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]
M($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R971U<FX@<W!R:6YT
M9B@G/&EN<'5T('1Y<&4](F9I;&4B('-I>F4](C,P(B!N86UE/2(E<R(@:60]
M(B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V
M87(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($!T;V1O(%-H;W<@:6UA9V4@
M9&EM96YS:6]N<R!I;B!T:&4@=VED=&@O:&5I9VAT(&)O>&5S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?:6UA9V4H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@:'1M;'-P
M96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DI.PH@("`@("`@("1I;6%G
M92`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*"B`@("`@("`@+RH@0VAE8VL@
M:68@97AI<W1I;F<@:6UA9V4@9&%T82!I<R!B96EN9R!L;V%D960N("HO"B`@
M("`@("`@)'9A<BT^='EP92T^7VQO861);6%G941A=&$H)&EM86=E*3L*"B`@
M("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)VEM86=E+FIS)RP@)VAO<F1E
M)RP@=')U92D["B`@("`@("`@)&=R87!H:6-S7V1I<B`]("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG971);6%G941I<B@G:&]R9&4G*3L*("`@("`@("`D:6UG
M7V1I<B`]("1G<F%P:&EC<U]D:7(@+B`G+VEM86=E)SL*"B`@("`@("`@)&AT
M;6P@/2`G)SL*"B`@("`@("`@+RH@0VAE8VL@:68@=&AE<F4@:7,@97AI<W1I
M;F<@:6UG(&EN9F]R;6%T:6]N('-T;W)E9"X@*B\*("`@("`@("!I9B`H:7-S
M970H)&EM86=E6R=I;6<G72DI('L*("`@("`@("`@("`@+RH@2&ED9&5N('1A
M9R!T;R!S=&]R92!T:&4@<')E=FEE=R!I;6%G92!F:6QE;F%M92X@*B\*("`@
M("`@("`@("`@)&AT;6P@/2!S<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N
M(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B("\^)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@)UMI;6==)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@)UMI;6==)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1I
M;6%G95LG:6UG)UTL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@
M("`@("`@("`@("`O*B!5;G-E<FEA;&EZ92!T:&4@:6UG(&EN9F]R;6%T:6]N
M('1O(&=E="!T:&4@9G5L;"!A<G)A>2X@*B\*("`@("`@("`@("`@)&EM86=E
M6R=I;6<G72`]($!U;G-E<FEA;&EZ92@D:6UA9V5;)VEM9R==*3L*("`@("`@
M("!]"@H@("`@("`@("\J($]U='!U="!T:&4@:6YP=70@=&%G+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D:6UA9V5;)VEM9R==*2D@>PH@("`@("`@("`@("`D
M:G,@/2`B=F%R('`@/2!D;V-U;65N="YG971%;&5M96YT0GE)9"@G(B`N("1V
M87)N86UE("X@(EMP<F5V:65W72<I.R!O(#T@)UQ<7%PG.R!A(#T@)R\G.R!T
M;7`@/2`G)R`K(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"<B("X@)'9A<FYA
M;64@+B`B6VYE=UTG*2YV86QU93L@:68@*'1M<"D@>R!W:&EL92`H=&UP+FEN
M9&5X3V8H;RD@/B`M,2D@>R!P;W,@/2!T;7`N:6YD97A/9BAO*3L@=&UP(#T@
M)R<@*R`H=&UP+G-U8G-T<FEN9R@P+"!P;W,I("L@82`K('1M<"YS=6)S=')I
M;F<H*'!O<R`K(&\N;&5N9W1H*2P@=&UP+FQE;F=T:"DI.WT[('`N<W)C(#T@
M)V9I;&4Z+R\O)R`K('1M<#L@<"YA;'0@/2`G(B`N(&%D9'-L87-H97,H7R@B
M268@>6]U('-E92!T:&ES(&UE<W-A9V4@8G5T(&YO(&EM86=E+"!T:&4@:6UA
M9V4@>6]U('=A;G0@=&\@=7!L;V%D(&-A;B=T(&)E(&1I<W!L87EE9"!B>2!Y
M;W5R(&)R;W=S97(N(BDI("X@(B<[('T[(CL*("`@("`@("`@("`@)&)R;W=S
M97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["B`@("`@("`@("`@(&EF("@D
M8G)O=W-E<BT^:7-"<F]W<V5R*"=M<VEE)RDI('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQI;G!U="!T>7!E/2)F:6QE(B!S:7IE/2(S
M,"(@;F%M93TB)7,B(&ED/2(E<R(@;VYC:&%N9V4](B5S(B`O/B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE("X@)UMN97==
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@
M+B`G6VYE=UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:G,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@<W!R:6YT9B@G/&EN<'5T('1Y<&4](F9I;&4B('-I>F4](C,P(B!N
M86UE/2(E<R(@:60](B5S(B!O;F-L:6-K/2)W:6YD;W<N<V5T5&EM96]U="A<
M)V1O8W5M96YT+F=E=$5L96UE;G1">4ED*%Q<7"<E<UQ<7"<I+F)L=7(H*3M<
M)RP@-2D[(B!O;F)L=7(](B5S(B`O/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE("X@)UMN97==)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VYE=UTG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`N("=;;F5W
M72<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1J<RD["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:'1M
M;"`N/2!S<')I;G1F*"<\:6YP=70@='EP93TB9FEL92(@<VEZ93TB,S`B(&YA
M;64](B5S(B!I9#TB)7,B("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92`N("=;;F5W72<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64@+B`G6VYE=UTG*3L*("`@("`@("!]"@H@("`@
M("`@("\J($]U='!U="!T:&4@8G5T=&]N('1O('5P;&]A9"]R97-E="!T:&4@
M:6UA9V4N("HO"B`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]S:&]W7W5P;&]A
M9"D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G)FYB<W`[)SL*("`@("`@("`@
M("`@)&AT;6P@+CT@<W!R:6YT9B@G/&EN<'5T(&-L87-S/2)B=71T;VXB(&YA
M;64](B5S(B!I9#TB)7,B('1Y<&4](G-U8FUI="(@=F%L=64](B5S(B`O/B`G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?9&]?)R`N("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=?9&]?)R`N("1V
M87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%\H(E5P;&]A
M9"(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D:6UA9V5;)VEM
M9R==*2D@>PH@("`@("`@("`@("`O*B!.;R!I;6%G92!I;F9O<FUA=&EO;B!S
M=&]R960@>65T+"!S:&]W(&$@8FQA;FL@<')E=FEE=RX@*B\*("`@("`@("`@
M("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G=')E92]B;&%N:RYP;F<G+"!?*")0
M<F5V:65W(BDL("=W:61T:#TB-3`B(&AE:6=H=#TB-#`B(&ED/2(G("X@)'9A
M<FYA;64@+B`G6W!R979I97==(B<L("1G<F%P:&EC<U]D:7(I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\J($EM86=E(&EN9F]R;6%T:6]N('-T
M;W)E9"P@<VAO=R!P<F5V:65W+"!A9&0@8G5T=&]N<R!F;W(@:6UA9V4*("`@
M("`@("`@("`@("H@;6%N:7!U;&%T:6]N+B`J+PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/&)R("\^)SL*("`@("`@("`@("`@)&EM9R`]($AO<F1E.CIU<FPH
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I
M("X@)R]S97)V:6-E<R]I;6%G97,O=FEE=RYP:'`G*3L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1I;6%G95LG:6UG)UU;)W9F<U]I9"==*2D@>PH@("`@("`@
M("`@("`@("`@+RH@0V%L;&EN9R!A;B!I;6%G92!F<F]M(%9&4RX@*B\*("`@
M("`@("`@("`@("`@("1I;6<@/2!5=&EL.CIA9&1087)A;65T97(H)&EM9RP@
M87)R87DH)V8G(#T^("1I;6%G95LG:6UG)UU;)W9F<U]I9"==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<R<@/3X@)W9F<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=P)R`]/B`D:6UA9V5;)VEM9R==
M6R=V9G-?<&%T:"==*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`O*B!#86QL:6YG(&%N(&EM86=E(&9R;VT@82!T;7`@9&ER96-T
M;W)Y("AU<&QO861S*2X@*B\*("`@("`@("`@("`@("`@("1I;6<@/2!5=&EL
M.CIA9&1087)A;65T97(H)&EM9RP@)V8G+"`D:6UA9V5;)VEM9R==6R=F:6QE
M)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!297-E="X@*B\*
M("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH)R,G+"!?*")297-E
M="(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@)&EM9R`N("=<)RP@7"=?
M<%\G("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G
M<F5F<F5S:"YP;F<G+"!?*")297-E="(I+"`G86QI9VX](FUI9&1L92(G+"`D
M:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!2;W1A=&4@,C<P
M+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H
M(E)O=&%T92!,969T(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL
M.CIA9&1087)A;65T97(H)&EM9RP@87)R87DH)V$G(#T^("=R;W1A=&4G+"`G
M=B<@/3X@)S(W,"<I*2`N("=<)RP@7"=?<%\G("X@)'9A<FYA;64@+B`G7"<L
M('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G<F]T871E+3(W,"YP;F<G+"!?*")2
M;W1A=&4@3&5F="(I+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I<BD@+B`G
M/"]A/B<["@H@("`@("`@("`@("`O*B!2;W1A=&4@,3@P+B`J+PH@("`@("`@
M("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(E)O=&%T92`Q.#`B
M*2P@)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E
M<B@D:6UG+"!A<G)A>2@G82<@/3X@)W)O=&%T92<L("=V)R`]/B`G,3@P)RDI
M("X@)UPG+"!<)U]P7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(
M;W)D93HZ:6UG*"=R;W1A=&4M,3@P+G!N9R<L(%\H(E)O=&%T92`Q.#`B*2P@
M)V%L:6=N/2)M:61D;&4B)RP@)&EM9U]D:7(I("X@)SPO83XG.PH*("`@("`@
M("`@("`@+RH@4F]T871E(#DP+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(
M;W)D93HZ;&EN:R@G(R<L(%\H(E)O=&%T92!2:6=H="(I+"`G)RP@)R<L("=S
M:&]W26UA9V4H7"<G("X@571I;#HZ861D4&%R86UE=&5R*"1I;6<L(&%R<F%Y
M*"=A)R`]/B`G<F]T871E)RP@)W8G(#T^("<Y,"<I*2`N("=<)RP@7"=?<%\G
M("X@)'9A<FYA;64@+B`G7"<L('1R=64I.R<I("X@2&]R9&4Z.FEM9R@G<F]T
M871E+3DP+G!N9R<L(%\H(E)O=&%T92!2:6=H="(I+"`G86QI9VX](FUI9&1L
M92(G+"`D:6UG7V1I<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!&;&EP
M(&EM86=E+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G
M(R<L(%\H(D9L:7`B*2P@)R<L("<G+"`G<VAO=TEM86=E*%PG)R`N(%5T:6PZ
M.F%D9%!A<F%M971E<B@D:6UG+"`G82<L("=F;&EP)RD@+B`G7"<L(%PG7W!?
M)R`N("1V87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)V9L
M:7`N<&YG)RP@7R@B1FQI<"(I+"`G86QI9VX](FUI9&1L92(G+"`D:6UG7V1I
M<BD@+B`G/"]A/B<["@H@("`@("`@("`@("`O*B!-:7)R;W(@:6UA9V4N("HO
M"B`@("`@("`@("`@("1H=&UL("X]($AO<F1E.CIL:6YK*"<C)RP@7R@B36ER
M<F]R(BDL("<G+"`G)RP@)W-H;W=);6%G92A<)R<@+B!5=&EL.CIA9&1087)A
M;65T97(H)&EM9RP@)V$G+"`G;6ER<F]R)RD@+B`G7"<L(%PG7W!?)R`N("1V
M87)N86UE("X@)UPG+"!T<G5E*3LG*2`N($AO<F1E.CII;6<H)VUI<G)O<BYP
M;F<G+"!?*")-:7)R;W(B*2P@)V%L:6=N/2)M:61D;&4B)RP@)&EM9U]D:7(I
M("X@)SPO83XG.PH*("`@("`@("`@("`@+RH@07!P;'D@9W)A>7-C86QE+B`J
M+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G(R<L(%\H(D=R
M87ES8V%L92(I+"`G)RP@)R<L("=S:&]W26UA9V4H7"<G("X@571I;#HZ861D
M4&%R86UE=&5R*"1I;6<L("=A)RP@)V=R87ES8V%L92<I("X@)UPG+"!<)U]P
M7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@+B!(;W)D93HZ:6UG*"=G
M<F%Y<V-A;&4N<&YG)RP@7R@B1W)A>7-C86QE(BDL("=A;&EG;CTB;6ED9&QE
M(B<L("1I;6=?9&ER*2`N("<\+V$^)SL*"B`@("`@("`@("`@("\J(%)E<VEZ
M92!W:61T:"X@*B\*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G)7,\
M:6YP=70@='EP93TB=&5X="(@<VEZ93TB-"(@;VYC:&%N9V4](G-R8SUG9712
M97-I>F53<F,H7"<E<UPG+"!<)R5S7"<I.W-H;W=);6%G92AS<F,L(%PG7W!?
M)7-<)RP@=')U92D[(B`E<R`O/B<L"B`@("`@("`@("`@("`@("`@("!?*")W
M.B(I+`H@("`@("`@("`@("`@("`@("`@571I;#HZ861D4&%R86UE=&5R*"1I
M;6<L("=A)RP@)W)E<VEZ92<I+`H@("`@("`@("`@("`@("`@("`@)'9A<FYA
M;64L"B`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9V5N240H)U]W7R<@+B`D=F%R;F%M92DI.PH*("`@
M("`@("`@("`@+RH@4F5S:7IE(&AE:6=H="X@*B\*("`@("`@("`@("`@)&AT
M;6P@+CT@<W!R:6YT9B@G)7,\:6YP=70@='EP93TB=&5X="(@<VEZ93TB-"(@
M;VYC:&%N9V4](G-R8SUG971297-I>F53<F,H7"<E<UPG+"!<)R5S7"<I.W-H
M;W=);6%G92AS<F,L(%PG7W!?)7-<)RP@=')U92D[(B`E<R`O/B<L"B`@("`@
M("`@("`@("`@("`@("!?*")H.B(I+`H@("`@("`@("`@("`@("`@("`@571I
M;#HZ861D4&%R86UE=&5R*"1I;6<L("=A)RP@)W)E<VEZ92<I+`H@("`@("`@
M("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`D=F%R
M;F%M92P*("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5N240H)U]H7R<@
M+B`D=F%R;F%M92DI.PH*("`@("`@("`@("`@+RH@07!P;'D@9FEX960@<F%T
M:6\@<F5S:7IE+B`J+PH@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN
M:R@G(R<L(%\H(D9I>"!R871I;R(I+"`G)RP@)R<L("=S<F,]9V5T4F5S:7IE
M4W)C*%PG)R`N(%5T:6PZ.F%D9%!A<F%M971E<B@D:6UG+"`G82<L("=R97-I
M>F4G*2`N("=<)RP@7"<G("X@)'9A<FYA;64@+B`G7"<L(%PG,5PG*3MS:&]W
M26UA9V4H<W)C+"!<)U]P7R<@+B`D=F%R;F%M92`N("=<)RP@=')U92D[)RD@
M+B!(;W)D93HZ:6UG*"=R871I;RYP;F<G+"!?*")&:7@@<F%T:6\B*2P@)V%L
M:6=N/2)M:61D;&4B)RP@)&EM9U]D:7(I("X@)SPO83XG.PH*("`@("`@("`@
M("`@+RH@2V5E<"!A;'-O(&]R:6=I;F%L(&EF(&ET(&AA<R!B965N(')E<75E
M<W1E9"X@*B\*("`@("`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]S:&]W7VME
M97!O<FEG*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*"<\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB
M)7,B(&ED/2(E<R(E<R`O/B5S)R`N(")<;B(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE("X@)UMK965P7V]R:6==)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64@+B`G6VME
M97!?;W)I9UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A
M96UP='DH)&EM86=E6R=K965P7V]R:6<G72D@/R`G(&-H96-K960](F-H96-K
M960B)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M*")+965P(&]R:6=I;F%L/R(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+RH@5&AE('!R979I97<@:6UA9V4@96QE;65N="X@*B\*("`@("`@("`@
M("`@)&AT;6P@+CT@)SQB<B`O/CQI;6<@<W)C/2(G("X@)&EM9R`N("<B("<@
M+B`D=&AI<RT^7V=E;DE$*"=?<%\G("X@)'9A<FYA;64I("X@(CY<;B(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VQO;F=T97AT*"8D9F]R;2P@)B1V87(L
M("8D=F%R<RD*("`@('L*("`@("`@("!G;&]B86P@)&)R;W=S97(["@H@("`@
M("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M("1H=&UL(#T@<W!R:6YT9B@G/'1E>'1A<F5A(&ED/2(E<R(@;F%M93TB)7,B
M(&-O;',](B5S(B!R;W=S/2(E<R(E<R5S/B5S/"]T97AT87)E83XG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("AI
M;G0I)'9A<BT^='EP92T^9V5T0V]L<R@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`H:6YT*21V87(M/G1Y<&4M/F=E=%)O=W,H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^:7-$:7-A8FQE
M9"@I(#\@)R!D:7-A8FQE9#TB9&ES86)L960B)R`Z("<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU
M92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH*("`@
M("`@("!I9B`H)'9A<BT^='EP92T^:&%S2&5L<&5R*"=R=&4G*2`F)B`D8G)O
M=W-E<BT^:&%S1F5A='5R92@G<G1E)RDI('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=(;W)D92]%9&ET;W(N<&AP)SL*("`@("`@("`@("`@)&5D:71O
M<B`]("9(;W)D95]%9&ET;W(Z.G-I;F=L971O;B@G:'1M;&%R96$G+"!A<G)A
M>2@G:60G(#T^("1V87)N86UE*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'9A<BT^='EP92T^:&%S2&5L<&5R*"D@)B8@)&)R;W=S97(M/FAA<T9E871U
M<F4H)VIA=F%S8W)I<'0G*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&)R
M("\^/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\='(^/'1D/B<["B`@("`@("`@
M("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=O<&5N7VAT;6Q?:&5L<&5R+FIS
M)RP@)VAO<F1E)RD["B`@("`@("`@("`@("1I;6=)9"`]("1T:&ES+3Y?9V5N
M240H)'9A<BT^9V5T5F%R3F%M92@I+"!F86QS92D@+B`G96AE;'!E<B<["B`@
M("`@("`@("`@(&EF("@D=F%R+3YT>7!E+3YH87-(96QP97(H)V5M;W1I8V]N
M<R<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2!(;W)D93HZ;&EN:R@G
M(R<L(%\H(D5M;W1I8V]N<R(I+"`G)RP@)R<L("=O<&5N2'1M;$AE;'!E<BA<
M)V5M;W1I8V]N<UPG+"!<)R<@+B`D=F%R+3YG971687).86UE*"D@+B`G7"<I
M.R!R971U<FX@9F%L<V4[)RD@+B!(;W)D93HZ:6UG*"=S;6EL92YP;F<G+"!?
M*")%;6]T:6-O;G,B*2P@)VED/2(G("X@)&EM9TED("X@)R(@86QI9VX](FUI
M9&1L92(G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H)VAO
M<F1E)RD@+B`G+V5M;W1I8V]N<R<I("X@)SPO83XG.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1H=&UL("X]("<\+W1D/CPO='(^/'1R/CQT9#X\9&EV
M("<@+B`D=&AI<RT^7V=E;DE$*"=H=&UL:&5L<&5R7R<@+B`D=F%R+3YG9716
M87).86UE*"DI("X@)R!C;&%S<STB8V]N=')O;"(^/"]D:78^/"]T9#X\+W1R
M/CPO=&%B;&4^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V-O
M=6YT961T97AT*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@
M("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA
M;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!R
M971U<FX@<W!R:6YT9B@G/'1E>'1A<F5A(&YA;64](B5S(B!I9#TB)7,B(&-O
M;',](B5S(B!R;W=S/2(E<R(E<R5S/B5S/"]T97AT87)E83XG+`H@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)'9A
M<BT^='EP92T^9V5T0V]L<R@I+`H@("`@("`@("`@("`@("`@("`@("`@("AI
M;G0I)'9A<BT^='EP92T^9V5T4F]W<R@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<BT^:7-$:7-A8FQE9"@I(#\@)R!D
M:7-A8FQE9#TB9&ES86)L960B)R`Z("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V%D9')E<W,H)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L
M8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\=&5X=&%R96$@
M;F%M93TB)7,B(&ED/2(E<R(@8V]L<STB)7,B(')O=W,](B5S(B5S)7,^)7,\
M+W1E>'1A<F5A/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YG971#;VQS*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YG9712;W=S*"DL
M"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I
M<'1S*"1F;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R
M+3YI<T1I<V%B;&5D*"D@/R`G(&1I<V%B;&5D/2)D:7-A8FQE9"(G(#H@)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A
M<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S
M970I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?9&%T
M92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA
M;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P
M<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<R(@:60](B5S(B!V
M86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A
M;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H
M)&9O<FTL("1V87(I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R
M26YP=71?=&EM92@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).
M86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!S:7IE/2(U(B!N
M86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA
M;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?:&]U<FUI;G5T97-E8V]N9"@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@)'1I;64@/2`D=F%R+3YT
M>7!E+3YG9714:6UE4&%R=',H)'9A<BT^9V5T5F%L=64H)'9A<G,I*3L*"B`@
M("`@("`@+RH@3W5T<'5T(&AO=7)S+B`J+PH@("`@("`@("1H;W5R<R`](&%R
M<F%Y*"<G(#T^(%\H(FAH(BDI.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M/2`R,SL@)&DK*RD@>PH@("`@("`@("`@("`D:&]U<G-;)&E=(#T@)&D["B`@
M("`@("`@?0H@("`@("`@("1H=&UL(#T@<W!R:6YT9B@G/'-E;&5C="!N86UE
M/2(E<UMH;W5R72(@:60](B5S6VAO=7)=(B5S/B5S/"]S96QE8W0^)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H)&AO=7)S
M+"`H)'1I;65;)VAO=7(G72`]/3T@)R<I(#\@)R<@.B`D=&EM95LG:&]U<B==
M*2D["@H@("`@("`@("\J($]U='!U="!M:6YU=&5S+B`J+PH@("`@("`@("1M
M:6YU=&5S(#T@87)R87DH)R<@/3X@7R@B;6TB*2D["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P](#4Y.R`D:2LK*2!["B`@("`@("`@("`@("1M(#T@<W!R
M:6YT9B@G)3`R9"<L("1I*3L*("`@("`@("`@("`@)&UI;G5T97-;)&U=(#T@
M)&T["B`@("`@("`@?0H@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQS96QE
M8W0@;F%M93TB)7-;;6EN=71E72(@:60](B5S6VUI;G5T95TB)7,^)7,\+W-E
M;&5C=#XG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@
M)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E;&5C
M=$]P=&EO;G,H)&UI;G5T97,L("@D=&EM95LG;6EN=71E)UT@/3T]("<G*2`_
M("<G(#H@<W!R:6YT9B@G)3`R9"<L("1T:6UE6R=M:6YU=&4G72DI*3L*"B`@
M("`@("`@+RH@4F5T=7)N(&EF('-E8V]N9',@87)E(&YO="!R97%U:7)E9"X@
M*B\*("`@("`@("!I9B`H(21V87(M/G1Y<&4M/E]S:&]W7W-E8V]N9',I('L*
M("`@("`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@("`@('T*"B`@("`@("`@
M+RH@3W5T<'5T('-E8V]N9',N("HO"B`@("`@("`@)'-E8V]N9',@/2!A<G)A
M>2@G)R`]/B!?*")S<R(I*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/#T@
M-3D[("1I*RLI('L*("`@("`@("`@("`@)'-E8V]N9'-;)&E=(#T@<W!R:6YT
M9B@G)3`R9"<L("1I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL
M("X@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<UMS96-O;F1=(B!I9#TB)7-;
M<V5C;VYD72(E<SXE<SPO<V5L96-T/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D=F%R*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T
M:6]N<R@D<V5C;VYD<RP@*"1T:6UE6R=S96-O;F0G72`]/3T@)R<I(#\@)R<@
M.B!S<')I;G1F*"<E,#)D)RP@)'1I;65;)W-E8V]N9"==*2DI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]M;VYT:'EE87(H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1D871E<R`](&%R<F%Y
M*"D["B`@("`@("`@)&1A=&5S6R=M;VYT:"==(#T@87)R87DH)R<@/3X@7R@B
M34TB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q(#T^(%\H
M(DIA;G5A<GDB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`R
M(#T^(%\H(D9E8G)U87)Y(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,R`]/B!?*")-87)C:"(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#0@/3X@7R@B07!R:6PB*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`U(#T^(%\H(DUA>2(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#8@/3X@7R@B2G5N92(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#<@/3X@7R@B2G5L>2(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#@@/3X@7R@B075G=7-T(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@.2`]/B!?*")397!T96UB97(B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,"`]/B!?*")/
M8W1O8F5R(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3$@
M/3X@7R@B3F]V96UB97(B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q,B`]/B!?*")$96-E;6)E<B(I*3L*("`@("`@("`D9&%T97-;)WEE
M87(G72`](&%R<F%Y*"<G(#T^(%\H(EE965DB*2D["B`@("`@("`@:68@*"1V
M87(M/G1Y<&4M/E]S=&%R=%]Y96%R(#X@)'9A<BT^='EP92T^7V5N9%]Y96%R
M*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`D=F%R+3YT>7!E+3Y?<W1A<G1?
M>65A<CL@)&D@/CT@)'9A<BT^='EP92T^7V5N9%]Y96%R.R`D:2TM*2!["B`@
M("`@("`@("`@("`@("`D9&%T97-;)WEE87(G75LD:5T@/2`D:3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`D=F%R+3YT>7!E+3Y?<W1A<G1?>65A<CL@)&D@/#T@)'9A<BT^='EP92T^
M7V5N9%]Y96%R.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D9&%T97-;)WEE
M87(G75LD:5T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<R(@:60](B5S(B5S
M/B5S/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YT
M>7!E+3YG971-;VYT:%9A<B@D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@
M("`D=F%R+3YT>7!E+3YG971-;VYT:%9A<B@D=F%R*2P*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V
M87(I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T
M:6]N<R@D9&%T97-;)VUO;G1H)UTL("1V87)S+3YG970H)'9A<BT^='EP92T^
M9V5T36]N=&A687(H)'9A<BDI*2D@+@H@("`@("`@("`@("!S<')I;G1F*"<\
M<V5L96-T(&YA;64](B5S(B!I9#TB)7,B)7,^)7,\+W-E;&5C=#XG+`H@("`@
M("`@("`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E=%EE87)687(H)'9A<BDL
M"B`@("`@("`@("`@("`@("`@("`@)'9A<BT^='EP92T^9V5T665A<E9A<B@D
M=F%R*2P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$%C=&EO;E-C
M<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5L96-T3W!T:6]N<R@D9&%T97-;)WEE87(G72P@)'9A<G,M/F=E="@D
M=F%R+3YT>7!E+3YG971996%R5F%R*"1V87(I*2DI.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]R96YD97)687));G!U=%]M;VYT:&1A>7EE87(H)B1F;W)M+"`F
M)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1D871E<R`](&%R<F%Y*"D[
M"B`@("`@("`@)&1A=&5S6R=M;VYT:"==(#T@87)R87DH)R<@("`]/B!?*")-
M32(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Q)R`@/3X@
M7R@B2F%N=6%R>2(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<R)R`@/3X@7R@B1F5B<G5A<GDB*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G,R<@(#T^(%\H(DUA<F-H(BDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)S0G("`]/B!?*")!<')I;"(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<U)R`@/3X@7R@B36%Y(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S8G("`]/B!?*")*=6YE
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S<G("`]/B!?
M*")*=6QY(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S@G
M("`]/B!?*")!=6=U<W0B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G.2<@(#T^(%\H(E-E<'1E;6)E<B(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<Q,"<@/3X@7R@B3V-T;V)E<B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<Q,2<@/3X@7R@B3F]V96UB97(B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G,3(G(#T^(%\H
M(D1E8V5M8F5R(BDI.PH@("`@("`@("1D871E<ULG9&%Y)UT@/2!A<G)A>2@G
M)R`]/B!?*")$1"(I*3L*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/#T@,S$[
M("1I*RLI('L*("`@("`@("`@("`@)&1A=&5S6R=D87DG75LD:5T@/2`D:3L*
M("`@("`@("!]"B`@("`@("`@)&1A=&5S6R=Y96%R)UT@/2!A<G)A>2@G)R`]
M/B!?*")965E9(BDI.PH@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?<W1A<G1?
M>65A<B`^("1V87(M/G1Y<&4M/E]E;F1?>65A<BD@>PH@("`@("`@("`@("!F
M;W(@*"1I(#T@)'9A<BT^='EP92T^7W-T87)T7WEE87([("1I(#X]("1V87(M
M/G1Y<&4M/E]E;F1?>65A<CL@)&DM+2D@>PH@("`@("`@("`@("`@("`@)&1A
M=&5S6R=Y96%R)UU;)&E=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'9A<BT^='EP92T^7W-T
M87)T7WEE87([("1I(#P]("1V87(M/G1Y<&4M/E]E;F1?>65A<CL@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@)&1A=&5S6R=Y96%R)UU;)&E=(#T@)&D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&1A=&4@/2`D=F%R+3YT
M>7!E+3YG971$871E4&%R=',H)'9A<BT^9V5T5F%L=64H)'9A<G,I*3L*"B`@
M("`@("`@+R\@5$]$3SH@=7-E($Y,4R!T;R!G970@=&AE(&]R9&5R(')I9VAT
M(&9O<B!T:&4@4F5S="!/9B!4:&4*("`@("`@("`O+R!7;W)L9"X*("`@("`@
M("`D:'1M;"`]("<G.PH@("`@("`@("1D871E7W!A<G1S(#T@87)R87DH)VUO
M;G1H)RP@)V1A>2<L("=Y96%R)RD["B`@("`@("`@9F]R96%C:"`H)&1A=&5?
M<&%R=',@87,@)'!A<G0I('L*("`@("`@("`@("`@)'9A<FYA;64@/2!`:'1M
M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"D@+B`G6R<@+B`D<&%R
M="`N("==)RP@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@
M("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'-E;&5C="!N86UE/2(E<R(@:60]
M(B5S(B5S/B5S/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D9&%T97-;
M)'!A<G1=+"`D9&%T95LD<&%R=%TI*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D=F%R+3YT>7!E+3Y?<&EC:V5R("8F("1'3$]"04Q36R=B<F]W<V5R)UTM
M/FAA<T9E871U<F4H)VIA=F%S8W)I<'0G*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ861D4V-R:7!T1FEL92@G;W!E;E]C86QE;F1A<BYJ<R<L("=H;W)D92<I
M.PH@("`@("`@("`@("`D:6UG260@/2`D=&AI<RT^7V=E;DE$*"1V87(M/F=E
M=%9A<DYA;64H*2P@9F%L<V4I("X@)V=O=&\G.PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/&1I=B!I9#TB9V]T;R(@8VQA<W,](FAE861E<F)O>"(@<W1Y;&4]
M(G!O<VET:6]N.F%B<V]L=71E.W9I<VEB:6QI='DZ:&ED9&5N.W!A9&1I;F<Z
M,"(^/"]D:78^)R`N"B`@("`@("`@("`@("`@("!(;W)D93HZ;&EN:R@G(R<L
M(%\H(E-E;&5C="!A(&1A=&4B*2P@)R<L("<G+"`G;W!E;D-A;&5N9&%R*%PG
M)R`N("1I;6=)9"`N("=<)RP@7"<G("X@)'9A<BT^9V5T5F%R3F%M92@I("X@
M)UPG*3L@<F5T=7)N(&9A;'-E.R<I("X@2&]R9&4Z.FEM9R@G8V%L96YD87(N
M<&YG)RP@7R@B0V%L96YD87(B*2P@)VED/2(G("X@)&EM9TED("X@)R(@86QI
M9VX](FUI9&1L92(G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI("X@(CPO83Y<;B(["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN
M<'5T7V-O;&]R<&EC:V5R*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*
M("`@("`@("!G;&]B86P@)')E9VES=')Y+"`D8G)O=W-E<CL*"B`@("`@("`@
M)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE
M*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@)&AT
M;6P@/2`G/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\='(^/'1D/B<@+@H@("`@
M("`@("`@("`G/&EN<'5T('1Y<&4](G1E>'0B('-I>F4](C$P(B!M87AL96YG
M=&@](C<B(&YA;64](B<@+@H@("`@("`@("`@("`D=F%R;F%M92`N("<B(&ED
M/2(G("X@)'9A<FYA;64@+@H@("`@("`@("`@("`G(B!V86QU93TB)R`N($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<B("\^/"]T9#XG.PH@("`@("`@
M(&EF("@D8G)O=W-E<BT^:&%S1F5A='5R92@G:F%V87-C<FEP="<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=O<&5N7V-O;&]R<&EC
M:V5R+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`@("`@("`@("1H=&UL("X]
M("<\=&0@=VED=&@](C(P(B!I9#TB8V]L;W)D96UO7R<@+B`D=F%R;F%M92`N
M("<B('-T>6QE/2)B86-K9W)O=6YD.B<@+B!`:'1M;'-P96-I86QC:&%R<R@D
M=F%R+3YG971686QU92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA
M<G-E="D@+B`G(CX@/"]T9#XG("X*("`@("`@("`@("`@("`@("<\=&0^)R`N
M($AO<F1E.CIL:6YK*"<C)RP@7R@B0V]L;W(@4&EC:V5R(BDL("=W:61G970G
M+"`G)RP@)V]P96Y#;VQO<E!I8VME<BA<)R<@+B`D=F%R;F%M92`N("=<)RD[
M(')E='5R;B!F86QS93LG*2`N($AO<F1E.CII;6<H)V-O;&]R<&EC:V5R+G!N
M9R<L(%\H(D-O;&]R(%!I8VME<B(I+"`G:&5I9VAT/2(Q-B(G+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^/"]T9#XG("X*("`@
M("`@("`@("`@("`@("<\=&0^/&1I=B!I9#TB8V]L;W)P:6-K97)?)R`N("1V
M87)N86UE("X@)R(@8VQA<W,](F-O;G1R;VPB/CPO9&EV/CPO=&0^)SL*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@)SPO='(^/"]T86)L93XG
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]S;W)T97(H
M)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D
M<F5G:7-T<GD["@H@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA
M<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I.PH@("`@("`@("1I;G-T86YC92`]("1V87(M/G1Y<&4M/E]I;G-T
M86YC93L*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W-O<G1E<BYJ
M<R<L("=H;W)D92<L('1R=64I.PH*("`@("`@("!R971U<FX@)SQI;G!U="!T
M>7!E/2)H:61D96XB(&YA;64](B<@+B`D=F%R;F%M92`N"B`@("`@("`@("`@
M("=;87)R87E=(B!V86QU93TB(B`G("X@)'1H:7,M/E]G96Y)1"@D=F%R;F%M
M92`N("=;87)R87E=)RD@+B`G+SXG("X*("`@("`@("`@("`@)SQS96QE8W0@
M8VQA<W,](FQE9G1&;&]A="(@;75L=&EP;&4](FUU;'1I<&QE(B!S:7IE/2(G
M("X*("`@("`@("`@("`@*&EN="DD=F%R+3YT>7!E+3YG9713:7IE*"D@+B`G
M(B!N86UE/2(G("X@)'9A<FYA;64@+@H@("`@("`@("`@("`G6VQI<W1=(B!O
M;F-H86YG93TB)R`N("1I;G-T86YC92`N("<N9&5S96QE8W1(96%D97(H*3LB
M("<@+@H@("`@("`@("`@("`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)UML
M:7-T72<I("X@)SXG("X*("`@("`@("`@("`@)'9A<BT^='EP92T^9V5T3W!T
M:6]N<R@D=F%R+3YG971686QU92@D=F%R<RDI("X@)SPO<V5L96-T/CQD:78@
M8VQA<W,](FQE9G1&;&]A="(^)R`N"B`@("`@("`@("`@($AO<F1E.CIL:6YK
M*"<C)RP@7R@B36]V92!U<"(I+"`G)RP@)R<L("1I;G-T86YC92`N("<N;6]V
M94-O;'5M;E5P*"D[(')E='5R;B!F86QS93LG*2`N($AO<F1E.CII;6<H)VYA
M=B]U<"YP;F<G+"!?*")-;W9E('5P(BDL("<G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2`N("<\+V$^/&)R("\^)R`N"B`@("`@("`@("`@
M($AO<F1E.CIL:6YK*"<C)RP@7R@B36]V92!U<"(I+"`G)RP@)R<L("1I;G-T
M86YC92`N("<N;6]V94-O;'5M;D1O=VXH*3L@<F5T=7)N(&9A;'-E.R<I("X@
M2&]R9&4Z.FEM9R@G;F%V+V1O=VXN<&YG)RP@7R@B36]V92!D;W=N(BDL("<G
M+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<\+V$^/"]D
M:78^)R`N"B`@("`@("`@("`@("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C
M<FEP="(^)R`N(")<;B(@+@H@("`@("`@("`@("!S<')I;G1F*"<E,21S(#T@
M;F5W($AO<F1E7T9O<FU?4V]R=&5R*%PG)3$D<UPG+"!<)R4R)'-<)RP@7"<E
M,R1S7"<I.R<@+B`B7&XB+`H@("`@("`@("`@("`@("`@("`@("1I;G-T86YC
M92P@)'9A<FYA;64L("1V87(M/G1Y<&4M/F=E=$AE861E<B@I*2`N"B`@("`@
M("`@("`@('-P<FEN=&8H(B5S+G-E=$AI9&1E;B@I.UQN/"]S8W)I<'0^7&XB
M+"`D:6YS=&%N8V4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]A<W-I9VXH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@
M("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@($AO<F1E.CIA9&138W)I
M<'1&:6QE*"=F;W)M7V%S<VEG;BYJ<R<L("=H;W)D92<L('1R=64I.PH*("`@
M("`@("`D;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA
M;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`D
M9FYA;64@/2`D9F]R;2T^9V5T3F%M92@I("X@)RXG("X@)'9A<BT^9V5T5F%R
M3F%M92@I.PH@("`@("`@("1S:7IE(#T@)'9A<BT^='EP92T^9V5T4VEZ92@I
M.PH@("`@("`@("1W:61T:"`]("1V87(M/G1Y<&4M/F=E=%=I9'1H*"D["B`@
M("`@("`@)&QH9'(@/2`H8F]O;"DD=F%R+3YT>7!E+3YG971(96%D97(H,"D[
M"B`@("`@("`@)')H9'(@/2`H8F]O;"DD=F%R+3YT>7!E+3YG971(96%D97(H
M,2D["B`@("`@("`@)'1H:7,M/E]A9&1/;DQO861*879A<V-R:7!T*"=(;W)D
M95]&;W)M7T%S<VEG;BYS971&:65L9"A<)R<@+B`D9FYA;64@+B`G7"<I.R<I
M.PH*("`@("`@("!R971U<FX@)SQT86)L93X\='(^/'1D/B<@+@H@("`@("`@
M("`@("`G/&EN<'5T('1Y<&4](FAI9&1E;B(@;F%M93TB)R`N("1N86UE("X@
M)U]?=F%L=65S(B`O/B<@+@H@("`@("`@("`@("!S<')I;G1F*"<\<V5L96-T
M(&YA;64](B5S7U]L969T(B!M=6QT:7!L93TB;75L=&EP;&4B('-I>F4](B5D
M(B!S='EL93TB=VED=&@Z)7,B)7,^)RP*("`@("`@("`@("`@("`@("`@("`D
M;F%M92P@)'-I>F4L("1W:61T:"P*("`@("`@("`@("`@("`@("`@("`D;&AD
M<B`_("<@;VYC:&%N9V4](DAO<F1E7T9O<FU?07-S:6=N+F1E<V5L96-T2&5A
M9&5R<RA<)R<@+B`D9FYA;64@+B`G7"<L(#`I.R(G(#H@)R<I("X*("`@("`@
M("`@("`@)'9A<BT^='EP92T^9V5T3W!T:6]N<R@P+"`D9FYA;64I("X*("`@
M("`@("`@("`@)SPO<V5L96-T/CPO=&0^/'1D/B<@+@H@("`@("`@("`@("`G
M/&$@:')E9CTB(B!O;F-L:6-K/2)(;W)D95]&;W)M7T%S<VEG;BYM;W9E*%PG
M)R`N("1F;F%M92`N"B`@("`@("`@("`@("=<)RP@,"D[(')E='5R;B!F86QS
M93LB/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=R:&%N9"YP;F<G+"!?
M*")!9&0@8V]L=6UN(BDL(&YU;&PL("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI("X*("`@("`@("`@("`@)SPO83X\8G(@+SX\82!H<F5F/2(B
M(&]N8VQI8VL](DAO<F1E7T9O<FU?07-S:6=N+FUO=F4H7"<G("X*("`@("`@
M("`@("`@)&9N86UE("X@)UPG+"`Q*3L@<F5T=7)N(&9A;'-E.R(^)R`N"B`@
M("`@("`@("`@($AO<F1E.CII;6<H)VQH86YD+G!N9R<L(%\H(E)E;6]V92!C
M;VQU;6XB*2P@;G5L;"P@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G
M*2D@+@H@("`@("`@("`@("`G/"]A/CPO=&0^/'1D/B<@+@H@("`@("`@("`@
M("!S<')I;G1F*"<\<V5L96-T(&YA;64](B5S7U]R:6=H="(@;75L=&EP;&4]
M(FUU;'1I<&QE(B!S:7IE/2(E9"(@<W1Y;&4](G=I9'1H.B5S(B5S/B<L"B`@
M("`@("`@("`@("`@("`@("`@)&YA;64L("1S:7IE+"`D=VED=&@L"B`@("`@
M("`@("`@("`@("`@("`@)')H9'(@/R`G(&]N8VAA;F=E/2)(;W)D95]&;W)M
M7T%S<VEG;BYD97-E;&5C=$AE861E<G,H7"<G("X@)&9N86UE("X@)UPG+"`Q
M*3LB)R`Z("<G*2`N"B`@("`@("`@("`@("1V87(M/G1Y<&4M/F=E=$]P=&EO
M;G,H,2P@)&9N86UE*2`N"B`@("`@("`@("`@("<\+W-E;&5C=#X\+W1D/CPO
M='(^/"]T86)L93XG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]I;G9A;&ED*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]R96YD97)687)$:7-P;&%Y7VEN=F%L:60H
M)&9O<FTL("1V87(L("1V87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R5F%R26YP=71?96YU;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@
M("1P<F]M<'0@/2`D=F%R+3YT>7!E+3YG9710<F]M<'0H*3L*("`@("`@("`D
M:'1M;&-H87)S(#T@)'9A<BT^9V5T3W!T:6]N*"=H=&UL8VAA<G,G*3L*("`@
M("`@("!I9B`H(65M<'1Y*"1P<F]M<'0I*2!["B`@("`@("`@("`@("1P<F]M
M<'0@/2`G/&]P=&EO;B!V86QU93TB(CXG("X@*"1H=&UL8VAA<G,@/R`D<')O
M;7!T(#H@0&AT;6QS<&5C:6%L8VAA<G,H)'!R;VUP="P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*2D@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"B`@
M("`@("`@)'9A<FYA;64@/2!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG9716
M87).86UE*"DL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@
M("`@<F5T=7)N('-P<FEN=&8H)SQS96QE8W0@;F%M93TB)7,B(&ED/2(E<R(@
M)7,^)7,E<SPO<V5L96-T/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F
M;W)M+"`D=F%R*2P*("`@("`@("`@("`@("`@("`@("`@("`D<')O;7!T+`H@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D
M=F%L=65S+"`D=F%R+3YG971686QU92@D=F%R<RDL("1H=&UL8VAA<G,I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;6QE;G5M*"8D
M9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]
M("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`D:'9A<FYA;64@/2!`:'1M
M;'-P96-I86QC:&%R<R@D=F%R;F%M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C
M:&%R<V5T*3L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^9V5T5F%L=65S*"D[
M"B`@("`@("`@)'!R;VUP=',@/2`D=F%R+3YT>7!E+3YG9710<F]M<'1S*"D[
M"B`@("`@("`@)'-E;&5C=&5D(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@
M("`@("`@("\J($EF('!A<W-I;F<@82!N;VXM87)R87D@=F%L=64@;F5E9"!T
M;R!G970@=&AE(&ME>7,N("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<V5L
M96-T960I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)&ME
M>5\Q(#T^("1V86QU97-?,BD@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1V86QU97-?,ELD<V5L96-T961=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1S96QE8W1E9"`](&%R<F%Y*"<Q)R`]/B`D:V5Y7S$L("<R)R`]/B`D<V5L
M96-T960I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!(
M:61D96X@=&%G('1O('-T;W)E('1H92!C=7)R96YT(&9I<G-T(&QE=F5L+B`J
M+PH@("`@("`@("1H=&UL(#T@<W!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB)7-;;VQD72(@=F%L=64](B5S(B`E<R`O/B<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("1H=F%R;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'-E;&5C=&5D6R<Q)UTL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G6V]L9%TG*2D["@H@("`@
M("`@("\J($9I<G-T(&QE=F5L+B`J+PH@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O07)R87DN<&AP)SL*("`@("`@("`D=F%L=65S7S$@/2!(;W)D95]!
M<G)A>3HZ=F%L=65S5&]+97ES*&%R<F%Y7VME>7,H)'9A;'5E<RDI.PH@("`@
M("`@("1H=&UL("X]('-P<FEN=&8H)SQS96QE8W0@)7,@;F%M93TB)7-;,5TB
M(&]N8VAA;F=E/2(E<R(E<SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]G96Y)1"@D=F%R;F%M92`N("=;,5TG*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("1H=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("=I9B`H=&AI<RYV86QU92D@>R!D;V-U;65N="XG("X@)&9O<FTM/F=E
M=$YA;64H*2`N("<N9F]R;6YA;64N=F%L=64]7"=<)SLG("X@)V1O8W5M96YT
M+B<@+B`D9F]R;2T^9V5T3F%M92@I("X@)RYS=6)M:70H*2!])RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("@D=F%R+3YH87-!8W1I;VXH*2`_("<@)R`N
M("1T:&ES+3Y?9V5N06-T:6]N4V-R:7!T*"1F;W)M+"`D=F%R+3Y?86-T:6]N
M+"`D=F%R;F%M92D@.B`G)RDI.PH@("`@("`@(&EF("@A96UP='DH)'!R;VUP
M=',I*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;W!T:6]N('9A;'5E/2(B
M/B<@+B!`:'1M;'-P96-I86QC:&%R<R@D<')O;7!T<ULP72P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*2`N("<\+V]P=&EO;CXG.PH@("`@("`@('T*
M("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W-E;&5C=$]P=&EO;G,H)'9A;'5E
M<U\Q+"`D<V5L96-T961;)S$G72D["B`@("`@("`@)&AT;6P@+CT@)SPO<V5L
M96-T/B<["@H@("`@("`@("\J(%-E8V]N9"!L979E;"X@*B\*("`@("`@("`D
M:'1M;"`N/2!S<')I;G1F*"<\<V5L96-T("5S(&YA;64](B5S6S)=(B5S/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E;DE$*"1V87)N
M86UE("X@)ULR72<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&AV87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@*"1V87(M/FAA<T%C=&EO
M;B@I(#\@)R`G("X@)'1H:7,M/E]G96Y!8W1I;VY38W)I<'0H)&9O<FTL("1V
M87(M/E]A8W1I;VXL("1V87)N86UE*2`Z("<G*2D["B`@("`@("`@:68@*"%E
M;7!T>2@D<')O;7!T<RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@)SQO<'1I
M;VX@=F%L=64](B(^)R`N($!H=&UL<W!E8VEA;&-H87)S*"1P<F]M<'1S6S%=
M+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I("X@)SPO;W!T:6]N/B<[
M"B`@("`@("`@?0H@("`@("`@("1V86QU97-?,B`](&%R<F%Y*"D["B`@("`@
M("`@:68@*"%E;7!T>2@D<V5L96-T961;)S$G72DI('L*("`@("`@("`@("`@
M)'9A;'5E<U\R(#T@)B1V86QU97-;)'-E;&5C=&5D6R<Q)UU=.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&AT;6P@+B`D=&AI<RT^7W-E;&5C=$]P=&EO
M;G,H)'9A;'5E<U\R+"`D<V5L96-T961;)S(G72D@+B`G/"]S96QE8W0^)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;75L=&EE;G5M
M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%L=65S
M(#T@)'9A<BT^9V5T5F%L=65S*"D["B`@("`@("`@)'-E;&5C=&5D(#T@)'9A
M<G,M/F=E=$5X:7-T<R@D=F%R+3YG971687).86UE*"DL("1W87-S970I.PH@
M("`@("`@(&EF("@A)'=A<W-E="D@>PH@("`@("`@("`@("`D<V5L96-T960@
M/2`D=F%R+3YG971$969A=6QT*"D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!S<')I;G1F*"<\<V5L96-T(&UU;'1I<&QE/2)M=6QT:7!L92(@<VEZ93TB
M)7,B(&YA;64](B5S6UTB("5S/B5S/"]S96QE8W0^)RP*("`@("`@("`@("`@
M("`@("`@("`@("`H:6YT*21V87(M/G1Y<&4M/G-I>F4L"B`@("`@("`@("`@
M("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M
M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@
M)'9A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M=6QT:5-E
M;&5C=$]P=&EO;G,H)'9A;'5E<RP@)'-E;&5C=&5D*2D@+@H@("`@("`@("`@
M("`B/&)R("\^7&XB("X@7R@B5&\@<V5L96-T(&UU;'1I<&QE(&ET96US+"!H
M;VQD(&1O=VX@=&AE($-O;G1R;VP@*%!#*2!O<B!#;VUM86YD("A-86,I(&ME
M>2!W:&EL92!C;&EC:VEN9RXB*2`N(")<;B(["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<E9A<DEN<'5T7W)A9&EO*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R861I;T)U='1O;G,H
M)'9A<BT^9V5T5F%R3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R+3YG971686QU97,H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%L=64H)'9A<G,I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5F%R26YP=71?<V5T*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("`D:'1M;"`]("1T:&ES+3Y?8VAE8VM";WAE<R@D
M=F%R+3YG971687).86UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'9A<BT^9V5T5F%L=65S*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%L=64H)'9A<G,I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T
M:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH*("`@("`@("!I9B`H)'9A<BT^
M='EP92T^7V-H96-K06QL*2!["B`@("`@("`@("`@("1F;W)M7VYA;64@/2`D
M9F]R;2T^9V5T3F%M92@I.PH@("`@("`@("`@("`D=F%R7VYA;64@/2`D=F%R
M+3YG971687).86UE*"D@+B`G6UTG.PH@("`@("`@("`@("`D9G5N8W1I;VY?
M;F%M92`]("=S96QE8W0G("`N("1F;W)M7VYA;64@+B`D=F%R+3YG971687).
M86UE*"D["B`@("`@("`@("`@("1E;F%B;&4@/2!?*")396QE8W0@86QL(BD[
M"B`@("`@("`@("`@("1D:7-A8FQE(#T@7R@B4V5L96-T(&YO;F4B*3L*("`@
M("`@("`@("`@)&EN=F5R="`](%\H(DEN=F5R="!S96QE8W1I;VXB*3L*("`@
M("`@("`@("`@)&AT;6P@+CT@/#P\14]4"CQS8W)I<'0@='EP93TB=&5X="]J
M879A<V-R:7!T(CX*9G5N8W1I;VX@)&9U;F-T:6]N7VYA;64H*0I["B`@("!F
M;W(@*'9A<B!I(#T@,#L@:2`\(&1O8W5M96YT+B1F;W)M7VYA;64N96QE;65N
M=',N;&5N9W1H.R!I*RLI('L*("`@("`@("!F(#T@9&]C=6UE;G0N)&9O<FU?
M;F%M92YE;&5M96YT<UMI73L*("`@("`@("!I9B`H9BYN86UE("$]("<D=F%R
M7VYA;64G*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@
M("`@("!I9B`H87)G=6UE;G1S+FQE;F=T:"D@>PH@("`@("`@("`@("!F+F-H
M96-K960@/2!A<F=U;65N='-;,%T["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@9BYC:&5C:V5D(#T@(68N8VAE8VME9#L*("`@("`@("!]"B`@("!]
M"GT*/"]S8W)I<'0^"CQA(&AR968](B,B(&]N8VQI8VL](B1F=6YC=&EO;E]N
M86UE*'1R=64I.R!R971U<FX@9F%L<V4[(CXD96YA8FQE/"]A/BP*/&$@:')E
M9CTB(R(@;VYC;&EC:STB)&9U;F-T:6]N7VYA;64H9F%L<V4I.R!R971U<FX@
M9F%L<V4[(CXD9&ES86)L93PO83XL"CQA(&AR968](B,B(&]N8VQI8VL](B1F
M=6YC=&EO;E]N86UE*"D[(')E='5R;B!F86QS93LB/B1I;G9E<G0\+V$^"D5/
M5#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R26YP=71?;&EN:R@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R
M5F%R1&ES<&QA>5]L:6YK*"1F;W)M+"`D=F%R+"`D=F%R<RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7VAT;6PH)B1F;W)M+"`F)'9A
M<BP@)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E
M<E9A<D1I<W!L87E?:'1M;"@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]E;6%I;"@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)SQI
M;G!U="!T>7!E/2)T97AT(B!N86UE/2(E<R(@:60](B5S(B!V86QU93TB)7,B
M)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A<DYA
M;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YG971687).86UE
M*"DL"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%L=64H)'9A
M<G,I+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N
M4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)687));G!U=%]M871R:7@H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@("1V87)N86UE("`@/2`D=F%R+3YG971687).86UE*"D[
M"B`@("`@("`@)'9A<E]A<G)A>2`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*
M("`@("`@("`D8V]L<R`@("`@(#T@)'9A<BT^='EP92T^9V5T0V]L<R@I.PH@
M("`@("`@("1R;W=S("`@("`@/2`D=F%R+3YT>7!E+3YG9712;W=S*"D["B`@
M("`@("`@)&UA=')I>"`@("`]("1V87(M/G1Y<&4M/F=E=$UA=')I>"@I.PH@
M("`@("`@("1N97=?:6YP=70@/2`D=F%R+3YT>7!E+3YG971.97=);G!U="@I
M.PH*("`@("`@("`D:'1M;"`]("<\=&%B;&4@8V5L;'-P86-I;F<](C`B/CQT
M<CXG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D(&%L:6=N/2)R:6=H="(@=VED
M=&@](C(P)2(^/"]T9#XG.PH@("`@("`@(&9O<F5A8V@@*"1C;VQS(&%S("1C
M;VQ?=&ET;&4I('L*("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D
M(&%L:6=N/2)C96YT97(B('=I9'1H/2(Q)24B/B5S/"]T9#XG+"`D8V]L7W1I
M=&QE*3L*("`@("`@("!]"B`@("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG;CTB
M<FEG:'0B('=I9'1H/2(V,"4B/CPO=&0^/"]T<CXG.PH*("`@("`@("`O*B!/
M9F9E<B!A(&YE=R!R;W<@;V8@9&%T82!T;R!B92!A9&1E9"!T;R!T:&4@;6%T
M<FEX/R`J+PH@("`@("`@(&EF("@D;F5W7VEN<'5T*2!["B`@("`@("`@("`@
M("1H=&UL("X]("<\='(^/'1D/B<["B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D;F5W7VEN<'5T*2D@>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R
M:6YT9B@G/'-E;&5C="`E<R!N86UE/2(E<UMN75MR72(^/&]P=&EO;B!V86QU
M93TB(CXE<SPO;W!T:6]N/B5S/"]S96QE8W0^/&)R("\^)RP*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E;DE$*"1V87)N86UE("X@)UMN75MR
M72<I+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@(%\H(BTM('-E;&5C="`M+2(I+`H@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<V5L96-T3W!T:6]N<R@D;F5W7VEN<'5T
M+"`D=F%R7V%R<F%Y6R=N)UU;)W(G72DI.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&YE=U]I;G!U="`]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2!S<')I;G1F*"<\:6YP=70@)7,@='EP93TB=&5X="(@;F%M93TB)7-;
M;EU;<ETB('9A;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9V5N240H)'9A<FYA;64@+B`G6VY=6W)=)RDL"B`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'9A<E]A<G)A>5LG;B==6R=R)UTI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1H=&UL("X]("<@/"]T9#XG.PH@("`@("`@("`@("!F;W)E86-H
M("@D8V]L<R!A<R`D8V]L7VED(#T^("1C;VQ?=&ET;&4I('L*("`@("`@("`@
M("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB
M)7-;;EU;=EU;)7-=(B`O/CPO=&0^)RP@)'9A<FYA;64L("1C;VQ?:60I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<\=&0^(#PO=&0^
M/"]T<CXG.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]O<"!T:')O=6=H('1H
M92!R;W=S(&%N9"!C<F5A=&4@8VAE8VMB;WAE<R!F;W(@96%C:"!C;VQU;6XN
M("HO"B`@("`@("`@9F]R96%C:"`H)')O=W,@87,@)')O=U]I9"`]/B`D<F]W
M7W1I=&QE*2!["B`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT<CX\
M=&0^)7,\+W1D/B<L("1R;W=?=&ET;&4I.PH@("`@("`@("`@("!F;W)E86-H
M("@D8V]L<R!A<R`D8V]L7VED(#T^("1C;VQ?=&ET;&4I('L*("`@("`@("`@
M("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT9"!A;&EG;CTB8V5N=&5R(CX\
M:6YP=70@='EP93TB8VAE8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB
M)7-;<EU;)7-=6R5S72(E<R`O/CPO=&0^)RP@)'9A<FYA;64L("1R;W=?:60L
M("1C;VQ?:60L("@A96UP='DH)&UA=')I>%LD<F]W7VED75LD8V]L7VED72D@
M/R`G(&-H96-K960](F-H96-K960B)R`Z("<G*2D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&AT;6P@+CT@)SQT9#X@/"]T9#X\+W1R/B<["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&AT;6P@+B`G/"]T86)L93XG.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]P87-S=V]R9"@F)&9O
M<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A<FYA;64@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971687).86UE*"DL($5.5%]154]4
M15,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@<F5T=7)N('-P<FEN=&8H
M)SQI;G!U="!T>7!E/2)P87-S=V]R9"(@;F%M93TB)7,B(&ED/2(E<R(@=F%L
M=64](B5S(B5S("\^)RP*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%R+3YG971686QU
M92@D=F%R<RDL($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F
M;W)M+"`D=F%R*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN
M<'5T7V5M86EL8V]N9FER;2@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@)&5M86EL(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@
M("`@("1V87)N86UE(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R
M3F%M92@I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@
M(')E='5R;B!S<')I;G1F*"<\:6YP=70@='EP93TB=&5X="(@;F%M93TB)7-;
M;W)I9VEN86Q=(B!I9#TB)7-;;W)I9VEN86Q=(B!V86QU93TB)7,B)7,@+SXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@
M($!H=&UL<W!E8VEA;&-H87)S*"1E;6%I;%LG;W)I9VEN86PG72P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I*2`N"B`@
M("`@("`@("`@("<@)R`N('-P<FEN=&8H)SQI;G!U="!T>7!E/2)T97AT(B!N
M86UE/2(E<UMC;VYF:7)M72(@:60](B5S6V-O;F9I<FU=(B!V86QU93TB)7,B
M)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1E;6%I;%LG8V]N
M9FER;2==+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D
M9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687))
M;G!U=%]P87-S=V]R9&-O;F9I<FTH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@("1P87-S=V]R9"`]("1V87(M/F=E=%9A;'5E*"1V87)S
M*3L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E8VEA;&-H87)S*"1V87(M
M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*
M("`@("`@("!R971U<FX@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G!A<W-W;W)D
M(B!N86UE/2(E<UMO<FEG:6YA;%TB(&ED/2(E<UMO<FEG:6YA;%TB('9A;'5E
M/2(E<R(E<R`O/B<L"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@)'9A<FYA;64L"B`@("`@("`@("`@
M("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'!A<W-W;W)D6R=O<FEG
M:6YA;"==+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R
M;2P@)'9A<BDI("X*("`@("`@("`@("`@)R`G("X@<W!R:6YT9B@G/&EN<'5T
M('1Y<&4](G!A<W-W;W)D(B!N86UE/2(E<UMC;VYF:7)M72(@:60](B5S6V-O
M;F9I<FU=(B!V86QU93TB)7,B)7,@+SXG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA
M;&-H87)S*"1P87-S=V]R9%LG8V]N9FER;2==+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T06-T:6]N4V-R:7!T<R@D9F]R;2P@)'9A<BDI.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687));G!U=%]B;V]L96%N*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H=&UL<W!E
M8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%4RP@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("`D:'1M;"`]("<\:6YP=70@='EP93TB
M8VAE8VMB;W@B(&-L87-S/2)C:&5C:V)O>"(@;F%M93TB)R`N("`D=F%R;F%M
M92`N("<B)R`N"B`@("`@("`@("`@("<@:60](B<@+B`D=F%R;F%M92`N("<B
M)R`N("@D=F%R+3YG971686QU92@D=F%R<RD@/R`G(&-H96-K960](F-H96-K
M960B)R`Z("<G*3L*("`@("`@("!I9B`H)'9A<BT^:&%S06-T:6]N*"DI('L*
M("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]G96Y!8W1I;VY38W)I<'0H
M)&9O<FTL("1V87(M/E]A8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1V87(M/F=E=%9A<DYA;64H*2D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D:'1M;"`N("<@+SXG.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]C<F5D:71C87)D*"8D9F]R
M;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R;F%M92`]($!H
M=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=%9A<DYA;64H*2P@14Y47U%53U1%
M4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`D:'1M;"`]("<\:6YP=70@
M='EP93TB=&5X="(@;F%M93TB)R`N("1V87)N86UE("X@)R(@:60](B<@+B`D
M=F%R;F%M92`N("<B('9A;'5E/2(G("X*("`@("`@("`@("`@0&AT;6QS<&5C
M:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A<G,I+"!%3E1?455/5$53+"`D
M=&AI<RT^7V-H87)S970I("X@)R(G.PH@("`@("`@(&EF("@D=F%R+3YH87-!
M8W1I;VXH*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7V=E;D%C
M=&EO;E-C<FEP="@D9F]R;2P@)'9A<BT^7V%C=&EO;BP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<BT^9V5T5F%R
M3F%M92@I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1H=&UL("X@)R`O
M/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7V]B<F]W
M<V5R*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`D=F%R
M;F%M92`]("1V87(M/F=E=%9A<DYA;64H*3L*("`@("`@("`D=F%R=F%L=64@
M/2`D=F%R<RT^9V5T*"1V87)N86UE*3L*("`@("`@("`D9FEE;&1)9"`]("1T
M:&ES+3Y?9V5N240H;60U*'5N:7%I9"AR86YD*"DL('1R=64I*2P@9F%L<V4I
M("X@)VED)SL*("`@("`@("`D:'1M;"`]("<*("`@("`@("`@("`@/'-C<FEP
M="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H@("`@("`@("`@("!V87(@;V)R
M;W=S97)7:6YD;W=.86UE.PH@("`@("`@("`@("!F=6YC=&EO;B!O8G)O=W-E
M<D-A;&QB86-K*&YA;64L(&]I9"D*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@:68@*&YA;64@/3T@;V)R;W=S97)7:6YD;W=.86UE*2!["B`@("`@
M("`@("`@("`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H7"<G("X@
M)&9I96QD260@+B`G7"<I+G9A;'5E(#T@;VED.PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("));G9A;&ED('=I;F1O=R!N86UE
M('-U<'!L:65D(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`\+W-C<FEP=#X*("`@("`@("`@("`@)SL*("`@("`@("`D
M:'1M;"`N/2!S<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE/2(E
M<R(@:60](B5S(B5S('9A;'5E/2(E<R(^)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V87)N86UE+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I96QD260L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E
M=$%C=&EO;E-C<FEP=',H)&9O<FTL("1V87(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A<G9A;'5E+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@("`@("!I9B`H(65M<'1Y*"1V
M87)V86QU92DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)'9A<G9A;'5E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1'3$]"04Q36R=B<F]W<V5R)UTM/FAA
M<T9E871U<F4H)VIA=F%S8W)I<'0G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M861D4V-R:7!T1FEL92@G<&]P=7`N:G,G+"`G:&]R9&4G+"!T<G5E*3L*("`@
M("`@("`@("`@)&EM9TED(#T@)'1H:7,M/E]G96Y)1"@D=F%R;F%M92P@9F%L
M<V4I("X@)V=O=&\G.PH@("`@("`@("`@("`D:'1M;"`N/2`G/&1I=B!I9#TB
M9V]T;R(@8VQA<W,](FAE861E<F)O>"(@<W1Y;&4](G!O<VET:6]N.F%B<V]L
M=71E.W9I<VEB:6QI='DZ:&ED9&5N.W!A9&1I;F<Z,"(^/"]D:78^)R`N"B`@
M("`@("`@("`@("`@("!(;W)D93HZ;&EN:R@G(R<L(%\H(E-E;&5C="!A;B!O
M8FIE8W0B*2P@)R<L("<G+"`G;V)R;W=S97)7:6YD;W<@/2!P;W!U<"A<)R<@
M+B`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@)VAO<F1E
M)RD@+B`G+W-E<G9I8V5S+V]B<F]W<V5R+R<@+B`G7"<I.R!O8G)O=W-E<E=I
M;F1O=TYA;64@/2!O8G)O=W-E<E=I;F1O=RYN86UE.R!R971U<FX@9F%L<V4[
M)RD@+B!(;W)D93HZ:6UG*"=T<F5E+VQE868N<&YG)RP@7R@B3V)J96-T(BDL
M("=I9#TB)R`N("1I;6=)9"`N("<B(&%L:6=N/2)M:61D;&4B)RP@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("(\+V$^
M7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]D8FQO;VMU<"@F)&9O<FTL
M("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F5N9&5R5F%R26YP=71?96YU;2@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]R96YD97)687));G!U=%]F:6=L970H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1V87)N86UE(#T@0&AT
M;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@(')E='5R;B!S<')I;G1F*"<\
M:6YP=70@='EP93TB=&5X="(@;F%M93TB)7,B(&ED/2(E<R(@<VEZ93TB)7,B
M('9A;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N
M86UE+`H@("`@("`@("`@("`@("`@("`@("`@("1V87)N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@('-T<FQE;B@D=F%R+3YT>7!E+3YG971497AT*"DI
M+`H@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1V
M87(M/F=E=%9A;'5E*"1V87)S*2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R
M<V5T*2D@+@H@("`@("`@("`@("`G/&)R("\^)R`N(%\H(D5N=&5R('1H92!L
M971T97)S(&)E;&]W.B(I("X@)SQB<B`O/B<@+@H@("`@("`@("`@("`D=&AI
M<RT^7W)E;F1E<E9A<D1I<W!L87E?9FEG;&5T*"1F;W)M+"`D=F%R+"`D=F%R
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E$969A
M=6QT*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("!R971U
M<FX@;FPR8G(H0&AT;6QS<&5C:6%L8VAA<G,H)'9A<BT^9V5T5F%L=64H)'9A
M<G,I+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]H=&UL*"8D9F]R;2P@)B1V
M87(L("8D=F%R<RD*("`@('L*("`@("`@("`O+R!3:6YC92!T:&ES(&ES(&%N
M($A434P@='EP92!W92!E>'!L:6-I=&QY(&1O;B=T(&5S8V%P90H@("`@("`@
M("\O(&ET+B!5<V5R(&)E=V%R92X*("`@("`@("!R971U<FX@)'9A<BT^9V5T
M5F%L=64H)'9A<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$
M:7-P;&%Y7V5M86EL*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("`D9&ES<&QA>5]E;6%I;"`]("1E;6%I;"`]("1V87(M/F=E=%9A;'5E
M*"1V87)S*3L*"B`@("`@("`@:68@*"1V87(M/G1Y<&4M/E]S=')I<%]D;VUA
M:6X@)B8@<W1R<&]S*"1E;6%I;"P@)T`G*2`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@)&1I<W!L87E?96UA:6P@/2!S=')?<F5P;&%C92AA<G)A>2@G0"<L
M("<N)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)R`H870I("<L("<@*&1O="D@)RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5M86EL*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?;&EN:U]C;VUP;W-E*2!["B`@
M("`@("`@("`@("1E;6%I;%]V86P@/2!T<FEM*"1E;6%I;"D["@H@("`@("`@
M("`@("`O+R!&;W)M870@=&AE(&%D9')E<W,@86-C;W)D:6YG('1O(%)&0S@R
M,BX*("`@("`@("`@("`@)&UA:6QB;WA?:&]S="`](&5X<&QO9&4H)T`G+"`D
M96UA:6Q?=F%L*3L*("`@("`@("`@("`@:68@*"%I<W-E="@D;6%I;&)O>%]H
M;W-T6S%=*2D@>PH@("`@("`@("`@("`@("`@)&UA:6QB;WA?:&]S=%LQ72`]
M("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;F%M92`](&YU;&P[
M"B`@("`@("`@("`@(&EF("@D=F%R+3YT>7!E+3Y?;&EN:U]N86UE*2!["B`@
M("`@("`@("`@("`@("`D;F%M92`]("1V87(M/G1Y<&4M/E]L:6YK7VYA;64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O34E-12YP:'`G.PH@("`@("`@("`@("`D861D<F5S<R`]($U)344Z.G)F
M8S@R,E=R:71E061D<F5S<R@D;6%I;&)O>%]H;W-T6S!=+"`D;6%I;&)O>%]H
M;W-T6S%=+"`D;F%M92D["@H@("`@("`@("`@("`O+R!'970@<FED(&]F('1H
M92!T<F%I;&EN9R!`("AW:&5N(&YO(&AO<W0@:7,@:6YC;'5D960@:6X*("`@
M("`@("`@("`@+R\@=&AE(&5M86EL(&%D9')E<W,I+@H@("`@("`@("`@("`D
M861D<F5S<R`]('-T<E]R97!L86-E*"=`/B<L("<^)RP@)&%D9')E<W,I.PH@
M("`@("`@("`@("`D;6%I;%]L:6YK(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM
M/F-A;&PH)VUA:6PO8V]M<&]S92<L(&%R<F%Y*&%R<F%Y*"=T;R<@/3X@861D
M<VQA<VAE<R@D861D<F5S<RDI*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1M
M86EL7VQI;FLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1M
M86EL7VQI;FL@/2`G;6%I;'1O.B<@+B!U<FQE;F-O9&4H)&%D9')E<W,I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH
M)&UA:6Q?;&EN:RP@)&5M86EL7W9A;"D@+B!`:'1M;'-P96-I86QC:&%R<R@D
M9&ES<&QA>5]E;6%I;"P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2`N
M("<\+V$^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M;FPR8G(H0&AT;6QS<&5C:6%L8VAA<G,H)&1I<W!L87E?96UA:6PL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]P87-S=V]R9"@F)&9O<FTL
M("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@<F5T=7)N("<J*BHJ*BHJ
M*B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?<&%S
M<W=O<F1C;VYF:7)M*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@
M("`@("!R971U<FX@)RHJ*BHJ*BHJ)SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R1&ES<&QA>5]O8W1A;"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@<F5T=7)N('-P<FEN=&8H)S`E;R<L(&]C=&1E8R@D
M=F%R+3YG971686QU92@D=F%R<RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R1&ES<&QA>5]B;V]L96%N*"8D9F]R;2P@)B1V87(L("8D=F%R
M<RD*("`@('L*("`@("`@("!R971U<FX@)'9A<BT^9V5T5F%L=64H)'9A<G,I
M(#\@7R@B665S(BD@.B!?*").;R(I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)687)$:7-P;&%Y7V5N=6TH)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG971686QU97,H*3L*("`@
M("`@("`D=F%L=64@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@
M:68@*&-O=6YT*"1V86QU97,I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N
M(%\H(DYO('9A;'5E<R(I.PH@("`@("`@('T@96QS96EF("AI<W-E="@D=F%L
M=65S6R1V86QU95TI("8F("1V86QU92`A/2`G)RD@>PH@("`@("`@("`@("!R
M971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E<ULD=F%L=65=+"!%3E1?
M455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]R861I;R@F)&9O<FTL("8D
M=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E
M=%9A;'5E<R@I.PH@("`@("`@(&EF("AC;W5N="@D=F%L=65S*2`]/2`P*2![
M"B`@("`@("`@("`@(')E='5R;B!?*").;R!V86QU97,B*3L*("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)'9A;'5E<ULD=F%R+3YG971686QU92@D=F%R<RE=
M*2D@>PH@("`@("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H)'9A
M;'5E<ULD=F%R+3YG971686QU92@D=F%R<RE=+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R1&ES<&QA>5]M=6QT:65N=6TH)B1F;W)M+"`F)'9A<BP@)B1V
M87)S*0H@("`@>PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG971686QU97,H
M*3L*("`@("`@("`D;VX@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@
M("`@:68@*"%C;W5N="@D=F%L=65S*2!\?"`A8V]U;G0H)&]N*2D@>PH@("`@
M("`@("`@("!R971U<FX@7R@B3F\@=F%L=65S(BD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&1I<W!L87D@/2!A<G)A>2@I.PH@("`@("`@("`@
M("!F;W)E86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D;F%M92D@>PH@("`@
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V86QU92P@)&]N*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1D:7-P;&%Y6UT@/2`D;F%M93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@0&AT
M;6QS<&5C:6%L8VAA<G,H:6UP;&]D92@G+"`G+"`D9&ES<&QA>2DL($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7W-E="@F)&9O<FTL("8D=F%R
M+"`F)'9A<G,I"B`@("!["B`@("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A
M;'5E<R@I.PH@("`@("`@("1O;B`]("1V87(M/F=E=%9A;'5E*"1V87)S*3L*
M("`@("`@("!I9B`H(6-O=6YT*"1V86QU97,I('Q\("%C;W5N="@D;VXI*2![
M"B`@("`@("`@("`@(')E='5R;B!?*").;R!V86QU97,B*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9&ES<&QA>2`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1V86QU97,@87,@)'9A;'5E(#T^("1N86UE*2![
M"B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E+"`D;VXI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&1I<W!L87E;72`]("1N86UE.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B!`:'1M;'-P96-I86QC:&%R<RAI;7!L;V1E*"<L("<L("1D:7-P;&%Y*2P@
M14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?:6UA9V4H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1I;6=?<&%R86US(#T@
M)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@("1I;6=?=7)L(#T@2&]R
M9&4Z.G5R;"@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=W96)R;V]T)RP@
M)VAO<F1E)RD@+B`G+W-E<G9I8V5S+VEM86=E<R]V:65W+G!H<"<I.PH@("`@
M("`@("1I;6=?=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1I;6=?=7)L+"`D
M:6UG7W!A<F%M<RD["@H@("`@("`@(')E='5R;B!(;W)D93HZ:6UG*"1I;6=?
M=7)L+"!I<W-E="@D:6UG7W!A<F%M<ULG9B==*2`_("1I;6=?<&%R86US6R=F
M)UT@.B`G)RP@)R<L("<G*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R1&ES<&QA>5]C96QL<&AO;F4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1N=6UB
M97(@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@)&AT;6P@/2!`
M:'1M;'-P96-I86QC:&%R<R@D;G5M8F5R+"!%3E1?455/5$53+"`D=&AI<RT^
M7V-H87)S970I.PH*("`@("`@("!I9B`H)&YU;6)E<B`F)B`D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G<VUS+V-O;7!O<V4G*2D@>PH@("`@("`@("`@("`D=7)L
M(#T@)')E9VES=')Y+3YL:6YK*"=S;7,O8V]M<&]S92<L(&%R<F%Y*"=T;R<@
M/3X@)&YU;6)E<BDI.PH@("`@("`@("`@("`D:'1M;"`N/2`G("<@+B!(;W)D
M93HZ;&EN:R@D=7)L+"!?*")396YD(%--4R(I*2`N($AO<F1E.CII;6<H)VUO
M8FEL92YP;F<G+"!?*")396YD(%--4R(I+"`G)RP@)')E9VES=')Y+3YG971)
M;6%G941I<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<D1I<W!L87E?861D<F5S<R@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&%D9')E<W,@
M/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@)&%U<U]S=&%T95]R
M96=E>"`]("<H/SI!0U1\3E-7?$Y4?%%,1'Q307Q405-\5DE#?%=!*2<["@H@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*"@_.D%;0DQ=?$);04)$2$Q.4E-4
M73]\0UM!0D9(34]25%9777Q$6T%$14=(3$Y465U\15M#2$Y873]\1EM+65U\
M1UM,55E=/WQ(6T%$1U!24U5877Q)6T=-4%9=?$I%?$M;051765U\3%M!1$5,
M3E-573]\35M%2TQ=/WQ.6T5'3E!25UT_?$];3%A=?%!;045(3$]277Q26T=(
M35U\4UM!14=+3$U.3U!24U1765T_?%1;041&3E%24U==?%5"?%=;04-$1DY2
M4U9=/WQ93WQ:12E<9"@_.EQD?%M!+5I=*3\@7&1;02U:77LR?2DO)RP@)&%D
M9')E<W,L("1P;W-T8V]D92DI('L*("`@("`@("`@("`@+RH@54L@<&]S=&-O
M9&4@9&5T96-T960N("HO"B`@("`@("`@("`@("\J($UU;'1I;6%P+F-O+G5K
M(&=E;F5R871E9"!M87`@*B\*("`@("`@("`@("`@)&UA<'5R;"`]("=H='1P
M.B\O=W=W+FUU;'1I;6%P+F-O;2]M87`O8G)O=W-E+F-G:3]P8STG("X@=7)L
M96YC;V1E*"1P;W-T8V]D95LQ72D["B`@("`@("`@("`@("1D97-C(#T@7R@B
M375L=&EM87`@54L@;6%P(BD["B`@("`@("`@("`@("1I8V]N(#T@)VUA<"YP
M;F<G.PH@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7&(G("X@)&%U
M<U]S=&%T95]R96=E>"`N("=<8B\G+"`D861D<F5S<RDI('L*("`@("`@("`@
M("`@+RH@075S=')A;&EA;B!S=&%T92!D971E8W1E9"X@*B\*("`@("`@("`@
M("`@+RH@5VAE<F5I<RYC;VTN874@9V5N97)A=&5D(&UA<"`J+PH@("`@("`@
M("`@("`D;6%P=7)L(#T@)VAT='`Z+R]W=W<N=VAE<F5I<RYC;VTN874O=VAE
M<F5I<R]M87!P:6YG+V=E;V-O9&5!9&1R97-S+F1O/R<["B`@("`@("`@("`@
M("1D97-C(#T@7R@B5VAE<F5I<R!!=7-T<F%L:6$@;6%P(BD["B`@("`@("`@
M("`@("1I8V]N(#T@)VUA<"YP;F<G.PH@("`@("`@("`@("`O*B!3<&QI="!O
M=70@=&AE(&%D9')E<W,L(&QI;F4M8GDM;&EN92X@*B\*("`@("`@("`@("`@
M)&%D9')E<W-,:6YE<R`](&5X<&QO9&4H(EQN(BP@)&%D9')E<W,I.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D861D<F5S<TQI;F5S
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@+RH@4V5E(&EF(&ET)W,@=&AE
M('-T<F5E="!N=6UB97(@)B!N86UE+B`J+PH@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R\H7&0K7',J7"]<<RHI/RA<9"M\7&0K6V$M>D$M6ETI
M7',K*%MA+7I!+5H@72HI+R<L("1A9&1R97-S3&EN97-;)&E=+"`D;&EN95!A
M<G1S*2D@>PH@("`@("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9S=')E
M971.=6UB97(])R`N('5R;&5N8V]D92@D;&EN95!A<G1S6S)=*2`N("<F<W1R
M965T3F%M93TG("X@=7)L96YC;V1E*"1L:6YE4&%R='-;,UTI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@+RH@3&]O:R!F;W(@(E-U8G5R
M8BP@4W1A=&4B+B`J+PH@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R\H6V$M>D$M6B!=*BDL/UQS*R<@+B`D875S7W-T871E7W)E9V5X("X@)R\G
M+"`D861D<F5S<TQI;F5S6R1I72P@)&QI;F5087)T<RDI('L*("`@("`@("`@
M("`@("`@("`@("`D;6%P=7)L("X]("<F<W5B=7)B/2<@+B!U<FQE;F-O9&4H
M)&QI;F5087)T<ULQ72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`O*B!,;V]K(&9O<B`B4W1A=&4@/#0@9&EG:70@<&]S=&-O9&4^(BX@
M*B\*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*"<@+B`D875S
M7W-T871E7W)E9V5X("X@)RE<<RLH7&1[-'TI+R<L("1A9&1R97-S3&EN97-;
M)&E=+"`D;&EN95!A<G1S*2D@>PH@("`@("`@("`@("`@("`@("`@("1M87!U
M<FP@+CT@)R9S=&%T93TG("X@=7)L96YC;V1E*"1L:6YE4&%R='-;,5TI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M:68@*'!R96=?;6%T8V@H)R\H+BHI7&XH+BHI7',J+%QS*BA<=RLI7"X_7',K
M*%QD*WQ;82UZ02U:75QD6V$M>D$M6EU<<S]<9%MA+7I!+5I=7&0I+R<L("1A
M9&1R97-S+"`D861D<F5S<U!A<G1S*2D@>PH@("`@("`@("`@("`O*B!!;65R
M:6-A;B]#86YA9&EA;B!A9&1R97-S('-T>6QE+B`J+PH@("`@("`@("`@("`O
M*B!-87!Q=65S="!G96YE<F%T960@;6%P("HO"B`@("`@("`@("`@("1M87!U
M<FP@/2`G:'1T<#HO+W=W=RYM87!Q=65S="YC;VTO;6%P<R]M87`N861P/W-I
M>F4]8FEG)GIO;VT]-R<["B`@("`@("`@("`@("1D97-C(#T@7R@B36%P475E
M<W0@;6%P(BD["B`@("`@("`@("`@("1I8V]N(#T@)VUA<"YP;F<G.PH@("`@
M("`@("`@("`D8V]U;G1R>2`](&YU;&P["B`@("`@("`@("`@(&EF("@A96UP
M='DH)&%D9')E<W-087)T<ULT72D@)B8@<')E9U]M871C:"@G?%MA+7I!+5I=
M7&1;82UZ02U:75QS/UQD6V$M>D$M6EU<9'PG+"`D861D<F5S<U!A<G1S6S1=
M*2D@>PH@("`@("`@("`@("`@("`@)&-O=6YT<GD@/2`G0T$G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULQ
M72DI('L*("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9A9&1R97-S/2<@
M+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULQ72D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S)=*2D@>PH@
M("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)F-I='D])R`N('5R;&5N8V]D
M92@D861D<F5S<U!A<G1S6S)=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,UTI*2!["B`@("`@("`@("`@
M("`@("`D;6%P=7)L("X]("<F<W1A=&4])R`N('5R;&5N8V]D92@D861D<F5S
M<U!A<G1S6S-=*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1A9&1R97-S4&%R='-;-%TI*2!["B`@("`@("`@("`@("`@("!I9B`H
M)&-O=6YT<GD@/3T@)T-!)RD@>PH@("`@("`@("`@("`@("`@("`@("1M87!U
M<FP@+CT@)R9C;W5N=')Y/4-!)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1M87!U<FP@+CT@)R9Z:7!C;V1E/2<@+B!U<FQE;F-O9&4H
M)&%D9')E<W-087)T<ULT72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J(%EA:&]O(2!G96YE<F%T960@;6%P+B`J+PH@("`@("`@("`@("`D;6%P
M=7)L,B`]("=H='1P.B\O=7,N<F0N>6%H;V\N8V]M+VUA<',O:&]M92]S=6)M
M:71?82\J+6AT='`Z+R]M87!S+GEA:&]O+F-O;2]M87!S/W-R8VAT>7!E/6$F
M9V5T;6%P/4=E="M-87`F)SL*("`@("`@("`@("`@)&1E<V,R(#T@7R@B66%H
M;V\A(&UA<"(I.PH@("`@("`@("`@("`D:6-O;C(@/2`G;6%P+G!N9R<["B`@
M("`@("`@("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULQ72DI('L*("`@
M("`@("`@("`@("`@("1M87!U<FPR("X]("<F861D<CTG("X@=7)L96YC;V1E
M*"1A9&1R97-S4&%R='-;,5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("\J($=I=F4@<')E8V5D96YC92!T;R!Z:7!C;V1E(&]V97(@8VET>2]S=&%T
M92`J+PH@("`@("`@("`@("!I9B`H96UP='DH)&%D9')E<W-087)T<ULT72D@
M)B8@(65M<'1Y*"1A9&1R97-S4&%R='-;,ETI("8F("%E;7!T>2@D861D<F5S
M<U!A<G1S6S-=*2D@>PH@("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@)R9C
M<WH])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S)=("X@)R`G("X@)&%D
M9')E<W-087)T<ULS72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D861D<F5S<U!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@("`@
M:68@*'!R96=?;6%T8V@H)WPH6V$M>D$M6EU<9%MA+7I!+5I=*5QS/RA<9%MA
M+7I!+5I=7&0I?"<L("1A9&1R97-S4&%R='-;-%TL("1P8U!A<G1S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1M87!U<FPR("X]("<F8V]U;G1R>3UC82<[
M"B`@("`@("`@("`@("`@("`@("`@+RH@;6%K92!S=7)E('1H92!P;W-T86PM
M8V]D92!H87,@82!S<&%C92`J+PH@("`@("`@("`@("`@("`@("`@("1A9&1R
M97-S4&%R='-;-%T@/2`D<&-087)T<ULQ72`N("<@)R`N("1P8U!A<G1S6S)=
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UA<'5R;#(@
M+CT@)R9C<WH])R`N('5R;&5N8V]D92@D861D<F5S<U!A<G1S6S1=*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+RH@1V]O9VQE(&=E;F5R871E9"!M
M87`N("HO"B`@("`@("`@("`@("1M87!U<FPS(#T@)VAT='`Z+R]M87!S+F=O
M;V=L92YC;VTO;6%P<S]Q/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-087)T<ULP
M72D@+B`G)FAL/65N)SL*("`@("`@("`@("`@)&1E<V,S(#T@7R@B1V]O9VQE
M($UA<',B*3L*("`@("`@("`@("`@)&EC;VXS(#T@)VUA<"YP;F<G.PH*("`@
M("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+R@N*C\I7'(_7&XH6T$M6EU[
M,2PS?2DM*%QD>S5]*5QS*R@N*BDO:2<L("1A9&1R97-S+"`D861D<F5S<U!A
M<G1S*2D@>PH@("`@("`@("`@("`O*B!%=7)O<&5A;B!A9&1R97-S('-T>6QE
M+B`J+PH@("`@("`@("`@("!I;F-L=61E("=(;W)D92].3%,O8V%R<VEG;G,N
M<&AP)SL*("`@("`@("`@("`@)&-O=6YT<GD@/2!A<G)A>5]S96%R8V@H4W1R
M:6YG.CIU<'!E<B@D861D<F5S<U!A<G1S6S)=*2P@)&-A<G-I9VYS*3L*"B`@
M("`@("`@("`@("\J($UA<#(T(&=E;F5R871E9"!M87`N("HO"B`@("`@("`@
M("`@(&EF("AI;E]A<G)A>2@D8V]U;G1R>2P@87)R87DH)V%L)RP@)V%D)RP@
M)V%M)RP@)V%Z)RP@)V)E)RP@)V)A)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G8F<G+"`G9&4G+"`G9&LG+"`G964G+"`G
M9F\G+"`G9FDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=F<B<L("=G92<L("=G<B<L("=G8B<L("=I92<L("=I<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VET)RP@
M)VAR)RP@)VQV)RP@)VQI)RP@)VQT)RP@)VQU)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;70G+"`G;6LG+"`G;60G+"`G
M;6,G+"`G;FPG+"`G;F\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P;"<L("=P="<L("=R;R<L("=R=2<L("=S92<L("=C
M:"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-S)RP@)W-K)RP@)W-I)RP@)V5S)RP@)V-Z)RP@)W1R)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=6$G+"`G:'4G+"`G
M8GDG+"`G8WDG+"`G870G*2DI('L*("`@("`@("`@("`@("`@(&EF("AI;E]A
M<G)A>2@D8V]U;G1R>2P@87)R87DH)V%T)RP@)V)E)RP@)V-H)RP@)V1E)RP@
M)V1K)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V5S)RP@)V9I)RP@)V9R)RP@)VET)RP@)VYL)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYO)RP@)W-E
M)RDI*2!["B`@("`@("`@("`@("`@("`@("`@)&UI<G)O<B`]("1C;W5N=')Y
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D;6ER<F]R(#T@)W5K)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1M87!U<FP@/2`G:'1T<#HO+W=W=RXG("X@)&UI<G)O<B`N("<N
M;6%P,C0N8V]M+W-O=7)C92]A9&1R97-S+W8R+C`N,"]C;G1?;F%V7VUA<&QE
M="YP:'`_8VED/79A;&ED871E861D<B9C;W5N=')Y/2<@+B`D8V]U;G1R>3L*
M("`@("`@("`@("`@("`@("1D97-C(#T@7R@B36%P,C0@;6%P(BD["B`@("`@
M("`@("`@("`@("`D:6-O;B`]("=M87!?974N<&YG)SL*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)&%D9')E<W-087)T<ULQ72DI('L*("`@("`@("`@
M("`@("`@("`@("`D;6%P=7)L("X]("<F<W1R965T/2<@+B!U<FQE;F-O9&4H
M)&%D9')E<W-087)T<ULQ72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1A9&1R97-S4&%R='-;,UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&UA<'5R;"`N/2`G)GII<#TG("X@=7)L96YC;V1E
M*"1A9&1R97-S4&%R='-;,UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S1=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1M87!U<FP@+CT@)R9C:71Y/2<@+B!U<FQE;F-O
M9&4H)&%D9')E<W-087)T<ULT72D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($UA<'%U97-T(&=E;F5R871E9"!M
M87`N("HO"B`@("`@("`@("`@("1M87!U<FPR(#T@)VAT='`Z+R]W=W<N;6%P
M<75E<W0N8V]M+VUA<',O;6%P+F%D<#]C;W5N=')Y/2<@+B!3=')I;F<Z.G5P
M<&5R*"1C;W5N=')Y*3L*("`@("`@("`@("`@)&1E<V,R(#T@7R@B36%P475E
M<W0@;6%P(BD["B`@("`@("`@("`@("1I8V]N,B`]("=M87!?974N<&YG)SL*
M("`@("`@("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S%=*2D@>PH@
M("`@("`@("`@("`@("`@)&UA<'5R;#(@+CT@)R9A9&1R97-S/2<@+B!U<FQE
M;F-O9&4H)&%D9')E<W-087)T<ULQ72D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S-=*2D@>PH@("`@("`@
M("`@("`@("`@)&UA<'5R;#(@+CT@)R9Z:7!C;V1E/2<@+B!U<FQE;F-O9&4H
M)&%D9')E<W-087)T<ULS72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D861D<F5S<U!A<G1S6S1=*2D@>PH@("`@("`@("`@("`@
M("`@)&UA<'5R;#(@+CT@)R9C:71Y/2<@+B!U<FQE;F-O9&4H)&%D9')E<W-0
M87)T<ULT72D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1H
M=&UL(#T@;FPR8G(H0&AT;6QS<&5C:6%L8VAA<G,H)&%D9')E<W,L($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DI.PH@("`@("`@(&EF("@A96UP='DH
M)&UA<'5R;"DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)R9N8G-P.R9N8G-P
M.R<@+B!(;W)D93HZ;&EN:RA(;W)D93HZ97AT97)N86Q5<FPH)&UA<'5R;"DL
M("1D97-C+"!N=6QL+"`G7V)L86YK)RD@+B!(;W)D93HZ:6UG*"1I8V]N+"`D
M9&5S8RP@)V%L:6=N/2)M:61D;&4B)RP@)')E9VES=')Y+3YG971);6%G941I
M<B@G:&]R9&4G*2D@+B`G/"]A/B<["B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&UA<'5R;#(I*2!["B`@("`@("`@("`@("1H=&UL("X]("<F;F)S
M<#LG("X@2&]R9&4Z.FQI;FLH2&]R9&4Z.F5X=&5R;F%L57)L*"1M87!U<FPR
M*2P@)&1E<V,R+"!N=6QL+"`G7V)L86YK)RD@+B!(;W)D93HZ:6UG*"1I8V]N
M,BP@)&1E<V,R+"`G86QI9VX](FUI9&1L92(G+"`D<F5G:7-T<GDM/F=E=$EM
M86=E1&ER*"=H;W)D92<I*2`N("<\+V$^)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"%E;7!T>2@D;6%P=7)L,RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)R9N8G-P.R<@+B!(;W)D93HZ;&EN:RA(;W)D93HZ97AT97)N86Q5<FPH)&UA
M<'5R;#,I+"`D9&5S8S,L(&YU;&PL("=?8FQA;FLG*2`N($AO<F1E.CII;6<H
M)&EC;VXS+"`D9&5S8S,L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^
M9V5T26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD
M97)687)$:7-P;&%Y7V1A=&4H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@(')E='5R;B!H=&UL<W!E8VEA;&-H87)S*"1V87(M/G1Y<&4M
M/F=E=$9O<FUA='1E9%1I;64H)'9A<BT^9V5T5F%L=64H)'9A<G,I*2D["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?:&]U<FUI;G5T
M97-E8V]N9"@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@
M)'1I;64@/2`D=F%R+3YT>7!E+3YG9714:6UE4&%R=',H)'9A<BT^9V5T5F%L
M=64H)'9A<G,I*3L*("`@("`@("!I9B`H(21V87(M/G1Y<&4M/E]S:&]W7W-E
M8V]N9',I('L*("`@("`@("`@("`@<F5T=7)N("AI;G0I)'1I;65;)VAO=7(G
M72`N("<Z)R`N('-P<FEN=&8H)R4P,F0G+"`H:6YT*21T:6UE6R=M:6YU=&4G
M72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("AI;G0I
M)'1I;65;)VAO=7(G72`N("<Z)R`N('-P<FEN=&8H)R4P,F0G+"`H:6YT*21T
M:6UE6R=M:6YU=&4G72D@+B`G.B<@+B!S<')I;G1F*"<E,#)D)RP@*&EN="DD
M=&EM95LG<V5C;VYD)UTI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R5F%R1&ES<&QA>5]M;VYT:'EE87(H)B1F;W)M+"`F)'9A<BP@
M)B1V87)S*0H@("`@>PH@("`@("`@(')E='5R;B`H:6YT*21V87)S+3YG970H
M)'9A<BT^9V5T5F%R3F%M92@I("X@)UMM;VYT:%TG*2`N("<L("<@+B`H:6YT
M*21V87)S+3YG970H)'9A<BT^9V5T5F%R3F%M92@I("X@)UMY96%R72<I.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)687)$:7-P;&%Y7VUO;G1H9&%Y
M>65A<B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@("`@)&1A
M=&4@/2`D=F%R+3YG971686QU92@D=F%R<RD["B`@("`@("`@:68@*"AI<U]A
M<G)A>2@D9&%T92D@)B8@(65M<'1Y*"1D871E6R=Y96%R)UTI("8F"B`@("`@
M("`@("`@("`A96UP='DH)&1A=&5;)VUO;G1H)UTI("8F("%E;7!T>2@D9&%T
M95LG9&%Y)UTI*0H@("`@("`@("`@("!\?"`H(6ES7V%R<F%Y*"1D871E*2`F
M)B`A96UP='DH)&1A=&4I*2D@>PH@("`@("`@("`@("!R971U<FX@)'9A<BT^
M='EP92T^9F]R;6%T1&%T92@D9&%T92D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5F%R1&ES<&QA
M>5]I;G9A;&ED*"8D9F]R;2P@)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@
M("!R971U<FX@)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXG("X@0&AT;6QS
M<&5C:6%L8VAA<G,H)'9A<BT^='EP92T^;65S<V%G92P@14Y47U%53U1%4RP@
M)'1H:7,M/E]C:&%R<V5T*2`N("<\+W-P86X^)SL*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5F%R1&ES<&QA>5]L:6YK*"8D9F]R;2P@)B1V87(L("8D
M=F%R<RD*("`@('L*("`@("`@("`D=F%L=65S(#T@)'9A<BT^='EP92T^=F%L
M=65S.PH@("`@("`@(&EF("@A:7-S970H)'9A;'5E<ULP72DI('L*("`@("`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1V86QU97,I.PH@("`@("`@('T*"B`@
M("`@("`@)&-O=6YT(#T@8V]U;G0H)'9A;'5E<RD["B`@("`@("`@)&AT;6P@
M/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI
M('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1V86QU97-;)&E=6R=U<FPG72D@
M?'P@96UP='DH)'9A;'5E<ULD:5U;)W1E>'0G72DI('L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'9A;'5E<ULD:5U;)W1A<F=E="==*2D@>PH@("`@("`@("`@("`@
M("`@)'9A;'5E<ULD:5U;)W1A<F=E="==(#T@)R<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=F%L=65S6R1I75LG;VYC;&EC:R==
M*2D@>PH@("`@("`@("`@("`@("`@)'9A;'5E<ULD:5U;)V]N8VQI8VLG72`]
M("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A
M;'5E<ULD:5U;)W1I=&QE)UTI*2!["B`@("`@("`@("`@("`@("`D=F%L=65S
M6R1I75LG=&ET;&4G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'9A;'5E<ULD:5U;)V%C8V5S<VME>2==*2D@>PH@("`@
M("`@("`@("`@("`@)'9A;'5E<ULD:5U;)V%C8V5S<VME>2==(#T@)R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1I(#X@,"D@>PH@("`@("`@
M("`@("`@("`@)&AT;6P@+CT@)R!\("<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&AT;6P@+CT@2&]R9&4Z.FQI;FLH)'9A;'5E<ULD:5U;)W5R;"==
M+"`D=F%L=65S6R1I75LG=&5X="==+"`G=VED9V5T)RP@)'9A;'5E<ULD:5U;
M)W1A<F=E="==+"`D=F%L=65S6R1I75LG;VYC;&EC:R==+"`D=F%L=65S6R1I
M75LG=&ET;&4G72P@)'9A;'5E<ULD:5U;)V%C8V5S<VME>2==*2`N($!H=&UL
M<W!E8VEA;&-H87)S*"1V86QU97-;)&E=6R=T97AT)UTL($5.5%]154]415,L
M("1T:&ES+3Y?8VAA<G-E="D@+B`G/"]A/B<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A
M<D1I<W!L87E?9&)L;V]K=7`H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<E9A<D1I<W!L87E?96YU
M;2@D9F]R;2P@)'9A<BP@)'9A<G,I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R
M96YD97)687)$:7-P;&%Y7V9I9VQE="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@<W1A=&EC("1F:6=L970["@H@("`@("`@(&EF("@A
M:7-S970H)&9I9VQE="DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=4
M97AT+T9I9VQE="YP:'`G.PH@("`@("`@("`@("`D9FEG;&5T(#T@)FYE=R!4
M97AT7T9I9VQE="@I.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]("1F
M:6=L970M/FQO861&;VYT*"1V87(M/G1Y<&4M/F=E=$9O;G0H*2D["B`@("`@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L="T^9V5T365S<V%G92@I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("<\<')E/B<@+B`D9FEG;&5T+3YL:6YE16-H;R@D
M=F%R+3YT>7!E+3YG971497AT*"DI("X@)SPO<')E/B<["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E9A<DEN<'5T7W-E;&5C=$9I;&5S*"8D9F]R;2P@
M)B1V87(L("8D=F%R<RD*("`@('L*("`@("`@("`O*B!.965D960@9F]R(&=O
M;&QE;2!J<R!C86QL<R`J+PH@("`@("`@("1V87)N86UE(#T@0&AT;6QS<&5C
M:6%L8VAA<G,H)'9A<BT^9V5T5F%R3F%M92@I+"!%3E1?455/5$53+"`D=&AI
M<RT^7V-H87)S970I.PH@("`@("`@("1H=&UL(#T@<W!R:6YT9B@G/&EN<'5T
M('1Y<&4](FAI9&1E;B(@;F%M93TB)7,B(&ED/2(E<R(@=F%L=64](B5S(B`O
M/B<L"B`@("`@("`@("`@("`@("`@("`@("`@("=S96QE8W1L:7-T7W-E;&5C
M=&ED)RP*("`@("`@("`@("`@("`@("`@("`@("`@)W-E;&5C=&QI<W1?<V5L
M96-T:60G+`H@("`@("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3Y?
M<V5L96-T:60I("X*("`@("`@("`@("`@<W!R:6YT9B@G/&EN<'5T('1Y<&4]
M(FAI9&1E;B(@;F%M93TB)7,B(&ED/2(E<R(@+SXG+"`G86-T:6]N240G+"`G
M86-T:6]N240G*2`N"@H@("`@("`@("`@("`O*B!&;W)M(&9I96QD+B`J+PH@
M("`@("`@("`@("!S<')I;G1F*"<\:6YP=70@='EP93TB:&ED9&5N(B!N86UE
M/2(E<R(@:60](B5S(B!V86QU93TB)7,B("\^)RP*("`@("`@("`@("`@("`@
M("`@("`D=F%R;F%M92P*("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92P*
M("`@("`@("`@("`@("`@("`@("`D=F%R+3YT>7!E+3Y?<V5L96-T:60I.PH*
M("`@("`@("`O*B!/<&5N('=I;F1O=R!L:6YK+B`J+PH@("`@("`@("1P87)A
M;2`](&%R<F%Y*"1V87(M/G1Y<&4M/E]L:6YK7W1E>'0L"B`@("`@("`@("`@
M("`@("`@("`@("`@)'9A<BT^='EP92T^7VQI;FM?<W1Y;&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<FTM/F=E=$YA;64H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`D=F%R+3YT>7!E+3Y?:6-O;BP*("`@("`@("`@("`@("`@
M("`@("`@("`D=F%R+3YT>7!E+3Y?<V5L96-T:60I.PH@("`@("`@("1H=&UL
M("X]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=F:6QE<R]S96QE8W1L
M:7-T3&EN:R<L("1P87)A;2D@+B`B/&)R("\^7&XB.PH*("`@("`@("!I9B`H
M)'9A<BT^='EP92T^7W-E;&5C=&ED*2!["B`@("`@("`@("`@("1P87)A;2`]
M(&%R<F%Y*"1V87(M/G1Y<&4M/E]S96QE8W1I9"D["B`@("`@("`@("`@("1F
M:6QE<R`]("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL*"=F:6QE<R]S96QE
M8W1L:7-T4F5S=6QT<R<L("1P87)A;2D["B`@("`@("`@("`@(&EF("@D9FEL
M97,I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F:6QE<R!A<R`D:60@
M/3X@)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("`D9&ER(#T@:V5Y*"1F
M:6QE*3L*("`@("`@("`@("`@("`@("`@("`D9FEL96YA;64@/2!C=7)R96YT
M*"1F:6QE*3L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`H)&ED("L@
M,2D@+B`G+B`G.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&1I
M<BD@)B8@*"1D:7(@(3T@)RXG*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEL96YA;64@/2`D9&ER("X@)R\G("X@)&9I;&5N86UE.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!`
M:'1M;'-P96-I86QC:&%R<R@D9FEL96YA;64L($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="D@+B`B/&)R("\^7&XB.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W-E;&5C=$]P=&EO;G,H)B1V86QU97,L
M("1S96QE8W1E9%9A;'5E(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:'1M;&-H87)S(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E
M<W5L="`]("<G.PH@("`@("`@("1S96P@/2!F86QS93L*("`@("`@("!F;W)E
M86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D9&ES<&QA>2D@>PH@("`@("`@
M("`@("!I9B`H(6ES7VYU;&PH)'-E;&5C=&5D5F%L=64I("8F("$D<V5L("8F
M"B`@("`@("`@("`@("`@("`D=F%L=64@/3T@)'-E;&5C=&5D5F%L=64@)B8*
M("`@("`@("`@("`@("`@('-T<FQE;B@D=F%L=64I(#T]('-T<FQE;B@D<V5L
M96-T961686QU92DI('L*("`@("`@("`@("`@("`@("1S96QE8W1E9"`]("<@
M<V5L96-T960](G-E;&5C=&5D(B<["B`@("`@("`@("`@("`@("`D<V5L(#T@
M=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1S
M96QE8W1E9"`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U
M;'0@+CT@)R`\;W!T:6]N('9A;'5E/2(G.PH@("`@("`@("`@("`D<F5S=6QT
M("X]("1H=&UL8VAA<G,*("`@("`@("`@("`@("`@(#\@)'9A;'5E"B`@("`@
M("`@("`@("`@("`Z($!H=&UL<W!E8VEA;&-H87)S*"1V86QU92P@14Y47U%5
M3U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@)')E<W5L="`N
M/2`G(B<@+B`D<V5L96-T960@+B`G/B<["B`@("`@("`@("`@("1R97-U;'0@
M+CT@)&AT;6QC:&%R<PH@("`@("`@("`@("`@("`@/R`D9&ES<&QA>0H@("`@
M("`@("`@("`@("`@.B!`:'1M;'-P96-I86QC:&%R<R@D9&ES<&QA>2P@14Y4
M7U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@)')E<W5L
M="`N/2`B/"]O<'1I;VX^7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("!]"@H@("`@9G5N8W1I;VX@7VUU;'1I4V5L96-T3W!T
M:6]N<R@F)'9A;'5E<RP@)'-E;&5C=&5D5F%L=65S*0H@("`@>PH@("`@("`@
M("1R97-U;'0@/2`G)SL*("`@("`@("`D<V5L(#T@9F%L<V4["B`@("`@("`@
M9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@)&1I<W!L87DI('L*("`@
M("`@("`@("`@:68@*$!I;E]A<G)A>2@D=F%L=64L("1S96QE8W1E9%9A;'5E
M<RDI('L*("`@("`@("`@("`@("`@("1S96QE8W1E9"`]("<@<V5L96-T960]
M(G-E;&5C=&5D(B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<V5L96-T960@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D<F5S=6QT("X]("(@/&]P=&EO;B!V86QU93U<(B(@+B!`:'1M;'-P96-I
M86QC:&%R<R@D=F%L=64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="D@
M+B`B7"(D<V5L96-T960^(B`N($!H=&UL<W!E8VEA;&-H87)S*"1D:7-P;&%Y
M+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I("X@(CPO;W!T:6]N/EQN
M(CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]C:&5C:T)O>&5S*"1N86UE+"`D=F%L=65S+"`D8VAE
M8VME9%9A;'5E<RP@)&%C=&EO;G,@/2`G)RD*("`@('L*("`@("`@("`D<F5S
M=6QT(#T@)R<["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8VAE8VME9%9A;'5E
M<RDI('L*("`@("`@("`@("`@)&-H96-K961686QU97,@/2!A<G)A>2@I.PH@
M("`@("`@('T*("`@("`@("`D:2`](#`["B`@("`@("`@9F]R96%C:"`H)'9A
M;'5E<R!A<R`D=F%L=64@/3X@)&1I<W!L87DI('L*("`@("`@("`@("`@)&-H
M96-K960@/2`H:6Y?87)R87DH)'9A;'5E+"`D8VAE8VME9%9A;'5E<RDI(#\@
M)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*("`@("`@("`@("`@)')E<W5L
M="`N/2!S<')I;G1F*"<\:6YP=70@:60](B5S)7,B('1Y<&4](F-H96-K8F]X
M(B!C;&%S<STB8VAE8VMB;W@B(&YA;64](B5S6UTB('9A;'5E/2(E<R(E<R5S
M("\^/&QA8F5L(&9O<CTB)7,E<R(^)FYB<W`[)7,\+VQA8F5L/CQB<B`O/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC
M:&%R<R@D;F%M92P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.
M5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R<R@D=F%L=64L($5.5%]1
M54]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8VAE8VME9"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1A8W1I;VYS+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@0&AT;6QS<&5C:6%L8VAA<G,H)&YA;64L($5.5%]154]415,L("1T:&ES
M+3Y?8VAA<G-E="DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M:2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA
M;&-H87)S*"1D:7-P;&%Y+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I
M*3L*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R861I;T)U='1O;G,H
M)&YA;64L("1V86QU97,L("1C:&5C:V5D5F%L=64@/2!N=6QL+"`D86-T:6]N
M<R`]("<G*0H@("`@>PH@("`@("`@("1R97-U;'0@/2`G)SL*("`@("`@("`D
M:2`](#`["B`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L=64@/3X@
M)&1I<W!L87DI('L*("`@("`@("`@("`@)&-H96-K960@/2`H(6ES7VYU;&PH
M)&-H96-K961686QU92D@)B8@)'9A;'5E(#T]("1C:&5C:V5D5F%L=64I(#\@
M)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*("`@("`@("`@("`@)')E<W5L
M="`N/2!S<')I;G1F*"<\:6YP=70@:60](B5S)7,B('1Y<&4](G)A9&EO(B!C
M;&%S<STB8VAE8VMB;W@B(&YA;64](B5S(B!V86QU93TB)7,B)7,E<R`O/CQL
M86)E;"!F;W(](B5S)7,B/B9N8G-P.R5S/"]L86)E;#X\8G(@+SXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H
M)&YA;64L($5.5%]154]415,L("1T:&ES+3Y?8VAA<G-E="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N86UE+"!%3E1?455/
M5$53+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@0&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E+"!%3E1?455/5$53
M+"`D=&AI<RT^7V-H87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-H96-K960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D86-T:6]N<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($!H
M=&UL<W!E8VEA;&-H87)S*"1N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H
M87)S970I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R
M<R@D9&ES<&QA>2P@14Y47U%53U1%4RP@)'1H:7,M/E]C:&%R<V5T*2D["B`@
M("`@("`@("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N240H)&YA;64L("1F=6QL
M=&%G(#T@=')U92D*("`@('L*("`@("`@("`D;F%M92`]($!H=&UL<W!E8VEA
M;&-H87)S*"1N86UE+"!%3E1?455/5$53+"`D=&AI<RT^7V-H87)S970I.PH@
M("`@("`@(')E='5R;B`D9G5L;'1A9R`_("=I9#TB)R`N("1N86UE("X@)R(G
M(#H@)&YA;64["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E;D%C=&EO;E-C<FEP
M="@F)&9O<FTL("1A8W1I;VXL("1V87)N86UE*0H@("`@>PH@("`@("`@("1H
M=&UL(#T@)R<["B`@("`@("`@)'1R:6=G97)S(#T@)&%C=&EO;BT^9V5T5')I
M9V=E<B@I.PH@("`@("`@(&EF("@A:7-?87)R87DH)'1R:6=G97)S*2D@>PH@
M("`@("`@("`@("`D=')I9V=E<G,@/2!A<G)A>2@D=')I9V=E<G,I.PH@("`@
M("`@('T*("`@("`@("`D:G,@/2`D86-T:6]N+3YG971!8W1I;VY38W)I<'0H
M)&9O<FTL("1T:&ES+"`D=F%R;F%M92D["B`@("`@("`@9F]R96%C:"`H)'1R
M:6=G97)S(&%S("1T<FEG9V5R*2!["B`@("`@("`@("`@(&EF("@D=')I9V=E
M<B`]/2`G;VYL;V%D)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1/
M;DQO861*879A<V-R:7!T*"1J<RD["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G("<@+B`D=')I9V=E<B`N("<](B<@
M+B`D:G,@+B`G(B<["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1H=&UL.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G971!8W1I;VY3
M8W)I<'1S*"8D9F]R;2P@)B1V87(I"B`@("!["B`@("`@("`@)&%C=&EO;G,@
M/2`G)SL*("`@("`@("!I9B`H)'9A<BT^:&%S06-T:6]N*"DI('L*("`@("`@
M("`@("`@)'9A<FYA;64@/2`D=F%R+3YG971687).86UE*"D["B`@("`@("`@
M("`@("1A8W1I;VX@/28@)'9A<BT^7V%C=&EO;CL*("`@("`@("`@("`@)'1R
M:6=G97)S(#T@)&%C=&EO;BT^9V5T5')I9V=E<B@I.PH@("`@("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1T<FEG9V5R<RDI('L*("`@("`@("`@("`@("`@("1T
M<FEG9V5R<R`](&%R<F%Y*"1T<FEG9V5R<RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&IS(#T@)&%C=&EO;BT^9V5T06-T:6]N4V-R:7!T*"1F;W)M
M+"`D=&AI<RP@)'9A<FYA;64I.PH@("`@("`@("`@("!F;W)E86-H("@D=')I
M9V=E<G,@87,@)'1R:6=G97(I('L*("`@("`@("`@("`@("`@(&EF("@D=')I
M9V=E<B`]/2`G;VYL;V%D)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?861D3VY,;V%D2F%V87-C<FEP="@D:G,I.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D86-T:6]N<R`N/2`G("<@
M+B`D=')I9V=E<B`N("<](B<@+B`D:G,@+B`G(B<["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A
M8W1I;VYS.PH@("`@?0H*("`@(&9U;F-T:6]N(%]A9&1/;DQO861*879A<V-R
M:7!T*"1S8W)I<'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]O;DQO861*4UM=
M(#T@)'-C<FEP=#L*("`@('T*"B`@("!F=6YC=&EO;B!R96YD97)%;F0H*0H@
M("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7V]N3&]A9$I3*2D@>PH@
M("`@("`@("`@("!R971U<FX@(CQS8W)I<'0@='EP93U<(G1E>'0O:F%V87-C
M<FEP=%PB/B(@+@H@("`@("`@("`@("`@("`@(CPA+2U<;B(@+B`@:6UP;&]D
M92@B7&XB+"`D=&AI<RT^7V]N3&]A9$I3*2`N(")<;B\O("TM/EQN(B`N"B`@
M("`@("`@("`@("`@("`B/"]S8W)I<'0^(CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U5)+U9A<E)E;F1E
M<F5R+W1A8FQE<V5T7VAT;6PN<&AP````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,#0T
M(#$P-3$U-#,T,30P(#`R-30S-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]5
M22]687)296YD97)E<B]H=&UL+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M
M97=O<FLO54DO54DO5F%R4F5N9&5R97(O=&%B;&5S971?:'1M;"YP:'`L=B`Q
M+C,N,BXQ(#(P,#4O,3`O,3@@,3$Z,#$Z,S8@:F%N($5X<"`D"B`J"B`J($!P
M86-K86=E($AO<F1E7U5)"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B\*8VQA
M<W,@2&]R9&5?54E?5F%R4F5N9&5R97)?=&%B;&5S971?:'1M;"!E>'1E;F1S
M($AO<F1E7U5)7U9A<E)E;F1E<F5R7VAT;6P@>PH*("`@(&9U;F-T:6]N(%]R
M96YD97)687));G!U=%]T86)L97-E="@F)&9O<FTL("8D=F%R+"`F)'9A<G,I
M"B`@("!["B`@("`@("`@)&AE861E<B`]("1V87(M/G1Y<&4M/F=E=$AE861E
M<B@I.PH@("`@("`@("1N86UE("`@/2`D=F%R+3YG971687).86UE*"D["B`@
M("`@("`@)'9A;'5E<R`]("1V87(M/F=E=%9A;'5E<R@I.PH@("`@("`@("1C
M:&5C:V5D5F%L=65S(#T@)'9A<BT^9V5T5F%L=64H)'9A<G,I.PH@("`@("`@
M("1A8W1I;VYS(#T@)'1H:7,M/E]G971!8W1I;VY38W)I<'1S*"1F;W)M+"`D
M=F%R*3L*"B`@("`@("`@)&AT;6P@/2`G/'1A8FQE('=I9'1H/2(Q,#`E(B!C
M;&%S<STB:71E;2(@8V5L;'-P86-I;F<](C$B/CQT<B!C;&%S<STB<V5L96-T
M960B/B<@+@H@("`@("`@("`@("`G/'1H(&-L87-S/2)W:61G970B(&%L:6=N
M/2)R:6=H="(@=VED=&@](C$E(CXF;F)S<#L\+W1H/B<["B`@("`@("`@9F]R
M96%C:"`H)&AE861E<B!A<R`D8V]L7W1I=&QE*2!["B`@("`@("`@("`@("1H
M=&UL("X]('-P<FEN=&8H)SQT:"!A;&EG;CTB;&5F="(@8VQA<W,](G=I9&=E
M="(^)7,\+W1H/B<L("1C;VQ?=&ET;&4I.PH@("`@("`@('T*("`@("`@("`D
M:'1M;"`N/2`G/"]T<CXG.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C:&5C
M:V5D5F%L=65S*2D@>PH@("`@("`@("`@("`D8VAE8VME9%9A;'5E<R`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1I(#T@,#L*("`@("`@("!F;W)E
M86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D9&ES<&QA>7,I('L*("`@("`@
M("`@("`@)&-L87-S(#T@)VET96TG("X@*"1I("L@,2D@)2`R.PH@("`@("`@
M("`@("`D8VAE8VME9"`]("AI;E]A<G)A>2@D=F%L=64L("1C:&5C:V5D5F%L
M=65S*2D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G.PH@("`@("`@("`@
M("`D:'1M;"`N/2!S<')I;G1F*"<\='(@8VQA<W,](B5S(CXG+"`D8VQA<W,I
M("X*("`@("`@("`@("`@("`@('-P<FEN=&8H)SQT9"!A;&EG;CTB8V5N=&5R
M(CX\:6YP=70@:60](B5S)7,B('1Y<&4](F-H96-K8F]X(B!N86UE/2(E<UM=
M(B!V86QU93TB)7,B)7,E<R`O/CPO=&0^)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("1I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`D;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E+`H@("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VME
M9"P*("`@("`@("`@("`@("`@("`@("`@("`@)&%C=&EO;G,I.PH@("`@("`@
M("`@("!F;W)E86-H("@D9&ES<&QA>7,@87,@)&-O;"D@>PH@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/'1D(&%L:6=N/2)L969T(CXF;F)S
M<#LE<SPO=&0^)RP@)&-O;"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&AT;6P@+CT@)SPO='(^)SL*("`@("`@("`@("`@)&DK*SL*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:'1M;"`N("<\+W1A8FQE/B<["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I<W!L87E?=&%B;&5S970H)B1F;W)M
M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@("`@("`@("1H96%D97(@/2`D=F%R
M+3YT>7!E+3YG971(96%D97(H*3L*("`@("`@("`D;F%M92`@(#T@)'9A<BT^
M9V5T5F%R3F%M92@I.PH@("`@("`@("1V86QU97,@/2`D=F%R+3YG971686QU
M97,H*3L*("`@("`@("`D8VAE8VME9%9A;'5E<R`]("1V87(M/F=E=%9A;'5E
M*"1V87)S*3L*("`@("`@("`D86-T:6]N<R`]("1T:&ES+3Y?9V5T06-T:6]N
M4V-R:7!T<R@D9F]R;2P@)'9A<BD["@H@("`@("`@("1H=&UL(#T@)SQT86)L
M92!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C$B/CQT<B!C;&%S<STB<V5L
M96-T960B/B<@+@H@("`@("`@("`@("`G/'1H(&-L87-S/2)W:61G970B(&%L
M:6=N/2)R:6=H="(@=VED=&@](C$E(CXF;F)S<#L\+W1H/B<["B`@("`@("`@
M9F]R96%C:"`H)&AE861E<B!A<R`D8V]L7W1I=&QE*2!["B`@("`@("`@("`@
M("1H=&UL("X]('-P<FEN=&8H)SQT:"!A;&EG;CTB;&5F="(@8VQA<W,](G=I
M9&=E="(^)7,\+W1H/B<L("1C;VQ?=&ET;&4I.PH@("`@("`@('T*("`@("`@
M("`D:'1M;"`N/2`G/"]T<CXG.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C
M:&5C:V5D5F%L=65S*2D@>PH@("`@("`@("`@("`D8VAE8VME9%9A;'5E<R`]
M(&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1I(#T@,#L*("`@("`@("!F
M;W)E86-H("@D=F%L=65S(&%S("1V86QU92`]/B`D9&ES<&QA>7,I('L*("`@
M("`@("`@("`@)&-L87-S("`@/2`G:71E;2<@+B`H)&D@*R`Q*2`E(#(["B`@
M("`@("`@("`@("1C:&5C:V5D(#T@*&EN7V%R<F%Y*"1V86QU92P@)&-H96-K
M961686QU97,I*2`_("=;(#QS=')O;F<^/&9O;G0@8V]L;W(]9W)E96X^5CPO
M9F]N=#X\+W-T<F]N9SX@72<@.B`G6R`\<W1R;VYG/CQF;VYT(&-O;&]R/7)E
M9#Y8/"]F;VYT/CPO<W1R;VYG/B!=)SL*("`@("`@("`@("`@)&AT;6P@+CT@
M<W!R:6YT9B@G/'1R(&-L87-S/2(E<R(^)RP@)&-L87-S*2`N"B`@("`@("`@
M("`@("`@("!S<')I;G1F*"<\=&0@86QI9VX](F-E;G1E<B(^)7,\+W1D/B<L
M("1C:&5C:V5D*3L*("`@("`@("`@("`@9F]R96%C:"`H)&1I<W!L87ES(&%S
M("1C;VPI('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H)SQT
M9"!A;&EG;CTB;&5F="(^)FYB<W`[)7,\+W1D/B<L("1C;VPI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1H=&UL("X]("<\+W1R/B<["B`@("`@("`@
M("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&AT;6P@+B`G
M/"]T86)L93XG.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]I0V%L96YD87(O
M=FYO=&4N<&AP````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0V
M,B`Q,#4Q-30S-#$T,"`P,C,P-S$`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O
M:4-A;&5N9&%R+G!H<"<["@HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('9.
M;W1E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE
M;F1A<B]V;F]T92YP:'`L=B`Q+C,N,3`N-2`R,#`V+S`S+S`S(#`Y.C`W.C,Q
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT(#QF;W5R;6]N=$!G;7@N
M9&4^"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R
M9&5?:4-A;&5N9&%R7W9N;W1E(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*
M"B`@("!F=6YC=&EO;B!(;W)D95]I0V%L96YD87)?=FYO=&4H)'9E<G-I;VX@
M/2`G,2XQ)RD*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI(;W)D95]I
M0V%L96YD87(H)'9E<G-I;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=DYO=&4G.PH@("`@?0H*("`@
M(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@
M(')E='5R;B!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5DY/5$4G
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&EK92!V979E;G0@86YD('9T
M;V1O+"!A('9N;W1E(&ES(&YO<FUA;&QY(&YO="!E;F-L;W-E9"!I;B!A;@H@
M("`@("H@:4-A;&5N9&%R(&-O;G1A:6YE<BX@*$)%1TE.+BY%3D0I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@)')E<75I<F5D071T<FEB=71E<ULG0D]$62==(#T@)R<["B`@("`@("`@
M)')E<75I<F5D071T<FEB=71E<ULG5D524TE/3B==(#T@)S$N,2<["@H@("`@
M("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T97,@87,@)&YA;64@/3X@
M)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/F=E=&%T=')I8G5T92@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YA;64L("1D969A=6QT
M7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?97AP;W)T=D1A=&$H)U9.3U1%)RD["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V:F]U<FYA;"YP:'``````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#$Q(#$P-3$U-#,T,30P(#`R,S4V-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('9*;W5R;F%L<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V:F]U<FYA
M;"YP:'`L=B`Q+C@N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C0W(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?:4-A;&5N
M9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?=FIO=7)N86P@97AT96YD
M<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B`G=DIO=7)N86PG.PH@("`@?0H*("`@(&9U
M;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A=&$L("=62D]54DY!3"<I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@<F5T=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=62D]54DY!3"<I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V=&]D;RYP:'``````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-3(Q(#$P-3$U-#,T,30P(#`R
M,S`V-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('94;V1O<RX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO:4-A;&5N9&%R+VE#86QE;F1A<B]V=&]D
M;RYP:'`L=B`Q+C$S+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7VE#86QE
M;F1A<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9T;V1O(&5X=&5N9',@
M2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)W94;V1O)SL*("`@('T*"B`@("!F=6YC=&EO
M;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@('L*("`@("`@("!P87)E;G0Z
M.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5E1/1$\G*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@>PH@("`@("`@(')E='5R
M;B!P87)E;G0Z.E]E>'!O<G1V1&%T82@G5E1/1$\G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G0@=&AI<R!T;V1O('1O(&%N(&%R<F%Y(&]F(&%T
M=')I8G5T97,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@
M8V]N=&%I;FEN9R!T:&4@9&5T86EL<R!O9B!T:&4@=&]D;R!I;B!A(&AA<V@*
M("`@("`J("`@("`@("`@("`@("`@(&%S('5S960@8GD@2&]R9&4@87!P;&EC
M871I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;T%R<F%Y*"D*("`@('L*
M("`@("`@("`D=&]D;R`](&%R<F%Y*"D["@H@("`@("`@("1N86UE(#T@)'1H
M:7,M/F=E=$%T=')I8G5T92@G4U5-34%262<I.PH@("`@("`@(&EF("@A:7-?
M87)R87DH)&YA;64I("8F("%I<U]A*"1N86UE+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("1T;V1O6R=N86UE)UT@/2`D;F%M93L*("`@("`@("!]
M"B`@("`@("`@)&1E<V,@/2`D=&AI<RT^9V5T071T<FEB=71E*"=$15-#4DE0
M5$E/3B<I.PH@("`@("`@(&EF("@A:7-?87)R87DH)&1E<V,I("8F("%I<U]A
M*"1D97-C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T;V1O6R=D
M97-C)UT@/2`D9&5S8SL*("`@("`@("!]"@H@("`@("`@("1P<FEO<FET>2`]
M("1T:&ES+3YG971!='1R:6)U=&4H)U!224]22519)RD["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<')I;W)I='DI("8F("%I<U]A*"1P<FEO<FET>2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&]D;ULG<')I;W)I='DG72`]
M("1P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("1D=64@/2`D=&AI<RT^
M9V5T071T<FEB=71E*"=$5%-404U0)RD["B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9'5E*2`F)B`A:7-?82@D9'5E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1T;V1O6R=D=64G72`]("1D=64["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1O9&\["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE
M(&%T=')I8G5T97,@9F]R('1H:7,@=&]D;R!I=&5M(&9R;VT@86X@87)R87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1T;V1O("!!<G)A>2!C;VYT
M86EN:6YG('1H92!D971A:6QS(&]F('1H92!T;V1O(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@('1H92!S86UE(&9O<FUA="!T:&%T('1O07)R87DH
M*2!E>'!O<G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!F<F]M07)R87DH)'1O
M9&\I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T;V1O6R=N86UE)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)U-534U!4EDG+"`D
M=&]D;ULG;F%M92==*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T
M;V1O6R=D97-C)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971!='1R:6)U
M=&4H)T1%4T-225!424].)RP@)'1O9&];)V1E<V,G72D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)'1O9&];)W!R:6]R:71Y)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)U!224]22519)RP@)'1O9&];
M)W!R:6]R:71Y)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T
M;V1O6R=D=64G72DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T
M92@G1%135$%-4"<L("1T;V1O6R=D=64G72D["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V979E
M;G0N<&AP````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(P,C4T(#$P
M-3$U-#,T,30P(#`R,S(T-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG
M('9%=F5N=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I
M0V%L96YD87(O=F5V96YT+G!H<"QV(#$N,S$N,3`N."`R,#`V+S`Q+S`Q(#(Q
M.C(X.C0W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI
M:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?:4-A;&5N9&%R"B`J+PIC;&%S<R!(;W)D95]I0V%L96YD87)?
M=F5V96YT(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO
M;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W9%=F5N="<["B`@
M("!]"@H@("`@9G5N8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("![
M"B`@("`@("`@<&%R96YT.CIP87)S979#86QE;F1A<B@D9&%T82P@)U9%5D5.
M5"<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@
M("!["B`@("`@("`@+R\@1&5F875L="!V86QU97,N"B`@("`@("`@)')E<75I
M<F5D071T<FEB=71E<R`](&%R<F%Y*"D["B`@("`@("`@)')E<75I<F5D071T
M<FEB=71E<ULG1%135$%-4"==(#T@=&EM92@I.PH@("`@("`@("1R97%U:7)E
M9$%T=')I8G5T97-;)T]21T%.25I%4B==(#T@)U5N:VYO=VX@3W)G86YI>F5R
M)SL*("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=5240G72`]("1T:&ES
M+3Y?97AP;W)T1&%T951I;64H=&EM92@I*2`N("=`)R`N("AI<W-E="@D7U-%
M4E9%4ELG4T525D527TY!344G72D@/R`D7U-%4E9%4ELG4T525D527TY!344G
M72`Z("=L;V-A;&AO<W0G*3L*"B`@("`@("`@)&UE=&AO9"`]("%E;7!T>2@D
M=&AI<RT^7V-O;G1A:6YE<BD@/PH@("`@("`@("`@("`D=&AI<RT^7V-O;G1A
M:6YE<BT^9V5T071T<FEB=71E*"=-151(3T0G*2`Z("=054),25-()SL*"B`@
M("`@("`@<W=I=&-H("@D;65T:&]D*2!["B`@("`@("`@8V%S92`G4%5"3$E3
M2"<Z"B`@("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T144U1!4E0G
M72`]('1I;64H*3L*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG
M4U5-34%262==(#T@)R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E("=215%515-4)SH*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E
M<ULG051414Y$144G72`]("<G.PH@("`@("`@("`@("`D<F5Q=6ER961!='1R
M:6)U=&5S6R=$5%-405)4)UT@/2!T:6UE*"D["B`@("`@("`@("`@("1R97%U
M:7)E9$%T=')I8G5T97-;)U-534U!4EDG72`]("<G.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G4D503%DG.@H@("`@("`@("`@("`D<F5Q
M=6ER961!='1R:6)U=&5S6R=!5%1%3D1%12==(#T@)R<["B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=!1$0G.@H@("`@("`@("`@("`D<F5Q
M=6ER961!='1R:6)U=&5S6R=$5%-405)4)UT@/2!T:6UE*"D["B`@("`@("`@
M("`@("1R97%U:7)E9$%T=')I8G5T97-;)U-%455%3D-%)UT@/2`Q.PH@("`@
M("`@("`@("`D<F5Q=6ER961!='1R:6)U=&5S6R=354U-05)9)UT@/2`G)SL*
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)T-!3D-%3"<Z"B`@
M("`@("`@("`@("1R97%U:7)E9$%T=')I8G5T97-;)T%45$5.1$5%)UT@/2`G
M)SL*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG4T51545.0T4G
M72`](#$["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=21492
M15-()SH*("`@("`@("`@("`@)')E<75I<F5D071T<FEB=71E<ULG051414Y$
M144G72`]("<G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@
M("`@(&9O<F5A8V@@*"1R97%U:7)E9$%T=')I8G5T97,@87,@)&YA;64@/3X@
M)&1E9F%U;'1?=F%L=64I('L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/F=E=$%T=')I8G5T92@D;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YS971!='1R:6)U=&4H)&YA;64L("1D969A=6QT
M7W9A;'5E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('!A<F5N=#HZ7V5X<&]R='9$871A*"=6159%3E0G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%5P9&%T92!T:&4@<W1A='5S(&]F(&%N(&%T=&5N9&5E
M(&]F(&%N(&5V96YT+@H@("`@("H*("`@("`J($!P87)A;2`D96UA:6P@("`@
M5&AE(&5M86EL(&%D9')E<W,@;V8@=&AE(&%T=&5N9&5E+@H@("`@("H@0'!A
M<F%M("1S=&%T=7,@("!4:&4@<&%R=&EC:7!A;G0@<W1A='5S('1O('-E="X*
M("`@("`J($!P87)A;2`D9G5L;&YA;64@5&AE(&9U;&P@;F%M92!O9B!T:&4@
M<&%R=&EC:7!A;G0@=&\@<V5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A
M=&5!='1E;F1E92@D96UA:6PL("1S=&%T=7,L("1F=6QL;F%M92`]("<G*0H@
M("`@>PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D
M:V5Y(#T^("1A='1R:6)U=&4I('L*("`@("`@("`@("`@:68@*"1A='1R:6)U
M=&5;)VYA;64G72`]/2`G051414Y$144G("8F("1A='1R:6)U=&5;)W9A;'5E
M)UT@/3T@)TU!24Q43SHG("X@)&5M86EL*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V%T=')I8G5T97-;)&ME>5U;)W!A<F%M<R==6R=005)44U1!5"==
M(#T@)'-T871U<SL*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&9U;&QN
M86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E
M<ULD:V5Y75LG<&%R86US)UU;)T-.)UT@/2`D9G5L;&YA;64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V%T=')I
M8G5T97-;)&ME>5U;)W!A<F%M<R==6R=24U90)UTI.PH@("`@("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@G4$%25%-4050G(#T^("1S=&%T=7,I.PH@("`@("`@
M(&EF("@A96UP='DH)&9U;&QN86UE*2D@>PH@("`@("`@("`@("`D<&%R86US
M6R=#3B==(#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M<V5T071T<FEB=71E*"=!5%1%3D1%12<L("=-04E,5$\Z)R`N("1E;6%I;"P@
M)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&]R
M9V%N:7IE<B!D:7-P;&%Y(&YA;64@;W(@96UA:6PN"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!O<F=A;FEZ97(@;F%M92!T;R!D:7-P;&%Y
M(&9O<B!T:&ES(&5V96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<F=A;FEZ
M97).86UE*"D*("`@('L*("`@("`@("`D;W)G86YI>F5R(#T@)'1H:7,M/F=E
M=$%T=')I8G5T92@G3U)'04Y)6D52)RP@=')U92D["B`@("`@("`@:68@*&ES
M7V$H)&]R9V%N:7IE<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W)G
M86YI>F5R6S!=6R=#3B==*2D@>PH@("`@("`@("`@("!R971U<FX@)&]R9V%N
M:7IE<ELP75LG0TXG73L*("`@("`@("!]"@H@("`@("`@("1O<F=A;FEZ97(@
M/2!P87)S95]U<FPH)'1H:7,M/F=E=$%T=')I8G5T92@G3U)'04Y)6D52)RDI
M.PH*("`@("`@("!R971U<FX@)&]R9V%N:7IE<ELG<&%T:"==.PH@("`@?0H*
M("`@("\J*@H@("`@("H@57!D871E('1H:7,@979E;G0@=VET:"!D971A:6QS
M(&9R;VT@86YO=&AE<B!E=F5N="X*("`@("`J"B`@("`@*B!`<&%R86T@2&]R
M9&5?:4-A;&5N9&%R7W9%=F5N="`D=F5V96YT("!4:&4@=D5V96YT('=I=&@@
M;&%T97-T(&1E=&%I;',N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T949R
M;VUV179E;G0H)'9E=F5N="D*("`@('L*("`@("`@("`D;F5W071T<FEB=71E
M<R`]("1V979E;G0M/F=E=$%L;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E
M86-H("@D;F5W071T<FEB=71E<R!A<R`D;F5W071T<FEB=71E*2!["B`@("`@
M("`@("`@("1C=7)R96YT5F%L=64@/2`D=&AI<RT^9V5T071T<FEB=71E*"1N
M97=!='1R:6)U=&5;)VYA;64G72D["B`@("`@("`@("`@(&EF("AI<U]A*"1C
M=7)R96YT5F%L=64L("=014%27V5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("\O($%L<F5A9'D@97AI<W1S('-O(&IU<W0@861D(&ET+@H@("`@("`@("`@
M("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@D;F5W071T<FEB=71E6R=N86UE
M)UTL("1N97=!='1R:6)U=&5;)W9A;'5E)UTL("1N97=!='1R:6)U=&5;)W!A
M<F%M<R==*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\O($%L<F5A9'D@97AI<W1S('-O(&QO8V%T92!A;F0@;6]D:69Y+@H@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4["@H@("`@("`@("`@("`@("`@
M+R\@5')Y(&UA=&-H:6YG('1H92!A='1R:6)T92!N86UE(&%N9"!V86QU92!I
M;F-A<V4*("`@("`@("`@("`@("`@("\O(&]N;'D@=&AE('!A<F%M<R!C:&%N
M9V5D("AE9R!A='1E;F1E92!U<&1A=&EN9PH@("`@("`@("`@("`@("`@+R\@
M<W1A='5S*2X*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?871T
M<FEB=71E<R!A<R`D:60@/3X@)&%T='(I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&%T=');)VYA;64G72`]/2`D;F5W071T<FEB=71E6R=N86UE)UT@
M)B8*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=');)W9A;'5E)UT@/3T@
M)&YE=T%T=')I8G5T95LG=F%L=64G72D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!M97)G92!T:&4@<&%R86US"B`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1N97=!='1R:6)U=&5;)W!A<F%M<R==(&%S("1P87)A
M;5]I9"`]/B`D<&%R86U?;F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1I9%U;)W!A<F%M<R==6R1P87)A
M;5]I9%T@/2`D<&%R86U?;F%M93L*("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(21F
M;W5N9"D@>PH@("`@("`@("`@("`@("`@("`@("\O($5L<V4@;6%T8V@@=&AE
M(&9I<G-T(&%T=')I8G5T92!W:71H('1H92!S86UE"B`@("`@("`@("`@("`@
M("`@("`@+R\@;F%M92`H96<@8VAA;F=I;F<@<W1A<G0@=&EM92DN"B`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S
M("1I9"`]/B`D871T<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M)&%T=');)VYA;64G72`]/2`D;F5W071T<FEB=71E6R=N86UE)UTI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E<ULD
M:61=6R=V86QU92==(#T@)&YE=T%T=')I8G5T95LG=F%L=64G73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O($UE<F=E('1H92!P87)A;7,N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D;F5W071T<FEB
M=71E6R=P87)A;7,G72!A<R`D<&%R86U?:60@/3X@)'!A<F%M7VYA;64I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%T=')I
M8G5T97-;)&ED75LG<&%R86US)UU;)'!A<F%M7VED72`]("1P87)A;5]N86UE
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5
M<&1A=&4@:G5S="!T:&4@871T96YD97-S(&]F(&5V96YT('=I=&@@9&5T86EL
M<R!F<F]M(&%N;W1H97(*("`@("`J(&5V96YT+@H@("`@("H*("`@("`J($!P
M87)A;2!(;W)D95]I0V%L96YD87)?=D5V96YT("1V979E;G0@(%1H92!V179E
M;G0@=VET:"!L871E<W0@9&5T86EL<PH@("`@("HO"B`@("!F=6YC=&EO;B!U
M<&1A=&5!='1E;F1E97-&<F]M=D5V96YT*"1V979E;G0I"B`@("!["B`@("`@
M("`@)&YE=T%T=')I8G5T97,@/2`D=F5V96YT+3YG971!;&Q!='1R:6)U=&5S
M*"D["B`@("`@("`@9F]R96%C:"`H)&YE=T%T=')I8G5T97,@87,@)&YE=T%T
M=')I8G5T92D@>PH@("`@("`@("`@("!I9B`H)&YE=T%T=')I8G5T95LG;F%M
M92==("$]("=!5%1%3D1%12<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C=7)R96YT5F%L=64@/2`D
M=&AI<RT^9V5T071T<FEB=71E*"1N97=!='1R:6)U=&5;)VYA;64G72D["B`@
M("`@("`@("`@(&EF("AI<U]A*"1C=7)R96YT5F%L=64L("=014%27V5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@("\O($%L<F5A9'D@97AI<W1S('-O(&IU
M<W0@861D(&ET+@H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T
M92@D;F5W071T<FEB=71E6R=N86UE)UTL("1N97=!='1R:6)U=&5;)W9A;'5E
M)UTL("1N97=!='1R:6)U=&5;)W!A<F%M<R==*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("\O($%L<F5A9'D@97AI<W1S('-O(&QO
M8V%T92!A;F0@;6]D:69Y+@H@("`@("`@("`@("`@("`@)&9O=6YD(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("`O+R!4<GD@;6%T8VAI;F<@=&AE(&%T=')I
M8G1E(&YA;64@86YD('9A;'5E(&EN8V%S90H@("`@("`@("`@("`@("`@+R\@
M;VYL>2!T:&4@<&%R86US(&-H86YG960@*&5G(&%T=&5N9&5E('5P9&%T:6YG
M"B`@("`@("`@("`@("`@("`O+R!S=&%T=7,I+@H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]A='1R:6)U=&5S(&%S("1I9"`]/B`D871T<BD@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D871T<ELG;F%M92==(#T]("1N
M97=!='1R:6)U=&5;)VYA;64G72`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`D871T<ELG=F%L=64G72`]/2`D;F5W071T<FEB=71E6R=V86QU92==*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O($UE<F=E('1H92!P87)A;7,N
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1N97=!='1R:6)U
M=&5;)W!A<F%M<R==(&%S("1P87)A;5]I9"`]/B`D<&%R86U?;F%M92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S
M6R1I9%U;)W!A<F%M<R==6R1P87)A;5]I9%T@/2`D<&%R86U?;F%M93L*("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]U;F0@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@
M("`@("`O+R!%;'-E(&UA=&-H('1H92!F:7)S="!A='1R:6)U=&4@=VET:"!T
M:&4@<V%M90H@("`@("`@("`@("`@("`@("`@("\O(&YA;64@*&5G(&-H86YG
M:6YG('-T87)T('1I;64I+@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?871T<FEB=71E<R!A<R`D:60@/3X@)&%T='(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1A='1R6R=N86UE)UT@/3T@)&YE=T%T
M=')I8G5T95LG;F%M92==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%T=')I8G5T97-;)&ED75LG=F%L=64G72`]("1N97=!='1R
M:6)U=&5;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!-97)G92!T:&4@<&%R86US+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&YE=T%T=')I8G5T95LG<&%R86US)UT@87,@)'!A<F%M
M7VED(#T^("1P87)A;5]N86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A='1R:6)U=&5S6R1I9%U;)W!A<F%M<R==6R1P
M87)A;5]I9%T@/2`D<&%R86U?;F%M93L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+VE#86QE;F1A<B]V=&EM97IO;F4N<&AP
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-S$W(#$P-3$U-#,T,30P
M(#`R,S<V,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@0VQA<W,@<F5P<F5S96YT:6YG('94:6UE>F]N
M97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD
M87(O=G1I;65Z;VYE+G!H<"QV(#$N."XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z
M-#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]I0V%L96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V=&EM
M97IO;F4@97AT96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@(&9U;F-T:6]N
M(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=E1I;65:;VYE)SL*
M("`@('T*"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@
M('L*("`@("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G5E1)
M345:3TY%)RD["B`@("!]"@H@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R
M*"D*("`@('L*("`@("`@("!R971U<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H
M)U9424U%6D].12<I.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E($AO<F1E
M7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W-T86YD87)D
M(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!G9714
M>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W-T86YD87)D)SL*("`@('T*
M"B`@("!F=6YC=&EO;B!P87)S979#86QE;F1A<B@D9&%T82D*("`@('L*("`@
M("`@("!P87)E;G0Z.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G4U1!3D1!4D0G
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L96YD87(H*0H@("`@
M>PH@("`@("`@(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V1&%T82@G4U1!3D1!
M4D0G*3L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!(;W)D95]I0V%L96YD
M87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]D87EL:6=H="!E>'1E;F1S
M($AO<F1E7VE#86QE;F1A<B!["@H@("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=D87EL:6=H="<["B`@("!]"@H@("`@9G5N
M8W1I;VX@<&%R<V5V0V%L96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R
M96YT.CIP87)S979#86QE;F1A<B@D9&%T82P@)T1!64Q)1TA4)RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@97AP;W)T=D-A;&5N9&%R*"D*("`@('L*("`@("`@
M("!R971U<FX@<&%R96YT.CI?97AP;W)T=D1A=&$H)T1!64Q)1TA4)RD["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M:4-A;&5N9&%R+W9F<F5E8G5S>2YP:'``````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,C,V-#$@,3`U,34T,S0Q-#`@,#(S-S4R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S
M<R!R97!R97-E;G1I;F<@=D9R965B=7-Y(&-O;7!O;F5N=',N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=F9R965B=7-Y
M+G!H<"QV(#$N,38N,3`N.2`R,#`V+S`R+S`V(#$W.C4S.C,Y(&UR=6)I;G-K
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]I
M0V%L96YD87(*("HO"F-L87-S($AO<F1E7VE#86QE;F1A<E]V9G)E96)U<WD@
M97AT96YD<R!(;W)D95]I0V%L96YD87(@>PH*("`@('9A<B`D7V)U<WE097)I
M;V1S(#T@87)R87DH*3L*"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*
M("`@("`@("!R971U<FX@)W9&<F5E8G5S>2<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!087)S97,@82!S=')I;F<@8V]N=&%I;FEN9R!V1G)E96)U<WD@9&%T
M82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("!4:&4@
M9&%T82!T;R!P87)S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5V0V%L
M96YD87(H)&1A=&$I"B`@("!["B`@("`@("`@<&%R96YT.CIP87)S979#86QE
M;F1A<B@D9&%T82P@)U9&4D5%0E5362<I.PH*("`@("`@("`O+R!$;R!S;VUE
M=&AI;F<@=VET:"!A;&P@=&AE(&)U<WD@<&5R:6]D<RX*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V%T=')I8G5T97,@87,@)&ME>2`]/B`D871T<FEB=71E
M*2!["B`@("`@("`@("`@(&EF("@D871T<FEB=71E6R=N86UE)UT@/3T@)T92
M145"55-9)RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T
M95LG=F%L=65S)UT@87,@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1V86QU95LG9'5R871I;VXG72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^861D0G5S>5!E<FEO9"@G0E5362<L("1V86QU
M95LG<W1A<G0G72P@;G5L;"P@)'9A;'5E6R=D=7)A=&EO;B==*3L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YA9&1"=7-Y4&5R:6]D*"="55-9)RP@)'9A;'5E6R=S=&%R="==
M+"`D=F%L=65;)V5N9"==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V%T
M=')I8G5T97-;)&ME>5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]B=7-Y4&5R:6]D<R!A<R`D<W1A<G0@/3X@
M)&5N9"D@>PH@("`@("`@("`@("`D<&5R:6]D<R`](&%R<F%Y*&%R<F%Y*"=S
M=&%R="<@/3X@)'-T87)T+"`G96YD)R`]/B`D96YD*2D["B`@("`@("`@("`@
M("1T:&ES+3YS971!='1R:6)U=&4H)T92145"55-9)RP@)'!E<FEO9',I.PH@
M("`@("`@('T*"B`@("`@("`@)')E<R`]('!A<F5N=#HZ7V5X<&]R='9$871A
M*"=61E)%14)54UDG*3L*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]A='1R
M:6)U=&5S(&%S("1K97D@/3X@)&%T=')I8G5T92D@>PH@("`@("`@("`@("!I
M9B`H)&%T=')I8G5T95LG;F%M92==(#T]("=&4D5%0E5362<I('L*("`@("`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?871T<FEB=71E<ULD:V5Y72D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&1I<W!L87D@;F%M92!F
M;W(@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($$@8VQE87(@=&5X="!N86UE(&9O<B!D:7-P;&%Y:6YG('1H:7,@;V)J96-T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D*("`@('L*("`@("`@
M("`D;F%M92`]("<G.PH@("`@("`@("1M971H;V0@/2`A96UP='DH)'1H:7,M
M/E]C;VYT86EN97(I(#\*("`@("`@("`@("`@)'1H:7,M/E]C;VYT86EN97(M
M/F=E=$%T=')I8G5T92@G34542$]$)RD@.B`G4%5"3$E32"<["@H@("`@("`@
M(&EF("AI<U]A*"1M971H;V0L("=014%27T5R<F]R)RD@?'P@)&UE=&AO9"`]
M/2`G4%5"3$E32"<I('L*("`@("`@("`@("`@)&%T='(@/2`G3U)'04Y)6D52
M)SL*("`@("`@("!](&5L<V5I9B`H)&UE=&AO9"`]/2`G4D503%DG*2!["B`@
M("`@("`@("`@("1A='1R(#T@)T%45$5.1$5%)SL*("`@("`@("!]"@H@("`@
M("`@("1N86UE(#T@)'1H:7,M/F=E=$%T=')I8G5T92@D871T<BP@=')U92D[
M"B`@("`@("`@:68@*&ES<V5T*"1N86UE6S!=6R=#3B==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&YA;65;,%U;)T-.)UT["B`@("`@("`@?0H*("`@("`@
M("`D;F%M92`]("1T:&ES+3YG971!='1R:6)U=&4H)&%T='(I.PH@("`@("`@
M(&EF("AI<U]A*"1N86UE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`G)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M
M92`]('!A<G-E7W5R;"@D;F%M92D["B`@("`@("`@("`@(')E='5R;B`D;F%M
M95LG<&%T:"==.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&5M86EL(&%D9')E<W,@9F]R('1H:7,@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96UA:6P@861D<F5S<R!O
M9B!T:&ES(&]B:F5C="=S(&]W;F5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971%;6%I;"@I"B`@("!["B`@("`@("`@)&YA;64@/2`G)SL*("`@("`@("`D
M;65T:&]D(#T@(65M<'1Y*"1T:&ES+3Y?8V]N=&%I;F5R*0H@("`@("`@("`@
M("`@("`@("`_("1T:&ES+3Y?8V]N=&%I;F5R+3YG971!='1R:6)U=&4H)TU%
M5$A/1"<I(#H@)U!50DQ)4T@G.PH*("`@("`@("!I9B`H:7-?82@D;65T:&]D
M+"`G4$5!4E]%<G)O<B<I('Q\("1M971H;V0@/3T@)U!50DQ)4T@G*2!["B`@
M("`@("`@("`@("1A='1R(#T@)T]21T%.25I%4B<["B`@("`@("`@?2!E;'-E
M:68@*"1M971H;V0@/3T@)U)%4$Q9)RD@>PH@("`@("`@("`@("`D871T<B`]
M("=!5%1%3D1%12<["B`@("`@("`@?0H*("`@("`@("`D;F%M92`]("1T:&ES
M+3YG971!='1R:6)U=&4H)&%T='(I.PH@("`@("`@(&EF("AI<U]A*"1N86UE
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;F%M92`]('!A<G-E7W5R;"@D
M;F%M92D["B`@("`@("`@("`@(')E='5R;B`D;F%M95LG<&%T:"==.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971"=7-Y4&5R:6]D<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8G5S>5!E<FEO9',["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L;"!T:&4@9G)E92!P97)I;V1S
M(&]F('1I;64@:6X@82!G:79E;B!P97)I;V0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'-T87)T4W1A;7`@(%1H92!S=&%R="!T:6UE<W1A;7`N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96YD4W1A;7`@("`@5&AE(&5N9"!T
M:6UE<W1A;7`N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H
M('=I=&@@9G)E92!T:6UE('!E<FEO9',L('1H92!S=&%R="!T:6UE<R!A<R!T
M:&4*("`@("`J("`@("`@("`@("`@("`@(&ME>7,@86YD('1H92!E;F0@=&EM
M97,@87,@=&AE('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1G)E
M95!E<FEO9',H)'-T87)T4W1A;7`L("1E;F13=&%M<"D*("`@('L*("`@("`@
M("`D=&AI<RT^<VEM<&QI9GDH*3L*("`@("`@("`D<&5R:6]D<R`](&%R<F%Y
M*"D["@H@("`@("`@("\O($-H96-K('1H870@=V4@:&%V92!D871A(&9O<B!S
M;VUE('!A<G0@;V8@=&AI<R!P97)I;V0N"B`@("`@("`@:68@*"1T:&ES+3YG
M971%;F0H*2`\("1S=&%R=%-T86UP('Q\("1T:&ES+3YG9713=&%R="@I(#X@
M)&5N9%-T86UP*2!["B`@("`@("`@("`@(')E='5R;B`D<&5R:6]D<SL*("`@
M("`@("!]"@H@("`@("`@("\O($QO8V%T92!T:&4@9FER<W0@=&EM92!I;B!T
M:&4@<F5Q=65S=&5D('!E<FEO9"!W92!H879E(&1A=&$@9F]R+@H@("`@("`@
M("1N97AT<W1A<G0@/2!M87@H)'-T87)T4W1A;7`L("1T:&ES+3YG9713=&%R
M="@I*3L*"B`@("`@("`@+R\@0VAE8VL@96%C:"!B=7-Y('!E<FEO9"!A;F0@
M861D(&9R964@<&5R:6]D<R!I;B!B971W965N+@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?8G5S>5!E<FEO9',@87,@)'-T87)T(#T^("1E;F0I('L*("`@
M("`@("`@("`@:68@*"1S=&%R="`\/2`D96YD4W1A;7`@)B8@)&5N9"`^/2`D
M;F5X='-T87)T*2!["B`@("`@("`@("`@("`@("!I9B`H)&YE>'1S=&%R="`\
M/2`D<W1A<G0I('L*("`@("`@("`@("`@("`@("`@("`D<&5R:6]D<ULD;F5X
M='-T87)T72`](&UI;B@D<W1A<G0L("1E;F13=&%M<"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D;F5X='-T87)T(#T@;6EN*"1E;F0L
M("1E;F13=&%M<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\O($EF('=E(&1I9&XG="!R96%D('1H92!E;F0@;V8@=&AE(')E<75E<W1E
M9"!P97)I;V0@8G5T('-T:6QL(&AA=F4*("`@("`@("`O+R!D871A('1H96X@
M;6%R:R!A<R!F<F5E('1O('1H92!E;F0@;V8@=&AE('!E<FEO9"!O<B!A=F%I
M;&%B;&4@9&%T82X*("`@("`@("!I9B`H)&YE>'1S=&%R="`\("1E;F13=&%M
M<"`F)B`D;F5X='-T87)T(#P@)'1H:7,M/F=E=$5N9"@I*2!["B`@("`@("`@
M("`@("1P97)I;V1S6R1N97AT<W1A<G1=(#T@;6EN*"1T:&ES+3YG971%;F0H
M*2P@)&5N9%-T86UP*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&5R
M:6]D<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@82!B=7-Y('!E<FEO
M9"!T;R!T:&4@:6YF;RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("`@("`@(%1H92!T>7!E(&]F('1H92!P97)I;V0N($5I=&AE<B`G1E)%
M12<@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@)T)54UDG
M.R!O;FQY("="55-9)R!S=7!P;W)T960@870@=&AE(&UO;65N="X*("`@("`J
M($!P87)A;2!I;G1E9V5R("1S=&%R="`@("`@5&AE('-T87)T('1I;65S=&%M
M<"!O9B!T:&4@<&5R:6]D+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@
M("`@("!4:&4@96YD('1I;65S=&%M<"!O9B!T:&4@<&5R:6]D+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&1U<F%T:6]N("!4:&4@9'5R871I;VX@;V8@=&AE
M('!E<FEO9"X@268@<W!E8VEF:65D+"!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&5N9"!P87)A;65T97(@=VEL;"!B92!I9VYO<F5D
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1"=7-Y4&5R:6]D*"1T>7!E+"`D
M<W1A<G0L("1E;F0@/2!N=6QL+"`D9'5R871I;VX@/2!N=6QL*0H@("`@>PH@
M("`@("`@(&EF("@D='EP92`]/2`G1E)%12<I('L*("`@("`@("`@("`@+R\@
M36%K92!S=7)E('1H:7,@<&5R:6]D(&ES(&YO="!M87)K960@87,@8G5S>2X*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0V%L8W5L871E('1H92!E;F0@=&EM92!I9B!D=7)A=&EO;B!W87,@<W!E
M8VEF:65D+@H@("`@("`@("1T96UP16YD(#T@:7-?;G5L;"@D9'5R871I;VXI
M(#\@)&5N9"`Z("1S=&%R="`K("1D=7)A=&EO;CL*"B`@("`@("`@+R\@36%K
M92!S=7)E('1H92!P97)I;V0@;&5N9W1H(&ES(&%L=V%Y<R!P;W-I=&EV92X*
M("`@("`@("`D96YD(#T@;6%X*"1S=&%R="P@)'1E;7!%;F0I.PH@("`@("`@
M("1S=&%R="`](&UI;B@D<W1A<G0L("1T96UP16YD*3L*"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?8G5S>5!E<FEO9'-;)'-T87)T72DI('L*("`@("`@
M("`@("`@+R\@06QR96%D>2!A('!E<FEO9"!S=&%R=&EN9R!A="!T:&ES('1I
M;64N($5X=&5N9"!T;R!T:&4@;&5N9W1H(&]F"B`@("`@("`@("`@("\O('1H
M92!L;VYG97-T(&]F('1H92!T=V\N"B`@("`@("`@("`@("1T:&ES+3Y?8G5S
M>5!E<FEO9'-;)'-T87)T72`](&UA>"@D96YD+"`D=&AI<RT^7V)U<WE097)I
M;V1S6R1S=&%R=%TI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M($%D9"!A(&YE=R!B=7-Y('!E<FEO9"X*("`@("`@("`@("`@)'1H:7,M/E]B
M=7-Y4&5R:6]D<ULD<W1A<G1=(#T@)&5N9#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@=&EM97-T86UP(&]F('1H92!S=&%R="!O9B!T:&4@=&EM92!P97)I;V0@
M=&AI<R!F<F5E(&)U<WD*("`@("`J(&EN9F]R;6%T:6]N(&-O=F5R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@($$@=&EM97-T86UP+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9713=&%R="@I"B`@("!["B`@("`@("`@:68@
M*"%I<U]A*"1T:&ES+3YG971!='1R:6)U=&4H)T144U1!4E0G*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$%T=')I
M8G5T92@G1%135$%25"<I.PH@("`@("`@('T@96QS96EF("AC;W5N="@D=&AI
M<RT^7V)U<WE097)I;V1S*2D@>PH@("`@("`@("`@("!R971U<FX@;6EN*&%R
M<F%Y7VME>7,H)'1H:7,M/E]B=7-Y4&5R:6]D<RDI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!T:6UE<W1A;7`@;V8@=&AE
M(&5N9"!O9B!T:&4@=&EM92!P97)I;V0@=&AI<R!F<F5E(&)U<WD*("`@("`J
M(&EN9F]R;6%T:6]N(&-O=F5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@($$@=&EM97-T86UP+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%
M;F0H*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D=&AI<RT^9V5T071T<FEB
M=71E*"=$5$5.1"<I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T071T<FEB=71E*"=$5$5.1"<I.PH@("`@("`@('T@
M96QS96EF("AC;W5N="@D=&AI<RT^7V)U<WE097)I;V1S*2D@>PH@("`@("`@
M("`@("!R971U<FX@;6%X*&%R<F%Y7W9A;'5E<R@D=&AI<RT^7V)U<WE097)I
M;V1S*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UE<F=E<R!T
M:&4@8G5S>2!P97)I;V1S(&]F(&%N;W1H97(@2&]R9&5?:4-A;&5N9&%R7W9F
M<F5E8G5S>2!O8FIE8W0@:6YT;PH@("`@("H@=&AI<R!O;F4N"B`@("`@*@H@
M("`@("H@0'!A<F%M($AO<F1E7VE#86QE;F1A<E]V9G)E96)U<WD@)&9R965B
M=7-Y("!!(&9R965B=7-Y(&]B:F5C="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1S:6UP;&EF>2`@("`@("`@("`@("`@("`@("`@268@=')U92P@<VEM<&QI
M9GDH*2!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A;&QE9"!A9G1E<B!T:&4@;65R9V4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&UE<F=E*"1F<F5E8G5S>2P@)'-I;7!L:69Y(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&9R965B=7-Y+"`G2&]R
M9&5?:4-A;&5N9&%R7W9F<F5E8G5S>2<I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1F<F5E8G5S
M>2T^9V5T0G5S>5!E<FEO9',H*2!A<R`D<W1A<G0@/3X@)&5N9"D@>PH@("`@
M("`@("`@("`D=&AI<RT^861D0G5S>5!E<FEO9"@G0E5362<L("1S=&%R="P@
M)&5N9"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<V%T='(@/2`D=&AI<RT^
M9V5T071T<FEB=71E*"=$5%-405)4)RD["B`@("`@("`@)'1H871A='1R(#T@
M)&9R965B=7-Y+3YG971!='1R:6)U=&4H)T144U1!4E0G*3L*("`@("`@("!I
M9B`H:7-?82@D=&AI<V%T='(L("=014%27T5R<F]R)RD@)B8@(6ES7V$H)'1H
M871A='1R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971!='1R:6)U=&4H)T144U1!4E0G+"`D=&AA=&%T='(I.PH@("`@("`@('T@
M96QS96EF("@A:7-?82@D=&AA=&%T='(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@:68@*"1T:&%T871T<B`^("1T:&ES871T<BD@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$%T=')I8G5T92@G1%135$%25"<L("1T:&%T
M871T<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES
M871T<B`]("1T:&ES+3YG971!='1R:6)U=&4H)T1414Y$)RD["B`@("`@("`@
M)'1H871A='1R(#T@)&9R965B=7-Y+3YG971!='1R:6)U=&4H)T1414Y$)RD[
M"B`@("`@("`@:68@*&ES7V$H)'1H:7-A='1R+"`G4$5!4E]%<G)O<B<I("8F
M("%I<U]A*"1T:&%T871T<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5T071T<FEB=71E*"=$5$5.1"<L("1T:&%T871T<BD["B`@
M("`@("`@?2!E;'-E:68@*"%I<U]A*"1T:&%T871T<BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!I9B`H)'1H871A='1R(#P@)'1H:7-A='1R*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T071T<FEB=71E*"=$5$5.1"<L
M("1T:&%T871T<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@D<VEM<&QI9GDI('L*("`@("`@("`@("`@)'1H:7,M/G-I;7!L:69Y
M*"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E;6]V97,@86QL(&]V97)L87!S(&%N9"!S:6UP;&EF
M:65S('1H92!B=7-Y('!E<FEO9',@87)R87D@87,@;75C:"!A<PH@("`@("H@
M<&]S<VEB;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L:69Y*"D*("`@
M('L*("`@("`@("`D8VAE8VME9"`](&%R<F%Y*"D["B`@("`@("`@)&-H96-K
M961%;7!T>2`]('1R=64["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8G5S
M>5!E<FEO9',@87,@)'-T87)T(#T^("1E;F0I('L*("`@("`@("`@("`@:68@
M*"1C:&5C:V5D16UP='DI('L*("`@("`@("`@("`@("`@("1C:&5C:V5D6R1S
M=&%R=%T@/2`D96YD.PH@("`@("`@("`@("`@("`@)&-H96-K961%;7!T>2`]
M(&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&%D9&5D(#T@9F%L<V4["B`@("`@("`@("`@("`@("!F;W)E86-H("@D8VAE
M8VME9"!A<R`D=&5S=%-T87)T(#T^("1T97-T16YD*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1S=&%R="`]/2`D=&5S=%-T87)T*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C:&5C:V5D6R1T97-T4W1A<G1=(#T@;6%X*"1T
M97-T16YD+"`D96YD*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&%D9&5D
M(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&5N9"`\
M/2`D=&5S=$5N9"`F)B`D96YD(#X]("1T97-T4W1A<G0I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)&-H96-K961;)'1E<W13=&%R=%TI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VME9%MM:6XH)'1E<W13=&%R
M="P@)'-T87)T*5T@/2!M87@H)'1E<W1%;F0L("1E;F0I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D861D960@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&%D9&5D*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A)&%D
M9&5D*2!["B`@("`@("`@("`@("`@("`@("`@)&-H96-K961;)'-T87)T72`]
M("1E;F0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&MS;W)T*"1C:&5C:V5D+"!33U)47TY5345224,I.PH@
M("`@("`@("1T:&ES+3Y?8G5S>5!E<FEO9',@/2`D8VAE8VME9#L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O:4-A
M;&5N9&%R+W9A;&%R;2YP:'``````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$S-S4@,3`U,34T,S0Q-#`@,#(S,C(R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!#;&%S<R!R
M97!R97-E;G1I;F<@=D%L87)M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M:4-A;&5N9&%R+VE#86QE;F1A<B]V86QA<FTN<&AP+'8@,2XX+C$P+C0@,C`P
M-B\P,2\P,2`R,3HR.#HT-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#,M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?
M:4-A;&5N9&%R7W9A;&%R;2!E>'1E;F1S($AO<F1E7VE#86QE;F1A<B!["@H@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=V
M06QA<FTG.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E=D-A;&5N9&%R*"1D
M871A*0H@("`@>PH@("`@("`@('!A<F5N=#HZ<&%R<V5V0V%L96YD87(H)&1A
M=&$L("=604Q!4DTG*3L*("`@('T*"B`@("!F=6YC=&EO;B!E>'!O<G1V0V%L
M96YD87(H*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E;G0Z.E]E>'!O<G1V
M1&%T82@G5D%,05)-)RD["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O:4-A;&5N9&%R+W9C87)D+G!H<```````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#<R-#(@,3`U,34T,S0Q-#`@,#(S,#,V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*+R\@5&AE(&9O;&QO=VEN
M9R!W97)E('-H86UE;&5S<VQY('EO:6YK960@9G)O;2!#;VYT86-T7U9C87)D
M7T)U:6QD"B\O(%!A<G0@;G5M8F5R<R!F;W(@3B!C;VUP;VYE;G1S+@ID969I
M;F4H)U9#05)$7TY?1D%-24Q9)RP@("`@(#`I.PID969I;F4H)U9#05)$7TY?
M1TE614XG+"`@("`@(#$I.PID969I;F4H)U9#05)$7TY?041$3"<L("`@("`@
M(#(I.PID969I;F4H)U9#05)$7TY?4%)%1DE8)RP@("`@(#,I.PID969I;F4H
M)U9#05)$7TY?4U5&1DE8)RP@("`@(#0I.PH*+R\@4&%R="!N=6UB97)S(&9O
M<B!!1%(@8V]M<&]N96YT<RX*9&5F:6YE*"=60T%21%]!1%)?4$]")RP@("`@
M("`P*3L*9&5F:6YE*"=60T%21%]!1%)?15A414Y$)RP@("`Q*3L*9&5F:6YE
M*"=60T%21%]!1%)?4U121454)RP@("`R*3L*9&5F:6YE*"=60T%21%]!1%)?
M3$]#04Q)5%DG+"`S*3L*9&5F:6YE*"=60T%21%]!1%)?4D5'24].)RP@("`T
M*3L*9&5F:6YE*"=60T%21%]!1%)?4$]35$-/1$4G+"`U*3L*9&5F:6YE*"=6
M0T%21%]!1%)?0T]53E1262<L("`V*3L*"B\O(%!A<G0@;G5M8F5R<R!F;W(@
M1T5/(&-O;7!O;F5N=',N"F1E9FEN92@G5D-!4D1?1T5/7TQ!5"<L("`@("`@
M,"D["F1E9FEN92@G5D-!4D1?1T5/7TQ/3B<L("`@("`@,2D["@HO*BH*("H@
M0VQA<W,@<F5P<F5S96YT:6YG('9#87)D(&5N=')I97,N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+VE#86QE;F1A<B]I0V%L96YD87(O=F-A<F0N<&AP+'8@
M,2XS+C$P+C@@,C`P-B\P-2\P.2`R,SHP.#HR,B!C:'5C:R!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($MA<G-T96X@1F]U<FUO;G0@*&MA<G-T
M96Y`:&]R9&4N;W)G*0H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2V%R
M<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E
M($AO<F1E7VE#86QE;F1A<@H@*B\*8VQA<W,@2&]R9&5?:4-A;&5N9&%R7W9C
M87)D(&5X=&5N9',@2&]R9&5?:4-A;&5N9&%R('L*"B`@("!F=6YC=&EO;B!(
M;W)D95]I0V%L96YD87)?=F-A<F0H)'9E<G-I;VX@/2`G,BXQ)RD*("`@('L*
M("`@("`@("!R971U<FX@<&%R96YT.CI(;W)D95]I0V%L96YD87(H)'9E<G-I
M;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B`G=F-A<F0G.PH@("`@?0H*("`@(&9U;F-T:6]N('!A<G-E
M=D-A;&5N9&%R*"1D871A*0H@("`@>PH@("`@("`@(')E='5R;B!P87)E;G0Z
M.G!A<G-E=D-A;&5N9&%R*"1D871A+"`G=F-A<F0G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%5N;&EK92!V979E;G0@86YD('9T;V1O+"!A('9C87)D(&ES
M(&YO<FUA;&QY(&YO="!E;F-L;W-E9"!I;B!A;@H@("`@("H@:4-A;&5N9&%R
M(&-O;G1A:6YE<BX@*$)%1TE.+BY%3D0I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X<&]R='9#86QE;F1A<B@I"B`@("!["B`@("`@("`@)')E<75I<F5D071T
M<FEB=71E<ULG0D]$62==(#T@)R<["B`@("`@("`@)')E<75I<F5D071T<FEB
M=71E<ULG5D524TE/3B==(#T@)S(N,2<["@H@("`@("`@(&9O<F5A8V@@*"1R
M97%U:7)E9$%T=')I8G5T97,@87,@)&YA;64@/3X@)&1E9F%U;'1?=F%L=64I
M('L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M/F=E=$%T=')I8G5T92@D
M;F%M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS971!='1R:6)U=&4H)&YA;64L("1D969A=6QT7W9A;'5E*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?97AP
M;W)T=D1A=&$H)U9#05)$)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C;VYT96YT<R!O9B!T:&4@(DXB('1A9R!A<R!A('!R:6YT86)L
M92!.86UE.@H@("`@("H@:2YE+B!C;VYV97)T<SH*("`@("`J"B`@("`@*B`@
M($XZ1'5C:SM$86=O8F5R=#M4.U!R;V9E<W-O<CM396XN"B`@("`@*B!T;PH@
M("`@("H@("`B4')O9F5S<V]R($1A9V]B97)T(%0@1'5C:R!396XB"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@($9U;&P@;F%M92!O9B!V8V%R9"`B
M3B(@=&%G"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@;G5L;"!I9B!N;R!.
M('1A9RX*("`@("`J+PH@("`@9G5N8W1I;VX@<')I;G1A8FQE3F%M92@I"B`@
M("!["B`@("`@("`@)&YA;65?<&%R=',@/2`D=&AI<RT^9V5T071T<FEB=71E
M5F%L=65S*"=.)RD["B`@("`@("`@:68@*&ES7V$H)&YA;65?<&%R=',L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1N86UE7W!A<G1S6U9#05)$7TY?
M4%)%1DE872DI('L*("`@("`@("`@("`@)&YA;65?87)R6UT@/2`D;F%M95]P
M87)T<UM60T%21%].7U!2149)6%T["B`@("`@("`@?0H@("`@("`@(&EF("@A
M96UP='DH)&YA;65?<&%R='-;5D-!4D1?3E]'259%3ETI*2!["B`@("`@("`@
M("`@("1N86UE7V%R<EM=(#T@)&YA;65?<&%R='-;5D-!4D1?3E]'259%3ET[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&YA;65?<&%R='-;5D-!
M4D1?3E]!1$1,72DI('L*("`@("`@("`@("`@)&YA;65?87)R6UT@/2`D;F%M
M95]P87)T<UM60T%21%].7T%$1$Q=.PH@("`@("`@('T*("`@("`@("!I9B`H
M(65M<'1Y*"1N86UE7W!A<G1S6U9#05)$7TY?1D%-24Q972DI('L*("`@("`@
M("`@("`@)&YA;65?87)R6UT@/2`D;F%M95]P87)T<UM60T%21%].7T9!34E,
M65T["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&YA;65?<&%R='-;
M5D-!4D1?3E]3549&25A=*2D@>PH@("`@("`@("`@("`D;F%M95]A<G);72`]
M("1N86UE7W!A<G1S6U9#05)$7TY?4U5&1DE873L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!I;7!L;V1E*"<@)RP@)&YA;65?87)R*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-T871I8R!F=6YC=&EO;B!T;R!M86ME(&$@9VEV96X@
M96UA:6P@861D<F5S<R!R9F,X,C(@8V]M<&QI86YT+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&%D9')E<W,@($%N(&5M86EL(&%D9')E<W,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!21D,X,C(M9F]R;6%T
M=&5D(&5M86EL(&%D9')E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)A
M<F5%;6%I;"@D861D<F5S<RD*("`@('L*("`@("`@("`O+R!%;7!T>2!V86QU
M97,@87)E('-T:6QL(&5M<'1Y+@H@("`@("`@(&EF("@A)&%D9')E<W,I('L*
M("`@("`@("`@("`@<F5T=7)N("1A9&1R97-S.PH@("`@("`@('T*"B`@("`@
M("`@<F5Q=6ER95]O;F-E("=-86EL+U)&0S@R,BYP:'`G.PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O34E-12YP:'`G.PH*("`@("`@("!S=&%T:6,@
M)')F8S@R,CL*("`@("`@("!I9B`H:7-?;G5L;"@D<F9C.#(R*2D@>PH@("`@
M("`@("`@("`D<F9C.#(R(#T@;F5W($UA:6Q?4D9#.#(R*"D["B`@("`@("`@
M?0H*("`@("`@("`D<F9C.#(R+3YV86QI9&%T94UA:6QB;W@H)&%D9')E<W,I
M.PH@("`@("`@(')E='5R;B!-24U%.CIR9F,X,C)7<FET94%D9')E<W,H)&%D
M9')E<W,M/FUA:6QB;W@L("1A9&1R97-S+3YH;W-T*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]P87-S=V0N<&AP````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,38Q,3`@,3`U,34T,S0Q-#`@
M,#(R,C4Q`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@075T:%]P87-S=V0Z.B!C;&%S<R!P<F]V
M:61E<R!A('!A<W-W9"UF:6QE(&EM<&QE;65N=&%T:6]N(&]F"B`J('1H92!(
M;W)D92!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J($]P=&EO;F%L('!A
M<F%M971E<G,Z/'!R93X*("H@("`G9FEL96YA;64G("!4:&4@<&%S<W=D(&9I
M;&4@=&\@=7-E+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("]E=&,O<&%S
M<W=D"B`J("`@)VQO8VLG("`@("`@4VAO=6QD('=E(&QO8VL@=&AE('!A<W-W
M9"!F:6QE/R`H8F]O;&5A;BD*("H@("`@("`@("`@("`@("!$149!54Q4.B!F
M86QS93PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O<&%S<W=D+G!H<"QV(#$N,38N,3`N,3$@,C`P-B\P."\Q-"`P,CHT.#HT
M."!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY-RTR,#`V(%)A<VUU
M<R!,97)D;W)F(#QR87-M=7-`<&AP+FYE=#X*("H@0V]P>7)I9VAT(#(P,#(M
M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@(%)A<VUU<R!,97)D;W)F(#QR87-M=7-`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(
M;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7W!A<W-W9"!E>'1E;F1S($%U=&@@
M>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I;&ET:65S+"!S
M;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@("`@("H@;W!E
M<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E<VXG="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D8V%P86)I
M;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97-E='!A
M<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A
M;'-E*3L*"B`@("`O*BH*("`@("`J(%!A<W-W9"!F:6QE+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V9I;&5N86UE(#T@
M)R]E=&,O<&%S<W=D)SL*"B`@("`O*BH*("`@("`J($AA<V@@;&ES="!O9B!U
M<V5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W5S97)S.PH*("`@("\J*@H@("`@("H@1FEL96AA;F1L92!F;W(@;&]C
M:V9I;&4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D7V9P;&]C:SL*"B`@("`O*BH*("`@("`J($QO8VMI;F<@<W1A=&4N
M"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D
M7VQO8VME9#L*"B`@("`O*BH*("`@("`J($QI<W0@;V8@=7-E<G,@=&AA="!S
M:&]U;&0@8F4@97AC;'5D960@9G)O;2!B96EN9R!L:7-T960O:&%N9&QE9`H@
M("`@("H@:6X@86YY('=A>2!B>2!T:&ES(&1R:79E<BX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5X8VQU9&4@/2!A<G)A
M>2@G<F]O="<L("=D865M;VXG+"`G8FEN)RP@)W-Y<R<L("=S>6YC)RP@)V=A
M;65S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%N)RP@)VQP)RP@
M)VUA:6PG+"`G;F5W<R<L("=U=6-P)RP@)W!R;WAY)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<&]S=&=R97,G+"`G=W=W+61A=&$G+"`G8F%C:W5P
M)RP@)V]P97)A=&]R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES
M="<L("=I<F,G+"`G9VYA=',G+"`G;F]B;V1Y)RP@)VED96YT9"<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-S:&0G+"`G9V1M)RP@)W!O<W1F:7@G
M+"`G;7ES<6PG+"`G8WER=7,G+"`G9G1P)RD["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W(%!A<W-W9"!A=71H96YT:6-A=&EO;B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@075T:%]P87-S=V0H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@(&EF
M("@A96UP='DH)'!A<F%M<ULG9FEL96YA;64G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]F:6QE;F%M92`]("1P87)A;7-;)V9I;&5N86UE)UT["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7V9P;&]C:R`](&9O<&5N*$AO<F1E.CIG
M971496UP1&ER*"D@+B`G+W!A<W-W9"YL;V-K)RP@)W<G*3L*("`@("`@("!I
M9B`H(65M<'1Y*"1P87)A;7-;)VQO8VLG72DI('L*("`@("`@("`@("`@9FQO
M8VLH)'1H:7,M/E]F<&QO8VLL($Q/0TM?15@I.PH@("`@("`@("`@("`D=&AI
M<RT^7VQO8VME9"`]('1R=64["B`@("`@("`@?0H*("`@("`@("`D9G`@/2!F
M;W!E;B@D=&AI<RT^7V9I;&5N86UE+"`G<B<I.PH@("`@("`@(&EF("@A)&9P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;W5L
M9&XG="!O<&5N("<B("X@)'1H:7,M/E]F:6QE;F%M92`N("(G+B(I.PH@("`@
M("`@('T*("`@("`@("!W:&EL92`H(69E;V8H)&9P*2D@>PH@("`@("`@("`@
M("`D;&EN92`](&9G971S*"1F<"P@,3(X*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@(&QI<W0H)'5S97(L("1P
M87-S+"`D=6ED+"`D9VED+"`D:6YF;RP@)&AO;64L("1S:&5L;"D@/2!E>'!L
M;V1E*"<Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D
M=7-E<BD@)B8*("`@("`@("`@("`@("`@("`@("`A:6Y?87)R87DH)'5S97(L
M("1T:&ES+3Y?97AC;'5D92DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W5S97)S6R1U<V5R75LG<&%S<W=O<F0G72`]("1P87-S.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=6R=U:60G72`]("1U
M:60["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5R<ULD=7-E<EU;
M)V=I9"==(#T@)&=I9#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S
M97)S6R1U<V5R75LG:6YF;R==(#T@)&EN9F\["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]U<V5R<ULD=7-E<EU;)VAO;64G72`]("1H;VUE.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<G-;)'5S97)=6R=S:&5L;"==
M(#T@)'-H96QL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&9C;&]S92@D9G`I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R
M260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS
M("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($U#04PL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES(&UU<W0@8V]N
M=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V
M86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E
M<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1C
M<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@2&]R9&4Z
M.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!005-35T0@875T
M:&5N=&EC871I;VXN(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W5S97)S6R1U<V5R261=*2D@
M>PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]U<V5R<ULD=7-E<DED75LG<&%S
M<W=O<F0G72`]/2!C<GEP="@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL('-U
M8G-T<B@D=&AI<RT^7W5S97)S6R1U<V5R261=6R=P87-S=V]R9"==+"`P+"`R
M*2DI(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T
M:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A
M<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("![
M"B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'1H:7,M/E]U<V5R<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@=7-E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("!.97<@=7-E<B!)1"X*("`@("`J
M($!P87)A;2!S=')I;F<@)'!A<W,@("`@(%!A<W-W;W)D(&9O<B!N97<@=7-E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&-V<W5S97(@($-64R!U<V5R(&ED
M("AN965D960@9F]R('!S97)V97(@<&%S<W=D(&9I;&5S*2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O<B!014%27T5R
M<F]R(&EF('1H92!U<V5R(&%L<F5A9'D*("`@("`J("`@("`@("`@("`@("`@
M("`@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R
M+"`D<&%S<RP@)&-V<W5S97(@/2`G)RD*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?=7-E<G-;)'5S97)=*2`F)B`D=&AI<RT^7VQO8VME9"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W5S97)S6R1U<V5R72`](&-R>7!T*"1P
M87-S*3L*("`@("`@("`@("`@)'1H:7,M/E]C=G-;)'5S97)=(#T@)&-V<W5S
M97(["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#;W5L9&XG
M="!A9&0@=7-E<B`G)'5S97(G+"!B96-A=7-E('1H92!U<V5R(&%L<F5A9'D@
M97AI<W1S+B(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UO
M9&EF:65S(&$@=7-E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U
M<V5R("`@("!5<V5R($E$+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S<R`@
M("`@4&%S<W=O<F0@9F]R(&YE=R!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8W9S=7-E<B`@0U93('5S97(@:60@*&YE961E9"!F;W(@<'-E<G9E<B!P
M87-S=V0@9FEL97,I+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M4F5T=7)N<R!T<G5E(&]R(%!%05)?17)R;W(@:68@=&AE('5S97(@9&]E<VXG
M=`H@("`@("H@("`@("`@("`@("`@("`@("!E>&ES=',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&UO9%5S97(H)'5S97(L("1P87-S+"`D8W9S=7-E<B`]("<G
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W5S97)S6R1U<V5R
M72D@)B8@)'1H:7,M/E]L;V-K960I('L*("`@("`@("`@("`@)'1H:7,M/E]U
M<V5R<ULD=7-E<ET@/2!C<GEP="@D<&%S<RD["B`@("`@("`@("`@("1T:&ES
M+3Y?8W9S6R1U<V5R72`]("1C=G-U<V5R.PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@B0V]U;&1N)W0@;6]D:69Y('5S97(@)R1U<V5R)RP@
M8F5C875S92!T:&4@=7-E<B!D;V5S;B=T(&5X:7-T+B(I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!U<V5R+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@(%5S97(@240N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!2971U<FYS('1R=64@;W(@4$5!4E]%
M<G)O<B!I9B!T:&4@=7-E<B!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!D96Q5<V5R*"1U<V5R*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W5S97)S6R1U<V5R72D@)B8@)'1H:7,M/E]L;V-K960I('L*
M("`@("`@("`@("`@=6YS970H)'1H:7,M/E]U<V5R<ULD=7-E<ETI.PH@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^7V-V<ULD=7-E<ETI.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")#
M;W5L9&XG="!D96QE=&4@=7-E<B`G)'5S97(G+"!B96-A=7-E('1H92!U<V5R
M(&1O97-N)W0@97AI<W0N(BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@5W)I=&5S(&-H86YG97,@=&\@<&%S<W=D(&9I;&4@86YD('5N;&]C
M:W,@:70N("!486ME<R!N;R!A<F=U;65N=',@86YD"B`@("`@*B!H87,@;F\@
M9&5F:6YE9"!R971U<FX@=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]L;V-K960I('L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]U<V5R<R!A<R`D=7-E<B`]/B`D
M<&%S<RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?=7-E<G-;)'5S
M97)=*2!["B`@("`@("`@("`@("`@("`@("`@9G!U=',H)'1H:7,M/E]F<&QO
M8VLL("(D=7-E<CHD<&%S<SHB("X@)'1H:7,M/E]U<V5R<ULD=7-E<ET@+B`B
M7&XB*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@9G!U=',H)'1H:7,M/E]F<&QO8VLL("(D=7-E<CHD<&%S<UQN(BD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5N86UE*"1T:&ES+3Y?;&]C:V9I;&4L("1T:&ES+3Y?9FEL96YA;64I.PH@
M("`@("`@("`@("!F;&]C:R@D=&AI<RT^7V9P;&]C:RP@3$]#2U]53BD["B`@
M("`@("`@("`@("1T:&ES+3Y?;&]C:V5D(#T@9F%L<V4["B`@("`@("`@("`@
M(&9C;&]S92@D=&AI<RT^7V9P;&]C:RD["B`@("`@("`@?0H@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VEP8F%S:6,N<&AP````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<R-B`Q,#4Q-30S-#$T
M,"`P,C(S-S8`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7VEP8F%S:6,@8VQA<W,@<')O
M=FED97,@86-C97-S(&-O;G1R;VP@8F%S960@;VX@0TE$4B!M87-K<PH@*B`H
M8VQI96YT($E0(&%D9')E<W-E<RDN($ET(&ES(&YO="!M96%N="!F;W(@=7-E
M<BUB87-E9"!S>7-T96US+"!B=70*("H@9F]R('1I;65S('=H96X@>6]U('=A
M;G0@82!B;&]C:R!O9B!)4',@=&\@8F4@86)L92!T;R!A8V-E<W,@82!S:71E
M+`H@*B!A;F0@=&AA="!A8V-E<W,@:7,@<VEM<&QY(&]N+V]F9B`M(&YO('!R
M969E<F5N8V5S+"!E=&,N($EF('EO=2!N965D"B`J(&UO<F4@<V]P:&ES=&EC
M871E9"!)4"UB87-E9"!A=71H96YT:6-A=&EO;BP@>6]U('-H;W5L9"!L;V]K
M(&%T('1H90H@*B!!=71H7VEP;6%P(&-L87-S('=H:6-H(&QE=',@>6]U(&UA
M<"!)4"!B;&]C:W,@=&\@<W!E8VEF:6,*("H@=7-E<FYA;65S+@H@*@H@*B!0
M87)A;65T97)S.@H@*B`@("=B;&]C:W,G("`@("!!;B!A<G)A>2!O9B!#2412
M(&UA<VMS('=H:6-H(&%R92!A;&QO=V5D(&%C8V5S<RX*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO075T:"]!=71H+VEP8F%S:6,N<&AP+'8@,2XR,"XQ,"XW
M(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P
M86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?:7!B87-I8R!E>'1E
M;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P86)I
M;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC:`H@
M("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@9&]E
M<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^(&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=R97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N
M="<@("`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N
M97<@0F%S:6,@25`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P
M87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VEP8F%S:6,H
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]S9710
M87)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@<&%R
M86UE=&5R<R!F;W(@=&AE($%U=&A?:7!B87-I8R!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@(%-H;W5L9"!C;VYT86EN("=B;&]C:W,G+"!A;B!A<G)A
M>2!O9B!#2412(&UA<VMS+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4&%R
M86US*"1P87)A;7,I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;
M)V)L;V-K<R==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=B;&]C:W,G72`]
M(&%R<F%Y*"D["B`@("`@("`@?2!E;'-E:68@*"%I<U]A<G)A>2@D<&%R86US
M6R=B;&]C:W,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG8FQO8VMS)UT@
M/2!A<G)A>2@D<&%R86US6R=B;&]C:W,G72D["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!=71O;6%T:6,@875T:&5N=&EC871I;VXZ($9I;F0@;W5T(&EF('1H
M92!C;&EE;G0@;6%T8VAE<R!A;B!A;&QO=V5D($E0"B`@("`@*B!B;&]C:RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T
M('1H92!C;&EE;G0@:7,@86QL;W=E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=')A;G-P87)E;G0H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)%]315)6
M15);)U)%34]415]!1$12)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T
M075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(DE0($%D9')E<W,@
M;F]T(&%V86EL86)L92XB*2D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("1C;&EE;G0@/2`D7U-%4E9%4ELG4D5-3U1%
M7T%$1%(G73L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG8FQO
M8VMS)UT@87,@)&-I9'(I('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?861D
M<F5S<U=I=&AI;D-)1%(H)&-L:65N="P@)&-I9'(I*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T075T:"@D8VED<BP@87)R87DH)W1R86YS<&%R96YT
M)R`]/B`Q*2D["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S971!=71H17)R
M;W(H05542%]214%33TY?34534T%'12P@7R@B25`@061D<F5S<R!N;W0@=VET
M:&EN(&%L;&]W960@0TE$4B!B;&]C:RXB*2D["B`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE(&EF(&%N($E0
M(&%D9')E<W,@:7,@=VET:&EN(&$@0TE$4B!B;&]C:RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A9&1R97-S("!4:&4@25`@861D<F5S<R!T;R!C:&5C:RX*("`@("`J($!P
M87)A;2!S=')I;F<@)&-I9'(@("`@(%1H92!B;&]C:R`H92YG+B`Q.3(N,38X
M+C`N,"\Q-BD@=&\@=&5S="!A9V%I;G-T+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&%D9')E<W,@;6%T8VAE
M<R!T:&4@;6%S:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9')E<W-7:71H
M:6Y#2412*"1A9&1R97-S+"`D8VED<BD*("`@('L*("`@("`@("`D861D<F5S
M<R`](&EP,FQO;F<H)&%D9')E<W,I.PH@("`@("`@(&QI<W0H)'%U860L("1B
M:71S*2`](&5X<&QO9&4H)R\G+"`D8VED<BD["B`@("`@("`@)&)I=',@/2!I
M;G1V86PH)&)I=',I.PH@("`@("`@("1Q=6%D(#T@:7`R;&]N9R@D<75A9"D[
M"@H@("`@("`@(')E='5R;B`H*"1A9&1R97-S(#X^("@S,B`M("1B:71S*2D@
M/3T@*"1Q=6%D(#X^("@S,B`M("1B:71S*2DI.PH@("`@?0H*?0H`````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]L9&%P+G!H<```````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#<Q,38@,3`U,34T,S0Q
M-#`@,#(Q-S`R`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]L9&%P(&-L87-S('!R;W9I
M9&5S(&%N($Q$05`@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U
M=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=B87-E9&XG("`@("`@(%1H92!B87-E($1.(&9O<B!T
M:&4@3$1!4"!S97)V97(N"B`J("`@)VAO<W1S<&5C)R`@("`@5&AE(&AO<W1N
M86UE(&]F('1H92!,1$%0('-E<G9E<BX*("H@("`G=6ED)R`@("`@("`@("!4
M:&4@=7-E<FYA;64@<V5A<F-H(&ME>2X*("H@("`G9FEL=&5R)R`@("`@("!4
M:&4@3$1!4"!F;W)M871T960@<V5A<F-H(&9I;'1E<B!T;R!S96%R8V@@9F]R
M('5S97)S+B!4:&ES"B`J("`@("`@("`@("`@("`@("`@<V5T=&EN9R!O=F5R
M<FED97,@=&AE("=O8FIE8W1C;&%S<R<@;65T:&]D(&)E;&]W+@H@*B`@("=O
M8FIE8W1C;&%S<R<@(%1H92!O8FIE8W1C;&%S<R!F:6QT97(@=7-E9"!T;R!S
M96%R8V@@9F]R('5S97)S+B!#86X@8F4@80H@*B`@("`@("`@("`@("`@("`@
M('-I;F=L92!O8FIE8W1C;&%S<R!O<B!A;B!A<G)A>2X\+W!R93X*("H*("H@
M3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@*B`@("=B:6YD9&XG("`@("`@
M(%1H92!$3B!U<V5D('1O(&)I;F0@=&\@=&AE($Q$05`@<V5R=F5R"B`J("`@
M)W!A<W-W;W)D)R`@("`@5&AE('!A<W-W;W)D('5S960@=&\@8FEN9"!T;R!T
M:&4@3$1!4"!S97)V97(*("H@("`G=F5R<VEO;B<@("`@("!4:&4@=F5R<VEO
M;B!O9B!T:&4@3$1!4"!P<F]T;V-O;"!T;R!U<V4N"B`J("`@("`@("`@("`@
M("`@("`@1$5&055,5#H@3D].12`H<WES=&5M(&1E9F%U;'0@=VEL;"!B92!U
M<V5D*3PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O;&1A<"YP:'`L=B`Q+C0W+C$P+C$Y(#(P,#8O,#@O,30@,#(Z-#@Z-#@@
M8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R
M:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,2XS"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?
M;&1A<"!E>'1E;F1S($%U=&@@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@
M;V8@8V%P86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R
M="!W:&EC:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI
M8V@@:70@9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@
M("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U
M<&1A=&4G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!T<G5E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@
M/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS
M<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($Q$05`@8V]N
M;F5C=&EO;B!H86YD;&4*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@
M("`@*B\*("`@('9A<B`D7V1S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!,1$%0(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!
M=71H7VQD87`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@
M*"%5=&EL.CIE>'1E;G-I;VY%>&ES=',H)VQD87`G*2D@>PH@("`@("`@("`@
M("!(;W)D93HZ9F%T86PH7R@B075T:%]L9&%P.B!297%U:7)E9"!,1$%0(&5X
M=&5N<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYF:6=U<F%T:6]N('!A<F%M
M971E<G,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@
M8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<V5T4&%R86US*"1P87)A;7,I"B`@("!["B`@("`@("`@+RH@16YS=7)E('=E
M)W9E(&)E96X@<')O=FED960@=VET:"!A;&P@;V8@=&AE(&YE8V5S<V%R>2!P
M87)A;65T97)S+B`J+PH@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV97)#;VYF
M:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)V)A<V5D;B<L("=U:60G*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A=71H96YT:6-A
M=&EO;B!,1$%0)RD["@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M
M<SL*("`@('T*"B`@("`O*BH*("`@("`J($1O97,@86X@;&1A<"!C;VYN96-T
M(&%N9"!B:6YD<R!A<R!T:&4@9W5E<W0@=7-E<B!O<B!A<R!T:&4@;W!T:6]N
M86P@9&XN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R($9A;'-E(&)A<V5D(&]N
M('-U8V-E<W,@;V8@8V]N;F5C="!A;F0@8FEN9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J($-O;FYE8W0@=&\@
M=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1T:&ES+3Y?9',@/2!`;&1A
M<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*3L*("`@("`@
M("!I9B`H(21T:&ES+3Y?9',I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!S97)V
M97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@(&EF("@A;&1A<%]S
M971?;W!T:6]N*"1T:&ES+3Y?9',L($Q$05!?3U!47U!23U1/0T],7U9%4E-)
M3TXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92AS<')I;G1F*"=3970@3$1!4"!P<F]T;V-O;"!V97)S:6]N
M('1O("5D(&9A:6QE9#H@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=V97)S:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&QD87!?97)R;F\H)&-O;FXI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R*"1C;VYN*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG8FEN9&1N)UTI*2!["B`@
M("`@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D=&AI
M<RT^7W!A<F%M<ULG8FEN9&1N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1T:&ES
M+3Y?9',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D8FEN9"D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@
M8FEN9"!T;R!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE('5S
M97(@9&X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@5&AE('5S97))9"!T
M;R!F:6YD+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=7-E
M<G,@9G5L;"!$3@H@("`@("HO"B`@("!F=6YC=&EO;B!?9FEN9$1.*"1U<V5R
M260I"B`@("!["B`@("`@("`@+RH@4V5A<F-H(&9O<B!T:&4@=7-E<B=S(&9U
M;&P@1$XN("HO"B`@("`@("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI
M<RT^7V1S+"`D=&AI<RT^7W!A<F%M<ULG8F%S961N)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=6ED)UT@+B`G
M/2<@+B`D=7-E<DED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'1H:7,M/E]P87)A;7-;)W5I9"==*2D["B`@("`@("`@:68@*"$D
M<V5A<F-H*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*&QD87!?
M97)R;W(H)'1H:7,M/E]D<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B0V]U;&0@;F]T('-E87)C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@
M("`@('T*"B`@("`@("`@)')E<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T
M:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<F5S
M=6QT*2`F)B`H8V]U;G0H)')E<W5L="D@/B`Q*2D@>PH@("`@("`@("`@("`D
M9&X@/2`D<F5S=6QT6S!=6R=D;B==.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D5M<'1Y(')E<W5L
M="XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1N.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!S:&%D;W=,87-T0VAA;F=E(&%N
M9"!S:&%D;W=-:6XO36%X('-U<'!O<G0@86YD(')E='5R;G,@=&AE:7(*("`@
M("`J('9A;'5E<RX@(%=E('=I;&P@86QS;R!C:&5C:R!F;W(@<'=D3&%S=%-E
M="!I9B!!8W1I=F4@1&ER96-T;W)Y(&ES"B`@("`@*B!S=7!P;W)T(&ES(')E
M<75E<W1E9"X@($9O<B!T:&ES(&-H96-K('1O('-U8V-E960@=V4@;F5E9"!T
M;R!B92!B;W5N9`H@("`@("H@=&\@=&AE(&1I<F5C=&]R>0H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&1N("`@("!4:&4@9&X@;V8@=&AE('5S97(*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!A<G)A>2!W:71H(&ME>7,@8F5I;F<@(G-H861O=VQA
M<W1C:&%N9V4B+"`B<VAA9&]W;6EN(@H@("`@("H@("`@("`@("`@("`@("`@
M(G-H861O=VUA>"(L(")S:&%D;W=W87)N:6YG(B!A;F0@8V]N=&%I;FEN9R!T
M:&5I<@H@("`@("H@("`@("`@("`@("`@("`@<F5S<&5C=&EV92!V86QU97,@
M;W(@9F%L<V4@9F]R(&YO('-U<'!O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]L;V]K=7!3:&%D;W<H)&1N*0H@("`@>PH@("`@("`@("\J($EN:70@=&AE
M(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D;&]O:W5P<VAA9&]W(#T@87)R
M87DH)W-H861O=VQA<W1C:&%N9V4G(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<VAA9&]W;6EN)R`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-H861O=VUA>"<@/3X@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:&%D;W=W87)N:6YG
M)R`]/B!F86QS92D["@H*("`@("`@("`D<F5S=6QT(#T@0&QD87!?<F5A9"@D
M=&AI<RT^7V1S+"`D9&XL("=O8FIE8W1#;&%S<STJ)RD["@H@("`@("`@(&EF
M("@D<F5S=6QT*2!["B`@("`@("`@("`@("1I;F9O<FUA=&EO;B`]($!L9&%P
M7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1R97-U;'0I.PH*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?<&%R86US6R=A9"==*2!["B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R=P=V1L87-T<V5T)UU;,%TI
M*2!["B`@("`@("`@("`@("`@("`@("`@+RH@06-T:79E($1I<F5C=&]R>2!H
M86YD;&5S('1I;65S=&%M<',@82!B:70*("`@("`@("`@("`@("`@("`@("`@
M*B!D:69F97)E;G1L>2X@($-O;G9E<G0@=&AE('1I;65S=&%M<"!T;R!A(%5.
M25@*("`@("`@("`@("`@("`@("`@("`@*B!T:6UE<W1A;7`N("HO"B`@("`@
M("`@("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;&%S=&-H86YG
M92==(#T@9FQO;W(H*"@D:6YF;W)M871I;VY;,%U;)W!W9&QA<W1S970G75LP
M72`O(#$P,#`P,#`P*2`M(#$Q-C0T-#`V-S@S*2`O(#@V-#`P*2`M(#$["@H@
M("`@("`@("`@("`@("`@("`@("\J(%!A<W-W;W)D(&5X<&ER>2!A='1R:6)U
M=&5S(&%R92!I;B!A('!O;&EC>2X@5V4*("`@("`@("`@("`@("`@("`@("`@
M*B!C86YN;W0@<F5A9"!T:&5M('-O('5S92!T:&4@2&]R9&4@8V]N9FEG+B`J
M+PH@("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=W=A
M<FYI;F<G72`]("1T:&ES+3Y?<&%R86US6R=W87)N86=E)UT["B`@("`@("`@
M("`@("`@("`@("`@)&QO;VMU<'-H861O=ULG<VAA9&]W;6EN)UT@("`@(#T@
M)'1H:7,M/E]P87)A;7-;)VUI;F%G92==.PH@("`@("`@("`@("`@("`@("`@
M("1L;V]K=7!S:&%D;W=;)W-H861O=VUA>"==("`@("`]("1T:&ES+3Y?<&%R
M86US6R=M87AA9V4G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;W)M871I
M;VY;,%U;)W-H861O=VUA>"==6S!=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1L;V]K=7!S:&%D;W=;)W-H861O=VUA>"==(#T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F]R;6%T:6]N6S!=
M6R=S:&%D;W=M87@G75LP73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M:6XG
M75LP72DI('L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P<VAA9&]W6R=S
M:&%D;W=M:6XG72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;6EN)UU;,%T[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=VQA<W1C
M:&%N9V4G72`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=L87-T8VAA;F=E)UU;,%T["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I
M;F9O<FUA=&EO;ELP75LG<VAA9&]W=V%R;FEN9R==6S!=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1L;V]K=7!S:&%D;W=;)W-H861O=W=A<FYI;F<G72`]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F]R;6%T:6]N6S!=6R=S:&%D;W=W87)N:6YG)UU;,%T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D;&]O:W5P<VAA9&]W.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O
M=70@:68@=&AE(&=I=F5N('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@
M=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@
M=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@("1C<F5D96YT:6%L<R`@
M06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@
M("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI
M<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L("1S=6-C
M97-S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!396%R8V@@9F]R('1H92!U<V5R)W,@
M9G5L;"!$3BX@*B\*("`@("`@("`D9&X@/2`D=&AI<RT^7V9I;F1$3B@D=7-E
M<DED*3L*("`@("`@("!I9B`H:7-?82@D9&XL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?
M34534T%'12P@)&1N+3YG971-97-S86=E*"DI.PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!!='1E;7!T('1O(&)I
M;F0@=&\@=&AE($Q$05`@<V5R=F5R(&%S('1H92!U<V5R+B`J+PH@("`@("`@
M("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V1S+"`D9&XL("1C<F5D96YT
M:6%L<ULG<&%S<W=O<F0G72D["B`@("`@("`@:68@*"1B:6YD("$](&9A;'-E
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?
M97AP:7)A=&EO;B==(#T]("=Y97,G*2!["@H@("`@("`@("`@("`@("`@)'-H
M861O=R`]("1T:&ES+3Y?;&]O:W5P4VAA9&]W*"1D;BD["@H@("`@("`@("`@
M("`@("`@:68@*"1S:&%D;W=;)W-H861O=VUA>"==("8F("1S:&%D;W=;)W-H
M861O=VQA<W1C:&%N9V4G72`F)@H@("`@("`@("`@("`@("`@("`@("1S:&%D
M;W=;)W-H861O=W=A<FYI;F<G72D@>PH*("`@("`@("`@("`@("`@("`@("`D
M=&]D87D@/2!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@("`@("`@
M("`@("`@)'=A<FYD87D@/2`D<VAA9&]W6R=S:&%D;W=L87-T8VAA;F=E)UT@
M*PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H861O=ULG<VAA
M9&]W;6%X)UT@+2`D<VAA9&]W6R=S:&%D;W=W87)N:6YG)UT["@H@("`@("`@
M("`@("`@("`@("`@("1T;V5X<&ER92`]("1S:&%D;W=;)W-H861O=VQA<W1C
M:&%N9V4G72`K"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-H
M861O=ULG<VAA9&]W;6%X)UT@+2`D=&]D87D["@H*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1O9&%Y(#X]("1W87)N9&%Y*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"AS<')I
M;G1F*%\H(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(I
M+"`D=&]E>'!I<F4I+"=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H)'1O97AP:7)E(#T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%U=&A#<F5D
M96YT:6%L<ULG8VAA;F=E4F5Q=65S=&5D)UT@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@:68@*"1T;V5X<&ER
M92`\(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!
M=71H17)R;W(H05542%]214%33TY?15A025)%1"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`;&1A<%]C;&]S
M92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R
M;W(H05542%]214%33TY?1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E
M="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&%D
M9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D
M96YT:6%L<R!T;R!B92!S970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E<DED
M+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<&%R
M86US6R=A9"==*2!["B`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B075T:%]L9&%P.B!!9&1I;F<@=7-E<G,@:7,@;F]T('-U<'!O<G1E
M9"!F;W(@06-T:79E($1I<F5C=&]R>2(I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S
M97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP='DH
M)&-O;F9;)VAO;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@("`@("`@("`@($!I
M;F-L=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]A=71H
M;&1A<"<I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2!C86QL7W5S97)?
M9G5N8R@G7VAO<F1E7VAO;VM?875T:&QD87`G+"`D=7-E<DED+"`D8W)E9&5N
M=&EA;',I.PH@("`@("`@("`@("`@("`@)&1N(#T@)&5N=')Y6R=D;B==.PH@
M("`@("`@("`@("`@("`@+RH@<F5M;W9E('1H92!D;B!E;G1R>2!F<F]M('1H
M92!A<G)A>2X@*B\*("`@("`@("`@("`@("`@('5N<V5T*"1E;G1R>5LG9&XG
M72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O*B!4<GD@=&AI<R!S:6UP;&4@9&5F875L="!A;F0@:&]P92!I="!W;W)K
M<RX@*B\*("`@("`@("`@("`@)&1N(#T@)'1H:7,M/E]P87)A;7-;)W5I9"==
M("X@)STG("X@)'5S97))9"`N("<L)R`N("1T:&ES+3Y?<&%R86US6R=B87-E
M9&XG73L*("`@("`@("`@("`@)&5N=')Y6R=C;B==(#T@)'5S97))9#L*("`@
M("`@("`@("`@)&5N=')Y6R=S;B==(#T@)'5S97))9#L*("`@("`@("`@("`@
M)&5N=')Y6R1T:&ES+3Y?<&%R86US6R=U:60G75T@/2`D=7-E<DED.PH@("`@
M("`@("`@("`D96YT<GE;)V]B:F5C=&-L87-S)UT@/2!A<G)A>5]M97)G92AA
M<G)A>2@G=&]P)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=N97=U<V5R7V]B:F5C=&-L87-S)UTI.PH@
M("`@("`@("`@("`D96YT<GE;)W5S97)087-S=V]R9"==(#T@)'1H:7,M/F=E
M=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL)R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=T<G5E)RD["@H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V5X<&ER871I;VXG72`]/2`G
M>65S)RD@>PH@("`@("`@("`@("`@("`@)&5N=')Y6R=S:&%D;W=-:6XG72`]
M("1T:&ES+3Y?<&%R86US6R=M:6YA9V4G73L*("`@("`@("`@("`@("`@("1E
M;G1R>5LG<VAA9&]W36%X)UT@/2`D=&AI<RT^7W!A<F%M<ULG;6%X86=E)UT[
M"B`@("`@("`@("`@("`@("`D96YT<GE;)W-H861O=U=A<FYI;F<G72`]("1T
M:&ES+3Y?<&%R86US6R=W87)N86=E)UT["B`@("`@("`@("`@("`@("`D96YT
M<GE;)W-H861O=TQA<W1#:&%N9V4G72`](&9L;V]R*'1I;64H*2`O(#@V-#`P
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D<W5C8V5S<R`]
M($!L9&%P7V%D9"@D=&AI<RT^7V1S+"`D9&XL("1E;G1R>2D["@H@("`@("`@
M(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(D%U=&A?;&1A<#H@56YA8FQE('1O(&%D9"!U
M<V5R("5S+B!4:&ES(&ES('=H870@=&AE('-E<G9E<B!S86ED.B`B*2P@)'5S
M97))9"D@+B!`;&1A<%]E<G)O<B@D=&AI<RT^7V1S*2D["B`@("`@("`@?0H*
M("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!S970@
M;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!A9&0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5M;W9E57-E<B@D=7-E<DED*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@4F5M;W9I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2(I+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N
M;F5C="!T;R!T:&4@3$1!4"!S97)V97(N("HO"B`@("`@("`@)'-U8V-E<W,@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D<W5C8V5S
M<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U
M=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"`D<W5C8V5S<RT^9V5T365S
M<V%G92@I*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP='DH)&-O
M;F9;)VAO;VMS)UU;)V%U=&AL9&%P)UTI*2!["B`@("`@("`@("`@($!I;F-L
M=61E($A/4D1%7T)!4T4@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@("`@
M("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=?:&]R9&5?:&]O:U]A=71H;&1A
M<"<I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2!C86QL7W5S97)?9G5N
M8R@G7VAO<F1E7VAO;VM?875T:&QD87`G+"`D=7-E<DED*3L*("`@("`@("`@
M("`@("`@("1D;B`]("1E;G1R>5LG9&XG73L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J(%-E87)C:"!F;W(@=&AE('5S
M97(G<R!F=6QL($1.+B`J+PH@("`@("`@("`@("`D9&X@/2`D=&AI<RT^7V9I
M;F1$3B@D=7-E<DED*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1N+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%
M<G)O<BA!551(7U)%05-/3E]-15-304=%+"`D9&XM/F=E=$UE<W-A9V4H*2D[
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1S=6-C97-S(#T@0&QD87!?9&5L971E*"1T
M:&ES+3Y?9',L)&1N*3L*("`@("`@("!I9B`H(21S=6-C97-S*2!["B`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!=71H
M7VQD87`Z(%5N86)L92!T;R!R96UO=F4@=7-E<B`E<R(I+"`D=7-E<DED*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@($!L9&%P
M7V-L;W-E*"1T:&ES+3Y?9',I.PH*("`@("`@("!R971U<FX@)'1H:7,M/G)E
M;6]V955S97)$871A*"1U<V5R260I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9$E$("`@("`@(%1H92!O
M;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@("`@
M5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I
M86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E57-E
M<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^7W!A<F%M<ULG860G72D@>PH@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D%U=&A?;&1A<#H@57!D871I;F<@=7-E
M<G,@:7,@;F]T('-U<'!O<G1E9"!F;W(@06-T:79E($1I<F5C=&]R>2XB*2P@
M7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\J($-O
M;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C97-S
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U8V-E
M<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2P@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&=L;V)A;"`D8V]N9CL*
M("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=H;V]K<R==6R=A=71H;&1A<"==
M*2D@>PH@("`@("`@("`@("!`:6YC;'5D92!(3U)$15]"05-%("X@)R]C;VYF
M:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T
M<R@G7VAO<F1E7VAO;VM?875T:&QD87`G*2D@>PH@("`@("`@("`@("`@("`@
M)&5N=')Y(#T@8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL9&%P
M)RP@)&]L9$E$+"`D8W)E9&5N=&EA;',I.PH@("`@("`@("`@("`@("`@)&]L
M9&1N(#T@)&5N=')Y6R=D;B==.PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@
M8V%L;%]U<V5R7V9U;F,H)U]H;W)D95]H;V]K7V%U=&AL9&%P)RP@)&YE=TE$
M+"`D8W)E9&5N=&EA;',I.PH@("`@("`@("`@("`@("`@)&YE=V1N(#T@)&5N
M=')Y6R=D;B==.PH@("`@("`@("`@("`@("`@=6YS970H)&5N=')Y6R=D;B==
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\J(%-E87)C:"!F;W(@=&AE('5S97(G<R!F=6QL($1.+B`J+PH@("`@("`@
M("`@("`D9&X@/2`D=&AI<RT^7V9I;F1$3B@D;VQD240I.PH*("`@("`@("`@
M("`@:68@*&ES7V$H)&1N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S
M<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&]L9&1N(#T@)&1N.PH@("`@("`@("`@
M("`@("`@)&YE=V1N(#T@<')E9U]R97!L86-E*"<O=6ED/2XJ/RPO)RPG=6ED
M/2<N)&YE=TE$+B<L)RPD9&XL,2D["B`@("`@("`@("`@("`@("`D<VAA9&]W
M(#T@)'1H:7,M/E]L;V]K=7!3:&%D;W<H)&1N*3L*"B`@("`@("`@("`@("`@
M("`O*B!I9B!S:&%D;W=M:6X@:&%S;B=T('EE="!E>'!I<F5D(&]N;'D@8VAA
M;F=E('=H96X@=V4@87)E"B`@("`@("`@("`@("`@("`@("!A9&UI;FES=')A
M=&]R("HO"B`@("`@("`@("`@("`@("!I9B`H)'-H861O=ULG<VAA9&]W;&%S
M=&-H86YG92==("8F("1S:&%D;W=;)W-H861O=VUI;B==*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1S:&%D;W=;)W-H861O=VQA<W1C:&%N9V4G72`K
M("1S:&%D;W=;)W-H861O=VUI;B==(#X@*'1I;64H*2`O(#@V-#`P*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")-:6YI;75M('!A<W-W;W)D(&%G92!H87,@;F]T('EE="!E>'!I<F5D
M(BDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`O*B!3970@=&AE(&QA<W1C:&%N9V4@9FEE;&0@
M*B\*("`@("`@("`@("`@("`@(&EF("@D<VAA9&]W6R=S:&%D;W=L87-T8VAA
M;F=E)UTI('L*("`@("`@("`@("`@("`@("`@("`D96YT<GE;)W-H861O=VQA
M<W1C:&%N9V4G72`]("!F;&]O<BAT:6UE*"D@+R`X-C0P,"D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@16YC<GEP="!T:&4@;F5W
M('!A<W-W;W)D("HO"B`@("`@("`@("`@("`@("`D96YT<GE;)W5S97)P87-S
M=V]R9"==(#T@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA
M;'-;)W!A<W-W;W)D)UTL)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1R=64G*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M:68@*"1O;&1)1"`A/2`D;F5W240I('L*("`@("`@("`@("`@:68@*$Q$05!?
M3U!47U!23U1/0T],7U9%4E-)3TX@/3T@,RD@>PH@("`@("`@("`@("`@("`@
M;&1A<%]R96YA;64H)'1H:7,M/E]D<RP@)&]L9&1N+"`D;F5W9&XL("1T:&ES
M+3Y?<&%R86US6R=B87-E9&XG72P@=')U92D["@H@("`@("`@("`@("`@("`@
M)'-U8V-E<W,@/2!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"`D;F5W9&XL("1E
M;G1R>2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O
M*B!'970@=&AE(&-O;7!L971E(&]L9"!R96-O<F0@9FER<W0@*B\*("`@("`@
M("`@("`@("`@("1S=6-C97-S(#T@0&QD87!?<F5A9"@D=&AI<RT^7V1S+"`D
M;VQD9&XL("=O8FIE8W1#;&%S<STJ)RD["@H@("`@("`@("`@("`@("`@:68@
M*"1S=6-C97-S*2!["B`@("`@("`@("`@("`@("`@("`@)&EN9F]R;6%T:6]N
M(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-U8V-E<W,I.PH*
M("`@("`@("`@("`@("`@("`@("`O*B!296UO=F4@=&AE(&-O=6YT(&5L96UE
M;G1S(&9R;VT@=&AE(&%R<F%Y("HO"B`@("`@("`@("`@("`@("`@("`@)&-O
M=6YT97(@/2`P.PH@("`@("`@("`@("`@("`@("`@("1N97=R96-O<F0@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("AI<W-E="@D:6YF
M;W)M871I;VY;,%U;)&-O=6YT97)=*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&EN9F]R;6%T:6]N6S!=6R1I;F9O<FUA=&EO;ELP75LD8V]U
M;G1E<EU=6R=C;W5N="==(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N97=R96-O<F1;)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R75T@
M/2`D:6YF;W)M871I;VY;,%U;)&EN9F]R;6%T:6]N6S!=6R1C;W5N=&5R75U;
M,%T["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;F5W<F5C;W)D6R1I;F9O<FUA=&EO;ELP
M75LD8V]U;G1E<EU=(#T@)&EN9F]R;6%T:6]N6S!=6R1I;F9O<FUA=&EO;ELP
M75LD8V]U;G1E<EU=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)&YE=W)E8V]R9%LD:6YF;W)M871I;VY;,%U;)&-O=6YT97)=75LG8V]U
M;G0G72D["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O=6YT97(K*SL*("`@("`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@("`@("\J($%D:G5S="!T:&4@8VAA;F=E9"!P
M87)A;65T97)S("HO"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&YE=W)E
M8V]R9%LG9&XG72D["B`@("`@("`@("`@("`@("`@("`@)&YE=W)E8V]R9%LD
M=&AI<RT^7W!A<F%M<ULG=6ED)UU=(#T@)&YE=TE$.PH@("`@("`@("`@("`@
M("`@("`@("1N97=R96-O<F1;)W5S97)P87-S=V]R9"==(#T@)&5N=')Y6R=U
M<V5R<&%S<W=O<F0G73L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&5N=')Y6R=S:&%D;W=L87-T8VAA;F=E)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N97=R96-O<F1;)W-H861O=VQA<W1C:&%N9V4G72`]("1E
M;G1R>5LG<VAA9&]W;&%S=&-H86YG92==.PH@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@)'-U8V-E<W,@/2!L9&%P7V%D9"@D
M=&AI<RT^7V1S+"1N97=D;BPD;F5W<F5C;W)D*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'-U8V-E<W,I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'-U8V-E<W,@/2!`;&1A<%]D96QE=&4H)'1H:7,M/E]D<RPD;VQD9&XI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=6-C97-S
M(#T@0&QD87!?;6]D:69Y*"1T:&ES+3Y?9',L("1O;&1D;BP@)&5N=')Y*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A)'-U8V-E<W,I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")!=71H7VQD
M87`Z(%5N86)L92!T;R!U<&1A=&4@=7-E<B`E<R(I+"`D;F5W240I+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@0&QD87!?8VQO
M<V4H)'1H:7,M/E]D<RD["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3&ES="!5<V5R<PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@($QI<W0@;V8@57-E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&ES=%5S97)S*"D*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,
M1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S
M=6-C97-S+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=F
M:6QT97(G72DI('L*("`@("`@("`@("`@)&9I;'1E<B`]("1T:&ES+3Y?<&%R
M86US6R=F:6QT97(G73L*("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1T
M:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==*2D@>PH@("`@("`@("`@("`D
M9FEL=&5R(#T@)V]B:F5C=&-L87-S/2<@+B`D=&AI<RT^7W!A<F%M<ULG;V)J
M96-T8VQA<W,G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL
M=&5R(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US
M6R=O8FIE8W1C;&%S<R==(&%S("1O8FIE8W1C;&%S<RD@>PH@("`@("`@("`@
M("`@("`@)&9I;'1E<B`]("<H)B<@+B`D9FEL=&5R.PH@("`@("`@("`@("`@
M("`@)&9I;'1E<B`N/2`G*&]B:F5C=&-L87-S/2<@+B`D;V)J96-T8VQA<W,@
M+B`G*2DG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<V5A
M<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US
M6R=B87-E9&XG72P@)&9I;'1E<BP@87)R87DH)'1H:7,M/E]P87)A;7-;)W5I
M9"==*2D["B`@("`@("`@)&5N=')I97,@/2!`;&1A<%]G971?96YT<FEE<R@D
M=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`D=7-E<FQI<W0@/2!A<G)A
M>2@I.PH@("`@("`@("1U:60@/2!3=')I;F<Z.FQO=V5R*"1T:&ES+3Y?<&%R
M86US6R=U:60G72D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&5N=')I
M97-;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@)'5S97)L:7-T6R1I
M72`]("1E;G1R:65S6R1I75LD=6ED75LP73L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=7-E<FQI<W0["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T%U=&@O8WER=7,N<&AP````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#,P,#<Q(#$P-3$U-#,T,30P(#`R,C$Q-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($%U=&A?8WER=7,@8VQA<W,@<')O=FED97,@:&]R9&4@=VET:"!T:&4@86)I
M;&ET>2!O9B!A9&UI;FES=')A=&EN9PH@*B!A($-Y<G5S(&UA:6P@<V5R=F5R
M(&%U=&AE;G1I8V%T:6]N<R!A9V%I;G-T(&%N;W1H97(@8F%C:V5N9"!T:&%T
M($AO<F1E"B`J(&-A;B!U<&1A=&4@*&5G(%-13"!O<B!,1$%0*2X*("H*("H@
M4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=C>7)A9&UI;B<@("!4
M:&4@=7-E<FYA;64@;V8@=&AE(&-Y<G5S(&%D;6EN:7-T<F%T;W(*("H@("`G
M8WER<&%S<R<@("`@5&AE('!A<W-W;W)D(&9O<B!T:&4@8WER=7,@861M:6YI
M<W1R871O<@H@*B`@("=I;6%P7V1S;B<@("!4:&4@9G5L;"!)34%0($133B`H
M:2YE+@H@("`@("`@("`@("`@("`@("![;&]C86QH;W-T.CDY,R]I;6%P+W-S
M;"]N;W9A;&ED871E+6-E<G1]*0H@*B`@("=B86-K96YD)R`@("!4:&4@8V]M
M<&QE=&4@:&%S:"!F;W(@=&AE($%U=&A?*B!D<FEV97(@=&AA="!C>7)U<PH@
M*B`@("`@("`@("`@("`@("!A=71H96YT:6-A=&5S(&%G86EN<W0@*&5G(%-1
M3"P@3$1!4"DN"B`J("`@)W-E<&%R871O<B<@($AI97)A<F-H>2!S97!A<F%T
M;W(@=&\@=7-E("AE+F<N+"!I<R!I="!U<V5R+VUA:6QB;W@@;W(*("H@("`@
M("`@("`@("`@("`@=7-E<BYM86EL8F]X*3PO<')E/@H@*@H@*B!/<'1I;VYA
M;"!V86QU97,Z/'!R93X*("H@("`G=6YI>&AI97(G("`@5&AE('9A;'5E(&]F
M(&EM87!D+F-O;F8G<R!U;FEX:&EE<F%R8VAY<V5P('-E='1I;F<N"B`J("`@
M("`@("`@("`@("`@(%-E="!T:&ES('1O("=T<G5E)R!I9B!T:&4@=F%L=64@
M:7,@=')U92!I;B!I;6%P9"YC;VYF"B`J("`@)V9O;&1E<G,G("`@($%N(&%R
M<F%Y(&]F(&9O;&1E<G,@=&\@8W)E871E('5N9&5R('5S97)N86UE+@H@*B`@
M("`@("`@("`@("`@("!$;V5S;B=T(&-R96%T92!S=6)F;VQD97)S(&)Y(&1E
M9F%U;'0N"B`J("`@)W%U;W1A)R`@("`@(%1H92!Q=6]T82`H:6X@:VEL;V)Y
M=&5S*2!T;R!G<F%N="!O;B!T:&4@;6%I;&)O>"X*("H@("`@("`@("`@("`@
M("`@1&]E<R!N;W0@97-T86)L:7-H('%U;W1A(&)Y(&1E9F%U;'0N/"]P<F4^
M"B`J"B`J($5X86UP;&4@57-A9V4Z/'!R93X*("H@("`D8V]N9ELG875T:"==
M6R=D<FEV97(G72`]("=C;VUP;W-I=&4G.PH@*B`@("1C;VYF6R=A=71H)UU;
M)W!A<F%M<R==6R=L;V=I;G-C<F5E;E]S=VET8V@G72`]("=?:&]R9&5?<V5L
M96-T7VQO9VEN<V-R965N)SL*("H@("`D8V]N9ELG875T:"==6R=P87)A;7,G
M75LG861M:6Y?9')I=F5R)UT@/2`G8WER=7,G.PH@*B`@("1C;VYF6R=A=71H
M)UU;)W!A<F%M<R==6R=D<FEV97)S)UU;)VEM<"==(#T@87)R87DH)V1R:79E
M<B<@/3X@)V%P<&QI8V%T:6]N)RP*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R
M<F%Y*"=A<'`G(#T^("=I;7`G*2D["B`J("`@)&-O;F9;)V%U=&@G75LG<&%R
M86US)UU;)V1R:79E<G,G75LG8WER=7,G72`](&%R<F%Y*"=D<FEV97(G(#T^
M("=C>7)U<R<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G(#T^(&%R<F%Y*"=C>7)A
M9&UI;B<@/3X@)V-Y<G5S)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-Y<G!A<W,G(#T^("=P87-S=V]R9"<L"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S97!A<F%T;W(G(#T^("<N)RP*("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VEM87!?9'-N)R`]/B`G>VUA:6LN97AA;7!L
M92YC;VTO:6UA<'TG*2D["B`J("`@)&-O;F9;)V%U=&@G75LG<&%R86US)UU;
M)V1R:79E<G,G75LG8WER=7,G75LG<&%R86US)UU;)V)A8VME;F0G72`](&%R
M<F%Y*"=D<FEV97(G(#T^("=S<6PG+`H@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@G<&AP='EP92<@/3X@)VUY
M<W%L)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VAO<W1S<&5C)R`]/B`G9&%T86)A<V4N97AA;7!L92YC
M;VTG+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<')O=&]C;VPG(#T^("=T8W`G+`H@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<FYA
M;64G(#T^("=U<V5R;F%M92<L"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)W!A<W-W
M;W)D)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V1A=&%B87-E)R`]/B`G;6%I;"<L"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T86)L
M92<@/3X@)V%C8V]U;G1U<V5R)RP*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5N8W)Y<'1I;VXG(#T^("=M
M9#4M:&5X)RP*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W5S97)N86UE7V9I96QD)R`]/B`G=7-E<FYA;64G
M+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<&%S<W=O<F1?9FEE;&0G(#T^("=P87-S=V]R9"<I*3L*("H*
M("H@("!I9B`H(69U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7W-E;&5C=%]L;V=I
M;G-C<F5E;B<I*2!["B`J("`@("`@(&9U;F-T:6]N(%]H;W)D95]S96QE8W1?
M;&]G:6YS8W)E96XH*2!["B`J("`@("`@("`@("!R971U<FX@)VEM<"<["B`J
M("`@("`@('T*("H@("!]/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T%U=&@O075T:"]C>7)U<RYP:'`L=B`Q+C$U+C$P+C$T(#(P,#8O,#@O,30@
M,#(Z-#@Z-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!);'EA(#QM86EL0&MR96PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V
M($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!);'EA(#QM86EL0&MR96PN;W)G/@H@
M*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M075T:`H@*B\*8VQA<W,@075T:%]C>7)U<R!E>'1E;F1S($%U=&@@>PH*("`@
M("\J*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!)34%0(&-O;FYE
M8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@
M("!V87(@)%]I;6%P4W1R96%M.PH*("`@("\J*@H@("`@("H@1FQA9R!I;F1I
M8V%T:6YG(&EF('1H92!)34%0(&-O;FYE8W1I;VX@:7,@8V]N;F5C=&5D+@H@
M("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C
M;VYN96-T960["@H@("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O(&%N;W1H97(@
M075T:%\@8F%C:V5N9"!T:&%T($-Y<G5S(&%U=&AE;G1I8V%T97,@86=A:6YS
M="X*("`@("`J"B`@("`@*B!`=F%R($%U=&@*("`@("`J+PH@("`@('9A<B`D
M7V)A8VME;F0["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL
M:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@
M("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S
M;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@=')U
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@
M("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R
M97-E='!A<W-W;W)D)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=R;W5P<R<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A
M;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R
M=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]C>7)U<R@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["@H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<V5P87)A=&]R)UT@/2`G
M+B<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A
M;7-;)W5N:7AH:65R)UTI("8F("1T:&ES+3Y?<&%R86US6R=U;FEX:&EE<B==
M(#T]('1R=64I('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-E<&%R
M871O<B==(#T@)R\G.PH@("`@("`@('T*"B`@("`@("`@:68@*"%5=&EL.CIE
M>'1E;G-I;VY%>&ES=',H)VEM87`G*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B075T:%]C>7)U<SH@4F5Q=6ER960@:6UA<"!E>'1E;G-I;VX@
M;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@0W)E871E(&)A8VME;F0@:6YS=&%N8V4N"B`@("`@("`@
M)'1H:7,M/E]B86-K96YD(#T@)D%U=&@Z.G-I;F=L971O;B@D=&AI<RT^7W!A
M<F%M<ULG8F%C:V5N9"==6R=D<FEV97(G72P@)'1H:7,M/E]P87)A;7-;)V)A
M8VME;F0G75LG<&%R86US)UTI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M8F%C:V5N9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]B86-K96YD.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@
M=&AE(&-A<&%B:6QI=&EE<R!O9B!T:&4@8F%C:V5N9"X*("`@("`@("!I9B`H
M(21T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G861D)RD@?'P*("`@
M("`@("`@("`@(21T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G=7!D
M871E)RD@?'P*("`@("`@("`@("`@(21T:&ES+3Y?8F%C:V5N9"T^:&%S0V%P
M86)I;&ET>2@G<F5M;W9E)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L
M*%\H(D%U=&A?8WER=7,Z($)A8VME;F0@9&]E<R!N;W0@:&%V92!R97%U:7)E
M9"!C87!A8FEL:71E<RXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)VQI<W0G72`]("1T
M:&ES+3Y?8F%C:V5N9"T^:&%S0V%P86)I;&ET>2@G;&ES="<I.PH@("`@("`@
M("1T:&ES+3YC87!A8FEL:71I97-;)V=R;W5P<R==(#T@)'1H:7,M/E]B86-K
M96YD+3YH87-#87!A8FEL:71Y*"=G<F]U<',G*3L*("`@("`@("`D=&AI<RT^
M8V%P86)I;&ET:65S6R=T<F%N<W!A<F5N="==(#T@)'1H:7,M/E]B86-K96YD
M+3YH87-#87!A8FEL:71Y*"=T<F%N<W!A<F5N="<I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@061D(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I
M86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@
M("!4:&4@=7-E<DED('1O(&%D9"X*("`@("`J($!P87)A;2!A<G)A>2`@)&-R
M961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@861D+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/E]B
M86-K96YD+3YA9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L<RD["B`@("`@
M("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1N86UE(#T@:6UA
M<%]U=&8W7V5N8V]D92@D=7-E<DED*3L*("`@("`@("!I9B`H0&EM87!?8W)E
M871E;6%I;&)O>"@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6UA<%]U=&8W7V5N8V]D92@D=&AI<RT^7W!A
M<F%M<ULG:6UA<%]D<VXG72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5S97(G("X@)'1H:7,M/E]P87)A;7-;)W-E<&%R871O<B==("X@
M)&YA;64I*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A
M;7-;)V9O;&1E<G,G72D@)B8@:7-?87)R87DH)'1H:7,M/E]P87)A;7-;)V9O
M;&1E<G,G72DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?
M<&%R86US6R=F;VQD97)S)UT@87,@)&9O;&1E<BD@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8W)E871E4W5B1F]L9&5R*"1N86UE+"`D9F]L9&5R
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=)34%0(&UA
M:6QB;W@@8W)E871I;VX@9F]R("<@+B`D;F%M92`N("<@9F%I;&5D("<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I
M;&5D.B`E<R(I+"!I;6%P7VQA<W1?97)R;W(H*2DI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=Q=6]T82==*2`F)B`D
M=&AI<RT^7W!A<F%M<ULG<75O=&$G72`^/2`P*2!["B`@("`@("`@("`@(&EF
M("@A0&EM87!?<V5T7W%U;W1A*"1T:&ES+3Y?:6UA<%-T<F5A;2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5S97(G("X@)'1H:7,M/E]S
M97!A<F%T;W(@+B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W%U;W1A)UTI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-05`@
M;6%I;&)O>"!Q=6]T82!C<F5A=&EO;B!F86EL960Z("5S(BDL(&EM87!?;&%S
M=%]E<G)O<B@I*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@
M<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE
M=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("!3=6-C
M97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S
M97(H)'5S97))9"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*
M"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8F%C:V5N9"T^<F5M;W9E57-E<B@D
M=7-E<DED*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4V5T($%#3"!F;W(@;6%I;&)O>"!D96QE=&EO;BX@*B\*("`@("`@
M("!L:7-T*"1A9&UI;BD@/2!E>'!L;V1E*"=`)RP@)'1H:7,M/E]P87)A;7-;
M)V-Y<F%D;6EN)UTI.PH@("`@("`@($!I;6%P7W-E=&%C;"@D=&AI<RT^7VEM
M87!3=')E86TL"B`@("`@("`@("`@("`@("`@("`@("=U<V5R)R`N("1T:&ES
M+3Y?<&%R86US6R=S97!A<F%T;W(G72`N("1U<V5R260L"B`@("`@("`@("`@
M("`@("`@("`@("1A9&UI;BP@)VQR<W=I<&-D82<I.PH*("`@("`@("`O*B!$
M96QE=&4@24U!4"!M86EL8F]X+B`J+PH@("`@("`@("1I;6%P<F5S=6QT(#T@
M0&EM87!?9&5L971E;6%I;&)O>"@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=I;6%P7V1S;B==("X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W5S97(G("X@)'1H:7,M/E]P87)A;7-;)W-E
M<&%R871O<B==("X@)'5S97))9"D["@H@("`@("`@(&EF("@A)&EM87!R97-U
M;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*"))34%0(&UA:6QB;W@@9&5L971I;VX@9F%I;&5D.B`E<R(I+"!I
M;6%P7VQA<W1?97)R;W(H*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@8V]N;F5C=&EO;G,@=&\@=&AE
M(%-13"!A;F0@24U!4"!S97)V97)S+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@("!I
M9B`H(21T:&ES+3Y?8V]N;F5C=&5D*2!["@H@("`@("`@("`@("`D=&AI<RT^
M7VEM87!3=')E86T@/2!`:6UA<%]O<&5N*"1T:&ES+3Y?<&%R86US6R=I;6%P
M7V1S;B==+"`D=&AI<RT^7W!A<F%M<ULG8WER861M:6XG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG8WER<&%S<R==+"!/4%](04Q&3U!%3BD["@H@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?:6UA<%-T<F5A;2D@>PH@("`@("`@("`@("`@("`@2&]R
M9&4Z.F9A=&%L*'-P<FEN=&8H7R@B0V%N)W0@8V]N;F5C="!T;R!)34%0('-E
M<G9E<CH@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EM87!?;&%S=%]E<G)O<B@I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@
M/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@=&AE($E-05`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@
M("`@("`@($!I;6%P7V-L;W-E*"1T:&ES+3Y?:6UA<%-T<F5A;2D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@82!M86EL8F]X97,@<W5P<&QI960@:6X@8V]N9FEG=7)A
M=&EO;@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97).86UE("`@1F]R('=H;VT@=&AE(&9O
M;&1E<B!W:6QL(&)E(&-R96%T960*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M;&1E<DYA;64@3F%M92!O9B!F;VQD97(@=&\@8W)E871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C<F5A=&53=6)&;VQD97(H)'5S97).86UE+"`D9F]L9&5R
M3F%M92D*("`@('L*("`@("`@("`@0&EM87!?8W)E871E;6%I;&)O>"@D=&AI
M<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;6%P7W5T9C=?96YC;V1E*"1T:&ES+3Y?<&%R86US6R=I;6%P7V1S;B==("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R)R`N("1T:&ES+3Y?
M<&%R86US6R=S97!A<F%T;W(G72`N("1U<V5R3F%M92`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<V5P
M87)A=&]R)UT@+B`D9F]L9&5R3F%M92DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@;W(@9F%L
M<V4@;VX@9F%I;'5R92]U;G-U<'!O<G1E9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B
M86-K96YD+3YL:7-T57-E<G,H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%5P
M9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@("!4:&4@;VQD
M('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$("`@("`@(%1H
M92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T955S97(H
M)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]B86-K96YD+3YU<&1A=&55<V5R*"1O;&1)1"P@)&YE
M=TE$+"`D8W)E9&5N=&EA;',I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!54DD@;V8@=&AE(&QO9VEN('-C<F5E;B!F;W(@=&AI<R!A=71H
M96YT:6-A=&EO;B!M971H;V0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("!4:&4@87!P
M;&EC871I;VX@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("!4
M:&4@55),('1O(')E9&ER96-T('1O(&%F=&5R(&QO9VEN+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@;&]G:6X@<V-R965N(%5222X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=$QO9VEN4V-R965N*"1A<'`@/2`G:&]R
M9&4G+"`D=7)L(#T@)R<I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M8F%C:V5N9"T^7V=E=$QO9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&$@=7-E<DED(&5X:7-T<R!I;B!T
M:&4@<VES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE
M=&AE<B!O<B!N;W0@=&AE('5S97))9"!A;')E861Y(&5X:7-T<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@97AI<W1S*"1U<V5R260I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8F%C:V5N9"T^97AI<W1S*"1U<V5R260I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!&
M:6YD(&]U="!I9B!T:&4@8VQI96YT(&UA=&-H97,@86X@86QL;W=E9"!)4`H@
M("`@("H@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7
M:&5T:&5R(&]R(&YO="!T:&4@8VQI96YT(&ES(&%L;&]W960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('1R86YS<&%R96YT*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]B86-K96YD+3YT<F%N<W!A<F5N="@I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+U-I
M9VYU<"YP:'``````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R
M,C0P,"`Q,#4Q-30S-#$T,"`P,C(R,30`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R
M9&4O1&%T851R964N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PH*
M+RHJ"B`J($%U=&A?4VEG;G5P.CH@5&AI<R!C;&%S<R!P<F]V:61E<R!A;B!I
M;G1E<F9A8V4@=&\@<VEG;B!U<"!O<B!H879E"B`J(&YE=R!U<V5R<R!S:6=N
M('1H96US96QV97,@=7`@:6YT;R!T:&4@:&]R9&4@:6YS=&%L;&%T:6]N+"!D
M97!E;F1I;F<*("H@;VX@:&]W('1H92!A9&UI;B!H87,@8V]N9FEG=7)E9"!(
M;W)D92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+U-I9VYU
M<"YP:'`L=B`Q+C,X+C(N,3$@,C`P-B\P."\Q-"`P,CHT.#HT."!C:'5C:R!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA<FMO($1J=6MI8R`\
M;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]3
M:6=N=7`@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T;R!A($1A=&%4<F5E
M(&EN<W1A;F-E('1O(&UA;F%G92]S=&]R92!S:6=N=7!S"B`@("`@*@H@("`@
M("H@0'9A<B!$871A5')E90H@("`@("HO"B`@("!V87(@)%]D871A=')E93L*
M"B`@("!F=6YC=&EO;B!!=71H7U-I9VYU<"@I"B`@("!["B`@("`@("`@9VQO
M8F%L("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH)&-O;F9;)V1A=&%T<F5E
M)UU;)V1R:79E<B==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B
M66]U(&UU<W0@8V]N9FEG=7)E(&$@1&%T851R964@8F%C:V5N9"!T;R!U<V4@
M4VEG;G5P<RXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@
M("`@("`@)&1R:79E<B`]("1C;VYF6R=D871A=')E92==6R=D<FEV97(G73L*
M("`@("`@("`D=&AI<RT^7V1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS:6YG;&5T
M;VXH)&1R:79E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87E?;65R9V4H2&]R9&4Z.F=E=$1R:79E<D-O
M;F9I9R@G9&%T871R964G+"`D9')I=F5R*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V=R;W5P)R`]/B`G:&]R9&4N<VEG;G5P)RDI*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A
M(&-O;F-R971E($%U=&A?4VEG;G5P"B`@("`@*B!I;G-T86YC92X@270@=VEL
M;"!O;FQY(&-R96%T92!A(&YE=R!I;G-T86YC92!I9B!N;R!!=71H7U-I9VYU
M<`H@("`@("H@:6YS=&%N8V4@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F
M075T:%]3:6=N=7`Z.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0')E='5R
M;B!!=71H7U-I9VYU<"`@5&AE(&-O;F-R971E($%U=&A?4VEG;G5P(')E9F5R
M96YC92P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D<VEG;G5P.PH*
M("`@("`@("!I9B`H(6ES<V5T*"1S:6=N=7`I*2!["B`@("`@("`@("`@("1S
M:6=N=7`@/2!N97<@075T:%]3:6=N=7`H*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<VEG;G5P.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A
M(&YE=R!U<V5R('1O('1H92!S>7-T96T@86YD(&AA;F1L97,@86YY(&5X=')A
M(&9I96QD<R!T:&%T(&UA>2!H879E"B`@("`@*B!B965N(&-O;7!I;&5D+"!R
M96QY:6YG(&]N('1H92!H;V]K<RYP:'`@9FEL92X*("`@("`J"B`@("`@*B!`
M<&%R86US(&UI>&5D("1I;F9O("!2969E<F5N8V4@=&\@87)R87D@;V8@<&%R
M86UE=&5R97,@=&\@8F4@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("!T;R!H;V]K"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4$5!
M4E]%<G)O<B!I9B!A;GD@97)R;W)S+"!O=&AE<G=I<V4@=')U92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D4VEG;G5P*"8D:6YF;RD*("`@('L*("`@("`@
M("!G;&]B86P@)&%U=&@L("1C;VYF.PH*("`@("`@("`O+R!097)F;W)M(&%N
M>2!P<F5P<F]C97-S:6YG(&EF(')E<75E<W1E9"X*("`@("`@("!I9B`H)&-O
M;F9;)W-I9VYU<"==6R=P<F5P<F]C97-S)UTI('L*("`@("`@("`@("`@)&EN
M9F\@/2!(;W)D93HZ8V%L;$AO;VLH)U]H;W)D95]H;V]K7W-I9VYU<%]P<F5P
M<F]C97-S)RP@87)R87DH)&EN9F\I*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)&EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D:6YF;SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@
M071T96UP="!T;R!A9&0@=&AE('5S97(@=&\@=&AE('-Y<W1E;2X*("`@("`@
M("`D<W5C8V5S<R`]("1A=71H+3YA9&15<V5R*"1I;F9O6R=U<V5R7VYA;64G
M72P@87)R87DH)W!A<W-W;W)D)R`]/B`D:6YF;ULG<&%S<W=O<F0G72DI.PH@
M("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<W5C8V5S<SL*("`@("`@("!]"@H@("`@("`@
M("\O($%T=&5M<'0@=&\@861D+W5P9&%T92!A;GD@97AT<F$@9&%T82!H86YD
M960@:6XN"B`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG97AT<F$G72DI('L*
M("`@("`@("`@("`@)&%D9&5D(#T@9F%L<V4["B`@("`@("`@("`@("1A9&1E
M9"`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VEG;G5P7V%D9&5X
M=')A)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"1I;F9O6R=U<V5R7VYA;64G72P@)&EN9F];)V5X=')A)UTI*3L*("`@
M("`@("`@("`@:68@*"$D861D960@?'P@:7-?82@D861D960L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1A
M9&1E9"P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%34521RD["B`@
M("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B56YA8FQE('1O(&%D9"!E
M>'1R82!U<V5R(&EN9F]R;6%T:6]N('=H96X@<VEG;FEN9R!U<"XB*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=65U
M97,@=&AE('5S97(G<R!S=6)M:71T960@<F5G:7-T<F%T:6]N(&EN9F\@9F]R
M(&QA=&5R(&%D;6EN(&%P<')O=F%L+@H@("`@("H*("`@("`J($!P87)A;7,@
M;6EX960@)&EN9F\@(%)E9F5R96YC92!T;R!A<G)A>2!O9B!P87)A;65T97)E
M<R!T;R!B92!P87-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@('1O
M(&AO;VL*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!014%27T5R<F]R
M(&EF(&%N>2!E<G)O<G,L(&]T:&5R=VES92!T<G5E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F<75E=653:6=N=7`H)B1I;F9O*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D875T:"PD8V]N9CL*"B`@("`@("`@+R\@4&5R9F]R;2!A;GD@<')E
M<')O8V5S<VEN9R!I9B!R97%U97-T960N"B`@("`@("`@:68@*"1C;VYF6R=S
M:6=N=7`G75LG<')E<')O8V5S<R==*2!["B`@("`@("`@("`@("1I;F9O(#T@
M2&]R9&4Z.F-A;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:6=N=7!?<')E<')O8V5S
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"1I;F9O*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;F9O+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&EN9F\["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($-H96-K('1O('-E92!I
M9B!T:&4@=7-E<FYA;64@86QR96%D>2!E>&ES=',N"B`@("`@("`@:68@*"1A
M=71H+3YE>&ES=',H)&EN9F];)W5S97)?;F%M92==*2!\?`H@("`@("`@("`@
M("`D=&AI<RT^7V1A=&%T<F5E+3YE>&ES=',H)&EN9F];)W5S97)?;F%M92==
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E5S97)N86UE(%PB)7-<(B!A;')E861Y(&5X:7-T<RXB*2P@)&EN
M9F];)W5S97)?;F%M92==*2D["B`@("`@("`@?0H*("`@("`@("`O+R!)9B!I
M="=S(&$@=6YI<75E('5S97)N86UE+"!G;R!A:&5A9"!A;F0@<75E=64@=&AE
M(')E<75E<W0N"B`@("`@("`@)'-I9VYU<"`]("1T:&ES+3YN97=3:6=N=7`H
M)&EN9F];)W5S97)?;F%M92==*3L*("`@("`@("!I9B`H(65M<'1Y*"1I;F9O
M6R=E>'1R82==*2D@>PH@("`@("`@("`@("`D<VEG;G5P+3YD871A(#T@87)R
M87E?;65R9V4H)&EN9F];)V5X=')A)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^("1I;F9O
M6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1A=&5296-E:79E9"<@/3X@=&EM92@I*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-I9VYU<"T^9&%T82`](&%R
M<F%Y*"=P87-S=V]R9"<@/3X@)&EN9F];)W!A<W-W;W)D)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&%T95)E8V5I=F5D)R`]/B!T
M:6UE*"DI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1C;VYF6R=S:6=N=7`G
M75LG<75E=64G72D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@2&]R9&4Z.F-A
M;&Q(;V]K*"=?:&]R9&5?:&]O:U]S:6=N=7!?<75E=65D)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@D:6YF;ULG=7-E
M<E]N86UE)UTL("1I;F9O*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D871A=')E92T^861D*"1S:6=N=7`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@=7-E<B=S('%U975E9"!S:6=N=7`@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA;64@
M(%1H92!U<V5R;F%M92!T;R!R971R:65V92!T:&4@<75E=65D(&EN9F\@9F]R
M+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R965/8FIE8W1?4VEG;G5P
M("!4:&4@1&%T851R965/8FIE8W0@9F]R('1H92!R97%U97-T960*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S:6=N=7`N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%%U975E9%-I9VYU<"@D=7-E<FYA;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=$]B:F5C
M="@D=7-E<FYA;64L("=$871A5')E94]B:F5C=%]3:6=N=7`G*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@<75E=65D(&EN9F]R;6%T:6]N(&9O
M<B!A;&P@<&5N9&EN9R!S:6=N=7!S+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@($%N(&%R<F%Y(&]F($1A=&%4<F5E3V)J96-T7U-I9VYU<"!O8FIE
M8W1S+"!O;F4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("!E86-H('-I9VYU
M<"!I;B!T:&4@<75E=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%%U975E
M9%-I9VYU<',H*0H@("`@>PH@("`@("`@("1S:6=N=7!S(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7V1A=&%T<F5E+3YG970H1$%40512
M145?1D]234%47T9,050L($1!5$%44D5%7U)/3U0L('1R=64I(&%S("1U<V5R
M;F%M92D@>PH@("`@("`@("`@("!I9B`H)'5S97)N86UE("$]($1!5$%44D5%
M7U)/3U0I('L*("`@("`@("`@("`@("`@("1S:6=N=7!S6UT@/2`D=&AI<RT^
M7V1A=&%T<F5E+3YG971/8FIE8W0H)'5S97)N86UE*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'-I9VYU<',["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296UO=F4@82!Q=65U960@<VEG;G5P+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4:&4@=7-E<B!T;R!R
M96UO=F4@9G)O;2!T:&4@<VEG;G5P('%U975E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96UO=F51=65U9613:6=N=7`H)'5S97)N86UE*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?9&%T871R964M/G)E;6]V92@D=7-E<FYA;64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@;F5W('-I9VYU<"!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('-I9VYU
M<',G<R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@1&%T851R965/8FIE
M8W1?4VEG;G5P("!!(&YE=R!S:6=N=7`@;V)J96-T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B`F;F5W4VEG;G5P*"1N86UE*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U-I9VYU<"!N86UE<R!M=7-T(&)E(&YO;BUE;7!T>2<I.PH@("`@
M("`@('T*("`@("`@("`D<VEG;G5P(#T@)FYE=R!$871A5')E94]B:F5C=%]3
M:6=N=7`H)&YA;64I.PH@("`@("`@(')E='5R;B`D<VEG;G5P.PH@("`@?0H*
M?0H*+RHJ"B`J($5X=&5N<VEO;B!O9B!T:&4@1&%T851R965/8FIE8W0@8VQA
M<W,@9F]R('-T;W)I;F<@4VEG;G5P"B`J(&EN9F]R;6%T:6]N(&EN('1H92!$
M871A5')E92!D<FEV97(N($EF('EO=2!W86YT('1O('-T;W)E"B`J('-P96-I
M86QI>F5D(%-I9VYU<"!I;F9O<FUA=&EO;BP@>6]U('-H;W5L9"!E>'1E;F0@
M=&AI<R!C;&%S<PH@*B!I;G-T96%D(&]F(&5X=&5N9&EN9R!$871A5')E94]B
M:F5C="!D:7)E8W1L>2X*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM
M87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T%U=&@*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7U-I9VYU
M<"!E>'1E;F1S($1A=&%4<F5E3V)J96-T('L*"B`@("`O*BH*("`@("`J(%=E
M('=A;G0@=&\@<V5E('%U975E9"!S:6=N=7!S(&EN(&1E<V-E;F1I;F<@;W)D
M97(@;V8@<F5C96EP="X*("`@("`J($EN<V5R="!N97<@<VEG;G5P<R!A="!P
M;W-I=&EO;B`P(&%N9"!P=7-H('1H92!R97-T(&1O=VXN"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D;W)D97(@/2`P.PH*
M("`@("\J*@H@("`@("H@5&AE($1A=&%4<F5E3V)J96-T7U-I9VYU<"!C;VYS
M=')U8W1O<BX@2G5S="!M86ME<R!S=7)E('1O(&-A;&P*("`@("`J('1H92!P
M87)E;G0@8V]N<W1R=6-T;W(@<V\@=&AA="!T:&4@<VEG;G5P)W,@:7,@:7,@
M<V5T"B`@("`@*B!P<F]P97)L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9"`@5&AE(&ED(&]F('1H92!S:6=N=7`N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($1A=&%4<F5E3V)J96-T7U-I9VYU<"@D:60I"B`@("!["B`@("`@
M("`@<&%R96YT.CI$871A5')E94]B:F5C="@D:60I.PH@("`@("`@(&EF("AI
M<U]N=6QL*"1T:&ES+3YD871A*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T
M82`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*?0H*+RHJ"B`J($AO<F1E
M(%-I9VYU<"!&;W)M+"!E>'1E;F1I;F<@;V8@2&]R9&5?1F]R;3HZ"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO
M+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC
M(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($AO<F1E4VEG;G5P1F]R;2!E
M>'1E;F1S($AO<F1E7T9O<FT@>PH*("`@('9A<B`D7W5S949O<FU4;VME;B`]
M('1R=64["@H@("`@9G5N8W1I;VX@2&]R9&53:6=N=7!&;W)M*"8D=F%R<RD*
M("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("!P87)E
M;G0Z.DAO<F1E7T9O<FTH)'9A<G,L('-P<FEN=&8H7R@B)7,@4VEG;B!5<"(I
M+"`D<F5G:7-T<GDM/F=E="@G;F%M92<I*2D["@H@("`@("`@("1T:&ES+3YS
M971"=71T;VYS*%\H(E-I9VX@=7`B*2P@=')U92D["@H@("`@("`@("1T:&ES
M+3YA9&1(:61D96XH)R<L("=U<FPG+"`G=&5X="<L(&9A;'-E*3L*("`@("`@
M("`D=&AI<RT^861D5F%R:6%B;&4H7R@B0VAO;W-E(&$@=7-E<FYA;64B*2P@
M)W5S97)?;F%M92<L("=T97AT)RP@=')U92D["B`@("`@("`@)'1H:7,M/F%D
M9%9A<FEA8FQE*%\H(D-H;V]S92!A('!A<W-W;W)D(BDL("=P87-S=V]R9"<L
M("=P87-S=V]R9&-O;F9I<FTG+"!T<G5E+"!F86QS92P@7R@B='EP92!T:&4@
M<&%S<W=O<F0@='=I8V4@=&\@8V]N9FER;2(I*3L*"B`@("`@("`@+RH@57-E
M(&AO;VMS(&=E="!A;GD@97AT<F$@9FEE;&1S(')E<75I<F5D(&EN('-I9VYI
M;F<@=7`N("HO"B`@("`@("`@)&5X=')A(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?
M:&]R9&5?:&]O:U]S:6=N=7!?9V5T97AT<F$G*3L*("`@("`@("!I9B`H(6ES
M7V$H)&5X=')A+"`G4$5!4E]%<G)O<B<I("8F("%E;7!T>2@D97AT<F$I*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1E>'1R82!A<R`D9FEE;&1?;F%M92`]
M/B`D9FEE;&0I('L*("`@("`@("`@("`@("`@("1R96%D;VYL>2`](&ES<V5T
M*"1F:65L9%LG<F5A9&]N;'DG72D@/R`D9FEE;&1;)W)E861O;FQY)UT@.B!N
M=6QL.PH@("`@("`@("`@("`@("`@)&1E<V,@/2!I<W-E="@D9FEE;&1;)V1E
M<V,G72D@/R`D9FEE;&1;)V1E<V,G72`Z(&YU;&P["B`@("`@("`@("`@("`@
M("`D<F5Q=6ER960@/2!I<W-E="@D9FEE;&1;)W)E<75I<F5D)UTI(#\@)&9I
M96QD6R=R97%U:7)E9"==(#H@9F%L<V4["B`@("`@("`@("`@("`@("`D9FEE
M;&1?<&%R86US(#T@:7-S970H)&9I96QD6R=P87)A;7,G72D@/R`D9FEE;&1;
M)W!A<F%M<R==(#H@87)R87DH*3L*"B`@("`@("`@("`@("`@("`D=&AI<RT^
M861D5F%R:6%B;&4H)&9I96QD6R=L86)E;"==+"`G97AT<F%;)R`N("1F:65L
M9%]N86UE("X@)UTG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F:65L9%LG='EP92==+"`D<F5Q=6ER960L("1R96%D;VYL>2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5S8RP@)&9I96QD
M7W!A<F%M<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O075T:"]I<&UA<"YP:'``````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T-30@,3`U,34T,S0Q-#`@,#(R
M,#8T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VEP
M8F%S:6,N<&AP)SL*"B\J*@H@*B!4:&4@075T:%]I<&UA<"!C;&%S<R!P<F]V
M:61E<R!A8V-E<W,@8V]N=')O;"!B87-E9"!O;B!#2412(&UA<VMS+@H@*@H@
M*B!087)A;65T97)S.@H@*B`@($Y/3D4*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO075T:"]!=71H+VEP;6%P+G!H<"QV(#$N,30N,3`N-B`R,#`V+S`Q+S`Q
M(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D
M95]!=71H"B`J+PIC;&%S<R!!=71H7VEP;6%P(&5X=&5N9',@075T:%]I<&)A
M<VEC('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE
M<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J
M(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A
M<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S
M971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@
M/3X@=')U92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($E0
M+6UA<'!I;F<@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A
M;65T97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VEP;6%P*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T4&%R86US
M*"1P87)A;7,I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H
M+W-A<VPN<&AP````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-C`Q,2`Q,#4Q-30S-#$T,"`P,C$W,3$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H
M7W-A<VPZ.B!C;&%S<R!P<F]V:61E<R!A(%-!4TPM8F%S960@:6UP;&5M96YT
M871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*
M("H*("H@4T%33"!I<R!T:&4@4VEM<&QE($%U=&AE;G1I8V%T:6]N(&%N9"!3
M96-U<FET>2!,87EE<B`H87,@9&5F:6YE9"!B>2!21D,*("H@,C(R,BDN($ET
M('!R;W9I9&5S(&$@<WES=&5M(&9O<B!A9&1I;F<@<&QU9V%B;&4@875T:&5N
M=&EC871I;F<@<W5P<&]R="!T;PH@*B!C;VYN96-T:6]N+6)A<V5D('!R;W1O
M8V]L<RX*("H*("H@5&AI<R!D<FEV97(@<F5L:65S(&]N('1H92!014-,('-A
M<VP@<&%C:V%G93H*("H*("H@("`@("!H='1P.B\O<&5C;"YP:'`N;F5T+W!A
M8VMA9V4O<V%S;`H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J
M("`@)V%P<"<@("`@("!4:&4@;F%M92!O9B!T:&4@875T:&5N=&EC871I;F<@
M87!P;&EC871I;VXN"B`J("`@("`@("`@("`@("!$149!54Q4.B!H;W)D90H@
M*B`@("=S97)V:6-E)R`@5&AE(&YA;64@;V8@=&AE(%-!4TP@<V5R=FEC92!T
M;R!U<V4@=VAE;B!A=71H96YT:6-A=&EN9RX*("H@("`@("`@("`@("`@($1%
M1D%53%0Z('!H<#PO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!
M=71H+T%U=&@O<V%S;"YP:'`L=B`Q+C0N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IO;B!0
M87)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*86X@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T
M:%]S87-L(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A
M>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P
M;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W
M:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@4T%33"!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@075T:%]S87-L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@:68@*"%E
M>'1E;G-I;VY?;&]A9&5D*"=S87-L)RDI('L*("`@("`@("`@("`@9&PH)W-A
M<VPN<V\G*3L*("`@("`@("!]"@H@("`@("`@("1A<'`@/2`H(65M<'1Y*"1P
M87)A;7-;)V%P<"==*2D@/R`D<&%R86US6R=A<'`G72`Z("=H;W)D92<["B`@
M("`@("`@<V%S;%]S97)V97)?:6YI="@D87!P*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS
M(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E
M<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N
M=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N
M=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I
M9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@
M("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R
M($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=S
M87-L)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(E-!4TP@875T
M:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1S97)V:6-E(#T@*"%E;7!T
M>2@D<&%R86US6R=S97)V:6-E)UTI*2`_("1P87)A;7-;)W-E<G9I8V4G72`Z
M("=P:'`G.PH@("`@("`@("1C;VYN(#T@<V%S;%]S97)V97)?;F5W*"1S97)V
M:6-E*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1C;VYN*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ9F%T86PH7R@B1F%I;&5D('1O(&-R96%T92!N97<@
M4T%33"!C;VYN96-T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%S87-L7V-H96-K<&%S<R@D8V]N;BP@)'5S
M97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!S
M87-L7V5R<F1E=&%I;"@D8V]N;BDI.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T
M:"]C;VUP;W-I=&4N<&AP````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,C$U-#,@,3`U,34T,S0Q-#`@,#(R-S8P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T
M:%]C;VUP;W-I=&4@8VQA<W,@<')O=FED97,@82!W<F%P<&5R(&%R;W5N9`H@
M*B!A<'!L:6-A=&EO;BUP<F]V:61E9"!(;W)D92!A=71H96YT:6-A=&EO;B!W
M:&EC:"!F:71S(&EN<VED92!T:&4*("H@2&]R9&4@075T:#HZ($%022X*("H*
M("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@($YO;F4N/"]P<F4^
M"B`J"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]C;VUP;W-I
M=&4N<&AP+'8@,2XR-BXQ,"XQ,"`R,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L
M87-S($%U=&A?8V]M<&]S:71E(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@
M("`@*B!(87-H(&-O;G1A:6YI;F<@86YY(&EN<W1A;G1I871E9"!D<FEV97)S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M9')I=F5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($-O;7!O<VET92!A=71H96YT:6-A=&EO;B!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN
M:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@075T:%]C;VUP;W-I=&4H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3970@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A
M<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971087)A;7,H)'!A
M<F%M<RD*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2![
M"B`@("`@("`@("`@($AO<F1E.CIF871A;"@G3F\@8V]N9FEG=7)A=&EO;B!I
M;F9O<FUA=&EO;B!S<&5C:69I960@9F]R($-O;7!O<VET92!A=71H96YT:6-A
M=&EO;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!N86UE9"!P87)A;65T97(@9F]R('1H92!C=7)R
M96YT(&%U=&@@9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A<F%M("!4:&4@<&%R86UE=&5R('1O(&9E=&-H+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@<&%R86UE=&5R)W,@=F%L=64N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*("`@('L*("`@("`@
M("!I9B`H*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A
M;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@
M("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD;&]G:6Y?
M9')I=F5R72T^9V5T4&%R86TH)'!A<F%M*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!O=70@
M:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@8VAE8VLN"B`@
M("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@8W)E9&5N=&EA
M;',@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE
M=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N
M=&EA;',I"B`@("!["B`@("`@("`@:68@*"@D875T:%]D<FEV97(@/2!!=71H
M.CI?9V5T1')I=F5R0GE087)A;2@G;&]G:6YS8W)E96Y?<W=I=&-H)RP@)'1H
M:7,M/E]P87)A;7,I*2`F)@H@("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV
M97(H)&%U=&A?9')I=F5R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]D<FEV97)S6R1A=71H7V1R:79E<ETM/F%U=&AE;G1I8V%T92@D=7-E<DED
M+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D875T
M:%]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G=7-E<FYA;65?
M<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,L(&%R<F%Y*"1U<V5R260I*2D@)B8*
M("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1A=71H7V1R:79E<BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD875T:%]D
M<FEV97)=+3YH87-#87!A8FEL:71Y*"=T<F%N<W!A<F5N="<I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?
M1D%)3$5$*3L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!1=65R>2!T:&4@8W5R<F5N="!!=71H(&]B:F5C="!T;R!F:6YD
M(&]U="!I9B!I="!S=7!P;W)T<R!T:&4@9VEV96X*("`@("`J(&-A<&%B:6QI
M='DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%P86)I;&ET>2`@
M5&AE(&-A<&%B:6QI='D@=&\@=&5S="!F;W(N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8V%P86)I;&ET>2!I
M<R!S=7!P;W)T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<T-A<&%B:6QI
M='DH)&-A<&%B:6QI='DI"B`@("!["B`@("`@("`@<W=I=&-H("@D8V%P86)I
M;&ET>2D@>PH@("`@("`@(&-A<V4@)V%D9"<Z"B`@("`@("`@8V%S92`G=7!D
M871E)SH*("`@("`@("!C87-E("=R96UO=F4G.@H@("`@("`@(&-A<V4@)VQI
M<W0G.@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A
M9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&]A
M9$1R:79E<B@D=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UTI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D<FEV97)S6R1T:&ES+3Y?
M<&%R86US6R=A9&UI;E]D<FEV97(G75TM/FAA<T-A<&%B:6QI='DH)&-A<&%B
M:6QI='DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=T<F%N<W!A<F5N="<Z"B`@("`@("`@("`@(&EF
M("@H)&QO9VEN7V1R:79E<B`]($%U=&@Z.E]G971$<FEV97)">5!A<F%M*"=L
M;V=I;G-C<F5E;E]S=VET8V@G+"`D=&AI<RT^7W!A<F%M<RDI("8F"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1R:79E<G-;)&QO
M9VEN7V1R:79E<ETM/FAA<T-A<&%B:6QI='DH)W1R86YS<&%R96YT)RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%U
M=&]M871I8R!A=71H96YT:6-A=&EO;CH@1FEN9"!O=70@:68@=&AE(&-L:65N
M="!M871C:&5S(&%N(&%L;&]W960@25`*("`@("`J(&)L;V-K+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L
M:65N="!I<R!A;&QO=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A
M<F5N="@I"B`@("!["B`@("`@("`@:68@*"@D;&]G:6Y?9')I=F5R(#T@075T
M:#HZ7V=E=$1R:79E<D)Y4&%R86TH)VQO9VEN<V-R965N7W-W:71C:"<L("1T
M:&ES+3Y?<&%R86US*2D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I
M=F5R*"1L;V=I;E]D<FEV97(I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1R:79E<G-;)&QO9VEN7V1R:79E<ETM/G1R86YS<&%R96YT*"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N(&9O
M<B!T:&ES(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A
M<'`@(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E
M96X@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E96XH
M)&%P<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!I9B`H
M*"1L;V=I;E]D<FEV97(@/2!!=71H.CI?9V5T1')I=F5R0GE087)A;2@G;&]G
M:6YS8W)E96Y?<W=I=&-H)RP@)'1H:7,M/E]P87)A;7,I*2`F)@H@("`@("`@
M("`@("`D=&AI<RT^7VQO861$<FEV97(H)&QO9VEN7V1R:79E<BDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD;&]G:6Y?9')I=F5R
M72T^7V=E=$QO9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!P87)E;G0Z.E]G971,;V=I;E-C<F5E
M;B@D87!P+"`D=7)L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U
M<V5R260@=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA
M;',@(%1H92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@("`@("`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UTI("8F
M"B`@("`@("`@("`@("1T:&ES+3Y?;&]A9$1R:79E<B@D=&AI<RT^7W!A<F%M
M<ULG861M:6Y?9')I=F5R)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1R:79E<G-;)'1H:7,M/E]P87)A;7-;)V%D;6EN7V1R:79E<B==72T^
M861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;G-U
M<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5P
M9&%T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1)1"`@("`@("!4:&4@;VQD
M('5S97))9"X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=TE$("`@("`@(%1H
M92!N97<@=7-E<DED+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R`@5&AE(&YE=R!C<F5D96YT:6%L<PH@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('5P9&%T955S97(H
M)&]L9$E$+"`D;F5W240L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I
M9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*
M("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US
M6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YU
M<&1A=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N=&EA;',I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=5;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D96YT
M:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@(%1H
M92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S
M97))9"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D
M1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M
M<ULG861M:6Y?9')I=F5R)UU=+3YR96UO=F55<V5R*"1U<V5R260I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=5;G-U<'!O<G1E9"<I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))9',L(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72D@)B8*("`@("`@("`@
M("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D
M<FEV97(G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R
M<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I=F5R)UU=+3YL:7-T57-E<G,H
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G56YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!U<V5R260@97AI<W1S(&EN('1H
M92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED
M("!5<V5R($E$('1O(&-H96-K"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!7:&5T:&5R(&]R(&YO="!T:&4@=7-E<DED(&%L<F5A9'D@97AI<W1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>&ES=',H)'5S97))9"D*("`@('L*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=A9&UI;E]D<FEV
M97(G72D@)B8*("`@("`@("`@("`@)'1H:7,M/E]L;V%D1')I=F5R*"1T:&ES
M+3Y?<&%R86US6R=A9&UI;E]D<FEV97(G72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9')I=F5R<ULD=&AI<RT^7W!A<F%M<ULG861M:6Y?9')I
M=F5R)UU=+3YE>&ES=',H)'5S97))9"D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D
M)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@;VYE
M(&]F('1H92!D<FEV97)S(&EN(&]U<B!C;VYF:6=U<F%T:6]N(&%R<F%Y+"!I
M9B!I="!I<VXG="!A;')E861Y"B`@("`@*B!L;V%D960N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9')I=F5R("!4:&4@;F%M92!O9B!T:&4@9')I=F5R('1O(&QO860N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N(%1R=64@:68@9')I=F5R('-U
M8V-E<W-F=6QL>2!I;FET:6%L:7IE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VQO861$<FEV97(H)&1R:79E<BD*("`@('L*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=*2D@>PH@("`@("`@("`@("`O+R!4
M:&ES(&ES(&$@8FET('-P96-I86QI>F5D(&9O<B!(;W)D93HZ9V5T1')I=F5R
M0V]N9FEG*"DL"B`@("`@("`@("`@("\O('-O(&QO8V%L:7IE(&ET(&AE<F4Z
M"B`@("`@("`@("`@(&=L;V)A;"`D8V]N9CL*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=P87)A
M;7,G72DI('L*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D=&AI<RT^7W!A
M<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=P87)A;7,G73L*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELD=&AI<RT^7W!A<F%M<ULG9')I=F5R
M<R==6R1D<FEV97)=6R=D<FEV97(G75TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1C;VYF6R1T:&ES+3Y?<&%R86US
M6R=D<FEV97)S)UU;)&1R:79E<EU;)V1R:79E<B==72P@)'!A<F%M<RD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH
M)&-O;F9;)&1R:79E<ETI*2!["B`@("`@("`@("`@("`@("`D<&%R86US(#T@
M)&-O;F9;)&1R:79E<ET["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<&%R86US(#T@;G5L;#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=(#T@)D%U=&@Z.G-I;F=L
M971O;B@D=&AI<RT^7W!A<F%M<ULG9')I=F5R<R==6R1D<FEV97)=6R=D<FEV
M97(G72P@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:7-S
M970H)'1H:7,M/E]D<FEV97)S6R1D<FEV97)=*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]!=71H+V%U=&\N<&AP````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-3,S-R`Q,#4Q-30S-#$T,"`P,C$W,S$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!!=71H7V%U=&\@8VQA<W,@=')A;G-P87)E;G1L>2!L;V=S('5S97)S
M(&EN('1O($AO<F1E('5S:6YG($].10H@*B!U<V5R;F%M92P@96ET:&5R(&1E
M9FEN960@:6X@=&AE(&-O;F9I9R!O<B!D969A=6QT:6YG('1O"B`J("=H;W)D
M95]U<V5R)RX@5&AI<R!I<R!O;FQY(&9O<B!U<V4@:6X@=&5S=&EN9R!O<B!B
M96AI;F0@82!F:7)E=V%L;#L*("H@:70@<VAO=6QD($Y/5"!B92!U<V5D(&]N
M(&$@<'5B;&EC+"!P<F]D=6-T:6]N(&UA8VAI;F4N"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G=7-E<FYA;64G("`@("!4:&4@=7-E
M<FYA;64@=&\@875T:&5N=&EC871E(&5V97)Y;VYE(&%S+@H@*B`@("`@("`@
M("`@("`@("`@($1%1D%53%0Z("=H;W)D95]U<V5R)PH@*B`@("=P87-S=V]R
M9"<@("`@(%1H92!P87-S=V]R9"!T;R!R96-O<F0@:6X@=&AE('5S97(G<R!C
M<F5D96YT:6%L<RX*("H@("`@("`@("`@("`@("`@("!$149!54Q4.B!N;VYE
M"B`J("`@)W)E<75E<W1U<V5R)R`@268@=')U92P@86QL;W<@=7-E<FYA;64@
M=&\@8F4@<&%S<V5D(&)Y($=%5"P@4$]35"!O<@H@*B`@("`@("`@("`@("`@
M("`@(&-O;VMI92X\+W!R93X*("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M075T:"]!=71H+V%U=&\N<&AP+'8@,2XQ,BXT+C@@,C`P-B\P,2\P,2`R,3HR
M.#HP-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?075T
M:`H@*B\*8VQA<W,@075T:%]A=71O(&5X=&5N9',@075T:"!["@H@("`@+RHJ
M"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE
M(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET
M('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A
M<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^
M(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E
M)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^('1R=64I.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!!=71O;6%T:6,@875T:&5N
M=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!!=71H7V%U=&\H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S971087)A;7,H)'!A<F%M<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3970@<&%R86UE=&5R<R!F;W(@=&AE($%U=&A?
M875T;R!O8FIE8W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%!A<F%M971E<G,N
M($YO;F4@8W5R<F5N=&QY(')E<75I<F5D.PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("=U<V5R;F%M92<L("=P87-S=V]R9"<L(&%N9"`G<F5Q=65S
M='5S97(G(&%R92!O<'1I;VYA;"X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=%!A<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'!A
M<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG=7-E
M<FYA;64G72`]("=H;W)D95]U<V5R)SL*("`@("`@("!]"B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@
M075T;VUA=&EC(&%U=&AE;G1I8V%T:6]N.B!3970@=&AE('5S97(@86QL;W=E
M9"!)4"!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H
M971H97(@;W(@;F]T('1H92!C;&EE;G0@:7,@86QL;W=E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=')A;G-P87)E;G0H*0H@("`@>PH@("`@("`@("1U<V5R
M;F%M92`]("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W)E<75E<W1U<V5R)UTI
M("8F(&ES<V5T*"1?4D5154535%LG=7-E<FYA;64G72DI(#\*("`@("`@("`@
M("`@)%]215%515-46R=U<V5R;F%M92==(#H*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W5S97)N86UE)UT["B`@("`@("`@)'1H:7,M/G-E=$%U=&@H
M)'5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T<F%N
M<W!A<F5N="<@/3X@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<&%S<W=O<F0G(#T^(&ES<V5T*"1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M*2`_("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#H@;G5L;"DI.PH@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:'1T<"YP
M:'``````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R,3`W
M(#$P-3$U-#,T,30P(#`R,3<S,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?:'1T<"!C
M;&%S<R!T<F%N<W!A<F5N=&QY(&QO9W,@=7-E<G,@:6X@=&\@2&]R9&4@=7-I
M;F<*("H@86QR96%D>2!P<F5S96YT($A45%`@875T:&5N=&EC871I;VX@:&5A
M9&5R<RX*("H*("H@5&AE("=E;F-R>7!T:6]N)R!P87)A;65T97(@<W!E8VEF
M:65S('=H870@:VEN9"!O9B!P87-S=V]R9',@87)E(&EN"B`J('1H92`N:'1P
M87-S=V0@9FEL92X@5&AE('-U<'!O<G1E9"!O<'1I;VYS(&%R92`G8W)Y<'0M
M9&5S)R`H<W1A;F1A<F0*("H@8W)Y<'1E9"!H='!A<W-W9"!E;G1R:65S*2!A
M;F0@)V%P<FUD-2<N(%1H:7,@:6YF;W)M871I;VX@:7,@=7-E9"!I9@H@*B!Y
M;W4@=V%N="!T;R!D:7)E8W1L>2!A=71H96YT:6-A=&4@=7-E<G,@=VET:"!T
M:&ES(&1R:79E<BP@:6YS=&5A9`H@*B!O9B!R96QY:6YG(&]N('1R86YS<&%R
M96YT(&%U=&@N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]H
M='1P+G!H<"QV(#$N,C$N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S
M<R!!=71H7VAT='`@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N
M(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A
M;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@
M86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G
M("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]
M/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G
M("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=')A;G-P87)E;G0G("`@/3X@=')U92D["@H@("`@+RHJ"B`@("`@
M*B!!<G)A>2!O9B!U<V5R;F%M97,@86YD(&AA<VAE9"!P87-S=V]R9',N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U<V5R
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W
M($A45%`@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!P87)A;65T
M97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VAT='`H)'!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH*("`@("`@("`O+R!$969A=6QT('1O($1%4R!P87-S=V]R9',N"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UT@
M/2`G8W)Y<'0M9&5S)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]P87)A;7-;)VAT<&%S<W=D7V9I;&4G72DI('L*("`@("`@("`@
M("`@)'5S97)S(#T@0&9I;&4H)'1H:7,M/E]P87)A;7-;)VAT<&%S<W=D7V9I
M;&4G72D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=7-E<G,I*2!["B`@
M("`@("`@("`@("`@("`O+R!%;F%B;&4@=&AE(&QI<W0@=7-E<G,@8V%P86)I
M;&ET>2X*("`@("`@("`@("`@("`@("1T:&ES+3YC87!A8FEL:71I97-;)VQI
M<W0G72`]('1R=64["@H@("`@("`@("`@("`@("`@+R\@4'5T('5S97)S(&EN
M=&\@86QP:&%B971I8V%L(&]R9&5R+@H@("`@("`@("`@("`@("`@<V]R="@D
M=7-E<G,I.PH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1U<V5R<R!A<R`D
M;&EN92D@>PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)'5S97(L("1P87-S
M*2`](&5X<&QO9&4H)SHG+"`D;&EN92P@,BD["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]U<V5R<UMT<FEM*"1U<V5R*5T@/2!T<FEM*"1P87-S*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN
M(&-R961E;G1I86QS(&%R92!V86QI9"X@3VYL>2!S=7!P;W)T<PH@("`@("H@
M:'1P87-S=V0@9FEL97,@=VET:"!$15,@<&%S<W=O<F1S(')I9VAT(&YO=RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R260@("`@("`@5&AE('5S97))9"!T;R!C:&5C
M:RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-R961E;G1I86QS("!!;B!A<G)A
M>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($E-05`L"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P
M87-S=V]R9"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%=H971H97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R
M961E;G1I86QS*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D8W)E9&5N=&EA
M;'-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?
M*").;R!P87-S=V]R9"!P<F]V:61E9"!F;W(@2%144"!A=71H96YT:6-A=&EO
M;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7W5S97)S6R1U<V5R261=*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)
M3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1H87-H(#T@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N
M=&EA;'-;)W!A<W-W;W)D)UTL("1T:&ES+3Y?=7-E<G-;)'5S97))9%TL("1T
M:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL("%E;7!T>2@D=&AI<RT^7W!A
M<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*3L*("`@("`@("!I9B`H)&AA<V@@
M/3T@)'1H:7,M/E]U<V5R<ULD=7-E<DED72D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N(&9O<B!T
M:&ES(&%U=&AE;G1I8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@
M(%1H92!A<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<FP@(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@
M55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E96XH)&%P
M<"`]("=H;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=L;V=I;E-C<F5E;B==*2D@>PH@("`@("`@
M("`@("!I9B`H)'5R;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%5T:6PZ
M.F%D9%!A<F%M971E<B@D=&AI<RT^7W!A<F%M<ULG;&]G:6Y38W)E96XG72P@
M)W5R;"<L("1U<FPI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US6R=L;V=I;E-C<F5E;B==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N('!A<F5N=#HZ7V=E=$QO9VEN4V-R965N*"1A<'`L("1U<FPI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN
M('1H92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&%R<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@
M('L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=&AI<RT^7W5S97)S*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%U=&]M871I8R!A=71H96YT:6-A=&EO
M;CH@1FEN9"!O=70@:68@=&AE(&-L:65N="!H87,@2%144`H@("`@("H@875T
M:&5N=&EC871I;VX@:6YF;R!P<F5S96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-L:65N="!I<R!A;&QO
M=V5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!T<F%N<W!A<F5N="@I"B`@("![
M"B`@("`@("`@:68@*"%E;7!T>2@D7U-%4E9%4ELG4$A07T%55$A?55-%4B==
M*2`F)@H@("`@("`@("`@("`A96UP='DH)%]315)615);)U!(4%]!551(7U!7
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971!=71H*%5T:6PZ.F1I<W!E
M;$UA9VEC475O=&5S*"1?4T525D526R=02%!?05542%]54T52)UTI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%S<W=O<F0G(#T^(%5T
M:6PZ.F1I<W!E;$UA9VEC475O=&5S*"1?4T525D526R=02%!?05542%]05R==
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R
M96YT)R`]/B`Q*2D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?
M34534T%'12P@7R@B2%144"!!=71H96YT:6-A=&EO;B!N;W0@9F]U;F0N(BDI
M.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T%U=&@O<VUB+G!H<```````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`W,3(V(#$P-3$U-#,T,30P(#`R,34T,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($%U=&A?<VUB(&-L87-S('!R;W9I9&5S(&%N(%--0B!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@
M<WES=&5M+@H@*@H@*B!4:&ES(&UO9'5L92!R97%U:7)E<R!T:&4@<VUB875T
M:"!E>'1E;G-I;VX@9F]R(%!(4#H*("H@("!H='1P.B\O=W=W+G1E:W)A="YC
M;VTO<VUB875T:"\*("H*("H@070@=&AE('1I;64@;V8@=&AI<R!W<FET:6YG
M+"!T:&4@97AT96YS:6]N+"!A;F0@=&AU<R!T:&ES(&UO9'5L92P@;VYL>0H@
M*B!S=7!P;W)T960@875T:&5N=&EC871I;VX@86=A:6YS="!A(&1O;6%I;BP@
M86YD('!D8R!A;F0@8F1C(&UU<W0@8F4@;F]N+6YU;&P*("H@86YD(&YO="!E
M<75A;"!T;R!E86-H(&]T:&5R+B!);B!O=&AE<B!W;W)D<RP@=&\@=7-E('1H
M:7,@;6]D=6QE('EO=2!M=7-T"B`J(&AA=F4@82!D;VUA:6X@=VET:"!A="!L
M96%S="!O;F4@4$1#(&%N9"!O;F4@0D1#+@H@*@H@*B!297%U:7)E9"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@25`L($1.4R!.86UE+"!O
M<B!.971":6]S($YA;64@;V8@=&AE(%--0B!S97)V97(@=&\*("H@("`@("`@
M("`@("`@("!A=71H96YT:6-A=&4@=VET:"X*("H@("`G9&]M86EN)R`@("!4
M:&4@9&]M86EN(&YA;64@=&\@875T:&5N=&EC871E('=I=&@N/"]P<F4^"B`J
M"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G9W)O=7`G("`@
M("!'<F]U<"!N86UE('1H870@=&AE('5S97(@;75S="!B92!A(&UE;6)E<B!O
M9BX@5VEL;"!B90H@*B`@("`@("`@("`@("`@(&EG;F]R960@:68@=&AE('9A
M;'5E('!A<W-E9"!I<R!A('IE<F\@;&5N9W1H('-T<FEN9RX\+W!R93X*("H*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W-M8BYP:'`L=B`Q
M+C(P+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA<F-U<R!)+B!2>6%N(#QM87)C
M=7-`<FEB;V9L879I;BYN970^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-87)C
M=7,@22X@4GEA;B`\;6%R8W5S0')I8F]F;&%V:6XN;F5T/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@
M075T:%]S;6(@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R
M<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R
M97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD
M('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!334(@875T:&5N=&EC871I;VX@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($%U=&A?<VUB*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=S;6)A=71H)RDI('L*
M("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?<VUB875T:#H@4F5Q
M=6ER960@<VUB875T:"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+RH@16YS=7)E('=E
M)W9E(&)E96X@<')O=FED960@=VET:"!A;&P@;V8@=&AE(&YE8V5S<V%R>2!P
M87)A;65T97)S+B`J+PH@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV97)#;VYF
M:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("!A<G)A>2@G:&]S='-P
M96,G+"`G9&]M86EN)RDL"B`@("`@("`@("`@("=A=71H96YT:6-A=&EO;B!3
M86UB82<I.PH*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!T:&4@9VEV96X@<V5T
M(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E
M9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L
M("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E
M;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R(%--0B!A=71H96YT:6-A
M=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@("\J($%U=&AE;G1I8V%T92X@*B\*("`@("`@("`D<G9A;"`]('9A;&ED
M871E*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1O;6%I;B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P87)A;7-;)V=R;W5P
M)UTI(#\@)R<@.B`D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1U<V5R260L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTI.PH*("`@("`@("!I9B`H
M)')V86P@/3T](#`I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1R=F%L(#T]/2`Q*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/
M3E]-15-304=%+"!?*")&86EL960@=&\@8V]N;F5C="!T;R!334(@<V5R=F5R
M+B(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(&5R<C)S
M='(H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O;&]G:6XN<&AP
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-C(W(#$P
M-3$U-#,T,30P(#`R,C`W,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($%U=&A?;&]G:6XZ.B!C
M;&%S<R!P<F]V:61E<R!A('-Y<W1E;2!L;V=I;B!I;7!L96UE;G1A=&EO;B!O
M9@H@*B!T:&4@2&]R9&4@875T:&5N=&EC871I;VX@<WES=&5M+@H@*B!4:&ES
M($%U=&@@9')I=F5R(&ES('5S969U;"!I9B!Y;W4@:&%V92!A('-H861O=R!P
M87-S=V]R9"!S>7-T96T*("H@=VAE<F4@=&AE($%U=&A?<&%S<W=D(&1R:79E
M<B!D;V5S;B=T('=O<FLN"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R
M93X*("H@("`G;&]C871I;VXG("!,;V-A=&EO;B!O9B!T:&4@<W4@8FEN87)Y
M+@H@*B`@("`@("`@("`@("`@($1%1D%53%0Z("]B:6XO<W4\+W!R93X*("H*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VQO9VEN+G!H<"QV
M(#$N,RXQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`
M<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VQO9VEN(&5X=&5N
M9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL
M:71I97,L('-O('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@
M("`@*B!O<&5R871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S
M;B=T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1C87!A8FEL:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT
M)R`@(#T^(&9A;'-E*3L*"B`@("`O*BH*("`@("`J('-U(&)I;F%R>2X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]L;V-A
M=&EO;B`]("<O8FEN+W-U)SL*"B`@("`O*BH*("`@("`J($QI<W0@;V8@=7-E
M<G,@=&AA="!S:&]U;&0@8F4@97AC;'5D960@9G)O;2!B96EN9R!L:7-T960O
M:&%N9&QE9`H@("`@("H@:6X@86YY('=A>2!B>2!T:&ES(&1R:79E<BX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5X8VQU
M9&4@/2!A<G)A>2@G<F]O="<L("=D865M;VXG+"`G8FEN)RP@)W-Y<R<L("=S
M>6YC)RP@)V=A;65S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`G;6%N
M)RP@)VQP)RP@)VUA:6PG+"`G;F5W<R<L("=U=6-P)RP@)W!R;WAY)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<&]S=&=R97,G+"`G=W=W+61A=&$G
M+"`G8F%C:W5P)RP@)V]P97)A=&]R)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;&ES="<L("=I<F,G+"`G9VYA=',G+"`G;F]B;V1Y)RP@)VED96YT
M9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)W-S:&0G+"`G9V1M)RP@
M)W!O<W1F:7@G+"`G;7ES<6PG+"`G8WER=7,G+"`G9G1P)RD["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($QO9VEN(&%U=&AE;G1I8V%T:6]N
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!!=71H7VQO9VEN*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@
M("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)VQO8V%T:6]N)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D<&%R86US6R=L;V-A=&EO;B==
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF
M(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G
M:6X@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C
M<F5D96YT:6%L<RD*("`@('L*("`@("`@("!I9B`H96UP='DH)&-R961E;G1I
M86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH
M7R@B3F\@<&%S<W=O<F0@<')O=FED960@9F]R($QO9VEN(&%U=&AE;G1I8V%T
M:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)'!R;V,@/2!P;W!E;B@D=&AI<RT^7VQO8V%T:6]N("X@)R`M8R`O8FEN
M+W1R=64@)R`N("1U<V5R260L("=W)RD["B`@("`@("`@:68@*"%I<U]R97-O
M=7)C92@D<')O8RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@("`@("!F=W)I=&4H)'!R;V,L("1C<F5D96YT:6%L<ULG<&%S
M<W=O<F0G72D["@H@("`@("`@(')E='5R;B!P8VQO<V4H)'!R;V,I(#T]/2`P
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O075T:"]C=7-T;VUS<6PN<&AP````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,C,W-C`@,3`U,34T,S0Q-#`@,#(S,#$S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-Q;"YP
M:'`G.PH*+RHJ"B`J(%1H92!!=71H7V-U<W1O;7-Q;"!C;&%S<R!P<F]V:61E
M<R!A('-Q;"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N
M=&EC871I;VX@<WES=&5M('=I=&@@=&AE('!O<W-I8FEL:71Y('1O('-E="!C
M=7-T;VTM;6%D92!Q=65R:65S+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)W!H<'1Y<&4G("!4:&4@9&%T86)A<V4@='EP92`H:64N
M("=P9W-Q;"<L("=M>7-Q;"<L(&5T8RXI+CPO<')E/@H@*@H@*B!297%U:7)E
M9"!P87)A;65T97)S.B`H0W5S=&]M('%U97)Y*3QP<F4^"B`J(%-O;64@<W!E
M8VEA;"!T;VME;G,@8V%N(&)E('5S960@:6X@=&AE('-Q;"!Q=65R>2X@5&AE
M>2!A<F4@<F5P;&%C960*("H@870@=&AE('%U97)Y('-T86=E.@H@*@H@*B`@
M("T@)UQ,)R!W:6QL(&)E(')E<&QA8V5D(&)Y('1H92!U<V5R)W,@;&]G:6X*
M("H@("`M("=<4"<@=VEL;"!B92!R97!L86-E9"!B>2!T:&4@=7-E<B=S('!A
M<W-W;W)D+@H@*B`@("T@)UQ/)R!W:6QL(&)E(')E<&QA8V5D(&)Y('1H92!O
M;&0@=7-E<B=S(&QO9VEN("AR97%U:7)E9"!F;W(@=7!D871E*0H@*@H@*B`@
M($5G.B`B4T5,14-4("H@1E)/32!U<V5R<R!72$5212!U:60@/2!<3`H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@<&%S<W=D(#T@7%`*("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$(&)I;&QI;F<@/2`G<&%I
M9"<*("H*("H@("`G<75E<GE?875T:"<@("`@075T:&5N=&EC871E('1H92!U
M<V5R+B`@("`@("`G7$PG("8@)UQ.)PH@*B`@("=Q=65R>5]A9&0G("`@("!!
M9&0@=7-E<BX@("`@("`@("`@("`@("`@("`@("=<3"<@)B`G7$XG"B`J("`@
M)W%U97)Y7W5P9&%T92<@(%5P9&%T92!U<V5R+B`@("`@("`@("`@("`@("`@
M)UQ/)RP@)UQ,)R`F("=<3B<*("H@("`G<75E<GE?<F5S971P87-S=V]R9"<@
M(%)E<V5T('!A<W-W;W)D+B`@("`@("`G7$PG+"`F("=<4"<*("H@("`G<75E
M<GE?<F5M;W9E)R`@4F5M;W9E('5S97(N("`@("`@("`@("`@("`@("`G7$PG
M"B`J("`@)W%U97)Y7VQI<W0G("`@($QI<W0@=7-E<BX@("`@("`@("`@("`@
M("`@("`@)UQ,)SPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP
M<F4^"B`J("`@)V5N8W)Y<'1I;VXG("`@("`@(%1H92!E;F-R>7!T:6]N('1O
M('5S92!T;R!S=&]R92!T:&4@<&%S<W=O<F0@:6X@=&AE"B`J("`@("`@("`@
M("`@("`@("`@("`@('1A8FQE("AE+F<N('!L86EN+"!C<GEP="P@;60U+6AE
M>"P@;60U+6)A<V4V-"P@<VUD-2P*("H@("`@("`@("`@("`@("`@("`@("`@
M<VAA+"!S<VAA*2X*("H@("`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@
M)VUD-2UH97@G"B`J("`@)W-H;W=?96YC<GEP=&EO;B<@(%=H971H97(@;W(@
M;F]T('1O('!R97!E;F0@=&AE(&5N8W)Y<'1I;VX@:6X@=&AE"B`J("`@("`@
M("`@("`@("`@("`@("`@('!A<W-W;W)D(&9I96QD+@H@*B`@("`@("`@("`@
M("`@("`@("`@("!$149!54Q4.B`G9F%L<V4G/"]P<F4^"B`J"B`J(%)E<75I
M<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J
M("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S92!S
M97)V97(N"B`J("`@)W!R;W1O8V]L)R`@5&AE(&-O;6UU;FEC871I;VX@<')O
M=&]C;VP@*"=T8W`G+"`G=6YI>"<L(&5T8RXI+@H@*B`@("=D871A8F%S92<@
M(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`G=7-E<FYA;64G("!4
M:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A
M8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S;V-I871E
M9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G("`@061D:71I;VYA
M;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T
M)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H92!45%D@;VX@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T%U=&@O075T:"]C=7-T;VUS<6PN<&AP+'8@,2XQ-BXQ
M,"XX(#(P,#4O,3$O,S`@,#`Z,#,Z,SD@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`R(%)O;FYI92!'87)C:6$@/')O;FYI94!M:S(N;F5T/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]N;FEE($=A<F-I82`\<F]N;FEE
M0&UK,BYN970^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!*;V5L(%9A;F1A;"`\:G9A;F1A;$!I
M;F9O=&5C:RYQ8RYC83X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K
M86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?8W5S=&]M<W%L(&5X=&5N
M9',@075T:%]S<6P@>PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@8V%P
M86)I;&ET:65S+"!S;R!T:&%T('1H92!D<FEV97(@8V%N(')E<&]R="!W:&EC
M:`H@("`@("H@;W!E<F%T:6]N<R!I="!S=7!P;W)T<R!A;F0@=VAI8V@@:70@
M9&]E<VXG="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D8V%P86)I;&ET:65S(#T@87)R87DH)V%D9"<@("`@("`@("`@(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G
M("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5S971P87-S=V]R9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E;6]V92<@("`@("`@(#T^('1R=64L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!T<G5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G
M("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!344P@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T
M:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?8W5S
M=&]M<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?<&%R86US(#T@)'!A<F%M<SL*"B`@("`@("`@2&]R9&4Z.F%S<V5R=$1R
M:79E<D-O;F9I9R@D<&%R86US+"`G875T:"<L"B`@("`@("`@("`@(&%R<F%Y
M*"=Q=65R>5]A=71H)RDL"B`@("`@("`@("`@("=A=71H96YT:6-A=&EO;B!C
M=7-T;VT@4U%,)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I
M9B!A('-E="!O9B!L;V=I;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7-E<DED("`@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@
M("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L
M<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T
M:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT
M:6%L<RD*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I
M=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T
M:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&-U<W1O;2!Q
M=65R>2P@8F%S960@;VX@=&AE(&-O;F9I9R!F:6QE+B`J+PH@("`@("`@("1Q
M=65R>2`]("1T:&ES+3Y?<&%R86US6R=Q=65R>5]A=71H)UT["B`@("`@("`@
M)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ,)RP@)'1H:7,M/E]D8BT^<75O=&4H
M)'5S97))9"DL("1Q=65R>2D["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA
M8V4H)UQ0)RP@)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/F=E=$-R>7!T9610
M87-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A<W-W;W)D)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI*2P@)'%U97)Y*3L*"B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@
M:68@*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T=%5$U/1$5?05-33T,I
M.PH@("`@("`@("`@("`O*B!)9B!W92!H879E(&%T(&QE87-T(&]N92!R971U
M<FYE9"!R;W<L('1H96X@=&AE('5S97(@:7,*("`@("`@("`@("`@("H@=F%L
M:60N("HO"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@
M("`@("`@("`@("`@)')E<W5L="T^9G)E92@I.PH@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(
M7U)%05-/3E]&04E,140I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@<V5T(&]F(&%U
M=&AE;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U<V5R260@=&\@861D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS
M('1O(&%D9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R260L("1C<F5D96YT
M:6%L<RD*("`@('L*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@
M("`@+RH@0G5I;&0@82!C=7-T;VT@<75E<GDL(&)A<V5D(&]N('1H92!C;VYF
M:6<@9FEL92X@*B\*("`@("`@("`D<75E<GD@/2`D=&AI<RT^7W!A<F%M<ULG
M<75E<GE?861D)UT["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ,
M)RP@)'1H:7,M/E]D8BT^<75O=&4H)'5S97))9"DL("1Q=65R>2D["B`@("`@
M("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ0)RP@)'1H:7,M/E]D8BT^<75O
M=&4H)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;)W!A
M<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<VAO=U]E;F-R>7!T:6]N)UTI
M*2P@)'%U97)Y*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U
M97)Y*"1Q=65R>2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@57!D871E(&$@<V5T(&]F(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9$E$("`@("`@(%1H
M92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W240@("`@
M("`@5&AE(&YE=R!U<V5R260N"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E
M;G1I86QS("!4:&4@;F5W(&-R961E;G1I86QS"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E
M57-E<B@D;VQD240L("1N97=)1"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@
M("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T86PH
M*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D[
M"@H@("`@("`@("\J($)U:6QD(&$@8W5S=&]M('%U97)Y+"!B87-E9"!O;B!T
M:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]P
M87)A;7-;)W%U97)Y7W5P9&%T92==.PH@("`@("`@("1Q=65R>2`]('-T<E]R
M97!L86-E*"=<3R<L("1T:&ES+3Y?9&(M/G%U;W1E*"1O;&1)1"DL("1Q=65R
M>2D["B`@("`@("`@)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ,)RP@)'1H:7,M
M/E]D8BT^<75O=&4H)&YE=TE$*2P@)'%U97)Y*3L*("`@("`@("`D<75E<GD@
M/2!S=')?<F5P;&%C92@G7%`G+"`D=&AI<RT^7V1B+3YQ=6]T92@D=&AI<RT^
M9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V5N
M8W)Y<'1I;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI+"`D<75E<GDI
M.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E=',@
M82!U<V5R)W,@<&%S<W=O<F0N(%5S960@9F]R(&5X86UP;&4@=VAE;B!T:&4@
M=7-E<B!D;V5S(&YO=`H@("`@("H@<F5M96UB97(@=&AE(&5X:7-T:6YG('!A
M<W-W;W)D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97)?:60@
M(%1H92!U<V5R(&ED(&9O<B!W:&EC:"!T;R!R97-E="!T:&4@<&%S<W=O<F0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&YE=R!P87-S=V]R
M9"!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX*("`@("`J
M("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<V5T4&%S<W=O<F0H)'5S97)?:60I"B`@("!["B`@("`@("`@+RH@7V-O
M;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I
M;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M+RH@1V5T(&$@;F5W(')A;F1O;2!P87-S=V]R9"X@*B\*("`@("`@("`D<&%S
M<W=O<F0@/2!!=71H.CIG96Y286YD;VU087-S=V]R9"@I.PH*("`@("`@("`O
M*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]("1T
M:&ES+3Y?<&%R86US6R=Q=65R>5]R97-E='!A<W-W;W)D)UT["B`@("`@("`@
M)'%U97)Y(#T@<W1R7W)E<&QA8V4H)UQ,)RP@)'1H:7,M/E]D8BT^<75O=&4H
M)'5S97)?:60I+"`D<75E<GDI.PH@("`@("`@("1Q=65R>2`]('-T<E]R97!L
M86-E*"=<4"<L("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3YG971#<GEP=&5D
M4&%S<W=O<F0H)'!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC
M<GEP=&EO;B==*2DL("1Q=65R>2D["@H@("`@("`@("1R97-U;'0@/2`D=&AI
M<RT^7V1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<W-W;W)D.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@<V5T(&]F(&%U=&AE;G1I8V%T
M:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'5S97))9"`@5&AE('5S97))9"!T;R!D96QE=&4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("`@("`@("!3=6-C97-S(&]R(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;6]V955S97(H)'5S97))9"D*("`@('L*
M("`@("`@("`O*B!?8V]N;F5C="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A
M=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!"=6EL9"!A(&-U<W1O;2!Q=65R>2P@8F%S960@
M;VX@=&AE(&-O;F9I9R!F:6QE+B`J+PH@("`@("`@("1Q=65R>2`]("1T:&ES
M+3Y?<&%R86US6R=Q=65R>5]R96UO=F4G73L*("`@("`@("`D<75E<GD@/2!S
M=')?<F5P;&%C92@G7$PG+"`D=&AI<RT^7V1B+3YQ=6]T92@D=7-E<DED*2P@
M)'%U97)Y*3L*"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y
M*"1Q=65R>2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))
M9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I;B!T
M:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!A
M<G)A>2!O9B!U<V5R261S+"!O<B!F86QS92!O;B!F86EL=7)E+W5N<W5P<&]R
M=&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@
M("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D:64@=VET:"!(;W)D93HZ9F%T
M86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@("\J($)U:6QD(&$@8W5S=&]M('%U97)Y+"!B87-E9"!O
M;B!T:&4@8V]N9FEG(&9I;&4N("HO"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M
M/E]P87)A;7-;)W%U97)Y7VQI<W0G73L*"B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL(&YU;&PL($1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3&]O<"!T:')O=6=H(&%N9"!B=6EL9"!R971U<FX@87)R
M87DN("HO"B`@("`@("`@)'5S97)S(#T@87)R87DH*3L*("`@("`@("!F;W)E
M86-H("@D<F5S=6QT(&%S("1A<BD@>PH@("`@("`@("`@("`D=7-E<G-;72`]
M("1A<ELP73L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=7-E<G,["B`@
M("!]"@I]"@````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O075T:"]K;VQA8BYP:'``````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#<Q,#,@,3`U,34T,S0Q-#`@,#(R,#0R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@IR97%U:7)E7V]N8V4@)TAO<F1E+T%U=&@O:6UA<"YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+TAI<W1O<GDN<&AP)SL*"B\J*@H@*B!+;VQA8B!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@2&]R9&4@875T:&5N=&EC871I;VX@<WES=&5M
M+B!$97)I=F5S(&9R;VT@=&AE"B`J($%U=&A?:6UA<"!)34%0(&%U=&AE;G1I
M8V%T:6]N(&]B:F5C="P@86YD('-I;7!L>2!P<F]V:61E<R!P87)A;65T97)S
M('1O(&ET"B`J(&)A<V5D(&]N('1H92!G;&]B86P@2V]L86(@8V]N9FEG=7)A
M=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VMO;&%B
M+G!H<"QV(#$N,2XQ,"XX(#(P,#8O,#,O,#,@,C,Z,#`Z,C@@8VAU8VL@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!3='5A<G0@0FEN9V4@/',N
M8FEN9V5`8V]D969U<VEO;BYC;RYZ83X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E9G5S:6]N+F-O+GIA
M/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?075T
M:`H@*B\*8VQA<W,@075T:%]K;VQA8B!E>'1E;F1S($%U=&A?:6UA<"!["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W($MO;&%B(&%U=&AE;G1I
M8V%T:6]N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!!=71H7VMO;&%B*"1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1P87)A;7-;)VAO<W1S<&5C)UT@/2`D
M1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=I;6%P)UU;)W-E<G9E<B==.PH@
M("`@("`@("1P87)A;7-;)W!O<G0G72`]("1'3$]"04Q36R=C;VYF)UU;)VMO
M;&%B)UU;)VEM87`G75LG<&]R="==.PH@("`@("`@("1P87)A;7-;)W!R;W1O
M8V]L)UT@/2`G:6UA<"]N;W1L<R]N;W9A;&ED871E+6-E<G0G.PH*("`@("`@
M("!P87)E;G0Z.D%U=&A?:6UA<"@D<&%R86US*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS
M(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E
M<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L
M<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N($9O<B!+;VQA8BP*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@;75S="!C
M;VYT86EN(&$@<&%S<W=O<F0@96YT<GDN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E
M('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U
M<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!G;&]B86P@)&-O
M;F8["@H@("`@("`@("1L;V=I;E]O:R`]('!A<F5N=#HZ7V%U=&AE;G1I8V%T
M92@D=7-E<DED+"`D8W)E9&5N=&EA;',I.PH*("`@("`@("!I9B`H)&-O;F9;
M)V%U=&@G75LG<&%R86US)UU;)VQO9VEN7V)L;V-K)UT@(3T@,2D@>PH@("`@
M("`@("`@("`O+R!2971U<FX@:68@9F5A='5R92!I<R!D:7-A8FQE9"X*("`@
M("`@("`@("`@<F5T=7)N("1L;V=I;E]O:SL*("`@("`@("!]"@H@("`@("`@
M("1H:7-T;W)Y(#T@)DAO<F1E7TAI<W1O<GDZ.G-I;F=L971O;B@I.PH*("`@
M("`@("`D:&ES=&]R>5]I9&5N=&EF:65R(#T@(B1U<V5R261`;&]G:6YS+FMO
M;&%B(CL*("`@("`@("`D:&ES=&]R>5]L;V<@/2`D:&ES=&]R>2T^9V5T2&ES
M=&]R>2@D:&ES=&]R>5]I9&5N=&EF:65R*3L*("`@("`@("`D:&ES=&]R>5]L
M:7-T(#T@87)R87DH*3L*"B`@("`@("`@+R\@17AT<F%C="!H:7-T;W)Y(&QI
M<W0@9G)O;2!L;V<N"B`@("`@("`@:68@*"1H:7-T;W)Y7VQO9R`F)B`A:7-?
M82@D:&ES=&]R>5]L;V<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M)&1A=&$@/2`D:&ES=&]R>5]L;V<M/F=E=$1A=&$H*3L*("`@("`@("`@("`@
M:68@*"%E;7!T>2@D9&%T82DI('L*("`@("`@("`@("`@("`@("1E;G1R>2`]
M(&%R<F%Y7W-H:69T*"1D871A*3L*("`@("`@("`@("`@("`@("1H:7-T;W)Y
M7VQI<W0@/2`D96YT<GE;)VAI<W1O<GE?;&ES="==.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O+R!#86QC=6QA=&4@=&AE('1I;64@<F%N
M9V4N"B`@("`@("`@)'-T87)T7W1I;64@/2`H=&EM92@I("T@)&-O;F9;)V%U
M=&@G75LG<&%R86US)UU;)VQO9VEN7V)L;V-K7W1I;64G72`J(#8P*3L*"B`@
M("`@("`@)&YE=U]H:7-T;W)Y7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("1C
M;W5N="`](#`["@H@("`@("`@("\O($-O<'D@86YD(&-O=6YT(&%L;"!R96QE
M=F%N="!T:6UE<W1A;7!S+@H@("`@("`@(&9O<F5A8V@@*"1H:7-T;W)Y7VQI
M<W0@87,@)&5N=')Y*2!["B`@("`@("`@("`@("1T:6UE<W1A;7`@/2`D96YT
M<GE;("=T:6UE<W1A;7`G(%T["@H@("`@("`@("`@("!I9B`H)'1I;65S=&%M
M<"`^("1S=&%R=%]T:6UE*2!["B`@("`@("`@("`@("`@("`D;F5W7VAI<W1O
M<GE?;&ES=%M=(#T@)&5N=')Y.PH@("`@("`@("`@("`@("`@)&-O=6YT*RL[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1M87A?8V]U;G0@
M/2`D8V]N9ELG875T:"==6R=P87)A;7,G75LG;&]G:6Y?8FQO8VM?8V]U;G0G
M73L*"B`@("`@("`@:68@*"1C;W5N="`^("1M87A?8V]U;G0@?'P@(21L;V=I
M;E]O:RD@>PH@("`@("`@("`@("`O+R!!9&0@96YT<GD@9F]R(&-U<G)E;G0@
M9F%I;&5D(&QO9VEN+@H@("`@("`@("`@("`D96YT<GD@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`D96YT<GE;("=T:6UE<W1A;7`G(%T@/2!T:6UE*"D["B`@
M("`@("`@("`@("1N97=?:&ES=&]R>5]L:7-T6UT@/2`D96YT<GD["@H@("`@
M("`@("`@("`O+R!7<FET92!B86-K(&AI<W1O<GDN"B`@("`@("`@("`@("1H
M:7-T;W)Y+3YL;V<H)&AI<W1O<GE?:61E;G1I9FEE<BP@87)R87DH)V%C=&EO
M;B<@/3X@)V%D9"<L("=W:&\G(#T^("1U<V5R260L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAI<W1O
M<GE?;&ES="<@/3X@)&YE=U]H:7-T;W)Y7VQI<W0I+"!T<G5E*3L*"B`@("`@
M("`@("`@(&EF("@D8V]U;G0@/B`D;6%X7V-O=6YT*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%
M+"!?*")4;V\@;6%N>2!I;G9A;&ED(&QO9VEN<R!D=7)I;F<@=&AE(&QA<W0@
M;6EN=71E<RXB*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)
M3BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&]G:6Y?;VL["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]S<6PN<&AP````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#`U-#0@,3`U
M,34T,S0Q-#`@,#(Q-34W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]S<6P@8VQA<W,@
M<')O=FED97,@82!344P@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J
M(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@4F5Q=6ER960@<&%R86UE
M=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@("`@(%1H92!D871A8F%S92!T
M>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J
M($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G96YC<GEP=&EO;B<@
M("`@("`@("`@("`@5&AE(&5N8W)Y<'1I;VX@=&\@=7-E('1O('-T;W)E('1H
M92!P87-S=V]R9"!I;@H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M:&4@=&%B;&4@*&4N9RX@<&QA:6XL(&-R>7!T+"!M9#4M:&5X+`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!M9#4M8F%S938T+"!S;60U+"!S:&$L
M('-S:&$L(&%P<FUD-2DN"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1%1D%53%0Z("=M9#4M:&5X)PH@*B`@("=S:&]W7V5N8W)Y<'1I;VXG("`@
M("`@("!7:&5T:&5R(&]R(&YO="!T;R!P<F5P96YD('1H92!E;F-R>7!T:6]N
M(&EN('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P87-S=V]R
M9"!F:65L9"X*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$5&055,
M5#H@)V9A;'-E)PH@*B`@("=P87-S=V]R9%]F:65L9"<@("`@("`@("!4:&4@
M;F%M92!O9B!T:&4@<&%S<W=O<F0@9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4N
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=U<V5R
M7W!A<W,G"B`J("`@)W1A8FQE)R`@("`@("`@("`@("`@("`@(%1H92!N86UE
M(&]F('1H92!344P@=&%B;&4@=&\@=7-E(&EN("=D871A8F%S92<N"B`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=H;W)D95]U<V5R
M<R<*("H@("`G=7-E<FYA;65?9FEE;&0G("`@("`@("`@5&AE(&YA;64@;V8@
M=&AE('5S97)N86UE(&9I96QD(&EN('1H92!A=71H('1A8FQE+@H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G=7-E<E]U:60G"B`J
M("`@)W-O9G1?97AP:7)A=&EO;E]F:65L9"<@(%1H92!N86UE(&]F('1H92!F
M:65L9"!C;VYT86EN:6YG(&$@9&%T92!A9G1E<@H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!W:&EC:"!T:&4@<WES=&5M('=I;&P@<F5Q=65S="!T
M:&4@=7-E<B!C:&%N9V4@:&ES"B`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&]R(&AE<B!P87-S=V]R9"X*("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1$5&055,5#H@;F]N90H@*B`@("=H87)D7V5X<&ER871I;VY?9FEE
M;&0G("!4:&4@;F%M92!O9B!T:&4@9FEE;&0@8V]N=&%I;FEN9R!A(&1A=&4@
M869T97(*("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=VAI8V@@=&AE
M(&%C8V]U;G0@:7,@;F\@;&]N9V5R('9A;&ED(&%N9"!T:&4@=7-E<@H@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!W:6QL(&YO="!B92!A8FQE('1O
M(&QO9R!I;B!A="!A;&PN"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($1%1D%53%0Z(&YO;F4\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M92!D
M871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P96,G
M("`@("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@
M("`G<')O=&]C;VPG("`@("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H
M)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@)V1A=&%B87-E)R`@("`@5&AE
M(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=U<V5R;F%M92<@("`@(%1H
M92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B
M87-E+@H@*B`@("=P87-S=V]R9"<@("`@(%1H92!P87-S=V]R9"!A<W-O8VEA
M=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`G;W!T:6]N<R<@("`@("!!9&1I
M=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@
M)W!O<G0G("`@("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T
M;R!T:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@("`@5&AE(%1462!O
M;B!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R93X*("H*
M("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE($%U=&@@<WES=&5M(&ES
M(&EN"B`J('-C<FEP=',O<W%L+VAO<F1E7W5S97)S+G-Q;"X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO075T:"]!=71H+W-Q;"YP:'`L=B`Q+C8Y+C$P+C$Y
M(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]S<6P@97AT96YD
M<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI
M=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@
M("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N
M)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!T<G5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7!D871E)R`@("`@
M("`@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E
M<V5T<&%S<W=O<F0G(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R96UO=F4G("`@("`@("`]/B!T<G5E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G;&ES="<@("`@("`@("`@/3X@=')U92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^
M(&9A;'-E*3L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E
M;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1"
M"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@0F]O;&5A
M;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E9"!T
M;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*
M("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-13"!A=71H96YT:6-A=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]S<6PH)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E
M9&5N=&EA;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@
M(%1H92!U<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R
M961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E
M;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE
M;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@
M+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P
M;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@
M("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=314Q%0U0@*B!&4D]-("5S(%=(15)%("5S(#T@/R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=U<V5R;F%M95]F:65L9"==*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'5S97))9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@075T:%]S<6PZ.E]A=71H96YT:6-A=&4H*3H@)R`N("1Q=65R>2P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I
M.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?
M1D%)3$5$*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T=%5$U/1$5?
M05-33T,I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@
M("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'
M24XI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21T:&ES+3Y?8V]M<&%R95!A<W-W;W)D<R@D<F]W6R1T:&ES
M+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8W)E9&5N=&EA;'-;)W!A<W-W;W)D
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?
M4D5!4T].7T)!1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)&YO=R`]('1I;64H*3L*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=H87)D7V5X<&ER871I;VY?9FEE;&0G
M72D@)B8*("`@("`@("`@("`@(65M<'1Y*"1R;W=;)'1H:7,M/E]P87)A;7-;
M)VAA<F1?97AP:7)A=&EO;E]F:65L9"==72D@)B8*("`@("`@("`@("`@*"1N
M;W<@/B`D<F]W6R1T:&ES+3Y?<&%R86US6R=H87)D7V5X<&ER871I;VY?9FEE
M;&0G75TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%5
M5$A?4D5!4T].7T584$E2140I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G72D@)B8*("`@("`@("`@("`@(65M
M<'1Y*"1R;W=;)'1H:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A=&EO;E]F:65L
M9"==72D@)B8*("`@("`@("`@("`@*"1N;W<@/B`D<F]W6R1T:&ES+3Y?<&%R
M86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G75TI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?875T:$-R961E;G1I86QS6R=C:&%N9V5297%U97-T960G72`]
M('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C
M<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M260@("`@("!4:&4@=7-E<DED('1O(&%D9"X*("`@("`J($!P87)A;2!A<G)A
M>2`D8W)E9&5N=&EA;',@(%1H92!C<F5D96YT:6%L<R!T;R!A9&0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D57-E<B@D=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H
M92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G24Y3
M15)4($E.5$\@)7,@*"5S+"`E<RD@5D%,5453("@_+"`_*2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M
M95]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!A<W-W;W)D7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@/2!A
M<G)A>2@D=7-E<DED+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG72DI.PH*("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L
M.CIA9&15<V5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@;V8@875T:&5N=&EC871I
M;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD240@("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;F5W240@("`@("`@(%1H92!N97<@=7-E<DED+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H92!N97<@8W)E9&5N=&EA;',*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE=TE$+"`D8W)E9&5N
M=&EA;',I"B`@("!["B`@("`@("`@+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W
M:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I;'5R92X@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D='5P;&4@/2!A<G)A>2@I.PH@("`@("`@("1T
M=7!L95LD=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G75T@/2`D;F5W
M240["B`@("`@("`@)'1U<&QE6R1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F
M:65L9"==72`]"B`@("`@("`@("`@("1T:&ES+3YG971#<GEP=&5D4&%S<W=O
M<F0H)&-R961E;G1I86QS6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*3L*"B`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?=VEN9&]W
M)UTI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;
M)W-O9G1?97AP:7)A=&EO;E]F:65L9"==*2D@>PH@("`@("`@("`@("`@("`@
M)'1U<&QE6R1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I;VY?9FEE;&0G
M75T@/2!N=6QL.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&1A=&4@/2!T:6UE*"D["B`@("`@("`@("`@("1D871E82`]
M(&QO8V%L=&EM92@D9&%T92P@=')U92D["B`@("`@("`@("`@("1D871E(#T@
M;6MT:6UE*"1D871E85LG=&U?:&]U<B==+"`D9&%T96%;)W1M7VUI;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T96%;)W1M7W-E8R==+"`D
M9&%T96%;)W1M7VUO;B==("L@,2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1A=&5A6R=T;5]M9&%Y)UT@*R`D=&AI<RT^7W!A<F%M<ULG<V]F=%]E
M>'!I<F%T:6]N7W=I;F1O=R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&%T96%;)W1M7WEE87(G72D["@H@("`@("`@("`@("`D='5P;&5;)'1H
M:7,M/E]P87)A;7-;)W-O9G1?97AP:7)A=&EO;E]F:65L9"==72`]("1D871E
M.PH*("`@("`@("`@("`@9VQO8F%L("1N;W1I9FEC871I;VX["B`@("`@("`@
M("`@(&EF("@A96UP='DH)&YO=&EF:6-A=&EO;BDI('L*("`@("`@("`@("`@
M("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W1R9G1I;64H7R@B3F5W('!A<W-W
M;W)D('=I;&P@97AP:7)E(&]N("5X+B(I+"`D9&%T92DL("=H;W)D92YM97-S
M86=E)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AE;7!T>2@D
M=&AI<RT^7W!A<F%M<ULG:&%R9%]E>'!I<F%T:6]N7W=I;F1O=R==*2D@>PH@
M("`@("`@("`@("`@("`@)'1U<&QE6R1T:&ES+3Y?<&%R86US6R=H87)D7V5X
M<&ER871I;VY?9FEE;&0G75T@/2!N=6QL.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)&1A=&5A(#T@;&]C86QT:6UE*"1D871E+"!T
M<G5E*3L*("`@("`@("`@("`@("`@("1D871E(#T@;6MT:6UE*"1D871E85LG
M=&U?:&]U<B==+"`D9&%T96%;)W1M7VUI;B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1A=&5A6R=T;5]S96,G72P@)&1A=&5A6R=T;5]M
M;VXG72`K(#$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M96%;)W1M7VUD87DG72`K("1T:&ES+3Y?<&%R86US6R=S;V9T7V5X<&ER871I
M;VY?=VEN9&]W)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%T96%;)W1M7WEE87(G72D["@H@("`@("`@("`@("`@("`@)'1U<&QE6R1T
M:&ES+3Y?<&%R86US6R=H87)D7V5X<&ER871I;VY?9FEE;&0G75T@/2`D9&%T
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]344PN<&AP)SL*("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*"=54$1!5$4@)7,@4T54("5S(%=(15)%("5S(#T@/R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@($AO<F1E7U-13#HZ=7!D871E5F%L=65S*"1T
M:&ES+3Y?9&(L("1T=7!L92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*"1O;&1)1"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S
M86=E*"=344P@475E<GD@8GD@075T:%]S<6PZ=7!D871E57-E<B@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@
M)'9A;'5E<RD["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E="!A('5S97(G<R!P
M87-S=V]R9"X@57-E9"!F;W(@97AA;7!L92!W:&5N('1H92!U<V5R(&1O97,@
M;F]T"B`@("`@*B!R96UE;6)E<B!T:&4@97AI<W1I;F<@<&%S<W=O<F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<E]I9"`@5&AE('5S97(@
M:60@9F]R('=H:6-H('1O(')E<V5T('1H92!P87-S=V]R9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@;F5W('!A<W-W;W)D(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;@H@("`@("H@("`@("`@("`@
M("`@("`@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S971087-S
M=V]R9"@D=7-E<E]I9"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I('=I
M;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J+PH@
M("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!'970@82!N
M97<@<F%N9&]M('!A<W-W;W)D+B`J+PH@("`@("`@("1P87-S=V]R9"`]($%U
M=&@Z.F=E;E)A;F1O;5!A<W-W;W)D*"D["@H@("`@("`@("\J($)U:6QD('1H
M92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$
M051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I
M96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1T:&ES+3YG971#<GEP=&5D4&%S<W=O<F0H)'!A<W-W;W)D+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)'5S97)?:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@G4U%,(%%U97)Y(&)Y($%U=&A?<W%L.CIR97-E=%!A<W-W;W)D*"DZ
M("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U
M97)Y+"`D=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1P87-S=V]R9#L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H96YT:6-A=&EO;B!C<F5D
M96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@
M(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@("`@("`@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I"B`@("!["B`@("`@("`@
M+RH@7V-O;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P
M;VX@9F%I;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@
M("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E
M<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212`E<R`](#\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;65?9FEE;&0G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1U
M<V5R260I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($%U=&A?<W%L.CIR96UO=F55<V5R*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YR96UO=F55<V5R1&%T82@D=7-E<DED*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H92!S>7-T96TN"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R<F%Y(&]F('5S97))
M9',L(&]R(&9A;'-E(&]N(&9A:6QU<F4O=6YS=7!P;W)T960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@("!["B`@("`@("`@+RH@7V-O
M;FYE8W0H*2!W:6QL(&1I92!W:71H($AO<F1E.CIF871A;"@I('5P;VX@9F%I
M;'5R92X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@
M+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!
M=71H7W-Q;#HZ;&ES=%5S97)S*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@:68@82!U<V5R260@97AI<W1S(&EN('1H92!S:7-T96TN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T
M:&4@=7-E<DED(&%L<F5A9'D@97AI<W1S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E>&ES=',H)'5S97))9"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C="@I
M('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E+B`J
M+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL
M9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S(#T@/R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@("1V86QU97,@/2!A<G)A
M>2@D=7-E<DED*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1
M=65R>2!B>2!!=71H7W-Q;#HZ97AI<W1S*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VUP87)E(&%N(&5N8W)Y<'1E9"!P87-S=V]R
M9"!T;R!A('!L86EN=&5X="!S=')I;F<@=&\@<V5E(&EF"B`@("`@*B!T:&5Y
M(&UA=&-H+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&5N8W)Y<'1E9"`@5&AE(&-R>7!T960@
M<&%S<W=O<F0@=&\@8V]M<&%R92!A9V%I;G-T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&QA:6YT97AT("!4:&4@<&QA:6YT97AT('!A<W-W;W)D('1O('9E
M<FEF>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M;6%T8VAE9"P@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8V]M<&%R95!A<W-W;W)D<R@D96YC<GEP=&5D+"`D<&QA:6YT97AT*0H@
M("`@>PH@("`@("`@(')E='5R;B`D96YC<GEP=&5D(#T]("1T:&ES+3YG971#
M<GEP=&5D4&%S<W=O<F0H)'!L86EN=&5X="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;F-R>7!T
M960L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-H;W=?96YC<GEP=&EO;B==*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C;VYN
M96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@
M;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R
M0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G875T:"<L(&%R<F%Y*"=P:'!T>7!E
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G875T:&5N
M=&EC871I;VX@4U%,)RD["@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@
M?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==
M(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG96YC<GEP=&EO;B==(#T@)VUD-2UH97@G
M.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US
M6R=S:&]W7V5N8W)Y<'1I;VXG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W-H;W=?96YC<GEP=&EO;B==(#T@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?
M=7-E<G,G.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P
M87)A;7-;)W5S97)N86UE7V9I96QD)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=U<V5R;F%M95]F:65L9"==(#T@)W5S97)?=6ED)SL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E
M<FYA;65?9FEE;&0G72`](%-T<FEN9SHZ;&]W97(H)'1H:7,M/E]P87)A;7-;
M)W5S97)N86UE7V9I96QD)UTI.PH@("`@("`@('T*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==(#T@)W5S
M97)?<&%S<R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UT@/2!3=')I;F<Z.FQO=V5R*"1T
M:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==*3L*("`@("`@("!]"@H@
M("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V97(@=7-I;F<@=&AE
M('-U<'!L:65D('!A<F%M971E<G,N("HO"B`@("`@("`@:6YC;'5D95]O;F-E
M("=$0BYP:'`G.PH@("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H
M)'1H:7,M/E]P87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=P97)S:7-T96YT)UTI*2D["B`@("`@("`@:68@*&ES7V$H)'1H:7,M
M/E]D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T
M86PH7R@B56YA8FQE('1O(&-O;FYE8W0@=&\@4U%,('-E<G9E<BXB*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E="!$
M0B!P;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@('-W:71C:"`H)'1H:7,M
M/E]D8BT^<&AP='EP92D@>PH@("`@("`@(&-A<V4@)VUS<W%L)SH*("`@("`@
M("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"
M7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]2
M4R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12!\($1"7U!/4E1!0DE,25197T524D]24RD["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+VMR8C4N<&AP````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3<R-R`Q,#4Q-30S-#$T
M,"`P,C$V,C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7VMR8C4@8VQA<W,@<')O=FED
M97,@86X@:V5R8F5R;W,@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J
M(&%U=&AE;G1I8V%T:6]N('-Y<W1E;2X*("H*("H@5&AI<R!D<FEV97(@<F5Q
M=6ER97,@=&AE("=K<F(U)R!02%`@97AT96YS:6]N('1O(&)E(&QO861E9"X*
M("H@5&AE(&UO9'5L92!C86X@8F4@9&]W;FQO861E9"!H97)E.@H@*B`@(&AT
M='`Z+R]W=W<N:&]R9&4N;W)G+V1O=VYL;V%D+W!H<"]P:'!K<F(U+G1A<BYG
M>@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J("`@3F]N92X\
M+W!R93X*("H*("H@26YS=&5A9"P@2V5R8F5R;W,@;75S="!B92!C;W)R96-T
M;'D@8V]N9FEG=7)E9"!O;B!Y;W5R('-Y<W1E;2`H92YG+@H@*B`@("]E=&,O
M:W)B-2YC;VYF*2!F;W(@=&AI<R!C;&%S<R!T;R!W;W)K(&-O<G)E8W1L>2X*
M("H*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+VMR8C4N<&AP
M+'8@,2XR,2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@
M2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]K<F(U(&5X=&5N9',@075T:"![
M"@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O
M('1H870@=&AE(&1R:79E<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R
M871I;VYS(&ET('-U<'!O<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL
M:71I97,@/2!A<G)A>2@G861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S
M<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5M;W9E)R`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=L:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A
M;'-E*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@2V5R8F5R
M;W,@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?:W)B-2@D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X
M=&5N<VEO;D5X:7-T<R@G:W)B-2<I*2!["B`@("`@("`@("`@($AO<F1E.CIF
M871A;"A?*")!=71H7VMR8C4Z(%)E<75I<F5D(&MR8C4@97AT96YS:6]N(&YO
M="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I
M86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@
M=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT
M:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!&;W(@:V5R8F5R;W,L('1H:7,@
M;75S="!C;VYT86EN(&$@<&%S<W=O<F0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&5N=')Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED
M+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1C<F5D
M96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@2&]R9&4Z.F9A
M=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!+97)B97)O<R!A=71H
M96YT:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("1R97-U;'0@/2!K<F(U7VQO9VEN*"1U<V5R260L("1C<F5D
M96YT:6%L<ULG<&%S<W=O<F0G72D["@H@("`@("`@(&EF("@D<F5S=6QT(#T]
M/2!+4D(U7T]+*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2!+4D(U7T)!
M1%]005-35T]21"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S971!=71H
M17)R;W(H05542%]214%33TY?34534T%'12P@7R@B0F%D(&ME<F)E<F]S('!A
M<W-W;W)D+B(I*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1R97-U;'0@/3T]
M($M20C5?0D%$7U5315(I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T
M075T:$5R<F]R*$%55$A?4D5!4T].7TU%4U-!1T4L(%\H(D)A9"!K97)B97)O
M<R!U<V5R;F%M92XB*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-3
M04=%+"!?*")+97)B97)O<R!S97)V97(@<F5J96-T960@875T:&5N=&EC871I
M;VXN(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@I]"@``````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+T%U=&@O;6-A;"YP:'``````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`U-C`S(#$P-3$U-#,T,30P(#`R,38W,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE($%U=&A?;6-A;"!C;&%S<R!P<F]V:61E<R!A;B!-0T%,(&EM<&QE
M;65N=&%T:6]N(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T
M96TN"B`J"B`J($U#04P@2&]M92!086=E.B!H='1P.B\O;6-A;"YC:&5K+F-O
M;2\*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=C86QE
M;F1A<B<@(%1H92!-0T%,(&-A;&5N9&%R(&YA;64N/"]P<F4^"B`J"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T%U=&@O075T:"]M8V%L+G!H<"QV(#$N,C<N
M,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB
M=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@
M*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7VUC86P@97AT
M96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B
M:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*
M("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O
M97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^('1R
M=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T<F%N<W!A<F5N
M="<@("`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@
M;F5W($U#04P@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN
M96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?
M;6-A;"@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(55T
M:6PZ.F5X=&5N<VEO;D5X:7-T<R@G;6-A;"<I*2!["B`@("`@("`@("`@($AO
M<F1E.CIF871A;"A?*")!=71H7VUC86PZ(%)E<75I<F5D($U#04P@97AT96YS
M:6]N(&YO="!F;W5N9"XB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=C86QE;F1A<B==*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@8V%L96YD87(@;F%M
M92!P<F]V:61E9"!F;W(@34-!3"!A=71H96YT:6-A=&EO;BXB*2P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R
M86US(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T
M(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@
M;&]G:6X@8W)E9&5N=&EA;',N($9O<B!-0T%,+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R
M9"!E;G1R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H
M97(@;W(@;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I
M86QS*0H@("`@>PH@("`@("`@("1M8V%L(#T@0&UC86Q?;W!E;B@D=&AI<RT^
M7W!A<F%M<ULG8V%L96YD87(G72P@)'5S97))9"P@)&-R961E;G1I86QS6R=P
M87-S=V]R9"==*3L*"B`@("`@("`@:68@*"1M8V%L*2!["B`@("`@("`@("`@
M($!M8V%L7V-L;W-E*"1M8V%L*3L*("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&UC86Q?8VQO<V4H)&UC
M86PI.PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%
M05-/3E]"041,3T=)3BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L;"!U<V5R<R!I
M;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H
M92!A<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15<V5R<R@I"B`@
M("!["B`@("`@("`@)&QI;F5S(#T@0&9I;&4H)R]E=&,O;7!A<W-W9"<I.PH@
M("`@("`@(&EF("@A)&QI;F5S('Q\("%I<U]A<G)A>2@D;&EN97,I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@
M;&ES="!U<V5R<RXG*3L*("`@("`@("!]"@H@("`@("`@("1U<V5R<R`](&%R
M<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@
M("`@("`@("`@("1U<V5R<UM=(#T@<W5B<W1R*"1L:6YE+"`P+"!S=')P;W,H
M)&QI;F4L("<Z)RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1U<V5R
M<SL*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O075T:"]F='`N
M<&AP````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0R
M,3<@,3`U,34T,S0Q-#`@,#(Q-30V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\J*@H@*B!4:&4@075T:%]F='`@
M8VQA<W,@<')O=FED97,@86X@1E10(&EM<&QE;65N=&%T:6]N(&]F('1H92!(
M;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J($]P=&EO;F%L
M('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P96,G("!4:&4@:&]S=&YA
M;64@;W(@25`@861D<F5S<R!O9B!T:&4@1E10('-E<G9E<BX*("H@("`@("`@
M("`@("`@("!$149!54Q4.B`G;&]C86QH;W-T)PH@*B`@("=P;W)T)R`@("`@
M(%1H92!S97)V97(@<&]R="!T;R!C;VYN96-T('1O+@H@*B`@("`@("`@("`@
M("`@($1%1D%53%0Z(#(Q/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T%U=&@O075T:"]F='`N<&AP+'8@,2XR,RXQ,BXX(#(P,#8O,#$O,#$@
M,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@36%X($MA;&EK82`\;6%X0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!-87@@2V%L:6MA(#QM87A`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?
M075T:`H@*B\*8VQA<W,@075T:%]F='`@97AT96YD<R!!=71H('L*"B`@("`O
M*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@1E10(&%U=&AE;G1I8V%T:6]N
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!!=71H7V9T<"@D<&%R86US(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9G1P
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?9G1P.B!2
M97%U:7)E9"!&5%`@97AT96YS:6]N(&YO="!F;W5N9"X@0V]M<&EL92!02%`@
M=VET:"!T:&4@+2UE;F%B;&4M9G1P('-W:71C:"XB*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1D969A=6QT7W!A<F%M<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`G:&]S='-P96,G(#T^("=L;V-A;&AO<W0G
M+`H@("`@("`@("`@("`G<&]R="<@/3X@,C$*("`@("`@("`I.PH@("`@("`@
M("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H)&1E9F%U;'1?<&%R86US
M+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF
M(&$@<V5T(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@06X@87)R87D@;V8@;&]G
M:6X@8W)E9&5N=&EA;',N($9O<B!&5%`L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&ES(&UU<W0@8V]N=&%I;B!A('!A<W-W;W)D(&5N
M=')Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O
M<B!N;W0@=&AE(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D=7-E<DED+"`D8W)E9&5N=&EA;',I
M"B`@("!["B`@("`@("`@)&9T<"`]($!F='!?8V]N;F5C="@D=&AI<RT^7W!A
M<F%M<ULG:&]S='-P96,G72P@)'1H:7,M/E]P87)A;7-;)W!O<G0G72D["@H@
M("`@("`@(&EF("@D9G1P("8F($!F='!?;&]G:6XH)&9T<"P@)'5S97))9"P@
M)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!`9G1P
M7W%U:70H)&9T<"D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@($!F='!?<75I="@D9G1P*3L*("`@("`@
M("`@("`@)'1H:7,M/E]S971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'
M24XI.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O075T:"]I;6%P+G!H<```````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,3,Q,3`@,3`U,34T,S0Q-#`@,#(Q-C<S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@075T:%]I;6%P.CH@8VQA<W,@<')O=FED97,@86X@24U!4"!I;7!L96UE
M;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@875T:&5N=&EC871I;VX@<WES=&5M
M+@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`G:&]S='-P
M96,G("`@("`@("!4:&4@:&]S=&YA;64@;W(@25`@861D<F5S<R!O9B!T:&4@
M<V5R=F5R+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@)VQO8V%L
M:&]S="<*("H@("=P;W)T)R`@("`@("`@("`@(%1H92!S97)V97(@<&]R="!T
M;R!W:&EC:"!W92!W:6QL(&-O;FYE8W0N"B`J("`@("`@("`@("`@("`@("`@
M("!)34%0(&ES(&=E;F5R86QL>2`Q-#,L('=H:6QE($E-05`M4U-,(&ES(&=E
M;F5R86QL>2`Y.3,N"B`J("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`Q
M-#,*("H@("=P<F]T;V-O;"<@("`@("`@(%1H92!C;VYN96-T:6]N('!R;W1O
M8V]L("AE+F<N("=I;6%P)RP@)W!O<#,G+"`G;FYT<"<I+@H@*B`@("`@("`@
M("`@("`@("`@("`@4')O=&]C;VP@:7,@;VYE(&]F("=I;6%P+VYO=&QS)R`H
M;W(@;VYL>2`G:6UA<"<@:68@>6]U"B`J("`@("`@("`@("`@("`@("`@("!H
M879E(&$@8RUC;&EE;G0@=F5R<VEO;B`R,#`P8R!O<B!O;&1E<BDL("=I;6%P
M+W-S;"<L"B`J("`@("`@("`@("`@("`@("`@("!O<B`G:6UA<"]S<VPO;F]V
M86QI9&%T92UC97)T)R`H9F]R(&$@<V5L9BUS:6=N960*("H@("`@("`@("`@
M("`@("`@("`@(&-E<G1I9FEC871E*2X*("H@("`@("`@("`@("`@("`@("`@
M($1%1D%53%0Z("=I;6%P)PH@*B`@)V%D;6EN7W5S97(G("`@("`@5&AE(&YA
M;64@;V8@82!U<V5R('=I=&@@861M:6X@<')I=FEL96=E<RX*("H@("`@("`@
M("`@("`@("`@("`@($1%1D%53%0Z(&YU;&P*("H@("=A9&UI;E]P87-S=V]R
M9"<@(%1H92!P87-S=V]R9"!O9B!T:&4@861M:6YS=')A=&]R+@H@*B`@("`@
M("`@("`@("`@("`@("`@1$5&055,5#H@;G5L;`H@*B`@)W5S97)H:65R87)C
M:'DG("`@5&AE(&AI97)A<F-H>2!W:&5R92!U<V5R(&UA:6QB;WAE<R!A<F4@
M<W1O<F5D+@H@*B`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@)W5S97(N
M)PH@*B`@)V1S;B<@("`@("`@("`@("`@5&AE(&9U;&P@24U!4"!C;VYN96-T
M:6]N('-T<FEN9RX*("H@("`@("`@("`@("`@("`@("`@($EF(&YO="!P<F5S
M96YT+"!T:&ES(&ES(&)U:6QT(&9R;VT@)VAO<W1S<&5C)RP@)W!O<G0G"B`J
M("`@("`@("`@("`@("`@("`@("!A;F0@)W!R;W1O8V]L)R!P87)A;65T97)S
M+CPO<')E/@H@*@H@*@H@*B!)9B!S971T:6YG('5P(&%S($AO<F1E(&%U=&@@
M:&%N9&QE<B!I;B!C;VYF+G!H<"P@=&AI<R!I<R!A('-A;7!L92!E;G1R>3H\
M<')E/@H@*B`@("1C;VYF6R=A=71H)UU;)W!A<F%M<R==6R=H;W-T<W!E8R==
M(#T@)VEM87`N97AA;7!L92YC;VTG.PH@*B`@("1C;VYF6R=A=71H)UU;)W!A
M<F%M<R==6R=P;W)T)UT@/2`Q-#,["B`J("`@)&-O;F9;)V%U=&@G75LG<&%R
M86US)UU;)W!R;W1O8V]L)UT@/2`G:6UA<"]N;W1L<R]N;W9A;&ED871E+6-E
M<G0G.SPO<')E/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U
M=&@O:6UA<"YP:'`L=B`Q+C(X+C$P+CD@,C`P-B\P-2\S,2`Q.3HS.3HT."!S
M;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@1V%U9&5N>B!3=&5I;FQI;B`\9V%U9&5N>BYS=&5I;FQI;D!I9"YU
M;FEB92YC:#X*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@
M($=A=61E;GH@4W1E:6YL:6X@/&=A=61E;GHN<W1E:6YL:6Y`:60N=6YI8F4N
M8V@^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]!=71H
M"B`J+PIC;&%S<R!!=71H7VEM87`@97AT96YD<R!!=71H('L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=',@82!N97<@24U!4"!A=71H96YT:6-A=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]I;6%P*"1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=I;6%P
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?:6UA<#H@
M4F5Q=6ER960@24U!4"!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)&1E9F%U;'1?<&%R
M86US(#T@87)R87DH"B`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)VQO8V%L
M:&]S="<L"B`@("`@("`@("`@("=P;W)T)R`]/B`G,30S)RP*("`@("`@("`@
M("`@)W!R;W1O8V]L)R`]/B`G:6UA<"<L"B`@("`@("`@("`@("=U<V5R:&EE
M<F%R8VAY)R`]/B`G=7-E<BXG"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^
M7W!A<F%M<R`](&%R<F%Y7VUE<F=E*"1D969A=6QT7W!A<F%M<RP@)'!A<F%M
M<RD["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V%D;6EN
M7W5S97(G72DI('L*("`@("`@("`@("`@)'1H:7,M/F-A<&%B:6QI=&EE<ULG
M861D)UT@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^8V%P86)I;&ET:65S
M6R=R96UO=F4G72`]('1R=64["B`@("`@("`@("`@("1T:&ES+3YC87!A8FEL
M:71I97-;)VQI<W0G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!#
M<F5A=&4@1%-.('-T<FEN9RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%R86US6R=D<VXG72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)V1S;B==(#T@<W!R:6YT9B@G>R5S.B5D+R5S?2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA
M;',@87)E('9A;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@(%1H92!U
M<V5R260@=&\@8VAE8VLN"B`@("`@*B!`<&%R86T@87)R87D@)&-R961E;G1I
M86QS("!!;B!A<G)A>2!O9B!L;V=I;B!C<F5D96YT:6%L<RX@1F]R($E-05`L
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&ES(&UU<W0@
M8V]N=&%I;B!A('!A<W-W;W)D(&5N=')Y+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&-R961E;G1I86QS(&%R
M92!V86QI9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&AE;G1I8V%T92@D
M=7-E<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@2&]R
M9&4Z.F9A=&%L*%\H(DYO('!A<W-W;W)D('!R;W9I9&5D(&9O<B!)34%0(&%U
M=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M('T*"B`@("`@("`@)&EM87`@/2!`:6UA<%]O<&5N*"1T:&ES+3Y?<&%R86US
M6R=D<VXG72P@)'5S97))9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-R961E;G1I86QS6R=P87-S=V]R9"==+"!/4%](04Q&3U!%3BD["@H@("`@
M("`@(&EF("@D:6UA<"D@>PH@("`@("`@("`@("!`:6UA<%]C;&]S92@D:6UA
M<"D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?<V5T075T:$5R<F]R*$%55$A?4D5!4T].
M7T)!1$Q/1TE.*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A('-E="!O9B!A=71H96YT
M:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1U<V5R260@("`@("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`
M<&%R86T@87)R87D@("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O
M('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A9&15<V5R*"1U<V5R260L("1C<F5D96YT:6%L
M<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O061M
M:6XN<&AP)SL*("`@("`@("`D:6UA<"`]("9N97<@24U!4%]!9&UI;B@D=&AI
M<RT^7W!A<F%M<RD["B`@("`@("`@<F5T=7)N("1I;6%P+3YA9&1-86EL8F]X
M*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'5S97))9"P@3DQ3.CIG971#:&%R
M<V5T*"DL("=U=&8W+6EM87`G*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&4@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED
M('1O(&1E;&5T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I"B`@
M("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0+T%D;6EN+G!H
M<"<["B`@("`@("`@)&EM87`@/2`F;F5W($E-05!?061M:6XH)'1H:7,M/E]P
M87)A;7,I.PH@("`@("`@("1R97-U;'0@/2`D:6UA<"T^<F5M;W9E36%I;&)O
M>"A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1U<V5R260L($Y,4SHZ9V5T0VAA
M<G-E="@I+"`G=71F-RUI;6%P)RDI.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E
M<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,:7-T(&%L
M;"!U<V5R<R!I;B!T:&4@<WES=&5M+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!A<G)A>2!O9B!U<V5R261S+"!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W15
M<V5R<R@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92])34%0
M+T%D;6EN+G!H<"<["B`@("`@("`@)&EM87`@/2`F;F5W($E-05!?061M:6XH
M)'1H:7,M/E]P87)A;7,I.PH@("`@("`@(')E='5R;B`D:6UA<"T^;&ES=$UA
M:6QB;WAE<R@I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!
M=71H+V-Y<G-Q;"YP:'``````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`T,3(V-2`Q,#4Q-30S-#$T,"`P,C(R-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O075T:"]S<6PN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92])
M34%0+T%D;6EN+G!H<"<["@HO*BH*("H@5&AE($%U=&A?8WER<W%L(&-L87-S
M('!R;W9I9&5S(&$@4U%,(&EM<&QE;65N=&%T:6]N(&]F('1H92!(;W)D90H@
M*B!A=71H96YT:6-A=&EO;B!S>7-T96T@9F]R('1H92!#>7)U<R!)34%0('-E
M<G9E<BX@36]S="!O9B!T:&4@9G5N8W1I;VYA;&ET>0H@*B!I<R!T:&4@<V%M
M92!A<R!F;W(@=&AE(%-13"!C;&%S<SL@;VYL>2!W:&%T(&ES(&1I9F9E<F5N
M="!O=F5R<FED97,@=&AE"B`J('!A<F5N="!C;&%S<R!I;7!L96UE;G1A=&EO
M;G,N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G8WER
M861M:6XG("!4:&4@=7-E<FYA;64@;V8@=&AE(&-Y<G5S(&%D;6EN:7-T<F%T
M;W(N"B`J("`@)V-Y<G!A<W,G("`@5&AE('!A<W-W;W)D(&9O<B!T:&4@8WER
M=7,@861M:6YI<W1R871O<BX*("H@("`G:6UA<%]D<VXG("!4:&4@9G5L;"!)
M34%0($133@H@*B`@("`@("`@("`@("`@("AI+F4N('ML;V-A;&AO<W0Z.3DS
M+VEM87`O<W-L+VYO=F%L:61A=&4M8V5R='TI+@H@*B`@("=P:'!T>7!E)R`@
M(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C
M+BDN/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G9&]M86EN7V9I96QD)R`@("!)9B!S970@=&\@86YY=&AI;F<@;W1H97(@
M=&AA;B`G;F]N92<@=&AI<R!I<R!U<V5D(&%S"B`J("`@("`@("`@("`@("`@
M("`@("`@9FEE;&0@;F%M92!W:&5R92!D;VUA:6X@:7,@<W1O<F5D+@H@*B`@
M("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=D;VUA:6Y?;F%M92<*("H@
M("`G96YC<GEP=&EO;B<@("`@("!4:&4@96YC<GEP=&EO;B!T;R!U<V4@=&\@
M<W1O<F4@=&AE('!A<W-W;W)D(&EN('1H90H@*B`@("`@("`@("`@("`@("`@
M("`@('1A8FQE("AE+F<N('!L86EN+"!C<GEP="P@;60U+6AE>"P@;60U+6)A
M<V4V-"P@<VUD-2P*("H@("`@("`@("`@("`@("`@("`@("!S:&$L('-S:&$I
M+@H@*B`@("`@("`@("`@("`@("`@("`@($1%1D%53%0Z("=M9#4M:&5X)PH@
M*B`@("=F;VQD97)S)R`@("`@("`@($%N(&%R<F%Y(&]F(&9O;&1E<G,@=&\@
M8W)E871E('5N9&5R('5S97)N86UE+@H@*B`@("`@("`@("`@("`@("`@("`@
M($1%1D%53%0Z($Y/3D4*("H@("`G<&%S<W=O<F1?9FEE;&0G("!4:&4@;F%M
M92!O9B!T:&4@<&%S<W=O<F0@9FEE;&0@:6X@=&AE(&%U=&@@=&%B;&4N"B`J
M("`@("`@("`@("`@("`@("`@("`@1$5&055,5#H@)W!A<W-W;W)D)PH@*B`@
M("=Q=6]T82<@("`@("`@("`@(%1H92!Q=6]T82`H:6X@:VEL;V)Y=&5S*2!T
M;R!G<F%N="!O;B!T:&4@;6%I;&)O>"X*("H@("`@("`@("`@("`@("`@("`@
M("!$149!54Q4.B!.3TY%"B`J("`@)W1A8FQE)R`@("`@("`@("`@5&AE(&YA
M;64@;V8@=&AE(&%U=&@@=&%B;&4@:6X@)V1A=&%B87-E)RX*("H@("`@("`@
M("`@("`@("`@("`@("!$149!54Q4.B`G86-C;W5N='5S97(G"B`J("`@)W5N
M:7AH:65R)R`@("`@("`@5&AE('9A;'5E(&]F(&EM87!D+F-O;F8G<R!U;FEX
M:&EE<F%R8VAY<V5P('-E='1I;F<N"B`J("`@("`@("`@("`@("`@("`@("`@
M4V5T('1H:7,@=&\@=')U92!I9B!T:&4@=F%L=64@:7,@=')U92!I;B!I;6%P
M9"YC;VYF+@H@*B`@("=U<V5R;F%M95]F:65L9"<@(%1H92!N86UE(&]F('1H
M92!U<V5R;F%M92!F:65L9"!I;B!T:&4@875T:"!T86)L92X*("H@("`@("`@
M("`@("`@("`@("`@("!$149!54Q4.B`G=7-E<FYA;64G/"]P<F4^"B`J"B`J
M(%)E<75I<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP
M<F4^"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E
M+@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A
M<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI8V%T:6]N
M('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G=7-E<FYA
M;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H
M92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@87-S
M;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V]P=&EO;G,G("`@061D
M:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@
M("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@
M=&AE(&1A=&%B87-E+@H@*B`@("=T='DG("`@("`@(%1H92!45%D@;VX@=VAI
M8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J"B`J
M(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!A=71H('-Y<W1E;2!I<R!A
M<R!F;VQL;W=S.@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@5$%"3$4@86-C;W5N
M='5S97(@*`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!4B@R-34I($))3D%2
M62!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@<&%S<W=O<F0@("`@5D%2
M0TA!4B@S,BD@0DE.05)9($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!P
M<F5F:7@@("`@("!605)#2$%2*#4P*2!.3U0@3E5,3"!$149!54Q4("<G+`H@
M*B`@("`@9&]M86EN7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%5
M3%0@)R<L"B`J("`@("!53DE1544@2T59('5S97)N86UE("AU<V5R;F%M92D*
M("H@*3L*("H*("H@0U)%051%(%1!0DQ%(&%D;6EN=7-E<B`H"B`J("`@("!U
M<V5R;F%M92`@("!605)#2$%2*#4P*2!"24Y!4ED@3D]4($Y53$P@1$5&055,
M5"`G)RP*("H@("`@('!A<W-W;W)D("`@(%9!4D-(05(H-3`I($))3D%262!.
M3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@='EP92`@("`@("`@24Y4*#$Q
M*2!.3U0@3E5,3"!$149!54Q4("<P)RP*("H@("`@(%-)1"`@("`@("`@(%9!
M4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G+`H@*B`@("`@:&]M92`@
M("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@
M("!04DE-05)9($M%62`H=7-E<FYA;64I"B`J("D["B`J"B`J($-214%412!4
M04),12!A;&EA<R`H"B`J("`@("!A;&EA<R`@("`@("!605)#2$%2*#(U-2D@
M3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@(&1E<W0@("`@("`@($Q/3D=4
M15A4+`H@*B`@("`@=7-E<FYA;64@("`@5D%20TA!4B@U,"D@3D]4($Y53$P@
M1$5&055,5"`G)RP*("H@("`@('-T871U<R`@("`@($E.5"@Q,2D@3D]4($Y5
M3$P@1$5&055,5"`G,2<L"B`J("`@("!04DE-05)9($M%62`H86QI87,I"B`J
M("D["B`J"B`J($-214%412!404),12!D;VUA:6X@*`H@*B`@("`@9&]M86EN
M7VYA;64@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@
M("!P<F5F:7@@("`@("!605)#2$%2*#4P*2!.3U0@3E5,3"!$149!54Q4("<G
M+`H@*B`@("`@;6%X86-C;W5N=',@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4
M("<R,"<L"B`J("`@("!Q=6]T82`@("`@("!)3E0H,3`I($Y/5"!.54Q,($1%
M1D%53%0@)S(P,#`P)RP*("H@("`@('1R86YS<&]R="`@(%9!4D-(05(H,C4U
M*2!.3U0@3E5,3"!$149!54Q4("=C>7)U<R<L"B`J("`@("!F<F5E;F%M97,@
M("!%3E5-*"=915,G+"=.3R<I($Y/5"!.54Q,($1%1D%53%0@)TY/)RP*("H@
M("`@(&9R965A9&1R97-S($5.54TH)UE%4R<L)TY/)RD@3D]4($Y53$P@1$5&
M055,5"`G3D\G+`H@*B`@("`@4%))34%262!+15D@*&1O;6%I;E]N86UE*2P*
M("H@("`@(%5.25%512!+15D@<')E9FEX("AP<F5F:7@I"B`J("D["B`J"B`J
M($-214%412!404),12!D;VUA:6YA9&UI;B`H"B`J("`@("!D;VUA:6Y?;F%M
M92!605)#2$%2*#(U-2D@3D]4($Y53$P@1$5&055,5"`G)RP*("H@("`@(&%D
M;6EN=7-E<B`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!54Q4("<G"B`J
M("D["B`J"B`J($-214%412!404),12!S96%R8V@@*`H@*B`@("`@<V5A<F-H
M7VED("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@
M("!S96%R8VA?<W%L("!415A4($Y/5"!.54Q,+`H@*B`@("`@<&5R<&%G92`@
M("`@24Y4*#$Q*2!.3U0@3E5,3"!$149!54Q4("<P)RP*("H@("`@('1I;65S
M=&%M<"`@(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"B`J("`@("!04DE-05)9
M($M%62`H<V5A<F-H7VED*2P*("H@("`@($M%62!S96%R8VA?:60@*'-E87)C
M:%]I9"D*("H@*3L*("H*("H@0U)%051%(%1!0DQ%('9I<G1U86P@*`H@*B`@
M("`@86QI87,@("`@("`@5D%20TA!4B@R-34I($Y/5"!.54Q,($1%1D%53%0@
M)R<L"B`J("`@("!D97-T("`@("`@("!,3TY'5$585"P*("H@("`@('5S97)N
M86UE("`@(%9!4D-(05(H-3`I($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@
M("!S=&%T=7,@("`@("!)3E0H,3$I($Y/5"!.54Q,($1%1D%53%0@)S$G+`H@
M*B`@("`@2T59(&%L:6%S("AA;&EA<RD*("H@*3L*("H*("H@0U)%051%(%1!
M0DQ%(&QO9R`H"B`J("`@("!I9"`@("`@("`@("!)3E0H,3$I($Y/5"!.54Q,
M($%55$]?24Y#4D5-14Y4+`H@*B`@("`@;7-G("`@("`@("`@5$585"!.3U0@
M3E5,3"P*("H@("`@('5S97(@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,
M3"!$149!54Q4("<G+`H@*B`@("`@:&]S="`@("`@("`@5D%20TA!4B@R-34I
M($Y/5"!.54Q,($1%1D%53%0@)R<L"B`J("`@("!T:6UE("`@("`@("!$051%
M5$E-12!.3U0@3E5,3"!$149!54Q4("<R,#`P+3`P+3`P(#`P.C`P.C`P)RP*
M("H@("`@('!I9"`@("`@("`@(%9!4D-(05(H,C4U*2!.3U0@3E5,3"!$149!
M54Q4("<G+`H@*B`@("`@4%))34%262!+15D@*&ED*0H@*B`I.PH@*B`\+W!R
M93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO075T:"]!=71H+V-Y<G-Q;"YP
M:'`L=B`Q+C,S+C$P+C$T(#(P,#8O,#@O,30@,#(Z-#@Z-#@@8VAU8VL@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!);'EA(#QM86EL0&MR96PN
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!);'EA
M(#QM86EL0&MR96PN;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]C>7)S<6P@97AT96YD<R!!
M=71H7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R
M96YT($E-05`@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U
M<F-E"B`@("`@*B\*("`@('9A<B`D7VEM87!3=')E86T["@H@("`@+RHJ"B`@
M("`@*B!(86YD;&4@9F]R(&%N($E-05!?061M:6X@;V)J96-T+@H@("`@("H*
M("`@("`J($!V87(@24U!4%]!9&UI;@H@("`@("HO"B`@("!V87(@)%]A9&UI
M;CL*"B`@("`O*BH*("`@("`J($AI97)A<F-H>2!S97!A<F%T;W(@=&\@=7-E
M("AE+F<N+"!I<R!I="!U<V5R+VUA:6QB;W@@;W(@=7-E<BYM86EL8F]X*0H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E
M<&%R871O<B`]("<N)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($%U=&A?8WER<W%L*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=I;6%P)RDI('L*
M("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%\H(D%U=&A?8WER<W%L.B!297%U
M:7)E9"!I;6%P(&5X=&5N<VEO;B!N;W0@9F]U;F0N(BDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@('!A<F5N=#HZ075T:%]S<6PH
M)'!A<F%M<RD["@H@("`@("`@("1A9&UI;E]P87)A;7,@/2!A<G)A>2@G861M
M:6Y?=7-E<B<@/3X@)'!A<F%M<ULG8WER861M:6XG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%D;6EN7W!A<W-W;W)D)R`]/B`D<&%R86US
M6R=C>7)P87-S)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D
M<VXG(#T^("1P87)A;7-;)VEM87!?9'-N)UTI.PH@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]P87)A;7-;)W5N:7AH:65R)UTI*2!["B`@("`@("`@("`@
M("1A9&UI;E]P87)A;7-;)W5S97)H:65R87)C:'DG72`]("=U<V5R+R<["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?861M:6X@/2`F;F5W($E-05!?061M
M:6XH)&%D;6EN7W!A<F%M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@
M82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@("`@(%1H92!U<V5R260@
M=&\@861D+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H
M92!C<F5D96YT:6%L<R!T;R!A9&0N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D57-E<B@D=7-E
M<DED+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN
M96-T*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;
M)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES
M="@D;F%M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`)RP@)'5S97))9"D["B`@
M("`@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T525"!)3E1/("5S("@E<RP@)7,L
M("5S*2!604Q515,@*#\L(#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE
M;&0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG9&]M86EN7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D7V9I96QD)UTI.PH@("`@
M("`@("`@("`D=F%L=65S(#T@87)R87DH)&YA;64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&]M86EN+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F=E=$-R>7!T961087-S=V]R9"@D8W)E9&5N=&EA;'-;
M)W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG96YC<GEP=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<VAO=U]E;F-R>7!T:6]N)UTI*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ.F%D9%5S97(H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["@H@("`@("`@("`@("`D9&)R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R
M>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("`D<75E<GD@/2`G24Y3
M15)4($E.5$\@=FER='5A;"`H86QI87,L(&1E<W0L('5S97)N86UE+"!S=&%T
M=7,I(%9!3%5%4R`H/RP@/RP@/RP@,2DG.PH@("`@("`@("`@("`D=F%L=65S
M(#T@87)R87DH)'5S97))9"P@)&YA;64L("1N86UE*3L*"B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@075T:%]C>7)S<6PZ
M.F%D9%5S97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`D9&)R97-U;'0R(#T@)'1H
M:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&1B<F5S=6QT,BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1D8G)E<W5L=#(["B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9&)R97-U;'0@/2!P87)E;G0Z
M.F%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*3L*("`@("`@("`@("`@
M)&YA;64@/2`D=7-E<DED.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D
M9&)R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1D8G)E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?82@D<F5S
M=6QT(#T@)'1H:7,M/E]A9&UI;BT^861D36%I;&)O>"@D;F%M92DL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@0&%R<F%Y7W=A;&LH)'1H:7,M/E]P
M87)A;7-;)V9O;&1E<G,G72P*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)'1H:7,L("=?8W)E871E4W5B1F]L9&5R<R<I+"`D;F%M92D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)TE-
M05`@;6%I;&)O>"!C<F5A=&EO;B!F;W(@)R`N("1N86UE("X@)R!F86EL960Z
M("<@+B`D<F5S=6QT+3YG971-97-S86=E*"DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*"))34%0(&UA:6QB;W@@8W)E871I;VX@9F%I;&5D.B`E<R(I+"`D<F5S
M=6QT+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A<F%M<ULG<75O=&$G72D@)B8@)'1H:7,M/E]P87)A
M;7-;)W%U;W1A)UT@/CT@,"D@>PH@("`@("`@("`@("!I9B`H(4!I;6%P7W-E
M=%]Q=6]T82@D=&AI<RT^7VEM87!3=')E86TL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=U<V5R)R`N("1T:&ES+3Y?<V5P87)A=&]R("X@
M)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R86US6R=Q=6]T82==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*"))34%0(&UA:6QB;W@@<75O
M=&$@8W)E871I;VX@9F%I;&5D.B`E<R(I+"!I;6%P7VQA<W1?97)R;W(H*2DI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A('-E="!O9B!A=71H
M96YT:6-A=&EO;B!C<F5D96YT:6%L<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U<V5R260@(%1H92!U<V5R260@=&\@9&5L971E+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@4W5C8V5S<R!O<B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@
M("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]
M("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@
M/2!E>'!L;V1E*"=`)RP@)'5S97))9"D["B`@("`@("`@("`@("\J($)U:6QD
M('1H92!344P@<75E<GDN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H)T1%3$5412!&4D]-("5S(%=(15)%("5S(#T@/R!A;F0@)7,@/2`_)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;65?9FEE;&0G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG9&]M86EN7V9I96QD)UTI.PH@
M("`@("`@("`@("`D=F%L=65S(#T@87)R87DH)&YA;64L("1D;VUA:6XI.PH*
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!!
M=71H7V-Y<G-Q;#HZ<F5M;W9E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("1D
M8G)E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD[
M"B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/32!V:7)T=6%L(%=(
M15)%(&1E<W0@/2`_)SL*("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1N
M86UE*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@075T:%]C>7)S<6PZ.G)E;6]V955S97(H*3H@)R`N("1Q=65R>2P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("`@("`D9&)R97-U;'0R(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D
M=F%L=65S*3L*("`@("`@("`@("`@:68@*&ES7V$H)&1B<F5S=6QT,BP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D8G)E<W5L
M=#(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D9&)R97-U;'0@/2!P87)E;G0Z.G)E;6]V955S97(H)'5S97))9"D["B`@
M("`@("`@("`@("1N86UE(#T@)'5S97))9#L*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<U]A*"1D8G)E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&1B<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1&5L971E($E-05`@;6%I;&)O>"X@*B\*("`@("`@("`D:6UA<')E<W5L="`]
M("1T:&ES+3Y?861M:6XM/G)E;6]V94UA:6QB;W@H)&YA;64I.PH*("`@("`@
M("!I9B`H:7-?82@D:6UA<')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DE-
M05`@;6%I;&)O>"!D96QE=&EO;B!F86EL960Z("5S(BDL("1I;6%P<F5S=6QT
M+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&-O;FYE8W1I;VYS('1O('1H92!3
M44P@86YD($E-05`@<V5R=F5R<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@
M*"$D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!P87)E;G0Z.E]C
M;VYN96-T*"D["@H@("`@("`@("`@("`O+R!297-E="!T:&4@)%]C;VYN96-T
M960@9FQA9SL@=V4@:&%V96XG="!Y970@<W5C8V5S<V9U;&QY(&]P96YE9`H@
M("`@("`@("`@("`O+R!E=F5R>71H:6YG+@H@("`@("`@("`@("`D=&AI<RT^
M7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("`@("`@("`@)'1H:7,M/E]I;6%P
M4W1R96%M(#T@0&EM87!?;W!E;B@D=&AI<RT^7W!A<F%M<ULG:6UA<%]D<VXG
M72P@)'1H:7,M/E]P87)A;7-;)V-Y<F%D;6EN)UTL("1T:&ES+3Y?<&%R86US
M6R=C>7)P87-S)UTL($]07TA!3$9/4$5.*3L*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^7VEM87!3=')E86TI('L*("`@("`@("`@("`@("`@($AO<F1E.CIF
M871A;"AS<')I;G1F*%\H(D-A;B=T(&-O;FYE8W0@=&\@24U!4"!S97)V97(Z
M("5S(BDL(&EM87!?;&%S=%]E<G)O<B@I*2P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7W!A<F%M<ULG=6YI>&AI97(G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V5P87)A=&]R(#T@)R\G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N
M;F5C="!F<F]M('1H92!344P@86YD($E-05`@<V5R=F5R<R!A;F0@8VQE86X@
M=7`@=&AE(&-O;FYE8W1I;VYS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N
M;F5C=&5D*2!["B`@("`@("`@("`@('!A<F5N=#HZ7V1I<V-O;FYE8W0H*3L*
M("`@("`@("`@("`@0&EM87!?8VQO<V4H)'1H:7,M/E]I;6%P4W1R96%M*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0W)E871E<R!A;&P@;6%I;&)O>&5S('-U<'!L:65D(&EN(&-O
M;F9I9W5R871I;VX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1V86QU90H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:V5Y("`@("`@56YU<V5D(&)Y('1H:7,@9')I=F5R"B`@("`@
M*B!`<&%R86T@<W1R:6YG('5S97).86UE"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C<F5A=&53=6)&;VQD97)S*"1V86QU92P@)&ME>2P@)'5S97).86UE*0H@
M("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O;6%I
M;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@;&ES="@D
M=7-E<DYA;64I(#T@97AP;&]D92@G0"<L("1U<V5R3F%M92D["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?861M:6XM/F%D9$UA:6QB;W@H)'5S97).86UE
M("X@)'1H:7,M/E]S97!A<F%T;W(@+B`D=F%L=64I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3&ES="!A;&P@=7-E<G,@:6X@=&AE('-Y<W1E;2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@87)R87D@;V8@=7-E<DED<RP@
M;W(@9F%L<V4@;VX@9F%I;'5R92]U;G-U<'!O<G1E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*("`@("`@("`O*B!?8V]N;F5C
M="@I('=I;&P@9&EE('=I=&@@2&]R9&4Z.F9A=&%L*"D@=7!O;B!F86EL=7)E
M+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72D@)B8*("`@
M("`@("`@("`@*"1T:&ES+3Y?<&%R86US6R=D;VUA:6Y?9FEE;&0G72`A/2`G
M;F]N92<I*2!["B`@("`@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GD@
M=VET:"!D;VUA:6XN("HO"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M)U-%3$5#5"`E<RP@)7,@1E)/32`E<R!/4D1%4B!"62`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE
M7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F
M:65L9"==*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!"=6EL
M9"!T:&4@4U%,('%U97)Y('=I=&AO=70@9&]M86EN+B`J+PH@("`@("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!/4D1%4B!"
M62`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W5S97)N86UE7V9I96QD)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S97)N86UE7V9I
M96QD)UTI.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!!=71H7V-Y<G-Q;#HZ;&ES=%5S97)S*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q=65R>2P@
M;G5L;"P@1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O*B!,;V]P('1H<F]U9V@@
M86YD(&)U:6QD(')E='5R;B!A<G)A>2X@*B\*("`@("`@("`D=7-E<G,@/2!A
M<G)A>2@I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;)V1O
M;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H)'1H:7,M/E]P87)A;7-;
M)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)')E<W5L="!A<R`D87(I('L*("`@("`@("`@("`@("`@("1U<V5R
M<UM=(#T@)&%R6S!=("X@)T`G("X@)&%R6S%=.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@9F]R96%C:"`H)')E<W5L="!A
M<R`D87(I('L*("`@("`@("`@("`@("`@("1U<V5R<UM=(#T@)&%R6S!=.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5S97)S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E(&$@<V5T(&]F(&%U=&AE
M;G1I8V%T:6]N(&-R961E;G1I86QS+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&]L9$E$("`@("`@(%1H92!O;&0@=7-E<DED+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F5W240@("`@("`@5&AE(&YE=R!U<V5R260N"B`@("`@
M*B!`<&%R86T@87)R87D@)&-R961E;G1I86QS("!4:&4@;F5W(&-R961E;G1I
M86QS"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7!D871E57-E<B@D;VQD240L("1N97=)1"P@)&-R
M961E;G1I86QS*0H@("`@>PH@("`@("`@("\J(%]C;VYN96-T*"D@=VEL;"!D
M:64@=VET:"!(;W)D93HZ9F%T86PH*2!U<&]N(&9A:6QU<F4N("HO"B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==*2`F)@H@("`@("`@("`@("`H
M)'1H:7,M/E]P87)A;7-;)V1O;6%I;E]F:65L9"==("$]("=N;VYE)RDI('L*
M("`@("`@("`@("`@;&ES="@D;F%M92P@)&1O;6%I;BD@/2!E>'!L;V1E*"=`
M)RP@)&]L9$E$*3L*("`@("`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R
M>2!W:71H(&1O;6%I;BX@*B\*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@/2`_(&%N9"`E<R`]
M(#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=P87-S=V]R9%]F:65L9"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M95]F:65L
M9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=D;VUA:6Y?9FEE;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A
M<G)A>2@D=&AI<RT^9V5T0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG
M<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=E;F-R>7!T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S
M:&]W7V5N8W)Y<'1I;VXG72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M92P@)&1O;6%I;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`@("`@)'%U
M97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"`E<R`](#\@5TA%4D4@)7,@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F1?9FEE;&0G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;65?9FEE
M;&0G72D["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^9V5T
M0W)Y<'1E9%!A<W-W;W)D*"1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=E;F-R>7!T:6]N
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=S:&]W7V5N8W)Y<'1I;VXG
M72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;VQD240I.PH@("`@
M("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!!=71H7V-Y<G-Q;#HZ=7!D871E57-E<B@I.B`G("X@)'%U97)Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O075T:"]Y86AO;RYP:'``````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#4P-C`@,3`U,34T,S0Q-#`@,#(R,#<Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@075T:%]Y86AO;SHZ(&-L87-S(&-H96-K<R!L;V=I;B!C<F5D
M96YT:6%L<R!A9V%I;G-T(%EA:&]O(2!M86EL"B`J(&%C8V]U;G1S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O>6%H;V\N<&AP+'8@,2XQ
M,RXQ,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!Y86AO;SHO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]!=71H"B`J+PIC;&%S<R!!=71H7WEA:&]O
M(&5X=&5N9',@075T:"!["@H@("`@+RHJ"B`@("`@*B!`=F%R($A45%!?4F5Q
M=65S=`H@("`@("HO"B`@("!V87(@)%]H='1P.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!986AO;R!A=71H96YT:6-A=&EO;B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C
M;VYT86EN:6YG('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U
M=&A?>6%H;V\H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1FEN9"!O=70@:68@82!S970@;V8@;&]G:6X@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97))9"`@("`@("!4:&4@=7-E<DED('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8W)E9&5N=&EA;',@(%1H
M92!C<F5D96YT:6%L<R!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@87)E('9A
M;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R
M260L("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@
M)TA45%`O4F5Q=65S="YP:'`G.PH*("`@("`@("`O+R!-86ME('-U<F4@=&AA
M="!W92!H879E(&$@8F%R92!U<V5R;F%M92`M('-T<FEP(&]F9B!A;GET:&EN
M9PH@("`@("`@("\O(&%F=&5R("AA;F0@:6YC;'5D:6YG*2!T:&4@9FER<W0@
M0"P@:68@=&AE<F4@:7,@;VYE+@H@("`@("`@("1P;W,@/2!S=')P;W,H)'5S
M97))9"P@)T`G*3L*("`@("`@("!I9B`H)'!O<R`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@)'5S97))9"`]('-U8G-T<B@D=7-E<DED+"`P+"`D<&]S*3L*
M("`@("`@("!]"@H@("`@("`@("1O<'1I;VYS6R=M971H;V0G72`]($A45%!?
M4D5154535%]-151(3T1?4$]35#L*("`@("`@("`D;W!T:6]N<ULG=&EM96]U
M="==(#T@-3L*("`@("`@("`D;W!T:6]N<ULG86QL;W=2961I<F5C=',G72`]
M('1R=64["@H@("`@("`@("1T:&ES+3Y?:'1T<"`]("9N97<@2%144%]297%U
M97-T*"=H='1P.B\O;&]G:6XN>6%H;V\N8V]M+V-O;F9I9R]L;V=I;B<L("1O
M<'1I;VYS*3L*("`@("`@("`D=&AI<RT^7VAT='`M/F%D9%!O<W1$871A*"=L
M;V=I;B<L("1U<V5R260I.PH@("`@("`@("1T:&ES+3Y?:'1T<"T^861D4&]S
M=$1A=&$H)W!A<W-W9"<L("1C<F5D96YT:6%L<ULG<&%S<W=O<F0G72D["@H@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VAT='`M/G-E;F1297%U97-T*"D[
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)')E<W5L="T^9V5T365S<V%G92@I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7VAT='`M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@("`@("`@("`D8V]O:VEE
M<R`]("1T:&ES+3Y?:'1T<"T^9V5T4F5S<&]N<V5#;V]K:65S*"D["B`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D8V]O:VEE<RDI('L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1C;V]K:65S(&%S("1C;V]K:64I('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7VAT='`M/F%D9$-O;VMI92@D8V]O:VEE6R=N
M86UE)UTL("1C;V]K:65;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!4:&ES(&ES(%]S
M=6-H7R!A(&AA8VLL(&)U="!I="!W;W)K<RX*("`@("`@("!I9B`H(7!R96=?
M;6%T8V@H)WQI;G9A;&ED('!A<W-W;W)D?&DG+"`D<F5S=6QT*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!(;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)'1H:7,M/E]S
M971!=71H17)R;W(H05542%]214%33TY?0D%$3$]'24XI.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]!=71H+W!A
M;2YP:'``````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-3,R,R`Q,#4Q-30S-#$T,"`P,C$U,S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!!=71H7W!A
M;3HZ(&-L87-S('!R;W9I9&5S(&$@4$%-+6)A<V5D(&EM<&QE;65N=&%T:6]N
M(&]F('1H92!(;W)D90H@*B!A=71H96YT:6-A=&EO;B!S>7-T96TN"B`J"B`J
M(%!!32`H4&QU9V=A8FQE($%U=&AE;G1I8V%T:6]N($UO9'5L97,I(&ES(&$@
M9FQE>&EB;&4@;65C:&%N:7-M(&9O<@H@*B!A=71H96YT:6-A=&EN9R!U<V5R
M<RX@($ET(&AA<R!B96-O;64@=&AE('-T86YD87)D(&%U=&AE;G1I8V%T:6]N
M('-Y<W1E;2!F;W(*("H@3&EN=7@L(%-O;&%R:7,@86YD($9R965"4T0N"B`J
M"B`J(%1H:7,@:6UP;&5M96YT871I;VX@<F5Q=6ER97,@0VAA9"!#=6YN:6YG
M:&%M)W,@<&%M7V%U=&@@97AT96YS:6]N.@H@*@H@*B`@("`@(&AT='`Z+R]W
M=W<N;6%T:"YO:&EO+7-T871E+F5D=2]^8V-U;FYI;F<O<&%M7V%U=&@O"B`J
M"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G<V5R=FEC92<@
M(%1H92!N86UE(&]F('1H92!004T@<V5R=FEC92!T;R!U<V4@=VAE;B!A=71H
M96YT:6-A=&EN9RX*("H@("`@("`@("`@("`@($1%1D%53%0Z('!H<#PO<')E
M/@H@*@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O<&%M+G!H
M<"QV(#$N,RXQ,"XQ,2`R,#`V+S`Q+S`Q(#(Q.C(X.C`W(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4&%R:7-E
M(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A
M8VMA9V4@2&]R9&5?075T:`H@*B\*8VQA<W,@075T:%]P86T@97AT96YD<R!!
M=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE
M<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J
M(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A
M<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5P9&%T92<@("`@("`@
M(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S
M971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R96UO=F4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-P87)E;G0G("`@
M/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!0
M04T@875T:&5N=&EC871I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($%U=&A?<&%M*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)W-E<G9I
M8V4G72DI('L*("`@("`@("`@("`@:6YI7W-E="@G<&%M7V%U=&@N<V5R=FEC
M96YA;64G+"`D<&%R86US6R=S97)V:6-E)UTI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=P86U?875T:"<I*2!["B`@("`@
M("`@("`@(&1L*"=P86U?875T:"YS;R<I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T(&]F(&QO9VEN(&-R961E
M;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R260@("`@("!4
M:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D
M96YT:6%L<R`@06X@87)R87D@;V8@;&]G:6X@8W)E9&5N=&EA;',N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@
M8W)E9&5N=&EA;',@87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M875T:&5N=&EC871E*"1U<V5R260L("1C<F5D96YT:6%L<RD*("`@('L*("`@
M("`@("!I9B`H96UP='DH)&-R961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@
M("`@("`@("`@("!(;W)D93HZ9F%T86PH7R@B3F\@<&%S<W=O<F0@<')O=FED
M960@9F]R($QO9VEN(&%U=&AE;G1I8V%T:6]N+B(I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A
M9&5D*"=P86U?875T:"<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A?
M*")004T@875T:&5N=&EC871I;VX@:7,@;F]T(&%V86EL86)L92XB*2P@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A<&%M
M7V%U=&@H)'5S97))9"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==+"`F)&5R
M<F]R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(
M7U)%05-/3E]-15-304=%+"`D97)R;W(I.PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O:6US<"YP:'``````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-#4V(#$P-3$U-#,T,30P
M(#`R,3<S,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($%U=&A?:6US<"!C;&%S<R!P<F]V:61E
M<R!B87-I8R!A=71H96YT:6-A=&EO;B!A9V%I;G-T(&%N($E-4U`@<V5R=F5R
M+@H@*B!4:&ES('=I;&P@8F4@;6]S="!B96YI9FEC:6%L(&EF(&%L<F5A9'D@
M=7-I;F<@86X@24U34"!B87-E9"!P<F5F97)E;F-E"B`J('-Y<W1E;2!O<B!)
M35-0(&)A<V5D(&%D9')E<W-B;V]K('-Y<W1E;0H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]!=71H+T%U=&@O:6US<"YP:'`L=B`Q+C(N,3`N,3`@,C`P-B\P
M,2\P,2`R,3HR.#HP-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!-:6-H865L(%)U8FEN<VMY(#QM<G5B:6YS:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%)U8FEN<VMY(#QM
M<G5B:6YS:T!H;W)D92YO<F<^"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO
M"F-L87-S($%U=&A?:6US<"!E>'1E;F1S($%U=&A["@H@("`@+RHJ"B`@("`@
M*B!!;B!A<G)A>2!O9B!C87!A8FEL:71I97,L('-O('1H870@=&AE(&1R:79E
M<B!C86X@<F5P;W)T('=H:6-H"B`@("`@*B!O<&5R871I;VYS(&ET('-U<'!O
M<G1S(&%N9"!W:&EC:"!I="!D;V5S;B=T+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1C87!A8FEL:71I97,@/2!A<G)A>2@G
M861D)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=U<&1A=&4G("`@("`@("`]/B!F86QS92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E<V5T<&%S<W=O<F0G(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5M;W9E)R`@("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L
M:7-T)R`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W1R86YS<&%R96YT)R`@(#T^(&9A;'-E*3L*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(@9G5N8W1I;VXN($-R96%T97,@;F5W($%U=&A?
M:6US<"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@02!H87-H(&-O;G1A:6YI;F<@<&%R86UE=&5R<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@075T:%]I;7-P*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<V5T4&%R86US*"1P87)A;7,I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4')I=F%T92!A=71H96YT:6-A=&EO;B!F=6YC=&EO;BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1U<V5R240@57-E<FYA;64@9F]R($E-4U`@<V5R=F5R
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1C<F5D96YT:6%L<R!(87-H(&-O;G1A
M:6YI;F<@)W!A<W-W;W)D)R!E;&5M96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B!4<G5E(&]N('-U8V-E<W,@+R!&86QS92!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E*"1U<V5R240L
M("1C<F5D96YT:6%L<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TYE
M="])35-0+T%U=&@N<&AP)SL*"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE)UT@/2`D=7-E<DE$.PH@("`@("`@("1T:&ES+3Y?<&%R86US6R=P
M87-S=V]R9"==(#T@)&-R961E;G1I86QS6R=P87-S=V]R9"==.PH@("`@("`@
M("1I;7-P(#T@)DYE=%])35-07T%U=&@Z.G-I;F=L971O;B@D=&AI<RT^7W!A
M<F%M<ULG875T:%]M971H;V0G72D["@H@("`@("`@(&EF("AI<U]A*"1I;7-P
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6US<#L*
M("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D:6US<"T^875T:&5N=&EC
M871E*"1T:&ES+3Y?<&%R86US+"!F86QS92D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]"041,3T=)3BD["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#:&5C:W,@=&AE('!A<F%M<R!A<G)A>2!A;F0@<V5T<R!D969A=6QT('9A
M;'5E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US($AA<V@@8V]N=&%I;FEN9R!)35-0('!A<F%M
M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971087)A;7,H)'!A<F%M
M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<V5R=F5R)UT@/2`D
M<&%R86US6R=S97)V97(G73L*("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R
M="==(#T@)'!A<F%M<ULG<&]R="==.PH@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=A=71H7VUE=&AO9"==(#T@)'!A<F%M<ULG875T:%]M971H;V0G73L*"B`@
M("`@("`@:68@*&ES<V5T*"1P87)A;7-;)V%U=&A?;65C:&%N:7-M)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=A=71H7VUE8VAA;FES;2==
M(#T@)'!A<F%M<ULG875T:%]M96-H86YI<VTG73L*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W-O8VME="==(#T@)'!A<F%M<ULG<V]C:V5T)UT["B`@
M("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=C;VUM86YD)UT@/2`D<&%R86US
M6R=C;VUM86YD)UT["B`@("`@("`@?0H@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O075T:"]R861I=7,N<&AP````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,30W,30@,3`U,34T,S0Q-#`@,#(R,C0W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&4@075T:%]R861I=7,@8VQA<W,@<')O=FED97,@82!2041)55,@:6UP
M;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J(&%U=&AE;G1I8V%T:6]N('-Y
M<W1E;2X*("H*("H@5&AI<R!C;&%S<R!R97%U:7)E<R!T:&4@)W)A9&EU<R<@
M4$5#3"!E>'1E;G-I;VXN"B`J(%)!1$E54R!014-,(&5X=&5N<VEO;CH@:'1T
M<#HO+W!E8VPN<&AP+FYE="]P86-K86=E+W)A9&EU<PH@*@H@*B!/;B`J;FEX
M+7D@;6%C:&EN97,L('1H:7,@97AT96YS:6]N(&-A;B!B92!I;G-T86QL960@
M87,@9F]L;&]W<SH\<')E/@H@*B`@(")P96%R(&EN<W1A;&P@<F%D:75S(CPO
M<')E/@H@*@H@*B!4:&5N+"!E9&ET('EO=7(@<&AP+FEN:2!F:6QE(&%N9"!M
M86ME('-U<F4@=&AE(&9O;&QO=VEN9R!L:6YE(&ES('!R97-E;G0Z/'!R93X*
M("H@("!&;W(@5VEN9&]W<R!M86-H:6YE<SH@(&5X=&5N<VEO;CUP:'!?<F%D
M:75S+F1L;`H@*B`@($9O<B!A;&P@;W1H97)S.B`@("`@("`@97AT96YS:6]N
M/7)A9&EU<RYS;SPO<')E/@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP
M<F4^"B`J("`@)VAO<W0G("`@(%1H92!2041)55,@:&]S="!T;R!U<V4@*$E0
M(&%D9')E<W,@;W(@9G5L;'D@<75A;&EF:65D"B`J("`@("`@("`@("`@(&AO
M<W1N86UE*2X*("H@("`G;65T:&]D)R`@5&AE(%)!1$E54R!M971H;V0@=&\@
M=7-E(&9O<B!V86QI9&%T:6YG('1H92!R97%U97-T+@H@*B`@("`@("`@("`@
M("!%:71H97(Z("=005`G+"`G0TA!4%]-1#4G+"`G35-#2$%0=C$G+"!O<B`G
M35-#2$%0=C(G+@H@*B`@("`@("`@("`@("`J*B!#55)214Y43%DL(&]N;'D@
M)U!!4"<@:7,@<W5P<&]R=&5D+B`J*@H@*B`@("=S96-R970G("!4:&4@4D%$
M2553('-H87)E9"!S96-R970@<W1R:6YG(&9O<B!T:&4@:&]S="X@5&AE"B`J
M("`@("`@("`@("`@(%)!1$E54R!P<F]T;V-O;"!I9VYO<F5S(&%L;"!B=70@
M=&AE(&QE861I;F<@,3(X(&)Y=&5S"B`J("`@("`@("`@("`@(&]F('1H92!S
M:&%R960@<V5C<F5T+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)VYA<R<@("`@("!4:&4@4D%$2553($Y!4R!I9&5N=&EF
M:65R('1O('5S92X*("H@("`@("`@("`@("`@($1%1D%53%0Z(%1H92!V86QU
M92!O9B`D7U-%4E9%4ELG2%144%](3U-4)UT@;W(L(&EF(&YO=`H@*B`@("`@
M("`@("`@("`@("`@("`@("`@9&5F:6YE9"P@=&AE;B`G;&]C86QH;W-T)RX*
M("H@("`G<&]R="<@("`@(%1H92!P;W)T('1O('5S92!O;B!T:&4@4D%$2553
M('-E<G9E<BX*("H@("`@("`@("`@("`@($1%1D%53%0Z(%=H871E=F5R('1H
M92!L;V-A;"!S>7-T96T@:61E;G1I9FEE<R!A<R!T:&4*("H@("`@("`@("`@
M("`@("`@("`@("`@("=R861I=7,G(%5$4"!P;W)T"B`J("`@)W)E=')I97,G
M("!4:&4@;6%X:6UU;2!N=6UB97(@;V8@<F5P96%T960@<F5Q=65S=',@=&\@
M;6%K92!B969O<F4*("H@("`@("`@("`@("`@(&=I=FEN9R!U<"X*("H@("`@
M("`@("`@("`@($1%1D%53%0Z(#,*("H@("`G<W5F9FEX)R`@(%1H92!D;VUA
M:6X@;F%M92!T;R!A9&0@=&\@=6YQ=6%L:69I960@=7-E<B!N86UE<RX*("H@
M("`@("`@("`@("`@($1%1D%53%0Z($Y/3D4*("H@("`G=&EM96]U="<@(%1H
M92!T:6UE;W5T(&9O<B!R96-E:79I;F<@<F5P;&EE<R!F<F]M('1H92!S97)V
M97(@*&EN"B`J("`@("`@("`@("`@("!S96-O;F1S*2X*("H@("`@("`@("`@
M("`@($1%1D%53%0Z(#,@<V5C;VYD<SPO<')E/@H@*@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]!=71H+T%U=&@O<F%D:75S+G!H<"QV(#$N,C0N."XX(#(P
M,#8O,#$O,#$@,C$Z,C@Z,#<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L
M;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?075T:`H@*B\*
M8VQA<W,@075T:%]R861I=7,@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@
M("`J($%N(&%R<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I
M=F5R(&-A;B!R97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P
M<&]R=',@86YD('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y
M*"=A9&0G("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@
M("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VQI<W0G("`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!2041)55,@875T:&5N=&EC871I
M;VX@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N($%U=&A?<F%D:75S*"1P87)A;7,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S
M*"=R861I=7,G*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)T%U=&A?
M<F%D:75S(')E<75I<F5S('1H92!R861I=7,@4$5#3"!E>'1E;G-I;VX@=&\@
M8F4@;&]A9&5D+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!P87)A;65T97)S+@H@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!4:&4@<&%R86UE=&5R(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]S971087)A;7,H)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!!(%)!1$E5
M4R!H;W-T(&ES(')E<75I<F5D+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R
M86US6R=H;W-T)UTI*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@G075T
M:%]R861I=7,@<F5Q=6ER97,@82!2041)55,@:&]S="!T;R!C;VYN96-T('1O
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O
M*B!!(%)!1$E54R!S96-R970@<W1R:6YG(&ES(')E<75I<F5D+B`J+PH@("`@
M("`@(&EF("AE;7!T>2@D<&%R86US6R=S96-R970G72DI('L*("`@("`@("`@
M("`@2&]R9&4Z.F9A=&%L*"=!=71H7W)A9&EU<R!R97%U:7)E<R!A(%)!1$E5
M4R!S96-R970@<W1R:6YG+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`O*B!!(%)!1$E54R!A=71H96YT:6-A=&EO;B!M971H
M;V0@:7,@<F5Q=6ER960N("HO"B`@("`@("`@:68@*&5M<'1Y*"1P87)A;7-;
M)VUE=&AO9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)T%U=&A?
M<F%D:75S(')E<75I<F5S(&$@4D%$2553(&%U=&AE;G1I8V%T:6]N(&UE=&AO
M9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4D%$2553($Y!4R!)9&5N=&EF:65R+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D<&%R86US6R=N87,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG;F%S
M)UT@/2!I<W-E="@D7U-%4E9%4ELG2%144%](3U-4)UTI(#\@)%]315)615);
M)TA45%!?2$]35"<*72`Z("=L;V-A;&AO<W0G.PH@("`@("`@('T*"B`@("`@
M("`@+RH@4W5F9FEX('1O(&%D9"!T;R!U;G%U86QI9FEE9"!U<V5R(&YA;65S
M+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=S=69F:7@G72DI('L*
M("`@("`@("`@("`@)'!A<F%M<ULG<W5F9FEX)UT@/2`G)SL*("`@("`@("!]
M"@H@("`@("`@("\J(%1H92!2041)55,@<&]R="!T;R!U<V4N("HO"B`@("`@
M("`@:68@*&5M<'1Y*"1P87)A;7-;)W!O<G0G72DI('L*("`@("`@("`@("`@
M)'!A<F%M<ULG<&]R="==(#T@,#L*("`@("`@("!]"@H@("`@("`@("\J($UA
M>&EM=6T@;G5M8F5R(&]F(')E=')I97,N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1P87)A;7-;)W)E=')I97,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG
M<F5T<FEE<R==(#T@,SL*("`@("`@("!]"@H@("`@("`@("\J(%)!1$E54R!T
M:6UE;W5T+B`J+PH@("`@("`@(&EF("AE;7!T>2@D<&%R86US6R=T:6UE;W5T
M)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)W1I;65O=70G72`](#,["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD(&]U="!I9B!A('-E="!O9B!L;V=I
M;B!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FYA
M;64@("`@5&AE('5S97))9"!T;R!C:&5C:RX*("`@("`J($!P87)A;2!A<G)A
M>2`D8W)E9&5N=&EA;',@($%N(&%R<F%Y(&]F(&QO9VEN(&-R961E;G1I86QS
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@1F]R(')A9&EU
M<RP@=&AI<R!M=7-T(&-O;G1A:6X@82!P87-S=V]R9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@96YT<GDN"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&4@8W)E9&5N=&EA;',@
M87)E('9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!?875T:&5N=&EC871E
M*"1U<V5R;F%M92P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@("\J(%!A
M<W-W;W)D(&ES(')E<75I<F5D+B`J+PH@("`@("`@(&EF("@A:7-S970H)&-R
M961E;G1I86QS6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M9F%T86PH7R@B4&%S<W=O<F0@<F5Q=6ER960@9F]R(%)!1$E54R!A=71H96YT
M:6-A=&EO;BXB*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("1R97,@/2!R861I=7-?875T:%]O<&5N*"D["B`@("`@("`@<F%D
M:75S7V%D9%]S97)V97(H)')E<RP@)'1H:7,M/E]P87)A;7-;)VAO<W0G72P@
M)'1H:7,M/E]P87)A;7-;)W!O<G0G72P@)'1H:7,M/E]P87)A;7-;)W-E8W)E
M="==+"`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==+"`D=&AI<RT^7W!A<F%M
M<ULG<F5T<FEE<R==*3L*("`@("`@("!R861I=7-?8W)E871E7W)E<75E<W0H
M)')E<RP@4D%$25537T%#0T534U]215%515-4*3L*("`@("`@("!R861I=7-?
M<'5T7V%T='(H)')E<RP@4D%$25537TY!4U])1$5.5$E&2452+"`D=&AI<RT^
M7W!A<F%M<ULG;F%S)UTI.PH@("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S
M+"!2041)55-?3D%37U!/4E1?5%E012P@4D%$25537U9)4E1504PI.PH@("`@
M("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2041)55-?4T525DE#15]465!%
M+"!2041)55-?1E)!345$*3L*("`@("`@("!R861I=7-?<'5T7V%T='(H)')E
M<RP@4D%$25537T9204U%1%]04D]43T-/3"P@4D%$25537U!04"D["B`@("`@
M("`@<F%D:75S7W!U=%]A='1R*"1R97,L(%)!1$E54U]#04Q,24Y'7U-4051)
M3TY?240L(&ES<V5T*"1?4T525D526R=214U/5$5?2$]35"==*2`_("1?4T52
M5D526R=214U/5$5?2$]35"==(#H@)S$R-RXP+C`N,2<I.PH*("`@("`@("`O
M*B!);G-E<G0@=7-E<FYA;64O<&%S<W=O<F0@:6YT;R!R97%U97-T+B`J+PH@
M("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2041)55-?55-%4E].04U%
M+"`D=7-E<FYA;64I.PH@("`@("`@(')A9&EU<U]P=71?871T<B@D<F5S+"!2
M041)55-?55-%4E]005-35T]21"P@)&-R961E;G1I86QS6R=P87-S=V]R9"==
M*3L*"B`@("`@("`@+RH@4V5N9"!R97%U97-T+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@<F%D:75S7W-E;F1?<F5Q=65S="@D<F5S*3L*"B`@("`@("`@<W=I
M=&-H("@D<W5C8V5S<RD@>PH@("`@("`@(&-A<V4@4D%$25537T%#0T534U]!
M0T-%4%0Z"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!C87-E
M(%)!1$E54U]!0T-%4U-?4D5*14-4.@H@("`@("`@("`@("`D=&AI<RT^7W-E
M=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!?*")!=71H96YT:6-A
M=&EO;B!R96IE8W1E9"!B>2!2041)55,@<V5R=F5R+B(I*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`D=&AI<RT^7W-E=$%U=&A%<G)O<BA!551(7U)%05-/3E]-15-304=%+"!R
M861I=7-?<W1R97)R;W(H)')E<RDI.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T%U=&@O87!P;&EC871I;VXN<&AP````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$T-#4P(#$P-3$U-#,T,30P(#`R
M,S(V,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($%U=&A?87!P;&EC871I;VX@8VQA<W,@<')O
M=FED97,@82!W<F%P<&5R(&%R;W5N9`H@*B!A<'!L:6-A=&EO;BUP<F]V:61E
M9"!(;W)D92!A=71H96YT:6-A=&EO;B!W:&EC:"!F:71S(&EN<VED92!T:&4*
M("H@2&]R9&4@075T:#HZ($%022X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=A<'`G("!4:&4@87!P;&EC871I;VX@=VAI8V@@:7,@
M<')O=FED:6YG(&%U=&AE;G1I8V%T:6]N+CPO<')E/@H@*@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]!=71H+T%U=&@O87!P;&EC871I;VXN<&AP+'8@,2XR
M-RXQ,"XQ,B`R,#`V+S`X+S$T(#`R.C0X.C0X(&-H=6-K($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@
M,RXP"B`J($!P86-K86=E($AO<F1E7T%U=&@*("HO"F-L87-S($%U=&A?87!P
M;&EC871I;VX@97AT96YD<R!!=71H('L*"B`@("`O*BH*("`@("`J($%N(&%R
M<F%Y(&]F(&-A<&%B:6QI=&EE<RP@<V\@=&AA="!T:&4@9')I=F5R(&-A;B!R
M97!O<G0@=VAI8V@*("`@("`J(&]P97)A=&EO;G,@:70@<W5P<&]R=',@86YD
M('=H:6-H(&ET(&1O97-N)W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)&-A<&%B:6QI=&EE<R`](&%R<F%Y*"=A9&0G("`@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W5P9&%T92<@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5S971P87-S=V]R9"<@/3X@9F%L<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=R96UO=F4G("`@("`@("`]/B!F
M86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI<W0G("`@
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=')A;G-P87)E;G0G("`@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T<R!A(&YE=R!!<'!L:6-A=&EO;B!A=71H96YT:6-A=&EO;B!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@
M:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@075T:%]A<'!L:6-A=&EO;B@D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=%!A<F%M<R@D<&%R86US
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%%U97)I97,@=&AE(&-U<G)E;G0@
M075T:"!O8FIE8W0@=&\@9FEN9"!O=70@:68@:70@<W5P<&]R=',@=&AE(&=I
M=F5N"B`@("`@*B!C87!A8FEL:71Y+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-A<&%B:6QI='D@(%1H92!C87!A8FEL:71Y('1O('1E<W0@9F]R
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N
M;W0@=&AE(&-A<&%B:6QI='D@:7,@<W5P<&]R=&5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H87-#87!A8FEL:71Y*"1C87!A8FEL:71Y*0H@("`@>PH@("`@
M("`@('-T871I8R`D;&]A9&5D(#T@87)R87DH*3L*"B`@("`@("`@)&UE=&AO
M9',@/2!A<G)A>2@G;&ES="<@/3X@)W5S97),:7-T)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("=A9&0G(#T^("=A9&15<V5R)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("=U<&1A=&4G(#T^("=U<&1A=&55<V5R)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("=R96UO=F4G(#T^("=R96UO=F55<V5R)RD[
M"@H@("`@("`@(&EF("AE;7!T>2@D;&]A9&5D6R1C87!A8FEL:71Y72D@)B8@
M:7-S970H)&UE=&AO9'-;)&-A<&%B:6QI='E=*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^8V%P86)I;&ET:65S6R1C87!A8FEL:71Y72`]("1'3$]"04Q36R=R
M96=I<W1R>2==+3YH87--971H;V0H)&UE=&AO9'-;)&-A<&%B:6QI='E=+"`D
M=&AI<RT^7W!A<F%M<ULG87!P)UTI.PH@("`@("`@("`@("`D;&]A9&5D6R1C
M87!A8FEL:71Y72`]('1R=64["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M(65M<'1Y*"1T:&ES+3YC87!A8FEL:71I97-;)&-A<&%B:6QI='E=*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!C;VYN96-T:6]N('!A<F%M971E<G,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=%!A
M<F%M<R@D<&%R86US*0H@("`@>PH@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV
M97)#;VYF:6<H)'!A<F%M<RP@)V%U=&@G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)V%P<"<I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V%U=&AE;G1I8V%T:6]N(&%P<&QI8V%T:6]N
M)RD["@H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M87!P;&EC871I;VYS6R1P87)A;7-;)V%P<"==72DI('L*("`@("`@("`@("`@
M2&]R9&4Z.F9A=&%L*"1P87)A;7-;)V%P<"==("X@)R!I<R!N;W0@8V]N9FEG
M=7)E9"!I;B!T:&4@2&]R9&4@4F5G:7-T<GDN)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@)'!A
M<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@;W5T(&EF(&$@<V5T
M(&]F(&QO9VEN(&-R961E;G1I86QS(&%R92!V86QI9"X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R260@("`@("!4:&4@=7-E<DED('1O(&-H96-K+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1C<F5D96YT:6%L<R`@5&AE(&-R961E;G1I86QS('1O('5S
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@;W(@
M;F]T('1H92!C<F5D96YT:6%L<R!A<F4@=F%L:60N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]A=71H96YT:6-A=&4H)'5S97))9"P@)&-R961E;G1I86QS*0H@
M("`@>PH@("`@("`@(&EF("@A)$=,3T)!3%-;)W)E9VES=')Y)UTM/FAA<TUE
M=&AO9"@G875T:&5N=&EC871E)RP@)'1H:7,M/E]P87)A;7-;)V%P<"==*2D@
M>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH)'1H:7,M/E]P87)A;7-;)V%P
M<"==("X@)R!D;V5S(&YO="!P<F]V:61E(&%N(&%U=&AE;G1I8V%T92@I(&UE
M=&AO9"XG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q">5!A8VMA9V4H
M)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G875T:&5N=&EC871E)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W5S97))9"<@/3X@)'5S97))9"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-R961E
M;G1I86QS)R`]/B`D8W)E9&5N=&EA;',L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;7,G
M(#T^("1T:&ES+3Y?<&%R86US*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE(%5222!O9B!T:&4@;&]G:6X@<V-R965N(&9O<B!T:&ES(&%U
M=&AE;G1I8V%T:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A<'`@(%1H92!A
M<'!L:6-A=&EO;B!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<FP@
M(%1H92!54DP@=&\@<F5D:7)E8W0@=&\@869T97(@;&]G:6XN"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L;V=I;B!S8W)E96X@55))+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&]G:6Y38W)E96XH)&%P<"`]("=H
M;W)D92<L("1U<FP@/2`G)RD*("`@('L*("`@("`@("!R971U<FX@<&%R96YT
M.CI?9V5T3&]G:6Y38W)E96XH)'1H:7,M/E]P87)A;7-;)V%P<"==+"`D=7)L
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@86QL('5S97)S(&EN('1H
M92!S>7-T96TN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(&%R
M<F%Y(&]F('5S97))9',L(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=%5S97)S*"D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q"
M>5!A8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G=7-E<DQI<W0G*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!9&0@82!S970@;V8@875T:&5N=&EC871I;VX@8W)E9&5N
M=&EA;',N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<DED("`@
M("`@5&AE('5S97))9"!T;R!A9&0N"B`@("`@*B!`<&%R86T@87)R87D@)&-R
M961E;G1I86QS("!4:&4@8W)E9&5N=&EA;',@=&\@=7-E+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%5S97(H)'5S97))9"P@)&-R961E;G1I86QS*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^:&%S0V%P86)I;&ET>2@G861D)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R>2==+3YC86QL0GE086-K86=E
M*"1T:&ES+3Y?<&%R86US6R=A<'`G72P@)V%D9%5S97(G+"!A<G)A>2@D=7-E
M<DED+"`D8W)E9&5N=&EA;',I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&4@82!S970@
M;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;VQD240@("`@("`@5&AE(&]L9"!U<V5R260N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N97=)1"`@("`@("!4:&4@;F5W('5S97))
M9"X*("`@("`J($!P87)A;2!A<G)A>2`D8W)E9&5N=&EA;',@(%1H92!N97<@
M8W)E9&5N=&EA;',*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!U<&1A=&55<V5R*"1O;&1)1"P@)&YE
M=TE$+"`D8W)E9&5N=&EA;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH
M87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q">5!A8VMA9V4H)'1H:7,M/E]P
M87)A;7-;)V%P<"==+"`G=7!D871E57-E<B<L(&%R<F%Y*"1O;&1)1"P@)&YE
M=TE$+"`D8W)E9&5N=&EA;',I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!S970@
M;V8@875T:&5N=&EC871I;VX@8W)E9&5N=&EA;',N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<DED("!4:&4@=7-E<DED('1O(&1E;&5T92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@
M;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F55<V5R*"1U<V5R260I"B`@("!["B`@("`@("`@
M:68@*"1T:&ES+3YH87-#87!A8FEL:71Y*"=R96UO=F4G*2D@>PH@("`@("`@
M("`@("`D<F5S=6QT(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F-A;&Q">5!A
M8VMA9V4H)'1H:7,M/E]P87)A;7-;)V%P<"==+"`G<F5M;W9E57-E<B<L(&%R
M<F%Y*"1U<V5R260I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G=6YS=7!P;W)T960G*3L*("`@("`@
M("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F5M;W9E57-E<D1A=&$H)'5S97))9"D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]";&]C:R],87EO=70`
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T,"`P,C$U-C<`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T)L;V-K+U5)+G!H<```````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`U-S8W(#$P-3$U-#,T,30P(#`R,30S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M0VQA<W,@9F]R('-E='1I;F<@=7`@2&]R9&4@0FQO8VMS('5S:6YG('1H92!(
M;W)D95]&;W)M.CH@8VQA<W-E<RX*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!-87)K;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO54DN<&AP+'8@
M,2XX+C$P+C4@,C`P-B\P,2\P,B`Q-SHT-CHS-2!J86X@17AP("0*("H*("H@
M0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC
M;&%S<R!(;W)D95]";&]C:U]522!["@H@("`@=F%R("1?8FQO8VMS(#T@87)R
M87DH*3L*("`@('9A<B`D7V9O<FT@/2!N=6QL.PH@("`@=F%R("1?=F%R<R`]
M(&YU;&P["@H@("`@9G5N8W1I;VX@2&]R9&5?0FQO8VM?54DH*0H@("`@>PH@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+T)L;V-K+T-O;&QE8W1I;VXN<&AP)SL*
M("`@("`@("`D=&AI<RT^7V)L;V-K<R`]("9(;W)D95]";&]C:U]#;VQL96-T
M:6]N.CIS:6YG;&5T;VXH*3L*("`@('T*"B`@("!F=6YC=&EO;B!S971&;W)M
M*"8D9F]R;2D*("`@('L*("`@("`@("`D=&AI<RT^7V9O<FT@/2`F)&9O<FT[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5F%R<R@F)'9A<G,I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]V87)S(#T@)B1V87)S.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-E='5P161I=$9O<FTH)&9I96QD(#T@)V)L;V-K)RD*("`@('L*("`@
M("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W9A<G,I*2!["B`@("`@("`@("`@
M("\J($YO(&5X:7-T:6YG('9A<G,@<V5T+"!G970@=&AE;2!N;W<N("HO"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<[
M"B`@("`@("`@("`@("1T:&ES+3Y?=F%R<R`]("9687)I86)L97,Z.F=E=$1E
M9F%U;'1687)I86)L97,H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?
M82@D=&AI<RT^7V9O<FTL("=(;W)D95]&;W)M)RDI('L*("`@("`@("`@("`@
M+RH@3F\@97AI<W1I;F<@=F%L:60@9F]R;2!O8FIE8W0@<V5T('-O('-E="!U
M<"!A(&YE=R!O;F4N("HO"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O1F]R;2YP:'`G.PH@("`@("`@("`@("`D=&AI<RT^7V9O<FT@/2`F2&]R
M9&5?1F]R;3HZ<VEN9VQE=&]N*"<G+"`D=&AI<RT^7W9A<G,L(%\H(D5D:70@
M0FQO8VLB*2D["B`@("`@("`@?0H*("`@("`@("`O*B!'970@=&AE(&-U<G)E
M;G0@=F%L=64@;V8@=&AE(&)L;V-K('-E;&5C=&EO;BX@*B\*("`@("`@("`D
M=F%L=64@/2`D=&AI<RT^7W9A<G,M/F=E="@D9FEE;&0I.PH*("`@("`@("`O
M*B!&:65L9"!T;R!S96QE8W0@87!P<RX@*B\*("`@("`@("`D87!P<R`]("1T
M:&ES+3Y?8FQO8VMS+3YG971";&]C:W-,:7-T*"D["B`@("`@("`@)'8@/2`F
M)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92A?*")!<'!L:6-A=&EO;B(I+"`D
M9FEE;&0@+B`G6V%P<%TG+"`G96YU;2<L('1R=64L(&9A;'-E+"!N=6QL+"!A
M<G)A>2@D87!P<RDI.PH@("`@("`@("1V+3YS971/<'1I;VXH)W1R86-K8VAA
M;F=E)RP@=')U92D["@H@("`@("`@(&EF("AE;7!T>2@D=F%L=65;)V%P<"==
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!A(&)L;V-K(&AA<R!B965N('-E;&5C=&5D+"!O=71P=70@86YY(&]P
M=&EO;G,@:6YP=70N("HO"B`@("`@("`@;&ES="@D87!P+"`D8FQO8VLI(#T@
M97AP;&]D92@G.B<L("1V86QU95LG87!P)UTI.PH*("`@("`@("`O*B!'970@
M=&AE(&]P=&EO;G,@9F]R('1H92!R97%U97-T960@8FQO8VLN("HO"B`@("`@
M("`@)&]P=&EO;G,@/2`D=&AI<RT^7V)L;V-K<RT^9V5T4&%R86US*"1A<'`L
M("1B;&]C:RD["@H@("`@("`@("\J($=O('1H<F]U9V@@=&AE(&]P=&EO;G,@
M9F]R('1H:7,@8FQO8VL@86YD('-E="!U<"!A;GD@<F5Q=6ER960*("`@("`@
M("`@*B!E>'1R82!I;G!U="X@*B\*("`@("`@("!F;W)E86-H("@D;W!T:6]N
M<R!A<R`D;W!T:6]N*2!["B`@("`@("`@("`@("1N86UE(#T@)'1H:7,M/E]B
M;&]C:W,M/F=E=%!A<F%M3F%M92@D87!P+"`D8FQO8VLL("1O<'1I;VXI.PH@
M("`@("`@("`@("`D='EP92`]("1T:&ES+3Y?8FQO8VMS+3YG971/<'1I;VY4
M>7!E*"1A<'`L("1B;&]C:RP@)&]P=&EO;BD["B`@("`@("`@("`@("1R97%U
M:7)E9"`]("1T:&ES+3Y?8FQO8VMS+3YG971/<'1I;VY297%U:7)E9"@D87!P
M+"`D8FQO8VLL("1O<'1I;VXI.PH@("`@("`@("`@("`D=F%L=65S(#T@)'1H
M:7,M/E]B;&]C:W,M/F=E=$]P=&EO;E9A;'5E<R@D87!P+"`D8FQO8VLL("1O
M<'1I;VXI.PH@("`@("`@("`@("`O*B!43T1/.B!T:&4@<V5T=&EN9R`G<W1R
M:6YG)R!S:&]U;&0@8F4@8VAA;F=E9"!I;B!A;&P@8FQO8VMS"B`@("`@("`@
M("`@("`J('1O("=T97AT)R!S;R!T:&%T(&ET(&-O;F9O<FUS('=I=&@@2&]R
M9&5?1F]R;2!S>6YT87@N("HO"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G
M<W1R:6YG)RD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`G=&5X="<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@
M("`@("`@("`@(&EF("@D='EP92`]/2`G96YU;2<@?'P@)'1Y<&4@/3T@)VUL
M96YU;2<I('L*("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@D=F%L
M=65S+"!T<G5E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7V9O<FTM/F%D9%9A<FEA8FQE*"1N86UE+"`D9FEE;&0@+B`G6V]P=&EO;G-=
M6R<@+B`D;W!T:6]N("X@)UTG+"`D='EP92P@)')E<75I<F5D+"!F86QS92P@
M;G5L;"P@)'!A<F%M<RD["B`@("`@("`@?0H@("`@?0H*?0H```````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VLO0V]L;&5C
M=&EO;BYP:'``````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S8U-3$@
M,3`U,34T,S0Q-#`@,#(S,C`W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T)L
M;V-K+G!H<"<["@HO*BH*("H@5&AE($AO<F1E7T)L;V-K7T-O;&QE8W1I;VXZ
M.B!C;&%S<R!P<F]V:61E<R!A;B!!4$D@=&\@=&AE(&)L;V-K<PH@*B`H87!P
M;&5T<RD@9G)A;65W;W)K+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]";&]C
M:R]";&]C:R]#;VQL96-T:6]N+G!H<"QV(#$N,S8N-"XQ-R`R,#`V+S`S+S`X
M(#$W.C4S.C4R(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N
M92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C
M:U]#;VQL96-T:6]N('L*"B`@("`O*BH*("`@("`J(%=H870@:VEN9"!O9B!B
M;&]C:W,@87)E('=E(&-O;&QE8W1I;F<_($1E9F%U;'1S('1O(&%N>2X*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T>7!E
M(#T@)W!O<G1A;"<["@H@("`@+RHJ"B`@("`@*B!!(&AA<V@@<W1O<FEN9R!T
M:&4@:6YF;W)M871I;VX@86)O=70@86QL(&%V86EL86)L92!B;&]C:W,@9G)O
M;0H@("`@("H@86QL(&%P<&QI8V%T:6]N<RX*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V)L;V-K<R`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T>7!E("!4:&4@:VEN9"!O9B!B;&]C:W,@=&\@;&ES="X*
M("`@("`J($!P87)A;2!A<G)A>2`D87!P<R`@(%1H92!A<'!L:6-A=&EO;G,@
M=VAO<V4@8FQO8VMS('1O(&QI<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T)L;V-K7T-O;&QE8W1I;VXH)'1Y<&4@/2!N=6QL+"`D87!P<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1T>7!E*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D='EP93L*("`@("`@("!]"@H@
M("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H)&%P<',I.PH@("`@("`@
M(&EF("AI<W-E="@D7U-%4U-)3TY;)VAO<F1E)UU;)V)L;V-K<R==6R1S:6=N
M871U<F5=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)L;V-K<R`]("8D7U-%
M4U-)3TY;)VAO<F1E)UU;)V)L;V-K<R==6R1S:6=N871U<F5=.PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@)')E9VES
M=')Y.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLN<&AP)SL*
M"B`@("`@("`@9F]R96%C:"`H)')E9VES=')Y+3YL:7-T07!P<R@I(&%S("1A
M<'`I('L*("`@("`@("`@("`@:68@*&-O=6YT*"1A<'!S*2`F)B`A:6Y?87)R
M87DH)&%P<"P@)&%P<',I*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)')E9VES=')Y+3YP=7-H07!P*"1A<'`I+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D8FQO8VMD:7(@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D
M87!P*2`N("<O;&EB+T)L;V-K)SL*("`@("`@("`@("`@)&1H(#T@0&]P96YD
M:7(H)&)L;V-K9&ER*3L*("`@("`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1D
M:"DI('L*("`@("`@("`@("`@("`@('=H:6QE("@H)&9I;&4@/2!R96%D9&ER
M*"1D:"DI("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS
M=6)S='(H)&9I;&4L("TT*2`]/2`G+G!H<"<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&)L;V-K7VYA;64@/2!N=6QL.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8FQO8VM?='EP92`](&YU;&P["B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<U]R96%D86)L92@D8FQO8VMD:7(@+B`G+R<@+B`D9FEL
M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`D8FQO8VMD:7(@+B`G+R<@+B`D9FEL93L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VYU;&PH
M)&)L;V-K7W1Y<&4I("8F("%I<U]N=6QL*"1T:&ES+3Y?='EP92D@)B8*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C:U]T>7!E("$]("1T:&ES
M+3Y?='EP92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D8FQO8VM?;F%M92DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8FQO8VMS6R1A<'!=6W-U8G-T
M<B@D9FEL92P@,"P@+30I75LG;F%M92==(#T@)&)L;V-K7VYA;64["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!C;&]S961I<B@D9&@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R96=I<W1R>2T^<&]P07!P
M*"1A<'`I.PH@("`@("`@('T*"B`@("`@("`@=6MS;W)T*"1T:&ES+3Y?8FQO
M8VMS+`H@("`@("`@("`@("`@("!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D8B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9VQO8F%L("1R96=I
M<W1R>3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M<W1R8V%S96-M<"@D<F5G:7-T<GDM/F=E="@B;F%M92(L("1A*2P@)')E9VES
M=')Y+3YG970H(FYA;64B+"`D8BDI.R<I"B`@("`@("`@("`@("`@("D["@H@
M("`@("`@("1?4T534TE/3ELG:&]R9&4G75LG8FQO8VMS)UU;)'-I9VYA='5R
M95T@/2`F)'1H:7,M/E]B;&]C:W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@<VEN9VQE(&EN<W1A;F-E(&]F('1H92!(;W)D95]";&]C:W,@
M8VQA<W,N"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1Y<&4@(%1H92!K:6YD(&]F(&)L;V-K<R!T;R!L:7-T
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<'!S("`@5&AE(&%P<&QI8V%T:6]N
M<R!W:&]S92!B;&]C:W,@=&\@;&ES="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@(%1H92!(;W)D95]";&]C:U]#;VQL
M96-T:6]N(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1T>7!E(#T@;G5L;"P@)&%P<',@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@('-T871I8R`D:6YS=&%N8V5S(#T@87)R87DH*3L*"B`@("`@("`@)'-I
M9VYA='5R92`]('-E<FEA;&EZ92AA<G)A>2@D='EP92P@)&%P<',I*3L*("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@
M("`@("`@("`@("1I;G-T86YC97-;)'-I9VYA='5R95T@/2!N97<@2&]R9&5?
M0FQO8VM?0V]L;&5C=&EO;B@D='EP92P@)&%P<',I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@H@
M("`@9G5N8W1I;VX@)F=E=$)L;V-K*"1A<'`L("1N86UE+"`D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@
M("`D<&%T:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@
M)R]L:6(O0FQO8VLO)R`N("1N86UE("X@)RYP:'`G.PH@("`@("`@("1C;&%S
M<R`]("=(;W)D95]";&]C:U\G("X@)&%P<"`N("=?)R`N("1N86UE.PH@("`@
M("`@(&EF("AI<U]R96%D86)L92@D<&%T:"DI('L*("`@("`@("`@("`@:6YC
M;'5D95]O;F-E("1P871H.PH@("`@("`@('T*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1E<G)O<B`](%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*"(E<R!N;W0@9F]U;F0N(BDL("1C;&%S
M<RDI.PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@
M("`@("`@)&)L;V-K(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@
M<F5T=7)N("1B;&]C:SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M82!P<F5T='D@<')I;G1E9"!L:7-T(&]F(&%L;"!A=F%I;&%B;&4@8FQO8VMS
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!W:71H(&)L
M;V-K($E$<R!A<R!K97ES(&%N9"!A<'!L:6-A=&EO;B!P;'5S(&)L;V-K"B`@
M("`@*B`@("`@("`@("`@("`@("!B;&]C:R!N86UE<R!A<R!V86QU97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L;V-K<TQI<W0H*0H@("`@>PH@("`@
M("`@('-T871I8R`D8FQO8VMS(#T@87)R87DH*3L*("`@("`@("!I9B`H(65M
M<'1Y*"1B;&]C:W,I*2!["B`@("`@("`@("`@(')E='5R;B`D8FQO8VMS.PH@
M("`@("`@('T*"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@
M+RH@1V5T(&%V86EL86)L92!B;&]C:W,@9G)O;2!A;&P@87!P<RX@*B\*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V)L;V-K<R!A<R`D87!P(#T^("1A<'!?
M8FQO8VMS*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1A<'!?8FQO8VMS(&%S
M("1B;&]C:U]I9"`]/B`D8FQO8VLI('L*("`@("`@("`@("`@("`@("1B;&]C
M:W-;)&%P<"`N("<Z)R`N("1B;&]C:U]I9%T@/2`D<F5G:7-T<GDM/F=E="@G
M;F%M92<L("1A<'`I("X@)SH@)R`N("1B;&]C:ULG;F%M92==.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L;V-K<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!L87EO=70@:&%S:"!W:71H
M(&%L;"!F:7AE9"!B;&]C:W,@87,@<&5R(&-O;F9I9W5R871I;VXN"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H(')E<')E<V5N=&EN9R!A
M(&1E9F%U;'0@;&%Y;W5T('=I=&@@86QL(&9I>&5D"B`@("`@*B`@("`@("`@
M("`@("`@("!B;&]C:W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9I>&5D
M0FQO8VMS*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M("1L87EO=70@/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<W-E="@D8V]N9ELG
M<&]R=&%L)UU;)V9I>&5D7V)L;V-K<R==*2D@>PH@("`@("`@("`@("!F;W)E
M86-H("@D8V]N9ELG<&]R=&%L)UU;)V9I>&5D7V)L;V-K<R==(&%S("1B;&]C
M:RD@>PH@("`@("`@("`@("`@("`@;&ES="@D87!P+"`D='EP92D@/2!E>'!L
M;V1E*"<Z)RP@)&)L;V-K+"`R*3L*("`@("`@("`@("`@("`@("1L87EO=71;
M72`](&%R<F%Y*&%R<F%Y*"=A<'`G(#T^("1A<'`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!A<G)A>2@G
M='EP92<@/3X@)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]/B!F86QS
M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M:&5I9VAT)R`]/B`Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W=I9'1H)R`]/B`Q*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D;&%Y;W5T.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A('-E;&5C="!W:61G970@=VET:"!A;&P@879A:6QA
M8FQE(&)L;V-K<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C=7)?
M87!P("`@(%1H92!B;&]C:R!F<F]M('1H:7,@87!P;&EC871I;VX@9V5T<R!S
M96QE8W1E9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-U<E]B;&]C:R`@5&AE
M(&)L;V-K('=I=&@@=&AI<R!N86UE(&=E=',@<V5L96-T960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S96QE8W0@=&%G('=I=&@@86QL
M(&%V86EL86)L92!B;&]C:W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L
M;V-K<U=I9&=E="@D8W5R7V%P<"`](&YU;&PL("1C=7)?8FQO8VL@/2!N=6QL
M+"`D;VYC:&%N9V4@/2!F86QS92D*("`@('L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@("`@("`D=VED9V5T(#T@)SQS96QE8W0@;F%M93TB87!P
M(B<["B`@("`@("`@:68@*"1O;F-H86YG92D@>PH@("`@("`@("`@("`D=VED
M9V5T("X]("<@;VYC:&%N9V4](F1O8W5M96YT+F)L;V-K9F]R;2YA8W1I;VXN
M=F%L=64]7"=S879E+7)E<W5M95PG.V1O8W5M96YT+F)L;V-K9F]R;2YS=6)M
M:70H*2(G.PH@("`@("`@('T*("`@("`@("`D=VED9V5T("X]("(^7&XB.PH@
M("`@("`@("1B;&]C:W-?;&ES="`]("1T:&ES+3YG971";&]C:W-,:7-T*"D[
M"B`@("`@("`@9F]R96%C:"`H)&)L;V-K<U]L:7-T(&%S("1I9"`]/B`D;F%M
M92D@>PH@("`@("`@("`@("`D=VED9V5T("X]('-P<FEN=&8H(CQO<'1I;VX@
M=F%L=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<;B(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&ED+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("@D:60@/3T@)&-U<E]A<'`@+B`G.B<@+B`D8W5R
M7V)L;V-K*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@.B`G)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F%M92D["B`@("`@("`@
M?0H@("`@("`@("1W:61G970@+CT@(CPO<V5L96-T/EQN(CL*"B`@("`@("`@
M<F5T=7)N("1W:61G970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!O<'1I;VX@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T
M:6]N5'EP92@D87!P+"`D8FQO8VLL("1P87)A;5]I9"D*("`@('L*("`@("`@
M("`D=&AI<RT^9V5T4&%R86US*"1A<'`L("1B;&]C:RD["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P
M87)A;5]I9%U;)W1Y<&4G73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=VAE=&AE<B!T:&4@;W!T:6]N(&ES(')E<75I<F5D(&]R(&YO="X@1&5F
M875L=',@=&\@=')U92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W!T:6]N
M4F5Q=6ER960H)&%P<"P@)&)L;V-K+"`D<&%R86U?:60I"B`@("!["B`@("`@
M("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US
M)UU;)'!A<F%M7VED75LG<F5Q=6ER960G72DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==6R1P87)A
M;5]I9%U;)W)E<75I<F5D)UT["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=F%L=65S(&9O<B!A;B!O<'1I;VXN"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9G971/<'1I;VY686QU97,H)&%P<"P@)&)L;V-K
M+"`D<&%R86U?:60I"B`@("!["B`@("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D
M87!P+"`D8FQO8VLI.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD
M87!P75LD8FQO8VM=6R=P87)A;7,G75LD<&%R86U?:61=6R=V86QU97,G73L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('=I9&=E="!N96-E
M<W-A<GD@=&\@8V]N9FEG=7)E('1H:7,@8FQO8VLN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$]P=&EO;G-7:61G970H)&%P<"P@)&)L;V-K+"`D<&%R86U?
M:60L("1V86P@/2!N=6QL*0H@("`@>PH@("`@("`@("1W:61G970@/2`G)SL*
M"B`@("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@
M("`@("1P87)A;2`]("1T:&ES+3Y?8FQO8VMS6R1A<'!=6R1B;&]C:UU;)W!A
M<F%M<R==6R1P87)A;5]I9%T["B`@("`@("`@:68@*"%I<W-E="@D<&%R86U;
M)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@)'!A<F%M6R=D969A=6QT)UT@
M/2`G)SL*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'!A<F%M6R=T>7!E
M)UTI('L*("`@("`@("!C87-E("=B;V]L96%N)SH*("`@("`@("!C87-E("=C
M:&5C:V)O>"<Z"B`@("`@("`@("`@("1C:&5C:V5D(#T@(65M<'1Y*"1V86Q;
M)'!A<F%M7VED72D@/R`G(&-H96-K960](F-H96-K960B)R`Z("<G.PH@("`@
M("`@("`@("`D=VED9V5T(#T@<W!R:6YT9B@G/&EN<'5T('1Y<&4](F-H96-K
M8F]X(B!N86UE/2)P87)A;7-;)7-=(B5S("\^)RP@)'!A<F%M7VED+"`D8VAE
M8VME9"D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=E;G5M
M)SH*("`@("`@("`@("`@)'=I9&=E="`]('-P<FEN=&8H)SQS96QE8W0@;F%M
M93TB<&%R86US6R5S72(^)RP@)'!A<F%M7VED*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A<F%M6R=V86QU97,G72!A<R`D:V5Y(#T^("1N86UE*2!["B`@
M("`@("`@("`@("`@("!I9B`H4W1R:6YG.CIL96YG=&@H)&YA;64I(#X@,S`I
M('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`]('-U8G-T<B@D;F%M92P@
M,"P@,C<I("X@)RXN+B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=VED9V5T("X]('-P<FEN=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB
M)7,^)7,\+V]P=&EO;CY<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H)'9A;%LD<&%R86U?:61=
M*2`F)B`D=F%L6R1P87)A;5]I9%T@/3T@)&ME>2D@/R`G('-E;&5C=&5D/2)S
M96QE8W1E9"(G(#H@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:'1M;'-P96-I86QC:&%R<R@D;F%M92DI.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`D=VED9V5T("X]("<\+W-E;&5C=#XG.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;75L=&EE;G5M)SH*("`@("`@
M("`@("`@)'=I9&=E="`]('-P<FEN=&8H)SQS96QE8W0@;75L=&EP;&4](FUU
M;'1I<&QE(B!N86UE/2)P87)A;7-;)7-=6UTB/B<L("1P87)A;5]I9"D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1P87)A;5LG=F%L=65S)UT@87,@)&ME>2`]
M/B`D;F%M92D@>PH@("`@("`@("`@("`@("`@:68@*%-T<FEN9SHZ;&5N9W1H
M*"1N86UE*2`^(#,P*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;64@/2!S
M=6)S='(H)&YA;64L(#`L(#(W*2`N("<N+BXG.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'=I9&=E="`N/2!S<')I;G1F*"(\;W!T:6]N
M('9A;'5E/5PB)7-<(B5S/B5S/"]O<'1I;VX^7&XB+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*&ES<V5T*"1V
M86Q;)'!A<F%M7VED72D@)B8@:6Y?87)R87DH)&ME>2P@)'9A;%LD<&%R86U?
M:61=*2D@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D
M;F%M92DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=VED9V5T("X]
M("<\+W-E;&5C=#XG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G;6QE;G5M)SH*("`@("`@("`@("`@+R\@375L=&DM;&5V96P@96YU;2X*
M("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86PI("8F(&ES<V5T*"1V86Q;
M)U]?)R`N("1P87)A;5]I9%TI*2!["B`@("`@("`@("`@("`@("`D9FER<W1V
M86P@/2`D=F%L6R=?7R<@+B`D<&%R86U?:61=.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1M<"`](&%R<F%Y7VME>7,H)'!A<F%M
M6R=V86QU97,G72D["B`@("`@("`@("`@("`@("`D9FER<W1V86P@/2!C=7)R
M96YT*"1T;7`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B;&]C:W9A
M;'5E<R`]("1P87)A;5LG=F%L=65S)UU;)&9I<G-T=F%L73L*("`@("`@("`@
M("`@87-O<G0H)&)L;V-K=F%L=65S*3L*"B`@("`@("`@("`@("1W:61G970@
M/2!S<')I;G1F*"<\<V5L96-T(&YA;64](G!A<F%M<UM?7R5S72(@;VYC:&%N
M9V4](F1O8W5M96YT+F)L;V-K9F]R;2YA8W1I;VXN=F%L=64]7"=S879E+7)E
M<W5M95PG.V1O8W5M96YT+F)L;V-K9F]R;2YS=6)M:70H*2(^)RP@)'!A<F%M
M7VED*2`N(")<;B(["B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;5LG=F%L
M=65S)UT@87,@)&ME>2`]/B`D=F%L=65S*2!["B`@("`@("`@("`@("`@("`D
M;F%M92`](%-T<FEN9SHZ;&5N9W1H*"1K97DI(#X@,S`@/R!3=')I;F<Z.G-U
M8G-T<B@D:V5Y+"`P+"`R-RD@+B`G+BXN)R`Z("1K97D["B`@("`@("`@("`@
M("`@("`D=VED9V5T("X]('-P<FEN=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB
M)7,^)7,\+V]P=&EO;CY<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D:V5Y*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:V5Y(#T]("1F:7)S='9A;"`_("<@
M<V5L96-T960](G-E;&5C=&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'=I9&=E="`N/2`B/"]S96QE8W0^
M/&)R("\^7&XB.PH*("`@("`@("`@("`@)'=I9&=E="`N/2!S<')I;G1F*"(\
M<V5L96-T(&YA;64]7")P87)A;7-;)7-=7"(^7&XB+"`D<&%R86U?:60I.PH@
M("`@("`@("`@("!F;W)E86-H("@D8FQO8VMV86QU97,@87,@)&ME>2`]/B`D
M;F%M92D@>PH@("`@("`@("`@("`@("`@)&YA;64@/2`H4W1R:6YG.CIL96YG
M=&@H)&YA;64I(#X@,S`I(#\@4W1R:6YG.CIS=6)S='(H)&YA;64L(#`L(#(W
M*2`N("<N+BXG(#H@)&YA;64["B`@("`@("`@("`@("`@("`D=VED9V5T("X]
M('-P<FEN=&8H(CQO<'1I;VX@=F%L=64]7"(E<UPB)7,^)7,\+V]P=&EO;CY<
M;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:'1M;'-P
M96-I86QC:&%R<R@D:V5Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L6R1P87)A;5]I9%T@/3T@)&ME>2`_("<@<V5L96-T960]
M(G-E;&5C=&5D(B<@.B`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!H=&UL<W!E8VEA;&-H87)S*"1N86UE*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'=I9&=E="`N/2`B/"]S96QE8W0^/&)R("\^7&XB
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8V]L;W(G.@H@
M("`@("`@("`@("`D=F%L(#T@:7-S970H)&)L;V-K+3Y?<&%R86US6R1P87)A
M;5]I9%TI(#\@)&)L;V-K+3Y?<&%R86US6R1P87)A;5]I9%T@.B`G)SL*("`@
M("`@("`@("`@)'=I9&=E="`]('-P<FEN=&8H)SQI;G!U="!S='EL93TB8F%C
M:V=R;W5N9"UC;VQO<CHE<R(@='EP93TB=&5X="(@;F%M93TB<&%R86US6R5S
M72(@=F%L=64](B5S(B`O/B<L("1V86PL("1P87)A;5]I9"P@)'9A;"D["B`@
M("`@("`@("`@("1U<FP@(#T@)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G
M:&]R9&4G*3L*("`@("`@("`@("`@)'5R;"`N/2!5=&EL.CIA9&1087)A;65T
M97(H)R]S97)V:6-E<R]I;6%G97,O8V]L;W)P:6-K97(N<&AP/W1A<F=E=#UP
M87)A;7-;)R`N("1P87)A;5]I9"`N("==)RP@)V9O<FTG+"`G8FQO8VMF;W)M
M)RD["B`@("`@("`@("`@("1W:61G970@+CT@<W!R:6YT9B@G/&$@:')E9CTB
M)7,B(&]N8VQI8VL](G=I;F1O=RYO<&5N*%PG)7-<)RP@7"=C;VQO<G!I8VME
M<EPG+"!<)W1O;VQB87(];F\L;&]C871I;VX];F\L<W1A='5S/6YO+'-C<F]L
M;&)A<G,];F\L<F5S:7IA8FQE/6YO+'=I9'1H/3$R,"QH96EG:'0],C4P+&QE
M9G0],3`P+'1O<#TQ,#!<)RD[(')E='5R;B!F86QS93LB(&]N;6]U<V5O=70]
M(G=I;F1O=RYS=&%T=7,]7"=<)SLB(&]N;6]U<V5O=F5R/2)W:6YD;W<N<W1A
M='5S/5PG)7-<)SL@<F5T=7)N('1R=64[(B!C;&%S<STB=VED9V5T(B!T87)G
M970](F-O;&]R<&EC:V5R(CXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'5R;"P@)'5R;"P@7R@B0V]L;W(@4&EC:V5R(BDI.PH@("`@("`@
M("`@("`D=VED9V5T("X]($AO<F1E.CII;6<H)V-O;&]R<&EC:V5R+G!N9R<L
M(%\H(D-O;&]R(%!I8VME<B(I+"`G:&5I9VAT/2(Q-B(G+"`D<F5G:7-T<GDM
M/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*("`@("`@("`@("`@)'=I9&=E="`N
M/2`G/"]A/B<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=I
M;G0G.@H@("`@("`@(&-A<V4@)W1E>'0G.@H@("`@("`@("`@("`D=VED9V5T
M(#T@<W!R:6YT9B@G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](G!A<F%M<ULE
M<UTB('9A;'5E/2(E<R(@+SXG+"`D<&%R86U?:60L("%I<W-E="@D=F%L6R1P
M87)A;5]I9%TI(#\@)'!A<F%M6R=D969A=6QT)UT@.B`D=F%L6R1P87)A;5]I
M9%TI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G97)R;W(G
M.@H@("`@("`@("`@("`D=VED9V5T(#T@)SQS<&%N(&-L87-S/2)F;W)M+65R
M<F]R(CXG("X@)'!A<F%M6R=D969A=6QT)UT@+B`G/"]S<&%N/B<["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1W:61G
M970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N86UE(&]F
M('1H92!S<&5C:69I960@8FQO8VLN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D87!P("`@($%N(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1B;&]C:R`@02!B;&]C:R!N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@;F%M92!O9B!T:&4@<W!E8VEF:65D(&)L
M;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"1A<'`L("1B;&]C
M:RD*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1A
M<'!=6R1B;&]C:UTI*2!["B`@("`@("`@("`@(')E='5R;B!S<')I;G1F*%\H
M(D)L;V-K(%PB)7-<(B!O9B!A<'!L:6-A=&EO;B!<(B5S7"(@;F]T(&9O=6YD
M+B(I+"`D8FQO8VLL("1A<'`I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG;F%M92==.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<&%R86UE=&5R(&QI<W0@;V8@
M=&AE('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<'`@("`@06X@87!P;&EC871I;VX@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&)L;V-K("!!(&)L;V-K(&YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@06X@87)R87D@=VET:"!A;&P@<&%R86UT97(@;F%M
M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<F%M<R@D87!P+"`D8FQO
M8VLI"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V)L;V-K<ULD
M87!P75LD8FQO8VM=6R=P87)A;7,G72DI('L*("`@("`@("`@("`@)&)L;V-K
M3V(@/2`F)'1H:7,M/F=E=$)L;V-K*"1A<'`L("1B;&]C:RD["B`@("`@("`@
M("`@(&EF("AI<U]A*"1B;&]C:T]B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&)L;V-K3V(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R86US
M)UT@/2`D8FQO8VM/8BT^9V5T4&%R86US*"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]B;&]C:W-;)&%P<%U;)&)L;V-K75LG<&%R
M86US)UTI("8F"B`@("`@("`@("`@(&ES7V%R<F%Y*"1T:&ES+3Y?8FQO8VMS
M6R1A<'!=6R1B;&]C:UU;)W!A<F%M<R==*2D@>PH@("`@("`@("`@("!R971U
M<FX@87)R87E?:V5Y<R@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P
M87)A;7,G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@*&-L96%R('1E>'0I(&YA;64@;V8@=&AE('-P96-I9FEE9"!P
M87)A;65T97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@
M($%N(&%P<&QI8V%T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1B
M;&]C:R`@02!B;&]C:R!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R
M86T@($$@<&%R86UE=&5R(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!N86UE(&]F('1H92!S<&5C:69I960@<&%R86UE=&5R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971087)A;4YA;64H)&%P<"P@)&)L;V-K
M+"`D<&%R86TI"B`@("!["B`@("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P
M+"`D8FQO8VLI.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD87!P
M75LD8FQO8VM=6R=P87)A;7,G75LD<&%R86U=6R=N86UE)UT["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!D969A=6QT('9A;'5E(&]F('1H
M92!S<&5C:69I960@<&%R86UE=&5R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&%P<"`@("!!;B!A<'!L:6-A=&EO;B!N86UE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8FQO8VL@($$@8FQO8VL@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A<F%M("!!('!A<F%M971E<B!N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5F875L="!V86QU92!O9B!T:&4@
M<W!E8VEF:65D('!A<F%M971E<B!O<B!N=6QL+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971$969A=6QT5F%L=64H)&%P<"P@)&)L;V-K+"`D<&%R86TI"B`@
M("!["B`@("`@("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=
M6R=P87)A;7,G75LD<&%R86U=6R=D969A=6QT)UTI*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A;7,G
M75LD<&%R86U=6R=D969A=6QT)UT["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I9B!T:&4@
M<W!E8VEF:65D(&)L;V-K(&ES(&-U<W1O;6EZ96%B;&4@8GD@=&AE('5S97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@($%N(&%P<&QI
M8V%T:6]N(&YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@02!B
M;&]C:R!N86UE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!I<R!T:&4@8FQO8VL@:7,@8W5S=&]M:7IE86)L92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:7-%9&ET86)L92@D87!P+"`D8FQO8VLI"B`@("!["B`@("`@
M("`@)'1H:7,M/F=E=%!A<F%M<R@D87!P+"`D8FQO8VLI.PH@("`@("`@(')E
M='5R;B!I<W-E="@D=&AI<RT^7V)L;V-K<ULD87!P75LD8FQO8VM=6R=P87)A
M;7,G72D@)B8*("`@("`@("`@("`@8V]U;G0H)'1H:7,M/E]B;&]C:W-;)&%P
M<%U;)&)L;V-K75LG<&%R86US)UTI.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T)L;V-K+TQA
M>6]U="]6:65W+G!H<```````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P
M-3,R(#$P-3$U-#,T,30P(#`R,S(W,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D
M92]"<F]W<V5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0FQO8VLO0V]L
M;&5C=&EO;BYP:'`G.PH*+RHJ"B`J(%1H92!(;W)D95]";&]C:U],87EO=71?
M5FEE=R!C;&%S<R!R97!R97-E;G1S('1H92!U<V5R(&1E9FEN960@<&]R=&%L
M(&QA>6]U="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO
M3&%Y;W5T+U9I97<N<&AP+'8@,2XT+C(N,R`R,#`V+S`V+S(S(#`T.C,U.C(Q
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXR"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U],87EO=71?
M5FEE=R!["@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!B;&]C:R!L87EO
M=70N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]L87EO=70@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06QL(&%P<&QI
M8V%T:6]N<R!U<V5D(&EN('1H:7,@;&%Y;W5T+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87!P;&EC871I;VYS(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-34R!L:6YK('1A9W,@<'5L;&5D(&]U
M="!O9B!B;&]C:R!C;VYT96YT+@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?;&EN:U1A9W,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7T)L;V-K7TQA>6]U=%]6:65W*"1L87EO=70@/2`G)RD*("`@('L*("`@
M("`@("`D=&AI<RT^7VQA>6]U="`]($!U;G-E<FEA;&EZ92@D;&%Y;W5T*3L*
M("`@("`@("!I9B`H(21T:&ES+3Y?;&%Y;W5T*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T(#T@87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!296YD97(@=&AE(&-U<G)E;G0@;&%Y;W5T(&%S($A434PN
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@2%1-3"!L87EO=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1O2'1M;"@I"B`@("!["B`@("`@("`@)&)R
M;W=S97(@/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["B`@("`@("`@)'1P;$1I
M<B`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I.PH@("`@("`@("1I;G1E<G9A;"`]("1'3$]"04Q36R=P<F5F<R==
M+3YG971686QU92@G<W5M;6%R>5]R969R97-H7W1I;64G*3L*"B`@("`@("`@
M)&AT;6P@/2`G/'1A8FQE(&-L87-S/2)N;W!A9&1I;F<B(&-E;&QS<&%C:6YG
M/2(V(B!W:61T:#TB,3`P)2(^)SL*"B`@("`@("`@)&-O=F5R960@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&%Y;W5T(&%S("1R;W=?
M;G5M(#T^("1R;W<I('L*("`@("`@("`@("`@)'=I9'1H(#T@9FQO;W(H,3`P
M("\@8V]U;G0H)')O=RDI.PH@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/B<[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1R;W<@87,@)&-O;%]N=6T@/3X@)&ET
M96TI('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D8V]V97)E9%LD<F]W
M7VYU;5TI("8F(&ES<V5T*"1C;W9E<F5D6R1R;W=?;G5M75LD8V]L7VYU;5TI
M*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&ET96TI*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A<'!L:6-A=&EO;G-;)&ET
M96U;)V%P<"==72`]("1I=&5M6R=A<'`G73L*("`@("`@("`@("`@("`@("`@
M("`D8FQO8VL@/2`F2&]R9&5?0FQO8VM?0V]L;&5C=&EO;CHZ9V5T0FQO8VLH
M)&ET96U;)V%P<"==+"`D:71E;5LG<&%R86US)UU;)W1Y<&4G72P@)&ET96U;
M)W!A<F%M<R==6R=P87)A;7,G72D["B`@("`@("`@("`@("`@("`@("`@)')O
M=W-P86X@/2`D:71E;5LG:&5I9VAT)UT["B`@("`@("`@("`@("`@("`@("`@
M)&-O;'-P86X@/2`D:71E;5LG=VED=&@G73L*("`@("`@("`@("`@("`@("`@
M("`D=VED=&@@*CT@)&-O;'-P86X["B`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&ET96U;)VAE:6=H="==.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-O=F5R961;)')O=U]N
M=6T@*R`D:5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]V
M97)E9%LD<F]W7VYU;2`K("1I72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`]
M(#`[("1J(#P@)&ET96U;)W=I9'1H)UT[("1J*RLI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1C;W9E<F5D6R1R;W=?;G5M("L@)&E=6R1C;VQ?
M;G5M("L@)&I=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D8FQO8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&AE861E<B`](%\H(D5R<F]R(BD["B`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&)L;V-K+3YG971-97-S86=E*"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EN8VQU9&4@)'1P;$1I<B`N("<O<&]R=&%L+V)L;V-K
M+FEN8R<["B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X](&]B7V=E
M=%]C;&5A;B@I.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A
M*"1B;&]C:RP@)TAO<F1E7T)L;V-K)RDI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AE861E<B`]("1B;&]C:RT^9V5T5&ET;&4H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D8FQO8VLM/F=E=$-O;G1E;G0H
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@:6YC;'5D92`D='!L1&ER("X@)R]P;W)T86PO
M8FQO8VLN:6YC)SL*("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@
M;V)?9V5T7V-L96%N*"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!W:61T:#TB
M)R`N("1W:61T:"`N("<E(CXF;F)S<#L\+W1D/B<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(G("X@)'=I9'1H("X@)R4B
M/B9N8G-P.SPO=&0^)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]T<CXG.PH@("`@("`@('T*("`@
M("`@("`D:'1M;"`N/2`G/"]T86)L93XG.PH*("`@("`@("`O+R!3=')I<"!A
M;GD@0U-3(#QL:6YK/B!T86=S(&]U="!O9B!T:&4@<F5T=7)N960@8V]N=&5N
M="!S;PH@("`@("`@("\O('1H97D@8V%N(&)E(&AA;F1L960@<V5P97)A=&5L
M>2X*("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R\\;&EN:R`N*C]R96P]
M(G-T>6QE<VAE970B+BH_7"\^+R<L("1H=&UL+"`D;&EN:W,I*2!["B`@("`@
M("`@("`@("1H=&UL(#T@<W1R7W)E<&QA8V4H)&QI;FMS6S!=+"`G)RP@)&AT
M;6PI.PH@("`@("`@("`@("`D=&AI<RT^7VQI;FM486=S(#T@)&QI;FMS6S!=
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&%N>2!L:6YK('1A9W,@9F]U;F0@:6X@=&AE('9I
M97<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI;FM486=S*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YK5&%G<SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@86QL('1H92!A<'!L:6-A=&EO
M;G,@=7-E9"!B>2!B;&]C:W,@:6X@=&AI<R!L87EO=70N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2!,:7-T(&]F(&%P<&QI8V%T:6]N<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T07!P;&EC871I;VYS*"D*("`@('L*("`@("`@
M("!R971U<FX@87)R87E?:V5Y<R@D=&AI<RT^7V%P<&QI8V%T:6]N<RD["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0FQO8VLO3&%Y;W5T+TUA;F%G
M97(N<&AP````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,S,R,3<@,3`U,34T
M,S0Q-#`@,#(S-S0P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H
M<"<["@HO*BH*("H@5&AE($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R(&-L
M87-S(&%L;&]W<R!M86YI<'5L871I;VX@;V8*("H@2&]R9&5?0FQO8VL@;&%Y
M;W5T<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0FQO8VLO0FQO8VLO3&%Y
M;W5T+TUA;F%G97(N<&AP+'8@,2XT+C(N,R`R,#`V+S`S+S`X(#$W.C4T.C`X
M(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXR"B`J($!P86-K
M86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U],87EO=71?
M36%N86=E<B!["@H@("`@+RHJ"B`@("`@*B!/=7(@2&]R9&5?0FQO8VM?0V]L
M;&5C=&EO;B!I;G-T86YC92X*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7T)L
M;V-K7T-O;&QE8W1I;VX*("`@("`J+PH@("`@=F%R("1?8V]L;&5C=&EO;CL*
M"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&)L;V-K(&QA>6]U="X*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VQA>6]U
M="`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!!(&-A8VAE(&9O<B!T:&4@
M8FQO8VL@;V)J96-T<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V)L;V-K<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;6%X:6UU;2!N=6UB97(@;V8@8V]L=6UN<RX*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8V]L=6UN<R`](#`[
M"@H@("`@+RHJ"B`@("`@*B!(87,@=&AE(&QA>6]U="!B965N('5P9&%T960@
M<VEN8V4@:70@=V%S(&EN<W1A;G1I871E9"X*("`@("`J"B`@("`@*B!`=F%R
M(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=7!D871E9"`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@8FQO8VL@*&%R<F%Y.B!;<F]W
M+"!C;VQ=*2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D7V-U<G)E;G1";&]C:R`](&%R<F%Y*&YU;&PL(&YU;&PI.PH*("`@
M("\J*@H@("`@("H@5&AE(&YE=R!R;W<@;V8@=&AE(&QA<W0@8VAA;F=E9"!B
M;&]C:RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1?8VAA;F=E9%]R;W<@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE
M(&YE=R!C;VQU;6X@;V8@=&AE(&QA<W0@8VAA;F=E9"!B;&]C:RX*("`@("`J
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8VAA;F=E
M9%]C;VP@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T)L;V-K7T-O;&QE8W1I;VX@)B1C
M;VQL96-T:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A"B`@("`@*B\*
M("`@(&9U;F-T:6]N($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R*"8D8V]L
M;&5C=&EO;BP@)&1A=&$@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^7V-O
M;&QE8W1I;VX@/2`F)&-O;&QE8W1I;VX["B`@("`@("`@)'1H:7,M/G5N<V5R
M:6%L:7IE*"1D871A*3L*"B`@("`@("`@+R\@1FEL;"!T:&4@7V-O=F5R960@
M8V%C:&5S(&%N9"!E;7!T>2!R;W=S+@H@("`@("`@("1R;W=S(#T@8V]U;G0H
M)'1H:7,M/E]L87EO=70I.PH@("`@("`@("1E;7!T>2`](&%R<F%Y*"D["B`@
M("`@("`@9F]R("@D<F]W(#T@,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI('L*
M("`@("`@("`@("`@)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W
M72D["B`@("`@("`@("`@(&EF("@A:7-S970H)&5M<'1Y6R1R;W==*2D@>PH@
M("`@("`@("`@("`@("`@)&5M<'1Y6R1R;W==(#T@=')U93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!F;W(@*"1C;VP@/2`P.R`D8V]L(#P@)&-O;',[
M("1C;VPK*RD@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7VQA>6]U=%LD<F]W75LD8V]L72DI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V)L;V-K<ULD<F]W75LD8V]L72`](%!%05(Z.G)A:7-E17)R;W(H
M7R@B3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-?87)R87DH)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&9I96QD(#T@)'1H:7,M/E]L87EO=71;)')O=UU;
M)&-O;%T["@H@("`@("`@("`@("`@("`@("`@("1E;7!T>5LD<F]W72`](&9A
M;'-E.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEE;&1;)W=I
M9'1H)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`Q
M.R`D:2`\("1F:65L9%LG=VED=&@G73L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I
M72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&9I96QD6R=H96EG:'0G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D9FEE;&1;)W=I9'1H)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9FEE;&1;)W=I9'1H)UT@/2`Q.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`Q.R`D:2`\("1F:65L9%LG:&5I9VAT)UT[("1I*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@
M*R`D:5U;)&-O;%T@/2`G8V]V97)E9"<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W(@*"1J(#T@,3L@)&H@/"`D9FEE;&1;)W=I9'1H)UT[("1J
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@*R`D:ET@/2`G8V]V97)E9"<["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D96UP='E;)')O=R`K("1I72`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!3
M=')I<"!E;7!T>2!B;&]C:W,@9G)O;2!T:&4@96YD(&]F('1H92!R;W=S+@H@
M("`@("`@("`@("!F;W(@*"1C;VP@/2`D8V]L<R`M(#$[("1C;VP@/CT@,#L@
M)&-O;"TM*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VQ=*2!\?`H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T]("=E;7!T>2<I('L*("`@("`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D=&AI<RT^7V-O;'5M;G,@/2!M87@H)'1H:7,M/E]C;VQU
M;6YS+"!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W72DI.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1FEL;"!A;&P@<F]W<R!U<"!T;R!T:&4@<V%M92!L96YG
M=&@N"B`@("`@("`@)&QA>6]U="`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D
M<F]W(#T@,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI('L*("`@("`@("`@("`@
M)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA>6]U=%LD<F]W72D["B`@("`@("`@
M("`@(&EF("@D8V]L<R`\("1T:&ES+3Y?8V]L=6UN<RD@>PH@("`@("`@("`@
M("`@("`@9F]R("@D8V]L(#T@)&-O;',[("1C;VP@/"`D=&AI<RT^7V-O;'5M
M;G,[("1C;VPK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W==6R1C;VQ=(#T@)V5M<'1Y)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;&%Y;W5T6UT@/2`D=&AI<RT^
M7VQA>6]U=%LD<F]W73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T(#T@)&QA>6]U=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E<FEA;&EZ
M92!A;F0@<F5T=7)N('1H92!C=7)R96YT(&)L;V-K(&QA>6]U="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*("`@("`@("!R971U
M<FX@<V5R:6%L:7IE*"1T:&ES+3Y?;&%Y;W5T*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E<V5T<R!T:&4@8W5R<F5N="!L87EO=70@=&\@=&AE('9A;'5E
M('-T;W)E9"!I;B!T:&4@<')E9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('5N<V5R:6%L:7IE*"1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T(#T@0'5N<V5R:6%L:7IE*"1D871A*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S:6YG;&4@:6YS=&%N8V4@;V8@=&AE($AO<F1E
M7T)L;V-K7TQA>6]U=%]-86YA9V5R(&-L87-S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64*("`@("`J($!P87)A;2!(;W)D95]";&]C:U]#
M;VQL96-T:6]N("8D8V]L;&5C=&EO;@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T80H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N($AO<F1E7T)L;V-K7TQA>6]U=%]-86YA9V5R("!4:&4@2&]R9&5?0FQO
M8VM?3&%Y;W5T7TUA;F%G97(@:6YS=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)&YA;64L("8D8V]L;&5C=&EO;BP@)&1A=&$@/2`G
M)RD*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<R`](&%R<F%Y*"D[
M"B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1N86UE72DI('L*("`@
M("`@("`@("`@)&EN<W1A;F-E<ULD;F%M95T@/2!N97<@2&]R9&5?0FQO8VM?
M3&%Y;W5T7TUA;F%G97(H)&-O;&QE8W1I;VXL("1D871A*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1I;G-T86YC97-;)&YA;65=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4')O8V5S<R!A(&UO9&EF:6-A=&EO;B!T;R!T:&4@8W5R
M<F5N="!L87EO=70N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@)&%C=&EO
M;@H@("`@("H@0'9A<B!I;G1E9V5R("1R;W<*("`@("`J($!V87(@:6YT96=E
M<B`D8V]L"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L92@D86-T:6]N+"`D
M<F]W+"`D8V]L*0H@("`@>PH@("`@("`@('-W:71C:"`H)&%C=&EO;BD@>PH@
M("`@("`@(&-A<V4@)VUO=F55<"<Z"B`@("`@("`@8V%S92`G;6]V941O=VXG
M.@H@("`@("`@(&-A<V4@)VUO=F5,969T)SH*("`@("`@("!C87-E("=M;W9E
M4FEG:'0G.@H@("`@("`@(&-A<V4@)V5X<&%N9%5P)SH*("`@("`@("!C87-E
M("=E>'!A;F1$;W=N)SH*("`@("`@("!C87-E("=E>'!A;F1,969T)SH*("`@
M("`@("!C87-E("=E>'!A;F12:6=H="<Z"B`@("`@("`@8V%S92`G<VAR:6YK
M3&5F="<Z"B`@("`@("`@8V%S92`G<VAR:6YK4FEG:'0G.@H@("`@("`@(&-A
M<V4@)W-H<FEN:U5P)SH*("`@("`@("!C87-E("=S:')I;FM$;W=N)SH*("`@
M("`@("!C87-E("=R96UO=F5";&]C:R<Z"B`@("`@("`@("`@("1R97-U;'0@
M/2!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,L("1A8W1I;VXI+"`D<F]W
M+"`D8V]L*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A
M=&EO;B==+3YP=7-H*"1R97-U;'0I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U<&1A=&5D(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@+R\@4V%V92!T
M:&4@8VAA;F=E<R!M861E('1O(&$@8FQO8VLN"B`@("`@("`@8V%S92`G<V%V
M92<Z"B`@("`@("`@+R\@4V%V92!T:&4@8VAA;F=E<R!M861E('1O(&$@8FQO
M8VL@86YD(&-O;G1I;G5E(&5D:71I;F<N"B`@("`@("`@8V%S92`G<V%V92UR
M97-U;64G.@H@("`@("`@("`@("`O+R!'970@<F5Q=65S=&5D(&)L;V-K('1Y
M<&4N"B`@("`@("`@("`@(&QI<W0H)&YE=V%P<"P@)&YE=W1Y<&4I(#T@97AP
M;&]D92@G.B<L(%5T:6PZ.F=E=$9O<FU$871A*"=A<'`G*2D["@H@("`@("`@
M("`@("`O+R!)<R!T:&ES(&$@;F5W(&)L;V-K/PH@("`@("`@("`@("`D;F5W
M(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T>2@D<F]W
M+"`D8V]L*2!\?`H@("`@("`@("`@("`@("`@(21T:&ES+3YR;W=%>&ES=',H
M)')O=RD@?'P*("`@("`@("`@("`@("`@("$D=&AI<RT^8V]L17AI<W1S*"1C
M;VPI*2!["B`@("`@("`@("`@("`@("`O+R!#:&5C:R!P97)M:7-S:6]N<RX*
M("`@("`@("`@("`@("`@(&EF("A(;W)D93HZ:&%S4&5R;6ES<VEO;B@G;6%X
M7V)L;V-K<R<I("$]/2!T<G5E("8F"B`@("`@("`@("`@("`@("`@("`@2&]R
M9&4Z.FAA<U!E<FUI<W-I;VXH)VUA>%]B;&]C:W,G*2`\/2`D=&AI<RT^8V]U
M;G0H*2D@>PH@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@0&AT;6QS
M<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")9;W4@87)E(&YO="!A;&QO=V5D('1O
M(&-R96%T92!M;W)E('1H86X@)60@8FQO8VMS+B(I+"!(;W)D93HZ:&%S4&5R
M;6ES<VEO;B@G;6%X7V)L;V-K<R<I*2P@14Y47T-/35!!5"P@3DQ3.CIG971#
M:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-O
M;F9;)VAO;VMS)UU;)W!E<FUS9&5N:65D)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1M97-S86=E(#T@2&]R9&4Z.F-A;&Q(;V]K*"=?<&5R;7-?
M:&]O:U]D96YI960G+"!A<G)A>2@G:&]R9&4Z;6%X7V)L;V-K<R<I+"`G:&]R
M9&4G+"`D;65S<V%G92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1'3$]"04Q36R=N;W1I9FEC871I;VXG72T^<'5S:"@D
M;65S<V%G92P@)VAO<F1E+F5R<F]R)RP@87)R87DH)V-O;G1E;G0N<F%W)RDI
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1N97<@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@+R\@36%K92!S=7)E('1H97)E(&ES('-O;65W:&5R92!T;R!P=70@:70N
M"B`@("`@("`@("`@("`@("`D=&AI<RT^861D0FQO8VLH)')O=RP@)&-O;"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($]R(&%N(&5X:7-T:6YG
M(&]N93\*("`@("`@("`@("`@)&5X:7-T<R`](&9A;'-E.PH@("`@("`@("`@
M("`D8VAA;F=E9"`](&9A;'-E.PH@("`@("`@("`@("!I9B`H(21N97<I('L*
M("`@("`@("`@("`@("`@("\O($=E="!T87)G970@8FQO8VL@:6YF;RX*("`@
M("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/F=E=$)L;V-K26YF;R@D<F]W
M+"`D8V]L*3L*("`@("`@("`@("`@("`@("1E>&ES=',@/2`D=&AI<RT^:7-"
M;&]C:R@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@("`@("\O($AA<R!A(&1I
M9F9E<F5N="!B;&]C:R!B965N('-E;&5C=&5D/PH@("`@("`@("`@("`@("`@
M:68@*"1E>&ES=',@)B8*("`@("`@("`@("`@("`@("`@("`H)&EN9F];)V%P
M<"==("$]("1N97=A<'`@?'P*("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)V)L;V-K)UT@(3T@)&YE=W1Y<&4I*2!["B`@("`@("`@("`@("`@("`@("`@
M)&-H86YG960@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&YE=R!\?"`D8VAA;F=E9"D@>PH@("`@
M("`@("`@("`@("`@+R\@0VAA;F=E(&%P<"!O<B!T>7!E+@H@("`@("`@("`@
M("`@("`@)&EN9F\@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&EN9F];
M)V%P<"==(#T@)&YE=V%P<#L*("`@("`@("`@("`@("`@("1I;F9O6R=B;&]C
M:R==(#T@)&YE=W1Y<&4["B`@("`@("`@("`@("`@("`D<&%R86US(#T@)'1H
M:7,M/E]C;VQL96-T:6]N+3YG971087)A;7,H)&YE=V%P<"P@)&YE=W1Y<&4I
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D;F5W<&%R
M86TI('L*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG<&%R86US)UU;)&YE
M=W!A<F%M72`]("1T:&ES+3Y?8V]L;&5C=&EO;BT^9V5T1&5F875L=%9A;'5E
M*"1N97=A<'`L("1N97=T>7!E+"`D;F5W<&%R86TI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$)L;V-K26YF;R@D<F]W
M+"`D8V]L+"`D:6YF;RD["B`@("`@("`@("`@('T@96QS96EF("@D97AI<W1S
M*2!["B`@("`@("`@("`@("`@("`O+R!#:&%N9V4@=F%L=65S+@H@("`@("`@
M("`@("`@("`@)'1H:7,M/G-E=$)L;V-K26YF;R@D<F]W+"`D8V]L+"!A<G)A
M>2@G<&%R86US)R`]/B!5=&EL.CIG971&;W)M1&%T82@G<&%R86US)RP@87)R
M87DH*2DI*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W5P
M9&%T960@/2!T<G5E.PH@("`@("`@("`@("!I9B`H)&%C=&EO;B`]/2`G<V%V
M92<I('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"@H@
M("`@("`@("\O($UA:V4@82!B;&]C:R!T:&4@8W5R<F5N="!B;&]C:R!F;W(@
M961I=&EN9RX*("`@("`@("!C87-E("=E9&ET)SH*("`@("`@("`@("`@)'1H
M:7,M/E]C=7)R96YT0FQO8VL@/2!A<G)A>2@D<F]W+"`D8V]L*3L*("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M2&%S('1H92!L87EO=70@8F5E;B!C:&%N9V5D('-I;F-E(&ET('=A<R!I;G-T
M86YT:6%T960_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('5P9&%T960H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W5P9&%T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M=&AE(&-U<G)E;G0@8FQO8VL@<F]W(&%N9"!C;VQU;6XN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2!;<F]W+"!C;VQ="B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$-U<G)E;G1";&]C:R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?8W5R<F5N=$)L;V-K.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@2&]R9&5?0FQO8VL@870@=&AE('-P96-I9FEE9"!P;W-I=&EO
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]";&]C:R`@5&AE
M(&)L;V-K(&9R;VT@=&AA="!P;W-I=&EO;B!O<B!A(%!%05)?17)R;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@(&EF('-O;65T:&EN9R!W96YT('=R
M;VYG+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T0FQO8VLH)')O=RP@)&-O
M;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8FQO8VMS6R1R
M;W==6R1C;VQ=*2D@>PH@("`@("`@("`@("`D9FEE;&0@/2`D=&AI<RT^7VQA
M>6]U=%LD<F]W75LD8V]L73L*("`@("`@("`@("`@)'1H:7,M/E]B;&]C:W-;
M)')O=UU;)&-O;%T@/0H@("`@("`@("`@("`@("`@)DAO<F1E7T)L;V-K7T-O
M;&QE8W1I;VXZ.F=E=$)L;V-K*"1F:65L9%LG87!P)UTL("1F:65L9%LG<&%R
M86US)UU;)W1Y<&4G72P@)&9I96QD6R=P87)A;7,G75LG<&%R86US)UTI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VMS6R1R;W==
M6R1C;VQ=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]O
M<F1I;F%T97,@;V8@=&AE(&)L;V-K(&-O=F5R:6YG('1H92!S<&5C:69I960*
M("`@("`J(&9I96QD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R
M;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@
M($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@=&]P+6QE9G0@<F]W+6-O;'5M;BUC;V]R9&EN871E(&]F('1H92!B
M;&]C:PH@("`@("H@("`@("`@("`@("`@("`@8V]V97)I;F<@=&AE('-P96-I
M9FEE9"!F:65L9"!O<B!N=6QL(&EF('1H92!F:65L9`H@("`@("H@("`@("`@
M("`@("`@("`@:7,@96UP='DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)L
M;V-K070H)')O=RP@)&-O;"D*("`@('L*("`@("`@("`O*B!4<FEV:6%L(&-A
M<V5S(&9I<G-T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T>2@D<F]W
M+"`D8V]L*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]
M(&5L<V5I9B`H(21T:&ES+3YI<T-O=F5R960H)')O=RP@)&-O;"DI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R;W<L("1C;VPI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5&AI<R!I<R!A(&-O=F5R960@9FEE;&0N("HO"B`@("`@
M("`@9F]R("@D=&5S="`]("1R;W<@+2`Q.R`D=&5S="`^/2`P.R`D=&5S="TM
M*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES0V]V97)E9"@D=&5S="P@
M)&-O;"D@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^:7-%;7!T>2@D=&5S
M="P@)&-O;"D@)B8*("`@("`@("`@("`@("`@("1T97-T("L@)'1H:7,M/F=E
M=$AE:6=H="@D=&5S="P@)&-O;"D@+2`Q(#T]("1R;W<I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@D=&5S="P@)&-O;"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@9F]R("@D=&5S="`]("1C;VP@+2`Q.R`D
M=&5S="`^/2`P.R`D=&5S="TM*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FES0V]V97)E9"@D<F]W+"`D=&5S="D@)B8*("`@("`@("`@("`@("`@("$D
M=&AI<RT^:7-%;7!T>2@D=&5S="P@)&-O;"D@)B8*("`@("`@("`@("`@("`@
M("1T97-T("L@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1T97-T*2`M(#$@/3T@
M)&-O;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R;W<L("1T
M97-T*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<V]M92!U<V5F=6P@:6YF;W)M
M871I;VX@86)O=70@=&AE('-P96-I9FEE9`H@("`@("H@8FQO8VLN"B`@("`@
M*@H@("`@("H@4F5T=7)N960@:&%S:"!V86QU97,Z"B`@("`@*B`G87!P)SH@
M87!P;&EC871I;VX@;F%M90H@("`@("H@)V)L;V-K)SH@8FQO8VL@;F%M90H@
M("`@("H@)W!A<F%M<R<Z('!A<F%M971E<B!H87-H"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@(%1H92!I;F9O<FUA=&EO;B!H87-H+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971";&]C:TEN9F\H)')O=RP@)&-O;"D*("`@
M('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C
M;VQ=*2!\?`H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72`]/2`G96UP='DG*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DYO(&)L;V-K(&5X:7-T<R!A="!T:&4@<F5Q=65S=&5D('!O
M<VET:6]N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=A<'`G(#T^("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C
M;VQ=6R=A<'`G72P*("`@("`@("`@("`@("`@("`@("`@)V)L;V-K)R`]/B`D
M=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG<&%R86US)UU;)W1Y<&4G72P*
M("`@("`@("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@)'1H:7,M/E]L87EO
M=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=P87)A;7,G72D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S(&$@8F%T8V@@;V8@:6YF;W)M871I;VX@86)O
M=70@=&AE('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*B!`<&%R86T@87)R
M87D@)&EN9F\@("!!(&AA<V@@=VET:"!I;F9O<FUA=&EO;B!V86QU97,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!0;W-S:6)L92!E;&5M96YT<R!A
M<F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`G87!P)SH@87!P;&EC
M871I;VX@;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)V)L;V-K
M)SH@8FQO8VL@;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@)W!A
M<F%M<R<Z('!A<F%M971E<B!H87-H"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$)L;V-K26YF;R@D<F]W+"`D8V]L+"`D:6YF;R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F\@8FQO8VL@97AI<W1S(&%T('1H92!R97%U97-T960@<&]S:71I;VXB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&EN9F];)V%P<"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W75LD8V]L75LG87!P)UT@/2`D:6YF;ULG87!P)UT["B`@("`@("`@?0H@
M("`@("`@(&EF("AI<W-E="@D:6YF;ULG8FQO8VLG72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=T>7!E
M)UT@/2`D:6YF;ULG8FQO8VLG73L*("`@("`@("!]"B`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=P87)A;7,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=P87)A;7,G72`]("1I;F9O
M6R=P87)A;7,G73L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?8VAA;F=E
M9%]R;W<@/2`D<F]W.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D
M8V]L.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R
M(&]F(&)L;V-K<R!I;B!T:&4@8W5R<F5N="!L87EO=70N"B`@("`@*@H@("`@
M("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!R971U<FX@:6YT
M96=E<B`@5&AE(&YU;6)E<B!O9B!B;&]C:W,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O=6YT*"D*("`@('L*("`@("`@("`D<F]W<R`]("1T:&ES+3YR;W=S
M*"D["B`@("`@("`@)&-O=6YT(#T@,#L*"B`@("`@("`@9F]R("@D<F]W(#T@
M,#L@)')O=R`\("1R;W=S.R`D<F]W*RLI('L*("`@("`@("`@("`@)&-O;',@
M/2`D=&AI<RT^8V]L=6UN<R@D<F]W*3L*("`@("`@("`@("`@9F]R("@D8V]L
M(#T@,#L@)&-O;"`\("1C;VQS.R`D8V]L*RLI('L*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/FES16UP='DH)')O=RP@)&-O;"D@)B8*("`@("`@("`@
M("`@("`@("`@("`A)'1H:7,M/FES0V]V97)E9"@D<F]W+"`D8V]L*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1C;W5N="LK.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-O
M=6YT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;G5M8F5R
M(&]F(')O=W,@:6X@=&AE(&-U<G)E;G0@;&%Y;W5T+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5&AE(&YU;6)E<B!O9B!R;W=S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R;W=S*"D*("`@('L*("`@("`@("!R971U<FX@8V]U
M;G0H)'1H:7,M/E]L87EO=70I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@=&AE('-P96-I9FEE9"!R
M;W<@;V8@=&AE"B`@("`@*B!C=7)R96YT(&QA>6]U="X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<F]W("!4:&4@<F]W('1O(')E='5R;B!T:&4@
M;G5M8F5R(&]F(&-O;'5M;G,@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&EN=&5G97(@(%1H92!N=6UB97(@;V8@8V]L=6UN<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]L=6UN<R@D<F]W*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]L87EO=71;)')O=UTI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B5&AE('-P96-I9FEE9"!R
M;W<@*"5D*2!D;V5S(&YO="!E>&ES="XB*2P@)')O=RDL("=H;W)D92YE<G)O
M<B<I.PH@("`@("`@('T*("`@("`@("!R971U<FX@8V]U;G0H)'1H:7,M/E]L
M87EO=71;)')O=UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O
M('-E92!I9B!A(&=I=F5N(&QO8V%T:6]N(&EF(&)E:6YG('5S960@8GD@82!B
M;&]C:PH@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y
M;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T
M(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@=&AE(&QO8V%T:6]N(&ES(&5M<'1Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@($9A;'-E(&ES('1H92!L;V-A=&EO;B!I<R!B96EN9R!U<V5D+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<T5M<'1Y*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@<F5T=7)N("%I<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M72D@?'P@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%T@/3T@)V5M<'1Y)SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@=&AE(&9I96QD(&%T
M('1H92!S<&5C:69I960@<&]S:71I;VX@:7,@8V]V97)E9"!B>0H@("`@("H@
M86YO=&AE<B!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L
M("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&EF('1H92!S<&5C:69I960@9FEE;&0@:7,@8V]V97)E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;W9E<F5D*"1R;W<L("1C;VPI"B`@
M("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==
M6R1C;VQ=*2`_("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T]("=C;W9E
M<F5D)R`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M9B!T:&4@<W!E8VEF:65D(&QO8V%T:6]N(&ES('1H92!T;W`@;&5F="!F:65L
M9"!O9@H@("`@("H@82!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C:69I960@<&]S:71I;VX@:7,@
M82!B;&]C:RP@9F%L<V4@:68*("`@("`J("`@("`@("`@("`@("`@("`@=&AE
M(&9I96QD(&1O97-N)W0@97AI<W0L(&ES(&5M<'1Y(&]R(&-O=F5R960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES0FQO8VLH)')O=RP@)&-O;"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G)O=T5X:7-T<R@D<F]W*2`F)B`D=&AI
M<RT^8V]L17AI<W1S*"1C;VPI("8F"B`@("`@("`@("`@("$D=&AI<RT^:7-%
M;7!T>2@D<F]W+"`D8V]L*2`F)B`A)'1H:7,M/FES0V]V97)E9"@D<F]W+"`D
M8V]L*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:68@=&AE('-P
M96-I9FEE9"!B;&]C:R!H87,@8F5E;B!C:&%N9V5D(&QA<W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&ES(&)L;V-K
M(&ES('1H92!L87-T(&]N92!T:&%T('=A<R!C:&%N9V5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!I<T-H86YG960H)')O=RP@)&-O;"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]C:&%N9V5D7W)O=R`]/3T@)')O=R`F)B`D=&AI
M<RT^7V-H86YG961?8V]L(#T]/2`D8V]L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I9B!T:&4@<W!E8VEF:65D(&)L;V-K(&UA>2!B92!R96UO
M=F5D+@H@("`@("H*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W
M("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!
M(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H:7,@8FQO8VL@;6%Y(&)E(')E;6]V960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&ES4F5M;W9A8FQE*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@9VQO8F%L("1C;VYF.PH*("`@("`@("`D87!P(#T@)'1H:7,M/E]L
M87EO=71;)')O=UU;)&-O;%U;)V%P<"==.PH@("`@("`@("1T>7!E(#T@)'1H
M:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W!A<F%M<R==6R=T>7!E)UT["B`@
M("`@("`@)&)L;V-K(#T@)&%P<"`N("<Z)R`N("1T>7!E.PH*("`@("`@("`O
M*B!#:&5C:R!I9B!T:&4@8FQO8VL@:7,@82!F:7AE9"!B;&]C:RX@*B\*("`@
M("`@("!I9B`H(6EN7V%R<F%Y*"1B;&]C:RP@)&-O;F9;)W!O<G1A;"==6R=F
M:7AE9%]B;&]C:W,G72DI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!I9B!W92!H879E('-T:6QL(&%N
M;W1H97(@8FQO8VL@;V8@=&AE('-A;64@='EP92X@*B\*("`@("`@("`D9F]U
M;F0@/2!F86QS93L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VQA>6]U="!A
M<R`D8W5R7W)O=RD@>PH@("`@("`@("`@("!F;W)E86-H("@D8W5R7W)O=R!A
M<R`D8W5R7V-O;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C=7)?
M8V]L6R=A<'`G72D@)B8*("`@("`@("`@("`@("`@("`@("`D8W5R7V-O;%LG
M87!P)UT@/3T@)&%P<"`F)@H@("`@("`@("`@("`@("`@("`@("1C=7)?8V]L
M6R=P87)A;7,G75LG='EP92==(#T]("1T>7!E*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*"1F;W5N9"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!A;B!54DP@=')I9V=E<FEN9R!A;B!A8W1I;VX@
M=&\@82!B;&]C:PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO
M;B`@06X@86-T:6]N('1O('1R:6=G97(N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D<F]W("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M8V]L("!!(&QA>6]U="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@($%N(%523"!W:71H(&%L;"!N96-E<W-A<GD@<&%R86UE=&5R<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T06-T:6]N57)L*"1A8W1I;VXL("1R
M;W<L("1C;VPI"B`@("!["B`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<BA(;W)D93HZ<V5L9E5R;"@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V-O;"<@/3X@)&-O;"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R;W<G(#T^("1R;W<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G86-T:6]N
M)R`]/B`D86-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VYO8V%C:&4G(#T^(&)A<V5?8V]N=F5R="AM:6-R;W1I;64H
M*2P@,3`L(#,V*2DI.PH@("`@("`@(')E='5R;B`D=7)L("X@)R-B;&]C:R<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V]N=')O;"`H;&EN
M:V5D(&%R<F]W*2!F;W(@82!C97)T86EN(&%C=&EO;B!O;B!T:&4*("`@("`J
M('-P96-I9FEE9"!B;&]C:RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("!!(&-O;G1R;VP@='EP92!I;B!T:&4@9F]R;0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(FUO9&EF:6-A=&EO;B]D:7)E8W1I;VXB+B!0
M;W-S:6)L92!V86QU97,@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!M;V1I9FEC871I;VXZ(&5X<&%N9"P@<VAR:6YK+"!M;W9E+B!0;W-S:6)L
M92!V86QU97,*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&9O<B!D:7)E
M8W1I;VXZ('5P+"!D;W=N+"!L969T+"!R:6=H="X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@02!L:6YK(&-O;G1A:6YI;F<@86X@87)R;W<@<F5P<F5S
M96YT:6YG('1H92!R97%U97-T960*("`@("`J("`@("`@("`@("`@("`@("!C
M;VYT<F]L+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971#;VYT<F]L*"1T>7!E
M+"`D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@("1T>7!E(#T@97AP;&]D92@G
M+R<L("1T>7!E*3L*("`@("`@("`D86-T:6]N(#T@)'1Y<&5;,%T@+B!U8V9I
M<G-T*"1T>7!E6S%=*3L*("`@("`@("`D=7)L(#T@)'1H:7,M/F=E=$%C=&EO
M;E5R;"@D86-T:6]N+"`D<F]W+"`D8V]L*3L*"B`@("`@("`@<W=I=&-H("@D
M='EP95LP72D@>PH@("`@("`@(&-A<V4@)V5X<&%N9"<Z"B`@("`@("`@("`@
M("1T:71L92`](%\H(D5X<&%N9"(I.PH@("`@("`@("`@("`D:6UG(#T@)VQA
M<F=E7R<@+B`D='EP95LQ73L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)W-H<FEN:R<Z"B`@("`@("`@("`@("1T:71L92`](%\H(E-H<FEN
M:R(I.PH@("`@("`@("`@("`D:6UG(#T@)VQA<F=E7R<["@H@("`@("`@("`@
M("!S=VET8V@@*"1T>7!E6S%=*2!["B`@("`@("`@("`@(&-A<V4@)W5P)SH*
M("`@("`@("`@("`@("`@("1I;6<@+CT@)V1O=VXG.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=D;W=N)SH*("`@("`@("`@
M("`@("`@("1I;6<@+CT@)W5P)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G;&5F="<Z"B`@("`@("`@("`@("`@("`D:6UG
M("X]("=R:6=H="<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)W)I9VAT)SH*("`@("`@("`@("`@("`@("1I;6<@+CT@)VQE
M9G0G.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)VUO=F4G.@H@("`@("`@
M("`@("!S=VET8V@@*"1T>7!E6S%=*2!["B`@("`@("`@("`@(&-A<V4@)W5P
M)SH*("`@("`@("`@("`@("`@("1T:71L92`](%\H(DUO=F4@57`B*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9&]W;B<Z
M"B`@("`@("`@("`@("`@("`D=&ET;&4@/2!?*")-;W9E($1O=VXB*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;&5F="<Z
M"B`@("`@("`@("`@("`@("`D=&ET;&4@/2!?*")-;W9E($QE9G0B*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<FEG:'0G
M.@H@("`@("`@("`@("`@("`@)'1I=&QE(#T@7R@B36]V92!2:6=H="(I.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1I;6<@/2`D='EP95LQ73L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@2&]R9&4Z.FQI;FLH)'5R;"P@)'1I=&QE
M*2`N"B`@("`@("`@("`@($AO<F1E.CII;6<H)V)L;V-K+R<@+B`D:6UG("X@
M)RYP;F<G+"`D=&ET;&4L("<G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T
M26UA9V5$:7(H)VAO<F1E)RDI("X@)SPO83XG.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&]E<R!A(')O=R!E>&ES=#\*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<F]W("!4:&4@<F]W('1O(&QO;VL@9F]R"B`@("`@*@H@("`@
M("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!R;W<@97AI<W1S"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')O=T5X:7-T<R@D<F]W*0H@("`@>PH@("`@
M("`@(')E='5R;B`D<F]W(#P@8V]U;G0H)'1H:7,M/E]L87EO=70I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1&]E<R!A(&-O;'5M;B!E>&ES=#\*("`@("`J
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!4:&4@8V]L=6UN('1O(&QO
M;VL@9F]R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H92!C;VQU;6X@97AI<W1S"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;$5X
M:7-T<R@D8V]L*0H@("`@>PH@("`@("`@(')E='5R;B`D8V]L(#P@)'1H:7,M
M/E]C;VQU;6YS.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T('1H92!W:61T
M:"!O9B!T:&4@8FQO8VL@870@82!G:79E;B!L;V-A=&EO;BX*("`@("`J(%1H
M:7,@<F5T=7)N<R!T:&4@=VED=&@@:68@=&AE<F4@:7,@82!B;&]C:R!A="!T
M:&ES"B`@("`@*B!L;V-A=&EO;BP@;W1H97)W:7-E(')E='5R;G,@,2X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U="!R;W<N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU;6XN
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F
M(&-O;'5M;G,@=&AI<R!B;&]C:R!S<&%N<PH@("`@("HO"B`@("!F=6YC=&EO
M;B!G9717:61T:"@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`Q.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG=VED=&@G72`](#$[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VQA>6]U=%LD<F]W
M75LD8V]L75LG=VED=&@G73L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T
M:&4@:&5I9VAT(&]F('1H92!B;&]C:R!A="!A(&=I=F5N(&QO8V%T:6]N+@H@
M("`@("H@5&AI<R!R971U<FYS('1H92!H96EG:'0@:68@=&AE<F4@:7,@82!B
M;&]C:R!A="!T:&ES"B`@("`@*B!L;V-A=&EO;BP@;W1H97)W:7-E(')E='5R
M;G,@,2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA
M>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U
M="!C;VQU;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@
M;G5M8F5R(&]F(')O=W,@=&AI<R!B;&]C:R!S<&%N<PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971(96EG:'0H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=*2D@>PH@
M("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!]"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H96EG
M:'0G72`](#$["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^7VQA
M>6]U=%LD<F]W75LD8V]L75LG:&5I9VAT)UT["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&%N(&5M<'1Y(&)L;V-K(&%T('1H92!S<&5C:69I960@<&]S
M:71I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1";&]C:R@D<F]W
M+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/G)O=T5X:7-T<R@D
M<F]W*2D@>PH@("`@("`@("`@("`D=&AI<RT^861D4F]W*"1R;W<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H(21T:&ES+3YC;VQ%>&ES=',H)&-O;"DI('L*
M("`@("`@("`@("`@)'1H:7,M/F%D9$-O;"@D8V]L*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=(#T@87)R87DH)V%P
M<"<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H96EG:'0G(#T^(#$L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^(#$L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86US)R`]
M/B!A<G)A>2@G='EP92<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A
M;7,G(#T^(&%R<F%Y*"DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M82!N97<@<F]W('1O('1H92!L87EO=70N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)')O=R`@5&AE(&YU;6)E<B!O9B!T:&4@<F]W('1O(&%D9`H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&12;W<H)')O=RD*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]C;VQU;6YS(#X@,"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W72`](&%R<F%Y7V9I;&PH,"P@)'1H:7,M/E]C;VQU
M;6YS+"`G96UP='DG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&$@;F5W(&-O;'5M;B!T;R!T:&4@;&%Y;W5T+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1C;VP@(%1H92!N=6UB97(@;V8@=&AE(&-O
M;'5M;B!T;R!A9&0*("`@("`J+PH@("`@9G5N8W1I;VX@861D0V]L*"1C;VPI
M"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]L87EO=70@87,@)&ED
M(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&ED75LD
M8V]L72`]("=E;7!T>2<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?8V]L
M=6UN<RLK.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A(&)L;V-K
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O
M;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E0FQO8VLH)')O=RP@
M)&-O;"D*("`@('L*("`@("`@("`D=VED=&@@/2`D=&AI<RT^9V5T5VED=&@H
M)')O=RP@)&-O;"D["B`@("`@("`@)&AE:6=H="`]("1T:&ES+3YG971(96EG
M:'0H)')O=RP@)&-O;"D["B`@("`@("`@9F]R("@D:2`]("1H96EG:'0@+2`Q
M.R`D:2`^/2`P.R`D:2TM*2!["B`@("`@("`@("`@(&9O<B`H)&H@/2`D=VED
M=&@@+2`Q.R`D:B`^/2`P.R`D:BTM*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1C;VP@*R`D:ET@/2`G96UP='DG.PH@
M("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1C;VP@*R`D
M:B`K(#$I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G)E;6]V94-O
M;$EF16UP='DH)&-O;"`K("1J*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES=',H)')O
M=R`K("1I("L@,2D@)B8@)'1H:7,M/G)O=T5X:7-T<R@D<F]W("L@)&DI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5M;W9E4F]W269%;7!T>2@D<F]W
M("L@)&DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG
M961?8V]L(#T@)&-O;#L*"B`@("`@("`@:68@*"$D=&AI<RT^<F]W17AI<W1S
M*"1R;W<I*2!["B`@("`@("`@("`@("1R;W<M+3L*("`@("`@("`@("`@=VAI
M;&4@*"1R;W<@/CT@,"`F)B`D=&AI<RT^<F5M;W9E4F]W269%;7!T>2@D<F]W
M*2D@>PH@("`@("`@("`@("`@("`@)')O=RTM.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/F-O;$5X:7-T<R@D8V]L*2D@
M>PH@("`@("`@("`@("`D8V]L+2T["B`@("`@("`@("`@('=H:6QE("@D8V]L
M(#X](#`@)B8@)'1H:7,M/G)E;6]V94-O;$EF16UP='DH)&-O;"DI('L*("`@
M("`@("`@("`@("`@("1C;VPM+3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!R;W<@:68@:70G<R!E
M;7!T>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!4:&4@
M;G5M8F5R(&]F('1H92!R;W<@=&\@=&\@8VAE8VL*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE(')O=R!I<R!N;W<@<F5M;W9E
M9"X*("`@("`J("`@("`@("`@("`@("`@("`@1F%L<V4@:68@=&AE(')O=R!S
M=&EL;"!E>&ES=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V95)O=TEF
M16UP='DH)')O=RD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3YR;W=%>&ES
M=',H)')O=RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("`D<F]W<R`](&-O=6YT*"1T:&ES+3Y?;&%Y;W5T6R1R;W==
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F]W<SL@)&DK*RD@>PH@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]L87EO=71;)')O=UU;)&E=
M*2`F)B`D=&AI<RT^7VQA>6]U=%LD<F]W75LD:5T@(3T@)V5M<'1Y)RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@('5N<V5T*"1T:&ES+3Y?;&%Y;W5T6R1R;W==*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96UO=F5S(&$@8V]L=6UN(&EF(&ET)W,@96UP='DN"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-O;"`@5&AE(&YU;6)E<B!O9B!T:&4@8V]L=6UN
M('1O('1O(&-H96-K"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF('1H92!C;VQU;6X@:7,@;F]W(')E;6]V960N"B`@("`@*B`@("`@
M("`@("`@("`@("`@($9A;'-E(&EF('1H92!C;VQU;6X@<W1I;&P@97AI<W1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5#;VQ)9D5M<'1Y*"1C;VPI
M"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1C;VPI*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M)&-O;',@/2!C;W5N="@D=&AI<RT^7VQA>6]U="D["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&-O;',[("1I*RLI('L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?;&%Y;W5T6R1I75LD8V]L72D@)B8@)'1H:7,M/E]L87EO
M=71;)&E=6R1C;VQ=("$]("=E;7!T>2<I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)&-O;',[("1I*RLI('L*("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]L87EO=71;)&E=6R1C;VQ=*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@36]V
M97,@82!B;&]C:R!O;F4@<F]W('5P+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;6]V955P*"1R;W<L("1C;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3YR;W=%>&ES=',H)')O=R`M(#$I*2!["B`@("`@("`@("`@("1W:61T:"`]
M("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@+R\@
M4V5E(&EF('1H97)E)W,@<F]O;2!T;R!M;W9E(&EN=&\*("`@("`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@+2`Q+"`D8V]L("L@)&DI
M*2!["B`@("`@("`@("`@("`@("`@("`@)&EN7W=A>2`]("1T:&ES+3YG971"
M;&]C:T%T*"1R;W<@+2`Q+"`D8V]L("L@)&DI.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-?;G5L;"@D:6Y?=V%Y*2`F)@H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6Y?=V%Y6S%=(#T]("1C;VP@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F=E=%=I9'1H*"1I;E]W87E;,%TL("1I;E]W87E;
M,5TI(#T]("1W:61T:"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!7
M92!N965D('1O('-W87`@=&AE(&)L;V-K<RX*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E8S$@/2!(;W)D95]!<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES
M+3Y?;&%Y;W5T+"`D<F]W+"`D8V]L+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E
M=$AE:6=H="@D<F]W+"`D8V]L*2P@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C
M;VPI*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E8S(@/2!(;W)D95]!
M<G)A>3HZ9V5T4F5C=&%N9VQE*"1T:&ES+3Y?;&%Y;W5T+"`D:6Y?=V%Y6S!=
M+"`D:6Y?=V%Y6S%=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=$AE:6=H="@D
M:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2P@)'1H:7,M/F=E=%=I9'1H*"1I;E]W
M87E;,%TL("1I;E]W87E;,5TI*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S$I.R`D:BLK*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N
M="@D<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L87EO=71;)&EN7W=A>5LP72`K("1J75LD:6Y?
M=V%Y6S%=("L@)&M=(#T@)')E8S%;)&I=6R1K73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D
M<F5C,BD[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&L@/2`P.R`D:R`\(&-O=6YT*"1R96,R6R1J72D[("1K*RLI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M:6Y?=V%Y6S!=("L@8V]U;G0H)')E8S$I("L@)&I=6R1I;E]W87E;,5T@*R`D
M:UT@/2`D<F5C,ELD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D:6Y?=V%Y6S!=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@
M)&EN7W=A>5LQ73L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R!.
M;W=H97)E('1O(&=O+@H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN
M9R<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D;&%S=')O=R`]("1R;W<@*R`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L
M("1C;VPI("T@,3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I
M9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<')E=B`]("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T["B`@("`@("`@("`@("`@("`O+R!-
M;W9E('1O<"!E9&=E"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD
M<F]W("T@,5U;)&-O;"`K("1I72`]("1P<F5V.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I72`]("=C;W9E<F5D)SL*
M("`@("`@("`@("`@("`@("\O($UO=F4@8F]T=&]M(&5D9V4*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T<F]W75LD8V]L("L@)&E=(#T@
M)V5M<'1Y)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^<F]W17AI<W1S*"1L87-T<F]W("L@,2DI('L*("`@("`@("`@("`@("`@
M("\O(%=A<R!O;B!T:&4@8F]T=&]M(')O=PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G)E;6]V95)O=TEF16UP='DH)&QA<W1R;W<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O
M=R`M(#$["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&)L;V-K(&]N92!R;W<@9&]W
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F5$;W=N*"1R;W<L("1C
M;VPI"B`@("!["B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R
M;W<L("1C;VPI.PH@("`@("`@("1L87-T<F]W(#T@)')O=R`K("1T:&ES+3YG
M971(96EG:'0H)')O=RP@)&-O;"D["B`@("`@("`@:68@*"1T:&ES+3YR;W=%
M>&ES=',H)&QA<W1R;W<I*2!["B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R
M92=S(')O;VT@=&\@;6]V92!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1W:61T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*"$D
M=&AI<RT^:7-%;7!T>2@D;&%S=')O=RP@)&-O;"`K("1I*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1I;E]W87D@/2`D=&AI<RT^9V5T0FQO8VM!="@D;&%S
M=')O=RP@)&-O;"`K("1I*3L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)&EN7W=A>2D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M7W=A>5LQ72`]/2`D8V]L("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2`]/2`D=VED
M=&@I('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@;F5E9"!T;R!S
M=V%P('1H92!B;&]C:W,N"B`@("`@("`@("`@("`@("`@("`@("`@("1R96,Q
M(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@
M)')O=RP@)&-O;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)')O
M=RP@)&-O;"DL("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1R96,R(#T@2&]R9&5?07)R87DZ.F=E=%)E
M8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)&EN7W=A>5LP72P@)&EN7W=A>5LQ
M72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YG971(96EG:'0H)&EN7W=A>5LP72P@
M)&EN7W=A>5LQ72DL("1T:&ES+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?
M=V%Y6S%=*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P
M.R`D:B`\(&-O=6YT*"1R96,R*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R("@D:R`](#`[("1K(#P@8V]U;G0H)')E8S);)&I=
M*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:EU;)&-O;"`K("1K72`]("1R96,R6R1J
M75LD:UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:B`](#`[("1J(#P@8V]U;G0H)')E8S$I.R`D:BLK*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D
M<F5C,5LD:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K(&-O=6YT*"1R96,R*2`K("1J
M75LD8V]L("L@)&M=(#T@)')E8S%;)&I=6R1K73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)&EN
M7W=A>5LP73L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D7V-O;"`]("1I;E]W87E;,5T["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@+R\@3F\@=VAE<F4@=&\@9V\*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG
M:&)O=7)I;F<@8FQO8VLH<RD@;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO
M<F1E+G=A<FYI;F<G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($UA:V4@<F]O;2!T
M;R!M;W9E(&EN=&\*("`@("`@("`@("`@)'1H:7,M/F%D9%)O=R@D;&%S=')O
M=RD["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED
M=&@[("1I*RLI('L*("`@("`@("`@("`@)'!R978@/2`D=&AI<RT^7VQA>6]U
M=%LD<F]W75LD8V]L("L@)&E=.PH@("`@("`@("`@("`O+R!-;W9E(&)O='1O
M;2!E9&=E"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1L87-T<F]W75LD
M8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@("`@("`O+R!-;W9E('1O
M<"!E9&=E"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`Q75LD
M8V]L("L@)&E=(#T@)'!R978["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W==6R1C;VP@*R`D:5T@/2`G96UP='DG.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<@*R`Q.PH@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@("`@?0H*("`@("\J*@H@("`@
M("H@36]V97,@86QL(&)L;V-K<R!B96QO=R!A(&-E<G1A:6X@<F]W(&]N92!R
M;W<@9&]W;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!
M(&QA>6]U="!R;W<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&EF(&%L;"!R;W=S(&-O=6QD(&)E(&UO=F5D(&1O=VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&UO=F5$;W=N0F5L;W<H)')O=RD*("`@('L*("`@("`@
M("`D;6]V960@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)'D@/2!C;W5N="@D
M=&AI<RT^7VQA>6]U="D@+2`Q.R`D>2`^("1R;W<[("1Y+2TI('L*("`@("`@
M("`@("`@9F]R("@D>"`](#`[("1X(#P@)'1H:7,M/E]C;VQU;6YS.R`D>"LK
M*2!["B`@("`@("`@("`@("`@("`D8FQO8VL@/2`D=&AI<RT^9V5T0FQO8VM!
M="@D>2P@)'@I.PH@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1B;&]C:RDI
M('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D;6]V961;)&)L;V-K
M6S%=("X@)SHG("X@)&)L;V-K6S!=72DI('L*("`@("`@("`@("`@("`@("`@
M("`D;6]V961;)&)L;V-K6S%=("X@)SHG("X@)&)L;V-K6S!=72`]('1R=64[
M"B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YM;W9E1&]W
M;B@D8FQO8VM;,%TL("1B;&]C:ULQ72D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M36]V97,@82!B;&]C:R!O;F4@8V]L=6UN(&QE9G0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!M;W9E3&5F="@D<F]W+"`D8V]L*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^8V]L17AI<W1S*"1C;VP@+2`Q*2D@>PH@("`@("`@("`@
M("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@
M("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O;2!T;R!M;W9E(&EN=&\N
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI
M('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH)')O=R`K
M("1I+"`D8V]L("T@,2DI('L*("`@("`@("`@("`@("`@("`@("`D:6Y?=V%Y
M(#T@)'1H:7,M/F=E=$)L;V-K070H)')O=R`K("1I+"`D8V]L("T@,2D["B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1I;E]W87DI("8F"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I;E]W87E;,%T@/3T@)')O=R`F)@H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1I;E]W
M87E;,%TL("1I;E]W87E;,5TI(#T]("1H96EG:'0I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@5V4@;F5E9"!T;R!S=V%P('1H92!B;&]C:W,N"B`@
M("`@("`@("`@("`@("`@("`@("`@("1R96,Q(#T@2&]R9&5?07)R87DZ.F=E
M=%)E8W1A;F=L92@D=&AI<RT^7VQA>6]U="P@)')O=RP@)&-O;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"DL("1T:&ES+3YG
M9717:61T:"@D<F]W+"`D8V]L*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R96,R(#T@2&]R9&5?07)R87DZ.F=E=%)E8W1A;F=L92@D=&AI<RT^7VQA
M>6]U="P@)&EN7W=A>5LP72P@)&EN7W=A>5LQ72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG971(96EG:'0H)&EN7W=A>5LP72P@)&EN7W=A>5LQ72DL("1T:&ES
M+3YG9717:61T:"@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=*2D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,Q
M*3L@)&HK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D
M:R`](#`[("1K(#P@8V]U;G0H)')E8S%;)&I=*3L@)&LK*RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1I;E]W
M87E;,%T@*R`D:EU;)&EN7W=A>5LQ72`K("1K72`]("1R96,Q6R1J75LD:UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:B`]
M(#`[("1J(#P@8V]U;G0H)')E8S(I.R`D:BLK*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W(@*"1K(#T@,#L@)&L@/"!C;W5N="@D<F5C,ELD
M:ETI.R`D:RLK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)&EN7W=A>5LP72`K("1J75LD:6Y?=V%Y6S%=("L@
M8V]U;G0H)')E8S%;)&I=*2`K("1K72`]("1R96,R6R1J75LD:UT["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D
M7W)O=R`]("1I;E]W87E;,%T["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9%]C;VP@/2`D:6Y?=V%Y6S%=.PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("\O($YO('=H97)E('1O(&=O"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4VAR:6YK(&]R
M(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T:&4@=V%Y(&9I
M<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1L87-T8V]L(#T@)&-O;"`K("1T
M:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@
M("`@("1P<F5V(#T@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L73L*
M("`@("`@("`@("`@("`@("\O($UO=F4@;&5F="!H86YD(&5D9V4*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:5U;)&-O;"`M(#%=
M(#T@)'!R978["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@)&E=6R1C;VQ=(#T@)V-O=F5R960G.PH@("`@("`@("`@("`@("`@+R\@
M36]V92!R:6=H="!H86YD(&5D9V4*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W<@*R`D:5U;)&QA<W1C;VQ=(#T@)V5M<'1Y)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]L17AI<W1S*"1L
M87-T8V]L("L@,2DI('L*("`@("`@("`@("`@("`@("\O(%=A<R!O;B!T:&4@
M<FEG:'0M;6]S="!C;VQU;6X*("`@("`@("`@("`@("`@("1T:&ES+3YR96UO
M=F5#;VQ)9D5M<'1Y*"1L87-T8V]L*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R;W<["B`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L("T@,3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&)L;V-K(&]N92!C;VQU;6X@
M<FEG:'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L
M87EO=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO
M=70@8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!M;W9E4FEG:'0H)')O
M=RP@)&-O;"D*("`@('L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E=$AE
M:6=H="@D<F]W+"`D8V]L*3L*("`@("`@("`D;&%S=&-O;"`]("1C;VP@*R`D
M=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"D["B`@("`@("`@:68@*"1T:&ES
M+3YC;VQ%>&ES=',H)&QA<W1C;VPI*2!["B`@("`@("`@("`@("\O(%-E92!I
M9B!T:&5R92=S(')O;VT@=&\@;6]V92!I;G1O+@H@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("`@
M("!I9B`H(21T:&ES+3YI<T5M<'1Y*"1R;W<@*R`D:2P@)&QA<W1C;VPI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&EN7W=A>2`]("1T:&ES+3YG971";&]C
M:T%T*"1R;W<@*R`D:2P@)&QA<W1C;VPI.PH@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-?;G5L;"@D:6Y?=V%Y*2`F)@H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6Y?=V%Y6S!=(#T]("1R;W<@)B8*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F=E=$AE:6=H="@D:6Y?=V%Y6S!=+"`D:6Y?=V%Y6S%=
M*2`]/2`D:&5I9VAT*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E
M(&YE960@=&\@<W=A<"!T:&4@8FQO8VMS+@H@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5C,2`]($AO<F1E7T%R<F%Y.CIG971296-T86YG;&4H)'1H:7,M
M/E]L87EO=70L("1R;W<L("1C;VPL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T
M2&5I9VAT*"1R;W<L("1C;VPI+"`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O
M;"DI.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5C,B`]($AO<F1E7T%R
M<F%Y.CIG971296-T86YG;&4H)'1H:7,M/E]L87EO=70L("1I;E]W87E;,%TL
M("1I;E]W87E;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T2&5I9VAT*"1I
M;E]W87E;,%TL("1I;E]W87E;,5TI+"`D=&AI<RT^9V5T5VED=&@H)&EN7W=A
M>5LP72P@)&EN7W=A>5LQ72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!F
M;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D<F5C,BD[("1J*RLI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&L@/2`P.R`D:R`\(&-O=6YT
M*"1R96,R6R1J72D[("1K*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&I=6R1C;VP@*R`D:UT@
M/2`D<F5C,ELD:EU;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\(&-O=6YT*"1R96,Q*3L@)&HK*RD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R("@D:R`](#`[("1K
M(#P@8V]U;G0H)')E8S%;)&I=*3L@)&LK*RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`D:EU;)&-O
M;"`K(&-O=6YT*"1R96,R6R1J72D@*R`D:UT@/2`D<F5C,5LD:EU;)&M=.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9%]R;W<@/2`D:6Y?=V%Y6S!=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&EN7W=A>5LQ73L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`O+R!.;R!W:&5R92!T;R!G;PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN
M:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A
M>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+R\@36%K92!R;V]M('1O(&UO=F4@:6YT;RX*("`@("`@("`@("`@)'1H:7,M
M/F%D9$-O;"@D;&%S=&-O;"D["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@("`@("`@("`@("1P<F5V
M(#T@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L73L*("`@("`@("`@
M("`@+R\@36]V92!R:6=H="!H86YD(&5D9V4*("`@("`@("`@("`@)'1H:7,M
M/E]L87EO=71;)')O=R`K("1I75LD;&%S=&-O;%T@/2`G8V]V97)E9"<["B`@
M("`@("`@("`@("\O($UO=F4@;&5F="!H86YD(&5D9V4*("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L("L@,5T@/2`D<')E=CL*
M("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD8V]L72`]
M("=E;7!T>2<["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?
M<F]W(#T@)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O
M;"`K(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A;&P@8FQO8VMS
M(&%F=&5R(&$@8V5R=&%I;B!C;VQU;6X@;VYE(&-O;'5M;B!R:6=H="X*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C;VQU
M;6XN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&%L
M;"!C;VQU;6YS(&-O=6QD(&)E(&UO=F5D(')I9VAT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!M;W9E4FEG:'1!9G1E<B@D8V]L*0H@("`@>PH@("`@("`@("1M
M;W9E9"`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D>"`]("1T:&ES+3Y?8V]L
M=6UN<R`M(#$[("1X(#X@)&-O;#L@)'@M+2D@>PH@("`@("`@("`@("!F;W(@
M*"1Y(#T@,#L@)'D@/"!C;W5N="@D=&AI<RT^7VQA>6]U="D[("1Y*RLI('L*
M("`@("`@("`@("`@("`@("1B;&]C:R`]("1T:&ES+3YG971";&]C:T%T*"1Y
M+"`D>"D["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)&)L;V-K*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M;W9E9%LD8FQO8VM;,5T@
M+B`G.B<@+B`D8FQO8VM;,%U=*2D@>PH@("`@("`@("`@("`@("`@("`@("1M
M;W9E9%LD8FQO8VM;,5T@+B`G.B<@+B`D8FQO8VM;,%U=(#T@=')U93L*("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/FUO=F52:6=H="@D
M8FQO8VM;,%TL("1B;&]C:ULQ72D["B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@36%K
M97,@82!B;&]C:R!O;F4@<F]W('1A;&QE<B!B>2!M;W9I;F<@=&AE('1O<"!U
M<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&%N9%5P*"1R;W<L("1C
M;VPI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YR;W=%>&ES=',H)')O=R`M
M(#$I*2!["B`@("`@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D
M<F]W+"`D8V]L*3L*("`@("`@("`@("`@+R\@4V5E(&EF('1H97)E)W,@<F]O
M;2!T;R!E>'!A;F0@:6YT;PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M
M/FES16UP='DH)')O=R`M(#$L("1C;VP@*R`D:2DI('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(21T:&ES+3YM;W9E1&]W;D)E;&]W*"1R;W<@+2`Q*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")3:')I;FL@;W(@;6]V92!N96EG:&)O=7)I;F<@8FQO8VLH<RD@
M;W5T(&]F('1H92!W87D@9FER<W0B*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<F]W*RL["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;&%Y;W5T6R1R;W<@+2`Q75LD8V]L("L@)&E=(#T@)'1H:7,M/E]L87EO
M=71;)')O=UU;)&-O;"`K("1I73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G8V]V97)E9"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=R`M(#%=6R1C
M;VQ=6R=H96EG:'0G72`]("1T:&ES+3YG971(96EG:'0H)')O=R`M(#$L("1C
M;VPI("L@,3L*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D
M<F]W("T@,3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C
M;VP["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!B
M;&]C:R!O;F4@<F]W('1A;&QE<B!B>2!M;W9I;F<@=&AE(&)O='1O;2!D;W=N
M+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W<@($$@;&%Y;W5T
M(')O=RX*("`@("`J($!P87)A;2!I;G1E9V5R("1C;VP@($$@;&%Y;W5T(&-O
M;'5M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@97AP86YD1&]W;B@D<F]W+"`D
M8V]L*0H@("`@>PH@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D
M<F]W+"`D8V]L*3L*("`@("`@("`D;&%S=')O=R`]("1R;W<@*R`D=&AI<RT^
M9V5T2&5I9VAT*"1R;W<L("1C;VPI("T@,3L*("`@("`@("!I9B`H(21T:&ES
M+3YR;W=%>&ES=',H)&QA<W1R;W<@*R`Q*2D@>PH@("`@("`@("`@("`O+R!!
M9&0@82!N97<@<F]W+@H@("`@("`@("`@("`D=&AI<RT^861D4F]W*"1L87-T
M<F]W("L@,2D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1W:61T
M:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)&QA
M<W1R;W<@*R`Q75LD8V]L("L@)&E=(#T@)V-O=F5R960G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VQ=6R=H
M96EG:'0G72`]("1T:&ES+3YG971(96EG:'0H)')O=RP@)&-O;"D@*R`Q.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%-E92!I9B!T:&5R92=S
M(')O;VT@=&\@97AP86YD(&EN=&\*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H(21T
M:&ES+3YI<T5M<'1Y*"1L87-T<F]W("L@,2P@)&-O;"`K("1I*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FUO=F5$;W=N0F5L;W<H)&QA
M<W1R;W<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE:6=H8F]U<FEN9R!B
M;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G:&]R9&4N=V%R;FEN
M9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)'=I9'1H.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U
M=%LD;&%S=')O=R`K(#%=6R1C;VP@*R`D:5T@/2`G8V]V97)E9"<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O
M;%U;)VAE:6=H="==(#T@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`K
M(#$["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@
M)')O=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@
M('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(&-O;'5M;B!W
M:61E<B!B>2!M;W9I;F<@=&AE(&QE9G0@<VED92!O=70N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>'!A;F1,969T*"1R;W<L("1C;VPI"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3YC;VQ%>&ES=',H)&-O;"`M(#$I*2!["B`@("`@
M("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI
M.PH@("`@("`@("`@("`O+R!3964@:68@=&AE<F4G<R!R;V]M('1O(&5X<&%N
M9"!I;G1O"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[
M("1I*RLI('L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES16UP='DH
M)')O=R`K("1I+"`D8V]L("T@,2DI('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H(21T:&ES+3YM;W9E4FEG:'1!9G1E<B@D8V]L("T@,2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M4VAR:6YK(&]R(&UO=F4@;F5I9VAB;W5R:6YG(&)L;V-K*',I(&]U="!O9B!T
M:&4@=V%Y(&9I<G-T(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;"LK.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO
M=71;)')O=R`K("1I75LD8V]L("T@,5T@/2`D=&AI<RT^7VQA>6]U=%LD<F]W
M("L@)&E=6R1C;VQ=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;
M)')O=R`K("1I75LD8V]L72`]("=C;W9E<F5D)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L("T@,5U;)W=I
M9'1H)UT@/2`D=&AI<RT^9V5T5VED=&@H)')O=RP@)&-O;"`M(#$I("L@,3L*
M"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]R;W<@/2`D<F]W.PH@("`@
M("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;"`M(#$["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@36%K97,@82!B;&]C:R!O;F4@
M8V]L=6UN('=I9&5R(&)Y(&UO=FEN9R!T:&4@<FEG:'0@<VED92!O=70N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO=70@<F]W
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@8V]L=6UN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F12:6=H="@D<F]W+"`D8V]L
M*0H@("`@>PH@("`@("`@("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R
M;W<L("1C;VPI.PH@("`@("`@("1L87-T8V]L(#T@)&-O;"`K("1T:&ES+3YG
M9717:61T:"@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@:68@*"1T:&ES+3YC
M;VQ%>&ES=',H)&QA<W1C;VP@*R`Q*2D@>PH@("`@("`@("`@("`O+R!3964@
M:68@=&AE<F4G<R!R;V]M('1O(&5X<&%N9"!I;G1O"B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1H96EG:'0[("1I*RLI('L*("`@("`@("`@("`@
M("`@(&EF("@A)'1H:7,M/FES16UP='DH)')O=R`K("1I+"`D;&%S=&-O;"`K
M(#$I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^;6]V95)I
M9VAT069T97(H)&QA<W1C;VPI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E-H<FEN:R!O<B!M;W9E(&YE
M:6=H8F]U<FEN9R!B;&]C:RAS*2!O=70@;V8@=&AE('=A>2!F:7)S="(I+"`G
M:&]R9&4N=V%R;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]L87EO=71;)')O=R`K("1I75LD;&%S=&-O;"`K(#%=(#T@)V-O
M=F5R960G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y
M;W5T6R1R;W==6R1C;VQ=6R=W:61T:"==(#T@)'1H:7,M/F=E=%=I9'1H*"1R
M;W<L("1C;VPI("L@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!!9&0@;F5W(&-O;'5M;@H@("`@("`@("`@("`D=&AI<RT^861D0V]L*"1L
M87-T8V]L("L@,2D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1H
M96EG:'0[("1I*RLI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`D:5U;)&QA<W1C;VP@*R`Q72`]("=C;W9E<F5D)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W75LD8V]L
M75LG=VED=&@G72`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`K(#$[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O
M=SL*("`@("`@("`D=&AI<RT^7V-H86YG961?8V]L(#T@)&-O;#L*("`@('T*
M"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@;VYE(')O=R!L;W=E<B!B
M>2!M;W9I;F<@=&AE('1O<"!D;W=N+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1R;W<@($$@;&%Y;W5T(')O=RX*("`@("`J($!P87)A;2!I;G1E
M9V5R("1C;VP@($$@;&%Y;W5T(&-O;'5M;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VAR:6YK57`H)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`^(#$I('L*("`@("`@("`@("`@
M)'=I9'1H(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VPI.PH@("`@("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=VED=&@[("1I*RLI('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W<@*R`Q75LD8V]L("L@)&E=
M(#T@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K("1I73L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&%Y;W5T6R1R;W==6R1C;VP@*R`D:5T@/2`G96UP
M='DG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T
M6R1R;W<@*R`Q75LD8V]L75LG:&5I9VAT)UT@/2`D=&AI<RT^9V5T2&5I9VAT
M*"1R;W<@*R`Q+"`D8V]L*2`M(#$["@H@("`@("`@("`@("`D=&AI<RT^7V-H
M86YG961?<F]W(#T@)')O=R`K(#$["B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9%]C;VP@/2`D8V]L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($UA:V5S(&$@8FQO8VL@;VYE(')O=R!L;W=E<B!B>2!M;W9I;F<@=&AE
M(&)O='1O;2!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W
M("!!(&QA>6]U="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!
M(&QA>6]U="!C;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H<FEN:T1O
M=VXH)')O=RP@)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E=$AE
M:6=H="@D<F]W+"`D8V]L*2`^(#$I('L*("`@("`@("`@("`@)&QA<W1R;W<@
M/2`D<F]W("L@)'1H:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`M(#$["B`@
M("`@("`@("`@("1W:61T:"`]("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L
M*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'=I9'1H.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD;&%S=')O=UU;
M)&-O;"`K("1I72`]("=E;7!T>2<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)VAE:6=H="==(#T@)'1H
M:7,M/F=E=$AE:6=H="@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@(&EF
M("@A)'1H:7,M/G)O=T5X:7-T<R@D;&%S=')O=R`K(#$I*2!["B`@("`@("`@
M("`@("`@("`O+R!787,@;VX@=&AE(&)O='1O;2!R;W<*("`@("`@("`@("`@
M("`@("1T:&ES+3YR96UO=F52;W=)9D5M<'1Y*"1L87-T<F]W*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7W)O=R`]("1R
M;W<["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9%]C;VP@/2`D8V]L.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@
M;VYE(&-O;'5M;B!N87)R;W=E<B!B>2!M;W9I;F<@=&AE(&QE9G0@<VED92!I
M;BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]W("!!(&QA>6]U
M="!R;W<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8V]L("!!(&QA>6]U="!C
M;VQU;6XN"B`@("`@*B\*("`@(&9U;F-T:6]N('-H<FEN:TQE9G0H)')O=RP@
M)&-O;"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F=E=%=I9'1H*"1R;W<L
M("1C;VPI(#X@,2D@>PH@("`@("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/F=E
M=$AE:6=H="@D<F]W+"`D8V]L*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&AE:6=H=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]L87EO=71;)')O=R`K("1I75LD8V]L("L@,5T@/2`D=&AI<RT^7VQA>6]U
M=%LD<F]W("L@)&E=6R1C;VQ=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]L
M87EO=71;)')O=R`K("1I75LD8V]L72`]("=E;7!T>2<["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]L87EO=71;)')O=UU;)&-O;"`K(#%=
M6R=W:61T:"==(#T@)'1H:7,M/F=E=%=I9'1H*"1R;W<L("1C;VP@*R`Q*2`M
M(#$["@H@("`@("`@("`@("`D=&AI<RT^7V-H86YG961?<F]W(#T@)')O=SL*
M("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D7V-O;"`]("1C;VP@*R`Q.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UA:V5S(&$@8FQO8VL@
M;VYE(&-O;'5M;B!N87)R;W=E<B!B>2!M;W9I;F<@=&AE(')I9VAT('-I9&4@
M:6XN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)')O=R`@02!L87EO
M=70@<F]W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-O;"`@02!L87EO=70@
M8V]L=6UN+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:')I;FM2:6=H="@D<F]W
M+"`D8V]L*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T5VED=&@H)')O
M=RP@)&-O;"D@/B`Q*2!["B`@("`@("`@("`@("1L87-T8V]L(#T@)&-O;"`K
M("1T:&ES+3YG9717:61T:"@D<F]W+"`D8V]L*2`M(#$["B`@("`@("`@("`@
M("1H96EG:'0@/2`D=&AI<RT^9V5T2&5I9VAT*"1R;W<L("1C;VPI.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:&5I9VAT.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VQA>6]U=%LD<F]W("L@)&E=6R1L87-T
M8V]L72`]("=E;7!T>2<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/E]L87EO=71;)')O=UU;)&-O;%U;)W=I9'1H)UT@/2`D=&AI<RT^9V5T
M5VED=&@H)')O=RP@)&-O;"D@+2`Q.PH@("`@("`@("`@("`D=&AI<RT^<F5M
M;W9E0V]L269%;7!T>2@D;&%S=&-O;"D["@H@("`@("`@("`@("`D=&AI<RT^
M7V-H86YG961?<F]W(#T@)')O=SL*("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D7V-O;"`]("1C;VP["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V%C:&4O9FEL92YP
M:'``````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,30Q-3<@
M,3`U,34T,S0Q-#`@,#(R,#`R`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V%C:&5?
M9FEL93HZ(&-L87-S('!R;W9I9&5S(&$@9FEL97-Y<W1E;2!I;7!L96UE;G1A
M=&EO;B!O9B!T:&4*("H@2&]R9&4@8V%C:&EN9R!S>7-T96TN"B`J"B`J($]P
M=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G9&ER)R`@("`@5&AE(&1I
M<F5C=&]R>2!T;R!S=&]R92!T:&4@8V%C:&4@9FEL97,@:6XN"B`J("`@)W!R
M969I>"<@(%1H92!F:6QE;F%M92!P<F5F:7@@=&\@=7-E(&9O<B!T:&4@8V%C
M:&4@9FEL97,N/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-A8VAE
M+T-A8VAE+V9I;&4N<&AP+'8@,2XR."XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-
M861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#$Y
M.3DM,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A
M8VMA9V4@2&]R9&5?0V%C:&4*("HO"F-L87-S($AO<F1E7T-A8VAE7V9I;&4@
M97AT96YD<R!(;W)D95]#86-H92!["@H@("`@+RHJ"B`@("`@*B!4:&4@;&]C
M871I;VX@;V8@=&AE('1E;7`@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1I<CL*"B`@("`O*BH*("`@
M("`J(%1H92!F:6QE;F%M92!P<F5F:7@@9F]R(&-A8VAE(&9I;&5S+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R969I
M>"`]("=C86-H95\G.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T(&$@;F5W
M($AO<F1E7T-A8VAE7V9I;&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!087)A;65T97(@87)R87DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7T-A8VAE7V9I;&4H)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=D:7(G72D@)B8@
M0&ES7V1I<B@D<&%R86US6R=D:7(G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]D:7(@/2`D<&%R86US6R=D:7(G73L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5T:6PN<&AP)SL*("`@("`@
M("`@("`@)'1H:7,M/E]D:7(@/2!5=&EL.CIG971496UP1&ER*"D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<')E9FEX)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<')E9FEX(#T@)'!A<F%M<ULG<')E9FEX
M)UT["B`@("`@("`@?0H*("`@("`@("!P87)E;G0Z.DAO<F1E7T-A8VAE*"1P
M87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T
M<FEE=F4@8V%C:&5D(&1A=&$@9G)O;2!T:&4@9FEL97-Y<W1E;2!A;F0@<F5T
M=7)N(&ET('1O"B`@("`@*B!T:&4@8V%L;&5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O(&9E=&-H+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM92!O9B!T
M:&4@9&%T82!I;B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($-A8VAE9"!D871A+"!O<B!F86QS92!I9B!N;VYE('=A<R!F;W5N9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T*"1K97DL("1L:69E=&EM92`](#$I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)&ME>2P@)&QI9F5T
M:6UE*2D@>PH@("`@("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7VME>51O
M1FEL92@D:V5Y*3L*("`@("`@("`@("`@)'-I>F4@/2!F:6QE<VEZ92@D9FEL
M96YA;64I.PH@("`@("`@("`@("!I9B`H(21S:7IE*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1A
M=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PH@("`@("`@("`@
M("!I9B`H)&1A=&$@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&1A=&$["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M($YO=&AI;F<@8V%C:&5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!S=&]R92!D871A('1O('1H92!F:6QE<WES=&5M+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&ME>2`@($-A8VAE(&ME>2X*("`@("`J($!P87)A
M;2!M:7AE9"`@)&1A=&$@($1A=&$@=&\@<W1O<F4@:6X@=&AE(&-A8VAE+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S
M+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!S970H
M)&ME>2P@)&1A=&$I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D
M92]5=&EL+G!H<"<["B`@("`@("`@)&9I;&5N86UE(#T@)'1H:7,M/E]K97E4
M;T9I;&4H)&ME>2D["B`@("`@("`@)'1M<%]F:6QE(#T@571I;#HZ9V5T5&5M
M<$9I;&4H)TAO<F1E0V%C:&4G+"!T<G5E+"`D=&AI<RT^7V1I<BD["@H@("`@
M("`@(&EF("@D9F0@/2!F;W!E;B@D=&UP7V9I;&4L("=W)RDI('L*("`@("`@
M("`@("`@:68@*&9W<FET92@D9F0L("1D871A*2`\('-T<FQE;B@D9&%T82DI
M('L*("`@("`@("`@("`@("`@(&9C;&]S92@D9F0I.PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@9F-L;W-E*"1F9"D["B`@("`@("`@("`@("`@("!`<F5N86UE
M*"1T;7!?9FEL92P@)&9I;&5N86UE*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&1I<F5C=&QY
M(&]U='!U="!C86-H960@9&%T82!F<F]M('1H92!F:6QE<WES=&5M+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y
M('1O(&]U='!U="X*("`@("`J($!P87)A;2!I;G1E9V5R("1L:69E=&EM92`@
M3&EF971I;64@;V8@=&AE(&1A=&$@:6X@<V5C;VYD<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!#86-H960@9&%T82P@;W(@9F%L<V4@:68@;F]N
M92!W87,@9F]U;F0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D:V5Y
M+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^97AI
M<W1S*"1K97DL("1L:69E=&EM92DI('L*("`@("`@("`@("`@)&9I;&5N86UE
M(#T@)'1H:7,M/E]K97E4;T9I;&4H)&ME>2D["B`@("`@("`@("`@("1F9"`]
M($!F;W!E;B@D9FEL96YA;64L("=R)RD["B`@("`@("`@("`@(&EF("@D9F0I
M('L*("`@("`@("`@("`@("`@(&9P87-S=&AR=2@D9F0I.PH@("`@("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($YO=&AI;F<@8V%C:&5D+"!R971U<FX@9F%I;'5R92X@*B\*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M:&5C:W,@:68@82!G:79E;B!K97D@97AI<W1S(&EN('1H92!C86-H92P@=F%L
M:60@9F]R('1H92!G:79E;@H@("`@("H@;&EF971I;64N($EF(&ET(&5X:7-T
M<R!B=70@:7,@97AP:7)E9"P@9&5L971E('1H92!F:6QE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O(&-H
M96-K+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E=&EM
M92!O9B!T:&4@:V5Y(&EN('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!%>&ES=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X
M:7-T<R@D:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@("1F:6QE
M;F%M92`]("1T:&ES+3Y?:V5Y5&]&:6QE*"1K97DI.PH*("`@("`@("`O*B!+
M97D@97AI<W1S(&EN('1H92!C86-H92`J+PH@("`@("`@(&EF("AF:6QE7V5X
M:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@("`@("\J(#`@;65A;G,@;F\@
M97AP:7)E+B`J+PH@("`@("`@("`@("!I9B`H)&QI9F5T:6UE(#T](#`I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!)9B!T:&4@9FEL92!W87,@8F5E;B!C<F5A=&5D(&%F
M=&5R('1H92!S=7!P;&EE9"!V86QU92P*("`@("`@("`@("`@("H@=&AE(&1A
M=&$@:7,@=F%L:60@*&9R97-H*2X@*B\*("`@("`@("`@("`@:68@*'1I;64H
M*2`M("1L:69E=&EM92`\/2!F:6QE;71I;64H)&9I;&5N86UE*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!`=6YL:6YK*"1F:6QE;F%M92D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J($5X<&ER92!A;GD@97AI<W1I;F<@9&%T82!F;W(@
M=&AE(&=I=F5N(&ME>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K
M97D@($-A8VAE(&ME>2!T;R!E>'!I<F4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5X<&ER92@D:V5Y*0H@("`@>PH@("`@("`@("1F:6QE;F%M92`]
M("1T:&ES+3Y?:V5Y5&]&:6QE*"1K97DI.PH@("`@("`@(')E='5R;B!`=6YL
M:6YK*"1F:6QE;F%M92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-87`@82!C
M86-H92!K97D@=&\@82!U;FEQ=64@9FEL96YA;64N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:V5Y("!#86-H92!K97DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($9U;&QY('%U86QI9FEE9"!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7VME>51O1FEL92@D:V5Y*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1I<B`N("<O)R`N("1T:&ES+3Y?<')E9FEX("X@;60U*"1K97DI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&\@86YY(&=A<F)A9V4@8V]L;&5C=&EO
M;B!N965D960@9F]R('1H92!D<FEV97(N"B`@("`@*@H@("`@("H@0'!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<V5C<R`@5&AE(&UI
M;FEM=6T@86UO=6YT(&]F('1I;64@*&EN('-E8V]N9',I(')E<75I<F5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@8F5F;W)E(&$@8V%C:&4@:71E
M;2!I<R!R96UO=F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&]'0R@D<V5C
M<RD*("`@('L*("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7V1I<B`N("<O
M:&]R9&5?8V%C:&5?9V,G.PH@("`@("`@("1G8U]T:6UE(#T@=&EM92@I("T@
M)'-E8W,["B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('L*
M("`@("`@("`@("`@)&]L9%]T:6UE(#T@9FEL95]G971?8V]N=&5N=',H)&9I
M;&5N86UE*3L*("`@("`@("`@("`@:68@*"@D;VQD7W1I;64@(3T](&9A;'-E
M*2`F)@H@("`@("`@("`@("`@("`@*"1G8U]T:6UE(#X@)&]L9%]T:6UE*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D9"`](&1I<B@D=&AI<RT^7V1I<BD["B`@("`@("`@
M=VAI;&4@*"@D96YT<GD@/2`D9"T^<F5A9"@I*2`A/3T@9F%L<V4I('L*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D96YT<GDL("1T:&ES+3Y?<')E9FEX*2`]
M/3T@,"D@>PH@("`@("`@("`@("`@("`@)&UT:6UE(#T@9FEL96UT:6UE*"1T
M:&ES+3Y?9&ER("X@)R\G("X@)&5N=')Y*3L*("`@("`@("`@("`@("`@(&EF
M("@D9V-?=&EM92`^("1M=&EM92D@>PH@("`@("`@("`@("`@("`@("`@($!U
M;FQI;FLH)'1H:7,M/E]D:7(@+B`G+R<@+B`D96YT<GDI.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D+3YC
M;&]S92@I.PH@"B`@("`@("`@)&9P(#T@9F]P96XH)&9I;&5N86UE+"`G=R<I
M.PH@("`@("`@(&9W<FET92@D9G`L('1I;64H*2D["B`@("`@("`@9F-L;W-E
M*"1F<"D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T-A8VAE+WIP<S0N<&AP````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`T-#<R(#$P-3$U-#,T,30P(#`R,3<V,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($AO<F1E7T-A8VAE7WIP<S0Z.B!C;&%S<R!P<F]V:61E<R!A(%IE;F0@4&5R
M9F]R;6%N8V4@4W5I=&4*("H@*'9E<G-I;VX@-"XP*RD@:6UP;&5M96YT871I
M;VX@;V8@=&AE($AO<F1E(&-A8VAI;F<@<WES=&5M+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]#86-H92]#86-H92]Z<',T+G!H<"QV(#$N,2XQ,"XT(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T-A8VAE"B`J+PIC;&%S<R!(;W)D95]#86-H95]Z<',T(&5X
M=&5N9',@2&]R9&5?0V%C:&4@>PH*("`@("\J*@H@("`@("H@071T96UP=',@
M=&\@<F5T<FEE=F4@82!P:65C92!O9B!C86-H960@9&%T82!A;F0@<F5T=7)N
M(&ET('1O('1H92!C86QL97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&ME>2`@("`@("!#86-H92!K97D@=&\@9F5T8V@N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;&EF971I;64@($QI9F5T:6UE(&]F('1H92!K97D@:6X@
M<V5C;VYD<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!#86-H960@
M9&%T82P@;W(@9F%L<V4@:68@;F]N92!W87,@9F]U;F0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E="@D:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@
M("`@(')E='5R;B!O=71P=71?8V%C:&5?9V5T*"1K97DL("1L:69E=&EM92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!S=&]R92!A;B!O
M8FIE8W0@=&\@=&AE(&-A8VAE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ME>2`@($-A8VAE(&ME>2`H:61E;G1I9FEE<BDN"B`@("`@*B!`<&%R
M86T@;6EX960@("1D871A("!$871A('1O('-T;W)E(&EN('1H92!C86-H92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M*"1K97DL("1D871A*0H@("`@>PH@("`@("`@(&]U='!U=%]C86-H95]P=70H
M)&ME>2P@)&1A=&$I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@9&ER96-T;'D@;W5T<'5T(&-A8VAE
M9"!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1K97D@("`@
M("`@0V%C:&4@:V5Y('1O(&]U='!U="X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1L:69E=&EM92`@3&EF971I;64@;V8@=&AE(&ME>2!I;B!S96-O;F1S+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@($-A8VAE9"!D871A+"!O<B!F
M86QS92!I9B!N;VYE('=A<R!F;W5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;W5T<'5T*"1K97DL("1L:69E=&EM92`](#$I"B`@("!["B`@("`@("`@96-H
M;R`D=&AI<RT^9F5T8V@H)&ME>2P@)&QI9F5T:6UE*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-H96-K<R!I9B!A(&=I=F5N(&ME>2!E>&ES=',@:6X@=&AE
M(&-A8VAE+"!V86QI9"!F;W(@=&AE(&=I=F5N(&QI9F5T:6UE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@("1K97D@("`@("`@0V%C:&4@:V5Y('1O
M(&-H96-K+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QI9F5T:6UE("!,:69E
M=&EM92!O9B!T:&4@:V5Y(&EN('-E8V]N9',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!%>&ES=&%N8V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5X:7-T<R@D:V5Y+"`D;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@("1E
M>&ES=',@/2!O=71P=71?8V%C:&5?97AI<W1S*"1K97DL("1L:69E=&EM92D[
M"B`@("`@("`@;W5T<'5T7V-A8VAE7W-T;W`H*3L*("`@("`@("!R971U<FX@
M)&5X:7-T<SL*("`@('T*"B`@("`O*BH*("`@("`J($5X<&ER92!A;GD@97AI
M<W1I;F<@9&%T82!F;W(@=&AE(&=I=F5N(&ME>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1K97D@($-A8VAE(&ME>2!T;R!E>'!I<F4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N("!3=6-C97-S(&]R(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&ER92@D:V5Y*0H@("`@>PH@("`@
M("`@(')E='5R;B!O=71P=71?8V%C:&5?<F5M;W9E7VME>2@D:V5Y*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T5D:71O<B]H=&UL87)E82YP:'``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V-C,P(#$P-3$U-#,T,30P(#`R,S$P,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($5D:71O<E]H=&UL87)E83HZ(&-L87-S('!R;W9I9&5S
M(&%N(%=94TE764<@961I=&]R(&9O<B!U<V4*("H@:6X@=&AE($AO<F1E($9R
M86UE=V]R:RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO161I=&]R+T5D:71O
M<B]H=&UL87)E82YP:'`L=B`Q+C(T+C0N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$T
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($YU;F\@3&]U
M<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#X*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@3G5N;R!,;W5R96ER;R`\;G5N;T!C;RYS87!O+G!T
M/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?161I=&]R
M"B`J+PIC;&%S<R!(;W)D95]%9&ET;W)?:'1M;&%R96$@97AT96YD<R!(;W)D
M95]%9&ET;W(@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N($EN8VQU
M9&4@=&AE(&YE8V5S<V%R>2!J879A<V-R:7!T(&9I;&5S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!(;W)D95]%9&ET;W)?:'1M;&%R96$H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>2P@)&YO=&EF
M:6-A=&EO;BP@)'!R969S.PH*("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL
M92@G:'1M;&%R96$N:G,G+"`G:&]R9&4G*3L*("`@("`@("!(;W)D93HZ861D
M4V-R:7!T1FEL92@G+W-E<G9I8V5S+V5D:71O<B]H=&UL87)E82]H=&UL87)E
M82YJ<R<L("=H;W)D92<L('1R=64I.PH@("`@("`@("1S8W)I<'0@/2!(;W)D
M93HZ=7)L*%5T:6PZ.F%D9%!A<F%M971E<B@D<F5G:7-T<GDM/F=E="@G=V5B
M<F]O="<L("=H;W)D92<I("X@)R]S97)V:6-E<R]J879A<V-R:7!T+G!H<"<L
M("=A<'`G+"`G:&]R9&4G*2P@=')U92D["B`@("`@("`@)&IS(#T@)TA434Q!
M<F5A+FQO86138W)I<'0H(B<@+B!5=&EL.CIA9&1087)A;65T97(H)'-C<FEP
M="P@)V9I;&4G+"`@)VAT;6QA<F5A7VQA;F<N:G,G+"!F86QS92D@+B`G(BD[
M("<["@H@("`@("`@("1P;'5G:6YS(#T@)R<["B`@("`@("`@:68@*"1P<F5F
M<RT^9V5T5F%L=64H)W1A8FQE;W!E<F%T:6]N<R<I*2!["B`@("`@("`@("`@
M("1J<R`N/2`G2%1-3$%R96$N;&]A9%!L=6=I;B@B5&%B;&5/<&5R871I;VYS
M(BD[("<@+@H@("`@("`@("`@("`@("`@("`@)TA434Q!<F5A+FQO86138W)I
M<'0H(B<@+B!5=&EL.CIA9&1087)A;65T97(H)'-C<FEP="P@)V9I;&4G+"`@
M)VAT;6QA<F5A7W1A8FQE7VQA;F<N:G,G+"!F86QS92D@+B`G(BD[("<["B`@
M("`@("`@("`@("1P;'5G:6YS("X]("=E9&ET;W(N<F5G:7-T97)0;'5G:6XH
M5&%B;&5/<&5R871I;VYS*3L@)SL*("`@("`@("!]"B`@("`@("`@:68@*"1P
M<F5F<RT^9V5T5F%L=64H)V-O;G1E>'1M96YU)RDI('L*("`@("`@("`@("`@
M)&IS("X]("=(5$U,07)E82YL;V%D4&QU9VEN*")#;VYT97AT365N=2(I.R`G
M("X*("`@("`@("`@("`@("`@("`@("=(5$U,07)E82YL;V%D4V-R:7!T*"(G
M("X@571I;#HZ861D4&%R86UE=&5R*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL
M87)E85]C;VYT97AT7VQA;F<N:G,G+"!F86QS92D@+B`G(BD[("<["B`@("`@
M("`@("`@("1P;'5G:6YS("X]("=E9&ET;W(N<F5G:7-T97)0;'5G:6XH0V]N
M=&5X=$UE;G4I.R`G.PH@("`@("`@('T*("`@("`@("!I9B`H)'!R969S+3YG
M971686QU92@G;&ES='1Y<&4G*2D@>PH@("`@("`@("`@("`D:G,@+CT@)TA4
M34Q!<F5A+FQO8610;'5G:6XH(DQI<W14>7!E(BD[("<@+@H@("`@("`@("`@
M("`@("`@("`@)TA434Q!<F5A+FQO86138W)I<'0H(B<@+B!5=&EL.CIA9&10
M87)A;65T97(H)'-C<FEP="P@)V9I;&4G+"`@)VAT;6QA<F5A7VQI<W1T>7!E
M7VQA;F<N:G,G+"!F86QS92D@+B`G(BD[("<["B`@("`@("`@("`@("1P;'5G
M:6YS("X]("=E9&ET;W(N<F5G:7-T97)0;'5G:6XH3&ES=%1Y<&4I.R`G.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'!R969S+3YG971686QU92@G86YS96QI
M;6%G92<I("8F("1R96=I<W1R>2T^:&%S365T:&]D*"=I;6%G97,O;&ES=$=A
M;&QE<FEE<R<I*2!["B`@("`@("`@("`@("1J<R`N/2`G2%1-3$%R96$N;&]A
M9%!L=6=I;B@B06YS96Q);6%G92(I.R`G("X*("`@("`@("`@("`@("`@("`@
M("=(5$U,07)E82YL;V%D4V-R:7!T*"(G("X@571I;#HZ861D4&%R86UE=&5R
M*"1S8W)I<'0L("=F:6QE)RP@("=H=&UL87)E85]A;G-E;&EM86=E7VQA;F<N
M:G,G+"!F86QS92D@+B`G(BD[("<["B`@("`@("`@("`@("1P;'5G:6YS("X]
M("=E9&ET;W(N<F5G:7-T97)0;'5G:6XH06YS96Q);6%G92D[("<["B`@("`@
M("`@?0H*("`@("`@("`D:G,@+CT@)TA434Q!<F5A+F]N;&]A9"`](&9U;F-T
M:6]N*"D@>R`G("X*("`@("`@("`@("`@("`@)W9A<B!C;VYF:6<@/2!N97<@
M2%1-3$%R96$N0V]N9FEG*"D@.R<@+@H@("`@("`@("`@("`@("`G8V]N9FEG
M+F1E8G5G(#T@9F%L<V4[("<@+@H@("`@("`@("`@("`@("`G8V]N9FEG+FAI
M9&53;VUE0G5T=&]N<R@B('-H;W=H96QP("(I.R`G.PH@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R=C;VYF:6<G72DI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<ULG8V]N9FEG)UT@87,@)&-O;F9I9R`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@("1J<R`N/2`G8V]N9FEG+B<@+B`D8V]N9FEG("X@
M)R`]("(G("X@861D<VQA<VAE<R@D=F%L=64I("X@)R([)SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;)VED
M)UTI*2!["B`@("`@("`@("`@("1J<R`N/2`G=F%R('1E>'1A<F5A<R`](%MD
M;V-U;65N="YG971%;&5M96YT0GE)9"@B)R`N("1P87)A;7-;)VED)UT@+B`G
M(BE=.R`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1J<R`N/2`G
M=F%R('1E>'1A<F5A<R`](&1O8W5M96YT+F=E=$5L96UE;G1S0GE486=.86UE
M*")T97AT87)E82(I.R`G.PH@("`@("`@('T*("`@("`@("`D:G,@+CT@)V9O
M<B`H=F%R(&D@/2!T97AT87)E87,N;&5N9W1H("T@,3L@:2`^/2`P.R!I+2TI
M('L@)R`N"B`@("`@("`@("`@("`@("=V87(@961I=&]R(#T@;F5W($A434Q!
M<F5A*'1E>'1A<F5A<UMI72P@8V]N9FEG*3L@)R`N"B`@("`@("`@("`@("`@
M("1P;'5G:6YS("X*("`@("`@("`@("`@("`@)V5D:71O<BYG96YE<F%T92@I
M?7T[("<@+@H@("`@("`@("`@("`@("`G2%1-3$%R96$N:6YI="@I.R<["@H@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)&IS+"`G:F%V87-C<FEP="<I
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]"<F]W<V5R+VEM;V1E+G!H<```````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`S,3`W,B`Q,#4Q-30S-#$T,"`P,C(U-S,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!"<F]W<V5R7VEM;V1E.CH@8VQA<W,@97AT96YD<R!T
M:&4@0G)O=W-E<B!!4$D@8GD@<')O=FED:6YG"B`J('-P96-I9FEC(&EN9F]R
M;6%T:6]N(&%B;W5T($EM;V1E(&AA;F1S971S+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]"<F]W<V5R+T)R;W=S97(O:6UO9&4N<&AP+'8@,2XW+C$R+C4@
M,C`P-B\P,2\P,2`R,3HR.#HP.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#`M,C`P-B!-:6MA(%1U=7!O;&$*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?0G)O=W-E<@H@*B\*8VQA<W,@0G)O=W-E<E]I;6]D92!["@H@("`@+RHJ
M"B`@("`@*B!$979I8V4@9&%T82X@1G)O;2!H='1P.B\O=W=W+FYT=&1O8V]M
M;RYC;RYJ<"]I+W1A9R]S-2YH=&UL(S5?,0H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?9&%T82`](&%R<F%Y*`H@("`@("`@
M("=$,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]
M/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y,"P*("`@("`@("`@("`@)W1E>'1W
M:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A
M<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=&,C`Y:2<@/3X@87)R
M87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I
M9VAT)R`]/B`Y,2P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E
M>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@
M("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@
M("`@("`I+`H@("`@("`@("=.,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@
M("=I;6%G97=I9'1H)R`]/B`Q,#@L("=I;6%G96AE:6=H="<@/3X@.#(L"B`@
M("`@("`@("`@("=T97AT=VED=&@G(#T^(#DL("=T97AT:&5I9VAT)R`]/B`V
M+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@
M)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@
M("`@("`G4#(P.6DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T
M:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@.#<L"B`@("`@("`@("`@("=T
M97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@
M("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T
M<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4#(P.6ES
M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G
M:6UA9V5H96EG:'0G(#T^(#@W+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]
M/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]
M/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G
M:68G*0H@("`@("`@("DL"B`@("`@("`@)U(R,#EI)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^
M(#<R+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H
M="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@
M("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@
M("DL"B`@("`@("`@)T52,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@-S(L"B`@("`@
M("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@-BP*
M("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)TM/,C`Y:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H
M)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y-BP*("`@("`@("`@("`@)W1E
M>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^(#@L"B`@("`@("`@("`@
M("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=$,C$P:2<@/3X@
M87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E
M:&5I9VAT)R`]/B`Y,2P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@
M)W1E>'1H96EG:'0G(#T^(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V
M+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*
M("`@("`@("`I+`H@("`@("`@("=&,C$P:2<@/3X@87)R87DH"B`@("`@("`@
M("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Q,3,L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]
M/B`X+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@
M)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@
M("`@("`G3C(Q,&DG(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T
M:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$Q,RP*("`@("`@("`@("`@
M)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT)R`]/B`X+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T
M<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G4#(Q,&DG
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@.38L("=I
M;6%G96AE:6=H="<@/3X@.3$L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^
M(#@L("=T97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^
M(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I
M9B<I"B`@("`@("`@*2P*("`@("`@("`G2T\R,3!I)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^
M(#DV+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H
M="<@/3X@."P*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@
M("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL
M"B`@("`@("`@)U-/,C$P:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G
M97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@,3$S+`H@("`@("`@
M("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@
M("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O
M<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T0U
M,#%I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV
M+"`G:6UA9V5H96EG:'0G(#T^(#<R+`H@("`@("`@("`@("`G=&5X='=I9'1H
M)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`G8FQA8VLG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A
M<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=&-3`Q:2<@/3X@87)R
M87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3(L("=I;6%G96AE
M:6=H="<@/3X@.#0L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T
M97AT:&5I9VAT)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C
M:R<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G
M*0H@("`@("`@("DL"B`@("`@("`@)TXU,#%I)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM86=E:&5I9VAT)R`]/B`Q
M,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$P+"`G=&5X=&AE:6=H
M="<@/3XQ,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`G8FQA8VLG+`H@("`@
M("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@
M("`I+`H@("`@("`@("=0-3`Q:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Q,C`L"B`@("`@
M("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`X+`H@
M("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C:R<L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)T0U,#)I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G
M(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#DP+`H@("`@("`@("`@("`G=&5X
M='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@
M)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^
M(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T8U,#)I)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#DV+"`G:6UA9V5H
M96EG:'0G(#T^(#DQ+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G
M=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`R-38L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("DL"B`@("`@("`@)T8U,#)I="<@/3X@87)R87DH"B`@("`@("`@
M("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I9VAT)R`]/B`Y,2P*
M("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^
M(#<L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G
M:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@
M("`@("=.-3`R:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H
M)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@,3(X+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG:'0G(#T^(#$P+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@)VEM86=E9F]R
M;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G3C4P
M,FET)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q
M."P@)VEM86=E:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED
M=&@G(#T^(#$P+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C
M;VQO<B<@/3X@,C4V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A
M<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0-3`R:2<@/3X@87)R
M87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Y-BP@)VEM86=E:&5I
M9VAT:"<@/3X@,3$W+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G
M=&5X=&AE:6=H="<@/3X@."P*("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E
M>2<L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G
M*0H@("`@("`@("DL"B`@("`@("`@)TY--3`R:2<@/3X@87)R87DH"B`@("`@
M("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3$L("=I;6%G96AE:6=H="<@/3X@
M-S<L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT
M)R`]/B`V+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=B;&%C:R<L"B`@("`@
M("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@
M("DL"B`@("`@("`@)U-/-3`R:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I
M;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H="<@/3X@,3(P+`H@("`@
M("`@("`@("`G=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@."P*
M("`@("`@("`@("`@)V-O;&]R)R`]/B`G9W)E>2<L"B`@("`@("`@("`@("=I
M;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@
M("`@)U-/-3`R:7=M)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,3,L"B`@("`@("`@("`@
M("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@
M("`@("`G8V]L;W(G(#T^(#(U-BP*("`@("`@("`@("`@)VEM86=E9F]R;6%T
M<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@("`@("`G1C4P,VDG
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W:61T:"<@/3X@,3(P+"`G
M:6UA9V5H96EG:'0G(#T^(#$S,"P*("`@("`@("`@("`@)W1E>'1W:61T:"<@
M/3X@,3`L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R
M)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y
M*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)T8U,#-I4R<@/3X@87)R87DH
M"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,C`L("=I;6%G96AE:6=H
M="<@/3X@,3,P+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,BP@)W1E
M>'1H96EG:'0G(#T^(#$R+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#0P.38L
M"B`@("`@("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@
M("`@("`@("DL"B`@("`@("`@)U`U,#-I)R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)VEM86=E=VED=&@G(#T^(#$R,"P@)VEM86=E:&5I9VAT)R`]/B`Q,S`L
M"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^(#$R+"`G=&5X=&AE:6=H="<@
M/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@/3X@,C4V+`H@("`@("`@("`@
M("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@
M("`@("`@("=0-3`S:5,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6UA9V5W
M:61T:"<@/3X@,3(P+"`G:6UA9V5H96EG:'0G(#T^(#$S,"P*("`@("`@("`@
M("`@)W1E>'1W:61T:"<@/3X@,3(L("=T97AT:&5I9VAT)R`]/B`Q,"P*("`@
M("`@("`@("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O
M<FUA=',G(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)U-/
M-3`S:2<@/3X@87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q
M,C`L("=I;6%G96AE:6=H="<@/3X@,3$S+`H@("`@("`@("`@("`G=&5X='=I
M9'1H)R`]/B`X+C4L("=T97AT:&5I9VAT)R`]/B`W+`H@("`@("`@("`@("`G
M8V]L;W(G(#T^(#8U-3,V+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]
M/B!A<G)A>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=$-3`S:2<@/3X@
M87)R87DH"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,S(L("=I;6%G
M96AE:6=H="<@/3X@,3(V+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`X
M+"`G=&5X=&AE:6=H="<@/3X@-RP*("`@("`@("`@("`@)V-O;&]R)R`]/B`T
M,#DV+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF
M)RD*("`@("`@("`I+`H@("`@("`@("=.-3`S:2<@/3X@87)R87DH"B`@("`@
M("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE:6=H="<@/3X@
M,3(X+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E>'1H96EG
M:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^(#0P.38L"B`@("`@
M("`@("`@("=I;6%G969O<FUA=',G(#T^(&%R<F%Y*"=G:68G+"`G:G!G)RD*
M("`@("`@("`I+`H@("`@("`@("=.-3`S:5,G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G:6UA9V5W:61T:"<@/3X@,3$X+"`G:6UA9V5H96EG:'0G(#T^(#$R
M."P*("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@,3`L("=T97AT:&5I9VAT
M)R`]/B`Q,"P*("`@("`@("`@("`@)V-O;&]R)R`]/B`T,#DV+`H@("`@("`@
M("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A>2@G9VEF)RP@)VIP9R<I"B`@
M("`@("`@*2P*("`@("`@("`G3C8Y,6DG(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`G:6UA9V5W:61T:"<@/3X@.38L("=I;6%G96AE:6=H="<@/3X@-S(L"B`@
M("`@("`@("`@("=T97AT=VED=&@G(#T^(#@L("=T97AT:&5I9VAT)R`]/B`V
M+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y)RP*("`@("`@("`@("`@
M)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*2P*("`@
M("`@("`G4T@X,C%I)R`]/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED
M=&@G(#T^(#DV+"`G:6UA9V5H96EG:'0G(#T^(#<X+`H@("`@("`@("`@("`G
M=&5X='=I9'1H)R`]/B`X+"`G=&5X=&AE:6=H="<@/3X@-BP*("`@("`@("`@
M("`@)V-O;&]R)R`]/B`R-38L"B`@("`@("`@("`@("=I;6%G969O<FUA=',G
M(#T^(&%R<F%Y*"=G:68G*0H@("`@("`@("DL"B`@("`@("`@)TXX,C%I)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@)VEM86=E=VED=&@G(#T^(#$Q."P@)VEM
M86=E:&5I9VAT)R`]/B`Q,C@L"B`@("`@("`@("`@("=T97AT=VED=&@G(#T^
M(#$P+"`G=&5X=&AE:6=H="<@/3X@,3`L"B`@("`@("`@("`@("=C;VQO<B<@
M/3X@)V=R97DG+`H@("`@("`@("`@("`G:6UA9V5F;W)M871S)R`]/B!A<G)A
M>2@G9VEF)RD*("`@("`@("`I+`H@("`@("`@("=0.#(Q:2<@/3X@87)R87DH
M"B`@("`@("`@("`@("=I;6%G97=I9'1H)R`]/B`Q,3@L("=I;6%G96AE:6=H
M="<@/3X@,3(X+`H@("`@("`@("`@("`G=&5X='=I9'1H)R`]/B`Q,"P@)W1E
M>'1H96EG:'0G(#T^(#$P+`H@("`@("`@("`@("`G8V]L;W(G(#T^("=G<F5Y
M)RP*("`@("`@("`@("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I
M"B`@("`@("`@*2P*("`@("`@("`G<V%F92<@/3X@87)R87DH"B`@("`@("`@
M("`@("=I;6%G97=I9'1H)R`]/B`Y-"P@)VEM86=E:&5I9VAT)R`]/B`W,BP*
M("`@("`@("`@("`@)W1E>'1W:61T:"<@/3X@."P@)W1E>'1H96EG:'0G(#T^
M(#8L"B`@("`@("`@("`@("=C;VQO<B<@/3X@)V)L86-K)RP*("`@("`@("`@
M("`@)VEM86=E9F]R;6%T<R<@/3X@87)R87DH)V=I9B<I"B`@("`@("`@*0H@
M("`@*3L*"B`@("!V87(@)%]M86YU9F%C='5R97)L:7-T(#T@87)R87DH"B`@
M("`@("`@)T0G(#T^("=-:71S=6)I<VAI)RP*("`@("`@("`G4"<@/3X@)U!A
M;F%S;VYI8R`H36%T<W5S:&ET82DG+`H@("`@("`@("=.32<@/3X@)TYO:VEA
M)RP*("`@("`@("`G4T\G(#T^("=3;VYY)RP*("`@("`@("`G1B<@/3X@)T9U
M:FET<W4G+`H@("`@("`@("=.)R`]/B`G3F5C)RP*("`@("`@("`G4T@G(#T^
M("=3:&%R<"<L"B`@("`@("`@)T52)R`]/B`G17)I8W-S;VXG+`H@("`@("`@
M("=2)R`]/B`G2F%P86X@4F%D:6\G+`H@("`@("`@("=+3R<@/3X@)TMO:W5S
M86D@*$AI=&%C:&DI)PH@("`@*3L*"B`@("!V87(@)%]E>'1R82`](&%R<F%Y
M*`H@("`@("`@("=T)R`]/B`G5')A;G-P;W)T(&QA>65R)RP*("`@("`@("`G
M92<@/3X@)T5N9VQI<V@@;&%N9W5A9V4G+`H@("`@("`@("=S)R`]/B`G4V5C
M;VYD('9E<G-I;VXG"B`@("`I.PH*("`@('9A<B`D7W5S97)?86=E;G0["B`@
M("!V87(@)%]M;V1E;#L*("`@('9A<B`D7VUA;G5F86-T=7)E<CL*("`@('9A
M<B`D7VAT='!V97)S:6]N.PH@("`@=F%R("1?8V%C:&4@/2`U.PH*("`@("\J
M*@H@("`@("H@1&]E<R!N;W0@:&%N9&QE(&)O9W5S('5S97)?86=E;G1S(&]R
M(&UO<W0@;V8@=&AE(&]T:&5R(&5R<F]R"B`@("`@*B!S:71U871I;VX@<')O
M<&5R;'D@>65T+@H@("`@("H*("`@("`J($5X86UP;&4@=7-A9V4Z"B`@("`@
M*B`@("1U82`]("9N97<@0G)O=W-E<E]I;6]D92@D7U-%4E9%<ELG2%144%]5
M4T527T%'14Y4)UTI.PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN
M<'5T("!4:&4@=7-E<B!A9V5N="!T;R!M871C:"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@0G)O=W-E<E]I;6]D92@D:6YP=70I"B`@("!["B`@("`@("`@)%]E
M<G)O<B`](#`["B`@("`@("`@)'1E;7`@/2!E>'!L;V1E*"<O)RP@)&EN<'5T
M*3L*"B`@("`@("`@)'1H:7,M/E]U<V5R7V%G96YT(#T@)&EN<'5T.PH@("`@
M("`@("1T:&ES+3Y?:'1T<'9E<G-I;VX@/2`D=&5M<%LQ73L*("`@("`@("`D
M=&AI<RT^7VUO9&5L(#T@)'1E;7!;,ET["B`@("`@("`@:68@*"1T96UP6S-=
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&4@/2!S=6)S='(H)'1E;7!;
M,UTL(#$I.PH@("`@("`@('T*"B`@("`@("`@<')E9U]M871C:"@G+RA>6V$M
M>D$M6ETK*2A;,"TY72MI*2@N*BE<+S\H+BHI+R<L("1T:&ES+3Y?;6]D96PL
M("1M871C:&5S*3L*"B`@("`@("`@+R\@0%1/1$\Z($9I>"!S:71U871I;VX@
M;V8@=6YK;F]W;B!M86YU9F%C='5R97(N($EM<&QE;65N=`H@("`@("`@("\O
M(&5X=')A:6YF;R!P<F]P97)L>2X*("`@("`@("`D=&AI<RT^7VUA;G5F86-T
M=7)E<B`]("1T:&ES+3Y?;6%N=69A8W1U<F5R;&ES=%LD;6%T8VAE<ULQ75T[
M"B`@("`@("`@)'1H:7,M/E]E>'1R82`]("1M871C:&5S6S-=.PH*("`@("`@
M("!I9B`H(2@D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%TI*2!["B`@("`@
M("`@("`@("1?97)R;W(@/2!014%2.CIR86ES945R<F]R*"=5;FMN;W=N(%5S
M97(@06=E;G0G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%
M>&%M<&QE('5S86=E.@H@("`@("H@("1I;6%G961I;2`@("`]("1U82T^9V5T
M26UA9V5$:6UE;G-I;VYS*"D["B`@("`@*B`@)&EM86=E=VED=&@@(#T@)&EM
M86=E9&EM6S!=.PH@("`@("H@("1I;6%G96AE:6=H="`]("1I;6%G961I;5LQ
M73L*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;6%X:6UU;2!I
M;6%G97=I9'1H(&%N9"!I;6%G96AE:6=H="!T:&%T"B`@("`@*B`@("`@("`@
M("`@("`@("!F:70@;VX@=&AE(&AA;F1S970@<V-R965N('=I=&AO=70@<V-R
M;VQL:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971);6%G941I;65N<VEO
M;G,H*0H@("`@>PH@("`@("`@("1D871A(#T@)'1H:7,M/E]D871A6R1T:&ES
M+3Y?;6]D96Q=.PH@("`@("`@(')E='5R;B!A<G)A>2@D9&%T85LG:6UA9V5W
M:61T:"==+"`D9&%T85LG:6UA9V5H96EG:'0G72D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!%>&%M<&QE('5S86=E.@H@("`@("H@("1T97AT9&EM("`@(#T@
M)'5A+3YG971497AT1&EM96YS:6]N<R@I.PH@("`@("H@("1T97AT=VED=&@@
M(#T@)'1E>'1D:6U;,%T["B`@("`@*B`@)'1E>'1H96EG:'0@/2`D=&5X=&1I
M;5LQ73L*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@36%X:6UU
M;2!T97AT=VED=&@@86YD('1E>'1H96EG:'0@=&AA=`H@("`@("H@("`@("`@
M("`@("`@("`@9FET(&]N('1H92!H86YD<V5T('-C<F5E;B!W:71H;W5T('-C
M<F]L;&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5X=$1I;65N<VEO
M;G,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@D=&AI<RT^7V1A=&%;
M)'1H:7,M/E]M;V1E;%U;)W1E>'1W:61T:"==+`H@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;)W1E>'1H96EG:'0G
M72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!A;6]U;G0@;V8@:&%N9'-E="!C86-H92!I;B!K:6QO8GET97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$-A8VAE*"D*("`@('L*("`@("`@("!R971U
M<FX@*&EN="DD=&AI<RT^7V-A8VAE.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$UA;G5F86-T=7)E<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;6%N=69A8W1U<F5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$5X=')A*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]E>'1R83L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971);6%G949O<FUA=',H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;)VEM86=E9F]R;6%T
M<R==.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!7
M:&EC:"!C;VQO<B!M;V1E;"!T:&4@:&%N9'-E="!S=7!P;W)T<RX*("`@("`J
M("`@5F%L=65S(&AA=F4@=&AE(&9O;&QO=VEN9R!M96%N:6YG.@H@("`@("H@
M("`@(#`@+3X@8FQA8VL@86YD('=H:71E"B`@("`@*B`@("`@,2`M/B`T('1O
M;F4@9W)E>7-C86QE"B`@("`@*B`@("`@,B`M/B`R-38@8V]L;W(*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0V]L;W(H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;)V-O;&]R)UT["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T2%144%9E<G-I;VXH*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7VAT='!V97)S:6]N.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&ES0V]L;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A
M=&%;)'1H:7,M/E]M;V1E;%U;)V-O;&]R)UT@/3T@,C4V.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&ES1W)E>5-C86QE*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]D871A6R1T:&ES+3Y?;6]D96Q=6R=C;VQO<B==(#T]("=G<F5Y
M)SL*("`@('T*"B`@("!F=6YC=&EO;B!I<T)L86-K06YD5VAI=&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)'1H:7,M/E]M;V1E;%U;
M)V-O;&]R)UT@/3T@)V)L86-K)SL*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]344PO071T<FEB=71E<RYP:'``````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,#,R-2`Q,#4Q-30S-#$T
M,"`P,C(V-#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H:7,@8VQA<W,@<')O=FED97,@871T<FEB
M=71E<R!M971H;V1S(&9O<B!A;GD@97AI<W1I;F<@4U%,(&-L87-S+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]344PO4U%,+T%T=')I8G5T97,N<&AP+'8@
M,2XQ-"XQ,"XY(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E
M(#(N,@H@*B!`<&%C:V%G92!(;W)D95]344P*("HO"F-L87-S($AO<F1E7U-1
M3%]!='1R:6)U=&5S('L*"B`@("`O*BH*("`@("`J(%1H92!014%2.CI$0B!O
M8FIE8W0@=&\@<G5N('%U97)I97,@=VET:"X*("`@("`J"B`@("`@*B!`=F%R
M($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@4&%R
M86UE=&5R<R!T;R!U<V4@=VAE;B!G96YE<F%T:6YG('%U97)I97,Z"B`@("`@
M*B`@(&ED7V-O;'5M;B`@("`@("`M(%1H92!P<FEM87)Y(&ED(&-O;'5M;B!T
M;R!U<V4@:6X@:F]I;G,N"B`@("`@*B`@('!R:6UA<GE?=&%B;&4@("`M(%1H
M92!M86EN('1A8FQE(&YA;64N"B`@("`@*B`@(&%T=')I8G5T95]T86)L92`M
M(%1H92!T86)L92!T:&%T('1H92!A='1R:6)U=&5S(&%R92!S=&]R960@:6XN
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P
M87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&YU;6)E<B!O
M9B!C;W!I97,@;V8@=&AE(&%T=')I8G5T97,@=&%B;&4@=&AA="!W92!N965D
M('1O(&IO:6X@;VX@:6X*("`@("`J('1H92!C=7)R96YT('%U97)Y+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]T86)L
M95]C;W5N="`](#$["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@1$(@)&1B:"`@("`@("`@02!014%2.CI$0B!O
M8FIE8W0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE(&ED(&-O
M;'5M;BP@=&%B;&4@;F%M97,L(&5T8RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M2&]R9&5?4U%,7T%T=')I8G5T97,H)&1B:"P@)'!A<F%M<RD*("`@('L*("`@
M("`@("`D=&AI<RT^7V1B(#T@)&1B:#L*("`@("`@("`D=&AI<RT^7W!A<F%M
M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%L
M;"!A='1R:6)U=&5S(&9O<B!A(&=I=F5N(&ED(&]R(&UU;'1I<&QE(&ED<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B!\(&%R<F%Y("1I9"`@5&AE
M(&ED('1O(&9E=&-H(&]R(&%N(&%R<F%Y(&]F(&ED<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@;V8@871T<FEB=71E<RP@;W(@82!M
M=6QT:2UL979E;"!H87-H"B`@("`@*B`@("`@("`@("`@("`@("!O9B!I9',@
M/3X@=&AE:7(@871T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M071T<FEB=71E<R@D:60I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1I
M9"DI('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4("4Q
M)',L(&%T=')I8G5T95]N86UE(&%S(&YA;64L(&%T=')I8G5T95]K97D@87,@
M(FME>2(L(&%T=')I8G5T95]V86QU92!A<R!V86QU92!&4D]-("4R)',@5TA%
M4D4@)3$D<R!)3B`H)3,D<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G
M+"`G+"`D:60I*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3
M44P@475E<GD@8GD@2&]R9&5?4U%,7T%T=')I8G5T97,Z.F=E=$%T=')I8G5T
M97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@("`@("1R;W=S(#T@)'1H:7,M/E]D8BT^9V5T
M06QL*"1Q=65R>2P@1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)')O=W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F]W<SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&ED7V-O;'5M;B`]("1T:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG73L*("`@
M("`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@("!F;W)E86-H
M("@D<F]W<R!A<R`D<F]W*2!["B`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&1A=&%;)')O=ULD:61?8V]L=6UN75TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&1A=&%;)')O=ULD:61?8V]L=6UN75T@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&1A=&%;)')O=ULD:61?8V]L
M=6UN75U;72`](&%R<F%Y*"=N86UE)R`@/3X@)')O=ULG;F%M92==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K
M97DG("`@/3X@)')O=ULG:V5Y)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D<F]W6R=V86QU
M92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&1A=&$[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G4T5,14-4("4Q)',L(&%T=')I8G5T95]N86UE(&%S(&YA;64L(&%T=')I
M8G5T95]K97D@87,@(FME>2(L(&%T=')I8G5T95]V86QU92!A<R!V86QU92!&
M4D]-("4R)',@5TA%4D4@)3$D<R`]("4S)',G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T
M<FEB=71E7W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*&EN="DD:60I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,
M(%%U97)Y(&)Y($AO<F1E7U-13%]!='1R:6)U=&5S.CIG971!='1R:6)U=&5S
M*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^9V5T06QL
M*"1Q=65R>2P@1$)?1D540TA-3T1%7T%34T]#*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!S970@;V8@:61S(&)A<V5D(&]N
M(&$@<V5T(&]F(&%T=')I8G5T92!C<FET97)I82X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&-R:71E<FEA("!4:&4@87)R87D@;V8@8W)I=&5R:6$N
M($5X86UP;&4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`D8W)I
M=&5R:6%;)T]2)UT@/2!A<G)A>2@*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=N86UE)RP*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5S="<@(#T^("=F;V\G*2P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G9FEE;&0G(#T^("=N86UE)RP*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;W`G("`@(#T^("<])RP*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=&5S="<@(#T^("=B87(G*2D["B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@5&AI<R!W;W5L9"!R971U<FX@86QL(&ED<R!F;W(@=VAI
M8V@@=&AE(&9I96QD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M871T<FEB=71E7VYA;64@:7,@96ET:&5R("=F;V\G(&]R("=B87(G+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971">4%T=')I8G5T97,H)&-R:71E<FEA*0H@
M("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E<FEA*2D@>PH@("`@("`@
M("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\J($)U
M:6QD('1H92!Q=65R>2X@*B\*("`@("`@("`D=&AI<RT^7W1A8FQE7V-O=6YT
M(#T@,3L*("`@("`@("`D<75E<GD@/2`G)SL*("`@("`@("!F;W)E86-H("@D
M8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L<RD@>PH@("`@("`@("`@("!I9B`H
M)&ME>2`]/2`G3U(G('Q\("1K97D@/3T@)T%.1"<I('L*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)'%U97)Y*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1Q=65R>2`N/2`G("<@+B`D:V5Y("X@)R`G.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'%U97)Y("X]("<H)R`N("1T:&ES+3Y?8G5I
M;&1!='1R:6)U=&51=65R>2@D:V5Y+"`D=F%L<RD@+B`G*2<["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD('1H92!&4D]-+TI/
M24X@8VQA=7-E<RX@*B\*("`@("`@("`D:F]I;G,@/2!A<G)A>2@I.PH@("`@
M("`@("1P86ER<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#$[("1I
M(#P]("1T:&ES+3Y?=&%B;&5?8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@
M)&IO:6YS6UT@/2!S<')I;G1F*"=,1494($I/24X@)3$D<R!A)3(D<R!/3B!A
M)3(D<RXE,R1S(#T@;2XE,R1S)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=A='1R:6)U=&5?=&%B;&4G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VED7V-O;'5M;B==
M*3L*"B`@("`@("`@("`@("1P86ER<UM=(#T@)T%.1"!A,2YA='1R:6)U=&5?
M;F%M92`](&$G("X@)&D@+B`G+F%T=')I8G5T95]N86UE)SL*("`@("`@("!]
M"B`@("`@("`@)&IO:6YS(#T@:6UP;&]D92@G("<L("1J;VEN<RD["B`@("`@
M("`@)'!A:7)S(#T@:6UP;&]D92@G("<L("1P86ER<RD["@H@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)U-%3$5#5"!$25-424Y#5"!A,2XE<R!&4D]-("5S
M(&T@)7,@5TA%4D4@)7,@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)VED7V-O;'5M;B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!R:6UA<GE?=&%B;&4G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("1J;VEN<RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1Q=65R>2P*("`@("`@("`@("`@("`@("`@("`@("`@("1P
M86ER<RD["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@2&]R9&5?4U%,7T%T=')I8G5T97,Z.F=E=$)Y071T<FEB=71E<R@I.B`G
M("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!N97<@871T<FEB=71E
M('-E="!A;F0@86X@:60L(&EN<V5R="!E86-H(&EN=&\@=&AE($1"+B!)9@H@
M("`@("H@86YY=&AI;F<@9F%I;',@:6X@:&5R92P@<F]L;&)A8VL@=&AE('1R
M86YS86-T:6]N+"!R971U<FX@=&AE(')E;&5V86YT"B`@("`@*B!E<G)O<B!A
M;F0@8F%I;"!O=70N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED
M("`@("`@("!4:&4@:60@;V8@=&AE(')E8V]R9"!F;W(@=VAI8V@@871T<FEB
M=71E<R!A<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8F5I
M;F<@:6YS97)T960N"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@
M($%N(&AA<V@@8V]N=&%I;FEN9R!T:&4@871T<FEB=71E<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@:6YS97)T071T<FEB=71E<R@D:60L("1A='1R:6)U=&5S
M*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1A='1R:6)U=&5S(&%S("1A='1R
M*2!["B`@("`@("`@("`@("1Q=65R>2`]("=)3E-%4E0@24Y43R`G("X@)'1H
M:7,M/E]P87)A;7-;)V%T=')I8G5T95]T86)L92==("X*("`@("`@("`@("`@
M("`@("`@("`@)R`H)R`N("1T:&ES+3Y?<&%R86US6R=I9%]C;VQU;6XG72`N
M("<L(&%T=')I8G5T95]N86UE+"<@+@H@("`@("`@("`@("`@("`@("`@("`G
M(&%T=')I8G5T95]K97DL(&%T=')I8G5T95]V86QU92D@5D%,5453("@_+"`_
M+"`_+"`_*2<["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I
M9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A='1R6R=N86UE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T<ELG:V5Y)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D871T<ELG=F%L=64G72D["@H@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($AO
M<F1E7U-13%]!='1R:6)U=&5S.CII;G-E<G1!='1R:6)U=&5S*"DZ("<@+B`D
M<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2P@)'9A;'5E<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G)O
M;&QB86-K*"D["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YA=71O0V]M
M;6ET*'1R=64I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-O;6UI="!T:&4@
M=')A;G-A8W1I;VXL(&%N9"!T=7)N(&%U=&]C;VUM:70@8F%C:R!O;BX@*B\*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^8V]M;6ET*"D["B`@("`@
M("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=I=F5N(&%N(&ED+"!D96QE=&4@86QL(&%T=')I8G5T97,@
M9F]R('1H870@:60@9G)O;2!T:&4*("`@("`J(&%T=')I8G5T97,@=&%B;&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("!4:&4@:60@;V8@
M=&AE(')E8V]R9"!F;W(@=VAI8V@@871T<FEB=71E<R!A<F4@8F5I;F<*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@9&5L971E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&5L971E071T<FEB=71E<R@D:60I"B`@("!["B`@("`@("`@
M+RH@1&5L971E(&%T=')I8G5T97,N("HO"B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@)7,@/2`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG871T<FEB=71E7W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG:61?8V]L=6UN)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT
M*21I9"D["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@2&]R9&5?4U%,7T%T=')I8G5T97,Z.F1E;&5T94%T=')I8G5T97,H*3H@
M)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R
M>2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@
M86X@:60L('5P9&%T92!A;&P@871T<FEB=71E<R!F;W(@=&AA="!I9"!I;B!T
M:&4@871T<FEB=71E<R!T86)L90H@("`@("H@=VET:"!T:&4@;F5W(&%T=')I
M8G5T97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@("`@
M("!4:&4@:60@;V8@=&AE(')E8V]R9"!F;W(@=VAI8V@@871T<FEB=71E<R!A
M<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@8F5I;F<@9&5L
M971E9"X*("`@("`J($!P87)A;2!A<G)A>2`D871T<FEB=71E<R`@06X@:&%S
M:"!C;VYT86EN:6YG('1H92!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!U<&1A=&5!='1R:6)U=&5S*"1I9"P@)&%T=')I8G5T97,I"B`@("![
M"B`@("`@("`@+RH@1&5L971E('1H92!O;&0@871T<FEB=71E<RX@*B\*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T94%T=')I8G5T97,H)&ED*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M+RH@26YS97)T('1H92!N97<@871T<FEB=71E('-E="X@*B\*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/FEN<V5R=$%T=')I8G5T97,H)&ED+"`D871T<FEB
M=71E<RD["B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!"=6EL9"!A('!I96-E(&]F(&%N(&%T=')I8G5T92!Q=65R>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G;'5E("`@("!4:&4@9VQU
M92!T;R!J;VEN('1H92!C<FET97)I82`H3U(O04Y$*2X*("`@("`J($!P87)A
M;2!A<G)A>2`D8W)I=&5R:6$@(%1H92!A<G)A>2!O9B!C<FET97)I82X*("`@
M("`J($!P87)A;2!B;V]L96%N("1J;VEN("`@(%-H;W5L9"!W92!J;VEN(&]N
M(&$@8VQE86X@871T<FEB=71E<R!T86)L93\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@06X@4U%,(&9R86=M96YT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?8G5I;&1!='1R:6)U=&51=65R>2@D9VQU92P@)&-R:71E<FEA+"`D
M:F]I;B`](&9A;'-E*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O4U%,+G!H<"<["@H@("`@("`@("\J($EN:71I86QI>F4@=&AE(&-L875S
M92!T:&%T('=E)W)E(&)U:6QD:6YG+B`J+PH@("`@("`@("1C;&%U<V4@/2`G
M)SL*"B`@("`@("`@+RH@1V5T('1H92!T86)L92!A;&EA<R!T;R!U<V4@9F]R
M('1H:7,@<V5T(&]F(&-R:71E<FEA+B`J+PH@("`@("`@(&EF("@D:F]I;BD@
M>PH@("`@("`@("`@("`D86QI87,@/2`D=&AI<RT^7V=E=$%L:6%S*'1R=64I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A;&EA<R`]("1T:&ES
M+3Y?9V5T06QI87,H*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C
M<FET97)I82!A<R`D:V5Y(#T^("1V86QS*2!["B`@("`@("`@("`@(&EF("@A
M96UP='DH)'9A;'-;)T]2)UTI('Q\("%E;7!T>2@D=F%L<ULG04Y$)UTI*2![
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1C;&%U<V4I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&-L875S92`N/2`G("<@+B`D9VQU92`N("<@)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@
M)R@G("X@)'1H:7,M/E]B=6EL9$%T=')I8G5T95%U97)Y*"1G;'5E+"`D=F%L
M<RD@+B`G*2<["B`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)'9A;'-;
M)TI/24XG72DI('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-L875S
M92DI('L*("`@("`@("`@("`@("`@("`@("`D8VQA=7-E("X]("<@)R`N("1G
M;'5E("X@)R`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&-L875S92`N/2`D=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&=L=64L
M("1V86QS6R=*3TE.)UTL('1R=64I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QS6R=F:65L9"==*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&-L875S92DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-L875S92`N/2`G("<@+B`D9VQU92`N
M("<@)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&-L875S92`N/2!(;W)D95]344PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?
M9&(L("1A;&EA<R`N("<N871T<FEB=71E7R<@+B`D=F%L<ULG9FEE;&0G72P@
M)'9A;'-;)V]P)UTL("1V86QS6R=T97-T)UTI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L<R!A
M<R`D=&5S="D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1C;&%U<V4I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQA
M=7-E("X]("<@)R`N("1K97D@+B`G("<["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&-L875S92`N/2!(;W)D
M95]344PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?9&(L("1A;&EA<R`N("<N871T
M<FEB=71E7R<@+B`D=&5S=%LG9FEE;&0G72P@)'1E<W1;)V]P)UTL("1T97-T
M6R=T97-T)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1C;&%U<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86X@86QI87,@
M=&\@86X@871T<FEB=71E<R!T86)L92P@:6YC<F5M96YT:6YG(&ET(&EF"B`@
M("`@*B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&EN8W)E;65N="`@26YC<F5M96YT('1H92!A;&EA<R!C;W5N=#\@1&5F875L
M=',@=&\@9F%L<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971!;&EA<R@D
M:6YC<F5M96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1S965N
M("`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D:6YC<F5M96YT("8F("%E;7!T
M>2@D<V5E;ELD=&AI<RT^7W1A8FQE7V-O=6YT72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]T86)L95]C;W5N="LK.PH@("`@("`@('T*"B`@("`@("`@)'-E
M96Y;)'1H:7,M/E]T86)L95]C;W5N=%T@/2!T<G5E.PH@("`@("`@(')E='5R
M;B`G82<@+B`D=&AI<RT^7W1A8FQE7V-O=6YT.PH@("`@?0H*("`@("\J*@H@
M("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E('1O(&$@8V]N
M8W)E=&4@4U%,($%T=')I8G5T97,*("`@("`J(&EN<W1A;F-E(&)A<V5D(&]N
M('!A<F%M971E<G,@<&%S<V5D+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W
M"B`@("`@*B!I;G-T86YC92!I9B!N;R!!='1R:6)U=&5S(&EN<W1A;F-E('=I
M=&@@=&AE('-A;64@<&%R86UE=&5R<PH@("`@("H@8W5R<F5N=&QY(&5X:7-T
M<RX*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!U<V5D(&EF(&UU;'1I
M<&QE(%-13"!A='1R:6)U=&4@=&%B;&5S(&%R90H@("`@("H@<F5Q=6ER960N
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S
M.B`D=F%R(#T*("`@("`J("9(;W)D95]344Q?071T<FEB=71E<SHZ<VEN9VQE
M=&]N*"D*("`@("`J"B`@("`@*B!`<&%R86T@1$(@)&1B:"`@("`@("`@06X@
M;V)J96-T('!O:6YT:6YG('1O(&$@4U%,(&1A=&%B87-E(&AA;F1L92X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R<R!F
M;W(@=&AE(&%T=')I8G5T97,@=&%B;&4L(&-O;G-I<W1I;F<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!O9B!T:&4@9F]L;&]W:6YG(&ME>7,Z"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W!R:6UA<GE?=&%B;&4G("`@
M+2!T:&4@;6%I;B!344P@=&%B;&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`G871T<FEB=71E7W1A8FQE)R`M('1H92!S96-O;F0@=&%B;&4@8V]N
M=&%I;FEN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&%T=')I8G5T97,@=&\@=&AE(&UA:6X*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1A
M8FQE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=I9%]C;VQU;6XG
M("`@("`@("T@=&AE(&YA;64@;V8@=&AE(&-O;'5M;B!W:71H"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M240@;W(@:V5Y(&9I96QD+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN9VQE
M=&]N*"1D8F@L("1P87)A;7,I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T
M86YC97,["@H@("`@("`@(&EF("@A:7-S970H)&EN<W1A;F-E<RDI('L*("`@
M("`@("`@("`@)&EN<W1A;F-E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*"1P87)A;7,I.PH@("`@("`@
M(&EF("@A:7-S970H)&EN<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E<ULD<VEG;F%T=7)E72`]("9N97<@2&]R9&5?4U%,
M7T%T=')I8G5T97,H)&1B:"P@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E73L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4U%,+TME>7=O<F1S+G!H<```````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,30U,S(@,3`U,34T,S0Q-#`@,#(R,S(S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&ES(&-L87-S('!R;W9I9&5S(&$@<&%R<V5R('=H:6-H
M(&-A;B!C;VYS=')U8W0@86X@4U%,(%=(15)%"B`J(&-L875S92!F<F]M(&$@
M1V]O9VQE+6QI:V4@<V5A<F-H(&5X<')E<W-I;VXN"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U-13"]344PO2V5Y=V]R9',N<&AP+'8@,2XR+C$P+C0@,C`P
M-B\P,2\P,2`R,3HR.#HS,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O
M;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@5&AE(&5X<')E<W-I;VX@<F5C;V=N
M:7IE<R!B;V]L96%N(")!3D0B+"`B3U(B+"!A;F0@(DY/5"(@*'!R;W9I9&EN
M9PH@*B!N;R!O<&5R871O<B!B971W965N(&ME>7=O<F1S(&EM<&QI97,@(D%.
M1"(I+"!L:6ME('-O.@H@*@H@*B`@(&-A="!A;F0@9&]G"B`J("`@8V%T(&]R
M(&1O9PH@*B`@(&-A="!A;F0@;F]T(&1O9PH@*@H@*B!)9B!N;R!O<&5R871O
M<B!A<'!E87)S(&)E='=E96X@:V5Y=V]R9',@;W(@<75O=&5D('-T<FEN9W,L
M(")!3D0B(&ES"B`J(&%S<W5M960N("!!(&-O;6UA(&-A;B!B92!U<V5D(&EN
M<W1E860@;V8@(D]2(CH*("H*("H@("!C870@9&]G"B`J("`@8V%T+"!D;V<*
M("H@("!C870@;F]T(&1O9PH@*@H@*B!4:&4@<&%R<V5R(')E8V]G;FEZ97,@
M<&%R96YT:&5S97,L('-O(&-O;7!L97@@97AP<F5S<VEO;G,@8V%N(&)E"B`J
M(&-R96%T960Z"B`J"B`J("`@8V%T(&%N9"!N;W0@*&1O9R!O<B!P=7!P>2D*
M("H*("H@475O=&5D('-T<FEN9W,@87)E(&%L<V\@<F5C;V=N:7IE9"P@86YD
M(&%R92!T86ME;B!A<R!L:71E<F%L"B`J(&ME>7=O<F1S.@H@*@H@*B`@(")C
M870@86YD(&1O9R(*("H*("H@4&%R<VEN9R!I<R!D97-I9VYE9"!T;R!B92!A
M<R!F=7IZ>2!A<R!P;W-S:6)L92P@<V\@:70@<VAO=6QD;B=T"B`J(&5R<F]R
M('5N;&5S<R!P96]P;&4@<V5A<F-H(&9O<B`B04Y$(BP@(D]2(BP@;W(@(DY/
M5"(@=VET:&]U=`H@*B!Q=6]T:6YG(&ET(&]R('5S92!U;F)A;&%N8V5D('!A
M<F5N=&AE<V5S+@H@*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF
M96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?4U%,"B`J+PIC;&%S<R!(;W)D95]344Q?2V5Y=V]R
M9',@>PH*("`@("\J*@H@("`@("H@4&%R<V4@82!K97EW;W)D(&5X<')E<W-I
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L=6UN("`@("`@
M("!4:&ES(&ES('1H92!344P@9FEE;&0@;F%M92!T:&4@<F5S=6QT:6YG"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5X<')E<W-I;VX@
M<VAO=6QD('1E<W0@86=A:6YS="X*("`@("`J($!P87)A;2!S=')I;F<@)&5X
M<'(@("`@("`@("`@5&AI<R!I<R!T:&4@:V5Y=V]R9"!E>'!R97-S:6]N('=E
M('=A;G0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<&%R<V4N"B`@("`@*B!`<F5T=7)N(&UI>&5D('1H92!Q=65R>2!E>'!R97-S
M:6]N(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P87)S92@D8V]L=6UN+"`D97AP<BD*("`@('L*("`@("`@("`O
M*B!&:7)S="!P87-S("T@<V-A;B!T:&4@<W1R:6YG(&9O<B!T;VME;G,N("!"
M87)E('=O<F1S(&%R90H@("`@("`@("`J('1O:V5N<RP@;W(@=&AE('5S97(@
M8V%N('%U;W1E('-T<FEN9W,@=&\@:&%V92!E;6)E9&1E9`H@("`@("`@("`J
M('-P86-E<RP@:V5Y=V]R9',L(&]R('!A<F5N=&AE<V5S+B`@4&%R96YT:&5S
M97,@8V%N(&)E('5S960*("`@("`@("`@*B!F;W(@9W)O=7!I;F<@8F]O;&5A
M;B!O<&5R871O<G,L(&%N9"!T:&4@8F]O;&5A;B!O<&5R871O<G,*("`@("`@
M("`@*B!!3D0L($]2+"!A;F0@3D]4(&%R92!A;&P@<F5C;V=N:7IE9"X*("`@
M("`@("`@*@H@("`@("`@("`J(%1H92!T;VME;G,@87)E(')E='5R;F5D(&EN
M('1H92`D=&]K96YS(&%R<F%Y("TM(&%N(&%R<F%Y(&]F"B`@("`@("`@("H@
M<W1R:6YG<RX@($5A8V@@<W1R:6YG(&EN('1H92!A<G)A>2!S=&%R=',@=VET
M:"!E:71H97(@82!@(2<*("`@("`@("`@*B!O<B!A(&`])RX@(&`])R!I<R!A
M(&)A<F4@=V]R9"!O<B!Q=6]T960@<W1R:6YG('=E(&%R90H@("`@("`@("`J
M('-E87)C:&EN9R!F;W(L(&%N9"!@(2<@:6YD:6-A=&5S(&$@8F]O;&5A;B!O
M<&5R871O<B!O<@H@("`@("`@("`J('!A<F5N=&AE<VES+B`@02!T;VME;B!T
M:&%T('-T87)T<R!W:71H(&$@)RXG("!I;F1I8V%T97,@80H@("`@("`@("`J
M(%!O<W1G<F5344P@=V]R9"!B;W5N9&%R>2!S96%R8V@N("HO"B`@("`@("`@
M)'1O:V5N<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*"%E;7!T>2@D97AP
M<BDI('L*("`@("`@("`@("`@)&5X<'(@/2!P<F5G7W)E<&QA8V4H(B]>7',K
M+R(L("(B+"`D97AP<BD["B`@("`@("`@("`@(&EF("AE;7!T>2@D97AP<BDI
M('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AS=6)S='(H)&5X<'(L,"PQ*2`]/2`G*"<I('L*("`@("`@
M("`@("`@("`@("1E>'!R(#T@<W5B<W1R*"1E>'!R+"`Q*3L*("`@("`@("`@
M("`@("`@("1T;VME;B`]("<A*"<["B`@("`@("`@("`@('T@96QS96EF("AS
M=6)S='(H)&5X<'(L(#`L(#$I(#T]("<I)RD@>PH@("`@("`@("`@("`@("`@
M)&5X<'(@/2!S=6)S='(H)&5X<'(L(#$I.PH@("`@("`@("`@("`@("`@)'1O
M:V5N(#T@)R$I)SL*("`@("`@("`@("`@?2!E;'-E:68@*'-U8G-T<B@D97AP
M<BP@,"P@,2D@/3T@)RPG*2!["B`@("`@("`@("`@("`@("`D97AP<B`]('-U
M8G-T<B@D97AP<BP@,2D["B`@("`@("`@("`@("`@("`D=&]K96X@/2`G(4]2
M)SL*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H(B]>*$%.1'Q/
M4GQ.3U0I*%M>82UZ72XJ*3\D+VDB+"`D97AP<BP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@
M("`D=&]K96X@/2`G(2<@+B!S=')T;W5P<&5R*"1M871C:&5S6S%=*3L*("`@
M("`@("`@("`@("`@("1E>'!R(#T@<W5B<W1R*"1E>'!R+"!S=')L96XH)&UA
M=&-H97-;,5TI*3L*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H
M(B]>7"(H*%M>7")=?%Q<6S`M-UTK?%Q<6UAX75LP+3EA+69!+49=*WQ<7%M>
M6'@P+3==*2HI7"(O(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X<'(L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'1O:V5N
M(#T@)STG("X@<W1R:7!C<VQA<VAE<R@D;6%T8VAE<ULQ72D["B`@("`@("`@
M("`@("`@("`D97AP<B`]('-U8G-T<B@D97AP<BP@<W1R;&5N*"1M871C:&5S
M6S!=*2D["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O7EM>
M7%QS7%PH7%PI+%TK+R(L("1E>'!R+"`D;6%T8VAE<RDI('L*("`@("`@("`@
M("`@("`@("1T;VME;B`]("<])R`N("1M871C:&5S6S!=.PH@("`@("`@("`@
M("`@("`@)&5X<'(@/2!S=6)S='(H)&5X<'(L<W1R;&5N*"1T;VME;BDM,2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")3>6YT87@@97)R;W(@:6X@<V5A<F-H('1E
M<FUS(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&]K96X@
M/3T@)R%!3D0G*2!["B`@("`@("`@("`@("`@("`O*B`A04Y$(&ES(&EM<&QI
M960@8GD@8V]N8V%T96YA=&EO;BX@*B\*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T;VME;G-;72`]("1T
M;VME;CL*("`@("`@("!]"@H@("`@("`@("\J($-A;&P@=&AE(&5X<')E<W-I
M;VX@<&%R<V5R+B`J+PH@("`@("`@(')E='5R;B!(;W)D95]344Q?2V5Y=V]R
M9',Z.E]P87)S94ME>7=O<F1S,2@D8V]L=6UN+"`D=&]K96YS*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?<&%R<V5+97EW;W)D<S$H)&-O;'5M;BP@)B1T;VME
M;G,I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T;VME;G,I(#T](#`I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B16UP='D@
M<V5A<F-H('1E<FUS(BDI.PH@("`@("`@('T*("`@("`@("`D;&AS(#T@2&]R
M9&5?4U%,7TME>7=O<F1S.CI?<&%R<V5+97EW;W)D<S(H)&-O;'5M;BP@)'1O
M:V5N<RD["B`@("`@("`@:68@*&ES7V$H)&QH<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@
M:68@*&-O=6YT*"1T;VME;G,I(#T](#`@?'P@)'1O:V5N<ULP72`A/2`G(4]2
M)RD@>PH@("`@("`@("`@("!R971U<FX@)&QH<SL*("`@("`@("!]"B`@("`@
M("`@87)R87E?<VAI9G0H)'1O:V5N<RD["B`@("`@("`@)')H<R`]($AO<F1E
M7U-13%]+97EW;W)D<SHZ7W!A<G-E2V5Y=V]R9',Q*"1C;VQU;6XL("1T;VME
M;G,I.PH@("`@("`@(&EF("AI<U]A*"1R:',L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1R:',["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`B*"`D;&AS($]2("1R:',@*2(["B`@("!]"@H@("`@9G5N8W1I;VX@
M7W!A<G-E2V5Y=V]R9',R*"1C;VQU;6XL("8D=&]K96YS*0H@("`@>PH@("`@
M("`@("1L:',@/2!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S
M,R@D8V]L=6UN+"`D=&]K96YS*3L*("`@("`@("!I9B`H:7-?82@D;&AS+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;&AS.PH@("`@
M("`@('T*("`@("`@("!I9B`H<VEZ96]F*"1T;VME;G,I(#T](#`@?'P@)'1O
M:V5N<ULP72`]/2`G(2DG('Q\("1T;VME;G-;,%T@/3T@)R%/4B<I('L*("`@
M("`@("`@("`@<F5T=7)N("1L:',["B`@("`@("`@?0H@("`@("`@("1R:',@
M/2!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S,B@D8V]L=6UN
M+"`D=&]K96YS*3L*("`@("`@("!I9B`H:7-?82@D<FAS+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<FAS.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@(B@@)&QH<R!!3D0@)')H<R`I(CL*("`@('T*"B`@("!F
M=6YC=&EO;B!?<&%R<V5+97EW;W)D<S,H)&-O;'5M;BP@)B1T;VME;G,I"B`@
M("!["B`@("`@("`@:68@*"1T;VME;G-;,%T@/3T@)R%.3U0G*2!["B`@("`@
M("`@("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I.PH@("`@("`@("`@("`D;&AS
M(#T@2&]R9&5?4U%,7TME>7=O<F1S.CI?<&%R<V5+97EW;W)D<S0H)&-O;'5M
M;BP@)'1O:V5N<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1L:',L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&AS.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`B*"!.3U0@)&QH<R`I(CL*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N($AO<F1E7U-13%]+97EW;W)D<SHZ
M7W!A<G-E2V5Y=V]R9',T*"1C;VQU;6XL("1T;VME;G,I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]P87)S94ME>7=O<F1S-"@D8V]L=6UN+"`F)'1O:V5N<RD*
M("`@('L*("`@("`@("!I9B`H("1T;VME;G-;,%T@/3T@)R$H)R`I('L*("`@
M("`@("`@("`@87)R87E?<VAI9G0H)'1O:V5N<RD["B`@("`@("`@("`@("1L
M:',@/2!(;W)D95]344Q?2V5Y=V]R9',Z.E]P87)S94ME>7=O<F1S,2@D8V]L
M=6UN+"`D=&]K96YS*3L*("`@("`@("`@("`@:68@*&ES7V$H)&QH<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:',["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*'-I>F5O9B@D=&]K96YS*2`]
M/2`P('Q\("1T;VME;G-;,%T@(3T@)R$I)RD@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B17AP96-T960@)RDG(BDI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T;VME;G,I
M.PH@("`@("`@("`@("!R971U<FX@)&QH<SL*("`@("`@("!]"B`@("`@("`@
M:68@*'-U8G-T<B@D=&]K96YS6S!=+"`P+"`Q*2`A/2`G/2<@)B8*("`@("`@
M("`@("`@<W5B<W1R*"1T;VME;G-;,%TL(#`L(#(I("$]("<]+B<I('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B17AP96-T960@
M8F%R92!W;W)D(&]R('%U;W1E9"!S96%R8V@@=&5R;2(I*3L*("`@("`@("!]
M"B`@("`@("`@)'9A;"`]('-T<G1O;&]W97(H<W5B<W1R*&%R<F%Y7W-H:69T
M*"1T;VME;G,I+"`Q*2D["B`@("`@("`@)'9A;"`](&%D9'-L87-H97,H97)E
M9U]R97!L86-E*"(H6UQ<)5TI(BP@(EQ<7%PQ(BP@)'9A;"DI.PH@("`@("`@
M(')E='5R;B`B*"!,3U=%4B@D8V]L=6UN*2!,24M%("<E)'9A;"4G("DB.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]R97-T+G!H<```````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-#$S(#$P-3$U
M-#,T,30P(#`R,30U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U)00U]R97-T(&-L
M87-S('!R;W9I9&5S(&$@4D535"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R
M9&4@4E!#"B`J('-Y<W1E;2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4E!#
M+U)00R]R97-T+G!H<"QV(#$N-BXR+C(@,C`P-B\P-2\P-"`Q,CHR-#HQ-"!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(%)A9F%E;"!687)E;&$@4&5T(#QR
M869A96PN=F%R96QA+G!E=$!U<V,N97,^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!2869A96P@5F%R96QA(#QR869A96PN=F%R96QA+G!E=$!U<V,N
M97,^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]2
M4$,*("HO"F-L87-S($AO<F1E7U)00U]R97-T(&5X=&5N9',@2&]R9&5?4E!#
M('L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V-O;G1E;G14>7!E(#T@)W1E>'0O:'1M;"<["@H@("`@+RHJ"B`@("`@
M*B!#:&5C:R!A=71H96YT:6-A=&EO;BX@1&EF9F5R96YT(&)A8VME;F1S(&UA
M>2!H86YD;&4*("`@("`J(&%U=&AE;G1I8V%T:6]N(&EN(&1I9F9E<F5N="!W
M87ES+B!4:&4@8F%S92!C;&%S<R!I;7!L96UE;G1A=&EO;@H@("`@("H@8VAE
M8VMS(&9O<B!(5%10($%U=&AE;G1I8V%T:6]N(&%G86EN<W0@=&AE($AO<F1E
M(&%U=&@@<V5T=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!2
M971U<FYS('1R=64@:68@875T:&5N=&EC871I;VX@:7,@<W5C8V5S<V9U;"X*
M("`@("`J("`@("`@("`@("`@("`@("`@4VAO=6QD('-E;F0@87!P<F]P<FEA
M=&4@(FYO="!A=71H;W)I>F5D(B!H96%D97)S"B`@("`@*B`@("`@("`@("`@
M("`@("`@(&]R(&]T:&5R(')E<W!O;G-E(&-O9&5S+V)O9'D@:68@875T:"!F
M86EL<RP*("`@("`J("`@("`@("`@("`@("`@("`@86YD('1A:V4@8V%R92!O
M9B!E>&ET:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!A=71H;W)I>F4H*0H@
M("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]A=71H;W)I>F4I('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("!I9B`H075T
M:#HZ9V5T075T:"@I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('!A<F5N=#HZ875T:&]R:7IE*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970N(&%L;"!T:&4@1T54(&EN<'5T(&1A
M=&$N(%1H92`G8V%L;"<@<&%R86T@:7,@97AT<F%C=&5D(&9R;VT@=&AE"B`@
M("`@*B!A<G)A>2!A;F0@=')E871E9"!S97!A<F%T96QY+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@("AM971H;V0@;F%M92P@87)R87D@;V8@<&%R
M86UE=&5R<RD*("`@("`J"B`@("`@*B!43T1/.B!D97-E<FEA;&EZ:6YG(&]F
M(&-O;7!L97@@9&%T82!T>7!E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M26YP=70H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y<&4@/2!5
M=&EL.CIG971'970H)W)E<W1#;VYT96YT5'EP92<L("=T97AT+VAT;6PG*3L*
M"B`@("`))&=E=$1A=&$@/2!5=&EL.CID:7-P96Q-86=I8U%U;W1E<R@D7T=%
M5"D["B`@("`)=6YS970H)&=E=$1A=&%;)W)E<W1#86QL)UTI.PH@("`@"75N
M<V5T*"1G971$871A6R=R97-T0V]N=&5N=%1Y<&4G72D["@H@("`@"7)E='5R
M;B!A<G)A>2@G;65T:&]D)R`]/B!5=&EL.CIG971'970H)W)E<W1#86QL)RDL
M"B`@("`)("`@("`@("`@("`@("=P87)A;7,G(#T^("1G971$871A*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E;F1S(&%N(%)00R!R97%U97-T('1O('1H
M92!S97)V97(@86YD(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!R97-P;VYS92!F<F]M('1H
M92!S97)V97(@;W(@86X@4$5!4B!E<G)O<B!O8FIE8W0@;VX*("`@("`J("`@
M("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%)E<W!O;G-E*"1R97%U97-T*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["@H@("`@("`@("1M971H;V0@/2!S=')?<F5P;&%C92@G+B<L("<O
M)RP@)')E<75E<W1;)VUE=&AO9"==*3L*"B`@("`@("`@:68@*"$D<F5G:7-T
M<GDM/FAA<TUE=&AO9"@D;65T:&]D*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(DUE=&AO9"!N;W0@9&5F:6YE
M9"X@0V%L;&5D(&UE=&AO9#H@)7,B*2P@)&UE=&AO9"DI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3&]O:R!A="!T:&4@;65T:&]D('-I9VYA='5R92!S;R!T
M:&%T('!A<F%M971E<G,@87)E(&%S<VEG;F5D(&)Y"B`@("`@("`@("H@;F%M
M92P@:6YS=&5A9"!O9B!R96QY:6YG(&]N('1H92!O<F1E<B!O9B!'150@<&%R
M86UE=&5R<R!T;R!M871C:`H@("`@("`@("`J('1H92!O<F1E<B!D969I;F5D
M(&EN('1H92!!4$D@;65T:&]D+B`J+PH@("`@("`@("1S:6=N871U<F4@/2`D
M<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D;65T:&]D*3L*("`@("`@("`D<&%R
M86US(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1S
M:6=N871U<F5;,%TI(&%S("1P87)A;2D@>PH@("`@("`@("`@("`D<&%R86US
M6R1P87)A;5T@/2!I<W-E="@D<F5Q=65S=%LG<&%R86US)UU;)'!A<F%M72D@
M/R`D<F5Q=65S=%LG<&%R86US)UU;)'!A<F%M72`Z(&YU;&P["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y+3YC86QL*"1M971H;V0L
M("1P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H*("`@("`@("`O*B!4:&4@<F5S=6QT(&ES(')E='5R;F5D(&1E<&5N9&EN
M9R!O;B!T:&4@<F5Q=65S=&5D(&-O;G1E;G0@='EP92X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]C;VYT96YT5'EP92`]/2`G=&5X="]H=&UL)RD@>PH@("`@
M("`@("`@("!R971U<FX@)SQH=&UL/CQB;V1Y/B<@+B!P<FEN=%]R*"1R97-U
M;'0L('1R=64I("X@)SPO8F]D>3X\+VAT;6P^)SL*("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]C;VYT96YT5'EP92`]/2`G=&5X="]P;&%I;B<I('L*("`@
M("`@("`@("`@<F5T=7)N('!R:6YT7W(H)')E<W5L="P@=')U92D["B`@("`@
M("`@?2!E;'-E:68@*"1T:&ES+3Y?8V]N=&5N=%1Y<&4@/3T@)V%P<&QI8V%T
M:6]N+W@M:'1T<&0M<&AP)RD@>PH@("`@("`@("`@("!R971U<FX@<V5R:6%L
M:7IE*"1R97-U;'0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($=E="!T:&4@0V]N=&5N="U4>7!E(&]F('1H92!R97-P;VYS92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@0V]N=&5N="U4>7!E
M(&]F('1H92!24$,@<F5S<&]N<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%)E<W!O;G-E0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@('-W:71C:"`H
M)'1H:7,M/E]C;VYT96YT5'EP92D@>PH@("`@("`@(&-A<V4@)V%P<&QI8V%T
M:6]N+W@M:'1T<&0M<&AP)SH*("`@("`@("`@("`@<F5T=7)N("=T97AT+W!L
M86EN)SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C;VYT96YT5'EP93L*("`@("`@("!]"B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+U)00R]X;6QR<&,N<&AP````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$S,3$V(#$P-3$U-#,T,30P(#`R,C`P,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($AO<F1E7U)00U]X;6QR<&,@8VQA<W,@<')O=FED97,@86X@6$U,4E!#(&EM
M<&QE;65N=&%T:6]N(&]F('1H90H@*B!(;W)D92!24$,@<WES=&5M+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]24$,O4E!#+WAM;')P8RYP:'`L=B`Q+CDN
M,3`N."`R,#`V+S`W+S`Q(#`T.C4T.C$V(&-H=6-K($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]24$,*("HO"F-L87-S($AO<F1E7U)00U]X;6QR<&,@97AT
M96YD<R!(;W)D95]24$,@>PH*("`@("\J*@H@("`@("H@4F5S;W5R8V4@:&%N
M9&QE<B!F;W(@=&AE(%A-3%)00R!S97)V97(N"B`@("`@*@H@("`@("H@0'9A
M<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]S97)V97(["@H@("`@+RHJ
M"B`@("`@*B!834Q24$,@<V5R=F5R(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7U)00U]X;6QR<&,H*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?4E!#
M*"D["@H@("`@("`@("1T:&ES+3Y?<V5R=F5R(#T@>&UL<G!C7W-E<G9E<E]C
M<F5A=&4H*3L*"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/FQI<W1-971H;V1S*"D@87,@)&UE=&AO9"D@>PH@("`@("`@("`@("!X
M;6QR<&-?<V5R=F5R7W)E9VES=&5R7VUE=&AO9"@D=&AI<RT^7W-E<G9E<BP@
M<W1R7W)E<&QA8V4H)R\G+"`G+B<L("1M971H;V0I+"!A<G)A>2@G2&]R9&5?
M4E!#7WAM;')P8R<L("=?9&ES<&%T8VAE<B<I*3L*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;&5A;G,@=7`@=&AE(%)00R!S97)V97(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-H=71D;W=N*"D*("`@('L*("`@("`@("!X
M;6QR<&-?<V5R=F5R7V1E<W1R;WDH)'1H:7,M/E]S97)V97(I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E<W0@=&\@=&AE('-E
M<G9E<B!A;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@(%1H92!R87<@<F5Q=65S="!S=')I;F<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!834P@96YC;V1E9"!R97-P;VYS
M92!F<F]M('1H92!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E
M<W!O;G-E*"1R97%U97-T*0H@("`@>PH@("`@("`@("1R97-P;VYS92`](&YU
M;&P["B`@("`@("`@<F5T=7)N('AM;')P8U]S97)V97)?8V%L;%]M971H;V0H
M)'1H:7,M/E]S97)V97(L("1R97%U97-T+"`D<F5S<&]N<V4I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5VEL;"!B92!R96=I<W1E<F5D(&%S('1H92!H86YD
M;&5R(&9O<B!A;&P@879A:6QA8FQE(&UE=&AO9',*("`@("`J(&%N9"!W:6QL
M(&-A;&P@=&AE(&%P<')O<')I871E(&9U;F-T:6]N('1H<F]U9V@@=&AE(')E
M9VES=')Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&YA;64@;V8@=&AE
M(&UE=&AO9"!C86QL960@8GD@=&AE(%)00R!R97%U97-T+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@("!4:&4@<&%S<V5D('!A<F%M971E<G,N"B`@
M("`@*B!`<&%R86T@;6EX960@)&1A=&$@("`@(%5N:VYO=VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<W5L="!O9B!T:&4@8V%L;&5D
M(')E9VES=')Y(&UE=&AO9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<W!A
M=&-H97(H)&UE=&AO9"P@)'!A<F%M<RP@)&1A=&$I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&UE=&AO9"`]('-T<E]R97!L
M86-E*"<N)RP@)R\G+"`D;65T:&]D*3L*("`@("`@("!I9B`H(21R96=I<W1R
M>2T^:&%S365T:&]D*"1M971H;V0I*2!["B`@("`@("`@("`@(')E='5R;B!S
M<')I;G1F*%\H(DUE=&AO9"!<(B5S7"(@:7,@;F]T(&1E9FEN960B*2P@)&UE
M=&AO9"D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)')E9VES=')Y
M+3YC86QL*"1M971H;V0L("1P87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)')E<W5L="`]
M(&%R<F%Y*"=F875L=$-O9&4G(#T^("AI;G0I)')E<W5L="T^9V5T0V]D92@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9A=6QT4W1R:6YG)R`]
M/B`D<F5S=6QT+3YG971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@
M86X@6$U,4E!#(')E<75E<W0@86YD('-E;F1S(&ET('1O('1H92!834Q24$,@
M<V5R=F5R+@H@("`@("H*("`@("`J(%1H:7,@<W1A=&EC86QL>2!C86QL960@
M;65T:&]D(&ES(&%C='5A;&QY('1H92!834Q24$,@8VQI96YT+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5R;"`@("`@5&AE('!A=&@@=&\@=&AE
M(%A-3%)00R!S97)V97(@;VX@=&AE(&-A;&QE9"!H;W-T+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;65T:&]D("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!N96-E<W-A<GD@<&%R86UE=&5R<R!F;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&UE=&AO9"!C86QL+@H@("`@("H@0'!A<F%M("1O
M<'1I;VYS("!/<'1I;VYA;"!A<W-O8VEA=&EV92!A<G)A>2!O9B!P87)A;65T
M97)S('=H:6-H(&-A;B!B93H*("`@("`J("`@("`@("`@("`@("`@("`@=7-E
M<B`@("`@("`@("`@+2!"87-I8R!!=71H('5S97)N86UE"B`@("`@*B`@("`@
M("`@("`@("`@("`@('!A<W,@("`@("`@("`@("T@0F%S:6,@075T:"!P87-S
M=V]R9`H@("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]H;W-T("`@("`M
M(%!R;WAY('-E<G9E<B!H;W-T"B`@("`@*B`@("`@("`@("`@("`@("`@('!R
M;WAY7W!O<G0@("`@("T@4')O>'D@<V5R=F5R('!O<G0*("`@("`J("`@("`@
M("`@("`@("`@("`@<')O>'E?=7-E<B`@("`@+2!0<F]X>2!A=71H('5S97)N
M86UE"B`@("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7W!A<W,@("`@("T@
M4')O>'D@875T:"!P87-S=V]R9`H@("`@("H@("`@("`@("`@("`@("`@("!T
M:6UE;W5T("`@("`@("`M($-O;FYE8W1I;VX@=&EM96]U="!I;B!S96-O;F1S
M+@H@("`@("H@("`@("`@("`@("`@("`@("!A;&QO=U)E9&ER96-T<R`M(%=H
M971H97(@=&\@9F]L;&]W(')E9&ER96-T<R!O<B!N;W0*("`@("`J("`@("`@
M("`@("`@("`@("`@;6%X4F5D:7)E8W1S("`@+2!-87@@;G5M8F5R(&]F(')E
M9&ER96-T<R!T;R!F;VQL;W<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("`@("`@("`@("`@5&AE(')E='5R;F5D(')E<W5L="!F<F]M('1H92!M971H
M;V0@;W(@82!014%2"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M97)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<75E<W0H)'5R;"P@)&UE=&AO9"P@)'!A<F%M<R`](&YU;&PL("1O<'1I
M;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("`D;W!T:6]N<ULG;65T:&]D
M)UT@/2`G4$]35"<["B`@("`@("`@)&QA;F=U86=E(#T@:7-S970H)$=,3T)!
M3%-;)VQA;F=U86=E)UTI(#\@)$=,3T)!3%-;)VQA;F=U86=E)UT@.@H@("`@
M("`@("`@("`@("`@("`@("AI<W-E="@D7U-%4E9%4ELG3$%.1R==*2`_("1?
M4T525D526R=,04Y')UT@.B`G)RD["@H@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W1I;65O=70G72DI('L*("`@("`@("`@("`@)&]P=&EO;G-;)W1I
M;65O=70G72`](#4["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)V%L;&]W4F5D:7)E8W1S)UTI*2!["B`@("`@("`@("`@("1O<'1I
M;VYS6R=A;&QO=U)E9&ER96-T<R==(#T@=')U93L*("`@("`@("`@("`@)&]P
M=&EO;G-;)VUA>%)E9&ER96-T<R==(#T@,SL*("`@("`@("!]"@H@("`@("`@
M(')E<75I<F5?;VYC92`G2%144"]297%U97-T+G!H<"<["@H@("`@("`@("1H
M='1P(#T@)FYE=R!(5%107U)E<75E<W0H)'5R;"P@)&]P=&EO;G,I.PH@("`@
M("`@(&EF("@A96UP='DH)&QA;F=U86=E*2D@>PH@("`@("`@("`@("`D:'1T
M<"T^861D2&5A9&5R*"=!8V-E<'0M3&%N9W5A9V4G+"`D;&%N9W5A9V4I.PH@
M("`@("`@('T*("`@("`@("`D:'1T<"T^861D2&5A9&5R*"=5<V5R+4%G96YT
M)RP@)TAO<F1E(%)00R!C;&EE;G0G*3L*("`@("`@("`D:'1T<"T^861D2&5A
M9&5R*"=#;VYT96YT+51Y<&4G+"`G=&5X="]X;6PG*3L*("`@("`@("`D:'1T
M<"T^861D4F%W4&]S=$1A=&$H>&UL<G!C7V5N8V]D95]R97%U97-T*"1M971H
M;V0L("1P87)A;7,I*3L*"B`@("`@("`@)')E<W5L="`]("1H='1P+3YS96YD
M4F5Q=65S="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?2!E;'-E:68@*"1H='1P+3YG971297-P;VYS94-O9&4H*2`A/2`R,#`I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4F5Q=65S
M="!C;W5L9&XG="!B92!A;G-W97)E9"X@4F5T=7)N960@97)R;W)C;V1E.B`B
M*2`N("1H='1P+3YG971297-P;VYS94-O9&4H*2P@)VAO<F1E+F5R<F]R)RD[
M"B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D:'1T<"T^9V5T4F5S<&]N<V5"
M;V1Y*"DL("<\/WAM;"<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").;R!V86QI9"!834P@9&%T82!R971U
M<FYE9"(I+"`G:&]R9&4N97)R;W(G+"!N=6QL+"!N=6QL+"`D:'1T<"T^9V5T
M4F5S<&]N<V5";V1Y*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1R97-P;VYS92`]($!X;6QR<&-?9&5C;V1E*'-U8G-T<B@D:'1T<"T^9V5T
M4F5S<&]N<V5";V1Y*"DL('-T<G!O<R@D:'1T<"T^9V5T4F5S<&]N<V5";V1Y
M*"DL("<\/WAM;"<I*2D["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5S
M<&]N<V4I("8F(&ES<V5T*"1R97-P;VYS95LG9F%U;'13=')I;F<G72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1R97-P
M;VYS95LG9F%U;'13=')I;F<G72P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@
M("`@('T@96QS96EF("AI<U]A<G)A>2@D<F5S<&]N<V4I("8F(&ES<V5T*"1R
M97-P;VYS95LP72D@)B8*("`@("`@("`@("`@("`@("`@("`@(&ES7V%R<F%Y
M*"1R97-P;VYS95LP72D@)B8@:7-S970H)')E<W!O;G-E6S!=6R=F875L=%-T
M<FEN9R==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)')E<W!O;G-E6S!=6R=F875L=%-T<FEN9R==+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')E<W!O
M;G-E.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#
M+W=E8F1A=BYP:'``````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,34V-#4@,3`U,34T,S0Q-#`@,#(Q-S4W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@
M)TA45%`O5V5B1$%6+U-E<G9E<BYP:'`G.PH*+RHJ"B`J(%1H92!(;W)D95]2
M4$-?=V5B9&%V(&-L87-S('!R;W9I9&5S(&$@5V5B1$%6(&EM<&QE;65N=&%T
M:6]N(&]F('1H90H@*B!(;W)D92!24$,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]24$,O4E!#+W=E8F1A=BYP:'`L=B`Q+C$N,3(N-B`R,#`V
M+S`Q+S`Q(#(Q.C(X.C,S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G
M92!(;W)D95]24$,*("HO"F-L87-S($AO<F1E7U)00U]W96)D878@97AT96YD
M<R!(;W)D95]24$,@>PH*("`@("\J*@H@("`@("H@4F5S;W5R8V4@:&%N9&QE
M<B!F;W(@=&AE(%=E8D1!5B!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!(
M5%107U=E8D1!5E]397)V97)?2&]R9&4*("`@("`J+PH@("`@=F%R("1?<V5R
M=F5R.PH*("`@("\J*@H@("`@("H@5V5B1&%V('-E<G9E<B!C;VYS=')U8W1O
M<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@2&]R9&5?4E!#7W=E8F1A=B@I"B`@("!["B`@("`@("`@<&%R
M96YT.CI(;W)D95]24$,H*3L*"B`@("`@("`@)'1H:7,M/E]S97)V97(@/2`F
M;F5W($A45%!?5V5B1$%67U-E<G9E<E](;W)D92@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5N9',@86X@4E!#(')E<75E<W0@=&\@=&AE('-E<G9E<B!A
M;F0@<F5T=7)N<R!T:&4@<F5S=6QT+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@(%1H92!R87<@<F5Q=65S="!S=')I;F<N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!834P@96YC;V1E9"!R97-P;VYS92!F<F]M
M('1H92!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E
M*"1R97%U97-T*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5R=F5R+3Y397)V
M95)E<75E<W0H*3L*("`@("`@("!E>&ET.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5V5B1$%6(&AA;F1L97,@875T:&5N=&EC871I;VX@:6YT97)N86QL>2P@
M<V\@8GEP87-S('1H90H@("`@("H@<WES=&5M+6QE=F5L(&%U=&@@8VAE8VL@
M8GD@:G5S="!R971U<FYI;F<@=')U92!H97)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!A=71H;W)I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*?0H*+RHJ"B`J($AO<F1E(&5X=&5N<VEO;B!O9B!T:&4@8F%S92!(
M5%107U=E8D1!5E]397)V97(@8VQA<W,N"B`J"B`J($!P86-K86=E($AO<F1E
M7U)00PH@*B\*8VQA<W,@2%144%]796)$059?4V5R=F5R7TAO<F1E(&5X=&5N
M9',@2%144%]796)$059?4V5R=F5R('L*"B`@("`O*BH*("`@("`J(%)E86QM
M('-T<FEN9R!T;R!B92!U<V5D(&EN(&%U=&AE;G1I9FEC871I;VX@<&]P=7!S
M"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1H
M='1P7V%U=&A?<F5A;&T@/2`G2&]R9&4@5V5B1$%6)SL*"B`@("`O*BH*("`@
M("`J(%-T<FEN9R!T;R!B92!U<V5D(&EN(")8+41A=BU0;W=E<F5D+4)Y(B!H
M96%D97(*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)&1A=E]P;W=E<F5D7V)Y(#T@)TAO<F1E(%=E8D1!5B!397)V97(G.PH*
M("`@("\J*@H@("`@("H@1T54(&EM<&QE;65N=&%T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@07)R87D@;V8@:6YP=70@86YD
M(&]U='!U="!P87)A;65T97)S+@H@("`@("H@/&)R/CQS=')O;F<^:6YP=70\
M+W-T<F]N9SX\=6P^"B`@("`@*B`\;&D^('!A=&@@+0H@("`@("H@/"]U;#X*
M("`@("`J(#QB<CX\<W1R;VYG/F]U='!U=#PO<W1R;VYG/CQU;#X*("`@("`J
M(#QL:3X@<VEZ92`M"B`@("`@*B`\+W5L/@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<B`@2%144"U3=&%T=7-C;V1E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!'150H)B1O<'1I;VYS*0H@("`@>PH@("`@("`@(&EF("@D;W!T:6]N
M<ULG<&%T:"==(#T]("<O)RD@>PH@("`@("`@("`@("`D;W!T:6]N<ULG;6EM
M971Y<&4G72`]("=H='1P9"]U;FEX+61I<F5C=&]R>2<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7VQI<W0H)&]P
M=&EO;G-;)W!A=&@G72P@,"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%!55"!M971H;V0@:&%N9&QE
M<@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&]P=&EO;G,@(%!A<F%M
M971E<B!P87-S:6YG(&%R<F%Y+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%!55"@F)&]P
M=&EO;G,I"B`@("!["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!04D]01DE.1"!M971H;V0@:&%N9&QE<@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@1V5N97)A;"!P87)A;65T97(@
M<&%S<VEN9R!A<G)A>2X*("`@("`J($!P87)A;2!A<G)A>2`F)&9I;&5S("!2
M971U<FX@87)R87D@9F]R(&9I;&4@<')O<&5R=&EE<RX*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!04D]01DE.1"@D;W!T:6]N<RP@)B1F:6QE<RD*("`@('L*("`@("`@
M("`D;&ES="`]("1T:&ES+3Y?;&ES="@D;W!T:6]N<ULG<&%T:"==+"`D;W!T
M:6]N<ULG9&5P=&@G72D["B`@("`@("`@:68@*"1L:7-T(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M("1F:6QE<ULG9FEL97,G72`]("1L:7-T.PH@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]L:7-T*"1P871H+"`D9&5P=&@I"B`@
M("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)&QI<W0@
M/2!A<G)A>2@*("`@("`@("`@("`@87)R87DH)W!A=&@G(#T^("1T:&ES+3YP
M871H+`H@("`@("`@("`@("`@("`@)W!R;W!S)R`]/B!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=D:7-P;&%Y;F%M92<L("1T
M:&ES+3YP871H*2P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P
M*"=C<F5A=&EO;F1A=&4G+"!T:6UE*"DI+`H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YM:W!R;W`H)V=E=&QA<W1M;V1I9FEE9"<L('1I;64H*2DL"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G<F5S;W5R8V5T>7!E
M)RP@)V-O;&QE8W1I;VXG*2P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;6MP<F]P*"=G971C;VYT96YT='EP92<L("=H='1P9"]U;FEX+61I<F5C=&]R
M>2<I+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O
M;G1E;G1L96YG=&@G+"`P*2DI*3L*("`@("`@("!I9B`H)'!A=&@@/3T@)R\G
M*2!["B`@("`@("`@("`@("1A<'!S(#T@)')E9VES=')Y+3YL:7-T07!P<RAN
M=6QL+"!F86QS92P@4$5235-?4D5!1"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1A<'!S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H
M)&%P<',@87,@)&%P<"D@>PH@("`@("`@("`@("`@("`@:68@*"1R96=I<W1R
M>2T^:&%S365T:&]D*"=B<F]W<V4G+"`D87!P*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1P<F]P<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;6MP<F]P*"=D:7-P;&%Y;F%M92<L(%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)')E9VES=')Y+3YG970H)VYA;64G+"`D87!P*2P@3DQ3.CIG
M971#:&%R<V5T*"DL("=55$8M."<I*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FUK<')O<"@G8W)E871I;VYD871E)RP@=&EM92@I*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T;&%S=&UO
M9&EF:65D)RP@=&EM92@I*2P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FUK<')O<"@G<F5S;W5R8V5T>7!E)RP@)V-O;&QE8W1I;VXG*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T8V]N=&5N
M='1Y<&4G+"`G:'1T<&0O=6YI>"UD:7)E8W1O<GDG*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T8V]N=&5N=&QE;F=T:"<L
M(#`I*3L*("`@("`@("`@("`@("`@("`@("`D:71E;2`](&%R<F%Y*"=P871H
M)R`]/B`D=&AI<RT^<&%T:"`N("<O)R`N("1A<'`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<')O<',G(#T^("1P<F]P<RD["B`@("`@
M("`@("`@("`@("`@("`@)&QI<W1;72`]("1I=&5M.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*'-U8G-T<B@D<&%T:"P@,"P@,2D@/3T@)R\G*2!["B`@("`@("`@
M("`@("`@("`D<&%T:"`]('-U8G-T<B@D<&%T:"P@,2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'!I96-E<R`](&5X<&QO9&4H)R\G+"`D<&%T:"D[
M"B`@("`@("`@("`@("1I=&5M<R`]("1R96=I<W1R>2T^8V%L;$)Y4&%C:V%G
M92@D<&EE8V5S6S!=+"`G8G)O=W-E)RP@87)R87DH)W!A=&@G(#T^("1P871H
M+"`G<')O<&5R=&EE<R<@/3X@87)R87DH)VYA;64G+"`G8G)O=W-E86)L92<L
M("=C;VYT96YT='EP92<L("=C;VYT96YT;&5N9W1H)RP@)V-R96%T960G+"`G
M;6]D:69I960G*2DI.PH@("`@("`@("`@("!I9B`H:7-?82@D:71E;7,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*')E<V5T
M*"1I=&5M<RDI*2!["B`@("`@("`@("`@("`@("`O*B!792!R971U<FX@86X@
M;V)J96-T)W,@8V]N=&5N="X@*B\*("`@("`@("`@("`@("`@(')E='5R;B`D
M:71E;7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&ET
M96US(&%S("1S=6)?<&%T:"`]/B`D:2D@>PH@("`@("`@("`@("`@("`@)'!R
M;W!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O
M<"@G9&ES<&QA>6YA;64G+"!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1I6R=N
M86UE)UTL($Y,4SHZ9V5T0VAA<G-E="@I+"`G551&+3@G*2DL"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G8W)E871I;VYD871E)RP@96UP
M='DH)&E;)V-R96%T960G72D@/R`P(#H@)&E;)V-R96%T960G72DL"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/FUK<')O<"@G9V5T;&%S=&UO9&EF:65D
M)RP@96UP='DH)&E;)VUO9&EF:65D)UTI(#\@,"`Z("1I6R=M;V1I9FEE9"==
M*2P*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;6MP<F]P*"=R97-O=7)C
M971Y<&4G+"`D:5LG8G)O=W-E86)L92==(#\@)V-O;&QE8W1I;VXG(#H@)R<I
M+`H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E
M;G1T>7!E)RP@)&E;)V)R;W=S96%B;&4G72`_("=H='1P9"]U;FEX+61I<F5C
M=&]R>2<@.B`H96UP='DH)&E;)V-O;G1E;G1T>7!E)UTI(#\@)V%P<&QI8V%T
M:6]N+V]C=&5T+7-T<F5A;2<@.B`D:5LG8V]N=&5N='1Y<&4G72DI+`H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YM:W!R;W`H)V=E=&-O;G1E;G1L96YG
M=&@G+"!E;7!T>2@D:5LG8V]N=&5N=&QE;F=T:"==*2`_(#`@.B`D:5LG8V]N
M=&5N=&QE;F=T:"==*2D["B`@("`@("`@("`@("`@("`D:71E;2`](&%R<F%Y
M*"=P871H)R`]/B`G+R<@+B`D<W5B7W!A=&@L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=P<F]P<R<@/3X@)'!R;W!S*3L*("`@("`@("`@("`@
M("`@("1L:7-T6UT@/2`D:71E;3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@:68@*"1D97!T:"D@>PH@("`@("`@("`@("!I9B`H)&1E<'1H
M(#T](#$I('L*("`@("`@("`@("`@("`@("1D97!T:"`](#`["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&%P<"`]/B`D
M:71E;2D@>PH@("`@("`@("`@("`@("`@+R]?;&ES="@D<&%T:"`N("<O)R`N
M("1I=&5M+"`D9&5P=&@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&QI<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C
M:R!A=71H96YT:6-A=&EO;BX@5V4@86QW87ES(')E='5R;B!T<G5E(&AE<F4@
M<VEN8V4@=V4*("`@("`J(&AA;F1L92!P97)M:7-S:6]N<R!B87-E9"!O;B!T
M:&4@<F5S;W5R8V4@=&AA="=S(')E<75E<W1E9"P@8G5T"B`@("`@*B!W92!D
M;R!R96-O<F0@=&AE(&%U=&AE;G1I8V%T960@=7-E<B!F;W(@;&%T97(@=7-E
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@("!!=71H
M96YT:6-A=&EO;B!T>7!E+"!E+F<N(")B87-I8R(@;W(@(F1I9V5S="(*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!4<F%N<VUI='1E9"!U<V5R
M;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4<F%N<VUI
M='1E9"!P87-S=V]R9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M($%U=&AE;G1I8V%T:6]N('-T871U<RX@06QW87ES('1R=64N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-H96-K7V%U=&@H)'1Y<&4L("1U<V5R;F%M92P@)'!A
M<W-W;W)D*0H@("`@>PH@("`@("`@("1A=71H(#T@)D%U=&@Z.G-I;F=L971O
M;B@D1TQ/0D%,4ULG8V]N9B==6R=A=71H)UU;)V1R:79E<B==*3L*("`@("`@
M("!R971U<FX@)&%U=&@M/F%U=&AE;G1I8V%T92@D=7-E<FYA;64L(&%R<F%Y
M*"=P87-S=V]R9"<@/3X@)'!A<W-W;W)D*2D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4E!#+W-Y;F-M;%]W8GAM;"YP
M:'``````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8W,#<@,3`U,34T
M,S0Q-#`@,#(S,C(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+W-Y;F-M;"YP:'`G.PIR97%U:7)E7V]N8V4@)UA-3"]70EA-3"]$
M96-O9&5R+G!H<"<["G)E<75I<F5?;VYC92`G6$U,+U="6$U,+T5N8V]D97(N
M<&AP)SL*"B\J*@H@*B!4:&4@2&]R9&5?4E!#7W-Y;F-M;%]W8GAM;"!C;&%S
M<R!P<F]V:61E<R!A(%-Y;F--3"!I;7!L96UE;G1A=&EO;B!O9B!T:&4*("H@
M2&]R9&4@4E!#('-Y<W1E;2!U<VEN9R!70EA-3"!E;F-O9&EN9RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO4E!#+U)00R]S>6YC;6Q?=V)X;6PN<&AP+'8@
M,2XQ,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL
M<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`
M875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J
M+PIC;&%S<R!(;W)D95]24$-?<WEN8VUL7W=B>&UL(&5X=&5N9',@2&]R9&5?
M4E!#7W-Y;F-M;"!["@H@("`@+RHJ"B`@("`@*B!396YD<R!A;B!24$,@<F5Q
M=65S="!T;R!T:&4@<V5R=F5R(&%N9"!R971U<FYS('1H92!R97-U;'0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<F5Q=65S="`@5&AE(')A=R!R
M97%U97-T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(%="6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R("AB
M:6YA<GDI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q
M=65S="D*("`@('L*("`@("`@("`O*B!#871C:"!A;GD@97)R;W)S+W=A<FYI
M;F=S+VYO=&EC97,@=&AA="!M87D@9V5T('1H<F]W;B!W:&EL90H@("`@("`@
M("`J('!R;V-E<W-I;F<N($1O;B=T('=A;G0@=&\@;&5T(&%N>71H:6YG(&=O
M('1O('1H92!C;&EE;G0@=&AA="=S(&YO=`H@("`@("`@("`J('!A<G0@;V8@
M=&AE('9A;&ED(')E<W!O;G-E+B`J+PH@("`@("`@(&]B7W-T87)T*"D["@H@
M("`@("`@("\J(%9E<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N($QO9W,@5T)8
M34P@<&%C:V5T<R!T;PH@("`@("`@("`J("1T:&ES+3Y?9&5B=6=$:7(N("HO
M"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F)B!I<U]D
M:7(H)'1H:7,M/E]D96)U9T1I<BDI('L*("`@("`@("`@("`@)'!A8VME=$YU
M;2`]($!I;G1V86PH9FEL95]G971?8V]N=&5N=',H)'1H:7,M/E]D96)U9T1I
M<B`N("<O<WEN8VUL+G!A8VME=&YU;2<I*3L*("`@("`@("`@("`@:68@*"%I
M<W-E="@D<&%C:V5T3G5M*2D@>PH@("`@("`@("`@("`@("`@)'!A8VME=$YU
M;2`](#`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F<"`](&9O<&5N
M*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]C;&EE;G1?)R`N("1P86-K
M971.=6T@+B`G+G=B>&UL)RP@)W=B)RD["B`@("`@("`@("`@(&9W<FET92@D
M9G`L("1R97%U97-T*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@
M("`@?0H*"B`@("`@("`@)&1E8V]D97(@/2`F;F5W(%A-3%]70EA-3%]$96-O
M9&5R*"D["B`@("`@("`@)'1H:7,M/E]O=71P=70@/2`F;F5W(%A-3%]70EA-
M3%]%;F-O9&5R*"D["@H@("`@("`@("1D96-O9&5R+3YS971#;VYT96YT2&%N
M9&QE<B@D=&AI<RD["@H@("`@("`@("1R(#T@)&1E8V]D97(M/F1E8V]D92@D
M<F5Q=65S="D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-Y;F--3#H@)R`N
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R+3YG971-97-S86=E
M*"DL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS971697)S:6]N*"1D96-O
M9&5R+3YG971697)S:6]N*"DI.PH@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YS
M971#:&%R<V5T*"1D96-O9&5R+3YG971#:&%R<V5T4W1R*"DI.PH@("`@("`@
M("1R97-P;VYS92`]("1T:&ES+3Y?;W5T<'5T+3YG971/=71P=70H*3L*"B`@
M("`@("`@:68@*&ES7V$H)')E<W!O;G-E+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-P;VYS92P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`D<F5S
M<&]N<V4@/2`D<F5S<&]N<V4M/F=E=$UE<W-A9V4H*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]D96)U9T1I<BD@)B8@:7-?9&ER
M*"1T:&ES+3Y?9&5B=6=$:7(I*2!["B`@("`@("`@("`@("1F<"`](&9O<&5N
M*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y;F-M;%]S97)V97)?)R`N("1P86-K
M971.=6T@+B`G+G=B>&UL)RP@)W=B)RD["B`@("`@("`@("`@(&9W<FET92@D
M9G`L("1R97-P;VYS92D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH*("`@
M("`@("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3Y?9&5B=6=$:7(@+B`G+W-Y
M;F-M;"YP86-K971N=6TG+"`G=R<I.PH@("`@("`@("`@("!I9B`H)&9P*2![
M"B`@("`@("`@("`@("`@("!F=W)I=&4H)&9P+"`K*R1P86-K971.=6TI.PH@
M("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*"B`@
M("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!T:&4@;W5T<'5T(&)U9F9E<B!T
M:&%T('=E('-T87)T960@86)O=F4L(&%N9"!L;V<@86YY=&AI;F<*("`@("`@
M("`@*B!T:&%T(&-A;64@=7`@9F]R(&QA=&5R(&1E8G5G9VEN9RX@*B\*("`@
M("`@("`D97)R;W),;V=G:6YG(#T@;V)?9V5T7V-L96%N*"D["B`@("`@("`@
M:68@*"%E;7!T>2@D97)R;W),;V=G:6YG*2D@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G4WEN8TU,.B!C875G:'0@;W5T<'5T/2<@+B`D97)R
M;W),;V=G:6YG+`H@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M<&]N<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!#;VYT
M96YT+51Y<&4@;V8@=&AE(')E<W!O;G-E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@34E-12!#;VYT96YT+51Y<&4@;V8@=&AE(%)00R!R
M97-P;VYS92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V5#;VYT
M96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A<'!L:6-A=&EO;B]V
M;F0N<WEN8VUL*W=B>&UL)SL*("`@('T*"GT*````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U)00R]S>6YC;6PN<&AP````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W-C0V(#$P-3$U
M-#,T,30P(#`R,C`Q-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=3>6YC34PN<&AP)SL*
M<F5Q=6ER95]O;F-E("=3>6YC34PO4W1A=&4N<&AP)SL*<F5Q=6ER95]O;F-E
M("=3>6YC34PO0V]M;6%N9"]3=&%T=7,N<&AP)SL*"B\J*@H@*B!4:&4@2&]R
M9&5?4E!#7W-Y;F-M;"!C;&%S<R!P<F]V:61E<R!A(%-Y;F--3"!I;7!L96UE
M;G1A=&EO;B!O9B!T:&4@2&]R9&4*("H@4E!#('-Y<W1E;2X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4E!#+U)00R]S>6YC;6PN<&AP+'8@,2XQ."XQ,"XW
M(#(P,#8O,#4O,#$@,3(Z,#4Z,3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS
M0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!!
M;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4E!#"B`J+PIC;&%S<R!(
M;W)D95]24$-?<WEN8VUL(&5X=&5N9',@2&]R9&5?4E!#('L*"B`@("`O*BH*
M("`@("`J($]U='!U="!#;VYT96YT2&%N9&QE<B!U<V5D('1O(&]U='!U="!8
M34P@979E;G1S+@H@("`@("H*("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*
M("`@('9A<B`D7V]U='!U=#L*"B`@("`O*BH*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]X;6Q3=&%C:R`](#`["@H@("`@+RHJ"B`@
M("`@*B!$96)U9R!D:7)E8W1O<GDL(&EF('-E="!W:6QL('-T;W)E(&-O<&EE
M<R!O9B!A;&P@<&%C:V5T<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)%]D96)U9T1I<B`]("<O=&UP+W-Y;F,G.PH*("`@
M("\J*@H@("`@("H@1&5F875L="!C:&%R86-T97(@<V5T+B`@3VYL>2!S=7!P
M;W)T<R!55$8M."A!4T-)23\I+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7V-H87)S970@/2`G551&+3@G.PH*("`@("\J
M*@H@("`@("H@4WEN8TU,(&AA;F1L97,@875T:&5N=&EC871I;VX@:6YT97)N
M86QL>2P@<V\@8GEP87-S('1H92!24$,@9G)A;65W;W)K"B`@("`@*B!A=71H
M(&-H96-K(&)Y(&IU<W0@<F5T=7)N:6YG('1R=64@:&5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@875T:&]R:7IE*"D*("`@('L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F1S(&%N(%)00R!R97%U
M97-T('1O('1H92!S97)V97(@86YD(')E='5R;G,@=&AE(')E<W5L="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R97%U97-T("!4:&4@<F%W(')E
M<75E<W0@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@6$U,(&5N8V]D960@<F5S<&]N<V4@9G)O;2!T:&4@<V5R=F5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D<F5Q=65S="D*("`@('L*
M("`@("`@("`O*B!#871C:"!A;GD@97)R;W)S+W=A<FYI;F=S+VYO=&EC97,@
M=&AA="!M87D@9V5T('1H<F]W;B!W:&EL90H@("`@("`@("`J('!R;V-E<W-I
M;F<N($1O;B=T('=A;G0@=&\@;&5T(&%N>71H:6YG(&=O('1O('1H92!C;&EE
M;G0@=&AA="=S(&YO=`H@("`@("`@("`J('!A<G0@;V8@=&AE('9A;&ED(')E
M<W!O;G-E+B`J+PH@("`@("`@(&]B7W-T87)T*"D["@H@("`@("`@("\J(%9E
M<GD@=7-E9G5L(&9O<B!D96)U9V=I;F<N($QO9W,@5T)834P@<&%C:V5T<R!T
M;PH@("`@("`@("`J("1T:&ES+3Y?9&5B=6=$:7(N("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7V1E8G5G1&ER*2`F)B!I<U]D:7(H)'1H:7,M/E]D
M96)U9T1I<BDI('L*("`@("`@("`@("`@)'!A8VME=$YU;2`]($!I;G1V86PH
M9FEL95]G971?8V]N=&5N=',H)'1H:7,M/E]D96)U9T1I<B`N("<O<WEN8VUL
M+G!A8VME=&YU;2<I*3L*("`@("`@("`@("`@:68@*"%I<W-E="@D<&%C:V5T
M3G5M*2D@>PH@("`@("`@("`@("`@("`@)'!A8VME=$YU;2`](#`["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1F(#T@0&9O<&5N*"1T:&ES+3Y?9&5B
M=6=$:7(@+B`G+W-Y;F-M;%]C;&EE;G1?)R`N("1P86-K971.=6T@+B`G+GAM
M;"<L("=W8B<I.PH@("`@("`@("`@("!I9B`H)&8I('L*("`@("`@("`@("`@
M("`@(&9W<FET92@D9BP@)')E<75E<W0I.PH@("`@("`@("`@("`@("`@9F-L
M;W-E*"1F*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=834PO5T)834PO0V]N=&5N=$AA;F1L97(N<&AP)SL*("`@
M("`@("`D=&AI<RT^7V]U='!U="`]("9N97<@6$U,7U="6$U,7T-O;G1E;G1(
M86YD;&5R*"D["@H@("`@("`@("1T:&ES+3Y?<&%R<V4H)')E<75E<W0I.PH@
M("`@("`@("1R97-P;VYS92`]("1T:&ES+3Y?;W5T<'5T+3YG971/=71P=70H
M*3L*"B`@("`@("`@+RH@5F5R>2!U<V5F=6P@9F]R(&1E8G5G9VEN9RX@*B\*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?9&5B=6=$:7(I("8F(&ES7V1I
M<B@D=&AI<RT^7V1E8G5G1&ER*2D@>PH@("`@("`@("`@("`D9B`]($!F;W!E
M;B@D=&AI<RT^7V1E8G5G1&ER("X@)R]S>6YC;6Q?<V5R=F5R7R<@+B`D<&%C
M:V5T3G5M("X@)RYX;6PG+"`G=V(G*3L*("`@("`@("`@("`@:68@*"1F*2![
M"B`@("`@("`@("`@("`@("!F=W)I=&4H)&8L("1R97-P;VYS92D["B`@("`@
M("`@("`@("`@("!F8VQO<V4H)&8I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D9G`@/2!`9F]P96XH)'1H:7,M/E]D96)U9T1I<B`N("<O<WEN8VUL
M+G!A8VME=&YU;2<L("=W)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@
M("`@("`@("`@("`@(&9W<FET92@D9G`L("LK)'!A8VME=$YU;2D["B`@("`@
M("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@0VQE87(@=&AE(&]U='!U="!B=69F97(@=&AA="!W
M92!S=&%R=&5D(&%B;W9E+"!A;F0@;&]G(&%N>71H:6YG"B`@("`@("`@("H@
M=&AA="!C86UE('5P(&9O<B!L871E<B!D96)U9V=I;F<N("HO"B`@("`@("`@
M)&5R<F]R3&]G9VEN9R`](&]B7V=E=%]C;&5A;B@I.PH@("`@("`@(&EF("@A
M96UP='DH)&5R<F]R3&]G9VEN9RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO
M9TUE<W-A9V4H)U-Y;F--3#H@8V%U9VAT(&]U='!U=#TG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H(EQN(BP@)R`G+"`D
M97)R;W),;V=G:6YG*2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$
M14)51RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W!O;G-E.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]P87)S92@D>&UL*0H@("`@>PH@("`@("`@
M("\J('1R>2!T;R!E>'1R86-T(&-H87)S970@9G)O;2!834P@=&5X="`J+PH@
M("`@("`@(&EF*'!R96=?;6%T8V@H)R]>7',J/%P_>&UL6UX^72IE;F-O9&EN
M9UQS*CU<<RHB*%M>(ETJ*2(O:2<L"B`@("`@("`@("`@("`@("`D>&UL+"`D
M;2DI('L*("`@("`@("`@("`@)'1H:7,M/E]C:&%R<V5T(#T@)&U;,5T["B`@
M("`@("`@?0H@("`@("`@($Y,4SHZ<V5T0VAA<G-E="@D=&AI<RT^7V-H87)S
M970I.PH@("`@("`@(%-T<FEN9SHZ<V5T1&5F875L=$-H87)S970H)'1H:7,M
M/E]C:&%R<V5T*3L*"B`@("`@("`@+RH@0W)E871E('1H92!834P@<&%R<V5R
M(&%N9"!S970@;65T:&]D(')E9F5R96YC97,N("HO"B`@("`@("`@)'1H:7,M
M/E]P87)S97(@/2!X;6Q?<&%R<V5R7V-R96%T95]N<R@D=&AI<RT^7V-H87)S
M970I.PH@("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES+3Y?<&%R<V5R+"`D
M=&AI<RD["B`@("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1T:&ES+3Y?
M<&%R<V5R+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH@("`@
M("`@('AM;%]S971?96QE;65N=%]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G
M7W-T87)T16QE;65N="<L("=?96YD16QE;65N="<I.PH@("`@("`@('AM;%]S
M971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]C
M:&%R86-T97)S)RD["B`@("`@("`@>&UL7W-E=%]P<F]C97-S:6YG7VEN<W1R
M=6-T:6]N7VAA;F1L97(H)'1H:7,M/E]P87)S97(L("<G*3L*("`@("`@("!X
M;6Q?<V5T7V5X=&5R;F%L7V5N=&ET>5]R969?:&%N9&QE<B@D=&AI<RT^7W!A
M<G-E<BP@)R<I.PH*("`@("`@("!I9B`H(7AM;%]P87)S92@D=&AI<RT^7W!A
M<G-E<BP@)'AM;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*'-P<FEN=&8H)UA-3"!E<G)O<CH@)7,@870@;&EN92`E9"<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM
M;%]E<G)O<E]S=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1T:&ES+3Y?<&%R
M<V5R*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D=&AI<RT^7W!A
M<G-E<BDI*3L*("`@("`@("!]"@H@("`@("`@('AM;%]P87)S97)?9G)E92@D
M=&AI<RT^7W!A<G-E<BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W-T87)T16QE
M;65N="@D<&%R<V5R+"`D=&%G+"`D871T<FEB=71E<RD*("`@('L*("`@("`@
M("!L:7-T*"1U<FDL("1N86UE*2`]("1T:&ES+3Y?<W!L:7154DDH)'1A9RD[
M"@H@("`@("`@("1T:&ES+3YS=&%R=$5L96UE;G0H)'5R:2P@)&YA;64L("1A
M='1R:6)U=&5S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?8VAA<F%C=&5R<R@D
M<&%R<V5R+"`D8VAA<G,I"B`@("!["B`@("`@("`@)'1H:7,M/F-H87)A8W1E
M<G,H)&-H87)S*3L*("`@('T*"B`@("!F=6YC=&EO;B!?96YD16QE;65N="@D
M<&%R<V5R+"`D=&%G*0H@("`@>PH@("`@("`@(&QI<W0H)'5R:2P@)&YA;64I
M(#T@)'1H:7,M/E]S<&QI=%5222@D=&%G*3L*"B`@("`@("`@)'1H:7,M/F5N
M9$5L96UE;G0H)'5R:2P@)&YA;64I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S
M<&QI=%5222@D=&%G*0H@("`@>PH@("`@("`@("1P87)T<R`](&5X<&QO9&4H
M)SHG+"`D=&%G*3L*("`@("`@("`D;F%M92`](&%R<F%Y7W!O<"@D<&%R=',I
M.PH@("`@("`@("1U<FD@/2!I;7!L;V1E*"<Z)RP@)'!A<G1S*3L*("`@("`@
M("!R971U<FX@87)R87DH)'5R:2P@)&YA;64I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@0V]N=&5N="U4>7!E(&]F('1H92!R97-P;VYS
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@0V]N
M=&5N="U4>7!E(&]F('1H92!24$,@<F5S<&]N<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%)E<W!O;G-E0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@
M(')E='5R;B`G87!P;&EC871I;VXO=FYD+G-Y;F-M;"MX;6PG.PH@("`@?0H*
M("`@(&9U;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T
M=')S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>&UL4W1A8VLK*SL*"B`@("`@
M("`@<W=I=&-H("@D=&AI<RT^7WAM;%-T86-K*2!["B`@("`@("`@8V%S92`Q
M.@H@("`@("`@("`@("`O+R`\4WEN8TU,/@H@("`@("`@("`@("`O+R!$969I
M;F5D(&EN(%-Y;F--3"!297!R97-E;G1A=&EO;B!0<F]T;V-O;"P@=F5R<VEO
M;B`Q+C$@-2XR+C$*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70M/G-T87)T
M16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@+R\@16ET:&5R
M(#Q3>6YC34P^/%-Y;F-(9'(^(&]R(#Q3>6YC34P^/%-Y;F-";V1Y/@H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I*2![
M"B`@("`@("`@("`@("`@("`O+R!)9B!N;W0@9&5F:6YE9"!T:&5N(&-R96%T
M92!3>6YC2&1R+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT2&%N
M9&QE<B`]("9N97<@4WEN8TU,7U-Y;F-M;$AD<B@I.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^<V5T3W5T<'5T*"1T:&ES+3Y?
M;W5T<'5T*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYT96YT2&%N9&QE<BT^<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D
M871T<G,I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=$AA;F1L97(I
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G1(86YD;&5R+3YS
M=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@
M("`@("`@<W=I=&-H("@D=&AI<RT^7WAM;%-T86-K*2!["B`@("`@("`@8V%S
M92`Q.@H@("`@("`@("`@("`O+R`\+U-Y;F--3#X*("`@("`@("`@("`@+R\@
M1&5F:6YE9"!I;B!3>6YC34P@4F5P<F5S96YT871I;VX@4')O=&]C;VPL('9E
M<G-I;VX@,2XQ(#4N,BXQ"B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T+3YE
M;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@+R\@16ET:&5R(#PO4WEN
M8TAD<CX\+U-Y;F--3#X@;W(@/"]3>6YC0F]D>3X\+U-Y;F--3#X*("`@("`@
M("`@("`@:68@*"1E;&5M96YT(#T]("=3>6YC2&1R)RD@>PH@("`@("`@("`@
M("`@("`@+R\@5&AE;B!W92!G970@=&AE('-T871E(&9R;VT@4WEN8TU,2&1R
M+"!A;F0@8W)E871E(&$@;F5W"B`@("`@("`@("`@("`@("`O+R!3>6YC34Q"
M;V1Y+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^
M96YD16QE;65N="@D=7)I+"`D96QE;65N="D["@H@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]C;VYT96YT2&%N9&QE<BD["@H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<B`]("9N97<@4WEN8TU,7U-Y;F-M
M;$)O9'DH*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L
M97(M/G-E=$]U='!U="@D=&AI<RT^7V]U='!U="D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O+R!.;R!L;VYG97(@=7-E9"X*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L97(M/F5N9$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@("`@("`@("`@("`@=6YS970H)'1H
M:7,M/E]C;VYT96YT2&%N9&QE<BD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("\O(#PO
M*CX\+U-Y;F-(9'(^/"]3>6YC34P^(&]R(#PO*CX\+U-Y;F-";V1Y/CPO4WEN
M8TU,/@H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C;VYT96YT2&%N
M9&QE<BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=$AA;F1L
M97(M/F5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?8VAA<G,I*2!["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?8VAA<G,I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]X;6Q3=&%C
M:RTM.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C;VYT96YT2&%N9&QE<BDI
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYT96YT2&%N9&QE<BT^8VAA<F%C
M=&5R<R@D<W1R*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<F%I
M<V5%<G)O<B@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B!(;W)D93HZ;&]G
M365S<V%G92@D<W1R+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T52
M4BD["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]24$,O<V]A<"YP:'``````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q-3$U-R`Q,#4Q-30S-#$T,"`P,C$T-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!(;W)D95]24$-?<V]A<"!C;&%S<R!P<F]V:61E<R!A;B!33T%0(&EM<&QE
M;65N=&%T:6]N(&]F('1H90H@*B!(;W)D92!24$,@<WES=&5M+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]24$,O4E!#+W-O87`N<&AP+'8@,2XQ,RXQ,"XW
M(#(P,#8O,#$O,#$@,C$Z,C@Z,S,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(
M;W)D95]24$,*("HO"F-L87-S($AO<F1E7U)00U]S;V%P(&5X=&5N9',@2&]R
M9&5?4E!#('L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AA;F1L97(@9F]R
M('1H92!24$,@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@;V)J96-T"B`@
M("`@*B\*("`@('9A<B`D7W-E<G9E<CL*"B`@("`O*BH*("`@("`J($AA<V@@
M:&]L9&EN9R!A;&P@;65T:&]D<R<@<VEG;F%T=7)E<RX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7U]D:7-P871C:%]M87`@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4T]!4"!S97)V97(@8V]N<W1R
M=6-T;W(*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@2&]R9&5?4E!#7W-O87`H)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"1P87)A;7,@/3T@)W=S9&PG('Q\("1P87)A;7,@
M/3T@)V1I<V-O)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V%U=&AO<FEZ92`]
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT.CI(;W)D95]24$,H
M*3L*"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=33T%0+U-E<G9E<BYP:'`G.PH@("`@("`@("1T:&ES+3Y?<V5R
M=F5R(#T@)FYE=R!33T%07U-E<G9E<B@I.PH@("`@("`@("1T:&ES+3Y?<V5R
M=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&:6QL<R!A(&AA<V@@=&AA="!I<R!U<V5D(&)Y('1H92!33T%0
M('-E<G9E<B!W:71H('1H92!S:6=N871U<F5S(&]F"B`@("`@*B!A;&P@879A
M:6QA8FQE(&UE=&AO9',N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971U<$1I
M<W!A=&-H36%P*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH*
M("`@("`@("`D;65T:&]D<R`]("1R96=I<W1R>2T^;&ES=$UE=&AO9',H*3L*
M("`@("`@("!F;W)E86-H("@D;65T:&]D<R!A<R`D;65T:&]D*2!["B`@("`@
M("`@("`@("1S:6=N871U<F4@/2`D<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D
M;65T:&]D*3L*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<VEG;F%T=7)E
M*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&UE=&AO9"`]('-T<E]R97!L86-E*"<O)RP@)RXG+"`D
M;65T:&]D*3L*("`@("`@("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R1M
M971H;V1=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G:6XG(#T^("1S:6=N
M871U<F5;,%TL"B`@("`@("`@("`@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T
M<'5T)R`]/B`D<VEG;F%T=7)E6S%=*0H@("`@("`@("`@("`I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/E]?='EP961E9B`]("1R96=I<W1R>2T^;&ES
M=%1Y<&5S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!S
M:6=N871U<F4@;V8@82!M971H;V0N"B`@("`@*B!);G1E<FYA;&QY('5S960@
M8GD@=&AE(%-/05`@<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&UE=&AO9"`@02!M971H;V0@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<G)A>2!D97-C<FEB:6YG('1H92!M971H;V0G<R!S
M:6=N871U<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]?9&ES<&%T8V@H)&UE
M=&AO9"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@
M("1M971H;V0@/2!S=')?<F5P;&%C92@G+B<L("<O)RP@)&UE=&AO9"D["@H@
M("`@("`@("1S:6=N871U<F4@/2`D<F5G:7-T<GDM/F=E=%-I9VYA='5R92@D
M;65T:&]D*3L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1S:6=N871U<F4I*2![
M"B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=I;B<@/3X@)'-I9VYA='5R95LP72P*("`@("`@("`@
M("`@("`@("`@("`@)V]U="<@/3X@87)R87DH)V]U='!U="<@/3X@)'-I9VYA
M='5R95LQ72DI.PH@("`@?0H*("`@("\J*@H@("`@("H@5VEL;"!B92!R96=I
M<W1E<F5D(&%S('1H92!H86YD;&5R(&9O<B!A;&P@;65T:&]D<R!C86QL960@
M:6X@=&AE"B`@("`@*B!33T%0('-E<G9E<B!A;F0@=VEL;"!C86QL('1H92!A
M<'!R;W!R:6%T92!F=6YC=&EO;B!T:')O=6=H('1H92!R96=I<W1R>2X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M971H;V0@("`@5&AE(&YA;64@;V8@=&AE(&UE=&AO9"!C
M86QL960@8GD@=&AE(%)00R!R97%U97-T+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@("`@(%1H92!P87-S960@<&%R86UE=&5R<RX*("`@("`J($!P
M87)A;2!M:7AE9"`D9&%T82`@("`@("!5;FMN;W=N+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@("`@("`@("`@("!4:&4@<F5S=6QT(&]F('1H92!C
M86QL960@<F5G:7-T<GD@;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M9&ES<&%T8VAE<B@D;65T:&]D+"`D<&%R86US*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D<F5G:7-T<GD["B`@("`@("`@)&UE=&AO9"`]('-T<E]R97!L86-E
M*"<N)RP@)R\G+"`D;65T:&]D*3L*"B`@("`@("`@:68@*"$D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@D;65T:&]D*2D@>PH@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9BA?*")-971H;V0@7"(E<UPB(&ES(&YO="!D969I;F5D(BDL("1M971H
M;V0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S97)V97(M/F)I;F17
M4T1,*$AO<F1E.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R
M9&4G*2`N("<O<G!C+G!H<#]W<V1L)RP@=')U92P@9F%L<V4I*3L*("`@("`@
M("!R971U<FX@)')E9VES=')Y+3YC86QL*"1M971H;V0L("1P87)A;7,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&%K97,@86X@4E!#(')E<75E<W0@86YD
M(')E='5R;G,@=&AE(')E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("!4:&4@<F%W(')E<75E<W0@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@4W1R:6YG('-P96-I9GEI;F<@=VAA="!K:6YD(&]F(&1A=&$@=&\@
M<F5T=7)N+B!$969A=6QT<PH@("`@("H@("`@("`@("`@("`@("`@=&\@4T]!
M4"!R97%U97-T+B!0;W-S:6)L92!O=&AE<B!V86QU97,Z(")W9'-L(B!A;F0*
M("`@("`J("`@("`@("`@("`@("`@(")D:7-C;R(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!834P@96YC;V1E9"!R97-P;VYS92!F<F]M
M('1H92!S97)V97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E
M*"1R97%U97-T+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W-E<G9E<BT^861D3V)J96-T36%P*"1T:&ES+"`G=7)N.FAO<F1E)RD[
M"@H@("`@("`@(&EF("@A)'!A<F%M<RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7W-E<G9E<BT^<V5T0V%L;$AA;F1L97(H87)R87DH)'1H:7,L("=?9&ES<&%T
M8VAE<B<I*3L*("`@("`@("`@("`@+RH@5V4@8V%N)W0@=7-E(%5T:6PZ.F)U
M9F9E<D]U='!U="@I(&AE<F4@9F]R('-O;64@<F5A<V]N+B`J+PH@("`@("`@
M("`@("!O8E]S=&%R="@I.PH@("`@("`@("`@("`D=&AI<RT^7W-E<G9E<BT^
M<V5R=FEC92@D<F5Q=65S="D["B`@("`@("`@("`@("1O=71P=70@/2!O8E]G
M971?8V]N=&5N=',H*3L*("`@("`@("`@("`@;V)?96YD7V-L96%N*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=33T%0
M+T1I<V-O+G!H<"<["B`@("`@("`@("`@("1D:7-C;R`](&YE=R!33T%07T1)
M4T-/7U-E<G9E<B@D=&AI<RT^7W-E<G9E<BP@)VAO<F1E)RD["B`@("`@("`@
M("`@(&EF("@D<&%R86US(#T]("=W<V1L)RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S971U<$1I<W!A=&-H36%P*"D["B`@("`@("`@("`@("`@("`D
M;W5T<'5T(#T@)&1I<V-O+3YG97174T1,*"D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@)&1I<V-O+3YG971$25-#
M3R@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!33T%0
M(')E<75E<W0@86YD('-E;F1S(&ET('1O('1H92!33T%0('-E<G9E<BX*("`@
M("`J"B`@("`@*B!4:&ES('-T871I8V%L;'D@8V%L;&5D(&UE=&AO9"!I<R!A
M8W1U86QL>2!T:&4@4T]!4"!C;&EE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=7)L("`@("!4:&4@<&%T:"!T;R!T:&4@4T]!4"!S97)V97(@
M;VX@=&AE(&-A;&QE9"!H;W-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T
M:&]D("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!N96-E<W-A<GD@<&%R
M86UE=&5R<R!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&UE=&AO9"!C86QL+@H@("`@("H@0'!A<F%M("1O<'1I;VYS("!/<'1I;VYA
M;"!A<W-O8VEA=&EV92!A<G)A>2!O9B!P87)A;65T97)S('=H:6-H(&-A;B!B
M93H*("`@("`J("`@("`@("`@("`@("`@("`@=7-E<B`@("`@("`@("`@("`@
M("`M($)A<VEC($%U=&@@=7-E<FYA;64*("`@("`J("`@("`@("`@("`@("`@
M("`@<&%S<R`@("`@("`@("`@("`@("`M($)A<VEC($%U=&@@<&%S<W=O<F0*
M("`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?:&]S="`@("`@("`@("`M
M(%!R;WAY('-E<G9E<B!H;W-T"B`@("`@*B`@("`@("`@("`@("`@("`@('!R
M;WAY7W!O<G0@("`@("`@("`@+2!0<F]X>2!S97)V97(@<&]R=`H@("`@("H@
M("`@("`@("`@("`@("`@("!P<F]X>5]U<V5R("`@("`@("`@("T@4')O>'D@
M875T:"!U<V5R;F%M90H@("`@("H@("`@("`@("`@("`@("`@("!P<F]X>5]P
M87-S("`@("`@("`@("T@4')O>'D@875T:"!P87-S=V]R9`H@("`@("H@("`@
M("`@("`@("`@("`@("!T:6UE;W5T("`@("`@("`@("`@("T@0V]N;F5C=&EO
M;B!T:6UE;W5T(&EN('-E8V]N9',N"B`@("`@*B`@("`@("`@("`@("`@("`@
M(&%L;&]W4F5D:7)E8W1S("`@("`@+2!7:&5T:&5R('1O(&9O;&QO=R!R961I
M<F5C=',@;W(@;F]T"B`@("`@*B`@("`@("`@("`@("`@("`@(&UA>%)E9&ER
M96-T<R`@("`@("`@+2!-87@@;G5M8F5R(&]F(')E9&ER96-T<R!T;R!F;VQL
M;W<*("`@("`J("`@("`@("`@("`@("`@("`@;F%M97-P86-E"B`@("`@*B`@
M("`@("`@("`@("`@("`@('-O87!A8W1I;VX*("`@("`J("`@("`@("`@("`@
M("`@("`@9G)O;2`@("`@("`@("`@("`@("`M(%--5%`L(&9R;VT@861D<F5S
M<PH@("`@("H@("`@("`@("`@("`@("`@("!T<F%N<V9E<BUE;F-O9&EN9R`@
M("T@4TU44"P@<V5T<R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($-O;G1E;G0M5')A;G-F97(M16YC;V1I;F<@
M:&5A9&5R"B`@("`@*B`@("`@("`@("`@("`@("`@('-U8FIE8W0@("`@("`@
M("`@("`@+2!33510+"!S=6)J96-T(&AE861E<@H@("`@("H@("`@("`@("`@
M("`@("`@("!H96%D97)S("`@("`@("`@("`@("T@4TU44"P@87)R87DM:&%S
M:"!O9B!E>'1R82!S;71P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!H96%D97)S"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@("`@("`@("`@(%1H92!R971U<FYE9"!R97-U;'0@9G)O;2!T
M:&4@;65T:&]D(&]R(&$@4$5!4@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R97%U97-T*"1U<FPL("1M971H;V0L("1P87)A;7,@/2!N=6QL
M+"`D;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG=&EM96]U="==*2D@>PH@("`@("`@("`@("`D;W!T:6]N
M<ULG=&EM96]U="==(#T@-3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG86QL;W=2961I<F5C=',G72DI('L*("`@("`@("`@("`@
M)&]P=&EO;G-;)V%L;&]W4F5D:7)E8W1S)UT@/2!T<G5E.PH@("`@("`@("`@
M("`D;W!T:6]N<ULG;6%X4F5D:7)E8W1S)UT@("`](#,["B`@("`@("`@?0H*
M("`@("`@("!R97%U:7)E7V]N8V4@)U-/05`O0VQI96YT+G!H<"<["B`@("`@
M("`@)'-O87`@/2`F;F5W(%-/05!?0VQI96YT*"1U<FPL(&9A;'-E+"!F86QS
M92P@)&]P=&EO;G,I.PH@("`@("`@(')E='5R;B`D<V]A<"T^8V%L;"@D;65T
M:&]D+"`D<&%R86US+"`D;W!T:6]N<ULG;F%M97-P86-E)UTI.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-
M;V1E````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$T,"`P,C(S,S$`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T-I<&AE<B]B;&]W9FES:"YP:'``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#4W-3`T(#$P-3$U-#,T,30P(#`R,S$Q,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($-I<&AE<E]B;&]W9FES:#HZ(&-L87-S(&EM<&QE;65N=',@=&AE($-I
M<&AE<B!I;G1E<F9A8V4@96YC<GEP=&EO;B!D871A"B`J('5S:6YG('1H92!"
M;&]W9FES:"!A;&=O<FET:&TN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I
M<&AE<B]#:7!H97(O8FQO=V9I<V@N<&AP+'8@,2XQ-"XQ,BXY(#(P,#8O,#$O
M,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`
M<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]B
M;&]W9FES:"!E>'1E;F1S($AO<F1E7T-I<&AE<B!["@H@("`@+RHJ"B`@("`@
M*B!0:2!!<G)A>0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1P(#T@87)R87DH"B`@("`@("`@,'@R-#-&-D$X."P@,'@X-4$S
M,#A$,RP@,'@Q,S$Y.$$R12P@,'@P,S<P-S,T-"P*("`@("`@("`P>$$T,#DS
M.#(R+"`P>#(Y.48S,40P+"`P>#`X,D5&03DX+"`P>$5#-$4V0S@Y+`H@("`@
M("`@(#!X-#4R.#(Q138L(#!X,SA$,#$S-S<L(#!X0D4U-#8V0T8L(#!X,S1%
M.3!#-D,L"B`@("`@("`@,'A#,$%#,CE"-RP@,'A#.3=#-3!$1"P@,'@S1C@T
M1#5"-2P@,'A"-30W,#DQ-RP*("`@("`@("`P>#DR,39$-40Y+"`P>#@Y-SE&
M0C%"*3L*"B`@("`O*BH*("`@("`J(%,@0F]X("AS,2D*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S$@/2!A<G)A>2@*("`@
M("`@("`P>$0Q,S$P0D$V+"`P>#DX1$9"-4%#+"`P>#)&1D0W,D1"+"`P>$0P
M,4%$1D(W+`H@("`@("`@(#!X0CA%,4%&140L(#!X-D$R-C=%.38L(#!X0D$W
M0SDP-#4L(#!X1C$R0S=&.3DL"B`@("`@("`@,'@R-$$Q.3DT-RP@,'A",SDQ
M-D-&-RP@,'@P.#`Q1C)%,BP@,'@X-3A%1D,Q-BP*("`@("`@("`P>#8S-CDR
M,$0X+"`P>#<Q-3<T138Y+"`P>$$T-3A&14$S+"`P>$8T.3,S1#=%+`H@("`@
M("`@(#!X,$0Y-3<T.$8L(#!X-S(X14(V-3@L(#!X-S$X0D-$-3@L(#!X.#(Q
M-31!144L"B`@("`@("`@,'@W0C4T030Q1"P@,'A#,C5!-3E"-2P@,'@Y0S,P
M1#4S.2P@,'@R048R-C`Q,RP*("`@("`@("`P>$,U1#%",#(S+"`P>#(X-C`X
M-48P+"`P>$-!-#$W.3$X+"`P>$(X1$(S.$5&+`H@("`@("`@(#!X.$4W.41#
M0C`L(#!X-C`S03$X,$4L(#!X-D,Y13!%.$(L(#!X0C`Q13A!,T4L"B`@("`@
M("`@,'A$-S$U-S=#,2P@,'A"1#,Q-$(R-RP@,'@W.$%&,D9$02P@,'@U-38P
M-4,V,"P*("`@("`@("`P>$4V-34R-48S+"`P>$%!-35!0CDT+"`P>#4W-#@Y
M.#8R+"`P>#8S13@Q-#0P+`H@("`@("`@(#!X-35#03,Y-D$L(#!X,D%!0C$P
M0C8L(#!X0C1#0S5#,S0L(#!X,3$T,44X0T4L"B`@("`@("`@,'A!,34T.#9!
M1BP@,'@W0S<R13DY,RP@,'A",T5%,30Q,2P@,'@V,S9&0D,R02P*("`@("`@
M("`P>#)"03E#-35$+"`P>#<T,3@S,48V+"`P>$-%-4,S13$V+"`P>#E".#<Y
M,S%%+`H@("`@("`@(#!X049$-D)!,S,L(#!X-D,R-$-&-4,L(#!X-T$S,C4S
M.#$L(#!X,C@Y-3@V-S<L"B`@("`@("`@,'@S0CA&-#@Y."P@,'@V0C1"0CE!
M1BP@,'A#-$)&13@Q0BP@,'@V-C(X,C$Y,RP*("`@("`@("`P>#8Q1#@P.4-#
M+"`P>$9",C%!.3DQ+"`P>#0X-T-!0S8P+"`P>#5$14,X,#,R+`H@("`@("`@
M(#!X148X-#5$-40L(#!X13DX-3<U0C$L(#!X1$,R-C(S,#(L(#!X14(V-3%"
M.#@L"B`@("`@("`@,'@R,S@Y,T4X,2P@,'A$,SDV04-#-2P@,'@P1C9$-D9&
M,RP@,'@X,T8T-#(S.2P*("`@("`@("`P>#)%,$(T-#@R+"`P>$$T.#0R,#`T
M+"`P>#8Y0SA&,#1!+"`P>#E%,48Y0C5%+`H@("`@("`@(#!X,C%#-C8X-#(L
M(#!X1C9%.39#.4$L(#!X-C<P0SE#-C$L(#!X04)$,S@X1C`L"B`@("`@("`@
M,'@V034Q03!$,BP@,'A$.#4T,D8V."P@,'@Y-C!&03<R."P@,'A!0C4Q,S-!
M,RP*("`@("`@("`P>#9%148P0C9#+"`P>#$S-T$S0D4T+"`P>$)!,T)&,#4P
M+"`P>#=%1D(R03DX+`H@("`@("`@(#!X03%&,38U,40L(#!X,SE!1C`Q-S8L
M(#!X-C9#034Y,T4L(#!X.#(T,S!%.#@L"B`@("`@("`@,'@X0T5%.#8Q.2P@
M,'@T-39&.49"-"P@,'@W1#@T035#,RP@,'@S0CA"-45"12P*("`@("`@("`P
M>$4P-D8W-40X+"`P>#@U0S$R,#<S+"`P>#0P,4$T-#E&+"`P>#4V0S$V04$V
M+`H@("`@("`@(#!X-$5$,T%!-C(L(#!X,S8S1C<W,#8L(#!X,4)&141&-S(L
M(#!X-#(Y0C`R,T0L"B`@("`@("`@,'@S-T0P1#<R-"P@,'A$,#!!,3(T."P@
M,'A$0C!&14%$,RP@,'@T.48Q0S`Y0BP*("`@("`@("`P>#`W-3,W,D,Y+"`P
M>#@P.3DQ0C="+"`P>#(U1#0W.40X+"`P>$8V13A$148W+`H@("`@("`@(#!X
M13-&134P,4$L(#!X0C8W.31#,T(L(#!X.3<V0T4P0D0L(#!X,#1#,#`V0D$L
M"B`@("`@("`@,'A#,4$Y-$9"-BP@,'@T,#E&-C!#-"P@,'@U135#.45#,BP@
M,'@Q.39!,C0V,RP*("`@("`@("`P>#8X1D(V1D%&+"`P>#-%-D,U,T(U+"`P
M>#$S,SE",D5"+"`P>#-"-3)%0S9&+`H@("`@("`@(#!X-D1&0S4Q,48L(#!X
M.4(S,#DU,D,L(#!X0T,X,30U-#0L(#!X048U14)$,#DL"B`@("`@("`@,'A"
M144S1#`P-"P@,'A$13,S-$%&1"P@,'@V-C!&,C@P-RP@,'@Q.3)%-$)",RP*
M("`@("`@("`P>$,P0T)!.#4W+"`P>#0U0S@W-#!&+"`P>$0R,$(U1C,Y+"`P
M>$(Y1#-&0D1"+`H@("`@("`@(#!X-34W.4,P0D0L(#!X,4$V,#,R,$$L(#!X
M1#9!,3`P0S8L(#!X-#`R0S<R-SDL"B`@("`@("`@,'@V-SE&,C5&12P@,'A&
M0C%&03-#0RP@,'@X14$U13E&."P@,'A$0C,R,C)&."P*("`@("`@("`P>#-#
M-S4Q-D1&+"`P>$9$-C$V0C$U+"`P>#)&-3`Q14,X+"`P>$%$,#4U,D%"+`H@
M("`@("`@(#!X,S(S1$(U1D$L(#!X1D0R,S@W-C`L(#!X-3,S,3="-#@L(#!X
M,T4P,$1&.#(L"B`@("`@("`@,'@Y135#-3="0BP@,'A#039&.$-!,"P@,'@Q
M03@W-38R12P@,'A$1C$W-CE$0BP*("`@("`@("`P>$0U-#)!.$8V+"`P>#(X
M-T5&1D,S+"`P>$%#-C<S,D,V+"`P>#A#-$8U-3<S+`H@("`@("`@(#!X-CDU
M0C(W0C`L(#!X0D)#034X0S@L(#!X13%&1D$S-40L(#!X0CA&,#$Q03`L"B`@
M("`@("`@,'@Q,$9!,T0Y."P@,'A&1#(Q.#-"."P@,'@T049#0C4V0RP@,'@R
M1$0Q1#,U0BP*("`@("`@("`P>#E!-3-%-#<Y+"`P>$(V1C@T-38U+"`P>$0R
M.$4T.4)#+"`P>#1"1D(Y-SDP+`H@("`@("`@(#!X13%$1$8R1$$L(#!X031#
M0C=%,S,L(#!X-C)&0C$S-#$L(#!X0T5%-$,V13@L"B`@("`@("`@,'A%1C(P
M0T%$02P@,'@S-C<W-$,P,2P@,'A$,#=%.45&12P@,'@R0D8Q,49"-"P*("`@
M("`@("`P>#DU1$)$031$+"`P>$%%.3`Y,3DX+"`P>$5!040X13<Q+"`P>#9"
M.3-$-4$P+`H@("`@("`@(#!X1#`X140Q1#`L(#!X049#-S(U13`L(#!X.$4S
M0S5",D8L(#!X.$4W-3DT0C<L"B`@("`@("`@,'@X1D8V13)&0BP@,'A&,C$R
M,D(V-"P@,'@X.#@X0C@Q,BP@,'@Y,#!$1C`Q0RP*("`@("`@("`P>#1&040U
M14$P+"`P>#8X.$9#,S%#+"`P>$0Q0T9&,3DQ+"`P>$(S03A#,4%$+`H@("`@
M("`@(#!X,D8R1C(R,3@L(#!X0D4P13$W-S<L(#!X14$W-3)$1D4L(#!X.$(P
M,C%&03$L"B`@("`@("`@,'A%-4$P0T,P1BP@,'A"-39&-S1%."P@,'@Q.$%#
M1C-$-BP@,'A#13@Y13(Y.2P*("`@("`@("`P>$(T03@T1D4P+"`P>$9$,3-%
M,$(W+"`P>#=#0S0S0C@Q+"`P>$0R041!.$0Y+`H@("`@("`@(#!X,38U1D$R
M-C8L(#!X.#`Y-3<W,#4L(#!X.3-#0S<S,30L(#!X,C$Q03$T-S<L"B`@("`@
M("`@,'A%-D%$,C`V-2P@,'@W-T(U1D$X-BP@,'A#-S4T-#)&-2P@,'A&0CE$
M,S5#1BP*("`@("`@("`P>$5"0T1!1C!#+"`P>#=",T4X.4$P+"`P>$0V-#$Q
M0D0S+"`P>$%%,44W130Y+`H@("`@("`@(#!X,#`R-3!%,D0L(#!X,C`W,4(S
M-44L(#!X,C(V.#`P0D(L(#!X-3=".$4P048L"B`@("`@("`@,'@R-#8T,S8Y
M0BP@,'A&,#`Y0CDQ12P@,'@U-38S.3$Q1"P@,'@U.41&039!02P*("`@("`@
M("`P>#<X0S$T,S@Y+"`P>$0Y-4$U,S=&+"`P>#(P-T0U0D$R+"`P>#`R135"
M.4,U+`H@("`@("`@(#!X.#,R-C`S-S8L(#!X-C(Y-4-&03DL(#!X,3%#.#$Y
M-C@L(#!X-$4W,S1!-#$L"B`@("`@("`@,'A",S0W,D1#02P@,'@W0C$T03DT
M02P@,'@Q0C4Q,#`U,BP@,'@Y034S,CDQ-2P*("`@("`@("`P>$0V,$8U-S-&
M+"`P>$)#.4)#-D4T+"`P>#)"-C!!-#<V+"`P>#@Q138W-#`P+`H@("`@("`@
M(#!X,#A"039&0C4L(#!X-3<Q0D4Y,48L(#!X1C(Y-D5#-D(L(#!X,D$P1$0Y
M,34L"B`@("`@("`@,'A"-C8S-C4R,2P@,'A%-T(Y1CE"-BP@,'A&1C,T,#4R
M12P@,'A#-3@U-38V-"P*("`@("`@("`P>#4S0C`R1#5$+"`P>$$Y.48X1D$Q
M+"`P>#`X0D$T-SDY+"`P>#9%.#4P-S9!*3L*"B`@("`O*BH*("`@("`J(%,@
M0F]X("AS,BD*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D<S(@/2!A<G)A>2@*("`@("`@("`P>#1"-T$W,$4Y+"`P>$(U0C,R
M.30T+"`P>$1"-S4P.3)%+"`P>$,T,3DR-C(S+`H@("`@("`@(#!X040V14$V
M0C`L(#!X-#E!-T1&-T0L(#!X.4-%138P0C@L(#!X.$9%1$(R-C8L"B`@("`@
M("`@,'A%0T%!.$,W,2P@,'@V.3E!,3=&1BP@,'@U-C8T-3(V0RP@,'A#,D(Q
M.45%,2P*("`@("`@("`P>#$Y,S8P,D$U+"`P>#<U,#DT0S(Y+"`P>$$P-3DQ
M,S0P+"`P>$4T,3@S03-%+`H@("`@("`@(#!X,T8U-#DX.4$L(#!X-4(T,CE$
M-C4L(#!X-D(X1D4T1#8L(#!X.3E&-S-&1#8L"B`@("`@("`@,'A!,40R.4,P
M-RP@,'A%1D4X,S!&-2P@,'@T1#)$,SA%-BP@,'A&,#(U-41#,2P*("`@("`@
M("`P>#1#1$0R,#@V+"`P>#@T-S!%0C(V+"`P>#8S.#)%.4,V+"`P>#`R,45#
M0S5%+`H@("`@("`@(#!X,#DV.#9",T8L(#!X,T5"045&0SDL(#!X,T,Y-S$X
M,30L(#!X-D(V03<P03$L"B`@("`@("`@,'@V.#=&,S4X-"P@,'@U,D$P13(X
M-BP@,'A"-SE#-3,P-2P@,'A!034P,#<S-RP*("`@("`@("`P>#-%,#<X-#%#
M+"`P>#=&1$5!135#+"`P>#A%-T0T-$5#+"`P>#4W,39&,D(X+`H@("`@("`@
M(#!X0C`S041!,S<L(#!X1C`U,#!#,$0L(#!X1C`Q0S%&,#0L(#!X,#(P,$(S
M1D8L"B`@("`@("`@,'A!13!#1C4Q02P@,'@S0T(U-S1",BP@,'@R-3@S-T$U
M."P@,'A$0S`Y,C%"1"P*("`@("`@("`P>$0Q.3$Q,T8Y+"`P>#=#03DR1D8V
M+"`P>#DT,S(T-S<S+"`P>#(R1C4T-S`Q+`H@("`@("`@(#!X,T%%-44U.#$L
M(#!X,S=#,D1!1$,L(#!X0SA"-3<V,S0L(#!X.4%&,T1$03<L"B`@("`@("`@
M,'A!.30T-C$T-BP@,'@P1D0P,#,P12P@,'A%0T,X0S<S12P@,'A!-#<U,44T
M,2P*("`@("`@("`P>$4R,SA#1#DY+"`P>#-"14$P13)&+"`P>#,R.#!"0D$Q
M+"`P>#$X,T5",S,Q+`H@("`@("`@(#!X-$4U-#A",S@L(#!X-$8V1$(Y,#@L
M(#!X-D8T,C!$,#,L(#!X1C8P03`T0D8L"B`@("`@("`@,'@R0T(X,3(Y,"P@
M,'@R-#DW-T,W.2P@,'@U-C<Y0C`W,BP@,'A"0T%&.#E!1BP*("`@("`@("`P
M>$1%.4$W-S%&+"`P>$0Y.3,P.#$P+"`P>$(S.$)!13$R+"`P>$1#0T8S1C)%
M+`H@("`@("`@(#!X-34Q,C<R,48L(#!X,D4V0C<Q,C0L(#!X-3`Q041$138L
M(#!X.48X-$-$.#<L"B`@("`@("`@,'@W034X-#<Q."P@,'@W-#`X1$$Q-RP@
M,'A"0SE&.4%"0RP@,'A%.31"-T0X0RP*("`@("`@("`P>$5#-T%%0S-!+"`P
M>$1".#4Q1$9!+"`P>#8S,#DT,S8V+"`P>$,T-C1#,T0R+`H@("`@("`@(#!X
M148Q0S$X-#<L(#!X,S(Q-40Y,#@L(#!X1$0T,S-",S<L(#!X,C1#,D)!,38L
M"B`@("`@("`@,'@Q,D$Q-$0T,RP@,'@R038U0S0U,2P@,'@U,#DT,#`P,BP@
M,'@Q,S-!131$1"P*("`@("`@("`P>#<Q1$9&.#E%+"`P>#$P,S$T134U+"`P
M>#@Q04,W-T0V+"`P>#5&,3$Q.3E"+`H@("`@("`@(#!X,#0S-34V1C$L(#!X
M1#=!,T,W-D(L(#!X,T,Q,3$X,T(L(#!X-3DR-$$U,#DL"B`@("`@("`@,'A&
M,CA&139%1"P@,'@Y-T8Q1D)&02P@,'@Y14)!0D8R0RP@,'@Q13$U,T,V12P*
M("`@("`@("`P>#@V13,T-3<P+"`P>$5!13DV1D(Q+"`P>#@V,$4U13!!+"`P
M>#5!,T4R04(S+`H@("`@("`@(#!X-S<Q1D4W,4,L(#!X-$4S1#`V1D$L(#!X
M,CDV-41#0CDL(#!X.3E%-S%$,$8L"B`@("`@("`@,'@X,#-%.#E$-BP@,'@U
M,C8V0S@R-2P@,'@R131#0SDW."P@,'@Y0S$P0C,V02P*("`@("`@("`P>$,V
M,34P14)!+"`P>#DT13)%03<X+"`P>$$U1D,S0S4S+"`P>#%%,$$R1$8T+`H@
M("`@("`@(#!X1C)&-S1%03<L(#!X,S8Q1#)",T0L(#!X,3DS.3(V,$8L(#!X
M,3E#,C<Y-C`L"B`@("`@("`@,'@U,C(S03<P."P@,'A&-S$S,3)"-BP@,'A%
M0D%$1D4V12P@,'A%04,S,48V-BP*("`@("`@("`P>$4S0D,T-3DU+"`P>$$V
M-T)#.#@S+"`P>$(Q-T8S-T0Q+"`P>#`Q.$-&1C(X+`H@("`@("`@(#!X0S,S
M,D1$148L(#!X0D4V0S5!034L(#!X-C4U.#(Q.#4L(#!X-CA!0CDX,#(L"B`@
M("`@("`@,'A%14-%034P1BP@,'A$0C)&.34S0BP@,'@R045&-T1!1"P@,'@U
M0C9%,D8X-"P*("`@("`@("`P>#$U,C%"-C(X+"`P>#(Y,#<V,3<P+"`P>$5#
M1$0T-S<U+"`P>#8Q.48Q-3$P+`H@("`@("`@(#!X,3-#0T$X,S`L(#!X14(V
M,4)$.38L(#!X,#,S-$9%,44L(#!X04$P,S8S0T8L"B`@("`@("`@,'A"-3<S
M-4,Y,"P@,'@T0S<P03(S.2P@,'A$-3E%.44P0BP@,'A#0D%!1$4Q-"P*("`@
M("`@("`P>$5%0T,X-D)#+"`P>#8P-C(R0T$W+"`P>#E#04(U0T%"+"`P>$(R
M1C,X-#9%+`H@("`@("`@(#!X-C0X0C%%048L(#!X,3E"1$8P0T$L(#!X03`R
M,S8Y0CDL(#!X-C4U04)"-3`L"B`@("`@("`@,'@T,#8X-4$S,BP@,'@S0S)!
M0C1",RP@,'@S,3E%13E$-2P@,'A#,#(Q0CA&-RP*("`@("`@("`P>#E"-30P
M0C$Y+"`P>#@W-49!,#DY+"`P>#DU1C<Y.3=%+"`P>#8R,T0W1$$X+`H@("`@
M("`@(#!X1C@S-S@X.4$L(#!X.3=%,S)$-S<L(#!X,3%%1#DS-48L(#!X,38V
M.#$R.#$L"B`@("`@("`@,'@P13,U.#@R.2P@,'A#-T4V,49$-BP@,'@Y-D1%
M1$9!,2P@,'@W.#4X0D$Y.2P*("`@("`@("`P>#4W1C4X-$$U+"`P>#%",C(W
M,C8S+"`P>#E".#-#,T9&+"`P>#%!0S(T-CDV+`H@("`@("`@(#!X0T1",S!!
M14(L(#!X-3,R13,P-30L(#!X.$9$.30X130L(#!X-D1"0S,Q,C@L"B`@("`@
M("`@,'@U.$5"1C)%1BP@,'@S-$,V1D9%02P@,'A&13(X140V,2P@,'A%13=#
M,T,W,RP*("`@("`@("`P>#5$-$$Q-$0Y+"`P>$4X-C1"-T4S+"`P>#0R,3`U
M1#$T+"`P>#(P,T4Q,T4P+`H@("`@("`@(#!X-#5%144R0C8L(#!X03-!04%"
M14$L(#!X1$(V0S1&,34L(#!X1D%#0C1&1#`L"B`@("`@("`@,'A#-S0R1C0T
M,BP@,'A%1C9!0D)"-2P@,'@V-31&,T(Q1"P@,'@T,4-$,C$P-2P*("`@("`@
M("`P>$0X,44W.3E%+"`P>#@V.#4T1$,W+"`P>$4T-$(T-S9!+"`P>#-$.#$V
M,C4P+`H@("`@("`@(#!X0T8V,D$Q1C(L(#!X-4(X1#(V-#8L(#!X1D,X.#@S
M03`L(#!X0S%#-T(V03,L"B`@("`@("`@,'@W1C$U,C1#,RP@,'@V.4-"-S0Y
M,BP@,'@T-S@T.$$P0BP@,'@U-CDR0C(X-2P*("`@("`@("`P>#`Y-4)"1C`P
M+"`P>$%$,3DT.#E$+"`P>#$T-C)",3<T+"`P>#(S.#(P13`P+`H@("`@("`@
M(#!X-3@T,CA$,D$L(#!X,$,U-48U14$L(#!X,41!1$8T,T4L(#!X,C,S1C<P
M-C$L"B`@("`@("`@,'@S,S<R1C`Y,BP@,'@X1#DS-T4T,2P@,'A$-C5&14-&
M,2P@,'@V0S(R,T)$0BP*("`@("`@("`P>#=#1$4S-S4Y+"`P>$-"144W-#8P
M+"`P>#0P.#5&,D$W+"`P>$-%-S<S,C9%+`H@("`@("`@(#!X038P-S@P.#0L
M(#!X,3E&.#4P.44L(#!X13A%1D0X-34L(#!X-C%$.3DW,S4L"B`@("`@("`@
M,'A!.38Y03=!02P@,'A#-3!#,#9#,BP@,'@U03`T04)&0RP@,'@X,#!"0T%$
M0RP*("`@("`@("`P>#E%-#0W03)%+"`P>$,S-#4S-#@T+"`P>$9$1#4V-S`U
M+"`P>#!%,44Y14,Y+`H@("`@("`@(#!X1$(W,T1"1#,L(#!X,3`U-3@X0T0L
M(#!X-C<U1D1!-SDL(#!X13,V-S0S-#`L"B`@("`@("`@,'A#-4,T,S0V-2P@
M,'@W,3-%,SA$."P@,'@S1#(X1C@Y12P@,'A&,39$1D8R,"P*("`@("`@("`P
M>#$U,T4R,44W+"`P>#A&0C`S1#1!+"`P>$4V13,Y1C)"+"`P>$1".#-!1$8W
M*3L*"B`@("`O*BH*("`@("`J(%,@0F]X("AS,RD*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S,@/2!A<G)A>2@*("`@("`@
M("`P>$4Y,T0U038X+"`P>#DT.#$T,$8W+"`P>$8V-$,R-C%#+"`P>#DT-CDR
M.3,T+`H@("`@("`@(#!X-#$Q-3(P1C<L(#!X-S8P,D0T1C<L(#!X0D-&-#9"
M,D4L(#!X1#1!,C`P-C@L"B`@("`@("`@,'A$-#`X,C0W,2P@,'@S,S(P1C0V
M02P@,'@T,T(W1#1"-RP@,'@U,#`P-C%!1BP*("`@("`@("`P>#%%,SE&-C)%
M+"`P>#DW,C0T-30V+"`P>#$T,C$T1C<T+"`P>$)&.$(X.#0P+`H@("`@("`@
M(#!X-$0Y-49#,40L(#!X.39"-3DQ048L(#!X-S!&-$1$1#,L(#!X-C9!,#)&
M-#4L"B`@("`@("`@,'A"1D)#,#E%0RP@,'@P,T)$.3<X-2P@,'@W1D%#-D1$
M,"P@,'@S,4-".#4P-"P*("`@("`@("`P>#DV14(R-T(S+"`P>#4U1D0S.30Q
M+"`P>$1!,C4T-T4V+"`P>$%"0T$P03E!+`H@("`@("`@(#!X,C@U,#<X,C4L
M(#!X-3,P-#(Y1C0L(#!X,$$R0S@V1$$L(#!X13E"-C9$1D(L"B`@("`@("`@
M,'@V.$1#,30V,BP@,'A$-S0X-CDP,"P@,'@V.#!%0S!!-"P@,'@R-T$Q.$1%
M12P*("`@("`@("`P>#1&,T9&14$R+"`P>$4X.#=!1#A#+"`P>$(U.$-%,#`V
M+"`P>#=!1C1$-D(V+`H@("`@("`@(#!X04%#13%%-T,L(#!X1#,S-S5&14,L
M(#!X0T4W.$$S.3DL(#!X-#`V0C)!-#(L"B`@("`@("`@,'@R,$9%.44S-2P@
M,'A$.48S.#5".2P@,'A%13,Y1#=!0BP@,'@S0C$R-$4X0BP*("`@("`@("`P
M>#%$0SE&048W+"`P>#1"-D0Q.#4V+"`P>#(V03,V-C,Q+"`P>$5!13,Y-T(R
M+`H@("`@("`@(#!X,T$V149!-S0L(#!X1$0U0C0S,S(L(#!X-C@T,44W1C<L
M(#!X0T$W.#(P1D(L"B`@("`@("`@,'A&0C!!1C4T12P@,'A$.$9%0C,Y-RP@
M,'@T-30P-39!0RP@,'A"030X.34R-RP*("`@("`@("`P>#4U-3,S03-!+"`P
M>#(P.#,X1#@W+"`P>$9%-D)!.4(W+"`P>$0P.38Y-31"+`H@("`@("`@(#!X
M-35!.#8W0D,L(#!X03$Q-3E!-3@L(#!X0T-!.3(Y-C,L(#!X.3E%,41",S,L
M"B`@("`@("`@,'A!-C)!-$$U-BP@,'@S1C,Q,C5&.2P@,'@U148T-T4Q0RP@
M,'@Y,#(Y,S$W0RP*("`@("`@("`P>$9$1CA%.#`R+"`P>#`T,C<R1C<P+"`P
M>#@P0D(Q-35#+"`P>#`U,C@R0T4S+`H@("`@("`@(#!X.35#,3$U-#@L(#!X
M131#-C9$,C(L(#!X-#A#,3$S,T8L(#!X0S<P1C@V1$,L"B`@("`@("`@,'@P
M-T8Y0SE%12P@,'@T,3`T,48P1BP@,'@T,#0W-SE!-"P@,'@U1#@X-D4Q-RP*
M("`@("`@("`P>#,R-48U,45"+"`P>$0U.4)#,$0Q+"`P>$8R0D-#,3A&+"`P
M>#0Q,3$S-38T+`H@("`@("`@(#!X,C4W0C<X,S0L(#!X-C`R03E#-C`L(#!X
M1$9&.$4X03,L(#!X,48V,S9#,4(L"B`@("`@("`@,'@P13$R0C1#,BP@,'@P
M,D4Q,S(Y12P@,'A!1C8V-$9$,2P@,'A#040Q.#$Q-2P*("`@("`@("`P>#9"
M,C,Y-44P+"`P>#,S,T4Y,D4Q+"`P>#-",C0P0C8R+"`P>$5%0D5".3(R+`H@
M("`@("`@(#!X.#5",D$R,$4L(#!X139"03!$.3DL(#!X1$4W,C!#.$,L(#!X
M,D1!,D8W,C@L"B`@("`@("`@,'A$,#$R-S@T-2P@,'@Y-4(W.31&1"P@,'@V
M-#=$,#@V,BP@,'A%-T-#1C5&,"P*("`@("`@("`P>#4T-#E!,S9&+"`P>#@W
M-T0T.$9!+"`P>$,S.41&1#(W+"`P>$8S,T4X1#%%+`H@("`@("`@(#!X,$$T
M-S8S-#$L(#!X.3DR149&-S0L(#!X,T$V1C9%04(L(#!X1C1&.$9$,S<L"B`@
M("`@("`@,'A!.#$R1$,V,"P@,'A!,45"1$1&."P@,'@Y.3%"13$T0RP@,'A$
M0C9%-D(P1"P*("`@("`@("`P>$,V-T(U-3$P+"`P>#9$-C<R0S,W+"`P>#(W
M-C5$-#-"+"`P>$1#1#!%.#`T+`H@("`@("`@(#!X1C$R.3!$0S<L(#!X0T,P
M,$9&03,L(#!X0C4S.3!&.3(L(#!X-CDP1D5$,$(L"B`@("`@("`@,'@V-C="
M.49&0BP@,'A#141"-T0Y0RP@,'A!,#DQ0T8P0BP@,'A$.3$U-45!,RP*("`@
M("`@("`P>$)",3,R1C@X+"`P>#4Q-4)!1#(T+"`P>#=".30W.4)&+"`P>#<V
M,T)$-D5"+`H@("`@("`@(#!X,S<S.3)%0C,L(#!X0T,Q,34Y-SDL(#!X.#`R
M-D4R.3<L(#!X1C0R13,Q,D0L"B`@("`@("`@,'@V.#0R041!-RP@,'A#-C9!
M,D(S0BP@,'@Q,C<U-$-#0RP@,'@W.#)%1C$Q0RP*("`@("`@("`P>#9!,3(T
M,C,W+"`P>$(W.3(U,44W+"`P>#`V03%"0D4V+"`P>#1"1D(V,S4P+`H@("`@
M("`@(#!X,4$V0C$P,3@L(#!X,3%#045$1D$L(#!X,T0R-4)$1#@L(#!X13)%
M,4,S0SDL"B`@("`@("`@,'@T-#0R,38U.2P@,'@P03$R,3,X-BP@,'A$.3!#
M14,V12P@,'A$-4%"14$R02P*("`@("`@("`P>#8T048V-S1%+"`P>$1!.#9!
M.#5&+"`P>$)%0D9%.3@X+"`P>#8T131#,T9%+`H@("`@("`@(#!X.41"0S@P
M-3<L(#!X1C!&-T,P.#8L(#!X-C`W.#="1C@L(#!X-C`P,S8P-$0L"B`@("`@
M("`@,'A$,49$.#,T-BP@,'A&-C,X,49","P@,'@W-S0U044P-"P@,'A$-S,V
M1D-#0RP*("`@("`@("`P>#@S-#(V0C,S+"`P>$8P,45!0C<Q+"`P>$(P.#`T
M,3@W+"`P>#-#,#`U135&+`H@("`@("`@(#!X-S=!,#4W0D4L(#!X0D1%.$%%
M,C0L(#!X-34T-C0R.3DL(#!X0D8U.#)%-C$L"B`@("`@("`@,'@T134X1C0X
M1BP@,'A&,D1$1D1!,BP@,'A&-#<T148S."P@,'@X-S@Y0D1#,BP*("`@("`@
M("`P>#4S-C9&.4,S+"`P>$,X0C,X13<T+"`P>$(T-S5&,C4U+"`P>#0V1D-$
M.4(Y+`H@("`@("`@(#!X-T%%0C(V-C$L(#!X.$(Q1$1&.#0L(#!X.#0V03!%
M-SDL(#!X.3$U1CDU13(L"B`@("`@("`@,'@T-C9%-3DX12P@,'@R,$(T-3<W
M,"P@,'@X0T0U-34Y,2P@,'A#.3`R1$4T0RP*("`@("`@("`P>$(Y,$)!0T4Q
M+"`P>$)".#(P-40P+"`P>#$Q03@V,C0X+"`P>#<U-S1!.3E%+`H@("`@("`@
M(#!X0C<W1C$Y0C8L(#!X13!!.41#,#DL(#!X-C8R1#`Y03$L(#!X0S0S,C0V
M,S,L"B`@("`@("`@,'A%.#5!,48P,BP@,'@P.48P0D4X0RP@,'@T03DY03`R
M-2P@,'@Q1#9%1D4Q,"P*("`@("`@("`P>#%!0CDS1#%$+"`P>#!"035!-$1&
M+"`P>$$Q.#9&,C!&+"`P>#(X-CA&,38Y+`H@("`@("`@(#!X1$-"-T1!.#,L
M(#!X-3<S.3`V1D4L(#!X03%%,D-%.4(L(#!X-$9#1#=&-3(L"B`@("`@("`@
M,'@U,#$Q-44P,2P@,'A!-S`V.#-&02P@,'A!,#`R0C5#-"P@,'@P1$4V1#`R
M-RP*("`@("`@("`P>#E!1C@X0S(W+"`P>#<W,T8X-C0Q+"`P>$,S-C`T0S`V
M+"`P>#8Q03@P-D(U+`H@("`@("`@(#!X1C`Q-S=!,C@L(#!X0S!&-3@V13`L
M(#!X,#`V,#4X04$L(#!X,S!$0S=$-C(L"B`@("`@("`@,'@Q,44V.45$-RP@
M,'@R,S,X14$V,RP@,'@U,T,R1$0Y-"P@,'A#,D,R,38S-"P*("`@("`@("`P
M>$)"0T)%134V+"`P>#DP0D-"-D1%+"`P>$5"1D,W1$$Q+"`P>$-%-3DQ1#<V
M+`H@("`@("`@(#!X-D8P-44T,#DL(#!X-$(W0S`Q.#@L(#!X,SDW,C!!,T0L
M(#!X-T,Y,C=#,C0L"B`@("`@("`@,'@X-D4S-S(U1BP@,'@W,C1$.41".2P@
M,'@Q04,Q-4)"-"P@,'A$,SE%0CA&0RP*("`@("`@("`P>$5$-30U-3<X+"`P
M>#`X1D-!-4(U+"`P>$0X,T0W0T0S+"`P>#1$040P1D,T+`H@("`@("`@(#!X
M,44U,$5&-44L(#!X0C$V,44V1C@L(#!X03(X-3$T1#DL(#!X-D,U,3$S,T,L
M"B`@("`@("`@,'@V1D0U0S=%-RP@,'@U-D4Q-$5#-"P@,'@S-C)!0D9#12P@
M,'A$1$,V0S@S-RP*("`@("`@("`P>$0W.4$S,C,T+"`P>#DR-C,X,C$R+"`P
M>#8W,$5&03A%+"`P>#0P-C`P,$4P*3L*"B`@("`O*BH*("`@("`J(%,@0F]X
M("AS-"D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D<S0@/2!A<G)A>2@*("`@("`@("`P>#-!,SE#13,W+"`P>$0S1D%&-4-&
M+"`P>$%"0S(W-S,W+"`P>#5!0S4R1#%"+`H@("`@("`@(#!X-4-",#8W.44L
M(#!X-$9!,S,W-#(L(#!X1#,X,C(W-#`L(#!X.3E"0SE"0D4L"B`@("`@("`@
M,'A$-3$Q.$4Y1"P@,'A"1C!&-S,Q-2P@,'A$-C)$,4,W12P@,'A#-S`P0S0W
M0BP*("`@("`@("`P>$(W.$,Q0C9"+"`P>#(Q03$Y,#0U+"`P>$(R-D5",4)%
M+"`P>#9!,S8V14(T+`H@("`@("`@(#!X-3<T.$%",D8L(#!X0D,Y-#9%-SDL
M(#!X0S9!,S<V1#(L(#!X-C4T.4,R0S@L"B`@("`@("`@,'@U,S!&1CA%12P@
M,'@T-CA$1$4W1"P@,'A$-3<S,$$Q1"P@,'@T0T0P-$1#-BP*("`@("`@("`P
M>#(Y,SE"0D1"+"`P>$$Y0D$T-C4P+"`P>$%#.34R-D4X+"`P>$)%-45%,S`T
M+`H@("`@("`@(#!X03%&040U1C`L(#!X-D$R1#4Q.4$L(#!X-C-%1CA#13(L
M(#!X.4$X-D5%,C(L"B`@("`@("`@,'A#,#@Y0S)"."P@,'@T,S(T,D5&-BP@
M,'A!-3%%,#-!02P@,'@Y0T8R1#!!-"P*("`@("`@("`P>#@S0S`V,4)!+"`P
M>#E"13DV031$+"`P>#A&134Q-34P+"`P>$)!-C0U0D0V+`H@("`@("`@(#!X
M,C@R-D$R1CDL(#!X03<S03-!13$L(#!X-$)!.3DU.#8L(#!X148U-38R13DL
M"B`@("`@("`@,'A#-S)&149$,RP@,'A&-S4R1C=$02P@,'@S1C`T-D8V.2P@
M,'@W-T9!,$$U.2P*("`@("`@("`P>#@P131!.3$U+"`P>#@W0C`X-C`Q+"`P
M>#E",#E%-D%$+"`P>#-",T5%-3DS+`H@("`@("`@(#!X13DY,$9$-4$L(#!X
M.44S-$0W.3<L(#!X,D-&,$(W1#DL(#!X,#(R0CA"-3$L"B`@("`@("`@,'@Y
M-D0U04,S02P@,'@P,3=$038W1"P@,'A$,4-&,T5$-BP@,'@W0S=$,D0R."P*
M("`@("`@("`P>#%&.48R-4-&+"`P>$%$1C)".#E"+"`P>#5!1#9"-#<R+"`P
M>#5!.#A&-31#+`H@("`@("`@(#!X13`R.4%#-S$L(#!X13`Q.4$U138L(#!X
M-#=",$%#1D0L(#!X140Y,T9!.4(L"B`@("`@("`@,'A%.$0S0S0X1"P@,'@R
M.#-"-3=#0RP@,'A&.$0U-C8R.2P@,'@W.3$S,D4R."P*("`@("`@("`P>#<X
M-48P,3DQ+"`P>$5$-S4V,#4U+"`P>$8W.38P130T+"`P>$4S1#,U13A#+`H@
M("`@("`@(#!X,34P-39$1#0L(#!X.#A&-#9$0D$L(#!X,#-!,38Q,C4L(#!X
M,#4V-$8P0D0L"B`@("`@("`@,'A#,T5".44Q-2P@,'@S0SDP-3=!,BP@,'@Y
M-S(W,4%%0RP@,'A!.3-!,#<R02P*("`@("`@("`P>#%",T8V1#E"+"`P>#%%
M-C,R,48U+"`P>$8U.4,V-D9"+"`P>#(V1$-&,S$Y+`H@("`@("`@(#!X-S4S
M,T0Y,C@L(#!X0C$U-49$1C4L(#!X,#,U-C,T.#(L(#!X.$%"03-#0D(L"B`@
M("`@("`@,'@R.#4Q-S<Q,2P@,'A#,C!!1#E&."P@,'A!0D-#-3$V-RP@,'A#
M0T%$.3(U1BP*("`@("`@("`P>#1$13@Q-S4Q+"`P>#,X,S!$0SA%+"`P>#,W
M.40U.#8R+"`P>#DS,C!&.3DQ+`H@("`@("`@(#!X14$W03DP0S(L(#!X1D(S
M13="0T4L(#!X-3$R,4-%-C0L(#!X-S<T1D)%,S(L"B`@("`@("`@,'A!.$(V
M13,W12P@,'A#,S(Y,T0T-BP@,'@T.$1%-3,V.2P@,'@V-#$S138X,"P*("`@
M("`@("`P>$$R044P.#$P+"`P>$1$-D1",C(T+"`P>#8Y.#4R1$9$+"`P>#`Y
M,#<R,38V+`H@("`@("`@(#!X0C,Y030V,$$L(#!X-C0T-4,P1$0L(#!X-3@V
M0T1%0T8L(#!X,4,R,$,X044L"B`@("`@("`@,'@U0D)%1C=$1"P@,'@Q0C4X
M.$0T,"P@,'A#0T0R,#$W1BP@,'@V0D(T13-"0BP*("`@("`@("`P>$1$03(V
M03=%+"`P>#-!-3E&1C0U+"`P>#-%,S4P030T+"`P>$)#0C1#1$0U+`H@("`@
M("`@(#!X-S)%04-%03@L(#!X1D$V-#@T0D(L(#!X.$0V-C$R044L(#!X0D8S
M0S9&-#<L"B`@("`@("`@,'A$,CE"130V,RP@,'@U-#)&-40Y12P@,'A!14,R
M-S<Q0BP@,'A&-C1%-C,W,"P*("`@("`@("`P>#<T,$4P1#A$+"`P>$4W-4(Q
M,S4W+"`P>$8X-S(Q-C<Q+"`P>$%&-3,W1#5$+`H@("`@("`@(#!X-#`T,$-"
M,#@L(#!X-$5"-$4R0T,L(#!X,S1$,C0V-D$L(#!X,#$Q-4%&.#0L"B`@("`@
M("`@,'A%,4(P,#0R."P@,'@Y-3DX,T$Q1"P@,'@P-D(X.49"-"P@,'A#139%
M03`T."P*("`@("`@("`P>#9&,T8S0C@R+"`P>#,U,C!!0C@R+"`P>#`Q,4$Q
M1#1"+"`P>#(W-S(R-T8X+`H@("`@("`@(#!X-C$Q-38P0C$L(#!X13<Y,S-&
M1$,L(#!X0D(S03<Y,D(L(#!X,S0T-3(U0D0L"B`@("`@("`@,'A!,#@X,SE%
M,2P@,'@U,4-%-SDT0BP@,'@R1C,R0SE"-RP@,'A!,#%&0D%#.2P*("`@("`@
M("`P>$4P,4-#.#=%+"`P>$)#0S=$,48V+"`P>$-&,#$Q,4,S+"`P>$$Q13A!
M04,W+`H@("`@("`@(#!X,4$Y,#@W-#DL(#!X1#0T1D)$.4$L(#!X1#!$041%
M0T(L(#!X1#4P041!,S@L"B`@("`@("`@,'@P,S,Y0S,R02P@,'A#-CDQ,S8V
M-RP@,'@X1$8Y,S$W0RP@,'A%,$(Q,D(T1BP*("`@("`@("`P>$8W.44U.4(W
M+"`P>#0S1C5"0C-!+"`P>$8R1#4Q.49&+"`P>#(W1#DT-3E#+`H@("`@("`@
M(#!X0D8Y-S(R,D,L(#!X,35%-D9#,D$L(#!X,$8Y,49#-S$L(#!X.4(Y-#$U
M,C4L"B`@("`@("`@,'A&044U.3,V,2P@,'A#14(V.4-%0BP@,'A#,D$X-C0U
M.2P@,'@Q,D)!03A$,2P*("`@("`@("`P>$(V0S$P-S5%+"`P>$4S,#4V03!#
M+"`P>#$P1#(U,#8U+"`P>$-",#-!-#0R+`H@("`@("`@(#!X13!%0S9%,$4L
M(#!X,38Y.$1",T(L(#!X-$,Y.$$P0D4L(#!X,S(W.$4Y-C0L"B`@("`@("`@
M,'@Y1C%&.34S,BP@,'A%,$0S.3)$1BP@,'A$,T$P,S0R0BP@,'@X.3<Q1C(Q
M12P*("`@("`@("`P>#%",$$W-#0Q+"`P>#1"03,S-#A#+"`P>$,U0D4W,3(P
M+"`P>$,S-S8S,D0X+`H@("`@("`@(#!X1$8S-3E&.$0L(#!X.4(Y.3)&,D4L
M(#!X138P0C9&-#<L(#!X,$9%,T8Q,40L"B`@("`@("`@,'A%-31#1$$U-"P@
M,'@Q141!1#@Y,2P@,'A#138R-SE#1BP@,'A#1#-%-T4V1BP*("`@("`@("`P
M>#$V,3A",38V+"`P>$9$,D,Q1#`U+"`P>#@T.$9$,D,U+"`P>$8V1D(R,CDY
M+`H@("`@("`@(#!X1C4R,T8S-3<L(#!X038S,C<V,C,L(#!X.3-!.#,U,S$L
M(#!X-39#0T-$,#(L"B`@("`@("`@,'A!0T8P.#$V,BP@,'@U03<U14)"-2P@
M,'@V13$V,S8Y-RP@,'@X.$0R-S-#0RP*("`@("`@("`P>$1%.38V,CDR+"`P
M>#@Q0CDT.40P+"`P>#1#-3`Y,#%"+"`P>#<Q0S8U-C$T+`H@("`@("`@(#!X
M139#-D,W0D0L(#!X,S(W03$T,$$L(#!X-#5%,40P,#8L(#!X0S-&,C=".4$L
M"B`@("`@("`@,'A#.4%!-3-&1"P@,'@V,D$X,$8P,"P@,'A"0C(U0D9%,BP@
M,'@S-4)$1#)&-BP*("`@("`@("`P>#<Q,3(V.3`U+"`P>$(R,#0P,C(R+"`P
M>$(V0T)#1C=#+"`P>$-$-S8Y0S)"+`H@("`@("`@(#!X-3,Q,3-%0S`L(#!X
M,38T,$4S1#,L(#!X,SA!0D)$-C`L(#!X,C4T-T%$1C`L"B`@("`@("`@,'A"
M03,X,C`Y0RP@,'A&-S0V0T4W-BP@,'@W-T%&03%#-2P@,'@R,#<U-C`V,"P*
M("`@("`@("`P>#@U0T)&131%+"`P>#A!13@X1$0X+"`P>#=!04%&.4(P+"`P
M>#1#1CE!03=%+`H@("`@("`@(#!X,3DT.$,R-4,L(#!X,#)&0CA!.$,L(#!X
M,#%#,S9!130L(#!X1#9%0D4Q1CDL"B`@("`@("`@,'@Y,$0T1C@V.2P@,'A!
M-C5#1$5!,"P@,'@S1C`Y,C4R1"P@,'A#,C`X138Y1BP*("`@("`@("`P>$(W
M-$4V,3,R+"`P>$-%-S=%,C5"+"`P>#4W.$9$1D4S+"`P>#-!0S,W,D4V*3L*
M"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@<F]U;F1S('1O(&1O"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7W)O
M=6YD<R`](#$V.PH*("`@("\J*@H@("`@("H@4V5T('1H92!K97D@=&\@8F4@
M=7-E9"!F;W(@96XO9&5C<GEP=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971+97DH)&ME>2D*("`@('L*("`@("`@("`D:V5Y(#T@)'1H:7,M
M/E]F;W)M871+97DH)&ME>2D["B`@("`@("`@)&ME>5!O<R`](#`["B`@("`@
M("`@)&ME>5AO<B`](#`["@H@("`@("`@("1I36%X(#T@8V]U;G0H)'1H:7,M
M/G`I.PH@("`@("`@("1K97E,96X@/2!C;W5N="@D:V5Y*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D:4UA>#L@)&DK*RD@>PH@("`@("`@("`@("!F
M;W(@*"1T(#T@,#L@)'0@/"`T.R`D="LK*2!["B`@("`@("`@("`@("`@("`D
M:V5Y6&]R(#T@*"1K97E8;W(@/#P@."D@?"`H*"1K97E;)&ME>5!O<UTI("8@
M,'@P9F8I.PH@("`@("`@("`@("`@("`@:68@*"LK)&ME>5!O<R`]/2`D:V5Y
M3&5N*2!["B`@("`@("`@("`@("`@("`@("`@)&ME>5!O<R`](#`["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/G!;)&E=(#T@)'1H:7,M/G!;)&E=(%X@)&ME>5AO<CL*("`@("`@("!]"@H@
M("`@("`@("1E;F-:97)O(#T@87)R87DH)TPG(#T^(#`L("=2)R`]/B`P*3L*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@*R`Q(#P@)&E-87@[("1I("L](#(I
M('L*("`@("`@("`@("`@)&5N8UIE<F\@/2`D=&AI<RT^7V5N8W)Y<'1";&]C
M:R@D96YC6F5R;ULG3"==+"`D96YC6F5R;ULG4B==*3L*("`@("`@("`@("`@
M)'1H:7,M/G!;)&E=(#T@)&5N8UIE<F];)TPG73L*("`@("`@("`@("`@)'1H
M:7,M/G!;)&D@*R`Q72`]("1E;F-:97)O6R=2)UT["B`@("`@("`@?0H*("`@
M("`@("`D:4UA>"`](&-O=6YT*"1T:&ES+3YS,2D["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&E-87@[("1I("L](#(I('L*("`@("`@("`@("`@)&5N
M8UIE<F\@/2`D=&AI<RT^7V5N8W)Y<'1";&]C:R@D96YC6F5R;ULG3"==+"`D
M96YC6F5R;ULG4B==*3L*("`@("`@("`@("`@)'1H:7,M/G,Q6R1I72`]("1E
M;F-:97)O6R=,)UT["B`@("`@("`@("`@("1T:&ES+3YS,5LD:2`K(#%=(#T@
M)&5N8UIE<F];)U(G73L*("`@("`@("!]"@H@("`@("`@("1I36%X(#T@8V]U
M;G0H)'1H:7,M/G,R*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:4UA
M>#L@)&D@*ST@,BD@>PH@("`@("`@("`@("`D96YC6F5R;R`]("1T:&ES+3Y?
M96YC<GEP=$)L;V-K*"1E;F-:97)O6R=,)UTL("1E;F-:97)O6R=2)UTI.PH@
M("`@("`@("`@("`D=&AI<RT^<S);)&E=(#T@)&5N8UIE<F];)TPG73L*("`@
M("`@("`@("`@)'1H:7,M/G,R6R1I("L@,5T@/2`D96YC6F5R;ULG4B==.PH@
M("`@("`@('T*"B`@("`@("`@)&E-87@@/2!C;W5N="@D=&AI<RT^<S,I.PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D:2`K/2`R*2!["B`@
M("`@("`@("`@("1E;F-:97)O(#T@)'1H:7,M/E]E;F-R>7!T0FQO8VLH)&5N
M8UIE<F];)TPG72P@)&5N8UIE<F];)U(G72D["B`@("`@("`@("`@("1T:&ES
M+3YS,ULD:5T@/2`D96YC6F5R;ULG3"==.PH@("`@("`@("`@("`D=&AI<RT^
M<S-;)&D@*R`Q72`]("1E;F-:97)O6R=2)UT["B`@("`@("`@?0H*("`@("`@
M("`D:4UA>"`](&-O=6YT*"1T:&ES+3YS-"D["B`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@)&E-87@[("1I("L](#(I('L*("`@("`@("`@("`@)&5N8UIE
M<F\@/2`D=&AI<RT^7V5N8W)Y<'1";&]C:R@D96YC6F5R;ULG3"==+"`D96YC
M6F5R;ULG4B==*3L*("`@("`@("`@("`@)'1H:7,M/G,T6R1I72`]("1E;F-:
M97)O6R=,)UT["B`@("`@("`@("`@("1T:&ES+3YS-%LD:2`K(#%=(#T@)&5N
M8UIE<F];)U(G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FX@=&AE('-I>F4@;V8@=&AE(&)L;V-K<R!T:&%T('1H:7,@8VEP:&5R
M(&YE961S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&YU
M;6)E<B!O9B!C:&%R86-T97)S('!E<B!B;&]C:RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0FQO8VM3:7IE*"D*("`@('L*("`@("`@("!R971U<FX@.#L*
M("`@('T*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!B;&]C:R!O9B!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("`@("`@5&AE
M(&1A=&$@=&\@96YC<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@
M("`@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!E;F-R>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!E;F-R>7!T0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@(&QI<W0H)$PL
M("12*2`](&%R<F%Y7W9A;'5E<RAU;G!A8VLH)TXJ)RP@)&)L;V-K*2D["B`@
M("`@("`@)'!A<G1S(#T@)'1H:7,M/E]E;F-R>7!T0FQO8VLH)$PL("12*3L*
M("`@("`@("!R971U<FX@<&%C:R@G3DXG+"`D<&%R='-;)TPG72P@)'!A<G1S
M6R=2)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC<GEP="!L969T(&%N
M9"!R:6=H="!H86QV97,@;V8@82!B;&]C:R!O9B!D871A+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!I;G1E
M9V5R("1,("!,969T(&AA;&8@;V8@=&AE(&1A=&$N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D4B`@4FEG:'0@:&%L9B!O9B!T:&4@9&%T82X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@L('=I=&@@:V5Y<R`G3"<@86YD
M("=2)RP@86YD('1H92!E;F-R>7!T960@9&%T82!A<PH@("`@("H@("`@("`@
M("`@("`@("`@=&AE('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N
M8W)Y<'1";&]C:R@D3"P@)%(I"B`@("!["B`@("`@("`@)$P@7CT@)'1H:7,M
M/G!;,%T["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@
M)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T
M:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@
M,'@P9F9=*2!>("1T:&ES+3YP6S%=.PH@("`@("`@("1,(%X]("@H*"1T:&ES
M+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V
M*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K
M("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LR73L*("`@("`@
M("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;,UT["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R
M-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>
M("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12
M("8@,'@P9F9=*2!>("1T:&ES+3YP6S1=.PH@("`@("`@("12(%X]("@H*"1T
M:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^
M(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=
M*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LU73L*("`@
M("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;-ET["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M/G,Q6R@D3"`^
M/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I("8@,'@P9F9=
M*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T
M6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S==.PH@("`@("`@("1,(%X]("@H
M*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"12
M(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P
M9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X,&9F72D@7B`D=&AI<RT^<%LX73L*
M("`@("`@("`D4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=
M("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S
M6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI
M(%X@)'1H:7,M/G!;.5T["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q6R@D
M4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@,'@P
M9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H:7,M
M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S$P73L*("`@("`@("`D4B!>
M/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R
M6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F
M(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;
M,3%=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@
M,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI
M<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X
M,&9F72D@7B`D=&AI<RT^<%LQ,ET["B`@("`@("`@)%(@7CT@*"@H)'1H:7,M
M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@,38I
M("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI("L@
M)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S$S73L*("`@("`@
M("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H
M:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^
M/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H
M:7,M/G!;,31=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@
M,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@
M7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD
M3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ-5T["B`@("`@("`@)$P@7CT@*"@H
M)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@
M/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F
M9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S$V73L*
M("`@("`@("`D4B!>/2`D=&AI<RT^<%LQ-UT["@H@("`@("`@(')E='5R;B!A
M<G)A>2@G3"<@/3X@)%(L("=2)R`]/B`D3"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$96-R>7!T(&$@8FQO8VL@;V8@9&%T82X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A=&$@=&\@9&5C<GEP="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4:&4@:V5Y('1O('5S92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1E8W)Y<'1E9"!O=71P
M=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8W)Y<'1";&]C:R@D8FQO8VLL
M("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D:V5Y
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T2V5Y*"1K97DI.PH@("`@("`@
M('T*"B`@("`@("`@;&ES="@D3"P@)%(I(#T@87)R87E?=F%L=65S*'5N<&%C
M:R@G3BHG+"`D8FQO8VLI*3L*"B`@("`@("`@)$P@7CT@)'1H:7,M/G!;,3==
M.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&
M1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^
M<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F
M72D@7B`D=&AI<RT^<%LQ-ET["B`@("`@("`@)$P@7CT@*"@H)'1H:7,M/G,Q
M6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)%(@/CX@,38I("8@
M,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P>#!F9ETI("L@)'1H
M:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6S$U73L*("`@("`@("`D
M4B!>/2`H*"@D=&AI<RT^<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M
M/G,R6R@D3"`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X
M*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M
M/G!;,31=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I
M("8@,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D
M=&AI<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F
M(#!X,&9F72D@7B`D=&AI<RT^<%LQ,UT["B`@("`@("`@)%(@7CT@*"@H)'1H
M:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH)$P@/CX@
M,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@)B`P>#!F9ETI
M("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP6S$R73L*("`@
M("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@
M)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D
M4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@
M)'1H:7,M/G!;,3%=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@
M/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F
M72D@7B`D=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS
M-%LD3"`F(#!X,&9F72D@7B`D=&AI<RT^<%LQ,%T["B`@("`@("`@)$P@7CT@
M*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS,ELH
M)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@."D@)B`P
M>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES+3YP6SE=
M.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I("8@,'A&
M1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI<RT^
M<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F(#!X,&9F
M72D@7B`D=&AI<RT^<%LX73L*("`@("`@("`D3"!>/2`H*"@D=&AI<RT^<S%;
M*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q-BD@)B`P
M>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@*R`D=&AI
M<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;-UT["B`@("`@("`@)%(@
M7CT@*"@H)'1H:7,M/G,Q6R@D3"`^/B`R-"D@)B`P>$9&72`K("1T:&ES+3YS
M,ELH)$P@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)$P@/CX@."D@
M)B`P>#!F9ETI("L@)'1H:7,M/G,T6R1,("8@,'@P9F9=*2!>("1T:&ES+3YP
M6S9=.PH@("`@("`@("1,(%X]("@H*"1T:&ES+3YS,5LH)%(@/CX@,C0I("8@
M,'A&1ET@*R`D=&AI<RT^<S);*"12(#X^(#$V*2`F(#!X,&9F72D@7B`D=&AI
M<RT^<S-;*"12(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD4B`F(#!X
M,&9F72D@7B`D=&AI<RT^<%LU73L*("`@("`@("`D4B!>/2`H*"@D=&AI<RT^
M<S%;*"1,(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D3"`^/B`Q-BD@
M)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D3"`^/B`X*2`F(#!X,&9F72D@*R`D
M=&AI<RT^<S1;)$P@)B`P>#!F9ETI(%X@)'1H:7,M/G!;-%T["B`@("`@("`@
M)$P@7CT@*"@H)'1H:7,M/G,Q6R@D4B`^/B`R-"D@)B`P>$9&72`K("1T:&ES
M+3YS,ELH)%(@/CX@,38I("8@,'@P9F9=*2!>("1T:&ES+3YS,ULH)%(@/CX@
M."D@)B`P>#!F9ETI("L@)'1H:7,M/G,T6R12("8@,'@P9F9=*2!>("1T:&ES
M+3YP6S-=.PH@("`@("`@("12(%X]("@H*"1T:&ES+3YS,5LH)$P@/CX@,C0I
M("8@,'A&1ET@*R`D=&AI<RT^<S);*"1,(#X^(#$V*2`F(#!X,&9F72D@7B`D
M=&AI<RT^<S-;*"1,(#X^(#@I("8@,'@P9F9=*2`K("1T:&ES+3YS-%LD3"`F
M(#!X,&9F72D@7B`D=&AI<RT^<%LR73L*("`@("`@("`D3"!>/2`H*"@D=&AI
M<RT^<S%;*"12(#X^(#(T*2`F(#!X1D9=("L@)'1H:7,M/G,R6R@D4B`^/B`Q
M-BD@)B`P>#!F9ETI(%X@)'1H:7,M/G,S6R@D4B`^/B`X*2`F(#!X,&9F72D@
M*R`D=&AI<RT^<S1;)%(@)B`P>#!F9ETI(%X@)'1H:7,M/G!;,5T["@H@("`@
M("`@("1D96-R>7!T960@/2!P86-K*").3B(L("12(%X@)'1H:7,M/G!;,%TL
M("1,*3L*("`@("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S(&$@=&5X="!K97D@:6YT;R!A;B!A<G)A>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@($ME>2!I;B!T97AT
M(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@:V5Y
M(&EN(&%R<F%Y(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA
M=$ME>2@D:V5Y*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>5]V86QU97,H
M=6YP86-K*"=#*B<L("1K97DI*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP:&5R+T)L;V-K36]D92YP
M:'``````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,V,C(@,3`U,34T
M,S0Q-#`@,#(S,3(T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0VEP:&5R7T)L;V-K
M36]D93HZ(&-L87-S('!R;W9I9&5S(&$@8V]M;6]N(&%B<W1R86-T960*("H@
M:6YT97)F86-E('1O('9A<FEO=7,@8FQO8VL@;6]D92!H86YD;&5R<R!F;W(@
M8VEP:&5R<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE
M<B]";&]C:TUO9&4N<&AP+'8@,2XQ-"XQ,BXY(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#
M;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(
M;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]";&]C:TUO9&4@
M>PH*("`@("\J*@H@("`@("H@5&AE(&EN:71I86QI>F%T:6]N('9E8W1O<BX*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I
M=B`](")<,%PP7#!<,%PP7#!<,%PP(CL*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T-I<&AE<E]";&]C:TUO
M9&4@:6YS=&%N8V4@8F%S960@;VX*("`@("`J("1M;V1E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&UO9&4@("!4:&4@='EP92!O9B!C;VYC<F5T
M92!(;W)D95]#:7!H97)?0FQO8VM-;V1E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@<W5B8VQA<W,@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L
M('!A<F%M971E<G,@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('-U
M8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D
M95]#:7!H97)?0FQO8VM-;V1E("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!#:7!H
M97)";&]C:TUO9&4@:6YS=&%N8V4L(&]R(%!%05)?17)R;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1M;V1E+"`D<&%R86US(#T@;G5L
M;"D*("`@('L*("`@("`@("`D;6]D92`](&)A<V5N86UE*"1M;V1E*3L*("`@
M("`@("!I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]"
M;&]C:TUO9&4O)R`N("1M;V1E("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+T)L;V-K36]D92\G
M("X@)&UO9&4@+B`G+G!H<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@
M/2`G2&]R9&5?0VEP:&5R7T)L;V-K36]D95\G("X@)&UO9&4["B`@("`@("`@
M:68@*&-L87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1B;&]C
M:VUO9&4@/2`F;F5W("1C;&%S<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D8FQO8VMM;V1E(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M0VQA<W,@9&5F:6YI=&EO;B!O9B`G("X@)&-L87-S("X@)R!N;W0@9F]U;F0N
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)L;V-K;6]D93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@258*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I=B`@5&AE(&YE=R!)5BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T258H)&EV*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:78@/2`D
M:78["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]D97,N<&AP````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(W,C`R(#$P-3$U-#,T,30P
M(#`R,C`T,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($-I<&AE<E]D97,Z.B!C;&%S<R!I;7!L
M96UE;G1S('1H92!#:7!H97(@:6YT97)F86-E(&5N8W)Y<'1I;VX@9&%T80H@
M*B!U<VEN9R!T:&4@1&%T82!%;F-R>7!T:6]N(%-T86YD87)D("A$15,I(&%L
M9V]R:71H;2!A<R!D969I;F4@:6X@1DE04S0V+3,N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O9&5S+G!H<"QV(#$N-"XQ,BXW(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN
M>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E7T-I
M<&AE<E]D97,@97AT96YD<R!(;W)D95]#:7!H97(@>PH*("`@("\J*@H@("`@
M("H@26YI=&EA;"!097)M=71A=&EO;@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1I<"`](&%R<F%Y*`H@("`@("`@(#4X+"`U
M,"P@-#(L(#,T+"`R-BP@,3@L(#$P+"`@,BP*("`@("`@("`V,"P@-3(L(#0T
M+"`S-BP@,C@L(#(P+"`Q,BP@(#0L"B`@("`@("`@-C(L(#4T+"`T-BP@,S@L
M(#,P+"`R,BP@,30L("`V+`H@("`@("`@(#8T+"`U-BP@-#@L(#0P+"`S,BP@
M,C0L(#$V+"`@."P*("`@("`@("`U-RP@-#DL(#0Q+"`S,RP@,C4L(#$W+"`@
M.2P@(#$L"B`@("`@("`@-3DL(#4Q+"`T,RP@,S4L(#(W+"`Q.2P@,3$L("`S
M+`H@("`@("`@(#8Q+"`U,RP@-#4L(#,W+"`R.2P@,C$L(#$S+"`@-2P*("`@
M("`@("`V,RP@-34L(#0W+"`S.2P@,S$L(#(S+"`Q-2P@(#<*("`@("D["@H@
M("`@+RHJ"B`@("`@*B!&:6YA;"!097)M=71A=&EO;B!)4%XM,0H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1F<"`](&%R<F%Y
M*`H@("`@("`@(#0P+"`@."P@-#@L(#$V+"`U-BP@,C0L(#8T+"`S,BP*("`@
M("`@("`S.2P@(#<L(#0W+"`Q-2P@-34L(#(S+"`V,RP@,S$L"B`@("`@("`@
M,S@L("`V+"`T-BP@,30L(#4T+"`R,BP@-C(L(#,P+`H@("`@("`@(#,W+"`@
M-2P@-#4L(#$S+"`U,RP@,C$L(#8Q+"`R.2P*("`@("`@("`S-BP@(#0L(#0T
M+"`Q,BP@-3(L(#(P+"`V,"P@,C@L"B`@("`@("`@,S4L("`S+"`T,RP@,3$L
M(#4Q+"`Q.2P@-3DL(#(W+`H@("`@("`@(#,T+"`@,BP@-#(L(#$P+"`U,"P@
M,3@L(#4X+"`R-BP*("`@("`@("`S,RP@(#$L(#0Q+"`@.2P@-#DL(#$W+"`U
M-RP@,C4*("`@("D["@H@("`@+RHJ"B`@("`@*B!%($)I="!396QE8W1I;VX@
M5&%B;&4*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D92`](&%R<F%Y*`H@("`@("`@(#,R+"`@,2P@(#(L("`S+"`@-"P@(#4L
M"B`@("`@("`@(#0L("`U+"`@-BP@(#<L("`X+"`@.2P*("`@("`@("`@."P@
M(#DL(#$P+"`Q,2P@,3(L(#$S+`H@("`@("`@(#$R+"`Q,RP@,30L(#$U+"`Q
M-BP@,3<L"B`@("`@("`@,38L(#$W+"`Q."P@,3DL(#(P+"`R,2P*("`@("`@
M("`R,"P@,C$L(#(R+"`R,RP@,C0L(#(U+`H@("`@("`@(#(T+"`R-2P@,C8L
M(#(W+"`R."P@,CDL"B`@("`@("`@,C@L(#(Y+"`S,"P@,S$L(#,R+"`@,0H@
M("`@*3L*"B`@("`O*BH*("`@("`J(%,@8F]X97,*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W,@/2!A<G)A>2@*("`@("`@
M("`O*B!3,2`J+PH@("`@("`@(#$@/3X@87)R87DH"B`@("`@("`@("`@,30L
M("`T+"`Q,RP@(#$L("`R+"`Q-2P@,3$L("`X+"`@,RP@,3`L("`V+"`Q,BP@
M(#4L("`Y+"`@,"P@(#<L"B`@("`@("`@("`@(#`L(#$U+"`@-RP@(#0L(#$T
M+"`@,BP@,3,L("`Q+"`Q,"P@(#8L(#$R+"`Q,2P@(#DL("`U+"`@,RP@(#@L
M"B`@("`@("`@("`@(#0L("`Q+"`Q-"P@(#@L(#$S+"`@-BP@(#(L(#$Q+"`Q
M-2P@,3(L("`Y+"`@-RP@(#,L(#$P+"`@-2P@(#`L"B`@("`@("`@("`@,34L
M(#$R+"`@."P@(#(L("`T+"`@.2P@(#$L("`W+"`@-2P@,3$L("`S+"`Q-"P@
M,3`L("`P+"`@-BP@,3,*("`@("`@("`I+`H*("`@("`@("`O*B!3,B`J+PH@
M("`@("`@(#(@/3X@87)R87DH"B`@("`@("`@("`@,34L("`Q+"`@."P@,30L
M("`V+"`Q,2P@(#,L("`T+"`@.2P@(#<L("`R+"`Q,RP@,3(L("`P+"`@-2P@
M,3`L"B`@("`@("`@("`@(#,L(#$S+"`@-"P@(#<L(#$U+"`@,BP@(#@L(#$T
M+"`Q,BP@(#`L("`Q+"`Q,"P@(#8L("`Y+"`Q,2P@(#4L"B`@("`@("`@("`@
M(#`L(#$T+"`@-RP@,3$L(#$P+"`@-"P@,3,L("`Q+"`@-2P@(#@L(#$R+"`@
M-BP@(#DL("`S+"`@,BP@,34L"B`@("`@("`@("`@,3,L("`X+"`Q,"P@(#$L
M("`S+"`Q-2P@(#0L("`R+"`Q,2P@(#8L("`W+"`Q,BP@(#`L("`U+"`Q-"P@
M(#DL"B`@("`@("`@*2P*"B`@("`@("`@+RH@4S,@*B\*("`@("`@("`S(#T^
M(&%R<F%Y*`H@("`@("`@("`@(#$P+"`@,"P@(#DL(#$T+"`@-BP@(#,L(#$U
M+"`@-2P@(#$L(#$S+"`Q,BP@(#<L(#$Q+"`@-"P@(#(L("`X+`H@("`@("`@
M("`@(#$S+"`@-RP@(#`L("`Y+"`@,RP@(#0L("`V+"`Q,"P@(#(L("`X+"`@
M-2P@,30L(#$R+"`Q,2P@,34L("`Q+`H@("`@("`@("`@(#$S+"`@-BP@(#0L
M("`Y+"`@."P@,34L("`S+"`@,"P@,3$L("`Q+"`@,BP@,3(L("`U+"`Q,"P@
M,30L("`W+`H@("`@("`@("`@("`Q+"`Q,"P@,3,L("`P+"`@-BP@(#DL("`X
M+"`@-RP@(#0L(#$U+"`Q-"P@(#,L(#$Q+"`@-2P@(#(L(#$R+`H@("`@("`@
M("DL"@H@("`@("`@("\J(%,T("HO"B`@("`@("`@-"`]/B!A<G)A>2@*("`@
M("`@("`@("`@-RP@,3,L(#$T+"`@,RP@(#`L("`V+"`@.2P@,3`L("`Q+"`@
M,BP@(#@L("`U+"`Q,2P@,3(L("`T+"`Q-2P*("`@("`@("`@("`Q,RP@(#@L
M(#$Q+"`@-2P@(#8L(#$U+"`@,"P@(#,L("`T+"`@-RP@(#(L(#$R+"`@,2P@
M,3`L(#$T+"`@.2P*("`@("`@("`@("`Q,"P@(#8L("`Y+"`@,"P@,3(L(#$Q
M+"`@-RP@,3,L(#$U+"`@,2P@(#,L(#$T+"`@-2P@(#(L("`X+"`@-"P*("`@
M("`@("`@("`@,RP@,34L("`P+"`@-BP@,3`L("`Q+"`Q,RP@(#@L("`Y+"`@
M-"P@(#4L(#$Q+"`Q,BP@(#<L("`R+"`Q-"P*("`@("`@("`I+`H*("`@("`@
M("`O*B!3-2`J+PH@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@(#(L
M(#$R+"`@-"P@(#$L("`W+"`Q,"P@,3$L("`V+"`@."P@(#4L("`S+"`Q-2P@
M,3,L("`P+"`Q-"P@(#DL"B`@("`@("`@("`@,30L(#$Q+"`@,BP@,3(L("`T
M+"`@-RP@,3,L("`Q+"`@-2P@(#`L(#$U+"`Q,"P@(#,L("`Y+"`@."P@(#8L
M"B`@("`@("`@("`@(#0L("`R+"`@,2P@,3$L(#$P+"`Q,RP@(#<L("`X+"`Q
M-2P@(#DL(#$R+"`@-2P@(#8L("`S+"`@,"P@,30L"B`@("`@("`@("`@,3$L
M("`X+"`Q,BP@(#<L("`Q+"`Q-"P@(#(L(#$S+"`@-BP@,34L("`P+"`@.2P@
M,3`L("`T+"`@-2P@(#,L"B`@("`@("`@*2P*"B`@("`@("`@+RH@4S8@*B\*
M("`@("`@("`V(#T^(&%R<F%Y*`H@("`@("`@("`@(#$R+"`@,2P@,3`L(#$U
M+"`@.2P@(#(L("`V+"`@."P@(#`L(#$S+"`@,RP@(#0L(#$T+"`@-RP@(#4L
M(#$Q+`H@("`@("`@("`@(#$P+"`Q-2P@(#0L("`R+"`@-RP@,3(L("`Y+"`@
M-2P@(#8L("`Q+"`Q,RP@,30L("`P+"`Q,2P@(#,L("`X+`H@("`@("`@("`@
M("`Y+"`Q-"P@,34L("`U+"`@,BP@(#@L(#$R+"`@,RP@(#<L("`P+"`@-"P@
M,3`L("`Q+"`Q,RP@,3$L("`V+`H@("`@("`@("`@("`T+"`@,RP@(#(L(#$R
M+"`@.2P@(#4L(#$U+"`Q,"P@,3$L(#$T+"`@,2P@(#<L("`V+"`@,"P@(#@L
M(#$S+`H@("`@("`@("DL"@H@("`@("`@("\J(%,W("HO"B`@("`@("`@-R`]
M/B!A<G)A>2@*("`@("`@("`@("`@-"P@,3$L("`R+"`Q-"P@,34L("`P+"`@
M."P@,3,L("`S+"`Q,BP@(#DL("`W+"`@-2P@,3`L("`V+"`@,2P*("`@("`@
M("`@("`Q,RP@(#`L(#$Q+"`@-RP@(#0L("`Y+"`@,2P@,3`L(#$T+"`@,RP@
M(#4L(#$R+"`@,BP@,34L("`X+"`@-BP*("`@("`@("`@("`@,2P@(#0L(#$Q
M+"`Q,RP@,3(L("`S+"`@-RP@,30L(#$P+"`Q-2P@(#8L("`X+"`@,"P@(#4L
M("`Y+"`@,BP*("`@("`@("`@("`@-BP@,3$L(#$S+"`@."P@(#$L("`T+"`Q
M,"P@(#<L("`Y+"`@-2P@(#`L(#$U+"`Q-"P@(#(L("`S+"`Q,BP*("`@("`@
M("`I+`H*("`@("`@("`O*B!3."`J+PH@("`@("`@(#@@/3X@87)R87DH"B`@
M("`@("`@("`@(#$S+"`@,BP@(#@L("`T+"`@-BP@,34L(#$Q+"`@,2P@,3`L
M("`Y+"`@,RP@,30L("`U+"`@,"P@,3(L("`W+`H@("`@("`@("`@("`@,2P@
M,34L(#$S+"`@."P@,3`L("`S+"`@-RP@(#0L(#$R+"`@-2P@(#8L(#$Q+"`@
M,"P@,30L("`Y+"`@,BP*("`@("`@("`@("`@(#<L(#$Q+"`@-"P@(#$L("`Y
M+"`Q,BP@,30L("`R+"`@,"P@(#8L(#$P+"`Q,RP@,34L("`S+"`@-2P@(#@L
M"B`@("`@("`@("`@("`R+"`@,2P@,30L("`W+"`@-"P@,3`L("`X+"`Q,RP@
M,34L(#$R+"`@.2P@(#`L("`S+"`@-2P@(#8L(#$Q"B`@("`@("`@*0H@("`@
M*3L*"B`@("`O*BH*("`@("`J(%!R:6UI=&EV92!F=6YC=&EO;@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P(#T@87)R87DH
M"B`@("`@("`@,38L("`W+"`R,"P@,C$L"B`@("`@("`@,CDL(#$R+"`R."P@
M,3<L"B`@("`@("`@(#$L(#$U+"`R,RP@,C8L"B`@("`@("`@(#4L(#$X+"`S
M,2P@,3`L"B`@("`@("`@(#(L("`X+"`R-"P@,30L"B`@("`@("`@,S(L(#(W
M+"`@,RP@(#DL"B`@("`@("`@,3DL(#$S+"`S,"P@(#8L"B`@("`@("`@,C(L
M(#$Q+"`@-"P@,C4*("`@("D["@H@("`@+RHJ"B`@("`@*B!097)M=71E9"!#
M:&]I8V4@5&%B;&4*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D<&,Q(#T@87)R87DH"B`@("`@("`@-3<L(#0Y+"`T,2P@,S,L
M(#(U+"`Q-RP@(#DL"B`@("`@("`@(#$L(#4X+"`U,"P@-#(L(#,T+"`R-BP@
M,3@L"B`@("`@("`@,3`L("`R+"`U.2P@-3$L(#0S+"`S-2P@,C<L"B`@("`@
M("`@,3DL(#$Q+"`@,RP@-C`L(#4R+"`T-"P@,S8L"@H@("`@("`@(#8S+"`U
M-2P@-#<L(#,Y+"`S,2P@,C,L(#$U+`H@("`@("`@("`W+"`V,BP@-30L(#0V
M+"`S."P@,S`L(#(R+`H@("`@("`@(#$T+"`@-BP@-C$L(#4S+"`T-2P@,S<L
M(#(Y+`H@("`@("`@(#(Q+"`Q,RP@(#4L(#(X+"`R,"P@,3(L("`T"B`@("`I
M.PH*("`@("\J*@H@("`@("H@3G5M8F5R(&QE9G0@<F]T871I;VYS(&]F('!C
M,0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S
M:&EF=',@/2!A<G)A>2@*("`@("`@("`Q+"`Q+"`R+"`R+"`R+"`R+"`R+"`R
M+`H@("`@("`@(#$L(#(L(#(L(#(L(#(L(#(L(#(L(#$*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!097)M=71E9"!#:&]I8V4@5&%B;&4@,@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1P8S(@/2!A<G)A>2@*
M("`@("`@("`Q-"P@,3<L(#$Q+"`R-"P@(#$L("`U+`H@("`@("`@("`S+"`R
M."P@,34L("`V+"`R,2P@,3`L"B`@("`@("`@,C,L(#$Y+"`Q,BP@(#0L(#(V
M+"`@."P*("`@("`@("`Q-BP@(#<L(#(W+"`R,"P@,3,L("`R+`H@("`@("`@
M(#0Q+"`U,BP@,S$L(#,W+"`T-RP@-34L"B`@("`@("`@,S`L(#0P+"`U,2P@
M-#4L(#,S+"`T."P*("`@("`@("`T-"P@-#DL(#,Y+"`U-BP@,S0L(#4S+`H@
M("`@("`@(#0V+"`T,BP@-3`L(#,V+"`R.2P@,S(*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!+97D@4V-H961U;&4*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7TMS(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%-E="!T:&4@:V5Y('1O(&)E('5S960@9F]R(&5N+V1E8W)Y<'1I;VXN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@:V5Y('1O
M('5S92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2V5Y*"1K97DI"B`@("![
M"B`@("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?2W,@/2`D=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<VEZ92!O9B!T
M:&4@8FQO8VMS('1H870@=&AI<R!C:7!H97(@;F5E9',N"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F(&-H87)A8W1E<G,@
M<&5R(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971";&]C:U-I>F4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`X.PH@("`@?0H*("`@("\J*@H@("`@
M("H@16YC<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&5N8W)Y<'0N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T960@;W5T<'5T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T0FQO8VLH)&)L;V-K+"`D
M:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]+<R`]("1T:&ES+3Y?:V5Y4V-H961U
M;&4H)&ME>2D["B`@("`@("`@?0H*("`@("`@("`D8FQO8VL@/2`D=&AI<RT^
M7VEN:71I86Q097)M*"1B;&]C:RD["@H@("`@("`@("1,(#T@<W5B<W1R*"1B
M;&]C:RP@,"P@-"D["B`@("`@("`@)%(@/2!S=6)S='(H)&)L;V-K+"`T+"`T
M*3L*"B`@("`@("`@9F]R("@D:2`](#$[("1I(#P](#$V.R`D:2LK("D@>PH@
M("`@("`@("`@("`D4E]P<F5V(#T@)%(["B`@("`@("`@("`@("1,7W!R978@
M/2`D3#L*"B`@("`@("`@("`@("1,(#T@)%(["B`@("`@("`@("`@("12(#T@
M)$Q?<')E=B!>("1T:&ES+3Y?9B@D4E]P<F5V+"`D:2D["B`@("`@("`@?0H*
M("`@("`@("`D8FQO8VL@/2`D4B`N("1,.PH@("`@("`@("1B;&]C:R`]("1T
M:&ES+3Y?9FEN86Q097)M*"1B;&]C:RD["@H@("`@("`@(')E='5R;B`D8FQO
M8VL["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@8FQO8VL@;V8@
M9&%T82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE
M(&1A=&$@=&\@9&5C<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@
M("!4:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&1E8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1B;&]C:R`]("1T:&ES+3Y?:6YI=&EA;%!E<FTH)&)L;V-K*3L*"B`@
M("`@("`@:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?2W,@/2`D=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI.PH@("`@("`@('T*
M"B`@("`@("`@)$P@/2!S=6)S='(H)&)L;V-K+"`P+"`T*3L*("`@("`@("`D
M4B`]('-U8G-T<B@D8FQO8VLL(#0L(#0I.PH*("`@("`@("!F;W(@*"1I(#T@
M,38[("1I(#X](#$[("1I+2T@*2!["B`@("`@("`@("`@("127W!R978@/2`D
M4CL*("`@("`@("`@("`@)$Q?<')E=B`]("1,.PH*("`@("`@("`@("`@)$P@
M/2`D4E]P<F5V.PH@("`@("`@("`@("`D4B`]("1,7W!R978@7B`D=&AI<RT^
M7V8H)%)?<')E=BP@)&DI.PH@("`@("`@('T*"B`@("`@("`@)&)L;V-K(#T@
M)%(@+B`D3#L*("`@("`@("`D8FQO8VL@/2`D=&AI<RT^7V9I;F%L4&5R;2@D
M8FQO8VLI.PH*("`@("`@("!R971U<FX@)&)L;V-K.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4'5T(&%N(&EN<'5T('-T<FEN9R!T:')O=6=H(&%N(&EN:71I
M86P@<&5R;75T871I;VX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I
M;G!U="`@26YP=70@<W1R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!097)M=71A=&5D('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7VEN:71I86Q097)M*"1I;G!U="D*("`@('L*("`@("`@("`O+R!43T1/.B!3
M;VUE('-T>6QI92!B:71W:7-E('1H:6YG(&EN<W1E860N"@H@("`@("`@("1I
M;G!U=%]B:6X@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`X.R`D
M:2LK*2!["B`@("`@("`@("`@("1I;G!U=%]B:6X@+CT@<W1R7W!A9"AD96-B
M:6XH;W)D*"1I;G!U=%LD:5TI*2P@."P@)S`G+"!35%)?4$%$7TQ%1E0I.PH@
M("`@("`@('T*"B`@("`@("`@)&]U='!U=%]B:6X@/2`G)SL*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^:7`@87,@)&]F9G-E="D@>PH@("`@("`@("`@("`D
M;W5T<'5T7V)I;B`N/2`D:6YP=71?8FEN6R1O9F9S970@+2`Q73L*("`@("`@
M("!]"@H@("`@("`@("1O=71P=70@/2`G)SL*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`X.R`D:2LK*2!["B`@("`@("`@("`@("1O=71P=70@+CT@8VAR
M*&)I;F1E8RAS=6)S='(H)&]U='!U=%]B:6XL(#@@*B`D:2P@."DI*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4'5T(&%N(&EN<'5T('-T<FEN9R!T:')O=6=H(&$@9FEN86P@
M<&5R;75T871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP
M=70@($EN<'5T('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@4&5R;75T871E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F
M:6YA;%!E<FTH)&EN<'5T*0H@("`@>PH@("`@("`@("\O(%1/1$\Z(%-O;64@
M<W1Y;&EE(&)I='=I<V4@=&AI;F<@:6YS=&5A9"X*("`@("`@("`D:6YP=71?
M8FEN(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@.#L@)&DK*RD@
M>PH@("`@("`@("`@("`D:6YP=71?8FEN("X]('-T<E]P860H9&5C8FEN*&]R
M9"@D:6YP=71;)&E=*2DL(#@L("<P)RP@4U127U!!1%],1494*3L*("`@("`@
M("!]"@H@("`@("`@("1O=71P=71?8FEN(#T@)R<["B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/F9P(&%S("1O9F9S970I('L*("`@("`@("`@("`@)&]U='!U
M=%]B:6X@+CT@)&EN<'5T7V)I;ELD;V9F<V5T("T@,5T["B`@("`@("`@?0H*
M("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@.#L@)&DK*RD@>PH@("`@("`@("`@("`D;W5T<'5T("X](&-H<BAB:6YD
M96,H<W5B<W1R*"1O=71P=71?8FEN+"`X("H@)&DL(#@I*2D["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"@H@("`@+RHJ"B`@
M("`@*B!F*"D@5&AE('!E<FUU=&%T:6]N(&9U;F-T:6]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!);G!U="!S=')I;F<N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D<F]U;F0@(%1H92!R;W5N9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&]U='!U="!S=')I;F<N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]F*"1I;G!U="P@)')O=6YD*0H@("`@>PH@("`@
M("`@("\O(%1/1$\Z(%-O;64@<W1Y;&EE(&)I='=I<V4@=&AI;F<@:6YS=&5A
M9"X*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]+<ULD<F]U;F1=.PH*("`@("`@
M("`D:6YP=71?8FEN(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M-#L@)&DK*RD@>PH@("`@("`@("`@("`D:6YP=71?8FEN("X]('-T<E]P860H
M9&5C8FEN*&]R9"@D:6YP=71;)&E=*2DL(#@L("<P)RP@4U127U!!1%],1494
M*3L*("`@("`@("!]"@H@("`@("`@("1E>'!A;F1E9%]B:6X@/2`G)SL*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^92!A<R`D;V9F<V5T*2!["B`@("`@("`@
M("`@("1E>'!A;F1E9%]B:6X@+CT@)&EN<'5T7V)I;ELD;V9F<V5T("T@,5T[
M"B`@("`@("`@?0H*("`@("`@("`D97AP86YD960@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[("1I*RLI('L*("`@("`@("`@("`@
M)&5X<&%N9&5D6R1I72`](&)I;F1E8R@G,#`G("X@<W5B<W1R*"1E>'!A;F1E
M9%]B:6XL("1I("H@-BP@-BDI(%X@)&ME>5LD:5T["B`@("`@("`@?0H*("`@
M("`@("`D8V]M8FEN961?8FEN(#T@)R<["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@.#L@)&DK*RD@>PH@("`@("`@("`@("`D<U]I;F1E>"`]("@H)&5X
M<&%N9&5D6R1I72`F(#!X,C`I(#X^(#0I('P@*"1E>'!A;F1E9%LD:5T@)B`P
M>#`Q*3L*("`@("`@("`@("`@)'-?:6YD97@@/2`Q-B`J("1S7VEN9&5X("L@
M*"@D97AP86YD961;)&E=("8@,'@Q12D@/CX@,2D["B`@("`@("`@("`@("1V
M86P@/2`D=&AI<RT^7W-;)&D@*R`Q75LD<U]I;F1E>%T["B`@("`@("`@("`@
M("1C;VUB:6YE9%]B:6X@+CT@<W1R7W!A9"AD96-B:6XH)'9A;"DL(#0L("<P
M)RP@4U127U!!1%],1494*3L*("`@("`@("!]"@H@("`@("`@("1O=71P=71?
M8FEN(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G`@87,@)&]F9G-E
M="D@>PH@("`@("`@("`@("`D;W5T<'5T7V)I;B`N/2`D8V]M8FEN961?8FEN
M6R1O9F9S970@+2`Q73L*("`@("`@("!]"@H@("`@("`@("1O=71P=70@/2`G
M)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`T.R`D:2LK*2!["B`@("`@
M("`@("`@("1O=71P=70@+CT@8VAR*&)I;F1E8RAS=6)S='(H)&]U='!U=%]B
M:6XL("1I("H@."P@."DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;VUP
M;&5T92!K97D@<VAE9'5L92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@2V5Y('-C:&5D=6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:V5Y
M4V-H961U;&4H)&ME>2D*("`@('L*("`@("`@("`D:V5Y(#T@<W1R7W!A9"@D
M:V5Y+"`X+"`B7#`B*3L*("`@("`@("`D:W,@/2!A<G)A>2@I.PH*("`@("`@
M("`D:V5Y7V)I;B`]("<G.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(#@[
M("1I*RLI('L*("`@("`@("`@("`@)&ME>5]B:6X@+CT@<W1R7W!A9"AD96-B
M:6XH;W)D*"1K97E;)&E=*2DL(#@L("<P)RP@4U127U!!1%],1494*3L*("`@
M("`@("!]"@H@("`@("`@("1C(#T@)R<["B`@("`@("`@)&0@/2`G)SL*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`R.#L@)&DK*RD@>PH@("`@("`@("`@
M("`D8R`N/2`D:V5Y7V)I;ELD=&AI<RT^<&,Q6R1I72`M(#%=.PH@("`@("`@
M("`@("`D9"`N/2`D:V5Y7V)I;ELD=&AI<RT^<&,Q6S(X("L@)&E=("T@,5T[
M"B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q-CL@)&DK
M*RD@>PH@("`@("`@("`@("`D8R`]('-U8G-T<B@D8RP@)'1H:7,M/G-H:69T
M<ULD:5TI("X@<W5B<W1R*"1C+"`P+"`D=&AI<RT^<VAI9G1S6R1I72D["B`@
M("`@("`@("`@("1D(#T@<W5B<W1R*"1D+"`D=&AI<RT^<VAI9G1S6R1I72D@
M+B!S=6)S='(H)&0L(#`L("1T:&ES+3YS:&EF='-;)&E=*3L*"B`@("`@("`@
M("`@("1C9"`]("1C("X@)&0["@H@("`@("`@("`@("`D<&5R;75T871E9%]B
M:6X@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/G!C,B!A<R`D
M;V9F<V5T*2!["B`@("`@("`@("`@("`@("`D<&5R;75T871E9%]B:6X@+CT@
M)&-D6R1O9F9S970@+2`Q73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M9F]R("@D:B`](#`[("1J(#P@.#L@)&HK*RD@>PH@("`@("`@("`@("`@("`@
M)&MS6R1I("L@,5U;72`](&)I;F1E8R@G,#`G("X@<W5B<W1R*"1P97)M=71A
M=&5D7V)I;BP@)&H@*B`V+"`V*2D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D:W,["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0VEP
M:&5R+V-A<W0Q,C@N<&AP````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`Q,S(U,S8@,3`U,34T,S0Q-#`@,#(R-#8Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@0VEP
M:&5R7V-A<W0Q,C@Z.B!C;&%S<R!I;7!L96UE;G1S('1H92!#:7!H97(@:6YT
M97)F86-E(&5N8W)Y<'1I;VX@9&%T80H@*B!U<VEN9R!T:&4@0T%35#$R."`H
M86MA($-A<W0U*2!A;&=O<FET:&T@87,@9&5F:6YE9"!I;B!21D,R,30T+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#:7!H97(O0VEP:&5R+V-A<W0Q,C@N
M<&AP+'8@,2XW+C$R+C@@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME
M0&=R869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@
M0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@
M*B\*8VQA<W,@2&]R9&5?0VEP:&5R7V-A<W0Q,C@@97AT96YD<R!(;W)D95]#
M:7!H97(@>PH*("`@("\J*@H@("`@("H@4R!B;W@@*',Q*0H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1S,2`](&%R<F%Y*`H@
M("`@("`@(#!X,S!F8C0P9#0L(#!X.69A,&9F,&(L(#!X-F)E8V-D,F8L(#!X
M,V8R-3AC-V$L(#!X,64R,3-F,F8L(#!X.6,P,#1D9#,L(#!X-C`P,V4U-#`L
M(#!X8V8Y9F,Y-#DL"B`@("`@("`@,'AB9F0T868R-RP@,'@X.&)B8F1B-2P@
M,'AE,C`S-#`Y,"P@,'@Y.&0P.38W-2P@,'@V938S83!E,"P@,'@Q-6,S-C%D
M,BP@,'AC,F4W-C8Q9"P@,'@R,F0T9F8X92P*("`@("`@("`P>#(X-C@S8C9F
M+"`P>&,P-V9D,#4Y+"`P>&9F,C,W.6,X+"`P>#<W-68U,&4R+"`P>#0S8S,T
M,&0S+"`P>&1F,F8X-C4V+"`P>#@X-V-A-#%A+"`P>&$R9#)B9#)D+`H@("`@
M("`@(#!X83%C.64P9#8L(#!X,S0V8S0X,3DL(#!X-C%B-S9D.#<L(#!X,C(U
M-#!F,F8L(#!X,F%B93,R93$L(#!X86$U-#$V-F(L(#!X,C(U-CAE,V$L(#!X
M83)D,S0Q9#`L"B`@("`@("`@,'@V-F1B-#!C."P@,'AA-S@T,SDR9BP@,'@P
M,#1D9F8R9BP@,'@R9&(Y9#)D92P@,'@Y-SDT,V9A8RP@,'@T83DW8S%D."P@
M,'@U,C<V-#1B-RP@,'AB-68T,S=A-RP*("`@("`@("`P>&(X,F-B865F+"`P
M>&0W-3%D,34Y+"`P>#9F9C=F,&5D+"`P>#5A,#DW83%F+"`P>#@R-V(V.&0P
M+"`P>#DP96-F-3)E+"`P>#(R8C!C,#4T+"`P>&)C.&4U.3,U+`H@("`@("`@
M(#!X-&(V9#)F-V8L(#!X-3!B8C8T83(L(#!X9#(V-C0Y,3`L(#!X8F5E-3@Q
M,F0L(#!X8C<S,S(R.3`L(#!X93DS8C$U.68L(#!X8C0X964T,3$L(#!X-&)F
M9C,T-60L"B`@("`@("`@,'AF9#0U8S(T,"P@,'AA9#,Q.3<S9BP@,'AC-&8V
M9#`R92P@,'@U-69C.#$V-2P@,'AD-6(Q8V%A9"P@,'AA,6%C,F1A92P@,'AA
M,F0T8C<V9"P@,'AC,3EB,&,U,"P*("`@("`@("`P>#@X,C(T,&8R+"`P>#!C
M-F4T9C,X+"`P>&$T931B9F0W+"`P>#1F-6)A,C<R+"`P>#4V-&,Q9#)F+"`P
M>&,U.6,U,S$Y+"`P>&(Y-#EE,S4T+"`P>&(P-#8V.69E+`H@("`@("`@(#!X
M8C%B-F%B.&$L(#!X8S<Q,S4X9&0L(#!X-C,X-6,U-#4L(#!X,3$P9CDS-60L
M(#!X-3<U,SAA9#4L(#!X-F$S.3`T.3,L(#!X938S9#,W93`L(#!X,F$U-&8V
M8C,L"B`@("`@("`@,'@S83<X-V0U9BP@,'@V,C<V83!B-2P@,'@Q.6$V9F-D
M9BP@,'@W830R,C`V82P@,'@R.68Y9#1D-2P@,'AF-C%B,3@Y,2P@,'AB8C<R
M,C<U92P@,'AA834P.#$V-RP*("`@("`@("`P>#,X.3`Q,#DQ+"`P>&,V8C4P
M-65B+"`P>#@T8S=C8CAC+"`P>#)A9#<U83!F+"`P>#@W-&$Q-#(W+"`P>&$R
M9#$Y,S9B+"`P>#)A9#(X-F%F+"`P>&%A-39D,CDQ+`H@("`@("`@(#!X9#<X
M.30S-C`L(#!X-#(U8S<U,&0L(#!X.3-B,SEE,C8L(#!X,3@W,3@T8SDL(#!X
M-F,P,&(S,F0L(#!X-S-E,F)B,30L(#!X83!B96)C,V,L(#!X-30V,C,W-SDL
M"B`@("`@("`@,'@V-#0U.65A8BP@,'@S9C,R.&(X,BP@,'@W-S$X8V8X,BP@
M,'@U.6$R8V5A-BP@,'@P-&5E,#`R92P@,'@X.69E-SAE-BP@,'@S9F%B,#DU
M,"P@,'@S,C5F9C9C,BP*("`@("`@("`P>#@Q,S@S9C`U+"`P>#8Y-C-C-6,X
M+"`P>#<V8V(U860V+"`P>&0T.3DW-&,Y+"`P>&-A,3@P9&-F+"`P>#,X,#<X
M,F0U+"`P>&,W9F$U8V8V+"`P>#AA8S,Q-3$Q+`H@("`@("`@(#!X,S5E-SEE
M,3,L(#!X-#=D83DQ9#`L(#!X9C0P9CDP.#8L(#!X83=E,C0Q.64L(#!X,S$S
M-C8R-#$L(#!X,#4Q968T.34L(#!X86$U-S-B,#0L(#!X-&$X,#5D.&0L"B`@
M("`@("`@,'@U-#@S,#!D,"P@,'@P,#,R,F$S8RP@,'AB9C8T8V1D9BP@,'AB
M834W838X92P@,'@W-6,V,S<R8BP@,'@U,&%F9#,T,2P@,'AA-V,Q,S(W-2P@
M,'@Y,35A,&)F-2P*("`@("`@("`P>#9B-31B9F%B+"`P>#)B,&(Q-#(V+"`P
M>&%B-&-C.60W+"`P>#0T.6-C9#@R+"`P>&8W9F)F,C8U+"`P>&%B.#5C-68S
M+"`P>#%B-35D8CDT+"`P>&%A9#1E,S(T+`H@("`@("`@(#!X8V9A-&)D,V8L
M(#!X,F1E86$S93(L(#!X.64R,#1D,#(L(#!X8SAB9#(U86,L(#!X96%D9C4U
M8C,L(#!X9#5B9#EE.3@L(#!X93,Q,C,Q8C(L(#!X,F%D-6%D-F,L"B`@("`@
M("`@,'@Y-30S,CED92P@,'AA9&)E-#4R."P@,'AD.#<Q,&8V.2P@,'AA834Q
M8SDP9BP@,'AA83<X-F)F-BP@,'@R,C4Q,V8Q92P@,'AA834Q83<Y8BP@,'@R
M860S-#1C8RP*("`@("`@("`P>#=B-6$T,68P+"`P>&0S-V-F8F%D+"`P>#%B
M,#8Y-3`U+"`P>#0Q96-E-#DQ+"`P>&(T8S,S,F4V+"`P>#`S,C(V.&0T+"`P
M>&,Y-C`P86-C+"`P>&-E,S@W939D+`H@("`@("`@(#!X8F8V8F(Q-F,L(#!X
M-F$W,&9B-S@L(#!X,&0P,V0Y8SDL(#!X9#1D9C,Y9&4L(#!X93`Q,#8S9&$L
M(#!X-#<S-F8T-C0L(#!X-6%D,S(X9#@L(#!X8C,T-V-C.38L"B`@("`@("`@
M,'@W-6)B,&9C,RP@,'@Y.#4Q,6)F8BP@,'@T9F9B8V,S-2P@,'AB-3AB8V8V
M82P@,'AE,3%F,&%B8RP@,'AB9F,U9F4T82P@,'AA-S!A96,Q,"P@,'AA8S,Y
M-3<P82P*("`@("`@("`P>#-F,#0T-#)F+"`P>#8Q.#AB,34S+"`P>&4P,SDW
M83)E+"`P>#4W,C=C8C<Y+"`P>#EC96(T,3AF+"`P>#%C86-D-CAD+"`P>#)A
M9#,W8SDV+"`P>#`Q-S5C8CED+`H@("`@("`@(#!X8S8Y9&9F,#DL(#!X8S<U
M8C8U9C`L(#!X9#ED8C0P9#@L(#!X96,P93<W-SDL(#!X-#<T-&5A9#0L(#!X
M8C$Q8S,R-S0L(#!X9&0R-&-B.64L(#!X-V4Q8S4T8F0L"B`@("`@("`@,'AF
M,#$Q-#1F.2P@,'AD,C(T,&5B,2P@,'@Y-C<U8C-F9"P@,'AA,V%C,S<U-2P@
M,'AD-#=C,C=A9BP@,'@U,6,X-68T9"P@,'@U-CDP-S4Y-BP@,'AA-6)B,35E
M-BP*("`@("`@("`P>#4X,#,P-&8P+"`P>&-A,#0R8V8Q+"`P>#`Q,6$S-V5A
M+"`P>#AD8F9A861B+"`P>#,U8F$S931A+"`P>#,U,C9F9F$P+"`P>&,S-V(T
M9#`Y+"`P>&)C,S`V960Y+`H@("`@("`@(#!X.3AA-3(V-C8L(#!X-38T.&8W
M,C4L(#!X9F8U934V.60L(#!X,&-E9#8S9#`L(#!X-V,V,V(R8V8L(#!X-S`P
M8C0U93$L(#!X9#5E834P9C$L(#!X.#5A.3(X-S(L"B`@("`@("`@,'AA9C%F
M8F1A-RP@,'AD-#(S-#@W,"P@,'AA-S@W,&)F,RP@,'@R9#-B-&0W.2P@,'@T
M,F4P-#$Y."P@,'@P8V0P961E-RP@,'@R-C0W,&1B."P@,'AF.#@Q.#$T8RP*
M("`@("`@("`P>#0W-&0V860W+"`P>#=C,&,U935C+"`P>&0Q,C,Q.34Y+"`P
M>#,X,6(W,CDX+"`P>&8U9#)F-&1B+"`P>&%B.#,X-C4S+"`P>#9E,F8Q93(S
M+"`P>#@S-S$Y8SEE+`H@("`@("`@(#!X8F0Y,64P-#8L(#!X.6$U-C0U-F4L
M(#!X9&,S.3(P,&,L(#!X,C!C.&,U-S$L(#!X.38R8F1A,6,L(#!X93%E-CDV
M9F8L(#!X8C$T,6%B,#@L(#!X-V-C83@Y8CDL"B`@("`@("`@,'@Q838Y93<X
M,RP@,'@P,F-C-#@T,RP@,'AA,F8W8S4W.2P@,'@T,CEE9C0W9"P@,'@T,C=B
M,38Y8RP@,'@U86,Y9C`T.2P@,'AD9#AF,&8P,"P@,'@U8S@Q-C5B9BD["@H@
M("`@+RHJ"B`@("`@*B!3(&)O>"`H<S(I"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)',R(#T@87)R87DH"B`@("`@("`@,'@Q
M9C(P,3`Y-"P@,'AE9C!B83<U8BP@,'@V.64S8V8W92P@,'@S.3-F-#,X,"P@
M,'AF938Q8V8W82P@,'AE96,U,C`W82P@,'@U-3@X.6,Y-"P@,'@W,F9C,#8U
M,2P*("`@("`@("`P>&%D83=E9C<Y+"`P>#1E,60W,C,U+"`P>&0U-6$V,V-E
M+"`P>&1E,#0S-F)A+"`P>#DY8S0S,&5F+"`P>#5F,&,P-SDT+"`P>#$X9&-D
M8C=D+"`P>&$Q9#9E9F8S+`H@("`@("`@(#!X83!B-3)F-V(L(#!X-3EE.#,V
M,#4L(#!X964Q-6(P.30L(#!X93EF9F0Y,#DL(#!X9&,T-#`P.#8L(#!X968Y
M-#0T-3DL(#!X8F$X,V-C8C,L(#!X93!C,V-D9F(L"B`@("`@("`@,'AD,61A
M-#$X,2P@,'@S8C`Y,F%B,2P@,'AF.3DW9C%C,2P@,'AA-64V8V8W8BP@,'@P
M,30R,&1D8BP@,'AE-&4W968U8BP@,'@R-6$Q9F8T,2P@,'AE,3@P9C@P-BP*
M("`@("`@("`P>#%F8S0Q,#@P+"`P>#$W.6)E93=A+"`P>&0S-V%C-F$Y+"`P
M>&9E-3@S,&$T+"`P>#DX9&4X8C=F+"`P>#<W93@S9C1E+"`P>#<Y.3(Y,C8Y
M+"`P>#(T9F$Y9C=B+`H@("`@("`@(#!X93$Q,V,X-6(L(#!X86-C-#`P.#,L
M(#!X9#<U,#,U,C4L(#!X9C=E838Q-68L(#!X-C(Q-#,Q-30L(#!X,&0U-31B
M-C,L(#!X-60V.#$Q,C$L(#!X8S@V-F,S-3DL"B`@("`@("`@,'@S9#8S8V8W
M,RP@,'AC964R,S1C,"P@,'AD-&0X-V4X-RP@,'@U8S8W,F(R,2P@,'@P-S%F
M-C$X,2P@,'@S.68W-C(W9BP@,'@S-C%E,S`X-"P@,'AE-&5B-3<S8BP*("`@
M("`@("`P>#8P,F8V-&$T+"`P>&0V,V%C9#EC+"`P>#%B8F,T-C,U+"`P>#EE
M.#$P,S)D+"`P>#(W,#%F-3!C+"`P>#DY.#0W86(T+"`P>&$P93-D9C<Y+"`P
M>&)A-F-F,SAC+`H@("`@("`@(#!X,3`X-#,P.30L(#!X,C4S-V$Y-64L(#!X
M9C0V9C9F9F4L(#!X83%F9C-B,68L(#!X,C`X8V9B-F$L(#!X.&8T-3AC-S0L
M(#!X9#EE,&$R,C<L(#!X-&5C-S-A,S0L"B`@("`@("`@,'AF8S@X-&8V.2P@
M,'@S931D93AD9BP@,'AE9C!E,#`X."P@,'@S-34Y-C0X9"P@,'@X830U,S@X
M8RP@,'@Q9#@P-#,V-BP@,'@W,C%D.6)F9"P@,'AA-3@V.#1B8BP*("`@("`@
M("`P>&4X,C4V,S,S+"`P>#@T-&4X,C$R+"`P>#$R.&0X,#DX+"`P>&9E9#,S
M9F(T+"`P>&-E,C@P864Q+"`P>#(W93$Y8F$U+"`P>&0U839C,C4R+"`P>&4T
M.3<U-&)D+`H@("`@("`@(#!X8S5D-C4U9&0L(#!X96(V-C<P-C0L(#!X-S<X
M-#!B-&0L(#!X83%B-F$X,#$L(#!X.#1D8C(V83DL(#!X93!B-38W,30L(#!X
M,C%F,#0S8C<L(#!X935D,#4X-C`L"B`@("`@("`@,'@U-&8P,S`X-"P@,'@P
M-C9F9C0W,BP@,'AA,S%A83$U,RP@,'AD861C-#<U-2P@,'AB-38R-61B9BP@
M,'@V.#4V,6)E-BP@,'@X,V-A-F(Y-"P@,'@R9#9E9#(S8BP*("`@("`@("`P
M>&5C8V8P,61B+"`P>&$V9#-D,&)A+"`P>&(V.#`S9#5C+"`P>&%F-S=A-S`Y
M+"`P>#,S8C1A,S1C+"`P>#,Y-V)C.&0V+"`P>#5E93(R8CDU+"`P>#5F,&4U
M,S`T+`H@("`@("`@(#!X.#%E9#9F-C$L(#!X,C!E-S0S-C0L(#!X8C0U93$S
M-S@L(#!X9&4Q.#8S.6(L(#!X.#@Q8V$Q,C(L(#!X8CDV-S(V9#$L(#!X.#`T
M.6$W93@L(#!X,C)B-V1A-V(L"B`@("`@("`@,'@U934U,F0R-2P@,'@U,C<R
M9#(S-RP@,'@W.60R.34Q8RP@,'AC-C!D.#DT8RP@,'@T.#AC8C0P,BP@,'@Q
M8F$T9F4U8BP@,'AA-&(P.68V8BP@,'@Q8V$X,35C9BP*("`@("`@("`P>&$R
M,&,S,#`U+"`P>#@X-S%D9C8S+"`P>&(Y9&4R9F-B+"`P>#!C8S9C.64Y+"`P
M>#!B965F9C4S+"`P>&4S,C$T-3$W+"`P>&(T-30R.#,U+"`P>#EF-C,R.3-C
M+`H@("`@("`@(#!X964T,64W,CDL(#!X-F4Q9#)D-V,L(#!X-3`P-#4R.#8L
M(#!X,64V-C@U9C,L(#!X9C,S-#`Q8S8L(#!X,S!A,C)C.34L(#!X,S%A-S`X
M-3`L(#!X-C`Y,S!F,3,L"B`@("`@("`@,'@W,V8Y.#0Q-RP@,'AA,3(V.3@U
M.2P@,'AE8S8T-6,T-"P@,'@U,F,X-S=A.2P@,'AC9&9F,S-A-BP@,'AA,#)B
M,3<T,2P@,'@W8V)A9#EA,BP@,'@R,3@P,#,V9BP*("`@("`@("`P>#4P9#DY
M8S`X+"`P>&-B,V8T.#8Q+"`P>&,R-F)D-S8U+"`P>#8T83-F-F%B+"`P>#@P
M,S0R-C<V+"`P>#(U83<U93=B+"`P>&4T939D,69C+"`P>#(P8S<Q,&4V+`H@
M("`@("`@(#!X8V1F,&(V.#`L(#!X,3<X-#1D,V(L(#!X,S%E968X-&0L(#!X
M-V4P.#(T930L(#!X,F-C8C0Y96(L(#!X.#0V83-B864L(#!X.&9F-S<X.#@L
M(#!X964U9#8P9C8L"B`@("`@("`@,'@W868W-38W,RP@,'@R9F1D-6-D8BP@
M,'AA,3$V,S%C,2P@,'@S,&8V-F8T,RP@,'AB,V9A96,U-"P@,'@Q-3=F9#=F
M82P@,'AE9C@U-SEC8RP@,'AD,34R9&4U."P*("`@("`@("`P>&1B,F9F9#5E
M+"`P>#AF,S)C93$Y+"`P>#,P-F%F.3=A+"`P>#`R9C`S968X+"`P>#DY,S$Y
M860U+"`P>&,R-#)F83!F+"`P>&$W93-E8F(P+"`P>&,V.&4T.3`V+`H@("`@
M("`@(#!X8CAD83(S,&,L(#!X.#`X,C,P,C@L(#!X9&-D968S8S@L(#!X9#,U
M9F(Q-S$L(#!X,#@X83%B8S@L(#!X8F5C,&,U-C`L(#!X-C%A,V,Y93@L(#!X
M8F-A.&8U-&0L"B`@("`@("`@,'AC-S)F969F82P@,'@R,C@R,F4Y.2P@,'@X
M,F,U-S!B-"P@,'AD.&0Y-&4X.2P@,'@X8C%C,S1B8RP@,'@S,#%E,39E-BP@
M,'@R-S-B93DW.2P@,'AB,&9F96%A-BP*("`@("`@("`P>#8Q9#EB.&,V+"`P
M>#`P8C(T.#8Y+"`P>&(W9F9C93-F+"`P>#`X9&,R.#-B+"`P>#0S9&%F-C5A
M+"`P>&8W93$Y-SDX+"`P>#<V,3EB-S)F+"`P>#AF,6,Y8F$T+`H@("`@("`@
M(#!X9&,X-C,W83`L(#!X,39A-V0S8C$L(#!X.69C,SDS8C<L(#!X83<Q,S9E
M96(L(#!X8S9B8V,V,V4L(#!X,6$U,3,W-#(L(#!X968V.#(X8F,L(#!X-3(P
M,S8U9#8L"B`@("`@("`@,'@R9#9A-S=A8BP@,'@S-3(W960T8BP@,'@X,C%F
M9#(Q-BP@,'@P.35C-F4R92P@,'AD8CDR9C)F8BP@,'@U965A,CEC8BP@,'@Q
M-#4X.3)F-2P@,'@Y,34X-&8W9BP*("`@("`@("`P>#4T.#,V.3=B+"`P>#(V
M-C=A.&-C+"`P>#@U,3DV,#0X+"`P>#AC-&)A8V5A+"`P>#@S,S@V,&0T+"`P
M>#!D,C-E,&8Y+"`P>#9C,S@W93AA+"`P>#!A939D,C0Y+`H@("`@("`@(#!X
M8C(X-#8P,&,L(#!X9#@S-3<S,60L(#!X9&-B,6,V-#<L(#!X86,T8S4V96$L
M(#!X,V5B9#@Q8C,L(#!X,C,P96%B8C`L(#!X-C0S.&)C.#<L(#!X9C!B-6(Q
M9F$L"B`@("`@("`@,'@X9C5E83)B,RP@,'AF8S$X-#8T,BP@,'@P83`S-F(W
M82P@,'@T9F(P.#EB9"P@,'@V-#ED834X.2P@,'AA,S0U-#$U92P@,'@U8S`S
M.#,R,RP@,'@S935D,V)B.2P*("`@("`@("`P>#0S9#<Y-3<R+"`P>#=E-F1D
M,#=C+"`P>#`V9&9D9C%E+"`P>#9C-F-C-&5F+"`P>#<Q-C!A-3,Y+"`P>#<S
M8F9B93<P+"`P>#@S.#<W-C`U+"`P>#0U,C-E8V8Q*3L*"B`@("`O*BH*("`@
M("`J(%,@8F]X("AS,RD*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D<S,@/2!A<G)A>2@*("`@("`@("`P>#AD969C,C0P+"`P
M>#(U9F$U9#EF+"`P>&5B.3`S9&)F+"`P>&4X,3!C.3`W+"`P>#0W-C`W9F9F
M+"`P>#,V.69E-#1B+"`P>#AC,69C-C0T+"`P>&%E8V5C83DP+`H@("`@("`@
M(#!X8F5B,68Y8F8L(#!X965F8F-A96$L(#!X93AC9C$Y-3`L(#!X-3%D9C`W
M864L(#!X.3(P93@X,#8L(#!X9C!A9#`U-#@L(#!X93$S8SAD.#,L(#!X.3(W
M,#$P9#4L"B`@("`@("`@,'@Q,3$P-V0Y9BP@,'@P-S8T-V1B.2P@,'AB,F4S
M931D-"P@,'@S9#1F,C@U92P@,'AB.6%F83@R,"P@,'AF861E.#)E,"P@,'AA
M,#8W,C8X8BP@,'@X,C<R-SDR92P*("`@("`@("`P>#4U,V9B,F,P+"`P>#0X
M.6%E,C)B+"`P>&0T968Y-SDT+"`P>#$R-64S9F)C+"`P>#(Q9F9F8V5E+"`P
M>#@R-6(Q8F9D+"`P>#DR-35C-65D+"`P>#$R-3=A,C0P+`H@("`@("`@(#!X
M-&4Q83@S,#(L(#!X8F%E,#=F9F8L(#!X-3(X,C0V93<L(#!X.&4U-S$T,&4L
M(#!X,S,W,V8W8F8L(#!X.&,Y9C@Q.#@L(#!X839F8S1E93@L(#!X8SDX,F(U
M834L"B`@("`@("`@,'AA.&,P,61B-RP@,'@U-SEF8S(V-"P@,'@V-S`Y-&8S
M,2P@,'AF,F)D,V8U9BP@,'@T,&9F9C=C,2P@,'@Q9F(W.&1F8RP@,'@X939B
M9#)C,2P@,'@T,S=B934Y8BP*("`@("`@("`P>#DY8C`S9&)F+"`P>&(U9&)C
M-C1B+"`P>#8S.&1C,&4V+"`P>#4U.#$Y9#DY+"`P>&$Q.3=C.#%C+"`P>#1A
M,#$R9#9E+"`P>&,U.#@T83(X+"`P>&-C8S,V9C<Q+`H@("`@("`@(#!X8C@T
M,V,R,3,L(#!X-F,P-S0S9C$L(#!X.#,P.3@Y,V,L(#!X,&9E9&1D-68L(#!X
M,F8W9F4X-3`L(#!X9#=C,#=F-V4L(#!X,#(U,#=F8F8L(#!X-6%F8CEA,#0L
M"B`@("`@("`@,'AA-S0W9#)D,"P@,'@Q-C4Q,3DR92P@,'AA9C<P8F8S92P@
M,'@U.&,S,3,X,"P@,'@U9CDX,S`R92P@,'@W,C=C8S-C-"P@,'@P83!F8C0P
M,BP@,'@P9C=F968X,BP*("`@("`@("`P>#AC.39F9&%D+"`P>#5D,F,R86%E
M+"`P>#AE93DY830Y+"`P>#4P9&$X.&(X+"`P>#@T,C=F-&$P+"`P>#%E86,U
M-SDP+"`P>#<Y-F9B-#0Y+"`P>#@R-3)D8S$U+`H@("`@("`@(#!X969B9#=D
M.6(L(#!X838W,C4Y-V0L(#!X861A.#0P9#@L(#!X-#5F-30U,#0L(#!X9F$U
M9#<T,#,L(#!X93@S96,S,#4L(#!X-&8Y,3<U,6$L(#!X.3(U-C8Y8S(L"B`@
M("`@("`@,'@R,V5F93DT,2P@,'AA.3`S9C$R92P@,'@V,#(W,&1F,BP@,'@P
M,C<V931B-BP@,'@Y-&9D-C4W-"P@,'@Y,C<Y.#5B,BP@,'@X,C<V9&)C8BP@
M,'@P,C<W.#$W-BP*("`@("`@("`P>&8X868Y,3AD+"`P>#1E-#AF-SEE+"`P
M>#AF-C$V9&1F+"`P>&4R.60X-#!E+"`P>#@T,F8W9#@S+"`P>#,T,&-E-6,X
M+"`P>#DV8F)B-C@R+"`P>#DS8C1B,30X+`H@("`@("`@(#!X968S,#-C86(L
M(#!X.3@T9F%F,C@L(#!X-S<Y9F%F.6(L(#!X.3)D8S4V,&0L(#!X,C(T9#%E
M,C`L(#!X.#0S-V%A.#@L(#!X-V0R.61C.38L(#!X,C<U-F0S9&,L"B`@("`@
M("`@,'@X8CDP-V-E92P@,'AB-3%F9#(T,"P@,'AE-V,P-V-E,RP@,'AE-38V
M8C1A,2P@,'AC,V4Y-C$U92P@,'@S8V8X,C`Y9"P@,'@V,#DT9#%E,RP@,'AC
M9#EC83,T,2P*("`@("`@("`P>#5C-S8T-C!E+"`P>#`P96$Y.#-B+"`P>&0T
M9#8W.#@Q+"`P>&9D-#<U-S)C+"`P>&8W-F-E9&0Y+"`P>&)D83@R,CEC+"`P
M>#$R-V1A9&%A+"`P>#0S.&$P-S1E+`H@("`@("`@(#!X,68Y-V,P.3`L(#!X
M,#@Q8F1B.&$L(#!X.3-A,#=E8F4L(#!X8CDS.&-A,34L(#!X.3=B,#-C9F8L
M(#!X,V1C,F,P9C@L(#!X.&0Q86(R96,L(#!X-C0S.#!E-3$L"B`@("`@("`@
M,'@V.&-C-V)F8BP@,'AD.3!F,C<X."P@,'@Q,C0Y,#$X,2P@,'@U9&4U9F9D
M-"P@,'AD9#=E9C@V82P@,'@W-F$R93(Q-"P@,'AB.6$T,#,V."P@,'@Y,C5D
M.34X9BP*("`@("`@("`P>#1B,SEF9F9A+"`P>&)A,SEA964Y+"`P>&$T9F9D
M,S!B+"`P>&9A9C<Y,S-B+"`P>#9D-#DX-C(S+"`P>#$Y,V-B8V9A+"`P>#(W
M-C(W-30U+"`P>#@R-6-F-#=A+`H@("`@("`@(#!X-C%B9#AB83`L(#!X9#$Q
M930R9#$L(#!X8V5A9#`T9C0L(#!X,3(W96$S.3(L(#!X,3`T,CAD8C<L(#!X
M.#(W,F$Y-S(L(#!X.3(W,&,T83@L(#!X,3(W9&4U,&(L"B`@("`@("`@,'@R
M.#5B83%C."P@,'@S8S8R9C0T9BP@,'@S-6,P96%A-2P@,'AE.#`U9#(S,2P@
M,'@T,C@Y,CEF8BP@,'AB-&9C9&8X,BP@,'@T9F(V-F$U,RP@,'@P93=D8S$U
M8BP*("`@("`@("`P>#%F,#@Q9F%B+"`P>#$P.#8Q.&%E+"`P>&9C9F0P.#9D
M+"`P>&8Y9F8R.#@Y+"`P>#8Y-&)C8S$Q+"`P>#(S-F$U8V%E+"`P>#$R9&5C
M831D+"`P>#)C,V8X8V,U+`H@("`@("`@(#!X9#)D,#)D9F4L(#!X9CAE9C4X
M.38L(#!X931C9C4R9&$L(#!X.34Q-35B-C<L(#!X-#DT830X.&,L(#!X8CEB
M-F$X,&,L(#!X-6,X9C@R8F,L(#!X.#ED,S9B-#4L"B`@("`@("`@,'@S838P
M.30S-RP@,'AE8S`P8SEA.2P@,'@T-#<Q-3(U,RP@,'@P83@W-&(T.2P@,'AD
M-S<S8F,T,"P@,'@W8S,T-C<Q8RP@,'@P,C<Q-V5F-BP@,'@T9F5B-34S-BP*
M("`@("`@("`P>&$R9#`R9F9F+"`P>&0R8F8V,&,T+"`P>&0T,V8P,V,P+"`P
M>#4P8C1E9C9D+"`P>#`W-#<X8V0Q+"`P>#`P-F4Q.#@X+"`P>&$R934S9C4U
M+"`P>&(Y939D-&)C+`H@("`@("`@(#!X83(P-#@P,38L(#!X.3<U-S,X,S,L
M(#!X9#<R,#=D-C<L(#!X9&4P9CAF,V0L(#!X-S)F.#=B,S,L(#!X86)C8S1F
M,S,L(#!X-S8X.&,U-60L(#!X-V(P,&$V8C`L"B`@("`@("`@,'@Y-#=B,#`P
M,2P@,'@U-S`P-S5D,BP@,'AF.6)B.#AF."P@,'@X.30R,#$Y92P@,'@T,C8T
M835F9BP@,'@X-38S,#)E,"P@,'@W,F1B9#DR8BP@,'AE93DW,6(V.2P*("`@
M("`@("`P>#9E83(R9F1E+"`P>#5F,#AA93)B+"`P>&%F-V$V,39D+"`P>&4U
M8SDX-S8W+"`P>&-F,69E8F0R+"`P>#8Q969C.&,R+"`P>&8Q86,R-3<Q+"`P
M>&-C.#(S.6,R+`H@("`@("`@(#!X-C<R,31C8C@L(#!X8C%E-3@S9#$L(#!X
M8C=D8S-E-C(L(#!X-V8Q,&)D8V4L(#!X9CDP835C,S@L(#!X,&9F,#0T,V0L
M(#!X-C`V939D8S8L(#!X-C`U-#-A-#DL"B`@("`@("`@,'@U-S(W8S$T."P@
M,'@R8F4Y.&$Q9"P@,'@X86(T,3<S."P@,'@R,&4Q8F4R-"P@,'AA9CDV9&$P
M9BP@,'@V.#0U.#0R-2P@,'@Y.3@S,V)E-2P@,'@V,#!D-#4W9"P*("`@("`@
M("`P>#(X,F8Y,S4P+"`P>#@S,S1B,S8R+"`P>&0Y,60Q,3(P+"`P>#)B-F0X
M9&$P+"`P>#8T,F(Q93,Q+"`P>#EC,S`U83`P+"`P>#4R8F-E-C@X+"`P>#%B
M,#,U.#AA+`H@("`@("`@(#!X9C=B865F9#4L(#!X-#$T,F5D.6,L(#!X830S
M,35C,3$L(#!X.#,S,C-E8S4L(#!X9&9E9C0V,S8L(#!X83$S,V,U,#$L(#!X
M93ED,S4S,6,L(#!X964S-3,W.#,I.PH*("`@("\J*@H@("`@("H@4R!B;W@@
M*',T*0H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1S-"`](&%R<F%Y*`H@("`@("`@(#!X.61B,S`T,C`L(#!X,69B-F4Y9&4L
M(#!X83=B93=B968L(#!X9#(W,V$R.3@L(#!X-&$T9C=B9&(L(#!X-C1A9#AC
M-3<L(#!X.#4U,3`T-#,L(#!X9F$P,C!E9#$L"B`@("`@("`@,'@W93(X-V%F
M9BP@,'AE-C!F8C8V,RP@,'@P.35F,S5A,2P@,'@W.65B9C$R,"P@,'AF9#`U
M.60T,RP@,'@V-#DW8C=B,2P@,'AF,S8T,68V,RP@,'@R-#%E-&%D9BP*("`@
M("`@("`P>#(X,30W9C5F+"`P>#1F83)B.&-D+"`P>&,Y-#,P,#0P+"`P>#!C
M8S,R,C(P+"`P>&9D9#,P8C,P+"`P>&,P834S-S1F+"`P>#%D,F0P,&0Y+"`P
M>#(T,30W8C$U+`H@("`@("`@(#!X964T9#$Q,6$L(#!X,&9C834Q-C<L(#!X
M-S%F9CDP-&,L(#!X,F0Q.35F9F4L(#!X,6$P-38T-68L(#!X,&,Q,V9E9F4L
M(#!X,#@Q8C`X8V$L(#!X,#4Q-S`Q,C$L"B`@("`@("`@,'@X,#4S,#$P,"P@
M,'AE.#-E-65F92P@,'AA8SEA9C1F."P@,'@W9F4W,C<P,2P@,'AD,F(X964U
M9BP@,'@P-F1F-#(V,2P@,'AB8CEE.6(X82P@,'@W,CDS96$R-2P*("`@("`@
M("`P>&-E.#1F9F1F+"`P>&8U-S$X.#`Q+"`P>#-D9#8T8C`T+"`P>&$R-F8R
M-C-B+"`P>#=E9#0X-#`P+"`P>#4T-V5E8F4V+"`P>#0T-F0T8V$P+"`P>#9C
M9C-D-F8U+`H@("`@("`@(#!X,C8T.6%B9&8L(#!X865A,&,W9C4L(#!X,S8S
M,SAC8S$L(#!X-3`S9C=E.3,L(#!X9#,W-S(P-C$L(#!X,3%B-C,X93$L(#!X
M-S(U,#!E,#,L(#!X9C@P96(R8F(L"B`@("`@("`@,'AA8F4P-3`R92P@,'AE
M8SAD-S=D92P@,'@U-SDW,64X,2P@,'AE,31F-C<T-BP@,'AC.3,S-30P,"P@
M,'@V.3(P,S$X9BP@,'@P.#%D8F(Y.2P@,'AF9F,S,#1A-2P*("`@("`@("`P
M>#1D,S4Q.#`U+"`P>#=F,V0U8V4S+"`P>&$V8S@V-F,V+"`P>#5D-6)C8V$Y
M+"`P>&1A96,V9F5A+"`P>#EF.3(V9CDQ+"`P>#EF-#8R,C)F+"`P>#,Y.3$T
M-C=D+`H@("`@("`@(#!X835B9C9D.&4L(#!X,3$T,V,T-&8L(#!X-#,Y-3@S
M,#(L(#!X9#`R,31E96(L(#!X,#(R,#@S8C@L(#!X,V9B-C$X,&,L(#!X,3AF
M.#DS,64L(#!X,C@Q-C4X938L"B`@("`@("`@,'@R-C0X-F4S92P@,'@X8F0W
M.&$W,"P@,'@W-#<W931C,2P@,'AB-3`V93`W8RP@,'AF,S)D,&$R-2P@,'@W
M.3`Y.&(P,BP@,'AE-&5A8F(X,2P@,'@R.#$R,V(R,RP*("`@("`@("`P>#8Y
M9&5A9#,X+"`P>#$U-S1C83$V+"`P>&1F.#<Q8C8R+"`P>#(Q,6,T,&(W+"`P
M>&$U,6$Y968Y+"`P>#`P,30S-S=B+"`P>#`T,64X86,X+"`P>#`Y,3$T,#`S
M+`H@("`@("`@(#!X8F0U.64T9#(L(#!X93-D,34V9#4L(#!X-&9E.#<V9#4L
M(#!X,F8Y,6$S-#`L(#!X-34W8F4X9&4L(#!X,#!E864T83<L(#!X,&-E-6,R
M96,L(#!X-&1B-&)B838L"B`@("`@("`@,'AE-S4V8F1F9BP@,'AD9#,S-CEA
M8RP@,'AE8S$W8C`S-2P@,'@P-C4W,C,R-RP@,'@Y.6%F8SAB,"P@,'@U-F,X
M8S,Y,2P@,'@V8C8U.#$Q8RP@,'@U93$T-C$Q.2P*("`@("`@("`P>#9E.#5C
M8C<U+"`P>&)E,#=C,#`R+"`P>&,R,S(U-3<W+"`P>#@Y,V9F-&5C+"`P>#5B
M8F9C.3)D+"`P>&0P96,S8C(U+"`P>&(W.#`Q86(W+"`P>#AD-F0S8C(T+`H@
M("`@("`@(#!X,C!C-S8S968L(#!X8S,V-F$U9F,L(#!X.6,S.#(X.#`L(#!X
M,&%C93,R,#4L(#!X86%C.34T.&$L(#!X96-A,60W8S<L(#!X,#0Q869A,S(L
M(#!X,60Q-C8R-6$L"B`@("`@("`@,'@V-S`Q.3`R8RP@,'@Y8C<U-V$U-"P@
M,'@S,60T-S=F-RP@,'@Y,3(V8C`S,2P@,'@S-F-C-F9D8BP@,'AC-S!B.&(T
M-BP@,'AD.64V-F$T."P@,'@U-F4U-6$W.2P*("`@("`@("`P>#`R-F$T8V5B
M+"`P>#4R-#,W969F+"`P>#)F.&8W-F(T+"`P>#!D9CDX,&$U+"`P>#@V-S1C
M9&4S+"`P>&5D9&$P-&5B+"`P>#$W83EB93`T+"`P>#)C,3AF-&1F+`H@("`@
M("`@(#!X8C<W-#=F.60L(#!X86(R868W8C0L(#!X969C,S1D,C`L(#!X,F4P
M.39B-V,L(#!X,3<T,6$R-30L(#!X935B-F$P,S4L(#!X,C$S9#0R9C8L(#!X
M,F,Q8S=C,C8L"B`@("`@("`@,'@V,6,R9C4P9BP@,'@V-34R9&%F.2P@,'AD
M,F,R,S%F."P@,'@R-3$S,&8V.2P@,'AD.#$V-V9A,BP@,'@P-#$X9C)C."P@
M,'@P,#%A.39A-BP@,'@P9#$U,C9A8BP*("`@("`@("`P>#8S,S$U8S(Q+"`P
M>#5E,&$W,F5C+"`P>#0Y8F%F969D+"`P>#$X-SDP.&0Y+"`P>#AD,&1B9#@V
M+"`P>#,Q,3$W,&$W+"`P>#-E.6(V-#!C+"`P>&-C,V4Q,&0W+`H@("`@("`@
M(#!X9#5C860S8C8L(#!X,&-A96,S.#@L(#!X9C<S,#`Q93$L(#!X-F,W,CAA
M9F8L(#!X-S%E864R83$L(#!X,68Y868S-F4L(#!X8V9C8F0Q,F8L(#!X8S%D
M93@T,3<L"B`@("`@("`@,'AA8S`W8F4V8BP@,'AC8C0T83%D."P@,'@X8CEB
M,&8U-BP@,'@P,3,Y.#AC,RP@,'AB,6,U,F9C82P@,'AB-&)E,S%C9"P@,'AD
M.#<X,C@P-BP@,'@Q,F$S831E,BP*("`@("`@("`P>#9F-V1E-3,R+"`P>#4X
M9F0W96(V+"`P>&0P,65E.3`P+"`P>#(T861F9F,R+"`P>&8T.3DP9F,U+"`P
M>#DW,3%A86,U+"`P>#`P,60W8CDU+"`P>#@R935E-V0R+`H@("`@("`@(#!X
M,3`Y.#<S9C8L(#!X,#`V,3,P.38L(#!X8S,R9#DU,C$L(#!X861A,3(Q9F8L
M(#!X,CDY,#@T,34L(#!X-V9B8CDW-V8L(#!X868Y96(S9&(L(#!X,CEC.65D
M,F$L"B`@("`@("`@,'@U8V4R830V-2P@,'AA-S,P9C,R8RP@,'AD,&%A,V9E
M."P@,'@X835C8S`Y,2P@,'AD-#EE,F-E-RP@,'@P8V4T-31A.2P@,'AD-C!A
M8V0X-BP@,'@P,35F,3DQ.2P*("`@("`@("`P>#<W,#<Y,3`S+"`P>&1E83`S
M868V+"`P>#<X83@U-C5E+"`P>&1E93,U-F1F+"`P>#(Q9C`U8V)E+"`P>#AB
M-S5E,S@W+"`P>&(S8S4P-C4Q+"`P>&(X835C,V5F+`H@("`@("`@(#!X9#AE
M96(V9#(L(#!X934R,V)E-S<L(#!X8S(Q-30U,CDL(#!X,F8V.65F9&8L(#!X
M869E-C=A9F(L(#!X9C0W,&,T8C(L(#!X9C-E,&5B-6(L(#!X9#9C8SDX-S8L
M"B`@("`@("`@,'@S.64T-#8P8RP@,'@Q9F1A.#4S."P@,'@Q.3@W.#,R9BP@
M,'AC83`P-S,V-RP@,'AA.3DQ-#1F."P@,'@R.39B,CDY92P@,'@T.3)F8S(Y
M-2P@,'@Y,C8V8F5A8BP*("`@("`@("`P>&(U-C<V938Y+"`P>#EB9#-D9&1A
M+"`P>&1F-V4P-3)F+"`P>&1B,C4W,#%C+"`P>#%B-64U,65E+"`P>&8V-3,R
M-&4V+"`P>#9A9F-E,S9C+"`P>#`S,39C8S`T+`H@("`@("`@(#!X.#8T-#(Q
M,V4L(#!X8C=D8S4Y9#`L(#!X-SDV-3(Y,68L(#!X8V-D-F9D-#,L(#!X-#$X
M,C,Y-SDL(#!X.3,R8F-D9C8L(#!X8C8U-V,S-&0L(#!X-&5D9F0R.#(L"B`@
M("`@("`@,'@W864U,CDP8RP@,'@S8V(Y-3,V8BP@,'@X-3%E,C!F92P@,'@Y
M.#,S-34W92P@,'@Q,V5C9C!B,"P@,'AD,V9F8C,W,BP@,'@S9C@U8S5C,2P@
M,'@P865F-V5D,BD["@H@("`@+RHJ"B`@("`@*B!3(&)O>"`H<S4I"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)',U(#T@87)R
M87DH"B`@("`@("`@,'@W96,Y,&,P-"P@,'@R8S9E-S1B.2P@,'@Y8C!E-C9D
M9BP@,'AA-C,S-SDQ,2P@,'AB.#9A-V9F9BP@,'@Q9&0S-3AF-2P@,'@T-&1D
M.60T-"P@,'@Q-S,Q,38W9BP*("`@("`@("`P>#`X9F)F,69A+"`P>&4W9C4Q
M,6-C+"`P>&0R,#4Q8C`P+"`P>#<S-6%B83`P+"`P>#)A8C<R,F0X+"`P>#,X
M-C,X,6-B+"`P>&%C9C8R-#-A+"`P>#8Y8F5F9#=A+`H@("`@("`@(#!X939A
M,F4W-V8L(#!X9C!C-S(P8V0L(#!X8S0T.30X,38L(#!X8V-F-6,Q.#`L(#!X
M,S@X-3$V-#`L(#!X,35B,&$X-#@L(#!X938X8C$X8V(L(#!X-&-A861E9F8L
M"B`@("`@("`@,'@U9C0X,&$P,2P@,'@P-#$R8C)A82P@,'@R-3DX,31F8RP@
M,'@T,60P969E,BP@,'@T930P8C0X9"P@,'@R-#AE8C9F8BP@,'@X9&)A,6-F
M92P@,'@T,6$Y.6(P,BP*("`@("`@("`P>#%A-34P83`T+"`P>&)A.&8V-6-B
M+"`P>#<R-3%F-&4W+"`P>#DU834Q-S(U+"`P>&,Q,#9E8V0W+"`P>#DW834Y
M.#!A+"`P>&,U,SEB.6%A+"`P>#1D-SEF939A+`H@("`@("`@(#!X9C)F,V8W
M-C,L(#!X-CAA9C@P-#`L(#!X960P8SEE-38L(#!X,3%B-#DU.&(L(#!X93%E
M8C5A.#@L(#!X.#<P.64V8C`L(#!X9#=E,#<Q-38L(#!X-&4R.69E83<L"B`@
M("`@("`@,'@V,S8V934R9"P@,'@P,F0Q8S`P,"P@,'AC-&%C.&4P-2P@,'@Y
M,S<W9C4W,2P@,'@P8S`U,S<R82P@,'@U-S@U,S5F,BP@,'@R,C8Q8F4P,BP@
M,'AD-C0R83!C.2P*("`@("`@("`P>&1F,3-A,C@P+"`P>#<T8C4U8F0R+"`P
M>#8X,C$Y.6,P+"`P>&0T,C%E-65C+"`P>#4S9F(S8V4X+"`P>&,X861E9&(S
M+"`P>#(X83@W9F,Y+"`P>#-D.34Y.3@Q+`H@("`@("`@(#!X-6,Q9F8Y,#`L
M(#!X9F4S.&0S.3DL(#!X,&,T969F,&(L(#!X,#8R-#`W96$L(#!X86$R9C1F
M8C$L(#!X-&9B.38Y-S8L(#!X.3!C-SDU,#4L(#!X8C!A.&$W-S0L"B`@("`@
M("`@,'AE9C4U83%F9BP@,'AE-3EC83)C,BP@,'AA-F(V,F0R-RP@,'AE-C9A
M-#(V,RP@,'AD9C8U,#`Q9BP@,'@P96,U,#DV-BP@,'AD9F1D-35B8RP@,'@R
M.61E,#8U-2P*("`@("`@("`P>#DQ,64W,SEA+"`P>#$W868X.3<U+"`P>#,R
M8S<Y,3%C+"`P>#@Y9C@Y-#8X+"`P>#!D,#%E.3@P+"`P>#4R-#<U-68T+"`P
M>#`S8C8S8V,Y+"`P>#!C8S@T-&(R+`H@("`@("`@(#!X8F-F,V8P86$L(#!X
M.#=A8S,V93DL(#!X934S83<T,C8L(#!X,#%B,V0X,F(L(#!X,6$Y93<T-#DL
M(#!X-C1E93)D-V4L(#!X8V1D8F(Q9&$L(#!X,#%C.30Y,3`L"B`@("`@("`@
M,'AB.#8X8F8X,"P@,'@P9#(V9C-F9"P@,'@Y,S0R961E-RP@,'@P-&$U8S(X
M-"P@,'@V,S8W,S=B-BP@,'@U,&8U8C8Q-BP@,'AF,C0W-C9E,RP@,'@X96-A
M,S9C,2P*("`@("`@("`P>#$S-F4P-61B+"`P>&9E9C$X,SDQ+"`P>&9B.#@W
M83,W+"`P>&0V93=F-V0T+"`P>&,W9F(W9&,Y+"`P>#,P-C-F8V1F+"`P>&(V
M9C4X.61E+"`P>&5C,CDT,61A+`H@("`@("`@(#!X,C9E-#8V.34L(#!X8C<U
M-C8T,3DL(#!X9C8U-&5F8S4L(#!X9#`X9#4X8C<L(#!X-#@Y,C4T,#$L(#!X
M8S%B86-B-V8L(#!X935F9C4U,&8L(#!X8C8P.#,P-#DL"B`@("`@("`@,'@U
M8F(U9#!E."P@,'@X-V0W,F4U82P@,'AA8C9A-F5E,2P@,'@R,C-A-C9C92P@
M,'AC-C)B9C-C9"P@,'@Y93`X.#5F.2P@,'@V.&-B,V4T-RP@,'@P.#9C,#$P
M9BP*("`@("`@("`P>&$R,61E.#(P+"`P>&0Q.&(V.61E+"`P>&8S9C8U-S<W
M+"`P>&9A,#)C,V8V+"`P>#0P-V5D86,S+"`P>&-B8C-D-34P+"`P>#$W.3,P
M.#1D+"`P>&(P9#<P96)A+`H@("`@("`@(#!X,&%B,S<X9#4L(#!X9#DU,69B
M,&,L(#!X9&5D-V1A-38L(#!X-#$R-&)B930L(#!X.31C83!B-38L(#!X,&8U
M-S4U9#$L(#!X93!E,64U-F4L(#!X-C$X-&(U8F4L"B`@("`@("`@,'@U.#!A
M,C0Y9BP@,'@Y-&8W-&)C,"P@,'AE,S(W.#@X92P@,'@Y9C=B-34V,2P@,'AC
M,V1C,#(X,"P@,'@P-38X-S<Q-2P@,'@V-#9C-F)D-RP@,'@T-#DP-&1B,RP*
M("`@("`@("`P>#8V8C1F,&$S+"`P>&,P9C$V-#AA+"`P>#8Y-V5D-6%F+"`P
M>#0Y93DR9F8V+"`P>#,P.64S-S1F+"`P>#)C8C8S-39A+"`P>#@U.#`X-3<S
M+"`P>#0Y.3%F.#0P+`H@("`@("`@(#!X-S9F,&%E,#(L(#!X,#@S8F4X-&0L
M(#!X,C@T,C%C.6$L(#!X-#0T.#DT,#8L(#!X-S,V931C8C@L(#!X8S$P.3(Y
M,3`L(#!X.&)C.35F8S8L(#!X-V0X-CEC9C0L"B`@("`@("`@,'@Q,S1F-C$V
M9BP@,'@R93<W,3$X9"P@,'AB,S%B,F)E,2P@,'AA83DP8C0W,BP@,'@S8V$U
M9#<Q-RP@,'@W9#$V,6)B82P@,'@Y8V%D.3`Q,"P@,'AA9C0V,F)A,BP*("`@
M("`@("`P>#EF930U.60R+"`P>#0U9#,T-34Y+"`P>&0Y9C)D83$S+"`P>&1B
M8S8U-#@W+"`P>&8S931F.31E+"`P>#$W-F0T.#9F+"`P>#`Y-V,Q,V5A+"`P
M>#8S,61A-6,W+`H@("`@("`@(#!X-#0U9C<S.#(L(#!X,3<U-C@S9C0L(#!X
M8V1C-C9A.3<L(#!X-S!B93`R.#@L(#!X8C-C9&-F-S(L(#!X-F4U9&0R9C,L
M(#!X,C`Y,S8P-SDL(#!X-#4Y8C@P834L"B`@("`@("`@,'AB938P93)D8BP@
M,'AA.6,R,S$P,2P@,'AE8F$U,S$U8RP@,'@R,C1E-#)F,BP@,'@Q8S5C,34W
M,BP@,'AF-C<R,6(R8RP@,'@Q860R9F9F,RP@,'@X8S(U-#`T92P*("`@("`@
M("`P>#,R-&5D-S)F+"`P>#0P-C=B-V9D+"`P>#`U,C,Q,SAE+"`P>#5C83-B
M8S<X+"`P>&1C,&9D-C9E+"`P>#<U.3(R,C@S+"`P>#<X-&0V8C$W+"`P>#4X
M96)B,39E+`H@("`@("`@(#!X-#0P.31F.#4L(#!X,V8T.#%D.#<L(#!X9F-F
M96%E-V(L(#!X-S=B-69F-S8L(#!X.&,R,S`R8F8L(#!X86%F-#<U-38L(#!X
M-68T-F(P,F$L(#!X,F(P.3(X,#$L"B`@("`@("`@,'@S9#,X9C5F-RP@,'@P
M8V$X,68S-BP@,'@U,F%F-&$X82P@,'@V-F0U93=C,"P@,'AD9C-B,#@W-"P@
M,'@Y-3`U-3$Q,"P@,'@Q8C5A9#=A."P@,'AF-C%E9#5A9"P*("`@("`@("`P
M>#9C9C9E-#<Y+"`P>#(P-S4X,3@T+"`P>&0P8V5F838U+"`P>#@X9C=B934X
M+"`P>#1A,#0V.#(V+"`P>#!F9C9F.&8S+"`P>&$P.6,W9C<P+"`P>#4S-#9A
M8F$P+`H@("`@("`@(#!X-6-E.39C,C@L(#!X93$W-F5D83,L(#!X-F)A8S,P
M-V8L(#!X,S<V.#(Y9#(L(#!X.#4S-C!F83DL(#!X,3=E,V9E,F$L(#!X,C1B
M-SDW-C<L(#!X9C5A.39B,C`L"B`@("`@("`@,'AD-F-D,C4Y-2P@,'@V.&9F
M,65B9BP@,'@W-34U-#0R8RP@,'AF,3EF,#9B92P@,'AF.64P-C4Y82P@,'AE
M96(Y-#DQ9"P@,'@S-#`Q,#<Q."P@,'AB8C,P8V%B."P*("`@("`@("`P>&4X
M,C)F93$U+"`P>#@X-3<P.3@S+"`P>#<U,&4V,C0Y+"`P>&1A-C(W934U+"`P
M>#5E-S9F9F$X+"`P>&(Q-3,T-30V+"`P>#9D-#=D93`X+"`P>&5F93EE-V0T
M*3L*"B`@("`O*BH*("`@("`J(%,@8F]X("AS-BD*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<S8@/2!A<G)A>2@*("`@("`@
M("`P>&8V9F$X9CED+"`P>#)C86,V8V4Q+"`P>#1C83,T.#8W+"`P>&4R,S,W
M9C=C+"`P>#DU9&(P.&4W+"`P>#`Q-C@T,V(T+"`P>&5C960U8V)C+"`P>#,R
M-34U,V%C+`H@("`@("`@(#!X8F8Y9C`Y-C`L(#!X9&9A,64R960L(#!X.#-F
M,#4W.60L(#!X-C-E9#@V8CDL(#!X,6%B-F$V8C@L(#!X9&4U96)E,SDL(#!X
M9C,X9F8W,S(L(#!X.#DX.6(Q,S@L"B`@("`@("`@,'@S,V8Q-#DV,2P@,'AC
M,#$Y,S=B9"P@,'AF-3`V8S9D82P@,'AE-#8R-64W92P@,'AA,S`X96$Y.2P@
M,'@T93(S93,S8RP@,'@W.6-B9#=C8RP@,'@T.&$Q-#,V-RP*("`@("`@("`P
M>&$S,30Y-C$Y+"`P>&9E8SDT8F0U+"`P>&$Q,30Q-S1A+"`P>&5A83`Q.#8V
M+"`P>&$P.#1D8C)D+"`P>#`Y83@T.#9F+"`P>&$X.#@V,31A+"`P>#(Y,#!A
M9CDX+`H@("`@("`@(#!X,#$V-C4Y.3$L(#!X93$Y.3(X-C,L(#!X8SAF,S!C
M-C`L(#!X,F4W.&5F,V,L(#!X9#!D-3$Y,S(L(#!X8V8P9F5C,30L(#!X9C=C
M83`W9#(L(#!X9#!A.#(P-S(L"B`@("`@("`@,'AF9#0Q,3DW92P@,'@Y,S`U
M839B,"P@,'AE.#9B93-D82P@,'@W-&)E9#-C9"P@,'@S-S)D834S8RP@,'@T
M8S=F-#0T."P@,'AD86(U9#0T,"P@,'@V9&)A,&5C,RP*("`@("`@("`P>#`X
M,SDQ.6$W+"`P>#EF8F%E960Y+"`P>#0Y9&)C9F(P+"`P>#1E-C<P8S4S+"`P
M>#5C,V0Y8S`Q+"`P>#8T8F1B.30Q+"`P>#)C,&4V,S9A+"`P>&)A-V1D.6-D
M+`H@("`@("`@(#!X96$V9C<S.#@L(#!X93<P8F,W-C(L(#!X,S5F,CEA9&(L
M(#!X-6,T8V1D.&0L(#!X9C!D-#AD.&,L(#!X8C@X,34S93(L(#!X,#AA,3DX
M-C8L(#!X,6%E,F5A8S@L"B`@("`@("`@,'@R.#1C868X.2P@,'AA83DR.#(R
M,RP@,'@Y,S,T8F4U,RP@,'@S8C-A,C%B9BP@,'@Q-C0S-&)E,RP@,'@Y865A
M,SDP-BP@,'AE9F4X8S,V92P@,'AF.#DP8V1D.2P*("`@("`@("`P>#@P,C(V
M9&%E+"`P>&,S-#!A-&$S+"`P>&1F-V4Y8S`Y+"`P>&$V.31A.#`W+"`P>#5B
M-V,U96-C+"`P>#(R,61B,V$V+"`P>#EA-CEA,#)F+"`P>#8X.#$X834T+`H@
M("`@("`@(#!X8V5B,C(Y-F8L(#!X-3-C,#@T,V$L(#!X9F4X.3,V-34L(#!X
M,C5B9F4V.&$L(#!X8C0V,CAA8F,L(#!X8V8R,C)E8F8L(#!X,C5A8S9F-#@L
M(#!X83EA.3DS.#<L"B`@("`@("`@,'@U,V)D9&(V-2P@,'AE-S9F9F)E-RP@
M,'AE.38W9F0W."P@,'@P8F$Y,S4V,RP@,'@X93,T,F)C,2P@,'AE.&$Q,6)E
M.2P@,'@T.3@P-S0P9"P@,'AC.#`X-V1F8RP*("`@("`@("`P>#AD931B9CDY
M+"`P>&$Q,3$P,6$P+"`P>#=F9#,W.3<U+"`P>&1A-6$R-F,P+"`P>&4X,68Y
M.31F+"`P>#DU,CAC9#@Y+"`P>&9D,S,Y9F5D+"`P>&(X-S@S-&)F+`H@("`@
M("`@(#!X-68P-#0U-F0L(#!X,C(R-3@V.3@L(#!X8SEC-&,X,V(L(#!X,F1C
M,34V8F4L(#!X-&8V,CAD86$L(#!X-3=F-35E8S4L(#!X93(R,C!A8F4L(#!X
M9#(Y,39E8F8L"B`@("`@("`@,'@T96,W-6(Y-2P@,'@R-&8R8S-C,"P@,'@T
M,F0Q-60Y.2P@,'AC9#!D-V9A,"P@,'@W8C9E,C=F9BP@,'AA.&1C.&%F,"P@
M,'@W,S0U8S$P-BP@,'AF-#%E,C,R9BP*("`@("`@("`P>#,U,38R,S@V+"`P
M>&4V96$X.3(V+"`P>#,S,S-B,#DT+"`P>#$U-V5C-F8R+"`P>#,W,F(W-&%F
M+"`P>#8Y,C4W,V4T+"`P>&4Y83ED.#0X+"`P>&8S,38P,C@Y+`H@("`@("`@
M(#!X,V$V,F5F,60L(#!X83<X-V4R,S@L(#!X9C-A-68V-S8L(#!X-S0S-C0X
M-3,L(#!X,C`Y-3$P-C,L(#!X-#4W-C8Y.&0L(#!X8C9F860T,#<L(#!X-3DR
M868Y-3`L"B`@("`@("`@,'@S-F8W,S4R,RP@,'@T8V9B-F4X-RP@,'@W9&$T
M8V5C,"P@,'@V8S$U,F1A82P@,'AC8C`S.39A."P@,'AC-3!D9F4U9"P@,'AF
M8V0W,#=A8BP@,'@P.3(Q8S0R9BP*("`@("`@("`P>#@Y9&9F,&)B+"`P>#5F
M93)B93<X+"`P>#0T.&8T9C,S+"`P>#<U-#8Q,V,Y+"`P>#)B,#5D,#AD+"`P
M>#0X8CED-3@U+"`P>&1C,#0Y-#0Q+"`P>&,X,#DX9CEB+`H@("`@("`@(#!X
M-V1E9&4W.#8L(#!X8S,Y83,S-S,L(#!X-#(T,3`P,#4L(#!X-F$P.3$W-3$L
M(#!X,&5F,V,X838L(#!X.#DP,#<R9#8L(#!X,C@R,#<V.#(L(#!X83EA.68W
M8F4L"B`@("`@("`@,'AB9C,R-C<Y9"P@,'AD-#5B-6(W-2P@,'AB,S4S9F0P
M,"P@,'AC8F(P93,U."P@,'@X,S!F,C(P82P@,'@Q9CAF8C(Q-"P@,'AD,S<R
M8V8P."P@,'AC8S-C-&$Q,RP*("`@("`@("`P>#AC9C8S,38V+"`P>#`V,6,X
M-V)E+"`P>#@X8SDX9C@X+"`P>#8P-C)E,SDW+"`P>#0W8V8X93=A+"`P>&(V
M8S@U,C@S+"`P>#-C8S)A8V9B+"`P>#-F8S`V.3<V+`H@("`@("`@(#!X-&4X
M9C`R-3(L(#!X-C1D.#,Q-&0L(#!X9&$S.#<P93,L(#!X,64V-C4T-3DL(#!X
M8S$P.3`X9C`L(#!X-3$S,#(Q834L(#!X-F,U8C8X8C<L(#!X.#(R9CAA83`L
M"B`@("`@("`@,'@S,#`W8V0S92P@,'@W-#<Q.65E9BP@,'AD8S@W,C8X,2P@
M,'@P-S,S-#!D-"P@,'@W930S,F9D.2P@,'@P8S5E8S(T,2P@,'@X.#`Y,C@V
M8RP@,'AF-3DR9#@Y,2P*("`@("`@("`P>#`X83DS,&8V+"`P>#DU-V5F,S`U
M+"`P>&(W9F)F9F)D+"`P>&,R-C9E.39F+"`P>#9F931A8SDX+"`P>&(Q-S-E
M8V,P+"`P>&)C-C!B-#)A+"`P>#DU,S0Y.&1A+`H@("`@("`@(#!X9F)A,6%E
M,3(L(#!X,F0T8F0W,S8L(#!X,&8R-69A86(L(#!X831F,V9C96(L(#!X93(Y
M-CDQ,C,L(#!X,C4W9C!C,V0L(#!X.3,T.&%F-#DL(#!X,S8Q-#`P8F,L"B`@
M("`@("`@,'AE.#@Q-F8T82P@,'@S.#$T9C(P,"P@,'AA,V8Y-#`T,RP@,'@Y
M8S=A-31C,BP@,'AB8S<P-&8U-RP@,'AD830Q93=F.2P@,'AC,C5A9#,S82P@
M,'@U-&8T83`X-"P*("`@("`@("`P>&(Q-V8U-3`U+"`P>#4Y,S4W8V)E+"`P
M>&5D8F0Q-6,X+"`P>#=F.3=C-6%B+"`P>&)A-6%C-V(U+"`P>&(V9C9D96%F
M+"`P>#-A-#<Y8S-A+"`P>#4S,#)D83(U+`H@("`@("`@(#!X-C4S9#=E-F$L
M(#!X-30R-CAD-#DL(#!X-3%A-#<W96$L(#!X-3`Q-V0U-6(L(#!X9#=D,C5D
M.#@L(#!X-#0Q,S9C-S8L(#!X,#0P-&$X8S@L(#!X8CAE-6$Q,C$L"B`@("`@
M("`@,'AB.#%A.3(X82P@,'@V,&5D-3@V.2P@,'@Y-V,U-6(Y-BP@,'AE865C
M.3DQ8BP@,'@R.3DS-3DQ,RP@,'@P,69D8C=F,2P@,'@P.#AE.&1F82P@,'@Y
M86(V9C9F-2P*("`@("`@("`P>#-B-&-B9CEF+"`P>#1A-61E,V%B+"`P>&4V
M,#4Q9#,U+"`P>&$P93%D.#4U+"`P>&0S-F(T8V8Q+"`P>&8U-#1E9&5B+"`P
M>&(P93DS-3(T+"`P>&)E8F(X9F)D+`H@("`@("`@(#!X83)D-S8R8V8L(#!X
M-#EC.3)F-30L(#!X,SAB-68S,S$L(#!X-S$R.&$T-30L(#!X-#@S.3(Y,#4L
M(#!X838U8C%D8C@L(#!X.#4Q8SDW8F0L(#!X9#8W-6-F,F8I.PH*("`@("\J
M*@H@("`@("H@4R!B;W@@*',W*0H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1S-R`](&%R<F%Y*`H@("`@("`@(#!X.#5E,#0P
M,3DL(#!X,S,R8F8U-C<L(#!X-C8R9&)F9F8L(#!X8V9C-C4V.3,L(#!X,F$X
M9#=F-F8L(#!X86(Y8F,Y,3(L(#!X9&4V,#`X83$L(#!X,C`R.&1A,68L"B`@
M("`@("`@,'@P,C(W8F-E-RP@,'@T9#8T,CDQ-BP@,'@Q.&9A8S,P,"P@,'@U
M,&8Q.&(X,BP@,'@R8V(R8V(Q,2P@,'AB,C,R93<U8RP@,'@T8C,V.35F,BP@
M,'AB,C@W,#=D92P*("`@("`@("`P>&$P-69B8V8V+"`P>&-D-#$X,64Y+"`P
M>&4Q-3`R,3!C+"`P>&4R-&5F,6)D+"`P>&(Q-CAC,S@Q+"`P>&9D931E-S@Y
M+"`P>#5C-SEB,&0X+"`P>#%E.&)F9#0S+`H@("`@("`@(#!X-&0T.34P,#$L
M(#!X,SAB930S-#$L(#!X.3$S8V5E,60L(#!X.3)A-SEC,V8L(#!X,#@Y-S8V
M8F4L(#!X8F%E96%D9C0L(#!X,3(X-F)E8V8L(#!X8C9E86-B,3DL"B`@("`@
M("`@,'@R-C8P8S(P,"P@,'@W-38U8F1E-"P@,'@V-#(T,68W82P@,'@X,C0X
M9&-A.2P@,'AC,V(S860V-BP@,'@R.#$S-C`X-BP@,'@P8F0X9&9A."P@,'@S
M-39D,6-F,BP*("`@("`@("`P>#$P-S<X.6)E+"`P>&(S8C)E.6-E+"`P>#`U
M,#)A83AF+"`P>#!B8S`S-3%E+"`P>#$V-F)F-3)A+"`P>&5B,3)F9C@R+"`P
M>&4S-#@V.3$Q+"`P>&0S-&0W-3$V+`H@("`@("`@(#!X-&4W8C-A9F8L(#!X
M-68T,S8W,6(L(#!X.6-F-F4P,S<L(#!X-#DX,6%C.#,L(#!X,S,T,C8V8V4L
M(#!X.&,Y,S0Q8C<L(#!X9#!D.#4T8S`L(#!X8V(S839C.#@L"B`@("`@("`@
M,'@T-V)C,C@R.2P@,'@T-S(U8F$S-RP@,'AA-C9A9#(R8BP@,'@W860V,68Q
M92P@,'@P8S5C8F%F82P@,'@T-#,W9C$P-RP@,'AB-F4W.3DV,BP@,'@T,F0R
M9#@Q-BP*("`@("`@("`P>#!A.38Q,C@X+"`P>&4Q835C,#9E+"`P>#$S-S0Y
M938W+"`P>#<R9F,P.#%A+"`P>&(Q9#$S.68W+"`P>&8Y-3@S-S0U+"`P>&-F
M,3ED9C4X+"`P>&)E8S-F-S4V+`H@("`@("`@(#!X8S`V96)A,S`L(#!X,#<R
M,3%B,C0L(#!X-#5C,C@X,CDL(#!X8SDU93,Q-V8L(#!X8F,X96,U,3$L(#!X
M,SAB8S0V93DL(#!X8S9E-F9A,30L(#!X8F%E.#4X-&$L"B`@("`@("`@,'AA
M9#1E8F,T-BP@,'@T-CAF-3`X8BP@,'@W.#(Y-#,U9BP@,'AF,3(T,3@S8BP@
M,'@X,C%D8F$Y9BP@,'AA9F8V,&9F-"P@,'AE83)C-&4V9"P@,'@Q-F4S.3(V
M-"P*("`@("`@("`P>#DR-30T83AB+"`P>#`P.6(T9F,S+"`P>&%B838X8V5D
M+"`P>#EA8SDV9C<X+"`P>#`V835B-SEA+"`P>&(R.#4V939E+"`P>#%A96,S
M8V$Y+"`P>&)E.#,X-C@X+`H@("`@("`@(#!X,&4P.#`T93DL(#!X-35F,6)E
M-38L(#!X93=E-3,V,V(L(#!X8C-A,68R-60L(#!X9C=D96)B.#4L(#!X-C%F
M93`S,V,L(#!X,38W-#8R,S,L(#!X,V,P,S1C,C@L"B`@("`@("`@,'AD839D
M,&,W-"P@,'@W.6%A8S4V8RP@,'@S8V4T93%A9"P@,'@U,68P8S@P,BP@,'@Y
M.&8X9C,U82P@,'@Q-C(V830Y9BP@,'AE960X,F(R.2P@,'@Q9#,X,F9E,RP*
M("`@("`@("`P>#!C-&9B.3EA+"`P>&)B,S(U-S<X+"`P>#-E8S9D.3=B+"`P
M>#9E-S=A-F$Y+"`P>&-B-C4X8C5C+"`P>&0T-3(S,&,W+"`P>#)B9#$T,#AB
M+"`P>#8P8S`S96(W+`H@("`@("`@(#!X8CDP-CAD-S@L(#!X83,S-S4T9C0L
M(#!X9C0S,&,X-V0L(#!X8SAA-S$S,#(L(#!X8CDV9#AC,S(L(#!X96)D-&4W
M8F4L(#!X8F4X8CED,F0L(#!X-SDW.69B,#8L"B`@("`@("`@,'AE-S(R-3,P
M."P@,'@X8C<U8V8W-RP@,'@Q,65F.&1A-"P@,'AE,#@S8S@U."P@,'@X9#9B
M-S@V9BP@,'@U838S,3=A-BP@,'AF835C9C=A,"P@,'@U9&1A,#`S,RP*("`@
M("`@("`P>&8R.&5B9F(P+"`P>&8U8CEC,S$P+"`P>&$P96%C,C@P+"`P>#`X
M8CDW-C=A+"`P>&$S9#ED,F(P+"`P>#<Y9#,T,C$W+"`P>#`R,6$W,3AD+"`P
M>#EA8S8S,S9A+`H@("`@("`@(#!X,C<Q,69D-C`L(#!X-#,X,#4P93,L(#!X
M,#8Y.3`X83@L(#!X,V0W9F5D8S0L(#!X.#(V9#)B968L(#!X-&5E8C@T-S8L
M(#!X-#@X9&-F,C4L(#!X,S9C.60U-C8L"B`@("`@("`@,'@R.&4W-&4T,2P@
M,'AC,C8Q,&%C82P@,'@S9#0Y83EC9BP@,'AB864S8CED9BP@,'AB-C5F.&1E
M-BP@,'@Y,F%E868V-"P@,'@S86,W9#5E-BP@,'@Y96$X,#4P.2P*("`@("`@
M("`P>&8R,F(P,3=D+"`P>&$T,3<S9C<P+"`P>&1D,64Q-F,S+"`P>#$U93!D
M-V8Y+"`P>#4P8C%B.#@W+"`P>#)B.68T9F0U+"`P>#8R-6%B83@R+"`P>#9A
M,#$W.38R+`H@("`@("`@(#!X,F5C,#%B.6,L(#!X,34T.#AA83DL(#!X9#<Q
M-F4W-#`L(#!X-#`P-35A,F,L(#!X.3-D,CEA,C(L(#!X93,R9&)F.6$L(#!X
M,#4X-S0U8CDL(#!X,S0U,V1C,64L"B`@("`@("`@,'AD-CDY,CDV92P@,'@T
M.39C9F8V9BP@,'@Q8SEF-#DX-BP@,'AD9F4R960P-RP@,'AB.#<R-#)D,2P@
M,'@Q.61E-V5A92P@,'@P-3-E-38Q82P@,'@Q-6%D-F8X8RP*("`@("`@("`P
M>#8V-C(V8S%C+"`P>#<Q-31C,C1C+"`P>&5A,#@R8C)A+"`P>#DS96(R.3,Y
M+"`P>#$W9&-B,&8P+"`P>#4X9#1F,F%E+"`P>#EE83(Y-&9B+"`P>#4R8V8U
M-C1C+`H@("`@("`@(#!X.3@X,V9E-C8L(#!X,F5C-#`U.#$L(#!X-S8S.34S
M8S,L(#!X,#%D-C8Y,F4L(#!X9#-A,&,Q,#@L(#!X83%E-S$V,&4L(#!X931F
M,F1F838L(#!X-CDS960R.#4L"B`@("`@("`@,'@W-#DP-#8Y."P@,'@T8S)B
M,&5D9"P@,'@T9C<U-S8U-BP@,'@U9#,Y,S,W."P@,'AA,3,R,C,T9BP@,'@S
M9#,R,6,U9"P@,'AC,V8U93$Y-"P@,'@T8C(V.3,P,2P*("`@("`@("`P>&,W
M.68P,C)F+"`P>#-C.3DW93=E+"`P>#5E-&8Y-3`T+"`P>#-F9F%F8F)D+"`P
M>#<V9C=A9#!E+"`P>#(Y-C8Y,V8T+"`P>#-D,69C939F+"`P>&,V,64T-6)E
M+`H@("`@("`@(#!X9#-B-6%B,S0L(#!X9C<R8F8Y8C<L(#!X,6(P-#,T8S`L
M(#!X-&4W,F(U-C<L(#!X-34Y,F$S,V0L(#!X8C4R,CDS,#$L(#!X8V9D,F$X
M-V8L(#!X-C!A96(W-C<L"B`@("`@("`@,'@Q.#$T,S@V8BP@,'@S,&)C8S,S
M9"P@,'@S.&$P8S`W9"P@,'AF9#$V,#9F,BP@,'AC,S8S-3$Y8BP@,'@U.#ED
M9#,Y,"P@,'@U-#<Y9CAE-BP@,'@Q8V(X9#8T-RP*("`@("`@("`P>#DW9F0V
M,6$Y+"`P>&5A-S<U.68T+"`P>#)D-3<U,SED+"`P>#4V.6$U.&-F+"`P>&4X
M-&4V,V%D+"`P>#0V,F4Q8C<X+"`P>#8U.#!F.#=E+"`P>&8S.#$W.3$T+`H@
M("`@("`@(#!X.3%D834U9C0L(#!X-#!A,C,P9C,L(#!X9#$Y.#AF,S4L(#!X
M8C9E,S$X9#(L(#!X,V9F834P8F,L(#!X,V0T,&8P,C$L(#!X8S-C,&)D864L
M(#!X-#DU.&,R-&,L"B`@("`@("`@,'@U,3AF,S9B,BP@,'@X-&(Q9#,W,"P@
M,'@P9F5D8V4X,RP@,'@X-SAD9&%D82P@,'AF,F$R-SEC-RP@,'@Y-&4P,6)E
M."P@,'@Y,#<Q-F8T8BP@,'@Y-31B.&%A,RD["@H@("`@+RHJ"B`@("`@*B!3
M(&)O>"`H<S@I"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)',X(#T@87)R87DH"B`@("`@("`@,'AE,C$V,S`P9"P@,'AB8F1D
M9F9F8RP@,'AA-V5B9&%B9"P@,'@S-38T.#`Y-2P@,'@W-S@Y9CAB-RP@,'AE
M-F,Q,3(Q8BP@,'@P93(T,38P,"P@,'@P-3)C93AB-2P*("`@("`@("`P>#$Q
M83EC9F(P+"`P>&4U.34R9C$Q+"`P>&5C93<Y.3!A+"`P>#DS.#9D,3<T+"`P
M>#)A-#(Y,S%C+"`P>#<V93,X,3$Q+"`P>&(Q,F1E9C-A+"`P>#,W9&1D9&9C
M+`H@("`@("`@(#!X9&4Y861E8C$L(#!X,&$P8V,S,F,L(#!X8F4Q.3<P,CDL
M(#!X.#1A,#`Y-#`L(#!X8F(R-#-A,&8L(#!X8C1D,3,W8V8L(#!X8C0T93<Y
M9C`L(#!X,#0Y965D9F0L"B`@("`@("`@,'@P8C$U83$U9"P@,'@T.#!D,S$V
M."P@,'@X8F)B9&4U82P@,'@V-CED960T,BP@,'AC-V5C93@S,2P@,'@S9CAF
M.35E-RP@,'@W,F1F,3DQ8BP@,'@W-3@P,S,P9"P*("`@("`@("`P>#DT,#<T
M,C4Q+"`P>#5C-V1C9&9A+"`P>&%B8F4V9#8S+"`P>&%A-#`R,38T+"`P>&(S
M,#%D-#!A+"`P>#`R93=D,6-A+"`P>#4S-3<Q9&%E+"`P>#=A,S$X,F$R+`H@
M("`@("`@(#!X,3)A.&1D96,L(#!X9F1A83,S-60L(#!X,3<V9C0S93@L(#!X
M-S%F8C0V9#0L(#!X,S@Q,CDP,C(L(#!X8V4Y-#EA9#0L(#!X8C@T-S8Y860L
M(#!X.38U8F0X-C(L"B`@("`@("`@,'@X,F8S9#`U-2P@,'@V-F9B.3<V-RP@
M,'@Q-6(X,&(T92P@,'@Q9#5B-#=A,"P@,'@T8V9D93`V9BP@,'AC,CAE8S1B
M."P@,'@U-V4X-S(V92P@,'@V-#=A-SAF8RP*("`@("`@("`P>#DY.#8U9#0T
M+"`P>#8P.&)D-3DS+"`P>#9C,C`P93`S+"`P>#,Y9&,U9F8V+"`P>#5D,&(P
M,&$S+"`P>&%E-C-A9F8R+"`P>#=E.&)D-C,R+"`P>#<P,3`X8S!C+`H@("`@
M("`@(#!X8F)D,S4P-#DL(#!X,CDY.&1F,#0L(#!X.3@P8V8T,F$L(#!X.6(V
M9&8T.3$L(#!X.64W961D-3,L(#!X,#8Y,3@U-#@L(#!X-3AC8C=E,#<L(#!X
M,V(W-&5F,F4L"B`@("`@("`@,'@U,C)F9F9B,2P@,'AD,C0W,#AC8RP@,'@Q
M8S=E,C=C9"P@,'AA-&5B,C$U8BP@,'@S8V8Q9#)E,BP@,'@Q.6(T-V$S."P@
M,'@T,C1F-S8Q."P@,'@S-3@U-C`S.2P*("`@("`@("`P>#ED,3=D964W+"`P
M>#(W96(S-64V+"`P>&,Y869F-C=B+"`P>#,V8F%F-6(X+"`P>#`Y8S0V-V-D
M+"`P>&,Q.#DQ,&(Q+"`P>&4Q,61B9C=B+"`P>#`V8V0Q868X+`H@("`@("`@
M(#!X-S$W,&,V,#@L(#!X,F0U93,S-30L(#!X9#1D930Y-6$L(#!X-C1C-F0P
M,#8L(#!X8F-C,&,V,F,L(#!X,V1D,#!D8C,L(#!X-S`X9CAF,S0L(#!X-S=D
M-3%B-#(L"B`@("`@("`@,'@R-C1F-C(P9BP@,'@R-&(X9#)B9BP@,'@Q-6,Q
M8C<Y92P@,'@T-F$U,C4V-"P@,'AF.&0W934T92P@,'@S93,W.#$V,"P@,'@W
M.#DU8V1A-2P@,'@X-3EC,35A-2P*("`@("`@("`P>&4V-#4Y-S@X+"`P>&,S
M-V)C-S5F+"`P>&1B,#=B83!C+"`P>#`V-S9A,V%B+"`P>#=F,C(Y8C%E+"`P
M>#,Q.#0R93=B+"`P>#(T,C4Y9F0W+"`P>&8X8F5F-#<R+`H@("`@("`@(#!X
M.#,U9F9C8C@L(#!X-F1F-&,Q9C(L(#!X.39F-6(Q.34L(#!X9F0P868P9F,L
M(#!X8C!F93$S-&,L(#!X93(U,#9D,V0L(#!X-&8Y8C$R96$L(#!X9C(Q-68R
M,C4L"B`@("`@("`@,'AA,C(S-S,V9BP@,'@Y9F(T8S0R."P@,'@R-60P-#DW
M.2P@,'@S-&,W,3-F."P@,'AC-#8Q.#$X-RP@,'AE83=A-F4Y."P@,'@W8V0Q
M-F5F8RP@,'@Q-#,V.#<V8RP*("`@("`@("`P>&8Q-30T,3`W+"`P>&)E9&5E
M93$T+"`P>#4V93EA9C(W+"`P>&$P-&%A-#0Q+"`P>#-C9C=C.#DY+"`P>#DR
M96-B864V+"`P>&1D-C<P,39D+"`P>#$U,38X,F5B+`H@("`@("`@(#!X83@T
M,F5E9&8L(#!X9F1B838P8C0L(#!X9C$Y,#=B-S4L(#!X,C!E,S`S,&8L(#!X
M,C1D.&,R.64L(#!X93$S.38W,V(L(#!X969A-C-F8C@L(#!X-S$X-S,P-30L
M"B`@("`@("`@,'AB-F8R8V8S8BP@,'@Y9C,R-C0T,BP@,'AC8C$U831C8RP@
M,'AB,#%A-#4P-"P@,'AF,64T-V0X9"P@,'@X-#1A,6)E-2P@,'AB864W9&9D
M8RP@,'@T,F-B9&$W,"P*("`@("`@("`P>&-D-V1A93!A+"`P>#4W93@U8C=A
M+"`P>&0U,V8U868V+"`P>#(P8V8T9#AC+"`P>&-E831D-#(X+"`P>#<Y9#$S
M,&$T+"`P>#,T.#9E8F9B+"`P>#,S9#-C9&1C+`H@("`@("`@(#!X-S<X-3-B
M-3,L(#!X,S=E9F9C8C4L(#!X8S4P-C@W-S@L(#!X934X,&(S938L(#!X-&4V
M.&(X9C0L(#!X8S5C.&(S-V4L(#!X,&0X,#EE83(L(#!X,SDX9F5B-V,L"B`@
M("`@("`@,'@Q,S)A-&8Y-"P@,'@T,V(W.34P92P@,'@R9F5E-V0Q8RP@,'@R
M,C,V,3-B9"P@,'AD9#`V8V%A,BP@,'@S-V1F.3,R8BP@,'AC-#(T.#(X.2P@
M,'AA8V8S96)C,RP*("`@("`@("`P>#4W,35F-F(W+"`P>&5F,S0W.&1D+"`P
M>&8R-C<V,39F+"`P>&,Q-#AC8F4T+"`P>#DP-3(X,35E+"`P>#5E-#$P9F%B
M+"`P>&(T.&$R-#8U+"`P>#)E9&$W9F$T+`H@("`@("`@(#!X93@W8C0P930L
M(#!X93DX96$P.#0L(#!X-3@X.64Y93$L(#!X969D,SDP9F,L(#!X9&0P-V0S
M-6(L(#!X9&(T.#4V.30L(#!X,SAD-V4U8C(L(#!X-3<W,C`Q,#$L"B`@("`@
M("`@,'@W,S!E9&5B8RP@,'@U8C8T,S$Q,RP@,'@Y-#DQ-V4T9BP@,'@U,#-C
M,F9B82P@,'@V-#9F,3(X,BP@,'@W-3(S9#(T82P@,'AE,#<W.38Y-2P@,'AF
M.6,Q-V$X9BP*("`@("`@("`P>#=A-6(R,3(Q+"`P>&0Q.#=B.#DV+"`P>#(Y
M,C8S831D+"`P>&)A-3$P8V1F+"`P>#@Q9C0W8SEF+"`P>&%D,3$V,V5D+"`P
M>&5A-V(U.38U+"`P>#%A,#`W,C9E+`H@("`@("`@(#!X,3$T,#,P.3(L(#!X
M,#!D839D-S<L(#!X-&$P8V1D-C$L(#!X860Q9C0V,#,L(#!X-C`U8F1F8C`L
M(#!X.65E9&,S-C0L(#!X,C)E8F4V83@L(#!X8V5E-V0R.&$L"B`@("`@("`@
M,'AA,&4W,S9A,"P@,'@U-38T839B.2P@,'@Q,#@U,S(P.2P@,'AC-V5B.&8S
M-RP@,'@R9&4W,#5C82P@,'@X.34Q-3<P9BP@,'AD9C`Y.#(R8BP@,'AB9#8Y
M,6$V8RP*("`@("`@("`P>&%A,3)E-&8R+"`P>#@W-#4Q8S!F+"`P>&4P9C9A
M,C=A+"`P>#-A9&$T.#$Y+"`P>#1C9C$W-C1F+"`P>#!D-S<Q8S)B+"`P>#8W
M8V1B,34V+"`P>#,U,&0X,S@T+`H@("`@("`@(#!X-3DS.&9A,&8L(#!X-#(S
M.3EE9C,L(#!X,S8Y.3=B,#<L(#!X,&4X-#`Y,V0L(#!X-&%A.3-E-C$L(#!X
M.#,V,&0X-V(L(#!X,69A.3AB,&,L(#!X,3$T.3,X,F,L"B`@("`@("`@,'AE
M.3<V,C5A-2P@,'@P-C$T9#%B-RP@,'@P93(U,C0T8BP@,'@P8S<V.#,T-RP@
M,'@U.#EE.&0X,BP@,'@P9#(P-3ED,2P@,'AA-#8V8F(Q92P@,'AF.&1A,&$X
M,BP*("`@("`@("`P>#`T9C$Y,3,P+"`P>&)A-F4T96,P+"`P>#DY,C8U,38T
M+"`P>#%E93<R,S!D+"`P>#4P8C)A9#@P+"`P>&5A964V.#`Q+"`P>#AD8C)A
M,C@S+"`P>&5A.&)F-3EE*3L*"B`@("`O*BH*("`@("`J($UA<VMI;F<@2V5Y
M<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M2VT@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@4F]T871E($ME>7,*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7TMR(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@<F]U;F1S
M('1O(&1O"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D7W)O=6YD<R`](#$V.PH*("`@("\J*@H@("`@("H@4V5T('1H92!K
M97D@=&\@8F4@=7-E9"!F;W(@96XO9&5C<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971+97DH)&ME>2D*("`@('L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]R;W5N9',@
M/2`H<W1R;&5N*"1K97DI(#P@,3$I(#\@,3(@.B`Q-CL*("`@("`@("`@("`@
M)&ME>2`]("1T:&ES+3Y?9F]R;6%T2V5Y*"1K97DI.PH@("`@("`@("`@("`D
M:V5Y4V-H961U;&4@/2`D=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<VEZ92!O
M9B!T:&4@8FQO8VMS('1H870@=&AI<R!C:7!H97(@;F5E9',N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R(&]F(&-H87)A8W1E
M<G,@<&5R(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971";&]C:U-I
M>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`X.PH@("`@?0H*("`@("\J*@H@
M("`@("H@16YC<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O(&5N8W)Y<'0N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;F-R>7!T960@;W5T
M<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T0FQO8VLH)&)L;V-K
M+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&ME
M>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]R;W5N9',@/2`H<W1R;&5N*"1K
M97DI(#P@,3$I(#\@,3(@.B`Q-CL*("`@("`@("`@("`@)&ME>2`]("1T:&ES
M+3Y?9F]R;6%T2V5Y*"1K97DI.PH@("`@("`@("`@("`D:V5Y4V-H961U;&4@
M/2`D=&AI<RT^7VME>5-C:&5D=6QE*"1K97DI.PH@("`@("`@('T*"B`@("`@
M("`@)$P@/2`D=&AI<RT^7V9O<FUA=$1A=&$H<W5B<W1R*"1B;&]C:RP@,"P@
M-"DI.PH@("`@("`@("12(#T@)'1H:7,M/E]F;W)M871$871A*'-U8G-T<B@D
M8FQO8VLL(#0L(#0I*3L*"B`@("`@("`@)$P@7CT@)'1H:7,M/F8Q*"12+"`D
M=&AI<RT^7TMM6S%=+"`@)'1H:7,M/E]+<ELQ72D["B`@("`@("`@)%(@7CT@
M)'1H:7,M/F8R*"1,+"`D=&AI<RT^7TMM6S)=+"`@)'1H:7,M/E]+<ELR72D[
M"B`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM6S-=+"`@
M)'1H:7,M/E]+<ELS72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8Q*"1,+"`D
M=&AI<RT^7TMM6S1=+"`@)'1H:7,M/E]+<ELT72D["B`@("`@("`@)$P@7CT@
M)'1H:7,M/F8R*"12+"`D=&AI<RT^7TMM6S5=+"`@)'1H:7,M/E]+<ELU72D[
M"B`@("`@("`@)%(@7CT@)'1H:7,M/F8S*"1,+"`D=&AI<RT^7TMM6S9=+"`@
M)'1H:7,M/E]+<ELV72D["B`@("`@("`@)$P@7CT@)'1H:7,M/F8Q*"12+"`D
M=&AI<RT^7TMM6S==+"`@)'1H:7,M/E]+<ELW72D["B`@("`@("`@)%(@7CT@
M)'1H:7,M/F8R*"1,+"`D=&AI<RT^7TMM6SA=+"`@)'1H:7,M/E]+<ELX72D[
M"B`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM6SE=+"`@
M)'1H:7,M/E]+<ELY72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8Q*"1,+"`D
M=&AI<RT^7TMM6S$P72P@)'1H:7,M/E]+<ELQ,%TI.PH@("`@("`@("1,(%X]
M("1T:&ES+3YF,B@D4BP@)'1H:7,M/E]+;5LQ,5TL("1T:&ES+3Y?2W);,3%=
M*3L*("`@("`@("`D4B!>/2`D=&AI<RT^9C,H)$PL("1T:&ES+3Y?2VU;,3)=
M+"`D=&AI<RT^7TMR6S$R72D["B`@("`@("`@:68@*"1T:&ES+3Y?<F]U;F1S
M(#X@,3(I('L*("`@("`@("`@("`@)$P@7CT@)'1H:7,M/F8Q*"12+"`D=&AI
M<RT^7TMM6S$S72P@)'1H:7,M/E]+<ELQ,UTI.PH@("`@("`@("`@("`D4B!>
M/2`D=&AI<RT^9C(H)$PL("1T:&ES+3Y?2VU;,31=+"`D=&AI<RT^7TMR6S$T
M72D["B`@("`@("`@("`@("1,(%X]("1T:&ES+3YF,R@D4BP@)'1H:7,M/E]+
M;5LQ-5TL("1T:&ES+3Y?2W);,35=*3L*("`@("`@("`@("`@)%(@7CT@)'1H
M:7,M/F8Q*"1,+"`D=&AI<RT^7TMM6S$V72P@)'1H:7,M/E]+<ELQ-ETI.PH@
M("`@("`@('T*"B`@("`@("`@)&5N8W)Y<'1E9"`]('!A8VLH(DXB+"`D4BD@
M+B!P86-K*").(BP@)$PI.PH*("`@("`@("!R971U<FX@)&5N8W)Y<'1E9#L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'0@82!B;&]C:R!O9B!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)L;V-K("!4:&4@9&%T
M82!T;R!D96-R>7!T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("`@(%1H
M92!K97D@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@9&5C<GEP=&5D(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C
M<GEP=$)L;V-K*"1B;&]C:RP@)&ME>2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F]U
M;F1S(#T@*'-T<FQE;B@D:V5Y*2`\(#$Q*2`_(#$R(#H@,38["B`@("`@("`@
M("`@("1K97D@/2`D=&AI<RT^7V9O<FUA=$ME>2@D:V5Y*3L*("`@("`@("`@
M("`@)&ME>5-C:&5D=6QE(#T@)'1H:7,M/E]K97E38VAE9'5L92@D:V5Y*3L*
M("`@("`@("!]"@H@("`@("`@("12(#T@)'1H:7,M/E]F;W)M871$871A*'-U
M8G-T<B@D8FQO8VLL(#`L(#0I*3L*("`@("`@("`D3"`]("1T:&ES+3Y?9F]R
M;6%T1&%T82AS=6)S='(H)&)L;V-K+"`T+"`T*2D["@H@("`@("`@(&EF("@D
M=&AI<RT^7W)O=6YD<R`^(#$R*2!["B`@("`@("`@("`@("12(%X]("1T:&ES
M+3YF,2@D3"P@)'1H:7,M/E]+;5LQ-ETL("1T:&ES+3Y?2W);,39=*3L*("`@
M("`@("`@("`@)$P@7CT@)'1H:7,M/F8S*"12+"`D=&AI<RT^7TMM6S$U72P@
M)'1H:7,M/E]+<ELQ-5TI.PH@("`@("`@("`@("`D4B!>/2`D=&AI<RT^9C(H
M)$PL("1T:&ES+3Y?2VU;,31=+"`D=&AI<RT^7TMR6S$T72D["B`@("`@("`@
M("`@("1,(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M/E]+;5LQ,UTL("1T:&ES
M+3Y?2W);,3-=*3L*("`@("`@("!]"@H@("`@("`@("12(%X]("1T:&ES+3YF
M,R@D3"P@)'1H:7,M/E]+;5LQ,ETL("1T:&ES+3Y?2W);,3)=*3L*("`@("`@
M("`D3"!>/2`D=&AI<RT^9C(H)%(L("1T:&ES+3Y?2VU;,3%=+"`D=&AI<RT^
M7TMR6S$Q72D["B`@("`@("`@)%(@7CT@)'1H:7,M/F8Q*"1,+"`D=&AI<RT^
M7TMM6S$P72P@)'1H:7,M/E]+<ELQ,%TI.PH@("`@("`@("1,(%X]("1T:&ES
M+3YF,R@D4BP@)'1H:7,M/E]+;5LY72P@("1T:&ES+3Y?2W);.5TI.PH@("`@
M("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H:7,M/E]+;5LX72P@("1T:&ES
M+3Y?2W);.%TI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M
M/E]+;5LW72P@("1T:&ES+3Y?2W);-UTI.PH@("`@("`@("12(%X]("1T:&ES
M+3YF,R@D3"P@)'1H:7,M/E]+;5LV72P@("1T:&ES+3Y?2W);-ETI.PH@("`@
M("`@("1,(%X]("1T:&ES+3YF,B@D4BP@)'1H:7,M/E]+;5LU72P@("1T:&ES
M+3Y?2W);-5TI.PH@("`@("`@("12(%X]("1T:&ES+3YF,2@D3"P@)'1H:7,M
M/E]+;5LT72P@("1T:&ES+3Y?2W);-%TI.PH@("`@("`@("1,(%X]("1T:&ES
M+3YF,R@D4BP@)'1H:7,M/E]+;5LS72P@("1T:&ES+3Y?2W);,UTI.PH@("`@
M("`@("12(%X]("1T:&ES+3YF,B@D3"P@)'1H:7,M/E]+;5LR72P@("1T:&ES
M+3Y?2W);,ETI.PH@("`@("`@("1,(%X]("1T:&ES+3YF,2@D4BP@)'1H:7,M
M/E]+;5LQ72P@("1T:&ES+3Y?2W);,5TI.PH*("`@("`@("`D9&5C<GEP=&5D
M(#T@<&%C:R@B3B(L("1,*2`N('!A8VLH(DXB+"`D4BD["@H@("`@("`@(')E
M='5R;B`D9&5C<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@9C$H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F,2@D9"P@)$MM+"`D2W(I"B`@("!["B`@
M("`@("`@)$D@/2`D2VT@*R`D9#L*"B`@("`@("`@+RH@3F%S='D@1FEX(&%S
M"B`@("`@("`@("H@)$D@/#P@)$MR('P@)$D@/CX@*#,R("T@)$MR*0H@("`@
M("`@("`J($1O97-N)W0@86QW87ES(&=I=F4@=&AE(&-O<G)E8W0@86YS=V5R
M"B`@("`@("`@("HO"B`@("`@("`@)&)I;B`]('-T<E]P860H9&5C8FEN*"1)
M*2P@,S(L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`D22`](&)I;F1E
M8RAS=6)S='(H)&)I;BP@)$MR*2`N('-U8G-T<B@D8FEN+"`P+"`D2W(I*3L*
M"B`@("`@("`@)&8@/2`D=&AI<RT^<S%;*"1)(#X^(#(T*2`F(#!X1D9=(%X@
M)'1H:7,M/G,R6R@D22`^/B`Q-BD@)B`P>$9&73L*("`@("`@("`D9B`]("1F
M("T@)'1H:7,M/G,S6R@D22`^/B`X*2`F(#!X1D9=.PH@("`@("`@("1F(#T@
M)&8@*R`D=&AI<RT^<S1;)$D@)B`P>$9&73L*("`@("`@("!R971U<FX@)&8[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!F,B@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&8R*"1D+"`D2VTL("1+<BD*("`@('L*("`@("`@("`D22`]("1+;2!>
M("1D.PH*("`@("`@("`O*B!.87-T>2!&:7@@87,*("`@("`@("`@*B`D22`\
M/"`D2W(@?"`D22`^/B`H,S(@+2`D2W(I"B`@("`@("`@("H@1&]E<VXG="!A
M;'=A>7,@9VEV92!T:&4@8V]R<F5C="!A;G-W97(*("`@("`@("`@*B\*("`@
M("`@("`D8FEN(#T@<W1R7W!A9"AD96-B:6XH)$DI+"`S,BP@)S`G+"!35%)?
M4$%$7TQ%1E0I.PH@("`@("`@("1)(#T@8FEN9&5C*'-U8G-T<B@D8FEN+"`D
M2W(I("X@<W5B<W1R*"1B:6XL(#`L("1+<BDI.PH*("`@("`@("`D9B`]("1T
M:&ES+3YS,5LH)$D@/CX@,C0I("8@,'A&1ET@+2`D=&AI<RT^<S);*"1)(#X^
M(#$V*2`F(#!X1D9=.PH@("`@("`@("1F(#T@)&8@*R`D=&AI<RT^<S-;*"1)
M(#X^(#@I("8@,'A&1ET["B`@("`@("`@)&8@/2`D9B!>("1T:&ES+3YS-%LD
M22`F(#!X1D9=.PH@("`@("`@(')E='5R;B`D9CL*("`@('T*"B`@("`O*BH*
M("`@("`J(&8S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9C,H)&0L("1+;2P@
M)$MR*0H@("`@>PH@("`@("`@("1)(#T@,'A&1D9&1D9&1B`F("@D2VT@+2`D
M9"D["@H@("`@("`@("\J($YA<W1Y($9I>"!A<PH@("`@("`@("`J("1)(#P\
M("1+<B!\("1)(#X^("@S,B`M("1+<BD*("`@("`@("`@*B!$;V5S;B=T(&%L
M=V%Y<R!G:79E('1H92!C;W)R96-T(&%N<W=E<@H@("`@("`@("`J+PH@("`@
M("`@("1B:6X@/2!S=')?<&%D*&1E8V)I;B@D22DL(#,R+"`G,"<L(%-44E]0
M041?3$5&5"D["B`@("`@("`@)$D@/2!B:6YD96,H<W5B<W1R*"1B:6XL("1+
M<BD@+B!S=6)S='(H)&)I;BP@,"P@)$MR*2D["@H@("`@("`@("1F(#T@*"1T
M:&ES+3YS,5LH)$D@/CX@,C0I("8@,'A&1ET@*R`D=&AI<RT^<S);*"1)(#X^
M(#$V*2`F(#!X1D9=*3L*("`@("`@("`D9B`]("1F(%X@)'1H:7,M/G,S6R@D
M22`^/B`X*2`F(#!X1D9=.PH@("`@("`@("1F(#T@,'A&1D9&1D9&1B`F("@D
M9B`M("1T:&ES+3YS-%LD22`F(#!X1D9=*3L*("`@("`@("!R971U<FX@)&8[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T(&$@<W1R:6YG(&EN=&\@
M82!A<G)A>2!O9B!T:&4@;W)D:6YA=&5S(&]F(&ET<R!C:&%R86-T97)S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@($1A=&$@=&\@8V]N
M=F5R="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8V]N=F5R
M=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]F;W)M871$871A*"1D
M871A*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;6)I;F4T*'5N
M<&%C:R@G0RHG+"`D9&%T82DL(#!X,2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T<R!A('1E>'0@:V5Y(&EN=&\@86X@87)R87D@<&%D9&5D('=I
M=&@@7#`G<R!T;R!A(&QE;F=T:"!O9B`Q,C@*("`@("`J(&)I=',N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@:V5Y('1O(&9O<FUA
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@<&%D9&5D(&ME
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA=$ME>2@D:V5Y*0H@("`@
M>PH@("`@("`@("1R97,@/2!A<G)A>5]V86QU97,H=6YP86-K*"=#*B<L("1K
M97DI*3L*("`@("`@("!F;W(@*"1I(#T@8V]U;G0H)')E<RD[("1I(#P@,38[
M("1I*RLI('L*("`@("`@("`@("`@)')E<ULD:5T@/2`P.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O*BH*("`@("`J($-R
M96%T92!T:&4@8V]M<&QE=&4@:V5Y('-H961U;&4N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1K97D@(%1H92!K97D@=&\@=7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?:V5Y4V-H961U;&4H)&ME>2D*("`@('L*("`@("`@("`D
M>#!X,7@R>#,@/2`D=&AI<RT^7V-O;6)I;F4T*"1K97DL(#!X,"D["B`@("`@
M("`@)'@T>#5X-G@W(#T@)'1H:7,M/E]C;VUB:6YE-"@D:V5Y+"`P>#0I.PH@
M("`@("`@("1X.'@Y>$%X0B`]("1T:&ES+3Y?8V]M8FEN930H)&ME>2P@,'@X
M*3L*("`@("`@("`D>$-X1'A%>$8@/2`D=&AI<RT^7V-O;6)I;F4T*"1K97DL
M(#!X0RD["@H@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#!X,7@R>#,I
M.R`D>#`@/2`D8ELP73L@)'@Q(#T@)&);,5T[("1X,B`]("1B6S)=.R`D>#,@
M/2`D8ELS73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'@T>#5X-G@W
M*3L@)'@T(#T@)&);,%T[("1X-2`]("1B6S%=.R`D>#8@/2`D8ELR73L@)'@W
M(#T@)&);,UT["B`@("`@("`@)&(@/2`D=&AI<RT^7W-P;&ET*"1X.'@Y>$%X
M0BD[("1X."`]("1B6S!=.R`D>#D@/2`D8ELQ73L@)'A!(#T@)&);,ET[("1X
M0B`]("1B6S-=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>$-X1'A%
M>$8I.R`D>$,@/2`D8ELP73L@)'A$(#T@)&);,5T[("1X12`]("1B6S)=.R`D
M>$8@/2`D8ELS73L*"B`@("`@("`@)'HP>C%Z,GHS(#T@)'@P>#%X,G@S(%X@
M)'1H:7,M/G,U6R1X1%T@7B`D=&AI<RT^<S9;)'A&72!>("1T:&ES+3YS-ULD
M>$-=(%X@)'1H:7,M/G,X6R1X15T@7B`D=&AI<RT^<S=;)'@X73L*("`@("`@
M("`D8B`]("1T:&ES+3Y?<W!L:70H)'HP>C%Z,GHS*3L@)'HP(#T@)&);,%T[
M("1Z,2`]("1B6S%=.R`D>C(@/2`D8ELR73L@)'HS(#T@)&);,UT["B`@("`@
M("`@)'HT>C5Z-GHW(#T@)'@X>#EX07A"(%X@)'1H:7,M/G,U6R1Z,%T@7B`D
M=&AI<RT^<S9;)'HR72!>("1T:&ES+3YS-ULD>C%=(%X@)'1H:7,M/G,X6R1Z
M,UT@7B`D=&AI<RT^<SA;)'A!73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L
M:70H)'HT>C5Z-GHW*3L@)'HT(#T@)&);,%T[("1Z-2`]("1B6S%=.R`D>C8@
M/2`D8ELR73L@)'HW(#T@)&);,UT["B`@("`@("`@)'HX>CEZ07I"(#T@)'A#
M>$1X17A&(%X@)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T
M:&ES+3YS-ULD>C5=(%X@)'1H:7,M/G,X6R1Z-%T@7B`D=&AI<RT^<S5;)'@Y
M73L*("`@("`@("`D8B`]("1T:&ES+3Y?<W!L:70H)'HX>CEZ07I"*3L@)'HX
M(#T@)&);,%T[("1Z.2`]("1B6S%=.R`D>D$@/2`D8ELR73L@)'I"(#T@)&);
M,UT["B`@("`@("`@)'I#>D1Z17I&(#T@)'@T>#5X-G@W(%X@)'1H:7,M/G,U
M6R1Z05T@7B`D=&AI<RT^<S9;)'HY72!>("1T:&ES+3YS-ULD>D)=(%X@)'1H
M:7,M/G,X6R1Z.%T@7B`D=&AI<RT^<S9;)'A"73L*("`@("`@("`D8B`]("1T
M:&ES+3Y?<W!L:70H)'I#>D1Z17I&*3L@)'I#(#T@)&);,%T[("1Z1"`]("1B
M6S%=.R`D>D4@/2`D8ELR73L@)'I&(#T@)&);,UT["@H@("`@("`@("1T:&ES
M+3Y?2VU;,5T@/2`D=&AI<RT^<S5;)'HX72!>("1T:&ES+3YS-ELD>CE=(%X@
M)'1H:7,M/G,W6R1Z-UT@7B`D=&AI<RT^<SA;)'HV72!>("1T:&ES+3YS-5LD
M>C)=.PH@("`@("`@("1T:&ES+3Y?2VU;,ET@/2`D=&AI<RT^<S5;)'I!72!>
M("1T:&ES+3YS-ELD>D)=(%X@)'1H:7,M/G,W6R1Z-5T@7B`D=&AI<RT^<SA;
M)'HT72!>("1T:&ES+3YS-ELD>C9=.PH@("`@("`@("1T:&ES+3Y?2VU;,UT@
M/2`D=&AI<RT^<S5;)'I#72!>("1T:&ES+3YS-ELD>D1=(%X@)'1H:7,M/G,W
M6R1Z,UT@7B`D=&AI<RT^<SA;)'HR72!>("1T:&ES+3YS-ULD>CE=.PH@("`@
M("`@("1T:&ES+3Y?2VU;-%T@/2`D=&AI<RT^<S5;)'I%72!>("1T:&ES+3YS
M-ELD>D9=(%X@)'1H:7,M/G,W6R1Z,5T@7B`D=&AI<RT^<SA;)'HP72!>("1T
M:&ES+3YS.%LD>D-=.PH*("`@("`@("`D>#!X,7@R>#,@/2`D>CAZ.7I!>D(@
M7B`D=&AI<RT^<S5;)'HU72!>("1T:&ES+3YS-ELD>C==(%X@)'1H:7,M/G,W
M6R1Z-%T@7B`D=&AI<RT^<SA;)'HV72!>("1T:&ES+3YS-ULD>C!=.PH@("`@
M("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#!X,7@R>#,I.R`D>#`@/2`D8ELP
M73L@)'@Q(#T@)&);,5T[("1X,B`]("1B6S)=.R`D>#,@/2`D8ELS73L*("`@
M("`@("`D>#1X-7@V>#<@/2`D>C!Z,7HR>C,@7B`D=&AI<RT^<S5;)'@P72!>
M("1T:&ES+3YS-ELD>#)=(%X@)'1H:7,M/G,W6R1X,5T@7B`D=&AI<RT^<SA;
M)'@S72!>("1T:&ES+3YS.%LD>C)=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S
M<&QI="@D>#1X-7@V>#<I.R`D>#0@/2`D8ELP73L@)'@U(#T@)&);,5T[("1X
M-B`]("1B6S)=.R`D>#<@/2`D8ELS73L*("`@("`@("`D>#AX.7A!>$(@/2`D
M>C1Z-7HV>C<@7B`D=&AI<RT^<S5;)'@W72!>("1T:&ES+3YS-ELD>#9=(%X@
M)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^<SA;)'@T72!>("1T:&ES+3YS-5LD
M>C%=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#AX.7A!>$(I.R`D
M>#@@/2`D8ELP73L@)'@Y(#T@)&);,5T[("1X02`]("1B6S)=.R`D>$(@/2`D
M8ELS73L*("`@("`@("`D>$-X1'A%>$8@/2`D>D-Z1'I%>D8@7B`D=&AI<RT^
M<S5;)'A!72!>("1T:&ES+3YS-ELD>#E=(%X@)'1H:7,M/G,W6R1X0ET@7B`D
M=&AI<RT^<SA;)'@X72!>("1T:&ES+3YS-ELD>C-=.PH@("`@("`@("1B(#T@
M)'1H:7,M/E]S<&QI="@D>$-X1'A%>$8I.R`D>$,@/2`D8ELP73L@)'A$(#T@
M)&);,5T[("1X12`]("1B6S)=.R`D>$8@/2`D8ELS73L*"B`@("`@("`@)'1H
M:7,M/E]+;5LU72`@/2`D=&AI<RT^<S5;)'@S72!>("1T:&ES+3YS-ELD>#)=
M(%X@)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;)'A$72!>("1T:&ES+3YS
M-5LD>#A=.PH@("`@("`@("1T:&ES+3Y?2VU;-ET@(#T@)'1H:7,M/G,U6R1X
M,5T@7B`D=&AI<RT^<S9;)'@P72!>("1T:&ES+3YS-ULD>$5=(%X@)'1H:7,M
M/G,X6R1X1ET@7B`D=&AI<RT^<S9;)'A$73L*("`@("`@("`D=&AI<RT^7TMM
M6S==("`]("1T:&ES+3YS-5LD>#==(%X@)'1H:7,M/G,V6R1X-ET@7B`D=&AI
M<RT^<S=;)'@X72!>("1T:&ES+3YS.%LD>#E=(%X@)'1H:7,M/G,W6R1X,UT[
M"B`@("`@("`@)'1H:7,M/E]+;5LX72`@/2`D=&AI<RT^<S5;)'@U72!>("1T
M:&ES+3YS-ELD>#1=(%X@)'1H:7,M/G,W6R1X05T@7B`D=&AI<RT^<SA;)'A"
M72!>("1T:&ES+3YS.%LD>#==.PH*("`@("`@("`D>C!Z,7HR>C,@/2`D>#!X
M,7@R>#,@7B`D=&AI<RT^<S5;)'A$72!>("1T:&ES+3YS-ELD>$9=(%X@)'1H
M:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;)'A%72!>("1T:&ES+3YS-ULD>#A=
M.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>C!Z,7HR>C,I.R`D>C`@
M/2`D8ELP73L@)'HQ(#T@)&);,5T[("1Z,B`]("1B6S)=.R`D>C,@/2`D8ELS
M73L*("`@("`@("`D>C1Z-7HV>C<@/2`D>#AX.7A!>$(@7B`D=&AI<RT^<S5;
M)'HP72!>("1T:&ES+3YS-ELD>C)=(%X@)'1H:7,M/G,W6R1Z,5T@7B`D=&AI
M<RT^<SA;)'HS72!>("1T:&ES+3YS.%LD>$%=.PH@("`@("`@("1B(#T@)'1H
M:7,M/E]S<&QI="@D>C1Z-7HV>C<I.R`D>C0@/2`D8ELP73L@)'HU(#T@)&);
M,5T[("1Z-B`]("1B6S)=.R`D>C<@/2`D8ELS73L*("`@("`@("`D>CAZ.7I!
M>D(@/2`D>$-X1'A%>$8@7B`D=&AI<RT^<S5;)'HW72!>("1T:&ES+3YS-ELD
M>C9=(%X@)'1H:7,M/G,W6R1Z-5T@7B`D=&AI<RT^<SA;)'HT72!>("1T:&ES
M+3YS-5LD>#E=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>CAZ.7I!
M>D(I.R`D>C@@/2`D8ELP73L@)'HY(#T@)&);,5T[("1Z02`]("1B6S)=.R`D
M>D(@/2`D8ELS73L*("`@("`@("`D>D-Z1'I%>D8@/2`D>#1X-7@V>#<@7B`D
M=&AI<RT^<S5;)'I!72!>("1T:&ES+3YS-ELD>CE=(%X@)'1H:7,M/G,W6R1Z
M0ET@7B`D=&AI<RT^<SA;)'HX72!>("1T:&ES+3YS-ELD>$)=.PH@("`@("`@
M("1B(#T@)'1H:7,M/E]S<&QI="@D>D-Z1'I%>D8I.R`D>D,@/2`D8ELP73L@
M)'I$(#T@)&);,5T[("1Z12`]("1B6S)=.R`D>D8@/2`D8ELS73L*"B`@("`@
M("`@)'1H:7,M/E]+;5LY72`@/2`D=&AI<RT^<S5;)'HS72!>("1T:&ES+3YS
M-ELD>C)=(%X@)'1H:7,M/G,W6R1Z0UT@7B`D=&AI<RT^<SA;)'I$72!>("1T
M:&ES+3YS-5LD>CE=.PH@("`@("`@("1T:&ES+3Y?2VU;,3!=(#T@)'1H:7,M
M/G,U6R1Z,5T@7B`D=&AI<RT^<S9;)'HP72!>("1T:&ES+3YS-ULD>D5=(%X@
M)'1H:7,M/G,X6R1Z1ET@7B`D=&AI<RT^<S9;)'I#73L*("`@("`@("`D=&AI
M<RT^7TMM6S$Q72`]("1T:&ES+3YS-5LD>C==(%X@)'1H:7,M/G,V6R1Z-ET@
M7B`D=&AI<RT^<S=;)'HX72!>("1T:&ES+3YS.%LD>CE=(%X@)'1H:7,M/G,W
M6R1Z,ET["B`@("`@("`@)'1H:7,M/E]+;5LQ,ET@/2`D=&AI<RT^<S5;)'HU
M72!>("1T:&ES+3YS-ELD>C1=(%X@)'1H:7,M/G,W6R1Z05T@7B`D=&AI<RT^
M<SA;)'I"72!>("1T:&ES+3YS.%LD>C9=.PH*("`@("`@("`D>#!X,7@R>#,@
M/2`D>CAZ.7I!>D(@7B`D=&AI<RT^<S5;)'HU72!>("1T:&ES+3YS-ELD>C==
M(%X@)'1H:7,M/G,W6R1Z-%T@7B`D=&AI<RT^<SA;)'HV72!>("1T:&ES+3YS
M-ULD>C!=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#!X,7@R>#,I
M.R`D>#`@/2`D8ELP73L@)'@Q(#T@)&);,5T[("1X,B`]("1B6S)=.R`D>#,@
M/2`D8ELS73L*("`@("`@("`D>#1X-7@V>#<@/2`D>C!Z,7HR>C,@7B`D=&AI
M<RT^<S5;)'@P72!>("1T:&ES+3YS-ELD>#)=(%X@)'1H:7,M/G,W6R1X,5T@
M7B`D=&AI<RT^<SA;)'@S72!>("1T:&ES+3YS.%LD>C)=.PH@("`@("`@("1B
M(#T@)'1H:7,M/E]S<&QI="@D>#1X-7@V>#<I.R`D>#0@/2`D8ELP73L@)'@U
M(#T@)&);,5T[("1X-B`]("1B6S)=.R`D>#<@/2`D8ELS73L*("`@("`@("`D
M>#AX.7A!>$(@/2`D>C1Z-7HV>C<@7B`D=&AI<RT^<S5;)'@W72!>("1T:&ES
M+3YS-ELD>#9=(%X@)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^<SA;)'@T72!>
M("1T:&ES+3YS-5LD>C%=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D
M>#AX.7A!>$(I.R`D>#@@/2`D8ELP73L@)'@Y(#T@)&);,5T[("1X02`]("1B
M6S)=.R`D>$(@/2`D8ELS73L*("`@("`@("`D>$-X1'A%>$8@/2`D>D-Z1'I%
M>D8@7B`D=&AI<RT^<S5;)'A!72!>("1T:&ES+3YS-ELD>#E=(%X@)'1H:7,M
M/G,W6R1X0ET@7B`D=&AI<RT^<SA;)'@X72!>("1T:&ES+3YS-ELD>C-=.PH@
M("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>$-X1'A%>$8I.R`D>$,@/2`D
M8ELP73L@)'A$(#T@)&);,5T[("1X12`]("1B6S)=.R`D>$8@/2`D8ELS73L*
M"B`@("`@("`@)'1H:7,M/E]+;5LQ,UT@/2`D=&AI<RT^<S5;)'@X72!>("1T
M:&ES+3YS-ELD>#E=(%X@)'1H:7,M/G,W6R1X-UT@7B`D=&AI<RT^<SA;)'@V
M72!>("1T:&ES+3YS-5LD>#-=.PH@("`@("`@("1T:&ES+3Y?2VU;,31=(#T@
M)'1H:7,M/G,U6R1X05T@7B`D=&AI<RT^<S9;)'A"72!>("1T:&ES+3YS-ULD
M>#5=(%X@)'1H:7,M/G,X6R1X-%T@7B`D=&AI<RT^<S9;)'@W73L*("`@("`@
M("`D=&AI<RT^7TMM6S$U72`]("1T:&ES+3YS-5LD>$-=(%X@)'1H:7,M/G,V
M6R1X1%T@7B`D=&AI<RT^<S=;)'@S72!>("1T:&ES+3YS.%LD>#)=(%X@)'1H
M:7,M/G,W6R1X.%T["B`@("`@("`@)'1H:7,M/E]+;5LQ-ET@/2`D=&AI<RT^
M<S5;)'A%72!>("1T:&ES+3YS-ELD>$9=(%X@)'1H:7,M/G,W6R1X,5T@7B`D
M=&AI<RT^<SA;)'@P72!>("1T:&ES+3YS.%LD>$1=.PH*("`@("`@("`D>C!Z
M,7HR>C,@/2`D>#!X,7@R>#,@7B`D=&AI<RT^<S5;)'A$72!>("1T:&ES+3YS
M-ELD>$9=(%X@)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;)'A%72!>("1T
M:&ES+3YS-ULD>#A=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>C!Z
M,7HR>C,I.R`D>C`@/2`D8ELP73L@)'HQ(#T@)&);,5T[("1Z,B`]("1B6S)=
M.R`D>C,@/2`D8ELS73L*("`@("`@("`D>C1Z-7HV>C<@/2`D>#AX.7A!>$(@
M7B`D=&AI<RT^<S5;)'HP72!>("1T:&ES+3YS-ELD>C)=(%X@)'1H:7,M/G,W
M6R1Z,5T@7B`D=&AI<RT^<SA;)'HS72!>("1T:&ES+3YS.%LD>$%=.PH@("`@
M("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>C1Z-7HV>C<I.R`D>C0@/2`D8ELP
M73L@)'HU(#T@)&);,5T[("1Z-B`]("1B6S)=.R`D>C<@/2`D8ELS73L*("`@
M("`@("`D>CAZ.7I!>D(@/2`D>$-X1'A%>$8@7B`D=&AI<RT^<S5;)'HW72!>
M("1T:&ES+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z-5T@7B`D=&AI<RT^<SA;
M)'HT72!>("1T:&ES+3YS-5LD>#E=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S
M<&QI="@D>CAZ.7I!>D(I.R`D>C@@/2`D8ELP73L@)'HY(#T@)&);,5T[("1Z
M02`]("1B6S)=.R`D>D(@/2`D8ELS73L*("`@("`@("`D>D-Z1'I%>D8@/2`D
M>#1X-7@V>#<@7B`D=&AI<RT^<S5;)'I!72!>("1T:&ES+3YS-ELD>CE=(%X@
M)'1H:7,M/G,W6R1Z0ET@7B`D=&AI<RT^<SA;)'HX72!>("1T:&ES+3YS-ELD
M>$)=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>D-Z1'I%>D8I.R`D
M>D,@/2`D8ELP73L@)'I$(#T@)&);,5T[("1Z12`]("1B6S)=.R`D>D8@/2`D
M8ELS73L*"B`@("`@("`@)'1H:7,M/E]+<ELQ72`@/2`P>#%&("8@*"1T:&ES
M+3YS-5LD>CA=(%X@)'1H:7,M/G,V6R1Z.5T@7B`D=&AI<RT^<S=;)'HW72!>
M("1T:&ES+3YS.%LD>C9=(%X@)'1H:7,M/G,U6R1Z,ETI.PH@("`@("`@("1T
M:&ES+3Y?2W);,ET@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'I!72!>("1T:&ES
M+3YS-ELD>D)=(%X@)'1H:7,M/G,W6R1Z-5T@7B`D=&AI<RT^<SA;)'HT72!>
M("1T:&ES+3YS-ELD>C9=*3L*("`@("`@("`D=&AI<RT^7TMR6S-=("`](#!X
M,48@)B`H)'1H:7,M/G,U6R1Z0UT@7B`D=&AI<RT^<S9;)'I$72!>("1T:&ES
M+3YS-ULD>C-=(%X@)'1H:7,M/G,X6R1Z,ET@7B`D=&AI<RT^<S=;)'HY72D[
M"B`@("`@("`@)'1H:7,M/E]+<ELT72`@/2`P>#%&("8@*"1T:&ES+3YS-5LD
M>D5=(%X@)'1H:7,M/G,V6R1Z1ET@7B`D=&AI<RT^<S=;)'HQ72!>("1T:&ES
M+3YS.%LD>C!=(%X@)'1H:7,M/G,X6R1Z0UTI.PH*("`@("`@("`D>#!X,7@R
M>#,@/2`D>CAZ.7I!>D(@7B`D=&AI<RT^<S5;)'HU72!>("1T:&ES+3YS-ELD
M>C==(%X@)'1H:7,M/G,W6R1Z-%T@7B`D=&AI<RT^<SA;)'HV72!>("1T:&ES
M+3YS-ULD>C!=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#!X,7@R
M>#,I.R`D>#`@/2`D8ELP73L@)'@Q(#T@)&);,5T[("1X,B`]("1B6S)=.R`D
M>#,@/2`D8ELS73L*("`@("`@("`D>#1X-7@V>#<@/2`D>C!Z,7HR>C,@7B`D
M=&AI<RT^<S5;)'@P72!>("1T:&ES+3YS-ELD>#)=(%X@)'1H:7,M/G,W6R1X
M,5T@7B`D=&AI<RT^<SA;)'@S72!>("1T:&ES+3YS.%LD>C)=.PH@("`@("`@
M("1B(#T@)'1H:7,M/E]S<&QI="@D>#1X-7@V>#<I.R`D>#0@/2`D8ELP73L@
M)'@U(#T@)&);,5T[("1X-B`]("1B6S)=.R`D>#<@/2`D8ELS73L*("`@("`@
M("`D>#AX.7A!>$(@/2`D>C1Z-7HV>C<@7B`D=&AI<RT^<S5;)'@W72!>("1T
M:&ES+3YS-ELD>#9=(%X@)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^<SA;)'@T
M72!>("1T:&ES+3YS-5LD>C%=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI
M="@D>#AX.7A!>$(I.R`D>#@@/2`D8ELP73L@)'@Y(#T@)&);,5T[("1X02`]
M("1B6S)=.R`D>$(@/2`D8ELS73L*("`@("`@("`D>$-X1'A%>$8@/2`D>D-Z
M1'I%>D8@7B`D=&AI<RT^<S5;)'A!72!>("1T:&ES+3YS-ELD>#E=(%X@)'1H
M:7,M/G,W6R1X0ET@7B`D=&AI<RT^<SA;)'@X72!>("1T:&ES+3YS-ELD>C-=
M.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>$-X1'A%>$8I.R`D>$,@
M/2`D8ELP73L@)'A$(#T@)&);,5T[("1X12`]("1B6S)=.R`D>$8@/2`D8ELS
M73L*"B`@("`@("`@)'1H:7,M/E]+<ELU72`@/2`P>#%&("8@*"1T:&ES+3YS
M-5LD>#-=(%X@)'1H:7,M/G,V6R1X,ET@7B`D=&AI<RT^<S=;)'A#72!>("1T
M:&ES+3YS.%LD>$1=(%X@)'1H:7,M/G,U6R1X.%TI.PH@("`@("`@("1T:&ES
M+3Y?2W);-ET@(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'@Q72!>("1T:&ES+3YS
M-ELD>#!=(%X@)'1H:7,M/G,W6R1X15T@7B`D=&AI<RT^<SA;)'A&72!>("1T
M:&ES+3YS-ELD>$1=*3L*("`@("`@("`D=&AI<RT^7TMR6S==("`](#!X,48@
M)B`H)'1H:7,M/G,U6R1X-UT@7B`D=&AI<RT^<S9;)'@V72!>("1T:&ES+3YS
M-ULD>#A=(%X@)'1H:7,M/G,X6R1X.5T@7B`D=&AI<RT^<S=;)'@S72D["B`@
M("`@("`@)'1H:7,M/E]+<ELX72`@/2`P>#%&("8@*"1T:&ES+3YS-5LD>#5=
M(%X@)'1H:7,M/G,V6R1X-%T@7B`D=&AI<RT^<S=;)'A!72!>("1T:&ES+3YS
M.%LD>$)=(%X@)'1H:7,M/G,X6R1X-UTI.PH*("`@("`@("`D>C!Z,7HR>C,@
M/2`D>#!X,7@R>#,@7B`D=&AI<RT^<S5;)'A$72!>("1T:&ES+3YS-ELD>$9=
M(%X@)'1H:7,M/G,W6R1X0UT@7B`D=&AI<RT^<SA;)'A%72!>("1T:&ES+3YS
M-ULD>#A=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>C!Z,7HR>C,I
M.R`D>C`@/2`D8ELP73L@)'HQ(#T@)&);,5T[("1Z,B`]("1B6S)=.R`D>C,@
M/2`D8ELS73L*("`@("`@("`D>C1Z-7HV>C<@/2`D>#AX.7A!>$(@7B`D=&AI
M<RT^<S5;)'HP72!>("1T:&ES+3YS-ELD>C)=(%X@)'1H:7,M/G,W6R1Z,5T@
M7B`D=&AI<RT^<SA;)'HS72!>("1T:&ES+3YS.%LD>$%=.PH@("`@("`@("1B
M(#T@)'1H:7,M/E]S<&QI="@D>C1Z-7HV>C<I.R`D>C0@/2`D8ELP73L@)'HU
M(#T@)&);,5T[("1Z-B`]("1B6S)=.R`D>C<@/2`D8ELS73L*("`@("`@("`D
M>CAZ.7I!>D(@/2`D>$-X1'A%>$8@7B`D=&AI<RT^<S5;)'HW72!>("1T:&ES
M+3YS-ELD>C9=(%X@)'1H:7,M/G,W6R1Z-5T@7B`D=&AI<RT^<SA;)'HT72!>
M("1T:&ES+3YS-5LD>#E=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D
M>CAZ.7I!>D(I.R`D>C@@/2`D8ELP73L@)'HY(#T@)&);,5T[("1Z02`]("1B
M6S)=.R`D>D(@/2`D8ELS73L*("`@("`@("`D>D-Z1'I%>D8@/2`D>#1X-7@V
M>#<@7B`D=&AI<RT^<S5;)'I!72!>("1T:&ES+3YS-ELD>CE=(%X@)'1H:7,M
M/G,W6R1Z0ET@7B`D=&AI<RT^<SA;)'HX72!>("1T:&ES+3YS-ELD>$)=.PH@
M("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>D-Z1'I%>D8I.R`D>D,@/2`D
M8ELP73L@)'I$(#T@)&);,5T[("1Z12`]("1B6S)=.R`D>D8@/2`D8ELS73L*
M"B`@("`@("`@)'1H:7,M/E]+<ELY72`@/2`P>#%&("8@*"1T:&ES+3YS-5LD
M>C-=(%X@)'1H:7,M/G,V6R1Z,ET@7B`D=&AI<RT^<S=;)'I#72!>("1T:&ES
M+3YS.%LD>D1=(%X@)'1H:7,M/G,U6R1Z.5TI.PH@("`@("`@("1T:&ES+3Y?
M2W);,3!=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'HQ72!>("1T:&ES+3YS-ELD
M>C!=(%X@)'1H:7,M/G,W6R1Z15T@7B`D=&AI<RT^<SA;)'I&72!>("1T:&ES
M+3YS-ELD>D-=*3L*("`@("`@("`D=&AI<RT^7TMR6S$Q72`](#!X,48@)B`H
M)'1H:7,M/G,U6R1Z-UT@7B`D=&AI<RT^<S9;)'HV72!>("1T:&ES+3YS-ULD
M>CA=(%X@)'1H:7,M/G,X6R1Z.5T@7B`D=&AI<RT^<S=;)'HR72D["B`@("`@
M("`@)'1H:7,M/E]+<ELQ,ET@/2`P>#%&("8@*"1T:&ES+3YS-5LD>C5=(%X@
M)'1H:7,M/G,V6R1Z-%T@7B`D=&AI<RT^<S=;)'I!72!>("1T:&ES+3YS.%LD
M>D)=(%X@)'1H:7,M/G,X6R1Z-ETI.PH*("`@("`@("`D>#!X,7@R>#,@/2`D
M>CAZ.7I!>D(@7B`D=&AI<RT^<S5;)'HU72!>("1T:&ES+3YS-ELD>C==(%X@
M)'1H:7,M/G,W6R1Z-%T@7B`D=&AI<RT^<SA;)'HV72!>("1T:&ES+3YS-ULD
M>C!=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#!X,7@R>#,I.R`D
M>#`@/2`D8ELP73L@)'@Q(#T@)&);,5T[("1X,B`]("1B6S)=.R`D>#,@/2`D
M8ELS73L*("`@("`@("`D>#1X-7@V>#<@/2`D>C!Z,7HR>C,@7B`D=&AI<RT^
M<S5;)'@P72!>("1T:&ES+3YS-ELD>#)=(%X@)'1H:7,M/G,W6R1X,5T@7B`D
M=&AI<RT^<SA;)'@S72!>("1T:&ES+3YS.%LD>C)=.PH@("`@("`@("1B(#T@
M)'1H:7,M/E]S<&QI="@D>#1X-7@V>#<I.R`D>#0@/2`D8ELP73L@)'@U(#T@
M)&);,5T[("1X-B`]("1B6S)=.R`D>#<@/2`D8ELS73L*("`@("`@("`D>#AX
M.7A!>$(@/2`D>C1Z-7HV>C<@7B`D=&AI<RT^<S5;)'@W72!>("1T:&ES+3YS
M-ELD>#9=(%X@)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^<SA;)'@T72!>("1T
M:&ES+3YS-5LD>C%=.PH@("`@("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>#AX
M.7A!>$(I.R`D>#@@/2`D8ELP73L@)'@Y(#T@)&);,5T[("1X02`]("1B6S)=
M.R`D>$(@/2`D8ELS73L*("`@("`@("`D>$-X1'A%>$8@/2`D>D-Z1'I%>D8@
M7B`D=&AI<RT^<S5;)'A!72!>("1T:&ES+3YS-ELD>#E=(%X@)'1H:7,M/G,W
M6R1X0ET@7B`D=&AI<RT^<SA;)'@X72!>("1T:&ES+3YS-ELD>C-=.PH@("`@
M("`@("1B(#T@)'1H:7,M/E]S<&QI="@D>$-X1'A%>$8I.R`D>$,@/2`D8ELP
M73L@)'A$(#T@)&);,5T[("1X12`]("1B6S)=.R`D>$8@/2`D8ELS73L*"B`@
M("`@("`@)'1H:7,M/E]+<ELQ,UT@/2`P>#%&("8@*"1T:&ES+3YS-5LD>#A=
M(%X@)'1H:7,M/G,V6R1X.5T@7B`D=&AI<RT^<S=;)'@W72!>("1T:&ES+3YS
M.%LD>#9=(%X@)'1H:7,M/G,U6R1X,UTI.PH@("`@("`@("1T:&ES+3Y?2W);
M,31=(#T@,'@Q1B`F("@D=&AI<RT^<S5;)'A!72!>("1T:&ES+3YS-ELD>$)=
M(%X@)'1H:7,M/G,W6R1X-5T@7B`D=&AI<RT^<SA;)'@T72!>("1T:&ES+3YS
M-ELD>#==*3L*("`@("`@("`D=&AI<RT^7TMR6S$U72`](#!X,48@)B`H)'1H
M:7,M/G,U6R1X0UT@7B`D=&AI<RT^<S9;)'A$72!>("1T:&ES+3YS-ULD>#-=
M(%X@)'1H:7,M/G,X6R1X,ET@7B`D=&AI<RT^<S=;)'@X72D["B`@("`@("`@
M)'1H:7,M/E]+<ELQ-ET@/2`P>#%&("8@*"1T:&ES+3YS-5LD>$5=(%X@)'1H
M:7,M/G,V6R1X1ET@7B`D=&AI<RT^<S=;)'@Q72!>("1T:&ES+3YS.%LD>#!=
M(%X@)'1H:7,M/G,X6R1X1%TI.PH@("`@?0H*("`@("\J*@H@("`@("H@56YP
M86-K('1H92`S,B!B:70@=F%L=64@:6YT;R!A;B!A<G)A>2!O9B!F;W5R(#@@
M8FET('9A;'5E<RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@
M,S(@8FET('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($9O
M=7(@."!B:70@=F%L=65S($U3('1O($Q3+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<W!L:70H)'@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"@D>"`^
M/B`R-"D@)B`P>$9&+"`H)'@@/CX@,38I("8@,'A&1BP@*"1X(#X^(#@I("8@
M,'A&1BP@)'@@)B`P>$9&*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!A8VL@
M9F]U<B`X(&)I="!V86QU97,@:6YT;R!O;F4@,S(@8FET('9A;'5E+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D:V5Y("`@("`@07)R87D@;V8@."!B
M:70@=F%L=65S+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T("!3=&%R
M="!P;W-I=&EO;B!I;B!A<G)A>2!T;R!G970@-"!V86QU97,@9G)O;2X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(#,R(&)I="!V86QU92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;6)I;F4T*"1K97DL("1S=&%R="`](#`I
M"B`@("!["B`@("`@("`@)')E<R`@/2`P.PH@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"1S=&%R="P@)&ME>2DI('L*("`@("`@("`@("`@)')E<R!\
M/2`H)&ME>5LD<W1A<G1=*2`\/"`R-#L*("`@("`@("!]"B`@("`@("`@:68@
M*&%R<F%Y7VME>5]E>&ES=',H)'-T87)T("L@,2P@)&ME>2DI('L*("`@("`@
M("`@("`@)')E<R!\/2`H)&ME>5LD<W1A<G0@*R`Q72D@/#P@,38["B`@("`@
M("`@?0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"1S=&%R="`K(#(L
M("1K97DI*2!["B`@("`@("`@("`@("1R97,@?#T@*"1K97E;)'-T87)T("L@
M,ETI(#P\(#@["B`@("`@("`@?0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"1S=&%R="`K(#,L("1K97DI*2!["B`@("`@("`@("`@("1R97,@?#T@
M*"1K97E;)'-T87)T("L@,UTI.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<SL*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-I<&AE<B]R8S(N<&AP
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W,#<W(#$P
M-3$U-#,T,30P(#`R,3<V-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AE($-I<&AE<E]R8S(Z.B!C
M;&%S<R!I;7!L96UE;G1S('1H92!#:7!H97(@:6YT97)F86-E(&5N8W)Y<'1I
M;VX@9&%T80H@*B!U<VEN9R!T:&4@4D,R(&%L9V]R:71H;2!A<R!D97-C<FEB
M960@:6X@4D9#,C(V."X*("H*("H@0F%S960@;VX@=&AE(&YO=&5S(&)Y(%!E
M=&5R($=U=&UA;FX@/'!G=70P,4!C<RYA=6-K;&%N9"YA8RYN>CX*("H@:'1T
M<#HO+W=W=RYM:7)R;W)S+G=I<F5T87!P960N;F5T+W-E8W5R:71Y+V-R>7!T
M;V=R87!H>2\*("H@("!A;&=O<FET:&US+W)C,B]C;VUM96YT<R]G=71M86XM
M.38P,C$Q"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O
M<F,R+G!H<"QV(#$N.2XQ,BXW(#(P,#8O,#$O,#$@,C$Z,C@Z,3`@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\
M;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H
M97(*("HO"F-L87-S($AO<F1E7T-I<&AE<E]R8S(@97AT96YD<R!(;W)D95]#
M:7!H97(@>PH*("`@("\J*@H@("`@("H@4&5R;75T871I;VYS(&%R<F%Y"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P97)M
M(#T@87)R87DH"B`@("`@("`@,'A$.2P@,'@W."P@,'A&.2P@,'A#-"P@,'@Q
M.2P@,'A$1"P@,'A"-2P@,'A%1"P*("`@("`@("`P>#(X+"`P>$4Y+"`P>$9$
M+"`P>#<Y+"`P>#1!+"`P>$$P+"`P>$0X+"`P>#E$+`H@("`@("`@(#!X0S8L
M(#!X-T4L(#!X,S<L(#!X.#,L(#!X,D(L(#!X-S8L(#!X-3,L(#!X.$4L"B`@
M("`@("`@,'@V,BP@,'@T0RP@,'@V-"P@,'@X."P@,'@T-"P@,'@X0BP@,'A&
M0BP@,'A!,BP*("`@("`@("`P>#$W+"`P>#E!+"`P>#4Y+"`P>$8U+"`P>#@W
M+"`P>$(S+"`P>#1&+"`P>#$S+`H@("`@("`@(#!X-C$L(#!X-#4L(#!X-D0L
M(#!X.$0L(#!X,#DL(#!X.#$L(#!X-T0L(#!X,S(L"B`@("`@("`@,'A"1"P@
M,'@X1BP@,'@T,"P@,'A%0BP@,'@X-BP@,'A"-RP@,'@W0BP@,'@P0BP*("`@
M("`@("`P>$8P+"`P>#DU+"`P>#(Q+"`P>#(R+"`P>#5#+"`P>#9"+"`P>#1%
M+"`P>#@R+`H@("`@("`@(#!X-30L(#!X1#8L(#!X-C4L(#!X.3,L(#!X0T4L
M(#!X-C`L(#!X0C(L(#!X,4,L"B`@("`@("`@,'@W,RP@,'@U-BP@,'A#,"P@
M,'@Q-"P@,'A!-RP@,'@X0RP@,'A&,2P@,'A$0RP*("`@("`@("`P>#$R+"`P
M>#<U+"`P>$-!+"`P>#%&+"`P>#-"+"`P>$)%+"`P>$4T+"`P>$0Q+`H@("`@
M("`@(#!X-#(L(#!X,T0L(#!X1#0L(#!X,S`L(#!X03,L(#!X,T,L(#!X0C8L
M(#!X,C8L"B`@("`@("`@,'@V1BP@,'A"1BP@,'@P12P@,'A$02P@,'@T-BP@
M,'@V.2P@,'@P-RP@,'@U-RP*("`@("`@("`P>#(W+"`P>$8R+"`P>#%$+"`P
M>#E"+"`P>$)#+"`P>#DT+"`P>#0S+"`P>#`S+`H@("`@("`@(#!X1C@L(#!X
M,3$L(#!X0S<L(#!X1C8L(#!X.3`L(#!X148L(#!X,T4L(#!X13<L"B`@("`@
M("`@,'@P-BP@,'A#,RP@,'A$-2P@,'@R1BP@,'A#."P@,'@V-BP@,'@Q12P@
M,'A$-RP*("`@("`@("`P>#`X+"`P>$4X+"`P>$5!+"`P>$1%+"`P>#@P+"`P
M>#4R+"`P>$5%+"`P>$8W+`H@("`@("`@(#!X.#0L(#!X04$L(#!X-S(L(#!X
M04,L(#!X,S4L(#!X-$0L(#!X-D$L(#!X,D$L"B`@("`@("`@,'@Y-BP@,'@Q
M02P@,'A$,BP@,'@W,2P@,'@U02P@,'@Q-2P@,'@T.2P@,'@W-"P*("`@("`@
M("`P>#1"+"`P>#E&+"`P>$0P+"`P>#5%+"`P>#`T+"`P>#$X+"`P>$$T+"`P
M>$5#+`H@("`@("`@(#!X0S(L(#!X13`L(#!X-#$L(#!X-D4L(#!X,$8L(#!X
M-3$L(#!X0T(L(#!X0T,L"B`@("`@("`@,'@R-"P@,'@Y,2P@,'A!1BP@,'@U
M,"P@,'A!,2P@,'A&-"P@,'@W,"P@,'@S.2P*("`@("`@("`P>#DY+"`P>#=#
M+"`P>#-!+"`P>#@U+"`P>#(S+"`P>$(X+"`P>$(T+"`P>#=!+`H@("`@("`@
M(#!X1D,L(#!X,#(L(#!X,S8L(#!X-4(L(#!X,C4L(#!X-34L(#!X.3<L(#!X
M,S$L"B`@("`@("`@,'@R1"P@,'@U1"P@,'A&02P@,'@Y."P@,'A%,RP@,'@X
M02P@,'@Y,BP@,'A!12P*("`@("`@("`P>#`U+"`P>$1&+"`P>#(Y+"`P>#$P
M+"`P>#8W+"`P>#9#+"`P>$)!+"`P>$,Y+`H@("`@("`@(#!X1#,L(#!X,#`L
M(#!X138L(#!X0T8L(#!X13$L(#!X.44L(#!X03@L(#!X,D,L"B`@("`@("`@
M,'@V,RP@,'@Q-BP@,'@P,2P@,'@S1BP@,'@U."P@,'A%,BP@,'@X.2P@,'A!
M.2P*("`@("`@("`P>#!$+"`P>#,X+"`P>#,T+"`P>#%"+"`P>$%"+"`P>#,S
M+"`P>$9&+"`P>$(P+`H@("`@("`@(#!X0D(L(#!X-#@L(#!X,$,L(#!X-48L
M(#!X0CDL(#!X0C$L(#!X0T0L(#!X,D4L"B`@("`@("`@,'A#-2P@,'A&,RP@
M,'A$0BP@,'@T-RP@,'A%-2P@,'A!-2P@,'@Y0RP@,'@W-RP*("`@("`@("`P
M>#!!+"`P>$$V+"`P>#(P+"`P>#8X+"`P>$9%+"`P>#=&+"`P>$,Q+"`P>$%$
M"B`@("`I.PH*("`@("\J*@H@("`@("H@07)R87D@=&\@:&]L9"!T:&4@:V5Y
M('-C:&5D=6QE"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]K97E38VAE9'5L92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@
M*B!3970@=&AE(&ME>2!T;R!B92!U<V5D(&9O<B!E;B]D96-R>7!T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@5&AE(&ME>2!T;R!U
M<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ME>2@D:V5Y*0H@("`@>PH@
M("`@("`@("1K97D@/2!A<G)A>5]V86QU97,H=6YP86-K*"=#*B<L("1K97DI
M*3L*("`@("`@("`D8FET<R`](#$P,C0["@H@("`@("`@("\J($5X<&%N9"!I
M;G!U="!K97D@=&\@,3(X(&)Y=&5S("HO"B`@("`@("`@)&QE;B`](&-O=6YT
M*"1K97DI.PH@("`@("`@("1L87-T(#T@)&ME>5LD;&5N("T@,5T["B`@("`@
M("`@9F]R("@D:2`]("1L96X[("1I(#P@,3(X.R`D:2LK*2!["B`@("`@("`@
M("`@("1L87-T(#T@)'1H:7,M/E]P97)M6R@D:V5Y6R1I("T@)&QE;ET@*R`D
M;&%S="D@)B`P>$9&73L*("`@("`@("`@("`@)&ME>5LD:5T@/2`D;&%S=#L*
M("`@("`@("!]"@H@("`@("`@("\J(%!H87-E(#(@+2!R961U8V4@969F96-T
M:79E(&ME>2!S:7IE('1O(")B:71S(B`J+PH@("`@("`@(&EF("@D;&5N("$]
M(#@I('L*("`@("`@("`@("`@)&QE;B`]("1L96X@*B`X.PH@("`@("`@('T*
M("`@("`@("`D:V5Y6S$R."`M("1L96Y=(#T@)'1H:7,M/E]P97)M6R1K97E;
M,3(X("T@)&QE;ET@)B`P>$9&73L*("`@("`@("!F;W(@*"1I(#T@,3(W("T@
M)&QE;CL@)&D@/CT@,#L@)&DM+2D@>PH@("`@("`@("`@("`D:V5Y6R1I72`]
M("1T:&ES+3Y?<&5R;5LD:V5Y6R1I("L@)&QE;ET@7B`D:V5Y6R1I("L@,5U=
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4&AA<V4@,R`M(&-O;G9E<G0@=&\@
M,38@8FET('9A;'5E<R`J+PH@("`@("`@(&9O<B`H)&D@/2`V,SL@)&D@/CT@
M,#L@)&DM+2D@>PH@("`@("`@("`@("`D=&AI<RT^7VME>5-C:&5D=6QE6R1I
M72`]("@D:V5Y6R1I("H@,B`K(#%=(#P\(#@@?"`D:V5Y6R1I("H@,ETI("8@
M,'A&1D9&.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@<VEZ92!O9B!T:&4@8FQO8VMS('1H870@=&AI<R!C:7!H97(@;F5E
M9',N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R
M(&]F(&-H87)A8W1E<G,@<&5R(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971";&]C:U-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`X.PH@("`@
M?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O
M(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME
M>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E
M;F-R>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T
M0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$ME>2@D
M:V5Y*3L*("`@("`@("!]"@H@("`@("`@("1P;&%I;B`]('5N<&%C:R@G=BHG
M+"`D8FQO8VLI.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q-CL@)&DK
M*RD@>PH@("`@("`@("`@("`D<&QA:6Y;,5T@*ST@*"1P;&%I;ELR72`F('XD
M<&QA:6Y;-%TI("L@*"1P;&%I;ELS72`F("1P;&%I;ELT72D@*R`D=&AI<RT^
M7VME>5-C:&5D=6QE6S0@*B`D:2`K(#!=.PH@("`@("`@("`@("`D8FEN(#T@
M<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)'!L86EN6S%=*2P@,S(L("<P)RP@
M4U127U!!1%],1494*3L*("`@("`@("`@("`@)'!L86EN6S%=(#T@8FEN9&5C
M*"1B:6X@+B!S=6)S='(H)&)I;BP@,38L(#$I*3L*"B`@("`@("`@("`@("1P
M;&%I;ELR72`K/2`H)'!L86EN6S-=("8@?B1P;&%I;ELQ72D@*R`H)'!L86EN
M6S1=("8@)'!L86EN6S%=*2`K("1T:&ES+3Y?:V5Y4V-H961U;&5;-"`J("1I
M("L@,5T["B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E8V)I;B@P>$9&
M1D8@)B`D<&QA:6Y;,ETI+"`S,BP@)S`G+"!35%)?4$%$7TQ%1E0I.PH@("`@
M("`@("`@("`D<&QA:6Y;,ET@/2!B:6YD96,H)&)I;B`N('-U8G-T<B@D8FEN
M+"`Q-BP@,BDI.PH*("`@("`@("`@("`@)'!L86EN6S-=("L]("@D<&QA:6Y;
M-%T@)B!^)'!L86EN6S)=*2`K("@D<&QA:6Y;,5T@)B`D<&QA:6Y;,ETI("L@
M)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`R73L*("`@("`@("`@("`@
M)&)I;B`]('-T<E]P860H9&5C8FEN*#!X1D9&1B`F("1P;&%I;ELS72DL(#$V
M+"`G,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1P;&%I;ELS72`]
M(&)I;F1E8R@D8FEN("X@<W5B<W1R*"1B:6XL(#`L(#,I*3L*"B`@("`@("`@
M("`@("1P;&%I;ELT72`K/2`H)'!L86EN6S%=("8@?B1P;&%I;ELS72D@*R`H
M)'!L86EN6S)=("8@)'!L86EN6S-=*2`K("1T:&ES+3Y?:V5Y4V-H961U;&5;
M-"`J("1I("L@,UT["B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D*&1E8V)I
M;B@P>$9&1D8@)B`D<&QA:6Y;-%TI+"`Q-BP@)S`G+"!35%)?4$%$7TQ%1E0I
M.PH@("`@("`@("`@("`D<&QA:6Y;-%T@/2!B:6YD96,H)&)I;B`N('-U8G-T
M<B@D8FEN+"`P+"`U*2D["@H@("`@("`@("`@("!I9B`H)&D@/3T@-"!\?"`D
M:2`]/2`Q,"D@>PH@("`@("`@("`@("`@("`@)'!L86EN6S%=("L]("1T:&ES
M+3Y?:V5Y4V-H961U;&5;)'!L86EN6S1=("8@,'@S1ET["B`@("`@("`@("`@
M("`@("`D<&QA:6Y;,ET@*ST@)'1H:7,M/E]K97E38VAE9'5L95LD<&QA:6Y;
M,5T@)B`P>#-&73L*("`@("`@("`@("`@("`@("1P;&%I;ELS72`K/2`D=&AI
M<RT^7VME>5-C:&5D=6QE6R1P;&%I;ELR72`F(#!X,T9=.PH@("`@("`@("`@
M("`@("`@)'!L86EN6S1=("L]("1T:&ES+3Y?:V5Y4V-H961U;&5;)'!L86EN
M6S-=("8@,'@S1ET["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@
M("`D96YC<GEP=&5D(#T@<&%C:R@B=BHB+"`D<&QA:6Y;,5TL("1P;&%I;ELR
M72P@)'!L86EN6S-=+"`D<&QA:6Y;-%TI.PH@("`@("`@(')E='5R;B`D96YC
M<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A(&)L;V-K
M(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@
M(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K
M97D@("`@5&AE(&ME>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!D96-R>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!D96-R>7!T0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=$ME>2@D:V5Y*3L*("`@("`@("!]"@H@("`@("`@("1C:7!H97(@
M/2!U;G!A8VLH)W8J)RP@)&)L;V-K*3L*"B`@("`@("`@9F]R("@D:2`](#$U
M.R`D:2`^/2`P.R`D:2TM*2!["B`@("`@("`@("`@("1B:6X@/2!S=')?<&%D
M*&1E8V)I;B@P>$9&1D8@)B`D8VEP:&5R6S1=*2P@,38L("<P)RP@4U127U!!
M1%],1494*3L*("`@("`@("`@("`@)&-I<&AE<ELT72`](&)I;F1E8RAS=6)S
M='(H)&)I;BP@+3(Q+"`R,2D@+B!S=6)S='(H)&)I;BP@,"P@,3$I*3L*("`@
M("`@("`@("`@)&-I<&AE<ELT72`M/2`H)&-I<&AE<ELQ72`F('XD8VEP:&5R
M6S-=*2`K("@D8VEP:&5R6S)=("8@)&-I<&AE<ELS72D@*R`D=&AI<RT^7VME
M>5-C:&5D=6QE6S0@*B`D:2`K(#-=.PH*("`@("`@("`@("`@)&)I;B`]('-T
M<E]P860H9&5C8FEN*#!X1D9&1B`F("1C:7!H97);,UTI+"`Q-BP@)S`G+"!3
M5%)?4$%$7TQ%1E0I.PH@("`@("`@("`@("`D8VEP:&5R6S-=(#T@8FEN9&5C
M*'-U8G-T<B@D8FEN+"`M,3DL(#$Y*2`N('-U8G-T<B@D8FEN+"`P+"`Q,RDI
M.PH@("`@("`@("`@("`D8VEP:&5R6S-=("T]("@D8VEP:&5R6S1=("8@?B1C
M:7!H97);,ETI("L@*"1C:7!H97);,5T@)B`D8VEP:&5R6S)=*2`K("1T:&ES
M+3Y?:V5Y4V-H961U;&5;-"`J("1I("L@,ET["@H@("`@("`@("`@("`D8FEN
M(#T@<W1R7W!A9"AD96-B:6XH,'A&1D9&("8@)&-I<&AE<ELR72DL(#$V+"`G
M,"<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1C:7!H97);,ET@/2!B
M:6YD96,H<W5B<W1R*"1B:6XL("TQ."P@,3@I("X@<W5B<W1R*"1B:6XL(#`L
M(#$T*2D["B`@("`@("`@("`@("1C:7!H97);,ET@+3T@*"1C:7!H97);,UT@
M)B!^)&-I<&AE<ELQ72D@*R`H)&-I<&AE<ELT72`F("1C:7!H97);,5TI("L@
M)'1H:7,M/E]K97E38VAE9'5L95LT("H@)&D@*R`Q73L*"B`@("`@("`@("`@
M("1B:6X@/2!S=')?<&%D*&1E8V)I;B@P>$9&1D8@)B`D8VEP:&5R6S%=*2P@
M,38L("<P)RP@4U127U!!1%],1494*3L*("`@("`@("`@("`@)&-I<&AE<ELQ
M72`](&)I;F1E8RAS=6)S='(H)&)I;BP@+3$W+"`Q-RD@+B!S=6)S='(H)&)I
M;BP@,"P@,34I*3L*("`@("`@("`@("`@)&-I<&AE<ELQ72`M/2`H)&-I<&AE
M<ELR72`F('XD8VEP:&5R6S1=*2`K("@D8VEP:&5R6S-=("8@)&-I<&AE<ELT
M72D@*R`D=&AI<RT^7VME>5-C:&5D=6QE6S0@*B`D:2`K(#!=.PH*("`@("`@
M("`@("`@:68@*"1I(#T](#4@?'P@)&D@/3T@,3$I('L*("`@("`@("`@("`@
M("`@("1C:7!H97);-%T@+3T@)'1H:7,M/E]K97E38VAE9'5L95LD8VEP:&5R
M6S-=("8@,'@S1ET["B`@("`@("`@("`@("`@("`D8VEP:&5R6S-=("T]("1T
M:&ES+3Y?:V5Y4V-H961U;&5;)&-I<&AE<ELR72`F(#!X,T9=.PH@("`@("`@
M("`@("`@("`@)&-I<&AE<ELR72`M/2`D=&AI<RT^7VME>5-C:&5D=6QE6R1C
M:7!H97);,5T@)B`P>#-&73L*("`@("`@("`@("`@("`@("1C:7!H97);,5T@
M+3T@)'1H:7,M/E]K97E38VAE9'5L95LD8VEP:&5R6S1=("8@,'@S1ET["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!P86-K*")V
M*B(L("1C:7!H97);,5TL("1C:7!H97);,ETL("1C:7!H97);,UTL("1C:7!H
M97);-%TI.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]#:7!H97(O<F,T+G!H<```````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-#0T,"`Q,#4Q-30S-#$T,"`P,C$W-30`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H92!#:7!H97)?<F,T.CH@8VQA<W,@:6UP;&5M96YT<R!T:&4@0VEP:&5R
M(&EN=&5R9F%C92!E;F-R>7!T:6]N(&1A=&$*("H@=7-I;F<@=&AE(%)#-"!E
M;F-R>7!T:6]N(&%L9V]R=&AI;2X@5&AI<R!C;&%S<R!U<V5S('1H92!014%2
M($-R>7!T7U)#-`H@*B!C;&%S<R!T;R!D;R!T:&4@96YC<GEP=&EO;BX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO0VEP:&5R+T-I<&AE<B]R8S0N<&AP+'8@
M,2XT+C$R+C<@,C`P-B\P,2\P,2`R,3HR.#HQ,"!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK
M92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E
M("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA
M<W,@2&]R9&5?0VEP:&5R7W)C-"!E>'1E;F1S($AO<F1E7T-I<&AE<B!["@H@
M("`@+RHJ"B`@("`@*B!0;VEN=&5R('1O(&$@4$5!4B!#<GEP=%]R8S0@;V)J
M96-T"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]C:7!H97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?0VEP:&5R7W)C-"@D<&%R
M86US(#T@;G5L;"D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)T-R>7!T
M+U)C-"YP:'`G.PH@("`@("`@("1T:&ES+3Y?8VEP:&5R(#T@)FYE=R!#<GEP
M=%]28S0H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:V5Y('1O
M(&)E('5S960@9F]R(&5N+V1E8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:V5Y("!4:&4@:V5Y('1O('5S92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T2V5Y*"1K97DI"B`@("!["B`@("`@("`@)'1H:7,M/E]C
M:7!H97(M/FME>2@D:V5Y*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@<VEZ92!O9B!T:&4@8FQO8VMS('1H870@=&AI<R!C:7!H97(@;F5E
M9',N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@;G5M8F5R
M(&]F(&-H87)A8W1E<G,@<&5R(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971";&]C:U-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`X.PH@("`@
M?0H*("`@("\J*@H@("`@("H@16YC<GEP="!A(&)L;V-K(&]F(&1A=&$N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8FQO8VL@(%1H92!D871A('1O
M(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1K97D@("`@5&AE(&ME
M>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E
M;F-R>7!T960@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;F-R>7!T
M0FQO8VLH)&)L;V-K+"`D:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(6ES7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$ME>2@D
M:V5Y*3L*("`@("`@("!]"@H@("`@("`@("\O($UA:V4@82!C;W!Y(&]F('1H
M92!C:7!H97(@87,@:70@9&5S=')O>7,@:71S96QF(&1U<FEN9R!A(&-R>7!T
M"B`@("`@("`@)&-I<&AE<B`]("1T:&ES+3Y?8VEP:&5R.PH@("`@("`@("1C
M:7!H97(M/F-R>7!T*"1B;&]C:RD["@H@("`@("`@(')E='5R;B`D8FQO8VL[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@8FQO8VL@;V8@9&%T
M82X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1B;&]C:R`@5&AE(&1A
M=&$@=&\@9&5C<GEP="X*("`@("`J($!P87)A;2!S=')I;F<@)&ME>2`@("!4
M:&4@:V5Y('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&1E8W)Y<'1E9"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M8W)Y<'1";&]C:R@D8FQO8VLL("1K97D@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T
M2V5Y*"1K97DI.PH@("`@("`@('T*"B`@("`@("`@+R\@36%K92!A(&-O<'D@
M;V8@=&AE(&-I<&AE<B!A<R!I="!D97-T<F]Y<R!I='-E;&8@9'5R:6YG(&$*
M("`@("`@("`O+R!C<GEP="X*("`@("`@("`D8VEP:&5R(#T@)'1H:7,M/E]C
M:7!H97(["B`@("`@("`@)&-I<&AE<BT^9&5C<GEP="@D8FQO8VLI.PH*("`@
M("`@("!R971U<FX@)&)L;V-K.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+V5C8BYP:'``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#,S-B`Q,#4Q-30S-#$T,"`P,C,V
M-C``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V5C8CHZ
M(%1H:7,@8VQA<W,@:6UP;&5M96YT<R!T:&4*("H@2&]R9&5?0VEP:&5R7T)L
M;V-K36]D92!U<VEN9R!T:&4@16QE8W1R;VYI8R!#;V1E($)O;VL@;65T:&]D
M(&]F"B`J(&5N8W)Y<'1I;F<@8FQO8VMS(&]F(&1A=&$N"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E+V5C8BYP:'`L
M=B`Q+C<N,3(N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C$Q(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!(;W)D92`R+C(*("H@0'!A8VMA9V4@2&]R9&5?0VEP:&5R"B`J+PIC
M;&%S<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V5C8B!E>'1E;F1S($AO<F1E
M7T-I<&AE<E]";&]C:TUO9&4@>PH*("`@("\J*@H@("`@("H@16YC<GEP="!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP:&5R("1C
M:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!E;F-R>7!T:6]N+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&QA:6YT97AT("`@("!4:&4@9&%T82!T;R!E;F-R
M>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!E;F-R>7!T960@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP="@F)&-I<&AE<BP@)'!L
M86EN=&5X="D*("`@('L*("`@("`@("`D96YC<GEP=&5D(#T@)R<["B`@("`@
M("`@)&)L;V-K<VEZ92`]("1C:7!H97(M/F=E=$)L;V-K4VEZ92@I.PH*("`@
M("`@("`D:DUA>"`]('-T<FQE;B@D<&QA:6YT97AT*3L*("`@("`@("!F;W(@
M*"1J(#T@,#L@)&H@/"`D:DUA>#L@)&H@*ST@)&)L;V-K<VEZ92D@>PH@("`@
M("`@("`@("`D<&QA:6X@/2!S=6)S='(H)'!L86EN=&5X="P@)&HL("1B;&]C
M:W-I>F4I.PH*("`@("`@("`@("`@:68@*'-T<FQE;B@D<&QA:6XI(#P@)&)L
M;V-K<VEZ92D@>PH@("`@("`@("`@("`@("`@+R\@<&%D('1H92!B;&]C:R!W
M:71H(%PP)W,@:68@:70G<R!N;W0@;&]N9R!E;F]U9V@*("`@("`@("`@("`@
M("`@("1P;&%I;B`]('-T<E]P860H)'!L86EN+"`X+"`B7#`B*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&5N8W)Y<'1E9"`N/2`D8VEP:&5R+3YE
M;F-R>7!T0FQO8VLH)'!L86EN*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP="!A
M('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?0VEP:&5R("1C
M:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!D96-R>7!T:6]N+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T82!T;R!D96-R
M>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!D96-R>7!T960@9&%T
M82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I<&AE<BP@)&-I
M<&AE<G1E>'0I"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]("<G.PH@("`@
M("`@("1B;&]C:W-I>F4@/2`D8VEP:&5R+3YG971";&]C:U-I>F4H*3L*"B`@
M("`@("`@)&I-87@@/2!S=')L96XH)&-I<&AE<G1E>'0I.PH@("`@("`@(&9O
M<B`H)&H@/2`P.R`D:B`\("1J36%X.R`D:B`K/2`D8FQO8VMS:7IE*2!["B`@
M("`@("`@("`@("1P;&%I;B`]('-U8G-T<B@D8VEP:&5R=&5X="P@)&HL("1B
M;&]C:W-I>F4I.PH@("`@("`@("`@("`D9&5C<GEP=&5D("X]("1C:7!H97(M
M/F1E8W)Y<'1";&]C:R@D<&QA:6XI.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4F5M;W9E('1R86EL:6YG(%PP)W,@=7-E9"!T;R!P860@=&AE(&QA<W0@8FQO
M8VLN"B`@("`@("`@=VAI;&4@*'-U8G-T<B@D9&5C<GEP=&5D+"`M,2P@,2D@
M/3T@(EPP(BD@>PH@("`@("`@("`@("`D9&5C<GEP=&5D(#T@<W5B<W1R*"1D
M96-R>7!T960L(#`L("TQ*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M9&5C<GEP=&5D.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H97(O0FQO8VM-;V1E
M+V]F8C8T+G!H<```````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#`W-B`Q,#4Q
M-30S-#$T,"`P,C0P-3``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]#:7!H97)?0FQO
M8VM-;V1E7V]F8C8T.CH@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H90H@*B!(
M;W)D95]#:7!H97)?0FQO8VM-;V1E('5S:6YG(&$@-C0@8FET(&]U='!U="!F
M965D8F%C:RX*("H*("H@5&AI<R!C86X@=7-E9"!T;R!E;F-R>7!T(&%N>2!L
M96YG=&@@<W1R:6YG(&%N9"!T:&4@96YC<GEP=&5D('9E<G-I;VX*("H@=VEL
M;"!B92!T:&4@<V%M92!L96YG=&@N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E+V]F8C8T+G!H<"QV(#$N-RXQ,BXU
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC
M;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI:V4@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!S:6YC92`@($AO<F1E
M(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*("HO"F-L87-S($AO<F1E
M7T-I<&AE<E]";&]C:TUO9&5?;V9B-C0@97AT96YD<R!(;W)D95]#:7!H97)?
M0FQO8VM-;V1E('L*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#
M:7!H97(@86QG;W)I=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)'!L86EN=&5X="`@("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I
M"B`@("!["B`@("`@("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@("`@("`D;B`]
M(#`["B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L86EN=&5X="D["B`@("`@
M("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@("`@
M("`@:68@*"1N(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:78@
M/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1C(#T@)'!L86EN=&5X=%LD:ET@7B`D=&AI
M<RT^7VEV6R1N73L*("`@("`@("`@("`@)&5N8W)Y<'1E9"`N/2`D8SL*"B`@
M("`@("`@("`@("1N(#T@*"LK)&XI("8@,'@P-SL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D96YC<GEP=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5C<GEP="!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@2&]R9&5?
M0VEP:&5R("1C:7!H97(@($-I<&AE<B!A;&=O<FET:&T@=&\@=7-E(&9O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D96-R>7!T:6]N
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VEP:&5R=&5X="`@("!4:&4@9&%T
M82!T;R!D96-R>7!T+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!D96-R
M>7!T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C<GEP="@F)&-I
M<&AE<BP@)&-I<&AE<G1E>'0I"B`@("!["B`@("`@("`@)&1E8W)Y<'1E9"`]
M("<G.PH*("`@("`@("`D;B`](#`["B`@("`@("`@)&I-87@@/2!S=')L96XH
M)&-I<&AE<G1E>'0I.PH@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\("1J36%X
M.R`D:BLK*2!["B`@("`@("`@("`@(&EF("@D;B`]/2`P*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VEV(#T@)&-I<&AE<BT^96YC<GEP=$)L;V-K*"1T
M:&ES+3Y?:78I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8R`]("1C
M:7!H97)T97AT6R1J72!>("1T:&ES+3Y?:79;)&Y=.PH@("`@("`@("`@("`D
M9&5C<GEP=&5D("X]("1C.PH*("`@("`@("`@("`@)&X@/2`H*RLD;BD@)B`P
M>#`W.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1D96-R>7!T960["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]#:7!H
M97(O0FQO8VM-;V1E+V-F8C8T+G!H<```````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-#8V-"`Q,#4Q-30S-#$T,"`P,C0P,S<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D
M95]#:7!H97)?0FQO8VM-;V1E7V-F8C8T.CH@5&AI<R!C;&%S<R!I;7!L96UE
M;G1S('1H90H@*B!(;W)D95]#:7!H97)?0FQO8VM-;V1E('5S:6YG(&$@-C0@
M8FET(&-I<&AE<B!F965D8F%C:RX*("H*("H@5&AI<R!C86X@8F4@=7-E9"!T
M;R!E;F-R>7!T(&%N>2!L96YG=&@@<W1R:6YG(&%N9"!T:&4@96YC<GEP=&5D
M"B`J('9E<G-I;VX@=VEL;"!B92!T:&4@<V%M92!L96YG=&@N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T-I<&AE<B]#:7!H97(O0FQO8VM-;V1E+V-F8C8T
M+G!H<"QV(#$N-RXQ,BXU(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J
M($!S:6YC92`@($AO<F1E(#(N,@H@*B!`<&%C:V%G92!(;W)D95]#:7!H97(*
M("HO"F-L87-S($AO<F1E7T-I<&AE<E]";&]C:TUO9&5?8V9B-C0@97AT96YD
M<R!(;W)D95]#:7!H97)?0FQO8VM-;V1E('L*"B`@("`O*BH*("`@("`J($5N
M8W)Y<'0@82!S=')I;F<N"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T-I
M<&AE<B`D8VEP:&5R("!#:7!H97(@86QG;W)I=&AM('1O('5S92!F;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)'!L86EN=&5X="`@("`@5&AE(&1A=&$@
M=&\@96YC<GEP="X*("`@("`J"B`@("`@*B!`<F5T=7)N("!4:&4@96YC<GEP
M=&5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)B1C:7!H
M97(L("1P;&%I;G1E>'0I"B`@("!["B`@("`@("`@)&5N8W)Y<'1E9"`]("<G
M.PH*("`@("`@("`D;B`](#`["B`@("`@("`@)&I-87@@/2!S=')L96XH)'!L
M86EN=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@)&I-87@[("1J
M*RLI('L*("`@("`@("`@("`@:68@*"1N(#T](#`I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R+3YE;F-R>7!T0FQO8VLH)'1H:7,M
M/E]I=BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C(#T@)'!L86EN
M=&5X=%LD:ET@7B`D=&AI<RT^7VEV6R1N73L*("`@("`@("`@("`@)'1H:7,M
M/E]I=B`]('-U8G-T<B@D=&AI<RT^7VEV+"`P+"`D;BD@+B`D8R`N('-U8G-T
M<B@D=&AI<RT^7VEV+"`D;B`K(#$I.PH@("`@("`@("`@("`D96YC<GEP=&5D
M("X]("1C.PH*("`@("`@("`@("`@)&X@/2`H*RLD;BD@)B`P>#`W.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1E;F-R>7!T960["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$96-R>7!T(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P
M87)A;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@0VEP:&5R(&%L9V]R:71H;2!T
M;R!U<V4@9F]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&1E8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C:7!H97)T97AT
M("`@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@*@H@("`@("H@0')E='5R
M;B`@5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D
M96-R>7!T*"8D8VEP:&5R+"`D8VEP:&5R=&5X="D*("`@('L*("`@("`@("`D
M9&5C<GEP=&5D(#T@)R<["@H@("`@("`@("1N(#T@,#L*("`@("`@("`D:DUA
M>"`]('-T<FQE;B@D8VEP:&5R=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[
M("1J(#P@)&I-87@[("1J*RLI('L*("`@("`@("`@("`@:68@*"1N(#T](#`I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:78@/2`D8VEP:&5R+3YE;F-R
M>7!T0FQO8VLH)'1H:7,M/E]I=BD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1C(#T@)&-I<&AE<G1E>'1;)&I=(%X@)'1H:7,M/E]I=ELD;ET["B`@
M("`@("`@("`@("1T:&ES+3Y?:78@/2!S=6)S='(H)'1H:7,M/E]I=BP@,"P@
M)&XI("X@<W5B<W1R*"1C:7!H97)T97AT+"`D:BP@,2D@+B!S=6)S='(H)'1H
M:7,M/E]I=BP@)&X@*R`Q*3L*("`@("`@("`@("`@)&1E8W)Y<'1E9"`N/2`D
M8SL*"B`@("`@("`@("`@("1N(#T@*"LK)&XI("8@,'@P-SL*("`@("`@("!]
M"@H@("`@("`@("\O(%)E;6]V92!T<F%I;&EN9R!<,"=S('5S960@=&\@<&%D
M('1H92!L87-T(&)L;V-K+@H@("`@("`@('=H:6QE("AS=6)S='(H)&1E8W)Y
M<'1E9"P@+3$L(#$I(#T](")<,"(I('L*("`@("`@("`@("`@)&1E8W)Y<'1E
M9"`]('-U8G-T<B@D9&5C<GEP=&5D+"`P+"`M,2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&1E8W)Y<'1E9#L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]#:7!H97(O0FQO8VM-;V1E+V-B8RYP:'``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-#<P,R`Q,#4Q-30S-#$T,"`P,C,V-30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!(;W)D95]#:7!H97)?0FQO8VM-;V1E7V-B8SHZ(%1H:7,@8VQA
M<W,@:6UP;&5M96YT<R!T:&4*("H@2&]R9&5?0VEP:&5R7T)L;V-K36]D92!U
M<VEN9R!T:&4@0VEP:&5R($)L;V-K($-H86EN:6YG(&UE=&AO9"!O9@H@*B!E
M;F-R>7!T:6YG(&)L;V-K<R!O9B!D871A+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]#:7!H97(O0VEP:&5R+T)L;V-K36]D92]C8F,N<&AP+'8@,2XW+C$R
M+C4@,C`P-B\P,2\P,2`R,3HR.#HQ,2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R
M9&4@,BXR"B`J($!P86-K86=E($AO<F1E7T-I<&AE<@H@*B\*8VQA<W,@2&]R
M9&5?0VEP:&5R7T)L;V-K36]D95]C8F,@97AT96YD<R!(;W)D95]#:7!H97)?
M0FQO8VM-;V1E('L*"B`@("`O*BH*("`@("`J($5N8W)Y<'0@82!S=')I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M($AO<F1E7T-I<&AE<B`D8VEP:&5R("!#
M:7!H97(@86QG;W)I=&AM('1O('5S92!F;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@96YC<GEP=&EO;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)'!L86EN=&5X="`@("`@5&AE(&1A=&$@=&\@96YC<GEP="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N("!4:&4@96YC<GEP=&5D(&1A=&$N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5N8W)Y<'0H)B1C:7!H97(L("1P;&%I;G1E>'0I
M"B`@("!["B`@("`@("`@)&5N8W)Y<'1E9"`]("<G.PH*("`@("`@("`D8FQO
M8VMS:7IE(#T@)&-I<&AE<BT^9V5T0FQO8VM3:7IE*"D["B`@("`@("`@)'!R
M979I;W5S0VEP:&5R(#T@)'1H:7,M/E]I=CL*"B`@("`@("`@)&I-87@@/2!S
M=')L96XH)'!L86EN=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@
M)&I-87@[("1J("L]("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN
M(#T@<W5B<W1R*"1P;&%I;G1E>'0L("1J+"`D8FQO8VMS:7IE*3L*"B`@("`@
M("`@("`@(&EF("AS=')L96XH)'!L86EN*2`\("1B;&]C:W-I>F4I('L*("`@
M("`@("`@("`@("`@("\O('!A9"!T:&4@8FQO8VL@=VET:"!<,"=S(&EF(&ET
M)W,@;F]T(&QO;F<@96YO=6=H"B`@("`@("`@("`@("`@("`D<&QA:6X@/2!S
M=')?<&%D*"1P;&%I;BP@."P@(EPP(BD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1P;&%I;B`]("1P;&%I;B!>("1P<F5V:6]U<T-I<&AE<CL*("`@
M("`@("`@("`@)'!R979I;W5S0VEP:&5R(#T@)&-I<&AE<BT^96YC<GEP=$)L
M;V-K*"1P;&%I;BD["B`@("`@("`@("`@("1E;F-R>7!T960@+CT@)'!R979I
M;W5S0VEP:&5R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E;F-R>7!T
M960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96-R>7!T(&$@<W1R:6YG+@H@
M("`@("H*("`@("`J($!P87)A;2!(;W)D95]#:7!H97(@)&-I<&AE<B`@0VEP
M:&5R(&%L9V]R:71H;2!T;R!U<V4@9F]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&1E8W)Y<'1I;VXN"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C:7!H97)T97AT("`@(%1H92!D871A('1O(&1E8W)Y<'0N"B`@("`@
M*@H@("`@("H@0')E='5R;B`@5&AE(&1E8W)Y<'1E9"!D871A+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!D96-R>7!T*"8D8VEP:&5R+"`D8VEP:&5R=&5X="D*
M("`@('L*("`@("`@("`D9&5C<GEP=&5D(#T@)R<["@H@("`@("`@("1B;&]C
M:W-I>F4@/2`D8VEP:&5R+3YG971";&]C:U-I>F4H*3L*("`@("`@("`D<')E
M=FEO=7-#:7!H97(@/2`D=&AI<RT^7VEV.PH*("`@("`@("`D:DUA>"`]('-T
M<FQE;B@D8VEP:&5R=&5X="D["B`@("`@("`@9F]R("@D:B`](#`[("1J(#P@
M)&I-87@[("1J("L]("1B;&]C:W-I>F4I('L*("`@("`@("`@("`@)'!L86EN
M(#T@<W5B<W1R*"1C:7!H97)T97AT+"`D:BP@)&)L;V-K<VEZ92D["B`@("`@
M("`@("`@("1D96-R>7!T960@+CT@)&-I<&AE<BT^9&5C<GEP=$)L;V-K*"1P
M;&%I;BD@7B`D<')E=FEO=7-#:7!H97(["B`@("`@("`@("`@("1P<F5V:6]U
M<T-I<&AE<B`]("1P;&%I;CL*("`@("`@("!]"@H@("`@("`@("\O(%)E;6]V
M92!T<F%I;&EN9R!<,"=S('5S960@=&\@<&%D('1H92!L87-T(&)L;V-K+@H@
M("`@("`@('=H:6QE("AS=6)S='(H)&1E8W)Y<'1E9"P@+3$L(#$I(#T](")<
M,"(I('L*("`@("`@("`@("`@)&1E8W)Y<'1E9"`]('-U8G-T<B@D9&5C<GEP
M=&5D+"`P+"`M,2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&1E8W)Y
M<'1E9#L*("`@('T*"GT*````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]$871A5')E92]S<6PN<&AP````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$W-#(V-2`Q,#4Q-30S-#$T,"`P
M,C(S-3<`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!$871A5')E95]S<6PZ.B!C;&%S<R!P<F]V
M:61E<R!A;B!344P@:6UP;&5M96YT871I;VX@;V8@=&AE($AO<F1E"B`J($1A
M=&%4<F5E('-Y<W1E;2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=P:'!T>7!E)R`@(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G
M<W%L)RP@)VUY<W%L)RP@971C+BDN"B`J("`@)V-H87)S970G("`@5&AE(&-H
M87)S970@=7-E9"!B>2!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO
M;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G=&%B;&4G("`@("!4:&4@;F%M
M92!O9B!T:&4@9&%T82!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@
M("`@("`@($1%1D%53%0Z("=H;W)D95]D871A=')E92<\+W!R93X*("H*("H@
M4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R
M93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N
M"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@
M8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@5&AE
M('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@("=H
M;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R
M+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L
M("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@("`G;W!T:6]N<R<@("!!9&1I
M=&EO;F%L(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@
M)W!O<G0G("`@("`@5&AE('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T
M:&4@9&%T86)A<V4N"B`J("`@)W1T>2<@("`@("`@5&AE(%1462!O;B!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R93X*("H*("H@5&AE
M('1A8FQE('-T<G5C='5R92!F;W(@=&AE($1A=&%4<F5E('-Y<W1E;2!I<R!I
M;@H@*B!S8W)I<'1S+W-Q;"]H;W)D95]D871A=')E92YS<6PN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+W-Q;"YP:'`L=B`Q
M+C$U-BXR+C,P(#(P,#8O,#<O,3,@,#DZ,#0Z,C`@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R
M0&)I9V9O;W0N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268*("H@>6]U(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E90H@*B!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H@0&%U=&AO<B`@4W1E<&AA;F4@2'5T:&5R(#QS:'5T:&5R0&)I
M9V9O;W0N8V]M/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@
M2&]R9&5?1&%T851R964*("HO"F-L87-S($1A=&%4<F5E7W-Q;"!E>'1E;F1S
M($1A=&%4<F5E('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U
M<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@5&AE
M(&YU;6)E<B!O9B!C;W!I97,@;V8@=&AE(&AO<F1E7V1A=&%T<F5E7V%T=')I
M8G5T97,@=&%B;&4*("`@("`J('1H870@=V4@;F5E9"!T;R!J;VEN(&]N(&EN
M('1H92!C=7)R96YT('%U97)Y+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]T86)L94-O=6YT(#T@,3L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=',@82!N97<@4U%,($1A=&%4<F5E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H87-H(&-O
M;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!$871A5')E95]S<6PH)'!A<F%M<RD*("`@('L*("`@("`@("!P
M87)E;G0Z.D1A=&%4<F5E*"1P87)A;7,I.PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@
M;V8@86QL(&=R;W5P<R`H<F]O="!N;V1E<RD@;V8@=&AE(&1A=&$@=')E92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@=&AE(&=R;W5P($E$
M<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<',H*0H@("`@>PH@("`@
M("`@("1Q=65R>2`]("=314Q%0U0@1$E35$E.0U0@9W)O=7!?=6ED($923TT@
M)R`N("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G73L*"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$=R
M;W5P<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/F=E=$-O
M;"@D<75E<GDI.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@*&$@<W5B
M<V5T(&]F*2!T:&4@9&%T871R964@:6YT;R!T:&4@)%]D871A(&%R<F%Y+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("1R;V]T("`@("`@("`@5VAI8V@@<&]R=&EO;B!O9B!T
M:&4@=')E92!T;R!L;V%D+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!$969A=6QT<R!T;R!A;&P@;V8@:70N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D;&]A9%1R964@("`@($QO860@82!T<F5E('-T87)T:6YG(&%T
M("1R;V]T+"!O<B!J=7-T('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R97%U97-T960@;&5V96P@86YD(&1I<F5C="!P87)E;G1S
M/PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT
M<R!T;R!S:6YG;&4@;&5V96PN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5L
M;V%D("`@("`@(%)E+6QO860@86QR96%D>2!L;V%D960@=F%L=65S/PH@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N86UE("!!='1R:6)U=&4@;F%M
M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@("!3;W)T(&1I
M<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQO860H)')O;W0@/2!$051!5%)%
M15]23T]4+"`D;&]A9%1R964@/2!F86QS92P@)')E;&]A9"`](&9A;'-E+`H@
M("`@("`@("`@("`@("`@("`@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B
M>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`O
M*B!$;R!.3U0@=7-E($1A=&%4<F5E.CIE>&ES=',H*2!H97)E.R!T:&%T('=O
M=6QD(&-A=7-E(&%N(&EN9FEN:71E"B`@("`@("`@("H@;&]O<"X@*B\*("`@
M("`@("!I9B`H(21R96QO860@)B8*("`@("`@("`@("`@*&EN7V%R<F%Y*"1R
M;V]T+"`D=&AI<RT^7VYA;65-87`I('Q\"B`@("`@("`@("`@("`H8V]U;G0H
M)'1H:7,M/E]D871A*2`F)B`D<F]O="`]/2!$051!5%)%15]23T]4*2D@?'P*
M("`@("`@("`@("`@*"%I<U]N=6QL*"1T:&ES+3Y?<V]R=$AA<V@I("8F"B`@
M("`@("`@("`@("!I<W-E="@D=&AI<RT^7V1A=&%;)')O;W1=6R=S;W)T97(G
M75LD=&AI<RT^7W-O<G1(87-H72DI*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/E]B=6EL
M9$QO8611=65R>2@D<F]O="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1L;V%D5')E92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($1!5$%44D5%7T)524Q$7U-%3$5#5"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?
M;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1S;W)T8GE?:V5Y+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1I<F5C=&EO;BD["B`@("`@("`@:68@*&ES7V$H)'%U97)Y
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D<75E<GDI*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.E]L;V%D
M*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH@("`@("`@("1D871A(#T@)'1H:7,M/E]D8BT^9V5T06QL*"1Q
M=65R>2D["B`@("`@("`@:68@*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1D871A.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/G-E="@D9&%T82P@)'1H:7,M/E]P87)A;7-;)V-H
M87)S970G72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W5N=',@*&$@<W5B
M<V5T(&]F*2!T:&4@9&%T871R964@=VAI8V@@=V]U;&0@8F4@;&]A9&5D(&EN
M=&\@=&AE("1?9&%T80H@("`@("H@87)R87D@:68@7VQO860H*2!I<R!C86QL
M960@=VET:"!T:&4@<V%M92!V86QU92!O9B`D<F]O="X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1R;V]T("!7:&EC:"!P;W)T:6]N(&]F('1H92!T<F5E('1O(&QO860N($1E
M9F%U;'1S('1O(&%L;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;V8@
M:70N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!.=6UB97(@;V8@
M;V)J96-T<PH@("`@("HO"B`@("!F=6YC=&EO;B!?8V]U;G0H)')O;W0@/2!$
M051!5%)%15]23T]4*0H@("`@>PH@("`@("`@("1Q=65R>2`]("1T:&ES+3Y?
M8G5I;&1,;V%D475E<GDH)')O;W0L('1R=64L($1!5$%44D5%7T)524Q$7T-/
M54Y4*3L*("`@("`@("!I9B`H:7-?82@D<75E<GDL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N(#`[
M"B`@("`@("`@?0H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@1&%T851R965?<W%L.CI?8V]U;G0H*3H@)R`N("1Q=65R>2P@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T
M=7)N("AI;G0I)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!,;V%D<R`H82!S=6)S970@;V8I('1H92!D871A=')E
M92!I;G1O('1H92`D7V1A=&$@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)')O;W0@
M("`@("`@("!7:&EC:"!P;W)T:6]N(&]F('1H92!T<F5E('1O(&QO860N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M(&%L;"!O9B!I="X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@
M("`@3&]A9"!A('1R964@<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<75E<W1E
M9"!L979E;"!A;F0@9&ER96-T('!A<F5N=',_"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O('-I;F=L92!L979E;"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1O<&5R871I;VX@("`@5'EP92!O9B!Q
M=65R>2!T;R!B=6EL9`H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-O<G1B>5]N
M86UE("!!='1R:6)U=&4@;F%M92!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@
M=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I
M<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO;CH*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@,"`M(&%S8V5N9&EN9PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U
M:6QD3&]A9%%U97)Y*"1R;V]T(#T@1$%40512145?4D]/5"P@)&QO8614<F5E
M(#T@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P97)A
M=&EO;B`]($1!5$%44D5%7T)524Q$7U-%3$5#5"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D<V]R=&)Y7VME
M>2`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1I<F5C
M=&EO;B`](#`I"B`@("!["B`@("`@("`@)'-O<G1E9"`](&9A;'-E.PH@("`@
M("`@("1W:&5R92`]('-P<FEN=&8H)V,N9W)O=7!?=6ED(#T@)7,@)RP@)'1H
M:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI*3L*"B`@
M("`@("`@:68@*"%E;7!T>2@D<F]O="D@)B8@)')O;W0@(3T@1$%40512145?
M4D]/5"D@>PH@("`@("`@("`@("`D<&%R96YT7W=H97)E(#T@)'1H:7,M/E]B
M=6EL9%!A<F5N=$ED<R@D<F]O="P@)&QO8614<F5E+"`G8RXG*3L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D<&%R96YT7W=H97)E*2`F)B`A:7-?82@D<&%R
M96YT7W=H97)E+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D
M=VAE<F4@/2!S<')I;G1F*"<E<R!!3D0@*"5S*2<L("1W:&5R92P@)'!A<F5N
M=%]W:&5R92D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1S;W)T8GE?;F%M92DI('L*("`@("`@("`@("`@)'=H97)E
M(#T@<W!R:6YT9B@G)7,@04Y$(&$N871T<FEB=71E7VYA;64@/2`E<R`G+"`D
M=VAE<F4L("1T:&ES+3Y?9&(M/G%U;W1E*"1S;W)T8GE?;F%M92DI.PH@("`@
M("`@("`@("`D<V]R=&5D(#T@=')U93L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1S;W)T8GE?:V5Y*2D@>PH@("`@("`@("`@("`D=VAE<F4@
M/2!S<')I;G1F*"<E<R!!3D0@82YA='1R:6)U=&5?:V5Y(#T@)7,@)RP@)'=H
M97)E+"`D=&AI<RT^7V1B+3YQ=6]T92@D<V]R=&)Y7VME>2DI.PH@("`@("`@
M("`@("`D<V]R=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@('-W:71C
M:"`H)&]P97)A=&EO;BD@>PH@("`@("`@(&-A<V4@1$%40512145?0E5)3$1?
M0T]53E0Z"B`@("`@("`@("`@("1W:&%T(#T@)T-/54Y4*"HI)SL*("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1W
M:&%T(#T@)V,N9&%T871R965?:60L(&,N9&%T871R965?;F%M92P@8RYD871A
M=')E95]P87)E;G1S+"!C+F1A=&%T<F5E7V]R9&5R)SL*("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@?0H*("`@("`@("!I9B`H)'-O<G1E9"D@>PH@("`@
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!C
M($Q%1E0@2D])3B`E<R!A($].("AC+F1A=&%T<F5E7VED(#T@82YD871A=')E
M95]I9"!/4B!C+F1A=&%T<F5E7VYA;64])7,I("<N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U=(15)%("5S($=23U50($)9(&,N9&%T871R965?
M:60L(&,N9&%T871R965?;F%M92P@8RYD871A=')E95]P87)E;G1S+"!C+F1A
M=&%T<F5E7V]R9&5R($]21$52($)9(&$N871T<FEB=71E7W9A;'5E("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=VAA="P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&5?871T<FEB=71E<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1R;V]T*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=VAE<F4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*"1D:7)E8W1I;VX@/3T@,2D@/R`G1$530R<@.B`G05-#)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M4T5,14-4("5S($923TT@)7,@8R!72$5212`E<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'=H870L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'=H97)E*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<75E<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@<&%R
M96YT($E$('-T<FEN9R!F;W(@<V5L96-T:6YG('1R965S+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("1R;V]T("`@("`@5VAI8V@@<&]R=&EO;B!O9B!T:&4@=')E92!T;R!L
M;V%D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&QO8614<F5E("!,;V%D(&$@
M=')E92!S=&%R=&EN9R!A="`D<F]O="P@;W(@:G5S="!T:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D
M:7)E8W0@<&%R96YT<S\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1&5F875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&IO:6Y?;F%M92!486)L92!J;VEN(&YA;64*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@260@;&ES="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V)U:6QD4&%R96YT261S*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@
M)&IO:6Y?;F%M92`]("<G*0H@("`@>PH@("`@("`@(&EF("AS=')P;W,H)')O
M;W0L("<Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T<R`](&5X
M<&QO9&4H)SHG+"`D<F]O="D["B`@("`@("`@("`@("1R;V]T(#T@87)R87E?
M<&]P*"1P87)T<RD["B`@("`@("`@?0H@("`@("`@("1R;V]T(#T@*'-T<FEN
M9RDD<F]O=#L*"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!D871A=')E95]I
M9"P@9&%T871R965?<&%R96YT<R<@+@H@("`@("`@("`@("`G($923TT@)R`N
M("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@)R!72$52
M12!D871A=')E95]N86UE(#T@/R!!3D0@9W)O=7!?=6ED(#T@/R<@+@H@("`@
M("`@("`@("`G($]21$52($)9(&1A=&%T<F5E7VED)SL*("`@("`@("`D=F%L
M=65S(#T@87)R87DH)')O;W0L"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=G<F]U<"==*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.E]B=6EL9%!A<F5N
M=$ED<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*("`@("`@("`D<F]O="`]("1T:&ES+3Y?9&(M/F=E=$%S
M<V]C*"1Q=65R>2P@9F%L<V4L("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A
M*"1R;V]T+"`G4$5!4E]%<G)O<B<I('Q\("%C;W5N="@D<F]O="DI('L*("`@
M("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)'=H97)E
M(#T@)R<["B`@("`@("`@)&9I<G-T7W1I;64@/2!T<G5E.PH@("`@("`@(&9O
M<F5A8V@@*"1R;V]T(&%S("1O8FIE8W1?:60@/3X@)&]B:F5C=%]P87)E;G1S
M*2!["B`@("`@("`@("`@("1P<W1R:6YG(#T@)&]B:F5C=%]P87)E;G1S("X@
M)SHG("X@)&]B:F5C=%]I9"`N("<E)SL*("`@("`@("`@("`@)'!Q=65R>2`]
M("<G.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1O8FIE8W1?<&%R96YT<RDI
M('L*("`@("`@("`@("`@("`@("1I9',@/2!S=6)S='(H)&]B:F5C=%]P87)E
M;G1S+"`Q*3L*("`@("`@("`@("`@("`@("1P<75E<GD@/2`G($]2("<@+B`D
M:F]I;E]N86UE("X@)V1A=&%T<F5E7VED($E.("@G("X@<W1R7W)E<&QA8V4H
M)SHG+"`G+"`G+"`D:61S*2`N("<I)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H)&QO8614<F5E*2!["B`@("`@("`@("`@("`@("`D<'%U97)Y
M("X]("<@3U(@)R`N("1J;VEN7VYA;64@+B`G9&%T871R965?<&%R96YT<R`]
M("<@+B`D=&AI<RT^7V1B+3YQ=6]T92AS=6)S='(H)'!S=')I;F<L(#`L("TR
M*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@A)&9I<G-T7W1I
M;64I('L*("`@("`@("`@("`@("`@("1W:&5R92`N/2`G($]2("<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'=H97)E("X]('-P<FEN=&8H)&IO:6Y?
M;F%M92`N("=D871A=')E95]P87)E;G1S($Q)2T4@)7,@3U(@)R`N("1J;VEN
M7VYA;64@+B`G9&%T871R965?:60@/2`E<R5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'!S=')I;F<I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;V)J96-T7VED+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<'%U97)Y*3L*"B`@("`@("`@
M("`@("1F:7)S=%]T:6UE(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'=H97)E.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A9',@82!S
M970@;V8@;V)J96-T<R!I9&5N=&EF:65D(&)Y('1H96ER('5N:7%U92!)1',L
M(&%N9"!T:&5I<@H@("`@("H@<&%R96YT<RP@:6YT;R!T:&4@)%]D871A(&%R
M<F%Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D8VED<R`@5&AE('5N:7%U92!)1"!O9B!T:&4@
M;V)J96-T('1O(&QO860L(&]R(&%N(&%R<F%Y(&]F"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@(&]B:F5C="!I9',N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?;&]A9$)Y260H)&-I9',I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@86X@87)R87DN
M("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8VED<RDI('L*("`@("`@("`@
M("`@)&-I9',@/2!A<G)A>2@H:6YT*21C:61S*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!A<G)A>5]W86QK*"1C:61S+"`G:6YT=F%L)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!"86EL(&]U="!N;W<@:68@=&AE<F4G<R!N
M;W1H:6YG('1O(&QO860N("HO"B`@("`@("`@:68@*"%C;W5N="@D8VED<RDI
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("`O*B!$;VXG="!L;V%D(&%N>2!T:&%T(&%R92!A;')E861Y(&QO861E9"X@
M06QS;RP@;6%K92!S=7)E('1H870*("`@("`@("`@*B!E=F5R>71H:6YG(&EN
M('1H92`D:61S(&%R<F%Y('1H870@=V4@87)E(&)U:6QD:6YG(&ES(&%N(&EN
M=&5G97(N("HO"B`@("`@("`@)&ED<R`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)&-I9',@87,@)&-I9"D@>PH@("`@("`@("`@("`O*B!$;R!.3U0@
M=7-E($1A=&%4<F5E.CIE>&ES=',H*2!H97)E.R!T:&%T('=O=6QD(&-A=7-E
M(&%N"B`@("`@("`@("`@("`J(&EN9FEN:71E(&QO;W`N("HO"B`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]D871A6R1C:61=*2D@>PH@("`@("`@
M("`@("`@("`@)&ED<UM=(#T@*&EN="DD8VED.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!T:&5R92!A<F4@;F]N92!L969T('1O
M(&QO860L(')E='5R;BX@*B\*("`@("`@("!I9B`H(6-O=6YT*"1I9',I*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M)&EN(#T@87)R87E?<V5A<F-H*$1!5$%44D5%7U)/3U0L("1I9',I(#T]/2!F
M86QS92`_('-P<FEN=&8H)V1A=&%T<F5E7VED($E.("@E<RD@04Y$("<L(&EM
M<&QO9&4H)RP@)RP@)&ED<RDI(#H@)R<["B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G4T5,14-4(&1A=&%T<F5E7VED+"!D871A=')E95]P87)E;G1S($92
M3TT@)7,G("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@5TA%4D4@)7-G
M<F]U<%]U:60@/2`E<R<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@)R!/
M4D1%4B!"62!D871A=')E95]I9"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1I;BP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&(M/G%U;W1E*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==*2D["B`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ
M.E]L;V%D0GE)9"@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D<&%R96YT<R`]("1T:&ES+3Y?
M9&(M/F=E=$%S<V]C*"1Q=65R>2D["B`@("`@("`@:68@*&ES7V$H)'!A<F5N
M=',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1P87)E
M;G1S.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)'!A<F5N=',I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!F
M;W5N9"XB*2P@;G5L;"P@;G5L;"P@;G5L;"P@)T1A=&%4<F5E(&ED<R`G("X@
M:6UP;&]D92@G+"`G+"`D:61S*2`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@
M('T*"B`@("`@("`@)&ED<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H
M)'!A<F5N=',@87,@)&-I9"`]/B`D<&%R96YT*2!["B`@("`@("`@("`@("1I
M9'-;*&EN="DD8VED72`]("AI;G0I)&-I9#L*"B`@("`@("`@("`@("1P:61S
M(#T@97AP;&]D92@G.B<L('-U8G-T<B@D<&%R96YT+"`Q*2D["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1P:61S(&%S("1P:60I('L*("`@("`@("`@("`@("`@
M("1P:60@/2`H:6YT*21P:60["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?9&%T85LD<&ED72DI('L*("`@("`@("`@("`@("`@("`@("`D
M:61S6R1P:61=(#T@)'!I9#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@)&ED<R!I<R!E;7!T>2P@
M=V4@:&%V92!N;W1H:6YG('1O(&QO860N("HO"B`@("`@("`@:68@*"%C;W5N
M="@D:61S*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M"@H@("`@("`@("1Q=65R>2`]("=314Q%0U0@9&%T871R965?:60L(&1A=&%T
M<F5E7VYA;64L(&1A=&%T<F5E7W!A<F5N=',L(&1A=&%T<F5E7V]R9&5R)R`N
M"B`@("`@("`@("`@("`@("`@)R!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I
M9"!)3B`H/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D:61S*2`M(#$I
M("X@)RDG("X*("`@("`@("`@("`@("`@("`G($%.1"!G<F]U<%]U:60@/2`_
M($]21$52($)9(&1A=&%T<F5E7VED)SL*("`@("`@("`D=F%L=65S(#T@87)R
M87E?;65R9V4H)&ED<RP@87)R87DH)'1H:7,M/E]P87)A;7-;)V=R;W5P)UTI
M*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$
M871A5')E95]S<6PZ.E]L;V%D0GE)9"@I.B`G("X@)'%U97)Y+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D9&%T82`]
M("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL("1V86QU97,I.PH@("`@("`@
M(&EF("AI<U]A*"1D871A+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D9&%T83L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^<V5T*"1D871A+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!T<F5E('-O<G1E9"!B>2!T
M:&4@<W!E8VEF:65D(&%T=')I8G5T92!N86UE(&%N9"]O<B!K97DN"B`@("`@
M*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)')O;W0@("`@("`@("!7:&EC:"!P;W)T:6]N(&]F('1H92!T
M<F5E('1O('-O<G0N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1&5F875L=',@=&\@86QL(&]F(&ET+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&QO8614<F5E("`@(%-O<G0@=&AE('1R964@<W1A<G1I;F<@870@)')O
M;W0L(&]R(&IU<W0@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5Q=65S=&5D(&QE=F5L(&%N9"!D:7)E8W0@<&%R96YT<S\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$969A=6QT<R!T;R!S
M:6YG;&4@;&5V96PN"B`@("`@*B!`<&%R86T@<W1R:6YG("1S;W)T8GE?;F%M
M92`@071T<FEB=71E(&YA;64@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<V]R=&)Y7VME>2`@($%T=')I8G5T92!K97D@=&\@
M=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C
M=&EO;B`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G9713;W)T9614<F5E*"1R;V]T+"`D;&]A9%1R964@/2!F86QS
M92P@)'-O<G1B>5]N86UE(#T@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@
M('L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^7V)U:6QD3&]A9%%U97)Y*"1R
M;V]T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QO8614<F5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1$%40512145?0E5)3$1?4T5,14-4+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O<G1B>5]K97DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER
M96-T:6]N*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/F=E=$%L;"@D
M<75E<GDI.PH@("`@?0H*("`@("\J*@H@("`@("H@061D<R!A;B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1O8FIE8W0@("`@("`@(%1H
M92!O8FIE8W0@=&\@861D("AS=')I;F<@;W(*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$871A5')E94]B:F5C="DN"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D:61?87-?;F%M92`@5VAE=&AE<B!T:&4@;V)J96-T($E$
M(&ES('1O(&)E('5S960@87,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O8FIE8W0@;F%M92X@(%5S960@:6X@<VET=6%T:6]N<R!W:&5R
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H97)E(&ES
M(&YO(&%V86EL86)L92!U;FEQ=64@:6YP=70@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;V)J96-T(&YA;64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9"@D;V)J96-T+"`D:61?87-?;F%M92`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1A='1R:6)U=&5S(#T@9F%L<V4["B`@("`@("`@:68@
M*&ES7V$H)&]B:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@
M("`@)&9U;&QN86UE(#T@)&]B:F5C="T^9V5T3F%M92@I.PH@("`@("`@("`@
M("`D;W)D97(@/2`D;V)J96-T+3YO<F1E<CL*"B`@("`@("`@("`@("\J(%=E
M(&AA;F1L92!D871A(&1I9F9E<F5N=&QY(&EF('=E(&-A;B!M87`@:70@=&\@
M=&AE"B`@("`@("`@("`@("`J(&AO<F1E7V1A=&%T<F5E7V%T=')I8G5T97,@
M=&%B;&4N("HO"B`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1O8FIE
M8W0L("=?=&]!='1R:6)U=&5S)RDI('L*("`@("`@("`@("`@("`@("1D871A
M(#T@)R<["B`@("`@("`@("`@("`@("`D<V5R(#T@;G5L;#L*"B`@("`@("`@
M("`@("`@("`O*B!3970@82!F;&%G(&9O<B!L871E<B!S;R!T:&%T('=E(&MN
M;W<@=&\@:6YS97)T('1H90H@("`@("`@("`@("`@("`@("H@871T<FEB=71E
M(')O=W,N("HO"B`@("`@("`@("`@("`@("`D871T<FEB=71E<R`]('1R=64[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)TAO<F1E+U-E<FEA;&EZ92YP:'`G.PH@("`@("`@("`@("`@("`@
M)'-E<B`](%-%4DE!3$E:15]55$8W7T)!4TE#.PH@("`@("`@("`@("`@("`@
M)&1A=&$@/2!(;W)D95]397)I86QI>F4Z.G-E<FEA;&EZ92@D;V)J96-T+3YG
M971$871A*"DL("1S97(L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F=6QL;F%M92`]
M("1O8FIE8W0["B`@("`@("`@("`@("1O<F1E<B`](&YU;&P["B`@("`@("`@
M("`@("1D871A(#T@)R<["B`@("`@("`@("`@("1S97(@/2!N=6QL.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1V5T('1H92!N97AT('5N:7%U92!)1"X@*B\*
M("`@("`@("`D:60@/2`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTI.PH@("`@("`@(&EF("AI<U]A*"1I9"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D:60L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N("1I9#L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')P;W,H)&9U
M;&QN86UE+"`G.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R=',@
M/2!E>'!L;V1E*"<Z)RP@)&9U;&QN86UE*3L*("`@("`@("`@("`@)'!A<F5N
M=',@/2`G)SL*("`@("`@("`@("`@)'!S=')I;F<@/2`G)SL*("`@("`@("`@
M("`@:68@*"1I9%]A<U]N86UE*2!["B`@("`@("`@("`@("`@("`O*B!297%U
M97-T960@=7-E(&]F($E$(&%S(&YA;64L('-O(&1I<V-A<F0@8W5R<F5N="!N
M86UE+B`J+PH@("`@("`@("`@("`@("`@87)R87E?<&]P*"1P87)T<RD["B`@
M("`@("`@("`@("`@("`O*B!3970@;F%M92!T;R!)1"X@*B\*("`@("`@("`@
M("`@("`@("1N86UE(#T@)&ED.PH@("`@("`@("`@("`@("`@+RH@36]D:69Y
M(&9U;&QN86UE('1O(')E9FQE8W0@;F5W(&YA;64N("HO"B`@("`@("`@("`@
M("`@("`D9G5L;&YA;64@/2!I;7!L;V1E*"<Z)RP@)'!A<G1S*2`N("<Z)R`N
M("1I9#L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1O8FIE8W0L("=$871A
M5')E94]B:F5C="<I*2!["B`@("`@("`@("`@("`@("`@("`@)&]B:F5C="T^
M<V5T3F%M92@D9G5L;&YA;64I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`D;V)J96-T(#T@)&9U;&QN86UE.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&YA;64@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!F;W)E86-H("@D<&%R=',@87,@)'!A<BD@>PH@("`@
M("`@("`@("`@("`@)'!S=')I;F<@+CT@*&5M<'1Y*"1P<W1R:6YG*2`_("<G
M(#H@)SHG*2`N("1P87(["B`@("`@("`@("`@("`@("`D<&ED(#T@)'1H:7,M
M/F=E=$ED*"1P<W1R:6YG*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`O*B!!
M=71O+6-R96%T92!P87)E;G1S+B`J+PH@("`@("`@("`@("`@("`@("`@("1P
M:60@/2`D=&AI<RT^861D*"1P<W1R:6YG*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<&ED.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P87)E;G1S
M("X]("<Z)R`N("1P:60["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!I9B`H)&ED7V%S7VYA;64I('L*("`@("`@("`@("`@
M("`@("\J(%)E<75E<W1E9"!U<V4@;V8@240@87,@;F%M92P@<V5T(&9U;&QN
M86UE(&%N9"!N86UE('1O($E$+B`J+PH@("`@("`@("`@("`@("`@)&9U;&QN
M86UE(#T@)&ED.PH@("`@("`@("`@("`@("`@)&YA;64@/2`D:60["B`@("`@
M("`@("`@("`@("!I9B`H:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1O8FIE8W0M/G-E=$YA;64H)&9U
M;&QN86UE*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&]B:F5C="`]("1F=6QL;F%M93L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N86UE
M(#T@)&9U;&QN86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P87)E
M;G1S(#T@)R<["B`@("`@("`@("`@("1P:60@/2!$051!5%)%15]23T]4.PH@
M("`@("`@('T*"B`@("`@("`@:68@*'!A<F5N=#HZ97AI<W1S*"1F=6QL;F%M
M92DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M06QR96%D>2!E>&ES=',B*2D["B`@("`@("`@?0H*("`@("`@("`D<75E<GD@
M/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*
M("`@("`@("`@("`@("`@("`G("AD871A=')E95]I9"P@9W)O=7!?=6ED+"!D
M871A=')E95]N86UE+"!D871A=')E95]O<F1E<BPG("X*("`@("`@("`@("`@
M("`@("`G(&1A=&%T<F5E7V1A=&$L('5S97)?=6ED+"!D871A=')E95]S97)I
M86QI>F5D+"<@+@H@("`@("`@("`@("`@("`@("<@9&%T871R965?<&%R96YT
M<RDG("X*("`@("`@("`@("`@("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@/RP@
M/RP@/RP@/RP@/RDG.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I
M9"P*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V=R
M;W5P)UTL"B`@("`@("`@("`@("`@("`@("`@("`@(%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)&YA;64L($Y,4SHZ9V5T0VAA<G-E="@I+"`D=&AI<RT^7W!A
M<F%M<ULG8VAA<G-E="==*2P*("`@("`@("`@("`@("`@("`@("`@("`@:7-?
M;G5L;"@D;W)D97(I(#\@3E5,3"`Z("AI;G0I)&]R9&5R+`H@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@
M*'-T<FEN9RE!=71H.CIG971!=71H*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("AI;G0I)'-E<BP*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N
M=',I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($1A=&%4<F5E7W-Q;#HZ861D*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"@H@("`@("`@("1R96]R9&5R(#T@)'1H:7,M/G)E;W)D97(H
M)'!A<F5N=',L("1O<F1E<BP@)&ED*3L*("`@("`@("!I9B`H:7-?82@D<F5O
M<F1E<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@D<F5O<F1E<BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)')E;W)D97(["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@<&%R96YT.CI?861D*"1F=6QL;F%M92P@
M)&ED+"`D<&ED+"`D;W)D97(I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!S=6-C97-F=6QL>2!I;G-E
M<G1E9"!T:&4@;V)J96-T(&%N9"!I="!S=7!P;W)T<PH@("`@("`@("`J(&)E
M:6YG(&UA<'!E9"!T;R!T:&4@871T<FEB=71E<R!T86)L92P@9&\@=&AA="!N
M;W<Z("HO"B`@("`@("`@:68@*"%E;7!T>2@D871T<FEB=71E<RDI('L*("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3YU<&1A=&5$871A*"1O8FIE8W0I
M.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I9#L*("`@('T*"B`@
M("`O*BH*("`@("`J($-H86YG97,@=&AE(&]R9&5R(&]F('1H92!C:&EL9')E
M;B!O9B!A;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%R96YT("!4:&4@9G5L;"!I9"!P871H(&]F('1H92!P87)E;G0@;V)J96-T
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1O<F1E<B`@("!)9B!A;B!A<G)A>2!I
M="!S<&5C:69I97,@=&AE(&YE=R!P;W-I=&EO;G,@9F]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&%L;"!C:&EL9"!O8FIE8W1S+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!)9B!A;B!I;G1E9V5R(&%N9"`D8VED
M(&ES('-P96-I9FEE9"P@=&AE('!O<VET:6]N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@('=H97)E('1H92!C:&EL9"!S<&5C:69I960@8GD@)&-I
M9"!I<R!I;G-E<G1E9"X@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@)&-I9"!I<R!N;W0@<W!E8VEF:65D+"!T:&4@<&]S:71I;VX@9V5T<R!D
M96QE=&5D+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C875S:6YG
M('1H92!F;VQL;W=I;F<@<&]S:71I;VYS('1O('-H:69T('5P+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&-I9"`@("!3964@)&]R9&5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96]R9&5R*"1P87)E;G0L("1O<F1E<B`](&YU;&PL("1C
M:60@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A)'!A<F5N="!\?"!I<U]A
M*"1P87)E;G0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@+R\@06)O
M<G0@:6UM961I871E;'D@:68@=&AE('!A<F5N="!S=')I;F<@:7,@96UP='D[
M('=E"B`@("`@("`@("`@("\O(&-A;FYO="!S869E;'D@<F5O<F1E<B!A;&P@
M=&]P+6QE=F5L(&5L96UE;G1S+@H@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("`D<'%U97)Y(#T@)R<["B`@("`@("`@:68@*"%I<U]A
M<G)A>2@D;W)D97(I("8F("%I<U]N=6QL*"1O<F1E<BDI('L*("`@("`@("`@
M("`@+RH@4VEN9VQE('5P9&%T92`H861D+V1E;"DN("HO"B`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1C:60I*2!["B`@("`@("`@("`@("`@("`O*B!.;R!O
M8FIE8W0@:60@9VEV96X@<V\@<VAU9F9L92!D;W=N+B`J+PH@("`@("`@("`@
M("`@("`@)&1I<F5C=&EO;B`]("<M)SL*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("\J(%=E(&AA=F4@86X@;V)J96-T(&ED('-O('-H
M=69F;&4@=7`N("HO"B`@("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@)RLG
M.PH*("`@("`@("`@("`@("`@("\J($QE879I;F<@=&AE(&YE=VQY(&EN<V5R
M=&5D(&]B:F5C="!A;&]N92X@*B\*("`@("`@("`@("`@("`@("1P<75E<GD@
M/2!S<')I;G1F*"<@04Y$(&1A=&%T<F5E7VED("$]("5S)RP@*&EN="DD8VED
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*"=54$1!5$4@)7,@4T54(&1A=&%T<F5E7V]R9&5R(#T@9&%T871R965?;W)D
M97(@)7,@,2!72$5212!G<F]U<%]U:60@/2`E<R!!3D0@9&%T871R965?<&%R
M96YT<R`]("5S($%.1"!D871A=')E95]O<F1E<B`^/2`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO;BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D
M=&AI<RT^7W!A<F%M<ULG9W)O=7`G72DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'!A<F5N="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:7-?;G5L;"@D;W)D97(I(#\@)TY53$PG
M(#H@*&EN="DD;W)D97(I("X@)'!Q=65R>3L*"B`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L.CIR96]R
M9&5R*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M<75E<GDH)'%U97)Y*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&]R
M9&5R*2D@>PH@("`@("`@("`@("`O*B!-=6QT:2!U<&1A=&4N("HO"B`@("`@
M("`@("`@("1Q=65R>2`]("=314Q%0U0@0T]53E0H9&%T871R965?:60I)R`N
M"B`@("`@("`@("`@("`@("`@("`@("<@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G(%=(15)%(&=R
M;W5P7W5I9"`](#\@04Y$(&1A=&%T<F5E7W!A<F5N=',@/2`_)R`N"B`@("`@
M("`@("`@("`@("`@("`@("<@1U)/55`@0ED@9&%T871R965?<&%R96YT<R<[
M"B`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG
M9W)O=7`G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)E;G0I
M.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B
M>2!$871A5')E95]S<6PZ.G)E;W)D97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD[
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!](&5L<V5I9B`H8V]U;G0H)&]R9&5R*2`A/2`D<F5S=6QT*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#86YN;W0@
M<F5O<F1E<BP@;G5M8F5R(&]F(&5N=')I97,@<W5P<&QI960@9F]R(')E;W)D
M97(@9&]E<R!N;W0@;6%T8V@@;G5M8F5R('-T;W)E9"XB*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1O7VME>2`](#`["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1O<F1E<B!A<R`D;U]C:60I('L*("`@("`@("`@("`@("`@("1Q
M=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("<@4T54(&1A=&%T<F5E7V]R9&5R
M(#T@/R!72$5212!D871A=')E95]I9"`](#\G.PH@("`@("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*"1O7VME>2P@:7-?;G5L;"@D;U]C:60I(#\@3E5,
M3"`Z("AI;G0I)&]?8VED*3L*"B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5O<F1E<B@I
M.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%
M0E5'*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1O7VME>2LK.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1P87)E;G0I.PH*("`@("`@("`@("`@
M+RH@4F4M;W)D97(@;W5R(&-A8VAE+B`J+PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R96]R9&5R*"1P:60L("1O<F1E<BD["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@17AP;&EC:71L>2!S970@=&AE(&]R9&5R(&9O
M<B!A(&1A=&%T<F5E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:60@("`@(%1H92!D871A=')E92!O8FIE8W0@:60@=&\@8VAA;F=E
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]R9&5R("!4:&4@;F5W(&]R9&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971/<F1E<B@D:60L("1O<F1E<BD*
M("`@('L*("`@("`@("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@)R!3150@9&%T871R
M965?;W)D97(@/2`_(%=(15)%(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*&ES7VYU;&PH)&]R9&5R*2`_($Y53$P@.B`H:6YT
M*21O<F1E<BP*("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD:60I.PH*
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4
M<F5E7W-Q;#HZ<V5T3W)D97(H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F5S(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@("`D;V)J96-T("!4:&4@;V)J96-T('1O(')E;6]V92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1F;W)C92`@($9O<F-E(')E;6]V86P@;V8@
M979E<GD@8VAI;&0@;V)J96-T/PH@("`@("HO"B`@("!F=6YC=&EO;B!R96UO
M=F4H)&]B:F5C="P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&ED
M(#T@)'1H:7,M/F=E=$ED*"1O8FIE8W0I.PH@("`@("`@("1O<F1E<B`]("1T
M:&ES+3YG971/<F1E<B@D;V)J96-T*3L*"B`@("`@("`@)'%U97)Y(#T@)U-%
M3$5#5"!D871A=')E95]I9"!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!G<F]U<%]U:60@/2`_
M($%.1"!D871A=')E95]P87)E;G1S($Q)2T4@/R<@+@H@("`@("`@("`@("`@
M("`@("<@3U)$15(@0ED@9&%T871R965?:60G.PH@("`@("`@("1V86QU97,@
M/2!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG9W)O=7`G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@)R4Z)R`N("AI;G0I)&ED("X@)R<I.PH*("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ
M<F5M;W9E*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH@("`@("`@("1C:&EL9')E;B`]("1T:&ES+3Y?9&(M
M/F=E=$%L;"@D<75E<GDL("1V86QU97,L($1"7T9%5$-(34]$15]!4U-/0RD[
M"@H@("`@("`@(&EF("AC;W5N="@D8VAI;&1R96XI*2!["B`@("`@("`@("`@
M(&EF("@D9F]R8V4I('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&EL
M9')E;B!A<R`D8VAI;&0I('L*("`@("`@("`@("`@("`@("`@("`D8V%T(#T@
M)'1H:7,M/F=E=$YA;64H)&-H:6QD6R=D871A=')E95]I9"==*3L*("`@("`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G)E;6]V92@D8V%T+"!T
M<G5E*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B0V%N;F]T(')E;6]V
M92P@)60@8VAI;&1R96X@97AI<W0N(BDL(&-O=6YT*"1C:&EL9')E;BDI*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4F5M;W9E(&%T
M=')I8G5T97,@9F]R('1H:7,@;V)J96-T+B`J+PH@("`@("`@("1Q=65R>2`]
M("=$14Q%5$4@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I
M8G5T97,G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I
M9"`](#\G.PH@("`@("`@("1V86QU97,@/2!A<G)A>2@H:6YT*21I9"D["@H@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R
M965?<W%L.CIR96UO=F4H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1Q=65R>2`]("=$14Q%
M5$4@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@
M("`@("`@("`@("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`D
M=F%L=65S(#T@87)R87DH*&EN="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E*"DZ
M("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"
M54<I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E
M<GDL("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H*("`@("`@("`D<&%R96YT<R`]("1T:&ES+3YG971087)E;G1)9%-T
M<FEN9R@D;V)J96-T*3L*("`@("`@("!I9B`H:7-?82@D<&%R96YT<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A<F5N=',["B`@
M("`@("`@?0H*("`@("`@("`D<F5O<F1E<B`]("1T:&ES+3YR96]R9&5R*"1P
M87)E;G1S+"`D;W)D97(I.PH@("`@("`@(&EF("AI<U]A*"1R96]R9&5R+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5O<F1E<CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!I<U]A*'!A<F5N=#HZ<F5M;W9E
M*"1O8FIE8W0I+"`G4$5!4E]%<G)O<B<I(#\@)&ED(#H@=')U93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V97,@;VYE(&]R(&UO<F4@;V)J96-T<R!B
M>2!I9"X*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T:6]N(&1O97,@*FYO="H@
M9&\@=&AE('9A;&ED871I;VXL(')E;W)D97)I;F<L(&5T8RX@=&AA=`H@("`@
M("H@<F5M;W9E*"D@9&]E<RX@268@>6]U(&YE960@=&\@8VAE8VL@9F]R(&-H
M:6QD<F5N+"!R92UD;R!O<F1E<FEN9RP@971C+BP*("`@("`J('1H96X@>6]U
M(&UU<W0@<F5M;W9E*"D@;V)J96-T<R!O;F4M8GDM;VYE+B!4:&ES(&ES(&9O
M<B!C;V1E('1H870@:VYO=W,*("`@("`J(&ET)W,@9&5A;&EN9R!W:71H('-I
M;F=L92`H;F]N+7!A<F5N=&5D*2!O8FIE8W1S(&%N9"!N965D<R!T;R!D96QE
M=&4@80H@("`@("H@8F%T8V@@;V8@=&AE;2!Q=6EC:VQY+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D:61S("!4:&4@;V)J96-T<R!T;R!R96UO=F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94)Y261S*"1I9',I"B`@("![
M"B`@("`@("`@+RH@4V%N:71I>F4@:6YP=70N("HO"B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D:61S*2D@>PH@("`@("`@("`@("`D:61S(#T@87)R87DH*&EN
M="DD:61S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!A<G)A>5]W
M86QK*"1I9',L("=I;G1V86PG*3L*("`@("`@("!]"@H@("`@("`@("\J(%)E
M;6]V:6YG('IE<F\@;V)J96-T<R!A;'=A>7,@<W5C8V5E9',N("HO"B`@("`@
M("`@:68@*"$D:61S*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@+RH@4F5M;W9E(&%T=')I8G5T97,@9F]R("1I9',N
M("HO"B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==("X*("`@("`@("`@("`@("`@
M("`G(%=(15)%(&1A=&%T<F5E7VED($E.("@_)R`N('-T<E]R97!E870H)RP@
M/R<L(&-O=6YT*"1I9',I("T@,2D@+B`G*2<["B`@("`@("`@)'9A;'5E<R`]
M("1I9',["@H@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@
M8GD@1&%T851R965?<W%L.CIR96UO=F5">4ED<R@I.B`G("X@)'%U97)Y+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@
M)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]I9"!)
M3B`H/R<@+B!S=')?<F5P96%T*"<L(#\G+"!C;W5N="@D:61S*2`M(#$I("X@
M)RDG.PH@("`@("`@("1V86QU97,@/2`D:61S.PH*("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E
M0GE)9',H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y
M*"1Q=65R>2P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO
M=F5S(&]N92!O<B!M;W)E(&]B:F5C=',@8GD@;F%M92X*("`@("`J"B`@("`@
M*B!4:&ES(&9U;F-T:6]N(&1O97,@*FYO="H@9&\@=&AE('9A;&ED871I;VXL
M(')E;W)D97)I;F<L(&5T8RX@=&AA=`H@("`@("H@<F5M;W9E*"D@9&]E<RX@
M268@>6]U(&YE960@=&\@8VAE8VL@9F]R(&-H:6QD<F5N+"!R92UD;R!O<F1E
M<FEN9RP@971C+BP*("`@("`J('1H96X@>6]U(&UU<W0@<F5M;W9E*"D@;V)J
M96-T<R!O;F4M8GDM;VYE+B!4:&ES(&ES(&9O<B!C;V1E('1H870@:VYO=W,*
M("`@("`J(&ET)W,@9&5A;&EN9R!W:71H('-I;F=L92`H;F]N+7!A<F5N=&5D
M*2!O8FIE8W1S(&%N9"!N965D<R!T;R!D96QE=&4@80H@("`@("H@8F%T8V@@
M;V8@=&AE;2!Q=6EC:VQY+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M;F%M97,@(%1H92!O8FIE8W1S('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5M;W9E0GE.86UE<R@D;F%M97,I"B`@("!["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D;F%M97,I*2!["B`@("`@("`@("`@("1N86UE<R`](&%R
M<F%Y*"1N86UE<RD["B`@("`@("`@?0H*("`@("`@("`O*B!296UO=FEN9R!Z
M97)O(&]B:F5C=',@86QW87ES('-U8V-E961S+B`J+PH@("`@("`@(&EF("@A
M)&YA;65S*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*
M"B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!D871A=')E95]I9"!&4D]-("<@
M+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@
M)R!72$5212!D871A=')E95]N86UE($E.("@_)R`N('-T<E]R97!E870H)RP@
M/R<L(&-O=6YT*"1N86UE<RD@+2`Q*2`N("<I)SL*("`@("`@("`D=F%L=65S
M(#T@)&YA;65S.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U
M97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ<F5M;W9E0GE.86UE<R@I.B`G("X@)'%U
M97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@
M("`@("`D:61S(#T@)'1H:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2P@,"P@)'9A
M;'5E<RD["B`@("`@("`@:68@*&ES7V$H)&ED<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&ED<SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F5M;W9E0GE)9',H)&ED<RD["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!-;W9E(&%N(&]B:F5C="!T;R!A(&YE=R!P87)E;G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;V)J96-T("`@("!4:&4@;V)J
M96-T('1O(&UO=F4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=P87)E;G0@
M(%1H92!N97<@<&%R96YT(&]B:F5C="X@1&5F875L=',@=&\@=&AE(')O;W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)&]B:F5C="P@)&YE=W!A<F5N
M="`](&YU;&PI"B`@("!["B`@("`@("`@)&]L9%]P87)E;G1?<&%T:"`]("1T
M:&ES+3YG971087)E;G1)9%-T<FEN9R@D;V)J96-T*3L*("`@("`@("`D<F5S
M=6QT(#T@<&%R96YT.CIM;W9E*"1O8FIE8W0L("1N97=P87)E;G0I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@("1I9"`]
M("1T:&ES+3YG971)9"@D;V)J96-T*3L*("`@("`@("`D;F5W7W!A<F5N=%]P
M871H(#T@)'1H:7,M/F=E=%!A<F5N=$ED4W1R:6YG*"1O8FIE8W0I.PH*("`@
M("`@("`O*B!&971C:"!T:&4@;V)J96-T(&)E:6YG(&UO=F5D(&%N9"!A;&P@
M;V8@:71S(&-H:6QD<F5N+"!S:6YC90H@("`@("`@("`J('=E(&%L<V\@;F5E
M9"!T;R!U<&1A=&4@=&AE:7(@<&%R96YT('!A=&AS('1O(&%V;VED(&-R96%T
M:6YG"B`@("`@("`@("H@;W)P:&%N<RX@*B\*("`@("`@("`D<75E<GD@/2`G
M4T5,14-4(&1A=&%T<F5E7VED+"!D871A=')E95]P87)E;G1S)R`N"B`@("`@
M("`@("`@("`@("`@)R!&4D]-("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G
M72`N"B`@("`@("`@("`@("`@("`@)R!72$5212!D871A=')E95]P87)E;G1S
M(#T@/R!/4B!D871A=')E95]P87)E;G1S($Q)2T4@/R<@+@H@("`@("`@("`@
M("`@("`@("<@3U(@9&%T871R965?:60@/2`_)SL*("`@("`@("`D=F%L=65S
M(#T@87)R87DH)&]L9%]P87)E;G1?<&%T:"`N("<Z)R`N("1I9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@)&]L9%]P87)E;G1?<&%T:"`N("<Z)R`N("1I
M9"`N("<Z)2<L"B`@("`@("`@("`@("`@("`@("`@("`@("AI;G0I)&ED*3L*
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A
M5')E95]S<6PZ.FUO=F4H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)')O=W-E="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@*&ES
M7V$H)')O=W-E="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')O=W-E=#L*("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T92!E86-H
M(&]B:F5C="P@<F5P;&%C:6YG('1H92!O;&0@<&%R96YT('!A=&@@=VET:"!T
M:&4*("`@("`@("`@*B!N97<@;VYE+B`J+PH@("`@("`@('=H:6QE("@D<F]W
M(#T@)')O=W-E="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@>PH@
M("`@("`@("`@("!I9B`H:7-?82@D<F]W+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')O=SL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&]Q=65R>2`]("<G.PH@("`@("`@("`@("!I9B`H)')O=ULG
M9&%T871R965?:60G72`]/2`D:60I('L*("`@("`@("`@("`@("`@("1O<75E
M<GD@/2`G+"!D871A=')E95]O<F1E<B`](#`@)SL*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@1&\@<W1R7W)E<&QA8V4H*2!O;FQY(&EF('1H:7,@
M:7,@;F]T(&$@9FER<W0@;&5V96P*("`@("`@("`@("`@("H@;V)J96-T+B`J
M+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1R;W=;)V1A=&%T<F5E7W!A<F5N
M=',G72DI('L*("`@("`@("`@("`@("`@("1P<&%T:"`]('-T<E]R97!L86-E
M*"1O;&1?<&%R96YT7W!A=&@L("1N97=?<&%R96YT7W!A=&@L("1R;W=;)V1A
M=&%T<F5E7W!A<F5N=',G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<'!A=&@@/2`D;F5W7W!A<F5N=%]P871H.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E
M<R!3150@9&%T871R965?<&%R96YT<R`]("5S)R`N("1O<75E<GD@+B`G(%=(
M15)%(&1A=&%T<F5E7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1P<&%T:"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*&EN="DD<F]W6R=D871A=')E
M95]I9"==*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@
M475E<GD@8GD@1&%T851R965?<W%L.CIM;W9E*"DZ("<@+B`D<75E<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1O<F1E<B`]("1T:&ES+3YG971/<F1E<B@D;V)J
M96-T*3L*"B`@("`@("`@+RH@4VAU9F9L92!D;W=N('1H92!O;&0@;W)D97(@
M<&]S:71I;VYS+B`J+PH@("`@("`@("1R96]R9&5R(#T@)'1H:7,M/G)E;W)D
M97(H)&]L9%]P87)E;G1?<&%T:"P@)&]R9&5R*3L*"B`@("`@("`@+RH@4VAU
M9F9L92!U<"!T:&4@;F5W(&]R9&5R('!O<VET:6]N<RX@*B\*("`@("`@("`D
M<F5O<F1E<B`]("1T:&ES+3YR96]R9&5R*"1N97=?<&%R96YT7W!A=&@L(#`L
M("1I9"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0VAA;F=E(&%N(&]B:F5C="=S(&YA;64N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("`D;VQD7V]B:F5C="`@("`@("!4:&4@;VQD(&]B:F5C
M="X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=U]O8FIE8W1?;F%M92`@5&AE
M(&YE=R!O8FIE8W0@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE
M*"1O;&1?;V)J96-T+"`D;F5W7V]B:F5C=%]N86UE*0H@("`@>PH@("`@("`@
M("\J($1O('1H92!C86-H92!R96YA;6EN9R!F:7)S="`J+PH@("`@("`@("1R
M97-U;'0@/2!P87)E;G0Z.G)E;F%M92@D;VQD7V]B:F5C="P@)&YE=U]O8FIE
M8W1?;F%M92D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@("\J($=E="!T:&4@;V)J96-T(&ED(&%N9"!S970@=7`@=&AE
M('-Q;"!Q=65R>2X@*B\*("`@("`@("`D:60@/2`D=&AI<RT^9V5T260H)&]L
M9%]O8FIE8W0I.PH@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X*("`@("`@("`@("`@("`@("`G(%-%5"!D
M871A=')E95]N86UE(#T@/R!72$5212!D871A=')E95]I9"`](#\G.PH@("`@
M("`@("1V86QU97,@/2!A<G)A>2A3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1N
M97=?;V)J96-T7VYA;64L($Y,4SHZ9V5T0VAA<G-E="@I+"`D=&AI<RT^7W!A
M<F%M<ULG8VAA<G-E="==*2P*("`@("`@("`@("`@("`@("`@("`@("`@*&EN
M="DD:60I.PH*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y
M(&)Y($1A=&%4<F5E7W-Q;#HZ<F5N86UE*"DZ("<@+B`D<75E<GDL(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@
M("`@("!R971U<FX@:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I(#\@)')E
M<W5L="`Z('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@
M9&%T82!F;W(@86X@;V)J96-T(&9R;VT@=&AE(&1A=&%T<F5E7V1A=&$@9FEE
M;&0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@5&AE(&]B
M:F5C="!I9"!T;R!F971C:"P@;W(@86X@87)R87D@;V8@;V)J96-T(&ED<RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T82@D8VED*0H@("`@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5R:6%L:7IE+G!H<"<["@H@("`@
M("`@(&EF("AI<U]A<G)A>2@D8VED*2D@>PH@("`@("`@("`@("!I9B`H(6-O
M=6YT*"1C:60I*2!["B`@("`@("`@("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M4T5,14-4(&1A=&%T<F5E7VED+"!D871A=')E95]D871A+"!D871A=')E95]S
M97)I86QI>F5D($923TT@)7,@5TA%4D4@9&%T871R965?:60@24X@*"5S*2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D
M92@G+"`G+"`D8VED*2D["@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G4U%,(%%U97)Y(&)Y($1A=&%4<F5E7W-Q;#HZ9V5T1&%T82@I.B`G("X@
M)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F=E=$%S<V]C*"1Q
M=65R>2D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R
M97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1R97-U;'0@87,@)&ED(#T^("1R;W<I('L*("`@("`@("`@("`@("`@
M("1D871A6R1I9%T@/2!(;W)D95]397)I86QI>F4Z.G5N<V5R:6%L:7IE*"1R
M;W=;,%TL("1R;W=;,5TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H
M*2D["B`@("`@("`@("`@("`@("`O*B!#;VYV97)T(&]L9"!D871A('1O('1H
M92!N97<@9F]R;6%T+B`J+PH@("`@("`@("`@("`@("`@:68@*"1R;W=;,5T@
M/3T@4T5224%,25I%7T)!4TE#*2!["B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)&ED72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&1A=&%;)&ED72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!.3%,Z.F=E=$-H87)S970H=')U92DI.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1D871A6R1I9%T@/2`H:7-?;G5L
M;"@D9&%T85LD:61=*2!\?"`A:7-?87)R87DH)&1A=&%;)&ED72DI"B`@("`@
M("`@("`@("`@("`@("`@/R!A<G)A>2@I"B`@("`@("`@("`@("`@("`@("`@
M.B`D9&%T85LD:61=.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!R971U
M<FX@)&1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'%U97)Y
M(#T@)U-%3$5#5"!D871A=')E95]D871A+"!D871A=')E95]S97)I86QI>F5D
M)R`N"B`@("`@("`@("`@("`@("`@("`@("<@1E)/32`G("X@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G(%=(15)%
M(&1A=&%T<F5E7VED(#T@/R<["B`@("`@("`@("`@("1V86QU97,@/2!A<G)A
M>2@H:6YT*21C:60I.PH*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H
M)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$1A=&$H*3H@)R`N("1Q
M=65R>2P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@
M("`@("`@("`@("1R;W<@/2`D=&AI<RT^7V1B+3YG9712;W<H)'%U97)Y+"`D
M=F%L=65S+"!$0E]&151#2$U/1$5?05-33T,I.PH*("`@("`@("`@("`@)&1A
M=&$@/2!(;W)D95]397)I86QI>F4Z.G5N<V5R:6%L:7IE*"1R;W=;)V1A=&%T
M<F5E7V1A=&$G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R;W=;)V1A=&%T<F5E7W-E<FEA;&EZ960G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@+RH@0V]N=F5R
M="!O;&0@9&%T82!T;R!T:&4@;F5W(&9O<FUA="X@*B\*("`@("`@("`@("`@
M:68@*"1R;W=;)V1A=&%T<F5E7W-E<FEA;&EZ960G72`]/2!315))04Q)6D5?
M0D%324,I('L*("`@("`@("`@("`@("`@("1D871A(#T@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D9&%T82P@3DQ3.CIG971#:&%R<V5T*'1R=64I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@*&ES7VYU;&PH)&1A=&$I
M('Q\("%I<U]A<G)A>2@D9&%T82DI(#\@87)R87DH*2`Z("1D871A.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!D871A(&9O
M<B!A;B!O8FIE8W0@9G)O;2!T:&4@:&]R9&5?9&%T871R965?871T<FEB=71E
M<R!T86)L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<GQA<G)A>2`D
M8VED("!4:&4@;V)J96-T(&ED('1O(&9E=&-H+"!O<B!A;B!A<G)A>2!O9@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;V)J96-T(&ED<RX*
M("`@("`J($!P87)A;2!A<G)A>2`D:V5Y<R`@("`@("`@(%1H92!A='1R:6)U
M=&5S(&ME>7,@=&\@9F5T8V@N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@02!H87-H(&]F(&%T=')I8G5T97,L(&]R(&$@;75L=&DM;&5V96P@:&%S
M:"!O9B!O8FIE8W0*("`@("`J("`@("`@("`@("`@("`@(&ED<R`]/B!T:&5I
M<B!A='1R:6)U=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U
M=&5S*"1C:60L("1K97ES(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1C:60I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1K97ES*2!["B`@("`@("`@("`@("1F:6QT
M97(@/2!S<')I;G1F*"<@04Y$(&%T=')I8G5T95]K97D@24X@*%PG)7-<)RDG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"(G+"`G
M(BP@)&ME>7,I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEL
M=&5R(#T@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)&-I
M9"DI('L*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G4T5,14-4(&1A
M=&%T<F5E7VED+"!A='1R:6)U=&5?;F%M92!!4R!N86UE+"!A='1R:6)U=&5?
M:V5Y($%3(")K97DB+"!A='1R:6)U=&5?=F%L=64@05,@=F%L=64@1E)/32`E
M<R!72$5212!D871A=')E95]I9"!)3B`H)7,I)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U
M=&5S)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G
M+"`G+"`D8VED*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL
M=&5R*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E
M<GD@8GD@1&%T851R965?<W%L.CIG971!='1R:6)U=&5S*"DZ("<@+B`D<75E
M<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("`@("`D<F]W<R`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E<GDL($1"
M7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R;W=S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')O
M=W,["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D871A(#T@87)R87DH
M*3L*("`@("`@("`@("`@9F]R96%C:"`H)')O=W,@87,@)')O=RD@>PH@("`@
M("`@("`@("`@("`@:68@*&5M<'1Y*"1D871A6R1R;W=;)V1A=&%T<F5E7VED
M)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1D871A6R1R;W=;)V1A=&%T
M<F5E7VED)UU=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1D871A6R1R;W=;)V1A=&%T<F5E7VED)UU=6UT@/2!A<G)A
M>2@G;F%M92<@/3X@)')O=ULG;F%M92==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K97DG(#T^("1R
M;W=;)VME>2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V86QU92<@/3X@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D<F]W6R=V86QU92==+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E
M="==+"!.3%,Z.F=E=$-H87)S970H*2DI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(')E='5R;B`D9&%T83L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@871T<FEB=71E7VYA;64@
M05,@;F%M92P@871T<FEB=71E7VME>2!!4R`B:V5Y(BP@871T<FEB=71E7W9A
M;'5E($%3('9A;'5E($923TT@)7,@5TA%4D4@9&%T871R965?:60@/2`E<R5S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&5?871T<FEB=71E<R==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("AI;G0I)&-I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FEL=&5R*3L*"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=3
M44P@475E<GD@8GD@1&%T851R965?<W%L.CIG971!='1R:6)U=&5S*"DZ("<@
M+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I
M.PH@("`@("`@("`@("`D<F]W<R`]("1T:&ES+3Y?9&(M/F=E=$%L;"@D<75E
M<GDL($1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1R;W=S*3L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)')O=W-;)&E=6R=V86QU92==(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E
M="@D<F]W<ULD:5U;)W9A;'5E)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=C:&%R<V5T)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,4SHZ9V5T0VAA
M<G-E="@I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')O
M=W,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@;G5M8F5R(&]F(&]B:F5C=',@;6%T8VAI;F<@82!S970@;V8@871T<FEB
M=71E(&-R:71E<FEA+@H@("`@("H*("`@("`J($!S964@8G5I;&1!='1R:6)U
M=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E
M<FEA("`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'!A<F5N="`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E
M87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L
M<R`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAI;&1R96X@;V8@)'!A
M<F5N=#\@1&5F875L=',@=&\@86QL(&QE=F5L<RX*("`@("`J($!P87)A;2!S
M=')I;F<@("1R97-T<FEC="`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@=VET
M:"!T:&4@<V%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;W5N=$)Y071T<FEB=71E<R@D8W)I=&5R:6$L("1P87)E;G0@
M/2!$051!5%)%15]23T]4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%L;$QE=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RD*("`@
M('L*("`@("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@("`@("`@
M("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@("`@("`D87$@/2`D=&AI<RT^
M8G5I;&1!='1R:6)U=&51=65R>2@D8W)I=&5R:6$L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N="P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86QL3&5V96QS+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-T
M<FEC="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!$051!5%)%15]"54E,1%]#3U5.5"D["B`@("`@("`@:68@*&ES7V$H)&%Q
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D87$["B`@
M("`@("`@?0H@("`@("`@(&QI<W0H)'%U97)Y+"`D=F%L=65S*2`]("1A<3L*
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A
M5')E95]S<6PZ.F-O=6YT0GE!='1R:6)U=&5S*"DZ("<@+B`D<75E<GDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H@("`@("`@("1R;W<@/2`F)')E<W5L="T^
M9F5T8VA2;W<H*3L*("`@("`@("!I9B`H:7-?82@D<F]W+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R;W<L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N("1R;W<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')O=ULP
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S970@;V8@;V)J
M96-T(&ED<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@8W)I=&5R:6$N
M"B`@("`@*@H@("`@("H@0'-E92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D8W)I=&5R:6$@("`@(%1H92!A
M<G)A>2!O9B!C<FET97)I82X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E
M;G0@("`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F
M<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U
M<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_
M($1E9F%U;'1S('1O(&%L;"!L979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<F5S=')I8W0@("`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T
M:&4@<V%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M='1R:6)U=&5?;F%M92!O<B!A='1R:6)U=&5?:60N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9G)O;2`@("`@("`@(%1H92!O8FIE8W0@=&\@<W1A<G0@=&\@
M9F5T8VAI;F<*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N="`@("`@("`@
M5&AE(&YU;6)E<B!O9B!O8FIE8W1S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F
M;W(@<V]R=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y
M("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E
M;F1I;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q
M("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971">4%T=')I
M8G5T97,H)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/5"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D86QL3&5V96QS(#T@=')U92P@
M)')E<W1R:6-T(#T@)VYA;64G+"`D9G)O;2`](#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O=6YT(#T@,"P@)'-O<G1B>5]N86UE(#T@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`]
M(&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@(&EF("@A8V]U
M;G0H)&-R:71E<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G;F\@8W)I=&5R:6$G*3L*("`@("`@("!]"@H@("`@("`@("1A
M<2`]("1T:&ES+3YB=6EL9$%T=')I8G5T95%U97)Y*"1C<FET97)I82P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R96YT
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A
M;&Q,979E;',L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<W1R:6-T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1!5$%44D5%7T)524Q$7U-%3$5#5"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VYA;64L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O
M<G1B>5]K97DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1I<F5C=&EO;BD["B`@("`@("`@:68@*&ES7V$H)&%Q+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D87$["B`@("`@("`@
M?0H@("`@("`@(&QI<W0H)'%U97)Y+"`D=F%L=65S*2`]("1A<3L*"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S
M<6PZ.F=E=$)Y071T<FEB=71E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@:68@*"1C;W5N
M="D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^;&EM:711
M=65R>2@D<75E<GDL("1F<F]M+"`D8V]U;G0L("1V86QU97,I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*("`@("`@("`D<F]W<R`](&%R<F%Y*"D["B`@("`@("`@=VAI
M;&4@*"1R;W<@/2`F)')E<W5L="T^9F5T8VA2;W<H*2D@>PH@("`@("`@("`@
M("`D<F]W<ULD<F]W6S!=72`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')O
M=ULQ72P@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M;W)T<R!)1',@8GD@871T<FEB=71E('9A;'5E<RX@241S('=I=&AO=70@871T
M<FEB=71E<R!W:6QL(&)E(&%D9&5D('1O"B`@("`@*B!T:&4@96YD(&]F('1H
M92!S;W)T960@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'5N
M;W)D97)E9%]I9',@($%R<F%Y(&]F(&ED<R!T;R!S;W)T+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1S;W)T8GE?;F%M92`@("!!='1R:6)U=&4@;F%M92!T;R!U
M<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]K
M97D@("`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1D:7)E8W1I;VX@("`@("!3;W)T(&1I<F5C=&EO
M;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@
M87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!3;W)T960@:61S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T0GE!='1R
M:6)U=&5S*"1U;F]R9&5R961?:61S+"`D<V]R=&)Y7VYA;64@/2!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<V]R=&)Y7VME>2`](&YU
M;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@("\J(%-E;&5C="!I
M9',@;W)D97)E9"!B>2!A='1R:6)U=&4@=F%L=64N("HO"B`@("`@("`@)'=H
M97)E(#T@)R<["B`@("`@("`@:68@*"%I<U]N=6QL*"1S;W)T8GE?;F%M92DI
M('L*("`@("`@("`@("`@)'=H97)E(#T@<W!R:6YT9B@G($%.1"!A='1R:6)U
M=&5?;F%M92`]("5S("<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D8BT^<75O=&4H)'-O<G1B>5]N86UE*2D["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VME>2DI('L*("`@("`@("`@
M("`@)'=H97)E(#T@<W!R:6YT9B@G)7,@04Y$(&%T=')I8G5T95]K97D@/2`E
M<R`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W:&5R92P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ=6]T92@D
M<V]R=&)Y7VME>2DI.PH@("`@("`@('T*"B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G4T5,14-4(&1A=&%T<F5E7VED($923TT@)7,@5TA%4D4@9&%T871R
M965?:60@24X@*"5S*2`E<R!/4D1%4B!"62!A='1R:6)U=&5?=F%L=64@)7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RPG+"`D=6YO<F1E<F5D7VED<RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=VAE<F4L"B`@("`@("`@("`@("`@("`@("`@("`@("`H)&1I
M<F5C=&EO;B`]/2`Q*2`_("=$15-#)R`Z("=!4T,G*3L*"B`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.G-O
M<G1">4%T=')I8G5T97,H*3H@)R`N("1Q=65R>2P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)&]R9&5R961?:61S(#T@
M)'1H:7,M/E]D8BT^9V5T0V]L*"1Q=65R>2D["@H@("`@("`@("\J($UA:V4@
M<W5R92!T:&%T('-O;64@:61S(&1I9&XG="!G970@;&]S="!B96-A=7-E(&AA
M<R!N;R!S=6-H"B`@("`@("`@("H@871T<FEB=71E(&YA;64O:V5Y+B!!<'!E
M;F0@=&AE;2!T;R!T:&4@96YD+B`J+PH@("`@("`@(&EF("AC;W5N="@D;W)D
M97)E9%]I9',I("$](&-O=6YT*"1U;F]R9&5R961?:61S*2D@>PH@("`@("`@
M("`@("`D;W)D97)E9%]I9',@/2!A<G)A>5]U;FEQ=64H87)R87E?;65R9V4H
M)&]R9&5R961?:61S+"`D=6YO<F1E<F5D7VED<RDI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O<F1E<F5D7VED<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!L:7-T(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A
M;'5E<R!O9B!T:&4@9VEV96X@871T<FEB=71E"B`@("`@*B!N86UE+VME>2!C
M;VUB:6YA=&EO;BX@16ET:&5R(&%T=')I8G5T95]N86UE(&]R(&%T=')I8G5T
M95]K97D@35535"!B90H@("`@("H@<W5P<&QI960L(&%N9"!B;W1H($U!62!B
M92!S=7!P;&EE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D871T
M<FEB=71E7VYA;64@(%1H92!N86UE(&]F('1H92!A='1R:6)U=&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D871T<FEB=71E7VME>2`@(%1H92!K97D@=F%L
M=64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J($!P87)A;2!S=')I;F<@("1P
M87)E;G0@("`@("`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C
M:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@
M("`@("!2971U<FX@86QL(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N
M(&]F("1P87)E;G0_($1E9F%U;'1S('1O(&%L;`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L979E;',N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&]F('1H92!A=F%I;&%B
M;&4@=F%L=65S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&56
M86QU97,H)&%T=')I8G5T95]N86UE(#T@;G5L;"P@)&%T=')I8G5T95]K97D@
M/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)E
M;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@=')U92D*("`@('L*
M("`@("`@("`O+R!"=6EL9"!T:&4@;F%M92]K97D@9FEL=&5R+@H@("`@("`@
M("1W:&5R92`]("<G.PH@("`@("`@(&EF("@A:7-?;G5L;"@D871T<FEB=71E
M7VYA;64I*2!["B`@("`@("`@("`@("1W:&5R92`N/2`G82YA='1R:6)U=&5?
M;F%M92`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D871T<FEB=71E7VYA;64I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&%T=')I8G5T95]K
M97DI*2!["B`@("`@("`@("`@(&EF("@D=VAE<F4I('L*("`@("`@("`@("`@
M("`@("1W:&5R92`N/2`G($%.1"`G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1W:&5R92`N/2`G82YA='1R:6)U=&5?:V5Y(#T@)R`N("1T:&ES+3Y?
M9&(M/G%U;W1E*"1A='1R:6)U=&5?:V5Y*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%)E='5R;B!I9B!W92!H879E(&YO(&-R:71E<FEA+@H@("`@("`@(&EF
M("@A)'=H97)E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=N;R!C<FET97)I82<I.PH@("`@("`@('T*"B`@("`@("`@+R\@061D
M(&9I;'1E<FEN9R!B>2!P87)E;G0L(&%N9"!F;W(@;VYE(&]R(&%L;"!L979E
M;',N"B`@("`@("`@)&QE=F5L475E<GD@/2`G)SL*("`@("`@("!I9B`H)'!A
M<F5N="`A/2!$051!5%)%15]23T]4*2!["B`@("`@("`@("`@("1P87)T<R`]
M(&5X<&QO9&4H)SHG+"`D<&%R96YT*3L*("`@("`@("`@("`@)'!A<F5N=',@
M/2`G)SL*("`@("`@("`@("`@)'!S=')I;F<@/2`G)SL*("`@("`@("`@("`@
M9F]R96%C:"`H)'!A<G1S(&%S("1P87)T*2!["B`@("`@("`@("`@("`@("`D
M<'-T<FEN9R`N/2`H96UP='DH)'!S=')I;F<I(#\@)R<@.B`G.B<I("X@)'!A
M<G0["B`@("`@("`@("`@("`@("`D<&ED(#T@)'1H:7,M/F=E=$ED*"1P<W1R
M:6YG*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'!I9#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P87)E;G1S("X]("<Z
M)R`N("1P:60["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D86QL
M3&5V96QS*2!["B`@("`@("`@("`@("`@("`D;&5V96Q1=65R>2`]('-P<FEN
M=&8H)T%.1"`H9&%T871R965?<&%R96YT<R`]("5S($]2(&1A=&%T<F5E7W!A
M<F5N=',@3$E+12`E<RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&(M/G%U;W1E*"1P87)E;G1S*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ
M=6]T92@D<&%R96YT<R`N("<Z)2<I*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1L979E;%%U97)Y(#T@<W!R:6YT9B@G04Y$(&1A
M=&%T<F5E7W!A<F5N=',@/2`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H)'!A<F5N=',I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@A)&%L;$QE=F5L<RD@
M>PH@("`@("`@("`@("`D;&5V96Q1=65R>2`](")!3D0@9&%T871R965?<&%R
M96YT<R`]("<G(CL*("`@("`@("!]"@H@("`@("`@("\O($)U:6QD('1H92!&
M4D]-+TI/24X@8VQA=7-E<RX*("`@("`@("`D:F]I;G,@/2`G3$5&5"!*3TE.
M("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("<@
M8R!/3B!A+F1A=&%T<F5E7VED(#T@8RYD871A=')E95]I9"<["@H@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!$25-424Y#5"!A+F%T=')I8G5T
M95]V86QU92!&4D]-("5S(&$@)7,@5TA%4D4@8RYG<F]U<%]U:60@/2`E<R!!
M3D0@)7,@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1J;VEN<RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?<&%R86US6R=G<F]U<"==*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1W:&5R92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1L979E;%%U97)Y*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)U-13"!1=65R>2!B>2!$871A5')E95]S<6PZ.F=E=$%T=')I8G5T959A
M;'5E<R@I.B`G("X@)'%U97)Y+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T1%0E5'*3L*"B`@("`@("`@)')O=W,@/2`D=&AI<RT^7V1B+3YG971#
M;VPH)'%U97)Y*3L*("`@("`@("!I9B`H:7-?82@D<F]W<RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D<F]W<RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0G5I;&1S(&%N(&%T=')I8G5T92!Q=65R>2X@2&5R92!I<R!A;B!E>&%M<&QE
M("1C<FET97)I82!A<G)A>3H*("`@("`J"B`@("`@*B`\8V]D93X*("`@("`J
M("1C<FET97)I85LG3U(G72`](&%R<F%Y*`H@("`@("H@("`@(&%R<F%Y*"=!
M3D0G(#T^(&%R<F%Y*`H@("`@("H@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^
M("=N86UE)RP*("`@("`J("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G/2<L
M"B`@("`@*B`@("`@("`@("`@("`@("=T97-T)R`@/3X@)V9O;R<I+`H@("`@
M("H@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^("=K97DG+`H@("`@("H@("`@
M("`@("`@("`@("`G;W`G("`@(#T^("<])RP*("`@("`J("`@("`@("`@("`@
M("`@)W1E<W0G("`]/B`G86)C)RDI*2P*("`@("`J("`@("`@("`@87)R87DH
M)T%.1"<@/3X@87)R87DH"B`@("`@*B`@("`@("`@("`@("!A<G)A>2@G9FEE
M;&0G(#T^("=N86UE)RP*("`@("`J("`@("`@("`@("`@("`@("`@("=O<"<@
M("`@/3X@)STG+`H@("`@("H@("`@("`@("`@("`@("`@("`@)W1E<W0G("`]
M/B`G8F%R)RDL"B`@("`@*B`@("`@("`@("`@("!A<G)A>2@G9FEE;&0G(#T^
M("=K97DG+`H@("`@("H@("`@("`@("`@("`@("`@("`@)V]P)R`@("`]/B`G
M/2<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`G=&5S="<@(#T^("=X>7HG
M*2DI*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!4:&ES('=O=6QD
M(&9E=&-H(&%L;"!O8FIE8W0@:61S('=H97)E(&%T=')I8G5T92!N86UE(&ES
M(")F;V\B($%.1"!K97D*("`@("`J(&ES(")A8F,B+"!/4B`B8F%R(B!!3D0@
M(GAY>B(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R:71E<FEA
M("`@("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D<&%R96YT("`@("`@(%1H92!P87)E;G0@;F]D92!T;R!S=&%R="!S
M96%R8VAI;F<@9G)O;2X*("`@("`J($!P87)A;2!B;V]L96%N("1A;&Q,979E
M;',@("`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O
M9B`D<&%R96YT/R!$969A=6QT<R!T;R!A;&P@;&5V96QS+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)')E<W1R:6-T("`@("!/;FQY(')E='5R;B!A='1R:6)U
M=&5S('=I=&@@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&]P97)A=&EO;B`@("!4>7!E(&]F('%U97)Y
M('1O(&)U:6QD"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V]R=&)Y7VYA;64@
M($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R=&EN9RX*("`@("`J($!P
M87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U
M<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9&ER96-T
M:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S8V5N9&EN9PH@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($%N(%-13"!Q=65R>2!A;F0@82!L:7-T
M(&]F('9A;'5E<R!S=6ET86)L92!F;W(@8FEN9&EN9PH@("`@("H@("`@("`@
M("`@("`@("`@87,@86X@87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U
M:6QD071T<FEB=71E475E<GDH)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512
M145?4D]/5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%L
M;$QE=F5L<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P97)A=&EO;B`]($1!5$%44D5%
M7T)524Q$7U-%3$5#5"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-O<G1B>5]N86UE(#T@;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER96-T:6]N(#T@
M,"D*("`@('L*("`@("`@("!I9B`H(6-O=6YT*"1C<FET97)I82DI('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"<G+"!A<G)A>2@I*3L*("`@("`@("!]
M"@H@("`@("`@("\J($)U:6QD('1H92!Q=65R>2X@*B\*("`@("`@("`D=&AI
M<RT^7W1A8FQE0V]U;G0@/2`Q.PH@("`@("`@("1Q=65R>2`]("<G.PH@("`@
M("`@("1V86QU97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1C<FET
M97)I82!A<R`D:V5Y(#T^("1V86QS*2!["B`@("`@("`@("`@(&EF("@D:V5Y
M(#T]("=/4B<@?'P@)&ME>2`]/2`G04Y$)RD@>PH@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D<75E<GDI*2!["B`@("`@("`@("`@("`@("`@("`@)'%U
M97)Y("X]("<@)R`N("1K97D@+B`G("<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`D8FEN9',@/2`D=&AI<RT^7V)U:6QD071T<FEB=71E
M475E<GDH)&ME>2P@)'9A;',I.PH@("`@("`@("`@("`@("`@)'%U97)Y("X]
M("<H)R`N("1B:6YD<ULP72`N("<I)SL*("`@("`@("`@("`@("`@("1V86QU
M97,@*ST@)&)I;F1S6S%=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O+R!!9&0@9FEL=&5R:6YG(&)Y('!A<F5N="P@86YD(&9O<B!O;F4@
M;W(@86QL(&QE=F5L<RX*("`@("`@("`D;&5V96Q1=65R>2`]("<G.PH@("`@
M("`@("1L979E;%9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@:68@*"1P87)E
M;G0@(3T@1$%40512145?4D]/5"D@>PH@("`@("`@("`@("`D<&%R=',@/2!E
M>'!L;V1E*"<Z)RP@)'!A<F5N="D["B`@("`@("`@("`@("1P87)E;G1S(#T@
M)R<["B`@("`@("`@("`@("1P<W1R:6YG(#T@)R<["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P87)T<R!A<R`D<&%R="D@>PH@("`@("`@("`@("`@("`@)'!S
M=')I;F<@+CT@*&5M<'1Y*"1P<W1R:6YG*2`_("<G(#H@)SHG*2`N("1P87)T
M.PH@("`@("`@("`@("`@("`@)'!I9"`]("1T:&ES+3YG971)9"@D<'-T<FEN
M9RD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<&ED+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1P:60["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<&%R96YT<R`N/2`G.B<@
M+B`D<&ED.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&%L;$QE
M=F5L<RD@>PH@("`@("`@("`@("`@("`@)&QE=F5L475E<GD@/2`G04Y$("AD
M871A=')E95]P87)E;G1S(#T@/R!/4B!D871A=')E95]P87)E;G1S($Q)2T4@
M/RDG.PH@("`@("`@("`@("`@("`@)&QE=F5L5F%L=65S(#T@87)R87DH)'!A
M<F5N=',L("1P87)E;G1S("X@)SHE)RD["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D;&5V96Q1=65R>2`]("=!3D0@9&%T871R965?
M<&%R96YT<R`](#\G.PH@("`@("`@("`@("`@("`@)&QE=F5L5F%L=65S(#T@
M87)R87DH)'!A<F5N=',I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M:68@*"$D86QL3&5V96QS*2!["B`@("`@("`@("`@("1L979E;%%U97)Y(#T@
M(D%.1"!D871A=')E95]P87)E;G1S(#T@)R<B.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0G5I;&0@=&AE($923TTO2D])3B!C;&%U<V5S+@H@("`@("`@("1J
M;VEN<R`](&%R<F%Y*"D["B`@("`@("`@)'!A:7)S(#T@87)R87DH*3L*("`@
M("`@("!F;W(@*"1I(#T@,3L@)&D@/#T@)'1H:7,M/E]T86)L94-O=6YT.R`D
M:2LK*2!["B`@("`@("`@("`@("1J;VEN<UM=(#T@)TQ%1E0@2D])3B`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@("`@("`@
M("`@("`@("`G(&$G("X@)&D@+B`G($].(&$G("X@)&D@+B`G+F1A=&%T<F5E
M7VED(#T@8RYD871A=')E95]I9"<["@H@("`@("`@("`@("!I9B`H)&D@(3T@
M,2D@>PH@("`@("`@("`@("`@("`@:68@*"1R97-T<FEC="`]/2`G;F%M92<I
M('L*("`@("`@("`@("`@("`@("`@("`D<&%I<G-;72`]("=!3D0@83$N871T
M<FEB=71E7VYA;64@/2!A)R`N("1I("X@)RYA='1R:6)U=&5?;F%M92<["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)')E<W1R:6-T(#T]("=I9"<I('L*
M("`@("`@("`@("`@("`@("`@("`D<&%I<G-;72`]("=!3D0@83$N9&%T871R
M965?:60@/2!A)R`N("1I("X@)RYD871A=')E95]I9"<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($]V
M97)R:61E('-O<G1I;F<N"B`@("`@("`@)'-O<G0@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VYA;64I('Q\("%I<U]N=6QL*"1S
M;W)T8GE?:V5Y*2D@>PH@("`@("`@("`@("`D;W)D97)?=&%B;&4@/2`G82<@
M+B`D:3L*("`@("`@("`@("`@)&IO:6YS6UT@/2`G3$5&5"!*3TE.("<@+B`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&5?871T<FEB=71E<R==("X*("`@("`@("`@
M("`@("`@("<@)R`N("1O<F1E<E]T86)L92`N("<@3TX@)R`N("1O<F1E<E]T
M86)L92`N"B`@("`@("`@("`@("`@("`G+F1A=&%T<F5E7VED(#T@8RYD871A
M=')E95]I9"<["@H@("`@("`@("`@("!I9B`H(6ES7VYU;&PH)'-O<G1B>5]N
M86UE*2D@>PH@("`@("`@("`@("`@("`@)'!A:7)S6UT@/2!S<')I;G1F*"=!
M3D0@)7,N871T<FEB=71E7VYA;64@/2`_("<L("1O<F1E<E]T86)L92D["B`@
M("`@("`@("`@("`@("`D<V]R=%M=(#T@)'-O<G1B>5]N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-?;G5L;"@D<V]R=&)Y7VME>2DI
M('L*("`@("`@("`@("`@("`@("1P86ER<UM=(#T@<W!R:6YT9B@G04Y$("5S
M+F%T=')I8G5T95]K97D@/2`_("<L("1O<F1E<E]T86)L92D["B`@("`@("`@
M("`@("`@("`D<V]R=%M=(#T@)'-O<G1B>5]K97D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1O<F1E<B`]('-P<FEN=&8H)R5S+F%T=')I8G5T95]V
M86QU92`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]R9&5R
M7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D9&ER96-T
M:6]N(#T](#$I(#\@)T1%4T,G(#H@)T%30R<I.PH@("`@("`@("`@("`D9W)O
M=7!?8GD@/2`G8RYD871A=')E95]I9"P@8RYD871A=')E95]N86UE+"!C+F1A
M=&%T<F5E7V]R9&5R+"`G("X*("`@("`@("`@("`@("`@("1O<F1E<E]T86)L
M92`N("<N871T<FEB=71E7W9A;'5E)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;W)D97(@/2`G8RYD871A=')E95]O<F1E<BP@8RYD871A=')E
M95]N86UE+"!C+F1A=&%T<F5E7VED)SL*("`@("`@("`@("`@)&=R;W5P7V)Y
M(#T@)V,N9&%T871R965?:60L(&,N9&%T871R965?;F%M92P@8RYD871A=')E
M95]O<F1E<B<["B`@("`@("`@?0H*("`@("`@("`D:F]I;G,@/2!I;7!L;V1E
M*"<@)RP@)&IO:6YS*3L*("`@("`@("`D<&%I<G,@/2!I;7!L;V1E*"<@)RP@
M)'!A:7)S*3L*("`@("`@("`D=&%I;"`]('-P<FEN=&8H)T=23U50($)9("5S
M($]21$52($)9("5S)RP@)&=R;W5P7V)Y+"`D;W)D97(I.PH*("`@("`@("!S
M=VET8V@@*"1O<&5R871I;VXI('L*("`@("`@("!C87-E($1!5$%44D5%7T)5
M24Q$7T-/54Y4.@H@("`@("`@("`@("`D=VAA="`]("=#3U5.5"A$25-424Y#
M5"!C+F1A=&%T<F5E7VED*2<["B`@("`@("`@("`@("1T86EL(#T@)R<["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`D=VAA="`]("=C+F1A=&%T<F5E7VED+"!C+F1A=&%T<F5E7VYA;64G.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A
M<G)A>2AS<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!C("5S(%=(15)%(&,N
M9W)O=7!?=6ED(#T@/R!!3D0@)7,@)7,@)7,@)7,G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W:&%T+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1J;VEN<RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<75E<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QE=F5L475E<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M:7)S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T86EL*2P*("`@
M("`@("`@("`@("`@("`@("`@87)R87E?;65R9V4H87)R87DH)'1H:7,M/E]P
M87)A;7-;)V=R;W5P)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=65S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;&5V96Q686QU97,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S;W)T*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@82!P
M:65C92!O9B!A;B!A='1R:6)U=&4@<75E<GDN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9VQU92`@("`@5&AE(&=L=64@=&\@:F]I;B!T:&4@8W)I
M=&5R:6$@*$]2+T%.1"DN"B`@("`@*B!`<&%R86T@87)R87D@)&-R:71E<FEA
M("!4:&4@87)R87D@;V8@8W)I=&5R:6$N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D:F]I;B`@("!3:&]U;&0@=V4@:F]I;B!O;B!A(&-L96%N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!H;W)D95]D871A=')E95]A='1R:6)U
M=&5S('1A8FQE/R!$969A=6QT<R!T;PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@9F%L<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M06X@4U%,(&9R86=M96YT(&%N9"!A(&QI<W0@;V8@=F%L=65S('-U:71A8FQE
M(&9O<B!B:6YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("!A<R!A;B!A<G)A
M>2X*("`@("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD071T<FEB=71E475E<GDH
M)&=L=64L("1C<FET97)I82P@)&IO:6X@/2!F86QS92D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+U-13"YP:'`G.PH*("`@("`@("`O+R!)
M;FET:6%L:7IE('1H92!C;&%U<V4@=&AA="!W92=R92!B=6EL9&EN9RX*("`@
M("`@("`D8VQA=7-E(#T@)R<["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D[
M"@H@("`@("`@("\O($=E="!T:&4@=&%B;&4@86QI87,@=&\@=7-E(&9O<B!T
M:&ES('-E="!O9B!C<FET97)I82X*("`@("`@("`D86QI87,@/2`D=&AI<RT^
M7V=E=$%L:6%S*"1J;VEN*3L*"B`@("`@("`@9F]R96%C:"`H)&-R:71E<FEA
M(&%S("1K97D@/3X@)'9A;',I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M8VQA=7-E*2D@>PH@("`@("`@("`@("`@("`@)&-L875S92`N/2`G("<@+B`D
M9VQU92`N("<@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(65M
M<'1Y*"1V86QS6R=/4B==*2!\?"`A96UP='DH)'9A;'-;)T%.1"==*2D@>PH@
M("`@("`@("`@("`@("`@)&)I;F1S(#T@)'1H:7,M/E]B=6EL9$%T=')I8G5T
M95%U97)Y*"1G;'5E+"`D=F%L<RD["B`@("`@("`@("`@("`@("`D8VQA=7-E
M("X]("<H)R`N("1B:6YD<ULP72`N("<I)SL*("`@("`@("`@("`@("`@("1V
M86QU97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@
M("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1V86QS6R=*3TE.)UTI*2!["B`@
M("`@("`@("`@("`@("`D8FEN9',@/2`D=&AI<RT^7V)U:6QD071T<FEB=71E
M475E<GDH)&=L=64L("1V86QS6R=*3TE.)UTL('1R=64I.PH@("`@("`@("`@
M("`@("`@)&-L875S92`N/2`D8FEN9'-;,%T["B`@("`@("`@("`@("`@("`D
M=F%L=65S(#T@87)R87E?;65R9V4H)'9A;'5E<RP@)&)I;F1S6S%=*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=F%L<ULG9FEE;&0G72DI('L*("`@("`@("`@("`@("`@("`@("`D8FEN9',@
M/2!(;W)D95]344PZ.F)U:6QD0VQA=7-E*"1T:&ES+3Y?9&(L("1A;&EA<R`N
M("<N871T<FEB=71E7R<@+B`D=F%L<ULG9FEE;&0G72P@)'9A;'-;)V]P)UTL
M("1V86QS6R=T97-T)UTL('1R=64I.PH@("`@("`@("`@("`@("`@("`@("1C
M;&%U<V4@+CT@)&)I;F1S6S!=.PH@("`@("`@("`@("`@("`@("`@("1V86QU
M97,@/2!A<G)A>5]M97)G92@D=F%L=65S+"`D8FEN9'-;,5TI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D8FEN9',@
M/2`D=&AI<RT^7V)U:6QD071T<FEB=71E475E<GDH)&ME>2P@)'9A;',I.PH@
M("`@("`@("`@("`@("`@("`@("1C;&%U<V4@+CT@)&)I;F1S6S!=.PH@("`@
M("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>5]M97)G92@D=F%L=65S
M+"`D8FEN9'-;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&-L875S92P@)'9A
M;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@86X@86QI87,@=&\@
M:&]R9&5?9&%T871R965?871T<FEB=71E<RP@:6YC<F5M96YT:6YG(&ET(&EF
M"B`@("`@*B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&EN8W)E;65N="`@26YC<F5M96YT('1H92!A;&EA<R!C;W5N=#\@1&5F
M875L=',@=&\@;F\N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971!;&EA<R@D
M:6YC<F5M96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A=&EC("1S965N
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1I;F-R96UE;G0@)B8@(65M<'1Y
M*"1S965N6R1T:&ES+3Y?=&%B;&5#;W5N=%TI*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?=&%B;&5#;W5N="LK.PH@("`@("`@('T*"B`@("`@("`@)'-E96Y;
M)'1H:7,M/E]T86)L94-O=6YT72`]('1R=64["B`@("`@("`@<F5T=7)N("=A
M)R`N("1T:&ES+3Y?=&%B;&5#;W5N=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%5P9&%T92!T:&4@9&%T82!I;B!A;B!O8FIE8W0N($1O97,@;F]T(&-H86YG
M92!T:&4@;V)J96-T)W,*("`@("`J('!A<F5N="!O<B!N86UE+"!J=7-T('-E
M<FEA;&EZ960@9&%T82!O<B!A='1R:6)U=&5S+@H@("`@("H*("`@("`J($!P
M87)A;2!$871A5')E92`D;V)J96-T("!!($1A=&%4<F5E(&]B:F5C="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=7!D871E1&%T82@D;V)J96-T*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?82@D;V)J96-T+"`G1&%T851R965/8FIE8W0G*2D@
M>PH@("`@("`@("`@("`O*B!.;W1H:6YG('1O(&1O(&9O<B!N;VX@;V)J96-T
M<RX@*B\*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@
M("`@("`O*B!'970@=&AE(&]B:F5C="!I9"X@*B\*("`@("`@("`D:60@/2`D
M=&AI<RT^9V5T260H)&]B:F5C="T^9V5T3F%M92@I*3L*("`@("`@("!I9B`H
M:7-?82@D:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1I9#L*("`@("`@("!]"@H@("`@("`@("\J(%-E92!I9B!W92!C86X@8G)E
M86L@=&AE(&]B:F5C="!O=70@=&\@9&%T871R965?871T<FEB=71E<R!T86)L
M92X@*B\*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V)J96-T+"`G7W1O
M071T<FEB=71E<R<I*2!["B`@("`@("`@("`@("\J($EF('=E(&-A;BP@8VQE
M87(@;W5T('1H92!D871A=')E95]D871A(&9I96QD('1O(&UA:V4@<W5R92!I
M=`H@("`@("`@("`@("`@*B!D;V5S;B=T(&=E="!P:6-K960@=7`@8GD@9V5T
M1&%T82@I+B!);G1E;G1I;VYA;&QY(&1O;B=T(&-H96-K"B`@("`@("`@("`@
M("`J(&9O<B!E<G)O<G,@:&5R92!I;B!C87-E(&1A=&%T<F5E7V1A=&$@9V]E
M<R!A=V%Y(&EN('1H90H@("`@("`@("`@("`@*B!F=71U<F4N("HO"B`@("`@
M("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N("1T:&ES+3Y?<&%R86US6R=T
M86)L92==("X*("`@("`@("`@("`@("`@("`@("`@)R!3150@9&%T871R965?
M9&%T82`](#\@5TA%4D4@9&%T871R965?:60@/2`_)SL*("`@("`@("`@("`@
M)'9A;'5E<R`](&%R<F%Y*$Y53$PL("AI;G0I)&ED*3L*"B`@("`@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R965?<W%L
M.CIU<&1A=&5$871A*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YQ
M=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("`@("`@+RH@4W1A<G0@
M82!T<F%N<V%C=&EO;BX@*B\*("`@("`@("`@("`@)'1H:7,M/E]D8BT^875T
M;T-O;6UI="AF86QS92D["@H@("`@("`@("`@("`O*B!$96QE=&4@;VQD(&%T
M=')I8G5T97,N("HO"B`@("`@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/
M32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G72`N"B`@
M("`@("`@("`@("`@("`@("`@("<@5TA%4D4@9&%T871R965?:60@/2`_)SL*
M("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI;G0I)&ED*3L*"B`@("`@
M("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=344P@475E<GD@8GD@1&%T851R
M965?<W%L.CIU<&1A=&5$871A*"DZ("<@+B`D<75E<GDL(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D<F5S=6QT
M(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D8BT^<F]L;&)A8VLH*3L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@1V5T('1H92!N97<@871T<FEB=71E('-E="P@86YD(&EN<V5R
M="!E86-H(&EN=&\@=&AE($1"+B!)9@H@("`@("`@("`@("`@*B!A;GET:&EN
M9R!F86EL<R!I;B!H97)E+"!R;VQL8F%C:R!T:&4@=')A;G-A8W1I;VXL(')E
M='5R;B!T:&4*("`@("`@("`@("`@("H@<F5L979A;G0@97)R;W(L(&%N9"!B
M86EL(&]U="X@*B\*("`@("`@("`@("`@)&%T=')I8G5T97,@/2`D;V)J96-T
M+3Y?=&]!='1R:6)U=&5S*"D["B`@("`@("`@("`@("1Q=65R>2`]("=)3E-%
M4E0@24Y43R`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE7V%T=')I8G5T97,G
M72`N"B`@("`@("`@("`@("`@("`@("`@("<@*&1A=&%T<F5E7VED+"!A='1R
M:6)U=&5?;F%M92P@871T<FEB=71E7VME>2P@871T<FEB=71E7W9A;'5E*2<@
M+@H@("`@("`@("`@("`@("`@("`@("`G(%9!3%5%4R`H/RP@/RP@/RP@/RDG
M.PH@("`@("`@("`@("`D<W1A=&5M96YT(#T@)'1H:7,M/E]D8BT^<')E<&%R
M92@D<75E<GDI.PH@("`@("`@("`@("!F;W)E86-H("@D871T<FEB=71E<R!A
M<R`D871T<BD@>PH@("`@("`@("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"AI
M;G0I)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A='1R
M6R=N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%T
M=');)VME>2==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-T
M<FEN9SHZ8V]N=F5R=$-H87)S970H)&%T=');)W9A;'5E)UTL($Y,4SHZ9V5T
M0VAA<G-E="@I+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*2D["@H@("`@
M("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U-13"!1=65R>2!B>2!$
M871A5')E95]S<6PZ.G5P9&%T941A=&$H*3H@)R`N("1Q=65R>2P@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F5X96-U=&4H)'-T871E;65N="P@
M)'9A;'5E<RD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^<F]L;&)A8VLH*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1B
M+3YA=71O0V]M;6ET*'1R=64I.PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!#;VUM:70@=&AE('1R86YS86-T:6]N+"!A;F0@='5R
M;B!A=71O8V]M;6ET(&)A8VL@;VXN("HO"B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YC;VUM:70H*3L*("`@("`@("`@("`@)'1H:7,M/E]D
M8BT^875T;T-O;6UI="AT<G5E*3L*"B`@("`@("`@("`@(')E='5R;B!I<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RD@/R`D<F5S=6QT(#H@=')U93L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!7<FET92!T;R!T:&4@9&%T
M871R965?9&%T82!F:65L9"X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]397)I86QI>F4N<&AP)SL*("`@("`@("`@("`@)'-E<B`](%-%
M4DE!3$E:15]55$8W7T)!4TE#.PH@("`@("`@("`@("`D9&%T82`]($AO<F1E
M7U-E<FEA;&EZ93HZ<V5R:6%L:7IE*"1O8FIE8W0M/F=E=$1A=&$H*2P@)'-E
M<BP@3DQ3.CIG971#:&%R<V5T*"DI.PH*("`@("`@("`@("`@)'%U97)Y(#T@
M)U501$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+@H@("`@("`@
M("`@("`@("`@("`@("`G(%-%5"!D871A=')E95]D871A(#T@/RP@9&%T871R
M965?<V5R:6%L:7IE9"`](#\G("X*("`@("`@("`@("`@("`@("`@("`@)R!7
M2$5212!D871A=')E95]I9"`](#\G.PH@("`@("`@("`@("`D=F%L=65S(#T@
M87)R87DH)&1A=&$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT
M*21S97(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H:6YT*21I9"D[
M"@H@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G4U%,(%%U97)Y(&)Y
M($1A=&%4<F5E7W-Q;#HZ=7!D871E1&%T82@I.B`G("X@)'%U97)Y+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD[
M"@H@("`@("`@("`@("!R971U<FX@:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I(#\@)')E<W5L="`Z('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE
M(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@
M("`@("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M
M<RP@)W-T;W)A9V4G+`H@("`@("`@("`@("!A<G)A>2@G<&AP='EP92<L("=C
M:&%R<V5T)RDL"B`@("`@("`@("`@("=$871A5')E92!344PG*3L*"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG9&%T86)A<V4G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=7-E<FYA;64G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2`G)SL*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT@/2`G:&]R9&5?9&%T871R964G.PH@("`@("`@('T*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L95]A='1R:6)U=&5S
M)UT@/2`G:&]R9&5?9&%T871R965?871T<FEB=71E<R<["B`@("`@("`@?0H*
M("`@("`@("`O*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H
M92!S=7!P;&EE9"!P87)A;65T97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC
M92`G1$(N<&AP)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T
M*"1T:&ES+3Y?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A
M<F%M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES
M+3Y?9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A
M=&%L*"1T:&ES+3Y?9&(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H*("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T:6]N<PH@("`@
M("`@('-W:71C:"`H)'1H:7,M/E]D8BT^<&AP='EP92D@>PH@("`@("`@(&-A
M<V4@)VUS<W%L)SH*("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N
M*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"
M7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/
M4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]$871A5')E92]N=6QL+G!H<```````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`R-S,W-R`Q,#4Q-30S-#$T,"`P,C(U,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M92!$871A5')E95]N=6QL.CH@8VQA<W,@<')O=FED97,@82!D=6UM>2!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4*("H@1&%T851R964Z.B!!4$D[(&YO(&1A=&$@
M=VEL;"!L87-T(&)E>6]N9"!A('-I;F=L92!P86=E(')E<75E<W0N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T1A=&%4<F5E+T1A=&%4<F5E+VYU;&PN<&AP
M+'8@,2XQ-2XR+C0@,C`P-2\Q,"\Q."`Q,3HP,3HP-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#$Y.3DL(#(P,#`L(#(P,#$L(#(P,#(@4W1E<&AA;F4@
M2'5T:&5R(#QS:'5T:&5R0&)I9V9O;W0N8V]M/@H@*B!#;W!Y<FEG:'0@,C`P
M,2P@,C`P,B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T1A=&%4<F5E"B`J+PIC;&%S<R!$871A5')E95]N=6QL(&5X
M=&5N9',@1&%T851R964@>PH*("`@("\J*@H@("`@("H@0V%C:&4@;V8@871T
M<FEB=71E<R!F;W(@86YY(&]B:F5C=',@8W)E871E9"!D=7)I;F<@=&AI<R!P
M86=E(')E<75E<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]A='1R:6)U=&5#86-H92`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!#86-H92!O9B!D871A(&9O<B!A;GD@;V)J96-T<R!C<F5A=&5D
M(&1U<FEN9R!T:&ES('!A9V4@<F5Q=65S="X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V1A=&%#86-H92`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!,;V%D("AA('-U8G-E="!O9BD@=&AE(&1A=&%T
M<F5E(&EN=&\@=&AE("1?9&%T82!A<G)A>2X@4&%R="!O9B!T:&4*("`@("`J
M($1A=&%4<F5E($%022!T:&%T(&UU<W0@8F4@;W9E<G)I9&1E;B!B>2!S=6)C
M;&%S<V5S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1R;V]T("`@
M(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R964@=&\@;&]A9"X@1&5F875L=',@
M=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%L;"!O9B!I="X*
M("`@("`J($!P87)A;2!B;V]L96%N("1R96QO860@(%)E+6QO860@86QR96%D
M>2!L;V%D960@=F%L=65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7VQO860H)')O;W0@/2!N=6QL+"`D<F5L;V%D(#T@9F%L<V4I"B`@
M("!["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D(&$@<W!E8VEF:6,@;V)J
M96-T(&ED96YT:69I960@8GD@:71S('5N:7%U92!)1"`H)&ED*2P@86YD"B`@
M("`@*B!I=',@<&%R96YT<RP@:6YT;R!T:&4@)%]D871A(&%R<F%Y+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ=64@240@
M;V8@=&AE(&]B:F5C="!T;R!L;V%D+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VQO861">4ED*"1C:60I"B`@("!["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@82!T<F5E('-O<G1E9"!B>2!T:&4@<W!E8VEF:65D
M(&%T=')I8G5T92!N86UE(&%N9"]O<B!K97DN"B`@("`@*@H@("`@("H@0'-I
M;F-E($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1R
M;V]T("`@("`@(%=H:6-H('!O<G1I;VX@;V8@=&AE('1R964@=&\@<V]R="X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M(&%L;"!O9B!I="X*("`@("`J($!P87)A;2!B;V]L96%N("1L;V%D5')E92`@
M(%-O<G0@=&AE('1R964@<W1A<G1I;F<@870@)')O;W0L(&]R(&IU<W0@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R97%U97-T960@
M;&5V96P@86YD(&1I<F5C="!P87)E;G1S/PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L=',@=&\@<VEN9VQE(&QE=F5L+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1S;W)T8GE?;F%M92`@071T<FEB=71E(&YA;64@
M=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("1S;W)T
M8GE?:V5Y("`@071T<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@
M("`@*B!`<&%R86T@87)R87D@)&1I<F5C=&EO;B`@("!3;W)T(&1I<F5C=&EO
M;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"`M(&%S
M8V5N9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q
M("T@9&5S8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G9713;W)T9614
M<F5E*"1R;V]T+"`D;&]A9%1R964@/2!F86QS92P@)'-O<G1B>5]N86UE(#T@
M;G5L;"P@)'-O<G1B>5]K97D@/2!N=6QL+"`D9&ER96-T:6]N(#T@,"D*("`@
M('L*("`@("`@("!R971U<FX@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($%D9"!A;B!O8FIE8W0N(%!A<G0@;V8@=&AE($1A=&%4<F5E($%022!T
M:&%T(&UU<W0@8F4*("`@("`J(&]V97)R:61D96X@8GD@<W5B8VQA<W-E<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&9U;&QN86UE("!4:&4@;V)J
M96-T('1O(&%D9"`H<W1R:6YG(&]R($1A=&%4<F5E3V)J96-T*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@861D*"1O8FIE8W0I"B`@("!["B`@("`@("`@:68@
M*&ES7V$H)&]B:F5C="P@)T1A=&%4<F5E3V)J96-T)RDI('L*("`@("`@("`@
M("`@)&9U;&QN86UE(#T@)&]B:F5C="T^9V5T3F%M92@I.PH@("`@("`@("`@
M("`D;W)D97(@/2`D;V)J96-T+3YO<F1E<CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9G5L;&YA;64@/2`D;V)J96-T.PH@("`@("`@("`@("`D
M;W)D97(@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@)&ED(#T@;60U*&UT
M7W)A;F0H*2D["B`@("`@("`@:68@*'-T<G!O<R@D9G5L;&YA;64L("<Z)RD@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)SHG
M+"`D9G5L;&YA;64I.PH@("`@("`@("`@("`D;F%M92`](&%R<F%Y7W!O<"@D
M<&%R=',I.PH@("`@("`@("`@("`D<&%R96YT(#T@:6UP;&]D92@G.B<L("1P
M87)T<RD["B`@("`@("`@("`@("1P:60@/2`D=&AI<RT^9V5T260H)'!A<F5N
M="D["B`@("`@("`@("`@(&EF("AI<U]A*"1P:60L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YA9&0H)'!A<F5N="D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&ED(#T@
M1$%40512145?4D]/5#L*("`@("`@("!]"@H@("`@("`@(&EF("AP87)E;G0Z
M.F5X:7-T<R@D9G5L;&YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=!;')E861Y(&5X:7-T<R<I.PH@("`@("`@('T*"B`@
M("`@("`@)&%D9&5D(#T@<&%R96YT.CI?861D*"1F=6QL;F%M92P@)&ED+"`D
M<&ED+"`D;W)D97(I.PH@("`@("`@(&EF("AI<U]A*"1A9&1E9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&%D9&5D.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)'1H:7,M/G5P9&%T941A=&$H)&]B:F5C="D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@;W)D97(@;V8@=&AE(&-H
M:6QD<F5N(&]F(&%N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P87)E;G1S("!4:&4@<&%R96YT(&ED('-T<FEN9R!P871H+@H@("`@
M("H@0'!A<F%M(&UI>&5D("1O<F1E<B`@("`@02!S<&5C:69I8R!N97<@;W)D
M97(@<&]S:71I;VX@;W(@86X@87)R87D*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1A:6YI;F<@=&AE(&YE=R!P;W-I=&EO;G,@9F]R('1H
M92!G:79E;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N
M=',@;V)J96-T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-I9"`@("`@268@
M<')O=FED960@:6YD:6-A=&5S(&EN<V5R=&EO;B!O9B!A(&YE=R!C:&EL9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&\@=&AE(&]B:F5C="P@
M86YD('=I;&P@8F4@=7-E9"!T;R!A=F]I9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@:6YC<F5M96YT:6YG(&ET('=H96X@<VAI9G1I;F<@=7`@
M86QL(&]T:&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL
M9')E;B=S(&]R9&5R+B!)9B!N;W0@<')O=FED960@:6YD:6-A=&5S"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!D96QE=&EO;BP@:&5N8V4@<VAI
M9G0@86QL(&]T:&5R('!O<VET:6]N<R!D;W=N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!O;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;W)D
M97(H)'!A<F5N=',L("1O<F1E<B`](&YU;&PL("1C:60@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;W)D97(I("8F("%E;7!T>2@D;W)D
M97(I*2!["B`@("`@("`@("`@("\O($UU;'1I('5P9&%T92X*("`@("`@("`@
M("`@)'1H:7,M/E]R96]R9&5R*"1P:60L("1O<F1E<BD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@17AP;&EC:71L>2!S970@=&AE(&]R9&5R
M(&9O<B!A(&1A=&%T<F5E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:60@("`@(%1H92!D871A=')E92!O8FIE8W0@:60@=&\@8VAA
M;F=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&]R9&5R("!4:&4@;F5W(&]R
M9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971/<F1E<B@D:60L("1O<F1E
M<BD*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@86X@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@("1O8FIE8W0@(%1H
M92!O8FIE8W0@=&\@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&9O
M<F-E("`@1F]R8V4@<F5M;W9A;"!O9B!E=F5R>2!C:&EL9"!O8FIE8W0_"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@D;V)J96-T+"`D9F]R8V4@/2!F
M86QS92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!O;F4@
M;W(@;6]R92!O8FIE8W1S(&)Y(&ED+B!4:&ES(&9U;F-T:6]N(&1O97,@*FYO
M="H@9&\*("`@("`J('1H92!V86QI9&%T:6]N+"!R96]R9&5R:6YG+"!E=&,N
M('1H870@<F5M;W9E*"D@9&]E<RX@268@>6]U"B`@("`@*B!N965D('1O(&-H
M96-K(&9O<B!C:&EL9')E;BP@<F4M9&\@;W)D97)I;F<L(&5T8RXL('1H96X@
M>6]U(&UU<W0*("`@("`J(')E;6]V92@I(&]B:F5C=',@;VYE+6)Y+6]N92X@
M5&AI<R!I<R!F;W(@8V]D92!T:&%T(&MN;W=S(&ET)W,*("`@("`J(&1E86QI
M;F<@=VET:"!S:6YG;&4@*&YO;BUP87)E;G1E9"D@;V)J96-T<R!A;F0@;F5E
M9',@=&\@9&5L971E"B`@("`@*B!A(&)A=&-H(&]F('1H96T@<75I8VML>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&ED<R`@5&AE(&]B:F5C=',@
M=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5">4ED<R@D
M:61S*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E(&]N92!O
M<B!M;W)E(&]B:F5C=',@8GD@;F%M92X@5&AI<R!F=6YC=&EO;B!D;V5S("IN
M;W0J(&1O"B`@("`@*B!T:&4@=F%L:61A=&EO;BP@<F5O<F1E<FEN9RP@971C
M+B!T:&%T(')E;6]V92@I(&1O97,N($EF('EO=0H@("`@("H@;F5E9"!T;R!C
M:&5C:R!F;W(@8VAI;&1R96XL(')E+61O(&]R9&5R:6YG+"!E=&,N+"!T:&5N
M('EO=2!M=7-T"B`@("`@*B!R96UO=F4H*2!O8FIE8W1S(&]N92UB>2UO;F4N
M(%1H:7,@:7,@9F]R(&-O9&4@=&AA="!K;F]W<R!I="=S"B`@("`@*B!D96%L
M:6YG('=I=&@@<VEN9VQE("AN;VXM<&%R96YT960I(&]B:F5C=',@86YD(&YE
M961S('1O(&1E;&5T90H@("`@("H@82!B871C:"!O9B!T:&5M('%U:6-K;'DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1N86UE<R`@5&AE(&]B:F5C
M=',@=&\@<F5M;W9E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5">4YA
M;65S*"1N86UE<RD*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($UO=F4@
M86X@;V)J96-T('1O(&$@;F5W('!A<F5N="X*("`@("`J"B`@("`@*B!`<&%R
M86T@;6EX960@("1O8FIE8W0@("`@(%1H92!O8FIE8W0@=&\@;6]V92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YE=W!A<F5N="`@5&AE(&YE=R!P87)E;G0@
M;V)J96-T+B!$969A=6QT<R!T;R!T:&4@<F]O="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;6]V92@D;V)J96-T+"`D;F5W<&%R96YT(#T@;G5L;"D*("`@('L*
M("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!A;B!O8FIE8W0G<R!N86UE
M+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@)&]L9%]O8FIE8W0@("`@
M("`@5&AE(&]L9"!O8FIE8W0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=?
M;V)J96-T7VYA;64@(%1H92!N97<@;V)J96-T(&YA;64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F%M92@D;VQD7V]B:F5C="P@)&YE=U]O8FIE8W1?;F%M
M92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&1A=&$@
M9F]R(&%N(&]B:F5C="!F<F]M('1H92!D871A=')E95]D871A(&9I96QD+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!O8FIE8W0@
M:60@=&\@9F5T8V@L(&]R(&%N(&%R<F%Y(&]F(&]B:F5C="!I9',N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1A=&$H)&-I9"D*("`@('L*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/E]D871A0V%C:&5;)&-I9%TI(#\*("`@("`@
M("`@("`@)'1H:7,M/E]D871A0V%C:&5;)&-I9%T@.@H@("`@("`@("`@("!A
M<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@9&%T82!F
M;W(@86X@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1C
M:60@(%1H92!O8FIE8W0@:60@=&\@9F5T8V@N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$%T=')I8G5T97,H)&-I9"D*("`@('L*("`@("`@("!I9B`H:7-?
M87)R87DH)&-I9"DI('L*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH@
M("`@("`@("`@("!F;W)E86-H("@D8VED(&%S("1I9"D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?871T<FEB=71E0V%C:&5;)&ED72DI
M('L*("`@("`@("`@("`@("`@("`@("`D9&%T85LD:61=(#T@)'1H:7,M/E]A
M='1R:6)U=&5#86-H95LD:61=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?871T<FEB
M=71E0V%C:&5;)&-I9%TI(#\*("`@("`@("`@("`@("`@("1T:&ES+3Y?871T
M<FEB=71E0V%C:&5;)&-I9%T@.@H@("`@("`@("`@("`@("`@87)R87DH*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N
M=6UB97(@;V8@;V)J96-T<R!M871C:&EN9R!A('-E="!O9B!A='1R:6)U=&4*
M("`@("`J(&-R:71E<FEA+@H@("`@("H*("`@("`J($!S964@8G5I;&1!='1R
M:6)U=&51=65R>2@I"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)&-R
M:71E<FEA("`@5&AE(&%R<F%Y(&]F(&-R:71E<FEA+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'!A<F5N="`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T
M('-E87)C:&EN9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE
M=F5L<R`@4F5T=7)N(&%L;"!L979E;',L(&]R(&IU<W0@=&AE(&1I<F5C=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8VAI;&1R96X@;V8@
M)'!A<F5N=#\@1&5F875L=',@=&\@86QL(&QE=F5L<RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1R97-T<FEC="`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@
M=VET:"!T:&4@<V%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@871T<FEB=71E7VYA;64@;W(@871T<FEB=71E7VED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;W5N=$)Y071T<FEB=71E<R@D8W)I=&5R:6$L("1P87)E
M;G0@/2!$051!5%)%15]23T]4+"`D86QL3&5V96QS(#T@=')U92P@)')E<W1R
M:6-T(#T@)VYA;64G*0H@("`@>PH@("`@("`@(&EF("@A8V]U;G0H)&-R:71E
M<FEA*2D@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V%T=')I8G5T94-A8VAE*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S970@;V8@;V)J96-T(&ED
M<R!B87-E9"!O;B!A('-E="!O9B!A='1R:6)U=&4@8W)I=&5R:6$N"B`@("`@
M*@H@("`@("H@0'-E92!B=6EL9$%T=')I8G5T95%U97)Y*"D*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@("`D8W)I=&5R:6$@("`@(%1H92!A<G)A>2!O
M9B!C<FET97)I82X*("`@("`J($!P87)A;2!S=')I;F<@("1P87)E;G0@("`@
M("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN9R!F<F]M+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("!2971U<FX@86QL
M(&QE=F5L<RP@;W(@:G5S="!T:&4@9&ER96-T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&-H:6QD<F5N(&]F("1P87)E;G0_($1E9F%U
M;'1S('1O(&%L;"!L979E;',N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<F5S
M=')I8W0@("`@($]N;'D@<F5T=7)N(&%T=')I8G5T97,@=VET:"!T:&4@<V%M
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A='1R:6)U
M=&5?;F%M92!O<B!A='1R:6)U=&5?:60N"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9G)O;2`@("`@("`@(%1H92!O8FIE8W0@=&\@<W1A<G0@=&\@9F5T8VAI
M;F<*("`@("`J($!P87)A;2!I;G1E9V5R("1C;W5N="`@("`@("`@5&AE(&YU
M;6)E<B!O9B!O8FIE8W1S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<V]R=&)Y7VYA;64@($%T=')I8G5T92!N86UE('1O('5S92!F;W(@<V]R
M=&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@("1S;W)T8GE?:V5Y("`@071T
M<FEB=71E(&ME>2!T;R!U<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9&ER96-T:6]N("`@(%-O<G0@9&ER96-T:6]N.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`@+2!A<V-E;F1I;F<*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q("T@9&5S
M8V5N9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971">4%T=')I8G5T97,H
M)&-R:71E<FEA+"`D<&%R96YT(#T@1$%40512145?4D]/5"P@)&%L;$QE=F5L
M<R`]('1R=64L("1R97-T<FEC="`]("=N86UE)RP@)&9R;VT@/2`P+"`D8V]U
M;G0@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;W)T8GE?
M;F%M92`](&YU;&PL("1S;W)T8GE?:V5Y(#T@;G5L;"P@)&1I<F5C=&EO;B`]
M(#`I"B`@("!["B`@("`@("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=N;R!C<FET97)I
M82<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y7VME>7,H)'1H
M:7,M/E]A='1R:6)U=&5#86-H92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M;W)T<R!)1',@8GD@871T<FEB=71E('9A;'5E<RX@241S('=I=&AO=70@871T
M<FEB=71E<R!W:6QL(&)E"B`@("`@*B!A9&1E9"!T;R!T:&4@96YD(&]F('1H
M92!S;W)T960@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'5N
M;W)D97)E9%]I9',@($%R<F%Y(&]F(&ED<R!T;R!S;W)T+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1S;W)T8GE?;F%M92`@("!!='1R:6)U=&4@;F%M92!T;R!U
M<V4@9F]R('-O<G1I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)'-O<G1B>5]K
M97D@("`@($%T=')I8G5T92!K97D@=&\@=7-E(&9O<B!S;W)T:6YG+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1D:7)E8W1I;VX@("`@("!3;W)T(&1I<F5C=&EO
M;CH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`P("T@
M87-C96YD:6YG"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@,2`M(&1E<V-E;F1I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!3;W)T960@:61S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S;W)T0GE!='1R
M:6)U=&5S*"1U;F]R9&5R961?:61S+"`D<V]R=&)Y7VYA;64@/2!N=6QL+"`D
M<V]R=&)Y7VME>2`](&YU;&PL("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=6YO<F1E<F5D7VED<SL*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!L:7-T(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A
M;'5E<R!O9B!T:&4@9VEV96X*("`@("`J(&%T=')I8G5T92!N86UE+VME>2!C
M;VUB:6YA=&EO;BX@16ET:&5R(&%T=')I8G5T95]N86UE(&]R"B`@("`@*B!A
M='1R:6)U=&5?:V5Y($U54U0@8F4@<W5P<&QI960L(&%N9"!B;W1H($U!62!B
M92!S=7!P;&EE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1A='1R
M:6)U=&5?;F%M92`@5&AE(&YA;64@;V8@=&AE(&%T=')I8G5T92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&%T=')I8G5T95]K97D@("!4:&4@:V5Y('9A;'5E
M(&]F('1H92!A='1R:6)U=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)E
M;G0@("`@("`@("`@5&AE('!A<F5N="!N;V1E('1O('-T87)T('-E87)C:&EN
M9R!F<F]M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;$QE=F5L<R`@("`@
M(%)E='5R;B!A;&P@;&5V96QS+"!O<B!J=7-T('1H92!D:7)E8W0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C:&EL9')E;B!O9B`D
M<&%R96YT/PH@("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y
M(&]F(&%L;"!O9B!T:&4@879A:6QA8FQE('9A;'5E<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T071T<FEB=71E5F%L=65S*"1A='1R:6)U=&5?;F%M92`]
M(&YU;&PL("1A='1R:6)U=&5?:V5Y(#T@;G5L;"P@)'!A<F5N="`]($1!5$%4
M4D5%7U)/3U0L("1A;&Q,979E;',@/2!T<G5E*0H@("`@>PH@("`@("`@(')E
M='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@57!D871E('1H
M92!D871A(&EN(&%N(&]B:F5C="X@1&]E<R!N;W0@8VAA;F=E('1H92!O8FIE
M8W0G<PH@("`@("H@<&%R96YT(&]R(&YA;64L(&IU<W0@<V5R:6%L:7IE9"!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]B:F5C="`@5&AE
M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E1&%T82@D;V)J
M96-T*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;V)J96-T+"`G1&%T851R
M965/8FIE8W0G*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("!]"@H@("`@("`@("1C:60@/2`D=&AI<RT^9V5T260H)&]B:F5C="T^9V5T
M3F%M92@I*3L*("`@("`@("!I9B`H:7-?82@D8VED+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8VED.PH@("`@("`@('T*"B`@("`@
M("`@+R\@5V4@:&%N9&QE(&1A=&$@9&EF9F5R96YT;'D@:68@=V4@8V%N(&UA
M<"!I="!T;PH@("`@("`@("\O(&%T=')I8G5T97,N"B`@("`@("`@:68@*&UE
M=&AO9%]E>&ES=',H)&]B:F5C="P@)U]T;T%T=')I8G5T97,G*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V%T=')I8G5T94-A8VAE6R1C:61=(#T@)&]B:F5C
M="T^7W1O071T<FEB=71E<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T:&ES+3Y?9&%T84-A8VAE6R1C:61=(#T@)&]B:F5C="T^9V5T1&%T
M82@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,4R]C;V]R9&EN871E<RYP:'``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P-S8U,S,T(#$P-3$U-#,T,30P
M(#`R,S`T,``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&QI<W1S('1H92!L;V-A=&EO
M;G,@;V8@8VET:65S(&%R;W5N9"!T:&4@=V]R;&0N(%1H90H@*B!F;W)M870@
M:7,Z"B`J"B`J("`@)&-O;W)D:6YA=&5S6R=C;W5N=')Y;F%M92==6R=L870Z
M;&]N9R==(#T@)V-I='EN86UE)SL*("H*("H@3&%T:71U9&4@86YD(&QO;F=I
M='5D92!A<F4@9&5C:6UA;',@*'-O=71H(&%N9"!W97-T(&%R92!N96=A=&EV
M92DN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TY,4R].3%,O8V]O<F1I;F%T
M97,N<&AP+'8@,2XR+C$R+C,@,C`P-2\Q,"\Q."`Q,3HP,3HQ."!J86X@17AP
M("0*("H*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PH*)&-O;W)D:6YA=&5S
M6R=!9F=H86YI<W1A;B==6R<S,2XP,#`Z-C$N.#4P)UT@/2`G6F%R86YJ)SL*
M)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S,BXS-C<Z-C(N,3@S)UT@
M/2`G1F%R86@G.PHD8V]O<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,S+C0P
M,#HV,BXR.#,G72`]("=3:&EN9&%N9"<["B1C;V]R9&EN871E<ULG069G:&%N
M:7-T86XG75LG,S0N,C$W.C8R+C(Q-R==(#T@)TAE<F%T)SL*)&-O;W)D:6YA
M=&5S6R=!9F=H86YI<W1A;B==6R<S-"XT,S,Z-S`N-#8W)UT@/2`G2F%L86QA
M8F%D)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-"XV,S,Z-CDN
M,C`P)UT@/2`G2V%B=6P@06ER<&]R="<["B1C;V]R9&EN871E<ULG069G:&%N
M:7-T86XG75LG,S4N,3,S.C8Y+C(U,"==(#T@)TIA8G5L+5-A<F%J)SL*)&-O
M;W)D:6YA=&5S6R=!9F=H86YI<W1A;B==6R<S-BXU,#`Z-S$N,C4P)UT@/2`G
M6F5B86LG.PHD8V]O<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,V+C8V-SHV
M-2XW,3<G72`]("=3:&5B:7)G:&%N)SL*)&-O;W)D:6YA=&5S6R=!9F=H86YI
M<W1A;B==6R<S-BXW,#`Z-C<N,C`P)UT@/2`G36%Z87(M22U3:&%R:68G.PHD
M8V]O<F1I;F%T97-;)T%F9VAA;FES=&%N)UU;)S,W+C$Q-SHW,"XU,3<G72`]
M("=&86EZ86)A9"<["B1C;V]R9&EN871E<ULG06QB86YI82==6R<T,2XS,S,Z
M,3DN-S@S)UT@/2`G5&ER86YA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;
M)S(T+C4U,#HY+C0V-R==(#T@)T1J86YE="<["B1C;V]R9&EN871E<ULG06QG
M97)I82==6R<R-BXU,#`Z."XT,3<G72`]("=);&QI>FDG.PHD8V]O<F1I;F%T
M97-;)T%L9V5R:6$G75LG,C<N-C8W.BTX+C$S,R==(#T@)U1I;F1O=68G.PHD
M8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,C<N.#@S.BTP+C(X,R==(#T@)T%D
M<F%R)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S(X+C`U,#HY+C8S,R==
M(#T@)TEN($%M96YA<R<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<R.2XR
M-3`Z,"XR.#,G72`]("=4:6UI;6]U;B<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S,"XU-C<Z,BXX-C<G72`]("=%;"!';VQE82<["B1C;V]R9&EN871E
M<ULG06QG97)I82==6R<S,2XV,3<Z+3(N,C,S)UT@/2`G0F5C:&%R)SL*)&-O
M;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,Q+C8V-SHV+C$U,"==(#T@)TAA<W-I
M+4UE<W-A;W5D)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,Q+CDQ-SHU
M+C0P,"==(#T@)T]U87)G;&$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG
M,S(N,S@S.C,N.#$W)UT@/2`G1VAA<F1A:6$G.PHD8V]O<F1I;F%T97-;)T%L
M9V5R:6$G75LG,S,N,3$W.C8N,3,S)UT@/2`G5&]U9V=O=7)T)SL*)&-O;W)D
M:6YA=&5S6R=!;&=E<FEA)UU;)S,S+C4P,#HV+C$Q-R==(#T@)T5L($]U960G
M.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S,N-S8W.C(N.3,S)UT@/2`G
M3&%G:&]U870G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S0N-C@S.C,N
M,C4P)UT@/2`G1&IE;&9A)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,T
M+C@P,#HU+C<S,R==(#T@)T)I<VMR82<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S-"XY,S,Z+3`N-#,S)UT@/2`G365C:&5R:6$G.PHD8V]O<F1I;F%T
M97-;)T%L9V5R:6$G75LG,S4N,#$W.BTQ+C0V-R==(#T@)U1L96UC96X@6F5N
M871A)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C(P,#HM,"XQ,S,G
M72`]("=-87-C87)A+4=H<FES<R<["B1C;V]R9&EN871E<ULG06QG97)I82==
M6R<S-2XR-3`Z,2XT,S,G72`]("=4:6%R970G.PHD8V]O<F1I;F%T97-;)T%L
M9V5R:6$G75LG,S4N,S,S.C0N,C`P)UT@/2`G0F]U+5-A861A)SL*)&-O;W)D
M:6YA=&5S6R=!;&=E<FEA)UU;)S,U+C0X,SHX+C$S,R==(#T@)U1E8F5S<V$G
M.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S4N-34P.C8N,3@S)UT@/2`G
M0F%T;F$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S4N-C,S.BTP+C8P
M,"==(#T@)T]R86X@+R!%<R!396YI82<["B1C;V]R9&EN871E<ULG06QG97)I
M82==6R<S-BXQ.#,Z-2XT,3<G72`]("=3971I9B<["B1C;V]R9&EN871E<ULG
M06QG97)I82==6R<S-BXR,3<Z,2XS,S,G72`]("=#:&QE9B<["B1C;V]R9&EN
M871E<ULG06QG97)I82==6R<S-BXR.#,Z-BXV,3<G72`]("=#;VYS=&%N=&EN
M92<["B1C;V]R9&EN871E<ULG06QG97)I82==6R<S-BXW,3<Z,RXR-3`G72`]
M("=$87(M16PM0F5I9&$G.PHD8V]O<F1I;F%T97-;)T%L9V5R:6$G75LG,S8N
M-S$W.C4N,#8W)UT@/2`G0F5J86EA)SL*)&-O;W)D:6YA=&5S6R=!;&=E<FEA
M)UU;)S,V+C@S,SHW+C@Q-R==(#T@)T%N;F%B82<["B1C;V]R9&EN871E<ULG
M06QG97)I82==6R<S-BXX.#,Z-2XX,3<G72`]("=*:6IE;"!!8VAO=6%T)SL*
M)&-O;W)D:6YA=&5S6R=!;&=E<FEA)UU;)S,V+CDS,SHV+CDU,"==(#T@)U-K
M:6MD82<["B1C;V]R9&EN871E<ULG06YG;VQA)UU;)RTQ,BXS.#,Z,38N.34P
M)UT@/2`G0FEE(%-I;'9A(%!O<G1O)SL*)&-O;W)D:6YA=&5S6R=!;F=O;&$G
M75LG+3$R+C4X,SHQ,RXT,3<G72`]("=-;VYB86-A($)E;F=U96QA)SL*)&-O
M;W)D:6YA=&5S6R=!;F=O;&$G75LG+3$R+C@P,#HQ-2XW-3`G72`]("=(=6%M
M8F\@3F]V82!,:7-B;V$G.PHD8V]O<F1I;F%T97-;)T%N9V]L82==6R<M-2XU
M-3`Z,3(N,3@S)UT@/2`G0V%B:6YD82<["B1C;V]R9&EN871E<ULG06YG;VQA
M)UU;)RTX+C@U,#HQ,RXR,S,G72`]("=,=6%N9&$G.PHD8V]O<F1I;F%T97-;
M)T%N=&%R8W1I8V$G75LG+3<W+C@V-SHQ-C8N.38W)UT@/2`G5VEL;&EA;7,@
M1FEE;&0G.PHD8V]O<F1I;F%T97-;)T%N=&%R8W1I8V$G75LG+3DP+C`P,#HP
M+C`P,"==(#T@)T%M=6YD<V5N+5-C;W1T(%-O=71H(%!O;&4@4W1A=&EO;B<[
M"B1C;V]R9&EN871E<ULG06YT:6=U82!A;F0@0F%R8G5D82==6R<Q-RXQ,3<Z
M+38Q+C<X,R==(#T@)U9C($)I<F0@26YT97)N871I;VYA;"!!:7)P;W)T($%N
M=&EG=6$G.PHD8V]O<F1I;F%T97-;)T%N=&EG=6$@86YD($)A<F)U9&$G75LG
M,3<N,C`P.BTV,BXU.#,G72`]("=#:&%R;&5S=&]W;B`O($YE=V-A<W0G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C(N,3`P.BTV-2XV,#`G72`]
M("=,82!1=6EA8V$@3V)S97)V871O<FEO)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3(R+C8U,#HM-C,N.#$W)UT@/2`G5&%R=&%G86P@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(S+C$U,#HM-C0N
M,S$W)UT@/2`G3W)A;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,C0N,38W.BTV,BXY,#`G72`]("=2:79A9&%V:6$G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,C0N,S@S.BTV-2XP.#,G72`]("=*
M=6IU>2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M,C0N-S`P.BTV,"XU.#,G72`]("=,87,@3&]M:71A<R<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTR-"XX-3`Z+38U+C0X,R==(#T@)U-A;'1A($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-2XW,S,Z
M+34T+C0V-R==(#T@)TEG=6%Z=2!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M,C8N,C`P.BTU."XR,S,G72`]("=&;W)M;W-A($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR-BXX,3<Z
M+38P+C0U,"==(#T@)U!R97-I9&5N8VEA(%)O<75E(%-A96YZ(%!E;F$@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(V+C@U,#HM
M-C4N,3`P)UT@/2`G5'5C=6UA;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M,C<N,S8W.BTU-2XY-C<G72`]("=0;W-A9&%S($%E
M<F\N)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(W+C0U,#HM-3@N
M-S8W)UT@/2`G0V]R<FEE;G1E<R!!97)O+B<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR-RXT-3`Z+34Y+C`U,"==(#T@)U)E<VES=&5N8VEA($%E
M<F\N)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(W+C<V-SHM-C0N
M,S`P)UT@/2`G4V%N=&EA9V\@1&5L($5S=&5R;R!!97)O+B<["B1C;V]R9&EN
M871E<ULG07)G96YT:6YA)UU;)RTR."XP-C<Z+38W+C4V-R==(#T@)U1I;F]G
M87-T82<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR."XV,#`Z+38U
M+C<V-R==(#T@)T-A=&%M87)C82!!97)O+B<["B1C;V]R9&EN871E<ULG07)G
M96YT:6YA)UU;)RTR.2XR,3<Z+38W+C0S,R==(#T@)T-H:6QE8VET;R<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR.2XS.#,Z+38V+C@Q-R==(#T@
M)TQA(%)I;VIA($%E<F\N)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3(Y+C8X,SHM-3<N,34P)UT@/2`G4&%S;R!$92!,;W,@3&EB<F5S($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTR.2XW.#,Z+34W
M+CDX,R==(#T@)T-U<G5Z=2!#=6%T:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3(Y+C@X,SHM-C$N.34P)UT@/2`G0V5R97,@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3(Y+CDP
M,#HM-C,N-C@S)UT@/2`G5FEL;&$@1&4@36%R:6$@1&5L(%)I;R!396-O)SL*
M)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,P+C(U,#HM-C@N-S4P)UT@
M/2`G2F%C:&%L)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,P+C(V
M-SHM-3<N-C4P)UT@/2`G36]N=&4@0V%S97)O<R!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N,S`P.BTU."XP,3<G72`]("=#
M;VYC;W)D:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+3,Q+C,Q-SHM-C0N,C$W)UT@/2`G0V]R9&]B82!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N,S,S.BTV-BXV,#`G72`]
M("=#:&5P97,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N-38W
M.BTV."XX-C<G72`]("=386X@2G5A;B!!97)O9')O;64G.PHD8V]O<F1I;F%T
M97-;)T%R9V5N=&EN82==6R<M,S$N-C8W.BTV,RXX.#,G72`]("=0:6QA<B!/
M8G-E<G9A=&]R:6\G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N
M-S`P.BTV,"XX,3<G72`]("=3875C92!6:65J;R!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S$N-S@S.BTV,"XT.#,G72`]("=0
M87)A;F$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG
M+3,Q+C@U,#HM-3DN,#@S)UT@/2`G5FEL;&%G=6%Y($%E<F]D<F]M92<["B1C
M;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,2XY-3`Z+38U+C$S,R==(#T@
M)U9I;&QA($1O;&]R97,@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,R+C8P,#HM-CDN,S,S)UT@/2`G57-P86QL871A)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,R+C<P,#HM-C(N,34P)UT@/2`G
M36%R8V]S($IU87)E>B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,S(N.#,S.BTV."XW.#,G72`]("=-96YD;WIA($%E<F]D<F]M
M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,BXY,3<Z+38P+C<X
M,R==(#T@)U)O<V%R:6\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E
M;G1I;F$G75LG+3,S+C`P,#HM-3@N-C$W)UT@/2`G1W5A;&5G=6%Y8VAU($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXP.#,Z
M+38X+C0Q-R==(#T@)U-A;B!-87)T:6XG.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,S,N,3$W.BTV-"XR,S,G72`]("=2:6\@0W5A<G1O($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS,RXR-C<Z+38V
M+C,U,"==(#T@)U-A;B!,=6ES($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTS,RXW,S,Z+38U+C,X,R==(#T@)U9I;&QA(%)E>6YO
M;&1S($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS
M,RXW-C<Z+38Y+C`S,R==(#T@)U-A;B!#87)L;W,G.PHD8V]O<F1I;F%T97-;
M)T%R9V5N=&EN82==6R<M,S0N,3,S.BTV,RXS-C<G72`]("=,86)O=6QA>64G
M.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S0N-#@S.BTU."XV,3<G
M72`]("=$;VX@5&]R8W5A=&\@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+3,T+C4U,#HM-C`N.3$W)UT@/2`G2G5N:6X@065R;V1R
M;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,T+C4V-SHM-3@N
M-#$W)UT@/2`G065R;W!A<G%U92!"<RX@07,N($%E<F]D<F]M92<["B1C;V]R
M9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XU.#,Z+34X+C0X,R==(#T@)T)U
M96YO<R!!:7)E<R!/8G-E<G9A=&]R:6\G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M,S0N-3@S.BTV."XT,#`G72`]("=386X@4F%F865L($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XV,#`Z+34X
M+C8P,"==(#T@)T5L(%!A;&]M87(@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!<F=E;G1I;F$G75LG+3,T+C@Q-SHM-3@N-3,S)UT@/2`G17IE:7IA($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-"XY-C<Z
M+34W+CDP,"==(#T@)TQA(%!L871A($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTS-2XU,#`Z+38Y+C4X,R==(#T@)TUA;&%R9W5E
M($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTS-2XW
M,#`Z+38S+C<U,"==(#T@)T=E;F5R86P@4&EC;R!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S4N.#8W.BTV,2XY,#`G72`]("=0
M96AU86IO($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;
M)RTS-BXS-3`Z+34W+C<S,R==(#T@)T1O;&]R97,@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,V+C4V-SHM-C0N,C8W)UT@/2`G
M4V%N=&$@4F]S82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN
M82==6R<M,S8N-S4P.BTU.2XX,S,G72`]("=!>G5L($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S<N,C,S.BTU-RXP,S,G72`]("=6
M:6QL82!'97-E;&PG.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S<N
M,C,S.BTU.2XR-3`G72`]("=486YD:6P@065R;V1R;VUE)SL*)&-O;W)D:6YA
M=&5S6R=!<F=E;G1I;F$G75LG+3,W+C8P,#HM-C(N,S@S)UT@/2`G4&EG=64@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,W+CDS
M,SHM-3<N-3@S)UT@/2`G36%R($1E;"!0;&%T82!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S@N,S,S.BTV,"XR-3`G72`]("=4
M<F5S($%R<F]Y;W,G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M,S@N
M-S,S.BTV,BXQ-C<G72`]("="86AI82!";&%N8V$@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+3,X+CDU,#HM-C@N,3,S)UT@/2`G
M3F5U<75E;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==
M6R<M,SDN,#$W.BTV-"XP.#,G72`]("=2:6\@0V]L;W)A9&\G.PHD8V]O<F1I
M;F%T97-;)T%R9V5N=&EN82==6R<M-#`N,#@S.BTW,2XQ,S,G72`]("=#:&%P
M96QC;R<["B1C;V]R9&EN871E<ULG07)G96YT:6YA)UU;)RTT,"XW.#,Z+38U
M+C$P,"==(#T@)U-A;B!!;G1O;FEO($]E<W1E($%E<F]D<F]M92<["B1C;V]R
M9&EN871E<ULG07)G96YT:6YA)UU;)RTT,"XX-3`Z+38S+C`Q-R==(#T@)U9I
M961M82!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M
M-#$N,34P.BTW,2XQ-C<G72`]("="87)I;&]C:&4@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+30Q+CDV-SHM-S$N-3$W)UT@/2`G
M16P@0F]L<V]N($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG07)G96YT:6YA
M)UU;)RTT,BXY,S,Z+3<Q+C$U,"==(#T@)T5S<75E;"!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#,N,C`P.BTV-2XR-C<G72`]
M("=4<F5L97<@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G
M75LG+30S+C@Q-SHM-C@N.#@S)UT@/2`G4&%S;R!$92!);F1I;W,G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#4N-S@S.BTV-RXU,#`G72`]("=#
M;VUO9&]R;R!2:79A9&%V:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!
M<F=E;G1I;F$G75LG+30V+C4Q-SHM-S$N,#$W)UT@/2`G4&5R:71O($UO<F5N
M;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#<N
M-S,S.BTV-2XY,3<G72`]("=0=65R=&\@1&5S96%D;R!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-#@N-S@S.BTW,"XQ-C<G72`]
M("=';V)E<FYA9&]R($=R96=O<F5S($%E<F]D<F]M92<["B1C;V]R9&EN871E
M<ULG07)G96YT:6YA)UU;)RTT.2XS,3<Z+38W+C<U,"==(#T@)U-A;B!*=6QI
M86X@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34P
M+C`Q-SHM-C@N-38W)UT@/2`G4V%N=&$@0W)U>B!!97)O9')O;64G.PHD8V]O
M<F1I;F%T97-;)T%R9V5N=&EN82==6R<M-3`N,S,S.BTW,BXS,#`G72`]("=,
M86=O($%R9V5N=&EN;R!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%R9V5N
M=&EN82==6R<M-3$N-C$W.BTV.2XR.#,G72`]("=2:6\@1V%L;&5G;W,@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<F=E;G1I;F$G75LG+34S+C@P,#HM
M-C<N-S4P)UT@/2`G4FEO($=R86YD92!"+B!!+B<["B1C;V]R9&EN871E<ULG
M07)G96YT:6YA)UU;)RTU-"XX,#`Z+38X+C,Q-R==(#T@)U5S:'5A:6$@065R
M;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!<FUE;FEA)UU;)S0P+C$S,SHT-"XT
M-C<G72`]("=997)E=F%N)SL*)&-O;W)D:6YA=&5S6R=!<G5B82==6R<Q,BXU
M,#`Z+3<P+C`Q-R==(#T@)U%U965N($)E871R:7@@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTQ,BXR-C<Z,3,V+C@Q-R==(#T@)T=O
M=F4@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ,BXT
M,#`Z,3,P+C@V-R==(#T@)T1A<G=I;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+3$R+C8S,SHQ-#$N.#@S)UT@/2`G5V5I<&$@0VET
M>2<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTQ-2XW-C<Z,3(X+C<P
M,"==(#T@)TMU;G5N=7)R82!+=6YU;G5R<F$@07=S)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+3$V+C@X,SHQ-#4N-S4P)UT@/2`G0V%I<FYS($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3<N,S`P.C$R
M,RXV,3<G72`]("=$97)B>2<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTQ-RXY-3`Z,3(R+C(Q-R==(#T@)T)R;V]M92!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<F%L:6$G75LG+3$Y+C(U,#HQ-#8N-S4P)UT@/2`G5&]W
M;G-V:6QL92!!;6\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,3DN
M-C,S.C$S-"XQ-C<G72`]("=496YN86YT($-R965K($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C`N,3`P.C$Q.2XU-C<G72`]("=0
M;W)T($AE9&QA;F0@4&%R9&]O)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3(P+C0X,SHQ-#@N-3,S)UT@/2`G4')O<V5R<&EN92!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(P+C8V-SHQ,SDN-#8W)UT@
M/2`G36]U;G0@27-A($%M;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTR,2XQ,3<Z,30Y+C(P,"==(#T@)TUA8VMA>2!-;R<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTR,BXR,S,Z,3$T+C`X,R==(#T@)TQE87)M;VYT
M:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(S+C,X
M,SHQ-3`N-#8W)UT@/2`G4F]C:VAA;7!T;VX@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG075S=')A;&EA)UU;)RTR,RXT,S,Z,30T+C(V-R==(#T@)TQO;F=R
M96%C:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(S
M+C@P,#HQ,S,N.#@S)UT@/2`G06QI8V4@4W!R:6YG<R!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C,N.#4P.C$U,2XR-3`G72`]
M("=';&%D<W1O;F4G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C4N
M,3@S.C$S,"XY-C<G72`]("=9=6QA<F$@07=S)SL*)&-O;W)D:6YA=&5S6R=!
M=7-T<F%L:6$G75LG+3(V+C0P,#HQ-#8N,C8W)UT@/2`G0VAA<FQE=FEL;&4@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTR-BXV,#`Z
M,3$X+C4S,R==(#T@)TUE96MA=&AA<G)A($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,C<N,S@S.C$U,RXQ,#`G72`]("="<FES8F%N
M92!!:7)P;W)T($TN($\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M
M,C<N-#$W.C$U,2XW,S,G72`]("=/86ME>2!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)T%U<W1R86QI82==6R<M,C<N-38W.C$U,RXP,#`G72`]("=!<F-H
M97)F:65L9"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,C<N-C,S.C$U,BXW,3<G72`]("=!;6)E<FQE>2!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,C@N,38W.C$U,RXU,#`G72`]
M("=#;V]L86YG871T82!!:7)P;W)T($%W<R<["B1C;V]R9&EN871E<ULG075S
M=')A;&EA)UU;)RTR."XW.#,Z,3$T+C<P,"==(#T@)T=E<F%L9'1O;B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3(Y+C`S,SHQ-C<N
M.3,S)UT@/2`G3F]R9F]L:R!)<VQA;F0@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTS,"XS,3<Z,34S+C$Q-R==(#T@)T-O9F9S($AA
M<F)O=7(@36\G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S`N-3@S
M.C$S."XT,3<G72`]("=,96EG:"!#<F5E:R!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=!=7-T<F%L:6$G75LG+3,P+C<X,SHQ,C$N-#4P)UT@/2`G2V%L9V]O
M<FQI92!";W5L9&5R($%M;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTS,"XX,S,Z,3(X+C$P,"==(#T@)T9O<G)E<W0@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTS,2XP.#,Z,34P+C@S,R==(#T@)U1A
M;7=O<G1H($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M
M,S$N,3,S.C$S-BXX,3<G72`]("=7;V]M97)A($%E<F]D<F]M92<["B1C;V]R
M9&EN871E<ULG075S=')A;&EA)UU;)RTS,2XV-C<Z,3$V+C`Q-R==(#T@)T)U
M;&QS8G)O;VL@4&5A<F-E($%M;R<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTS,2XY,S,Z,3$U+CDU,"==(#T@)T)E;&UO;G0@4&5R=&@@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,2XY-C<Z,30Q+C0V
M-R==(#T@)T)R;VME;B!(:6QL(%!A='1O;B!3=')E970G.PHD8V]O<F1I;F%T
M97-;)T%U<W1R86QI82==6R<M,S(N,3$W.C$S,RXW,#`G72`]("=#961U;F$@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,BXR,#`Z
M,30X+C4V-R==(#T@)T1U8F)O)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G
M75LG+3,R+C<X,SHQ-3$N.#$W)UT@/2`G5VEL;&EA;71O=VX@065R;V1R;VUE
M)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,S+C8P,#HQ-3`N-S@S
M)UT@/2`G4FEC:&UO;F0@075S+4%F8B<["B1C;V]R9&EN871E<ULG075S=')A
M;&EA)UU;)RTS,RXY,3<Z,34P+CDX,R==(#T@)T)A;FMS=&]W;B!!:7)P;W)T
M($%W<R<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS,RXY-3`Z,34Q
M+C$X,R==(#T@)U-Y9&YE>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3,T+C`S,SHQ-3`N-C@S)UT@/2`G0V%M9&5N($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S0N,C$W.C$T,BXP.#,G
M72`]("=-:6QD=7)A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI
M82==6R<M,S0N-S`P.C$S."XV,3<G72`]("=%9&EN8G5R9V@@32X@3RXG.PHD
M8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S0N-S@S.C$S."XV,S,G72`]
M("=087)A9FEE;&0@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA
M)UU;)RTS-"XY,S,Z,3$W+C@P,"==(#T@)T%L8F%N>2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,T+CDS,SHQ,S@N-3$W)UT@/2`G
M061E;&%I9&4@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;
M)RTS-"XY-3`Z,34P+C4S,R==(#T@)TYO=W)A(%)A;B!!:7(@4W1A=&EO;B<[
M"B1C;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-2XQ-3`Z,30W+C0U,"==
M(#T@)U=A9V=A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S4N,S`P.C$T.2XQ.#,G72`]("=#86YB97)R82<["B1C;V]R9&EN871E
M<ULG075S=')A;&EA)UU;)RTS-BXP-C<Z,30V+CDU,"==(#T@)T%L8G5R>2!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+3,V+C(S,SHQ
M-#DN,#@S)UT@/2`G0V]O;6$G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==
M6R<M,S<N-C8W.C$T-"XX,S,G72`]("=-96QB;W5R;F4@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG075S=')A;&EA)UU;)RTS-RXW,S,Z,30P+C<X,R==(#T@
M)TUO=6YT($=A;6)I97(@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=!=7-T
M<F%L:6$G75LG+3,W+C<S,SHQ-#4N-#`P)UT@/2`G1V]L9'-T<F5A;2!!=W,G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S<N.#4P.C$T-"XW,S,G
M72`]("=,879E<G1O;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M,S<N.38W.C$T-2XQ,#`G72`]("=-;V]R86)B:6X@06ER<&]R
M="!!=W,G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M,S@N,3`P.C$T
M-RXQ,S,G72`]("=%87-T(%-A;&4@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S
M6R=!=7-T<F%L:6$G75LG+30P+CDX,SHQ-#4N-S$W)UT@/2`G5WEN>6%R9"!7
M97-T)SL*)&-O;W)D:6YA=&5S6R=!=7-T<F%L:6$G75LG+30Q+C$V-SHQ-#8N
M,S8W)UT@/2`G1&5V;VYP;W)T($5A<W0G.PHD8V]O<F1I;F%T97-;)T%U<W1R
M86QI82==6R<M-#$N-3,S.C$T-RXR,#`G72`]("=,875N8V5S=&]N($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T%U<W1R86QI82==6R<M-#(N.#,S.C$T-RXT
M.#,G72`]("=(;V)A<G0@06ER<&]R="<["B1C;V]R9&EN871E<ULG075S=')A
M;&EA)UU;)RTU-"XT.#,Z,34X+CDU,"==(#T@)TUA8W%U87)I92!)<VQA;F0G
M.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#8N-C4P.C$T+C,S,R==(#T@
M)TML86=E;F9U<G0M1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R=!=7-T<FEA
M)UU;)S0W+C`P,#HQ-2XT,S,G72`]("='<F%Z+51H86QE<FAO9BU&;'5G:&%F
M96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N,C`P.C$T+C<U,"==
M(#T@)UIE;'1W96<G.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG-#<N,C8W
M.C$Q+C,U,"==(#T@)TEN;G-B<G5C:RU&;'5G:&%F96XG.PHD8V]O<F1I;F%T
M97-;)T%U<W1R:6$G75LG-#<N,S,S.C$Q+C<P,"==(#T@)U-C:'=A>B!(96QI
M<&]R="<["B1C;V]R9&EN871E<ULG075S=')I82==6R<T-RXU,S,Z,30N,3,S
M)UT@/2`G06EG96X@26T@16YN<W1A;"<["B1C;V]R9&EN871E<ULG075S=')I
M82==6R<T-RXX,#`Z,3,N,#`P)UT@/2`G4V%L>F)U<F<M1FQU9VAA9F5N)SL*
M)&-O;W)D:6YA=&5S6R=!=7-T<FEA)UU;)S0W+CDV-#HQ-BXR-3DG72`]("=.
M:65D97)O<W1E<G)E:6-H("\@3'5G<&QA='H@(%9O<VQA=2<["B1C;V]R9&EN
M871E<ULG075S=')I82==6R<T."XQ,3<Z,38N-38W)UT@/2`G5VEE;B`O(%-C
M:'=E8VAA="U&;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G75LG
M-#@N,C,S.C$T+C$X,R==(#T@)TAO<G-C:&EN9R!!=7,M069B)SL*)&-O;W)D
M:6YA=&5S6R=!=7-T<FEA)UU;)S0X+C(S,SHQ-"XQ.#,G72`]("=,:6YZ("\@
M2&]E<G-C:&EN9RU&;'5G:&%F96XG.PHD8V]O<F1I;F%T97-;)T%U<W1R:6$G
M75LG-#@N,S$W.C$V+C$Q-R==(#T@)U1U;&QN)SL*)&-O;W)D:6YA=&5S6R=!
M>F5R8F%I:F%N)UU;)S0P+C0U,#HU,"XP-C<G72`]("="86MU("\@0FEN92!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S)UU;)S(P+CDU,#HM-S,N
M-C@S)UT@/2`G36%T=&AE=R!4;W=N+"!);F%G=6$G.PHD8V]O<F1I;F%T97-;
M)T)A:&%M87,G75LG,C,N-#<U.BTW-2XW-C<G72`]("='96]R9V5T;W=N+"!%
M>'5M82<["B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-"XP-3`Z+3<T+C4S
M,R==(#T@)T-O8VMB=7)N(%1O=VXL(%-A;B!386QV861O<B<["B1C;V]R9&EN
M871E<ULG0F%H86UA<R==6R<R-2XP-3`Z+3<W+C0V-R==(#T@)TYA<W-A=2!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="86AA;6%S)UU;)S(U+C<S,SHM-SDN
M,S`P)UT@/2`G06QI8V4@5&]W;BP@0FEM:6YI)SL*)&-O;W)D:6YA=&5S6R="
M86AA;6%S)UU;)S(V+C4U,#HM-S@N-S`P)UT@/2`G1G)E97!O<G0L($=R86YD
M($)A:&%M82<["B1C;V]R9&EN871E<ULG0F%H86UA<R==6R<R-BXW,#`Z+3<X
M+CDV-R==(#T@)U=E<W0@16YD+"!'<F%N9"!"86AA;6$G.PHD8V]O<F1I;F%T
M97-;)T)A:')A:6XG75LG,C8N,C8W.C4P+C8U,"==(#T@)T)A:')A:6X@26YT
M97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H
M)UU;)S(Q+C0S,SHY,2XY-C<G72`]("=#;WA<)W,@0F%Z87(G.PHD8V]O<F1I
M;F%T97-;)T)A;F=L861E<V@G75LG,C(N,C8W.CDQ+C@Q-R==(#T@)T-H:71T
M86=O;F<@4&%T96YG82<["B1C;V]R9&EN871E<ULG0F%N9VQA9&5S:"==6R<R
M,RXQ.#,Z.#DN,38W)UT@/2`G2F5S<V]R92<["B1C;V]R9&EN871E<ULG0F%N
M9VQA9&5S:"==6R<R,RXW-C<Z.3`N,S@S)UT@/2`G1&AA:V$G.PHD8V]O<F1I
M;F%T97-;)T)A;F=L861E<V@G75LG,C,N.#4P.CDP+C0P,"==(#T@)TMU<FUI
M=&]L82P@1&EA)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D97-H)UU;)S(T+C$S
M,SHX.2XP-3`G72`]("=)<VAU<F1I)SL*)&-O;W)D:6YA=&5S6R="86YG;&%D
M97-H)UU;)S(T+C,V-SHX."XW,#`G72`]("=286IS:&%H:2<["B1C;V]R9&EN
M871E<ULG0F%N9VQA9&5S:"==6R<R-"XY,#`Z.3$N.#@S)UT@/2`G4WEL:&5T
M)SL*)&-O;W)D:6YA=&5S6R="87)B861O<R==6R<Q,RXP-C<Z+34Y+C0X,R==
M(#T@)T=R86YT;&5Y($%D86US)SL*)&-O;W)D:6YA=&5S6R="96QA<G5S)UU;
M)S4S+CDS,SHR-RXV,S,G72`]("=-:6YS:R<["B1C;V]R9&EN871E<ULG0F5L
M87)U<R==6R<U-2XQ-C<Z,S`N,C$W)UT@/2`G5FET96)S:R<["B1C;V]R9&EN
M871E<ULG0F5L9VEU;2==6R<T.2XY,#`Z-2XR,3<G72`]("="97)T<FEX($)E
M;"U!9F(G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N,#,S.C4N-#`P
M)UT@/2`G4W0M2'5B97)T)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P
M+C(S,SHT+C8U,"==(#T@)T9L;W)E;FYE<R<["B1C;V]R9&EN871E<ULG0F5L
M9VEU;2==6R<U,"XT-C<Z-"XT-3`G72`]("=#:&%R;&5R;VD@+R!';W-S96QI
M97,G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N-#8W.C8N,3@S)UT@
M/2`G16QS96YB;W)N)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+C0X
M,SHU+CDQ-R==(#T@)U-P82`O($QA(%-A=79E;FEE<F4G.PHD8V]O<F1I;F%T
M97-;)T)E;&=I=6TG75LG-3`N-38W.C,N.#,S)UT@/2`G0VAI979R97,G.PHD
M8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3`N-C4P.C4N-#4P)UT@/2`G0FEE
M<G-E="<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XW-3`Z-"XW-C<G
M72`]("="96%U=F5C:&%I;B<["B1C;V]R9&EN871E<ULG0F5L9VEU;2==6R<U
M,"XW.#,Z-"XY-3`G72`]("=';V5T<V5N:&]V96XG.PHD8V]O<F1I;F%T97-;
M)T)E;&=I=6TG75LG-3`N.#`P.C4N,C`P)UT@/2`G4VEN="U4<G5I9&5N)SL*
M)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P+CDP,#HT+C4P,"==(#T@)TUE
M;'-B<F]E:R!"96PM069B)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4P
M+CDP,#HT+C4S,R==(#T@)T)R=7AE;&QE<R!.871I;VYA;"<["B1C;V]R9&EN
M871E<ULG0F5L9VEU;2==6R<U,"XY,S,Z,RXW,S,G72`]("=-=6YT92<["B1C
M;V]R9&EN871E<ULG0F5L9VEU;2==6R<U,"XY,S,Z-2XU,#`G72`]("='96YK
M)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C`P,#HU+C`V-R==(#T@
M)U-C:&%F9F5N)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C`X,SHR
M+C8U,"==(#T@)TMO:W-I:F1E)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;
M)S4Q+C$V-SHU+C0V-R==(#T@)TML96EN92!"<F]G96PG.PHD8V]O<F1I;F%T
M97-;)T)E;&=I=6TG75LG-3$N,3@S.C,N.#$W)UT@/2`G1V5N="`O($EN9'5S
M=')I92U:;VYE)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C(P,#HR
M+C@V-R==(#T@)T]O<W1E;F1E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)E
M;&=I=6TG75LG-3$N,C`P.C0N-#8W)UT@/2`G06YT=V5R<&5N("\@1&5U<FYE
M)SL*)&-O;W)D:6YA=&5S6R="96QG:75M)UU;)S4Q+C,S,SHT+C4P,"==(#T@
M)T)R87-S8VAA870G.PHD8V]O<F1I;F%T97-;)T)E;&=I=6TG75LG-3$N-#$W
M.C4N,#`P)UT@/2`G5V5E;&1E($UI;&ET87)Y)SL*)&-O;W)D:6YA=&5S6R="
M96QI>F4G75LG,3<N-3,S.BTX."XS,#`G72`]("="96QI>F4@+R!0:&EL;&EP
M($=O;&1S=&]N($EN=&PN($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)E;FEN
M)UU;)S$P+C,Q-SHQ+C,X,R==(#T@)TYA=&ET:6YG;W4G.PHD8V]O<F1I;F%T
M97-;)T)E;FEN)UU;)S$Q+C$S,SHR+CDS,R==(#T@)TMA;F1I)SL*)&-O;W)D
M:6YA=&5S6R="96YI;B==6R<V+C,U,#HR+C,X,R==(#T@)T-O=&]N;W4G.PHD
M8V]O<F1I;F%T97-;)T)E;FEN)UU;)S<N,38W.C(N,#8W)UT@/2`G0F]H:6-O
M;B<["B1C;V]R9&EN871E<ULG0F5N:6XG75LG."XP,S,Z,BXT-C<G72`]("=3
M879E)SL*)&-O;W)D:6YA=&5S6R="96YI;B==6R<Y+C,U,#HR+C8Q-R==(#T@
M)U!A<F%K;W4G.PHD8V]O<F1I;F%T97-;)T)E<FUU9&$G75LG,S(N,S8W.BTV
M-"XV.#,G72`]("="97)M=61A)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;
M)RTQ,"XX,3<Z+38U+C,U,"==(#T@)T=U87EA<F%M97)I;B<["B1C;V]R9&EN
M871E<ULG0F]L:79I82==6R<M,3$N,#`P.BTV-BXQ,3<G72`]("=2:6)E<F%L
M=&$G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$Q+C`S,SHM-C@N-S@S
M)UT@/2`G0V]B:6IA)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ,RXP
M-C<Z+38T+C@Q-R==(#T@)U-A;B!*;V%Q=6EN)SL*)&-O;W)D:6YA=&5S6R="
M;VQI=FEA)UU;)RTQ,RXS,S,Z+38T+C$Q-R==(#T@)TUA9V1A;&5N82<["B1C
M;V]R9&EN871E<ULG0F]L:79I82==6R<M,3,N-S8W.BTV-2XT,S,G72`]("=3
M86YT82!!;F$G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3$T+C,Q-SHM
M-C<N,S@S)UT@/2`G4F5Y97,G.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG
M+3$T+C0V-SHM-C<N-38W)UT@/2`G4G5R<F5N86)A<75E)SL*)&-O;W)D:6YA
M=&5S6R=";VQI=FEA)UU;)RTQ-"XW,S,Z+38X+C4P,"==(#T@)T%P;VQO)SL*
M)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-"XX,3<Z+38T+CDQ-R==(#T@
M)U1R:6YI9&%D)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-"XX-C<Z
M+38V+C@V-R==(#T@)U-A;B!";W)J82<["B1C;V]R9&EN871E<ULG0F]L:79I
M82==6R<M,30N.3$W.BTV-2XV,#`G72`]("=386X@26=N86-I;R!$92!-;WAO
M<R<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,34N-S$W.BTV,RXQ,#`G
M72`]("=!<V-E;F-I;VX@1&4@1W5A<F%Y;W,G.PHD8V]O<F1I;F%T97-;)T)O
M;&EV:6$G75LG+3$V+C$U,#HM-C(N,#$W)UT@/2`G0V]N8V5P8VEO;B<["B1C
M;V]R9&EN871E<ULG0F]L:79I82==6R<M,38N,C8W.BTV,BXT-C<G72`]("=3
M86X@2F%V:65R)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-BXS.#,Z
M+38P+CDV-R==(#T@)U-A;B!)9VYA8VEO($1E(%9E;&%S8V\G.PHD8V]O<F1I
M;F%T97-;)T)O;&EV:6$G75LG+3$V+C4Q-SHM-C@N,3@S)UT@/2`G3&$@4&%Z
M("\@06QT;R<["B1C;V]R9&EN871E<ULG0F]L:79I82==6R<M,3<N-#$W.BTV
M-BXQ.#,G72`]("=#;V-H86)A;6)A)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA
M)UU;)RTQ-RXU.#,Z+38Y+C8P,"==(#T@)T-H87)A;F$G.PHD8V]O<F1I;F%T
M97-;)T)O;&EV:6$G75LG+3$W+C8S,SHM-C,N,3,S)UT@/2`G5FER=2U6:7)U
M)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-RXX,#`Z+38P+C<S,R==
M(#T@)U-A;B!*;W-E($1E($-H:7%U:71O<R<["B1C;V]R9&EN871E<ULG0F]L
M:79I82==6R<M,3<N.#`P.BTV,RXQ.#,G72`]("=386YT82!#<G5Z("\@16P@
M5')O;7!I;&QO)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ-RXY-C<Z
M+38W+C`V-R==(#T@)T]R=7)O)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;
M)RTQ."XS,3<Z+34Y+C<V-R==(#T@)U)O8F]R92<["B1C;V]R9&EN871E<ULG
M0F]L:79I82==6R<M,3@N.3@S.BTU-RXX,3<G72`]("=0=65R=&\@4W5A<F5Z
M)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ.2XP,3<Z+38U+C,P,"==
M(#T@)U-U8W)E)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTQ.2XU-3`Z
M+38U+C<S,R==(#T@)U!O=&]S:2<["B1C;V]R9&EN871E<ULG0F]L:79I82==
M6R<M,C`N,#`P.BTV,RXU,S,G72`]("=#86UI<FDG.PHD8V]O<F1I;F%T97-;
M)T)O;&EV:6$G75LG+3(Q+C(U,#HM-C,N-#4P)UT@/2`G5FEL;&%M;VYT97,G
M.PHD8V]O<F1I;F%T97-;)T)O;&EV:6$G75LG+3(Q+C4U,#HM-C0N-S`P)UT@
M/2`G5&%R:6IA)SL*)&-O;W)D:6YA=&5S6R=";VQI=FEA)UU;)RTR,2XY-3`Z
M+38S+C8U,"==(#T@)UEA8W5I8F$G.PHD8V]O<F1I;F%T97-;)T)O<VYI82!A
M;F0@2&5R>F5G;W9I;F$G75LG-#,N.#,S.C$W+C`Q-R==(#T@)TQI=FYO)SL*
M)&-O;W)D:6YA=&5S6R=";W1S=V%N82==6R<M,3<N.#$W.C(U+C$U,"==(#T@
M)TMA<V%N92<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3$X+C,V-SHR
M,2XX-3`G72`]("=3:&%K87=E)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N82==
M6R<M,3DN.3@S.C(S+C0Q-R==(#T@)TUA=6XG.PHD8V]O<F1I;F%T97-;)T)O
M='-W86YA)UU;)RTR,"XT-C<Z,C4N.3@S)UT@/2`G4W5A+5!A;B<["B1C;V]R
M9&EN871E<ULG0F]T<W=A;F$G75LG+3(Q+C(Q-SHR-RXU,#`G72`]("=&<F%N
M8VES=&]W;B<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3(Q+C0Q-SHR
M-2XV,#`G72`]("=,971L:&%K86YE)SL*)&-O;W)D:6YA=&5S6R=";W1S=V%N
M82==6R<M,C$N-S`P.C(Q+C8U,"==(#T@)T=H86YZ:2<["B1C;V]R9&EN871E
M<ULG0F]T<W=A;F$G75LG+3(T+C`Q-SHR,2XX.#,G72`]("=4<VAA;F4G.PHD
M8V]O<F1I;F%T97-;)T)O='-W86YA)UU;)RTR-"XR,3<Z,C4N.3$W)UT@/2`G
M4V5R971S92!+:&%M82!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)T)O='-W86YA)UU;)RTR-"XV,#`Z,C0N-C8W)UT@/2`G2G=A;F5N
M9R<["B1C;V]R9&EN871E<ULG0F]T<W=A;F$G75LG+3(V+C`U,#HR,BXT-3`G
M72`]("=4<V%B;VYG)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG,"XP,S,Z
M+34P+C`U,"==(#T@)TUA8V%P82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTP+C$S,SHM-C<N,#@S)UT@/2`G4V%O($=A8G)I96P@1&$@0V%C:&]E:7)A
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG,"XV,3<Z+38Y+C(P,"==(#T@
M)TEA=6%R971E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3`N.3@S.BTV
M,BXU.#,G72`]("="87)C96QO<R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTQ+C,X,SHM-#@N-#@S)UT@/2`G0F5L96T@065R;W!O<G1O)SL*)&-O;W)D
M:6YA=&5S6R="<F%Z:6PG75LG+3$P+C`P,#HM-C<N.#`P)UT@/2`G4FEO($)R
M86YC;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ,"XW,#`Z+30X+C0P
M,"==(#T@)U!O<G1O($YA8VEO;F%L($%E<F]P;W)T;R<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTQ,"XY.#,Z+3,W+C`V-R==(#T@)T%R86-A:G4@065R
M;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$R+C<P,#HM-C`N
M,3`P)UT@/2`G5FEL:&5N82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,3(N.3`P.BTS."XS,S,G72`]("=386QV861O<B!!97)O<&]R
M=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3,N,C8W.BTT,RXT,3<G
M72`]("=";VT@2F5S=7,@1&$@3&%P82<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTQ-"XW,#`Z+34R+C,U,"==(#T@)UAA=F%N=&EN82<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTQ-"XX,3<Z+3,Y+C`S,R==(#T@)TEL:&5U<R!!
M97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,30N.34P.BTT
M,"XX.#,G72`]("=6:71O<FEA($1A($-O;G%U:7-T82<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTQ-2XV-3`Z+34V+C$P,"==(#T@)T-U:6%B82!!97)O
M<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,34N.#8W.BTT-RXY
M,S,G72`]("="<F%S:6QI82!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,34N.#8W.BTU,BXS.#,G72`]("="87)R82!$;R!'87)C87,G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,38N,#4P.BTT."XP-3`G72`]
M("='86UA)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$V+C(S,SHM-#@N
M.38W)UT@/2`G06YA<&]L:7,@0G)A>BU!9F(G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,38N-C,S.BTT.2XR,3<G72`]("=';VEA;FEA($%E<F]P;W)T
M;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ-BXW,3<Z+30S+C@V-R==
M(#T@)TUO;G1E<R!#;&%R;W,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,3<N-C,S.BTS.2XR-3`G72`]("=#87)A=F5L87,@065R;W!O<BU4;R<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTQ.2XP.#,Z+34W+C4P,"==(#T@)T-O
M<G5M8F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,3DN-S@S.BTT-RXY
M-C<G72`]("=58F5R86)A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$Y
M+C@U,#HM-#,N.34P)UT@/2`G0F5L;R!(;W)I>F]N=&4@065R;W!O<G1O)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3$Y+CDS,SHM-#,N.3,S)UT@/2`G
M0F5L;R!(;W)I>F]N=&4G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,BXT
M,S,Z+34T+C<Q-R==(#T@)U-A;G1A<F5M+4%E<F]P;W)T;R<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTR+C8P,#HM-#0N,C,S)UT@/2`G4V%O($QU:7H@
M065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG,BXX,S,Z+38P
M+C<P,"==(#T@)T)O82!6:7-T82!!97)O<&]R+51O)SL*)&-O;W)D:6YA=&5S
M6R="<F%Z:6PG75LG+3(N.3$W.BTT,2XW-3`G72`]("=087)N86EB82!!97)O
M<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C`N,C8W.BTT,"XR
M.#,G72`]("=6:71O<FEA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTR,"XT-C<Z+34T+C8V-R==(#T@)T-A;7!O($=R86YD92!!97)O
M<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N,C4P.BTT,RXW
M-C<G72`]("="87)B86-E;F$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M
M,C$N-S4P.BTT,2XS,S,G72`]("=#86UP;W,G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M,C$N-S8W.BTT,RXS-3`G72`]("=*=6EZ($1E($9O<F$G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N.#4P.BTT-BXU-C<G72`]("=0
M;V-O<R!$92!#86QD87,G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C$N
M.3@S.BTT-RXS,S,G72`]("=0:7)A<W-U;G5N9V$G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M,C(N,#$W.BTT-RXX.#,G72`]("=386\@0V%R;&]S)SL*
M)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C$Q-SHM-3$N,S@S)UT@/2`G
M4')E<VED96YT92!0<G5D96YT92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR,BXS,3<Z+30Y+C`V-R==(#T@)T)A=7)U)SL*)&-O;W)D:6YA=&5S6R="
M<F%Z:6PG75LG+3(R+C0X,SHM-#0N-#8W)UT@/2`G4F5S96YD92<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)RTR,BXU-3`Z+34U+C<P,"==(#T@)U!O;G1A
M(%!O<F$@065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR
M,BXW.#,Z+30U+C(P,"==(#T@)T=U87)A=&EN9W5E=&$G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M,C(N.#$W.BTT,BXQ,#`G72`]("=3+B!0+B!!;&1E
M:6$@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3(R+C@Q
M-SHM-#,N,C4P)UT@/2`G1V%L96%O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG
M75LG+3(R+C@V-SHM-#,N,S8W)UT@/2`G069O;G-O<R!!97)O<&]R=&\G.PHD
M8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N.3`P.BTT,RXQ-C<G72`]("=2
M:6\@1&4@2F%N96ER;R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II
M;"==6R<M,C(N.3,S.BTT,RXW,3<G72`]("=386YT82!#<G5Z($%E<F]P;W(M
M5&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C(N.3@S.BTT,RXS-C<G
M72`]("=2:6\@+R!*86-A<F5P86=U82<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTR,RXP,#`Z+30W+C$S,R==(#T@)T-A;7!I;F%S($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR,RXS,S,Z+34Q+C$S,R==(#T@
M)TQO;F1R:6YA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR,RXT,3<Z+34Q+CDU,"==(#T@)TUA<FEN9V$G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M,C,N-3$W.BTT-BXV,S,G72`]("=-87)T92!#:78@+R!-
M:6PG.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C,N-C$W.BTT-BXV-3`G
M72`]("=386\@4&%U;&\@065R;W!O<BU4;R<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTR,RXY,S,Z+30V+C,P,"==(#T@)U-A;G1O<R!!97)O<&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C4N-#,S.BTT.2XR-C<G72`]
M("=#=7)I=&EB82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR-2XU,3<Z
M+30X+C4Q-R==(#T@)U!A<F%N86=U82<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTR-2XU,3<Z+30Y+C$V-R==(#T@)T-U<FET:6)A($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTR-2XU,3<Z+34T+C4X,R==(#T@
M)T9O>B!$;R!)9W5A8W4@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3(W+C8V-SHM-#@N-34P)UT@/2`G1FQO<FEA;F]P;VQI<R!!97)O
M<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,C@N,C4P.BTU,BXT
M,#`G72`]("=087-S;R!&=6YD;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;
M)RTR.2XW,3<Z+34S+C<P,"==(#T@)U-A;G1A($UA<FEA($%E<F\M4&]R=&\G
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M,CDN-S@S.BTU-RXP,S,G72`]
M("=5<G5G=6%I86YA($%E<F]P;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTS+C`S,SHM-C`N,#4P)UT@/2`G161U87)D;R!';VUE<R!);G1E<FYA
M=&EO;F%L)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N,34P.BTU.2XY
M.#,G72`]("=-86YA=7,@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3,N,C`P.BTU,BXR,#`G72`]("=!;'1A;6ER82<["B1C;V]R9&EN
M871E<ULG0G)A>FEL)UU;)RTS+C,V-SHM-C0N-C@S)UT@/2`G5&5F92<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C8V-SHM-CDN-C8W)UT@/2`G5&%B
M871I;F=A)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N-S$W.BTT.2XW
M,3<G72`]("=4=6-U<G5I)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,N
M-S@S.BTS."XU,S,G72`]("=&;W)T86QE>F$@065R;W!O<BU4;R<["B1C;V]R
M9&EN871E<ULG0G)A>FEL)UU;)S,N.#,S.BTU,2XX,S,G72`]("=/:6%P;W%U
M92<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTS+C@U,#HM,S(N-#$W)UT@
M/2`G1F5R;F%N9&\@1&4@3F]R;VYH82<["B1C;V]R9&EN871E<ULG0G)A>FEL
M)UU;)RTS,"XP,#`Z+34Q+C$X,R==(#T@)U!O<G1O($%L96=R92!!97)O+5!O
M<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3,P+C`Q-SHM-3$N,C$W
M)UT@/2`G4&]R=&\@06QE9W)E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3,Q+C,U,#HM-30N,3$W)UT@/2`G0F%G92!!97)O<&]R=&\G.PHD8V]O<F1I
M;F%T97-;)T)R87II;"==6R<M,S$N.#8W.BTU,BXS-3`G72`]("=096QO=&%S
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+30N,C4P.BTU-BXP,#`G72`]
M("=)=&%I='5B82<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTT+C,X,SHM
M-S`N,#,S)UT@/2`G0F5N:F%M:6X@0V]N<W1A;G0G.PHD8V]O<F1I;F%T97-;
M)T)R87II;"==6R<M-2XP-3`Z+30R+C@Q-R==(#T@)U1E<F5S:6YA($%E<F]P
M;W)T;R<["B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTU+C(P,#HM,S<N,S8W
M)UT@/2`G36]C;W)O("\@,3<@4F]S861O)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+34N,S4P.BTT.2XQ-3`G72`]("=-87)A8F$G.PHD8V]O<F1I;F%T
M97-;)T)R87II;"==6R<M-2XU,S,Z+30W+C4P,"==(#T@)TEM<&5R871R:7HG
M.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-2XX,3<Z+38Q+C,P,"==(#T@
M)TUA;FEC;W)E)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+34N.3$W.BTS
M-2XR-3`G72`]("=.871A;"!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)T)R
M87II;"==6R<M-BXR-C<Z+34W+C<S,R==(#T@)TIA8V%R96%C86YG82<["B1C
M;V]R9&EN871E<ULG0G)A>FEL)UU;)RTW+C$P,#HM,S0N.#8W)UT@/2`G2F]A
M;R!097-S;V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-RXR,3<Z+3,U
M+C@X,R==(#T@)T-A;7!I;F$@1W)A;F1E)SL*)&-O;W)D:6YA=&5S6R="<F%Z
M:6PG75LG+3<N,S$W.BTT-RXT-C<G72`]("=-87)A;FAA;R`O($-A<F]L:6YA
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M-RXV,S,Z+3<R
M+C8V-R==(#T@)T-R=7IE:7)O($1O(%-U;"<["B1C;V]R9&EN871E<ULG0G)A
M>FEL)UU;)RTX+C`V-SHM,S0N.#4P)UT@/2`G4F5C:69E($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)A>FEL)UU;)RTX+C$V-SHM-S`N-S8W)UT@/2`G
M5&%R875A8V$G.PHD8V]O<F1I;F%T97-;)T)R87II;"==6R<M."XR-3`Z+30Y
M+C(X,R==(#T@)T-O;F-E:6-A;R!$;R!!<F%G=6%I82<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTX+C<V-SHM-C,N.3$W)UT@/2`G4&]R=&\@5F5L:&\@
M065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3DN,S4P.BTT
M,"XU-3`G72`]("=0971R;VQI;F$@065R;W!O<BU4;R<["B1C;V]R9&EN871E
M<ULG0G)A>FEL)UU;)RTY+C0P,#HM,S@N,C$W)UT@/2`G4&%U;&\@069O;G-O
M)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG+3DN-3$W.BTS-2XW.#,G72`]
M("=-86-E:6\@065R;W!O<G1O)SL*)&-O;W)D:6YA=&5S6R="<F%Z:6PG75LG
M+3DN.#8W.BTU-BXQ,#`G72`]("=!;'1A($9L;W)E<W1A($%E<F]P;W)T;R<[
M"B1C;V]R9&EN871E<ULG0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M)UU;)RTW+C,P,#HW,BXT,#`G72`]("=$:65G;R!'87)C:6$G.PHD8V]O<F1I
M;F%T97-;)T)R=6YE:2!$87)U<W-A;&%M)UU;)S0N.3,S.C$Q-"XY,S,G72`]
M("="<G5N96D@06ER<&]R="<["B1C;V]R9&EN871E<ULG0G5L9V%R:6$G75LG
M-#(N,3,S.C(T+C<U,"==(#T@)U!L;W9D:78G.PHD8V]O<F1I;F%T97-;)T)U
M;&=A<FEA)UU;)S0R+C0X,SHR-RXT.#,G72`]("="=7)G87,G.PHD8V]O<F1I
M;F%T97-;)T)U;&=A<FEA)UU;)S0R+C8U,#HR,RXS.#,G72`]("=3;V9I82!/
M8G-E<G8N)SL*)&-O;W)D:6YA=&5S6R="=6QG87)I82==6R<T,RXR,#`Z,C<N
M.3$W)UT@/2`G5F%R;F$G.PHD8V]O<F1I;F%T97-;)T)U;&=A<FEA)UU;)S0S
M+C@U,#HR-2XY-3`G72`]("=2;W5S<V4G.PHD8V]O<F1I;F%T97-;)T)U<FMI
M;F$@1F%S;R==6R<Q,"XS,S,Z+3,N,3@S)UT@/2`G1V%O=6$G.PHD8V]O<F1I
M;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,2XQ-3`Z+3$N,34P)UT@/2`G4&\G
M.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,2XQ-C<Z+30N,S$W
M)UT@/2`G0F]B;RU$:6]U;&%S<V\G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@
M1F%S;R==6R<Q,2XW-3`Z+3(N.3,S)UT@/2`G0F]R;VUO)SL*)&-O;W)D:6YA
M=&5S6R="=7)K:6YA($9A<V\G75LG,3(N,#,S.C`N,S8W)UT@/2`G1F%D82!.
M7"=';W5R;6$G.PHD8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,BXS
M-3`Z+3$N-3$W)UT@/2`G3W5A9V%D;W5G;W4G.PHD8V]O<F1I;F%T97-;)T)U
M<FMI;F$@1F%S;R==6R<Q,BXT-C<Z+3,N-#@S)UT@/2`G1&5D;W5G;W4G.PHD
M8V]O<F1I;F%T97-;)T)U<FMI;F$@1F%S;R==6R<Q,RXU-C<Z+3(N-#$W)UT@
M/2`G3W5A:&EG;W5Y82<["B1C;V]R9&EN871E<ULG0G5R:VEN82!&87-O)UU;
M)S$T+C`S,SHM,"XP,S,G72`]("=$;W)I)SL*)&-O;W)D:6YA=&5S6R="=7)U
M;F1I)UU;)RTS+C,Q-SHR.2XS,3<G72`]("="=6IU;6)U<F$G.PHD8V]O<F1I
M;F%T97-;)T-A;6)O9&EA)UU;)S$Q+C4U,#HQ,#0N.#4P)UT@/2`G4&AN;VTM
M4&5N:"`O(%!O8VAE;G1O;F<G.PHD8V]O<F1I;F%T97-;)T-A;6)O9&EA)UU;
M)S$R+C`P,#HQ,#4N-#4P)UT@/2`G2V]M<&]N9RU#:&%M)SL*)&-O;W)D:6YA
M=&5S6R=#86UB;V1I82==6R<Q,RXS-C<Z,3`S+C@U,"==(#T@)U-I96UR96%P
M)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<Q,"XT-3`Z,30N,C4P)UT@
M/2`G36%R;W5A+5-A;&%K)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==6R<R
M+CDU,#HY+CDP,"==(#T@)TMR:6)I)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O
M;B==6R<S+C$U,#HQ,RXV,3<G72`]("=,;VUI92<["B1C;V]R9&EN871E<ULG
M0V%M97)O;VXG75LG,RXX,S,Z,3$N-3$W)UT@/2`G66%O=6YD92<["B1C;V]R
M9&EN871E<ULG0V%M97)O;VXG75LG,RXY-C<Z,3,N,C`P)UT@/2`G06)O;F<M
M36)A;F<G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N,#`P.CDN-S,S
M)UT@/2`G1&]U86QA($]B<RXG.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;
M)S0N,#@S.CDN,S8W)UT@/2`G5&EK;R<["B1C;V]R9&EN871E<ULG0V%M97)O
M;VXG75LG-"XT-C<Z,30N,S8W)UT@/2`G0F%T;W5R:2<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG-"XW,S,Z,3$N,C4P)UT@/2`G0F%F:6$G.PHD8V]O
M<F1I;F%T97-;)T-A;65R;V]N)UU;)S0N.34P.CDN.3,S)UT@/2`G3FMO;F=S
M86UB82<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-2XU-3`Z,3(N,S8W
M)UT@/2`G66]K;R<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-2XV,#`Z
M,30N,#8W)UT@/2`G0F5T87)E+4]Y82<["B1C;V]R9&EN871E<ULG0V%M97)O
M;VXG75LG-2XV-3`Z,3`N-S4P)UT@/2`G2V]U;F1J82<["B1C;V]R9&EN871E
M<ULG0V%M97)O;VXG75LG-2XW,3<Z.2XR.#,G72`]("=-86UF92<["B1C;V]R
M9&EN871E<ULG0V%M97)O;VXG75LG-BXP-3`Z,3`N,3$W)UT@/2`G0F%M96YD
M82<["B1C;V]R9&EN871E<ULG0V%M97)O;VXG75LG-BXU,S,Z,30N,S8W)UT@
M/2`G365I9V%N9V$G.PHD8V]O<F1I;F%T97-;)T-A;65R;V]N)UU;)S8N-S@S
M.C$Q+C@Q-R==(#T@)T)A;GEO)SL*)&-O;W)D:6YA=&5S6R=#86UE<F]O;B==
M6R<W+C,U,#HQ,RXU-C<G72`]("=.9V%O=6YD97)E)SL*)&-O;W)D:6YA=&5S
M6R=#86UE<F]O;B==6R<Y+C,S,SHQ,RXS.#,G72`]("='87)O=6$G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T,2XX,S,Z+3@R+C0V-R==(#T@)U,N($4N
M(%-H;V%L($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I
M;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N,C4P.BTX
M,2XY,#`G72`]("=%<FEE874@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T,BXR-C<Z+3@R+CDV-R==(#T@)U=I;F1S;W(L($]N="XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T,BXS,#`Z+3@R+C<P,"==(#T@)T)E;&QE(%)I
M=F5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#(N-38W.BTX,"XP-3`G
M72`]("=,;VYG(%!O:6YT($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0
M<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#(N.#4P.BTX,"XR-C<G72`]("=3:6UC;V4L($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T,BXX-C<Z+3<Y+C(U,"==(#T@)U!O<G0@0V]L8F]R
M;F4@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#(N.#8W.BTX,"XU-3`G72`]("=$96QH:2!#4RP@3VYT
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C`P,#HM.#(N,S$W)UT@
M/2`G4V%R;FEA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M,RXP,S,Z+3@Q+C$U,"==(#T@)TQO;F1O;BP@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0S+C$V-SHM-SDN.3,S)UT@/2`G2&%M:6QT;VX@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+C(U,#HM-SDN,C$W
M)UT@/2`G4&]R="!796QL97(L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T,RXS,#`Z+3<Y+C@P,"==(#T@)T)U<FQI;F=T;VX@4&EE<G,G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXT-C<Z+3@P+C,X,R==(#T@)U=A
M=&5R;&]O(%=E;&PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T,RXV,3<Z
M+3<Y+C,U,"==(#T@)U1O<F]N=&\@2&5A9&QA;F0G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T,RXV,S,Z+3<Y+C0P,"==(#T@)U1O<F]N=&\@27-L86YD
M($%I<G!O<G0@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#,N-C8W.BTW.2XV,S,G72`]("=4;W)O;G1O
M(%!E87)S;VX@26YT7"=,+B!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#,N-S8W.BTX,2XW,3<G72`]("=';V1E<FEC:"!!=71O;6%T:6,@5V5A
M=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#,N-S@S.BTW.2XT-C<G72`]("=4;W)O;G1O($%E<R!(<2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0S+C@S,SHM-C8N,#@S)UT@/2`G66%R;6]U
M=&@L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#,N.#,S.BTW
M-RXQ-3`G72`]("=0;VEN="!0971R92P@3VYT+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0S+CDS,SHM-C`N,#$W)UT@/2`G4V%B;&4@27-L86YD+"!.
M+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0S+CDU,#HM-S@N,38W
M)UT@/2`G0V]B;W5R9RP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0S+CDX,SHM-C0N-C8W)UT@/2`G5V5S=&5R;B!(96%D+"!.+B!3+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0S+CDX,SHM.#`N-S4P)UT@/2`G36]U
M;G0@1F]R97-T+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N
M,3$W.BTW-RXU,S,G72`]("=4<F5N=&]N+"!/;G0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#0N,C$W.BTW-BXV,#`G72`]("=+:6YG<W1O;BP@3VYT
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C(S,SHM-S@N,S8W)UT@
M/2`G4&5T97)B;W)O=6=H($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-"XR.#8Z+38V+C,T-R==(#T@)T)R:65R($ES;&%N9"P@3BX@4RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XS.#,Z+3<Y+C<X,R==(#T@
M)T)A<G)I92P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C0Q
M-SHM-S4N.#4P)UT@/2`G1W)E;F%D:65R($ES;&%N9"<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0T+C0S,SHM-C4N,C`P)UT@/2`G2V5J:6UK=6II:R`Q
M+"!.+B!3+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C4P,#HM.#`N
M,C$W)UT@/2`G0V]L;&EN9W=O;V0@075T;VUA=&EC(%=E871H97(@4F5P;W)T
M:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T+C4S,SHM
M-SDN,C$W)UT@/2`G3&%G;V]N($-I='DG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T-"XV,S,Z+38S+C4P,"==(#T@)U-H96%R=V%T97(L($XN(%,N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N-S`P.BTW-BXS,#`G72`]("=5
M<'!E<B!2:61E874@3&%K92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0T
M+C<S,SHM.#$N,C@S)UT@/2`G3VQI<&AA;G0@7"!/;G0G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T-"XW-3`Z+3@Q+C$P,"==(#T@)U=I87)T;VXL($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-"XX,3<Z+38R+C,S,R==
M(#T@)T)E879E;B!)<VQA;F0L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#0N.#4P.BTW.2XX-C<G72`]("="96%U<V]L96EL($ES;&%N9"!!
M=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-"XX.#,Z+38S+C4P,"==(#T@)TAA;&EF87@@26YT97)N871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#0N.38W
M.BTW.2XS,#`G72`]("=-=7-K;VMA+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#0N.3@S.BTV-"XY,3<G72`]("='<F5E;G=O;V0L($XN(%,N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,#,S.BTX,"XS-C<G72`]
M("=797-T97)N($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@
M4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S0U+C`U,#HM-S(N.#,S)UT@/2`G1G)E;&EG:'-B=7)G)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#4N,#8W.BTV-"XT.#,G72`]("=+96YT=FEL;&4L
M($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,3$W.BTW-"XR
M.#,G72`]("=3="!!;FEC970G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XQ-C<Z+3<S+C8X,R==(#T@)U-A:6YT($-L;W1H:6QD92!!=71O;6%T960@
M4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XR,3<Z+38W+C(U,"==(#T@)U-T+B!3=&5P:&5N+"!.+B!"+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C,P,#HM-S,N,S4P)UT@/2`G3%PG06-A
M9&EE)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,S$W.BTW,BXR-3`G
M72`]("=-;VYT+4]R9F]R9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U
M+C,Q-SHM-S4N-C8W)UT@/2`G3W1T87=A($EN=%PG3"X@3VYT+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C,S,SHM-C4N.#@S)UT@/2`G4V%I;G0@
M2F]H;BP@3BX@0BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XS,S,Z
M+3@Q+C<S,R==(#T@)T-O=F4@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N
M875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#4N,S4P.BTV,"XY.#,G72`]("=(87)T($ES;&%N9"!-971E
M;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C,V-SHM-C,N,C8W)UT@/2`G
M5')U<F\L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N,S8W
M.BTW,2XX,3<G72`]("=,96YN;WAV:6QL92<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0U+C0P,#HM-S$N.#@S)UT@/2`G4VAE<F)R;V]K92P@475E+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C0Q-SHM-S,N.3,S)UT@/2`G
M36-G:6QL(%)A9&%R(%-I=&4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XT,S,Z+3<S+CDS,R==(#T@)U-T92!!;FYE($1E($)E;&P@,2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0U+C0V-SHM-S,N-S4P)UT@/2`G36]N=')E
M86P@+R!$;W)V86P@26YT97)N871I;VYA;"P@475E)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#4N-3`P.BTW,RXU.#,G72`]("=-8R!4879I<V@@075T
M;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#4N-3$W.BTW,RXT,3<G72`]("=386EN="!(=6)E<G0@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U+C8S,SHM-S`N-34P)UT@
M/2`G36]N=')E86PM17-T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N
M-C,S.BTX,BXY-C<G72`]("='<F5A="!$=6-K($ES;&%N9"<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0U+C<Q-SHM-C`N,C,S)UT@/2`G1F]U<F-H=2!(
M96%D($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N-S$W.BTW,RXS
M.#,G72`]("=687)E;FYE<R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0U
M+C<V-SHM-C(N-C@S)UT@/2`G0V%R:6)O=2!0;VEN="!-971E;W)O;&]G:6-A
M;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0U+C@P,#HM.#`N-3,S)UT@/2`G0G)I='0L($]N
M="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX,3<Z+3<S+C0S,R==
M(#T@)TQ<)T%S<V]M<'1I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M-2XX,S,Z+38V+C0S,R==(#T@)T=A9V5T;W=N($-A;BU-:6PG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-2XX,S,Z+3<U+C8U,"==(#T@)TAI9V@@1F%L
M;',L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX-3`Z+38T
M+C(V-R==(#T@)T%M:&5R<W0L($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#4N.#8W.BTV-BXU,S,G72`]("=&<F5D97)I8W1O;BP@3BX@0BXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-2XX.#,Z+3@R+C4V-R==(#T@
M)T=O<F4@0F%Y+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#4N
M.34P.BTW-RXS,3<G72`]("=0971A=V%W82P@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0U+CDV-SHM.#$N-#@S)UT@/2`G2VEL;&%R;F5Y($UE
M=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,#4P.BTW-"XR.#,G72`]
M("=3=&4@06=A=&AE($1E<R!-;VYT)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N,#8W.BTW-"XU,S,G72`]("=3="!*;W9I=&4@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0V+C$Q-SHM-C0N-C@S)UT@/2`G36]N8W1O;BP@3BX@0BXG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T-BXQ-C<Z+38P+C`U,"==(#T@)U-Y9&YE
M>2P@3BX@4RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-BXR,#`Z+3<P
M+C<X,R==(#T@)T)E875C979I;&QE)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N,C$W.BTW,BXV-3`G72`]("=.:6-O;&5T($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-BXR.#,Z+38S+C$S,R==(#T@)T-H87)L;W1T971O=VXL(%`N($4N($DN
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,C@S.BTW-BXP,#`G72`]
M("=-86YI=V%K:2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C,Q-SHM
M-SDN-#8W)UT@/2`G3FEP:7-S:6YG)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N,S4P.BTW,BXU,3<G72`]("=4<F]I<R!2:79I97)E<R<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C,U,#HM-SDN-#,S)UT@/2`G3F]R=&@@
M0F%Y+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N,S@S.BTW
M-2XY-C<G72`]("=-86YI=V%K:2P@475E+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0V+C0S,SHM-C,N.#,S)UT@/2`G4W5M;65R<VED92!#86XM36EL
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N-#,S.BTW,2XY,S,G72`]
M("=6:6QL97)O>2!2861A<B!3:71E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N-#4P.BTV,2XY-C<G72`]("=%87-T(%!O:6YT+"!0+B!%+B!))SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N-#@S.BTX-"XU,#`G72`]("=3
M875L="!3=&4@36%R:64L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<T-BXU-3`Z+38Q+C`U,"==(#T@)T=R86YD($5T86YG+"!.+B!3+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0V+C4X,SHM-S(N-3@S)UT@/2`G4VAA
M=VEN:6=A;B!#4RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0V
M+C8Q-SHM.#`N.#`P)UT@/2`G4W5D8G5R>2P@3VYT+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0V+C8U,#HM-3,N,#8W)UT@/2`G0V%P92!286-E+"!.
M9FQD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N-C@S.BTW,2XY-3`G
M72`]("=$97-C:&%M8F%U;'1S+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#8N.#`P.BTW,2XS.#,G72`]("=1=65B96,L(%%U92<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0V+C@Q-SHM-C`N-C8W)UT@/2`G3F]R=&@@
M36]U;G1A:6XL($XN(%,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N
M.#,S.BTW,2XR,#`G72`]("="96%U<&]R="!#4RP@475E+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0V+CDP,#HM-S$N-3`P)UT@/2`G5F%L8V%R=&EE
M<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#8N.3`P.BTW
M,2XU,#`G72`]("=686QC87)T:65R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#8N.3$W.BTU-2XS.#,G72`]("=3="X@3&%W<F5N8V4L($YF;&0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,#`P.BTV-2XT-3`G72`]("=#
M:&%T:&%M($-A;BU-:6PG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXP
M,#`Z+3<P+C@Q-R==(#T@)TEL92!$7"=/<FQE86YS($%U=&]M871E9"!297!O
M<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C`V
M-SHM-C0N.#`P)UT@/2`G4&]I;G0@17-C=6UI;F%C($UE=&5O<F]L;V=I8V%L
M($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#<N,#8W.BTW,"XX,#`G72`]("=#87`@5&]U<FUE
M;G1E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,34P.BTV-RXX,S,G
M72`]("=386EN="!,96]N87)D($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T-RXR,S,Z+38P+C$S,R==(#T@)U-A:6YT(%!A=6P@27-L86YD
M($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES
M=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N,C@S.BTW,"XV,S,G
M72`]("=#:&%R;&5V;VEX($-3+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#<N,S`P.BTU-"XP,#`G72`]("=!<F=E;G1I82P@3F9L9"<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C,P,#HM-S$N,C8W)UT@/2`G4W1E
M($9O>2!#4RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C,S
M,SHM.#4N.#,S)UT@/2`G0V%R:6)O=2!)<VQA;F0L($]N="XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T-RXS-3`Z+3<P+C`S,R==(#T@)TQA(%!O8V%T
M:65R92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C,V-SHM-34N.#`P
M)UT@/2`G4V%G;VYA($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC
M86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0W+C0Q-SHM-C$N-S@S)UT@/2`G26QE<R!$92!,82!-861E;&5I;F5Q
M=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#<N-#$W.BTV,2XX,#`G
M72`]("=);&5S+41E+4QA+4UA9&5L96EN)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#<N-#$W.BTW,BXX,#`G72`]("=,82!4=7%U92<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0W+C4Q-CHM-3(N-S@U)UT@/2`G4W0N($IO:&Y<
M)W,@5V5S="!#1$$@0U,L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#<N-38W.BTU.2XQ-C<G72`]("=0;W)T+4%U>"U"87-Q=65S+"!.9FQD
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C4V-SHM-S$N,C,S)UT@
M/2`G4&%R8R!$97,@3&%U<F5N=&ED)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#<N-C$W.BTU,BXW,S,G72`]("=3="X@2F]H;EPG<RP@3F9L9"<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C<P,#HM-SDN.#4P)UT@/2`G16%R
M;'1O;BP@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0W+C@P,#HM
M-CDN-34P)UT@/2`G4FEV:65R92!$=2!,;W5P+"!1=64N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#<N.3$W.BTW-"XV,3<G72`]("=087)E;G0L(%%U
M92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXY-C<Z+3@T+C<X,R==
M(#T@)U=A=V$L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T-RXY
M.#,Z+38V+C,S,R==(#T@)T-H87)L;RP@3BX@0BXG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T."XP,3<Z+38T+C4P,"==(#T@)TUI<V-O=2!)<VQA;F0L
M($XN($(N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,#$W.BTV-2XS
M,S,G72`]("=.97<@0V%R;&ES;&4Q)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#@N,#8W.BTW-RXW.#,G72`]("=686P@1%PG3W(L(%%U92XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T."XP.#,Z+38Y+C4U,"==(#T@)TEL92!2
M;W5G92!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C(U,#HM-SDN
M,#,S)UT@/2`G4F]U>6XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XR
M-C<Z+3<P+C$Q-R==(#T@)U!U:6YT92!#;&%V96%U)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N,S`P.BTQ,C,N-3,S)UT@/2`G4F%C92!2;V-K<R!!
M=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#@N,S`P.BTW,"XY,S,G72`]("=,82!"86EE+"!1
M=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N,S,S.BTW,2XP,#`G
M72`]("="86=O='9I;&QE+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#@N,S8W.BTX.2XQ,3<G72`]("=796QC;VUE($ES;&%N9"<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0X+C,V-SHM.#DN,S$W)UT@/2`G5&AU;F1E
M<B!"87DL($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XS.#,Z
M+3$R,RXY,3<G72`]("=3:&5R:6YG:&%M($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XS
M.#,Z+3<P+C4S,R==(#T@)T-A<"!2;W5G92<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S0X+C0Q-CHM-C@N.#DS)UT@/2`G26QE($)I8W%U971T92P@475E
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C0Q-SHM,3(S+C,Q-R==
M(#T@)U9I8W1O<FEA($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT,3<Z+38T+C,Q-R==
M(#T@)T-A<"!$7"=%<W!O:7(L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T."XT,3<Z+3<Q+C(Q-R==(#T@)TIO;G%U:65R92!!=71O;6%T960@
M4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M."XT,S,Z+3$R,RXT,S,G72`]("=%<W%U:6UA;'0@2&%R8F]U<BP@0BX@0RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XT-3`Z+3$R,RXS,#`G72`]
M("=6:6-T;W)I82!5;FEV97)S:71Y)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#@N-#8W.BTV-RXT,S,G72`]("=!;7%U:2P@475E+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0X+C4Q-SHM-S(N,C8W)UT@/2`G4F]B97)V86PL
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XU,S,Z+34X+C4U
M,"==(#T@)U-T97!H96YV:6QL92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XU-3<Z+34S+CDW-"==(#T@)U1E<G)A($YO=F$@3F%T:6]N
M86P@4&%R:R!#4RP@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M."XU-C<Z+3@Q+C,V-R==(#T@)U1I;6UI;G,L($]N="XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T."XU.#,Z+3$R,RXU.#,G72`]("=-86QA:&%T($%U
M=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T."XV,#`Z+38X+C(Q-R==(#T@)TUO;G0@2F]L:2P@
M475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C8P,#HM.#8N,S`P
M)UT@/2`G4'5K87-K=V$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XV
M,S,Z+3<Y+C0U,"==(#T@)U)O<75E;6%U<F4G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T."XV-3`Z+3$R,RXT,S,G72`]("=6:6-T;W)I82!);G0N($%I
M<G!O<G0L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-C8W
M.BTQ,C0N.#,S)UT@/2`G3FET:6YA="!,86ME($UE=&5O<F]L;V=I8V%L($%E
M<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#@N-C8W.BTU,RXQ,3<G72`]("=";VYA=FES=&$L($YF
M;&0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-S4P.BTY,2XV,3<G
M72`]("=!=&EK;VMA;B!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XW-C<Z+38T+C0X,R==(#T@)T=A
M<W!E+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#@N-S8W.BTW
M,2XW,3<G72`]("=-:7-T;V]K($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO
M;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+C<X,SHM,3(S+C`U,"==
M(#T@)U-A='5R;F$@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A
M;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#@N.#,S.BTW,BXU-3`G72`]("=.;W)M86YD:6XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T."XX.#,Z+3<Q+C`S,R==(#T@)T]N871C:&EW87DL
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T."XY,3<Z+3$R-2XU
M-3`G72`]("=!;7!H:71R:71E(%!O:6YT)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#@N.34P.BTU-"XU-C<G72`]("='86YD97(@26YT+B!!:7)P;W)T
M+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0X+CDV-SHM-38N
M,#8W)UT@/2`G0F%D9V5R+"!.9FQD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-#DN,#$W.BTQ,C(N-S@S)UT@/2`G5VAI=&4@4F]C:R!!=71O;6%T:6,@
M5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN,#,S.BTQ,3DN-#,S)UT@/2`G3W-O>6]O<R!!=71O;6%T:6,@
M5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN,#,S.BTQ,C(N,S8W)UT@/2`G06)B;W1S9F]R9"P@0BX@0RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XP,S,Z+3DP+C0V-R==(#T@
M)U5P<V%L82P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`S
M,SHM.3<N-38W)UT@/2`G1W)E=&YA+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN,#4P.BTQ,#4N-#@S)UT@/2`G0V]R;VYA8V@@4W!C)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,#4P.BTQ,C,N.#8W)UT@/2`G
M3F%N86EM;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M,#8W.BTQ,#<N-3@S)UT@/2`G5F%L($UA<FEE(%-O=71H96%S="P@4V%S:R<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`X,SHM,3$V+C4P,"==(#T@
M)T-R97-T;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C`X,SHM,3(U+C<V-R==(#T@
M)U1O9FEN;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M,#@S.BTV,2XW,#`G72`]("=(96%T:"!0;VEN="!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C$Q-SHM,3$P+C0V-R==(#T@)T]N969O=7(@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C$Q-SHM-C8N-C4P)UT@/2`G0V%P($-H870@0U,L
M(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XQ,S,Z+3$Q,BXP
M-3`G72`]("=-:6QK(%)I=F5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-#DN,3,S.BTV."XR,#`G72`]("="86EE($-O;65A=2P@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0Y+C$V-SHM,3`U+CDX,R==(#T@)U)O8VMG
M;&5N+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$X,SHM
M,3(S+C$V-R==(#T@)U9A;F-O=79E<B!);G1E<FYA=&EO;F%L($%I<BU0;W)T
M+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C$X,SHM.3@N
M,#@S)UT@/2`G36]R9&5N($-$02!#4RP@36%N+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C(P,#HM,3$S+C(X,R==(#T@)T-A<F1S=&]N($%U=&]M
M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C(P,#HM,3(R+C8X,R==(#T@)U`N($UE861O=W,@0V]A<W1A;"!3
M=&%T:6]N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XR,#`Z+3DX+CDP,"==(#T@)U!I
M;&]T($UO=6YD+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M,C$W.BTQ,#(N.38W)UT@/2`G17-T979A;BP@4V%S:RXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XR,3<Z+3$R,RXX,#`G72`]("=%;G1R86YC92!)
M<VQA;F0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(Q-SHM-3<N-#`P)UT@/2`G1&5E
M<B!,86ME+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(U
M,#HM,3(Q+C<V-R==(#T@)T%G87-S:7H@075T;VUA=&5D(%)E<&]R=&EN9R!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,C4P.BTQ,C0N
M.#,S)UT@/2`G4&]R="!!;&)E<FYI+"!"+B!#+B<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S0Y+C(U,#HM-C4N,S,S)UT@/2`G0V%P($UA9&5L96EN92!-
M971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(V-SHM-30N.#@S)UT@
M/2`G0V]M9F]R="!#;W9E+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C(V-SHM-C@N,34P)UT@/2`G0F%I92!#;VUE874G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<T.2XR.#,Z+3$P,"XY.#,G72`]("=-96QI=&$L
M($UA;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C(X,SHM-S,N,S4P
M)UT@/2`G0VAA;6]U8VAO=6%N92!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I
M;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN,S`P.BTQ
M,3<N-C,S)UT@/2`G0V%S=&QE9V%R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<T.2XS,#`Z+3$R,RXQ,3<G72`]("=686YC;W5V97(@075T
M;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S0Y+C,Q-SHM-C<N,S@S)UT@/2`G4&]I;G1E+41E<RU-
M;VYT<RP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C,U,#HM
M,3(S+C$X,R==(#T@)U<@5F%N8V]U=F5R($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XS
M-3`Z+3$R-"XQ-C<G72`]("="86QL96YA<R!)<VQA;F0@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C,V-SHM,3(Q+C0X,R==(#T@)TAO<&4L($(N($,N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-#DN,S@S.BTQ,C8N-34P)UT@/2`G17-T979A
M;B!0;VEN="P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT
M,#`Z+3DX+C,Q-R==(#T@)T1E97)W;V]D(%)#4RP@36%N+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C0Q-SHM.#(N-#8W)UT@/2`G2V%P=7-K87-I
M;F<L($]N="XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XT,S,Z+3$P
M."XY.#,G72`]("=%87-T96YD($-Y<')E<W,L(%-A<VLG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<T.2XT-C<Z+3$Q.2XV,#`G72`]("=096YT:6-T;VXL
M($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-#8W.BTQ,C`N
M-3$W)UT@/2`G4')I;F-E=&]N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XT.#,Z+3$R,RXS,#`G72`]("=086T@4F]C:W,G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XT.#,Z+3$R-"XT,S,G72`]("=3:7-T
M97)S($ES;&%N9"!!=71O;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-3`P.BTQ,3<N,S`P)UT@
M/2`G3F5L<V]N($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XU,#`Z+3DX+C`S,R==(#T@
M)T-A<FUA;B!5($]F($TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XU
M-C<Z+3$Q.2XV-3`G72`]("=3=6UM97)L86YD($%U=&]M871I8R!796%T:&5R
M(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M.2XU-C<Z+34W+C@X,R==(#T@)U)O8VMY($AA<F)O=7(@0U,L($YF;&0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-3@S.BTQ,30N-#$W)UT@/2`G
M5'5R=&QE($UO=6YT86EN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN
M-C$W.BTQ,34N-S@S)UT@/2`G0W)A;F)R;V]K+"!"+B!#+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C8S,SHM,3$Q+C0U,"==(#T@)T)O=R!)<VQA
M;F0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XV,S,Z+3$Q,BXX,#`G
M72`]("=,971H8G)I9&=E+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C8S,SHM,3$T+C0X,R==(#T@)T-R;W=S;F5S="<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S0Y+C8U,#HM,3`Y+C4Q-R==(#T@)T-Y<')E<W,@
M2&EL;',@4&%R:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C8X,SHM
M-30N.#`P)UT@/2`G5'=I;&QI;F=A=&4@365T96]R;VQO9VEC86P@065R;VYA
M=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XW,#`Z+3$P,RXX,#`G72`]("=797EB=7)N($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XW,#`Z+3$Q,BXW.#,G72`]("=,971H8G)I9&=E($%U=&]M
M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S0Y+C<Q-SHM,3(T+CDP,"==(#T@)T-O;6]X+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S0Y+C<Q-SHM.#@N,S,S)UT@/2`G2V%T871O
M=&$@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN-S,S.BTQ
M,#4N.3,S)UT@/2`G07-S:6YI8F]I82!!:7)P;W)T($%U=&]M871E9"!297!O
M<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<U
M,#HM,3$T+CDP,"==(#T@)U-P87)W;V]D($%U=&]M871I8R!796%T:&5R(%)E
M<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW
M-3`Z+3@T+C$V-R==(#T@)TYA9V%G86UI+"!/;G0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-#DN-S8W.BTW-"XU,S,G72`]("=#:&EB;W5G86UA=2U#
M:&%P86ES+"!1=64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XW-C<Z
M+3<W+C@Q-R==(#T@)TUA=&%G86UI+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-#DN-S@S.BTQ,C,N,38W)UT@/2`G4W%U86UI<V@@06ER<&]R
M="P@0BX@0R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S0Y+C<X,SHM.#8N
M.3,S)UT@/2`G1V5R86QD=&]N+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-#DN-S@S.BTY-"XS-C<G72`]("=+96YO<F$L($]N="XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<T.2XW.#,Z+3DY+C8S,R==(#T@)U-H:6QO
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.#,S.BTQ,C0N-3`P)UT@
M/2`G4&]W96QL(%)I=F5R($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XX,S,Z+38T+C,P,"==(#T@)U!O<G0@365N:65R+"!1=64N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.#@S.BTY-RXQ,S,G72`]("=7
M:6YN:7!E9R!4:&4@1F]R:W,L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<T.2XY,#`Z+3$P.2XT-C<G72`]("=-87!L96-R965K($%U=&]M871I
M8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XY,#`Z+3<Q+C(U,"==(#T@)T-H=71E($1E<R!087-S97,G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3DW+C(S,R==(#T@
M)U=I;FYI<&5G($EN="X@06ER<&]R=&UA;BXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<T.2XY,#`Z+3DX+C(V-R==(#T@)U!O<G1A9V4@4V]U=&AP;W)T
M($$G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T.2XY,#`Z+3DY+C,U,"==
M(#T@)T-A<F)E<G)Y($UC9&,G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<T
M.2XY,3<Z+34U+C8V-R==(#T@)TQA(%-C:64L($YF;&0N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-#DN.3$W.BTY.2XY-3`G72`]("="<F%N9&]N+"!-
M86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-#DN.38W.BTQ,3DN,S@S
M)UT@/2`G2V5L;W=N82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3`N,#$W.BTQ,3`N-S$W)UT@/2`G365D:6-I;F4@2&%T+"!!;'1A+B<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C`Q-SHM,3$S+C8S,R==(#T@
M)T-L87)E<VAO;&T@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C`U,#HM,3$R+C$S,R==
M(#T@)U9A=7AH86QL($-D82<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P
M+C$Q-SHM,3(W+CDS,R==(#T@)U-O;&%N9&5R($ES;&%N9"!-971E;W)O;&]G
M:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C$Q-SHM.3$N.3`P)UT@/2`G4VEO=7@@
M3&]O:V]U="P@3VYT+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C$V
M-SHM-C`N,#8W)UT@/2`G0V%P92!7:&ET=&QE)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3`N,38W.BTV-BXT,S,G72`]("=0;VEN=&4@3F]I<F4L(%%U
M92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XQ.#,Z+38Q+C@Q-R==
M(#T@)TYA=&%S:'%U86XL(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XQ.#,Z+3DV+C`V-R==(#T@)U!I;F%W82!!=71O;6%T:6,@5V5A=&AE
M<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3`N,C`P.BTQ,#0N-S`P)UT@/2`G0G)A='1S($QA:V4L(%-A<VLN)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N,C$W.BTV-BXR-C<G72`]("=397!T
M+4EL97,L(%%U92XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR,C0Z
M+38T+C(P."==(#T@)TEL92!!=7@@4&5R<F]Q=65T<RP@475E+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C(S,SHM,3$Y+C(X,R==(#T@)U9E<FYO
M;BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XR,S,Z+3$R
M,2XU.#,G72`]("=,>71T;VXL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3`N,C,S.BTU-RXU.#,G72`]("=$86YI96Q<)W,@2&%R8F]U<BP@
M3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(V-SHM,3`W+C<S
M,R==(#T@)U-W:69T($-U<G)E;G0@075T;VUA=&EC(%=E871H97(@4F5P;W)T
M:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(V-SHM
M,3$Q+C$X,R==(#T@)U-U9F9I96QD($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U,"XR-C<Z+3$Q-RXX,3<G72`]("=.86MU<W`@075T;VUA
M=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S4P+C(V-SHM-C0N,C,S)UT@/2`G3&]N9W5E(%!O:6YT($1E
M($UI;F=A;BP@475E+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C(X
M,SHM,3`W+C8X,R==(#T@)U-W:69T($-U<G)E;G0L(%-A<VLN)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3`N,C@S.BTV,RXV,3<G72`]("=(879R92!3
M="!0:65R<F4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XS,#`Z+3$R
M,BXW,S,G72`]("=096UB97)T;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T
M:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C,P,#HM
M.#DN,#,S)UT@/2`G07)M<W1R;VYG+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3`N,S,S.BTQ,#4N-34P)UT@/2`G36]O<V4@2F%W+"!387-K
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C,X,SHM,3`R+C8X,R==
M(#T@)T)R;V%D=FEE=RP@4V%S:RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,"XT,#`Z+3$P-"XU.#,G72`]("=296=I;F$@56YI=F5R<VET>2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C0P,#HM,3(U+C@V-R==(#T@)TAE
M;&UC:V5N($ES;&%N9"!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E
M<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P
M+C0S,SHM,3`T+C8V-R==(#T@)U)E9VEN82P@4V%S:RXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,"XT-3`Z+3$P,"XV,#`G72`]("=3:&]A;"!,86ME
M($%I<G!O<G0@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3`N-#8W.BTU.2XV,S,G72`]("=#:&5V97)Y
M+"!1=64N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-34P.BTQ,3$N
M.#4P)UT@/2`G0G)O;VMS($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3
M>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XV,#`Z+3$R,"XU
M,3<G72`]("=0<FEN8V5T;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C8Q-SHM.3<N
M,#,S)UT@/2`G1VEM;&D@26YD=7-T<FEA;"P@36%N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N-C,Q.BTY-BXY.#(G72`]("=':6UL:2!(87)B;W5R
M($-3+"!-86XN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N-C,S.BTQ
M,C@N,3$W)UT@/2`G2&]L8F5R9RP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,"XV-3`Z+3DY+CDS,R==(#T@)U=A<V%G86UI;F<L($UA;BXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XV-C<Z+3<P+C4S,R==(#T@
M)TUA;F]U86YE+45S="!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XV.#,Z+3$R-RXS-C<G72`]("=0
M;W)T($AA<F1Y+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P
M+C<P,#HM,3$Y+C(X,R==(#T@)U-A;&UO;B!!<FT@075T;VUA=&EC(%=E871H
M97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4P+C<P,#HM,3(P+C0U,"==(#T@)TMA;6QO;W!S+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+C<P,#HM.38N-38W)UT@/2`G5FEC=&]R
M:6$@0F5A8V@G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,"XW,3<Z+34V
M+C$Q-R==(#T@)T5N9VQE92!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@
M4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4P+C<S,SHM-S$N,#$W)UT@/2`G0F]N;F%R9"`Q+"!1=64N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-3`N-S@S.BTQ,C@N-#,S)UT@/2`G0V%P92!3
M8V]T="!,:6=H="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4P+C@Q-SHM
M,3(X+CDP,"==(#T@)U-A<G1I;F4@27-L86YD($UE=&5O<F]L;V=I8V%L($%E
M<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3`N.3`P.BTQ,#DN-3`P)UT@/2`G3&5A9&5R($%I<G!O
M<G0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4P+CDS,SHM,3(W+C8S,R==(#T@)TAE<F)E
M<G0@27-L86YD($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT
M871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N.34P
M.BTQ,#<N,34P)UT@/2`G3'5C:WD@3&%K92!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N
M.34P.BTQ,34N,3@S)UT@/2`G3F%K:7-K82!2:61G971O<"<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4P+CDV-SHM,3$X+C$X,R==(#T@)U)E=F5L<W1O
M:V4L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3`N.3@S.BTQ
M,C<N-S,S)UT@/2`G4&EN92!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA
M=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,2XP-C<Z+3DS+C@P,"==(#T@)U)E9"!,86ME+"!/;G0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,#@S.BTQ,30N,C$W)UT@/2`G
M0V]P(%5P<&5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,#@S.BTQ
M,34N,#8W)UT@/2`G0F]W(%9A;&QE>2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4Q+C`X,SHM.3<N-34P)UT@/2`G1FES:&5R($)R86YC:"!-87)I;F4@
M079I871I;VX@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,2XQ,#`Z+3$P,"XP-3`G72`]("=$875P:&EN($-O87-T86P@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C$P,#HM,3`P
M+C`U,"==(#T@)T1A=7!H:6XL($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,2XQ,3<Z+3$Q-"XP,3<G72`]("=#86QG87)Y($EN=&5R;F%T:6]N
M86PL($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,3,S.BTQ
M,#8N-3@S)UT@/2`G16QB;W<@36%R:6YE($%V:6%T:6]N(%)E<&]R=&EN9R!3
M=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N,34P.BTQ,C$N
M-3`P)UT@/2`G0VQI;G1O;BP@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,2XQ.#,Z+3$Q-2XU-C<G72`]("="86YF9BP@06QT82XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,2XR-3`Z+3$R,RXP.#,G72`]("=":6<@
M0W)E96LG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XR-C<Z+3$P,BXT
M-C<G72`]("=9;W)K=&]N+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4Q+C(V-SHM.#`N-C4P)UT@/2`G36]O<V]N964L($]N="XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,2XS-C<Z+34U+C8S,R==(#T@)U-T+B!!
M;G1H;VYY+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C0U
M,#HM,3$V+C,S,R==(#T@)UEO:&\@4&%R:R!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N
M-#4P.BTU-RXQ.#,G72`]("=";&%N8R!386)L;VXL(%%U92XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<U,2XT-3`Z+3DP+C(P,"==(#T@)U!I8VML92!,
M86ME+"!/;G0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-#@S.BTQ
M,#<N,#4P)UT@/2`G3W5T;&]O:R!09G)A)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3$N-3$W.BTQ,#DN,38W)UT@/2`G2VEN9&5R<VQE>2P@4V%S:RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XU-3`Z+3<Q+C$Q-R==(#T@
M)TQA8R!"96YO:70G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,2XU-C<Z
M+3$P-RXY,3<G72`]("=2;W-E=&]W;B!%87-T+"!387-K)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3$N-C8W.BTQ,#4N-#`P)UT@/2`G5V%T<F]U<R!%
M87-T($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4Q+C8V-SHM,3$P+C(P,"==(#T@)T5S=&AE<B`Q)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-C8W.BTY."XW-3`G72`]("='
M>7!S=6UV:6QL92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Q+C<P,#HM
M,3$S+C(Q-R==(#T@)U1H<F5E($AI;&QS)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-3$N-S4P.BTY.2XY,#`G72`]("="86-H96QO<G,@27-L86YD($%U
M=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4Q+C<V-SHM,3`T+C(P,"==(#T@)U=Y;GEA<F0L(%-A<VLN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N-S8W.BTQ,30N-C@S)UT@/2`G
M4W5N9')E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3$N.#8W.BTV,RXR
M.#,G72`]("=,86,@16]N+"!1=64G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U,BXP-C<Z+3$Q,2XT-3`G72`]("=#;W)O;F%T:6]N($UA<FEN92!!=FEA
M=&EO;B!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4R+C$Q-SHM,3`Q+C(S,R==(#T@)U-W86X@4FEV97(L($UA;BXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXQ,3<Z+3$R-"XQ,S,G72`]("=0
M=6YT>FD@36]U;G1A:6XL($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-3(N,3,S.BTQ,3DN,S`P)UT@/2`G0FQU92!2:79E<BP@0BX@0RXG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXQ-3`Z+3$P-BXU-3`G72`]("=3
M87-K871O;VX@2V5R;F5N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N
M,38W.BTQ,#8N-C@S)UT@/2`G4V%S:V%T;V]N+"!387-K+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4R+C$X,SHM,3$S+CDP,"==(#T@)U)E9"!$965R
M+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C$X,SHM,3(R
M+C`U,"==(#T@)U=I;&QI86US($QA:V4L($(N($,N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3(N,3@S.BTQ,C<N-#8W)UT@/2`G0V%T:&5D<F%L(%!O
M:6YT($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@
M4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,C,S.BTX-RXX
M.#,G72`]("=,86YS9&]W;F4@2&]U<V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U,BXR-C<Z+3$R."XW,3<G72`]("=-8VEN;F5S($ES;&%N9"P@0BX@
M0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXS,#`Z+34U+C@S,R==
M(#T@)TUA<GE<)W,@2&%R8F]U<BP@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,BXS-3`Z+3DW+C`S,R==(#T@)T)E<F5N<R!2:79E<B!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N,S4P.BTY-RXP,S,G
M72`]("="97)E;G,@4FEV97(@0U,L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,BXS.#,Z+3$R-BXU.#,G72`]("="96QL82!#;V]L82!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3(N-#,S.BTQ,30N.3$W
M)UT@/2`G4F]C:WD@36]U;G1A:6X@2&]U<V4L($%L=&$G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,BXT-3`Z+3$Q,RXW-3`G72`]("=,86-O;6)E($-D
M82<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+C8U,#HM-38N.#8W)UT@
M/2`G06QE>&ES(%)I=F5R($UE=&5O<F]L;V=I8V%L($%E<F]N875T:6-A;"!0
M<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3(N-S8W.BTQ,#@N,C4P)UT@/2`G3F]R=&@@0F%T=&QE9F]R9"P@4V%S:RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXX,#`Z+3DW+C8Q-R==(#T@
M)T=E;W)G92!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R
M97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,BXX,3<Z+3$P,BXS,3<G72`]("=(=61S;VX@0F%Y+"!387-K+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4R+C@Q-SHM,3`T+C8P,"==(#T@)TUE;&9O
M<G0@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4R+C@X,SHM,3$X+C`V-R==(#T@)TIA<W!E
M<BP@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,BXY,S,Z+3$Q
M."XS,3<G72`]("=*87-P97(@5V%R9&5N($%U=&]M871E9"!297!O<G1I;F<@
M4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4R+CDS,SHM-C8N
M.#8W)UT@/2`G5V%B=7-H($QA:V4L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3,N,#,S.BTQ,#`N.3,S)UT@/2`G2'5N=&5R<R!0;VEN="!-
M87(G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXP,S,Z+3$Q,BXX,3<G
M72`]("=#86UR;W-E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,#,S
M.BTQ,C(N-3$W)UT@/2`G475E<VYE;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3,N,#4P.BTQ,CDN-C@S)UT@/2`G171H96QD82!"87DG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXQ.#,Z+3DY+C(V-R==(#T@
M)T=R86YD(%)A<&ED<RP@36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4S+C(Q-SHM,3`U+C8X,R==(#T@)U!R:6YC92!!;&)E<G0L(%-A<VLN)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,C4P.BTQ,S$N.#$W)UT@/2`G
M4V%N9'-P:70L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N
M,S`P.BTQ,3,N-3@S)UT@/2`G161M;VYT;VX@26YT97)N871I;VYA;"P@06QT
M82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS,#`Z+3$Q,RXV,#`G
M72`]("=%9&UO;G1O;B!);G1E<FYA=&EO;F%L($-3+"!!;'1A+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4S+C,Q-SHM,3$P+C`V-R==(#T@)TQL;WED
M;6EN:7-T97(L($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N
M,S$W.BTQ,S(N-S4P)UT@/2`G2VEN9&%K=6X@4F]C:W,L($(N($,N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N,S$W.BTV,"XT,3<G72`]("=';V]S
M92P@3F9L9"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXS,S,Z+3$P
M-"XP,#`G72`]("=.:7!A=VEN+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4S+C,V-SHM,3`W+C4U,"==(#T@)U-P:7)I='=O;V0@5V5S="P@
M4V%S:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C,X,SHM,3$X+C,S
M,R==(#T@)U=I;&QO=R!#<F5E:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4S+C0Q-SHM,3$S+C(P,"==(#T@)T5L;&5R<VQI92<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4S+C0U,#HM,3$T+C0V-R==(#T@)TAI9VAV86QE)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-3`P.BTQ,S`N-C,S)UT@/2`G
M0F]N:6QL82!)<VQA;F0@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R
M97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M,RXU,S,Z+3$Q-"XQ,#`G72`]("=%9&UO;G1O;B!3=&]N>2!0;&%I;B!!;'1A
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4U,#HM-C0N,3`P)UT@
M/2`G0VAU<F-H:6QL($9A;&QS+"!.9FQD+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S4S+C4V-SHM,3$S+C4Q-R==(#T@)T5D;6]N=&]N($UU;FEC:7!A
M;"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4V-SHM,3$S
M+C4Q-R==(#T@)T5D;6]N=&]N($UU;FEC:7!A;"!#4C$P+"!!;'1A+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C4V-SHM-C0N,3`P)UT@/2`G0VAU
M<F-H:6QL($9A;&QS)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-3@S
M.BTQ,38N-#8W)UT@/2`G161S;VXL($%L=&$N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3,N-C$W.BTQ,3(N,#,S)UT@/2`G5F5G<F5V:6QL92!!=71O
M;6%T:6,@5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3,N-C,S.BTW-RXW,#`G72`]("=,82!'<F%N9&4@4FEV
M:65R92P@475E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3,N-C8W.BTQ
M,3,N-#8W)UT@/2`G161M;VYT;VX@3F%M86\@06QT82XG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U,RXV.#,Z+3$Q,BXX-C<G72`]("=%;&L@27-L86YD
M($YA=&EO;F%L(%!A<FLG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXV
M.#,Z+3$R-"XX,S,G72`]("=.96-H86MO(%)I=F5R)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3,N-S`P.BTU-RXP,S,G72`]("=#87)T=W)I9VAT+"!.
M9FQD+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C<S,SHM,3`U+C(V
M-R==(#T@)T-A;F1L92!,86ME)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-3,N-S4P.BTW,RXV-C<G72`]("=,82!'<F%N9&4@278L(%%U92XG.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U,RXW.#,Z+3$Q."XT,S,G72`]("=(96YD
M97)I8VMS;VX@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+C@S,SHM.#DN.#8W)UT@/2`G
M0FEG(%1R;W5T($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXX
M-3`Z+3DT+C8U,"==(#T@)TES;&%N9"!,86ME+"!-86XN)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3,N.#@S.BTQ,C(N-C@S)UT@/2`G4')I;F-E($=E
M;W)G92P@0BX@0RXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U,RXY,3<Z
M+3$P-BXP-C<G72`]("=787-K97-I=2!,86ME($%U=&]M871E9"!297!O<G1I
M;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4S+CDV-SHM
M,3`Q+C$P,"==(#T@)U1H92!087,L($UA;BXG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U,RXY-C<Z+3DW+C@S,R==(#T@)TYO<G=A>2!(;W5S92P@36%N
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C$S,SHM,3`X+C4Q-R==
M(#T@)TUE861O=R!,86ME+"!387-K+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4T+C$U,#HM,3$U+C<X,R==(#T@)U=H:71E8V]U<G0L($%L=&$N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N,34P.BTQ,34N-S@S)UT@/2`G
M5VAI=&5C;W5R="P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-"XQ-C<Z+3$S,"XS-C<G72`]("=(;VQL86YD(%)O8VL@075T;VUA=&EC(%=E
M871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4T+C$V-SHM,3,Q+C8V-R==(#T@)U)O<V4@4W!I="!-971E;W)O;&]G
M:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4T+C(U,#HM,3,S+C$S,R==(#T@)TQA;F=A
M<F$L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N,S`P.BTQ
M,S`N-#,S)UT@/2`G4')I;F-E(%)U<&5R="P@0BX@0RXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U-"XS.#,Z+3$R-2XY-3`G72`]("="=7)N<R!,86ME
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N-#$W.BTQ,3`N,C@S)UT@
M/2`G0V]L9"!,86ME+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4T+C0V-SHM,3(X+C4X,R==(#T@)U1E<G)A8V4L($(N($,N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-30N-3@S.BTQ,S`N-S`P)UT@/2`G1W)E>2!)
M<VQE="!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N
M(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4T+C<U,#HM,3$P
M+C`U,"==(#T@)U!R:6UR;W-E($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-"XW-C<Z+3$Q,BXP,3<G72`]("=,86,@3&$@0FEC:&4L($%L=&$N
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N-S@S.BTQ,3`N,#8W)UT@
M/2`G4')I;7)O<V4@3&%K92`R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-30N.#`P.BTV-BXX,#`G72`]("=38VAE9F9E<G9I;&QE+"!1=64N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-30N.#$W.BTQ,C<N,3@S)UT@/2`G4VUI
M=&AE<G,L($(N($,N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-30N.3@S
M.BTX-2XT,S,G72`]("=096%W86YU8VL@365T96]R;VQO9VEC86P@065R;VYA
M=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<U-2XQ-3`Z+3$P-2XR-C<G72`]("=,82!2;VYG92P@4V%S:RXG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-2XQ-3`Z+3$P-2XR-C<G72`]
M("=,82!2;VYG92P@4V%S:R<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U
M+C$X,SHM,3$X+C@X,R==(#T@)T=R86YD92!0<F%I<FEE+"!!;'1A+B<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C(P,#HM,3$Y+C0P,"==(#T@)T)E
M879E<FQO9&=E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,C@S.BTW
M-RXW-C<G72`]("=+=75J:G5A<F%P:6LL(%%U92XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<U-2XS,#`Z+3$Q-"XW.#,G72`]("=3;&%V92!,86ME+"!!
M;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N,S`P.BTQ,C,N,3,S
M)UT@/2`G36%C:V5N>FEE+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S4U+C,S,SHM-C,N,C$W)UT@/2`G0F]R9&5R+"!1=64N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-34N-#4P.BTV,"XR,S,G72`]("=(;W!E9&%L
M92!-971E;W)O;&]G:6-A;"!!97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y
M<W1E;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4U+C8Y-3HM,3$Y+C(S
M-"==(#T@)U-P:7)I="!2:79E<B!!=71O(%-T871I;VXL($%L=&$G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-2XX,#`Z+3DW+C@U,"==(#T@)U1H;VUP
M<V]N(%=E871H97(@3V9F:6-E+"!-86XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U-2XX,S,Z+3$P."XT,S,G72`]("="=69F86QO($YA<G)O=W,L(%-A
M<VLN)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-34N.3,S.BTQ,CDN.3@S
M)UT@/2`G4W1E=V%R="!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-38N,C,S.BTQ,3<N-#,S)UT@/2`G4&5A8V4@4FEV97(L($%L=&$N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-38N,C,S.BTQ,C`N-S,S)UT@/2`G
M1F]R="!3="!*;VAN+"!"+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4V+C,S,SHM,3`S+C(X,R==(#T@)U-O=71H96YD($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U-BXS-3`Z+3DT+C<P,"==(#T@)T=I;&QA;2P@36%N+B<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S4V+C4S,SHM,3$U+C(V-R==(#T@)U)E9"!%87)T
M:"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C4U,#HM-C$N-C@S)UT@
M/2`G3F%I;BP@3F9L9"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4V+C8U
M,#HM,3$Q+C(Q-R==(#T@)T9O<G0@36--=7)R87D@0U,L($%L=&$N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-38N-C4P.BTQ,3$N,C$W)UT@/2`G1F]R
M="!-8VUU<G)A>2P@06QT82XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U
M-BXW,S,Z+3$S,2XV-C<G72`]("=)<VMU="!2:79E<B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S4V+C@V-SHM,3`Q+C`X,R==(#T@)TQY;FX@3&%K92P@
M36%N+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4W+C$S,SHM-C$N-#@S
M)UT@/2`G0V%P92!+:6=L87!A:70L($YF;&0N)SL*)&-O;W)D:6YA=&5S6R=#
M86YA9&$G75LG-3<N,C4P.BTQ,#4N-C$W)UT@/2`G2V5Y($QA:V4G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U-RXS-3`Z+3$P-RXQ,S,G72`]("=#<F5E
M($QA:V4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO
M;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<U-RXU,S,Z+3$Q
M,2XU-C<G72`]("=-:6QD<F5D($QA:V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<U."XQ,#`Z+38X+C0Q-R==(#T@)TMU=6IJ=6%Q+"!1=64N)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N,3@S.BTQ,#,N-S`P)UT@/2`G0V]L
M;&EN<R!"87D@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<[
M"B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C,S,SHM-C(N-3@S)UT@/2`G
M4V%G;&5K($)A>2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C,X,SHM
M,3`Y+C4P,"==(#T@)T-L=69F($QA:V4L(%-A<VLN)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-3@N-#$W.BTQ,S`N,#`P)UT@/2`G1&5A<V4@3&%K92!"
M+B!#+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X+C0Q-SHM,3,P+C`P
M,"==(#T@)T1E87-E($QA:V4@0V]A<W1A;"!3=&%T:6]N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-3@N-#4P.BTW."XQ,3<G72`]("=);G5K:G5A:RP@
M475E)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N-3@S.BTQ,3@N-3`P
M)UT@/2`G4V]U<V$@0W)K($%V="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S4X+C8Q-SHM,3$W+C$V-R==(#T@)TAI9V@@3&5V96PL($%L=&$G.PHD8V]O
M<F1I;F%T97-;)T-A;F%D82==6R<U."XV,C(Z+3$Q,2XV-S(G72`]("=0<F%I
M<FEE(%)I=F5R+"!!;'1A)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-3@N
M-C@S.BTQ,3,N.#@S)UT@/2`G1V%R9&5N(%)I=F5R($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<U."XW,S,Z+3DT+C`V-R==(#T@)T-H=7)C:&EL;"P@36%N+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4X+C<V-SHM,3$Q+C$Q-R==(#T@)T9O<G0@
M0VAI<&5W>6%N+"!!;'1A+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4X
M+C@S,SHM,3(R+C4X,R==(#T@)T9O<G0@3F5L<V]N+"!"+B!#+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S4Y+C$S,SHM,3$S+C@P,"==(#T@)U=A=&5R
M=&]N(%!A<FL@1V%T92<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Y+C(Q
M-SHM,3`Y+C<P,"==(#T@)T)E87)T;V]T:"!)<VQA;F0G.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U.2XR-3`Z+3$P-2XX,S,G72`]("=3=&]N>2!287!I
M9',@06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S4Y+C4V-SHM
M,3`X+C0X,R==(#T@)U5R86YI=6T@0VET>2P@4V%S:RXG.PHD8V]O<F1I;F%T
M97-;)T-A;F%D82==6R<U.2XY.#,Z+38T+C$V-R==(#T@)T-A<&4@2V%K:VEV
M:6%K)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C`N,#$W.BTQ,3$N.34P
M)UT@/2`G1F]R="!3;6ET:"P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V,"XQ,3<Z+3$R."XX,3<G72`]("=7871S;VX@3&%K92P@62X@
M5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,"XQ-C<Z+3$S,BXW,S,G
M72`]("=497-L:6XL(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C`N-#$W.BTV-"XX-3`G72`]("=+:6QL:6YE:R!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8P+C0S,SHM,3(Q+C(S,R==(#T@)U1R;W5T($QA:V4G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,"XW,3<Z+3$S-2XP-C<G72`]
M("=7:&ET96AO<G-E+"!9+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S8P+C<V-SHM,3,W+C4X,R==(#T@)TAA:6YE<R!*=6YC=&EO;B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8P+C@S,SHM,3$U+C<X,R==(#T@)TAA>2!2
M:79E<BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XP
M-3`Z+3$P.2XS,S,G72`]("=0;W=D97(@3&%K92<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S8Q+C`U,#HM-CDN-C,S)UT@/2`G475A<71A<2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N,3$W.BTQ,C(N.#4P)UT@
M/2`G3&EN9&)E<F<@3&%N9&EN9RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;
M)T-A;F%D82==6R<V,2XQ,S,Z+3$P,"XY,#`G72`]("=%;FYA9&%I($QA:V4@
M365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E;G1A=&EO;B!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,2XS,3<Z+3$Q-RXV,#`G
M72`]("=&;W)T(%!R;W9I9&5N8V4G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,2XS-C<Z+3$S.2XP-3`G72`]("="=7)W87-H($%U=&]M871I8R!796%T
M:&5R(%)E<&]R=&EN9R!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,2XU.#,Z+38T+C8U,"==(#T@)U)E<V]L=71I;VX@27-L86YD+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8Q+C8S,SHM,3(U+C@P
M,"==(#T@)U9I<F=I;FEA($9A;&QS)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-C$N-C8W.BTQ,#@N-#$W)UT@/2`G4&]R=&5R($QA:V4G.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V,2XW-3`Z+3$R,2XR,S,G72`]("=&;W)T(%-I
M;7!S;VXL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C$N
M.3$W.BTQ,3,N-S,S)UT@/2`G26YN97(@5VAA;&5B86-K<R<["B1C;V]R9&EN
M871E<ULG0V%N861A)UU;)S8Q+CDV-SHM,3(W+C(Q-R==(#T@)U)A8F)I="!+
M971T;&4@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-C(N,3$W.BTQ,S8N,3@S)UT@/2`G0V%R;6%C:W,@
M0U,L(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C(N,C,S.BTQ
M,S,N,S4P)UT@/2`G1F%R;RP@62X@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D
M82==6R<V,BXT-C<Z+3$Q-"XT-3`G72`]("=996QL;W=K;FEF92P@3BX@5RX@
M5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,BXW,#`Z+3DX+C,P,"==
M(#T@)UEA=&AK>65D($QA:V4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L
M(%!R97-E;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V,BXW,3<Z+3$P.2XQ.#,G72`]("=&;W)T(%)E;&EA;F-E+"!.+B!7+B!4
M+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8R+C@Q-SHM.3(N,3$W)UT@
M/2`G4F%N:VEN($EN;&5T+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8S+C$U,#HM,3$W+C(V-R==(#T@)TQA8R!,82!-87)T<F4G.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXR,S,Z+3$P,2XW-C<G72`]("=$
M=6)A=VYT($QA:V4@365T96]R;VQO9VEC86P@065R;VYA=71I8V%L(%!R97-E
M;G1A=&EO;B!3>7-T96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V,RXS
M,S,Z+38T+C$U,"==(#T@)T)R979O;W)T($ES;&%N9"<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8S+C4X,SHM,3`U+C$U,"==(#T@)TAA;F)U<GD@4FEV
M97(@075T;VUA=&5D(%)E<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C,N-C`P.BTQ,3,N.#8W)UT@/2`G3&]W97(@0V%R<"!,
M86ME+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8S+C8Q
M-SHM,3,U+C@V-R==(#T@)TUA>6\@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M0V%N861A)UU;)S8S+C<U,#HM-C@N-34P)UT@/2`G27%A;'5I="P@3BX@5RX@
M5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-"XP-3`Z+3$S.2XQ,S,G
M72`]("=$87=S;VXL(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C0N,3$W.BTQ,3<N,S8W)UT@/2`G4F%E($QA:V5S)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C0N,C`P.BTX,RXS-C<G72`]("=#;W)A;"!(87)B;W5R
M+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C(Q-SHM
M-S8N-3,S)UT@/2`G0V%P92!$;W)S970L($XN(%<N(%0N)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-C0N,S`P.BTY-BXP.#,G72`]("="86ME<B!,86ME
M+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8T+C,X,SHM
M,3$U+C`Q-R==(#T@)TEN9&EA;B!2:79E<B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8T+C<U,#HM,3(T+C(Q-R==(#T@)U-T($-H87)L97,@0W)E96LG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-"XY-3`Z+38S+C4X,R==(#T@
M)T-A<&4@365R8WDG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-2XQ,#`Z
M+3$P,BXT,S,G72`]("=2;V)E<G1S;VX@3&%K92!!=71O;6%T960@4F5P;W)T
M:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-2XR,3<Z
M+3$R,RXT,S,G72`]("=$96QI;F4L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C4N,C@S.BTQ,C8N.#`P)UT@/2`G3F]R;6%N(%=E;&QS
M+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8U+C8Q-SHM
M,3$X+C$Q-R==(#T@)T-A;7-E;&P@4FEV97(L($XN(%<N(%0N)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C4N-S8W.BTQ,3$N,C,S)UT@/2`G3'5P:6XL
M($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C4N.34P.BTQ
M,S`N-#8W)UT@/2`G4F%M<&%R="!2:79E<B!!=71O;6%T:6,@5V5A=&AE<B!2
M97!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C8N
M,#`P.BTQ,3<N-S8W)UT@/2`G0VQU="!,86ME($%U=&]M871E9"!297!O<G1I
M;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8V+C`S,SHM
M.3$N.#,S)UT@/2`G0BP@4B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8V
M+C`X,SHM.38N-3`P)UT@/2`G0F%C:R!2:79E<B!-971E;W)O;&]G:6-A;"!!
M97)O;F%U=&EC86P@4')E<V5N=&%T:6]N(%-Y<W1E;2<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8V+C$U,#HM-C4N-S,S)UT@/2`G4&%N9VYI<G1U;F<G
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V-BXU.#,Z+38Q+C8Q-R==(#T@
M)T-A<&4@1'EE<BP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V-BXX-C<Z+3$S-"XR,#`G72`]("=3871A:"!2:79E<B!!=71O;6%T:6,@
M5V5A=&AE<B!297!O<G1I;F<@4WES=&5M)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C<N,#,S.BTQ,C8N,#@S)UT@/2`G0V]L=FEL;&4@3&%K92<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8W+C`V-SHM,3(Q+C$P,"==(#T@)TAA
M;&1A;F4@4FEV97(@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E
M;2<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8W+C(P,#HM,3,P+C(Q-R==
M(#T@)TQI='1L92!#:&EC86=O)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG
M-C<N-3,S.BTV,RXW.#,G72`]("="<F]U9VAT;VX@27-L86YD)SL*)&-O;W)D
M:6YA=&5S6R=#86YA9&$G75LG-C<N-38W.BTQ,SDN.#,S)UT@/2`G3VQD($-R
M;W<@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8W+C<P,#HM,3`T+C0V-R==(#T@)T5L;&EC
M92!2:79E<B!!=71O;6%T960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V-RXX,3<Z+3$Q-2XQ,S,G72`]("=#;W!P97)M
M:6YE+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C(U
M.#HM,3(R+C$P-"==(#T@)U%A=G9I:R!,86ME+"!.+B!7+B!4+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8X+C,P,#HM,3,S+C0X,R==(#T@)TEN=79I
M:RP@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XS,#`Z
M+3@U+C8V-R==(#T@)TUA8VMA<B!);FQE="<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8X+C,Q-SHM,3`P+C`X,R==(#T@)TAA="!)<VQA;F0L($XN(%<N
M(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-#,S.BTX.2XW,3<G
M72`]("=096QL>2!"87DG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XT
M-C<Z+38V+C@P,"==(#T@)T-A<&4@2&]O<&5R+"!.+B!7+B!4+B<["B1C;V]R
M9&EN871E<ULG0V%N861A)UU;)S8X+C4P,#HM,3$S+C(Q-R==(#T@)TQA9'D@
M1G)A;FML:6X@4&]I;G0L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-C@N-C4P.BTQ,#$N-S,S)UT@/2`G2F5N;GD@3&EN9"!)<VQA;F0@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C8U,#HM-S$N
M,38W)UT@/2`G1&5W87(@3&%K97,L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C@N-S4P.BTQ,#DN,#8W)UT@/2`G0GER;VX@0F%Y($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V."XW-3`Z+3$S,RXU
M,#`G72`]("=4<F%I;"!686QL97DL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S
M6R=#86YA9&$G75LG-C@N-S@S.BTQ,30N.#,S)UT@/2`G0F5R;F%R9"!(87)B
M;W5R)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-C@N-S@S.BTX,2XR-3`G
M72`]("=(86QL($)E86-H+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8X+C@Q-SHM.3,N-#,S)UT@/2`G4VAE<&AE<F0@0F%Y+"!.+B!7
M+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+C@X,SHM-S4N,3,S
M)UT@/2`G3&]N9W-T869F($)L=69F+"!.+B!7+B!4+B<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+CDP,#HM,3,S+CDS,R==(#T@)U-T;W)M($AI;&QS
M+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S8X+CDS,SHM
M,3$V+CDQ-R==(#T@)T-A<&4@66]U;F<@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0V%N861A)UU;)S8X+CDU,#HM,3,W+C(Q-R==(#T@)U-H:6YG;&4@4&]I
M;G0L(%DN(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN,3`P.BTQ
M,#4N,3$W)UT@/2`G0V%M8G)I9&=E($)A>2P@3BX@5RX@5"XG.PHD8V]O<F1I
M;F%T97-;)T-A;F%D82==6R<V.2XQ-3`Z+3$T,"XQ-3`G72`]("=)=G9A=FEK
M(%!A<FL@075T;VUA=&EC(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C
M;V]R9&EN871E<ULG0V%N861A)UU;)S8Y+C$X,SHM,3(R+C,U,"==(#T@)U1U
M:W1U="!.;V=A:70L($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G
M75LG-CDN,S4P.BTQ,C0N,#4P)UT@/2`G4&%U;&%T=6L@075T;VUA=&5D(%)E
M<&]R=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN
M-#,S.BTQ,S,N,#,S)UT@/2`G5'5K=&]Y86MT=6L@075T;VUA=&5D(%)E<&]R
M=&EN9R!3=&%T:6]N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-#,S
M.BTX.2XW,S,G72`]("=096QL>2!"87D@,2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8Y+C0U,#HM,3,S+C`Q-R==(#T@)U1U:W1O>6%K='5K)SL*)&-O
M;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-38W.BTQ,S@N.3$W)UT@/2`G2&5R
M<V-H96P@27-L86YD($%U=&]M871I8R!796%T:&5R(%)E<&]R=&EN9R!3>7-T
M96TG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<V.2XU.#,Z+3$T,"XQ.#,G
M72`]("=+;VUA:W5K($)E86-H($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T-A
M;F%D82==6R<V.2XV,#`Z+3$S,"XY,#`G72`]("=,:79E<G!O;VP@0F%Y)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-CDN-C$W.BTQ-#`N,C`P)UT@/2`G
M2V]M86MU:R!"96%C:"P@62X@5"XG.PHD8V]O<F1I;F%T97-;)T-A;F%D82==
M6R<V.2XV,S,Z+3$S-2XT,S,G72`]("=096QL>2!)<VQA;F0@075T;VUA=&EC
M(%=E871H97(@4F5P;W)T:6YG(%-Y<W1E;2<["B1C;V]R9&EN871E<ULG0V%N
M861A)UU;)S8Y+CDS,SHM,3(X+CDV-R==(#T@)TYI8VAO;'-O;B!096YI;G-U
M;"<["B1C;V]R9&EN871E<ULG0V%N861A)UU;)S<P+C$V-SHM,3(T+C<P,"==
M(#T@)T-A<&4@4&%R<GDL($XN(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA
M9&$G75LG-S`N-#@S.BTV."XU,3<G72`]("=#;'ED92P@3BX@5RX@5"XG.PHD
M8V]O<F1I;F%T97-;)T-A;F%D82==6R<W,BXP,#`Z+3$R-2XR-C<G72`]("=3
M86-H<R!(87)B;W5R+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S<R+C<P,#HM-S<N.38W)UT@/2`G4&]N9"!);FQE="P@3BX@5RX@5"XG
M.PHD8V]O<F1I;F%T97-;)T-A;F%D82==6R<W-"XQ,S,Z+3$Q.2XY.#,G72`]
M("=!=6QV:6L@3F%T:6]N86P@4&%R:R<["B1C;V]R9&EN871E<ULG0V%N861A
M)UU;)S<T+C<Q-SHM.30N.3@S)UT@/2`G4F5S;VQU=&4L($XN(%<N(%0N)SL*
M)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG-S8N,C,S.BTQ,3DN,S,S)UT@/2`G
M36]U;&0@0F%Y+"!.+B!7+B!4+B<["B1C;V]R9&EN871E<ULG0V%N861A)UU;
M)S<X+C<X,SHM,3`S+C4U,"==(#T@)TES86-H<V5N($UE=&5O<F]L;V=I8V%L
M($%E<F]N875T:6-A;"!0<F5S96YT871I;VX@4WES=&5M)SL*)&-O;W)D:6YA
M=&5S6R=#86YA9&$G75LG-SDN.3@S.BTX-2XY,S,G72`]("=%=7)E:V$L($XN
M(%<N(%0N)SL*)&-O;W)D:6YA=&5S6R=#86YA9&$G75LG.#(N-3`P.BTV,BXS
M,S,G72`]("=!;&5R="P@3BX@5RX@5"XG.PHD8V]O<F1I;F%T97-;)T-A<&4@
M5F5R9&4G75LG,38N-S,S.BTR,BXY-3`G72`]("=386PG.PHD8V]O<F1I;F%T
M97-;)T-A>6UA;B!)<VQA;F1S)UU;)S$Y+C(X,SHM.#$N,S4P)UT@/2`G3W=E
M;B!2;V)E<G1S($%I<G!O<G1G<F%N9"!#87EM86XG.PHD8V]O<F1I;F%T97-;
M)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<Q,"XR.#,Z,C(N-S@S)UT@
M/2`G0FER86\G.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U
M8FQI8R==6R<T+C(U,#HQ-2XX,#`G72`]("="97)B97)A=&DG.PHD8V]O<F1I
M;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<T+C0P,#HQ."XU
M,3<G72`]("="86YG=6DG.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A
M;B!297!U8FQI8R==6R<T+C<S,SHR,BXX,S,G72`]("="86YG87-S;W4G.PHD
M8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<U+C`U
M,#HR,2XR,#`G72`]("=!;&EN9&%O)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L
M($%F<FEC86X@4F5P=6)L:6,G75LG-2XR-C<Z,3<N-C,S)UT@/2`G0F]S<V5M
M8F5L92<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC
M)UU;)S4N-#`P.C(V+C4P,"==(#T@)T]B;R<["B1C;V]R9&EN871E<ULG0V5N
M=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S4N.#4P.C(P+C8U,"==(#T@)T)A
M;6)A<FDG.PHD8V]O<F1I;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI
M8R==6R<U+CDV-SHQ-2XV,S,G72`]("=";W5A<B<["B1C;V]R9&EN871E<ULG
M0V5N=')A;"!!9G)I8V%N(%)E<'5B;&EC)UU;)S8N-#@S.C$W+C0S,R==(#T@
M)T)O<W-A;F=O82<["B1C;V]R9&EN871E<ULG0V5N=')A;"!!9G)I8V%N(%)E
M<'5B;&EC)UU;)S8N-3`P.C(S+C(V-R==(#T@)UEA;&EN9V$G.PHD8V]O<F1I
M;F%T97-;)T-E;G1R86P@069R:6-A;B!297!U8FQI8R==6R<V+C4S,SHR,2XY
M.#,G72`]("="<FEA)SL*)&-O;W)D:6YA=&5S6R=#96YT<F%L($%F<FEC86X@
M4F5P=6)L:6,G75LG."XT,#`Z,C`N-C4P)UT@/2`G3EPG1&5L92<["B1C;V]R
M9&EN871E<ULG0VAA9"==6R<Q,2XP,S,Z,C`N,C@S)UT@/2`G06TM5&EM86XG
M.PHD8V]O<F1I;F%T97-;)T-H860G75LG,3(N,3,S.C$U+C`S,R==(#T@)TYD
M:F%M96YA)SL*)&-O;W)D:6YA=&5S6R=#:&%D)UU;)S$R+C,X,SHQ-RXP-3`G
M72`]("=";VMO<F\G.PHD8V]O<F1I;F%T97-;)T-H860G75LG,3,N-#,S.C$T
M+C<S,R==(#T@)T)O;"U"97)I;2<["B1C;V]R9&EN871E<ULG0VAA9"==6R<Q
M,RXX-3`Z,C`N.#4P)UT@/2`G06)E8VAE)SL*)&-O;W)D:6YA=&5S6R=#:&%D
M)UU;)S$X+C`P,#HQ.2XQ-C<G72`]("=&87EA)SL*)&-O;W)D:6YA=&5S6R=#
M:&%D)UU;)S@N-C$W.C$V+C`V-R==(#T@)TUO=6YD;W4G.PHD8V]O<F1I;F%T
M97-;)T-H860G75LG.2XQ-3`Z,3@N,S@S)UT@/2`G4V%R:"<["B1C;V]R9&EN
M871E<ULG0VAA9"==6R<Y+C,V-SHQ-"XY,3<G72`]("=086QA)SL*)&-O;W)D
M:6YA=&5S6R=#:&EL92==6R<M,3@N,S,S.BTW,"XS,S,G72`]("=!<FEC82<[
M"B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3(P+C4S,SHM-S`N,3@S)UT@/2`G
M27%U:7%U92`O($1I96=O($%R86,G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;
M)RTR,RXT,S,Z+3<P+C0S,R==(#T@)T%N=&]F86=A<W1A)SL*)&-O;W)D:6YA
M=&5S6R=#:&EL92==6R<M,C8N,S$W.BTW,"XV,3<G72`]("=#:&%N87)A;"<[
M"B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3(W+C$U,#HM,3`Y+C0Q-R==(#T@
M)TES;&$@1&4@4&%S8W5A)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,C<N
M,S`P.BTW,"XT,3<G72`]("=#;W!I87!O)SL*)&-O;W)D:6YA=&5S6R=#:&EL
M92==6R<M,C@N-C`P.BTW,"XW-C<G72`]("=686QL96YA<B<["B1C;V]R9&EN
M871E<ULG0VAI;&4G75LG+3(Y+CDP,#HM-S$N,C`P)UT@/2`G3&$@4V5R96YA
M)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M,S(N-S@S.BTW,2XU,3<G72`]
M("=1=6EN=&5R;R!386YT:6%G;R<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG
M+3,S+C,X,SHM-S`N-S@S)UT@/2`G4'5D86AU96PG.PHD8V]O<F1I;F%T97-;
M)T-H:6QE)UU;)RTS-"XY-C<Z+3<Q+C(S,R==(#T@)T-U<FEC;R<["B1C;V]R
M9&EN871E<ULG0VAI;&4G75LG+3,V+C4V-SHM-S(N,#,S)UT@/2`G0VAI;&QA
M;B<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,V+C<V-SHM-S,N,#4P)UT@
M/2`G0V]N8V5P8VEO;B<["B1C;V]R9&EN871E<ULG0VAI;&4G75LG+3,X+C<U
M,#HM-S(N-C,S)UT@/2`G5&5M=6-O)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==
M6R<M,SDN-C$W.BTW,RXP.#,G72`]("=686QD:79I82<["B1C;V]R9&EN871E
M<ULG0VAI;&4G75LG+30Q+C0Q-SHM-S,N,#@S)UT@/2`G4'5E<G1O($UO;G1T
M)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M-#4N-3@S.BTW,BXQ,3<G72`]
M("=#;WEH86EQ=64G.PHD8V]O<F1I;F%T97-;)T-H:6QE)UU;)RTT-2XY,3<Z
M+3<Q+C8X,R==(#T@)T)A;&UA8V5D82<["B1C;V]R9&EN871E<ULG0VAI;&4G
M75LG+30V+C4U,#HM-S$N-S`P)UT@/2`G0VAI;&4@0VAI8V\G.PHD8V]O<F1I
M;F%T97-;)T-H:6QE)UU;)RTT-RXR,S,Z+3<R+C4U,"==(#T@)T-O8VAR86YE
M)SL*)&-O;W)D:6YA=&5S6R=#:&EL92==6R<M-3,N,#`P.BTW,"XX-3`G72`]
M("=0=6YT82!!<F5N87,G.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S(P+C`S
M,SHQ,3`N,S4P)UT@/2`G2&%I:V]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==
M6R<R,2XR,3<Z,3$P+C0P,"==(#T@)UIH86YJ:6%N9R<["B1C;V]R9&EN871E
M<ULG0VAI;F$G75LG,C(N-34P.C$Q-"XQ,#`G72`]("=3:&5N>FAE;B<["B1C
M;V]R9&EN871E<ULG0VAI;F$G75LG,C(N.#$W.C$P."XS-3`G72`]("=.86YN
M:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R,RXQ-C<Z,3$S+C,S,R==
M(#T@)T=U86YG>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C,N-#`P
M.C$Q-BXV.#,G72`]("=3:&%N=&]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==
M6R<R-"XT.#,Z,3$X+C`X,R==(#T@)UAI86UE;B<["B1C;V]R9&EN871E<ULG
M0VAI;F$G75LG,C4N,#$W.C$P,BXV.#,G72`]("=+=6YM:6YG)SL*)&-O;W)D
M:6YA=&5S6R=#:&EN82==6R<R-2XS,S,Z,3$P+C,P,"==(#T@)T=U:6QI;B<[
M"B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C4N.#4P.C$Q-"XY-3`G72`]("='
M86YZ:&]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<R-BXP.#,Z,3$Y+C(X
M,R==(#T@)T9U>FAO=2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,C8N-3@S
M.C$P-BXW,3<G72`]("='=6EY86YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==
M6R<R."XR,#`Z,3$S+C`X,R==(#T@)T-H86YG<VAA)SL*)&-O;W)D:6YA=&5S
M6R=#:&EN82==6R<R."XV,#`Z,3$U+CDQ-R==(#T@)TYA;F-H86YG)SL*)&-O
M;W)D:6YA=&5S6R=#:&EN82==6R<R.2XU,3<Z,3`V+C0X,R==(#T@)T-H;VYG
M<6EN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,CDN-C8W.CDQ+C$S,R==
M(#T@)TQH87-A)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S,"XR,S,Z,3(P
M+C$V-R==(#T@)TAA;F=Z:&]U)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S
M,"XV,3<Z,3$T+C$S,R==(#T@)U=U:&%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN
M82==6R<S,"XV-C<Z,3`T+C`Q-R==(#T@)T-H96YG9'4G.PHD8V]O<F1I;F%T
M97-;)T-H:6YA)UU;)S,Q+C$V-SHQ,C$N-#,S)UT@/2`G4VAA;F=H86D@+R!(
M;VYG<6EA;R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S$N.#8W.C$Q-RXR
M,S,G72`]("=(969E:2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S(N,#`P
M.C$Q."XX,#`G72`]("=.86YJ:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==
M6R<S-"XS,#`Z,3`X+CDS,R==(#T@)UAI7"=!;B<["B1C;V]R9&EN871E<ULG
M0VAI;F$G75LG,S0N-S$W.C$Q,RXV-3`G72`]("=::&5N9WIH;W4G.PHD8V]O
M<F1I;F%T97-;)T-H:6YA)UU;)S,V+C`V-SHQ,C`N,S,S)UT@/2`G46EN9V1A
M;R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S8N-C`P.C$P.2XU,#`G72`]
M("=986X@06XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,V+C8Q-SHQ,#$N
M-S8W)UT@/2`G6&EN:6YG)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==6R<S-BXV
M.#,Z,3$V+CDX,R==(#T@)TII;F%N)SL*)&-O;W)D:6YA=&5S6R=#:&EN82==
M6R<S-RXQ,S,Z-SDN.3,S)UT@/2`G2&]T86XG.PHD8V]O<F1I;F%T97-;)T-H
M:6YA)UU;)S,W+C<X,SHQ,3(N-34P)UT@/2`G5&%I>75A;B<["B1C;V]R9&EN
M871E<ULG0VAI;F$G75LG,S@N-#@S.C$P-BXR,3<G72`]("=9:6YC:'5A;B<[
M"B1C;V]R9&EN871E<ULG0VAI;F$G75LG,S@N.3`P.C$R,2XV,S,G72`]("=$
M86QI86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Y+C0V-SHW-2XY.#,G
M72`]("=+87-H:2<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG,SDN-S8W.CDX
M+C0X,R==(#T@)TII=7%U86XG.PHD8V]O<F1I;F%T97-;)T-H:6YA)UU;)S,Y
M+CDS,SHQ,38N,C@S)UT@/2`G0F5I:FEN9R<["B1C;V]R9&EN871E<ULG0VAI
M;F$G75LG-#`N.#$W.C$Q,2XV.#,G72`]("=(;VAH;W0G.PHD8V]O<F1I;F%T
M97-;)T-H:6YA)UU;)S0R+C@Q-SHY,RXU,3<G72`]("=(86UI)SL*)&-O;W)D
M:6YA=&5S6R=#:&EN82==6R<T,RXY,#`Z,3(U+C(Q-R==(#T@)T-H86YG8VAU
M;B<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG-#,N.34P.C@Q+C,S,R==(#T@
M)UEI;FEN9R<["B1C;V]R9&EN871E<ULG0VAI;F$G75LG-#<N,S@S.C$R,RXY
M,3<G72`]("=1:7%I:&%R)SL*)&-O;W)D:6YA=&5S6R=#:')I<W1M87,@27-L
M86YD)UU;)RTQ,"XT,S,Z,3`U+C8X,R==(#T@)T-H<FES=&UA<R!)<VQA;F0@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=#:')I<W1M87,@27-L86YD)UU;
M)RTQ,BXQ.#,Z.38N.#$W)UT@/2`G0V]C;W,@27-L86YD($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S`N-3`P.BTW-BXU,#`G72`]("=0
M=65R=&\@07-I<R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,"XX,3<Z
M+3<W+C8S,R==(#T@)TEP:6%L97,@+R!386X@3'5I<R<["B1C;V]R9&EN871E
M<ULG0V]L;VUB:6$G75LG,2XQ,S,Z+3<P+C`U,"==(#T@)TUI='4G.PHD8V]O
M<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$N-#$W.BTW-RXR-C<G72`]("=087-T
M;R`O($%N=&]N:6\@3F%R:6XG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;
M)S$P+C0S,SHM-S,N,C4P)UT@/2`G5F%L;&5D=7!A<B`O($%L9F]N<V\@3&]P
M97HG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$P+C0U,#HM-S4N-3$W
M)UT@/2`G0V%R=&%G96YA("\@4F%F865L($YU;F5Z)SL*)&-O;W)D:6YA=&5S
M6R=#;VQO;6)I82==6R<Q,"XX.#,Z+3<T+C<X,R==(#T@)T)A<G)A;G%U:6QL
M82`O($5R;F5S=&]C;W)T:7-S;WHG.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)S$Q+C$S,SHM-S0N,C,S)UT@/2`G4V%N=&$@36%R=&$@+R!3:6UO;B!"
M;VQI=F%R)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<Q,2XU,S,Z+3<R
M+CDS,R==(#T@)U)I;VAA8VAA("\@06QM:7)A;G1E(%!A9&EL;&$G.PHD8V]O
M<F1I;F%T97-;)T-O;&]M8FEA)UU;)S$R+C4X,SHM.#$N-S$W)UT@/2`G4V%N
M($%N9')E<R!)<VQA("\@4V5S<75I8V5N=&5N87)I;R<["B1C;V]R9&EN871E
M<ULG0V]L;VUB:6$G75LG,3,N,S8W.BTX,2XS-3`G72`]("=0<F]V:61E;F-I
M82!)<VQA("\@16P@16UB<G5J;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G
M75LG,BXT-C<Z+3<V+C8P,"==(#T@)U!O<&%Y86X@+R!'=6EL;&5R;6\G.PHD
M8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S(N-38W.BTW,BXV,S,G72`]("=3
M86X@2F]S92!$96P@1W5A=FEA<F4G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)S(N.38W.BTW-2XS,#`G72`]("=.96EV82`O($)E;FET;R!386QA<R<[
M"B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG,RXU-3`Z+3<V+C,X,R==(#T@
M)T-A;&D@+R!!;&9O;G-O($)O;FEL;&%A<F%G;VXG.PHD8V]O<F1I;F%T97-;
M)T-O;&]M8FEA)UU;)S,N.#4P.BTW-BXY-C<G72`]("="=65N879E;G1U<F$G
M.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)RTT+C$V-SHM-CDN.34P)UT@
M/2`G3&5T:6-I82`O(%9A<W%U97H@0V]B;R<["B1C;V]R9&EN871E<ULG0V]L
M;VUB:6$G75LG-"XQ-C<Z+3<S+C8Q-R==(#T@)U9I;&QA=FEC96YC:6\@+R!6
M86YG=6%R9&EA)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<T+C0S,SHM
M-S4N,34P)UT@/2`G26)A9W5E("\@4&5R86QE<R<["B1C;V]R9&EN871E<ULG
M0V]L;VUB:6$G75LG-"XU,#`Z+3<U+C<Q-R==(#T@)T%R;65N:6$@+R!%;"!%
M9&5N)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<T+C<Q-SHM-S0N,34P
M)UT@/2`G0F]G;W1A("\@16QD;W)A9&\G.PHD8V]O<F1I;F%T97-;)T-O;&]M
M8FEA)UU;)S0N.#$W.BTW-2XW,S,G72`]("=097)E:7)A("\@36%T96-A;F$G
M.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S4N-S$W.BTW-BXV,3<G72`]
M("=1=6EB9&\@+R!%;"!#87)A;F\G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA
M)UU;)S8N,3,S.BTW-2XT,S,G72`]("=2:6]N96=R;R`O($HN($TN($-O<F1O
M=F$G.PHD8V]O<F1I;F%T97-;)T-O;&]M8FEA)UU;)S8N,38W.BTV-RXU,#`G
M72`]("=0=65R=&\@0V%R<F5N;R`O($$N($=U875Q=65A)SL*)&-O;W)D:6YA
M=&5S6R=#;VQO;6)I82==6R<V+C(Q-SHM-S4N-C`P)UT@/2`G365D96QL:6X@
M+R!/;&%Y82!(97)R97)A)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<W
M+C`Q-SHM-S,N.#`P)UT@/2`G0F%R<F%N8V%B97)M96IA("\@66%R:6=U:65S
M)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<W+C`V-SHM-S`N-S,S)UT@
M/2`G07)A=6-A("\@4V%N=&EA9V\@4&5R97HG.PHD8V]O<F1I;F%T97-;)T-O
M;&]M8FEA)UU;)S<N,3`P.BTW,RXR,#`G72`]("="=6-A<F%M86YG82`O(%!A
M;&]N96=R;R<["B1C;V]R9&EN871E<ULG0V]L;VUB:6$G75LG-RXX,3<Z+3<V
M+C<P,"==(#T@)T%P87)T861O("\@3&]S($-E9')O<R<["B1C;V]R9&EN871E
M<ULG0V]L;VUB:6$G75LG-RXY,S,Z+3<R+C4Q-R==(#T@)T-U8W5T82`O($-A
M;6EL;R!$87IA)SL*)&-O;W)D:6YA=&5S6R=#;VQO;6)I82==6R<X+C@Q-SHM
M-S4N.#4P)UT@/2`G36]N=&5R:6$@+R!,;W,@1V%R>F]N97,G.PHD8V]O<F1I
M;F%T97-;)T-O;6]R;W,G75LG+3$Q+C4S,SHT,RXR-C<G72`]("=(86AA>6$@
M26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#;VUO<F]S
M)UU;)RTQ,BXQ,3<Z-#0N-#,S)UT@/2`G3W5A;FD@06YJ;W5A;B<["B1C;V]R
M9&EN871E<ULG0V]M;W)O<R==6R<M,3(N.#`P.C0U+C(X,R==(#T@)T1Z86]U
M9'II("\@4&%M86YZ:2!-87EO='1E)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==
M6R<M,"XP,3<Z,34N-3@S)UT@/2`G36%K;W5A)SL*)&-O;W)D:6YA=&5S6R=#
M;VYG;R==6R<Q+C8Q-SHQ-BXP-3`G72`]("=/=65S<V\G.PHD8V]O<F1I;F%T
M97-;)T-O;F=O)UU;)S$N-C$W.C$X+C`V-R==(#T@)TEM<&9O;F1O)SL*)&-O
M;W)D:6YA=&5S6R=#;VYG;R==6R<M,2XX-C<Z,34N.#8W)UT@/2`G1V%M8F]M
M82<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG,BXP-C<Z,30N,3,S)UT@/2`G
M4V]U86YK92<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+3(N-3,S.C$T+C<V
M-R==(#T@)T1J86UB86QA)SL*)&-O;W)D:6YA=&5S6R=#;VYG;R==6R<M,BXV
M,3<Z,38N,C$W)UT@/2`G35PG4&]U>6$G.PHD8V]O<F1I;F%T97-;)T-O;F=O
M)UU;)RTS+C0X,SHQ,BXV,3<G72`]("=-86MA8F%N82<["B1C;V]R9&EN871E
M<ULG0V]N9V\G75LG+3,N-C@S.C$S+C,U,"==(#T@)U-I8FET:2<["B1C;V]R
M9&EN871E<ULG0V]N9V\G75LG+3,N.3@S.C$S+CDQ-R==(#T@)TUO=7EO;F1Z
M:2<["B1C;V]R9&EN871E<ULG0V]N9V\G75LG+30N,C`P.C$R+C<P,"==(#T@
M)TQO=6)O;6\G.PHD8V]O<F1I;F%T97-;)T-O;F=O)UU;)RTT+C(U,#HQ-2XR
M-3`G72`]("="<F%Z>F%V:6QL92`O($UA>6$M36%Y82<["B1C;V]R9&EN871E
M<ULG0V]N9V\G75LG+30N.#$W.C$Q+CDP,"==(#T@)U!O:6YT92U.;VER92<[
M"B1C;V]R9&EN871E<ULG0V]O:R!)<VQA;F1S)UU;)RTQ.2XP-C<Z+3$V.2XY
M,3<G72`]("=!;&]F:2`O($YI=64G.PHD8V]O<F1I;F%T97-;)T-O;VL@27-L
M86YD<R==6R<M,C$N,C`P.BTQ-3DN.#$W)UT@/2`G4F%R;W1O;F=A)SL*)&-O
M;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;)S$P+C`P,#HM.#,N,#4P)UT@/2`G
M4'5E<G1O($QI;6]N)SL*)&-O;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;)S$P
M+C`P,#HM.#0N,C$W)UT@/2`G2G5A;B!386YT86UA<FEA)SL*)&-O;W)D:6YA
M=&5S6R=#;W-T82!2:6-A)UU;)S$P+C$U,#HM.#4N-#4P)UT@/2`G3FEC;WEA
M)SL*)&-O;W)D:6YA=&5S6R=#;W-T82!2:6-A)UU;)S$P+C8Q-SHM.#4N-#,S
M)UT@/2`G3&EB97)I82<["B1C;V]R9&EN871E<ULG0V]S=&$@4FEC82==6R<X
M+CDU,#HM.#,N-#8W)UT@/2`G4&%L;6%R(%-U<B<["B1C;V]R9&EN871E<ULG
M0V]T92!$7"=)=F]I<F4G75LG-"XT,3<Z+3<N,S8W)UT@/2`G5&%B;W4G.PHD
M8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S0N-S4P.BTV+C8U,"==
M(#T@)U-A;B!0961R;R<["B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G
M75LG-"XY-3`Z+38N,#@S)UT@/2`G4V%S<V%N9')A)SL*)&-O;W)D:6YA=&5S
M6R=#;W1E($1<)TEV;VER92==6R<U+C(U,#HM,RXY,S,G72`]("=!8FED:F%N
M)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==6R<U+C,P,#HM,RXS
M,#`G72`]("=!9&EA:V4G.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E
M)UU;)S8N,3,S.BTU+CDU,"==(#T@)T=A9VYO82<["B1C;V]R9&EN871E<ULG
M0V]T92!$7"=)=F]I<F4G75LG-BXV-3`Z+30N-S`P)UT@/2`G1&EM8F]K<F\G
M.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)S8N.#8W.BTV+C0V
M-R==(#T@)T1A;&]A)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==
M6R<V+CDP,#HM-2XS-3`G72`]("=986UO=7-S;W5K<F\G.PHD8V]O<F1I;F%T
M97-;)T-O=&4@1%PG279O:7)E)UU;)S<N,S@S.BTW+C4Q-R==(#T@)TUA;B<[
M"B1C;V]R9&EN871E<ULG0V]T92!$7"=)=F]I<F4G75LG-RXW,S,Z+34N,#8W
M)UT@/2`G0F]U86ME)SL*)&-O;W)D:6YA=&5S6R=#;W1E($1<)TEV;VER92==
M6R<X+C`U,#HM,BXW.#,G72`]("=";VYD;W5K;W4G.PHD8V]O<F1I;F%T97-;
M)T-O=&4@1%PG279O:7)E)UU;)SDN-#$W.BTU+C8Q-R==(#T@)TMO<FAO9V\G
M.PHD8V]O<F1I;F%T97-;)T-O=&4@1%PG279O:7)E)UU;)SDN-3`P.BTW+C4V
M-R==(#T@)T]D:65N;F4G.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#(N
M-38W.C$X+C(V-R==(#T@)T1U8G)O=FYI:R`O($-I;&EP:2<["B1C;V]R9&EN
M871E<ULG0W)O871I82==6R<T,RXQ-C<Z,38N-#4P)UT@/2`G2'9A<B<["B1C
M;V]R9&EN871E<ULG0W)O871I82==6R<T,RXU,S,Z,38N,S`P)UT@/2`G4W!L
M:70@+R!297-N:6LG.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#0N,3`P
M.C$U+C,U,"==(#T@)UIA9&%R("\@6F5M=6YI:R<["B1C;V]R9&EN871E<ULG
M0W)O871I82==6R<T-2XP,S,Z,3@N.#`P)UT@/2`G3W-I:F5K("\@0V5P:6XG
M.PHD8V]O<F1I;F%T97-;)T-R;V%T:6$G75LG-#4N,38W.C$X+C`P,"==(#T@
M)U-L879O;G-K:2!"<F]D)SL*)&-O;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0U
M+C(Q-SHQ-"XU.#,G72`]("=2:6IE:V$@+R!/;6ES86QJ)SL*)&-O;W)D:6YA
M=&5S6R=#<F]A=&EA)UU;)S0U+C<S,SHQ-BXP-C<G72`]("=:86=R96(@+R!0
M;&5S;R<["B1C;V]R9&EN871E<ULG0W)O871I82==6R<T-2XX,3<Z,38N,#,S
M)UT@/2`G6F%G<F5B("\@36%K<VEM:7(G.PHD8V]O<F1I;F%T97-;)T-R;V%T
M:6$G75LG-#4N.3`P.C$S+CDQ-R==(#T@)U!U;&$@065R;V1R;VUE)SL*)&-O
M;W)D:6YA=&5S6R=#<F]A=&EA)UU;)S0V+C,P,#HQ-BXS.#,G72`]("=687)A
M>F1I;B<["B1C;V]R9&EN871E<ULG0W5B82==6R<Q.2XY,#`Z+3<U+C$S,R==
M(#T@)T=U86YT86YA;6\L($]R:65N=&4G.PHD8V]O<F1I;F%T97-;)T-U8F$G
M75LG,3DN.38W.BTW-2XX-3`G72`]("=386YT:6%G;R!$92!#=6)A+"!/<FEE
M;G1E)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(P+C`X,SHM-S4N,34P)UT@
M/2`G1W5A;G1A;F%M;RP@3W)I96YT92<["B1C;V]R9&EN871E<ULG0W5B82==
M6R<R,"XS,S,Z+3<W+C$Q-R==(#T@)TUA;GIA;FEL;&\L($]R:65N=&4G.PHD
M8V]O<F1I;F%T97-;)T-U8F$G75LG,C`N,S4P.BTW-"XU,#`G72`]("="87)A
M8V]A+"!/<FEE;G1E)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(P+CDU,#HM
M-S8N.34P)UT@/2`G3&%S(%1U;F%S+"!,87,@5'5N87,G.PHD8V]O<F1I;F%T
M97-;)T-U8F$G75LG,C$N-#$W.BTW-RXX-3`G72`]("=#86UA9W5E>2!!97)O
M<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(Q+C<X,SHM-S@N-S@S
M)UT@/2`G5F5N97IU96QA+"!#:65G;R!$92!!=FEL82<["B1C;V]R9&EN871E
M<ULG0W5B82==6R<R,2XX,S,Z+3@R+C<X,R==(#T@)TYU979A($=E<F]N82P@
M27-L82!$92!0:6YO<R<["B1C;V]R9&EN871E<ULG0W5B82==6R<R,BXQ-3`Z
M+3@P+C0P,"==(#T@)T-I96YF=65G;W,L($QA<R!6:6QL87,G.PHD8V]O<F1I
M;F%T97-;)T-U8F$G75LG,C(N-#$W.BTX,RXV.#,G72`]("=0:6YA<B!$96P@
M4FEO+"!0:6YA<B!$96P@4FEO)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(R
M+CDX,SHM.#(N-#`P)UT@/2`G065R;W!U97)T;R!*;W-E($UA<G1I+"!286YC
M:&\M0F]Y97)O<RP@2&%B86YA)SL*)&-O;W)D:6YA=&5S6R=#=6)A)UU;)S(S
M+C$S,SHM.#$N,C@S)UT@/2`G5F%R861E<F\L($UA=&%N>F%S)SL*)&-O;W)D
M:6YA=&5S6R=#>7!R=7,G75LG,S0N-3@S.C,R+CDX,R==(#T@)T%K<F]T:7)I
M)SL*)&-O;W)D:6YA=&5S6R=#>7!R=7,G75LG,S0N-S$W.C,R+C0X,R==(#T@
M)U!A<&AO<R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=#>7!R=7,G75LG,S0N
M.#@S.C,S+C8S,R==(#T@)TQA<FYA8V$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG0WEP<G5S)UU;)S,U+C$U,#HS,RXT,#`G72`]("=!=&AA;&%S<V$G.PHD
M8V]O<F1I;F%T97-;)T-Z96-H(%)E<'5B;&EC)UU;)S0Y+C$U,#HQ-BXW,#`G
M72`]("="<FYO("\@5'5R86YY)SL*)&-O;W)D:6YA=&5S6R=#>F5C:"!297!U
M8FQI8R==6R<T.2XS,3<Z,3<N-38W)UT@/2`G2&]L97-O=B<["B1C;V]R9&EN
M871E<ULG0WIE8V@@4F5P=6)L:6,G75LG-#DN-C@S.C$X+C$Q-R==(#T@)T]S
M=')A=F$@+R!-;W-N;W8G.PHD8V]O<F1I;F%T97-;)T-Z96-H(%)E<'5B;&EC
M)UU;)S4P+C$P,#HQ-"XR-3`G72`]("=0<F%H82`O(%)U>GEN92<["B1C;V]R
M9&EN871E<ULG0WIE8V@@4F5P=6)L:6,G75LG-3`N,C`P.C$R+CDQ-R==(#T@
M)TMA<FQO=GD@5F%R>2<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-"XW
M,#`Z,3$N-#4P)UT@/2`G36%R:6)O($QU9G1H879N)SL*)&-O;W)D:6YA=&5S
M6R=$96YM87)K)UU;)S4T+CDV-SHY+C<X,R==(#T@)U-O96YD97)B;W)G($QU
M9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C`Q-SHQ,"XU
M-C<G72`]("=3>61F>6YS($9L>79E<&QA9',G.PHD8V]O<F1I;F%T97-;)T1E
M;FUA<FLG75LG-34N,#8W.C$T+C<U,"==(#T@)U)O96YN92<["B1C;V]R9&EN
M871E<ULG1&5N;6%R:R==6R<U-2XP.#,Z,3$N-S@S)UT@/2`G079N;R!$86YI
M<V@@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG
M-34N,C,S.CDN,C8W)UT@/2`G4VMR>61S=')U<"<["B1C;V]R9&EN871E<ULG
M1&5N;6%R:R==6R<U-2XT,S,Z.2XS,S,G72`]("=686UD<G5P)SL*)&-O;W)D
M:6YA=&5S6R=$96YM87)K)UU;)S4U+C0X,SHQ,"XS,S,G72`]("=/9&5N<V4@
M+R!"96QD<FEN9V4G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG-34N-3,S
M.C@N-38W)UT@/2`G17-B:F5R9R<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==
M6R<U-2XU.#,Z,3(N,3,S)UT@/2`G2V]E8F5N:&%V;B`O(%)O<VMI;&1E)SL*
M)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4U+C8Q-SHQ,BXV-3`G72`]("=+
M;V5B96YH879N("\@2V%S=')U<"<["B1C;V]R9&EN871E<ULG1&5N;6%R:R==
M6R<U-2XW,#`Z.2XR,#`G72`]("=686YD96PG.PHD8V]O<F1I;F%T97-;)T1E
M;FUA<FLG75LG-34N-S,S.CDN,38W)UT@/2`G0FEL;'5N9"!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-2XW-C<Z,3(N,S,S)UT@/2`G
M5F%E<FQO97-E)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4V+C`P,#HX
M+C,U,"==(#T@)U-T875N:6YG($QU9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$
M96YM87)K)UU;)S4V+C,P,#HQ,"XV,3<G72`]("=4:7)S=')U<"<["B1C;V]R
M9&EN871E<ULG1&5N;6%R:R==6R<U-BXS,#`Z.2XQ,3<G72`]("=+87)U<"<[
M"B1C;V]R9&EN871E<ULG1&5N;6%R:R==6R<U-BXT,#`Z."XT-3`G72`]("=,
M:6YD=&]R<"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4V
M+C4U,#HY+C$V-R==(#T@)U-K:79E($QU9G1H879N)SL*)&-O;W)D:6YA=&5S
M6R=$96YM87)K)UU;)S4V+C<P,#HQ,2XU-3`G72`]("=!;FAO;'0@27-L86YD
M($%U=&]M871E9"!297!O<G1I;F<@4W1A=&EO;B<["B1C;V]R9&EN871E<ULG
M1&5N;6%R:R==6R<U-BXW,3<Z,3`N,3$W)UT@/2`G2&%D<W5N9"<["B1C;V]R
M9&EN871E<ULG1&5N;6%R:R==6R<U-RXP-C<Z."XW,3<G72`]("=4:&ES=&5D
M($QU9G1H879N)SL*)&-O;W)D:6YA=&5S6R=$96YM87)K)UU;)S4W+C$P,#HY
M+C@U,"==(#T@)T%A;&)O<F<G.PHD8V]O<F1I;F%T97-;)T1E;FUA<FLG75LG
M-3<N-3`P.C$P+C(Q-R==(#T@)U-I;F1A;"!&;'EV97!L861S)SL*)&-O;W)D
M:6YA=&5S6R=$96YM87)K)UU;)S8R+C`V-SHM-RXR.#,G72`]("=3;V5R=F%A
M9R`O(%9A9V%R)SL*)&-O;W)D:6YA=&5S6R=$:FEB;W5T:2==6R<Q,2XU-3`Z
M-#,N,34P)UT@/2`G1&II8F]U=&DG.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A
M)UU;)S$U+C,P,#HM-C$N-#`P)UT@/2`G4F]S96%U)SL*)&-O;W)D:6YA=&5S
M6R=$;VUI;FEC82==6R<Q-2XU,S,Z+38Q+C,P,"==(#T@)TUE;'9I;&QE($AA
M;&P@06ER<&]R="<["B1C;V]R9&EN871E<ULG1&]M:6YI8V$G75LG,34N-3,S
M.BTV,2XT,#`G72`]("=#86YE9FEE;&0@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$X+C(P,#HM-S$N,3`P)UT@/2`G
M0F%R86AO;F$G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI8R==
M6R<Q."XT,S,Z+38Y+C8V-R==(#T@)TQA<R!!;65R:6-A<R<["B1C;V]R9&EN
M871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$X+C0V-SHM-CDN.38W)UT@
M/2`G2&5R<F5R82<["B1C;V]R9&EN871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC
M)UU;)S$X+C4V-SHM-C@N,S8W)UT@/2`G4'5N=&$@0V%N82<["B1C;V]R9&EN
M871E<ULG1&]M:6YI8V%N(%)E<'5B;&EC)UU;)S$Y+C0U,#HM-S`N-S`P)UT@
M/2`G4V%N=&EA9V\G.PHD8V]O<F1I;F%T97-;)T1O;6EN:6-A;B!297!U8FQI
M8R==6R<Q.2XW-3`Z+3<P+C4U,"==(#T@)U!U97)T;R!0;&%T82!);G1E<FYA
M=&EO;F%L)SL*)&-O;W)D:6YA=&5S6R=%87-T(%1I;6]R)UU;)RTX+C4P,#HQ
M,C8N-#`P)UT@/2`G0F%U8V%U)SL*)&-O;W)D:6YA=&5S6R=%87-T(%1I;6]R
M)UU;)RTX+C4V-SHQ,C4N-38W)UT@/2`G1&EL;&D@+R!$:6QL:2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=%87-T(%1I;6]R)UU;)RTY+C(P,#HQ,C0N,S8W
M)UT@/2`G3V4M0W5S<V4@+R!/92!#=7-S92<["B1C;V]R9&EN871E<ULG16-U
M861O<B==6R<M,"XQ-3`Z+3<X+C0X,R==(#T@)U%U:71O("\@36%R:7-C86P@
M4W5C<F4G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG,"XS-3`Z+3<X+C$S
M,R==(#T@)TEB87)R82`O($%T86AU86QP82<["B1C;V]R9&EN871E<ULG16-U
M861O<B==6R<M,"XU.#,Z+3@P+C0P,"==(#T@)T)A:&EA($1E($-A<F%Q=65Z
M)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTP+C<X,SHM-S4N-3$W)UT@
M/2`G5&EP=71I;FDG.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG,"XX,3<Z
M+3<W+C<P,"==(#T@)U1U;&-A;B`O($5L(%)O<V%L)SL*)&-O;W)D:6YA=&5S
M6R=%8W5A9&]R)UU;)RTP+CDP,#HM.#DN-C`P)UT@/2`G4V%N($-R:7-T;V)A
M;"!'86QA<&%G;W,G.PHD8V]O<F1I;F%T97-;)T5C=6%D;W(G75LG+3`N.3$W
M.BTW."XV,3<G72`]("=,871A8W5N9V$G.PHD8V]O<F1I;F%T97-;)T5C=6%D
M;W(G75LG+3`N.34P.BTX,"XV.#,G72`]("=-86YT82<["B1C;V]R9&EN871E
M<ULG16-U861O<B==6R<P+CDV-SHM-SDN-C,S)UT@/2`G17-M97)A;&1A<RU4
M86-H:6YA)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTQ+C(P,#HM-S@N
M-38W)UT@/2`G06UB871O("\@0VAA8VAO86XG.PHD8V]O<F1I;F%T97-;)T5C
M=6%D;W(G75LG+3$N-3`P.BTW."XP-3`G72`]("=087-T87IA("\@4FEO($%M
M87IO;F%S)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTR+C$U,#HM-SDN
M.#@S)UT@/2`G1W5A>6%Q=6EL("\@4VEM;VX@0F]L:79A<B<["B1C;V]R9&EN
M871E<ULG16-U861O<B==6R<M,BXR,#`Z+3@P+CDX,R==(#T@)U-A;&EN87,@
M+R!'96YE<F%L(%5L<&EA;F\@4&%E>B<["B1C;V]R9&EN871E<ULG16-U861O
M<B==6R<M,BXX.#,Z+3<X+CDX,R==(#T@)T-U96YC82`O($UA<FES8V%L($QA
M;6%R)SL*)&-O;W)D:6YA=&5S6R=%8W5A9&]R)UU;)RTS+C(U,#HM-SDN.38W
M)UT@/2`G36%C:&%L82`O($=E;F5R86P@32X@4V5R<F%N;R<["B1C;V]R9&EN
M871E<ULG16-U861O<B==6R<M-"XP,#`Z+3<Y+C,V-R==(#T@)T-A=&%M87EO
M("\@0V%M:6QO(%!O;F-E($5N<FEQ=65Z)SL*)&-O;W)D:6YA=&5S6R=%8W5A
M9&]R)UU;)RTT+C,V-SHM-SDN.3,S)UT@/2`G36%C87)A("\@2BX@32X@5F5L
M87-C;R!)+B<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,C,N.38W.C,R+C<X
M,R==(#T@)T%S<W=A;B<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,C4N-C8W
M.C,R+C<P,"==(#T@)TQU>&]R)SL*)&-O;W)D:6YA=&5S6R=%9WEP="==6R<R
M-RXP-3`Z,S$N,#$W)UT@/2`G07-Y=70G.PHD8V]O<F1I;F%T97-;)T5G>7!T
M)UU;)S(W+C$U,#HS,RXW,3<G72`]("=(=7)G=6%D82<["B1C;V]R9&EN871E
M<ULG16=Y<'0G75LG,C@N,C,S.C,R+C8Q-R==(#T@)T5L(%1O<B<["B1C;V]R
M9&EN871E<ULG16=Y<'0G75LG,S`N,3,S.C,Q+C0P,"==(#T@)T-A:7)O($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,Q+C`X,SHS,RXX,3<G
M72`]("=%;"!!<FES:"<["B1C;V]R9&EN871E<ULG16=Y<'0G75LG,S$N,C`P
M.C(Y+CDU,"==(#T@)T%L97AA;F1R:6$@+R!.;W5Z:&$G.PHD8V]O<F1I;F%T
M97-;)T5G>7!T)UU;)S,Q+C(V-SHS,BXS,#`G72`]("=0;W)T(%-A:60G.PHD
M8V]O<F1I;F%T97-;)T5G>7!T)UU;)S,Q+C,S,SHR-RXR,3<G72`]("=-97)S
M82!-871R=6@G.PHD8V]O<F1I;F%T97-;)T5L(%-A;'9A9&]R)UU;)S$S+C0S
M,SHM.#DN,#4P)UT@/2`G16P@4V%L=F%D;W(@26YT;"X@06ER<&]R="`O($-O
M;6%L87!A)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXT-3`Z
M+3@X+C$Q-R==(#T@)U-A;B!-:6=U96P@+R!%;"!087!A;&]N)SL*)&-O;W)D
M:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXU-C<Z+3@Y+C@S,R==(#T@)T%C
M86IU=&QA)SL*)&-O;W)D:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXW,#`Z
M+3@Y+C$Q-R==(#T@)U-A;B!386QV861O<B`O($EL;W!A;F=O)SL*)&-O;W)D
M:6YA=&5S6R=%;"!386QV861O<B==6R<Q,RXY.#,Z+3@Y+C4V-R==(#T@)U-A
M;G1A($%N82`O($5L(%!A;&UA<B<["B1C;V]R9&EN871E<ULG17%U871O<FEA
M;"!'=6EN96$G75LG,RXW-3`Z."XW-C<G72`]("=-86QA8F\O1F5R;F%N9&\@
M4&]O)SL*)&-O;W)D:6YA=&5S6R=%<W1O;FEA)UU;)S4X+CDX,SHR,BXX,3<G
M72`]("=+87)D;&$G.PHD8V]O<F1I;F%T97-;)T5S=&]N:6$G75LG-3DN,S@S
M.C(T+C4X,R==(#T@)U1A;&QI;FXG.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA
M)UU;)S$P+C,U,#HS-RXW,3<G72`]("=$96)R96UA<F-O<R<["B1C;V]R9&EN
M871E<ULG171H:6]P:6$G75LG,3$N,#@S.C,Y+C<Q-R==(#T@)T-O;6)O;&-H
M82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,3$N-C`P.C,W+C0P,"==
M(#T@)T)A:&%R($1A<B<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG,3(N
M-3,S.C,W+C0S,R==(#T@)T=O;F1A<B<["B1C;V]R9&EN871E<ULG171H:6]P
M:6$G75LG,3,N,#8W.C0R+C<Q-R==(#T@)T%S<V%B)SL*)&-O;W)D:6YA=&5S
M6R=%=&AI;W!I82==6R<Q,RXU,#`Z,SDN-#@S)UT@/2`G36%K86QE)SL*)&-O
M;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Q-2XR.#,Z,S@N.3$W)UT@/2`G07-M
M87)A)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Q-2XV,3<Z,SDN-#4P
M)UT@/2`G36%S<V%W82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG-2XQ
M,#`Z-#0N-3@S)UT@/2`G1V]D92<["B1C;V]R9&EN871E<ULG171H:6]P:6$G
M75LG-2XR.#,Z,SDN-S4P)UT@/2`G3F5G:&5L;&DG.PHD8V]O<F1I;F%T97-;
M)T5T:&EO<&EA)UU;)S8N,#8W.C,W+C8V-R==(#T@)T%R8F$@36EN8V@G.PHD
M8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S<N,#8W.C,X+C4P,"==(#T@)T%W
M87-S82<["B1C;V]R9&EN871E<ULG171H:6]P:6$G75LG-RXV-C<Z,S8N.#,S
M)UT@/2`G2FEM;6$G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;)S@N,38W
M.C,U+C4U,"==(#T@)T=O<F4G.PHD8V]O<F1I;F%T97-;)T5T:&EO<&EA)UU;
M)S@N-S,S.C,Y+C`P,"==(#T@)TAA<F%R($UE9&$G.PHD8V]O<F1I;F%T97-;
M)T5T:&EO<&EA)UU;)S@N.3@S.C,X+C@P,"==(#T@)T%D9&ES($%B86)A)SL*
M)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Y+C,S,SHT,BXW,3<G72`]("=*
M:6=G:6=A)SL*)&-O;W)D:6YA=&5S6R=%=&AI;W!I82==6R<Y+C8P,#HT,2XX
M-C<G72`]("=$:7)E($1A=V$G.PHD8V]O<F1I;F%T97-;)T9A;&ML86YD($ES
M;&%N9',@*$UA;'9I;F%S*2==6R<M-3$N-C@S.BTU-RXW-C<G72`]("=3=&%N
M;&5Y($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T9I:FDG75LG+3$R+C4P,#HQ
M-S<N,#4P)UT@/2`G4F]T=6UA)SL*)&-O;W)D:6YA=&5S6R=&:6II)UU;)RTQ
M-RXW-3`Z,3<W+C0U,"==(#T@)TYA;F1I)SL*)&-O;W)D:6YA=&5S6R=&:6II
M)UU;)RTQ."XP-3`Z,3<X+C4V-R==(#T@)TYA=7-O<FDG.PHD8V]O<F1I;F%T
M97-;)T9I:FDG75LG+3$X+C(S,SHM,3<X+C@P,"==(#T@)TQA:V5M8F$G.PHD
M8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N,3$W.C$Y+CDP,"==(#T@)TUA
M<FEE:&%M;B`O($%L86YD($ES;&%N9"<["B1C;V]R9&EN871E<ULG1FEN;&%N
M9"==6R<V,"XR-3`Z,C4N,#4P)UT@/2`G2&5L<VEN:VDM36%L;6DG.PHD8V]O
M<F1I;F%T97-;)T9I;FQA;F0G75LG-C`N,S$W.C(T+CDV-R==(#T@)TAE;'-I
M;FMI+59A;G1A82<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,"XU,3<Z
M,C(N,C8W)UT@/2`G5'5R:W4G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG
M-C`N.3`P.C(V+CDS,R==(#T@)U5T=&DG.PHD8V]O<F1I;F%T97-;)T9I;FQA
M;F0G75LG-C$N,#0V.C(X+C$T.2==(#T@)TQA<'!E96YR86YT82<["B1C;V]R
M9&EN871E<ULG1FEN;&%N9"==6R<V,2XT,3<Z,C,N-3@S)UT@/2`G5&%M<&5R
M92`O(%!I<FMK86QA)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8Q+C0V
M-SHR,2XX,#`G72`]("=0;W)I)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;
M)S8Q+C<S,SHR-RXS,#`G72`]("=-:6MK96QI)SL*)&-O;W)D:6YA=&5S6R=&
M:6YL86YD)UU;)S8Q+C@U,#HR-"XX,#`G72`]("=(86QL:2<["B1C;V]R9&EN
M871E<ULG1FEN;&%N9"==6R<V,2XY-3`Z,C@N.34P)UT@/2`G4V%V;VYL:6YN
M82<["B1C;V]R9&EN871E<ULG1FEN;&%N9"==6R<V,BXT,#`Z,C4N-C@S)UT@
M/2`G2GEV87-K>6QA)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8R+C4S
M,SHR-"XR,3<G72`]("=!:'1A<FDG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G
M75LG-C(N-C8W.C(Y+C8S,R==(#T@)TIO96YS=74G.PHD8V]O<F1I;F%T97-;
M)T9I;FQA;F0G75LG-C,N,#$W.C(W+C@P,"==(#T@)TMU;W!I;R<["B1C;V]R
M9&EN871E<ULG1FEN;&%N9"==6R<V,RXP-3`Z,C$N-S8W)UT@/2`G5F%A<V$G
M.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,#@S.C(U+C@V-R==(#T@
M)U9I:71A<V%A<FDG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C,N,3`P
M.C(S+C`S,R==(#T@)TMA=6AA=F$G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G
M75LG-C,N-S$W.C(S+C$U,"==(#T@)TMR=75N=7!Y>2<["B1C;V]R9&EN871E
M<ULG1FEN;&%N9"==6R<V-"XR.#,Z,C<N-C@S)UT@/2`G2V%J86%N:2<["B1C
M;V]R9&EN871E<ULG1FEN;&%N9"==6R<V-"XY,#`Z,CDN,#$W)UT@/2`G4W5O
M;75S<V%L;6DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C0N.3,S.C(U
M+C,V-R==(#T@)T]U;'4G.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG-C4N
M,#,S.C(T+C@P,"==(#T@)TAA:6QU;W1O)SL*)&-O;W)D:6YA=&5S6R=&:6YL
M86YD)UU;)S8U+C,V-SHR-RXP,3<G72`]("=0=61A<VIA<G9I)SL*)&-O;W)D
M:6YA=&5S6R=&:6YL86YD)UU;)S8U+C<X,SHR-"XU.#,G72`]("=+96UI)SL*
M)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8U+CDV-SHR.2XQ.#,G72`]("=+
M=75S86UO)SL*)&-O;W)D:6YA=&5S6R=&:6YL86YD)UU;)S8V+C4V-SHR-2XX
M,S,G72`]("=2;W9A;FEE;6DG.PHD8V]O<F1I;F%T97-;)T9I;FQA;F0G75LG
M-C8N.#`P.C(T+C`P,"==(#T@)U!E;&QO)SL*)&-O;W)D:6YA=&5S6R=&:6YL
M86YD)UU;)S8W+C,V-SHR-BXV-3`G72`]("=3;V1A;FMY;&$G.PHD8V]O<F1I
M;F%T97-;)T9I;FQA;F0G75LG-C@N-C$W.C(W+C0Q-R==(#T@)TEV86QO)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG+3$S+C(S,SHM,3<V+C$V-R==(#T@
M)TAI:&EF;R!);&4@5V%L;&ES)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M+3$T+C,Q-SHM,3<X+C$Q-R==(#T@)TUA;W!O;W!O($EL92!&=71U;F$G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T,2XU,#`Z.2XQ,#`G72`]("=&:6=A
M<FDG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,2XY,3<Z."XX,#`G72`]
M("=!:F%C8VEO)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#$N.3$W.CDN
M-#`P)UT@/2`G4V]L96YZ87)A)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG
M-#(N-3,S.C@N.#`P)UT@/2`G0V%L=FDG.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T,BXU-3`Z.2XT.#,G72`]("="87-T:6$G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T,BXW,S,Z,BXX-C<G72`]("=097)P:6=N86XG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T,RXP,#`Z,2XQ,#`G72`]("=3="U':7)O
M;G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXQ,#`Z-BXQ-3`G72`]
M("=(>65R97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXQ.#,Z,"XP
M,#`G72`]("=487)B97,@+R!/<W-U;B<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0S+C(Q-SHR+C,Q-R==(#T@)T-A<F-A<W-O;FYE)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#,N,S@S.BTP+C0Q-R==(#T@)U!A=2<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0S+C,X,SHV+C,X,R==(#T@)TQE($QU8R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C0Q-SHV+C<U,"==(#T@)U-T
M+5)A<&AA96PG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXT-3`Z-2XR
M,S,G72`]("=-87)S96EL;&4@+R!-87)I9VYA;F4G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T,RXT-C<Z+3$N-3,S)UT@/2`G0FEA<G)I='HG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T,RXU,#`Z-2XS-C<G72`]("=!:7@@3&5S
M($UI;&QE<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4Q-SHT+CDS
M,R==(#T@)TES=')E<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C4S
M,SHQ+C,V-R==(#T@)U1O=6QO=7-E("\@1G)A;F-A>F%L)SL*)&-O;W)D:6YA
M=&5S6R=&<F%N8V4G75LG-#,N-34P.C8N.34P)UT@/2`G0V%N;F5S)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N-3@S.C,N.38W)UT@/2`G36]N='!E
M;&QI97(G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T,RXV,#`Z-2XQ,#`G
M72`]("=386QO;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C8S,SHQ
M+C,V-R==(#T@)U1O=6QO=7-E("\@0FQA9VYA8R<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0S+C8U,#HW+C(P,"==(#T@)TYI8V4G.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T,RXV.#,Z,"XV,#`G72`]("=!=6-H)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#,N-C@S.BTQ+C`V-R==(#T@)T1A>"<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0S+C<U,#HT+C0Q-R==(#T@)TYI;65S
M("\@1V%R;VYS)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N.#8W.C0N
M-#`P)UT@/2`G3FEM97,@+R!#;W5R8F5S<V%C)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#,N.3$W.BTP+C4P,"==(#T@)TUO;G0M1&4M36%R<V%N)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#,N.3$W.C(N,3$W)UT@/2`G06QB
M:2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C`V-SHV+C`P,"==(#T@
M)U-T+4%U8F%N+5-U<BU$=7)A;F-E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#0N,3,S.C0N.#,S)UT@/2`G3W)A;F=E)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#0N,3@S.C`N-C`P)UT@/2`G06=E;B<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0T+C$X,SHR+C4Q-R==(#T@)T-A<W-A9VYE<RU"96=O
M;FAE<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0T+C0P,#HR+C0X,R==
M(#T@)U)O9&5Z)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N-#,S.BTQ
M+C(U,"==(#T@)T)I<V-A<F]S<V4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T-"XU,S,Z+3$N,3,S)UT@/2`G0V%Z875X)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#0N-3@S.C0N-S,S)UT@/2`G36]N=&5L:6UA<B<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0T+C@Q-SHP+C4Q-R==(#T@)T)E<F=E<F%C
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#0N.#,S.BTP+C<P,"==(#T@
M)T)O<F1E875X("\@365R:6=N86,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==
M6R<T-"XY,#`Z,BXT,3<G72`]("=!=7)I;&QA8R<["B1C;V]R9&EN871E<ULG
M1G)A;F-E)UU;)S0U+C`X,SHS+C<V-R==(#T@)TQE(%!U>2<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0U+C$U,#HQ+C0V-R==(#T@)T)R:79E)SL*)&-O
M;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N,C`P.C`N.#$W)UT@/2`G4&5R:6=U
M975X)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N,S8W.C4N,S,S)UT@
M/2`G1W)E;F]B;&4@+R!3="X@1V5O:7)S)SL*)&-O;W)D:6YA=&5S6R=&<F%N
M8V4G75LG-#4N-3,S.C0N,S`P)UT@/2`G4W0M171I96YN92!";W5T:&5O;B<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C8U,#HU+C@X,R==(#T@)T-H
M86UB97)Y("\@06EX+4QE<RU"86EN<R<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0U+C8V-SHM,"XS,3<G72`]("=#;V=N86,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T-2XW,3<Z-"XY-3`G72`]("=,>6]N("\@0G)O;B<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0U+C<S,SHU+C`X,R==(#T@)TQY;VX@
M+R!3871O;&%S)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#4N-S@S.C,N
M,38W)UT@/2`G0VQE<FUO;G0M1F5R<F%N9"<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0U+C@V-SHQ+C$X,R==(#T@)TQI;6]G97,G.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-2XY.#,Z-2XS,S,G72`]("=!;6)E<FEE=2<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V+C$U,#HM,2XQ-3`G72`]("=,82!2
M;V-H96QL92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V+C$V-SHS+C0P
M,"==(#T@)U9I8VAY)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#8N,S`P
M.C0N.#`P)UT@/2`G36%C;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M-BXS,3<Z+3`N-#`P)UT@/2`G3FEO<G0G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T-BXT,3<Z-"XP,3<G72`]("=386EN="U986XG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-BXU.#,Z,"XS,3<G72`]("=0;VET:65R<R<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0V+C<P,#HM,2XS.#,G72`]("=,82!2
M;V-H92U3=7(M66]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#8N.#4P
M.C$N-S$W)UT@/2`G0VAA=&5A=7)O=7@G.PHD8V]O<F1I;F%T97-;)T9R86YC
M92==6R<T-RXP,#`Z,RXQ,#`G72`]("=.979E<G,G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T-RXP-C<Z,BXS-C<G72`]("=";W5R9V5S)SL*)&-O;W)D
M:6YA=&5S6R=&<F%N8V4G75LG-#<N,38W.BTQ+C8P,"==(#T@)TYA;G1E<R<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+C(U,#HU+CDX,R==(#T@)T)E
M<V%N8V]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N,C8W.C4N,#@S
M)UT@/2`G1&EJ;VXG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXS,3<Z
M,2XV.#,G72`]("=2;VUO<F%N=&EN)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G
M75LG-#<N,S$W.BTR+C$V-R==(#T@)U-T+4YA>F%I<F4G.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-RXT-3`Z,"XW,3<G72`]("=4;W5R<R<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0W+C4P,#HM,"XU-C<G72`]("=!;F=E<G,G
M.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T-RXV,#`Z-RXU,3<G72`]("="
M86QE+4UU;&AO=7-E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N-C,S
M.C8N.#8W)UT@/2`G0F5L9F]R="<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0W+C<V-SHM,RXT-3`G72`]("=,86YN($)I:&]U92<["B1C;V]R9&EN871E
M<ULG1G)A;F-E)UU;)S0W+C<X,SHV+C,U,"==(#T@)TQU>&5U:6PG.PHD8V]O
M<F1I;F%T97-;)T9R86YC92==6R<T-RXX,#`Z,RXU-3`G72`]("=!=7AE<G)E
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#<N.#4P.C0N-34P)UT@/2`G
M0VAA=&EL;&]N+5-U<BU396EN92<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0W+CDQ-SHW+C0P,"==(#T@)T-O;&UA<B<["B1C;V]R9&EN871E<ULG1G)A
M;F-E)UU;)S0W+CDS,SHP+C(P,"==(#T@)TQE($UA;G,G.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T-RXY-C<Z+30N,38W)UT@/2`G475I;7!E<B<["B1C
M;V]R9&EN871E<ULG1G)A;F-E)UU;)S0W+CDX,SHQ+C<U,"==(#T@)T]R;&5A
M;G,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XP-3`Z,2XS.#,G72`]
M("=#:&%T96%U9'5N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N,#8W
M.BTQ+C<S,R==(#T@)U)E;FYE<R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0X+C(X,SHM-"XT,S,G72`]("=,86YV96]C(%!O=6QM:6,G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XS,S,Z-"XP,3<G72`]("=4<F]Y97,G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XT-3`Z,"XQ,3<G72`]("=!;&5N
M8V]N)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-#4P.BTT+C0Q-R==
M(#T@)T)R97-T)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-#8W.C$N
M-3$W)UT@/2`G0VAA<G1R97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M."XU,3<Z+30N,34P)UT@/2`G3&%N9&EV:7-I874G.PHD8V]O<F1I;F%T97-;
M)T9R86YC92==6R<T."XU,S,Z+3(N.#4P)UT@/2`G4V%I;G0M0G)I975C)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-34P.C<N-C,S)UT@/2`G4W1R
M87-B;W5R9R<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0X+C4X,SHM,BXP
M-C<G72`]("=$:6YA<F0G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XU
M.#,Z-2XY-C<G72`]("=.86YC>2`O($]C:&5Y)SL*)&-O;W)D:6YA=&5S6R=&
M<F%N8V4G75LG-#@N-C$W.C(N-C@S)UT@/2`G365L=6XG.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T."XV,S,Z-"XY,#`G72`]("=3="U$:7II97(G.PHD
M8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XV.#,Z-BXR,3<G72`]("=.86YC
M>2`O($5S<V5Y)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#@N-S,S.C(N
M-#`P)UT@/2`G4&%R:7,M3W)L>2<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;
M)S0X+C<V-SHQ+C$P,"==(#T@)U1O=7-S=7,@3&4@3F]B;&4G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XW-C<Z,BXR,#`G72`]("=6:6QL86-O=6)L
M87DG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T."XW.#,Z-2XT.#,G72`]
M("=4;W5L("\@4F]S:65R97,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M."XY-C<Z,BXT-3`G72`]("=087)I<R`O($QE($)O=7)G970G.PHD8V]O<F1I
M;F%T97-;)T9R86YC92==6R<T."XY.#,Z-BXR-3`G72`]("=-971Z+4YA;F-Y
M+4QO<G)A:6YE)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN,#$W.C$N
M,C$W)UT@/2`G179R975X)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN
M,#$W.C(N-3,S)UT@/2`G4&%R:7,M065R;W!O<G0@0VAA<FQE<R!$92!'875L
M;&4G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XP.#,Z-BXQ,S,G72`]
M("=-971Z("\@1G)E<V-A='DG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T
M.2XQ.#,Z+3`N-#4P)UT@/2`G0V%E;B<["B1C;V]R9&EN871E<ULG1G)A;F-E
M)UU;)S0Y+C(U,#HR+C4Q-R==(#T@)T-R96EL($9A9F(G.PHD8V]O<F1I;F%T
M97-;)T9R86YC92==6R<T.2XS,#`Z-"XP,S,G72`]("=296EM<R<["B1C;V]R
M9&EN871E<ULG1G)A;F-E)UU;)S0Y+C,X,SHQ+C$X,R==(#T@)U)O=65N)SL*
M)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN-#8W.C(N,3$W)UT@/2`G0F5A
M=79A:7,G.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<T.2XU,3<Z,"XP-C<G
M72`]("=,82!(979E)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN-C4P
M.BTQ+C0V-R==(#T@)T-H97)B;W5R9R`O($UA=7!E<G1U<R<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S0Y+C<X,SHT+C8S,R==(#T@)T-H87)L979I;&QE
M)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-#DN.#$W.C,N,C`P)UT@/2`G
M4V%I;G0M475E;G1I;B<["B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S0Y+C@S
M,SHP+C8U,"==(#T@)U9I='1E9FQE=7(@+R!3="X@5F%L92<["B1C;V]R9&EN
M871E<ULG1G)A;F-E)UU;)S4P+C$S,SHQ+C@S,R==(#T@)T%B8F5V:6QL92<[
M"B1C;V]R9&EN871E<ULG1G)A;F-E)UU;)S4P+C(Q-SHS+C$U,"==(#T@)T-A
M;6)R86DG.PHD8V]O<F1I;F%T97-;)T9R86YC92==6R<U,"XU,3<Z,2XV,3<G
M72`]("=,92!4;W5Q=65T)SL*)&-O;W)D:6YA=&5S6R=&<F%N8V4G75LG-3`N
M-38W.C,N,3`P)UT@/2`G3&EL;&4G.PHD8V]O<F1I;F%T97-;)T9R96YC:"!'
M=6EA;F$G75LG-"XX,S,Z+34R+C,V-R==(#T@)T-A>65N;F4@+R!2;V-H86UB
M96%U)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@1W5I86YA)UU;)S4N-3`P.BTU
M-"XP,S,G72`]("=386EN="U,875R96YT+41U+4UA<F]N:2<["B1C;V]R9&EN
M871E<ULG1G)E;F-H(%!O;'EN97-I82==6R<M,30N.38W.BTQ-#<N-C8W)UT@
M/2`G4F%N9VER;V$@+R!4=6%M;W1O($ES;&%N9"<["B1C;V]R9&EN871E<ULG
M1G)E;F-H(%!O;'EN97-I82==6R<M,38N-#4P.BTQ-3$N-S4P)UT@/2`G0F]R
M82U";W)A)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@4&]L>6YE<VEA)UU;)RTQ
M-RXU-3`Z+3$T.2XV,3<G72`]("=486AI=&DM1F%A82<["B1C;V]R9&EN871E
M<ULG1G)E;F-H(%!O;'EN97-I82==6R<M,3@N,#8W.BTQ-#`N.34P)UT@/2`G
M2&%O)SL*)&-O;W)D:6YA=&5S6R=&<F5N8V@@4&]L>6YE<VEA)UU;)RTR,2XX
M,3<Z+3$S."XX,#`G72`]("=-=7)U<F]A)SL*)&-O;W)D:6YA=&5S6R=&<F5N
M8V@@4&]L>6YE<VEA)UU;)RTR,RXS-3`Z+3$T.2XT.#,G72`]("=4=6)U86DG
M.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)S`N-#4P.CDN-#$W)UT@/2`G3&EB
M<F5V:6QL92<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG,"XU-C<Z,3(N.#8W
M)UT@/2`G36%K;VMO=2<["B1C;V]R9&EN871E<ULG1V%B;VXG75LG+3`N-S`P
M.C@N-S4P)UT@/2`G4&]R="U'96YT:6PG.PHD8V]O<F1I;F%T97-;)T=A8F]N
M)UU;)RTP+C<Q-SHQ,"XR,S,G72`]("=,86UB87)E;F4G.PHD8V]O<F1I;F%T
M97-;)T=A8F]N)UU;)S`N-S@S.C$Q+C4S,R==(#T@)TUI='II8R<["B1C;V]R
M9&EN871E<ULG1V%B;VXG75LG+3`N.#,S.C$R+C<Q-R==(#T@)TQA<W1O=7)S
M=FEL;&4G.PHD8V]O<F1I;F%T97-;)T=A8F]N)UU;)S$N,#`P.CDN-C`P)UT@
M/2`G0V]C;V)E86-H)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<Q+C`Q-SHQ
M,RXY,S,G72`]("=-96MA;6)O)SL*)&-O;W)D:6YA=&5S6R='86)O;B==6R<M
M,2XU,S,Z,3,N,C8W)UT@/2`G36]A;F1A)SL*)&-O;W)D:6YA=&5S6R='86)O
M;B==6R<M,2XX-C<Z,3$N,#$W)UT@/2`G36]U:6QA)SL*)&-O;W)D:6YA=&5S
M6R='86)O;B==6R<R+C`X,SHQ,2XT.#,G72`]("=":71A;2<["B1C;V]R9&EN
M871E<ULG1V%B;VXG75LG+3(N.#4P.C$Q+C`Q-R==(#T@)U1C:&EB86YG82<[
M"B1C;V]R9&EN871E<ULG1V%B;VXG75LG+3,N-#$W.C$P+C8U,"==(#T@)TUA
M>75M8F$G.PHD8V]O<F1I;F%T97-;)T=A;6)I82==6R<Q,RXS-3`Z+3$V+C@P
M,"==(#T@)T)A;FIU;"`O(%EU;F1U;2<["B1C;V]R9&EN871E<ULG1V5O<F=I
M82==6R<T,2XV.#,Z-#0N.34P)UT@/2`G5&)I;&ES:2<["B1C;V]R9&EN871E
M<ULG1V5O<F=I82==6R<T,2XY,S,Z-#0N-3@S)UT@/2`G375H<F%N:2<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<T-RXV-C<Z.2XU,3<G72`]("=&<FEE
M9')I8VAS:&%F96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N-C@S
M.CDN,3@S)UT@/2`G2V]N<W1A;GHG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-#<N.#,S.C$P+C@V-R==(#T@)T%L=&5N<W1A9'0G.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-#<N.38W.C@N-3$W)UT@/2`G1&]N875E<V-H:6YG
M96X@+R!6:6QL:6YG96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#<N
M.3@S.C$P+C(S,R==(#T@)TUE;6UI;F=E;B<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<T."XP-C<Z,3`N.3`P)UT@/2`G3&%N9'-B97)G)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0X+C$S,SHQ,2XW,#`G72`]("=-=6YI8V@@
M+R!2:65M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0X+C$X,SHQ,"XX
M-C<G72`]("=,96-H9F5L9"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T
M."XQ.#,Z.2XP,#`G72`]("=-97-S<W1E='1E;B<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<T."XR,#`Z,3$N,C8W)UT@/2`G1G5E<G-T96YF96QD8G)U
M8VLG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N,C$W.CDN.3$W)UT@
M/2`G3&%U<&AE:6TG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#@N,S$W
M.C$Q+CDU,"==(#T@)T5R9&EN9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<T."XT,S,Z,3`N.3,S)UT@/2`G075G<V)U<F<G.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-#@N-C@S.CDN,C$W)UT@/2`G4W1U='1G87)T+45C:'1E
M<F1I;F=E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T."XW,3<Z,3$N
M,C$W)UT@/2`G3F5U8G5R9R`O($1O;F%U)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S0X+C<Q-SHQ,2XU,S,G72`]("=);F=O;'-T861T)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0Y+C(Q-SHQ,2XQ,#`G72`]("=2;W1H)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S0Y+C(Q-SHQ,2XX,S,G72`]("=(
M;VAE;F9E;',G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN,C$W.C<N
M,3$W)UT@/2`G4V%A<F)R=65C:V5N("\@16YS:&5I;2<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<T.2XS,3<Z,3`N-C,S)UT@/2`G06YS8F%C:"`O($MA
M='1E<F)A8V@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#`P.C@N
M-C4P)UT@/2`G2&5I9&5L8F5R9R<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<T.2XT,#`Z.2XY-C<G72`]("=.:65D97)S=&5T=&5N)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S0Y+C0S,SHQ,2XY,#`G72`]("=+=65M;65R<W)U
M8VLG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#,S.C<N-C`P)UT@
M/2`G4F%M<W1E:6XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-#8W
M.C$P+C,X,R==(#T@)TEL;&5S:&5I;2<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<T.2XT-S,Z."XU,38G72`]("="861E;B!7=7)T=&5M8F5R9RP@3F5U
M;W-T:&5I;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XU,#`Z,3$N
M,#4P)UT@/2`G3G5E<FYB97)G)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S0Y+C4P,#HW+C@V-R==(#T@)U-E;6)A8V@@56YI=&5D(%-T871E<R!!:7(@
M1F]R8V4@3W!E<F%T960@0F%S92!);B!&;W)E:6=N($-O=6YT<GDG.PHD8V]O
M<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-38W.C@N-#8W)UT@/2`G0V]L96UA
M;B!-86YN:&5I;2<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XV-3`Z
M.2XY-C<G72`]("=':65B96QS=&%D="<["B1C;V]R9&EN871E<ULG1V5R;6%N
M>2==6R<T.2XW,#`Z,3$N.34P)UT@/2`G1W)A9F5N=V]E:'(G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-#DN-S`P.C<N,S,S)UT@/2`G261A<BU/8F5R
M<W1E:6XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN-S4P.C$P+C(P
M,"==(#T@)TMI='II;F=E;B!5<V$@7"!!9B<["B1C;V]R9&EN871E<ULG1V5R
M;6%N>2==6R<T.2XX-3`Z-RXV,#`G72`]("=09F5R9'-F96QD)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S0Y+C@U,#HW+C@X,R==(#T@)T)A9"!+<F5U
M>FYA8V@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-#DN.34P.C<N,C8W
M)UT@/2`G2&%H;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<T.2XY.#,Z
M,3$N-C,S)UT@/2`G0F%Y<F5U=&@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-#DN.3@S.C8N-S`P)UT@/2`G4W!A;F=D86AL96TG.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-3`N,#4P.C@N,S,S)UT@/2`G5VEE<V)A9&5N)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+C`U,#HX+C8P,"==(#T@)T9R
M86YK9G5R="`O($TM1FQU9VAA9F5N)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4P+C$V-SHW+C`V-R==(#T@)T)U96-H96PG.PHD8V]O<F1I;F%T97-;
M)T=E<FUA;GDG75LG-3`N,38W.C@N.38W)UT@/2`G2&%N874G.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3`N,S$W.C$Q+C@X,R==(#T@)TAO9B<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,"XS-C<Z-RXS,3<G72`]("=-96YD
M:6<G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N.#$W.C8N,3@S)UT@
M/2`G06%C:&5N("\@365R>F)R=6-K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY
M)UU;)S4P+C@S,SHV+C8V-R==(#T@)TYO97)V96YI8V@G.PHD8V]O<F1I;F%T
M97-;)T=E<FUA;GDG75LG-3`N.#8W.C<N,38W)UT@/2`G2V]E;&X@+R!";VYN
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4P+CDV-SHV+C`U,"==(#T@
M)T=E:6QE;FMI<F-H96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3`N
M.3@S.C$P+CDV-R==(#T@)T5R9G5R="U":6YD97)S;&5B96XG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3$N,3$W.CDN,C@S)UT@/2`G1G)I='IL87(G
M.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N,3,S.C$S+C<U,"==(#T@
M)T1R97-D96XM2VQO='IS8VAE)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4Q+C(P,#HV+C$S,R==(#T@)T)R=65G9V5N)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S4Q+C,P,#HV+C<V-R==(#T@)T1U97-S96QD;W)F)SL*)&-O
M;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C0P,#HV+CDV-R==(#T@)T5S<V5N
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C0P,#HY+C,X,R==(#T@
M)TMA<W-E;"`O($-A;&1E;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U
M,2XT,3<Z,3(N,C,S)UT@/2`G3&5I<'II9RU38VAK975D:71Z)SL*)&-O;W)D
M:6YA=&5S6R='97)M86YY)UU;)S4Q+C4Q-SHW+C8Q-R==(#T@)T1O<G1M=6YD
M("\@5VEC:V5D92<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XV,#`Z
M-BXQ-3`G72`]("=,86%R8G)U8V@G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG
M75LG-3$N-C$W.C@N-C$W)UT@/2`G4&%D97)B;W)N("\@3&EP<'-T861T)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4Q+C8V-SHQ-"XV,S,G72`]("=0
M<F5S8VAE;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XW,S,Z-BXR
M-C<G72`]("=+86QK87(G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3$N
M-S8W.C$S+C$X,R==(#T@)TAO;'ID;W)F)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S4Q+C<V-SHQ-"XS,#`G72`]("=#;W1T8G5S($9L=6=P;&%T>B<[
M"B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,2XY,3<Z."XS,#`G72`]("='
M=65T97)S;&]H)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C$S,SHW
M+C<P,"==(#T@)TUU96YS=&5R("\@3W-N86)R=65C:R<["B1C;V]R9&EN871E
M<ULG1V5R;6%N>2==6R<U,BXR.#,Z.2XP.#,G72`]("="=65C:V5B=7)G)SL*
M)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4R+C,P,#HQ,"XT-3`G72`]("="
M<F%U;G-C:'=E:6<G.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N,S`P
M.C<N,S@S)UT@/2`G4FAE:6YE+4)E;G1L86=E)SL*)&-O;W)D:6YA=&5S6R='
M97)M86YY)UU;)S4R+C,S,SHW+C4S,R==(#T@)TAO<'-T96XG.PHD8V]O<F1I
M;F%T97-;)T=E<FUA;GDG75LG-3(N,S@S.C$S+C4Q-R==(#T@)T)E<FQI;BU3
M8VAO96YE9F5L9"<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT-3`Z
M-RXQ-C<G72`]("=.;W)D:&]R;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<U,BXT-3`Z.2XT,S,G72`]("=7=6YS=&]R9B<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,BXT-C<Z,3,N-#`P)UT@/2`G0F5R;&EN+51E;7!E;&AO
M9B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXT-C<Z.2XV.#,G72`]
M("=(86YN;W9E<B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXU-C<Z
M,3,N,S$W)UT@/2`G0F5R;&EN+51E9V5L)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S4R+C4X,SHX+C,U,"==(#T@)T1I97!H;VQZ)SL*)&-O;W)D:6YA
M=&5S6R='97)M86YY)UU;)S4R+C8P,#HQ,"XP,3<G72`]("=#96QL92<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U,BXX,3<Z.2XY,S,G72`]("="97)G
M96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3(N.3$W.C$P+C$X,R==
M(#T@)T9A<W-B97)G)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C`U
M,#HX+C@P,"==(#T@)T)R96UE;B<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==
M6R<U,RXR,#`Z,3(N-3$W)UT@/2`G5VET='-T;V-K)SL*)&-O;W)D:6YA=&5S
M6R='97)M86YY)UU;)S4S+C0R-SHQ,2XW.#0G72`]("=-96-K;&5N8G5R9RU6
M;W)P;VUM97)N+"!087)C:&EM)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;
M)S4S+C4S,SHW+C@X,R==(#T@)TIE=F5R)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S4S+C4S,SHY+C@S,R==(#T@)TAA;6)U<F<M1FEN:V5N=V5R9&5R
M)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4S+C4U,#HW+C8V-R==(#T@
M)U=I='1M=6YD:&%V96XG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N
M-C`P.C$S+C,Q-R==(#T@)U1R;VQL96YH86=E;B<["B1C;V]R9&EN871E<ULG
M1V5R;6%N>2==6R<U,RXV,S,Z,3`N,#`P)UT@/2`G2&%M8G5R9RU&=6AL<V)U
M971T96PG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N-S8W.C@N-C8W
M)UT@/2`G3F]R9&AO;'HG.PHD8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-3,N
M.#$W.C$P+C<P,"==(#T@)TQU96)E8VLM0FQA;FME;G-E92<["B1C;V]R9&EN
M871E<ULG1V5R;6%N>2==6R<U,RXY,3<Z,3(N,C@S)UT@/2`G3&%A9V4G.PHD
M8V]O<F1I;F%T97-;)T=E<FUA;GDG75LG-30N,#`P.CDN-3@S)UT@/2`G271Z
M96AO92<["B1C;V]R9&EN871E<ULG1V5R;6%N>2==6R<U-"XS,3<Z.2XU,S,G
M72`]("=(;VAN)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C,X,SHQ
M,"XQ-3`G72`]("=+:65L+4AO;'1E;F%U)SL*)&-O;W)D:6YA=&5S6R='97)M
M86YY)UU;)S4T+C0V-SHY+C4Q-R==(#T@)U-C:&QE<W=I9RU*86=E;"<["B1C
M;V]R9&EN871E<ULG1V5R;6%N>2==6R<U-"XV,S,Z.2XS-3`G72`]("=%9V=E
M8F5K)SL*)&-O;W)D:6YA=&5S6R='97)M86YY)UU;)S4T+C@S,SHY+C4P,"==
M(#T@)T=L=65C:W-B=7)G("\@365I97)W:6LG.PHD8V]O<F1I;F%T97-;)T=E
M<FUA;GDG75LG-30N.3$W.C@N,S4P)UT@/2`G5V5S=&5R;&%N9"`O(%-Y;'0G
M.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S$P+C`U,#HM,BXU,#`G72`]("=7
M82<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG,3`N.3`P.BTQ+C$P,"==(#T@
M)TYA=G)O;F=O)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<T+C@V-SHM,BXR
M,S,G72`]("=!>&EM)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<T+C@X,SHM
M,2XW-C<G72`]("=486MO<F%D:2<["B1C;V]R9&EN871E<ULG1VAA;F$G75LG
M-2XR,#`Z+3$N,#8W)UT@/2`G4V%L='!O;F0G.PHD8V]O<F1I;F%T97-;)T=H
M86YA)UU;)S4N-C`P.BTP+C$V-R==(#T@)T%C8W)A)SL*)&-O;W)D:6YA=&5S
M6R=':&%N82==6R<U+C8Q-SHP+C`P,"==(#T@)U1E;6$G.PHD8V]O<F1I;F%T
M97-;)T=H86YA)UU;)S4N-S@S.C`N-C,S)UT@/2`G061A)SL*)&-O;W)D:6YA
M=&5S6R=':&%N82==6R<U+CDS,SHM,"XY.#,G72`]("=!:VEM($]D82<["B1C
M;V]R9&EN871E<ULG1VAA;F$G75LG-BXP.#,Z+3`N,C4P)UT@/2`G2V]F;W)I
M9'5A)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<V+C$P,#HP+C$Q-R==(#T@
M)T%K=7-E)SL*)&-O;W)D:6YA=&5S6R=':&%N82==6R<V+C(P,#HM,BXS,S,G
M72`]("=3969W:2!"96MW86DG.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S8N
M-C`P.C`N-#8W)UT@/2`G2&\G.PHD8V]O<F1I;F%T97-;)T=H86YA)UU;)S8N
M-S$W.BTQ+C8P,"==(#T@)TMU;6%S:2<["B1C;V]R9&EN871E<ULG1VAA;F$G
M75LG-RXS,S,Z+3(N,S,S)UT@/2`G4W5N>6%N:2<["B1C;V]R9&EN871E<ULG
M1VAA;F$G75LG-RXW-3`Z+3(N,3`P)UT@/2`G5V5N8VAI)SL*)&-O;W)D:6YA
M=&5S6R=':&%N82==6R<Y+C`S,SHM,BXT.#,G72`]("=";VQE)SL*)&-O;W)D
M:6YA=&5S6R=':&%N82==6R<Y+C0U,#HM,"XP,3<G72`]("=996YD:2<["B1C
M;V]R9&EN871E<ULG1VAA;F$G75LG.2XU,#`Z+3`N.#4P)UT@/2`G5&%M86QE
M)SL*)&-O;W)D:6YA=&5S6R=':6)R86QT87(G75LG,S8N,34P.BTU+C,U,"==
M(#T@)T=I8G)A;'1A<B<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,U+C,S
M,SHR-2XQ.#,G72`]("=(97)A:VQI;VX@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG1W)E96-E)UU;)S,U+C0Q-#HR-RXQ-#@G72`]("=+87)P871H;W,@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;)S,U+C0X,SHR-"XQ,3<G
M72`]("=3;W5D82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M,S8N-#`P.C(X+C`X,R==(#T@)U)H;V1E<R!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R='<F5E8V4G75LG,S8N-S@S.C(W+C`V-R==(#T@)TMO<R!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S<N,#8W.C(R+C`Q-R==(#T@
M)TMA;&%M871A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S
M-RXU,S,Z,C(N-#`P)UT@/2`G5')I<&]L:7,@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG1W)E96-E)UU;)S,W+C<P,#HR-BXY,3<G72`]("=386UO<R!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG,S<N.3`P.C(S+C<S,R==
M(#T@)T%T:&EN86D@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;
M)S,W+CDQ-SHR,2XR.#,G72`]("=!;F1R879I9&$@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG1W)E96-E)UU;)S,X+C`V-SHR,RXU-3`G72`]("=%;&5F<VES
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XQ,#`Z,C,N
M-S@S)UT@/2`G5&%T;VDG.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XQ
M,3<Z,C`N-3`P)UT@/2`G2V5F86QH;FEA($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T=R965C92==6R<S."XQ-3`Z,C$N-#$W)UT@/2`G07)A>&]S($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S."XS,3<Z,C,N-3,S)UT@
M/2`G5&%N86=R82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG
M,S@N,S,S.C(V+C$S,R==(#T@)T-H:6]S($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)T=R965C92==6R<S."XV,3<Z,C`N-S8W)UT@/2`G06MT:6]N($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S.2XP-C<Z,C8N-C`P)UT@
M/2`G37ET:6QI;FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E96-E)UU;
M)S,Y+C(Q-SHR,BXX,#`G72`]("=!;F-H:6%L;W,@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG1W)E96-E)UU;)S,Y+C8Q-SHQ.2XY,3<G72`]("=+97)K>7)A
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<S.2XV,S,Z,C(N
M-#$W)UT@/2`G3&%R:7-S82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E
M8V4G75LG,SDN.3$W.C(U+C(S,R==(#T@)TQI;6YO<R!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R='<F5E8V4G75LG-#`N,S`P.C(Q+C<X,R==(#T@)TMO>F%N
M:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R='<F5E8V4G75LG-#`N-#4P.C(Q
M+C(X,R==(#T@)TMA<W1O<FEA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=R
M965C92==6R<T,"XU,3<Z,C(N.38W)UT@/2`G5&AE<W-A;&]N:6MI($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)T=R965C92==6R<T,"XX-3`Z,C4N.3$W)UT@
M/2`G06QE>&%N9')O=7!O;&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG1W)E
M96-E)UU;)S0P+CDX,SHR-"XV,#`G72`]("=#:')Y<V]U<&]L:2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-3DN.3@S.BTT-2XR,#`G
M72`]("=!;F=I<V]Q)SL*)&-O;W)D:6YA=&5S6R='<F5E;FQA;F0G75LG-C`N
M,#4P.BTT,RXQ-C<G72`]("=0<FEN<R!#:')I<W1I86X@4W5N9"<["B1C;V]R
M9&EN871E<ULG1W)E96YL86YD)UU;)S8P+C<Q-SHM-#8N,#4P)UT@/2`G2G5L
M:6%N96AA86(G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V,2XQ-C<Z
M+30U+C0Q-R==(#T@)TYA<G-A<G-U87$G.PHD8V]O<F1I;F%T97-;)T=R965N
M;&%N9"==6R<V,2XR,S,Z+30X+C$P,"==(#T@)T=R;V5N;F5D86PG.PHD8V]O
M<F1I;F%T97-;)T=R965N;&%N9"==6R<V,BXP,#`Z+30Y+C8V-R==(#T@)T9R
M961E<FEK<VAA86(G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<V-"XQ
M-C<Z+34Q+C<U,"==(#T@)T=O9'1H86%B("\@3G5U:R<["B1C;V]R9&EN871E
M<ULG1W)E96YL86YD)UU;)S8U+C4X,SHM,S<N,34P)UT@/2`G2W5L=7-U:R!,
M=69T:&%V;B<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8U+C8P,#HM
M,S<N-C,S)UT@/2`G5&%S:6EL87$G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N
M9"==6R<V-BXY,3<Z+34S+C8V-R==(#T@)TAO;'-T96EN<V)O<F<G.PHD8V]O
M<F1I;F%T97-;)T=R965N;&%N9"==6R<V-RXP,3<Z+34P+C<P,"==(#T@)U-D
M<B!3=')O96UF:F]R9"<["B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8W
M+C<X,SHM,S(N,S`P)UT@/2`G07!U=&ET965Q)SL*)&-O;W)D:6YA=&5S6R='
M<F5E;FQA;F0G75LG-C@N-S`P.BTU,BXW-3`G72`]("=%9V5D97-M:6YD92<[
M"B1C;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S8Y+C(S,SHM-3$N,#8W)UT@
M/2`G2F%C;V)S:&%V;B!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG1W)E96YL
M86YD)UU;)S<P+C0Q-SHM,C$N.38W)UT@/2`G0V%P92!4;V)I;B!!=71O;6%T
M960@4F5P;W)T:6YG(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)T=R965N;&%N
M9"==6R<W,"XT.#,Z+3(Q+CDU,"==(#T@)U-C;W)E<V)Y<W5N9"<["B1C;V]R
M9&EN871E<ULG1W)E96YL86YD)UU;)S<P+C<U,#HM,C(N-C4P)UT@/2`G0V]N
M<W1A8FQE(%!Y;G0G.PHD8V]O<F1I;F%T97-;)T=R965N;&%N9"==6R<W-"XS
M,#`Z+3(P+C(Q-R==(#T@)T1A;F5B;W)G)SL*)&-O;W)D:6YA=&5S6R='<F5E
M;FQA;F0G75LG-S8N-3,S.BTV."XW-3`G72`]("=4:'5L92!!+B!"+B<["B1C
M;V]R9&EN871E<ULG1W)E96YL86YD)UU;)S<V+C<V-SHM,3@N-C8W)UT@/2`G
M1&%N;6%R:W-H879N)SL*)&-O;W)D:6YA=&5S6R='<F5N861A)UU;)S$R+C`P
M,#HM-C$N-S@S)UT@/2`G4&]I;G0@4V%L:6YE<R!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R='=6%D96QO=7!E)UU;)S$V+C(V-SHM-C$N-3$W)UT@/2`G3&4@
M4F%I>F5T+"!'=6%D96QO=7!E)SL*)&-O;W)D:6YA=&5S6R='=6%D96QO=7!E
M)UU;)S$W+CDP,#HM-C(N.#4P)UT@/2`G1W5S=&%V:6$L(%-A:6YT($)A<G1H
M96QE;7DG.PHD8V]O<F1I;F%T97-;)T=U871E;6%L82==6R<Q,RXY,3<Z+3DP
M+C@Q-R==(#T@)U-A;B!*;W-E)SL*)&-O;W)D:6YA=&5S6R='=6%T96UA;&$G
M75LG,30N-3,S.BTY,2XV-C<G72`]("=2971A;&AU;&5U)SL*)&-O;W)D:6YA
M=&5S6R='=6%T96UA;&$G75LG,30N-3@S.BTY,"XU,3<G72`]("='=6%T96UA
M;&$@065R;W!U97)T;VQA($%U<F]R82<["B1C;V]R9&EN871E<ULG1W5A=&5M
M86QA)UU;)S$U+C,Q-SHM.3$N-#8W)UT@/2`G2'5E:'5E=&5N86YG;R<["B1C
M;V]R9&EN871E<ULG1W5A=&5M86QA)UU;)S$U+C0V-SHM.3`N,S$W)UT@/2`G
M0V]B86XG.PHD8V]O<F1I;F%T97-;)T=U871E;6%L82==6R<Q-2XW,3<Z+3@X
M+C8P,"==(#T@)U!U97)T;R!"87)R:6]S)SL*)&-O;W)D:6YA=&5S6R='=6%T
M96UA;&$G75LG,38N.3$W.BTX.2XX.#,G72`]("=&;&]R97,G.PHD8V]O<F1I
M;F%T97-;)T=U:6YE82==6R<Q,"XP,S,Z+3$P+C<U,"==(#T@)T9A<F%N86@@
M+R!"861A;&$G.PHD8V]O<F1I;F%T97-;)T=U:6YE82==6R<Q,"XP-3`Z+3$R
M+C@V-R==(#T@)TMI;F1I82<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)S$P
M+C,X,SHM.2XS,#`G72`]("=+86YK86XG.PHD8V]O<F1I;F%T97-;)T=U:6YE
M82==6R<Q,"XY,S,Z+3$T+C,Q-R==(#T@)T)O:V4G.PHD8V]O<F1I;F%T97-;
M)T=U:6YE82==6R<Q,2XS,3<Z+3$R+C,P,"==(#T@)TQA8F4G.PHD8V]O<F1I
M;F%T97-;)T=U:6YE82==6R<Q,2XT,S,Z+3DN,38W)UT@/2`G4VEG=6ER:2<[
M"B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)S<N-S,S.BTX+C@S,R==(#T@)TY<
M)UIE<F5K;W)E)SL*)&-O;W)D:6YA=&5S6R='=6EN96$G75LG."XU,S,Z+3DN
M-#8W)UT@/2`G36%C96YT82<["B1C;V]R9&EN871E<ULG1W5I;F5A)UU;)SDN
M,3@S.BTQ,"XQ,#`G72`]("=+:7-S:61O=6=O=2<["B1C;V]R9&EN871E<ULG
M1W5I;F5A)UU;)SDN-38W.BTQ,RXV,3<G72`]("=#;VYA:W)Y("\@1V)E<W-I
M82<["B1C;V]R9&EN871E<ULG1W5I;F5A+4)I<W-A=2==6R<Q,2XX.#,Z+3$U
M+C8U,"==(#T@)T)I<W-A=2!!97)O<&]R="<["B1C;V]R9&EN871E<ULG1W5I
M;F5A+4)I<W-A=2==6R<Q,BXQ-C<Z+3$T+C8V-R==(#T@)T)A9F%T82<["B1C
M;V]R9&EN871E<ULG1W5Y86YA)UU;)S8N-3`P.BTU."XR-3`G72`]("=4:6UE
M:')I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)T=U>6%N82==6R<V+C@P,#HM
M-3@N,34P)UT@/2`G1V5O<F=E=&]W;B<["B1C;V]R9&EN871E<ULG2&%I=&DG
M75LG,3@N-38W.BTW,BXS,#`G72`]("=0;W)T+4%U+5!R:6YC92`O($%E<F]P
M;W)T($EN=&5R;F%T:6]N86PG.PHD8V]O<F1I;F%T97-;)TAA:71I)UU;)S$Y
M+C<U,#HM-S(N,3@S)UT@/2`G0V%P+4AA:71I96XG.PHD8V]O<F1I;F%T97-;
M)TAO;F1U<F%S)UU;)S$S+C(V-SHM.#<N-C4P)UT@/2`G06UA<&%L82<["B1C
M;V]R9&EN871E<ULG2&]N9'5R87,G75LG,3,N,S`P.BTX-RXQ.#,G72`]("=#
M:&]L=71E8V$G.PHD8V]O<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$T+C`U,#HM
M.#<N,C$W)UT@/2`G5&5G=6-I9V%L<&$G.PHD8V]O<F1I;F%T97-;)TAO;F1U
M<F%S)UU;)S$T+C,Q-SHM.#@N,34P)UT@/2`G3&$@17-P97)A;GIA)SL*)&-O
M;W)D:6YA=&5S6R=(;VYD=7)A<R==6R<Q-"XS.#,Z+3@W+C8Q-R==(#T@)T-O
M<F]N96P@16YR:7%U92!3;W1O($-A;F\@06ER($)A<V4G.PHD8V]O<F1I;F%T
M97-;)TAO;F1U<F%S)UU;)S$T+C<X,SHM.#@N-S@S)UT@/2`G4V%N=&$@4F]S
M82!$92!#;W!A;B<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,30N.3`P
M.BTX-2XY,S,G72`]("=#871A8V%M87,G.PHD8V]O<F1I;F%T97-;)TAO;F1U
M<F%S)UU;)S$U+C$V-SHM.#<N,3$W)UT@/2`G66]R;R<["B1C;V]R9&EN871E
M<ULG2&]N9'5R87,G75LG,34N,C$W.BTX,RXX,#`G72`]("=0=65R=&\@3&5M
M<&ER82<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,34N-#4P.BTX-RXY
M,S,G72`]("=,82!-97-A(%-A;B!0961R;R!3=6QA)SL*)&-O;W)D:6YA=&5S
M6R=(;VYD=7)A<R==6R<Q-2XW,3<Z+3@W+C0X,R==(#T@)U1E;&$G.PHD8V]O
M<F1I;F%T97-;)TAO;F1U<F%S)UU;)S$U+C<S,SHM.#8N.#8W)UT@/2`G3&$@
M0V5I8F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2&]N9'5R87,G75LG,38N
M,S$W.BTX-BXU,3<G72`]("=2;V%T86XG.PHD8V]O<F1I;F%T97-;)TAO;F1U
M<F%S)UU;)S$V+C0V-SHM.#8N,#8W)UT@/2`G1W5A;F%J82<["B1C;V]R9&EN
M871E<ULG2&]N9'5R87,G75LG,3<N-#`P.BTX,RXY,S,G72`]("=)<VQA<R!$
M96P@0VES;F4G.PHD8V]O<F1I;F%T97-;)TAO;F<@2V]N9R==6R<R,BXR,#`Z
M,3$T+C`Q-R==(#T@)T-H975N9R!#:&%U)SL*)&-O;W)D:6YA=&5S6R=(;VYG
M($MO;F<G75LG,C(N,S,S.C$Q-"XQ.#,G72`]("=(;VYG($MO;F<@26YT97(M
M3F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T
M-BXQ,#`Z,3@N,C,S)UT@/2`G4&5C<R`O(%!O9V%N>2<["B1C;V]R9&EN871E
M<ULG2'5N9V%R>2==6R<T-BXR-3`Z,C`N,3`P)UT@/2`G4WIE9V5D)SL*)&-O
M;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0V+C,X,SHQ-RXX,S,G72`]("=+87!O
M<W9A<B<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-BXV.#,Z,C$N,38W
M)UT@/2`G0F5K97-C<V%B82<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T
M-BXY,3<Z,3@N,#4P)UT@/2`G4VEO9F]K)SL*)&-O;W)D:6YA=&5S6R=(=6YG
M87)Y)UU;)S0V+CDQ-SHQ.2XW-3`G72`]("=+96-S:V5M970G.PHD8V]O<F1I
M;F%T97-;)TAU;F=A<GDG75LG-#<N,3$W.C(P+C(S,R==(#T@)U-Z;VQN;VLG
M.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N,C`P.C$W+C4P,"==(#T@
M)U!A<&$G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#<N,C8W.C$V+C8S
M,R==(#T@)U-Z;VUB871H96QY)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;
M)S0W+C0S,SHQ.2XR-C<G72`]("="=61A<&5S="`O($9E<FEH96=Y)SL*)&-O
M;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C0U,#HQ."XY-C<G72`]("="=61A
M;W)S)SL*)&-O;W)D:6YA=&5S6R=(=6YG87)Y)UU;)S0W+C0X,SHR,2XV,#`G
M72`]("=$96)R96-E;B<["B1C;V]R9&EN871E<ULG2'5N9V%R>2==6R<T-RXU
M,3<Z,3DN,#,S)UT@/2`G0G5D87!E<W0@365T($-E;G1E<B<["B1C;V]R9&EN
M871E<ULG2'5N9V%R>2==6R<T-RXY-C<Z,C$N.3@S)UT@/2`G3GEI<F5G>6AA
M>F$@+R!.87!K;W(G.PHD8V]O<F1I;F%T97-;)TAU;F=A<GDG75LG-#@N,#@S
M.C(P+C<V-R==(#T@)TUI<VMO;&,G.PHD8V]O<F1I;F%T97-;)TEC96QA;F0G
M75LG-C,N-#`P.BTR,"XR.#,G72`]("=697-T;6%N;F%E>6IA<B<["B1C;V]R
M9&EN871E<ULG26-E;&%N9"==6R<V,RXY-C<Z+3(R+C8P,"==(#T@)TME9FQA
M=FEK=7)F;'5G=F]L;'5R)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8T
M+C$S,SHM,C$N.3`P)UT@/2`G4F5Y:VIA=FEK)SL*)&-O;W)D:6YA=&5S6R=)
M8V5L86YD)UU;)S8T+C,P,#HM,34N,C$W)UT@/2`G06MU<FYE<R<["B1C;V]R
M9&EN871E<ULG26-E;&%N9"==6R<V-2XP.#,Z+3(R+C<S,R==(#T@)U-T>6MK
M:7-H;VQM=7(G.PHD8V]O<F1I;F%T97-;)TEC96QA;F0G75LG-C4N,C@S.BTQ
M-"XT,#`G72`]("=%9VEL<W-T861I<B<["B1C;V]R9&EN871E<ULG26-E;&%N
M9"==6R<V-2XV.#,Z+3$X+C`X,R==(#T@)T%K=7)E>7)I)SL*)&-O;W)D:6YA
M=&5S6R=)8V5L86YD)UU;)S8U+C<P,#HM,30N.#$W)UT@/2`G4VMJ86QD=&AI
M;F=S<W1A9&ER)SL*)&-O;W)D:6YA=&5S6R=)8V5L86YD)UU;)S8V+C0U,#HM
M,34N.34P)UT@/2`G4F%U9F%R:&]F;B<["B1C;V]R9&EN871E<ULG26-E;&%N
M9"==6R<V-BXU,S,Z+3$X+C`Q-R==(#T@)T=R:6US97DG.PHD8V]O<F1I;F%T
M97-;)TEN9&EA)UU;)S$P+C<V-SHW."XW,3<G72`]("=4:7)U8VAC:&ER87!A
M;&QI)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q,2XP,S,Z-S<N,#4P)UT@
M/2`G0V]I;6)A=&]R92`O(%!E96QA;65D=2<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,3$N-C8W.CDR+C<Q-R==(#T@)U!O<G0@0FQA:7(G.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S$R+CDQ-SHW-"XX.#,G72`]("=-86YG86QO<F4@
M+R!"86IP92<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3(N.3$W.C<Y+C$U
M,"==(#T@)U9E;&QO<F4G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$S+C`P
M,#HX,"XQ.#,G72`]("=-861R87,@+R!-:6YA;6)A:VMA;2<["B1C;V]R9&EN
M871E<ULG26YD:6$G75LG,30N-#@S.C<X+C@S,R==(#T@)T-U9&1A<&%H)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<Q-2XQ-3`Z-S8N.#4P)UT@/2`G0F5L
M;&%R>2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,34N,S@S.C<S+C@Q-R==
M(#T@)T=O82`O($1A8F]L:6T@06ER<&]R="<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,34N.#4P.C<T+C8Q-R==(#T@)T)E;&=A=6T@+R!386UB<F$G.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$V+C4S,SHX,"XX,#`G72`]("=6:6IA
M>6%W861A("\@1V%N;F%V87)A;2<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,38N-S`P.C<T+C(S,R==(#T@)TMO;&AA<'5R)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<Q-RXT-3`Z-S@N-#8W)UT@/2`G2'ED97)A8F%D($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S$W+C8V-SHW-2XY,#`G72`]("=3
M:&]L87!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,3DN,3$W.C<R+C@U
M,"==(#T@)T)O;6)A>2`O(%-A;G1A8W)U>B<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,3DN.#4P.C<U+C0P,"==(#T@)T%U<F%N9V%B860@0VAI:V%L=&AA
M;B!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(P+C(U,#HX
M-2XX,S,G72`]("=":'5B86YE<W=A<B<["B1C;V]R9&EN871E<ULG26YD:6$G
M75LG,C`N-S`P.C<W+C`V-R==(#T@)T%K;VQA)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<R,2XQ,#`Z-SDN,#4P)UT@/2`G3F%G<'5R(%-O;F5G86]N)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,2XW-3`Z-S(N,C`P)UT@/2`G0FAA
M=6YA9V%R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R,2XX,S,Z-S8N,S8W
M)UT@/2`G2VAA;F1W82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C$N.3$W
M.C@T+C`X,R==(#T@)TIH87)S=6=U9&$G.PHD8V]O<F1I;F%T97-;)TEN9&EA
M)UU;)S(R+C,P,#HW,"XW.#,G72`]("=286IK;W0G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(R+C8U,#HX."XT-3`G72`]("=#86QC=71T82`O($1U;2!$
M=6TG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R+C<Q-SHW-2XX,#`G72`]
M("=);F1O<F4G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(R+C@Q-SHX-BXQ
M.#,G72`]("=*86US:&5D<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R
M,RXP-C<Z-S(N-C,S)UT@/2`G06AM861A8F%D)SL*)&-O;W)D:6YA=&5S6R=)
M;F1I82==6R<R,RXR,#`Z-SDN.34P)UT@/2`G2F%B86QP=7(G.PHD8V]O<F1I
M;F%T97-;)TEN9&EA)UU;)S(S+C(U,#HV.2XV-C<G72`]("=":'5J+5)U9')A
M;6%T82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,C,N,C@S.C<W+C,U,"==
M(#T@)T)H;W!A;"`O($)A:7)A9V%R:"<["B1C;V]R9&EN871E<ULG26YD:6$G
M75LG,C,N,S$W.C@U+C,Q-R==(#T@)TTN($\N(%)A;F-H:2<["B1C;V]R9&EN
M871E<ULG26YD:6$G75LG,C,N.#@S.CDQ+C(U,"==(#T@)T%G87)T86QA)SL*
M)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-"XU-C<Z.#`N.#,S)UT@/2`G4V%T
M;F$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(T+C8Q-SHW,RXX.#,G72`]
M("=59&%I<'5R($1A8F]K)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-"XW
M-3`Z.#0N.34P)UT@/2`G1V%Y82<["B1C;V]R9&EN871E<ULG26YD:6$G75LG
M,C0N-S8W.CDS+CDP,"==(#T@)TEM<&AA;"!4=6QI:&%L)SL*)&-O;W)D:6YA
M=&5S6R=);F1I82==6R<R-2XQ-3`Z-S4N.#4P)UT@/2`G2V]T82!!97)O9')O
M;64G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(U+C0U,#HW."XU.#,G72`]
M("=*:&%N<VDG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(U+C0U,#HX,2XW
M,S,G72`]("=!;&QA:&%B860@+R!"86UH<F%U;&DG.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(U+C0U,#HX,BXX-C<G72`]("=687)A;F%S:2`O($)A8F%T
M<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-2XV,#`Z.#4N,3`P)UT@
M/2`G4&%T;F$G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(V+C$P,#HY,2XU
M.#,G72`]("='875H871I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXR
M,S,Z-S@N,C4P)UT@/2`G1W=A;&EO<B<["B1C;V]R9&EN871E<ULG26YD:6$G
M75LG,C8N,S`P.C<S+C`Q-R==(#T@)TIO9&AP=7(G.PHD8V]O<F1I;F%T97-;
M)TEN9&EA)UU;)S(V+C0P,#HX,"XT,#`G72`]("=+86YP=7(@+R!#:&%K97)I
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-BXV,S,Z.#@N,S$W)UT@/2`G
M4VEL:6=U<FDG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(V+C<U,#HX,"XX
M.#,G72`]("=,=6-K;F]W("\@06UA=7-I)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R-BXW-3`Z.#,N,S8W)UT@/2`G1V]R86MH<'5R)SL*)&-O;W)D:6YA
M=&5S6R=);F1I82==6R<R-BXX,3<Z-S4N.#`P)UT@/2`G2F%I<'5R("\@4V%N
M9V%N97(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(W+C$U,#HW-RXY-C<G
M72`]("=!9W)A)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R-RXR,S,Z.30N
M,3$W)UT@/2`G3F]R=&@@3&%K:&EM<'5R)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<R-RXT.#,Z.34N,#$W)UT@/2`G1&EB<G5G87)H("\@36]H86YB87)I
M)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<R."XS-C<Z-SDN-#`P)UT@/2`G
M0F%R96EL;'DG.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(X+C4V-SHW-RXQ
M,3<G72`]("=.97<@1&5L:&D@+R!086QA;2<["B1C;V]R9&EN871E<ULG26YD
M:6$G75LG,C@N-3@S.C<W+C(P,"==(#T@)TYE=R!$96QH:2`O(%-A9F1A<FIU
M;F<G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S(Y+C$V-SHW-2XW,S,G72`]
M("=(:7-S87(G.PHD8V]O<F1I;F%T97-;)TEN9&EA)UU;)S,Q+C(U,#HW-BXV
M-C<G72`]("=":6QA<W!U<B<["B1C;V]R9&EN871E<ULG26YD:6$G75LG,S$N
M-C,S.C<T+C@V-R==(#T@)T%M<FET<V%R)SL*)&-O;W)D:6YA=&5S6R=);F1I
M82==6R<X+C0V-SHW-BXY-3`G72`]("=4:&ER=79A;F%N=&AA<'5R86TG.PHD
M8V]O<F1I;F%T97-;)TEN9&EA)UU;)SDN,34P.CDR+C@Q-R==(#T@)T-A<B!.
M:6-O8F%R)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Y+C@S,SHW."XP.#,G
M72`]("=-861U<F%I)SL*)&-O;W)D:6YA=&5S6R=);F1I82==6R<Y+CDU,#HW
M-BXR-C<G72`]("=#;V-H:6X@+R!7:6QL:6YG9&]N)SL*)&-O;W)D:6YA=&5S
M6R=);F1O;F5S:6$G75LG,"XQ,3<Z,3$Q+C4S,R==(#T@)U-I;G1A;F<G.PHD
M8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,"XQ-3`Z,3`Y+C0P,"==(#T@
M)U!O;G1I86YA:R`O(%-U<&%D:6\G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<P+C0V-SHQ,#$N-#4P)UT@/2`G4&%K86YB87)U("\@4VEM<&%N9W1I
M9V$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<P+C0V-SHQ,#(N,S$W
M)UT@/2`G4F5N9V%T("\@2F%P=7)A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3`N-#@S.C$P-"XU.#,G72`]("=3:6YG:V5P("\@1&%B;R<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S`N-3$W.C$R,RXP-C<G72`]("='
M;W)O;G1A;&\@+R!*86QA;'5D9&EN)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3`N-C$W.C$Q-RXQ-3`G72`]("=386UA<FEN9&$@+R!496UI;F1U
M;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,"XV.#,Z,3$Y+C<S
M,R==(#T@)U!A;'4@+R!-=71I87)A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG,"XW.#,Z,3(W+C,X,R==(#T@)U1E<FYA=&4@+R!"86)U;&QA:"<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTP+C@X,SHQ,#`N,S4P)UT@
M/2`G4&%D86YG("\@5&%B:6YG)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3`N.#@S.C$S-"XP-3`G72`]("=-86YO:W=A<FD@+R!296YD86YI)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N.3`P.C$R,BXW.#,G72`]
M("=,=7=U:R`O($)U8G5N9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;
M)S`N.3$W.C$P-"XU,S,G72`]("=486YJ=6YG<&EN86YG("\@2VEJ86YG)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3`N.3,S.C$S,2XQ,3<G72`]
M("=3;W)O;F<@+R!*969M86XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M,"XY-3`Z,3$T+CDP,"==(#T@)TUU87)A=&5W92`O($)E<FEN9VEN)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3$N,#`P.C$Q-"XP,#`G72`]
M("=086QA;F=K87)A>6$@+R!086YA<G5N9R<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)S$N,#$W.C$R,"XX,#`G72`]("=4;VQI+51O;&D@+R!,86QO
M<R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N,#@S.C$P.2XV-C<G
M72`]("=3:6YG:V%W86YG($EI)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG,2XQ,3<Z,3`T+C$Q-R==(#T@)T)A=&%N("A3=6UA=')A*2<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C$X,SHQ,S8N,3$W)UT@/2`G0FEA
M:R`O($UO:VUE<B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C(V
M-SHQ,38N.3`P)UT@/2`G0F%L:6MP87!A;B`O(%-E<&EN9V=A;B<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C,X,SHQ,C`N-S,S)UT@/2`G4&]S
M;R`O($MA<VEG=6YC=2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N
M-3`P.CDW+C8S,R==(#T@)T=U;G5N9R!3:71O;&D@+R!":6YA:V$G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<Q+C4S,SHQ,C0N.3$W)UT@/2`G365N
M861O("\@1'(N(%-A;2!2871U;&%N9VDG.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<Q+C4U,#HY."XX.#,G72`]("=3:6)O;&=A("\@4&EN86YG<V]R
M:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ+C8Q-SHQ,C0N-34P
M)UT@/2`G3&%B=6AA("\@5&%L:6%B=2<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTQ+C8S,SHQ,#,N-C4P)UT@/2`G2F%M8FD@+R!3=6QT86X@5&%H
M82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S$N.#$W.C$R-RXX,S,G
M72`]("='86QE;&$@+R!'86UA<FUA;&%M=2<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)RTQ+C@S,SHQ,S@N-S$W)UT@/2`G4V%R;6DG.PHD8V]O<F1I
M;F%T97-;)TEN9&]N97-I82==6R<M,2XX-3`Z,3`Y+CDV-R==(#T@)TME=&%P
M86YG("\@4F%H861I(%5S;6%M86XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I
M82==6R<M,2XX-C<Z,3,V+C(S,R==(#T@)U-E<G5I("\@665N9&]S82<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ,"XQ-C<Z,3(S+C8V-R==(#T@
M)TMU<&%N9R`O($5L(%1A<FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M,3`N-3`P.C$R,2XX,S,G72`]("=386)U("\@5&%R9&%M=2<["B1C;V]R
M9&EN871E<ULG26YD;VYE<VEA)UU;)RTQ,"XW,S,Z,3(S+C`V-R==(#T@)U)O
M=&4@+R!"86$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXP.#,Z
M,3(V+C`P,"==(#T@)U-A;F%N82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)S(N,3$W.C$Q-RXT-3`G72`]("=486YJ=6YG(%)E9&5P("\@0F5R874G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXQ-C<Z,3`V+C$S,R==
M(#T@)U!A;F=K86QP:6YA;F<@+R!086YG:V%L<&EN86YG)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3(N-38W.C$T,"XT.#,G72`]("=*87EA<'5R
M82`O(%-E;G1A;FDG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,BXW
M,#`Z,3$P+C<P,"==(#T@)U!A;F=K86QA;B!"=6X@+R!)<VMA;F1A<B<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTR+C<U,#HQ,#<N-S4P)UT@/2`G
M5&%N:G5N9W!A;F1A;B`O($)U;'5H(%1U;6)A;F<G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,BXW-C<Z,3`Q+C,V-R==(#T@)TME<FEN8VD@+R!$
M97!A=&D@4&%R8F\G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<R+C@U
M,#HQ,3<N,S,S)UT@/2`G5&%N:G5N9R!396QO<B<["B1C;V]R9&EN871E<ULG
M26YD;VYE<VEA)UU;)RTR+C@X,SHQ,S(N,C4P)UT@/2`G1F%K+49A:R`O(%1O
M<F5A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3(N.3`P.C$P-"XW
M,#`G72`]("=086QE;6)A;F<@+R!486QA;F=B971U='4G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M,RXR-3`Z,3(W+C`X,R==(#T@)TYA;6QE82<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S,N,S,S.C$Q-RXU-C<G72`]
M("=487)A:V%N("\@2G5W871A)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+3,N,S,S.C$S-2XU,#`G72`]("=.86)I<F4G.PHD8V]O<F1I;F%T97-;
M)TEN9&]N97-I82==6R<M,RXS-3`Z,3(X+C@X,R==(#T@)T%M86AA:2<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTS+C0P,#HQ,38N,C$W)UT@/2`G
M2V]T86)A<G4G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXT,S,Z
M,3$T+C<U,"==(#T@)T)A;FIA<FUA<VEN("\@4WEA;7-U9&1I;B!.;V]R)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG,RXU-C<Z.3@N-C@S)UT@/2`G
M365D86X@+R!0;VQO;FEA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG
M,RXU.#,Z,3(U+C0V-R==(#T@)U1A:'5N82<["B1C;V]R9&EN871E<ULG26YD
M;VYE<VEA)UU;)RTS+C8V-SHQ,S,N-S4P)UT@/2`G2V%I;6%N82`O(%5T87)O
M;2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTS+C<P,#HQ,C@N,#@S
M)UT@/2`G06UB;VX@+R!0871T:6UU<F$G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<S+C<S,SHQ,34N-C@S)UT@/2`G3&]N9V)A=V%N("\@2G5V86D@
M4V5M87)I;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXX.#,Z
M,3`R+C,S,R==(#T@)T)E;F=K=6QU("\@4&%D86YG:V5M:6QI;F<G.PHD8V]O
M<F1I;F%T97-;)TEN9&]N97-I82==6R<M,RXY,3<Z,3,V+C,V-R==(#T@)T5N
M87)O=&%L:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S,N.34P.C$P
M."XS.#,G72`]("=286YA:2`O(%)A;F%I)SL*)&-O;W)D:6YA=&5S6R=);F1O
M;F5S:6$G75LG+30N,#8W.C$S."XY-3`G72`]("=786UE;F$@+R!786UE;F$G
M.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-"XQ,#`Z,3(R+C0S,R==
M(#T@)TME;F1A<FD@+R!7;VQT97)M;VXM1VEN<VED:2<["B1C;V]R9&EN871E
M<ULG26YD;VYE<VEA)UU;)S0N,C4P.CDV+C$Q-R==(#T@)TUE=6QA8F]H("\@
M0W5T($YY86L@1&AI96XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M-"XT-3`Z,3`U+C$X,R==(#T@)TUE;F=G86QA("\@07-T<F$@2W-E=')A)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+30N-S$W.C$S-BXT,S,G72`]
M("=+;VMO;F%O("\@5&EM=6MA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G
M75LG+34N,#8W.C$Q.2XU-3`G72`]("=5:G5N9R!086YD86YG("\@2&%S86YU
M9&1I;B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S4N,C,S.CDW+C(P
M,"==(#T@)TQH;VMS975M87=E("\@36%L:6MU<W-A;&5H)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+34N,C8W.C$P-2XQ.#,G72`]("=496QU:V)E
M='5N9R`O($)E<F%N=&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M-2XT-C<Z,3(R+C8Q-R==(#T@)T)A=2U"874@+R!"971O($%M8FER:2<["B1C
M;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)S4N-3$W.CDU+C0Q-R==(#T@)T)A
M;F1A($%C96@@+R!";&%N9V)I;G1A;F<G.PHD8V]O<F1I;F%T97-;)TEN9&]N
M97-I82==6R<U+C@V-SHY-2XS,3<G72`]("=386)A;F<@+R!#=70@0F%U)SL*
M)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+38N,3`P.C$T,"XS,#`G72`]
M("=486YA:"!-97)A:"`O(%1A;F%H($UE<F%H)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+38N,3$W.C$P-BXV-3`G72`]("=*86MA<G1A("\@4V]E
M:V%R;F\M2&%T=&$G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-BXR
M,S,Z,3`V+C8U,"==(#T@)T-U<G5G("\@0G5D:6%R=&\G.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M-BXR-3`Z,3`V+CDP,"==(#T@)TIA:V%R=&$@
M2&%L:6T@4&5R9&%N86MU<W5M82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA
M)UU;)RTV+C4U,#HQ,#<N-C8W)UT@/2`G2V%L:6IA=&DG.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M-BXY,#`Z,3`W+C4X,R==(#T@)T)A;F1U;F<@
M+R!(=7-E:6XG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-BXY.#,Z
M,3$P+C,X,R==(#T@)U-E;6%R86YG("\@06AM861Y86YI)SL*)&-O;W)D:6YA
M=&5S6R=);F1O;F5S:6$G75LG+3<N,C$W.C$Q,BXW,3<G72`]("=3=7)A8F%Y
M82`O(%!E<F%K)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N,C$W
M.C$Q,RXW,3<G72`]("=3=7)A8F%Y82<["B1C;V]R9&EN871E<ULG26YD;VYE
M<VEA)UU;)RTW+C,S,SHQ,#@N,C4P)UT@/2`G5&%S:6MM86QA>6$@+R!#:6)E
M=7)E=6TG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXS-C<Z,3$R
M+C<V-R==(#T@)U-U<F%B87EA("\@2G5A;F1A)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+3<N-C$W.C$Q,2XU,3<G72`]("=-861I=6X@+R!)<W=A
M:'EU9&DG.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M-RXW,S,Z,3`Y
M+C`Q-R==(#T@)T-I;&%C87`G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==
M6R<M-RXW.#,Z,3$P+C0S,R==(#T@)TIO9WEA:V%R=&$@+R!!9&ES=6-I<'1O
M)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3<N.#8W.C$Q,"XY,3<G
M72`]("=3=7)A:V%R=&$@+R!!9&ES=6UA<FUO)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+3<N.38W.C$Q,BXW,#`G72`]("=-86QA;F<@+R!!8F1U
M;"!286AK;6%N<V%L96@G.PHD8V]O<F1I;F%T97-;)TEN9&]N97-I82==6R<M
M-RXY.#,Z,3,Q+C,P,"==(#T@)U-A=6UL86MI)SL*)&-O;W)D:6YA=&5S6R=)
M;F1O;F5S:6$G75LG+3@N,C$W.C$R-"XU-C<G72`]("=!;&]R("\@36%L:2<[
M"B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C(V-SHQ,C(N.38W)UT@
M/2`G3&%R86YT=6MA)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S:6$G75LG+3@N
M-#,S.C$Q-RXT,3<G72`]("=3=6UB87=A($)E<V%R("\@4W5M8F%W82!"97-A
M<B<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C0V-SHQ-#`N,S@S
M)UT@/2`G365R875K92`O($UO<&%H)SL*)&-O;W)D:6YA=&5S6R=);F1O;F5S
M:6$G75LG+3@N-3,S.C$Q-BXP-C<G72`]("=!;7!E;F%N("\@4V5L87!A<F%N
M9R<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C4U,#HQ,3@N-S`P
M)UT@/2`G0FEM82<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTX+C8S
M,SHQ,C(N,C4P)UT@/2`G36%U;65R92`O(%=A:2!/=&DG.PHD8V]O<F1I;F%T
M97-;)TEN9&]N97-I82==6R<M."XW-3`Z,3$U+C$V-R==(#T@)T1E;G!A<V%R
M("\@3F=U<F%H+5)A:2<["B1C;V]R9&EN871E<ULG26YD;VYE<VEA)UU;)RTY
M+C8V-SHQ,C`N,S,S)UT@/2`G5V%I;F=A<'4@+R!-874@2&%U)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(U+C0Q-SHV
M,"XW-3`G72`]("=#:&%H8F%H87(G.PHD8V]O<F1I;F%T97-;)TER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8G75LG,C8N-3@S.C4T+C@S,R==(#T@)T)A;F1A
M<B!,96YG96@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8G75LG,C8N-C,S.C4W+C<V-R==(#T@)TIA<VLG.PHD8V]O<F1I;F%T
M97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,C<N,C`P.C8P+C<P
M,"==(#T@)TER86YS:&%H<B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B==6R<R-RXR,3<Z-38N,S8W)UT@/2`G0F%N9&%R86)B
M87-S)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F
M)UU;)S(X+CDV-SHU,RXV.#,G72`]("=&87-A)SL*)&-O;W)D:6YA=&5S6R=)
M<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(X+CDX,SHU,"XX,S,G72`]
M("="=7-H96AR($-I=B`O($%F8B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L
M86UI8R!297!U8FQI8R!O9B==6R<R.2XQ,#`Z-3@N-#`P)UT@/2`G0F%M)SL*
M)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(Y
M+C0V-SHV,"XX.#,G72`]("=:86AE9&%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S(Y+C4S,SHU,BXU.#,G72`]("=3
M:&ER87HG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@
M;V8G75LG,S`N,C4P.C4V+CDV-R==(#T@)TME<FUA;B<["B1C;V]R9&EN871E
M<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,"XS-C<Z-#@N,C4P
M)UT@/2`G06)A9&%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E
M<'5B;&EC(&]F)UU;)S,P+C0S,SHU,"XW-C<G72`]("='86-H(%-A<F%N($1U
M($=U;F)A9&%N)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B
M;&EC(&]F)UU;)S,P+C<V-SHT.2XV-C<G72`]("=/;6ED:65H)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,Q+C$X,SHU
M,BXV-C<G72`]("=!8F%D96@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M
M:6,@4F5P=6)L:6,@;V8G75LG,S$N,S,S.C0X+C8V-R==(#T@)T%H=V%Z)SL*
M)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,Q
M+C,S,SHV,2XT.#,G72`]("=:86)O;"<["B1C;V]R9&EN871E<ULG27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B==6R<S,2XY,#`Z-30N-#`P)UT@/2`G66%Z
M9"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==
M6R<S,2XY.#,Z-#DN,C8W)UT@/2`G36%S:F5D+5-O;&5Y;6%N)SL*)&-O;W)D
M:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,R+C,S,SHU
M,"XX-3`G72`]("=3:&%H<F4M2V]R9"<["B1C;V]R9&EN871E<ULG27)A;BP@
M27-L86UI8R!297!U8FQI8R!O9B==6R<S,BXT-C<Z-3$N-S$W)UT@/2`G17-F
M86AA;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B==6R<S,BXX-C<Z-3DN,C`P)UT@/2`G0FER:F%N9"<["B1C;V]R9&EN871E
M<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S,RXV,#`Z-38N.3$W
M)UT@/2`G5&%B87,G.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P
M=6)L:6,@;V8G75LG,S,N.3@S.C4Q+C0U,"==(#T@)TMA<VAA;B<["B1C;V]R
M9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-"XQ,#`Z
M-#DN-#`P)UT@/2`G07)A:R<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI
M8R!297!U8FQI8R!O9B==6R<S-"XR-C<Z-#<N,3$W)UT@/2`G2V5R;6%N<VAA
M:"<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==
M6R<S-"XU,3<Z-#4N-3@S)UT@/2`G1VAA<W)E+5-H:7)I;B<["B1C;V]R9&EN
M871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-2XR-C<Z-3DN
M,C$W)UT@/2`G5&]R8F%T+4AE>61A<FEE:"<["B1C;V]R9&EN871E<ULG27)A
M;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-2XS,S,Z-#<N,#`P)UT@/2`G
M4V%N86YD86HG.PHD8V]O<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L
M:6,@;V8G75LG,S4N-34P.C4S+C,X,R==(#T@)U-E;6YA;B<["B1C;V]R9&EN
M871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==6R<S-2XV.#,Z-3$N
M,S4P)UT@/2`G5&5H<F%N+4UE:')A8F%D)SL*)&-O;W)D:6YA=&5S6R=)<F%N
M+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C(Q-SHU-RXV-C<G72`]("=3
M86)Z979A<B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI
M8R!O9B==6R<S-BXR-3`Z-#8N,C8W)UT@/2`G4V%G:&5Z)SL*)&-O;W)D:6YA
M=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V+C(U,#HU,"XP
M,#`G72`]("=':&%Z=FEN)SL*)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F)UU;)S,V+C(V-SHU.2XV,S,G72`]("=-87-H:&%D)SL*
M)&-O;W)D:6YA=&5S6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,V
M+C8X,SHT."XT.#,G72`]("=:86YJ86XG.PHD8V]O<F1I;F%T97-;)TER86XL
M($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S8N.#$W.C4T+C0V-R==(#T@)T=O
M<F=A;B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O
M9B==6R<S-BXY,#`Z-3`N-C8W)UT@/2`G4F%M<V%R)SL*)&-O;W)D:6YA=&5S
M6R=)<F%N+"!)<VQA;6EC(%)E<'5B;&EC(&]F)UU;)S,W+C(P,#HT.2XV,S,G
M72`]("=287-H="<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U
M8FQI8R!O9B==6R<S-RXT-C<Z-3<N,S,S)UT@/2`G0F]J;F]U<F0G.PHD8V]O
M<F1I;F%T97-;)TER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8G75LG,S<N-3,S
M.C0U+C`X,R==(#T@)T]R=6UI96@G.PHD8V]O<F1I;F%T97-;)TER86XL($ES
M;&%M:6,@4F5P=6)L:6,@;V8G75LG,S@N,#@S.C0V+C(X,R==(#T@)U1A8G)I
M>B<["B1C;V]R9&EN871E<ULG27)A;BP@27-L86UI8R!297!U8FQI8R!O9B==
M6R<S."XU-3`Z-#0N.38W)UT@/2`G2VAO>2<["B1C;V]R9&EN871E<ULG27)A
M<2==6R<S,"XT,3<Z-#<N-C4P)UT@/2`G4VAA:6)A:"`O($)A<W)A:"<["B1C
M;V]R9&EN871E<ULG27)A<2==6R<S,RXR,S,Z-#0N,C,S)UT@/2`G0F%G:&1A
M9"<["B1C;V]R9&EN871E<ULG27)A<2==6R<S-BXS,3<Z-#,N,34P)UT@/2`G
M36]S=6PG.PHD8V]O<F1I;F%T97-;)TER96QA;F0G75LG-3$N.#4P.BTX+C0X
M,R==(#T@)T-O<FL@06ER<&]R="<["B1C;V]R9&EN871E<ULG27)E;&%N9"==
M6R<U,BXW,#`Z+3@N.3$W)UT@/2`G4VAA;FYO;B!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=)<F5L86YD)UU;)S4S+C,P,#HM-BXT,S,G72`]("=#87-E;65N
M="!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TER96QA;F0G75LG-3,N-#,S
M.BTV+C(U,"==(#T@)T1U8FQI;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=)
M<W)A96PG75LG,CDN-34P.C,T+CDU,"==(#T@)T5I;&%T)SL*)&-O;W)D:6YA
M=&5S6R=)<W)A96PG75LG,S`N,#`P.C,T+C@S,R==(#T@)T]V9&$G.PHD8V]O
M<F1I;F%T97-;)TES<F%E;"==6R<S,2XR,S,Z,S0N-S@S)UT@/2`G0F5E<BU3
M:&5V82<["B1C;V]R9&EN871E<ULG27-R865L)UU;)S,Q+C@V-SHS-2XR,3<G
M72`]("=*97)U<V%L96T@06ER<&]R="<["B1C;V]R9&EN871E<ULG27-R865L
M)UU;)S,R+C`P,#HS-"XY,#`G72`]("="96XM1W5R:6]N($EN=&5R;F%T:6]N
M86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG27-R865L)UU;)S,R+C@P,#HS
M-2XP,S,G72`]("=39&4M2&%I9F$@2&%I9F$G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S,U+C4P,#HQ,BXV,#`G72`]("=,86UP961U<V$G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S,V+C8X,SHQ-2XQ,S,G72`]("=#;WIZ;R!3<&%D
M87)O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S-BXX,3<Z,3$N.38W)UT@
M/2`G4&%N=&5L;&5R:6$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,W+C`X
M,SHQ-"XR,3<G72`]("='96QA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S
M-RXT,#`Z,30N.3$W)UT@/2`G0V%T86YI82`O(%-I9V]N96QL82<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG,S<N-#8W.C$U+C`U,"==(#T@)T-A=&%N:6$@
M+R!&;VYT86YA<F]S<V$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,W+C4V
M-SHQ-"XR.#,G72`]("=%;FYA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S
M-RXY,3<Z,3(N-3`P)UT@/2`G5')A<&%N:2`O($)I<F=I)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<S."XP-C<Z,34N-C4P)UT@/2`G4F5G9VEO($-A;&%B
M<FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XQ,#`Z,3,N,S`P)UT@
M/2`G4&%L97)M;R!";V-C861I9F%L8V\G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S,X+C$X,SHQ,RXQ,#`G72`]("=086QE<FUO("\@4'5N=&$@4F%I<VDG
M.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,X+C(P,#HQ-2XU-3`G72`]("=-
M97-S:6YA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XW,#`Z,3,N,3@S
M)UT@/2`G57-T:6-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S."XY,#`Z
M,38N,C4P)UT@/2`G3&%M97II82!497)M92<["B1C;V]R9&EN871E<ULG271A
M;'DG75LG,SDN,#`P.C$W+C`V-R==(#T@)T-R;W1O;F4G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S,Y+C$P,#HY+C4Q-R==(#T@)T-A<&\@0V%R8F]N87)A
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XR-3`Z.2XP-C<G72`]("=#
M86=L:6%R:2`O($5L;6%S)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XS
M,S,Z,38N-#`P)UT@/2`G36]N=&4@4V-U<F\G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S,Y+C,U,#HX+CDV-R==(#T@)T1E8VEM;VUA;FYU)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<S.2XU,#`Z.2XV,S,G72`]("=#87!O(%,N($QO
M<F5N>F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S,Y+C4X,SHQ-2XX.#,G
M72`]("=";VYI9F%T:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG,SDN-C8W
M.CDN-#,S)UT@/2`G4&5R9&%S9&5F;V=U)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<S.2XW-3`Z."XT-C<G72`]("=#87!O($9R87-C82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG,SDN.#$W.C$X+C,U,"==(#T@)U,N($UA<FEA($1I
M($QE=6-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<S.2XY,S,Z.2XW,3<G
M72`]("=#87!O($)E;&QA=FES=&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0P+C`Q-SHQ-2XR.#,G72`]("=#87!O(%!A;&EN=7)O)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T,"XP.#,Z,38N,#$W)UT@/2`G3&%T<F]N:6-O)SL*
M)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XQ,3<Z.2XR-3`G72`]("=&;VYN
M:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N,C,S.C$X+C$U,"==(#T@
M)TQE8V-E)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XT,S,Z,38N.#@S
M)UT@/2`G36%R:6YA($1I($=I;F]S82<["B1C;V]R9&EN871E<ULG271A;'DG
M75LG-#`N-3$W.C$W+C0P,"==(#T@)T=R;W1T86=L:64G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0P+C4U,#HQ-"XR,#`G72`]("=#87!R:2<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#`N-38W.C@N,38W)UT@/2`G0V%P;R!#86-C
M:6$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0P+C8S,SHQ-2XX,#`G72`]
M("=0;W1E;GIA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XV,S,Z."XR
M.#,G72`]("=!;&=H97)O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,"XV
M-3`Z,3<N.34P)UT@/2`G0G)I;F1I<VDG.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0P+C<V-SHQ-BXY,S,G72`]("=':6]I82!$96P@0V]L;&4G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0P+C@U,#HQ-"XS,#`G72`]("=.87!O;&D@
M+R!#87!O9&EC:&EN;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#`N.3`P
M.CDN-3$W)UT@/2`G3VQB:6$@+R!#;W-T82!3;65R86QD82<["B1C;V]R9&EN
M871E<ULG271A;'DG75LG-#`N.3$W.C$R+CDU,"==(#T@)U!O;GIA)SL*)&-O
M;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XP-3`Z,30N,#8W)UT@/2`G1W)A>GIA
M;FES92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#$N,#4P.C$U+C(S,R==
M(#T@)U1R979I8V\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C$S,SHQ
M-BXW.#,G72`]("="87)I("\@4&%L97-E($UA8V-H:64G.PHD8V]O<F1I;F%T
M97-;)TET86QY)UU;)S0Q+C(Q-SHY+C0P,"==(#T@)T=U87)D:6%V96-C:&EA
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XU,S,Z,34N-S$W)UT@/2`G
M06UE;F1O;&$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C4U,#HQ,BXY
M,#`G72`]("=,871I;F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+C4V
M-SHQ-"XV-3`G72`]("=#86UP;V)A<W-O)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T,2XV,S,Z,3,N,S`P)UT@/2`G1G)O<VEN;VYE)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T,2XV-3`Z,3(N-#4P)UT@/2`G4')A=&EC82!$:2!-
M87)E)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,2XW,#`Z,34N.34P)UT@
M/2`G36]N=&4@4RX@06YG96QO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M,2XW.#,Z,3(N-3@S)UT@/2`G4F]M82`O($-I86UP:6YO)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T,2XX,#`Z,3(N,C,S)UT@/2`G4F]M82!&:75M:6-I
M;F\G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0Q+CDU,#HQ,BXU,#`G72`]
M("=2;VUA("\@57)B92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N,#`P
M.C$R+C<S,R==(#T@)T=U:61O;FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,BXP,#`Z,34N,#`P)UT@/2`G5&5R;6]L:2<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#(N,#,S.C$Q+C@S,R==(#T@)T-I=FET879E8V-H:6$G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0R+C`X,SHQ,BXR,3<G72`]("=6:6=N
M82!$:2!686QL92<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N,S@S.C$Q
M+C$V-R==(#T@)TUO;G1E($%R9V5N=&%R:6\G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0R+C0Q-SHQ,BXX-3`G72`]("=2:65T:2<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#(N-#,S.C$R+C`U,"==(#T@)U9I=&5R8F\G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0R+C0S,SHQ-"XR,#`G72`]("=097-C87)A
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,BXT-C<Z,3(N.3@S)UT@/2`G
M36]N=&4@5&5R;6EN:6QL;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#(N
M-S,S.C$P+C0P,"==(#T@)TTN($-A;&%M:71A)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,BXW-3`Z,3$N,#8W)UT@/2`G1W)O<W-E=&\G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0R+CDP,#HQ,2XW-C<G72`]("=2861I8V]F86YI
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXP.#,Z,3(N-3`P)UT@/2`G
M4&5R=6=I82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#,N-#`P.C$P+C@V
M-R==(#T@)U9O;'1E<G)A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXT
M-C<Z,3$N.#4P)UT@/2`G07)E>GIO)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==
M6R<T,RXU,3<Z,3(N-S,S)UT@/2`G1G)O;G1O;F4G.PHD8V]O<F1I;F%T97-;
M)TET86QY)UU;)S0S+C8Q-SHQ,RXS-C<G72`]("=&86QC;VYA<F$G.PHD8V]O
M<F1I;F%T97-;)TET86QY)UU;)S0S+C8X,SHQ,"XS.#,G72`]("=0:7-A("\@
M4RX@1VEU<W1O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T,RXX,#`Z,3$N
M,C`P)UT@/2`G1FER96YZ92`O(%!E<F5T;VQA)SL*)&-O;W)D:6YA=&5S6R=)
M=&%L>2==6R<T,RXY-3`Z."XQ-C<G72`]("=#87!O($UE;&4G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0T+C`S,SHQ,BXV,3<G72`]("=2:6UI;FDG.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0T+C`S,SHY+C@S,R==(#T@)TES;VQA
M($1I(%!A;&UA<FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XP-3`Z
M."XQ,3<G72`]("=!;&)E;F=A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M-"XP.#,Z.2XY.#,G72`]("=387)Z86YA("\@3'5N:2<["B1C;V]R9&EN871E
M<ULG271A;'DG75LG-#0N,C`P.C$P+C<P,"==(#T@)TUO;G1E($-I;6]N92<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N,C`P.C$R+C`V-R==(#T@)T9O
M<FQI)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XR,3<Z,3(N,S`P)UT@
M/2`G0V5R=FEA)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XR-3`Z-RXX
M,#`G72`]("=-;VYT92!-86QA;F]T=&4G.PHD8V]O<F1I;F%T97-;)TET86QY
M)UU;)S0T+C0Q-SHX+C@U,"==(#T@)T=E;F]V82`O(%-E<W1R:2<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#0N-#,S.CDN.3,S)UT@/2`G4&%S<V\@1&5L
M;&$@0VES82<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N-#4P.C$R+C,P
M,"==(#T@)U!U;G1A($UA<FEN82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#0N-3,S.C$Q+C,P,"==(#T@)T)O;&]G;F$@+R!";W)G;R!086YI9V%L92<[
M"B1C;V]R9&EN871E<ULG271A;'DG75LG-#0N-C,S.C@N.3,S)UT@/2`G4&%S
M<V\@1&5I($=I;W9I)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-"XX,S,Z
M,3$N-C$W)UT@/2`G1F5R<F%R82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#0N.3$W.CDN-S,S)UT@/2`G4&EA8V5N>F$G.PHD8V]O<F1I;F%T97-;)TET
M86QY)UU;)S0U+C`S,SHW+C<S,R==(#T@)U1O<FEN;R`O($)R:6,@1&5L;&$@
M0W)O8V4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C(Q-SHW+C8U,"==
M(#T@)U1O<FEN;R`O($-A<V5L;&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;
M)S0U+C,X,SHQ,"XX-C<G72`]("=697)O;F$@+R!6:6QL869R86YC82<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#4N-#$W.C$P+C(X,R==(#T@)T)R97-C
M:6$@+R!':&5D:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-#,S.CDN
M,C@S)UT@/2`G36EL86YO("\@3&EN871E)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-2XU,#`Z,3(N,S,S)UT@/2`G5F5N97II82`O(%1E<W-E<F$G.PHD
M8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C4Q-SHX+C8V-R==(#T@)TYO=F%R
M82`O($-A;65R:2<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-38W.C$Q
M+C4Q-R==(#T@)U9I8V5N>F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U
M+C8Q-SHX+C<S,R==(#T@)TUI;&%N;R`O($UA;'!E;G-A)SL*)&-O;W)D:6YA
M=&5S6R=)=&%L>2==6R<T-2XV-3`Z,3(N,3@S)UT@/2`G5')E=FES;R`O(%,N
M($%N9V5L;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#4N-C4P.C$S+C<U
M,"==(#T@)U1R:65S=&4G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C8V
M-SHY+C<P,"==(#T@)T)E<F=A;6\@+R!/<FEO($%L(%-E<FEO)SL*)&-O;W)D
M:6YA=&5S6R=)=&%L>2==6R<T-2XV.#,Z,3(N,3`P)UT@/2`G5')E=FES;R`O
M($ES=')A;F$G.PHD8V]O<F1I;F%T97-;)TET86QY)UU;)S0U+C@Q-SHQ,RXT
M.#,G72`]("=2;VYC:&D@1&5I($QE9VEO;F%R:2<["B1C;V]R9&EN871E<ULG
M271A;'DG75LG-#4N.#8W.CDN,#8W)UT@/2`G36]N=&4@0FES8FEN;R<["B1C
M;V]R9&EN871E<ULG271A;'DG75LG-#4N.3,S.C<N-S`P)UT@/2`G4&EA;B!2
M;W-A)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-2XY.#,Z,3,N,#,S)UT@
M/2`G561I;F4@+R!2:79O;'1O)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T
M-BXP,S,Z,3(N-C`P)UT@/2`G079I86YO)SL*)&-O;W)D:6YA=&5S6R=)=&%L
M>2==6R<T-BXP,S,Z,3(N-C$W)UT@/2`G079I86YO(%5S868G.PHD8V]O<F1I
M;F%T97-;)TET86QY)UU;)S0V+C`S,SHQ,RXQ.#,G72`]("=59&EN92`O($-A
M;7!O9F]R;6ED;R<["B1C;V]R9&EN871E<ULG271A;'DG75LG-#8N,34P.C$Q
M+C`S,R==(#T@)U!A9V%N96QL82<["B1C;V]R9&EN871E<ULG271A;'DG75LG
M-#8N,S`P.C$Q+C<X,R==(#T@)U!A<W-O(%)O;&QE)SL*)&-O;W)D:6YA=&5S
M6R=)=&%L>2==6R<T-BXT-C<Z,3$N,S,S)UT@/2`G0F]L>F%N;R<["B1C;V]R
M9&EN871E<ULG271A;'DG75LG-#8N-3`P.C$S+C4X,R==(#T@)U1A<G9I<VEO
M)SL*)&-O;W)D:6YA=&5S6R=)=&%L>2==6R<T-BXW,S,Z,3(N,C$W)UT@/2`G
M1&]B8FEA8V\G.PHD8V]O<F1I;F%T97-;)TIA;6%I8V$G75LG,3<N.3,S.BTW
M-BXW.#,G72`]("=+:6YG<W1O;B`O($YO<FUA;B!-86YL97DG.PHD8V]O<F1I
M;F%T97-;)TIA;6%I8V$G75LG,3@N-3`P.BTW-RXY,3<G72`]("=-;VYT96=O
M($)A>2`O(%-A;F=S=&5R)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-"XS
M,#`Z,34S+CDV-R==(#T@)TUI;F%M:71O<FES:&EM82<["B1C;V]R9&EN871E
M<ULG2F%P86XG75LG,C0N,S,S.C$R-"XQ-C<G72`]("=)<VAI9V%K:6II;6$G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(T+C0V-SHQ,C(N.3@S)UT@/2`G
M66]N86=U;FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,C0N
M-S@S.C$R-2XR.#,G72`]("=-:7EA:V]J:6UA)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<R-"XW.#,Z,30Q+C,Q-R==(#T@)TEW;VII;6$G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S(U+C@S,SHQ,S$N,C,S)UT@/2`G36EN86UI9&%I
M=&]J:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<R-BXQ.#,Z,3(W+C8U
M,"==(#T@)TYA:&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,C8N,C8W.C$R-RXW-3`G72`]("=&=71E;FUA($UA<FEN92!#;W)P<R!!:7(@
M1F%C:6QI='DG.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C,P,#HQ,C<N
M-S8W)UT@/2`G2&%M8GD@52X@4RX@07)M>2!!:7)F:65L9"<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,C8N,S,S.C$R-BXX,#`G72`]("=+=6UE:FEM82<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,C8N,S4P.C$R-RXW-C<G72`]("=+
M861E;F$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(V+C<Q-SHQ,C<N
M-S@S)UT@/2`G265J:6UA($%U>&EL:6%R>2!!8B<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,C<N,#@S.C$T,BXQ.#,G72`]("=#:&EC:&EJ:6UA)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<R-RXT,S,Z,3(X+C<P,"==(#T@)T]K:6YO
M97)A8G4G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S(W+C@S,SHQ,C@N.#@S
M)UT@/2`G5&]K=6YO<VAI;6$@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=*87!A
M;B==6R<R."XT,S,Z,3(Y+C<Q-R==(#T@)T%M86UI($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,P+C,X,SHQ,S`N-C8W)UT@/2`G66%K=7-H
M:6UA)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,"XU-3`Z,3,P+CDU,"==
M(#T@)U1A;F5G87-H:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,Q+C,V-SHQ,S`N.#,S)UT@/2`G2V%N;WEA($%B)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<S,2XX,#`Z,3,P+C<Q-R==(#T@)TMA9V]S:&EM82!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S,2XX-C<Z,3,Q+C0U
M,"==(#T@)TUI>6%Z86MI($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,R+C`X,SHQ,S$N-#4P)UT@/2`G3GEU=&%B87)U($%B)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<S,BXV-C<Z,3(X+C@S,R==(#T@)T9U:W5E($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,R+C@S,SHQ,S`N.#4P
M)UT@/2`G2W5M86UO=&\@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S(N.3$W.C$R.2XY,3<G72`]("=.86=A<V%K:2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S,RXQ,3<Z,3,Y+C<X,R==(#T@)TAA8VAI
M:F]J:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C$U
M,#HQ,CDN-S$W)UT@/2`G4V%S96)O(%5S;B<["B1C;V]R9&EN871E<ULG2F%P
M86XG75LG,S,N,S$W.C$S,"XT,3<G72`]("=-971A8F%R=2!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S,N-#@S.C$S,2XW,S,G72`]("=/:71A($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C4S,SHQ,S,N-C8W
M)UT@/2`G2V]C:&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S,N-3@S.C$S,"XT-3`G72`]("=&=6MU;VMA($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,S+C8V-SHQ,S4N,S4P)UT@/2`G3F%N:VES:&ER
M86AA;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S,N-C@S
M.C$S,2XP-3`G72`]("=4<W5I:VD@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S,S+C<U,#HQ,CDN-S@S)UT@/2`G26MI($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,S+C@Q-SHQ,S(N-S`P)UT@/2`G36%T<W5Y86UA
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,S+C@S,SHQ,S`N
M.34P)UT@/2`G2VET86MY=7-H=2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<S,RXX.#,Z,3,P+C8U,"==(#T@)T%S:&EY82!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S,N.3,S.C$S,2XR.#,G72`]("=986UA9W5C
M:&D@56)E($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C`P
M,#HQ,S0N-C,S)UT@/2`G2V]M871S=6II;6$@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,T+C`S,SHQ,S$N-34P)UT@/2`G2&]F=2!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S0N,#4P.C$S,2XP-3`G72`]("=/>G5K:2!!
M8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N,#8W.C$S.2XU-C<G72`]
M("=-:7EA:V5J:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,T+C$S,SHQ,S(N,C,S)UT@/2`G27=A:W5N:2!-87)I;F4@0V]R<',@06ER
M(%-T871I;VXG.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C$S,SHQ,S0N
M-C$W)UT@/2`G5&]K=7-H:6UA($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S-"XR,3<Z,3,T+C`Q-R==(#T@)U1A:V%M871S=2!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=*87!A;B==6R<S-"XR.#,Z,3(Y+C,S,R==(#T@)U1S=7-H
M:6UA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,T+C0Q-SHQ
M,S4N,C4P)UT@/2`G2V%N<V%I($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S0N-#,S.C$S,BXY,3<G72`]("=(:7)O
M<VAI;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N-3,S
M.C$S-BXV.#,G72`]("=!:V5N;R!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S0N-C`P.C$S-2XV,#`G72`]("=986\@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S0N-C8W.C$S,2XX,#`G72`]("=)=V%M:2!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XW-3`Z,3,S+C@U,"==
M(#T@)T]K87EA;6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S0N-S4P.C$S-RXW,#`G72`]("=(86UA;6%T<W4@06(G.PHD8V]O<F1I;F%T
M97-;)TIA<&%N)UU;)S,T+C<X,SHQ,S4N-#4P)UT@/2`G3W-A:V$@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-"XW
M.#,Z,3,Y+C,V-R==(#T@)T]S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S-"XX,3<Z,3,X+C,P,"==(#T@)U-H:7IU:&%M82!!8B<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S0N.3@S.C$S.2XX,S,G72`]("=4
M871E>6%M82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N,C4P.C$S
M-BXY,S,G72`]("=.86=O>6$@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P
M86XG75LG,S4N,C@S.C$S.2XV-C<G72`]("=9;VMO<W5K82!&=V8G.PHD8V]O
M<F1I;F%T97-;)TIA<&%N)UU;)S,U+C,Q-SHQ,S@N.#8W)UT@/2`G1G5J:2!!
M8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG,S4N,S@S.C$S-BXX-C<G72`]
M("=':69U($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XT,#`Z,3,Y
M+CDQ-R==(#T@)TMI<V%R87IU($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S-2XT,3<Z,3,R+CDP,"==(#T@)TEZ=6UO($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S,U+C0U,#HQ,SDN-#4P)UT@/2`G071S=6=I(%5N
M:71E9"!3=&%T97,@3F%V86P@06ER(%-T871I;VXG.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S,U+C0X,SHQ,S,N,C4P)UT@/2`G36EH;R!!8B<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S4N-3$W.C$S.2XT,#`G72`]("=:86UA($%I
M<F9I96QD)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XU,S,Z,3,T+C$V
M-R==(#T@)U1O='1O<FD@06ER<&]R="<["B1C;V]R9&EN871E<ULG2F%P86XG
M75LG,S4N-34P.C$S.2XW.#,G72`]("=4;VMY;R!);G1E<FYA=&EO;F%L($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C8S,SHQ,SDN.#4P
M)UT@/2`G5&]K>6\@2&5L:7!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,U+C8V-SHQ,SDN-3,S)UT@/2`G0VAO9G4@06ER<&]R="<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S4N-C@S.C$S.2XW-C<G72`]("=4;VMY;R<["B1C
M;V]R9&EN871E<ULG2F%P86XG75LG,S4N-S`P.C$S.2XT,#`G72`]("=486-H
M:6MA=V$@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,U+C<U,#HQ,SDN
M,S4P)UT@/2`G66]K;W1A($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S
M-2XW-C<Z,30P+C,X,R==(#T@)TYE=R!4;VMY;R!);G1E<BU.871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-2XX,#`Z,30P+C`Q
M-R==(#T@)U-H:6UO9G5S82!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S4N.#,S.C$S.2XT,3<G72`]("=)<G5M82!!8B<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG,S8N,#,S.C$T,"XR,#`G72`]("=+87-U;6EG875R82!!8B<[
M"B1C;V]R9&EN871E<ULG2F%P86XG75LG,S8N,3,S.C$S-BXR,S,G72`]("=&
M=6MU:2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-BXQ-C<Z
M,3,W+CDS,R==(#T@)TUA='-U;6]T;R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=*87!A;B==6R<S-BXQ.#,Z,3,S+C,S,R==(#T@)T]K:2!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-BXQ.#,Z,30P+C0Q-R==(#T@)TAY
M86MU<FD@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,V+C,X,SHQ,S8N
M-#$W)UT@/2`G2V]M871S=2!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M,S8N-3$W.C$S.2XX-C<G72`]("=5='-U;F]M:7EA($%B)SL*)&-O;W)D:6YA
M=&5S6R=*87!A;B==6R<S-BXV-3`Z,3,W+C$X,R==(#T@)U1O>6%M82!!:7)P
M;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S-RXR,S,Z,30P+C0S,R==
M(#T@)T9U:W5S:&EM82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==
M6R<S-RXY-3`Z,3,Y+C$Q-R==(#T@)TYI:6=A=&$@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,S@N,#4P.C$S."XT,3<G72`]("=3861O($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S,X+C$S,SHQ-#`N.3$W
M)UT@/2`G4V5N9&%I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,X+C(S,SHQ-#`N.3$W)UT@/2`G2V%S=6UI;F]M92!!8B<["B1C;V]R9&EN
M871E<ULG2F%P86XG75LG,S@N-#`P.C$T,2XR,3<G72`]("=-871S=7-H:6UA
M($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<S."XT,3<Z,30P+C,V-R==
M(#T@)UEA;6%G871A($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S,Y+C0S,SHQ-#$N,3,S)UT@/2`G2&%N86UA:VD@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG2F%P86XG75LG,SDN-C$W.C$T,"XR,3<G72`]("=!:VET82!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,"XU-3`Z,30Q+C0V
M-R==(#T@)TAA8VAI;F]H92!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG
M-#`N-S`P.C$T,2XS.#,G72`]("=-:7-A=V$@06(G.PHD8V]O<F1I;F%T97-;
M)TIA<&%N)UU;)S0P+C<S,SHQ-#`N-S`P)UT@/2`G06]M;W)I($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0Q+C(S,SHQ-#$N,3,S)UT@/2`G
M3VUI;F%T;R!!8B<["B1C;V]R9&EN871E<ULG2F%P86XG75LG-#$N-S8W.C$T
M,"XX,3<G72`]("=(86MO9&%T92!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*
M87!A;B==6R<T,BXS,3<Z,30P+CDX,R==(#T@)TUU<F]R86XG.PHD8V]O<F1I
M;F%T97-;)TIA<&%N)UU;)S0R+C<S,SHQ-#,N,C$W)UT@/2`G3V)I:&ER;R!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,BXX,#`Z,30Q+C8V
M-R==(#T@)T-H:71O<V4@06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0R
M+C@Q-SHQ-#$N-C@S)UT@/2`G0VAI=&]S92!*87!A;F5S92!!:7(@4V5L9B!$
M969E;G-E($9O<F-E)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,BXY.#,Z
M,30T+C0P,"==(#T@)TMU<VAI<F\G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;
M)S0S+C`S,SHQ-#0N,C`P)UT@/2`G2W5S:&ER;R!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=*87!A;B==6R<T,RXQ,3<Z,30Q+C,X,R==(#T@)U-A<'!O<F\@
M06(G.PHD8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S+C4V-SHQ-#0N.38W)UT@
M/2`G3F%K87-H:6)E='-U($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIA<&%N
M)UU;)S0S+C8V-SHQ-#(N-#4P)UT@/2`G07-A:&EK87=A($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)TIA<&%N)UU;)S0S+C@P,#HQ-#(N,S8W)UT@/2`G07-A
M:&EK87=A($%B)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T,RXX.#,Z,30T
M+C$V-R==(#T@)TUE;6%M8F5T<W4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M2F%P86XG75LG-#0N,C4P.C$T,RXU,S,G72`]("=-;VUB971S=2!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=*87!A;B==6R<T-2XT,#`Z,30Q+C@P,"==(#T@
M)U=A:VMA;F%I($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIO<F1A;B==6R<R
M.2XV,S,Z,S4N,#$W)UT@/2`G07%A8F$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG2F]R9&%N)UU;)S,P+C$V-SHS-2XW.#,G72`]("=-85PG06XG.PHD8V]O
M<F1I;F%T97-;)TIO<F1A;B==6R<S,2XV-C<Z,S4N.38W)UT@/2`G475E96X@
M06QI82!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S$N.3@S
M.C,U+CDX,R==(#T@)T%M;6%N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TIO
M<F1A;B==6R<S,BXR,#`Z,S<N,3,S)UT@/2`G2"TU7"=3869A=VDG.PHD8V]O
M<F1I;F%T97-;)TIO<F1A;B==6R<S,BXS-C<Z,S8N,C4P)UT@/2`G36%F<F%Q
M)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N-3`P.C,X+C(P,"==(#T@
M)T@M-%PG27)W86ES:&5D)SL*)&-O;W)D:6YA=&5S6R=*;W)D86XG75LG,S(N
M-34P.C,U+C@U,"==(#T@)TER8FED)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS
M=&%N)UU;)S0R+C,Q-SHV.2XW,#`G72`]("=3:'EM:V5N="<["B1C;V]R9&EN
M871E<ULG2V%Z86MH<W1A;B==6R<T,RXR,S,Z-S8N.3,S)UT@/2`G06QM871Y
M)SL*)&-O;W)D:6YA=&5S6R=+87IA:VAS=&%N)UU;)S0T+C@U,#HV-2XU,#`G
M72`]("=+>GEL+4]R9&$G.PHD8V]O<F1I;F%T97-;)TMA>F%K:'-T86XG75LG
M-#8N-S@S.C8Q+C8U,"==(#T@)T%R86QS:V]E($UO<F4G.PHD8V]O<F1I;F%T
M97-;)TMA>F%K:'-T86XG75LG-3`N,C@S.C4W+C$U,"==(#T@)T%K=&IU8FEN
M<VLG.PHD8V]O<F1I;F%T97-;)TMA>F%K:'-T86XG75LG-3$N,C4P.C4Q+C(X
M,R==(#T@)U5R86QS:R<["B1C;V]R9&EN871E<ULG2V%Z86MS=&%N)UU;)S0Y
M+C@P,#HW,RXQ-3`G72`]("=+87)A9V%N9&$G.PHD8V]O<F1I;F%T97-;)TME
M;GEA)UU;)S`N,#@S.C,W+C8U,"==(#T@)TUE<G4G.PHD8V]O<F1I;F%T97-;
M)TME;GEA)UU;)RTP+C$P,#HS-"XW-3`G72`]("=+:7-U;74G.PHD8V]O<F1I
M;F%T97-;)TME;GEA)UU;)RTP+C(V-SHS-BXQ,#`G72`]("=.86MU<G4G.PHD
M8V]O<F1I;F%T97-;)TME;GEA)UU;)S`N,C@S.C,T+C<X,R==(#T@)TMA:V%M
M96=A)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,"XS-C<Z,S4N,S4P)UT@
M/2`G2V5R:6-H;R<["B1C;V]R9&EN871E<ULG2V5N>6$G75LG+3`N-#8W.C,Y
M+C8S,R==(#T@)T=A<FES<V$G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTP
M+C4P,#HS-BXY-C<G72`]("=.>65R:2<["B1C;V]R9&EN871E<ULG2V5N>6$G
M75LG+3`N-3`P.C,W+C0U,"==(#T@)T5M8G4G.PHD8V]O<F1I;F%T97-;)TME
M;GEA)UU;)S`N-3,S.C,U+C(X,R==(#T@)T5L9&]R970G.PHD8V]O<F1I;F%T
M97-;)TME;GEA)UU;)RTP+C8V-SHS-"XW.#,G72`]("=+:7-I:2<["B1C;V]R
M9&EN871E<ULG2V5N>6$G75LG,2XP,3<Z,S4N,#`P)UT@/2`G2VET86QE)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,2XQ,S,Z,S4N.#,S)UT@/2`G3F%R
M;VLG.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTQ+C,P,#HS-BXW-3`G72`]
M("=.86ER;V)I("\@1&%G;W)E='1I)SL*)&-O;W)D:6YA=&5S6R=+96YY82==
M6R<M,2XS,3<Z,S8N.#$W)UT@/2`G3F%I<F]B:2`O(%=I;'-O;B<["B1C;V]R
M9&EN871E<ULG2V5N>6$G75LG+3$N,S$W.C,V+CDS,R==(#T@)TYA:7)O8FD@
M04-#+T9)0R]20T,O3454+T-/32\G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;
M)S$N-S4P.C0P+C`V-R==(#T@)U=A:FER)SL*)&-O;W)D:6YA=&5S6R=+96YY
M82==6R<M,BXR-C<Z-#`N.#,S)UT@/2`G3&%M=2<["B1C;V]R9&EN871E<ULG
M2V5N>6$G75LG+3(N,C@S.C,W+C@S,R==(#T@)TUA:VEN9'4G.PHD8V]O<F1I
M;F%T97-;)TME;GEA)UU;)S(N,S`P.C,W+CDP,"==(#T@)TUA<G-A8FET)SL*
M)&-O;W)D:6YA=&5S6R=+96YY82==6R<S+C$Q-SHS-2XV,3<G72`]("=,;V1W
M87(G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)RTS+C(S,SHT,"XQ,#`G72`]
M("=-86QI;F1I)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<M,RXT,#`Z,S@N
M-38W)UT@/2`G5F]I)SL*)&-O;W)D:6YA=&5S6R=+96YY82==6R<S+C4S,SHS
M.2XP-3`G72`]("=-;WEA;&4G.PHD8V]O<F1I;F%T97-;)TME;GEA)UU;)S,N
M.3,S.C0Q+C@V-R==(#T@)TUA;F1E<F$G.PHD8V]O<F1I;F%T97-;)TME;GEA
M)UU;)RTT+C`S,SHS.2XV,3<G72`]("=-;VUB87-A)SL*)&-O;W)D:6YA=&5S
M6R=+:7)I8F%T:2==6R<Q+C,U,#HQ-S(N.3$W)UT@/2`G5&%R87=A)SL*)&-O
M;W)D:6YA=&5S6R=+:7)I8F%T:2==6R<M,2XS-3`Z,3<V+C`P,"==(#T@)T)E
M<G4G.PHD8V]O<F1I;F%T97-;)TMI<FEB871I)UU;)RTR+C8V-SHQ-S8N.#,S
M)UT@/2`G07)O<F%E)SL*)&-O;W)D:6YA=&5S6R=+:7)I8F%T:2==6R<S+C`S
M,SHQ-S(N-S@S)UT@/2`G0G5T87)I=&%R:2<["B1C;V]R9&EN871E<ULG2V]R
M96$L($1E;6]C<F%T:6,@4&5O<&QE7"=S(%)E<'5B;&EC(&]F)UU;)S,Y+C`S
M,SHQ,C4N-S@S)UT@/2`G4'EO;F=Y86YG)SL*)&-O;W)D:6YA=&5S6R=+;W)E
M82P@1&5M;V-R871I8R!096]P;&5<)W,@4F5P=6)L:6,@;V8G75LG-#`N-C8W
M.C$R.2XR,#`G72`]("=+:6UC:&%E:R<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,S+C(P,#HQ,C8N,C8W)UT@/2`G36]S=6QP;R!!
M8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,S+C4P
M,#HQ,C8N-3`P)UT@/2`G0VAE:G4@26YT97)N871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S0N.#,S.C$R
M-RXV,3<G72`]("=9;W-U($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S-2XP.#,Z,3(X+C`X,R==(#T@)U-A8VA<)T]N
M($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N
M,3$W.C$R-BXX,3<G72`]("=+=V%N9VIU($%B)SL*)&-O;W)D:6YA=&5S6R=+
M;W)E82P@4F5P=6)L:6,@;V8G75LG,S4N,3@S.C$R."XY,S,G72`]("=0=7-A
M;B`O($MI;6AA92!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-2XU-3`Z,3(Y+C,Q-R==(#T@
M)U5L<V%N)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG
M,S4N.#@S.C$R."XV,3<G72`]("=4865G=2<["B1C;V]R9&EN871E<ULG2V]R
M96$L(%)E<'5B;&EC(&]F)UU;)S,U+CDP,#HQ,C@N-C4P)UT@/2`G5&%E9W4@
M06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-2XY
M,3<Z,3(V+C8Q-R==(#T@)TMU;G-A;B!!8B<["B1C;V]R9&EN871E<ULG2V]R
M96$L(%)E<'5B;&EC(&]F)UU;)S,U+CDX,SHQ,CDN-#$W)UT@/2`G4&]H86YG
M($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N
M,S`P.C$R-RXT,#`G72`]("=4865J;VXG.PHD8V]O<F1I;F%T97-;)TMO<F5A
M+"!297!U8FQI8R!O9B==6R<S-BXS,S,Z,3(W+C,X,R==(#T@)U1A96IO;B!+
M;W(M069B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG
M,S8N-#`P.C$R-RXU,#`G72`]("=3;VYG;74@06(G.PHD8V]O<F1I;F%T97-;
M)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-BXU-3`Z,3(X+C<Q-R==(#T@)T%N
M9&]N9R<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,V
M+C8S,SHQ,C@N,S4P)UT@/2`G665C:&]N($%B)SL*)&-O;W)D:6YA=&5S6R=+
M;W)E82P@4F5P=6)L:6,@;V8G75LG,S8N-S`P.C$R-RXU,#`G72`]("=#:&]N
M9VIU($%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG
M,S8N.3,S.C$R-BXT-3`G72`]("=-86YG:6QS86X@06(G.PHD8V]O<F1I;F%T
M97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-BXY,S,Z,3(W+C`P,"==(#T@
M)U!Y;VYG=&%E:R!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC
M(&]F)UU;)S,W+C`S,SHQ,C8N-S4P)UT@/2`G2V]O;BU.:2!286YG92<["B1C
M;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C`S,SHQ,C<N
M.#@S)UT@/2`G2G5N9R!7;VX@4F]K+4%B)SL*)&-O;W)D:6YA=&5S6R=+;W)E
M82P@4F5P=6)L:6,@;V8G75LG,S<N,3`P.C$R-RXP,S,G72`]("=/<V%N($%B
M)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N,C4P
M.C$R-RXP,#`G72`]("=3=7=O;B!!8B<["B1C;V]R9&EN871E<ULG2V]R96$L
M(%)E<'5B;&EC(&]F)UU;)S,W+C,S,SHQ,C<N.34P)UT@/2`G5V]N:G4G.PHD
M8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXT,S,Z,3(W
M+C$Q-R==(#T@)U-E;W5L($4@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!2
M97!U8FQI8R!O9B==6R<S-RXT,S,Z,3(W+CDU,"==(#T@)TAO96YG<V]N9R!!
M8B<["B1C;V]R9&EN871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C0V
M-SHQ,C8N-#4P)UT@/2`G26YC:&5O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXU,#`Z
M,3(V+CDS,R==(#T@)U-E;W5L("\@66]N9V1U;F=P7"=/(%)O:V%F(%=C)SL*
M)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G75LG,S<N-3`P.C$R
M.2XQ,S,G72`]("=4;VYG:&%E(%)A9&%R(%-I=&4G.PHD8V]O<F1I;F%T97-;
M)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXU-3`Z,3(V+C@P,"==(#T@)U-E
M;W5L("\@2VEM<%PG3R!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I
M;F%T97-;)TMO<F5A+"!297!U8FQI8R!O9B==6R<S-RXU-C<Z,3(V+CDV-R==
M(#T@)U-E;W5L)SL*)&-O;W)D:6YA=&5S6R=+;W)E82P@4F5P=6)L:6,@;V8G
M75LG,S<N-S4P.C$R."XY-3`G72`]("=+86YG;G5N9R!!8B<["B1C;V]R9&EN
M871E<ULG2V]R96$L(%)E<'5B;&EC(&]F)UU;)S,W+C@V-SHQ,C<N-S$W)UT@
M/2`G0VAU;F-H;VX@06(G.PHD8V]O<F1I;F%T97-;)TMO<F5A+"!297!U8FQI
M8R!O9B==6R<S-RXY-C<Z,3(T+C8V-R==(#T@)U!A96YG;GEO;F=D;R!!8B<[
M"B1C;V]R9&EN871E<ULG2W5W86ET)UU;)S(Y+C(Q-SHT-RXY.#,G72`]("=+
M=7=A:70@26YT97)N871I;VYA;&%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)TQA
M;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q-"XX,#`Z,3`V
M+C@S,R==(#T@)T%T=&]P974G.PHD8V]O<F1I;F%T97-;)TQA;R!096]P;&5<
M)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q-2XQ,3<Z,3`U+C$V-R==(#T@
M)U!A:W-E)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S($1E;6]C<F%T
M:6,@4F5P=6)L:6,G75LG,34N-C@S.C$P-BXT,S,G72`]("=387)A=F%N92<[
M"B1C;V]R9&EN871E<ULG3&%O(%!E;W!L95PG<R!$96UO8W)A=&EC(%)E<'5B
M;&EC)UU;)S$V+C4U,#HQ,#0N-C4P)UT@/2`G4V%V86YN86MH970G.PHD8V]O
M<F1I;F%T97-;)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==
M6R<Q-RXS.#,Z,3`T+C8U,"==(#T@)U1H86MH96LG.PHD8V]O<F1I;F%T97-;
M)TQA;R!096]P;&5<)W,@1&5M;V-R871I8R!297!U8FQI8R==6R<Q-RXY-3`Z
M,3`R+C4V-R==(#T@)U9I96YT:6%N92<["B1C;V]R9&EN871E<ULG3&%O(%!E
M;W!L95PG<R!$96UO8W)A=&EC(%)E<'5B;&EC)UU;)S$Y+C(S,SHQ,#$N-S,S
M)UT@/2`G4V%Y86)O=7)Y)SL*)&-O;W)D:6YA=&5S6R=,86\@4&5O<&QE7"=S
M($1E;6]C<F%T:6,@4F5P=6)L:6,G75LG,3DN.#@S.C$P,BXQ,S,G72`]("=,
M=6%N9RU0<F%B86YG)SL*)&-O;W)D:6YA=&5S6R=,871V:6$G75LG-38N.38W
M.C(T+C`U,"==(#T@)U)I9V$G.PHD8V]O<F1I;F%T97-;)TQA='9I82==6R<U
M-RXT,#`Z,C$N-3,S)UT@/2`G5F5N='-P:6QS)SL*)&-O;W)D:6YA=&5S6R=,
M96)A;F]N)UU;)S,S+C@Q-SHS-2XT.#,G72`]("="97ER;W5T:"!!97)O<&]R
M="<["B1C;V]R9&EN871E<ULG3&5S;W1H;R==6R<M,CDN-#4P.C(W+C4U,"==
M(#T@)TUA<V5R=2U-:6$G.PHD8V]O<F1I;F%T97-;)TQI8F5R:6$G75LG-BXR
M-3`Z+3$P+C,U,"==(#T@)T=R86YD($)A<W-A+"!2;V)E<G1S($9I96QD)SL*
M)&-O;W)D:6YA=&5S6R=,:6)Y86X@07)A8B!*86UA:&ER:7EA)UU;)S(T+C(Q
M-SHR,RXS,#`G72`]("=+=69R82<["B1C;V]R9&EN871E<ULG3&EB>6%N($%R
M86(@2F%M86AI<FEY82==6R<R-2XQ,S,Z,3`N,34P)UT@/2`G1VAA="<["B1C
M;V]R9&EN871E<ULG3&EB>6%N($%R86(@2F%M86AI<FEY82==6R<R-RXP,3<Z
M,30N-#4P)UT@/2`G4V5B:&$G.PHD8V]O<F1I;F%T97-;)TQI8GEA;B!!<F%B
M($IA;6%H:7)I>6$G75LG,S`N,3,S.CDN-3`P)UT@/2`G1VAA9&%M97,G.PHD
M8V]O<F1I;F%T97-;)TQI8GEA;B!!<F%B($IA;6%H:7)I>6$G75LG,S(N,3`P
M.C(P+C(V-R==(#T@)T)E;FEN82<["B1C;V]R9&EN871E<ULG3&EB>6%N($%R
M86(@2F%M86AI<FEY82==6R<S,BXV-C<Z,3,N,34P)UT@/2`G5')I<&]L:2!)
M;G1E<BU.871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=,:71H=6%N
M:6$G75LG-30N-C,S.C(U+C$P,"==(#T@)U9I;&YI=7,G.PHD8V]O<F1I;F%T
M97-;)TQU>&5M8F]U<F<G75LG-#DN-C$W.C8N,C$W)UT@/2`G3'5X96UB;W5R
M9R`O($QU>&5M8F]U<F<G.PHD8V]O<F1I;F%T97-;)TUA8V%U)UU;)S(R+C$V
M-SHQ,3,N-38W)UT@/2`G5&%I<&$G.PHD8V]O<F1I;F%T97-;)TUA8V5D;VYI
M82P@=&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B==6R<T,2XQ,3<Z
M,C`N.#`P)UT@/2`G3VAR:60G.PHD8V]O<F1I;F%T97-;)TUA8V5D;VYI82P@
M=&AE($9O<FUE<B!9=6=O<VQA=B!297!U8FQI8R!O9B==6R<T,2XY-C<Z,C$N
M-C4P)UT@/2`G4VMO<&IE+5!E=')O=F5C)SL*)&-O;W)D:6YA=&5S6R=-861A
M9V%S8V%R)UU;)RTQ,BXS-3`Z-#DN,S`P)UT@/2`G1&EE9V\M4W5A<F5Z)SL*
M)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ,RXS,3<Z-#@N,S$W)UT@
M/2`G1F%S8V5N92!.;W-S:2U"92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A
M<B==6R<M,3,N,S8W.C4P+C`P,"==(#T@)U9O:&5M87(G.PHD8V]O<F1I;F%T
M97-;)TUA9&%G87-C87(G75LG+3$T+C(X,SHU,"XQ-C<G72`]("=386UB879A
M)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-"XV,S,Z-#<N-S8W
M)UT@/2`G06YA;&%L879A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;
M)RTQ-"XV-3`Z-#DN-C$W)UT@/2`G06YD87!A)SL*)&-O;W)D:6YA=&5S6R=-
M861A9V%S8V%R)UU;)RTQ-"XX.#,Z-3`N,C4P)UT@/2`G06YT86QA:&$G.PHD
M8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3$U+C8V-SHT-BXS-3`G72`]
M("=-86IU;F=A)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R)UU;)RTQ-BXW
M-3`Z-#0N-#@S)UT@/2`G0F5S86QA;7!Y)SL*)&-O;W)D:6YA=&5S6R=-861A
M9V%S8V%R)UU;)RTQ-RXP.#,Z-#DN.#$W)UT@/2`G4V%I;G1E+4UA<FEE($%E
M<F]D<F]M92<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,3@N,#4P
M.C0T+C`S,R==(#T@)TUA:6YT:7)A;F\G.PHD8V]O<F1I;F%T97-;)TUA9&%G
M87-C87(G75LG+3$X+C$Q-SHT.2XT,#`G72`]("=486UA=&%V92<["B1C;V]R
M9&EN871E<ULG36%D86=A<V-A<B==6R<M,3@N.#`P.C0W+C0X,R==(#T@)T%N
M=&%N86YA<FEV;R`O($EV871O)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTQ.2XX,3<Z-#<N,#8W)UT@/2`G06YT<VER86)E)SL*)&-O;W)D:6YA
M=&5S6R=-861A9V%S8V%R)UU;)RTQ.2XX,S,Z-#@N.#`P)UT@/2`G36%H86YO
M<F\G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(P+C(X,SHT-"XS
M,3<G72`]("=-;W)O;F1A=F$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G
M75LG+3(Q+C(P,#HT."XS-C<G72`]("=-86YA;FIA<GDG.PHD8V]O<F1I;F%T
M97-;)TUA9&%G87-C87(G75LG+3(Q+C0U,#HT-RXQ,#`G72`]("=&:6%N87)A
M;G1S;V$G.PHD8V]O<F1I;F%T97-;)TUA9&%G87-C87(G75LG+3(Q+C<U,#HT
M,RXS-C<G72`]("=-;W)O;6)E)SL*)&-O;W)D:6YA=&5S6R=-861A9V%S8V%R
M)UU;)RTR,BXU-3`Z-#4N-#`P)UT@/2`G4F%N;VAI<F$G.PHD8V]O<F1I;F%T
M97-;)TUA9&%G87-C87(G75LG+3(R+C@P,#HT-RXX,S,G72`]("=&87)A9F%N
M9V%N82<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==6R<M,C,N,S@S.C0S
M+C<S,R==(#T@)U1U;&5A<B<["B1C;V]R9&EN871E<ULG36%D86=A<V-A<B==
M6R<M,C4N,#,S.C0V+CDU,"==(#T@)T9O<G0M1&%U<&AI;B<["B1C;V]R9&EN
M871E<ULG36%L87=I)UU;)RTQ,2XT-3`Z,S0N,#$W)UT@/2`G37IU>G4G.PHD
M8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,3$N.#@S.C,S+C8Q-R==(#T@)TUZ
M:6UB82<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTQ,BXY,3<Z,S0N,C8W
M)UT@/2`G3FMH;W1A($MO=&$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M
M,3,N-S4P.C,T+C4X,R==(#T@)U-A;&EM82<["B1C;V]R9&EN871E<ULG36%L
M87=I)UU;)RTQ,RXW.#,Z,S,N-S8W)UT@/2`G3&EL;VYG=V4@26YT97)N871I
M;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=-86QA=VDG75LG+3$T+C`X
M,SHS-"XY,3<G72`]("=-;VYK97D@0F%Y)SL*)&-O;W)D:6YA=&5S6R=-86QA
M=VDG75LG+3$T+C,Q-SHS-"XR-C<G72`]("=$961Z82<["B1C;V]R9&EN871E
M<ULG36%L87=I)UU;)RTQ-"XT,S,Z,S4N,C4P)UT@/2`G36%N9V]C:&DG.PHD
M8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M,34N-C@S.C,T+CDV-R==(#T@)T-H
M:6QE:V$G.PHD8V]O<F1I;F%T97-;)TUA;&%W:2==6R<M.2XW,#`Z,S,N,C8W
M)UT@/2`G0VAI=&EP82<["B1C;V]R9&EN871E<ULG36%L87=I)UU;)RTY+CDU
M,#HS,RXX.#,G72`]("=+87)O;F=A)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I
M82==6R<Q+C0X,SHQ,3`N,S,S)UT@/2`G2W5C:&EN9R<["B1C;V]R9&EN871E
M<ULG36%L87ES:6$G75LG,2XV,S,Z,3`S+C8V-R==(#T@)TIO:&]R92!":&%R
M=2`O(%-E;F%I)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<R+C(V-SHQ
M,#(N,C4P)UT@/2`G36%L86-C82<["B1C;V]R9&EN871E<ULG36%L87ES:6$G
M75LG,BXS,S,Z,3$Q+C@S,R==(#T@)U-I8G4G.PHD8V]O<F1I;F%T97-;)TUA
M;&%Y<VEA)UU;)S,N,3$W.C$P,2XU-3`G72`]("=+=6%L82!,=6UP=7(@+R!3
M=6)A;F<G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S,N,C`P.C$Q,RXP
M,S,G72`]("=":6YT=6QU)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<S
M+C8Q-SHQ,#,N,C$W)UT@/2`G2W5A;G1A;B<["B1C;V]R9&EN871E<ULG36%L
M87ES:6$G75LG-"XR,3<Z,3`P+C<P,"==(#T@)U-I=&EA=V%N)SL*)&-O;W)D
M:6YA=&5S6R=-86QA>7-I82==6R<T+C(V-SHQ,3<N.#@S)UT@/2`G5&%W874G
M.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S0N,S,S.C$Q,RXY.#,G72`]
M("=-:7)I)SL*)&-O;W)D:6YA=&5S6R=-86QA>7-I82==6R<U+C,P,#HQ,#`N
M,C8W)UT@/2`G4&5N86YG("\@0F%Y86X@3&5P87,G.PHD8V]O<F1I;F%T97-;
M)TUA;&%Y<VEA)UU;)S4N,S`P.C$Q-2XR-3`G72`]("=,86)U86XG.PHD8V]O
M<F1I;F%T97-;)TUA;&%Y<VEA)UU;)S4N.3`P.C$Q."XP-C<G72`]("=386YD
M86MA;B<["B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-2XY,S,Z,3$V+C`U
M,"==(#T@)TMO=&$@2VEN86)A;'4G.PHD8V]O<F1I;F%T97-;)TUA;&%Y<VEA
M)UU;)S8N,38W.C$P,BXR.#,G72`]("=+;W1A($)H87)U)SL*)&-O;W)D:6YA
M=&5S6R=-86QA>7-I82==6R<V+C,S,SHY.2XW,S,G72`]("=,86YG:V%W:2<[
M"B1C;V]R9&EN871E<ULG36%L87ES:6$G75LG-BXY,3<Z,3$V+C@S,R==(#T@
M)TMU9&%T)SL*)&-O;W)D:6YA=&5S6R=-86QD:79E<R==6R<M,"XV.#,Z-S,N
M,34P)UT@/2`G1V%N)SL*)&-O;W)D:6YA=&5S6R=-86QD:79E<R==6R<T+C(P
M,#HW,RXU,S,G72`]("=-86QE)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$Q
M+C,U,#HM-2XV.#,G72`]("=3:6MA<W-O)SL*)&-O;W)D:6YA=&5S6R=-86QI
M)UU;)S$Q+C0Q-SHM-RXU,#`G72`]("=";W5G;W5N:2<["B1C;V]R9&EN871E
M<ULG36%L:2==6R<Q,BXS.#,Z+34N-#8W)UT@/2`G2V]U=&EA;&$G.PHD8V]O
M<F1I;F%T97-;)TUA;&DG75LG,3(N-3,S.BTW+CDU,"==(#T@)T)A;6%K;R`O
M(%-E;F]U)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$R+C@U,#HM,3$N,C,S
M)UT@/2`G2V5N:65B82<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q,RXP-C<Z
M+3DN-#8W)UT@/2`G2VET82<["B1C;V]R9&EN871E<ULG36%L:2==6R<Q,RXS
M,S,Z+30N.#,S)UT@/2`G4V%N)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$S
M+C0P,#HM-BXQ-3`G72`]("=396=O=2<["B1C;V]R9&EN871E<ULG36%L:2==
M6R<Q-"XT,S,Z+3$Q+C0S,R==(#T@)TMA>65S)SL*)&-O;W)D:6YA=&5S6R=-
M86QI)UU;)S$T+C4Q-SHM-"XQ,#`G72`]("=-;W!T:2<["B1C;V]R9&EN871E
M<ULG36%L:2==6R<Q-2XQ-C<Z+3<N,C@S)UT@/2`G3F%R82<["B1C;V]R9&EN
M871E<ULG36%L:2==6R<Q-2XR,S,Z+3DN,S4P)UT@/2`G3FEO<F\@1'4@4V%H
M96PG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,34N,S,S.BTQ+C8X,R==(#T@
M)TAO;6)O<FDG.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,34N.#8W.C(N,C$W
M)UT@/2`G365N86MA)SL*)&-O;W)D:6YA=&5S6R=-86QI)UU;)S$V+C(V-SHM
M,"XP-3`G72`]("='86\G.PHD8V]O<F1I;F%T97-;)TUA;&DG75LG,38N-S$W
M.BTS+C`P,"==(#T@)U1O;6)O=6-T;W4G.PHD8V]O<F1I;F%T97-;)TUA;&DG
M75LG,3@N-#,S.C$N,S4P)UT@/2`G2VED86PG.PHD8V]O<F1I;F%T97-;)TUA
M;&DG75LG,C`N,C`P.C`N.3@S)UT@/2`G5&5S<V%L:70G.PHD8V]O<F1I;F%T
M97-;)TUA;'1A)UU;)S,U+C@U,#HQ-"XT.#,G72`]("=,=7%A)SL*)&-O;W)D
M:6YA=&5S6R=-87)S:&%L;"!)<VQA;F1S)UU;)S<N,#8W.C$W,2XR.#,G72`]
M("=-86IU<F\@071O;&PL($UA<G-H86QL($ES;&%N9',@26YT+B!!:7)P+B<[
M"B1C;V]R9&EN871E<ULG36%R<VAA;&P@27-L86YD<R==6R<X+C<Q-SHQ-C<N
M-S,S)UT@/2`G2W=A:F%L96EN+"!"=6-H;VQZ($%!1BA+=V%J86QE:6X@2TU2
M*2A!5$],*2!!:7)P+B<["B1C;V]R9&EN871E<ULG36%R=&EN:7%U92==6R<Q
M-"XV,#`Z+38Q+C`P,"==(#T@)TQE($QA;65N=&EN)SL*)&-O;W)D:6YA=&5S
M6R=-875R:71A;FEA)UU;)S$V+C$U,#HM,3,N-3$W)UT@/2`G2V%E9&DG.PHD
M8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G75LG,38N-3`P.BTQ-2XX,3<G72`]
M("=2;W-S;R<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q-BXV,#`Z
M+3<N,C8W)UT@/2`G3F5M82<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==
M6R<Q-BXV,S,Z+3$Q+C0P,"==(#T@)TMI9F9A)SL*)&-O;W)D:6YA=&5S6R=-
M875R:71A;FEA)UU;)S$V+C<P,#HM.2XV,#`G72`]("=!:6]U;B!%;"!!=')O
M=7-S)SL*)&-O;W)D:6YA=&5S6R=-875R:71A;FEA)UU;)S$W+C4S,SHM,30N
M-C@S)UT@/2`G0F]U=&EL:6UI="<["B1C;V]R9&EN871E<ULG36%U<FET86YI
M82==6R<Q."XQ,#`Z+3$U+CDU,"==(#T@)TYO=6%K8VAO='0G.PHD8V]O<F1I
M;F%T97-;)TUA=7)I=&%N:6$G75LG,3@N-38W.BTQ,2XT,S,G72`]("=4:61J
M:6MJ82<["B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<Q.2XW-3`Z+3$T
M+C,V-R==(#T@)T%K:F]U:G0G.PHD8V]O<F1I;F%T97-;)TUA=7)I=&%N:6$G
M75LG,C`N-3$W.BTQ,RXP-C<G72`]("=!=&%R)SL*)&-O;W)D:6YA=&5S6R=-
M875R:71A;FEA)UU;)S(P+CDS,SHM,3<N,#,S)UT@/2`G3F]U861H:6)O=2<[
M"B1C;V]R9&EN871E<ULG36%U<FET86YI82==6R<R-2XR,S,Z+3$Q+C8Q-R==
M(#T@)T)I<B!-;V=H<F5I;B<["B1C;V]R9&EN871E<ULG36%U<FET:75S)UU;
M)RTQ.2XV.#,Z-C,N-#$W)UT@/2`G4F]D<FEG=65S)SL*)&-O;W)D:6YA=&5S
M6R=-875R:71I=7,G75LG+3(P+C0S,SHU-RXV-C<G72`]("=0;&%I<V%N8V4@
M36%U<FET:75S)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,38N-S4P.BTY
M,RXQ,3<G72`]("=4=7AT;&$@1W5T:65R<F5Z+"!#:&ES+B<["B1C;V]R9&EN
M871E<ULG365X:6-O)UU;)S$X+C0X,SHM.#@N,S`P)UT@/2`G0VAE='5M86PL
M(%$N(%)O;R<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S$X+C@X,SHM.3DN
M,C,S)UT@/2`G0W5E<FYA=F%C82P@36]R+B<["B1C;V]R9&EN871E<ULG365X
M:6-O)UU;)S$Y+C`U,#HM.3@N,38W)UT@/2`G4'5E8FQA+"!0=64N)SL*)&-O
M;W)D:6YA=&5S6R=-97AI8V\G75LG,3DN,C8W.BTQ,#,N-3@S)UT@/2`G0V]L
M:6UA)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG,3DN.#4P.BTY,"XU-3`G
M72`]("=#86UP96-H92P@0V%M<"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==
M6R<R,"XP.#,Z+3DX+C,V-R==(#T@)U1U;&%N8VEN9V\G.PHD8V]O<F1I;F%T
M97-;)TUE>&EC;R==6R<R,"XV,#`Z+3$P,"XS.#,G72`]("=1=65R971A<F\L
M(%%R;RXG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,"XY,S,Z+3@Y+C8U
M,"==(#T@)TUE<FED82`O(&QI8R!-86YU96P@0W)E8V5N8VEO)SL*)&-O;W)D
M:6YA=&5S6R=-97AI8V\G75LG,C$N-3$W.BTQ,#0N.3`P)UT@/2`G5&5P:6,L
M($YA>2XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R,2XX.#,Z+3$P,BXS
M,#`G72`]("=!9W5A<V-A;&EE;G1E<RP@06=S+B<["B1C;V]R9&EN871E<ULG
M365X:6-O)UU;)S(R+C$U,#HM,3`P+CDX,R==(#T@)U-A;B!,=6ES(%!O=&]S
M:2P@4RX@3"X@4"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-"XX,3<Z
M+3$P-RXT,#`G72`]("=#=6QI86-A;BP@4VEN+B<["B1C;V]R9&EN871E<ULG
M365X:6-O)UU;)S(U+C0U,#HM,3`P+CDX,R==(#T@)U-A;'1I;&QO+"!#;V%H
M+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(U+C4S,SHM,3`S+C0U,"==
M(#T@)U1O<G)E;VXL($-O86@N)SL*)&-O;W)D:6YA=&5S6R=-97AI8V\G75LG
M,C4N.#8W.BTQ,#`N,C,S)UT@/2`G065R;W`N($EN=&5R;F%C:6]N86P@36]N
M=&5R<F5Y+"!.+B!,+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(V+C`Q
M-SHM,3$Q+C,U,"==(#T@)TQO<F5T;RP@0BX@0RX@4RXG.PHD8V]O<F1I;F%T
M97-;)TUE>&EC;R==6R<R-BXX.#,Z+3$P,2XT,3<G72`]("=-;VYC;&]V82P@
M0V]A:"XG.PHD8V]O<F1I;F%T97-;)TUE>&EC;R==6R<R-RXS,3<Z+3$Q,BXS
M,#`G72`]("=386YT82!2;W-A;&EA+"!"+B!#+B!3+B<["B1C;V]R9&EN871E
M<ULG365X:6-O)UU;)S(X+C<P,#HM,3`P+C4Q-R==(#T@)U!I961R87,@3F5G
M<F%S+"!#;V%H+B<["B1C;V]R9&EN871E<ULG365X:6-O)UU;)S(Y+C`V-SHM
M,3$P+CDU,"==(#T@)TAE<FUO<VEL;&\L(%-O;BXG.PHD8V]O<F1I;F%T97-;
M)TUI8W)O;F5S:6$L($9E9&5R871E9"!3=&%T97,@;V8G75LG-2XS-3`Z,38R
M+CDU,"==(#T@)TMO<W)A92!#87)O;&EN97,@+R!6)SL*)&-O;W)D:6YA=&5S
M6R=-:6-R;VYE<VEA+"!&961E<F%T960@4W1A=&5S(&]F)UU;)S4N,S4P.C$V
M,BXY-3`G72`]("=+;W-R864@27-L86YD+"!+;W-R864@06ER<&]R="<["B1C
M;V]R9&EN871E<ULG36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B==
M6R<V+CDX,SHQ-3@N,C`P)UT@/2`G4&]H;G!E:2!)<VQA;F0L(%!O:&YP96D@
M26YT+B!!:7)P+B<["B1C;V]R9&EN871E<ULG36EC<F]N97-I82P@1F5D97)A
M=&5D(%-T871E<R!O9B==6R<W+C0V-SHQ-3$N.#4P)UT@/2`G5V5N;R!)<VQA
M;F0L($-H=75K($EN="X@06ER<"XG.PHD8V]O<F1I;F%T97-;)TUI8W)O;F5S
M:6$L($9E9&5R871E9"!3=&%T97,@;V8G75LG.2XT.#,Z,3,X+C`X,R==(#T@
M)UEA<"!)<VQA;F0L(%EA<"!);G0N($%I<G`N)SL*)&-O;W)D:6YA=&5S6R=-
M;VQD;W9A+"!297!U8FQI8R!O9B==6R<T-RXP,3<Z,C@N.3@S)UT@/2`G2VES
M:6YE=B<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<R."XT-3`Z+3$Q+C$U
M,"==(#T@)U1A;BU486XG.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,CDN
M,S8W.BTQ,"XQ.#,G72`]("=3:61I($EF;FDG.PHD8V]O<F1I;F%T97-;)TUO
M<F]C8V\G75LG,S`N,S,S.BTY+C0P,"==(#T@)T%G861I<B!!;"!-87-S:7)A
M)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,P+C,X,SHM.2XU-C<G72`]
M("=!9V%D:7(G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S`N.3,S.BTV
M+CDP,"==(#T@)T]U87)Z87IA=&4G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G
M75LG,S$N-3$W.BTY+C<X,R==(#T@)T5S<V%O=6ER82<["B1C;V]R9&EN871E
M<ULG36]R;V-C;R==6R<S,2XV,3<Z+3@N,#,S)UT@/2`G36%R<F%K96-H)SL*
M)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,Q+CDS,SHM-"XT,#`G72`]("=%
M<G)A8VAI9&EA)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,R+C(X,SHM
M.2XR,S,G72`]("=3869I)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,S
M+C,V-SHM-RXU.#,G72`]("=.;W5A<W-E=7(G.PHD8V]O<F1I;F%T97-;)TUO
M<F]C8V\G75LG,S,N-3`P.BTU+C$V-R==(#T@)TEF<F%N92<["B1C;V]R9&EN
M871E<ULG36]R;V-C;R==6R<S,RXU-C<Z+3<N-C8W)UT@/2`G0V%S86)L86YC
M82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S,RXX.#,Z+34N-3,S)UT@
M/2`G365K;F5S)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,S+CDS,SHM
M-"XY.#,G72`]("=&97,M4V%I<R<["B1C;V]R9&EN871E<ULG36]R;V-C;R==
M6R<S-"XP-3`Z+38N-S8W)UT@/2`G4F%B870M4V%L92<["B1C;V]R9&EN871E
M<ULG36]R;V-C;R==6R<S-"XR,3<Z+30N,#`P)UT@/2`G5&%Z82<["B1C;V]R
M9&EN871E<ULG36]R;V-C;R==6R<S-"XS,#`Z+38N-C`P)UT@/2`G2V5N:71R
M82<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-"XW.#,Z+3$N.3,S)UT@
M/2`G3W5J9&$G.PHD8V]O<F1I;F%T97-;)TUO<F]C8V\G75LG,S4N,34P.BTR
M+CDQ-R==(#T@)TYA9&]R)SL*)&-O;W)D:6YA=&5S6R=-;W)O8V-O)UU;)S,U
M+C$X,SHM,RXX-3`G72`]("=!;"!(;V-E:6UA)SL*)&-O;W)D:6YA=&5S6R=-
M;W)O8V-O)UU;)S,U+C4X,SHM-2XS,S,G72`]("=4971U86X@+R!386YI82!2
M86UE;"<["B1C;V]R9&EN871E<ULG36]R;V-C;R==6R<S-2XW,S,Z+34N.3`P
M)UT@/2`G5&%N9V5R($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG36]Z86UB
M:7%U92==6R<M,3$N,S4P.C0P+C,V-R==(#T@)TUO8VEM8F]A($1A(%!R86EA
M)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ,BXY.#,Z-#`N-3,S
M)UT@/2`G4&5M8F$G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$S
M+C,P,#HS-2XR,S,G72`]("=,:6-H:6YG82<["B1C;V]R9&EN871E<ULG36]Z
M86UB:7%U92==6R<M,30N.#$W.C,V+C4S,R==(#T@)T-U86UB82<["B1C;V]R
M9&EN871E<ULG36]Z86UB:7%U92==6R<M,34N,#,S.C0P+C8V-R==(#T@)TQU
M;6)O)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ-2XQ,#`Z,SDN
M,C@S)UT@/2`G3F%M<'5L82<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U92==
M6R<M,38N,3@S.C,S+C4X,R==(#T@)U1E=&4G.PHD8V]O<F1I;F%T97-;)TUO
M>F%M8FEQ=64G75LG+3$W+C@X,SHS-BXX.#,G72`]("=1=65L:6UA;F4G.PHD
M8V]O<F1I;F%T97-;)TUO>F%M8FEQ=64G75LG+3$Y+C$Q-SHS,RXT-C<G72`]
M("=#:&EM;VEO)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTQ.2XX
M,#`Z,S0N.3`P)UT@/2`G0F5I<F$G.PHD8V]O<F1I;F%T97-;)TUO>F%M8FEQ
M=64G75LG+3(R+C`P,#HS-2XS,3<G72`]("=6:6QA;F-U;&]S)SL*)&-O;W)D
M:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTR,RXX-C<Z,S4N,S@S)UT@/2`G26YH
M86UB86YE)SL*)&-O;W)D:6YA=&5S6R=-;WIA;6)I<75E)UU;)RTR-2XP-3`Z
M,S,N-C,S)UT@/2`G6&%I(%AA:2<["B1C;V]R9&EN871E<ULG36]Z86UB:7%U
M92==6R<M,C4N.3$W.C,R+C4V-R==(#T@)TUA<'5T;R`O($UA=F%L86YE)SL*
M)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$R+C0S,SHY."XV,#`G72`]("=-
M97)G=6DG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,30N,3`P.CDX+C(Q
M-R==(#T@)T1A=V5I)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$T+C$Q
M-SHY,RXS-C<G72`]("=#;V-O($ES;&%N9"<["B1C;V]R9&EN871E<ULG37EA
M;FUA<B==6R<Q-BXU,#`Z.3<N-C$W)UT@/2`G36]U;&UE:6XG.PHD8V]O<F1I
M;F%T97-;)TUY86YM87(G75LG,38N-S4P.CDW+C8V-R==(#T@)TAP82U!;B<[
M"B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q-BXW-C<Z.30N-S8W)UT@/2`G
M4&%T:&5I;B<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<Q-BXW-C<Z.38N
M,38W)UT@/2`G66%N9V]N)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S$V
M+CDP,#HY-BXQ.#,G72`]("=-:6YG86QA9&]N)SL*)&-O;W)D:6YA=&5S6R=-
M>6%N;6%R)UU;)S$X+C0V-SHY-"XS-3`G72`]("=386YD;W=A>2<["B1C;V]R
M9&EN871E<ULG37EA;FUA<B==6R<Q."XX,#`Z.34N,C$W)UT@/2`G4')O;64G
M.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,3DN-#$W.CDS+C4U,"==(#T@
M)TMY875K<'EU)SL*)&-O;W)D:6YA=&5S6R=->6%N;6%R)UU;)S(P+C$S,SHY
M,BXX.#,G72`]("=3:71T=V4G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG
M,C`N.#,S.CDU+C@S,R==(#T@)TUE:6MT:6QA)SL*)&-O;W)D:6YA=&5S6R=-
M>6%N;6%R)UU;)S(Q+C,P,#HY.2XV,3<G72`]("=+96YG='5N9R<["B1C;V]R
M9&EN871E<ULG37EA;FUA<B==6R<R,2XY.#,Z.38N,3`P)UT@/2`G36%N9&%L
M87DG.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG,C(N.3,S.CDW+C<U,"==
M(#T@)TQA<VAI;R<["B1C;V]R9&EN871E<ULG37EA;FUA<B==6R<R-"XR-C<Z
M.3<N,C`P)UT@/2`G0FAA;6\G.PHD8V]O<F1I;F%T97-;)TUY86YM87(G75LG
M,C0N.#8W.CDT+CDQ-R==(#T@)TAO;6%L:6XG.PHD8V]O<F1I;F%T97-;)TUY
M86YM87(G75LG,C4N,S8W.CDW+C0P,"==(#T@)TUY:71K>6EN82<["B1C;V]R
M9&EN871E<ULG37EA;FUA<B==6R<R-RXS,S,Z.3<N-#$W)UT@/2`G4'5T86\G
M.PHD8V]O<F1I;F%T97-;)TYA;6EB:6$G75LG+3$W+CDQ-SHQ.2XW-C<G72`]
M("=2=6YD=2<["B1C;V]R9&EN871E<ULG3F%M:6)I82==6R<M,3DN-C`P.C$X
M+C$Q-R==(#T@)T=R;V]T9F]N=&5I;B<["B1C;V]R9&EN871E<ULG3F%M:6)I
M82==6R<M,C(N-#8W.C$X+CDV-R==(#T@)T=O8F%B:7,G.PHD8V]O<F1I;F%T
M97-;)TYA;6EB:6$G75LG+3(R+C0X,SHQ-RXT-C<G72`]("=*+B!'+B!3=')I
M:F1O;2<["B1C;V]R9&EN871E<ULG3F%M:6)I82==6R<M,C8N-3,S.C$X+C$Q
M-R==(#T@)TME971M86YS:&]O<"<["B1C;V]R9&EN871E<ULG3F%U<G4G75LG
M+3`N-3,S.C$V-BXY,3<G72`]("=.875R=2!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=.97!A;"==6R<R-BXT.#,Z.#<N,C8W)UT@/2`G0FER871N86=A<B!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=.97!A;"==6R<R-RXQ-C<Z.#0N.3@S
M)UT@/2`G4VEM<F$@06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG
M,C<N,S4P.C@W+C8V-R==(#T@)U1A<&QE:G5N9R<["B1C;V]R9&EN871E<ULG
M3F5P86PG75LG,C<N-3$W.C@S+C0U,"==(#T@)T)H86ER87=A($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TYE<&%L)UU;)S(W+C<P,#HX-2XS-C<G72`]("=+
M871H;6%N9'4@06ER<&]R="<["B1C;V]R9&EN871E<ULG3F5P86PG75LG,C@N
M,C$W.C@T+C`P,"==(#T@)U!O:VAA<F$@06ER<&]R="<["B1C;V]R9&EN871E
M<ULG3F5P86PG75LG,C@N-C`P.C@Q+C8Q-R==(#T@)U-U<FMH970G.PHD8V]O
M<F1I;F%T97-;)TYE<&%L)UU;)S(Y+C(X,SHX,BXQ-C<G72`]("=*=6UL82<[
M"B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',@06YT:6QL97,G75LG,3(N,34P
M.BTV."XR.#,G72`]("=&;&%M:6YG;R!!:7)P;W)T+"!";VYA:7)E)SL*)&-O
M;W)D:6YA=&5S6R=.971H97)L86YD<R!!;G1I;&QE<R==6R<Q,BXR,#`Z+38X
M+CDV-R==(#T@)TAA=&\@06ER<&]R="P@0W5R86-A;R<["B1C;V]R9&EN871E
M<ULG3F5T:&5R;&%N9',@06YT:6QL97,G75LG,3<N-#@S.BTV,BXY.#,G72`]
M("=2;V]S979E;'0@06ER<&]R="!386EN="!%=7-T871I=7,G.PHD8V]O<F1I
M;F%T97-;)TYE=&AE<FQA;F1S($%N=&EL;&5S)UU;)S$X+C`U,#HM-C,N,3$W
M)UT@/2`G2G5L:6%N82!!:7)P;W)T+"!386EN="!-86%R=&5N)SL*)&-O;W)D
M:6YA=&5S6R=.971H97)L86YD<R==6R<U,"XY,3<Z-2XW.#,G72`]("=-86%S
M=')I8VAT($%I<G!O<G0@6G5I9"!,:6UB=7)G)SL*)&-O;W)D:6YA=&5S6R=.
M971H97)L86YD<R==6R<U,2XT-3`Z-"XS,S,G72`]("=7;V5N<V1R96-H="<[
M"B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3$N-#4P.C4N-#$W)UT@
M/2`G16EN9&AO=F5N)SL*)&-O;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U
M,2XU-C<Z-"XY,S,G72`]("=':6QZ92U2:6IE;B<["B1C;V]R9&EN871E<ULG
M3F5T:&5R;&%N9',G75LG-3$N-C4P.C4N-S`P)UT@/2`G5F]L:V5L)SL*)&-O
M;W)D:6YA=&5S6R=.971H97)L86YD<R==6R<U,2XY-3`Z-"XT-3`G72`]("=2
M;W1T97)D86T@06ER<&]R="!:97-T:65N:&]V96XG.PHD8V]O<F1I;F%T97-;
M)TYE=&AE<FQA;F1S)UU;)S4R+C`V-SHU+C@X,R==(#T@)T1E96QE;B<["B1C
M;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N,3`P.C4N,3@S)UT@/2`G
M1&4@0FEL="<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N,3,S
M.C4N,C@S)UT@/2`G4V]E<W1E<F)E<F<G.PHD8V]O<F1I;F%T97-;)TYE=&AE
M<FQA;F1S)UU;)S4R+C$X,SHT+C0Q-R==(#T@)U9A;&ME;F)U<F<G.PHD8V]O
M<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C(V-SHV+CDP,"==(#T@)U1W
M96YT:&4G.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4R+C,P,#HT
M+C<V-R==(#T@)T%M<W1E<F1A;2!!:7)P;W)T(%-C:&EP:&]L)SL*)&-O;W)D
M:6YA=&5S6R=.971H97)L86YD<R==6R<U,BXT-3`Z-2XU,3<G72`]("=,96QY
M<W1A9"<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G75LG-3(N.3$W.C0N
M-S@S)UT@/2`G1&4@2V]O>2<["B1C;V]R9&EN871E<ULG3F5T:&5R;&%N9',G
M75LG-3,N,3,S.C8N-3@S)UT@/2`G1W)O;FEN9V5N($%I<G!O<G0@165L9&4G
M.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;)S4S+C(Q-SHU+C<V-R==
M(#T@)TQE975W87)D96XG.PHD8V]O<F1I;F%T97-;)TYE=&AE<FQA;F1S)UU;
M)S4S+C(U,#HT+CDQ-R==(#T@)U9L:65L86YD)SL*)&-O;W)D:6YA=&5S6R=.
M97<@0V%L961O;FEA)UU;)RTR,"XU-C<Z,38T+C(X,R==(#T@)TMO=6UA8R!.
M;&QE+4-A;&5D;VYI92<["B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==
M6R<M,C`N-C4P.C$V-BXU.#,G72`]("=/=6QO=7`@26QE($]U=F5A)SL*)&-O
M;W)D:6YA=&5S6R=.97<@0V%L961O;FEA)UU;)RTR,"XW-C<Z,38W+C(S,R==
M(#T@)T]U86YA:&%M($EL92!,:69O=2<["B1C;V]R9&EN871E<ULG3F5W($-A
M;&5D;VYI82==6R<M,C$N-#@S.C$V."XP,S,G72`]("=,82!2;V-H92!);&4@
M36%R92<["B1C;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C(N,#$W
M.C$V-BXR,3<G72`]("=,82!4;VYT;W5T82!.;&QE+4-A;&5D;VYI92<["B1C
M;V]R9&EN871E<ULG3F5W($-A;&5D;VYI82==6R<M,C(N,C8W.C$V-BXT-3`G
M72`]("=.;W5M96$@3FQL92U#86QE9&]N:64G.PHD8V]O<F1I;F%T97-;)TYE
M=R!#86QE9&]N:6$G75LG+3(R+C8P,#HQ-C<N-#4P)UT@/2`G36]U92!);&4@
M1&5S(%!I;G,G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)S$N.3@S
M.BTQ-3<N-#@S)UT@/2`G0VAR:7-T;6%S("\@0V%S<VED>2<["B1C;V]R9&EN
M871E<ULG3F5W(%IE86QA;F0G75LG+3(Y+C(U,#HM,3<W+CDQ-R==(#T@)U)A
M;W5L($ES;&%N9"P@2V5R;6%D96,@27-L86YD)SL*)&-O;W)D:6YA=&5S6R=.
M97<@6F5A;&%N9"==6R<S+C@U,#HM,34Y+C,V-R==(#T@)T9A;FYI;F<@27-L
M86YD)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S8N-S@S.C$W
M-"XV,S,G72`]("=7:&5N=6%P86DG.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L
M86YD)UU;)RTS-RXP,3<Z,3<T+C@P,"==(#T@)T%U8VML86YD($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTS-RXV-C<Z,3<V+C(P
M,"==(#T@)U1A=7)A;F=A($%E<F]D<F]M92!!=W,G.PHD8V]O<F1I;F%T97-;
M)TYE=R!:96%L86YD)UU;)RTS."XQ,3<Z,3<V+C,Q-R==(#T@)U)O=&]R=6$@
M065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M,S@N
M-C8W.C$W-RXY.#,G72`]("=':7-B;W)N92!!97)O9')O;64G.PHD8V]O<F1I
M;F%T97-;)TYE=R!:96%L86YD)UU;)RTS.2XP,3<Z,3<T+C$X,R==(#T@)TYE
M=R!0;'EM;W5T:"!!97)O9')O;64G.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L
M86YD)UU;)RTT,"XR,#`Z,3<U+C,V-R==(#T@)T]H86ME82<["B1C;V]R9&EN
M871E<ULG3F5W(%IE86QA;F0G75LG+30P+CDP,#HQ-S0N.3@S)UT@/2`G4&%R
M87!A<F%U;74@065R;V1R;VUE)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N
M9"==6R<M-#$N,S,S.C$W-"XX,#`G72`]("=796QL:6YG=&]N($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,BXT,3<Z,3<S+C<P
M,"==(#T@)TMA:6MO=7)A)SL*)&-O;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==
M6R<M-#(N-S$W.C$W,"XY.#,G72`]("=(;VMI=&EK82!!97)O9')O;64G.PHD
M8V]O<F1I;F%T97-;)TYE=R!:96%L86YD)UU;)RTT,RXT.#,Z,3<R+C4U,"==
M(#T@)T-H<FES=&-H=7)C:"<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA;F0G
M75LG+30S+CDU,#HM,3<V+C4V-R==(#T@)T-H871H86T@27-L86YD)SL*)&-O
M;W)D:6YA=&5S6R=.97<@6F5A;&%N9"==6R<M-#4N.3,S.C$W,"XR,#`G72`]
M("=$=6YE9&EN($%E<F]D<F]M92<["B1C;V]R9&EN871E<ULG3F5W(%IE86QA
M;F0G75LG+30V+C<P,#HQ-C@N-34P)UT@/2`G26YV97)C87)G:6QL($%E<F]D
M<F]M92<["B1C;V]R9&EN871E<ULG3FEC87)A9W5A)UU;)S$Q+C0Q-SHM.#4N
M.#,S)UT@/2`G4FEV87,G.PHD8V]O<F1I;F%T97-;)TYI8V%R86=U82==6R<Q
M,BXP,#`Z+3@V+C<V-R==(#T@)T)L=65F:65L9',G.PHD8V]O<F1I;F%T97-;
M)TYI8V%R86=U82==6R<Q,BXQ,#`Z+3@U+C,V-R==(#T@)TIU:6=A;'!A)SL*
M)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,3(N,34P.BTX-BXQ-C<G72`]
M("=-86YA9W5A($$N($,N(%-A;F1I;F\G.PHD8V]O<F1I;F%T97-;)TYI8V%R
M86=U82==6R<Q,BXV,S,Z+3@W+C$S,R==(#T@)T-H:6YA;F1E9V$G.PHD8V]O
M<F1I;F%T97-;)TYI8V%R86=U82==6R<Q,RXP.#,Z+3@U+CDX,R==(#T@)TII
M;F]T96=A)SL*)&-O;W)D:6YA=&5S6R=.:6-A<F%G=6$G75LG,30N,#4P.BTX
M,RXS-C<G72`]("=0=65R=&\@0V%B97IA<R<["B1C;V]R9&EN871E<ULG3FEG
M97(G75LG,3$N.#@S.C,N-#4P)UT@/2`G1V%Y82<["B1C;V]R9&EN871E<ULG
M3FEG97(G75LG,3,N,C,S.C$Q+CDX,R==(#T@)TUA:6YE+5-O<F]A)SL*)&-O
M;W)D:6YA=&5S6R=.:6=E<B==6R<Q,RXT,3<Z,3(N-S@S)UT@/2`G1&EF9F$G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$S+C0V-SHW+C`X,R==(#T@)TUA
M<F%D:2<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3,N-#@S.C(N,38W)UT@
M/2`G3FEA;65Y+4%E<F\G.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$S+C<X
M,SHX+CDX,R==(#T@)UII;F1E<B<["B1C;V]R9&EN871E<ULG3FEG97(G75LG
M,3,N.#`P.C4N,C4P)UT@/2`G0FER;FDM3EPG2V]N;FDG.PHD8V]O<F1I;F%T
M97-;)TYI9V5R)UU;)S$S+CDX,SHQ,"XS,#`G72`]("=';W5R92<["B1C;V]R
M9&EN871E<ULG3FEG97(G75LG,30N,C`P.C$N-#4P)UT@/2`G5&EL;&%B97)Y
M)SL*)&-O;W)D:6YA=&5S6R=.:6=E<B==6R<Q-"XY,#`Z-2XR-3`G72`]("=4
M86AO=6$G.PHD8V]O<F1I;F%T97-;)TYI9V5R)UU;)S$V+CDV-SHW+CDX,R==
M(#T@)T%G861E>B<["B1C;V]R9&EN871E<ULG3FEG97(G75LG,3@N-C@S.C$R
M+CDQ-R==(#T@)T)I;&UA)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$P
M+C8P,#HW+C0U,"==(#T@)TMA9'5N82<["B1C;V]R9&EN871E<ULG3FEG97)I
M82==6R<Q,2XQ,S,Z-RXV.#,G72`]("=:87)I82<["B1C;V]R9&EN871E<ULG
M3FEG97)I82==6R<Q,2XX-3`Z,3,N,#@S)UT@/2`G36%I9'5G=7)I)SL*)&-O
M;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S$R+C`U,#HX+C4S,R==(#T@)TMA;F\G
M.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG,3(N,38W.C8N-S`P)UT@/2`G
M1W5S874G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG,3,N,#$W.C4N,C4P
M)UT@/2`G4V]K;W1O)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;)S0N.#4P
M.C<N,#$W)UT@/2`G4&]R="!(87)C;W5R="<["B1C;V]R9&EN871E<ULG3FEG
M97)I82==6R<T+CDV-SHX+C,U,"==(#T@)T-A;&%B87(G.PHD8V]O<F1I;F%T
M97-;)TYI9V5R:6$G75LG-BXT-C<Z-RXU-3`G72`]("=%;G5G=2<["B1C;V]R
M9&EN871E<ULG3FEG97)I82==6R<V+C4X,SHS+C,S,R==(#T@)TQA9V]S("\@
M26ME:F$G.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-RXT,S,Z,RXY,#`G
M72`]("=)8F%D86XG.PHD8V]O<F1I;F%T97-;)TYI9V5R:6$G75LG-RXV.#,Z
M."XV,3<G72`]("=-86MU<F1I)SL*)&-O;W)D:6YA=&5S6R=.:6=E<FEA)UU;
M)S<N-S@S.C0N-#@S)UT@/2`G3W-H;V=B;R<["B1C;V]R9&EN871E<ULG3FEG
M97)I82==6R<X+C0X,SHT+C4X,R==(#T@)TEL;W)I;B<["B1C;V]R9&EN871E
M<ULG3FEG97)I82==6R<Y+C$P,#HV+C`Q-R==(#T@)T)I9&$G.PHD8V]O<F1I
M;F%T97-;)TYI9V5R:6$G75LG.2XR,S,Z,3(N-#8W)UT@/2`G66]L82<["B1C
M;V]R9&EN871E<ULG3FEG97)I82==6R<Y+C@V-SHX+CDP,"==(#T@)TIO<R<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S4X+C$P,#HV+C8S,R==(#T@)TQI
M<W1A($9L>7!L87-S)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-3@N,C`P
M.C@N,#@S)UT@/2`G2W)I<W1I86YS86YD("\@2VIE=FEK)SL*)&-O;W)D:6YA
M=&5S6R=.;W)W87DG75LG-3@N.#@S.C4N-C,S)UT@/2`G4W1A=F%N9V5R("\@
M4V]L82<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S4Y+C$X,SHY+C4V-R==
M(#T@)U-K:65N+4=E:71E<GEG9V5N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG
M75LG-3DN,C`P.C$P+C(V-R==(#T@)U1O<G`G.PHD8V]O<F1I;F%T97-;)TYO
M<G=A>2==6R<U.2XS-3`Z-2XR,3<G72`]("=(875G97-U;F0@+R!+87)M;WDG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U.2XS.#,Z,3`N-S@S)UT@/2`G
M4GEG9V4G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<U.2XY,#`Z,3`N-C,S
M)UT@/2`G3W-L;R`O($9O<FYE8G4G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==
M6R<V,"XR,#`Z,3$N,#@S)UT@/2`G3W-L;R`O($=A<F1E<FUO96XG.PHD8V]O
M<F1I;F%T97-;)TYO<G=A>2==6R<V,"XR.#,Z-2XR,S,G72`]("="97)G96X@
M+R!&;&5S;&%N9"<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8P+C8U,#HV
M+C4P,"==(#T@)U9O<W,M0F\G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V
M,2XP,#`Z.2XS,#`G72`]("=&86=E<FYE<R!,96ER:6XG.PHD8V]O<F1I;F%T
M97-;)TYO<G=A>2==6R<V,2XQ-3`Z-RXQ,S,G72`]("=3;V=N9&%L("\@2&%U
M:V%S96XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,2XU.#,Z-2XP,S,G
M72`]("=&;&]R;R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Q+C@S,SHV
M+C$Q-R==(#T@)U-A;F1A;F4@+R!!;F1A)SL*)&-O;W)D:6YA=&5S6R=.;W)W
M87DG75LG-C(N,3@S.C8N,#8W)UT@/2`G3W)S=&$M5F]L9&$@+R!(;W9D96XG
M.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,BXU-C<Z-BXQ,3<G72`]("=!
M;&5S=6YD("\@5FEG<F$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,BXU
M.#,Z,3$N,S4P)UT@/2`G4F]R;W,@3'5F=&AA=FXG.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V,BXW-3`Z-RXR-C<G72`]("=-;VQD92`O($%R;R<["B1C
M;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8S+C$Q-SHW+C@S,R==(#T@)TMR:7-T
M:6%N<W5N9"`O($MV97)N8F5R9V5T)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG
M75LG-C,N-#8W.C$P+CDS,R==(#T@)U1R;VYD:&5I;2`O(%9A97)N97,G.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V,RXW,#`Z.2XV,#`G72`]("=/<FQA
M;F0@26EI)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C0N-#8W.C$Q+C4X
M,R==(#T@)TYA;7-O<R!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S8T+C@S,SHQ,2XQ-3`G72`]("=2;W)V:6L@+R!2>75M)SL*)&-O;W)D
M:6YA=&5S6R=.;W)W87DG75LG-C4N-#8W.C$R+C(Q-R==(#T@)T)R;VYN;WES
M=6YD("\@0G)O;FYO>2<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8U+C@P
M,#HQ,RXQ,S,G72`]("=-;W-J;V5N($MJ865R<W1A9"<["B1C;V]R9&EN871E
M<ULG3F]R=V%Y)UU;)S8U+CDV-SHQ,BXT-C<G72`]("=386YD;F5S<VIO96X@
M+R!3=&]K:V$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V-BXS-C<Z,30N
M,S`P)UT@/2`G36\@22!286YA("\@4F]S<W9O;&PG.PHD8V]O<F1I;F%T97-;
M)TYO<G=A>2==6R<V-RXR-C<Z,30N,S8W)UT@/2`G0F]D;R!6:2<["B1C;V]R
M9&EN871E<ULG3F]R=V%Y)UU;)S8W+C4Q-SHQ,BXQ,#`G72`]("=2;W-T($9L
M>7!L87-S)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N,34P.C$S+C8Q
M-R==(#T@)TQE:VYE<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8X+C(U
M,#HQ-"XV-C<G72`]("=3=F]L=F%E<B`O($AE;&QE)SL*)&-O;W)D:6YA=&5S
M6R=.;W)W87DG75LG-C@N-#8W.C$W+C4P,"==(#T@)TYA<G9I:R!):6DG.PHD
M8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V."XU,3<Z,38N-C@S)UT@/2`G179E
M;F5S)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-C@N-3@S.C$U+C`Q-R==
M(#T@)U-T;W)K;6%R:VYE<R`O(%-K86=E;B<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S8Y+C`P,#HR,RXP,S,G72`]("=+875T;VME:6YO)SL*)&-O;W)D
M:6YA=&5S6R=.;W)W87DG75LG-CDN,#8W.C$X+C4S,R==(#T@)T)A<F1U9F]S
M<R<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C,P,#HQ-BXQ-3`G72`]
M("=!;F1O>6$G.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XV.#,Z,3@N
M.3$W)UT@/2`G5')O;7-O("\@3&%N9VYE<R<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S8Y+C<S,SHR.2XY,#`G72`]("=+:7)K96YE<R!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S8Y+C<X,SHR,"XY-C<G72`]("=3
M;W)K:F]S96XG.PHD8V]O<F1I;F%T97-;)TYO<G=A>2==6R<V.2XY.#,Z,C,N
M,S8W)UT@/2`G06QT82!,=69T:&%V;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y
M)UU;)S<P+C`V-SHR-"XY.#,G72`]("="86YA:R<["B1C;V]R9&EN871E<ULG
M3F]R=V%Y)UU;)S<P+C`V-SHR.2XX-3`G72`]("=6861S;R<["B1C;V]R9&EN
M871E<ULG3F]R=V%Y)UU;)S<P+C,U,#HS,2XP-3`G72`]("=3=F%R=&YE<R<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<P+C8V-SHR,RXV-C<G72`]("=(
M86UM97)F97-T)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-S`N.#8W.C(Y
M+C`S,R==(#T@)T)E<FQE=F%G)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG
M-S`N.3,S.BTX+C8V-R==(#T@)TIA;B!-87EE;B<["B1C;V]R9&EN871E<ULG
M3F]R=V%Y)UU;)S<Q+C`Q-SHR-2XY.#,G72`]("=(;VYN:6YG<W9A9R`O(%9A
M;&%N)SL*)&-O;W)D:6YA=&5S6R=.;W)W87DG75LG-S$N,#,S.C(W+C@S,R==
M(#T@)TUE:&%M;B<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<T+C4Q-SHQ
M.2XP,3<G72`]("=":F]R;F]Y82<["B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;
M)S<V+C4P,#HR-2XP-C<G72`]("=(;W!E;B<["B1C;V]R9&EN871E<ULG3F]R
M=V%Y)UU;)S<X+C(U,#HQ-2XT-C<G72`]("=3=F%L8F%R9"!,=69T:&%V;B<[
M"B1C;V]R9&EN871E<ULG3F]R=V%Y)UU;)S<X+CDQ-SHQ,2XY,S,G72`]("=.
M>2U!;&5S=6YD($EI)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S$W+C`S,SHU
M-"XP.#,G72`]("=386QA;&%H)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;)S$W
M+C8V-SHU-"XP,S,G72`]("=4:'5M<F%I="<["B1C;V]R9&EN871E<ULG3VUA
M;B==6R<R,"XV-C<Z-3@N.3`P)UT@/2`G36%S:7)A:"<["B1C;V]R9&EN871E
M<ULG3VUA;B==6R<R,BXS-3`Z-38N-#@S)UT@/2`G1F%H=60G.PHD8V]O<F1I
M;F%T97-;)T]M86XG75LG,C(N-3,S.C4Y+C0X,R==(#T@)U-U<B<["B1C;V]R
M9&EN871E<ULG3VUA;B==6R<R,RXP-C<Z-3<N-C4P)UT@/2`G4V%I<2<["B1C
M;V]R9&EN871E<ULG3VUA;B==6R<R,RXU.#,Z-3@N,C@S)UT@/2`G4V5E8BP@
M26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=/;6%N)UU;
M)S(T+C(S,SHU-2XW.#,G72`]("="=7)A:6UI)SL*)&-O;W)D:6YA=&5S6R=/
M;6%N)UU;)S(T+C0V-SHU-BXV,S,G72`]("=3;VAA<B!-86II<R<["B1C;V]R
M9&EN871E<ULG3VUA;B==6R<R-BXR,3<Z-38N,C,S)UT@/2`G2VAA<W-A8B<[
M"B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,C0N.3`P.C8W+C$S,R==(#T@
M)TMA<F%C:&D@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG
M,C4N,#8W.C8Q+C@P,"==(#T@)TII=V%N:2<["B1C;V]R9&EN871E<ULG4&%K
M:7-T86XG75LG,C4N,S@S.C8X+C0Q-R==(#T@)TAY9&5R86)A9"!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<R-BXR-3`Z-C@N,S8W)UT@
M/2`G3F%W86)S:&%H)SL*)&-O;W)D:6YA=&5S6R=086MI<W1A;B==6R<R-BXY
M-C<Z-C0N,3`P)UT@/2`G4&%N:F=U<B<["B1C;V]R9&EN871E<ULG4&%K:7-T
M86XG75LG,C@N,S`P.C8X+C0V-R==(#T@)TIA8V]B86)A9"<["B1C;V]R9&EN
M871E<ULG4&%K:7-T86XG75LG,CDN-34P.C8W+C@X,R==(#T@)U-I8FDG.PHD
M8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,P+C(P,#HW,2XT,S,G72`]("=-
M=6QT86XG.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,P+C(U,#HV-BXX
M.#,G72`]("=1=65T=&$@06ER<&]R="<["B1C;V]R9&EN871E<ULG4&%K:7-T
M86XG75LG,S$N-3$W.C<T+C0P,"==(#T@)TQA:&]R92!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=086MI<W1A;B==6R<S,2XU-3`Z-S0N,S,S)UT@/2`G3&%H
M;W)E($-I='DG.PHD8V]O<F1I;F%T97-;)U!A:VES=&%N)UU;)S,Q+C@Q-SHW
M,"XY,3<G72`]("=$97)A($ES;6%I;"!+:&%N)SL*)&-O;W)D:6YA=&5S6R=0
M86MI<W1A;B==6R<S,BXP-3`Z-S(N-C8W)UT@/2`G4V%R9V]D:&$G.PHD8V]O
M<F1I;F%T97-;)U!A:VES=&%N)UU;)S,R+C4U,#HW,2XU,3<G72`]("=-:6%N
M=V%L:2<["B1C;V]R9&EN871E<ULG4&%K:7-T86XG75LG,S,N-C$W.C<S+C$P
M,"==(#T@)TES;&%M86)A9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=086MI
M<W1A;B==6R<S-"XP,3<Z-S$N-3@S)UT@/2`G4&5S:&%W87(G.PHD8V]O<F1I
M;F%T97-;)U!A:VES=&%N)UU;)S,T+C`V-SHW,2XY.#,G72`]("=2:7-A;'!U
M<B<["B1C;V]R9&EN871E<ULG4&%L874G75LG-RXS-C<Z,3,T+C4S,R==(#T@
M)T)A8F5L=&AU87`@27-L86YD+"!"86)E;'1H=6%P+TMO<F]R($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U!A;F%M82==6R<X+C`X,SHM.#`N.34P)UT@/2`G
M4V%N=&EA9V\G.PHD8V]O<F1I;F%T97-;)U!A;F%M82==6R<X+C0P,#HM.#(N
M-#$W)UT@/2`G1&%V:60G.PHD8V]O<F1I;F%T97-;)U!A;F%M82==6R<X+CDQ
M-SHM-SDN-C`P)UT@/2`G2&]W87)D($%I<B!&;W)C92!"87-E)SL*)&-O;W)D
M:6YA=&5S6R=086YA;6$G75LG.2XP-3`Z+3<Y+C,V-R==(#T@)U1O8W5M96XG
M.PHD8V]O<F1I;F%T97-;)U!A;F%M82==6R<Y+C,S,SHM-SDN.3@S)UT@/2`G
M1G0@4VAE<FUA;B!2;V-O8B<["B1C;V]R9&EN871E<ULG4&%P=6$@3F5W($=U
M:6YE82==6R<M,RXU-C<Z,30S+C8S,R==(#T@)U=E=V%K)SL*)&-O;W)D:6YA
M=&5S6R=087!U82!.97<@1W5I;F5A)UU;)RTU+C(Q-SHQ-#4N-S@S)UT@/2`G
M36%D86YG)SL*)&-O;W)D:6YA=&5S6R=087!U82!.97<@1W5I;F5A)UU;)RTY
M+C0S,SHQ-#<N,C$W)UT@/2`G36]R97-B>2<["B1C;V]R9&EN871E<ULG4&%R
M86=U87DG75LG+3(P+C<Q-SHM-C$N.3$W)UT@/2`G3G5E=F$@07-U;F-I;VXG
M.PHD8V]O<F1I;F%T97-;)U!A<F%G=6%Y)UU;)RTR,BXP,3<Z+38P+C8P,"==
M(#T@)TUA<FES8V%L($5S=&EG87)R:6)I82<["B1C;V]R9&EN871E<ULG4&%R
M86=U87DG75LG+3(S+C0Q-SHM-3<N,S`P)UT@/2`G0V]N8V5P8VEO;B<["B1C
M;V]R9&EN871E<ULG4&%R86=U87DG75LG+3(U+C(V-SHM-3<N-C,S)UT@/2`G
M07-U;F-I;VX@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=087)A9W5A
M>2==6R<M,C<N,S$W.BTU-2XX,S,G72`]("=%;F-A<FYA8VEO;B<["B1C;V]R
M9&EN871E<ULG4&5R=2==6R<M,3`N-S,S.BTW,RXW.#,G72`]("=!=&%L87EA
M)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ,BXP,#`Z+3<W+C$Q-R==(#T@
M)TQI;6$M0V%L;&%O("\@065R;W`N($EN=&5R;F%C:6]N86P@2F]R9V5C:&%V
M97HG.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3$R+C8S,SHM-CDN,C`P)UT@
M/2`G4'5E<G1O($UA;&1O;F%D;R<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M
M,3,N,3,S.BTW-"XR,3<G72`]("=!>6%C=6-H;R<["B1C;V]R9&EN871E<ULG
M4&5R=2==6R<M,3,N-34P.BTW,2XY.#,G72`]("=#=7IC;R<["B1C;V]R9&EN
M871E<ULG4&5R=2==6R<M,3,N-S$W.BTW,RXS-3`G72`]("=!;F1A:'5A>6QA
M)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ,RXW-3`Z+3<V+C(X,R==(#T@
M)U!I<V-O)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ-2XS.#,Z+3<U+C$V
M-R==(#T@)U-A;B!*=6%N)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTQ-2XT
M.#,Z+3<P+C$U,"==(#T@)TIU;&EA8V$G.PHD8V]O<F1I;F%T97-;)U!E<G4G
M75LG+3$V+C,Q-SHM-S$N-34P)UT@/2`G07)E<75I<&$G.PHD8V]O<F1I;F%T
M97-;)U!E<G4G75LG+3$X+C`V-SHM-S`N,S`P)UT@/2`G5&%C;F$G.PHD8V]O
M<F1I;F%T97-;)U!E<G4G75LG+3,N-34P.BTX,"XT,#`G72`]("=4=6UB97,G
M.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3,N-S4P.BTW,RXR-3`G72`]("=)
M<75I=&]S)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTT+C4V-SHM.#$N,C4P
M)UT@/2`G5&%L87)A)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTU+C$X,SHM
M.#`N-C`P)UT@/2`G4&EU<F$G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+34N
M.3`P.BTW-BXP.#,G72`]("=9=7)I;6%G=6%S)SL*)&-O;W)D:6YA=&5S6R=0
M97)U)UU;)RTV+C`U,#HM-S<N,34P)UT@/2`G4FEO:F$G.PHD8V]O<F1I;F%T
M97-;)U!E<G4G75LG+38N,C$W.BTW-RXX,S,G72`]("=#:&%C:&%P;WEA<R<[
M"B1C;V]R9&EN871E<ULG4&5R=2==6R<M-BXT-3`Z+3<V+C,X,R==(#T@)U1A
M<F%P;W1O)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTV+C<X,SHM-SDN.#,S
M)UT@/2`G0VAI8VQA>6\G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG+3<N,3,S
M.BTW."XT-C<G72`]("=#86IA;6%R8V$G.PHD8V]O<F1I;F%T97-;)U!E<G4G
M75LG+3<N,C$W.BTW-BXW,3<G72`]("=*=6%N:G5I)SL*)&-O;W)D:6YA=&5S
M6R=097)U)UU;)RTX+C$P,#HM-SDN,#,S)UT@/2`G5')U:FEL;&\G.PHD8V]O
M<F1I;F%T97-;)U!E<G4G75LG+3@N-#$W.BTW-"XV,#`G72`]("=0=6-A;&QP
M82<["B1C;V]R9&EN871E<ULG4&5R=2==6R<M.2XQ,S,Z+3<U+CDU,"==(#T@
M)U1I;F=O($UA<FEA)SL*)&-O;W)D:6YA=&5S6R=097)U)UU;)RTY+C$V-SHM
M-S@N-3$W)UT@/2`G0VAI;6)O=&4G.PHD8V]O<F1I;F%T97-;)U!E<G4G75LG
M+3DN,S4P.BTW-RXV,#`G72`]("=!;G1A($AU87)A>B<["B1C;V]R9&EN871E
M<ULG4&5R=2==6R<M.2XY,#`Z+3<U+C<U,"==(#T@)TAU86YU8V\G.PHD8V]O
M<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$P+C,P,#HQ,C,N.38W)UT@/2`G
M36%C=&%N)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q,"XW,#`Z
M,3(R+C4V-R==(#T@)TEL;VEL;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG,3$N,#,S.C$R-BXW,S,G72`]("='=6EU86XG.PHD8V]O<F1I;F%T
M97-;)U!H:6QI<'!I;F5S)UU;)S$Q+C(U,#HQ,C4N,#`P)UT@/2`G5&%C;&]B
M86XG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$Q+C4X,SHQ,C(N
M-S4P)UT@/2`G4F]X87,G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;
M)S$R+C,U,#HQ,C$N,#,S)UT@/2`G4V%N($IO<V4G.PHD8V]O<F1I;F%T97-;
M)U!H:6QI<'!I;F5S)UU;)S$R+C,V-SHQ,C,N-C$W)UT@/2`G36%S8F%T92<[
M"B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3(N-#@S.C$R-"XV,S,G
M72`]("=#871A<FUA;B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG
M,3(N-3@S.C$R,BXR-C<G72`]("=2;VUB;&]N)SL*)&-O;W)D:6YA=&5S6R=0
M:&EL:7!P:6YE<R==6R<Q,RXQ,S,Z,3(S+C<S,R==(#T@)TQE9V%S<&DG.PHD
M8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$S+C0Q-SHQ,C$N,3@S)UT@
M/2`G0V%L87!A;B<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3,N
M-3@S.C$R-"XR,S,G72`]("=6:7)A8R<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG,30N,#@S.C$R,BXP,3<G72`]("=!;&%B870G.PHD8V]O<F1I
M;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$T+C$S,SHQ,C(N.3@S)UT@/2`G1&%E
M="<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,30N-3`P.C$R,"XY
M,3<G72`]("=386YG;&5Y(%!O:6YT)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P
M:6YE<R==6R<Q-"XU,3<Z,3(Q+C`P,"==(#T@)TYI;F]Y($%Q=6EN;R!);G1E
M<BU.871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE
M<R==6R<Q-"XX,#`Z,3(P+C(V-R==(#T@)U-U8FEC($)A>2!796%T:&5R(%-T
M871I;VXG.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)S$U+C$V-SHQ
M,C`N-38W)UT@/2`G0VQA<FL@06(G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I
M;F5S)UU;)S$U+C,S,SHQ,3DN.38W)UT@/2`G26)A)SL*)&-O;W)D:6YA=&5S
M6R=0:&EL:7!P:6YE<R==6R<Q-2XW-C<Z,3(Q+C4V-R==(#T@)T)A;&5R)SL*
M)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q-BXT,3<Z,3(P+C8P,"==
M(#T@)T)A9W5I;R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG,3<N
M-38W.C$R,"XS.#,G72`]("=6:6=A;B<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG,3<N-C$W.C$R,2XW,S,G72`]("=4=6=U96=A<F%O)SL*)&-O
M;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q."XQ.#,Z,3(P+C4S,R==(#T@
M)TQA;V%G)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<Q."XS-C<Z
M,3(Q+C8S,R==(#T@)T%P87)R:2<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN
M97,G75LG,C`N-#4P.C$R,2XY-C<G72`]("="87-C;R<["B1C;V]R9&EN871E
M<ULG4&AI;&EP<&EN97,G75LG-BXQ,3<Z,3(U+C$X,R==(#T@)T=E;BX@4V%N
M=&]S)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<V+CDP,#HQ,C(N
M,#8W)UT@/2`G6F%M8F]A;F=A)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE
M<R==6R<W+C$Q-SHQ,C4N-C4P)UT@/2`G1&%V86\@06ER<&]R="<["B1C;V]R
M9&EN871E<ULG4&AI;&EP<&EN97,G75LG-RXQ-C<Z,3(T+C(Q-R==(#T@)T-O
M=&]B871O)SL*)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<X+C$U,#HQ
M,C4N,#@S)UT@/2`G36%L87EB86QA>2<["B1C;V]R9&EN871E<ULG4&AI;&EP
M<&EN97,G75LG."XT.#,Z,3(T+C8S,R==(#T@)T-A9V%Y86X@1&4@3W)O)SL*
M)&-O;W)D:6YA=&5S6R=0:&EL:7!P:6YE<R==6R<X+C8P,#HQ,C,N,S4P)UT@
M/2`G1&EP;VQO9R<["B1C;V]R9&EN871E<ULG4&AI;&EP<&EN97,G75LG.2XS
M,#`Z,3(S+C,P,"==(#T@)T1U;6%G=65T92<["B1C;V]R9&EN871E<ULG4&AI
M;&EP<&EN97,G75LG.2XV,#`Z,3(S+C@U,"==(#T@)U1A9V)I;&%R86XG.PHD
M8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S)UU;)SDN-S4P.C$Q."XW,S,G72`]
M("=0=65R=&\@4')I;F-E<V$G.PHD8V]O<F1I;F%T97-;)U!H:6QI<'!I;F5S
M)UU;)SDN.#`P.C$R-2XU,#`G72`]("=3=7)I9V%O)SL*)&-O;W)D:6YA=&5S
M6R=0:&EL:7!P:6YE<R==6R<Y+CDS,SHQ,C4N-3$W)UT@/2`G0G5T=6%N)SL*
M)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3`N,#@S.C$Y+C@P,"==(#T@)TMR
M86MO=R<["B1C;V]R9&EN871E<ULG4&]L86YD)UU;)S4P+C$P,#HR,BXP-3`G
M72`]("=2>F5S>F]W+4IA<VEO;FMA)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G
M75LG-3`N,C,S.C$Y+C`S,R==(#T@)TMA=&]W:6-E)SL*)&-O;W)D:6YA=&5S
M6R=0;VQA;F0G75LG-3$N,3`P.C$V+C@X,R==(#T@)U=R;V-L87<@26DG.PHD
M8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U,2XY,S,Z,34N-3,S)UT@/2`G6FEE
M;&]N82!';W)A)SL*)&-O;W)D:6YA=&5S6R=0;VQA;F0G75LG-3(N,38W.C(P
M+CDV-R==(#T@)U=A<G-Z87=A+4]K96-I92<["B1C;V]R9&EN871E<ULG4&]L
M86YD)UU;)S4R+C0Q-SHQ-BXX,S,G72`]("=0;WIN86XG.PHD8V]O<F1I;F%T
M97-;)U!O;&%N9"==6R<U,RXT,#`Z,30N-C$W)UT@/2`G4WIC>F5C:6XG.PHD
M8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U-"XR,#`Z,38N,34P)UT@/2`G2V]S
M>F%L:6XG.PHD8V]O<F1I;F%T97-;)U!O;&%N9"==6R<U-"XS.#,Z,3@N-#8W
M)UT@/2`G1V1A;G-K+5)E8FEE8VAO=V\G.PHD8V]O<F1I;F%T97-;)U!O<G1U
M9V%L)UU;)S,R+C8X,SHM,38N-S8W)UT@/2`G1G5N8VAA;"`O(%,N($-A=&%R
M:6YA)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S,RXP-C<Z+3$V+C,U
M,"==(#T@)U!O<G1O(%-A;G1O)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==
M6R<S-BXY-C<Z+3(U+C$V-R==(#T@)U-A;G1A($UA<FEA($%C;W)E<R<["B1C
M;V]R9&EN871E<ULG4&]R='5G86PG75LG,S<N,#$W.BTW+CDV-R==(#T@)T9A
M<F\@+R!!97)O<&]R=&\G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,W
M+C<S,SHM,C4N-S`P)UT@/2`G4&]N=&$@1&5L9V%D82`O($YO<F1E;&$@06-O
M<F5S)SL*)&-O;W)D:6YA=&5S6R=0;W)T=6=A;"==6R<S."XP,3<Z+3<N.#8W
M)UT@/2`G0F5J82<["B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG,S@N-3$W
M.BTR."XW,3<G72`]("=(;W)T82`O($-A<W1E;&\@0G)A;F-O($%C;W)E<R<[
M"B1C;V]R9&EN871E<ULG4&]R='5G86PG75LG,S@N-S8W.BTR-RXQ,#`G72`]
M("=,86IE<R!!8V]R97,G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S,X
M+C<V-SHM.2XQ,S,G72`]("=,:7-B;V$@+R!0;W)T96QA)SL*)&-O;W)D:6YA
M=&5S6R=0;W)T=6=A;"==6R<S.2XT-3`Z+3,Q+C$S,R==(#T@)T9L;W)E<R!!
M8V]R97,G.PHD8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S0Q+C(S,SHM."XV
M.#,G72`]("=0;W)T;R`O(%!E9')A<R!2=6)R87,G.PHD8V]O<F1I;F%T97-;
M)U!O<G1U9V%L)UU;)S0Q+C(V-SHM-RXW,3<G72`]("=6:6QA(%)E86PG.PHD
M8V]O<F1I;F%T97-;)U!O<G1U9V%L)UU;)S0Q+C@P,#HM-BXW,S,G72`]("="
M<F%G86YC82<["B1C;V]R9&EN871E<ULG46%T87(G75LG,C4N,C4P.C4Q+C4V
M-R==(#T@)T1O:&$@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=2975N:6]N)UU;)RTR,"XX.#,Z-34N-3$W)UT@/2`G4V%I;G0M1&5N
M:7,@+R!':6QL;W0G.PHD8V]O<F1I;F%T97-;)U)E=6YI;VXG75LG+3(Q+C,S
M,SHU-2XT.#,G72`]("=386EN="U0:65R<F4G.PHD8V]O<F1I;F%T97-;)U)O
M;6%N:6$G75LG-#0N,C,S.C(S+C@V-R==(#T@)T-R86EO=F$G.PHD8V]O<F1I
M;F%T97-;)U)O;6%N:6$G75LG-#0N,S,S.C(X+C0S,R==(#T@)TMO9V%L;FEC
M96%N=2<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-"XU,#`Z,C8N,3,S
M)UT@/2`G0G5C=7)E<W1I("\@26UH)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA
M)UU;)S0T+C4U,#HR-BXQ,#`G72`]("="=6-U<F5S=&D@3W1O<&5N:2<["B1C
M;V]R9&EN871E<ULG4F]M86YI82==6R<T-2XQ.#,Z,C@N.#$W)UT@/2`G5'5L
M8V5A)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0U+C0Q-SHR,BXR-3`G
M72`]("=#87)A;G-E8F5S)SL*)&-O;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0U
M+C<V-SHR,2XR-3`G72`]("=4:6UI<V]A<F$G.PHD8V]O<F1I;F%T97-;)U)O
M;6%N:6$G75LG-#4N.#`P.C(T+C$U,"==(#T@)U-I8FEU)SL*)&-O;W)D:6YA
M=&5S6R=2;VUA;FEA)UU;)S0V+C(P,#HR,2XT,#`G72`]("=!<F%D)SL*)&-O
M;W)D:6YA=&5S6R=2;VUA;FEA)UU;)S0V+C4S,SHR-"XU,S,G72`]("=4:7)G
M=2!-=7)E<R<["B1C;V]R9&EN871E<ULG4F]M86YI82==6R<T-BXU.#,Z,C8N
M.38W)UT@/2`G0F%C874G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#8N
M-S@S.C(S+C4V-R==(#T@)T-L=6HM3F%P;V-A)SL*)&-O;W)D:6YA=&5S6R=2
M;VUA;FEA)UU;)S0W+C`U,#HR,2XY,S,G72`]("=/<F%D96$G.PHD8V]O<F1I
M;F%T97-;)U)O;6%N:6$G75LG-#<N,38W.C(W+C8S,R==(#T@)TEA<VDG.PHD
M8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#<N-C4P.C(V+C(U,"==(#T@)U-U
M8V5A=F$@+R!386QC96$G.PHD8V]O<F1I;F%T97-;)U)O;6%N:6$G75LG-#<N
M-C8W.C(S+C4X,R==(#T@)T)A:6$@36%R92<["B1C;V]R9&EN871E<ULG4F]M
M86YI82==6R<T-RXX,#`Z,C(N.#@S)UT@/2`G4V%T=2!-87)E)SL*)&-O;W)D
M:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-#,N,3$W.C$S,2XY,S,G
M72`]("=6;&%D:79O<W1O:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E
M<F%T:6]N)UU;)S0S+C0S,SHS.2XY,#`G72`]("=!9&QE<B<["B1C;V]R9&EN
M871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0T+C(S,SHT,RXP-C<G72`]
M("=-:6YE<F%L7"=.>64@5F]D>2<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&
M961E<F%T:6]N)UU;)S0U+C`S,SHS.2XQ-3`G72`]("=+<F%S;F]D87(G.PHD
M8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<T-BXS-C<Z-#0N
M,S,S)UT@/2`G16QI<W1A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R
M871I;VXG75LG-#8N.34P.C$T,BXW,3<G72`]("=9=7IH;F\M4V%K:&%L:6YS
M:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S0W+C(V
M-SHS.2XX,3<G72`]("=2;W-T;W8M3F$M1&]N=2<["B1C;V]R9&EN871E<ULG
M4G5S<VEA;B!&961E<F%T:6]N)UU;)S0X+C4Q-SHQ,S4N,38W)UT@/2`G2&%B
M87)O=G-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG
M-#@N-S@S.C0T+C,V-R==(#T@)U9O;&=O9W)A9"<["B1C;V]R9&EN871E<ULG
M4G5S<VEA;B!&961E<F%T:6]N)UU;)S0Y+C0U,#HQ,S8N-38W)UT@/2`G5')O
M:6-K;V4G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U
M,2XV-3`Z,SDN,C4P)UT@/2`G5F]R;VYE>B<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S4Q+C@S,SHQ,#<N-C`P)UT@/2`G56QA;BU5
M9&4G.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,BXP
M.#,Z,3$S+C0X,R==(#T@)T-H:71A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N
M($9E9&5R871I;VXG75LG-3(N,38W.C$P.2XW.#,G72`]("=(;W)I;G-K)SL*
M)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3(N,C8W.C$P
M-"XS,3<G72`]("=)<FMU='-K)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E
M9&5R871I;VXG75LG-3(N.#$W.C$P-"XW-C<G72`]("=5<W1<)T]R9'EN<VMI
M:B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4S+C`V
M-SHQ,S(N.3@S)UT@/2`G16MI;6-H86XG.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<U,RXP.#,Z,34X+C4X,R==(#T@)U!E=')O<&%V
M;&]V<VLM2V%M8VAA='-K:6HG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D
M97)A=&EO;B==6R<U,RXQ,3<Z-#4N,#$W)UT@/2`G4&5N>F$G.PHD8V]O<F1I
M;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,RXR,#`Z-3`N,34P)UT@
M/2`G4V%M87)A)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG
M75LG-3,N,C4P.C,T+C,Q-R==(#T@)T)R:F%N<VLG.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<U,RXT,S,Z.#,N-3$W)UT@/2`G0F%R
M;F%U;"<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4T
M+C@X,SHY.2XP,S,G72`]("=.:7IH;F5U9&EN<VLG.PHD8V]O<F1I;F%T97-;
M)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-2XP.#,Z.#(N.3`P)UT@/2`G3F]V
M;W-I8FER<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==
M6R<U-BXS-3`Z,S`N-C$W)UT@/2`G5F5L:6MI92!,=6MI)SL*)&-O;W)D:6YA
M=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-38N.#,S.C$R-"XX-C<G72`]
M("=#=6Q<)TUA;B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N
M)UU;)S4V+C@S,SHV,"XV,S,G72`]("=%:V%T97)I;F)U<F<G.PHD8V]O<F1I
M;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U-BXY,#`Z,S4N.#@S)UT@
M/2`G5'9E<B<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;
M)S4W+C<V-SHQ,#@N,#8W)UT@/2`G2VER96YS:R<["B1C;V]R9&EN871E<ULG
M4G5S<VEA;B!&961E<F%T:6]N)UU;)S4W+C@U,#HQ,30N,C,S)UT@/2`G0F]D
M86IB;R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S4X
M+C0U,#HY,BXQ-3`G72`]("=%;FES96IS:R<["B1C;V]R9&EN871E<ULG4G5S
M<VEA;B!&961E<F%T:6]N)UU;)S4Y+C,Q-SHS.2XY,3<G72`]("=6;VQO9V1A
M)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-3DN-34P
M.C$U,"XW.#,G72`]("=-86=A9&%N)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N
M($9E9&5R871I;VXG75LG-3DN.#@S.C0R+C<U,"==(#T@)U1O=%PG36$G.PHD
M8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<U.2XY-C<Z,S`N
M,S`P)UT@/2`G4W0N(%!E=&5R8G5R9R<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S8Q+C`Q-SHV.2XP,S,G72`]("=(86YT>2U-86YS
M:6IS:R<["B1C;V]R9&EN871E<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S8Q
M+C(S,SHT-BXW,3<G72`]("=+;W1L87,G.PHD8V]O<F1I;F%T97-;)U)U<W-I
M86X@1F5D97)A=&EO;B==6R<V,2XR-3`Z-S,N-3`P)UT@/2`G4W5R9W5T)SL*
M)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG-C$N-C@S.C4S
M+C8X,R==(#T@)U5S=%PG+2!+=6QO;2<["B1C;V]R9&EN871E<ULG4G5S<VEA
M;B!&961E<F%T:6]N)UU;)S8Q+C<Q-SHU,"XX,S,G72`]("=3>6MT>79K87(G
M.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@1F5D97)A=&EO;B==6R<V,BXP,3<Z
M,3(Y+C<Q-R==(#T@)TIA:W5T<VLG.PHD8V]O<F1I;F%T97-;)U)U<W-I86X@
M1F5D97)A=&EO;B==6R<V-"XT,3<Z+3$W,RXR,S,G72`]("="=6AT82!0<F]V
M:61E;FIA)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG
M-C0N-3`P.C0P+C<S,R==(#T@)T%R:&%N9V5L7"=3:R<["B1C;V]R9&EN871E
M<ULG4G5S<VEA;B!&961E<F%T:6]N)UU;)S8T+C<X,SHQ-S<N-38W)UT@/2`G
M06YA9'ER)SL*)&-O;W)D:6YA=&5S6R=2=7-S:6%N($9E9&5R871I;VXG75LG
M-C@N.38W.C,S+C`U,"==(#T@)TUU<FUA;G-K)SL*)&-O;W)D:6YA=&5S6R=2
M=V%N9&$G75LG+3$N-C8W.C(Y+C(U,"==(#T@)T=I<V5N>6DG.PHD8V]O<F1I
M;F%T97-;)U)W86YD82==6R<M,2XY-C<Z,S`N,3$W)UT@/2`G2VEG86QI)SL*
M)&-O;W)D:6YA=&5S6R=386EN="!(96QE;F$G75LG+3<N.38W.BTQ-"XT,#`G
M72`]("=7:61E($%W86ME($9I96QD($%S8V5N<VEO;B!)<VQA;F0G.PHD8V]O
M<F1I;F%T97-;)U-A:6YT($MI='1S(&%N9"!.979I<R==6R<Q-RXS,#`Z+38R
M+C8X,R==(#T@)T=O;&1E;B!2;V-K)SL*)&-O;W)D:6YA=&5S6R=386EN="!,
M=6-I82==6R<Q,RXW-3`Z+38P+CDU,"==(#T@)TAE=V%N;W)R82!);G1E<FYA
M=&EO;F%L($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-A:6YT($QU8VEA)UU;
M)S$T+C`Q-SHM-C$N,#`P)UT@/2`G5FEG:64G.PHD8V]O<F1I;F%T97-;)U-A
M:6YT(%!I97)R92!A;F0@36EQ=65L;VXG75LG-#8N-S8W.BTU-BXQ-C<G72`]
M("=386EN="U0:65R<F4G.PHD8V]O<F1I;F%T97-;)U-A:6YT(%9I;F-E;G0@
M86YD('1H92!'<F5N861I;F5S)UU;)S$S+C$S,SHM-C$N,C`P)UT@/2`G07)N
M;W,@5F%L92<["B1C;V]R9&EN871E<ULG4V%M;V$G75LG+3$S+C@P,#HM,3<Q
M+C<X,R==(#T@)T%P:6$@+R!5<&]L=2!)<VQA;F0G.PHD8V]O<F1I;F%T97-;
M)U-A;6]A)UU;)RTQ,RXX,3<Z+3$W,BXP,#`G72`]("=&86QE;VQO($EN=&P@
M+R!!<&EA)SL*)&-O;W)D:6YA=&5S6R=386\@5&]M92!A;F0@4')I;F-I<&4G
M75LG,"XS.#,Z-BXW,3<G72`]("=3+B!4;VUE)SL*)&-O;W)D:6YA=&5S6R=3
M86\@5&]M92!A;F0@4')I;F-I<&4G75LG,2XV-3`Z-RXT,3<G72`]("=0<FEN
M8VEP92<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$V+CDP,#HT
M,BXU.#,G72`]("=':7IA;B<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA
M)UU;)S$W+C0V-SHT-RXQ,3<G72`]("=3:&%R=7)A:"<["B1C;V]R9&EN871E
M<ULG4V%U9&D@07)A8FEA)UU;)S$W+C8Q-SHT-"XT,3<G72`]("=.86IR86XG
M.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<Q."XR,S,Z-#(N-C4P
M)UT@/2`G06)H82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S$X
M+C,P,#HT,BXX,#`G72`]("=+:&%M:7,@375S:&%I="<["B1C;V]R9&EN871E
M<ULG4V%U9&D@07)A8FEA)UU;)S$Y+CDX,SHT,BXV,3<G72`]("=":7-H82<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(P+C,P,#HT,2XV,S,G
M72`]("=!;"!"86AA)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG
M,C`N-3`P.C0U+C(P,"==(#T@)U=A9&D@06P@1&%W87-S97(@06ER<&]R="<[
M"B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(Q+C0S,SHS.2XW-C<G
M72`]("=-86MK86@G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R
M,2XT.#,Z-#`N-34P)UT@/2`G5&%I9B<["B1C;V]R9&EN871E<ULG4V%U9&D@
M07)A8FEA)UU;)S(Q+C4P,#HS.2XR,#`G72`]("=*961D86@G.PHD8V]O<F1I
M;F%T97-;)U-A=61I($%R86)I82==6R<R,2XW,#`Z,SDN,3@S)UT@/2`G2F5D
M9&%H($MI;F<@06)D=6P@07II>B!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-"XQ-3`Z,S@N,#8W)UT@
M/2`G665N8F\G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-"XU
M,#`Z-#0N,S4P)UT@/2`G1&%W861M:2<["B1C;V]R9&EN871E<ULG4V%U9&D@
M07)A8FEA)UU;)S(T+C4U,#HS.2XW,#`G72`]("=-861I;F%H)SL*)&-O;W)D
M:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C0N-S$W.C0V+C<S,R==(#T@)U)I
M>6%D:"<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(T+CDS,SHT
M-BXW,3<G72`]("=+:6YG($MH86QE9"!);G1E<FYA=&EO;F%L($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-2XS,#`Z-#DN-#@S
M)UT@/2`G06P@06AS82<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;
M)S(V+C(P,#HS-BXT-C<G72`]("=796IH)SL*)&-O;W)D:6YA=&5S6R=3875D
M:2!!<F%B:6$G75LG,C8N,C8W.C4P+C$U,"==(#T@)T1H86AR86XG.PHD8V]O
M<F1I;F%T97-;)U-A=61I($%R86)I82==6R<R-BXS,#`Z-#,N-S8W)UT@/2`G
M1V%S<VEM)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C8N-#8W
M.C0Y+C<X,R==(#T@)T1A;6UA;2U+:6YG($9A:&0@26YT97)N871I;VYA;"!!
M:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,C<N-#,S
M.C0Q+C8X,R==(#T@)TAA:6PG.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I
M82==6R<R-RXY,#`Z-#4N-3,S)UT@/2`G2&%F<B!!;"U"871I;B<["B1C;V]R
M9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(X+C,Q-SHT-BXQ,3<G72`]("=!
M;"!187ES=6UA:"<["B1C;V]R9&EN871E<ULG4V%U9&D@07)A8FEA)UU;)S(X
M+C,V-SHS-BXV,#`G72`]("=486)U:R<["B1C;V]R9&EN871E<ULG4V%U9&D@
M07)A8FEA)UU;)S(Y+C8Q-SHT,RXT.#,G72`]("=2869H82<["B1C;V]R9&EN
M871E<ULG4V%U9&D@07)A8FEA)UU;)S(Y+C<X,SHT,"XQ,#`G72`]("=!;"U*
M;W5F)SL*)&-O;W)D:6YA=&5S6R=3875D:2!!<F%B:6$G75LG,S`N.3`P.C0Q
M+C$S,R==(#T@)T%R87(G.PHD8V]O<F1I;F%T97-;)U-A=61I($%R86)I82==
M6R<S,2XT,#`Z,S<N,C8W)UT@/2`G1W5R:6%T)SL*)&-O;W)D:6YA=&5S6R=3
M875D:2!!<F%B:6$G75LG,S$N-C@S.C,X+C<S,R==(#T@)U1U<F%I9B<["B1C
M;V]R9&EN871E<ULG4V5N96=A;"==6R<Q,BXT,#`Z+3$V+C<U,"==(#T@)T-A
M<"U3:VER<FEN9R<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q,BXU-3`Z
M+3$V+C(V-R==(#T@)UII9W5I;F-H;W(G.PHD8V]O<F1I;F%T97-;)U-E;F5G
M86PG75LG,3(N-38W.BTQ,BXR,3<G72`]("=+961O=6=O=2<["B1C;V]R9&EN
M871E<ULG4V5N96=A;"==6R<Q,BXX.#,Z+3$T+CDV-R==(#T@)TMO;&1A)SL*
M)&-O;W)D:6YA=&5S6R=396YE9V%L)UU;)S$S+C<V-SHM,3,N-C@S)UT@/2`G
M5&%M8F%C;W5N9&$G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,30N,3,S
M.BTQ-BXP-C<G72`]("=+86]L86-K)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L
M)UU;)S$T+C8U,#HM,38N,C,S)UT@/2`G1&EO=7)B96PG.PHD8V]O<F1I;F%T
M97-;)U-E;F5G86PG75LG,30N-S,S.BTQ-RXU,#`G72`]("=$86MA<B`O(%EO
M9F8G.PHD8V]O<F1I;F%T97-;)U-E;F5G86PG75LG,34N,S@S.BTQ-2XQ,3<G
M72`]("=,:6YG=65R92<["B1C;V]R9&EN871E<ULG4V5N96=A;"==6R<Q-2XV
M-3`Z+3$S+C(U,"==(#T@)TUA=&%M)SL*)&-O;W)D:6YA=&5S6R=396YE9V%L
M)UU;)S$V+C`U,#HM,38N-#4P)UT@/2`G4V%I;G0M3&]U:7,G.PHD8V]O<F1I
M;F%T97-;)U-E;F5G86PG75LG,38N-C4P.BTQ-"XY-C<G72`]("=0;V1O<B<[
M"B1C;V]R9&EN871E<ULG4V5Y8VAE;&QE<R==6R<M-"XV-C<Z-34N-3$W)UT@
M/2`G4V5Y8VAE;&QE<R!);G1E<BU.871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D
M:6YA=&5S6R=397EC:&5L;&5S)UU;)RTT+C8X,SHU-2XU,S,G72`]("=397EC
M:&5L;&5S($EN=&5R;F%T:6]N86P@06ER<&]R="!287=I;G-O;F1E(%-T871I
M;VXG.PHD8V]O<F1I;F%T97-;)U-I97)R82!,96]N92==6R<X+C8Q-SHM,3,N
M,C`P)UT@/2`G3'5N9VDG.PHD8V]O<F1I;F%T97-;)U-I;F=A<&]R92==6R<Q
M+C,V-SHQ,#,N.3$W)UT@/2`G4VEN9V%P;W)E("\@4&%Y82!,96)A<B<["B1C
M;V]R9&EN871E<ULG4VEN9V%P;W)E)UU;)S$N,S8W.C$P,RXY.#,G72`]("=3
M:6YG87!O<F4@+R!#:&%N9VD@06ER<&]R="<["B1C;V]R9&EN871E<ULG4VQO
M=F%K:6$G75LG-#@N,C`P.C$W+C(P,"==(#T@)T)R871I<VQA=F$@279A;FMA
M)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI82==6R<T."XS,S,Z,3DN-S,S)UT@
M/2`G3'5C96YE8R<["B1C;V]R9&EN871E<ULG4VQO=F%K:6$G75LG-#@N-C$W
M.C$W+C@S,R==(#T@)U!I97-T86YY)SL*)&-O;W)D:6YA=&5S6R=3;&]V86MI
M82==6R<T."XV-3`Z,3DN,34P)UT@/2`G4VQI86,G.PHD8V]O<F1I;F%T97-;
M)U-L;W9A:VEA)UU;)S0X+C8V-SHR,2XR,3<G72`]("=+;W-I8V4G.PHD8V]O
M<F1I;F%T97-;)U-L;W9A:VEA)UU;)S0X+CDS,SHR,BXP,#`G72`]("=+86UE
M;FEC82!.860@0VER;V-H;W4G.PHD8V]O<F1I;F%T97-;)U-L;W9A:VEA)UU;
M)S0Y+C`V-SHR,"XR-3`G72`]("=0;W!R860@+R!4871R>2<["B1C;V]R9&EN
M871E<ULG4VQO=F5N:6$G75LG-#4N-#@S.C$S+C8Q-R==(#T@)U!O<G1O<F]Z
M("\@4V5C;W9L:F4G.PHD8V]O<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0U+C4Q
M-SHQ,RXU-C<G72`]("=0;W)T;W)O>B<["B1C;V]R9&EN871E<ULG4VQO=F5N
M:6$G75LG-#8N,C$W.C$T+C0X,R==(#T@)TQJ=6)L:F%N82`O($)R;FEK)SL*
M)&-O;W)D:6YA=&5S6R=3;&]V96YI82==6R<T-BXR,3<Z,30N-#@S)UT@/2`G
M3&IU8FQJ86YA("\@0G)N:6LG.PHD8V]O<F1I;F%T97-;)U-L;W9E;FEA)UU;
M)S0V+C0X,SHQ-2XV.#,G72`]("=-87)I8F]R("\@4VQI=FYI8V$G.PHD8V]O
M<F1I;F%T97-;)U-L;W9E;FEA)UU;)S0V+C8U,#HQ-BXQ.#,G72`]("=-=7)S
M:V$@4V]B;W1A)SL*)&-O;W)D:6YA=&5S6R=3;VQO;6]N($ES;&%N9',G75LG
M+3$P+C<P,#HQ-C4N.#`P)UT@/2`G4V%N=&$@0W)U>B<["B1C;V]R9&EN871E
M<ULG4V]L;VUO;B!)<VQA;F1S)UU;)RTX+C,S,SHQ-3<N,C8W)UT@/2`G375N
M9&$G.PHD8V]O<F1I;F%T97-;)U-O;&]M;VX@27-L86YD<R==6R<M.2XT,3<Z
M,38P+C`U,"==(#T@)TAO;FEA<F$@+R!(96YD97)S;VXG.PHD8V]O<F1I;F%T
M97-;)U-O;6%L:6$G75LG,3`N-#$W.C0U+C`Q-R==(#T@)T)E<F)E<F$G.PHD
M8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG,BXP,S,Z-#4N,S4P)UT@/2`G36]G
M861I<V-I;R<["B1C;V]R9&EN871E<ULG4V]M86QI82==6R<T+C<P,#HT-2XR
M,3<G72`]("="96QE="!596XG.PHD8V]O<F1I;F%T97-;)U-O;6%L:6$G75LG
M.2XU,#`Z-#0N,#@S)UT@/2`G2&%R9V5I<V$G.PHD8V]O<F1I;F%T97-;)U-O
M;6%L:6$G75LG.2XU,#`Z-#4N-38W)UT@/2`G0G5R86\G.PHD8V]O<F1I;F%T
M97-;)U-O=71H($%F<FEC82==6R<M,C,N-S(V.C(W+C8X."==(#T@)T5L;&ES
M<F%S)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(S+C@V-SHR
M.2XT-3`G72`]("=0:65T97)S8G5R9R<["B1C;V]R9&EN871E<ULG4V]U=&@@
M069R:6-A)UU;)RTR,RXY,S,Z,S$N,34P)UT@/2`G4&AA;&%B;W)W82<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-"XS-C<Z,S$N,#,S)UT@
M/2`G2&]E9'-P<G5I="<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;
M)RTR-2XT,S,Z,S`N.3@S)UT@/2`G3F5L<W!R=6ET)SL*)&-O;W)D:6YA=&5S
M6R=3;W5T:"!!9G)I8V$G75LG+3(U+C<S,SHR."XQ.#,G72`]("=0<F5T;W)I
M82<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-2XW.#,Z,C4N
M-3,S)UT@/2`G36UA8F%T:&\@06ER<&]R="<["B1C;V]R9&EN871E<ULG4V]U
M=&@@069R:6-A)UU;)RTR-2XX,S,Z,C@N,C$W)UT@/2`G5V%T97)K;&]O9B!,
M;6(G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,C4N.3$W.C(X
M+C(Q-R==(#T@)U!R971O<FEA($ER96YE)SL*)&-O;W)D:6YA=&5S6R=3;W5T
M:"!!9G)I8V$G75LG+3(V+C`V-SHS,"XQ,3<G72`]("=#87)O;&EN82<["B1C
M;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR-BXQ,S,Z,C@N,C,S)UT@
M/2`G2F%N(%-M=71S)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG
M+3(V+C@V-SHR-BXW,3<G72`]("=+;&5R:W-D;W)P)SL*)&-O;W)D:6YA=&5S
M6R=3;W5T:"!!9G)I8V$G75LG+3(V+CDU,#HR-"XV,S,G72`]("=6<GEB=7)G
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(W+C(V-SHR."XU
M,#`G72`]("=&<F%N:V9O<G0G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC
M82==6R<M,C@N,#`P.C(V+C8V-R==(#T@)U=E;&MO;2<["B1C;V]R9&EN871E
M<ULG4V]U=&@@069R:6-A)UU;)RTR."XR-3`Z,C@N,S,S)UT@/2`G0F5T:&QE
M:&5M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M
M,C@N-#`P.C(Q+C(V-R==(#T@)U5P:6YG=&]N)SL*)&-O;W)D:6YA=&5S6R=3
M;W5T:"!!9G)I8V$G75LG+3(X+C4V-SHQ-BXU,S,G72`]("=!;&5X86YD97(@
M0F%Y)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(X+C4V-SHR
M.2XW-C<G72`]("=,861Y<VUI=&@G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M,C@N.#`P.C(T+C<V-R==(#T@)TMI;6)E<FQE>2<["B1C;V]R
M9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTR."XX,#`Z,S(N,3`P)UT@/2`G
M4FEC:&%R9"!"87DG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M
M,CDN,3`P.C(V+C,P,"==(#T@)T)L;V5M9F]N=&5I;B!*+B!"+B!-+B!(97)T
M>F]G)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3(Y+C8V-SHQ
M-RXX-C<G72`]("=3<')I;F=B;VLG.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M,CDN.38W.C,P+CDU,"==(#T@)T1U<F)A;B!,;W5I<R!";W1H
M82<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,"XV,S,Z,C,N
M.3$W)UT@/2`G1&4@06%R)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G
M75LG+3,P+C8U,#HR-"XP,3<G72`]("=$92!!87(G.PHD8V]O<F1I;F%T97-;
M)U-O=71H($%F<FEC82==6R<M,S`N-S$W.C(V+C<Q-R==(#T@)T%L:7=A;"!.
M;W)T:"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XT-C<Z
M,3DN-S8W)UT@/2`G0V%L=FEN:6$G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F
M<FEC82==6R<M,S$N-#@S.C(U+C`S,R==(#T@)TUI9&1E;&)U<F<G.PHD8V]O
M<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S$N-3,S.C(X+C8V-R==(#T@
M)U5M=&%T82<["B1C;V]R9&EN871E<ULG4V]U=&@@069R:6-A)UU;)RTS,2XV
M,S,Z,CDN-34P)UT@/2`G4&]R="!3="!*;VAN<R<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTS,2XV-C<Z,3@N-3`P)UT@/2`G5G)E9&5N9&%L
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,Q+CDP,#HR-BXX
M-C<G72`]("=1=65E;G-T;W=N)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I
M8V$G75LG+3,Q+CDQ-SHR,2XU,3<G72`]("=&<F%S97)B=7)G)SL*)&-O;W)D
M:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,R+C(U,#HR-"XU,S,G72`]("='
M<F%A9F8@4F5I;F5T)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG
M+3,R+C,U,#HR,BXU.#,G72`]("="96%U9F]R="!797-T)SL*)&-O;W)D:6YA
M=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,R+CDV-SHQ."XQ-C<G72`]("=,86YG
M96)A86YW96<G.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M,S,N
M,#,S.C(W+C@S,R==(#T@)T5A<W0@3&]N9&]N)SL*)&-O;W)D:6YA=&5S6R=3
M;W5T:"!!9G)I8V$G75LG+3,S+C4V-SHR,BXR,3<G72`]("=/=61T<VAO;W)N
M)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,S+CDX,SHQ."XV
M,#`G72`]("=#87!E(%1O=VX@1"X@1BX@36%L86XG.PHD8V]O<F1I;F%T97-;
M)U-O=71H($%F<FEC82==6R<M,S,N.3@S.C(U+C8P,"==(#T@)U!O<G0@16QI
M>F%B971H)SL*)&-O;W)D:6YA=&5S6R=3;W5T:"!!9G)I8V$G75LG+3,T+C`P
M,#HR,BXS.#,G72`]("='96]R9V4@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M4V]U=&@@069R:6-A)UU;)RTS-"XQ.#,Z,C(N,34P)UT@/2`G36]S<V5L($)A
M>2!#87!E(%-A:6YT($)L86EZ92<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTS-RXP-3`Z+3$R+C,Q-R==(#T@)U1R:7-T86X@1&$@0W5N:&$G
M.PHD8V]O<F1I;F%T97-;)U-O=71H($%F<FEC82==6R<M-#`N,S4P.BTY+C@X
M,R==(#T@)T=O=6=H($ES;&%N9"<["B1C;V]R9&EN871E<ULG4V]U=&@@069R
M:6-A)UU;)RTT-BXX.#,Z,S<N.#8W)UT@/2`G36%R:6]N($ES;&%N9"<["B1C
M;V]R9&EN871E<ULG4V]U=&@@1V5O<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W
M:6-H($ES;&%N9',G75LG+34Q+C@Q-SHM-3@N-#4P)UT@/2`G36]U;G0@4&QE
M87-A;G0@06ER<&]R="<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,C<N.#$W
M.BTQ-RXX.#,G72`]("=(:65R<F\@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<R-RXY,S,Z+3$U+C,X,R==(#T@)TQA<R!086QM87,@
M1&4@1W)A;B!#86YA<FEA("\@1V%N9&\G.PHD8V]O<F1I;F%T97-;)U-P86EN
M)UU;)S(X+C`U,#HM,38N-38W)UT@/2`G5&5N97)I9F4@4W5R)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<R."XT-3`Z+3$S+C@V-R==(#T@)T9U97)T979E
M;G1U<F$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<R
M."XT-C<Z+3$V+C,Q-R==(#T@)U1E;F5R:69E("\@3&]S(%)O9&5O<R<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG,C@N-C$W.BTQ-RXW-3`G72`]("=,82!0
M86QM82`O($%E<F]P=65R=&\G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S(X
M+CDU,#HM,3,N-C`P)UT@/2`G3&%N>F%R;W1E("\@065R;W!U97)T;R<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG,S4N,C@S.BTR+CDU,"==(#T@)TUE;&EL
M;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,V+C8U,#HM-BXS-3`G72`]
M("=2;W1A)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S-BXV-C<Z+30N-#@S
M)UT@/2`G36%L86=A("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG,S8N-S4P.BTV+C`V-R==(#T@)TIE<F5Z($1E($QA($9R;VYT97)A
M865R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG,S8N.#4P.BTR
M+C,X,R==(#T@)T%L;65R:6$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S
M6R=3<&%I;B==6R<S-RXQ-3`Z+34N-C$W)UT@/2`G36]R;VX@1&4@3&$@1G)O
M;G1E<F$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,W+C$X,SHM,RXW.#,G
M72`]("='<F%N861A("\@065R;W!U97)T;R<["B1C;V]R9&EN871E<ULG4W!A
M:6XG75LG,S<N-#$W.BTU+CDP,"==(#T@)U-E=FEL;&$@+R!386X@4&%B;&\G
M.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,W+C<X,SHM,"XX,#`G72`]("=-
M=7)C:6$@+R!386X@2F%V:65R)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S
M-RXX-3`Z+30N.#4P)UT@/2`G0V]R9&]B82`O($%E<F]P=65R=&\G.PHD8V]O
M<F1I;F%T97-;)U-P86EN)UU;)S,W+CDU,#HM,2XR,S,G72`]("=-=7)C:6$@
M+R!!;&-A;G1A<FEL;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S,X+C(X
M,SHM,"XU-3`G72`]("=!;&EC86YT92`O($5L($%L=&5T)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<S."XU,3<Z+34N,3$W)UT@/2`G2&EN;VIO<V$@1&5L
M($1U<75E)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S."XX-C<Z,2XS.#,G
M72`]("=)8FEZ82`O($5S($-O9&]L82<["B1C;V]R9&EN871E<ULG4W!A:6XG
M75LG,S@N.#@S.BTV+C@Q-R==(#T@)T)A9&%J;WH@+R!486QA=F5R82!,82!2
M96%L)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S."XY-3`Z+3$N.#4P)UT@
M/2`G06QB86-E=&4@+R!,;W,@3&QA;F]S)SL*)&-O;W)D:6YA=&5S6R=3<&%I
M;B==6R<S.2XU,#`Z+3`N-#8W)UT@/2`G5F%L96YC:6$@+R!!97)O<'5E<G1O
M)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<S.2XU-3`Z,BXW,S,G72`]("=0
M86QM82!$92!-86QL;W)C82`O(%-O;B!386X@2G5A;B<["B1C;V]R9&EN871E
M<ULG4W!A:6XG75LG,SDN.#8W.C0N,C,S)UT@/2`G365N;W)C82`O($UA:&]N
M)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XS,#`Z+3,N-S$W)UT@/2`G
M36%D<FED("\@1V5T869E)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XS
M.#,Z+3,N-S@S)UT@/2`G36%D<FED("\@0W5A=')O(%9I96YT;W,G.PHD8V]O
M<F1I;F%T97-;)U-P86EN)UU;)S0P+C0U,#HM,RXU-3`G72`]("=-861R:60@
M+R!"87)A:F%S)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,"XT.#,Z+3,N
M-#4P)UT@/2`G36%D<FED("\@5&]R<F5J;VXG.PHD8V]O<F1I;F%T97-;)U-P
M86EN)UU;)S0P+C8U,#HM,RXW,S,G72`]("=-861R:2U#;VQM96YA<B<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG-#`N.3,S.BTQ+C,P,"==(#T@)T-A;&%M
M;V-H82<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#`N.34P.BTU+C4P,"==
M(#T@)U-A;&%M86YC82`O($UA=&%C86XG.PHD8V]O<F1I;F%T97-;)U-P86EN
M)UU;)S0Q+C$U,#HQ+C$V-R==(#T@)U)E=7,@+R!!97)O<'5E<G1O)SL*)&-O
M;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XR.#,Z,BXP-C<G72`]("="87)C96QO
M;F$@+R!!97)O<'5E<G1O)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,2XV
M-C<Z+3$N,#$W)UT@/2`G6F%R86=O>F$@+R!!97)O<'5E<G1O)SL*)&-O;W)D
M:6YA=&5S6R=3<&%I;B==6R<T,2XW,3<Z+30N.#4P)UT@/2`G5F%L;&%D;VQI
M9"`O(%9I;&QA;G5B;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0Q+CDP
M,#HR+C<V-R==(#T@)T=E<F]N82`O($-O<W1A($)R879A)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<T,BXR,3<Z+3@N-C,S)UT@/2`G5FEG;R`O(%!E:6YA
M9&]R)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXS-C<Z+3,N-C,S)UT@
M/2`G0G5R9V]S("\@5FEL;&%F<FEA)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==
M6R<T,BXT-3`Z+3(N,S,S)UT@/2`G3&]G<F]N;R`O($%G;VYC:6QL;R<["B1C
M;V]R9&EN871E<ULG4W!A:6XG75LG-#(N-3@S.BTU+C8U,"==(#T@)TQE;VX@
M+R!6:7)G96X@1&5L($-A;6EN;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG
M-#(N-S8W.BTQ+C8S,R==(#T@)U!A;7!L;VYA("\@3F]A:6XG.PHD8V]O<F1I
M;F%T97-;)U-P86EN)UU;)S0R+C@X,SHM,BXW,3<G72`]("=6:71O<FEA)SL*
M)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,BXY,#`Z+3@N-#,S)UT@/2`G4V%N
M=&EA9V\@+R!,86)A8V]L;&$G.PHD8V]O<F1I;F%T97-;)U-P86EN)UU;)S0S
M+C,P,#HM,BXY,S,G72`]("=":6QB86\@+R!3;VYD:6-A)SL*)&-O;W)D:6YA
M=&5S6R=3<&%I;B==6R<T,RXS,#`Z+3@N,S@S)UT@/2`G3&$@0V]R=6YA("\@
M06QV961R;R<["B1C;V]R9&EN871E<ULG4W!A:6XG75LG-#,N,S4P.BTQ+C@P
M,"==(#T@)U-A;B!396)A<W1I86X@+R!&=65N=&5R<F%B:6$G.PHD8V]O<F1I
M;F%T97-;)U-P86EN)UU;)S0S+C0S,SHM,RXX,3<G72`]("=386YT86YD97(@
M+R!087)A>6%S)SL*)&-O;W)D:6YA=&5S6R=3<&%I;B==6R<T,RXU-3`Z+38N
M,#,S)UT@/2`G07-T=7)I87,@+R!!=FEL97,G.PHD8V]O<F1I;F%T97-;)U-R
M:2!,86YK82==6R<V+C@Q-SHW.2XX.#,G72`]("=2871M86QA;F$G.PHD8V]O
M<F1I;F%T97-;)U-R:2!,86YK82==6R<W+C$V-SHW.2XX.#,G72`]("=+871U
M;F%Y86ME)SL*)&-O;W)D:6YA=&5S6R=3<FD@3&%N:V$G75LG-RXW,3<Z.#$N
M-S`P)UT@/2`G0F%T=&EC86QO82<["B1C;V]R9&EN871E<ULG4W)I($QA;FMA
M)UU;)S@N,S,S.C@P+C0Q-R==(#T@)T%N=7)A9&AA<'5R82<["B1C;V]R9&EN
M871E<ULG4W)I($QA;FMA)UU;)S@N-3@S.C@Q+C(U,"==(#T@)U1R:6YC;VUA
M;&5E)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q,2XP,#`Z,CDN-S$W)UT@
M/2`G2V%D=6=L:2<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3$N-S4P.C,R
M+C<X,R==(#T@)U)E;FLG.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$Q+C<X
M,SHS-"XS.#,G72`]("=$86UA>FEN92<["B1C;V]R9&EN871E<ULG4W5D86XG
M75LG,3(N,#4P.C(T+C@X,R==(#T@)TYY86QA)SL*)&-O;W)D:6YA=&5S6R=3
M=61A;B==6R<Q,RXQ-C<Z,S`N,C,S)UT@/2`G16P@3V)E:60G.PHD8V]O<F1I
M;F%T97-;)U-U9&%N)UU;)S$S+C$V-SHS,BXV-C<G72`]("=+;W-T:2<["B1C
M;V]R9&EN871E<ULG4W5D86XG75LG,3,N-#@S.C(R+C0U,"==(#T@)T=E;F5I
M;F$G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C4U,#HS,RXV,3<G72`]
M("=396YN87(G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$S+C8Q-SHR-2XS
M,S,G72`]("=%;"!&87-H97(G.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S$T
M+C`S,SHS-2XT,#`G72`]("='961A<F5F)SL*)&-O;W)D:6YA=&5S6R=3=61A
M;B==6R<Q-2XT-C<Z,S8N-#`P)UT@/2`G2V%S<V%L82<["B1C;V]R9&EN871E
M<ULG4W5D86XG75LG,34N-C`P.C,R+C4U,"==(#T@)TMH87)T;W5M)SL*)&-O
M;W)D:6YA=&5S6R=3=61A;B==6R<Q-RXW,#`Z,S,N.38W)UT@/2`G071B87)A
M)SL*)&-O;W)D:6YA=&5S6R=3=61A;B==6R<Q.2XQ-C<Z,S`N-#@S)UT@/2`G
M1&]N9V]L82<["B1C;V]R9&EN871E<ULG4W5D86XG75LG,3DN-3@S.C,W+C(Q
M-R==(#T@)U!O<G0@4W5D86XG.PHD8V]O<F1I;F%T97-;)U-U9&%N)UU;)S(Q
M+C@Q-SHS,2XT.#,G72`]("=7861I($AA;&9A)SL*)&-O;W)D:6YA=&5S6R=3
M=61A;B==6R<T+C@V-SHS,2XV,#`G72`]("=*=6)A)SL*)&-O;W)D:6YA=&5S
M6R=3=61A;B==6R<Y+C4U,#HS,2XV-3`G72`]("=-86QA:V%L)SL*)&-O;W)D
M:6YA=&5S6R=3=7)I;F%M92==6R<U+C0U,#HM-34N,C`P)UT@/2`G6F%N9&5R
M:6HG.PHD8V]O<F1I;F%T97-;)U-W87II;&%N9"==6R<M,C8N-3,S.C,Q+C,P
M,"==(#T@)TUA;GII;FD@+R!-871S87!A($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U-W961E;B==6R<U-2XU-3`Z,3,N,S8W)UT@/2`G36%L;6\@+R!3='5R
M=7`G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U-2XY,3<Z,30N,#@S)UT@
M/2`G2W)I<W1I86YS=&%D("\@179E<F]D)SL*)&-O;W)D:6YA=&5S6R=3=V5D
M96XG75LG-38N,#@U.C$S+C(P-R==(#T@)TQJ=6YG8GEH960L($QJ=6YG8GEH
M960@*%-712U!1D(I)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-38N,C8W
M.C$U+C(X,R==(#T@)U)O;FYE8GDG.PHD8V]O<F1I;F%T97-;)U-W961E;B==
M6R<U-BXS,#`Z,3(N.#4P)UT@/2`G06YG96QH;VQM)SL*)&-O;W)D:6YA=&5S
M6R=3=V5D96XG75LG-38N-C@S.C$R+C@S,R==(#T@)TAA;&US=&%D(%-W961I
M<V@@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U
M-BXW,S,Z,38N,S`P)UT@/2`G2V%L;6%R)SL*)&-O;W)D:6YA=&5S6R=3=V5D
M96XG75LG-38N.#4P.C$T+C@S,R==(#T@)U9A>&IO)SL*)&-O;W)D:6YA=&5S
M6R=3=V5D96XG75LG-3<N,S`P.C$T+C$S,R==(#T@)TAA9W-H=6QT)SL*)&-O
M;W)D:6YA=&5S6R=3=V5D96XG75LG-3<N-3$W.C$U+C@S,R==(#T@)TAU;'1S
M9G)E9"!3=V5D:7-H($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=3
M=V5D96XG75LG-3<N-C8W.C$R+C,P,"==(#T@)T=O=&5B;W)G("\@3&%N9'9E
M='1E<B<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C8V-SHQ."XS-3`G
M72`]("=6:7-B>2!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==
M6R<U-RXW-C<Z,30N,#@S)UT@/2`G2F]N:V]P:6YG($9L>6=P;&%T<R<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S4W+C<X,SHQ,2XX.#,G72`]("=';W1E
M8F]R9R`O(%-A=F4G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U."XT,#`Z
M,34N-3$W)UT@/2`G3&EN:V]P:6YG("\@36%L;65N)SL*)&-O;W)D:6YA=&5S
M6R=3=V5D96XG75LG-3@N-#,S.C$R+C<P,"==(#T@)U-A=&5N87,G.PHD8V]O
M<F1I;F%T97-;)U-W961E;B==6R<U."XT-3`Z,3,N.38W)UT@/2`G4VMO=F1E
M($9L>6=P;&%T<R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4X+C4X,SHQ
M-BXQ-3`G72`]("=.;W)R:V]P:6YG)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG
M75LG-3DN,S4P.C$W+CDU,"==(#T@)U-T;V-K:&]L;2`O($)R;VUM82<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S4Y+C,V-SHQ,RXT-C<G72`]("=+87)L
M<W1A9"!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<U.2XU
M.#,Z,38N-C,S)UT@/2`G5F%S=&5R87,@+R!(87-S;&\G.PHD8V]O<F1I;F%T
M97-;)U-W961E;B==6R<U.2XV-3`Z,3<N.34P)UT@/2`G4W1O8VMH;VQM("\@
M07)L86YD82<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S4Y+C@X,SHQ-RXV
M,#`G72`]("=5<'!S86QA)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C`N
M-#,S.C$U+C4Q-R==(#T@)T)O<FQA;F=E)SL*)&-O;W)D:6YA=&5S6R=3=V5D
M96XG75LG-C`N-C`P.C$V+CDU,"==(#T@)T=A=FQE("\@4V%N9'9I:V5N($%I
M<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C$N,C8W
M.C$W+C$P,"==(#T@)U-O9&5R:&%M;B<["B1C;V]R9&EN871E<ULG4W=E9&5N
M)UU;)S8R+C4S,SHQ-RXT-3`G72`]("=3=6YD<W9A;&PM2&%R;F]S86YD($9L
M>6=P;&%T<R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8S+C`U,#HQ-RXW
M-C<G72`]("=+<F%M9F]R<R!&;'EG<&QA=',G.PHD8V]O<F1I;F%T97-;)U-W
M961E;B==6R<V,RXQ.#,Z,30N-3`P)UT@/2`G3W-T97)S=6YD("\@1G)O<V]N
M)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG-C,N-#`P.C$X+CDV-R==(#T@
M)T]R;G-K;VQD<W9I:R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG
M75LG-C,N.#`P.C(P+C(X,R==(#T@)U5M96$@1FQY9W!L871S)SL*)&-O;W)D
M:6YA=&5S6R=3=V5D96XG75LG-C0N-C,S.C(Q+C`X,R==(#T@)U-K96QL969T
M96$@06ER<&]R="<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8T+CDV-SHQ
M-RXW,#`G72`]("='=6YN87)N)SL*)&-O;W)D:6YA=&5S6R=3=V5D96XG75LG
M-C4N-34P.C(R+C$S,R==(#T@)TQU;&5A("\@2V%L;&%X)SL*)&-O;W)D:6YA
M=&5S6R=3=V5D96XG75LG-C4N.#8W.C(P+C$S,R==(#T@)U9I9'-E;"<["B1C
M;V]R9&EN871E<ULG4W=E9&5N)UU;)S8V+C8S,SHQ.2XV-3`G72`]("=*;VMK
M;6]K:R<["B1C;V]R9&EN871E<ULG4W=E9&5N)UU;)S8W+C$U,#HR,"XV-3`G
M72`]("='86QL:79A<F4G.PHD8V]O<F1I;F%T97-;)U-W961E;B==6R<V-RXX
M,3<Z,C`N,S,S)UT@/2`G2VER=6YA($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)U-W:71Z97)L86YD)UU;)S0V+C`P,#HX+CDV-R==(#T@)TQU9V%N;R<["B1C
M;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#8N,C$W.C<N,S,S)UT@/2`G
M4VEO;B<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#8N,C4P.C8N
M,3,S)UT@/2`G1V5N979E+4-O:6YT<FEN)SL*)&-O;W)D:6YA=&5S6R=3=VET
M>F5R;&%N9"==6R<T-BXU-3`Z-BXV,3<G72`]("=,875S86YN92<["B1C;V]R
M9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#8N.#$W.C8N.34P)UT@/2`G4&%Y
M97)N92<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#<N,#`P.C8N
M.34P)UT@/2`G3F5U8VAA=&5L)SL*)&-O;W)D:6YA=&5S6R=3=VET>F5R;&%N
M9"==6R<T-RXQ.#$Z-RXT,38G72`]("='<F5N8VAE;B<["B1C;V]R9&EN871E
M<ULG4W=I='IE<FQA;F0G75LG-#<N-#@S.C@N-3,S)UT@/2`G6G5R:6-H+4ML
M;W1E;B<["B1C;V]R9&EN871E<ULG4W=I='IE<FQA;F0G75LG-#<N-#@U.CDN
M-38R)UT@/2`G4V%I;G0@1V%L;&5N+4%L=&5N<FAE:6XG.PHD8V]O<F1I;F%T
M97-;)U-Y<FEA;B!!<F%B(%)E<'5B;&EC)UU;)S,S+C0Q-SHS-BXU,3<G72`]
M("=$86UA<V-U<R!);G0N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U-Y<FEA
M;B!!<F%B(%)E<'5B;&EC)UU;)S,T+C4U,#HS."XS,#`G72`]("=086QM>7)A
M)SL*)&-O;W)D:6YA=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S-2XS
M,3<Z-#`N,34P)UT@/2`G1&5I<B!%>GIO<B<["B1C;V]R9&EN871E<ULG4WER
M:6%N($%R86(@4F5P=6)L:6,G75LG,S4N-3,S.C,U+C<V-R==(#T@)TQA='1A
M:VEA)SL*)&-O;W)D:6YA=&5S6R=3>7)I86X@07)A8B!297!U8FQI8R==6R<S
M-BXQ.#,Z,S<N,C`P)UT@/2`G06QE<'!O($EN=&5R;F%T:6]N86P@06ER<&]R
M="<["B1C;V]R9&EN871E<ULG4WER:6%N($%R86(@4F5P=6)L:6,G75LG,S<N
M,#4P.C0Q+C(Q-R==(#T@)TMA;6ES:&QI)SL*)&-O;W)D:6YA=&5S6R=486EW
M86XG75LG,C`N-C8W.C$Q-BXW,3<G72`]("=$;VYG<VAA)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C$N.3,S.C$R,"XX,S,G72`]("=(96YG8VAU;B<[
M"B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C`S,SHQ,C$N-34P)UT@/2`G
M3&%N(%EU)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N-#$W.C$R,"XU
M-3`G72`]("=#:&EA(%1U;F<G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R
M,BXT-C<Z,3(P+C0S,R==(#T@)T1O;F=G86YG)SL*)&-O;W)D:6YA=&5S6R=4
M86EW86XG75LG,C(N-3@S.C$R,"XS-3`G72`]("=+86]H<VEU;F<@26YT97)N
M871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C(N
M-C@S.C$R,"XT-C<G72`]("=0:6YG='5N9R!3;W5T:"!!:7(@1F]R8V4@0F%S
M92<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C<P,#HQ,C`N-#@S)UT@
M/2`G4&EN9W1U;F<@3F]R=&@@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T
M97-;)U1A:7=A;B==6R<R,BXW.#,Z,3(P+C(V-R==(#T@)TMA;F=S:&%N(%1W
M+4%F8B<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(R+C@P,#HQ,C$N,3@S
M)UT@/2`G0VAI:&AA;F<@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG
M75LG,C(N.34P.C$R,"XR,#`G72`]("=486EN86X@5'<M069B)SL*)&-O;W)D
M:6YA=&5S6R=486EW86XG75LG,C,N,C8W.C$Q.2XV-C<G72`]("=$;VYG<VAI
M)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C,N-#8W.C$R,"XS.#,G72`]
M("=#:&EA>6D@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C,N
M-3@S.C$Q.2XV,3<G72`]("=-86MU;F<@06(G.PHD8V]O<F1I;F%T97-;)U1A
M:7=A;B==6R<R-"XP,S,Z,3(Q+C8Q-R==(#T@)TAU;&EE;B!!8B<["B1C;V]R
M9&EN871E<ULG5&%I=V%N)UU;)S(T+C$X,SHQ,C`N-C4P)UT@/2`G5&%I8VAU
M;F<@5'<M069B)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C0N,C8W.C$R
M,"XV,3<G72`]("=7=6-H:6$@3V)S97)V871O<GDG.PHD8V]O<F1I;F%T97-;
M)U1A:7=A;B==6R<R-"XT,S,Z,3$X+C,V-R==(#T@)T-H:6YM96T@+R!3:&%T
M;W4@06ER($9O<F-E($)A<V4G.PHD8V]O<F1I;F%T97-;)U1A:7=A;B==6R<R
M-"XW-3`Z,3(Q+C<V-R==(#T@)TEL86XG.PHD8V]O<F1I;F%T97-;)U1A:7=A
M;B==6R<R-"XX,3<Z,3(P+CDS,R==(#T@)TAS:6YC:'4@5'<M069B)SL*)&-O
M;W)D:6YA=&5S6R=486EW86XG75LG,C0N.3,S.C$R,2XS,#`G72`]("=082!+
M=65I("\@0F%K=6%I)SL*)&-O;W)D:6YA=&5S6R=486EW86XG75LG,C4N,#8W
M.C$R,2XR,S,G72`]("=486]Y=6%N($%B(#T@-3@Y-C4P)SL*)&-O;W)D:6YA
M=&5S6R=486EW86XG75LG,C4N,#8W.C$R,2XU-3`G72`]("=3=6YG<VAA;B`O
M(%1A:7!E:2<["B1C;V]R9&EN871E<ULG5&%I=V%N)UU;)S(U+C`X,SHQ,C$N
M,C$W)UT@/2`G0VAI86YG($MA:2!3:&5K)SL*)&-O;W)D:6YA=&5S6R=486EW
M86XG75LG,C8N,38W.C$Q.2XY,S,G72`]("=-87IU)SL*)&-O;W)D:6YA=&5S
M6R=486II:VES=&%N)UU;)S,X+C4U,#HV."XW.#,G72`]("=$=7-H86YB92<[
M"B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==
M6R<M,2XS,S,Z,S$N.#$W)UT@/2`G0G5K;V)A)SL*)&-O;W)D:6YA=&5S6R=4
M86YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTQ+C4P,#HS,RXX,#`G
M72`]("=-=7-O;6$G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8G75LG+3$P+C(V-SHT,"XQ.#,G72`]("=-='=A<F$G.PHD
M8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG
M+3$P+C,U,#HS."XW-3`G72`]("=.86-H:6YG=V5A)SL*)&-O;W)D:6YA=&5S
M6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTQ,"XV.#,Z,S4N
M-3@S)UT@/2`G4V]N9V5A)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI
M=&5D(%)E<'5B;&EC(&]F)UU;)RTR+C0V-SHS,BXY,3<G72`]("=-=V%N>F$G
M.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G
M75LG+3,N,S,S.C,V+C8Q-R==(#T@)T%R=7-H82<["B1C;V]R9&EN871E<ULG
M5&%N>F%N:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M,RXS-3`Z,S<N,S,S
M)UT@/2`G36]S:&DG.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@
M4F5P=6)L:6,@;V8G75LG+3,N-#$W.C,W+C`V-R==(#T@)TMI;&EM86YJ87)O
M($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P
M=6)L:6,@;V8G75LG+30N,#@S.C,W+C<Q-R==(#T@)U-A;64G.PHD8V]O<F1I
M;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+30N.#@S
M.C(Y+C8S,R==(#T@)TMI9V]M82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L
M(%5N:71E9"!297!U8FQI8R!O9B==6R<M-"XX.#,Z,S@N,C@S)UT@/2`G36]M
M8F\G.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8G75LG+34N,#@S.C,R+C@S,R==(#T@)U1A8F]R82!!:7)P;W)T)SL*)&-O
M;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTU
M+C`X,SHS.2XP-C<G72`]("=486YG82<["B1C;V]R9&EN871E<ULG5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M-2XR-3`Z,SDN.#$W)UT@/2`G
M4&5M8F$@+R!+87)U;64@06ER<&]R="<["B1C;V]R9&EN871E<ULG5&%N>F%N
M:6$L(%5N:71E9"!297!U8FQI8R!O9B==6R<M-BXQ-C<Z,S4N-S8W)UT@/2`G
M1&]D;VUA)SL*)&-O;W)D:6YA=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B
M;&EC(&]F)UU;)RTV+C(Q-SHS.2XR,3<G72`]("=:86YZ:6)A<B`O($MI<V%U
M;FDG.PHD8V]O<F1I;F%T97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@
M;V8G75LG+38N.#,S.C,W+C8U,"==(#T@)TUO<F]G;W)O)SL*)&-O;W)D:6YA
M=&5S6R=486YZ86YI82P@56YI=&5D(%)E<'5B;&EC(&]F)UU;)RTV+C@V-SHS
M.2XR,#`G72`]("=$87(@17,@4V%L86%M($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U1A;GIA;FEA+"!5;FET960@4F5P=6)L:6,@;V8G75LG+3<N-C8W.C,U
M+C<U,"==(#T@)TER:6YG82<["B1C;V]R9&EN871E<ULG5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B==6R<M."XY,S,Z,S,N-#8W)UT@/2`G36)E>6$G
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$P+C0X,SHY.2XQ.#,G72`]
M("=#:'5M<&AO;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3$N.#,S
M.CDY+C@S,R==(#T@)U!R86-H=6%P($MH:7)I:VAA;B<["B1C;V]R9&EN871E
M<ULG5&AA:6QA;F0G75LG,3(N-3@S.CDY+CDU,"==(#T@)TAU82!(:6XG.PHD
M8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$R+C8P,#HQ,#(N,3$W)UT@/2`G
M0VAA;G1H86)U<FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$R+C8S
M,SHQ,#$N,S4P)UT@/2`G4F%Y;VYG)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N
M9"==6R<Q,RXQ-3`Z,3`P+C`V-R==(#T@)U!H971C:&%B=7)I)SL*)&-O;W)D
M:6YA=&5S6R=4:&%I;&%N9"==6R<Q,RXS-C<Z,3`P+CDX,R==(#T@)T-H;VX@
M0G5R:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3,N.3$W.C$P,"XV
M,#`G72`]("=$;VX@375A;F<G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;
M)S$T+C`Q-SHY.2XU,S,G72`]("=+86YC:&%N86)U<FDG.PHD8V]O<F1I;F%T
M97-;)U1H86EL86YD)UU;)S$T+C`U,#HQ,#$N,S8W)UT@/2`G4')A8VAI;B!"
M=7)I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-"XY-C<Z,3`R+C`X
M,R==(#T@)TYA:VAO;B!2871C:&%S:6UA)SL*)&-O;W)D:6YA=&5S6R=4:&%I
M;&%N9"==6R<Q-2XR-3`Z,3`T+C@V-R==(#T@)U5B;VX@4F%T8VAA=&AA;FDG
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$U+C@P,#HQ,#`N,38W)UT@
M/2`G3F%K:&]N(%-A=V%N)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M-2XX,#`Z,3`R+C`S,R==(#T@)T-H86EY87!H=6TG.PHD8V]O<F1I;F%T97-;
M)U1H86EL86YD)UU;)S$V+C`U,#HQ,#,N-C@S)UT@/2`G4F]I($5T)SL*)&-O
M;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q-BXT,S,Z,3`R+C@S,R==(#T@)TMH
M;VX@2V%E;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,38N-3,S.C$P
M-"XW,3<G72`]("=-=6MD86AA;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G
M75LG,38N-C8W.CDX+C4U,"==(#T@)TUA92!3;W0G.PHD8V]O<F1I;F%T97-;
M)U1H86EL86YD)UU;)S$V+C<X,SHQ,#`N,C8W)UT@/2`G4&AI='-A;G5L;VLG
M.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$V+C@X,SHY.2XQ-3`G72`]
M("=486LG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$W+C$U,#HQ,#0N
M,3,S)UT@/2`G4V%K;VX@3F%K:&]N)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N
M9"==6R<Q-RXS.#,Z,3`R+C@P,"==(#T@)U5D;VX@5&AA;FDG.PHD8V]O<F1I
M;F%T97-;)U1H86EL86YD)UU;)S$W+C0Q-SHQ,#0N-S@S)UT@/2`G3F%K:&]N
M(%!H86YO;2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3<N-#4P.C$P
M,2XW,S,G72`]("=,;V5I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<Q
M-RXV,3<Z,3`P+C$P,"==(#T@)U5T=&%R861I="<["B1C;V]R9&EN871E<ULG
M5&AA:6QA;F0G75LG,3<N.#8W.C$P,BXW,3<G72`]("=.;VYG($MH86DG.PHD
M8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$X+C$V-SHQ,#`N,38W)UT@/2`G
M4&AR864G.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S$X+C$V-SHY-RXY
M,S,G72`]("=-864@4V%R:6%N9R<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G
M75LG,3@N,C@S.CDY+C4Q-R==(#T@)TQA;7!A;F<G.PHD8V]O<F1I;F%T97-;
M)U1H86EL86YD)UU;)S$X+C<V-SHQ,#`N-S8W)UT@/2`G3F%N)SL*)&-O;W)D
M:6YA=&5S6R=4:&%I;&%N9"==6R<Q."XW.#,Z.3@N.3@S)UT@/2`G0VAI86YG
M($UA:2<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG,3DN,S`P.CDW+C@S
M,R==(#T@)TUA92!(;VYG(%-O;B<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G
M75LG,3DN.3$W.CDY+C@S,R==(#T@)T-H:6%N9R!286DG.PHD8V]O<F1I;F%T
M97-;)U1H86EL86YD)UU;)S8N-C4P.C$P,"XP.#,G72`]("=3871U;B<["B1C
M;V]R9&EN871E<ULG5&AA:6QA;F0G75LG-BXW.#,Z,3`Q+C$U,"==(#T@)U!A
M='1A;FDG.PHD8V]O<F1I;F%T97-;)U1H86EL86YD)UU;)S8N.3$W.C$P,"XT
M,S,G72`]("=(870@66%I)SL*)&-O;W)D:6YA=&5S6R=4:&%I;&%N9"==6R<W
M+C(P,#HQ,#`N-C`P)UT@/2`G4V]N9VMH;&$G.PHD8V]O<F1I;F%T97-;)U1H
M86EL86YD)UU;)S<N-3$W.CDY+C8Q-R==(#T@)U1R86YG)SL*)&-O;W)D:6YA
M=&5S6R=4:&%I;&%N9"==6R<X+C$Q-SHY."XS,3<G72`]("=0:'5K970@06ER
M<&]R="<["B1C;V]R9&EN871E<ULG5&AA:6QA;F0G75LG."XT-C<Z.3DN.38W
M)UT@/2`G3F%K:&]N(%-I(%1H86UM87)A="<["B1C;V]R9&EN871E<ULG5&AA
M:6QA;F0G75LG.2XQ,3<Z.3DN,S4P)UT@/2`G4W5R870@5&AA;FDG.PHD8V]O
M<F1I;F%T97-;)U1H86EL86YD)UU;)SDN.3@S.CDX+C8Q-R==(#T@)U)A;F]N
M9R<["B1C;V]R9&EN871E<ULG5&]G;R==6R<Q,"XS-C<Z,"XT-C<G72`]("=-
M86YG;R<["B1C;V]R9&EN871E<ULG5&]G;R==6R<V+C$V-SHQ+C(U,"==(#T@
M)TQO;64G.PHD8V]O<F1I;F%T97-;)U1O9V\G75LG-BXU.#,Z,2XU,#`G72`]
M("=486)L:6=B;R<["B1C;V]R9&EN871E<ULG5&]G;R==6R<W+C4X,SHQ+C$Q
M-R==(#T@)T%T86MP86UE)SL*)&-O;W)D:6YA=&5S6R=4;V=O)UU;)S@N.3@S
M.C$N,34P)UT@/2`G4V]K;V1E)SL*)&-O;W)D:6YA=&5S6R=4;V=O)UU;)SDN
M-S8W.C$N,3`P)UT@/2`G3FEA;71O=6=O=2<["B1C;V]R9&EN871E<ULG5&]N
M9V$G75LG+3$Y+C@P,#HM,3<T+C,U,"==(#T@)TAA87!A:2<["B1C;V]R9&EN
M871E<ULG5&]N9V$G75LG+3(Q+C(S,SHM,3<U+C$U,"==(#T@)T9U85PG06UO
M='4G.PHD8V]O<F1I;F%T97-;)U1R:6YI9&%D(&%N9"!4;V)A9V\G75LG,3`N
M-C$W.BTV,2XS-3`G72`]("=0:6%R8V\@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!4<FEN:61A9"<["B1C;V]R9&EN871E<ULG5')I;FED860@86YD(%1O8F%G
M;R==6R<Q,2XQ-3`Z+38P+C@S,R==(#T@)T-R;W=N(%!O:6YT($%I<G!O<G0L
M(%1O8F%G;R<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S,2XV.#,Z.2XQ
M-C<G72`]("=%;"!";W)M82<["B1C;V]R9&EN871E<ULG5'5N:7-I82==6R<S
M,BXS,3<Z,3`N-#`P)UT@/2`G4F5M861A)SL*)&-O;W)D:6YA=&5S6R=4=6YI
M<VEA)UU;)S,S+C@V-SHQ,"XW-C<G72`]("=$:F5R8F$@365L;&ET82<["B1C
M;V]R9&EN871E<ULG5'5N:7-I82==6R<S,RXX.#,Z,3`N,3`P)UT@/2`G1V%B
M97,G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S,N.3$W.C@N,3`P)UT@
M/2`G5&]Z975R)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,T+C0Q-SHX
M+C@Q-R==(#T@)T=A9G-A)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,T
M+C<Q-SHQ,"XV.#,G72`]("=39F%X($5L+4UA;W4G.PHD8V]O<F1I;F%T97-;
M)U1U;FES:6$G75LG,S4N-C8W.C$P+C$P,"==(#T@)TMA:7)O=6%N)SL*)&-O
M;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,U+C8V-SHQ,"XW-3`G72`]("=-;VYA
M<W1I<BU3:V%N97,G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S8N-#@S
M.C@N.#`P)UT@/2`G2F5N9&]U8F$G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G
M75LG,S8N.#,S.C$P+C(S,R==(#T@)U1U;FES+4-A<G1H86=E)SL*)&-O;W)D
M:6YA=&5S6R=4=6YI<VEA)UU;)S,V+C@U,#HQ,2XP.#,G72`]("=+96QI8FEA
M)SL*)&-O;W)D:6YA=&5S6R=4=6YI<VEA)UU;)S,V+CDU,#HX+C<U,"==(#T@
M)U1A8F%R:V$G.PHD8V]O<F1I;F%T97-;)U1U;FES:6$G75LG,S<N,C4P.CDN
M.#`P)UT@/2`G0FEZ97)T92<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,V
M+C4X,SHS-BXQ-C<G72`]("=)<VME;F1E<G5N)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,S8N-S`P.C(X+C<X,R==(#T@)T1A;&%M86XG.PHD8V]O<F1I
M;F%T97-;)U1U<FME>2==6R<S-BXW,#`Z,S`N-S,S)UT@/2`G06YT86QY82<[
M"B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,V+CDX,SHS-2XS,#`G72`]("=!
M9&%N82`O(%-A:VER<&%S82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W
M+C`P,#HS-2XT,3<G72`]("=!9&%N82`O($EN8VER;&EK)SL*)&-O;W)D:6YA
M=&5S6R=4=7)K97DG75LG,S<N,#,S.C(W+C0Q-R==(#T@)T)O9')U;2<["B1C
M;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C`X,SHS-RXS-C<G72`]("='87II
M86YT97`G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S-RXQ,S,Z,S@N-S8W
M)UT@/2`G57)F82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,W+C<U,#HS
M,"XU-3`G72`]("=)<W!A<G1A)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG
M,S<N.#4P.C(W+C@U,"==(#T@)T%Y9&EN)SL*)&-O;W)D:6YA=&5S6R=4=7)K
M97DG75LG,S<N.#8W.C0Q+C$V-R==(#T@)T)A=&UA;B<["B1C;V]R9&EN871E
M<ULG5'5R:V5Y)UU;)S,W+C@X,SHT,"XQ.#,G72`]("=$:7EA<F)A:VER)SL*
M)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S<N.38W.C,R+C4U,"==(#T@)TMO
M;GEA)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N,C8W.C(W+C$U,"==
M(#T@)TEZ;6ER("\@061N86X@365N9&5R97,G.PHD8V]O<F1I;F%T97-;)U1U
M<FME>2==6R<S."XT,S,Z,S@N,#@S)UT@/2`G36%L871Y82`O($5R:&%C)SL*
M)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N-#4P.C0S+C,Q-R==(#T@)U9A
M;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,X+C4P,#HR-RXP,3<G72`]
M("=)>FUI<B`O($-I9VQI)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N
M-C`P.C,Y+C(X,R==(#T@)T5L87II9R<["B1C;V]R9&EN871E<ULG5'5R:V5Y
M)UU;)S,X+C8V-SHR.2XT,3<G72`]("=5<V%K)SL*)&-O;W)D:6YA=&5S6R=4
M=7)K97DG75LG,S@N-S4P.C,P+C4S,R==(#T@)T%F>6]N)SL*)&-O;W)D:6YA
M=&5S6R=4=7)K97DG75LG,S@N-S@S.C,U+C0X,R==(#T@)TMA>7-E<FD@+R!%
M<FMI;&5T)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,S@N.3$W.C(W+C@U
M,"==(#T@)T%K:&ES87(G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<S.2XV
M,3<Z,C<N.3$W)UT@/2`G0F%L:6ME<VER)SL*)&-O;W)D:6YA=&5S6R=4=7)K
M97DG75LG,SDN-S,S.C,Y+C4P,"==(#T@)T5R>FEN8V%N)SL*)&-O;W)D:6YA
M=&5S6R=4=7)K97DG75LG,SDN-S4P.C,W+C`Q-R==(#T@)U-I=F%S)SL*)&-O
M;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN-S@S.C,P+C4V-R==(#T@)T5S:VES
M96AI<B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S,Y+CDQ-SHT,2XR-C<G
M72`]("=%<GIU<G5M)SL*)&-O;W)D:6YA=&5S6R=4=7)K97DG75LG,SDN.34P
M.C,R+C8X,R==(#T@)T%N:V%R82`O($5T:6UE<V=U="<["B1C;V]R9&EN871E
M<ULG5'5R:V5Y)UU;)S0P+C`X,SHS,BXU-C<G72`]("=-=7)T960@5'5R+4%F
M8B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C$Q-SHS,BXY.#,G72`]
M("=!;FMA<F$@+R!%<V5N8F]G82<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;
M)S0P+C$S,SHR-BXT,#`G72`]("=#86YA:VMA;&4G.PHD8V]O<F1I;F%T97-;
M)U1U<FME>2==6R<T,"XQ.#,Z,CDN,#8W)UT@/2`G0G5R<V$G.PHD8V]O<F1I
M;F%T97-;)U1U<FME>2==6R<T,"XS,#`Z,S8N-38W)UT@/2`G5&]K870G.PHD
M8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XS,3<Z,C<N.38W)UT@/2`G0F%N
M9&ER;6$G.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,"XV,#`Z-#,N,#@S
M)UT@/2`G2V%R<R<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0P+C@U,#HS
M-2XU.#,G72`]("=-97)Z:69O;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;
M)S0P+CDV-SHR."XX,3<G72`]("=)<W1A;F)U;"`O($%T871U<FLG.PHD8V]O
M<F1I;F%T97-;)U1U<FME>2==6R<T,2XP,#`Z,SDN-S$W)UT@/2`G5')A8GIO
M;B<["B1C;V]R9&EN871E<ULG5'5R:V5Y)UU;)S0Q+C(V-SHS-BXS,#`G72`]
M("=386US=6XG.PHD8V]O<F1I;F%T97-;)U1U<FME>2==6R<T,2XT-3`Z,S$N
M.#`P)UT@/2`G6F]N9W5L9&%K)SL*)&-O;W)D:6YA=&5S6R=4=79A;'4G75LG
M+34N-C8W.C$W-BXQ,S,G72`]("=.86YU;65A)SL*)&-O;W)D:6YA=&5S6R=4
M=79A;'4G75LG+3@N-3$W.C$W.2XR,3<G72`]("=&=6YA9G5T:2<["B1C;V]R
M9&EN871E<ULG56=A;F1A)UU;)S`N,#4P.C,R+C0U,"==(#T@)T5N=&5B8F4@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S`N,3@S.C,P+C$P
M,"==(#T@)TMA<V5S92<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S`N-#4P
M.C,S+C$X,R==(#T@)TII;FIA)SL*)&-O;W)D:6YA=&5S6R=59V%N9&$G75LG
M+3`N-C$W.C,P+C8U,"==(#T@)TUB87)A<F$G.PHD8V]O<F1I;F%T97-;)U5G
M86YD82==6R<P+C8X,SHS-"XQ-C<G72`]("=4;W)O<F\G.PHD8V]O<F1I;F%T
M97-;)U5G86YD82==6R<M,2XR-3`Z,CDN.3@S)UT@/2`G2V%B86QE)SL*)&-O
M;W)D:6YA=&5S6R=59V%N9&$G75LG,2XV.#,Z,S$N-S$W)UT@/2`G36%S:6YD
M:2<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S$N-S$W.C,S+C8Q-R==(#T@
M)U-O<F]T:2<["B1C;V]R9&EN871E<ULG56=A;F1A)UU;)S(N-S4P.C,R+C,S
M,R==(#T@)T=U;'4G.PHD8V]O<F1I;F%T97-;)U5G86YD82==6R<S+C`U,#HS
M,"XY,3<G72`]("=!<G5A)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;)S0T
M+C8X,SHS-"XQ,S,G72`]("=3:6UF97)O<&]L)SL*)&-O;W)D:6YA=&5S6R=5
M:W)A:6YE)UU;)S0V+C0S,SHS,"XW-C<G72`]("=/9&5S82<["B1C;V]R9&EN
M871E<ULG56MR86EN92==6R<T.2XX,3<Z,C,N.34P)UT@/2`G3%PG5FEV)SL*
M)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;)S0Y+CDV-SHS-BXQ,S,G72`]("=+
M:&%R:VEV)SL*)&-O;W)D:6YA=&5S6R=5:W)A:6YE)UU;)S4P+C,S,SHS,"XY
M-C<G72`]("=";W)Y<W!I;"<["B1C;V]R9&EN871E<ULG56MR86EN92==6R<U
M,"XT,#`Z,S`N-38W)UT@/2`G2WEI=B<["B1C;V]R9&EN871E<ULG56MR86EN
M92==6R<U,"XU.#,Z,C8N,3,S)UT@/2`G4FEV;F4G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!!<F%B($5M:7)A=&5S)UU;)S(T+C(V-SHU-2XV,#`G72`]("=!
M;"!!:6X@26YT97)N871I;VYA;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@07)A8B!%;6ER871E<R==6R<R-"XT,S,Z-30N-#8W)UT@/2`G06)U
M($1H86)I($)A=&5E;B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M07)A8B!%;6ER871E<R==6R<R-"XT,S,Z-30N-C4P)UT@/2`G06)U($1H86)I
M($EN=&5R;F%T:6]N86P@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D
M($%R86(@16UI<F%T97,G75LG,C4N,3`P.C4V+C,S,R==(#T@)T9U:F%I<F%H
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-2XR
M-3`Z-34N,S,S)UT@/2`G1'5B86D@26YT97)N871I;VYA;"!!:7)P;W)T)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@07)A8B!%;6ER871E<R==6R<R-2XS,S,Z
M-34N-3$W)UT@/2`G4VAA<FIA:"!);G1E<FYA=&EO;F%L($%I<G!O<G0G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!!<F%B($5M:7)A=&5S)UU;)S(U+C8Q-SHU
M-2XY,S,G72`]("=287,@06P@2VAA:6UA:"!);G1E<FYA=&EO;F%L($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S0Y+C(Q-SHM
M,BXR,#`G72`]("=*97)S97D@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-#DN-#,S.BTR+C8P,"==(#T@)T=U97)N<V5Y($%I
M<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S0Y+CDQ
M-SHM-BXS,#`G72`]("=38VEL;'DL(%-A:6YT($UA<GE<)U,G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4P+C`X,SHM-2XR-3`G72`]("=#
M=6QD<F]S92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3`N
M,S4P.BTT+C$Q-R==(#T@)U!L>6UO=71H)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,"XT,S,Z+34N,#`P)UT@/2`G4V%I;G0@36%W9V%N
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,"XU-C<Z+3(N
M-#4P)UT@/2`G4&]R=&QA;F0@+R!2;F%S)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,"XW,S,Z+3,N-#$W)UT@/2`G17AE=&5R($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4P+C<X,SHM
M,2XX,S,G72`]("=";W5R;F5M;W5T:"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U,"XX,S,Z+3`N,C@S)UT@/2`G4VAO<F5H
M86T@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3`N.3`P.BTQ+C0P,"==(#T@)U-O=71H86UP=&]N("\@5V5A=&AE<B!#96YT
M<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C`P,#HM
M,BXV,S,G72`]("=996]V:6QT;VXG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+
M:6YG9&]M)UU;)S4Q+C`X,SHM-"XQ-3`G72`]("=#:&EV96YO<B<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,34P.BTP+C$X,R==(#T@
M)TQO;F1O;B`O($=A='=I8VL@06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI
M=&5D($MI;F=D;VTG75LG-3$N,34P.BTQ+C4V-R==(#T@)TUI9&1L92!786QL
M;W`G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C$V-SHM
M,2XW-3`G72`]("=";W-C;VUB92!$;W=N)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,2XR,S,Z+3`N.34P)UT@/2`G3V1I:&%M)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XR.#,Z+3`N-S8W)UT@
M/2`G1F%R;F)O<F]U9V@@36EL:71A<GDG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!+:6YG9&]M)UU;)S4Q+C(X,SHM,"XW-C<G72`]("=&87)N8F]R;W5G:"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N,S4P.C$N,S4P
M)UT@/2`G36%N<W1O;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG
M75LG-3$N,S@S.BTP+C<X,R==(#T@)T)R86-K;F5L;"`O($)E875F;W)T(%!A
M<FLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C0P,#HM
M,RXS-3`G72`]("=#87)D:69F+5=A;&5S($%I<G!O<G0G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C0X,SHM,"XT-3`G72`]("=,;VYD
M;VX@+R!(96%T:')O=R!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U,2XU,#`Z+3$N.3@S)UT@/2`G3'EN96AA;2<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3$N-3$W.BTP+C$Q-R==(#T@
M)TQO;F1O;B!796%T:&5R($-E;G1R92<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-3$N-34P.BTP+C0Q-R==(#T@)TYO<G1H;VQT)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XV,3<Z+3$N,#@S)UT@
M/2`G0F5N<V]N)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U
M,2XV.#,Z+3$N-S@S)UT@/2`G1F%I<F9O<F0@4F]Y86P@06ER($9O<F-E($)A
M<V4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4Q+C<Q-SHM
M-"XS-C<G72`]("=096UB<F5Y(%-A;F1S)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,2XW-3`Z+3$N-3@S)UT@/2`G0G)I>F4@3F]R=&]N
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,2XX.#,Z,"XR
M,S,G72`]("=3=&%N<W1E9"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,BXQ,3<Z,"XY-C<G72`]("=7871T:7-H86TG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C$S,SHM-"XU-C<G
M72`]("=!8F5R<&]R=&@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M
M)UU;)S4R+C,S,SHP+C<V-R==(#T@)TAO;FEN9W1O;B!2;WEA;"!!:7(@1F]R
M8V4@0F%S92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N
M,S4P.BTP+C$Q-R==(#T@)U=Y=&]N(%)O>6%L($%I<B!&;W)C92!"87-E)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXS-C<Z+3`N,C$W
M)UT@/2`G06QC;VYB=7)Y(%)O>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXS-C<Z,"XT.#,G72`]("=-
M:6QD96YH86QL(%)O>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@2VEN9V1O;2==6R<U,BXT,3<Z,"XU-C<G72`]("=,86ME;FAE
M871H(%)O>6%L($%I<B!&;W)C92!"87-E)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,BXT,S,Z,2XS-3`G72`]("=#;VQT:7-H86QL)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,BXT-3`Z+3$N-S,S
M)UT@/2`G0FER;6EN9VAA;2`O($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4R+C8Q-SHM,"XT-C<G72`]("=7:71T97)I;F<G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4R+C8S,SHQ+C,P
M,"==(#T@)TYO<G=I8V@@5V5A=&AE<B!#96YT<F4G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!+:6YG9&]M)UU;)S4R+C8U,#HP+C4V-R==(#T@)TUA<FAA;2<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N-S,S.BTP+C8U
M,"==(#T@)T-O='1E<VUO<F4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4R+C@P,#HM,BXV-C<G72`]("=3:&%W8G5R>2<["B1C;V]R9&EN
M871E<ULG56YI=&5D($MI;F=D;VTG75LG-3(N.#8W.C`N,34P)UT@/2`G2&]L
M8F5A8V@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S+C`S
M,SHM,"XU,#`G72`]("=#<F%N=V5L;"<["B1C;V]R9&EN871E<ULG56YI=&5D
M($MI;F=D;VTG75LG-3,N,#@S.BTP+C$V-R==(#T@)T-O;FEN9W-B>2!2;WEA
M;"!!:7(@1F]R8V4@0F%S92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3,N,#@S.C`N,C8W)UT@/2`G5V%I;F9L965T)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXQ-C<Z+3`N-3$W)UT@/2`G5V%D
M9&EN9W1O;B<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3,N
M,38W.BTR+CDX,R==(#T@)TAA=V%R9&5N)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,RXR-3`Z+30N-3,S)UT@/2`G5F%L;&5Y)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U,RXS-3`Z+3(N,C@S)UT@
M/2`G36%N8VAE<W1E<B!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U,RXW-C<Z+3,N,#,S)UT@/2`G0FQA8VMP;V]L($%I<G!O
M<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4S+C@S,SHM
M,2XR,#`G72`]("=#:'5R8V@@1F5N=&]N)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@2VEN9V1O;2==6R<U,RXX-C<Z+3`N-#,S)UT@/2`G3&5C;VYF:65L9"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-30N,#4P.BTQ+C(U
M,"==(#T@)TQI;G1O;BU/;BU/=7-E)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U-"XP.#,Z+30N-C,S)UT@/2`G27-L92!/9B!-86X@+R!2
M;VYA;&1S=V%Y($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG
M9&]M)UU;)S4T+C$Q-SHM,RXR-3`G72`]("=786QN97D@27-L86YD)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XQ,S,Z+3$N-#$W)UT@
M/2`G1&ES9F]R=&@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;
M)S4T+C,P,#HM,2XU,S,G72`]("=,965M:6YG)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@2VEN9V1O;2==6R<U-"XV,#`Z+34N.#@S)UT@/2`G0F5L9F%S="`O
M($AA<F)O=7(G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4T
M+C8U,#HM-BXR,3<G72`]("="96QF87-T("\@06QD97)G<F]V92!!:7)P;W)T
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-"XX-3`Z+30N
M.34P)UT@/2`G5V5S="!&<F5U9V@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+
M:6YG9&]M)UU;)S4T+CDS,SHM,BXY-3`G72`]("=#87)L:7-L92<["B1C;V]R
M9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-34N,#4P.BTR+C4U,"==(#T@
M)U-P861E861A;2<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-34N-#$W.BTQ+C8P,"==(#T@)T)O=6QM97(G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!+:6YG9&]M)UU;)S4U+C0S,SHM-2XW,#`G72`]("=-86-H<FEH86YI
M<V@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4U+C4P,#HM
M-"XU.#,G72`]("=0<F5S='=I8VL@06ER<&]R="<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-34N.#8W.BTT+C0S,R==(#T@)T=L87-G;W<@
M06ER<&]R="<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-34N
M.34P.BTS+C,U,"==(#T@)T5D:6YB=7)G:"!!:7)P;W)T)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@2VEN9V1O;2==6R<U-BXS.#,Z+3(N.#8W)UT@/2`G3&5U
M8VAA<G,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4V+C4P
M,#HM-BXX.#,G72`]("=4:7)E92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI
M;F=D;VTG75LG-3<N,C`P.BTR+C(Q-R==(#T@)T%B97)D965N("\@1'EC92<[
M"B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG-3<N-#8W.BTW+C,V
M-R==(#T@)T)E;F)E8W5L82<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3<N-3,S.BTT+C`U,"==(#T@)TEN=F5R;F5S<R`O($1A;&-R;W-S
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-RXV-3`Z+3,N
M-38W)UT@/2`G2VEN;&]S<R<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D
M;VTG75LG-3<N-S$W.BTS+C,Q-R==(#T@)TQO<W-I96UO=71H)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@2VEN9V1O;2==6R<U-RXX,3<Z+3,N.38W)UT@/2`G
M5&%I;B!286YG92<["B1C;V]R9&EN871E<ULG56YI=&5D($MI;F=D;VTG75LG
M-3@N,C$W.BTV+C,Q-R==(#T@)U-T;W)N;W=A>2<["B1C;V]R9&EN871E<ULG
M56YI=&5D($MI;F=D;VTG75LG-3@N-#4P.BTS+C`X,R==(#T@)U=I8VLG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!+:6YG9&]M)UU;)S4X+CDU,#HM,BXY,#`G
M72`]("=+:7)K=V%L;"!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M2VEN9V1O;2==6R<U.2XX.#,Z+3$N,S`P)UT@/2`G4W5M8G5R9V@@0V%P92<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)
M<VQA;F1S)UU;)RTQ-"XS,S,Z+3$W,"XW,3<G72`]("=086=O(%!A9V\@+R!)
M;G0N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,@36EN
M;W(@3W5T;'EI;F<@27-L86YD<R==6R<Q-BXW,S,Z+3$V.2XU,S,G72`]("=*
M;VAN<W1O;B!)<VQA;F0L($IO:&YS=&]N($%T;VQL($%I<G!O<G0G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,3,N-#@S.C$T-"XX,#`G72`]
M("=!9V%N82P@1W5A;2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($=5)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$S+C4X,SHQ-#0N.3,S)UT@
M/2`G06YD97)S96X@*$UA<FEA;F$@27,I+"!!;F1E<G-E;B!!:7(@1F]R8V4@
M0F%S92P@1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,3,N
M.3$W.C$T-"XX,S,G72`]("='=6%M+"!-87)I86YA($ES;&%N9"P@1U4G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,30N,3@S.C$T-2XR-3`G
M72`]("=2;W1A($ES;&%N9"`H3BX@36%R:6%N82!)<RDL(%)O=&$@26YT97)N
M871I;VYA;"!!:7)P;W)T+"!'52<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<Q-"XY.#,Z,30U+C8Q-R==(#T@)U1I;FEA;B!)<VQA;F0@*$XN
M($UA<FEA;F$@27,I+"!797-T(%1I;FEA;B!!:7)P;W)T+"!'52<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<Q-2XQ,3<Z,30U+C<S,R==(#T@
M)U-A:7!A;B!)<VQA;F0L(%-A:7!A;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($YO<G1H97)N($UA<FEA;F$@27-L86YD<R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<Q."XR-34Z+38U+C8T,R==(#T@)U)O;W-E=F5L="!2
M;V%D<RP@4F]O<V5V96QT(%)O861S($YA=F%L(%-T871I;VX@*$]F<W1I92!&
M:65L9"DL(%!2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$X
M+C4P,#HM-C<N,3,S)UT@/2`G07%U861I;&QA+"!2869A96P@2&5R;F%N9&5Z
M($%I<G!O<G0L(%!2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S$Y+C$P,#HM,34U+C<U,"==(#T@)U-O=71H($MO;F$@+R!(87=A:6DL($A)
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S$Y+C(X,SHQ-C8N
M-C4P)UT@/2`G5V%K92!)<VQA;F0L(%=A:V4@27-L86YD($%R;7D@06ER9FEE
M;&0@06ER<&]R="P@1U4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,3DN-S(R.BTQ-34N,#4V)UT@/2`G2&EL;RP@2&EL;R!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S(P+C@Y,CHM,34V+C0S-R==(#T@)TMA:'5L=6DL($MA:'5L=6D@06ER
M<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C$N
M,34P.BTQ-3<N,3`P)UT@/2`G36]L;VMA:2!!=71O;6%T:6,@365T96]R;VQO
M9VEC86P@3V)S97)V:6YG(%-Y<W1E;2P@2$DG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,C$N,S`X.BTQ-3@N,#8X)UT@/2`G3V%H=2P@2V%L
M865L;V$@06ER<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,C$N,S(X.BTQ-3<N.30S)UT@/2`G2&]N;VQU;'4L($AO;F]L=6QU
M($EN=&5R;F%T:6]N86P@06ER<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,C$N-#4T.BTQ-3<N-S8V)UT@/2`G2V%N96]H92P@
M36%R:6YE($-O<G!S($%I<B!3=&%T:6]N+"!(22<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<R,2XT.#,Z+3$U."XP,S,G72`]("=7:&5E;&5R
M($%I<B!&;W)C92!"87-E("\@3V%H=2P@2$DG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,C$N.3@T.BTQ-3DN,S0Q)UT@/2`G3&EH=64L($QI
M:'5E($%I<G!O<G0L($A))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S(R+C`S-CHM,34Y+C<X-B==(#T@)TME:V%H82P@4&%C:69I8R!-:7-S
M:6QE(%1E<W0@1F%C:6QI='D@0F%R:VEN9R!386YD<RP@2$DG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C0N-34T.BTX,2XW-30G72`]("=+
M97D@5V5S="P@2V5Y(%=E<W0@26YT97)N871I;VYA;"!!:7)P;W)T+"!&3"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-2XW.3$Z+3@P+C,Q
M-B==(#T@)TUI86UI+"!-:6%M:2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($9,
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(U+CDQ-#HM.3<N
M-#(S)UT@/2`G0G)O=VYS=FEL;&4L($)R;W=N<W9I;&QE("\@4V]U=&@@4&%D
M<F4@27-L86YD($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C8N-C@U.BTX,"XP.3DG72`]("=7
M97-T(%!A;&T@0F5A8V@L(%!A;&T@0F5A8V@@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R-RXU
M-3`Z+3DY+C0V-R==(#T@)TQA<F5D;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+C8U,#HM
M.#$N,S,S)UT@/2`G079O;B!087)K($=U;FYE<GD@4F%N9V4L($9,)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+C<P,#HM.#(N-#`P)UT@
M/2`G5&%M<&$@0F%Y($%R96$L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S(W+C<W,SHM.3<N-3$S)UT@/2`G0V]R<'5S($-H<FES=&DL
M($-O<G!U<R!#:')I<W1I($EN=&5R;F%T:6]N86P@06ER<&]R="P@5%@G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C<N.#4P.BTX,BXU,#`G
M72`]("=-86-D:6QL($%I<B!&;W)C92!"87-E+"!&;"XL($9,)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(W+CDV,3HM.#(N-30P)UT@/2`G
M5&%M<&$L(%1A;7!A($EN=&5R;F%T:6]N86P@06ER<&]R="P@1DPG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C@N,3`S.BTX,"XV-#8G72`]
M("=-96QB;W5R;F4L($UE;&)O=7)N92!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C(Q-SHM
M,3<W+C,V-R==(#T@)U-A;F0@27-L86YD+"!(96YD97)S;VX@1FEE;&0@06ER
M<&]R="P@2$DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,C@N
M,C,S.BTX,"XV,#`G72`]("=#;V-O82`O(%!A=')I8VL@06ER($9O<F-E($)A
M<V4L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S(X+C0Q
M-SHM.#$N,S(U)UT@/2`G3W)L86YD;RP@3W)L86YD;R!);G1E<FYA=&EO;F%L
M($%I<G!O<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S(X+C0V-SHM.#`N-34P)UT@/2`G0V%P92!+96YN961Y+"!&3"<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R."XX-C,Z+3DV+CDS,"==(#T@
M)U9I8W1O<FEA+"!6:6-T;W)I82!296=I;VYA;"!!:7)P;W)T+"!46"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R.2XR-S`Z+3DT+C@V-"==
M(#T@)T=A;'9E<W1O;BP@4V-H;VQE<R!&:65L9"P@5%@G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,CDN,S,S.BTX.2XT,#`G72`]("=";V]T
M:'9I;&QE+"!,02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<R
M.2XS-S4Z+3$P,"XY,C0G72`]("=$96P@4FEO+"!$96P@4FEO($EN=&5R;F%T
M:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,CDN-3,S.BTY."XT-C0G72`]("=386X@06YT;VYI;RP@4V%N($%N
M=&]N:6\@26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<R.2XU-3`Z+3@S+C$P-2==(#T@)T-R;W-S
M($-I='DL($-R;W-S($-I='D@06ER<&]R="P@1DPG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,CDN-S(W.BTX-2XP,C4G72`]("=!<&%L86-H
M:6-O;&$L($%P86QA8VAI8V]L82P@1DPG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,CDN.34Q.BTY-"XP,C$G72`]("="96%U;6]N="`O(%!O
M<G0@07)T:'5R+"!3;W5T:&5A<W0@5&5X87,@4F5G:6]N86P@06ER<&]R="P@
M5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,CDN.3DR.BTY
M-2XS-C0G72`]("=(;W5S=&]N+"!(;W5S=&]N($EN=&5R8V]N=&EN96YT86P@
M06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,CDN.3DS.BTY,"XR-3$G72`]("=.97<@3W)L96%N<RP@3F5W($]R;&5A;G,@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!,02<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S,"XP-C<Z+3@U+C4X,R==(#T@)U1Y;F1A;&P@06ER
M($9O<F-E($)A<V4L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,P+C$R-CHM.3,N,C(S)UT@/2`G3&%K92!#:&%R;&5S+"!,86ME($-H
M87)L97,@4F5G:6]N86P@06ER<&]R="P@3$$G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S`N,38W.BTQ,#(N-#$W)UT@/2`G4V%N9&5R<V]N
M+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XS,S,Z
M+3@Y+C@Q-R==(#T@)U-L:61E;&PL($Q!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,P+C,V-SHM,3`T+C`Q-R==(#T@)TUA<F9A+"!46"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XS.3,Z+3@T+C,U
M,R==(#T@)U1A;&QA:&%S<V5E+"!486QL86AA<W-E92!296=I;VYA;"!!:7)P
M;W)T+"!&3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XT
M,3<Z+3@V+C8X,R==(#T@)TAU<FQB=7)T($9I96QD+"!&3"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,"XT.#,Z+3@V+C4Q-R==(#T@)U9A
M;'!A<F%I<V\@+R!%9VQI;B!!:7(@1F]R8V4@0F%S92P@1DPG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N-#DT.BTX,2XV.3,G72`]("=*
M86-K<V]N=FEL;&4L($IA8VMS;VYV:6QL92!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($9,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,P+C4Q
M,3HM.3DN-S8V)UT@/2`G2G5N8W1I;VXL($MI;6)L92!#;W5N='D@06ER<&]R
M="P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S`N-C@X
M.BTX."XR-#8G72`]("=-;V)I;&4L($UO8FEL92!296=I;VYA;"!!:7)P;W)T
M+"!!3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,"XY-C<Z
M+3@S+C(P,"==(#T@)TUO;V1Y($%I<B!&;W)C92!"87-E+"!'02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XP,S,Z+3DS+C`S,R==(#T@
M)T9O<G0@4&]L:RP@3$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S$N,3`P.BTY-RXS,S,G72`]("=&;W)T($AO;V0L(%18)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C$S,SHM.3(N-38W)UT@/2`G
M0VQA:6)O<FYE(%)A;F=E+"!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!,
M02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XR-3`Z+3@R
M+C0P,"==(#T@)U=A>6-R;W-S("\@5V%R92!#;W5N='DL($=A+"!'02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XS,S4Z+3DR+C4U.2==
M(#T@)T%L97AA;F1R:6$L($%L97AA;F1R:6$@26YT97)N871I;VYA;"!!:7)P
M;W)T+"!,02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XS
M-3$Z+3$P,"XT.30G72`]("=386X@06YG96QO+"!-871H:7,@1FEE;&0L(%18
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C4S-CHM.#0N
M,3DT)UT@/2`G06QB86YY+"!3;W5T:'=E<W0@1V5O<F=I82!296=I;VYA;"!!
M:7)P;W)T+"!'02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M,2XU.#,Z+3$Q,"XS,S,G72`]("=&;W)T($AU86-H=6-A+"!!6B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,2XV,3<Z+3DW+C(R."==(#T@
M)U=A8V\L(%=A8V\@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S$N.#$Q.BTQ,#8N,S<V)UT@/2`G16P@
M4&%S;RP@16P@4&%S;R!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%18)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C@S,3HM,3`T+C@P.2==
M(#T@)U!I;F4@4W!R:6YG<RP@1W5A9&%L=7!E($UO=6YT86EN<R!.871I;VYA
M;"!087)K+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M,2XX-C<Z+3$P-BXW,#`G72`]("=386YT82!497)E<V$L($Y-)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Q+C@X,SHM.#$N-38W)UT@/2`G
M1G0N(%-T97=A<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,Q+CDT.#HM,3`R+C(P.2==(#T@)TUI9&QA;F0L($UI9&QA;F0@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,BXQ,3DZ+3@Q+C(P,B==(#T@)U-A=F%N;F%H+"!3879A
M;FYA:"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,R+C$S,3HM,3$P+CDU-2==(#T@)U1U8W-O
M;BP@5'5C<V]N($EN=&5R;F%T:6]N86P@06ER<&]R="P@05HG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,C$W.BTY."XQ.#,G72`]("=3
M=&5P:&5N=FEL;&4@+R!#;&%R:R!&:65L9"!-=6YI8VEP86PL(%1X+BP@5%@G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S`P.BTX-BXT
M,#8G72`]("=-;VYT9V]M97)Y+"!$86YN96QL>2!&:65L9"P@04PG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S(P.BTY,"XP-S@G72`]
M("=*86-K<V]N+"!*86-K<V]N($EN=&5R;F%T:6]N86P@06ER<&]R="P@35,G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N,S,S.BTX-"XX
M,S,G72`]("=&;W)T($)E;FYI;F<L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,R+C,S.#HM.#@N-S0X)UT@/2`G365R:61I86XL($ME
M>2!&:65L9"P@35,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M,S(N,S@S.BTQ,#8N-#@S)UT@/2`G5VAI=&4@4V%N9',L($Y-)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C,Y,3HM.30N-S$T)UT@/2`G
M3&]N9W9I97<L($=R96=G($-O=6YT>2!!:7)P;W)T+"!46"<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S,BXT,3`Z+3DY+C8X,B==(#T@)T%B
M:6QE;F4L($%B:6QE;F4@4F5G:6]N86P@06ER<&]R="P@5%@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N-#,S.BTQ,3(N-C@S)UT@/2`G
M1VEL82!"96YD(%4N(%,N($%R;7D@06ER9FEE;&0L($%:)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C0T-SHM.3,N.#(T)UT@/2`G4VAR
M979E<&]R="P@4VAR979E<&]R="!296=I;VYA;"!!:7)P;W)T+"!,02<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,BXV,S,Z+3$P."XQ-3`G
M72`]("=3:6QV97(@0VET>2`O($=R86YT+"!.32<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,BXV-3`Z+3$Q-"XV,#`G72`]("=9=6UA("\@
M675M82!);G1E<FYA=&EO;F%L+"!!6B<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,BXV.#@Z+3@S+C8U-"==(#T@)TUA8V]N+"!-:61D;&4@
M1V5O<F=I82!296=I;VYA;"!!:7)P;W)T+"!'02<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S,BXW,S0Z+3$Q-RXQ.#,G72`]("=386X@1&EE
M9V\L(%-A;B!$:65G;R!);G1E<FYA=&EO;F%L+4QI;F1B97)G:"!&:65L9"P@
M0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S(N.#(U.BTQ
M,34N-C8Q)UT@/2`G16P@0V5N=')O+"!.879A;"!!:7(@1F%C:6QI='DL($-!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,R+C@S,SHM.3<N
M,S`P)UT@/2`G1F]R="!7;W)T:"P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S(N.#4P.BTQ,#8N,3`P)UT@/2`G2&]L;&]M86X@06ER
M($9O<F-E($)A<V4L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,R+C@V.#HM,3$W+C$T,R==(#T@)U-A;B!$:65G;RP@36ER86UA<B!-
M0T%3+TUI='-C:&5R($9I96QD($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,R+C@Y-SHM.3<N,#(R)UT@/2`G1&%L;&%S
M("\@1F]R="!7;W)T:"P@1&%L;&%S("\@1F]R="!7;W)T:"!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L(%18)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,R+C@Y.3HM.#`N,#0Q)UT@/2`G0VAA<FQE<W1O;BP@0VAA<FQE<W1O
M;B!!:7(@1F]R8V4@0F%S92P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S(N.3`P.BTX-RXR-3`G72`]("=#96YT<F5V:6QL92P@04PG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N,C,U.BTQ,3DN
M-#4S)UT@/2`G4V%N($YI8VAO;&%S($ES;&%N9"P@0T$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S,N,C,W.BTQ,#<N,C8X)UT@/2`G5')U
M=&@@3W(@0V]N<V5Q=65N8V5S+"!4<G5T:"!/<B!#;VYS97%U96YC97,@375N
M:6-I<&%L($%I<G!O<G0L($Y-)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,S+C,P.#HM,3`T+C4P."==(#T@)U)O<W=E;&PL(%)O<W=E;&P@
M26YD=7-T<FEA;"!!:7(@0V5N=&5R($%I<G!O<G0L($Y-)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+C,V-#HM.#$N.38S)UT@/2`G075G
M=7-T82P@0G5S:"!&:65L9"P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S,N-#`U.BTQ,3@N-#$V)UT@/2`G079A;&]N+"!#871A;&EN
M82!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<S,RXT,S0Z+3$Q,BXP-3$G72`]("=0:&]E;FEX+"!0:&]E;FEX(%-K>2!(
M87)B;W(@26YT97)N871I;VYA;"!!:7)P;W)T+"!!6B<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S,RXU-C8Z+3@V+C<T-2==(#T@)T)I<FUI
M;F=H86TL($)I<FUI;F=H86T@26YT97)N871I;VYA;"!!:7)P;W)T+"!!3"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXV,S`Z+3@T+C0T
M,B==(#T@)T%T;&%N=&$L($AA<G1S9FEE;&0@071L86YT82!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,S+C8V-SHM,3`Q+C@R,2==(#T@)TQU8F)O8VLL($QU8F)O8VL@26YT
M97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,RXV.#,Z+3<X+CDS,R==(#T@)TUY<G1L92!"96%C:"!!
M:7(@1F]R8V4@0F%S92P@4T,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S,N.#$R.BTQ,3@N,30V)UT@/2`G3&]N9R!"96%C:"P@3&]N9R!"
M96%C:"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S,RXX-3`Z+3@P+C0X,R==(#T@)U!O:6YS971T(%)A;F=E+"!3=6UP
M=&5R+"!30R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXY
M,#`Z+3$P-BXT,#`G72`]("=.;W)T:')U<"!,86YD:6YG(%-T<FEP+"!.32<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S,RXY,#`Z+3$Q-RXR
M-3`G72`]("=2:79E<G-I9&4@+R!-87)C:"!!:7(@1F]R8V4@0F%S92P@0T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.3$W.BTX-"XU
M,3<G72`]("=-87)I971T82`O($1O8F)I;G,@06ER($9O<F-E($)A<V4L($=!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,S+CDS.#HM,3$X
M+C,X.2==(#T@)TQO<R!!;F=E;&5S+"!,;W,@06YG96QE<R!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,S+CDT,CHM.#$N,3$X)UT@/2`G0V]L=6UB:6$L($-O;'5M8FEA($UE
M=')O<&]L:71A;B!!:7)P;W)T+"!30R<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S,RXY-3$Z+3@S+C,R."==(#T@)T%T:&5N<RP@071H96YS
M($%I<G!O<G0L($=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S,S+CDV-SHM.#`N-#@S)UT@/2`G4VAA=R!!:7(@1F]R8V4@0F%S92P@4T,G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S,N.3<Y.BTY."XT
M.3,G72`]("=7:6-H:71A($9A;&QS+"!3:&5P<&%R9"!!:7(@1F]R8V4@0F%S
M92P@5%@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N,#$W
M.BTQ,#8N.3`P)UT@/2`G4V]C;W)R;R!-=6YI8VEP86PL($Y-)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C$R-#HM,3$Y+C$R,B==(#T@
M)U!O:6YT($UU9W4L($YA=F%L($%I<B!787)F87)E($-E;G1E<BP@0T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N,C`P.BTQ,3@N,S8U
M)UT@/2`G0G5R8F%N:RP@0G5R8F%N:RU';&5N9&%L92U087-A9&5N82!!:7)P
M;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XR
M,S,Z+3$Q."XP-C<G72`]("=-;W5N="!7:6QS;VXL($-!)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C(V.#HM.#@N-S<P)UT@/2`G5'5P
M96QO+"!4=7!E;&\@4F5G:6]N86P@06ER<&]R="P@35,G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S0N,S`P.BTQ,#,N.#`P)UT@/2`G365L
M<F]S92!'=6YN97)Y(%)A;F=E+"!.32<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-"XS-#@Z+3@U+C$V,2==(#T@)U)O;64L(%(N($(N(%)U
M<W-E;&P@06ER<&]R="P@1T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T
M97,G75LG,S0N-3$W.BTY-BXY.#,G72`]("=3=6QP:'5R($UU;FEC:7!A;"P@
M3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-C`P.BTY
M."XT,#`G72`]("=&;W)T(%-I;&PL($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,T+C8S,#HM,3$X+C`X,2==(#T@)U!A;&UD86QE+"!0
M86QM9&%L92!0<F]D=6-T:6]N($9L:6=H="!0;&%N="P@0T$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-C0T.BTX-BXW.#8G72`]("=(
M=6YT<W9I;&QE+"!(=6YT<W9I;&QE($EN=&5R;F%T:6]N86P@+R!*;VYE<R!&
M:65L9"P@04PG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N
M-C4P.BTY.2XR-C<G72`]("=!;'1U<R!!:7(@1F]R8V4@0F%S92P@3TLG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S0N-S,Y.BTY,BXR-S@G
M72`]("=,:71T;&4@4F]C:RP@2&5I9VAT<RP@05(G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S0N-S0T.BTQ,3@N-S(T)UT@/2`G4V%N9&)E
M<F<L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C<U
M,#HM,3(P+C4V-R==(#T@)U9A;F1E;F)E<F<@06ER($9O<F-E($)A<V4L($-!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+C<X,SHM-S8N
M.#@S)UT@/2`G3F5W<&]R="P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S0N.#,S.BTY,BXR-3`G72`]("=.;W)T:"!,:71T;&4@4F]C
M:RP@3F]R=&@@3&ET=&QE(%)O8VL@06ER<&]R="P@05(G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S0N.#@T.BTX,BXR,C$G72`]("='<F5E
M<BP@1W)E96YV:6QL92U3<&%R=&%N8G5R9R!!:7)P;W)T+"!30R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XX.3@Z+3<V+C@X,2==(#T@
M)T-H97)R>2!0;VEN="P@36%R:6YE($-O<G!S($%I<B!3=&%T:6]N+"!.0R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-"XX.3DZ+3$R,"XT
M-#DG72`]("=386YT82!-87)I82P@4V%N=&$@36%R:6$@4'5B;&EC($%I<G!O
M<G0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,T+CDQ
M-SHM,3$W+CDP,"==(#T@)T5D=V%R9',@06ER($9O<F-E($)A<V4L($-!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C`R.#HM,3$P+C<R
M,2==(#T@)U=I;G-L;W<L(%=I;G-L;W<@375N:6-I<&%L($%I<G!O<G0L($%:
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C`S,SHM.#4N
M,C`P)UT@/2`G0VAA='1A;F]O9V$L($QO=F5L;"!&:65L9"P@5$XG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,#0R.BTQ,#8N-C$U)UT@
M/2`G06QB=7%U97)Q=64L($%L8G5Q=65R<75E($EN=&5R;F%T:6]N86P@06ER
M<&]R="P@3DTG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N
M,#8Q.BTX.2XY.#4G72`]("=-96UP:&ES+"!-96UP:&ES($EN=&5R;F%T:6]N
M86P@06ER<&]R="P@5$XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S4N,3,S.BTW."XY,S,G72`]("=&;W)T($)R86=G("\@4VEM;6]N<R!!
M<FUY($%I<F9I96QD+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-2XQ-3`Z+3<U+C,P,"==(#T@)T1I86UO;F0@4VAO86QS($-O87-T
M($=U87)D(%-T871I;VXL($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,U+C$V-SHM-SDN,#,S)UT@/2`G4&]P92!!:7(@1F]R8V4@0F%S
M92P@3D,G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N,C$S
M.BTX,"XY-#DG72`]("=#:&%R;&]T=&4L($-H87)L;W1T92`O($1O=6=L87,@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!.0R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-2XR,3<Z+3DW+C0U,"==(#T@)TYO<FUA;B`O($UA
M>"!797-T:&5I;65R+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<S-2XR,C`Z+3$P,2XW,3<G72`]("=!;6%R:6QL;RP@06UA<FEL;&\@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!46"<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-2XR-3@Z+3$Q,RXY,S,G72`]("=+:6YG;6%N+"!+
M:6YG;6%N($%I<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,U+C(U.3HM.3,N,#DS)UT@/2`G4G5S<V5L;'9I;&QE+"!2=7-S
M96QL=FEL;&4@4F5G:6]N86P@06ER<&]R="P@05(G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S4N,C8W.BTQ,3<N-#,S)UT@/2`G0W5D9&QE
M8F%C:R!'=6YN97)Y(%)A;F=E+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-2XR-C<Z+3<U+C4U,"==(#T@)T-A<&4@2&%T=&5R87,L
M($Y#)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C(X,SHM
M,3$V+C8Q-R==(#T@)T)I8WEC;&4@3&%K92!5+B!3+B!!<FUY($%I<F9I96QD
M+"!#82P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N
M,S,T.BTY-"XS-C4G72`]("=&;W)T(%-M:71H+"!&;W)T(%-M:71H(%)E9VEO
M;F%L($%I<G!O<G0L($%2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,U+C,X.3HM.3<N-C`P)UT@/2`G3VML86AO;6$@0VET>2P@5VEL;"!2
M;V=E<G,@5V]R;&0@06ER<&]R="P@3TLG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S4N-#`P.BTY-BXP,3<G72`]("=(96YR>65T=&$@375N
M:6-I<&%L+"!/2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M-2XT,3<Z+3DW+C,X,R==(#T@)U1I;FME<B!!:7(@1F]R8V4@0F%S92P@3TLG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N-#,R.BTX,BXU
M,S<G72`]("=!<VAE=FEL;&4L($%S:&5V:6QL92!296=I;VYA;"!!:7)P;W)T
M+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XT,S0Z
M+3$Q.2XP-3<G72`]("="86ME<G-F:65L9"P@365A9&]W<R!&:65L9"!!:7)P
M;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-2XV
M-3`Z+3$P.2XP-C<G72`]("=7:6YD;W<@4F]C:RP@5VEN9&]W(%)O8VL@06ER
M<&]R="P@05HG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N
M-C8V.BTQ,C$N,C@U)UT@/2`G4&]I;G0@4&EE9')A<R!";&%N8V$L($-!)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C8V-SHM-S4N.3`P
M)UT@/2`G1&%R92!#;W5N='D@1W5N;F5R>2!286YG92P@3D,G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S4N-C@V.BTQ,3<N-CDP)UT@/2`G
M0VAI;F$@3&%K92P@3F%V86P@06ER($9A8VEL:71Y+"!#02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-2XX,3@Z+3@S+CDX-B==(#T@)TMN
M;WAV:6QL92P@36-':&5E(%1Y<V]N($%I<G!O<G0L(%1.)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,U+C@W,3HM-S@N-S@V)UT@/2`G4F%L
M96EG:"`O($1U<FAA;2P@4F%L96EG:"U$=7)H86T@26YT97)N871I;VYA;"!!
M:7)P;W)T+"!.0R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M-BXP-SDZ+3$Q-2XQ-34G72`]("=,87,@5F5G87,L($UC0V%R<F%N($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@3E8G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S8N,#DX.BTW.2XY-#0G72`]("='<F5E;G-B;W)O+"!0:65D
M;6]N="!4<FEA9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y#)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C$Q.3HM.#8N-C@Y)UT@/2`G
M3F%S:'9I;&QE+"!.87-H=FEL;&4@26YT97)N871I;VYA;"!!:7)P;W)T+"!4
M3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXQ.3<Z+3DU
M+C@X-B==(#T@)U1U;'-A+"!4=6QS82!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,V+C,P-#HM
M,3$Y+CDS."==(#T@)TQE;6]O<F4L($YA=F%L($%I<B!3=&%T:6]N+"!#02<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-BXS,S,Z+3$Q-RXQ
M,#`G72`]("=3=7!E<FEO<B!686QL97D@1W5N;F5R>2!286YG92P@0T$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S8N-#,S.BTY-BXS.#,G
M72`]("=(;VUI;GD@375N:6-I<&%L+"!/2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S-BXT,S<Z+3DY+C4R,2==(#T@)U=O;V1W87)D+"!7
M97-T(%=O;V1W87)D($%I<G!O<G0L($]+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,V+C0T.#HM,3`S+C$U,R==(#T@)T-L87ET;VXL($-L
M87ET;VX@375N:6-I<&%L($%I<G!A<FLL($Y-)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,V+C4S,SHM,3$U+CDP,"==(#T@)TEN9&EA;B!3
M<')I;F=S($=U;FYE<GD@4F%N9V4L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,V+C8R,3HM,3$V+C`R."==(#T@)TUE<F-U<GDL($1E
M<V5R="!2;V-K($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,V+C8V-SHM.#<N-3`P)UT@/2`G1F]R="!#86UP8F5L;"!5
M+B!3+B!!<FUY($%I<F9I96QD+"!+62<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<S-BXW.#`Z+3$Q.2XW,3DG72`]("=&<F5S;F\L($9R97-N
M;R!!:7(@5&5R;6EN86PL($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,V+CDP-#HM-S8N,3DR)UT@/2`G3F]R9F]L:RP@3F]R9F]L:R!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,V+CDR,3HM,3$Q+C0T."==(#T@)U!A9V4L(%!A9V4@
M375N:6-I<&%L($%I<G!O<G0L($%:)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C`P,#HM,3`Q+C@X,R==(#T@)T5L:VAA<G0@+R!%;&MH
M87)T+4UO<G1O;B!#;W5N='D@06ER<&]R="P@2U,G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S<N,#4V.BTX."XW-S0G72`]("=0861U8V%H
M+"!"87)K;&5Y(%)E9VEO;F%L($%I<G!O<G0L($M9)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,W+C`X,SHM-S8N,S4P)UT@/2`G3&%N9VQE
M>2!!:7(@1F]R8V4@0F%S92P@5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S<N,C0P.BTY,RXS.3`G72`]("=3<')I;F=F:65L9"P@4W!R
M:6YG9FEE;&0@4F5G:6]N86P@06ER<&]R="P@34\G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S<N,C@T.BTY."XU-3,G72`]("=-961I8VEN
M92!,;V1G92P@365D:6-I;F4@3&]D9V4L($M3)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,W+C,Q-SHM-SDN.3<T)UT@/2`G4F]A;F]K92P@
M4F]A;F]K92!296=I;VYA;"!!:7)P;W)T+"!602<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<S-RXS,C$Z+3<Y+C(P-R==(#T@)TQY;F-H8G5R
M9RP@3'EN8VAB=7)G(%)E9VEO;F%L($%I<G!O<G0L(%9!)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,W+C,V-SHM,3(P+C4V-R==(#T@)TUE
M<F-E9"`O($-A<W1L92!!:7(@1F]R8V4@0F%S92P@0T$G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S<N,S<Q.BTQ,3@N,S4X)UT@/2`G0FES
M:&]P+"!":7-H;W`@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,S<N-#`V.BTQ,C(N,#0X)UT@/2`G36]U;G1A:6X@5FEE
M=RP@36]F9F5T="!&:65L9"P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S<N-#,Y.BTQ,#4N.#8Q)UT@/2`G06QA;6]S82P@4V%N($QU
M:7,@5F%L;&5Y(%)E9VEO;F%L($%I<G!O<G0L($-/)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,W+C4Q,3HM-S<N,S(S)UT@/2`G4FEC:&UO
M;F0L(%)I8VAM;VYD($EN=&5R;F%T:6]N86P@06ER<&]R="P@5D$G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S<N-C$R.BTQ,30N-3(V)UT@
M/2`G0V%L:65N=&4L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,W+C8R,#HM,3(R+C,V-2==(#T@)U-A;B!&<F%N8VES8V\L(%-A;B!&
M<F%N8VES8V\@26YT97)N871I;VYA;"!!:7)P;W)T+"!#02<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S-RXV-#<Z+3DW+C0R.2==(#T@)U=I
M8VAI=&$L(%=I8VAI=&$@36ED+4-O;G1I;F5N="!!:7)P;W)T+"!+4R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW,#`Z+3$R,RXP,#`G
M72`]("=&87)A;&QO;B!)<VQA;F0L($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S,W+C<P,#HM.3@N-S4P)UT@/2`G4')A='0@375N:6-I
M<&%L+"!+4R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXW
M,3DZ+3$R,BXR,S4G72`]("=/86ML86YD+"!-971R;R!/86ML86YD($EN=&5R
M;F%T:6]N86P@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG,S<N-S<S.BTY.2XY-S`G72`]("=$;V1G92!#:71Y+"!$;V1G
M92!#:71Y(%)E9VEO;F%L($%I<G!O<G0L($M3)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S,W+C<X,SHM,3(R+C,Q-R==(#T@)T%L86UE9&$@
M3F%V86P@06ER(%-T871I;VXL($-!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,W+C<Y-3HM.#$N,3(U)UT@/2`G0F5C:VQE>2P@4F%L96EG
M:"!#;W5N='D@365M;W)I86P@06ER<&]R="P@5U8G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S<N.#DP.BTQ,C$N,C(T)UT@/2`G4W1O8VMT
M;VXL(%-T;V-K=&]N($UE=')O<&]L:71A;B!!:7)P;W)T+"!#02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S-RXY,#`Z+3@U+CDV-R==(#T@
M)T9O<G0@2VYO>"P@2UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG,S<N.30Q.BTW-2XT-C,G72`]("=786QL;W!S($ES;&%N9"P@5V%L;&]P
M<R!&;&EG:'0@1F%C:6QI='D@06ER<&]R="P@5D$G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S@N,#0Q.BTX-"XV,#8G72`]("=,97AI;F=T
M;VXL($)L=64@1W)A<W,@06ER<&]R="P@2UDG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,S@N,#0S.BTX-RXU,C`G72`]("=%=F%N<W9I;&QE
M+"!%=F%N<W9I;&QE(%)E9VEO;F%L($%I<G!O<G0L($E.)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C$W-SHM.#4N-S,P)UT@/2`G3&]U
M:7-V:6QL92P@4W1A;F1I9F]R9"!&:65L9"P@2UDG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG,S@N,C8W.BTQ,C$N.34P)UT@/2`G1F%I<F9I
M96QD("\@5')A=FES($%I<B!&;W)C92!"87-E+"!#02<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S."XR-SDZ+3<V+C0Q-"==(#T@)U!A='5X
M96YT(%)I=F5R+"!.879A;"!!:7(@4W1A=&EO;BP@340G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S@N,CDP.BTQ,#0N-#DX)UT@/2`G4'5E
M8FQO+"!0=65B;&\@365M;W)I86P@06ER<&]R="P@0T\G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S@N,S,S.BTW-2XP.#,G72`]("=/8V5A
M;B!#:71Y+"!-1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M."XS-C4Z+3@R+C4U-2==(#T@)TAU;G1I;F=T;VXL(%1R:2U3=&%T92!!:7)P
M;W)T+"!75B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XS
M-SDZ+3@Q+C4Y,2==(#T@)T-H87)L97-T;VXL(%EE86=E<B!!:7)P;W)T+"!7
M5B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XU,#<Z+3$R
M,2XT.34G72`]("=386-R86UE;G1O+"!386-R86UE;G1O($5X96-U=&EV92!!
M:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M."XV-#,Z+3@X+CDV-"==(#T@)U-A;&5M+"!386QE;2U,96-K<F]N92!!:7)P
M;W)T+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S."XW
M,#`Z+3$P-"XW-C<G72`]("=&;W)T($-A<G-O;BP@0T\G.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,S@N-S4R.BTY,"XS-S0G72`]("=3="X@
M3&]U:7,L($QA;6)E<G0M4W0N($QO=6ES($EN=&5R;F%T:6]N86P@06ER<&]R
M="P@34\G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.#$V
M.BTQ,#0N-S$Q)UT@/2`G0V]L;W)A9&\@4W!R:6YG<RP@0VET>2!/9B!#;VQO
M<F%D;R!3<')I;F=S($UU;FEC:7!A;"!!:7)P;W)T+"!#3R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S."XX,3<Z+3<V+C@U,"==(#T@)T-A
M;7`@4W!R:6YG<R`O($%N9')E=W,@06ER($9O<F-E($)A<V4L($U$)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@Q-SHM.3(N,C$X)UT@
M/2`G0V]L=6UB:6$L($-O;'5M8FEA(%)E9VEO;F%L($%I<G!O<G0L($U/)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@T.#HM-S<N,#,T
M)UT@/2`G5V%S:&EN9W1O;B!$0RP@4F5A9V%N($YA=&EO;F%L($%I<G!O<G0L
M(%9!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,X+C@X-3HM
M-SDN.#4S)UT@/2`G16QK:6YS+"!%;&MI;G,M4F%N9&]L<&@@0V]U;G1Y+4IE
M;FYI;F=S(%)A;F1O;'!H($9I96QD+"!75B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<S."XY,S4Z+3<W+C0T."==(#T@)U=A<VAI;F=T;VX@
M1$,L(%=A<VAI;F=T;VXM1'5L;&5S($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M5D$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,S@N.38W.BTQ
M,#0N.#$W)UT@/2`G06ER($9O<F-E($%C861E;7DL($-/)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C`T,SHM.#0N-C<R)UT@/2`G0V]V
M:6YG=&]N("\@0VEN8VEN;F%T:2P@0VEN8VEN;F%T:2`O($YO<G1H97)N($ME
M;G1U8VMY($EN=&5R;F%T:6]N86P@06ER<&]R="P@2UDG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG,SDN,#<S.BTY-2XV,C8G72`]("=4;W!E
M:V$L(%!H:6QI<"!":6QL87)D($UU;FEC:7!A;"!!:7)P;W)T+"!+4R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XQ,#`Z+3DV+C<V-R==
M(#T@)T9O<G0@4FEL97DL($M3)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S,Y+C$S-#HM,3`X+C4S.2==(#T@)T=R86YD($IU;F-T:6]N+"!7
M86QK97(@1FEE;&0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,Y+C$V-SHM-S8N-C@S)UT@/2`G0F%L=&EM;W)E+"!"86QT:6UO<F4M
M5V%S:&EN9W1O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U$)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S,Y+C(Y-3HM,3$T+C@T-2==(#T@
M)T5L>2P@16QY($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S,Y+C(Y-SHM.30N-S,Q)UT@/2`G2V%N<V%S($-I='DL($MA
M;G-A<R!#:71Y($EN=&5R;F%T:6]N86P@06ER<&]R="P@34\G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN,S8W.BTQ,#$N-CDS)UT@/2`G
M1V]O9&QA;F0L(%)E;FYE<B!&:65L9"P@2U,G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG,SDN-#`P.BTQ,C,N.#$W)UT@/2`G1F]R="!"<F%G
M9RP@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-#8U
M.BTW-"XU.#<G72`]("=!=&QA;G1I8R!#:71Y+"!!=&QA;G1I8R!#:71Y($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@3DHG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,SDN-#@T.BTQ,3DN-S<Q)UT@/2`G4F5N;RP@4F5N;R!4
M86AO92!);G1E<FYA=&EO;F%L($%I<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S,Y+C4U,3HM.3<N-C4Q)UT@/2`G0V]N8V]R
M9&EA+"!";&]S<V5R($UU;FEC:7!A;"!!:7)P;W)T+"!+4R<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<S.2XV,#DZ+3$Q,"XW-34G72`]("=0
M<FEC92P@0V%R8F]N($-O=6YT>2!!:7)P;W)T+"!55"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<S.2XW,C4Z+3@V+C(X,B==(#T@)TEN9&EA
M;F%P;VQI<RP@26YD:6%N87!O;&ES($EN=&5R;F%T:6]N86P@06ER<&]R="P@
M24XG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN-S8W.BTW
M-"XQ,#`G72`]("="87)N96=A="!#;V%S="!'=6%R9"!3=&%T:6]N+"!.2B<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XW-C@Z+3DT+CDP
M.2==(#T@)U-T+B!*;W-E<&@L(%)O<V5C<F%N<R!-96UO<FEA;"!!:7)P;W)T
M+"!-3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XW.#,Z
M+3$P-"XX-C<G72`]("=$96YV97(@+R!3=&%P;&5T;VX@26YT97)N871I;VYA
M;"P@0V\N+"!#3R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S
M.2XX,S,Z+3$P-"XV-3<G72`]("=$96YV97(L($1E;G9E<B!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L($-/)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S,Y+C@S,SHM.#0N,#4P)UT@/2`G1&%Y=&]N("\@5W)I9VAT+5!A='1E
M<G-O;B!!:7(@1F]R8V4@0F%S92P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG,SDN.#0U.BTX.2XV.#0G72`]("=3<')I;F=F:65L9"P@
M0V%P:71A;"!!:7)P;W)T+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<S.2XX-C@Z+3<U+C(S,2==(#T@)U!H:6QA9&5L<&AI82P@4&AI
M;&%D96QP:&EA($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG,SDN.3`V.BTX-"XR,3DG72`]("=$
M87ET;VXL($-O>"!$87ET;VX@26YT97)N871I;VYA;"!!:7)P;W)T+"!/2"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<S.2XY.34Z+3@R+C@W
M-B==(#T@)T-O;'5M8G5S+"!0;W)T($-O;'5M8G5S($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@3T@G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#`N,#,S.BTW-"XS,3<G72`]("=,86ME:'5R<W0@3F%V86P@06ER(%-T871I
M;VXL($Y*)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C$U
M,3HM,3(R+C(U,B==(#T@)U)E9"!";'5F9BP@4F5D($)L=69F($UU;FEC:7!A
M;"!!:7)P;W)T+"!#02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,"XQ-C<Z+3$Q,BXY,S,G72`]("=$=6=W87D@4')O=FEN9R!'<F]U;F1S
M+"!55"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XR-3`Z
M+3DS+C<Q-R==(#T@)U-P:6-K87)D+"!-3R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,"XS,#`Z+3$P.2XY.#,G72`]("=2;V]S979E;'0L
M(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C0Y,SHM
M,3`W+C4R-"==(#T@)T-R86EG+"!#<F%I9RU-;V9F870@06ER<&]R="P@0T\G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N-3`T.BTX,"XR
M-C8G72`]("=0:71T<V)U<F=H+"!0:71T<V)U<F=H($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@4$$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#`N-3$U.BTQ,C(N,CDW)UT@/2`G4F5D9&EN9RP@4F5D9&EN9R!-=6YI8VEP
M86P@06ER<&]R="P@0T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#`N-C,Y.BTW,RXW-C(G72`]("=.97<@66]R:RP@2V5N;F5D>2!);G1E
M<FYA=&EO;F%L($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0P+C8U,3HM-S4N-#0Y)UT@/2`G06QL96YT;W=N+"!,96AI
M9V@@5F%L;&5Y($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#`N-C8W.BTX.2XV.#0G72`]("=0
M96]R:6$L($=R96%T97(@4&5O<FEA(%)E9VEO;F%L($%I<G!O<G0L($E,)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C8X,CHM-S0N,38Y
M)UT@/2`G3F5W87)K+"!.97=A<FL@26YT97)N871I;VYA;"!!:7)P;W)T+"!.
M2B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XW,S,Z+3$Q
M-"XP,S,G72`]("=796YD;W9E<B`O($%I<B!&;W)C92!!=7AI;&QA<GD@1FEE
M;&0L(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+C<W
M.#HM,3$Q+CDV.2==(#T@)U-A;'0@3&%K92!#:71Y+"!386QT($QA:V4@0VET
M>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%54)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0P+C<W.3HM-S,N.#@P)UT@/2`G3F5W(%EO<FLL
M($QA($=U87)D:6$@06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#`N.#`P.BTQ,C0N,38W)UT@/2`G175R96MA+"!#02<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,"XX,S$Z+3DV+C<V
M-"==(#T@)TQI;F-O;&XL($QI;F-O;&X@375N:6-I<&%L($%I<G!O<G0L($Y%
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P+CDP,CHM,3$W
M+C@P-R==(#T@)U=I;FYE;75C8V$L(%=I;FYE;75C8V$@375N:6-I<&%L($%I
M<G!O<G0L($Y6)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0P
M+CDQ.#HM.#$N-#0S)UT@/2`G06MR;VXL($%K<F]N+4-A;G1O;B!296=I;VYA
M;"!!:7)P;W)T+"!/2"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,"XY-3@Z+3DX+C,Q,R==(#T@)T=R86YD($ES;&%N9"P@0V5N=')A;"!.
M96)R87-K82!296=I;VYA;"!!:7)P;W)T+"!.12<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T,"XY-S@Z+3@U+C$Y-2==(#T@)T9O<G0@5V%Y
M;F4L($9O<G0@5V%Y;F4@26YT97)N871I;VYA;"!!:7)P;W)T+"!)3B<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XP.3DZ+3$P,BXY.#8G
M72`]("=3:61N97DL(%-I9&YE>2!-=6YI8VEP86P@06ER<&]R="P@3D4G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,3$W.BTY-2XY,#`G
M72`]("=/;6%H82`O($]F9G5T="!!:7(@1F]R8V4@0F%S92P@3D4G.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,3(R.BTQ,#`N-C8X)UT@
M/2`G3F]R=&@@4&QA='1E+"!.;W)T:"!0;&%T=&4@4F5G:6]N86P@06ER<&]R
M="P@3D4G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,34X
M.BTQ,#0N.#`W)UT@/2`G0VAE>65N;F4L($-H97EE;FYE($%I<G!O<G0L(%=9
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C$U.#HM-S,N
M,3(Y)UT@/2`G0G)I9&=E<&]R="P@4VEK;W)S:WD@365M;W)I86P@06ER<&]R
M="P@0U0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,3DT
M.BTQ,3(N,#$V)UT@/2`G3V=D96XL($]G9&5N+4AI;F-K;&5Y($%I<G!O<G0L
M(%54)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C(T,SHM
M-S8N.3(R)UT@/2`G5VEL;&EA;7-P;W)T+"!7:6QL:6%M<W!O<G0M3'EC;VUI
M;F<@0V]U;G1Y($%I<G!O<G0L(%!!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0Q+C(U-#HM.#`N-C<T)UT@/2`G66]U;F=S=&]W;BP@66]U
M;F=S=&]W;BU787)R96X@4F5G:6]N86P@06ER<&]R="P@3T@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,S$P.BTY-2XX.3DG72`]("=/
M;6%H82P@17!P;&5Y($%I<F9I96QD+"!.12<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,2XS,3<Z+3DV+C,V-R==(#T@)U9A;&QE>2P@3D4G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N,S,Y.BTW-2XW
M,C<G72`]("=7:6QK97,M0F%R<F4@+2!38W)A;G1O;BP@5VEL:V5S+4)A<G)E
M("\@4V-R86YT;VX@26YT97)N871I;VYA;"!!:7)P;W)T+"!002<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XS-C<Z+3@X+C8X,R==(#T@
M)TUA<G-E:6QL97,@27-L86YD+"!)3"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,2XT,#4Z+3@Q+C@U,R==(#T@)T-L979E;&%N9"P@0VQE
M=F5L86YD+4AO<&MI;G,@26YT97)N871I;VYA;"!!:7)P;W)T+"!/2"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XT-3$Z+3DP+C4Q-2==
M(#T@)TUO;&EN92P@475A9"U#:71Y($%I<G!O<G0L($E,)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C4S.#HM.3,N-C8V)UT@/2`G1&5S
M($UO:6YE<RP@1&5S($UO:6YE<R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($E!
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C4X.3HM.#,N
M.#`Q)UT@/2`G5&]L961O+"!4;VQE9&\@17AP<F5S<R!!:7)P;W)T+"!/2"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,2XU.30Z+3$P.2XP
M-C4G72`]("=2;V-K(%-P<FEN9W,L(%)O8VL@4W!R:6YG<RU3=V5E='=A=&5R
M($-O=6YT>2!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,2XV-3`Z+3<P+C4Q-R==(#T@)T]T:7,@06ER($YA=&EO;F%L
M($=U87)D($)A<V4L($U!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0Q+C8V-SHM-CDN.38W)UT@/2`G0VAA=&AA;2P@34$G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N-S`Y.BTX-BXS,3DG72`]("=3
M;W5T:"!"96YD+"!3;W5T:"!"96YD(%)E9VEO;F%L($%I<G!O<G0L($E.)SL*
M)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C<R-#HM-S$N-#(X
M)UT@/2`G4')O=FED96YC92P@5&AE;V1O<F4@1G)A;F-I<R!'<F5E;B!3=&%T
M92!!:7)P;W)T+"!222<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T,2XW.#0Z+3@W+C<U-2==(#T@)T-H:6-A9V\L($-H:6-A9V\@36ED=V%Y
M($%I<G!O<G0L($E,)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0Q+C@V-SHM,3`S+C4X-B==(#T@)U-C;W1T<V)L=69F+"!(96EL:6<@1FEE
M;&0L($Y%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0Q+C@X
M,SHM.3$N-S(T)UT@/2`G0V5D87(@4F%P:61S+"!#961A<B!287!I9',@375N
M:6-I<&%L($%I<G!O<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0Q+CDS.#HM-S(N-C@S)UT@/2`G5VEN9'-O<B!,;V-K<RP@0G)A
M9&QE>2!);G1E<FYA=&EO;F%L($%I<G!O<G0L($-4)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0Q+CDX,#HM.#<N.3`T)UT@/2`G0VAI8V%G
M;RP@0VAI8V%G;RU/7"=(87)E($EN=&5R;F%T:6]N86P@06ER<&]R="P@24PG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#$N.3@Q.BTY-RXT
M,S<G72`]("=.;W)F;VQK+"!3=&5F86X@365M;W)I86P@06ER<&]R="P@3D4G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,#@P.BTX,"XQ
M.#,G72`]("=%<FEE+"!%<FEE($EN=&5R;F%T:6]N86P@06ER<&]R="P@4$$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N,3DS.BTX.2XP
M.3,G72`]("=2;V-K9F]R9"P@1W)E871E<B!2;V-K9F]R9"!!:7)P;W)T+"!)
M3"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXR,#`Z+3<R
M+C4S,R==(#T@)T-H:6-O<&5E($9A;&QS("\@5V5S=&]V97(@06ER($9O<F-E
M($)A<V4L($U!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R
M+C(P.#HM-S4N.3@Q)UT@/2`G0FEN9VAA;71O;BP@0FEN9VAA;71O;B!296=I
M;VYA;"!!:7)P;W)T+"!.62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,BXR,S$Z+3@S+C,S,2==(#T@)T1E=')O:70L($1E=')O:70@365T
M<F]P;VQI=&%N(%=A>6YE($-O=6YT>2!!:7)P;W)T+"!-22<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T,BXS-C$Z+3<Q+C`Q,2==(#T@)T)O
M<W1O;BP@3&]G86X@26YT97)N871I;VYA;"!!:7)P;W)T+"!-02<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXS.#$Z+3$R,BXX-S(G72`]
M("=-961F;W)D+"!2;V=U92!686QL97D@26YT97)N871I;VYA;"!!:7)P;W)T
M+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXS.3@Z
M+3DP+C<P-"==(#T@)T1U8G5Q=64L($1U8G5Q=64@4F5G:6]N86P@06ER<&]R
M="P@24$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N-#`R
M.BTY-BXS.#0G72`]("=3:6]U>"!#:71Y+"!3:6]U>"!'871E=V%Y($%I<G!O
M<G0L($E!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C0V
M.#HM-S$N,CDT)UT@/2`G0F5D9F]R9"P@2&%N<V-O;2!&:65L9"P@34$G.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#(N-34P.BTY-"XQ.#,G
M72`]("=&;W)T($1O9&=E+"!)02<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<T,BXU-30Z+3DR+C0P,2==(#T@)U=A=&5R;&]O+"!7871E<FQO
M;R!-=6YI8VEP86P@06ER<&]R="P@24$G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#(N-3<Y.BTQ,3`N,3`S)UT@/2`G0FEG(%!I;F5Y+"!"
M:6<@4&EN97DM36%R8FQE=&]N($%I<G!O<G0L(%=9)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0R+C<T-SHM-S,N-SDY)UT@/2`G06QB86YY
M+"!!;&)A;GD@0V]U;G1Y($%I<G!O<G0L($Y9)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0R+C<X,#HM.#0N-3<Y)UT@/2`G3&%N<VEN9RP@
M0V%P:71A;"!#:71Y($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0R+C<Y-#HM,3`U+C,X,B==(#T@)T1O=6=L87,L($-O
M;G9E<G-E($-O=6YT>2!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T,BXX,34Z+3$P."XW,C@G72`]("=,86YD97(L(%=9
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0R+C@U.3HM,3`P
M+C4U,2==(#T@)U9A;&5N=&EN92P@36EL;&5R($9I96QD+"!.12<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXX.#$Z+3@U+C4R,R==(#T@
M)T=R86YD(%)A<&ED<RP@1V5R86QD(%(N($9O<F0@26YT97)N871I;VYA;"!!
M:7)P;W)T+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T
M,BXX.3@Z+3$P-BXT-S,G72`]("=#87-P97(L($YA=')O;F$@0V]U;G1Y($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#(N.3(P.BTQ,3(N-3<Q)UT@/2`G4&]C871E;&QO+"!0
M;V-A=&5L;&\@4F5G:6]N86P@06ER<&]R="P@240G.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-#(N.30Q.BTW."XW,S8G72`]("="=69F86QO
M+"!'<F5A=&5R($)U9F9A;&\@26YT97)N871I;VYA;"!!:7)P;W)T+"!.62<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,BXY-34Z+3@W+CDP
M-"==(#T@)TUI;'=A=6ME92P@1V5N97)A;"!-:71C:&5L;"!);G1E<FYA=&EO
M;F%L($%I<G!O<G0L(%=))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0R+CDV-SHM.#,N-S0Y)UT@/2`G1FQI;G0L($)I<VAO<"!);G1E<FYA
M=&EO;F%L($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0S+C`V,CHM,3`X+C0T-B==(#T@)U)I=F5R=&]N+"!2:79E<G1O
M;B!296=I;VYA;"!!:7)P;W)T+"!762<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,RXQ,#DZ+3<V+C$P,R==(#T@)U-Y<F%C=7-E+"!3>7)A
M8W5S92!(86YC;V-K($EN=&5R;F%T:6]N86P@06ER<&]R="P@3EDG.PHD8V]O
M<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#,N,3$W.BTW-RXV-S<G72`]
M("=2;V-H97-T97(L($=R96%T97(@4F]C:&5S=&5R($EN=&5R;F%T:6]N86P@
M06ER<&]R="P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#,N,30Q.BTX.2XS-#4G72`]("=-861I<V]N+"!$86YE($-O=6YT>2!296=I
M;VYA;"U4<G5A>"!&:65L9"P@5TDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-#,N,3<Q.BTX-BXR,S<G72`]("=-=7-K96=O;BP@375S:V5G
M;VX@0V]U;G1Y($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S0S+C$Y-3HM-S$N-3`Q)UT@/2`G0V]N8V]R9"P@0V]N8V]R
M9"!-=6YI8VEP86P@06ER<&]R="P@3D@G.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-#,N,SDQ.BTY.2XX-#,G72`]("=7:6YN97(L($)O8B!7
M:6QE>2!&:65L9"!!:7)P;W)T+"!31"<["B1C;V]R9&EN871E<ULG56YI=&5D
M(%-T871E<R==6R<T,RXU-C<Z+3$Q-BXR-#$G72`]("=";VES92P@0F]I<V4@
M06ER(%1E<FUI;F%L+"!)1"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T,RXU-S<Z+3DV+C<U-"==(#T@)U-I;W5X($9A;&QS+"!&;W-S($9I
M96QD+"!31"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T,RXU
M.34Z+3$Q."XY-38G72`]("="=7)N<RP@0G5R;G,@375N:6-I<&%L($%I<G!O
M<G0L($]2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0S+C8T
M,CHM-S`N,S`T)UT@/2`G4&]R=&QA;F0L(%!O<G1L86YD($EN=&5R;F%T:6]N
M86P@2F5T<&]R="P@344G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#,N-S8W.BTY.2XS,3@G72`]("=#:&%M8F5R;&%I;BP@0VAA;6)E<FQA
M:6X@375N:6-I<&%L($%I<G!O<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0S+C@W.3HM.3$N,C4W)UT@/2`G3&$@0W)O<W-E+"!,
M82!#<F]S<V4@375N:6-I<&%L($%I<G!O<G0L(%=))SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0S+CDP,#HM-CDN.3,U)UT@/2`G0G)U;G-W
M:6-K+"!.879A;"!!:7(@4W1A=&EO;BP@344G.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#,N.3`T.BTY,BXT.3(G72`]("=2;V-H97-T97(L
M(%)O8VAE<W1E<B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U.)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C`T-CHM,3`S+C`U-"==(#T@
M)U)A<&ED($-I='DL(%)A<&ED($-I='D@4F5G:6]N86P@06ER<&]R="P@4T0G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N,#4P.BTW-2XW
M,S,G72`]("=&;W)T($1R=6T@+R!7:&5E;&5R+5-A8VL@52X@4RX@07)M>2!!
M:7)F:65L9"P@3EDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#0N,3,S.BTQ,C,N,C$T)UT@/2`G175G96YE+"!-86AL;VX@4W=E970@1FEE
M;&0L($]2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C(V
M-SHM-S$N,S`P)UT@/2`G36]U;G0@5V%S:&EN9W1O;BP@3D@G.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N,S,Y.BTQ,#4N-30R)UT@/2`G
M1VEL;&5T=&4L($=I;&QE='1E+4-A;7!B96QL($-O=6YT>2!!:7)P;W)T+"!7
M62<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-"XS-3$Z+3@T
M+C8W-"==(#T@)TAO=6=H=&]N($QA:V4L(%)O<V-O;6UO;B!#;W5N='D@06ER
M<&]R="P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N
M,S@X.BTY."XR,C@G72`]("=(=7)O;BP@2'5R;VX@4F5G:6]N86P@06ER<&]R
M="P@4T0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N-#$Y
M.BTW,BXP,3DG72`]("=386EN="!*;VAN<V)U<GDL(%94)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C0V.#HM-S,N,34P)UT@/2`G0G5R
M;&EN9W1O;BP@0G5R;&EN9W1O;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L(%94
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T+C0W.3HM.#@N
M,3,W)UT@/2`G1W)E96X@0F%Y+"!!=7-T:6X@4W1R875B96P@26YT97)N871I
M;VYA;"!!:7)P;W)T+"!722<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E
M<R==6R<T-"XU,3<Z+3$P.2XP,3<G72`]("=#;V1Y+"!762<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-"XU,S,Z+3<P+C4S,R==(#T@)U)U
M;69O<F0L($U%)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T
M+C4W-CHM-S$N,3<Y)UT@/2`G0F5R;&EN+"!"97)L:6X@375N:6-I<&%L($%I
M<G!O<G0L($Y()SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0T
M+C<V.3HM,3`V+CDV.2==(#T@)U-H97)I9&%N+"!3:&5R:61A;B!#;W5N='D@
M06ER<&]R="P@5UDG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-#0N.#,S.BTX-"XU-3`G72`]("='<F%Y:6YG($%I<B!&;W)C92!286YG92P@
M34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#0N.#@S.BTY
M,RXR,CDG72`]("=-:6YN96%P;VQI<RP@36EN;F5A<&]L:7,M4W0N(%!A=6P@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!-3B<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-"XY,#@Z+3$R,BXY.34G72`]("=386QE;2P@36-.
M87)Y($9I96QD+"!/4B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T-"XY,3<Z+38W+C`P,"==(#T@)T5A<W1P;W)T+"!-12<["B1C;V]R9&EN
M871E<ULG56YI=&5D(%-T871E<R==6R<T-"XY,S,Z+3<R+C(P,"==(#T@)TYE
M=W!O<G0L(%94)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U
M+C`W,CHM.#,N-38T)UT@/2`G06QP96YA+"!!;'!E;F$@0V]U;G1Y(%)E9VEO
M;F%L($%I<G!O<G0L($U))SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S0U+C0T,SHM.3@N-#$S)UT@/2`G06)E<F1E96XL($%B97)D965N(%)E
M9VEO;F%L($%I<G!O<G0L(%-$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0U+C4T-3HM.30N,#4R)UT@/2`G4W0N($-L;W5D+"!3="X@0VQO
M=60@375N:6-I<&%L($%I<G!O<G0L($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0U+C4Y,3HM,3(R+C8P,"==(#T@)U!O<G1L86YD+"!0
M;W)T;&%N9"!);G1E<FYA=&EO;F%L($%I<G!O<G0L($]2)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C8Y.#HM,3$X+C@S-"==(#T@)U!E
M;F1L971O;BP@16%S=&5R;B!/<F5G;VX@4F5G:6]N86P@070@4&5N9&QE=&]N
M($%I<G!O<G0L($]2)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S0U+C<U,#HM.#<N,#,S)UT@/2`G17-C86YA8F$L($U))SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+C@P-SHM,3`X+C4T,B==(#T@)T)I
M;&QI;F=S+"!":6QL:6YG<R!,;V=A;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0U+CDS,SHM
M.3`N-#4P)UT@/2`G4&%R:R!&86QL<RP@5TDG.PHD8V]O<F1I;F%T97-;)U5N
M:71E9"!3=&%T97,G75LG-#8N,34W.BTQ,C,N.#@R)UT@/2`G07-T;W)I82P@
M07-T;W)I82!296=I;VYA;"!!:7)P;W)T+"!/4B<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-BXS-S4Z+3$Q-RXP,30G72`]("=,97=I<W1O
M;BP@3&5W:7-T;VXM3F5Z(%!E<F-E($-O=6YT>2!!:7)P;W)T+"!)1"<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXT,C@Z+3$P-2XX.#8G
M72`]("=-:6QE<R!#:71Y+"!&<F%N:R!7:6QE>2!&:65L9"!!:7)P;W)T+"!-
M5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXT-SDZ+3@T
M+C,U-R==(#T@)U-A=6QT(%-T92X@36%R:64L($U))SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S0V+C4S,SHM.#<N-34P)UT@/2`G36%R<75E
M='1E+"!-22<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXU
M-C0Z+3$R,"XU,S0G72`]("=986MI;6$L(%EA:VEM82!!:7(@5&5R;6EN86PL
M(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C4V-SHM
M,3$Y+C8P,"==(#T@)TAA;F9O<F0L(%=!)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S0V+C8P,#HM.30N,S$W)UT@/2`G4&5Q=6]T($QA:V4L
M($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C8P-CHM
M,3$Q+CDV-"==(#T@)TAE;&5N82P@2&5L96YA(%)E9VEO;F%L($%I<G!O<G0L
M($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C8X,SHM
M-C@N,#4P)UT@/2`G4')E<W%U92!)<VQE+"!-12<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-BXW.#(Z+3$P,"XW-3<G72`]("=":7-M87)C
M:RP@0FES;6%R8VL@375N:6-I<&%L($%I<G!O<G0L($Y$)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+C@T,SHM.3(N,C(V)UT@/2`G1'5L
M=71H+"!$=6QU=&@@26YT97)N871I;VYA;"!!:7)P;W)T+"!-3B<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-BXX-C<Z+38X+C`Q,R==(#T@
M)T-A<FEB;W4L($-A<FEB;W4@375N:6-I<&%L($%I<G!O<G0L($U%)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+CDR,3HM,3$T+C`Y,R==
M(#T@)TUI<W-O=6QA+"!-:7-S;W5L82!);G1E<FYA=&EO;F%L($%I<G!O<G0L
M($U4)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+CDR-3HM
M.38N.#$Q)UT@/2`G1F%R9V\L($AE8W1O<B!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($Y$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0V+CDW
M,SHM,3(R+CDP,R==(#T@)T]L>6UP:6$L($]L>6UP:6$@06ER<&]R="P@5T$G
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N,3$W.BTQ,C(N
M-34P)UT@/2`G1F]R="!,97=I<R`O($=R87D@52X@4RX@07)M>2!!:7)F:65L
M9"P@5T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N,34P
M.BTQ,C(N-#@S)UT@/2`G5&%C;VUA("\@36-#:&]R9"!!:7(@1F]R8V4@0F%S
M92P@5T$G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N,38X
M.BTX."XT.#DG72`]("=(86YC;V-K+"!(;W5G:'1O;B!#;W5N='D@365M;W)I
M86P@06ER<&]R="P@34DG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G
M75LG-#<N-#0U.BTQ,C(N,S$T)UT@/2`G4V5A='1L92P@4V5A='1L92U486-O
M;6$@26YT97)N871I;VYA;"!!:7)P;W)T+"!702<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T-RXT-S,Z+3$Q,2XS.#(G72`]("='<F5A="!&
M86QL<RP@1W)E870@1F%L;',@26YT97)N871I;VYA;"!!:7)P;W)T+"!-5"<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T-RXU,#`Z+3DT+CDS
M,R==(#T@)T)E;6ED:FDL($U.)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S0W+C8R,3HM,3$W+C4R."==(#T@)U-P;VMA;F4L(%-P;VMA;F4@
M26YT97)N871I;VYA;"!!:7)P;W)T+"!702<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<T-RXW-3`Z+3$P,2XX,S,G72`]("=2;W-E9VQE;BP@
M3D0G.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#<N.3,X.BTQ
M,C0N-34U)UT@/2`G475I;&QA>75T92P@475I;&QA>75T92!3=&%T92!!:7)P
M;W)T+"!702<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<T."XQ
M,#`Z+3DX+C@V-R==(#T@)T1E=FEL<R!,86ME+"!.1"<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<T."XQ,S,Z+3$R,RXT,#`G72`]("=0;W)T
M($%N9V5L97,@0V]A<W0@1W5A<F0@06ER(%-T871I;VXL(%=!)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0X+C$W-#HM,3`S+C8S-R==(#T@
M)U=I;&QI<W1O;BP@4VQO=6QI;B!&:65L9"!);G1E<FYA=&EO;F%L($%I<G!O
M<G0L($Y$)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S0X+C(Q
M-#HM,3`V+C8R,2==(#T@)T=L87-G;W<L($=L87-G;W<@26YT97)N871I;VYA
M;"!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<T."XS,#0Z+3$Q-"XR-C0G72`]("=+86QI<W!E;&PL($=L86-I97(@4&%R
M:R!);G1E<FYA=&EO;F%L($%I<G!O<G0L($U4)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S0X+C4T,SHM,3`Y+C<V,R==(#T@)TAA=G)E+"!(
M879R92!#:71Y+4-O=6YT>2!!:7)P;W)T+"!-5"<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<T."XU-C(Z+3DS+C,Y."==(#T@)TEN=&5R;F%T
M:6]N86P@1F%L;',L($9A;&QS($EN=&5R;F%T:6]N86P@06ER<&]R="P@34XG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-#@N.3,S.BTY-2XS
M-3`G72`]("=787)R;V%D+"!-3B<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<U,2XX.3`Z+3$W-BXV,C4G72`]("=!9&%K+"!.879A;"!!:7(@
M4W1A=&EO;BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG
M-3(N-S$W.C$W-"XQ,3<G72`]("=3:&5M>6$L($5A<F5C:W-O;B!!<RP@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3(N.34P.BTQ-C@N
M.#4P)UT@/2`G3FEK;VQS:VDL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@
M4W1A=&5S)UU;)S4S+CDP,#HM,38V+C4U,"==(#T@)T1U=&-H($AA<F)O<BP@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-34N,#,S.BTQ
M,S$N-38W)UT@/2`G06YN971T92!)<VQA;F0L($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S4U+C(R,3HM,38R+C<R."==(#T@)T-O;&0@
M0F%Y+"!#;VQD($)A>2!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<U-2XS-3,Z+3$S,2XW,C(G72`]("=+971C:&EK86XL
M($ME=&-H:6MA;B!);G1E<FYA=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4U+C4X,SHM,3,S+C`X,R==(#T@
M)TML87=O8VLL($ML87=O8VL@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-38N-#@S.BTQ,S(N,S8W)UT@/2`G5W)A;F=E
M;&PL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4V+C@Q
M-SHM,3,R+CDV-R==(#T@)U!E=&5R<V)U<F<L($%+)SL*)&-O;W)D:6YA=&5S
M6R=5;FET960@4W1A=&5S)UU;)S4V+CDU,#HM,34X+C8Q-R==(#T@)U!O<G0@
M2&5I9&5N+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U
M-RXP-#@Z+3$S-2XS-C4G72`]("=3:71K82P@4VET:V$@06ER<&]R="P@04LG
M.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3<N,34P.BTQ-S`N
M,C$W)UT@/2`G4V%I;G0@4&%U;"P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-3<N-3`P.BTQ,S0N-3@S)UT@/2`G06YG;V]N+"!!2R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<U-RXW-3`Z+3$U,BXU
M,#`G72`]("=+;V1I86LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S4X+C,U-CHM,3,T+C4V,R==(#T@)TIU;F5A=2P@2G5N96%U($EN
M=&5R;F%T:6]N86P@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-3@N-#$W.BTQ,S4N-S,S)UT@/2`G1W5S=&%V=7,L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4X+C8U,#HM,38R
M+C`V-R==(#T@)T-A<&4@3F5W96YH86T@06ER=V%Y<R!&86-I;&ET:65S(%-E
M8W1O<BP@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3@N
M-C@T.BTQ-38N-C4T)UT@/2`G2VEN9R!386QM;VXL($MI;F<@4V%L;6]N($%I
M<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y
M+C`U,#HM,34X+C4Q-R==(#T@)T1I;&QI;F=H86T@375N:6-I<&%L+"!!:RP@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-3DN-#,S.BTQ
M-#8N,S,S)UT@/2`G36ED9&QE=&]N($ES;&%N9"P@06LL($%+)SL*)&-O;W)D
M:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y+C0V-SHM,3,U+C,P,"==(#T@
M)U-K86=W87DL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;
M)S4Y+C4Q-SHM,3,Y+C8V-R==(#T@)UEA:W5T870L($%+)SL*)&-O;W)D:6YA
M=&5S6R=5;FET960@4W1A=&5S)UU;)S4Y+C8S,SHM,34Q+C4P,"==(#T@)TAO
M;65R("\@375N:6-I<&%L+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<U.2XW-3`Z+3$U-"XY,3<G72`]("=);&EA;6YA("\@26QI86UN
M82!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<U.2XX,#`Z+3$T-"XV,#`G72`]("=#87!E(%-A:6YT($5L:6%S+"!!2R<[
M"B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,"XP.#,Z+3$T,BXU
M,#`G72`]("=986MA=&%G82P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3
M=&%T97,G75LG-C`N,3$W.BTQ-#DN-#4P)UT@/2`G4V5W87)D+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,"XT.3(Z+3$T-2XT-S@G
M72`]("=#;W)D;W9A+"!-97)L92!++B`H375D:&]L92D@4VUI=&@@06ER<&]R
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C`N-3@P
M.BTQ-3$N,C,Y)UT@/2`G2V5N86DL($ME;F%I($UU;FEC:7!A;"!!:7)P;W)T
M+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,"XW.#,Z
M+3$V,2XX,S,G72`]("="971H96P@+R!"971H96P@06ER<&]R="P@04LG.PHD
M8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C$N,3`P.BTQ-34N-38W
M)UT@/2`G4W!A<G)E=F]H;B!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,2XQ-S0Z+3$T
M.2XY.38G72`]("=!;F-H;W)A9V4L(%1E9"!3=&5V96YS($%N8VAO<F%G92!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S8Q+C(U,#HM,30Y+C@P,"==(#T@)T%N8VAO<F%G92`O
M($5L;65N9&]R9B!!:7(@1F]R8V4@0F%S92P@04LG.PHD8V]O<F1I;F%T97-;
M)U5N:71E9"!3=&%T97,G75LG-C$N,C8W.BTQ-#DN-C4P)UT@/2`G1G0N(%)I
M8VAA<F1S;VX@+R!"<GEA;G0@52X@4RX@07)M>2!(96QI<&]R="P@06LL($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C4X,SHM,34Y
M+C4S,R==(#T@)T%N:6%K+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T
M871E<R==6R<V,2XV,#`Z+3$T.2XP.#,G72`]("=086QM97(L($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+C<X,SHM,38V+C`S,R==
M(#T@)T-A<&4@4F]M86YZ;V9F($%I<G=A>7,@1F%C:6QI=&EE<R!396-T;W(L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8Q+CDV-SHM
M,34Q+C$X,R==(#T@)U-K=V5N=&YA+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V,BXQ,#`Z+3$U,BXW-3`G72`]("=0=6YT:6QL82P@
M04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C(N,34P.BTQ
M-#4N-#4P)UT@/2`G1W5L:V%N82P@1W5L:V%N82!!:7)P;W)T+"!!2R<["B1C
M;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,BXS,C$Z+3$U,"XP.30G
M72`]("=486QK965T;F$L(%1A;&ME971N82!!:7)P;W)T+"!!2R<["B1C;V]R
M9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V,BXY-C,Z+3$T,2XY,S8G72`]
M("=.;W)T:'=A>2P@3F]R=&AW87D@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-C(N.38W.BTQ-34N-C$W)UT@/2`G36-'
M<F%T:"P@36-'<F%T:"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V,RXW-C<Z+3$W,2XW,S,G72`]("='86UB96QL($%U
M=&]M871I8R!796%T:&5R($]B<V5R=FEN9R`O(%)E<&]R=&EN9R!3>7-T96TL
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8S+C@X,SHM
M,38P+C@P,"==(#T@)U5N86QA:VQE970L($%+)SL*)&-O;W)D:6YA=&5S6R=5
M;FET960@4W1A=&5S)UU;)S8S+CDP,#HM,34R+C(V-R==(#T@)TUI;F-H=6UI
M;F$L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8T+C`P
M,#HM,30U+C<S,R==(#T@)T9O<G0@1W)E96QY("\@06QL96X@52X@4RX@07)M
M>2!!:7)F:65L9"P@06LL($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A
M=&5S)UU;)S8T+C4Q,CHM,38U+C0S-B==(#T@)TYO;64L($YO;64@06ER<&]R
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C0N-34P
M.BTQ-#DN,#@S)UT@/2`G3F5N86YA("\@375N+BP@04LG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-C0N-C4P.BTQ-#<N,#8W)UT@/2`G1F%I
M<F)A;FMS("\@16EE;'-O;B!!:7(@1F]R8V4@0F%S92P@04LG.PHD8V]O<F1I
M;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C0N-S,S.BTQ-38N.3,S)UT@/2`G
M1V%L96YA($$N+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==
M6R<V-"XX,#0Z+3$T-RXX-S8G72`]("=&86ER8F%N:W,L($9A:7)B86YK<R!)
M;G1E<FYA=&EO;F%L($%I<G!O<G0L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET
M960@4W1A=&5S)UU;)S8U+C$V-SHM,34R+C$P,"==(#T@)U1A;F%N82P@0V%L
M:&]U;B!-96UO<FEA;"!!:7)P;W)T+"!!2R<["B1C;V]R9&EN871E<ULG56YI
M=&5D(%-T871E<R==6R<V-2XR-3`Z+3$V-BXX-C<G72`]("=0;W)T($-L87)E
M;F-E+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V-2XU
M-C<Z+3$V-RXY,3<G72`]("=4:6X@0VET>2!!:7)W87ES($9A8VEL:71I97,@
M4V5C=&]R+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<V
M-2XY.#(Z+3$V,2XQ-3(G72`]("="=6-K;&%N9"P@0G5C:VQA;F0@06ER<&]R
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-C8N,#`P
M.BTQ-3,N-S`P)UT@/2`G26YD:6%N($UO=6YT86EN($%I<G=A>7,@1F%C:6QI
M=&EE<R!396-T;W(L($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S
M)UU;)S8V+C4V-SHM,30U+C(V-R==(#T@)T9O<G0@675K;VXL($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8V+C@X-CHM,38R+C8P-"==
M(#T@)TMO='IE8G5E+"!7:65N($UE;6]R:6%L($%I<G!O<G0L($%+)SL*)&-O
M;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S8V+CDQ-SHM,34Q+C4Q-R==
M(#T@)T)E='1L97,L($)E='1L97,@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T
M97-;)U5N:71E9"!3=&%T97,G75LG-C<N,3`P.BTQ-3<N.#4P)UT@/2`G06UB
M;&5R+"!!;6)L97(@06ER<&]R="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E
M9"!3=&%T97,G75LG-C@N.#@S.BTQ-C8N,3,S)UT@/2`G0V%P92!,:7-B=7)N
M92!!:7)W87ES($9A8VEL:71I97,@4V5C=&]R+"!!2R<["B1C;V]R9&EN871E
M<ULG56YI=&5D(%-T871E<R==6R<V.2XS-C<Z+3$U,BXQ,S,G72`]("=5;6EA
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5N:71E9"!3=&%T97,G75LG-CDN.#$W
M.BTQ-C(N.3$W)UT@/2`G4&]I;G0@3&%Y+"!!2R<["B1C;V]R9&EN871E<ULG
M56YI=&5D(%-T871E<R==6R<W,"XQ,S,Z+3$T,RXV,S,G72`]("="87)T97(@
M27-L86YD+"!!2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W
M,"XR,3`Z+3$U,2XP,#8G72`]("=.=6EQ<W5T+"!.=6EQ<W5T($%I<G!O<G0L
M($%+)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S<P+C4P,#HM
M,30Y+C@X,R==(#T@)T]L:6MT;VL@1&ES=&%N="!%87)L>2!787)N:6YG+"!!
M2R<["B1C;V]R9&EN871E<ULG56YI=&5D(%-T871E<R==6R<W,"XV,S,Z+3$U
M.2XX-3`G72`]("=786EN=W)I9VAT+"!786EN=W)I9VAT($%I<G!O<G0L($%+
M)SL*)&-O;W)D:6YA=&5S6R=5;FET960@4W1A=&5S)UU;)S<Q+C(X-#HM,34V
M+C<W."==(#T@)T)A<G)O=RP@4&]S="!2;V=E<G,@365M;W)I86P@06ER<&]R
M="P@04LG.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG75LG+3,P+C,X,SHM-38N
M-3`P)UT@/2`G07)T:6=A<R<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M
M,S`N.#@S.BTU-2XU,S,G72`]("=2:79E<F$G.PHD8V]O<F1I;F%T97-;)U5R
M=6=U87DG75LG+3,Q+C,X,SHM-3<N.34P)UT@/2`G4V%L=&\G.PHD8V]O<F1I
M;F%T97-;)U5R=6=U87DG75LG+3,Q+C<P,#HM-34N.3@S)UT@/2`G5&%C=6%R
M96UB;R<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M,S(N,S,S.BTU."XP
M,S,G72`]("=087ES86YD=2<["B1C;V]R9&EN871E<ULG57)U9W5A>2==6R<M
M,S(N,S8W.BTU-"XR,3<G72`]("=-96QO)SL*)&-O;W)D:6YA=&5S6R=5<G5G
M=6%Y)UU;)RTS,RXR,3<Z+34T+C,X,R==(#T@)U1R96EN=&$@62!4<F5S)SL*
M)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,RXR-3`Z+34X+C`V-R==(#T@
M)TUE<F-E9&5S)SL*)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS,RXS-3`Z
M+34V+C4P,"==(#T@)T1U<F%Z;F\G.PHD8V]O<F1I;F%T97-;)U5R=6=U87DG
M75LG+3,T+C0U,#HM-3<N.#,S)UT@/2`G0V]L;VYI82<["B1C;V]R9&EN871E
M<ULG57)U9W5A>2==6R<M,S0N-S@S.BTU-BXR-3`G72`]("=-96QI;&QA)SL*
M)&-O;W)D:6YA=&5S6R=5<G5G=6%Y)UU;)RTS-"XX,S,Z+34V+C`P,"==(#T@
M)T-A<G)A<V-O)SL*)&-O;W)D:6YA=&5S6R=5>F)E:VES=&%N)UU;)S,W+C(S
M,SHV-RXR-C<G72`]("=497)M97HG.PHD8V]O<F1I;F%T97-;)U5Z8F5K:7-T
M86XG75LG,SDN-38W.C8V+CDU,"==(#T@)U-A;6%R:V%N9"<["B1C;V]R9&EN
M871E<ULG57IB96MI<W1A;B==6R<T,"XQ,3<Z-C<N.#,S)UT@/2`G1'II>F%K
M)SL*)&-O;W)D:6YA=&5S6R=5>F)E:VES=&%N)UU;)S0Q+C(V-SHV.2XR-C<G
M72`]("=487-H:V5N="<["B1C;V]R9&EN871E<ULG57IB96MI<W1A;B==6R<T
M,2XW,S,Z-C0N-C$W)UT@/2`G5&%M9'DG.PHD8V]O<F1I;F%T97-;)U9A;G5A
M='4G75LG+3$S+C@U,#HQ-C<N-34P)UT@/2`G4V]L82!686YU82!,879A)SL*
M)&-O;W)D:6YA=&5S6R=686YU871U)UU;)RTQ-2XU,3<Z,38W+C(Q-R==(#T@
M)U!E:V]A($%I<G!O<G0@4V%N=&\G.PHD8V]O<F1I;F%T97-;)U9A;G5A='4G
M75LG+3$V+C0Q-SHQ-C<N.#`P)UT@/2`G3&%M87`@36%L96MU;&$G.PHD8V]O
M<F1I;F%T97-;)U9A;G5A='4G75LG+3$W+C<P,#HQ-C@N,S`P)UT@/2`G0F%U
M97)F:65L9"!%9F%T92<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S$P
M+C`V-SHM-CDN,S$W)UT@/2`G0F%R<75I<VEM971O)SL*)&-O;W)D:6YA=&5S
M6R=696YE>G5E;&$G75LG,3`N,3$W.BTV-"XV.#,G72`]("="87)C96QO;F$G
M.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XQ-C<Z+38W+CDS,R==
M(#T@)U9A;&5N8VEA)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG,3`N
M,C4P.BTV-RXV-3`G72`]("=-87)A8V%Y+4(N($$N(%-U8W)E)SL*)&-O;W)D
M:6YA=&5S6R=696YE>G5E;&$G75LG,3`N-#4P.BTV-"XQ.#,G72`]("=#=6UA
M;F$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XU,#`Z+38V+C@X
M,R==(#T@)T-A<F%C87,@+R!,82!#87)L;W1A)SL*)&-O;W)D:6YA=&5S6R=6
M96YE>G5E;&$G75LG,3`N-3`P.BTV."XP,#`G72`]("=0=&\N($-A8F5L;&\G
M.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,"XU-C<Z+3<Q+C<S,R==
M(#T@)TUA<F%C86EB;RU,82!#:&EN:71A)SL*)&-O;W)D:6YA=&5S6R=696YE
M>G5E;&$G75LG,3`N-3@S.BTV,BXS,3<G72`]("='=6ER:6$G.PHD8V]O<F1I
M;F%T97-;)U9E;F5Z=65L82==6R<Q,"XV,#`Z+38V+CDX,R==(#T@)T-A<F%C
M87,@+R!-86EQ=65T:6$@065R;W`N($EN=&PN(%-I;6]N($)O;&EV87(G.PHD
M8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,2XT,3<Z+38Y+C8X,R==(#T@
M)T-O<F\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Q,2XX,#`Z+38V
M+C$X,R==(#T@)TQA($]R8VAI;&$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L
M82==6R<T+C8P,#HM-C$N,3$W)UT@/2`G4V%N=&$@16QE;F$@1&4@56%I<F5N
M)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG-2XV,#`Z+38W+C4P,"==
M(#T@)U!U97)T;R!!>6%C=6-H;R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA
M)UU;)S<N,C,S.BTW,"XX,#`G72`]("='=6%S9'5A;&ET;R<["B1C;V]R9&EN
M871E<ULG5F5N97IU96QA)UU;)S<N,S`P.BTV,2XT-3`G72`]("=4=6UE<F5M
M;R<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S<N-3@S.BTW,BXP-C<G
M72`]("=3=&\N($1O;6EN9V\G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==
M6R<W+C@U,#HM-S(N-#4P)UT@/2`G4V%N($%N=&]N:6\@1&5L(%1A8VAI<F$G
M.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<W+CDP,#HM-C<N-#$W)UT@
M/2`G4V%N($9E<FYA;F1O($1E($%P=7)E)SL*)&-O;W)D:6YA=&5S6R=696YE
M>G5E;&$G75LG."XQ-3`Z+38S+C4U,"==(#T@)T-I=61A9"!";VQI=F%R)SL*
M)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG."XV,#`Z+3<Q+C$X,R==(#T@
M)TUE<FED82<["B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)S@N-C$W.BTW
M,"XR,3<G72`]("="87)I;F%S)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G
M75LG."XY,S,Z+38W+C0Q-R==(#T@)T-A;&%B;WIO)SL*)&-O;W)D:6YA=&5S
M6R=696YE>G5E;&$G75LG.2XP,3<Z+38R+C8Q-R==(#T@)U1E;6)L861O<B<[
M"B1C;V]R9&EN871E<ULG5F5N97IU96QA)UU;)SDN,#$W.BTV.2XW,S,G72`]
M("='=6%N87)E)SL*)&-O;W)D:6YA=&5S6R=696YE>G5E;&$G75LG.2XR,3<Z
M+38V+C`Q-R==(#T@)U9A;&QE($1E($QA(%!A<V-U82<["B1C;V]R9&EN871E
M<ULG5F5N97IU96QA)UU;)SDN,S4P.BTW,"XV,3<G72`]("=686QE<F$G.PHD
M8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y+C4U,#HM-CDN,C,S)UT@/2`G
M06-A<FEG=6$G.PHD8V]O<F1I;F%T97-;)U9E;F5Z=65L82==6R<Y+C<U,#HM
M-C,N,3@S)UT@/2`G36%T=7)I;B<["B1C;V]R9&EN871E<ULG5F5N97IU96QA
M)UU;)SDN.#$W.BTW,"XY,S,G72`]("=-96YE($=R86YD92<["B1C;V]R9&EN
M871E<ULG5F5N97IU96QA)UU;)SDN.3$W.BTV-RXS,S,G72`]("=386X@2G5A
M;B!$92!,;W,@36]R<F]S)SL*)&-O;W)D:6YA=&5S6R=6:65T($YA;2==6R<Q
M,"XX,3<Z,3`V+C8V-R==(#T@)TAO($-H:2!-:6YH)SL*)&-O;W)D:6YA=&5S
M6R=6:65T($YA;2==6R<Q,BXR-3`Z,3`Y+C(P,"==(#T@)TYH82!4<F%N9R<[
M"B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,3,N-S8W.C$P.2XR,3<G72`]
M("=1=7D@3FAO;B<["B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,3,N.3@S
M.C$P."XP,#`G72`]("=0;&5I:W4@0VET>2<["B1C;V]R9&EN871E<ULG5FEE
M="!.86TG75LG,38N,#,S.C$P."XQ.#,G72`]("=$82!.86YG)SL*)&-O;W)D
M:6YA=&5S6R=6:65T($YA;2==6R<Q-BXT,#`Z,3`W+C8X,R==(#T@)TAU92<[
M"B1C;V]R9&EN871E<ULG5FEE="!.86TG75LG,3@N-S`P.C$P-2XV-C<G72`]
M("=6:6YH)SL*)&-O;W)D:6YA=&5S6R=6:65T($YA;2==6R<R,2XP,3<Z,3`U
M+C@P,"==(#T@)TAA($YO:2<["B1C;V]R9&EN871E<ULG5FER9VEN($ES;&%N
M9',L($)R:71I<V@G75LG,3@N-#4P.BTV-"XU,S,G72`]("="965F($ES;&%N
M9"P@5&]R=&]L82<["B1C;V]R9&EN871E<ULG5FER9VEN($ES;&%N9',L(%5N
M:71E9"!3=&%T97,G75LG,3<N-S`P.BTV-"XX,#`G72`]("=#:')I<W1I86YS
M=&5D+"!(96YR>2!%+B!2;VAL<V5N($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;
M)U9I<F=I;B!)<VQA;F1S+"!5;FET960@4W1A=&5S)UU;)S$X+C,S,SHM-C0N
M.3@S)UT@/2`G0VAA<FQO='1E($%M86QI92!3="X@5&AO;6%S+"!#>7)I;"!%
M+B!+:6YG($%I<G!O<G0G.PHD8V]O<F1I;F%T97-;)U=E<W1E<FX@4V%H87)A
M)UU;)S(S+C<P,#HM,34N.#8W)UT@/2`G5FEL;&$@0VES;F5R;W,G.PHD8V]O
M<F1I;F%T97-;)UEE;65N)UU;)S$R+C8S,SHU,RXY,#`G72`]("=3;V-O=')A
M)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q,BXV-C<Z-#4N,#,S)UT@/2`G
M061E;B<["B1C;V]R9&EN871E<ULG665M96XG75LG,3,N,C4P.C0S+C(X,R==
M(#T@)TUO:VAA)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q,RXR-3`Z-#0N
M,3,S)UT@/2`G36]K:&$G.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$S+C8X
M,SHT-"XQ,S,G72`]("=486EZ)SL*)&-O;W)D:6YA=&5S6R=996UE;B==6R<Q
M-"XU,3<Z-#8N.#4P)UT@/2`G071A<2<["B1C;V]R9&EN871E<ULG665M96XG
M75LG,30N-C4P.C0Y+C,X,R==(#T@)U)I>6%N)SL*)&-O;W)D:6YA=&5S6R=9
M96UE;B==6R<Q-"XW-3`Z-#(N.3@S)UT@/2`G2&]D96ED86@G.PHD8V]O<F1I
M;F%T97-;)UEE;65N)UU;)S$U+C0S,SHT-2XS,S,G72`]("=-87)I8B<["B1C
M;V]R9&EN871E<ULG665M96XG75LG,34N-3$W.C0T+C$X,R==(#T@)U-A;F%<
M)T$G.PHD8V]O<F1I;F%T97-;)UEE;65N)UU;)S$V+C(P,#HT-"XW.#,G72`]
M("=!;"U(87IM)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0R+C,V
M-SHQ.2XR-3`G72`]("=0;V1G;W)I8V$@+R!';VQU8F]V8VDG.PHD8V]O<F1I
M;F%T97-;)UEU9V]S;&%V:6$G75LG-#(N-#`P.C$X+C<S,R==(#T@)U1I=F%T
M)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0R+C8U,#HR,2XQ-3`G
M72`]("=0<FES=&EN82<["B1C;V]R9&EN871E<ULG675G;W-L879I82==6R<T
M,RXS,S,Z,C$N.3`P)UT@/2`G3FES)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA
M=FEA)UU;)S0S+C,U,#HQ-RXX,#`G72`]("=-;W-T87(G.PHD8V]O<F1I;F%T
M97-;)UEU9V]S;&%V:6$G75LG-#,N.#$W.C$X+C,S,R==(#T@)U-A<F%J979O
M("\@0G5T;6ER)SL*)&-O;W)D:6YA=&5S6R=9=6=O<VQA=FEA)UU;)S0T+C4U
M,#HQ."XW,#`G72`]("=4=7IL82<["B1C;V]R9&EN871E<ULG675G;W-L879I
M82==6R<T-"XW.#,Z,3<N,C$W)UT@/2`G0F%N:F$@3'5K82<["B1C;V]R9&EN
M871E<ULG675G;W-L879I82==6R<T-"XX,3<Z,34N.#@S)UT@/2`G0FEH86,G
M.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V:6$G75LG-#0N.#$W.C(P+C(X,R==
M(#T@)T)E;V=R860@+R!3=7)C:6XG.PHD8V]O<F1I;F%T97-;)UEU9V]S;&%V
M:6$G75LG-#4N,34P.C(Q+C,Q-R==(#T@)U9R<V%C)SL*)&-O;W)D:6YA=&5S
M6R=:86ER92==6R<P+C`U,#HQ."XR-C<G72`]("=-8F%N9&%K82<["B1C;V]R
M9&EN871E<ULG6F%I<F4G75LG,"XQ,S,Z,CDN,C8W)UT@/2`G0G5T96UB;R<[
M"B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3`N,C$W.C(P+C@U,"==(#T@)T)O
M96YD92<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG,"XU,3<Z,C4N,3@S)UT@
M/2`G2VES86YG86YI)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M,2XQ.#,Z
M,CDN-#4P)UT@/2`G4G5T<VAU<G4G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;
M)RTQ+C8X,SHR.2XR,S,G72`]("=';VUA)SL*)&-O;W)D:6YA=&5S6R=:86ER
M92==6R<M,2XY-C<Z,3@N,C8W)UT@/2`G26YO;F=O)SL*)&-O;W)D:6YA=&5S
M6R=:86ER92==6R<M,3`N-S$W.C(U+C0U,"==(#T@)TMO;'=E>FDG.PHD8V]O
M<F1I;F%T97-;)UIA:7)E)UU;)RTQ,2XV-C<Z,C<N-#@S)UT@/2`G3'5B=6UB
M87-H:2U,=6%N;R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3(N.34P.C(U
M+CDQ-R==(#T@)TMI;F1U)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<S+C(X
M,SHQ.2XW.#,G72`]("='96UE;F$G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;
M)RTS+C,P,#HQ-RXS-3`G72`]("="86YD=6YD=2<["B1C;V]R9&EN871E<ULG
M6F%I<F4G75LG+3,N-#@S.C(S+C0V-R==(#T@)TQO9&IA)SL*)&-O;W)D:6YA
M=&5S6R=:86ER92==6R<M-"XS,S,Z,C`N-3@S)UT@/2`G26QE8F\G.PHD8V]O
M<F1I;F%T97-;)UIA:7)E)UU;)RTT+C,X,SHQ-2XT,S,G72`]("=+:6YS:&%S
M82`O($Y<)T1J:6QI)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-"XY,3<Z
M,3<N,#8W)UT@/2`G2V5N9V4G.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTT
M+CDV-SHR,RXT,S,G72`]("=,=7-A;6)O)SL*)&-O;W)D:6YA=&5S6R=:86ER
M92==6R<M-2XP,S,Z,3@N.#`P)UT@/2`G2VEK=VET)SL*)&-O;W)D:6YA=&5S
M6R=:86ER92==6R<M-2XS-3`Z,C<N,#`P)UT@/2`G2V]N9V]L;R<["B1C;V]R
M9&EN871E<ULG6F%I<F4G75LG+34N-3$W.C$S+C4X,R==(#T@)TEN9V$G.PHD
M8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTU+C@P,#HQ,RXT,S,G72`]("=-871A
M9&DG.PHD8V]O<F1I;F%T97-;)UIA:7)E)UU;)RTU+C@X,SHR,BXT,3<G72`]
M("=+86YA;F=A)SL*)&-O;W)D:6YA=&5S6R=:86ER92==6R<M-2XX.#,Z,CDN
M,3@S)UT@/2`G2V%L96UI92<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+38N
M,#`P.C$R+C0Q-R==(#T@)TUO86YD82<["B1C;V]R9&EN871E<ULG6F%I<F4G
M75LG+38N,38W.C(S+C8Q-R==(#T@)TUB=6II+4UA>6DG.PHD8V]O<F1I;F%T
M97-;)UIA:7)E)UU;)RTV+C0Q-SHR,"XX-3`G72`]("=4<VAI:V%P82<["B1C
M;V]R9&EN871E<ULG6F%I<F4G75LG+3<N,C@S.C(W+C0S,R==(#T@)TUA;F]N
M;R<["B1C;V]R9&EN871E<ULG6F%I<F4G75LG+3@N-C,S.C(U+C(U,"==(#T@
M)TMA;6EN82`O($)A<V4G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3`N
M,3$W.C,R+C8S,R==(#T@)TES;VMA)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G
M75LG+3$P+C(Q-SHS,2XQ,S,G72`]("=+87-A;6$G.PHD8V]O<F1I;F%T97-;
M)UIA;6)I82==6R<M,3$N,3`P.C(X+C@U,"==(#T@)TUA;G-A)SL*)&-O;W)D
M:6YA=&5S6R=:86UB:6$G75LG+3$Q+C<U,#HR-"XT,S,G72`]("=-=VEN:6QU
M;F=A)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$Q+CDP,#HS,2XT,S,G
M72`]("=-<&EK82<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;)RTQ,BXQ.#,Z
M,C8N,S@S)UT@/2`G4V]L=V5Z:2<["B1C;V]R9&EN871E<ULG6F%M8FEA)UU;
M)RTQ,BXR.#,Z,S,N,C`P)UT@/2`G3'5N9&%Z:2<["B1C;V]R9&EN871E<ULG
M6F%M8FEA)UU;)RTQ,RXP,#`Z,C@N-C4P)UT@/2`G3F1O;&$G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,3,N,C,S.C,P+C(Q-R==(#T@)U-E<F5N:F4G
M.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-3,S.C(S+C$Q-R==(#T@
M)UIA;6)E>FDG.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3,N-3,S.C(U
M+C@U,"==(#T@)TMA<V5M<&$G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M
M,3,N-34P.C,R+C4X,R==(#T@)T-H:7!A=&$G.PHD8V]O<F1I;F%T97-;)UIA
M;6)I82==6R<M,3,N-C`P.C(T+C(P,"==(#T@)TMA8F]M<&\G.PHD8V]O<F1I
M;F%T97-;)UIA;6)I82==6R<M,30N,C4P.C,Q+C(X,R==(#T@)U!E=&%U:V4G
M.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,30N-#4P.C(X+C0V-R==(#T@
M)TMA8G=E)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG+3$T+C0U,#HR."XT
M-C<G72`]("=,=7-A:V$@0VET>2!!:7)P;W)T)SL*)&-O;W)D:6YA=&5S6R=:
M86UB:6$G75LG+3$T+C@P,#HR-"XX,#`G72`]("=+86]M82<["B1C;V]R9&EN
M871E<ULG6F%M8FEA)UU;)RTQ-2XR-3`Z,C,N,34P)UT@/2`G36]N9W4G.PHD
M8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,34N,S$W.C(X+C0U,"==(#T@)TQU
M<V%K82!);G1E<FYA=&EO;F%L86ER<&]R="<["B1C;V]R9&EN871E<ULG6F%M
M8FEA)UU;)RTQ-BXQ,#`Z,C,N,C8W)UT@/2`G4V5N86YG82<["B1C;V]R9&EN
M871E<ULG6F%M8FEA)UU;)RTQ-BXX,S,Z,C<N,#8W)UT@/2`G0VAO;6$G.PHD
M8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3<N-#8W.C(T+C,P,"==(#T@)U-E
M<VAE:V4G.PHD8V]O<F1I;F%T97-;)UIA;6)I82==6R<M,3<N.#$W.C(U+C@Q
M-R==(#T@)TQI=FEN9W-T;VYE)SL*)&-O;W)D:6YA=&5S6R=:86UB:6$G75LG
M+3@N.#4P.C,Q+C,S,R==(#T@)TUB86QA)SL*)&-O;W)D:6YA=&5S6R=:86UB
M:6$G75LG+3DN.#`P.C(Y+C`X,R==(#T@)TMA=V%M8G=A)SL*)&-O;W)D:6YA
M=&5S6R=::6UB86)W92==6R<M,38N-3$W.C(X+C@X,R==(#T@)TMA<FEB82<[
M"B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3$V+C@S,SHR.2XV,3<G72`]
M("=+87)O:2<["B1C;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3$W+C0Q-SHS
M,BXR,3<G72`]("=-=71O:V\G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;
M)RTQ-RXV,3<Z,C<N,S,S)UT@/2`G0FEN9V$G.PHD8V]O<F1I;F%T97-;)UII
M;6)A8G=E)UU;)RTQ-RXY,3<Z,S$N,3,S)UT@/2`G2&%R87)E($MU='-A9V$G
M.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTQ."XQ,#`Z,C4N.#4P)UT@
M/2`G5FEC=&]R:6$@1F%L;',G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;
M)RTQ."XR,3<Z,C@N.3,S)UT@/2`G1V]K=V4G.PHD8V]O<F1I;F%T97-;)UII
M;6)A8G=E)UU;)RTQ."XU,S,Z,S(N,3,S)UT@/2`G4G5S87!E)SL*)&-O;W)D
M:6YA=&5S6R=::6UB86)W92==6R<M,3@N-C,S.C(W+C`P,"==(#T@)TAW86YG
M92!.871I;VYA;"!087)K)SL*)&-O;W)D:6YA=&5S6R=::6UB86)W92==6R<M
M,3DN-#4P.C(Y+C@U,"==(#T@)T=W97)U)SL*)&-O;W)D:6YA=&5S6R=::6UB
M86)W92==6R<M,C`N,#$W.C(X+C8Q-R==(#T@)T)U;&%W87EO($%I<G!O<G0G
M.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,"XP-C<Z,S`N.#8W)UT@
M/2`G36%S=FEN9V\G.PHD8V]O<F1I;F%T97-;)UII;6)A8G=E)UU;)RTR,"XR
M,#`Z,S(N-C$W)UT@/2`G0VAI<&EN9V4G.PHD8V]O<F1I;F%T97-;)UII;6)A
M8G=E)UU;)RTR,2XP,3<Z,S$N-3@S)UT@/2`G0G5F9F%L;R!286YG92<["B1C
M;V]R9&EN871E<ULG6FEM8F%B=V4G75LG+3(R+C(Q-SHS,"XP,#`G72`]("="
M96ET8G)I9&=E)SL*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,O8V%R<VEG;G,N<&AP````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S,R,B`Q,#4Q-30S-#$T
M,"`P,C(S,C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!L:7-T(&]F(&EN=&5R;F%T:6]N86P@
M;&EC96YS92!P;&%T92!C;V1E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C87)S:6=N<RYP:'`L=B`Q+C$@,C`P-"\P.2\P."`Q-3HQ.#HU
M-R!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J+PH*)&-A
M<G-I9VYS(#T@87)R87DH"B`@("`G870G(#T^("=!)RP*("`@("=A9B<@/3X@
M)T%&1R<L"B`@("`G86<G(#T^("=!1R<L"B`@("`G86PG(#T^("=!3"<L"B`@
M("`G860G(#T^("=!3D0G+`H@("`@)V%O)R`]/B`G04Y')RP*("`@("=A;2<@
M/3X@)T%232<L"B`@("`G874G(#T^("=!55,G+`H@("`@)V%Z)R`]/B`G05HG
M+`H@("`@)V)E)R`]/B`G0B<L"B`@("`G8F0G(#T^("="1"<L"B`@("`G8F(G
M(#T^("="1%,G+`H@("`@)V)F)R`]/B`G0D8G+`H@("`@)V)G)R`]/B`G0D<G
M+`H@("`@)V)Z)R`]/B`G0D@G+`H@("`@)V)T)R`]/B`G0DA4)RP*("`@("=B
M82<@/3X@)T))2"<L"B`@("`G8F\G(#T^("="3TPG+`H@("`@)V)R)R`]/B`G
M0E(G+`H@("`@)V)H)R`]/B`G0E).)RP*("`@("=B;B<@/3X@)T)252<L"B`@
M("`G8G,G(#T^("="4R<L"B`@("`G8FDG(#T^("="52<L"B`@("`G=F<G(#T^
M("="5DDG+`H@("`@)V)Y)R`]/B`G0EDG+`H@("`@)V)Z)R`]/B`G0EHG+`H@
M("`@)V-U)R`]/B`G0R<L"B`@("`G8VTG(#T^("=#04TG+`H@("`@)V-D)R`]
M/B`G0T0G+`H@("`@)V-A)R`]/B`G0T1.)RP*("`@("=C:"<@/3X@)T-()RP*
M("`@("=C:2<@/3X@)T-))RP*("`@("=L:R<@/3X@)T-,)RP*("`@("=C;R<@
M/3X@)T-/)RP*("`@("=K;2<@/3X@)T-/32<L"B`@("`G8W(G(#T^("=#4B<L
M"B`@("`G8W8G(#T^("=#5B<L"B`@("`G8WDG(#T^("=#62<L"B`@("`G8WHG
M(#T^("=#6B<L"B`@("`G9&4G(#T^("=$)RP*("`@("=D:B<@/3X@)T1*22<L
M"B`@("`G9&LG(#T^("=$2R<L"B`@("`G9&\G(#T^("=$3TTG+`H@("`@)VMP
M)R`]/B`G1%922R<L"B`@("`G8FHG(#T^("=$62<L"B`@("`G9'HG(#T^("=$
M6B<L"B`@("`G97,G(#T^("=%)RP*("`@("=K92<@/3X@)T5!2R<L"B`@("`G
M='HG(#T^("=%050G+`H@("`@)W5G)R`]/B`G14%5)RP*("`@("=E8R<@/3X@
M)T5#)RP*("`@("=E<B<@/3X@)T52)RP*("`@("=S=B<@/3X@)T53)RP*("`@
M("=E92<@/3X@)T535"<L"B`@("`G96<G(#T^("=%5"<L"B`@("`G970G(#T^
M("=%5$@G+`H@("`@)V9R)R`]/B`G1B<L"B`@("`G9FDG(#T^("=&24XG+`H@
M("`@)V9J)R`]/B`G1DI))RP*("`@("=L:2<@/3X@)T9,)RP*("`@("=F;R<@
M/3X@)T9/)RP*("`@("=F;2<@/3X@)T9332<L"B`@("`G9V$G(#T^("=')RP*
M("`@("=G8B<@/3X@)T=")RP*("`@("=G:2<@/3X@)T="6B<L"B`@("`G9W0G
M(#T^("='0T$G+`H@("`@)V=E)R`]/B`G1T4G+`H@("`@)V=H)R`]/B`G1T@G
M+`H@("`@)V=Q)R`]/B`G1U$G+`H@("`@)V=R)R`]/B`G1U(G+`H@("`@)V=Y
M)R`]/B`G1U59)RP*("`@("=H=2<@/3X@)T@G+`H@("`@)VAK)R`]/B`G2$LG
M+`H@("`@)VAN)R`]/B`G2$XG+`H@("`@)VAR)R`]/B`G2%(G+`H@("`@)VET
M)R`]/B`G22<L"B`@("`G:6PG(#T^("=)3"<L"B`@("`G:6XG(#T^("=)3D0G
M+`H@("`@)VER)R`]/B`G25(G+`H@("`@)VEE)R`]/B`G25),)RP*("`@("=I
M<2<@/3X@)TE242<L"B`@("`G:7,G(#T^("=)4R<L"B`@("`G:G`G(#T^("=*
M)RP*("`@("=J;2<@/3X@)TI!)RP*("`@("=J;R<@/3X@)TI/4B<L"B`@("`G
M:V@G(#T^("=+)RP*("`@("=K:2<@/3X@)TM)4B<L"B`@("`G9VPG(#T^("=+
M3B<L"B`@("`G:V<G(#T^("=+4R<L"B`@("`G<V$G(#T^("=+4T$G+`H@("`@
M)VMW)R`]/B`G2U=4)RP*("`@("=K>B<@/3X@)TM:)RP*("`@("=L=2<@/3X@
M)TPG+`H@("`@)VQA)R`]/B`G3$%/)RP*("`@("=L>2<@/3X@)TQ!4B<L"B`@
M("`G;'(G(#T^("=,0B<L"B`@("`G;',G(#T^("=,4R<L"B`@("`G;'0G(#T^
M("=,5"<L"B`@("`G;'8G(#T^("=,5B<L"B`@("`G;70G(#T^("=-)RP*("`@
M("=M82<@/3X@)TU!)RP*("`@("=M>2<@/3X@)TU!3"<L"B`@("`G;6,G(#T^
M("=-0R<L"B`@("`G;60G(#T^("=-1"<L"B`@("`G;7@G(#T^("=-15@G+`H@
M("`@)VUN)R`]/B`G34=,)RP*("`@("=M:"<@/3X@)TU()RP*("`@("=M:R<@
M/3X@)TU+)RP*("`@("=M>B<@/3X@)TU/0R<L"B`@("`G;74G(#T^("=-4R<L
M"B`@("`G;78G(#T^("=-5B<L"B`@("`G;7<G(#T^("=-5R<L"B`@("`G;6TG
M(#T^("=-64$G+`H@("`@)VYO)R`]/B`G3B<L"B`@("`G86XG(#T^("=.02<L
M"B`@("`G;FPG(#T^("=.3"<L"B`@("`G;GHG(#T^("=.6B<L"B`@("`G;VTG
M(#T^("=/32<L"B`@("`G<'0G(#T^("=0)RP*("`@("=P82<@/3X@)U!!)RP*
M("`@("=P=R<@/3X@)U!!3"<L"B`@("`G<&4G(#T^("=012<L"B`@("`G<&LG
M(#T^("=02R<L"B`@("`G<&PG(#T^("=03"<L"B`@("`G<&<G(#T^("=03D<G
M+`H@("`@)V-N)R`]/B`G4%)#)RP*("`@("=P<R<@/3X@)U!3)RP*("`@("=P
M>2<@/3X@)U!9)RP*("`@("=Q82<@/3X@)U$G+`H@("`@)V%R)R`]/B`G4D$G
M+`H@("`@)V)W)R`]/B`G4D(G+`H@("`@)W1W)R`]/B`G4D,G+`H@("`@)V-F
M)R`]/B`G4D-!)RP*("`@("=C9"<@/3X@)U)#0B<L"B`@("`G8VPG(#T^("=2
M0T@G+`H@("`@)W)E)R`]/B`G4D4G+`H@("`@)V=N)R`]/B`G4D<G+`H@("`@
M)VAT)R`]/B`G4D@G+`H@("`@)VED)R`]/B`G4DDG+`H@("`@)VUR)R`]/B`G
M4DE-)RP*("`@("=L8B<@/3X@)U),)RP*("`@("=M9R<@/3X@)U)-)RP*("`@
M("=M;"<@/3X@)U)-32<L"B`@("`G;F4G(#T^("=23B<L"B`@("`G<F\G(#T^
M("=23R<L"B`@("`G:W(G(#T^("=23TLG+`H@("`@)W5Y)R`]/B`G4D]5)RP*
M("`@("=P:"<@/3X@)U)0)RP*("`@("=S;2<@/3X@)U)332<L"B`@("`G=&<G
M(#T^("=25"<L"B`@("`G<G4G(#T^("=255,G+`H@("`@)W)W)R`]/B`G4E=!
M)RP*("`@("=S92<@/3X@)U,G+`H@("`@)V-S)R`]/B`G4T-')RP*("`@("=K
M;B<@/3X@)U-#3B<L"B`@("`G<WHG(#T^("=31"<L"B`@("`G<V<G(#T^("=3
M1U`G+`H@("`@)W-K)R`]/B`G4TLG+`H@("`@)W-I)R`]/B`G4TQ/)RP*("`@
M("=S<B<@/3X@)U--12<L"B`@("`G<VXG(#T^("=33B<L"B`@("`G<V(G(#T^
M("=33TPG+`H@("`@)W-O)R`]/B`G4U`G+`H@("`@)W-T)R`]/B`G4U10)RP*
M("`@("=S9"<@/3X@)U-51"<L"B`@("`G<V,G(#T^("=362<L"B`@("`G<WDG
M(#T^("=365(G+`H@("`@)W1D)R`]/B`G5$-()RP*("`@("=T:"<@/3X@)U1(
M02<L"B`@("`G=&HG(#T^("=42B<L"B`@("`G=&PG(#T^("=43"<L"B`@("`G
M=&TG(#T^("=432<L"B`@("`G=&XG(#T^("=43B<L"B`@("`G=&\G(#T^("=4
M3R<L"B`@("`G='(G(#T^("=44B<L"B`@("`G='0G(#T^("=45"<L"B`@("`G
M='8G(#T^("=4558G+`H@("`@)W5A)R`]/B`G54$G+`H@("`@)V%E)R`]/B`G
M54%%)RP*("`@("=U<R<@/3X@)U5302<L"B`@("`G=7HG(#T^("=56B<L"B`@
M("`G=F$G(#T^("=6)RP*("`@("=V;B<@/3X@)U9.)RP*("`@("=V=2<@/3X@
M)U95)RP*("`@("='32<@/3X@)U=!1R<L"B`@("`G<VPG(#T^("=704PG+`H@
M("`@)VYG)R`]/B`G5T%.)RP*("`@("=D;2<@/3X@)U=$)RP*("`@("=G9"<@
M/3X@)U=')RP*("`@("=L8R<@/3X@)U=,)RP*("`@("=W<R<@/3X@)U=3)RP*
M("`@("=V8R<@/3X@)U=6)RP*("`@("=Y92<@/3X@)UE!4B<L"B`@("`G=F4G
M(#T^("=95B<L"B`@("`G>FTG(#T^("=:)RP*("`@("=Z82<@/3X@)UI!)RP*
M("`@("=Z=R<@/3X@)UI7)PHI.PH`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].3%,O
M=&QD+G!H<```````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`Q-C<R-2`Q,#4Q-30S-#$T,"`P,C$S,#(`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1O<"!L979E
M;"!D;VUA:6X@*%1,1"D@;&ES="!F;W(@8V]U;G1R>2!C;V1E<RX*("H@1V5N
M97)A=&5D(&9R;VT@24%.02`H26YT97)N970@07-S:6=N960@3G5M8F5R<R!!
M=71H;W)I='DI(&1A=&$@;&]C871E9`H@*B!A="!H='1P.B\O=W=W+FEA;F$N
M;W)G+V-C=&QD+V-C=&QD+7=H;VES+FAT;0H@*@H@*B!&;W)M870Z"B`J("`@
M)'1L9%LG8V]U;G1R>6-O9&4G72`]("=C;W5N=')Y;F%M92<["B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TY,4R].3%,O=&QD+G!H<"QV(#$N-2`R,#`T+S`Q
M+S`T(#`R.C(T.C`U(&UD:G5K:6,@17AP("0*("H*("H@0'!A8VMA9V4@2&]R
M9&5?3DQ3"B`J+PHD=&QD(#T@87)R87DH"B`@("`G86,G(#T^(%\H(D%S8V5N
M<VEO;B!)<VQA;F0B*2P*("`@("=A9"<@/3X@7R@B06YD;W)R82(I+`H@("`@
M)V%E)R`]/B!?*")5;FET960@07)A8B!%;6ER871E<R(I+`H@("`@)V%F)R`]
M/B!?*")!9F=H86YI<W1A;B(I+`H@("`@)V%G)R`]/B!?*")!;G1I9W5A(&%N
M9"!"87)B=61A(BDL"B`@("`G86DG(#T^(%\H(D%N9W5I;&QA(BDL"B`@("`G
M86PG(#T^(%\H(D%L8F%N:6$B*2P*("`@("=A;2<@/3X@7R@B07)M96YI82(I
M+`H@("`@)V%N)R`]/B!?*").971H97)L86YD<R!!;G1I;&QE<R(I+`H@("`@
M)V%O)R`]/B!?*")!;F=O;&$B*2P*("`@("=A<2<@/3X@7R@B06YT87)C=&EC
M82(I+`H@("`@)V%R)R`]/B!?*")!<F=E;G1I;F$B*2P*("`@("=A<R<@/3X@
M7R@B06UE<FEC86X@4V%M;V$B*2P*("`@("=A="<@/3X@7R@B075S=')I82(I
M+`H@("`@)V%U)R`]/B!?*")!=7-T<F%L:6$B*2P*("`@("=A=R<@/3X@7R@B
M07)U8F$B*2P*("`@("=A>B<@/3X@7R@B07IE<F)A:6IA;B(I+`H@("`@)V)A
M)R`]/B!?*")";W-N:6$@86YD($AE<GIE9V]V:6YA(BDL"B`@("`G8F(G(#T^
M(%\H(D)A<F)A9&]S(BDL"B`@("`G8F0G(#T^(%\H(D)A;F=L861E<V@B*2P*
M("`@("=B92<@/3X@7R@B0F5L9VEU;2(I+`H@("`@)V)F)R`]/B!?*")"=7)K
M:6YA($9A<V\B*2P*("`@("=B9R<@/3X@7R@B0G5L9V%R:6$B*2P*("`@("=B
M:"<@/3X@7R@B0F%H<F%I;B(I+`H@("`@)V)I)R`]/B!?*")"=7)U;F1I(BDL
M"B`@("`G8FHG(#T^(%\H(D)E;FEN(BDL"B`@("`G8FTG(#T^(%\H(D)E<FUU
M9&$B*2P*("`@("=B;B<@/3X@7R@B0G)U;F5I($1A<G5S<V%L86TB*2P*("`@
M("=B;R<@/3X@7R@B0F]L:79I82(I+`H@("`@)V)R)R`]/B!?*")"<F%Z:6PB
M*2P*("`@("=B<R<@/3X@7R@B0F%H86UA<R(I+`H@("`@)V)T)R`]/B!?*")"
M:'5T86XB*2P*("`@("=B=B<@/3X@7R@B0F]U=F5T($ES;&%N9"(I+`H@("`@
M)V)W)R`]/B!?*")";W1S=V%N82(I+`H@("`@)V)Y)R`]/B!?*")"96QA<G5S
M(BDL"B`@("`G8GHG(#T^(%\H(D)E;&EZ92(I+`H@("`@)V-A)R`]/B!?*")#
M86YA9&$B*2P*("`@("=C8R<@/3X@7R@B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B*2P*("`@("=C9"<@/3X@7R@B0V]N9V\L(%1H92!$96UO8W)A=&EC(%)E
M<'5B;&EC(&]F('1H92(I+`H@("`@)V-F)R`]/B!?*")#96YT<F%L($%F<FEC
M86X@4F5P=6)L:6,B*2P*("`@("=C9R<@/3X@7R@B0V]N9V\B*2P*("`@("=C
M:"<@/3X@7R@B4W=I='IE<FQA;F0B*2P*("`@("=C:2<@/3X@7R@B0V]T92!D
M)TEV;VER92(I+`H@("`@)V-K)R`]/B!?*")#;V]K($ES;&%N9',B*2P*("`@
M("=C;"<@/3X@7R@B0VAI;&4B*2P*("`@("=C;2<@/3X@7R@B0V%M97)O;VXB
M*2P*("`@("=C;B<@/3X@7R@B0VAI;F$B*2P*("`@("=C;R<@/3X@7R@B0V]L
M;VUB:6$B*2P*("`@("=C<B<@/3X@7R@B0V]S=&$@4FEC82(I+`H@("`@)V-U
M)R`]/B!?*")#=6)A(BDL"B`@("`G8W8G(#T^(%\H(D-A<&4@5F5R9&4B*2P*
M("`@("=C>"<@/3X@7R@B0VAR:7-T;6%S($ES;&%N9"(I+`H@("`@)V-Y)R`]
M/B!?*")#>7!R=7,B*2P*("`@("=C>B<@/3X@7R@B0WIE8V@@4F5P=6)L:6,B
M*2P*("`@("=D92<@/3X@7R@B1V5R;6%N>2(I+`H@("`@)V1J)R`]/B!?*")$
M:FEB;W5T:2(I+`H@("`@)V1K)R`]/B!?*")$96YM87)K(BDL"B`@("`G9&TG
M(#T^(%\H(D1O;6EN:6-A(BDL"B`@("`G9&\G(#T^(%\H(D1O;6EN:6-A;B!2
M97!U8FQI8R(I+`H@("`@)V1Z)R`]/B!?*")!;&=E<FEA(BDL"B`@("`G96,G
M(#T^(%\H(D5C=6%D;W(B*2P*("`@("=E92<@/3X@7R@B17-T;VYI82(I+`H@
M("`@)V5G)R`]/B!?*")%9WEP="(I+`H@("`@)V5H)R`]/B!?*")797-T97)N
M(%-A:&%R82(I+`H@("`@)V5R)R`]/B!?*")%<FET<F5A(BDL"B`@("`G97,G
M(#T^(%\H(E-P86EN(BDL"B`@("`G970G(#T^(%\H(D5T:&EO<&EA(BDL"B`@
M("`G9FDG(#T^(%\H(D9I;FQA;F0B*2P*("`@("=F:B<@/3X@7R@B1FEJ:2(I
M+`H@("`@)V9K)R`]/B!?*")&86QK;&%N9"!)<VQA;F1S("A-86QV:6YA<RDB
M*2P*("`@("=F;2<@/3X@7R@B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E
M<R!O9B(I+`H@("`@)V9O)R`]/B!?*")&87)O92!)<VQA;F1S(BDL"B`@("`G
M9G(G(#T^(%\H(D9R86YC92(I+`H@("`@)V=A)R`]/B!?*")'86)O;B(I+`H@
M("`@)V=D)R`]/B!?*")'<F5N861A(BDL"B`@("`G9V4G(#T^(%\H(D=E;W)G
M:6$B*2P*("`@("=G9B<@/3X@7R@B1G)E;F-H($=U:6%N82(I+`H@("`@)V=G
M)R`]/B!?*")'=65R;G-E>2(I+`H@("`@)V=H)R`]/B!?*")':&%N82(I+`H@
M("`@)V=I)R`]/B!?*")':6)R86QT87(B*2P*("`@("=G;"<@/3X@7R@B1W)E
M96YL86YD(BDL"B`@("`G9VTG(#T^(%\H(D=A;6)I82(I+`H@("`@)V=N)R`]
M/B!?*")'=6EN96$B*2P*("`@("=G<"<@/3X@7R@B1W5A9&5L;W5P92(I+`H@
M("`@)V=Q)R`]/B!?*")%<75A=&]R:6%L($=U:6YE82(I+`H@("`@)V=R)R`]
M/B!?*")'<F5E8V4B*2P*("`@("=G<R<@/3X@7R@B4V]U=&@@1V5O<F=I82!A
M;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B*2P*("`@("=G="<@/3X@
M7R@B1W5A=&5M86QA(BDL"B`@("`G9W4G(#T^(%\H(D=U86TB*2P*("`@("=G
M=R<@/3X@7R@B1W5I;F5A+4)I<W-A=2(I+`H@("`@)V=Y)R`]/B!?*")'=7EA
M;F$B*2P*("`@("=H:R<@/3X@7R@B2&]N9R!+;VYG(BDL"B`@("`G:&TG(#T^
M(%\H(DAE87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(I+`H@("`@
M)VAN)R`]/B!?*")(;VYD=7)A<R(I+`H@("`@)VAR)R`]/B!?*")#<F]A=&EA
M(BDL"B`@("`G:'0G(#T^(%\H(DAA:71I(BDL"B`@("`G:'4G(#T^(%\H(DAU
M;F=A<GDB*2P*("`@("=I9"<@/3X@7R@B26YD;VYE<VEA(BDL"B`@("`G:64G
M(#T^(%\H(DER96QA;F0B*2P*("`@("=I;"<@/3X@7R@B27-R865L(BDL"B`@
M("`G:6TG(#T^(%\H(DES;&4@;V8@36%N(BDL"B`@("`G:6XG(#T^(%\H(DEN
M9&EA(BDL"B`@("`G:6\G(#T^(%\H(D)R:71I<V@@26YD:6%N($]C96%N(%1E
M<G)I=&]R>2(I+`H@("`@)VEQ)R`]/B!?*"))<F%Q(BDL"B`@("`G:7(G(#T^
M(%\H(DER86XL($ES;&%M:6,@4F5P=6)L:6,@;V8B*2P*("`@("=I<R<@/3X@
M7R@B26-E;&%N9"(I+`H@("`@)VET)R`]/B!?*"))=&%L>2(I+`H@("`@)VIE
M)R`]/B!?*")*97)S97DB*2P*("`@("=J;2<@/3X@7R@B2F%M86EC82(I+`H@
M("`@)VIO)R`]/B!?*")*;W)D86XB*2P*("`@("=J<"<@/3X@7R@B2F%P86XB
M*2P*("`@("=K92<@/3X@7R@B2V5N>6$B*2P*("`@("=K9R<@/3X@7R@B2WER
M9WEZ<W1A;B(I+`H@("`@)VMH)R`]/B!?*")#86UB;V1I82(I+`H@("`@)VMI
M)R`]/B!?*")+:7)I8F%T:2(I+`H@("`@)VMM)R`]/B!?*")#;VUO<F]S(BDL
M"B`@("`G:VXG(#T^(%\H(E-A:6YT($MI='1S(&%N9"!.979I<R(I+`H@("`@
M)VMP)R`]/B!?*")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U8FQI
M8R!O9B(I+`H@("`@)VMR)R`]/B!?*")+;W)E82P@4F5P=6)L:6,@;V8B*2P*
M("`@("=K=R<@/3X@7R@B2W5W86ET(BDL"B`@("`G:WDG(#T^(%\H(D-A>6UA
M;B!)<VQA;F1S(BDL"B`@("`G:WHG(#T^(%\H(DMA>F%K:'-T86XB*2P*("`@
M("=L82<@/3X@7R@B3&%O(%!E;W!L92=S($1E;6]C<F%T:6,@4F5P=6)L:6,B
M*2P*("`@("=L8B<@/3X@7R@B3&5B86YO;B(I+`H@("`@)VQC)R`]/B!?*")3
M86EN="!,=6-I82(I+`H@("`@)VQI)R`]/B!?*"),:65C:'1E;G-T96EN(BDL
M"B`@("`G;&LG(#T^(%\H(E-R:2!,86YK82(I+`H@("`@)VQR)R`]/B!?*"),
M:6)E<FEA(BDL"B`@("`G;',G(#T^(%\H(DQE<V]T:&\B*2P*("`@("=L="<@
M/3X@7R@B3&ET:'5A;FEA(BDL"B`@("`G;'4G(#T^(%\H(DQU>&5M8F]U<F<B
M*2P*("`@("=L=B<@/3X@7R@B3&%T=FEA(BDL"B`@("`G;'DG(#T^(%\H(DQI
M8GEA;B!!<F%B($IA;6%H:7)I>6$B*2P*("`@("=M82<@/3X@7R@B36]R;V-C
M;R(I+`H@("`@)VUC)R`]/B!?*")-;VYA8V\B*2P*("`@("=M9"<@/3X@7R@B
M36]L9&]V82P@4F5P=6)L:6,@;V8B*2P*("`@("=M9R<@/3X@7R@B36%D86=A
M<V-A<B(I+`H@("`@)VUH)R`]/B!?*")-87)S:&%L;"!)<VQA;F1S(BDL"B`@
M("`G;6LG(#T^(%\H(DUA8V5D;VYI82P@5&AE($9O<FUE<B!9=6=O<VQA=B!2
M97!U8FQI8R!O9B(I+`H@("`@)VUL)R`]/B!?*")-86QI(BDL"B`@("`G;6TG
M(#T^(%\H(DUY86YM87(B*2P*("`@("=M;B<@/3X@7R@B36]N9V]L:6$B*2P*
M("`@("=M;R<@/3X@7R@B36%C86\B*2P*("`@("=M<"<@/3X@7R@B3F]R=&AE
M<FX@36%R:6%N82!)<VQA;F1S(BDL"B`@("`G;7$G(#T^(%\H(DUA<G1I;FEQ
M=64B*2P*("`@("=M<B<@/3X@7R@B36%U<FET86YI82(I+`H@("`@)VUS)R`]
M/B!?*")-;VYT<V5R<F%T(BDL"B`@("`G;70G(#T^(%\H(DUA;'1A(BDL"B`@
M("`G;74G(#T^(%\H(DUA=7)I=&EU<R(I+`H@("`@)VUV)R`]/B!?*")-86QD
M:79E<R(I+`H@("`@)VUW)R`]/B!?*")-86QA=VDB*2P*("`@("=M>"<@/3X@
M7R@B365X:6-O(BDL"B`@("`G;7DG(#T^(%\H(DUA;&%Y<VEA(BDL"B`@("`G
M;7HG(#T^(%\H(DUO>F%M8FEQ=64B*2P*("`@("=N82<@/3X@7R@B3F%M:6)I
M82(I+`H@("`@)VYC)R`]/B!?*").97<@0V%L961O;FEA(BDL"B`@("`G;F4G
M(#T^(%\H(DYI9V5R(BDL"B`@("`G;F8G(#T^(%\H(DYO<F9O;&L@27-L86YD
M(BDL"B`@("`G;F<G(#T^(%\H(DYI9V5R:6$B*2P*("`@("=N:2<@/3X@7R@B
M3FEC87)A9W5A(BDL"B`@("`G;FPG(#T^(%\H(DYE=&AE<FQA;F1S(BDL"B`@
M("`G;F\G(#T^(%\H(DYO<G=A>2(I+`H@("`@)VYP)R`]/B!?*").97!A;"(I
M+`H@("`@)VYR)R`]/B!?*").875R=2(I+`H@("`@)VYU)R`]/B!?*").:75E
M(BDL"B`@("`G;GHG(#T^(%\H(DYE=R!:96%L86YD(BDL"B`@("`G;VTG(#T^
M(%\H(D]M86XB*2P*("`@("=P82<@/3X@7R@B4&%N86UA(BDL"B`@("`G<&4G
M(#T^(%\H(E!E<G4B*2P*("`@("=P9B<@/3X@7R@B1G)E;F-H(%!O;'EN97-I
M82(I+`H@("`@)W!G)R`]/B!?*")087!U82!.97<@1W5I;F5A(BDL"B`@("`G
M<&@G(#T^(%\H(E!H:6QI<'!I;F5S(BDL"B`@("`G<&LG(#T^(%\H(E!A:VES
M=&%N(BDL"B`@("`G<&PG(#T^(%\H(E!O;&%N9"(I+`H@("`@)W!M)R`]/B!?
M*")386EN="!0:65R<F4@86YD($UI<75E;&]N(BDL"B`@("`G<&XG(#T^(%\H
M(E!I=&-A:7)N(BDL"B`@("`G<'(G(#T^(%\H(E!U97)T;R!2:6-O(BDL"B`@
M("`G<',G(#T^(%\H(E!A;&5S=&EN:6%N(%1E<G)I=&]R>2P@3V-C=7!I960B
M*2P*("`@("=P="<@/3X@7R@B4&]R='5G86PB*2P*("`@("=P=R<@/3X@7R@B
M4&%L874B*2P*("`@("=P>2<@/3X@7R@B4&%R86=U87DB*2P*("`@("=Q82<@
M/3X@7R@B46%T87(B*2P*("`@("=R92<@/3X@7R@B4F5U;FEO;B(I+`H@("`@
M)W)O)R`]/B!?*")2;VUA;FEA(BDL"B`@("`G<G4G(#T^(%\H(E)U<W-I86X@
M1F5D97)A=&EO;B(I+`H@("`@)W)W)R`]/B!?*")2=V%N9&$B*2P*("`@("=S
M82<@/3X@7R@B4V%U9&D@07)A8FEA(BDL"B`@("`G<V(G(#T^(%\H(E-O;&]M
M;VX@27-L86YD<R(I+`H@("`@)W-C)R`]/B!?*")397EC:&5L;&5S(BDL"B`@
M("`G<V0G(#T^(%\H(E-U9&%N(BDL"B`@("`G<V4G(#T^(%\H(E-W961E;B(I
M+`H@("`@)W-G)R`]/B!?*")3:6YG87!O<F4B*2P*("`@("=S:"<@/3X@7R@B
M4V%I;G0@2&5L96YA(BDL"B`@("`G<VDG(#T^(%\H(E-L;W9E;FEA(BDL"B`@
M("`G<VHG(#T^(%\H(E-V86QB87)D(&%N9"!*86X@36%Y96XB*2P*("`@("=S
M:R<@/3X@7R@B4VQO=F%K:6$B*2P*("`@("=S;"<@/3X@7R@B4VEE<G)A($QE
M;VYE(BDL"B`@("`G<VTG(#T^(%\H(E-A;B!-87)I;F\B*2P*("`@("=S;B<@
M/3X@7R@B4V5N96=A;"(I+`H@("`@)W-O)R`]/B!?*")3;VUA;&EA(BDL"B`@
M("`G<W(G(#T^(%\H(E-U<FEN86UE(BDL"B`@("`G<W0G(#T^(%\H(E-A;R!4
M;VUE(&%N9"!0<FEN8VEP92(I+`H@("`@)W-V)R`]/B!?*")%;"!386QV861O
M<B(I+`H@("`@)W-Y)R`]/B!?*")3>7)I86X@07)A8B!297!U8FQI8R(I+`H@
M("`@)W-Z)R`]/B!?*")3=V%Z:6QA;F0B*2P*("`@("=T8R<@/3X@7R@B5'5R
M:W,@86YD($-A:6-O<R!)<VQA;F1S(BDL"B`@("`G=&0G(#T^(%\H(D-H860B
M*2P*("`@("=T9B<@/3X@7R@B1G)E;F-H(%-O=71H97)N(%1E<G)I=&]R:65S
M(BDL"B`@("`G=&<G(#T^(%\H(E1O9V\B*2P*("`@("=T:"<@/3X@7R@B5&AA
M:6QA;F0B*2P*("`@("=T:B<@/3X@7R@B5&%J:6MI<W1A;B(I+`H@("`@)W1K
M)R`]/B!?*")4;VME;&%U(BDL"B`@("`G=&TG(#T^(%\H(E1U<FMM96YI<W1A
M;B(I+`H@("`@)W1N)R`]/B!?*")4=6YI<VEA(BDL"B`@("`G=&\G(#T^(%\H
M(E1O;F=A(BDL"B`@("`G='`G(#T^(%\H(E1I;6]R+4QE<W1E(BDL"B`@("`G
M='(G(#T^(%\H(E1U<FME>2(I+`H@("`@)W1T)R`]/B!?*")4<FEN:61A9"!A
M;F0@5&]B86=O(BDL"B`@("`G='8G(#T^(%\H(E1U=F%L=2(I+`H@("`@)W1W
M)R`]/B!?*")486EW86XB*2P*("`@("=T>B<@/3X@7R@B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(I+`H@("`@)W5A)R`]/B!?*")5:W)A:6YE(BDL
M"B`@("`G=6<G(#T^(%\H(E5G86YD82(I+`H@("`@)W5K)R`]/B!?*")5;FET
M960@2VEN9V1O;2(I+`H@("`@)W5M)R`]/B!?*")5;FET960@4W1A=&5S($UI
M;F]R($]U=&QY:6YG($ES;&%N9',B*2P*("`@("=U<R<@/3X@7R@B56YI=&5D
M(%-T871E<R(I+`H@("`@)W5Y)R`]/B!?*")5<G5G=6%Y(BDL"B`@("`G=7HG
M(#T^(%\H(E5Z8F5K:7-T86XB*2P*("`@("=V82<@/3X@7R@B2&]L>2!3964@
M*%9A=&EC86X@0VET>2!3=&%T92DB*2P*("`@("=V8R<@/3X@7R@B4V%I;G0@
M5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B*2P*("`@("=V92<@/3X@7R@B
M5F5N97IU96QA(BDL"B`@("`G=F<G(#T^(%\H(E9I<F=I;B!)<VQA;F1S+"!"
M<FET:7-H(BDL"B`@("`G=FDG(#T^(%\H(E9I<F=I;B!)<VQA;F1S+"!5+E,N
M(BDL"B`@("`G=FXG(#T^(%\H(E9I970@3F%M(BDL"B`@("`G=G4G(#T^(%\H
M(E9A;G5A='4B*2P*("`@("=W9B<@/3X@7R@B5V%L;&ES(&%N9"!&=71U;F$B
M*2P*("`@("=W<R<@/3X@7R@B4V%M;V$B*2P*("`@("=Y92<@/3X@7R@B665M
M96XB*2P*("`@("=Y="<@/3X@7R@B36%Y;W1T92(I+`H@("`@)WEU)R`]/B!?
M*")9=6=O<VQA=FEA(BDL"B`@("`G>F$G(#T^(%\H(E-O=71H($%F<FEC82(I
M+`H@("`@)WIM)R`]/B!?*"):86UB:6$B*2P*("`@("=Z=R<@/3X@7R@B6FEM
M8F%B=V4B*0HI.PH`````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TY,
M4R]C;W5N=')I97,N<&AP````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$V,S`U(#$P-3$U-#,T,30P(#`R,C4R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($E3
M3RTS,38V(&-O=6YT<GD@;&ES="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M3DQ3+TY,4R]C;W5N=')I97,N<&AP+'8@,2XS+C$R+C$@,C`P-2\Q,"\Q."`Q
M,3HP,3HQ."!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?3DQ3"B`J
M+PH*)&-O=6YT<FEE<R`](&%R<F%Y*`H@("`@)T%&)R`]/B!?*")!9F=H86YI
M<W1A;B(I+`H@("`@)T%,)R`]/B!?*")!;&)A;FEA(BDL"B`@("`G1%HG(#T^
M(%\H(D%L9V5R:6$B*2P*("`@("=!4R<@/3X@7R@B06UE<FEC86X@4V%M;V$B
M*2P*("`@("=!1"<@/3X@7R@B06YD;W)R82(I+`H@("`@)T%/)R`]/B!?*")!
M;F=O;&$B*2P*("`@("=!22<@/3X@7R@B06YG=6EL;&$B*2P*("`@("=!42<@
M/3X@7R@B06YT87)C=&EC82(I+`H@("`@)T%')R`]/B!?*")!;G1I9W5A(&%N
M9"!"87)B=61A(BDL"B`@("`G05(G(#T^(%\H(D%R9V5N=&EN82(I+`H@("`@
M)T%-)R`]/B!?*")!<FUE;FEA(BDL"B`@("`G05<G(#T^(%\H(D%R=6)A(BDL
M"B`@("`G054G(#T^(%\H(D%U<W1R86QI82(I+`H@("`@)T%4)R`]/B!?*")!
M=7-T<FEA(BDL"B`@("`G05HG(#T^(%\H(D%Z97)B86EJ86XB*2P*("`@("="
M4R<@/3X@7R@B0F%H86UA<R(I+`H@("`@)T)()R`]/B!?*")"86AR86EN(BDL
M"B`@("`G0D0G(#T^(%\H(D)A;F=L861E<V@B*2P*("`@("="0B<@/3X@7R@B
M0F%R8F%D;W,B*2P*("`@("="62<@/3X@7R@B0F5L87)U<R(I+`H@("`@)T)%
M)R`]/B!?*")"96QG:75M(BDL"B`@("`G0EHG(#T^(%\H(D)E;&EZ92(I+`H@
M("`@)T)*)R`]/B!?*")"96YI;B(I+`H@("`@)T)-)R`]/B!?*")"97)M=61A
M(BDL"B`@("`G0E0G(#T^(%\H(D)H=71A;B(I+`H@("`@)T)/)R`]/B!?*")"
M;VQI=FEA(BDL"B`@("`G0D$G(#T^(%\H(D)O<VYI82!A;F0@2&5R>F5G;W9I
M;F$B*2P*("`@("="5R<@/3X@7R@B0F]T<W=A;F$B*2P*("`@("="5B<@/3X@
M7R@B0F]U=F5T($ES;&%N9"(I+`H@("`@)T)2)R`]/B!?*")"<F%Z:6PB*2P*
M("`@("=)3R<@/3X@7R@B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(BDL"B`@("`G0DXG(#T^(%\H(D)R=6YE:2!$87)U<W-A;&%M(BDL"B`@("`G
M0D<G(#T^(%\H(D)U;&=A<FEA(BDL"B`@("`G0D8G(#T^(%\H(D)U<FMI;F$@
M1F%S;R(I+`H@("`@)T)))R`]/B!?*")"=7)U;F1I(BDL"B`@("`G2T@G(#T^
M(%\H(D-A;6)O9&EA(BDL"B`@("`G0TTG(#T^(%\H(D-A;65R;V]N(BDL"B`@
M("`G0T$G(#T^(%\H(D-A;F%D82(I+`H@("`@)T-6)R`]/B!?*")#87!E(%9E
M<F1E(BDL"B`@("`G2UDG(#T^(%\H(D-A>6UA;B!)<VQA;F1S(BDL"B`@("`G
M0T8G(#T^(%\H(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(I+`H@("`@)U1$
M)R`]/B!?*")#:&%D(BDL"B`@("`G0TPG(#T^(%\H(D-H:6QE(BDL"B`@("`G
M0TXG(#T^(%\H(D-H:6YA(BDL"B`@("`G0U@G(#T^(%\H(D-H<FES=&UA<R!)
M<VQA;F0B*2P*("`@("=#0R<@/3X@7R@B0V]C;W,@*$ME96QI;F<I($ES;&%N
M9',B*2P*("`@("=#3R<@/3X@7R@B0V]L;VUB:6$B*2P*("`@("=+32<@/3X@
M7R@B0V]M;W)O<R(I+`H@("`@)T-')R`]/B!?*")#;VYG;R(I+`H@("`@)T-$
M)R`]/B!?*")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE
M(BDL"B`@("`G0TLG(#T^(%\H(D-O;VL@27-L86YD<R(I+`H@("`@)T-2)R`]
M/B!?*")#;W-T82!2:6-A(BDL"B`@("`G0TDG(#T^(%\H(D-O=&4@9"=)=F]I
M<F4B*2P*("`@("=(4B<@/3X@7R@B0W)O871I82(I+`H@("`@)T-5)R`]/B!?
M*")#=6)A(BDL"B`@("`G0UDG(#T^(%\H(D-Y<')U<R(I+`H@("`@)T-:)R`]
M/B!?*")#>F5C:"!297!U8FQI8R(I+`H@("`@)T1+)R`]/B!?*")$96YM87)K
M(BDL"B`@("`G1$HG(#T^(%\H(D1J:6)O=71I(BDL"B`@("`G1$TG(#T^(%\H
M(D1O;6EN:6-A(BDL"B`@("`G1$\G(#T^(%\H(D1O;6EN:6-A;B!297!U8FQI
M8R(I+`H@("`@)T5#)R`]/B!?*")%8W5A9&]R(BDL"B`@("`G14<G(#T^(%\H
M(D5G>7!T(BDL"B`@("`G4U8G(#T^(%\H(D5L(%-A;'9A9&]R(BDL"B`@("`G
M1U$G(#T^(%\H(D5Q=6%T;W)I86P@1W5I;F5A(BDL"B`@("`G15(G(#T^(%\H
M(D5R:71R96$B*2P*("`@("=%12<@/3X@7R@B17-T;VYI82(I+`H@("`@)T54
M)R`]/B!?*")%=&AI;W!I82(I+`H@("`@)T9+)R`]/B!?*")&86QK;&%N9"!)
M<VQA;F1S("A-86QV:6YA<RDB*2P*("`@("=&3R<@/3X@7R@B1F%R;V4@27-L
M86YD<R(I+`H@("`@)T9*)R`]/B!?*")&:6II(BDL"B`@("`G1DDG(#T^(%\H
M(D9I;FQA;F0B*2P*("`@("=&4B<@/3X@7R@B1G)A;F-E(BDL"B`@("`G1T8G
M(#T^(%\H(D9R96YC:"!'=6EA;F$B*2P*("`@("=01B<@/3X@7R@B1G)E;F-H
M(%!O;'EN97-I82(I+`H@("`@)U1&)R`]/B!?*")&<F5N8V@@4V]U=&AE<FX@
M5&5R<FET;W)I97,B*2P*("`@("='02<@/3X@7R@B1V%B;VXB*2P*("`@("='
M32<@/3X@7R@B1V%M8FEA(BDL"B`@("`G1T4G(#T^(%\H(D=E;W)G:6$B*2P*
M("`@("=$12<@/3X@7R@B1V5R;6%N>2(I+`H@("`@)T=()R`]/B!?*")':&%N
M82(I+`H@("`@)T=))R`]/B!?*")':6)R86QT87(B*2P*("`@("='4B<@/3X@
M7R@B1W)E96-E(BDL"B`@("`G1TPG(#T^(%\H(D=R965N;&%N9"(I+`H@("`@
M)T=$)R`]/B!?*")'<F5N861A(BDL"B`@("`G1U`G(#T^(%\H(D=U861E;&]U
M<&4B*2P*("`@("='52<@/3X@7R@B1W5A;2(I+`H@("`@)T=4)R`]/B!?*")'
M=6%T96UA;&$B*2P*("`@("='3B<@/3X@7R@B1W5I;F5A(BDL"B`@("`G1U<G
M(#T^(%\H(D=U:6YE82U":7-S874B*2P*("`@("='62<@/3X@7R@B1W5Y86YA
M(BDL"B`@("`G2%0G(#T^(%\H(DAA:71I(BDL"B`@("`G2$TG(#T^(%\H(DAE
M87)D($ES;&%N9"!A;F0@36-$;VYA;&0@27-L86YD<R(I+`H@("`@)U9!)R`]
M/B!?*")(;VQY(%-E92`H5F%T:6-A;B!#:71Y(%-T871E*2(I+`H@("`@)TA.
M)R`]/B!?*")(;VYD=7)A<R(I+`H@("`@)TA+)R`]/B!?*")(;VYG($MO;F<B
M*2P*("`@("=(52<@/3X@7R@B2'5N9V%R>2(I+`H@("`@)TE3)R`]/B!?*"))
M8V5L86YD(BDL"B`@("`G24XG(#T^(%\H(DEN9&EA(BDL"B`@("`G240G(#T^
M(%\H(DEN9&]N97-I82(I+`H@("`@)TE2)R`]/B!?*"))<F%N+"!)<VQA;6EC
M(%)E<'5B;&EC(&]F(BDL"B`@("`G25$G(#T^(%\H(DER87$B*2P*("`@("=)
M12<@/3X@7R@B27)E;&%N9"(I+`H@("`@)TE,)R`]/B!?*"))<W)A96PB*2P*
M("`@("=)5"<@/3X@7R@B271A;'DB*2P*("`@("=*32<@/3X@7R@B2F%M86EC
M82(I+`H@("`@)TI0)R`]/B!?*")*87!A;B(I+`H@("`@)TI/)R`]/B!?*")*
M;W)D86XB*2P*("`@("=+6B<@/3X@7R@B2V%Z86MH<W1A;B(I+`H@("`@)TM%
M)R`]/B!?*")+96YY82(I+`H@("`@)TM))R`]/B!?*")+:7)I8F%T:2(I+`H@
M("`@)TM0)R`]/B!?*")+;W)E82P@1&5M;V-R871I8R!096]P;&4G<R!297!U
M8FQI8R!O9B(I+`H@("`@)TM2)R`]/B!?*")+;W)E82P@4F5P=6)L:6,@;V8B
M*2P*("`@("=+5R<@/3X@7R@B2W5W86ET(BDL"B`@("`G2T<G(#T^(%\H(DMY
M<F=Y>G-T86XB*2P*("`@("=,02<@/3X@7R@B3&%O(%!E;W!L92=S($1E;6]C
M<F%T:6,@4F5P=6)L:6,B*2P*("`@("=,5B<@/3X@7R@B3&%T=FEA(BDL"B`@
M("`G3$(G(#T^(%\H(DQE8F%N;VXB*2P*("`@("=,4R<@/3X@7R@B3&5S;W1H
M;R(I+`H@("`@)TQ2)R`]/B!?*"),:6)E<FEA(BDL"B`@("`G3%DG(#T^(%\H
M(DQI8GEA;B!!<F%B($IA;6%H:7)I>6$B*2P*("`@("=,22<@/3X@7R@B3&EE
M8VAT96YS=&5I;B(I+`H@("`@)TQ4)R`]/B!?*"),:71H=6%N:6$B*2P*("`@
M("=,52<@/3X@7R@B3'5X96UB;W5R9R(I+`H@("`@)TU/)R`]/B!?*")-86-A
M;R(I+`H@("`@)TU+)R`]/B!?*")-86-E9&]N:6$L(%1H92!&;W)M97(@675G
M;W-L878@4F5P=6)L:6,@;V8B*2P*("`@("=-1R<@/3X@7R@B36%D86=A<V-A
M<B(I+`H@("`@)TU7)R`]/B!?*")-86QA=VDB*2P*("`@("=-62<@/3X@7R@B
M36%L87ES:6$B*2P*("`@("=-5B<@/3X@7R@B36%L9&EV97,B*2P*("`@("=-
M3"<@/3X@7R@B36%L:2(I+`H@("`@)TU4)R`]/B!?*")-86QT82(I+`H@("`@
M)TU()R`]/B!?*")-87)S:&%L;"!)<VQA;F1S(BDL"B`@("`G35$G(#T^(%\H
M(DUA<G1I;FEQ=64B*2P*("`@("=-4B<@/3X@7R@B36%U<FET86YI82(I+`H@
M("`@)TU5)R`]/B!?*")-875R:71I=7,B*2P*("`@("=95"<@/3X@7R@B36%Y
M;W1T92(I+`H@("`@)TU8)R`]/B!?*")-97AI8V\B*2P*("`@("=&32<@/3X@
M7R@B36EC<F]N97-I82P@1F5D97)A=&5D(%-T871E<R!O9B(I+`H@("`@)TU$
M)R`]/B!?*")-;VQD;W9A+"!297!U8FQI8R!O9B(I+`H@("`@)TU#)R`]/B!?
M*")-;VYA8V\B*2P*("`@("=-3B<@/3X@7R@B36]N9V]L:6$B*2P*("`@("=-
M4R<@/3X@7R@B36]N='-E<G)A="(I+`H@("`@)TU!)R`]/B!?*")-;W)O8V-O
M(BDL"B`@("`G35HG(#T^(%\H(DUO>F%M8FEQ=64B*2P*("`@("=-32<@/3X@
M7R@B37EA;FUA<B(I+`H@("`@)TY!)R`]/B!?*").86UI8FEA(BDL"B`@("`G
M3E(G(#T^(%\H(DYA=7)U(BDL"B`@("`G3E`G(#T^(%\H(DYE<&%L(BDL"B`@
M("`G3DPG(#T^(%\H(DYE=&AE<FQA;F1S(BDL"B`@("`G04XG(#T^(%\H(DYE
M=&AE<FQA;F1S($%N=&EL;&5S(BDL"B`@("`G3D,G(#T^(%\H(DYE=R!#86QE
M9&]N:6$B*2P*("`@("=.6B<@/3X@7R@B3F5W(%IE86QA;F0B*2P*("`@("=.
M22<@/3X@7R@B3FEC87)A9W5A(BDL"B`@("`G3D4G(#T^(%\H(DYI9V5R(BDL
M"B`@("`G3D<G(#T^(%\H(DYI9V5R:6$B*2P*("`@("=.52<@/3X@7R@B3FEU
M92(I+`H@("`@)TY&)R`]/B!?*").;W)F;VQK($ES;&%N9"(I+`H@("`@)TU0
M)R`]/B!?*").;W)T:&5R;B!-87)I86YA($ES;&%N9',B*2P*("`@("=.3R<@
M/3X@7R@B3F]R=V%Y(BDL"B`@("`G3TTG(#T^(%\H(D]M86XB*2P*("`@("=0
M2R<@/3X@7R@B4&%K:7-T86XB*2P*("`@("=05R<@/3X@7R@B4&%L874B*2P*
M("`@("=04R<@/3X@7R@B4&%L97-T:6YI86X@5&5R<FET;W)Y+"!/8V-U<&EE
M9"(I+`H@("`@)U!!)R`]/B!?*")086YA;6$B*2P*("`@("=01R<@/3X@7R@B
M4&%P=6$@3F5W($=U:6YE82(I+`H@("`@)U!9)R`]/B!?*")087)A9W5A>2(I
M+`H@("`@)U!%)R`]/B!?*")097)U(BDL"B`@("`G4$@G(#T^(%\H(E!H:6QI
M<'!I;F5S(BDL"B`@("`G4$XG(#T^(%\H(E!I=&-A:7)N(BDL"B`@("`G4$PG
M(#T^(%\H(E!O;&%N9"(I+`H@("`@)U!4)R`]/B!?*")0;W)T=6=A;"(I+`H@
M("`@)U!2)R`]/B!?*")0=65R=&\@4FEC;R(I+`H@("`@)U%!)R`]/B!?*")1
M871A<B(I+`H@("`@)U)%)R`]/B!?*")2975N:6]N(BDL"B`@("`G4D\G(#T^
M(%\H(E)O;6%N:6$B*2P*("`@("=252<@/3X@7R@B4G5S<VEA;B!&961E<F%T
M:6]N(BDL"B`@("`G4E<G(#T^(%\H(E)W86YD82(I+`H@("`@)U-()R`]/B!?
M*")386EN="!(96QE;F$B*2P*("`@("=+3B<@/3X@7R@B4V%I;G0@2VET=',@
M86YD($YE=FES(BDL"B`@("`G3$,G(#T^(%\H(E-A:6YT($QU8VEA(BDL"B`@
M("`G4$TG(#T^(%\H(E-A:6YT(%!I97)R92!A;F0@36EQ=65L;VXB*2P*("`@
M("=60R<@/3X@7R@B4V%I;G0@5FEN8V5N="!A;F0@=&AE($=R96YA9&EN97,B
M*2P*("`@("=74R<@/3X@7R@B4V%M;V$B*2P*("`@("=332<@/3X@7R@B4V%N
M($UA<FEN;R(I+`H@("`@)U-4)R`]/B!?*")386\@5&]M92!A;F0@4')I;F-I
M<&4B*2P*("`@("=302<@/3X@7R@B4V%U9&D@07)A8FEA(BDL"B`@("`G4TXG
M(#T^(%\H(E-E;F5G86PB*2P*("`@("=#4R<@/3X@7R@B4V5R8FEA(&%N9"!-
M;VYT96YE9W)O(BDL"B`@("`G4T,G(#T^(%\H(E-E>6-H96QL97,B*2P*("`@
M("=33"<@/3X@7R@B4VEE<G)A($QE;VYE(BDL"B`@("`G4T<G(#T^(%\H(E-I
M;F=A<&]R92(I+`H@("`@)U-+)R`]/B!?*")3;&]V86MI82(I+`H@("`@)U-)
M)R`]/B!?*")3;&]V96YI82(I+`H@("`@)U-")R`]/B!?*")3;VQO;6]N($ES
M;&%N9',B*2P*("`@("=33R<@/3X@7R@B4V]M86QI82(I+`H@("`@)UI!)R`]
M/B!?*")3;W5T:"!!9G)I8V$B*2P*("`@("='4R<@/3X@7R@B4V]U=&@@1V5O
M<F=I82!A;F0@=&AE(%-O=71H(%-A;F1W:6-H($ES;&%N9',B*2P*("`@("=%
M4R<@/3X@7R@B4W!A:6XB*2P*("`@("=,2R<@/3X@7R@B4W)I($QA;FMA(BDL
M"B`@("`G4T0G(#T^(%\H(E-U9&%N(BDL"B`@("`G4U(G(#T^(%\H(E-U<FEN
M86UE(BDL"B`@("`G4THG(#T^(%\H(E-V86QB87)D(&%N9"!*86X@36%Y96XB
M*2P*("`@("=36B<@/3X@7R@B4W=A>FEL86YD(BDL"B`@("`G4T4G(#T^(%\H
M(E-W961E;B(I+`H@("`@)T-()R`]/B!?*")3=VET>F5R;&%N9"(I+`H@("`@
M)U-9)R`]/B!?*")3>7)I86X@07)A8B!297!U8FQI8R(I+`H@("`@)U17)R`]
M/B!?*")486EW86XL(%!R;W9I;F-E(&]F($-H:6YA(BDL"B`@("`G5$HG(#T^
M(%\H(E1A:FEK:7-T86XB*2P*("`@("=46B<@/3X@7R@B5&%N>F%N:6$L(%5N
M:71E9"!297!U8FQI8R!O9B(I+`H@("`@)U1()R`]/B!?*")4:&%I;&%N9"(I
M+`H@("`@)U1,)R`]/B!?*")4:6UO<BU,97-T92(I+`H@("`@)U1')R`]/B!?
M*")4;V=O(BDL"B`@("`G5$LG(#T^(%\H(E1O:V5L874B*2P*("`@("=43R<@
M/3X@7R@B5&]N9V$B*2P*("`@("=45"<@/3X@7R@B5')I;FED860@86YD(%1O
M8F%G;R(I+`H@("`@)U1.)R`]/B!?*")4=6YI<VEA(BDL"B`@("`G5%(G(#T^
M(%\H(E1U<FME>2(I+`H@("`@)U1-)R`]/B!?*")4=7)K;65N:7-T86XB*2P*
M("`@("=40R<@/3X@7R@B5'5R:W,@86YD($-A:6-O<R!)<VQA;F1S(BDL"B`@
M("`G5%8G(#T^(%\H(E1U=F%L=2(I+`H@("`@)U5')R`]/B!?*")59V%N9&$B
M*2P*("`@("=502<@/3X@7R@B56MR86EN92(I+`H@("`@)T%%)R`]/B!?*")5
M;FET960@07)A8B!%;6ER871E<R(I+`H@("`@)T=")R`]/B!?*")5;FET960@
M2VEN9V1O;2(I+`H@("`@)U53)R`]/B!?*")5;FET960@4W1A=&5S(BDL"B`@
M("`G54TG(#T^(%\H(E5N:71E9"!3=&%T97,@36EN;W(@3W5T;'EI;F<@27-L
M86YD<R(I+`H@("`@)U59)R`]/B!?*")5<G5G=6%Y(BDL"B`@("`G55HG(#T^
M(%\H(E5Z8F5K:7-T86XB*2P*("`@("=652<@/3X@7R@B5F%N=6%T=2(I+`H@
M("`@)U9%)R`]/B!?*")696YE>G5E;&$B*2P*("`@("=63B<@/3X@7R@B5FEE
M="!.86TB*2P*("`@("=61R<@/3X@7R@B5FER9VEN($ES;&%N9',L($)R:71I
M<V@B*2P*("`@("=622<@/3X@7R@B5FER9VEN($ES;&%N9',L(%4N4RXB*2P*
M("`@("=71B<@/3X@7R@B5V%L;&ES(&%N9"!&=71U;F$B*2P*("`@("=%2"<@
M/3X@7R@B5V5S=&5R;B!386AA<F$B*2P*("`@("=912<@/3X@7R@B665M96XB
M*2P*("`@("=:32<@/3X@7R@B6F%M8FEA(BDL"B`@("`G6E<G(#T^(%\H(EII
M;6)A8G=E(BDI.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M3DQ3+T=E;TE0+G!H<```````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,S$U-#,@,3`U,34T,S0Q-#`@,#(Q-#4U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!(;W)D
M92!O<'1I;6EZ960@:6YT97)F86-E('1O('1H92!-87A-:6YD($E0($%D9')E
M<W,M/D-O=6YT<GD*("H@;&ES=&EN9RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO3DQ3+TY,4R]'96])4"YP:'`L=B`Q+C$P+C$P+C<@,C`P-B\P-B\R-R`Q
M-3HQ.3HQ,B!S;'5S87)Z($5X<"`D"B`J"B`J($)A<V5D(&]N(%!(4"!G96]I
M<"YI;F,@;&EB<F%R>2!B>2!-87A-:6YD($Q,0SH*("H@("!H='1P.B\O=W=W
M+FUA>&UI;F0N8V]M+V1O=VYL;V%D+V=E;VEP+V%P:2]P:'`O"B`J"B`J($]R
M:6=I;F%L;'D@8F%S960@;VX@<&AP('9E<G-I;VX@;V8@=&AE(&=E;VEP(&QI
M8G)A<GD@=W)I='1E;B!I;B!-87D*("H@,C`P,B!B>2!J:6T@=VEN<W1E860@
M/&II;7=`87!A8VAE+F]R9SX*("H*("H@0V]P>7)I9VAT("A#*2`R,#`S($UA
M>$UI;F0@3$Q#"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S
M87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!4:&ES
M(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U
M=&4@:70@86YD+V]R"B`J(&UO9&EF>2!I="!U;F1E<B!T:&4@=&5R;7,@;V8@
M=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("H@3&EC96YS92!A<R!P
M=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET
M:&5R"B`J('9E<G-I;VX@,BXQ(&]F('1H92!,:6-E;G-E+"!O<B`H870@>6]U
M<B!O<'1I;VXI(&%N>2!L871E<B!V97)S:6]N+@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?3DQ3"B`J+PH*+RH@0V]U;G1R>2!L:7-T+B`J+PHD1TQ/0D%,
M4ULG1T5/25!?0T]53E1265]#3T1%4R==(#T@87)R87DH"B<G+"`G05`G+"`G
M154G+"`G040G+"`G044G+"`G048G+"`G04<G+"`G04DG+"`G04PG+"`G04TG
M+"`G04XG+"`G04\G+"`G05$G+`HG05(G+"`G05,G+"`G050G+"`G054G+"`G
M05<G+"`G05HG+"`G0D$G+"`G0D(G+"`G0D0G+"`G0D4G+"`G0D8G+"`G0D<G
M+"`G0D@G+`HG0DDG+"`G0DHG+"`G0DTG+"`G0DXG+"`G0D\G+"`G0E(G+"`G
M0E,G+"`G0E0G+"`G0E8G+"`G0E<G+"`G0EDG+"`G0EHG+"`G0T$G+`HG0T,G
M+"`G0T0G+"`G0T8G+"`G0T<G+"`G0T@G+"`G0TDG+"`G0TLG+"`G0TPG+"`G
M0TTG+"`G0TXG+"`G0T\G+"`G0U(G+"`G0U4G+`HG0U8G+"`G0U@G+"`G0UDG
M+"`G0UHG+"`G1$4G+"`G1$HG+"`G1$LG+"`G1$TG+"`G1$\G+"`G1%HG+"`G
M14,G+"`G144G+"`G14<G+`HG14@G+"`G15(G+"`G15,G+"`G150G+"`G1DDG
M+"`G1DHG+"`G1DLG+"`G1DTG+"`G1D\G+"`G1E(G+"`G1E@G+"`G1T$G+"`G
M54LG+`HG1T0G+"`G1T4G+"`G1T8G+"`G1T@G+"`G1TDG+"`G1TPG+"`G1TTG
M+"`G1TXG+"`G1U`G+"`G1U$G+"`G1U(G+"`G1U,G+"`G1U0G+`HG1U4G+"`G
M1U<G+"`G1UDG+"`G2$LG+"`G2$TG+"`G2$XG+"`G2%(G+"`G2%0G+"`G2%4G
M+"`G240G+"`G244G+"`G24PG+"`G24XG+`HG24\G+"`G25$G+"`G25(G+"`G
M25,G+"`G250G+"`G2DTG+"`G2D\G+"`G2E`G+"`G2T4G+"`G2T<G+"`G2T@G
M+"`G2TDG+"`G2TTG+`HG2TXG+"`G2U`G+"`G2U(G+"`G2U<G+"`G2UDG+"`G
M2UHG+"`G3$$G+"`G3$(G+"`G3$,G+"`G3$DG+"`G3$LG+"`G3%(G+"`G3%,G
M+`HG3%0G+"`G3%4G+"`G3%8G+"`G3%DG+"`G34$G+"`G34,G+"`G340G+"`G
M34<G+"`G34@G+"`G34LG+"`G34PG+"`G34TG+"`G34XG+`HG34\G+"`G35`G
M+"`G35$G+"`G35(G+"`G35,G+"`G350G+"`G354G+"`G358G+"`G35<G+"`G
M35@G+"`G35DG+"`G35HG+"`G3D$G+`HG3D,G+"`G3D4G+"`G3D8G+"`G3D<G
M+"`G3DDG+"`G3DPG+"`G3D\G+"`G3E`G+"`G3E(G+"`G3E4G+"`G3EHG+"`G
M3TTG+"`G4$$G+`HG4$4G+"`G4$8G+"`G4$<G+"`G4$@G+"`G4$LG+"`G4$PG
M+"`G4$TG+"`G4$XG+"`G4%(G+"`G4%,G+"`G4%0G+"`G4%<G+"`G4%DG+`HG
M44$G+"`G4D4G+"`G4D\G+"`G4E4G+"`G4E<G+"`G4T$G+"`G4T(G+"`G4T,G
M+"`G4T0G+"`G4T4G+"`G4T<G+"`G4T@G+"`G4TDG+`HG4THG+"`G4TLG+"`G
M4TPG+"`G4TTG+"`G4TXG+"`G4T\G+"`G4U(G+"`G4U0G+"`G4U8G+"`G4UDG
M+"`G4UHG+"`G5$,G+"`G5$0G+`HG5$8G+"`G5$<G+"`G5$@G+"`G5$HG+"`G
M5$LG+"`G5$TG+"`G5$XG+"`G5$\G+"`G5%`G+"`G5%(G+"`G5%0G+"`G5%8G
M+"`G5%<G+`HG5%HG+"`G54$G+"`G54<G+"`G54TG+"`G55,G+"`G55DG+"`G
M55HG+"`G5D$G+"`G5D,G+"`G5D4G+"`G5D<G+"`G5DDG+"`G5DXG+`HG5E4G
M+"`G5T8G+"`G5U,G+"`G644G+"`G650G+"`G654G+"`G6D$G+"`G6DTG+"`G
M6E(G+"`G6E<G+"`G03$G+"`G03(G+"`G3S$G"BD["@HO*B!#;W5N=')Y($YA
M;65S+B`J+PHD1TQ/0D%,4ULG1T5/25!?0T]53E1265].04U%4R==(#T@87)R
M87DH"B(B+"!?*")!<VEA+U!A8VEF:6,@4F5G:6]N(BDL(%\H(D5U<F]P92(I
M+"!?*")!;F1O<G)A(BDL"E\H(E5N:71E9"!!<F%B($5M:7)A=&5S(BDL(%\H
M(D%F9VAA;FES=&%N(BDL(%\H(D%N=&EG=6$@86YD($)A<F)U9&$B*2P*7R@B
M06YG=6EL;&$B*2P@7R@B06QB86YI82(I+"!?*")!<FUE;FEA(BDL(%\H(DYE
M=&AE<FQA;F1S($%N=&EL;&5S(BDL"E\H(D%N9V]L82(I+"!?*")!;G1A<F-T
M:6-A(BDL(%\H(D%R9V5N=&EN82(I+"!?*")!;65R:6-A;B!386UO82(I+`I?
M*")!=7-T<FEA(BDL(%\H(D%U<W1R86QI82(I+"!?*")!<G5B82(I+"!?*")!
M>F5R8F%I:F%N(BDL"E\H(D)O<VYI82!A;F0@2&5R>F5G;W9I;F$B*2P@7R@B
M0F%R8F%D;W,B*2P@7R@B0F%N9VQA9&5S:"(I+"!?*")"96QG:75M(BDL"E\H
M(D)U<FMI;F$@1F%S;R(I+"!?*")"=6QG87)I82(I+"!?*")"86AR86EN(BDL
M(%\H(D)U<G5N9&DB*2P@7R@B0F5N:6XB*2P*7R@B0F5R;75D82(I+"!?*")"
M<G5N96D@1&%R=7-S86QA;2(I+"!?*")";VQI=FEA(BDL(%\H(D)R87II;"(I
M+"!?*")"86AA;6%S(BDL"E\H(D)H=71A;B(I+"!?*")";W5V970@27-L86YD
M(BDL(%\H(D)O='-W86YA(BDL(%\H(D)E;&%R=7,B*2P@7R@B0F5L:7IE(BDL
M"E\H(D-A;F%D82(I+"!?*")#;V-O<R`H2V5E;&EN9RD@27-L86YD<R(I+`I?
M*")#;VYG;RP@5&AE($1E;6]C<F%T:6,@4F5P=6)L:6,@;V8@=&AE(BDL(%\H
M(D-E;G1R86P@069R:6-A;B!297!U8FQI8R(I+`I?*")#;VYG;R(I+"!?*")3
M=VET>F5R;&%N9"(I+"!?*")#;W1E(&0G279O:7)E(BDL(%\H(D-O;VL@27-L
M86YD<R(I+`I?*")#:&EL92(I+"!?*")#86UE<F]O;B(I+"!?*")#:&EN82(I
M+"!?*")#;VQO;6)I82(I+"!?*")#;W-T82!2:6-A(BDL"E\H(D-U8F$B*2P@
M7R@B0V%P92!697)D92(I+"!?*")#:')I<W1M87,@27-L86YD(BDL(%\H(D-Y
M<')U<R(I+`I?*")#>F5C:"!297!U8FQI8R(I+"!?*")'97)M86YY(BDL(%\H
M(D1J:6)O=71I(BDL(%\H(D1E;FUA<FLB*2P@7R@B1&]M:6YI8V$B*2P*7R@B
M1&]M:6YI8V%N(%)E<'5B;&EC(BDL(%\H(D%L9V5R:6$B*2P@7R@B16-U861O
M<B(I+"!?*")%<W1O;FEA(BDL(%\H(D5G>7!T(BDL"E\H(E=E<W1E<FX@4V%H
M87)A(BDL(%\H(D5R:71R96$B*2P@7R@B4W!A:6XB*2P@7R@B171H:6]P:6$B
M*2P@7R@B1FEN;&%N9"(I+`I?*")&:6II(BDL(%\H(D9A;&ML86YD($ES;&%N
M9',@*$UA;'9I;F%S*2(I+"!?*")-:6-R;VYE<VEA+"!&961E<F%T960@4W1A
M=&5S(&]F(BDL"E\H(D9A<F]E($ES;&%N9',B*2P@7R@B1G)A;F-E(BDL(%\H
M(D9R86YC92P@365T<F]P;VQI=&%N(BDL(%\H(D=A8F]N(BDL"E\H(E5N:71E
M9"!+:6YG9&]M(BDL(%\H(D=R96YA9&$B*2P@7R@B1V5O<F=I82(I+"!?*")&
M<F5N8V@@1W5I86YA(BDL"E\H(D=H86YA(BDL(%\H(D=I8G)A;'1A<B(I+"!?
M*")'<F5E;FQA;F0B*2P@7R@B1V%M8FEA(BDL(%\H(D=U:6YE82(I+`I?*")'
M=6%D96QO=7!E(BDL(%\H(D5Q=6%T;W)I86P@1W5I;F5A(BDL(%\H(D=R965C
M92(I+`I?*")3;W5T:"!'96]R9VEA(&%N9"!T:&4@4V]U=&@@4V%N9'=I8V@@
M27-L86YD<R(I+"!?*")'=6%T96UA;&$B*2P@7R@B1W5A;2(I+`I?*")'=6EN
M96$M0FES<V%U(BDL(%\H(D=U>6%N82(I+"!?*")(;VYG($MO;F<B*2P*7R@B
M2&5A<F0@27-L86YD(&%N9"!-8T1O;F%L9"!)<VQA;F1S(BDL(%\H(DAO;F1U
M<F%S(BDL(%\H(D-R;V%T:6$B*2P*7R@B2&%I=&DB*2P@7R@B2'5N9V%R>2(I
M+"!?*"));F1O;F5S:6$B*2P@7R@B27)E;&%N9"(I+"!?*"))<W)A96PB*2P*
M7R@B26YD:6$B*2P@7R@B0G)I=&ES:"!);F1I86X@3V-E86X@5&5R<FET;W)Y
M(BDL(%\H(DER87$B*2P*7R@B27)A;BP@27-L86UI8R!297!U8FQI8R!O9B(I
M+"!?*"))8V5L86YD(BDL(%\H(DET86QY(BDL(%\H(DIA;6%I8V$B*2P*7R@B
M2F]R9&%N(BDL(%\H(DIA<&%N(BDL(%\H(DME;GEA(BDL(%\H(DMY<F=Y>G-T
M86XB*2P@7R@B0V%M8F]D:6$B*2P*7R@B2VER:6)A=&DB*2P@7R@B0V]M;W)O
M<R(I+"!?*")386EN="!+:71T<R!A;F0@3F5V:7,B*2P*7R@B2V]R96$L($1E
M;6]C<F%T:6,@4&5O<&QE)W,@4F5P=6)L:6,@;V8B*2P@7R@B2V]R96$L(%)E
M<'5B;&EC(&]F(BDL"E\H(DMU=V%I="(I+"!?*")#87EM86X@27-L86YD<R(I
M+"!?*")+87IA:VAS=&%N(BDL"E\H(DQA;R!096]P;&4G<R!$96UO8W)A=&EC
M(%)E<'5B;&EC(BDL(%\H(DQE8F%N;VXB*2P@7R@B4V%I;G0@3'5C:6$B*2P*
M7R@B3&EE8VAT96YS=&5I;B(I+"!?*")3<FD@3&%N:V$B*2P@7R@B3&EB97)I
M82(I+"!?*"),97-O=&AO(BDL"E\H(DQI=&AU86YI82(I+"!?*"),=7AE;6)O
M=7)G(BDL(%\H(DQA='9I82(I+"!?*"),:6)Y86X@07)A8B!*86UA:&ER:7EA
M(BDL"E\H(DUO<F]C8V\B*2P@7R@B36]N86-O(BDL(%\H(DUO;&1O=F$L(%)E
M<'5B;&EC(&]F(BDL(%\H(DUA9&%G87-C87(B*2P*7R@B36%R<VAA;&P@27-L
M86YD<R(I+"!?*")-86-E9&]N:6$L(%1H92!&;W)M97(@675G;W-L878@4F5P
M=6)L:6,@;V8B*2P*7R@B36%L:2(I+"!?*")->6%N;6%R(BDL(%\H(DUO;F=O
M;&EA(BDL(%\H(DUA8V%O(BDL"E\H(DYO<G1H97)N($UA<FEA;F$@27-L86YD
M<R(I+"!?*")-87)T:6YI<75E(BDL(%\H(DUA=7)I=&%N:6$B*2P*7R@B36]N
M='-E<G)A="(I+"!?*")-86QT82(I+"!?*")-875R:71I=7,B*2P@7R@B36%L
M9&EV97,B*2P@7R@B36%L87=I(BDL"E\H(DUE>&EC;R(I+"!?*")-86QA>7-I
M82(I+"!?*")-;WIA;6)I<75E(BDL(%\H(DYA;6EB:6$B*2P@7R@B3F5W($-A
M;&5D;VYI82(I+`I?*").:6=E<B(I+"!?*").;W)F;VQK($ES;&%N9"(I+"!?
M*").:6=E<FEA(BDL(%\H(DYI8V%R86=U82(I+`I?*").971H97)L86YD<R(I
M+"!?*").;W)W87DB*2P@7R@B3F5P86PB*2P@7R@B3F%U<G4B*2P@7R@B3FEU
M92(I+`I?*").97<@6F5A;&%N9"(I+"!?*")/;6%N(BDL(%\H(E!A;F%M82(I
M+"!?*")097)U(BDL(%\H(D9R96YC:"!0;VQY;F5S:6$B*2P*7R@B4&%P=6$@
M3F5W($=U:6YE82(I+"!?*")0:&EL:7!P:6YE<R(I+"!?*")086MI<W1A;B(I
M+"!?*")0;VQA;F0B*2P*7R@B4V%I;G0@4&EE<G)E(&%N9"!-:7%U96QO;B(I
M+"!?*")0:71C86ER;B(I+"!?*")0=65R=&\@4FEC;R(I+`I?*")086QE<W1I
M;FEA;B!497)R:71O<GDL($]C8W5P:65D(BDL(%\H(E!O<G1U9V%L(BDL(%\H
M(E!A;&%U(BDL"E\H(E!A<F%G=6%Y(BDL(%\H(E%A=&%R(BDL(%\H(E)E=6YI
M;VXB*2P@7R@B4F]M86YI82(I+`I?*")2=7-S:6%N($9E9&5R871I;VXB*2P@
M7R@B4G=A;F1A(BDL(%\H(E-A=61I($%R86)I82(I+"!?*")3;VQO;6]N($ES
M;&%N9',B*2P*7R@B4V5Y8VAE;&QE<R(I+"!?*")3=61A;B(I+"!?*")3=V5D
M96XB*2P@7R@B4VEN9V%P;W)E(BDL(%\H(E-A:6YT($AE;&5N82(I+`I?*")3
M;&]V96YI82(I+"!?*")3=F%L8F%R9"!A;F0@2F%N($UA>65N(BDL(%\H(E-L
M;W9A:VEA(BDL(%\H(E-I97)R82!,96]N92(I+`I?*")386X@36%R:6YO(BDL
M(%\H(E-E;F5G86PB*2P@7R@B4V]M86QI82(I+"!?*")3=7)I;F%M92(I+`I?
M*")386\@5&]M92!A;F0@4')I;F-I<&4B*2P@7R@B16P@4V%L=F%D;W(B*2P@
M7R@B4WER:6%N($%R86(@4F5P=6)L:6,B*2P*7R@B4W=A>FEL86YD(BDL(%\H
M(E1U<FMS(&%N9"!#86EC;W,@27-L86YD<R(I+"!?*")#:&%D(BDL"E\H(D9R
M96YC:"!3;W5T:&5R;B!497)R:71O<FEE<R(I+"!?*")4;V=O(BDL(%\H(E1H
M86EL86YD(BDL(%\H(E1A:FEK:7-T86XB*2P*7R@B5&]K96QA=2(I+"!?*")4
M=7)K;65N:7-T86XB*2P@7R@B5'5N:7-I82(I+"!?*")4;VYG82(I+"!?*")4
M:6UO<BU,97-T92(I+`I?*")4=7)K97DB*2P@7R@B5')I;FED860@86YD(%1O
M8F%G;R(I+"!?*")4=79A;'4B*2P@7R@B5&%I=V%N(BDL"E\H(E1A;GIA;FEA
M+"!5;FET960@4F5P=6)L:6,@;V8B*2P@7R@B56MR86EN92(I+"!?*")59V%N
M9&$B*2P*7R@B56YI=&5D(%-T871E<R!-:6YO<B!/=71L>6EN9R!)<VQA;F1S
M(BDL(%\H(E5N:71E9"!3=&%T97,B*2P@7R@B57)U9W5A>2(I+`I?*")5>F)E
M:VES=&%N(BDL(%\H(DAO;'D@4V5E("A6871I8V%N($-I='D@4W1A=&4I(BDL
M"E\H(E-A:6YT(%9I;F-E;G0@86YD('1H92!'<F5N861I;F5S(BDL(%\H(E9E
M;F5Z=65L82(I+`I?*")6:7)G:6X@27-L86YD<RP@0G)I=&ES:"(I+"!?*")6
M:7)G:6X@27-L86YD<RP@52Y3+B(I+"!?*")6:65T($YA;2(I+`I?*")686YU
M871U(BDL(%\H(E=A;&QI<R!A;F0@1G5T=6YA(BDL(%\H(E-A;6]A(BDL(%\H
M(EEE;65N(BDL(%\H(DUA>6]T=&4B*2P*7R@B675G;W-L879I82(I+"!?*")3
M;W5T:"!!9G)I8V$B*2P@7R@B6F%M8FEA(BDL(%\H(EIA:7)E(BDL(%\H(EII
M;6)A8G=E(BDL"E\H(D%N;VYY;6]U<R!0<F]X>2(I+"!?*")3871E;&QI=&4@
M4')O=FED97(B*2P@7R@B3W1H97(B*0HI.PH*9&5F:6YE*"='14])4%]#3U5.
M5%)97T)%1TE.)RP@,38W-S8Y-C`I.PID969I;F4H)U-44E5#5%5215])3D9/
M7TU!6%]325I%)RP@,C`I.PID969I;F4H)U-404Y$05)$7U)%0T]21%],14Y'
M5$@G+"`S*3L*"F-L87-S($Y,4U]'96])4"!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@;&]C871I;VX@;V8@=&AE($=E;TE0(&1A=&%B87-E+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1A=&%F:6QE.PH*
M("`@("\J*@H@("`@("H@5&AE(&]P96X@9FEL96AA;F1L92!T;R!T:&4@1V5O
M25`@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@
M("HO"B`@("!V87(@)%]F:6QE:&%N9&QE.PH*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A(')E9F5R96YC92!T;R!T:&4@9VQO8F%L($Y,4U]'96])4"!O8FIE
M8W0L(&]N;'D@8W)E871I;F<@:70*("`@("`J(&EF(&ET(&1O97-N)W0@86QR
M96%D>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E
M(&EN=F]K960@87,Z"B`@("`@*B`@("1G96]I<"`]("9'96])4#HZ<VEN9VQE
M=&]N*"1D871A9FEL92D["B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&%T869I;&4@(%1H92!L;V-A=&EO;B!O9B!T:&4@1V5O25`@9&%T86)A<V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@3DQ37T=E;TE0("!4:&4@
M3DQ37T=E;TE0(&EN<W1A;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<VEN
M9VQE=&]N*"1D871A9FEL92D*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A
M;F-E.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;G-T86YC92DI('L*("`@("`@
M("`@("`@)&EN<W1A;F-E(#T@;F5W($Y,4U]'96])4"@D9&%T869I;&4I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC93L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T92!A($Y,4U]'96])4"!I;G-T86YC92`H0V]N
M<W1R=6-T;W(I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%F
M:6QE("!4:&4@;&]C871I;VX@;V8@=&AE($=E;TE0(&1A=&%B87-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!.3%-?1V5O25`H)&1A=&%F:6QE*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?9&%T869I;&4@/2`D9&%T869I;&4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!/<&5N('1H92!'96])4"!D871A8F%S92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@($9A;'-E(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?;W!E;B@I"B`@("!["B`@("`@("`@+RH@4F5T=7)N(&EF('=E(&%L<F5A
M9'D@:&%V92!A;B!O8FIE8W0N("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI
M<RT^7V9I;&5H86YD;&4I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5T=7)N(&EF(&YO(&1A=&%F:6QE('-P
M96-I9FEE9"X@*B\*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]D871A9FEL
M92DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]F:6QE:&%N9&QE(#T@9F]P96XH)'1H:7,M/E]D871A
M9FEL92P@)W)B)RD["@H@("`@("`@("1F:6QE<&]S(#T@9G1E;&PH)'1H:7,M
M/E]F:6QE:&%N9&QE*3L*("`@("`@("!F<V5E:R@D=&AI<RT^7V9I;&5H86YD
M;&4L("TS+"!3145+7T5.1"D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M4U1254-455)%7TE.1D]?34%87U-)6D4[("1I*RLI('L*("`@("`@("`@("`@
M)&1E;&EM(#T@9G)E860H)'1H:7,M/E]F:6QE:&%N9&QE+"`S*3L*("`@("`@
M("`@("`@:68@*"1D96QI;2`]/2`H8VAR*#(U-2D@+B!C:'(H,C4U*2`N(&-H
M<B@R-34I*2D@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("!F<V5E:R@D=&AI<RT^7V9I;&5H
M86YD;&4L("TT+"!3145+7T-54BD["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@9G-E96LH)'1H:7,M/E]F:6QE:&%N9&QE+"`D9FEL97!O<RP@
M4T5%2U]3150I.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-O=6YT<GD@240@9F]R(&$@:&]S=&YA
M;64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&AO
M<W1N86UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE($=E
M;TE0(&-O=6YT<GD@240N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE)
M9$)Y3F%M92@D;F%M92D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E
M;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)&%D9'(@/2!G971H;W-T8GEN86UE*"1N86UE*3L*("`@("`@("!I
M9B`H(21A9&1R('Q\("@D861D<B`]/2`D;F%M92DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M
M/F-O=6YT<GE)9$)Y061D<B@D861D<BD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!C;W5N=')Y(&%B8G)E=FEA=&EO;B`H,BUL971T97(I
M(&9O<B!A(&AO<W1N86UE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!H;W-T;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1H92!C;W5N=')Y(&%B8G)E=FEA=&EO;BX*("`@("`J+PH@("`@
M9G5N8W1I;VX@8V]U;G1R>4-O9&5">4YA;64H)&YA;64I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?;W!E;B@I*2!["B`@("`@("`@("`@("1C;W5N=')Y
M7VED(#T@)'1H:7,M/F-O=6YT<GE)9$)Y3F%M92@D;F%M92D["B`@("`@("`@
M("`@(&EF("@D8V]U;G1R>5]I9"`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG1T5/25!?0T]53E1265]#3T1%4R==6R1C
M;W5N=')Y7VED73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R
M971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!C;W5N=')Y(&YA;64@9F]R(&$@:&]S=&YA;64N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&AO<W1N86UE+@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT96=E<B`@5&AE(&-O=6YT<GD@;F%M92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]U;G1R>4YA;65">4YA;64H)&YA;64I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;B@I*2!["B`@("`@("`@("`@("1C
M;W5N=')Y7VED(#T@)'1H:7,M/F-O=6YT<GE)9$)Y3F%M92@D;F%M92D["B`@
M("`@("`@("`@(&EF("@D8V]U;G1R>5]I9"`A/3T@9F%L<V4I('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG1T5/25!?0T]53E1265].04U%
M4R==6R1C;W5N=')Y7VED73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!C;W5N=')Y($E$(&9O<B!A;B!)4"!!9&1R97-S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%D9'(@(%1H92!)4"!!9&1R97-S+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE($=E;TE0(&-O=6YT
M<GD@240N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE)9$)Y061D<B@D
M861D<BD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;B@I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)&EP
M;G5M(#T@:7`R;&]N9R@D861D<BD["B`@("`@("`@<F5T=7)N("@D=&AI<RT^
M7W-E96M#;W5N=')Y*"1I<&YU;2D@+2!'14])4%]#3U5.5%)97T)%1TE.*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O=6YT<GD@86)B
M<F5V:6%T:6]N("@R+6QE='1E<BD@9F]R(&%N($E0($%D9')E<W,N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D861D<B`@5&AE($E0($%D9')E<W,N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8V]U;G1R>2!A
M8F)R979I871I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT<GE#;V1E
M0GE!9&1R*"1A9&1R*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96XH
M*2D@>PH@("`@("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES+3YC;W5N=')Y
M261">4%D9'(H)&%D9'(I.PH@("`@("`@("`@("!I9B`H)&-O=6YT<GE?:60@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)$=,3T)!3%-;
M)T=%3TE07T-/54Y44EE?0T]$15,G75LD8V]U;G1R>5]I9%T["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]U;G1R>2!N86UE(&9O<B!A
M;B!)4"!A9&1R97-S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%D
M9'(@(%1H92!)4"!A9&1R97-S+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1H92!C;W5N=')Y(&YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M=6YT<GE.86UE0GE!9&1R*"1A9&1R*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7V]P96XH*2D@>PH@("`@("`@("`@("`D8V]U;G1R>5]I9"`]("1T:&ES
M+3YC;W5N=')Y261">4%D9'(H)&%D9'(I.PH@("`@("`@("`@("!I9B`H)&-O
M=6YT<GE?:60@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)$=,3T)!3%-;)T=%3TE07T-/54Y44EE?3D%-15,G75LD8V]U;G1R>5]I9%T[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEN9',@82!C;W5N=')Y(&)Y($E0
M($%D9')E<W,@:6X@=&AE($=E;TE0(&1A=&%B87-E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&EP;G5M("!4:&4@25`@061D<F5S<R!T;R!S96%R8V@@9F]R+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!C;W5N=')Y($E$(&]R(&9A;'-E
M(&EF(&YO="!F;W5N9"X*("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@
M4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M96M#;W5N=')Y*"1I<&YU;2D*("`@('L*("`@("`@("`D;V9F<V5T(#T@,#L*
M("`@("`@("!F;W(@*"1D97!T:"`](#,Q.R`D9&5P=&@@/CT@,#L@+2TD9&5P
M=&@I('L*("`@("`@("`@("`@:68@*&9S965K*"1T:&ES+3Y?9FEL96AA;F1L
M92P@,B`J(%-404Y$05)$7U)%0T]21%],14Y'5$@@*B`D;V9F<V5T+"!3145+
M7U-%5"D@(3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)V9S965K(&9A:6QE9"<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1B=68@/2!F<F5A9"@D=&AI<RT^7V9I;&5H86YD;&4L(#(@*B!3
M5$%.1$%21%]214-/4D1?3$5.1U1(*3L*("`@("`@("`@("`@)'@@/2!A<G)A
M>2@P+"`P*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@,CL@*RLD
M:2D@>PH@("`@("`@("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@4U1!3D1!
M4D1?4D5#3U)$7TQ%3D=42#L@*RLD:BD@>PH@("`@("`@("`@("`@("`@("`@
M("1X6R1I72`K/2!O<F0H)&)U9EM35$%.1$%21%]214-/4D1?3$5.1U1(("H@
M)&D@*R`D:ETI(#P\("@D:B`J(#@I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&EF("@D:7!N=6T@)B`H,2`\/"`D9&5P
M=&@I*2!["B`@("`@("`@("`@("`@("!I9B`H)'A;,5T@/CT@1T5/25!?0T]5
M3E1265]"14=)3BD@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D>%LQ
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O9F9S970@
M/2`D>%LQ73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(&EF("@D>%LP72`^/2!'14])4%]#3U5.5%)97T)%1TE.*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1X6S!=.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&]F9G-E="`]("1X6S!=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O5D,O<F-S+G!H<```````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,38R,S8@,3`U,34T,S0Q-#`@,#(Q,34W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!60U]R8W,@:6UP;&5M96YT871I;VXN"B`J"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F5F9B!38VAW96YT;F5R(#QJ969F<F5Y+G-C:'=E;G1N97)`
M;&UC;RYC;VT^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9#+U9#+W)C<RYP
M:'`L=B`Q+C,N."XU(#(P,#8O,#$O,#$@,C$Z,C@Z-#(@:F%N($5X<"`D"B`J
M"B`J($!A=71H;W(@($IE9F8@4V-H=V5N=&YE<B`\:F5F9G)E>2YS8VAW96YT
M;F5R0&QM8V\N8V]M/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7W)C
M<R!E>'1E;F1S(%9#('L*"B`@("`O*BH*("`@("`J($-H96-K<R!A;B!20U,@
M9FEL92!I;B!W:71H(&$@<W!E8VEF:65D(&-H86YG92!L;V<N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@("`@3&]C871I;VX@;V8@
M9FEL92!T;R!C:&5C:R!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A
M9V4@("`@($QO9R!O9B!C:&%N9V5S('-I;F-E(&QA<W0@=F5R<VEO;BX*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("`@(%1H92!U<V5R(&YA;64@
M=&\@=7-E(&9O<B!T:&4@8VAE8VL@:6XN"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;F5W0FEN87)Y("!$;V5S('1H92!C:&%N9V4@:6YV;VQV92!B:6YA<GD@
M9&%T83\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9WQO8FIE8W0@(%1H
M92!N97<@<F5V:7-I;VX@;G5M8F5R(&]N('-U8V-E<W,L(&]R(&$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VDH)&9I;&5P871H+"`D
M;65S<V%G92P@)'5S97(@/2!N=6QL+"`D;F5W0FEN87)Y(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"1U<V5R*2!["B`@("`@("`@("`@('!U=&5N=B@G
M3$]'3D%-13TG("X@)'5S97(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@('!U=&5N=B@G3$]'3D%-13UG=65S="<I.PH@("`@("`@('T*"B`@("`@
M("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B(#L*"B`@("`@("`@)&-I
M7V-M9"`]("1T:&ES+3YG9710871H*"=C:2<I("X@)R`G("X@)%$@+B`D9FEL
M97!A=&@@+B`D42XG(#(^)C$G.PH@("`@("`@("1R8W-?8VUD(#T@)'1H:7,M
M/F=E=%!A=&@H)W)C<R<I("X@)R`M:2`M:V(@)R`N("11("X@)&9I;&5P871H
M("X@)%$N)R`R/B8Q)SL*("`@("`@("`D;W5T<'5T(#T@)R<["@H@("`@("`@
M("1M97-S86=E7VQI;F5S(#T@97AP;&]D92@B7&XB+"`D;65S<V%G92D["@H@
M("`@("`@("1P:7!E7V1E9B`](&%R<F%Y*#`@/3X@87)R87DH(G!I<&4B+"`G
M<B<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@(#$@/3X@87)R87DH(G!I
M<&4B+"`G=R<I*3L*"B`@("`@("`@:68@*"1N97=":6YA<GDI('L*("`@("`@
M("`@("`@)'!R;V-E<W,@/2!P<F]C7V]P96XH)')C<U]C;60L("1P:7!E7V1E
M9BP@)'!I<&5S*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<')O
M8V5S<R`]('!R;V-?;W!E;B@D8VE?8VUD+"`D<&EP95]D968L("1P:7!E<RD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)'!R;V-E<W,I
M*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1M97-S86=E7VQI;F5S(&%S("1L
M:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H)&QI;F4@/3T@)RY<;B<I('L*
M("`@("`@("`@("`@("`@("`@("`D;&EN92`]("<N(%QN)SL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&9W<FET92@D<&EP97-;,%TL("1L
M:6YE*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9G=R:71E*"1P:7!E
M<ULP72P@(EQN+EQN(BD["B`@("`@("`@("`@(&9C;&]S92@D<&EP97-;,%TI
M.PH*("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1P:7!E<ULQ72DI('L*("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@9G)E860H)'!I<&5S6S%=+"`X,3DR
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO<V4H)'!I<&5S6S%=
M*3L*("`@("`@("`@("`@<')O8U]C;&]S92@D<')O8V5S<RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)T9A:6QE9"!T;R!O<&5N('!I<&4@:6X@8VDH*2<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1N97=":6YA<GDI('L*("`@("`@("`@("`@97AE8R@D8VE?
M8VUD("X@)R`R/B8Q)RP@)')E='5R;E]A<G)A>2P@)')E='9A;"D["@H@("`@
M("`@("`@("!I9B`H)')E='9A;"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(E5N86)L92!T;R!S<&%W;B!C:2!O;B`D9FEL
M97!A=&@@9G)O;2!C:2@I(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<F5T=7)N7V%R<F%Y(&%S("1L:6YE*2![
M"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)')E=E]S=&%R="`]('-T<G!O<R@D;W5T<'5T+"`G;F5W(')E=FES:6]N.B`G
M*3L*"B`@("`@("`@+R\@268@;F\@;F5W(')E=FES:6]N+"!S964@:68@=&AI
M<R!I<R!A;B!I;FET:6%L(&-H96-K:6XN"B`@("`@("`@:68@*"1R979?<W1A
M<G0@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1R979?<W1A<G0@/2!S=')P
M;W,H)&]U='!U="P@)VEN:71I86P@<F5V:7-I;VXZ("<I.PH@("`@("`@("`@
M("`D<F5V7V5N9"`]('-T<G!O<R@D;W5T<'5T+"`G("<L("1R979?<W1A<G0I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R979?96YD(#T@<W1R
M<&]S*"1O=71P=70L("<[)RP@)')E=E]S=&%R="D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)')E=E]S=&%R="`A/3T@9F%L<V4@)B8@)')E=E]E;F0@(3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1R979?<W1A<G0@*ST@,30["B`@("`@
M("`@("`@(')E='5R;B!S=6)S='(H)&]U='!U="P@)')E=E]S=&%R="P@)')E
M=E]E;F0@+2`D<F5V7W-T87)T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!U;FQO8VLH)&9I;&5P871H*3L*("`@("`@("`@("`@)'1E;7!?<&]S
M(#T@<W1R<&]S*"1O=71P=70L("=F:6QE(&ES('5N8VAA;F=E9"<I.PH@("`@
M("`@("`@("!I9B`H)'1E;7!?<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-H96-K+6EN($9A:6QU
M<F4Z("<@+B!B87-E;F%M92@D9FEL97!A=&@I("X@)R!H87,@;F]T(&)E96X@
M;6]D:69I960G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&86EL960@=&\@8VAE8VMI
M;B`D9FEL97!A=&@L("1C:5]C;60L("1O=71P=70B*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@
M;&]C:W,@;VX@82!#5E,O4D-3(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9FEL97!A=&@@("`@3&]C871I;VX@;V8@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)B1L;V-K961?8GD@(%)E='5R;G,@=&AE('5S97)N
M86UE(&AO;&1I;F<@=&AE(&QO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R
M;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-,;V-K960H
M)&9I;&5P871H+"`F)&QO8VME9%]B>2D*("`@('L*("`@("`@("`D<FQO9U]C
M;60@(#T@)'1H:7,M/F=E=%!A=&@H)W)L;V<G*3L*("`@("`@("`D<FQO9U]F
M;&%G(#T@)R`M3"`G.PH*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@
M.B`B)R(["@H@("`@("`@("1C;60@/2`D<FQO9U]C;60@+B`D<FQO9U]F;&%G
M("X@)%$@+B`D9FEL97!A=&@@+B`D43L*"B`@("`@("`@97AE8R@D8VUD+B<@
M,CXF,2<L("1R971U<FY?87)R87DL("1R971V86PI.PH*("`@("`@("!I9B`H
M)')E='9A;"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B56YA8FQE('1O('-P87=N(')L;V<@;VX@)&9I;&5P871H(&9R;VT@:7-,
M;V-K960H*2(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O=71P
M=70@/2`G)SL*"B`@("`@("`@("`@(&9O<F5A8V@@*"1R971U<FY?87)R87D@
M87,@)&QI;F4I('L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&QI;F4[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%R=%]N86UE(#T@<W1R
M<&]S*"1O=71P=70L("=L;V-K960@8GDZ("<I.PH@("`@("`@("`@("`D96YD
M7VYA;64@/2!S=')P;W,H)&]U='!U="P@)SLG+"`D<W1A<G1?;F%M92D["@H@
M("`@("`@("`@("!I9B`H)'-T87)T7VYA;64@(3T](&9A;'-E("8F("1E;F1?
M;F%M92`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S=&%R=%]N86UE
M("L](#$Q.PH@("`@("`@("`@("`@("`@)&QO8VME9%]B>2`]('-U8G-T<B@D
M;W5T<'5T+"`D<W1A<G1?;F%M92P@)&5N9%]N86UE("T@)'-T87)T7VYA;64I
M.PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@
M(&5L<V5I9B`H<W1R;&5N*"1O=71P=70I(#T](#`I('L*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL=7)E(')U
M;FYI;F<@<FQO9R!I;B!I<TQO8VME9"@I)RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V-K<R!A($-64R]20U,@
M9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE<&%T:"`@
M3&]C871I;VX@;V8@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@
M("`@("!5<V5R(&YA;64@=&\@;&]C:R!T:&4@9FEL92!W:71H"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C97-S
M+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&]C:R@D9FEL97!A=&@L("1U<V5R(#T@;G5L;"D*("`@('L*("`@
M("`@("`O+R!'970@=7-E<FYA;64@9F]R(%)#4R!T86<N"B`@("`@("`@:68@
M*"1U<V5R*2!["B`@("`@("`@("`@('!U=&5N=B@G3$]'3D%-13TG("X@)'5S
M97(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!U=&5N=B@G3$]'
M3D%-13UG=65S="<I.PH@("`@("`@('T*"B`@("`@("`@)')C<U]C;60@/2`D
M=&AI<RT^9V5T4&%T:"@G<F-S)RD["B`@("`@("`@)')C<U]F;&%G(#T@)R`M
M;"`G.PH*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@.B`B)R(@.PH@
M("`@("`@("1C;60@/2`D<F-S7V-M9"`N("1R8W-?9FQA9R`N("11("X@)&9I
M;&5P871H("X@)%$["B`@("`@("`@97AE8R@D8VUD+B<@,CXF,2<L("1R971U
M<FY?87)R87DL("1R971V86PI.PH*("`@("`@("!I9B`H)')E='9A;"D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O
M('-P87=N(')C<R`H(B<@+B`D8VUD("X@)R(I(&]N("(G("X@)&9I;&5P871H
M("X@)R(@*')E='5R;F5D("<@+B`D<F5T=F%L("X@)RDG*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D;W5T<'5T(#T@)R<["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1R971U<FY?87)R87D@87,@)&QI;F4I('L*("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@)&QI;F4["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1L;V-K961?<&]S(#T@<W1R<&]S*"1O=71P=70L("=L;V-K960G
M*3L*("`@("`@("`@("`@:68@*"1L;V-K961?<&]S("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M1F%I;&5D('1O(&QO8VL@(B<@+B`D9FEL97!A=&@@+B`G(B`H4F%N("(G("X@
M)&-M9"`N("<B+"!G;W0@<F5T=7)N(&-O9&4@)R`N("1R971V86P@+B`G+"!O
M=71P=70Z("<@+B`D;W5T<'5T("X@)RDG*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%5N;&]C:W,@82!#5E,O4D-3
M(&9I;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL97!A=&@@
M($QO8V%T:6]N(&]F(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R
M("`@("`@57-E<B!N86UE('1O('5N;&]C:R!T:&4@9FEL92!W:71H"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@5')U92!O;B!S=6-C
M97-S+"!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=6YL;V-K*"1F:6QE<&%T:"P@)'5S97(@/2!N=6QL*0H@("`@
M>PH@("`@("`@("\O($=E="!U<V5R;F%M92!F;W(@4D-3('1A9RX*("`@("`@
M("!I9B`H)'5S97(I('L*("`@("`@("`@("`@<'5T96YV*"=,3T=.04U%/2<@
M+B`D=7-E<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<'5T96YV
M*"=,3T=.04U%/6=U97-T)RD["B`@("`@("`@?0H*("`@("`@("`D<F-S7V-M
M9"`]("1T:&ES+3YG9710871H*"=R8W,G*3L*("`@("`@("`D<F-S7V9L86<@
M/2`G("UU("<["@H@("`@("`@("11(#T@5D-?5TE.1$]74R`_("<B)R`Z("(G
M(B`["B`@("`@("`@)&-M9"`]("1R8W-?8VUD("X@)')C<U]F;&%G("X@)%$@
M+B`D9FEL97!A=&@@+B`D43L*("`@("`@("!E>&5C*"1C;60@+B`G(#(^)C$G
M+"`D<F5T=7)N7V%R<F%Y+"`D<F5T=F%L*3L*"B`@("`@("`@:68@*"1R971V
M86PI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A
M:6QE9"!T;R!S<&%W;B!R8W,@*"(G("X@)&-M9"`N("<B*2!O;B`B)R`N("1F
M:6QE<&%T:"`N("<B("AR971U<FYE9"`G("X@)')E='9A;"`N("<I)RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]U='!U="`]("<G.PH*("`@
M("`@("`@("`@9F]R96%C:"`H)')E='5R;E]A<G)A>2!A<R`D;&EN92D@>PH@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D;&EN93L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)'5N;&]C:V5D7W!O<R`]('-T<G!O<R@D;W5T<'5T
M+"`G=6YL;V-K960G*3L*"B`@("`@("`@("`@(&EF("@D=6YL;V-K961?<&]S
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!!;')E861Y
M('5N;&]C:V5D+@H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]60R]C=G,N<&AP````````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#$P,C(U-2`Q,#4Q-30S-#$T,"`P,C$Q-C``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O<F-S+G!H<"<[
M"@HO*BH*("H@5D-?8W9S(&EM<&QE;65N=&%T:6]N+@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,"TR,#`V($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]60R]60R]C=G,N<&AP+'8@
M,2XS,BXR+C(T(#(P,#8O,#4O,3(@,#0Z-#<Z,#@@8VAU8VL@17AP("0*("H*
M("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R
M9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7V-V<R!E>'1E;F1S(%9#
M7W)C<R!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<B!T:&4@
M8VQA<W,@97AP96-T<RX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`\
M<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($-U<G)E;G0@<&%R
M86UE=&5R<SH*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`G<V]U<F-E
M<F]O="<Z(%1H92!S;W5R8V4@<F]O="!F;W(@=&AI<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5P;W-I=&]R>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("=P871H<R<Z($AA<V@@=VET:"!T
M:&4@;&]C871I;VYS(&]F(&%L;`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YE8V5S<V%R>2!B:6YA<FEE<SH@)W)C<V1I9F8G+"`G
M<FQO9R<L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-V<W!S)RP@)V-V<W!S7VAO;64G(&%N9"!T:&4@=&5M<`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('!A=&@Z("=T96UP)PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@(#PO<')E/@H@("`@("HO"B`@("!F
M=6YC=&EO;B!60U]C=G,H)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^
M7W-O=7)C97)O;W0@/2`D<&%R86US6R=S;W5R8V5R;V]T)UT["B`@("`@("`@
M)'1H:7,M/E]P871H<R`]("1P87)A;7-;)W!A=&AS)UT["B`@("!]"@H@("`@
M9G5N8W1I;VX@:7-&:6QE*"1W:&5R92D*("`@('L*("`@("`@("!R971U<FX@
M0&ES7V9I;&4H)'=H97)E("X@)RQV)RD["B`@("!]"@H@("`@9G5N8W1I;VX@
M)G%U97)Y1&ER*"1W:&5R92D*("`@('L*("`@("`@("`D9&ER(#T@;F5W(%9#
M7T1I<F5C=&]R>5]C=G,H)'1H:7,L("1W:&5R92D["B`@("`@("`@<F5T=7)N
M("1D:7(["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0VAE8VMO=70H)&9I;&4L
M("1R978I"B`@("!["B`@("`@("`@<F5T=7)N(%9#7T-H96-K;W5T7V-V<SHZ
M9V5T*"1T:&ES+"`D9FEL92T^<75E<GE&=6QL4&%T:"@I+"`D<F5V*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971$:69F*"1F:6QE+"`D<F5V,2P@)')E=C(L
M("1T>7!E(#T@)V-O;G1E>'0G+"`D;G5M(#T@,RP@)'=S(#T@=')U92D*("`@
M('L*("`@("`@("!R971U<FX@5D-?1&EF9E]C=G,Z.F=E="@D=&AI<RP@)&9I
M;&4L("1R978Q+"`D<F5V,BP@)'1Y<&4L("1N=6TL("1W<RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@)F=E=$9I;&5/8FIE8W0H)&9I;&5N86UE+"`D8V%C:&4@
M/2!N=6QL+"`D<75I8VML;V<@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H
M<W5B<W1R*"1F:6QE;F%M92P@,"P@,2D@(3T@)R\G*2!["B`@("`@("`@("`@
M("1F:6QE;F%M92`]("<O)R`N("1F:6QE;F%M93L*("`@("`@("!]"B`@("`@
M("`@)&9O(#T@)E9#7T9I;&5?8W9S.CIG971&:6QE3V)J96-T*"1T:&ES+"`D
M=&AI<RT^<V]U<F-E<F]O="@I("X@)&9I;&5N86UE+"`D8V%C:&4L("1Q=6EC
M:VQO9RD["B`@("`@("`@<F5T=7)N("1F;SL*("`@('T*"B`@("!F=6YC=&EO
M;B`F9V5T06YN;W1A=&5/8FIE8W0H)&9I;&5N86UE*0H@("`@>PH@("`@("`@
M("1B;&%M92`](&YE=R!60U]!;FYO=&%T95]C=G,H)'1H:7,L("1F:6QE;F%M
M92P@571I;#HZ9V5T5&5M<$9I;&4H)W9C)RP@=')U92P@)'1H:7,M/E]P871H
M<ULG=&5M<"==*2D["B`@("`@("`@<F5T=7)N("1B;&%M93L*("`@('T*"B`@
M("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H)&9I;&5N86UE+"`D8V%C
M:&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1P;R`]("960U]0871C:'-E=%]C
M=G,Z.F=E=%!A=&-H<V5T3V)J96-T*"1T:&ES+"`D=&AI<RT^<V]U<F-E<F]O
M="@I("X@)R\G("X@)&9I;&5N86UE+"`D8V%C:&4I.PH@("`@("`@(')E='5R
M;B`D<&\["B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&%N;F]T871E(&-L87-S
M+@H@*@H@*B!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL
M+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7T%N;F]T871E7V-V
M<R!["@H@("`@=F%R("1F:6QE.PH@("`@=F%R("1R97`["B`@("!V87(@)'1M
M<&9I;&4["@H@("`@9G5N8W1I;VX@5D-?06YN;W1A=&5?8W9S*"1R97`L("1F
M:6QE+"`D=&UP9FEL92D*("`@('L*("`@("`@("`D=&AI<RT^<F5P(#T@)')E
M<#L*("`@("`@("`D=&AI<RT^9FEL92`]("1F:6QE.PH@("`@("`@("1T:&ES
M+3YT;7!F:6QE(#T@)'1M<&9I;&4["B`@("!]"@H@("`@9G5N8W1I;VX@9&]!
M;FYO=&%T92@D<F5V*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!T:&%T
M('1H92!F:6QE('9A;'5E<R!F;W(@=&AI<R!O8FIE8W0@:7,@=F%L:60N("HO
M"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/F9I;&4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@36%K92!S=7)E('1H870@=&AE(&-V<W)E<"!P87)A;65T97(@:7,@
M=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/G)E<"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(59#7U)E=FES:6]N.CIV86QI9"@D<F5V*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D
M=VAE<F4@/2`D=&AI<RT^9FEL92T^<75E<GE-;V1U;&50871H*"D["B`@("`@
M("`@)'-O=7)C97)O;W0@/2`D=&AI<RT^<F5P+3YS;W5R8V5R;V]T*"D["@H@
M("`@("`@("1P:7!E(#T@<&]P96XH)'1H:7,M/G)E<"T^9V5T4&%T:"@G8W9S
M)RD@+B`G("UN('-E<G9E<B`^("<@+B`D=&AI<RT^=&UP9FEL92P@5D-?5TE.
M1$]74R`_("=W8B<@.B`G=R<I.PH*("`@("`@("`D;W5T(#T@87)R87DH*3L*
M("`@("`@("`D;W5T6UT@/2`B4F]O="`D<V]U<F-E<F]O="(["B`@("`@("`@
M)&]U=%M=(#T@)U9A;&ED+7)E<W!O;G-E<R!O:R!E<G)O<B!686QI9"UR97%U
M97-T<R!#:&5C:V5D+6EN(%5P9&%T960@365R9V5D(%)E;6]V960@32!%)SL*
M("`@("`@("`D;W5T6UT@/2`G57-E56YC:&%N9V5D)SL*("`@("`@("`D;W5T
M6UT@/2`G07)G=6UE;G0@+7(G.PH@("`@("`@("1O=71;72`](")!<F=U;65N
M="`D<F5V(CL*("`@("`@("`D;W5T6UT@/2`B07)G=6UE;G0@)'=H97)E(CL*
M("`@("`@("`D9&ER<R`](&5X<&QO9&4H)R\G+"!D:7)N86UE*"1W:&5R92DI
M.PH@("`@("`@('=H:6QE("AC;W5N="@D9&ER<RDI('L*("`@("`@("`@("`@
M)&]U=%M=(#T@)T1I<F5C=&]R>2`G("X@:6UP;&]D92@G+R<L("1D:7)S*3L*
M("`@("`@("`@("`@)&]U=%M=(#T@(B1S;W5R8V5R;V]T+R(@+B!I;7!L;V1E
M*"<O)RP@)&1I<G,I.PH@("`@("`@("`@("!A<G)A>5]P;W`H)&1I<G,I.PH@
M("`@("`@('T*("`@("`@("`D;W5T6UT@/2`G1&ER96-T;W)Y("XG.PH@("`@
M("`@("1O=71;72`]("1S;W5R8V5R;V]T.PH@("`@("`@("1O=71;72`]("=A
M;FYO=&%T92<["@H@("`@("`@(&9O<F5A8V@@*"1O=70@87,@)&QI;F4I('L*
M("`@("`@("`@("`@9G=R:71E*"1P:7!E+"`B)&QI;F5<;B(I.PH@("`@("`@
M('T*("`@("`@("!P8VQO<V4H)'!I<&4I.PH*("`@("`@("!I9B`H(2@D9FP@
M/2!F;W!E;B@D=&AI<RT^=&UP9FEL92P@5D-?5TE.1$]74R`_("=R8B<@.B`G
M<B<I*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@("1L:6YE(#T@9F=E
M=',H)&9L+"`T,#DV*3L*"B`@("`@("`@+R\@5VEN9&]W<R!V97)S:6]N<R!O
M9B!C=G,@86QW87ES(')E='5R;B`D=VAE<F4@=VET:"!F;W)W87)D<R!S;&%S
M:&5S+@H@("`@("`@(&EF("A60U]724Y$3U=3*2!["B`@("`@("`@("`@("1W
M:&5R92`]('-T<E]R97!L86-E*$1)4D5#5$]265]315!!4D%43U(L("<O)RP@
M)'=H97)E*3L*("`@("`@("!]"@H@("`@("`@('=H:6QE("@D;&EN92`F)B`A
M<')E9U]M871C:"@B?%Y%7',K06YN;W1A=&EO;G,@9F]R("1W:&5R97PB+"`D
M;&EN92DI('L*("`@("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9FPL(#0P.38I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D;&EN92D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O(&%N;F]T871E
M.R!S97)V97(@<V%I9#H@)R`N("1L:6YE*3L*("`@("`@("!]"@H@("`@("`@
M("1L:6YE;F\@/2`Q.PH@("`@("`@('=H:6QE("@D;&EN92`](&9G971S*"1F
M;"P@-#`Y-BDI('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>35QS
M*RA;7&1<+ETK*5QS*UPH*"XK*5QS*RA<9"LM7'<K+5QD*RE<*3HN*"XJ*20O
M)RP@)&QI;F4L("1R96=S*2D@>PH@("`@("`@("`@("`@("`@)&5N=')Y(#T@
M87)R87DH*3L*("`@("`@("`@("`@("`@("1E;G1R>5LG<F5V)UT@("`@/2`D
M<F5G<ULQ73L*("`@("`@("`@("`@("`@("1E;G1R>5LG875T:&]R)UT@/2!T
M<FEM*"1R96=S6S)=*3L*("`@("`@("`@("`@("`@("1E;G1R>5LG9&%T92==
M("`@/2`D<F5G<ULS73L*("`@("`@("`@("`@("`@("1E;G1R>5LG;&EN92==
M("`@/2`D<F5G<ULT73L*("`@("`@("`@("`@("`@("1E;G1R>5LG;&EN96YO
M)UT@/2`D;&EN96YO*RL["B`@("`@("`@("`@("`@("`D;&EN97-;72`]("1E
M;G1R>3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F-L;W-E
M*"1F;"D["B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*"GT*"B\J*@H@
M*B!60U]C=G,@8VAE8VMO=70@8VQA<W,N"B`J"B`J(%-E92!T:&4@4D5!1$U%
M(&9I;&4@=&AA="!C86UE('=I=&@@=&AI<R!L:6)R87)Y(&9O<B!M;W)E"B`J
M(&EN9F]R;6%T:6]N+"!A;F0@<F5A9"!T:&4@:6YL:6YE(&1O8W5M96YT871I
M;VXN"B`J"B`J($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G
M/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O
M:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?0VAE8VMO=71?
M8W9S('L*"B`@("`O*BH*("`@("`J(%-T871I8R!F=6YC=&EO;B!W:&EC:"!R
M971U<FYS(&$@9FEL92!P;VEN=&EN9R!T;R!T:&4@:&5A9"!O9B!T:&4*("`@
M("`J(')E<75E<W1E9"!R979I<VEO;B!O9B!A;B!20U,@9FEL92X*("`@("`J
M"B`@("`@*B!`<&%R86T@5D-?8W9S("1R97`@("`@("`@02!R97!O<VET;W)Y
M(&]B:F5C=`H@("`@("H@0'!A<F%M('-T<FEN9R`D9G5L;&YA;64@($9U;&QY
M('%U86QI9FEE9"!P871H;F%M92!O9B!T:&4@9&5S:7)E9"!20U,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!F:6QE('1O(&-H96-K;W5T"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1R978@("`@("`@4D-3(')E=FES:6]N(&YU
M;6)E<B!T;R!C:&5C:R!O=70*("`@("`J"B`@("`@*B!`<F5T=7)N(')E<V]U
M<F-E?&]B:F5C="`@16ET:&5R(&$@4$5!4E]%<G)O<B!O8FIE8W0L(&]R(&$@
M<W1R96%M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@<&]I;G1E
M<B!T;R!T:&4@:&5A9"!O9B!T:&4@8VAE8VMO=70*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T*"1R97`L("1F=6QL;F%M92P@)')E=BD*("`@('L*("`@("`@
M("!I9B`H(59#7U)E=FES:6]N.CIV86QI9"@D<F5V*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G26YV86QI9"!R979I<VEO;B!N
M=6UB97(G*3L*("`@("`@("!]"@H@("`@("`@(&EF("A60U]724Y$3U=3*2![
M"B`@("`@("`@("`@("1M;V1E(#T@)W)B)SL*("`@("`@("`@("`@)'%?;F%M
M92`]("<B)R`N(&5S8V%P97-H96QL8VUD*'-T<E]R97!L86-E*"=<7"<L("<O
M)RP@)&9U;&QN86UE*2D@+B`G(B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&UO9&4@/2`G<B<["B`@("`@("`@("`@("1Q7VYA;64@/2!E<V-A
M<&5S:&5L;&%R9R@D9G5L;&YA;64I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"$H)%)#4R`]('!O<&5N*"1R97`M/F=E=%!A=&@H)V-O)RD@+B`B("UP)')E
M=B`D<5]N86UE(#(^)C$B+"`D;6]D92DI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#;W5L9&Y<)W0@<&5R9F]R;2!C:&5C:V]U
M="!O9B!T:&4@<F5Q=65S=&5D(&9I;&4G*3L*("`@("`@("!]"@H@("`@("`@
M("\J($9I<G-T(&QI;F4@9G)O;2!C;R!S:&]U;&0@8F4@;V8@=&AE(&9O<FT@
M.@H@("`@("`@("`J("]P871H+W1O+V9I;&5N86UE+'8@("TM/B`@<W1A;F1A
M<F0@;W5T"B`@("`@("`@("H@86YD('=E(&-H96-K('1H870@=&AI<R!I<R!T
M:&4@8V%S92!A;F0@97)R;W(@;W1H97)W:7-E"B`@("`@("`@("HO"@H@("`@
M("`@("1C;R`](&9G971S*"120U,L(#$P,C0I.PH@("`@("`@(&EF("@A<')E
M9U]M871C:"@G+UXH6UQ3(%TK*2QV7',K+2T^7',K<W0H86YD87(I/V0@/V]U
M="AP=70I/UQS*B0O)RP@)&-O+"`D<F5G<RD@?'P@)')E9W-;,5TN)RQV)R`A
M/2`D9G5L;&YA;64I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N97AP96-T960@;W5T<'5T(&9R;VT@8VAE8VMO=70Z("<@+B`D
M8V\I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F5X="!L:6YE(&9R;VT@8V\@
M:7,@;V8@=&AE(&9O<FTZ"B`@("`@("`@("H@<F5V:7-I;VX@,2XR+C,*("`@
M("`@("`@*B!43T1/.B!C;VUP87)E('1H:7,@=&\@)')E=B!F;W(@8V]N<VES
M=&5N8WDL(&%T;2!W92!J=7-T"B`@("`@("`@("H@("`@("`@9&ES8V%R9"!T
M:&4@=F%L=64@=&\@;6]V92!I;G!U="!P;VEN=&5R(&%L;VYG("T@879S;0H@
M("`@("`@("`J+PH@("`@("`@("1C;R`](&9G971S*"120U,L(#$P,C0I.PH*
M("`@("`@("!R971U<FX@)%)#4SL*("`@('T*"GT*"B\J*@H@*B!60U]C=G,@
M9&EF9B!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y
M+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA
M=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*
M8VQA<W,@5D-?1&EF9E]C=G,@>PH*("`@("\J*@H@("`@("H@3V)T86EN('1H
M92!D:69F97)E;F-E<R!B971W965N('1W;R!R979I<VEO;G,@;V8@82!F:6QE
M+@H@("`@("H*("`@("`J($!P87)A;2!60U]C=G,@)')E<"`@("`@("`@02!R
M97!O<VET;W)Y(&]B:F5C="X*("`@("`J($!P87)A;2!60U]&:6QE7V-V<R`D
M9FEL92`@5&AE(&1E<VER960@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)')E=C$@("`@("`@3W)I9VEN86P@<F5V:7-I;VX@;G5M8F5R('1O(&-O;7!A
M<F4@9G)O;2X*("`@("`J($!P87)A;2!S=')I;F<@)')E=C(@("`@("`@3F5W
M(')E=FES:6]N(&YU;6)E<B!T;R!C;VUP87)E(&%G86EN<W0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T>7!E("`@("`@(%1H92!T>7!E(&]F(&1I9F8@*&4N
M9RX@)W5N:69I960G*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1N=6T@("`@
M("`@3G5M8F5R(&]F(&QI;F5S('1O(&)E('5S960@:6X@8V]N=&5X="!A;F0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YI9FEE9"!D:69F
M<RX*("`@("`J($!P87)A;2!B;V]L96%N("1W<R`@("`@("`@4VAO=R!W:&ET
M97-P86-E(&EN('1H92!D:69F/PH@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG?&)O;VQE86X@($9A;'-E(&]N(&9A:6QU<F4L(&]R(&$@<W1R:6YG(&-O
M;G1A:6YI;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!D
M:69F(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D<F5P
M+"`D9FEL92P@)')E=C$L("1R978R+"`D='EP92`]("=C;VYT97AT)RP@)&YU
M;2`](#,L"B`@("`@("`@("`@("`@("`@)'=S(#T@=')U92D*("`@('L*("`@
M("`@("`O*B!-86ME('-U<F4@=&AA="!T:&4@9FEL92!P87)A;65T97(@:7,@
M=F%L:60N("HO"B`@("`@("`@:68@*&ES7V$H)&9I;&4L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0VAE8VL@=&AA="!T:&4@<F5V:7-I;VX@;G5M8F5R<R!A<F4@
M=F%L:60N("HO"B`@("`@("`@)')E=C$@/2!60U]2979I<VEO;CHZ=F%L:60H
M)')E=C$I(#\@)')E=C$@.B`G,2XQ)SL*("`@("`@("`D<F5V,B`](%9#7U)E
M=FES:6]N.CIV86QI9"@D<F5V,2D@/R`D<F5V,B`Z("<Q+C$G.PH*("`@("`@
M("`D9G5L;$YA;64@/2`D9FEL92T^<75E<GE&=6QL4&%T:"@I.PH@("`@("`@
M("1D:69F(#T@87)R87DH*3L*("`@("`@("`D;W!T:6]N<R`]("<M:VL@)SL*
M("`@("`@("!I9B`H(21W<RD@>PH@("`@("`@("`@("`D;W!T<R`]("<@+6)"
M("<["B`@("`@("`@("`@("1O<'1I;VYS("X]("1O<'1S.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1O<'1S(#T@)R<["B`@("`@("`@?0H@("`@
M("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E("=C;VYT97AT)SH*
M("`@("`@("`@("`@)&]P=&EO;G,@/2`D;W!T<R`N("<M<"`M+6-O;G1E>'0]
M)R`N("AI;G0I)&YU;3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)W5N:69I960G.@H@("`@("`@("`@("`D;W!T:6]N<R`]("1O<'1S("X@
M)RUP("TM=6YI9FEE9#TG("X@*&EN="DD;G5M.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@8V%S92`G8V]L=6UN)SH*("`@("`@("`@("`@)&]P=&EO
M;G,@/2`D;W!T<R`N("<M+7-I9&4M8GDM<VED92`M+7=I9'1H/3$R,"<["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=E9"<Z"B`@("`@("`@
M("`@("1O<'1I;VYS(#T@)&]P=',@+B`G+64G.PH@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!]"@H@("`@("`@("\O(%=I;F1O=W,@=F5R<VEO;G,@;V8@
M8W9S(&%L=V%Y<R!R971U<FX@)'=H97)E('=I=&@@9F]R=V%R9',@<VQA<VAE
M<RX*("`@("`@("!I9B`H5D-?5TE.1$]74RD@>PH@("`@("`@("`@("`D9G5L
M;$YA;64@/2!S=')?<F5P;&%C92A$25)%0U1/4EE?4T5005)!5$]2+"`G+R<L
M("1F=6QL3F%M92D["B`@("`@("`@?0H*("`@("`@("`O+R!43T1/.B!A9&0@
M;W!T:6]N<R!F;W(@)&AR(&]P=&EO;G,@+2!H;W=E=F5R('1H97-E(&UA>2!N
M;W0@8F4*("`@("`@("`O+R!C;VUP871I8FQE('=I=&@@<V]M92!D:69F<RX*
M("`@("`@("`D8V]M;6%N9"`]("1R97`M/F=E=%!A=&@H)W)C<V1I9F8G*2`N
M("(@)&]P=&EO;G,@+7(D<F5V,2`M<B1R978R(%PB(B`N(&5S8V%P97-H96QL
M8VUD*"1F=6QL3F%M92D@+B`G(B`R/B8Q)SL*("`@("`@("!I9B`H5D-?5TE.
M1$]74RD@>PH@("`@("`@("`@("`D8V]M;6%N9"`N/2`G(#P@(B<@+B!?7T9)
M3$5?7R`N("<B)SL*("`@("`@("!]"@H@("`@("`@(&5X96,H)&-O;6UA;F0L
M("1D:69F+"`D<F5T=F%L*3L*("`@("`@("!R971U<FX@*"1R971V86P@/B`P
M*2`_("1D:69F(#H@87)R87DH*3L*("`@('T*"GT*"B\J*@H@*B!60U]C=G,@
M9&ER96-T;W)Y(&-L87-S+@H@*@H@*B!#;W!Y<FEG:'0@06YI;"!-861H879A
M<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J($!A=71H;W(@($%N:6P@
M36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#
M"B`J+PIC;&%S<R!60U]$:7)E8W1O<GE?8W9S('L*"B`@("!V87(@)')E<#L*
M("`@('9A<B`D9&ER3F%M93L*("`@('9A<B`D9FEL97,["B`@("!V87(@)&%T
M=&EC1FEL97,["B`@("!V87(@)&UE<F=E9$9I;&5S.PH@("`@=F%R("1D:7)S
M.PH@("`@=F%R("1P87)E;G0["B`@("!V87(@)&UO9'5L94YA;64["B`@("!V
M87(@)'-O<G1$:7(["@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@0U93($1I
M<F5C=&]R>2!O8FIE8W0@=&\@<W1O<F4@:6YF;W)M871I;VX*("`@("`J(&%B
M;W5T('1H92!F:6QE<R!I;B!A('-I;F=L92!D:7)E8W1O<GD@:6X@=&AE(')E
M<&]S:71O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M(%9#7V-V<R`D<F5P("`@
M("`@("`@("!!(')E<&]S:71O<GD@;V)J96-T"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D;B`@("`@("`@("`@(%!A=&@@=&\@=&AE(&1I<F5C=&]R>2X*("`@
M("`J($!P87)A;2!60U]$:7)E8W1O<GE?8W9S("1P;B`@5&AE('!A<F5N="!6
M0U]$:7)E8W1O<GD@=&\@=&AI<R!O;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%9#7T1I<F5C=&]R>5]C=G,H)')E<"P@)&1N+"`D<&X@/2`G)RD*("`@('L*
M("`@("`@("`D=&AI<RT^<F5P(#T@)')E<#L*("`@("`@("`D=&AI<RT^<&%R
M96YT(#T@)'!N.PH@("`@("`@("1T:&ES+3YM;V1U;&5.86UE(#T@)&1N.PH@
M("`@("`@("1T:&ES+3YD:7).86UE(#T@)')E<"T^<V]U<F-E<F]O="@I("X@
M(B\D9&XB.PH@("`@("`@("1T:&ES+3YF:6QE<R`](&%R<F%Y*"D["B`@("`@
M("`@)'1H:7,M/F1I<G,@/2!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&9U;&QY('%U86QI9FEE9"!P871H;F%M92!T;R!T:&ES(&1I
M<F5C=&]R>2!W:71H(&YO"B`@("`@*B!T<F%I;&EN9R`O+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!0871H;F%M92!O9B!T:&ES(&1I<F5C=&]R
M>0H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>41I<B@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD:7).86UE.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9Q=65R>41I<DQI<W0H*0H@("`@>PH@("`@("`@(')E<V5T*"1T:&ES+3YD
M:7)S*3L*("`@("`@("!R971U<FX@)'1H:7,M/F1I<G,["B`@("!]"@H@("`@
M9G5N8W1I;VX@)G%U97)Y1FEL94QI<W0H)'-H;W=A='1I8R`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&EF("@D<VAO=V%T=&EC("8F(&ES<V5T*"1T:&ES+3YM
M97)G961&:6QE<RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM97)G
M961&:6QE<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F9I;&5S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%1E;&P@=&AE(&]B:F5C="!T;R!O<&5N(&%N9"!B<F]W<V4@:71S(&-U<G)E
M;G0@9&ER96-T;W)Y+"!A;F0*("`@("`J(')E=')I979E(&$@;&ES="!O9B!A
M;&P@=&AE(&]B:F5C=',@:6X@=&AE<F4N("!)="!T:&5N('!O<'5L871E<PH@
M("`@("H@=&AE(&9I;&4O9&ER96-T;W)Y('-T86-K(&%N9"!M86ME<R!I="!A
M=F%I;&%B;&4@9F]R(')E=')I979A;"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86Y\;V)J96-T("!014%27T5R<F]R(&]B:F5C="!O;B!A;B!E<G)O
M<BP@=')U92!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO;B!B<F]W
M<V5$:7(H)&-A8VAE(#T@;G5L;"P@)'%U:6-K;&]G(#T@=')U92P@)'-H;W=A
M='1I8R`](&9A;'-E*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!A
M<F4@=')Y:6YG('1O(&QI<W0@82!D:7)E8W1O<GD@*B\*("`@("`@("!I9B`H
M(4!I<U]D:7(H)'1H:7,M/F1I<DYA;64I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=5;F%B;&4@=&\@9FEN9"!D:7)E8W1O<GD@
M)R`N("1T:&ES+3YD:7).86UE*3L*("`@("`@("!]"@H@("`@("`@("\J($]P
M96X@=&AE(&1I<F5C=&]R>2!F;W(@<F5A9&EN9R!I=',@8V]N=&5N=',@*B\*
M("`@("`@("!I9B`H(2@D1$E2(#T@0&]P96YD:7(H)'1H:7,M/F1I<DYA;64I
M*2D@>PH@("`@("`@("`@("`D97)R;7-G(#T@*"%E;7!T>2@D<&AP7V5R<F]R
M;7-G*2D@/R`D<&AP7V5R<F]R;7-G(#H@)U!E<FUI<W-I;VX@9&5N:65D)SL*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<FUS9RD[
M"B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@='=O(&%R<F%Y<R`M(&]N
M92!O9B!A;&P@=&AE(&9I;&5S+"!A;F0@=&AE(&]T:&5R(&]F"B`@("`@("`@
M("H@86QL('1H92!D:7)E8W1O<FEE<RX@*B\*("`@("`@("!W:&EL92`H*"1N
M86UE(#T@<F5A9&1I<B@D1$E2*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M(&EF("@D;F%M92`]/2`G+B<@?'P@)&YA;64@/3T@)RXN)RD@>PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1P871H(#T@)'1H:7,M/F1I<DYA;64@+B`G+R<@+B`D;F%M93L*("`@("`@
M("`@("`@:68@*$!I<U]D:7(H)'!A=&@I*2!["B`@("`@("`@("`@("`@("`O
M*B!3:VEP($%T=&EC(&1I<F5C=&]R>2X@*B\*("`@("`@("`@("`@("`@(&EF
M("@D;F%M92`A/2`G071T:6,G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F1I<G-;72`]("1N86UE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V5I9B`H0&ES7V9I;&4H)'!A=&@I("8F('-U8G-T<B@D;F%M
M92P@+3(I(#T]("<L=B<I('L*("`@("`@("`@("`@("`@("\J(%-P87=N(&$@
M;F5W(&9I;&4@;V)J96-T('1O(')E<')E<V5N="!T:&ES(&9I;&4N("HO"B`@
M("`@("`@("`@("`@("`D9FP@/2`D=&AI<RT^<F5P+3YG971&:6QE3V)J96-T
M*'-U8G-T<B@D<&%T:"P@<W1R;&5N*"1T:&ES+3YR97`M/G-O=7)C97)O;W0H
M*2DL("TR*2P@)&-A8VAE+"`D<75I8VML;V<I.PH@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)&9L+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1F;#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5S6UT@/2`D9FP["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\J($-L;W-E('1H92!F:6QE:&%N9&QE.R!W92=V92!N;W<@9V]T(&$@;&ES
M="!O9B!D:7)S(&%N9`H@("`@("`@("`J(&9I;&5S+B`J+PH@("`@("`@(&-L
M;W-E9&ER*"1$25(I.PH*("`@("`@("`O*B!)9B!W92!W86YT('1O(&UE<F=E
M('1H92!A='1I8RP@861D(&ET(&EN(&AE<F4N("HO"B`@("`@("`@:68@*"1S
M:&]W871T:6,I('L*("`@("`@("`@("`@)&%T=&EC1&ER(#T@;F5W(%9#7T1I
M<F5C=&]R>5]C=G,H)'1H:7,M/G)E<"P@)'1H:7,M/FUO9'5L94YA;64@+B`G
M+T%T=&EC)RP@)'1H:7,I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&%T=&EC
M1&ER+3YB<F]W<V5$:7(H)&-A8VAE+"`D<75I8VML;V<I+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^871T:6-&:6QE<R`]("1A
M='1I8T1I<BT^<75E<GE&:6QE3&ES="@I.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FUE<F=E9$9I;&5S(#T@87)R87E?;65R9V4H)'1H:7,M/F9I;&5S+"`D
M=&AI<RT^871T:6-&:6QE<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V]R
M="!T:&4@8V]N=&5N=',@;V8@=&AE(&1I<F5C=&]R>2!I;B!A(&=I=F5N(&9A
M<VAI;VX@86YD"B`@("`@*B!O<F1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:&]W("!/9B!T:&4@9F]R;2!60U]33U)47RH@=VAE<F4@*B!C
M86X@8F4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!.3TY%+"!.04U%
M+"!!1T4L(%)%5B!F;W(@<V]R=&EN9R!B>2!N86UE+"!A9V4@;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@(')E=FES:6]N+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&1I<B`@3V8@=&AE(&9O<FT@5D-?4T]25%\J('=H97)E("H@
M8V%N(&)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@05-#14Y$24Y'
M+"!$15-#14Y$24Y'(&9O<B!T:&4@;W)D97(@;V8@=&AE('-O<G0N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%P<&QY4V]R="@D:&]W(#T@5D-?4T]25%].3TY%
M+"`D9&ER(#T@5D-?4T]25%]!4T-%3D1)3D<I"B`@("!["B`@("`@("`@+R\@
M06QW87ES('-O<G0@9&ER96-T;W)I97,@8GD@;F%M92X*("`@("`@("!N871C
M87-E<V]R="@D=&AI<RT^9&ER<RD["@H@("`@("`@("1T:&ES+3YD;T9I;&53
M;W)T*"1T:&ES+3YF:6QE<RP@)&AO=RP@)&1I<BD["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YA='1I8T9I;&5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M9&]&:6QE4V]R="@D=&AI<RT^871T:6-&:6QE<RP@)&AO=RP@)&1I<BD["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65R9V5D1FEL97,I
M*2!["B`@("`@("`@("`@("1T:&ES+3YD;T9I;&53;W)T*"1T:&ES+3YM97)G
M961&:6QE<RP@)&AO=RP@)&1I<BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&1O1FEL95-O<G0H)B1F:6QE3&ES="P@)&AO=R`](%9#7U-/4E1?
M3D].12P@)&1I<B`](%9#7U-/4E1?05-#14Y$24Y'*0H@("`@>PH@("`@("`@
M("1T:&ES+3YS;W)T1&ER(#T@)&1I<CL*"B`@("`@("`@<W=I=&-H("@D:&]W
M*2!["B`@("`@("`@8V%S92!60U]33U)47T%'13H*("`@("`@("`@("`@=7-O
M<G0H)&9I;&5,:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&5!9V53;W)T)RDI.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47TY!344Z
M"B`@("`@("`@("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H:7,L("=F
M:6QE3F%M95-O<G0G*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C
M87-E(%9#7U-/4E1?05542$]2.@H@("`@("`@("`@("!U<V]R="@D9FEL94QI
M<W0L(&%R<F%Y*"1T:&ES+"`G9FEL94%U=&AO<E-O<G0G*2D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#7U-/4E1?4D56.@H@("`@("`@
M("`@("!U<V]R="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL95)E=E-O
M<G0G*2D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@
M=6YS970H)'1H:7,M/G-O<G1$:7(I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V]R="!F=6YC=&EO;B!F;W(@9FEL92!A9V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9I;&5!9V53;W)T*"1A+"`D8BD*("`@('L*("`@("`@("`D86$@/2`D
M82T^<75E<GE,87-T3&]G*"D["B`@("`@("`@)&)B(#T@)&(M/G%U97)Y3&%S
M=$QO9R@I.PH@("`@("`@(&EF("@D86$M/G%U97)Y1&%T92@I(#T]("1B8BT^
M<75E<GE$871E*"DI('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3YS;W)T1&ER(#T](%9#7U-/4E1?05-#14Y$24Y'
M*2!["B`@("`@("`@("`@(')E='5R;B`H)&%A+3YQ=65R>41A=&4H*2`\("1B
M8BT^<75E<GE$871E*"DI(#\@,2`Z("TQ.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`H)&)B+3YQ=65R>41A=&4H*2`\("1A82T^<75E
M<GE$871E*"DI(#\@,2`Z("TQ.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%-O<G0@9G5N8W1I;VX@8GD@875T:&]R(&YA;64N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9I;&5!=71H;W)3;W)T*"1A+"`D8BD*("`@('L*("`@
M("`@("`D86$@/2`D82T^<75E<GE,87-T3&]G*"D["B`@("`@("`@)&)B(#T@
M)&(M/G%U97)Y3&%S=$QO9R@I.PH@("`@("`@(&EF("@D86$M/G%U97)Y075T
M:&]R*"D@/3T@)&)B+3YQ=65R>4%U=&AO<B@I*2!["B`@("`@("`@("`@(')E
M='5R;B`P.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^<V]R=$1I<B`]/2!6
M0U]33U)47T%30T5.1$E.1RD@>PH@("`@("`@("`@("!R971U<FX@*"1A82T^
M<75E<GE!=71H;W(H*2`^("1B8BT^<75E<GE!=71H;W(H*2D@/R`Q(#H@+3$[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("@D8F(M/G%U
M97)Y075T:&]R*"D@/B`D86$M/G%U97)Y075T:&]R*"DI(#\@,2`Z("TQ.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-O<G0@9G5N8W1I;VX@
M9F]R(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE3F%M95-O
M<G0H)&$L("1B*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^<V]R=$1I<B`]
M/2!60U]33U)47T%30T5.1$E.1RD@>PH@("`@("`@("`@("!R971U<FX@<W1R
M8V%S96-M<"@D82T^;F%M92P@)&(M/FYA;64I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!S=')C87-E8VUP*"1B+3YN86UE+"`D82T^
M;F%M92D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V]R="!F
M=6YC=&EO;B!F;W(@<F5V:7-I;VXN"B`@("`@*B\*("`@(&9U;F-T:6]N(&9I
M;&529793;W)T*"1A+"`D8BD*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G-O
M<G1$:7(@/3T@5D-?4T]25%]!4T-%3D1)3D<I('L*("`@("`@("`@("`@<F5T
M=7)N(%9#7U)E=FES:6]N.CIC;7`H)&$M/G%U97)Y2&5A9"@I+"`D8BT^<75E
M<GE(96%D*"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!60U]2979I<VEO;CHZ8VUP*"1B+3YQ=65R>4AE860H*2P@)&$M/G%U97)Y
M2&5A9"@I*3L*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@5D-?8W9S(&9I
M;&4@8VQA<W,N"B`J"B`J($-O<'ER:6=H="!!;FEL($UA9&AA=F%P961D>2P@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A
M<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L
M87-S(%9#7T9I;&5?8W9S(&5X=&5N9',@5D-?1FEL92!["@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@82!R97!O<VET;W)Y(&9I;&4@;V)J96-T+"!A;F0@9VEV
M92!I="!I;F9O<FUA=&EO;B!A8F]U=`H@("`@("H@=VAA="!I=',@<&%R96YT
M(&1I<F5C=&]R>2!A;F0@<F5P;W-I=&]R>2!O8FIE8W1S(&%R92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;"`@1G5L;"!P871H('1O('1H:7,@
M9FEL92X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?1FEL95]C=G,H)&9L+"`D
M<75I8VML;V<@/2!F86QS92D*("`@('L*("`@("`@("`D9FP@+CT@)RQV)SL*
M("`@("`@("`D=&AI<RT^;F%M92`](&)A<V5N86UE*"1F;"D["B`@("`@("`@
M)'1H:7,M/F1I<B`](&1I<FYA;64H)&9L*3L*("`@("`@("`D=&AI<RT^;&]G
M<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/G%U:6-K;&]G(#T@)'%U:6-K
M;&]G.PH@("`@("`@("1T:&ES+3YR979S(#T@87)R87DH*3L*("`@("`@("`D
M=&AI<RT^8G)A;F-H97,@/2!A<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G971&:6QE3V)J96-T*"1R97`L("1F:6QE;F%M92P@)&-A8VAE(#T@;G5L
M;"P@)'%U:6-K;&]G(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@5&AE('9E
M<G-I;VX@;V8@=&AE(&-A8VAE9"!D871A+B!);F-R96UE;G0@=&AI<R!W:&5N
M979E<B!T:&4*("`@("`@("`@*B!I;G1E<FYA;"!S=&]R86=E(&9O<FUA="!C
M:&%N9V5S+"!S=6-H('1H870@=V4@;75S=`H@("`@("`@("`J(&EN=F%L:61A
M=&4@<')I;W(@8V%C:&5D(&1A=&$N("HO"B`@("`@("`@)&-A8VAE5F5R<VEO
M;B`](#(["B`@("`@("`@)&-A8VAE260@/2`D<F5P+3YS;W5R8V5R;V]T*"D@
M+B`G7VXG("X@)&9I;&5N86UE("X@)U]F)R`N("AI;G0I)'%U:6-K;&]G("X@
M)U]V)R`N("1C86-H959E<G-I;VX["@H@("`@("`@("1C=&EM92`]('1I;64H
M*2`M($!F:6QE;71I;64H)&9I;&5N86UE("X@)RQV)RD["B`@("`@("`@:68@
M*"1C86-H92`F)@H@("`@("`@("`@("`D8V%C:&4M/F5X:7-T<R@D8V%C:&5)
M9"P@)&-T:6UE*2D@>PH@("`@("`@("`@("`D9FEL94]B(#T@=6YS97)I86QI
M>F4H)&-A8VAE+3YG970H)&-A8VAE260L("1C=&EM92DI.PH@("`@("`@("`@
M("`D9FEL94]B+3YS971297!O<VET;W)Y*"1R97`I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1F:6QE3V(@/2!N97<@5D-?1FEL95]C=G,H)&9I
M;&5N86UE+"`D<75I8VML;V<I.PH@("`@("`@("`@("`D9FEL94]B+3YS9712
M97!O<VET;W)Y*"1R97`I.PH@("`@("`@("`@("!I9B`H:7-?82@H)')E<W5L
M="`]("1F:6QE3V(M/F=E=$)R;W=S94EN9F\H*2DL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1F:6QE3V(M/F%P<&QY4V]R="A60U]33U)47T%'
M12D["@H@("`@("`@("`@("!I9B`H)&-A8VAE*2!["B`@("`@("`@("`@("`@
M("`D8V%C:&4M/G-E="@D8V%C:&5)9"P@<V5R:6%L:7IE*"1F:6QE3V(I*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE
M3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)9B!T:&ES(&9I;&4@:7,@<')E
M<V5N="!I;B!A;B!!='1I8R!D:7)E8W1O<GDL('1H:7,@:6YD:6-A=&5S"B`@
M("`@*B!I="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@
M:68@9FEL92!I<R!I;B!T:&4@071T:6,L(&%N9"!F86QS92!O=&AE<G=I<V4*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-!='1I8T9I;&4H*0H@("`@>PH@("`@
M("`@(')E='5R;B!S=6)S='(H)'1H:7,M/F1I<BP@+34I(#T]("=!='1I8R<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N86UE(&]F('1H
M92!C=7)R96YT(&9I;&4@87,@:6X@=&AE(')E<&]S:71O<GD*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@1FEL96YA;64@*'=I=&AO=70@=&AE('!A
M=&@I"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y4F5P;W-I=&]R>4YA;64H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;F%M93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@;F%M92!O9B!T:&4@8W5R<F5N="!F:6QE
M('=I=&AO=70@=&AE(')E<&]S:71O<GD*("`@("`J(&5X=&5N<VEO;G,@*'5S
M=6%L;'D@+'8I"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($9I;&5N
M86UE('=I=&AO=70@<F5P;W-I=&]R>2!E>'1E;G-I;VX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75E<GE.86UE*"D*("`@('L*("`@("`@("!R971U<FX@<')E
M9U]R97!L86-E*"<O+'8D+R<L("<G+"`D=&AI<RT^;F%M92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&QA<W0@<F5V:7-I;VX@;V8@=&AE
M(&-U<G)E;G0@9FEL92!O;B!T:&4@2$5!1"!B<F%N8V@*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9WQO8FIE8W0@($QA<W0@<F5V:7-I;VX@;V8@=&AE
M(&-U<G)E;G0@9FEL92!O<B!014%27T5R<F]R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('%U97)Y4F5V:7-I;VXH*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/G)E=G-;,%TI*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=.;R!R979I<VEO;G,G*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YR979S6S!=.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y
M4')E=FEO=7-2979I<VEO;B@D<F5V*0H@("`@>PH@("`@("`@(')E='5R;B!6
M0U]2979I<VEO;CHZ<')E=B@D<F5V*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!T:&4@2$5!1"`H;6]S="!R96-E;G0I(')E=FES:6]N(&YU;6)E
M<B!F;W(@=&AI<R!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!(14%$(')E=FES:6]N(&YU;6)E<@H@("`@("HO"B`@("!F=6YC=&EO;B!Q
M=65R>4AE860H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^:&5A9#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@;&%S="!60U]L;V<@
M;V)J96-T(&EN('1H92!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@5D-?
M;&]G(&]F('1H92!L87-T(&5N=')Y(&EN('1H92!F:6QE"B`@("`@*B\*("`@
M(&9U;F-T:6]N('%U97)Y3&%S=$QO9R@I"B`@("!["B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^<F5V<ULP72D@?'P@(6ES<V5T*"1T:&ES+3YL;V=S6R1T
M:&ES+3YR979S6S!=72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)TYO(')E=FES:6]N<R<I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)'1H:7,M/FQO9W-;)'1H:7,M/G)E=G-;,%U=.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V]R="!T:&4@;&ES="!O9B!60U]L;V<@;V)J96-T<R!T
M:&%T('1H:7,@9FEL92!C;VYT86EN<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:&]W("!60U]33U)47U)%5B`H<V]R="!B>2!R979I<VEO;BDL
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!60U]33U)47TY!344@*'-O
M<G0@8GD@875T:&]R(&YA;64I+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@5D-?4T]25%]!1T4@*'-O<G0@8GD@8V]M;6ET(&1A=&4I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%P<&QY4V]R="@D:&]W(#T@5D-?4T]25%]2158I"B`@
M("!["B`@("`@("`@<W=I=&-H("@D:&]W*2!["B`@("`@("`@8V%S92!60U]3
M3U)47TY!344Z"B`@("`@("`@("`@("1F=6YC(#T@)TYA;64G.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47T%'13H*("`@("`@
M("`@("`@)&9U;F,@/2`G06=E)SL*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@5D-?4T]25%]2158Z"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@)&9U;F,@/2`G4F5V:7-I;VXG.PH@("`@("`@('T*"B`@("`@("`@
M=6%S;W)T*"1T:&ES+3YL;V=S+"!A<G)A>2@D=&AI<RP@(G-O<G1">21F=6YC
M(BDI.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AE('-O<G1">2HH*2!F=6YC=&EO;G,@87)E(&EN=&5R;F%L;'D@=7-E
M9"!B>2!A<'!L>5-O<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1">5)E
M=FES:6]N*"1A+"`D8BD*("`@('L*("`@("`@("!R971U<FX@5D-?4F5V:7-I
M;VXZ.F-M<"@D8BT^<F5V+"`D82T^<F5V*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!S;W)T0GE!9V4H)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R;B`D8BT^
M9&%T92`M("1A+3YD871E.PH@("`@?0H*("`@(&9U;F-T:6]N('-O<G1">4YA
M;64H)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R;B!S=')C;7`H)&$M/F%U
M=&AO<BP@)&(M/F%U=&AO<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!0;W!U
M;&%T92!T:&4@;V)J96-T('=I=&@@:6YF;W)M871I;VX@86)O=70@=&AE(')E
M=FES:6]N<R!L;V=S(&%N9"!D871E<PH@("`@("H@;V8@=&AE(&9I;&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?&]B:F5C="`@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@97)R;W(L(&]R('1R=64@;VX@<W5C8V5S<PH@("`@("HO
M"B`@("!F=6YC=&EO;B!G971"<F]W<V5);F9O*"D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!T:&%T('=E(&%R92!A8W1U86QL>2!I;B!T:&4@9FEL97-Y<W1E
M;2X@*B\*("`@("`@("`D9FEL92`]("1T:&ES+3YQ=65R>49U;&Q0871H*"D[
M"B`@("`@("`@:68@*"%I<U]F:6QE*"1F:6QE*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1FEL92!.;W0@1F]U;F0Z("<@+B`D
M9FEL92D["B`@("`@("`@?0H*("`@("`@("`O*B!#86QL('1H92!20U,@<FQO
M9R!C;VUM86YD('1O(')E=')I979E('1H92!F:6QE"B`@("`@("`@("H@:6YF
M;W)M871I;VXN("HO"B`@("`@("`@)&9L86<@/2`D=&AI<RT^<75I8VML;V<@
M/R`G("UR("<@.B`G("<["B`@("`@("`@)'%?9FEL92`](%9#7U=)3D1/5U,@
M/R`G(B<@+B!E<V-A<&5S:&5L;&-M9"@D9FEL92D@+B`G(B<@.B!E<V-A<&5S
M:&5L;&%R9R@D9FEL92D["@H@("`@("`@("1C;60@/2`D=&AI<RT^<F5P+3YG
M9710871H*"=R;&]G)RD@+B`D9FQA9R`N("1Q7V9I;&4["B`@("`@("`@97AE
M8R@D8VUD+"`D<F5T=7)N7V%R<F%Y+"`D<F5T=F%L*3L*"B`@("`@("`@:68@
M*"1R971V86PI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T9A:6QE9"!T;R!S<&%W;B!R;&]G('1O(')E=')I979E(&9I;&4@;&]G
M(&EN9F]R;6%T:6]N(&9O<B`G("X@)&9I;&4I.PH@("`@("`@('T*"B`@("`@
M("`@)&%C8W5M(#T@87)R87DH*3L*("`@("`@("`D<WEM<F5V(#T@87)R87DH
M*3L*("`@("`@("`D<F5V<WEM(#T@87)R87DH*3L*("`@("`@("`D<W1A=&4@
M/2`G:6YI="<["B`@("`@("`@9F]R96%C:"`H)')E='5R;E]A<G)A>2!A<R`D
M;&EN92D@>PH@("`@("`@("`@("!S=VET8V@@*"1S=&%T92D@>PH@("`@("`@
M("`@("!C87-E("=I;FET)SH*("`@("`@("`@("`@("`@(&EF("@A<W1R;F-M
M<"@G:&5A9#H@)RP@)&QI;F4L(#8I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FAE860@/2!S=6)S='(H)&QI;F4L(#8I.PH@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"%S=')N8VUP*"=B<F%N8V@Z)RP@)&QI;F4L(#<I*2![
M"B`@("`@("`@("`@("`@("`@("`@)'-T871E(#T@)W)E=B<["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)W)E=B<Z"B`@("`@("`@("`@("`@("!I9B`H(7-T<FYC;7`H)RTM
M+2TM+2TM+2TG+"`D;&EN92P@,3`I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'-T871E(#T@)VEN9F\G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS
M>6UR978@/2`D<WEM<F5V.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YR
M979S>6T@/2`D<F5V<WEM.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H(B]>7',K*%M>.ETK*3I<<RLH6UQD7"Y=*RDO(BP@)&QI;F4L
M("1R96=S*2D@>PH@("`@("`@("`@("`@("`@("`@("\O($-H96-K('1O('-E
M92!I9B!T:&ES(&ES(&$@8G)A;F-H"B`@("`@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>*%QD*RA<+EQD*RDK*5PN,%PN*%QD*RDD+R<L)')E
M9W-;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1B<F%N8VA2978@
M/2!60U]2979I<VEO;CHZ=&]"<F%N8V@H)')E9W-;,ETI.PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YB<F%N8VAE<ULD8G)A
M;F-H4F5V72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YB<F%N8VAE<ULD8G)A;F-H4F5V72`]("1R96=S6S%=.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-Y;7)E=ELD<F5G<ULQ75T@/2`D
M<F5G<ULR73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1R
M979S>6U;)')E9W-;,EU=*2D@)')E=G-Y;5LD<F5G<ULR75T]87)R87DH*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E=G-Y;5LD<F5G<ULR75U;72`]
M("1R96=S6S%=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G:6YF;R<Z"B`@("`@("`@("`@("`@("!I9B`H<W1R;F-M<"@G/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T])RP@)&QI;F4L(#,P*2`F)@H@("`@
M("`@("`@("`@("`@("`@('-T<F-M<"@G+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2<L("1L:6YE*2D@>PH@("`@("`@("`@("`@("`@("`@("1A8V-U
M;5M=(#T@)&QI;F4["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H8V]U;G0H
M)&%C8W5M*2D@>PH@("`@("`@("`@("`@("`@("`@("\O('-P87=N(&$@;F5W
M(%9#7VQO9R!O8FIE8W0@86YD(&%D9"!I="!T;R!T:&4@;&]G<R!H87-H"B`@
M("`@("`@("`@("`@("`@("`@)&QO9R`](&YE=R!60U],;V=?8W9S*"1T:&ES
M*3L*("`@("`@("`@("`@("`@("`@("`D97)R(#T@)&QO9RT^<')O8V5S<TQO
M9R@D86-C=6TI.PH@("`@("`@("`@("`@("`@("`@("\O(%1/1$\Z(&5R<F]R
M(&-H96-K<R`M(&%V<VT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M<ULD;&]G+3YQ=65R>5)E=FES:6]N*"E=(#T@)&QO9SL*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<F5V<UM=(#T@)&QO9RT^<75E<GE2979I<VEO;B@I
M.PH@("`@("`@("`@("`@("`@("`@("1A8V-U;2`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&9U;&QY('%U86QI9FEE9"!F:6QE
M;F%M92!O9B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N($9U
M;&QY('%U86QI9FEE9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=65R>49U;&Q0871H*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F1I<B`N("<O)R`N("1T:&ES+3YN86UE.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N86UE(&]F('1H:7,@9FEL92!R
M96QA=&EV92!T;R!I=',@<V]U<F-E<F]O="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@4&%T:&YA;64@<F5L871I=F4@=&\@=&AE('-O=7)C97)O
M;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y36]D=6QE4&%T:"@I"B`@
M("!["B`@("`@("`@<F5T=7)N('!R96=?<F5P;&%C92@G?%XG+B`D=&AI<RT^
M<F5P+3YS;W5R8V5R;V]T*"D@+B`G+S\H+BHI+'8D?"<L("=<,2<L("1T:&ES
M+3YQ=65R>49U;&Q0871H*"DI.PH@("`@?0H*?0H*+RHJ"B`J(%9#7V-V<R!L
M;V<@8VQA<W,N"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!P86-K86=E(%9#"B`J+PIC;&%S<R!60U],
M;V=?8W9S('L*"B`@("!V87(@)')E<#L*("`@('9A<B`D9FEL93L*("`@('9A
M<B`D=&%G<SL*("`@('9A<B`D<F5V.PH@("`@=F%R("1D871E.PH@("`@=F%R
M("1L;V<["B`@("!V87(@)&%U=&AO<CL*("`@('9A<B`D<W1A=&4["B`@("!V
M87(@)&QI;F5S.PH@("`@=F%R("1B<F%N8VAE<SL*"B`@("`O*BH*("`@("`J
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%9#7TQO9U]C=G,H)&9L*0H@("`@>PH@
M("`@("`@("1T:&ES+3YF:6QE(#T@)&9L.PH@("`@("`@("1T:&ES+3YB<F%N
M8VAE<R`](&%R<F%Y*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<')O8V5S<TQO
M9R@D<F%W*0H@("`@>PH@("`@("`@("\J($EN:71I86QI<V4@82!S:6UP;&4@
M<W1A=&4@;6%C:&EN92!T;R!P87)S92!T:&4@;W5T<'5T(&]F(')L;V<@*B\*
M("`@("`@("`D<W1A=&4@/2`G:6YI="<["B`@("`@("`@=VAI;&4@*"%E;7!T
M>2@D<F%W*2`F)B`D<W1A=&4@(3T@)V1O;F4G*2!["B`@("`@("`@("`@('-W
M:71C:"`H)'-T871E*2!["B`@("`@("`@("`@("\J($9O=6YD(&9I;&5N86UE
M+"!N;W<@;&]O:VEN9R!F;W(@=&AE(')E=FES:6]N(&YU;6)E<B`J+PH@("`@
M("`@("`@("!C87-E("=I;FET)SH*("`@("`@("`@("`@("`@("1L:6YE(#T@
M87)R87E?<VAI9G0H)')A=RD["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@B+W)E=FES:6]N("@N*RDD+R(L("1L:6YE+"`D<&%R=',I*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G)E=B`]("1P87)T<ULQ73L*("`@
M("`@("`@("`@("`@("`@("`D<W1A=&4@/2`G9&%T92<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\J
M($9O=6YD(')E=FES:6]N(&%N9"!F:6QE;F%M92P@;F]W(&QO;VMI;F<@9F]R
M(&1A=&4@*B\*("`@("`@("`@("`@8V%S92`G9&%T92<Z"B`@("`@("`@("`@
M("`@("`D;&EN92`](&%R<F%Y7W-H:69T*"1R87<I.PH@("`@("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H(GQ>9&%T93I<<RLH7&0K*5LM+UTH7&0K*5LM
M+UTH7&0K*5QS*RA<9"LI.BA<9"LI.BA<9"LI+BH_.UQS*V%U=&AO<CI<<RLH
M+BLI.UQS*W-T871E.EQS*RA<4RLI.RA<<RML:6YE<SI<<RLH6S`M.5QS*RU=
M*RDI/WPB+"`D;&EN92P@)'!A<G1S*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YD871E(#T@9VUM:W1I;64H)'!A<G1S6S1=+"`D<&%R='-;-5TL
M("1P87)T<ULV72P@)'!A<G1S6S)=+"`D<&%R='-;,UTL("1P87)T<ULQ72D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%U=&AO<B`]("1P87)T<ULW
M73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<W1A=&4@/2`D<&%R='-;
M.%T["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQI;F5S(#T@:7-S970H
M)'!A<G1S6S$P72D@/R`D<&%R='-;,3!=(#H@)R<["B`@("`@("`@("`@("`@
M("`@("`@)'-T871E(#T@)V)R86YC:&5S)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+RH@3&]O:R!F
M;W(@82!B<F%N8V@@<&]I;G0@:&5R92`M(&9O<FUA="!I<R`G8G)A;F-H97,Z
M("!X+GDN>CL@(&$N8BYC.R<@*B\*("`@("`@("`@("`@8V%S92`G8G)A;F-H
M97,G.@H@("`@("`@("`@("`@("`@+RH@268@=V4@9FEN9"!A(&)R86YC:"!T
M86<L('!R;V-E<W,@86YD('!O<"!I="P*("`@("`@("`@("`@("`@("`@(&]T
M:&5R=VES92!L96%V92!I;G!U="!S=')E86T@=6YT;W5C:&5D("HO"B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1R87<I("8F('!R96=?;6%T8V@H(B]>
M8G)A;F-H97,Z7',K*"XJ*2\B+"`D<F%W6S!=+"`D8G(I*2!["B`@("`@("`@
M("`@("`@("`@("`@+RH@1V5T('1H92!L:7-T(&]F(&)R86YC:&5S(&9R;VT@
M=&AE('-T<FEN9RP@86YD"B`@("`@("`@("`@("`@("`@("`@("H@<'5S:"!V
M86QI9"!R979I<VEO;G,@:6YT;R!T:&4@8G)A;F-H97,@87)R87D@*B\*("`@
M("`@("`@("`@("`@("`@("`D8G)S(#T@<')E9U]S<&QI="@G+SM<<RHO)RP@
M)&)R6S%=*3L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D8G)S(&%S
M("1B<G!O:6YT*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("A60U]2
M979I<VEO;CHZ=F%L:60H)&)R<&]I;G0I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^8G)A;F-H97-;72`]("1B<G!O:6YT.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1R87<I.PH*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1A=&4@/2`G9&]N92<[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@07-S=6UE('1H92!R97-T(&]F('1H92!L:6YE<R!A
M<F4@=&AE(&QO9R!M97-S86=E("HO"B`@("`@("`@)'1H:7,M/FQO9R`](&EM
M<&QO9&4H(EQN(BP@)')A=RD["B`@("`@("`@)'1H:7,M/G1A9W,@/2!`)'1H
M:7,M/F9I;&4M/G)E=G-Y;5LD=&AI<RT^<F5V73L*("`@("`@("!I9B`H96UP
M='DH)'1H:7,M/G1A9W,I*2!["B`@("`@("`@("`@("1T:&ES+3YT86=S(#T@
M87)R87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE$
M871E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F1A=&4["B`@("!]
M"@H@("`@9G5N8W1I;VX@<75E<GE2979I<VEO;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YR978["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE!
M=71H;W(H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^875T:&]R.PH@
M("`@?0H*("`@(&9U;F-T:6]N('%U97)Y3&]G*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/FQO9SL*("`@('T*"B`@("!F=6YC=&EO;B!Q=65R>4-H
M86YG961,:6YE<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES
M+3YL:6YE<RD@/R`H)'1H:7,M/FQI;F5S*2`Z("<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1VEV96X@82!B<F%N8V@@<F5V:7-I;VX@;G5M8F5R+"!T:&ES
M(&9U;F-T:6]N(')E;6%P<R!I=`H@("`@("H@86-C;W)D:6YG;'DL(&%N9"!P
M97)F;W)M<R!A(&QO;VMU<"!O;B!T:&4@9FEL92!O8FIE8W0@=&\*("`@("`J
M(')E='5R;B!T:&4@<WEM8F]L:6,@;F%M92AS*2!O9B!T:&%T(&)R86YC:"!I
M;B!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!(87-H
M(&]F('-Y;6)O;&EC(&YA;65S(#T^(&)R86YC:"!N=6UB97)S"B`@("`@*B\*
M("`@(&9U;F-T:6]N('%U97)Y4WEM8F]L:6-"<F%N8VAE<R@I"B`@("!["B`@
M("`@("`@)'-Y;4)R86YC:&5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^8G)A;F-H97,@87,@)&)R86YC:"D@>PH@("`@("`@("`@("`D
M<&%R=',@/2!E>'!L;V1E*"<N)RP@)&)R86YC:"D["B`@("`@("`@("`@("1L
M87-T(#T@87)R87E?<&]P*"1P87)T<RD["B`@("`@("`@("`@("1P87)T<UM=
M(#T@)S`G.PH@("`@("`@("`@("`D<&%R='-;72`]("1L87-T.PH@("`@("`@
M("`@("`D<F5V(#T@:6UP;&]D92@G+B<L("1P87)T<RD["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^9FEL92T^8G)A;F-H97-;)&)R86YC:%TI*2![
M"B`@("`@("`@("`@("`@("`D<WEM0G)A;F-H97-;)'1H:7,M/F9I;&4M/F)R
M86YC:&5S6R1B<F%N8VA=72`]("1B<F%N8V@["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1S>6U"<F%N8VAE<SL*("`@('T*"GT*
M"B\J*@H@*B!60U]C=G,@4&%T8VAS970@8VQA<W,N"B`J"B`J($-O<'ER:6=H
M="!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@
M0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7U!A=&-H<V5T7V-V<R!E>'1E
M;F1S(%9#7U!A=&-H<V5T('L*"B`@("!V87(@)%]D:7(["B`@("!V87(@)%]N
M86UE.PH*("`@("\J*@H@("`@("H@0W)E871E(&$@<&%T8VAS970@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@(%1H92!F:6QE
M;F%M92!T;R!G970@<&%T8VAS971S(&9O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@5D-?4&%T8VAS971?8W9S*"1F:6QE*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;F%M92`](&)A<V5N86UE*"1F:6QE*3L*("`@("`@("`D=&AI<RT^7V1I
M<B`](&1I<FYA;64H)&9I;&4I.PH@("`@?0H*("`@(&9U;F-T:6]N("9G9710
M871C:'-E=$]B:F5C="@D<F5P+"`D9FEL96YA;64L("1C86-H92`](&YU;&PI
M"B`@("!["B`@("`@("`@+RH@5&AE('9E<G-I;VX@;V8@=&AE(&-A8VAE9"!D
M871A+B!);F-R96UE;G0@=&AI<R!W:&5N979E<B!T:&4*("`@("`@("`@*B!I
M;G1E<FYA;"!S=&]R86=E(&9O<FUA="!C:&%N9V5S+"!S=6-H('1H870@=V4@
M;75S=`H@("`@("`@("`J(&EN=F%L:61A=&4@<')I;W(@8V%C:&5D(&1A=&$N
M("HO"B`@("`@("`@)&-A8VAE5F5R<VEO;B`](#$["B`@("`@("`@)&-A8VAE
M260@/2`D<F5P+3YS;W5R8V5R;V]T*"D@+B`G7VXG("X@)&9I;&5N86UE("X@
M)U]F7W8G("X@)&-A8VAE5F5R<VEO;CL*"B`@("`@("`@)&-T:6UE(#T@=&EM
M92@I("T@0&9I;&5M=&EM92@D9FEL96YA;64@+B`G+'8G*3L*("`@("`@("!I
M9B`H)&-A8VAE("8F"B`@("`@("`@("`@("1C86-H92T^97AI<W1S*"1C86-H
M94ED+"`D8W1I;64I*2!["B`@("`@("`@("`@("1P<T]B(#T@=6YS97)I86QI
M>F4H)&-A8VAE+3YG970H)&-A8VAE260L("1C=&EM92DI.PH@("`@("`@("`@
M("`D<'-/8BT^<V5T4F5P;W-I=&]R>2@D<F5P*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<'-/8B`](&YE=R!60U]0871C:'-E=%]C=G,H)&9I
M;&5N86UE*3L*("`@("`@("`@("`@)'!S3V(M/G-E=%)E<&]S:71O<GDH)')E
M<"D["B`@("`@("`@("`@(&EF("AI<U]A*"@D<F5S=6QT(#T@)'!S3V(M/F=E
M=%!A=&-H<V5T<R@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@D8V%C:&4I('L*("`@("`@("`@("`@("`@("1C86-H92T^<V5T*"1C
M86-H94ED+"!S97)I86QI>F4H)'!S3V(I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1P<T]B.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4&]P=6QA=&4@=&AE(&]B:F5C="!W:71H(&EN9F]R;6%T:6]N(&%B
M;W5T('1H92!P871C:'-E=',@=&AA=`H@("`@("H@=&AI<R!F:6QE(&ES(&EN
M=F]L=F5D(&EN+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQO8FIE
M8W0@(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+"!O<B!T<G5E(&]N('-U
M8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A=&-H<V5T<R@I"B`@
M("!["B`@("`@("`@+RH@0VAE8VL@=&AA="!W92!A<F4@86-T=6%L;'D@:6X@
M=&AE(&9I;&5S>7-T96TN("HO"B`@("`@("`@:68@*"%I<U]F:6QE*"1T:&ES
M+3YG971&=6QL4&%T:"@I("X@)RQV)RDI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H)T9I;&4@3F]T($9O=6YD)RD["B`@("`@("`@
M?0H*("`@("`@("`O*B!#86QL(&-V<W!S('1O(')E=')I979E(&%L;"!P871C
M:'-E=',@9F]R('1H:7,@9FEL92X@*B\*("`@("`@("`D<5]R;V]T(#T@)'1H
M:7,M/E]R97`M/G-O=7)C97)O;W0H*3L*("`@("`@("`D<5]R;V]T(#T@5D-?
M5TE.1$]74R`_("<B)R`N(&5S8V%P97-H96QL8VUD*"1Q7W)O;W0I("X@)R(G
M(#H@97-C87!E<VAE;&QA<F<H)'%?<F]O="D["@H@("`@("`@("1C=G-P<U]H
M;VUE(#T@)'1H:7,M/E]R97`M/F=E=%!A=&@H)V-V<W!S7VAO;64G*3L*("`@
M("`@("`D2$]-12`]("%E;7!T>2@D8W9S<'-?:&]M92D@/PH@("`@("`@("`@
M("`G2$]-13TG("X@)&-V<W!S7VAO;64@+B`G("<@.@H@("`@("`@("`@("`G
M)SL*"B`@("`@("`@)&-M9"`]("1(3TU%("X@)'1H:7,M/E]R97`M/F=E=%!A
M=&@H)V-V<W!S)RD@+B`G("UU("TM8W9S+61I<F5C="`M+7)O;W0@)R`N("1Q
M7W)O;W0@+B`G("UF("<@+B!E<V-A<&5S:&5L;&%R9R@D=&AI<RT^7VYA;64I
M("X@)R`G("X@97-C87!E<VAE;&QA<F<H)'1H:7,M/E]D:7(I.PH@("`@("`@
M(&5X96,H)&-M9"P@)')E='5R;E]A<G)A>2P@)')E='9A;"D["B`@("`@("`@
M:68@*"1R971V86PI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T9A:6QE9"!T;R!S<&%W;B!C=G-P<R!T;R!R971R:65V92!P871C
M:'-E="!I;F9O<FUA=&EO;B<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]P871C:'-E=',@/2!A<G)A>2@I.PH@("`@("`@("1S=&%T92`]("=B96=I
M;B<["B`@("`@("`@9F]R96%C:"`H)')E='5R;E]A<G)A>2!A<R`D;&EN92D@
M>PH@("`@("`@("`@("`D;&EN92`]('1R:6TH)&QI;F4I.PH@("`@("`@("`@
M("!I9B`H)&QI;F4@/3T@)RTM+2TM+2TM+2TM+2TM+2TM+2TM+2<I('L*("`@
M("`@("`@("`@("`@("1S=&%T92`]("=B96=I;B<["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<W=I=&-H
M("@D<W1A=&4I('L*("`@("`@("`@("`@8V%S92`G8F5G:6XG.@H@("`@("`@
M("`@("`@("`@)&ED(#T@<W1R7W)E<&QA8V4H)U!A=&-H4V5T("<L("<G+"`D
M;&EN92D["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD:61=
M(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1S=&%T92`]("=I;F9O)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:6YF
M;R<Z"B`@("`@("`@("`@("`@("`D:6YF;R`](&5X<&QO9&4H)SHG+"`D;&EN
M92P@,BD["B`@("`@("`@("`@("`@("!S=VET8V@@*"1I;F9O6S!=*2!["B`@
M("`@("`@("`@("`@("!C87-E("=$871E)SH*("`@("`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G?"A<9'LT?2DO*%QD>S)]*2\H7&1[,GTI("A<
M9'LR?2DZ*%QD>S)]*3HH7&1[,GTI?"<L("1I;F9O6S%=+"`D9&%T92DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED
M75LG9&%T92==(#T@9VUM:W1I;64H)&1A=&5;-%TL("1D871E6S5=+"`D9&%T
M95LV72P@)&1A=&5;,ETL("1D871E6S-=+"`D9&%T95LQ72D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@)T%U=&AO<B<Z"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG875T:&]R)UT@/2!T<FEM*"1I
M;F9O6S%=*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("="<F%N8V@G.@H@("`@("`@("`@("`@("`@("`@(&EF
M("AT<FEM*"1I;F9O6S%=*2`A/2`G2$5!1"<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)&ED75LG8G)A;F-H)UT@/2!T
M<FEM*"1I;F9O6S%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G5&%G
M)SH*("`@("`@("`@("`@("`@("`@("!I9B`H=')I;2@D:6YF;ULQ72D@(3T@
M)RAN;VYE*2<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M871C:'-E='-;)&ED75LG=&%G)UT@/2!T<FEM*"1I;F9O6S%=*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G3&]G)SH*("`@("`@("`@("`@("`@("`@
M("`D<W1A=&4@/2`G;&]G)SL*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A=&-H<V5T<ULD:61=6R=L;V<G72`]("<G.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=L;V<G.@H@("`@("`@("`@("`@
M("`@:68@*"1L:6YE(#T]("=-96UB97)S.B<I('L*("`@("`@("`@("`@("`@
M("`@("`D<W1A=&4@/2`G;65M8F5R<R<["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P871C:'-E='-;)&ED75LG;&]G)UT@/2!T<FEM*"1T:&ES+3Y?
M<&%T8VAS971S6R1I9%U;)VQO9R==*3L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=M96UB97)S)UT@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A=&-H<V5T<ULD:61=6R=L;V<G72`N/2`D;&EN92`N(")<;B([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@)VUE;6)E<G,G.@H@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D;&EN92DI('L*("`@("`@("`@("`@("`@("`@("`D<&%R=',@
M/2!E>'!L;V1E*"<Z)RP@)&QI;F4I.PH@("`@("`@("`@("`@("`@("`@("1R
M979S(#T@97AP;&]D92@G+3XG+"`D<&%R='-;,5TI.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1I9%U;)VUE;6)E<G,G75M=(#T@
M87)R87DH)V9I;&4G(#T^("1P87)T<ULP72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=F<F]M)R`]/B`D<F5V<ULP72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T;R<@
M/3X@)')E=G-;,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!F
M=6QL>2!Q=6%L:69I960@9FEL96YA;64@;V8@=&AI<R!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@($9U;&QY('%U86QI9FEE9"!F:6QE
M;F%M92!O9B!T:&ES(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO;B!G971&
M=6QL4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&ER("X@
M)R\G("X@)'1H:7,M/E]N86UE.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5D,O
M<W9N+G!H<```````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-C`U,S<@,3`U,34T,S0Q-#`@,#(Q,C`Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!60U]S=FX@
M:6UP;&5M96YT871I;VXN"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@06YI
M;"!-861H879A<&5D9'DL(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+U9#+U9#+W-V;BYP:'`L=B`Q+C(X+C0N,3@@,C`P-B\P
M-2\Q,B`P-#HT-SHP."!C:'5C:R!%>'`@)`H@*@H@*B!`875T:&]R("!!;FEL
M($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(
M;W)D92`S+C`*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7W-V;B!E>'1E
M;F1S(%9#('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R('1H
M92!C;&%S<R!E>'!E8W1S+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M($-U<G)E;G0@<&%R86UE=&5R<SH*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`G<V]U<F-E<F]O="<Z(%1H92!S;W5R8V4@<F]O="!F;W(@=&AI<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5P
M;W-I=&]R>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("=P871H<R<Z
M($AA<V@@=VET:"!T:&4@;&]C871I;VYS(&]F(&%L;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YE8V5S<V%R>2!B:6YA<FEE<SH@
M)W-V;B<L("=D:69F)PH@("`@("HO"B`@("!F=6YC=&EO;B!60U]S=FXH)'!A
M<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^7W-O=7)C97)O;W0@/2`D<&%R
M86US6R=S;W5R8V5R;V]T)UT["B`@("`@("`@)'1H:7,M/E]P871H<R`]("1P
M87)A;7-;)W!A=&AS)UT["B`@("!]"@H@("`@9G5N8W1I;VX@:7-&:6QE*"1W
M:&5R92D*("`@('L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("!F
M=6YC=&EO;B`F<75E<GE$:7(H)'=H97)E*0H@("`@>PH@("`@("`@("1D:7(@
M/2!N97<@5D-?1&ER96-T;W)Y7W-V;B@D=&AI<RP@)'=H97)E*3L*("`@("`@
M("!R971U<FX@)&1I<CL*("`@('T*"B`@("!F=6YC=&EO;B!G971#:&5C:V]U
M="@D9FEL92P@)')E=BD*("`@('L*("`@("`@("!R971U<FX@5D-?0VAE8VMO
M=71?<W9N.CIG970H)'1H:7,L("1F:6QE+3YQ=65R>49U;&Q0871H*"DL("1R
M978I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$1I9F8H)&9I;&4L("1R978Q
M+"`D<F5V,BP@)'1Y<&4@/2`G8V]N=&5X="<L("1N=6T@/2`S+"`D=W,@/2!T
M<G5E*0H@("`@>PH@("`@("`@(')E='5R;B!60U]$:69F7W-V;CHZ9V5T*"1T
M:&ES+"`D9FEL92P@)')E=C$L("1R978R+"`D='EP92P@)&YU;2P@)'=S*3L*
M("`@('T*"B`@("!F=6YC=&EO;B`F9V5T1FEL94]B:F5C="@D9FEL96YA;64L
M("1C86-H92`](&YU;&PL("1Q=6EC:VQO9R`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1F;R`]("960U]&:6QE7W-V;CHZ9V5T1FEL94]B:F5C="@D=&AI<RP@
M)&9I;&5N86UE+"`D8V%C:&4L("1Q=6EC:VQO9RD["B`@("`@("`@<F5T=7)N
M("1F;SL*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T06YN;W1A=&5/8FIE8W0H
M)&9I;&5N86UE*0H@("`@>PH@("`@("`@("1B;&%M92`](&YE=R!60U]!;FYO
M=&%T95]S=FXH)'1H:7,L("1F:6QE;F%M92D["B`@("`@("`@<F5T=7)N("1B
M;&%M93L*("`@('T*"B`@("!F=6YC=&EO;B`F9V5T4&%T8VAS971/8FIE8W0H
M)&9I;&5N86UE+"`D8V%C:&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1P;R`]
M("960U]0871C:'-E=%]S=FXZ.F=E=%!A=&-H<V5T3V)J96-T*"1T:&ES+"`D
M9FEL96YA;64L("1C86-H92D["B`@("`@("`@<F5T=7)N("1P;SL*("`@('T*
M"GT*"B\J*@H@*B!60U]S=FX@86YN;W1A=&4@8VQA<W,N"B`J"B`J($%N:6P@
M36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R
M("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C
M:V%G92!60PH@*B\*8VQA<W,@5D-?06YN;W1A=&5?<W9N('L*"B`@("!V87(@
M)&9I;&4["B`@("!V87(@)%-63CL*("`@('9A<B`D=&UP9FEL93L*"B`@("!F
M=6YC=&EO;B!60U]!;FYO=&%T95]S=FXH)')E<"P@)&9I;&4I"B`@("!["B`@
M("`@("`@)'1H:7,M/E-63B`]("1R97`["B`@("`@("`@)'1H:7,M/F9I;&4@
M/2`D9FEL93L*("`@('T*"B`@("!F=6YC=&EO;B!D;T%N;F]T871E*"1R978I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('1H870@=&AE(&9I;&4@=F%L
M=65S(&9O<B!T:&ES(&]B:F5C="!I<R!V86QI9"X@*B\*("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^9FEL92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(59#7U)E
M=FES:6]N.CIV86QI9"@D<F5V*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D42`](%9#7U=)3D1/5U,@/R`G(B<@
M.B`B)R(["B`@("`@("`@)&-O;6UA;F0@/2`D=&AI<RT^4U9.+3YG9710871H
M*"=S=FXG*2`N("<@86YN;W1A=&4@+7(@,3HG("X@)')E=B`N("<@)R`N("11
M("X@<W1R7W)E<&QA8V4H)%$L("=<7"<@+B`D42P@)'1H:7,M/F9I;&4M/G%U
M97)Y1G5L;%!A=&@H*2D@+B`D42`N("<@,CXF,2<["B`@("`@("`@)'!I<&4@
M/2!P;W!E;B@D8V]M;6%N9"P@)W(G*3L*("`@("`@("!I9B`H(21P:7!E*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@
M=&\@97AE8W5T92!S=FX@86YN;W1A=&4Z("<@+B`D8V]M;6%N9"D["B`@("`@
M("`@?0H*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@("1L:6YE
M;F\@/2`Q.PH@("`@("`@('=H:6QE("@A9F5O9B@D<&EP92DI('L*("`@("`@
M("`@("`@)&QI;F4@/2!F9V5T<R@D<&EP92P@-#`Y-BD["B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7EQS*RA<9"LI7',K*%M<=UPN72LI7',H+BHI
M)"\G+"`D;&EN92P@)')E9W,I*2!["B`@("`@("`@("`@("`@("`D96YT<GD@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=R978G72`@("`]
M("1R96=S6S%=.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=A=71H;W(G72`]
M('1R:6TH)')E9W-;,ETI.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=D871E
M)UT@("`]("<G.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=L:6YE)UT@("`]
M("1R96=S6S-=.PH@("`@("`@("`@("`@("`@)&5N=')Y6R=L:6YE;F\G72`]
M("1L:6YE;F\K*SL*("`@("`@("`@("`@("`@("1L:6YE<UM=(#T@)&5N=')Y
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!P8VQO<V4H)'!I
M<&4I.PH@("`@("`@(')E='5R;B`D;&EN97,["B`@("!]"@I]"@HO*BH*("H@
M5D-?<W9N(&-H96-K;W5T(&-L87-S+@H@*@H@*B!!;FEL($UA9&AA=F%P961D
M>2P@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H
M879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO
M"F-L87-S(%9#7T-H96-K;W5T7W-V;B!["@H@("`@+RHJ"B`@("`@*B!3=&%T
M:6,@9G5N8W1I;VX@=VAI8V@@<F5T=7)N<R!A(&9I;&4@<&]I;G1I;F<@=&\@
M=&AE(&AE860@;V8@=&AE(')E<75E<W1E9`H@("`@("H@<F5V:7-I;VX@;V8@
M86X@4D-3(&9I;&4N"B`@("`@*B!`<&%R86T@9G5L;&YA;64@1G5L;'D@<75A
M;&EF:65D('!A=&AN86UE(&]F('1H92!D97-I<F5D(%)#4R!F:6QE('1O(&-H
M96-K;W5T"B`@("`@*B!`<&%R86T@<F5V(%)#4R!R979I<VEO;B!N=6UB97(@
M=&\@8VAE8VL@;W5T"B`@("`@*B!`<F5T=7)N($5I=&AE<B!A(%!%05)?17)R
M;W(@;V)J96-T+"!O<B!A('-T<F5A;2!P;VEN=&5R('1O('1H92!H96%D(&]F
M('1H92!C:&5C:V]U=`H@("`@("HO"B`@("!F=6YC=&EO;B!G970H)')E<"P@
M)&9U;&QN86UE+"`D<F5V*0H@("`@>PH@("`@("`@(&EF("@A5D-?4F5V:7-I
M;VXZ.G9A;&ED*"1R978I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=);G9A;&ED(')E=FES:6]N(&YU;6)E<B<I.PH@("`@("`@
M('T*"B`@("`@("`@:68@*%9#7U=)3D1/5U,I('L*("`@("`@("`@("`@)%$@
M/2`G(B<["B`@("`@("`@("`@("1M;V1E(#T@)W)B)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D42`]("(G(CL*("`@("`@("`@("`@)&UO9&4@
M/2`G<B<["B`@("`@("`@?0H*("`@("`@("!I9B`H(2@D4D-3(#T@<&]P96XH
M)')E<"T^9V5T4&%T:"@G<W9N)RD@+B`G(&-A="`M<B`G("X@)')E=B`N("<@
M)R`N("11("X@<W1R7W)E<&QA8V4H)%$L("=<7"<@+B`D42P@)&9U;&QN86UE
M*2`N("11("X@)R`R/B8Q)RP@)&UO9&4I*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&1N7"=T('!E<F9O<FT@8VAE8VMO
M=70@;V8@=&AE(')E<75E<W1E9"!F:6QE)RD["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)%)#4SL*("`@('T*"GT*"B\J*@H@*B!60U]S=FX@9&EF9B!C
M;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI
M;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D
M>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@
M5D-?1&EF9E]S=FX@>PH*("`@("\J*@H@("`@("H@3V)T86EN('1H92!D:69F
M97)E;F-E<R!B971W965N('1W;R!R979I<VEO;G,@;V8@82!F:6QE+@H@("`@
M("H*("`@("`J($!P87)A;2!60U]S=FX@)')E<"`@("`@("`@02!R97!O<VET
M;W)Y(&]B:F5C="X*("`@("`J($!P87)A;2!60U]&:6QE7W-V;B`D9FEL92`@
M5&AE(&1E<VER960@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)')E=C$@
M("`@("`@3W)I9VEN86P@<F5V:7-I;VX@;G5M8F5R('1O(&-O;7!A<F4@9G)O
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)')E=C(@("`@("`@3F5W(')E=FES
M:6]N(&YU;6)E<B!T;R!C;VUP87)E(&%G86EN<W0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T>7!E("`@("`@(%1H92!T>7!E(&]F(&1I9F8@*&4N9RX@)W5N
M:69I960G*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1N=6T@("`@("`@3G5M
M8F5R(&]F(&QI;F5S('1O(&)E('5S960@:6X@8V]N=&5X="!A;F0*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YI9FEE9"!D:69F<RX*("`@
M("`J($!P87)A;2!B;V]L96%N("1W<R`@("`@("`@4VAO=R!W:&ET97-P86-E
M(&EN('1H92!D:69F/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG?&)O
M;VQE86X@($9A;'-E(&]N(&9A:6QU<F4L(&]R(&$@<W1R:6YG(&-O;G1A:6YI
M;F<@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!D:69F(&]N
M('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E="@D<F5P+"`D9FEL
M92P@)')E=C$L("1R978R+"`D='EP92`]("=C;VYT97AT)RP@)&YU;2`](#,L
M"B`@("`@("`@("`@("`@("`@)'=S(#T@=')U92D*("`@('L*("`@("`@("`O
M*B!-86ME('-U<F4@=&AA="!T:&4@9FEL92!P87)A;65T97(@:7,@=F%L:60@
M*B\*("`@("`@("!I9B`H:7-?82@D9FEL92P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!#:&5C:R!T:&%T('1H92!R979I<VEO;B!N=6UB97)S(&%R92!V86QI9"`J
M+PH@("`@("`@("1R978Q(#T@5D-?4F5V:7-I;VXZ.G9A;&ED*"1R978Q*2`_
M("1R978Q(#H@,#L*("`@("`@("`D<F5V,B`](%9#7U)E=FES:6]N.CIV86QI
M9"@D<F5V,2D@/R`D<F5V,B`Z(#`["@H@("`@("`@("1F=6QL3F%M92`]("1F
M:6QE+3YQ=65R>49U;&Q0871H*"D["B`@("`@("`@)&1I9F8@/2!A<G)A>2@I
M.PH@("`@("`@("1O<'1I;VYS(#T@)R<["B`@("`@("`@:68@*"$D=W,I('L*
M("`@("`@("`@("`@)&]P=&EO;G,@+CT@)R`M8D(@)SL*("`@("`@("!]"@H@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("!C87-E("=C;VYT97AT
M)SH*("`@("`@("`@("`@)&]P=&EO;G,@+CT@)RTM8V]N=&5X=#TG("X@*&EN
M="DD;G5M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G=6YI
M9FEE9"<Z"B`@("`@("`@("`@("1O<'1I;VYS("X]("<M+75N:69I960])R`N
M("AI;G0I)&YU;3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)V-O;'5M;B<Z"B`@("`@("`@("`@("1O<'1I;VYS("X]("<M+7-I9&4M8GDM
M<VED92`M+7=I9'1H/3$R,"<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=E9"<Z"B`@("`@("`@("`@("1O<'1I;VYS("X]("<M92<["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@5$]$3SH@
M861D(&]P=&EO;G,@9F]R("1H<B!O<'1I;VYS("T@:&]W979E<B!T:&5S92!M
M87D@;F]T"B`@("`@("`@+R\@8F4@8V]M<&%T:6)L92!W:71H('-O;64@9&EF
M9G,N"B`@("`@("`@)%$@/2!60U]724Y$3U=3(#\@)R(G(#H@(B<B.PH@("`@
M("`@("1C;VUM86YD(#T@)')E<"T^9V5T4&%T:"@G<W9N)RD@+B`B(&1I9F8@
M+2UD:69F+6-M9"`B("X@)')E<"T^9V5T4&%T:"@G9&EF9B<I("X@(B`M<B`D
M<F5V,3HD<F5V,B`M>"`B("X@)%$@+B`D;W!T:6]N<R`N("11("X@)R`G("X@
M)&9I;&4M/G%U97)Y1G5L;%!A=&@H*2`N("<@,CXF,2<["@H@("`@("`@(&5X
M96,H)&-O;6UA;F0L("1D:69F+"`D<F5T=F%L*3L*("`@("`@("!R971U<FX@
M)&1I9F8["B`@("!]"@I]"@HO*BH*("H@5D-?<W9N(&1I<F5C=&]R>2!C;&%S
M<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R
M96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\
M86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?
M1&ER96-T;W)Y7W-V;B!["@H@("`@=F%R("1R97`["B`@("!V87(@)&1I<DYA
M;64["B`@("!V87(@)&9I;&5S.PH@("`@=F%R("1A='1I8T9I;&5S.PH@("`@
M=F%R("1M97)G961&:6QE<SL*("`@('9A<B`D9&ER<SL*("`@('9A<B`D<&%R
M96YT.PH@("`@=F%R("1M;V1U;&5.86UE.PH*("`@("\J*@H@("`@("H@0W)E
M871E(&$@4U9.($1I<F5C=&]R>2!O8FIE8W0@=&\@<W1O<F4@:6YF;W)M871I
M;VX@86)O=70@=&AE"B`@("`@*B!F:6QE<R!I;B!A('-I;F=L92!D:7)E8W1O
M<GD@:6X@=&AE(')E<&]S:71O<GD*("`@("`J"B`@("`@*B!`<&%R86T@5D-?
M4F5P;W-I=&]R>5]S=FX@)')P("!4:&4@5D-?4F5P;W-I=&]R>2!O8FIE8W0@
M=&AI<R!D:7)E8W1O<GD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&ES('!A<G0@;V8N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@
M("`@("`@("`@("!0871H('1O('1H92!D:7)E8W1O<GDN"B`@("`@*B!`<&%R
M86T@5D-?1&ER96-T;W)Y7W-V;B`D<&X@("!4:&4@<&%R96YT(%9#7T1I<F5C
M=&]R>2!T;R!T:&ES(&]N92X*("`@("`J+PH@("`@9G5N8W1I;VX@5D-?1&ER
M96-T;W)Y7W-V;B@D<F5P+"`D9&XL("1P;B`]("<G*0H@("`@>PH@("`@("`@
M("1T:&ES+3YR97`@/2`D<F5P.PH@("`@("`@("1T:&ES+3YP87)E;G0@/2`D
M<&X["B`@("`@("`@)'1H:7,M/FUO9'5L94YA;64@/2`D9&X["B`@("`@("`@
M)'1H:7,M/F1I<DYA;64@/2`B+R1D;B(["B`@("`@("`@)'1H:7,M/F9I;&5S
M(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^9&ER<R`](&%R<F%Y*"D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@9G5L;'D@<75A;&EF:65D('!A
M=&AN86UE('1O('1H:7,@9&ER96-T;W)Y('=I=&@@;F\*("`@("`J('1R86EL
M:6YG("\N"B`@("`@*@H@("`@("H@0')E='5R;B!0871H;F%M92!O9B!T:&ES
M(&1I<F5C=&]R>0H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>41I<B@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD:7).86UE.PH@("`@?0H*("`@
M(&9U;F-T:6]N("9Q=65R>41I<DQI<W0H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^9&ER<SL*("`@('T*"B`@("!F=6YC=&EO;B`F<75E<GE&:6QE
M3&ES="@D<VAO=V%T=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"1S
M:&]W871T:6,@)B8@:7-S970H)'1H:7,M/FUE<F=E9$9I;&5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FUE<F=E9$9I;&5S.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FEL97,["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&5L;"!T:&4@;V)J96-T('1O
M(&]P96X@86YD(&)R;W=S92!I=',@8W5R<F5N="!D:7)E8W1O<GDL(&%N9`H@
M("`@("H@<F5T<FEE=F4@82!L:7-T(&]F(&%L;"!T:&4@;V)J96-T<R!I;B!T
M:&5R92X@($ET('1H96X@<&]P=6QA=&5S"B`@("`@*B!T:&4@9FEL92]D:7)E
M8W1O<GD@<W1A8VL@86YD(&UA:V5S(&ET(&%V86EL86)L92!F;W(@<F5T<FEE
M=F%L+@H@("`@("H*("`@("`J($!R971U<FX@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@86X@97)R;W(L(#$@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@8G)O=W-E1&ER*"1C86-H92`](&YU;&PL("1Q=6EC:VQO9R`]('1R=64L
M("1S:&]W871T:6,@/2!F86QS92D*("`@('L*("`@("`@("`D42`](%9#7U=)
M3D1/5U,@/R`G(B<@.B`B)R(@.PH@("`@("`@("1C;60@/2`D=&AI<RT^<F5P
M+3YG9710871H*"=S=FXG*2`N("<@;',@)R`N("11("X@<W1R7W)E<&QA8V4H
M)%$L("=<7"<@+B`D42P@)'1H:7,M/G)E<"T^<V]U<F-E<F]O="@I("X@)'1H
M:7,M/G%U97)Y1&ER*"DI("X@)%$@+B`G(#(^)C$G.PH@("`@("`@("1D:7(@
M/2!P;W!E;B@D8VUD+"`G<B<I.PH@("`@("`@(&EF("@A)&1I<BD@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&5X
M96-U=&4@<W9N(&QS.B`G("X@)&-M9"D["B`@("`@("`@?0H*("`@("`@("`O
M*B!#<F5A=&4@='=O(&%R<F%Y<R`M(&]N92!O9B!A;&P@=&AE(&9I;&5S+"!A
M;F0@=&AE(&]T:&5R(&]F"B`@("`@("`@("H@86QL('1H92!D:7)S+B`J+PH@
M("`@("`@("1E<G)O<G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE("@A9F5O
M9B@D9&ER*2D@>PH@("`@("`@("`@("`D;&EN92`](&-H;W`H9F=E=',H)&1I
M<BP@,3`R-"DI.PH@("`@("`@("`@("!I9B`H(7-T<FQE;B@D;&EN92DI('L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H<W5B<W1R*"1L:6YE+"`P+"`T*2`]/2`G<W9N.B<I('L*
M("`@("`@("`@("`@("`@("1E<G)O<G-;72`]("1L:6YE.PH@("`@("`@("`@
M("!](&5L<V5I9B`H<W5B<W1R*"1L:6YE+"`M,2D@/3T@)R\G*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^9&ER<UM=(#T@<W5B<W1R*"1L:6YE+"`P+"`M
M,2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9FP@
M/2`D=&AI<RT^<F5P+3YG971&:6QE3V)J96-T*"1T:&ES+3YQ=65R>41I<B@I
M("X@(B\D;&EN92(L("1C86-H92P@)'%U:6-K;&]G*3L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A*"1F;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D9FP["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YF:6QE<UM=(#T@)&9L.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!P8VQO<V4H)&1I<BD["@H@("`@("`@(&EF("@D97)R;W)S*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*&EM<&QO9&4H(EQN
M(BP@)&5R<F]R<RDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T('1H92!C;VYT96YT<R!O9B!T
M:&4@9&ER96-T;W)Y(&EN(&$@9VEV96X@9F%S:&EO;B!A;F0*("`@("`J(&]R
M9&5R+@H@("`@("H*("`@("`J($!P87)A;2`D:&]W($]F('1H92!F;W)M(%9#
M7U-/4E1?*B!W:&5R92`J(&-A;B!B93H*("`@("`J("`@("`@("`@("`@($Y/
M3D4L($Y!344L($%'12P@4D56(&9O<B!S;W)T:6YG(&)Y(&YA;64L(&%G92!O
M<B!R979I<VEO;BX*("`@("`J($!P87)A;2`D9&ER($]F('1H92!F;W)M(%9#
M7U-/4E1?*B!W:&5R92`J(&-A;B!B93H*("`@("`J("`@("`@("`@("`@($%3
M0T5.1$E.1RP@1$530T5.1$E.1R!F;W(@=&AE(&]R9&5R(&]F('1H92!S;W)T
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<'!L>5-O<G0H)&AO=R`](%9#7U-/
M4E1?3D].12P@)&1I<B`](%9#7U-/4E1?05-#14Y$24Y'*0H@("`@>PH@("`@
M("`@("\J(%1/1$\Z('1H:7,@8V]D92!L;V]K<R!V97)Y(&EN969F:6-I96YT
M(2!O<'1I;6ES92XN+B`M"B`@("`@("`@("H@879S;2X@*B\*"B`@("`@("`@
M+R\@07-S=6UE(&)Y(&YA;64@9F]R('1H92!M;VUE;G0N"B`@("`@("`@;F%T
M8V%S97-O<G0H)'1H:7,M/F1I<G,I.PH@("`@("`@("1T:&ES+3YD;T9I;&53
M;W)T*"1T:&ES+3YF:6QE<RP@)&AO=RP@)&1I<BD["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YA='1I8T9I;&5S*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M9&]&:6QE4V]R="@D=&AI<RT^871T:6-&:6QE<RP@)&AO=RP@)&1I<BD["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65R9V5D1FEL97,I
M*2!["B`@("`@("`@("`@("1T:&ES+3YD;T9I;&53;W)T*"1T:&ES+3YM97)G
M961&:6QE<RP@)&AO=RP@)&1I<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D
M9&ER(#T](%9#7U-/4E1?1$530T5.1$E.1RD@>PH@("`@("`@("`@("`D=&AI
M<RT^9&ER<R`](&%R<F%Y7W)E=F5R<V4H)'1H:7,M/F1I<G,I.PH@("`@("`@
M("`@("`D=&AI<RT^9FEL97,@/2!A<G)A>5]R979E<G-E*"1T:&ES+3YF:6QE
M<RD["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65R9V5D1FEL97,I
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^;65R9V5D1FEL97,@/2!A<G)A
M>5]R979E<G-E*"1T:&ES+3YM97)G961&:6QE<RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9&]&:6QE4V]R="@F)&9I
M;&5,:7-T+"`D:&]W(#T@5D-?4T]25%].3TY%+"`D9&ER(#T@5D-?4T]25%]!
M4T-%3D1)3D<I"B`@("!["B`@("`@("`@<W=I=&-H("@D:&]W*2!["B`@("`@
M("`@8V%S92!60U]33U)47T%'13H*("`@("`@("`@("`@=7-O<G0H)&9I;&5,
M:7-T+"!A<G)A>2@D=&AI<RP@)V9I;&5!9V53;W)T)RDI.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92!60U]33U)47TY!344Z"B`@("`@("`@
M("`@('5S;W)T*"1F:6QE3&ES="P@87)R87DH)'1H:7,L("=F:6QE3F%M95-O
M<G0G*2D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#7U-/
M4E1?05542$]2.@H@("`@("`@("`@("!U<V]R="@D9FEL94QI<W0L(&%R<F%Y
M*"1T:&ES+"`G9FEL94%U=&AO<E-O<G0G*2D["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E(%9#7U-/4E1?4D56.@H@("`@("`@("`@("!U<V]R
M="@D9FEL94QI<W0L(&%R<F%Y*"1T:&ES+"`G9FEL95)E=E-O<G0G*2D["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%9#7U-/4E1?3D].13H*
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T:6]N(&9O<B!A<V-E
M;F1I;F<@86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6QE06=E4V]R="@D
M82P@)&(I"B`@("!["B`@("`@("`@)&%A(#T@)&$M/G%U97)Y3&%S=$QO9R@I
M.PH@("`@("`@("1B8B`]("1B+3YQ=65R>4QA<W1,;V<H*3L*("`@("`@("!I
M9B`H)&%A+3YQ=65R>41A=&4H*2`]/2`D8F(M/G%U97)Y1&%T92@I*2!["B`@
M("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`H)&%A+3YQ=65R>41A=&4H*2`\("1B8BT^<75E<GE$871E
M*"DI(#\@,2`Z("TQ.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-O<G0@9G5N8W1I;VX@8GD@875T:&]R(&YA;64N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&9I;&5!=71H;W)3;W)T*"1A+"`D8BD*("`@('L*("`@("`@("`D
M86$@/2`D82T^<75E<GE,87-T3&]G*"D["B`@("`@("`@)&)B(#T@)&(M/G%U
M97)Y3&%S=$QO9R@I.PH@("`@("`@(&EF("@D86$M/G%U97)Y075T:&]R*"D@
M/3T@)&)B+3YQ=65R>4%U=&AO<B@I*2!["B`@("`@("`@("`@(')E='5R;B`P
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`H)&%A+3YQ
M=65R>4%U=&AO<B@I(#X@)&)B+3YQ=65R>4%U=&AO<B@I*2`_(#$@.B`M,3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&9U;F-T:6]N
M(&9O<B!A<V-E;F1I;F<@9FEL96YA;64N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&9I;&5.86UE4V]R="@D82P@)&(I"B`@("!["B`@("`@("`@<F5T=7)N('-T
M<F-A<V5C;7`H)&$M/FYA;64L("1B+3YN86UE*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-O<G0@9G5N8W1I;VX@9F]R(&%S8V5N9&EN9R!R979I<VEO;BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@9FEL95)E=E-O<G0H)&$L("1B*0H@("`@
M>PH@("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ8VUP*"1A+3YQ=65R>4AE
M860H*2P@)&(M/G%U97)Y2&5A9"@I*3L*("`@('T*"GT*"B\J*@H@*B!60U]S
M=FX@9FEL92!C;&%S<RX*("H*("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E
M9&1Y+"`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@
M*B\*8VQA<W,@5D-?1FEL95]S=FX@97AT96YD<R!60U]&:6QE('L*"B`@("`O
M*BH*("`@("`J($-R96%T92!A(')E<&]S:71O<GD@9FEL92!O8FIE8W0L(&%N
M9"!G:79E(&ET(&EN9F]R;6%T:6]N(&%B;W5T"B`@("`@*B!W:&%T(&ET<R!P
M87)E;G0@9&ER96-T;W)Y(&%N9"!R97!O<VET;W)Y(&]B:F5C=',@87)E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9L("!&=6QL('!A=&@@=&\@
M=&AI<R!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!60U]&:6QE7W-V;B@D
M<F5P+"`D9FPL("1Q=6EC:VQO9R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3YR97`@/2`D<F5P.PH@("`@("`@("1T:&ES+3YN86UE(#T@8F%S96YA
M;64H)&9L*3L*("`@("`@("`D=&AI<RT^9&ER(#T@9&ER;F%M92@D9FPI.PH@
M("`@("`@("1T:&ES+3YL;V=S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^
M<75I8VML;V<@/2`D<75I8VML;V<["B`@("`@("`@)'1H:7,M/G)E=G,@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3YR979S>6T@/2!A<G)A>2@I.PH@("`@
M("`@("1T:&ES+3YS>6UR978@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3YB
M<F%N8VAE<R`](&%R<F%Y*"D["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=$9I
M;&5/8FIE8W0H)')E<"P@)&9I;&5N86UE+"`D8V%C:&4@/2!N=6QL+"`D<75I
M8VML;V<@/2!F86QS92D*("`@('L*("`@("`@("`O*B!4:&4@=F5R<VEO;B!O
M9B!T:&4@8V%C:&5D(&1A=&$N($EN8W)E;65N="!T:&ES('=H96YE=F5R('1H
M90H@("`@("`@("`J(&EN=&5R;F%L('-T;W)A9V4@9F]R;6%T(&-H86YG97,L
M('-U8V@@=&AA="!W92!M=7-T"B`@("`@("`@("H@:6YV86QI9&%T92!P<FEO
M<B!C86-H960@9&%T82X@*B\*("`@("`@("`D8V%C:&5697)S:6]N(#T@,CL*
M("`@("`@("`D8V%C:&5)9"`]("1R97`M/G-O=7)C97)O;W0H*2`N("=?;B<@
M+B`D9FEL96YA;64@+B`G7V8G("X@*&EN="DD<75I8VML;V<@+B`G7W8G("X@
M)&-A8VAE5F5R<VEO;CL*"B`@("`@("`@:68@*"1C86-H92`F)@H@("`@("`@
M("`@("`O+R!4:&4@9FEL92!I<R!C86-H960@9F]R(&]N92!H;W5R(&YO(&UA
M='1E<B!W:&%T+"!B96-A=7-E"B`@("`@("`@("`@("\O('1H97)E(&ES(&YO
M('=A>2!T;R!D971E<FUI;F4@=VET:"!3=6)V97)S:6]N('1H92!T:6UE"B`@
M("`@("`@("`@("\O('1H92!F:6QE(&QA<W0@8VAA;F=E9"X*("`@("`@("`@
M("`@)&-A8VAE+3YE>&ES=',H)&-A8VAE260L(#,V,#`I*2!["B`@("`@("`@
M("`@("1F:6QE3V(@/2!U;G-E<FEA;&EZ92@D8V%C:&4M/F=E="@D8V%C:&5)
M9"P@,S8P,"DI.PH@("`@("`@("`@("`D9FEL94]B+3YS971297!O<VET;W)Y
M*"1R97`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F:6QE3V(@
M/2!N97<@5D-?1FEL95]S=FXH)')E<"P@)&9I;&5N86UE+"`D<75I8VML;V<I
M.PH@("`@("`@("`@("`D9FEL94]B+3YS971297!O<VET;W)Y*"1R97`I.PH@
M("`@("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1F:6QE3V(M/F=E=$)R
M;W=S94EN9F\H*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F
M:6QE3V(M/F%P<&QY4V]R="A60U]33U)47T%'12D["@H@("`@("`@("`@("!I
M9B`H)&-A8VAE*2!["B`@("`@("`@("`@("`@("`D8V%C:&4M/G-E="@D8V%C
M:&5)9"P@<V5R:6%L:7IE*"1F:6QE3V(I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE3V(["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!)9B!T:&ES(&9I;&4@:7,@<')E<V5N="!I;B!A;B!!='1I8R!D
M:7)E8W1O<GDL('1H:7,@:6YD:6-A=&5S"B`@("`@*B!I="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('1R=64@:68@9FEL92!I<R!I;B!T:&4@071T:6,L(&%N
M9"!F86QS92!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@:7-!='1I
M8T9I;&4H*0H@("`@>PH@("`@("`@("\O($YO="!I;7!L96UE;G1E9"!Y970*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!N86UE(&]F('1H92!C=7)R96YT(&9I;&4@87,@:6X@=&AE
M(')E<&]S:71O<GD*("`@("`J"B`@("`@*B!`<F5T=7)N($9I;&5N86UE("AW
M:71H;W5T('1H92!P871H*0H@("`@("HO"B`@("!F=6YC=&EO;B!Q=65R>5)E
M<&]S:71O<GE.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FYA
M;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&YA;64@;V8@=&AE
M(&-U<G)E;G0@9FEL92!W:71H;W5T('1H92!R97!O<VET;W)Y"B`@("`@*B!E
M>'1E;G-I;VYS("AU<W5A;&QY("QV*0H@("`@("H*("`@("`J($!R971U<FX@
M1FEL96YA;64@=VET:&]U="!R97!O<VET;W)Y(&5X=&5N<VEO;@H@("`@("HO
M"B`@("!F=6YC=&EO;B!Q=65R>4YA;64H*0H@("`@>PH@("`@("`@<F5T=7)N
M('!R96=?<F5P;&%C92@G+RQV)"\G+"`G)RP@)'1H:7,M/FYA;64I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!L87-T(')E=FES:6]N(&]F
M('1H92!C=7)R96YT(&9I;&4@;VX@=&AE($A%040@8G)A;F-H"B`@("`@*@H@
M("`@("H@0')E='5R;B!,87-T(')E=FES:6]N(&]F('1H92!C=7)R96YT(&9I
M;&4*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE2979I<VEO;B@I"B`@("![
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^<F5V<ULP72DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(')E=FES:6]N<R<I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)E=G-;,%T["B`@
M("!]"@H@("`@9G5N8W1I;VX@<75E<GE0<F5V:6]U<U)E=FES:6]N*"1R978I
M"B`@("!["B`@("`@("`@)&QA<W0@/2!F86QS93L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^<F5V<R!A<R`D96YT<GDI('L*("`@("`@("`@("`@:68@*"1L
M87-T*0H@("`@("`@("`@("`@("`@<F5T=7)N("1E;G1R>3L*("`@("`@("`@
M("`@:68@*"1E;G1R>2`]/2`D<F5V*0H@("`@("`@("`@("`@("`@)&QA<W0@
M/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!(14%$("AM;W-T(')E8V5N
M="D@<F5V:7-I;VX@;G5M8F5R(&9O<B!T:&ES(&9I;&4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!(14%$(')E=FES:6]N(&YU;6)E<@H@("`@("HO"B`@("!F
M=6YC=&EO;B!Q=65R>4AE860H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^<75E<GE2979I<VEO;B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!L87-T(%9#7TQO9R!O8FIE8W0@:6X@=&AE(&9I;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!60U],;V<@;V8@=&AE(&QA<W0@96YT<GD@:6X@
M=&AE(&9I;&4*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE,87-T3&]G*"D*
M("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YR979S6S!=*2!\?"`A
M:7-S970H)'1H:7,M/FQO9W-;)'1H:7,M/G)E=G-;,%U=*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@<F5V:7-I;VYS)RD[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^;&]G<ULD=&AI<RT^
M<F5V<ULP75T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T('1H92!L:7-T
M(&]F(%9#7TQO9R!O8FIE8W1S('1H870@=&AI<R!F:6QE(&-O;G1A:6YS+@H@
M("`@("H*("`@("`J($!P87)A;2!H;W<@5D-?4T]25%]2158@*'-O<G0@8GD@
M<F5V:7-I;VXI+`H@("`@("H@("`@("`@("`@("!60U]33U)47TY!344@*'-O
M<G0@8GD@875T:&]R(&YA;64I+`H@("`@("H@("`@("`@("`@("!60U]33U)4
M7T%'12`H<V]R="!B>2!C;VUM:70@9&%T92D*("`@("`J+PH@("`@9G5N8W1I
M;VX@87!P;'E3;W)T*"1H;W<@/2!60U]33U)47U)%5BD*("`@('L*("`@("`@
M("!S=VET8V@@*"1H;W<I('L*("`@("`@("!C87-E(%9#7U-/4E1?4D56.@H@
M("`@("`@("`@("`D9G5N8R`]("=2979I<VEO;B<["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@(&-A<V4@5D-?4T]25%].04U%.@H@("`@("`@("`@("`D
M9G5N8R`]("=.86UE)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92!60U]33U)47T%'13H*("`@("`@("`@("`@)&9U;F,@/2`G06=E)SL*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M)&9U;F,@/2`G4F5V:7-I;VXG.PH@("`@("`@('T*("`@("`@("!U87-O<G0H
M)'1H:7,M/FQO9W,L(&%R<F%Y*"1T:&ES+"`B<V]R=$)Y)&9U;F,B*2D["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@
M<V]R=$)Y*B@I(&9U;F-T:6]N<R!A<F4@:6YT97)N86QL>2!U<V5D(&)Y(&%P
M<&QY4V]R="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V]R=$)Y4F5V:7-I;VXH
M)&$L("1B*0H@("`@>PH@("`@("`@(')E='5R;B!60U]2979I<VEO;CHZ8VUP
M*"1B+3YR978L("1A+3YR978I.PH@("`@?0H*("`@(&9U;F-T:6]N('-O<G1"
M>4%G92@D82P@)&(I"B`@("!["B`@("`@("`@<F5T=7)N("1B+3YD871E("T@
M)&$M/F1A=&4["B`@("!]"@H@("`@9G5N8W1I;VX@<V]R=$)Y3F%M92@D82P@
M)&(I"B`@("!["B`@("`@("`@<F5T=7)N('-T<F-M<"@D82T^875T:&]R+"`D
M8BT^875T:&]R*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!O<'5L871E('1H
M92!O8FIE8W0@=VET:"!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<F5V:7-I;VYS
M(&QO9W,*("`@("`J(&%N9"!D871E<R!O9B!T:&4@9FEL92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(&)O;VQE86X@("`@("`@("`@("!4<G5E(&]N
M('-U8V-E<W,L"B`@("`@*B`@("`@("`@("`@("`@(%!%05)?17)R;W(@("`@
M("`@("!/;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0G)O=W-E
M26YF;R@I"B`@("!["B`@("`@("`@+RH@5&AI<R!D;V5S;B=T('=O<FL[(&YE
M960@=&\@9FEN9"!A;F]T:&5R('=A>2!T;R!S:6UP;'D*("`@("`@("`@*B!R
M97%U97-T('1H92!M;W-T(')E8V5N="!R979I<VEO;CH*("`@("`@("`@*@H@
M("`@("`@("`J("1F;&%G(#T@)'1H:7,M/G%U:6-K;&]G(#\@)RUR($A%040@
M)R`Z("<G.R`J+PH@("`@("`@("1F;&%G(#T@)R<["B`@("`@("`@)%$@/2!6
M0U]724Y$3U=3(#\@)R(G(#H@(B<B.PH@("`@("`@("1C;60@/2`D=&AI<RT^
M<F5P+3YG9710871H*"=S=FXG*2`N("<@;&]G("UV("<@+B`D9FQA9R`N("11
M("X@<W1R7W)E<&QA8V4H)%$L("=<7"<@+B`D42P@)'1H:7,M/G%U97)Y1G5L
M;%!A=&@H*2D@+B`D42`N("<@,CXF,2<["B`@("`@("`@)'!I<&4@/2!P;W!E
M;B@D8VUD+"`G<B<I.PH@("`@("`@(&EF("@A)'!I<&4I('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!E>&5C=71E
M('-V;B!L;V<Z("<@+B`D8VUD*3L*("`@("`@("!]"@H@("`@("`@(&9G971S
M*"1P:7!E*3L*("`@("`@("!W:&EL92`H(69E;V8H)'!I<&4I*2!["B`@("`@
M("`@("`@("1L;V<@/2!N97<@5D-?3&]G7W-V;B@D=&AI<RT^<F5P+"`D=&AI
M<RD["B`@("`@("`@("`@("1E<G(@/2`D;&]G+3YP<F]C97-S3&]G*"1P:7!E
M*3L*("`@("`@("`@("`@:68@*"1E<G(I('L*("`@("`@("`@("`@("`@("1R
M978@/2`D;&]G+3YQ=65R>5)E=FES:6]N*"D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G<ULD<F5V72`]("1L;V<["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<F5V<UM=(#T@)')E=CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1T:&ES+3YQ=6EC:VQO9RD@>PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('!C;&]S92@D<&EP
M92D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FX@=&AE(&9U;&QY('%U86QI9FEE9"!F:6QE;F%M92!O9B!T:&ES
M(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N($9U;&QY('%U86QI9FEE
M9"!F:6QE;F%M92!O9B!T:&ES(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO
M;B!Q=65R>49U;&Q0871H*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G)E<"T^<V]U<F-E<F]O="@I("X@)R\G("X@)'1H:7,M/G%U97)Y36]D=6QE
M4&%T:"@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!N86UE
M(&]F('1H:7,@9FEL92!R96QA=&EV92!T;R!I=',@<V]U<F-E<F]O="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4&%T:&YA;64@<F5L871I=F4@
M=&\@=&AE('-O=7)C97)O;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N('%U97)Y
M36]D=6QE4&%T:"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD:7(@
M+B`G+R<@+B`D=&AI<RT^;F%M93L*("`@('T*"GT*"B\J*@H@*B!60U]S=FX@
M;&]G(&-L87-S+@H@*@H@*B!!;FEL($UA9&AA=F%P961D>2P@/&%N:6Q`<F5C
M;VEL+F]R9SX*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H@0'!A8VMA9V4@5D,*("HO"F-L87-S(%9#7TQO
M9U]S=FX@>PH*("`@('9A<B`D<F5P.PH@("`@=F%R("1E<G(["B`@("!V87(@
M)&9I;&4["B`@("!V87(@)&9I;&5S.PH@("`@=F%R("1T86=S.PH@("`@=F%R
M("1R978["B`@("!V87(@)&1A=&4["B`@("!V87(@)&QO9SL*("`@('9A<B`D
M875T:&]R.PH@("`@=F%R("1S=&%T93L*("`@('9A<B`D;&EN97,["B`@("!V
M87(@)&)R86YC:&5S.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%9#7TQO9U]S=FXH)')E<"P@)&9L*0H@("`@
M>PH@("`@("`@("1T:&ES+3YR97`@/2`D<F5P.PH@("`@("`@("1T:&ES+3YF
M:6QE(#T@)&9L.PH@("`@("`@("1T:&ES+3YB<F%N8VAE<R`](&%R<F%Y*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@<')O8V5S<TQO9R@D<&EP92D*("`@('L*
M("`@("`@("`D;&EN92`](&9G971S*"1P:7!E*3L*"B`@("`@("`@:68@*&9E
M;V8H)'!I<&4I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7G(H6S`M.5TJ*2!<?"`H
M+BH_*2!<?"`H+BHI(%PH+BI<*2!<?"`H6S`M.5TJ*2!L:6YE<S\D+R<L("1L
M:6YE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)'1H:7,M/G)E=B`]("1M
M871C:&5S6S%=.PH@("`@("`@("`@("`D=&AI<RT^875T:&]R(#T@)&UA=&-H
M97-;,ET["B`@("`@("`@("`@("1T:&ES+3YD871E(#T@<W1R=&]T:6UE*"1M
M871C:&5S6S-=*3L*("`@("`@("`@("`@)'-I>F4@/2`D;6%T8VAE<ULT73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^97)R(#T@)&QI
M;F4["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(&9G971S*"1P:7!E*3L*"B`@("`@("`@)'1H:7,M/F9I;&5S(#T@87)R
M87DH*3L*("`@("`@("!W:&EL92`H*"1L:6YE(#T@=')I;2AF9V5T<R@D<&EP
M92DI*2`A/2`G)RD@>PH@("`@("`@("`@("`D=&AI<RT^9FEL97-;72`]("1L
M:6YE.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I("$]("1S
M:7IE.R`K*R1I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<@/2`D=&AI<RT^
M;&]G("X@8VAO<"AF9V5T<R@D<&EP92DI("X@(EQN(CL*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YL;V<@/2!C:&]P*"1T:&ES+3YL;V<I.PH@("`@("`@
M(&9G971S*"1P:7!E*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@9G5N8W1I;VX@<75E<GE$871E*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F1A=&4["B`@("!]"@H@("`@9G5N8W1I;VX@<75E<GE2979I<VEO
M;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR978["B`@("!]"@H@
M("`@9G5N8W1I;VX@<75E<GE!=71H;W(H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^875T:&]R.PH@("`@?0H*("`@(&9U;F-T:6]N('%U97)Y3&]G
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9SL*("`@('T*"B`@
M("!F=6YC=&EO;B!Q=65R>4-H86YG961,:6YE<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&ES<V5T*"1T:&ES+3YL:6YE<RD@/R`H)'1H:7,M/FQI;F5S*2`Z
M("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!B<F%N8V@@<F5V
M:7-I;VX@;G5M8F5R+"!T:&ES(&9U;F-T:6]N(')E;6%P<R!I=`H@("`@("H@
M86-C;W)D:6YG;'DL(&%N9"!P97)F;W)M<R!A(&QO;VMU<"!O;B!T:&4@9FEL
M92!O8FIE8W0@=&\*("`@("`J(')E='5R;B!T:&4@<WEM8F]L:6,@;F%M92AS
M*2!O9B!T:&%T(&)R86YC:"!I;B!T:&4@=')E92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&AA<V@@;V8@<WEM8F]L:6,@;F%M97,@/3X@8G)A;F-H(&YU;6)E
M<G,*("`@("`J+PH@("`@9G5N8W1I;VX@<75E<GE3>6UB;VQI8T)R86YC:&5S
M*"D*("`@('L*("`@("`@("`D<WEM0G)A;F-H97,@/2!A<G)A>2@I.PH@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3YB<F%N8VAE<R!A<R`D8G)A;F-H*2!["B`@
M("`@("`@("`@("1P87)T<R`](&5X<&QO9&4H)RXG+"`D8G)A;F-H*3L*("`@
M("`@("`@("`@)&QA<W0@/2!A<G)A>5]P;W`H)'!A<G1S*3L*("`@("`@("`@
M("`@)'!A<G1S6UT@/2`G,"<["B`@("`@("`@("`@("1P87)T<UM=(#T@)&QA
M<W0["B`@("`@("`@("`@("1R978@/2!I;7!L;V1E*"<N)RP@)'!A<G1S*3L*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YF:6QE+3YB<F%N8VAE<ULD
M8G)A;F-H72DI('L*("`@("`@("`@("`@("`@("1S>6U"<F%N8VAE<ULD=&AI
M<RT^9FEL92T^8G)A;F-H97-;)&)R86YC:%U=(#T@)&)R86YC:#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'-Y;4)R86YC:&5S
M.PH@("`@?0H*?0H*+RHJ"B`J(%9#7W-V;B!0871C:'-E="!C;&%S<RX*("H*
M("H@0V]P>7)I9VAT($%N:6P@36%D:&%V87!E9&1Y+"`\86YI;$!R96-O:6PN
M;W)G/@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*B!`<&%C:V%G92!60PH@*B\*8VQA<W,@5D-?4&%T8VAS
M971?<W9N(&5X=&5N9',@5D-?4&%T8VAS970@>PH*("`@('9A<B`D7V9I;&4[
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!P871C:'-E="!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@5&AE(&9I;&5N86UE
M('1O(&=E="!P871C:'-E=',@9F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!6
M0U]0871C:'-E=%]S=FXH)&9I;&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]F
M:6QE(#T@)&9I;&4["B`@("!]"@H@("`@9G5N8W1I;VX@)F=E=%!A=&-H<V5T
M3V)J96-T*"1R97`L("1F:6QE;F%M92P@)&-A8VAE(#T@;G5L;"D*("`@('L*
M("`@("`@("`O*B!4:&4@=F5R<VEO;B!O9B!T:&4@8V%C:&5D(&1A=&$N($EN
M8W)E;65N="!T:&ES('=H96YE=F5R('1H90H@("`@("`@("`J(&EN=&5R;F%L
M('-T;W)A9V4@9F]R;6%T(&-H86YG97,L('-U8V@@=&AA="!W92!M=7-T"B`@
M("`@("`@("H@:6YV86QI9&%T92!P<FEO<B!C86-H960@9&%T82X@*B\*("`@
M("`@("`D8V%C:&5697)S:6]N(#T@,3L*("`@("`@("`D8V%C:&5)9"`]("1R
M97`M/G-O=7)C97)O;W0H*2`N("=?;B<@+B`D9FEL96YA;64@+B`G7V9?=B<@
M+B`D8V%C:&5697)S:6]N.PH*("`@("`@("!I9B`H)&-A8VAE("8F"B`@("`@
M("`@("`@("\O(%1H92!F:6QE(&ES(&-A8VAE9"!F;W(@;VYE(&AO=7(@;F\@
M;6%T=&5R('=H870L(&)E8V%U<V4*("`@("`@("`@("`@+R\@=&AE<F4@:7,@
M;F\@=V%Y('1O(&1E=&5R;6EN92!W:71H('-V;B!T:&4@=&EM92!T:&4@9FEL
M90H@("`@("`@("`@("`O+R!L87-T(&-H86YG960N"B`@("`@("`@("`@("1C
M86-H92T^97AI<W1S*"1C86-H94ED+"`S-C`P*2D@>PH@("`@("`@("`@("`D
M<'-/8B`]('5N<V5R:6%L:7IE*"1C86-H92T^9V5T*"1C86-H94ED+"`S-C`P
M*2D["B`@("`@("`@("`@("1P<T]B+3YS971297!O<VET;W)Y*"1R97`I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P<T]B(#T@;F5W(%9#7U!A
M=&-H<V5T7W-V;B@D9FEL96YA;64I.PH@("`@("`@("`@("`D<'-/8BT^<V5T
M4F5P;W-I=&]R>2@D<F5P*3L*("`@("`@("`@("`@:68@*&ES7V$H*"1R97-U
M;'0@/2`D<'-/8BT^9V5T4&%T8VAS971S*"DI+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"1C86-H92D@>PH@("`@("`@("`@("`@("`@
M)&-A8VAE+3YS970H)&-A8VAE260L('-E<FEA;&EZ92@D<'-/8BDI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!S3V(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0;W!U;&%T92!T:&4@;V)J96-T('=I=&@@
M:6YF;W)M871I;VX@86)O=70@=&AE('!A=&-H<V5T<R!T:&%T"B`@("`@*B!T
M:&ES(&9I;&4@:7,@:6YV;VQV960@:6XN"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@97)R;W(L(&]R('1R=64@
M;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T8VAS971S
M*"D*("`@('L*("`@("`@("`D9FEL94]B(#T@;F5W(%9#7T9I;&5?<W9N*"1T
M:&ES+3Y?<F5P+"`D=&AI<RT^7V9I;&4I.PH@("`@("`@(&EF("AI<U]A*"@D
M<F5S=6QT(#T@)&9I;&5/8BT^9V5T0G)O=W-E26YF;R@I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?<&%T8VAS971S(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("@D9FEL94]B+3YL;V=S(&%S("1R978@/3X@)&QO9RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V72`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R979=6R=D871E)UT@
M/2`D;&]G+3YQ=65R>41A=&4H*3L*("`@("`@("`@("`@)'1H:7,M/E]P871C
M:'-E='-;)')E=EU;)V%U=&AO<B==(#T@)&QO9RT^<75E<GE!=71H;W(H*3L*
M("`@("`@("`@("`@)'1H:7,M/E]P871C:'-E='-;)')E=EU;)V)R86YC:"==
M(#T@)R<["B`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R979=6R=T
M86<G72`]("<G.PH@("`@("`@("`@("`D=&AI<RT^7W!A=&-H<V5T<ULD<F5V
M75LG;&]G)UT@/2`D;&]G+3YQ=65R>4QO9R@I.PH@("`@("`@("`@("`D=&AI
M<RT^7W!A=&-H<V5T<ULD<F5V75LG;65M8F5R<R==(#T@87)R87DH*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)&QO9RT^9FEL97,@87,@)&9I;&4I('L*("`@
M("`@("`@("`@("`@("1A8W1I;VX@/2!S=6)S='(H)&9I;&4L(#`L(#$I.PH@
M("`@("`@("`@("`@("`@)&9I;&4@/2!P<F5G7W)E<&QA8V4H)R\N*C]<<R@N
M*C\I*%QS?"0I+BHO)RP@)UQ<,2<L("1F:6QE*3L*("`@("`@("`@("`@("`@
M("1T;R`]("1R978["B`@("`@("`@("`@("`@("!I9B`H)&%C=&EO;B`]/2`G
M02<I('L*("`@("`@("`@("`@("`@("`@("`D9G)O;2`]("=)3DE424%,)SL*
M("`@("`@("`@("`@("`@('T@96QS96EF("@D86-T:6]N(#T]("=$)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1F<F]M(#T@)'1O.PH@("`@("`@("`@("`@
M("`@("`@("1T;R`]("<H1$5!1"DG.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`O+R!4:&ES('1E8VAN:6-A;&QY(&ES
M;B=T('1H92!P<F5V:6]U<R!R979I<VEO;BP*("`@("`@("`@("`@("`@("`@
M("`O+R!B=70@:70@=V]R:W,@9F]R(&1I9F9I;F<@<'5R<&]S97,N"B`@("`@
M("`@("`@("`@("`@("`@)&9R;VT@/2`D=&\@+2`Q.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%T8VAS971S6R1R979=
M6R=M96UB97)S)UU;72`](&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=F<F]M)R`]/B`D9G)O;2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T
M;R<@/3X@)'1O*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T-O;7!R97-S
M+V1B>"YP:'``````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(Q
M,#<T(#$P-3$U-#,T,30P(#`R,C0R-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E7T-O
M;7!R97-S7V1B>"!C;&%S<R!A;&QO=W,@9&)X(&9I;&5S("AE+F<N(&9R;VT@
M3W5T;&]O:R!%>'!R97-S*0H@*B!T;R!B92!R96%D+@H@*@H@*B!4:&ES(&-L
M87-S(&ES(&)A<V5D(&]N(&-O9&4@8GDZ"B`J($%N=&]N>2!286EJ96MO=B`\
M9&5V0'-T<F%T96=M82YB9SX*("H@:'1T<#HO+W5R=61S+F=A=&5W87DN8F<O
M>F5O<R\*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E
M<W,O9&)X+G!H<"QV(#$N,RXQ,BXY(#(P,#8O,#$O,#$@,C$Z,C@Z,3$@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F%N(%-C:&YE:61E
M<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@*B\*8VQA<W,@
M2&]R9&5?0V]M<')E<W-?9&)X(&5X=&5N9',@2&]R9&5?0V]M<')E<W,@>PH*
M("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?;6%I;',@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?=&UP(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($1E8V]M
M<')E<W-E<R!A($1"6"!F:6QE(&%N9"!G971S(&EN9F]R;6%T:6]N(&9R;VT@
M:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@5&AE(&1B
M>"!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE(')E<75E<W1E9"!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O;7!R97-S*"8D9&%T82P@
M)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]M86EL<R`]
M(&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]T;7`@/2!A<G)A>2@I.PH@("`@
M("`@("1P;W-I=&EO;B`](#!X0S0["B`@("`@("`@)&AE861E<E]I;F9O(#T@
M=6YP86-K*"=,<&]S:71I;VXO3$1A=&%,96YG=&@O;DAE861E<DQE;F=T:"]N
M1FQA9T-O=6YT)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(#$R*2D["B`@
M("`@("`@)'!O<VET:6]N("L](#$R.PH@("`@("`@("\O($=O('1O('1H92!F
M:7)S="!T86)L92!O9F9E<W0@86YD('!R;V-E<W,@:70N"B`@("`@("`@:68@
M*"1H96%D97)?:6YF;ULG<&]S:71I;VXG72`^(#`I('L*("`@("`@("`@("`@
M)'!O<VET:6]N(#T@,'@S,#L*("`@("`@("`@("`@)&)U9B`]('5N<&%C:R@G
M3'!O<VET:6]N)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL(#0I*3L*("`@
M("`@("`@("`@)'!O<VET:6]N(#T@)&)U9ELG<&]S:71I;VXG73L*("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?<F5A9$EN9&5X*"1D871A+"`D<&]S
M:71I;VXI.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]M
M86EL<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!N=6QL+71E
M<FUI;F%T960@<W1R:6YG(&9R;VT@=&AE('-P96-I9FEE9"!D871A+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)B1B=68@(%1/1$\*("`@("`J($!P87)A;2!I;G1E9V5R("1P
M;W,@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?<F5A9%-T<FEN9R@F)&)U9BP@)'!O<RD*
M("`@('L*("`@("`@("!I9B`H)&QE;B`]('-T<G!O<RAS=6)S='(H)&)U9BP@
M)'!O<RDL(&-H<B@P*2DI('L*("`@("`@("`@("`@<F5T=7)N('-U8G-T<B@D
M8G5F+"`D<&]S+"`D;&5N*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("<G
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D
M871A("`@("`@5$]$3PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<VET:6]N
M("!43T1/"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1/1$\*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W)E861-97-S86=E*"8D9&%T82P@)'!O<VET
M:6]N*0H@("`@>PH@("`@("`@("1M<V<@/2`G)SL*("`@("`@("`D<&%R="`]
M(#`["@H@("`@("`@(&EF("@D<&]S:71I;VX@/B`P*2!["B`@("`@("`@("`@
M("1);F1E>$ET96US0V]U;G0@/2!A<G)A>5]P;W`H=6YP86-K*"=3)RP@<W5B
M<W1R*"1D871A+"`P>$,T+"`T*2DI.PH@("`@("`@("`@("!I9B`H)$EN9&5X
M271E;7-#;W5N="`^(#`I('L*("`@("`@("`@("`@("`@('=H:6QE("@D<&]S
M:71I;VX@/"!S=')L96XH)&1A=&$I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'!A<G0K*SL*("`@("`@("`@("`@("`@("`@("`D<R`]('-U8G-T<B@D9&%T
M82P@)'!O<VET:6]N+"`U,C@I.PH@("`@("`@("`@("`@("`@("`@(&EF("AS
M=')L96XH)',I(#T](#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("1M<V=?:71E;2`]('5N<&%C:R@G3$9I;&50;W,O3%5N:VYO=VXO3$ET96U3
M:7IE+TQ.97AT271E;2]A-3$R0V]N=&5N="<L("1S*3L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&US9U]I=&5M6R=&:6QE4&]S)UT@(3T@)'!O<VET:6]N
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(DEN=F%L:60@9FEL92!F;W)M870B*2D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1P;W-I=&EO;B`K/2`U
M,C@["B`@("`@("`@("`@("`@("`@("`@)&US9R`N/2!S=6)S='(H)&US9U]I
M=&5M6R=#;VYT96YT)UTL(#`L("1M<V=?:71E;5LG271E;5-I>F4G72D["B`@
M("`@("`@("`@("`@("`@("`@)'!O<VET:6]N(#T@)&US9U]I=&5M6R=.97AT
M271E;2==.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&]S:71I;VX@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("`@("`@5$]$3PH@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<VET:6]N("!43T1/"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>2`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO
M;B!?<F5A9$UE<W-A9V5);F9O*"8D9&%T82P@)'!O<VET:6]N*0H@("`@>PH@
M("`@("`@("1M97-S86=E7VEN9F\@/2!A<G)A>2@I.PH@("`@("`@("1M<V=?
M:&5A9&5R(#T@=6YP86-K*"=,<&]S:71I;VXO3$1A=&%,96YG=&@O4TAE861E
M<DQE;F=T:"]31FQA9T-O=6YT)RP@<W5B<W1R*"1D871A+"`D<&]S:71I;VXL
M(#$R*2D["B`@("`@("`@:68@*"1M<V=?:&5A9&5R6R=P;W-I=&EO;B==("$]
M("1P;W-I=&EO;BD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*"));G9A;&ED(&9I;&4@9F]R;6%T(BDI.PH@("`@("`@('T*("`@
M("`@("`D<&]S:71I;VX@*ST@,3(["B`@("`@("`@)&UE<W-A9V5?:6YF;ULG
M2&5A9&5R4&]S:71I;VXG72`]("1M<V=?:&5A9&5R6R=P;W-I=&EO;B==.PH@
M("`@("`@("1F;&%G<R`]("1M<V=?:&5A9&5R6R=&;&%G0V]U;G0G72`F(#!X
M1D8["B`@("`@("`@)$1A=&%3:7IE(#T@)&US9U]H96%D97);)T1A=&%,96YG
M=&@G72`M("1F;&%G<R`J(#0["B`@("`@("`@)'-I>F4@/2`T("H@)&9L86=S
M.PH@("`@("`@("1&;&%G<T)U9F9E<B`]('-U8G-T<B@D9&%T82P@)'!O<VET
M:6]N+"`D<VEZ92D["B`@("`@("`@)'!O<VET:6]N("L]("1S:7IE.PH@("`@
M("`@("1S:7IE(#T@)$1A=&%3:7IE.PH@("`@("`@("1$871A0G5F9F5R(#T@
M<W5B<W1R*"1D871A+"`D<&]S:71I;VXL("1S:7IE*3L*("`@("`@("`D<&]S
M:71I;VX@*ST@)'-I>F4["B`@("`@("`@)&UE<W-A9V5?:6YF;R`](&%R<F%Y
M*"D["@H@("`@("`@("1F;&%G7V%R<F%Y(#T@87)R87DH"B`@("`@("`@("`@
M(#!X,2`]/B`G37-G1FQA9W,G+`H@("`@("`@("`@("`P>#(@/3X@)U-E;G0G
M+`H@("`@("`@("`@("`P>#0@/3X@)W!O<VET:6]N)RP*("`@("`@("`@("`@
M,'@W(#T^("=-97-S86=E240G+`H@("`@("`@("`@("`P>#@@/3X@)U-U8FIE
M8W0G+`H@("`@("`@("`@("`P>#D@/3X@)T9R;VU?<F5P;'DG+`H@("`@("`@
M("`@("`P>$$@/3X@)U)E9F5R96YC97,G+`H@("`@("`@("`@("`P>$(@/3X@
M)TYE=W-G<F]U<"<L"B`@("`@("`@("`@(#!X1"`]/B`G1G)O;2<L"B`@("`@
M("`@("`@(#!X12`]/B`G4F5P;'E?5&\G+`H@("`@("`@("`@("`P>#$R(#T^
M("=296-E:79E9"<L"B`@("`@("`@("`@(#!X,3,@/3X@)U)E8V5I<'0G+`H@
M("`@("`@("`@("`P>#%!(#T^("=!8V-O=6YT)RP*("`@("`@("`@("`@,'@Q
M0B`]/B`G06-C;W5N=$E$)RP*("`@("`@("`@("`@,'@X,"`]/B`G37-G)RP*
M("`@("`@("`@("`@,'@X,2`]/B`G37-G1FQA9W,G+`H@("`@("`@("`@("`P
M>#@T(#T^("=P;W-I=&EO;B<L"B`@("`@("`@("`@(#!X.3$@/3X@)W-I>F4G
M+`H@("`@("`@("D["@H@("`@("`@("\J(%!R;V-E<W,@9FQA9W,@*B\*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D9FQA9W,[("1I*RLI('L*("`@("`@
M("`@("`@)'!O<R`](#`["B`@("`@("`@("`@("1F(#T@87)R87E?<&]P*'5N
M<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F97(L("1I("H@-"P@-"DI*3L*
M"B`@("`@("`@("`@("1M87-K(#T@)&8@)B`P>$9&.PH@("`@("`@("`@("!S
M=VET8V@@*"1M87-K*2!["B`@("`@("`@("`@(&-A<V4@,'@Q.@H@("`@("`@
M("`@("`@("`@)'!O<R`]("1P;W,@*R`H)&8@/CX@."D["B`@("`@("`@("`@
M("`@("`D;65S<V%G95]I;F9O6R=-<V=&;&%G<R==(#T@87)R87E?<&]P*'5N
M<&%C:R@G0R<L('-U8G-T<B@D1&%T84)U9F9E<BP@)'!O<RLK+"`Q*2DI.PH@
M("`@("`@("`@("`@("`@)&UE<W-A9V5?:6YF;ULG37-G1FQA9W,G72`K/2!A
M<G)A>5]P;W`H=6YP86-K*"=#)RP@<W5B<W1R*"1$871A0G5F9F5R+"`D<&]S
M*RLL(#$I*2D@*B`R-38["B`@("`@("`@("`@("`@("`D;65S<V%G95]I;F9O
M6R=-<V=&;&%G<R==("L](&%R<F%Y7W!O<"AU;G!A8VLH)T,G+"!S=6)S='(H
M)$1A=&%"=69F97(L("1P;W,L(#$I*2D@*B`V-34S-CL*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#(Z"B`@("`@("`@("`@
M(&-A<V4@,'@T.@H@("`@("`@("`@("`@("`@)'!O<R`K/2!A<G)A>5]P;W`H
M=6YP86-K*"=,)RP@<W5B<W1R*"1&;&%G<T)U9F9E<BP@)&D@*B`T+"`T*2DI
M(#X^(#@["B`@("`@("`@("`@("`@("`D;65S<V%G95]I;F9O6R1F;&%G7V%R
M<F%Y6R1M87-K75T@/2!A<G)A>5]P;W`H=6YP86-K*"=,)RP@<W5B<W1R*"1$
M871A0G5F9F5R+"`D<&]S+"`T*2DI.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E(#!X-SH*("`@("`@("`@("`@8V%S92`P>#@Z
M"B`@("`@("`@("`@(&-A<V4@,'@Y.@H@("`@("`@("`@("!C87-E(#!X03H*
M("`@("`@("`@("`@8V%S92`P>$(Z"B`@("`@("`@("`@(&-A<V4@,'A$.@H@
M("`@("`@("`@("!C87-E(#!X13H*("`@("`@("`@("`@8V%S92`P>#$S.@H@
M("`@("`@("`@("!C87-E(#!X,4$Z"B`@("`@("`@("`@("`@("`D<&]S("L]
M(&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S='(H)$9L86=S0G5F9F5R+"`D
M:2`J(#0L(#0I*2D@/CX@.#L*("`@("`@("`@("`@("`@("1M97-S86=E7VEN
M9F];)&9L86=?87)R87E;)&UA<VM=72`]("1T:&ES+3Y?<F5A9%-T<FEN9R@D
M1&%T84)U9F9E<BP@)'!O<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&-A<V4@,'@Q,CH*("`@("`@("`@("`@("`@("1P;W,@*ST@
M87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F97(L("1I
M("H@-"P@-"DI*2`^/B`X.PH@("`@("`@("`@("`@("`@)&UE<W-A9V5?:6YF
M;ULG4F5C96EV960G72`](&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S='(H
M)$1A=&%"=69F97(L("1P;W,L(#0I*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@,'@Q0CH*("`@("`@("`@("`@("`@("1P
M;W,@*ST@87)R87E?<&]P*'5N<&%C:R@G3"<L('-U8G-T<B@D1FQA9W-"=69F
M97(L("1I("H@-"P@-"DI*2`^/B`X.PH@("`@("`@("`@("`@("`@)&UE<W-A
M9V5?:6YF;ULG06-C;W5N=$E$)UT@/2!I;G1V86PH)'1H:7,M/E]R96%D4W1R
M:6YG*"1$871A0G5F9F5R+"`D<&]S*2D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@(&-A<V4@,'@X,#H*("`@("`@("`@("`@8V%S92`P
M>#@Q.@H@("`@("`@("`@("!C87-E(#!X.#0Z"B`@("`@("`@("`@(&-A<V4@
M,'@Y,3H*("`@("`@("`@("`@("`@("1M97-S86=E7VEN9F];)&9L86=?87)R
M87E;)&UA<VM=72`](&%R<F%Y7W!O<"AU;G!A8VLH)TPG+"!S=6)S='(H)$9L
M86=S0G5F9F5R+"`D:2`J(#0L(#0I*2D@/CX@.#L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&UE<W-A9V5?:6YF;SL*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("8D9&%T82`@("`@(%1/1$\*("`@("`J($!P87)A;2!I
M;G1E9V5R("1P;W-I=&EO;B`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO;B!?
M<F5A9$EN9&5X*"8D9&%T82P@)'!O<VET:6]N*0H@("`@>PH@("`@("`@("1I
M;F1E>%]H96%D97(@/2!U;G!A8VLH)TQ&:6QE4&]S+TQ5;FMN;W=N,2],4')E
M=DEN9&5X+TQ.97AT26YD97@O3$-O=6YT+TQ5;FMN;W=N)RP@<W5B<W1R*"1D
M871A+"`D<&]S:71I;VXL(#(T*2D["B`@("`@("`@:68@*"1I;F1E>%]H96%D
M97);)T9I;&50;W,G72`A/2`D<&]S:71I;VXI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B26YV86QI9"!F:6QE(&9O<FUA="(I
M*3L*("`@("`@("!]"@H@("`@("`@("\O(%!U<V@@:70@:6YT;R!L:7-T(&]F
M('!R;V-E<W-E9"!I=&5M<RX*("`@("`@("`D=&AI<RT^7W1M<%LD<&]S:71I
M;VY=(#T@=')U93L*("`@("`@("!I9B`H*"1I;F1E>%]H96%D97);)TYE>'1)
M;F1E>"==(#X@,"D@)B8*("`@("`@("`@("`@96UP='DH)'1H:7,M/E]T;7!;
M)&EN9&5X7VAE861E<ELG3F5X=$EN9&5X)UU=*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W)E861);F1E>"@D9&%T82P@)&EN9&5X7VAE861E<ELG3F5X=$EN
M9&5X)UTI.PH@("`@("`@('T*("`@("`@("!I9B`H*"1I;F1E>%]H96%D97);
M)U!R979);F1E>"==(#X@,"D@)B8*("`@("`@("`@("`@96UP='DH)'1H:7,M
M/E]T;7!;)&EN9&5X7VAE861E<ELG4')E=DEN9&5X)UU=*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)E861);F1E>"@D9&%T82P@)&EN9&5X7VAE861E<ELG
M4')E=DEN9&5X)UTI.PH@("`@("`@('T*("`@("`@("`D<&]S:71I;VX@*ST@
M,C0["B`@("`@("`@)&EC;W5N="`]("1I;F1E>%]H96%D97);)T-O=6YT)UT@
M/CX@.#L*("`@("`@("!I9B`H)&EC;W5N="`^(#`I('L*("`@("`@("`@("`@
M)&)U9B`]('-U8G-T<B@D9&%T82P@)'!O<VET:6]N+"`Q,B`J("1I8V]U;G0I
M.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:6-O=6YT.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D:&1R7V)U9B`]('-U8G-T<B@D8G5F+"`D
M:2`J(#$R+"`Q,BD["B`@("`@("`@("`@("`@("`D26YD97A)=&5M(#T@=6YP
M86-K*"=,2&5A9&5R4&]S+TQ#:&EL9$EN9&5X+TQ5;FMN;W=N)RP@)&AD<E]B
M=68I.PH@("`@("`@("`@("`@("`@:68@*"1);F1E>$ET96U;)TAE861E<E!O
M<R==(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("1M86EL6R=I;F9O)UT@
M/2`D=&AI<RT^7W)E861-97-S86=E26YF;R@D9&%T82P@)$EN9&5X271E;5LG
M2&5A9&5R4&]S)UTI.PH@("`@("`@("`@("`@("`@("`@("1M86EL6R=C;VYT
M96YT)UT@/2`D=&AI<RT^7W)E861-97-S86=E*"1D871A+"`D;6%I;%LG:6YF
M;R==6R=P;W-I=&EO;B==*3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUA:6QS6UT@/2`D;6%I;#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("@H)$EN9&5X271E;5LG0VAI;&1);F1E>"==(#X@,"D@)B8*
M("`@("`@("`@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W1M<%LD26YD97A)
M=&5M6R=#:&EL9$EN9&5X)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5A9$EN9&5X*"1F<"P@)$EN9&5X271E;5LG0VAI;&1);F1E>"==
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M0V]M<')E<W,O>FEP+G!H<```````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,S0W,S,@,3`U,34T,S0Q-#`@,#(R-#4W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@HO*BH*("H@1F]R
M(&1E8V]M<')E<W,H*2P@<F5T=7)N(&$@;&ES="!O9B!F:6QE<R]I;F9O<FUA
M=&EO;B!A8F]U="!T:&4@>FEP9FEL92X*("HO"F1E9FEN92@G2$]21$5?0T]-
M4%)%4U-?6DE07TQ)4U0G+"`Q*3L*"B\J*@H@*B!&;W(@9&5C;VUP<F5S<R@I
M+"!R971U<FX@=&AE(&1A=&$@9F]R(&%N(&EN9&EV:61U86P@9FEL92!I;B!T
M:&4@>FEP9FEL92X*("HO"F1E9FEN92@G2$]21$5?0T]-4%)%4U-?6DE07T1!
M5$$G+"`R*3L*"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E<W-?>FEP(&-L87-S
M(&%L;&]W<R!:25`@9FEL97,@=&\@8F4@8W)E871E9"!A;F0*("H@<F5A9"X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO0V]M<')E<W,O0V]M<')E<W,O>FEP
M+G!H<"QV(#$N,3$N,3(N,38@,C`P-B\P-B\R.2`P.#HS-#HS,"!J86X@17AP
M("0*("H*("H@5&AE(%I)4"!C;VUP<F5S<VEO;B!C;V1E(&ES('!A<G1I86QL
M>2!B87-E9"!O;B!C;V1E(&9R;VTZ"B`J("`@17)I8R!-=65L;&5R(#QE<FEC
M0'1H96UE<&%R:RYC;VT^"B`J("`@:'1T<#HO+W=W=RYZ96YD+F-O;2]C;V1E
M>"YP:'`_:60]-3,U)G-I;F=L93TQ"B`J"B`J("`@1&5I;G,Q,C4@/'=E8FUA
M<W1E<D!A=&QA;G0N<G4^"B`J("`@:'1T<#HO+W=W=RYZ96YD+F-O;2]C;V1E
M>"YP:'`_:60]-#<P)G-I;F=L93TQ"B`J"B`J(%1H92!:25`@8V]M<')E<W-I
M;VX@9&%T92!C;V1E(&ES('!A<G1I86QL>2!B87-E9"!O;B!C;V1E(&9R;VT*
M("H@("!0971E<B!,:7-T:6%K(#QM;&%D>4!U<V5R<RYS;W5R8V5F;W)G92YN
M970^"B`J"B`J($-O<'ER:6=H="`R,#`P+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC
M:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@36EC:&%E;"!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*
M("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN
M8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?0V]M<')E<W,*("HO"F-L87-S($AO<F1E7T-O;7!R97-S7WII
M<"!E>'1E;F1S($AO<F1E7T-O;7!R97-S('L*"B`@("`O*BH*("`@("`J(%I)
M4"!C;VUP<F5S<VEO;B!M971H;V1S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?;65T:&]D<R`](&%R<F%Y*`H@("`@("`@
M(#!X,"`]/B`G3F]N92<L"B`@("`@("`@,'@Q(#T^("=3:')U;FLG+`H@("`@
M("`@(#!X,B`]/B`G4W5P97(@1F%S="<L"B`@("`@("`@,'@S(#T^("=&87-T
M)RP*("`@("`@("`P>#0@/3X@)TYO<FUA;"<L"B`@("`@("`@,'@U(#T^("=-
M87AI;75M)RP*("`@("`@("`P>#8@/3X@)TEM<&QO9&5D)RP*("`@("`@("`P
M>#@@/3X@)T1E9FQA=&5D)PH@("`@*3L*"B`@("`O*BH*("`@("`J($)E9VEN
M;FEN9R!O9B!C96YT<F%L(&1I<F5C=&]R>2!R96-O<F0N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W1R;$1I<DAE861E
M<B`](")<>#4P7'@T8EQX,#%<>#`R(CL*"B`@("`O*BH*("`@("`J($5N9"!O
M9B!C96YT<F%L(&1I<F5C=&]R>2!R96-O<F0N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8W1R;$1I<D5N9"`](")<>#4P
M7'@T8EQX,#5<>#`V7'@P,%QX,#!<>#`P7'@P,"(["@H@("`@+RHJ"B`@("`@
M*B!"96=I;FYI;F<@;V8@9FEL92!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]F:6QE2&5A9&5R(#T@(EQX
M-3!<>#1B7'@P,UQX,#0B.PH*("`@("\J*@H@("`@("H@0W)E871E(&$@6DE0
M(&-O;7!R97-S960@9FEL92!F<F]M(&%N(&%R<F%Y(&]F(&9I;&4@9&%T82X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@5&AE(&1A=&$@
M=&\@8V]M<')E<W,N"B`@("`@*B`\<')E/@H@("`@("H@4F5Q=6ER97,@86X@
M87)R87D@;V8@87)R87ES("T@96%C:"!S=6)A<G)A>2!S:&]U;&0@8V]N=&%I
M;B!T:&4*("`@("`J(&9O;&QO=VEN9R!F:65L9',Z"B`@("`@*B`G9&%T82<@
M*'-T<FEN9RD@("`M+2`@5&AE(&1A=&$@=&\@8V]M<')E<W,N"B`@("`@*B`G
M;F%M92<@*'-T<FEN9RD@("`M+2`@5&AE('!A=&AN86UE('1O('1H92!F:6QE
M+@H@("`@("H@)W1I;64G("AI;G1E9V5R*2`@+2T@(%MO<'1I;VYA;%T@5&AE
M('1I;65S=&%M<"!T;R!U<V4@9F]R('1H92!F:6QE+@H@("`@("H@/"]P<F4^
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<B!A
M<G)A>2`H56YU<V5D*2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(%I)4"!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUP<F5S<R@D
M9&%T82P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&-O;G1E
M;G1S(#T@)&-T<FQD:7(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D
M9&%T82!A<R`D=F%L*2!["B`@("`@("`@("`@("1T:&ES+3Y?861D5&]:25!&
M:6QE*"1V86PL("1C;VYT96YT<RP@)&-T<FQD:7(I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8W)E871E6DE01FEL92@D8V]N=&5N=',L
M("1C=')L9&ER*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E8V]M<')E<W,@
M82!:25`@9FEL92!A;F0@9V5T(&EN9F]R;6%T:6]N(&9R;VT@:70N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!Z:7!F:6QE(&1A
M=&$N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E
M<B!A<G)A>2X*("`@("`J(#QP<F4^"B`@("`@*B!4:&4@9F]L;&]W:6YG('!A
M<F%M971E<G,@87)E(%)%455)4D5$.@H@("`@("H@)V%C=&EO;B<@*&EN=&5G
M97(I("`]/B`@5&AE(&%C=&EO;B!T;R!T86ME(&]N('1H92!D871A+B`@16ET
M:&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!(3U)$15]#3TU0
M4D534U]:25!?3$E35"!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@2$]21$5?0T]-4%)%4U-?6DE07T1!5$$N"B`@("`@*@H@("`@("H@5&AE
M(&9O;&QO=VEN9R!P87)A;65T97)S(&%R92!215%525)%1"!F;W(@2$]21$5?
M0T]-4%)%4U-?6DE07T1!5$$@86QS;SH*("`@("`J("=I;F9O)R`H87)R87DI
M("`@/3X@(%1H92!Z:7!F:6QE(&QI<W0N"B`@("`@*B`G:V5Y)R`H:6YT96=E
M<BD@(#T^("!4:&4@<&]S:71I;VX@;V8@=&AE(&9I;&4@:6X@=&AE(&%R8VAI
M=F4@;&ES="X*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!R97%U97-T960@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&5C;VUP<F5S<R@D9&%T82P@)'!A<F%M<RD*("`@('L*("`@("`@("!I
M9B`H:7-S970H)'!A<F%M<ULG86-T:6]N)UTI*2!["B`@("`@("`@("`@(&EF
M("@D<&%R86US6R=A8W1I;VXG72`]/2!(3U)$15]#3TU04D534U]:25!?3$E3
M5"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T6FEP26YF
M;R@D9&%T82D["B`@("`@("`@("`@('T@96QS96EF("@D<&%R86US6R=A8W1I
M;VXG72`]/2!(3U)$15]#3TU04D534U]:25!?1$%402D@>PH@("`@("`@("`@
M("`@("`@+R\@5$]$3SH@0VAE8VL@9F]R('!A<F%M971E<G,N"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]G971::7!$871A*"1D871A+"`D<&%R
M86US6R=I;F9O)UTL("1P87)A;7-;)VME>2==*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DEN8V]R<F5C="!A8W1I;VX@8V]D92!G:79E;BXB*2P@)VAO<F1E+F5R
M<F]R)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(EEO=2!M=7-T('-P96-I9GD@=VAA="!A
M8W1I;VX@=&\@<&5R9F]R;2XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE(&QI<W0@;V8@9FEL97,O9&%T82!F<F]M
M('1H92!Z:7`@87)C:&EV92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@5&AE('II
M<&9I;&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!+15DZ
M(%!O<VET:6]N(&EN('II<&9I;&4*("`@("`J("`@("`@("`@("`@("`@(%9!
M3%5%4SH@)V%T='(G("`@("TM("!&:6QE(&%T=')I8G5T97,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@)V-R8R<@("`@("TM("!#4D,@8VAE8VMS
M=6T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)V-S:7IE)R`@("TM
M("!#;VUP<F5S<V5D(&9I;&4@<VEZ90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`G9&%T92<@("`@+2T@($9I;&4@;6]D:69I8V%T:6]N('1I;64*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@("TM("!&
M:6QE;F%M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G;65T:&]D
M)R`@+2T@($-O;7!R97-S:6]N(&UE=&AO9`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`G<VEZ92<@("`@+2T@($]R:6=I;F%L(&9I;&4@<VEZ90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@("`@+2T@($9I
M;&4@='EP90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T6FEP26YF;R@F)&1A
M=&$I"B`@("!["B`@("`@("`@)&5N=')I97,@/2!A<G)A>2@I.PH*("`@("`@
M("`O*B!'970@9&5T86EL<R!F<F]M($-E;G1R86P@9&ER96-T;W)Y('-T<G5C
M='5R92X@*B\*("`@("`@("`D9FA3=&%R="`]('-T<G!O<R@D9&%T82P@)'1H
M:7,M/E]C=')L1&ER2&5A9&5R*3L*"B`@("`@("`@9&\@>PH@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1D871A*2`\("1F:%-T87)T("L@,S$I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@
M6DE0(&1A=&$B*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EN9F\@
M/2!U;G!A8VLH)W9-971H;V0O5E1I;64O5D-20S,R+U9#;VUP<F5S<V5D+U95
M;F-O;7!R97-S960O=DQE;F=T:"<L('-U8G-T<B@D9&%T82P@)&9H4W1A<G0@
M*R`Q,"P@,C`I*3L*("`@("`@("`@("`@)&YA;64@/2!S=6)S='(H)&1A=&$L
M("1F:%-T87)T("L@-#8L("1I;F9O6R=,96YG=&@G72D["@H@("`@("`@("`@
M("`D96YT<FEE<ULD;F%M95T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=A
M='1R)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@)V-R8R<@/3X@<W!R:6YT
M9B@B)3`X<R(L(&1E8VAE>"@D:6YF;ULG0U)#,S(G72DI+`H@("`@("`@("`@
M("`@("`@)V-S:7IE)R`]/B`D:6YF;ULG0V]M<')E<W-E9"==+`H@("`@("`@
M("`@("`@("`@)V1A=&4G(#T^(&YU;&PL"B`@("`@("`@("`@("`@("`G7V1A
M=&%3=&%R="<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D
M;F%M92P*("`@("`@("`@("`@("`@("=M971H;V0G(#T^("1T:&ES+3Y?;65T
M:&]D<ULD:6YF;ULG365T:&]D)UU=+`H@("`@("`@("`@("`@("`@)U]M971H
M;V0G(#T^("1I;F9O6R=-971H;V0G72P*("`@("`@("`@("`@("`@("=S:7IE
M)R`]/B`D:6YF;ULG56YC;VUP<F5S<V5D)UTL"B`@("`@("`@("`@("`@("`G
M='EP92<@/3X@;G5L;`H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@)&5N
M=')I97-;)&YA;65=6R=D871E)UT@/0H@("`@("`@("`@("`@("`@;6MT:6UE
M*"@H)&EN9F];)U1I;64G72`^/B`Q,2D@)B`P>#%F*2P*("`@("`@("`@("`@
M("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/CX@-2D@)B`P>#-F*2P*("`@
M("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@/#P@,2D@)B`P
M>#-E*2P*("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4:6UE)UT@
M/CX@,C$I("8@,'@P-RDL"B`@("`@("`@("`@("`@("`@("`@("`@*"@D:6YF
M;ULG5&EM92==(#X^(#$V*2`F(#!X,68I+`H@("`@("`@("`@("`@("`@("`@
M("`@("@H*"1I;F9O6R=4:6UE)UT@/CX@,C4I("8@,'@W9BD@*R`Q.3@P*2D[
M"@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1D871A*2`\("1F:%-T87)T("L@
M-#,I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(DEN=F%L:60@6DE0(&1A=&$B*2D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&EN9F\@/2!U;G!A8VLH)W9);G1E<FYA;"]617AT97)N86PG+"!S
M=6)S='(H)&1A=&$L("1F:%-T87)T("L@,S8L(#8I*3L*"B`@("`@("`@("`@
M("1E;G1R:65S6R1N86UE75LG='EP92==(#T@*"1I;F9O6R=);G1E<FYA;"==
M("8@,'@P,2D@/R`G=&5X="<@.B`G8FEN87)Y)SL*("`@("`@("`@("`@)&5N
M=')I97-;)&YA;65=6R=A='1R)UT@/0H@("`@("`@("`@("`@("`@*"@D:6YF
M;ULG17AT97)N86PG72`F(#!X,3`I(#\@)T0G(#H@)RTG*2`N"B`@("`@("`@
M("`@("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@,'@R,"D@/R`G02<@.B`G
M+2<I("X*("`@("`@("`@("`@("`@("@H)&EN9F];)T5X=&5R;F%L)UT@)B`P
M>#`S*2`_("=3)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@*"@D:6YF;ULG
M17AT97)N86PG72`F(#!X,#(I(#\@)T@G(#H@)RTG*2`N"B`@("`@("`@("`@
M("`@("`H*"1I;F9O6R=%>'1E<FYA;"==("8@,'@P,2D@/R`G4B<@.B`G+2<I
M.PH@("`@("`@('T@=VAI;&4@*"@D9FA3=&%R="`]('-T<G!O<R@D9&%T82P@
M)'1H:7,M/E]C=')L1&ER2&5A9&5R+"`D9FA3=&%R="`K(#0V*2D@(3T](&9A
M;'-E*3L*"B`@("`@("`@+RH@1V5T(&1E=&%I;',@9G)O;2!L;V-A;"!F:6QE
M(&AE861E<BX@*B\*("`@("`@("`D9FA3=&%R="`]('-T<G!O<R@D9&%T82P@
M)'1H:7,M/E]F:6QE2&5A9&5R*3L*"B`@("`@("`@9&\@>PH@("`@("`@("`@
M("!I9B`H<W1R;&5N*"1D871A*2`\("1F:%-T87)T("L@,S0I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DEN=F%L:60@
M6DE0(&1A=&$B*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&EN9F\@
M/2!U;G!A8VLH)W9-971H;V0O5E1I;64O5D-20S,R+U9#;VUP<F5S<V5D+U95
M;F-O;7!R97-S960O=DQE;F=T:"]V17AT<F%,96YG=&@G+"!S=6)S='(H)&1A
M=&$L("1F:%-T87)T("L@."P@,C4I*3L*("`@("`@("`@("`@)&YA;64@/2!S
M=6)S='(H)&1A=&$L("1F:%-T87)T("L@,S`L("1I;F9O6R=,96YG=&@G72D[
M"B`@("`@("`@("`@("1E;G1R:65S6R1N86UE75LG7V1A=&%3=&%R="==(#T@
M)&9H4W1A<G0@*R`S,"`K("1I;F9O6R=,96YG=&@G72`K("1I;F9O6R=%>'1R
M84QE;F=T:"==.PH@("`@("`@('T@=VAI;&4@*'-T<FQE;B@D9&%T82D@/B`D
M9FA3=&%R="`K(#,P("L@)&EN9F];)TQE;F=T:"==("8F"B`@("`@("`@("`@
M("`@("`@*"1F:%-T87)T(#T@<W1R<&]S*"1D871A+"`D=&AI<RT^7V9I;&5(
M96%D97(L("1F:%-T87)T("L@,S`@*R`D:6YF;ULG3&5N9W1H)UTI*2`A/3T@
M9F%L<V4I.PH*("`@("`@("!R971U<FX@87)R87E?=F%L=65S*"1E;G1R:65S
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&1A=&$@9F]R
M(&$@<W!E8VEF:6,@87)C:&EV960@9FEL92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T
M82`@5&AE('II<"!A<F-H:79E(&-O;G1E;G1S+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("8D:6YF;R`@(%1H92!I;F9O<FUA=&EO;B!A<G)A>2!F<F]M(%]G971:
M:7!);F9O*"DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:V5Y("`@5&AE('!O
M<VET:6]N(&]F('1H92!F:6QE(&EN('1H92!A<F-H:79E+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!D871A+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5T6FEP1&%T82@F)&1A=&$L("8D:6YF;RP@)&ME>2D*
M("`@('L*("`@("`@("!I9B`H*"1I;F9O6R1K97E=6R=?;65T:&]D)UT@/3T@
M,'@X*2`F)B!5=&EL.CIE>'1E;G-I;VY%>&ES=',H)WIL:6(G*2D@>PH@("`@
M("`@("`@("`O*B!)9B!T:&4@9FEL92!H87,@8F5E;B!D969L871E9"P@86YD
M('IL:6(@:7,@:6YS=&%L;&5D+`H@("`@("`@("`@("`@("!T:&5N(&EN9FQA
M=&4@=&AE(&1A=&$@86=A:6XN("HO"B`@("`@("`@("`@(')E='5R;B!`9WII
M;F9L871E*'-U8G-T<B@D9&%T82P@)&EN9F];)&ME>5U;)U]D871A4W1A<G0G
M72P@)&EN9F];)&ME>5U;)V-S:7IE)UTI*3L*("`@("`@("!](&5L<V5I9B`H
M)&EN9F];)&ME>5U;)U]M971H;V0G72`]/2`P>#`I('L*("`@("`@("`@("`@
M+RH@1FEL97,@=&AA="!A<F5N)W0@8V]M<')E<W-E9"X@*B\*("`@("`@("`@
M("`@<F5T=7)N('-U8G-T<B@D9&%T82P@)&EN9F];)&ME>5U;)U]D871A4W1A
M<G0G72P@)&EN9F];)&ME>5U;)V-S:7IE)UTI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("<G.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1O
M('-E92!I9B!T:&4@9&%T82!I<R!A('9A;&ED(%I)4"!F:6QE+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)B1D871A("!4:&4@6DE0(&9I;&4@9&%T
M82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=F%L
M:60L(&9A;'-E(&EF(&EN=F%L:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-H
M96-K6FEP1&%T82@F)&1A=&$I"B`@("!["B`@("`@("`@:68@*'-T<G!O<R@D
M9&%T82P@)'1H:7,M/E]F:6QE2&5A9&5R*2`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G1S(&$@54Y)6"!T:6UE<W1A;7`@=&\@82`T+6)Y=&4@1$]3
M(&1A=&4@86YD('1I;64@9F]R;6%T"B`@("`@*B`H9&%T92!I;B!H:6=H(#(M
M8GET97,L('1I;64@:6X@;&]W(#(M8GET97,@86QL;W=I;F<@;6%G;FET=61E
M"B`@("`@*B!C;VUP87)I<V]N*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=6YI>'1I;64@
M(%1H92!C=7)R96YT(%5.25@@=&EM97-T86UP+@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT96=E<B`@5&AE(&-U<G)E;G0@9&%T92!I;B!A(#0M8GET92!$
M3U,@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=6YI>#)$3U-4:6UE
M*"1U;FEX=&EM92`](&YU;&PI"B`@("!["B`@("`@("`@)'1I;65A<G)A>2`]
M("AI<U]N=6QL*"1U;FEX=&EM92DI(#\@9V5T9&%T92@I(#H@9V5T9&%T92@D
M=6YI>'1I;64I.PH*("`@("`@("!I9B`H)'1I;65A<G)A>5LG>65A<B==(#P@
M,3DX,"D@>PH@("`@("`@("`@("`D=&EM96%R<F%Y6R=Y96%R)UT@("`@/2`Q
M.3@P.PH@("`@("`@("`@("`D=&EM96%R<F%Y6R=M;VXG72`@("`@/2`Q.PH@
M("`@("`@("`@("`D=&EM96%R<F%Y6R=M9&%Y)UT@("`@/2`Q.PH@("`@("`@
M("`@("`D=&EM96%R<F%Y6R=H;W5R<R==("`@/2`P.PH@("`@("`@("`@("`D
M=&EM96%R<F%Y6R=M:6YU=&5S)UT@/2`P.PH@("`@("`@("`@("`D=&EM96%R
M<F%Y6R=S96-O;F1S)UT@/2`P.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("@H)'1I;65A<G)A>5LG>65A<B==("T@,3DX,"D@/#P@,C4I('P*("`@("`@
M("`@("`@("`@("@D=&EM96%R<F%Y6R=M;VXG72`\/"`R,2D@?`H@("`@("`@
M("`@("`@("`@*"1T:6UE87)R87E;)VUD87DG72`\/"`Q-BD@?`H@("`@("`@
M("`@("`@("`@*"1T:6UE87)R87E;)VAO=7)S)UT@/#P@,3$I('P*("`@("`@
M("`@("`@("`@("@D=&EM96%R<F%Y6R=M:6YU=&5S)UT@/#P@-2D@?`H@("`@
M("`@("`@("`@("`@*"1T:6UE87)R87E;)W-E8V]N9',G72`^/B`Q*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@82`B9FEL92(@=&\@=&AE(%I)4"!A
M<F-H:79E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`F)&9I;&4@("`@("!3964@2&]R9&5?0V]M
M<')E<W-?>FEP.CIC<F5A=&5::7!&:6QE*"DN"B`@("`@*B!`<&%R86T@87)R
M87D@)B1C;VYT96YT<R`@06X@87)R87D@;V8@97AI<W1I;F<@>FEP<&5D(&9I
M;&5S+@H@("`@("H@0'!A<F%M(&%R<F%Y("8D8W1R;&1I<B`@($%N(&%R<F%Y
M(&]F(&-E;G1R86P@9&ER96-T;W)Y(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?861D5&]:25!&:6QE*"8D9FEL92P@)B1C;VYT96YT<RP@
M)B1C=')L9&ER*0H@("`@>PH@("`@("`@("1D871A(#T@)B1F:6QE6R=D871A
M)UT["B`@("`@("`@)&YA;64@/2!S=')?<F5P;&%C92@G7%PG+"`G+R<L("1F
M:6QE6R=N86UE)UTI.PH*("`@("`@("`O*B!3964@:68@=&EM92]D871E(&EN
M9F]R;6%T:6]N(&AA<R!B965N('!R;W9I9&5D+B`J+PH@("`@("`@("1F=&EM
M92`](&YU;&P["B`@("`@("`@:68@*&ES<V5T*"1F:6QE6R=T:6UE)UTI*2![
M"B`@("`@("`@("`@("1F=&EM92`]("1F:6QE6R=T:6UE)UT["B`@("`@("`@
M?0H*("`@("`@("`O*B!'970@=&AE(&AE>"!T:6UE+B`J+PH@("`@("`@("1D
M=&EM92`@("`](&1E8VAE>"@D=&AI<RT^7W5N:7@R1&]S5&EM92@D9G1I;64I
M*3L*("`@("`@("`D:&5X9'1I;64@/2!C:'(H:&5X9&5C*"1D=&EM95LV72`N
M("1D=&EM95LW72DI("X*("`@("`@("`@("`@("`@("`@("!C:'(H:&5X9&5C
M*"1D=&EM95LT72`N("1D=&EM95LU72DI("X*("`@("`@("`@("`@("`@("`@
M("!C:'(H:&5X9&5C*"1D=&EM95LR72`N("1D=&EM95LS72DI("X*("`@("`@
M("`@("`@("`@("`@("!C:'(H:&5X9&5C*"1D=&EM95LP72`N("1D=&EM95LQ
M72DI.PH*("`@("`@("`D9G(@(#T@)'1H:7,M/E]F:6QE2&5A9&5R.R`@("\J
M($)E9VEN(&-R96%T:6YG('1H92!:25`@9&%T82X@*B\*("`@("`@("`D9G(@
M+CT@(EQX,31<>#`P(CL@("`@("`@("`@("\J(%9E<G-I;VX@;F5E9&5D('1O
M(&5X=')A8W0N("HO"B`@("`@("`@)&9R("X](")<>#`P7'@P,"([("`@("`@
M("`@("`O*B!'96YE<F%L('!U<G!O<V4@8FET(&9L86<N("HO"B`@("`@("`@
M)&9R("X](")<>#`X7'@P,"([("`@("`@("`@("`O*B!#;VUP<F5S<VEO;B!M
M971H;V0N("HO"B`@("`@("`@)&9R("X]("1H97AD=&EM93L@("`@("`@("`@
M("`O*B!,87-T(&UO9&EF:6-A=&EO;B!T:6UE+V1A=&4N("HO"@H@("`@("`@
M("\J("),;V-A;"!F:6QE(&AE861E<B(@<V5G;65N="X@*B\*("`@("`@("`D
M=6YC7VQE;B`]('-T<FQE;B@D9&%T82D["B`@("`@("`@)&-R8R`@("`@/2!C
M<F,S,B@D9&%T82D["B`@("`@("`@)'ID871A("`@/2!G>F-O;7!R97-S*"1D
M871A*3L*("`@("`@("`D>F1A=&$@("`]('-U8G-T<BAS=6)S='(H)'ID871A
M+"`P+"!S=')L96XH)'ID871A*2`M(#0I+"`R*3L*("`@("`@("`D8U]L96X@
M("`]('-T<FQE;B@D>F1A=&$I.PH*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L
M("1C<F,I.R`@("`@("`@("`@("\J($-20R`S,B!I;F9O<FUA=&EO;BX@*B\*
M("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1C7VQE;BD[("`@("`@("`@("\J
M($-O;7!R97-S960@9FEL97-I>F4N("HO"B`@("`@("`@)&9R("X]('!A8VLH
M)U8G+"`D=6YC7VQE;BD[("`@("`@("`O*B!5;F-O;7!R97-S960@9FEL97-I
M>F4N("HO"B`@("`@("`@)&9R("X]('!A8VLH)W8G+"!S=')L96XH)&YA;64I
M*3L@("`O*B!,96YG=&@@;V8@9FEL96YA;64N("HO"B`@("`@("`@)&9R("X]
M('!A8VLH)W8G+"`P*3L@("`@("`@("`@("`@("`O*B!%>'1R82!F:65L9"!L
M96YG=&@N("HO"B`@("`@("`@)&9R("X]("1N86UE.R`@("`@("`@("`@("`@
M("`@("`@("`O*B!&:6QE(&YA;64N("HO"@H@("`@("`@("\J(")&:6QE(&1A
M=&$B('-E9VUE;G0N("HO"B`@("`@("`@)&9R("X]("1Z9&%T83L*"B`@("`@
M("`@+RH@(D1A=&$@9&5S8W)I<'1O<B(@<V5G;65N="`H;W!T:6]N86P@8G5T
M(&YE8V5S<V%R>2!I9B!A<F-H:79E(&ES"B`@("`@("`@("`@;F]T('-E<G9E
M9"!A<R!F:6QE*2X@*B\*("`@("`@("`D9G(@+CT@<&%C:R@G5B<L("1C<F,I
M.PH@("`@("`@("1F<B`N/2!P86-K*"=6)RP@)&-?;&5N*3L*("`@("`@("`D
M9G(@+CT@<&%C:R@G5B<L("1U;F-?;&5N*3L*"B`@("`@("`@+RH@061D('1H
M:7,@96YT<GD@=&\@87)R87DN("HO"B`@("`@("`@)&]L9%]O9F9S970@/2!S
M=')L96XH:6UP;&]D92@G)RP@)&-O;G1E;G1S*2D["B`@("`@("`@)&-O;G1E
M;G1S6UT@/2`F)&9R.PH*("`@("`@("`O*B!!9&0@=&\@8V5N=')A;"!D:7)E
M8W1O<GD@<F5C;W)D+B`J+PH@("`@("`@("1C9')E8R`@/2`D=&AI<RT^7V-T
M<FQ$:7)(96%D97(["B`@("`@("`@)&-D<F5C("X](")<>#`P7'@P,"([("`@
M("`@("`@("`@("`@("\J(%9E<G-I;VX@;6%D92!B>2X@*B\*("`@("`@("`D
M8V1R96,@+CT@(EQX,31<>#`P(CL@("`@("`@("`@("`@("`@+RH@5F5R<VEO
M;B!N965D960@=&\@97AT<F%C="`J+PH@("`@("`@("1C9')E8R`N/2`B7'@P
M,%QX,#`B.R`@("`@("`@("`@("`@("`O*B!'96YE<F%L('!U<G!O<V4@8FET
M(&9L86<@*B\*("`@("`@("`D8V1R96,@+CT@(EQX,#A<>#`P(CL@("`@("`@
M("`@("`@("`@+RH@0V]M<')E<W-I;VX@;65T:&]D("HO"B`@("`@("`@)&-D
M<F5C("X]("1H97AD=&EM93L@("`@("`@("`@("`@("`@("\J($QA<W0@;6]D
M('1I;64O9&%T92X@*B\*("`@("`@("`D8V1R96,@+CT@<&%C:R@G5B<L("1C
M<F,I.R`@("`@("`@("`@+RH@0U)#(#,R(&EN9F]R;6%T:6]N+B`J+PH@("`@
M("`@("1C9')E8R`N/2!P86-K*"=6)RP@)&-?;&5N*3L@("`@("`@("`O*B!#
M;VUP<F5S<V5D(&9I;&5S:7IE+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K
M*"=6)RP@)'5N8U]L96XI.R`@("`@("`O*B!5;F-O;7!R97-S960@9FEL97-I
M>F4N("HO"B`@("`@("`@)&-D<F5C("X]('!A8VLH)W8G+"!S=')L96XH)&YA
M;64I*3L@("\J($QE;F=T:"!O9B!F:6QE;F%M92X@*B\*("`@("`@("`D8V1R
M96,@+CT@<&%C:R@G=B<L(#`I.R`@("`@("`@("`@("`@+RH@17AT<F$@9FEE
M;&0@;&5N9W1H+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=V)RP@,"D[
M("`@("`@("`@("`@("`O*B!&:6QE(&-O;6UE;G0@;&5N9W1H+B`J+PH@("`@
M("`@("1C9')E8R`N/2!P86-K*"=V)RP@,"D[("`@("`@("`@("`@("`O*B!$
M:7-K(&YU;6)E<B!S=&%R="X@*B\*("`@("`@("`D8V1R96,@+CT@<&%C:R@G
M=B<L(#`I.R`@("`@("`@("`@("`@+RH@26YT97)N86P@9FEL92!A='1R:6)U
M=&5S+B`J+PH@("`@("`@("1C9')E8R`N/2!P86-K*"=6)RP@,S(I.R`@("`@
M("`@("`@("`O*B!%>'1E<FYA;"!F:6QE(&%T=')I8G5T97,@+0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G87)C
M:&EV92<@8FET('-E="X@*B\*("`@("`@("`D8V1R96,@+CT@<&%C:R@G5B<L
M("1O;&1?;V9F<V5T*3L@("`@+RH@4F5L871I=F4@;V9F<V5T(&]F(&QO8V%L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&AE861E<BX@*B\*("`@("`@("`D8V1R96,@+CT@)&YA;64[("`@("`@
M("`@("`@("`@("`@("`@+RH@1FEL92!N86UE+B`J+PH@("`@("`@("\J($]P
M=&EO;F%L(&5X=')A(&9I96QD+"!F:6QE(&-O;6UE;G0@9V]E<R!H97)E+B`J
M+PH*("`@("`@("`O+R!3879E('1O(&-E;G1R86P@9&ER96-T;W)Y(&%R<F%Y
M+B`J+PH@("`@("`@("1C=')L9&ER6UT@/2`F)&-D<F5C.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E<R!T:&4@6DE0(&9I;&4N"B`@("`@*B!/9F9I
M8VEA;"!:25`@9FEL92!F;W)M870Z(&AT='`Z+R]W=W<N<&MW87)E+F-O;2]A
M<'!N;W1E+G1X=`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@6DE0(&9I;&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5:25!&:6QE*"8D8V]N=&5N=',L("8D
M8W1R;$1I<BD*("`@('L*("`@("`@("`D9&%T82`](&EM<&QO9&4H)R<L("1C
M;VYT96YT<RD["B`@("`@("`@)&1I<B`](&EM<&QO9&4H)R<L("1C=')L1&ER
M*3L*"B`@("`@("`@<F5T=7)N("1D871A("X@)&1I<B`N("1T:&ES+3Y?8W1R
M;$1I<D5N9"`N"B`@("`@("`@("`@("\J(%1O=&%L(",@;V8@96YT<FEE<R`B
M;VX@=&AI<R!D:7-K(BX@*B\*("`@("`@("`@("`@<&%C:R@G=B<L(&-O=6YT
M*"1C=')L1&ER*2D@+@H@("`@("`@("`@("`O*B!4;W1A;"`C(&]F(&5N=')I
M97,@;W9E<F%L;"X@*B\*("`@("`@("`@("`@<&%C:R@G=B<L(&-O=6YT*"1C
M=')L1&ER*2D@+@H@("`@("`@("`@("`O*B!3:7IE(&]F(&-E;G1R86P@9&ER
M96-T;W)Y+B`J+PH@("`@("`@("`@("!P86-K*"=6)RP@<W1R;&5N*"1D:7(I
M*2`N"B`@("`@("`@("`@("\J($]F9G-E="!T;R!S=&%R="!O9B!C96YT<F%L
M(&1I<BX@*B\*("`@("`@("`@("`@<&%C:R@G5B<L('-T<FQE;B@D9&%T82DI
M("X*("`@("`@("`@("`@+RH@6DE0(&9I;&4@8V]M;65N="!L96YG=&@N("HO
M"B`@("`@("`@("`@(")<>#`P7'@P,"(["B`@("!]"@I]"@``````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O=&%R+G!H<```````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<W-30@,3`U,34T,S0Q-#`@,#(R-#0V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E<W-?=&%R(&-L87-S(&%L;&]W
M<R!T87(@9FEL97,@=&\@8F4@<F5A9"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO0V]M<')E<W,O0V]M<')E<W,O=&%R+G!H<"QV(#$N-"XQ,BXY(#(P,#8O
M,#0O,S`@,C(Z,C@Z,CD@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O
M+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\
M<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA
M;&PN8V\N;GH^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7T-O;7!R97-S"B`J+PIC;&%S<R!(;W)D95]#
M;VUP<F5S<U]T87(@97AT96YD<R!(;W)D95]#;VUP<F5S<R!["@H@("`@+RHJ
M"B`@("`@*B!487(@9FEL92!T>7!E<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W1Y<&5S(#T@87)R87DH"B`@("`@("`@
M,'@P("`@/3X@("=5;FEX(&9I;&4G+`H@("`@("`@(#!X,S`@(#T^("`G1FEL
M92<L"B`@("`@("`@,'@S,2`@/3X@("=,:6YK)RP*("`@("`@("`P>#,R("`]
M/B`@)U-Y;6)O;&EC(&QI;FLG+`H@("`@("`@(#!X,S,@(#T^("`G0VAA<F%C
M=&5R('-P96-I86P@9FEL92<L"B`@("`@("`@,'@S-"`@/3X@("=";&]C:R!S
M<&5C:6%L(&9I;&4G+`H@("`@("`@(#!X,S4@(#T^("`G1&ER96-T;W)Y)RP*
M("`@("`@("`P>#,V("`]/B`@)T9)1D\@<W!E8VEA;"!F:6QE)RP*("`@("`@
M("`P>#,W("`]/B`@)T-O;G1I9W5O=7,@9FEL92<*("`@("D["@H@("`@+RHJ
M"B`@("`@*B!487(@9FEL92!F;&%G<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7V9L86=S(#T@87)R87DH"B`@("`@("`@
M)T9415A4)R`@("`@/3X@(#!X,#$L"B`@("`@("`@)T9(0U)#)R`@("`@/3X@
M(#!X,#(L"B`@("`@("`@)T9%6%1202<@("`@/3X@(#!X,#0L"B`@("`@("`@
M)T9.04U%)R`@("`@/3X@(#!X,#@L"B`@("`@("`@)T9#3TU-14Y4)R`@/3X@
M(#!X,3`*("`@("D["@H@("`@+RHJ"B`@("`@*B!$96-O;7!R97-S(&$@=&%R
M(&9I;&4@86YD(&=E="!I;F9O<FUA=&EO;B!F<F]M(&ET+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)B1D871A("`@5&AE('1A<B!F:6QE(&1A=&$N
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E<B!A
M<G)A>2`H56YU<V5D*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4
M:&4@<F5Q=65S=&5D(&1A=&$@;W(@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@
M("`J(#QP<F4^"B`@("`@*B!+15DZ(%!O<VET:6]N(&EN('1H92!A<G)A>0H@
M("`@("H@5D%,5453.B`G871T<B<@("TM("!&:6QE(&%T=')I8G5T97,*("`@
M("`J("`@("`@("`@)V1A=&$G("`M+2`@4F%W(&9I;&4@8V]N=&5N=',*("`@
M("`J("`@("`@("`@)V1A=&4G("`M+2`@1FEL92!M;V1I9FEC871I;VX@=&EM
M90H@("`@("H@("`@("`@("`G;F%M92<@("TM("!&:6QE;F%M90H@("`@("H@
M("`@("`@("`G<VEZ92<@("TM("!/<FEG:6YA;"!F:6QE('-I>F4*("`@("`J
M("`@("`@("`@)W1Y<&4G("`M+2`@1FEL92!T>7!E"B`@("`@*B`\+W!R93X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;VUP<F5S<R@F)&1A=&$L("1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1P;W-I=&EO;B`](#`["B`@
M("`@("`@)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE
M("@D<&]S:71I;VX@/"!S=')L96XH)&1A=&$I*2!["B`@("`@("`@("`@("1I
M;F9O(#T@0'5N<&%C:R@B83$P,&9I;&5N86UE+V$X;6]D92]A.'5I9"]A.&=I
M9"]A,3)S:7IE+V$Q,FUT:6UE+V$X8VAE8VMS=6TO0W1Y<&5F;&%G+V$Q,#!L
M:6YK+V$V;6%G:6,O83)V97)S:6]N+V$S,G5N86UE+V$S,F=N86UE+V$X9&5V
M;6%J;W(O83AD979M:6YO<B(L('-U8G-T<B@D9&%T82P@)'!O<VET:6]N*2D[
M"B`@("`@("`@("`@(&EF("@A)&EN9F\I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96-O;7!R97-S
M(&1A=&$N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&]S:71I
M;VX@*ST@-3$R.PH@("`@("`@("`@("`D8V]N=&5N=',@/2!S=6)S='(H)&1A
M=&$L("1P;W-I=&EO;BP@;V-T9&5C*"1I;F9O6R=S:7IE)UTI*3L*("`@("`@
M("`@("`@)'!O<VET:6]N("L](&-E:6PH;V-T9&5C*"1I;F9O6R=S:7IE)UTI
M("\@-3$R*2`J(#4Q,CL*"B`@("`@("`@("`@(&EF("@D:6YF;ULG9FEL96YA
M;64G72D@>PH@("`@("`@("`@("`@("`@)&9I;&4@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`G871T<B<@/3X@;G5L;"P*("`@("`@("`@("`@("`@
M("`@("`G9&%T82<@/3X@;G5L;"P*("`@("`@("`@("`@("`@("`@("`G9&%T
M92<@/3X@;V-T9&5C*"1I;F9O6R=M=&EM92==*2P*("`@("`@("`@("`@("`@
M("`@("`G;F%M92<@/3X@=')I;2@D:6YF;ULG9FEL96YA;64G72DL"B`@("`@
M("`@("`@("`@("`@("`@)W-I>F4G(#T^(&]C=&1E8R@D:6YF;ULG<VEZ92==
M*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@:7-S970H)'1H:7,M
M/E]T>7!E<ULD:6YF;ULG='EP969L86<G75TI(#\@)'1H:7,M/E]T>7!E<ULD
M:6YF;ULG='EP969L86<G75T@.B!N=6QL"B`@("`@("`@("`@("`@("`I.PH*
M("`@("`@("`@("`@("`@(&EF("@H)&EN9F];)W1Y<&5F;&%G)UT@/3T@,"D@
M?'P*("`@("`@("`@("`@("`@("`@("`H)&EN9F];)W1Y<&5F;&%G)UT@/3T@
M,'@S,"D@?'P*("`@("`@("`@("`@("`@("`@("`H)&EN9F];)W1Y<&5F;&%G
M)UT@/3T@,'@S-2DI('L*("`@("`@("`@("`@("`@("`@("`O*B!&:6QE(&]R
M(&9O;&1E<BX@*B\*("`@("`@("`@("`@("`@("`@("`D9FEL95LG9&%T82==
M(#T@)&-O;G1E;G1S.PH*("`@("`@("`@("`@("`@("`@("`D;6]D92`](&AE
M>&1E8RAS=6)S='(H)&EN9F];)VUO9&4G72P@-"P@,RDI.PH@("`@("`@("`@
M("`@("`@("`@("1F:6QE6R=A='1R)UT@/0H@("`@("`@("`@("`@("`@("`@
M("`@("`H*"1I;F9O6R=T>7!E9FQA9R==(#T](#!X,S4I(#\@)V0G(#H@)RTG
M*2`N"B`@("`@("`@("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P>#0P,"D@
M/R`G<B<@.B`G+2<I("X*("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D
M92`F(#!X,C`P*2`_("=W)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@
M("`@("`H*"1M;V1E("8@,'@Q,#`I(#\@)W@G(#H@)RTG*2`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("@H)&UO9&4@)B`P>#`T,"D@/R`G<B<@.B`G+2<I
M("X*("`@("`@("`@("`@("`@("`@("`@("`@*"@D;6]D92`F(#!X,#(P*2`_
M("=W)R`Z("<M)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E
M("8@,'@P,3`I(#\@)W@G(#H@)RTG*2`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("@H)&UO9&4@)B`P>#`P-"D@/R`G<B<@.B`G+2<I("X*("`@("`@("`@
M("`@("`@("`@("`@("`@*"@D;6]D92`F(#!X,#`R*2`_("=W)R`Z("<M)RD@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`H*"1M;V1E("8@,'@P,#$I(#\@
M)W@G(#H@)RTG*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@+RH@4V]M92!O=&AE<B!T>7!E+B`J+PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@("1R971U<FY?87)R87E;72`]("1F
M:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E='5R;E]A<G)A>3L*("`@('T*"GT*``````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0V]M<')E<W,O9WII
M<"YP:'``````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4T,3,@
M,3`U,34T,S0Q-#`@,#(R-C$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?0V]M<')E
M<W-?9WII<"!C;&%S<R!A;&QO=W,@9WII<"!F:6QE<R!T;R!B92!R96%D+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP<F5S<R]#;VUP<F5S<R]G>FEP
M+G!H<"QV(#$N-RXQ,BXY(#(P,#8O,#0O,S`@,C(Z,C@Z,CD@8VAU8VL@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L($-O8VAR86YE
M(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,RTR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!A=71H;W(@($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-O;7!R
M97-S"B`J+PIC;&%S<R!(;W)D95]#;VUP<F5S<U]G>FEP(&5X=&5N9',@2&]R
M9&5?0V]M<')E<W,@>PH*("`@("\J*@H@("`@("H@1WII<"!F:6QE(&9L86=S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M9FQA9W,@/2!A<G)A>2@*("`@("`@("`G1E1%6%0G("`@("`]/B`@,'@P,2P*
M("`@("`@("`G1DA#4D,G("`@("`]/B`@,'@P,BP*("`@("`@("`G1D585%)!
M)R`@("`]/B`@,'@P-"P*("`@("`@("`G1DY!344G("`@("`]/B`@,'@P."P*
M("`@("`@("`G1D-/34U%3E0G("`]/B`@,'@Q,`H@("`@*3L*"B`@("`O*BH*
M("`@("`J($1E8V]M<')E<W,@82!G>FEP(&9I;&4@86YD(&=E="!I;F9O<FUA
M=&EO;B!F<F]M(&ET+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D
M871A("!4:&4@=&%R(&9I;&4@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D
M<&%R86US("!4:&4@<&%R86UE=&5R(&%R<F%Y("A5;G5S960I+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=6YC;VUP<F5S<V5D(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]M<')E<W,H)B1D871A+"`D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`O*B!)9B!G>FEP(&ES(&YO
M="!C;VUP:6QE9"!I;G1O(%!(4"P@<F5T=7)N(&YO=RX@*B\*("`@("`@("!I
M9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>FQI8B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H:7,@<V5R=F5R(&-A
M;B=T('5N8V]M<')E<W,@>FEP(&%N9"!G>FEP(&9I;&5S+B(I*3L*("`@("`@
M("!]"@H@("`@("`@("\J($=Z:7!P960@1FEL92`M(&1E8V]M<')E<W,@:70@
M9FER<W0N("HO"B`@("`@("`@)'!O<VET:6]N(#T@,#L*("`@("`@("`D:6YF
M;R`]($!U;G!A8VLH)T-#32]#1DQ'+U94:6UE+T-81DPO0T]3)RP@<W5B<W1R
M*"1D871A+"`D<&]S:71I;VX@*R`R*2D["B`@("`@("`@:68@*"$D:6YF;RD@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B
M;&4@=&\@9&5C;VUP<F5S<R!D871A+B(I*3L*("`@("`@("!]"B`@("`@("`@
M)'!O<VET:6]N("L](#$P.PH*("`@("`@("!I9B`H)&EN9F];)T9,1R==("8@
M)'1H:7,M/E]F;&%G<ULG1D585%)!)UTI('L*("`@("`@("`@("`@)%A,14X@
M/2!U;G!A8VLH)W9,96YG=&@G+"!S=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K
M(#`L(#(I*3L*("`@("`@("`@("`@)%A,14X@/2`D6$Q%3ELG3&5N9W1H)UT[
M"B`@("`@("`@("`@("1P;W-I=&EO;B`K/2`D6$Q%3B`K(#(["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&EN9F];)T9,1R==("8@)'1H:7,M/E]F;&%G<ULG
M1DY!344G72D@>PH@("`@("`@("`@("`D9FEL96YA;650;W,@/2!S=')P;W,H
M)&1A=&$L(")<>#`B+"`D<&]S:71I;VXI.PH@("`@("`@("`@("`D9FEL96YA
M;64@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO;BP@)&9I;&5N86UE4&]S("T@
M)'!O<VET:6]N*3L*("`@("`@("`@("`@)'!O<VET:6]N(#T@)&9I;&5N86UE
M4&]S("L@,3L*("`@("`@("!]"@H@("`@("`@(&EF("@D:6YF;ULG1DQ')UT@
M)B`D=&AI<RT^7V9L86=S6R=&0T]-345.5"==*2!["B`@("`@("`@("`@("1C
M;VUM96YT4&]S(#T@<W1R<&]S*"1D871A+"`B7'@P(BP@)'!O<VET:6]N*3L*
M("`@("`@("`@("`@)&-O;6UE;G0@/2!S=6)S='(H)&1A=&$L("1P;W-I=&EO
M;BP@)&-O;6UE;G10;W,@+2`D<&]S:71I;VXI.PH@("`@("`@("`@("`D<&]S
M:71I;VX@/2`D8V]M;65N=%!O<R`K(#$["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)&EN9F];)T9,1R==("8@)'1H:7,M/E]F;&%G<ULG1DA#4D,G72D@>PH@
M("`@("`@("`@("`D:&-R8R`]('5N<&%C:R@G=D-20R<L('-U8G-T<B@D9&%T
M82P@)'!O<VET:6]N("L@,"P@,BDI.PH@("`@("`@("`@("`D:&-R8R`]("1H
M8W)C6R=#4D,G73L*("`@("`@("`@("`@)'!O<VET:6]N("L](#(["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&=Z:6YF;&%T92AS=6)S='(H)&1A
M=&$L("1P;W-I=&EO;BP@<W1R;&5N*"1D871A*2`M("1P;W-I=&EO;BDI.PH@
M("`@("`@(&EF("AE;7!T>2@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5C;VUP<F5S<R!D
M871A+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]#;VUP<F5S<R]T;F5F+G!H<```````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-3,R-"`Q,#4Q-30S-#$T,"`P,C(V
M,#4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"F1E9FEN92@G5$Y%1E]324=.05154D4G+"`@("`@(#!X,C(S93EF
M-S@I.PID969I;F4H)U1.149?3%9,7TU%4U-!1T4G+"`@("`P>#`Q*3L*9&5F
M:6YE*"=43D5&7TQ63%]!5%1!0TA-14Y4)RP@,'@P,BD["@ID969I;F4H)U1.
M149?4U1224Y')RP@,'@P,#`Q,#`P,"D["F1E9FEN92@G5$Y%1E]"651%)RP@
M("`P>#`P,#8P,#`P*3L*9&5F:6YE*"=43D5&7U=/4D0G+"`@(#!X,#`P-S`P
M,#`I.PID969I;F4H)U1.149?1%=/4D0G+"`@,'@P,#`X,#`P,"D["@ID969I
M;F4H)U1.149?05-50DI%0U0G+"`@(%1.149?1%=/4D0@('P@,'@X,#`T*3L*
M9&5F:6YE*"=43D5&7T%-0TQ!4U,G+"`@("!43D5&7U=/4D0@("!\(#!X.#`P
M."D["F1E9FEN92@G5$Y%1E]!5%1!0TA$051!)RP@5$Y%1E]"651%("`@?"`P
M>#@P,&8I.PID969I;F4H)U1.149?049)3$5.04U%)RP@(%1.149?4U1224Y'
M('P@,'@X,#$P*3L*9&5F:6YE*"=43D5&7T%214Y$1$%402<L("!43D5&7T)9
M5$4@("!\(#!X.3`P,BD["F1E9FEN92@G5$Y%1E]!34%024%45%)3)RP@5$Y%
M1E]"651%("`@?"`P>#DP,#4I.PID969I;F4H)U1.149?059%4E-)3TXG+"`@
M(%1.149?1%=/4D0@('P@,'@Y,#`V*3L*"F1E9FEN92@G5$Y%1E]-05!)7TY5
M3$PG+"`@("`@("`@("`@,'@P,#`Q*3L*9&5F:6YE*"=43D5&7TU!4$E?4TA/
M4E0G+"`@("`@("`@("`P>#`P,#(I.PID969I;F4H)U1.149?34%025])3E0G
M+"`@("`@("`@("`@(#!X,#`P,RD["F1E9FEN92@G5$Y%1E]-05!)7T9,3T%4
M)RP@("`@("`@("`@,'@P,#`T*3L*9&5F:6YE*"=43D5&7TU!4$E?1$]50DQ%
M)RP@("`@("`@("`P>#`P,#4I.PID969I;F4H)U1.149?34%025]#55)214Y#
M62<L("`@("`@(#!X,#`P-BD["F1E9FEN92@G5$Y%1E]-05!)7T%04%1)344G
M+"`@("`@("`@,'@P,#`W*3L*9&5F:6YE*"=43D5&7TU!4$E?15)23U(G+"`@
M("`@("`@("`P>#`P,&$I.PID969I;F4H)U1.149?34%025]"3T],14%.)RP@
M("`@("`@(#!X,#`P8BD["F1E9FEN92@G5$Y%1E]-05!)7T]"2D5#5"<L("`@
M("`@("`@,'@P,#!D*3L*9&5F:6YE*"=43D5&7TU!4$E?24Y4.$)95$4G+"`@
M("`@("`P>#`P,30I.PID969I;F4H)U1.149?34%025]35%))3D<G+"`@("`@
M("`@(#!X,#`Q92D["F1E9FEN92@G5$Y%1E]-05!)7U5.24-/1$5?4U1224Y'
M)RP@,'@P,#%F*3L*9&5F:6YE*"=43D5&7TU!4$E?4UE35$E-12<L("`@("`@
M("`P>#`P-#`I.PID969I;F4H)U1.149?34%025]#3%-)1"<L("`@("`@("`@
M(#!X,#`T."D["F1E9FEN92@G5$Y%1E]-05!)7T))3D%262<L("`@("`@("`@
M,'@P,3`R*3L*"F1E9FEN92@G5$Y%1E]-05!)7T%45$%#2%],3TY'7T9)3$5.
M04U%)RP@,'@S-S`W*3L*9&5F:6YE*"=43D5&7TU!4$E?051404-(7TU)345?
M5$%')RP@("`@("`P>#,W,$4I.PH*9&5F:6YE*"=43D5&7TU!4$E?3D%-141?
M5%E015])1"<L("`@("`P>#`P,#`I.PID969I;F4H)U1.149?34%025].04U%
M1%]465!%7U-44DE.1R<L(#!X,#`P,2D["F1E9FEN92@G5$Y%1E]-05!)7TU6
M7T9,04<G+"`@("`@("`@("`@,'@Q,#`P*3L*"B\J*@H@*B!4:&4@2&]R9&5?
M0V]M<')E<W-?=&YE9B!C;&%S<R!A;&QO=W,@35,M5$Y%1B!D871A('1O(&)E
M(&1I<W!L87EE9"X*("H*("H@5&AE(%1.148@<F5N9&5R:6YG(&ES(&)A<V5D
M(&]N(&-O9&4@8GDZ"B`J("`@1W)A:&%M($YO<F)U<GD@/&=N;W)B=7)Y0&)O
M;F1C87(N8V]M/@H@*B!/<FEG:6YA;"!D97-I9VX@8GDZ"B`J("`@5&AO;6%S
M($)O;&P@/'1B0&)O;&PN8V@^+"!-87)K(%-I;7!S;VX@/&1A;6YE9$!W;W)L
M9"YS=&0N8V]M/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]#;VUP<F5S<R]#
M;VUP<F5S<R]T;F5F+G!H<"QV(#$N-BXQ,BXY(#(P,#8O,#$O,#$@,C$Z,C@Z
M,3$@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE
M9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R
M(#QJ86Y`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]#;VUP<F5S<PH@*B\*8VQA<W,@
M2&]R9&5?0V]M<')E<W-?=&YE9B!E>'1E;F1S($AO<F1E7T-O;7!R97-S('L*
M"B`@("`O*BH*("`@("`J($1E8V]M<')E<W,@=&AE(&1A=&$N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D871A('1O(&1E8V]M
M<')E<W,N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@
M;V8@87)G=6UE;G1S(&YE961E9"!T;R!D96-O;7!R97-S('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(&1A=&$N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&1E8V]M<')E<W-E9"!D871A+@H@("`@("H@("`@
M("`@("`@("`@("`@4F5T=7)N<R!A(%!%05)?17)R;W(@;V)J96-T(&]N(&5R
M<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-O;7!R97-S*"1D871A+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D;W5T(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I(#T](%1.
M149?4TE'3D%455)%*2!["B`@("`@("`@("`@("1T:&ES+3Y?9V5T:2@D9&%T
M82P@,38I.PH*("`@("`@("`@("`@=VAI;&4@*'-T<FQE;B@D9&%T82D@/B`P
M*2!["B`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9V5T:2@D9&%T
M82P@."DI('L*("`@("`@("`@("`@("`@(&-A<V4@5$Y%1E],5DQ?34534T%'
M13H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94UE<W-A9V4H
M)&1A=&$I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@("`@(&-A<V4@5$Y%1E],5DQ?051404-(345.5#H*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1E8V]D94%T=&%C:&UE;G0H)&1A=&$L("1O=70I
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R
M87E?<F5V97)S92@D;W5T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("8D9&%T82`@5&AE(&1A=&$@<W1R:6YG+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)&)I=',@($AO=R!M86YY(&)I=',@=&\@<F5T<FEE
M=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!43T1/"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]G971X*"8D9&%T82P@)&)I=',I"B`@("!["B`@("`@("`@)'9A
M;'5E(#T@;G5L;#L*"B`@("`@("`@:68@*'-T<FQE;B@D9&%T82D@/CT@)&)I
M=',I('L*("`@("`@("`@("`@)'9A;'5E(#T@<W5B<W1R*"1D871A+"`P+"`D
M8FET<RD["B`@("`@("`@("`@("1D871A(#T@<W5B<W1R7W)E<&QA8V4H)&1A
M=&$L("<G+"`P+"`D8FET<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)B1D871A("!4:&4@9&%T82!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D8FET<R`@2&]W(&UA;GD@8FET<R!T;R!R971R:65V92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=&DH)B1D871A+"`D8FET<RD*("`@('L*("`@("`@("`D8GET97,@/2`D8FET
M<R`O(#@["B`@("`@("`@)'9A;'5E(#T@;G5L;#L*"B`@("`@("`@:68@*'-T
M<FQE;B@D9&%T82D@/CT@)&)Y=&5S*2!["B`@("`@("`@("`@("1V86QU92`]
M(&]R9"@D9&%T85LP72D["B`@("`@("`@("`@(&EF("@D8GET97,@/CT@,BD@
M>PH@("`@("`@("`@("`@("`@)'9A;'5E("L]("AO<F0H)&1A=&%;,5TI(#P\
M(#@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D8GET97,@/CT@
M-"D@>PH@("`@("`@("`@("`@("`@)'9A;'5E("L]("AO<F0H)&1A=&%;,ETI
M(#P\(#$V*2`K("AO<F0H)&1A=&%;,UTI(#P\(#(T*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D9&%T82`]('-U8G-T<E]R97!L86-E*"1D871A+"`G
M)RP@,"P@)&)Y=&5S*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=F%L
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`F
M)&1A=&$@("`@("!4:&4@9&%T82!S=')I;F<N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A='1R:6)U=&4@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E
M8V]D94%T=')I8G5T92@F)&1A=&$L("1A='1R:6)U=&4I"B`@("!["B`@("`@
M("`@+RH@1&%T82X@*B\*("`@("`@("`D=&AI<RT^7V=E='@H)&1A=&$L("1T
M:&ES+3Y?9V5T:2@D9&%T82P@,S(I*3L*"B`@("`@("`@+RH@0VAE8VMS=6TN
M("HO"B`@("`@("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("`@
M("`@("!4:&4@9&%T82!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)B1A
M='1A8VAM96YT7V1A=&$@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7V5X
M=')A8W1-87!I071T<FEB=71E<R@D9&%T82P@)B1A='1A8VAM96YT7V1A=&$I
M"B`@("!["B`@("`@("`@+RH@3G5M8F5R(&]F(&%T=')I8G5T97,N("HO"B`@
M("`@("`@)&YU;6)E<B`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH*("`@
M("`@("!W:&EL92`H*'-T<FQE;B@D9&%T82D@/B`P*2`F)B`D;G5M8F5R+2TI
M('L*("`@("`@("`@("`@)&AA=F5?;79A;"`](&9A;'-E.PH@("`@("`@("`@
M("`D;G5M7VUV86P@/2`Q.PH@("`@("`@("`@("`D;F%M961?:60@/2`D=F%L
M=64@/2!N=6QL.PH@("`@("`@("`@("`D871T<E]T>7!E(#T@)'1H:7,M/E]G
M971I*"1D871A+"`Q-BD["B`@("`@("`@("`@("1A='1R7VYA;64@/2`D=&AI
M<RT^7V=E=&DH)&1A=&$L(#$V*3L*"B`@("`@("`@("`@(&EF("@H)&%T=')?
M='EP92`F(%1.149?34%025]-5E]&3$%'*2`A/2`P*2!["B`@("`@("`@("`@
M("`@("`D:&%V95]M=F%L(#T@=')U93L*("`@("`@("`@("`@("`@("1A='1R
M7W1Y<&4@/2`D871T<E]T>7!E("8@?E1.149?34%025]-5E]&3$%'.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H*"1A='1R7VYA;64@/CT@,'@X
M,#`P*2`F)B`H)&%T=')?;F%M92`\(#!X1D9&12DI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9V5T>"@D9&%T82P@,38I.PH@("`@("`@("`@("`@("`@
M)&YA;65D7W1Y<&4@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*"B`@("`@
M("`@("`@("`@("!S=VET8V@@*"1N86UE9%]T>7!E*2!["B`@("`@("`@("`@
M("`@("!C87-E(%1.149?34%025].04U%1%]465!%7TE$.@H@("`@("`@("`@
M("`@("`@("`@("1N86UE9%]I9"`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I
M.PH@("`@("`@("`@("`@("`@("`@("1A='1R7VYA;64@/2`D;F%M961?:60[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92!43D5&7TU!4$E?3D%-141?5%E015]35%))3D<Z"B`@("`@("`@("`@
M("`@("`@("`@)&%T=')?;F%M92`](#!X.3DY.3L*("`@("`@("`@("`@("`@
M("`@("`D:61L96X@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*("`@("`@
M("`@("`@("`@("`@("`D9&%T86QE;B`]("1I9&QE;B`K("@H-"`M("@D:61L
M96X@)2`T*2D@)2`T*3L*("`@("`@("`@("`@("`@("`@("`D;F%M961?:60@
M/2!S=6)S='(H)'1H:7,M/E]G971X*"1D871A+"`D9&%T86QE;BDL(#`L("1I
M9&QE;BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D:&%V95]M
M=F%L*2!["B`@("`@("`@("`@("`@("`D;G5M7VUV86P@/2`D=&AI<RT^7V=E
M=&DH)&1A=&$L(#,R*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<W=I
M=&-H("@D871T<E]T>7!E*2!["B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)
M7U-(3U)4.@H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)'1H:7,M/E]G971I
M*"1D871A+"`Q-BD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@5$Y%1E]-05!)7TE.5#H*("`@("`@("`@("`@8V%S92!43D5&
M7TU!4$E?0D]/3$5!3CH*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D
M:2`\("1N=6U?;79A;#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1V
M86QU92`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(%1.149?34%025]&3$]!5#H*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?
M15)23U(Z"B`@("`@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V=E='@H
M)&1A=&$L(#0I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("!C87-E(%1.149?34%025]$3U5"3$4Z"B`@("`@("`@("`@(&-A<V4@5$Y%
M1E]-05!)7T%04%1)344Z"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T-5
M4E)%3D-9.@H@("`@("`@("`@("!C87-E(%1.149?34%025])3E0X0EE413H*
M("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?4UE35$E-13H*("`@("`@("`@
M("`@("`@("1V86QU92`]("1T:&ES+3Y?9V5T>"@D9&%T82P@."D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)
M7U-44DE.1SH*("`@("`@("`@("`@8V%S92!43D5&7TU!4$E?54Y)0T]$15]3
M5%))3D<Z"B`@("`@("`@("`@(&-A<V4@5$Y%1E]-05!)7T))3D%263H*("`@
M("`@("`@("`@8V%S92!43D5&7TU!4$E?3T)*14-4.@H@("`@("`@("`@("`@
M("`@)&YU;5]V86QS(#T@*"1H879E7VUV86PI(#\@)&YU;5]M=F%L(#H@)'1H
M:7,M/E]G971I*"1D871A+"`S,BD["B`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D;G5M7W9A;',[("1I*RLI('L*("`@("`@("`@("`@("`@
M("`@("`D;&5N9W1H(#T@)'1H:7,M/E]G971I*"1D871A+"`S,BD["@H@("`@
M("`@("`@("`@("`@("`@("\J(%!A9"!T;R!N97AT(#0@8GET92!B;W5N9&%R
M>2X@*B\*("`@("`@("`@("`@("`@("`@("`D9&%T86QE;B`]("1L96YG=&@@
M*R`H*#0@+2`H)&QE;F=T:"`E(#0I*2`E(#0I.PH*("`@("`@("`@("`@("`@
M("`@("!I9B`H)&%T=')?='EP92`]/2!43D5&7TU!4$E?4U1224Y'*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1L96YG=&@@+3T@,3L*("`@("`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J(%)E860@86YD
M('1R=6YC871E('1O(&QE;F=T:"X@*B\*("`@("`@("`@("`@("`@("`@("`D
M=F%L=64@/2!S=6)S='(H)'1H:7,M/E]G971X*"1D871A+"`D9&%T86QE;BDL
M(#`L("1L96YG=&@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%-T;W)E
M(&%N>2!I;G1E<F5S=&EN9R!A='1R:6)U=&5S+B`J+PH@("`@("`@("`@("!S
M=VET8V@@*"1A='1R7VYA;64I('L*("`@("`@("`@("`@8V%S92!43D5&7TU!
M4$E?051404-(7TQ/3D=?1DE,14Y!344Z"B`@("`@("`@("`@("`@("`O*B!5
M<V5D(&EN('!R969E<F5N8V4@=&\@049)3$5.04U%('9A;'5E+B`J+PH@("`@
M("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==(#T@<')E
M9U]R97!L86-E*"<O+BI;7"]=*"XJ*20O)RP@)UPQ)RP@)'9A;'5E*3L*("`@
M("`@("`@("`@("`@("1A='1A8VAM96YT7V1A=&%;,%U;)VYA;64G72`]('-T
M<E]R97!L86-E*")<,"(L("<G+"`D871T86-H;65N=%]D871A6S!=6R=N86UE
M)UTI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(%1.149?34%025]!5%1!0TA?34E-15]404<Z"B`@("`@("`@("`@("`@("`O
M*B!)<R!T:&ES(&5V97(@<V5T+"!A;F0@=VAA="!I<R!F;W)M870_("HO"B`@
M("`@("`@("`@("`@("`D871T86-H;65N=%]D871A6S!=6R=T>7!E)UT@/2!P
M<F5G7W)E<&QA8V4H)R]>*"XJ*5PO+BHO)RP@)UPQ)RP@)'9A;'5E*3L*("`@
M("`@("`@("`@("`@("1A='1A8VAM96YT7V1A=&%;,%U;)W-U8G1Y<&4G72`]
M('!R96=?<F5P;&%C92@G+RXJ7"\H+BHI)"\G+"`G7#$G+"`D=F%L=64I.PH@
M("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG<W5B='EP92==
M(#T@<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1A='1A8VAM96YT7V1A=&%;,%U;
M)W-U8G1Y<&4G72D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("8D9&%T82`@5&AE(&1A=&$@<W1R:6YG+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9&5C;V1E365S<V%G92@F)&1A=&$I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]D96-O9&5!='1R:6)U=&4H)&1A=&$L("1T:&ES+3Y?9V5T
M:2@D9&%T82P@,S(I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1/1$\*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("8D9&%T82`@("`@("`@("`@(%1H92!D871A('-T<FEN9RX*
M("`@("`J($!P87)A;2!A<G)A>2`F)&%T=&%C:&UE;G1?9&%T82`@5$]$3PH@
M("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E071T86-H;65N="@F)&1A=&$L
M("8D871T86-H;65N=%]D871A*0H@("`@>PH@("`@("`@("1A='1R:6)U=&4@
M/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*"B`@("`@("`@<W=I=&-H("@D
M871T<FEB=71E*2!["B`@("`@("`@8V%S92!43D5&7T%214Y$1$%403H*("`@
M("`@("`@("`@+RH@36%R:W,@<W1A<G0@;V8@;F5W(&%T=&%C:&UE;G0N("HO
M"B`@("`@("`@("`@("1T:&ES+3Y?9V5T>"@D9&%T82P@)'1H:7,M/E]G971I
M*"1D871A+"`S,BDI.PH*("`@("`@("`@("`@+RH@0VAE8VMS=6T@*B\*("`@
M("`@("`@("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["@H@("`@("`@("`@
M("`O*B!!9&0@82!N97<@9&5F875L="!D871A(&)L;V-K('1O(&AO;&0@9&5T
M86EL<R!O9B!T:&ES"B`@("`@("`@("`@("`@(&%T=&%C:&UE;G0N(%)E=F5R
M<V4@;W)D97(@:7,@96%S:65R('1O(&AA;F1L92!L871E<B$@*B\*("`@("`@
M("`@("`@87)R87E?=6YS:&EF="@D871T86-H;65N=%]D871A+"!A<G)A>2@G
M='EP92<@("`@/3X@)V%P<&QI8V%T:6]N)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W5B='EP92<@/3X@
M)V]C=&5T+7-T<F5A;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@(#T^("=U;FMN;W=N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G<W1R96%M)R`@/3X@)R<I*3L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@5$Y%1E]!1DE,14Y!344Z"B`@("`@("`@("`@("\J(%-T
M<FEP('!A=&@N("HO"B`@("`@("`@("`@("1A='1A8VAM96YT7V1A=&%;,%U;
M)VYA;64G72`]('!R96=?<F5P;&%C92@G+RXJ6UPO72@N*BDD+R<L("=<,2<L
M("1T:&ES+3Y?9V5T>"@D9&%T82P@)'1H:7,M/E]G971I*"1D871A+"`S,BDI
M*3L*("`@("`@("`@("`@)&%T=&%C:&UE;G1?9&%T85LP75LG;F%M92==(#T@
M<W1R7W)E<&QA8V4H(EPP(BP@)R<L("1A='1A8VAM96YT7V1A=&%;,%U;)VYA
M;64G72D["@H@("`@("`@("`@("`O*B!#:&5C:W-U;2`J+PH@("`@("`@("`@
M("`D=&AI<RT^7V=E=&DH)&1A=&$L(#$V*3L*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@5$Y%1E]!5%1!0TA$051!.@H@("`@("`@("`@("`O
M*B!4:&4@871T86-H;65N="!I='-E;&8N("HO"B`@("`@("`@("`@("1L96YG
M=&@@/2`D=&AI<RT^7V=E=&DH)&1A=&$L(#,R*3L*("`@("`@("`@("`@)&%T
M=&%C:&UE;G1?9&%T85LP75LG<VEZ92==(#T@)&QE;F=T:#L*("`@("`@("`@
M("`@)&%T=&%C:&UE;G1?9&%T85LP75LG<W1R96%M)UT@/2`D=&AI<RT^7V=E
M='@H)&1A=&$L("1L96YG=&@I.PH*("`@("`@("`@("`@+RH@0VAE8VMS=6T@
M*B\*("`@("`@("`@("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(%1.149?04U!4$E!5%124SH*
M("`@("`@("`@("`@)&QE;F=T:"`]("1T:&ES+3Y?9V5T:2@D9&%T82P@,S(I
M.PH@("`@("`@("`@("`D=F%L=64@/2`D=&AI<RT^7V=E='@H)&1A=&$L("1L
M96YG=&@I.PH*("`@("`@("`@("`@+RH@0VAE8VMS=6T@*B\*("`@("`@("`@
M("`@)'1H:7,M/E]G971I*"1D871A+"`Q-BD["B`@("`@("`@("`@("1T:&ES
M+3Y?97AT<F%C=$UA<&E!='1R:6)U=&5S*"1V86QU92P@)&%T=&%C:&UE;G1?
M9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`D=&AI<RT^7V1E8V]D94%T=')I8G5T92@D9&%T82P@)&%T
M=')I8G5T92D["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O0W)Y<'0O<VUI;64N<&AP````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`Q-#0U,C$@,3`U,34T,S0Q-#`@,#(R,C<R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TAO<F1E+T-R>7!T+G!H<"<["@HO*BH*("H@2&]R9&5?0W)Y<'1?
M<VUI;64Z.B!P<F]V:61E<R!A(&9R86UE=V]R:R!F;W(@2&]R9&4@87!P;&EC
M871I;VYS('1O"B`J(&EN=&5R86-T('=I=&@@=&AE($]P96Y34TP@;&EB<F%R
M>2!A;F0@:6UP;&5M96YT(%,O34E-12X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<VUI;64N<&AP+'8@,2XT.2XR+C$R(#(P,#8O,#(O
M,#,@,34Z-3(Z-34@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?0W)Y<'0*("HO"F-L87-S($AO<F1E7T-R>7!T
M7W-M:6UE(&5X=&5N9',@2&]R9&5?0W)Y<'0@>PH*("`@("\J*@H@("`@("H@
M3V)J96-T($ED96YT:69E<G,@=&\@;F%M92!A<G)A>2X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V]I9',@/2!A<G)A>2@*
M("`@("`@("`G,BXU+C0N,R<@/3X@)T-O;6UO;DYA;64G+`H@("`@("`@("<R
M+C4N-"XT)R`]/B`G4W5R;F%M92<L"B`@("`@("`@)S(N-2XT+C8G(#T^("=#
M;W5N=')Y)RP*("`@("`@("`G,BXU+C0N-R<@/3X@)TQO8V%T:6]N)RP*("`@
M("`@("`G,BXU+C0N."<@/3X@)U-T871E3W)0<F]V:6YC92<L"B`@("`@("`@
M)S(N-2XT+CDG(#T^("=3=')E971!9&1R97-S)RP*("`@("`@("`G,BXU+C0N
M,3`G(#T^("=/<F=A;FES871I;VXG+`H@("`@("`@("<R+C4N-"XQ,2<@/3X@
M)T]R9V%N:7-A=&EO;F%L56YI="<L"B`@("`@("`@)S(N-2XT+C$R)R`]/B`G
M5&ET;&4G+`H@("`@("`@("<R+C4N-"XR,"<@/3X@)U1E;&5P:&]N94YU;6)E
M<B<L"B`@("`@("`@)S(N-2XT+C0R)R`]/B`G1VEV96Y.86UE)RP*"B`@("`@
M("`@)S(N-2XR.2XQ-"<@/3X@)VED+6-E+7-U8FIE8W1+97E)9&5N=&EF:65R
M)RP*"B`@("`@("`@)S(N-2XR.2XQ-"<@/3X@)VED+6-E+7-U8FIE8W1+97E)
M9&5N=&EF:65R)RP*("`@("`@("`G,BXU+C(Y+C$U)R`]/B`G:60M8V4M:V5Y
M57-A9V4G+`H@("`@("`@("<R+C4N,CDN,3<G(#T^("=I9"UC92US=6)J96-T
M06QT3F%M92<L"B`@("`@("`@)S(N-2XR.2XQ.2<@/3X@)VED+6-E+6)A<VEC
M0V]N<W1R86EN=',G+`H@("`@("`@("<R+C4N,CDN,S$G(#T^("=I9"UC92U#
M4DQ$:7-T<FEB=71I;VY0;VEN=',G+`H@("`@("`@("<R+C4N,CDN,S(G(#T^
M("=I9"UC92UC97)T:69I8V%T95!O;&EC:65S)RP*("`@("`@("`G,BXU+C(Y
M+C,U)R`]/B`G:60M8V4M875T:&]R:71Y2V5Y261E;G1I9FEE<B<L"B`@("`@
M("`@)S(N-2XR.2XS-R<@/3X@)VED+6-E+65X=$ME>55S86=E)RP*"B`@("`@
M("`@)S$N,BXX-#`N,3$S-30Y+C$N.2XQ)R`]/B`G16UA:6PG+`H@("`@("`@
M("<Q+C(N.#0P+C$Q,S4T.2XQ+C$N,2<@/3X@)U)3045N8W)Y<'1I;VXG+`H@
M("`@("`@("<Q+C(N.#0P+C$Q,S4T.2XQ+C$N,B<@/3X@)VUD,E=I=&A24T%%
M;F-R>7!T:6]N)RP*("`@("`@("`G,2XR+C@T,"XQ,3,U-#DN,2XQ+C0G(#T^
M("=M9#5W:71H4E-!16YC<GEP=&EO;B<L"B`@("`@("`@)S$N,BXX-#`N,3$S
M-30Y+C$N,2XU)R`]/B`G4TA!+3%7:71H4E-!16YC<GEP=&EO;B<L"B`@("`@
M("`@)S$N,BXX-#`N,3`P-#`N-"XS)R`]/B`G:60M9'-A+7=I=&@M<VAA+3$G
M+`H*("`@("`@("`G,2XS+C8N,2XU+C4N-RXS+C(G(#T^("=I9%]K<%]C;&EE
M;G1!=71H)RP*"B`@("`@("`@)S(N,38N.#0P+C$N,3$S-S,P+C$N,2<@/3X@
M)VYE='-C87!E+6-E<G0M='EP92<L"B`@("`@("`@)S(N,38N.#0P+C$N,3$S
M-S,P+C$N,B<@/3X@)VYE='-C87!E+6)A<V4M=7)L)RP*("`@("`@("`G,BXQ
M-BXX-#`N,2XQ,3,W,S`N,2XS)R`]/B`G;F5T<V-A<&4M<F5V;V-A=&EO;BUU
M<FPG+`H@("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C0G(#T^("=N971S
M8V%P92UC82UR979O8V%T:6]N+75R;"<L"B`@("`@("`@)S(N,38N.#0P+C$N
M,3$S-S,P+C$N-R<@/3X@)VYE='-C87!E+6-E<G0M<F5N97=A;"UU<FPG+`H@
M("`@("`@("<R+C$V+C@T,"XQ+C$Q,S<S,"XQ+C@G(#T^("=N971S8V%P92UC
M82UP;VQI8WDM=7)L)RP*("`@("`@("`G,BXQ-BXX-#`N,2XQ,3,W,S`N,2XQ
M,B<@/3X@)VYE='-C87!E+7-S;"US97)V97(M;F%M92<L"B`@("`@("`@)S(N
M,38N.#0P+C$N,3$S-S,P+C$N,3,G(#T^("=N971S8V%P92UC;VUM96YT)RP*
M("`@("D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@4&%R86UE=&5R(&%R<F%Y+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("=T96UP)R`]/B!,;V-A=&EO
M;B!O9B!T96UP;W)A<GD@9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!(;W)D95]#<GEP=%]S;6EM92@D<&%R86US*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?=&5M<&1I<B`]("1P87)A;7-;)W1E;7`G73L*("`@('T*"B`@("`O
M*BH*("`@("`J(%9E<FEF>2!A('!A<W-P:')A<V4@9F]R(&$@9VEV96X@<')I
M=F%T92!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I=F%T
M95]K97D@(%1H92!U<V5R)W,@<')I=F%T92!K97DN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P87-S<&AR87-E("`@5&AE('5S97(G<R!P87-S<&AR87-E+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&]N
M('9A;&ED('!A<W-P:')A<V4L(&9A;'-E(&]N(&EN=F%L:60*("`@("`J("`@
M("`@("`@("`@("`@("`@<&%S<W!H<F%S92X*("`@("`J("`@("`@("`@("`@
M("`@("`@4F5T=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!V97)I9GE087-S<&AR87-E*"1P<FEV871E7VME>2P@)'!A
M<W-P:')A<V4I"B`@("!["B`@("`@("`@:68@*&ES7VYU;&PH)'!A<W-P:')A
M<V4I*2!["B`@("`@("`@("`@("1R97,@/2!O<&5N<W-L7W!K97E?9V5T7W!R
M:79A=&4H)'!R:79A=&5?:V5Y*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<F5S(#T@;W!E;G-S;%]P:V5Y7V=E=%]P<FEV871E*"1P<FEV871E
M7VME>2P@)'!A<W-P:')A<V4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M(&ES7W)E<V]U<F-E*"1R97,I.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC
M<GEP="!T97AT('5S:6YG(%,O34E-12X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@96YC<GEP=&5D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E
M9"!F;W(@96YC<GEP=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!3964@=&AE(&EN9&EV:61U86P@7V5N8W)Y<'0J*"D@9G5N8W1I;VYS(&9O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H92!P87)A;65T97(@
M<F5Q=6ER96UE;G1S+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@96YC<GEP=&5D(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@
M4F5T=7)N<R!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@96YC<GEP="@D=&5X="P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R(&%V86EL86)I;&ET>2!O9B!/
M<&5N4U-,(%!(4"!E>'1E;G-I;VXN("HO"B`@("`@("`@)&]P96YS<VP@/2`D
M=&AI<RT^8VAE8VM&;W)/<&5N4U-,*"D["B`@("`@("`@:68@*&ES7V$H)&]P
M96YS<VPL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O
M<&5N<W-L.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;
M)W1Y<&4G72DI('L*("`@("`@("`@("`@:68@*"1P87)A;7-;)W1Y<&4G72`]
M/3T@)VUE<W-A9V4G*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]E;F-R>7!T365S<V%G92@D=&5X="P@)'!A<F%M<RD["B`@("`@("`@("`@
M('T@96QS96EF("@D<&%R86US6R=T>7!E)UT@/3T]("=S:6=N871U<F4G*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E;F-R>7!T4VEG;F%T
M=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'0@=&5X="!V:6$@4R]-24U%
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X
M="!T;R!B92!S;6EM92!D96-R>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!D96-R>7!T:6]N
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%-E92!T:&4@:6YD:79I
M9'5A;"!?9&5C<GEP="HH*2!F=6YC=&EO;G,@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@=&AE('!A<F%M971E<B!R97%U:7)E;65N=',N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;65S
M<V%G92X*("`@("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R
M;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96-R
M>7!T*"1T97AT+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@4$A0(&5X=&5N
M<VEO;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC:&5C:T9O<D]P
M96Y34TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP["B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG='EP92==*2D@>PH@("`@
M("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G;65S<V%G92<I('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E8W)Y<'1-97-S86=E
M*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?2!E;'-E:68@*"@D<&%R
M86US6R=T>7!E)UT@/3T]("=S:6=N871U<F4G*2!\?`H@("`@("`@("`@("`@
M("`@("`@("`@*"1P87)A;7-;)W1Y<&4G72`]/3T@)V1E=&%C:&5D+7-I9VYA
M='5R92<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D96-R
M>7!T4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%9E<FEF>2!A('-I9VYA
M='5R92!U<VEN9R!V:6$@4R]-24U%+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'1E>'0@(%1H92!M=6QT:7!A<G0O<VEG;F5D(&1A=&$@=&\@8F4@
M=F5R:69I960N"B`@("`@*B!`<&%R86T@;6EX960@)&-E<G1S("!%:71H97(@
M82!S:6YG;&4@;W(@87)R87D@;V8@<F]O="!C97)T:69I8V%T97,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@3V)J96-T('=I=&@@=&AE(&9O
M;&QO=VEN9R!E;&5M96YT<SH*("`@("`J("`@("`@("`@("`@("`@("`@("=R
M97-U;'0G("T^(%)E='5R;G,@=')U92!O;B!S=6-C97-S.PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@97)R;W(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`G8V5R="<@+3X@
M5&AE(&-E<G1I9FEC871E(&]F('1H92!S:6=N97(@<W1O<F5D"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6X@=&AE(&UE<W-A9V4@*&EN
M(%!%32!F;W)M870I+@H@("`@("H@("`@("`@("`@("`@("`@("`@)V5M86EL
M)R`M/B!4:&4@96UA:6P@;V8@=&AE('-I9VYI;F<@<&5R<V]N+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!V97)I9GDH)'1E>'0L("1C97)T<RD*("`@('L*("`@
M("`@("`O*B!#:&5C:R!F;W(@879A:6QA8FEL:71Y(&]F($]P96Y34TP@4$A0
M(&5X=&5N<VEO;BX@*B\*("`@("`@("`D;W!E;G-S;"`]("1T:&ES+3YC:&5C
M:T9O<D]P96Y34TPH*3L*("`@("`@("!I9B`H:7-?82@D;W!E;G-S;"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&]P96YS<VP["B`@
M("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@:6YP
M=70O;W5T<'5T+B`J+PH@("`@("`@("1I;G!U="`]("1T:&ES+3Y?8W)E871E
M5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@("`@)&]U='!U="`]("1T
M:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["@H@("`@("`@
M("\J(%=R:71E('1E>'0@=&\@9FEL92`J+PH@("`@("`@("1F<"`](&9O<&5N
M*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G=R:71E*"1F<"P@)'1E>'0I.PH@
M("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`D<F]O=%]C97)T<R`](&%R
M<F%Y*"D["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V5R=',I*2!["B`@("`@
M("`@("`@("1C97)T<R`](&%R<F%Y*"1C97)T<RD["B`@("`@("`@?0H@("`@
M("`@(&9O<F5A8V@@*"1C97)T<R!A<R`D9FEL92D@>PH@("`@("`@("`@("!I
M9B`H9FEL95]E>&ES=',H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D<F]O
M=%]C97)T<UM=(#T@)&9I;&4["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1O8B`]("9N97<@<W1D0VQA<W,["@H@("`@("`@(&EF("@A96UP
M='DH)')O;W1?8V5R=',I*2!["B`@("`@("`@("`@("1R97-U;'0@/2!O<&5N
M<W-L7W!K8W,W7W9E<FEF>2@D:6YP=70L(#`L("1O=71P=70L("1R;V]T7V-E
M<G1S*3L*("`@("`@("`@("`@+RH@365S<V%G92!V97)I9FEE9"`J+PH@("`@
M("`@("`@("!I9B`H)')E<W5L="`]/3T@=')U92D@>PH@("`@("`@("`@("`@
M("`@)&]B+3YR97-U;'0@/2!T<G5E.PH@("`@("`@("`@("`@("`@)&]B+3YC
M97)T(#T@9FEL95]G971?8V]N=&5N=',H)&]U='!U="D["B`@("`@("`@("`@
M("`@("`D;V(M/F5M86EL(#T@)'1H:7,M/F=E=$5M86EL1G)O;4ME>2@D;V(M
M/F-E<G0I.PH@("`@("`@("`@("`@("`@<F5T=7)N("1O8CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@5')Y(&%G86EN('=I=&AO=70@
M=F5R9GEI;F<@=&AE('-I9VYE<B=S(&-E<G0@*B\*("`@("`@("`D<F5S=6QT
M(#T@;W!E;G-S;%]P:V-S-U]V97)I9GDH)&EN<'5T+"!02T-3-U].3U9%4DE&
M62P@)&]U='!U="D["@H@("`@("`@(&EF("@H)')E<W5L="`]/3T@=')U92D@
M?'P@*"1R97-U;'0@/3T]("TQ*2D@>PH@("`@("`@("`@("`D;V(M/G)E<W5L
M="`](%!%05(Z.G)A:7-E17)R;W(H7R@B365S<V%G92!697)I9FEE9"!3=6-C
M97-S9G5L;'D@8G5T('1H92!S:6=N97(G<R!C97)T:69I8V%T92!C;W5L9"!N
M;W0@8F4@=F5R:69I960N(BDL("=H;W)D92YW87)N:6YG)RD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&]B+3YR97-U;'0@/2!014%2.CIR86ES
M945R<F]R*%\H(E9E<FEF:6-A=&EO;B!F86EL960@+2!T:&ES(&UE<W-A9V4@
M;6%Y(&AA=F4@8F5E;B!T86UP97)E9"!W:71H+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@("`@("!]"@H@("`@("`@("1O8BT^8V5R="`](&9I;&5?9V5T7V-O
M;G1E;G1S*"1O=71P=70I.PH@("`@("`@("1O8BT^96UA:6P@/2`D=&AI<RT^
M9V5T16UA:6Q&<F]M2V5Y*"1O8BT^8V5R="D["@H@("`@("`@(')E='5R;B`D
M;V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'1R86-T('1H92!C;VYT96YT
M<R!F<F]M('-I9VYE9"!3+TU)344@9&%T82X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A("`@("!4:&4@<VEG;F5D(%,O34E-12!D871A+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<W-L<&%T:"`@5&AE('!A=&@@=&\@=&AE
M($]P96Y34TP@8FEN87)Y+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@8V]N=&5N=',@96UB961D960@:6X@=&AE('-I9VYE9"!D871A+@H@
M("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O;B!E
M<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@97AT<F%C=%-I9VYE9$-O;G1E
M;G1S*"1D871A+"`D<W-L<&%T:"D*("`@('L*("`@("`@("`D<&EP97-?9&5S
M8R`](&%R<F%Y*`H@("`@("`@("`@("`P(#T^(&%R<F%Y*"=P:7!E)RP@)W(G
M*2P*("`@("`@("`@("`@,2`]/B!A<G)A>2@G<&EP92<L("=W)RD*("`@("`@
M("`I.PH*("`@("`@("`D9G`@/2!P<F]C7V]P96XH)'-S;'!A=&@@+B`G('-M
M:6UE("UV97)I9GD@+6YO=F5R:69Y("UN;V-H86EN)RP@)'!I<&5S7V1E<V,L
M("1P:7!E<RD["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D9G`I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D]P96Y34TP@
M97)R;W(Z($-O=6QD(&YO="!E>'1R86-T(&1A=&$@9G)O;2!S:6=N960@4R]-
M24U%('!A<G0N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@
M("`@)&]U='!U="`]("<G.PH*("`@("`@("`O*B`D<&EP97-;,%T@/3X@=W)I
M=&5A8FQE(&AA;F1L92!C;VYN96-T960@=&\@8VAI;&0@<W1D:6X*("`@("`@
M("`@("`D<&EP97-;,5T@/3X@<F5A9&%B;&4@:&%N9&QE(&-O;FYE8W1E9"!T
M;R!C:&EL9"!S=&1O=70@*B\*("`@("`@("!F=W)I=&4H)'!I<&5S6S!=+"`D
M9&%T82D["B`@("`@("`@9F-L;W-E*"1P:7!E<ULP72D["@H@("`@("`@('=H
M:6QE("@A9F5O9B@D<&EP97-;,5TI*2!["B`@("`@("`@("`@("1O=71P=70@
M+CT@9F=E=',H)'!I<&5S6S%=+"`Q,#(T*3L*("`@("`@("!]"B`@("`@("`@
M9F-L;W-E*"1P:7!E<ULQ72D["B`@("`@("`@<')O8U]C;&]S92@D9G`I.PH*
M("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-I9VX@82!-24U%7U!A<G0@=7-I;F<@4R]-24U%+@H@("`@("H*("`@("`J
M($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O
M8FIE8W0@=&\@<VEG;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@
M("`@("`@5&AE('!A<F%M971E<G,@<F5Q=6ER960@9F]R('-I9VYI;F<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B
M:F5C="!T:&%T(&ES('-I9VYE9"X*("`@("`J("`@("`@("`@("`@("`@("`@
M("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T(&]N(&5R<F]R+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S:6=N34E-15!A<G0H)&UI;65?<&%R="P@)'!A<F%M
M<RD*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4&%R
M="YP:'`G.PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]3=')U
M8W1U<F4N<&AP)SL*"B`@("`@("`@+RH@4VEG;B!T:&4@<&%R="!A<R!A(&UE
M<W-A9V4@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3YE;F-R>7!T*"1M
M:6UE7W!A<G0M/G1O0V%N;VYI8V%L4W1R:6YG*"DL("1P87)A;7,I.PH*("`@
M("`@("`O*B!"<F5A:R!T:&4@<F5S=6QT(&EN=&\@:71S(&-O;7!O;F5N=',@
M*B\*("`@("`@("`D;6EM95]M97-S86=E(#T@34E-15]3=')U8W1U<F4Z.G!A
M<G-E5&5X=$U)345-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)'-M:6UE
M7W-I9VX@/2`D;6EM95]M97-S86=E+3YG971087)T*#(I.PH@("`@("`@("1S
M;6EM95]S:6=N+3YS971$97-C<FEP=&EO;BA?*")3+TU)344@0W)Y<'1O9W)A
M<&AI8R!3:6=N871U<F4B*2D["B`@("`@("`@)'-M:6UE7W-I9VXM/G1R86YS
M9F5R1&5C;V1E0V]N=&5N=',H*3L*("`@("`@("`D<VUI;65?<VEG;BT^<V5T
M5')A;G-F97)%;F-O9&EN9R@G8F%S938T)RD["@H@("`@("`@("1S;6EM95]P
M87)T(#T@)FYE=R!-24U%7U!A<G0H)VUU;'1I<&%R="]S:6=N960G*3L*("`@
M("`@("`D<VUI;65?<&%R="T^<V5T0V]N=&5N=',H)U1H:7,@:7,@82!C<GEP
M=&]G<F%P:&EC86QL>2!S:6=N960@;65S<V%G92!I;B!-24U%(&9O<FUA="XG
M("X@(EQN(BD["B`@("`@("`@)'-M:6UE7W!A<G0M/F%D9%!A<G0H)&UI;65?
M<&%R="D["B`@("`@("`@)'-M:6UE7W!A<G0M/F%D9%!A<G0H)'-M:6UE7W-I
M9VXI.PH@("`@("`@("1S;6EM95]P87)T+3YS971#;VYT96YT5'EP95!A<F%M
M971E<B@G<')O=&]C;VPG+"`G87!P;&EC871I;VXO<&MC<S<M<VEG;F%T=7)E
M)RD["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E=$-O;G1E;G14>7!E4&%R86UE
M=&5R*"=M:6-A;&<G+"`G<VAA,2<I.PH*("`@("`@("!R971U<FX@)'-M:6UE
M7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@34E-15]0
M87)T('5S:6YG(%,O34E-12X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]0
M87)T("1M:6UE7W!A<G0@(%1H92!-24U%7U!A<G0@;V)J96-T('1O(&5N8W)Y
M<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@("`@(%1H92!P
M87)A;65T97)S(')E<75I<F5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@34E-15]087)T("!!($U)345?4&%R="!O8FIE8W0@=&AA
M="!I<R!E;F-R>7!T960N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@4F5T
M=7)N<R!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!E;F-R>7!T34E-15!A<G0H)&UI;65?<&%R="P@)'!A<F%M<R`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+U!A
M<G0N<&AP)SL*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O4W1R
M=6-T=7)E+G!H<"<["@H@("`@("`@("\J(%-I9VX@=&AE('!A<G0@87,@82!M
M97-S86=E("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^96YC<GEP="@D
M;6EM95]P87)T+3YT;T-A;F]N:6-A;%-T<FEN9R@I+"`D<&%R86US*3L*("`@
M("`@("!I9B`H:7-?82@D;65S<V%G92P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&UE<W-A9V4["B`@("`@("`@?0H*("`@("`@("`O
M*B!"<F5A:R!T:&4@<F5S=6QT(&EN=&\@:71S(&-O;7!O;F5N=',@*B\*("`@
M("`@("`D;6EM95]M97-S86=E(#T@34E-15]3=')U8W1U<F4Z.G!A<G-E5&5X
M=$U)345-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)'-M:6UE7W!A<G0@
M/2`D;6EM95]M97-S86=E+3YG971"87-E4&%R="@I.PH@("`@("`@("1S;6EM
M95]P87)T+3YS971$97-C<FEP=&EO;BA?*")3+TU)344@16YC<GEP=&5D($UE
M<W-A9V4B*2D["B`@("`@("`@)'-M:6UE7W!A<G0M/G1R86YS9F5R1&5C;V1E
M0V]N=&5N=',H*3L*("`@("`@("`D<VUI;65?<&%R="T^<V5T5')A;G-F97)%
M;F-O9&EN9R@G8F%S938T)RD["B`@("`@("`@)'-M:6UE7W!A<G0M/G-E=$1I
M<W!O<VET:6]N*"=I;FQI;F4G*3L*"B`@("`@("`@+RH@0GD@9&5F875L="P@
M96YC<GEP="@I('!R;V1U8V5S(&$@;65S<V%G92!W:71H('1Y<&4*("`@("`@
M("`@*B`G87!P;&EC871I;VXO>"UP:V-S-RUM:6UE)R!A;F0@;F\@)W-M:6UE
M+71Y<&4G('!A<F%M971E<BX@4&5R"B`@("`@("`@("H@4D9#(#(S,3$L('1H
M92!M;W)E(&-O<G)E8W0@34E-12!T>7!E(&ES("=A<'!L:6-A=&EO;B]P:V-S
M-RUM:6UE)PH@("`@("`@("`J(&%N9"!T:&4@<VUI;64M='EP92!S:&]U;&0@
M8F4@)V5N=F5L;W!E9"UD871A)RX@*B\*("`@("`@("`D<VUI;65?<&%R="T^
M<V5T5'EP92@G87!P;&EC871I;VXO<&MC<S<M;6EM92<I.PH@("`@("`@("1S
M;6EM95]P87)T+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<VUI;64M='EP
M92<L("=E;G9E;&]P960M9&%T82<I.PH*("`@("`@("!R971U<FX@)'-M:6UE
M7W!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F-R>7!T(&$@;65S<V%G
M92!I;B!3+TU)344@9F]R;6%T('5S:6YG(&$@<'5B;&EC(&ME>2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("`@5&AE('1E>'0@=&\@8F4@96YC<GEP=&5D+@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E
M9"!F;W(@96YC<GEP=&EO;BX*("`@("`J(#QP<F4^"B`@("`@*B!087)A;65T
M97)S.@H@("`@("H@/3T]/3T]/3T]/3T*("`@("`J("=T>7!E)R`@("`]/B`@
M)VUE<W-A9V4G("A215%525)%1"D*("`@("`J("=P=6)K97DG("`]/B`@<'5B
M;&EC(&ME>2X@*%)%455)4D5$*0H@("`@("H@)V5M86EL)R`@(#T^("!%+6UA
M:6P@861D<F5S<R!O9B!R96-I<&EE;G0N($EF(&YO="!P<F5S96YT+"!O<B!N
M;W0@9F]U;F0*("`@("`J("`@("`@("`@("`@("`@:6X@=&AE('!U8FQI8R!K
M97DL('1H92!F:7)S="!E+6UA:6P@861D<F5S<R!F;W5N9"!I;B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@:V5Y('=I;&P@8F4@=7-E9"!I;G-T96%D+B`H
M3W!T:6]N86PI"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!M97-S86=E+@H@("`@("H@("`@("`@
M("`@("`@("`@(%)E='5R;B!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V5N8W)Y<'1-97-S86=E*"1T97AT+"`D
M<&%R86US*0H@("`@>PH@("`@("`@("1E;6%I;"`](&YU;&P["@H@("`@("`@
M("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%--24U%(&ME
M>2!I<R!R97%U:7)E9"!T;R!E;F-R>7!T(&$@;65S<V%G92XB*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M<"!F
M:6QE<R!F;W(@:6YP=70O;W5T<'5T+B`J+PH@("`@("`@("1I;G!U="`]("1T
M:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@("`@
M)&]U='!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE
M)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@9FEL92X@*B\*("`@
M("`@("`D9G`Q(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T
M<R@D9G`Q+"`D=&5X="D["B`@("`@("`@9F-L;W-E*"1F<#$I.PH*("`@("`@
M("!I9B`H:7-S970H)'!A<F%M<ULG96UA:6PG72DI('L*("`@("`@("`@("`@
M)&5M86EL(#T@)'!A<F%M<ULG96UA:6PG73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D96UA:6P@/2`D=&AI<RT^9V5T16UA:6Q&<F]M2V5Y*"1P
M87)A;7-;)W!U8FME>2==*3L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&5M
M86EL*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B0V]U;&0@;F]T(&1E=&5R;6EN92!T:&4@<F5C:7!I96YT)W,@92UM
M86EL(&%D9')E<W,N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!%;F-R>7!T('1H92!D;V-U;65N="X@
M*B\*("`@("`@("!I9B`H;W!E;G-S;%]P:V-S-U]E;F-R>7!T*"1I;G!U="P@
M)&]U='!U="P@)'!A<F%M<ULG<'5B:V5Y)UTL(&%R<F%Y*"=4;R<@/3X@)&5M
M86EL*2DI('L*("`@("`@("`@("`@)')E<W5L="`](&9I;&5?9V5T7V-O;G1E
M;G1S*"1O=71P=70I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1R97-U;'0I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]F:7A#;VYT96YT
M5'EP92@D<F5S=6QT+"`G96YC<GEP="<I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L
M9"!N;W0@4R]-24U%(&5N8W)Y<'0@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6=N(&$@;65S<V%G92!I;B!3
M+TU)344@9F]R;6%T('5S:6YG(&$@<')I=F%T92!K97DN"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@(%1H92!T97AT('1O(&)E('-I9VYE9"X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R('-I
M9VYI;F<N"B`@("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J
M(#T]/3T]/3T]/3T]"B`@("`@*B`G8V5R=',G("`@("`@(#T^("!!9&1I=&EO
M;F%L('-I9VYI;F<@8V5R=',@*$]P=&EO;F%L*0H@("`@("H@)W!A<W-P:')A
M<V4G("`]/B`@4&%S<W!H<F%S92!F;W(@:V5Y("A215%525)%1"D*("`@("`J
M("=P<FEV:V5Y)R`@("`@/3X@(%!R:79A=&4@:V5Y("A215%525)%1"D*("`@
M("`J("=P=6)K97DG("`@("`@/3X@(%!U8FQI8R!K97D@*%)%455)4D5$*0H@
M("`@("H@)W-I9W1Y<&4G("`@("`]/B`@1&5T97)M:6YE('1H92!S:6=N871U
M<F4@='EP92!T;R!U<V4N("A/<'1I;VYA;"D*("`@("`J("`@("`@("`@("`@
M("`@("`@("=C;&5A<G1E>'0G("`M+2`@36%K92!A(&-L96%R('1E>'0@<VEG
M;F%T=7)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`G9&5T86-H)R`@("`@
M+2T@($UA:V4@82!D971A8VAE9"!S:6=N871U<F4@*$1%1D%53%0I"B`@("`@
M*B`G='EP92<@("`@("`@(#T^("`G<VEG;F%T=7)E)R`H4D5154E2140I"B`@
M("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('-I9VYE9"!M97-S86=E+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R
M;B!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V5N8W)Y<'13:6=N871U<F4H)'1E>'0L("1P87)A;7,I"B`@("![
M"B`@("`@("`@+RH@0VAE8VL@9F]R('-E8W5R92!C;VYN96-T:6]N+B`J+PH@
M("`@("`@("1S96-U<F5?8VAE8VL@/2`D=&AI<RT^<F5Q=6ER95-E8W5R94-O
M;FYE8W1I;VXH*3L*("`@("`@("!I9B`H:7-?82@D<V5C=7)E7V-H96-K+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5C=7)E7V-H
M96-K.PH@("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D
M('!A<F%M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=P
M=6)K97DG72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W!R:79K
M97DG72D@?'P*("`@("`@("`@("`@(6%R<F%Y7VME>5]E>&ES=',H)W!A<W-P
M:')A<V4G+"`D<&%R86US*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")!('!U8FQI8R!3+TU)344@:V5Y+"!P<FEV871E(%,O
M34E-12!K97DL(&%N9"!P87-S<&AR87-E(&%R92!R97%U:7)E9"!T;R!S:6=N
M(&$@;65S<V%G92XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!#<F5A=&4@=&5M<"!F:6QE<R!F;W(@:6YP=70O;W5T<'5T+V-E
M<G1I9FEC871E<RX@*B\*("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R96%T
M951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@("`@("1O=71P=70@/2`D
M=&AI<RT^7V-R96%T951E;7!&:6QE*"=H;W)D92US;6EM92<I.PH@("`@("`@
M("1C97)T<R`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE
M)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@=&5M<&]R87)Y(&9I
M;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@
M("`@("!F<'5T<R@D9G`L("1T97AT*3L*("`@("`@("!F8VQO<V4H)&9P*3L*
M"B`@("`@("`@+RH@4W1O<F4@861D:71I;VYA;"!C97)T<R!I;B!T96UP;W)A
M<GD@9FEL92X@*B\*("`@("`@("!I9B`H(65M<'1Y*"1P87)A;7-;)V-E<G1S
M)UTI*2!["B`@("`@("`@("`@("1F<"`](&9O<&5N*"1C97)T<RP@)W<K)RD[
M"B`@("`@("`@("`@(&9P=71S*"1F<"P@)'!A<F%M<ULG8V5R=',G72D["B`@
M("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M1&5T97)M:6YE('1H92!S:6=N871U<F4@='EP92!T;R!U<V4N("HO"B`@("`@
M("`@:68@*&ES<V5T*"1P87)A;7-;)W-I9W1Y<&4G72D@)B8@*"1P87)A;7-;
M)W-I9W1Y<&4G72`]/2`G8VQE87)T97AT)RDI('L*("`@("`@("`@("`@)&9L
M86=S(#T@4$M#4S=?5$585#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D9FQA9W,@/2!02T-3-U]$151!0TA%1#L*("`@("`@("!]"@H@("`@("`@
M("1P<FEV:V5Y(#T@*&ES7VYU;&PH)'!A<F%M<ULG<&%S<W!H<F%S92==*2D@
M/R`D<&%R86US6R=P<FEV:V5Y)UT@.B!A<G)A>2@D<&%R86US6R=P<FEV:V5Y
M)UTL("1P87)A;7-;)W!A<W-P:')A<V4G72D["@H@("`@("`@(&EF("AE;7!T
M>2@D<&%R86US6R=C97)T<R==*2D@>PH@("`@("`@("`@("`D<F5S(#T@;W!E
M;G-S;%]P:V-S-U]S:6=N*"1I;G!U="P@)&]U='!U="P@)'!A<F%M<ULG<'5B
M:V5Y)UTL("1P<FEV:V5Y+"!A<G)A>2@I+"`D9FQA9W,I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1R97,@/2!O<&5N<W-L7W!K8W,W7W-I9VXH
M)&EN<'5T+"`D;W5T<'5T+"`D<&%R86US6R=P=6)K97DG72P@)'!R:79K97DL
M(&%R<F%Y*"DL("1F;&%G<RP@)&-E<G1S*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")#;W5L9"!N;W0@4R]-24U%('-I9VX@;65S<V%G92XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`D9&%T82`](&9I;&5?
M9V5T7V-O;G1E;G1S*"1O=71P=70I.PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7V9I>$-O;G1E;G14>7!E*"1D871A+"`G<VEG;F%T=7)E)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96-R>7!T(&%N(%,O34E-12!E;F-R>7!T960@;65S
M<V%G92!U<VEN9R!A('!R:79A=&4O<'5B;&EC(&ME>7!A:7(*("`@("`J(&%N
M9"!A('!A<W-H<')A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT
M('1O(&)E(&1E8W)Y<'1E9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!4:&4@<&%R86UE=&5R<R!N965D960@9F]R(&1E8W)Y<'1I;VXN"B`@("`@
M*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]
M"B`@("`@*B`G='EP92<@("`@("`@(#T^("`G;65S<V%G92<@*%)%455)4D5$
M*0H@("`@("H@)W!U8FME>2<@("`@("`]/B`@<'5B;&EC(&ME>2X@*%)%455)
M4D5$*0H@("`@("H@)W!R:79K97DG("`@("`]/B`@<')I=F%T92!K97DN("A2
M15%525)%1"D*("`@("`J("=P87-S<&AR87-E)R`@/3X@(%!A<W-P:')A<V4@
M9F]R($ME>2X@*%)%455)4D5$*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!D96-R>7!T960@;65S<V%G92X*("`@
M("`J("`@("`@("`@("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;V)J96-T
M(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C<GEP=$UE<W-A
M9V4H)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R
M('-E8W5R92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1S96-U<F5?8VAE8VL@
M/2`D=&AI<RT^<F5Q=6ER95-E8W5R94-O;FYE8W1I;VXH*3L*("`@("`@("!I
M9B`H:7-?82@D<V5C=7)E7V-H96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<V5C=7)E7V-H96-K.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A<F%M971E<G,N("HO"B`@("`@
M("`@:68@*"%I<W-E="@D<&%R86US6R=P=6)K97DG72D@?'P*("`@("`@("`@
M("`@(6ES<V5T*"1P87)A;7-;)W!R:79K97DG72D@?'P*("`@("`@("`@("`@
M(6%R<F%Y7VME>5]E>&ES=',H)W!A<W-P:')A<V4G+"`D<&%R86US*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI
M8R!3+TU)344@:V5Y+"!P<FEV871E(%,O34E-12!K97DL(&%N9"!P87-S<&AR
M87-E(&%R92!R97%U:7)E9"!T;R!D96-R>7!T(&$@;65S<V%G92XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&5M
M<"!F:6QE<R!F;W(@:6YP=70O;W5T<'5T+B`J+PH@("`@("`@("1I;G!U="`]
M("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M:6UE)RD["B`@("`@
M("`@)&]U='!U="`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7-M
M:6UE)RD["@H@("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@9FEL92X@*B\*
M("`@("`@("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P
M=71S*"1F<"P@=')I;2@D=&5X="DI.PH@("`@("`@(&9C;&]S92@D9G`I.PH*
M("`@("`@("`D<')I=FME>2`]("AI<U]N=6QL*"1P87)A;7-;)W!A<W-P:')A
M<V4G72DI(#\@)'!A<F%M<ULG<')I=FME>2==(#H@87)R87DH)'!A<F%M<ULG
M<')I=FME>2==+"`D<&%R86US6R=P87-S<&AR87-E)UTI.PH@("`@("`@(&EF
M("AO<&5N<W-L7W!K8W,W7V1E8W)Y<'0H)&EN<'5T+"`D;W5T<'5T+"`D<&%R
M86US6R=P=6)K97DG72P@)'!R:79K97DI*2!["B`@("`@("`@("`@(')E='5R
M;B!F:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!D96-R
M>7!T(%,O34E-12!D871A+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-I9VX@86YD($5N8W)Y<'0@82!-24U%7U!A<G0@=7-I
M;F<@4R]-24U%+@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)&UI
M;65?<&%R="`@(%1H92!-24U%7U!A<G0@;V)J96-T('1O('-I9VX@86YD(&5N
M8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'-I9VY?<&%R86US("`@("!4
M:&4@<&%R86UE=&5R<R!R97%U:7)E9"!F;W(@<VEG;FEN9RX@4V5E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?96YC<GEP=%-I9VYA
M='5R92@I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;F-R>7!T7W!A<F%M<R`@
M5&AE('!A<F%M971E<G,@<F5Q=6ER960@9F]R(&5N8W)Y<'1I;VXN"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!3964@7V5N8W)Y<'1-
M97-S86=E*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U!A<G0@($$@
M34E-15]087)T(&]B:F5C="!T:&%T(&ES('-I9VYE9"!A;F0@96YC<GEP=&5D
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O
M<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<VEG;D%N9$5N8W)Y
M<'1-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,@/2!A<G)A>2@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC<GEP
M=%]P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC
M92`G2&]R9&4O34E-12]087)T+G!H<"<["@H@("`@("`@("1P87)T(#T@)'1H
M:7,M/G-I9VY-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,I.PH@
M("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"B`@("`@("`@)'!A<G0@
M/2`D=&AI<RT^96YC<GEP=$U)345087)T*"1P87)T+"`D96YC<GEP=%]P87)A
M;7,I.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@
M82!014T@9F]R;6%T(&-E<G1I9FEC871E('1O(')E861A8FQE($A434P@=F5R
M<VEO;@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-E<G0@("!014T@
M9F]R;6%T(&-E<G1I9FEC871E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@($A434P@9&5T86EL:6YG('1H92!C97)T:69I8V%T92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V5R=%1O2%1-3"@D8V5R="D*("`@('L*("`@("`@("`O
M*B!#;VUM;VX@1FEE;&1S("HO"B`@("`@("`@)&9I96QD;F%M97,@/2!A<G)A
M>2@*("`@("`@("`@("`@)T5M86EL)R`]/B!?*")%;6%I;"!!9&1R97-S(BDL
M"B`@("`@("`@("`@("=#;VUM;VY.86UE)R`]/B!?*")#;VUM;VX@3F%M92(I
M+`H@("`@("`@("`@("`G3W)G86YI<V%T:6]N)R`]/B!?*")/<F=A;FES871I
M;VXB*2P*("`@("`@("`@("`@)T]R9V%N:7-A=&EO;F%L56YI="<@/3X@7R@B
M3W)G86YI<V%T:6]N86P@56YI="(I+`H@("`@("`@("`@("`G0V]U;G1R>2<@
M/3X@7R@B0V]U;G1R>2(I+`H@("`@("`@("`@("`G4W1A=&5/<E!R;W9I;F-E
M)R`]/B!?*")3=&%T92!O<B!0<F]V:6YC92(I+`H@("`@("`@("`@("`G3&]C
M871I;VXG(#T^(%\H(DQO8V%T:6]N(BDL"B`@("`@("`@("`@("=3=')E971!
M9&1R97-S)R`]/B!?*")3=')E970@061D<F5S<R(I+`H@("`@("`@("`@("`G
M5&5L97!H;VYE3G5M8F5R)R`]/B!?*")496QE<&AO;F4@3G5M8F5R(BDL"B`@
M("`@("`@("`@("=3=7)N86UE)R`]/B!?*")3=7)N86UE(BDL"B`@("`@("`@
M("`@("=':79E;DYA;64G(#T^(%\H(D=I=F5N($YA;64B*0H@("`@("`@("D[
M"@H@("`@("`@("\J($YE='-C87!E($5X=&5N<VEO;G,@*B\*("`@("`@("`D
M9FEE;&1N86UE<R`K/2!A<G)A>2@*("`@("`@("`@("`@)VYE='-C87!E+6-E
M<G0M='EP92<@/3X@7R@B3F5T<V-A<&4@8V5R=&EF:6-A=&4@='EP92(I+`H@
M("`@("`@("`@("`G;F5T<V-A<&4M8F%S92UU<FPG(#T^(%\H(DYE='-C87!E
M($)A<V4@55),(BDL"B`@("`@("`@("`@("=N971S8V%P92UR979O8V%T:6]N
M+75R;"<@/3X@7R@B3F5T<V-A<&4@4F5V;V-A=&EO;B!54DPB*2P*("`@("`@
M("`@("`@)VYE='-C87!E+6-A+7)E=F]C871I;VXM=7)L)R`]/B!?*").971S
M8V%P92!#02!2979O8V%T:6]N(%523"(I+`H@("`@("`@("`@("`G;F5T<V-A
M<&4M8V5R="UR96YE=V%L+75R;"<@/3X@7R@B3F5T<V-A<&4@4F5N97=A;"!5
M4DPB*2P*("`@("`@("`@("`@)VYE='-C87!E+6-A+7!O;&EC>2UU<FPG(#T^
M(%\H(DYE='-C87!E($-!('!O;&EC>2!54DPB*2P*("`@("`@("`@("`@)VYE
M='-C87!E+7-S;"US97)V97(M;F%M92<@/3X@7R@B3F5T<V-A<&4@4U-,('-E
M<G9E<B!N86UE(BDL"B`@("`@("`@("`@("=N971S8V%P92UC;VUM96YT)R`]
M/B!?*").971S8V%P92!C97)T:69I8V%T92!C;VUM96YT(BD*("`@("`@("`I
M.PH*("`@("`@("`O*B!8-3DP=C,@17AT96YS:6]N<R`J+PH@("`@("`@("1F
M:65L9&YA;65S("L](&%R<F%Y*`H@("`@("`@("`@("`G:60M8V4M97AT2V5Y
M57-A9V4G(#T^(%\H(E@U,#EV,R!%>'1E;F1E9"!+97D@57-A9V4B*2P*("`@
M("`@("`@("`@)VED+6-E+6)A<VEC0V]N<W1R86EN=',G(#T^(%\H(E@U,#EV
M,R!"87-I8R!#;VYS=')A:6YT<R(I+`H@("`@("`@("`@("`G:60M8V4M<W5B
M:F5C=$%L=$YA;64G(#T^(%\H(E@U,#EV,R!3=6)J96-T($%L=&5R;F%T:79E
M($YA;64B*2P*("`@("`@("`@("`@)VED+6-E+7-U8FIE8W1+97E)9&5N=&EF
M:65R)R`]/B!?*")8-3`Y=C,@4W5B:F5C="!+97D@261E;G1I9FEE<B(I+`H@
M("`@("`@("`@("`G:60M8V4M8V5R=&EF:6-A=&50;VQI8VEE<R<@/3X@7R@B
M0V5R=&EF:6-A=&4@4&]L:6-I97,B*2P*("`@("`@("`@("`@)VED+6-E+4-2
M3$1I<W1R:6)U=&EO;E!O:6YT<R<@/3X@7R@B0U),($1I<W1R:6)U=&EO;B!0
M;VEN=',B*2P*("`@("`@("`@("`@)VED+6-E+6ME>55S86=E)R`]/B!?*")+
M97D@57-A9V4B*0H@("`@("`@("D["@H@("`@("`@("1C97)T7V1E=&%I;',@
M/2`D=&AI<RT^<&%R<V5#97)T*"1C97)T*3L*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1C97)T7V1E=&%I;',I*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R
M92!C;&%S<STB9FEX960B/B<@+B!?*")5;F%B;&4@=&\@97AT<F%C="!C97)T
M:69I8V%T92!D971A:6QS(BD@+B`G/"]P<F4^)SL*("`@("`@("!]"B`@("`@
M("`@)&-E<G1I9FEC871E(#T@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G
M73L*"B`@("`@("`@)'1E>'0@/2`G/'!R92!C;&%S<STB9FEX960B/B<["@H@
M("`@("`@("\J(%-U8FIE8W0@*&$O:R]A($-E<G1I9FEC871E($]W;F5R*2`J
M+PH@("`@("`@(&EF("AI<W-E="@D8V5R=&EF:6-A=&5;)W-U8FIE8W0G72DI
M('L*("`@("`@("`@("`@)'1E>'0@+CT@(CQS=')O;F<^(B`N(%\H(D-E<G1I
M9FEC871E($]W;F5R(BD@+B`B.CPO<W1R;VYG/EQN(CL*"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1C97)T:69I8V%T95LG<W5B:F5C="==(&%S("1K97D@/3X@
M)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9I96QD;F%M
M97-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R
M:6YT9B@B)FYB<W`[)FYB<W`[)7,Z("5S7&XB+"`D9FEE;&1N86UE<ULD:V5Y
M72P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[*B5S
M.B`E<UQN(BP@)&ME>2P@)'9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`N/2`B7&XB.PH@("`@("`@
M('T*"B`@("`@("`@+RH@27-S=65R("HO"B`@("`@("`@:68@*&ES<V5T*"1C
M97)T:69I8V%T95LG:7-S=65R)UTI*2!["B`@("`@("`@("`@("1T97AT("X]
M("(\<W1R;VYG/B(@+B!?*"))<W-U97(B*2`N("(Z/"]S=')O;F<^7&XB.PH*
M("`@("`@("`@("`@9F]R96%C:"`H)&-E<G1I9FEC871E6R=I<W-U97(G72!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1F:65L9&YA;65S6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@)&9I96QD
M;F%M97-;)&ME>5TL("1V86QU92D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P
M.R9N8G-P.RHE<SH@)7-<;B(L("1K97DL("1V86QU92D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1E>'0@+CT@(EQN
M(CL*("`@("`@("!]"@H@("`@("`@("\J($1A=&5S("`J+PH@("`@("`@("1T
M97AT("X]("(\<W1R;VYG/B(@+B!?*")686QI9&ET>2(I("X@(CH\+W-T<F]N
M9SY<;B(["B`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[
M)7,Z("5S7&XB+"!?*").;W0@0F5F;W)E(BDL('-T<F9T:6UE*"(E>"`E6"(L
M("1C97)T:69I8V%T95LG=F%L:61I='DG75LG;F]T8F5F;W)E)UTI*3L*("`@
M("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@)7-<;B(L
M(%\H(DYO="!!9G1E<B(I+"!S=')F=&EM92@B)7@@)5@B+"`D8V5R=&EF:6-A
M=&5;)W9A;&ED:71Y)UU;)VYO=&%F=&5R)UTI*3L*("`@("`@("`D=&5X="`N
M/2`B7&XB.PH*("`@("`@("`O*B!#97)T:69I8V%T92!/=VYE<B`M(%!U8FQI
M8R!+97D@26YF;R`J+PH@("`@("`@("1T97AT("X]("(\<W1R;VYG/B(@+B!?
M*")0=6)L:6,@2V5Y($EN9F\B*2`N("(Z/"]S=')O;F<^7&XB.PH@("`@("`@
M("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E<UQN(BP@7R@B
M4'5B;&EC($ME>2!!;&=O<FET:&TB*2P@)&-E<G1I9FEC871E6R=S=6)J96-T
M4'5B;&EC2V5Y26YF;R==6R=A;&=O<FET:&TG72D["B`@("`@("`@:68@*"1C
M97)T:69I8V%T95LG<W5B:F5C=%!U8FQI8TME>4EN9F\G75LG86QG;W)I=&AM
M)UT@/3T@)W)S845N8W)Y<'1I;VXG*2!["B`@("`@("`@("`@(&EF("A5=&EL
M.CIE>'1E;G-I;VY%>&ES=',H)V)C;6%T:"<I*2!["B`@("`@("`@("`@("`@
M("`D;6]D=6QU<R`]("1C97)T:69I8V%T95LG<W5B:F5C=%!U8FQI8TME>4EN
M9F\G75LG<W5B:F5C=%!U8FQI8TME>2==6R=M;V1U;'5S)UT["B`@("`@("`@
M("`@("`@("`D;6]D=6QU<U]H97@@/2`G)SL*("`@("`@("`@("`@("`@('=H
M:6QE("@D;6]D=6QU<R`A/2`G,"<I('L*("`@("`@("`@("`@("`@("`@("`D
M;6]D=6QU<U]H97@@/2!D96-H97@H8F-M;V0H)&UO9'5L=7,L("<Q-B<I*2`N
M("1M;V1U;'5S7VAE>#L*("`@("`@("`@("`@("`@("`@("`D;6]D=6QU<R`]
M(&)C9&EV*"1M;V1U;'5S+"`G,38G+"`P*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!I9B`H*'-T<FQE;B@D;6]D=6QU<U]H97@I(#X@
M-C0I("8F"B`@("`@("`@("`@("`@("`@("`@*'-T<FQE;B@D;6]D=6QU<U]H
M97@I(#P@,3(X*2D@>PH@("`@("`@("`@("`@("`@("`@('-T<E]P860H)&UO
M9'5L=7-?:&5X+"`Q,C@L("<P)RP@4U127U!!1%]224=(5"D["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H*'-T<FQE;B@D;6]D=6QU<U]H97@I(#X@,3(X
M*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("AS=')L96XH)&UO9'5L
M=7-?:&5X*2`\(#(U-BDI('L*("`@("`@("`@("`@("`@("`@("!S=')?<&%D
M*"1M;V1U;'5S7VAE>"P@,C4V+"`G,"<L(%-44E]0041?4DE'2%0I.PH@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1T97AT("X]("(F;F)S
M<#LF;F)S<#LB("X@<W!R:6YT9BA?*")24T$@4'5B;&EC($ME>2`H)60@8FET
M*2(I+"!S=')L96XH)&UO9'5L=7-?:&5X*2`J(#0I("X@(CI<;B(["@H@("`@
M("`@("`@("`@("`@)&UO9'5L=7-?<W1R(#T@)R<["B`@("`@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&UO9'5L=7-?:&5X*3L@)&D@
M*ST@,BD@>PH@("`@("`@("`@("`@("`@("`@(&EF("@H)&D@)2`S,BD@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;6]D=6QU<U]S='(@+CT@
M(EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(CL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&UO9'5L
M=7-?<W1R("X]('-U8G-T<B@D;6]D=6QU<U]H97@L("1I+"`R*2`N("<Z)SL*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D=&5X="`N/2!S
M<')I;G1F*"(F;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<SH@)7-<;B(L(%\H
M(DUO9'5L=7,B*2P@)&UO9'5L=7-?<W1R*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)FYB<W`[
M)FYB<W`[)7,Z("5S7&XB+"!?*")%>'!O;F5N="(I+"`D8V5R=&EF:6-A=&5;
M)W-U8FIE8W10=6)L:6-+97E);F9O)UU;)W-U8FIE8W10=6)L:6-+97DG75LG
M<'5B;&EC17AP;VYE;G0G72D["B`@("`@("`@?0H@("`@("`@("1T97AT("X]
M(")<;B(["@H@("`@("`@("\J(%@U,#EV,R!E>'1E;G-I;VYS("HO"B`@("`@
M("`@:68@*&ES<V5T*"1C97)T:69I8V%T95LG97AT96YS:6]N<R==*2D@>PH@
M("`@("`@("`@("`D=&5X="`N/2`B/'-T<F]N9SXB("X@7R@B6#4P.78S(&5X
M=&5N<VEO;G,B*2`N("(Z/"]S=')O;F<^7&XB.PH*("`@("`@("`@("`@9F]R
M96%C:"`H)&-E<G1I9FEC871E6R=E>'1E;G-I;VYS)UT@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@7R@B56YS=7!P;W)T
M960@17AT96YS:6]N(BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&9I96QD;F%M97-;)&ME>5TI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[)7,Z
M7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<UQN(BP@)&9I96QD;F%M97-;
M)&ME>5TL('=O<F1W<F%P*"1V86QU92P@-#`L(")<;B9N8G-P.R9N8G-P.R9N
M8G-P.R9N8G-P.R(I*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@<W!R:6YT9B@B)FYB<W`[)FYB<W`[
M)7,Z7&XF;F)S<#LF;F)S<#LF;F)S<#LF;F)S<#LE<UQN(BP@)&ME>2P@=V]R
M9'=R87`H)'9A;'5E+"`V,"P@(EQN)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[
M(BDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D=&5X="`N/2`B7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@0V5R
M=&EF:6-A=&4@1&5T86EL<R`J+PH@("`@("`@("1T97AT("X]("(\<W1R;VYG
M/B(@+B!?*")#97)T:69I8V%T92!$971A:6QS(BD@+B`B.CPO<W1R;VYG/EQN
M(CL*("`@("`@("`D=&5X="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SH@
M)61<;B(L(%\H(E9E<G-I;VXB*2P@)&-E<G1I9FEC871E6R=V97)S:6]N)UTI
M.PH@("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B`E
M9%QN(BP@7R@B4V5R:6%L($YU;6)E<B(I+"`D8V5R=&EF:6-A=&5;)W-E<FEA
M;$YU;6)E<B==*3L*"B`@("`@("`@9F]R96%C:"`H)&-E<G1?9&5T86EL<ULG
M9FEN9V5R<')I;G1S)UT@87,@)&AA<V@@/3X@)&9I;F=E<G!R:6YT*2!["B`@
M("`@("`@("`@("1L86)E;"`]('-P<FEN=&8H7R@B)7,@1FEN9V5R<')I;G0B
M*2P@4W1R:6YG.CIU<'!E<B@D:&%S:"DI.PH@("`@("`@("`@("`D9FEN9V5R
M<')I;G1?<W1R(#T@)R<["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M('-T<FQE;B@D9FEN9V5R<')I;G0I.R`D:2`K/2`R*2!["B`@("`@("`@("`@
M("`@("`D9FEN9V5R<')I;G1?<W1R("X]('-U8G-T<B@D9FEN9V5R<')I;G0L
M("1I+"`R*2`N("<Z)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&5X
M="`N/2!S<')I;G1F*"(F;F)S<#LF;F)S<#LE<SI<;B9N8G-P.R9N8G-P.R9N
M8G-P.R9N8G-P.R9N8G-P.R9N8G-P.R5S7&XB+"`D;&%B96PL("1F:6YG97)P
M<FEN=%]S='(I.PH@("`@("`@('T*("`@("`@("`D=&5X="`N/2!S<')I;G1F
M*"(F;F)S<#LF;F)S<#LE<SH@)7-<;B(L(%\H(E-I9VYA='5R92!!;&=O<FET
M:&TB*2P@)&-E<G1?9&5T86EL<ULG<VEG;F%T=7)E06QG;W)I=&AM)UTI.PH@
M("`@("`@("1T97AT("X]('-P<FEN=&8H(B9N8G-P.R9N8G-P.R5S.B(L(%\H
M(E-I9VYA='5R92(I*3L*"B`@("`@("`@)'-I9U]S='(@/2`G)SL*("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&-E<G1?9&5T86EL<ULG<VEG
M;F%T=7)E)UTI.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@H)&D@)2`Q-BD@
M/3T@,"D@>PH@("`@("`@("`@("`@("`@)'-I9U]S='(@+CT@(EQN)FYB<W`[
M)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[)FYB<W`[(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<VEG7W-T<B`N/2!S<')I;G1F*"(E,#)X.B(L(&]R
M9"@D8V5R=%]D971A:6QS6R=S:6=N871U<F4G75LD:5TI*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&5X="`N("1S:6=?<W1R("X@(EQN/"]P<F4^
M(CL*("`@('T*"B`@("`O*BH*("`@("`J($5X=')A8W0@=&AE(&-O;G1E;G1S
M(&]F(&$@4$5-(&9O<FUA="!C97)T:69I8V%T92!T;R!A;B!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C97)T("!014T@9F]R;6%T(&-E
M<G1I9FEC871E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07)R87D@
M8V]N=&%I;FEN9R!A;&P@97AT<F%C=&%B;&4@:6YF;W)M871I;VX@86)O=70*
M("`@("`J("`@("`@("`@("`@("`@('1H92!C97)T:69I8V%T92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<&%R<V5#97)T*"1C97)T*0H@("`@>PH@("`@("`@
M("1C97)T7W-P;&ET(#T@<')E9U]S<&QI="@G+R@M+2TM+2@H0D5'24XI?"A%
M3D0I*2!#15)4249)0T%412TM+2TM*2\G+"`D8V5R="D["B`@("`@("`@:68@
M*"%I<W-E="@D8V5R=%]S<&QI=%LQ72DI('L*("`@("`@("`@("`@)')A=U]C
M97)T(#T@8F%S938T7V1E8V]D92@D8V5R="D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')A=U]C97)T(#T@8F%S938T7V1E8V]D92@D8V5R=%]S
M<&QI=%LQ72D["B`@("`@("`@?0H*("`@("`@("`D8V5R=%]D871A(#T@)'1H
M:7,M/E]P87)S94%33B@D<F%W7V-E<G0I.PH@("`@("`@(&EF("@A:7-?87)R
M87DH)&-E<G1?9&%T82D@?'P@*"1C97)T7V1A=&%;,%T@/3T@)U5.2TY/5TXG
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`D8V5R=%]D971A:6QS(#T@87)R87DH*3L*("`@("`@("`D8V5R=%]D
M971A:6QS6R=F:6YG97)P<FEN=',G75LG;60U)UT@/2!M9#4H)')A=U]C97)T
M*3L*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"=M:&%S:"<I
M*2!["B`@("`@("`@("`@("1C97)T7V1E=&%I;'-;)V9I;F=E<G!R:6YT<R==
M6R=S:&$Q)UT@/2!B:6XR:&5X*&UH87-H*$U(05-(7U-(03$L("1R87=?8V5R
M="DI.PH@("`@("`@('T*"B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF
M:6-A=&4G75LG97AT96YS:6]N<R==(#T@87)R87DH*3L*("`@("`@("`D8V5R
M=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V97)S:6]N)UT@/2`D8V5R=%]D
M871A6S%=6S!=6S%=6S!=6S%=("L@,3L*("`@("`@("`D8V5R=%]D971A:6QS
M6R=C97)T:69I8V%T92==6R=S97)I86Q.=6UB97(G72`]("1C97)T7V1A=&%;
M,5U;,%U;,5U;,5U;,5T["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF
M:6-A=&4G75LG<VEG;F%T=7)E)UT@/2`D8V5R=%]D871A6S%=6S!=6S%=6S)=
M6S%=6S!=6S%=.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E
M)UU;)VES<W5E<B==(#T@)&-E<G1?9&%T85LQ75LP75LQ75LS75LQ73L*("`@
M("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET>2==
M(#T@)&-E<G1?9&%T85LQ75LP75LQ75LT75LQ73L*("`@("`@("`D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T)UT@/2!`)&-E<G1?9&%T
M85LQ75LP75LQ75LU75LQ73L*("`@("`@("`D8V5R=%]D971A:6QS6R=C97)T
M:69I8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==(#T@)&-E<G1?9&%T
M85LQ75LP75LQ75LV75LQ73L*"B`@("`@("`@)&-E<G1?9&5T86EL<ULG<VEG
M;F%T=7)E06QG;W)I=&AM)UT@/2`D8V5R=%]D871A6S%=6S%=6S%=6S!=6S%=
M.PH@("`@("`@("1C97)T7V1E=&%I;'-;)W-I9VYA='5R92==(#T@)&-E<G1?
M9&%T85LQ75LR75LQ73L*"B`@("`@("`@+R\@:7-S=65R"B`@("`@("`@)&ES
M<W5E<B`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-E<G1?9&5T86EL
M<ULG8V5R=&EF:6-A=&4G75LG:7-S=65R)UT@87,@)'9A;'5E*2!["B`@("`@
M("`@("`@("1I<W-U97);)'9A;'5E6S%=6S%=6S!=6S%=72`]("1V86QU95LQ
M75LQ75LQ75LQ73L*("`@("`@("!]"B`@("`@("`@)&-E<G1?9&5T86EL<ULG
M8V5R=&EF:6-A=&4G75LG:7-S=65R)UT@/2`D:7-S=65R.PH*("`@("`@("`O
M+R!S=6)J96-T"B`@("`@("`@)'-U8FIE8W0@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W-U8FIE
M8W0G72!A<R`D=F%L=64I('L*("`@("`@("`@("`@)'-U8FIE8W1;)'9A;'5E
M6S%=6S%=6S!=6S%=72`]("1V86QU95LQ75LQ75LQ75LQ73L*("`@("`@("!]
M"B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG<W5B:F5C
M="==(#T@)'-U8FIE8W0["@H@("`@("`@("\O('9A;&ED:71Y"B`@("`@("`@
M)'9A;',@/2`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET
M>2==.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A
M;&ED:71Y)UT@/2!A<G)A>2@I.PH@("`@("`@("1C97)T7V1E=&%I;'-;)V-E
M<G1I9FEC871E)UU;)W9A;&ED:71Y)UU;)VYO=&)E9F]R92==(#T@)'9A;'-;
M,%U;,5T["B`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG
M=F%L:61I='DG75LG;F]T869T97(G72`]("1V86QS6S%=6S%=.PH@("`@("`@
M(&9O<F5A8V@@*"1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)W9A;&ED
M:71Y)UT@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1Y96%R(#T@
M<W5B<W1R*"1V86PL(#`L(#(I.PH@("`@("`@("`@("`D;6]N=&@@/2!S=6)S
M='(H)'9A;"P@,BP@,BD["B`@("`@("`@("`@("1D87D@/2!S=6)S='(H)'9A
M;"P@-"P@,BD["B`@("`@("`@("`@("1H;W5R(#T@<W5B<W1R*"1V86PL(#8L
M(#(I.PH@("`@("`@("`@("`D;6EN=71E(#T@<W5B<W1R*"1V86PL(#@L(#(I
M.PH@("`@("`@("`@("!I9B`H*"1V86Q;,3%=(#T]("<M)RD@?'P@*"1V86Q;
M.5T@/3T@)RLG*2D@>PH@("`@("`@("`@("`@("`@+R\@:&%N9&QE('1I;64@
M>F]N92!O9F9S970@:&5R90H@("`@("`@("`@("`@("`@)'-E8V]N9',@/2`P
M.PH@("`@("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D=F%L6S$Q
M72D@/3T@)UHG*2!["B`@("`@("`@("`@("`@("`D<V5C;VYD<R`](#`["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V5C;VYD<R`]
M('-U8G-T<B@D=F%L+"`Q,"P@,BD["B`@("`@("`@("`@("`@("!I9B`H*"1V
M86Q;,3%=(#T]("<M)RD@?'P@*"1V86Q;.5T@/3T@)RLG*2D@>PH@("`@("`@
M("`@("`@("`@("`@("\O(&AA;F1L92!T:6UE('IO;F4@;V9F<V5T(&AE<F4*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=V86QI9&ET>2==6R1K97E=
M(#T@;6MT:6UE("@D:&]U<BP@)&UI;G5T92P@)'-E8V]N9',L("1M;VYT:"P@
M)&1A>2P@)'EE87(I.PH@("`@("`@('T*"B`@("`@("`@+R\@4W!L:70@=&AE
M(%!U8FQI8R!+97D@:6YT;R!C;VUP;VYE;G1S+@H@("`@("`@("1S=6)J96-T
M4'5B;&EC2V5Y26YF;R`](&%R<F%Y*"D["B`@("`@("`@)'-U8FIE8W10=6)L
M:6-+97E);F9O6R=A;&=O<FET:&TG72`]("1C97)T7V1E=&%I;'-;)V-E<G1I
M9FEC871E)UU;)W-U8FIE8W10=6)L:6-+97E);F9O)UU;,%U;,5U;,%U;,5T[
M"B`@("`@("`@:68@*"1S=6)J96-T4'5B;&EC2V5Y26YF;ULG86QG;W)I=&AM
M)UT@/3T@)W)S845N8W)Y<'1I;VXG*2!["B`@("`@("`@("`@("1S=6)J96-T
M4'5B;&EC2V5Y(#T@)'1H:7,M/E]P87)S94%33B@D8V5R=%]D971A:6QS6R=C
M97)T:69I8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==6S%=6S%=*3L*
M("`@("`@("`@("`@)'-U8FIE8W10=6)L:6-+97E);F9O6R=S=6)J96-T4'5B
M;&EC2V5Y)UU;)VUO9'5L=7,G72`]("1S=6)J96-T4'5B;&EC2V5Y6S%=6S!=
M6S%=.PH@("`@("`@("`@("`D<W5B:F5C=%!U8FQI8TME>4EN9F];)W-U8FIE
M8W10=6)L:6-+97DG75LG<'5B;&EC17AP;VYE;G0G72`]("1S=6)J96-T4'5B
M;&EC2V5Y6S%=6S%=6S%=.PH@("`@("`@('T*("`@("`@("`D8V5R=%]D971A
M:6QS6R=C97)T:69I8V%T92==6R=S=6)J96-T4'5B;&EC2V5Y26YF;R==(#T@
M)'-U8FIE8W10=6)L:6-+97E);F9O.PH*("`@("`@("!I9B`H:7-S970H)&-E
M<G1?9&%T85LQ75LP75LQ75LW72D@)B8*("`@("`@("`@("`@:7-?87)R87DH
M)&-E<G1?9&%T85LQ75LP75LQ75LW75LQ72DI('L*("`@("`@("`@("`@9F]R
M96%C:"`H)&-E<G1?9&%T85LQ75LP75LQ75LW75LQ72!A<R`D97AT*2!["B`@
M("`@("`@("`@("`@("`D;VED(#T@)&5X=%LQ75LP75LQ73L*("`@("`@("`@
M("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N<VEO
M;G,G75LD;VED72`]("1E>'1;,5U;,5T["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("1I(#T@.3L*("`@("`@("!W:&EL92`H:7-S970H)&-E
M<G1?9&%T85LQ75LP75LQ75LD:5TI*2!["B`@("`@("`@("`@("1O:60@/2`D
M8V5R=%]D871A6S%=6S!=6S%=6R1I75LQ75LP75LQ73L*("`@("`@("`@("`@
M)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O
M:61=(#T@)&-E<G1?9&%T85LQ75LP75LQ75LD:5U;,5U;,5T["B`@("`@("`@
M("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UT@87,@)&]I9"`]
M/B`D=F%L*2!["B`@("`@("`@("`@('-W:71C:"`H)&]I9"D@>PH@("`@("`@
M("`@("!C87-E("=N971S8V%P92UB87-E+75R;"<Z"B`@("`@("`@("`@(&-A
M<V4@)VYE='-C87!E+7)E=F]C871I;VXM=7)L)SH*("`@("`@("`@("`@8V%S
M92`G;F5T<V-A<&4M8V$M<F5V;V-A=&EO;BUU<FPG.@H@("`@("`@("`@("!C
M87-E("=N971S8V%P92UC97)T+7)E;F5W86PM=7)L)SH*("`@("`@("`@("`@
M8V%S92`G;F5T<V-A<&4M8V$M<&]L:6-Y+75R;"<Z"B`@("`@("`@("`@(&-A
M<V4@)VYE='-C87!E+7-S;"US97)V97(M;F%M92<Z"B`@("`@("`@("`@(&-A
M<V4@)VYE='-C87!E+6-O;6UE;G0G.@H@("`@("`@("`@("`@("`@)'9A;"`]
M("1T:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@("`D
M8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I
M9%T@/2`D=F%L6S%=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=I9"UC92US=6)J96-T06QT3F%M92<Z"B`@("`@("`@("`@
M("`@("`D=F%L(#T@)'1H:7,M/E]P87)S94%33B@D=F%L6S%=*3L*("`@("`@
M("`@("`@("`@("1C97)T7V1E=&%I;'-;)V-E<G1I9FEC871E)UU;)V5X=&5N
M<VEO;G,G75LD;VED72`]("<G.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'9A;%LQ72!A<R`D;F%M92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N
M<R==6R1O:61=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8V5R=%]D
M971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@+CT@
M)RP@)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==
M6R1O:61=("X]("1N86UE6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=N971S8V%P92UC
M97)T+71Y<&4G.@H@("`@("`@("`@("`@("`@)'9A;"`]("1T:&ES+3Y?<&%R
M<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@("`D=F%L(#T@;W)D*"1V
M86Q;,5TI.PH@("`@("`@("`@("`@("`@)&YE=U9A;"`]("<G.PH*("`@("`@
M("`@("`@("`@(&EF("@D=F%L("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@
M("`@("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4U-,(&-L:65N="<@
M.B`G+"!34TP@8VQI96YT)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("@D=F%L("8@,'@T,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1N97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4U-,('-E<G9E<B<@.B`G
M+"!34TP@<V5R=F5R)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@D=F%L("8@,'@R,"D@>PH@("`@("`@("`@("`@("`@("`@("1N
M97=686P@+CT@96UP='DH)&YE=U9A;"D@/R`G4R]-24U%)R`Z("<L(%,O34E-
M12<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)'9A
M;"`F(#!X,3`I('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X](&5M
M<'1Y*"1N97=686PI(#\@)T]B:F5C="!3:6=N:6YG)R`Z("<L($]B:F5C="!3
M:6=N:6YG)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF
M("@D=F%L("8@,'@P-"D@>PH@("`@("`@("`@("`@("`@("`@("1N97=686P@
M+CT@96UP='DH)&YE=U9A;"D@/R`G4U-,($-!)R`Z("<L(%-33"!#02<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H)'9A;"`F(#!X
M,#(I('L*("`@("`@("`@("`@("`@("`@("`D;F5W5F%L("X](&5M<'1Y*"1N
M97=686PI(#\@)U,O34E-12!#02<@.B`G+"!3+TU)344@0T$G.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1V86P@)B`P>#`Q*2![
M"B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T>2@D;F5W5F%L
M*2`_("=/8FIE8W0@4VEG;FEN9R!#02<@.B`G+"!/8FIE8W0@4VEG;FEN9R!#
M02<["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&-E<G1?
M9&5T86EL<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@
M)&YE=U9A;#L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G:60M8V4M97AT2V5Y57-A9V4G.@H@("`@("`@("`@("`@("`@)'9A
M;"`]("1T:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@
M("`D=F%L(#T@)'9A;%LQ73L*"B`@("`@("`@("`@("`@("`D;F5W5F%L(#T@
M)R<["B`@("`@("`@("`@("`@("!I9B`H)'9A;%LP75LQ72`A/2`G<V5Q=65N
M8V4G*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;"`](&%R<F%Y*"1V86PI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=F%L(#T@)'9A;%LQ75LQ73L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86P@87,@)'5S86=E*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1U<V%G95LQ72`]/2`G:61?:W!?8VQI96YT075T
M:"<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!E;7!T
M>2@D;F5W5F%L*2`_("=43%,@5V5B($-L:65N="!!=71H96YT:6-A=&EO;B<@
M.B`G+"!43%,@5V5B($-L:65N="!!=71H96YT:6-A=&EO;B<["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&YE=U9A;"`N/2!E;7!T>2@D;F5W5F%L*2`_("1U<V%G95LQ72`Z("<L("<@
M+B`D=7-A9V5;,5T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF
M:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@)&YE=U9A;#L*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:60M8V4M<W5B
M:F5C=$ME>4ED96YT:69I97(G.@H@("`@("`@("`@("`@("`@)'9A;"`]("1T
M:&ES+3Y?<&%R<V5!4TXH)'9A;%LQ72D["B`@("`@("`@("`@("`@("`D=F%L
M(#T@)'9A;%LQ73L*"B`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)R<["@H@
M("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<W1R;&5N*"1V86PI
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A;"`N/2!S<')I
M;G1F*"(E,#)X.B(L(&]R9"@D=F%L6R1I72DI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)&-E<G1?9&5T86EL<ULG8V5R=&EF:6-A=&4G
M75LG97AT96YS:6]N<R==6R1O:61=(#T@)&YE=U9A;#L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:60M8V4M875T:&]R:71Y
M2V5Y261E;G1I9FEE<B<Z"B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M
M/E]P87)S94%33B@D=F%L6S%=*3L*("`@("`@("`@("`@("`@(&EF("@D=F%L
M6S!=(#T]("=S=')I;F<G*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;"`]
M("1V86Q;,5T["@H@("`@("`@("`@("`@("`@("`@("1N97=686P@/2`G)SL*
M("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH
M)'9A;"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&YE=U9A
M;"`N/2!S<')I;G1F*"(E,#)X.B(L(&]R9"@D=F%L6R1I72DI.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8V5R=%]D971A
M:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS)UU;)&]I9%T@/2`D;F5W
M5F%L.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`D8V5R=%]D971A:6QS6R=C97)T:69I8V%T92==6R=E>'1E;G-I;VYS
M)UU;)&]I9%T@/2!?*")5;G-U<'!O<G1E9"!%>'1E;G-I;VXB*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@8V%S92`G:60M8V4M8F%S:6-#;VYS=')A:6YT<R<Z"B`@("`@("`@("`@
M(&-A<V4@)V1E9F%U;'0G.@H@("`@("`@("`@("`@("`@)&-E<G1?9&5T86EL
M<ULG8V5R=&EF:6-A=&4G75LG97AT96YS:6]N<R==6R1O:61=(#T@7R@B56YS
M=7!P;W)T960@17AT96YS:6]N(BD["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C97)T
M7V1E=&%I;',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O('!A
M<G-E($%33BXQ(&9O<FUA=&5D(&1A=&$N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@
M05-.+C$@9F]R;6%T960@9&%T80H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($%R<F%Y(&-O;G1A:6YE9"!T:&4@97AT<F%C=&5D('9A;'5E<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E05-.*"1D871A*0H@("`@>PH@("`@
M("`@("1R97-U;'0@/2!A<G)A>2@I.PH*("`@("`@("!W:&EL92`H<W1R;&5N
M*"1D871A*2`^(#$I('L*("`@("`@("`@("`@)&-L87-S(#T@;W)D*"1D871A
M6S!=*3L*("`@("`@("`@("`@<W=I=&-H("@D8VQA<W,I('L*("`@("`@("`@
M("`@8V%S92`P>#,P.@H@("`@("`@("`@("`@("`@+R\@4V5Q=65N8V4*("`@
M("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@("`@
M("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N("8@
M,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@)B`P
M>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@?"!O
M<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-E<75E;F-E7V1A=&$@
M/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@("`@
M("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N
M*3L*"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@)'1H:7,M/E]P87)S94%3
M3B@D<V5Q=65N8V5?9&%T82D["B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1V86QU97,I('Q\(&ES7W-T<FEN9R@D=F%L=65S6S!=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1V86QU97,@/2!A<G)A>2@D=F%L=65S*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S97%U96YC95]V86QU
M97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'9A;'5E<R!A<R`D=F%L*2!["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1V86Q;,%T@/3T@)V5X=&5N<VEO;B<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'-E<75E;F-E7W9A;'5E<ULG97AT96YS
M:6]N<R==6UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1S97%U96YC95]V86QU97-;)&DK
M*UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=S97%U
M96YC92<L("1S97%U96YC95]V86QU97,I.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E(#!X,S$Z"B`@("`@("`@("`@("`@("`O
M+R!3970@;V8*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI
M.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@
M(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E
M<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P
M.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E
M<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L
M96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-E
M<75E;F-E7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI
M.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D
M8GET97,@*R`D;&5N*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R
M<F%Y*"=S970G+"`D=&AI<RT^7W!A<G-E05-.*"1S97%U96YC95]D871A*2D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P
M,3H*("`@("`@("`@("`@("`@("\O($)O;VQE86X@='EP90H@("`@("`@("`@
M("`@("`@)&)O;VQE86Y?=F%L=64@/2`H;W)D*"1D871A6S)=*2`]/2`P>&9F
M*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`S*3L*
M("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=B;V]L96%N)RP@
M)&)O;VQE86Y?=F%L=64I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E(#!X,#(Z"B`@("`@("`@("`@("`@("`O+R!);G1E9V5R
M('1Y<&4*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@
M("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF
M("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`]
M("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P.PH@
M("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@
M)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@
M/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1I;G1E
M9V5R7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,L("1L96XI.PH@
M("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET
M97,@*R`D;&5N*3L*"B`@("`@("`@("`@("`@("`D=F%L=64@/2`P.PH@("`@
M("`@("`@("`@("`@:68@*"1L96X@/#T@-"D@>PH@("`@("`@("`@("`@("`@
M("`@("\J($UE=&AO9"!W;W)K<R!F:6YE(&9O<B!S;6%L;"!I;G1E9V5R<R`J
M+PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE
M;B@D:6YT96=E<E]D871A*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%L=64@/2`H)'9A;'5E(#P\(#@I('P@;W)D*"1I;G1E9V5R7V1A
M=&%;)&E=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\J($UE=&AO9"!W;W)K
M<R!F;W(@87)B:71R87)Y(&QE;F=T:"!I;G1E9V5R<R`J+PH@("`@("`@("`@
M("`@("`@("`@(&EF("A5=&EL.CIE>'1E;G-I;VY%>&ES=',H)V)C;6%T:"<I
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M('-T<FQE;B@D:6YT96=E<E]D871A*3L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'9A;'5E(#T@8F-A9&0H8F-M=6PH)'9A;'5E+"`R
M-38I+"!O<F0H)&EN=&5G97)?9&%T85LD:5TI*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1V86QU92`]("TQ.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R
M97-U;'1;72`](&%R<F%Y*"=I;G1E9V5R*"<@+B`D;&5N("X@)RDG+"`D=F%L
M=64I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(#!X,#,Z"B`@("`@("`@("`@("`@("`O+R!":71S=')I;F<@='EP90H@("`@
M("`@("`@("`@("`@)&QE;B`](&]R9"@D9&%T85LQ72D["B`@("`@("`@("`@
M("`@("`D8GET97,@/2`P.PH@("`@("`@("`@("`@("`@:68@*"1L96X@)B`P
M>#@P*2!["B`@("`@("`@("`@("`@("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X
M,&8["B`@("`@("`@("`@("`@("`@("`@)&QE;B`](#`["B`@("`@("`@("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R
M9"@D9&%T85LD:2`K(#)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8FET<W1R:6YG7V1A=&$@
M/2!S=6)S='(H)&1A=&$L(#,@*R`D8GET97,L("1L96XI.PH@("`@("`@("`@
M("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N
M*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=B:70@<W1R
M:6YG)RP@)&)I='-T<FEN9U]D871A*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`P>#`T.@H@("`@("`@("`@("`@("`@+R\@
M3V-T971S=')I;F<@='EP90H@("`@("`@("`@("`@("`@)&QE;B`](&]R9"@D
M9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@("`@("`@
M("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@("`@("`@
M("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@("`@("`@
M)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1L
M96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D;V-T96-T<W1R:6YG7V1A=&$@/2!S=6)S='(H)&1A=&$L(#(@*R`D
M8GET97,L("1L96XI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H
M)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N*3L*("`@("`@("`@("`@("`@("1R
M97-U;'1;72`](&%R<F%Y*"=O8W1E="!S=')I;F<G+"`D;V-T96-T<W1R:6YG
M7V1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(#!X,#4Z"B`@("`@("`@("`@("`@("`O+R!.=6QL('1Y<&4*("`@("`@
M("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R*3L*("`@("`@("`@
M("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=N=6QL)RP@;G5L;"D["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@,'@P-CH*("`@
M("`@("`@("`@("`@("\O($]B:F5C="!I9&5N=&EF:65R('1Y<&4*("`@("`@
M("`@("`@("`@("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@("`@("`@
M("`@)&)Y=&5S(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N("8@,'@X
M,"D@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@)B`P>#!F
M.PH@("`@("`@("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@("`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@?"!O<F0H
M)&1A=&%;)&D@*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&]I9%]D871A(#T@<W5B<W1R
M*"1D871A+"`R("L@)&)Y=&5S+"`D;&5N*3L*("`@("`@("`@("`@("`@("1D
M871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S("L@)&QE;BD["@H@("`@
M("`@("`@("`@("`@+R\@56YP86-K('1H92!/240*("`@("`@("`@("`@("`@
M("1P;&%I;B`@/2!F;&]O<BAO<F0H)&]I9%]D871A6S!=*2`O(#0P*3L*("`@
M("`@("`@("`@("`@("1P;&%I;B`N/2`G+B<@+B!O<F0H)&]I9%]D871A6S!=
M*2`E(#0P.PH*("`@("`@("`@("`@("`@("1V86QU92`](#`["B`@("`@("`@
M("`@("`@("`D:2`](#$["B`@("`@("`@("`@("`@("!W:&EL92`H)&D@/"!S
M=')L96XH)&]I9%]D871A*2D@>PH@("`@("`@("`@("`@("`@("`@("1V86QU
M92`]("1V86QU92`\/"`W.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`]
M("1V86QU92!\("AO<F0H)&]I9%]D871A6R1I72D@)B`P>#=F*3L*"B`@("`@
M("`@("`@("`@("`@("`@:68@*"$H;W)D*"1O:61?9&%T85LD:5TI("8@,'@X
M,"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'!L86EN("X]("<N)R`N
M("1V86QU93L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@,#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&DK
M*SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]O:61S6R1P;&%I;ETI*2!["B`@("`@("`@("`@("`@("`@
M("`@)')E<W5L=%M=(#T@87)R87DH)V]I9"<L("1T:&ES+3Y?;VED<ULD<&QA
M:6Y=*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)')E<W5L=%M=(#T@87)R87DH)V]I9"<L("1P;&%I;BD["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E(#!X,3(Z"B`@("`@("`@("`@(&-A<V4@,'@Q,SH*("`@("`@
M("`@("`@8V%S92`P>#$T.@H@("`@("`@("`@("!C87-E(#!X,34Z"B`@("`@
M("`@("`@(&-A<V4@,'@Q-CH*("`@("`@("`@("`@8V%S92`P>#@Q.@H@("`@
M("`@("`@("!C87-E(#!X.#`Z"B`@("`@("`@("`@("`@("`O+R!#:&%R86-T
M97(@<W1R:6YG('1Y<&4*("`@("`@("`@("`@("`@("1L96X@/2!O<F0H)&1A
M=&%;,5TI.PH@("`@("`@("`@("`@("`@)&)Y=&5S(#T@,#L*("`@("`@("`@
M("`@("`@(&EF("@D;&5N("8@,'@X,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1B>71E<R`]("1L96X@)B`P>#!F.PH@("`@("`@("`@("`@("`@("`@("1L
M96X@/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1B>71E<SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;&5N
M(#T@*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@*R`R72D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'-T<FEN9U]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S+"`D
M;&5N*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`R
M("L@)&)Y=&5S("L@)&QE;BD["B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@
M/2!A<G)A>2@G<W1R:6YG)RP@)'-T<FEN9U]D871A*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`P>#$W.@H@("`@("`@("`@
M("`@("`@+R\@5&EM92!T>7!E<PH@("`@("`@("`@("`@("`@)&QE;B`](&]R
M9"@D9&%T85LQ72D["B`@("`@("`@("`@("`@("`D8GET97,@/2`P.PH@("`@
M("`@("`@("`@("`@:68@*"1L96X@)B`P>#@P*2!["B`@("`@("`@("`@("`@
M("`@("`@)&)Y=&5S(#T@)&QE;B`F(#!X,&8["B`@("`@("`@("`@("`@("`@
M("`@)&QE;B`](#`["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&)Y=&5S.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1L96X@/2`H)&QE;B`\/"`X*2!\(&]R9"@D9&%T85LD:2`K(#)=*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D=&EM95]D871A(#T@<W5B<W1R*"1D871A+"`R("L@)&)Y=&5S
M+"`D;&5N*3L*("`@("`@("`@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A
M+"`R("L@)&)Y=&5S("L@)&QE;BD["B`@("`@("`@("`@("`@("`D<F5S=6QT
M6UT@/2!A<G)A>2@G=71C=&EM92<L("1T:6UE7V1A=&$I.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X.#(Z"B`@("`@("`@
M("`@("`@("`O+R!8-3`Y=C,@97AT96YS:6]N<S\*("`@("`@("`@("`@("`@
M("1L96X@/2!O<F0H)&1A=&%;,5TI.PH@("`@("`@("`@("`@("`@)&)Y=&5S
M(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;&5N("8@,'@X,"D@>PH@("`@
M("`@("`@("`@("`@("`@("1B>71E<R`]("1L96X@)B`P>#!F.PH@("`@("`@
M("`@("`@("`@("`@("1L96X@/2`P.PH@("`@("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("1B>71E<SL@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;&5N(#T@*"1L96X@/#P@."D@?"!O<F0H)&1A=&%;)&D@
M*R`R72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'-E<75E;F-E7V1A=&$@/2!S=6)S='(H)&1A
M=&$L(#(@*R`D8GET97,L("1L96XI.PH@("`@("`@("`@("`@("`@)&1A=&$@
M/2!S=6)S='(H)&1A=&$L(#(@*R`D8GET97,@*R`D;&5N*3L*("`@("`@("`@
M("`@("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"`G6#4P.78S
M(&5X=&5N<VEO;G,G*3L*("`@("`@("`@("`@("`@("1R97-U;'1;72`]("1T
M:&ES+3Y?<&%R<V5!4TXH)'-E<75E;F-E7V1A=&$I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X83`Z"B`@("`@("`@("`@
M(&-A<V4@,'AA,SH*("`@("`@("`@("`@("`@("\O($5X=&5N<VEO;G,*("`@
M("`@("`@("`@("`@("1E>'1E;G-I;VY?9&%T82`]('-U8G-T<B@D9&%T82P@
M,"P@,BD["B`@("`@("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@
M,BD["B`@("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G97AT96YS
M:6]N)RP@9&5C:&5X*"1E>'1E;G-I;VY?9&%T82DI.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X938Z"B`@("`@("`@("`@
M("`@("`D97AT96YS:6]N7V1A=&$@/2!S=6)S='(H)&1A=&$L(#`L(#$I.PH@
M("`@("`@("`@("`@("`@)&1A=&$@/2!S=6)S='(H)&1A=&$L(#$I.PH@("`@
M("`@("`@("`@("`@)')E<W5L=%M=(#T@87)R87DH)V5X=&5N<VEO;B<L(&1E
M8VAE>"@D97AT96YS:6]N7V1A=&$I*3L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`P>&$Q.@H@("`@("`@("`@("`@("`@)&5X
M=&5N<VEO;E]D871A(#T@<W5B<W1R*"1D871A+"`P+"`Q*3L*("`@("`@("`@
M("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`V*3L*("`@("`@("`@("`@
M("`@("1R97-U;'1;72`](&%R<F%Y*"=E>'1E;G-I;VXG+"!D96-H97@H)&5X
M=&5N<VEO;E]D871A*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`O+R!5;FMN;W=N"B`@
M("`@("`@("`@("`@("`D<F5S=6QT6UT@/2!A<G)A>2@G54Y+3D]73B<L(&1E
M8VAE>"@D9&%T82DI.PH@("`@("`@("`@("`@("`@)&1A=&$@/2`G)SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@*&-O=6YT*"1R97-U;'0I(#X@,2D@/R`D<F5S=6QT
M(#H@87)R87E?<&]P*"1R97-U;'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5C<GEP="!A;B!3/TU)344@<VEG;F5D(&UE<W-A9V4@=7-I;F<@82!P=6)L
M:6,@:V5Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T;R!B92!V
M97)I9FEE9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R
M86UE=&5R<R!N965D960@9F]R('9E<FEF:6-A=&EO;BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('9E<FEF:6-A=&EO;B!M97-S86=E+@H@
M("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D96-R>7!T4VEG
M;F%T=7)E*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=?9&5C<GEP=%-I9VYA='5R92@I("<@+B!?*")N
M;W0@>65T(&EM<&QE;65N=&5D(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VL@9F]R('1H92!P<F5S96YC92!O9B!T:&4@3W!E;E-33"!E>'1E;G-I
M;VX@=&\@4$A0+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@4F5T
M=7)N<R!T<G5E(&EF('1H92!O<&5N<W-L(&5X=&5N<VEO;B!I<R!A=F%I;&%B
M;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@(%)E='5R;G,@82!014%27T5R
M<F]R(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM&;W)/<&5N
M4U-,*"D*("`@('L*("`@("`@("!I9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T
M<R@G;W!E;G-S;"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(E1H92!O<&5N<W-L(&UO9'5L92!I<R!R97%U:7)E9"!F;W(@
M=&AE($AO<F1E7T-R>7!T7W-M:6UE.CH@8VQA<W,N(BDI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($5X=')A8W0@=&AE(&5M86EL(&%D9')E
M<W,@9G)O;2!A('!U8FQI8R!K97DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:V5Y("!4:&4@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@4F5T=7)N<R!T:&4@96UA:6P@861D<F5S<RP@;W(@;G5L
M;"!I9B!N;VYE(&ES(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971%
M;6%I;$9R;VU+97DH)&ME>2D*("`@('L*("`@("`@("`D:V5Y7VEN9F\@/2!O
M<&5N<W-L7W@U,#E?<&%R<V4H)&ME>2D["B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1K97E?:6YF;RD@)B8@:7-S970H)&ME>5]I;F9O6R=S=6)J96-T)UTI*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D:V5Y7VEN9F];)W-U8FIE8W0G75LG
M16UA:6PG72DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:V5Y7VEN9F];
M)W-U8FIE8W0G75LG16UA:6PG73L*("`@("`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1K97E?:6YF;ULG<W5B:F5C="==6R=E;6%I;$%D9')E<W,G72DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D:V5Y7VEN9F];)W-U8FIE8W0G75LG
M96UA:6Q!9&1R97-S)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R
M="!A(%!+0U,@,3(@96YC<GEP=&5D(&-E<G1I9FEC871E('!A8VMA9V4@:6YT
M;R!A('!R:79A=&4@:V5Y+`H@("`@("H@<'5B;&EC(&ME>2P@86YD(&%N>2!A
M9&1I=&EO;F%L(&ME>7,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@(%1H92!02T-3(#$R(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!P87)S:6YG+@H@
M("`@("H@/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]
M/3T]/0H@("`@("H@)W-S;'!A=&@G(#T^(%1H92!P871H('1O('1H92!/<&5N
M4U-,(&)I;F%R>2X@*%)%455)4D5$*0H@("`@("H@)W!A<W-W;W)D)R`]/B!4
M:&4@<&%S<W=O<F0@=&\@=7-E('1O(&1E8W)Y<'0@=&AE(&1A=&$N("A/<'1I
M;VYA;"D*("`@("`J("=N97=P87-S=V]R9"<@/3X@5&AE('!A<W-W;W)D('1O
M('5S92!T;R!E;F-R>7!T('1H92!P<FEV871E(&ME>2X*("`@("`J("`@("`@
M("`@("`@("`@("`@*$]P=&EO;F%L*0H@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=&1#;&%S<R`@06X@;V)J96-T+@H@("`@("H@("`@
M("`@("`@("`@("`@("`@)W!R:79A=&4G("T@(%1H92!P<FEV871E(&ME>2!I
M;B!014T@9F]R;6%T+@H@("`@("H@("`@("`@("`@("`@("`@("`@)W!U8FQI
M8R<@("T@(%1H92!P=6)L:6,@:V5Y(&EN(%!%32!F;W)M870N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`G8V5R=',G("`@+2`@06X@87)R87D@;V8@861D
M:71I;VYA;"!C97)T<RX*("`@("`J("`@("`@("`@("`@("`@("`@(%)E='5R
M;G,@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<&%R<V502T-3,3)$871A*"1P:V-S,3(L("1P87)A;7,I"B`@("!["B`@("`@
M("`@+RH@0VAE8VL@9F]R(&%V86EL86)I;&ET>2!O9B!/<&5N4U-,(%!(4"!E
M>'1E;G-I;VXN("HO"B`@("`@("`@)&]P96YS<VP@/2`D=&AI<RT^8VAE8VM&
M;W)/<&5N4U-,*"D["B`@("`@("`@:68@*&ES7V$H)&]P96YS<VPL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O<&5N<W-L.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=S<VQP871H)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO
M('!A=&@@=&\@=&AE($]P96Y34TP@8FEN87)Y('!R;W9I9&5D+B!4:&4@3W!E
M;E-33"!B:6YA<GD@:7,@;F5C97-S87)Y('1O('=O<FL@=VET:"!02T-3(#$R
M(&1A=&$N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*("`@("`@("`D
M<W-L<&%T:"`](&5S8V%P97-H96QL8VUD*"1P87)A;7-;)W-S;'!A=&@G72D[
M"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U="]O=71P
M=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL
M92@G:&]R9&4M<VUI;64G*3L*("`@("`@("`D;W5T<'5T(#T@)'1H:7,M/E]C
M<F5A=&5496UP1FEL92@G:&]R9&4M<VUI;64G*3L*"B`@("`@("`@)&]B(#T@
M)FYE=R!S=&1#;&%S<SL*"B`@("`@("`@+RH@5W)I=&4@=&5X="!T;R!F:6QE
M("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G=RLG*3L*("`@("`@
M("!F=W)I=&4H)&9P+"`D<&MC<S$R*3L*("`@("`@("!F8VQO<V4H)&9P*3L*
M"B`@("`@("`@+RH@17AT<F%C="!T:&4@<')I=F%T92!K97D@9G)O;2!T:&4@
M9FEL92!F:7)S="X@*B\*("`@("`@("`D8VUD;&EN92`]("1S<VQP871H("X@
M)R!P:V-S,3(@+6EN("<@+B`D:6YP=70@+B`G("UO=70@)R`N("1O=71P=70@
M+B`G("UN;V-E<G1S)SL*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<&%S
M<W=O<F0G72DI('L*("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M<&%S<VEN
M('-T9&EN)SL*("`@("`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=N97=P
M87-S=V]R9"==*2D@>PH@("`@("`@("`@("`@("`@)&-M9&QI;F4@+CT@)R`M
M<&%S<V]U="!S=&1I;B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D8VUD;&EN92`N/2`G("UN;V1E<R<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)&9D(#T@<&]P96XH)&-M9&QI;F4L("=W)RD["B`@("`@
M("`@("`@(&9W<FET92@D9F0L("1P87)A;7-;)W!A<W-W;W)D)UT@+B`B7&XB
M*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=N97=P87-S=V]R
M9"==*2D@>PH@("`@("`@("`@("`@("`@9G=R:71E*"1F9"P@)'!A<F%M<ULG
M;F5W<&%S<W=O<F0G72`N(")<;B(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@('!C;&]S92@D9F0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1C;61L:6YE("X]("<@+6YO9&5S)SL*("`@("`@("`@("`@97AE8R@D8VUD
M;&EN92D["B`@("`@("`@?0H@("`@("`@("1O8BT^<')I=F%T92`]('1R:6TH
M9FEL95]G971?8V]N=&5N=',H)&]U='!U="DI.PH@("`@("`@(&EF("AE;7!T
M>2@D;V(M/G!R:79A=&4I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E!A<W-W;W)D(&EN8V]R<F5C="(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('!U8FQI
M8R!K97D@;F5X="X@*B\*("`@("`@("`D8VUD;&EN92`]("1S<VQP871H("X@
M)R!P:V-S,3(@+6EN("<@+B`D:6YP=70@+B`G("UO=70@)R`N("1O=71P=70@
M+B`G("UN;VME>7,@+6-L8V5R=',G.PH@("`@("`@(&EF("AI<W-E="@D<&%R
M86US6R=P87-S=V]R9"==*2D@>PH@("`@("`@("`@("`D8VUD;&EN92`N/2`G
M("UP87-S:6X@<W1D:6XG.PH@("`@("`@("`@("`D9F0@/2!P;W!E;B@D8VUD
M;&EN92P@)W<G*3L*("`@("`@("`@("`@9G=R:71E*"1F9"P@)'!A<F%M<ULG
M<&%S<W=O<F0G72`N(")<;B(I.PH@("`@("`@("`@("!P8VQO<V4H)&9D*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E>&5C*"1C;61L:6YE*3L*
M("`@("`@("!]"B`@("`@("`@)&]B+3YP=6)L:6,@/2!T<FEM*&9I;&5?9V5T
M7V-O;G1E;G1S*"1O=71P=70I*3L*"B`@("`@("`@+RH@17AT<F%C="!T:&4@
M<'5B;&EC(&ME>2!N97AT+B`J+PH@("`@("`@("1C;61L:6YE(#T@)'-S;'!A
M=&@@+B`G('!K8W,Q,B`M:6X@)R`N("1I;G!U="`N("<@+6]U="`G("X@)&]U
M='!U="`N("<@+6YO:V5Y<R`M8V%C97)T<R<["B`@("`@("`@:68@*&ES<V5T
M*"1P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1C;61L:6YE
M("X]("<@+7!A<W-I;B!S=&1I;B<["B`@("`@("`@("`@("1F9"`]('!O<&5N
M*"1C;61L:6YE+"`G=R<I.PH@("`@("`@("`@("!F=W)I=&4H)&9D+"`D<&%R
M86US6R=P87-S=V]R9"==("X@(EQN(BD["B`@("`@("`@("`@('!C;&]S92@D
M9F0I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5X96,H)&-M9&QI
M;F4I.PH@("`@("`@('T*("`@("`@("`D;V(M/F-E<G1S(#T@=')I;2AF:6QE
M7V=E=%]C;VYT96YT<R@D;W5T<'5T*2D["@H@("`@("`@(')E='5R;B`D;V([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@0V]N=&5N="U4>7!E('!A<F%M
M971E<G,@4$A0)W,@;W!E;G-S;%]P:V-S-U\J(&9U;F-T:6]N<R!R971U<FX@
M87)E"B`@("`@*B!D97!R96-A=&5D+B`@1FEX('1H97-E(&AE861E<G,@=&\@
M=&AE(&-O<G)E8W0@;VYE<R`H<V5E(%)&0R`R,S$Q*2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T97AT("!4:&4@4$M#4S<@9&%T82X*("`@("`J($!P87)A;2!S=')I;F<@
M)'1Y<&4@($ES('1H:7,@)VUE<W-A9V4G(&]R("=S:6=N871U<F4G(&1A=&$_
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!02T-3-R!D871A
M('=I=&@@=&AE(&-O<G)E8W0@0V]N=&5N="U4>7!E('!A<F%M971E<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V9I>$-O;G1E;G14>7!E*"1T97AT+"`D='EP
M92D*("`@('L*("`@("`@("!I9B`H)'1Y<&4@/3T@)VUE<W-A9V4G*2!["B`@
M("`@("`@("`@("1F<F]M(#T@)V%P<&QI8V%T:6]N+W@M<&MC<S<M;6EM92<[
M"B`@("`@("`@("`@("1T;R`]("=A<'!L:6-A=&EO;B]P:V-S-RUM:6UE)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9G)O;2`]("=A<'!L:6-A
M=&EO;B]X+7!K8W,W+7-I9VYA='5R92<["B`@("`@("`@("`@("1T;R`]("=A
M<'!L:6-A=&EO;B]P:V-S-RUS:6=N871U<F4G.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@<W1R7W)E<&QA8V4H)T-O;G1E;G0M5'EP93H@)R`N("1F<F]M
M+"`G0V]N=&5N="U4>7!E.B`G("X@)'1O+"`D=&5X="D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O0W)Y<'0O<&=P+G!H<```````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q-#8R,#8@,3`U,34T
M,S0Q-#`@,#(Q-S4P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+T-R>7!T+G!H
M<"<["@HO*BH*("H@07)M;W(@2&5A9&5R($QI;F5S("T@1G)O;2!21D,@,C0T
M,`H@*@H@*B`@06X@07)M;W(@2&5A9&5R($QI;F4@8V]N<VES=',@;V8@=&AE
M(&%P<')O<')I871E(&AE861E<B!L:6YE('1E>'0*("H@('-U<G)O=6YD960@
M8GD@9FEV92`H-2D@9&%S:&5S("@G+2<L(#!X,D0I(&]N(&5I=&AE<B!S:61E
M(&]F('1H92!H96%D97(*("H@(&QI;F4@=&5X="X@5&AE(&AE861E<B!L:6YE
M('1E>'0@:7,@8VAO<V5N(&)A<V5D('5P;VX@=&AE('1Y<&4@;V8@9&%T82!T
M:&%T"B`J("!I<R!B96EN9R!E;F-O9&5D(&EN($%R;6]R+"!A;F0@:&]W(&ET
M(&ES(&)E:6YG(&5N8V]D960N($AE861E<B!L:6YE('1E>'1S"B`J("!I;F-L
M=61E('1H92!F;VQL;W=I;F<@<W1R:6YG<SH*("H*("H@($%L;"!!<FUO<B!(
M96%D97(@3&EN97,@87)E('!R969I>&5D('=I=&@@)U!'4"<N"B`J"B`J("!4
M:&4@07)M;W(@5&%I;"!,:6YE(&ES(&-O;7!O<V5D(&EN('1H92!S86UE(&UA
M;FYE<B!A<R!T:&4@07)M;W(@2&5A9&5R"B`J("!,:6YE+"!E>&-E<'0@=&AE
M('-T<FEN9R`B0D5'24XB(&ES(')E<&QA8V5D(&)Y('1H92!S=')I;F<@(D5.
M1"XB"B`J+PH*+RHJ(%5S960@9F]R('-I9VYE9"P@96YC<GEP=&5D+"!O<B!C
M;VUP<F5S<V5D(&9I;&5S+B`J+PID969I;F4H)U!'4%]!4DU/4E]-15-304=%
M)RP@,2D["@HO*BH@57-E9"!F;W(@<VEG;F5D(&9I;&5S+B`J+PID969I;F4H
M)U!'4%]!4DU/4E]324=.141?34534T%'12<L(#(I.PH*+RHJ(%5S960@9F]R
M(&%R;6]R:6YG('!U8FQI8R!K97ES+B`J+PID969I;F4H)U!'4%]!4DU/4E]0
M54),24-?2T59)RP@,RD["@HO*BH@57-E9"!F;W(@87)M;W)I;F<@<')I=F%T
M92!K97ES+B`J+PID969I;F4H)U!'4%]!4DU/4E]04DE6051%7TM%62<L(#0I
M.PH*+RHJ"B`J(%5S960@9F]R(&1E=&%C:&5D('-I9VYA='5R97,L(%!'4"]-
M24U%('-I9VYA='5R97,L(&%N9"!N871U<F5S(&9O;&QO=VEN9PH@*B!C;&5A
M<G-I9VYE9"!M97-S86=E<RX*("HO"F1E9FEN92@G4$=07T%234]27U-)1TY!
M5%5212<L(#4I.PH*+RHJ(%)E9W5L87(@=&5X="!C;VYT86EN960@:6X@86X@
M4$=0(&UE<W-A9V4N("HO"F1E9FEN92@G4$=07T%234]27U1%6%0G+"`V*3L*
M"@HO*BH@5&AE(&1E9F%U;'0@<'5B;&EC(%!'4"!K97ES97)V97(@=&\@=7-E
M+B`J+PID969I;F4H)U!'4%]+15E315)615)?4%5"3$E#)RP@)W=W=VME>7,N
M<&=P+FYE="<I.PH*+RHJ"B`J(%1H92!N=6UB97(@;V8@=&EM97,@=&AE(&ME
M>7-E<G9E<B!R969U<V5S(&-O;FYE8W1I;VX@8F5F;W)E(&%N(&5R<F]R(&ES
M"B`J(')E='5R;F5D+@H@*B\*9&5F:6YE*"=01U!?2T594T525D527U)%1E53
M12<L(#,I.PH*+RHJ"B`J(%1H92!N=6UB97(@;V8@<V5C;VYD<R!T:&%T(%!(
M4"!W:6QL(&%T=&5M<'0@=&\@8V]N;F5C="!T;R!T:&4@:V5Y<V5R=F5R"B`J
M(&)E9F]R92!I="!W:6QL('-T;W`@<')O8V5S<VEN9R!T:&4@<F5Q=65S="X*
M("HO"F1E9FEN92@G4$=07TM%65-%4E9%4E]424U%3U54)RP@,3`I.PH*"B\J
M*@H@*B!(;W)D95]#<GEP=%]P9W`Z.B!P<F]V:61E<R!A(&9R86UE=V]R:R!F
M;W(@2&]R9&4@87!P;&EC871I;VYS('1O(&EN=&5R86-T"B`J('=I=&@@=&AE
M($=.52!0<FEV86-Y($=U87)D('!R;V=R86T@*")';G501R(I+B`@1VYU4$<@
M:6UP;&5M96YT<R!T:&4@3W!E;E!'4`H@*B!S=&%N9&%R9"`H4D9#(#(T-#`I
M+@H@*@H@*B!';G501R!796)S:71E.B!H='1P.B\O=W=W+F=N=7!G+F]R9R\*
M("H*("H@5&AI<R!C;&%S<R!H87,@8F5E;B!D979E;&]P960@=VET:"P@86YD
M(&ES(&]N;'D@9W5A<F%N=&5E9"!T;R!W;W)K('=I=&@L"B`J(%9E<G-I;VX@
M,2XR,2!O<B!A8F]V92!O9B!';G501RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO0W)Y<'0O0W)Y<'0O<&=P+G!H<"QV(#$N.#4N,BXQ-2`R,#`V+S`W+S(P
M(#`Y.C`R.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@
M2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T-R>7!T"B`J+PIC;&%S<R!(
M;W)D95]#<GEP=%]P9W`@97AT96YD<R!(;W)D95]#<GEP="!["@H@("`@+RHJ
M"B`@("`@*B!3=')I;F=S(&EN(&%R;6]R(&AE861E<B!L:6YE<R!U<V5D('1O
M(&1I<W1I;F=U:7-H(&)E='=E96X@=&AE(&1I9F9E<F5N=`H@("`@("H@='EP
M97,@;V8@4$=0(&1E8W)Y<'1I;VXO96YC<GEP=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%R;6]R(#T@87)R87DH
M"B`@("`@("`@)TU%4U-!1T4G("`@("`@("`@("`@/3X@(%!'4%]!4DU/4E]-
M15-304=%+`H@("`@("`@("=324=.140@34534T%'12<@("`@(#T^("!01U!?
M05)-3U)?4TE'3D5$7TU%4U-!1T4L"B`@("`@("`@)U!50DQ)0R!+15D@0DQ/
M0TLG("`@/3X@(%!'4%]!4DU/4E]054),24-?2T59+`H@("`@("`@("=04DE6
M051%($M%62!"3$]#2R<@(#T^("!01U!?05)-3U)?4%))5D%415]+15DL"B`@
M("`@("`@)U-)1TY!5%5212<@("`@("`@("`@/3X@(%!'4%]!4DU/4E]324=.
M05154D4*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!01U`@
M:&%S:"!A;&=O<FET:&US("AF<F]M(%)&0R`S,34V*2X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VAA<VA!;&<@/2!A<G)A
M>2@*("`@("`@("`Q("`]/B`@)W!G<"UM9#4G+`H@("`@("`@(#(@(#T^("`G
M<&=P+7-H83$G+`H@("`@("`@(#,@(#T^("`G<&=P+7)I<&5M9#$V,"<L"B`@
M("`@("`@-2`@/3X@("=P9W`M;60R)RP*("`@("`@("`V("`]/B`@)W!G<"UT
M:6=E<C$Y,B<L"B`@("`@("`@-R`@/3X@("=P9W`M:&%V86PM-2TQ-C`G+`H@
M("`@("`@(#@@(#T^("`G<&=P+7-H83(U-B<L"B`@("`@("`@.2`@/3X@("=P
M9W`M<VAA,S@T)RP*("`@("`@("`Q,"`]/B`@)W!G<"US:&$U,3(G+`H@("`@
M*3L*"B`@("`O*BH*("`@("`J($=N=5!'('!R;V=R86T@;&]C871I;VXO8V]M
M;6]N(&]P=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]G;G5P9SL*"B`@("`O*BH*("`@("`J($9I;&5N86UE(&]F
M('1H92!T96UP;W)A<GD@<'5B;&EC(&ME>7)I;F<N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?<'5B;&EC2V5Y<FEN9SL*
M"B`@("`O*BH*("`@("`J($9I;&5N86UE(&]F('1H92!T96UP;W)A<GD@<')I
M=F%T92!K97ER:6YG+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7W!R:79A=&5+97ER:6YG.PH*("`@("\J*@H@("`@("H@
M5&AE(&5X:7-T96YC92!O9B!T:&ES('!R;W!E<G1Y(&EN9&EC871E<R!T:&%T
M(&UU;'1I<&QE(')E8VEP:65N=`H@("`@("H@96YC<GEP=&EO;B!I<R!A=F%I
M;&%B;&4N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@("`@("H*
M("`@("`J($!D97!R96-A=&5D"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N
M"B`@("`@*B\*("`@('9A<B`D;75L=&EP;&5296-I<&EE;G1%;F-R>7!T:6]N
M(#T@=')U93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!087)A;65T97(@87)R87D@
M8V]N=&%I;FEN9R!T:&4@<&%T:"!T;R!T:&4@1VYU4$<*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!B:6YA<GD@*&ME>2`]("=P<F]G<F%M)RD@86YD
M('1O(&$@=&5M<&]R87)Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]#<GEP=%]P
M9W`H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]T
M96UP9&ER(#T@571I;#HZ8W)E871E5&5M<$1I<BAT<G5E+"`D<&%R86US6R=T
M96UP)UTI.PH*("`@("`@("!I9B`H96UP='DH)'!A<F%M<ULG<')O9W)A;2==
M*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I<V5%<G)O
M<BA?*")4:&4@;&]C871I;VX@;V8@=&AE($=N=5!'(&)I;F%R>2!M=7-T(&)E
M(&=I=F5N('1O('1H92!#<GEP=%]P9W`Z.B!C;&%S<RXB*2DL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T:&4@
M;&]C871I;VX@;V8@1VYU4$<@86YD('-E="!C;VUM;VX@;W!T:6]N<RX@*B\*
M("`@("`@("`D=&AI<RT^7V=N=7!G(#T@87)R87DH"B`@("`@("`@("`@("1P
M87)A;7-;)W!R;V=R86TG72P*("`@("`@("`@("`@)RTM;F\M='1Y)RP*("`@
M("`@("`@("`@)RTM;F\M<V5C;65M+7=A<FYI;F<G+`H@("`@("`@("`@("`G
M+2UN;RUO<'1I;VYS)RP*("`@("`@("`@("`@)RTM;F\M9&5F875L="UK97ER
M:6YG)RP*("`@("`@("`@("`@)RTM<75I970G+`H@("`@("`@("`@("`G+2UY
M97,G+`H@("`@("`@("`@("`G+2UH;VUE9&ER("<@+B`D=&AI<RT^7W1E;7!D
M:7(*("`@("`@("`I.PH*("`@("`@("!I9B`H<W5B<W1R*%!(4%]/4RP@,"P@
M,RD@(3T@)U=)3B<I('L*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D=&AI
M<RT^7V=N=7!G+"`G3$%.1ST@.R<I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=E;F5R871E<R!A('!E<G-O;F%L(%!U8FQI8R]0<FEV871E
M(&ME>7!A:7(@8V]M8FEN871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<F5A;&YA;64@("`@5&AE(&YA;64@=&\@=7-E(&9O<B!T:&4@:V5Y
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96UA:6P@("`@("`@5&AE(&5M86EL
M('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M<W-P:')A<V4@(%1H92!P87-S<&AR87-E('1O('5S92!F;W(@=&AE(&ME>2X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UE;G0@("`@(%1H92!C;VUM96YT
M('1O('5S92!F;W(@=&AE(&ME>2X*("`@("`J($!P87)A;2!I;G1E9V5R("1K
M97EL96YG=&@@(%1H92!K97EL96YG=&@@=&\@=7-E(&9O<B!T:&4@:V5Y+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&-O;G-I<W1I
M;F<@;V8@=&AE('!U8FQI8R!K97D@86YD('1H92!P<FEV871E"B`@("`@*B`@
M("`@("`@("`@("`@("!K97DL(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@
M("`@*B`\<')E/@H@("`@("H@4F5T=7)N(&%R<F%Y.@H@("`@("H@2V5Y("`@
M("`@("`@("`@5F%L=64*("`@("`J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"B`@("`@*B`G<'5B;&EC)R`@(#T^("!0=6)L:6,@2V5Y"B`@("`@*B`G
M<')I=F%T92<@(#T^("!0<FEV871E($ME>0H@("`@("H@/"]P<F4^"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E;F5R871E2V5Y*"1R96%L;F%M92P@)&5M86EL
M+"`D<&%S<W!H<F%S92P@)&-O;6UE;G0@/2`G)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1K97EL96YG=&@@/2`Q,#(T*0H@("`@>PH@("`@("`@("\J
M($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D<V5C
M=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T:6]N*"D[
M"B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*("`@("`@
M("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S('1O(&AO;&0@=&AE
M(&=E;F5R871E9"!K97ES+B`J+PH@("`@("`@("1P=6)?9FEL92`]("1T:&ES
M+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("1S96-R
M971?9FEL92`]("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I
M.PH*("`@("`@("`O*B!#<F5A=&4@=&AE(&-O;F9I9R!F:6QE(&YE8V5S<V%R
M>2!F;W(@1VYU4$<@=&\@<G5N(&EN(&)A=&-H(&UO9&4N("HO"B`@("`@("`@
M+RH@5$]$3SH@4V%N:71I>F4@:6YP=70L($UO<F4@=7-E<B!C=7-T;VUI>F%B
M;&4_("HO"B`@("`@("`@)&EN<'5T(#T@87)R87DH*3L*("`@("`@("`D:6YP
M=71;72`]("<E<'5B<FEN9R`G("X@)'!U8E]F:6QE.PH@("`@("`@("1I;G!U
M=%M=(#T@)R5S96-R:6YG("<@+B`D<V5C<F5T7V9I;&4["B`@("`@("`@)&EN
M<'5T6UT@/2`G2V5Y+51Y<&4Z($1302<["B`@("`@("`@)&EN<'5T6UT@/2`G
M2V5Y+4QE;F=T:#H@,3`R-"<["B`@("`@("`@)&EN<'5T6UT@/2`G4W5B:V5Y
M+51Y<&4Z($5,1RU%)SL*("`@("`@("`D:6YP=71;72`]("=3=6)K97DM3&5N
M9W1H.B`G("X@)&ME>6QE;F=T:#L*("`@("`@("`D:6YP=71;72`]("=.86UE
M+5)E86PZ("<@+B`D<F5A;&YA;64["B`@("`@("`@:68@*"%E;7!T>2@D8V]M
M;65N="DI('L*("`@("`@("`@("`@)&EN<'5T6UT@/2`G3F%M92U#;VUM96YT
M.B`G("X@)&-O;6UE;G0["B`@("`@("`@?0H@("`@("`@("1I;G!U=%M=(#T@
M)TYA;64M16UA:6PZ("<@+B`D96UA:6P["B`@("`@("`@)&EN<'5T6UT@/2`G
M17AP:7)E+41A=&4Z(#`G.PH@("`@("`@("1I;G!U=%M=(#T@)U!A<W-P:')A
M<V4Z("<@+B`D<&%S<W!H<F%S93L*("`@("`@("`D:6YP=71;72`]("<E8V]M
M;6ET)SL*"B`@("`@("`@+RH@4G5N('1H<F]U9V@@9W!G(&)I;F%R>2X@*B\*
M("`@("`@("`D8VUD;&EN92`](&%R<F%Y*`H@("`@("`@("`@("`G+2UG96XM
M:V5Y)RP*("`@("`@("`@("`@)RTM8F%T8V@G+`H@("`@("`@("`@("`G+2UA
M<FUO<B<*("`@("`@("`I.PH@("`@("`@("1T:&ES+3Y?8V%L;$=P9R@D8VUD
M;&EN92P@)W<G+"`D:6YP=70I.PH*("`@("`@("`O*B!'970@=&AE(&ME>7,@
M9G)O;2!T:&4@=&5M<"!F:6QE<RX@*B\*("`@("`@("`D<'5B;&EC7VME>2`]
M(&9I;&4H)'!U8E]F:6QE*3L*("`@("`@("`D<V5C<F5T7VME>2`](&9I;&4H
M)'-E8W)E=%]F:6QE*3L*"B`@("`@("`@+RH@268@96ET:&5R(&ME>2!I<R!E
M;7!T>2P@<V]M971H:6YG('=E;G0@=W)O;F<N("HO"B`@("`@("`@:68@*&5M
M<'1Y*"1P=6)L:6-?:V5Y*2!\?"!E;7!T>2@D<V5C<F5T7VME>2DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B4'5B;&EC+U!R
M:79A=&4@:V5Y<&%I<B!N;W0@9V5N97)A=&5D('-U8V-E<W-F=6QL>2XB*2P@
M)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@87)R
M87DH)W!U8FQI8R<@/3X@)'!U8FQI8U]K97DL("=P<FEV871E)R`]/B`D<V5C
M<F5T7VME>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R
M;6%T:6]N(&]N(&$@4$=0(&1A=&$@8FQO8VLN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&=P9&%T82`@5&AE(%!'4"!D871A(&)L;V-K+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I=&@@:6YF;W)M
M871I;VX@;VX@=&AE(%!'4"!D871A(&)L;V-K+B!)9B!A;@H@("`@("H@("`@
M("`@("`@("`@("`@96QE;65N="!I<R!N;W0@<')E<V5N="!I;B!T:&4@9&%T
M82!B;&]C:RP@:70@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@;&EK97=I
M<V4@;F]T(&)E('-E="!I;B!T:&4@87)R87DN"B`@("`@*B`\<')E/@H@("`@
M("H@07)R87D@1F]R;6%T.@H@("`@("H@+2TM+2TM+2TM+2TM+0H@("`@("H@
M6W!U8FQI8U]K97E=+UMS96-R971?:V5Y72`]/B!!<G)A>0H@("`@("H@("`H
M"B`@("`@*B`@("`@6V-R96%T961=(#T^($ME>2!C<F5A=&EO;B`M(%5.25@@
M=&EM97-T86UP"B`@("`@*B`@("`@6V5X<&ER97-=(#T^($ME>2!E>'!I<F%T
M:6]N("T@54Y)6"!T:6UE<W1A;7`@*#`@/2!N979E<B!E>'!I<F5S*0H@("`@
M("H@("`@(%MS:7IE72`@("`]/B!3:7IE(&]F('1H92!K97D@:6X@8FET<PH@
M("`@("H@("`I"B`@("`@*@H@("`@("H@6V9I;F=E<G!R:6YT72`]/B!&:6YG
M97)P<FEN="!O9B!T:&4@4$=0(&1A=&$@*&EF(&%V86EL86)L92D*("`@("`J
M("`@("`@("`@("`@("`@("`@,38M8FET(&AE>"!V86QU90H@("`@("H*("`@
M("`J(%MS:6=N871U<F5=(#T^($%R<F%Y("@*("`@("`J("`@("!;:61[;GTO
M)U]324=.05154D4G72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("`@(%MN86UE
M72`@("`@("`@/3X@1G5L;"!.86UE"B`@("`@*B`@("`@("`@(%MC;VUM96YT
M72`@("`@/3X@0V]M;65N=`H@("`@("H@("`@("`@("!;96UA:6Q=("`@("`@
M(#T^($4M;6%I;"!!9&1R97-S"B`@("`@*B`@("`@("`@(%MF:6YG97)P<FEN
M=%T@/3X@,38M8FET(&AE>"!V86QU90H@("`@("H@("`@("`@("!;8W)E871E
M9%T@("`@(#T^(%-I9VYA='5R92!C<F5A=&EO;B`M(%5.25@@=&EM97-T86UP
M"B`@("`@*B`@("`@("`@(%MM:6-A;&==("`@("`@/3X@5&AE(&AA<V@@=7-E
M9"!T;R!C<F5A=&4@=&AE('-I9VYA='5R90H@("`@("H@("`@("`@("!;<VEG
M7WMH97A]72`@(#T^($%R<F%Y(%MD971A:6QS(&]F(&$@<VEG('9E<FEF>6EN
M9R!T:&4@241=("@*("`@("`J("`@("`@("`@("`@(%MC<F5A=&5D72`@("`@
M/3X@4VEG;F%T=7)E(&-R96%T:6]N("T@54Y)6"!T:6UE<W1A;7`*("`@("`J
M("`@("`@("`@("`@(%MF:6YG97)P<FEN=%T@/3X@,38M8FET(&AE>"!V86QU
M90H@("`@("H@("`@("`@("`@("`@6VUI8V%L9UT@("`@("`]/B!4:&4@:&%S
M:"!U<V5D('1O(&-R96%T92!T:&4@<VEG;F%T=7)E"B`@("`@*B`@("`@("`@
M("D*("`@("`J("`@("`I"B`@("`@*B`I"B`@("`@*B`\+W!R93X*("`@("`J
M"B`@("`@*B!%86-H('5S97(@240@=VEL;"!B92!S=&]R960@:6X@=&AE(&%R
M<F%Y("=S:6=N871U<F4G(&%N9"!H879E(&1A=&$*("`@("`J(&%S<V]C:6%T
M960@=VET:"!I="P@:6YC;'5D:6YG(&%N(&%R<F%Y(&9O<B!I;F9O<FUA=&EO
M;B!O;B!E86-H"B`@("`@*B!S:6=N871U<F4@=&AA="!H87,@<VEG;F5D('1H
M870@54E$+B!3:6=N871U<F5S(&YO="!A<W-O8VEA=&5D('=I=&@@80H@("`@
M("H@54E$("AE+F<N(')E=F]C871I;VX@<VEG;F%T=7)E<R!A;F0@<W5B(&ME
M>7,I('=I;&P@8F4@<W1O<F5D('5N9&5R('1H90H@("`@("H@<W!E8VEA;"!K
M97EW;W)D("=?4TE'3D%455)%)RX*("`@("`J+PH@("`@9G5N8W1I;VX@<&=P
M4&%C:V5T26YF;W)M871I;VXH)'!G<&1A=&$I"B`@("!["B`@("`@("`@)&1A
M=&%?87)R87D@/2!A<G)A>2@I.PH@("`@("`@("1F:6YG97)P<FEN="`]("<G
M.PH@("`@("`@("1H96%D97(@/2!N=6QL.PH@("`@("`@("1I;G!U="`]("1T
M:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("1S
M:6=?:60@/2`D=6ED7VED>"`](#`["@H@("`@("`@("\J(%-T;W)E(&UE<W-A
M9V4@:6X@=&5M<&]R87)Y(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH
M)&EN<'5T+"`G=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1P9W!D871A*3L*
M("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A
M>2@*("`@("`@("`@("`@)RTM;&ES="UP86-K971S)RP*("`@("`@("`@("`@
M)&EN<'5T"B`@("`@("`@*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL1W!G*"1C;61L:6YE+"`G<B<I.PH*("`@("`@("!F;W)E86-H("AE>'!L
M;V1E*")<;B(L("1R97-U;'0M/G-T9&]U="D@87,@)&QI;F4I('L*("`@("`@
M("`@("`@+RH@2&5A9&5R<R!A<F4@<')E9F%C960@=VET:"!A("<Z)R!A<R!T
M:&4@9FER<W0@8VAA<F%C=&5R(&]N('1H90H@("`@("`@("`@("`@("!L:6YE
M+B`J+PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1L:6YE+"`G.B<I(#T]/2`P
M*2!["B`@("`@("`@("`@("`@("`D;&]W97),:6YE(#T@4W1R:6YG.CIL;W=E
M<B@D;&EN92D["@H@("`@("`@("`@("`@("`@+RH@268@=V4@:&%V92!A(&ME
M>2`H<F%T:&5R('1H86X@82!S:6=N871U<F4@8FQO8VLI+"!G970@=&AE"B`@
M("`@("`@("`@("`@("`@("!K97DG<R!F:6YG97)P<FEN="`J+PH@("`@("`@
M("`@("`@("`@:68@*'-T<G!O<R@D;&]W97),:6YE+"`G.G!U8FQI8R!K97D@
M<&%C:V5T.B<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@("`@('-T
M<G!O<R@D;&]W97),:6YE+"`G.G-E8W)E="!K97D@<&%C:V5T.B<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1C;61L:6YE(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@("<M+7=I=&@M8V]L;VYS)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN<'5T"B`@("`@("`@("`@("`@("`@
M("`@*3L*("`@("`@("`@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?8V%L
M;$=P9R@D8VUD;&EN92P@)W(G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H
M<')E9U]M871C:"@B+RAS96-\<'5B*3HN*CHN*CHN*CHH6T$M1C`M.5U[,39]
M*3HO(BP@)&1A=&$M/G-T9&]U="P@)&UA=&-H97,I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6YG97)P<FEN="`]("1M871C:&5S6S)=.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("!I9B`H<W1R<&]S*"1L;W=E<DQI;F4L("<Z<'5B;&EC(&ME>2!P
M86-K970Z)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@)&AE
M861E<B`]("=P=6)L:6-?:V5Y)SL*("`@("`@("`@("`@("`@('T@96QS96EF
M("AS=')P;W,H)&QO=V5R3&EN92P@)SIS96-R970@:V5Y('!A8VME=#HG*2`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R(#T@)W-E
M8W)E=%]K97DG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D
M;&]W97),:6YE+"`G.G5S97(@:60@<&%C:V5T.B<I("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@("1U:61?:61X*RL["B`@("`@("`@("`@("`@
M("`@("`@)&QI;F4@/2!P<F5G7W)E<&QA8V5?8V%L;&)A8VLH)R]<7%Q<>"A;
M,"TY82UF77LR?2DO)RP@8W)E871E7V9U;F-T:6]N*"<D82<L("=R971U<FX@
M8VAR*&AE>&1E8R@D85LQ72DI.R<I+"`D;&EN92D["B`@("`@("`@("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H(B]<(BA;7EP\72LI7#PH6UY</ETK*5P^
M7"(O(BP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:&5A9&5R(#T@)VED)R`N("1U:61?:61X.PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;7EPH72LI7"@H+BLI7"DD
M+R<L('1R:6TH)&UA=&-H97-;,5TI+"`D8V]M;65N=%]M871C:&5S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)W-I9VYA
M='5R92==6R1H96%D97)=6R=N86UE)UT@/2!T<FEM*"1C;VUM96YT7VUA=&-H
M97-;,5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R
M87E;)W-I9VYA='5R92==6R1H96%D97)=6R=C;VUM96YT)UT@/2`D8V]M;65N
M=%]M871C:&5S6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)W-I
M9VYA='5R92==6R1H96%D97)=6R=N86UE)UT@/2!T<FEM*"1M871C:&5S6S%=
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y6R=S
M:6=N871U<F4G75LD:&5A9&5R75LG8V]M;65N="==(#T@)R<["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&%?87)R87E;)W-I9VYA='5R92==6R1H96%D97)=6R=E;6%I;"==(#T@)&UA
M=&-H97-;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y
M6R=S:6=N871U<F4G75LD:&5A9&5R75LG9FEN9V5R<')I;G0G72`]("1F:6YG
M97)P<FEN=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H<W1R<&]S*"1L;W=E<DQI;F4L("<Z<VEG;F%T=7)E('!A
M8VME=#HG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M96UP='DH)&AE861E<BD@?'P@96UP='DH)'5I9%]I9'@I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1H96%D97(@/2`G7U-)1TY!5%5212<["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"(O:V5Y:61<<RLH6S`M.4$M1ETK*2]I(BP@)&QI;F4L("1M871C
M:&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<VEG7VED(#T@)&UA
M=&-H97-;,5T["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A7V%R<F%Y
M6R=S:6=N871U<F4G75LD:&5A9&5R75LG<VEG7R<@+B`D<VEG7VED75LG9FEN
M9V5R<')I;G0G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%T85]A<G)A>5LG9FEN9V5R<')I;G0G72`]("1M871C:&5S6S%=
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<B`](&YU;&P["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!I9B`H*"1H96%D97(@/3T@)W-E8W)E=%]K97DG*2!\?"`H)&AE861E
M<B`]/2`G<'5B;&EC7VME>2<I*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*'!R96=?;6%T8V@H(B]C<F5A=&5D7',K*%QD*RDL7',K97AP:7)E<UQS*RA<
M9"LI+VDB+"`D;&EN92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1D871A7V%R<F%Y6R1H96%D97)=6R=C<F5A=&5D)UT@/2`D;6%T
M8VAE<ULQ73L*("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;
M)&AE861E<EU;)V5X<&ER97,G72`]("1M871C:&5S6S)=.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O7',K6W-P76ME>5Q;
M,%Q=.EQS*UQ;*%QD*RDO:2(L("1L:6YE+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&%?87)R87E;)&AE861E<EU;)W-I>F4G
M72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T@96QS96EF("@D:&5A9&5R*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H(B]V97)S:6]N7',K7&0K+%QS*V-R96%T
M961<<RLH7&0K*2]I(BP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9&%T85]A<G)A>5LG<VEG;F%T=7)E)UU;)&AE861E
M<EU;)W-I9U\G("X@)'-I9U]I9%U;)V-R96%T960G72`]("1M871C:&5S6S%=
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"(O
M9&EG97-T(&%L9V]<<RLH7&1[,7TI+R(L("1L:6YE+"`D;6%T8VAE<RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&UI8V%L9R`]("1T:&ES+3Y?:&%S
M:$%L9ULD;6%T8VAE<ULQ75T["B`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A7V%R<F%Y6R=S:6=N871U<F4G75LD:&5A9&5R75LG<VEG7R<@+B`D<VEG
M7VED75LG;6EC86QG)UT@/2`D;6EC86QG.PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&AE861E<B`]/2`G7U-)1TY!5%5212<I('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\J($QI:V5L>2!A('-I9VYA='5R92!B;&]C
M:RP@;F]T(&$@:V5Y+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&%?87)R87E;)W-I9VYA='5R92==6R=?4TE'3D%455)%)UU;)VUI8V%L
M9R==(#T@)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)'-I9U]I9"`]/2`D9FEN9V5R<')I
M;G0I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\J(%-E;&8@<VEG
M;FEN9R!S:6=N871U<F4@+2!W92!C86X@87-S=6UE('1H90H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;6EC86QG('9A;'5E(&9R;VT@=&AI<R!S
M:6=N871U<F4@:7,@=&AA="!F;W(*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H92!K97D@*B\*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A7V%R<F%Y6R=S:6=N871U<F4G75LG7U-)1TY!5%5212==6R=M:6-A
M;&<G72`]("1M:6-A;&<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&%T85]A<G)A>5LG<VEG;F%T=7)E)UU;)&AE861E<EU;)VUI8V%L9R==(#T@
M)&UI8V%L9SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&9I;F=E<G!R:6YT("8F("1D871A7V%R<F%Y
M6R=F:6YG97)P<FEN="==(#T@)&9I;F=E<G!R:6YT.PH*("`@("`@("!R971U
M<FX@)&1A=&%?87)R87D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&AU;6%N(')E861A8FQE(&EN9F]R;6%T:6]N(&]N(&$@4$=0(&ME>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P9W!D871A("!4:&4@4$=0(&1A
M=&$@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1A8G5L
M87(@:6YF;W)M871I;VX@;VX@=&AE(%!'4"!K97DN"B`@("`@*B\*("`@(&9U
M;F-T:6]N('!G<%!R971T>4ME>2@D<&=P9&%T82D*("`@('L*("`@("`@("`D
M;7-G(#T@)R<["B`@("`@("`@)'!A8VME=%]I;F9O(#T@)'1H:7,M/G!G<%!A
M8VME=$EN9F]R;6%T:6]N*"1P9W!D871A*3L*"B`@("`@("`@:68@*"%E;7!T
M>2@D<&%C:V5T7VEN9F];)W-I9VYA='5R92==*2D@>PH@("`@("`@("`@("`O
M*B!-86MI;F<@=&AE('!R;W!E<G1Y(&YA;65S('1H92!S86UE('=I9'1H(&9O
M<B!A;&P*("`@("`@("`@("`@("H@;&]C86QI>F%T:6]N<R`N*B\*("`@("`@
M("`@("`@)&QE9G1R;W<@/2!A<G)A>2A?*").86UE(BDL(%\H(DME>2!4>7!E
M(BDL(%\H(DME>2!#<F5A=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%\H(D5X<&ER871I;VX@1&%T92(I+"!?*")+97D@3&5N9W1H(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B0V]M;65N="(I+"!?
M*")%+4UA:6PB*2P@7R@B2&%S:"U!;&=O<FET:&TB*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?*")+97D@1FEN9V5R<')I;G0B*2D["B`@("`@
M("`@("`@("1L969T=VED=&@@/2!A<G)A>5]M87`H)W-T<FQE;B<L("1L969T
M<F]W*3L*("`@("`@("`@("`@)&UA>'=I9'1H("`](&UA>"@D;&5F='=I9'1H
M*2`K(#(["B`@("`@("`@("`@(&%R<F%Y7W=A;&LH)&QE9G1R;W<L(&-R96%T
M95]F=6YC=&EO;B@G)B1S+"`D:RP@)&TG+"`G)',@/2`D<R`N("(Z(B`N('-T
M<E]R97!E870H(B`B+"`D;2`M(%-T<FEN9SHZ;&5N9W1H*"1S*2D[)RDL("1M
M87AW:61T:"D["@H@("`@("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1P
M86-K971?:6YF;ULG<VEG;F%T=7)E)UTI(&%S("1U:61?:61X*2!["B`@("`@
M("`@("`@("`@("!I9B`H)'5I9%]I9'@@/3T@)U]324=.05154D4G*2!C;VYT
M:6YU93L*("`@("`@("`@("`@("`@("1K97E?:6YF;R`]("1T:&ES+3YP9W!0
M86-K9713:6=N871U<F5">55I9$EN9&5X*"1P9W!D871A+"`D=6ED7VED>"D[
M"B`@("`@("`@("`@("`@("`D;7-G("X]("1L969T<F]W6S!=("X@<W1R:7!C
M<VQA<VAE<R@D:V5Y7VEN9F];)VYA;64G72D@+B`B7&XB.PH@("`@("`@("`@
M("`@("`@)&US9R`N/2`D;&5F=')O=ULQ72`N("@H)&ME>5]I;F9O6R=K97E?
M='EP92==(#T]("=P=6)L:6-?:V5Y)RD@/R!?*")0=6)L:6,@2V5Y(BD@.B!?
M*")0<FEV871E($ME>2(I*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G
M("X]("1L969T<F]W6S)=("X@<W1R9G1I;64H(B5$(BP@)&ME>5]I;F9O6R=K
M97E?8W)E871E9"==*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]
M("1L969T<F]W6S-=("X@*&5M<'1Y*"1K97E?:6YF;ULG:V5Y7V5X<&ER97,G
M72D@/R`G6R<@+B!?*").979E<B(I("X@)UTG(#H@<W1R9G1I;64H(B5$(BP@
M)&ME>5]I;F9O6R=K97E?97AP:7)E<R==*2D@+B`B7&XB.PH@("`@("`@("`@
M("`@("`@)&US9R`N/2`D;&5F=')O=ULT72`N("1K97E?:6YF;ULG:V5Y7W-I
M>F4G72`N("(@0GET97-<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]("1L
M969T<F]W6S5=("X@*&5M<'1Y*"1K97E?:6YF;ULG8V]M;65N="==*2`_("=;
M)R`N(%\H(DYO;F4B*2`N("==)R`Z("1K97E?:6YF;ULG8V]M;65N="==*2`N
M(")<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]("1L969T<F]W6S9=("X@
M)&ME>5]I;F9O6R=E;6%I;"==("X@(EQN(CL*("`@("`@("`@("`@("`@("1M
M<V<@+CT@)&QE9G1R;W=;-UT@+B`H96UP='DH)&ME>5]I;F9O6R=M:6-A;&<G
M72D@/R`G6R<@+B!?*")5;FMN;W=N(BD@+B`G72<@.B`D:V5Y7VEN9F];)VUI
M8V%L9R==*2`N(")<;B(["B`@("`@("`@("`@("`@("`D;7-G("X]("1L969T
M<F]W6SA=("X@*&5M<'1Y*"1K97E?:6YF;ULG9FEN9V5R<')I;G0G72D@/R`G
M6R<@+B!?*")5;FMN;W=N(BD@+B`G72<@.B`D:V5Y7VEN9F];)V9I;F=E<G!R
M:6YT)UTI("X@(EQN7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&US9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@;VYL>2!I;F9O<FUA=&EO;B!O;B!T:&4@9FER<W0@240@=&AA="!M871C
M:&5S('1H92!E;6%I;"!A9&1R97-S"B`@("`@*B!I;G!U="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P9W!D871A("!4:&4@4$=0(&1A=&$@8FQO
M8VLN"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;6%I;"`@("!!;B!E+6UA:6P@
M861D<F5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A
M>2!W:71H(&EN9F]R;6%T:6]N(&]N('1H92!01U`@9&%T82!B;&]C:RX@268@
M86X*("`@("`J("`@("`@("`@("`@("`@(&5L96UE;G0@:7,@;F]T('!R97-E
M;G0@:6X@=&AE(&1A=&$@8FQO8VLL(&ET('=I;&P*("`@("`J("`@("`@("`@
M("`@("`@(&QI:V5W:7-E(&YO="!B92!S970@:6X@=&AE(&%R<F%Y+@H@("`@
M("H@/'!R93X*("`@("`J($%R<F%Y($9I96QD<SH*("`@("`J("TM+2TM+2TM
M+2TM+2T*("`@("`J(&ME>5]C<F5A=&5D("`]/B`@2V5Y(&-R96%T:6]N("T@
M54Y)6"!T:6UE<W1A;7`*("`@("`J(&ME>5]E>'!I<F5S("`]/B`@2V5Y(&5X
M<&ER871I;VX@+2!53DE8('1I;65S=&%M<"`H,"`](&YE=F5R(&5X<&ER97,I
M"B`@("`@*B!K97E?<VEZ92`@("`@/3X@(%-I>F4@;V8@=&AE(&ME>2!I;B!B
M:71S"B`@("`@*B!K97E?='EP92`@("`@/3X@(%1H92!K97D@='EP92`H<'5B
M;&EC7VME>2!O<B!S96-R971?:V5Y*0H@("`@("H@;F%M92`@("`@("`@(#T^
M("!&=6QL($YA;64*("`@("`J(&-O;6UE;G0@("`@("`]/B`@0V]M;65N=`H@
M("`@("H@96UA:6P@("`@("`@(#T^("!%+6UA:6P@061D<F5S<PH@("`@("H@
M9FEN9V5R<')I;G0@(#T^("`Q-BUB:70@:&5X('9A;'5E"B`@("`@*B!C<F5A
M=&5D("`@("`@/3X@(%-I9VYA='5R92!C<F5A=&EO;B`M(%5.25@@=&EM97-T
M86UP"B`@("`@*B!M:6-A;&<@("`@("`@/3X@(%1H92!H87-H('5S960@=&\@
M8W)E871E('1H92!S:6=N871U<F4*("`@("`J(#PO<')E/@H@("`@("HO"B`@
M("!F=6YC=&EO;B!P9W!086-K9713:6=N871U<F4H)'!G<&1A=&$L("1E;6%I
M;"D*("`@('L*("`@("`@("`D9&%T82`]("1T:&ES+3YP9W!086-K971);F9O
M<FUA=&EO;B@D<&=P9&%T82D["B`@("`@("`@)&ME>5]T>7!E(#T@;G5L;#L*
M("`@("`@("`D<F5T=7)N7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@+RH@
M0VAE8VL@=&AA="!;<VEG;F%T=7)E72!K97D@97AI<W1S+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)&1A=&%;)W-I9VYA='5R92==*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E='5R;E]A<G)A>3L*("`@("`@("!]"@H@("`@("`@("\J
M(%-T;W)E('1H92!S:6=N871U<F4@:6YF;W)M871I;VX@;F]W+B`J+PH@("`@
M("`@(&EF("@H)&5M86EL(#T]("=?4TE'3D%455)%)RD@)B8*("`@("`@("`@
M("`@:7-S970H)&1A=&%;)W-I9VYA='5R92==6R=?4TE'3D%455)%)UTI*2![
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=S:6=N871U<F4G75LD96UA
M:6Q=(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("`D<F5T
M=7)N7V%R<F%Y6R1K97E=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'5I9%]I9'@@/2`Q.PH*("`@("`@
M("`@("`@=VAI;&4@*&ES<V5T*"1D871A6R=S:6=N871U<F4G75LG:60G("X@
M)'5I9%]I9'A=*2D@>PH@("`@("`@("`@("`@("`@:68@*"1D871A6R=S:6=N
M871U<F4G75LG:60G("X@)'5I9%]I9'A=6R=E;6%I;"==(#T]("1E;6%I;"D@
M>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=S:6=N871U
M<F4G75LG:60G("X@)'5I9%]I9'A=(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1K97E=(#T@)'9A
M;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=6ED
M7VED>"LK.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]P9W!086-K9713:6=N871U<F4H)&1A=&$L("1R971U<FY?
M87)R87DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA
M=&EO;B!O;B!A(%!'4"!S:6=N871U<F4@96UB961D960@:6X@4$=0(&1A=&$N
M("!3:6UI;&%R"B`@("`@*B!T;R!P9W!086-K9713:6=N871U<F4H*2P@8G5T
M(')E='5R;G,@:6YF;W)M871I;VX@8GD@=6YI<75E(%5S97(@240*("`@("`J
M($EN9&5X("AF;W)M870@:61[;GT@=VAE<F4@;B!I<R!A;B!I;G1E9V5R(&]F
M(#$@;W(@9W)E871E<BDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&=P9&%T82`@(%-E92!P9W!086-K9713:6=N871U<F4H*2X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1U:61?:61X("!4:&4@54E$(&EN9&5X+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%-E92!P9W!086-K9713:6=N871U<F4H
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<&=P4&%C:V5T4VEG;F%T=7)E0GE5
M:61);F1E>"@D<&=P9&%T82P@)'5I9%]I9'@I"B`@("!["B`@("`@("`@)&1A
M=&$@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH)'!G<&1A=&$I.PH@
M("`@("`@("1K97E?='EP92`](&YU;&P["B`@("`@("`@)')E='5R;E]A<G)A
M>2`](&%R<F%Y*"D["@H@("`@("`@("\J(%-E87)C:"!F;W(@=&AE(%5)1"!I
M;F1E>"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1D871A6R=S:6=N871U<F4G
M72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1D871A6R=S:6=N871U<F4G75LD
M=6ED7VED>%TI*2!["B`@("`@("`@("`@(')E='5R;B`D<F5T=7)N7V%R<F%Y
M.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE('-I9VYA='5R92!I
M;F9O<FUA=&EO;B!N;W<N("HO"B`@("`@("`@9F]R96%C:"`H)&1A=&%;)W-I
M9VYA='5R92==6R1U:61?:61X72!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`D<F5T=7)N7V%R<F%Y6R1K97E=(#T@)'9A;'5E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&=P4&%C:V5T4VEG;F%T=7)E
M*"1D871A+"`D<F5T=7)N7V%R<F%Y*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@<V]M92!D871A('1O('1H92!P9W!086-K9713:6=N871U<F4J*"D@
M9G5N8W1I;VX@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D871A("`@("`@4V5E('!G
M<%!A8VME=%-I9VYA='5R92@I+@H@("`@("H@0'!A<F%M(&%R<F%Y("1R971A
M<G)A>2`@5&AE(')E='5R;B!A<G)A>2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@<F5T=7)N(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<&=P4&%C:V5T4VEG;F%T=7)E*"1D871A+"`D<F5T87)R87DI"B`@("![
M"B`@("`@("`@+RH@268@96UP='DL(')E='5R;B!N;W<N("HO"B`@("`@("`@
M:68@*&5M<'1Y*"1R971A<G)A>2DI('L*("`@("`@("`@("`@<F5T=7)N("1R
M971A<G)A>3L*("`@("`@("!]"@H@("`@("`@("1K97E?='EP92`](&YU;&P[
M"@H@("`@("`@("\J(%-T;W)E(&%N>2!P=6)L:6,O<')I=F%T92!K97D@:6YF
M;W)M871I;VXN("HO"B`@("`@("`@:68@*&ES<V5T*"1D871A6R=P=6)L:6-?
M:V5Y)UTI*2!["B`@("`@("`@("`@("1K97E?='EP92`]("=P=6)L:6-?:V5Y
M)SL*("`@("`@("!](&5L<V5I9B`H:7-S970H)&1A=&%;)W-E8W)E=%]K97DG
M72DI('L*("`@("`@("`@("`@)&ME>5]T>7!E(#T@)W-E8W)E=%]K97DG.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1K97E?='EP92D@>PH@("`@("`@("`@
M("`D<F5T87)R87E;)VME>5]T>7!E)UT@/2`D:V5Y7W1Y<&4["B`@("`@("`@
M("`@(&EF("AI<W-E="@D9&%T85LD:V5Y7W1Y<&5=6R=C<F5A=&5D)UTI*2![
M"B`@("`@("`@("`@("`@("`D<F5T87)R87E;)VME>5]C<F5A=&5D)UT@/2`D
M9&%T85LD:V5Y7W1Y<&5=6R=C<F5A=&5D)UT["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1D871A6R1K97E?='EP95U;)V5X<&ER97,G
M72DI('L*("`@("`@("`@("`@("`@("1R971A<G)A>5LG:V5Y7V5X<&ER97,G
M72`]("1D871A6R1K97E?='EP95U;)V5X<&ER97,G73L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)&ME>5]T>7!E75LG<VEZ
M92==*2D@>PH@("`@("`@("`@("`@("`@)')E=&%R<F%Y6R=K97E?<VEZ92==
M(#T@)&1A=&%;)&ME>5]T>7!E75LG<VEZ92==.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E=&%R<F%Y.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<VAO<G0@9FEN9V5R<')I;G0@*$ME
M>2!)1"D@;V8@=&AE(&ME>2!U<V5D('1O('-I9VX@82!B;&]C:PH@("`@("H@
M;V8@4$=0(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X
M="`@5&AE(%!'4"!S:6=N960@=&5X="!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE('-H;W)T(&9I;F=E<G!R:6YT(&]F('1H92!K
M97D@=7-E9"!T;R!S:6=N("1T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713:6=N97)S1FEN9V5R<')I;G0H)'1E>'0I"B`@("!["B`@("`@("`@)&9I
M;F=E<G!R:6YT(#T@;G5L;#L*"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C
M<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("1F<"`](&9O
M<&5N*"1I;G!U="P@)W<K)RD["B`@("`@("`@9G!U=',H)&9P+"`D=&5X="D[
M"B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@("1C;61L:6YE(#T@87)R
M87DH"B`@("`@("`@("`@("<M+79E<FEF>2<L"B`@("`@("`@("`@("1I;G!U
M="P*("`@("`@("`@("`@)S(^)C$G"B`@("`@("`@*3L*("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G<B<I.PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O9W!G.EQS4VEG;F%T=7)E7'-M861E+BI)1%QS
M*RA;02U&,"TY77LX?2E<<RLO)RP@)')E<W5L="T^<W1D;W5T+"`D;6%T8VAE
M<RDI('L*("`@("`@("`@("`@)&9I;F=E<G!R:6YT(#T@)&UA=&-H97-;,5T[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;F=E<G!R:6YT.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5F5R:69Y(&$@<&%S<W!H<F%S92!F;W(@82!G
M:79E;B!P=6)L:6,O<')I=F%T92!K97EP86ER+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!U8FQI8U]K97D@("!4:&4@=7-E<B=S(%!'4"!P=6)L
M:6,@:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I=F%T95]K97D@(%1H
M92!U<V5R)W,@4$=0('!R:79A=&4@:V5Y+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%S<W!H<F%S92`@(%1H92!U<V5R)W,@<&%S<W!H<F%S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92!O;B!V86QI
M9"!P87-S<&AR87-E+"!F86QS92!O;B!I;G9A;&ED"B`@("`@*B`@("`@("`@
M("`@("`@("`@('!A<W-P:')A<V4L(&%N9"!014%27T5R<F]R(&]N(&5R<F]R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!V97)I9GE087-S<&AR87-E*"1P=6)L
M:6-?:V5Y+"`D<')I=F%T95]K97DL("1P87-S<&AR87-E*0H@("`@>PH@("`@
M("`@("\J($-H96-K(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@
M("`D<V5C=7)E7V-H96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T
M:6]N*"D["B`@("`@("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*
M("`@("`@("!]"@H@("`@("`@("\J($5N8W)Y<'0@82!T97-T(&UE<W-A9V4N
M("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YE;F-R>7!T*"=497-T)RP@
M87)R87DH)W1Y<&4G(#T^("=M97-S86=E)RP@)W!U8FME>2<@/3X@)'!U8FQI
M8U]K97DI*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("\J(%1R>2!T;R!D96-R>7!T('1H92!M97-S86=E+B`J+PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^9&5C<GEP="@D<F5S=6QT+"!A<G)A>2@G
M='EP92<@/3X@)VUE<W-A9V4G+"`G<'5B:V5Y)R`]/B`D<'5B;&EC7VME>2P@
M)W!R:79K97DG(#T^("1P<FEV871E7VME>2P@)W!A<W-P:')A<V4G(#T^("1P
M87-S<&AR87-E*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!A<G-E<R!A(&UE<W-A9V4@:6YT;R!T97AT(&%N9"!01U`@8V]M<&]N96YT
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!T;R!P87)S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A
M<G)A>2!W:71H('1H92!P87)S960@=&5X="P@<F5T=7)N960@:6X@8FQO8VMS
M(&]F"B`@("`@*B`@("`@("`@("`@("`@("!T97AT(&-O<G)E<W!O;F1I;F<@
M=&\@=&AE:7(@86-T=6%L(&]R9&5R+@H@("`@("H@/'!R93X*("`@("`J(%)E
M='5R;B!A<G)A>3H*("`@("`J($ME>2`@("`@("`@(%9A;'5E"B`@("`@*B`M
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"B`@("`@*B`G='EP92<@(#T^("!4:&4@='EP92!O9B!D871A(&-O;G1A
M:6YE9"!I;B!B;&]C:RX*("`@("`J("`@("`@("`@("`@(%9A;&ED('1Y<&5S
M(&%R92!D969I;F5D(&%T('1H92!T;W`@;V8@=&AI<R!C;&%S<PH@("`@("H@
M("`@("`@("`@("`@*'1H92!01U!?05)-3U)?*B!C;VYS=&%N=',I+@H@("`@
M("H@)V1A=&$G("`]/B`@5&AE(&%C='5A;"!D871A(&9O<B!E86-H('-E8W1I
M;VXN"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V50
M1U!$871A*"1T97AT*0H@("`@>PH@("`@("`@("1D871A(#T@87)R87DH*3L*
M"B`@("`@("`@)&)U9F9E<B`](&5X<&QO9&4H(EQN(BP@)'1E>'0I.PH*("`@
M("`@("`O*B!3970@)'1E;7!?87)R87D@=&\@8F4@;V8@='EP92!01U!?05)-
M3U)?5$585"X@*B\*("`@("`@("`D=&5M<%]A<G)A>2`](&%R<F%Y*"D["B`@
M("`@("`@)'1E;7!?87)R87E;)W1Y<&4G72`](%!'4%]!4DU/4E]415A4.PH*
M("`@("`@("!F;W)E86-H("@D8G5F9F5R(&%S("1V86QU92D@>PH@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+UXM+2TM+2A"14=)3GQ%3D0I(%!'4"`H
M6UXM72LI+2TM+2U<<RHD+R<L("1V86QU92P@)&UA=&-H97,I*2!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1E;7!?87)R87E;)V1A=&$G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D9&%T85M=(#T@)'1E;7!?87)R87D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!U;G-E="@D=&5M<%]A
M<G)A>2D["B`@("`@("`@("`@("`@("`D=&5M<%]A<G)A>2`](&%R<F%Y*"D[
M"@H@("`@("`@("`@("`@("`@:68@*"1M871C:&5S6S%=(#T]/2`G0D5'24XG
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1E;7!?87)R87E;)W1Y<&4G72`]
M("1T:&ES+3Y?87)M;W);)&UA=&-H97-;,EU=.PH@("`@("`@("`@("`@("`@
M("`@("1T96UP7V%R<F%Y6R=D871A)UU;72`]("1V86QU93L*("`@("`@("`@
M("`@("`@('T@96QS96EF("@D;6%T8VAE<ULQ72`]/3T@)T5.1"<I('L*("`@
M("`@("`@("`@("`@("`@("`D=&5M<%]A<G)A>5LG='EP92==(#T@4$=07T%2
M34]27U1%6%0["B`@("`@("`@("`@("`@("`@("`@)&1A=&%;8V]U;G0H)&1A
M=&$I("T@,5U;)V1A=&$G75M=(#T@)'9A;'5E.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1E;7!?
M87)R87E;)V1A=&$G75M=(#T@)'9A;'5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)'1E;7!?87)R87E;)V1A=&$G72DI
M('L*("`@("`@("`@("`@)&1A=&%;72`]("1T96UP7V%R<F%Y.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A(%!'4"!P=6)L:6,@:V5Y(&9R;VT@82!P=6)L:6,@:V5Y
M<V5R=F5R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9P<FEN="`@
M5&AE(&9I;F=E<G!R:6YT(&]F('1H92!01U`@:V5Y+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V5R=F5R("!4:&4@:V5Y<V5R=F5R('1O('5S92X*("`@("`J
M($!P87)A;2!F;&]A="`D=&EM96]U="`@5&AE(&ME>7-E<G9E<B!T:6UE;W5T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@4$=0('!U8FQI
M8R!K97DL(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!U8FQI8TME>7-E<G9E<B@D9G!R:6YT+"`D<V5R=F5R(#T@
M4$=07TM%65-%4E9%4E]054),24,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1I;65O=70@/2!01U!?2T594T525D527U1)345/550I"B`@
M("!["B`@("`@("`@+RH@1V5T('1H92`X(&-H87)A8W1E<B!F:6YG97)P<FEN
M="!S=')I;F<N("HO"B`@("`@("`@:68@*'-T<G!O<R@D9G!R:6YT+"`G,'@G
M*2`]/3T@,"D@>PH@("`@("`@("`@("`D9G!R:6YT(#T@<W5B<W1R*"1F<')I
M;G0L(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R;&5N*"1F<')I;G0I
M(#X@."D@>PH@("`@("`@("`@("`D9G!R:6YT(#T@<W5B<W1R*"1F<')I;G0L
M(#@I.PH@("`@("`@('T*("`@("`@("`D9G!R:6YT(#T@)S!X)R`N("1F<')I
M;G0["@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE('!U8FQI8R!K97ES97)V
M97(N("HO"B`@("`@("`@)&-M9"`]("='150@+W!K<R]L;V]K=7`_;W`]9V5T
M)F5X86-T/6]N)G-E87)C:#TG("X@)&9P<FEN="`N("<@2%144"\Q+C`G.PH@
M("`@("`@("1O=71P=70@/2`D=&AI<RT^7V-O;FYE8W1+97ES97)V97(H)&-M
M9"P@)'-E<G9E<BP@)'1I;65O=70I.PH@("`@("`@(&EF("AI<U]A*"1O=71P
M=70L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1O=71P
M=70["B`@("`@("`@?0H*("`@("`@("`O*B!3=')I<"!(5$U,(%1A9W,@9G)O
M;2!O=71P=70N("HO"B`@("`@("`@:68@*"@D<W1A<G0@/2!S=')S='(H)&]U
M='!U="P@)RTM+2TM0D5'24XG*2DI('L*("`@("`@("`@("`@)&QE;F=T:"`]
M('-T<G!O<R@D<W1A<G0L("<M+2TM+45.1"<I("L@,S0["B`@("`@("`@("`@
M(')E='5R;B!S=6)S='(H)'-T87)T+"`P+"`D;&5N9W1H*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")#;W5L9"!N;W0@;V)T86EN('!U8FQI8R!K97D@9G)O;2!T:&4@:V5Y<V5R
M=F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!396YD<R!A(%!'4"!P=6)L:6,@:V5Y('1O(&$@<'5B;&EC
M(&ME>7-E<G9E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P=6)K
M97D@(%1H92!01U`@<'5B;&EC(&ME>0H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5R=F5R("!4:&4@:V5Y<V5R=F5R('1O('5S92X*("`@("`J($!P87)A;2!F
M;&]A="`D=&EM96]U="`@5&AE(&ME>7-E<G9E<B!T:6UE;W5T+@H@("`@("H*
M("`@("`J($!R971U<FX@4$5!4E]%<G)O<B`@4$5!4E]%<G)O<B!O;B!E<G)O
M<B]F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P=710=6)L:6-+97ES
M97)V97(H)'!U8FME>2P@)'-E<G9E<B`](%!'4%]+15E315)615)?4%5"3$E#
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:6UE;W5T(#T@
M4$=07TM%65-%4E9%4E]424U%3U54*0H@("`@>PH@("`@("`@("\J($=E="!T
M:&4@9FEN9V5R<')I;G0@;V8@=&AE('!U8FQI8R!K97DN("HO"B`@("`@("`@
M)&EN9F\@/2`D=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH)'!U8FME>2D[
M"@H@("`@("`@("\J(%-E92!I9B!T:&4@<'5B;&EC(&ME>2!A;')E861Y(&5X
M:7-T<R!O;B!T:&4@:V5Y<V5R=F5R+B`J+PH@("`@("`@(&EF("@A:7-?82@D
M=&AI<RT^9V5T4'5B;&EC2V5Y<V5R=F5R*"1I;F9O6R=F:6YG97)P<FEN="==
M+"`D<V5R=F5R+"`D=&EM96]U="DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B2V5Y(&%L<F5A9'D@
M97AI<W1S(&]N('1H92!P=6)L:6,@:V5Y<V5R=F5R+B(I+"`G:&]R9&4N=V%R
M;FEN9R<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@
M<'5B;&EC(&ME>7-E<G9E<BX@7V-O;FYE8W1+97ES97)V97(H*2!R971U<FYS
M(&$*("`@("`@("`@("!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<B!A;F0@
M=&AE(&]U='!U="!T97AT(&]N('-U8V-E<W,N("HO"B`@("`@("`@)'!U8FME
M>2`]("=K97ET97AT/2<@+B!U<FQE;F-O9&4H<G1R:6TH)'!U8FME>2DI.PH@
M("`@("`@("1C;60@/2!A<G)A>2@*("`@("`@("`@("`@)U!/4U0@+W!K<R]A
M9&0@2%144"\Q+C`G+`H@("`@("`@("`@("`G2&]S=#H@)R`N("1S97)V97(@
M+B`G.C$Q,S<Q)RP*("`@("`@("`@("`@)U5S97(M06=E;G0Z($AO<F1E($%P
M<&QI8V%T:6]N($9R86UE=V]R:R`S+C$G+`H@("`@("`@("`@("`G0V]N=&5N
M="U4>7!E.B!A<'!L:6-A=&EO;B]X+7=W=RUF;W)M+75R;&5N8V]D960G+`H@
M("`@("`@("`@("`G0V]N=&5N="U,96YG=&@Z("<@+B!S=')L96XH)'!U8FME
M>2DL"B`@("`@("`@("`@("=#;VYN96-T:6]N.B!C;&]S92<L"B`@("`@("`@
M("`@("<G+`H@("`@("`@("`@("`D<'5B:V5Y"B`@("`@("`@*3L*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T2V5Y<V5R=F5R*&EM<&QO9&4H
M(EQR7&XB+"`D8VUD*2P@)'-E<G9E<BP@)'1I;65O=70I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N;F5C=',@=&\@82!P=6)L:6,@:V5Y('-E<G9E<B!V:6$@2$M0("A(
M;W)R;W=I='H@2V5Y<V5R=F5R(%!R;W1O8V]L*2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C
M;VUM86YD("!4:&4@4$=0(&-O;6UA;F0@=&\@<G5N+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V5R=F5R("`@5&AE(&ME>7-E<G9E<B!T;R!U<V4N"B`@("`@
M*B!`<&%R86T@9FQO870@)'1I;65O=70@("!4:&4@=&EM96]U="!V86QU92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('1E>'0@9G)O;2!S
M=&%N9&%R9"!O=71P=70@;VX@<W5C8V5S<RP@;W(@4$5!4E]%<G)O<@H@("`@
M("H@("`@("`@("`@("`@("`@(&]N(&5R<F]R+V9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C;VYN96-T2V5Y<V5R=F5R*"1C;VUM86YD+"`D<V5R
M=F5R+"`D=&EM96]U="D*("`@('L*("`@("`@("`D8V]N;E)E9G5S92`](#`[
M"B`@("`@("`@)&]U='!U="`]("<G.PH*("`@("`@("`O*B!!='1E;7!T('1O
M(&=E="!T:&4@:V5Y(&9R;VT@=&AE(&ME>7-E<G9E<BX@*B\*("`@("`@("!D
M;R!["B`@("`@("`@("`@("1C;VYN17)R;W(@/2!F86QS93L*("`@("`@("`@
M("`@)&5R<FYO(#T@)&5R<G-T<B`](&YU;&P["@H@("`@("`@("`@("`O*B!4
M:&4@2$M0('-E<G9E<B!I<R!L;V-A=&5D(&]N('!O<G0@,3$S-S$N("HO"B`@
M("`@("`@("`@("1F<"`]($!F<V]C:V]P96XH)'-E<G9E<BP@)S$Q,S<Q)RP@
M)&5R<FYO+"`D97)R<W1R+"`D=&EM96]U="D["B`@("`@("`@("`@(&EF("@A
M)&9P*2!["B`@("`@("`@("`@("`@("`D8V]N;D5R<F]R(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9P=71S*"1F<"P@
M)&-O;6UA;F0@+B`B7&Y<;B(I.PH@("`@("`@("`@("`@("`@=VAI;&4@*"%F
M96]F*"1F<"DI('L*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X](&9G
M971S*"1F<"P@,3`R-"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1C;VYN17)R;W(I('L*("`@("`@("`@("`@("`@(&EF("@K*R1C;VYN
M4F5F=7-E(#T]/2!01U!?2T594T525D527U)%1E5312D@>PH@("`@("`@("`@
M("`@("`@("`@(&EF("@D97)R;F\@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D;W5T<'5T(#T@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;VYN96-T
M:6]N(')E9G5S960@=&\@=&AE('!U8FQI8R!K97ES97)V97(N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@/2!014%2.CIR86ES945R<F]R
M*'-P<FEN=&8H7R@B0V]N;F5C=&EO;B!R969U<V5D('1O('1H92!P=6)L:6,@
M:V5Y<V5R=F5R+B!296%S;VXZ("5S("@E<RDB*2P@4W1R:6YG.CIC;VYV97)T
M0VAA<G-E="@D97)R<W1R+"!.3%,Z.F=E=$5X=&5R;F%L0VAA<G-E="@I*2P@
M)&5R<FYO*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL92`H)&-O;FY%<G)O<BD[
M"@H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@
M("H@16YC<GEP=',@=&5X="!U<VEN9R!01U`N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E(%!'4"!E;F-R>7!T
M960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@5&AE('!A<F%M971E
M<G,@;F5E9&5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(%-E92!T:&4@:6YD:79I9'5A;"!?96YC<GEP="HH*2!F=6YC
M=&EO;G,@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('!A
M<F%M971E<B!R97%U:7)E;65N=',N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!E;F-R>7!T960@;65S<V%G92P@;W(@4$5!4E]%<G)O<B!O
M;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@96YC<GEP="@D=&5X="P@
M)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)W1Y<&4G72DI('L*("`@("`@("`@("`@:68@*"1P87)A;7-;)W1Y
M<&4G72`]/3T@)VUE<W-A9V4G*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]E;F-R>7!T365S<V%G92@D=&5X="P@)'!A<F%M<RD["B`@("`@
M("`@("`@('T@96QS96EF("@D<&%R86US6R=T>7!E)UT@/3T]("=S:6=N871U
M<F4G*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]E;F-R>7!T
M4VEG;F%T=7)E*"1T97AT+"`D<&%R86US*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E8W)Y<'1S('1E>'0@=7-I
M;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4
M:&4@=&5X="!T;R!B92!01U`@9&5C<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@9&5C<GEP
M=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!3964@=&AE(&EN
M9&EV:61U86P@7V1E8W)Y<'0J*"D@9G5N8W1I;VYS(&9O<B!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97(@<F5Q=6ER96UE;G1S
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9&5C<GEP=&5D
M(&UE<W-A9V4L(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1E8W)Y<'0H)'1E>'0L("1P87)A;7,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=T>7!E)UTI*2!["B`@
M("`@("`@("`@(&EF("@D<&%R86US6R=T>7!E)UT@/3T]("=M97-S86=E)RD@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&5C<GEP=$UE<W-A
M9V4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@("!](&5L<V5I9B`H*"1P
M87)A;7-;)W1Y<&4G72`]/3T@)W-I9VYA='5R92<I('Q\"B`@("`@("`@("`@
M("`@("`@("`@("`H)'!A<F%M<ULG='EP92==(#T]/2`G9&5T86-H960M<VEG
M;F%T=7)E)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E
M8W)Y<'13:6=N871U<F4H)'1E>'0L("1P87)A;7,I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!A('1E
M;7!O<F%R>2!G<&<@:V5Y<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4:&4@
M='EP92!O9B!K97D@=&\@86YA;'EZ92X@16ET:&5R("=P=6)L:6,G"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`H1&5F875L="D@;W(@)W!R:79A=&4G
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($-O;6UA;F0@;&EN92!K
M97ES=')I;F<@;W!T:6]N('1O('5S92!W:71H(&=P9R!P<F]G<F%M+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?8W)E871E2V5Y<FEN9R@D='EP92`]("=P=6)L
M:6,G*0H@("`@>PH@("`@("`@("1T>7!E(#T@4W1R:6YG.CIL;W=E<B@D='EP
M92D["@H@("`@("`@(&EF("@D='EP92`]/3T@)W!U8FQI8R<I('L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<'5B;&EC2V5Y<FEN9RDI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<'5B;&EC2V5Y<FEN9R`]("1T:&ES+3Y?
M8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`G+2UK97ER:6YG("<@+B`D=&AI<RT^7W!U8FQI
M8TME>7)I;F<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]/2`G<')I=F%T
M92<I('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<')I=F%T94ME
M>7)I;F<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!R:79A=&5+97ER
M:6YG(#T@)'1H:7,M/E]C<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("<M+7-E8W)E="UK97ER
M:6YG("<@+B`D=&AI<RT^7W!R:79A=&5+97ER:6YG.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@4$=0(&ME>7,@=&\@=&AE(&ME>7)I
M;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&UI>&5D("1K97ES("`@02!S:6YG;&4@:V5Y(&]R(&%N(&%R
M<F%Y(&]F(&ME>2AS*2!T;R!A9&0@=&\@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!K97ER:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP
M92`@5&AE('1Y<&4@;V8@:V5Y*',I('1O(&%D9"X@16ET:&5R("=P=6)L:6,G
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`H1&5F875L="D@;W(@)W!R
M:79A=&4G"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($-O;6UA;F0@
M;&EN92!K97ES=')I;F<@;W!T:6]N('1O('5S92!W:71H(&=P9R!P<F]G<F%M
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<'5T26Y+97ER:6YG*"1K97ES(#T@
M87)R87DH*2P@)'1Y<&4@/2`G<'5B;&EC)RD*("`@('L*("`@("`@("`D='EP
M92`](%-T<FEN9SHZ;&]W97(H)'1Y<&4I.PH*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1K97ES*2D@>PH@("`@("`@("`@("`D:V5Y<R`](&%R<F%Y*"1K97ES
M*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T:&4@:V5Y<FEN9W,@
M:68@=&AE>2!D;VXG="!A;')E861Y(&5X:7-T+B`J+PH@("`@("`@("1K97ER
M:6YG(#T@)'1H:7,M/E]C<F5A=&5+97ER:6YG*"1T>7!E*3L*"B`@("`@("`@
M+RH@4W1O<F4@=&AE(&ME>2AS*2!I;B!T:&4@:V5Y<FEN9RX@*B\*("`@("`@
M("`D8VUD;&EN92`](&%R<F%Y*`H@("`@("`@("`@("`G+2UA;&QO=RUS96-R
M970M:V5Y+6EM<&]R="<L"B`@("`@("`@("`@("<M+69A<W0M:6UP;W)T)RP*
M("`@("`@("`@("`@)&ME>7)I;F<*("`@("`@("`I.PH@("`@("`@("1T:&ES
M+3Y?8V%L;$=P9R@D8VUD;&EN92P@)W<G+"!A<G)A>5]V86QU97,H)&ME>7,I
M*3L*"B`@("`@("`@<F5T=7)N("1K97ER:6YG.PH@("`@?0H*("`@("\J*@H@
M("`@("H@16YC<GEP=',@82!M97-S86=E(&EN(%!'4"!F;W)M870@=7-I;F<@
M82!P=6)L:6,@:V5Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@("!4:&4@=&5X="!T
M;R!B92!E;F-R>7!T960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!E;F-R>7!T:6]N+@H@("`@("H@
M/'!R93X*("`@("`J(%!A<F%M971E<G,Z"B`@("`@*B`]/3T]/3T]/3T]/0H@
M("`@("H@)W1Y<&4G("`@(#T^("`G;65S<V%G92<@*%)%455)4D5$*0H@("`@
M("H@)W!U8FME>2<@(#T^("!01U`@<'5B;&EC(&ME>2X@*$]P=&EO;F%L*2`H
M1$504D5#051%1"D*("`@("`J("=E;6%I;"<@("`]/B`@12UM86EL(&%D9')E
M<W,@;V8@<F5C:7!I96YT+B!)9B!N;W0@<')E<V5N="P@;W(@;F]T(&9O=6YD
M"B`@("`@*B`@("`@("`@("`@("`@(&EN('1H92!P=6)L:6,@:V5Y+"!T:&4@
M9FER<W0@92UM86EL(&%D9')E<W,@9F]U;F0@:6X@=&AE"B`@("`@*B`@("`@
M("`@("`@("`@(&ME>2!W:6QL(&)E('5S960@:6YS=&5A9"X@*$]P=&EO;F%L
M*2`H1$504D5#051%1"D*("`@("`J("=R96-I<',G("`]/B`@06X@87)R87D@
M=VET:"!T:&4@92UM86EL(&%D9')E<W,@;V8@=&AE(')E8VEP:65N="!A<PH@
M("`@("H@("`@("`@("`@("`@("!T:&4@:V5Y(&%N9"!T:&%T('!E<G-O;B=S
M('!U8FQI8R!K97D@87,@=&AE('9A;'5E+@H@("`@("H@("`@("`@("`@("`@
M("`H4D5154E2140I"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(&5N8W)Y<'1E9"!M97-S86=E+"!O<B!014%27T5R
M<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?96YC<GEP=$UE
M<W-A9V4H)'1E>'0L("1P87)A;7,I"B`@("!["B`@("`@("`@)&5M86EL(#T@
M;G5L;#L*"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=R96-I<',G72DI
M('L*("`@("`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A<F%M971E
M<G,N("HO"B`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y
M)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I<F5D('1O(&5N8W)Y<'0@
M82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+RH@1V5T(&EN9F]R;6%T:6]N(&]N('1H92!K97DN("HO
M"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=E;6%I;"==*2D@>PH@
M("`@("`@("`@("`@("`@)&ME>5]I;F9O(#T@)'1H:7,M/G!G<%!A8VME=%-I
M9VYA='5R92@D<&%R86US6R=P=6)K97DG72P@)'!A<F%M<ULG96UA:6PG72D[
M"B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1K97E?:6YF;RDI('L*("`@
M("`@("`@("`@("`@("`@("`D96UA:6P@/2`D:V5Y7VEN9F];)V5M86EL)UT[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\J($EF('=E(&AA=F4@;F\@96UA:6P@861D<F5S<R!A="!T:&ES('!O:6YT
M+"!U<V4@=&AE(&9I<G-T(&5M86EL"B`@("`@("`@("`@("`@(&%D9')E<W,@
M9F]U;F0@:6X@=&AE('!U8FQI8R!K97DN("HO"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D96UA:6PI*2!["B`@("`@("`@("`@("`@("`D:V5Y7VEN9F\@/2`D
M=&AI<RT^<&=P4&%C:V5T26YF;W)M871I;VXH)'!A<F%M<ULG<'5B:V5Y)UTI
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1K97E?:6YF;ULG<VEG;F%T
M=7)E)UU;)VED,2==6R=E;6%I;"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1E;6%I;"`]("1K97E?:6YF;ULG<VEG;F%T=7)E)UU;)VED,2==6R=E;6%I
M;"==.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!R96-I<&EE;G0G<R!E+6UA:6P@861D<F5S<RXB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1P87)A;7-;)W)E8VEP<R==(#T@87)R87DH)&5M86EL
M(#T^("1P87)A;7-;)W!U8FME>2==*3L*("`@("`@("!]"@H@("`@("`@("\J
M(%-T;W)E('!U8FQI8R!K97D@:6X@=&5M<&]R87)Y(&ME>7)I;F<N("HO"B`@
M("`@("`@)&ME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A>5]V
M86QU97,H)'!A<F%M<ULG<F5C:7!S)UTI*3L*"B`@("`@("`@+RH@16YC<GEP
M="!T:&4@9&]C=6UE;G0N("HO"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A>2@*
M("`@("`@("`@("`@)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UB871C:"<L
M"B`@("`@("`@("`@("<M+6%L=V%Y<RUT<G5S="<L"B`@("`@("`@("`@("1K
M97ER:6YG+`H@("`@("`@("`@("`G+2UE;F-R>7!T)PH@("`@("`@("D["B`@
M("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D<&%R86US6R=R96-I<',G72D@
M87,@)'9A;"D@>PH@("`@("`@("`@("`D8VUD;&EN95M=(#T@)RTM<F5C:7!I
M96YT("<@+B`D=F%L.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@)'1H
M:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G=R<L("1T97AT+"!T<G5E+"!T<G5E
M*3L*("`@("`@("!I9B`H96UP='DH)')E<W5L="T^;W5T<'5T*2D@>PH@("`@
M("`@("`@("`D97)R;W(@/2!P<F5G7W)E<&QA8V4H)R]<;BXJ+R<L("<G+"`D
M<F5S=6QT+3YS=&1E<G(I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@4$=0(&5N8W)Y<'0@;65S<V%G93H@(BD@
M+B`D97)R;W(L("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'0M/F]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-I9VYS(&$@;65S<V%G92!I;B!01U`@9F]R;6%T('5S:6YG(&$@<')I=F%T
M92!K97DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@(%1H92!T97AT('1O(&)E('-I
M9VYE9"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!4:&4@<&%R86UE
M=&5R<R!N965D960@9F]R('-I9VYI;F<N"B`@("`@*B`\<')E/@H@("`@("H@
M4&%R86UE=&5R<SH*("`@("`J(#T]/3T]/3T]/3T]"B`@("`@*B`G='EP92<@
M("`@("`@(#T^("`G<VEG;F%T=7)E)R`H4D5154E2140I"B`@("`@*B`G<'5B
M:V5Y)R`@("`@(#T^("!01U`@<'5B;&EC(&ME>2X@*%)%455)4D5$*0H@("`@
M("H@)W!R:79K97DG("`@("`]/B`@4$=0('!R:79A=&4@:V5Y+B`H4D5154E2
M140I"B`@("`@*B`G<&%S<W!H<F%S92<@(#T^("!087-S<&AR87-E(&9O<B!0
M1U`@2V5Y+B`H4D5154E2140I"B`@("`@*B`G<VEG='EP92<@("`@(#T^("!$
M971E<FUI;F4@=&AE('-I9VYA='5R92!T>7!E('1O('5S92X@*$]P=&EO;F%L
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@)V-L96%R=&5X="<@("TM("!-
M86ME(&$@8VQE87(@=&5X="!S:6=N871U<F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("=D971A8V@G("`@("`M+2`@36%K92!A(&1E=&%C:&5D('-I9VYA
M='5R92`H1$5&055,5"D*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<VEG;F5D(&UE<W-A9V4L(&]R(%!%05)?17)R
M;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E;F-R>7!T4VEG
M;F%T=7)E*"1T97AT+"`D<&%R86US*0H@("`@>PH@("`@("`@("\J($-H96-K
M(&9O<B!S96-U<F4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D<V5C=7)E7V-H
M96-K(#T@)'1H:7,M/G)E<75I<F5396-U<F5#;VYN96-T:6]N*"D["B`@("`@
M("`@:68@*&ES7V$H)'-E8W5R95]C:&5C:RP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'-E8W5R95]C:&5C:SL*("`@("`@("!]"@H@
M("`@("`@("\J($-H96-K(&9O<B!R97%U:7)E9"!P87)A;65T97)S+B`J+PH@
M("`@("`@(&EF("@A:7-S970H)'!A<F%M<ULG<'5B:V5Y)UTI('Q\"B`@("`@
M("`@("`@("%I<W-E="@D<&%R86US6R=P<FEV:V5Y)UTI('Q\"B`@("`@("`@
M("`@("%I<W-E="@D<&%R86US6R=P87-S<&AR87-E)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D$@<'5B;&EC(%!'4"!K
M97DL('!R:79A=&4@4$=0(&ME>2P@86YD('!A<W-P:')A<V4@87)E(')E<75I
M<F5D('1O('-I9VX@82!M97-S86=E+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@
M("`@("!]"@H@("`@("`@("\J($-R96%T92!T96UP(&9I;&5S(&9O<B!I;G!U
M="X@*B\*("`@("`@("`D:6YP=70@/2`D=&AI<RT^7V-R96%T951E;7!&:6QE
M*"=H;W)D92UP9W`G*3L*"B`@("`@("`@+RH@16YC<GEP=&EO;B!R97%U:7)E
M<R!B;W1H(&ME>7)I;F=S+B`J+PH@("`@("`@("1P=6)?:V5Y<FEN9R`]("1T
M:&ES+3Y?<'5T26Y+97ER:6YG*&%R<F%Y*"1P87)A;7-;)W!U8FME>2==*2D[
M"B`@("`@("`@)'-E8U]K97ER:6YG(#T@)'1H:7,M/E]P=71);DME>7)I;F<H
M87)R87DH)'!A<F%M<ULG<')I=FME>2==*2P@)W!R:79A=&4G*3L*"B`@("`@
M("`@+RH@4W1O<F4@;65S<V%G92!I;B!T96UP;W)A<GD@9FEL92X@*B\*("`@
M("`@("`D9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S
M*"1F<"P@)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`O
M*B!$971E<FUI;F4@=&AE('-I9VYA='5R92!T>7!E('1O('5S92X@*B\*("`@
M("`@("`D8VUD;&EN92`](&%R<F%Y*"D["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)W-I9W1Y<&4G72D@)B8*("`@("`@("`@("`@)'!A<F%M<ULG<VEG
M='EP92==(#T]("=C;&5A<G1E>'0G*2!["B`@("`@("`@("`@("1S:6=N7W1Y
M<&4@/2`G+2UC;&5A<G-I9VXG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1S:6=N7W1Y<&4@/2`G+2UD971A8V@M<VEG;B<["B`@("`@("`@?0H*
M("`@("`@("`O*B!!9&1I=&EO;F%L($=01R!O<'1I;VYS+B`J+PH@("`@("`@
M("1C;61L:6YE("L](&%R<F%Y*`H@("`@("`@("`@("`G+2UA<FUO<B<L"B`@
M("`@("`@("`@("<M+6)A=&-H)RP*("`@("`@("`@("`@)RTM<&%S<W!H<F%S
M92UF9"`P)RP*("`@("`@("`@("`@)'-E8U]K97ER:6YG+`H@("`@("`@("`@
M("`D<'5B7VME>7)I;F<L"B`@("`@("`@("`@("1S:6=N7W1Y<&4L"B`@("`@
M("`@("`@("1I;G!U=`H@("`@("`@("D["@H@("`@("`@("\J(%-I9VX@=&AE
M(&1O8W5M96YT+B`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&Q'
M<&<H)&-M9&QI;F4L("=W)RP@)'!A<F%M<ULG<&%S<W!H<F%S92==+"!T<G5E
M+"!T<G5E*3L*("`@("`@("!I9B`H96UP='DH)')E<W5L="T^;W5T<'5T*2D@
M>PH@("`@("`@("`@("`D97)R;W(@/2!P<F5G7W)E<&QA8V4H)R]<;BXJ+R<L
M("<G+"`D<F5S=6QT+3YS=&1E<G(I.PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@4$=0('-I9VX@;65S<V%G93H@
M(BD@+B`D97)R;W(L("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT+3YO=71P=70["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5C<GEP=',@86X@4$=0(&5N8W)Y
M<'1E9"!M97-S86=E('5S:6YG(&$@<')I=F%T92]P=6)L:6,@:V5Y<&%I<B!A
M;F0@80H@("`@("H@<&%S<VAP<F%S92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@
M5&AE('1E>'0@=&\@8F4@9&5C<GEP=&5D+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P87)A;7,@(%1H92!P87)A;65T97)S(&YE961E9"!F;W(@9&5C<GEP=&EO
M;BX*("`@("`J(#QP<F4^"B`@("`@*B!087)A;65T97)S.@H@("`@("H@/3T]
M/3T]/3T]/3T*("`@("`J("=T>7!E)R`@("`@("`@/3X@("=M97-S86=E)R`H
M4D5154E2140I"B`@("`@*B`G<'5B:V5Y)R`@("`@(#T^("!01U`@<'5B;&EC
M(&ME>2X@*%)%455)4D5$*0H@("`@("H@)W!R:79K97DG("`@("`]/B`@4$=0
M('!R:79A=&4@:V5Y+B`H4D5154E2140I"B`@("`@*B`G<&%S<W!H<F%S92<@
M(#T^("!087-S<&AR87-E(&9O<B!01U`@2V5Y+B`H4D5154E2140I"B`@("`@
M*B`\+W!R93X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!!;B!O
M8FIE8W0@=VET:"!T:&4@9F]L;&]W:6YG('!R;W!E<G1I97,L(&]R(%!%05)?
M17)R;W(*("`@("`J("`@("`@("`@("`@("`@("`@(&]N(&5R<F]R.@H@("`@
M("H@/'!R93X*("`@("`J("=M97-S86=E)R`@("`@+2`@5&AE(&1E8W)Y<'1E
M9"!M97-S86=E+@H@("`@("H@)W-I9U]R97-U;'0G("`M("!4:&4@<F5S=6QT
M(&]F('1H92!S:6=N871U<F4@=&5S="X*("`@("`J(#PO<')E/@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&5C<GEP=$UE<W-A9V4H)'1E>'0L("1P87)A;7,I
M"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R('-E8W5R92!C;VYN96-T:6]N
M+B`J+PH@("`@("`@("1S96-U<F5?8VAE8VL@/2`D=&AI<RT^<F5Q=6ER95-E
M8W5R94-O;FYE8W1I;VXH*3L*("`@("`@("!I9B`H:7-?82@D<V5C=7)E7V-H
M96-K+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D<V5C
M=7)E7V-H96-K.PH@("`@("`@('T*"B`@("`@("`@)&=O;V1?<VEG7V9L86<@
M/2!F86QS93L*"B`@("`@("`@+RH@0VAE8VL@9F]R(')E<75I<F5D('!A<F%M
M971E<G,N("HO"B`@("`@("`@:68@*"%I<W-E="@D<&%R86US6R=P=6)K97DG
M72D@?'P*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W!R:79K97DG72D@
M?'P*("`@("`@("`@("`@(6ES<V5T*"1P87)A;7-;)W!A<W-P:')A<V4G72DI
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B02!P
M=6)L:6,@4$=0(&ME>2P@<')I=F%T92!01U`@:V5Y+"!A;F0@<&%S<W!H<F%S
M92!A<F4@<F5Q=6ER960@=&\@9&5C<GEP="!A(&UE<W-A9V4N(BDL("=H;W)D
M92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@+RH@0W)E871E('1E;7`@
M9FEL97,N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("\J($1E8W)Y<'1I;VX@<F5Q
M=6ER97,@8F]T:"!K97ER:6YG<RX@*B\*("`@("`@("`D<'5B7VME>7)I;F<@
M/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9RAA<G)A>2@D<&%R86US6R=P=6)K97DG
M72DI.PH@("`@("`@("1S96-?:V5Y<FEN9R`]("1T:&ES+3Y?<'5T26Y+97ER
M:6YG*&%R<F%Y*"1P87)A;7-;)W!R:79K97DG72DL("=P<FEV871E)RD["@H@
M("`@("`@("\J(%-T;W)E(&UE<W-A9V4@:6X@9FEL92X@*B\*("`@("`@("`D
M9G`@/2!F;W!E;B@D:6YP=70L("=W*R<I.PH@("`@("`@(&9P=71S*"1F<"P@
M)'1E>'0I.PH@("`@("`@(&9C;&]S92@D9G`I.PH*("`@("`@("`O*B!$96-R
M>7!T('1H92!D;V-U;65N="!N;W<N("HO"B`@("`@("`@)&-M9&QI;F4@/2!A
M<G)A>2@*("`@("`@("`@("`@)RTM86QW87ES+71R=7-T)RP*("`@("`@("`@
M("`@)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UB871C:"<L"B`@("`@("`@
M("`@("<M+7!A<W-P:')A<V4M9F0@,"<L"B`@("`@("`@("`@("1S96-?:V5Y
M<FEN9RP*("`@("`@("`@("`@)'!U8E]K97ER:6YG+`H@("`@("`@("`@("`G
M+2UD96-R>7!T)RP*("`@("`@("`@("`@)&EN<'5T"B`@("`@("`@*3L*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G=R<L
M("1P87)A;7-;)W!A<W-P:')A<V4G72P@=')U92P@=')U92D["B`@("`@("`@
M:68@*&5M<'1Y*"1R97-U;'0M/F]U='!U="DI('L*("`@("`@("`@("`@)&5R
M<F]R(#T@<')E9U]R97!L86-E*"<O7&XN*B\G+"`G)RP@)')E<W5L="T^<W1D
M97)R*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V]U;&0@;F]T(&1E8W)Y<'0@4$=0(&1A=&$Z("(I("X@)&5R<F]R+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("!]"@H@("`@("`@("\J($-R96%T92!T:&4@
M<F5T=7)N(&]B:F5C="X@*B\*("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S
M.PH@("`@("`@("1O8BT^;65S<V%G92`]("1R97-U;'0M/F]U='!U=#L*"B`@
M("`@("`@+RH@0VAE8VL@=&AE(%!'4"!S:6=N871U<F4N("HO"B`@("`@("`@
M)'-I9U]C:&5C:R`]("1T:&ES+3Y?8VAE8VM3:6=N871U<F5297-U;'0H)')E
M<W5L="T^<W1D97)R*3L*("`@("`@("!I9B`H:7-?82@D<VEG7V-H96-K+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1O8BT^<VEG7W)E<W5L="`]
M("1S:6=?8VAE8VL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]B
M+3YS:6=?<F5S=6QT(#T@*"1S:6=?8VAE8VLI(#\@)')E<W5L="T^<W1D97)R
M(#H@)R<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]B.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1&5C<GEP=',@86X@4$=0('-I9VYE9"!M97-S86=E
M('5S:6YG(&$@<'5B;&EC(&ME>2X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@5&AE
M('1E>'0@=&\@8F4@=F5R:69I960N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@5&AE('!A<F%M971E<G,@;F5E9&5D(&9O<B!V97)I9FEC871I;VXN
M"B`@("`@*B`\<')E/@H@("`@("H@4&%R86UE=&5R<SH*("`@("`J(#T]/3T]
M/3T]/3T]"B`@("`@*B`G='EP92<@("`@("`@/3X@("=S:6=N871U<F4G(&]R
M("=D971A8VAE9"US:6=N871U<F4G("A215%525)%1"D*("`@("`J("=P=6)K
M97DG("`@("`]/B`@4$=0('!U8FQI8R!K97DN("A215%525)%1"D*("`@("`J
M("=S:6=N871U<F4G("`]/B`@4$=0('-I9VYA='5R92!B;&]C:RX@*%)%455)
M4D5$(&9O<B!D971A8VAE9"!S:6=N871U<F4I"B`@("`@*B`\+W!R93X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('9E<FEF:6-A=&EO;B!M
M97-S86=E(&9R;VT@9W!G+B!)9B!N;R!S:6=N871U<F4L"B`@("`@*B`@("`@
M("`@("`@("`@("`@<F5T=7)N<R!E;7!T>2!S=')I;F<L(&%N9"!014%27T5R
M<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C<GEP=%-I
M9VYA='5R92@D=&5X="P@)'!A<F%M<RD*("`@('L*("`@("`@("`O*B!#:&5C
M:R!F;W(@<F5Q=6ER960@<&%R86UE=&5R<RX@*B\*("`@("`@("!I9B`H(6ES
M<V5T*"1P87)A;7-;)W!U8FME>2==*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")!('!U8FQI8R!01U`@:V5Y(&ES(')E<75I
M<F5D('1O('9E<FEF>2!A('-I9VYE9"!M97-S86=E+B(I+"`G:&]R9&4N97)R
M;W(G*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D<&%R86US6R=T>7!E)UT@
M/3T]("=D971A8VAE9"US:6=N871U<F4G*2`F)@H@("`@("`@("`@("`A:7-S
M970H)'!A<F%M<ULG<VEG;F%T=7)E)UTI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E1H92!D971A8VAE9"!01U`@<VEG;F%T
M=7)E(&)L;V-K(&ES(')E<75I<F5D('1O('9E<FEF>2!T:&4@<VEG;F5D(&UE
M<W-A9V4N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T*"B`@("`@("`@
M)&=O;V1?<VEG7V9L86<@/2`P.PH*("`@("`@("`O*B!#<F5A=&4@=&5M<"!F
M:6QE<R!F;W(@:6YP=70N("HO"B`@("`@("`@)&EN<'5T(#T@)'1H:7,M/E]C
M<F5A=&5496UP1FEL92@G:&]R9&4M<&=P)RD["@H@("`@("`@("\J(%-T;W)E
M('!U8FQI8R!K97D@:6X@=&5M<&]R87)Y(&ME>7)I;F<N("HO"B`@("`@("`@
M)&ME>7)I;F<@/2`D=&AI<RT^7W!U=$EN2V5Y<FEN9R@D<&%R86US6R=P=6)K
M97DG72D["@H@("`@("`@("\J(%-T;W)E('1H92!M97-S86=E(&EN(&$@=&5M
M<&]R87)Y(&9I;&4N("HO"B`@("`@("`@)&9P(#T@9F]P96XH)&EN<'5T+"`G
M=RLG*3L*("`@("`@("!F<'5T<R@D9G`L("1T97AT*3L*("`@("`@("!F8VQO
M<V4H)&9P*3L*"B`@("`@("`@+RH@3W!T:6]N<R!F;W(@=&AE($=01R!B:6YA
M<GDN("HO"B`@("`@("`@)&-M9&QI;F4@/2!A<G)A>2@*("`@("`@("`@("`@
M)RTM87)M;W(G+`H@("`@("`@("`@("`G+2UA;'=A>7,M=')U<W0G+`H@("`@
M("`@("`@("`G+2UB871C:"<L"B`@("`@("`@("`@("<M+6-H87)S970@)R`N
M($Y,4SHZ9V5T0VAA<G-E="@I+`H@("`@("`@("`@("`D:V5Y<FEN9RP*("`@
M("`@("`@("`@)RTM=F5R:69Y)PH@("`@("`@("D["@H@("`@("`@("\J($5X
M=')A('-T=69F('1O(&1O(&EF('=E(&%R92!U<VEN9R!A(&1E=&%C:&5D('-I
M9VYA='5R92X@*B\*("`@("`@("!I9B`H)'!A<F%M<ULG='EP92==(#T]/2`G
M9&5T86-H960M<VEG;F%T=7)E)RD@>PH@("`@("`@("`@("`D<VEG9FEL92`]
M("1T:&ES+3Y?8W)E871E5&5M<$9I;&4H)VAO<F1E+7!G<"<I.PH@("`@("`@
M("`@("`D8VUD;&EN95M=(#T@)'-I9V9I;&4@+B`G("<@+B`D:6YP=70["@H@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D<VEG9FEL92P@)W<K)RD["B`@("`@
M("`@("`@(&9P=71S*"1F<"P@)'!A<F%M<ULG<VEG;F%T=7)E)UTI.PH@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D8VUD;&EN95M=(#T@)&EN<'5T.PH@("`@("`@('T*("`@("`@("`D
M8VUD;&EN95M=(#T@)S(^)C$G.PH*("`@("`@("`O*B!697)I9GD@=&AE('-I
M9VYA='5R92X*("`@("`@("`@("!792!N965D('1O(&-A=&-H('-T86YD87)D
M(&5R<F]R(&]U='!U="P@<VEN8V4@=&AI<R!I<R!W:&5R90H@("`@("`@("`@
M('1H92!S:6=N871U<F4@:6YF;W)M871I;VX@:7,@<V5N="X@*B\*("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL1W!G*"1C;61L:6YE+"`G<B<I.PH@
M("`@("`@("1S:6=?<F5S=6QT(#T@)'1H:7,M/E]C:&5C:U-I9VYA='5R95)E
M<W5L="@D<F5S=6QT+3YS=&1O=70I.PH@("`@("`@(&EF("AI<U]A*"1S:6=?
M<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<VEG7W)E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@*"1S:6=?<F5S=6QT*2`_("1R97-U;'0M/G-T9&]U="`Z("<G.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!S:6=N871U<F4@
M<F5S=6QT(&9R;VT@=&AE($=N=5!'(&)I;F%R>2X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1R
M97-U;'0@(%1H92!S:6=N871U<F4@<F5S=6QT+@H@("`@("H*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5')U92!I9B!S:6=N871U<F4@:7,@9V]O9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-H96-K4VEG;F%T=7)E4F5S=6QT*"1R97-U
M;'0I"B`@("!["B`@("`@("`@+RH@1V]O9"!S:6=N871U<F4Z"B`@("`@("`@
M("H@("!G<&<Z($=O;V0@<VEG;F%T=7)E(&9R;VT@(F)L86@@8FQA:"!B;&%H
M("A#;VUM96YT*2(*("`@("`@("`@*B!"860@<VEG;F%T=7)E.@H@("`@("`@
M("`J("`@9W!G.B!"040@<VEG;F%T=7)E(&9R;VT@(F)L86@@8FQA:"!B;&%H
M("A#;VUM96YT*2(@*B\*("`@("`@("!I9B`H<W1R<&]S*"1R97-U;'0L("=G
M<&<Z($)!1"!S:6=N871U<F4G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)')E<W5L="P@)VAO<F1E+F5R<F]R
M)RD["B`@("`@("`@?2!E;'-E:68@*'-T<G!O<R@D<F5S=6QT+"`G9W!G.B!'
M;V]D('-I9VYA='5R92<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4VEG;G,@
M82!-24U%7U!A<G0@=7-I;F<@4$=0+@H@("`@("H*("`@("`J($!P87)A;2!-
M24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)345?4&%R="!O8FIE8W0@=&\@
M<VEG;BX*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("`@("`@("`@5&AE
M('!A<F%M971E<G,@<F5Q=6ER960@9F]R('-I9VYI;F<N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($!S964@7V5N8W)Y<'13:6=N871U
M<F4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%
M7U!A<G0@;V)J96-T('1H870@:7,@<VEG;F5D(&%C8V]R9&EN9R!T;R!21D,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`R,#$U+S,Q-38L(&]R(%!%05)?
M17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N('-I9VY-24U%
M4&%R="@D;6EM95]P87)T+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I;F-L=61E7V]N8V4@)TAO<F1E+TU)344O4&%R="YP:'`G.PH*("`@
M("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M<RP@87)R87DH)W1Y
M<&4G(#T^("=S:6=N871U<F4G+"`G<VEG='EP92<@/3X@)V1E=&%C:"<I*3L*
M"B`@("`@("`@+RH@4D9#(#(P,34@4F5Q=6ER96UE;G1S(&9O<B!A(%!'4"!S
M:6=N960@;65S<V%G93H*("`@("`@("`@*B`K($-O;G1E;G0M5'EP92!P87)A
M;7,@)VUI8V%L9R<@)B`G<')O=&]C;VPG(&%R92!215%525)%1"X*("`@("`@
M("`@*B`K(%1H92!D:6=I=&%L;'D@<VEG;F5D(&UE<W-A9V4@35535"!B92!C
M;VYS=')A:6YE9"!T;R`W(&)I=',N"B`@("`@("`@("H@*R!4:&4@34E-12!H
M96%D97)S($U54U0@8F4@82!P87)T(&]F('1H92!S:6=N960@9&%T82X@*B\*
M"B`@("`@("`@)&UI;65?<&%R="T^<W1R:6-T-V)I="AT<G5E*3L*("`@("`@
M("`D;7-G7W-I9VX@/2`D=&AI<RT^96YC<GEP="@D;6EM95]P87)T+3YT;T-A
M;F]N:6-A;%-T<FEN9R@I+"`D<&%R86US*3L*("`@("`@("!I9B`H:7-?82@D
M;7-G7W-I9VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1M<V=?<VEG;CL*("`@("`@("!]"@H@("`@("`@("\J($%D9"!T:&4@4$=0
M('-I9VYA='5R92X@*B\*("`@("`@("`D<&=P7W-I9VX@/2`F;F5W($U)345?
M4&%R="@G87!P;&EC871I;VXO<&=P+7-I9VYA='5R92<L("1M<V=?<VEG;BP@
M;G5L;"P@)VEN;&EN92<I.PH@("`@("`@("1P9W!?<VEG;BT^<V5T1&5S8W)I
M<'1I;VXH7R@B4$=0($1I9VET86P@4VEG;F%T=7)E(BDI.PH*("`@("`@("`O
M*B!'970@=&AE(&%L9V]R:71H:6T@:6YF;W)M871I;VX@9G)O;2!T:&4@<VEG
M;F%T=7)E+B!3:6YC92!W92!A<F4*("`@("`@("`@*B!A;F%L>7II;F<@82!S
M:6=N871U<F4@<&%C:V5T+"!W92!N965D('1O('5S92!T:&4@<W!E8VEA;"!K
M97EW;W)D"B`@("`@("`@("H@)U]324=.05154D4G("T@<V5E($AO<F1E7T-R
M>7!T7W!G<"X@*B\*("`@("`@("`D<VEG7VEN9F\@/2`D=&AI<RT^<&=P4&%C
M:V5T4VEG;F%T=7)E*"1M<V=?<VEG;BP@)U]324=.05154D4G*3L*"B`@("`@
M("`@+RH@4V5T=7`@=&AE(&UU;'1I<&%R="!-24U%(%!A<G0N("HO"B`@("`@
M("`@)'!A<G0@/2`F;F5W($U)345?4&%R="@G;75L=&EP87)T+W-I9VYE9"<I
M.PH@("`@("`@("1P87)T+3YS971#;VYT96YT<R@G5&AI<R!M97-S86=E(&ES
M(&EN($U)344@9F]R;6%T(&%N9"!H87,@8F5E;B!01U`@<VEG;F5D+B<@+B`B
M7&XB*3L*("`@("`@("`D<&%R="T^861D4&%R="@D;6EM95]P87)T*3L*("`@
M("`@("`D<&%R="T^861D4&%R="@D<&=P7W-I9VXI.PH@("`@("`@("1P87)T
M+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<')O=&]C;VPG+"`G87!P;&EC
M871I;VXO<&=P+7-I9VYA='5R92<I.PH@("`@("`@("1P87)T+3YS971#;VYT
M96YT5'EP95!A<F%M971E<B@G;6EC86QG)RP@)'-I9U]I;F9O6R=M:6-A;&<G
M72D["@H@("`@("`@(')E='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($5N8W)Y<'1S(&$@34E-15]087)T('5S:6YG(%!'4"X*("`@("`J"B`@
M("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A<G0@(%1H92!-24U%7U!A
M<G0@;V)J96-T('1O(&5N8W)Y<'0N"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("`@("`@(%1H92!P87)A;65T97)S(')E<75I<F5D(&9O<B!E;F-R
M>7!T:6]N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M0'-E92!?96YC<GEP=$UE<W-A9V4H*2X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($U)345?4&%R="`@02!-24U%7U!A<G0@;V)J96-T('1H870@:7,@96YC<GEP
M=&5D(&%C8V]R9&EN9R!T;R!21D,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`R,#$U+S,Q-38L(&]R(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N8W)Y<'1-24U%4&%R="@D;6EM95]P87)T+"`D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I;F-L=61E7V]N8V4@)TAO
M<F1E+TU)344O4&%R="YP:'`G.PH*("`@("`@("`D<&%R86US(#T@87)R87E?
M;65R9V4H)'!A<F%M<RP@87)R87DH)W1Y<&4G(#T^("=M97-S86=E)RDI.PH*
M("`@("`@("`D<VEG;F5N8U]B;V1Y(#T@)&UI;65?<&%R="T^=&]#86YO;FEC
M86Q3=')I;F<H*3L*("`@("`@("`D;65S<V%G95]E;F-R>7!T(#T@)'1H:7,M
M/F5N8W)Y<'0H)'-I9VYE;F-?8F]D>2P@)'!A<F%M<RD["B`@("`@("`@:68@
M*&ES7V$H)&UE<W-A9V5?96YC<GEP="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&UE<W-A9V5?96YC<GEP=#L*("`@("`@("!]"@H@
M("`@("`@("\J(%-E="!U<"!-24U%(%-T<G5C='5R92!A8V-O<F1I;F<@=&\@
M4D9#(#(P,34N("HO"B`@("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R="@G
M;75L=&EP87)T+V5N8W)Y<'1E9"<I.PH@("`@("`@("1P87)T+3YS971#;VYT
M96YT<R@G5&AI<R!M97-S86=E(&ES(&EN($U)344@9F]R;6%T(&%N9"!H87,@
M8F5E;B!01U`@96YC<GEP=&5D+B<@+B`B7&XB*3L*("`@("`@("`D<&%R="T^
M861D4&%R="AN97<@34E-15]087)T*"=A<'!L:6-A=&EO;B]P9W`M96YC<GEP
M=&5D)RP@(E9E<G-I;VXZ(#%<;B(L(&YU;&PI*3L*("`@("`@("`D<&%R="T^
M861D4&%R="AN97<@34E-15]087)T*"=A<'!L:6-A=&EO;B]O8W1E="US=')E
M86TG+"`D;65S<V%G95]E;F-R>7!T+"!N=6QL+"`G:6YL:6YE)RDI.PH@("`@
M("`@("1P87)T+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G<')O=&]C;VPG
M+"`G87!P;&EC871I;VXO<&=P+65N8W)Y<'1E9"<I.PH@("`@("`@("1P87)T
M+3YS971$97-C<FEP=&EO;BA?*")01U`@16YC<GEP=&5D($1A=&$B*2D["@H@
M("`@("`@(')E='5R;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-I
M9VYS(&%N9"!E;F-R>7!T<R!A($U)345?4&%R="!U<VEN9R!01U`N"B`@("`@
M*@H@("`@("H@0'!A<F%M($U)345?4&%R="`D;6EM95]P87)T("`@5&AE($U)
M345?4&%R="!O8FIE8W0@=&\@<VEG;B!A;F0@96YC<GEP="X*("`@("`J($!P
M87)A;2!A<G)A>2`D<VEG;E]P87)A;7,@("`@(%1H92!P87)A;65T97)S(')E
M<75I<F5D(&9O<B!S:6=N:6YG+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@0'-E92!?96YC<GEP=%-I9VYA='5R92@I+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1E;F-R>7!T7W!A<F%M<R`@5&AE('!A<F%M971E<G,@
M<F5Q=6ER960@9F]R(&5N8W)Y<'1I;VXN"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!`<V5E(%]E;F-R>7!T365S<V%G92@I+@H@("`@
M("H*("`@("`J($!R971U<FX@34E-15]087)T("!!($U)345?4&%R="!O8FIE
M8W0@=&AA="!I<R!S:6=N960@86YD(&5N8W)Y<'1E9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@(&%C8V]R9&EN9R!T;R!21D,@,C`Q-2\S,34V+"!O<B!0
M14%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:6=N
M06YD16YC<GEP=$U)345087)T*"1M:6UE7W!A<G0L("1S:6=N7W!A<F%M<R`]
M(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;F-R>7!T7W!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@:6YC
M;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@("`@("`@+RH@
M4D9#(#(P,34@<F5Q=6ER97,@=&AA="!T:&4@96YT:7)E('-I9VYE9"!M97-S
M86=E(&)E(&5N8W)Y<'1E9"X@(%=E"B`@("`@("`@("H@;F5E9"!T;R!E>'!L
M:6-I=&QY(&-A;&P@=7-I;F<@2&]R9&5?0W)Y<'1?<&=P.CH@8F5C875S92!W
M92!D;VXG=`H@("`@("`@("`J(&MN;W<@=VAE=&AE<B!A('-U8F-L87-S(&AA
M<R!E>'1E;F1E9"!T:&5S92!M971H;V1S+B`J+PH@("`@("`@("1P87)T(#T@
M)'1H:7,M/G-I9VY-24U%4&%R="@D;6EM95]P87)T+"`D<VEG;E]P87)A;7,I
M.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"B`@("`@("`@)'!A
M<G0@/2`D=&AI<RT^96YC<GEP=$U)345087)T*"1P87)T+"`D96YC<GEP=%]P
M87)A;7,I.PH@("`@("`@(&EF("AI<U]A*"1P87)T+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<&%R=#L*("`@("`@("!]"B`@("`@
M("`@)'!A<G0M/G-E=$-O;G1E;G1S*"=4:&ES(&UE<W-A9V4@:7,@:6X@34E-
M12!F;W)M870@86YD(&AA<R!B965N(%!'4"!S:6=N960@86YD(&5N8W)Y<'1E
M9"XG("X@(EQN(BD["B`@("`@("`@)'!A<G0M/G-E=$1E<V-R:7!T:6]N*%\H
M(E!'4"!3:6=N960O16YC<GEP=&5D($1A=&$B*2D["@H@("`@("`@(')E='5R
M;B`D<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A($U)
M345?4&%R="!O8FIE8W0L(&EN(&%C8V]R9&%N8V4@=VET:"!21D,@,C`Q-2\S
M,34V+"!T:&%T"B`@("`@*B!C;VYT86EN<R!A('!U8FQI8R!K97DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:V5Y("!4:&4@<'5B;&EC(&ME>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@02!-24U%7U!A<G0@
M;V)J96-T('1H870@8V]N=&%I;G,@=&AE('!U8FQI8R!K97DN"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!U8FQI8TME>4U)345087)T*"1K97DI"B`@("!["B`@
M("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-24U%+U!A<G0N<&AP)SL*"B`@
M("`@("`@)'!A<G0@/2`F;F5W($U)345?4&%R="@G87!P;&EC871I;VXO<&=P
M+6ME>7,G+"`D:V5Y+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@)'!A
M<G0M/G-E=$1E<V-R:7!T:6]N*%\H(E!'4"!0=6)L:6,@2V5Y(BDI.PH*("`@
M("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T:&%T(&AA;F1L97,@:6YT97)F86-I;F<@=VET:"!T:&4@1VYU4$<@
M8FEN87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@(%1/1$\*("`@("`J($!P
M87)A;2!S=')I;F<@)&UO9&4@("`@(%1/1$\*("`@("`J($!P87)A;2!A<G)A
M>2`D:6YP=70@("`@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1O=71P
M=70@(%1/1$\*("`@("`J($!P87)A;2!B;V]L96%N("1S=&1E<G(@(%1/1$\*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L87-S("!43T1/"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C86QL1W!G*"1O<'1I;VYS+"`D;6]D92P@)&EN<'5T
M(#T@87)R87DH*2P@)&]U='!U="`](&9A;'-E+`H@("`@("`@("`@("`@("`@
M("`@("`@)'-T9&5R<B`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;61L:6YE
M(#T@87)R87E?;65R9V4H)'1H:7,M/E]G;G5P9RP@)&]P=&EO;G,I.PH@("`@
M("`@("1D871A(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`D9&%T82T^;W5T
M<'5T(#T@;G5L;#L*("`@("`@("`D9&%T82T^<W1D97)R(#T@;G5L;#L*("`@
M("`@("`D9&%T82T^<W1D;W5T(#T@;G5L;#L*"B`@("`@("`@+RH@0W)E871E
M('1E;7`@9FEL97,@9F]R(&]U='!U="X@*B\*("`@("`@("!I9B`H)&]U='!U
M="D@>PH@("`@("`@("`@("`D;W5T<'5T7V9I;&4@/2`D=&AI<RT^7V-R96%T
M951E;7!&:6QE*"=H;W)D92UP9W`G+"!F86QS92D["B`@("`@("`@("`@(&%R
M<F%Y7W5N<VAI9G0H)&]P=&EO;G,L("<M+6]U='!U="`G("X@)&]U='!U=%]F
M:6QE*3L*"B`@("`@("`@("`@("\J($1O('=E(&YE960@<W1A;F1A<F0@97)R
M;W(@;W5T<'5T/R`J+PH@("`@("`@("`@("!I9B`H)'-T9&5R<BD@>PH@("`@
M("`@("`@("`@("`@)'-T9&5R<E]F:6QE(#T@)'1H:7,M/E]C<F5A=&5496UP
M1FEL92@G:&]R9&4M<&=P)RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@)&]P
M=&EO;G-;72`]("<R/B`G("X@)'-T9&5R<E]F:6QE.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!T:&4@8V]M;6%N9"!L:6YE
M('-T<FEN9R!N;W<N("HO"B`@("`@("`@)&-M9&QI;F4@/2!I;7!L;V1E*"<@
M)RP@87)R87E?;65R9V4H)'1H:7,M/E]G;G5P9RP@)&]P=&EO;G,I*3L*"B`@
M("`@("`@:68@*"1M;V1E(#T]("=W)RD@>PH@("`@("`@("`@("`D9G`@/2!P
M;W!E;B@D8VUD;&EN92P@)W<G*3L*("`@("`@("`@("`@)'=I;C,R(#T@<W5B
M<W1R*%!(4%]/4RP@,"P@,RD@/3T@)U=)3B<["@H@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1I;G!U="DI('L*("`@("`@("`@("`@("`@("1I;G!U="`]
M(&%R<F%Y*"1I;G!U="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R
M96%C:"`H)&EN<'5T(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'=I;C,R("8F("AS=')P;W,H)&QI;F4L(")<>#!D7'@P82(I("$]/2!F86QS
M92DI('L*("`@("`@("`@("`@("`@("`@("`D8VAU;FMS(#T@97AP;&]D92@B
M7'@P9%QX,&$B+"`D;&EN92D["B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&-H=6YK<R!A<R`D8VAU;FLI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@9G!U=',H)&9P+"`D8VAU;FL@+B`B7&XB*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&9P=71S*"1F<"P@)&QI;F4@+B`B7&XB*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D;6]D92`]
M/2`G<B<I('L*("`@("`@("`@("`@)&9P(#T@<&]P96XH)&-M9&QI;F4L("=R
M)RD["B`@("`@("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2!["B`@("`@("`@
M("`@("`@("`D9&%T82T^<W1D;W5T("X](&9G971S*"1F<"P@,3`R-"D["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F<"D["@H@
M("`@("`@(&EF("@D;W5T<'5T*2!["B`@("`@("`@("`@("1D871A+3YO=71P
M=70@/2!F:6QE7V=E=%]C;VYT96YT<R@D;W5T<'5T7V9I;&4I.PH@("`@("`@
M("`@("!U;FQI;FLH)&]U='!U=%]F:6QE*3L*("`@("`@("`@("`@:68@*"1S
M=&1E<G(I('L*("`@("`@("`@("`@("`@("1D871A+3YS=&1E<G(@/2!F:6QE
M7V=E=%]C;VYT96YT<R@D<W1D97)R7V9I;&4I.PH@("`@("`@("`@("`@("`@
M=6YL:6YK*"1S=&1E<G)?9FEL92D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O
M:'1M;"YP:'``````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#0R,3(U(#$P-3$U-#,T,30P(#`R,3<Q-P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@5&AE($AO<F1E
M7U1R965?:'1M;#HZ(&-L87-S(&5X=&5N9',@=&AE($AO<F1E7U1R964@8VQA
M<W,@=&\@<')O=FED90H@*B!(5$U,('-P96-I9FEC(')E;F1E<FEN9R!F=6YC
M=&EO;G,N"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC
M(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U1R964O5')E92]H=&UL+G!H<"QV(#$N-3$N,BXQ,B`R,#`V
M+S`Q+S$U(#$V.C,S.C(Y(&-H=6-K($5X<"`D"B`J"B`J($!A=71H;W(@($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K86=E($AO<F1E
M7U1R964*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!(;W)D95]4
M<F5E7VAT;6P@97AT96YD<R!(;W)D95]4<F5E('L*"B`@("`O*BH*("`@("`J
M($EM86=E(&1I<F5C=&]R>2!L;V-A=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?9&ER(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!L:6YE+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM
M9U]L:6YE(#T@)VQI;F4N<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@
M=')E92!G<F%P:&EC(&9O<B!A(&)L86YK+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]B;&%N:R`]("=B;&%N:RYP
M;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R
M(&$@:F]I;BX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]I;6=?:F]I;B`]("=J;VEN+G!N9R<["@H@("`@+RHJ"B`@("`@
M*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!B;W1T;VT@:F]I;BX*("`@
M("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?
M:F]I;E]B;W1T;VT@/2`G:F]I;F)O='1O;2YP;F<G.PH*("`@("\J*@H@("`@
M("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@<&QU<RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?<&QU<R`]
M("=P;'5S+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A
M<&AI8R!F;W(@82!B;W1T;VT@<&QU<RX*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]I;6=?<&QU<U]B;W1T;VT@/2`G<&QU
M<V)O='1O;2YP;F<G.PH*("`@("\J*@H@("`@("H@1&5F875L="!T<F5E(&=R
M87!H:6,@9F]R(&$@<&QU<R!O;FQY+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]P;'5S7V]N;'D@/2`G<&QU<V]N
M;'DN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC
M(&9O<B!A(&UI;G5S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D7VEM9U]M:6YU<R`]("=M:6YU<RYP;F<G.PH*("`@("\J
M*@H@("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@8F]T=&]M(&UI
M;G5S+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7VEM9U]M:6YU<U]B;W1T;VT@/2`G;6EN=7-B;W1T;VTN<&YG)SL*"B`@
M("`O*BH*("`@("`J($1E9F%U;'0@=')E92!G<F%P:&EC(&9O<B!A(&UI;G5S
M(&]N;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?:6UG7VUI;G5S7V]N;'D@/2`G;6EN=7-O;FQY+G!N9R<["@H@("`@
M+RHJ"B`@("`@*B!$969A=6QT('1R964@9W)A<&AI8R!F;W(@82!N=6QL(&]N
M;'DN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?:6UG7VYU;&Q?;VYL>2`]("=N=6QL;VYL>2YP;F<G.PH*("`@("\J*@H@
M("`@("H@1&5F875L="!T<F5E(&=R87!H:6,@9F]R(&$@9F]L9&5R+@H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VEM9U]F
M;VQD97(@/2`G9F]L9&5R+G!N9R<["@H@("`@+RHJ"B`@("`@*B!$969A=6QT
M('1R964@9W)A<&AI8R!F;W(@86X@;W!E;B!F;VQD97(N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7V9O;&1E<E]O
M<&5N(#T@)V9O;&1E<F]P96XN<&YG)SL*"B`@("`O*BH*("`@("`J($1E9F%U
M;'0@=')E92!G<F%P:&EC(&9O<B!A(&QE868N"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?:6UG7VQE868@/2`G;&5A9BYP
M;F<G.PH*("`@("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?;F]D97,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1?;F]D95]P;W,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@5$]$3PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?9')O<&QI;F4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@
M0W5R<F5N="!V86QU92!O9B!T:&4@86QT('1A9R!C;W5N="X*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?86QT7V-O=6YT
M(#T@,#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@
M(&9U;F-T:6]N($AO<F1E7U1R965?:'1M;"@D=')E95]N86UE+"`D<&%R86US
M*0H@("`@>PH@("`@("`@('!A<F5N=#HZ2&]R9&5?5')E92@D=')E95]N86UE
M+"`D<&%R86US*3L*"B`@("`@("`@)'1H:7,M/E]I;6=?9&ER(#T@)$=,3T)!
M3%-;)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"=H;W)D92<I("X@)R]T<F5E
M)SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1R964N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T871I8R`@268@=')U92!T
M:&4@=')E92!N;V1E<R!C86XG="!B92!E>'!A;F1E9"!A;F0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;&QA<'-E9"!A;F0@=&AE('1R964@
M9V5T<R!R96YD97)E9"!E>'!A;F1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE($A434P@8V]D92!O9B!T:&4@<F5N9&5R960@=')E92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5')E92@D<W1A=&EC(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%T:6,@/2`D<W1A=&EC.PH@("`@
M("`@("1T:&ES+3Y?8G5I;&1);F1E;G1S*"1T:&ES+3Y?<F]O=%]N;V1E<RD[
M"@H@("`@("`@("1T<F5E(#T@)'1H:7,M/E]B=6EL9$AE861E<B@I.PH@("`@
M("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F]O=%]N;V1E<R!A<R`D;F]D95]I9"D@
M>PH@("`@("`@("`@("`D=')E92`N/2`D=&AI<RT^7V)U:6QD5')E92@D;F]D
M95]I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=')E93L*("`@('T*
M"B`@("`O*BH*("`@("`J($-H96-K('1H92!C=7)R96YT(&5N=FER;VYM96YT
M('1O('-E92!I9B!W92!C86X@<F5N9&5R('1H92!(5$U,"B`@("`@*B!T<F5E
M+B!(5$U,(&ES(&%L=V%Y<R!R96YD97)A8FQE+"!A="!L96%S="!U;G1I;"!W
M92!A9&0@80H@("`@("H@<&AP+6=T:R!T<F5E(&)A8VME;F0L(&EN('=H:6-H
M(&-A<V4@=&AI<R!I;7!L96UE;G1A=&EO;B!W:6QL"B`@("`@*B!A8W1U86QL
M>2!N965D(&$@8F]D>2X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!T:&ES(%1R
M964Z.B!B86-K96YD('=I;&P@9G5N8W1I;VXN"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&ES4W5P<&]R=&5D*"D*("`@('L*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:G5S="!T:&4@2E,@;F]D
M92!D969I;FET:6]N<R!A<R!A('-T<FEN9RX@5&AI<R!I<R!A"B`@("`@*B!N
M;RUO<"!F;W(@=&AE($A434P@<F5N9&5R97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')E;F1E<DYO9&5$969I;FET:6]N<R@I"B`@("!["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!(5$U,(&-O9&4@9F]R(&$@:&5A9&5R
M(')O=RP@:68@;F5C97-S87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@2%1-3"!C
M;V1E(&]F('1H92!H96%D97(@<F]W(&]R(&%N(&5M<'1Y('-T<FEN9RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V)U:6QD2&5A9&5R*"D*("`@('L*("`@("`@
M("!I9B`H(6-O=6YT*"1T:&ES+3Y?:&5A9&5R*2D@>PH@("`@("`@("`@("!R
M971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D:'1M;"`]("<\9&EV)SL*
M("`@("`@("`O*B!)9B!U<VEN9R!A;'1E<FYA=&EN9R!R;W<@<VAA9&EN9RP@
M=V]R:R!O=70@8V]R<F5C=`H@("`@("`@("`J('-H861E+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^9V5T3W!T:6]N*"=A;'1E<FYA=&4G*2D@>PH@("`@("`@
M("`@("`D:'1M;"`N/2`G(&-L87-S/2)I=&5M)R`N("1T:&ES+3Y?86QT7V-O
M=6YT("X@)R(G.PH@("`@("`@("`@("`D=&AI<RT^7V%L=%]C;W5N="`](#$@
M+2`D=&AI<RT^7V%L=%]C;W5N=#L*("`@("`@("!]"B`@("`@("`@)&AT;6P@
M+CT@)SXG.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAE861E<B!A<R`D
M:&5A9&5R*2!["B`@("`@("`@("`@("1H=&UL("X]("<\9&EV(&-L87-S/2)L
M969T1FQO870G.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1H96%D97);)V-L
M87-S)UTI*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G("<@+B`D:&5A
M9&5R6R=C;&%S<R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL
M("X]("<B)SL*"B`@("`@("`@("`@("1S='EL92`]("<G.PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1H96%D97);)W=I9'1H)UTI*2!["B`@("`@("`@("`@
M("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D:&5A9&5R6R=W:61T:"==("X@
M)SLG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&AE
M861E<ELG86QI9VXG72DI('L*("`@("`@("`@("`@("`@("1S='EL92`N/2`G
M=&5X="UA;&EG;CHG("X@)&AE861E<ELG86QI9VXG72`N("<[)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1S='EL92DI('L*("`@
M("`@("`@("`@("`@("1H=&UL("X]("<@<W1Y;&4](B<@+B`D<W1Y;&4@+B`G
M(B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@+CT@)SXG.PH@
M("`@("`@("`@("`D:'1M;"`N/2!E;7!T>2@D:&5A9&5R6R=H=&UL)UTI(#\@
M)R9N8G-P.R<@.B`D:&5A9&5R6R=H=&UL)UT["B`@("`@("`@("`@("1H=&UL
M("X]("<\+V1I=CXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1H=&UL
M("X@)SPO9&EV/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296-U<G-I=F4@
M9G5N8W1I;VX@=&\@=V%L:R!T:')O=6=H('1H92!T<F5E(&%R<F%Y(&%N9"!B
M=6EL9"!T:&4@;W5T<'5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YO9&5?:60@(%1H92!.
M;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=')E
M92!R96YD97)I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B=6EL9%1R964H
M)&YO9&5?:60I"B`@("!["B`@("`@("`@)&]U='!U="`]("1T:&ES+3Y?8G5I
M;&1,:6YE*"1N;V1E7VED*3L*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*2`F)@H@("`@("`@("`@("`D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@("`@("`@
M("`@("`D;G5M7W-U8FYO9&5S(#T@8V]U;G0H)'1H:7,M/E]N;V1E<ULD;F]D
M95]I9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@("`@("!F;W(@*"1C(#T@,#L@
M)&,@/"`D;G5M7W-U8FYO9&5S.R`D8RLK*2!["B`@("`@("`@("`@("`@("`D
M8VAI;&1?;F]D95]I9"`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL
M9')E;B==6R1C73L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D95]P;W-;
M)&-H:6QD7VYO9&5?:61=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;F]D95]P;W-;)&-H:6QD7VYO9&5?:61=6R=P;W,G72`]("1C("L@
M,3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F]D95]P;W-;)&-H:6QD7VYO
M9&5?:61=6R=C;W5N="==(#T@)&YU;5]S=6)N;V1E<SL*("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@)'1H:7,M/E]B=6EL9%1R964H)&-H:6QD7VYO9&5?
M:60I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T:6]N('1O(&-R
M96%T92!A('-I;F=L92!L:6YE(&]F('1H92!T<F5E+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YO9&5?:60@(%1H92!.;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F5N9&5R960@;&EN92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V)U:6QD3&EN92@D;F]D95]I9"D*("`@('L*("`@("`@("`D8VQA<W-.
M86UE(#T@)W1R9652;W<G.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)V-L87-S)UTI*2!["B`@("`@("`@("`@("1C;&%S
M<TYA;64@+CT@)R`G("X@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-L87-S
M)UT["B`@("`@("`@?0H@("`@("`@("\J($EF('5S:6YG(&%L=&5R;F%T:6YG
M(')O=R!S:&%D:6YG+"!W;W)K(&]U="!C;W)R96-T"B`@("`@("`@("H@<VAA
M9&4N("HO"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)V%L=&5R;F%T
M92<I*2!["B`@("`@("`@("`@("1C;&%S<TYA;64@+CT@)R!I=&5M)R`N("1T
M:&ES+3Y?86QT7V-O=6YT.PH@("`@("`@("`@("`D=&AI<RT^7V%L=%]C;W5N
M="`](#$@+2`D=&AI<RT^7V%L=%]C;W5N=#L*("`@("`@("!]"@H@("`@("`@
M("1L:6YE(#T@)SQD:78@8VQA<W,](B<@+B`D8VQA<W-.86UE("X@)R(^)SL*
M"B`@("`@("`@+RH@268@=V4@:&%V92!H96%D97)S+"!T<F%C:R!W:&EC:"!L
M;V=I8V%L(")C;VQU;6XB('=E)W)E(&EN"B`@("`@("`@("H@9F]R(&%N>2!G
M:79E;B!C96QL(&]F(&-O;G1E;G0N("HO"B`@("`@("`@)&-O;'5M;B`](#`[
M"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG
M97AT<F$G75M(3U)$15]44D5%7T585%)!7TQ%1E1=*2D@>PH@("`@("`@("`@
M("`D97AT<F$@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AT<F$G75M(
M3U)$15]44D5%7T585%)!7TQ%1E1=.PH@("`@("`@("`@("`D8TUA>"`](&-O
M=6YT*"1E>'1R82D["B`@("`@("`@("`@(&9O<B`H)&,@/2`P.R`D8R`\("1C
M36%X.R`D8RLK*2!["B`@("`@("`@("`@("`@("`D<W1Y;&4@/2`G)SL*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<ELD8V]L=6UN
M75LG=VED=&@G72DI('L*("`@("`@("`@("`@("`@("`@("`D<W1Y;&4@+CT@
M)W=I9'1H.B<@+B`D=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G72`N
M("<[)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D;&EN
M92`N/2`G/&1I=B!C;&%S<STB;&5F=$9L;V%T(B<["B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1S='EL92DI('L*("`@("`@("`@("`@("`@("`@("`D
M;&EN92`N/2`G('-T>6QE/2(G("X@)'-T>6QE("X@)R(G.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)&QI;F4@+CT@)SXG("X@)&5X=')A
M6R1C72`N("<\+V1I=CXG.PH*("`@("`@("`@("`@("`@("1C;VQU;6XK*SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'-T>6QE(#T@)R<[
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R6R1C;VQU;6Y=6R=W
M:61T:"==*2D@>PH@("`@("`@("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D
M=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G72`N("<[)SL*("`@("`@
M("!]"B`@("`@("`@)&QI;F4@+CT@)SQD:78@8VQA<W,](FQE9G1&;&]A="(G
M.PH@("`@("`@(&EF("@A96UP='DH)'-T>6QE*2D@>PH@("`@("`@("`@("`D
M;&EN92`N/2`G('-T>6QE/2(G("X@)'-T>6QE("X@)R(G.PH@("`@("`@('T*
M("`@("`@("`D;&EN92`N/2`G/B<["@H@("`@("`@(&EF("@D=&AI<RT^9V5T
M3W!T:6]N*"=M=6QT:6QI;F4G*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G
M/'1A8FQE(&-E;&QS<&%C:6YG/2(P(CX\='(^/'1D/B<["B`@("`@("`@?0H*
M("`@("`@("!F;W(@*"1I(#T@)'1H:7,M/E]S=&%T:6,@/R`Q(#H@,#L@)&D@
M/"`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UT[("1I*RLI('L*
M("`@("`@("`@("`@)&QI;F4@+CT@)SQI;6<@<W)C/2(G("X@)'1H:7,M/E]I
M;6=?9&ER("X@)R\G.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]D<F]P;&EN
M95LD:5T@)B8@)'1H:7,M/F=E=$]P=&EO;B@G;&EN97,G+"!F86QS92P@=')U
M92DI('L*("`@("`@("`@("`@("`@("1L:6YE("X]("1T:&ES+3Y?:6UG7VQI
M;F4@+B`G(B`G"B`@("`@("`@("`@("`@("`@("`@+B`G86QT/2)\)FYB<W`[
M)FYB<W`[)FYB<W`[(B`G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&QI;F4@+CT@)'1H:7,M/E]I;6=?8FQA;FL@+B`G(B`G"B`@
M("`@("`@("`@("`@("`@("`@+B`G86QT/2(F;F)S<#LF;F)S<#LF;F)S<#LB
M("<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QI;F4@+CT@)VAE:6=H
M=#TB,C`B('=I9'1H/2(R,"(@<W1Y;&4](G9E<G1I8V%L+6%L:6=N.FUI9&1L
M92(@+SXG.PH@("`@("`@('T*("`@("`@("`D;&EN92`N/2`D=&AI<RT^7W-E
M=$YO9&54;V=G;&4H)&YO9&5?:60I("X@)'1H:7,M/E]S971.;V1E26-O;B@D
M;F]D95]I9"D["B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VUU;'1I
M;&EN92<I*2!["B`@("`@("`@("`@("1L:6YE("X]("<\+W1D/CQT9#XG.PH@
M("`@("`@('T*("`@("`@("`D;&EN92`N/2`D=&AI<RT^7W-E=$QA8F5L*"1N
M;V1E7VED*3L*"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)VUU;'1I
M;&EN92<I*2!["B`@("`@("`@("`@("1L:6YE("X]("<\+W1D/CPO='(^/"]T
M86)L93XG.PH@("`@("`@('T*"B`@("`@("`@)&QI;F4@+CT@)SPO9&EV/B<[
M"B`@("`@("`@)&-O;'5M;BLK.PH*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]N;V1E<ULD;F]D95]I9%U;)V5X=')A)UU;2$]21$5?5%)%15]%6%1205]2
M24=(5%TI*2!["B`@("`@("`@("`@("1E>'1R82`]("1T:&ES+3Y?;F]D97-;
M)&YO9&5?:61=6R=E>'1R82==6TA/4D1%7U12145?15A44D%?4DE'2%1=.PH@
M("`@("`@("`@("`D8TUA>"`](&-O=6YT*"1E>'1R82D["B`@("`@("`@("`@
M(&9O<B`H)&,@/2`P.R`D8R`\("1C36%X.R`D8RLK*2!["B`@("`@("`@("`@
M("`@("`D<W1Y;&4@/2`G)SL*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7VAE861E<ELD8V]L=6UN75LG=VED=&@G72DI('L*("`@("`@("`@
M("`@("`@("`@("`D<W1Y;&4@+CT@)W=I9'1H.B<@+B`D=&AI<RT^7VAE861E
M<ELD8V]L=6UN75LG=VED=&@G72`N("<[)SL*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`D;&EN92`N/2`G/&1I=B!C;&%S<STB;&5F=$9L
M;V%T(B<["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1S='EL92DI('L*
M("`@("`@("`@("`@("`@("`@("`D;&EN92`N/2`G('-T>6QE/2(G("X@)'-T
M>6QE("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&QI;F4@+CT@)SXG("X@)&5X=')A6R1C72`N("<\+V1I=CXG.PH*("`@("`@
M("`@("`@("`@("1C;VQU;6XK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1L:6YE("X@(CPO9&EV/EQN(CL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE(&QA8F5L(&]N('1H92!T<F5E(&QI;F4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F]D95]I9"`@5&AE($YO9&4@240N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!L86)E;"!F;W(@=&AE('1R964@
M;&EN92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$QA8F5L*"1N;V1E7VED
M*0H@("`@>PH@("`@("`@("1N(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%T[
M"@H@("`@("`@("1O=71P=70@/2`G/'-P86XG.PH@("`@("`@(&EF("@A96UP
M='DH)&Y;)V]N8VQI8VLG72DI('L*("`@("`@("`@("`@)&]U='!U="`N/2`G
M(&]N8VQI8VL](B<@+B`D;ELG;VYC;&EC:R==("X@)R(G.PH@("`@("`@('T*
M("`@("`@("`D;W5T<'5T("X]("<^)SL*"B`@("`@("`@)&QA8F5L(#T@)&Y;
M)VQA8F5L)UT["B`@("`@("`@:68@*"%E;7!T>2@D;ELG=7)L)UTI*2!["B`@
M("`@("`@("`@("1T87)G970@/2`G)SL*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D;ELG=&%R9V5T)UTI*2!["B`@("`@("`@("`@("`@("`D=&%R9V5T(#T@
M)R!T87)G970](B<@+B`D;ELG=&%R9V5T)UT@+B`G(B<["B`@("`@("`@("`@
M('T@96QS96EF("@D=&%R9V5T(#T@)'1H:7,M/F=E=$]P=&EO;B@G=&%R9V5T
M)RDI('L*("`@("`@("`@("`@("`@("1T87)G970@/2`G('1A<F=E=#TB)R`N
M("1T87)G970@+B`G(B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U
M='!U="`N/2`G/&$G("X@*"%E;7!T>2@D;ELG=7)L8VQA<W,G72D@/R`G(&-L
M87-S/2(G("X@)&Y;)W5R;&-L87-S)UT@+B`G(B<@.B`G)RD@+B`G(&AR968]
M(B<@+B`D;ELG=7)L)UT@+B`G(B<@+B`D=&%R9V5T("X@)SXG("X@)&QA8F5L
M("X@)SPO83XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1O=71P
M=70@+CT@)&QA8F5L.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P
M=70@+B`G/"]S<&%N/B<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!N;V1E('1O9V=L92!O;B!T:&4@=')E92!L:6YE+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YO9&5?:60@(%1H92!.;V1E($E$+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;F]D92!T;V=G;&4@9F]R('1H92!T<F5E(&QI;F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]S971.;V1E5&]G9VQE*"1N;V1E7VED*0H@
M("`@>PH@("`@("`@("1L:6YK7W-T87)T(#T@)R<["@H@("`@("`@(&EF("@H
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N="==(#T](#`I("8F"B`@
M("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL
M9')E;B==*2D@>PH@("`@("`@("`@("`O*B!4;W`@;&5V96P@;F]D92!W:71H
M(&-H:6QD<F5N+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1R;W!L:6YE6S!=
M(#T@9F%L<V4["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-T871I8RD@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("!](&5L<V5I
M9B`H(21T:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2![
M"B`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?8FQA;FL["B`@
M("`@("`@("`@("`@("`D86QT(#T@)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@
M("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG
M97AP86YD960G72D@>PH@("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?
M:6UG7VUI;G5S7V]N;'D["B`@("`@("`@("`@("`@("`D86QT(#T@)RTG.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&EM9R`]("1T
M:&ES+3Y?:6UG7W!L=7-?;VYL>3L*("`@("`@("`@("`@("`@("1A;'0@/2`G
M*R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W-T
M871I8RD@>PH@("`@("`@("`@("`@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<BA(;W)D93HZ<V5L9E5R;"@I+"!(3U)$15]44D5%7U1/1T=,12`N("1T
M:&ES+3Y?:6YS=&%N8V4L("1N;V1E7VED*3L*("`@("`@("`@("`@("`@("1L
M:6YK7W-T87)T(#T@2&]R9&4Z.FQI;FLH)'5R;"D["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I
M;F1E;G0G72`A/2`P*2`F)@H@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]N
M;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI*2!["B`@("`@("`@("`@("\J
M($YO9&4@=VET:&]U="!C:&EL9')E;BX@*B\*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?;F]D95]P;W-;)&YO9&5?:61=6R=P;W,G72`\("1T:&ES+3Y?;F]D
M95]P;W-;)&YO9&5?:61=6R=C;W5N="==*2!["B`@("`@("`@("`@("`@("`O
M*B!.;W0@;&%S="!N;V1E+B`J+PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VIO:6X["B`@("`@("`@
M("`@("`@("`@("`@)&%L="`]("=\+2<["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VEM9U]B
M;&%N:SL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@)R9N8G-P.R9N8G-P
M.R9N8G-P.R<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1R;W!L:6YE6R1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=I;F1E
M;G0G75T@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@+RH@3&%S="!N;V1E+B`J+PH@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YG971/<'1I;VXH)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VIO:6Y?8F]T=&]M
M.PH@("`@("`@("`@("`@("`@("`@("1A;'0@/2`G8"TG.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H
M:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<F
M;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D<F]P;&EN95LD=&AI<RT^7VYO9&5S6R1N;V1E
M7VED75LG:6YD96YT)UU=(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H
M:6QD<F5N)UTI*2!["B`@("`@("`@("`@("\J($YO9&4@=VET:"!C:&EL9')E
M;BX@*B\*("`@("`@("`@("`@:68@*"1T:&ES+3Y?;F]D95]P;W-;)&YO9&5?
M:61=6R=P;W,G72`\("1T:&ES+3Y?;F]D95]P;W-;)&YO9&5?:61=6R=C;W5N
M="==*2!["B`@("`@("`@("`@("`@("`O*B!.;W0@;&%S="!N;V1E+B`J+PH@
M("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^9V5T3W!T:6]N*"=L:6YE<R<L
M(&9A;'-E+"!T<G5E*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;6<@/2`D
M=&AI<RT^7VEM9U]B;&%N:SL*("`@("`@("`@("`@("`@("`@("`D86QT(#T@
M)R9N8G-P.R9N8G-P.R9N8G-P.R<["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@("`@("`D:6UG
M(#T@)'1H:7,M/E]I;6=?:F]I;CL*("`@("`@("`@("`@("`@("`@("`D86QT
M(#T@)WPM)SL*("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@("`@("`@("`@("`@("`@
M("`@("1I;6<@/2`D=&AI<RT^7VEM9U]M:6YU<SL*("`@("`@("`@("`@("`@
M("`@("`D86QT(#T@)RTG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?<&QU<SL*("`@
M("`@("`@("`@("`@("`@("`D86QT(#T@)RLG.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D<F]P;&EN95LD=&AI<RT^7VYO
M9&5S6R1N;V1E7VED75LG:6YD96YT)UU=(#T@=')U93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($QA<W0@;F]D92X@*B\*("`@
M("`@("`@("`@("`@(&EF("@A)'1H:7,M/F=E=$]P=&EO;B@G;&EN97,G+"!F
M86QS92P@=')U92DI('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H
M:7,M/E]I;6=?8FQA;FL["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<F
M;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?<W1A=&EC*2!["B`@("`@("`@("`@("`@("`@("`@)&EM9R`]
M("1T:&ES+3Y?:6UG7VIO:6Y?8F]T=&]M.PH@("`@("`@("`@("`@("`@("`@
M("1A;'0@/2`G8"TG.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES
M+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A;F1E9"==*2!["B`@("`@("`@("`@
M("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7VUI;G5S7V)O='1O;3L*("`@
M("`@("`@("`@("`@("`@("`D86QT(#T@)RTG.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UG(#T@)'1H:7,M/E]I
M;6=?<&QU<U]B;W1T;VT["B`@("`@("`@("`@("`@("`@("`@)&%L="`]("<K
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9')O<&QI;F5;)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEN9&5N="==72`]
M(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]S=&%T:6,I('L*("`@("`@("`@("`@("`@("1U<FP@/2!5=&EL.CIA9&10
M87)A;65T97(H2&]R9&4Z.G-E;&95<FPH*2P@2$]21$5?5%)%15]43T='3$4@
M+B`D=&AI<RT^7VEN<W1A;F-E+"`D;F]D95]I9"D["B`@("`@("`@("`@("`@
M("`D;&EN:U]S=&%R="`]($AO<F1E.CIL:6YK*"1U<FPI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@5&]P(&QE=F5L
M(&YO9&4@=VET:"!N;R!C:&EL9')E;BX@*B\*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?<W1A=&EC*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH
M)VQI;F5S)RP@9F%L<V4L('1R=64I*2!["B`@("`@("`@("`@("`@("`D:6UG
M(#T@)'1H:7,M/E]I;6=?;G5L;%]O;FQY.PH@("`@("`@("`@("`@("`@)&%L
M="`]("<F;F)S<#LF;F)S<#LG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)&EM9R`]("1T:&ES+3Y?:6UG7V)L86YK.PH@("`@("`@
M("`@("`@("`@)&%L="`]("<F;F)S<#LF;F)S<#LF;F)S<#LG.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9')O<&QI;F5;,%T@/2!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("1L:6YK7V5N9"`]("@D;&EN:U]S=&%R
M="D@/R`G/"]A/B<@.B`G)SL*"B`@("`@("`@)&EM9R`]("1L:6YK7W-T87)T
M("X@)SQI;6<@<W)C/2(G("X@)'1H:7,M/E]I;6=?9&ER("X@)R\G("X@)&EM
M9R`N("<B)PH@("`@("`@("`@("`N("AI<W-E="@D86QT*2`_("<@86QT/2(G
M("X@)&%L="`N("<B)R`Z("<G*0H@("`@("`@("`@("`N("<@:&5I9VAT/2(R
M,"(@=VED=&@](C(P(B!S='EL93TB=F5R=&EC86PM86QI9VXZ;6ED9&QE(B!B
M;W)D97(](C`B("\^)PH@("`@("`@("`@("`N("1L:6YK7V5N9#L*"B`@("`@
M("`@<F5T=7)N("1I;6<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!I8V]N(&9O<B!T:&4@;F]D92X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N;V1E7VED("!4
M:&4@3F]D92!)1"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&YO9&4@:6-O;B!F;W(@=&AE('1R964@;&EN92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-E=$YO9&5)8V]N*"1N;V1E7VED*0H@("`@>PH@("`@("`@("1I
M;6=?9&ER(#T@:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VYD
M:7(G72D@/R`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;F1I<B==(#H@
M)'1H:7,M/E]I;6=?9&ER.PH@("`@("`@(&EF("@D:6UG7V1I<BD@>PH@("`@
M("`@("`@("`D:6UG7V1I<B`N/2`G+R<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VXG72DI('L*
M("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=
M6R=I8V]N)UTI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@+RH@3F]D92!H87,@82!U<V5R(&1E9FEN
M960@:6-O;BX@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;F]D
M97-;)&YO9&5?:61=6R=I8V]N;W!E;B==*2`F)@H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V5X<&%N9&5D)UTI('L*("`@("`@
M("`@("`@("`@("1I;6<@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O
M;F]P96XG73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1I;6<@/2`D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG:6-O;B==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E
M('-T86YD87)D(&EC;VX@<V5T+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)V-H:6QD<F5N)UTI*2!["B`@("`@
M("`@("`@("`@("`O*B!.;V1E('=I=&@@8VAI;&1R96XN("HO"B`@("`@("`@
M("`@("`@("`D:6UG(#T@*"1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=E>'!A
M;F1E9"==*2`_("1T:&ES+3Y?:6UG7V9O;&1E<E]O<&5N(#H@)'1H:7,M/E]I
M;6=?9F]L9&5R.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@+RH@3&5A9B!N;V1E("AN;R!C:&EL9')E;BDN("HO"B`@("`@("`@("`@
M("`@("`D:6UG(#T@)'1H:7,M/E]I;6=?;&5A9CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&EM9W1X="`]("<\:6UG('-R8STB)R`N("1I
M;6=?9&ER("X@)&EM9R`N("<B)SL*"B`@("`@("`@+RH@1&]E<R!T:&4@;F]D
M92!H879E('5S97(@9&5F:6YE9"!A;'0@=&5X=#\@*B\*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VYA;'0G72DI('L*
M("`@("`@("`@("`@)&EM9W1X="`N/2`G(&%L=#TB)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)VEC;VYA;'0G72D@+B`G
M(B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EM9W1X="`N("<@+SXG
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1R964O<V5L96-T+G!H<```````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-C`Q(#$P-3$U-#,T,30P
M(#`R,C(S,0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($AO<F1E7U1R965?<V5L96-T.CH@8VQA
M<W,@97AT96YD<R!T:&4@2&]R9&5?5')E92!C;&%S<R!T;R!P<F]V:61E"B`J
M(#QO<'1I;VX^('1A9R!R96YD97)I;F<N"B`J"B`J($-O<'ER:6=H="`R,#`U
M+3(P,#8@0F5N($-H879E="`\8F5N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1R964O5')E92]S96QE8W0N<&AP
M+'8@,2XR+C(N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C0P(&IA;B!%>'`@)`H@*@H@
M*B!`875T:&]R("!"96X@0VAA=F5T(#QB96Y`:&]R9&4N;W)G/@H@*B!`<&%C
M:V%G92!(;W)D95]4<F5E"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B\*8VQA
M<W,@2&]R9&5?5')E95]S96QE8W0@97AT96YD<R!(;W)D95]4<F5E('L*"B`@
M("`O*BH*("`@("`J(%1/1$\*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7VYO9&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J($-O;G-T<G5C=&]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!(;W)D95]4
M<F5E7W-E;&5C="@D=')E95]N86UE+"`D<&%R86US*0H@("`@>PH@("`@("`@
M('!A<F5N=#HZ2&]R9&5?5')E92@D=')E95]N86UE+"`D<&%R86US*3L*("`@
M("`@("`D=&AI<RT^7W-T871I8R`]('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!T<F5E+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@2%1-3"!C;V1E(&]F('1H92!R96YD97)E9"!T<F5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9714<F5E*"D*("`@('L*("`@("`@("`D
M=&AI<RT^7V)U:6QD26YD96YT<R@D=&AI<RT^7W)O;W1?;F]D97,I.PH*("`@
M("`@("`D=')E92`]("<G.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F]O
M=%]N;V1E<R!A<R`D;F]D95]I9"D@>PH@("`@("`@("`@("`D=')E92`N/2`D
M=&AI<RT^7V)U:6QD5')E92@D;F]D95]I9"D["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=')E93L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T
M:&4@8W5R<F5N="!E;G9I<F]N;65N="!T;R!S964@:68@=V4@8V%N(')E;F1E
M<B!T:&4@2%1-3"!T<F5E+@H@("`@("H@2%1-3"!I<R!A;'=A>7,@<F5N9&5R
M86)L92P@870@;&5A<W0@=6YT:6P@=V4@861D(&$@<&AP+6=T:R!T<F5E"B`@
M("`@*B!B86-K96YD+"!I;B!W:&EC:"!C87-E('1H:7,@:6UP;&5M96YT871I
M;VX@=VEL;"!A8W1U86QL>2!N965D(&$@8F]D>2X*("`@("`J"B`@("`@*B!`
M<W1A=&EC"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R
M(&]R(&YO="!T:&ES(%1R964Z.B!B86-K96YD('=I;&P@9G5N8W1I;VXN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES4W5P<&]R=&5D*"D*("`@('L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M:G5S="!T:&4@2E,@;F]D92!D969I;FET:6]N<R!A<R!A('-T<FEN9RX@5&AI
M<R!I<R!A(&YO+6]P(&9O<@H@("`@("H@=&AE('-E;&5C="!R96YD97)E<BX*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R3F]D941E9FEN:71I;VYS*"D*
M("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@861D:71I;VYA;"!P
M87)A;65T97)S('1O(&$@;F]D92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9"`@("`@5&AE('5N:7%U92!N;V1E(&ED+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N>2!O=&AE<B!P87)A;65T97)S('1O('-E="X*
M("`@("`J(#QP<F4^"B`@("`@*B!S96QE8W1E9"`M+2`@5VAE=&AE<B!T:&ES
M(&YO9&4@:7,@<V5L96-T960*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&1.;V1E4&%R86US*"1I9"P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%R86US*2D@>PH@("`@
M("`@("`@("`D<&%R86US(#T@87)R87DH)'!A<F%M<RD["B`@("`@("`@?0H*
M("`@("`@("`D86QL;W=E9"`](&%R<F%Y*"=S96QE8W1E9"<I.PH*("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;5]I9"`]/B`D<&%R86U?=F%L
M*2!["B`@("`@("`@("`@("\J(%-E="!O;FQY(&%L;&]W960@86YD(&YO;BUN
M=6QL('!A<F%M<RX@*B\*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1P87)A
M;5]I9"P@)&%L;&]W960I("8F("%I<U]N=6QL*"1P87)A;5]V86PI*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VYO9&5S6R1I9%U;)'!A<F%M7VED72`]
M("1P87)A;5]V86P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296-U<G-I=F4@9G5N8W1I;VX@=&\@=V%L:R!T:')O
M=6=H('1H92!T<F5E(&%R<F%Y(&%N9"!B=6EL9"!T:&4@;W5T<'5T+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YO9&5?:60@(%1H92!.;V1E($E$+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@=')E92!R96YD97)I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]B=6EL9%1R964H)&YO9&5?:60I"B`@("!["B`@("`@
M("`@)'-E;&5C=&5D(#T@)'1H:7,M/E]N;V1E<ULD;F]D95]I9%U;)W-E;&5C
M=&5D)UT@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<["@H@("`@("`@
M("1O=71P=70@/2`G/&]P=&EO;B!V86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA
M<G,H)&YO9&5?:60I("X@)R(G("X@)'-E;&5C=&5D("X@)SXG("X*("`@("`@
M("`@("`@<W1R7W)E<&5A="@G)FYB<W`[)FYB<W`[)RP@*&EN="DD=&AI<RT^
M7VYO9&5S6R1N;V1E7VED75LG:6YD96YT)UTI("X@:'1M;'-P96-I86QC:&%R
M<R@D=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG;&%B96PG72D@+@H@("`@("`@
M("`@("`G/"]O<'1I;VX^)SL*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M;F]D97-;)&YO9&5?:61=6R=C:&EL9')E;B==*2`F)@H@("`@("`@("`@("`D
M=&AI<RT^7VYO9&5S6R1N;V1E7VED75LG97AP86YD960G72D@>PH@("`@("`@
M("`@("`D;G5M7W-U8FYO9&5S(#T@8V]U;G0H)'1H:7,M/E]N;V1E<ULD;F]D
M95]I9%U;)V-H:6QD<F5N)UTI.PH@("`@("`@("`@("!F;W(@*"1C(#T@,#L@
M)&,@/"`D;G5M7W-U8FYO9&5S.R`D8RLK*2!["B`@("`@("`@("`@("`@("`D
M8VAI;&1?;F]D95]I9"`]("1T:&ES+3Y?;F]D97-;)&YO9&5?:61=6R=C:&EL
M9')E;B==6R1C73L*("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M
M/E]B=6EL9%1R964H)&-H:6QD7VYO9&5?:60I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]4<F5E+VIA=F%S8W)I<'0N<&AP````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S$T-R`Q,#4Q-30S-#$T
M,"`P,C,Q,C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!(;W)D95]4<F5E7VIA=F%S8W)I<'0Z
M.B!C;&%S<R!E>'1E;F1S('1H92!(;W)D95]4<F5E(&-L87-S('1O('!R;W9I
M9&4*("H@:F%V87-C<FEP="!S<&5C:69I8R!R96YD97)I;F<@9G5N8W1I;VYS
M+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R
M:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]4<F5E+U1R964O:F%V87-C<FEP="YP:'`L=B`Q+C,T+C(N.2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C0P(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!-87)K
M;R!$:G5K:6,@/&UA<FMO0&]B;&\N8V]M/@H@*B!`<&%C:V%G92!(;W)D95]4
M<F5E"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@2&]R9&5?5')E
M95]J879A<V-R:7!T(&5X=&5N9',@2&]R9&5?5')E92!["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;F%M92!O9B!T:&4@<V]U<F-E(&9O<B!T:&4@=')E92!D871A
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W-O=7)C95]N86UE(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!N86UE
M(&]F('1H92!T87)G970@96QE;65N="!T;R!O=71P=70@=&AE(&IA=F%S8W)I
M<'0@=')E92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]O<'1I;VYS7VYA;64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(&YA;64@;V8@=&AE('1A<F=E="!E;&5M96YT('1O(&]U='!U="!T:&4@
M:F%V87-C<FEP="!T<F5E+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W1A<F=E=%]N86UE(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E
M7U1R965?:F%V87-C<FEP="@D=')E95]N86UE+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!P87)E;G0Z.DAO<F1E7U1R964H)'1R965?;F%M
M92P@)'!A<F%M<RD["@H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)V)R
M;W=S97(G72DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]"
M<F]W<V5R+G!H<"<["B`@("`@("`@("`@("1'3$]"04Q36R=B<F]W<V5R)UT@
M/2`F0G)O=W-E<CHZ<VEN9VQE=&]N*"D["B`@("`@("`@?0H*("`@("`@("`O
M*B!#:&5C:R!F;W(@82!J879A<V-R:7!T('-E<W-I;VX@<W1A=&4N("HO"B`@
M("`@("`@:68@*"1T:&ES+3Y?=7-E<V5S<VEO;B`F)@H@("`@("`@("`@("!I
M<W-E="@D7T-/3TM)15LD=&AI<RT^7VEN<W1A;F-E("X@)U]E>'!A;F1E9"==
M*2D@>PH@("`@("`@("`@("`O*B!296UO=F4@(F5X<"(@<')E9FEX(&9R;VT@
M8V]O:VEE('9A;'5E+B`J+PH@("`@("`@("`@("`D;F]D97,@/2!E>'!L;V1E
M*"<L)RP@<W5B<W1R*"1?0T]/2TE%6R1T:&ES+3Y?:6YS=&%N8V4@+B`G7V5X
M<&%N9&5D)UTL(#,I*3L*"B`@("`@("`@("`@("\J($UA:V4@<W5R92!T:&5R
M92!A<F4@;F\@<')E=FEO=7,@;F]D97,@<W1O<F5D(&EN('1H90H@("`@("`@
M("`@("`@*B!S97-S:6]N+B`J+PH@("`@("`@("`@("`D7U-%4U-)3TY;)VAO
M<F1E7W1R964G75LD=&AI<RT^7VEN<W1A;F-E75LG97AP86YD960G72`](&%R
M<F%Y*"D["@H@("`@("`@("`@("`O*B!3879E(&YO9&5S('1O('1H92!S97-S
M:6]N+B`J+PH@("`@("`@("`@("!F;W)E86-H("@D;F]D97,@87,@)&ED*2![
M"B`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VAO<F1E7W1R964G75LD=&AI
M<RT^7VEN<W1A;F-E75LG97AP86YD960G75LD:61=(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('1R964N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'-T
M871I8R`@268@=')U92!T:&4@=')E92!N;V1E<R!C86XG="!B92!E>'!A;F1E
M9"!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&-O;&QA<'-E
M9"!A;F0@=&AE('1R964@9V5T<R!R96YD97)E9"!E>'!A;F1E9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($A434P@8V]D92!O9B!T:&4@
M<F5N9&5R960@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5')E92@D
M<W1A=&EC(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%T:6,@
M/2`D<W1A=&EC.PH@("`@("`@("1T:&ES+3Y?<V]U<F-E7VYA;64@/2`G;E\G
M("X@)'1H:7,M/E]I;G-T86YC93L*("`@("`@("`D=&AI<RT^7VAE861E<E]N
M86UE(#T@)VA?)R`N("1T:&ES+3Y?:6YS=&%N8V4["B`@("`@("`@)'1H:7,M
M/E]O<'1I;VYS7VYA;64@/2`G;U\G("X@)'1H:7,M/E]I;G-T86YC93L*("`@
M("`@("`D=&AI<RT^7W1A<F=E=%]N86UE(#T@)W1?)R`N("1T:&ES+3Y?:6YS
M=&%N8V4["B`@("`@("`@)'1H:7,M/E]B=6EL9$EN9&5N=',H)'1H:7,M/E]R
M;V]T7VYO9&5S*3L*"B`@("`@("`@)'1R964@/2`D=&AI<RT^7V=E=%1R9653
M;W5R8V4H*2`N"B`@("`@("`@("`@("`G/&1I=B!I9#TB)R`N("1T:&ES+3Y?
M=&%R9V5T7VYA;64@+B`G(CX\+V1I=CXG("X*("`@("`@("`@("`@("1T:&ES
M+3Y?9V5T5')E94EN:70H*3L*"B`@("`@("`@2&]R9&4Z.F%D9%-C<FEP=$9I
M;&4H)W1R964N:G,G+"`G:&]R9&4G*3L*("`@("`@("!R971U<FX@)'1R964[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!T:&4@8W5R<F5N="!E;G9I
M<F]N;65N="!T;R!S964@:68@=V4@8V%N(')E;F1E<B!T:&4@2%1-3`H@("`@
M("H@=')E92X@5V4@8VAE8VL@9F]R($1/32!S=7!P;W)T(&EN('1H92!B<F]W
M<V5R+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%=H971H97(@;W(@;F]T('1H:7,@5')E93HZ(&)A8VME
M;F0@=VEL;"!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@:7-3=7!P
M;W)T960H*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG8G)O=W-E
M<B==+3YH87-&96%T=7)E*"=D;VTG*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@:G5S="!T:&4@2E,@;F]D92!D969I;FET:6]N<R!A<R!A('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($IA=F%S
M8W)I<'0@;F]D92!A<G)A>2!D969I;FET:6]N<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5N9&5R3F]D941E9FEN:71I;VYS*"D*("`@('L*("`@("`@("`D
M=&AI<RT^7V)U:6QD26YD96YT<R@D=&AI<RT^7W)O;W1?;F]D97,I.PH*("`@
M("`@("`D;F]D94IS(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]N
M;V1E<R!A<R`D;F]D95]I9"`]/B`D;F]D92D@>PH@("`@("`@("`@("`D;F]D
M94IS("X]("1T:&ES+3Y?9V5T2G-!<G)A>45L96UE;G0H<W!R:6YT9B@G)7-;
M7"<E<UPG72<L("=N7R<@+B`D=&AI<RT^7VEN<W1A;F-E+"`D;F]D95]I9"DL
M("1N;V1E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;F]D94IS("X@
M)'1H:7,M/E]I;G-T86YC92`N("<N<F5N9&5R5')E92AR;V]T7VYO9&5S*3LG
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@9&%T82!F;W(@
M=&AE('1R964@87,@82!J879A<V-R:7!T(&%R<F%Y+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T5')E
M95-O=7)C92@I"B`@("!["B`@("`@("`@9VQO8F%L("1B<F]W<V5R.PH*("`@
M("`@("`D:G,@(#T@)SQS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG
M("X@(EQN(CL*("`@("`@("`D:G,@+CT@)W9A<B!E>'1R84-O;'-,969T(#T@
M)R`N("1T:&ES+3Y?97AT<F%?8V]L<U]L969T("X@(CM<;B(["B`@("`@("`@
M)&IS("X]("=V87(@97AT<F%#;VQS4FEG:'0@/2`G("X@)'1H:7,M/E]E>'1R
M85]C;VQS7W)I9VAT("X@(CM<;B(["B`@("`@("`@)&IS("X]("=V87(@)R`N
M("1T:&ES+3Y?<V]U<F-E7VYA;64@+B`G(#T@;F5W($%R<F%Y*"D[)R`N(")<
M;B(["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;F]D97,@87,@)&YO9&5?
M:60@/3X@)&YO9&4I('L*("`@("`@("`@("`@)&IS("X]("1T:&ES+3Y?9V5T
M2G-!<G)A>45L96UE;G0H<W!R:6YT9B@G)7-;7"<E<UPG72<L("1T:&ES+3Y?
M<V]U<F-E7VYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&)R;W=S97(M/F5S8V%P94I30V]D92AA
M9&1S;&%S:&5S*"1N;V1E7VED*2DI+"`D;F]D92D["B`@("`@("`@?0H@("`@
M("`@("1J<R`N/2`D=&AI<RT^7V=E=$IS07)R87E%;&5M96YT*"1T:&ES+3Y?
M:&5A9&5R7VYA;64L("1T:&ES+3Y?:&5A9&5R*3L*("`@("`@("`D:G,@+CT@
M)'1H:7,M/E]G971*<T%R<F%Y16QE;65N="@D=&AI<RT^7V]P=&EO;G-?;F%M
M92P@)'1H:7,M/E]O<'1I;VYS*3L*("`@("`@("`D:G,@+CT@)SPO<V-R:7!T
M/B<@+B`B7&XB.PH*("`@("`@("!R971U<FX@)&IS.PH@("`@?0H*("`@("\J
M*@H@("`@("H@3W5T<'5T<R!T:&4@:F%V87-C<FEP="!T;R!I;FET:6%L:7-E
M('1H92!T<F5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T5')E94EN:70H*0H@("`@>PH@("`@("`@
M("1J<R`@/2`G/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/B<@+B`B
M7&XB.PH@("`@("`@("1J<R`N/2!S<')I;G1F*"<E,21S(#T@;F5W($AO<F1E
M7U1R964H7"<E,21S7"<I.R<@+B`B7&XB+`H@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6YS=&%N8V4I.PH*("`@("`@("`D:G,@+CT@)'1H:7,M
M/E]G971*<T%R<F%Y16QE;65N="@G<F]O=%]N;V1E<R<L("1T:&ES+3Y?<F]O
M=%]N;V1E<RD["@H@("`@("`@("1J<R`N/2!S<')I;G1F*"(E<RYR96YD97)4
M<F5E*')O;W1?;F]D97,L("5S*3M<;CPO<V-R:7!T/EQN(BP*("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEN<W1A;F-E+`H@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W1A=&EC(#\@)W1R=64G(#H@)V9A;'-E)RD[
M"@H@("`@("`@(')E='5R;B`D:G,["B`@("!]"@H@("`@9G5N8W1I;VX@7V=E
M=$IS07)R87E%;&5M96YT*"1V87(L("1V86QU92D*("`@('L*("`@("`@("!I
M9B`H:7-?87)R87DH)'9A;'5E*2D@>PH@("`@("`@("`@("`D:G,@/2`D=F%R
M("X@)R`](&YE=R!!<G)A>2@I.R<@+B`B7&XB.PH@("`@("`@("`@("!F;W)E
M86-H("@D=F%L=64@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@
M("!I9B`H:7-?;G5M97)I8R@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1N97=687(@/2`D=F%R("X@)ULG("X@)&ME>2`N("==)SL*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&YE=U9A<B`]
M("1V87(@+B`G6UPG)R`N("1K97D@+B`G7"==)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1J<R`N/2`D=&AI<RT^7V=E=$IS07)R87E%
M;&5M96YT*"1N97=687(L("1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(')E='5R;B`D:G,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1V87(@+B`B(#T@)R(@+B!A9&1S;&%S:&5S*"1V86QU92D@+B`B
M)SM<;B(["B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,30P(#`R
M,30S,0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT
M97(N<&AP````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$U
M-#4@,3`U,34T,S0Q-#`@,#(R,C(W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*"F1E9FEN92@G5$585%](5$U,7U!!4U-42%)5)RP@,"D["F1E9FEN
M92@G5$585%](5$U,7U-93E1!6"<L(#$I.PID969I;F4H)U1%6%1?2%1-3%]-
M24-23R<L(#(I.PID969I;F4H)U1%6%1?2%1-3%]-24-23U],24Y+55),)RP@
M,RD["F1E9FEN92@G5$585%](5$U,7TY/2%1-3"<L(#0I.PID969I;F4H)U1%
M6%1?2%1-3%].3TA434Q?3D]"4D5!2R<L(#4I.PH*+RHJ"B`J(%1E>'1?1FEL
M=&5R.CH@:7,@82!P87)E;G0@8VQA<W,@9F]R(&1E9FEN:6YG('-T86-K86)L
M92!T97AT(&9I;'1E<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?
M1FEL=&5R+T9I;'1E<BYP:'`L=B`Q+C$U+C(N.2`R,#`V+S`U+S$Q(#$Y.C0Y
M.C$T(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H
M:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L
M+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@
M("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H870@=&AE(&9I;'1E<B!I
M;G-T86YC92!N965D<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]&:6QT
M97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]P
M87)A;7,@/2!A<G)A>5]M97)G92@D=&AI<RT^7W!A<F%M<RP@)'!A<F%M<RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<'!L:65S(&$@<V5T(&]F('!A='1E
M<FYS('1O(&$@8FQO8VL@;V8@=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T97AT("`@("!4:&4@=&5X="!T;R!F:6QT97(N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A='1E<FYS("!4:&4@87)R87D@;V8@<&%T=&5R;G,@
M=&\@9FEL=&5R('=I=&@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!T<F%N<V9O<FUE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!F
M:6QT97(H)'1E>'0L("1F:6QT97)S(#T@87)R87DH*2P@)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D9FEL=&5R<RDI
M('L*("`@("`@("`@("`@)&9I;'1E<G,@/2!A<G)A>2@D9FEL=&5R<RD["B`@
M("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@D<&%R86US*3L*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1F:6QT97)S(&%S("1N=6T@/3X@)&9I;'1E
M<BD@>PH@("`@("`@("`@("`D9FEL=&5R3V(@/2!497AT7T9I;'1E<CHZ9F%C
M=&]R>2@D9FEL=&5R+"!I<W-E="@D<&%R86US6R1N=6U=*2`_("1P87)A;7-;
M)&YU;5T@.B!A<G)A>2@I*3L*("`@("`@("`@("`@:68@*&ES7V$H)&9I;'1E
M<D]B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&9I;'1E<D]B+3YG971-97-S86=E*"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'!A='1E<FYS(#T@)&9I;'1E<D]B+3YG9710871T97)N<R@I.PH*
M("`@("`@("`@("`@+RH@4')E+7!R;V-E<W-I;F<N("HO"B`@("`@("`@("`@
M("1T97AT(#T@)&9I;'1E<D]B+3YP<F50<F]C97-S*"1T97AT*3L*"B`@("`@
M("`@("`@("\J('-T<E]R97!L86-E*"D@<VEM<&QE('!A='1E<FYS+B`J+PH@
M("`@("`@("`@("!I9B`H:7-S970H)'!A='1E<FYS6R=R97!L86-E)UTI*2![
M"B`@("`@("`@("`@("`@("`D9G)O;2`](&%R<F%Y7VME>7,H)'!A='1E<FYS
M6R=R97!L86-E)UTI.PH@("`@("`@("`@("`@("`@)'1O(#T@87)R87E?=F%L
M=65S*"1P871T97)N<ULG<F5P;&%C92==*3L*("`@("`@("`@("`@("`@("1T
M97AT(#T@<W1R7W)E<&QA8V4H)&9R;VTL("1T;RP@)'1E>'0I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`O*B!P<F5G7W)E<&QA8V4@8V]M<&QE>"!P
M871T97)N<RX@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1P871T97)N<ULG
M<F5G97AP)UTI*2!["B`@("`@("`@("`@("`@("`D9G)O;2`](&%R<F%Y7VME
M>7,H)'!A='1E<FYS6R=R96=E>'`G72D["B`@("`@("`@("`@("`@("`D=&\@
M/2!A<G)A>5]V86QU97,H)'!A='1E<FYS6R=R96=E>'`G72D["B`@("`@("`@
M("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@D9G)O;2P@)'1O+"`D=&5X
M="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%!O<W0M<')O8V5S
M<VEN9RX@*B\*("`@("`@("`@("`@)'1E>'0@/2`D9FEL=&5R3V(M/G!O<W10
M<F]C97-S*"1T97AT*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&5X
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE
M8V5S<V%R87D@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(*("`@("`J('!A
M='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H
M92!T97AT(&)E9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("!R971U
M<FX@)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S
M:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@(')E='5R;B!A<G)A>2@I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S
M87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X
M="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N
M(&$@8V]N8W)E=&4@5&5X=%]F:6QT97(@:6YS=&%N8V4@8F%S960@;VX*("`@
M("`J("1D<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1D<FEV
M97(@(%1H92!T>7!E(&]F(&-O;F-R971E(%1E>'1?1FEL=&5R('-U8F-L87-S
M('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N+B!4:&ES
M(&ES(&)A<V5D(&]N('1H92!F:6QT97(@9')I=F5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@*"1D<FEV97(I+B!4:&4@8V]D92!I<R!D>6YA;6EC
M86QL>2!I;F-L=61E9"X@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`D9')I=F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E('=I;&P@;&]O:R!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("1D<FEV97);,%T@9F]R('1H
M92!S=6)C;&%S<R!I;7!L96UE;G1A=&EO;B!N86UE9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("1D<FEV97);,5TN<&AP+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO
M;F%L(&-O;F9I9W5R871I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!P87)A;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(%1E>'1?1FEL=&5R("!4:&4@;F5W;'D@8W)E871E9"!C
M;VYC<F5T92!497AT7T9I;'1E<B!I;G-T86YC92P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@(&]R(&9A;'-E(&]N(&%N(&5R<F]R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R+"`D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&1R:79E<BDI('L*("`@
M("`@("`@("`@;&ES="@D9&ER+"`D9')I=F5R*2`]("1D<FEV97(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1D:7(I*2!["B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`D9&ER("X@)R\G("X@)&1R:79E<B`N("<N<&AP)SL*
M("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]&:6QT97(O)R`N("1D<FEV97(@+B`G+G!H<"<I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O1FEL
M=&5R+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@($!I;F-L=61E7V]N8V4@)TAO<F1E+U1E>'0O1FEL=&5R+R<@
M+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S
M(#T@)U1E>'1?1FEL=&5R7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S
M<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D9FEL=&5R(#T@)FYE
M=R`D8VQA<W,H)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&9I;'1E<B`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I
M;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1F:6QT97(["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'``````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$V,3<Q(#$P-3$U-#,T,3,W(#`R-30T-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M("=(;W)D92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G
M.PH*+RHJ"B`J($AI9VAL:6=H=',@<75O=&5D(&UE<W-A9V5S('=I=&@@9&EF
M9F5R96YT(&-O;&]R<R!F;W(@=&AE(&1I9F9E<F5N="!Q=6]T:6YG"B`J(&QE
M=F5L<RX*("H*("H@0U-3(&-L87-S(&YA;65S(&-A;&QE9"`B<75O=&5D,2(@
M+BXN(")Q=6]T961[)&-S<TQE=F5L<WTB(&UU<W0@8F4@<')E<V5N="X*("H@
M5&AE('1E>'0@=&\@8F4@<&%S<V5D(&EN(&UU<W0@:&%V92!A;')E861Y(&)E
M96X@<&%S<V5D('1H<F]U9V@*("H@:'1M;'-P96-I86QC:&%R<R@I+@H@*@H@
M*B!087)A;65T97)S.@H@*B`\<')E/@H@*B`G8VET96)L;V-K)R`@+2T@1&ES
M<&QA>2!C:71E(&)L;V-K<S\@1&5F875L=',@=&\@=')U92X*("H@)V-S<TQE
M=F5L<R<@("TM($YU;6)E<B!O9B!D969I;F5D($-34R!C;&%S<R!N86UE<RX@
M1&5F875L=',@=&\@-2X*("H@)VAI9&5";&]C:W,G("TM($AI9&4@<75O=&5D
M('1E>'0@8FQO8VMS(&)Y(&1E9F%U;'0_($1E9F%U;'1S('1O(&9A;'-E+@H@
M*B`\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O
M1FEL=&5R+VAI9VAL:6=H='%U;W1E<RYP:'`L=B`Q+C8N."XQ-B`R,#`V+S`X
M+S$V(#$V.C4V.C`P('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R
M9SX*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&-U<F5C86YT:2YO<F<^"B`J($!A=71H;W(@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT
M7T9I;'1E<E]H:6=H;&EG:'1Q=6]T97,@97AT96YD<R!497AT7T9I;'1E<B![
M"@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R
M<F%Y*`H@("`@("`@("=C:71E8FQO8VLG(#T^('1R=64L"B`@("`@("`@)V-S
M<TQE=F5L<R<@/3X@-2P*("`@("`@("`G:&ED94)L;V-K<R<@/3X@9F%L<V4*
M("`@("D["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N96-E
M<W-A<F%Y(&)E9F]R92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E
M9F]R92!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<')E4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@("`O*B!486-K(&$@;F5W
M;&EN92!O;G1O('1H92!B96=I;FYI;F<@;V8@=&AE('-T<FEN9R!S;R!T:&%T
M('=E"B`@("`@("`@("H@8V]R<F5C=&QY(&AI9VAL:6=H="!W:&5N('1H92!F
M:7)S="!C:&%R86-T97(@:6X@=&AE('-T<FEN9R!I<R!A"B`@("`@("`@("H@
M<75O=&4@8VAA<F%C=&5R+B`J+PH@("`@("`@(')E='5R;B`B7&XD=&5X="([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E
M<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R
M;G,H*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!E>'1R82!S<&%C97,@8F5F
M;W)E('%U;W1E9"!T97AT(&%S('1H92!#4U,@9F]R;6%T=&EN9R!W:6QL"B`@
M("`@("`@("H@875T;VUA=&EC86QL>2!A9&0@82!B:70@;V8@<W!A8V4@9F]R
M('5S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG8VET96)L;V-K
M)UTI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^(&%R
M<F%Y*"(O/&)R(%PO/EQS*EQN7',J/&)R(%PO/EQS*EQN7',J*"@F9W0[7',_
M*2LI+VTB(#T^("(\8G(@+SY<;EQ<,2(I*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!A<G)A>2@I.PH@("`@?0H*("`@("\J*@H@("`@("H@17AE8W5T
M97,@86YY(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL
M=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@(%1H92!T97AT(&%F=&5R('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S<R@D=&5X="D*("`@('L*("`@("`@
M("`O*B!)<R!T:&5R92!A(&)L86YK(&QI;F4H<RD@8F5F;W)E('1H92!C=7)R
M96YT(&QI;F4_("HO"B`@("`@("`@)&)L86YK;&EN92`](&9A;'-E.PH*("`@
M("`@("`O*B!5<V4@8VET92!B;&]C:W,@=&\@9&ES<&QA>2!T:&4@9&EF9F5R
M96YT('%U;W1I;F<@;&5V96QS/R`J+PH@("`@("`@("1C8B`]("1T:&ES+3Y?
M<&%R86US6R=C:71E8FQO8VLG73L*"B`@("`@("`@+RH@0VET92!L979E;"!B
M969O<F4@<&%R<VEN9R!T:&4@8W5R<F5N="!L:6YE+B`J+PH@("`@("`@("1Q
M;&5V96P@/2`P.PH*("`@("`@("`O*B!'96YE<F%T960@;W5T<'5T+B`J+PH@
M("`@("`@("1T97AT7V]U="`]("<G.PH*("`@("`@("`O*B!!9&0@<VAO=R]H
M:61E('1O9V=L97,@9F]R('=H;VQE('%U;W1E(&)L;V-K<RX@*B\*("`@("`@
M("`D=&5X="`]('!R96=?<F5P;&%C95]C86QL8F%C:R@G+RA<;BDH*"`J*"9G
M=#M<<S\I*R@_(2`_)F=T.RDN*C\I*%QN?"0I*#\A("HH)F=T.R`_*2LI*2]S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@D=&AI<RP@)U]A9&11=6]T951O9V=L97,G*2P@)'1E>'0I.PH*("`@("`@
M("`O*B!087)S92!T97AT(&QI;F4@8GD@;&EN92X@*B\*("`@("`@("!F;W)E
M86-H("AE>'!L;V1E*")<;B(L("1T97AT*2!A<R`D;&EN92D@>PH@("`@("`@
M("`@("`O*B!#:71E(&QE=F5L(&]F(&-U<G)E;G0@;&EN92X@*B\*("`@("`@
M("`@("`@)&-L979E;"`]("1C;&]S96QE=F5L(#T@,#L*("`@("`@("`@("`@
M)&UA=&-H97,@/2!A<G)A>2@I.PH@("`@("`@("`@("`O*B!$;R!W92!H879E
M(&$@8VET871I;VX@;&EN93\@*B\*("`@("`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R]>7',J*"@F9W0[7',_*2LI+VTG+"`D;&EN92P@)&UA=&-H97,I*2![
M"B`@("`@("`@("`@("`@("`O*B!#;W5N="!N=6UB97(@;V8@/B!C:&%R86-T
M97)S(#T^(&-I=&4@;&5V96P@*B\*("`@("`@("`@("`@("`@("1C;&5V96P@
M/2`D8VQO<V5L979E;"`](&-O=6YT*'!R96=?<W!L:70H)R\F9W0[7',_+R<L
M("1M871C:&5S6S%=*2D@+2`Q.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&-B("8F(&ES<V5T*"1M871C:&5S6S%=*2D@>PH@("`@("`@("`@
M("`@("`@+RH@4W1R:7`@86QL(#X@8VAA<F%C=&5R<RX@*B\*("`@("`@("`@
M("`@("`@("1L:6YE(#T@<W5B<W1R*"1L:6YE+"!3=')I;F<Z.FQE;F=T:"@D
M;6%T8VAE<ULQ72DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)
M<R!T:&ES(&-I=&4@;&5V96P@;&]W97(@=&AA;B!T:&4@8W5R<F5N="!L979E
M;#\@*B\*("`@("`@("`@("`@:68@*"1C;&5V96P@/"`D<6QE=F5L*2!["B`@
M("`@("`@("`@("`@("`O*B!3=')I<"!M;W)E('1H86X@;VYE(&)L86YK(&QI
M;F4@:6X@9G)O;G0@;V8@=&AE(&-I=&4*("`@("`@("`@("`@("`@("`J(&)L
M;V-K<RX@*B\*("`@("`@("`@("`@("`@(&EF("@D8FQA;FML:6YE*2!["B`@
M("`@("`@("`@("`@("`@("`@=VAI;&4@*"@D8G)?<W1R(#T@<W5B<W1R*"1T
M97AT7V]U="P@+3<I*2`]/2`B/&)R("\^7&XB*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T97AT7V]U="`]('-U8G-T<B@D=&5X=%]O=70L(#`L("TW
M*3L*("`@("`@("`@("`@("`@("`@("!].PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@+RH@061D('%U;W1E(&)L;V-K(&5N9"!T86=S(&9O
M<B!E86-H(&-I=&4@;&5V96PN("HO"B`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@)&-L979E;#L@)&D@/"`D<6QE=F5L.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1E>'1?;W5T("X]("@D8V(I(#\@)SPO9&EV/B<@.B`G/"]F
M;VYT/B<["B`@("`@("`@("`@("`@("`@("`@+2TD8VQO<V5L979E;#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\J(%-T<FEP('1R86EL
M:6YG(&QI;F4@8G)E86L@:68@=7-I;F<@8VET92!B;&]C:W,L('=E(&%L<F5A
M9'D*("`@("`@("`@("`@("`@("`J(&AA=F4@82!D:78@=&%G+B`J+PH@("`@
M("`@("`@("`@("`@:68@*"1C8B`F)B!P<F5G7VUA=&-H*"<O7#QB<B!<+SXD
M+R<L("1L:6YE*2D@>PH@("`@("`@("`@("`@("`@("`@("1L:6YE(#T@<W5B
M<W1R*"1L:6YE+"`P+"`M-BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("\J($ES('1H:7,@8VET92!L979E;"!H:6=H97(@=&AA;B!T:&4@8W5R
M<F5N="!L979E;#\@*B\*("`@("`@("`@("`@?2!E;'-E:68@*"1C;&5V96P@
M/B`D<6QE=F5L*2!["B`@("`@("`@("`@("`@("`O*B!3=')I<"!M;W)E('1H
M86X@;VYE(&)L86YK(&QI;F4@:6X@9G)O;G0@;V8@=&AE(&-I=&4*("`@("`@
M("`@("`@("`@("`J(&)L;V-K<RX@*B\*("`@("`@("`@("`@("`@(&EF("@D
M8FQA;FML:6YE*2!["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"@D8G)?
M<W1R(#T@<W5B<W1R*"1T97AT7V]U="P@+3<I*2`]/2`B/&)R("\^7&XB*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T97AT7V]U="`]('-U8G-T<B@D
M=&5X=%]O=70L(#`L("TW*3L*("`@("`@("`@("`@("`@("`@("!].PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@9F]R("@D:2`]("1Q;&5V
M96P[("1I(#P@)&-L979E;#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@
M("\J($%D9"!Q=6]T92!B;&]C:R!S=&%R="!T86=S(&9O<B!E86-H(&-I=&4@
M;&5V96PN("HO"B`@("`@("`@("`@("`@("`@("`@)'1E>'1?;W5T("X]("@D
M8V(I(#\@)SQD:78@8VQA<W,](F-I=&%T:6]N("<@.B`G/&9O;G0@8VQA<W,]
M(B<["B`@("`@("`@("`@("`@("`@("`@)'1E>'1?;W5T("X]("=Q=6]T960G
M("X@*"@D:2`E("1T:&ES+3Y?<&%R86US6R=C<W-,979E;',G72D@*R`Q*2`N
M("<B/B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($-O=6YT(&)L86YK(&QI;F5S+B`J+PH@("`@("`@("`@("`D
M8FQA;FML:6YE(#T@*"1L:6YE(#T]("<\8G(@+SXG*3L*"B`@("`@("`@("`@
M("1T97AT7V]U="`N/2`D;&EN92`N(")<;B(["B`@("`@("`@("`@("1Q;&5V
M96P@/2`D8VQE=F5L.PH@("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E
M(&%L;"!D:78O9F]N="!T86=S(&%R92!C;&]S960N("HO"B`@("`@("`@:68@
M*"1C;&]S96QE=F5L(#X@,"D@>PH@("`@("`@("`@("`D=&5X=%]O=70@/2!P
M<F5G7W)E<&QA8V4H)R\\7"]D:78^)"\G+"!S=')?<F5P96%T*"@D8V(I(#\@
M)SPO9&EV/B<@.B`G/"]F;VYT/B<L("1C;&]S96QE=F5L*2`N("<\+V1I=CXG
M+"`D=&5X=%]O=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5M;W9E('1H
M92!L96%D:6YG(&YE=VQI;F4@=V4@861D960@86)O=F4L(&EF(&ET)W,@<W1I
M;&P@=&AE<F4N("HO"B`@("`@("`@:68@*"1T97AT7V]U=%LP72`]/2`B7&XB
M*2!["B`@("`@("`@("`@("1T97AT7V]U="`]('-U8G-T<B@D=&5X=%]O=70L
M(#$I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT7V]U=#L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@;&EN:W,@=&\@<VAO=R!A;F0@:&ED
M92!Q=6]T960@8FQO8VMS+"!H:61I;F<@=&AE;2!B>2!D969A=6QT(&EF"B`@
M("`@*B!T:&4@)VAI9&5";&]C:W,G('!A<F%M971E<B!I<R!T<G5E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`D;6%T8VAE<R`@5&AE(&UA=&-H97,@9G)O;2!T:&4@<F5G97AP
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D475O=&54;V=G;&5S*"1M871C
M:&5S*0H@("`@>PH@("`@("`@('-T871I8R`D:2`](#`["@H@("`@("`@("\J
M($1O;B=T('1O9V=L92!S;6%L;"!B;&]C:W,[(&1O97-N)W0@<')O=FED92!A
M(%5)(&)E;F5F:70@86YD(&QO;VMS"B`@("`@("`@("H@86YN;WEI;F<N("HO
M"B`@("`@("`@)&QI;F5S(#T@<W5B<W1R7V-O=6YT*"1M871C:&5S6S!=+"`B
M7&XB*3L*("`@("`@("!I9B`H)&QI;F5S(#P@."D@>PH@("`@("`@("`@("!R
M971U<FX@)&UA=&-H97-;,%T["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ
M861D4V-R:7!T1FEL92@G:&ED96%B;&4N:G,G+"`G:&]R9&4G+"!T<G5E*3L*
M("`@("`@("!(;W)D93HZ861D4V-R:7!T1FEL92@G<75O=&5";&]C:W,N:G,G
M+"`G:&]R9&4G*3L*"B`@("`@("`@)'1E>'0@/2`G)SL*("`@("`@("!I9B`H
M)'1H:7,M/E]P87)A;7-;)V-I=&5B;&]C:R==*2!["B`@("`@("`@("`@("1T
M97AT(#T@)SQB<B`O/B<["B`@("`@("`@?3L*("`@("`@("`D=&5X="`N/2`G
M/&1I=B!I9#TB<71?)R`N("1I("X@)R(^)R`N"B`@("`@("`@("`@($AO<F1E
M.CIL:6YK*"<C)RP@)R<L("=W:61G970@=&]G9VQE<75O=&4G+"`G)RP@)W1O
M9V=L95%U;W1E0FQO8VLH7"<G("X@)&D@+B`G7"<L(%PG)R`N("1L:6YE<R`N
M("=<)RD[(')E='5R;B!F86QS93LG+"`G)RP@)R<L(&%R<F%Y*"=S='EL92<@
M/3X@)V9O;G0M<VEZ93HW,"4G*2D@+@H@("`@("`@("`@("`H)'1H:7,M/E]P
M87)A;7-;)VAI9&5";&]C:W,G72`_('-P<FEN=&8H7R@B6U-H;W<@475O=&5D
M(%1E>'0@+2`E<R!L:6YE<UTB*2P@)&QI;F5S*2`Z(%\H(EM(:61E(%%U;W1E
M9"!497AT72(I*2`N"B`@("`@("`@("`@("<\+V$^/"]D:78^/&1I=B!I9#TB
M<6)?)R`N("1I("X@)R(G("X@*"1T:&ES+3Y?<&%R86US6R=H:61E0FQO8VMS
M)UT@/R`G('-T>6QE/2)D:7-P;&%Y.FYO;F4[(B<@.B`G)RD@+B`G/B<@+B`D
M;6%T8VAE<ULP72`N("<\+V1I=CXG.PH*("`@("`@("`D:2LK.PH*("`@("`@
M("!R971U<FX@)'1E>'0["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M5&5X="]&:6QT97(O>'-S+G!H<```````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,3<V,C4@,3`U,34T,S0Q,S<@,#(S,#4W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!4:&ES
M(&9I;'1E<B!A='1E;7!T<R!T;R!M86ME($A434P@<V%F92!F;W(@=FEE=VEN
M9RX@250@25,@3D]4(%!%4D9%0U0N($EF"B`J('EO=2!E;F%B;&4@2%1-3"!V
M:65W:6YG+"!Y;W4@87)E(&]P96YI;F<@82!S96-U<FET>2!H;VQE+B!7:71H
M('1H92!C=7)R96YT"B`J('-T871E(&]F('1H92!W96(L($D@8F5L:65V92!T
M:&%T('1H92!B97-T('=E(&-A;B!D;R!I<R!T;R!M86ME('-U<F4@=&AA=`H@
M*B!P96]P;&4@*DM.3U<J($A434P@:7,@82!S96-U<FET>2!H;VQE+"!C;&5A
M;B!U<"!W:&%T('=E(&-A;BP@86YD(&QE879E(&ET"B`J(&%T('1H870N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]X<W,N
M<&AP+'8@,2XQ+C(N,R`R,#`V+S`R+S`Y(#$V.C0P.C0Q(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C$*
M("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?
M>'-S(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@1FEL
M=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G8F]D>5]O;FQY)R`]/B!T
M<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W)E<&QA8V4G(#T^("=8
M4U-#;&5A;F5D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=S=')I<%]S
M='EL97,G(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA
M<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D<&%T=&5R;G,@/2!A<G)A
M>2@I.PH*("`@("`@("`O*B!296UO=F5S($A434P@8V]M;65N=',@*&EN8VQU
M9&EN9R!S;VUE('-C<FEP=',@)B!S='EL97,I+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7W!A<F%M<ULG<W1R:7!?<W1Y;&5S)UTI('L*("`@("`@("`@("`@
M)'!A='1E<FYS6R<O/"$M+2XJ/RTM/B]S)UT@/2`G)SL*("`@("`@("!]"@H@
M("`@("`@("\J($-H86YG92!S<&%C92!E;G1I=&EE<R!T;R!S<&%C92!C:&%R
M86-T97)S+B`J+PH@("`@("`@("1P871T97)N<ULG+R8C*'@P*C(P?#`J,S(I
M.S\O:2==(#T@)R`G.PH*("`@("`@("`O*B!.=6ME(&YO;BUP<FEN=&%B;&4@
M8VAA<F%C=&5R<R`H82!P;&%Y(&EN('1H<F5E(&%C=',I+B`J+PH*("`@("`@
M("`O*B!2=6QE(#$I+B!296UO=F4@86QL(&-O;G1R;VP@8VAA<F%C=&5R<RX@
M*B\*("`@("`@("`O+R1D871A(#T@<')E9U]R97!L86-E*"<O6UQX,#`M7'@P
M.%QX,&4M7'@Q9ETO)RP@)R<L("1D871A*3L*"B`@("`@("`@+RH@4G5L92`Q
M*2X@268@=V4@:&%V92!A('-E;6EC;VQO;BP@:70@:7,@9&5T97)M:6YI<W1I
M8V%L;'D@9&5T96-T86)L90H@("`@("`@("`J(&%N9"!F:7AA8FQE+"!W:71H
M;W5T(&EN=')O9'5C:6YG(&-O;&QA=&5R86P@9&%M86=E+B`J+PH@("`@("`@
M("1P871T97)N<ULG+R8C>#\P*BA;.4$M1%U\,5LP+3-=*3LO:2==(#T@)R9N
M8G-P.R<["@H@("`@("`@("\J(%)U;&4@,BDN($AE>"!N=6UB97)S("AU<W5A
M;&QY(&AA=FEN9R!A;B!X('!R969I>"D@87)E(&%L<V\*("`@("`@("`@*B!D
M971E<FUI;FES=&EC+"!E=F5N(&EF('=E(&1O;B=T(&AA=F4@=&AE('-E;6DN
M($YO=&4@=&AA="!S;VUE"B`@("`@("`@("H@8G)O=W-E<G,@=VEL;"!T<F5A
M="`F(V$@;W(@)B,P82!A<R!A(&AE>"!N=6UB97(@979E;B!W:71H;W5T('1H
M92!X"B`@("`@("`@("H@<')E9FEX.R!H96YC92`O>#\O('=H:6-H('=I;&P@
M8V]V97(@=&AO<V4@8V%S97,@:6X@=&AI<R!R=6QE+B`J+PH@("`@("`@("1P
M871T97)N<ULG+R8C>#\P*ELY02U$72A;7C`M.4$M1EU\)"DO:2==(#T@)R9N
M8G-P7%PQ)SL*"B`@("`@("`@+RH@4G5L92`S*2X@1&5C:6UA;"!N=6UB97)S
M('=I=&AO=70@=')A:6QI;F<@<V5M:6-O;&]N<RX@5&AE('!R;V)L96T*("`@
M("`@("`@*B!I<R!T:&%T('-O;64@8G)O=W-E<G,@=VEL;"!I;G1E<G!R970@
M)B,Q,&$@87,@(EQN82(L('-O;64@87,*("`@("`@("`@*B`B)B-X,3!A(B!S
M;R!W92!H879E('1O(&-L96%N('1H92`F(S$P('1O(&)E('-A9F4@9F]R('1H
M92`B7&YA(B!C87-E"B`@("`@("`@("H@870@=&AE(&5X<&5N<V4@;V8@;6%N
M9VQI;F<@82!V86QI9"!E;G1I='D@:6X@;W1H97(@8V%S97,N("A3;VQU=&EO
M;@H@("`@("`@("`J(&9O<B!V86QI9"!(5$U,(&%U=&AO<G,Z(&%L=V%Y<R!U
M<V4@=&AE('-E;6EC;VQO;BXI("HO"B`@("`@("`@)'!A='1E<FYS6R<O)B,P
M*B@Y?#%;,"TS72DH6UXP+3E=?"0I+VDG72`]("<F;F)S<%Q<,B<["@H@("`@
M("`@("\J(%)E;6]V92!O=F5R;'D@;&]N9R!N=6UE<FEC(&5N=&ET:65S+B`J
M+PH@("`@("`@("1P871T97)N<ULG+R8C>#\P*ELP+3E!+49=>S8L?3L_+VDG
M72`]("<F;F)S<#LG.PH*("`@("`@("`O*B!296UO=F4@979E<GET:&EN9R!O
M=71S:61E(&]F(&%N9"!I;F-L=61I;F<@=&AE(#QB;V1Y/B!T86<N("HO"B`@
M("`@("`@:68@*"1T:&ES+3Y?<&%R86US6R=B;V1Y7V]N;'DG72D@>PH@("`@
M("`@("`@("`D<&%T=&5R;G-;)R\N*CQB;V1Y6UX^72H^+W-I)UT@/2`G)SL*
M("`@("`@("`@("`@)'!A='1E<FYS6R<O/%PO8F]D>3XN*B]S:2==(#T@)R<[
M"B`@("`@("`@?0H*("`@("`@("`O*B!'970@86QL(&%T=')I8G5T93TB:F%V
M87-C<FEP=#IF;V\H*2(@=&%G<RX@5&AI<R!I<R!E<W-E;G1I86QL>2!T:&4*
M("`@("`@("`@*B!R96=E>"`O*#U\=7)L7"@I*"(_*5M>/ETJ<V-R:7!T.B\@
M8G5T(&5X<&%N9&5D('1O(&-A=&-H(&-A;6]U9FQA9V4*("`@("`@("`@*B!W
M:71H('-P86-E<R!A;F0@96YT:71I97,N("HO"B`@("`@("`@)'!R96<@/2`G
M+R@H)B,P*C8Q.S]\)B-X,"HS1#L_?#TI?"<@+@H@("`@("`@("`@("`@("`@
M)R@H=7PF(S`J.#4[/WPF(W@P*C4U.S]\)B,P*C$Q-SL_?"8C>#`J-S4[/RE<
M<RHG("X*("`@("`@("`@("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\
M)B,P*C$Q-#L_?"8C>#`J-S([/RE<<RHG("X*("`@("`@("`@("`@("`@("<H
M;'PF(S`J-S8[/WPF(W@P*C1C.S]\)B,P*C$P.#L_?"8C>#`J-F,[/RE<<RHG
M("X*("`@("`@("`@("`@("`@("<H7"@I*2E<<RHG("X*("`@("`@("`@("`@
M("`@("<H)B,P*C,T.S]\)B-X,"HR,CL_?")\)B,P*C,Y.S]\)B-X,"HR-SL_
M?%PG*3\G("X*("`@("`@("`@("`@("`@("=;7CY=*EQS*B<@+@H@("`@("`@
M("`@("`@("`@)RAS?"8C,"HX,SL_?"8C>#`J-3,[/WPF(S`J,3$U.S]\)B-X
M,"HW,SL_*5QS*B<@+@H@("`@("`@("`@("`@("`@)RAC?"8C,"HV-SL_?"8C
M>#`J-#,[/WPF(S`J.3D[/WPF(W@P*C8S.S\I7',J)R`N"B`@("`@("`@("`@
M("`@("`G*')\)B,P*C@R.S]\)B-X,"HU,CL_?"8C,"HQ,30[/WPF(W@P*C<R
M.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G*&E\)B,P*C<S.S]\)B-X,"HT
M.3L_?"8C,"HQ,#4[/WPF(W@P*C8Y.S\I7',J)R`N"B`@("`@("`@("`@("`@
M("`G*'!\)B,P*C@P.S]\)B-X,"HU,#L_?"8C,"HQ,3([/WPF(W@P*C<P.S\I
M7',J)R`N"B`@("`@("`@("`@("`@("`G*'1\)B,P*C@T.S]\)B-X,"HU-#L_
M?"8C,"HQ,38[/WPF(W@P*C<T.S\I7',J)R`N"B`@("`@("`@("`@("`@("`G
M*#I\)B,P*C4X.S]\)B-X,"HS83L_*2]I)SL*("`@("`@("`D<&%T=&5R;G-;
M)'!R96==(#T@)UPQ7#@G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G73L*
M"B`@("`@("`@+RH@1V5T(&%L;"!O;CQF;V\^/2)B87(H*2(N($Y%5D52(&%L
M;&]W('1H97-E+B`J+PH@("`@("`@("1P871T97)N<ULG+RA;7',B7"==*R<@
M+@H@("`@("`@("`@("`@("`@("`G*&]\)B,P*C<Y.S]\)B,P*C1F.S]\)B,P
M*C$Q,3L_?"8C,"HV9CL_*2<@+@H@("`@("`@("`@("`@("`@("`G*&Y\)B,P
M*C<X.S]\)B,P*C1E.S]\)B,P*C$Q,#L_?"8C,"HV93L_*2<@+@H@("`@("`@
M("`@("`@("`@("`G7'<K*5QS*CTO:2==(#T@)UPQ)R`N("1T:&ES+3Y?<&%R
M86US6R=R97!L86-E)UT@+B`G/2<["@H@("`@("`@("\J(%)E;6]V92!A;&P@
M<V-R:7!T<R!S:6YC92!T:&5Y(&UI9VAT(&EN=')O9'5C92!G87)B86=E(&EF
M('1H97D@87)E"B`@("`@("`@("H@;F]T('%U;W1E9"!P<F]P97)L>2X@*B\*
M("`@("`@("`D<&%T=&5R;G-;)WP\<V-R:7!T6UX^72H^+BH_/"]S8W)I<'0^
M?&ES)UT@/2`G/"<@+B`D=&AI<RT^7W!A<F%M<ULG<F5P;&%C92==("X@)U]S
M8W)I<'0@+SXG.PH*("`@("`@("`O*B!'970@86QL('1A9W,@=&AA="!M:6=H
M="!C875S92!T<F]U8FQE("T@/&]B:F5C=#XL(#QE;6)E9#XL(#QB87-E/BP*
M("`@("`@("`@*B!E=&,N($UE=&$@<F5F<F5S:&5S(&%N9"!I9G)A;65S+"!T
M;V\N("HO"B`@("`@("`@)&UA;&EC:6]U<R`](&%R<F%Y*`H@("`@("`@("`@
M("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H<WPF(S`J.#,[/WPF
M(W@P*C4S.S]\)B,P*C$Q-3L_?"8C>#`J-S,[/RE<<RHG("X*("`@("`@("`@
M("`@)RAC?"8C,"HV-SL_?"8C>#`J-#,[/WPF(S`J.3D[/WPF(W@P*C8S.S\I
M7',J)R`N"B`@("`@("`@("`@("<H<GPF(S`J.#([/WPF(W@P*C4R.S]\)B,P
M*C$Q-#L_?"8C>#`J-S([/RE<<RHG("X*("`@("`@("`@("`@)RAI?"8C,"HW
M,SL_?"8C>#`J-#D[/WPF(S`J,3`U.S]\)B-X,"HV.3L_*5QS*B<@+@H@("`@
M("`@("`@("`G*'!\)B,P*C@P.S]\)B-X,"HU,#L_?"8C,"HQ,3([/WPF(W@P
M*C<P.S\I7',J)R`N"B`@("`@("`@("`@("<H='PF(S`J.#0[/WPF(W@P*C4T
M.S]\)B,P*C$Q-CL_?"8C>#`J-S0[/RE<<RHO:2<L"@H@("`@("`@("`@("`G
M+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF(S`J
M-#4[/WPF(S`J,3`Q.S]\)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@("<H
M;7PF(S`J-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\)B,P*C9D.S\I7',J)R`N
M"B`@("`@("`@("`@("<H8GPF(S`J-C8[/WPF(S`J-#([/WPF(S`J.3@[/WPF
M(S`J-C([/RE<<RHG("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_?"8C,"HT
M-3L_?"8C,"HQ,#$[/WPF(S`J-C4[/RE<<RHG("X*("`@("`@("`@("`@)RAD
M?"8C,"HV.#L_?"8C,"HT-#L_?"8C,"HQ,#`[/WPF(S`J-C0[/RE<<RHO:2<L
M"@H@("`@("`@("`@("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H
M>'PF(S`J.#@[/WPF(S`J-3@[/WPF(S`J,3(P.S]\)B,P*C<X.S\I7',J)R`N
M"B`@("`@("`@("`@("<H;7PF(S`J-S<[/WPF(S`J-&0[/WPF(S`J,3`Y.S]\
M)B,P*C9D.S\I7',J)R`N"B`@("`@("`@("`@("<H;'PF(S`J-S8[/WPF(W@P
M*C1C.S]\)B,P*C$P.#L_?"8C>#`J-F,[/RE<<RHO:2<L"@H@("`@("`@("`@
M("`G+SPH6UX^82UZ72HI)R`N"B`@("`@("`@("`@("<H8GPF(S`J-C8[/WPF
M(S`J-#([/WPF(S`J.3@[/WPF(S`J-C([/RE<<RHG("X*("`@("`@("`@("`@
M)RAA?"8C,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C,"HV,3L_*5QS*B<@
M+@H@("`@("`@("`@("`G*'-\)B,P*C@S.S]\)B-X,"HU,SL_?"8C,"HQ,34[
M/WPF(W@P*C<S.S\I7',J)R`N"B`@("`@("`@("`@("<H97PF(S`J-CD[/WPF
M(S`J-#4[/WPF(S`J,3`Q.S]\)B,P*C8U.S\I7',J)R`N"B`@("`@("`@("`@
M("=;7FQI;F5=+VDG+`H*("`@("`@("`@("`@)R\\*%M>/F$M>ETJ*2<@+@H@
M("`@("`@("`@("`G*&U\)B,P*C<W.S]\)B,P*C1D.S]\)B,P*C$P.3L_?"8C
M,"HV9#L_*5QS*B<@+@H@("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U
M.S]\)B,P*C$P,3L_?"8C,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G*'1\
M)B,P*C@T.S]\)B-X,"HU-#L_?"8C,"HQ,38[/WPF(W@P*C<T.S\I7',J)R`N
M"B`@("`@("`@("`@("<H87PF(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF
M(S`J-C$[/RE<<RHO:2<L"@H@("`@("`@("`@("`G+SPH6UX^82UZ72HI)R`N
M"B`@("`@("`@("`@("<H:GPF(S`J-S0[/WPF(S`J-&$[/WPF(S`J,3`V.S]\
M)B,P*C9A.S\I7',J)R`N"B`@("`@("`@("`@("<H87PF(S`J-C4[/WPF(S`J
M-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<<RHG("X*("`@("`@("`@("`@)RAV
M?"8C,"HX-CL_?"8C,"HU-CL_?"8C,"HQ,3@[/WPF(S`J-S8[/RE<<RHG("X*
M("`@("`@("`@("`@)RAA?"8C,"HV-3L_?"8C,"HT,3L_?"8C,"HY-SL_?"8C
M,"HV,3L_*5QS*B]I)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*
M("`@("`@("`@("`@)RAO?"8C,"HW.3L_?"8C,"HT9CL_?"8C,"HQ,3$[/WPF
M(S`J-F8[/RE<<RHG("X*("`@("`@("`@("`@)RAB?"8C,"HV-CL_?"8C,"HT
M,CL_?"8C,"HY.#L_?"8C,"HV,CL_*5QS*B<@+@H@("`@("`@("`@("`G*&I\
M)B,P*C<T.S]\)B,P*C1A.S]\)B,P*C$P-CL_?"8C,"HV83L_*5QS*B<@+@H@
M("`@("`@("`@("`G*&5\)B,P*C8Y.S]\)B,P*C0U.S]\)B,P*C$P,3L_?"8C
M,"HV-3L_*5QS*B<@+@H@("`@("`@("`@("`G*&-\)B,P*C8W.S]\)B-X,"HT
M,SL_?"8C,"HY.3L_?"8C>#`J-C,[/RE<<RHG("X*("`@("`@("`@("`@)RAT
M?"8C,"HX-#L_?"8C>#`J-30[/WPF(S`J,3$V.S]\)B-X,"HW-#L_*5QS*B]I
M)RP*"B`@("`@("`@("`@("<O/"A;7CYA+7I=*BDG("X*("`@("`@("`@("`@
M)RAI?"8C,"HW,SL_?"8C>#`J-#D[/WPF(S`J,3`U.S]\)B-X,"HV.3L_*5QS
M*B<@+@H@("`@("`@("`@("`G*&9\)B,P*C<P.S]\)B,P*C0V.S]\)B,P*C$P
M,CL_?"8C,"HV-CL_*5QS*B<@+@H@("`@("`@("`@("`G*')\)B,P*C@R.S]\
M)B-X,"HU,CL_?"8C,"HQ,30[/WPF(W@P*C<R.S\I7',J)R`N"B`@("`@("`@
M("`@("<H87PF(S`J-C4[/WPF(S`J-#$[/WPF(S`J.3<[/WPF(S`J-C$[/RE<
M<RHG("X*("`@("`@("`@("`@)RAM?"8C,"HW-SL_?"8C,"HT9#L_?"8C,"HQ
M,#D[/WPF(S`J-F0[/RE<<RHG("X*("`@("`@("`@("`@)RAE?"8C,"HV.3L_
M?"8C,"HT-3L_?"8C,"HQ,#$[/WPF(S`J-C4[/RE<<RHO:2<I.PH*("`@("`@
M("!F;W)E86-H("@D;6%L:6-I;W5S(&%S("1P871T97)N*2!["B`@("`@("`@
M("`@("1P871T97)N<ULD<&%T=&5R;ET@/2`G/"<@+B`D=&AI<RT^7W!A<F%M
M<ULG<F5P;&%C92==("X@)U]T86<G.PH@("`@("`@('T*"B`@("`@("`@+RH@
M0V]M;65N="!O=70@<W1Y;&4O;&EN:R!T86=S+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7W!A<F%M<ULG<W1R:7!?<W1Y;&5S)UTI('L*("`@("`@("`@("`@
M)'!A='1E<FYS6R<O7',K<W1Y;&5<<RH]+VDG72`]("<@)R`N("1T:&ES+3Y?
M<&%R86US6R=R97!L86-E)UT@+B`G/2<["B`@("`@("`@("`@("1P871T97)N
M<ULG?#QS='EL95M>/ETJ/B@_.EQS*CQ<(2TM*2I\:2==(#T@)SPA+2TG.PH@
M("`@("`@("`@("`D<&%T=&5R;G-;)WPH/SHM+3Y<<RHI*CPO<W1Y;&4^?&DG
M72`]("<M+3XG.PH@("`@("`@("`@("`D<&%T=&5R;G-;)WPH/&QI;FM;7CY=
M*CXI?&DG72`]("<\(2TM("0Q("TM/B<["B`@("`@("`@?0H*("`@("`@("`O
M*B!!(&9E=R!O=&AE<B!M871C:&5S+B`J+PH@("`@("`@("1P871T97)N<ULG
M?#PH6UX^72HI)GLN*GTH6UX^72HI/GPG72`]("<\)GL[?5PS/B<["B`@("`@
M("`@)'!A='1E<FYS6R=\/"A;7CY=*BEM;V-H83HH6UX^72HI/GQI)UT@/2`G
M/%PQ)R`N("1T:&ES+3Y?<&%R86US6R=R97!L86-E)UT@+B`G.EPR/B<["B`@
M("`@("`@)'!A='1E<FYS6R=\/"A;7CY=*BEB:6YD:6YG.BA;7CY=*BD^?&DG
M72`]("<\7#$G("X@)'1H:7,M/E]P87)A;7-;)W)E<&QA8V4G72`N("<Z7#(^
M)SL*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1P871T97)N
M<RD["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+V-L96%N87-C:6DN<&AP
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,38S(#$P-3$U-#,T,3,W(#`R
M-#,R-P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@4F5M;W9E<R!S;VUE(&-O;6UO;B!E;G1I=&EE<R!A
M;F0@:&EG:"UA<V-I:2!O<B!O=&AE<G=I<V4@;F]N<W1A;F1A<F0*("H@8VAA
M<F%C=&5R<R!C;VUM;VX@:6X@=&5X="!P87-T960@9G)O;2!-:6-R;W-O9G0@
M5V]R9"!I;G1O(&$@8G)O=W-E<BX*("H*("H@5&AI<R!F=6YC=&EO;B!S:&]U
M;&0@3D]4(&)E('5S960@;VX@;F]N+4%30TE)('1E>'0[(&ET(&UA>2!A;F0@
M<')O8F%B;'D*("H@=VEL;"!B=71C:&5R(&]T:&5R(&-H87)A8W1E<B!S971S
M(&EN9&5S8W)I;6EN871E;'DN("!5<V4@:70@;VYL>2!T;R!C;&5A;@H@*B!5
M4RU!4T-)22`H-RUB:70I('1E>'0@=VAI8V@@>6]U('-U<W!E8W0@*&]R(&MN
M;W<I(&UA>2!H879E(&EN=F%L:60@;W(*("H@;F]N+7!R:6YT:6YG(&-H87)A
M8W1E<G,@:6X@:70N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]C;&5A;F%S8VEI+G!H<"QV(#$N,RXR+C0@,C`P-B\P,2\P
M,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P
M-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E>'0*
M("HO"F-L87-S(%1E>'1?1FEL=&5R7V-L96%N87-C:6D@97AT96YD<R!497AT
M7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D92!N
M96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R;G,N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@
M8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O?"A;7B-=*BDC+BHO)RP@)'1E>'0L("1R96=S*2D@>PH@("`@("`@
M("`@("`D=&5X="`]("1R96=S6S%=.PH*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&5X="DI('L*("`@("`@("`@("`@("`@("1T97AT(#T@)'1E>'0@+B`B
M7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1E>'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W
M:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("\J(%)E;6]V92!C;VYT<F]L(&-H
M87)A8W1E<G,N("HO"B`@("`@("`@)')E9V5X<"`](&%R<F%Y*"<O6UQX,#`M
M7'@Q9ETK+R<@/3X@)R<I.PH*("`@("`@("`O*B!4:&4@)Y(G(&5N=')Y(&UA
M>2!L;V]K('=R;VYG+"!D97!E;F1I;F<@;VX@>6]U<B!E9&ET;W(L"B`@("`@
M("`@("H@8G5T(&ET)W,@;F]T("T@=&AA="=S(&YO="!R96%L;'D@82!S:6YG
M;&4@<75O=&4N("HO"B`@("`@("`@)')E<&QA8V4@/2!A<G)A>2AC:'(H,34P
M*2`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("!C:'(H,38W*2`]
M/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G@;<G(#T^("<J)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@(">%)R`]/B`G+BXN)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@(">1)R`]/B`B)R(L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`GDB<@/3X@(B<B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)Y,G(#T^("<B)RP*("`@("`@("`@("`@("`@("`@("`@("`@(">4)R`]
M/B`G(B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`GE2<@/3X@)RHG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)Y8G(#T^("<M)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@(">7)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`GGR<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)R8C-C$T-SD[)R`]/B`G+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G
M)B,V,34W,CLG(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F
M(S8Q-3DT.R<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C
M-C$V-#`[)R`]/B`G+2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V
M,38R,SLG(#T^("<M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S8Q
M-C`W.R<@/3X@)RHG+`H@("`@("`@("`@("`@("`@("`@("`@("`@)R8C-C$U
M-3,[)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,V,34U
M.#LG(#T^("<J)RP*("`@("`@("`@("`@("`@("`@("`@("`@("<F(S@R,C8[
M)R`]/B`G*B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)B,Y-C4X.R<@
M/3X@)SXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`L("=R97!L86-E)R`]
M/B`D<F5P;&%C92D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O5&5X="]&:6QT97(O=V]R9',N<&AP````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#,Q,3$@,3`U,34T,S0Q,S<@,#(S,S8Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!&
M:6QT97)S('1H92!G:79E;B!T97AT(&)A<V5D(&]N('1H92!W;W)D<R!F;W5N
M9"!I;B!A('=O<F0@;&ES=`H@*B!F:6QE+@H@*@H@*B!087)A;65T97)S.@H@
M*B`\<')E/@H@*B!W;W)D<U]F:6QE("`M+2!&:6QE;F%M92!C;VYT86EN:6YG
M('1H92!W;W)D<R!T;R!R97!L86-E+@H@*B!R97!L86-E;65N="`M+2!4:&4@
M<F5P;&%C96UE;G0@<W1R:6YG+B`@1&5F875L=',@=&\@(BHJ*BHJ(BX*("H@
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]W;W)D<RYP:'`L=B`Q+C(N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA<W,@
M5&5X=%]&:6QT97)?=V]R9',@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@
M+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=R
M97!L86-E;65N="<@/3X@)RHJ*BHJ)RD["@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@("1R96=E>'`@
M/2!A<G)A>2@I.PH*("`@("`@("!I9B`H0&ES7W)E861A8FQE*"1T:&ES+3Y?
M<&%R86US6R=W;W)D<U]F:6QE)UTI*2!["B`@("`@("`@("`@("\J(%)E860@
M=&AE(&9I;&4@86YD(&ET97)A=&4@=&AR;W5G:"!T:&4@;&EN97,N("HO"B`@
M("`@("`@("`@("1L:6YE<R`](&9I;&4H)'1H:7,M/E]P87)A;7-;)W=O<F1S
M7V9I;&4G72D["B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN
M92D@>PH@("`@("`@("`@("`@("`@+RH@4W1R:7`@=VAI=&5S<&%C92!A;F0@
M8V]M;65N=',N("HO"B`@("`@("`@("`@("`@("`D;&EN92`]('1R:6TH)&QI
M;F4I.PH@("`@("`@("`@("`@("`@)&QI;F4@/2!P<F5G7W)E<&QA8V4H)WPC
M+BHD?"<L("<G+"`D;&EN92D["@H@("`@("`@("`@("`@("`@+RH@1FEL=&5R
M('1H92!T97AT+B`J+PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D;&EN
M92DI('L*("`@("`@("`@("`@("`@("`@("`D<F5G97AP6R(O*%QB*%QW*BDD
M;&EN95QB?%QB)&QI;F4H7'<J*5QB*2]I(ET@/2`D=&AI<RT^7W!A<F%M<ULG
M<F5P;&%C96UE;G0G73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^
M("1R96=E>'`I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+W)S="YP:'``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q-S4V(#$P-3$U-#,T,3,W(#`R,S`U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E
M("=497AT+W)E4U0N<&AP)SL*<F5Q=6ER95]O;F-E("=497AT+W)E4U0O1F]R
M;6%T=&5R+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?1FEL=&5R7W)S=#HZ(&-L
M87-S(&-O;G9E<G1S(')E4W1R=6-T=7)E9%1E>'0@=&\@2%1-3"X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+W)S="YP:'`L
M=B`Q+CDN,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C,X(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N($TN($9E;&EC92`\:F9E;&EC
M94!C<F]N;W-Y<RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*
M87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C
M:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]R<W0@97AT
M96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A
M;GD@8V]D92!N96-E<W-A<F%Y(&%F=&5R(&%P<&QY:6YG('1H92!F:6QT97(*
M("`@("`J('!A='1E<FYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@(%1H92!T97AT(&%F=&5R('1H92!F:6QT97)I;F<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!P;W-T4')O8V5S<R@D=&5X="D*("`@('L*("`@
M("`@("`D9&]C=6UE;G0@/2`F5&5X=%]R95-4.CIP87)S92@D=&5X="D["B`@
M("`@("`@)&9O<FUA='1E<B`]("9497AT7W)E4U1?1F]R;6%T=&5R.CIF86-T
M;W)Y*"=H=&UL)RD["B`@("`@("`@<F5T=7)N("1F;W)M871T97(M/F9O<FUA
M="@D9&]C=6UE;G0L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@('T*"GT*````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+W-P86-E,FAT;6PN<&AP````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`T,C(W(#$P-3$U-#,T,3,W(#`R-#(W-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE('-P86-E,FAT;6P@9FEL=&5R(&-O;G9E<G1S(&AO<FEZ;VYT86P@=VAI
M=&5S<&%C92!T;R!(5$U,(&-O9&4N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP
M<F4^"B`J(&5N8V]D92`@("`@+2T@2%1-3"!E;F-O9&4@=&AE('1E>'0_("!$
M969A=6QT<R!T;R!F86QS92X*("H@8VAA<G-E="`@("`M+2!#:&%R<V5T(&]F
M('1H92!T97AT+B`@1&5F875L=',@=&\@25-/+3@X-3DM,2X*("H@96YC;V1E
M7V%L;"`M+2!297!L86-E(&%L;"!S<&%C97,@=VET:"`F;F)S<#L_("!$969A
M=6QT<R!T;R!F86QS92X*("H@/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]S<&%C93)H=&UL+G!H<"QV(#$N,2XQ
M,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@:F%N($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`Q($UA=&AI974@07)N;VQD(#QA<FY?;6%T0&-L=6(M:6YT97)N
M970N9G(^"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($UA=&AI
M974@07)N;VQD(#QA<FY?;6%T0&-L=6(M:6YT97)N970N9G(^"B`J($!P86-K
M86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7W-P86-E,FAT
M;6P@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT
M97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=E;F-O9&4G(#T^(&9A;'-E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V-H87)S970G(#T^("=)4T\M
M.#@U.2TQ)RP*("`@("`@("`@("`@("`@("`@("`@("`@("=E;F-O9&5?86QL
M)R`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D
M92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R
M;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E
M>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7W!A<F%M<ULG96YC;V1E)UTI('L*("`@("`@("`@("`@)'1E>'0@/2!`
M:'1M;'-P96-I86QC:&%R<R@D=&5X="P@14Y47T-/35!!5"P@)'1H:7,M/E]P
M87)A;7-;)V-H87)S970G72D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I
M=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M871T97)N<R@I"B`@("!["B`@("`@("`@)')E<&QA8V4@/2!A<G)A>2@B7'0B
M(#T^("<F;F)S<#L@)FYB<W`[("9N8G-P.R`F;F)S<#L@)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("<@("<@/3X@)R9N8G-P.R`G*3L*("`@("`@("!R
M971U<FX@87)R87DH)W)E<&QA8V4G(#T^("1R97!L86-E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@869T
M97(@87!P;'EI;F<@=&AE(&9I;'1E<B!P871T97)N<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!A9G1E<B!T:&4@9FEL
M=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H
M)'1E>'0I"B`@("!["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@G("`G
M+"`G("9N8G-P.R<L("1T97AT*3L*("`@("`@("!I9B`H)'1H:7,M/E]P87)A
M;7-;)V5N8V]D95]A;&PG72D@>PH@("`@("`@("`@("`D=&5X="`]('-T<E]R
M97!L86-E*"<@)RP@)R9N8G-P.R<L("1T97AT*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W-I;7!L96UA<FMU<"YP:'``
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,3$U(#$P-3$U-#,T,3,W(#`R-#<S
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@2&EG:&QI9VAT<R!S:6UP;&4@;6%R:W5P(&%S('5S960@
M:6X@96UA:6QS(&]R('5S96YE="!P;W-T:6YG<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL=&5R+W-I;7!L96UA<FMU<"YP:'`L
M=B`Q+C$N,3`N-2`R,#`V+S`W+S(T(#$U.C4T.C4T('-L=7-A<GH@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*
M("H@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R
M7W-I;7!L96UA<FMU<"!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C92!P871T97)N<RX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T97)N<R!H87-H+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I"B`@("!["B`@("`@
M("`@)')E9V5X<"`](&%R<F%Y*`H@("`@("`@("`@("`O+R!";VQD+@H@("`@
M("`@("`@("`G+RA>?%QS?"9N8G-P.WP\8G(@7"\^*2A<*EM>*EQS72M<*BDH
M7'-\)FYB<W`[?#QB<GQ<+BDO:2<@/3X@)UPQ/'-T<F]N9SY<,CPO<W1R;VYG
M/EPS)RP*"B`@("`@("`@("`@("\O(%5N9&5R;&EN92X*("`@("`@("`@("`@
M)R\H7GQ<<WPF;F)S<#M\/&)R(%PO/BDH7UM>7UQS72M?*2A<<WPF;F)S<#M\
M/&)R?%PN*2]I)R`]/B`G7#$\=3Y<,CPO=3Y<,R<L"@H@("`@("`@("`@("`O
M+R!)=&%L:6,N"B`@("`@("`@("`@("<[*%Y\7'-\)FYB<W!<.WP\8G(@+SXI
M*"];7B]<<UTK+RDH7'-\)FYB<W!<.WP\8G)\7"XI.VDG(#T^("=<,3QE;3Y<
M,CPO96T^7#,G*3L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R96=E>'`G(#T^
M("1R96=E>'`I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&
M:6QT97(O9&EM<VEG;F%T=7)E+G!H<```````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(S-C,@,3`U,34T,S0Q,S<@,#(T-S(V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!$:7-P;&%Y<R!M
M97-S86=E('-I9VYA='5R97,@;6%R:V5D(&)Y(&$@)RTM("<@:6X@=&AE('-T
M>6QE(&]F('1H90H@*B!#4U,@8VQA<W,@(G-I9VYA='5R92(N($-L87-S(&YA
M;65S(&EN<VED92!T:&4@<VEG;F%T=7)E(&%R90H@*B!P<F5F:7AE9"!W:71H
M(")S:6=N871U<F4M(BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&
M:6QT97(O1FEL=&5R+V1I;7-I9VYA='5R92YP:'`L=B`Q+C(N,3`N-B`R,#`V
M+S`X+S$W(#$R.C(Y.C4U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M5&5X=`H@*B\*8VQA<W,@5&5X=%]&:6QT97)?9&EM<VEG;F%T=7)E(&5X=&5N
M9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@17AE8W5T97,@86YY
M(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A<'!L>6EN9R!T:&4@9FEL=&5R"B`@
M("`@*B!P871T97)N<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M97AT("!4:&4@=&5X="!A9G1E<B!T:&4@9FEL=&5R:6YG+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@=&5X="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H)'1E>'0I"B`@("!["B`@("`@
M("`@)'!A<G1S(#T@<')E9U]S<&QI="@G?"A<;BTM7',J*#QB<B`O/BD_7'(_
M7&XI?"<L("1T97AT+"`R+"!04D5'7U-03$E47T1%3$E-7T-!4%154D4I.PH@
M("`@("`@(&EF("AC;W5N="@D<&%R=',I(#X@,RD@>PH@("`@("`@("`@("`D
M=&5X="`](&%R<F%Y7W-H:69T*"1P87)T<RD["B`@("`@("`@("`@("1T97AT
M("X]("<\<W!A;B!C;&%S<STB<VEG;F%T=7)E(CXG("X@)'!A<G1S6S!=.PH@
M("`@("`@("`@("`D=&5X="`N/2!P<F5G7W)E<&QA8V4H)WQC;&%S<STB*%M>
M(ETK*2)\)RP@)V-L87-S/2)S:6=N871U<F4M7#$B)RP@)'!A<G1S6S)=*3L*
M("`@("`@("`@("`@)'1E>'0@+CT@)SPO<W!A;CXG.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]497AT+T9I;'1E<B]B8F-O9&4N<&AP````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,3`W,R`Q,#4Q-30S-#$S-R`P,C,T
M-#<`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4N<&AP)SL*"B\J*@H@*B!4:&4@
M5&5X=%]&:6QT97)?8F)C;V1E.CH@8VQA<W,@9FEN9',@8F)C;V1E+7-T>6QE
M(&UA<FMU<"`H<V5E(&)E;&]W*2!I;B!A"B`J(&)L;V-K(&]F('1E>'0@86YD
M('1U<FYS(&ET(&EN=&\@2%1-3"X*("H*("H@4&%R86UE=&5R<SH*("H@/'!R
M93X*("H@96YT:71I97,@+2T@268@=')U92!B969O<F4@<F5P;&%C:6YG(&)B
M8V]D92!W:71H($A434P@=&%G<RP@86YY($A434P*("H@("`@("`@("`@("`@
M96YT:71I97,@=VEL;"!B92!R97!L86-E9"X*("H@/"]P<F4^"B`J"B`J(%-U
M<'!O<G1E9"!B8F-O9&4Z"B`J(#QP<F4^"B`J("`@("!;8EU";VQD(%1E>'1;
M+V)="B`J("`@("!;:5U)=&%L:6-S(%1E>'1;+VE="B`J("`@("!;=5U5;F1E
M<FQI;F5D(%1E>'1;+W5="B`J("`@("!;<75O=&5=475O=&5D(%1E>'1;+W%U
M;W1E70H@*B`@("`@6V-E;G1E<EU#96YT97)E9"!497AT6R]C96YT97)="B`J
M"B`J("`@("!,:7-T(&]F(&ET96US"B`J("`@("!;;&ES=%T*("H@("`@(%LJ
M72!)=&5M(&]N90H@*B`@("`@6RI=($ET96T@='=O"B`J("`@("!;+VQI<W1=
M"B`J"B`J("`@("!.=6UB97)E9"!L:7-T"B`J("`@("!;;G5M;&ES=%T*("H@
M("`@(%LJ72!)=&5M(&]N90H@*B`@("`@6RI=($ET96T@='=O"B`J("`@("!;
M+VYU;6QI<W1="B`J"B`J("`@("!;=7)L76AT='`Z+R]W=W<N:&]R9&4N;W)G
M6R]U<FQ=("T^($QI;FL@=&\@=&AE(&%D9')E<W,@=7-I;F<@=&AE"B`J("`@
M("`@("`@861D<F5S<R!I='-E;&8@9F]R('1H92!T97AT+B`@66]U(&-A;B!S
M<&5C:69Y('1H92!P<F]T;V-O;#H@:'1T<"!O<@H@*B`@("`@("`@(&AT='!S
M(&%N9"!T:&4@<&]R="X*("H@("`@(%MU<FQ==W=W+FAO<F1E+F]R9ULO=7)L
M72`M/B!,:6YK('1O('1H92!A9&1R97-S('5S:6YG('1H92!A9&1R97-S"B`J
M("`@("`@("`@:71S96QF(&9O<B!T:&4@=&5X="X@(%EO=2!C86X@<W!E8VEF
M>2!T:&4@<&]R="X@(%1H92!P<F]T;V-O;"!I<R!B>0H@*B`@("`@("`@(&1E
M9F%U;'0@:'1T<"X*("H@("`@(%MU<FP]:'1T<#HO+W=W=RYH;W)D92YO<F==
M3&EN:R!T;R!(;W)D95LO=7)L72`M/B!,:6YK('1O('1H92!A9&1R97-S"B`J
M("`@("`@("`@=7-I;F<@(DQI;FL@=&\@2&]R9&4B(&9O<B!T:&4@=&5X="X@
M(%EO=2!C86X@<W!E8VEF>2!T:&4@<')O=&]C;VPZ"B`J("`@("`@("`@:'1T
M<"!O<B!H='1P<R!A;F0@=&AE('!O<G0N"B`J("`@("!;=7)L/7=W=RYH;W)D
M92YO<F==3&EN:R!T;R!(;W)D95LO=7)L72`M/B!,:6YK('1O('1H92!A9&1R
M97-S('5S:6YG"B`J("`@("`@("`@(DQI;FL@=&\@2&]R9&4B(&9O<B!T:&4@
M=&5X="X@(%EO=2!C86X@<W!E8VEF>2!T:&4@<&]R="X@(%1H90H@*B`@("`@
M("`@('!R;W1O8V]L(&ES(&)Y(&1E9F%U;'0@:'1T<`H@*B`@("`@6V5M86EL
M76-P961R:6YA8VE`>6%H;V\N97-;+V5M86EL72`M/B!S971S(&$@;6%I;'1O
M(&QI;FLN"B`J("`@("!;96UA:6P]8W!E9')I;F%C:4!Y86AO;RYE<UU-86EL
M('1O($-A<FQO<ULO96UA:6Q=("T^(%-E=',@82!M86EL=&\@;&EN:PH@*B`@
M("`@("`@(&%N9"!T:&4@=&5X="!I<R`B36%I;"!T;R!#87)L;W,B+@H@*B`\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V)B8V]D92YP:'`L=B`Q+C@N,3`N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C,X
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($-A<FQO<R!0
M961R:6YA8VD@/&-P961R:6YA8VE`>6%H;V\N97,^"B`J"B`J($5M86EL('9A
M;&ED871I;VX@8F%S960@;VX@0VAU8VL@2&%G96YB=6-H)W,*("H@36%I;%]2
M1D,X,C(Z.FES5F%L:61);F5T061D<F5S<RX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($-A<FQO<R!0961R:6YA8VD@/&-P961R:6YA8VE`>6%H;V\N
M97,^"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL
M=&5R7V)B8V]D92!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@
M("`J($9I;'1E<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH)V5N=&ET:65S
M)R`]/B!F86QS92D["@H@("`@+RHJ"B`@("`@*B!%>&5C=71E<R!A;GD@8V]D
M92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R
M;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E
M>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@>PH@("`@"6EF("@D=&AI<RT^
M7W!A<F%M<ULG96YT:71I97,G72D@>PH@("`@("`@("`@("`D=&5X="`]($!H
M=&UL<W!E8VEA;&-H87)S*"1T97AT*3L*("`@(`E]"@H@("`@("`@(')E='5R
M;B`D=&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H
M('=I=&@@<F5P;&%C92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710871T97)N<R@I"B`@("!["B`@("`))')E<&QA8V4@/2!A<G)A>2@*("`@
M(`D@("`@)UMI72<@/3X@)SQE;3XG+"`G6R]I72<@/3X@)SPO96T^)RP*("`@
M("`@("`@("`@)UMU72<@/3X@)SQU/B<L("=;+W5=)R`]/B`G/"]U/B<L"B`@
M("`@("`@("`@("=;8ETG(#T^("<\<W1R;VYG/B<L("=;+V)=)R`]/B`G/"]S
M=')O;F<^)RP*("`@("`@("`@("`@)UMC96YT97)=)R`]/B`G/&-E;G1E<CXG
M+"`G6R]C96YT97)=)R`]/B`G/"]C96YT97(^)RP*("`@("`@("`@("`@)UMQ
M=6]T95TG(#T^("<\8FQO8VMQ=6]T93XG+"`G6R]Q=6]T95TG(#T^("<\+V)L
M;V-K<75O=&4^)RP*("`@("`@("`@("`@)UML:7-T72<@/3X@)SQU;#XG+"`G
M6R]L:7-T72<@/3X@)SPO=6P^)RP*("`@("`@("`@("`@)UMN=6UL:7-T72<@
M/3X@)SQO;#XG+"`G6R]N=6UL:7-T72<@/3X@)SPO;VP^)RP*("`@("`@("`@
M("`@)ULJ72<@/3X@)SQL:3XG*3L*"B`@("`@("`@+RH@5VAE;B!C:&5C:VEN
M9R!54DQS('=E('9A;&ED871E('!A<G0@;V8@=&AE;2P@8G5T(&ET(&ES('5P
M"B`@("`@("`@("H@=&\@=&AE('5S97(@=&\@=W)I=&4@=&AE;2!C;W)R96-T
M;'D@*&EN('!A<G1I8W5L87(@=&AE"B`@("`@("`@("H@<75E<GD@<W1R:6YG
M*2X@0V]N8V5R;FEN9R!M86EL<R!W92!U<V4@=&AE(')E9W5L87(*("`@("`@
M("`@*B!E>'!R97-S:6]N(&EN($UA:6Q?4D9#.#(R)W,@:7-686QI9$EN971!
M9&1R97-S*"D@9G5N8W1I;VXL"B`@("`@("`@("H@<VQI9VAT;'D@;6]D:69I
M960N("HO"B`@("`@("`@)')E9V5X<"`](&%R<F%Y*`H@("`@("`@("`@("`B
M(UQ;=7)L7%TH*&AT='!\:'1T<',I.B\O*%MA+7I!+5I<9%U;7'<M72HI*%PN
M6V$M>D$M6EQD75M<=RU=*BDK*#HH7&0K*2D_*"\H6UX\/ETK*2DJ*5Q;+W5R
M;%Q=(U4B(#T^"B`@("`@("`@("`@($AO<F1E.CIL:6YK*"(D,2(L("(D,2(I
M("X@(B0Q/"]A/B(L"@H@("`@("`@("`@("`B(UQ;=7)L7#TH*&AT='!\:'1T
M<',I.B\O*%MA+7I!+5I<9%U;7'<M72HI*%PN6V$M>D$M6EQD75M<=RU=*BDK
M*#HH7&0K*2D_*"\H6UX\/ETK*2DJ*5Q=*%M>/#Y=*RE<6R]U<FQ<72-5(B`]
M/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B)#$B+"`B)#$B*2`N("(D.3PO
M83XB+`H*("`@("`@("`@("`@(B-<6W5R;%Q=*"A;82UZ02U:7&1=6UQW+5TJ
M*2A<+EMA+7I!+5I<9%U;7'<M72HI*R@Z*%QD*RDI/R@O*%M>/#Y=*RDI*BE<
M6R]U<FQ<72-5(B`]/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B:'1T<#HO
M+R0Q(BP@(FAT='`Z+R\D,2(I("X@(B0Q/"]A/B(L"@H@("`@("`@("`@("`B
M(UQ;=7)L7#TH*%MA+7I!+5I<9%U;7'<M72HI*%PN6V$M>D$M6EQD75M<=RU=
M*BDK*#HH7&0K*2D_*"\H6UX\/ETK*2DJ*5Q=*%M>/#Y=*RE<6R]U<FQ<72-5
M(B`]/@H@("`@("`@("`@("!(;W)D93HZ;&EN:R@B:'1T<#HO+R0Q(BP@(FAT
M='`Z+R\D,2(I("X@(B0X/"]A/B(L"@H@("`@("`@("`@("`B(UQ;96UA:6Q<
M72@H6RHK(2XF7",D?%PG7%PE7"\P+3EA+7I!+5I>7V![?3T_?CHM72LI0"@H
M6S`M.6$M>D$M6BU=*UPN*2M;,"TY82UZ02U:77LR+#1]*2E<6R]E;6%I;%Q=
M(U4B(#T^"B`@("`@("`@("`@($AO<F1E.CIL:6YK*")M86EL=&\Z)#$B+"`B
M;6%I;'1O.B0Q(BD@+B`B)#$\+V$^(BP*"B`@("`@("`@("`@("(C7%ME;6%I
M;%P]*"A;*BLA+B9<(R1\7"=<7"5<+S`M.6$M>D$M6EY?8'M]/3]^.BU=*RE`
M*"A;,"TY82UZ02U:+5TK7"XI*ULP+3EA+7I!+5I=>S(L-'TI*5Q=*%M>/#Y=
M*RE<6R]E;6%I;%Q=(U4B(#T^"B`@("`@("`@("`@($AO<F1E.CIL:6YK*")M
M86EL=&\Z)#$B+"`B;6%I;'1O.B0Q(BD@+B`B)#4\+V$^(@H@("`@("`@("D[
M"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5P;&%C92<@/3X@)')E<&QA8V4L
M("=R96=E>'`G(#T^("1R96=E>'`I.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O5&5X="]&:6QT97(O;&EN:W5R;',N
M<&AP````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4R,38@,3`U,34T,S0Q
M,S<@,#(T,#<V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@5&5X=%]&:6QT97)?;&EN:W5R;',Z
M.B!C;&%S<R!T=7)N<R!A;&P@55),<R!I;B!T:&4@=&5X="!I;G1O(&AY<&5R
M;&EN:W,N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J('1A<F=E="`@
M("TM(%1H92!L:6YK('1A<F=E="X@($1E9F%U;'1S('1O(%]B;&%N:RX*("H@
M8VQA<W,@("`@+2T@5&AE($-34R!C;&%S<R!O9B!T:&4@9V5N97)A=&5D(&QI
M;FMS+B`@1&5F875L=',@=&\@;F]N92X*("H@;F]F;VQL;W<@+2T@5VAE=&AE
M<B!T;R!S970@=&AE("=R96P](FYO9F]L;&]W(B<@871T<FEB=71E(&]N(&QI
M;FMS+@H@*B!C87!I=&%L("`M+2!G96YE<F%T92!U<'!E<F-A<V4@/$$^('1A
M9W,@<V\@>6]U(&-A;B!K;F]W('=H:6-H('1A9W,@>6]U(&IU<W0*("H@("`@
M("`@("`@("`@9V5N97)A=&5D+B`@1&5F875L=',@=&\@9F%L<V4N"B`J(&-A
M;&QB86-K("TM($%N(&]P=&EO;F%L(&-A;&QB86-K(&9U;F-T:6]N('1H870@
M=&AE(%523"!I<R!P87-S960@=&AR;W5G:`H@*B`@("`@("`@("`@("!B969O
M<F4@8F5I;F<@<V5T(&%S('1H92!H<F5F(&%T=')I8G5T92X@($UU<W0@8F4@
M82!S=')I;F<@=VET:`H@*B`@("`@("`@("`@("!T:&4@9G5N8W1I;VX@;F%M
M92P@=&AE(&9U;F-T:6]N(&UU<W0@=&%K92!T:&4@;W)I9VEN86P@87,@=&AE
M"B`J("`@("`@("`@("`@(&9I<G-T(&%N9"!O;FQY('!A<F%M971E<BX*("H@
M/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I
M;'1E<B]L:6YK=7)L<RYP:'`L=B`Q+C$Q+C$P+C4@,C`P-B\P,2\P,2`R,3HR
M.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!4>6QE
M<B!#;VQB97)T(#QT>6QE<BUH;W)D96UL0&-O;&)E<G1S+G5S/@H@*B!#;W!Y
M<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!4>6QE<B!#;VQB97)T(#QT
M>6QE<BUH;W)D96UL0&-O;&)E<G1S+G5S/@H@*B!`875T:&]R("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]497AT
M"B`J+PIC;&%S<R!497AT7T9I;'1E<E]L:6YK=7)L<R!E>'1E;F1S(%1E>'1?
M1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E<B!P87)A;65T97)S+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R
M86US(#T@87)R87DH)W1A<F=E="<@/3X@)U]B;&%N:R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G8VQA<W,G(#T^("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)VYO9F]L;&]W)R`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("=C87!I=&%L)R`]/B!F86QS92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("=C86QL8F%C:R<@/3X@;G5L;"D["@H@("`@+RHJ"B`@("`@
M*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG
M('1H92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG8V%P:71A;"==*2!["B`@
M("`@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H87)R87DH)SPO03XG+"`G
M/$$G*2P@87)R87DH)SPO83XG+"`G/&$G*2P@)'1E>'0I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!A(&AA<V@@=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D82`]
M("1T:&ES+3Y?<&%R86US6R=C87!I=&%L)UT@/R`G02<@.B`G82<["@H@("`@
M("`@("1C;&%S<R`]("1T:&ES+3Y?<&%R86US6R=C;&%S<R==.PH@("`@("`@
M(&EF("@A96UP='DH)&-L87-S*2D@>PH@("`@("`@("`@("`D8VQA<W,@/2`G
M(&-L87-S/2(G("X@)&-L87-S("X@)R(G.PH@("`@("`@('T*("`@("`@("`D
M;F]F;VQL;W<@/2`D=&AI<RT^7W!A<F%M<ULG;F]F;VQL;W<G72`_("<@<F5L
M/2)N;V9O;&QO=R(G(#H@)R<["@H@("`@("`@("1U<FP@/2`D=&AI<RT^7W!A
M<F%M<ULG8V%L;&)A8VLG72`_("=<)R`N("<@+B`D=&AI<RT^7W!A<F%M<ULG
M8V%L;&)A8VLG72`N("<H7"<D,%PG*2`N(%PG)R`Z("<D,"<["@H@("`@("`@
M("1R96=E>'`@/2!A<G)A>2@G?"A<=RLI.B\O*%M>7',B/%TJ6UQW*R,_+R8]
M72E\92<@/3X*("`@("`@("`@("`@("`@("`@("`@("`@)UPG/"<@+B`D82`N
M("<@:')E9CTB)R`N("1U<FP@+B`G(B<@+B`D;F]F;VQL;W<@+B`G('1A<F=E
M=#TB7V)L86YK(B<@+B`D8VQA<W,@+B`G/B0P/"\G("X@)&$@+B`G/EPG)RD[
M"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]497AT+T9I;'1E<B]E;6%I;',N<&AP````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,#0P,"`Q,#4Q-30S-#$S-R`P,C,T-S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!497AT7T9I;'1E<E]E;6%I;',Z.B!C;&%S<R!F:6YD<R!E;6%I
M;"!A9&1R97-S97,@:6X@82!B;&]C:R!O9B!T97AT(&%N9`H@*B!T=7)N<R!T
M:&5M(&EN=&\@;&EN:W,N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J
M(&%L=V%Y<U]M86EL=&\@+2T@268@=')U92P@82!M86EL=&\Z(&QI;FL@:7,@
M9V5N97)A=&5D(&%L=V%Y<RX@($]N;'D@:68@;F\*("H@("`@("`@("`@("`@
M("`@("!M86EL+V-O;7!O<V4@<F5G:7-T<GD@05!)(&UE=&AO9"!E>&ES=',@
M;W1H97)W:7-E+@H@*B!C;&%S<R`@("`@("`@("TM($-34R!C;&%S<R!O9B!T
M:&4@9V5N97)A=&5D(#QA/B!T86<N("!$969A=6QT<R!T;R!N;VYE+@H@*B`\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]&:6QT97(O1FEL
M=&5R+V5M86EL<RYP:'`L=B`Q+C$U+C$P+C@@,C`P-B\P,B\Q-R`R,#HP-3HT
M.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V(%1Y;&5R
M($-O;&)E<G0@/'1Y;&5R+6AO<F1E;6Q`8V]L8F5R=',N=7,^"B`J($-O<'ER
M:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@5'EL97(@0V]L8F5R="`\='EL
M97(M:&]R9&5M;$!C;VQB97)T<RYU<SX*("H@0&%U=&AO<B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J
M+PIC;&%S<R!497AT7T9I;'1E<E]E;6%I;',@97AT96YD<R!497AT7T9I;'1E
M<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`]
M(&%R<F%Y*"=A;'=A>7-?;6%I;'1O)R`]/B!F86QS92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("=C;&%S<R<@/3X@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G8V%P:71A;%]T86=S)R`]/B!F86QS92D["@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA8V4@<&%T=&5R;G,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T=&5R;G,@:&%S:"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1C;&%S<R`](&5M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=C;&%S<R==*2`_("<G(#H@)R!C;&%S<STB)R`N("1T
M:&ES+3Y?<&%R86US6R=C;&%S<R==("X@)R(G.PH@("`@("`@("1T86<@/2`D
M=&AI<RT^7W!A<F%M<ULG8V%P:71A;%]T86=S)UT@/R`G02<@.B`G82<["@H@
M("`@("`@("1R96=E>'`@/2`\/#Q%3U(*("`@("`@("`@("`@+PH@("`@("`@
M("`@("`C(%9E<G-I;VX@,3H@;6%I;'1O.B!L:6YK<R!W:71H(&%N>2!V86QI
M9"!E;6%I;"!C:&%R86-T97)S+@H@("`@("`@("`@("`C(%!A='1E<FX@,3H@
M3W5T;&]O:R!P87)E;G1H97-I>F5S(&EN('-Q87)E(&)R86-K971S"B`@("`@
M("`@("`@("A<6UQS*BD_"B`@("`@("`@("`@(",@4&%T=&5R;B`R.B!M86EL
M=&\Z('!R;W1O8V]L('!R969I>`H@("`@("`@("`@("`H;6%I;'1O.EQS/RD*
M("`@("`@("`@("`@(R!0871T97)N(#,Z(&5M86EL(&%D9')E<W,*("`@("`@
M("`@("`@*%M>7'-</R(\72HI"B`@("`@("`@("`@(",@4&%T=&5R;B`T('1O
M(#8Z($]P=&EO;F%L('!A<F%M971E<G,*("`@("`@("`@("`@*"A</RDH6UY<
M<R(\72I;7'<K(S]<+R8]72DI/PH@("`@("`@("`@("`C(%!A='1E<FX@-SH@
M0VQO<VEN9R!/=71L;V]K('-Q=6%R92!B<F%C:V5T"B`@("`@("`@("`@("@H
M/R@Q*5QS*EQ=*2D*"B`@("`@("`@("`@('P*("`@("`@("`@("`@(R!697)S
M:6]N(#(@4&%T=&5R;B`X.B!S:6UP;&4@96UA:6P@861D<F5S<V5S+@H@("`@
M("`@("`@("`H7&);7'<M*RX]72M`6RU!+5HP+3DN72I;02U:,"TY72D*("`@
M("`@("`@("`@(R!0871T97)N(#D@=&\@,3$Z($]P=&EO;F%L('!A<F%M971E
M<G,*("`@("`@("`@("`@*"A</RDH6UY<<R(\72I;7'<K(S]<+R8]72DI/PH*
M("`@("`@("`@("`@+V5I>`I%3U(["@H@("`@("`@(&EF("AI<U]A*"1R96=I
M<W1R>2P@)U)E9VES=')Y)RD@)B8*("`@("`@("`@("`@)')E9VES=')Y+3YH
M87--971H;V0H)VUA:6PO8V]M<&]S92<I("8F"B`@("`@("`@("`@("$D=&AI
M<RT^7W!A<F%M<ULG86QW87ES7VUA:6QT;R==*2!["B`@("`@("`@("`@("\J
M($EF('=E(&AA=F4@82!M86EL+V-O;7!O<V4@<F5G:7-T<GD@;65T:&]D+"!U
M<V4@:70N("HO"B`@("`@("`@("`@("1R97!L86-E;65N="`]("=497AT7T9I
M;'1E<E]E;6%I;',Z.F-A;&QB86-K*%PG)R`N("1T86<@+@H@("`@("`@("`@
M("`@("`@)UPG+"!<)R<@+B`D8VQA<W,@+B`G7"<L(%PG)#%<)RP@7"<D,EPG
M+"!<)R0S7"<L(%PG)#1<)RP@7"<D-EPG+"!<)R0W7"<L(%PG)#A<)RP@7"<D
M.5PG+"!<)R0Q,5PG*2<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M+RH@3W1H97)W:7-E+"!G96YE<F%T92!A('-T86YD87)D(&UA:6QT;SH@86YD
M(&QE="!T:&4*("`@("`@("`@("`@("H@8G)O=W-E<B!H86YD;&4@:70N("HO
M"B`@("`@("`@("`@("1R97!L86-E;65N="`](#P\/$5/4`H@("`@("`@("`@
M("`@("`@)R0X)R`]/3T@)R<@/PH*("`@("`@("`@("`@("`@("<D,20R/"1T
M86<D8VQA<W,@:')E9CTB;6%I;'1O.B0S)#0B('1I=&QE/2(G("X@<W!R:6YT
M9BA?*").97<@365S<V%G92!T;R`E<R(I+"!H=&UL<W!E8VEA;&-H87)S*"<D
M,R<I*2`N"B`@("`@("`@("`@("`@("`G(CXD,R0T/"\D=&%G/B0W)R`Z"@H@
M("`@("`@("`@("`@("`@)SPD=&%G)&-L87-S(&AR968](FUA:6QT;SHD."0Y
M(B!T:71L93TB)R`N('-P<FEN=&8H7R@B3F5W($UE<W-A9V4@=&\@)7,B*2P@
M:'1M;'-P96-I86QC:&%R<R@G)#@G*2D@+@H@("`@("`@("`@("`@("`@)R(^
M)#@D.3PO)'1A9SXG"D5/4#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A
M<G)A>2@G<F5G97AP)R`]/B!A<G)A>2@D<F5G97AP(#T^("1R97!L86-E;65N
M="DI.PH@("`@?0H*("`@(&9U;F-T:6]N(&-A;&QB86-K*"1T86<L("1C;&%S
M<RP@)&)R86-K970Q+"`D<')O=&]C;VPL("1E;6%I;"P@)&%R9W-?;&]N9RP*
M("`@("`@("`@("`@("`@("`@("`@("1A<F=S+"`D8G)A8VME=#(L("1E;6%I
M;#(L("1A<F=S7VQO;F<R+"`D87)G<S(I"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D96UA:6PR*2D@>PH@("`@("`@("`@("`D87)G<R`]("1A<F=S,CL*
M("`@("`@("`@("`@)&5M86EL(#T@)&5M86EL,CL*("`@("`@("`@("`@)&%R
M9W-?;&]N9R`]("1A<F=S7VQO;F<R.PH@("`@("`@('T*("`@("`@("`D97AT
M<F$@/2!C86QL7W5S97)?9G5N8RAC<F5A=&5?9G5N8W1I;VXH)R1A)RP@)R1P
M/6%R<F%Y*"D[9F]R96%C:"@D82!A<R`D8BE[)&(]97AP;&]D92@B/2(L)&(L
M,BD[)'!;)&);,%U=/4`D8ELQ73M]<F5T=7)N("1P.R<I+"!E>'!L;V1E*"<F
M)RP@)&%R9W,I*3L*("`@("`@("`D=7)L(#T@)$=,3T)!3%-;)W)E9VES=')Y
M)UTM/F-A;&PH)VUA:6PO8V]M<&]S92<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*&%R<F%Y*"=T;R<@/3X@)&5M
M86EL*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X=')A*2D["B`@("`@("`@)'5R;"`]('-T<E]R97!L86-E*"<F86UP
M.R<L("<F)RP@)'5R;"D["B`@("`@("`@:68@*'-U8G-T<B@D=7)L+"`P+"`Q
M,2D@/3T@)VIA=F%S8W)I<'0Z)RD@>PH@("`@("`@("`@("`D:')E9B`]("<C
M)SL*("`@("`@("`@("`@)&]N8VQI8VL@/2`G(&]N8VQI8VL](B<@+B!S=6)S
M='(H)'5R;"P@,3$I("X@)R(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1H<F5F(#T@)'5R;#L*("`@("`@("`@("`@)&]N8VQI8VL@/2`G)SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8G)A8VME=#$@+B`D<')O=&]C
M;VP@+B`G/"<@+B`D=&%G("X@)&-L87-S("X@)R!H<F5F/2(G("X*("`@("`@
M("`@("`@)&AR968@+B`G(B!T:71L93TB)R`N('-P<FEN=&8H7R@B3F5W($UE
M<W-A9V4@=&\@)7,B*2P@:'1M;'-P96-I86QC:&%R<R@D96UA:6PI*2`N("<B
M)R`N"B`@("`@("`@("`@("1O;F-L:6-K("X@)SXG("X@:'1M;'-P96-I86QC
M:&%R<R@D96UA:6PI("X@)&%R9W-?;&]N9R`N("<\+R<@+B`D=&%G("X@)SXG
M("X@)&)R86-K970R.PH@("`@?0H*?0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U1E
M>'0O1FEL=&5R+V5N=FER;VYM96YT+G!H<```````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`Q-S`W(#$P-3$U-#,T,3,W(#`R-#8P,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@4F5P;&%C
M97,@;V-C=7)E;F-E<R!O9B`E5D%2)2!W:71H(%9!4BP@:68@5D%2(&5X:7-T
M<R!I;B!T:&4@=V5B<V5R=F5R)W,*("H@96YV:7)O;FUE;G0N("!)9VYO<F5S
M(&%L;"!T97AT(&%F=&5R(&$@)R,G(&-H87)A8W1E<B`H<VAE;&PM<W1Y;&4*
M("H@8V]M;65N=',I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I
M;'1E<B]&:6QT97(O96YV:7)O;FUE;G0N<&AP+'8@,2XS+C$P+C0@,C`P-B\P
M,2\P,2`R,3HR.#HS."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U1E
M>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7V5N=FER;VYM96YT(&5X=&5N9',@
M5&5X=%]&:6QT97(@>PH*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&AA<V@@
M=VET:"!R97!L86-E('!A='1E<FYS+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@(%!A='1E<FYS(&AA<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A='1E<FYS*"D*("`@('L*("`@("`@("`D<F5G97AP(#T@87)R87DH)R]>
M(RXJ)%QN+VTG(#T^("<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G+UXH
M6UXC72HI(RXJ)"]M)R`]/B`G)#$G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G+R4H6T$M6F$M>E]=*RDE+V4G(#T^("=G971E;G8H(B0Q(BDG*3L*("`@
M("`@("!R971U<FX@87)R87DH)W)E9V5X<"<@/3X@)')E9V5X<"D["B`@("!]
M"@I]````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+U1E>'0O1FEL=&5R+VAT;6PR=&5X="YP:'``````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$V,3,P(#$P-3$U-#,T,3,W(#`R-#$V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*<F5Q=6ER
M95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*"B\J*@H@*B!486ME<R!(5$U,
M(&%N9"!C;VYV97)T<R!I="!T;R!F;W)M871T960L('!L86EN('1E>'0N"B`J
M"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^"B`J(&-H87)S970@+2T@5&AE(&-H
M87)S970@=&\@=7-E(&9O<B!H=&UL7V5N=&ET>5]D96-O9&4H*2!C86QL<RX*
M("H@=VED=&@@("`M+2!4:&4@=W)A<'!I;F<@=VED=&@N"B`J('=R87`@("`@
M+2T@5VAE=&AE<B!T;R!W<F%P('1H92!T97AT(&]R(&YO="X*("H@/"]P<F4^
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E<B]H
M=&UL,G1E>'0N<&AP+'8@,2XT+C$P+C$R(#(P,#8O,#$O,#$@,C$Z,C@Z,S@@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@2F]N($%B97)N
M871H>2`\:F]N0&-H=6=G;G5T="YC;VT^"B`J($]R:6=I;F%L('-O=7)C93H@
M:'1T<#HO+W=W=RYC:'5G9VYU='0N8V]M+VAT;6PR=&5X="YP:'`*("H@0V]P
M>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60*("H@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N($%B97)N871H>2`\
M:F]N0&-H=6=G;G5T="YC;VT^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!(;W)D95]497AT"B`J+PIC;&%S<R!497AT7T9I;'1E<E]H=&UL,G1E
M>'0@97AT96YD<R!497AT7T9I;'1E<B!["@H@("`@+RHJ"B`@("`@*B!&:6QT
M97(@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"=C:&%R<V5T)R`]/B!N=6QL
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)W=I9'1H)R`]/B`W,"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("=W<F%P)R`]/B!T<G5E*3L*"B`@("`O
M*BH*("`@("`J($5X96-U=&5S(&%N>2!C;V1E(&YE8V5S<V%R87D@8F5F;W)E
M(&%P<&QY:6YG('1H92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H92!F:6QT
M97)I;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I
M9FEE9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C97-S*"1T
M97AT*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7VAT;6PR=&5X=%]S=&%T93L*
M"B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]P87)A;7-;)V-H87)S970G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V-H87)S970G72`]
M(&ES<V5T*"1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72D@/R`D
M1TQ/0D%,4ULG7TA/4D1%7U-44DE.1U]#2$%24T54)UT@.B`G25-/+3@X-3DM
M,2<["B`@("`@("`@?0H*("`@("`@("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN
M:TQI<W0G72`]("<G.PH@("`@("`@("1?:'1M;#)T97AT7W-T871E6R=L:6YK
M0V]U;G0G72`](#`["@H@("`@("`@(')E='5R;B!T<FEM*"1T97AT*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@<F5P;&%C
M92!P871T97)N<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0871T
M97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710871T97)N<R@I
M"B`@("!["B`@("`@("`@)')E9V5X<"`](&%R<F%Y*`H@("`@("`@("`@("`O
M+R!.;VXM;&5G86P@8V%R<FEA9V4@<F5T=7)N+@H@("`@("`@("`@("`G+UQR
M+R<@/3X@)R<L"@H@("`@("`@("`@("`O+R!,96%D:6YG(&%N9"!T<F%I;&EN
M9R!W:&ET97-P86-E+@H@("`@("`@("`@("`G+UY<<RHH+BH_*5QS*B0O;2<@
M/3X@)UPQ)RP*"B`@("`@("`@("`@("\O($YO<FUA;&EZ92`\8G(^+@H@("`@
M("`@("`@("`G+SQB<EM>/ETJ/BA;7EQN72DO:2<@/3X@(CQB<CY<;EQ<,2(L
M"@H@("`@("`@("`@("`O+R!.97=L:6YE<R!A;F0@=&%B<RX*("`@("`@("`@
M("`@)R];7&Y<=%TK+R<@/3X@)R`G+`H*("`@("`@("`@("`@+R\@/'-C<FEP
M=#YS("TM('=H:6-H('-T<FEP7W1A9W,H*2!S=7!P;W-E9&QY(&AA<R!P<F]B
M;&5M<R!W:71H+@H@("`@("`@("`@("`G+SQS8W)I<'1;7CY=*CXN*C\\7"]S
M8W)I<'0^+VDG(#T^("<G+`H*("`@("`@("`@("`@+R\@/'-T>6QE/G,@+2T@
M=VAI8V@@<W1R:7!?=&%G<R@I('-U<'!O<V5D;'D@:&%S('!R;V)L96US('=I
M=&@N"B`@("`@("`@("`@("<O/'-T>6QE6UX^72H^+BH_/%PO<W1Y;&4^+VDG
M(#T^("<G+`H*("`@("`@("`@("`@+R\@0V]M;65N=',@+2T@=VAI8V@@<W1R
M:7!?=&%G<R@I(&UI9VAT(&AA=F4@82!P<F]B;&5M('=I=&@N"B`@("`@("`@
M("`@("\O("\O)R\\(2TM("XJ("TM/B\G(#T^("<G+`H*("`@("`@("`@("`@
M+R\@:#$@+2!H,PH@("`@("`@("`@("`G+SQH6S$R,UU;7CY=*CXH+BL_*3Q<
M+VA;,3(S73X@/R]I92<@/3X@)W-T<G1O=7!P97(H(EQN7&XB("X@7"=<,5PG
M("X@(EQN7&XB*2<L"@H@("`@("`@("`@("`O+R!H-"`M(&@V"B`@("`@("`@
M("`@("<O/&A;-#4V75M>/ETJ/B@N*S\I/%PO:%LT-39=/B`_+VEE)R`]/B`G
M=6-W;W)D<R@B7&Y<;B(@+B!<)UPQ7"<@+B`B7&Y<;B(I)RP*"B`@("`@("`@
M("`@("\O(#QP/@H@("`@("`@("`@("`G+SQP6UX^72H^(#\O:2<@/3X@(EQN
M7&X@("(L"@H@("`@("`@("`@("`O+R`\8G(^"B`@("`@("`@("`@("<O/&)R
M6UX^72H^(#\O:2<@/3X@(EQN(BP*"B`@("`@("`@("`@("\O(#QB/@H@("`@
M("`@("`@("`G+SQB6UX^72H^*"XK/RD\7"]B/B]I92<@/3X@)W-T<G1O=7!P
M97(H7"=<,5PG*2<L"@H@("`@("`@("`@("`O+R`\<W1R;VYG/@H@("`@("`@
M("`@("`G+SQS=')O;F=;7CY=*CXH+BL_*3Q<+W-T<F]N9SXO:64G(#T^("=S
M=')T;W5P<&5R*%PG7#%<)RDG+`H@("`@("`@("`@("`G+SQS<&%N7%QS*W-T
M>6QE/2)F;VYT+7=E:6=H=#I<7',J8F]L9"XJ(CXH+BL_*3Q<+W-P86X^+VEE
M)R`]/B`G<W1R=&]U<'!E<BA<)UPQ7"<I)RP*"B`@("`@("`@("`@("\O(#QI
M/@H@("`@("`@("`@("`G+SQI6UX^72H^*"XK/RD\7"]I/B]I)R`]/B`G+UQ<
M,2\G+`H*("`@("`@("`@("`@+R\@/&5M/@H@("`@("`@("`@("`G+SQE;5M>
M/ETJ/B@N*S\I/%PO96T^+VDG(#T^("<O7%PQ+R<L"@H@("`@("`@("`@("`O
M+R`\=3X*("`@("`@("`@("`@)R\\=5M>/ETJ/B@N*S\I/%PO=3XO:2<@/3X@
M)U]<7#%?)RP*"B`@("`@("`@("`@("\O(#QU;#XO/&]L/B!A;F0@/"]U;#XO
M/"]O;#X*("`@("`@("`@("`@)R\H/"AU?&\I;%M>/ETJ/GP@/SQ<+RAU?&\I
M;#XI(#\O:2<@/3X@(EQN7&XB+`H*("`@("`@("`@("`@+R\@/&QI/@H@("`@
M("`@("`@("`G+R`_/&QI6UX^72H^+VDG(#T^(")<;B`@*B`B+`H*("`@("`@
M("`@("`@+R\@/&$@:')E9CTB(CX*("`@("`@("`@("`@)R\\82!H<F5F/2(H
M6UXB72LI(EM>/ETJ/B@N*S\I/%PO83XO:64G(#T^("=497AT7T9I;'1E<E]H
M=&UL,G1E>'0Z.E]B=6EL9$QI;FM,:7-T*"1'3$]"04Q36R)?:'1M;#)T97AT
M7W-T871E(EU;(FQI;FM#;W5N=")=+"!<)UPQ7"<L(%PG7#)<)RDG+`H*("`@
M("`@("`@("`@+R\@/&AR/@H@("`@("`@("`@("`G+SQH<EM>/ETJ/B`_+VDG
M(#T^(")<;BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(L"@H@("`@("`@
M("`@("`O+R`\=&%B;&4^(&%N9"`\+W1A8FQE/@H@("`@("`@("`@("`G+R@\
M=&%B;&5;7CY=*CY\(#\\7"]T86)L93XI(#\O:2<@/3X@(EQN7&XB+`H*("`@
M("`@("`@("`@+R\@/'1R/@H@("`@("`@("`@("`G+R`_/'1R6UX^72H^(#\O
M:2<@/3X@(EQN7'0B+`H*("`@("`@("`@("`@+R\@/'1D/B!A;F0@/"]T9#X*
M("`@("`@("`@("`@)R\@/SQT9%M>/ETJ/B@N*S\I/%PO=&0^(#\O:2<@/3X@
M)UPQ)R`N(")<=%QT(BP*("`@("`@("`@("`@)R]<=%QT/%PO='(^+VDG(#T^
M("<G+`H*("`@("`@("`@("`@+R\@96YT:71I97,*("`@("`@("`@("`@)R\F
M;F)S<#LO:2<@/3X@)R`G+`H@("`@("`@("`@("`G+R9T<F%D93LO:2<@/3X@
M)RAT;2DG+`H@("`@("`@("`@("`G+R8C*%QD*RD[+V4G(#T^("=3=')I;F<Z
M.F-O;G9E<G1#:&%R<V5T*%1E>'1?1FEL=&5R7VAT;6PR=&5X=#HZ7VEN=#)U
M=&8X*%PG7#%<)RDL(")55$8M."(L("(G("X@)'1H:7,M/E]P87)A;7-;)V-H
M87)S970G72`N("<B*2<L"@H@("`@("`@("`@("`O+R!3;VUE(&UA:6QE<G,@
M*&4N9RX@2&]T;6%I;"D@=7-E('1H92!F;VQL;W=I;F<@9&EV('1A9R!A<R!A
M('=A>0H@("`@("`@("`@("`O+R!T;R!D969I;F4@82!B;&]C:R!O9B!T97AT
M+@H@("`@("`@("`@("`G+SQD:78@8VQA<W,]<G1E/B@N*S\I/%PO9&EV/B`_
M+VDG(#T^("=<,2<@+B`B7&XB"B`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"=R96=E>'`G(#T^("1R96=E>'`I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)A>2!A9G1E<B!A<'!L
M>6EN9R!T:&4@9FEL=&5R"B`@("`@*B!P871T97)N<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!A9G1E<B!T:&4@9FEL
M=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<&]S=%!R;V-E<W,H
M)'1E>'0I"B`@("!["B`@("`@("`@9VQO8F%L("1?:'1M;#)T97AT7W-T871E
M.PH*("`@("`@("`O*B!3=')I<"!A;GD@;W1H97(@2%1-3"!T86=S+B`J+PH@
M("`@("`@("1T97AT(#T@<W1R:7!?=&%G<R@D=&5X="D["@H@("`@("`@("\J
M($-O;G9E<G0@:'1M;"!E;G1I=&EE<RX@*B\*("`@("`@("`D=&5X="`]($!H
M=&UL7V5N=&ET>5]D96-O9&4H)'1E>'0L($5.5%]154]415,L("1T:&ES+3Y?
M<&%R86US6R=C:&%R<V5T)UTI.PH*("`@("`@("`O*B!"<FEN9R!D;W=N(&YU
M;6)E<B!O9B!E;7!T>2!L:6YE<R!T;R`R(&UA>"X@*B\*("`@("`@("`D=&5X
M="`]('!R96=?<F5P;&%C92@B+UQN6ULZ<W!A8V4Z75TK7&XO(BP@(EQN7&XB
M+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H(B];7&Y=
M>S,L?2\B+"`B7&Y<;B(L("1T97AT*3L*"B`@("`@("`@+RH@5W)A<"!T:&4@
M=&5X="!T;R!A(')E861A8FQE(&9O<FUA="X@*B\*("`@("`@("!I9B`H)'1H
M:7,M/E]P87)A;7-;)W=R87`G72D@>PH@("`@("`@("`@("`D=&5X="`]('=O
M<F1W<F%P*"1T97AT+"`D=&AI<RT^7W!A<F%M<ULG=VED=&@G72D["B`@("`@
M("`@?0H*("`@("`@("`O*B!!9&0@;&EN:R!L:7-T+B`J+PH@("`@("`@(&EF
M("@A96UP='DH)%]H=&UL,G1E>'1?<W1A=&5;)VQI;FM,:7-T)UTI*2!["B`@
M("`@("`@("`@("1T97AT("X](")<;EQN(B`N(%\H(DQI;FMS(BD@+B`B.EQN
M(B`N('-T<E]R97!E870H)RTG+"!3=')I;F<Z.FQE;F=T:"A?*"),:6YK<R(I
M*2`K(#$I("X@(EQN(B`N("1?:'1M;#)T97AT7W-T871E6R=L:6YK3&ES="==
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@551&+3@@8VAA<F%C=&5R('-E<75E
M;F-E(&]F(&$@56YI8V]D92!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D;G5M("!!(%5N:6-O9&4@=F%L=64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!55$8M."!S=')I;F<N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]I;G0R=71F."@D;G5M*0H@("`@>PH@("`@("`@(&EF("@D
M;G5M(#P@,3(X*2!["B`@("`@("`@("`@(')E='5R;B!C:'(H)&YU;2D["B`@
M("`@("`@?0H@("`@("`@(&EF("@D;G5M(#P@,C`T."D@>PH@("`@("`@("`@
M("!R971U<FX@8VAR*"@D;G5M(#X^(#8I("L@,3DR*2`N(&-H<B@H)&YU;2`F
M(#8S*2`K(#$R."D["B`@("`@("`@?0H@("`@("`@(&EF("@D;G5M(#P@-C4U
M,S8I('L*("`@("`@("`@("`@<F5T=7)N(&-H<B@H)&YU;2`^/B`Q,BD@*R`R
M,C0I("X@8VAR*"@H)&YU;2`^/B`V*2`F(#8S*2`K(#$R."D@+@H@("`@("`@
M("`@("`@("`@8VAR*"@D;G5M("8@-C,I("L@,3(X*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"1N=6T@/"`R,#DW,34R*2!["B`@("`@("`@("`@(')E='5R
M;B!C:'(H*"1N=6T@/CX@,3@I("L@,C0P*2`N(&-H<B@H*"1N=6T@/CX@,3(I
M("8@-C,I("L@,3(X*2`N"B`@("`@("`@("`@("`@("!C:'(H*"@D;G5M(#X^
M(#8I("8@-C,I("L@,3(X*2`N(&-H<B@H)&YU;2`F(#8S*2`K(#$R."D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($AE;'!E<B!F=6YC=&EO;B!C86QL960@8GD@<')E9U]R97!L86-E*"D@
M;VX@;&EN:R!R97!L86-E;65N="X*("`@("`J"B`@("`@*B!-86EN=&%I;G,@
M86X@:6YT97)N86P@;&ES="!O9B!L:6YK<R!T;R!B92!D:7-P;&%Y960@870@
M=&AE(&5N9`H@("`@("H@;V8@=&AE('1E>'0L('=I=&@@;G5M97)I8R!I;F1I
M8V5S('1O('1H92!O<FEG:6YA;"!P;VEN="!I;B!T:&4*("`@("`J('1E>'0@
M=&AE>2!A<'!E87)E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EN:U]C;W5N="`@0V]U
M;G1E<B!T<F%C:VEN9R!C=7)R96YT(&QI;FL@;G5M8F5R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)&QI;FL@("`@("`@(%523"!O9B!T:&4@;&EN:RX*("`@
M("`J($!P87)A;2!S=')I;F<@("1D:7-P;&%Y("`@("!087)T(&]F('1H92!T
M97AT('1O(&%S<V]C:6%T92!N=6UB97(@=VET:"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&QI;FL@<F5P;&%C96UE;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]B=6EL9$QI;FM,:7-T*"1L:6YK7V-O=6YT+"`D;&EN
M:RP@)&1I<W!L87DI"B`@("!["B`@("`@("`@9VQO8F%L("1?:'1M;#)T97AT
M7W-T871E.PH*("`@("`@("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:T-O=6YT
M)UTK*SL*("`@("`@("`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:TQI<W0G72`N
M/2`G6R<@+B`D7VAT;6PR=&5X=%]S=&%T95LG;&EN:T-O=6YT)UT@+B`B72`D
M;&EN:UQN(CL*("`@("`@("!R971U<FX@)&1I<W!L87D@+B`G6R<@+B`D7VAT
M;6PR=&5X=%]S=&%T95LG;&EN:T-O=6YT)UT@+B`G72<["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O5&5X="]&:6QT97(O96UO=&EC;VYS+G!H<```````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,3`T-S8@,3`U,34T,S0Q,S<@,#(T,C,W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TAO<F1E+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?1FEL=&5R
M7V5M;W1I8V]N<SHZ(&-L87-S(&9I;F1S(&5M;W1I8V]N('-T<FEN9W,@*"`Z
M*2P@971C+BD@:6X@80H@*B!B;&]C:R!O9B!T97AT(&%N9"!T=7)N<R!T:&5M
M(&EN=&\@:6UA9V4@;&EN:W,N"B`J"B`J(%!A<F%M971E<G,Z"B`J(#QP<F4^
M"B`J(&5N=&ET:65S("TM($EF('1R=64@=&AE(&AT;6P@96YT:71Y('9E<G-I
M;VYS(&]F('1H92!P871T97)N<R!W:6QL(&)E('5S960N"B`J(#PO<')E/@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7T9I;'1E<B]&:6QT97(O96UO
M=&EC;VYS+G!H<"QV(#$N,3<N,3`N,3`@,C`P-B\P-R\R-"`P-#HT.#HQ-R!S
M;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@
M1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($!P86-K
M86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R7V5M;W1I8V]N
M<R!E>'1E;F1S(%1E>'1?1FEL=&5R('L*"B`@("`O*BH*("`@("`J($9I;'1E
M<B!P87)A;65T97)S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<&%R86US(#T@87)R87DH)V5N=&ET:65S)R`]/B!F86QS
M92D["@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@:&%S:"!W:71H(')E<&QA
M8V4@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@4&%T
M=&5R;G,@:&%S:"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%T=&5R;G,H
M*0H@("`@>PH@("`@("`@("1R96=E>'`@/2!A<G)A>2@I.PH@("`@("`@("1I
M8V]N<&%T:"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971);6%G941I<B@G
M:&]R9&4G*2`N("<O96UO=&EC;VYS)SL*"B`@("`@("`@+RH@3&]O<"!T:')O
M=6=H('!O<W-I8FQE('-T<FEN9R!E;6]T:6-O;G,@86YD(&-O;G9E<G0@=&\@
M9W)A<&AI8W,N("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E=$EC;VYS
M*"D@87,@)'-T<FEN9R`]/B`D:6-O;BD@>PH@("`@("`@("`@("`D8F5G7W!A
M='1E<FX@/2`G*%Y\7',I)SL*("`@("`@("`@("`@)&5N9%]P871T97)N(#T@
M)R@_/5QS*2<["B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG96YT
M:71I97,G72D@>PH@("`@("`@("`@("`@("`@)'-T<FEN9R`](&AT;6QS<&5C
M:6%L8VAA<G,H)'-T<FEN9RD["B`@("`@("`@("`@("`@("`D8F5G7W!A='1E
M<FX@/2`G*%Y\7'-\/&)R("\^?"9N8G-P.RDG.PH@("`@("`@("`@("`@("`@
M)&5N9%]P871T97)N(#T@)R@_/5QS?#QB<B`O/GPF;F)S<#LI)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+RH@0VAE8VL@9F]R(&$@<VUI;&5Y(&5I
M=&AE<B!I;6UE9&EA=&5L>2!A="!T:&4@<W1A<G0@;V8@82!L:6YE(&]R"B`@
M("`@("`@("`@("`J(&9O;&QO=VEN9R!A('-P86-E+B!5<V4@>WT@87,@=&AE
M('!R96<@9&5L:6UI=&5R<R!A<R!T:&ES(&ES(&YO=`H@("`@("`@("`@("`@
M*B!F;W5N9"!I;B!A;GD@<VUI;&5Y+B`J+PH@("`@("`@("`@("`D<F5G97AP
M6R=[)R`N("1B96=?<&%T=&5R;B`N('!R96=?<75O=&4H)'-T<FEN9RD@+B`D
M96YD7W!A='1E<FX@+B`G?2==(#T@)UQ<,2<@+B!(;W)D93HZ:6UG*"1I8V]N
M("X@)RYP;F<G+"`D<W1R:6YG+"!A<G)A>2@G86QI9VXG(#T^("=M:61D;&4G
M+"`G=&ET;&4G(#T^("1S=')I;F<I+"`D:6-O;G!A=&@I("X@*"@D=&AI<RT^
M7W!A<F%M<ULG96YT:71I97,G72D@/R`G7%PR)R`Z("<G*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!A<G)A>2@G<F5G97AP)R`]/B`D<F5G97AP*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!H87-H('=I=&@@96UO
M=&EC;VYS(&%N9"!N86UE<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!0871T97)N<R!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971)8V]N
M<R@I"B`@("!["B`@("`@("`@+RH@3&ES="!C;VUP;&5X('-T<FEN9W,@8F5F
M;W)E('-I;7!L97(@;VYE<RP@;W1H97)W:7-E(&9O<B!E>&%M<&QE(#HH*`H@
M("`@("`@("`J('=O=6QD(&)E(&UA=&-H960@86=A:6YS="`Z*"!B969O<F4@
M.B@H(&ES(&9O=6YD+B`J+PH@("`@("`@(')E='5R;B!A<G)A>2@*("`@("`@
M("`@("`@)SHO)R`]/B`G9G)U<W1R871E9"<L("<Z+2\G(#T^("=F<G5S=')A
M=&5D)RP*("`@("`@("`@("`@+R\@)SHJ/B<@/3X@)V)L=7-H)RP*("`@("`@
M("`@("`@)SIE)R`]/B`G9&ES87!P;VEN=&5D)RP*("`@("`@("`@("`@)STZ
M*20G(#T^("=M<G0G+`H@("`@("`@("`@("`G(WPG(#T^("=H86YG;W9E<B<L
M("<C+7PG(#T^("=H86YG;W9E<B<L"B`@("`@("`@("`@("<Z+4`G(#T^("=S
M:&]U="<L"B`@("`@("`@("`@("<Z*"@G(#T^("=B:6=F<F]W;B<L("<Z0R<@
M/3X@)V)I9V9R;W=N)RP*("`@("`@("`@("`@)SI3)R`]/B`G9&%Z960G+"`G
M.BU3)R`]/B`G9&%Z960G+`H@("`@("`@("`@("`G6$`G(#T^("=A;F=R>2<L
M"B`@("`@("`@("`@("=8*"<@/3X@)VUA9"<L"B`@("`@("`@("`@("\O("<^
M.BDG(#T^("=D979I;"<L("<^.BTI)R`]/B`G9&5V:6PG+`H@("`@("`@("`@
M("`O+R`G/CIP)R`]/B`G9&5V:6QT;VYG=64G+"`G/CHM<"<@/3X@)V1E=FEL
M=&]N9W5E)RP*("`@("`@("`@("`@+R\@)SXZ<"<@/3X@)W)A<W!B97)R>2<L
M("<^.E`G(#T^("=R87-P8F5R<GDG+`H@("`@("`@("`@("`O+R`G)BDG(#T^
M("=P=6YK)RP*("`@("`@("`@("`@+R\@)R9P)R`]/B`G<'5N:W1O;F=U92<L
M"B`@("`@("`@("`@("\O("<])BDG(#T^("=P=6YK;6]H87=K)RP*("`@("`@
M("`@("`@)SI=)R`]/B`G9W)I;B<L"B`@("`@("`@("`@("<C6R<@/3X@)VAU
M<G0G+"`G(R@G(#T^("=H=7)T)RP@)R,M6R<@/3X@)VAU<G0G+"`G(RTH)R`]
M/B`G:'5R="<L"B`@("`@("`@("`@("<Z3R<@/3X@)V5M8F%R<F%S<V5D)RP@
M)SHM3R<@/3X@)V5M8F%R<F%S<V5D)RP*("`@("`@("`@("`@)SI;)R`]/B`G
M<V%D)RP*("`@("`@("`@("`@+R\@)SXZ0"<@/3X@)V5N<F%G960G+`H@("`@
M("`@("`@("`O+R`G.B8G(#T^("=A;FYO>65D)RP*("`@("`@("`@("`@)STH
M)R`]/B`G=V]R<FEE9"<L("<]+2@G(#T^("=W;W)R:65D)RP*("`@("`@("`@
M("`@)SI\/2<@/3X@)W9A;7!I<F4G+`H@("`@("`@("`@("`G.BTH)R`]/B`G
M9G)O=VXG+`H@("`@("`@("`@("`G.D0G(#T^("=B:6=G<FEN)RP*("`@("`@
M("`@("`@)S@I)R`]/B`G8V]O;"<L"B`@("`@("`@("`@("\O($EN($5N9VQI
M<V@L(#A032!O8V-U<G,@<W5F9FEC:65N=&QY(&]F=&5N('1O('-P96-I9FEC
M86QL>0H@("`@("`@("`@("`O+R!S96%R8V@@9F]R(&%N9"!E>&-L=61E"B`@
M("`@("`@("`@("<X<"@_/"%;36U=7',K*2<@/3X@)V-O;VQT;VYG=64G+"`O
M+R`G.-XG(#T^("=C;V]L=&]N9W5E)RP*("`@("`@("`@("`@)SA$)R`]/B`G
M8V]O;&=R:6XG+`H@("`@("`@("`@("`G.G`G(#T^("=T;VYG=65O=70G+"`G
M.E`G(#T^("=T;VYG=65O=70G+"`O+R`G.MXG(#T^("=T;VYG=65O=70G+`H@
M("`@("`@("`@("`G/SHH)R`]/B`G8V]N9G5S960G+"`G)2TH)R`]/B`G8V]N
M9G5S960G+`H@("`@("`@("`@("`O+R`G.BDF)R`]/B`G;&]V92<L"B`@("`@
M("`@("`@("=/.RTI)R`]/B`G86YG96QW:6YK)RP*("`@("`@("`@("`@)SM=
M)R`]/B`G=VEN:V=R:6XG+`H@("`@("`@("`@("`G.W`G(#T^("=W:6YK=&]N
M9W5E)RP@)SM0)R`]/B`G=VEN:W1O;F=U92<L("\O("<[WB<@/3X@)W=I;FMT
M;VYG=64G+`H@("`@("`@("`@("`G.GPG(#T^("=I;F1I9F9E<F5N="<L("<Z
M+7PG(#T^("=I;F1I9F9E<F5N="<L"B`@("`@("`@("`@("<A?"<@/3X@)W1I
M<F5D)RP@)R$M22<@/3X@)W1I<F5D)RP*("`@("`@("`@("`@)WQ))R`]/B`G
M87-L965P)RP@)WPM22<@/3X@)V%S;&5E<"<L"B`@("`@("`@("`@("=/.BDG
M(#T^("=A;F=E;"<L("=/.BTI)R`]/B`G86YG96PG+`H@("`@("`@("`@("`G
M3SLI)R`]/B`G86YG96QW:6YK)RP*("`@("`@("`@("`@)SLM*2<@/3X@)W=I
M;FLG+`H@("`@("`@("`@("`G.B,I)R`]/B`G8VQO=VXG+"`G.F\I)R`]/B`G
M8VQO=VXG+`H@("`@("`@("`@("`G.BDG(#T^("=S;6EL92<L"B`@("`@("`@
M("`@("<[*2<@/3X@)W=I;FLG+`H@("`@("`@("`@("`G.BTI)R`]/B`G<VUI
M;&4G+`H@("`@("`@("`@("`G.D`G(#T^("=S:&]U="<L"B`@("`@("`@("`@
M("<Z*"<@/3X@)V9R;W=N)RP*("`@("`@("`I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]497AT
M+T9I;'1E<B]T86)S,G-P86-E<RYP:'``````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C4P,R`Q,#4Q-30S-#$S-R`P,C0T-#$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!497AT
M7T9I;'1E<E]T86)S,G-P86-E<SHZ(&-O;G9E<G1S('1A8G,@:6YT;R!S<&%C
M97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL=&5R+T9I;'1E
M<B]T86)S,G-P86-E<RYP:'`L=B`Q+C,N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X
M.C,X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($!P86-K86=E($AO<F1E7U1E>'0*("HO"F-L87-S(%1E>'1?1FEL=&5R
M7W1A8G,R<W!A8V5S(&5X=&5N9',@5&5X=%]&:6QT97(@>PH*("`@("\J*@H@
M("`@("H@1FEL=&5R('!A<F%M971E<G,N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]P87)A;7,@/2!A<G)A>2@G=&%B<W1O
M<"<@/3X@."P@)V)R96%K8VAA<B<@/3X@(EQN(BD["@H@("`@+RHJ"B`@("`@
M*B!%>&5C=71E<R!A;GD@8V]D92!N96-E<W-A<GD@8F5F;W)E(&%P<&QY:6YG
M('1H92!F:6QT97(@<&%T=&5R;G,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D=&5X="`@5&AE('1E>'0@8F5F;W)E('1H92!F:6QT97)I;F<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!M;V1I9FEE9"!T97AT
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F50<F]C97-S*"1T97AT*0H@("`@
M>PH@("`@("`@("1L:6YE<R`](&5X<&QO9&4H)'1H:7,M/E]P87)A;7-;)V)R
M96%K8VAA<B==+"`D=&5X="D["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)&QI;F5S*3L@)&DK*RD@>PH@("`@("`@("`@("!W:&EL92`H*"1P
M;W,@/2!S=')P;W,H)&QI;F5S6R1I72P@(EQT(BDI("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)&Y?<W!A8V4@/2`D=&AI<RT^7W!A<F%M<ULG=&%B
M<W1O<"==("T@*"1P;W,@)2`D=&AI<RT^7W!A<F%M<ULG=&%B<W1O<"==*3L*
M("`@("`@("`@("`@("`@("1N97=?<W1R(#T@<W1R7W)E<&5A="@G("<L("1N
M7W-P86-E*3L*("`@("`@("`@("`@("`@("1L:6YE<ULD:5T@/2!S=6)S=')?
M<F5P;&%C92@D;&EN97-;)&E=+"`D;F5W7W-T<BP@)'!O<RP@,2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H(EQN
M(BP@)&QI;F5S*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+U1E>'0O1FEL=&5R+W1E>'0R:'1M;"YP:'``
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$R-#8W(#$P-3$U-#,T,30P(#`R
M-#$V-@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92YP:'`G.PH*+RHJ"B`J(%1U
M<FX@=&5X="!I;G1O($A434P@=VET:"!V87)Y:6YG(&QE=F5L<R!O9B!P87)S
M:6YG+B`@1F]R(&YO(&AT;6P*("H@=VAA='-O979E<BP@=7-E(&AT;6QS<&5C
M:6%L8VAA<G,H*2!I;G-T96%D+@H@*@H@*B!087)A;65T97)S.@H@*B`\<')E
M/@H@*B!P87)S96QE=F5L("TM(%1H92!P87)S96QE=F5L(&]F('1H92!O=71P
M=70N(%-E92!T:&4@;&ES="!O9B!C;VYS=&%N=',@8F5L;W<N"B`J(&-H87)S
M970@("`@+2T@5&AE(&-H87)S970@=&\@=7-E(&9O<B!H=&UL<W!E8VEA;&-H
M87)S*"D@8V%L;',N"B`J(&-L87-S("`@("`@+2T@5&AE($-34R!C;&%S<R!N
M86UE(&9O<B!T:&4@;&EN:W,N"B`J(&YO9F]L;&]W("`@+2T@5VAE=&AE<B!T
M;R!S970@=&AE("=R96P](FYO9F]L;&]W(B<@871T<FEB=71E(&]N(&QI;FMS
M+@H@*B!C86QL8F%C:R`@("TM($%N(&]P=&EO;F%L(&-A;&QB86-K(&9U;F-T
M:6]N('1H870@=&AE(%523"!I<R!P87-S960@=&AR;W5G:`H@*B`@("`@("`@
M("`@("`@(&)E9F]R92!B96EN9R!S970@87,@=&AE(&AR968@871T<FEB=71E
M+B`@375S="!B92!A('-T<FEN9R!W:71H"B`J("`@("`@("`@("`@("`@=&AE
M(&9U;F-T:6]N(&YA;64L('1H92!F=6YC=&EO;B!M=7-T('1A:V4@=&AE(&]R
M:6=I;F%L(&%S('1H90H@*B`@("`@("`@("`@("`@(&9I<G-T(&%N9"!O;FQY
M('!A<F%M971E<BX*("H@/"]P<F4^"B`J"B`J(#QP<F4^"B`J($QI<W0@;V8@
M=F%L:60@8V]N<W1A;G1S(&9O<B!T:&4@<&%R<V4@;&5V96PZ"B`J("TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`J(%1%
M6%1?2%1-3%]005-35$A252`@("`@("`@/2`@3F\@86-T:6]N+B!087-S+71H
M<F]U9V@N($EN8VQU9&5D(&9O<@H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;7!L971E;F5S<RX*("H@5$585%](5$U,7U-93E1!6"`@("`@
M("`@("`]("!!;&QO=R!F=6QL(&AT;6PL(&%L<V\@9&\@;&EN92UB<F5A:W,L
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6XM;&EN:6YG+"!S
M>6YT87@M<&%R<VEN9RX*("H@5$585%](5$U,7TU)0U)/("`@("`@("`@("`]
M("!-:6-R;R!H=&UL("AO;FQY(&QI;F4M8G)E86MS+"!I;BUL:6YE(&QI;FMI
M;F<I+@H@*B!415A47TA434Q?34E#4D]?3$E.2U523"`@(#T@($UI8W)O(&AT
M;6P@*&]N;'D@;&EN92UB<F5A:W,L(&EN+6QI;F4@;&EN:VEN9PH@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]F(%523%-S.R!N;R!E;6%I;"!A
M9&1R97-S97,@87)E(&QI;FME9"DN"B`J(%1%6%1?2%1-3%].3TA434P@("`@
M("`@("`@/2`@3F\@:'1M;"`H86QL('-T<FEP<&5D+"!O;FQY(&QI;F4M8G)E
M86MS*0H@*B!415A47TA434Q?3D](5$U,7TY/0E)%04L@(#T@($YO(&AT;6P@
M=VAA='-O979E<BP@;F\@;&EN92!B<F5A:W,@861D960N"B`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@26YC;'5D960@9F]R(&-O;7!L971E;F5S
M<RX*("H@/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1FEL
M=&5R+T9I;'1E<B]T97AT,FAT;6PN<&AP+'8@,2XT+C(N-B`R,#`V+S`R+S$W
M(#(P.C`U.C0Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O<'ER
M:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ
M86Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]497AT"B`J+PIC;&%S
M<R!497AT7T9I;'1E<E]T97AT,FAT;6P@97AT96YD<R!497AT7T9I;'1E<B![
M"@H@("`@+RHJ"B`@("`@*B!&:6QT97(@<&%R86UE=&5R<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R
M<F%Y*"=C:&%R<V5T)R`]/B!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-L87-S)R`]/B`G9FEX960G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYO9F]L;&]W)R`]/B!F86QS92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("=C86QL8F%C:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I.PH*("`@
M("\J*@H@("`@("H@17AE8W5T97,@86YY(&-O9&4@;F5C97-S87)Y(&)E9F]R
M92!A<'!L>6EN9R!T:&4@9FEL=&5R('!A='1E<FYS+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&)E9F]R92!T:&4@9FEL
M=&5R:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6]D
M:69I960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@<')E4')O8V5S<R@D
M=&5X="D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^7W!A<F%M
M<ULG8VAA<G-E="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M8VAA<G-E="==(#T@:7-S970H)$=,3T)!3%-;)U](3U)$15]35%))3D=?0TA!
M4E-%5"==*2`_("1'3$]"04Q36R=?2$]21$5?4U1224Y'7T-(05)3150G72`Z
M("=)4T\M.#@U.2TQ)SL*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&]U
M="!O;B!S:6UP;&4@8V%S97,N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%R
M86US6R=P87)S96QE=F5L)UT@/3T@5$585%](5$U,7U!!4U-42%)5*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&5X=#L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3Y?<&%R86US6R=P87)S96QE=F5L)UT@/3T@5$585%](5$U,7TY/
M2%1-3%].3T)214%+*2!["B`@("`@("`@("`@(')E='5R;B!`:'1M;'-P96-I
M86QC:&%R<R@D=&5X="P@14Y47T-/35!!5"P@)'1H:7,M/E]P87)A;7-;)V-H
M87)S970G72D["B`@("`@("`@?0H*("`@("`@("`O*B!$;R!I;BUL:6YI;F<@
M;V8@:'1T<#HO+WAX>"YX>'@@=&\@;&EN:RP@>'AX0'AX>"YX>'@@=&\@96UA
M:6PL('!A<G0*("`@("`@("`@*B!O;F4N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?<&%R86US6R=P87)S96QE=F5L)UT@/"!415A47TA434Q?3D](5$U,*2![
M"B`@("`@("`@("`@("\J($UA:V4@<W5R92!T:&%T('1H92!O<FEG:6YA;"!M
M97-S86=E(&1O97-N)W0@8V]N=&%I;B!A;GD@8V%P:71A;`H@("`@("`@("`@
M("`@*B`\+T$^('1A9W,@;W(@;W!E;B`\03X@=&%G<R`L('-O('=E(&-A;B!A
M<W-U;64@=V4@9V5N97)A=&5D"B`@("`@("`@("`@("`J('1H96TN("HO"B`@
M("`@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H87)R87DH)SPO03XG+"`G
M/$$G*2P@87)R87DH)SPO83XG+"`G/&$G*2P@)'1E>'0I.PH@("`@("`@("`@
M("`D9FEL=&5R7V%R<F%Y(#T@87)R87DH)VQI;FMU<FQS)RD["B`@("`@("`@
M("`@("1F:6QT97)?<&%R86US(#T@87)R87DH87)R87DH)V-A;&QB86-K)R`]
M/B`D=&AI<RT^7W!A<F%M<ULG8V%L;&)A8VLG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]F;VQL;W<G(#T^("1T:&ES
M+3Y?<&%R86US6R=N;V9O;&QO=R==+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=C87!I=&%L)R`]/B!T<G5E*2D["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W!A<F%M<ULG<&%R<V5L979E;"==(#P@5$58
M5%](5$U,7TU)0U)/7TQ)3DM54DPI('L*("`@("`@("`@("`@("`@("1F:6QT
M97)?87)R87E;72`]("=E;6%I;',G.PH@("`@("`@("`@("`@("`@)&9I;'1E
M<E]P87)A;7-;72`](&%R<F%Y*"=C87!I=&%L7W1A9W,G(#T^('1R=64I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT(#T@5&5X=%]&:6QT97(Z
M.F9I;'1E<B@D=&5X="P@)&9I;'1E<E]A<G)A>2P@)&9I;'1E<E]P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1F]R(&QE=F5L(%1%6%1?2%1-3%]-
M24-23RP@5$585%](5$U,7TY/2%1-3"P@<W1A<G0@=VET:`H@("`@("`@("`J
M(&AT;6QS<&5C:6%L8VAA<G,H*2X@*B\*("`@("`@("`D=&5X="`]($!H=&UL
M<W!E8VEA;&-H87)S*"1T97AT+"!%3E1?0T]-4$%4+"`D=&AI<RT^7W!A<F%M
M<ULG8VAA<G-E="==*3L*"B`@("`@("`@+RH@1&\@:6XM;&EN:6YG(&]F(&AT
M='`Z+R]X>'@N>'AX('1O(&QI;FLL('AX>$!X>'@N>'AX('1O(&5M86EL+"!P
M87)T"B`@("`@("`@("H@='=O+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG<&%R<V5L979E;"==(#P@5$585%](5$U,7TY/2%1-3"D@>PH@("`@
M("`@("`@("`D<WEN=&%X(#T@87)R87DH"B`@("`@("`@("`@("`@("`G)FQT
M.T$@:')E9CTF<75O=#LG(#T^("<\82<@+B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)V-L87-S)UTI(#\@)R<@.B`G(&-L87-S/2(G("X@)'1H:7,M/E]P87)A
M;7-;)V-L87-S)UT@+B`G(B<I("X@)R!H<F5F/2(G+`H@("`@("`@("`@("`@
M("`@)R9Q=6]T.R!R96P])G%U;W0[)R`]/B`G(B!R96P](B<L"B`@("`@("`@
M("`@("`@("`G)G%U;W0[('1I=&QE/29Q=6]T.R<@/3X@)R(@=&ET;&4](B<L
M"B`@("`@("`@("`@("`@("`G)G%U;W0[('1A<F=E=#TF<75O=#M?8FQA;FLF
M<75O=#LF9W0[)R`@/3X@)R(@=&%R9V5T/2)?8FQA;FLB/B<L"B`@("`@("`@
M("`@("`@("`G)G%U;W0[(&]N8VQI8VL])G%U;W0[)R`]/B`G(B!O;F-L:6-K
M/2(G+`H@("`@("`@("`@("`@("`@)UPG*3LF<75O=#LF9W0[)R`]/B`G7"<I
M.R(^)RP*("`@("`@("`@("`@("`@("<F<75O=#LF9W0[)R`]/B`@)R(^)RP*
M("`@("`@("`@("`@("`@("\J($]N;'D@<F5C;VYV97)T(&-A<&ET86P@+T$@
M=&%G<R`M('1H92!O;F5S('=E(&=E;F5R871E9"X@*B\*("`@("`@("`@("`@
M("`@("<F;'0[+T$F9W0[)R`]/B`G/"]A/B<*("`@("`@("`@("`@("`@("D[
M"@H@("`@("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*&%R<F%Y7VME>7,H
M)'-Y;G1A>"DL("1S>6YT87@L("1T97AT*3L*("`@("`@("`@("`@)'1E>'0@
M/2!497AT7T9I;'1E<CHZ9FEL=&5R*"1T97AT+"`G<W!A8V4R:'1M;"<I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@1&\@=&AE(&)L86YK+6QI;F4@+2TM/B`\
M8G(@+SX@<W5B<W1I='5T:6]N+B`@179E<GEB;V1Y(&=E=',@=&AI<SL*("`@
M("`@("`@*B!I9B!Y;W4@9&]N)W0@=V%N="!E=F5N('1H870L(&IU<W0@<V%V
M92!T:&4@:'1M;'-P96-I86QC:&%R<R@I"B`@("`@("`@("H@=F5R<VEO;B!O
M9B!T:&4@:6YP=70N("HO"B`@("`@("`@)'1E>'0@/2!N;#)B<B@D=&5X="D[
M"@H@("`@("`@(')E='5R;B`D=&5X=#L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,3,W(#`R,3(U-@`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O34E-12]087)T+G!H<```````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`Q,C,R,3$@,3`U,34T,S0Q,S<@,#(Q-3$S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PIR97%U:7)E
M7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TU)344N<&AP)SL*"B\J
M*@H@*B!4:&4@8VAA<F%C=&5R*',I('5S960@:6YT97)N86QL>2!F;W(@14],
M<RX*("HO"F1E9FEN92@G34E-15]005)47T5/3"<L(")<;B(I.PH*+RHJ"B`J
M(%1H92!C:&%R86-T97(@<W1R:6YG(&1E<VEG;F%T960@8GD@4D9#<R`X,C(O
M,C`T-2!T;R!D97-I9VYA=&4@14],<R!I;B!-24U%"B`J(&UE<W-A9V5S+@H@
M*B\*9&5F:6YE*"=-24U%7U!!4E1?4D9#7T5/3"<L(")<<EQN(BD["@HO*B!$
M969A=6QT($U)344@<&%R86UE=&5R<RX@*B\*"B\J*@H@*B!4:&4@9&5F875L
M="!-24U%(&-H87)A8W1E<B!S970N"B`J+PID969I;F4H)TU)345?1$5&055,
M5%]#2$%24T54)RP@)W5S+6%S8VEI)RD["@HO*BH*("H@5&AE(&1E9F%U;'0@
M34E-12!D97-C<FEP=&EO;BX*("HO"F1E9FEN92@G34E-15]$149!54Q47T1%
M4T-225!424].)RP@7R@B=6YN86UE9"(I*3L*"B\J*@H@*B!4:&4@9&5F875L
M="!-24U%(&1I<W!O<VET:6]N+@H@*B\*9&5F:6YE*"=-24U%7T1%1D%53%1?
M1$E34$]3251)3TXG+"`G:6YL:6YE)RD["@HO*BH*("H@5&AE(&1E9F%U;'0@
M34E-12!E;F-O9&EN9RX*("HO"F1E9FEN92@G34E-15]$149!54Q47T5.0T]$
M24Y')RP@)S=B:70G*3L*"B\J*@H@*B!4:&4@34E-15]087)T.CH@8VQA<W,@
M<')O=FED97,@82!W<F%P<&5R(&%R;W5N9"!-24U%('!A<G1S(&%N9"!M971H
M;V1S"B`J(&9O<B!D96%L:6YG('=I=&@@=&AE;2X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO34E-12]-24U%+U!A<G0N<&AP+'8@,2XQ-S<N-"XR,"`R,#`V
M+S`S+S`Y(#(Q.C4Y.C,Q(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO
M<F1E7TU)344*("HO"F-L87-S($U)345?4&%R="!["@H@("`@+RHJ"B`@("`@
M*B!4:&4@='EP92`H97@N.B!T97AT*2!O9B!T:&ES('!A<G0N"B`@("`@*B!0
M97(@4D9#(#(P-#4L('1H92!D969A=6QT(&ES("=A<'!L:6-A=&EO;B<N"B`@
M("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?='EP
M92`]("=A<'!L:6-A=&EO;B<["@H@("`@+RHJ"B`@("`@*B!4:&4@<W5B='EP
M92`H97@N.B!P;&%I;BD@;V8@=&AI<R!P87)T+@H@("`@("H@4&5R(%)&0R`R
M,#0U+"!T:&4@9&5F875L="!I<R`G;V-T970M<W1R96%M)RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]S=6)T>7!E(#T@
M)V]C=&5T+7-T<F5A;2<["@H@("`@+RHJ"B`@("`@*B!4:&4@8F]D>2!O9B!T
M:&4@<&%R="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]C;VYT96YT<R`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&1E
M<VER960@=')A;G-F97(@96YC;V1I;F<@;V8@=&AI<R!P87)T+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1R86YS9F5R
M16YC;V1I;F<@/2!-24U%7T1%1D%53%1?14Y#3T1)3D<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@8W5R<F5N="!T<F%N<V9E<B!E;F-O9&EN9R!O9B!T:&4@8V]N
M=&5N=',@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1%;F-O9&EN9R`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!3:&]U;&0@=&AE(&UE<W-A9V4@8F4@96YC;V1E9"!V
M:6$@-RUB:70_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7V5N8V]D93=B:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@
M5&AE(&1E<V-R:7!T:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D97-C<FEP=&EO;B`]("<G
M.PH*("`@("\J*@H@("`@("H@5&AE(&1I<W!O<VET:6]N(&]F('1H:7,@<&%R
M="`H:6YL:6YE(&]R(&%T=&%C:&UE;G0I+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1I<W!O<VET:6]N(#T@34E-15]$
M149!54Q47T1)4U!/4TE424]..PH*("`@("\J*@H@("`@("H@5&AE(&1I<W!O
M<VET:6]N('!A<F%M971E<G,@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9&ES<&]S:71I;VY087)A
M;65T97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!C;VYT96YT
M('1Y<&4@<&%R86UE=&5R<R!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]C;VYT96YT5'EP95!A<F%M
M971E<G,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE('-U8G!A<G1S
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W!A<G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J
M($EN9F]R;6%T:6]N+U-T871I<W1I8W,@;VX@=&AE('-U8G!A<G0N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I;F9O<FUA
M=&EO;B`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@;&ES="!O9B!#
M241S(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]C:61S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%1H92!-24U%($E$(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]M:6UE:60@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@5&AE('-E<75E;F-E('1O('5S92!A<R!%3TP@9F]R
M('1H:7,@<&%R="X*("`@("`J(%1H92!D969A=6QT(&ES(&-U<G)E;G1L>2!T
M;R!O=71P=70@=&AE($5/3"!S97%U96YC92!I;G1E<FYA;&QY(&%S"B`@("`@
M*B!J=7-T(")<;B(@:6YS=&5A9"!O9B!T:&4@8V%N;VYI8V%L(")<<EQN(B!R
M97%U:7)E9"!I;B!21D,@.#(R("8@,C`T-2X*("`@("`J(%1O(&)E(%)&0R!C
M;VUP;&%I;G0L('1H92!F=6QL(#Q#4CX\3$8^($5/3"!C;VUB:6YA=&EO;B!S
M:&]U;&0@8F4@=7-E9`H@("`@("H@=VAE;B!S96YD:6YG(&$@;65S<V%G92X*
M("`@("`J($ET(&ES(&YO="!C<G5C:6%L(&AE<F4@<VEN8V4@=&AE(%!(4"]0
M14%2(&UA:6QI;F<@9G5N8W1I;VYS('=I;&P@:&%N9&QE"B`@("`@*B!T:&4@
M14],(&1E=&%I;',N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?96]L(#T@34E-15]005)47T5/3#L*"B`@("`O*BH*("`@
M("`J($EN=&5R;F%L(&-L87-S(&9L86=S+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?9FQA9W,@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@4&%R="`M/B!)1"!M87!P:6YG(&-A8VAE+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:61M87`@/2!A
M<G)A>2@I.PH*("`@("\J*@H@("`@("H@56YI<75E($U)345?4&%R="!B;W5N
M9&%R>2!S=')I;F<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8F]U;F1A<GD@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M1&5F875L="!V86QU92!F;W(@=&AI<R!087)T)W,@<VEZ92X*("`@("`J"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8GET97,@/2`P
M.PH*("`@("\J*@H@("`@("H@5&AE(&-O;G1E;G0M240@9F]R('1H:7,@<&%R
M="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]C;VYT96YT:60@/2!N=6QL.PH*("`@("\J*@H@("`@("H@34E-15]087)T
M(&-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI
M;65T>7!E("`@("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!P87)T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@("`@(%1H92!B;V1Y(&]F('1H
M92!P87)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@("`@(%1H
M92!C:&%R86-T97(@<V5T(&]F('1H92!P87)T+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&ES<&]S:71I;VX@(%1H92!C;VYT96YT(&1I<W!O<VET:6]N(&]F
M('1H92!P87)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D96YC;V1I;F<@("`@
M(%1H92!C;VYT96YT(&5N8V]D:6YG(&]F('1H92!C;VYT96YT<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@34E-15]087)T*"1M:6UE='EP92`](&YU;&PL("1C
M;VYT96YT<R`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@)&-H87)S
M970@/2!-24U%7T1%1D%53%1?0TA!4E-%5"P@)&1I<W!O<VET:6]N(#T@;G5L
M;"P*("`@("`@("`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!N=6QL*0H@
M("`@>PH@("`@("`@("\J($-R96%T92!T:&4@=6YI<75E($U)345?4&%R="!B
M;W5N9&%R>2!S=')I;F<N("HO"B`@("`@("`@)'1H:7,M/E]G96YE<F%T94)O
M=6YD87)Y*"D["@H@("`@("`@("\J(%1H92!C:&%R86-T97(@<V5T('-H;W5L
M9"!A;'=A>7,@8F4@<V5T+"!E=F5N(&EF('=E(&%R92!D96%L:6YG"B`@("`@
M("`@("H@=VET:"!#;VYT96YT+51Y<&5S(&]T:&5R('1H86X@=&5X="\J+B`J
M+PH@("`@("`@("1T:&ES+3YS971#:&%R<V5T*"1C:&%R<V5T*3L*"B`@("`@
M("`@:68@*"%I<U]N=6QL*"1M:6UE='EP92DI('L*("`@("`@("`@("`@)'1H
M:7,M/G-E=%1Y<&4H)&UI;65T>7!E*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%I<U]N=6QL*"1C;VYT96YT<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$-O;G1E;G1S*"1C;VYT96YT<RP@)&5N8V]D:6YG*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"%I<U]N=6QL*"1D:7-P;W-I=&EO;BDI('L*("`@("`@("`@
M("`@)'1H:7,M/G-E=$1I<W!O<VET:6]N*"1D:7-P;W-I=&EO;BD["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!C;VYT96YT+61I
M<W!O<VET:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D:7-P;W-I=&EO;B`@5&AE(&-O;G1E;G0M9&ES<&]S:71I;VX@
M=&\@<V5T("AI;FQI;F4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A='1A8VAM96YT*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M1&ES<&]S:71I;VXH)&1I<W!O<VET:6]N*0H@("`@>PH@("`@("`@("1D:7-P
M;W-I=&EO;B`](%-T<FEN9SHZ;&]W97(H)&1I<W!O<VET:6]N*3L*"B`@("`@
M("`@:68@*"@D9&ES<&]S:71I;VX@/3T@)VEN;&EN92<I('Q\("@D9&ES<&]S
M:71I;VX@/3T@)V%T=&%C:&UE;G0G*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V1I<W!O<VET:6]N(#T@)&1I<W!O<VET:6]N.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($=E="!T:&4@8V]N=&5N="UD:7-P;W-I=&EO;B!O
M9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!P87)T)W,@8V]N=&5N="UD:7-P;W-I=&EO;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&ES<&]S:71I;VXH*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1I<W!O<VET:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M('1H92!N86UE(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE(%1H92!N86UE('1O('-E="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T3F%M92@D;F%M92D*("`@('L*("`@("`@("`D=&AI<RT^<V5T
M0V]N=&5N=%1Y<&5087)A;65T97(H)VYA;64G+"`D;F%M92D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@=&AE(&YA;64@;V8@=&AI<R!P87)T+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96-O9&4@("!-24U%(&1E8V]D
M92!D97-C<FEP=&EO;C\*("`@("`J($!P87)A;2!B;V]L96%N("1D969A=6QT
M("!)9B!T:&4@;F%M92!P87)A;65T97(@9&]E<VXG="!E>&ES="P@<VAO=6QD
M('=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E('1H92!D
M969A=6QT(&YA;64@9G)O;2!T:&4@9&5S8W)I<'1I;VX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!P87)A;65T97(_"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!N86UE(&]F('1H92!P87)T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971.86UE*"1D96-O9&4@/2!F86QS92P@)&1E9F%U
M;'0@/2!F86QS92D*("`@('L*("`@("`@("`D;F%M92`]("1T:&ES+3YG971#
M;VYT96YT5'EP95!A<F%M971E<B@G;F%M92<I.PH*("`@("`@("!I9B`H)&1E
M9F%U;'0@)B8@96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@
M<')E9U]R97!L86-E*"=\7%=\)RP@)U\G+"`D=&AI<RT^9V5T1&5S8W)I<'1I
M;VXH9F%L<V4L('1R=64I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9&5C
M;V1E*2!["B`@("`@("`@("`@(')E='5R;B!T<FEM*$U)344Z.F1E8V]D92@D
M;F%M92DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D
M;F%M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE
M(&)O9'D@8V]N=&5N=',@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;G1E;G1S("!4:&4@<&%R="!B;V1Y+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D96YC;V1I;F<@(%1H92!C=7)R96YT(&5N8V]D:6YG
M(&]F('1H92!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N
M=&5N=',H)&-O;G1E;G1S+"`D96YC;V1I;F<@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?8V]N=&5N=',@/2`D8V]N=&5N=',["B`@("`@("`@)'1H
M:7,M/E]F;&%G<ULG8V]N=&5N='-3970G72`]('1R=64["B`@("`@("`@)'1H
M:7,M/E]C=7)R96YT16YC;V1I;F<@/2`H:7-?;G5L;"@D96YC;V1I;F<I*2`_
M("1T:&ES+3YG971#=7)R96YT16YC;V1I;F<H*2`Z($U)344Z.F5N8V]D:6YG
M*"1E;F-O9&EN9RP@34E-15]35%))3D<I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@061D('1O('1H92!B;V1Y(&-O;G1E;G1S(&]F('1H:7,@<&%R="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT<R`@5&AE(&-O;G1E
M;G1S('1O(&%P<&5N9"!T;R!T:&4@8W5R<F5N="!P87)T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@8F]D>2X*("`@("`J($!P87)A;2!S=')I
M;F<@)&5N8V]D:6YG("!4:&4@8W5R<F5N="!E;F-O9&EN9R!O9B!T:&4@8V]N
M=&5N=',N($EF(&YO=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M('-P96-I9FEE9"P@=VEL;"!T<GD@=&\@875T;R!D971E<FUI;F4@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@96YC;V1I;F<N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%P<&5N9$-O;G1E;G1S*"1C;VYT96YT<RP@)&5N
M8V]D:6YG(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T0V]N=&5N
M=',H)'1H:7,M/E]C;VYT96YT<R`N("1C;VYT96YT<RP@)&5N8V]D:6YG*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-L96%R<R!T:&4@8F]D>2!C;VYT96YT
M<R!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%R0V]N
M=&5N=',H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8V]N=&5N=',@/2`G)SL*
M("`@("`@("`D=&AI<RT^7V9L86=S6R=C;VYT96YT<U-E="==(#T@9F%L<V4[
M"B`@("`@("`@)'1H:7,M/E]C=7)R96YT16YC;V1I;F<@/2!N=6QL.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!B;V1Y(&]F('1H92!P87)T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&)O9'D@
M;V8@=&AE('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G1S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT<SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-O;G1E;G1S(&EN('-T
M<FEC="!21D,@.#(R("8@,C`T-2!O=71P=70@+2!N86UE;'DL(&%L;`H@("`@
M("H@;F5W;&EN97,@96YD('=I=&@@=&AE(&-A;F]N:6-A;"`\0U(^/$Q&/B!S
M97%U96YC92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N
M=&ER92!-24U%('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A;F]N
M:6-A;$-O;G1E;G1S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)E
M<&QA8V5%3TPH)'1H:7,M/E]C;VYT96YT<RP@34E-15]005)47U)&0U]%3TPI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5')A;G-F97(@96YC;V1E('1H92!C
M;VYT96YT<R`H=&\@=&AE('1R86YS9F5R(&5N8V]D:6YG(&ED96YT:69I960@
M=FEA"B`@("`@*B!G9714<F%N<V9E<D5N8V]D:6YG*"DI(&%N9"!S970@87,@
M=&AE('!A<G0G<R!N97<@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1R86YS9F5R16YC;V1E0V]N=&5N=',H*0H@("`@>PH@("`@("`@("1C;VYT
M96YT<R`]("1T:&ES+3YT<F%N<V9E<D5N8V]D92@I.PH@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$5N8V]D:6YG(#T@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS
M9F5R16YC;V1E)UT["B`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G1S*"1C;VYT
M96YT<RP@)'1H:7,M/E]C=7)R96YT16YC;V1I;F<I.PH@("`@("`@("1T:&ES
M+3YS9714<F%N<V9E<D5N8V]D:6YG*"1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1R86YS9F5R(&1E8V]D92!T:&4@
M8V]N=&5N=',@86YD('-E="!T:&5M(&%S('1H92!N97<@8V]N=&5N=',N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1R86YS9F5R1&5C;V1E0V]N=&5N=',H*0H@
M("`@>PH@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YT<F%N<V9E<D1E8V]D
M92@I.PH@("`@("`@("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG(#T@)'1H:7,M
M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT["B`@("`@("`@)'1H:7,M
M/G-E=%1R86YS9F5R16YC;V1I;F<H)'1H:7,M/E]C=7)R96YT16YC;V1I;F<I
M.PH*("`@("`@("`O*B!$;VXG="!S970@8V]N=&5N=',@:68@=&AE>2!A<F4@
M96UP='DL(&)E8V%U<V4@=&AI<R!W:6QL(&1O('-T=69F"B`@("`@("`@("`@
M;&EK92!R97-E="!T:&4@:6YT97)N86P@8GET97,@9FEE;&0L(&5V96X@=&AO
M=6=H('=E('-H;W5L9&XG="!D;PH@("`@("`@("`@('1H870@*'1H92!U<V5R
M(&AA<R!T:&5I<B!R96%S;VYS('1O('-E="!T:&4@8GET97,@9FEE;&0@=&\@
M80H@("`@("`@("`@(&YO;BUZ97)O('9A;'5E('=I=&AO=70@<'5T=&EN9R!T
M:&4@8V]N=&5N=',@:6YT;R!T:&ES('!A<G0N("HO"B`@("`@("`@:68@*'-T
M<FQE;B@D8V]N=&5N=',I*2!["B`@("`@("`@("`@("1T:&ES+3YS971#;VYT
M96YT<R@D8V]N=&5N=',L("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG*3L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&UI;65T>7!E
M(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M:6UE='EP92`@5&AE(&UI;65T>7!E('1O('-E="`H97@N.B!T97AT+W!L86EN
M*2X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5'EP92@D;6EM971Y<&4I"B`@
M("!["B`@("`@("`@+RH@4D9#(#(P-#4Z($%N>2!E;G1I='D@=VET:"!U;G)E
M8V]G;FEZ960@96YC;V1I;F<@;75S="!B92!T<F5A=&5D"B`@("`@("`@("`@
M87,@:68@:70@:&%S(&$@0V]N=&5N="U4>7!E(&]F(")A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TB"B`@("`@("`@("`@<F5G87)D;&5S<R!O9B!W:&%T('1H
M92!#;VYT96YT+51Y<&4@9FEE;&0@86-T=6%L;'D@<V%Y<RX@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]T<F%N<V9E<D5N8V]D:6YG(#T]("=X+75N:VYO=VXG
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J
M(%-E="!T:&4@)W-E=%1Y<&4G(&9L86<N("HO"B`@("`@("`@)'1H:7,M/E]F
M;&%G<ULG<V5T5'EP92==(#T@=')U93L*"B`@("`@("`@;&ES="@D=&AI<RT^
M7W1Y<&4L("1T:&ES+3Y?<W5B='EP92D@/2!E>'!L;V1E*"<O)RP@4W1R:6YG
M.CIL;W=E<B@D;6EM971Y<&4I*3L*("`@("`@("!I9B`H*"1T>7!E(#T@34E-
M13HZ='EP92@D=&AI<RT^7W1Y<&4L($U)345?4U1224Y'*2DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]T>7!E(#T@)'1Y<&4["@H@("`@("`@("`@("`O*B!3
M970@=&AE(&)O=6YD87)Y('-T<FEN9R!F;W(@)VUU;'1I<&%R="\J)R!P87)T
M<RX@*B\*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M=6QT:7!A<G0G*2![
M"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YG971#;VYT96YT5'EP95!A
M<F%M971E<B@G8F]U;F1A<GDG*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YS971#;VYT96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG+"`D=&AI
M<RT^7V=E;F5R871E0F]U;F1A<GDH*2D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^8VQE
M87)#;VYT96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?='EP
M92`]("=X+75N:VYO=VXG.PH@("`@("`@("`@("`D=&AI<RT^8VQE87)#;VYT
M96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG*3L*("`@("`@("!]"B`@("!]
M"@H@("`@("\J*@H@("`@("`J($=E="!T:&4@9G5L;"!-24U%($-O;G1E;G0M
M5'EP92!O9B!T:&ES('!A<G0N"B`@("`@("H*("`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D8VAA<G-E="`@07!P96YD(&-H87)A8W1E<B!S970@:6YF;W)M871I
M;VX@=&\@=&AE(&5N9"!O9@H@("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!T:&4@8V]N=&5N="!T>7!E(&EF('1H:7,@:7,@82!T97AT+RH@<&%R
M="X*("`@("`@*@H@("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@;6EM971Y
M<&4@;V8@=&AI<R!P87)T"B`@("`@("H@("`@("`@("`@("`@("`@("AE>"XZ
M('1E>'0O<&QA:6X[(&-H87)S970]=7,M87-C:6DI+@H@("`@("`J+PH@("`@
M(&9U;F-T:6]N(&=E=%1Y<&4H)&-H87)S970@/2!F86QS92D*("`@("!["B`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T>7!E*2!\?"`A:7-S970H)'1H
M:7,M/E]S=6)T>7!E*2D@>PH@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("!]"B`@("`@("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y
M5'EP92@I.PH@("`@("`@("`D='EP92`]("1P='EP92`N("<O)R`N("1T:&ES
M+3YG9713=6)4>7!E*"D["B`@("`@("`@(&EF("@D8VAA<G-E="`F)B`H)'!T
M>7!E(#T]("=T97AT)RDI('L*("`@("`@("`@("`@("1T>7!E("X]("<[(&-H
M87)S970])R`N("1T:&ES+3YG971#:&%R<V5T*"D["B`@("`@("`@('T*("`@
M("`@("`@<F5T=7)N("1T>7!E.PH@("`@('T*"B`@("`O*BH*("`@("`J($EF
M('1H92!S=6)T>7!E(&]F(&$@34E-12!P87)T(&ES('5N<F5C;V=N:7IE9"!B
M>2!A;B!A<'!L:6-A=&EO;BP@=&AE"B`@("`@*B!D969A=6QT('1Y<&4@<VAO
M=6QD(&)E('5S960@:6YS=&5A9"`H4V5E(%)&0R`R,#0V*2X@(%1H:7,@;65T
M:&]D"B`@("`@*B!R971U<FYS('1H92!D969A=6QT('-U8G1Y<&4@9F]R(&$@
M<&%R=&EC=6QA<B!P<FEM87)Y($U)344@5'EP92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&1E9F%U;'0@;6EM971Y<&4@;V8@=&AI<R!P
M87)T("AE>"XZ('1E>'0O<&QA:6XI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971$969A=6QT5'EP92@I"B`@("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^
M9V5T4')I;6%R>51Y<&4H*2D@>PH@("`@("`@(&-A<V4@)W1E>'0G.@H@("`@
M("`@("`@("`O*B!21D,@,C`T-B`H-"XQ+C0I.B!T97AT('!A<G1S(&1E9F%U
M;'0@=&\@=&5X="]P;&%I;BX@*B\*("`@("`@("`@("`@<F5T=7)N("=T97AT
M+W!L86EN)SL*"B`@("`@("`@8V%S92`G;75L=&EP87)T)SH*("`@("`@("`@
M("`@+RH@4D9#(#(P-#8@*#4N,2XS*3H@;75L=&EP87)T('!A<G1S(&1E9F%U
M;'0@=&\@;75L=&EP87)T+VUI>&5D+B`J+PH@("`@("`@("`@("!R971U<FX@
M)VUU;'1I<&%R="]M:7AE9"<["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("\J(%)&0R`R,#0V("@T+C(L(#0N,RP@-"XT+"`T+C4N,RP@-2XR+C0I
M.B!A;&P@;W1H97)S(&1E9F%U;'0@=&\*("`@("`@("`@("`@("`@87!P;&EC
M871I;VXO;V-T970M<W1R96%M+B`J+PH@("`@("`@("`@("!R971U<FX@)V%P
M<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T('1H92!P<FEM87)Y('1Y<&4@;V8@=&AI<R!P87)T
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<')I;6%R>2!-
M24U%('1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710<FEM87)Y5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M='EP93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<W5B='EP92!O
M9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!-24U%('-U8G1Y<&4@;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9713=6)4>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]S=6)T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!C:&%R
M86-T97(@<V5T(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!O9B!T:&ES('!A
M<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-H87)S970H)&-H87)S970I
M"B`@("!["B`@("`@("`@)'1H:7,M/G-E=$-O;G1E;G14>7!E4&%R86UE=&5R
M*"=C:&%R<V5T)RP@)&-H87)S970I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T('1H92!C:&%R86-T97(@<V5T('1O('5S92!F;W(@;V8@=&AI<R!P87)T
M+B`@4F5T=7)N<R!A(&-H87)S970@9F]R"B`@("`@*B!A;&P@='EP97,@*&YO
M="!J=7-T("=T97AT+RHG*2!S:6YC92!W92!U<V4@=&AI<R!C:&%R<V5T('1O
M(&1E=&5R;6EN90H@("`@("H@:&]W('1O(&5N8V]D92!T97AT(&EN($U)344@
M:&5A9&5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-H
M87)A8W1E<B!S970@;V8@=&AI<R!P87)T+B`@4F5T=7)N<R!N=6QL(&EF('1H
M97)E"B`@("`@*B`@("`@("`@("`@("`@("`@:7,@;F\@8VAA<F%C=&5R('-E
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0VAA<G-E="@I"B`@("!["B`@
M("`@("`@)&-H87)S970@/2`D=&AI<RT^9V5T0V]N=&5N=%1Y<&5087)A;65T
M97(H)V-H87)S970G*3L*("`@("`@("!R971U<FX@*&5M<'1Y*"1C:&%R<V5T
M*2D@/R!N=6QL(#H@)&-H87)S970["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M970@=&AE(&1E<V-R:7!T:6]N(&]F('1H:7,@<&%R="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1D97-C<FEP=&EO;B`@5&AE(&1E<V-R:7!T:6]N
M(&]F('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5S8W)I
M<'1I;VXH)&1E<V-R:7!T:6]N*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5S
M8W)I<'1I;VX@/2!-24U%.CIE;F-O9&4H)&1E<V-R:7!T:6]N+"`D=&AI<RT^
M9V5T0VAA<G-E="@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M9&5S8W)I<'1I;VX@;V8@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A
M;2!B;V]L96%N("1D96-O9&4@("!-24U%(&1E8V]D92!D97-C<FEP=&EO;C\*
M("`@("`J($!P87)A;2!B;V]L96%N("1D969A=6QT("!)9B!T:&4@;F%M92!P
M87)A;65T97(@9&]E<VXG="!E>&ES="P@<VAO=6QD('=E"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@=7-E('1H92!D969A=6QT(&YA;64@9G)O
M;2!T:&4@9&5S8W)I<'1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("!P87)A;65T97(_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!D97-C<FEP=&EO;B!O9B!T:&ES('!A<G0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$1E<V-R:7!T:6]N*"1D96-O9&4@/2!F86QS92P@)&1E9F%U
M;'0@/2!F86QS92D*("`@('L*("`@("`@("`D9&5S8R`]("1T:&ES+3Y?9&5S
M8W)I<'1I;VX["@H@("`@("`@(&EF("@D9&5F875L="`F)B!E;7!T>2@D9&5S
M8RDI('L*("`@("`@("`@("`@)&1E<V,@/2`D=&AI<RT^9V5T3F%M92@I.PH@
M("`@("`@("`@("!I9B`H96UP='DH)&1E<V,I*2!["B`@("`@("`@("`@("`@
M("`D9&5S8R`]($U)345?1$5&055,5%]$15-#4DE05$E/3CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1D96-O9&4I('L*("`@("`@
M("`@("`@<F5T=7)N($U)344Z.F1E8V]D92@D9&5S8RD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N("1D97-C.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=')A;G-F97(@96YC;V1I;F<@
M=&\@=7-E(&9O<B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D96YC;V1I;F<@(%1H92!T<F%N<V9E<B!E;F-O9&EN9R!T;R!U<V4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1R86YS9F5R16YC;V1I;F<H)&5N
M8V]D:6YG*0H@("`@>PH@("`@("`@(&EF("@H)&UI;65?96YC;V1I;F<@/2!-
M24U%.CIE;F-O9&EN9R@D96YC;V1I;F<L($U)345?4U1224Y'*2DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]T<F%N<V9E<D5N8V]D:6YG(#T@)&UI;65?96YC
M;V1I;F<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@4D9#(#(P
M-#4Z($%N>2!E;G1I='D@=VET:"!U;G)E8V]G;FEZ960@96YC;V1I;F<@;75S
M="!B92!T<F5A=&5D"B`@("`@("`@("`@("`@(&%S(&EF(&ET(&AA<R!A($-O
M;G1E;G0M5'EP92!O9B`B87!P;&EC871I;VXO;V-T970M<W1R96%M(@H@("`@
M("`@("`@("`@("!R96=A<F1L97-S(&]F('=H870@=&AE($-O;G1E;G0M5'EP
M92!F:65L9"!A8W1U86QL>2!S87ES+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M<V5T5'EP92@G87!P;&EC871I;VXO;V-T970M<W1R96%M)RD["B`@("`@("`@
M("`@("1T:&ES+3Y?=')A;G-F97)%;F-O9&EN9R`]("=X+75N:VYO=VXG.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A($U)344@<W5B
M<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("1M:6UE7W!A
M<G0@($%D9"!A($U)345?4&%R="!S=6)P87)T('1O('1H92!C=7)R96YT"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($U)345?4&%R="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&EN9&5X("`@("`@("`@5&AE(&EN9&5X
M(&]F('1H92!A9&1E9"!-24U%7U!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9%!A<G0H)&UI;65?<&%R="P@)&EN9&5X(#T@;G5L;"D*("`@('L*("`@
M("`@("`O*B!!9&0@=&AE('!A<G0@=&\@=&AE('!A<G1S(&QI<W0N("HO"B`@
M("`@("`@:68@*&ES7VYU;&PH)&EN9&5X*2D@>PH@("`@("`@("`@("!E;F0H
M)'1H:7,M/E]P87)T<RD["B`@("`@("`@("`@("1I9"`](&ME>2@D=&AI<RT^
M7W!A<G1S*2`K(#$["B`@("`@("`@("`@("1P='(@/2`F)'1H:7,M/E]P87)T
M<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<'1R(#T@)B1T:&ES
M+3Y?<&%R=$9I;F0H)&EN9&5X+"`D=&AI<RT^7W!A<G1S+"!T<G5E*3L*("`@
M("`@("`@("`@:68@*"@D<&]S(#T@<W1R<G!O<R@D:6YD97@L("<N)RDI*2![
M"B`@("`@("`@("`@("`@("`D:60@/2!S=6)S='(H)&EN9&5X+"`D<&]S("L@
M,2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D:60@
M/2`D:6YD97@["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M(%-E="!T:&4@34E-12!)1"!I9B!I="!H87,@;F]T(&%L<F5A9'D@8F5E;B!S
M970N("HO"B`@("`@("`@:68@*"1M:6UE7W!A<G0M/F=E=$U)345)9"@I(#T]
M/2!N=6QL*2!["B`@("`@("`@("`@("1M:6UE7W!A<G0M/G-E=$U)345)9"@D
M:60I.PH@("`@("`@('T*"B`@("`@("`@+RH@4W1O<F4@=&AE('!A<G0@;F]W
M+B`J+PH@("`@("`@("1P=');)&ED72`]("1M:6UE7W!A<G0["@H@("`@("`@
M("\J($-L96%R('1H92!)1"`M/B!087)T(&UA<'!I;F<@8V%C:&4N("HO"B`@
M("`@("`@)'1H:7,M/E]I9&UA<"`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@82!L:7-T(&]F(&%L;"!-24U%('-U8G!A<G1S+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F('1H92!-24U%
M7U!A<G0@<W5B<&%R=',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!A<G1S
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P87)T<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E=')I979E(&$@<W!E8VEF:6,@34E-12!P87)T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@34E-15]0
M87)T($E$('-T<FEN9RX*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R
M="`@5&AE($U)345?4&%R="!R97%U97-T960L(&]R(&9A;'-E(&EF('1H92!P
M87)T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@9&]E<VXG="!E>&ES="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R="@D:60I"B`@("!["B`@("`@
M("`@)&UI;65I9"`]("1T:&ES+3YG971-24U%260H*3L*"B`@("`@("`@+RH@
M5&AI<R!W:6QL(&-O;G9E<G0@)R,N,"<@=&\@<VEM<&QY("<C)RP@=VAI8V@@
M:7,@:&]W('1H92!P87)T(&ES"B`@("`@("`@("H@:6YT97)N86QL>2!S=&]R
M960N("HO"B`@("`@("`@)'-E87)C:%]I9"`]("1I9#L*("`@("`@("!I9B`H
M*"1S='(@/2!S=')R8VAR*"1I9"P@)RXG*2D@)B8*("`@("`@("`@("`@*"1S
M='(@/3T@)RXP)RDI('L*("`@("`@("`@("`@)'-E87)C:%]I9"`]('-U8G-T
M<B@D<V5A<F-H7VED+"`P+"`M,BD["B`@("`@("`@?0H*("`@("`@("`O*B!2
M971U<FX@=&AI<R!P87)T(&EF.@H@("`@("`@("`@(#$I(%1H97)E(&ES(&]N
M;'D@;VYE('!A<G0@*&4N9RX@=&AE($U)344@240@:7,@,"P@;W(@=&AE"B`@
M("`@("`@("`@("`@34E-12!)1"!I<R`Q(&%N9"!T:&5R92!A<F4@;F\@<W5B
M<&%R=',N"B`@("`@("`@("`@,BD@)&ED(&UA=&-H97,@=&AI<R!P87)T<R!-
M24U%($E$+B`J+PH@("`@("`@(&EF("@H)'-E87)C:%]I9"`]/2`P*2!\?`H@
M("`@("`@("`@("`H*"1S96%R8VA?:60@/3T@,2D@)B8@(6-O=6YT*"1T:&ES
M+3Y?<&%R=',I*2!\?`H@("`@("`@("`@("`H(65M<'1Y*"1M:6UE:60I("8F
M("@D<V5A<F-H7VED(#T]("1M:6UE:60I*2D@>PH@("`@("`@("`@("`D<&%R
M="`]("1T:&ES.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)T
M(#T@)'1H:7,M/E]P87)T1FEN9"@D:60L("1T:&ES+3Y?<&%R=',I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*"1P87)T("8F"B`@("`@("`@("`@("@D<V5A
M<F-H7VED("$]("1I9"D@)B8*("`@("`@("`@("`@*"1P87)T+3YG9714>7!E
M*"D@/3T@)VUE<W-A9V4O<F9C.#(R)RDI('L*("`@("`@("`@("`@)')E=%]P
M87)T(#T@571I;#HZ8VQO;F5/8FIE8W0H)'!A<G0I.PH@("`@("`@("`@("`D
M<F5T7W!A<G0M/E]P87)T<R`](&%R<F%Y*"D["B`@("`@("`@("`@(')E='5R
M;B`D<F5T7W!A<G0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A<G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!-24U%7U!A<G0@<W5B
M<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE($U)
M344@4&%R="!T;R!D96QE=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V
M95!A<G0H)&ED*0H@("`@>PH@("`@("`@(&EF("@H)'!T<B`]("8D=&AI<RT^
M7W!A<G1&:6YD*"1I9"P@)'1H:7,M/E]P87)T<RDI*2!["B`@("`@("`@("`@
M('5N<V5T*"1P='(I.PH@("`@("`@("`@("`D=&AI<RT^7VED;6%P(#T@87)R
M87DH*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!;'1E<B!A
M(&-U<G)E;G0@34E-12!S=6)P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("`@("`@("`@("`@5&AE($U)344@4&%R="!)1"!T;R!A;'1E
M<BX*("`@("`J($!P87)A;2!-24U%7U!A<G0@)&UI;65?<&%R="`@5&AE($U)
M344@4&%R="!T;R!S=&]R92X*("`@("`J+PH@("`@9G5N8W1I;VX@86QT97)0
M87)T*"1I9"P@)&UI;65?<&%R="D*("`@('L*("`@("`@("!I9B`H*"1P='(@
M/2`F)'1H:7,M/E]P87)T1FEN9"@D:60L("1T:&ES+3Y?<&%R=',I*2D@>PH@
M("`@("`@("`@("`D<'1R(#T@)&UI;65?<&%R=#L*("`@("`@("`@("`@)'1H
M:7,M/E]I9&UA<"`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1G5N8W1I;VX@=7-E9"!T;R!F:6YD(&$@<W!E8VEF:6,@34E-
M12!087)T(&)Y($E$+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@5&AE($U)
M345?4&%R="!)1"!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@)B1P87)T
M<R`@("`@($$@;&ES="!O9B!-24U%7U!A<G0@;V)J96-T<RX*("`@("`J($!P
M87)A;2!B;V]L96%N("1R971A<G)A>2`@4F5T=7)N(&$@<&]I;G1E<B!T;R!T
M:&4@87)R87D@=&AA="!S=&]R97,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*'=O=6QD('-T;W)E*2!T:&4@<&%R="!R871H97(@=&AA;B!T
M:&4@<&%R=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!I='-E
M;&8_"B`@("`@*B\*("`@(&9U;F-T:6]N("9?<&%R=$9I;F0H)&ED+"`F)'!A
M<G1S+"`D<F5T87)R87D@/2!F86QS92D*("`@('L*("`@("`@("`O*B!0;VEN
M=&5R<R!D;VXG="!P97)S:7-T('1H<F]U9V@@<V5S<VEO;G,[('1H97)E9F]R
M92P@=V4@;75S="!M86ME"B`@("`@("`@("H@<W5R92!T:&%T('1H92!)9$UA
M<"!I<R!D97-T<F]Y960@870@=&AE(&5N9"!O9B!E86-H(')E<75E<W0N"B`@
M("`@("`@("H@2&]W(&-A;B!W92!D;R!T:&ES/R!792!C:&5C:R!T;R!S964@
M:68@)%]I9&UA<"!C;VYT86EN<R!A;B!A<G)A>0H@("`@("`@("`J(&]F($U)
M345?4&%R=',@;W(@86X@87)R87D@;V8@87)R87ES+B`J+PH@("`@("`@("1C
M:&5C:R`](')E<V5T*"1T:&ES+3Y?:61M87`I.PH@("`@("`@(&EF("AE;7!T
M>2@D8VAE8VLI('Q\("%I<U]A*"1C:&5C:RP@)TU)345?4&%R="<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?:61M87`@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D=&AI<RT^7V=E;F5R871E261-87`H)'1H:7,M/E]P87)T<RD["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)')E=&%R<F%Y*2!["B`@("`@("`@("`@(&EF
M("@D<&]S(#T@<W1R<G!O<R@D:60L("<N)RDI('L*("`@("`@("`@("`@("`@
M("1I9"`]('-U8G-T<B@D:60L(#`L("1P;W,I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1P87)T<SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:61M
M87!;)&ED72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:61M87!;
M)&ED73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<&%R="`](&9A
M;'-E.PH@("`@("`@("`@("!R971U<FX@)'!A<G0["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1V5N97)A=&5S(&$@;6%P<&EN9R!O9B!-24U%
M7U!A<G1S('=I=&@@=&AE:7(@34E-12!)1',N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D<&%R
M=',@($%N(&%R<F%Y(&]F($U)345?4&%R=',@=&\@;6%P+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?9V5N97)A=&5)9$UA<"@F)'!A<G1S*0H@("`@>PH@("`@
M("`@(&EF("@A96UP='DH)'!A<G1S*2D@>PH@("`@("`@("`@("!F;W)E86-H
M("AA<G)A>5]K97ES*"1P87)T<RD@87,@)&ME>2D@>PH@("`@("`@("`@("`@
M("`@)'!T<B`]("8D<&%R='-;)&ME>5T["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VED;6%P6R1P='(M/F=E=$U)345)9"@I72`]("8D<'1R.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]G96YE<F%T94ED36%P*"1P='(M/E]P87)T<RD[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&0@:6YF;W)M871I;VX@86)O=70@=&AE($U)345?4&%R="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@5&AE(&EN9F]R;6%T:6]N
M(&QA8F5L+@H@("`@("H@0'!A<F%M(&UI>&5D("1D871A("`@(%1H92!I;F9O
M<FUA=&EO;B!T;R!S=&]R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T26YF
M;W)M871I;VXH)&QA8F5L+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI<RT^
M7VEN9F]R;6%T:6]N6R1L86)E;%T@/2`D9&%T83L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E=')I979E(&EN9F]R;6%T:6]N(&%B;W5T('1H92!-24U%7U!A
M<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;&%B96P@(%1H92!I
M;F9O<FUA=&EO;B!L86)E;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@
M("`@("`@4F5T=7)N<R!F86QS92!I9B`D;&%B96P@:7,@;F]T('-E="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T26YF;W)M871I;VXH)&QA8F5L*0H@("`@
M>PH@("`@("`@(')E='5R;B`H:7-S970H)'1H:7,M/E]I;F9O<FUA=&EO;ELD
M;&%B96Q=*2D@/R`D=&AI<RT^7VEN9F]R;6%T:6]N6R1L86)E;%T@.B!F86QS
M93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A(&1I<W!O<VET:6]N('!A
M<F%M971E<B!T;R!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;&%B96P@(%1H92!D:7-P;W-I=&EO;B!P87)A;65T97(@;&%B96PN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@5&AE(&1I<W!O<VET:6]N
M('!A<F%M971E<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$:7-P
M;W-I=&EO;E!A<F%M971E<B@D;&%B96PL("1D871A*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E;%T@/2`D9&%T
M83L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&1I<W!O<VET:6]N('!A
M<F%M971E<B!F<F]M('1H:7,@<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L86)E;"`@5&AE(&1I<W!O<VET:6]N('!A<F%M971E<B!L86)E
M;"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1A=&$@<F5Q
M=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@9F%L<V4@
M:68@)&QA8F5L(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$1I<W!O<VET:6]N4&%R86UE=&5R*"1L86)E;"D*("`@('L*("`@("`@("!R
M971U<FX@*&ES<V5T*"1T:&ES+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L
M86)E;%TI*2`_("1T:&ES+3Y?9&ES<&]S:71I;VY087)A;65T97)S6R1L86)E
M;%T@.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A;&P@<&%R
M86UE=&5R<R!F<F]M('1H92!#;VYT96YT+41I<W!O<VET:6]N(&AE861E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@
M=&AE('!A<F%M971E<G,*("`@("`J("`@("`@("`@("`@("`@(%)E='5R;G,@
M=&AE(&5M<'1Y(&%R<F%Y(&EF(&YO('!A<F%M971E<G,@<V5T+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971!;&Q$:7-P;W-I=&EO;E!A<F%M971E<G,H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<W!O<VET:6]N4&%R86UE
M=&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!A(&-O;G1E;G0@='EP
M92!P87)A;65T97(@=&\@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&QA8F5L("!4:&4@9&ES<&]S:71I;VX@<&%R86UE=&5R(&QA
M8F5L+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D:7-P;W-I
M=&EO;B!P87)A;65T97(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M0V]N=&5N=%1Y<&5087)A;65T97(H)&QA8F5L+"`D9&%T82D*("`@('L*("`@
M("`@("`D=&AI<RT^7V-O;G1E;G14>7!E4&%R86UE=&5R<ULD;&%B96Q=(#T@
M)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&5A<G,@82!C;VYT96YT
M('1Y<&4@<&%R86UE=&5R(&9R;VT@=&AI<R!P87)T+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&QA8F5L("!4:&4@9&ES<&]S:71I;VX@<&%R86UE
M=&5R(&QA8F5L+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@(%1H92!D
M:7-P;W-I=&EO;B!P87)A;65T97(@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VQE87)#;VYT96YT5'EP95!A<F%M971E<B@D;&%B96PI"B`@("!["B`@
M("`@("`@=6YS970H)'1H:7,M/E]C;VYT96YT5'EP95!A<F%M971E<G-;)&QA
M8F5L72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!C;VYT96YT('1Y
M<&4@<&%R86UE=&5R(&9R;VT@=&AI<R!P87)T+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&QA8F5L("!4:&4@8V]N=&5N="!T>7!E('!A<F%M971E
M<B!L86)E;"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&1A
M=&$@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@(%)E='5R;G,@
M9F%L<V4@:68@)&QA8F5L(&ES(&YO="!S970N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"1L86)E;"D*("`@('L*("`@
M("`@("!R971U<FX@*&ES<V5T*"1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T
M97)S6R1L86)E;%TI*2`_("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T97)S
M6R1L86)E;%T@.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A
M;&P@<&%R86UE=&5R<R!F<F]M('1H92!#;VYT96YT+51Y<&4@:&5A9&5R+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y(&]F(&%L;"!T
M:&4@<&%R86UE=&5R<PH@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N<R!T
M:&4@96UP='D@87)R87D@:68@;F\@<&%R86UE=&5R<R!S970N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$%L;$-O;G1E;G14>7!E4&%R86UE=&5R<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=%1Y<&5087)A;65T
M97)S.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!A(&YE=R!S=')I;F<@
M=&\@=7-E(&9O<B!%3TQS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&5O;"`@5&AE('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$5/3"@D96]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M96]L(#T@)&5O;#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@<W1R
M:6YG('1O('5S92!F;W(@14],<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$5/3"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?96]L.PH@("`@?0H*("`@("\J*@H@("`@("H@061D('1H92!A<'!R;W!R
M:6%T92!-24U%(&AE861E<G,@9F]R('1H:7,@<&%R="!T;R!A;B!E>&ES=&EN
M9R!A<G)A>2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&AE861E<G,@
M($%N(&%R<F%Y(&]F(&%N>2!O=&AE<B!H96%D97)S(&9O<B!T:&4@<&%R="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@:&5A9&5R<RP@=VET
M:"!T:&4@34E-12!H96%D97)S(&%D9&5D+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!H96%D97(H)&AE861E<G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1E
M;VP@/2`D=&AI<RT^9V5T14],*"D["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M
M/F=E=%!R:6UA<GE4>7!E*"D["B`@("`@("`@)'-T>7!E(#T@)'1H:7,M/F=E
M=%-U8E1Y<&4H*3L*"B`@("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@<V5T
M(&9O<B!T:&ES('!A<G0N("HO"B`@("`@("`@)&-H87)S970@/2`D=&AI<RT^
M9V5T0VAA<G-E="@I.PH*("`@("`@("`O*B!'970@=&AE($-O;G1E;G0M5'EP
M92`M('1H:7,@:7,@04Q705E3(')E<75I<F5D+B`J+PH@("`@("`@("1C='EP
M92`]("1T:&ES+3YG9714>7!E*'1R=64I.PH@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YG971!;&Q#;VYT96YT5'EP95!A<F%M971E<G,H*2!A<R`D:V5Y(#T^
M("1V86QU92D@>PH@("`@("`@("`@("`O*B!3:VEP('1H92!C:&%R<V5T(&ME
M>2!S:6YC92!T:&%T('=O=6QD(&AA=F4@86QR96%D>2!B965N"B`@("`@("`@
M("`@("`J(&%D9&5D('1O("1C='EP92!B>2!G9714>7!E*"DN("HO"B`@("`@
M("`@("`@(&EF("@D:V5Y(#T]("=C:&%R<V5T)RD@>PH@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-T>7!E
M("X]("<[("<@+B`D:V5Y("X@)STB)R`N('-T<E]R97!L86-E*"<B)RP@)UPB
M)RP@34E-13HZ96YC;V1E*"1V86QU92P@)&-H87)S970I*2`N("<B)SL*("`@
M("`@("!]"B`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@34E-
M13HZ=W)A<$AE861E<G,H)T-O;G1E;G0M5'EP92<L("1C='EP92P@)&5O;"D[
M"@H@("`@("`@("\J($=E="!T:&4@9&5S8W)I<'1I;VXL(&EF(&%N>2X@*B\*
M("`@("`@("!I9B`H*"1D97-C<FEP(#T@)'1H:7,M/F=E=$1E<V-R:7!T:6]N
M*"DI*2!["B`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+41E<V-R:7!T
M:6]N)UT@/2!-24U%.CIW<F%P2&5A9&5R<R@G0V]N=&5N="U$97-C<FEP=&EO
M;B<L($U)344Z.F5N8V]D92@D9&5S8W)I<"P@)&-H87)S970I+"`D96]L*3L*
M("`@("`@("!]"@H@("`@("`@("\J(%)&0R`R,#0U(%LT72`M(&UE<W-A9V4O
M<F9C.#(R(&%N9"!M97-S86=E+W!A<G1I86P@<F5Q=6ER92!T:&4*("`@("`@
M("`@("!-24U%+59E<G-I;VX@:&5A9&5R(&]N;'D@:68@=&AE>2!T:&5M<V5L
M=F5S(&-L86EM('1O(&)E($U)344*("`@("`@("`@("!C;VUP;&EA;G0N("HO
M"B`@("`@("`@:68@*"@D<'1Y<&4@/3T@)VUE<W-A9V4G*2`F)@H@("`@("`@
M("`@("`H*"1S='EP92`]/2`G<F9C.#(R)RD@?'P@*"1S='EP92`]/2`G<&%R
M=&EA;"<I*2`F)@H@("`@("`@("`@("`H<W1R<&]S*"1T:&ES+3Y?8V]N=&5N
M=',L("=-24U%+59E<G-I;VXZ(#$N,"<I("$]/2!F86QS92DI('L*("`@("`@
M("`@("`@)&AE861E<G-;)TU)344M5F5R<VEO;B==(#T@)S$N,"<["B`@("`@
M("`@?0H*("`@("`@("`O*B!M97-S86=E+RH@<&%R=',@<F5Q=6ER92!N;R!A
M9&1I=&EO;F%L(&AE861E<B!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H
M)'!T>7!E(#T]("=M97-S86=E)RD@>PH@("`@("`@("`@("!R971U<FX@)&AE
M861E<G,["B`@("`@("`@?0H*("`@("`@("`O*B!$;VXG="!S:&]W($-O;G1E
M;G0M1&ES<&]S:71I;VX@9F]R(&UU;'1I<&%R="!M97-S86=E<R!U;FQE<W,*
M("`@("`@("`@("!T:&5R92!I<R!A(&YA;64@<&%R86UE=&5R+B`J+PH@("`@
M("`@("1N86UE(#T@)'1H:7,M/F=E=$YA;64H*3L*("`@("`@("!I9B`H*"1P
M='EP92`A/2`G;75L=&EP87)T)RD@?'P@(65M<'1Y*"1N86UE*2D@>PH@("`@
M("`@("`@("`D9&ES<"`]("1T:&ES+3YG971$:7-P;W-I=&EO;B@I.PH*("`@
M("`@("`@("`@+RH@061D(&%N>2!D:7-P;W-I=&EO;B!P87)A;65T97(@:6YF
M;W)M871I;VXL(&EF(&%V86EL86)L92X@*B\*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@("`@("1D:7-P("X]("<[("<@
M+B`G9FEL96YA;64](B<@+B!-24U%.CIE;F-O9&4H)&YA;64L("1C:&%R<V5T
M*2`N("<B)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&AE861E<G-;
M)T-O;G1E;G0M1&ES<&]S:71I;VXG72`]($U)344Z.G=R87!(96%D97)S*"=#
M;VYT96YT+41I<W!O<VET:6]N)RP@)&1I<W`L("1E;VPI.PH@("`@("`@('T*
M"B`@("`@("`@+RH@061D('1R86YS9F5R(&5N8V]D:6YG(&EN9F]R;6%T:6]N
M+B`J+PH@("`@("`@("1H96%D97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG)UT@/2`D=&AI<RT^9V5T5')A;G-F97)%;F-O9&EN9R@I.PH*("`@("`@
M("`O*B!!9&0@8V]N=&5N="!)1"!I;F9O<FUA=&EO;BX@*B\*("`@("`@("!I
M9B`H(6ES7VYU;&PH)'1H:7,M/E]C;VYT96YT:60I*2!["B`@("`@("`@("`@
M("1H96%D97)S6R=#;VYT96YT+4E$)UT@/2`D=&AI<RT^7V-O;G1E;G1I9#L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!T:&4@96YT:7)E('!A<G0@:6X@34E-12!F
M;W)M870N($EN8VQU9&5S(&AE861E<G,@;VX@<F5Q=65S="X*("`@("`J"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R<R`@26YC;'5D92!T:&4@34E-
M12!H96%D97)S/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M34E-12!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"1H
M96%D97)S(#T@=')U92D*("`@('L*("`@("`@("`D96]L(#T@)'1H:7,M/F=E
M=$5/3"@I.PH@("`@("`@("1P='EP92`]("1T:&ES+3YG9710<FEM87)Y5'EP
M92@I.PH*("`@("`@("!I9B`H)&AE861E<G,I('L*("`@("`@("`@("`@)'1E
M>'0@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FAE861E<B@I
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@
M)&ME>2`N("<Z("<@+B`D=F%L("X@)&5O;#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&5X="`N/2`D96]L.PH@("`@("`@('T*"B`@("`@("`@+RH@
M06YY(&EN9F]R;6%T:6]N(&%B;W5T(&$@;65S<V%G92\J(&ES(&5M8F5D9&5D
M(&EN('1H92!M97-S86=E"B`@("`@("`@("`@8V]N=&5N=',@=&AE;7-E;&8N
M(%-I;7!L>2!O=71P=70@=&AE(&-O;G1E;G1S(&]F('1H92!P87)T"B`@("`@
M("`@("`@9&ER96-T;'D@86YD(')E='5R;BX@*B\*("`@("`@("!I9B`H)'!T
M>7!E(#T]("=M97-S86=E)RD@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1E
M>'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1E>'0@+B`D=&AI<RT^
M7V-O;G1E;G1S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5N=',["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D=&5X="DI('L*("`@("`@("`@
M("`@)'1E>'0@+CT@)'1H:7,M/G1R86YS9F5R16YC;V1E*"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@/2`D=&AI<RT^=')A;G-F97)%
M;F-O9&4H*3L*("`@("`@("!]"@H@("`@("`@("\J($1E86P@=VET:"!M=6QT
M:7!A<G0@;65S<V%G97,N("HO"B`@("`@("`@:68@*"1P='EP92`]/2`G;75L
M=&EP87)T)RD@>PH@("`@("`@("`@("`D8F]U;F1A<GD@/2!T<FEM*"1T:&ES
M+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G8F]U;F1A<GDG*2P@)R(G*3L*
M("`@("`@("`@("`@:68@*"%S=')L96XH)'1H:7,M/E]C;VYT96YT<RDI('L*
M("`@("`@("`@("`@("`@("1T97AT("X]("=4:&ES(&UE<W-A9V4@:7,@:6X@
M34E-12!F;W)M870N)R`N("1E;VP["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/F=E=%!A<G1S*"D@87,@)'!A<G0I('L*("`@
M("`@("`@("`@("`@("1T97AT("X]("1E;VP@+B`G+2TG("X@)&)O=6YD87)Y
M("X@)&5O;#L*("`@("`@("`@("`@("`@("1O;&1%3TP@/2`D<&%R="T^9V5T
M14],*"D["B`@("`@("`@("`@("`@("`D<&%R="T^<V5T14],*"1E;VPI.PH@
M("`@("`@("`@("`@("`@)'1E>'0@+CT@)'!A<G0M/G1O4W1R:6YG*'1R=64I
M.PH@("`@("`@("`@("`@("`@)'!A<G0M/G-E=$5/3"@D;VQD14],*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&5X="`N/2`D96]L("X@)RTM)R`N
M("1B;W5N9&%R>2`N("<M+2<@+B`D96]L.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@96YC;V1E9"!P87)T(&EN('-T<FEC="!21D,@.#(R("8@,C`T-2!O=71P
M=70@+2!N86UE;'DL(&%L;`H@("`@("H@;F5W;&EN97,@96YD('=I=&@@=&AE
M(&-A;F]N:6-A;"`\0U(^/$Q&/B!S97%U96YC92X*("`@("`J"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D:&5A9&5R<R`@26YC;'5D92!T:&4@34E-12!H96%D
M97)S/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96YT:7)E
M($U)344@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@=&]#86YO;FEC86Q3
M=')I;F<H)&AE861E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1S=')I;F<@
M/2`D=&AI<RT^=&]3=')I;F<H)&AE861E<G,I.PH@("`@("`@(')E='5R;B`D
M=&AI<RT^<F5P;&%C945/3"@D<W1R:6YG+"!-24U%7U!!4E1?4D9#7T5/3"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:&]U;&0@=V4@;6%K92!S=7)E('1H
M92!M97-S86=E(&ES(&5N8V]D960@=FEA(#<M8FET("AE+F<N('1O(&%D:&5R
M90H@("`@("H@=&\@;6%I;"!D96QI=F5R>2!S=&%N9&%R9',@<W5C:"!A<R!2
M1D,@,C@R,2D_"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5S93=B
M:70@(%5S92`W+6)I="!E;F-O9&EN9S\*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W1R:6-T-V)I="@D=7-E-V)I="D*("`@('L*("`@("`@("`D=&AI<RT^7V5N
M8V]D93=B:70@/2`D=7-E-V)I=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!T:&4@=')A;G-F97(@96YC;V1I;F<@9F]R('1H92!P87)T(&)A<V5D(&]N
M('1H92!U<V5R(')E<75E<W1E9`H@("`@("H@=')A;G-F97(@96YC;V1I;F<@
M86YD('1H92!C=7)R96YT(&-O;G1E;G1S(&]F('1H92!P87)T+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=')A;G-F97(M96YC;V1I;F<@
M;V8@=&AI<R!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714<F%N<V9E
M<D5N8V]D:6YG*"D*("`@('L*("`@("`@("`D96YC;V1I;F<@/2`D=&AI<RT^
M7W1R86YS9F5R16YC;V1I;F<["B`@("`@("`@)'!T>7!E(#T@)'1H:7,M/F=E
M=%!R:6UA<GE4>7!E*"D["B`@("`@("`@)'1E>'0@/2!S=')?<F5P;&%C92@D
M=&AI<RT^9V5T14],*"DL("<@)RP@)'1H:7,M/E]C;VYT96YT<RD["@H@("`@
M("`@("\J($EF('1H97)E(&%R92!N;R!C;VYT96YT<RP@<F5T=7)N('=H871E
M=F5R('1H92!C=7)R96YT('9A;'5E(&]F"B`@("`@("`@("`@)%]T<F%N<V9E
M<D5N8V]D:6YG(&ES+B`J+PH@("`@("`@(&EF("AE;7!T>2@D=&5X="DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E;F-O9&EN9SL*("`@("`@("!]"@H@("`@
M("`@('-W:71C:"`H)'!T>7!E*2!["B`@("`@("`@8V%S92`G;65S<V%G92<Z
M"B`@("`@("`@("`@("\J(%)&0R`R,#0V(%LU+C(N,5T@+2!M97-S86=E+W)F
M8S@R,B!M97-S86=E<R!O;FQY(&%L;&]W(#=B:70L"B`@("`@("`@("`@("`@
M(#AB:70L(&%N9"!B:6YA<GD@96YC;V1I;F=S+B!)9B!T:&4@8W5R<F5N="!E
M;F-O9&EN9R!I<R!E:71H97(*("`@("`@("`@("`@("`@8F%S938T(&]R('$M
M<"P@<W=I=&-H(&ET('1O(#AB:70@:6YS=&5A9"X*("`@("`@("`@("`@("`@
M4D9#(#(P-#8@6S4N,BXR+"`U+C(N,RP@-2XR+C1=("T@06QL(&]T:&5R(&UE
M<W-A9V4O*B!M97-S86=E<PH@("`@("`@("`@("`@("!O;FQY(&%L;&]W(#=B
M:70@96YC;V1I;F=S+B`J+PH@("`@("`@("`@("`D96YC;V1I;F<@/2`H)'1H
M:7,M/F=E=%-U8E1Y<&4H*2`]/2`G<F9C.#(R)RD@/R`G.&)I="<@.B`G-V)I
M="<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T97AT)SH*
M("`@("`@("`@("`@:68@*$U)344Z.FES.&)I="@D=&5X="DI('L*("`@("`@
M("`@("`@("`@("1E;F-O9&EN9R`]("@D=&AI<RT^7V5N8V]D93=B:70I(#\@
M)W%U;W1E9"UP<FEN=&%B;&4G(#H@)SAB:70G.PH@("`@("`@("`@("!](&5L
M<V5I9B`H<')E9U]M871C:"@B+R@_.EQN?%XI6UY<;EU[.3DY+'TH/SI<;GPD
M*2\B+"`D=&5X="DI('L*("`@("`@("`@("`@("`@("\J($EF('1H92!T97AT
M(&ES(&QO;F=E<B!T:&%N(#DY."!C:&%R86-T97)S(&)E='=E96X*("`@("`@
M("`@("`@("`@("`J(&QI;F5B<F5A:W,L('5S92!Q=6]T960M<')I;G1A8FQE
M(&5N8V]D:6YG('1O(&5N<W5R92!T:&4*("`@("`@("`@("`@("`@("`J('1E
M>'0@=VEL;"!N;W0@8F4@8VAO<'!E9"`H:2YE+B!B>2!S96YD;6%I;"!I9B!B
M96EN9R!S96YT"B`@("`@("`@("`@("`@("`@*B!A<R!M86EL('1E>'0I+B`J
M+PH@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@)W%U;W1E9"UP<FEN=&%B
M;&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("!I9B`H34E-13HZ:7,X8FET*"1T97AT
M*2D@>PH@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@*"1T:&ES+3Y?96YC
M;V1E-V)I="D@/R`G8F%S938T)R`Z("<X8FET)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("\J($YE960@
M=&\@9&\@;VYE(&QA<W0@8VAE8VL@9F]R(&)I;F%R>2!D871A(&EF(&5N8V]D
M:6YG(&ES(#=B:70@;W(*("`@("`@("`@*B`X8FET+B`@268@=&AE(&UE<W-A
M9V4@8V]N=&%I;G,@82!.54Q,(&-H87)A8W1E<B!A="!A;&PL('1H92!M97-S
M86=E"B`@("`@("`@("H@35535"!B92!I;B!B:6YA<GD@9F]R;6%T+B!21D,@
M,C`T-B!;,BXW+"`R+C@L(#(N.5TN(%$M4"!A;F0@8F%S938T"B`@("`@("`@
M("H@8V%N(&AA;F1L92!B:6YA<GD@9&%T82!F:6YE('-O(&YO(&YE960@=&\@
M<W=I=&-H('1H;W-E(&5N8V]D:6YG<RX@*B\*("`@("`@("!I9B`H*"@D96YC
M;V1I;F<@/3T@)SAB:70G*2!\?"`H)&5N8V]D:6YG(#T]("<W8FET)RDI("8F
M"B`@("`@("`@("`@('!R96=?;6%T8V@H)R]<>#`P+R<L("1T97AT*2D@>PH@
M("`@("`@("`@("`D96YC;V1I;F<@/2`H)'1H:7,M/E]E;F-O9&4W8FET*2`_
M("=B87-E-C0G(#H@)V)I;F%R>2<["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)&5N8V]D:6YG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S
M('1H92!C=7)R96YT(&5N8V]D:6YG(&]F('1H92!C;VYT96YT<R!I;B!T:&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8W5R
M<F5N="!E;F-O9&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0W5R<F5N
M=$5N8V]D:6YG*"D*("`@('L*("`@("`@("!R971U<FX@*&ES7VYU;&PH)'1H
M:7,M/E]C=7)R96YT16YC;V1I;F<I*2`_("1T:&ES+3Y?=')A;G-F97)%;F-O
M9&EN9R`Z("1T:&ES+3Y?8W5R<F5N=$5N8V]D:6YG.PH@("`@?0H*("`@("\J
M*@H@("`@("H@16YC;V1E<R!T:&4@8V]N=&5N=',@=VET:"!T:&4@<&%R="=S
M('1R86YS9F5R(&5N8V]D:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@96YC;V1E9"!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!T
M<F%N<V9E<D5N8V]D92@I"B`@("!["B`@("`@("`@)&5N8V]D:6YG(#T@)'1H
M:7,M/F=E=%1R86YS9F5R16YC;V1I;F<H*3L*("`@("`@("`D96]L(#T@)'1H
M:7,M/F=E=$5/3"@I.PH*("`@("`@("`O*B!3970@=&AE("=L87-T5')A;G-F
M97)%;F-O9&4G(&9L86<@<V\@=&AA="!T<F%N<V9E<D5N8V]D94-O;G1E;G1S
M*"D*("`@("`@("`@("!C86X@<V%V92!A(&-A;&P@=&\@9V5T5')A;G-F97)%
M;F-O9&EN9R@I+B`J+PH@("`@("`@("1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N
M<V9E<D5N8V]D92==(#T@)&5N8V]D:6YG.PH*("`@("`@("`O*B!)9B!C;VYT
M96YT<R!A<F4@96UP='DL(&]R(&-O;G1E;G1S(&%R92!A;')E861Y(&5N8V]D
M960@=&\@=&AE"B`@("`@("`@("`@8V]R<F5C="!E;F-O9&EN9RP@<F5T=7)N
M(&YO=RX@*B\*("`@("`@("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O;G1E;G1S
M*2!\?`H@("`@("`@("`@("`H)&5N8V]D:6YG(#T]("1T:&ES+3Y?8W5R<F5N
M=$5N8V]D:6YG*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT
M96YT<SL*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)&5N8V]D:6YG*2![
M"B`@("`@("`@+RH@0F%S938T($5N8V]D:6YG.B!3964@4D9#(#(P-#4L('-E
M8W1I;VX@-BXX("HO"B`@("`@("`@8V%S92`G8F%S938T)SH*("`@("`@("`@
M("`@+RH@2V5E<&EN9R!T:&5S92!T=V\@;&EN97,@<V5P87)A=&4@<V5E;7,@
M=&\@=7-E(&UU8V@@;&5S<PH@("`@("`@("`@("`@("!M96UO<GD@=&AA;B!C
M;VUB:6YI;F<@=&AE;2`H87,@;V8@4$A0(#0N,RDN("HO"B`@("`@("`@("`@
M("1E;F-O9&5D7V-O;G1E;G1S(#T@8F%S938T7V5N8V]D92@D=&AI<RT^7V-O
M;G1E;G1S*3L*("`@("`@("`@("`@<F5T=7)N(&-H=6YK7W-P;&ET*"1E;F-O
M9&5D7V-O;G1E;G1S+"`W-BP@)&5O;"D["@H@("`@("`@("\J(%%U;W1E9"U0
M<FEN=&%B;&4@16YC;V1I;F<Z(%-E92!21D,@,C`T-2P@<V5C=&EO;B`V+C<@
M*B\*("`@("`@("!C87-E("=Q=6]T960M<')I;G1A8FQE)SH*("`@("`@("`@
M("`@)&]U='!U="`]($U)344Z.G%U;W1E9%!R:6YT86)L945N8V]D92@D=&AI
M<RT^7V-O;G1E;G1S+"`D96]L*3L*("`@("`@("`@("`@:68@*"@D96]L;&5N
M9W1H(#T@4W1R:6YG.CIL96YG=&@H)&5O;"DI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@<W5B<W1R*"1O=71P=70L(#`L("1E;VQL96YG=&@@*B`M,2D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&]U='!U=#L*("`@("`@("`@("`@?0H*("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)E<&QA8V5%3TPH)'1H:7,M/E]C;VYT
M96YT<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5C;V1E
M<R!T:&4@8V]N=&5N=',@;V8@=&AE('!A<G0@=&\@96ET:&5R(&$@-V)I="!O
M<B`X8FET(&5N8V]D:6YG+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@9&5C;V1E9"!T97AT+@H@("`@("H@("`@("`@("`@("`@("`@(%)E
M='5R;G,@=&AE(&5M<'1Y('-T<FEN9R!I9B!T:&5R92!I<R!N;R!T97AT('1O
M(&1E8V]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@=')A;G-F97)$96-O9&4H
M*0H@("`@>PH@("`@("`@("1E;F-O9&EN9R`]("1T:&ES+3YG971#=7)R96YT
M16YC;V1I;F<H*3L*"B`@("`@("`@+RH@268@=&AE(&-O;G1E;G1S(&%R92!E
M;7!T>2P@<F5T=7)N(&YO=RX@*B\*("`@("`@("!I9B`H(7-T<FQE;B@D=&AI
M<RT^7V-O;G1E;G1S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=L
M87-T5')A;G-F97)$96-O9&4G72`]("1E;F-O9&EN9SL*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?8V]N=&5N=',["B`@("`@("`@?0H*("`@("`@("!S
M=VET8V@@*"1E;F-O9&EN9RD@>PH@("`@("`@(&-A<V4@)V)A<V4V-"<Z"B`@
M("`@("`@("`@("1M97-S86=E(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V-O
M;G1E;G1S*3L*("`@("`@("`@("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS
M9F5R1&5C;V1E)UT@/2`G.&)I="<["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E("=Q=6]T960M<')I;G1A8FQE)SH*("`@("`@("`@("`@)&UE
M<W-A9V4@/2!P<F5G7W)E<&QA8V4H(B\]7'(_7&XO(BP@)R<L("1T:&ES+3Y?
M8V]N=&5N=',I.PH@("`@("`@("`@("`D;65S<V%G92`]("1T:&ES+3YR97!L
M86-E14],*"1M97-S86=E*3L*("`@("`@("`@("`@)&UE<W-A9V4@/2!Q=6]T
M961?<')I;G1A8FQE7V1E8V]D92@D;65S<V%G92D["B`@("`@("`@("`@("1T
M:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==(#T@*$U)344Z.FES
M.&)I="@D;65S<V%G92DI(#\@)SAB:70G(#H@)S=B:70G.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@+RH@4W5P<&]R="!F;W(@=75E;F-O9&5D(&5N
M8V]D:6YG("T@86QT:&]U9V@@;F]T(')E<75I<F5D(&)Y(%)&0W,L"B`@("`@
M("`@("`@<V]M92!M86EL97)S(&UA>2!S=&EL;"!E;F-O9&4@=&AI<R!W87DN
M("HO"B`@("`@("`@8V%S92`G=75E;F-O9&4G.@H@("`@("`@(&-A<V4@)W@M
M=75E;F-O9&4G.@H@("`@("`@(&-A<V4@)W@M=75E)SH*("`@("`@("`@("`@
M:68@*&9U;F-T:6]N7V5X:7-T<R@G8V]N=F5R=%]U=61E8V]D92<I*2!["B`@
M("`@("`@("`@("`@("`D;65S<V%G92`](&-O;G9E<G1?=75E;F-O9&4H)'1H
M:7,M/E]C;VYT96YT<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PH@
M("`@("`@("`@("`@("`@)&9I;&5S(#T@)DUA:6Q?;6EM941E8V]D93HZ=75D
M96-O9&4H)'1H:7,M/E]C;VYT96YT<RD["B`@("`@("`@("`@("`@("`D;65S
M<V%G92`]("1F:6QE<ULP75LG9FEL961A=&$G73L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G
M.PH@("`@("`@("`@("`D9FEL97,@/2`F36%I;%]M:6UE1&5C;V1E.CIU=61E
M8V]D92@D=&AI<RT^7V-O;G1E;G1S*3L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2`D9FEL97-;,%U;)V9I;&5D871A)UT["B`@("`@("`@("`@("1T:&ES+3Y?
M9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==(#T@)SAB:70G.PH@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E<D1E8V]D92==*2`F
M)@H@("`@("`@("`@("`@("`@*"1T:&ES+3Y?9FQA9W-;)VQA<W14<F%N<V9E
M<D1E8V]D92==("$]("1E;F-O9&EN9RDI('L*("`@("`@("`@("`@("`@("1M
M97-S86=E(#T@)'1H:7,M/G)E<&QA8V5%3TPH)'1H:7,M/E]C;VYT96YT<RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;65S<V%G
M92`]("1T:&ES+3Y?8V]N=&5N=',["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]F;&%G<ULG;&%S=%1R86YS9F5R1&5C;V1E)UT@/2`D96YC
M;V1I;F<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1M97-S86=E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W!L:70@
M=&AE(&-O;G1E;G1S(&]F('1H92!C=7)R96YT(%!A<G0@:6YT;R!I=',@<F5S
M<&5C=&EV92!S=6)P87)T<RP*("`@("`J(&EF(&ET(&ES(&UU;'1I<&%R="!-
M24U%(&5N8V]D:6YG+B!5;FQI:V4@=&AE(&EM87!?*B@I(&9U;F-T:6]N<RP@
M=&AI<PH@("`@("H@=VEL;"!P<F5S97)V92!A;&P@34E-12!H96%D97(@:6YF
M;W)M871I;VXN"B`@("`@*@H@("`@("H@5&AE(&)O=6YD87)Y(&-O;G1E;G0M
M='EP92!P87)A;65T97(@;75S="!B92!S970@9F]R('1H:7,@9G5N8W1I;VX@
M=&\*("`@("`J('=O<FL@8V]R<F5C=&QY+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@8V]N=&5N=',@=V5R92!S=6-C97-S
M9G5L;'D@<W!L:70N"B`@("`@*B`@("`@("`@("`@("`@("`@($9A;'-E(&EF
M(&%N>2!E<G)O<B!O8V-U<G)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<W!L
M:71#;VYT96YT<R@I"B`@("!["B`@("`@("`@:68@*"$H)&)O=6YD87)Y(#T@
M)'1H:7,M/F=E=$-O;G1E;G14>7!E4&%R86UE=&5R*"=B;W5N9&%R>2<I*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(7-T<FQE;B@D=&AI<RT^7V-O;G1E;G1S*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D96]L(#T@)'1H
M:7,M/F=E=$5/3"@I.PH@("`@("`@("1R971V86QU92`](&9A;'-E.PH*("`@
M("`@("!F;W)E86-H("AE>'!L;V1E*"1E;VPL("1T:&ES+3Y?8V]N=&5N=',I
M(&%S("1L:6YE*2!["B`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&QI;F4L
M("<M+2<@+B`D8F]U;F1A<GDI.PH@("`@("`@("`@("!I9B`H*"1P;W,@/3T]
M(&9A;'-E*2`F)B!I<W-E="@D<&%R=%]P='(I*2!["B`@("`@("`@("`@("`@
M("`D9&%T85M=(#T@)&QI;F4["B`@("`@("`@("`@('T@96QS96EF("@D<&]S
M(#T]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5T=F%L=64@/2!T<G5E.PH@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T7W!T<BDI('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<G1S6R1P87)T7W!T<ETM/G-E=$-O
M;G1E;G1S*&EM<&QO9&4H)&5O;"P@)&1A=&$I*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<G1S6R1P87)T7W!T<ETM/G-P;&ET0V]N=&5N=',H
M*3L*("`@("`@("`@("`@("`@("`@("!N97AT*"1T:&ES+3Y?<&%R=',I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R
M97-E="@D=&AI<RT^7W!A<G1S*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T82DI('L*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D9&%T82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D9&%T82`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`D<&%R
M=%]P='(@/2!K97DH)'1H:7,M/E]P87)T<RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T=F%L=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!297!L86-E(&YE=VQI;F5S(&EN('1H:7,@<&%R="=S(&-O
M;G1E;G1S('=I=&@@=&AO<V4@<W!E8VEF:65D(&)Y(&5I=&AE<@H@("`@("H@
M=&AE(&=I=F5N(&YE=VQI;F4@<V5Q=65N8V4@;W(@=&AE('!A<G0G<R!C=7)R
M96YT($5/3"!S971T:6YG+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@(%1H92!T97AT('1O(')E<&QA8V4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E;VP@("!4:&4@14],('-E<75E;F-E('1O('5S92X@268@;F]T('!R
M97-E;G0L('5S97,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!P
M87)T)W,@8W5R<F5N="!%3TP@<V5T=&EN9RX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('1E>'0@=VET:"!T:&4@;F5W;&EN97,@<F5P;&%C
M960@8GD@=&AE(&1E<VER960*("`@("`J("`@("`@("`@("`@("`@("!N97=L
M:6YE('-E<75E;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97!L86-E14],
M*"1T97AT+"`D96]L(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D96]L*2D@>PH@("`@("`@("`@("`D96]L(#T@)'1H:7,M/F=E=$5/3"@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"(O7'(_
M7&XO(BP@)&5O;"P@)'1E>'0I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!U;FEQ=64@34E-15]087)T(&)O=6YD87)Y('-T<FEN9R!G96YE
M<F%T960@9F]R('1H:7,@;V)J96-T+@H@("`@("H@5&AI<R!M87D@;F]T(&)E
M('1H92!B;W5N9&%R>2!S=')I;F<@=7-E9"!W:&5N(&)U:6QD:6YG('1H92!M
M97-S86=E"B`@("`@*B!S:6YC92!A('5S97(@9&5F:6YE9"`G8F]U;F1A<GDG
M($-O;G1E;G0M5'EP92!P87)A;65T97(@=VEL;"!O=F5R<FED90H@("`@("H@
M=&AI<R!V86QU92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('5N:7%U92!B;W5N9&%R>2!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%5N:7%U94E$*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B
M;W5N9&%R>3L*("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!T:&4@
M<VEZ92!O9B!A($U)345?4&%R="!A;F0@:71S(&-H:6QD(&UE;6)E<G,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!3:7IE(&]F('1H92!-24U%
M7U!A<G0L(&EN(&)Y=&5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971">71E
M<R@I"B`@("!["B`@("`@("`@)&)Y=&5S(#T@,#L*"B`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3Y?9FQA9W-;)V-O;G1E;G1S4V5T)UTI("8F("1T:&ES+3Y?
M8GET97,I('L*("`@("`@("`@("`@)&)Y=&5S(#T@)'1H:7,M/E]B>71E<SL*
M("`@("`@("!](&5L<V5I9B`H)'1H:7,M/F=E=%!R:6UA<GE4>7!E*"D@/3T@
M)VUU;'1I<&%R="<I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F=E
M=%!A<G1S*"D@87,@)'!A<G0I('L*("`@("`@("`@("`@("`@("\J(%-K:7`@
M;75L=&EP87)T(&5N=')I97,@*'-I;F-E('1H:7,@;6%Y(')E<W5L="!I;B!D
M;W5B;&4*("`@("`@("`@("`@("`@("`@(&-O=6YT:6YG*2X@*B\*("`@("`@
M("`@("`@("`@(&EF("@D<&%R="T^9V5T4')I;6%R>51Y<&4H*2`A/2`G;75L
M=&EP87)T)RD@>PH@("`@("`@("`@("`@("`@("`@("1B>71E<R`K/2`D<&%R
M="T^9V5T0GET97,H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T
M4')I;6%R>51Y<&4H*2`]/2`G=&5X="<I('L*("`@("`@("`@("`@("`@("1B
M>71E<R`](%-T<FEN9SHZ;&5N9W1H*"1T:&ES+3Y?8V]N=&5N=',L("1T:&ES
M+3YG971#:&%R<V5T*"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&)Y=&5S(#T@<W1R;&5N*"1T:&ES+3Y?8V]N=&5N=',I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&)Y=&5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@17AP;&EC:71L>2!S970@=&AE('-I
M>F4@*&EN(&)Y=&5S*2!O9B!T:&ES('!A<G0N(%1H:7,@=F%L=64@=VEL;"!O
M;FQY"B`@("`@*B!B92!R971U<FYE9"`H=FEA(&=E=$)Y=&5S*"DI(&EF('1H
M97)E(&%R92!N;R!C;VYT96YT<R!C=7)R96YT;'D@<V5T+@H@("`@("H@5&AI
M<R!F=6YC=&EO;B!I<R!U<V5F=6P@9F]R('-E='1I;F<@=&AE('-I>F4@;V8@
M=&AE('!A<G0@=VAE;B!T:&4*("`@("`J(&-O;G1E;G1S(&]F('1H92!P87)T
M(&%R92!N;W0@9G5L;'D@;&]A9&5D("AI+F4N(&-R96%T:6YG(&$@34E-15]0
M87)T"B`@("`@*B!O8FIE8W0@9G)O;2!)34%0(&AE861E<B!I;F9O<FUA=&EO
M;B!W:71H;W5T(&QO861I;F<@=&AE(&1A=&$@;V8@=&AE"B`@("`@*B!P87)T
M*2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8GET97,@(%1H92!S
M:7IE(&]F('1H:7,@<&%R="!I;B!B>71E<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T0GET97,H)&)Y=&5S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8GET
M97,@/2`D8GET97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=70@=&AE
M('-I>F4@;V8@=&AI<R!-24U%7U!A<G0@:6X@2T(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%-I>F4@;V8@=&AE($U)345?4&%R="P@:6X@<W1R
M:6YG(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VEZ92@I"B`@
M("!["B`@("`@("`@)&)Y=&5S(#T@)'1H:7,M/F=E=$)Y=&5S*"D["B`@("`@
M("`@:68@*&5M<'1Y*"1B>71E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1B
M>71E<SL*("`@("`@("!]"@H@("`@("`@("1L;V-A;&5I;F9O(#T@3DQ3.CIG
M971,;V-A;&5);F9O*"D["B`@("`@("`@<F5T=7)N(&YU;6)E<E]F;W)M870H
M)&)Y=&5S("\@,3`R-"P@,BP@)&QO8V%L96EN9F];)V1E8VEM86Q?<&]I;G0G
M72P@)&QO8V%L96EN9F];)W1H;W5S86YD<U]S97`G72D["B`@("`@?0H*("`@
M("\J*@H@("`@("H@061D('1O('1H92!L:7-T(&]F($-)1',@9F]R('1H:7,@
M<&%R="X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&-I9',@($$@;&ES
M="!O9B!-24U%($E$<R!O9B!T:&4@<&%R="X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@2V5Y("T@34E-12!)1`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!686QU92`M($-)1"!F;W(@=&AE('!A<G0*("`@("`J+PH@("`@9G5N
M8W1I;VX@861D0TE$*"1C:61S(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M=&AI<RT^7V-I9',@*ST@)&-I9',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!L:7-T(&]F($-)1',@9F]R('1H:7,@<&%R="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@;&ES="!O9B!#241S(&9O<B!T
M:&ES('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-)1$QI<W0H*0H@
M("`@>PH@("`@("`@(&%S;W)T*"1T:&ES+3Y?8VED<RP@4T]25%]35%))3D<I
M.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V-I9',["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!#;VYT96YT+4E$(&AE861E<B!F;W(@=&AI<R!P
M87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-I9"`@57-E('1H
M:7,@0TE$("AI9B!N;W0@86QR96%D>2!S970I+B`@16QS92P@9V5N97)A=&4@
M80H@("`@("H@("`@("`@("`@("`@("`@("`@("!R86YD;VT@0TE$+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971#;VYT96YT240H)&-I9"`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)'1H:7,M/E]C;VYT96YT:60I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=&ED(#T@*&ES7VYU;&PH)&-I
M9"DI(#\@*&)A<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@,3`L(#,V*2`N("=`
M)R`N("1?4T525D526R=315)615)?3D%-12==*2`Z("1C:60["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^7V-O;G1E;G1I9#L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE($-O;G1E;G0M240@9F]R('1H:7,@
M<&%R="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($-O;G1E
M;G0M240@9F]R('1H:7,@<&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M0V]N=&5N=$E$*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT
M96YT:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!;'1E<B!T:&4@34E-12!)
M1"!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;6EM96ED("!4:&4@34E-12!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M34E-14ED*"1M:6UE:60I"B`@("!["B`@("`@("`@)'1H:7,M/E]M:6UE:60@
M/2`D;6EM96ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M34E-12!)1"!O9B!T:&ES('!A<G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!-24U%($E$+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-
M24U%260H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUI;65I9#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(')E;&%T:79E($U)
M344@240@;V8@=&AI<R!P87)T+@H@("`@("H@92YG+BP@:68@=&AE(&)A<V4@
M<&%R="!H87,@34E-12!)1"!O9B`R+"!A;F0@>6]U('=A;G0@=&AE(&9I<G-T
M"B`@("`@*B!S=6)P87)T(&]F('1H92!B87-E('!A<G0L('1H92!R96QA=&EV
M92!-24U%($E$(&ES(#(N,2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9"`@5&AE(')E;&%T:79E('!A<G0@240N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!R96QA=&EV92!-24U%($E$+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971296QA=&EV94U)345)9"@D:60I"B`@("!["B`@("`@
M("`@)')E;"`]("1T:&ES+3YG971-24U%260H*3L*("`@("`@("!R971U<FX@
M*&5M<'1Y*"1R96PI*2`_("1I9"`Z("1R96P@+B`G+B<@+B`D:60["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;6%P<&EN9R!O9B!A;&P@34E-
M12!)1',@=&\@=&AE:7(@8V]N=&5N="UT>7!E<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!+15DZ($U)344@240L(%9!3%5%.B!#;VYT96YT('1Y
M<&4*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=&5N=%1Y<&5-87`H*0H@("`@
M>PH@("`@("`@("1M87`@/2!A<G)A>2@D=&AI<RT^9V5T34E-14ED*"D@/3X@
M)'1H:7,M/F=E=%1Y<&4H*2D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P
M87)T<R!A<R`D=F%L*2!["B`@("`@("`@("`@("1M87`@*ST@)'9A;"T^8V]N
M=&5N=%1Y<&5-87`H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1M87`[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@=6YI<75E(&)O
M=6YD87)Y('-T<FEN9R`H:68@;F]T(&%L<F5A9'D@9&]N92DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!B;W5N9&%R>2!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G96YE<F%T94)O=6YD87)Y*"D*("`@('L*("`@("`@("!I9B`H:7-?
M;G5L;"@D=&AI<RT^7V)O=6YD87)Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V)O=6YD87)Y(#T@)SU?)R`N(&)A<V5?8V]N=F5R="AM:6-R;W1I;64H*2P@
M,3`L(#,V*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8F]U
M;F1A<GD["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+TUA9VEC+G!H<```````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#4V-2`Q,#4Q-30S-#$S-R`P
M,C$V,S4`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7TUA9VEC.CH@8VQA<W,@<')O=FED
M97,@86X@:6YT97)F86-E('1O(&1E=&5R;6EN92!A"B`J($U)344@='EP92!F
M;W(@=F%R:6]U<R!C;VYT96YT+"!I9B!I="!P<F]V:61E9"!W:71H(&1I9F9E
M<F5N=`H@*B!L979E;',@;V8@:6YF;W)M871I;VXN"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+TU)344O34E-12]-86=I8RYP:'`L=B`Q+C4R+C@N,3(@,C`P
M-B\P,2\P,2`R,3HR.#HR-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y
M.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R
M>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J
M($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7TU)344*("HO"F-L87-S($U)345?36%G:6,@>PH*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!A(&-O<'D@;V8@=&AE($U)344@97AT96YS:6]N(&UA
M<"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!4:&4@34E-12!E>'1E;G-I;VX@;6%P+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F7V=E=$UI;65%>'1E;G-I;VY-87`H*0H@("`@
M>PH@("`@("`@('-T871I8R`D;6EM95]E>'1E;G-I;VY?;6%P.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1M:6UE7V5X=&5N<VEO;E]M87`I*2!["B`@("`@("`@
M("`@(')E<75I<F4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+VUI;64N;6%P<&EN
M9RYP:'`G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M:6UE7V5X=&5N
M<VEO;E]M87`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@8V]P
M>2!O9B!T:&4@34E-12!M86=I8R!F:6QE+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!-
M24U%(&UA9VEC(&9I;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9V5T36EM
M94UA9VEC1FEL92@I"B`@("!["B`@("`@("`@<W1A=&EC("1M:6UE7VUA9VEC
M.PH*("`@("`@("!I9B`H(6ES<V5T*"1M:6UE7VUA9VEC*2D@>PH@("`@("`@
M("`@("!R97%U:7)E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]M:6UE+FUA9VEC
M+G!H<"<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UI;65?;6%G:6,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O;G9E<G0@82!F
M:6QE(&5X=&5N<VEO;B!T;R!A($U)344@='EP92P@8F%S960*("`@("`J(&]N
M('1H92!G;&]B86P@2&]R9&4@86YD(&%P<&QI8V%T:6]N('-P96-I9FEC(&-O
M;F9I9R!F:6QE<RX*("`@("`J"B`@("`@*B!)9B!W92!C86YN;W0@;6%P('1H
M92!F:6QE(&5X=&5N<VEO;B!T;R!A('-P96-I9FEC('1Y<&4L('1H96X*("`@
M("`J('=E(&9A;&P@8F%C:R!T;R!A(&-U<W1O;2!-24U%(&AA;F1L97(@)W@M
M97AT96YS:6]N+R1E>'0G+"!W:&EC:`H@("`@("H@8V%N(&)E('5S960@87,@
M82!N;W)M86P@34E-12!T>7!E(&EN=&5R;F%L;'D@=&AR;W5G:&]U="!(;W)D
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E>'0@(%1H92!F:6QE
M(&5X=&5N<VEO;B!T;R!B92!M87!P960@=&\@82!-24U%('1Y<&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!-24U%('1Y<&4@;V8@=&AE
M(&9I;&4@97AT96YS:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'14;TU)
M344H)&5X="D*("`@('L*("`@("`@("!I9B`H96UP='DH)&5X="DI('L*("`@
M("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5X="`](%-T<FEN9SHZ;&]W
M97(H)&5X="D["B`@("`@("`@("`@("1M87`@/2`F34E-15]-86=I8SHZ7V=E
M=$UI;65%>'1E;G-I;VY-87`H*3L*("`@("`@("`@("`@)'!O<R`](#`["B`@
M("`@("`@("`@('=H:6QE("@A:7-S970H)&UA<%LD97AT72D@)B8@)'!O<R`A
M/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)&5X
M="P@)RXG*3L*("`@("`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@("`@("1E>'0@/2!S=6)S='(H)&5X="P@)'!O
M<R`K(#$I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H:7-S970H)&UA<%LD97AT72DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D;6%P6R1E>'1=.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("=X+65X=&5N<VEO;B\G("X@)&5X=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%T=&5M<'0@=&\@8V]N=F5R="!A(&9I;&5N86UE('1O(&$@34E-12!T>7!E
M+"!B87-E9"!O;B!T:&4@9VQO8F%L($AO<F1E"B`@("`@*B!A;F0@87!P;&EC
M871I;VX@<W!E8VEF:6,@8V]N9FEG(&9I;&5S+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@9FEL96YA;64@=&\@8F4@;6%P
M<&5D('1O(&$@34E-12!T>7!E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5N
M:VYO=VX@($AO=R!S:&]U;&0@=6YK;F]W;B!E>'1E;G-I;VYS(&)E(&AA;F1L
M960_($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92P@
M=VEL;"!R971U<FX@)W@M97AT96YS:6]N+RHG('1Y<&5S+B`@268*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@=VEL;"!R971U<FX@
M)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@(%1H92!-24U%('1Y<&4@;V8@=&AE(&9I;&5N86UE+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!F:6QE;F%M951O34E-12@D9FEL96YA;64L
M("1U;FMN;W=N(#T@=')U92D*("`@('L*("`@("`@("`D<&]S(#T@<W1R;&5N
M*"1F:6QE;F%M92D@*R`Q.PH@("`@("`@("1T>7!E(#T@)R<["@H@("`@("`@
M("1M87`@/2`F34E-15]-86=I8SHZ7V=E=$UI;65%>'1E;G-I;VY-87`H*3L*
M("`@("`@("!F;W(@*"1I(#T@,#L*("`@("`@("`@("`@("1I(#P]("1M87!;
M)U]?34%84$5224]$7U\G72`F)@H@("`@("`@("`@("`@("`@('-T<G)P;W,H
M<W5B<W1R*"1F:6QE;F%M92P@,"P@)'!O<R`M(#$I+"`G+B<I("$]/2!F86QS
M93L*("`@("`@("`@("`@("1I*RLI('L*("`@("`@("`@("`@)'!O<R`]('-T
M<G)P;W,H<W5B<W1R*"1F:6QE;F%M92P@,"P@)'!O<R`M(#$I+"`G+B<I("L@
M,3L*("`@("`@("!]"B`@("`@("`@)'1Y<&4@/2!-24U%7TUA9VEC.CIE>'14
M;TU)344H<W5B<W1R*"1F:6QE;F%M92P@)'!O<RDI.PH*("`@("`@("!I9B`H
M96UP='DH)'1Y<&4I('Q\"B`@("`@("`@("`@("@A)'5N:VYO=VX@)B8@*'-T
M<G!O<R@D='EP92P@)W@M97AT96YS:6]N)RD@(3T](&9A;'-E*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D='EP93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T('1O(&-O;G9E
M<G0@82!-24U%('1Y<&4@=&\@82!F:6QE(&5X=&5N<VEO;BP@8F%S960*("`@
M("`J(&]N('1H92!G;&]B86P@2&]R9&4@86YD(&%P<&QI8V%T:6]N('-P96-I
M9FEC(&-O;F9I9R!F:6QE<RX*("`@("`J"B`@("`@*B!)9B!W92!C86YN;W0@
M;6%P('1H92!T>7!E('1O(&$@9FEL92!E>'1E;G-I;VXL('=E(')E='5R;B!F
M86QS92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4:&4@
M34E-12!T>7!E('1O(&)E(&UA<'!E9"!T;R!A(&9I;&4@97AT96YS:6]N+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!E>'1E;G-I
M;VX@;V8@=&AE($U)344@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@34E-
M151O17AT*"1T>7!E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D='EP92DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)&ME>2`](&%R<F%Y7W-E87)C:"@D='EP92P@34E-15]-86=I8SHZ7V=E
M=$UI;65%>'1E;G-I;VY-87`H*2D["B`@("`@("`@:68@*"1K97D@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@(&QI<W0H)&UA:F]R+"`D;6EN;W(I(#T@97AP
M;&]D92@G+R<L("1T>7!E*3L*("`@("`@("`@("`@:68@*"1M86IO<B`]/2`G
M>"UE>'1E;G-I;VXG*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&UI;F]R
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')P;W,H)&UI;F]R
M+"`G>"TG*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N('-U8G-T
M<B@D;6EN;W(L(#(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M)&ME>3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<V5S('9A
M<FEA;G1S(&]F('1H92!53DE8(")F:6QE(B!C;VUM86YD('1O(&%T=&5M<'0@
M=&\@9&5T97)M:6YE('1H90H@("`@("H@34E-12!T>7!E(&]F(&%N('5N:VYO
M=VX@9FEL92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@
M("`@5&AE('!A=&@@=&\@=&AE(&9I;&4@=&\@86YA;'EZ92X*("`@("`J($!P
M87)A;2!S=')I;F<@)&UA9VEC7V1B("!0871H('1O('1H92!M:6UE(&UA9VEC
M(&1A=&%B87-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M34E-12!T>7!E(&]F('1H92!F:6QE+B`@4F5T=7)N<R!F86QS92!I9B!T:&4@
M9FEL90H@("`@("H@("`@("`@("`@("`@("`@('1Y<&4@:7-N)W0@<F5C;V=N
M:7IE9"!O<B!A;B!E<G)O<B!H87!P96YE9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@86YA;'EZ949I;&4H)'!A=&@L("1M86=I8U]D8B`](&YU;&PI"B`@("![
M"B`@("`@("`@+RH@268@=&AE(%!(4"!-:6UE='EP92!E>'1E;G-I;VX@:7,@
M879A:6QA8FQE+"!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H571I;#HZ97AT
M96YS:6]N17AI<W1S*"=F:6QE:6YF;R<I*2!["B`@("`@("`@("`@(&EF("AE
M;7!T>2@D;6%G:6-?9&(I*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@0&9I
M;F9O7V]P96XH1DE,14E.1D]?34E-12D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<F5S(#T@0&9I;F9O7V]P96XH1DE,14E.1D]?
M34E-12P@)&UA9VEC7V1B*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)')E<RD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2!F:6YF;U]F:6QE
M*"1R97,L("1P871H*3L*("`@("`@("`@("`@("`@(&9I;F9O7V-L;W-E*"1R
M97,I.PH*("`@("`@("`@("`@("`@("\J(%)E;6]V92!A;GD@861D:71I;VYA
M;"!I;F9O<FUA=&EO;BX@*B\*("`@("`@("`@("`@("`@(&9O<F5A8V@@*&%R
M<F%Y*"<[)RP@)RPG+"`G7%PP)RD@87,@)'-E<&%R871O<BD@>PH@("`@("`@
M("`@("`@("`@("`@("1P;W,@/2!S=')P;W,H)'1Y<&4L("1S97!A<F%T;W(I
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D='EP92`](')T<FEM*'-U8G-T<B@D
M='EP92P@,"P@)'!O<RDI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M?%Y;82UZ,"TY72LO6RXM82UZ,"TY72LD?&DG+"`D='EP92DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("A5=&EL.CIE
M>'1E;G-I;VY%>&ES=',H)VUI;65?;6%G:6,G*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')I;2AM:6UE7V-O;G1E;G1?='EP92@D<&%T:"DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\J(%5S92!A(&)U:6QT+6EN(&UA9VEC
M(&9I;&4N("HO"B`@("`@("`@("`@("1M:6UE7VUA9VEC(#T@)DU)345?36%G
M:6,Z.E]G971-:6UE36%G:6-&:6QE*"D["B`@("`@("`@("`@(&EF("@A*"1F
M<"`]($!F;W!E;B@D<&%T:"P@)W)B)RDI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@9F]R96%C
M:"`H)&UI;65?;6%G:6,@87,@)&]F9G-E="`]/B`D;V1A=&$I('L*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1O9&%T82!A<R`D;&5N9W1H(#T^("1L9&%T
M82D@>PH@("`@("`@("`@("`@("`@("`@($!F<V5E:R@D9G`L("1O9F9S970L
M(%-%14M?4T54*3L*("`@("`@("`@("`@("`@("`@("`D;&]O:W5P(#T@0&9R
M96%D*"1F<"P@)&QE;F=T:"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;&1A=&%;)&QO;VMU<%TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&QD871A6R1L;V]K=7!=.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"@H@("`@+RHJ"B`@("`@*B!5<V5S('9A<FEA;G1S(&]F('1H92!53DE8
M(")F:6QE(B!C;VUM86YD('1O(&%T=&5M<'0@=&\@9&5T97)M:6YE('1H90H@
M("`@("H@34E-12!T>7!E(&]F(&%N('5N:VYO=VX@8GET92!S=')E86TN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@(%1H92!F:6QE
M(&1A=&$@=&\@86YA;'EZ92X*("`@("`J($!P87)A;2!S=')I;F<@)&UA9VEC
M7V1B("!0871H('1O('1H92!M:6UE(&UA9VEC(&1A=&%B87-E+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@34E-12!T>7!E(&]F('1H92!F
M:6QE+B`@4F5T=7)N<R!F86QS92!I9B!T:&4@9FEL90H@("`@("H@("`@("`@
M("`@("`@("`@('1Y<&4@:7-N)W0@<F5C;V=N:7IE9"!O<B!A;B!E<G)O<B!H
M87!P96YE9"X*("`@("`J+PH@("`@9G5N8W1I;VX@86YA;'EZ941A=&$H)&1A
M=&$L("1M86=I8U]D8B`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@=&AE
M(%!(4"!-:6UE='EP92!E>'1E;G-I;VX@:7,@879A:6QA8FQE+"!U<V4@=&AA
M="X@*B\*("`@("`@("!I9B`H571I;#HZ97AT96YS:6]N17AI<W1S*"=F:6QE
M:6YF;R<I*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D;6%G:6-?9&(I*2![
M"B`@("`@("`@("`@("`@("`D<F5S(#T@0&9I;F9O7V]P96XH1DE,14E.1D]?
M34E-12D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<F5S(#T@0&9I;F9O7V]P96XH1DE,14E.1D]?34E-12P@)&UA9VEC7V1B*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(21R97,I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1Y<&4@/2!F:6YF;U]B=69F97(H)')E<RP@)&1A=&$I.PH@("`@
M("`@("`@("!F:6YF;U]C;&]S92@D<F5S*3L*"B`@("`@("`@("`@("\J(%)E
M;6]V92!A;GD@861D:71I;VYA;"!I;F9O<FUA=&EO;BX@*B\*("`@("`@("`@
M("`@)'!O<R`]('-T<G!O<R@D='EP92P@)SLG*3L*("`@("`@("`@("`@:68@
M*"1P;W,@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`D='EP92`](')T
M<FEM*'-U8G-T<B@D='EP92P@,"P@)'!O<RDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1P;W,@/2!S=')P;W,H)'1Y<&4L("<L)RD["B`@("`@("`@
M("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1Y
M<&4@/2!R=')I;2AS=6)S='(H)'1Y<&4L(#`L("1P;W,I*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!R971U<FX@)'1Y<&4["B`@("`@("`@?0H*("`@
M("`@("`O*B!5<V4@82!B=6EL="UI;B!M86=I8R!F:6QE+B`J+PH@("`@("`@
M("1M:6UE7VUA9VEC(#T@)DU)345?36%G:6,Z.E]G971-:6UE36%G:6-&:6QE
M*"D["B`@("`@("`@9F]R96%C:"`H)&UI;65?;6%G:6,@87,@)&]F9G-E="`]
M/B`D;V1A=&$I('L*("`@("`@("`@("`@9F]R96%C:"`H)&]D871A(&%S("1L
M96YG=&@@/3X@)&QD871A*2!["B`@("`@("`@("`@("`@("`D;&]O:W5P(#T@
M<W5B<W1R*"1D871A+"`D;V9F<V5T+"`D;&5N9W1H*3L*("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)&QD871A6R1L;V]K=7!=*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D;&1A=&%;)&QO;VMU<%T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]-24U%+TU$3BYP:'``````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`R,C<S,B`Q,#4Q-30S-#$S-R`P,C$R,S$`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H92!-24U%7TU$3CHZ(&-L87-S(&EM<&QE;65N=',@365S<V%G
M92!$:7-P;W-I=&EO;B!.;W1I9FEC871I;VYS(&%S"B`J(&1E<V-R:6)E9"!B
M>2!21D,@,C(Y."X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%
M+TU$3BYP:'`L=B`Q+C0N,3`N."`R,#`V+S`Q+S(T(#(Q.C,R.C4V('-L=7-A
M<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`8W5R96-A;G1I+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N
M=&DN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R
M9&5?34E-10H@*B\*8VQA<W,@34E-15]-1$X@>PH*("`@("\J*@H@("`@("H@
M5&AE($U)345?2&5A9&5R<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!-
M24U%7TAE861E<G,*("`@("`J+PH@("`@=F%R("1?:&5A9&5R<SL*"B`@("`O
M*BH*("`@("`J(%1H92!T97AT(&]F('1H92!O<FEG:6YA;"!M97-S86=E+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VUS
M9W1E>'0@/2!F86QS93L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!P87)A;2!-24U%7TAE861E<G,@)&UI;65?:&5A9&5R
M<R`@02!-24U%7TAE861E<G,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!-24U%7TU$3B@D;6EM95]H96%D97)S(#T@;G5L;"D*("`@('L*("`@("`@
M("`D=&AI<RT^7VAE861E<G,@/2`D;6EM95]H96%D97)S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@861D<F5S<R!T;R!R971U<FX@=&AE
M($U$3B!T;RX*("`@("`J(%)E='5R;G,@;G5L;"!I9B!N;R!-1$X@:7,@<F5Q
M=65S=&5D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@861D
M<F5S<R!T;R!S96YD('1H92!-1$X@=&\N(%)E='5R;G,@;G5L;"!I9B!N;PH@
M("`@("H@("`@("`@("`@("`@("`@($U$3B!I<R!R97%U97-T960N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$U$3E)E='5R;D%D9'(H*0H@("`@>PH@("`@
M("`@("\J(%)&0R`R,CDX(%LR+C%=(')E<75I<F5S('1H92!$:7-P;W-I=&EO
M;BU.;W1I9FEC86EO;BU4;R!H96%D97(*("`@("`@("`@*B!F;W(@86X@341.
M('1O(&)E(&-R96%T960N("HO"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:&5A
M9&5R<RT^9V5T5F%L=64H)T1I<W!O<VET:6]N+4YO=&EF:6-A=&EO;BU4;R<I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=7-E<B!I;G!U="!R97%U:7)E
M9"!T;R!S96YD('1H92!-1$X_"B`@("`@*B!%>'!L:6-I="!C;VYF:7)M871I
M;VX@:7,@;F5E9&5D(&EN('-O;64@8V%S97,@=&\@<')E=F5N="!M86EL(&QO
M;W!S"B`@("`@*B!A;F0@=&AE('5S92!O9B!-1$YS(&9O<B!M86EL(&)O;6)I
M;F<N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!)<R!E>'!L:6-I
M="!U<V5R(&EN<'5T(')E<75I<F5D('1O('-E;F0@=&AE($U$3C\*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7-E<D-O;F9I<FUA=&EO;DYE961E9"@I"B`@("![
M"B`@("`@("`@)')E='5R;E]P871H(#T@)'1H:7,M/E]H96%D97)S+3YG9716
M86QU92@G4F5T=7)N+5!A=&@G*3L*"B`@("`@("`@+RH@4D9#(#(R.3@@6S(N
M,5TZ($5X<&QI8VET(&-O;F9I<FUA=&EO;B!I<R!N965D960@:68@=&AE<F4@
M:7,@;F\*("`@("`@("`@*B!2971U<FXM4&%T:"!I;B!T:&4@:&5A9&5R+B!!
M;'-O+"`B:68@=&AE(&UE<W-A9V4@8V]N=&%I;G,@;6]R90H@("`@("`@("`J
M('1H86X@;VYE(%)E='5R;BU0871H(&AE861E<BP@=&AE(&EM<&QE;65N=&%T
M:6]N(&UA>2!;72!T<F5A="!T:&4*("`@("`@("`@*B!S:71U871I;VX@87,@
M82!F86EL=7)E(&]F('1H92!C;VUP87)I<V]N+B`J+PH@("`@("`@(&EF("AE
M;7!T>2@D<F5T=7)N7W!A=&@I('Q\(&ES7V%R<F%Y*"1R971U<FY?<&%T:"DI
M('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@
M("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@)'!A
M<G-E<B`]("9N97<@36%I;%]21D,X,C(H*3L*"B`@("`@("`@+RH@4D9#(#(R
M.3@@6S(N,5TZ($5X<&QI8VET(&-O;F9I<FUA=&EO;B!I<R!N965D960@:68@
M=&AE<F4@:7,@;6]R90H@("`@("`@("`J('1H86X@;VYE(&1I<W1I;F-T(&%D
M9')E<W,@:6X@=&AE($1I<W!O<VET:6]N+4YO=&EF:6-A=&EO;BU4;PH@("`@
M("`@("`J(&AE861E<BX@*B\*("`@("`@("`D861D<E]A<G(@/2`D<&%R<V5R
M+3YP87)S94%D9')E<W-,:7-T*"1T:&ES+3YG971-1$Y2971U<FY!9&1R*"DL
M(&YU;&PL(&YU;&PL(&9A;'-E*3L*("`@("`@("!I9B`H:7-?82@D861D<E]A
M<G(L("=014%27T5R<F]R)RD@?'P@*&-O=6YT*"1A9&1R7V%R<BD@/B`Q*2D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M("\J(%)&0R`R,CDX(%LR+C%=('-T871E<R!T:&%T(")-1$YS(%-(3U5,1"!.
M3U0@8F4@<V5N="!A=71O;6%T:6-A;&QY"B`@("`@("`@("H@:68@=&AE(&%D
M9')E<W,@:6X@=&AE($1I<W!O<VET:6]N+4YO=&EF:6-A=&EO;BU4;R!H96%D
M97(@9&EF9F5R<PH@("`@("`@("`J(&9R;VT@=&AE(&%D9')E<W,@:6X@=&AE
M(%)E='5R;BU0871H(&AE861E<BXB(%1H:7,@8V]M<&%R:7-O;B!I<PH@("`@
M("`@("`J(&-A<V4M<V5N<VET:79E(&9O<B!T:&4@;6%I;&)O>"!P87)T(&%N
M9"!C87-E+6EN<V5N<VET:79E(&9O<B!T:&4*("`@("`@("`@*B!H;W-T('!A
M<G0N("HO"B`@("`@("`@)')E=%]A<G(@/2`D<&%R<V5R+3YP87)S94%D9')E
M<W-,:7-T*"1R971U<FY?<&%T:"P@;G5L;"P@;G5L;"P@9F%L<V4I.PH@("`@
M("`@(&EF("@A:7-?82@D<F5T7V%R<BP@)U!%05)?17)R;W(G*2`F)@H@("`@
M("`@("`@("`H*"1A9&1R7V%R<ELP72T^;6%I;&)O>"`A/2`D<F5T7V%R<ELP
M72T^;6%I;&)O>"D@?'P*("`@("`@("`@("`@*%-T<FEN9SHZ;&]W97(H)&%D
M9')?87)R6S!=+3YH;W-T*2`A/2!3=')I;F<Z.FQO=V5R*"1R971?87)R6S!=
M+3YH;W-T*2DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5VAE;B!G96YE<F%T:6YG('1H92!-1$XL('-H;W5L9"!W92!R971U<FX@
M=&AE(&5N:71R92!T97AT(&]F('1H90H@("`@("H@;W)I9VEN86P@;65S<V%G
M93\@(%1H92!D969A=6QT(&ES(&YO("T@=V4@;VYL>2!R971U<FX@=&AE(&AE
M861E<G,@;V8*("`@("`J('1H92!O<FEG:6YA;"!M97-S86=E+B!)9B!T:&4@
M=&5X="!I<R!P87-S960@:6X@=FEA('1H:7,@;65T:&]D+"!W90H@("`@("H@
M=VEL;"!R971U<FX@=&AE(&5N=&ER92!M97-S86=E+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%1H92!T97AT(&]F('1H92!O<FEG:6YA
M;"!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<FEG:6YA;$UE<W-A
M9V5497AT*"1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;7-G=&5X="`]
M("1T97AT.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5N97)A=&4@=&AE($U$
M3B!A8V-O<F1I;F<@=&\@=&AE('-P96-I9FEC871I;VYS(&QI<W1E9"!I;B!2
M1D,*("`@("`J(#(R.3@@6S-=+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1A8W1I;VX@("!787,@=&AI<R!-1$X@='EP92!A(')E<W5L="!O9B!A
M(&UA;G5A;"!A8W1I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("!O;B!P87)T(&]F('1H92!U<V5R/PH@("`@("H@0'!A<F%M(&)O;VQE86X@
M)'-E;F1I;F<@(%=A<R!T:&ES($U$3B!S96YT(&%S(&$@<F5S=6QT(&]F(&$@
M;6%N=6%L"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@86-T:6]N
M(&]N('!A<G0@;V8@=&AE('5S97(_"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("`@("`@5&AE('1Y<&4@;V8@86-T:6]N('!E<F9O<FUE9"!B>2!T:&4@
M=7-E<BX*("`@("`J(#QP<F4^"B`@("`@*B!097(@4D9#(#(R.3@@6S,N,BXV
M+C)=('1H92!F;VQL;W=I;F<@='EP97,@87)E('9A;&ED.@H@("`@("H@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H@("`@("H@)V1I<W!L87EE9"<*("`@("`J("=D:7-P871C:&5D)PH@
M("`@("H@)W!R;V-E<W-E9"<*("`@("`J("=D96QE=&5D)PH@("`@("H@)V1E
M;FEE9"<*("`@("`J("=F86EL960G"B`@("`@*B`\+W!R93X*("`@("`J($!P
M87)A;2!A<G)A>2`D;6]D("`@("`@("!4:&4@;&ES="!O9B!M;V1I9FEC871I
M;VYS+@H@("`@("H@/'!R93X*("`@("`J(%!E<B!21D,@,C(Y."!;,RXR+C8N
M,UT@=&AE(&9O;&QO=VEN9R!M;V1I9FEC871I;VYS(&%R92!V86QI9#H*("`@
M("`J(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/0H@("`@("H@)V5R<F]R)PH@("`@("H@)W=A
M<FYI;F<G"B`@("`@*B`G<W5P97)S961E9"<*("`@("`J("=E>'!I<F5D)PH@
M("`@("H@)VUA:6QB;W@M=&5R;6EN871E9"<*("`@("`J(#PO<')E/@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1E<G(@("`@("`@($EF("1T>7!E(&ES("=F86EL
M=64G(&]R("1M;V0@:7,@96ET:&5R("=E<G)O<B<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!O<B`G=V%R;FEN9R<L('1H92!A9&1I=&EO;F%L
M(&EN9F]R;6%T:6]N('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@<')O=FED92X@($ME>2!I<R!T:&4@='EP92!O9B!M;V1I9FEC871I;VXL
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@=F%L=64@:7,@=&AE
M('1E>'0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S+"!014%27T5R<F]R(&]B:F5C="!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5N97)A=&4H)&%C=&EO;BP@)'-E;F1I;F<L("1T>7!E
M+"`D;6]D(#T@87)R87DH*2P@)&5R<B`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+TAE861E<G,N<&AP)SL*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O365S<V%G92YP:'`G.PH@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0N<&AP)SL*"B`@("`@("`@
M+RH@4V5T('5P('-O;64@=F%R:6%B;&5S('=E('5S92!L871E<BX@*B\*("`@
M("`@("`D:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@I.PH@("`@
M("`@("1F<F]M7V%D9'(@/2`D:61E;G1I='DM/F=E=$1E9F%U;'1&<F]M061D
M<F5S<R@I.PH*("`@("`@("`D=&\@/2`D=&AI<RT^9V5T341.4F5T=7)N061D
M<B@I.PH*("`@("`@("`D=6$@/2`D=&AI<RT^7VAE861E<G,M/F=E=$%G96YT
M2&5A9&5R*"D["@H@("`@("`@("1O<FEG7W)E8VEP(#T@)'1H:7,M/E]H96%D
M97)S+3YG971686QU92@G3W)I9VEN86PM4F5C:7!I96YT)RD["B`@("`@("`@
M:68@*"%E;7!T>2@D;W)I9U]R96-I<"D@)B8@:7-?87)R87DH)&]R:6=?<F5C
M:7`I*2!["B`@("`@("`@("`@("1O<FEG7W)E8VEP(#T@)&]R:6=?<F5C:7!;
M,%T["B`@("`@("`@?0H*("`@("`@("`D;7-G7VED(#T@)'1H:7,M/E]H96%D
M97)S+3YG971686QU92@G365S<V%G92U)1"<I.PH*("`@("`@("`O*B!#<F5A
M=&4@=&AE($1I<W!O<VET:6]N(&9I96QD(&YO=R`H4D9#(#(R.3@@6S,N,BXV
M72DN("HO"B`@("`@("`@)&1I<W!O(#T@)T1I<W!O<VET:6]N.B`G("X*("`@
M("`@("`@("`@("`@("`H*"1A8W1I;VXI(#\@)VUA;G5A;"UA8W1I;VXG(#H@
M)V%U=&]M871I8RUA8W1I;VXG*2`N"B`@("`@("`@("`@("`@("`@)R\G("X*
M("`@("`@("`@("`@("`@("`H*"1S96YD:6YG*2`_("=-1$XM<V5N="UM86YU
M86QL>2<@.B`G341.+7-E;G0M875T;VUA=&EC86QL>2<I("X*("`@("`@("`@
M("`@("`@("`G.R`G("X*("`@("`@("`@("`@("`@("`D='EP93L*("`@("`@
M("!I9B`H(65M<'1Y*"1M;V0I*2!["B`@("`@("`@("`@("1D:7-P;R`N/2`G
M+R<@+B!I;7!L;V1E*"<L("<L("1M;V0I.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4V5T('5P('1H92!M86EL(&AE861E<G,N("HO"B`@("`@("`@)&US9U]H
M96%D97)S(#T@)FYE=R!-24U%7TAE861E<G,H*3L*("`@("`@("`D;7-G7VAE
M861E<G,M/F%D9$UE<W-A9V5)9$AE861E<B@I.PH@("`@("`@("1M<V=?:&5A
M9&5R<RT^861D06=E;G1(96%D97(H)'5A*3L*("`@("`@("`D;7-G7VAE861E
M<G,M/F%D9$AE861E<B@G1&%T92<L(&1A=&4H)W(G*2D["B`@("`@("`@)&US
M9U]H96%D97)S+3YA9&1(96%D97(H)T9R;VTG+"`D9G)O;5]A9&1R*3L*("`@
M("`@("`D;7-G7VAE861E<G,M/F%D9$AE861E<B@G5&\G+"`D=&AI<RT^9V5T
M341.4F5T=7)N061D<B@I*3L*("`@("`@("`D;7-G7VAE861E<G,M/F%D9$AE
M861E<B@G4W5B:F5C="<L(%\H(D1I<W!O<VET:6]N($YO=&EF:6-A=&EO;B(I
M*3L*"B`@("`@("`@+RH@341.<R!A<F4@82!S=6)T>7!E(&]F("=M=6QT:7!A
M<G0O<F5P;W)T)RX@*B\*("`@("`@("`D;7-G(#T@)FYE=R!-24U%7TUE<W-A
M9V4H*3L*("`@("`@("`D;7-G+3YS9714>7!E*"=M=6QT:7!A<G0O<F5P;W)T
M)RD["B`@("`@("`@)&US9RT^<V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W)E
M<&]R="UT>7!E)RP@)V1I<W!O<VET:6]N+6YO=&EF:6-A=&EO;B<I.PH*("`@
M("`@("`O*B!4:&4@9FER<W0@<&%R="!I<R!A(&AU;6%N(')E861A8FQE(&UE
M<W-A9V4N("HO"B`@("`@("`@)'!A<G1?;VYE(#T@)FYE=R!-24U%7U!A<G0H
M)W1E>'0O<&QA:6XG*3L*("`@("`@("`D<&%R=%]O;F4M/G-E=$-H87)S970H
M3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@(&EF("@D='EP92`]/2`G9&ES
M<&QA>65D)RD@>PH@("`@("`@("`@("`D<&%R=%]O;F4M/G-E=$-O;G1E;G1S
M*'-P<FEN=&8H7R@B5&AE(&UE<W-A9V4@<V5N="!O;B`E<R!T;R`E<R!W:71H
M('-U8FIE8W0@7"(E<UPB(&AA<R!B965N(&1I<W!L87EE9"Y<;E1H:7,@:7,@
M;F\@9W5A<F%N=&5E('1H870@=&AE(&UE<W-A9V4@:&%S(&)E96X@<F5A9"!O
M<B!U;F1E<G-T;V]D+B(I+"`D=&AI<RT^7VAE861E<G,M/F=E=%9A;'5E*"=$
M871E)RDL("1T:&ES+3Y?:&5A9&5R<RT^9V5T5F%L=64H)U1O)RDL("1T:&ES
M+3Y?:&5A9&5R<RT^9V5T5F%L=64H)U-U8FIE8W0G*2DI.PH@("`@("`@('T*
M("`@("`@("`O+R!43T1/.B!-97-S86=E<R!F;W(@;W1H97(@;F]T:69I8V%T
M:6]N('1Y<&5S+@H@("`@("`@("1M<V<M/F%D9%!A<G0H)'!A<G1?;VYE*3L*
M"B`@("`@("`@+RH@5&AE('-E8V]N9"!P87)T(&ES(&$@;6%C:&EN92UP87)S
M96%B;&4@9&5S8W)I<'1I;VXN("HO"B`@("`@("`@)'!A<G1?='=O(#T@)FYE
M=R!-24U%7U!A<G0H)VUE<W-A9V4O9&ES<&]S:71I;VXM;F]T:69I8V%T:6]N
M)RD["B`@("`@("`@)'!A<G1?='=O+3YS971#;VYT96YT<R@G4F5P;W)T:6YG
M+55!.B`G("X@)$=,3T)!3%-;)V-O;F8G75LG<V5R=F5R)UU;)VYA;64G72`N
M("<[("<@+B`D=6$@+B`B7&XB*3L*("`@("`@("!I9B`H(65M<'1Y*"1O<FEG
M7W)E8VEP*2D@>PH@("`@("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O;G1E
M;G1S*"=/<FEG:6YA;"U296-I<&EE;G0Z(')F8S@R,CLG("X@)&]R:6=?<F5C
M:7`@+B`B7&XB*3L*("`@("`@("!]"B`@("`@("`@)'!A<G1?='=O+3YA<'!E
M;F1#;VYT96YT<R@G1FEN86PM4F5C:7!I96YT.B!R9F,X,C([)R`N("1F<F]M
M7V%D9'(@+B`B7&XB*3L*("`@("`@("!I9B`H(65M<'1Y*"1M<V=?:60I*2![
M"B`@("`@("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T]R:6=I
M;F%L+4UE<W-A9V4M240Z(')F8S@R,CLG("X@)&US9U]I9"`N(")<;B(I.PH@
M("`@("`@('T*("`@("`@("`D<&%R=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"1D
M:7-P;R`N(")<;B(I.PH@("`@("`@(&EF("@H)'1Y<&4@/3T@)V9A:6QE9"<I
M("8F(&ES<V5T*"1E<G);)V9A:6QE9"==*2D@>PH@("`@("`@("`@("`D<&%R
M=%]T=V\M/F%P<&5N9$-O;G1E;G1S*"=&86EL=7)E.B`G("X@)&5R<ELG9F%I
M;&5D)UT@+B`B7&XB*3L*("`@("`@("!]"B`@("`@("`@:68@*&EN7V%R<F%Y
M*"=E<G)O<B<L("1M;V0I("8F(&ES<V5T*"1E<G);)V5R<F]R)UTI*2!["B`@
M("`@("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N=&5N=',H)T5R<F]R.B`G
M("X@)&5R<ELG97)R;W(G72`N(")<;B(I.PH@("`@("`@('T*("`@("`@("!I
M9B`H:6Y?87)R87DH)W=A<FYI;F<G+"`D;6]D*2`F)B!I<W-E="@D97)R6R=W
M87)N:6YG)UTI*2!["B`@("`@("`@("`@("1P87)T7W1W;RT^87!P96YD0V]N
M=&5N=',H)U=A<FYI;F<Z("<@+B`D97)R6R=W87)N:6YG)UT@+B`B7&XB*3L*
M("`@("`@("!]"B`@("`@("`@)&US9RT^861D4&%R="@D<&%R=%]T=V\I.PH*
M("`@("`@("`O*B!4:&4@=&AI<F0@<&%R="!I<R!T:&4@=&5X="!O9B!T:&4@
M;W)I9VEN86P@;65S<V%G92X@(%)&0R`R,CDX(%LS70H@("`@("`@("`J(&%L
M;&]W<R!U<R!T;R!R971U<FX@;VYL>2!A('!O<G1I;VX@;V8@=&AE(&5N=&ER
M92!M97-S86=E("T@=&AI<PH@("`@("`@("`J(&ES(&QE9G0@=7`@=&\@=&AE
M('5S97(N("HO"B`@("`@("`@)'!A<G1?=&AR964@/2`F;F5W($U)345?4&%R
M="@G;65S<V%G92]R9F,X,C(G*3L*("`@("`@("`D<&%R=%]T:')E92T^<V5T
M0V]N=&5N=',H)'1H:7,M/E]H96%D97)S+3YT;U-T<FEN9R@I*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?;7-G=&5X="DI('L*("`@("`@("`@("`@
M)'!A<G1?=&AR964M/F%P<&5N9$-O;G1E;G1S*")<;B(@+B`D=&AI<RT^7VUS
M9W1E>'0I.PH@("`@("`@('T*("`@("`@("`D;7-G+3YA9&1087)T*"1P87)T
M7W1H<F5E*3L*"B`@("`@("`@)&US9U]H96%D97)S+3YA9&1-24U%2&5A9&5R
M<R@D;7-G*3L*"B`@("`@("`@<F5T=7)N("1M<V<M/G-E;F0H)'1O+"`D;7-G
M7VAE861E<G,I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@341.("AR
M96%D(')E8V5I<'0I(')E<75E<W0@:&5A9&5R<R!T;R!T:&4@34E-15](96%D
M97)S(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15](96%D97)S
M("8D:&5A9&]B("!4:&4@34E-15](96%D97)S(&]B:F5C="!T;R!A9&0@=&AE
M(&AE861E<G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&\@("`@("`@("`@("`@5&AE
M(&%D9')E<W,@=&AE(')E8V5I<'0@<VAO=6QD(&)E(&UA:6QE9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&\N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9$U$3E)E<75E<W1(96%D97)S*"8D:&5A9&]B+"`D=&\I
M"B`@("!["B`@("`@("`@+RH@5&AI<R!I<R!T:&4@4D9#(#(R.3@@=V%Y(&]F
M(')E<75E<W1I;F<@82!R96-E:7!T+B`J+PH@("`@("`@("1H96%D;V(M/F%D
M9$AE861E<B@G1&ES<&]S:71I;VXM3F]T:69I8V%T:6]N+51O)RP@)'1O*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]#;VYT
M96YT<RYP:'``````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#4P
M-S`@,3`U,34T,S0Q,S<@,#(R-#`U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+TUE<W-A9V4N<&AP)SL*"B\J*@H@*B!4:&4@;F%M
M92!O9B!T:&4@55),('!A<F%M971E<B!T:&%T(&AO;&1S('1H92!-24U%7T-O
M;G1E;G1S(&-A8VAE"B`J(&ED96YT:69I97(N"B`J+PID969I;F4H)TU)345?
M0T].5$5.5%-?0T%#2$4G+"`G;6EM96-A8VAE)RD["@HO*BH*("H@1&ES<&QA
M>2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&EN(&QI<W0@9F]R;6%T+@H@*B\*
M9&5F:6YE*"=-24U%7T-/3E1%3E137T1)4U!,05E?5%E015],25-4)RP@,"D[
M"@HO*BH*("H@1&ES<&QA>2!A='1A8VAM96YT(&EN9F]R;6%T:6]N(&EN;&EN
M92!W:71H(&%T=&%C:&UE;G0N"B`J+PID969I;F4H)TU)345?0T].5$5.5%-?
M1$E34$Q!65]465!%7TE.3$E.12<L(#$I.PH*+RHJ"B`J($1I<W!L87D@871T
M86-H;65N="!I;F9O<FUA=&EO;B!B;W1H(&EN(&QI<W0@9F]R;6%T(&%N9"!I
M;FQI;F4@=VET:`H@*B!A='1A8VAM96YT+@H@*B\*9&5F:6YE*"=-24U%7T-/
M3E1%3E137T1)4U!,05E?5%E015]"3U1()RP@,BD["@HO*BH*("H@5&AE($U)
M345?0V]N=&5N=',Z.B!C;&%S<R!C;VYT86EN<R!F=6YC=&EO;G,@<F5L871E
M9"!T;R!H86YD;&EN9R!T:&4@;W5T<'5T"B`J(&]F($U)344@8V]N=&5N="X*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+T-O;G1E;G1S+G!H
M<"QV(#$N,3(Y+C0N,S4@,C`P-B\P-2\P-2`P,SHS,#HR,B!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7TU)344*("HO"F-L87-S($U)345?0V]N=&5N=',@>PH*("`@
M("\J*@H@("`@("H@5&AE($U)345?365S<V%G92!O8FIE8W0@9F]R('1H92!M
M97-S86=E+@H@("`@("H*("`@("`J($!V87(@34E-15]-97-S86=E"B`@("`@
M*B\*("`@('9A<B`D7VUE<W-A9V4["@H@("`@+RHJ"B`@("`@*B!4:&4@34E-
M15]-97-S86=E(&]B:F5C="!W92!U<V4@=VAE;B!C86-H:6YG+@H@("`@("H*
M("`@("`J($!V87(@34E-15]-97-S86=E"B`@("`@*B\*("`@('9A<B`D7V-A
M8VAE;65S<V%G93L*"B`@("`O*BH*("`@("`J(%1H92!A='1A8VAM96YT<R!L
M:7-T+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?871C(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!M97-S86=E
M('!A<G1S(&QI<W0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]P87)T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4
M:&4@<W5M;6%R>2!P87)T<R!L:7-T+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<W5M;6%R>2`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<W5M;6%R>2!T>7!E+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-U;6UA<GE4>7!E(#T@;G5L
M;#L*"B`@("`O*BH*("`@("`J(%1H92!#86-H95]S97-S:6]N(&ED96YT:69I
M97(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<V5S<VEO;D-A8VAE240@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE
M($U)345?5FEE=V5R(&]B:F5C="!C86-H92X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W9I97=E<D-A8VAE(#T@87)R87DH
M*3L*"B`@("`O*BH*("`@("`J(%1H92!A='1A8VAM96YT(&1I<W!L87D@='EP
M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D7V1I<W!L87E4>7!E(#T@34E-15]#3TY414Y44U]$25-03$%9
M7U194$5?0D]42#L*"B`@("`O*BH*("`@("`J(%1H92!-24U%(&EN9&5X(&ME
M>2!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?;6EM96ME>2`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@
M86-T:6]N240@=F%L=64@9F]R('9A<FEO=7,@86-T:6]N<RX*("`@("`J("=D
M;W=N;&]A9"<@("TM("!$;W=N;&]A9&EN9R!A('!A<G0O871T86-H;65N="X*
M("`@("`J("=V:65W)R`@("`@("TM("!6:65W:6YG(&$@<&%R="]A='1A8VAM
M96YT+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?=FEE=TE$(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-H;W<@=&AE
M(&QI;FMS(&EN('1H92!S=6UM87)I97,_"B`@("`@*@H@("`@("H@0'9A<B!B
M;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VQI;FMS(#T@=')U93L*"B`@("`O
M*BH*("`@("`J(%1H92!B87-E($U)345?0V]N=&5N=',@;V)J96-T+@H@("`@
M("H*("`@("`J($!V87(@34E-15]#;VYT96YT<PH@("`@("HO"B`@("!V87(@
M)%]B87-E(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@
M;65S<V%G92]R9F,X,C(@;&5V96QS(&QA8F5L960@87,@)V%T=&%C:&UE;G1S
M)R!O9B!T:&4*("`@("`J(&-U<G)E;G0@<&%R="X*("`@("`J"B`@("`@*B!`
M=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?871T86-H.#(R(#T@,#L*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P
M87)A;2!-24U%7TUE<W-A9V4@)&UE<W-A9V5/8B`@5&AE(&]B:F5C="!T;R!W
M;W)K('=I=&@N"B`@("`@*B!`<&%R86T@87)R87D@)'9I97=)1"`@("`@("`@
M("`@(%1H92!A8W1I;VY)1"!V86QU97,@9F]R('9I97=I;F<*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%R=',O871T86-H;65N
M=',N"B`@("`@*B!`<&%R86T@87)R87D@)B1C;VYT96YT<R`@("`@("`@($%R
M<F%Y(&-O;G1A:6YI;F<@82!S:6YG;&4@=F%L=64Z"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&$@<F5F97)E;F-E('1O('1H92!B
M87-E(&]B:F5C="X*("`@("`J("A4:&ES(&QA<W0@<&%R86UE=&5R(&YE961S
M('1O(&)E(&AA;F1L960@=FEA(&%N(&%R<F%Y(&)E8V%U<V4@4$A0(#P*("`@
M("`J("`U+C`@9&]E<VXG="!H86YD;&4@;W!T:6]N86P@<&]I;G1E<B!P87)A
M;65T97)S(&]T:&5R=VES92XI"B`@("`@*B\*("`@(&9U;F-T:6]N($U)345?
M0V]N=&5N=',H)&UE<W-A9V5/8BP@)'9I97=)1"`](&%R<F%Y*"DL("1C;VYT
M96YT<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/E]M97-S86=E
M(#T@)&UE<W-A9V5/8CL*("`@("`@("`D=&AI<RT^7V-A8VAE;65S<V%G92`]
M(%5T:6PZ.F-L;VYE3V)J96-T*"1M97-S86=E3V(I.PH@("`@("`@("1T:&ES
M+3Y?=FEE=TE$(#T@)'9I97=)1#L*"B`@("`@("`@+RH@0W)E871E('1H92!P
M;VEN=&5R('1O('1H92!B87-E(&]B:F5C="X@*B\*("`@("`@("!I9B`H(65M
M<'1Y*"1C;VYT96YT<RDI('L*("`@("`@("`@("`@)'!T<B`](')E<V5T*"1C
M;VYT96YT<RD["B`@("`@("`@("`@("1O;&1?<'1R(#T@)B1P='(M/F=E=$)A
M<V5/8FIE8W10='(H*3L*("`@("`@("`@("`@)'1H:7,M/E]B87-E(#T@)&]L
M9%]P='(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@96YT:7)E(&)O9'D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B!9;W4@
M<')O8F%B;'D@=V%N="!T;R!O=F5R<FED92!T:&ES(&9U;F-T:6]N(&EN(&%N
M>2!S=6)C;&%S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('1E>'0@;V8@=&AE(&)O9'D@;V8@=&AE(&UE<W-A9V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$)O9'DH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUE<W-A9V4M/G1O4W1R:6YG*"D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!R87<@=&5X="!F;W(@;VYE('-E8W1I;VX@;V8@=&AE
M(&UE<W-A9V4N"B`@("`@*B!9;W4@<')O8F%B;'D@=V%N="!T;R!O=F5R<FED
M92!T:&ES(&9U;F-T:6]N(&EN(&%N>2!S=6)C;&%S<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE($E$(&]F('1H92!-24U%7U!A<G0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&]F('1H
M92!P87)T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971";V1Y4&%R="@D:60I
M"B`@("!["B`@("`@("`@:68@*"@D<&%R="`]("8D=&AI<RT^9V5T34E-15!A
M<G0H)&ED*2DI('L*("`@("`@("`@("`@<F5T=7)N("1P87)T+3YG971#;VYT
M96YT<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`G
M)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!-24U%7TUE<W-A9V4@;V)J96-T(&9O<B!T:&4@;6%I;"!M97-S86=E+@H@
M("`@("H*("`@("`J($!R971U<FX@34E-15]-97-S86=E("!!($U)345?365S
M<V%G92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$U)345-97-S
M86=E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M97-S86=E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1F5T8V@@82!P87)T(&]F(&$@34E-12!M
M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I9"`@5&AE
M($U)344@:6YD97@@;V8@=&AE('!A<G0@<F5Q=65S=&5D+@H@("`@("H*("`@
M("`J($!R971U<FX@34E-15]087)T("!4:&4@<F%W($U)344@<&%R="!A<VME
M9"!F;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971-24U%4&%R="@D:60I
M"B`@("!["B`@("`@("`@)'!A<G0@/2`D=&AI<RT^7VUE<W-A9V4M/F=E=%!A
M<G0H)&ED*3L*("`@("`@("!R971U<FX@)'!A<G0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296)U:6QD('1H92!-24U%7U!A<G0@<W1R=6-T=7)E(&]F(&$@
M;65S<V%G92X*("`@("`J(%EO=2!P<F]B86)L>2!W86YT('1O(&]V97)R:61E
M('1H:7,@9G5N8W1I;VX@:6X@86YY('-U8F-L87-S+@H@("`@("H*("`@("`J
M($!R971U<FX@34E-15]-97-S86=E("!!($U)345?365S<V%G92!O8FIE8W0@
M=VET:"!A;&P@;V8@=&AE(&)O9'D@=&5X=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@('-T;W)E9"!I;B!T:&4@:6YD:79I9'5A;"!-24U%7U!A<G1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96)U:6QD365S<V%G92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;65S<V%G93L*("`@('T*"B`@("`O
M*BH*("`@("`J($9E=&-H('!A<G0@;V8@82!-24U%(&UE<W-A9V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&ED("`@5&AE($U)344@240@;V8@
M=&AE('!A<G0@<F5Q=65S=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L
M;"`@268@=&AI<R!I<R!A(&AE861E<B!P87)T+"!S:&]U;&0@=V4@<F5T=7)N
M(&%L;"!T97AT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@
M8F]D>3\*("`@("`J"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)
M345?4&%R="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%)A=TU)345087)T
M*"1I9"P@)&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@("1M:6UE7W!A<G0@
M/2`F)'1H:7,M/F=E=$U)345087)T*"1I9"D["B`@("`@("`@:68@*"%I<U]A
M*"1M:6UE7W!A<G0L("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("`D;6EM
M95]P87)T(#T@;G5L;#L*("`@("`@("`@("`@<F5T=7)N("1M:6UE7W!A<G0[
M"B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A;&P@=&5X="!I<R!R97%U97-T
M960L(&-H86YG92!T:&4@240@;F]W+B`J+PH@("`@("`@(&EF("@D86QL("8F
M("1M:6UE7W!A<G0M/F=E=$EN9F]R;6%T:6]N*"=H96%D97(G*2D@>PH@("`@
M("`@("`@("`D:60@/2!S=6)S='(H)&ED+"`P+"!S=')R<&]S*"1I9"P@)RXG
M*2D["B`@("`@("`@?0H*("`@("`@("`O*B!/;FQY('-E="!C;VYT96YT<R!I
M9B!T:&5R92!I<R!C=7)R96YT;'D@;F]N92!I;B!T:&4@34E-12!087)T+B`J
M+PH@("`@("`@(&EF("@A)&UI;65?<&%R="T^9V5T0V]N=&5N=',H*2D@>PH@
M("`@("`@("`@("`D;6EM95]P87)T+3YS971#;VYT96YT<R@D=&AI<RT^9V5T
M0F]D>5!A<G0H)&ED*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UI
M;65?<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J($9E=&-H('!A<G0@;V8@
M82!-24U%(&UE<W-A9V4@86YD(&1E8V]D92!I="P@:68@:70@:7,@8F%S95\V
M-"!O<@H@("`@("H@<7!R:6YT(&5N8V]D960N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&ED("`@5&AE($U)344@240@;V8@=&AE('!A<G0@<F5Q
M=65S=&5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;"`@268@=&AI<R!I
M<R!A(&AE861E<B!P87)T+"!S:&]U;&0@=V4@<F5T=7)N(&%L;"!T97AT"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!I;B!T:&4@8F]D>3\*("`@("`J
M"B`@("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="!W:71H
M(&ET<R!C;VYT96YT<R!D96-O9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9V5T1&5C;V1E9$U)345087)T*"1I9"P@)&%L;"`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("@H)&UI;65?<&%R="`]("8D=&AI<RT^9V5T4F%W34E-15!A
M<G0H)&ED+"`D86QL*2DI('L*("`@("`@("`@("`@)&UI;65?<&%R="T^=')A
M;G-F97)$96-O9&5#;VYT96YT<R@I.PH@("`@("`@("`@("`O+R!.;V]P+@H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M:6UE7W!A<G0@/2!N=6QL
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&UI;65?<&%R=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@871T86-H;65N="!L:7-T("A(
M5$U,('1A8FQE(&9O<FUA="DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!L:7-T(&]F(&%T=&%C:&UE;G1S(&9O<FUA='1E9"!I;G1O($A4
M34PN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%T=&%C:&UE;G1S*"D*("`@
M('L*("`@("`@("`D;7-G(#T@)R<["@H@("`@("`@("1A:V5Y<R`](&%R<F%Y
M7VME>7,H)'1H:7,M/E]A=&,I.PH@("`@("`@(&YA='-O<G0H)&%K97ES*3L*
M("`@("`@("!F;W)E86-H("@D86ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@
M("`D;7-G("X]("1T:&ES+3Y?87)R87E4;U1A8FQE4F]W*"1T:&ES+3Y?871C
M6R1K97E=*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!M97-S86=E(&QI<W0@*$A4
M34P@=&%B;&4@9F]R;6%T*2X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D;VYE9G)A;64@(%-H;W5L9"!T:&4@;W5T<'5T(&)E(&1E<VEG;F5D(&9O
M<B!D:7-P;&%Y(&EN(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<VEN9VQE(&9R86UE/PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@;65S<V%G92!F;W)M871T960@:6YT;R!(5$U,+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971-97-S86=E*"1O;F5F<F%M92`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1M<V<@/2`G)SL*("`@("`@("`D;7-G0V]U;G0@/2!C;W5N
M="@D=&AI<RT^7W!A<G1S*3L*("`@("`@("`D<&%R=$1I<W!L87EE9"`](&9A
M;'-E.PH*("`@("`@("!I9B`H)&]N969R86UE*2!["B`@("`@("`@("`@("1M
M<V<@+CT@)SQS='EL92!T>7!E/2)T97AT+V-S<R(^+F]N969R('MP861D:6YG
M.C%P>#L@;6%R9VEN+6)O='1O;3HQ<'@[(&)O<F1E<CHQ<'@@9&%S:&5D(",P
M,&,[(&)A8VMG<F]U;F0Z(V5E9CL@8V]L;W(Z(S`P-GT\+W-T>6QE/B<@+B`B
M7&XB.PH@("`@("`@('T*"B`@("`@("`@+R\@5$]$3SH@5&5M<&]R87)Y(&AA
M8VL@=&\@9&ES<&QA>2!H96%D97(@:6YF;R!F;W(@82!M97-S86=E('=I=&@@
M;VYE"B`@("`@("`@+R\@34E-12!P87)T('1H870@8V%N;F]T(&)E(&1I<W!L
M87EE9"!I;FQI;F4N"B`@("`@("`@:68@*"$D;7-G0V]U;G0@?'P@*"1M<V=#
M;W5N="`]/2`Q("8F("%R97-E="@D=&AI<RT^7W!A<G1S*2DI('L*("`@("`@
M("`@("`@)'1H:7,M/G-E=%-U;6UA<GDH)'1H:7,M/E]M97-S86=E+"`G<&%R
M="<I.PH@("`@("`@("`@("`D;7-G0V]U;G0@/2`Q.PH@("`@("`@('T*("`@
M("`@("`@("`@"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)T<R!A<R`D
M:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]S=6UM87)Y6R1K97E=*2`F)@H@("`@("`@("`@("`@("`@*"@H)&US9T-O
M=6YT(#T](#$I("8F(&5M<'1Y*"1V86QU92DI('Q\("@D;7-G0V]U;G0@/B`Q
M*2DI('L*("`@("`@("`@("`@("`@("1M<V<@+CT@)SQT<CX\=&0^)SL*("`@
M("`@("`@("`@("`@(&EF("@D;VYE9G)A;64I('L*("`@("`@("`@("`@("`@
M("`@("`D;7-G("X]("<\=&%B;&4@8VQA<W,](F]N969R(CXG.PH@("`@("`@
M("`@("`@("`@("`@("1S=6UM87)Y(#T@)'1H:7,M/E]S=6UM87)Y6R1K97E=
M.PH@("`@("`@("`@("`@("`@("`@("1S=6UM87)Y(#T@87)R87E?;65R9V4H
M87)R87E?<W!L:6-E*"1S=6UM87)Y+"`P+"`Q*2P@87)R87E?<W!L:6-E*"1S
M=6UM87)Y+"`Q*2D["B`@("`@("`@("`@("`@("`@("`@)&US9R`N/2`D=&AI
M<RT^7V%R<F%Y5&]486)L95)O=R@D<W5M;6%R>2D["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@)SQT86)L
M93XG.PH@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@)'1H:7,M/E]A<G)A
M>51O5&%B;&52;W<H)'1H:7,M/E]S=6UM87)Y6R1K97E=*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1M<V<@+CT@)SPO=&%B;&4^/"]T
M9#X\+W1R/B<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D;7-G("X]("<\='(^/'1D
M(&-L87-S/2)T97AT(CXG("X@)'9A;'5E("X@)SPO=&0^/"]T<CXG.PH@("`@
M("`@("`@("`@("`@)'!A<G1$:7-P;&%Y960@/2!T<G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21P87)T1&ES<&QA>65D*2![
M"B`@("`@("`@("`@("1M<V<@+CT@)SQT<CX\=&0@8VQA<W,](G1E>'0B(&%L
M:6=N/2)L969T(CX\96T^)R`N(%\H(E1H97)E(&%R92!N;R!P87)T<R!T:&%T
M(&-A;B!B92!D:7-P;&%Y960@:6YL:6YE+B(I("X@)SPO96T^/"]T9#X\+W1R
M/B<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&US9SL*("`@('T*"B`@
M("`O*BH*("`@("`J($5X<&%N9',@86X@87)R87D@:6YT;R!A('1A8FQE(')O
M=RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&%R<F%Y("!4:&4@87)R87D@=&\@97AP86YD+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@87)R87D@97AP86YD
M960@=&\@82!(5$U,('1A8FQE(')O=RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V%R<F%Y5&]486)L95)O=R@D87)R87DI"B`@("!["B`@("`@("`@)'1E>'0@
M/2`G/'1R('9A;&EG;CTB;6ED9&QE(CXG.PH*("`@("`@("!F;W)E86-H("@D
M87)R87D@87,@)&5L96TI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D96QE
M;2DI('L*("`@("`@("`@("`@("`@("1T97AT("X]("(\=&0^)&5L96TF;F)S
M<#L\+W1D/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T97AT("X@(CPO='(^7&XB.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@9&%T82!F;W(@82!S<&5C:69I8R!-24U%(&EN9&5X
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("!4:&4@34E-
M12!I;F1E>"X*("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("!4:&4@9FEE
M;&0@=&\@<F5T=7)N("AM97-S86=E+"!A=&,L('-U;6UA<GDI"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!T97AT(&-U<G)E;G1L>2!S970@
M9F]R('1H870@:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$EN9&5X
M*"1I9"P@)&9I96QD*0H@("`@>PH@("`@("`@("1F:65L9"`]("=?)R`N("1F
M:65L9#L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/B1F:65L9"D@)B8@
M87)R87E?:V5Y7V5X:7-T<R@D:60L("1T:&ES+3XD9FEE;&0I*2!["B`@("`@
M("`@("`@("1E;G1R>2`]("1T:&ES+3XD9FEE;&0["B`@("`@("`@("`@(')E
M='5R;B`D96YT<GE;)&ED73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!296UO=F5S('1H92!M97-S86=E('1E>'0@86YD('-U;6UA<GD@9F]R(&$@
M<W!E8VEF:6,@34E-12!I;F1E>"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1I9"`@5&AE($U)344@:6YD97@N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;6]V94EN9&5X*"1I9"D*("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^
M7W!A<G1S6R1I9%TI.PH@("`@("`@('5N<V5T*"1T:&ES+3Y?<W5M;6%R>5LD
M:61=*3L*("`@("`@("!U;G-E="@D=&AI<RT^7V%T8ULD:61=*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!I9B!W92!C86X@*&%N9"!K;F]W
M(&AO=R!T;RD@:6YL:6YE(&$@34E-12!087)T+@H@("`@("H*("`@("`J($!P
M87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@<&%R
M="!C86X@8F4@:6YL:6YE9"X*("`@("`J("`@("`@("`@("`@("`@("`@1F%L
M<V4@:68@:70@8V%N;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y$:7-P
M;&%Y26YL:6YE*"8D;6EM95]P87)T*0H@("`@>PH@("`@("`@("1V:65W97(@
M/2`F)'1H:7,M/F=E=$U)3456:65W97(H)&UI;65?<&%R="D["@H@("`@("`@
M("\J($9I<G-T(&-H96-K.B!4:&4@34E-12!H96%D97)S(&%L;&]W('1H92!P
M87)T('1O(&)E(&EN;&EN960N"B`@("`@("`@("H@2&]W979E<BP@:68@=V4@
M87)E(&%L<F5A9'D@:6X@=FEE=R!M;V1E+"!T:&5N('=E(&-A;B!S:VEP('1H
M:7,*("`@("`@("`@*B!C:&5C:RX@*B\*("`@("`@("!I9B`H(21T:&ES+3YV
M:65W07-!='1A8VAM96YT*"D@)B8*("`@("`@("`@("`@*"1M:6UE7W!A<G0M
M/F=E=$1I<W!O<VET:6]N*"D@(3T@)VEN;&EN92<I("8F"B`@("`@("`@("`@
M("$D=FEE=V5R+3YF;W)C94EN;&EN959I97<H*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!396-O;F0@8VAE
M8VL@*'-A=F4@=&AE(&UO<W0@97AP96YS:79E(&9O<B!L87-T*3H*("`@("`@
M("`@*B!#:&5C:R!T;R!S964@:68@=&AE(&1R:79E<B!I<R!S970@=&\@:6YL
M:6YE+B`J+PH@("`@("`@(')E='5R;B`H:7-?82@D=FEE=V5R+"`G34E-15]6
M:65W97(G*2`F)B`D=FEE=V5R+3YC86Y$:7-P;&%Y26YL:6YE*"DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T($U)345?5FEE=V5R(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!!($U)
M345?4&%R="!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U9I
M97=E<B`@5&AE($U)345?5FEE=V5R(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971-24U%5FEE=V5R*"8D;6EM
M95]P87)T*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@
M34E-15]087)T('1O('!R;V-E<W,N("HO"B`@("`@("`@:68@*&5M<'1Y*"1M
M:6UE7W!A<G0I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N
M("<O5FEE=V5R+G!H<"<["@H@("`@("`@("1K97D@/2`D;6EM95]P87)T+3YG
M9715;FEQ=65)1"@I("X@)WPG("X@)&UI;65?<&%R="T^9V5T5'EP92@I.PH@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]V:65W97)#86-H95LD:V5Y72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]V:65W97)#86-H95LD:V5Y72`]("9-
M24U%7U9I97=E<CHZ9F%C=&]R>2@D;6EM95]P87)T*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W9I97=E<D-A8VAE6R1K97E=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T('1H92!-24U%($-O;G1E;G0M5'EP92!O
M=71P=70@8GD@82!-24U%7U9I97=E<B!F;W(@82!P87)T:6-U;&%R"B`@("`@
M*B!-24U%7U!A<G0N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F
M)&UI;65?<&%R="`@02!-24U%7U!A<G0@;V)J96-T+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@34E-12!T>7!E(&]U='!U="!B>2!T:&4@
M34E-15]6:65W97(L(&]R(&9A;'-E(&]N"B`@("`@*B`@("`@("`@("`@("`@
M("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$U)3456:65W97)4
M>7!E*"8D;6EM95]P87)T*0H@("`@>PH@("`@("`@(&EF("@H)'9I97=E<B`]
M("8D=&AI<RT^9V5T34E-159I97=E<B@D;6EM95]P87)T*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1V:65W97(M/F=E=%1Y<&4H*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@:V5Y('1O('5S92!F;W(@
M82!P87)T:6-U;&%R($U)345?4&%R="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM
M95]P87)T("!!($U)345?4&%R="!O8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D;W9E<G)I9&4@("`@("!297-P96-T('1H92!-24U%(&ME>2!O=F5R
M<FED92!V86QU93\*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('5N:7%U92!I9&5N=&EF:65R(&]F('1H92!-24U%7U!A<G0N"B`@("`@*B`@
M("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!I9B!N;R!K97D@9F]U;F0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971-24U%2V5Y*"8D;6EM95]P87)T
M+"`D;W9E<G)I9&4@/2!T<G5E*0H@("`@>PH@("`@("`@("1I9"`]("1T:&ES
M+3YG971-24U%2V5Y3W9E<G)I9&4H*3L*"B`@("`@("`@:68@*"1O=F5R<FED
M92`F)B`A:7-?;G5L;"@D:60I*2!["B`@("`@("`@("`@(')E='5R;B`D:60[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&ED(#T@)&UI;65?<&%R
M="T^9V5T34E-14ED*"D["B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1I9"DI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D:60["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!-24U%(&ME>2!O=F5R<FED92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE($U)344@:V5Y(&]V97)R:61E("T@;G5L;"!I9B!N;R!O=F5R
M<FED92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T34E-14ME>4]V97)R:61E
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]M:6UE:V5Y.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T<R!A;B!O=F5R<FED92!F;W(@=&AE($U)
M344@:V5Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UI;65K97D*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T34E-14ME>4]V97)R:61E*"1M:6UE
M:V5Y(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7VUI;65K97D@/2`D
M;6EM96ME>3L*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W92!D:7-P
M;&%Y(&QI;FMS(&9O<B!T:&4@<W5M;6%R:65S/PH@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("1S:&]W("!3:&]W('1H92!S=6UM87)Y(&QI;FMS/PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S:&]W4W5M;6%R>4QI;FMS*"1S:&]W(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)'-H;W<I*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?;&EN:W,@/2`D<VAO=SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D=&AI<RT^7VQI;FMS.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5N9&5R(&$@34E-12!087)T+@H@("`@("H*("`@("`J($!P87)A
M;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]087)T(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A
M=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<DU)345087)T*"8D;6EM
M95]P87)T*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W)E;F1E<DU)
M345087)T*"1M:6UE7W!A<G0L(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E;F1E<B!-24U%(%!A<G0@871T86-H;65N="!I;F9O+@H@("`@("H*
M("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@($$@34E-15]0
M87)T(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<DU)
M345!='1A8VAM96YT26YF;R@F)&UI;65?<&%R="D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]R96YD97)-24U%4&%R="@D;6EM95]P87)T+"!T<G5E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F1E<B!-24U%(%!A<G0@9&%T
M82X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!!($U)345?4&%R="!O
M8FIE8W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D871T86-H;65N="`@("!2
M96YD97(@34E-12!087)T(&%T=&%C:&UE;G0@:6YF;S\*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]R96YD97)-24U%4&%R="@F)&UI;65?<&%R="P@)&%T
M=&%C:&UE;G0@/2!F86QS92D*("`@('L*("`@("`@("`O*B!'970@=&AE($U)
M345?5FEE=V5R(&]B:F5C="!F;W(@=&AI<R!-24U%('!A<G0@*B\*("`@("`@
M("`D=FEE=V5R(#T@)B1T:&ES+3YG971-24U%5FEE=V5R*"1M:6UE7W!A<G0I
M.PH@("`@("`@(&EF("@A:7-?82@D=FEE=V5R+"`G34E-15]6:65W97(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("`D
M;7-G(#T@)R<["@H@("`@("`@("1M:6UE7W!A<G0M/G1R86YS9F5R1&5C;V1E
M0V]N=&5N=',H*3L*"B`@("`@("`@+RH@268@=&AI<R!I<R!A('1E>'0O*B!P
M87)T+"!!3D0@=&AE('1E>'0@:7,@:6X@82!D:69F97)E;G0@8VAA<F%C=&5R
M"B`@("`@("`@("H@<V5T('1H86X@=&AE(&)R;W=S97(L(&-O;G9E<G0@=&\@
M=&AE(&-U<G)E;G0@8VAA<F%C=&5R('-E="X*("`@("`@("`@*B!!9&1I=&EO
M;F%L;'DL(&EF('1H92!B<F]W<V5R(&1O97,@;F]T('-U<'!O<G0@551&+3@L
M(&=I=F4@=&AE"B`@("`@("`@("H@=7-E<B!A(&QI;FL@=&\@;W!E;B!T:&4@
M<&%R="!I;B!A(&YE=R!W:6YD;W<@=VET:"!T:&4@8V]R<F5C=`H@("`@("`@
M("`J(&-H87)A8W1E<B!S970N("HO"B`@("`@("`@)&-H87)S970@/2`D;6EM
M95]P87)T+3YG971#:&%R<V5T*"D["B`@("`@("`@:68@*"1C:&%R<V5T*2![
M"B`@("`@("`@("`@("1C:&%R<V5T7W5P<&5R(#T@4W1R:6YG.CIU<'!E<B@D
M8VAA<G-E="D["B`@("`@("`@("`@(&EF("@H)&-H87)S971?=7!P97(@(3T@
M)U53+4%30TE))RD@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^=FEE=T%S
M071T86-H;65N="@I*2!["B`@("`@("`@("`@("`@("`D9&5F875L=%]C:&%R
M<V5T(#T@4W1R:6YG.CIU<'!E<BA.3%,Z.F=E=$-H87)S970H*2D["B`@("`@
M("`@("`@("`@("!I9B`H)&-H87)S971?=7!P97(@(3T@)&1E9F%U;'1?8VAA
M<G-E="D@>PH@("`@("`@("`@("`@("`@("`@("1M:6UE7W!A<G0M/G-E=$-O
M;G1E;G1S*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&UI;65?<&%R="T^9V5T
M0V]N=&5N=',H*2P@)&-H87)S970L("1D969A=6QT7V-H87)S970I*3L*("`@
M("`@("`@("`@("`@("`@("`D;6EM95]P87)T+3YS971#:&%R<V5T*"1D969A
M=6QT7V-H87)S970I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9&5F875L
M=%]C:&%R<V5T("$]("=55$8M."<I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T871U<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W!R:6YT9BA?*")4:&ES(&UE<W-A9V4@=V%S('=R:71T96X@:6X@82!C
M:&%R86-T97(@<V5T("@E<RD@;W1H97(@=&AA;B!Y;W5R(&]W;BXB*2P@:'1M
M;'-P96-I86QC:&%R<R@D8VAA<G-E="DI+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W!R:6YT9BA?*"))9B!I="!I<R!N;W0@9&ES<&QA>65D(&-O
M<G)E8W1L>2P@)7,@=&\@;W!E;B!I="!I;B!A(&YE=R!W:6YD;W<N(BDL("1T
M:&ES+3YL:6YK5FEE=TI3*"1M:6UE7W!A<G0L("=V:65W7V%T=&%C:"<L(%\H
M(F-L:6-K(&AE<F4B*2DI"B`@("`@("`@("`@("`@("`@("`@("`@("D["B`@
M("`@("`@("`@("`@("`@("`@("`@("1M<V<@/2`D=&AI<RT^9F]R;6%T4W1A
M='5S37-G*"1S=&%T=7,L(&YU;&PL(&9A;'-E*2`N("1M<V<["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D=FEE=V5R+3YS971-24U%4&%R="@D;6EM
M95]P87)T*3L*("`@("`@("`D<&%R86US(#T@87)R87DH)B1T:&ES*3L*("`@
M("`@("!I9B`H)&%T=&%C:&UE;G0I('L*("`@("`@("`@("`@)&US9R`N/2`D
M=FEE=V5R+3YR96YD97)!='1A8VAM96YT26YF;R@D<&%R86US*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D;7-G("X]("1V:65W97(M/G)E;F1E
M<B@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;7-G.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@=&AE(&UE<W-A9V4@9&5C:61I
M;F<@=VAA="!-24U%(%!A<G1S('1O('-H;W<N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!&86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@8G5I;&1-97-S86=E*"D*("`@('L*("`@("`@("`D=&AI<RT^7V%T
M8R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]P87)T<R`](&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/E]S=6UM87)Y(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*"%I<U]A*"1T:&ES+3Y?;65S<V%G92P@)TU)345?365S<V%G92<I*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@
M("\J($YO=R!D:7-P;&%Y('1H92!P87)T<RX@*B\*("`@("`@("`D;6EM95]P
M87)T(#T@)'1H:7,M/E]M97-S86=E+3YG971"87-E4&%R="@I.PH@("`@("`@
M("1T:&ES+3YB=6EL9$UE<W-A9V5087)T*"1M:6UE7W!A<G0I.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%!R;V-E<W-E
M<R!A($U)345?4&%R="!A;F0@<W1O<F5S('1H92!D:7-P;&%Y(&EN9F]R;6%T
M:6]N(&EN('1H92!I;G1E<FYA;`H@("`@("H@8VQA<W,@=F%R:6%B;&5S+@H@
M("`@("H*("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H
M92!-24U%7U!A<G0@;V)J96-T('1O('!R;V-E<W,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T97AT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!B=6EL9$UE<W-A9V5087)T*"8D;6EM95]P87)T*0H@("`@
M>PH@("`@("`@("1M<V<@/2`G)SL*"B`@("`@("`@+RH@268@=V4@8V%N)W0@
M9&ES<&QA>2!T:&4@<&%R="!I;FQI;F4L(&%D9"!I="!T;R!T:&4@871T86-H
M;65N=`H@("`@("`@("`@(&QI<W0N($EF('1H92!-24U%($E$(&]F('1H92!C
M=7)R96YT('!A<G0@:7,@)S`G+"!T:&5N(&9O<F-E(&$*("`@("`@("`@("!R
M96YD97(@;V8@=&AE('!A<G0@*'-I;F-E(&ET(&ES('1H92!B87-E('!A<G0@
M86YD+"!W:71H;W5T"B`@("`@("`@("`@871T96UP=&EN9R!T;R!R96YD97(L
M('1H92!M97-S86=E('=I;&P@04Q705E3(&%P<&5A<B!E;7!T>2X@*B\*("`@
M("`@("!I9B`H(21T:&ES+3YC86Y$:7-P;&%Y26YL:6YE*"1M:6UE7W!A<G0I
M("8F"B`@("`@("`@("`@("@D;6EM95]P87)T+3YG971-24U%260H*2`A/2`P
M*2D@>PH@("`@("`@("`@("`O*B!.;W0@9&ES<&QA>6EN9R!I;FQI;F4[(&%D
M9"!T;R!T:&4@871T86-H;65N=',@;&ES="X@*B\*("`@("`@("`@("`@:68@
M*"@D=&AI<RT^7V1I<W!L87E4>7!E(#T]($U)345?0T].5$5.5%-?1$E34$Q!
M65]465!%7TQ)4U0I('Q\"B`@("`@("`@("`@("`@("`H)'1H:7,M/E]D:7-P
M;&%Y5'EP92`]/2!-24U%7T-/3E1%3E137T1)4U!,05E?5%E015]"3U1(*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E=%-U;6UA<GDH)&UI;65?<&%R
M="P@)V%T=&%C:&UE;G0G*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H*"1T:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$25-0
M3$%97U194$5?24Y,24Y%*2!\?`H@("`@("`@("`@("`@("`@*"1T:&ES+3Y?
M9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]4
M2"DI('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9713=6UM87)Y*"1M:6UE
M7W!A<G0L("=P87)T)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($-H96-K('1O('-E92!I9B!A;GD@871T86-H;65N="!I;F9O<FUA=&EO;B!C
M86X@8F4@<F5N9&5R960@8GD*("`@("`@("`@("`@("`@=&AE($U)345?5FEE
M=V5R+B`J+PH@("`@("`@("`@("`D;7-G(#T@)'1H:7,M/G)E;F1E<DU)345!
M='1A8VAM96YT26YF;R@D;6EM95]P87)T*3L*("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;7-G*2D@>PH@("`@("`@("`@("`@("`@)&ME>2`]("1T:&ES+3Y?
M9V5T34E-14ME>2@D;6EM95]P87)T*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R='-;)&ME>5T@/2`D;7-G.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&US9R`]("1T:&ES+3YR96YD97)-24U%
M4&%R="@D;6EM95]P87)T*3L*("`@("`@("`@("`@)&ME>2`]("1T:&ES+3Y?
M9V5T34E-14ME>2@D;6EM95]P87)T*3L*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7V%T=&%C:#@R,BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)T
M<ULD:V5Y72`]("1M<V<["B`@("`@("`@("`@('T*("`@("`@("`@("`@+RH@
M4V]M92!-24U%7U9I97=E<G,@<V5T('1H92!S=6UM87)Y(&)Y('1H96UE;'9E
M<RP@<V\@;VYL>0H@("`@("`@("`@("`@*B!A9&0@=&\@871T86-H;65N="]I
M;FQI;F4@;&ES=',@:68@;F]T:&EN9R!H87,@8F5E;B!S970*("`@("`@("`@
M("`@("H@87,@;V8@>65T+B`J+PH@("`@("`@("`@("!I9B`H*"@D;6EM95]P
M87)T+3YG9714>7!E*"D@(3T@)VUU;'1I<&%R="]M:7AE9"<I('Q\"B`@("`@
M("`@("`@("`@("`@(65M<'1Y*"1M<V<I*2`F)@H@("`@("`@("`@("`@("`@
M(65M<'1Y*"1K97DI("8F"B`@("`@("`@("`@("`@("`A)'1H:7,M/F=E=$EN
M9&5X*"1K97DL("=S=6UM87)Y)RDI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3YS9713=6UM87)Y*"1M:6UE7W!A<G0L("=P87)T)RD["B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]A='1A8V@X,C(@)B8*("`@("`@("`@("`@("`@
M("`@("`H*"1T:&ES+3Y?9&ES<&QA>51Y<&4@/3T@34E-15]#3TY414Y44U]$
M25-03$%97U194$5?3$E35"D@?'P*("`@("`@("`@("`@("`@("`@("`H)'1H
M:7,M/E]D:7-P;&%Y5'EP92`]/2!-24U%7T-/3E1%3E137T1)4U!,05E?5%E0
M15]"3U1(*2DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4W5M
M;6%R>2@D;6EM95]P87)T+"`G871T86-H;65N="<I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&UI
M;65?<&%R="T^9V5T26YF;W)M871I;VXH)VAE861E<B<I*2!["B`@("`@("`@
M("`@("\J($EF('1H:7,@:7,@;65S<V%G92]R9F,X,C(@<&%R="P@86YD(&ET
M(&ES(&UA<FME9"!A<R!A;@H@("`@("`@("`@("`@*B!A='1A8VAM96YT+"!W
M92!N965D('1O(&QE="!F=71U<F4@8V%L;',@=&\@8G5I;&1-97-S86=E4&%R
M="@I"B`@("`@("`@("`@("`J(&MN;W<@=&AA="!I="!S:&]U;&0@;6%R:R!E
M;6)E9&1E9"!P87)T<R!A<R!N;W0@=FEE=V%B;&4*("`@("`@("`@("`@("H@
M:6YL:6YE+B`J+PH@("`@("`@("`@("`D:6YC<F5M96YT7S@R,B`](&9A;'-E
M.PH@("`@("`@("`@("!I9B`H*"1M:6UE7W!A<G0M/F=E=%1Y<&4H*2`]/2`G
M;65S<V%G92]R9F,X,C(G*2`F)@H@("`@("`@("`@("`@("`@*"1M:6UE7W!A
M<G0M/F=E=$1I<W!O<VET:6]N*"D@/3T@)V%T=&%C:&UE;G0G*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]A='1A8V@X,C(K*SL*("`@("`@("`@("`@
M("`@("1I;F-R96UE;G1?.#(R(#T@=')U93L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@9F]R96%C:"`H)&UI;65?<&%R="T^9V5T4&%R=',H*2!A<R`D
M<&%R="D@>PH@("`@("`@("`@("`@("`@)&US9R`N/2`D=&AI<RT^8G5I;&1-
M97-S86=E4&%R="@D<&%R="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@D:6YC<F5M96YT7S@R,BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A='1A8V@X,C(M+3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@
M=FEE=VEN9R!T:&ES('!A9V4@87,@86X@871T86-H;65N="!T:')O=6=H('9I
M97<N<&AP/PH@("`@("H@5&AI<R!M971H;V0@8V%N(&%L<V\@8F4@8V%L;&5D
M('9I82!-24U%7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"DN"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'!O<'5P("!)9B!T<G5E+"!A;'-O
M(&-H96-K(&EF('=E(&%R92!V:65W:6YG(&%T=&%C:&UE;G0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@:6X@<&]P=7`@=FEE=R!W:6YD;W<N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('=E(&%R92!V
M:65W:6YG('1H:7,@<&%R="!A<R!A;B!A='1A8VAM96YT"B`@("`@*B`@("`@
M("`@("`@("`@("`@('1H<F]U9V@@=FEE=RYP:'`N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('9I97=!<T%T=&%C:&UE;G0H)'!O<'5P(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<F5T=7)N("@H<W1R<&]S*"1?4T525D526R=02%!?4T5,1B==
M+"`G=FEE=RYP:'`G*2`A/3T@9F%L<V4I("8F"B`@("`@("`@("`@("`@("`H
M(21P;W!U<"!\?"!5=&EL.CIG971&;W)M1&%T82@G<&]P=7!?=FEE=R<I*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S(&$@<W5M;6%R>2!E;G1R>2X*
M("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!4
M:&4@34E-15]087)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y
M<&4@("`@("`@("`@(%1H92!S=6UM87)Y(&-A8VAE('1O('5S92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T4W5M;6%R>2@F)&UI;65?<&%R="P@)'1Y<&4I
M"B`@("!["B`@("`@("`@:68@*"1T>7!E(#T]("=A='1A8VAM96YT)RD@>PH@
M("`@("`@("`@("`D8V%C:&4@/2`F)'1H:7,M/E]A=&,["B`@("`@("`@?2!E
M;'-E:68@*"1T>7!E(#T]("=P87)T)RD@>PH@("`@("`@("`@("`D8V%C:&4@
M/2`F)'1H:7,M/E]S=6UM87)Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1K97D@/2`D=&AI<RT^
M7V=E=$U)345+97DH)&UI;65?<&%R="D["@H@("`@("`@("1T:&ES+3Y?<W5M
M;6%R>51Y<&4@/2`D='EP93L*("`@("`@("`D<W5M;6%R>2`]("1T:&ES+3YP
M87)T4W5M;6%R>2@D;6EM95]P87)T+"!N=6QL*3L*("`@("`@("`D=&AI<RT^
M7W-U;6UA<GE4>7!E(#T@;G5L;#L*"B`@("`@("`@:68@*"%E;7!T>2@D<W5M
M;6%R>2DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<G1S
M6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)T<ULD:V5Y
M72`](&YU;&P["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-A8VAE6R1K
M97E=(#T@)'-U;6UA<GD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!A;B!A<G)A>2!S=6UM87)I>FEN9R!A('!A<G0@;V8@82!-
M24U%(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F
M)&UI;65?<&%R="`@5&AE($U)345?4&%R="!T;R!S=6UM87)I>F4N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9W5E<W,@("`@("`@("!)<R!T:&ES(&$@=&5M
M<&]R87)Y(&=U97-S960M='EP92!P87)T/PH@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(%1H92!S=6UM87)Y(&]F('1H92!P87)T+@H@("`@("H@("`@
M("`@("`@("`@("`@6S!=(#T@26-O;@H@("`@("H@("`@("`@("`@("`@("`@
M6S%=(#T@24U!4"!)1`H@("`@("H@("`@("`@("`@("`@("`@6S)=(#T@1&5S
M8W)I<'1I;VX*("`@("`J("`@("`@("`@("`@("`@(%LS72`]($U)344@5'EP
M90H@("`@("H@("`@("`@("`@("`@("`@6S1=(#T@4VEZ90H@("`@("H@("`@
M("`@("`@("`@("`@6S5=(#T@1&]W;FQO860@;&EN:R]I8V]N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!A<G13=6UM87)Y*"8D;6EM95]P87)T+"`D9W5E<W,@
M/2!F86QS92D*("`@('L*("`@("`@("`D871T86-H;65N="`]("@D;6EM95]P
M87)T+3YG971$:7-P;W-I=&EO;B@I(#T]("=A='1A8VAM96YT)RD["B`@("`@
M("`@)&)Y=&5S(#T@)&UI;65?<&%R="T^9V5T0GET97,H*3L*("`@("`@("`D
M9&5S8W)I<'1I;VX@/2!H=&UL<W!E8VEA;&-H87)S*"1M:6UE7W!A<G0M/F=E
M=$1E<V-R:7!T:6]N*'1R=64L('1R=64I*3L*("`@("`@("`D<W5M;6%R>2`]
M(&%R<F%Y*"D["B`@("`@("`@)'1Y<&4@/2!H=&UL<W!E8VEA;&-H87)S*"1M
M:6UE7W!A<G0M/F=E=%1Y<&4H*2D["B`@("`@("`@)'9I97=E<B`]("8D=&AI
M<RT^9V5T34E-159I97=E<B@D;6EM95]P87)T*3L*("`@("`@("!I9B`H(21V
M:65W97(I('L*("`@("`@("`@("`@<F5T=7)N("1S=6UM87)Y.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4F5T=7)N(&EF('=E('-T:6QL(&1I9&XG="!F:6YD
M(&$@;F%T:79E(&UI;64@=FEE=V5R"B`@("`@("`@("H@9F]R(&$@9W5E<W-E
M9"!M:6UE('1Y<&4N("HO"B`@("`@("`@:68@*"1G=65S<R`F)B!I<U]A*"1V
M:65W97(L("=-24U%7U9I97=E<E]D969A=6QT)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1S=6UM87)Y.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T('1H
M92!-24U%(&ED(&EN9&5X+B`J+PH@("`@("`@("1I9"`]("1T:&ES+3Y?9V5T
M34E-14ME>2@D;6EM95]P87)T*3L*"B`@("`@("`@+RH@26-O;B!C;VQU;6XN
M("HO"B`@("`@("`@)'-U;6UA<GE;72`]($AO<F1E.CII;6<H)'9I97=E<BT^
M9V5T26-O;B@D='EP92DL(&YU;&PL(&YU;&PL("<G*3L*"B`@("`@("`@+RH@
M3G5M8F5R(&-O;'5M;BX@*B\*("`@("`@("!I9B`H*"1T:&ES+3Y?9&ES<&QA
M>51Y<&4@/3T@34E-15]#3TY414Y44U]$25-03$%97U194$5?0D]42"D@)B8*
M("`@("`@("`@("`@(6ES7VYU;&PH)'1H:7,M/E]S=6UM87)Y5'EP92DI('L*
M("`@("`@("`@("`@)'-U;6UA<GE;72`]("<\82!I9#TB;6EM95]C;VYT96YT
M<U\G("X@)'1H:7,M/E]S=6UM87)Y5'EP92`N("=?)R`N("1I9"`N("<B(&AR
M968](B-M:6UE7V-O;G1E;G1S7R<@+B`H*"1T:&ES+3Y?<W5M;6%R>51Y<&4@
M/3T@)V%T=&%C:&UE;G0G*2`_)W!A<G0G(#H@)V%T=&%C:&UE;G0G*2`N("=?
M)R`N("1I9"`N("<B/B<@+B`D:60@+B`G/"]A/B<["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'-U;6UA<GE;72`]("1I9#L*("`@("`@("!]"@H@
M("`@("`@("\J($YA;64O=&5X="!P87)T(&-O;'5M;BX@*B\*("`@("`@("!I
M9B`H(21T:&ES+3Y?;&EN:W,@?'P*("`@("`@("`@("`@*"$D871T86-H;65N
M="`F)B!E;7!T>2@D8GET97,I*2`@?'P*("`@("`@("`@("`@(6ES<V5T*"1T
M:&ES+3Y?=FEE=TE$6R=V:65W)UTI('Q\"B`@("`@("`@("`@(&ES7V$H)'9I
M97=E<BP@)TU)345?5FEE=V5R7V1E9F%U;'0G*2D@>PH@("`@("`@("`@("`D
M<W5M;6%R>5M=(#T@)&1E<V-R:7!T:6]N.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1P87)A;5]A<G)A>2`](&%R<F%Y*"D["B`@("`@("`@("`@
M(&EF("@D9W5E<W,@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("1P87)A
M;5]A<G)A>5LG8W1Y<&4G72`]("1T>7!E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1S=6UM87)Y6UT@/2`D=&AI<RT^;&EN:U9I97=*4R@D;6EM95]P
M87)T+"`D=&AI<RT^7W9I97=)1%LG=FEE=R==+"`D9&5S8W)I<'1I;VXL(&YU
M;&PL(&YU;&PL("1P87)A;5]A<G)A>2D["B`@("`@("`@?0H*("`@("`@("`O
M*B!-24U%('1Y<&4@8V]L=6UN+B`J+PH@("`@("`@(&EF("@D9W5E<W,I('L*
M("`@("`@("`@("`@)'-U;6UA<GE;72`]("<\96T^)R`N('-P<FEN=&8H7R@B
M5FEE=R!A<R`E<R(I+"`D='EP92D@+B`G/"]E;3XG.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S=6UM87)Y6UT@/2`G6R<@+B`D='EP92`N("==
M)SL*("`@("`@("!]"@H@("`@("`@("\J(%-I>F4@0V]L=6UN+B`J+PH@("`@
M("`@("1S:7IE(#T@)&UI;65?<&%R="T^9V5T4VEZ92AT<G5E*3L*("`@("`@
M("!I9B`H(65M<'1Y*"1B>71E<RD@)B8*("`@("`@("`@("`@*"1M:6UE7W!A
M<G0M/F=E=$-U<G)E;G1%;F-O9&EN9R@I(#T]("=B87-E-C0G*2D@>PH@("`@
M("`@("`@("`O*B!&<F]M(%)&0R`R,#0U(%LV+CA=.B`B+BXN=&AE(&5N8V]D
M960@9&%T82!A<F4@8V]N<VES=&5N=&QY"B`@("`@("`@("`@("`@(&]N;'D@
M86)O=70@,S,@<&5R8V5N="!L87)G97(@=&AA;B!T:&4@=6YE;F-O9&5D(&1A
M=&$N(B`J+PH@("`@("`@("`@("`D<VEZ92`](&YU;6)E<E]F;W)M870H;6%X
M*"@H)&)Y=&5S("H@,"XW-2D@+R`Q,#(T*2P@,2DI.PH@("`@("`@("`@("`D
M<W5M;6%R>5M=(#T@)SQA8W)O;GEM('1I=&QE/2(G("X@7R@B07!P<F]X:6UA
M=&4@4VEZ92(I("X@)R(^)R`N('-P<FEN=&8H7R@B)7,@2T(B*2P@)'-I>F4I
M("X@)SPO86-R;VYY;3XG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1S=6UM87)Y6UT@/2!S<')I;G1F*%\H(B5S($M"(BDL("1S:7IE*3L*("`@
M("`@("!]"@H@("`@("`@("\J($1O=VYL;V%D(&-O;'5M;BX@*B\*("`@("`@
M("!I9B`H(21T:&ES+3Y?;&EN:W,@?'P*("`@("`@("`@("`@:7-?;G5L;"@D
M<VEZ92D@?'P*("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?=FEE=TE$6R=D
M;W=N;&]A9"==*2D@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@;G5L;#L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<W5M;6%R>5M=(#T@)'1H
M:7,M/FQI;FM6:65W*"1M:6UE7W!A<G0L("1T:&ES+3Y?=FEE=TE$6R=D;W=N
M;&]A9"==+"!(;W)D93HZ:6UG*"=D;W=N;&]A9"YP;F<G+"!?*")$;W=N;&]A
M9"(I+"!N=6QL+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI+"!A<G)A>2@G:G-T97AT)R`]/B!S<')I;G1F*%\H(D1O=VYL
M;V%D("5S(BDL("1M:6UE7W!A<G0M/F=E=$1E<V-R:7!T:6]N*'1R=64L('1R
M=64I*2DL('1R=64I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE($U)
M344@5'EP92!I<R!A<'!L:6-A=&EO;B]O8W1E="US=')E86TL('1R>2!T;R!U
M<V4*("`@("`@("`@("!T:&4@9FEL92!E>'1E;G-I;VX@=&\@9&5T97)M:6YE
M('1H92!A8W1U86P@34E-12!T>7!E+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7VQI;FMS("8F"B`@("`@("`@("`@("$D9W5E<W,@)B8*("`@("`@("`@("`@
M(6ES7VYU;&PH)'-I>F4I("8F"B`@("`@("`@("`@("@D='EP92`]/2`G87!P
M;&EC871I;VXO;V-T970M<W1R96%M)RD@?'P*("`@("`@("`@("`@*"1T>7!E
M(#T]("=A<'!L:6-A=&EO;B]B87-E-C0G*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+TUA9VEC+G!H<"<["B`@
M("`@("`@("`@("1N97=?='EP92`]($U)345?36%G:6,Z.F9I;&5N86UE5&]-
M24U%*$U)344Z.F1E8V]D92@D;6EM95]P87)T+3YG971.86UE*"DI*3L*("`@
M("`@("`@("`@:68@*"1N97=?='EP92`A/2`G87!P;&EC871I;VXO;V-T970M
M<W1R96%M)RD@>PH@("`@("`@("`@("`@("`@)'1E;7!?<&%R="`]("1M:6UE
M7W!A<G0["B`@("`@("`@("`@("`@("`D=&5M<%]P87)T+3YS9714>7!E*"1N
M97=?='EP92D["B`@("`@("`@("`@("`@("`D<W5M;6%R>2`](&%R<F%Y7VUA
M<"@*("`@("`@("`@("`@("`@("`@("!C<F5A=&5?9G5N8W1I;VXH)R1A+"`D
M8B<L("=R971U<FX@96UP='DH)&(I(#\@)&$@.B`D82`N(%PG/&)R("\^7"<@
M+B`D8CLG*2P*("`@("`@("`@("`@("`@("`@("`D<W5M;6%R>2P*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^<&%R=%-U;6UA<GDH)'1E;7!?<&%R="P@
M=')U92DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'-U;6UA<GD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(%523"!T;R!T:&4@=FEE=RYP:'`@<&%G92X*("`@("`J"B`@("`@*B!`<&%R
M86T@34E-15]087)T("8D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C
M="!T;R!V:65W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&%C=&EO;DE$("`@
M("`@5&AE($%C=&EO;DE$('1O('!E<F9O<FTN"B`@("`@*B!`<&%R86T@87)R
M87D@)'!A<F%M<R`@("`@("`@("!!(&QI<W0@;V8@86YY(&%D9&ET:6]N86P@
M<&%R86UE=&5R<R!T:&%T"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N965D('1O(&)E('!A<W-E9"!T;R!V:65W+G!H<"X@*&ME>2`]
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE*0H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&1L;V%D("`@("`@("`@4VAO=6QD('=E
M(&=E;F5R871E(&$@9&]W;FQO860@;&EN:S\*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(%523"!T;R!V:65W+G!H<"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@=7)L5FEE=R@F)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D<&%R
M86US(#T@87)R87DH*2P@)&1L;V%D(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M+RH@1V5T('1H92!-24U%($E$(&9O<B!T:&ES('!A<G0N("HO"B`@("`@("`@
M)&ED(#T@*&ES<V5T*"1P87)A;7-;)VED)UTI*2`_("1P87)A;7-;)VED)UT@
M.B`D;6EM95]P87)T+3YG971-24U%260H*3L*"B`@("`@("`@+RH@061D('1H
M92!N96-E<W-A<GD@;&]C86P@<&%R86UE=&5R<RX@*B\*("`@("`@("`D<&%R
M86US6R=A8W1I;VY)1"==(#T@)&%C=&EO;DE$.PH@("`@("`@("1P87)A;7-;
M)VED)UT@/2`D:60["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y7VUE<F=E*"1P
M87)A;7,L("1T:&ES+3YC86-H94E$55),4&%R86TH*2D["@H@("`@("`@(&EF
M("@D9&QO860I('L*("`@("`@("`@("`@)'5R;"`]($AO<F1E.CID;W=N;&]A
M9%5R;"@D;6EM95]P87)T+3YG971.86UE*'1R=64L('1R=64I+"`D<&%R86US
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7)L(#T@571I;#HZ
M861D4&%R86UE=&5R*$AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G=FEE=RYP:'`G
M*2P@)'!A<F%M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'5R;#L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E(&$@;&EN:R!T;R!T:&4@
M=FEE=RYP:'`@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T
M("8D;6EM95]P87)T("!4:&4@34E-15]087)T(&]B:F5C="!T;R!V:65W+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)&%C=&EO;DE$("`@("`@5&AE(&%C=&EO
M;DE$('9A;'5E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("`@
M("`@5&AE(&QI;FL@=&5X="X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("`@("`@("`@($$@;&ES="!O9B!A9&1I=&EO;F%L('!A<F%M971E<G,N"B`@
M("`@*B`@("=C;&%S<R<@("`@("`@+2`@5&AE($-34R!C;&%S<R!T;R!U<V4N
M"B`@("`@*B`@("=J<W1E>'0G("`@("`@+2`@5&AE($I3('1E>'0@=&\@=7-E
M+@H@("`@("H@("`G=FEE=W!A<F%M<R<@("T@($$@;&ES="!O9B!A;GD@861D
M:71I;VYA;"!P87)A;65T97)S('1H870@;F5E9"!T;R!B90H@("`@("H@("`@
M("`@("`@("`@("`@("`@('!A<W-E9"!T;R!V:65W+G!H<"X*("`@("`J($!P
M87)A;2!B;V]L96%N("1D;&]A9"`@("`@("`@(%-H;W5L9"!W92!G96YE<F%T
M92!A(&1O=VYL;V%D(&QI;FL_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@($$@2%1-3"!H<F5F(&QI;FL@=&\@=FEE=RYP:'`N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI;FM6:65W*"8D;6EM95]P87)T+"`D86-T:6]N240L("1T
M97AT+"`D<&%R86US(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@
M("1D;&]A9"`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'!A
M<F%M<ULG8VQA<W,G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULG8VQA<W,G
M72`](&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'!A<F%M
M<ULG:G-T97AT)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)VIS=&5X="==
M(#T@)'1E>'0["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'!A<F%M
M<ULG=FEE=W!A<F%M<R==*2D@>PH@("`@("`@("`@("`D<&%R86US6R=V:65W
M<&%R86US)UT@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1D
M;&]A9"D@>PH@("`@("`@("`@("`D=VEN9&]W(#T@;G5L;#L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=VEN9&]W(#T@)W9I97=?)R`N(&%B<RAC
M<F,S,BAM:6-R;W1I;64H*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M($AO<F1E.CIL:6YK*"1T:&ES+3YU<FQ6:65W*"1M:6UE7W!A<G0L("1A8W1I
M;VY)1"P@)'!A<F%M<ULG=FEE=W!A<F%M<R==+"`D9&QO860I+"`D<&%R86US
M6R=J<W1E>'0G72P@)'!A<F%M<ULG8VQA<W,G72P@)'=I;F1O=RD@+B`D=&5X
M="`N("<\+V$^)SL*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E(&$@
M:F%V87-C<FEP="!L:6YK('1O('1H92!V:65W+G!H<"!P86=E+@H@("`@("H*
M("`@("`J($!P87)A;2!-24U%7U!A<G0@)B1M:6UE7W!A<G0@(%1H92!-24U%
M7U!A<G0@;V)J96-T('1O('9I97<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M86-T:6]N240@("`@("!4:&4@06-T:6]N240@=&\@<&5R9F]R;2X*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("`@("`@("`@(%1H92!L:6YK('1E>'0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1J<W1E>'0@("`@("`@("!4:&4@2F%V
M87-C<FEP="!L:6YK('1E>'0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C<W,@
M("`@("`@("`@("!4:&4@0U-3(&-L87-S('1O('5S92X*("`@("`J($!P87)A
M;2!A<G)A>2`D<&%R86US("`@("`@("`@($$@;&ES="!O9B!A;GD@861D:71I
M;VYA;"!P87)A;65T97)S('1H870*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&YE960@=&\@8F4@<&%S<V5D('1O('9I97<N<&AP+B`H
M:V5Y(#T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YA
M;64I"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=VED9V5T("`@("`@("!)9B!T
M<G5E('5S92!(;W)D93HZ=VED9V5T*"D@=&\@9V5N97)A=&4L"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(;W)D93HZ;&EN:R@I(&]T
M:&5R=VES92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@02!(5$U,
M(&AR968@;&EN:R!T;R!V:65W+G!H<"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&EN:U9I97=*4R@F)&UI;65?<&%R="P@)&%C=&EO;DE$+"`D=&5X="P@)&IS
M=&5X="`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("1C<W,@/2!N
M=6QL+"`D<&%R86US(#T@87)R87DH*2P@)'=I9&=E="`](&9A;'-E*0H@("`@
M>PH@("`@("`@("\J($EF('9I97=I;F<@=FEA('9I97<N<&AP+"!W92!D;VXG
M="!W86YT(&$@2E,@;&EN:RX@*B\*("`@("`@("!I9B`H)'1H:7,M/G9I97=!
M<T%T=&%C:&UE;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQI
M;FM6:65W*"1M:6UE7W!A<G0L("1A8W1I;VY)1"P@)'1E>'0L("1P87)A;7,I
M.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1J<W1E>'0I*2!["B`@
M("`@("`@("`@("1J<W1E>'0@/2!S<')I;G1F*%\H(E9I97<@)7,B*2P@)&UI
M;65?<&%R="T^9V5T1&5S8W)I<'1I;VXH=')U92P@=')U92DI.PH@("`@("`@
M('T*("`@("`@("`D<&%R86US6R=P;W!U<%]V:65W)UT@/2`Q.PH*("`@("`@
M("`D=7)L(#T@)'1H:7,M/G5R;%9I97<H)&UI;65?<&%R="P@)&%C=&EO;DE$
M+"`D<&%R86US*3L*"B`@("`@("`@:68@*"$H)&ED(#T@)&UI;65?<&%R="T^
M9V5T34E-14ED*"DI*2!["B`@("`@("`@("`@("1I9"`](&%B<RAC<F,S,BAS
M97)I86QI>F4H)&UI;65?<&%R="DI*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D=VED9V5T*2!["B`@("`@("`@("`@(')E='5R;B!(;W)D93HZ=VED9V5T
M*"<C)RP@)&IS=&5X="P@)&-S<RP@;G5L;"P@(G9I97<H)R(@+B`D=7)L("X@
M(B<L("<B("X@)&ED("X@(B<I.R!R971U<FX@9F%L<V4[(BP@)'1E>'0I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!(;W)D93HZ;&EN
M:R@G(R<L("1J<W1E>'0L("1C<W,L(&YU;&PL(")V:65W*"<B("X@)'5R;"`N
M("(G+"`G(B`N("1I9"`N("(G*3L@<F5T=7)N(&9A;'-E.R(I("X@)'1E>'0@
M+B`G/"]A/B<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4')I
M;G1S(&]U="!T:&4@<W1A='5S(&UE<W-A9V4@9F]R(&$@9VEV96X@34E-12!0
M87)T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@("`@5&AE
M(&UE<W-A9V4@=&\@;W5T<'5T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6UG
M("`@("!!;B!I;6%G92!L:6YK('1O(&%D9"!T;R!T:&4@8F5G:6YN:6YG(&]F
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!M97-S86=E+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)'!R:6YT("!/=71P=70@=&AI<R!M97-S
M86=E('=H96X@:6X@82!P<FEN="!V:65W/PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D8VQA<W,@("!!;B!O<'1I;VYA;"!S='EL92!F;W(@=&AE('-T871U<R!B
M;W@N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T
M960@<W1A='5S(&UE<W-A9V4@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!F;W)M8713=&%T=7--<V<H)&US9RP@)&EM9R`](&YU;&PL("1P<FEN=&%B
M;&4@/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&%S
M<R`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;7-G*2D@
M>PH@("`@("`@("`@("`D;7-G(#T@87)R87DH)&US9RD["B`@("`@("`@?0H*
M("`@("`@("`O*B!)9B!W92!A<F4@=FEE=VEN9R!A<R!A;B!A='1A8VAM96YT
M+"!D;VXG="!P<FEN="!(5$U,(&-O9&4N("HO"B`@("`@("`@:68@*"1T:&ES
M+3YV:65W07-!='1A8VAM96YT*"DI('L*("`@("`@("`@("`@<F5T=7)N(&EM
M<&QO9&4H(EQN(BP@)&US9RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M;G5L;"@D8VQA<W,I*2!["B`@("`@("`@("`@("1C;&%S<R`]("=M:6UE4W1A
M='5S365S<V%G92<["B`@("`@("`@?0H@("`@("`@("1T97AT(#T@)SQT86)L
M92!C;&%S<STB)R`N("1C;&%S<R`N("<B/B<["@H@("`@("`@("\J($EF(&YO
M(&EM86=E+"!S:6UP;'D@<')I;G0@;W5T('1H92!M97-S86=E+B`J+PH@("`@
M("`@(&EF("AI<U]N=6QL*"1I;6<I*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1M<V<@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@)'1E>'0@+CT@)SQT
M<CX\=&0^)R`N("1V86P@+B`G/"]T9#X\+W1R/B<@+B`B7&XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@+CT@
M)SQT<CX\=&0@=F%L:6=N/2)M:61D;&4B/B<@+B`D:6UG("X@)R9N8G-P.SPO
M=&0^)SL*("`@("`@("`@("`@)'1E>'0@+CT@)SQT9#XG.PH*("`@("`@("`@
M("`@:68@*&-O=6YT*"1M<V<I(#T](#$I('L*("`@("`@("`@("`@("`@("1T
M97AT("X]("1M<V=;,%T["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&5X="`N/2`G/'1A8FQE/B<["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D;7-G(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D
M=&5X="`N/2`G/'1R/CQT9#XG("X@)'9A;"`N("<\+W1D/CPO='(^)R`N(")<
M;B(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&5X="`N
M/2`G/"]T86)L93XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T97AT
M("X]("<\+W1D/CPO='(^)R`N(")<;B(["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1E>'0@+B`G/"]T86)L93XG.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N(&$@<&]I;G1E<B!T;R!T:&4@8F%S92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5T=7)N<R!A('!O:6YT97(@=&\@
M=&AE(&)A<V4@;V)J96-T+@H@("`@("H@("`@("`@("`@("`@("`@4F5T=7)N
M<R!F86QS92!I9B!T:&5R92!I<R!N;R!B87-E(&]B:F5C="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F=E=$)A<V5/8FIE8W10='(H*0H@("`@>PH@("`@("`@
M(&EF("AI<U]N=6QL*"1T:&ES+3Y?8F%S92DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V)A<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T('1H92!-24U%7T-O;G1E;G1S.CH@;V)J96-T('1O(&)E(&-A8VAE
M9"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("!4:&4@8V%C:&4@3TE$+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?861D0V%C:&4H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL
M*"1T:&ES+3Y?<V5S<VEO;D-A8VAE240I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<V5S<VEO;D-A8VAE240@/2`D=&AI<RT^7V-R96%T94-A8VAE240H*3L*
M("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH87)R87DH
M)B1T:&ES+"`G7V%D9$-A8VAE4VAU=&1O=VXG*2D["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]S97-S:6]N0V%C:&5)1#L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!U;FEQ=64@8V%C:&4@240@9F]R('1H
M:7,@;V)J96-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!!('5N:7%U92!C86-H92!)1"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T94-A8VAE240H*0H@("`@>PH@
M("`@("`@(')E='5R;B!M9#4H;6EC<F]T:6UE*"DI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V%V97,@82!C;W!Y(&]F('1H92!-24U%7T-O;G1E;G1S(&]B
M:F5C="!A="!T:&4@96YD(&]F(&$@<F5Q=65S="X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V%D9$-A8VAE
M4VAU=&1O=VXH*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M4V5S<VEO;D]B:F5C=',N<&AP)SL*("`@("`@("`D8V%C:&4@/2`F2&]R9&5?
M4V5S<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I.PH*("`@("`@("`O*B!$;VXG
M="!S879E('1H92!-24U%7U9I97=E<B!C86-H960@;V)J96-T<R!S:6YC92!T
M:&5R92!I<R!N;R!E87-Y"B`@("`@("`@("`@=V%Y('1O(')E9V5N97)A=&4@
M=&AE;2!O;B!C86-H92!R96QO860N("HO"B`@("`@("`@)'1H:7,M/E]V:65W
M97)#86-H92`](&%R<F%Y*"D["@H@("`@("`@("\J($-O<'D@=&AE($U)345?
M365S<V%G92!C86-H92!O8FIE8W0@=&\@=&AE(%]M97-S86=E('9A<FEA8FQE
M+B`J+PH@("`@("`@("1T:&ES+3Y?;65S<V%G92`]("1T:&ES+3Y?8V%C:&5M
M97-S86=E.PH*("`@("`@("`D8V%C:&4M/G-T;W)E*"1T:&ES+3Y?<V5S<VEO
M;D-A8VAE240L("1T:&ES*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&-A8VAE9"!-24U%7T-O;G1E;G1S.CH@;V)J96-T+@H@("`@("H@
M5&AI<R!F=6YC=&EO;B!S:&]U;&0@8F4@8V%L;&5D('-T871I8V%L;'D@92YG
M+CH*("`@("`J("1P='(@/2`F34E-15]#;VYT96YT<SHZ9V5T0V%C:&4H*2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C86-H96ED("!4:&4@8V%C
M:&4@240@=&\@=7-E+B`@268@96UP='DL('=I;&P@=7-E('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%C:&4@240@;&]C871E9"!I;B!T
M:&4@55),('!A<F%M971E<B!N86UE9`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@34E-15]#3TY414Y44U]#04-(12X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?0V]N=&5N=',@(%1H92!-24U%7T-O;G1E;G1S(&]B:F5C
M="P@;W(@;G5L;"!I9B!I="!D;V5S(&YO=`H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$-A
M8VAE*"1C86-H96ED(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D8V%C:&5I9"DI('L*("`@("`@("`@("`@)&-A8VAE:60@/2!5=&EL.CIG
M971&;W)M1&%T82A-24U%7T-/3E1%3E137T-!0TA%*3L*("`@("`@("!]"@H@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;D]B:F5C=',N<&AP
M)SL*("`@("`@("`D8V%C:&4@/2`F2&]R9&5?4V5S<VEO;D]B:F5C=',Z.G-I
M;F=L971O;B@I.PH@("`@("`@("1C;VYT96YT<R`]("8D8V%C:&4M/G%U97)Y
M*"1C86-H96ED*3L*("`@("`@("!R971U<FX@)&-O;G1E;G1S.PH@("`@?0H*
M("`@("\J*@H@("`@("H@061D('1H92!C=7)R96YT(&]B:F5C="!T;R!T:&4@
M8V%C:&4L(&%N9"!R971U<FX@=&AE(&-A8VAE(&ED96YT:69I97(*("`@("`J
M('1O(&)E('5S960@:6X@55),<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!4:&4@<&%R86UE=&5R(&ME>2]V86QU92!S970@=&\@=7-E(&EN(%52
M3',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A8VAE24154DQ087)A;2@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*$U)345?0T].5$5.5%-?0T%#2$4@
M/3X@)'1H:7,M/E]A9&1#86-H92@I*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O2&5A9&5R<RYP:'``
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4P,#,P(#$P-3$U
M-#,T,3,W(#`R,C$U-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE(&1E<V-R:7!T:6]N(&]F($AO
M<F1E('1O('5S92!I;B!T:&4@)U5S97(M06=E;G0Z)R!H96%D97(N"B`J+PID
M969I;F4H)TA/4D1%7T%'14Y47TA%041%4B<L("=(;W)D92!!<'!L:6-A=&EO
M;B!&<F%M97=O<FL@,RXQ)RD["@HO*BH*("H@5&AE($U)345?2&5A9&5R<SHZ
M(&-L87-S(&-O;G1A:6YS(&=E;F5R:6,@9G5N8W1I;VYS(')E;&%T960@=&\*
M("H@:&%N9&QI;F<@=&AE(&AE861E<G,@;V8@;6%I;"!M97-S86=E<RX*("H*
M("H@5&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="!T;R!U<V4@9F]R(&AE861E
M<G,@<VAO=6QD(&)E(&1E9FEN960@:6X@=&AE"B`J('9A<FEA8FQE("1'3$]"
M04Q36R=M:6UE7VAE861E<G,G75LG9&5F875L=%]C:&%R<V5T)UT@*&1E9F%U
M;'1S('1O(%53+4%30TE)"B`J('!E<B!21D,@,C`T-2DN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TU)344O34E-12](96%D97)S+G!H<"QV(#$N,CDN,3`N
M,C`@,C`P-B\P-"\Q-2`Q-SHR-#HQ.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I
M9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N
M961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M34E-10H@*B\*8VQA<W,@34E-15](96%D97)S('L*"B`@("`O*BH*("`@("`J
M(%1H92!I;G1E<FYA;"!H96%D97)S(&%R<F%Y+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:&5A9&5R<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!#86-H960@;W5T<'5T(&]F('1H92!-24U%7U-T
M<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<R@I(&-O;6UA;F0N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]A;&Q(96%D97)S
M.PH*("`@("\J*@H@("`@("H@0V%C:&5D(&]U='!U="!O9B!T:&4@:6UA<%]F
M971C:&AE861E<B@I(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?:&5A9&5R5&5X=#L*"B`@("`O*BH*("`@
M("`J(%1H92!H96%D97(@;V)J96-T(')E='5R;F5D(&9R;VT@:6UA<%]H96%D
M97)I;F9O*"DN"B`@("`@*@H@("`@("H@0'9A<B!S=&1#;&%S<PH@("`@("HO
M"B`@("!V87(@)%]H96%D97)/8FIE8W0["@H@("`@+RHJ"B`@("`@*B!4:&4@
M:6YT97)N86P@9FQA9W,@87)R87DN"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)%]F;&%G<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!4:&4@57-E<BU!9V5N="!S=')I;F<@=&\@=7-E+@H@("`@("H@
M5$A)4R!604Q512!32$]53$0@0D4@3U9%4E))1$5.($)9($%,3"!354)#3$%3
M4T53+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D7V%G96YT(#T@2$]21$5?04=%3E1?2$5!1$52.PH*("`@("\J*@H@("`@
M("H@5&AE('-E<75E;F-E('1O('5S92!A<R!%3TP@9F]R('1H92!H96%D97)S
M+@H@("`@("H@5&AE(&1E9F%U;'0@:7,@8W5R<F5N=&QY('1O(&]U='!U="!T
M:&4@14],('-E<75E;F-E(&EN=&5R;F%L;'D@87,*("`@("`J(&IU<W0@(EQN
M(B!I;G-T96%D(&]F('1H92!C86YO;FEC86P@(EQR7&XB(')E<75I<F5D(&EN
M(%)&0R`X,C(@)B`R,#0U+@H@("`@("H@5&\@8F4@4D9#(&-O;7!L86EN="P@
M=&AE(&9U;&P@/$-2/CQ,1CX@14],(&-O;6)I;F%T:6]N('-H;W5L9"!B92!U
M<V5D"B`@("`@*B!W:&5N('-E;F1I;F<@82!M97-S86=E+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5O;"`](")<;B([
M"@H@("`@+RHJ"B`@("`@*B!4:&4@:6YD97@@;V8@=&AE(&UE<W-A9V4N"B`@
M("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D7VEN
M9&5X.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@;65S<V%G92!I;F1E>"!T
M;R!P87)S92!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!-24U%7TAE
M861E<G,H)&EN9&5X(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7VEN
M9&5X(#T@)&EN9&5X.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M(')E9F5R96YC92!T;R!A(&-U<G)E;G1L>2!O<&5N($E-05`@<W1R96%M+@H@
M("`@("H@5$A)4R!604Q512!32$]53$0@0D4@3U9%4E))1$5.($)9($%,3"!3
M54)#3$%34T53+@H@("`@("H*("`@("`J($!R971U<FX@<F5S;W5R8V4@($%N
M($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("HO"B`@("!F=6YC=&EO;B`F
M7V=E=%-T<F5A;2@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!F=6QL(&QI<W0@;V8@:&5A
M9&5R<R!F<F]M('1H92!I;6%P7V9E=&-H:&5A9&5R*"D@9G5N8W1I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%-E92!I;6%P7V9E=&-H:&5A
M9&5R*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$AE861E<E1E>'0H*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI<RT^7VEN9&5X*2`F)B!E
M;7!T>2@D=&AI<RT^7VAE861E<E1E>'0I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?:&5A9&5R5&5X="`]($!I;6%P7V9E=&-H:&5A9&5R*"1T:&ES+3Y?9V5T
M4W1R96%M*"DL("1T:&ES+3Y?:6YD97@L($947U5)1"D["B`@("`@("`@("`@
M(&EF("@A96UP='DH)$=,3T)!3%-;)VUI;65?:&5A9&5R<R==6R=D969A=6QT
M7V-H87)S970G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R
M5&5X="`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)'1H:7,M/E]H96%D97)4
M97AT+"`D1TQ/0D%,4ULG;6EM95]H96%D97)S)UU;)V1E9F%U;'1?8VAA<G-E
M="==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:&5A9&5R5&5X=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@9G5L;"!L:7-T(&]F(&AE861E<G,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&1E8V]D92`@1&5C;V1E('1H92!H96%D97)S/PH@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%-E92!-24U%7U-T<G5C='5R
M93HZ<&%R<V5-24U%2&5A9&5R<R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!;&Q(96%D97)S*"1D96-O9&4@/2!T<G5E*0H@("`@>PH@("`@("`@(')E
M<75I<F5?;VYC92`G2&]R9&4O34E-12]3=')U8W1U<F4N<&AP)SL*"B`@("`@
M("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?:6YD97@I("8F(&5M<'1Y*"1T:&ES
M+3Y?86QL2&5A9&5R<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]A;&Q(96%D
M97)S(#T@34E-15]3=')U8W1U<F4Z.G!A<G-E34E-14AE861E<G,H)'1H:7,M
M/F=E=$AE861E<E1E>'0H*2P@)&1E8V]D92D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H:7,M/E]A;&Q(96%D97)S.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N('1H92!H96%D97(@;V)J96-T(&9R;VT@:6UA<%]H96%D
M97)I;F9O*"DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@4V5E
M(&EM87!?:&5A9&5R:6YF;R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(
M96%D97)/8FIE8W0H*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=&AI
M<RT^7VEN9&5X*2`F)B!E;7!T>2@D=&AI<RT^7VAE861E<D]B:F5C="DI('L*
M("`@("`@("`@("`@)'-T<F5A;2`]("1T:&ES+3Y?9V5T4W1R96%M*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?:&5A9&5R3V)J96-T(#T@0&EM87!?:&5A9&5R
M:6YF;R@D<W1R96%M+"!`:6UA<%]M<V=N;R@D<W1R96%M+"`D=&AI<RT^7VEN
M9&5X*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D
M97)/8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9"!T:&4@:&5A
M9&5R(&%R<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96-O
M9&4@($U)344@9&5C;V1E('1H92!H96%D97)S/PH@("`@("HO"B`@("!F=6YC
M=&EO;B!B=6EL9$AE861E<G,H)&1E8V]D92`]('1R=64I"B`@("!["B`@("`@
M("`@:68@*"%E;7!T>2@D=&AI<RT^7VAE861E<G,I*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%!A<G-E('1H<F]U9V@@
M=&AE(&QI<W0@;V8@86QL(&AE861E<G,N("HO"B`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/F=E=$%L;$AE861E<G,H)&1E8V]D92D@87,@)&ME>2`]/B`D=F%L
M*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)&ME>2P@)'9A;"D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&0@=&AE(&9L
M86=S(&%R<F%Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$9L86=S*"D*
M("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?9FQA9W,I*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\J($=E="!T
M:&4@24U!4"!H96%D97(@;V)J96-T+B`J+PH@("`@("`@("1O8B`]("1T:&ES
M+3YG971(96%D97)/8FIE8W0H*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D
M;V(I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@
M("\J(%5N<V5E;B!F;&%G("HO"B`@("`@("`@:68@*"@D;V(M/E5N<V5E;B`]
M/2`G52<I('Q\("@D;V(M/E)E8V5N="`]/2`G3B<I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?9FQA9W-;)W5N<V5E;B==(#T@=')U93L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E8V5N="!F;&%G("HO"B`@("`@("`@:68@*"@D;V(M/E)E
M8V5N="`]/2`G3B<I('Q\("@D;V(M/E)E8V5N="`]/2`G4B<I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?9FQA9W-;)W)E8V5N="==(#T@=')U93L*("`@("`@
M("!]"@H@("`@("`@("\J($%N<W=E<F5D(&9L86<@*B\*("`@("`@("!I9B`H
M)&]B+3Y!;G-W97)E9"`]/2`G02<I('L*("`@("`@("`@("`@)'1H:7,M/E]F
M;&%G<ULG86YS=V5R960G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O
M*B!$<F%F="!F;&%G("HO"B`@("`@("`@:68@*&ES<V5T*"1O8BT^1')A9G0I
M("8F("@D;V(M/D1R869T(#T]("=8)RDI('L*("`@("`@("`@("`@)'1H:7,M
M/E]F;&%G<ULG9')A9G0G72`]('1R=64["B`@("`@("`@?0H*("`@("`@("`O
M*B!&;&%G9V5D(&9L86<@*B\*("`@("`@("!I9B`H)&]B+3Y&;&%G9V5D(#T]
M("=&)RD@>PH@("`@("`@("`@("`D=&AI<RT^7V9L86=S6R=F;&%G9V5D)UT@
M/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@1&5L971E9"!F;&%G("HO
M"B`@("`@("`@:68@*"1O8BT^1&5L971E9"`]/2`G1"<I('L*("`@("`@("`@
M("`@)'1H:7,M/E]F;&%G<ULG9&5L971E9"==(#T@=')U93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!I;G1E<FYA;"!H
M96%D97(@87)R87D@:6X@87)R87D@9F]R;6%T+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!H96%D97)S(&EN(&%R<F%Y(&9O<FUA="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&]!<G)A>2@I"B`@("!["B`@("`@("`@)')E
M='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3Y?:&5A9&5R<R!A<R`D;V(I('L*("`@("`@("`@("`@)&5O;"`]("1T:&ES
M+3YG971%3TPH*3L*("`@("`@("`@("`@)&AE861E<B`]("1O8ELG:&5A9&5R
M)UT["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D;V);)W9A;'5E)UTI*2![
M"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+TU)344N<&AP)SL*("`@("`@("`@("`@("`@("1R971U<FY?
M87)R87E;)&AE861E<ET@/2!-24U%.CIW<F%P2&5A9&5R<R@D:&5A9&5R+"!R
M97-E="@D;V);)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@(&YE>'0H)&]B
M6R=V86QU92==*3L*("`@("`@("`@("`@("`@('=H:6QE("AL:7-T*"PD=F%L
M*2`](&5A8V@H)&]B6R=V86QU92==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1R971U<FY?87)R87E;)&AE861E<ET@+CT@)&5O;"`N("1H96%D97(@+B`G
M.B`G("X@34E-13HZ=W)A<$AE861E<G,H)&AE861E<BP@)'9A;"P@)&5O;"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6R1H96%D97)=(#T@)&]B6R=V86QU
M92==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E='5R;E]A<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&EN=&5R;F%L(&AE861E<B!A<G)A>2!I;B!S=')I;F<@9F]R;6%T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@:&5A9&5R<R!I;B!S
M=')I;F<@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I
M"B`@("!["B`@("`@("`@)&5O;"`]("1T:&ES+3YG971%3TPH*3L*("`@("`@
M("`D=&5X="`]("<G.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAE861E
M<G,@87,@)&]B*2!["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&]B6R=V
M86QU92==*2D@>PH@("`@("`@("`@("`@("`@)&]B6R=V86QU92==(#T@87)R
M87DH)&]B6R=V86QU92==*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F
M;W)E86-H("@D;V);)W9A;'5E)UT@87,@)&5N=')Y*2!["B`@("`@("`@("`@
M("`@("`D=&5X="`N/2`D;V);)VAE861E<B==("X@)SH@)R`N("1E;G1R>2`N
M("1E;VP["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&5X="`N("1E;VP["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T
M92!T:&4@)U)E8V5I=F5D)R!H96%D97(@9F]R('1H92!796(@8G)O=W-E<BT^
M2&]R9&4@:&]P"B`@("`@*B`H871T96UP=',@=&\@8V]N9F]R;2!T;R!G=6ED
M96QI;F5S(&EN(%)&0R`R.#(Q*2X*("`@("`J+PH@("`@9G5N8W1I;VX@861D
M4F5C96EV961(96%D97(H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D7U-%
M4E9%4ELG2%144%]87T9/4E=!4D1%1%]&3U(G72DI('L*("`@("`@("`@("`@
M+RH@5&AI<R!I;F1I8V%T97,@=&AE('5S97(@:7,@8V]N;F5C=&EN9R!T:')O
M=6=H(&$@<')O>'DN("HO"B`@("`@("`@("`@("1R96UO=&5?<&%T:"`](&5X
M<&QO9&4H)RPG+"`D7U-%4E9%4ELG2%144%]87T9/4E=!4D1%1%]&3U(G72D[
M"B`@("`@("`@("`@("1R96UO=&5?861D<B`]("1R96UO=&5?<&%T:%LP73L*
M("`@("`@("`@("`@)')E;6]T92`]($!G971H;W-T8GEA9&1R*"1R96UO=&5?
M861D<BD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E;6]T95]A
M9&1R(#T@)%]315)615);)U)%34]415]!1$12)UT["B`@("`@("`@("`@(&EF
M("AE;7!T>2@D7U-%4E9%4ELG4D5-3U1%7TA/4U0G72DI('L*("`@("`@("`@
M("`@("`@("1R96UO=&4@/2!`9V5T:&]S=&)Y861D<B@D<F5M;W1E7V%D9'(I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E;6]T
M92`]("1?4T525D526R=214U/5$5?2$]35"==.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1R96-E:79E9"`]("=F<F]M("<@+B`D<F5M;W1E
M("X@)R`H)SL*"B`@("`@("`@:68@*"%E;7!T>2@D7U-%4E9%4ELG4D5-3U1%
M7TE$14Y4)UTI*2!["B`@("`@("`@("`@("1R96-E:79E9"`N/2`D7U-%4E9%
M4ELG4D5-3U1%7TE$14Y4)UT@+B`G0"<@+B`D<F5M;W1E("X@)R`G.PH@("`@
M("`@('T@96QS96EF("@D<F5M;W1E("$]("1?4T525D526R=214U/5$5?041$
M4B==*2!["B`@("`@("`@("`@("1R96-E:79E9"`N/2`D<F5M;W1E("X@)R`G
M.PH@("`@("`@('T*("`@("`@("`D<F5C96EV960@+CT@)ULG("X@)')E;6]T
M95]A9&1R("X@)UTI("<["@H@("`@("`@(&EF("@A96UP='DH)$=,3T)!3%-;
M)V-O;F8G75LG<V5R=F5R)UU;)VYA;64G72DI('L*("`@("`@("`@("`@)'-E
M<G9E<E]N86UE(#T@)$=,3T)!3%-;)V-O;F8G75LG<V5R=F5R)UU;)VYA;64G
M73L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1?4T525D526R=315)615)?
M3D%-12==*2D@>PH@("`@("`@("`@("`D<V5R=F5R7VYA;64@/2`D7U-%4E9%
M4ELG4T525D527TY!344G73L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1?
M4T525D526R=(5%107TA/4U0G72DI('L*("`@("`@("`@("`@)'-E<G9E<E]N
M86UE(#T@)%]315)615);)TA45%!?2$]35"==.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1S97)V97)?;F%M92`]("=U;FMN;W=N)SL*("`@("`@
M("!]"B`@("`@("`@)')E8V5I=F5D("X]("=B>2`G("X@)'-E<G9E<E]N86UE
M("X@)R`H2&]R9&4@34E-12!L:6)R87)Y*2!W:71H($A45%`[("<["@H@("`@
M("`@("1R96-E:79E9"`N/2!D871E*"=R)RD["@H@("`@("`@("1T:&ES+3YA
M9&1(96%D97(H)U)E8V5I=F5D)RP@)')E8V5I=F5D*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E;F5R871E('1H92`G365S<V%G92U)1"<@:&5A9&5R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1-97-S86=E261(96%D97(H*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO34E-12YP:'`G.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)TUE<W-A
M9V4M240G+"!-24U%.CIG96YE<F%T94UE<W-A9V5)1"@I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E;F5R871E('1H92`G4F5S96YT)R!H96%D97)S("AC
M;VYF;W)M<R!T;R!G=6ED96QI;F5S(&EN"B`@("`@*B!21D,@,C@R,B!;,RXV
M+C9=*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F<F]M("!4:&4@
M861D<F5S<R!T;R!U<V4@9F]R("=297-E;G0M1G)O;2<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T;R`@("!4:&4@861D<F5S<R!T;R!U<V4@9F]R("=297-E
M;G0M5&\G+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1297-E;G1(96%D97)S
M*"1F<F]M+"`D=&\I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B]-24U%+G!H<"<["@H@("`@("`@("\J(%=E
M(&1O;B=T('-E="!297-E;G0M4V5N9&5R+"!297-E;G0M0V,L(&]R(%)E<V5N
M="U"8V,N("HO"B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G4F5S96YT+41A
M=&4G+"!D871E*"=R)RDI.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U)E
M<V5N="U&<F]M)RP@)&9R;VTI.PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H
M)U)E<V5N="U4;R<L("1T;RD["B`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G
M4F5S96YT+4UE<W-A9V4M240G+"!-24U%.CIG96YE<F%T94UE<W-A9V5)1"@I
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E(&1E;&EV97)Y(')E
M8V5I<'0@:&5A9&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M;R`@5&AE(&%D9')E<W,@=&AE(')E8V5I<'0@<VAO=6QD(&)E(&UA:6QE9"!T
M;RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D1&5L:79E<GE296-E:7!T2&5A
M9&5R<R@D=&\I"B`@("!["B`@("`@("`@+RH@5&AI<R!I<R!O;&0@<V5N9&UA
M:6P@*'!R92TX+C<I(&)E:&%V:6]R+B`J+PH@("`@("`@("1T:&ES+3YA9&1(
M96%D97(H)U)E='5R;BU296-E:7!T+51O)RP@)'1O*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E;F5R871E('1H92!U<V5R(&%G96YT(&1E<V-R:7!T:6]N
M(&AE861E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@861D06=E;G1(96%D97(H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U5S97(M06=E;G0G
M+"`D=&AI<RT^7V%G96YT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('5S97(@86=E;G0@9&5S8W)I<'1I;VX@:&5A9&5R+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=7-E<B!A9V5N="!H96%D97(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%G96YT2&5A9&5R*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]A9V5N=#L*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9"!A(&AE861E<B!T;R!T:&4@:&5A9&5R(&%R<F%Y+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE(&AE861E<B!N
M86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@("!4:&4@:&5A9&5R
M('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1(96%D97(H)&AE861E
M<BP@)'9A;'5E*0H@("`@>PH@("`@("`@("1H96%D97(@/2!T<FEM*"1H96%D
M97(I.PH@("`@("`@("1L8TAE861E<B`](%-T<FEN9SHZ;&]W97(H)&AE861E
M<BD["@H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]H96%D97)S6R1L8TAE
M861E<ETI*2!["B`@("`@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D
M97)=(#T@87)R87DH*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]H96%D
M97)S6R1L8TAE861E<EU;)VAE861E<B==(#T@)&AE861E<CL*("`@("`@("`D
M=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG=F%L=64G72`]("1V86QU93L*
M("`@("`@("`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG7V%L=&5R)UT@
M/2!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!A(&AE861E
M<B!F<F]M('1H92!H96%D97(@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A9&5R(&YA;64N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;6]V94AE861E<B@D:&5A9&5R*0H@("`@>PH@("`@("`@
M("1H96%D97(@/2!T<FEM*"1H96%D97(I.PH@("`@("`@("1L8TAE861E<B`]
M(%-T<FEN9SHZ;&]W97(H)&AE861E<BD["B`@("`@("`@=6YS970H)'1H:7,M
M/E]H96%D97)S6R1L8TAE861E<ETI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T(&$@=F%L=64@9F]R(&$@<&%R=&EC=6QA<B!H96%D97(@3TY,62!I9B!T
M:&%T(&AE861E<B!I<R!S970N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:&5A9&5R("!4:&4@:&5A9&5R(&YA;64N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1V86QU92`@(%1H92!H96%D97(@=F%L=64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&EF('9A;'5E('=A<R!S970L(&9A;'-E
M(&EF(&YO="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5F%L=64H)&AE861E
M<BP@)'9A;'5E*0H@("`@>PH@("`@("`@("1L8TAE861E<B`](%-T<FEN9SHZ
M;&]W97(H)&AE861E<BD["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A
M9&5R<ULD;&-(96%D97)=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E
M<G-;)&QC2&5A9&5R75LG=F%L=64G72`]("1V86QU93L*("`@("`@("`@("`@
M)'1H:7,M/E]H96%D97)S6R1L8TAE861E<EU;)U]A;'1E<B==(#T@=')U93L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!T:&4@:&5A9&5R(&EN('1H
M92!C;W)R96-T(&-A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:&5A9&5R("!4:&4@:&5A9&5R('1O('-E87)C:"!F;W(N"B`@("`@*@H@("`@
M("H@0')E='5R;B!S=')I;F<@(%1H92!V86QU92!F;W(@=&AE(&=I=F5N(&AE
M861E<BX*("`@("`J("`@("`@("`@("`@("`@("!)9B!T:&4@:&5A9&5R(&ES
M(&YO="!F;W5N9"P@<F5T=7)N<R!N=6QL+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G9713=')I;F<H)&AE861E<BD*("`@('L*("`@("`@("`D;&-(96%D97(@
M/2!3=')I;F<Z.FQO=V5R*"1H96%D97(I.PH@("`@("`@(')E='5R;B`H:7-S
M970H)'1H:7,M/E]H96%D97)S6R1L8TAE861E<ETI*2`_("1T:&ES+3Y?:&5A
M9&5R<ULD;&-(96%D97)=6R=H96%D97(G72`Z(&YU;&P["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T('1O(')E='5R;B!T:&4@=F%L=64@9F]R(&$@
M9VEV96X@:&5A9&5R+@H@("`@("H@5&AE(&9O;&QO=VEN9R!H96%D97(@9FEE
M;&1S(&-A;B!O;FQY(&AA=F4@,2!E;G1R>2P@<V\@:68@9'5P;&EC871E"B`@
M("`@*B!E;G1R:65S(&5X:7-T+"!T:&4@9FER<W0@=F%L=64@=VEL;"!B92!U
M<V5D.@H@("`@("H@("`J(%1O+"!&<F]M+"!#8RP@0F-C+"!$871E+"!396YD
M97(L(%)E<&QY+71O+"!-97-S86=E+4E$+"!);BU297!L>2U4;RP*("`@("`J
M("`@("!2969E<F5N8V5S+"!3=6)J96-T("A21D,@,C@R,B!;,RXV72D*("`@
M("`J("`@*B!!;&P@3&ES="!(96%D97)S("A21D,@,C,V.2!;,UTI"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&5A9&5R("!4:&4@:&5A9&5R('1O
M('-E87)C:"!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M('9A;'5E(&9O<B!T:&4@9VEV96X@:&5A9&5R+@H@("`@("H@("`@("`@("`@
M("`@("`@268@=&AE(&AE861E<B!I<R!N;W0@9F]U;F0L(')E='5R;G,@;G5L
M;"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5F%L=64H)&AE861E<BD*("`@
M('L*("`@("`@("`D:&5A9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R72DI
M('L*("`@("`@("`@("`@)'-I;F=L92`](&%R<F%Y*"=T;R<L("=F<F]M)RP@
M)V-C)RP@)V)C8R<L("=D871E)RP@)W-E;F1E<B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5P;'DM=&\G+"`G;65S<V%G92UI9"<L("=I;BUR
M97!L>2UT;R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5F97)E
M;F-E<R<L("=S=6)J96-T)RP@)W@M<')I;W)I='DG*3L*("`@("`@("`@("`@
M)'-I;F=L92`](&%R<F%Y7VUE<F=E*"1S:6YG;&4L(&%R<F%Y7VME>7,H)'1H
M:7,M/FQI<W1(96%D97)S*"DI*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R75LG=F%L=64G72D@)B8*("`@("`@
M("`@("`@("`@(&EN7V%R<F%Y*"1H96%D97(L("1S:6YG;&4I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]H96%D97)S6R1H96%D97)=6R=V
M86QU92==6S!=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:&5A9&5R<ULD:&5A9&5R75LG=F%L=64G73L*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($AA
M<R!T:&4@:&5A9&5R(&)E96X@86QT97)E9"!F<F]M('1H92!O<FEG:6YA;#\*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D97(@(%1H92!H96%D
M97(@=&\@86YA;'EZ92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE(&AE861E<B!H87,@8F5E;B!A;'1E<F5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A;'1E<F5D2&5A9&5R*"1H96%D97(I"B`@("!["B`@
M("`@("`@)&QC2&5A9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*("`@
M("`@("!R971U<FX@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD;&-(96%D97)=
M*2D@/R`D=&AI<RT^7VAE861E<G-;)&QC2&5A9&5R75LG7V%L=&5R)UT@.B!F
M86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%1R86YS9F]R;7,@82!(96%D
M97(@=F%L=64@=7-I;F<@=&AE(&QI<W0@;V8@9G5N8W1I;VYS('!R;W9I9&5D
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&AE861E<B`@5&AE(&AE
M861E<B!T;R!A;'1E<BX*("`@("`J($!P87)A;2!M:7AE9"`D9G5N8W,@("`@
M02!F=6YC=&EO;BP@;W(@86X@87)R87D@;V8@9G5N8W1I;VYS+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("!4:&4@9G5N8W1I;VYS('=I;&P@8F4@
M<&5R9F]R;65D(&9R;VT@<FEG:'0@=&\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@;&5F="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T5F%L=65"
M>49U;F-T:6]N*"1H96%D97(L("1F=6YC<RD*("`@('L*("`@("`@("`D:&5A
M9&5R(#T@4W1R:6YG.CIL;W=E<B@D:&5A9&5R*3L*"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1F=6YC<RDI('L*("`@("`@("`@("`@)&9U;F-S(#T@87)R87E?
M<F5V97)S92@D9G5N8W,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1F=6YC<R`](&%R<F%Y*"1F=6YC<RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]H96%D97)S6R1H96%D97)=*2D@>PH@("`@("`@
M("`@("`D=F%L(#T@)'1H:7,M/F=E=%9A;'5E*"1H96%D97(I.PH@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)'9A;"DI('L*("`@("`@("`@("`@("`@("1V
M86P@/2!I;7!L;V1E*")<;B(L("1V86PI.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1F=6YC<R!A<R`D9G5N8RD@>PH@("`@("`@("`@
M("`@("`@)'9A;"`](&-A;&Q?=7-E<E]F=6YC*"1F=6YC+"`D=F%L*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<V5T5F%L=64H)&AE861E
M<BP@)'9A;"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061D
M(&%N>2!-24U%(&AE861E<G,@<F5Q=6ER960@9F]R('1H92!-24U%7U!A<G0N
M"B`@("`@*@H@("`@("H@0'!A<F%M($U)345?4&%R="`F)&UI;65?<&%R="`@
M5&AE($U)345?4&%R="!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$U)345(96%D97)S*"8D;6EM95]P87)T*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*"1M:6UE7W!A<G0M/FAE861E<BAA<G)A>2@I*2!A<R`D:&5A9"`]/B`D
M=F%L*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1(96%D97(H)&AE860L("1V
M86PI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T
M:&4@;&ES="!O9B!A9&1R97-S97,@9F]R(&$@:&5A9&5R(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]B<R`@06X@87)R87D@;V8@:&5A
M9&5R(&]B:F5C=',@*%-E92!I;6%P7VAE861E<FEN9F\H*0H@("`@("H@("`@
M("`@("`@("`@("`@("`@(&9O<B!T:&4@;V)J96-T('-T<G5C='5R92DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@;V)J96-T
M<RX*("`@("`J(#QP<F4^"B`@("`@*B!/8FIE8W0@96QE;65N=',Z"B`@("`@
M*B`G861D<F5S<R<@("`M("!&=6QL(&%D9')E<W,*("`@("`J("=H;W-T)R`@
M("`@("T@($AO<W0@;F%M90H@("`@("H@)VEN;F5R)R`@("`@+2`@5')I;6UE
M9"P@8F%R92!A9&1R97-S"B`@("`@*B`G<&5R<V]N86PG("`M("!097)S;VYA
M;"!S=')I;F<*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971!9&1R97-S97-&<F]M3V)J96-T*"1O8G,I"B`@("!["B`@("`@("`@)')E
M=$%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;V)S
M*2!\?"!E;7!T>2@D;V)S*2D@>PH@("`@("`@("`@("!R971U<FX@)')E=$%R
M<F%Y.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&]B<R!A<R`D;V(I
M('L*("`@("`@("`@("`@+RH@16YS=7)E('=E)W)E('=O<FMI;F<@=VET:"!I
M;FET:6%L:7IE9"!V86QU97,N("HO"B`@("`@("`@("`@(&EF("AI<W-E="@D
M;V(M/G!E<G-O;F%L*2D@>PH@("`@("`@("`@("`@("`@)&]B+3YP97)S;VYA
M;"`]($U)344Z.F1E8V]D92@D;V(M/G!E<G-O;F%L*3L*("`@("`@("`@("`@
M("`@(&EF("@H<W5B<W1R*"1O8BT^<&5R<V]N86PL(#`L(#$I(#T]("<B)RD@
M)B8*("`@("`@("`@("`@("`@("`@("`H<W5B<W1R*"1O8BT^<&5R<V]N86PL
M("TQ*2`]/2`G(B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&]B+3YP97)S
M;VYA;"`]('-U8G-T<B@D;V(M/G!E<G-O;F%L+"`Q+"`M,2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;V(M/G!E<G-O;F%L(#T@)R<["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("AI<W-E="@D;V(M/FUA:6QB;W@I*2!["B`@("`@("`@("`@("`@
M("`O*B!$;VXG="!P<F]C97-S(&EN=F%L:60@861D<F5S<V5S+B`J+PH@("`@
M("`@("`@("`@("`@:68@*'-T<G!O<R@D;V(M/FUA:6QB;W@L("=53D584$5#
M5$5$7T1!5$%?049415)?041$4D534R<I("$]/2!F86QS92!\?`H@("`@("`@
M("`@("`@("`@("`@('-T<G!O<R@D;V(M/FUA:6QB;W@L("=)3E9!3$E$7T%$
M1%)%4U,G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1O8BT^;6%I;&)O>"`]("<G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1O8BT^:&]S="DI('L*("`@
M("`@("`@("`@("`@("1O8BT^:&]S="`]("<G.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!'96YE<F%T92!T:&4@;F5W(&]B:F5C="X@*B\*("`@
M("`@("`@("`@)&YE=T]B(#T@)FYE=R!S=&1#;&%S<SL*("`@("`@("`@("`@
M)&YE=T]B+3YA9&1R97-S(#T@34E-13HZ861D<D]B:F5C=#)3=')I;F<H)&]B
M+"!A<G)A>2@G=6YD:7-C;&]S960M<F5C:7!I96YT<T`G+"`G56YD:7-C;&]S
M960@<F5C:7!I96YT<T`G*2D["B`@("`@("`@("`@("1N97=/8BT^:&]S="`]
M("1O8BT^:&]S=#L*("`@("`@("`@("`@)&YE=T]B+3YI;FYE<B`]($U)344Z
M.G1R:6U%;6%I;$%D9')E<W,H34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1O
M8BT^;6%I;&)O>"P@)&]B+3YH;W-T+"`G)RDI.PH@("`@("`@("`@("`D;F5W
M3V(M/G!E<G-O;F%L(#T@)&]B+3YP97)S;VYA;#L*"B`@("`@("`@("`@("1R
M971!<G)A>5M=(#T@)B1N97=/8CL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5T07)R87D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!L:7-T(&]F('9A;&ED(&UA:6QI;F<@;&ES="!H96%D97)S+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!L:7-T(&]F('9A;&ED(&UA:6QI
M;F<@;&ES="!H96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T2&5A
M9&5R<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@
M("`O*B!21D,@,C,V.2`J+PH@("`@("`@("`@("`G;&ES="UH96QP)R`@("`@
M("`@(#T^("!?*"),:7-T+4AE;'`B*2P*("`@("`@("`@("`@)VQI<W0M=6YS
M=6)S8W)I8F4G("`]/B`@7R@B3&ES="U5;G-U8G-C<FEB92(I+`H@("`@("`@
M("`@("`G;&ES="US=6)S8W)I8F4G("`@(#T^("!?*"),:7-T+5-U8G-C<FEB
M92(I+`H@("`@("`@("`@("`G;&ES="UO=VYE<B<@("`@("`@(#T^("!?*"),
M:7-T+4]W;F5R(BDL"B`@("`@("`@("`@("=L:7-T+7!O<W0G("`@("`@("`@
M/3X@(%\H(DQI<W0M4&]S="(I+`H@("`@("`@("`@("`G;&ES="UA<F-H:79E
M)R`@("`@(#T^("!?*"),:7-T+4%R8VAI=F4B*2P*("`@("`@("`@("`@+RH@
M4D9#(#(Y,3D@*B\*("`@("`@("`@("`@)VQI<W0M:60G("`@("`@("`@("`]
M/B`@7R@B3&ES="U)9"(I"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($1O(&%N>2!M86EL:6YG(&QI<W0@:&5A9&5R<R!E>&ES=#\*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@86YY(&UA:6QI;F<@
M;&ES="!H96%D97)S(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T
M2&5A9&5R<T5X:7-T*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M;&ES=$AE861E<G,H*2!A<R`D=F%L(#T^("1S='(I('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULD=F%L72DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M971S(&$@;F5W('-T<FEN9R!T;R!U<V4@9F]R($5/3',N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D96]L("!4:&4@<W1R:6YG('1O('5S92!F;W(@
M14],<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T14],*"1E;VPI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]E;VP@/2`D96]L.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T('1H92!S=')I;F<@=&\@=7-E(&9O<B!%3TQS+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<W1R:6YG('1O('5S92!F;W(@
M14],<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T14],*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]E;VP["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!F;&%G('-T871U<RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F;&%G("!)<R!T:&ES(&9L86<@<V5T/PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@1FQA9W,Z(')E8V5N="P@=6YS965N+"!A;G-W
M97)E9"P@9')A9G0L(&EM<&]R=&%N="P*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&EF('1H92!F;&%G(&AA<R!B965N('-E="P@9F%L<V4@
M:68@;F]T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&;&%G*"1F;&%G*0H@
M("`@>PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]F;&%G<UM3=')I;F<Z
M.FQO=V5R*"1F;&%G*5TI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('!R:6UA<GD@
M9G)O;2!A9&1R97-S("AF:7)S="!A9&1R97-S(&EN('1H92!&<F]M.B!H96%D
M97(I+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9G)O;2!A
M9&1R97-S("AU<V5R0&AO<W0I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&
M<F]M061D<F5S<R@I"B`@("!["B`@("`@("`@:68@*"$H)&]B(#T@)'1H:7,M
M/F=E=$]B*"=F<F]M)RDI*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H
M<"<["@H@("`@("`@(')E='5R;B!T<FEM*$U)344Z.G1R:6U%;6%I;$%D9')E
M<W,H34E-13HZ<F9C.#(R5W)I=&5!9&1R97-S*"1O8ELP72T^;6%I;&)O>"P@
M*&ES<V5T*"1O8ELP72T^:&]S="DI(#\@)&]B6S!=+3YH;W-T(#H@)R<L("<G
M*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@:&5A9&5R(&9R;VT@
M=&AE(&AE861E<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'1O9&\@4F5P;&%C
M92!W:71H(&=E=$]B*"D@9G)O;2!)35`G<R!)35!?2&5A9&5R<R!F;W(@2&]R
M9&4@-"XP+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("`@
M(%1H92!O8FIE8W0@9FEE;&0@=&\@<F5T<FEE=F4@*'-E90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@:6UA<%]H96%D97)I;F9O*"D@9F]R('1H
M92!L:7-T(&]F(&9I96QD<RDN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C
M;V1E("!3:&]U;&0@=&AE(')E='5R;B!V86QU92!B92!-24U%(&1E8V]D960_
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!)="!W:6QL(&]N;'D@
M8F4@9&5C;V1E9"!I9B!I="!I<R!N;W0@86X@;V)J96-T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!I='-E;&8N"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE(&9I96QD(')E<75E<W1E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T3V(H)&9I96QD+"`D9&5C;V1E(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&1A=&$@/2!A<G)A>2@I.PH*("`@("`@("`D;V(@/2`D=&AI
M<RT^9V5T2&5A9&5R3V)J96-T*"D["B`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)&]B*2D@>PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)&]B+3XD9FEE;&0I*2!["B`@("`@("`@("`@
M("1D871A(#T@)&]B+3XD9FEE;&0["B`@("`@("`@("`@(&EF("@A96UP='DH
M)&1E8V]D92D@)B8@(6ES7V]B:F5C="@D9&%T82D@)B8@(6ES7V%R<F%Y*"1D
M871A*2D@>PH@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E("=(;W)D92]-
M24U%+G!H<"<["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1'3$]"04Q3
M6R=M:6UE7VAE861E<G,G75LG9&5F875L=%]C:&%R<V5T)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)&1A=&$@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T
M*"1D871A+"`D1TQ/0D%,4ULG;6EM95]H96%D97)S)UU;)V1E9F%U;'1?8VAA
M<G-E="==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1D
M871A(#T@34E-13HZ9&5C;V1E*"1D871A*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("AI<U]S=')I;F<H)&1A=&$I*2`_('-T
M<G1R*"1D871A+"`B7'0B+"`G("<I(#H@)&1A=&$["B`@("!]"@I]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<```````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,U,#8T(#$P-3$U-#,T,3,W
M(#`R,C8Q-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R]-97-S86=E+G!H<"<["G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O4&%R="YP:'`G.PIR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?
M7RD@+B`G+RXN+TU)344N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]-24U%+TU)344O4W1R=6-T=7)E+G!H<"QV(#$N.#<N,3`N,3D@,C`P-B\P
M-2\P-"`Q.#HP,SHR-2!S;'5S87)Z($5X<"`D"B`J"B`J(%1H92!-24U%7U-T
M<G5C='5R93HZ(&-L87-S('!R;W9I9&5S(&UE=&AO9',@9F]R(&1E86QI;F<@
M=VET:"!-24U%(&UA:6PN"B`J"B`J(%1H92!D969A=6QT(&-H87)A8W1E<B!S
M970@=&\@=7-E(&9O<B!M97-S86=E<R!S:&]U;&0@8F4@9&5F:6YE9"!I;B!T
M:&4*("H@=F%R:6%B;&4@)$=,3T)!3%-;)VUI;65?<W1R=6-T=7)E)UU;)V1E
M9F%U;'1?8VAA<G-E="==("AD969A=6QT<R!T;R!54RU!4T-)20H@*B!P97(@
M4D9#(#(P-#4I+@H@*@H@*B!43T1/.B!#;VYV97)T('1O($]/"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W
M;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P
M86-K86=E($AO<F1E7TU)344*("HO"F-L87-S($U)345?4W1R=6-T=7)E('L*
M"B`@("`O*BH*("`@("`J($=I=F5N('1H92!R97-U;'1S(&]F(&EM87!?9F5T
M8VAS=')U8W1U<F4H*2P@<&%R<V4@=&AE('-T<G5C='5R90H@("`@("H@;V8@
M=&AE(&UE<W-A9V4L(&9I9W5R:6YG(&]U="!C;W)R96-T(&)O9'EP87)T(&YU
M;6)E<G,L(&5T8RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@)&)O
M9'D@(%1H92!R97-U;'0@;V8@:6UA<%]F971C:'-T<G5C='5R92@I+@H@("`@
M("H*("`@("`J($!R971U<FX@)DU)345?365S<V%G92`@5&AE(&UE<W-A9V4@
M<&%R<V5D(&EN=&\@82!-24U%7TUE<W-A9V4@;V)J96-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F<&%R<V4H)&)O9'DI"B`@("!["B`@("`@("`@)&US9T]B
M(#T@)FYE=R!-24U%7TUE<W-A9V4H*3L*("`@("`@("`D;7-G3V(M/F%D9%!A
M<G0H34E-15]3=')U8W1U<F4Z.E]P87)S92@D8F]D>2DI.PH@("`@("`@("1M
M<V=/8BT^8G5I;&1-97-S86=E*"D["@H@("`@("`@("1P='(@/2!A<G)A>2@F
M)&US9T]B*3L*("`@("`@("!-24U%7U-T<G5C='5R93HZ7V%D9$UU;'1I<&%R
M=$EN9F\H)'!T<BD["@H@("`@("`@(')E='5R;B`D;7-G3V(["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!':79E;B!T:&4@<F5S=6QT<R!O9B!I;6%P7V9E=&-H
M<W1R=6-T=7)E*"DL('!A<G-E('1H92!S=')U8W1U<F4*("`@("`J(&]F('1H
M92!M97-S86=E+"!F:6=U<FEN9R!O=70@8V]R<F5C="!B;V1Y<&%R="!N=6UB
M97)S+"!E=&,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T9$-L87-S("1B;V1Y("!4:&4@<F5S=6QT(&]F
M(&EM87!?9F5T8VAS=')U8W1U<F4H*2X*("`@("`J($!P87)A;2!S=')I;F<@
M)')E9B`@("`@5&AE(&-U<G)E;G0@8F]D>7!A<G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!-24U%7U!A<G0@($$@34E-15]087)T(&]B:F5C="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)E]P87)S92@D8F]D>2P@)')E9B`](#`I"B`@("![
M"B`@("`@("`@<W1A=&EC("1M97-S86=E+"`D;75L=&EP87)T.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1M97-S86=E*2D@>PH@("`@("`@("`@("`D;65S<V%G
M92`]($U)344Z.G1Y<&4H)VUE<W-A9V4G*3L*("`@("`@("`@("`@)&UU;'1I
M<&%R="`]($U)344Z.G1Y<&4H)VUU;'1I<&%R="<I.PH@("`@("`@('T*"B`@
M("`@("`@)&UI;65?<&%R="`]("9N97<@34E-15]087)T*"D["@H@("`@("`@
M("\J(%1O<"!M=6QT:7!A<G1S(&1O;B=T(&=E="!T:&5I<B!O=VX@;&EN92X@
M*B\*("`@("`@("!I9B`H96UP='DH)')E9BD@)B8*("`@("`@("`@("`@*"%I
M<W-E="@D8F]D>2T^='EP92D@?'P@*"1B;V1Y+3YT>7!E("$]("1M=6QT:7!A
M<G0I*2D@>PH@("`@("`@("`@("`D<F5F(#T@,3L*("`@("`@("!]"@H@("`@
M("`@($U)345?4W1R=6-T=7)E.CI?<V5T26YF;R@D8F]D>2P@)&UI;65?<&%R
M="P@)')E9BD["@H@("`@("`@(&EF("AI<W-E="@D8F]D>2T^='EP92D@)B8@
M*"1B;V1Y+3YT>7!E(#T]("1M97-S86=E*2`F)@H@("`@("`@("`@("`D8F]D
M>2T^:69S=6)T>7!E("8F("@D8F]D>2T^<W5B='EP92`]/2`G4D9#.#(R)RDI
M('L*("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*"1R968@+B`G
M+C`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6EM95]P87)T
M+3YS971-24U%260H)')E9BD["B`@("`@("`@?0H*("`@("`@("`O*B!$96%L
M('=I=&@@;75L=&EP87)T(&1A=&$N("HO"B`@("`@("`@:68@*&ES<V5T*"1B
M;V1Y+3YP87)T<RDI('L*("`@("`@("`@("`@)'-U8E]I9"`](#$["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1B;V1Y+3YP87)T<R!A<R`D<W5B7W!A<G0I('L*
M("`@("`@("`@("`@("`@("\J($%R92!W92!D96%L:6YG('=I=&@@82!M=6QT
M:7!A<G0@;65S<V%G93\@*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M8F]D>2T^='EP92D@)B8@*"1B;V1Y+3YT>7!E(#T]("1M97-S86=E*2`F)@H@
M("`@("`@("`@("`@("`@("`@(&ES<V5T*"1S=6)?<&%R="T^='EP92D@)B8@
M*"1S=6)?<&%R="T^='EP92`]/2`D;75L=&EP87)T*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1S=6)?<F5F(#T@)')E9CL*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'-U8E]R968@/2`H96UP='DH
M)')E9BDI(#\@)'-U8E]I9"`Z("1R968@+B`G+B<@+B`D<W5B7VED.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&UI;65?<&%R="T^861D
M4&%R="A-24U%7U-T<G5C='5R93HZ7W!A<G-E*"1S=6)?<&%R="P@)'-U8E]R
M968I+"`D<W5B7VED*RLI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&UI;65?<&%R=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($=I=F5N(&$@;6EM92!P87)T(&9R;VT@:6UA<%]F971C:'-T<G5C='5R92@I
M+"!M=6YG92!I="!I;G1O(&$*("`@("`J('5S969U;"!F;W)M(&%N9"!M86ME
M('-U<F4@=&AA="!A;GD@<&%R86UE=&5R<R!W:&EC:"!A<F4@;6ES<VEN9PH@
M("`@("H@87)E(&=I=F5N(&1E9F%U;'0@=F%L=65S+@H@("`@("H*("`@("`J
M(%1O('-P96-I9GD@=&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="P@9&5F:6YE
M('1H92!G;&]B86P@=F%R:6%B;&4*("`@("`J("1'3$]"04Q36R=M:6UE7W-T
M<G5C=71R92==6R=D969A=6QT7V-H87)S970G72X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1D0VQA<W,@
M)'!A<G0@(%1H92!O<FEG:6YA;"!P87)T(&EN9F\N"B`@("`@*B!`<&%R86T@
M34E-15]087)T("8D;V(@($$@34E-15]087)T(&]B:F5C="X*("`@("`J($!P
M87)A;2!S=')I;F<@)')E9B`@("`@5&AE($E$(&]F('1H:7,@<&%R="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W-E=$EN9F\H)'!A<G0L("8D;V(L("1R968I
M"B`@("!["B`@("`@("`@+RH@4W1O<F4@0V]N=&5N="UT>7!E(&EN9F]R;6%T
M:6]N+B`J+PH@("`@("`@("1P<FEM87)Y7W1Y<&4@/2`H:7-S970H)'!A<G0M
M/G1Y<&4I*2`_(%-T<FEN9SHZ;&]W97(H)'!A<G0M/G1Y<&4I(#H@34E-13HZ
M='EP92@G=&5X="<I.PH@("`@("`@("1S96-?='EP92`]("@D<&%R="T^:69S
M=6)T>7!E("8F("1P87)T+3YS=6)T>7!E*2`_(%-T<FEN9SHZ;&]W97(H)'!A
M<G0M/G-U8G1Y<&4I(#H@)W@M=6YK;F]W;B<["B`@("`@("`@)&]B+3YS9714
M>7!E*"1P<FEM87)Y7W1Y<&4@+B`G+R<@+B`D<V5C7W1Y<&4I.PH*("`@("`@
M("`O*B!3970@=')A;G-F97(@96YC;V1I;F<N("HO"B`@("`@("`@:68@*&ES
M<V5T*"1P87)T+3YE;F-O9&EN9RDI('L*("`@("`@("`@("`@)&5N8V]D:6YG
M(#T@)'!A<G0M/F5N8V]D:6YG.PH@("`@("`@("`@("`D;V(M/G-E=%1R86YS
M9F5R16YC;V1I;F<H)&5N8V]D:6YG*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D96YC;V1I;F<@/2!N=6QL.PH@("`@("`@('T*"B`@("`@("`@
M+RH@4V5T('1R86YS9F5R(&1I<W!O<VET:6]N+B`J+PH@("`@("`@("1O8BT^
M<V5T1&ES<&]S:71I;VXH*"1P87)T+3YI9F1I<W!O<VET:6]N*2`_(%-T<FEN
M9SHZ;&]W97(H)'!A<G0M/F1I<W!O<VET:6]N*2`Z($U)345?1$5&055,5%]$
M25-03U-)5$E/3BD["@H@("`@("`@("\J($EF("=B;V1Y)R!I<R!S970L('-E
M="!A<R!T:&4@8V]N=&5N=',@;V8@=&AE('!A<G0N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1P87)T+3YB;V1Y*2D@>PH@("`@("`@("`@("`D;V(M/G-E=$-O
M;G1E;G1S*"1P87)T+3YB;V1Y+"`D96YC;V1I;F<I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@268@)V)Y=&5S)R!I<R!S970L('-T;W)E(&%S(&EN9F]R;6%T
M:6]N('9A<FEA8FQE+B`J+PH@("`@("`@(&EF("AI<W-E="@D<&%R="T^8GET
M97,I*2!["B`@("`@("`@("`@("1O8BT^<V5T0GET97,H)'!A<G0M/F)Y=&5S
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@<&%R="=S(&ED96YT
M:69I8V%T:6]N('-T<FEN9RP@:68@879A:6QA8FQE+B`J+PH@("`@("`@(&EF
M("@A96UP='DH)')E9BD@)B8@)'!A<G0M/FEF:60I('L*("`@("`@("`@("`@
M)&]B+3YS971#;VYT96YT240H)'!A<G0M/FED*3L*("`@("`@("!]"@H@("`@
M("`@("\J($=O('1H<F]U9V@@=&AE(&-O;G1E;G0M='EP92!P87)A;65T97)S
M+"!I9B!A;GDN("HO"B`@("`@("`@9F]R96%C:"`H34E-15]3=')U8W1U<F4Z
M.E]G971087)A;65T97)S*"1P87)T+"`Q*2!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@:68@*"1K97D@/3T@)V-H87)S970G*2!["B`@("`@("`@
M("`@("`@("`D;V(M/G-E=$-H87)S970H)'9A;"D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D;V(M/G-E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"1K97DL("1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O*B!3970@=&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="X@*B\*
M("`@("`@("!I9B`H*"1O8BT^9V5T0VAA<G-E="@I(#T]("=U<RUA<V-I:2<I
M("8F"B`@("`@("`@("`@(&ES<V5T*"1'3$]"04Q36R=M:6UE7W-T<G5C='5R
M92==6R=D969A=6QT7V-H87)S970G72DI('L*("`@("`@("`@("`@)&]B+3YS
M971#:&%R<V5T*"1'3$]"04Q36R=M:6UE7W-T<G5C='5R92==6R=D969A=6QT
M7V-H87)S970G72D["B`@("`@("`@?0H*("`@("`@("`O*B!';R!T:')O=6=H
M('1H92!D:7-P;W-I=&EO;B!P87)A;65T97)S+"!I9B!A;GDN("HO"B`@("`@
M("`@9F]R96%C:"`H34E-15]3=')U8W1U<F4Z.E]G971087)A;65T97)S*"1P
M87)T+"`R*2!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)&]B+3YS
M971$:7-P;W-I=&EO;E!A<F%M971E<B@D:V5Y+"`D=F%L*3L*("`@("`@("!]
M"@H@("`@("`@("\J(%-E="!T:&4@;F%M92X@*B\*("`@("`@("!I9B`H)&]B
M+3YG971#;VYT96YT5'EP95!A<F%M971E<B@G9FEL96YA;64G*2D@>PH@("`@
M("`@("`@("`D;V(M/G-E=$YA;64H)&]B+3YG971#;VYT96YT5'EP95!A<F%M
M971E<B@G9FEL96YA;64G*2D["B`@("`@("`@?2!E;'-E:68@*"1O8BT^9V5T
M1&ES<&]S:71I;VY087)A;65T97(H)V9I;&5N86UE)RDI('L*("`@("`@("`@
M("`@)&]B+3YS971.86UE*"1O8BT^9V5T1&ES<&]S:71I;VY087)A;65T97(H
M)V9I;&5N86UE)RDI.PH@("`@("`@('T*"B`@("`@("`@+RH@4V5T('1H92!D
M97-C<FEP=&EO;BX@*B\*("`@("`@("!I9B`H:7-S970H)'!A<G0M/F1E<V-R
M:7!T:6]N*2D@>PH@("`@("`@("`@("`D;V(M/G-E=$1E<V-R:7!T:6]N*"1P
M87)T+3YD97-C<FEP=&EO;BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&%L;"!P87)A;65T97)S(&9O<B!A(&=I=F5N('!O<G1I;VX@
M;V8@82!M97-S86=E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!S=&1#;&%S<R`D<&%R="`@5&AE(&]R:6=I
M;F%L('!A<G0@:6YF;RX*("`@("`J($!P87)A;2!I;G1E9V5R("1T>7!E("`@
M5&AE('!A<F%M971E<B!T>7!E('1O(')E=')I979E+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`Q(#T@8V]N=&5N=`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`R(#T@9&ES<&]S:71I;VX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!P87)A;65T97(@:V5Y+W9A;'5E
M('!A:7)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4&%R86UE=&5R<R@D
M<&%R="P@)'1Y<&4I"B`@("!["B`@("`@("`@)'!A<F%M7VQI<W0@/2!A<G)A
M>2@I.PH*("`@("`@("!I9B`H)'1Y<&4@/3T@,2D@>PH@("`@("`@("`@("`D
M<'1Y<&4@/2`G<&%R86UE=&5R<R<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E
M(#T](#(I('L*("`@("`@("`@("`@)'!T>7!E(#T@)V1P87)A;65T97)S)SL*
M("`@("`@("!]"B`@("`@("`@)'!E>&ES=',@/2`G:68G("X@)'!T>7!E.PH*
M("`@("`@("!I9B`H)'!A<G0M/B1P97AI<W1S*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P87)T+3XD<'1Y<&4@87,@)'!A<F%M*2!["B`@("`@("`@("`@
M("`@("`D<&%R86TM/G9A;'5E(#T@<W1R7W)E<&QA8V4H87)R87DH(EQT(BP@
M)UPB)RDL(&%R<F%Y*"<@)RP@)R(G*2P@)'!A<F%M+3YV86QU92D["@H@("`@
M("`@("`@("`@("`@)')E<R`]($U)344Z.F1E8V]D95)&0S(R,S$H)'!A<F%M
M+3YA='1R:6)U=&4@+B`G/2<@+B`D<&%R86TM/G9A;'5E*3L*("`@("`@("`@
M("`@("`@(&EF("@D<F5S*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M
M+3YA='1R:6)U=&4@/2`D<F5S6R=A='1R:6)U=&4G73L*("`@("`@("`@("`@
M("`@("`@("`D<&%R86TM/G9A;'5E(#T@)')E<ULG=F%L=64G73L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1F:65L9"`](%-T<FEN9SHZ
M;&]W97(H)'!A<F%M+3YA='1R:6)U=&4I.PH@("`@("`@("`@("`@("`@:68@
M*"1F:65L9"`]/2`G='EP92<I('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M*"1T>7!E(#T@34E-13HZ='EP92@D<&%R86TM/G9A;'5E*2DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M7VQI<W1;)W1Y<&4G72`]("1T>7!E
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M7VQI<W1;)&9I96QD72`]
M("1P87)A;2T^=F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R86U?;&ES=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<W!E8VEA;"!I;F9O<FUA=&EO
M;B!F;W(@8V5R=&%I;B!-24U%('1Y<&5S+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)'!A<G1S
M("!4:&4@;&ES="!O9B!P87)T<R!C;VYT86EN960@=VET:&EN('1H92!M=6QT
M:7!A<G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!O8FIE8W0N"B`@
M("`@*B!`<&%R86T@87)R87D@)&EN9F\@("`@26YF;W)M871I;VX@86)O=70@
M=&AE(&UU;'1I<&%R="!S=')U8W1U<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]A9&1-=6QT:7!A<G1);F9O*"8D<&%R=',L("1I;F9O(#T@87)R87DH*2D*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'!A<G1S*2D@>PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1P87)T<RD@87,@)&ME>2D@>PH@("`@("`@("`@("`D<'1R(#T@)B1P
M87)T<ULD:V5Y73L*("`@("`@("`@("`@)&YE=U]I;F9O(#T@)&EN9F\["@H@
M("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)V%L="==*2D@>PH@("`@("`@
M("`@("`@("`@)'!T<BT^<V5T26YF;W)M871I;VXH)V%L=&5R;F%T:79E)RP@
M*&ES7VYU;&PH)&EN9F];)V%L="==*2D@/R`G+2<@.B`D:6YF;ULG86QT)UTI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG
M<F5L871E9"==*2D@>PH@("`@("`@("`@("`@("`@)'!T<BT^<V5T26YF;W)M
M871I;VXH)W)E;&%T961?<&%R="<L("1I;F9O6R=R96QA=&5D)UTM/F=E=$U)
M345)9"@I*3L*("`@("`@("`@("`@("`@(&EF("@D:60@/2`D<'1R+3YG971#
M;VYT96YT240H*2D@>PH@("`@("`@("`@("`@("`@("`@("1I;F9O6R=R96QA
M=&5D)UTM/F%D9$-)1"AA<G)A>2@D<'1R+3YG971-24U%260H*2`]/B`D:60I
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F];)W)F8S@R,B==*2D@>PH@("`@("`@("`@("`@
M("`@)'!T<BT^<V5T26YF;W)M871I;VXH)W)F8S@R,E]P87)T)RP@)&EN9F];
M)W)F8S@R,B==*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<W=I=&-H
M("@D<'1R+3YG9714>7!E*"DI('L*("`@("`@("`@("`@8V%S92`G;75L=&EP
M87)T+V%L=&5R;F%T:79E)SH*("`@("`@("`@("`@("`@("1N97=?:6YF;ULG
M86QT)UT@/2`D<'1R+3YG971-24U%260H*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+W)E;&%T960G.@H@
M("`@("`@("`@("`@("`@)&YE=U]I;F9O6R=R96QA=&5D)UT@/2`F)'!T<CL*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;65S
M<V%G92]R9F,X,C(G.@H@("`@("`@("`@("`@("`@)&YE=U]I;F9O6R=R9F,X
M,C(G72`]("1P='(M/F=E=$U)345)9"@I.PH@("`@("`@("`@("`@("`@)'!T
M<BT^<V5T26YF;W)M871I;VXH)VAE861E<B<L('1R=64I.PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@($U)345?
M4W1R=6-T=7)E.CI?861D375L=&EP87)T26YF;R@D<'1R+3Y?<&%R=',L("1N
M97=?:6YF;RD["B`@("`@("`@?0H@("`@?0H*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(&)U:6QD(&$@34E-15]-97-S86=E(&]B:F5C="!F<F]M(&$@
M=&5X="!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1E
M>'0@(%1H92!T97AT(&]F('1H92!-24U%(&UE<W-A9V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!-24U%7TUE<W-A9V4@($$@34E-15]-97-S86=E(&]B:F5C
M="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9P
M87)S951E>'1-24U%365S<V%G92@D=&5X="D*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@)TUA:6PO;6EM941E8V]D92YP:'`G.PH*("`@("`@("`O*B!3
M970@=7`@=&AE(&]P=&EO;G,@9F]R('1H92!M:6UE1&5C;V1E(&-L87-S+B`J
M+PH@("`@("`@("1D96-O9&5?87)G<R`](&%R<F%Y*"D["B`@("`@("`@)&1E
M8V]D95]A<F=S6R=I;F-L=61E7V)O9&EE<R==(#T@=')U93L*("`@("`@("`D
M9&5C;V1E7V%R9W-;)V1E8V]D95]B;V1I97,G72`](&9A;'-E.PH@("`@("`@
M("1D96-O9&5?87)G<ULG9&5C;V1E7VAE861E<G,G72`](&9A;'-E.PH*("`@
M("`@("`D;6EM941E8V]D92`]("9N97<@36%I;%]M:6UE1&5C;V1E*"1T97AT
M+"!-24U%7U!!4E1?14],*3L*("`@("`@("!I9B`H(2@D<W1R=6-T=7)E(#T@
M)&UI;65$96-O9&4M/F1E8V]D92@D9&5C;V1E7V%R9W,I*2D@>PH@("`@("`@
M("`@("`D;65S<V%G92`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\J(%!U="!T:&4@;V)J96-T(&EN=&\@:6UA<%]P87)S97-T<G5C
M='5R92@I(&9O<FTN("HO"B`@("`@("`@("`@($U)345?4W1R=6-T=7)E.CI?
M8V]N=F5R=$UI;65$96-O9&5$871A*"1S=')U8W1U<F4I.PH*("`@("`@("`@
M("`@)&UE<W-A9V4@/2!-24U%7U-T<G5C='5R93HZ<&%R<V4H)'-T<G5C='5R
M92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&UE<W-A9V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1H92!O=71P=70@9G)O;2!M:6UE
M1&5C;V1E.CID96-O9&4H*2!I;G1O(&$@<W1R=6-T=7)E('1H870*("`@("`J
M(&UA=&-H97,@:6UA<%]F971C:'-T<G5C='5R92@I(&]U='!U="X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1D0VQA<W,@)B1O8B`@5&AE(&]U='!U="!F<F]M(&UI;65$96-O9&4Z.F1E
M8V]D92@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N=F5R=$UI;65$96-O
M9&5$871A*"8D;V(I"B`@("!["B`@("`@("`@+RH@4')I;6%R>2!C;VYT96YT
M+71Y<&4N("HO"B`@("`@("`@)&]B+3YT>7!E(#T@:6YT=F%L*$U)344Z.G1Y
M<&4H)&]B+3YC='EP95]P<FEM87)Y*2D["@H@("`@("`@("\J(%-E8V]N9&%R
M>2!C;VYT96YT+71Y<&4N("HO"B`@("`@("`@:68@*&ES<V5T*"1O8BT^8W1Y
M<&5?<V5C;VYD87)Y*2D@>PH@("`@("`@("`@("`D;V(M/G-U8G1Y<&4@/2!3
M=')I;F<Z.G5P<&5R*"1O8BT^8W1Y<&5?<V5C;VYD87)Y*3L*("`@("`@("`@
M("`@)&]B+3YI9G-U8G1Y<&4@/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1O8BT^:69S=6)T>7!E(#T@,#L*("`@("`@("!]"@H@("`@("`@
M("\J($-O;G1E;G0@=')A;G-F97(@96YC;V1I;F<N("HO"B`@("`@("`@:68@
M*&ES<V5T*"1O8BT^:&5A9&5R<ULG8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN
M9R==*2D@>PH@("`@("`@("`@("`D;V(M/F5N8V]D:6YG(#T@34E-13HZ96YC
M;V1I;F<H)&]B+3YH96%D97)S6R=C;VYT96YT+71R86YS9F5R+65N8V]D:6YG
M)UTI.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N=&5N="UT>7!E(&%N9"!$
M:7-P;W-I=&EO;B!P87)A;65T97)S+B`J+PH@("`@("`@("1P87)A;5]T>7!E
M<R`](&%R<F%Y("@G8W1Y<&5?<&%R86UE=&5R<R<@/3X@)W!A<F%M971E<G,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9%]P87)A;65T97)S
M)R`]/B`G9'!A<F%M971E<G,G*3L*("`@("`@("!F;W)E86-H("@D<&%R86U?
M='EP97,@87,@)'!A<F%M7VME>2`]/B`D<&%R86U?=F%L=64I('L*("`@("`@
M("`@("`@)&EF7W9A<B`]("=I9B<@+B`D<&%R86U?=F%L=64["B`@("`@("`@
M("`@(&EF("AI<W-E="@D;V(M/B1P87)A;5]K97DI*2!["B`@("`@("`@("`@
M("`@("`D;V(M/B1I9E]V87(@/2`Q.PH@("`@("`@("`@("`@("`@)&]B+3XD
M<&%R86U?=F%L=64@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&]B+3XD<&%R86U?:V5Y(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@("1N97=/8B`]("9N97<@<W1D0VQA<W,["B`@("`@("`@
M("`@("`@("`@("`@)&YE=T]B+3YA='1R:6)U=&4@/2`D:V5Y.PH@("`@("`@
M("`@("`@("`@("`@("1N97=/8BT^=F%L=64@/2`D=F%L.PH@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W!U<V@H)&]B+3XD<&%R86U?=F%L=64L("1N97=/
M8BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;V(M/B1I9E]V87(@/2`P.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!#;VYT96YT+41I<W!O<VET:6]N+B`J
M+PH@("`@("`@(&EF("AI<W-E="@D;V(M/FAE861E<G-;)V-O;G1E;G0M9&ES
M<&]S:71I;VXG72DI('L*("`@("`@("`@("`@)&]B+3YI9F1I<W!O<VET:6]N
M(#T@,3L*("`@("`@("`@("`@)&AD<B`]("1O8BT^:&5A9&5R<ULG8V]N=&5N
M="UD:7-P;W-I=&EO;B==.PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1H
M9'(L("<[)RD["B`@("`@("`@("`@(&EF("@D<&]S("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)&AD<B`]('-U8G-T<B@D:&1R+"`P+"`D<&]S*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;V(M/F1I<W!O<VET:6]N(#T@
M)&AD<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(M/FEF9&ES
M<&]S:71I;VX@/2`P.PH@("`@("`@('T*"B`@("`@("`@+RH@0V]N=&5N="U)
M1"X@*B\*("`@("`@("!I9B`H:7-S970H)&]B+3YH96%D97)S6R=C;VYT96YT
M+6ED)UTI*2!["B`@("`@("`@("`@("1O8BT^:69I9"`](#$["B`@("`@("`@
M("`@("1O8BT^:60@/2`D;V(M/FAE861E<G-;)V-O;G1E;G0M:60G73L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(M/FEF:60@/2`P.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1V5T(&9I;&4@<VEZ92`H:68@)V)O9'DG('1E
M>'0@:7,@<V5T*2X@*B\*("`@("`@("!I9B`H:7-S970H)&]B+3YB;V1Y*2D@
M>PH@("`@("`@("`@("`D;V(M/F)Y=&5S(#T@<W1R;&5N*"1O8BT^8F]D>2D[
M"B`@("`@("`@?0H*("`@("`@("`O*B!0<F]C97-S('!A<G1S(&%L<V\N("HO
M"B`@("`@("`@:68@*&ES<V5T*"1O8BT^<&%R=',I*2!["B`@("`@("`@("`@
M(&9O<F5A8V@@*&%R<F%Y7VME>7,H)&]B+3YP87)T<RD@87,@)&ME>2D@>PH@
M("`@("`@("`@("`@("`@34E-15]3=')U8W1U<F4Z.E]C;VYV97)T36EM941E
M8V]D941A=&$H)&]B+3YP87)T<ULD:V5Y72D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@86X@87)R87D@
M8V]N<VES=&EN9R!O9B!-24U%(&AE861E<B]V86QU92!P86ER<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1H96%D97)S("`@("!!('1E>'0@<W1R
M:6YG(&-O;G1A:6YI;F<@=&AE(&AE861E<G,@*&4N9RX*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]U='!U="!F<F]M(&EM87!?9F5T8VAH
M96%D97(H*2DN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&5C;V1E("`@("!3
M:&]U;&0@=&AE(&AE861E<G,@8F4@9&5C;V1E9#\*("`@("`J($!P87)A;2!B
M;V]L96%N("1L;W=E<F-A<V4@(%-H;W5L9"!T:&4@:V5Y<R!B92!I;B!L;W=E
M<F-A<V4_"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@
M8V]N<VES=&EN9R!O9B!T:&4@:&5A9&5R(&YA;64@87,@=&AE(&ME>2!A;F0*
M("`@("`J("`@("`@("`@("`@("`@('1H92!H96%D97(@=F%L=64@87,@=&AE
M('9A;'5E+@H@("`@("H@("`@("`@("`@("`@("`@02!H96%D97(@=VET:"!M
M=6QT:7!L92!E;G1R:65S('=I;&P@8F4@<W1O<F5D(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`G=F%L=64G(&%S(&%N(&%R<F%Y+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!P87)S94U)345(96%D97)S*"1H96%D97)S+"`D9&5C;V1E(#T@
M=')U92P@)&QO=V5R8V%S92`](&9A;'-E*0H@("`@>PH@("`@("`@("1H96%D
M97(@/2`G)SL*("`@("`@("`D;V(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("AE>'!L;V1E*")<;B(L("1H96%D97)S*2!A<R`D=F%L*2!["B`@("`@
M("`@("`@(&EF("@D9&5C;V1E*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@
M34E-13HZ9&5C;V1E*"1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"(O7BA;7EQS72LI7#HH+BHI+R(L("1V86PL("1M
M871C:&5S*2D@>PH@("`@("`@("`@("`@("`@)'9A;"`]('1R:6TH)&UA=&-H
M97-;,ETI.PH@("`@("`@("`@("`@("`@)&AE861E<B`]("1M871C:&5S6S%=
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O8ELD:&5A9&5R72DI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O8ELD:&5A9&5R
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1E;7`@/2`D;V);)&AE
M861E<ET["B`@("`@("`@("`@("`@("`@("`@("`@("1O8ELD:&5A9&5R72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("1O8ELD:&5A9&5R
M75M=(#T@)'1E;7`["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1O8ELD:&5A9&5R75M=(#T@)'9A;#L*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V86P@/2`G("<@+B!T<FEM
M*"1V86PI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1H96%D97(I*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]B6R1H
M96%D97)=*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M;V);)&AE861E<ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&5N9"@D
M;V);)&AE861E<ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`D;V);)&AE
M861E<EU;:V5Y*"1O8ELD:&5A9&5R72E=("X]("1V86P["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&]B
M6R1H96%D97)=("X]("1V86P["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;V);
M)&AE861E<ET@/2`D=F%L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"1L;W=E<F-A<V4I(#\@
M87)R87E?8VAA;F=E7VME>5]C87-E*"1O8BP@0T%315],3U=%4BD@.B`D;V([
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O34E-12]6:65W97(N<&AP````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,S8S,#,@,3`U,34T,S0Q,S<@,#(R,#4S`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&4@34E-15]6:65W97(Z.B!C;&%S<R!P<F]V:61E<R!A;B!A8G-T
M<F%C=&5D(&EN=&5R9F%C92!T;PH@*B!R96YD97(@;W5T($U)344@='EP97,@
M:6YT;R!(5$U,(&9O<FUA="X@($ET(&1E<&5N9',@;VX@80H@*B!S970@;V8@
M34E-15]6:65W97)?*B!D<FEV97)S('=H:6-H(&AA;F1L92!T:&4@86-T=6%L
M(')E;F1E<FEN9RP*("H@86YD(&%L<V\@82!C;VYF:6=U<F%T:6]N(&9I;&4@
M=&\@;6%P($U)344@='EP97,@=&\@9')I=F5R<RX*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO34E-12]-24U%+U9I97=E<BYP:'`L=B`Q+C8T+C$P+C$P(#(P
M,#8O,#4O,#4@,#,Z,S`Z,C,@<VQU<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO
M<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P
M961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*
M("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?
M5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%1H92!-24U%7U!A<G0@;V)J96-T
M('1O(')E;F1E<BX*("`@("`J"B`@("`@*B!`=F%R($U)345?4&%R=`H@("`@
M("HO"B`@("!V87(@)&UI;65?<&%R=#L*"B`@("`O*BH*("`@("`J($-O;F9I
M9W5R871I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7V-O;F8@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@9V5T1')I=F5R(&-A8VAE+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?9')I=F5R0V%C:&4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@1F]R8V4@=FEE=VEN9R!O9B!A('!A<G0@:6YL:6YE
M+"!R96=A<F1L97-S(&]F('1H92!#;VYT96YT+41I<W!O<VET:6]N"B`@("`@
M*B!O9B!T:&4@34E-12!087)T+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A
M;@H@("`@("HO"B`@("!V87(@)%]F;W)C96EN;&EN92`](&9A;'-E.PH*("`@
M("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@8V]N8W)E=&4@34E-
M15]6:65W97)?*B!O8FIE8W0@8F%S960@;VX@=&AE"B`@("`@*B!T>7!E(&]F
M($U)345?4&%R="!P87-S960@;VYT;R!I="X*("`@("`J"B`@("`@*B!`<&%R
M86T@34E-15]087)T("8D;6EM95]P87)T("!2969E<F5N8V4@=&\@82!-24U%
M7U!A<G0@;V)J96-T('=I=&@@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I;F9O<FUA=&EO;B!T;R!B92!R96YD97)E9"X*("`@
M("`J($!P87)A;2!S=')I;F<@)&UI;65?='EP92`@("`@(%5S92!T:&ES($U)
M344@='EP92!I;G-T96%D(&]F('1H92!T>7!E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=&]R960@:6X@=&AE("1M:6UE7W!A<G0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!-24U%7U9I97=E<B`@5&AE($U)345?
M5FEE=V5R(&]B:F5C="P@;W(@9F%L<V4@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9F86-T;W)Y*"8D;6EM95]P87)T+"`D;6EM95]T>7!E(#T@
M;G5L;"D*("`@('L*("`@("`@("`O*B!#:&5C:R!T:&%T('=E(&AA=F4@82!V
M86QI9"!-24U%7U!A<G0@;V)J96-T("HO"B`@("`@("`@:68@*"%I<U]A*"1M
M:6UE7W!A<G0L("=-24U%7U!A<G0G*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!$971E<FUI;F4@9')I=F5R
M('1Y<&4@9G)O;2!T:&4@34E-12!T>7!E("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1M:6UE7W1Y<&4I*2!["B`@("`@("`@("`@("1M:6UE7W1Y<&4@/2`D;6EM
M95]P87)T+3YG9714>7!E*"D["B`@("`@("`@("`@(&EF("AE;7!T>2@D;6EM
M95]T>7!E*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=FEE=V5R(#T@9F%L<V4[
M"@H@("`@("`@("\J(%-P87=N('1H92!R96QE=F%N="!D<FEV97(L(&%N9"!R
M971U<FX@:70@*&]R(&9A;'-E(&]N(&9A:6QU<F4I("HO"B`@("`@("`@:68@
M*"@D;V(@/2!-24U%7U9I97=E<CHZ:6YC;'5D941R:79E<B@D;6EM95]T>7!E
M*2DI('L*("`@("`@("`@("`@)&-L87-S(#T@*"@D;V(M/FUO9'5L92`]/2`G
M:&]R9&4G*2`_("<G(#H@)&]B+3YM;V1U;&4@+B`G7R<I("X@)TU)345?5FEE
M=V5R7R<@+B`D;V(M/F1R:79E<CL*("`@("`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("`@("`D=FEE=V5R(#T@)FYE
M=R`D8VQA<W,H)&UI;65?<&%R="P@)$=,3T)!3%-;)VUI;65?9')I=F5R<R==
M6R1O8BT^;6]D=6QE75LD;V(M/F1R:79E<ETI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'9I97=E<CL*("`@('T*"B`@("`O
M*BH*("`@("`J($EN8VQU9&4@=&AE(&-O9&4@9F]R('1H92!R96QE=F%N="!D
M<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM95]T>7!E
M("!4:&4@0V]N=&5N="UT>7!E(&]F('1H92!P87)T('1O(&)E(')E;F1E<F5D
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1D0VQA<W,@(%-E92!-24U%7T1R
M:79E<CHZ9V5T1')I=F5R*"DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN8VQU
M9&5$<FEV97(H)&UI;65?='EP92D*("`@('L*("`@("`@("`O+R!43T1/.B!"
M0R`M('-W:71C:"!T;R!R97%U:7)E7V]N8V4@9F]R($AO<F1E(#0N,#L@9&]N
M)W0@;F5E9"`D8V]N9FEG.PH@("`@("`@("\O("`@("`@(&1O;B=T(&YE960@
M=&\@;6%K92!S=7)E('1H92`R('9A<FEA8FQE<R!A<F4@=6YS970N"B`@("`@
M("`@<W1A=&EC("1C;VYF:6<@/2!F86QS93L*("`@("`@("!G;&]B86P@)')E
M9VES=')Y.PH*("`@("`@("`D87!P(#T@)')E9VES=')Y+3YG971!<'`H*3L*
M"B`@("`@("`@:68@*"$D8V]N9FEG*2!["B`@("`@("`@("`@("1'3$]"04Q3
M6R=M:6UE7V1R:79E<G,G72`]("1'3$]"04Q36R=M:6UE7V1R:79E<G-?;6%P
M)UT@/2!A<G)A>2@I.PH@("`@("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^
M9V5T*"=F:6QE<F]O="<L("=H;W)D92<I("X@)R]C;VYF:6<O;6EM95]D<FEV
M97)S+G!H<"<["B`@("`@("`@("`@(&EF("@D87!P("$]("=H;W)D92<I('L*
M("`@("`@("`@("`@("`@("1B87-E(#T@)')E9VES=')Y+3YG970H)V9I;&5R
M;V]T)RP@)&%P<"D["B`@("`@("`@("`@("`@("!I9B`H:7-?<F5A9&%B;&4H
M)&)A<V4@+B`G+V-O;F9I9R]M:6UE7V1R:79E<G,N<&AP)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R97%U:7)E("1B87-E("X@)R]C;VYF:6<O;6EM95]D
M<FEV97)S+G!H<"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)$=,3T)!3%-;)VUI;65?9')I=F5R<R==(#T@)&UI;65?
M9')I=F5R<SL*("`@("`@("`@("`@)$=,3T)!3%-;)VUI;65?9')I=F5R<U]M
M87`G72`]("1M:6UE7V1R:79E<G-?;6%P.PH@("`@("`@("`@("`D8V]N9FEG
M(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("\J($9I9W5R92!T:&4@8V]R
M<F5C="!D<FEV97(@9F]R('1H:7,@34E-12!T>7!E+B!)9B!T:&5R92!I<R!N
M;PH@("`@("`@("`@(&%P<&QI8V%T:6]N+7-P96-I9FEC(&UO9'5L92P@82!G
M96YE<F%L($AO<F1E(&]N92!W:6QL(&%T=&5M<'0@=&\*("`@("`@("`@("!B
M92!U<V5D+B`J+PH@("`@("`@(&EF("@H)&]B(#T@34E-15]6:65W97(Z.F=E
M=$1R:79E<B@D;6EM95]T>7!E+"`D<F5G:7-T<GDM/F=E=$%P<"@I*2DI('L*
M("`@("`@("`@("`@+RH@26YC;'5D92!T:&4@8VQA<W,N("HO"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92!-24U%7U9I97=E<CHZ<F5S;VQV941R:79E<B@D
M;V(M/F1R:79E<BP@)&]B+3YM;V1U;&4I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1O8CL*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R
M(&9O<B!-24U%7U9I97=E<@H@("`@("H*("`@("`J($!P87)A;2!-24U%7U!A
M<G0@)B1M:6UE7W!A<G0@(%)E9F5R96YC92!T;R!A($U)345?4&%R="!O8FIE
M8W0@=VET:"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EN9F]R;6%T:6]N('1O(&)E(')E;F1E<F5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!-24U%7U9I97=E<B@F)&UI;65?<&%R="P@)&-O;F8@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3YM:6UE7W!A<G0@/2`F)&UI;65?
M<&%R=#L*("`@("`@("`D=&AI<RT^7V-O;F8@/2`D8V]N9CL*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@=&AE($U)345?4&%R="!O8FIE8W0@9F]R('1H
M92!C;&%S<RX*("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM
M95]P87)T("!2969E<F5N8V4@=&\@82!-24U%7U!A<G0@;V)J96-T('=I=&@@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;F9O
M<FUA=&EO;B!T;R!B92!R96YD97)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T34E-15!A<G0H)B1M:6UE7W!A<G0I"B`@("!["B`@("`@("`@)'1H:7,M
M/FUI;65?<&%R="`]("8D;6EM95]P87)T.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!-24U%('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E
M;G0N("!4:&ES(&-A;B!B90H@("`@("H@;W9E<G)I9&1E;B!B>2!T:&4@:6YD
M:79I9'5A;"!D<FEV97)S+"!D97!E;F1I;F<@;VX@=VAA="!F;W)M870*("`@
M("`J('1H97D@;W5T<'5T(&EN+B!">2!D969A=6QT+"!I="!P87-S97,@=&AR
M;W5G:"!T:&4@34E-12!T>7!E(&]F"B`@("`@*B!T:&4@;V)J96-T+"!O<B!R
M97!L86-E<R!C=7-T;VT@97AT96YS:6]N('1Y<&5S('=I=&@*("`@("`J("=T
M97AT+W!L86EN)R!T;R!L970@=&AE(&)R;W=S97(@9&\@82!B97-T+6=U97-S
M(')E;F1E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@34E-12UT
M>7!E(&]F('1H92!O=71P=70@8V]N=&5N="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM:6UE7W!A
M<G0M/F=E=%!R:6UA<GE4>7!E*"D@/3T@)W@M97AT96YS:6]N)RD@>PH@("`@
M("`@("`@("!R971U<FX@)W1E>'0O<&QA:6XG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E
M*'1R=64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@<F5N9&5R960@=F5R<VEO;B!O9B!T:&4@;V)J96-T+@H@("`@("H*
M("`@("`J(%-H;W5L9"!B92!O=F5R<FED9&5N(&)Y(&EN9&EV:61U86P@9')I
M=F5R<R!T;R!P97)F;W)M(&-U<W1O;2!T87-K<RX*("`@("`J(%1H92`D;6EM
M95]P87)T(&-L87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I;VX@=&\@
M<F5N9&5R+`H@("`@("H@96YC87!S=6QA=&5D(&EN(&$@34E-15]087)T(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'!A<F%M<R`@06YY
M(&]P=&EO;F%L('!A<F%M971E<G,@=&AI<R!D<FEV97(@;F5E9',@870*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!R=6YT:6UE+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!296YD97)E9"!V97)S:6]N(&]F('1H92!O
M8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@
M;G5L;"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FUI;65?<&%R="T^
M9V5T0V]N=&5N=',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T
M97AT+VAT;6P@;W5T<'5T('5S960@87,@86QT97)N871I=F4@;W5T<'5T('=H
M96X@=&AE(&9U;&QY"B`@("`@*B!R96YD97)E9"!O8FIE8W0@8V%N;F]T("AO
M<B!S:&]U;&0@;F]T*2!B92!D:7-P;&%Y960N("!&;W(@97AA;7!L92P*("`@
M("`J('1H:7,@9G5N8W1I;VX@<VAO=6QD(&)E('5S960@9F]R($U)344@871T
M86-H;65N=',@=&AA="!C86YN;W0@8F4*("`@("`J('9I97=E9"!I;FQI;F4L
M('=H97)E('1H92!U<V5R(&UA>2!B92!G:79E;B!O<'1I;VYS(&]N(&AO=R!T
M;R!V:65W"B`@("`@*B!T:&4@871T86-H;65N="X*("`@("`J(%-H;W5L9"!B
M92!O=F5R<FED9&5N(&)Y(&EN9&EV:61U86P@9')I=F5R<R!T;R!P97)F;W)M
M(&-U<W1O;2!T87-K<RX*("`@("`J(%1H92`D;6EM95]P87)T(&-L87-S('9A
M<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I;VX@=&\@<F5N9&5R+`H@("`@("H@
M96YC87!S=6QA=&5D(&EN(&$@34E-15]087)T(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)'!A<F%M<R`@06YY(&]P=&EO;F%L('!A<F%M
M971E<G,@=&AI<R!D<FEV97(@;F5E9',@870*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!R=6YT:6UE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!497AT+VAT;6P@<F5N9&5R960@:6YF;W)M871I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')E;F1E<D%T=&%C:&UE;G1);F9O*"D*("`@('L*("`@
M('T*"B`@("`O*BH*("`@("`J($-A;B!T:&ES(&1R:79E<B!R96YD97(@=&AE
M('1H92!D871A(&EN;&EN93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AE(&1R:79E<B!C86X@9&ES<&QA>2!I;FQI;F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-A;D1I<W!L87E);FQI;F4H*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^9V5T0V]N9FEG4&%R86TH)VEN;&EN92<I*2![
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!':79E;B!A(&1R:79E<B!A;F0@86X@87!P;&EC871I;VXL
M('1H:7,@<F5T=7)N<R!T:&4@9G5L;'D*("`@("`J('%U86QI9FEE9"!F:6QE
M<WES=&5M('!A=&@@=&\@=&AE(&1R:79E<B!S;W5R8V4@9FEL92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D<FEV97(@($1R:79E<B!N86UE+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D87!P("`@("!!<'!L:6-A=&EO;B!N86UE
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!&:6QE<WES=&5M('!A
M=&@@;V8@=&AE(&1R:79E<B]A<'!L:6-A=&EO;B!Q=65R:65D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R97-O;'9E1')I=F5R*"1D<FEV97(@/2`G9&5F875L
M="<L("1A<'`@/2`G:&]R9&4G*0H@("`@>PH@("`@("`@(&EF("@D87!P(#T]
M("=H;W)D92<I('L*("`@("`@("`@("`@<F5T=7)N(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]6:65W97(O)R`N("1D<FEV97(@+B`G+G!H<"<["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=R96=I<W1R
M>2==+3YA<'!L:6-A=&EO;G-;)&%P<%U;)V9I;&5R;V]T)UT@+B`G+VQI8B]-
M24U%+U9I97=E<B\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A;B!I;G!U="!-24U%('1Y<&4@
M86YD(&$@;6]D=6QE(&YA;64L('1H:7,@9G5N8W1I;VX*("`@("`J(')E<V]L
M=F5S(&ET(&EN=&\@82!S<&5C:69I8R!O=71P=70@9')I=F5R('=H:6-H(&-A
M;B!H86YD;&4@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;6EM
M951Y<&4@($U)344@='EP92!T;R!R97-O;'9E+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;6]D=6QE("`@($UO9'5L92!I;B!W:&EC:"!T;R!S96%R8V@@9F]R
M('1H92!D<FEV97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@
M3V)J96-T('=I=&@@=&AE(&9O;&QO=VEN9R!I=&5M<SH*("`@("`J(#QP<F4^
M"B`@("`@*B`G9')I=F5R)R`@+2T@($YA;64@;V8@9')I=F5R("AE+F<N("=E
M;G-C<FEP="<I"B`@("`@*B`G97AA8W0G("`@+2T@(%=A<R!T:&4@9')I=F5R
M(&%N9"!E>&%C="!M871C:#\@*'1R=64O9F%L<V4I"B`@("`@*B`G;6]D=6QE
M)R`@+2T@(%1H92!M;V1U;&4@8V]N=&%I;FEN9R!D<FEV97(@*&4N9RX@)VAO
M<F1E)RD*("`@("`J(#PO<')E/@H@("`@("H@4F5T=7)N<R!F86QS92!I9B!D
M<FEV97(@8V]U;&0@;F]T(&)E(&9O=6YD+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971$<FEV97(H)&UI;654>7!E+"`D;6]D=6QE(#T@)VAO<F1E)RD*("`@
M('L*("`@("`@("!G;&]B86P@)&UI;65?9')I=F5R<RP@)&UI;65?9')I=F5R
M<U]M87`["@H@("`@("`@("1C86-H94YA;64@/2`D;6EM951Y<&4@+B`G?"<@
M+B`D;6]D=6QE.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H
M)'1H:7,M/E]D<FEV97)#86-H95LD8V%C:&5.86UE72DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?9')I=F5R0V%C:&5;)&-A8VAE3F%M95T["B`@
M("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@)R<["B`@("`@("`@)&5X86-T
M1')I=F5R(#T@9F%L<V4["@H@("`@("`@(&QI<W0H)'!R:6UA<GE?='EP92P@
M*2`](&5X<&QO9&4H)R\G+"`D;6EM951Y<&4L(#(I.PH@("`@("`@("1A;&Q3
M=6(@/2`D<')I;6%R>5]T>7!E("X@)R\J)SL*"B`@("`@("`@+RH@268@=&AE
M(&UO9'5L92!D;V5S;B=T(&5X:7-T(&EN("1M:6UE7V1R:79E<G-?;6%P+"!C
M:&5C:R!F;W(*("`@("`@("`@("!(;W)D92!V:65W97)S+B`J+PH@("`@("`@
M(&EF("@A:7-S970H)&UI;65?9')I=F5R<U]M87!;)&UO9'5L95TI("8F("1M
M;V1U;&4@(3T@)VAO<F1E)RD@>PH@("`@("`@("`@("!R971U<FX@34E-15]6
M:65W97(Z.F=E=$1R:79E<B@D;6EM951Y<&4L("=H;W)D92<I.PH@("`@("`@
M('T*"B`@("`@("`@)&1R(#T@)B1M:6UE7V1R:79E<G-;)&UO9'5L95T["B`@
M("`@("`@)&UA<"`]("8D;6EM95]D<FEV97)S7VUA<%LD;6]D=6QE73L*"B`@
M("`@("`@+RH@268@86X@;W9E<G)I9&4@97AI<W1S(&9O<B!T:&ES($U)344@
M='EP92P@=&AE;B!U<V4@=&AA="`J+PH@("`@("`@(&EF("AI<W-E="@D;6%P
M6R=O=F5R<FED97,G75LD;6EM951Y<&5=*2D@>PH@("`@("`@("`@("`D9')I
M=F5R(#T@)&UA<%LG;W9E<G)I9&5S)UU;)&UI;654>7!E73L*("`@("`@("`@
M("`@)&5X86-T1')I=F5R(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H:7-S
M970H)&UA<%LG;W9E<G)I9&5S)UU;)&%L;%-U8ETI*2!["B`@("`@("`@("`@
M("1D<FEV97(@/2`D;6%P6R=O=F5R<FED97,G75LD86QL4W5B73L*("`@("`@
M("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*("`@("`@("!](&5L<V5I9B`H
M:7-S970H)&UA<%LG<F5G:7-T97)E9"==*2D@>PH@("`@("`@("`@("`O*B!)
M=&5R871E('1H<F]U9V@@=&AE(&QI<W0@;V8@<F5G:7-T97)E9"!D<FEV97)S
M+"!A;F0@<V5E(&EF"B`@("`@("`@("`@("`@('1H:7,@34E-12!T>7!E(&5X
M:7-T<R!I;B!T:&4@34E-12!T>7!E<R!T:&%T('1H97D@8VQA:6T@=&\*("`@
M("`@("`@("`@("`@:&%N9&QE+B!)9B!T:&4@9')I=F5R(&AA;F1L97,@:70L
M('1H96X@87-S:6=N(&ET(&%S('1H90H@("`@("`@("`@("`@("!R96YD97)I
M;F<@9')I=F5R+B!)9B!W92!F:6YD(&$@9V5N97)I8R!H86YD;&5R+"!K965P
M(&ET97)A=&EN9PH@("`@("`@("`@("`@("!T;R!S964@:68@=V4@8V%N(&9I
M;F0@82!S<&5C:69I8R!H86YD;&5R+B`J+PH@("`@("`@("`@("!F;W)E86-H
M("@D;6%P6R=R96=I<W1E<F5D)UT@87,@)'9A;"D@>PH@("`@("`@("`@("`@
M("`@:68@*&EN7V%R<F%Y*"1M:6UE5'EP92P@)&1R6R1V86Q=6R=H86YD;&5S
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)&1R:79E<B`]("1V86P["B`@
M("`@("`@("`@("`@("`@("`@)&5X86-T1')I=F5R(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@96QS96EF
M("AI;E]A<G)A>2@D86QL4W5B+"`D9');)'9A;%U;)VAA;F1L97,G72DI('L*
M("`@("`@("`@("`@("`@("`@("`D9')I=F5R(#T@)'9A;#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@
M268@=&AI<R!I<R!A;B!A<'!L:6-A=&EO;B!S<&5C:69I8R!M;V1U;&4L(&%N
M9"!A;B!E>&%C="!M871C:"!W87,*("`@("`@("`@("!N;W0@9F]U;F0L('-E
M87)C:"!F;W(@82!(;W)D92UW:61E('-P96-I9FEC(&1R:79E<BX@3VYL>2!U
M<V4@=&AE"B`@("`@("`@("`@2&]R9&4M<W!E8VEF:6,@9')I=F5R(&EF(&ET
M(&ES($Y/5"!T:&4@)V1E9F%U;'0G(&1R:79E<B!!3D0@=&AE"B`@("`@("`@
M("`@2&]R9&4@9')I=F5R(&ES(&%N(&5X86-T(&UA=&-H+B`J+PH@("`@("`@
M(&EF("@A)&5X86-T1')I=F5R("8F("1M;V1U;&4@(3T@)VAO<F1E)RD@>PH@
M("`@("`@("`@("`D;V(@/2!-24U%7U9I97=E<CHZ9V5T1')I=F5R*"1M:6UE
M5'EP92P@)VAO<F1E)RD["B`@("`@("`@("`@(&EF("AE;7!T>2@D9')I=F5R
M*2!\?`H@("`@("`@("`@("`@("`@*"@D;V(M/F1R:79E<B`A/2`G9&5F875L
M="<I("8F("1O8BT^97AA8W0I*2!["B`@("`@("`@("`@("`@("`D9')I=F5R
M(#T@)&]B+3YD<FEV97(["B`@("`@("`@("`@("`@("`D;6]D=6QE(#T@)VAO
M<F1E)SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@268@
M=&AE("=D969A=6QT)R!D<FEV97(@97AI<W1S(&EN('1H:7,@;6]D=6QE+"!F
M86QL(&)A8VL@=&\@=&AA="X@*B\*("`@("`@("!I9B`H96UP='DH)&1R:79E
M<BD@)B8*("`@("`@("`@("`@0&ES7V9I;&4H34E-15]6:65W97(Z.G)E<V]L
M=F5$<FEV97(H)V1E9F%U;'0G+"`D;6]D=6QE*2DI('L*("`@("`@("`@("`@
M)&1R:79E<B`]("=D969A=6QT)SL*("`@("`@("!]"@H@("`@("`@(&EF("AE
M;7!T>2@D9')I=F5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1R:79E<D-A
M8VAE6R1C86-H94YA;65=(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V(@/2!N97<@
M<W1D0VQA<W,["B`@("`@("`@("`@("1O8BT^9')I=F5R(#T@)&1R:79E<CL*
M("`@("`@("`@("`@)&]B+3YE>&%C="`@/2`D97AA8W1$<FEV97(["B`@("`@
M("`@("`@("1O8BT^;6]D=6QE(#T@)&UO9'5L93L*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D<FEV
M97)#86-H95LD8V%C:&5.86UE72`]("1O8CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!R971U<FX@)&]B.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($=I=F5N(&$@34E-12!T>7!E+"!T:&ES(&9U;F-T:6]N('=I;&P@
M<F5T=7)N(&%N(&%P<')O<')I871E"B`@("`@*B!I8V]N+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&UI;654>7!E("!4:&4@34E-12!T>7!E('1H
M870@=V4@;F5E9"!A;B!I8V]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(%523"!T;R!T:&4@87!P<F]P<FEA=&4@:6-O;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T26-O;B@D;6EM951Y<&4I"B`@("!["B`@
M("`@("`@)&%P<"`]("1'3$]"04Q36R=R96=I<W1R>2==+3YG971!<'`H*3L*
M("`@("`@("`D;V(@/2!-24U%7U9I97=E<CHZ7V=E=$EC;VXH)&UI;654>7!E
M+"`D87!P*3L*"B`@("`@("`@:68@*"1O8B`]/3T@;G5L;"D@>PH@("`@("`@
M("`@("!I9B`H)&%P<"`A/2`G:&]R9&4G*2!["B`@("`@("`@("`@("`@("`D
M;V)(;W)D92`]($U)345?5FEE=V5R.CI?9V5T26-O;B@D;6EM951Y<&4L("=H
M;W)D92<I.PH@("`@("`@("`@("`@("`@<F5T=7)N("@D;V)(;W)D92`]/3T@
M;G5L;"D@/R!N=6QL(#H@)&]B2&]R9&4M/G5R;#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E:68@*"@D;V(M/FUA=&-H("$]/2`P*2`F)B`H
M)&%P<"`A/2`G:&]R9&4G*2D@>PH@("`@("`@("`@("`D;V)(;W)D92`]($U)
M345?5FEE=V5R.CI?9V5T26-O;B@D;6EM951Y<&4L("=H;W)D92<I.PH@("`@
M("`@("`@("!I9B`H)&]B+3YM871C:"`A/3T@;G5L;"`F)B`D;V(M/FUA=&-H
M(#P]("1O8DAO<F1E+3YM871C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1O8BT^=7)L.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1O8DAO<F1E+3YU<FP["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)&]B+3YU<FP["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@86X@:6YP=70@34E-
M12!T>7!E(&%N9"!M;V1U;&4L('1H:7,@9G5N8W1I;VX@<F5T=7)N<R!T:&4*
M("`@("`J(%523"!O9B!A;B!I8V]N('1H870@8V%N(&)E(&%S<V]C:6%T960@
M=VET:"!I=`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&UI;654>7!E("!-24U%('1Y<&4@=&\@
M9V5T('1H92!I8V]N(&9O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L
M87-S("!U<FPZ("`@55),('1O(&%N(&EC;VXL(&]R(&YU;&P@:68@;F]N90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-O=6QD(&)E(&9O=6YD
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@97AA8W0Z($AO=R!E>&%C="!T
M:&4@;6%T8V@@:7,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M,"`]/B`G97AA8W0G+"`Q(#T^("=P<FEM87)Y)RP*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`R(#T^("=D<FEV97(G+"`S(#T^("=D969A=6QT
M)PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&YU;&PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]G971)8V]N*"1M:6UE5'EP92P@)&UO9'5L
M92`]("=H;W)D92<I"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E
M<G,["@H@("`@("`@("1O8B`]($U)345?5FEE=V5R.CIG971$<FEV97(H)&UI
M;654>7!E+"`D;6]D=6QE*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D;V(I
M*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2AF86QS92P@;G5L;"D["B`@
M("`@("`@?0H@("`@("`@("1D<FEV97(@/2`D;V(M/F1R:79E<CL*"B`@("`@
M("`@;&ES="@D<')I;6%R>5]T>7!E+"D@/2!E>'!L;V1E*"<O)RP@)&UI;654
M>7!E+"`R*3L*("`@("`@("`D86QL4W5B(#T@)'!R:6UA<GE?='EP92`N("<O
M*B<["B`@("`@("`@)')E=$]B(#T@)FYE=R!S=&1#;&%S<R@I.PH@("`@("`@
M("1R971/8BT^;6%T8V@@/2!N=6QL.PH@("`@("`@("1R971/8BT^=7)L(#T@
M;G5L;#L*"B`@("`@("`@+RH@268@=&AE(&UO9'5L92!D;V5S;B=T(&5X:7-T
M(&EN("1M:6UE7V1R:79E<G,L(')E='5R;B!N;W<N("HO"B`@("`@("`@:68@
M*"%I<W-E="@D;6EM95]D<FEV97)S6R1M;V1U;&5=*2D@>PH@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@)&1R(#T@)B1M:6UE
M7V1R:79E<G-;)&UO9'5L95T["@H@("`@("`@("\J($EF(&$@<W!E8VEF:6,@
M:6-O;B!F;W(@=&AI<R!D<FEV97(@86YD(&UI;65T>7!E(&ES(&1E9FEN960L
M"B`@("`@("`@("`@=&AE;B!U<V4@=&AA="X@*B\*("`@("`@("!I9B`H:7-S
M970H)&1R6R1D<FEV97)=6R=I8V]N<R==*2D@>PH@("`@("`@("`@("`D:6-O
M;F1R(#T@)B1M:6UE7V1R:79E<G-;)&UO9'5L95U;)&1R:79E<EU;)VEC;VYS
M)UT["B`@("`@("`@("`@("1I8V]N3&ES="`](&%R<F%Y*"1M:6UE5'EP92`]
M/B`P+"`D86QL4W5B(#T^(#$L("=D969A=6QT)R`]/B`R*3L*("`@("`@("`@
M("`@9F]R96%C:"`H)&EC;VY,:7-T(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1I8V]N9');)&ME>5TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E=$]B+3YU<FP@/2`D:6-O;F1R6R1K97E=.PH@
M("`@("`@("`@("`@("`@("`@("1R971/8BT^;6%T8V@@/2`D=F%L.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!4<GD@=&\@=7-E(&$@
M9&5F875L="!I8V]N(&EF(&YO;F4@86QR96%D>2!O8G1A:6YE9"X@*B\*("`@
M("`@("!I9B`H:7-?;G5L;"@D<F5T3V(M/G5R;"D@)B8@:7-S970H)&1R6R=D
M969A=6QT)UTI*2!["B`@("`@("`@("`@("1D<B`]("8D;6EM95]D<FEV97)S
M6R1M;V1U;&5=6R=D969A=6QT)UT["B`@("`@("`@("`@(&EF("AI<W-E="@D
M9');)VEC;VYS)UU;)V1E9F%U;'0G72DI('L*("`@("`@("`@("`@("`@("1R
M971/8BT^=7)L(#T@)&1R6R=D969A=6QT)UU;)VEC;VYS)UU;)V1E9F%U;'0G
M73L*("`@("`@("`@("`@("`@("1R971/8BT^;6%T8V@@/2`S.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7VYU;&PH)')E=$]B
M+3YU<FPI*2!["B`@("`@("`@("`@("1R971/8BT^=7)L(#T@)$=,3T)!3%-;
M)W)E9VES=')Y)UTM/F=E=$EM86=E1&ER*"1M;V1U;&4I("X@)R]M:6UE+R<@
M+B`D<F5T3V(M/G5R;#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5T
M3V(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R86-T
M97(@<V5T('5S960@9F]R('1H92!6:65W97(N"B`@("`@*B!3:&]U;&0@8F4@
M;W9E<G)I9&1E;B!B>2!I;F1I=FED=6%L(&1R:79E<G,@=&\@<&5R9F]R;2!C
M=7-T;VT@=&%S:W,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!C:&%R86-T97(@<V5T('5S960@8GD@=&AI<R!6:65W97(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=$-H87)S970H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^;6EM95]P87)T+3YG971#:&%R<V5T*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!C;VYF:6=U<F%T:6]N('!A<F%M971E<B!F
M;W(@=&AE(&-U<G)E;G0@=FEE=V5R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A<F%M("!4:&4@<&%R86UE=&5R(&YA;64N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE('9A;'5E(&]F('1H92!P87)A;65T97([
M(')E='5R;G,@;G5L;"!I9B!T:&4@<&%R86UE=&5R"B`@("`@*B`@("`@("`@
M("`@("`@("!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971#;VYF:6=087)A;2@D<&%R86TI"B`@("!["B`@("`@("`@<F5T=7)N("AI
M<W-E="@D=&AI<RT^7V-O;F9;)'!A<F%M72DI(#\@)'1H:7,M/E]C;VYF6R1P
M87)A;5T@.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4VAO=6QD('=E
M(&9O<F-E('9I97=I;F<@;V8@=&AI<R!-24U%(%!A<G0@:6YL:6YE+"!R96=A
M<F1L97-S(&]F('1H90H@("`@("H@0V]N=&5N="U$:7-P;W-I=&EO;B!O9B!T
M:&4@34E-12!087)T/PH@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M1F]R8V4@=FEE=VEN9R!I;FQI;F4_"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O
M<F-E26YL:6YE5FEE=R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9F]R8V5I;FQI;F4["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O365S<V%G92YP:'``````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#(T,C0Q(#$P-3$U-#,T,3,W(#`R,C$W-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R]087)T+G!H
M<"<["@HO*BH*("H@5&AE($U)345?365S<V%G93HZ(&-L87-S('!R;W9I9&5S
M(&UE=&AO9',@9F]R(&-R96%T:6YG(&%N9"!M86YI<'5L871I;F<*("H@34E-
M12!E;6%I;"!M97-S86=E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-
M12]-24U%+TUE<W-A9V4N<&AP+'8@,2XW-BXQ,"XQ,B`R,#`V+S`Q+S`Q(#(Q
M.C(X.C(T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@
M,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O
M;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J
M+PIC;&%S<R!-24U%7TUE<W-A9V4@97AT96YD<R!-24U%7U!A<G0@>PH*("`@
M("\J*@H@("`@("H@2&%S('1H92!M97-S86=E(&)E96X@<&%R<V5D('9I82!B
M=6EL9$UE<W-A9V4H*3\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?8G5I;&0@/2!F86QS93L*"B`@("`O*BH*("`@("`J
M(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9"!A9&1R97-S97,@
M=&\N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?9&5F875L=%-E<G9E<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W1O<B`M(&-R96%T97,@82!N97<@34E-12!E;6%I;"!M97-S86=E+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1E9F%U;'1397)V97(@(%1H
M92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@861D<F5S<V5S('1O+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!-24U%7TUE<W-A9V4H)&1E9F%U;'1397)V97(@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1D969A=6QT4V5R=F5R
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1E9F%U;'1397)V97(@/2`D7U-%
M4E9%4ELG4T525D527TY!344G73L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7V1E9F%U;'1397)V97(@/2`D9&5F875L=%-E<G9E<CL*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!-24U%
M7TUE<W-A9V4@;V)J96-T(&9R;VT@82!-24U%7U!A<G0@;V)J96-T+@H@("`@
M("H@5&AI<R!F=6YC=&EO;B!C86X@8F4@8V%L;&5D('-T871I8V%L;'D@=FEA
M.@H@("`@("H@("`@34E-15]-97-S86=E.CIC;VYV97)T34E-15!A<G0H*3L*
M("`@("`J"B`@("`@*B!`<&%R86T@34E-15]087)T("8D;6EM95]P87)T("!4
M:&4@34E-15]087)T(&]B:F5C="X*("`@("`J($!P87)A;2!S=')I;F<@)'-E
M<G9E<B`@("`@("`@(%1H92!S97)V97(@=&\@9&5F875L="!U;G%U86QI9FEE
M9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<F5S
M<V5S('1O+@H@("`@("H*("`@("`J($!R971U<FX@34E-15]-97-S86=E("!4
M:&4@;F5W($U)345?365S<V%G92!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9C;VYV97)T34E-15!A<G0H)B1M:6UE7W!A<G0L("1S97)V97(@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("@A)&UI;65?<&%R="T^9V5T34E-14ED
M*"DI('L*("`@("`@("`@("`@)&UI;65?<&%R="T^<V5T34E-14ED*#$I.PH@
M("`@("`@('T*"B`@("`@("`@)&UI;65?;65S<V%G92`]("9N97<@34E-15]-
M97-S86=E*"1S97)V97(I.PH@("`@("`@("1M:6UE7VUE<W-A9V4M/F%D9%!A
M<G0H)&UI;65?<&%R="D["B`@("`@("`@)&UI;65?;65S<V%G92T^8G5I;&1-
M97-S86=E*"D["@H@("`@("`@(')E='5R;B`D;6EM95]M97-S86=E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5N9',@=&AI<R!M97-S86=E+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&5M86EL("`@(%1H92!A9&1R97-S(&QI
M<W0@=&\@<V5N9"!T;RX*("`@("`J($!P87)A;2!M:7AE9"`F)&AE861E<G,@
M(%1H92!-24U%7TAE861E<G,@;V)J96-T(&AO;&1I;F<@=&AI<R!M97-S86=E
M)W,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&AE861E<G,L(&]R
M(&$@:&%S:"!W:71H(&AE861E<BT^=F%L=64@;6%P<&EN9W,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D<FEV97(@("!4:&4@36%I;"!D<FEV97(@=&\@=7-E
M("AS:6YC92!(;W)D92`S+C`N-"DN"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("!!;GD@<&%R86UE=&5R<R!N96-E<W-A<GD@9F]R('1H92!-86EL
M(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@*'-I;F-E
M($AO<F1E(#,N,"XT*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4
M<G5E(&]N('-U8V-E<W,L(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E;F0H)&5M86EL+"`F)&AE861E<G,L("1D<FEV97(@
M/2!N=6QL+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B
M86P@)&-O;F8["B`@("`@("`@<W1A=&EC("1M86EL97(["@H@("`@("`@(&EF
M("@A:7-S970H)&UA:6QE<BDI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=-86EL+G!H<"<["B`@("`@("`@("`@(&EF("@A:7-S970H)&1R:79E<BDI
M('L*("`@("`@("`@("`@("`@("1D<FEV97(@/2`D8V]N9ELG;6%I;&5R)UU;
M)W1Y<&4G73L*("`@("`@("`@("`@("`@("1P87)A;7,@/2`D8V]N9ELG;6%I
M;&5R)UU;)W!A<F%M<R==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1M
M86EL97(@/2!-86EL.CIF86-T;W)Y*"1D<FEV97(L("1P87)A;7,I.PH@("`@
M("`@('T*"B`@("`@("`@)&US9R`]("1T:&ES+3YT;U-T<FEN9R@I.PH@("`@
M("`@(&EF("AI<U]O8FIE8W0H)&AE861E<G,I*2!["B`@("`@("`@("`@("1H
M96%D97)!<G)A>2`]("1T:&ES+3YE;F-O9&4H)&AE861E<G,M/G1O07)R87DH
M*2P@)'1H:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&AE861E<D%R<F%Y(#T@)'1H:7,M/F5N8V]D92@D:&5A9&5R
M<RP@)'1H:7,M/F=E=$-H87)S970H*2D["B`@("`@("`@?0H*("`@("`@("`O
M*B!-86ME('-U<F4@=&AE(&UE<W-A9V4@:&%S(&$@=')A:6QI;F<@;F5W;&EN
M92X@*B\*("`@("`@("!I9B`H<W5B<W1R*"1M<V<L("TQ*2`A/2`B7&XB*2![
M"B`@("`@("`@("`@("1M<V<@+CT@(EQN(CL*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2`D;6%I;&5R+3YS96YD*$U)344Z.F5N8V]D94%D9')E<W,H
M)&5M86EL*2P@)&AE861E<D%R<F%Y+"`D;7-G*3L*"B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2`F)@H@("`@("`@("`@("`D8V]N
M9ELG;6%I;&5R)UU;)W1Y<&4G72`]/2`G<V5N9&UA:6PG*2!["B`@("`@("`@
M("`@("\O($EN=&5R<')E="!R971U<FX@=F%L=65S(&%S(&1E9FEN960@:6X@
M+W5S<B]I;F-L=61E+W-Y<V5X:71S+F@*("`@("`@("`@("`@<W=I=&-H("@D
M<F5S=6QT+3YG971#;V1E*"DI('L*("`@("`@("`@("`@8V%S92`V-#H@+R\@
M15A?55-!1T4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(F-O;6UA;F0@;&EN92!U<V%G92!E<G)O<B(I("X@)R`H-C0I)SL*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`V-3H@
M+R\@15A?1$%404524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M
M86EL.B`G("X@7R@B9&%T82!F;W)M870@97)R;W(B*2`N("<@*#8U*2<["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-C8Z("\O
M($587TY/24Y0550*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I
M;#H@)R`N(%\H(F-A;FYO="!O<&5N(&EN<'5T(BD@+B`G("@V-BDG.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8W.B`O+R!%
M6%].3U5315(*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(F%D9')E<W-E92!U;FMN;W=N(BD@+B`G("@V-RDG.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8X.B`O+R!%6%].
M3TA/4U0*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N
M(%\H(FAO<W0@;F%M92!U;FMN;W=N(BD@+B`G("@V."DG.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#8Y.B`O+R!%6%]53D%6
M04E,04),10H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL.B`G
M("X@7R@B<V5R=FEC92!U;F%V86EL86)L92(I("X@)R`H-CDI)SL*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W,#H@+R\@15A?
M4T]&5%=!4D4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@
M)R`N(%\H(FEN=&5R;F%L('-O9G1W87)E(&5R<F]R(BD@+B`G("@W,"DG.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<Q.B`O
M+R!%6%]/4T524@H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M86EL
M.B`G("X@7R@B<WES=&5M(&5R<F]R(BD@+B`G("@W,2DG.PH@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<R.B`O+R!%6%]/4T9)
M3$4*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S96YD;6%I;#H@)R`N(%\H
M(F-R:71I8V%L('-Y<W1E;2!F:6QE(&UI<W-I;F<B*2`N("<@*#<R*2<["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@-S,Z("\O
M($587T-!3E1#4D5!5`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E;F1M
M86EL.B`G("X@7R@B8V%N;F]T(&-R96%T92!O=71P=70@9FEL92(I("X@)R`H
M-S,I)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`W-#H@+R\@15A?24]%4E(*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S
M96YD;6%I;#H@)R`N(%\H(FEN<'5T+V]U='!U="!E<G)O<B(I("X@)R`H-S0I
M)SL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`W
M-3H@+R\@15A?5$5-4$9!24P*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S
M96YD;6%I;#H@)R`N(%\H(G1E;7!O<F%R>2!F86EL=7)E(BD@+B`G("@W-2DG
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#<V
M.B`O+R!%6%]04D]43T-/3`H@("`@("`@("`@("`@("`@)&5R<F]R(#T@)W-E
M;F1M86EL.B`G("X@7R@B<F5M;W1E(&5R<F]R(&EN('!R;W1O8V]L(BD@+B`G
M("@W-BDG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(#<W.B`O+R!%6%].3U!%4DT*("`@("`@("`@("`@("`@("1E<G)O<B`]
M("=S96YD;6%I;#H@)R`N(%\H(G!E<FUI<W-I;VX@9&5N:65D(BD@+B`G("@W
M-RDG.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E
M(#<X.B`O+R!%6%]#3TY&24<*("`@("`@("`@("`@("`@("1E<G)O<B`]("=S
M96YD;6%I;#H@)R`N(%\H(F-O;F9I9W5R871I;VX@97)R;W(B*2`N("<@*#<X
M*2<["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M-SDZ("\O($587TY/5$9/54Y$"B`@("`@("`@("`@("`@("`D97)R;W(@/2`G
M<V5N9&UA:6PZ("<@+B!?*")E;G1R>2!N;W0@9F]U;F0B*2`N("<@*#<Y*2<[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("`@("`D97)R;W(@/2`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O
M<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1A:V4@82!S970@;V8@:&5A9&5R<R!A;F0@;6%K
M92!S=7)E('1H97D@87)E(&5N8V]D960@<')O<&5R;'DN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1H96%D97)S("`@5&AE(&AE861E<G,@=&\@96YC
M;V1E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)A
M8W1E<B!S970@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!A<G)A>2!O9B!E;F-O9&5D(&AE861E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5N8V]D92@D:&5A9&5R<RP@)&-H87)S970I"B`@("!["B`@("`@
M("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+G!H<"<["@H@("`@("`@("1A
M9&1R97-S2V5Y<R`](&%R<F%Y*"=4;R<L("=#8R<L("="8V,G+"`G1G)O;2<I
M.PH@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&ME>2P@)&%D9')E<W-+97ES
M*2D@>PH@("`@("`@("`@("`@("`@)'1E>'0@/2!-24U%.CIE;F-O9&5!9&1R
M97-S*"1V86PL("1C:&%R<V5T+"`D=&AI<RT^7V1E9F%U;'1397)V97(I.PH@
M("`@("`@("`@("`@("`@:68@*&ES7V$H)'1E>'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("`@("`D=&5X="`]("1V86P["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=&5X="`]($U)344Z.F5N8V]D92@D=F%L+"`D8VAA<G-E="D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&AE861E<G-;)&ME>5T@/2!-24U%.CIW
M<F%P2&5A9&5R<R@D:V5Y+"`D=&5X="P@)'1H:7,M/F=E=$5/3"@I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D:&5A9&5R<SL*("`@('T*"B`@("`O
M*BH*("`@("`J($%D9"!T:&4@<')O<&5R('-E="!O9B!-24U%(&AE861E<G,@
M9F]R('1H:7,@;65S<V%G92!T;R!A;B!A<G)A>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&AE861E<G,@(%1H92!H96%D97)S('1O(&%D9"!T:&4@
M34E-12!H96%D97)S('1O+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(%1H92!F=6QL('-E="!O9B!H96%D97)S(&EN8VQU9&EN9R!-24U%(&AE861E
M<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AE861E<B@D:&5A9&5R<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@+RH@4&5R(%)&0R`R,#0U(%LT72P@=&AI
M<R!-55-4(&%P<&5A<B!I;B!T:&4@;65S<V%G92!H96%D97)S+B`J+PH@("`@
M("`@("1H96%D97)S6R=-24U%+59E<G-I;VXG72`]("<Q+C`G.PH*("`@("`@
M("!I9B`H)'1H:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R
M96YT.CIH96%D97(H)&AE861E<G,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YE;F-O9&4H)'1H:7,M/FAE861E<B@D:&5A9&5R<RDL("1T
M:&ES+3YG971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!T:&4@96YT:7)E(&UE<W-A9V4@8V]N=&5N=',L(&EN
M8VQU9&EN9R!H96%D97)S+"!A<R!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960L(&=E;F5R871E9"!M97-S86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@("`@
M("`@:68@*"1T:&ES+3Y?8G5I;&0I('L*("`@("`@("`@("`@<F5T=7)N('!A
M<F5N=#HZ=&]3=')I;F<H9F%L<V4I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YB=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YT;U-T<FEN9R@I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($)U:6QD(&UE<W-A9V4@9G)O;2!C=7)R96YT(&-O;G1E;G1S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL9$UE<W-A9V4H*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7V)U:6QD*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V9L86=S
M6R=S9714>7!E)UTI*2!["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^
M7W!A<G1S*2`^(#$I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS9714>7!E
M*"=M=6QT:7!A<G0O;6EX960G*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("\J($-O<'D@=&AE(&EN9F]R;6%T:6]N(&9R;VT@=&AE
M('-I;F=L92!P87)T('1O('1H92!C=7)R96YT"B`@("`@("`@("`@("`@("`@
M("!B87-E('!A<G0N("HO"B`@("`@("`@("`@("`@("!I9B`H*"1O8E9A<G,@
M/2!G971?;V)J96-T7W9A<G,H<F5S970H)'1H:7,M/E]P87)T<RDI*2D@>PH@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O8E9A<G,@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3XD:V5Y
M(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T
M:&4@8G5I;&0@9FQA9R!N;W<N("HO"B`@("`@("`@)'1H:7,M/E]B=6EL9"`]
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&%L
M;"!-24U%('-U8G!A<G1S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($%N(&%R<F%Y(&]F('1H92!-24U%7U!A<G0@<W5B<&%R=',N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!A<G1S*"D*("`@('L*("`@("`@("!I9B`H)'1H
M:7,M/E]B=6EL9"D@>PH@("`@("`@("`@("!R971U<FX@<&%R96YT.CIG9710
M87)T<R@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YB
M=6EL9$UE<W-A9V4H*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG9710
M87)T<R@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;B!T:&4@8F%S92!P87)T(&]F('1H92!M97-S86=E+B!4:&ES(&9U;F-T:6]N
M(&1O97,@3D]4"B`@("`@*B!R971U<FX@82!R969E<F5N8V4@=&\@;6%K92!S
M=7)E('1H870@=&AE('=H;VQE($U)345?365S<V%G90H@("`@("H@;V)J96-T
M(&ES;B=T(&%C8VED96YT86QL>2!M;V1I9FEE9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N($U)345?365S<V%G92`@5&AE(&)A<V4@34E-15]087)T(&]F('1H
M92!M97-S86=E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971"87-E4&%R="@I
M"B`@("!["B`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G92@I.PH@("`@("`@
M(')E='5R;B`D=&AI<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E
M(&$@<W!E8VEF:6,@34E-12!P87)T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&ED("!4:&4@34E-15]087)T($E$('-T<FEN9RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N($U)345?4&%R="`@5&AE($U)345?4&%R="!R97%U97-T
M960L(&]R(&9A;'-E(&EF('1H92!P87)T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E
M=%!A<G0H)&ED*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V)U:6QD*2![
M"B`@("`@("`@("`@("1P87)T(#T@<&%R96YT.CIG971087)T*"1I9"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F)U:6QD365S<V%G
M92@I.PH@("`@("`@("`@("`D<&%R="`]("1T:&ES+3YG971087)T*"1I9"D[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1P87)T+"`G34E-15]-97-S
M86=E)RDI('L*("`@("`@("`@("`@)&YE=W!A<G0@/2`F;F5W($U)345?4&%R
M="@I.PH@("`@("`@("`@("`D<VMI<"`](&%R<F%Y*"=?8G5I;&0G+"`G7V1E
M9F%U;'1397)V97(G*3L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y
M<RAG971?;V)J96-T7W9A<G,H)'!A<G0I*2!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("`O*B!)9VYO<F4@;&]C86P@=F%R:6%B;&5S('1H870@87)E;B=T
M(&$@<&%R="!O9B!T:&4@;W)I9VEN86P*("`@("`@("`@("`@("`@("`J(&-L
M87-S+B`J+PH@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D:V5Y+"`D
M<VMI<"DI('L*("`@("`@("`@("`@("`@("`@("`D;F5W<&%R="T^)&ME>2`]
M("8D<&%R="T^)&ME>3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!R971U<FX@)&YE=W!A<G0["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N("1P87)T.PH@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]M:6UE+FUA<'!I;F<N
M<&AP````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-3,S-#`@,3`U,34T
M,S0Q,S<@,#(S,3<S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@82!M
M87!P:6YG(&]F(&-O;6UO;B!F:6QE(&5X=&5N<VEO;G,@=&\*("H@34E-12!T
M>7!E<RX@270@:&%S(&)E96X@875T;VUA=&EC86QL>2!G96YE<F%T960@9G)O
M;2!T:&4*("H@:&]R9&4O<V-R:7!T<R]M:6UE7VUA<'!I;F<@9&ER96-T;W)Y
M+@H@*@H@*B!!3$P@8VAA;F=E<R!S:&]U;&0@8F4@;6%D92!T;R!H;W)D92]S
M8W)I<'1S+VUI;65?;6%P<&EN9R]M:6UE+G1Y<&5S+FAO<F1E"B`J(&]R(&5L
M<V4@=&AE>2!W:6QL(&)E(&QO<W0@=VAE;B!T:&ES(&9I;&4@:7,@<F5G96YE
M<F%T960N"B`J"B`J($%N>2!U;FMN;W=N(&9I;&4@97AT96YS:6]N<R!W:6QL
M(&%U=&]M871I8V%L;'D@8F4@;6%P<&5D('1O"B`J("=X+65X=&5N<VEO;B\\
M97AT/B<@=VAE<F4@/&5X=#X@:7,@=&AE('5N:VYO=VX@9FEL92!E>'1E;G-I
M;VXN"B`J"B`J($!P86-K86=E($AO<F1E7TU)344*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO34E-12]-24U%+VUI;64N;6%P<&EN9RYP:'`L=B`Q+C$Q+C(N
M,R`R,#`V+S`R+S$P(#$P.C,W.C,S(&IA;B!%>'`@)`H@*@H@*B!'96YE<F%T
M960Z(#`R+S$P+S`V(#`P.C$X.C0U(&)Y('-L=7-A<GH@;VX@8FEG=V]R;2YC
M=7)E8V%N=&DN;W)G"B`J+PHD;6EM95]E>'1E;G-I;VY?;6%P(#T@87)R87DH
M"B=?7TU!6%!%4DE/1%]?)R`]/B`G,2<L"B`@("`G,V1S)R`@("`@("`@("`@
M/3X@)VEM86=E+W@M,V1S)RP*("`@("="3$5.1"<@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UB;&5N9&5R)RP*("`@("=#)R`@("`@("`@("`@("`]/B`G
M=&5X="]X+6,K*W-R8R<L"B`@("`G0U-33"<@("`@("`@("`@/3X@)W1E>'0O
M8W-S)RP*("`@("=.4U8G("`@("`@("`@("`]/B`G=FED96\O>"UN<W8G+`H@
M("`@)U!!4C(G("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!A<C(G+`H@
M("`@)UA-)R`@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G6B<@
M("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M8V]M<')E<W,G+`H@("`@
M)V$G("`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%R8VAI=F4G+`H@
M("`@)V%B=R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%B:7=O<F0G
M+`H@("`@)V%B=RY#4D%32$5$)R`@(#T^("=A<'!L:6-A=&EO;B]X+6%B:7=O
M<F0G+`H@("`@)V%B=RYG>B<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6%B
M:7=O<F0G+`H@("`@)V%C,R<@("`@("`@("`@(#T^("=A=61I;R]A8S,G+`H@
M("`@)V%D8B<@("`@("`@("`@(#T^("=T97AT+W@M861A<W)C)RP*("`@("=A
M9',G("`@("`@("`@("`]/B`G=&5X="]X+6%D87-R8R<L"B`@("`G869M)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UA9FTG+`H@("`@)V%G
M)R`@("`@("`@("`@(#T^("=I;6%G92]X+6%P<&QI>"UG<F%P:&EC<R<L"B`@
M("`G86DG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+VEL;'5S=')A=&]R
M)RP*("`@("=A:68G("`@("`@("`@("`]/B`G875D:6\O>"UA:69F)RP*("`@
M("=A:69C)R`@("`@("`@("`]/B`G875D:6\O>"UA:69F)RP*("`@("=A:69F
M)R`@("`@("`@("`]/B`G875D:6\O>"UA:69F)RP*("`@("=A;"<@("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UP97)L)RP*("`@("=A<FHG("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UA<FHG+`H@("`@)V%S)R`@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6%P<&QI>"US<')E861S:&5E="<L"B`@
M("`G87-C)R`@("`@("`@("`@/3X@)W1E>'0O<&QA:6XG+`H@("`@)V%S9B<@
M("`@("`@("`@(#T^("=V:61E;R]X+6US+6%S9B<L"B`@("`G87-P)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M87-P)RP*("`@("=A<W@G("`@("`@
M("`@("`]/B`G=FED96\O>"UM<RUA<V8G+`H@("`@)V%T;VTG("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]A=&]M*WAM;"<L"B`@("`G874G("`@("`@("`@
M("`@/3X@)V%U9&EO+V)A<VEC)RP*("`@("=A=FDG("`@("`@("`@("`]/B`G
M=FED96\O>"UM<W9I9&5O)RP*("`@("=A=R<@("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UA<'!L:7@M=V]R9"<L"B`@("`G8F%K)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M=')A<V@G+`H@("`@)V)C<&EO)R`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+6)C<&EO)RP*("`@("=B9&8G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UF;VYT+6)D9B<L"B`@("`G8FEB)R`@("`@
M("`@("`@/3X@)W1E>'0O>"UB:6)T97@G+`H@("`@)V)I;B<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@)V)L96YD)R`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)L96YD97(G+`H@("`@)V)L96YD
M97(G("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)L96YD97(G+`H@("`@)V)M
M<"<@("`@("`@("`@(#T^("=I;6%G92]B;7`G+`H@("`@)V)Z)R`@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`G+`H@("`@)V)Z,B<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`G+`H@("`@)V,G("`@("`@("`@
M("`@(#T^("=T97AT+W@M8W-R8R<L"B`@("`G8RLK)R`@("`@("`@("`@/3X@
M)W1E>'0O>"UC*RMS<F,G+`H@("`@)V-C)R`@("`@("`@("`@(#T^("=T97AT
M+W@M8RLK<W)C)RP*("`@("=C9&8G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UN971C9&8G+`H@("`@)V-D<B<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]V;F0N8V]R96PM9')A=R<L"B`@("`G8V5R)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W@M>#4P.2UC82UC97)T)RP*("`@("=C97)T)R`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO>"UX-3`Y+6-A+6-E<G0G+`H@("`@)V-G
M:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6-G:2<L"B`@("`G8V=M
M)R`@("`@("`@("`@/3X@)VEM86=E+V-G;2<L"B`@("`G8VAM)R`@("`@("`@
M("`@/3X@)V%P<&QI8V%T:6]N+W@M8VAM)RP*("`@("=C:')T)R`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK8VAA<G0G+`H@("`@)V-L87-S)R`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA=F$G+`H@("`@)V-L<R<@("`@("`@
M("`@(#T^("=T97AT+W@M=&5X)RP*("`@("=C<&EO)R`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UC<&EO)RP*("`@("=C<&EO+F=Z)R`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UC<&EO+6-O;7!R97-S960G+`H@("`@)V-P<"<@("`@
M("`@("`@(#T^("=T97AT+W@M8RLK<W)C)RP*("`@("=C<'0G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO;6%C+6-O;7!A8W1P<F\G+`H@("`@)V-R="<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7@U,#DM8V$M8V5R="<L"B`@
M("`G8W,G("`@("`@("`@("`@/3X@)W1E>'0O>"UC<VAA<G`G+`H@("`@)V-S
M:"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6-S:"<L"B`@("`G8W-S
M)R`@("`@("`@("`@/3X@)W1E>'0O8W-S)RP*("`@("=C<W8G("`@("`@("`@
M("`]/B`G=&5X="]X+6-O;6UA+7-E<&%R871E9"UV86QU97,G+`H@("`@)V-U
M<B<@("`@("`@("`@(#T^("=I;6%G92]X+7=I;BUB:71M87`G+`H@("`@)V-X
M>"<@("`@("`@("`@(#T^("=T97AT+W@M8RLK<W)C)RP*("`@("=D)R`@("`@
M("`@("`@("`]/B`G=&5X="]X+61S<F,G+`H@("`@)V1A="<@("`@("`@("`@
M(#T^("=V:61E;R]M<&5G)RP*("`@("=D8F8G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UD8F%S92<L"B`@("`G9&,G("`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M9&,M<F]M)RP*("`@("=D8VPG("`@("`@("`@("`]/B`G
M=&5X="]X+61C;"<L"B`@("`G9&-M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+V1I8V]M)RP*("`@("=D8W(G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UD:7)E8W1O<B<L"B`@("`G9&5B)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9&5B)RP*("`@("=D97(G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UX-3`Y+6-A+6-E<G0G+`H@("`@)V1E<VMT;W`G("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+61E<VMT;W`G+`H@("`@)V1I82<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+61I82UD:6%G<F%M)RP*("`@("=D:69F)R`@
M("`@("`@("`]/B`G=&5X="]X+7!A=&-H)RP*("`@("=D:7(G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UD:7)E8W1O<B<L"B`@("`G9&IV)R`@("`@
M("`@("`@/3X@)VEM86=E+W9N9"YD:G9U)RP*("`@("=D:G9U)R`@("`@("`@
M("`]/B`G:6UA9V4O=FYD+F1J=G4G+`H@("`@)V1L;"<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@)V1M9R<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@)V1M<R<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]O8W1E="US=')E86TG+`H@("`@
M)V1O8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]M<W=O<F0G+`H@("`@
M)V1S;"<@("`@("`@("`@(#T^("=T97AT+W@M9'-L)RP*("`@("=D=&0G("`@
M("`@("`@("`]/B`G=&5X="]X+61T9"<L"B`@("`G9'9I)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9'9I)RP*("`@("=D=V<G("`@("`@("`@("`]
M/B`G:6UA9V4O=FYD+F1W9R<L"B`@("`G9'AF)R`@("`@("`@("`@/3X@)VEM
M86=E+W9N9"YD>&8G+`H@("`@)V1X<B<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+61I<F5C=&]R)RP*("`@("=E9V]N)R`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UE9V]N)RP*("`@("=E;"<@("`@("`@("`@("`]/B`G=&5X
M="]X+65M86-S+6QI<W`G+`H@("`@)V5P<R<@("`@("`@("`@(#T^("=I;6%G
M92]X+65P<R<L"B`@("`G97!S9B<@("`@("`@("`@/3X@)VEM86=E+W@M97!S
M)RP*("`@("=E<'-I)R`@("`@("`@("`]/B`G:6UA9V4O>"UE<',G+`H@("`@
M)V5T:&5M92<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+64M=&AE;64G+`H@
M("`@)V5T>"<@("`@("`@("`@(#T^("=T97AT+W@M<V5T97AT)RP*("`@("=E
M>&4G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UM<RUD;W,M97AE8W5T
M86)L92<L"B`@("`G97HG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V%N
M9')E=RUI;G-E="<L"B`@("`G9B<@("`@("`@("`@("`@/3X@)W1E>'0O>"UF
M;W)T<F%N)RP*("`@("=F:6<G("`@("`@("`@("`]/B`G:6UA9V4O>"UX9FEG
M)RP*("`@("=F:71S)R`@("`@("`@("`]/B`G:6UA9V4O>"UF:71S)RP*("`@
M("=F;&%C)R`@("`@("`@("`]/B`G875D:6\O>"UF;&%C)RP*("`@("=F;&,G
M("`@("`@("`@("`]/B`G=FED96\O>"UF;&EC)RP*("`@("=F;&DG("`@("`@
M("`@("`]/B`G=FED96\O>"UF;&EC)RP*("`@("=F;'<G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO>"UK:79I;R<L"B`@("`G9F\G("`@("`@("`@("`@
M/3X@)W1E>'0O>"UX<VQF;R<L"B`@("`G9S,G("`@("`@("`@("`@/3X@)VEM
M86=E+V9A>"UG,R<L"B`@("`G9V(G("`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M9V%M96)O>2UR;VTG+`H@("`@)V=C<F0G("`@("`@("`@(#T^("=T
M97AT+V1I<F5C=&]R>2<L"B`@("`G9V5N)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9V5N97-I<RUR;VTG+`H@("`@)V=G)R`@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+7-M<RUR;VTG+`H@("`@)V=I9B<@("`@("`@("`@
M(#T^("=I;6%G92]G:68G+`H@("`@)V=L861E)R`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6=L861E)RP*("`@("=G;6\G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UG971T97AT+71R86YS;&%T:6]N)RP*("`@("=G;F,G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UG;G5C87-H)RP*("`@("=G;G5C
M87-H)R`@("`@("`]/B`G87!P;&EC871I;VXO>"UG;G5C87-H)RP*("`@("=G
M;G5M97)I8R<@("`@("`]/B`G87!P;&EC871I;VXO>"UG;G5M97)I8R<L"B`@
M("`G9W)A)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9W)A<&AI=&4G
M+`H@("`@)V=R86TG("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]S<F=S)RP*
M("`@("=G<GAM;"<@("`@("`@("`]/B`G87!P;&EC871I;VXO<W)G<RMX;6PG
M+`H@("`@)V=S9B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+69O;G0M
M='EP93$G+`H@("`@)V=S;2<@("`@("`@("`@(#T^("=A=61I;R]X+6=S;2<L
M"B`@("`G9W1A<B<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9W1A<B<L
M"B`@("`G9WHG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9WII<"<L
M"B`@("`G:"<@("`@("`@("`@("`@/3X@)W1E>'0O>"UC:&1R)RP*("`@("=H
M*RLG("`@("`@("`@("`]/B`G=&5X="]X+6-H9'(G+`H@("`@)VAD9B<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6AD9B<L"B`@("`G:&@G("`@("`@
M("`@("`@/3X@)W1E>'0O>"UC*RMH9'(G+`H@("`@)VAP)R`@("`@("`@("`@
M(#T^("=T97AT+W@M8VAD<B<L"B`@("`G:'!G;"<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W9N9"YH<"UH<&=L)RP*("`@("=H<7@G("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO;6%C+6)I;FAE>#0P)RP*("`@("=H<R<@("`@("`@
M("`@("`]/B`G=&5X="]X+6AA<VME;&PG+`H@("`@)VAT;2<@("`@("`@("`@
M(#T^("=T97AT+VAT;6PG+`H@("`@)VAT;6PG("`@("`@("`@(#T^("=T97AT
M+VAT;6PG+`H@("`@)VEC8B<@("`@("`@("`@(#T^("=I;6%G92]X+6EC8B<L
M"B`@("`G:6-E)R`@("`@("`@("`@/3X@)W@M8V]N9F5R96YC92]X+6-O;VQT
M86QK)RP*("`@("=I8V\G("`@("`@("`@("`]/B`G:6UA9V4O>"UI8V\G+`H@
M("`@)VEC<R<@("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R)RP*("`@("=I
M9&PG("`@("`@("`@("`]/B`G=&5X="]X+6ED;"<L"B`@("`G:65F)R`@("`@
M("`@("`@/3X@)VEM86=E+VEE9B<L"B`@("`G:69B)R`@("`@("`@("`@/3X@
M)W1E>'0O8V%L96YD87(G+`H@("`@)VEF9B<@("`@("`@("`@(#T^("=I;6%G
M92]X+6EF9B<L"B`@("`G:6=E<R<@("`@("`@("`@/3X@)VUO9&5L+VEG97,G
M+`H@("`@)VEG<R<@("`@("`@("`@(#T^("=M;V1E;"]I9V5S)RP*("`@("=I
M;&)M)R`@("`@("`@("`]/B`G:6UA9V4O>"UI;&)M)RP*("`@("=I<V\G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UC9"UI;6%G92<L"B`@("`G:70G
M("`@("`@("`@("`@/3X@)V%U9&EO+W@M:70G+`H@("`@)VIA<B<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6IA<B<L"B`@("`G:F%V82<@("`@("`@
M("`@/3X@)W1E>'0O>"UJ879A)RP*("`@("=J;F<G("`@("`@("`@("`]/B`G
M:6UA9V4O>"UJ;F<G+`H@("`@)VIN;'`G("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6IA=F$M:FYL<"UF:6QE)RP*("`@("=J<#(G("`@("`@("`@("`]
M/B`G:6UA9V4O:G!E9S(P,#`G+`H@("`@)VIP9R<@("`@("`@("`@(#T^("=I
M;6%G92]J<&5G)RP*("`@("=J<&4G("`@("`@("`@("`]/B`G:6UA9V4O:G!E
M9R<L"B`@("`G:G!E9R<@("`@("`@("`@/3X@)VEM86=E+VIP96<G+`H@("`@
M)VIP<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6IB=6EL9&5R+7!R
M;VIE8W0G+`H@("`@)VIP>"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6IB=6EL9&5R+7!R;VIE8W0G+`H@("`@)VIS)R`@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0G+`H@("`@)VMA<B<@("`@("`@("`@
M(#T^("=A=61I;R]M:61I)RP*("`@("=K87)B;VXG("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UK87)B;VXG+`H@("`@)VMD96QN:R<@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+61E<VMT;W`G+`H@("`@)VMF;R<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+6MF;W)M=6QA)RP*("`@("=K:6PG("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO>"UK:6QL=7-T<F%T;W(G+`H@("`@)VMO;B<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO;G1O=7(G+`H@("`@)VMP
M;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MP;W9M;V1E;&5R)RP*
M("`@("=K<'(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK<')E<V5N
M=&5R)RP*("`@("=K<'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UK
M<')E<V5N=&5R)RP*("`@("=K<F$G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UK<FET82<L"B`@("`G:W-P)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M:W-P<F5A9"<L"B`@("`G:W5D)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M:W5G87(G+`H@("`@)VMW9"<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+6MW;W)D)RP*("`@("=K=W0G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UK=V]R9"<L"B`@("`G;&$G("`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M<VAA<F5D+6QI8G)A<GDM;&$G+`H@("`@)VQA=&5X)R`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QA=&5X)RP*("`@("=L:&$G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UL:&$G+`H@("`@)VQH<R<@("`@
M("`@("`@(#T^("=T97AT+W@M;&ET97)A=&4M:&%S:V5L;"<L"B`@("`G;&AZ
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;&AZ)RP*("`@("=L;V<G
M("`@("`@("`@("`]/B`G=&5X="]X+6QO9R<L"B`@("`G;'1X)R`@("`@("`@
M("`@/3X@)W1E>'0O>"UT97@G+`H@("`@)VQW;R<@("`@("`@("`@(#T^("=I
M;6%G92]X+6QW;R<L"B`@("`G;'=O8B<@("`@("`@("`@/3X@)VEM86=E+W@M
M;'=O)RP*("`@("=L=W,G("`@("`@("`@("`]/B`G:6UA9V4O>"UL=W,G+`H@
M("`@)VQY>"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6QY>"<L"B`@
M("`G;'IH)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;&AA)RP*("`@
M("=L>F\G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UL>F]P)RP*("`@
M("=M)R`@("`@("`@("`@("`]/B`G=&5X="]X+6]B:F-S<F,G+`H@("`@)VTQ
M-2<@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G;3-U)R`@("`@
M("`@("`@/3X@)V%U9&EO+W@M;7!E9W5R;"<L"B`@("`G;31A)R`@("`@("`@
M("`@/3X@)V%U9&EO+W@M;31A)RP*("`@("=M-'4G("`@("`@("`@("`]/B`G
M=FED96\O=FYD+FUP96=U<FPG+`H@("`@)VUA;B<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+71R;V9F+6UA;B<L"B`@("`G;6%T:&UL)R`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+VUA=&AM;"MX;6PG+`H@("`@)VUD)R`@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6=E;F5S:7,M<F]M)RP*("`@("=M92<@
M("`@("`@("`@("`]/B`G=&5X="]X+71R;V9F+6UE)RP*("`@("=M97-H)R`@
M("`@("`@("`]/B`G;6]D96PO;65S:"<L"B`@("`G;6=P)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M;6%G:6-P;VEN="<L"B`@("`G;6ED)R`@("`@
M("`@("`@/3X@)V%U9&EO+VUI9&DG+`H@("`@)VUI9&DG("`@("`@("`@(#T^
M("=A=61I;R]M:61I)RP*("`@("=M:68G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UM:68G+`H@("`@)VUK=B<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6UA=')O<VMA)RP*("`@("=M;2<@("`@("`@("`@("`]/B`G=&5X
M="]X+71R;V9F+6UM)RP*("`@("=M;6PG("`@("`@("`@("`]/B`G=&5X="]M
M871H;6PG+`H@("`@)VUN9R<@("`@("`@("`@(#T^("=V:61E;R]X+6UN9R<L
M"B`@("`G;6]C)R`@("`@("`@("`@/3X@)W1E>'0O>"UM;V,G+`H@("`@)VUO
M9"<@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G;6]O=B<@("`@
M("`@("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L"B`@("`G;6]V)R`@("`@("`@
M("`@/3X@)W9I9&5O+W%U:6-K=&EM92<L"B`@("`G;6]V:64G("`@("`@("`@
M/3X@)W9I9&5O+W@M<V=I+6UO=FEE)RP*("`@("=M<#(G("`@("`@("`@("`]
M/B`G=FED96\O;7!E9R<L"B`@("`G;7`S)R`@("`@("`@("`@/3X@)V%U9&EO
M+VUP96<G+`H@("`@)VUP92<@("`@("`@("`@(#T^("=V:61E;R]M<&5G)RP*
M("`@("=M<&5G)R`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G;7!G
M)R`@("`@("`@("`@/3X@)W9I9&5O+VUP96<G+`H@("`@)VUP9V$G("`@("`@
M("`@(#T^("=A=61I;R]M<&5G)RP*("`@("=M<R<@("`@("`@("`@("`]/B`G
M=&5X="]X+71R;V9F+6US)RP*("`@("=M<V@G("`@("`@("`@("`]/B`G;6]D
M96PO;65S:"<L"B`@("`G;7-O9"<@("`@("`@("`@/3X@)VEM86=E+W@M;7-O
M9"<L"B`@("`G;7-X)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;7-X
M+7)O;2<L"B`@("`G;71M)R`@("`@("`@("`@/3X@)V%U9&EO+W@M;6]D)RP*
M("`@("=M>'4G("`@("`@("`@("`]/B`G=FED96\O=FYD+FUP96=U<FPG+`H@
M("`@)VXV-"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6XV-"UR;VTG
M+`H@("`@)VYB)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]M871H96UA
M=&EC82<L"B`@("`G;F,G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M;F5T8V1F)RP*("`@("=N97,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UN97,M<F]M)RP*("`@("=N<W8G("`@("`@("`@("`]/B`G=FED96\O>"UN
M<W8G+`H@("`@)V\G("`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6]B
M:F5C="<L"B`@("`G;V)J)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M=&=I9B<L"B`@("`G;V1A)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+V]D
M82<L"B`@("`G;V1B)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO
M87-I<RYO<&5N9&]C=6UE;G0N9&%T86)A<V4G+`H@("`@)V]D8R<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+F-H
M87)T)RP*("`@("=O9&8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+F]A<VES+F]P96YD;V-U;65N="YF;W)M=6QA)RP*("`@("=O9&<G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YG
M<F%P:&EC<R<L"B`@("`G;V1I)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N:6UA9V4G+`H@("`@)V]D;2<@("`@
M("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT
M+G1E>'0M;6%S=&5R)RP*("`@("=O9'`G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YP<F5S96YT871I;VXG+`H@
M("`@)V]D<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N
M;W!E;F1O8W5M96YT+G-P<F5A9'-H965T)RP*("`@("=O9'0G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YT97AT
M)RP*("`@("=O9V<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO;V=G)RP*
M("`@("=O;&0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F%S:"<L
M"B`@("`G;VQE;R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;VQE;R<L
M"B`@("`G;V]T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YO87-I
M<RYO<&5N9&]C=6UE;G0N=&5X="<L"B`@("`G;W1G)R`@("`@("`@("`@/3X@
M)V%P<&QI8V%T:6]N+W9N9"YO87-I<RYO<&5N9&]C=6UE;G0N9W)A<&AI8W,M
M=&5M<&QA=&4G+`H@("`@)V]T:"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+G1E>'0M=V5B)RP*("`@("=O='`G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U
M;65N="YP<F5S96YT871I;VXM=&5M<&QA=&4G+`H@("`@)V]T<R<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;V%S:7,N;W!E;F1O8W5M96YT+G-P
M<F5A9'-H965T+71E;7!L871E)RP*("`@("=O='0G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO=FYD+F]A<VES+F]P96YD;V-U;65N="YT97AT+71E;7!L
M871E)RP*("`@("=P)R`@("`@("`@("`@("`]/B`G=&5X="]X+7!A<V-A;"<L
M"B`@("`G<#$R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&MC<S$R
M)RP*("`@("=P-W,G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO<&MC<S<M
M<VEG;F%T=7)E)RP*("`@("=P87(R)R`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UP87(R)RP*("`@("=P87,G("`@("`@("`@("`]/B`G=&5X="]X+7!A
M<V-A;"<L"B`@("`G<&%T8V@G("`@("`@("`@/3X@)W1E>'0O>"UP871C:"<L
M"B`@("`G<&)M)R`@("`@("`@("`@/3X@)VEM86=E+W@M<&]R=&%B;&4M8FET
M;6%P)RP*("`@("=P8V0G("`@("`@("`@("`]/B`G:6UA9V4O>"UP:&]T;RUC
M9"<L"B`@("`G<&-F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N
M="UP8V8G+`H@("`@)W!C9BY:)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+69O;G0M='EP93$G+`H@("`@)W!C;"<@("`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]V;F0N:'`M<&-L)RP*("`@("=P9&(G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO=FYD+G!A;&TG+`H@("`@)W!D9B<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]P9&8G+`H@("`@)W!E;2<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+7@U,#DM8V$M8V5R="<L"B`@("`G<&5R;"<@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M<&5R;"<L"B`@("`G<&9A)R`@("`@("`@("`@
M/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UT>7!E,2<L"B`@("`G<&9B)R`@("`@
M("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UT>7!E,2<L"B`@("`G<&9X
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&MC<S$R)RP*("`@("=P
M9VTG("`@("`@("`@("`]/B`G:6UA9V4O>"UP;W)T86)L92UG<F%Y;6%P)RP*
M("`@("=P9VXG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UC:&5S<RUP
M9VXG+`H@("`@)W!G<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P9W`G
M+`H@("`@)W!H<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!H<"<L
M"B`@("`G<&AP,R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<&AP)RP*
M("`@("=P:'`T)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP:'`G+`H@
M("`@)W!I8W0G("`@("`@("`@(#T^("=I;6%G92]X+7!I8W0G+`H@("`@)W!I
M8W0Q)R`@("`@("`@(#T^("=I;6%G92]X+7!I8W0G+`H@("`@)W!I8W0R)R`@
M("`@("`@(#T^("=I;6%G92]X+7!I8W0G+`H@("`@)W!L)R`@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]X+7!E<FPG+`H@("`@)W!L<R<@("`@("`@("`@
M(#T^("=A=61I;R]X+7-C<&QS)RP*("`@("=P;2<@("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>"UP97)L)RP*("`@("=P;F<G("`@("`@("`@("`]/B`G
M:6UA9V4O<&YG)RP*("`@("=P;FTG("`@("`@("`@("`]/B`G:6UA9V4O>"UP
M;W)T86)L92UA;GEM87`G+`H@("`@)W!O)R`@("`@("`@("`@(#T^("=T97AT
M+W@M9V5T=&5X="UT<F%N<VQA=&EO;B<L"B`@("`G<&]T)R`@("`@("`@("`@
M/3X@)W1E>'0O>"UG971T97AT+71R86YS;&%T:6]N+71E;7!L871E)RP*("`@
M("=P<&TG("`@("`@("`@("`]/B`G:6UA9V4O>"UP;W)T86)L92UP:7AM87`G
M+`H@("`@)W!P<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;7,M
M<&]W97)P;VEN="<L"B`@("`G<'!T)R`@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YM<RUP;W=E<G!O:6YT)RP*("`@("=P<'HG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+FUS+7!O=V5R<&]I;G0G+`H@("`@)W!S)R`@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]P;W-T<V-R:7!T)RP*("`@("=P
M<RYG>B<@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UG>G!O<W1S8W)I<'0G
M+`H@("`@)W!S9"<@("`@("`@("`@(#T^("=I;6%G92]X+7!S9"<L"B`@("`G
M<'-F)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M9F]N="UL:6YU>"UP
M<V8G+`H@("`@)W!S:60G("`@("`@("`@(#T^("=A=61I;R]P<G,N<VED)RP*
M("`@("=P=R<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UP=R<L"B`@
M("`G<'DG("`@("`@("`@("`@/3X@)W1E>'0O>"UP>71H;VXG+`H@("`@)W!Y
M8R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+7!Y=&AO;BUB>71E8V]D
M92<L"B`@("`G<'EO)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<'ET
M:&]N+6)Y=&5C;V1E)RP*("`@("=Q:68G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"UQ=R<L"B`@("`G<70G("`@("`@("`@("`@/3X@)W9I9&5O+W%U
M:6-K=&EM92<L"B`@("`G<71V<B<@("`@("`@("`@/3X@)W9I9&5O+W%U:6-K
M=&EM92<L"B`@("`G<F$G("`@("`@("`@("`@/3X@)V%U9&EO+W@M<&XM<F5A
M;&%U9&EO)RP*("`@("=R86TG("`@("`@("`@("`]/B`G875D:6\O>"UP;BUR
M96%L875D:6\G+`H@("`@)W)A<B<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+7)A<B<L"B`@("`G<F%S)R`@("`@("`@("`@/3X@)VEM86=E+W@M8VUU
M+7)A<W1E<B<L"B`@("`G<F1F)R`@("`@("`@("`@/3X@)W1E>'0O<F1F)RP*
M("`@("=R96HG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UR96IE8W0G
M+`H@("`@)W)G8B<@("`@("`@("`@(#T^("=I;6%G92]X+7)G8B<L"B`@("`G
M<FQE)R`@("`@("`@("`@/3X@)VEM86=E+W)L92<L"B`@("`G<FTG("`@("`@
M("`@("`@/3X@)V%U9&EO+W@M<&XM<F5A;&%U9&EO)RP*("`@("=R;V9F)R`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F]F9B<L"B`@("`G<G!M)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<G!M)RP*("`@("=R<W,G("`@
M("`@("`@("`]/B`G=&5X="]R<W,G+`H@("`@)W)T9B<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]R=&8G+`H@("`@)W)T>"<@("`@("`@("`@(#T^("=T
M97AT+W)I8VAT97AT)RP*("`@("=S,VTG("`@("`@("`@("`]/B`G875D:6\O
M>"US,VTG+`H@("`@)W-A;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+6%M:7!R;R<L"B`@("`G<V-M)R`@("`@("`@("`@/3X@)W1E>'0O>"US8VAE
M;64G+`H@("`@)W-D82<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N
M<W1A<F1I=FES:6]N+F1R87<G+`H@("`@)W-D8R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F-A;&,G+`H@("`@)W-D9"<@
M("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+FEM
M<')E<W,G+`H@("`@)W-D<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N<W1A<F1I=FES:6]N+FEM<')E<W,G+`H@("`@)W-D<R<@("`@("`@("`@
M(#T^("=A<'!L:6-A=&EO;B]V;F0N<W1A<F1I=FES:6]N+F-H87)T)RP*("`@
M("=S9'<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I
M<VEO;BYW<FET97(G+`H@("`@)W-G:2<@("`@("`@("`@(#T^("=I;6%G92]X
M+7-G:2<L"B`@("`G<V=L)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N
M9"YS=&%R9&EV:7-I;VXN=W)I=&5R)RP*("`@("=S9VTG("`@("`@("`@("`]
M/B`G=&5X="]S9VUL)RP*("`@("=S9VUL)R`@("`@("`@("`]/B`G=&5X="]S
M9VUL)RP*("`@("=S:"<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US
M:&5L;'-C<FEP="<L"B`@("`G<VAA<B<@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M<VAA<B<L"B`@("`G<VAT;6PG("`@("`@("`@/3X@)W1E>'0O:'1M
M;"<L"B`@("`G<VEA9R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<VEA
M9R<L"B`@("`G<VED)R`@("`@("`@("`@/3X@)V%U9&EO+W!R<RYS:60G+`H@
M("`@)W-I:R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71R87-H)RP*
M("`@("=S:6QO)R`@("`@("`@("`]/B`G;6]D96PO;65S:"<L"B`@("`G<VET
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W-T=69F:70G+`H@("`@)W-K
M9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-K
M;2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-K
M<"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-K
M="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6MO86XG+`H@("`@)W-L
M:R<@("`@("`@("`@(#T^("=T97AT+W-P<F5A9'-H965T)RP*("`@("=S;60G
M("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYM
M86EL)RP*("`@("=S;68G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+G-T87)D:79I<VEO;BYM871H)RP*("`@("=S;6DG("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO<VUI;"<L"B`@("`G<VUI;"<@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W-M:6PG+`H@("`@)W-M;"<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]S;6EL)RP*("`@("=S;7,G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO>"US;7,M<F]M)RP*("`@("=S;F0G("`@("`@("`@("`]/B`G875D
M:6\O8F%S:6,G+`H@("`@)W-O)R`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X+7-H87)E9&QI8B<L"B`@("`G<W!D)R`@("`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W@M9F]N="US<&5E9&\G+`H@("`@)W-P;"<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+69U='5R97-P;&%S:"<L"B`@("`G<W%L)R`@("`@
M("`@("`@/3X@)W1E>'0O>"US<6PG+`H@("`@)W-R8R<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]X+7=A:7,M<V]U<F-E)RP*("`@("=S=&,G("`@("`@
M("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN8V%L8RYT96UP;&%T
M92<L"B`@("`G<W1D)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS
M=6XN>&UL+F1R87<N=&5M<&QA=&4G+`H@("`@)W-T:2<@("`@("`@("`@(#T^
M("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YI;7!R97-S+G1E;7!L871E)RP*
M("`@("=S=&TG("`@("`@("`@("`]/B`G875D:6\O>"US=&TG+`H@("`@)W-T
M=R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N<W5N+GAM;"YW<FET
M97(N=&5M<&QA=&4G+`H@("`@)W-T>2<@("`@("`@("`@(#T^("=T97AT+W@M
M=&5X)RP*("`@("=S=6XG("`@("`@("`@("`]/B`G:6UA9V4O>"US=6XM<F%S
M=&5R)RP*("`@("=S=C1C<&EO)R`@("`@("`]/B`G87!P;&EC871I;VXO>"US
M=C1C<&EO)RP*("`@("=S=C1C<F,G("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"US=C1C<F,G+`H@("`@)W-V9R<@("`@("`@("`@(#T^("=I;6%G92]S=F<K
M>&UL)RP*("`@("=S=V8G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"US
M:&]C:W=A=F4M9FQA<V@G+`H@("`@)W-X8R<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]V;F0N<W5N+GAM;"YC86QC)RP*("`@("=S>&0G("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN9')A=R<L"B`@("`G<WAG
M)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E
M<BYG;&]B86PG+`H@("`@)W-X:2<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N<W5N+GAM;"YI;7!R97-S)RP*("`@("=S>&TG("`@("`@("`@("`]
M/B`G87!P;&EC871I;VXO=FYD+G-U;BYX;6PN;6%T:"<L"B`@("`G<WAW)R`@
M("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YS=6XN>&UL+G=R:71E<B<L
M"B`@("`G<WEL:R<@("`@("`@("`@/3X@)W1E>'0O<W!R96%D<VAE970G+`H@
M("`@)W0G("`@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71R;V9F)RP*
M("`@("=T87(G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT87(G+`H@
M("`@)W1A<BY:)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+71A<GHG+`H@
M("`@)W1A<BYB>B<@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6)Z:7`M8V]M
M<')E<W-E9"UT87(G+`H@("`@)W1A<BYB>C(G("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X+6)Z:7`M8V]M<')E<W-E9"UT87(G+`H@("`@)W1A<BYG>B<@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]X+6-O;7!R97-S960M=&%R)RP*("`@("=T
M87(N;'IO)R`@("`@("`]/B`G87!P;&EC871I;VXO>"UT>F\G+`H@("`@)W1C
M;"<@("`@("`@("`@(#T^("=T97AT+W@M=&-L)RP*("`@("=T97@G("`@("`@
M("`@("`]/B`G=&5X="]X+71E>"<L"B`@("`G=&5X:2<@("`@("`@("`@/3X@
M)W1E>'0O>"UT97AI;F9O)RP*("`@("=T97AI;F9O)R`@("`@("`]/B`G=&5X
M="]X+71E>&EN9F\G+`H@("`@)W1G82<@("`@("`@("`@(#T^("=I;6%G92]X
M+71G82<L"B`@("`G=&=Z)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M8V]M<')E<W-E9"UT87(G+`H@("`@)W1H96UE)R`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]X+71H96UE)RP*("`@("=T:68G("`@("`@("`@("`]/B`G:6UA
M9V4O=&EF9B<L"B`@("`G=&EF9B<@("`@("`@("`@/3X@)VEM86=E+W1I9F8G
M+`H@("`@)W1K)R`@("`@("`@("`@(#T^("=T97AT+W@M=&-L)RP*("`@("=T
M;W)R96YT)R`@("`@("`]/B`G87!P;&EC871I;VXO>"UB:71T;W)R96YT)RP*
M("`@("=T<B<@("`@("`@("`@("`]/B`G87!P;&EC871I;VXO>"UT<F]F9B<L
M"B`@("`G=',G("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M;&EN9W5I
M<W0G+`H@("`@)W1S=B<@("`@("`@("`@(#T^("=T97AT+W1A8BUS97!A<F%T
M960M=F%L=65S)RP*("`@("=T=&8G("`@("`@("`@("`]/B`G87!P;&EC871I
M;VXO>"UF;VYT+71T9B<L"B`@("`G='AT)R`@("`@("`@("`@/3X@)W1E>'0O
M<&QA:6XG+`H@("`@)W1Z;R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X
M+71Z;R<L"B`@("`G=6DG("`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M9&5S:6=N97(G+`H@("`@)W5I;"<@("`@("`@("`@(#T^("=T97AT+W@M=6EL
M)RP*("`@("=U;'0G("`@("`@("`@("`]/B`G875D:6\O>"UM;V0G+`H@("`@
M)W5N:2<@("`@("`@("`@(#T^("=A=61I;R]X+6UO9"<L"B`@("`G=7)I)R`@
M("`@("`@("`@/3X@)W1E>'0O>"UU<FDG+`H@("`@)W5R;"<@("`@("`@("`@
M(#T^("=T97AT+W@M=7)I)RP*("`@("=U<W1A<B<@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UU<W1A<B<L"B`@("`G=F-D)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M8V1L:6YK)RP*("`@("=V8V8G("`@("`@("`@("`]/B`G
M=&5X="]D:7)E8W1O<GDG+`H@("`@)W9C<R<@("`@("`@("`@(#T^("=T97AT
M+V-A;&5N9&%R)RP*("`@("=V8W0G("`@("`@("`@("`]/B`G=&5X="]D:7)E
M8W1O<GDG+`H@("`@)W9F8B<@("`@("`@("`@(#T^("=T97AT+V-A;&5N9&%R
M)RP*("`@("=V;V(G("`@("`@("`@("`]/B`G=FED96\O;7!E9R<L"B`@("`G
M=F]C)R`@("`@("`@("`@/3X@)V%U9&EO+W@M=F]C)RP*("`@("=V;W(G("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G-T87)D:79I<VEO;BYW<FET
M97(G+`H@("`@)W9R;6PG("`@("`@("`@(#T^("=M;V1E;"]V<FUL)RP*("`@
M("=V<V0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+G9I<VEO)RP*
M("`@("=V>&UL)R`@("`@("`@("`]/B`G87!P;&EC871I;VXO=F]I8V5X;6PK
M>&UL)RP*("`@("=W878G("`@("`@("`@("`]/B`G875D:6\O>"UW878G+`H@
M("`@)W=A>"<@("`@("`@("`@(#T^("=A=61I;R]X+6US+7=A>"<L"B`@("`G
M=V(Q)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<75A='1R;W!R;R<L
M"B`@("`G=V(R)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M<75A='1R
M;W!R;R<L"B`@("`G=V(S)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W@M
M<75A='1R;W!R;R<L"B`@("`G=V)M<"<@("`@("`@("`@/3X@)VEM86=E+W9N
M9"YW87`N=V)M<"<L"B`@("`G=V)X;6PG("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W9N9"YW87`N=V)X;6PG+`H@("`@)W=K,2<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=K,R<@("`@("`@
M("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)W=K
M-"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G
M+`H@("`@)W=K<R<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N;&]T
M=7,M,2TR+3,G+`H@("`@)W=M)R`@("`@("`@("`@(#T^("=V:61E;R]X+6US
M+7=M)RP*("`@("=W;6$G("`@("`@("`@("`]/B`G875D:6\O>"UM<RUW;6$G
M+`H@("`@)W=M9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]X+6US+7=M
M9"<L"B`@("`G=VUF)R`@("`@("`@("`@/3X@)VEM86=E+W@M=VUF)RP*("`@
M("=W;6PG("`@("`@("`@("`]/B`G=&5X="]V;F0N=V%P+G=M;"<L"B`@("`G
M=VUL8R<@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N+W9N9"YW87`N=VUL8R<L
M"B`@("`G=VUL<R<@("`@("`@("`@/3X@)W1E>'0O=FYD+G=A<"YW;6QS8W)I
M<'0G+`H@("`@)W=M;'-C)R`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V;F0N
M=V%P+G=M;'-C<FEP=&,G+`H@("`@)W=M=B<@("`@("`@("`@(#T^("=V:61E
M;R]X+6US+7=M=B<L"B`@("`G=VUX)R`@("`@("`@("`@/3X@)W9I9&5O+W@M
M;7,M=VUX)RP*("`@("=W;7HG("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M>"UM<RUW;7HG+`H@("`@)W=P9"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]V;F0N=V]R9'!E<F9E8W0G+`H@("`@)W=P9R<@("`@("`@("`@(#T^("=A
M<'!L:6-A=&EO;B]X+7=P9R<L"B`@("`G=W)I)R`@("`@("`@("`@/3X@)V%P
M<&QI8V%T:6]N+W@M;7-W<FET92<L"B`@("`G=W)L)R`@("`@("`@("`@/3X@
M)VUO9&5L+W9R;6PG+`H@("`@)W=V>"<@("`@("`@("`@(#T^("=V:61E;R]X
M+6US+7=V>"<L"B`@("`G>&%C)R`@("`@("`@("`@/3X@)V%P<&QI8V%T:6]N
M+W@M9VYU8V%S:"<L"B`@("`G>&)E;"<@("`@("`@("`@/3X@)V%P<&QI8V%T
M:6]N+W@M>&)E;"<L"B`@("`G>&)M)R`@("`@("`@("`@/3X@)VEM86=E+W@M
M>&)I=&UA<"<L"B`@("`G>&-F)R`@("`@("`@("`@/3X@)VEM86=E+W@M>&-F
M)RP*("`@("=X8V8N8GHR)R`@("`@("`]/B`G:6UA9V4O>"UC;VUP<F5S<V5D
M+7AC9B<L"B`@("`G>&-F+F=Z)R`@("`@("`@/3X@)VEM86=E+W@M8V]M<')E
M<W-E9"UX8V8G+`H@("`@)WAH="<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO
M;B]X:'1M;"MX;6PG+`H@("`@)WAH=&UL)R`@("`@("`@(#T^("=A<'!L:6-A
M=&EO;B]X:'1M;"MX;6PG+`H@("`@)WAI)R`@("`@("`@("`@(#T^("=A=61I
M;R]X+7AI)RP*("`@("=X;&$G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO
M=FYD+FUS+65X8V5L)RP*("`@("=X;&,G("`@("`@("`@("`]/B`G87!P;&EC
M871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;&0G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;&PG("`@("`@("`@
M("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X;&TG("`@
M("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*("`@("=X
M;',G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X8V5L)RP*
M("`@("=X;'0G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD+FUS+65X
M8V5L)RP*("`@("=X;'<G("`@("`@("`@("`]/B`G87!P;&EC871I;VXO=FYD
M+FUS+65X8V5L)RP*("`@("=X;2<@("`@("`@("`@("`]/B`G875D:6\O>"UX
M;2<L"B`@("`G>&UI)R`@("`@("`@("`@/3X@)W1E>'0O>"UX;6DG+`H@("`@
M)WAM;"<@("`@("`@("`@(#T^("=T97AT+WAM;"<L"B`@("`G>'!M)R`@("`@
M("`@("`@/3X@)VEM86=E+W@M>'!I>&UA<"<L"B`@("`G>'-L)R`@("`@("`@
M("`@/3X@)W1E>'0O>"UX<VQT)RP*("`@("=X<VQF;R<@("`@("`@("`]/B`G
M=&5X="]X+7AS;&9O)RP*("`@("=X<VQT)R`@("`@("`@("`]/B`G=&5X="]X
M+7AS;'0G+`H@("`@)WAU;"<@("`@("`@("`@(#T^("=A<'!L:6-A=&EO;B]V
M;F0N;6]Z:6QL82YX=6PK>&UL)RP*("`@("=X=V0G("`@("`@("`@("`]/B`G
M:6UA9V4O>"UX=VEN9&]W9'5M<"<L"B`@("`G>'EZ)R`@("`@("`@("`@/3X@
M)V-H96UI8V%L+W@M>'EZ)RP*("`@("=Z86)W)R`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UA8FEW;W)D)RP*("`@("=Z:7`G("`@("`@("`@("`]/B`G
M87!P;&EC871I;VXO>FEP)RP*("`@("=Z;V\G("`@("`@("`@("`]/B`G87!P
M;&EC871I;VXO>"UZ;V\G+`H@("`@)S$R,R<@("`@("`@("`@(#T^("=A<'!L
M:6-A=&EO;B]V;F0N;&]T=7,M,2TR+3,G+`H@("`@)S8V.2<@("`@("`@("`@
M(#T^("=A=61I;R]X+6UO9"<**3L`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]M:6UE+FUA9VEC+G!H
M<```````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C<T,S4@,3`U,34T
M,S0Q,S<@,#(R-C,R`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!$871A(&9I;&4@=7-E9"!B>2!-24U%
M7TUA9VEC.CHN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]M
M:6UE+FUA9VEC+G!H<"QV(#$N-2`R,#`T+S`S+S(P(#(R.C0U.C,W(&IA;B!%
M>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]-24U%"B`J+PHD;6EM95]M86=I
M8ULP75LS,%U;(EPQ-#5<,38V7#$T,5PQ-31<-#!<-#)<,30U7#$W,%PQ-#5<
M,30S7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<
M-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC
M871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,C1=6R)<,30U7#$V-EPQ
M-#%<,34T7#0P7#0R7#$T-5PQ-S!<,30U7#$T,UPT,%PU-UPQ-C5<,38S7#$V
M,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L
M:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LR,UU;(EPQ,#-<,34W
M7#$U-5PQ-35<,34W7#$U-EPT,%PQ-C-<,38U7#$T,EPQ-#1<,34Q7#$V,EPQ
M-#5<,30S7#$V-%PQ-3=<,38R7#$U,5PQ-#5<,38S7#<R7#0P(ET@/2`G=&5X
M="]X+7!A=&-H)SL*)&UI;65?;6%G:6-;,%U;,C-=6R)<-S5<-S1<,34T7#$U
M,5PQ-C-<,38T7#<V7#$U-EPW-%PQ-C!<,38R7#$U-UPQ-C1<,34W7#$T,UPQ
M-3=<,34T7#0P7#$T,EPQ-#)<,34V7#4U7#$U-2)=(#T@)V%P<&QI8V%T:6]N
M+V1A=&$G.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#%<,3$U7#$P,5PQ,39<
M,3`T7#$P,5PW,EPT,%PQ,C1<,3`Q7#$R,%PQ,#5<,3(S7#$R-%PQ,#%<,3(R
M7#$R-%PT,%PQ,#1<,3`Q7#$R-%PQ,#4B72`]("=A<'!L:6-A=&EO;B]X+6%M
M86YD82UH96%D97(G.PHD;6EM95]M86=I8ULP75LR,EU;(EPQ,#=<,3`V7#8Q
M7#$R,%PQ,#%<,3(T7#$P,UPQ,3!<-C%<-C!<-C!<-C!<,3$Q7#$P-%PT,UPV
M,%PV,%PV,%PV,%PV,%PV,EPV,")=(#T@)V%U9&EO+W@M9W5S+7!A=&-H)SL*
M)&UI;65?;6%G:6-;,%U;,C)=6R)<,3`W7#$P-EPV,5PQ,C!<,3`Q7#$R-%PQ
M,#-<,3$P7#8Q7#8Q7#8P7#8P7#$Q,5PQ,#1<-#-<-C!<-C!<-C!<-C!<-C!<
M-C)<-C`B72`]("=A=61I;R]X+6=U<RUP871C:"<["B1M:6UE7VUA9VEC6S!=
M6S(R75LB7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S
M7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@
M/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S
M7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<
M-3=<,30R7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC
M871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU
M-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ
M-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M87=K)SL*)&UI;65?;6%G:6-;,%U;,C)=6R)<-#-<-#%<,3%<-3=<,38U7#$V
M,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU
M-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO;B]X+7!E<FPG.PHD
M;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU
M-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ
M-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G
M:6-;,%U;,C)=6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U
M-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ
M-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,C)=
M6R)<-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q
M7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A
M<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q
M7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<
M,30R7#$U,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I
M;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LR,EU;(EPT,UPT,5PT,%PU-UPQ
M-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<
M,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI8V%T:6]N+W@M<&5R
M;"<["B1M:6UE7VUA9VEC6S!=6S(R75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<
M,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<
M,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC<V@G.PHD;6EM
M95]M86=I8ULP75LR,5U;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ
M-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C-<
M,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR
M,5U;(EPT,UPT,5PQ,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ
M-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$W,EPQ-C-<,34P(ET@/2`G87!P
M;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PT
M,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T
M,EPQ-3%<,34V7#4W7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ
M<V@G.PHD;6EM95]M86=I8ULP75LR,5U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S
M7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W
M7#$W,EPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UZ<V@G.PHD;6EM95]M
M86=I8ULP75LR,5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W
M7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U
M,")=(#T@)V%P<&QI8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LR,5U;
M(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<,34W7#$T,UPQ-#%<,34T
M7#4W7#$T,EPQ-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI
M8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,C%=6R)<-#-<-#%<-3=<
M,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W
M:R<["B1M:6UE7VUA9VEC6S!=6S(Q75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R
M7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U,5PQ-39<-3=<,38P
M7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?
M;6%G:6-;,%U;,C%=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U
M-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V,UPQ
M-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S(P
M75LB7#$T-5PQ-C9<,30Q7#$U-%PT,%PT,EPQ-#5<,3<P7#$T-5PQ-#-<-#!<
M-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC
M871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,C!=6R)<-#-<-#%<,3%<
M-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M
M86=I8ULP75LR,%U;(EPT,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-31<
M,34W7#$T,UPQ-#%<,34T7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-#4B72`]
M("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S(P75LB7#0S7#0Q7#4W
M7#$V-5PQ-C-<,38R7#4W7#$U-%PQ-3=<,30S7#$T,5PQ-31<-3=<,30R7#$U
M,5PQ-39<-3=<,30Q7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+7-H)SL*
M)&UI;65?;6%G:6-;,%U;,C!=6R)<-#-<-#%<-3=<,38U7#$V,UPQ-C)<-3=<
M,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-S)<,38S
M7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M>G-H)SL*)&UI;65?;6%G:6-;,%U;
M,3E=6R)<,3`S7#$V,EPQ-#5<,30Q7#$V-%PQ-3%<,38V7#$T-5PT,%PQ,C9<
M,34W7#$U,5PQ-#-<,30U7#0P7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%U9&EO
M+W@M=F]C)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#%<-S1<,30Q7#$V,EPQ
M-#-<,34P7#<V7#$U-EPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W
M7#$S-UPQ,S=<,3`U(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA
M9VEC6S!=6S$Y75LB7#0Q7#<T7#$T,5PQ-C)<,30S7#$U,%PW-EPQ-39<,3,W
M7#$S-UPQ,S=<,3,W7#$S-UPQ,S=<,3,W7#$S-UPV-EPV-%PQ,#4B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,3E=6R)<-#-<-#%<
M-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#%<,30U(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M
M86=I8ULP75LQ.%U;(EPQ,#9<,34Q7#$Q-%PQ-#5<,3(S7#$V-%PQ,#%<,38R
M7#$R-%PQ-#9<,3$Q7#$U-%PQ,#5<,38S7#$R-%PQ-#%<,3(R7#$V-")=(#T@
M)W1E>'0O>"UA<'!L92UB:6YS8VEI)SL*)&UI;65?;6%G:6-;,%U;,3A=6R)<
M-#-<-#%<-#!<-3=<,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U
M-%PU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<[
M"B1M:6UE7VUA9VEC6S!=6S$X75LB7#0U7#0Q7#$R,%PQ,C-<-35<,3`Q7#$T
M-%PQ-3=<,30R7#$T-5PQ,#9<,34W7#$U-EPQ-C1<-35<-C%<-39<-C`B72`]
M("=F;VYT+W1Y<&4Q)SL*)&UI;65?;6%G:6-;,%U;,3==6R)<-#-<-#%<-3=<
M,38U7#$V,UPQ-C)<-3=<,34T7#$U-UPQ-#-<,30Q7#$U-%PU-UPQ-C1<,30S
M7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6-S:"<["B1M:6UE7VUA9VEC
M6S!=6S$V75LB7#$P-5PQ-S!<,38T7#$T-5PQ-39<,30T7#$T-5PQ-#1<-#!<
M,3$U7#$U-UPQ-#1<,38U7#$U-%PQ-#5<-S(B72`]("=A=61I;R]X+69T,BUM
M;V0G.PHD;6EM95]M86=I8ULP75LQ-EU;(EPQ,C-<,38T7#$T,5PQ-C)<,38T
M7#$P-EPQ-3=<,34V7#$V-%PQ,35<,30U7#$V-%PQ-C)<,34Q7#$T,UPQ-C,B
M72`]("=F;VYT+W@M<W5N;W,M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S$V75LB
M7#0S7#0Q7#$Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$T
M-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?
M;6%G:6-;,%U;,39=6R)<-#-<-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,30R
M7#$U,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO
M>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT,UPT,5PQ,5PU-UPQ-C5<
M,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]
M("=A<'!L:6-A=&EO;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LQ-EU;(EPT
M,UPT,5PT,%PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<
M,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA
M9VEC6S!=6S$V75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ
M-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M87=K)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<-#-<-#%<-#!<-3=<,38U7#$V
M,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G
M87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,39=6R)<-S1<
M,3$U7#$T,5PQ-3-<,30U7#$V,EPQ,#1<,34Q7#$T,UPQ-C1<,34Q7#$U-UPQ
M-39<,30Q7#$V,EPQ-S$B72`]("=A<'!L:6-A=&EO;B]X+69R86UE;6%K97(G
M.PHD;6EM95]M86=I8ULP75LQ-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R
M7#$R,UPQ-#-<,38R7#$T-5PQ-#5<,34V7#$P-EPQ-3=<,34V7#$V-")=(#T@
M)V9O;G0O>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<
M-#%<,3%<-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,30Q7#$V
M-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=
M6S$U75LB7#0S7#0Q7#0P7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ-3%<,34V
M7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM
M95]M86=I8ULP75LQ-5U;(EPT,UPT,5PU-UPQ-C5<,38S7#$V,EPU-UPQ-#)<
M,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L:6-A=&EO;B]X
M+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$U75LB7#0S7#0Q7#4W7#$V-5PQ-C-<
M,38R7#4W7#$T,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P
M<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,35=6R)<-#-<-#%<
M-3=<,38U7#$V,UPQ-C)<-3=<,30R7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<
M,34T(ET@/2`G87!P;&EC871I;VXO>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;
M,31=6R)<-#%<-S1<,30Q7#$V,EPQ-#-<,34P7#<V7#$U-EPQ-#1<,30U7#$T
M,EPQ-3%<,30Q7#$U-B)=(#T@)V%P<&QI8V%T:6]N+W@M9'!K9R<["B1M:6UE
M7VUA9VEC6S!=6S$T75LB7#0S7#0Q7#4W7#$V-5PQ-C-<,38R7#4W7#$T,EPQ
M-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG
M.PHD;6EM95]M86=I8ULP75LQ-%U;(EPW-%PT,5PQ,#1<,3$W7#$P,UPQ,C1<
M,3,Q7#$R,%PQ,#5<-#!<,3$P7#$R-%PQ,35<,3$T(ET@/2`G=&5X="]H=&UL
M)SL*)&UI;65?;6%G:6-;,%U;,31=6R)<-S1<-#%<,30T7#$U-UPQ-#-<,38T
M7#$W,5PQ-C!<,30U7#0P7#$U,%PQ-C1<,34U7#$U-")=(#T@)W1E>'0O:'1M
M;"<["B1M:6UE7VUA9VEC6S!=6S$S75LB7#$P-UPQ,3%<,3$U7#$R,%PT,%PQ
M,#=<,38R7#$T,5PQ-#1<,34Q7#$T-5PQ-39<,38T(ET@/2`G87!P;&EC871I
M;VXO>"UG:6UP+6=R861I96YT)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<,3(R
M7#$T-5PQ-C1<,38U7#$V,EPQ-39<-35<,3(P7#$T,5PQ-C1<,34P7#<R(ET@
M/2`G;65S<V%G92]R9F,X,C(G.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT
M,5PQ,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#)<,30Q7#$V,UPQ-3`B72`]("=A
M<'!L:6-A=&EO;B]X+7-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<
M,3%<-3=<,30R7#$U,5PQ-39<-3=<,30W7#$T,5PQ-C=<,34S(ET@/2`G87!P
M;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PQ
M,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-39<,30Q7#$V-UPQ-3,B72`]("=A<'!L
M:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q
M7#4W7#$T,EPQ-3%<,34V7#4W7#$V,%PQ-#5<,38R7#$U-")=(#T@)V%P<&QI
M8V%T:6]N+W@M<&5R;"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#$Q
M7#4W7#$T,EPQ-3%<,34V7#4W7#$V-%PQ-#-<,38S7#$U,")=(#T@)V%P<&QI
M8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<
M-3=<,30R7#$U,5PQ-39<-3=<,30R7#$T,5PQ-C-<,34P(ET@/2`G87!P;&EC
M871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S$R75LB7#0S7#0Q7#0P7#4W
M7#$T,EPQ-3%<,34V7#4W7#$T-UPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T
M:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,3)=6R)<-#-<-#%<-#!<-3=<
M,30R7#$U,5PQ-39<-3=<,34V7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I
M;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-C!<,30U7#$V,EPQ-30B72`]("=A<'!L:6-A=&EO
M;B]X+7!E<FPG.PHD;6EM95]M86=I8ULP75LQ,EU;(EPT,UPT,5PT,%PU-UPQ
M-#)<,34Q7#$U-EPU-UPQ-C1<,30S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO
M;B]X+6-S:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#$Q7#4W7#$T
M,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA
M=VLG.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT,5PQ,5PU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*
M)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<
M-3=<,34S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE
M7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#0P7#4W7#$T,EPQ-3%<,34V7#4W7#$T
M,5PQ-C=<,34S(ET@/2`G87!P;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I
M8ULP75LQ,5U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#-<,38S
M7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;
M,3%=6R)<-#-<-#%<-#!<-3=<,30R7#$U,5PQ-39<-3=<,34S7#$V,UPQ-3`B
M72`]("=A<'!L:6-A=&EO;B]X+6MS:"<["B1M:6UE7VUA9VEC6S!=6S$Q75LB
M7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$T,EPQ-#%<,38S7#$U,")=(#T@
M)V%P<&QI8V%T:6]N+W@M<V@G.PHD;6EM95]M86=I8ULP75LQ,5U;(EPT,UPT
M,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-#=<,30Q7#$V-UPQ-3,B72`]("=A<'!L
M:6-A=&EO;B]X+6%W:R<["B1M:6UE7VUA9VEC6S!=6S$Q75LB7#0S7#0Q7#4W
M7#$T,EPQ-3%<,34V7#4W7#$U-EPQ-#%<,38W7#$U,R)=(#T@)V%P<&QI8V%T
M:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R
M7#$U,5PQ-39<-3=<,38P7#$T-5PQ-C)<,34T(ET@/2`G87!P;&EC871I;VXO
M>"UP97)L)SL*)&UI;65?;6%G:6-;,%U;,3%=6R)<-#-<-#%<-3=<,30R7#$U
M,5PQ-39<-3=<,38T7#$T,UPQ-C-<,34P(ET@/2`G87!P;&EC871I;VXO>"UC
M<V@G.PHD;6EM95]M86=I8ULP75LQ,%U;(EPQ,#)<,34Q7#$V-%PQ-35<,30Q
M7#$V,%PQ-#9<,34Q7#$U-%PQ-#4B72`]("=I;6%G92]U;FMN;W=N)SL*)&UI
M;65?;6%G:6-;,%U;,3!=6R)<,3(S7#$R-%PQ,#%<,3(R7#$R-%PQ,#9<,3$W
M7#$Q-EPQ,C1<-#`B72`]("=F;VYT+W@M8F1F)SL*)&UI;65?;6%G:6-;,%U;
M,3!=6R)<-#-<-#%<,3%<-3=<,30R7#$U,5PQ-39<-3=<,38R7#$T,R)=(#T@
M)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<,3%<
M-3=<,30R7#$U,5PQ-39<-3=<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N+W@M
M<V@G.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q
M7#$U-EPU-UPQ-C)<,30S(ET@/2`G=&5X="]S8W)I<'0G.PHD;6EM95]M86=I
M8ULP75LQ,%U;(EPT,UPT,5PT,%PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P
M(ET@/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6S$P75LB
M7#0S7#0Q7#4W7#$T,EPQ-3%<,34V7#4W7#$T,5PQ-C=<,34S(ET@/2`G87!P
M;&EC871I;VXO>"UA=VLG.PHD;6EM95]M86=I8ULP75LQ,%U;(EPT,UPT,5PU
M-UPQ-#)<,34Q7#$U-EPU-UPQ-#-<,38S7#$U,")=(#T@)V%P<&QI8V%T:6]N
M+W@M8W-H)SL*)&UI;65?;6%G:6-;,%U;,3!=6R)<-#-<-#%<-3=<,30R7#$U
M,5PQ-39<-3=<,34S7#$V,UPQ-3`B72`]("=A<'!L:6-A=&EO;B]X+6MS:"<[
M"B1M:6UE7VUA9VEC6S!=6S$P75LB7#<T7#$Q-5PQ-#%<,34S7#$T-5PQ-C)<
M,3`V7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R
M)SL*)&UI;65?;6%G:6-;,%U;.5U;(EPQ,C)<,30U7#$T,UPQ-#5<,34Q7#$V
M-EPQ-#5<,30T7#<R(ET@/2`G;65S<V%G92]R9F,X,C(G.PHD;6EM95]M86=I
M8ULP75LY75LB7#$R,UPQ-C1<,30Q7#$V,EPQ-C1<,3`V7#$U-UPQ-39<,38T
M(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M86=I8ULP75LY75LB
M7#(Q,5PQ,31<,3,R7#$Q-UPP7#$U7#$R7#,R7#$R(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-#-<-#%<-3=<,30R7#$U
M,5PQ-39<-3=<,38R7#$T,R)=(#T@)W1E>'0O<V-R:7!T)SL*)&UI;65?;6%G
M:6-;,%U;.5U;(EPT,UPT,5PU-UPQ-#)<,34Q7#$U-EPU-UPQ-C-<,34P(ET@
M/2`G87!P;&EC871I;VXO>"US:"<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-35<
M,38R7#$U-UPQ-35<-C%<,30V7#$V,UPU-5PV,")=(#T@)V%P<&QI8V%T:6]N
M+W@M9FEL97-Y<W1E;2<["B1M:6UE7VUA9VEC6S!=6SE=6R)<-S1<,3`R7#$U
M-UPQ-3=<,34S7#$P-EPQ-3%<,34T7#$T-2)=(#T@)V%P<&QI8V%T:6]N+W@M
M9G)A;65M86ME<B<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,3$W7#$U-EPQ-31<
M,3<Q7#0P7#$U,5PQ-39<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M
M86=I8ULP75LX75LB7#$T-UPQ-3%<,34U7#$V,%PT,%PQ-S!<,30S7#$T-B)=
M(#T@)V%P<&QI8V%T:6]N+W@M9VEM<"UI;6%G92<["B1M:6UE7VUA9VEC6S!=
M6SA=6R)<,34U7#$V,UPQ-#=<,30S7#$T,5PQ-C1<-C!<-C$B72`]("=A<'!L
M:6-A=&EO;B]X+6QO8V%L92<["B1M:6UE7VUA9VEC6S!=6SA=6R)<,S)<,30Q
M7#$V,EPQ-#-<,34P7#$U,5PQ-C9<,30U(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6SA=6R)<-#%<-S1<,3(P7#$P-%PQ,#9<-S9<
M-#%<,34V(ET@/2`G87!P;&EC871I;VXO>"UP<F]F)SL*)&UI;65?;6%G:6-;
M,%U;.%U;(EPW-%PQ,35<,3$Q7#$P-EPQ,#9<,34Q7#$U-%PQ-#4B72`]("=A
M<'!L:6-A=&EO;B]X+69R86UE;6%K97(G.PHD;6EM95]M86=I8ULP75LW75LB
M7#$P,5PQ-C)<,38T7#$U,5PQ-#-<,34T7#$T-2)=(#T@)VUE<W-A9V4O;F5W
M<R<["B1M:6UE7VUA9VEC6S!=6S==6R)<,3(P7#$P,UPQ,#1<,3,W7#$Q-UPQ
M,C!<,3`Q(ET@/2`G>"]X+7!H;W1O+6-D+6]V97)F:65W+69I;&4G.PHD;6EM
M95]M86=I8ULP75LW75LB7#,U,5PU-%PQ7#$Q,EPQ,#%<,3$U7#$Q(ET@/2`G
M87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S==6R)<-#%<-S1<
M,30Q7#$V,EPQ-#-<,34P7#<V(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M
M:6UE7VUA9VEC6S!=6S==6R)<-S)<-#!<,38S7#$U,%PQ-#5<,34T7#$U-")=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LV75LB7#$Q
M-EPQ-C5<,3`V7#$U,5PQ-31<,30U(ET@/2`G87!P;&EC871I;VXO9&%T82<[
M"B1M:6UE7VUA9VEC6S!=6S9=6R)<,3$V7#,V-5PQ,#9<,S4Q7#$U-%PS-#4B
M72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPV
M,%PV-UPV,%PV-UPV,%PV,2)=(#T@)V%P<&QI8V%T:6]N+W@M8W!I;R<["B1M
M:6UE7VUA9VEC6S!=6S9=6R)<-C!<-C=<-C!<-C=<-C!<-C(B72`]("=A<'!L
M:6-A=&EO;B]X+6-P:6\G.PHD;6EM95]M86=I8ULP75LV75LB7#8P7#8W7#8P
M7#8W7#8P7#8W(ET@/2`G87!P;&EC871I;VXO>"UC<&EO)SL*)&UI;65?;6%G
M:6-;,%U;-EU;(EPW-%PQ,35<,30Q7#$U,UPQ-#5<,38R(ET@/2`G87!P;&EC
M871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G:6-;,%U;-EU;(EPW-%PQ
M,C1<,3$Q7#$R-%PQ,31<,3`U(ET@/2`G=&5X="]H=&UL)SL*)&UI;65?;6%G
M:6-;,%U;-EU;(EPW-%PQ-C1<,34Q7#$V-%PQ-31<,30U(ET@/2`G=&5X="]H
M=&UL)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPP7#%<,%PP7#`B72`]("=F;VYT
M+W1T9B<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,%PT7#,V7#(Q,EPR,#`B72`]
M("=A<'!L:6-A=&EO;B]C;W)E)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#)<
M,3`Q7#$P,EPQ,S%<,3$T(ET@/2`G;65S<V%G92]X+6=N=2UR;6%I;"<["B1M
M:6UE7VUA9VEC6S!=6S5=6R)<,3`R7#$P-5PQ,#=<,3$Q7#$Q-B)=(#T@)V%P
M<&QI8V%T:6]N+W@M87=K)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#-<,34W
M7#$V,EPQ-#5<,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#1<-C%<-39<-C!<,34B72`]("=F
M;VYT+W@M<W!E961O)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ,#9<,38R7#$U
M-UPQ-35<-S(B72`]("=M97-S86=E+W)F8S@R,B<["B1M:6UE7VUA9VEC6S!=
M6S5=6R)<,3$U7#$P,5PQ,C-<,3,W7#$R-2)=(#T@)V%U9&EO+W@M;75L=&EM
M871E+6UO9"<["B1M:6UE7VUA9VEC6S!=6S5=6R)<,3(P7#$Q-UPQ,S9<,3(Q
M7#$T,")=(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM95]M86=I8ULP75LU
M75LB7#$R,%PQ-#%<,38T7#$U,%PW,B)=(#T@)VUE<W-A9V4O;F5W<R<["B1M
M:6UE7VUA9VEC6S!=6S5=6R)<,3,P7#$V,EPQ-#5<,30V7#<R(ET@/2`G;65S
M<V%G92]N97=S)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPQ-#1<,34Q7#$T-EPQ
M-#9<-#`B72`]("=T97AT+W@M<&%T8V@G.PHD;6EM95]M86=I8ULP75LU75LB
M7#(R-5PV-%PV,EPV,EPS,S8B72`]("=A<'!L:6-A=&EO;B]X+6QO8V%L92<[
M"B1M:6UE7VUA9VEC6S!=6S5=6R)<,S,V7#8R7#8R7#8T7#(R-2)=(#T@)V%P
M<&QI8V%T:6]N+W@M;&]C86QE)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ
M,3!<,3`U7#$P,5PQ,#0B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP
M75LU75LB7#<T7#$Q,%PQ,C1<,3$U7#$Q-")=(#T@)W1E>'0O:'1M;"<["B1M
M:6UE7VUA9VEC6S!=6S5=6R)<-S1<,34P7#$T-5PQ-#%<,30T(ET@/2`G=&5X
M="]H=&UL)SL*)&UI;65?;6%G:6-;,%U;-5U;(EPW-%PQ-3!<,38T7#$U-5PQ
M-30B72`]("=T97AT+VAT;6PG.PHD;6EM95]M86=I8ULP75LU75LB7#<U7#<T
M7#$T,5PQ-C)<-S8B72`]("=A<'!L:6-A=&EO;B]X+6%R)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPP7#!<,%PS,30B72`]("=A<'!L:6-A=&EO;B]X+65X96-U
M=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#!<-")=(#T@
M)V9O;G0O>"US;F8G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#$P-R)=
M(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP
M75LT75LB7#!<,%PQ7#$Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L
M92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#!<,5PQ,34B72`]("=A
M<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=
M6S1=6R)<,%PP7#%<,3$W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PQ7#(P,2)=(#T@)V%P
M<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB
M7#!<,%PQ7#(P-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I
M8ULP75LT75LB7#!<,%PQ7#(V,R)=(#T@)W9I9&5O+VUP96<G.PHD;6EM95]M
M86=I8ULP75LT75LB7#!<,%PQ7#(W,B)=(#T@)W9I9&5O+VUP96<G.PHD;6EM
M95]M86=I8ULP75LT75LB7#!<,%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X+65X
M96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PP7#(P,5PQ
M-30B72`]("=A<'!L:6-A=&EO;B]X+6%P;"UW;W)K<W!A8V4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#!<,%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO>"UL
M:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#!<,%PS-S=<,34U
M(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,%PP7#-<,S0W(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#!<,%PS7#,V,R)=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#$T
M-%PQ-C-<-38B72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,%PQ7#(R7#$R-R)=(#T@)V%P<&QI8V%T:6]N+V-O<F4G.PHD;6EM95]M
M86=I8ULP75LT75LB7#!<,C)<,S(V7#(P-R)=(#T@)VEM86=E+W@Q,2<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,%PS7#(S,UPS-34B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPP7#-<,C,S7#,U-B)=(#T@
M)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#!<-5PR
M-EPP(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,%PU7#(V7#<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPP7#5<-C%<,30R(ET@/2`G87!P;&EC871I;VXO>"UD8B<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,%PV7#(U7#$T,2)=(#T@)V%P<&QI8V%T
M:6]N+W@M9&(G.PHD;6EM95]M86=I8ULP75LT75LB7#$P,UPQ,C1<,3$U7#$P
M-B)=(#T@)V%U9&EO+W@M8VUF)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,#5<
M,3$U7#$Q-UPQ,#0B72`]("=A=61I;R]X+65M;V0G.PHD;6EM95]M86=I8ULP
M75LT75LB7#$P-EPQ,#9<,3$Q7#$Q-")=(#T@)V9O;G0O='1F)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M=F9O
M;G0G.PHD;6EM95]M86=I8ULP75LT75LB7#$P-UPQ,#1<,3`R7#$Q-2)=(#T@
M)V%P<&QI8V%T:6]N+W@M9V1B;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3`W
M7#$Q,5PQ,#9<-S`B72`]("=I;6%G92]G:68G.PHD;6EM95]M86=I8ULP75LT
M75LB7#$P7#$V7#$R7#$W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,3$P7#$R,%PQ,#%<,3$S(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3$Q7#$Q,5PQ,39<-C$B
M72`]("=I;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,3%<,3$Q
M7#4R7#`B72`]("=I;6%G92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ
M,31<,3`T7#$Q,%PQ-3$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT+W1Y<&4Q
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$U7#!<-3(B72`]("=I;6%G
M92]T:69F)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,35<,3$W7#$R-EPQ,3$B
M72`]("=V:61E;R]X+7-G:2UM;W9I92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,3$U7#$R-%PQ-3!<,30T(ET@/2`G875D:6\O;6ED:2<["B1M:6UE7VUA9VEC
M6S!=6S1=6R)<,3$U7#(T-UPS-39<,S4P(ET@/2`G9F]N="]X+6AP+7=I;F1O
M=W,G.PHD;6EM95]M86=I8ULP75LT75LB7#$Q-EPQ,C1<,3(R7#$Q,R)=(#T@
M)V%U9&EO+W@M;75L=&ET<F%C:R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3(P
M7#$Q,UPS7#0B72`]("=A<'!L:6-A=&EO;B]Z:7`G.PHD;6EM95]M86=I8ULP
M75LT75LB7#$R,EPQ,3%<,3`V7#$P-B)=(#T@)V%U9&EO+W@M=V%V)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPQ,C)<,30Q7#$V,EPT,2)=(#T@)V%P<&QI8V%T
M:6]N+W@M<F%R)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPQ,C-<,3(Q7#$R,UPQ
M,3`B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;-%U;
M(EPQ,C1<,3`Q7#$P-%PQ,C,B72`]("=A<'!L:6-A=&EO;B]X+71A9',M9V%M
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3(U7#$P,UPV,EPS,B)=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#$R-5PQ,39<
M-C!<-C4B72`]("=A=61I;R]X+6UI:VUO9"UU;FDG.PHD;6EM95]M86=I8ULP
M75LT75LB7#$R7#$W7#$P7#$V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<,3,Q7#(T-EPQ-3)<,C(U(ET@/2`G>"]X+6EM
M86=E+7-U;BUR87-T97(G.PHD;6EM95]M86=I8ULP75LT75LB7#$T-5PS-S=<
M,%PP(ET@/2`G87!P;&EC871I;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,34P7#$V,UPQ-3%<-C$B72`]("=I;6%G92]X+6IP96<M<')O<')I971A
M<GDG.PHD;6EM95]M86=I8ULP75LT75LB7#$V7#$P7#$W7#$R(ET@/2`G87!P
M;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,3<W7#$P-5PQ
M,31<,3`V(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#$W7#$R7#$V7#$P(ET@/2`G87!P;&EC871I
M;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ,S!<-#%<,C0V(ET@
M/2`G87!P;&EC871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,5PQ
M-#9<,30S7#$V,")=(#T@)V9O;G0O>"UP8V8G.PHD;6EM95]M86=I8ULP75LT
M75LB7#(Q,5PQ,C!<,3$V7#$P-R)=(#T@)VEM86=E+W@M<&YG)SL*)&UI;65?
M;6%G:6-;,%U;-%U;(EPR,UPQ,C=<,C,R7#,Q-B)=(#T@)V%P<&QI8V%T:6]N
M+W@M9V1B;2<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$P-")=
M(#T@)V9O;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR
M,UPQ-S)<-3%<,3`W(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G.PHD;6EM95]M
M86=I8ULP75LT75LB7#(S7#$W,EPU,5PQ,C`B72`]("=F;VYT+W@M<W5N;W,M
M;F5W<R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,C-<,3<R7#4Q7#$R,2)=(#T@
M)V9O;G0O>"US=6YO<RUN97=S)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR-%PR
M7#$S,5PS,2)=(#T@)V9O;G0O>"UL:6)G<G@G.PHD;6EM95]M86=I8ULP75LT
M75LB7#(V,%PV,5PV,UPQ-#`B72`]("=A<'!L:6-A=&EO;B]X+6)O;W1A8FQE
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$P7#%<,3`B72`]("=A<'!L:6-A
M=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,EPQ,%PQ7#8B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<[
M"B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,%PQ7#<B72`]("=A<'!L:6-A=&EO
M;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ
M,%PS-S=<,30U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#)<,3)<,5PQ,")=(#T@)V%P<&QI8V%T:6]N
M+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$R
M7#%<-R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPR7#$R7#,W-UPQ-#4B72`]("=A<'!L:6-A=&EO
M;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ,UPQ
M7#$P(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM
M95]M86=I8ULP75LT75LB7#)<,3-<,5PQ,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$S7#%<
M,34B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM9FEL92<["B1M:6UE7VUA
M9VEC6S!=6S1=6R)<,EPQ,UPQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R
M87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,3-<,5PV(ET@/2`G
M87!P;&EC871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPQ,UPQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#$P(ET@/2`G87!P;&EC
M871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB
M7#)<,31<,5PQ,R)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#$T7#%<,30B72`]("=A<'!L:6-A
M=&EO;B]X+6QI<W`G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,31<,5PQ-2)=
M(#T@)V%P<&QI8V%T:6]N+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPR7#$T7#%<,38B72`]("=A<'!L:6-A=&EO;B]X+6QI8G)A<GDM
M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PQ7#8B72`]("=A<'!L
M:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPQ-%PQ7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL
M92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPQ-%PS-S=<,30U(ET@/2`G87!P
M;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB
M7#)<,C!<,5PQ,")=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<,3,B72`]("=A<'!L:6-A
M=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M,EPR,%PQ7#$U(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G.PHD
M;6EM95]M86=I8ULP75LT75LB7#)<,C!<,5PQ-B)=(#T@)V%P<&QI8V%T:6]N
M+W@M;&EB<F%R>2UF:6QE)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPR7#(P7#%<
M-B)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD;6EM95]M86=I
M8ULP75LT75LB7#)<,C!<,5PW(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A
M8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PQ,")=(#T@
M)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPR7#(T7#%<,3,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B
M;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ7#$U(ET@/2`G
M87!P;&EC871I;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=
M6R)<,EPR-%PQ7#$V(ET@/2`G87!P;&EC871I;VXO>"UL:6)R87)Y+69I;&4G
M.PHD;6EM95]M86=I8ULP75LT75LB7#)<,C1<,5PV(ET@/2`G87!P;&EC871I
M;VXO>"UO8FIE8W0M9FEL92<["B1M:6UE7VUA9VEC6S!=6S1=6R)<,EPR-%PQ
M7#<B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S1=6R)<,S8Q7#8P7#$P,%PR-S,B72`]("=I;6%G92]X+6-M
M=2UR87-T97(G.PHD;6EM95]M86=I8ULP75LT75LB7#,V-EPS-C9<,S8V7#,V
M-B)=(#T@)V%P<&QI8V%T:6]N+W@M<&,M9FQO<'!Y)SL*)&UI;65?;6%G:6-;
M,%U;-%U;(EPS-S=<,3`V7#$Q-UPQ,38B72`]("=F;VYT+W@M9&]S)SL*)&UI
M;65?;6%G:6-;,%U;-%U;(EPT,5PW-%PQ-#%<,38R(ET@/2`G87!P;&EC871I
M;VXO>"UA<B<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<,3%<-3<B72`]
M("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-#-<-#%<-#!<
M-3<B72`]("=T97AT+W-C<FEP="<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-3)<
M,3(S7#$R-%PQ,#$B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPU,EPU,EPU,EPT,")=(#T@)W1E>'0O>"UP871C:"<["B1M
M:6UE7VUA9VEC6S!=6S1=6R)<-39<,38R7#$T,5PS-S4B72`]("=A=61I;R]X
M+7!N+7)E86QA=61I;R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<-39<,38S7#$U
M-EPQ-#0B72`]("=A=61I;R]B87-I8R<["B1M:6UE7VUA9VEC6S!=6S1=6R)<
M-C%<,30S7#$V-UPT,")=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M
M86=I8ULP75LT75LB7#8Q7#(W-EPP7#`B72`]("=T97AT+W9N9"YM<RUW;W)D
M)SL*)&UI;65?;6%G:6-;,%U;-%U;(EPV,EPV,EPV-UPW,")=(#T@)V%P<&QI
M8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LT75LB7#<T7#$Q-5PQ,35<
M,3$T(ET@/2`G87!P;&EC871I;VXO>"UF<F%M96UA:V5R)SL*)&UI;65?;6%G
M:6-;,%U;-%U;(EPW-%PQ-#%<,38R7#<V(ET@/2`G87!P;&EC871I;VXO>"UA
M<B<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,3`R7#$S,EPQ-3`B72`]("=A<'!L
M:6-A=&EO;B]X+6)Z:7`R)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ,#9<,3`Q
M7#$R,B)=(#T@)V%U9&EO+VUO9"<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,3$U
M7#$R-%PQ,34B72`]("=A=61I;R]X+6UU;'1I=')A8VLG.PHD;6EM95]M86=I
M8ULP75LS75LB7#$R,UPQ,#)<,3$Q(ET@/2`G875D:6\O>"US8FDG.PHD;6EM
M95]M86=I8ULP75LS75LB7#$R-%PQ,3=<,3`S(ET@/2`G875D:6\O>"UT;V,G
M.PHD;6EM95]M86=I8ULP75LS75LB7#$R7#$P-UPQ,30B72`]("=A<'!L:6-A
M=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPQ-#9<,34T7#$T,R)=
M(#T@)V%P<&QI8V%T:6]N+W@M9F]N="<["B1M:6UE7VUA9VEC6S!=6S-=6R)<
M,30V7#$U-%PQ-#8B72`]("=F;VYT+W@M9FEG;&5T)SL*)&UI;65?;6%G:6-;
M,%U;,UU;(EPS,UPQ,#5<,S,B72`]("=I;6%G92]X+7!C;"UH<"<["B1M:6UE
M7VUA9VEC6S!=6S-=6R)<,S-<,30S7#,S(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S-=6R)<,S<W7#,W-UPQ-S0B72`]("=A<'!L
M:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,UU;(EPS-S=<,S<W7#$W
M-B)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB
M7#,W-UPS-S=<,3<W(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA
M9VEC6S!=6S-=6R)<-#-<-#%<-#`B72`]("=T97AT+W-C<FEP="<["B1M:6UE
M7VUA9VEC6S!=6S-=6R)<-#-<-#%<-3<B72`]("=T97AT+W-C<FEP="<["B1M
M:6UE7VUA9VEC6S!=6S-=6R)<-%PT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O
M<W1S8W)I<'0G.PHD;6EM95]M86=I8ULP75LS75LB7#4U7#$U,%PU-2)=(#T@
M)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LS75LB7#8Q7#$T
M,UPQ-C<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;
M,EU;(EPP7#`B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<[
M"B1M:6UE7VUA9VEC6S!=6S)=6R)<,3`R7#$Q-2)=(#T@)VEM86=E+W@M8FUP
M)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,#)<,3,R(ET@/2`G87!P;&EC871I
M;VXO>"UB>FEP)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ,3%<,3`S(ET@/2`G
M:6UA9V4O>"UI8V\G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q,EPQ,38B72`]
M("=A=61I;R]X+38V.2UM;V0G.PHD;6EM95]M86=I8ULP75LR75LB7#$Q-5PQ
M,S(B72`]("=A<'!L:6-A=&EO;B]X+6US+61O<RUE>&5C=71A8FQE)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPQ,C!<-C$B72`]("=I;6%G92]X+7!O<G1A8FQE
M+6)I=&UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8R(ET@/2`G:6UA
M9V4O>"UP;W)T86)L92UG<F%Y;6%P)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ
M,C!<-C,B72`]("=I;6%G92]X+7!O<G1A8FQE+7!I>&UA<"<["B1M:6UE7VUA
M9VEC6S!=6S)=6R)<,3(P7#8T(ET@/2`G:6UA9V4O>"UP;W)T86)L92UB:71M
M87`G.PHD;6EM95]M86=I8ULP75LR75LB7#$R,%PV-2)=(#T@)VEM86=E+W@M
M<&]R=&%B;&4M9W)A>6UA<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,3(P7#8V
M(ET@/2`G:6UA9V4O>"UP;W)T86)L92UP:7AM87`G.PHD;6EM95]M86=I8ULP
M75LR75LB7#$U,5PQ-#8B72`]("=A=61I;R]X+38V.2UM;V0G.PHD;6EM95]M
M86=I8ULP75LR75LB7#$V,5PS,#<B72`]("=A<'!L:6-A=&EO;B]X+6-P:6\G
M.PHD;6EM95]M86=I8ULP75LR75LB7#$V-EPS-S<B72`]("=A<'!L:6-A=&EO
M;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$Q,")=(#T@)V%P<&QI
M8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;
M(EPQ7#$Q,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*
M)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#$R-")=(#T@)V%P<&QI8V%T:6]N+V1A
M=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,3(U(ET@/2`G87!P;&EC871I
M;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<
M,38P(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM
M95]M86=I8ULP75LR75LB7#%<,38Q(ET@/2`G87!P;&EC871I;VXO>"UE>&5C
M=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,3<U(ET@/2`G
M87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP
M75LR75LB7#%<,3<W(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I
M;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C`B72`]("=A<'!L:6-A=&EO
M;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,5PR
M,#,B72`]("=A<'!L:6-A=&EO;B]X+65X96-U=&%B;&4M9FEL92<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,5PR,2)=(#T@)V%P<&QI8V%T:6]N+W@M97AE8W5T
M86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPQ7#(Q,")=(#T@)V%P
M<&QI8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;
M,EU;(EPQ7#(Q-R)=(#T@)V%P<&QI8V%T:6]N+W@M;V)J96-T+69I;&4G.PHD
M;6EM95]M86=I8ULP75LR75LB7#%<,C(T(ET@/2`G87!P;&EC871I;VXO>"UE
M>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#%<,C(W(ET@
M/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE+69I;&4G.PHD;6EM95]M86=I
M8ULP75LR75LB7#%<,S,R(ET@/2`G>"]X+6EM86=E+7-G:2<["B1M:6UE7VUA
M9VEC6S!=6S)=6R)<,5PS-B)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA
M9VEC6S!=6S)=6R)<,5PV(ET@/2`G87!P;&EC871I;VXO>"UE>&5C=71A8FQE
M+69I;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#,P-UPQ-C$B72`]("=A<'!L
M:6-A=&EO;B]X+6)C<&EO)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS,3-<-2)=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,U
M,EPQ-#`B72`]("=A<'!L:6-A=&EO;B]X+6%R:B<["B1M:6UE7VUA9VEC6S!=
M6S)=6R)<,S8W7#$S,2)=(#T@)V9O;G0O>"UT97@G.PHD;6EM95]M86=I8ULP
M75LR75LB7#,V-UPR,#,B72`]("=F;VYT+W@M=&5X)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPS-C=<,S$R(ET@/2`G9F]N="]X+71E>"<["B1M:6UE7VUA9VEC
M6S!=6S)=6R)<,S9<,2)=(#T@)V9O;G0O>"UV9F]N="<["B1M:6UE7VUA9VEC
M6S!=6S)=6R)<,S<U7#$V-B)=(#T@)V%P<&QI8V%T:6]N+W@M;'IH)SL*)&UI
M;65?;6%G:6-;,%U;,EU;(EPS-S9<,38V(ET@/2`G87!P;&EC871I;VXO9&%T
M82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<,S<W7#$T-2)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W-UPQ-34B72`]("=A
M<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,%U;,EU;(EPS-S=<,38V
M(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=6R)<
M,S<W7#,S,")=(#T@)VEM86=E+VIP96<G.PHD;6EM95]M86=I8ULP75LR75LB
M7#,W-UPS-R)=(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP
M75LR75LB7#,W7#(Q,R)=(#T@)V%P<&QI8V%T:6]N+W@M9WII<"<["B1M:6UE
M7VUA9VEC6S!=6S)=6R)<,S=<,C,U(ET@/2`G87!P;&EC871I;VXO8V]M<')E
M<W,G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(S-B)=(#T@)V%P<&QI8V%T
M:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(S-R)=(#T@)V%P
M<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W7#(T,")=
M(#T@)V%P<&QI8V%T:6]N+V1A=&$G.PHD;6EM95]M86=I8ULP75LR75LB7#,W
M7#,V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S!=6S)=
M6R)<,S=<,S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;
M,%U;,EU;(EPS-UPS-S<B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?
M;6%G:6-;,%U;,EU;(EPT-5PT,2)=(#T@)V%P<&QI8V%T:6]N+W!O<W1S8W)I
M<'0G.PHD;6EM95]M86=I8ULP75LR75LB7#1<-C8B72`]("=F;VYT+VQI;G5X
M+7!S9B<["B1M:6UE7VUA9VEC6S!=6S)=6R)<-3=<-3<B72`]("=T97AT+V-P
M<"<["B1M:6UE7VUA9VEC6S!=6S)=6R)<-5PQ(ET@/2`G87!P;&EC871I;VXO
M>"UL;V-A;&4G.PHD;6EM95]M86=I8ULP75LR75LB7#9<,2)=(#T@)V%P<&QI
M8V%T:6]N+W@M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,%U;,EU;
M(EPV7#(B72`]("=A<'!L:6-A=&EO;B]X+6%L86XM861V96YT=7)E+6=A;64G
M.PHD;6EM95]M86=I8ULP75LR75LB7#=<,2)=(#T@)V%P<&QI8V%T:6]N+W@M
M97AE8W5T86)L92UF:6QE)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ,C!<,3$V
M7#$P-R)=(#T@)VEM86=E+W@M<&YG)SL*)&UI;65?;6%G:6-;,5U;,UU;(EPQ
M,C=<,3(P7#$P,R)=(#T@)V%P<&QI8V%T:6]N+W9N9"YW;W)D<&5R9F5C="<[
M"B1M:6UE7VUA9VEC6S)=6S9=6R)<-35<,34T7#$U,%PV-%PV,%PU-2)=(#T@
M)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ
M-31<,34P7#$T-%PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?
M;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8P7#4U(ET@/2`G87!P;&EC871I
M;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-3!<-C%<
M-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S5=
M6R)<-35<,34T7#$U,%PV,EPU-2)=(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*
M)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,34P7#8S7#4U(ET@/2`G87!P
M;&EC871I;VXO>"UL:&$G.PHD;6EM95]M86=I8ULR75LU75LB7#4U7#$U-%PQ
M-3!<-C1<-34B72`]("=A<'!L:6-A=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC
M6S)=6S5=6R)<-35<,34T7#$U,%PV-5PU-2)=(#T@)V%P<&QI8V%T:6]N+W@M
M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU-5PQ-31<,3<R7#$V,UPU-2)=
M(#T@)V%P<&QI8V%T:6]N+W@M;&AA)SL*)&UI;65?;6%G:6-;,EU;-5U;(EPU
M-5PQ-31<,3<R7#8T7#4U(ET@/2`G87!P;&EC871I;VXO>"UL:&$G.PHD;6EM
M95]M86=I8ULR75LU75LB7#4U7#$U-%PQ-S)<-C5<-34B72`]("=A<'!L:6-A
M=&EO;B]X+6QH82<["B1M:6UE7VUA9VEC6S)=6S)=6R)<,%PR,2)=(#T@)V9O
M;G0O>"UT97@M=&9M)SL*)&UI;65?;6%G:6-;,EU;,EU;(EPP7#(R(ET@/2`G
M9F]N="]X+71E>"UT9FTG.PHD;6EM95]M86=I8ULT75LT75LB7#$U-5PQ-#1<
M,30Q7#$V-")=(#T@)W9I9&5O+W%U:6-K=&EM92<["B1M:6UE7VUA9VEC6S1=
M6S1=6R)<,34U7#$U-UPQ-3=<,38V(ET@/2`G=FED96\O<75I8VMT:6UE)SL*
M)&UI;65?;6%G:6-;-%U;-%U;(EPQ-C!<,34Q7#$V,%PQ-#4B72`]("=A<'!L
M:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-%U;-%U;(EPQ-C!<,38R7#$U
M-UPQ-#8B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;-%U;
M,EU;(EPR-3=<,C$B72`]("=V:61E;R]F;&DG.PHD;6EM95]M86=I8ULT75LR
M75LB7#(U-UPR,B)=(#T@)W9I9&5O+V9L8R<["B1M:6UE7VUA9VEC6S9=6S$X
M75LB7#0U7#0Q7#$R,%PQ,C-<-35<,3`Q7#$T-%PQ-3=<,30R7#$T-5PQ,#9<
M,34W7#$U-EPQ-C1<-35<-C%<-39<-C`B72`]("=F;VYT+W1Y<&4Q)SL*)&UI
M;65?;6%G:6-;-UU;,C)=6R)<,S4W7#(P7#8P7#8P7#8P7#8P7#8P7#8P7#8P
M7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P7#8P(ET@/2`G
M87!P;&EC871I;VXO8V]R92<["B1M:6UE7VUA9VEC6S==6S1=6R)<,%PQ,#5<
M,3`W7#$P,2)=(#T@)V9O;G0O>"UD;W,G.PHD;6EM95]M86=I8ULW75LT75LB
M7#!<,3(V7#$Q,5PQ,#0B72`]("=F;VYT+W@M9&]S)SL*)&UI;65?;6%G:6-;
M.%U;-%U;(EPR,UPQ-S)<-3-<,3`U(ET@/2`G9F]N="]X+7-U;F]S+6YE=W,G
M.PHD;6EM95]M86=I8ULX75LT75LB7#(S7#$W,EPU,UPQ,3`B72`]("=F;VYT
M+W@M<W5N;W,M;F5W<R<["B1M:6UE7VUA9VEC6S$P75LR-5U;(EPT,UPT,%PQ
M,C1<,34P7#$U,5PQ-C-<-#!<,34Q7#$V,UPT,%PQ-#%<-#!<,38S7#$U,%PQ
M-#5<,34T7#$U-%PT,%PQ-#%<,38R7#$T,UPQ-3!<,34Q7#$V-EPQ-#4B72`]
M("=A<'!L:6-A=&EO;B]X+7-H87(G.PHD;6EM95]M86=I8ULR,%U;-%U;(EPQ
M,#=<,3$Q7#$Q-5PQ,C`B72`]("=A<'!L:6-A=&EO;B]X+6=I;7`M8G)U<V@G
M.PHD;6EM95]M86=I8ULR,%U;-%U;(EPQ,#=<,3(P7#$P,5PQ,C0B72`]("=A
M<'!L:6-A=&EO;B]X+6=I;7`M<&%T=&5R;B<["B1M:6UE7VUA9VEC6S(P75LT
M75LB7#,W-5PS,#1<,C0W7#,S-")=(#T@)V%P<&QI8V%T:6]N+W@M>F]O)SL*
M)&UI;65?;6%G:6-;,C%=6SA=6R)<-#%<,3(S7#$P,UPQ,C)<,3`U7#$P,5PQ
M,35<-#$B72`]("=A=61I;R]X+7-T,BUM;V0G.PHD;6EM95]M86=I8ULR-%U;
M-%U;(EPP7#!<,S4R7#$U,R)=(#T@)V%P<&QI8V%T:6]N+W@M9'5M<"<["B1M
M:6UE7VUA9VEC6S(T75LT75LB7#!<,%PS-3)<,34T(ET@/2`G87!P;&EC871I
M;VXO>"UD=6UP)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<,%PP7#,U,EPQ-34B
M72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G:6-;,C1=6S1=6R)<
M,%PP7#,U,EPQ-38B72`]("=A<'!L:6-A=&EO;B]D871A)SL*)&UI;65?;6%G
M:6-;-C5=6S1=6R)<,3`V7#$P-EPQ,3%<,3$T(ET@/2`G9F]N="]T=&8G.PHD
M;6EM95]M86=I8ULV-5U;-%U;(EPQ,31<,3(W7#$P-EPQ,38B72`]("=F;VYT
M+W1Y<&4Q)SL*)&UI;65?;6%G:6-;,C4W75LX75LB7#$V-5PQ-C-<,38T7#$T
M,5PQ-C)<-#!<-#!<-C`B72`]("=A<'!L:6-A=&EO;B]X+6=T87(G.PHD;6EM
M95]M86=I8ULR-3==6S9=6R)<,38U7#$V,UPQ-C1<,30Q7#$V,EPV,")=(#T@
M)V%P<&QI8V%T:6]N+W@M=&%R)SL*)&UI;65?;6%G:6-;,#<W-%U;,EU;(EPS
M,S)<,C<V(ET@/2`G87!P;&EC871I;VXO9&%T82<["B1M:6UE7VUA9VEC6S$P
M.#!=6S1=6R)<,3`S7#$P-%PW,%PV,2)=(#T@)V%U9&EO+W@M;VMT86QY>F5R
M+6UO9"<["B1M:6UE7VUA9VEC6S$P.#!=6S1=6R)<,3`V7#$Q-%PQ,C1<-C0B
M72`]("=A=61I;R]X+7-T87)T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P
M.#!=6S1=6R)<,3$U7#0Q7#$Q,UPT,2)=(#T@)V%U9&EO+W@M<')O=')A8VME
M<BUM;V0G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#$Q-5PU-EPQ,3-<-38B
M72`]("=A=61I;R]X+7!R;W1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X
M,%U;-%U;(EPQ,3=<,3$S7#$R-%PQ,#$B72`]("=A=61I;R]X+6]K=&%L>7IE
M<BUM;V0G.PHD;6EM95]M86=I8ULQ,#@P75LT75LB7#8Q7#8V7#$P,UPQ,38B
M72`]("=A=61I;R]X+71A:V5T<F%C:V5R+6UO9"<["B1M:6UE7VUA9VEC6S$P
M.#!=6S1=6R)<-C-<-C)<,3`S7#$Q-B)=(#T@)V%U9&EO+W@M=&%K971R86-K
M97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPV-%PQ,#-<,3$P7#$Q
M-B)=(#T@)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G:6-;
M,3`X,%U;-%U;(EPV-EPQ,#-<,3$P7#$Q-B)=(#T@)V%U9&EO+W@M9F%S='1R
M86-K97(M;6]D)SL*)&UI;65?;6%G:6-;,3`X,%U;-%U;(EPW,%PQ,#-<,3$P
M7#$Q-B)=(#T@)V%U9&EO+W@M9F%S='1R86-K97(M;6]D)SL*)&UI;65?;6%G
M:6-;,C`T.%U;-UU;(EPQ,C!<,3`S7#$P-%PQ,S=<,3$Q7#$R,%PQ,3$B72`]
M("=X+W@M<&AO=&\M8V0M<&%C:RUF:6QE)SL*)&UI;65?;6%G:6-;,C`X,%U;
M,CE=6R)<,3$U7#$U,5PQ-#-<,38R7#$U-UPQ-C-<,34W7#$T-EPQ-C1<-#!<
M,3`U7#$W,%PQ-#-<,30U7#$U-%PT,%PV-5PU-EPV,%PT,%PQ,C=<,34W7#$V
M,EPQ-3-<,38S7#$U,%PQ-#5<,30U7#$V-")=(#T@)V%P<&QI8V%T:6]N+W9N
M9"YM<RUE>&-E;"<["B1M:6UE7VUA9VEC6S(P.#!=6S(W75LB7#$Q-5PQ-3%<
M,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ-3=<,38R7#$T
M-%PT,%PV-EPU-EPV,%PT,%PQ,#1<,34W7#$T,UPQ-C5<,34U7#$T-5PQ-39<
M,38T(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC6S(P.#!=
M6S(V75LB7#$P-%PQ-3=<,30S7#$V-5PQ-35<,30U7#$U-EPQ-C1<,34W7#0P
M7#$Q-5PQ-3%<,30S7#$V,EPQ-3=<,38S7#$U-UPQ-#9<,38T7#0P7#$R-UPQ
M-3=<,38R7#$T-%PT,%PV-B)=(#T@)W1E>'0O=FYD+FUS+7=O<F0G.PHD;6EM
M95]M86=I8ULR,3$R75LY75LB7#$Q-5PQ,C-<,3(W7#$U-UPQ-C)<,30T7#$P
M-%PQ-3=<,30S(ET@/2`G=&5X="]V;F0N;7,M=V]R9"<["B1M:6UE7VUA9VEC
M6S(Q,31=6S5=6R)<,3`R7#$U,5PQ-#9<,30V7#8U(ET@/2`G87!P;&EC871I
M;VXO=FYD+FUS+65X8V5L)SL*)&UI;65?;6%G:6-;-#`Y.%U;-UU;(EPQ,#1<
M,3$W7#$R,UPQ,#9<,3$W7#$Q-EPQ,C0B72`]("=F;VYT+W@M9&]S)SL*)&UI
M;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<,C-<,3<W(ET@/2`G87!P;&EC871I
M;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<
M,C-<,C$W(ET@/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?
M;6%G:6-;-C@Q-3@T.#!=6S)=6R)<-#1<,34P(ET@/2`G87!P;&EC871I;VXO
M>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G:6-;-C@Q-3@T.#!=6S)=6R)<-#1<
M,3<P(ET@/2`G87!P;&EC871I;VXO>"UF:6QE<WES=&5M)SL*)&UI;65?;6%G
M:6-;-S`W-SDY-C!=6S)=6R)<,S4W7#$R,R)=(#T@)V%P<&QI8V%T:6]N+W@M
M;&EN=7@M97AT,F9S)SL*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O;V]O````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S<@,#(R,#4R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]D96(N<&AP````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0P-R`Q,#4Q-30S-#$S
M-R`P,C(V,#0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]D96(@8VQA<W,@
M<F5N9&5R<R!O=70@;&ES=',@;V8@9FEL97,@:6X@1&5B:6%N('!A8VMA9V5S
M(&)Y"B`J('5S:6YG('1H92!D<&MG('1O;VP@=&\@<75E<GD@=&AE('!A8VMA
M9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O
M9&5B+G!H<"QV(#$N,3$N,3`N."`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N:6P@36%D:&%V87!E
M9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W
M97(*("HO"F-L87-S($U)345?5FEE=V5R7V1E8B!E>'1E;F1S($U)345?5FEE
M=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!T:&4@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@
M=&AE('9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B
M86P@)&UI;65?9')I=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S
M=7)E('1H92!P<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("!I
M9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V1E8B==
M6R=L;V-A=&EO;B==*2D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N
M('-P<FEN=&8H7R@B5&AE('!R;V=R86T@=7-E9"!T;R!V:65W('1H:7,@9&%T
M82!T>7!E("@E<RD@=V%S(&YO="!F;W5N9"!O;B!T:&4@<WES=&5M+B(I+"`D
M;6EM95]D<FEV97)S6R=H;W)D92==6R=D96(G75LG;&]C871I;VXG72D@+B`G
M/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@("1T;7!?9&5B(#T@2&]R9&4Z
M.F=E=%1E;7!&:6QE*"=H;W)D95]D96(G*3L*"B`@("`@("`@)&9H(#T@9F]P
M96XH)'1M<%]D96(L("=W)RD["B`@("`@("`@9G=R:71E*"1F:"P@)'1H:7,M
M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("`@("`@9F-L;W-E*"1F
M:"D["@H@("`@("`@("1F:"`]('!O<&5N*"1M:6UE7V1R:79E<G-;)VAO<F1E
M)UU;)V1E8B==6R=L;V-A=&EO;B==("X@(B`M9B`D=&UP7V1E8B`R/B8Q(BP@
M)W(G*3L*("`@("`@("!W:&EL92`H*"1R8R`](&9G971S*"1F:"P@.#$Y,BDI
M*2!["B`@("`@("`@("`@("1D871A("X]("1R8SL*("`@("`@("!]"B`@("`@
M("`@<&-L;W-E*"1F:"D["@H@("`@("`@(')E='5R;B`G/'!R93XG("X@:'1M
M;'-P96-I86QC:&%R<R@D9&%T82D@+B`G/"]P<F4^)SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE
M(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<F%R+G!H<```````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,38Q,C8@,3`U,34T,S0Q,S<@,#(R
M-C0P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<F%R(&-L87-S(')E;F1E
M<G,@;W5T('1H92!C;VYT96YT<R!O9B`N<F%R(&%R8VAI=F5S(&EN($A434P*
M("H@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+W)A<BYP:'`L=B`Q+C$X+C$P+CD@,C`P-B\P,2\P,2`R,3HR.#HR
M-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA
M9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P
M961D>2`\86YI;$!R96-O:6PN;W)G/@H@*B!`875T:&]R("!-:6-H865L($-O
M8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(
M;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L
M87-S($U)345?5FEE=V5R7W)A<B!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@
M("`O*BH*("`@("`J(%)A<B!C;VUP<F5S<VEO;B!M971H;V1S+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?;65T:&]D<R`]
M(&%R<F%Y*`H@("`@("`@(#!X,S`@(#T^("`G4W1O<F4G+`H@("`@("`@(#!X
M,S$@(#T^("`G1F%S=&5S="<L"B`@("`@("`@,'@S,B`@/3X@("=&87-T)RP*
M("`@("`@("`P>#,S("`]/B`@)TYO<FUA;"<L"B`@("`@("`@,'@S-"`@/3X@
M("=';V]D)RP*("`@("`@("`P>#,U("`]/B`@)T)E<W0G"B`@("`I.PH*("`@
M("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N=&QY('-E="!C;VYT
M96YT<R!U<VEN9R!R87(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT
M96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1C;VYT96YT<R`]("1T:&ES+3YM:6UE
M7W!A<G0M/F=E=$-O;G1E;G1S*"D["@H@("`@("`@("\J($UA:V4@<W5R92!T
M:&ES(&ES(&$@=F%L:60@<F%R(&9I;&4N("HO"B`@("`@("`@:68@*"1T:&ES
M+3YC:&5C:U)A<D1A=&$H)&-O;G1E;G1S*2`]/3T@9F%L<V4I('L*("`@("`@
M("`@("`@<F5T=7)N("<\<')E/B<@+B!?*")4:&ES(&1O97,@;F]T(&%P<&5A
M<B!T;R!B92!A('9A;&ED(')A<B!A<F-H:79E+B(I("X@)SPO<')E/B<["B`@
M("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U1E>'0N<&AP
M)SL*"B`@("`@("`@)')A<D1A=&$@/2`D=&AI<RT^9V5T4F%R1&%T82@D8V]N
M=&5N=',I.PH@("`@("`@("1F:6QE0V]U;G0@/2!C;W5N="@D<F%R1&%T82D[
M"@H@("`@("`@("1T97AT("`]("<\<W1R;VYG/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*'-P<FEN=&8H7R@B0V]N=&5N=',@;V8@7"(E<UPB(BDL("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$YA;64H*2DI("X@)SH\+W-T<F]N9SXG("X@(EQN(CL*
M("`@("`@("`D=&5X="`N/2`G/'1A8FQE/CQT<CX\=&0@86QI9VX](FQE9G0B
M/CQT=#X\<W!A;B!C;&%S<STB9FEX960B/B<["B`@("`@("`@)'1E>'0@+CT@
M5&5X=#HZ:'1M;$%L;%-P86-E<RA?*")!<F-H:79E($YA;64B*2`N("<Z("`G
M("X@)'1H:7,M/FUI;65?<&%R="T^9V5T3F%M92@I*2`N(")<;B(["B`@("`@
M("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<RA?*")!<F-H:79E($9I
M;&4@4VEZ92(I("X@)SH@)R`N('-T<FQE;B@D8V]N=&5N=',I("X@)R!B>71E
M<R<I("X@(EQN(CL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A
M8V5S*"@D9FEL94-O=6YT("$](#$I(#\@<W!R:6YT9BA?*")&:6QE($-O=6YT
M.B`E<R!F:6QE<R(I+"`D9FEL94-O=6YT*2`Z('-P<FEN=&8H7R@B1FEL92!#
M;W5N=#H@)7,@9FEL92(I+"`D9FEL94-O=6YT*2D["B`@("`@("`@)'1E>'0@
M+CT@(EQN7&XB.PH@("`@("`@("1T97AT("X](%1E>'0Z.FAT;6Q!;&Q3<&%C
M97,H"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B1FEL92!.86UE
M(BDL("`@("`U,"P@)R`G+"!35%)?4$%$7U))1TA4*2`N"B`@("`@("`@("`@
M("`@("`@("`@('-T<E]P860H7R@B071T<FEB=71E<R(I+"`@("`Q,"P@)R`G
M+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A
M9"A?*")3:7IE(BDL("`@("`@("`@(#$P+"`G("<L(%-44E]0041?3$5&5"D@
M+@H@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*%\H(DUO9&EF:65D($1A
M=&4B*2P@,3DL("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@
M("`@("`@('-T<E]P860H7R@B365T:&]D(BDL("`@("`@("`Q,"P@)R`G+"!3
M5%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?
M*")2871I;R(I+"`@("`@("`@("`W+"`G("<L(%-44E]0041?3$5&5"D*("`@
M("`@("`@("`@("`@("`I("X@(EQN(CL*"B`@("`@("`@)'1E>'0@+CT@<W1R
M7W)E<&5A="@G+2<L(#$P-BD@+B`B7&XB.PH*("`@("`@("!F;W)E86-H("@D
M<F%R1&%T82!A<R`D=F%L*2!["B`@("`@("`@("`@("1R871I;R`]("AE;7!T
M>2@D=F%L6R=S:7IE)UTI*2`_(#`@.B`Q,#`@*B`H)'9A;%LG8W-I>F4G72`O
M("1V86Q;)W-I>F4G72D["B`@("`@("`@("`@("1T97AT("X](%1E>'0Z.FAT
M;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@("`@("`@("`@("`@("!S=')?<&%D
M*"1V86Q;)VYA;64G72P@-3`L("<@)RP@4U127U!!1%]224=(5"D@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"@D=F%L6R=A='1R)UTL(#$P
M+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P+"`G("<L(%-44E]0041?3$5&
M5"D@+@H@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"AS=')F=&EM
M92@B)60M)6(M)5D@)4@Z)4TB+"`D=F%L6R=D871E)UTI+"`Q.2P@)R`G+"!3
M5%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P
M860H)'9A;%LG;65T:&]D)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"AS<')I;G1F*"(E,2XQ
M9B4E(BP@)')A=&EO*2P@-RP@)R`G+"!35%)?4$%$7TQ%1E0I"B`@("`@("`@
M("`@("`@("`@("`@("D@+B`B7&XB.PH@("`@("`@('T*"B`@("`@("`@)'1E
M>'0@+CT@<W1R7W)E<&5A="@G+2<L(#$P-BD@+B`B7&XB.PH@("`@("`@("1T
M97AT("X]("<\+W-P86X^/"]T=#X\+W1D/CPO='(^/"]T86)L93XG.PH*("`@
M("`@("!R971U<FX@;FPR8G(H)'1E>'0I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@34E-12!T>7!E(&]F('1H:7,@<&%R="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($U)344@='EP92!O9B!T:&ES
M('!A<G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E
M=$-H87)S970H*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T;R!S
M964@:68@=&AE(&1A=&$@:7,@82!V86QI9"!287(@87)C:&EV92X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("8D9&%T82`@5&AE(')A<B!A<F-H:79E
M(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('9A;&ED+"!F86QS92!I9B!I;G9A;&ED+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C:&5C:U)A<D1A=&$H)B1D871A*0H@("`@>PH@("`@("`@("1F:6QE2&5A
M9&5R(#T@(EQX-3)<>#8Q7'@W,EQX,C%<>#%A7'@P-UQX,#`B.PH@("`@("`@
M(&EF("AS=')P;W,H)&1A=&$L("1F:6QE2&5A9&5R*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@;&ES="!O9B!F:6QE<R]D871A(&9R;VT@=&AE
M(')A<B!A<F-H:79E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)B1D
M871A("!4:&4@<F%R(&%R8VAI=F4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!+15DZ(%!O<VET:6]N(&EN(%)!4B!A<F-H:79E"B`@("`@
M*B`@("`@("`@("`@("`@("!604Q515,Z("=A='1R)R`@("`M+2`@1FEL92!A
M='1R:6)U=&5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=D871E
M)R`@("`M+2`@1FEL92!M;V1I9FEC871I;VX@=&EM90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`G8W-I>F4G("`@+2T@($-O;7!R97-S960@9FEL
M92!S:7IE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("=M971H;V0G
M("`M+2`@0V]M<')E<W-I;VX@;65T:&]D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("=N86UE)R`@("`M+2`@1FEL96YA;64*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@)W-I>F4G("`@("TM("!/<FEG:6YA;"!F:6QE
M('-I>F4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F%R1&%T82@F)&1A=&$I
M"B`@("!["B`@("`@("`@)')E='5R;E]A<G)A>2`](&%R<F%Y*"D["@H@("`@
M("`@("1B;&]C:U-T87)T(#T@<W1R<&]S*"1D871A+"`B7'@U,EQX-C%<>#<R
M7'@R,5QX,6%<>#`W7'@P,"(I.PH@("`@("`@("1P;W-I=&EO;B`]("1B;&]C
M:U-T87)T("L@-SL*"B`@("`@("`@=VAI;&4@*"1P;W-I=&EO;B`\('-T<FQE
M;B@D9&%T82DI('L*("`@("`@("`@("`@)&AE861?8W)C("`@/2!S=6)S='(H
M)&1A=&$L("1P;W-I=&EO;B`K(#`L(#(I.PH@("`@("`@("`@("`D:&5A9%]T
M>7!E("`](&]R9"AS=6)S='(H)&1A=&$L("1P;W-I=&EO;B`K(#(L(#$I*3L*
M("`@("`@("`@("`@)&AE861?9FQA9W,@/2!U;G!A8VLH)W9&;&%G<R<L('-U
M8G-T<B@D9&%T82P@)'!O<VET:6]N("L@,RP@,BDI.PH@("`@("`@("`@("`D
M:&5A9%]F;&%G<R`]("1H96%D7V9L86=S6R=&;&%G<R==.PH@("`@("`@("`@
M("`D:&5A9%]S:7IE("`]('5N<&%C:R@G=E-I>F4G+"!S=6)S='(H)&1A=&$L
M("1P;W-I=&EO;B`K(#4L(#(I*3L*("`@("`@("`@("`@)&AE861?<VEZ92`@
M/2`D:&5A9%]S:7IE6R=3:7IE)UT["@H@("`@("`@("`@("`D<&]S:71I;VX@
M*ST@-SL*("`@("`@("`@("`@)&AE861?<VEZ92`M/2`W.PH*("`@("`@("`@
M("`@<W=I=&-H("@D:&5A9%]T>7!E*2!["@H@("`@("`@("`@("!C87-E(#!X
M-S,Z"B`@("`@("`@("`@("`@("`O*B!!<F-H:79E(&AE861E<B`J+PH@("`@
M("`@("`@("`@("`@)'!O<VET:6]N("L]("1H96%D7W-I>F4["@H@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(#!X-S0Z"B`@("`@
M("`@("`@("`@("`D9FEL92`](&%R<F%Y*"D["@H@("`@("`@("`@("`@("`@
M+RH@1FEL92!(96%D97(@*B\*("`@("`@("`@("`@("`@("1I;F9O(#T@=6YP
M86-K*"=64&%C:V5D+U95;G!A8VME9"]#3U,O5D-20S,R+U94:6UE+T-697)S
M:6]N+T--971H;V0O=DQE;F=T:"]V071T<FEB)RP@<W5B<W1R*"1D871A+"`D
M<&]S:71I;VXI*3L*"B`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@
M<W5B<W1R*"1D871A+"`D<&]S:71I;VX@*R`R-2P@)&EN9F];)TQE;F=T:"==
M*3L*("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`D:6YF;ULG56YP
M86-K960G73L*("`@("`@("`@("`@("`@("1F:6QE6R=C<VEZ92==(#T@)&EN
M9F];)U!A8VME9"==.PH*("`@("`@("`@("`@("`@("1F:6QE6R=D871E)UT@
M/2!M:W1I;64H*"@D:6YF;ULG5&EM92==(#X^(#$Q*2`F(#!X,68I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H*"1I;F9O6R=4
M:6UE)UT@/CX@-2D@)B`P>#-F*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*"@D:6YF;ULG5&EM92==(#P\(#$I("8@,'@S92DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@H)&EN
M9F];)U1I;64G72`^/B`R,2D@)B`P>#`W*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*"@D:6YF;ULG5&EM92==(#X^(#$V*2`F
M(#!X,68I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H*"@D:6YF;ULG5&EM92==(#X^(#(U*2`F(#!X-V8I("L@.#`I*3L*"B`@
M("`@("`@("`@("`@("`D9FEL95LG;65T:&]D)UT@/2`D=&AI<RT^7VUE=&AO
M9'-;)&EN9F];)TUE=&AO9"==73L*"B`@("`@("`@("`@("`@("`D9FEL95LG
M871T<B==("`]("<G.PH@("`@("`@("`@("`@("`@)&9I;&5;)V%T='(G72`N
M/2`H)&EN9F];)T%T=')I8B==("8@,'@Q,"D@/R`G1"<@.B`G+2<["B`@("`@
M("`@("`@("`@("`D9FEL95LG871T<B==("X]("@D:6YF;ULG071T<FEB)UT@
M)B`P>#(P*2`_("=!)R`Z("<M)SL*("`@("`@("`@("`@("`@("1F:6QE6R=A
M='1R)UT@+CT@*"1I;F9O6R=!='1R:6(G72`F(#!X,#,I(#\@)U,G(#H@)RTG
M.PH@("`@("`@("`@("`@("`@)&9I;&5;)V%T='(G72`N/2`H)&EN9F];)T%T
M=')I8B==("8@,'@P,BD@/R`G2"<@.B`G+2<["B`@("`@("`@("`@("`@("`D
M9FEL95LG871T<B==("X]("@D:6YF;ULG071T<FEB)UT@)B`P>#`Q*2`_("=2
M)R`Z("<M)SL*"B`@("`@("`@("`@("`@("`D<F5T=7)N7V%R<F%Y6UT@/2`D
M9FEL93L*"B`@("`@("`@("`@("`@("`D<&]S:71I;VX@*ST@)&AE861?<VEZ
M93L*("`@("`@("`@("`@("`@("1P;W-I=&EO;B`K/2`D:6YF;ULG4&%C:V5D
M)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("`D<&]S:71I;VX@*ST@)&AE861?<VEZ93L*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D7W-I>F4I*2!["B`@("`@
M("`@("`@("`@("`@("`@)'!O<VET:6]N("L]("1A9&1?<VEZ93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FY?87)R87D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]R9F,X,C(N<&AP````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C4P,"`Q,#4Q-30S-#$S-R`P
M,C,P-34`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]R9F,X,C(@8VQA<W,@
M<F5N9&5R<R!O=70@;65S<V%G97,@9G)O;2!T:&4*("H@;65S<V%G92]R9F,X
M,C(@8V]N=&5N="!T>7!E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+W)F8S@R,BYP:'`L=B`Q+C@N,3`N."`R,#`V+S`Q+S`Q
M(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+V=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@
M/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J($!S:6YC92`@($AO
M<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA
M<W,@34E-15]6:65W97)?<F9C.#(R(&5X=&5N9',@34E-15]6:65W97(@>PH*
M("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N=&QY('-E="!C
M;VYT96YT<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M06X@87)R87D@=VET:"!A;GD@<&%R86UE=&5R<R!N965D960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E9"!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@)'!A<G0@/2`D=&AI<RT^;6EM95]P87)T.PH@("`@("`@
M("1P87)T+3YT<F%N<V9E<D1E8V]D94-O;G1E;G1S*"D["@H@("`@("`@("1T
M97AT(#T@)'!A<G0M/F=E=$-O;G1E;G1S*"D["B`@("`@("`@:68@*"$D=&5X
M="D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP)SL*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)FYE=R!-24U%
M7T-O;G1E;G1S*&YE=R!-24U%7U!A<G0H*2D["B`@("`@("`@("`@(')E='5R
M;B`D8V]N=&5N=',M/F9O<FUA=%-T871U<TUS9RA?*")4:&5R92!W87,@86X@
M97)R;W(@9&ES<&QA>6EN9R!T:&ES(&UE<W-A9V4@<&%R="(I*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1E>'0["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!A='1A8VAM96YT
M(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R
M86US("!!;B!A<G)A>2!W:71H(&%N>2!P87)A;65T97)S(&YE961E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D('1E>'0@
M:6X@2%1-3"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R071T86-H;65N
M=$EN9F\H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&US9R`]
M("<G.PH*("`@("`@("`O*B!'970@=&AE('1E>'0@;V8@=&AE('!A<G0N("!3
M:6YC92!W92!N965D('1O(&QO;VL@9F]R('1H92!E;F0@;V8*("`@("`@("`@
M*B!T:&4@:&5A9&5R<R!B>2!S96%R8VAI;F<@9F]R('1H92!#4DQ&0U),1B!S
M97%U96YC92P@=7-E"B`@("`@("`@("H@9V5T0V%N;VYI8V%L0V]N=&5N=',H
M*2!T;R!M86ME('-U<F4@=V4@87)E(&=E='1I;F<@=&AE('1E>'0@=VET:`H@
M("`@("`@("`J($-23$8G<RX@*B\*("`@("`@("`D=&5X="`]("1T:&ES+3YM
M:6UE7W!A<G0M/F=E=$-A;F]N:6-A;$-O;G1E;G1S*"D["@H@("`@("`@("\J
M(%-E87)C:"!F;W(@=&AE(&5N9"!O9B!T:&4@:&5A9&5R('1E>'0@*$-23$9#
M4DQ&*2X@*B\*("`@("`@("`D=&5X="`]('-U8G-T<B@D=&5X="P@,"P@<W1R
M<&]S*"1T97AT+"`B7')<;EQR7&XB*2D["@H@("`@("`@("\J($=E="!T:&4@
M;&ES="!O9B!H96%D97)S(&YO=RX@*B\*("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TU)344O4W1R=6-T=7)E+G!H<"<["B`@("`@("`@)&AE861E<G,@
M/2!-24U%7U-T<G5C='5R93HZ<&%R<V5-24U%2&5A9&5R<R@D=&5X="P@=')U
M92P@=')U92D["@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]#
M;VYT96YT<RYP:'`G.PH@("`@("`@("1C;VYT96YT<R`]("9N97<@34E-15]#
M;VYT96YT<RAN97<@34E-15]087)T*"DI.PH@("`@("`@("1M<V<@/2`D8V]N
M=&5N=',M/F9O<FUA=%-T871U<TUS9RA?*")4:&4@9F]L;&]W:6YG(&%R92!T
M:&4@:&5A9&5R<R!F;W(@=&AI<R!M97-S86=E+W)F8S@R,B!M97-S86=E+B(I
M+"!(;W)D93HZ:6UG*"=I;F9O7VEC;VXN<&YG)RP@7R@B26YF;R(I+"`G:&5I
M9VAT/2(Q-B(@=VED=&@](C$V(B<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG
M971);6%G941I<B@G:&]R9&4G*2DL(&9A;'-E*3L*"B`@("`@("`@)&US9R`N
M/2`G/'-P86X@8VQA<W,](F9I>&5D(CXG.PH*("`@("`@("`D:&5A9&5R7V%R
M<F%Y(#T@87)R87DH"B`@("`@("`@("`@("=D871E)R`]/B!?*")$871E(BDL
M"B`@("`@("`@("`@("=S=6)J96-T)R`]/B!?*")3=6)J96-T(BDL"B`@("`@
M("`@("`@("=F<F]M)R`]/B!?*")&<F]M(BDL"B`@("`@("`@("`@("=T;R<@
M/3X@7R@B5&\B*0H@("`@("`@("D["B`@("`@("`@)&AE861E<E]O=71P=70@
M/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D:&5A9&5R7V%R<F%Y(&%S
M("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&AE861E
M<G-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&AE
M861E<G-;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@)&AE861E<G-;
M)&ME>5T@/2`D:&5A9&5R<ULD:V5Y75LP73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1H96%D97)?;W5T<'5T6UT@/2`G/'-T<F]N9SXG
M("X@)'9A;"`N("<Z/"]S=')O;F<^("<@+B`D:&5A9&5R<ULD:V5Y73L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(
M;W)D92]497AT+T9I;'1E<BYP:'`G.PH@("`@("`@("1M<V<@+CT@:6UP;&]D
M92@B/&)R("\^7&XB+"!497AT7T9I;'1E<CHZ9FEL=&5R*"1H96%D97)?;W5T
M<'5T+"`G96UA:6QS)RDI("X@)SPO<W!A;CXG.PH*("`@("`@("!R971U<FX@
M)&US9SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C
M;VYT96YT('1Y<&4@9F]R('1H92!R96YD97)E9"!D871A+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@
M("`@("!R971U<FX@)W1E>'0O<&QA:6X[(&-H87)S970])R`N($Y,4SHZ9V5T
M0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<&QA:6XN<&AP````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4T-S8@,3`U,34T,S0Q,S<@
M,#(S,38U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<&QA:6X@8VQA<W,@
M<F5N9&5R<R!O=70@<&QA:6X@=&5X="!W:71H(%523',@;6%D90H@*B!I;G1O
M(&AY<&5R;&EN:W,@*&EF('9I97=I;F<@:6YL:6YE*2X*("H*("H@)$AO<F1E
M.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]P;&%I;BYP:'`L=B`Q+C$X
M+C8N,3`@,C`P-B\P,2\R,R`Q-3HS-3HP-B!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L
M=7-A<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*
M("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)
M345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]P;&%I;B!E>'1E;F1S
M($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE
M(&-O;G1E;G1S+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N
M=&5N=',N<&AP)SL*"B`@("`@("`@)'1E>'0@/2`D=&AI<RT^;6EM95]P87)T
M+3YG971#;VYT96YT<R@I.PH*("`@("`@("`O*B!#:&5C:R!F;W(@)V9L;W=E
M9"<@=&5X="!D871A+B`J+PH@("`@("`@("1F;&]W960@/2`H)'1H:7,M/FUI
M;65?<&%R="T^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)V9O<FUA="<I(#T]
M("=F;&]W960G*3L*("`@("`@("!I9B`H)&9L;W=E9"D@>PH@("`@("`@("`@
M("`D=&5X="`]("1T:&ES+3Y?9F]R;6%T1FQO=V5D*"1T97AT*3L*("`@("`@
M("!]"@H@("`@("`@("\J($EF(&-A;&QI;F<@87,@86X@871T86-H;65N="!F
M<F]M('9I97<N<&AP+"!W92!D;R!N;W0@=V%N=`H@("`@("`@("`@('1O(&%L
M=&5R('1H92!T97AT(&EN(&%N>2!W87D@=VET:"!(5$U,+B`J+PH@("`@("`@
M(&EF("A-24U%7T-O;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T97AT.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O5&5X="]&:6QT97(N<&AP)SL*
M("`@("`@("`@("`@<F5T=7)N(%1E>'1?1FEL=&5R.CIF:6QT97(H)'1E>'0L
M("=T97AT,FAT;6PG+"!A<G)A>2@G<&%R<V5L979E;"<@/3X@5$585%](5$U,
M7TU)0U)/+"`G8VAA<G-E="<@/3X@;G5L;"P@)V-L87-S)R`]/B!N=6QL*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-
M24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O
M9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*
M("`@('L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N
M=',N<&AP)SL*("`@("`@("!R971U<FX@*$U)345?0V]N=&5N=',Z.G9I97=!
M<T%T=&%C:&UE;G0H*2D@/R`D=&AI<RT^;6EM95]P87)T+3YG9714>7!E*'1R
M=64I(#H@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W)M870@9FQO=V5D('1E>'0@
M9F]R($A434P@;W5T<'5T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("`@5&AE('1E>'0@=&\@9F]R;6%T+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&]P="`@("!4:&4@;W!T:6UA;"!L96YG=&@@=&\@=W)A<"X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1M87@@("`@5&AE(&UA>&EM=6T@;&5N9W1H
M('1O('=R87`N(#`@;65A;G,@9&]N)W0@=W)A<"X*("`@("`J($!P87)A;2!B
M;V]L96%N("1D96QS<"`@5V%S('1E>'0@8W)E871E9"!W:71H($1E;%-P(&9O
M<FUA='1I;F<_"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F
M;W)M871T960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA=$9L
M;W=E9"@D=&5X="P@)&]P="`](&YU;&PL("1M87@@/2!N=6QL+"`D9&5L<W`@
M/2!N=6QL*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G5&5X="]&;&]W
M960N<&AP)SL*("`@("`@("`D9FQO=V5D(#T@)FYE=R!497AT7T9L;W=E9"@D
M=&AI<RT^;6EM95]P87)T+3YR97!L86-E14],*"1T97AT+"`B7&XB*2P@)'1H
M:7,M/FUI;65?<&%R="T^9V5T0VAA<G-E="@I*3L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&]P="DI('L*("`@("`@("`@("`@)&9L;W=E9"T^<V5T3W!T3&5N
M9W1H*"1O<'0I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&UA
M>"DI('L*("`@("`@("`@("`@)&9L;W=E9"T^<V5T36%X3&5N9W1H*"1M87@I
M.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)&1E;'-P*2D@>PH@
M("`@("`@("`@("`D9FQO=V5D+3YS971$96Q3<"@D9&5L<W`I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)&9L;W=E9"T^=&]&:7AE9"@I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]C<W,N<&AP````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-C<P-2`Q,#4Q-30S-#$S-R`P,C(V-#8`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"G)E<75I
M<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O<V]U<F-E+G!H<"<["@HO
M*BH*("H@5&AE($U)345?5FEE=V5R7V-S<R!C;&%S<R!R96YD97)S($-34R!S
M;W5R8V4@87,@2%1-3"!W:71H(&%N(&5F9F]R=`H@*B!T;R!R96UO=F4@<&]T
M96YT:6%L;'D@;6%L:6-I;W5S(&-O9&4N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+TU)344O34E-12]6:65W97(O8W-S+G!H<"QV(#$N,2XQ,"XX(#(P,#8O
M,#8O,#$@,#,Z,#@Z-3,@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#0M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7V-S
M<R!E>'1E;F1S($U)345?5FEE=V5R7W-O=7)C92!["@H@("`@+RHJ"B`@("`@
M*B!296YD97(@;W5T('1H92!C=7)R96YT;'D@<V5T(&-O;G1E;G1S+@H@("`@
M("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R
M<R!T:&4@=FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F5N9&5R960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5N9&5R*"1P87)A;7,@/2!N=6QL*0H@("`@>PH@("`@("`@("1C<W,@
M/2!H=&UL<W!E8VEA;&-H87)S*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E
M;G1S*"DL($5.5%].3U%53U1%4RD["B`@("`@("`@)&-S<R`]('!R96=?<F5P
M;&%C95]C86QL8F%C:R@G(2A]?%PJ+RDN*C\H>WPO7"HI(7,G+"!A<G)A>2@D
M=&AI<RP@)U]H86YD;&5S)RDL("1C<W,I.PH@("`@("`@("1C<W,@/2!P<F5G
M7W)E<&QA8V5?8V%L;&)A8VLH)R%[6UY]72I](7,G+"!A<G)A>2@D=&AI<RP@
M)U]A='1R:6)U=&5S)RDL("1C<W,I.PH@("`@("`@("1C<W,@/2!P<F5G7W)E
M<&QA8V5?8V%L;&)A8VLH)R$O7"HN*C]<*B\A<R<L(&%R<F%Y*"1T:&ES+"`G
M7V-O;6UE;G1S)RDL("1C<W,I.PH@("`@("`@("1C<W,@/2!T<FEM*"1C<W,I
M.PH*("`@("`@("`O+R!%9'5C871E9"!'=65S<R!A="!W:&5T:&5R('=E(&%R
M92!I;FQI;F4@;W(@;F]T+@H@("`@("`@(&EF("AH96%D97)S7W-E;G0H*2!\
M?"!O8E]G971?;&5N9W1H*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YL:6YE3G5M8F5R*"1C<W,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D1TQ/
M0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N
M("<O8V]M;6]N+6AE861E<BYI;F,G*2`N"B`@("`@("`@("`@("`@("`D=&AI
M<RT^;&EN94YU;6)E<B@D8W-S*2`N"B`@("`@("`@("`@("`@("!5=&EL.CIB
M=69F97)/=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+69O;W1E<BYI
M;F,G*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7V-O;6UE;G1S
M*"1M871C:&5S*0H@("`@>PH@("`@("`@("1P871T97)N<UM=(#T@)R$H:'1T
M<#HO+ULO7'<M+ETK*2%S)SL*("`@("`@("`D<F5P;&%C97-;72`]("<\82!H
M<F5F/2)<7#$B/EQ<,3PO83XG.PH*("`@("`@("`D8V]M;65N=',@/2!P<F5G
M7W)E<&QA8V4H)'!A='1E<FYS+"`D<F5P;&%C97,L("1M871C:&5S6S!=*3L*
M"B`@("`@("`@<F5T=7)N("<\<W!A;B!C;&%S<STB8V]M;65N="(^)R`N("1C
M;VUM96YT<R`N("<\+W-P86X^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?871T
M<FEB=71E<R@D;6%T8VAE<RD*("`@('L*("`@("`@("`O+R!!='1R:6)U=&5S
M+@H@("`@("`@("1P871T97)N<UM=(#T@)R$H6RU<=UTK7',J*3HA<R<["B`@
M("`@("`@)')E<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,](F%T='(B(CY<7#$\
M+W-P86X^.B<["@H@("`@("`@("\O(%9A;'5E<RX*("`@("`@("`D<&%T=&5R
M;G-;72`]("<A.BA<<RHI*"XK/RDH7',J.RDA<R<["B`@("`@("`@)')E<&QA
M8V5S6UT@/2`G.EQ<,3QS<&%N(&-L87-S/2)V86QU92(^7%PR/"]S<&%N/CQS
M<&%N(&-L87-S/2)E;VPB/EQ<,SPO<W!A;CXG.PH*("`@("`@("`O+R!54DQS
M+@H@("`@("`@("1P871T97)N<UM=(#T@)R$H=7)L7"A;7"<B73\I*"XJ/RDH
M6UPG(ET_7"DI(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L
M87-S/2)U<FPB/EQ<,3QS<&%N(&-L87-S/2)F:6QE(CY<7#(\+W-P86X^7%PS
M/"]S<&%N/B<["@H@("`@("`@("\O($-O;&]R<RX*("`@("`@("`D<&%T=&5R
M;G-;72`]("<A*"-;6SIX9&EG:70Z75U[,RPV?2DA<R<["B`@("`@("`@)')E
M<&QA8V5S6UT@/2`G/'-P86X@8VQA<W,](F-O;&]R(CY<7#$\+W-P86X^)SL*
M"B`@("`@("`@+R\@4&%R96YT:&5S97,N"B`@("`@("`@)'!A='1E<FYS6UT@
M/2`G(2A[?'TI(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L
M87-S/2)P87)E;G1H97-E<R(^7%PQ/"]S<&%N/B<["@H@("`@("`@("\O(%5N
M:71Y+@H@("`@("`@("1P871T97)N<UM=(#T@)R$H96U\<'A\)2E<8B%S)SL*
M("`@("`@("`D<F5P;&%C97-;72`]("<\96T^7%PQ/"]E;3XG.PH*("`@("`@
M("!R971U<FX@<')E9U]R97!L86-E*"1P871T97)N<RP@)')E<&QA8V5S+"`D
M;6%T8VAE<ULP72D["B`@("!]"@H@("`@9G5N8W1I;VX@7VAA;F1L97,H)&UA
M=&-H97,I"B`@("!["B`@("`@("`@+R\@2%1-3"!486=S+@H@("`@("`@("1P
M871T97)N<UM=(#T@)R%<8BAB;V1Y?&A<9'QA?'-P86Y\9&EV?&%C<F]N>6U\
M<VUA;&Q\<W1R;VYG?&5M?'!R97QU;'QO;'QL:7QP*5QB(7,G.PH@("`@("`@
M("1R97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)H=&%G(CY<7#$\+W-P86X^
M7%PR)SL*"B`@("`@("`@+R\@241S+@H@("`@("`@("1P871T97)N<UM=(#T@
M)R$H(ULM7'==*RDA<R<["B`@("`@("`@)')E<&QA8V5S6UT@/2`G/'-P86X@
M8VQA<W,](FED(CY<7#$\+W-P86X^)SL*"B`@("`@("`@+R\@0VQA<W,N"B`@
M("`@("`@)'!A='1E<FYS6UT@/2`G(2A<+ELM7'==*RE<8B%S)SL*("`@("`@
M("`D<F5P;&%C97-;72`]("<\<W!A;B!C;&%S<STB8VQA<W,B/EQ<,3PO<W!A
M;CXG.PH*("`@("`@("`O+R!-151!<RX*("`@("`@("`D<&%T=&5R;G-;72`]
M("<A*#IL:6YK?#IV:7-I=&5D?#IH;W9E<GPZ86-T:79E?#IF:7)S="UL971T
M97(I(7,G.PH@("`@("`@("1R97!L86-E<UM=(#T@)SQS<&%N(&-L87-S/2)M
M971A8R(^7%PQ/"]S<&%N/B<["@H@("`@("`@(')E='5R;B!P<F5G7W)E<&QA
M8V4H)'!A='1E<FYS+"`D<F5P;&%C97,L("1M871C:&5S6S!=*3L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O96YS8W)I<'0N<&AP````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#<V-34@,3`U,34T,S0Q,S<@,#(S-S$R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W-O=7)C92YP:'`G.PH*
M+RHJ"B`J(%1H92!-24U%7U9I97=E<E]E;G-C<FEP="!C;&%S<R!R96YD97)S
M(&]U="!V87)I;W5S(&-O;G1E;G0*("H@:6X@2%1-3"!F;W)M870@8GD@=7-I
M;F<@1TY5($5N<V-R:7!T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%
M+TU)344O5FEE=V5R+V5N<V-R:7!T+G!H<"QV(#$N,SDN,3`N."`R,#`V+S`V
M+S`Q(#`S.C`X.C4S(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA
M;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?
M96YS8W)I<'0@97AT96YD<R!-24U%7U9I97=E<E]S;W5R8V4@>PH*("`@("\J
M*@H@("`@("H@4F5N9&5R(&]U="!T:&4@9&%T82!U<VEN9R!%;G-C<FEP="X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M
M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!G;&]B86P@)&UI;65?9')I=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@=&\@
M;6%K92!S=7)E('1H92!P<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@
M("`@("!I9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)V5N<V-R:7!T)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R
M;B`G/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I
M97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S
M>7-T96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)V5N<V-R:7!T)UU;
M)VQO8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`O
M*B!#<F5A=&4@=&5M<&]R87)Y(&9I;&5S(&9O<B!I;G!U="!T;R!%;G-C<FEP
M="X@3F]T92!T:&%T('=E"B`@("`@("`@("`@8V%N;F]T('5S92!A('!I<&4L
M('-I;F-E(&5N<V-R:7!T(&UU<W0@:&%V92!A8V-E<W,@=&\@=&AE"B`@("`@
M("`@("`@=VAO;&4@9FEL92!T;R!D971E<FUI;F4@:71S('1Y<&4@9F]R(&-O
M;&]U<F5D('-Y;G1A>`H@("`@("`@("`@(&AI9VAL:6=H=&EN9RX@*B\*("`@
M("`@("`D=&UP:6X@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)T5N<V-R:7!T26XG
M*3L*"B`@("`@("`@+RH@5W)I=&4@=&AE(&-O;G1E;G1S(&]F(&]U<B!B=69F
M97(@=&\@=&AE('1E;7!O<F%R>2!I;G!U="!F:6QE+B`J+PH@("`@("`@("1C
M;VYT96YT<R`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"D["B`@
M("`@("`@)&9H(#T@9F]P96XH)'1M<&EN+"`G=V(G*3L*("`@("`@("!F=W)I
M=&4H)&9H+"`D8V]N=&5N=',L('-T<FQE;B@D8V]N=&5N=',I*3L*("`@("`@
M("!F8VQO<V4H)&9H*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@96YS8W)I
M<'0@8V]M;6%N9"X@*B\*("`@("`@("`D;&%N9R`](&5S8V%P97-H96QL87)G
M*"1T:&ES+3Y?='EP951O3&%N9R@D=&AI<RT^;6EM95]P87)T+3YG9714>7!E
M*"DI*3L*("`@("`@("`D<F5S=6QT<R`]('-H96QL7V5X96,H)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG96YS8W)I<'0G75LG;&]C871I;VXG72`N("(@+44D
M;&%N9R`M+6QA;F=U86=E/6AT;6P@+2UC;VQO<B`M+6]U='!U=#TM(#P@)'1M
M<&EN(BD["@H@("`@("`@("\J(%-T<FEP(&]U="!T:&4@97AT<F%N96]U<R!(
M5$U,(&9R;VT@16YS8W)I<'0L(&%N9"!O=71P=70@:70N("HO"B`@("`@("`@
M)')E<U]A<G(@/2!P<F5G7W-P;&ET*"<O7#Q<+S]P<F5</B]I)RP@)')E<W5L
M=',I.PH@("`@("`@(&EF("AC;W5N="@D<F5S7V%R<BD@/3T@,RD@>PH@("`@
M("`@("`@("`D<F5S=6QT<R`]('1R:6TH)')E<U]A<G);,5TI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@161U8V%T960@1W5E<W,@870@=VAE=&AE<B!W92!A
M<F4@:6YL:6YE(&]R(&YO="X@*B\*("`@("`@("!I9B`H:&5A9&5R<U]S96YT
M*"D@?'P@;V)?9V5T7VQE;F=T:"@I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT<RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(%5T:6PZ.F)U9F9E<D]U='!U="@G<F5Q=6ER
M92<L("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)W1E;7!L871E<R<L("=H
M;W)D92<I("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<I("X*("`@("`@("`@("`@
M("`@("1T:&ES+3YL:6YE3G5M8F5R*"1R97-U;'1S*2`N"B`@("`@("`@("`@
M("`@("!5=&EL.CIB=69F97)/=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG
M<F5G:7-T<GDG72T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M
M;6]N+69O;W1E<BYI;F,G*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!='1E;7!T<R!T;R!D971E<FUI;F4@=VAA="!L86YG=6%G92!T;R!U
M<V4@9F]R('1H92!E;G-C<FEP="!P<F]G<F%M"B`@("`@*B!F<F]M(&$@34E-
M12!T>7!E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@(%1H92!-24U%('1Y<&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!E;G-C<FEP="`G;&%N
M9W5A9V4G('!A<F%M971E<B!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]T>7!E5&],86YG*"1T>7!E*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC
M92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO36%G:6,N<&AP)SL*"B`@("`@
M("`@)&5X="`]($U)345?36%G:6,Z.DU)3454;T5X="@D='EP92D["@H@("`@
M("`@('-W:71C:"`H)&5X="D@>PH@("`@("`@(&-A<V4@)V-S)SH*("`@("`@
M("`@("`@<F5T=7)N("=J879A)SL*"B`@("`@("`@8V%S92`G96PG.@H@("`@
M("`@("`@("!R971U<FX@)V5L:7-P)SL*"B`@("`@("`@8V%S92`G:"<Z"B`@
M("`@("`@("`@(')E='5R;B`G8R<["@H@("`@("`@(&-A<V4@)T,G.@H@("`@
M("`@(&-A<V4@)T@G.@H@("`@("`@(&-A<V4@)V-C)SH*("`@("`@("!C87-E
M("=H:"<Z"B`@("`@("`@8V%S92`G8RLK)SH*("`@("`@("!C87-E("=C>'@G
M.@H@("`@("`@(&-A<V4@)V-P<"<Z"B`@("`@("`@("`@(')E='5R;B`G8W!P
M)SL*"B`@("`@("`@8V%S92`G:'1M)SH*("`@("`@("!C87-E("=S:'1M;"<Z
M"B`@("`@("`@8V%S92`G>&UL)SH*("`@("`@("`@("`@<F5T=7)N("=H=&UL
M)SL*"B`@("`@("`@8V%S92`G:G,G.@H@("`@("`@("`@("!R971U<FX@)VIA
M=F%S8W)I<'0G.PH*("`@("`@("!C87-E("=P87,G.@H@("`@("`@("`@("!R
M971U<FX@)W!A<V-A;"<["@H@("`@("`@(&-A<V4@)V%L)SH*("`@("`@("!C
M87-E("=C9VDG.@H@("`@("`@(&-A<V4@)W!L)SH*("`@("`@("!C87-E("=P
M;2<Z"B`@("`@("`@("`@(')E='5R;B`G<&5R;"<["@H@("`@("`@(&-A<V4@
M)W!S)SH*("`@("`@("`@("`@<F5T=7)N("=P;W-T<V-R:7!T)SL*"B`@("`@
M("`@8V%S92`G=F(G.@H@("`@("`@("`@("!R971U<FX@)W9B82<["@H@("`@
M("`@(&-A<V4@)W9H9"<Z"B`@("`@("`@("`@(')E='5R;B`G=FAD;"<["@H@
M("`@("`@(&-A<V4@)W!A=&-H)SH*("`@("`@("!C87-E("=D:69F)SH*("`@
M("`@("`@("`@<F5T=7)N("=D:69F=2<["@H@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@(')E='5R;B`D97AT.PH@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O:6UA9V5S+G!H
M<```````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8V,3$@,3`U,34T,S0Q
M,S<@,#(S,S$W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?:6UA9V5S(&-L
M87-S(&%L;&]W<R!I;6%G97,@=&\@8F4@9&ES<&QA>65D+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+VEM86=E<RYP:'`L=B`Q
M+C$X+C@N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B
M:6=W;W)M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J($!P86-K86=E($AO<F1E
M7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]I;6%G97,@97AT
M96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE
M(&-O;G1E;G0M='EP92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&-O;G1E;G0M='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("`D='EP92`]("1T:&ES
M+3YM:6UE7W!A<G0M/F=E=%1Y<&4H*3L*("`@("`@("!I9B`H)$=,3T)!3%-;
M)V)R;W=S97(G72T^:7-"<F]W<V5R*"=M;WII;&QA)RD@)B8*("`@("`@("`@
M("`@*"1T>7!E(#T]("=I;6%G92]P:G!E9R<I*2!["B`@("`@("`@("`@("\J
M(&EM86=E+VIP96<@86YD(&EM86=E+W!J<&5G("IA<'!E87(J('1O(&)E('1H
M92!S86UE"B`@("`@("`@("`@("`J(&5N=&ET>2P@8G5T($UO>FEL;&$@9&]N
M)W0@<V5E;2!T;R!W86YT('1O(&%C8V5P="!T:&4*("`@("`@("`@("`@("H@
M;&%T=&5R+B`@1F]R(&]U<B!P=7)P;W-E<RP@=V4@=VEL;"!T<F5A="!T:&5M
M('1H90H@("`@("`@("`@("`@*B!S86UE+B`J+PH@("`@("`@("`@("!R971U
M<FX@)VEM86=E+VIP96<G.PH@("`@("`@('T@96QS96EF("@D='EP92`]/2`G
M:6UA9V4O>"UP;F<G*2!["B`@("`@("`@("`@("\J(&EM86=E+W@M<&YG(&ES
M(&5Q=6EV86QE;G0@=&\@:6UA9V4O<&YG+B`J+PH@("`@("`@("`@("!R971U
M<FX@)VEM86=E+W!N9R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("1T>7!E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($=E;F5R871E($A434P@;W5T<'5T(&9O<B!A(&IA=F%S8W)I<'0@875T;RUR
M97-I>F4@=FEE=R!W:6YD;W<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7)L("`@(%1H92!5
M4DP@=VAI8V@@8V]N=&%I;G,@=&AE(&%C='5A;"!I;6%G92!D871A+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&ET;&4@(%1H92!T:71L92!T;R!U<V4@9F]R
M('1H92!P86=E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M2%1-3"!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P;W!U<$EM86=E
M5VEN9&]W*"1U<FPL("1T:71L92D*("`@('L*("`@("`@("!G;&]B86P@)&)R
M;W=S97(["@H@("`@("`@("1S='(@/2`\/#Q%3T0*/&AT;6P^"CQH96%D/@H\
M=&ET;&4^)'1I=&QE/"]T:71L93X*/'-T>6QE('1Y<&4](G1E>'0O8W-S(CX\
M(2TM(&)O9'D@>R!M87)G:6XZ,'!X.R!P861D:6YG.C!P>#L@?2`M+3X\+W-T
M>6QE/@I%3T0["@H@("`@("`@("\J($]N;'D@=7-E(&IA=F%S8W)I<'0@:68@
M=V4@87)E('5S:6YG(&$@1$]-(&-A<&%B;&4@8G)O=W-E<BX@*B\*("`@("`@
M("!I9B`H)&)R;W=S97(M/F=E=$9E871U<F4H)V1O;2<I*2!["B`@("`@("`@
M("`@("\J(%1R86YS;&%T92`G)F%M<"<@96YT:71I97,@=&\@)R8G(&9O<B!*
M4R!54DP@;&EN:W,N("HO"B`@("`@("`@("`@("1U<FP@/2!S=')?<F5P;&%C
M92@G)F%M<#LG+"`G)B<L("1U<FPI.PH*("`@("`@("`@("`@+RH@36]Z:6QL
M82!A;F0@244@9&5T97)M:6YE('=I;F1O=R!D:6UE;G-I;VYS(&EN(&1I9F9E
M<F5N="!W87ES+B`J+PH@("`@("`@("`@("!I9B`H)&)R;W=S97(M/FES0G)O
M=W-E<B@G;7-I92<I*2!["B`@("`@("`@("`@("`@("`D:5=I9'1H7V-O9&4@
M/2`G9&]C=6UE;G0N8F]D>2YC;&EE;G17:61T:#LG.PH@("`@("`@("`@("`@
M("`@)&E(96EG:'1?8V]D92`]("=D;V-U;65N="YB;V1Y+F-L:65N=$AE:6=H
M=#LG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&E7
M:61T:%]C;V1E(#T@)W=I;F1O=RYI;FYE<E=I9'1H.R<["B`@("`@("`@("`@
M("`@("`D:4AE:6=H=%]C;V1E(#T@)W=I;F1O=RYI;FYE<DAE:6=H=#LG.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!*879A<V-R:7!T(&1I<W!L
M87DN("HO"B`@("`@("`@("`@("1L;V%D:6YG(#T@7R@B3&]A9&EN9RXN+B(I
M.PH@("`@("`@("`@("`D<W1R("X](#P\/$5/1`H\<V-R:7!T('1Y<&4](G1E
M>'0O:F%V87-C<FEP="(^"F9U;F-T:6]N(')E<VEZ95=I;F1O=R@I('L*("`@
M('=I;F1O=RYM;W9E5&\H,"P@,"D["B`@("!D;V-U;65N="YG971%;&5M96YT
M0GE)9"@G<W!L87-H)RDN<W1Y;&4N9&ES<&QA>2`]("=N;VYE)SL*("`@(&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*"=D:7-P7VEM86=E)RDN<W1Y;&4N9&ES
M<&QA>2`]("=B;&]C:R<["B`@("!V87(@:5=I9'1H(#T@9&]C=6UE;G0N:6UA
M9V5S6S!=+G=I9'1H("T@)&E7:61T:%]C;V1E"B`@("!V87(@:4AE:6=H="`]
M(&1O8W5M96YT+FEM86=E<ULP72YH96EG:'0@+2`D:4AE:6=H=%]C;V1E"B`@
M("!W:6YD;W<N<F5S:7IE0GDH:5=I9'1H+"!I2&5I9VAT*3L*("`@('-E;&8N
M9F]C=7,H*3L@"GT*/"]S8W)I<'0^/"]H96%D/@H\8F]D>2!O;FQO860](G)E
M<VEZ95=I;F1O=R@I.R(^/'-P86X@:60](G-P;&%S:"(@<W1Y;&4](F-O;&]R
M.F=R87D[9F]N="UF86UI;'DZ<V%N<RUS97)I9CMP861D:6YG.C)P>#LB/B1L
M;V%D:6YG/"]S<&%N/CQI;6<@:60](F1I<W!?:6UA9V4B('-T>6QE/2)D:7-P
M;&%Y.FYO;F4[(B!S<F,](B1U<FPB("\^/"]B;V1Y/CPO:'1M;#X*14]$.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J($YO;BUJ879A<V-R:7!T
M(&1I<W!L87DN("HO"B`@("`@("`@("`@("1I;6=?='AT(#T@7R@B26UA9V4B
M*3L*("`@("`@("`@("`@)'-T<B`N/2`\/#Q%3T0*/"]H96%D/@H\8F]D>2!B
M9V-O;&]R/2(C9F9F9F9F(B!T;W!M87)G:6X](C`B(&UA<F=I;FAE:6=H=#TB
M,"(@;&5F=&UA<F=I;CTB,"(@;6%R9VEN=VED=&@](C`B/@H\:6UG(&)O<F1E
M<CTB,"(@<W)C/2(D=7)L(B!A;'0](B1I;6=?='AT(B`O/@H\+V)O9'D^"CPO
M:'1M;#X*14]$.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S='(["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+VUS<&]W97)P
M;VEN="YP:'``````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-3$R(#$P-3$U-#,T
M,3,W(#`R-#8Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7VUS<&]W97)P
M;VEN="!C;&%S<R!R96YD97)S(&]U="!-:6-R;W-O9G0@4&]W97)P;VEN=`H@
M*B!D;V-U;65N=',@:6X@2%1-3"!F;W)M870@8GD@=7-I;F<@=&AE('AL2'1M
M;"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O
M5FEE=V5R+VUS<&]W97)P;VEN="YP:'`L=B`Q+C$S+C$P+C<@,C`P-B\P,2\P
M,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]M<W!O
M=V5R<&]I;G0@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@
M*B!296YD97(@;W5T('1H92!C=7)R96YT(&1A=&$@=7-I;F<@<'!T:'1M;"X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M
M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@("\J($-H96-K
M('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U86QL>2!E>&ES=',N("HO
M"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM95]D<FEV97)S6R=H;W)D
M92==6R=M<W!O=V5R<&]I;G0G75LG;&]C871I;VXG72DI('L*("`@("`@("`@
M("`@<F5T=7)N("<\<')E/B<@+B!S<')I;G1F*%\H(E1H92!P<F]G<F%M('5S
M960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N;W0@9F]U;F0@
M;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-P
M;W=E<G!O:6YT)UU;)VQO8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@("`@
M?0H*("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("1T;7!?<'!T(#T@2&]R
M9&4Z.F=E=%1E;7!&:6QE*"=H;W)D95]M<W!O=V5R<&]I;G0G*3L*"B`@("`@
M("`@)&9H(#T@9F]P96XH)'1M<%]P<'0L("=W)RD["B`@("`@("`@9G=R:71E
M*"1F:"P@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H*2D["B`@("`@
M("`@9F-L;W-E*"1F:"D["@H@("`@("`@("1F:"`]('!O<&5N*"1M:6UE7V1R
M:79E<G-;)VAO<F1E)UU;)VUS<&]W97)P;VEN="==6R=L;V-A=&EO;B==("X@
M(B`D=&UP7W!P="`R/B8Q(BP@)W(G*3L*("`@("`@("!W:&EL92`H*"1R8R`]
M(&9G971S*"1F:"P@.#$Y,BDI*2!["B`@("`@("`@("`@("1D871A("X]("1R
M8SL*("`@("`@("!]"B`@("`@("`@<&-L;W-E*"1F:"D["@H@("`@("`@(')E
M='5R;B`D9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M34E-12!C;VYT96YT('1Y<&4@;V8@=&AE(')E;F1E<F5D(&-O;G1E;G0N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@
M;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]M<W=O<F0N<&AP````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3$R-"`Q,#4Q-30S-#$S-R`P
M,C,S-C,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]M<W=O<F0@8VQA<W,@
M<F5N9&5R<R!O=70@36EC<F]S;V9T(%=O<F0*("H@9&]C=6UE;G1S(&EN($A4
M34P@9F]R;6%T(&)Y('5S:6YG('1H92!W=E=A<F4@<&%C:V%G92X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]M<W=O<F0N<&AP
M+'8@,2XR-2XQ,"XX(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@/&%N
M:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N
M:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*
M8VQA<W,@34E-15]6:65W97)?;7-W;W)D(&5X=&5N9',@34E-15]6:65W97(@
M>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R<F5N="!D871A
M('5S:6YG('=V5V%R92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E
M;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@9VQO8F%L("1M:6UE7V1R:79E<G,["@H@
M("`@("`@("\J($-H96-K('1O(&UA:V4@<W5R92!T:&4@<')O9W)A;2!A8W1U
M86QL>2!E>&ES=',N("HO"B`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D;6EM
M95]D<FEV97)S6R=H;W)D92==6R=M<W=O<F0G75LG;&]C871I;VXG72DI('L*
M("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!S<')I;G1F*%\H(E1H92!P
M<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H)7,I('=A<R!N
M;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I=F5R<ULG:&]R
M9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@
M("`@?0H*("`@("`@("`D9&%T82`]("<G.PH@("`@("`@("1T;7!?=V]R9"`@
M(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=M<W=O<F0G*3L*("`@("`@("`D=&UP
M7V]U='!U="`]($AO<F1E.CIG971496UP1FEL92@G;7-W;W)D)RD["B`@("`@
M("`@)'1M<%]D:7(@("`@/2!(;W)D93HZ9V5T5&5M<$1I<B@I.PH@("`@("`@
M("1T;7!?9FEL92`@(#T@<W1R7W)E<&QA8V4H)'1M<%]D:7(@+B`G+R<L("<G
M+"`D=&UP7V]U='!U="D["@H@("`@("`@(&EF("A/4U]724Y$3U=3*2!["B`@
M("`@("`@("`@("1A<F=S(#T@)R`M>"`G("X@9&ER;F%M92@D;6EM95]D<FEV
M97)S6R=H;W)D92==6R=M<W=O<F0G75LG;&]C871I;VXG72D@+B`B7%QW=DAT
M;6PN>&UL("UD("1T;7!?9&ER("TQ("1T;7!?=V]R9"`^("1T;7!?;W5T<'5T
M(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=F5R<VEO;B`](&5X
M96,H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-W;W)D)UU;)VQO8V%T:6]N
M)UT@+B`G("TM=F5R<VEO;B<I.PH@("`@("`@("`@("!I9B`H=F5R<VEO;E]C
M;VUP87)E*"1V97)S:6]N+"`G,"XW+C`G*2`^/2`P*2!["B`@("`@("`@("`@
M("`@("`D87)G<R`]("(@+2UC:&%R<V5T/2(@+B!.3%,Z.F=E=$-H87)S970H
M*2`N("(@+2UT87)G971D:7(])'1M<%]D:7(@)'1M<%]W;W)D("1T;7!?9FEL
M92(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D87)G
M<R`]("(@)'1M<%]W;W)D("1T;7!?;W5T<'5T(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&9H(#T@9F]P96XH)'1M<%]W;W)D+"`G=R<I
M.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DI.PH@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("!E>&5C
M*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS=V]R9"==6R=L;V-A=&EO;B==
M("X@)&%R9W,I.PH*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1T;7!?;W5T
M<'5T*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B56YA8FQE('1O('1R86YS
M;&%T92!T:&ES(%=O<F0@9&]C=6UE;G0B*3L*("`@("`@("!]"@H@("`@("`@
M("1F:"`](&9O<&5N*"1T;7!?;W5T<'5T+"`G<B<I.PH@("`@("`@('=H:6QE
M("@H)')C(#T@9F=E=',H)&9H+"`X,3DR*2DI('L*("`@("`@("`@("`@)&1A
M=&$@+CT@)')C.PH@("`@("`@('T*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N
M=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E
M;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA
M<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+TU)344O5FEE=V5R+VAT;6PN<&AP````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$T-3$Q(#$P-3$U-#,T,3,W(#`R,S`Q-``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($U)345?5FEE=V5R7VAT;6P@8VQA<W,@<F5N9&5R<R!O=70@2%1-3"!T
M97AT('=I=&@@86X@969F;W)T('1O"B`J(')E;6]V92!P;W1E;G1I86QL>2!M
M86QI8VEO=7,@8V]D92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]H=&UL+G!H<"QV(#$N,30N-"XR,"`R,#`V+S`V+S`W(#$S
M.C,T.C$V(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($%N
M:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N:6P@36%D:&%V
M87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!A=71H;W(@($IO;B!087)I
M<V4@/&IO;D!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI8VAA96P@4VQU<V%R
M>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6
M:65W97)?:'1M;"!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@
M("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T
M97)S('1H92!V:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R96YD97)E9"!T97AT+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?8VQE86Y(5$U,*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEL=&5R<R!A8W1I
M=F4@8V]N=&5N="P@9&5R969E<F5N8V5S(&5X=&5R;F%L(&QI;FMS+"!D971E
M8W1S('!H:7-H:6YG+`H@("`@("H@971C+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@
M(%1H92!(5$U,(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!C;&5A;F5D($A434P@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-L96%N2%1-3"@D9&%T82D*("`@('L*("`@("`@("!G;&]B86P@)&)R;W=S
M97(L("1P<F5F<SL*"B`@("`@("`@)'!H:7-H7W=A<FX@/2!F86QS93L*"B`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]-24U%+T-O;G1E;G1S+G!H<"<[
M"B`@("`@("`@)&%T=&%C:&UE;G0@/2!-24U%7T-O;G1E;G1S.CIV:65W07-!
M='1A8VAM96YT*"D["@H@("`@("`@("\J($1E86P@=VET:"`\8F%S93X@=&%G
M<R!I;B!T:&4@2%1-3"P@<VEN8V4@=&AE>2!W:6QL('-C<F5W('5P(&]U<B!O
M=VX*("`@("`@("`@*B!R96QA=&EV92!P871H<RX@*B\*("`@("`@("!I9B`H
M<')E9U]M871C:"@G+SQB87-E(&AR968](C\H6UXB/B!=*BDB/R`_7"\_/B]I
M)RP@)&1A=&$L("1M871C:&5S*2D@>PH@("`@("`@("`@("`D8F%S92`]("1M
M871C:&5S6S%=.PH@("`@("`@("`@("!I9B`H<W5B<W1R*"1B87-E+"`M,2P@
M,2D@(3T@)R\G*2!["B`@("`@("`@("`@("`@("`D8F%S92`N/2`G+R<["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%)E8W5R<VEV96QY(&-A;&P@
M7V-L96%N2%1-3"@I('1O('!R979E;G0@8VQE=F5R(&9I96YD<R!F<F]M"B`@
M("`@("`@("`@("`J('-N96%K:6YG(&YA<W1Y('1H:6YG<R!I;G1O('1H92!P
M86=E('9I82`D8F%S92X@*B\*("`@("`@("`@("`@)&)A<V4@/2`D=&AI<RT^
M7V-L96%N2%1-3"@D8F%S92D["B`@("`@("`@?0H*("`@("`@("`O*B!!='1E
M;7!T('1O(&9I>"!P871H<R!T:&%T('=E<F4@<F5L>6EN9R!O;B!A(#QB87-E
M/B!T86<N("HO"B`@("`@("`@:68@*"%E;7!T>2@D8F%S92DI('L*("`@("`@
M("`@("`@)'!A='1E<FX@/2!A<G)A>2@G?'-R8STH6R)<)UTI*%M>.B)<)UTK
M*5PQ?&DG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=\<W)C/2A;
M7CH@/B)<)UTK*7QI)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M?&AR968]("HH6R)<)UTI*%M>.B)<)UTK*5PQ?&DG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=\:')E9CTH6UXZ(#XB7"==*RE\:2<I.PH@("`@
M("`@("`@("`D<F5P;&%C92`](&%R<F%Y*"=S<F,]7#$G("X@)&)A<V4@+B`G
M7#)<,2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-R8STG("X@
M)&)A<V4@+B`G7#$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H
M<F5F/5PQ)R`N("1B87-E("X@)UPR7#$G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H<F5F/2<@+B`D8F%S92`N("=<,2<I.PH@("`@("`@("`@
M("`D9&%T82`]('!R96=?<F5P;&%C92@D<&%T=&5R;BP@)')E<&QA8V4L("1D
M871A*3L*("`@("`@("!]"@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O
M5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`D<W1R:7!?<W1Y;&5S(#T@(21A
M='1A8VAM96YT('Q\"B`@("`@("`@("`@("@D8G)O=W-E<BT^:7-"<F]W<V5R
M*"=M;WII;&QA)RD@)B8*("`@("`@("`@("`@("1B<F]W<V5R+3YG971-86IO
M<B@I(#T](#0I('Q\"B`@("`@("`@("`@("1B<F]W<V5R+3YI<T)R;W=S97(H
M)VUS:64G*3L*("`@("`@("`D9&%T82`](%1E>'1?1FEL=&5R.CIF:6QT97(H
M)&1A=&$L("=X<W,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G8F]D>5]O;FQY)R`]/B`A)&%T=&%C:&UE;G0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S=')I<%]S
M='EL97,G(#T^("1S=')I<%]S='EL97,I*3L*"B`@("`@("`@+RH@0VAE8VL@
M9F]R('!H:7-H:6YG(&5X<&QO:71S+B`J+PH@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O:')E9EQS*CU<<RI;(EPG73]<<RHH:'1T<'QH='1P<WQF='`I.EPO
M7"]<9'LQ+#-]7"Y<9'LQ+#-]7"Y<9'LQ+#-]7"Y<9'LQ+#-]+VDG+"`D9&%T
M82DI('L*("`@("`@("`@("`@+RH@0VAE8VL@,3H@0VAE8VL@9F]R($E0(&%D
M9')E<W,@;&EN:W,N("HO"B`@("`@("`@("`@("1P:&ES:%]W87)N(#T@=')U
M93L*("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:%]A;&PH)R]H<F5F7',J
M/5QS*ELB7"==/UQS*B@_.FAT='!\:'1T<'-\9G1P*3I<+UPO*%M>7',B7"<^
M72LI6R)<)UT_6UX^72H^7',J*#\Z*#\Z:'1T<'QH='1P<WQF='`I.EPO7"\I
M/R@N*C\I/%PO82]I<R<L("1D871A+"`D;2DI('L*("`@("`@("`@("`@+RH@
M)&U;,5T@/2!,:6YK.R`D;5LR72`](%1A<F=E=`H@("`@("`@("`@("`@*B!#
M:&5C:R`R.B!#:&5C:R!F;W(@;&EN:W,@=&AA="!P;VEN="!T;R!A(&1I9F9E
M<F5N="!H;W-T('1H86X*("`@("`@("`@("`@("H@=&AE('1A<F=E="!U<FP[
M(&EF('1A<F=E="!L;V]K<R!L:6ME(&$@9&]M86EN(&YA;64L(&-H96-K(&ET
M"B`@("`@("`@("`@("`J(&%G86EN<W0@=&AE(&QI;FLN("HO"B`@("`@("`@
M("`@("1L:6YK<R`](&-O=6YT*"1M6S!=*3L*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&QI;FMS.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D
M;5LQ75LD:5T@/2!S=')T;VQO=V5R*'5R;&1E8V]D92@D;5LQ75LD:5TI*3L*
M("`@("`@("`@("`@("`@("1M6S)=6R1I72`]('-T<G1O;&]W97(H<')E9U]R
M97!L86-E*"<O7BAH='1P?&AT='!S?&9T<"DZ7"]<+R\G+"`G)RP@<W1R:7!?
M=&%G<R@D;5LR75LD:5TI*2D["B`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UY;+2Y?7&1A+7I=*UPN6V$M>EU[,BQ]+VDG+"`D;5LR75LD:5TI
M("8F"B`@("`@("`@("`@("`@("`@("`@<W1R<&]S*"1M6S%=6R1I72P@)&U;
M,EU;)&E=*2`A/3T@,"`F)@H@("`@("`@("`@("`@("`@("`@('-T<G!O<R@D
M;5LR75LD:5TL("1M6S%=6R1I72D@(3T](#`I('L*("`@("`@("`@("`@("`@
M("`@("`O*B!$;VXG="!C;VYS:61E<B!T:&4@;&EN:R!A('!H:7-H:6YG(&QI
M;FL@:68@=&AE(&1O;6%I;@H@("`@("`@("`@("`@("`@("`@("`J(&ES('1H
M92!S86UE(&]N(&)O=&@@;&EN:W,@*&4N9RX@861T<F%C:VEN9RYE>&%M<&QE
M+F-O;0H@("`@("`@("`@("`@("`@("`@("`J("8@=W=W+F5X86UP;&4N8V]M
M*2X@*B\*("`@("`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O7"X_*%M>
M7"Y<+UTK7"Y;7EPN7"]=*RE<+R\G+"`D;5LQ75LD:5TL("1H;W-T,2D["B`@
M("`@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UPN/RA;7EPN7"]=*UPN
M6UY<+EPO72LI*%PO+BHI/R0O)RP@)&U;,EU;)&E=+"`D:&]S=#(I.PH@("`@
M("`@("`@("`@("`@("`@(&EF("@A*&-O=6YT*"1H;W-T,2D@)B8@8V]U;G0H
M)&AO<W0R*2D@?'P*("`@("`@("`@("`@("`@("`@("`@("`@<W1R8V%S96-M
M<"@D:&]S=#%;,5TL("1H;W-T,ELQ72D@(3T](#`I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!H:7-H7W=A<FX@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@5')Y('1O(&1E<F5F97(@86QL(&5X=&5R;F%L
M(')E9F5R96YC97,N("HO"B`@("`@("`@)&1A=&$@/2!P<F5G7W)E<&QA8V5?
M8V%L;&)A8VLH)R]H<F5F7',J/5QS*BA;(EPG72D_*"@_*#$I6UY<,5TJ/WQ;
M7EQS/ETK*2DH/R@Q*5PQ?"DO:2<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8W)E871E7V9U;F-T:6]N*"<D;2<L("=R971U<FX@
M7"=H<F5F/2)<)R`N("AS=')L96XH)&U;,ETI("8F("1M6S)=>S!](#T](%PG
M(UPG(#\@)&U;,ET@.B!(;W)D93HZ97AT97)N86Q5<FPH)&U;,ETI*2`N(%PG
M(EPG.R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A*3L*"B`@("`@("`@+RH@4')E<&5N9"!P:&ES:&EN9R!W87)N:6YG
M+B`J+PH@("`@("`@(&EF("@D<&AI<VA?=V%R;BD@>PH@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+TU)344O0V]N=&5N=',N<&AP)SL*("`@("`@
M("`@("`@)&-O;G1E;G1S(#T@)FYE=R!-24U%7T-O;G1E;G1S*&YE=R!-24U%
M7U!A<G0H*2D["B`@("`@("`@("`@("1P:&ES:%]W87)N:6YG(#T@<W!R:6YT
M9BA?*"(E<SH@5&AI<R!M97-S86=E(&UA>2!N;W0@8F4@9G)O;2!W:&]M(&ET
M(&-L86EM<R!T;R!B92X@0F5W87)E(&]F(&9O;&QO=VEN9R!A;GD@;&EN:W,@
M:6X@:70@;W(@;V8@<')O=FED:6YG('1H92!S96YD97(@=VET:"!A;GD@<&5R
M<V]N86P@:6YF;W)M871I;VXN(BDL(%\H(E=A<FYI;F<B*2D["B`@("`@("`@
M("`@(&EF("@D8V]N=&5N=',M/G9I97=!<T%T=&%C:&UE;G0H*2D@>PH@("`@
M("`@("`@("`@("`@)'!H:7-H7W=A<FYI;F<@/2`G/'-P86X@<W1Y;&4](F)A
M8VMG<F]U;F0M8V]L;W(Z(V9F9#!A9CMC;VQO<CIB;&%C:R(^)R`N(%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)'!H:7-H7W=A<FYI;F<L($Y,4SHZ9V5T0VAA
M<G-E="@I+"`D=&AI<RT^;6EM95]P87)T+3YG971#:&%R<V5T*"DI("X@)SPO
M<W!A;CX\8G(@+SXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1P:&ES
M:%]W87)N:6YG(#T@)&-O;G1E;G1S+3YF;W)M8713=&%T=7--<V<H)'!H:7-H
M7W=A<FYI;F<L(&YU;&PL('1R=64L("=M:6UE4W1A='5S5V%R;FEN9R<I.PH@
M("`@("`@("`@("!I9B`H<W1R:7-T<B@D9&%T82P@)SQB;V1Y)RD@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D9&%T82`]("1P:&ES:%]W87)N:6YG
M("X@)&1A=&$["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D9&%T82`]('!R96=?<F5P;&%C92@G+R@N*CQB;V1Y+BH_/BDH+BHI+VDG
M+"`G)#$G("X@)'!H:7-H7W=A<FYI;F<@+B`G)#(G+"`D9&%T82D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9&%T83L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E(&]F
M('1H92!R96YD97)E9"!T97AT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@34E-12!#;VYT96YT+51Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O34E-12]#;VYT96YT<RYP:'`G.PH@("`@("`@(')E='5R;B!-24U%7T-O
M;G1E;G1S.CIV:65W07-!='1A8VAM96YT*"D@/R`D=&AI<RT^;6EM95]P87)T
M+3YG9714>7!E*'1R=64I(#H@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3
M.CIG971#:&%R<V5T*"D["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]D969A=6QT+G!H<```````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3$W-R`Q,#4Q-30S-#$S-R`P,C,U
M,#``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]D969A=6QT(&-L87-S('-I
M;7!L>2!P<FEN=',@;W5T('1H92!E;F-A<'-U;&%T960*("H@8V]N=&5N="X@
M($ET(&5X:7-T<R!A<R!A(&9A;&QB86-K(&EF(&YO(&]T:&5R(&EN=&5L;&EG
M96YT(')E;F1E<FEN9PH@*B!M96-H86YI<VT@8V]U;&0@8F4@=7-E9"X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]D969A=6QT
M+G!H<"QV(#$N.2XQ,BXT(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H879A<&5D9'D@
M/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@
M*B\*8VQA<W,@34E-15]6:65W97)?9&5F875L="!E>'1E;F1S($U)345?5FEE
M=V5R('L*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]V8V%R9"YP:'``
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-S0U-B`Q,#4Q-30S-#$S
M-R`P,C,Q-C,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]V8V%R9"!C;&%S
M<R!R96YD97)S(&]U="!V0V%R9',@:6X@2%1-3"!F;W)M870N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=F-A<F0N<&AP+'8@
M,2XS-"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E
M+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,`H@*B!`
M<&%C:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W
M97)?=F-A<F0@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@
M*B!296YD97(@;W5T('1H92!V8V%R9"!C;VYT96YT<RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I
M97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96YD97(H)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@9VQO8F%L("1R
M96=I<W1R>2P@)'!R969S.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E
M+VE#86QE;F1A<BYP:'`G.PH*("`@("`@("`D87!P(#T@9F%L<V4["B`@("`@
M("`@)&1A=&$@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I.PH@
M("`@("`@("1H=&UL(#T@)R<["B`@("`@("`@)&EM<&]R=%]M<V<@/2!N=6QL
M.PH@("`@("`@("1T:71L92`](%\H(G9#87)D(BD["@H@("`@("`@("1I0V%L
M(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L
M+3YP87)S979#86QE;F1A<B@D9&%T82DI('L*("`@("`@("`@("`@)&EM<&]R
M=%]M<V<@/2!?*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!C
M;VYT86-T(&1A=&$N(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H571I;#HZ
M9V5T1F]R;41A=&$H)VEM<&]R="<I("8F"B`@("`@("`@("`@(%5T:6PZ.F=E
M=$9O<FU$871A*"=S;W5R8V4G*2`F)@H@("`@("`@("`@("`D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G8V]N=&%C=',O:6UP;W)T)RDI('L*("`@("`@("`@("`@
M)'-O=7)C92`](%5T:6PZ.F=E=$9O<FU$871A*"=S;W5R8V4G*3L*("`@("`@
M("`@("`@)&-O;G1A8W1S(#T@)')E9VES=')Y+3YC86QL*"=C;VYT86-T<R]I
M;7!O<G0G+"!A<G)A>2@D9&%T82P@)W1E>'0O>"UV8V%R9"<L("1S;W5R8V4I
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)&-O;G1A8W1S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`D:6UP;W)T7VUS9R`](%\H(E1H97)E
M('=A<R!A;B!E<G)O<B!I;7!O<G1I;F<@=&AE(&-O;G1A8W0@9&%T82XB*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D:4-A
M;"T^9V5T0V]M<&]N96YT0V]U;G0H*2`]/2`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@)&EM<&]R=%]M<V<@/2!?*")4:&4@8V]N=&%C="!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D('1O('EO=7(@861D<F5S<R!B;V]K+B(I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:6UP;W)T
M7VUS9R`](%\H(D-O;G1A8W1S('=E<F4@<W5C8V5S<V9U;&QY(&%D9&5D('1O
M('EO=7(@861D<F5S<R!B;V]K+B(I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D:'1M;"`@/2!5=&EL.CIB
M=69F97)/=71P=70H)VEN8VQU9&4G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA
M=&5S)RP@)VAO<F1E)RD@+B`G+V-O;6UO;BUH96%D97(N:6YC)RD["B`@("`@
M("`@)&AT;6P@+CT@)SQT86)L92!C96QL<W!A8VEN9STB,2(@8F]R9&5R/2(P
M(B!C96QL<&%D9&EN9STB,2(^)SL*("`@("`@("!I9B`H(6ES7VYU;&PH)&EM
M<&]R=%]M<V<I*2!["B`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O
M;'-P86X](C(B(&-L87-S/2)H96%D97(B/B<@+B`D:6UP;W)T7VUS9R`N("<\
M+W1D/CPO='(^/'1R/CQT9#XF;F)S<#L\+W1D/CPO='(^)SL*("`@("`@("!]
M(&5L<V5I9B`H)')E9VES=')Y+3YH87--971H;V0H)V-O;G1A8W1S+VEM<&]R
M="<I("8F"B`@("`@("`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D
M*"=C;VYT86-T<R]S;W5R8V5S)RDI('L*("`@("`@("`@("`@)&AT;6P@+CT@
M)SQT<CX\=&0@8V]L<W!A;CTB,B(@8VQA<W,](FAE861E<B(^/&9O<FT@86-T
M:6]N/2(G("X@)%]315)615);)U!(4%]314Q&)UT@+B`G(B!M971H;V0](F=E
M="(@;F%M93TB=F-A<F1?:6UP;W)T(CXG("X@571I;#HZ9F]R;4EN<'5T*"D[
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1?1T54(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQI;G!U="!T>7!E/2)H:61D
M96XB(&YA;64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1K97DI("X@)R(@=F%L
M=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1V86PI("X@)R(@+SXG.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D<V]U<F-E<R`]("1R96=I<W1R>2T^
M8V%L;"@G8V]N=&%C=',O<V]U<F-E<R<L(&%R<F%Y*'1R=64I*3L*("`@("`@
M("`@("`@:68@*&-O=6YT*"1S;W5R8V5S*2`^(#$I('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]("<\:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T
M=&]N(B!N86UE/2)I;7!O<G0B('9A;'5E/2(G("X@7R@B061D('1O(&%D9')E
M<W,@8F]O:SHB*2`N("<B("\^)SL*("`@("`@("`@("`@("`@("1H=&UL("X]
M("<\<V5L96-T(&YA;64](G-O=7)C92(^)SL*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1S;W5R8V5S(&%S("1K97D@/3X@)&QA8F5L*2!["B`@("`@("`@
M("`@("`@("`@("`@)'-E;&5C=&5D(#T@*"1K97D@/3T@)'!R969S+3YG9716
M86QU92@G861D7W-O=7)C92<I*2`_("<@<V5L96-T960](G-E;&5C=&5D(B<@
M.B`G)SL*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V
M86QU93TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&ME>2D@+B`G(B<@+B`D<V5L
M96-T960@+B`G/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1L86)E;"D@+B`G/"]O
M<'1I;VX^)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1H=&UL("X]("<\:6YP=70@='EP93TB<W5B
M;6ET(B!C;&%S<STB8G5T=&]N(B!N86UE/2)I;7!O<G0B('9A;'5E/2(G("X@
M7R@B061D('1O(&UY(&%D9')E<W,@8F]O:R(I("X@)R(@+SXG.PH@("`@("`@
M("`@("`@("`@)'-O=7)C92`](&%R<F%Y7VME>7,H)'-O=7)C97,I.PH@("`@
M("`@("`@("`@("`@)&AT;6P@+CT@)SQI;G!U="!T>7!E/2)H:61D96XB(&YA
M;64](G-O=7)C92(@=F%L=64](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1S;W5R
M8V5;,%TI("X@)R(@+SXG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M:'1M;"`N/2`G/"]F;W)M/CPO=&0^/"]T<CX\='(^/'1D/B9N8G-P.SPO=&0^
M/"]T<CXG.PH@("`@("`@('T*"B`@("`@("`@)&D@/2`P.PH@("`@("`@(&9O
M<F5A8V@@*"1I0V%L+3YG971#;VUP;VYE;G1S*"D@87,@)'9C*2!["B`@("`@
M("`@("`@(&EF("@D:2`^(#`I('L*("`@("`@("`@("`@("`@("1H=&UL("X]
M("<\='(^/'1D/B9N8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("LK)&D["@H@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/CQT
M9"!C;VQS<&%N/2(R(B!C;&%S<STB:&5A9&5R(CXG.PH@("`@("`@("`@("`D
M9G5L;&YA;64@/2`D=F,M/F=E=$%T=')I8G5T941E9F%U;'0H)T9.)RP@9F%L
M<V4I.PH@("`@("`@("`@("!I9B`H)&9U;&QN86UE("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)&AT;6P@+CT@)&9U;&QN86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1H=&UL("X]("<\+W1D/CPO='(^)SL*"B`@("`@
M("`@("`@("1N(#T@)'9C+3YP<FEN=&%B;&5.86UE*"D["B`@("`@("`@("`@
M(&EF("@A96UP='DH)&XI*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D
M=&AI<RT^7W)O=RA?*").86UE(BDL("1N*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&%L:6%S97,@/2`D=F,M/F=E=$%T=')I8G5T959A;'5E<R@G
M04Q)05,G*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1A;&EA<V5S+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^
M7W)O=RA?*")!;&EA<R(I+"!I;7!L;V1E*"<\8G(@+SXG+"`D86QI87-E<RDI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B:7)T:&1A>7,@/2`D=F,M
M/F=E=$%T=')I8G5T959A;'5E<R@G0D1!62<I.PH@("`@("`@("`@("!I9B`H
M(6ES7V$H)&)I<G1H9&%Y<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B0FER=&AD87DB*2P@9&%T
M92@G62UM+60G+"`D8FER=&AD87ES6S!=*2D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1L86)E;',@/2`D=F,M/F=E=$%L;$%T=')I8G5T97,H)TQ!
M0D5,)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1L86)E;',@87,@)&QA8F5L
M*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&QA8F5L6R=P87)A;7,G
M75LG5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L
M86)E;%LG<&%R86US)UU;)U194$4G72!A<R`D='EP92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D;&%B96Q;)W!A<F%M<R==6U-T<FEN9SHZ=7!P97(H
M)'1Y<&4I72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1L86)E;%LG
M<&%R86US)UU;)TA/344G72DI('L*("`@("`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`D=&AI<RT^7W)O=RA?*")(;VUE($%D9')E<W,B*2P@;FPR8G(H)&QA
M8F5L6R=V86QU92==*2D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S
M970H)&QA8F5L6R=P87)A;7,G75LG5T]22R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E=O<FL@061D<F5S<R(I
M+"!N;#)B<B@D;&%B96Q;)W9A;'5E)UTI*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R
M;W<H7R@B061D<F5S<R(I+"!N;#)B<B@D;&%B96Q;)W9A;'5E)UTI*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M1F]R('9#87)D(#,N,"X*("`@("`@("`@("`@)&%D<G,@/2`D=F,M/F=E=$%L
M;$%T=')I8G5T97,H)T%$4B<I.PH@("`@("`@("`@("!F;W)E86-H("@D861R
M<R!A<R`D:71E;2D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M
M6R=P87)A;7,G75LG5%E012==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-?87)R87DH)&ET96U;)W!A<F%M<R==6R=465!%)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==(#T@
M87)R87DH)&ET96U;)W!A<F%M<R==6R=465!%)UTI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&ET96U;)W!A<F%M<R==6R=465!%)UT@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;
M)U=/4DLG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ET96U;)W!A
M<F%M<R==6R=465!%)UU;72`]("=73U)+)SL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I=&5M6R=P87)A
M;7,G75LG2$]-12==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:71E
M;5LG<&%R86US)UU;)U194$4G75M=(#T@)TA/344G.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1A
M9&1R97-S(#T@)&ET96U;)W9A;'5E<R==.PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&ET96U;)W!A<F%M<R==6R=465!%)UT@87,@)&%D<BD@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("A3=')I;F<Z.G5P<&5R*"1A9'(I(#T]("=(
M3TU%)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D82`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM6
M0T%21%]!1%)?4U12145472DI("`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?
M04127U-44D5%5%T[('T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1A9&1R97-S6U9#05)$7T%$4E],3T-!3$E465TI*2![("1A6UT@/2`D
M861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=.R!]"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?4D5'24].
M72DI("`@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ET[('T*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A9&1R97-S6U9#
M05)$7T%$4E]03U-40T]$15TI*2![("1A6UT@/2`D861D<F5S<UM60T%21%]!
M1%)?4$]35$-/1$5=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D861D<F5S<UM60T%21%]!1%)?0T]53E1265TI*2`@>R`D85M=(#T@
M)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=.R!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(DAO;64@061D<F5S
M<R(I+"!N;#)B<BAI;7!L;V1E*")<;B(L("1A*2DI.PH*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D861R*2`]/2`G5T]2
M2R<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&$@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!
M4D1?04127U-44D5%5%TI*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$
M4E]35%)%151=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=*2D@>R`D85M=(#T@)&%D
M9')E<W-;5D-!4D1?04127TQ/0T%,251973L@?0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127U)%1TE/3ETI
M*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=.R!]"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<UM60T%2
M1%]!1%)?4$]35$-/1$5=*2D@>R`D85M=(#T@)&%D9')E<W-;5D-!4D1?0412
M7U!/4U1#3T1%73L@?0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=*2D@('L@)&%;72`]("1A
M9&1R97-S6U9#05)$7T%$4E]#3U5.5%)973L@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")7;W)K($%D9')E<W,B
M*2P@;FPR8G(H:6UP;&]D92@B7&XB+"`D82DI*3L*"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&$@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D
M9')E<W-;5D-!4D1?04127U-44D5%5%TI*2`@('L@)&%;72`]("1A9&1R97-S
M6U9#05)$7T%$4E]35%)%151=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D861D<F5S<UM60T%21%]!1%)?3$]#04Q)5%E=*2D@>R`D
M85M=(#T@)&%D9')E<W-;5D-!4D1?04127TQ/0T%,251973L@?0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?0412
M7U)%1TE/3ETI*2`@('L@)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]214=)
M3TY=.R!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D861D
M<F5S<UM60T%21%]!1%)?4$]35$-/1$5=*2D@>R`D85M=(#T@)&%D9')E<W-;
M5D-!4D1?04127U!/4U1#3T1%73L@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&%D9')E<W-;5D-!4D1?04127T-/54Y44EE=*2D@('L@
M)&%;72`]("1A9&1R97-S6U9#05)$7T%$4E]#3U5.5%)973L@?0H@("`@("`@
M("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")!9&1R
M97-S(BDL(&YL,F)R*&EM<&QO9&4H(EQN(BP@)&$I*2D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D;G5M8F5R<R`]("1V8RT^9V5T06QL071T<FEB=71E<R@G
M5$5,)RD["@H@("`@("`@("`@("!F;W)E86-H("@D;G5M8F5R<R!A<R`D;G5M
M8F5R*2!["B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&YU;6)E<ELG<&%R
M86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D;G5M8F5R6R=P87)A;7,G75LG5%E012==(&%S("1T>7!E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1N=6UB97);)W!A<F%M<R==6U-T<FEN9SHZ
M=7!P97(H)'1Y<&4I72`]('1R=64["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N
M=6UB97);)W!A<F%M<R==6R=&05@G72DI('L*("`@("`@("`@("`@("`@("`@
M("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")&87@B*2P@)&YU;6)E<ELG=F%L
M=64G72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G75LG2$]-12==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O
M=RA?*")(;VUE(%!H;VYE(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D;G5M8F5R6R=P87)A;7,G
M75LG5T]22R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:'1M;"`N
M/2`D=&AI<RT^7W)O=RA?*")7;W)K(%!H;VYE(BDL("1N=6UB97);)W9A;'5E
M)UTI.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D;G5M
M8F5R6R=P87)A;7,G75LG0T5,3"==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")#96QL(%!H;VYE(BDL("1N
M=6UB97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W
M*%\H(E!H;VYE(BDL("1N=6UB97);)W9A;'5E)UTI.PH@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&%D9')E<W-E<R`]("1V8RT^9V5T06QL071T<FEB=71E<R@G
M14U!24PG*3L*("`@("`@("`@("`@)&5M86EL<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1A9&1R97-S97,@87,@)&%D9')E<W,I('L*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D861D<F5S<ULG<&%R86US)UU;)U19
M4$4G72DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D861D<F5S
M<ULG<&%R86US)UU;)U194$4G72!A<R`D='EP92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D861D<F5S<ULG<&%R86US)UU;4W1R:6YG.CIU<'!E<B@D
M='EP92E=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D96UA:6P@/2`G/&$@:')E9CTB
M)SL*("`@("`@("`@("`@("`@(&EF("@D<F5G:7-T<GDM/FAA<TUE=&AO9"@G
M;6%I;"]C;VUP;W-E)RDI('L*("`@("`@("`@("`@("`@("`@("`D96UA:6P@
M+CT@)')E9VES=')Y+3YC86QL*"=M86EL+V-O;7!O<V4G+"!A<G)A>2AA<G)A
M>2@G=&\G(#T^("1A9&1R97-S6R=V86QU92==*2DI.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D96UA:6P@+CT@)VUA
M:6QT;SHG("X@)&%D9')E<W-;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D96UA:6P@+CT@)R(^)R`N("1A9&1R97-S6R=V
M86QU92==("X@)SPO83XG.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A
M9&1R97-S6R=P87)A;7,G75LG4%)%1B==*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y7W5N<VAI9G0H)&5M86EL<RP@)&5M86EL*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&5M86EL<UM=
M(#T@)&5M86EL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H8V]U;G0H)&5M86EL<RDI('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(D5M86EL(BDL(&EM<&QO9&4H
M)SQB<B`O/B<L("1E;6%I;',I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'1I=&QE(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H)U1)5$Q%)RD[
M"B`@("`@("`@("`@(&EF("@A:7-?82@D=&ET;&4L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(E1I
M=&QE(BDL("1T:71L95LP72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1R;VQE(#T@)'9C+3YG971!='1R:6)U=&5686QU97,H)U)/3$4G*3L*("`@
M("`@("`@("`@:68@*"%I<U]A*"1R;VQE+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")2;VQE(BDL
M("1R;VQE6S!=*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&]R9R`]
M("1V8RT^9V5T071T<FEB=71E5F%L=65S*"=/4D<G*3L*("`@("`@("`@("`@
M:68@*"%I<U]A*"1O<F<L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(D-O;7!A;GDB*2P@)&]R9ULP
M72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1N;W1E<R`]("1V8RT^
M9V5T071T<FEB=71E5F%L=65S*"=.3U1%)RD["B`@("`@("`@("`@(&EF("@A
M:7-?82@D;F]T97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M("1H=&UL("X]("1T:&ES+3Y?<F]W*%\H(DYO=&5S(BDL(&YL,F)R*"1N;W1E
M<ULP72DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=7)L(#T@)'9C
M+3YG971!='1R:6)U=&5686QU97,H)U523"<I.PH@("`@("`@("`@("!I9B`H
M(6ES7V$H)'5R;"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B55),(BDL("<\82!H<F5F/2(G("X@
M)'5R;%LP72X@)R(@=&%R9V5T/2)?8FQA;FLB/B<@+B`D=7)L6S!=("X@)SPO
M83XG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AT;6P@
M+CT@)SPO=&%B;&4^)SL*("`@("`@("`D:'1M;"`N/2!5=&EL.CIB=69F97)/
M=71P=70H)VEN8VQU9&4G+"`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@
M)VAO<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["@H@("`@("`@(')E
M='5R;B`D:'1M;#L*("`@('T*"B`@("!F=6YC=&EO;B!?<F]W*"1L86)E;"P@
M)'9A;'5E*0H@("`@>PH@("`@("`@(')E='5R;B`G/'1R/CQT9"!C;&%S<STB
M:71E;2(@=F%L:6=N/2)T;W`B/B<@+B`D;&%B96P@+B`G/"]T9#X\=&0@8VQA
M<W,](FET96TB('9A;&EG;CTB=&]P(CXG("X@)'9A;'5E("X@(CPO=&0^/"]T
M<CY<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@
M8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H
M92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z
M.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+W)P;2YP:'``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S-#0U(#$P-3$U-#,T,3,W(#`R,C8U,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@5&AE($U)
M345?5FEE=V5R7W)P;2!C;&%S<R!R96YD97)S(&]U="!L:7-T<R!O9B!F:6QE
M<R!I;B!24$T*("H@<&%C:V%G97,@8GD@=7-I;F<@=&AE(')P;2!T;V]L('1O
M('%U97)Y('1H92!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-
M24U%+TU)344O5FEE=V5R+W)P;2YP:'`L=B`Q+C$R+C$P+C<@,C`P-B\P,2\P
M,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P
M-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@06YI;"!-861H879A<&5D9'D@/&%N:6Q`
M<F5C;VEL+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E
M($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]R<&T@
M97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@
M;W5T('1H92!24$T@8V]N=&5N=',N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W97(@;6%Y(&YE
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!R96YD97)E
M9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&=L;V)A;"`D;6EM95]D<FEV
M97)S.PH*("`@("`@("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R
M86T@86-T=6%L;'D@97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES
M=',H)&UI;65?9')I=F5R<ULG:&]R9&4G75LG<G!M)UU;)VQO8V%T:6]N)UTI
M*2!["B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4
M:&4@<')O9W)A;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W
M87,@;F]T(&9O=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;
M)VAO<F1E)UU;)W)P;2==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@
M("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D=&UP7W)P;2`]
M($AO<F1E.CIG971496UP1FEL92@G:&]R9&5?<G!M)RD["@H@("`@("`@("1F
M:"`](&9O<&5N*"1T;7!?<G!M+"`G=R<I.PH@("`@("`@(&9W<FET92@D9F@L
M("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@("`@(&9C
M;&]S92@D9F@I.PH*("`@("`@("`D9F@@/2!P;W!E;B@D;6EM95]D<FEV97)S
M6R=H;W)D92==6R=R<&TG75LG;&]C871I;VXG72`N("(@+7%I<"`D=&UP7W)P
M;2`R/B8Q(BP@)W(G*3L*("`@("`@("!W:&EL92`H*"1R8R`](&9G971S*"1F
M:"P@.#$Y,BDI*2!["B`@("`@("`@("`@("1D871A("X]("1R8SL*("`@("`@
M("!]"B`@("`@("`@<&-L;W-E*"1F:"D["@H@("`@("`@(')E='5R;B`G/'!R
M93XG("X@:'1M;&5N=&ET:65S*"1D871A*2`N("<\+W!R93XG.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O
M9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U
M<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]R97!O<G0N<&AP````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-3`W-B`Q,#4Q-30S-#$S-R`P,C,S-S$`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]R97!O<G0@8VQA<W,@:7,@82!W<F%P<&5R('5S960@=&\@;&]A9"!T
M:&4@87!P<F]P<FEA=&4*("H@34E-15]6:65W97(@9F]R(&UU;'1I<&%R="]R
M97!O<G0@9&%T82`H4D9#(#,T-C(I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]-24U%+TU)344O5FEE=V5R+W)E<&]R="YP:'`L=B`Q+C8N,3`N-B`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]R97!O<G0@97AT96YD<R!-24U%7U9I
M97=E<B!["@H@("`@+RHJ"B`@("`@*B!3=&]R97,@=&AE($U)345?5FEE=V5R
M(&]F('1H92!S<&5C:69I960@<')O=&]C;VPN"B`@("`@*@H@("`@("H@0'9A
M<B!-24U%7U9I97=E<@H@("`@("HO"B`@("!V87(@)%]V:65W97(["@H@("`@
M+RHJ"B`@("`@*B!296YD97(@=&AE(&UU;'1I<&%R="]R97!O<G0@9&%T82X*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06X@87)R87D@
M;V8@<&%R86UE=&5R<R!N965D960N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@(%1H92!R96YD97)E9"!D871A+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+RH@
M1V5T('1H92!A<'!R;W!R:6%T92!-24U%7U9I97=E<B!F;W(@=&AE('!R;W1O
M8V]L('-P96-I9FEE9"X@*B\*("`@("`@("!I9B`H(2@D=&AI<RT^7W)E<V]L
M=F56:65W97(H*2DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@+RH@4F5N9&5R('5S:6YG('1H92!L;V%D960@34E-15]6:65W
M97(@;V)J96-T+B`J+PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9I97=E<BT^
M<F5N9&5R*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@8V]N=&5N="UT>7!E(&]F('1H92!6:65W97(@=7-E9"!T;R!V:65W
M('1H92!P87)T+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!!(&-O
M;G1E;G0M='EP92!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@("\J($=E="!T:&4@87!P<F]P<FEA=&4@34E-
M15]6:65W97(@9F]R('1H92!P<F]T;V-O;"!S<&5C:69I960N("HO"B`@("`@
M("`@:68@*"$H)'1H:7,M/E]R97-O;'9E5FEE=V5R*"DI*2!["B`@("`@("`@
M("`@(')E='5R;B`G87!P;&EC871I;VXO;V-T970M<W1R96%M)SL*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]V:65W97(M
M/F=E=%1Y<&4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,
M;V%D(&$@34E-15]6:65W97(@86-C;W)D:6YG('1O('1H92!R97!O<G0M='EP
M92!P87)A;65T97(@<W1O<F5D"B`@("`@*B!I;B!T:&4@34E-15]087)T('1O
M(')E;F1E<BX@268@=6YS=6-C97-S9G5L+"!T<GD@=&\@;&]A9"!A(&=E;F5R
M:6,*("`@("`J(&UU;'1I<&%R="!-24U%7U9I97=E<BX*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W)E<V]L=F56:65W97(H*0H@("`@>PH@("`@("`@
M("1V:65W97(@/2!N=6QL.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]V
M:65W97(I*2!["B`@("`@("`@("`@(&EF("@A*"1T>7!E(#T@)'1H:7,M/FUI
M;65?<&%R="T^9V5T0V]N=&5N=%1Y<&5087)A;65T97(H)W)E<&]R="UT>7!E
M)RDI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1V:65W97(@/2`F34E-15]6:65W97(Z.F9A
M8W1O<GDH)'1H:7,M/FUI;65?<&%R="P@)VUE<W-A9V4O)R`N(%-T<FEN9SHZ
M;&]W97(H)'1Y<&4I*3L*("`@("`@("`@("`@:68@*&5M<'1Y*"1V:65W97(I
M('Q\"B`@("`@("`@("`@("`@("`H4W1R:6YG.CIL;W=E<BAG971?8VQA<W,H
M)'9I97=E<BDI(#T]("=M:6UE7W9I97=E<E]D969A=6QT)RDI('L*("`@("`@
M("`@("`@("`@(&EF("@A*"1V:65W97(@/2`F34E-15]6:65W97(Z.F9A8W1O
M<GDH)'1H:7,M/FUI;65?<&%R="P@)'1H:7,M/FUI;65?<&%R="T^9V5T4')I
M;6%R>51Y<&4H*2`N("<O*B<I*2D@>PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7W9I97=E<B`]("1V:65W97(["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W=E8F-P<"YP:'``
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,S,T(#$P-3$U-#,T,3,W
M(#`R,S,S-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W=E8F-P<"!C;&%S
M<R!R96YD97)S(&]U="!V87)I;W5S(&-O;G1E;G0*("H@:6X@2%1-3"!F;W)M
M870@8GD@=7-I;F<@5V5B($,@4&QU<R!0;'5S+@H@*@H@*B!796(@0R!0;'5S
M('!L=7,Z(&AT='`Z+R]W96)C<'`N<V]U<F-E9F]R9V4N;F5T+PH@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R+W=E8F-P<"YP:'`L
M=B`Q+C$Q+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R
M869T;VYH86QL+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]W96)C<'`@97AT96YD<R!-24U%7U9I
M97=E<B!["@H@("`@+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT
M;'D@<V5T(&-O;G1E;G1S('5S:6YG(%=E8B!#(%!L=7,@4&QU<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@
M=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M9VQO8F%L("1M:6UE7V1R:79E<G,["@H@("`@("`@(')E<75I<F5?;VYC92`G
M2&]R9&4O34E-12]#;VYT96YT<RYP:'`G.PH@("`@("`@("1A='1A8VAM96YT
M(#T@34E-15]#;VYT96YT<SHZ=FEE=T%S071T86-H;65N="@I.PH*("`@("`@
M("`O*B!#:&5C:R!T;R!M86ME('-U<F4@=&AE('!R;V=R86T@86-T=6%L;'D@
M97AI<W1S+B`J+PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG=V5B8W!P)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B`G/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A
M;2!U<V5D('1O('9I97<@=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O
M=6YD(&]N('1H92!S>7-T96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;
M)W=E8F-P<"==6R=L;V-A=&EO;B==*2`N("<\+W!R93XG.PH@("`@("`@('T*
M"B`@("`@("`@+RH@0W)E871E('1E;7!O<F%R>2!F:6QE<R!F;W(@5V5B8W!P
M+B`J+PH@("`@("`@("1T;7!I;B`@/2!(;W)D93HZ9V5T5&5M<$9I;&4H)U=E
M8F-P<$EN)RD["B`@("`@("`@)'1M<&]U="`]($AO<F1E.CIG971496UP1FEL
M92@G5V5B8W!P3W5T)RD["@H@("`@("`@("\J(%=R:71E('1H92!C;VYT96YT
M<R!O9B!O=7(@8G5F9F5R('1O('1H92!T96UP;W)A<GD@:6YP=70@9FEL92X@
M*B\*("`@("`@("`D8V]N=&5N=',@/2`D=&AI<RT^;6EM95]P87)T+3YG971#
M;VYT96YT<R@I.PH@("`@("`@("1F:"`](&9O<&5N*"1T;7!I;BP@)W=B)RD[
M"B`@("`@("`@9G=R:71E*"1F:"P@)&-O;G1E;G1S+"!S=')L96XH)&-O;G1E
M;G1S*2D["B`@("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("\J($=E="!T
M:&4@97AT96YS:6]N(&9O<B!T:&4@;6EM92!T>7!E+B`J+PH@("`@("`@(&EN
M8VQU9&5?;VYC92`G2&]R9&4O34E-12]-86=I8RYP:'`G.PH@("`@("`@("1E
M>'0@/2!-24U%7TUA9VEC.CI-24U%5&]%>'0H)'1H:7,M/FUI;65?<&%R="T^
M9V5T5'EP92@I*3L*"B`@("`@("`@+RH@17AE8W5T92!796(@0R!0;'5S(%!L
M=7,N(%-P96-I9GEI;F<@=&AE(&EN(&%N9"!O=70@9FEL97,@9&ED;B=T"B`@
M("`@("`@("`@=V]R:R!F;W(@;64@8G5T('!I<&5S(&1I9"X@*B\*("`@("`@
M("!E>&5C*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W=E8F-P<"==6R=L;V-A
M=&EO;B==("X@(B`M+7!I<&4@+2UP:7!E("UX/21E>'0@+6P@+6$@+70@/"`D
M=&UP:6X@/B`D=&UP;W5T(BD["B`@("`@("`@)')E<W5L=',@/2!F:6QE7V=E
M=%]C;VYT96YT<R@D=&UP;W5T*3L*"B`@("`@("`@+RH@268@=V4@87)E(&YO
M="!D:7-P;&%Y:6YG(&EN;&EN92P@86QL('1H92!F;W)M871T:6YG(&ES(&%L
M<F5A9'D*("`@("`@("`@*B!D;VYE(&9O<B!U<RX@*B\*("`@("`@("!I9B`H
M)&%T=&%C:&UE;G0I('L*("`@("`@("`@("`@+RH@5&AE(&9I<G-T(#(@;&EN
M97,@87)E('1H92!#;VYT96YT+51Y<&4@;&EN92!A;F0@82!B;&%N:R!L:6YE
M"B`@("`@("`@("`@("`J('-O('=E('-H;W5L9"!R96UO=F4@=&AE;2!B969O
M<F4@;W5T<'5T=&EN9RX@*B\*("`@("`@("`@("`@<F5T=7)N('!R96=?<F5P
M;&%C92@B+RXJ7&XN*EQN+R(L("<G+"`D<F5S=6QT<RP@,2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S='EL92!S:&5E="P@<F5M;W9I
M;F<@86YY(&=L;V)A;"!B;V1Y(&9O<FUA='1I;F<*("`@("`@("`@*B!I9B!W
M92=R92!D:7-P;&%Y:6YG(&EN;&EN92X@*B\*("`@("`@("`D<F5S(#T@<')E
M9U]S<&QI="@G.R@\+W-T>6QE/BE\*#QS='EL92!T>7!E/2)T97AT+V-S<R(^
M*3LG+"`D<F5S=6QT<RD["B`@("`@("`@)'-T>6QE(#T@)')E<ULQ73L*("`@
M("`@("`D<W1Y;&4@/2!P<F5G7W)E<&QA8V4H)R]<;F)O9'E<<RL_>RXJ/WTO
M<R<L("<G+"`D<W1Y;&4I.PH*("`@("`@("`O*B!%>'1R86-T('1H92!C;VYT
M96YT+B`J+PH@("`@("`@("1R97,@/2!P<F5G7W-P;&ET*"<O7#Q<+S]P<F5<
M/B\G+"`D<F5S=6QT<RD["B`@("`@("`@)&)O9'D@/2`D<F5S6S%=.PH*("`@
M("`@("!R971U<FX@)SQS='EL93XG("X@)'-T>6QE("X@)SPO<W1Y;&4^/&1I
M=B!C;&%S<STB=V5B8W!P(B!S='EL93TB=VAI=&4M<W!A8V4Z<')E.V9O;G0M
M9F%M:6QY.FUO;F]S<&%C92(^)R`N("1B;V1Y("X@)SPO9&EV/B<["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E
M(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]Z:7`N<&AP````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#8V-R`Q,#4Q-30S-#$S
M-R`P,C(V-C(`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]Z:7`@8VQA<W,@
M<F5N9&5R<R!O=70@=&AE(&-O;G1E;G1S(&]F(%I)4"!F:6QE<R!I;B!(5$U,
M"B`J(&9O<FUA="X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]Z:7`N<&AP+'8@,2XS,"XQ,"XQ,"`R,#`V+S`R+S$P(#$S.C4T
M.C`T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,"TR,#`V($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P
M,BTR,#`V($UI8VAA96P@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N
M;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L
M:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P
M>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U
M8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R
M9&4@,BXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S
M<R!-24U%7U9I97=E<E]Z:7`@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@
M+RHJ"B`@("`@*B!296YD97(@;W5T('1H92!C=7)R96YT('II<"!C;VYT96YT
M<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A
M<F%M971E<G,@=&AE(%9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5N9&5R*"1T:&ES+3YM:6UE7W!A
M<G0M/F=E=$-O;G1E;G1S*"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@3W5T
M<'5T('1H92!F:6QE(&QI<W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=',@(%1H
M92!C;VYT96YT<R!O9B!T:&4@>FEP(&%R8VAI=F4N"B`@("`@*B!`<&%R86T@
M;6EX960@)&-A;&QB86-K("`@5&AE(&-A;&QB86-K(&9U;F-T:6]N('1O('5S
M92!O;B!T:&4@>FEP9FEL90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@9FEL92!L:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5N9&5R
M*"1C;VYT96YT<RP@)&-A;&QB86-K(#T@;G5L;"D*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)TAO<F1E+T-O;7!R97-S+G!H<"<["@H@("`@("`@("1Z
M:7`@/2`F2&]R9&5?0V]M<')E<W,Z.G-I;F=L971O;B@G>FEP)RD["@H@("`@
M("`@("\J($UA:V4@<W5R92!T:&ES(&ES(&$@=F%L:60@>FEP(&9I;&4N("HO
M"B`@("`@("`@:68@*"1Z:7`M/F-H96-K6FEP1&%T82@D8V]N=&5N=',I(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@)SQP<F4^)R`N(%\H(E1H
M:7,@9&]E<R!N;W0@87!P96%R('1O(&)E(&$@=F%L:60@>FEP(&9I;&4N(BD@
M+B`G/"]P<F4^)SL*("`@("`@("!]"@H@("`@("`@("1Z:7!);F9O(#T@)'II
M<"T^9&5C;VUP<F5S<R@D8V]N=&5N=',L(&%R<F%Y*"=A8W1I;VXG(#T^($A/
M4D1%7T-/35!215-37UI)4%],25-4*2D["B`@("`@("`@:68@*&ES7V$H)'II
M<$EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1Z
M:7!);F9O+3YG971-97-S86=E*"D["B`@("`@("`@?0H@("`@("`@("1F:6QE
M0V]U;G0@/2!C;W5N="@D>FEP26YF;RD["@H@("`@("`@(')E<75I<F5?;VYC
M92`G2&]R9&4O5&5X="YP:'`G.PH*("`@("`@("`D=&5X="`]("<\<W1R;VYG
M/B<@+B!H=&UL<W!E8VEA;&-H87)S*'-P<FEN=&8H7R@B0V]N=&5N=',@;V8@
M7"(E<UPB(BDL("1T:&ES+3YM:6UE7W!A<G0M/F=E=$YA;64H*2DI("X@)SH\
M+W-T<F]N9SXG("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G/'1A8FQE/CQT
M<CX\=&0@86QI9VX](FQE9G0B/CQT=#X\<W!A;B!C;&%S<STB9FEX960B/B<[
M"B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ:'1M;$%L;%-P86-E<RA?*")!<F-H
M:79E($YA;64B*2`N("<Z("<@+B`D=&AI<RT^;6EM95]P87)T+3YG971.86UE
M*"DI("X@(EQN(CL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A
M8V5S*%\H(D%R8VAI=F4@1FEL92!3:7IE(BD@+B`G.B`G("X@<W1R;&5N*"1C
M;VYT96YT<RD@+B`G(&)Y=&5S)RD@+B`B7&XB.PH@("`@("`@("1T97AT("X]
M(%1E>'0Z.FAT;6Q!;&Q3<&%C97,H*"1F:6QE0V]U;G0@(3T@,2D@/R!S<')I
M;G1F*%\H(D9I;&4@0V]U;G0Z("5S(&9I;&5S(BDL("1F:6QE0V]U;G0I(#H@
M<W!R:6YT9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE(BDL("1F:6QE0V]U;G0I
M*3L*("`@("`@("`D=&5X="`N/2`B7&Y<;B(["B`@("`@("`@)'1E>'0@+CT@
M5&5X=#HZ:'1M;$%L;%-P86-E<R@*("`@("`@("`@("`@("`@("`@("`@<W1R
M7W!A9"A?*")&:6QE($YA;64B*2P@("`@("`U,"P@)R`G+"!35%)?4$%$7U))
M1TA4*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B071T<FEB
M=71E<R(I+"`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H7R@B4VEZ92(I+"`@("`@("`@("`@,3`L
M("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T
M<E]P860H7R@B36]D:69I960@1&%T92(I+"`@,3DL("<@)RP@4U127U!!1%],
M1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B365T:&]D
M(BDL("`@("`@("`@,3`L("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@
M("`@("`@("`@("`@('-T<E]P860H7R@B0U)#(BDL("`@("`@("`@("`@,3`L
M("<@)RP@4U127U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T
M<E]P860H7R@B4F%T:6\B*2P@("`@("`@("`@(#<L("<@)RP@4U127U!!1%],
M1494*0H@("`@("`@("`@("`@("`@("D@+B`B7&XB.PH*("`@("`@("`D=&5X
M="`N/2!S=')?<F5P96%T*"<M)RP@,3$V*2`N(")<;B(["@H@("`@("`@(&9O
M<F5A8V@@*"1Z:7!);F9O(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@
M("`D<F%T:6\@/2`H96UP='DH)'9A;%LG<VEZ92==*2D@/R`P(#H@,3`P("H@
M*"1V86Q;)V-S:7IE)UT@+R`D=F%L6R=S:7IE)UTI.PH*("`@("`@("`@("`@
M)'9A;%LG;F%M92==(#T@<W1R7W!A9"@D=F%L6R=N86UE)UTL(#4P+"`G("<L
M(%-44E]0041?4DE'2%0I.PH@("`@("`@("`@("`D=F%L6R=A='1R)UT@/2!S
M=')?<&%D*"1V86Q;)V%T='(G72P@,3`L("<@)RP@4U127U!!1%],1494*3L*
M("`@("`@("`@("`@)'9A;%LG<VEZ92==(#T@<W1R7W!A9"@D=F%L6R=S:7IE
M)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D["B`@("`@("`@("`@("1V86Q;
M)V1A=&4G72`]('-T<E]P860H<W1R9G1I;64H(B5D+25B+259("5(.B5-(BP@
M)'9A;%LG9&%T92==*2P@,3DL("<@)RP@4U127U!!1%],1494*3L*("`@("`@
M("`@("`@)'9A;%LG;65T:&]D)UT@/2!S=')?<&%D*"1V86Q;)VUE=&AO9"==
M+"`Q,"P@)R`G+"!35%)?4$%$7TQ%1E0I.PH@("`@("`@("`@("`D=F%L6R=C
M<F,G72`]('-T<E]P860H)'9A;%LG8W)C)UTL(#$P+"`G("<L(%-44E]0041?
M3$5&5"D["B`@("`@("`@("`@("1V86Q;)W)A=&EO)UT@/2!S=')?<&%D*'-P
M<FEN=&8H(B4Q+C%F)24B+"`D<F%T:6\I+"`W+"`G("<L(%-44E]0041?3$5&
M5"D["@H@("`@("`@("`@("`D=F%L(#T@87)R87E?;6%P*&%R<F%Y*"=497AT
M)RP@)VAT;6Q!;&Q3<&%C97,G*2P@)'9A;"D["@H@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)&-A;&QB86-K*2D@>PH@("`@("`@("`@("`@("`@)'9A;"`]
M(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)&ME>2P@)'9A;"D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T97AT("X]("1V86Q;)VYA;64G72`N
M("1V86Q;)V%T='(G72`N("1V86Q;)W-I>F4G72`N"B`@("`@("`@("`@("`@
M("`@("`@("1V86Q;)V1A=&4G72`N("1V86Q;)VUE=&AO9"==("X@)'9A;%LG
M8W)C)UT@+@H@("`@("`@("`@("`@("`@("`@("`D=F%L6R=R871I;R==("X@
M(EQN(CL*("`@("`@("!]"@H@("`@("`@("1T97AT("X]('-T<E]R97!E870H
M)RTG+"`Q,38I("X@(EQN(CL*("`@("`@("`D=&5X="`N/2`G/"]S<&%N/CPO
M='0^/"]T9#X\+W1R/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N(&YL,F)R
M*"1T97AT*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8V]N
M=&5N="UT>7!E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M;VYT96YT+71Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[
M(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W1G>BYP:'``````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$P-#4V(#$P-3$U-#,T,3,W(#`R,C8V,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W1G>B!C;&%S<R!R96YD97)S(&]U
M="!P;&%I;B!O<B!G>FEP<&5D('1A<F)A;&QS(&EN($A434PN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TU)344O34E-12]6:65W97(O=&=Z+G!H<"QV(#$N
M,S<N,3`N,3,@,C`P-B\P,2\R-B`Q,#HR,CHT-B!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#$Y.3DM,C`P-B!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R
M96-O:6PN;W)G/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI8VAA96P@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!!;FEL($UA9&AA=F%P961D>2`\86YI;$!R96-O:6PN
M;W)G/@H@*B!`875T:&]R("!-:6-H865L($-O8VAR86YE(#QM:6ME0&=R869T
M;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA
M9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W1G
M>B!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@=&%R(&9I;&4@8V]N=&5N=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T
M97)S('1H92!6:65W97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%1H92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5N9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(')E<75I<F5?;VYC92`G2&]R9&4O0V]M<')E<W,N<&AP)SL*"B`@("`@
M("`@)&-O;G1E;G1S(#T@)'1H:7,M/FUI;65?<&%R="T^9V5T0V]N=&5N=',H
M*3L*"B`@("`@("`@+RH@3VYL>2!D96-O;7!R97-S(&=Z:7!P960@9FEL97,N
M("HO"B`@("`@("`@)'-U8G1Y<&4@/2`D=&AI<RT^;6EM95]P87)T+3YG9713
M=6)4>7!E*"D["B`@("`@("`@:68@*"@D<W5B='EP92`]/2`G>"UC;VUP<F5S
M<V5D+71A<B<I('Q\"B`@("`@("`@("`@("@D<W5B='EP92`]/2`G=&=Z)RD@
M?'P*("`@("`@("`@("`@*"1S=6)T>7!E(#T]("=X+71G>B<I('Q\"B`@("`@
M("`@("`@("@D<W5B='EP92`]/2`G9WII<"<I('Q\"B`@("`@("`@("`@("@D
M<W5B='EP92`]/2`G>"UG>FEP)RD@?'P*("`@("`@("`@("`@*"1S=6)T>7!E
M(#T]("=X+6=Z:7`M8V]M<')E<W-E9"<I('Q\"B`@("`@("`@("`@("@D<W5B
M='EP92`]/2`G>"UG=&%R)RDI('L*("`@("`@("`@("`@)&=Z:7`@/2`F2&]R
M9&5?0V]M<')E<W,Z.G-I;F=L971O;B@G9WII<"<I.PH@("`@("`@("`@("`D
M8V]N=&5N=',@/2`D9WII<"T^9&5C;VUP<F5S<R@D8V]N=&5N=',I.PH@("`@
M("`@("`@("!I9B`H96UP='DH)&-O;G1E;G1S*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("<\<')E/B<@+B!?*")5;F%B;&4@=&\@;W!E;B!C;VUP<F5S
M<V5D(&%R8VAI=F4N(BD@+B`G/"]P<F4^)SL*("`@("`@("`@("`@?2!E;'-E
M:68@*&ES7V$H)&-O;G1E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)SQP<F4^)R`N("1C;VYT96YT<RT^9V5T365S<V%G
M92@I("X@)SPO<')E/B<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@D<W5B='EP92`]/2`G9WII<"<@?'P*("`@("`@("`@("`@)'-U
M8G1Y<&4@/3T@)W@M9WII<"<@?'P*("`@("`@("`@("`@)'-U8G1Y<&4@/3T@
M)W@M9WII<"UC;VUP<F5S<V5D)RD@>PH@("`@("`@("`@("!G;&]B86P@)&-O
M;F8["B`@("`@("`@("`@(')E<75I<F5?;VYC92`G2&]R9&4O34E-12]-86=I
M8RYP:'`G.PH@("`@("`@("`@("`D;6EM95]T>7!E(#T@34E-15]-86=I8SHZ
M86YA;'EZ941A=&$H)&-O;G1E;G1S+"!I<W-E="@D8V]N9ELG;6EM92==6R=M
M86=I8U]D8B==*2`_("1C;VYF6R=M:6UE)UU;)VUA9VEC7V1B)UT@.B!N=6QL
M*3L*("`@("`@("`@("`@:68@*"$D;6EM95]T>7!E*2!["B`@("`@("`@("`@
M("`@("`D;6EM95]T>7!E(#T@7R@B56YK;F]W;B(I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(')E='5R;B`G/'!R93XG("X@7R@B0V]N=&5N="!T>7!E
M(&]F(&-O;7!R97-S960@9FEL93H@(BD@+B`D;6EM95]T>7!E("X@)SPO<')E
M/B<["B`@("`@("`@?0H*("`@("`@("`O*B!/8G1A:6X@=&AE(&QI<W0@;V8@
M9FEL97,O9&%T82!I;B!T:&4@=&%R(&9I;&4N("HO"B`@("`@("`@)'1A<B`]
M("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE=&]N*"=T87(G*3L*"B`@("`@("`@
M)'1A<D1A=&$@/2`D=&%R+3YD96-O;7!R97-S*"1C;VYT96YT<RD["B`@("`@
M("`@:68@*&ES7V$H)'1A<D1A=&$L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("<\<')E/B<@+B`D=&%R1&%T82T^9V5T365S<V%G92@I
M("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`D9FEL94-O=6YT(#T@
M8V]U;G0H)'1A<D1A=&$I.PH*("`@("`@("!I;F-L=61E7V]N8V4@)TAO<F1E
M+U1E>'0N<&AP)SL*"B`@("`@("`@)'1E>'0@(#T@)SQS=')O;F<^)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H<W!R:6YT9BA?*")#;VYT96YT<R!O9B!<(B5S7"(B
M*2P@)'1H:7,M/FUI;65?<&%R="T^9V5T3F%M92@I*2D@+B`G.CPO<W1R;VYG
M/B<@+B`B7&XB.PH@("`@("`@("1T97AT("X]("<\=&%B;&4^/'1R/CQT9"!A
M;&EG;CTB;&5F="(^/'1T/CQS<&%N(&-L87-S/2)F:7AE9"(^)SL*("`@("`@
M("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*%\H(D%R8VAI=F4@3F%M
M92(I("X@)SH@("<@+B`D=&AI<RT^;6EM95]P87)T+3YG971.86UE*"DI("X@
M(EQN(CL*("`@("`@("`D=&5X="`N/2!497AT.CIH=&UL06QL4W!A8V5S*%\H
M(D%R8VAI=F4@1FEL92!3:7IE(BD@+B`G.B`G("X@<W1R;&5N*"1C;VYT96YT
M<RD@+B`G(&)Y=&5S)RD@+B`B7&XB.PH@("`@("`@("1T97AT("X](%1E>'0Z
M.FAT;6Q!;&Q3<&%C97,H*"1F:6QE0V]U;G0@(3T@,2D@/R!S<')I;G1F*%\H
M(D9I;&4@0V]U;G0Z("5S(&9I;&5S(BDL("1F:6QE0V]U;G0I(#H@<W!R:6YT
M9BA?*")&:6QE($-O=6YT.B`E<R!F:6QE(BDL("1F:6QE0V]U;G0I*3L*("`@
M("`@("`D=&5X="`N/2`B7&Y<;B(["B`@("`@("`@)'1E>'0@+CT@5&5X=#HZ
M:'1M;$%L;%-P86-E<R@*("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?
M*")&:6QE($YA;64B*2P@("`@(#8R+"`G("<L(%-44E]0041?4DE'2%0I("X*
M("`@("`@("`@("`@("`@("`@("`@<W1R7W!A9"A?*")!='1R:6)U=&5S(BDL
M("`@(#$U+"`G("<L(%-44E]0041?3$5&5"D@+@H@("`@("`@("`@("`@("`@
M("`@("!S=')?<&%D*%\H(E-I>F4B*2P@("`@("`@("`@,3`L("<@)RP@4U12
M7U!!1%],1494*2`N"B`@("`@("`@("`@("`@("`@("`@('-T<E]P860H7R@B
M36]D:69I960@1&%T92(I+"`Q.2P@)R`G+"!35%)?4$%$7TQ%1E0I"B`@("`@
M("`@("`@("`@("`@*2`N(")<;B(["@H@("`@("`@("1T97AT("X]('-T<E]R
M97!E870H)RTG+"`Q,#8I("X@(EQN(CL*"B`@("`@("`@9F]R96%C:"`H)'1A
M<D1A=&$@87,@)'9A;"D@>PH@("`@("`@("`@("1T97AT("X](%1E>'0Z.FAT
M;6Q!;&Q3<&%C97,H"B`@("`@("`@("`@("`@("`@("`@("`@('-T<E]P860H
M)'9A;%LG;F%M92==+"`V,BP@)R`G+"!35%)?4$%$7U))1TA4*2`N"B`@("`@
M("`@("`@("`@("`@("`@("`@('-T<E]P860H)'9A;%LG871T<B==+"`Q-2P@
M)R`G+"!35%)?4$%$7TQ%1E0I("X*("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R7W!A9"@D=F%L6R=S:7IE)UTL(#$P+"`G("<L(%-44E]0041?3$5&5"D@
M+@H@("`@("`@("`@("`@("`@("`@("`@("!S=')?<&%D*'-T<F9T:6UE*"(E
M9"TE8BTE62`E2#HE32(L("1V86Q;)V1A=&4G72DL(#$Y+"`G("<L(%-44E]0
M041?3$5&5"D*("`@("`@("`@("`@("`@("`@("`I("X@(EQN(CL*("`@("`@
M("!]"@H@("`@("`@("1T97AT("X]('-T<E]R97!E870H)RTG+"`Q,#8I("X@
M(EQN(CL*("`@("`@("`D=&5X="`N/2`G/"]S<&%N/CPO='0^/"]T9#X\+W1R
M/CPO=&%B;&4^)SL*"B`@("`@("`@<F5T=7)N(&YL,F)R*"1T97AT*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@8V]N=&5N="UT>7!E"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT+71Y<&4@
M;V8@=&AE(&]U='!U="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5'EP92@I
M"B`@("!["B`@("`@("`@<F5T=7)N("=T97AT+VAT;6P[(&-H87)S970])R`N
M($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O34E-12]6:65W97(O<V]U<F-E+G!H<```````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(T-#<@,3`U,34T,S0Q,S<@,#(S,S4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@34E-15]6:65W97)?<V]U<F-E(&-L87-S(&ES(&$@8VQA<W,@9F]R(&%N
M>2!V:65W97(@=&AA="!W86YT<PH@*B!T;R!P<F]V:61E(&QI;F4@;G5M8F5R
M<R!T;R!E>'1E;F0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O34E-
M12]6:65W97(O<V]U<F-E+G!H<"QV(#$N.2XQ,"XY(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7TU)
M345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]S;W5R8V4@97AT96YD
M<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@("`@*B!!9&0@;&EN92!N=6UB
M97)S('1O(&$@8FQO8VL@;V8@8V]D92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;V1E("!4:&4@8V]D92!T;R!N=6UB97(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QI;F5.=6UB97(H)&-O9&4L("1L:6YE8G)E86L@/2`B7&XB
M*0H@("`@>PH@("`@("`@("1L:6YE<R`]('-U8G-T<E]C;W5N="@D8V]D92P@
M)&QI;F5B<F5A:RD@*R`Q.PH@("`@("`@("1H=&UL(#T@)SQT86)L92!C;&%S
M<STB;&EN94YU;6)E<F5D(B!C96QL<W!A8VEN9STB,"(^/'1R/CQT:#XG.PH@
M("`@("`@(&9O<B`H)&P@/2`Q.R`D;"`\/2`D;&EN97,[("1L*RLI('L*("`@
M("`@("`@("`@)&AT;6P@+CT@<W!R:6YT9B@G/&$@:60](FPE<R(@:')E9CTB
M(VPE<R(^)7,\+V$^/&)R("\^)RP@)&PL("1L+"`D;"D@+B`B7&XB.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)&AT;6P@+B`G/"]T:#X\=&0^)R`N("1C
M;V1E("X@)SPO=&0^/"]T<CX\+W1A8FQE/B<["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD
M97)E9"!C;VYT96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@8V]N=&5N="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H
M=&UL.R!C:&%R<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]T;F5F+G!H
M<```````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0T,"`Q,#4Q-30S
M-#$S-R`P,C,P,#,`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]T;F5F(&-L
M87-S(&%L;&]W<R!-4RU43D5&(&%T=&%C:&UE;G1S('1O(&)E(&1I<W!L87EE
M9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%+U9I97=E<B]T
M;F5F+G!H<"QV(#$N,3,N,3`N.2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%
M>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IA;B!38VAN96ED97(@
M/&IA;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E
M;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z
M0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?
M5FEE=V5R7W1N968@97AT96YD<R!-24U%7U9I97=E<B!["@H@("`@+RHJ"B`@
M("`@*B!296YD97(@;W5T('1H92!C=7)R96YT('1N968@9&%T82X*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@
M=&AE('9I97=E<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M<F5Q=6ER95]O;F-E("=(;W)D92]#;VUP<F5S<RYP:'`G.PH*("`@("`@("`D
M=&YE9B`]("9(;W)D95]#;VUP<F5S<SHZ<VEN9VQE=&]N*"=T;F5F)RD["@H@
M("`@("`@("1D871A(#T@)SQT86)L92!B;W)D97(](C$B/B<["B`@("`@("`@
M)&EN9F\@/2`D=&YE9BT^9&5C;VUP<F5S<R@D=&AI<RT^;6EM95]P87)T+3YG
M971#;VYT96YT<R@I*3L*("`@("`@("!I9B`H96UP='DH)&EN9F\I('Q\(&ES
M7V$H)&EN9F\L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&1A=&$@
M+CT@)SQT<CX\=&0^)R`N(%\H(DU3+51.148@071T86-H;65N="!C;VYT86EN
M960@;F\@9&%T82XB*2`N("<\+W1D/CPO='(^)SL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D9&%T82`N/2`G/'1R/CQT9#XG("X@7R@B3F%M92(I
M("X@)SPO=&0^/'1D/B<@+B!?*")-:6UE(%1Y<&4B*2`N("<\+W1D/CPO='(^
M)SL*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F\@87,@)'!A<G0I('L*("`@
M("`@("`@("`@("`@("1D871A("X]("<\='(^/'1D/B<@+B`D<&%R=%LG;F%M
M92==("X@)SPO=&0^/'1D/B<@+B`D<&%R=%LG='EP92==("X@)R\G("X@)'!A
M<G1;)W-U8G1Y<&4G72`N("<\+W1D/CPO='(^)SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("`D9&%T82`N/2`G/"]T86)L93XG.PH*("`@("`@
M("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N="!T
M>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y
M<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R<V5T
M/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<W)C:&EG:&QI=&4N
M<&AP````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8V,#<@,3`U,34T,S0Q,S<@
M,#(T,S8T`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]S<F-H:6=H
M;&ET92!C;&%S<R!R96YD97)S(&]U="!V87)I;W5S(&-O;G1E;G0@:6X@2%1-
M3`H@*B!F;W)M870@8GD@=7-I;F<@4V]U<F-E+6AI9VAL:6=H="X*("H*("H@
M4V]U<F-E+6AI9VAL:6=H=#H@:'1T<#HO+W=W=RYG;G4N;W)G+W-O9G1W87)E
M+W-R8RUH:6=H;&ET92\*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-
M24U%+U9I97=E<B]S<F-H:6=H;&ET92YP:'`L=B`Q+C$T+C$P+C@@,C`P-B\P
M-B\P,2`P,SHP.#HU,R!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?34E-15]6:65W97(*("HO"F-L87-S($U)345?
M5FEE=V5R7W-R8VAI9VAL:71E(&5X=&5N9',@34E-15]6:65W97)?<V]U<F-E
M('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L>2!S
M970@8V]N=&5N=',@=7-I;F<@4V]U<F-E+6AI9VAL:6=H=`H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@<&%R86UE=&5R<R!T:&4@
M=FEE=V5R(&UA>2!N965D+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!4:&4@<F5N9&5R960@8V]N=&5N=',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E;F1E<B@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B
M86P@)&UI;65?9')I=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S
M=7)E('1H92!P<F]G<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("!I
M9B`H(69I;&5?97AI<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI
M9VAL:71E)UU;)VQO8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B`G
M/'!R93XG("X@<W!R:6YT9BA?*")4:&4@<')O9W)A;2!U<V5D('1O('9I97<@
M=&AI<R!D871A('1Y<&4@*"5S*2!W87,@;F]T(&9O=6YD(&]N('1H92!S>7-T
M96TN(BDL("1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)W-R8VAI9VAL:71E)UU;
M)VQO8V%T:6]N)UTI("X@)SPO<')E/B<["B`@("`@("`@?0H*("`@("`@("`O
M*B!#<F5A=&4@=&5M<&]R87)Y(&9I;&5S(&9O<B!796)C<'`N("HO"B`@("`@
M("`@)'1M<&EN("`]($AO<F1E.CIG971496UP1FEL92@G4W)C26XG*3L*("`@
M("`@("`D=&UP;W5T(#T@2&]R9&4Z.F=E=%1E;7!&:6QE*"=3<F-/=70G+"!F
M86QS92D["@H@("`@("`@("\J(%=R:71E('1H92!C;VYT96YT<R!O9B!O=7(@
M8G5F9F5R('1O('1H92!T96UP;W)A<GD@:6YP=70@9FEL92X@*B\*("`@("`@
M("`D8V]N=&5N=',@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I
M.PH@("`@("`@("1F:"`](&9O<&5N*"1T;7!I;BP@)W=B)RD["B`@("`@("`@
M9G=R:71E*"1F:"P@)&-O;G1E;G1S+"!S=')L96XH)&-O;G1E;G1S*2D["B`@
M("`@("`@9F-L;W-E*"1F:"D["@H@("`@("`@("\J($1E=&5R;6EN92!T:&4@
M;&%N9W5A9V4@9G)O;2!T:&4@;6EM92!T>7!E+B`J+PH@("`@("`@("1L86YG
M(#T@)R<["B`@("`@("`@<W=I=&-H("@D=&AI<RT^;6EM95]P87)T+3YG9714
M>7!E*"DI('L*("`@("`@("!C87-E("=T97AT+W@M:F%V82<Z"B`@("`@("`@
M("`@("1L86YG(#T@)VIA=F$G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`G=&5X="]X+6-S<F,G.@H@("`@("`@(&-A<V4@)W1E>'0O>"UC
M*RMS<F,G.@H@("`@("`@(&-A<V4@)W1E>'0O8W!P)SH*("`@("`@("`@("`@
M)&QA;F<@/2`G8W!P)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@)V%P<&QI8V%T:6]N+W@M<&5R;"<Z"B`@("`@("`@("`@("1L86YG(#T@
M)W!E<FPG.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G87!P
M;&EC871I;VXO>"UP:'`G.@H@("`@("`@(&-A<V4@)W@M97AT96YS:6]N+W!H
M<',G.@H@("`@("`@(&-A<V4@)W@M97AT96YS:6]N+W!H<#-S)SH*("`@("`@
M("!C87-E("=A<'!L:6-A=&EO;B]X+6AT='!D+7!H<"<Z"B`@("`@("`@8V%S
M92`G87!P;&EC871I;VXO>"UH='1P9"UP:'`S)SH*("`@("`@("!C87-E("=A
M<'!L:6-A=&EO;B]X+6AT='!D+7!H<',G.@H@("`@("`@("`@("`D;&%N9R`]
M("=P:'`S)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V%P
M<&QI8V%T:6]N+W@M<'ET:&]N)SH*("`@("`@("`@("`@)&QA;F<@/2`G<'ET
M:&]N)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`O+R`D;&%N
M9R`]("=P<F]L;V<G.PH@("`@("`@("`@("`O+R!B<F5A:SL*"B`@("`@("`@
M("`@("\O("1L86YG(#T@)V9L97@G.PH@("`@("`@("`@("`O+R!B<F5A:SL*
M"B`@("`@("`@("`@("\O("1L86YG(#T@)V-H86YG96QO9R<["B`@("`@("`@
M("`@("\O(&)R96%K.PH*("`@("`@("`@("`@+R\@)&QA;F<@/2`G<G5B>2<[
M"B`@("`@("`@("`@("\O(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+RH@
M17AE8W5T92!3;W5R8V4M2&EG:&QI=&4N("HO"B`@("`@("`@97AE8R@D;6EM
M95]D<FEV97)S6R=H;W)D92==6R=S<F-H:6=H;&ET92==6R=L;V-A=&EO;B==
M("X@(B`M+7-R8RUL86YG("1L86YG("TM;W5T+69O<FUA="!X:'1M;"`M+6EN
M<'5T("1T;7!I;B`M+6]U='!U="`D=&UP;W5T(BD["B`@("`@("`@)')E<W5L
M=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP;W5T*3L*("`@("`@("!U;FQI
M;FLH)'1M<&]U="D["@H@("`@("`@("\J($5D=6-A=&5D($=U97-S(&%T('=H
M971H97(@=V4@87)E(&EN;&EN92!O<B!N;W0N("HO"B`@("`@("`@:68@*&AE
M861E<G-?<V5N="@I('Q\(&]B7V=E=%]L96YG=&@H*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB=69F97)/=71P
M=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T96UP
M;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+6AE861E<BYI;F,G*2`N"B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT<RD@+@H@
M("`@("`@("`@("`@("`@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E)RP@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO<F1E
M)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+W!D9BYP:'``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-3,Q(#$P-3$U-#,T,3,W
M(#`R,C8Q-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7W!D9B!C;&%S<R!S
M:6UP;'D@;W5T<'5T<R!T:&4@4$1&(&9I;&4@=VET:"!T:&4@8V]N=&5N="UT
M>7!E"B`J("=A<'!L:6-A=&EO;B]P9&8G(&5N86)L:6YG('=E8B!B<F]W<V5R
M<R!W:71H(&$@4$1&('9I97=E<B!P;'5G:6X@=&\@=FEE=PH@*B!T:&4@4$1&
M(&9I;&4@:6YS:61E('1H92!B<F]W<V5R+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W!D9BYP:'`L=B`Q+C,N,3(N-2`R,#`V
M+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P
M,RTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I
M;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R
M"B`J+PIC;&%S<R!-24U%7U9I97=E<E]P9&8@97AT96YD<R!-24U%7U9I97=E
M<B!["@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&-O;G1E;G0M='EP92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0M='EP
M92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)V%P<&QI8V%T:6]N+W!D9B<["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O;RYP
M:'``````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W,C(Q(#$P-3$U
M-#,T,3,W(#`R,C8T-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@5&AE($U)345?5FEE=V5R7V]O;R!C
M;&%S<R!R96YD97)S(&]U="!/<&5N3V9F:6-E+F]R9PH@*B!D;V-U;65N=',@
M:6X@2%1-3"!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TU)344O
M34E-12]6:65W97(O;V]O+G!H<"QV(#$N,30N,3`N-R`R,#`V+S`Q+S`Q(#(Q
M.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA
M<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC;VT^"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L;RYC
M;VT^"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-24U%
M7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?;V]O(&5X=&5N9',@34E-
M15]6:65W97(@>PH*("`@("\J*@H@("`@("H@4F5N9&5R(&]U="!T:&4@8W5R
M<F5N="!D871A+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!;GD@<&%R86UE=&5R<R!T:&4@5FEE=V5R(&UA>2!N965D+@H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F5N9&5R960@8V]N=&5N=',N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R86US(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D=7-E7WAS;'0@/2!5=&EL.CIE>'1E;G-I;VY%
M>&ES=',H)WAS;'0G*2!\?"!F=6YC=&EO;E]E>&ES=',H)V1O;7AM;%]X<VQT
M7W-T>6QE<VAE971?9FEL92<I.PH@("`@("`@(&EF("@D=7-E7WAS;'0I('L*
M("`@("`@("`@("`@)'1M<&1I<B`](%5T:6PZ.F-R96%T951E;7!$:7(H=')U
M92D["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T-O
M;7!R97-S+G!H<"<["B`@("`@("`@)'AM;%]T86=S("`](&%R<F%Y*"=T97AT
M.G`G+"`G=&%B;&4Z=&%B;&4@)RP@)W1A8FQE.G1A8FQE+7)O=R<L("=T86)L
M93IT86)L92UC96QL)RP@)W1A8FQE.FYU;6)E<BUC;VQU;6YS+7-P86YN960]
M)RD["B`@("`@("`@)&AT;6Q?=&%G<R`](&%R<F%Y*"=P)RP@)W1A8FQE(&)O
M<F1E<CTB,"(@8V5L;'-P86-I;F<](C$B(&-E;&QP861D:6YG/2(P(B`G+"`G
M='(@8F=C;VQO<CTB(V-C8V-C8R(G+"`G=&0G+"`G8V]L<W!A;CTG*3L*("`@
M("`@("`D>FEP(#T@)DAO<F1E7T-O;7!R97-S.CIS:6YG;&5T;VXH)WII<"<I
M.PH@("`@("`@("1L:7-T(#T@)'II<"T^9&5C;VUP<F5S<R@D=&AI<RT^;6EM
M95]P87)T+3YG971#;VYT96YT<R@I+`H@("`@("`@("`@("!A<G)A>2@G86-T
M:6]N)R`]/B!(3U)$15]#3TU04D534U]:25!?3$E35"DI.PH@("`@("`@(&9O
M<F5A8V@@*"1L:7-T(&%S("1K97D@/3X@)&9I;&4I('L*("`@("`@("`@("`@
M:68@*"1F:6QE6R=N86UE)UT@/3T@)V-O;G1E;G0N>&UL)R!\?`H@("`@("`@
M("`@("`@("`@)&9I;&5;)VYA;64G72`]/2`G<W1Y;&5S+GAM;"<@?'P*("`@
M("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/3T@)VUE=&$N>&UL)RD@>PH@
M("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D>FEP+3YD96-O;7!R97-S*"1T
M:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G1S*"DL"B`@("`@("`@("`@("`@
M("`@("`@87)R87DH)V%C=&EO;B<@/3X@2$]21$5?0T]-4%)%4U-?6DE07T1!
M5$$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)VEN9F\G("`@/3X@)&QI
M<W0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)VME>2<@("`@/3X@)&ME
M>2DI.PH@("`@("`@("`@("`@("`@:68@*"1U<V5?>'-L="D@>PH@("`@("`@
M("`@("`@("`@("`@("1F<"`](&9O<&5N*"1T;7!D:7(@+B`D9FEL95LG;F%M
M92==+"`G=R<I.PH@("`@("`@("`@("`@("`@("`@(&9W<FET92@D9G`L("1C
M;VYT96YT*3L*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D9FEL95LG;F%M92==(#T]("=C;VYT
M96YT+GAM;"<I('L*("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="`]('-T
M<E]R97!L86-E*"1X;6Q?=&%G<RP@)&AT;6Q?=&%G<RP@)&-O;G1E;G0I.PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H
M(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G>'-L="<I*2!["B`@("`@("`@("`@
M(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES
M=',H)V1O;7AM;%]X<VQT7W-T>6QE<VAE971?9FEL92<I*2!["B`@("`@("`@
M("`@("\O(%5S92!$3TU834P*("`@("`@("`@("`@)'AS;'0@/2!D;VUX;6Q?
M>'-L=%]S='EL97-H965T7V9I;&4H9&ER;F%M92A?7T9)3$5?7RD@+B`G+V]O
M;R]M86EN7VAT;6PN>'-L)RD["B`@("`@("`@("`@("1D;VT@(#T@9&]M>&UL
M7V]P96Y?9FEL92@D=&UP9&ER("X@)V-O;G1E;G0N>&UL)RD["B`@("`@("`@
M("`@("1R97-U;'0@/2!`)'AS;'0M/G!R;V-E<W,H)&1O;2P@87)R87DH)VUE
M=&%&:6QE55),)R`]/B`D=&UP9&ER("X@)VUE=&$N>&UL)RP@)W-T>6QE<T9I
M;&554DPG(#T^("1T;7!D:7(@+B`G<W1Y;&5S+GAM;"<L("=D:7-A8FQE2F%V
M82<@/3X@=')U92DI.PH@("`@("`@("`@("!R971U<FX@4W1R:6YG.CIC;VYV
M97)T0VAA<G-E="@D>'-L="T^<F5S=6QT7V1U;7!?;65M*"1R97-U;'0I+"`G
M551&+3@G+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@57-E(%A33%0*("`@("`@("`@("`@)'AS;'0@/2!X
M<VQT7V-R96%T92@I.PH@("`@("`@("`@("`D<F5S=6QT(#T@0'AS;'1?<')O
M8V5S<R@D>'-L="P@)'1M<&1I<B`N("=C;VYT96YT+GAM;"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]O;V\O;6%I;E]H=&UL+GAS;"<L(&YU;&PL(&YU;&PL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M971A1FEL9552
M3"<@/3X@)'1M<&1I<B`N("=M971A+GAM;"<L("=S='EL97-&:6QE55),)R`]
M/B`D=&UP9&ER("X@)W-T>6QE<RYX;6PG+"`G9&ES86)L94IA=F$G(#T^('1R
M=64I*3L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@>'-L=%]E<G)O<B@D>'-L="D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@>'-L=%]F<F5E*"1X<VQT*3L*("`@("`@("`@("`@
M<F5T=7)N(%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)')E<W5L="P@)U541BTX
M)RP@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!T:&4@34E-12!C;VYT96YT('1Y<&4@;V8@=&AE
M(')E;F1E<F5D(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!C;VYT96YT('1Y<&4@;V8@=&AE(&]U='!U="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+TU)344O5FEE=V5R+W-E8W5R:71Y+G!H<```````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`U-3$T(#$P-3$U-#,T,3,W(#`R,S<R,@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@5&AE
M($U)345?5FEE=V5R7W-E8W5R:71Y(&-L87-S(&ES(&$@=W)A<'!E<B!U<V5D
M('1O(&QO860@=&AE(&%P<')O<')I871E"B`J($U)345?5FEE=V5R(&9O<B!S
M96-U<F4@;75L=&EP87)T(&UE<W-A9V5S("AD969I;F5D(&)Y(%)&0R`Q.#0W
M*2X@5&AI<PH@*B!C;&%S<R!H86YD;&5S(&UU;'1I<&%R="]S:6=N960@86YD
M(&UU;'1I<&%R="]E;F-R>7!T960@9&%T82X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]S96-U<FET>2YP:'`L=B`Q+C8N,3`N
M-2`R,#`V+S`Q+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M
M+F-O;&]R861O+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*
M("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?
M5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]S96-U<FET>2!E>'1E;F1S
M($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!T:&4@34E-
M15]6:65W97(@;V8@=&AE('-P96-I9FEE9"!S96-U<FET>2!P<F]T;V-O;"X*
M("`@("`J"B`@("`@*B!`=F%R($U)345?5FEE=V5R"B`@("`@*B\*("`@('9A
M<B`D7W9I97=E<CL*"B`@("`O*BH*("`@("`J(%1H92`D;6EM95]P87)T(&-L
M87-S('9A<FEA8FQE(&AA<R!T:&4@:6YF;W)M871I;VX@=&\@<F5N9&5R"B`@
M("`@*B!O=70L(&5N8V%P<W5L871E9"!I;B!A($U)345?4&%R="!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M("1P87)A;7,@;6EX960@(%1H92!P87)A
M;65T97)S("AI9B!A;GDI('1O('!A<W,@=&\@=&AE('5N9&5R;'EI;F<*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!-24U%7U9I97=E<BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@4F5N9&5R:6YG(&]F('1H92!C;VYT
M96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)'!A<F%M<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@+RH@1V5T('1H92!A<'!R;W!R:6%T92!-
M24U%7U9I97=E<B!F;W(@=&AE('!R;W1O8V]L('-P96-I9FEE9"X@*B\*("`@
M("`@("!I9B`H(2@D=&AI<RT^7W)E<V]L=F56:65W97(H*2DI('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@4F5N9&5R('5S
M:6YG('1H92!L;V%D960@34E-15]6:65W97(@;V)J96-T+B`J+PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7W9I97=E<BT^<F5N9&5R*"1P87)A;7,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N="UT>7!E(&]F
M('1H92!6:65W97(@=7-E9"!T;R!V:65W('1H92!P87)T+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!!(&-O;G1E;G0M='EP92!S=')I;F<N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%1Y<&4H*0H@("`@>PH@("`@("`@("\J
M($=E="!T:&4@87!P<F]P<FEA=&4@34E-15]6:65W97(@9F]R('1H92!P<F]T
M;V-O;"!S<&5C:69I960N("HO"B`@("`@("`@:68@*"$H)'1H:7,M/E]R97-O
M;'9E5FEE=V5R*"DI*2!["B`@("`@("`@("`@(')E='5R;B`G87!P;&EC871I
M;VXO;V-T970M<W1R96%M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]V:65W97(M/F=E=%1Y<&4H*3L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V%D(&$@34E-15]6:65W97(@86-C
M;W)D:6YG('1O('1H92!P<F]T;V-O;"!P87)A;65T97(@<W1O<F5D"B`@("`@
M*B!I;B!T:&4@34E-15]087)T('1O(')E;F1E<BX@268@=6YS=6-C97-S9G5L
M+"!T<GD@=&\@;&]A9"!A(&=E;F5R:6,*("`@("`J(&UU;'1I<&%R="!-24U%
M7U9I97=E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E<V]L=F56
M:65W97(H*0H@("`@>PH@("`@("`@("1V:65W97(@/2!N=6QL.PH*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/E]V:65W97(I*2!["B`@("`@("`@("`@("1P
M<F]T;V-O;"`]("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O;G1E;G14>7!E4&%R
M86UE=&5R*"=P<F]T;V-O;"<I.PH@("`@("`@("`@("!I9B`H96UP='DH)'!R
M;W1O8V]L*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1V:65W97(@/2`F34E-15]6:65W97(Z
M.F9A8W1O<GDH)'1H:7,M/FUI;65?<&%R="P@)'!R;W1O8V]L*3L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1V:65W97(I('Q\"B`@("`@("`@("`@("`@("`H
M4W1R:6YG.CIL;W=E<BAG971?8VQA<W,H)'9I97=E<BDI(#T]("=M:6UE7W9I
M97=E<E]D969A=6QT)RDI('L*("`@("`@("`@("`@("`@("1V:65W97(@/2`F
M34E-15]6:65W97(Z.F9A8W1O<GDH)'1H:7,M/FUI;65?<&%R="P@)'1H:7,M
M/FUI;65?<&%R="T^9V5T4')I;6%R>51Y<&4H*2`N("<O*B<I.PH@("`@("`@
M("`@("`@("`@:68@*&5M<'1Y*"1V:65W97(I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?=FEE=V5R(#T@)'9I97=E<CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<&AP
M+G!H<```````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W,#4@,3`U
M,34T,S0Q,S<@,#(R-C0Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+W-O=7)C92YP:'`G.PH*+RHJ"B`J(%1H92!-24U%7U9I97=E
M<E]P:'`@8VQA<W,@<F5N9&5R<R!O=70@<WEN=&%X+6AI9VAL:6=H=&5D(%!(
M4"!C;V1E"B`J(&EN($A434P@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]-24U%+TU)344O5FEE=V5R+W!H<"YP:'`L=B`Q+C(R+C$P+C@@,C`P
M-B\P-B\P,2`P,SHP.#HU,R!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@
M,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C
M:V%G92!(;W)D95]-24U%7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?
M<&AP(&5X=&5N9',@34E-15]6:65W97)?<V]U<F-E('L*"B`@("`O*BH*("`@
M("`J(%)E;F1E<G,@;W5T('1H92!C;VYT96YT<RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M971E<G,@=&AE(%9I97=E
M<B!M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(')E;F1E<F5D(&-O;G1E;G1S+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD
M97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)')E<W5L=',@
M/2!T<FEM*'-T<E]R97!L86-E*&%R<F%Y*")<;B(L("<\8G(@+SXG*2P@87)R
M87DH)R<L(")<;B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!H:6=H;&EG:'1?<W1R:6YG*"1T:&ES+3YM:6UE7W!A<G0M/F=E=$-O
M;G1E;G1S*"DL('1R=64I*2D["@H@("`@("`@("\O($5D=6-A=&5D($=U97-S
M(&%T('=H971H97(@=V4@87)E(&EN;&EN92!O<B!N;W0N"B`@("`@("`@:68@
M*&AE861E<G-?<V5N="@I('Q\(&]B7V=E=%]L96YG=&@H*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FQI;F5.=6UB97(H)')E<W5L=',I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!5=&EL.CIB=69F97)/
M=71P=70H)W)E<75I<F4G+"`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T*"=T
M96UP;&%T97,G+"`G:&]R9&4G*2`N("<O8V]M;6]N+6AE861E<BYI;F,G*2`N
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&EN94YU;6)E<B@D<F5S=6QT<RD@
M+@H@("`@("`@("`@("`@("`@571I;#HZ8G5F9F5R3W5T<'5T*"=R97%U:7)E
M)RP@)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=&5M<&QA=&5S)RP@)VAO
M<F1E)RD@+B`G+V-O;6UO;BUF;V]T97(N:6YC)RD["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U9I97=E<B]R:6-H=&5X="YP:'``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q-30S-R`Q,#4Q-30S-#$S-R`P,C,W,3(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J(%1H92!-24U%7U9I97=E<E]R:6-H=&5X="!C;&%S<R!R96YD97)S(&]U
M="!(5$U,('1E>'0@9G)O;2!T97AT+W)I8VAT97AT"B`J(&-O;G1E;G0@=&%G
M<RP@*%)&0R`Q.#DV(%LW+C$N,UTI+@H@*@H@*B!!(&UI;FEM86P@<FEC:'1E
M>'0@:6UP;&5M96YT871I;VX@:7,@;VYE('1H870@<VEM<&QY(&-O;G9E<G1S
M("(\;'0^(B!T;PH@*B`B/"(L(&-O;G9E<G1S($-23$9S('1O(%-004-%+"!C
M;VYV97)T<R`\;FP^('1O(&$@;F5W;&EN92!A8V-O<F1I;F<@=&\*("H@;&]C
M86P@;F5W;&EN92!C;VYV96YT:6]N+"!R96UO=F5S(&5V97)Y=&AI;F<@8F5T
M=V5E;B!A(#QC;VUM96YT/B!C;VUM86YD"B`J(&%N9"!T:&4@;F5X="!B86QA
M;F-I;F<@/"]C;VUM96YT/B!C;VUM86YD+"!A;F0@<F5M;W9E<R!A;&P@;W1H
M97(*("H@;W1H97(@9F]R;6%T=&EN9R!C;VUM86YD<R`H86QL('1E>'0@96YC
M;&]S960@:6X@86YG;&4@8G)A8VME=',I+@H@*@H@*B!792!I;7!L96UE;G0@
M=&AE(&9O;&QO=VEN9R!T86=S.@H@*B`\8F]L9#XL(#QI=&%L:6,^+"`\9FEX
M960^+"`\<VUA;&QE<CXL(#QB:6=G97(^+"`\=6YD97)L:6YE/BP@/&-E;G1E
M<CXL"B`J(#QF;'5S:&QE9G0^+"`\9FQU<VAR:6=H=#XL(#QI;F1E;G0^+"`\
M<W5B<V-R:7!T/BP@/&5X8V5R<'0^+"`\<&%R86=R87!H/BP*("H@/'-I9VYA
M='5R93XL(#QC;VUM96YT/BP@/&YO+6]P/BP@/&QT/BP@/&YL/@H@*@H@*B!4
M:&4@9F]L;&]W:6YG('1A9W,@87)E(&EM<&QE;65N=&5D(&1I9F9E<F5N=&QY
M('1H86X@9&5S8W)I8F5D(&EN('1H92!21D,*("H@*&1U92!T;R!L:6UI=&%T
M:6]N<R!I;B!(5$U,(&]U='!U="DZ"B`J(#QH96%D:6YG/B`M($]U='!U="!A
M<R!C96YT97)E9"P@8F]L9"!T97AT+@H@*B`\9F]O=&EN9SX@+2!/=71P=70@
M87,@8V5N=&5R960L(&)O;&0@=&5X="X*("H@/&YP/B`@("`@("T@3W5T<'5T
M(&%S('!A<F%G<F%P:"!B<F5A:RX*("H*("H@5&AE(&9O;&QO=VEN9R!T86=S
M(&%R92!.3U0@:6UP;&5M96YT960Z"B`J(#QI;F1E;G1R:6=H=#XL(#QO=71D
M96YT/BP@/&]U=&1E;G1R:6=H=#XL(#QS86UE<&%G93XL(#QI<V\M.#@U.2U8
M/BP*("H@/'5S+6%S8VEI/BP*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-
M12]-24U%+U9I97=E<B]R:6-H=&5X="YP:'`L=B`Q+C0N,3`N-R`R,#`V+S`Q
M+S`Q(#(Q.C(X.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR
M,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI8VAA96P@4VQU
M<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*("H@0'-I;F-E
M("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TU)345?5FEE=V5R"B`J
M+PIC;&%S<R!-24U%7U9I97=E<E]R:6-H=&5X="!E>'1E;F1S($U)345?5FEE
M=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE(&-U<G)E;G1L
M>2!S970@8V]N=&5N=',@:6X@2%1-3"!F;W)M870N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1P87)A;7,@($%N>2!P87)A;65T97)S('1H92!6:65W
M97(@;6%Y(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R96YD97)E9"!C;VYT96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("@H)'1E
M>'0@/2`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I*2`]/3T@9F%L
M<V4I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'1R:6TH)'1E>'0I(#T]("<G*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&5X=#L*("`@("`@("!]"@H@("`@("`@("\J(%5S92!S=')?:7)E
M<&QA8V4H*2!I9B!U<VEN9R!02%`@-2XP*RX@*B\*("`@("`@("`D:&%S7W-T
M<E]I<F5P;&%C92`](&9U;F-T:6]N7V5X:7-T<R@G<W1R7VER97!L86-E)RD[
M"@H@("`@("`@("\J(%=E(&%D9"!S<&%C92!A="!T:&4@8F5G:6YN:6YG(&%N
M9"!E;F0@;V8@=&AE('-T<FEN9R!A<R!I="!W:6QL"B`@("`@("`@("H@;6%K
M92!S;VUE(')E9W5L87(@97AP<F5S<VEO;B!C:&5C:W,@;&%T97(@;75C:"!E
M87-I97(@*'-O('=E"B`@("`@("`@("H@9&]N)W0@:&%V92!T;R!W;W)R>2!A
M8F]U="!S=&%R="]E;F0@;V8@;&EN92!C:&%R86-T97)S*2X@*B\*("`@("`@
M("`D=&5X="`]("<@)R`N("1T97AT("X@)R`G.PH*("`@("`@("`O*B!296UO
M=F4@979E<GET:&EN9R!B971W965N(#QC;VUM96YT/B!T86=S+B`J+PH@("`@
M("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O/&-O;6UE;G0N*CXN*CQ<+V-O
M;6UE;G0^+U5I<R<L("<G+"`D=&5X="D["@H@("`@("`@("\J(%)E;6]V92!A
M;GD@=6YR96-O9VYI>F5D('1A9W,@:6X@=&AE('1E>'0N("!792!D;VXG="!N
M965D(#QN;RUO<#X*("`@("`@("`@*B!I;B`D=&%G<R!S:6YC92!I="!D;V5S
M;B=T(&1O(&%N>71H:6YG(&%N>7=A>2X@($%L;"`\8V]M;65N=#X@=&%G<PH@
M("`@("`@("`J(&AA=F4@86QR96%D>2!B965N(')E;6]V960N("HO"B`@("`@
M("`@)'1A9W,@/2`G/&)O;&0^/&ET86QI8SX\9FEX960^/'-M86QL97(^/&)I
M9V=E<CX\=6YD97)L:6YE/CQC96YT97(^/&9L=7-H;&5F=#X\9FQU<VAR:6=H
M=#X\:6YD96YT/CQS=6)S8W)I<'0^/&5X8V5R<'0^/'!A<F%G<F%P:#X\<VEG
M;F%T=7)E/CQL=#X\;FP^)SL*("`@("`@("`D=&5X="`]('-T<FEP7W1A9W,H
M)'1E>'0L("1T86=S*3L*"B`@("`@("`@+RH@/&QT/B!B96-O;65S(&$@)SPG
M+B!#4DQ&(&)E8V]M97,@82!34$%#12X@*B\*("`@("`@("!I9B`H)&AA<U]S
M=')?:7)E<&QA8V4I('L*("`@("`@("`@("`@)'1E>'0@/2!S=')?:7)E<&QA
M8V4H87)R87DH)SQL=#XG+"`B7')<;B(I+"!A<G)A>2@G)FQT.R<L("<@)RDL
M("1T97AT*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&5X="`]
M('!R96=?<F5P;&%C92AA<G)A>2@G+SQL=#XO:2<L("(O7')<;B\B*2P@87)R
M87DH)R9L=#LG+"`G("<I+"`D=&5X="D["B`@("`@("`@?0H*("`@("`@("`O
M*B!792!T<GD@=&\@<')O=&5C="!A9V%I;G-T(&)A9"!S='5F9B!H97)E+B`J
M+PH@("`@("`@("1T97AT(#T@0&AT;6QS<&5C:6%L8VAA<G,H)'1E>'0L($5.
M5%]154]415,L("1T:&ES+3YM:6UE7W!A<G0M/F=E=$-H87)S970H*2D["@H@
M("`@("`@("\J(#QN;#X@8F5C;VUE<R!A(&YE=VQI;F4@*#QB<B`O/BD["B`@
M("`@("`@("H@/&YP/B!B96-O;65S(&$@<&%R86=R87!H(&)R96%K("@\<"`O
M/BDN("HO"B`@("`@("`@:68@*"1H87-?<W1R7VER97!L86-E*2!["B`@("`@
M("`@("`@("1T97AT(#T@<W1R7VER97!L86-E*&%R<F%Y*"<F;'0[;FPF9W0[
M)RP@)R9L=#MN<"9G=#LG*2P@87)R87DH)SQB<B`O/B<L("<\<"`O/B<I+"`D
M=&5X="D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1E>'0@/2!P
M<F5G7W)E<&QA8V4H87)R87DH)R\H/SPA)FQT.RDF;'0[;FPN*B9G=#LO56ES
M)RP@)R\H/SPA)FQT.RDF;'0[;G`N*B9G=#LO56ES)RDL(&%R<F%Y*"<\8G(@
M+SXG+"`G/'`@+SXG*2P@)'1E>'0I.PH@("`@("`@('T*"B`@("`@("`@+RH@
M3F]W(&-O;G9E<G0@=&AE(&MN;W=N('1A9W,@=&\@:'1M;"X@5')Y('1O(')E
M;6]V92!A;GD@=&%G"B`@("`@("`@("H@<&%R86UE=&5R<R!T;R!S=&]P('!E
M;W!L92!F<F]M('1R>6EN9R!T;R!P=6QL(&$@9F%S="!O;F4N("HO"B`@("`@
M("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[8F]L9"XJ
M)F=T.R@N*BDF;'0[7"]B;VQD)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O
M;G0M=V5I9VAT.B!B;VQD(CY<,3PO<W!A;CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[:71A;&EC+BHF
M9W0[*"XJ*29L=#M<+VET86QI8R9G=#LO56ES)RP@)SQS<&%N('-T>6QE/2)F
M;VYT+7-T>6QE.B!I=&%L:6,B/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@
M("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF:7AE9"XJ
M)F=T.R@N*BDF;'0[7"]F:7AE9"9G=#LO56ES)RP@)SQF;VYT(&9A8V4](F9I
M>&5D(CY<,3PO9F]N=#XG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[<VUA;&QE<BXJ)F=T.R]5:7,G+"`G
M/'-P86X@<W1Y;&4](F9O;G0M<VEZ93H@<VUA;&QE<B(^)RP@)'1E>'0I.PH@
M("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.UPO
M<VUA;&QE<B9G=#LO56ES)RP@)SPO<W!A;CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[8FEG9V5R+BHF
M9W0[+U5I<R<L("<\<W!A;B!S='EL93TB9F]N="US:7IE.B!L87)G97(B/B<L
M("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F
M;'0[*29L=#M<+V)I9V=E<B9G=#LO56ES)RP@)SPO<W!A;CXG+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[
M=6YD97)L:6YE+BHF9W0[*"XJ*29L=#M<+W5N9&5R;&EN929G=#LO56ES)RP@
M)SQS<&%N('-T>6QE/2)T97AT+61E8V]R871I;VXZ('5N9&5R;&EN92(^7#$\
M+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E
M*"<O*#\\(29L=#LI)FQT.V-E;G1E<BXJ)F=T.R@N*BDF;'0[7"]C96YT97(F
M9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)C96YT97(B/EPQ/"]D:78^)RP@)'1E
M>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI
M)FQT.V9L=7-H;&5F="XJ)F=T.R@N*BDF;'0[7"]F;'5S:&QE9G0F9W0[+U5I
M<R<L("<\9&EV(&%L:6=N/2)L969T(CY<,3PO9&EV/B<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF;'5S
M:')I9VAT+BHF9W0[*"XJ*29L=#M<+V9L=7-H<FEG:'0F9W0[+U5I<R<L("<\
M9&EV(&%L:6=N/2)R:6=H="(^7#$\+V1I=CXG+"`D=&5X="D["B`@("`@("`@
M)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[:6YD96YT+BHF
M9W0[*"XJ*29L=#M<+VEN9&5N="9G=#LO56ES)RP@)SQB;&]C:W%U;W1E/EPQ
M/"]B;&]C:W%U;W1E/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?
M<F5P;&%C92@G+R@_/"$F;'0[*29L=#ME>&-E<G!T+BHF9W0[*"XJ*29L=#M<
M+V5X8V5R<'0F9W0[+U5I<R<L("<\8VET93Y<,3PO8VET93XG+"`D=&5X="D[
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[
M<W5B<V-R:7!T+BHF9W0[*"XJ*29L=#M<+W-U8G-C<FEP="9G=#LO56ES)RP@
M)SQS=6(^7#$\+W-U8CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\H/SPA)FQT.RDF;'0[<W5P97)S8W)I<'0N*B9G=#LH+BHI
M)FQT.UPO<W5P97)S8W)I<'0F9W0[+U5I<R<L("<\<W5P/EPQ/"]S=7`^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.VAE861I;F<N*B9G=#LH+BHI)FQT.UPO:&5A9&EN9R9G=#LO56ES
M)RP@)SQB<B`O/CQD:78@86QI9VX](F-E;G1E<B(@<W1Y;&4](F9O;G0M=V5I
M9VAT.B!B;VQD(CY<,3PO9&EV/CQB<B`O/B<L("1T97AT*3L*("`@("`@("`D
M=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF;V]T:6YG+BHF
M9W0[*"XJ*29L=#M<+V9O;W1I;F<F9W0[+U5I<R<L("<\8G(@+SX\9&EV(&%L
M:6=N/2)C96YT97(B('-T>6QE/2)F;VYT+7=E:6=H=#H@8F]L9"(^7#$\+V1I
M=CX\8G(@+SXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R\H/SPA)FQT.RDF;'0[<&%R86=R87!H+BHF9W0[*"XJ*29L=#M<+W!A
M<F%G<F%P:"9G=#LO56ES)RP@)SQP/EPQ/"]P/B<L("1T97AT*3L*("`@("`@
M("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MS:6=N871U
M<F4N*B9G=#LH+BHI)FQT.UPO<VEG;F%T=7)E)F=T.R]5:7,G+"`G/&%D9')E
M<W,^7#$\+V%D9')E<W,^)RP@)'1E>'0I.PH*("`@("`@("`O*B!.;W<@=V4@
M<F5M;W9E('1H92!L96%D:6YG+W1R86EL:6YG('-P86-E('=E(&%D9&5D(&%T
M('1H92!S=&%R="X@*B\*("`@("`@("`D=&5X="`]('-U8G-T<B@D=&5X="P@
M,2P@+3$I.PH*("`@("`@("`O*B!7;W)D=W)A<"X@*B\*("`@("`@("`D=&5X
M="`]('-T<E]R97!L86-E*")<="(L("<@("`@("`@("<L("1T97AT*3L*("`@
M("`@("`D=&5X="`]('-T<E]R97!L86-E*"<@("<L("<@)FYB<W`[)RP@)'1E
M>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H(EQN("(L(")<;B9N
M8G-P.R(L("1T97AT*3L*("`@("`@("!I9B`H)'1E>'1;,%T@/3T@)R`G*2![
M"B`@("`@("`@("`@("1T97AT(#T@)R9N8G-P.R<@+B!S=6)S='(H)'1E>'0L
M(#$I.PH@("`@("`@('T*("`@("`@("`D=&5X="`](&YL,F)R*"1T97AT*3L*
M("`@("`@("`D=&5X="`]("<\<"!C;&%S<STB9FEX960B/B<@+B`D=&5X="`N
M("<\+W`^)SL*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O;G1E;G0@='EP92!O9B!T:&4@
M<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@;W5T<'5T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*("`@("`@("!R971U<FX@)W1E
M>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I
M97=E<B]E;G)I8VAE9"YP:'``````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R
M,#$S,2`Q,#4Q-30S-#$S-R`P,C,V,C0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I
M97=E<E]E;G)I8VAE9"!C;&%S<R!R96YD97)S(&]U="!P;&%I;B!T97AT(&9R
M;VT*("H@96YR:6-H960@8V]N=&5N="!T86=S+"!A;&$@4D9#(#$X.38N"B`J
M"B`J($)Y(%)&0RP@=V4@;75S="!D;R!T:&4@;6EN:6UA;"!C;VYF;W)M86YC
M92!M96%S=7)E<R!O9CH@02!M:6YI;6%L"B`J('1E>'0O96YR:6-H960@:6UP
M;&5M96YT871I;VX@:7,@;VYE('1H870@8V]N=F5R=',@(CP\(B!T;R`B/"(L
M"B`J(')E;6]V97,@979E<GET:&EN9R!B971W965N(&$@/'!A<F%M/B!C;VUM
M86YD(&%N9"!T:&4@;F5X="!B86QA;F-I;F<*("H@/"]P87)A;3X@<F5M;W9E
M<R!A;&P@;W1H97(@9F]R;6%T=&EN9R!C;VUM86YD<R`H86QL('1E>'0@96YC
M;&]S960*("H@:6X@86YG;&4@8G)A8VME=',I+"!A;F0@;W5T<VED92!O9B`\
M;F]F:6QL/B!E;G9I<F]N;65N=',@8V]N=F5R=',*("H@86YY('-E<FEE<R!O
M9B!N($-23$9S('1O(&XM,2!#4DQ&<RP@86YD(&-O;G9E<G1S(&%N>2!L;VYE
M($-23$8*("H@<&%I<G,@=&\@4U!!0T4N"B`J"B`J(%=E(&1O;B=T('%U86QI
M9GD@87,@=V4@9&]N)W0@8W5R<F5N=&QY('1R86-K('1H92`\;F]F:6QL/@H@
M*B!E;G9I<F]N;65N="P@=&AA="!I<R!W92!D;R!#4DQ&(&-O;G9E<G-I;VX@
M979E;B!I9B`\;F]F:6QL/B!I<PH@*B!S<&5C:69I960@:6X@=&AE('1E>'0L
M(&)U="!W92=R92!C;&]S92!A="!L96%S="X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO34E-12]-24U%+U9I97=E<B]E;G)I8VAE9"YP:'`L=B`Q+C(S+C$P
M+C8@,C`P-B\P,2\P,2`R,3HR.#HR-2!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#$M,C`P-B!%<FEC(%)O<W1E='1E<B`\97)I8RYR;W-T971T97)`
M<&AY<VEC<RYU=&5X87,N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E
M>&%S+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO
M<F1E7TU)345?5FEE=V5R"B`J+PIC;&%S<R!-24U%7U9I97=E<E]E;G)I8VAE
M9"!E>'1E;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E
M<B!O=70@=&AE(&-U<G)E;G1L>2!S970@8V]N=&5N=',@:6X@2%1-3"!F;W)M
M870N(%1H90H@("`@("H@)&UI;65?<&%R="!C;&%S<R!V87)I86)L92!H87,@
M=&AE(&EN9F]R;6%T:6]N('1O(')E;F1E<B!O=70L"B`@("`@*B!E;F-A<'-U
M;&%T960@:6X@82!-24U%7U!A<G0@;V)J96-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96YD97(H*0H@("`@>PH@("`@("`@(&EF("@H)'1E>'0@/2`D=&AI
M<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*'1R:6TH)'1E>'0I(#T]("<G*2!["B`@("`@("`@("`@(')E='5R;B`D=&5X
M=#L*("`@("`@("!]"@H@("`@("`@("\O(%=E(&%D9"!S<&%C92!A="!T:&4@
M8F5G:6YN:6YG(&%N9"!E;F0@;V8@=&AE('-T<FEN9R!A<R!I="!W:6QL"B`@
M("`@("`@+R\@;6%K92!S;VUE(')E9W5L87(@97AP<F5S<VEO;B!C:&5C:W,@
M;&%T97(@;75C:"!E87-I97(@*'-O('=E"B`@("`@("`@+R\@9&]N)W0@:&%V
M92!T;R!W;W)R>2!A8F]U="!S=&%R="]E;F0@;V8@;&EN92!C:&%R86-T97)S
M*0H@("`@("`@("1T97AT(#T@)R`G("X@)'1E>'0@+B`G("<["@H@("`@("`@
M("\O(%=E(&YE960@=&\@<')E<V5R=F4@/#P@=&%G<RP@<V\@;6%P('1H96T@
M=&\@87-C:6D@,2!O<B!A<V-I:2`R-34*("`@("`@("`O+R!792!M86ME('1H
M92!A<W-U;7!T:6]N(&AE<F4@=&AA="!T:&5R92!W;W5L9"!N979E<B!B92!A
M;B!A<V-I:0H@("`@("`@("\O(#$@:6X@86X@96UA:6PL('=H:6-H(&UA>2!N
M;W0@8F4@=F%L:60L(&)U="!S965M<R!R96%S;VYA8FQE+BXN"B`@("`@("`@
M+R\@87-C:6D@,C4U('=O=6QD('=O<FL@:68@9F]R('-O;64@<F5A<V]N('EO
M=2!D;VXG="!L:6ME(&%S8VEI(#$*("`@("`@("`O+R!A<V-I:2`P(&1O97,@
M3D]4('-E96T@=&\@=V]R:R!F;W(@=&AI<RP@=&AO=6=H($DG;2!N;W0@<W5R
M92!W:'D*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"<\/"<L(&-H<B@Q
M*2P@)'1E>'0I.PH*("`@("`@("`O+R!296UO=F4@86YY('5N<F5C;V=N:7IE
M9"!T86=S(&EN('1H92!T97AT("AV:6$@4D9#(&UI;FEM86P@<W!E8W,I"B`@
M("`@("`@+R\@86YY('1A9W,@=V4@:G5S="!D;VXG="!W86YT('1O(&EM<&QE
M;65N="!C86X@86QS;R!B92!R96UO=F5D(&AE<F4*("`@("`@("`O+R!.;W1E
M('1H870@=&AI<R!W:6QL(')E;6]V92!A;GD@:'1M;"!L:6YK<RP@8G5T('1H
M:7,@:7,@:6YT96YD960*("`@("`@("`D:6UP;&5M96YT961486=S(#T@)SQP
M87)A;3X\8F]L9#X\:71A;&EC/CQU;F1E<FQI;F4^/&9I>&5D/CQE>&-E<G!T
M/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`G/'-M86QL97(^/&)I
M9V=E<CX\8V5N=&5R/CQC;VQO<CX\9F]N=&9A;6EL>3XG("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)SQF;'5S:&QE9G0^/&9L=7-H<FEG:'0^/&9L
M=7-H8F]T:#X\<&%R86EN9&5N=#XG.PH@("`@("`@("\O("1U;DEM<&QE;65N
M=&5D5&%G<R`]("<\;F]F:6QL/CQL86YG/B<["B`@("`@("`@)'1E>'0@/2!S
M=')I<%]T86=S*"1T97AT+"`D:6UP;&5M96YT961486=S*3L*"B`@("`@("`@
M+R\@<F5S=&]R92!T:&4@/#P@=&%G<R!A<R`\('1A9W,@;F]W+BXN"B`@("`@
M("`@)'1E>'0@/2!S=')?<F5P;&%C92AC:'(H,2DL("<\/"<L("1T97AT*3L*
M("`@("`@("`O+R`D=&5X="`]('-T<E]R97!L86-E*&-H<B@R-34I+"`G/"<L
M("1T97AT*3L*"B`@("`@("`@+R\@1V5T(&-O;&]R('!A<F%M971E<G,@:6YT
M;R!A(&UO<F4@=7-E86)L92!F;W)M870N"B`@("`@("`@)'1E>'0@/2!P<F5G
M7W)E<&QA8V4H)R\\8V]L;W(^/'!A<F%M/BA;7&1A+69!+49=*RDL*%M<9&$M
M9D$M1ETK*2PH6UQD82UF02U&72LI/%PO<&%R86T^+U5I<R<L("<\8V]L;W(@
M<CU<,2!G/5PR(&(]7#,^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E
M9U]R97!L86-E*"<O/&-O;&]R/CQP87)A;3XH<F5D?&)L=65\9W)E96Y\>65L
M;&]W?&-Y86Y\;6%G96YT87QB;&%C:WQW:&ET92D\7"]P87)A;3XO56ES)RP@
M)SQC;VQO<B!N/5PQ/B<L("1T97AT*3L*"B`@("`@("`@+R\@1V5T(&9O;G0@
M9F%M:6QY('!A<F%M971E<G,@:6YT;R!A(&UO<F4@=7-E86)L92!F;W)M870N
M"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\\9F]N=&9A;6EL>3X\
M<&%R86T^*%QW*RD\7"]P87)A;3XO56ES)RP@)SQF;VYT9F%M:6QY(&8]7#$^
M)RP@)'1E>'0I.PH*("`@("`@("`O+R!*=7-T(')E;6]V92!A;GD@<F5M86EN
M:6YG('!A<F%M971E<G,@+2T@=V4@=V]N)W0@=7-E"B`@("`@("`@+R\@=&AE
M;2X@06YY('1A9W,@=VET:"!P87)A;65T97)S('1H870@=V4@=V%N="!T;R!I
M;7!L96UE;G0*("`@("`@("`O+R!W:6QL(&AA=F4@=&\@8V]M92!B969O<F4@
M=&AI<R!3;VUE9&%Y('=E(&AO<&4@=&\@=7-E('1H97-E"B`@("`@("`@+R\@
M=&%G<R`H92YG+B!F;W(@/&-O;&]R/CQP87)A;3X@=&%G<RD*("`@("`@("`D
M=&5X="`]('!R96=?<F5P;&%C92@G+SQP87)A;3XN*CQ<+W!A<F%M/B]5:7,G
M+"`G)RP@)'1E>'0I.PH*("`@("`@("`O+R!3:6YG;&4@;&EN92!B<F5A:W,@
M8F5C;VUE('-P86-E<RP@9&]U8FQE(&QI;F4@8G)E86MS(&%R92!A"B`@("`@
M("`@+R\@<F5A;"!B<F5A:RX@5&AI<R!N965D<R!T;R!D;R`\;F]F:6QL/B!T
M<F%C:VEN9R!T;R!B90H@("`@("`@("\O(&-O;7!L:6%N="!B=70@=V4@9&]N
M)W0@=V%N="!T;R!D96%L('=I=&@@<W1A=&4@870@=&AI<PH@("`@("`@("\O
M('1I;64L('-O('=E(&9A:V4@:70@<V]M92!D87D@=V4@<VAO=6QD(')E=W)I
M=&4@=&AI<R!T;PH@("`@("`@("\O(&AA;F1L92`\;F]F:6QL/B!C;W)R96-T
M;'DN"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H6UY<;ETI7')<
M;BA;7EQR72DO)RP@)UPQ(%PR)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@
M<')E9U]R97!L86-E*"<O*%QR7&XI7')<;B\G+"`G7#$G+"`D=&5X="D["@H@
M("`@("`@("\O(%=E('1R>2!T;R!P<F]T96-T(&%G86EN<W0@8F%D('-T=69F
M(&AE<F4N"B`@("`@("`@)'1E>'0@/2!`:'1M;'-P96-I86QC:&%R<R@D=&5X
M="P@14Y47U%53U1%4RP@)'1H:7,M/FUI;65?<&%R="T^9V5T0VAA<G-E="@I
M*3L*"B`@("`@("`@+R\@3F]W(&-O;G9E<G0@=&AE(&MN;W=N('1A9W,@=&\@
M:'1M;"X@5')Y('1O(')E;6]V92!A;GD@=&%G"B`@("`@("`@+R\@<&%R86UE
M=&5R<R!T;R!S=&]P('!E;W!L92!F<F]M('1R>6EN9R!T;R!P=6QL(&$@9F%S
M="!O;F4*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[
M*29L=#MB;VQD+BHF9W0[*"XJ*29L=#M<+V)O;&0F9W0[+U5I<R<L("<\<W!A
M;B!S='EL93TB9F]N="UW96EG:'0Z(&)O;&0B/EPQ/"]S<&%N/B<L("1T97AT
M*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L
M=#MI=&%L:6,N*B9G=#LH+BHI)FQT.UPO:71A;&EC)F=T.R]5:7,G+"`G/'-P
M86X@<W1Y;&4](F9O;G0M<W1Y;&4Z(&ET86QI8R(^7#$\+W-P86X^)RP@)'1E
M>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI
M)FQT.W5N9&5R;&EN92XJ)F=T.R@N*BDF;'0[7"]U;F1E<FQI;F4F9W0[+U5I
M<R<L("<\<W!A;B!S='EL93TB=&5X="UD96-O<F%T:6]N.B!U;F1E<FQI;F4B
M/EPQ/"]S<&%N/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P
M;&%C95]C86QL8F%C:R@G+R@_/"$F;'0[*29L=#MC;VQO<B!R/2A;7&1A+69!
M+49=*RD@9STH6UQD82UF02U&72LI(&(]*%M<9&$M9D$M1ETK*29G=#LH+BHI
M)FQT.UPO8V]L;W(F9W0[+U5I<R<L(&%R<F%Y*"1T:&ES+"`G8V]L;W)I>F4G
M*2P@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\
M(29L=#LI)FQT.V-O;&]R(&X]*')E9'QB;'5E?&=R965N?'EE;&QO=WQC>6%N
M?&UA9V5N=&%\8FQA8VM\=VAI=&4I)F=T.R@N*BDF;'0[7"]C;VQO<B9G=#LO
M56ES)RP@)SQS<&%N('-T>6QE/2)C;VQO<CH@7#$B/EPR/"]S<&%N/B<L("1T
M97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[
M*29L=#MF;VYT9F%M:6QY)F=T.R@N*BDF;'0[7"]F;VYT9F%M:6QY)F=T.R]5
M:7,G+"`G7#$G+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R\H/SPA)FQT.RDF;'0[9F]N=&9A;6EL>2!F/2A<=RLI)F=T.R@N*BDF
M;'0[7"]F;VYT9F%M:6QY)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M
M9F%M:6QY.B!<,2(^7#(\+W-P86X^)RP@)'1E>'0I.PH@("`@("`@("1T97AT
M(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.W-M86QL97(N*B9G=#LO
M56ES)RP@)SQS<&%N('-T>6QE/2)F;VYT+7-I>F4Z('-M86QL97(B/B<L("1T
M97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[
M*29L=#M<+W-M86QL97(F9W0[+U5I<R<L("<\+W-P86X^)RP@)'1E>'0I.PH@
M("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L=#LI)FQT.V)I
M9V=E<BXJ)F=T.R]5:7,G+"`G/'-P86X@<W1Y;&4](F9O;G0M<VEZ93H@;&%R
M9V5R(CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H
M)R\H/SPA)FQT.RDF;'0[7"]B:6=G97(F9W0[+U5I<R<L("<\+W-P86X^)RP@
M)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O*#\\(29L
M=#LI)FQT.V9I>&5D+BHF9W0[*"XJ*29L=#M<+V9I>&5D)F=T.R]5:7,G+"`G
M/&9O;G0@9F%C93TB9FEX960B/EPQ/"]F;VYT/B<L("1T97AT*3L*("`@("`@
M("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MC96YT97(N
M*B9G=#LH+BHI)FQT.UPO8V5N=&5R)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB
M8V5N=&5R(CY<,3PO9&EV/B<L("1T97AT*3L*("`@("`@("`D=&5X="`]('!R
M96=?<F5P;&%C92@G+R@_/"$F;'0[*29L=#MF;'5S:&QE9G0N*B9G=#LH+BHI
M)FQT.UPO9FQU<VAL969T)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB;&5F="(^
M7#$\+V1I=CXG+"`D=&5X="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R\H/SPA)FQT.RDF;'0[9FQU<VAR:6=H="XJ)F=T.R@N*BDF;'0[7"]F
M;'5S:')I9VAT)F=T.R]5:7,G+"`G/&1I=B!A;&EG;CTB<FEG:'0B/EPQ/"]D
M:78^)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<')E9U]R97!L86-E*"<O
M*#\\(29L=#LI)FQT.V9L=7-H8F]T:"XJ)F=T.R@N*BDF;'0[7"]F;'5S:&)O
M=&@F9W0[+U5I<R<L("<\9&EV(&%L:6=N/2)J=7-T:69Y(CY<,3PO9&EV/B<L
M("1T97AT*3L*("`@("`@("`D=&5X="`]('!R96=?<F5P;&%C92@G+R@_/"$F
M;'0[*29L=#MP87)A:6YD96YT+BHF9W0[*"XJ*29L=#M<+W!A<F%I;F1E;G0F
M9W0[+U5I<R<L("<\8FQO8VMQ=6]T93Y<,3PO8FQO8VMQ=6]T93XG+"`D=&5X
M="D["B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA8V4H)R\H/SPA)FQT.RDF
M;'0[97AC97)P="XJ)F=T.R@N*BDF;'0[7"]E>&-E<G!T)F=T.R]5:7,G+"`G
M/&)L;V-K<75O=&4^7#$\+V)L;V-K<75O=&4^)RP@)'1E>'0I.PH*("`@("`@
M("`O+R!297!L86-E(#P\('=I=&@@/"!N;W<@*&9R;VT@=')A;G-L871E9"!(
M5$U,(&9O<FTI+@H@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)R9L=#LF
M;'0[)RP@)R9L=#LG+"`D=&5X="D["@H@("`@("`@("\O($YO=R!W92!R96UO
M=F4@=&AE(&QE861I;F<O=')A:6QI;F<@<W!A8V4@=V4@861D960@870@=&AE
M"B`@("`@("`@+R\@<W1A<G0N"B`@("`@("`@)'1E>'0@/2!P<F5G7W)E<&QA
M8V4H)R]>("@N*BD@)"]S)RP@)UPQ)RP@)'1E>'0I.PH*("`@("`@("`O+R!-
M86ME(%523',@8VQI8VMA8FQE+@H@("`@("`@(')E<75I<F5?;VYC92`G2&]R
M9&4O5&5X="]&:6QT97(N<&AP)SL*("`@("`@("`D=&5X="`](%1E>'1?1FEL
M=&5R.CIF:6QT97(H)'1E>'0L("=L:6YK=7)L<R<L(&%R<F%Y*"=C86QL8F%C
M:R<@/3X@)TAO<F1E.CIE>'1E<FYA;%5R;"<I*3L*"B`@("`@("`@+R\@5V]R
M9'=R87`@+2T@;F]T92!T:&ES(&-O=6QD(&EM<&%C="!O;B!O=7(@86)O=F4@
M4D9#"B`@("`@("`@+R\@8V]M<&QI86YC92`J248J('=E(&AO;F]R960@;F]F
M:6QL('1A9W,@*'=H:6-H('=E(&1O;B=T"B`@("`@("`@+R\@>65T*2X*("`@
M("`@("`D=&5X="`]('-T<E]R97!L86-E*")<="(L("<@("`@("`@("<L("1T
M97AT*3L*("`@("`@("`D=&5X="`]('-T<E]R97!L86-E*"<@("<L("<@)FYB
M<W`[)RP@)'1E>'0I.PH@("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H(EQN
M("(L(")<;B9N8G-P.R(L("1T97AT*3L*("`@("`@("!I9B`H)'1E>'1;,%T@
M/3T@)R`G*2!["B`@("`@("`@("`@("1T97AT(#T@)R9N8G-P.R<@+B!S=6)S
M='(H)'1E>'0L(#$I.PH@("`@("`@('T*("`@("`@("`D=&5X="`](&YL,F)R
M*"1T97AT*3L*("`@("`@("`D=&5X="`]("<\<"!C;&%S<STB9FEX960B/B<@
M+B`D=&5X="`N("<\+W`^)SL*"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&-O;&]R:7IE*"1C;VQO<G,I"B`@("!["B`@("`@
M("`@9F]R("@D:2`](#$[("1I(#P@-#L@)&DK*RD@>PH@("`@("`@("`@("`D
M8V]L;W)S6R1I72`]('-P<FEN=&8H)R4P,E@G+"!R;W5N9"AH97AD96,H)&-O
M;&]R<ULD:5TI("\@,C4U*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G
M/'-P86X@<W1Y;&4](F-O;&]R.B`C)R`N("1C;VQO<G-;,5T@+B`D8V]L;W)S
M6S)=("X@)&-O;&]R<ULS72`N("<B/B<@+B`D8V]L;W)S6S1=("X@)SPO<W!A
M;CXG.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!-24U%(&-O
M;G1E;G0@='EP92!O9B!T:&4@<F5N9&5R960@8V]N=&5N="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&-O;G1E;G0@='EP92!O9B!T:&4@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*
M("`@("`@("!R971U<FX@)W1E>'0O:'1M;#L@8VAA<G-E=#TG("X@3DQ3.CIG
M971#:&%R<V5T*"D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-24U%+U9I97=E<B]M<V5X
M8V5L+G!H<```````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S0T,"`Q,#4Q
M-30S-#$S-R`P,C,U,#<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!-24U%7U9I97=E<E]M<V5X
M8V5L(&-L87-S(')E;F1E<G,@;W5T($UI8W)O<V]F="!%>&-E;`H@*B!D;V-U
M;65N=',@:6X@2%1-3"!F;W)M870@8GD@=7-I;F<@=&AE('AL2'1M;"!P86-K
M86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]-24U%+TU)344O5FEE=V5R
M+VUS97AC96PN<&AP+'8@,2XR,"XQ,"XW(#(P,#8O,#$O,#$@,C$Z,C@Z,C4@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@06YI;"!-861H
M879A<&5D9'D@/&%N:6Q`<F5C;VEL+F]R9SX*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J
M($!A=71H;W(@($%N:6P@36%D:&%V87!E9&1Y(#QA;FEL0')E8V]I;"YO<F<^
M"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]-24U%
M7U9I97=E<@H@*B\*8VQA<W,@34E-15]6:65W97)?;7-E>&-E;"!E>'1E;F1S
M($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E;F1E<B!O=70@=&AE
M(&-U<G)E;G1L>2!D871A('5S:6YG('AL:'1M;"X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A<F%M<R!T:&ES(%9I97=E<B!M
M87D@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')E
M;F1E<F5D(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<B@D<&%R
M86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!G;&]B86P@)&UI;65?9')I
M=F5R<SL*"B`@("`@("`@+RH@0VAE8VL@=&\@;6%K92!S=7)E('1H92!P<F]G
M<F%M(&%C='5A;&QY(&5X:7-T<RX@*B\*("`@("`@("!I9B`H(69I;&5?97AI
M<W1S*"1M:6UE7V1R:79E<G-;)VAO<F1E)UU;)VUS97AC96PG75LG;&]C871I
M;VXG72DI('L*("`@("`@("`@("`@<F5T=7)N("<\<')E/B<@+B!S<')I;G1F
M*%\H(E1H92!P<F]G<F%M('5S960@=&\@=FEE=R!T:&ES(&1A=&$@='EP92`H
M)7,I('=A<R!N;W0@9F]U;F0@;VX@=&AE('-Y<W1E;2XB*2P@)&UI;65?9')I
M=F5R<ULG:&]R9&4G75LG;7-E>&-E;"==6R=L;V-A=&EO;B==*2`N("<\+W!R
M93XG.PH@("`@("`@('T*"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D
M=&UP7WAL<R`]($AO<F1E.CIG971496UP1FEL92@G:&]R9&5?;7-E>&-E;"<I
M.PH*("`@("`@("`D9F@@/2!F;W!E;B@D=&UP7WAL<RP@)W<G*3L*("`@("`@
M("!F=W)I=&4H)&9H+"`D=&AI<RT^;6EM95]P87)T+3YG971#;VYT96YT<R@I
M*3L*("`@("`@("!F8VQO<V4H)&9H*3L*"B`@("`@("`@)&9H(#T@<&]P96XH
M)&UI;65?9')I=F5R<ULG:&]R9&4G75LG;7-E>&-E;"==6R=L;V-A=&EO;B==
M("X@(B`M;F@@)'1M<%]X;',@,CXF,2(L("=R)RD["B`@("`@("`@=VAI;&4@
M*"@D<F,@/2!F9V5T<R@D9F@L(#@Q.3(I*2D@>PH@("`@("`@("`@("`D9&%T
M82`N/2`D<F,["B`@("`@("`@?0H@("`@("`@('!C;&]S92@D9F@I.PH*("`@
M("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@=&AE($U)344@8V]N=&5N="!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]N=&5N
M="!T>7!E(&]F('1H92!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G=&5X="]H=&UL.R!C:&%R
M<V5T/2<@+B!.3%,Z.F=E=$-H87)S970H*3L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O<VEM<&QE+G!H
M<```````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$S-3<@,3`U,34T,S0Q
M,S<@,#(S,S0U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!4:&4@34E-15]6:65W97)?<VEM<&QE(&-L
M87-S(')E;F1E<G,@;W5T('!L86EN('1E>'0@=VET:&]U="!A;GD*("H@;6]D
M:69I8V%T:6]N<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO34E-12]-24U%
M+U9I97=E<B]S:6UP;&4N<&AP+'8@,2XQ+C8N-2`R,#`V+S`Q+S`Q(#(Q.C(X
M.C(U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA
M96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M34E-15]6:65W97(*("HO"F-L87-S($U)345?5FEE=V5R7W-I;7!L92!E>'1E
M;F1S($U)345?5FEE=V5R('L*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@
M34E-12!T>7!E(&]F('1H92!R96YD97)E9"!C;VYT96YT+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!-24U%+71Y<&4@;V8@=&AE(&]U='!U="!C
M;VYT96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9714>7!E*"D*("`@('L*
M("`@("`@("!R971U<FX@)W1E>'0O<&QA:6XG.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O
M+W1A8FQE7V-E;&QS+GAS;```````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C8R-S(@,3`U
M,34T,S0Q,S<@,#(U,30W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I
M;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F
M"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@
M("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!)
M;F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO
M(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R
M87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET
M(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R
M+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T
M:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.
M62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y
M(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A
M<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R
M>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O
M('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E
M(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E
M('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,
M:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N
M<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN
M"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@
M<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)2
M04Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@
M24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@
M5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#
M2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/
M3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C
M:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@
M;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@
M26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V
M960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I
M8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT
M97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V
M9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA
M=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@
M("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*
M("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@
M("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H
M='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT
M='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@
M("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\
M(2TM("HJ*B!W<FET92!R97!E871I;F<@=&%B;&4@8V5L;',@*BHJ("TM/@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*"@H@("`@/"$M+2!M871C:&EN9R!C96QL<R!T;R!G:79E(&]U="`M/B!C
M;W9E<F5D('1A8FQE(&-E;&QS(&%R92!N;W0@=W)I='1E;B!O=70@+2T^"B`@
M("`\>'-L.G1E;7!L871E(&UA=&-H/2)T86)L93IT86)L92UC96QL(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E
M;&P@=&\@9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E
M(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB;6%X4F]W3&5N9W1H(B\^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES
M1&5B=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E/@HM+2TM+2TM
M+2TM+2TM+3X@=&%B;&4Z=&%B;&4M8V5L;"!H87,@8F5E;B!E;G1E<F5D('=I
M=&@@;F]D92!V86QU93H@/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^=&%B;&4Z;G5M
M8F5R+6-O;'5M;G,M<F5P96%T960Z("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B\^+3PO>'-L.FUE<W-A
M9V4^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M8V]L=6UN+7!O<VET:6]N+79A<FEA8FQE(CX*
M("`@("`@("`@("`@/"$M+2!P;W-I=&EO;B!O9B!T:&4@8W5R<F5N="!I;G!U
M="!C96QL('1O(&=E="!T:&4@8V]R<F5C="!C;VQU;2!S='EL92`H:&ED9&5N
M(&%R92!A;'-O(&-O=6YT960I+2T^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB
M)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S
M96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)C<F5A=&4M8V]L=6UN+7!O<VET:6]N+79A<FEA8FQE(CX*
M("`@("`@("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E
M;&P@=&\@9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E
M(&%L<V\@8V]U;G1E9"DM+3X*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L
M;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB;6%X4F]W3&5N9W1H(B\^"@H@("`@("`@(#PA+2T@8V]L=6UN('!O
M<VET:6]N(&YE961E9"!F;W(@<W1Y;&5S+"!E<W`N(&9O<B!C;VQU;6XM:&ED
M9&5N+69L86<@+2T^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P<F5C
M961I;F<M8V]L=6UN<R(^"B`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L
M96-T/2)P<F5C961I;F<M<VEB;&EN9SHZ*B(^"B`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB<75A;G1I='DB/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"A`=&%B;&4Z;G5M8F5R+6-O;'5M
M;G,M<F5P96%T960I(#T@,"(^,3PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/CQX<VPZ=F%L=64M;V8@<V5L96-T
M/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960B+SX\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ
M9F]R+65A8V@^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&%B;&4M8V5L;"(^
M"B`@("`@("`@("`@("`@("`@("`@/"$M+2!P;W-I=&EO;B!O9B!T:&4@8W5R
M<F5N="!I;G!U="!C96QL('1O(&=E="!T:&4@8V]R<F5C="!C;VQU;2!S='EL
M92`H:&ED9&5N(&%R92!A;'-O(&-O=6YT960I+2T^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT
M<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O
M=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L96-T/2)S=6TH>'0Z;F]D92US
M970H)'!R96-E9&EN9RUC;VQU;6YS*2]Q=6%N=&ET>2D@*R`Q(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0](F9U;F-T:6]N+6%V86EL86)L92@G>&%L86XZ;F]D97-E="<I(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M
M=&%B;&4M8V5L;"(^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!P;W-I=&EO
M;B!O9B!T:&4@8W5R<F5N="!I;G!U="!C96QL('1O(&=E="!T:&4@8V]R<F5C
M="!C;VQU;2!S='EL92`H:&ED9&5N(&%R92!A;'-O(&-O=6YT960I+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O
M;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X
M4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO;B(@("`@("`@("`@<V5L96-T/2)S
M=6TH>&%L86XZ;F]D97-E="@D<')E8V5D:6YG+6-O;'5M;G,I+W%U86YT:71Y
M*2`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2).;V1E4V5T1G5N8W1I;VY.;W1!=F%I;&%B;&4B+SX*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&%B
M;&4M8V5L;"(O/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F-R96%T92UT86)L92UC96QL(CX*("`@("`@
M("`\(2TM('!O<VET:6]N(&]F('1H92!C=7)R96YT(&EN<'5T(&-E;&P@=&\@
M9V5T('1H92!C;W)R96-T(&-O;'5M('-T>6QE("AH:61D96X@87)E(&%L<V\@
M8V]U;G1E9"DM+3X*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M;6%X4F]W3&5N9W1H(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQU
M;6XM<&]S:71I;VXB+SX*"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B
M=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E/DY%5R!604Q513H@
M8V]L=6UN+7!O<VET:6]N.B`M/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQU
M;6XM<&]S:71I;VXB+SXM/"]X<VPZ;65S<V%G93X*("`@("`@("`\+WAS;#II
M9CX*"@H@("`@("`@(#PA+2T@82!H:61D96X@8V]L=6UN('=I;&P@9VEV92!O
M=70@;F]T:&EN9R`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](FYO="@D86QL
M0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO
M;B@I(#T@)&-O;'5M;BUP;W-I=&EO;ETO0&-O;'5M;BUH:61D96XM9FQA9RDB
M/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PA
M+2T@=VAE;B!T:&4@8V]L=6UN<R!A<F4@;F]T(')E<&5A=&5D('1H92!N97AT
M(&-O;'5M;BUP;W-I=&EO;G,@<F%I<V5S('5P('1O(#$L(&]T:&5R=VES92!U
M<"!T;R!T:&4@86UO=6YT(&]F(')E<&5A=&5D(&-O;'5M;G,@+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1A8FQE.FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D(CX*("`@("`@("`@("`@("`@("`@("`\(2TM('=R:71E
M<R!M=6QT:7!L92!E;G1R:65S(&]F(&$@8V5L;"`M+3X*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB<F5P96%T+7=R:71E
M+6-E;&PB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y;&5%;G1R:65S(B`@("!S
M96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I
M=&EO;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M
M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T
M:"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB;G5M8F5R+6-O;'5M;G,M<F5P96%T960B("!S96QE8W0](D!T86)L
M93IN=6UB97(M8V]L=6UN<RUR97!E871E9"(O/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C96QL
M("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)W<FET92UC96QL(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT
M<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQU;6XM<&]S:71I;VXB("`@("`@("`@('-E;&5C=#TB)&-O;'5M;BUP;W-I
M=&EO;B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB;6%X4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M
M87A2;W=,96YG=&@B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ:68^"@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(G)E<&5A="UW<FET92UC96QL(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)M87A2;W=,96YG=&@B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B\^"@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\(2TM(#)$3SH@5&AI<R!I<R!T:&4@8W5R
M<F5N="!W;W)K87)O=6YD(&%G86EN<W0@=&AE(&)A8VMG<F]U;F0@<VEM=6QA
M=&EO;B!B>2!A;B`G96YD;&5S<R<@<F5P96%T:6YG(&-E;&P@+2T^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;G5M8F5R+6-O;'5M;G,M<F5P96%T
M960@/B`Q(&%N9"`D;6%X4F]W3&5N9W1H(#X@)&-O;'5M;BUP;W-I=&EO;B(^
M"@H@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93XK*RLK*RLK*RL@
M<W1A<G1I;F<@8V5L;"!W<FET:6YG("LK*RLK*RLK*SPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/FYU;6)E<BUC;VQU
M;6YS+7)E<&5A=&5D.B`M/'AS;#IV86QU92UO9B!S96QE8W0](B1N=6UB97(M
M8V]L=6UN<RUR97!E871E9"(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YM87A2;W=,96YG=&@Z("T\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/BT\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC;VQU;6XM<&]S
M:71I;VXZ("T\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO
M;B(O/BT\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^
M"@H@("`@("`@("`@("`@("`@/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C
M96QL("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G=R:71E+6-E;&PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@
M<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUP;W-I=&EO
M;B(@("`@("`@("`@<V5L96-T/2(D8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA>%)O=TQE
M;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@/"$M+2!R97!E870@8V%L;&EN9R!T:&ES(&UE=&AO9"!U;G1I;"!A
M;&P@96QE;65N=',@=W)I='1E;B!O=70@+2T^"B`@("`@("`@("`@("`@("`\
M>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IM97-S86=E/BLK*RLK*RLK*R!C96QL(')E<&5T:71I;VX@*RLK
M*RLK*RLK/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF
M/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E
M<&5A="UW<FET92UC96QL(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@
M('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<&]S:71I
M;VXB("`@("`@("`@('-E;&5C=#TB)&-O;'5M;BUP;W-I=&EO;B`K(#$B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X
M4F]W3&5N9W1H(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B
M+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M;G5M8F5R+6-O;'5M;G,M<F5P96%T960B("!S96QE8W0](B1N=6UB97(M8V]L
M=6UN<RUR97!E871E9"`M(#$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"$M+2`R1$\Z
M(%1H:7,@:7,@=&AE(&-U<G)E;G0@=V]R:V%R;W5N9"!A9V%I;G-T('1H92!B
M86-K9W)O=6YD('-I;75L871I;VX@8GD@86X@)V5N9&QE<W,G(')E<&5A=&EN
M9R!C96QL("TM/@H@("`@("`@("`@("`@("`@/"$M+2`@("`@(%=H96X@=&AE
M(&UA>%)O=TQE;F=T:"!I<R!R96%C:&5D(&$@;&%S="!E;G1R>2!O9B!A(&-E
M;&P@:7,@=W)I='1E;B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)W<FET92UC96QL(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M("`@("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3
M='EL945N=')I97,B("`@('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQU;6XM<&]S:71I;VXB("`@("`@("`@('-E;&5C=#TB)&-O;'5M;BUP
M;W-I=&EO;B(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB)&UA
M>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)W<FET92UC96QL(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L=6UN+7!O<VET:6]N(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)M87A2;W=,96YG=&@B+SX*"@H@("`@("`@(#QX<VPZ
M:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IM97-S
M86=E/E=R:71E5&5S="`M/B!)9B!N;W1H:6YG(&)E='=E96X@)RTG('=R:71E
M(&-E;&P@+3QX<VPZ=F%L=64M;V8@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%
M;G1R:65S+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I(#T@)&-O;'5M
M;BUP;W-I=&EO;ETO0&-O;'5M;BUH:61D96XM9FQA9R(O/BT\+WAS;#IM97-S
M86=E/@H@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`@("`@/'AS;#II9B!T
M97-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S+V-O;'5M;BUS='EL92UE;G1R
M>5MP;W-I=&EO;B@I(#T@)&-O;'5M;BUP;W-I=&EO;ETO0&-O;'5M;BUH:61D
M96XM9FQA9R(^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E
M8G5G36]D92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/E1!
M0DQ%($-/3%5-3B!I<R!H:61D96XA/"]X<VPZ;65S<V%G93X*("`@("`@("`@
M("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2T@82!H:61D96X@8V]L
M=6UN('=I;&P@9VEV92!O=70@;F]T:&EN9R`M+3X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T
M>6QE+65N=')Y6W!O<VET:6]N*"D@/2`D8V]L=6UN+7!O<VET:6]N72]`8V]L
M=6UN+6AI9&1E;BUF;&%G(CX*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S
M=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE
M<W-A9V4^5$%"3$4@0T],54U.(&ES(&AI9&1E;B$\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@(#PO>'-L.G=H
M96X^"@H@("`@("`@("`@("`\(2TM($Y/5"!A(&AI9&1E;B!C;VQU;6X@+2T^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H*("`@("`@("`@("`@("`@
M(#PA+2T@82!T86)L92!I<R!A('1A8FQE(&AE861E<BP@=VAE;B!I="!H87,@
M82`B=&%B;&4Z=&%B;&4M:&5A9&5R+7)O=W,B(&%N8V5S=&]R("TM/@H@("`@
M("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)T86)L941A=&%4>7!E
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R.CIT86)L
M93IT86)L92UH96%D97(M<F]W<R(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^=&@\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YT9#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*"B`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\
M(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I($A%041%4B!3
M5%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1T86)L941A
M=&%4>7!E?2(^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II
M9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93X**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHG/'AS;#IV86QU92UO9B!S96QE8W0](B1T
M86)L941A=&%4>7!E(B\^)R!E;&5M96YT(&AA<R!B965N(&%D9&5D(3PO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VQS
M<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N
M;F5D(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M:68^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)R;W=S<&%N
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M<F]W<RUS<&%N;F5D(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H*
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM("HJ*B!T:&4@8V5L
M;"US='EL92`J*BH@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(%1H92!C96QL('-T>6QE(&AA<R!N;R!C;VYC;'5S:6]N('=I=&@@=&AE
M(&-O;'5M;B!S='EL92P@<V\@=V4@<W=I=&-H('1H92!O<F1E<B]P<FEO<FET
M:65S(&1U92!T;R!B<F]W<V5R(&ES<W5E<PH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!4:&4@8V5L;"US='EL92!D97!E;F1S(&]N('1W;R!A
M='1R:6)U=&5S.@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q
M*2!T86)L93IS='EL92UN86UE("T@=&AE('-T>6QE('!R;W!E<G1I97,@;V8@
M8V5L;"X@5VAE;B!T:&5Y(&5X:7-T+"!A(&1E9F%U;'0@86QI9VYE;65N="`H
M8W`N(&)E;&]W*2!W:6QL(&)E(&%D9&5D(&9O<B!T:&4*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92!O9B!N;R!A;&EG;FUE;G0@:6X@=&AE('-T>6QE(&5X:7-T+@H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`R*2!T86)L93IV86QU92UT>7!E
M("T@=&AE('9A;'5E('1Y<&4@;V8@=&AE('1A8FQE+6-E;&P@9VEV:6YG('1H
M92!D969A=6QT(&%L:6=N;65N=',N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($)Y(&1E9F%U;'0@82!S
M=')I;F<@=F%L=64@:7,@;&5F="!A;&EG;F5D+"!A;&P@;W1H97(@87)E(&%L
M:6=N960Z<FEG:'0N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`
M=&%B;&4Z<W1Y;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM($-%3$PM
M4U193$4Z(&%L:6=N;65N="!B>2!T86)L93IV86QU92UT>7!E("AW:71H;W5T
M(&5X:7-T:6YG('1A8FQE.G-T>6QE+6YA;64I+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F-E;&Q3='EL92(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS
M='EL97,O*EMN86UE*"D]8W5R<F5N="@I+T!T86)L93IS='EL92UN86UE72(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](G-T<FEN9RUL96YG=&@H)&-E;&Q3
M='EL92D@/B`P(&%N9"!N;W0H8V]N=&%I;G,H)&-E;&Q3='EL92P@)W1E>'0M
M86QI9VXG*2DB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\(2TM($-%3$PM4U193$4Z(&%L:6=N;65N="!B>2!T
M86)L93IV86QU92UT>7!E("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&YO(&%L:6=N;65N="!I;B!T
M:&4@8V5L;"!S='EL92P@=&AE(&%L:6=N;65N="!B87-E9"!O;B!T:&4@=&%B
M;&4Z=F%L=64M='EP92!W:6QL(&)E(&%D9&5D("TM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&%B;&4Z=F%L=64M='EP92!A
M;F0@;F]T*$!T86)L93IV86QU92UT>7!E(#T@)W-T<FEN9R<I(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1C;VQL96-T961'
M;&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE
M.G-T>6QE+6YA;65=+"`G=&5X="UA;&EG;CIR:6=H=#L@)RDB+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1C;VQL96-T961';&]B
M86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T
M>6QE+6YA;65=+"`G=&5X="UA;&EG;CIL969T.R`G*2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"$M+2!#14Q,+5-464Q%.B!A;&EG;FUE;G0@8GD@
M=&%B;&4Z=F%L=64M='EP92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!N;R!#4U,@<W1Y;&4@<')O
M<&5R=&EE<R!E>&ES="P@;VYL>2!A;&EG;FUE;G0@9G)O;2!T:&4@=&%B;&4Z
M=F%L=64M='EP92!W:6QL(&)E('5S960@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!T86)L93IV86QU92UT>7!E(&%N9"!N
M;W0H0'1A8FQE.G9A;'5E+71Y<&4@/2`G<W1R:6YG)RDB/G1E>'0M86QI9VXZ
M<FEG:'0[(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93YT97AT
M+6%L:6=N.FQE9G0[(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C;VQU;6XM<W1Y;&4@*&1I
M<VIU;F-T(&]F(&-E;&P@<W1Y;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2`R1$\Z(&]N;'D@86)S;VQU="!S
M='EL97,@87)E('-U<'!O<G1E9"P@<F5L871I=F4@<W1Y;&5S("AI+F4N("=S
M='EL93IR96PM8V]L=6UN+7=I9'1H)R!E+F<N('=I=&@@=F%L=64@(C@Y,S,J
M(B!A<F4@:6=N;W)E9"X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($ES<W5E.B!B<F]W<V5R<R`H;F]T('-U<F4@:68@
M0U-3*2!D;V5S(&YO="!S=7!P;W)T('1H92`G*B<@<F5L871I;VYS:&EP+"!O
M;FQY('1H92`G)2<L('=H97)E('1H92!S=6T@:7,@86QW87ES("<Q,#`G(0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1F]R('1H:7,L(&ET(&ES(&5A<VEE<B!T;R!W;W)K(&]N('=I=&@@=&AE(&%B
M<V]L=71E('9A;'5E<RP@:6YS=&5A9"!O9B!C86QC=6QA=&EN9R!T:&4@=F%L
M=65S(&9O<B`Q,#`E("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S+V-O;'5M;BUS='EL92UE;G1R>5MP;W-I=&EO;B@I/21C
M;VQU;6XM<&]S:71I;VY=(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"$M+2!#14Q,+5-464Q%.B!T86)L93IS='EL
M92UN86UE("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB=')A;G-L871E*$!T86)L93IS='EL92UN86UE+"`G+B`E*"DO7"<L("<G
M*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!#14Q,+5-464Q%
M.B!A;&EG;FUE;G0@8GD@=&%B;&4Z=F%L=64M='EP92`H=VET:&]U="!E>&ES
M=&EN9R!T86)L93IS='EL92UN86UE*2TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"$M+2!N;R!T86)L93IS='EL92UN86UE
M(&5X:7-T+"!O;FQY(&%L:6=N;65N="!F<F]M('1H92!T86)L93IV86QU92UT
M>7!E('=I;&P@8F4@=7-E9"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`
M=&%B;&4Z=F%L=64M='EP92!A;F0@;F]T*$!T86)L93IV86QU92UT>7!E(#T@
M)W-T<FEN9R<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&5X="UA;&EG;CIR:6=H=#L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!T97AT+6%L:6=N.FQE9G0["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PA+2T@26X@8V%S92!O9B!N;R!C96QL(&-O;G1E;G0@82!N;VXM
M8G)E86MA8FQE('-P86-E('=I;&P@8F4@:6YS97)T960*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('1O(&UA:V4@=&AE(&)R;W=S97(@
M<VAO=R!T:&4@=&%B;&4M8V5L;"!G<FED("TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H8VAI;&0Z.G1E
M>'0H*2D@86YD(&YO="AC:&EL9#HZ*BDB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^("8C,38P.SPO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2`J
M*BH@=&AE(&-O;'5M;BUS='EL92`J*BH@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PA+2T@('1H92!C;VQU;6X@<W1Y;&4@:&%S
M(&YO(&-O;F-L=7-I;VX@=VET:"!T:&4@8V5L;"!S='EL92P@<V\@=V4@<W=I
M=&-H('1H92!O<F1E<B]P<FEO<FET:65S(&1U92!T;R!B<F]W<V5R(&ES<W5E
M<RTM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S<R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N=')I97,O
M8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D@/2`D8V]L=6UN+7!O<VET
M:6]N72]`<W1Y;&4M;F%M92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T
M97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L
M871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@
M("`@("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.140@5T%9
M("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2(D;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1T86)L941A=&%4>7!E
M?2(^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T
M/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<W!A;FYE9"(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L
M<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<W!A
M;FYE9"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T
M/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<F]W<W!A
M;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(&-E;&PM<W1Y;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE.G-T>6QE
M+6YA;65=(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M
M+2!C;VQU;6XM<W1Y;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1A;&Q#;VQU;6Y3='EL945N
M=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6W!O<VET:6]N*"D])&-O;'5M;BUP
M;W-I=&EO;ETB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM(%1!0DQ%.E9!3%5%+5194$4@+2!T:&4@=F%L=64@;V8@82!T86)L92UC
M96QL('=I;&P@8F4@86QI9VYE9"!L969T(&)Y(&1E9F%U;'0@;VYL>2!E>&QI
M8VET(&YO;BUS=')I;F<@:7,@86QI9VYE9#IR:6=H="TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1A
M8FQE.G9A;'5E+71Y<&4@86YD(&YO="A`=&%B;&4Z=F%L=64M='EP92`]("=S
M=')I;F<G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^=&5X="UA;&EG;CIR:6=H=#L\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=&5X=#YT97AT+6%L:6=N.FQE9G0[/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM("8C,38P
M(&ES(&$@;F]N+6)R96%K86)L92!S<&%C92P@;F5C97-S87)Y('1O(&UA:V4@
M=&\@=&AE(&)R;W=S97(@<VAO=R!T:&4@=&%B;&4M8V5L;"!G<FED("TM/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H
M8VAI;&0Z.G1E>'0H*2D@86YD(&YO="AC:&EL9#HZ*BDB/B`F(S$V,#L\+WAS
M;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM
M=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\(2TM*RLK*RL@
M4$%,32!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB>R1T86)L
M941A=&%4>7!E?2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.FEF('1E<W0](D!T86)L93IN=6UB97(M8V]L=6UN<RUS<&%N;F5D(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)C;VQS<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!T86)L93IN=6UB97(M8V]L
M=6UN<RUS<&%N;F5D(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#II9B!T97-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M<W!A;FYE9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB<F]W<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+7)O=W,M
M<W!A;FYE9"(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.FEF/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L
M>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#PA+2TK*RLK
M*R!734P@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=734PG(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB;F]T*"1A;&Q#;VQU;6Y3='EL945N
M=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6VQA<W0H*2`]("1C;VQU;6XM<&]S
M:71I;VY=*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#XL(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F)R(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"CPO>'-L.G-T>6QE<VAE970^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE
M=V5R+V]O;R]M86EN7VAT;6PN>'-L````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4V
M-3,S(#$P-3$U-#,T,3,W(#`R-#8T-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@
M=&AI<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T
M97)M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*
M("`@("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E
M(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R
M9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y
M<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE
M<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG
M:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@
M06YT;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H
M:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I
M8G5T92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O
M9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E
M<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@
M1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I
M;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE4
M2$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W
M87)R86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@
M02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@
M1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@
M66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE
M<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI
M<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E
M"B`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@
M,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@
M26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ
M"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B
M:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@
M3&EC96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@
M;F]T('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET
M:"!T:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@
M("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS
M92YH=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E
M;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/
M550@5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-
M4$Q)140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)2
M04Y42453(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*
M("`@34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T
M:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@
M86YD"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*
M("`@5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E
M(&ES.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@
M,C`P,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S
M(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E
M="!V97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@
M("`@("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#`O;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*
M("`@("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@
M("`@("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO
M1F]R;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN
M=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*
M("`@("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O
M,C`P,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X
M;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O
M,3DY."]-871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@
M("`@("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+W-C<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*
M("`@("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@
M("`@("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S
M+S$N,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@
M("`@("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z
M+R]W=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y
M<W1E;3TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG
M+E-Y<W1E;2(*("`@("`@("`@("`@("`@('AM;&YS.G5R;&5N8V]D97(](FAT
M='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J879A+VIA=F$N;F5T+E523$5N8V]D
M97(B"B`@("`@("`@("`@("`@("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA
M<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB
M:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@
M("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S/2)J879A(CX*"B`@("`\>'-L
M.F]U='!U="!M971H;V0@("`@("`](GAM;"(*("`@("`@("`@("`@("`@(&5N
M8V]D:6YG("`@(#TB551&+3@B"B`@("`@("`@("`@("`@("!I;F1E;G0@("`@
M("`](GEE<R(O/@H*"@H@("`@/"$M+2LK*RLK($E.0TQ51$5$(%A33"!-3T15
M3$53("LK*RLK+2T^"B`@("`\(2TM(&EN:&5R:71E9"!S='EL92!P<F]P97)T
M:65S('=I;&P@8F4@8V]L;&5C=&5D(&%N9"!W<FET=&5N(&EN(&$@0U-3(&AE
M861E<B`H0U-3*2`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)S='EL95]H
M96%D97(N>'-L(B\^"@H@("`@/"$M+2!I;FAE<FET960@<W1Y;&4@<')O<&5R
M=&EE<R!W:6QL(&)E(&-O;&QE8W1E9"!A;F0@=W)I='1E;B!A<R!H=&UL('!R
M;W!E<G1I97,@:6X@82!T96UP;W)A<GD@=F%R:6%B;&4@*$A434PT+"!004Q-
M*2`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)S='EL95]I;FQI;F5D+GAS
M;"(O/@H*("`@(#PA+2T@;W5R('AM;"!S='EL92!P<F]P97)T:65S('=I;&P@
M8F4@;6%P<&5D('1O($-34R!A;F0@2%1-3#0N>"!P<F]P97)T:65S("TM/@H@
M("`@/'AS;#II;F-L=61E(&AR968](G-T>6QE7VUA<'!I;F<N>'-L(B\^"@H@
M("`@/"$M+2!C;VUM;VX@96QE;65N="!H86YD;&EN9R`M+3X*("`@(#QX<VPZ
M:6YC;'5D92!H<F5F/2)C;VUM;VXN>'-L(B\^"@H@("`@/"$M+2!T86)L92!H
M86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L92YX<VPB
M+SX*"B`@("`\(2TM('!A;&T@:&%N9&QI;F<@+2T^"B`@("`\>'-L.FEN8VQU
M9&4@:')E9CTB<&%L;2YX<VPB+SX*"B`@("`\(2TM(&=L;V)A;"!D;V-U;65N
M="!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F/2)G;&]B86Q?
M9&]C=6UE;G0N>'-L(B\^"@H*"@H*"@H@("`@/"$M+2LK*RLK(%!!4D%-151%
M4B!&4D]-(%1(12!!4%!,24-!5$E/3B!!3D0@1TQ/0D%,(%9!4DE!0DQ%4R`K
M*RLK*RTM/@H*("`@(#PA+2T@34%.1$%43U)9.B!54DP@;V8@;65T82!S=')E
M86T@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](FUE=&%&:6QE55),(B\^"@H@
M("`@/"$M+2!-04Y$051/4EDZ(%523"!O9B!S='EL97,@<W1R96%M("TM/@H@
M("`@/'AS;#IP87)A;2!N86UE/2)S='EL97-&:6QE55),(B\^"@H@("`@/"$M
M+2!-04Y$051/4EDZ(&9O<B!R97-O;'9I;F<@<F5L871I=F4@;&EN:W,*("`@
M("`@("!&;W(@<F5S;VQV:6YG(')E86QT:79E(&QI;FMS('1O('1H92!P86-K
M960@4T\@9&]C=6UE;G0L(&DN92X@=&AE('!A=&@O55),(&]F('1H92!J87)E
M9"!S>'<@9FEL92`H92YG+B!M971A+GAM;"P@<W1Y;&5S+GAM;"P@;&EN:W,@
M=&\@9W)A<&AI8W,@:6X@82!R96QA=&EV92!D:7)E8W1O<GDI("TM/@H@("`@
M/'AS;#IP87)A;2!N86UE/2)A8G-O;'5T95-O=7)C941I<E)E9B(O/@H*("`@
M(#PA+2T@3U!424].04P@*&UA;F1A=&]R>2P@=VAE;B!W:&5N('-O=7)C92!I
M<R!C;VUP<F5S<V5D*3H@3F5C97-S87)Y(&9O<B!T:&4@:6X@=&AE('!A8VME
M9"!/3R!D;V-U;65N="!E;6)E9&1E9"!F:6QE<R`H;6]S=&QY(&=R87!H:6-S
M(&9R;VT@=&AE(&-O;7!R97-S960@+U!I8W1U<F4@9&ER*2X*("`@("`@("`@
M5VAE;B!T:&4@3W!E;D]F9FEC92`H3T\I(&9I;&4@:&%S(&)E96X@=6YP86-K
M960@=&AE(&%B<V]L=71E4V]U<F5$:7)2968@8V%N(&)E('1A:V5N+`H@("`@
M("`@("!/=&AE<G=I<V4L(&$@2D%2(%523"!C;W5L9"!B92!C:&]O<V5N(&]R
M('=H96X@=V]R:VEN9R!W:71H($]P96Y/9F9I8V4@82!S;R!C86QL960@4&%C
M:V%G92U54DP@96YC;V1E9"!O=F5R($A45%`@8V%N(&)E('5S960@=&\*("`@
M("`@("`@86-C97-S('1H92!J87)E9"!C;VYT96YT<R!O9B!T:&4@=&AE(&IA
M<F5D(&1O8W5M96YT+B`N("TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)J87)E
M9%)O;W154DPB('-E;&5C=#TB)&%B<V]L=71E4V]U<F-E1&ER4F5F(B\^"@H@
M("`@/"$M+2!/4%1)3TY!3"`H;6%N9&%T;W)Y+"!W:&5N('5S960@:6X@<V5S
M<VEO;B!B87-E9"!E;G9I<F]N;65N="D*("`@("`@("`@57-E9G5L(&9O<B!7
M96)!<'!L:6-A=&EO;G,Z(&EF(&$@2%144"!S97-S:6]N(&ES(&YO="!C;V]K
M:64@8F%S960L(%523"!R97=R:71I;F<@:7,@8F5E:6YG('5S960@*'1H92!S
M97-S:6]N(&ES(&%P<&5N9&5D('1O('1H92!54DPI+@H@("`@("`@("!4:&ES
M(%523"!S97-S:6]N(&ES('5S960@=VAE;B!C<F5A=&EN9R!L:6YK<R!T;R!G
M<F%P:&EC<R!B>2!84TQ4+B!/=&AE<G=I<V4@=&AE('5S97(@:&%V="!T;R!L
M;V<@86=A:6X@:6X@9F]R(&5V97)Y(&=R87!H:6,@:&4@=V]U;&0@;&EK92!T
M;R!S964N("TM/@H@("`@/'AS;#IP87)A;2!N86UE/2)O<'1I;VYA;%523%-U
M9F9I>"(O/@H*("`@(#PA+2T@3U!424].04PZ($1022`H9&]T<R!P97(@:6YC
M:"D@=&AE('-T86YD87)D('-O;'5T:6]N(&]F(&=I=F5N('!I8W1U<F5S("AN
M96-E<W-A<GD@9F]R('1H92!C;VYV97)S:6]N(&]F("=C;2<@:6YT;R`G<&EX
M96PG*2TM/@H@("`@/"$M+2!!;'1H;W5G:"!M86YY('!I8W1U<F5S(&AA=F4@
M=&AE(#DV(&1P:2!R97-O;'5T:6]N+"!A(&AI9VAE<B!R97-O;'1I;VX@9VEV
M92!B971T97(@<F5S=6QT<R!F;W(@8V]M;6]N(&)R;W=S97)S("TM/@H@("`@
M/'AS;#IP87)A;2!N86UE/2)D<&DB('-E;&5C=#TB.38B+SX*"B`@("`\(2TM
M($]05$E/3D%,.B!I;B!C87-E(&]F('5S:6YG(&$@9&EF9F5R96YT('!R;V-E
M<W-O<B!T:&%N(&$@2D%602!84TQ4+"!Y;W4@8V%N('5N86)L92!T:&4@2F%V
M82!F=6YC=&EO;F%L:71Y"B`@("`@("`@("AI+F4N(&1E8G5G9VEN9R!T:6UE
M(&%N9"!E;F-O9&EN9R!C:&%P=&5R(&YA;65S(&9O<B!T:&4@8V]N=&5N="UT
M86)L92!A<R!H<F5F(&%N9"!A;F-H;W)S("D@+2T^"B`@("`\>'-L.G!A<F%M
M(&YA;64](F1I<V%B;&5*879A(B`@("!S96QE8W0](F9A;'-E(B\^"B`@("`\
M>'-L.G!A<F%M(&YA;64](FES2F%V841I<V%B;&5D(B!S96QE8W0](F)O;VQE
M86XH)&1I<V%B;&5*879A*2(O/@H*("`@(#PA+2T@3U!424].04PZ('5S97(M
M86=E;G0@=VEL;"!B92!D:69F97)N=&EA=&5D(&)Y('1H:7,@<&%R86UE=&5R
M(&=I=F5N(&)Y(&%P<&QI8V%T:6]N("AE+F<N(&IA=F$@<V5R=FQE="DM+3X*
M("`@(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T5'EP92(@<V5L96-T/2(G0U-3
M7TA%041%4B<B+SX*("`@(#PA+2T@<V5T(&]F('!O<W-I8FQE(&1E=FEC951Y
M<',@*%=-3"!I<R!S970@:6X@:71S(&]W;B!S=&%R=&9I;&4@;6%I;E]W;6PN
M>'-L*3H*("`@(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T5'EP92(@<V5L96-T
M/2(G0U-37TA%041%4B<B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB;W5T<'5T
M5'EP92(@<V5L96-T/2(G0U-37TE.3$E.140G(B\^"B`@("`\>'-L.G!A<F%M
M(&YA;64](F]U='!U=%1Y<&4B('-E;&5C=#TB)U!!3$TG(B\^("TM/@H*("`@
M(#PA+2T@3U!424].04PZ(&9O<B!A8W1I=F%T:6YG('1H92!D96)U9R!M;V1E
M('-E="!T:&4@=F%R:6%B;&4@:&5R92!T;R`G=')U92@I)R!O<B!G:79E(&%N
M>2!V86QU92!F<F]M(&]U='-I9&4@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64]
M(F1E8G5G(B`@("`@("`@('-E;&5C=#TB9F%L<V4B+SX*("`@(#QX<VPZ<&%R
M86T@;F%M93TB:7-$96)U9TUO9&4B("`@<V5L96-T/2)B;V]L96%N*"1D96)U
M9RDB+SX*"CPA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*@H@("`@
M3U!424].04PZ($Y%141%1"!)3B!#3TY.14-424].(%=)5$@@02!'3$]"04P@
M1$]#54U%3E0@+2T^"@H@("`@/"$M+5-534U!4EDZ"B`@("`@("`@(&9O;&QO
M=VEN9R!P87)A;65T97(@=')I9V=E<G,@82`H<75I=&4@=&EM92!C;VYS=6UI
M;F<I(&5N86)L:6YG(&]F(&)O;VMM87)K<R!I;B!T:&4@=&%B;&4M;V8M8V]N
M=&5N="X*("`@("`@("!)3B!$151!24PZ"B`@("`@("`@($-U<G)E;G1L>2!S
M;VUE(&QI;FMS('5S960@:6X@=&AE($]F9FEC92!834P@*&4N9RX@:6X@=&AE
M(&-O;G1E;G0@=&%B;&4@87,@)R,W+E-O;64E,C!%>&%M<&QE)3(P2&5A9&QI
M;F4E-T]U=&QI;F4G*0H@("`@("`@("!I<R!N;W0@82!V86QI9"!54DP@*&-M
M<"X@8G5G(&ED(R`Q,#(S,3$I+B!.;R!F:6QE(&1E<W1I;F%T:6]N(&ES('-P
M96-I9FEE9"!N;W(@97AI<W0@86YY(&%N8VAO<B!E;&5M96YT(&9O<B!T:&5S
M90H@("`@("`@("!L:6YK<R!I;B!T:&4@3V9F:6-E(%A-3"X*("`@("`@("`@
M02!W;W)K87)O=6YD(&9O<B!T:&ES('1R86YS9F]R;6%T:6]N('1H97)E9F]R
M92!H860@=&\@8F4@;6%D92X@5&AI<R!T:6UE+6-O;G-U;6EN9R!M96-H86YI
M<VT@:7,@9&ES86)L960@8GD@9&5F875L="!A;F0*("`@("`@("`@8V%N(&)E
M(&%C=&EV871E9"!B>2!A('!A<F%M971E<B`H:2YE+B`G9&ES86)L94QI;FME
M9%1A8FQE3V9#;VYT96YT)RDN($$@8W)E871I;VX@;V8@86X@86YC:&]R(&ES
M(&UA9&4@9F]R(&5A8V@@:&5A9&5R(&5L96UE;G0N"B`@("`@("`@($%L;"!H
M96%D97(@=&ET;&5S(&=O;FYA(&)E(&5N8V]D:6YG('1O(&)E('5S86)L92!I
M;B!A(')E;&%T:79E(%523"X@("`@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64]
M(F1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="(@<V5L96-T/2)F86QS92@I
M(B\^"@H@("`@/"$M+2!4:&4@8VAA<'1E<B!N=6UB97)S(&]F('1H92!C=7)R
M96YT(&1O8W5M96YT("AA<R!A('-E<75E;F-E(&]F(&$@9VQO8F%L(&1O8W5M
M96YT*2!I<R!D97!E;F1E;G0@;V8@=&AE(&YU;6)E<@H@("`@("`@(&]F(&-H
M87!T97(@;V8@=&AE('-A;64@;&5V96P@:6X@<')E8V5D:6YG(&1O8W5M96YT
M<RX@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),
M979E;#$B("!S96QE8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E
M8V5D:6YG0VAA<'1E<DQE=F5L,B(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP
M87)A;2!N86UE/2)P<F5C961I;F=#:&%P=&5R3&5V96PS(B`@<V5L96-T/2(P
M(B\^"B`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E
M;#0B("!S96QE8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D
M:6YG0VAA<'1E<DQE=F5L-2(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A
M;2!N86UE/2)P<F5C961I;F=#:&%P=&5R3&5V96PV(B`@<V5L96-T/2(P(B\^
M"B`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#<B
M("!S96QE8W0](C`B+SX*("`@(#QX<VPZ<&%R86T@;F%M93TB<')E8V5D:6YG
M0VAA<'1E<DQE=F5L."(@('-E;&5C=#TB,"(O/@H@("`@/'AS;#IP87)A;2!N
M86UE/2)P<F5C961I;F=#:&%P=&5R3&5V96PY(B`@<V5L96-T/2(P(B\^"B`@
M("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),979E;#$P(B!S
M96QE8W0](C`B+SX*"B`@("`\(2TM(%A-3"!D;V-U;65N=',@8V]N=&%I;FEN
M9R!A('1A8FQE(&]F(&-O;G1E;G1S+`H@("`@("`@(&=O;FYA(&QI;FL@9F]R
M('5S86)I;&ET>2!R96%S;VX@86)O=F4@96%C:"!C:&%P=&5R('1O('1H92!P
M<F5C961I;F<@86YD(&9O;&QO=VEN9R!D;V-U;65N="!A;F0@=&AE(&-O;G1E
M;G0@=&%B;&4@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F-O;G1E;G1486)L
M95523"(O/@H*("`@(#PA+2T@3F5E9&5D(&9O<B!T:&4@8G5G('=O<FMA<F]U
M;F0@;V8@;6ES<VEN9R!C;VYT96YT('1A8FQE(&QI;FMS"B`@("`@("`@8GD@
M=&AI<R!A;6)I9V]U<R!(5$U,(')E9F5R96YC97,@9G)O;2!T:&4@8V]N=&5N
M="!T86)L92!C86X@8F4@979O:61E9"TM/@H@("`@/'AS;#IP87)A;2!N86UE
M/2)G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B+SX*"B`@("`\(2TM
M($YE961E9"!F;W(@=&AE(&)U9R!W;W)K87)O=6YD(&]F(&UI<W-I;F<@8V]N
M=&5N="!T86)L92!L:6YK<PH@("`@("`@(&)Y('1H:7,@;F]D92US970@=&AE
M(')E;&%T:6]N(&)E='=E96X@8V]N=&5N="UT86)L92!L:6YK(&%N9"!C:&EL
M9')E;B!D;V-U;65N="!H96%D97(@8V%N(&)E('5N86UB:6=O=7,@97-T86)L
M:7-H960@+2T^"B`@("`\>'-L.G!A<F%M(&YA;64](F-O;G1E;G1486)L94AE
M861I;F=S(B\^"@H*/"$M+2!%3D0@3T8@1TQ/0D%,($1/0U5-14Y4(%-%0U1)
M3TX**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BTM/@H*"@H@("`@/"$M
M+2!W;W)K<R!F;W(@;F]R;6%L('-E<&%R871E9"!Z:7!P960@>&UL(&9I;&5S
M(&%S(&9O<B!F;&%T(&9I;'1E<B!S:6YG;&4@>&UL(&9I;&4@9F]R;6%T(&%S
M('=E;&P@+2T^"B`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]F9FEC93IM971A
M+69I;&4B("`@("`@("`@("!S96QE8W0](F1O8W5M96YT*"1M971A1FEL9552
M3"DB+SX*("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;V9F:6-E.G-T>6QE<RUF
M:6QE(B`@("`@("`@('-E;&5C=#TB9&]C=6UE;G0H)'-T>6QE<T9I;&554DPI
M(B\^"B`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]F9FEC93IF;VYT+61E8VQS
M(B`@("`@("`@("!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+69I;&4O*B]O9F9I
M8V4Z9F]N="UD96-L<R(O/@H@("`@/'AS;#IV87)I86)L92!N86UE/2)O9F9I
M8V4Z<W1Y;&5S(B`@("`@("`@("`@("`@<V5L96-T/2(D;V9F:6-E.G-T>6QE
M<RUF:6QE+RHO;V9F:6-E.G-T>6QE<R(O/@H@("`@/"$M+2!O9F9I8V4Z875T
M;VUA=&EC+7-T>6QE<R!M87D@;V-C=7)E(&EN('1W;R!D:69F97)E;G0@9FEL
M97,@*&DN9"X@8V]N=&5N="YX;6P@86YD('-T>6QE<RYX;6PI+B!&=7)T:&5R
M;6]R92!T:&4@=&]P(&QE=F5L('1A9R!I<R!D:69F97)E;G0@:6X@82!F;&%T
M('AM;"!F:6QE("TM/@H@("`@/'AS;#IV87)I86)L92!N86UE/2)O9F9I8V4Z
M875T;VUA=&EC+7-T>6QE<R(@("`@<V5L96-T/2(O*B]O9F9I8V4Z875T;VUA
M=&EC+7-T>6QE<R(O/@H*("`@(#PA+2T@<VEM<&QE(&1E8VQA<F%T:6]N(&]F
M(%=-3"!U<V5D('1O(&%V;VED('!A<G-E<B!E<G)O<G,@+2T^"B`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](G=A<"UP87)A9W)A<&@M96QE;65N=',M=VET:&]U
M="UT86)L92UR;W<B+SX*("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=V%P+7!A
M<F%G<F%P:"UE;&5M96YT<R(O/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W
M;6PM<F5P96%T+7=R:71E+7)O=R(O/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!B
M=6EL9"!T:&4@<')O<')I871E($A434P@9FEL92`J*BH@+2T^"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@
M("`@/'AS;#IT96UP;&%T92!M871C:#TB+R(^"@H@("`@("`@(#PA+2T\>'-L
M.FUE<W-A9V4^"@H*("`@("`@("!%;G1E<F5D('1H92!S='EL95-H965T<RP@
M=')A;G-F;W)M871I;VX@8F5G:6YS+BXN(#PO>'-L.FUE<W-A9V4^+2T^"@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)C:&5C:RUP87)A;65T97(B+SX*"B`@("`@("`@("`@
M("`@("`\>'-L.FEF('1E<W0](FYO="@D:7-*879A1&ES86)L960I(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9&5B
M=6<M<W1Y;&4M8V]L;&5C=&EN9RUT:6UE(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#II9CX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM('1O(&%C8V5S
M<R!T:&4@=F%R:6%B;&4@;&EK92!A(&YO9&4M<V5T(&ET(&ES(&YE8V5S<V%R
M>2!T;R!C;VYV97)T(&ET"B`@("`@("`@("`@("`@("`@("`@(&9R;VT@82!R
M97-U;'0M=')E92UF<F%G;65N="`H4E1&*2!T;R!A(&YO9&4@<V5T('5S:6YG
M('1H92!*86UE<R!#;&%R:R!E>'1E;G-I;VX@+2T^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TG8W)E871E+6%L;"UI;FQI;F4M<W1Y;&5S)R\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IV87)I86)L93X*"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-T87)T(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](GAT.FYO9&4M<V5T*"1C
M;VQL96-T961';&]B86Q$871A+5)41BDB+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G*2(^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)S=&%R="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2)X
M86QA;CIN;V1E<V5T*"1C;VQL96-T961';&]B86Q$871A+5)41BDB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB3F]D95-E=$9U;F-T:6]N3F]T079A:6QA8FQE
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)S=&%R="(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M<W1A<G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@
M4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB:'1M;"(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](FAE860B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S
M86=E/D-34R!H96QP97(@=F%R:6%B;&4@=VEL;"!B92!C<F5A=&5D+BXN+CPO
M>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=C;VUM;VXM:&5A9&5R+7!R;W!E
M<G1I97,G+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T
M/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#4U,@=F%R:6%B;&4@<F5A
M9'DL(&AE861E<B!W:6QL(&)E(&-R96%T960N+BXN/"]X<VPZ;65S<V%G93X\
M+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C;VYS=')U
M8W1I;F<@=&AE(&-S<R!H96%D97(@<VEM=6QA=&EN9R!I;FAE<FET86YC92!O
M9B!S='EL92UF86UI;&EE<R!B>2!S='EL92!O<F1E<B`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V-R96%T
M92UC<W,M<W1Y;&5H96%D97(G+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#4U,@
M:&5A9&5R(&-R96%T:6]N(&9I;FES:&5D(3PO>'-L.FUE<W-A9V4^/"]X<VPZ
M:68^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*"@H*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F)A8VMG<F]U
M;F1);6%G95523"(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O
M<W1Y;&4Z<&%G92UM87-T97(O<W1Y;&4Z<')O<&5R=&EE<R]S='EL93IB86-K
M9W)O=6YD+6EM86=E+T!X;&EN:SIH<F5F(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F)O9'DB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM(&)A8VMG<F]U;F0@:6UA9V4@+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&)A8VMG<F]U;F1);6%G9552
M3"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)B86-K9W)O=6YD(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!F;W(@:6UA9V5S(&IA<F5D(&EN(&]P96X@;V9F
M:6-E(&1O8W5M96YT("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)&)A8VMG<F]U;F1)
M;6%G95523"P@)R-0:6-T=7)E<R\G*2(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM(&-R96%T:6YG(&%N(&%B<V]L=71E
M(&AT='`@55),('1O('1H92!C;VYT86EN960O<&%C:V5D(&EM86=E(&9I;&4@
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1J87)E9%)O;W154DPL("<O
M4&EC='5R97,O)RP@<W5B<W1R:6YG+6%F=&5R*"1B86-K9W)O=6YD26UA9V55
M4DPL("<C4&EC='5R97,O)RDL("1O<'1I;VYA;%523%-U9F9I>"DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D8F%C:V=R;W5N9$EM86=E55),(B\^/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T
M<FEB=71E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<')O8V5S<VEN9R!T:&4@8V]N
M=&5N="!O9B!T:&4@>&UL(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O
M9'DB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(
M5$U,(#0N,"!)3DQ)3DE.1R`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB:'1M;"(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FAE860B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TG8V]M
M;6]N+6AE861E<BUP<F]P97)T:65S)R\^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)B86-K9W)O=6YD26UA9V554DPB('-E;&5C=#TB)&]F9FEC
M93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G!A9V4M;6%S=&5R+W-T>6QE.G!R
M;W!E<G1I97,O<W1Y;&4Z8F%C:V=R;W5N9"UI;6%G92]`>&QI;FLZ:')E9B(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B;V1Y
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!B86-K9W)O=6YD(&EM
M86=E("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(B1B86-K9W)O=6YD26UA9V554DPB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8F%C:V=R;W5N9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@9F]R(&EM86=E
M<R!J87)E9"!I;B!O<&5N(&]F9FEC92!D;V-U;65N="`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"1B86-K9W)O=6YD26UA9V554DPL("<C4&EC='5R97,O)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C
M<F5A=&EN9R!A;B!A8G-O;'5T92!H='1P(%523"!T;R!T:&4@8V]N=&%I;F5D
M+W!A8VME9"!I;6%G92!F:6QE("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A
M="@D:F%R9612;V]T55),+"`G+U!I8W1U<F5S+R<L('-U8G-T<FEN9RUA9G1E
M<B@D8F%C:V=R;W5N9$EM86=E55),+"`G(U!I8W1U<F5S+R<I+"`D;W!T:6]N
M86Q54DQ3=69F:7@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB<W)C
M(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&)A8VMG<F]U;F1);6%G95523"(O
M/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM
M=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$TM5DE)("@S
M+C(@2%1-3"!354)3150I("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@
M("`@/"$M+2!T:&4@<')O>'D@=VEL;"!C;VYV97)T('1H92!H=&UL(&9I;&4@
M;&%T97(@=&\@4%%!("TM/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](FAT;6PB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N
M="!N86UE/2)H96%D(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64])W!A;&TM:&5A9&5R+7!R;W!E<G1I97,G+SX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8F]D>2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@<')O8V5S<VEN9R!T:&4@8V]N=&5N="!O
M9B!T:&4@>&UL(&9I;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P
M;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L
M.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(96%D
M97(@9F]R($-34U])3DQ)3D5$(&%N9"!#4U-?2$5!1$52("HJ*B`M+3X*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG8V]M;6]N+6AE
M861E<BUP<F]P97)T:65S)SX*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E
M<R!S96QE8W0](B1O9F9I8V4Z;65T82UF:6QE+RHO;V9F:6-E.FUE=&$O9&,Z
M=&ET;&4B+SX*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE8W0]
M(B1O9F9I8V4Z;65T82UF:6QE+RHO;V9F:6-E.FUE=&$O9&,Z9&5S8W)I<'1I
M;VXB+SX*/"$M+3)$3R!A9&0@9G5R=&AE<B!H96%D97(@96QE;65N=',N+@H@
M("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB)&]F9FEC93IM
M971A+69I;&4O*B]O9F9I8V4Z;65T82]D8SIS=6)J96-T(B\^"B`@("`@("`@
M/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2(D;V9F:6-E.FUE=&$M9FEL
M92\J+V]F9FEC93IM971A+VUE=&$Z:V5Y=V]R9'-;<&]S=&ET:6]N*"D],5TB
M+SXM+3X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;6%T8V@](F1C.G1I=&QE(CX*("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M=&ET;&4B/@H@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O
M/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\+WAS;#IT96UP;&%T93X*
M"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)D8SID97-C<FEP=&EO;B(^"B`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#YD97-C<FEP=&EO;CPO>'-L.G1E>'0^"B`@("`@("`@("`@(#PO
M>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB8V]N=&5N="(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB+B(O/@H@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($UE87-U<FEN9R!T:&4@=&EM92!F;W(@
M<W1Y;&4@8W)E871I;F<@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB9&5B=6<M<W1Y;&4M8V]L;&5C=&EN9RUT:6UE
M(CX*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%1I;64M4E1&
M(CX*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>7-T96TZ8W5R
M<F5N="UT:6UE+6UI;&QI<R<I(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,H
M*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z
M:F%V82YL86YG+E-Y<W1E;2YC=7)R96YT5&EM94UI;&QI<R<I(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IJ879A
M+FQA;F<N4WES=&5M+F-U<G)E;G14:6UE36EL;&ES*"DB+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*
M("`@("`@("`\+WAS;#IV87)I86)L93X*"@H*("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$M4E1&(CX*("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64])V-R96%T92UA;&PM:6YL:6YE
M+7-T>6QE<R<O/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC
M=&EO;BUA=F%I;&%B;&4H)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IM97-S86=E/D-R96%T:6YG('1H92!I;FQI;F4@<W1Y;&5S+BXN
M+CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](G-T87)T5&EM92(@("`@("`@("`@("`@('-E;&5C=#TB;G5M8F5R
M*'AT.FYO9&4M<V5T*"1S=&%R=%1I;64M4E1&*2DB+SX*("`@("`@("`@("`@
M("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M("`@<V5L96-T/2)X=#IN;V1E+7-E="@D8V]L;&5C=&5D1VQO8F%L1&%T82U2
M5$8I(B\^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F5N
M9%1I;64B("`@("`@("`@("`@("`@('-E;&5C=#TB<WES=&5M.F-U<G)E;G0M
M=&EM92UM:6QL:7,H*2(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93Y4:6UE(&9O<B!I;G-T86YT:6%T:6YG('-T>6QE('9A<FEA8FQE.B`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB*"1E;F14:6UE("T@)'-T87)T5&EM92DB+SX@
M;7,\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](G-T87)T(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G
M>&%L86XZ;F]D97-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G
M93Y#<F5A=&EN9R!T:&4@:6YL:6YE('-T>6QE<RXN+BX\+WAS;#IM97-S86=E
M/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S=&%R=%1I
M;64B("`@("`@("`@("`@("!S96QE8W0](FYU;6)E<BAX86QA;CIN;V1E<V5T
M*"1S=&%R=%1I;64M4E1&*2DB+SX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB96YD5&EM92(@("`@("`@("`@("`@("`@<V5L96-T/2)J
M879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@
M("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B`@("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-O;&QE8W1E
M9$=L;V)A;$1A=&$M4E1&*2(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93Y4:6UE(&9O<B!I;G-T86YT:6%T:6YG('-T>6QE('9A<FEA8FQE.B`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB*"1E;F14:6UE("T@)'-T87)T5&EM92DB
M+SX@;7,\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G-T87)T(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@
M("`@/"$M+2!$14)51R!P=7)P;W-E(&]N;'DZ(&-H96-K:6YG('1H92!P87)A
M;65T97)S(&]F('1H:7,@=&5M<&QA=&4M+3X*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB8VAE8VLM<&%R86UE=&5R(CX*("`@("`@("`\>'-L.FUE<W-A9V4^
M4&%R86UE=&5R(&1P:3H@/'AS;#IV86QU92UO9B!S96QE8W0](B1D<&DB+SX\
M+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A;65T97(@
M;65T849I;&554DPZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;65T849I;&55
M4DPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ;65S<V%G93Y087)A
M;65T97(@<W1Y;&5S1FEL95523#H@/'AS;#IV86QU92UO9B!S96QE8W0](B1S
M='EL97-&:6QE55),(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`\>'-L.FUE
M<W-A9V4^4&%R86UE=&5R(&%B<V]L=71E4V]U<F-E1&ER4F5F.B`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&%B<V]L=71E4V]U<F-E1&ER4F5F(B\^/"]X<VPZ
M;65S<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E
M9&EN9T-H87!T97),979E;#$@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R
M96-E9&EN9T-H87!T97),979E;#$B+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M(#QX<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L
M,B`Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE
M=F5L,B(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A
M<F%M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PS(#H@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PS(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN
M9T-H87!T97),979E;#0@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E
M9&EN9T-H87!T97),979E;#0B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX
M<VPZ;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L-2`Z
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M-2(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M
M971E<B!P<F5C961I;F=#:&%P=&5R3&5V96PV(#H@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PV(B\^/"]X<VPZ;65S<V%G
M93X*("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H
M87!T97),979E;#<@.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN
M9T-H87!T97),979E;#<B+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#QX<VPZ
M;65S<V%G93Y087)A;65T97(@<')E8V5D:6YG0VAA<'1E<DQE=F5L."`Z(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L."(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@/'AS;#IM97-S86=E/E!A<F%M971E
M<B!P<F5C961I;F=#:&%P=&5R3&5V96PY(#H@/'AS;#IV86QU92UO9B!S96QE
M8W0](B1P<F5C961I;F=#:&%P=&5R3&5V96PY(B\^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`\>'-L.FUE<W-A9V4^4&%R86UE=&5R('!R96-E9&EN9T-H87!T
M97),979E;#$P.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!R96-E9&EN9T-H
M87!T97),979E;#$P(B\^/"]X<VPZ;65S<V%G93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)
M344O5FEE=V5R+V]O;R]P86QM+GAS;```````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#0Q-3,W(#$P-3$U-#,T,3,W(#`R,S8R-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\(2TM"@H@("!4:&4@0V]N=&5N
M=',@;V8@=&AI<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O
M('1H92!T97)M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E
M;G-E<PH*("`@("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,
M:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3
M=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-
M:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E
M<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#
M;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP
M,2!386X@06YT;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*
M"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E
M9&ES=')I8G5T92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T
M97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E
M;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F
M='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB
M=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B
M=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP
M;&EE9"!W87)R86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D53
M4R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,
M97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS
M+@H*("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I
M=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O
M9G1W87)E"B`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@
M4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@
M("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I
M;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A
M<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3
M;W5R8V4@3&EC96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO
M=2!M87D@;F]T('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N
M8V4@=VET:"!T:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F
M('1H90H@("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O
M;&EC96YS92YH=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI
M<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@
M(%=)5$A/550@5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3
M($]2($E-4$Q)140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].
M+"!705)204Y42453(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&
M14-44RP*("`@34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!0
M55)03U-%+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E
M(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R
M:6=H=',@86YD"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W
M87)E+@H*("`@5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA
M;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG
M:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@
M4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y
M;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX
M<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@
M("`@("`@("`@("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M=&5X="(*("`@("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS
M.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@
M("`@("`@("`@("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M.2]84TPO1F]R;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X
M;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S
M='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW
M,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@
M("`@("!X;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D
M<C-D(@H@("`@("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW
M,RYO<F<O,3DY."]-871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS
M.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@
M("`@("`@("`@("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+W-C<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB
M=&5X="(*("`@("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@
M("`@("`@("`@("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L
M96UE;G1S+S$N,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF
M:6<B"B`@("`@("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0]
M(FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM
M;&YS.G-Y<W1E;3TB:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V
M82YL86YG+E-Y<W1E;2(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H
M='1P.B\O>&UL+F%P86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X
M;6QN<SIJ879A/2)H='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@
M("`@("`@("`@("`@("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B
M/@H*("`@(#QX<VPZ;W5T<'5T(&-D871A+7-E8W1I;VXM96QE;65N=',](FUE
M=&$B+SX*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M("TM/@H@("`@/"$M+2`J*BH@<W!E8VEF:6,@<&%L;2!H96%D97(@*BHJ("TM
M/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG<&%L;2UH96%D97(M<')O<&5R=&EE
M<R<^"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@
M("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CY086QM0V]M<'5T:6YG
M4&QA=&9O<FT\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](F-O;G1E;G0B/G1R=64\+WAS;#IA='1R:6)U=&4^"B`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA
M;64B/DAA;F1H96QD1G)I96YD;'D\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;G1E;G0B/G1R=64\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FYA;64B/DAI<W1O<GE,:7-T5&5X=#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="(^
M1&%T96EM86YA9V5R)B,Q,#LZ("9A;7`[9&%T92`F86UP.W1I;64\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FYA;64B/F1E<V-R:7!T:6]N/"]X<VPZ871T<FEB=71E/@H@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;VYT96YT(CY3=&%R
M4&]R=&%L/"]X<VPZ871T<FEB=71E/@H@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](FUE=&$B/@H@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CYK97EW;W)D<SPO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N
M=&5N="(^<W1A<G!O<G1A;"P@<W1A<F]F9FEC92P@<V]F='=A<F4\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB;65T82(^"B`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FAT='`M97%U:78B/D-O;G1E;G0M5'EP93PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N
M="(^=&5X="]H=&UL.R!C:&%R<V5T/6ES;RTX.#4Y+3$\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E
M/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*B`M+3X*("`@(#PA+2T@*BHJ(&-R96%T:6YG('1A8FQE(&%T=')I8G5T97,@
M*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BH@+2T^"@H@("`@/"$M+2!T86)L92!D871A("AT9"D@86YD('1A8FQE
M(&AE861E<B`H=&@I(&%T=')I8G5T97,@+2T^"B`@("`\>'-L.G1E;7!L871E
M(&YA;64](F-R96%T92UA='1R:6)U=&4M04Q)1TXB/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ
M:68@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N)RDB
M/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)A;&EG;B(^"B`@
M("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L
M("=A;&EG;CIL969T)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^;&5F=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N.G)I9VAT)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^<FEG:'0\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YC96YT97(\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`\+WAS;#II9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA
M+2T@*BHJ(&-R96%T:6YG($QI<W0@871T<FEB=71E<R`@*BHJ("TM/@H@("`@
M/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"CPA
M+2T*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6QI<W0M871T<FEB
M=71E<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I
M97,B+SX*"@HA(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(0HR(&)E(&EM
M<&QE;65N=&5D"B$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A(2$A"@H*("`@
M(#PO>'-L.G1E;7!L871E/@HM+3X*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA
M+2T@*BHJ(&-R96%T:6YG(&YE<W1E9"!F;W)M870@=&%G<R`H4$%,32`F(%=-
M3"D@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/"$M+2!)=&%L:6,@
M+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UN97-T960M9F]R
M;6%T+71A9W,B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50
M<F]P97)T:65S(B\^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G
M:71A;&EC)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(FDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)B;VQD(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50
M<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE
M;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F)O;&0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O
M<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@
M0F]L9"`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8F]L9"(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B+SX*"B`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G8F]L9"<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=6YD97)L:6YE(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G5N9&5R
M;&EN92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P97)T:65S
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!5;F1E<FQI
M;F4@.B!L87-T(&9O<FUA="!A='1R:6)U=&4L('=H:6-H(&ES(&%L<V\@=7-E
M9"!F<F]M(%=-3"`M(%=-3"!E;F1S(&AE<F4A("TM/@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)U;F1E<FQI;F4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB<W1Y;&50<F]P97)T:65S(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G
M4$%,32<B/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R
M;W!E<G1I97,L("=U;F1E<FQI;F4G*2(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)U(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=')I:V5T:')O
M=6=H(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1S='EL
M95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H
M97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB<W1R:6ME=&AR;W5G:"(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&50<F]P97)T
M:65S(B!S96QE8W0](B1S='EL95!R;W!E<G1I97,B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G=6YD97)L:6YE)RDB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M=2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E
M;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA
M=&5S/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\(2TM('-T<FEK971H<F]U
M9V@@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](G-T<FEK971H<F]U9V@B
M/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T:65S
M(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)W-T<FEK92<I
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S=')I:V4B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A;&EG;B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O
M<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)A;&EG;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y;&50<F]P
M97)T:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!!
M;&EG;FUE;G0@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F%L:6=N(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(O
M/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=A;&EG;B<I(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)D:78B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F%L:6=N(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"1S='EL95!R;W!E<G1I97,L("=A;&EG;CIL969T)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YL969T/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N
M=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V%L:6=N.G)I9VAT)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/F-E;G1E<CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)F;VYT7V-O;6)I;F5D(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T
M/2(D<W1Y;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F9O;G1?8V]M8FEN960B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B
M('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M
M<&QA=&4^"@H*("`@(#PA+2T@0F]T:"!S:7IE(&%N9"!#;VQO<B!F;W(@9F]N
M="`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9F]N=%]C;VUB:6YE9"(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL95!R;W!E<G1I97,B
M+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)C;VYT86EN<R@D<W1Y;&50<F]P97)T:65S+"`G8V]L;W(G*2!A
M;F0@8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)W-I>F4G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB9F]N="(^"@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O;&]R(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S
M='EL95!R;W!E<G1I97,L("=C;VQO<CHC,#`P,#`P)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC,#`P,#`P/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^(T9&
M1D9&1CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S
M:7IE(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](G-U8G-T<FEN9RUA9G1E<BAS=6)S=')I;F<M8F5F;W)E*"1S='EL
M95!R;W!E<G1I97,@+"<Z<VEZ92<I+"`G<VEZ93HG*2(O/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*"B`@("`@("`@("`@("`@("`@
M("`@/"$M+2!G970@=&AE(&5M8F5D9&5D(&-O;G1E;G0@+2T^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9F]N=%]S:6UP;&4B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL
M95!R;W!E<G1I97,B('-E;&5C=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@<VEZ92!O<B!#;VQO<B!F
M;W(@9F]N="`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9F]N=%]S:6UP
M;&4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&50<F]P97)T
M:65S(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'-T>6QE4')O<&5R=&EE<RP@)V-O;&]R
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F9O;G0B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-O
M;&]R(CX*("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O
M;G1A:6YS*"1S='EL95!R;W!E<G1I97,L("=C;VQO<CHC,#`P,#`P)RDB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC,#`P
M,#`P/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G1E>'0^(T9&1D9&1CPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\(2TM(&=E="!T:&4@
M96UB961D960@8V]N=&5N="`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1S='EL95!R;W!E<G1I97,L
M("=S:7IE)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F9O;G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](G-I>F4B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*'-U8G-T<FEN9RUB969O<F4H
M)'-T>6QE4')O<&5R=&EE<R`L)SIS:7IE)RDL("=S:7IE.B<I(B\^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@
M("`@("`@("`\(2TM(&=E="!T:&4@96UB961D960@8V]N=&5N="`M+3X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"B`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@
M("`@("`@("`@("`\(2TM(&=E="!T:&4@96UB961D960@8V]N=&5N="`M+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H\+WAS;#IS='EL97-H965T/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92]-24U%+U9I97=E<B]O;V\O<W1Y;&5?;6%P<&EN9RYX<VP`````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#$Q,#0S,B`Q,#4Q-30S-#$S-R`P,C4U,S4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/"$M+0H*("`@
M5&AE($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@
M<W5B:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F;VQL
M;W=I;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N97)A
M;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3=6X@
M26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ
M"@H@("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*"B`@
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N
M,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@
M26YC+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y
M-#,P,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@
M>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I="!U
M;F1E<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L
M:6,*("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H
M92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A<GD@
M:7,@9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S
M969U;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V
M96X@=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,2519
M(&]R($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H
M92!'3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO
M<F4@9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O
M<'D@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS
M92!A;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T
M:&4@1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP
M;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P
M-R`@55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC
M96YS92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T
M:&ES(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N
M9&%R9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC
M96YS92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I
M;B!C;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T86EN
M(&$@8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P96YO
M9F9I8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D
M('5N9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@25,B
M(&)A<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(
M15(@15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/550@
M3$E-251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)4R!&
M4D5%($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!(%!!
M4E1)0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E92!T
M:&4@3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V97)N
M:6YG('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG
M('1H92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O9B!T
M:&4@3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*
M("`@0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC
M+@H*("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I
M.B!?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM
M/@H\>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N
M<V9O<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O
M<&5N;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@('AM
M;&YS.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL92(*
M("`@("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L93TB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@("`@
M("`@("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D
M<F%W:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM;&YS
M.GAL:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<](FAT
M='`Z+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@](FAT
M='`Z+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@("`@
M("`@("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F
M;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E
M;F]F9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O9F9I
M8V4Z8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R<VEO
M;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L
M+F]R9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M;65T83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@("`@
M("`@("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@("`@
M('AM;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X
M="]J879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@("`@("!X;6QN
M<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS
M;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R969I
M>&5S/2)J879A(CX*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)W<FET92US
M='EL92UP<F]P97)T:65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-T
M>6QE071T<FEB=71E4&%T:"(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@
M("`@("`@("`@/"$M+2LK*RLK($-34R!04D]015)42453("`K*RLK*RTM/@H@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-3
M7TA%041%4B<@;W(@)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*"B`@
M("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)'-T>6QE071T
M<FEB=71E4&%T:"(^"B`@("`@("`@("`@("`@("`\(2TM(&ES1&5B=6=-;V1E
M34534T%'13H*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^($YA
M;64Z/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H*2(O/B!686QU93H\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB+B(O/CPO>'-L.FUE<W-A9V4^("`@("`@+2T^
M"@H*("`@("`@("`@("`@("`@("`@("`\(2TM(#PA05143$E35"!S='EL93IP
M<F]P97)T:65S('-T>6QE.FAO<FEZ;VYT86PM<&]S("AF<F]M+6QE9G1\;&5F
M='QC96YT97)\<FEG:'1\9G)O;2UI;G-I9&5\:6YS:61E?&]U='-I9&4I(TE-
M4$Q)140^+2T^"B`@("`@("`@("`@("`@("`@("`@/"$M+2`R1$\Z(&ES(&EN
M<VED92]F<F]M+6EN<VED92!A;'-O(&)E='1E<B!S:&]W86)L92`_("TM/@H@
M("`@("`@("`@("`@("`@("`@(#PA+2T@(2$A(2`R1$\Z(%-T:6QL('1H97)E
M(&AA=F4@=&\@8F4@<&QA8V5D(&$@/&)R(&-L96%R/2=A;&PG+SX@=&\@9&ES
M86)L92!T:&4@9FQO=R$A(2$M+3X*("`@("`@("`@("`@("`@("`@("`\(2TM
M("`@("`@("`@("!4:&4@3T]O(&%T=')I8G5T92`G<W1Y;&4Z;G5M8F5R+7=R
M87!P960M<&%R86=R87!H<R<@:7,@8W5R<F5N=&QY(&EG;F]R960@+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S='EL93IW<F%P
M(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TG+CTB;&5F="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^9FQO870Z(')I9VAT.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX]
M(G)I9VAT(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YF;&]A=#H@;&5F=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD@/2`B<W1Y;&4Z:&]R:7IO;G1A
M;"UP;W,B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2<N/2)L969T(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YA;&EG;CH@;&5F=#L@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2<N/2)R:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G1E>'0^86QI9VXZ(')I9VAT.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])RX]
M(F-E;G1E<B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^86QI9VXZ(&-E;G1E<CL@/"]X<VPZ=&5X=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H\(2TM(')E<W5L=',@:6YT;R!A
M(&)A9"!V:65W("AO=F5R;&%P<&5D*2!I;B!-;WII;&QA(#$N,`H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*2`](")T
M86)L93IA;&EG;B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])RX](FQE9G0B)SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IT97AT/F9L;V%T.B!R:6=H=#L@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2<N/2)R:6=H="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^9FQO870Z(&QE9G0[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*+2T^"@H@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM(%!!1$1)3D<@9F]R(&%L;"!V87)I871I
M;VYS.B!F;SIP861D:6YG+"!F;SIP861D:6YG+71O<"P@9F\Z<&%D9&EN9RUB
M;W1T;VTL(&9O.G!A9&1I;F<M;&5F="P@9F\Z<&%D9&EN9RUR:6=H="`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])V-O;G1A
M:6YS*&YA;64H+BDL(F9O.G!A9&1I;F<B*2<^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^<&%D9&EN9SH@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW
M:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM"B`@("`@("`@("`@
M("`@("`@("`@("`@(&9O.F)O<F1E<@H@("`@("`@("`@("`@("`@("`@("`@
M("!F;SIB;W)D97(M=&]P"B`@("`@("`@("`@("`@("`@("`@("`@(&9O.F)O
M<F1E<BUB;W1T;VT*("`@("`@("`@("`@("`@("`@("`@("`@9F\Z8F]R9&5R
M+6QE9G0*("`@("`@("`@("`@("`@("`@("`@("`@9F\Z8F]R9&5R+7)I9VAT
M"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@070@<')E<V5N="P@86QL
M(&9O=7(@8F]R9&5R<R!M=7-T(&)E('-E="!S:6UU;'1A;F5O=7-L>2!B>2!U
M<VEN9R!E:71H97(*("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F
M;SIB;W)D97(@<')O<&5R='D@;W(@8GD@871T86-H:6YG(&%L;"!F;W5R(&]F
M('1H92!O=&AE<B!B;W)D97(*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('!R;W!E<G1I97,@=&\@86X@:71E;2!S970@96QE;65N="X@26X@=&AE(&QA
M='1E<B!C87-E+"!I9B!O;F4@;W(@;6]R90H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;V8@=&AE('!R;W!E<G1I97,@:7,@;6ES<VEN9R!T:&5I<B!V
M86QU97,@87)E(&%S<W5M960@=&\@8F4@;F]N92X@5&AE"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!O;FQY(&)O<F1E<B!S='EL97,@<W5P<&]R=&5D
M(&%R92!N;VYE(&]R(&AI9&1E;BP@<V]L:60L(&%N9"!D;W5B;&4N($%N>0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97(@8F]R9&5R('-T>6QE
M('-P96-I9FEE9"!I<R!D:7-P;&%Y960@87,@<V]L:60N(%1R86YS<&%R96YT
M(&)O<F1E<G,*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R92!N;W0@
M<W5P<&]R=&5D(&%N9"!T:&4@8F]R9&5R('=I9'1H<R!T:&EN+"!M961I=6TL
M(&%N9"!T:&EC:R!A<F4*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&UA
M<'!E9"!T;R!L96YG=&AS+B!);B!A9&1I=&EO;BP@;VYL>2!S;VUE(&1I<W1I
M;F-T(&)O<F1E<B!W:61T:',@87)E"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=7!P;W)T960N(%5N<W5P<&]R=&5D('=I9'1H<R!A<F4@<F]U;F1E
M9"!U<"!T;R!T:&4@;F5X="!S=7!P;W)T960*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('=I9'1H+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M268@=&AE<F4@87)E(&YO('!A9&1I;F<@<')O<&5R=&EE<R!S<&5C:69I960@
M=VET:&EN('1H92!S86UE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M=&5M('-E="!E;&5M96YT+"!A(&1E9F%U;'0@<&%D9&EN9R!I<R!U<V5D(&9O
M<B!S:61E<R!T:&%T(&AA=F4@80H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8F]R9&5R+B!!('9A;'5E(&]F(#!C;2!I<R!U<V5D(&9O<B!S:61E<R!W
M:71H;W5T(&$@8F]R9&5R+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*&-P+B!W9"US;RUX;6PM=&5X="YS9'<I"B`@("`@("`@("`@("`@("`@("`@
M("`@("TM/@H*/"$M+3)$3R!35$%25#H@8VAA;F=E(&UE87-U<F5M96YT(&5Q
M=6%L;'D@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2=N86UE*"XI/2)F;SIB;W)D97(B)SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@8VAA;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z
M(&EN8V@@=&\@:6X@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O<F1E
M<BUW:61T:#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S
M=')I;F<M8F5F;W)E*"XL)V-H("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F)O<F1E<BUS='EL93H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M8F5F;W)E*'-U8G-T<FEN9RUA9G1E<B@N+"=C:"`G
M*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L
M;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG
M+6%F=&5R*'-U8G-T<FEN9RUA9G1E<B@N+"=C:"`G*2P@)R`G*2(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-M)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R
M9&5R+7=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUB969O<F4H+BPG("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F)O<F1E<BUS='EL93H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M8F5F;W)E*'-U8G-T<FEN9RUA9G1E<B@N+"=C;2`G
M*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L
M;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG
M+6%F=&5R*'-U8G-T<FEN9RUA9G1E<B@N+"=C;2`G*2P@)R`G*2(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)W!T)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R
M9&5R+7=I9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U
M8G-T<FEN9RUB969O<F4H+BPG("<I(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/F)O<F1E<BUS='EL93H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M8F5F;W)E*'-U8G-T<FEN9RUA9G1E<B@N+"=P="`G
M*2P@)R`G*2(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M8V]L
M;W(Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG
M+6%F=&5R*'-U8G-T<FEN9RUA9G1E<B@N+"=P="`G*2P@)R`G*2(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M)VYA;64H+BD](F9O.F)O<F1E<BUT;W`B)SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YB;W)D97(M=&]P.B`\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O
M.F)O<F1E<BUB;W1T;VTB)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=&5X=#YB;W)D97(M8F]T=&]M.B`\+WAS;#IT97AT/CQX<VPZ=F%L
M=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F)O<F1E
M<BUL969T(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^8F]R9&5R+6QE9G0Z(#PO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z8F]R9&5R+7)I9VAT(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^8F]R9&5R
M+7)I9VAT.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^
M/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0])VYA;64H+BD](G-T>6QE.F-O;'5M;BUW:61T:"(G/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES
M=&%N8V4@;65A<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@
M)V-H)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB<W5B<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS;#IT97AT/CL@/"]X
M<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z<F]W+6AE:6=H
M="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN
M9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N
M=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^:&5I9VAT.CPO>'-L.G1E>'0^/'AS;#IV86QU
M92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H+BPG8V@G*2(O/CQX<VPZ
M=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/FAE:6=H=#H\+WAS;#IT97AT/CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIW
M:61T:"(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C:&%N
M9VEN9R!T:&4@9&ES=&%N8V4@;65A<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H+BP@)V-H)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H\(2TM,D1/
M($5.1#H@8VAA;F=E(&UE87-U<F5M96YT(&5Q=6%L;'D@+2T^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF
M;VYT+7-T>6QE(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z
M)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE
M8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z9F]N="UN86UE(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^9F]N="UF
M86UI;'DZ/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-O;G1E;G0B('-E;&5C=#TB+B(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(D;V9F:6-E.F9O;G0M9&5C;',O<W1Y;&4Z9F]N="UD96-L
M6T!S='EL93IN86UE/21C;VYT96YT72]`9F\Z9F]N="UF86UI;'DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X[(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(F-O;G1A:6YS*"1O9F9I8V4Z9F]N="UD96-L<R]S='EL93IF;VYT+61E8VQ;
M0'-T>6QE.FYA;64])&-O;G1E;G1=+T!S='EL93IF;VYT+7-T>6QE+6YA;64L
M("=)=&%L:6,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/F9O;G0M<W1Y;&4Z:71A;&EC.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](F-O;G1A:6YS*"1O9F9I
M8V4Z9F]N="UD96-L<R]S='EL93IF;VYT+61E8VQ;0'-T>6QE.FYA;64])&-O
M;G1E;G1=+T!S='EL93IF;VYT+7-T>6QE+6YA;64L("=";VQD)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YF;VYT+7=E
M:6=H=#IB;VQD.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2=N86UE*"XI/2)F;SIF;VYT+7=E:6=H="(G/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA
M9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O
M.F9O;G0M<VEZ92(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G
M.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.F9O;G0M9F%M:6QY(B<^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA;64H+BDL("<Z)RDB+SX\>'-L.G1E
M>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L
M.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TG;F%M92@N*3TB9F\Z8V]L;W(B)SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T
M97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIM
M87)G:6XM;&5F="(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G
M.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.FUA<F=I;BUR:6=H="(G
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT
M97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS
M;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])VYA;64H+BD](F9O.FUA<F=I;BUT;W`B)SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S=6)S=')I
M;F<M869T97(H;F%M92@N*2P@)SHG*2(O/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI
M/2)F;SIM87)G:6XM8F]T=&]M(B<^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<W5B<W1R:6YG+6%F=&5R*&YA
M;64H+BDL("<Z)RDB+SX\>'-L.G1E>'0^.CPO>'-L.G1E>'0^/'AS;#IV86QU
M92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB9F\Z;&EN92UH
M96EG:'0B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)S=6)S=')I;F<M869T97(H;F%M92@N*2P@)SHG*2(O
M/CQX<VPZ=&5X=#XZ/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M+B(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIT97AT+6%L:6=N(B<^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM($E-4$]25$%.5"!I<R!N96-E
M<W-A<GD@87,@=&%B;&4@8V5L;"!V86QU92!A;&EG;FUE;G0@:7,@9&5C:61E
M9"!B>2!R=6YT:6UE(&]V97(@=&AE('9A;'5E='EP90H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!/=&AE<G=I<V4@82!T86)L92!C96QL('-T
M>6QE+6-L87-S('=I;&P@04Q705E3(&)E(&]V97)W<FET=&5N(&)Y('1H92!R
M=6XM=&EM92!V86QU92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)W-T87)T)RDB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^=&5X
M="UA;&EG;CIL969T("$@:6UP;W)T86YT.R`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"XL("=E;F0G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YT97AT+6%L:6=N.G)I9VAT("$@:6UP;W)T86YT
M.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YT97AT+6%L:6=N.CPO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0])RXG+SX\>'-L.G1E>'0^("$@:6UP;W)T86YT.R`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N
M86UE*"XI/2)F;SIT97AT+6EN9&5N="(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E
M<BAN86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ
M=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE
M.G1E>'0M8F%C:V=R;W5N9"UC;VQO<B(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IT97AT/F)A8VMG<F]U;F0M8V]L;W(Z/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#X[(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI
M/2)F;SIB86-K9W)O=6YD+6-O;&]R(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^8F%C:V=R;W5N9"UC;VQO<CH\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD]
M(G-T>6QE.F)A8VMG<F]U;F0M:6UA9V4B)SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YB86-K9W)O=6YD+6EM86=E.G5R;"@\+WAS
M;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/CQX
M<VPZ=&5X=#XI.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IR97!E870@/2`G<F5P96%T
M)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=&5X=#YB86-K9W)O=6YD+7)E<&5A=#IR97!E870[(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/F)A8VMG<F]U;F0M<F5P96%T.FYO+7)E<&5A=#L@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@=&5X="US:&%D;W<@:7,@82!#4U,R(&9E871U
M<F4@86YD('EE="!N;W0@8V]M;6]N('5S960@:6X@=7-E<BUA9V5N=',@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE
M*"XI/2)F;SIT97AT+7-H861O=R(G/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUA9G1E<BAN
M86UE*"XI+"`G.B<I(B\^/'AS;#IT97AT/CH\+WAS;#IT97AT/CQX<VPZ=F%L
M=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/CL@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G1E
M>'0M8W)O<W-I;F<M;W5T(B<^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.FEF('1E<W0])VYO="@N/2)N;VYE(BDG/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YT97AT+61E8V]R871I;VXZ
M;&EN92UT:')O=6=H.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2=N86UE*"XI/2)S='EL93IT97AT+75N9&5R;&EN92(G/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2=N;W0H+CTB;F]N
M92(I)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^=&5X="UD96-O<F%T:6]N.G5N9&5R;&EN93L@/"]X<VPZ=&5X=#X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB<W1Y;&4Z=&5X="UP;W-I
M=&EO;B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T
M97-T/2=C;VYT86EN<R@N+"`B<W5B(BDG/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#YV97)T:6-A;"UA;&EG;CIS=6([(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II
M9CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TG
M8V]N=&%I;G,H+BP@(G-U<"(I)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^=F5R=&EC86PM86QI9VXZ<W5P.R`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PA+2T@:7-$96)U9TUO9&5-15-304=%.@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^3F\@=')A;G-F;W)M
M871I;VX@:6UP;&5M96YT960@9F]R(&%T=')I8G5T92UT>7`@/'AS;#IV86QU
M92UO9B!S96QE8W0](FYA;64H+BDB+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^+2T^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ9F]R+65A8V@^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@
M("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@04Y$(%=!4"!04D]015)4
M2453("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D<W1Y;&5!='1R
M:6)U=&50871H(CX*("`@("`@("`@("`@("`@("`@("`\(2TM(&ES1&5B=6=-
M;V1E34534T%'13H*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M($YA;64Z/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H*2(O/B!686QU93H\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB+B(O/CPO>'-L.FUE<W-A9V4^("`@("`@
M+2T^"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@0E5'(%=/4DL@05)/54Y$
M.@H@("`@("`@("`@("`@("`@("`@($1U92!T;R!A(&)U9R!I;B!T:&4@6%0@
M4')O8V5S<V]R+"!I="!I<R!N;W0@<&]S<VEB;&4@=&\@8W)E871E('-E<G9E
M<F%L(&5L96UE;G1S(&EN('9A<FEA8FQE(&%N9"!S96%R8V@@;W9E<B!T:&5M
M+`H@("`@("`@("`@("`@("`@("`@(&%F=&5R(&5X<&QI8VET(&-O;G9E<G-I
M;VX@=&\@;F]D97-E=`H@("`@("`@("`@("`@("`@("`@(%1H:7,@9V5N97)A
M=&5D('-T:6YG(&ED96YT:69I97(@<VAA;&P@8F4@;&%T97(@8VAA;F=E9"!B
M86-K('1O(&$@<V5T(&]F(&5L96UE;G1S"B`@("`@("`@("`@("`@("`@("`@
M+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2TJ*BH@1D]234%4($%45%))0E5415,@*BHJ
M+2T^"@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM($ET86QI8R`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H
M+BD](F9O.F9O;G0M<W1Y;&4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB8V]N=&%I;G,H+BP@)VET86QI8R<I(&]R(&-O
M;G1A:6YS*"XL("=O8FQI<75E)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YI=&%L:6,L(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@0F]L9&9A8V4@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT+7=E:6=H="(G/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2)C;VYT
M86EN<R@N+"`G8F]L9"<I(&]R(&-O;G1A:6YS*"XL("=B;VQD97(G*2(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F)O;&0L
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#II9CX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@56YD97)L:6YE("TM/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TG;F%M92@N*3TB
M<W1Y;&4Z=&5X="UU;F1E<FQI;F4B)SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YU;F1E<FQI;F4L(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`@
M("`@("`@("`@("`\(2TM($%L:6=N;65N="`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])VYA;64H+BD](F9O.G1E>'0M86QI
M9VXB)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB8V]N=&%I;G,H+BP@)W-T87)T)RDB/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ;&5F="P@/"]X
M<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<R@N+"`G96YD)RDB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^86QI9VXZ<FEG:'0L
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@)V-E;G1E<B<I(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L:6=N
M.F-E;G1E<BP@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<W1R:6ME
M=&AR;W5G:"`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0])VYA;64H+BD](G-T>6QE.G1E>'0M8W)O<W-I;F<M;W5T(B<^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^<W1R:6ME+"`\
M+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H*("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!&;VYT("T@<VEZ92`H
M4&%L;3H@96UU;&%T;W(@=')A;G-F;W)M960@<VEZ97,@=&\@879A:6QA8FQE
M('-E="`H92YG+B`S,"!T;R`H<')O8F%B;'DI(#DI+2T^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)F;SIF;VYT
M+7-I>F4B)SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#YS:7IE.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\
M>'-L.G1E>'0^.G-I>F4L(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM($9O;G0@+2!#;VQO<B`H4$%,33H@8G5T(&UO<W1L>2!O;FQY(#(@879A
M:6QA8FQE*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8FQA8VL@*",P
M,#`P,#`I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!G<F%Y("@C.#`X
M,#@P*2AR96YD97)E9"!A<R!D87)K(&=R87DI"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S:6QV97(@*"-#,$,P0S`I*')E;F1E<F5D(&%S(&QI9VAT
M(&=R87DI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!W:&ET92`H(T9&
M1D9&1BDM+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E
M<W0])VYA;64H+BD](F9O.F-O;&]R(B<^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+B`L("<C1D9&1D9&
M)RD@;W(@8V]N=&%I;G,H+B`L("<C9F9F9F9F)RD@;W(@8V]N=&%I;G,H+B`L
M("=W:&ET92<I(&]R(&-O;G1A:6YS*"X@+"`G5TA)5$4G*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YC;VQO<CHC
M1D9&1D9&+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#YC;VQO<CHC,#`P,#`P+"`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"@H@
M("`@("`@("`@("`@("`@("`@("`@("`\(2TM*BHJ(%1!0DQ%($%45%))0E54
M15,@*BHJ+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2=N86UE*"XI/2)F;SIF;VYT+7-I>F4B)SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#YS:7IE.CPO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.G-I>F4L(#PO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI/2)S
M='EL93IC;VQU;6XM=VED=&@B)SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@8VAA;F=I;F<@=&AE(&1I<W1A;F-E(&UE87-U<F4Z(&EN8V@@
M=&\@:6X@+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL("=C:"<I(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.CPO>'-L
M.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](G-U8G-T<FEN9RUB969O<F4H
M+BPG8V@G*2(O/CQX<VPZ=&5X=#XZ=VED=&@L(#PO>'-L.G1E>'0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I
M9'1H.CPO>'-L.G1E>'0^/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L
M.G1E>'0^.G=I9'1H.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0])VYA;64H+BD](G-T>6QE.G)O=RUH96EG:'0B)SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@8VAA;F=I;F<@=&AE(&1I
M<W1A;F-E(&UE87-U<F4Z(&EN8V@@=&\@:6X@+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"XL
M("=C:"<I(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/FAE:6=H=#H\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L
M96-T/2)S=6)S=')I;F<M8F5F;W)E*"XL)V-H)RDB+SX\>'-L.G1E>'0^.FAE
M:6=H=#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^:&5I9VAT.CPO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^.FAE:6=H=#L@/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2=N86UE*"XI
M/2)S='EL93IW:61T:"(G/B`\(2TM96%R;&EE<B!F;SIW:61T:"TM/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"$M+2!C:&%N9VEN9R!T:&4@9&ES
M=&%N8V4@;65A<W5R93H@:6YC:"!T;R!I;B`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H+BP@
M)V-H)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB<W5B<W1R:6YG+6)E9F]R92@N+"=C:"<I(B\^/'AS;#IT97AT/CIW:61T
M:#L@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^=VED=&@Z/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB+B(O/CQX<VPZ=&5X=#XZ=VED=&@[(#PO>'-L.G1E>'0^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#PO
M>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"CPA
M+2T@,D1/.B!.04U)3D<@0T].5D5.5$E/3B!V87)I86)L92!A<F4@=W)I='1E
M;B!W:71H("<M)R!I;G-T96%D(&]F(&-A<V4M<V5N<VET:79E('=R:71I;F<@
M+2T^"@H*"B`@("`\(2TM("HJ*BHJ($U%05-54D5-14Y4($-/3E9%4E-)3TY3
M("HJ*BHJ"@H@("`@("H@,2!C96YT:6UE=&5R(#T@,3`@;6T*"B`@("`@*B`Q
M(&EN8V@@/2`R-2XT(&UM"B`@("`@("`@5VAI;&4@=&AE($5N9VQI<V@@:&%V
M92!A;')E861Y('-E96X@=&AE(&QI9VAT("AR96%D.B!T:&4@;65T<FEC('-Y
M<W1E;2DL('1H92!54PH@("`@("`@(')E;6%I;G,@;&]Y86P@=&\@=&AI<R!M
M961I979A;"!S>7-T96TN"@H@("`@("H@,2!D:61O="!P;VEN="`](#`N,S<V
M,#8U(&UM"B`@("`@("`@("`@(%1H92!D:61O="!S>7-T96T@;W)I9VEN871E
M9"!I;B!&<F%N8V4@8G5T('=A<R!U<V5D(&EN(&UO<W0@;V8@175R;W!E"@H@
M("`@("H@,2!P:6-A('!O:6YT(#T@,"XS-3$T-B!M;0H@("`@("`@("`@("!4
M:&4@4&EC82!P;VEN=',@<WES=&5M('=A<R!D979E;&]P960@:6X@16YG;&%N
M9"!A;F0@:7,@=7-E9"!I;B!'<F5A="U"<FET86EN(&%N9"!T:&4@55,N"@H@
M("`@("H@,2!0;W-T4V-R:7!T('!O:6YT(#T@,"XS-3(W-S$S."!M;0H@("`@
M("`@("`@("!7:&5N($%D;V)E(&-R96%T960@4&]S=%-C<FEP="P@=&AE>2!A
M9&1E9"!T:&5I<B!O=VX@<WES=&5M(&]F('!O:6YT<RX*("`@("`@("`@("`@
M5&AE<F4@87)E(&5X86-T;'D@-S(@4&]S=%-C<FEP="!P;VEN=',@:6X@,2!I
M;F-H+@H*("`@("`J(#$@<&EX96P@/2`P+C(V-#4X,S,S+BX@;6T@("`H8GD@
M.38@9'!I*0H@("`@("`@("`@("!-;W-T('!I8W1U<F5S(&AA=F4@=&AE(#DV
M(&1P:2!R97-O;'5T:6]N+"!B=70@=&AE(&1P:2!V87)I86)L92!M87D@=F%R
M>2!B>2!S='EL97-H965T('!A<F%M971E<@H@("`@+2T^"@H*("`@(#PA+2T@
M8VAA;F=I;F<@;65A<W5R92!T;R!M;2`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TB8V]N=F5R=#)M;2(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)V
M86QU92(O/@H*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-E;G1I;65T97(M
M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,3`B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](FEN8V@M:6XM;6TB("`@("`@("`@("`@("`@('-E;&5C=#TB
M,C4N-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M
M:6XM;6TB("`@("`@("`@<V5L96-T/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<&EC82UP;VEN="UI;BUM;2(@("`@("`@("`@<V5L
M96-T/2(P+C,U,30V(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G8VTG*2(^
M"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H
M;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"=C;2<@*2D@*B`D8V5N
M=&EM971E<BUI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)VEN
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O
M=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG:6XG("DI("H@
M)&EN8V@M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=D<'0G
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U
M;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"=D<'0G*2D@*B`D
M9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L
M("=P<'0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"=P<'0G
M*2D@*B`D<&EC82UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!C:&%N9VEN9R!M96%S=7)E
M('1O(&-M("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C;VYV97)T,F-M
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G9A;'5E(B\^"@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V5N=&EM971E<BUI;BUM;2(@("`@("`@("`@
M<V5L96-T/2(Q,"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI
M;BUM;2(@("`@("`@("`@("`@("`@<V5L96-T/2(R-2XT(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)D:61O="UP;VEN="UI;BUM;2(@("`@("`@("!S
M96QE8W0](C`N,S<V,#8U(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M:6-A+7!O:6YT+6EN+6UM(B`@("`@("`@("!S96QE8W0](C`N,S4Q-#8B+SX*
M"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)C;VYT86EN<R@D=F%L=64L("=M;2<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG
M+6)E9F]R92@D=F%L=64L("=M;2<I*2!D:78@)&-E;G1I;65T97(M:6XM;6TI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=I;B<I(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B
M<W1R:6YG+6)E9F]R92@D=F%L=64L("=I;B<I*2!D:78@)&-E;G1I;65T97(M
M:6XM;6T@*B`D:6YC:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU
M92P@)V1P="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P
M="<I*2!D:78@)&-E;G1I;65T97(M:6XM;6T@*B`D9&ED;W0M<&]I;G0M:6XM
M;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=P<'0G*2(^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R
M*'-U8G-T<FEN9RUB969O<F4H)'9A;'5E+"=P<'0G*2D@9&EV("1C96YT:6UE
M=&5R+6EN+6UM("H@)'!I8V$M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1V86QU92(O/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/"$M+2!C:&%N9VEN9R!M
M96%S=7)E('1O(&EN8V@@*&-P+B!S96-T:6]N(&-O;6UE;G0I("TM/@H@("`@
M/'AS;#IT96UP;&%T92!N86UE/2)C;VYV97)T,FEN8V@B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB=F%L=64B+SX*"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C96YT:6UE=&5R+6EN+6UM(B`@("`@("`@("!S96QE8W0](C$P(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)I;F-H+6EN+6UM(B`@("`@("`@
M("`@("`@("!S96QE8W0](C(U+C0B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F1I9&]T+7!O:6YT+6EN+6UM(B`@("`@("`@('-E;&5C=#TB,"XS-S8P
M-C4B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!I8V$M<&]I;G0M:6XM
M;6TB("`@("`@("`@('-E;&5C=#TB,"XS-3$T-B(O/@H*("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"1V86QU92P@)VUM)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU
M92P@)VUM)RDI(&1I=B`D:6YC:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS
M*"1V86QU92P@)V-M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU
M92P@)V-M)RDI(&1I=B`D:6YC:"UI;BUM;2`J("1C96YT:6UE=&5R+6EN+6UM
M*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G9'!T)RDB/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS
M=6)S=')I;F<M8F5F;W)E*"1V86QU92PG9'!T)RDI(&1I=B`D:6YC:"UI;BUM
M;2`J("1D:61O="UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V
M86QU92P@)W!P="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L
M)W!P="<I*2!D:78@)&EN8V@M:6XM;6T@*B`D<&EC82UP;VEN="UI;BUM;2DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)'9A;'5E(B\^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@
M/"$M+2!C:&%N9VEN9R!M96%S=7)E('1O(&1P="`H8W`N('-E8W1I;VX@8V]M
M;65N="D@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-O;G9E<G0R9'!T
M(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G9A;'5E(B\^"@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V5N=&EM971E<BUI;BUM;2(@("`@("`@("`@
M<V5L96-T/2(Q,"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB:6YC:"UI
M;BUM;2(@("`@("`@("`@("`@("`@<V5L96-T/2(R-2XT(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)D:61O="UP;VEN="UI;BUM;2(@("`@("`@("!S
M96QE8W0](C`N,S<V,#8U(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M:6-A+7!O:6YT+6EN+6UM(B`@("`@("`@("!S96QE8W0](C`N,S4Q-#8B+SX*
M"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)C;VYT86EN<R@D=F%L=64L("=M;2<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG
M+6)E9F]R92@D=F%L=64L("=M;2<I*2!D:78@)&1I9&]T+7!O:6YT+6EN+6UM
M*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G8VTG*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)'9A;'5E+"`G8VTG*2D@9&EV("1D:61O="UP;VEN
M="UI;BUM;2`J("1C96YT:6UE=&5R+6EN+6UM*2(O/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'9A;'5E+"`G:6XG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"`G:6XG*2D@9&EV("1D:61O="UP;VEN="UI;BUM;2`J("1I;F-H+6EN
M+6UM*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'9A;'5E+"`G<'!T)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E
M<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92PG<'!T)RDI(&1I=B`D9&ED;W0M
M<&]I;G0M:6XM;6T@*B`D<&EC82UP;VEN="UI;BUM;2DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'9A;'5E(B\^
M"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC
M:&]O<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@8VAA;F=I
M;F<@;65A<W5R92!T;R!P<'0@*&-P+B!S96-T:6]N(&-O;6UE;G0I("TM/@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)C;VYV97)T,G!P="(^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)V86QU92(O/@H*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-E;G1I;65T97(M:6XM;6TB("`@("`@("`@('-E;&5C=#TB,3`B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FEN8V@M:6XM;6TB("`@("`@
M("`@("`@("`@('-E;&5C=#TB,C4N-"(O/@H@("`@("`@(#QX<VPZ<&%R86T@
M;F%M93TB9&ED;W0M<&]I;G0M:6XM;6TB("`@("`@("`@<V5L96-T/2(P+C,W
M-C`V-2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&EC82UP;VEN="UI
M;BUM;2(@("`@("`@("`@<V5L96-T/2(P+C,U,30V(B\^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'9A;'5E+"`G;6TG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"`G;6TG*2D@9&EV("1P:6-A+7!O:6YT+6EN+6UM*2(O/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H)'9A;'5E+"`G8VTG*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O
M<F4H)'9A;'5E+"`G8VTG*2D@9&EV("1P:6-A+7!O:6YT+6EN+6UM("H@)&-E
M;G1I;65T97(M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D=F%L=64L("=I
M;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)R
M;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L("=I;B<I*2!D
M:78@)'!I8V$M<&]I;G0M:6XM;6T@*B`D:6YC:"UI;BUM;2DB+SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F-O;G1A:6YS*"1V86QU92P@)V1P="<I(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E
M9F]R92@D=F%L=64L)V1P="<I*2!D:78@)'!I8V$M<&]I;G0M:6XM;6T@*B`D
M9&ED;W0M<&]I;G0M:6XM;6TI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](B1V86QU92(O/@H@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@8VAA;F=I;F<@;65A<W5R92!T;R!P
M:7AE;"!B>2!V:6$@<&%R86UE=&5R('!R;W9I9&5D(&1P:2`H9&]T<R!P97(@
M:6YC:"D@<W1A;F1A<F0@9F%C=&]R("AC<"X@<V5C=&EO;B!C;VUM96YT*2`M
M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)P:7AE;"(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)V86QU92(O/@H*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-E;G1I;65T97(M:6XM;6TB("`@("`@("`@('-E;&5C
M=#TB,3`B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FEN8V@M:6XM;6TB
M("`@("`@("`@("`@("`@('-E;&5C=#TB,C4N-"(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB9&ED;W0M<&]I;G0M:6XM;6TB("`@("`@("`@<V5L96-T
M/2(P+C,W-C`V-2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&EC82UP
M;VEN="UI;BUM;2(@("`@("`@("`@<V5L96-T/2(P+C,U,30V(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)P:7AE;"UI;BUM;2(@("`@("`@("`@("`@
M("!S96QE8W0](B1I;F-H+6EN+6UM(&1I=B`D9'!I(B\^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I
M;G,H)'9A;'5E+"`G;6TG*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB<F]U;F0H;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H)'9A
M;'5E+"`G;6TG*2D@9&EV("1P:7AE;"UI;BUM;2DB+SX*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A
M:6YS*"1V86QU92P@)V-M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](G)O=6YD*&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1V
M86QU92P@)V-M)RDI(&1I=B`D<&EX96PM:6XM;6T@*B`D8V5N=&EM971E<BUI
M;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU92P@)VEN)RDB/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G)O=6YD*&YU;6)E
M<BAS=6)S=')I;F<M8F5F;W)E*"1V86QU92P@)VEN)RDI(&1I=B`D<&EX96PM
M:6XM;6T@*B`D:6YC:"UI;BUM;2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1V86QU
M92P@)V1P="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)R;W5N9"AN=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=F%L=64L)V1P
M="<I*2!D:78@)'!I>&5L+6EN+6UM("H@)&1I9&]T+7!O:6YT+6EN+6UM*2(O
M/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2(D=F%L=64B+SX*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ
M<W1Y;&5S:&5E=#X*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O34E-12]6:65W97(O;V]O+V=L;V)A;%]D;V-U;65N="YX<VP`````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`R-3(U,S<@,3`U,34T,S0Q,S<@,#(V,#,U`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"`\(2TM"@H@("!4
M:&4@0V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!M861E(&%V86EL86)L92!S
M=6)J96-T('1O('1H92!T97)M<R!O9@H@("!E:71H97(@;V8@=&AE(&9O;&QO
M=VEN9R!L:6-E;G-E<PH*("`@("`@("`@("T@1TY5($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@("`@("`@("`M(%-U;B!)
M;F1U<W1R>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*
M"B`@(%-U;B!-:6-R;W-Y<W1E;7,@26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ
M"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H@("!#;W!Y<FEG:'0@,C`P,"!B>2!3=6X@36EC<F]S>7-T96US+"!)
M;F,N"B`@(#DP,2!386X@06YT;VYI;R!2;V%D+"!086QO($%L=&\L($-!(#DT
M,S`S+"!54T$*"B`@(%1H:7,@;&EB<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y
M;W4@8V%N(')E9&ES=')I8G5T92!I="!A;F0O;W(*("`@;6]D:69Y(&ET('5N
M9&5R('1H92!T97)M<R!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI
M8PH@("!,:6-E;G-E('9E<G-I;VX@,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE
M($9R964@4V]F='=A<F4@1F]U;F1A=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I
M<R!D:7-T<FEB=71E9"!I;B!T:&4@:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E
M9G5L+`H@("!B=70@5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E
M;B!T:&4@:6UP;&EE9"!W87)R86YT>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@
M;W(@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4N("!3964@=&AE
M($=.50H@("!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R
M92!D971A:6QS+@H*("`@66]U('-H;W5L9"!H879E(')E8V5I=F5D(&$@8V]P
M>2!O9B!T:&4@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E
M(&%L;VYG('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H
M92!&<F5E(%-O9G1W87)E"B`@($9O=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L
M92!0;&%C92P@4W5I=&4@,S,P+"!";W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W
M("!54T$*"@H@("!3=6X@26YD=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E
M;G-E(%9E<G-I;VX@,2XQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H
M:7,@9FEL92!A<F4@<W5B:F5C="!T;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD
M87)D<PH@("!3;W5R8V4@3&EC96YS92!697)S:6]N(#$N,2`H=&AE("),:6-E
M;G-E(BD[(%EO=2!M87D@;F]T('5S92!T:&ES(&9I;&4*("`@97AC97!T(&EN
M(&-O;7!L:6%N8V4@=VET:"!T:&4@3&EC96YS92X@66]U(&UA>2!O8G1A:6X@
M82!C;W!Y(&]F('1H90H@("!,:6-E;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F
M9FEC92YO<F<O;&EC96YS92YH=&UL+@H*("`@4V]F='=A<F4@<')O=FED960@
M=6YD97(@=&AI<R!,:6-E;G-E(&ES('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@
M8F%S:7,L"B`@(%=)5$A/550@5T%24D%.5%D@3T8@04Y9($M)3D0L($5)5$A%
M4B!%6%!215-3($]2($E-4$Q)140L($E.0TQ51$E.1RP*("`@5TE42$]55"!,
M24U)5$%424].+"!705)204Y42453(%1(050@5$A%(%-/1E1705)%($E3($92
M144@3T8@1$5&14-44RP*("`@34520TA!3E1!0DQ%+"!&250@1D]2($$@4$%2
M5$E#54Q!4B!055)03U-%+"!/4B!.3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H
M92!,:6-E;G-E(&9O<B!T:&4@<W!E8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI
M;F<@>6]U<B!R:6=H=',@86YD"B`@(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@
M=&AE(%-O9G1W87)E+@H*("`@5&AE($EN:71I86P@1&5V96QO<&5R(&]F('1H
M92!/<FEG:6YA;"!#;V1E(&ES.B!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@
M("!#;W!Y<FEG:'0@PJD@,C`P,B!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N
M"@H@("!!;&P@4FEG:'1S(%)E<V5R=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ
M(%]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^
M"CQX<VPZ<W1Y;&5S:&5E="!V97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@
M("!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS
M9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O;V9F:6-E(@H@("`@("`@("`@("`@("`@>&UL
M;G,Z<W1Y;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O=&5X="(*("`@("`@("`@("`@("`@('AM;&YS.G1A8FQE/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T86)L92(*("`@("`@("`@("`@
M("`@('AM;&YS.F1R87<](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R
M87=I;F<B"B`@("`@("`@("`@("`@("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW
M,RYO<F<O,3DY.2]84TPO1F]R;6%T(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M>&QI;FL](FAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@
M("`@("`@("!X;6QN<SIN=6UB97(](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+V1A=&%S='EL92(*("`@("`@("`@("`@("`@('AM;&YS.G-V9STB:'1T
M<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B"B`@("`@("`@("`@("`@("!X;6QN
M<SIC:&%R=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@
M("`@("`@("`@("`@("!X;6QN<SID<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]D<C-D(@H@("`@("`@("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T
M<#HO+W=W=RYW,RYO<F<O,3DY."]-871H+TUA=&A-3"(*("`@("`@("`@("`@
M("`@('AM;&YS.F9O<FT](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O
M<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+W-C<FEP="(*("`@("`@("`@("`@("`@(&]F9FEC
M93IC;&%S<STB=&5X="(*("`@("`@("`@("`@("`@(&]F9FEC93IV97)S:6]N
M/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SID8STB:'1T<#HO+W!U<FPN
M;W)G+V1C+V5L96UE;G1S+S$N,2\B"B`@("`@("`@("`@("`@("!X;6QN<SIM
M971A/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]M971A(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z8V]N9FEG/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,2]C;VYF:6<B"B`@("`@("`@("`@("`@("!X;6QN<SIH96QP/2)H='1P
M.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]H96QP(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>'0](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="(*("`@("`@("`@
M("`@("`@(&5X=&5N<VEO;BUE;&5M96YT+7!R969I>&5S/2)X="(*("`@("`@
M("`@("`@("`@('AM;&YS.G5R;&5N8V]D97(](FAT='`Z+R]W=W<N:F-L87)K
M+F-O;2]X="]J879A+VIA=F$N;F5T+E523$5N8V]D97(B"B`@("`@("`@("`@
M("`@("!X;6QN<SIS>&=H96QP97(](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X
M="]J879A+V-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS
M9F]R;65R(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X
M;6PN87!A8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA
M=F$](FAT='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@
M("`@("`@("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*"@H@
M("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@1VQO8F%L($1O8W5M96YT("T@
M(%1A8FQE(&]F($-O;G1E;G0@("`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*
M"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IT86)L92UO9BUC;VYT
M96YT(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*
M"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.FEN9&5X+6)O9'DB/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H*("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!M;V1E/2)C;VYT96YT
M+71A8FQE(CX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z
M:6YD97@M=&ET;&4B(&UO9&4](F-O;G1E;G0M=&%B;&4B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@
M("`\>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\>'-L.G1E;7!L871E
M(&UA=&-H/2)T97AT.G)E9F5R96YC92UR968B/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@("`\(2TM
M($IA=F$@:7,@;F5E9&5D(&%S('=E(&AA=F4@=&\@96YC;V1E('1H92!R96QA
M=&EV92!L:6YK<R`H8G5G(S$P,C,Q,2D@+2T^"B`@("`@("`@/'AS;#II9B!T
M97-T/2)N;W0H)&ES2F%V841I<V%B;&5D*2(^"B`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FAR968B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#XC/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M86QI>F5D
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E(&%N(&EL
M;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!8
M5"TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](G1E>'14;T)E16YC;V1E9"(@<V5L96-T/2)`=&5X=#IR968M;F%M
M92(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@("`@("`@("`@
M("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*"B`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T
M93X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G)E9F5R96YC92UM
M87)K(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"B`@("`@("`@/"$M+2!*879A(&ES(&YE961E9"!A<R!W92!H
M879E('1O(&5N8V]D92!T:&4@<F5L871I=F4@;&EN:W,@*&)U9R,Q,#(S,3$I
M("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*"1I<TIA=F%$:7-A8FQE
M9"DB/@H@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E
M+7-T<FEN9R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@=&AE('-P
M86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;W1H97)W:7-E(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T
M:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!85"TM/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D
M(B!S96QE8W0](D!T97AT.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ871T
M<FEB=71E/@H*("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^
M"@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.FEF
M/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)T97AT.G)E9F5R96YC92UM87)K+7-T87)T(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@
M/"$M+2!*879A(&ES(&YE961E9"!A<R!W92!H879E('1O(&5N8V]D92!T:&4@
M<F5L871I=F4@;&EN:W,@*&)U9R,Q,#(S,3$I("TM/@H@("`@("`@(#QX<VPZ
M:68@=&5S=#TB;F]T*"1I<TIA=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN9R(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M
M86QI>F5D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E
M(&%N(&EL;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N
M(&9O<B!85"TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D(B!S96QE8W0](D!T97AT.FYA
M;64B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96YD3V92969E<F5N8V4B/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2)T97AT
M.G)E9F5R96YC92UM87)K+65N9%M`;F%M93UC=7)R96YT*"DO0'1E>'0Z;F%M
M95TB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB<&]S:71I;VXH*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F9O<BUE86-H/@H@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H@
M("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](F9O;&QO=VEN
M9RUS:6)L:6YG.CHJ6W!O<VET:6]N*"D@)FQT.R`D96YD3V92969E<F5N8V5=
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT96UP
M;&%T97,^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@("`@
M("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@(#PO>'-L.FEF/@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*"@H@("`@(#PA+2T@8V]N=&5N="!T86)L92!L:6YK
M("`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z82(@;6]D93TB
M8V]N=&5N="UT86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B\^"@H*("`@("`@("`\(2TM($9O<B!A;F-H;W)S
M(&EN(&-O;G1E;G0M:&5A9&5R<R!A(&)U9R!E>&ES=',@*&-P+B!B=6<@:60C
M(#$P,C,Q,2D@86YD('1H97D@:&%V92!T;R!B92!W;W)K960@;W5T('-E<&%R
M871E;'DN"B`@("`@("`@("`@($-U<G)E;G1L>2!T:&4@;&EN:R!U<V5D(&EN
M('1H92!C;VYT96YT+71A8FQE(&]F(&%N($]F9FEC92!834P@*&4N9RX@:6X@
M=&AE(&-O;G1E;G0@=&%B;&4@87,@)R,W+E-O;64E,C!%>&%M<&QE)3(P2&5A
M9&QI;F4E-T]U=&QI;F4G*0H@("`@("`@("`@("!I<R!N;W0@82!V86QI9"!5
M4DP@*&-P+B!B=6<@:60C(#$P,C,Q,2DN($YO(&9I;&4@9&5S=&EN871I;VX@
M:7,@<W!E8VEF:65D(&YO<B!E>&ES="!A;GD@86YC:&]R(&5L96UE;G0@9F]R
M('1H97-E"B`@("`@("`@("`@(&QI;FMS(&EN('1H92!/9F9I8V4@6$U,+"!N
M;W(@:7,@=&AE(&-H87!T97(@;F\N(&MN;W=N(&EN('1H92!L:6YK960@9FEL
M97,N"B`@("`@("`@("`@($$@=V]R:V%R;W5N9"!F;W(@=&AI<R!T<F%N<V9O
M<FUA=&EO;B!T:&5R969O<F4@:&%D('1O(&)E(&UA9&4N(%1H:7,@=&EM92UC
M;VYS=6UI;F<@;65C:&%N:7-M(&ES(&1I<V%B;&5D(&)Y(&1E9F%U;'0@86YD
M"B`@("`@("`@("`@(&-A;B!B92!A8W1I=F%T960@8GD@82!P87)A;65T97(@
M*&DN92X@)V1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="<I+B!!(&-R96%T
M:6]N(&]F(&%N(&%N8VAO<B!I<R!M861E(&9O<B!E86-H(&AE861E<B!E;&5M
M96YT+@H@("`@("`@("`@("!!;&P@:&5A9&5R('1I=&QE<R!G;VYN82!B92!E
M;F-O9&EN9R!T;R!B92!U<V%B;&4@:6X@82!R96QA=&EV92!54DPN("TM/@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&1I<V%B;&5,:6YK961486)L94]F0V]N=&5N="!O<B`D:7-*879A1&ES
M86)L960B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F-R96%T92UC;VUM;VXM;&EN:R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E
M;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC;VYT96YT+71A8FQE
M+6QI;FLB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@("!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@
M("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\
M>'-L.G1E;7!L871E(&YA;64](F=E="UA8G-O;'5T92UC:&%P=&5R+6YO(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!R96-E9&EN9T-H87!T97),
M979E;#$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE
M(CX*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E
M;G1&:6QE2&5A9&EN9TYO(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB9V5T+6-U<G)E;G0M9FEL92UH96%D:6YG+6YO
M(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S=%)E<W5L="(@<V5L96-T
M/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULD9VQO8F%L1&]C=6UE
M;G129694;T-U<G)E;G1&:6QE(#T@0&9I;&4M=7)L75MN=6UB97(H)&-U<G)E
M;G1&:6QE2&5A9&EN9TYO*5TB+SX*"B`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB9V5T+6=L;V)A;"UH96%D:6YG+6YO(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N
M=$9I;&5(96%D:6YG3F\B('-E;&5C=#TB=')A;G-L871E*"1T97-T4F5S=6QT
M+T!A8G-O;'5T92UC:&%P=&5R+6QE=F5L+"`G*R<L("<N)RDB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E8V5D:6YG
M0VAA<'1E<DQE=F5L,2(@<V5L96-T/2(D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M,2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@(#PA+2T@5VAE;B!T:&4@8VAA<'1E<B!I<R!I
M;B!T:&4@9VQO8F%L(&1O8W5M96YT(&ET<V5L9B!T:&4@;&EN:R!H87,@=&\@
M8F4@<F5L871I=F4@*&4N9RX@(VEN9&5X*2!A(&%B<V]L=71E(&AR968@9&]E
M<R!N;W0*("`@("`@("`@("`@("`@("`@("!W;W)K('=I=&@@=&AE(&)R;W=S
M97(N($EN(&-A<V4@;V8@8VAA<'1E<B!I;B!T:&4@9VQO8F%L(&1O8W5M96YT
M+"!T:&4@;W5T<'5T(%523"!O9B!T:&4@9VQO8F%L(&1O8W5M96YT('=A<R!T
M86ME;BX@+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F-U<G)E;G1&:6QE2&5A9&EN9TYO(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6-U<G)E;G0M9FEL92UH96%D
M:6YG+6YO(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB=&5S=%)E<W5L="(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE
M861I;F=S+VAE861I;F=;)&-O;G1E;G1486)L95523"`]($!F:6QE+75R;%U;
M;G5M8F5R*"1C=7)R96YT1FEL94AE861I;F=.;RE=(B\^"@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UG;&]B86PM:&5A
M9&EN9RUN;R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN9TYO(B!S96QE8W0](G1R86YS;&%T
M92@D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL979E;"P@)RLG+"`G
M+B<I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!R96-E9&EN9T-H87!T97),979E;#$B('-E;&5C=#TB)'!R96-E9&EN
M9T-H87!T97),979E;#$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)G970M8W5R<F5N="UF:6QE+6AE861I;F<M;F\B
M/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z9V5T+6-U<G)E
M;G0M8VAI;&0M:&5A9&EN9RUN;R<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+6-U<G)E;G0M8VAI;&0M
M:&5A9&EN9RUN;R@I(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA
M=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M
M97(N9V5T0W5R<F5N=$-H:6QD2&5A9&EN9TYO)RDB/@H@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T0W5R<F5N=$-H:6QD
M2&5A9&EN9TYO*"DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS
M;#IT96UP;&%T92!N86UE/2)G970M;F5X="UC=7)R96YT+69I;&4M:&5A9&EN
M9RUN;R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)F:6QE(B\^"B`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F
M=6YC=&EO;BUA=F%I;&%B;&4H)W-X9VAE;'!E<CIG970M;F5X="UC=7)R96YT
M+6-H:6QD+6AE861I;F<M;F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F=E="UN97AT+6-U<G)E;G0M8VAI
M;&0M:&5A9&EN9RUN;R@D9FEL92DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL
M86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14
M<F%N<V9O<FUE<BYG971.97AT0W5R<F5N=$-H:6QD2&5A9&EN9TYO)RDB/@H@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M
M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T
M3F5X=$-U<G)E;G1#:&EL9$AE861I;F=.;R@D9FEL92DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M9VQO
M8F%L+6AE861I;F<M;F\B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R
M<F5N=$9I;&5(96%D:6YG3F\B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G!R96-E9&EN9T-H87!T97),979E;#$B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I
M;&%B;&4H)W-X9VAE;'!E<CIG970M9VQO8F%L+6AE861I;F<M;F\G*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R
M.F=E="UG;&]B86PM:&5A9&EN9RUN;RAS=')I;F<H)&-U<G)E;G1&:6QE2&5A
M9&EN9TYO*2P@;G5M8F5R*"1P<F5C961I;F=#:&%P=&5R3&5V96PQ*2DB+SX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N
M>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971';&]B86Q(96%D
M:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N
M<V9O<FUE<BYG971';&]B86Q(96%D:6YG3F\H<W1R:6YG*"1C=7)R96YT1FEL
M94AE861I;F=.;RDL(&YU;6)E<B@D<')E8V5D:6YG0VAA<'1E<DQE=F5L,2DI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H@("`@/"$M+2!N96-E<W-A
M<GD@87,@86YC:&]R(&9O<B!T:&4@8V]N=&5N="!T86)L92`M+3X*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6AE861I;F<M86YC:&]R(CX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M"B`@("`@("`@/"$M+0H@("`@("`@($-U<G)E;G1L>2!T:&4@;&EN:R!U<V5D
M(&EN('1H92!/9F9I8V4@6$U,("AE+F<N(&EN('1H92!C;VYT96YT('1A8FQE
M(&%S("<C-RY3;VUE)3(P17AA;7!L924R,$AE861L:6YE)3=/=71L:6YE)RD*
M("`@("`@("!I<R!N;W0@82!V86QI9"!54DP@*&-M<"X@8G5G(&ED(R`Q,#(S
M,3$I+B!.;R!F:6QE(&1E<W1I;F%T:6]N(&ES('-P96-I9FEE9"!N;W(@97AI
M<W0@86YY(&%N8VAO<B!E;&5M96YT(&9O<B!T:&5S90H@("`@("`@(&QI;FMS
M(&EN('1H92!/9F9I8V4@6$U,+@H@("`@("`@($AE<F4@=V4@87)E(&-R96%T
M:6YG(&%N(&%N8VAO<B!W:71H('1H92!S<&%C92!N;W)M86QI>F5D('1E>'0@
M;V8@=&AI<R!H96%D97(@87,@<&]T96YT:6%L(&IU;7`@861D<F5S<R!O9B!T
M:&4@8V]N=&5N="!T86)L92`M+3X*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9VQO8F%L1&]C=6UE;G129694
M;T-U<G)E;G1&:6QE(CX*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F-U<G)E;G1&:6QE2&5A9&EN9TYO(CX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YE>'0M8W5R<F5N
M="UF:6QE+6AE861I;F<M;F\B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&4B('-E;&5C=#TB)&=L;V)A;$1O
M8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IV
M87)I86)L93X*"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)T97-T4F5S=6QT(B!S96QE8W0](B1C;VYT96YT5&%B;&5(96%D:6YG<R]H
M96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4@/2!`9FEL
M92UU<FQ=6VYU;6)E<B@D8W5R<F5N=$9I;&5(96%D:6YG3F\I72(O/@H@("`@
M("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y-871C:&EN9R!C:&EL9"!D
M;V-U;65N="!H96%D97(@3F\N(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R
M<F5N=$9I;&5(96%D:6YG3F\B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;65S<V%G93YA8G-O;'5T92UC:&%P=&5R+6QE=F5L
M.B`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&5S=%)E<W5L="]`
M86)S;VQU=&4M8VAA<'1E<BUL979E;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F5N8V]D9614:71L93H@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T97-T4F5S
M=6QT+T!E;F-O9&5D+71I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@
M("`@("`@("`@("`\>'-L.FUE<W-A9V4^9VQO8F%L1&]C=6UE;G129694;T-U
M<G)E;G1&:6QE.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&=L;V)A;$1O8W5M
M96YT4F5F5&]#=7)R96YT1FEL92(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IM97-S86=E/BHJ*B`\+WAS;#IM97-S86=E/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](FYA;64B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&%B<V]L=71E
M+6-H87!T97(M;&5V96PB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IT97AT/BL\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB)'1E<W1297-U;'0O0&5N8V]D960M=&ET
M;&4B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@(#PO>'-L
M.G=H96X^"@H@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/"$M+2!7:&5N('1H92!C:&%P=&5R(&ES(&EN('1H92!G;&]B86P@
M9&]C=6UE;G0@:71S96QF('1H92!L:6YK(&AA<R!T;R!B92!R96QA=&EV92`H
M92YG+B`C:6YD97@I(&$@86)S;VQU=&4@:')E9B!D;V5S(&YO=`H@("`@("`@
M("`@("`@("`@("`@('=O<FL@=VET:"!T:&4@8G)O=W-E<BX@26X@8V%S92!O
M9B!C:&%P=&5R(&EN('1H92!G;&]B86P@9&]C=6UE;G0L('1H92!O=71P=70@
M55),(&]F('1H92!G;&]B86P@9&]C=6UE;G0@=V%S('1A:V5N+B`M+3X*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$9I;&5(
M96%D:6YG3F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)G970M;F5X="UC=7)R96YT+69I;&4M:&5A9&EN9RUN;R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB9FEL92(@<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^"B`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M("`@(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](G1E<W1297-U;'0B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<R]H96%D:6YG6R1C;VYT
M96YT5&%B;&554DP@/2!`9FEL92UU<FQ=6VYU;6)E<B@D8W5R<F5N=$9I;&5(
M96%D:6YG3F\I72(O/@H*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^36%T8VAI;F<@9VQO8F%L(&1O8W5M96YT(&AE861E<B!.;RX@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1C=7)R96YT1FEL94AE861I;F=.;R(O/CPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/F%B
M<V]L=71E+6-H87!T97(M;&5V96PZ("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)'1E<W1297-U;'0O0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93YE;F-O
M9&5D5&ET;&4Z("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1T
M97-T4F5S=6QT+T!E;F-O9&5D+71I=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8V]N=&5N=%1A8FQE55),
M.B`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]N=&5N=%1A8FQE
M55),(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^*BHJ(#PO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#II9CX*"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M82(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D=&5S=%)E<W5L="]`86)S;VQU=&4M8VAA<'1E<BUL979E;"(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*SPO>'-L.G1E
M>'0^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2(D=&5S=%)E<W5L="]`96YC;V1E9"UT:71L92(O/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H*"@H\(2TM"@H@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB=&ET;&4B('-E;&5C=#TB;F]R;6%L:7IE+7-P86-E*"XI
M(B\^"B`@("`@("`@/"%^?D1/3B=4(%=/4DL@("`@/'AS;#IV87)I86)L92!N
M86UE/2)T:71L92(@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H9&5S8V5N9&%N
M=#HZ=&5X="@I*2(O/B`@("`@("`@?GX^"B`@("`@("`@(#QX<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&=L;V)A;$1O8W5M96YT
M4F5F5&]#=7)R96YT1FEL92(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](G1E<W1297-U;'1S(B!S96QE8W0](B1C;VYT96YT5&%B;&5(
M96%D:6YG<R]H96%D:6YG6R1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I
M;&4@/2!`9FEL92UU<FQ=6R1T:71L92`]($!T:71L95U;8W5R<F5N="@I+T!T
M97AT.FQE=F5L(#T@0&QE=F5L72(O/@H@("`@("`@("`@("`@("`@/'AS;#II
M9B!T97-T/2(Q("9L=#L@8V]U;G0H)'1E<W1297-U;'1S*2(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IM97-S86=E/B`J*BH@0T%55$E/3CH@375L=&EP
M;&4@8VAA<'1E<B!H96%D:6YG<R!W:71H('-I;6EL87(@;F%M97,Z(#PO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E/B`J
M*BH@5&ET;&4Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D=&ET;&4B+SX@3&5V
M96PZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&5X=#IL979E;"(O/CPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)E;F-O9&5D5&ET;&4B('-E
M;&5C=#TB)'1E<W1297-U;'1S+T!E;F-O9&5D+71I=&QE(B\^"B`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D96YC;V1E9%1I=&QE(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FYA;64B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D96YC;V1E9%1I=&QE(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"%^?B!E=F5N('=H96X@:70@:7,@
M;F]T('Y^/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](FYE=T5N8V]D9614:71L92(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB96YC;V1E+7-T<FEN
M9R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"%^?B!T:&4@
M<W!A8V4@:&%S('1O(&)E(&YO<FUA;&EZ960L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]T:&5R=VES92!A;B!I;&QE9V%L(&%R9W5M
M96YT(&5X8V5P=&EO;B!W:6QL(&)E('1H<F]W;B!F;W(@6%1^?CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G1E>'14;T)E16YC;V1E9"(@<V5L96-T/2(D=&ET;&4B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1N97=%;F-O9&5D5&ET;&4B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L
M92!N86UE/2)T97-T4F5S=6QT<R(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S+VAE861I;F=;)&-O;G1E;G14
M86)L95523"`]($!F:6QE+75R;%U;)'1I=&QE(#T@0'1I=&QE75MC=7)R96YT
M*"DO0'1E>'0Z;&5V96P@/2!`;&5V96Q=(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.FEF('1E<W0](C$@)FQT.R!C;W5N="@D=&5S=%)E<W5L=',I(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^("HJ*B!#055424]..B!-
M=6QT:7!L92!C:&%P=&5R(&AE861I;F=S('=I=&@@<VEM:6QA<B!N86UE<SH@
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^("HJ*B!4:71L93H@/'AS;#IV86QU92UO9B!S96QE8W0](B1T:71L92(O
M/B!,979E;#H@/'AS;#IV86QU92UO9B!S96QE8W0](D!T97AT.FQE=F5L(B\^
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^("HJ*B`\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M:68^"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)E;F-O
M9&5D5&ET;&4B('-E;&5C=#TB)'1E<W1297-U;'1S+T!E;F-O9&5D+71I=&QE
M(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E;F-O9&5D5&ET;&4B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M
M93TB;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](B1E;F-O9&5D5&ET;&4B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(7Y^(&5V96X@
M=VAE;B!I="!I<R!N;W0@?GX^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB;F5W16YC;V1E9%1I=&QE(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)E
M;F-O9&4M<W1R:6YG(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(7Y^('1H92!S<&%C92!H87,@=&\@8F4@;F]R;6%L:7IE9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97)W:7-E(&%N(&EL
M;&5G86P@87)G=6UE;G0@97AC97!T:6]N('=I;&P@8F4@=&AR;W=N(&9O<B!8
M5'Y^/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB=&5X=%1O0F5%;F-O9&5D(B!S96QE8W0](B1T:71L
M92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B
M;&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB82(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I
M8G5T92!N86UE/2)N86UE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&YE=T5N8V]D9614:71L92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"BTM/@H*("`@(#PO>'-L.G1E
M;7!L871E/@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("`@($-214%424].($]&($$@
M0T].5$5.5"!404),12!,24Y+("`@("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"@H@("`@/"$M+2!A
M('-P96-I86P@8F5H879I;W(@;V8@=&5X=#IA"B`@("`@("`@*&-A;&QE9"!F
M<F]M('1H92`G=&5X=#IA)R!T96UP;&%T92D@+2T^"@H@("`@/'AS;#IT96UP
M;&%T92!N86UE/2)C<F5A=&4M8V]N=&5N="UT86)L92UL:6YK(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@
M("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)N;W0H)&]U='!U=%1Y<&4@/2`G5TU,)RDB/@H@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ871T<FEB=71E(&YA;64](FAR968B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2)S=&%R=',M=VET:"A`>&QI;FLZ:')E9BP@)R,G
M*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)C;W)R96-T2&5A9&EN9R(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82]C;VYT96YT+71A8FQE+6AE861I;F=S+VAE861I;F=;8W5R
M<F5N="@I+T!X;&EN:SIH<F5F(#T@0&-O;G1E;G0M=&%B;&4M:61=(B\^"@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D8V]R<F5C=$AE861I;F<O0&]U="UF:6QE+75R;"(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XC/"]X<VPZ
M=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB)&-O<G)E8W1(96%D:6YG+T!A8G-O;'5T92UC:&%P
M=&5R+6QE=F5L(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/BL\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]R<F5C=$AE861I
M;F<O0&5N8V]D960M=&ET;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;6UO;BUL:6YK
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`\(2TM(#)$3SH@8W5R<F5N=&QY(&YO(%=-3"!S=7!P
M;W)T"@H@("`@("`@("`@("`@("`@/"%^?B!N;R!N97-T960@<"!T86=S(&EN
M('=M;#$N,2!A;&QO=V5D('Y^/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S
M=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S+"!N86UE
M*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI
M;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+B(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT
M96UP;&%T97,@<V5L96-T/2(N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X@("TM/@H@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"3PA+2T*"2`@("!#4D5!5$E/3B!/
M1B!!($A%3%!%4B!605))04),12!!4R!73U)+05)/54Y$($9/4B!42$4@0T].
M5$5.5"!404),12!53%(@0E5'"@H*("`@("`@("!!<R!N;R!V86QI9"!54DP@
M9G)O;2!T:&4@8V]N=&5N="!T86)L92!T;R!T:&4@8VAI;&0@9&]C=6UE;G1S
M(&5X:7-T(&EN('1H92!C;VYT96YT('1A8FQE+`H@("`@("`@(&$@=V]R:RUA
M<F]U;F0@:7,@9&]N93H*"B`@("`@("`@1FER<W0@='=O(&AE;'!E<B!V87)I
M86)L97,@87)E(&)E:6YG(&-R96%T960N"@H@("`@("`@($]N92!C;VYT86EN
M:6YG('1H92!L:7-T(&]F(&%L;"!R969E<F5N8V5S(&]F('1H92!G;&]B86P@
M9&]C=6UE;G0Z"B`@("`@("`@8V]N=&%I;F<@86QL('1H96ER('1I=&QE+`H@
M("`@("`@(&9O<B!E>&%M<&QE.@H*("`@("`@("`@(`D\8VAA<'1E<BUR968@
M=&ET;&4](F%4:71L92`Q(B\^"B`@("`@("`@("`)/&-H87!T97(M<F5F('1I
M=&QE/2)A5&ET;&4@,B(O/@H@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L
M93TB851I=&QE(#(O/@H@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB
M851I=&QE(#,O/@H*("`@("`@("!4:&4@;W1H97(@8V]N=&%I;FEN9R!A;&P@
M:&5A9&EN9R!F<F]M('1H92!C:&EL9"!D;V-U;65N=',@;&EN:V5D(&9R;VT@
M=&AE(&=L;V)A;"!D;V-U;65N="X*("`@("`@("!4:&4@=F%R:6%B;&4@)V-H
M:6QD<F5N2&5A9&EN9W,G(&-O;G1A:6YS('1H96ER('1I=&QE(&%N9"!T:&4@
M;G5M8F5R(&]F('!R96-E9&EN9R!S:6UI;&%R('1I=&QE<RP*("`@("`@("!F
M;W(@97AA;7!L93H*"@H@("`@("`@("`@"3QC:&EL9"!F:6QE+75R;#TB8552
M3"(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4Q(B!L979E
M;#TB,2(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4R(B!L
M979E;#TB,B(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4S
M(B!L979E;#TB,2(^"B`@("`@("`@("`@(#PO8VAI;&0^"@H@("`@("`@($9O
M<B!E86-H(&-H87!T97(@<F5F97)E;F-E(&9R;VT@=&AE(&-O;G1E;G0@=&%B
M;&4@=&AE"@H@("`@("`@("!B>2!E;F-O9&EN9R!T:&4@8VAA<'1E<B!N86UE
M<R!O9B!T:&4@8VAI;&0@9&]C=6UE;G0@=VET:"!T:&4@:F%V82!54DQ%;F-O
M9&5R(&%N9`H@("`@("`@('5S92!T:&ES(&%S(&$@<&%R="!O9B!A(&QI;FLN
M($9U<G1H97)M;W)E(&9O<B!A;&P@:&5A9&EN9R!E;&5M96YT<R!A(&5N8V]D
M960@86YC:&]R('=I;&P@8F4@8W)E871E9"!F<F]M('1H92!H96%D:6YG+@H@
M("`@("`@($QA<W0@=&AE('=O<FMA<F]U;F0@<&%R<V5S(&%L;"!C:&EL9')E
M;B!D;V-U;65N=',@9F]R('1H:7,@86YH;W(L(&%S('1H97)E(&ES(&YO(&1I
M<W1I;F-T:6]N(&]F(&9I;&5S(&9R;VT@=&AE(&-O;G1E;G0@=&%B;&4@96YT
M<FEE<RX*"B`@("`@("`@5&AE(&YE=R!A9&1E9"!N;V1E('-E="!T;R!T:&4@
M8V]L;&5C=&5D1VQO8F%L1&%T82!V87)I86)L92!C;VYC97)I;F<@=&AE(&-O
M;G1E;G0@=&%B;&4@:7,@=W)I='1E;B!A<PH*"@D)/&-O;G1E;G0M=&%B;&4M
M:&5A9&EN9W,@8V]N=&5N="UT86)L92UU<FP](F%54DQ?5&]4:&5'96YE<F%T
M961#;VYT96YT5&%B;&4B/@H@("`@("`)"3QH96%D:6YG(&9I;&4M=7)L/2)A
M1FEL95523%1O5&AE1V5N97)A=&5D2&5A9&EN9S$B(&QE=F5L/2(Q(CX*("`@
M("`@"0D\:&5A9&EN9R!F:6QE+75R;#TB849I;&554DQ4;U1H94=E;F5R871E
M9$AE861I;F<R(B!L979E;#TB,B(^"B`@("`@(`D)/&AE861I;F<@9FEL92UU
M<FP](F%&:6QE55),5&]4:&5'96YE<F%T961(96%D:6YG,2(@;&5V96P](C$B
M/@H@("`@("`)"3QH96%D:6YG(&9I;&4M=7)L/2)A1FEL95523%1O5&AE1V5N
M97)A=&5D2&5A9&EN9S(B(&QE=F5L/2(R(CX*"0D\+V-O;G1E;G0M=&%B;&4M
M:&5A9&EN9W,^"@H*("`@("`@("!0<F5C;VYD:71I;VYS.@H)"51H92!C;W)R
M96-T('-E<75E;F-E(&]F(&-H:6QD(&1O8W5M96YT<R!A8V-O<F1I;F<@=&\@
M=&AE($-O;G1E;G0@5&%B;&4@:7,@;F5C97-S87)Y+"!G<F%N=&5D(&)Y('1H
M92!O9F9I8V4N"@DM+3X*"3QX<VPZ=&5M<&QA=&4@;F%M93TB0W)E871E+6AE
M;'!E<BUV87)I86)L97,M9F]R+4-O;G1E;G0M5&%B;&4B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@("`@
M("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D-R
M96%T:6]N(&]F(&=L;V)A;"!D;V-U;65N="!H96QP97(@=F%R:6%B;&4@9F]R
M('1H92!C;VYT96YT('1A8FQE+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^
M"@H@("`@("`@(#PA+2T@2&5R92!A(&AE;'!E<B!V87)I86)L92!O9B!T:&4@
M8V]N=&5N="!T86)L92!I<R!C<F5A=&5D+"!O9B!A;&P@8VAA<'1E<BUR969E
M<F5N8V5S('=H:6-H('!O:6YT('1O(&$@8VAI;&0@9&]C=6UE;G0N"B`@("`@
M("`@("`@("!A;B`G8VAA<'1E<BUR968G(&5L96UE;G0@=VEL;"!B92!C<F5A
M=&5D+"!C;VYT86EN9R!T:&5I<B!T:71L92!A;F0@=&AE(&YU;6)E<B!O9B!P
M<F5C961I;F<@<VEM:6QA<B!T:71L97,L"B`@("`@("`@("`@("!F;W(@97AA
M;7!L93H*"B`@("`@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L93TB851I
M=&QE(#$B+SX*("`@("`@("`@("`@("`)/&-H87!T97(M<F5F('1I=&QE/2)A
M5&ET;&4@,B(O/@H@("`@("`@("`@("`@(`D\8VAA<'1E<BUR968@=&ET;&4]
M(F%4:71L92`R(B\^"B`@("`@("`@("`@("`@"3QC:&%P=&5R+7)E9B!T:71L
M93TB851I=&QE(#,B+SX*("`@("`@("`@("`@+2T^"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)C:&%P=&5R4F5F<RU25$8B/@H@("`@("`@("`@("`\
M(2TM("<O*B\G(&%S('1H92!F;&%T(&%N9"!T:&4@>FEP<&5D(%A-3"!F:6QE
M(&9O<FUA="!H879E(&1I9F9E<F5N="!R;V]T(&5L96UE;G1S("TM/@H@("`@
M("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DO
M=&5X=#IT86)L92UO9BUC;VYT96YT+W1E>'0Z:6YD97@M8F]D>2]T97AT.G`O
M=&5X=#IA(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M8W5R<F5N=%1I=&QE(B!S96QE8W0](FYO<FUA;&EZ92US<&%C92AS=')I;F<H
M+BDI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB8VAA
M<'1E<BUR968B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](G1I=&QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV
M86QU92UO9B!S96QE8W0](B1C=7)R96YT5&ET;&4B+SX*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="UT86)L92UI9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI
M;FLZ:')E9B(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@
M("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y&
M:6YI<VAE9"!T:&4@0W)E871I;VX@;V8@9VQO8F%L(&1O8W5M96YT(&AE;'!E
M<B!V87)I86)L92!F;W(@=&AE(&-O;G1E;G0@=&%B;&4A/"]X<VPZ;65S<V%G
M93X\+WAS;#II9CX*"@H*"B`@("`@("`@/'AS;#II9B!T97-T/2(D:7-$96)U
M9TUO9&4B/CQX<VPZ;65S<V%G93Y#<F5A=&EO;B!O9B!G;&]B86P@9&]C=6UE
M;G0@:&5L<&5R('9A<FEA8FQE(&9O<B!T:&4@8VAI;&0@9&]C=6UE;G1S+BXN
M+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@/"$M+2!(97)E(&$@
M:&5L<&5R('9A<FEA8FQE(&]F(&-R96%T960@9G)O;2!T:&4@8VAI;&1R96X@
M9&]C=6UE;G1S+@H@("`@("`@("`@("`@0V]N=&%I;F<@86QL(&AE861I;F<@
M96QE;65N=',@9G)O;2!T:&4@8VAI;&0@9&]C=6UE;G1S+B!3;VUE(&]R(&%L
M;"!O9B!T:&5M(&%R90H@("`@("`@("`@("`@8VAA<'1E<G,@<F5F97)E;F-E
M9"!B>2!T:&4@1VQO8F%L($1O8W5M96YT+@H@("`@("`@("`@("`@5&AE('9A
M<FEA8FQE(&-O;G1A:6YS('1H96ER('1I=&QE+"!T:&4@;&5V96P@;V8@=&AE
M(&AE861I;F<@86YD('1H92!F:6QE(%523"!O9B!T:&4@8VAI;&0L"B`@("`@
M("`@("`@("!F;W(@97AA;7!L93H*"B`@("`@("`@("`)"3QH96%D:6YG('1I
M=&QE/2)A5&ET;&4Q(B!L979E;#TB,2(@9FEL92UU<FP](F%54DPQ(CX*("`@
M("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L93(B(&QE=F5L/2(R(B!F
M:6QE+75R;#TB85523#$B/@H@("`@("`@("`@"0D\:&5A9&EN9R!T:71L93TB
M851I=&QE,R(@;&5V96P](C$B(&9I;&4M=7)L/2)A55),,2(^"B`@("`@("`@
M("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4T(B!L979E;#TB,2(@9FEL92UU
M<FP](F%54DPR(CX*("`@("`@("`@(`D)/&AE861I;F<@=&ET;&4](F%4:71L
M934B(&QE=F5L/2(R(B!F:6QE+75R;#TB85523#(B/@H@("`@("`@("`@"0D\
M:&5A9&EN9R!T:71L93TB851I=&QE,B(@;&5V96P](C,B(&9I;&4M=7)L/2)A
M55),,B(^"B`@("`@("`@("`)"3QH96%D:6YG('1I=&QE/2)A5&ET;&4V(B!L
M979E;#TB,R(@9FEL92UU<FP](F%54DPR(CX*("`@("`@("`@("`@("`@(#QH
M96%D:6YG+6-O=6YT/C<\+VAE861I;F<M8V]U;G0^"B`@("`@("`@("`@("TM
M/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8VAI;&1R96Y(96%D:6YG
M<RU25$8B/@H@("`@("`@("`@("`\(2TM(&%L;"!H96%D97)S(&9R;VT@8VAI
M;&1R96X@9&]C=6UE;G1S('=I;&P@8F4@861D960@+2T^"B`@("`@("`@("`@
M(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB+RHO;V9F:6-E.F)O9'DO
M=&5X=#IS96-T:6]N(B!M;V1E/2)C<F5A=&EO;BUO9BUV87)I86)L92(O/@H@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)&ES1&5B=6=-;V1E(CX\>'-L.FUE<W-A9V4^1FEN:7-H960@=&AE($-R96%T
M:6]N(&]F(&=L;V)A;"!D;V-U;65N="!H96QP97(@=F%R:6%B;&4@9F]R('1H
M92!C:&EL9"!D;V-U;65N=',A/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X=#IN;V1E+7-E="<I(CX*("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)#<F5A=&4M9VQO
M8F%L+79A<FEA8FQE+69O<BU#;VYT96YT+51A8FQE(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@
M("!S96QE8W0](GAT.FYO9&4M<V5T*"1C:&%P=&5R4F5F<RU25$8I(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H:6QD
M<F5N2&5A9&EN9W,B("`@("!S96QE8W0](GAT.FYO9&4M<V5T*"1C:&EL9')E
M;DAE861I;F=S+5)41BDB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA
M;&%N.FYO9&5S970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB0W)E871E+6=L;V)A;"UV87)I86)L92UF;W(M0V]N=&5N
M="U486)L92(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-H87!T97)2969S(B`@("`@<V5L96-T/2)X86QA;CIN;V1E<V5T
M*"1C:&%P=&5R4F5F<RU25$8I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B("`@("!S96QE
M8W0](GAA;&%N.FYO9&5S970H)&-H:6QD<F5N2&5A9&EN9W,M4E1&*2(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL
M96-T961';&]B86Q$871A(B`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(D-R96%T92UG;&]B86PM=F%R:6%B;&4M9F]R+4-O;G1E;G0M5&%B;&4B/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@
M("`@/"$M+2!H96QP97(@=F%R:6%B;&4@8V]L;&5C=&EN9R!A;&P@:&5A9&EN
M9W,@9G)O;2!T:&4@9VQO8F%L(&1O8W5M96YT(&9I;&4@8VAI;&1R96XM+3X*
M("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1C:&EL9')E;DAE
M861I;F=S+VAE861I;F<B/@H@("`@("`@("`@("`@("`@/'AS;#IM97-S86=E
M/B,@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)P;W-I=&EO
M;B@I(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93YL979E;#H@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&QE
M=F5L(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93YT:71L93H@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1I
M=&QE(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93YE;F-O9&5D+71I=&QE.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&5N
M8V]D960M=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M/'AS;#IM97-S86=E/F9I;&4M=7)L.B`@("`@(#QX<VPZ=F%L=64M;V8@<V5L
M96-T/2)`9FEL92UU<FPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@
M("`@/'AS;#IM97-S86=E/FAE861E<BUN;SH@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`:&5A9&5R+6YO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@
M("`@("`@(#QX<VPZ;65S<V%G93XJ*CPO>'-L.FUE<W-A9V4^"B`@("`@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M*BH\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^*BH\
M+WAS;#IM97-S86=E/@H*("`@("`@("`@("`@/"$M+2!H96QP97(@=F%R:6%B
M;&4@8V]L;&5C=&EN9R!A;&P@:&5A9&EN9R!R969E<F5N8V5S(&9R;VT@=&AE
M(&-O;G1E;G0@=&%B;&4@;V8@=&AE('1H92!G;&]B86P@9&]C=6UE;G0@+2T^
M"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC:&EL9')E;DAE861I;F=S+VAE
M861I;F<M8V]U;G0Z(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8VAI;&1R96Y(
M96%D:6YG<R]H96%D:6YG+6-O=6YT(B\^/"]X<VPZ;65S<V%G93X*("`@("`@
M("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1C:&%P=&5R4F5F<R]C:&%P
M=&5R+7)E9B(^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^(R`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB<&]S:71I;VXH*2(O/CPO>'-L.FUE<W-A9V4^
M"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^=&ET;&4Z(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)`=&ET;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@
M("`@("`@("`@/'AS;#IM97-S86=E/BHJ/"]X<VPZ;65S<V%G93X*("`@("`@
M("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@/"]X<VPZ:68^"@H*("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.G-E="UH96%D:6YG+6YO
M)RDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)S>&=H96QP97(Z<V5T+6AE861I;F<M;F\H,2DB+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.G-E="UC
M=7)R96YT+6-H:6QD+6YO*#$I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS970M8W5R<F5N="UC:&EL
M9"UU<FPH<W1R:6YG*"1C:&EL9')E;DAE861I;F=S+VAE861I;F<O0&9I;&4M
M=7)L*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN
M<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971(
M96%D:6YG3F\G*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H
M:6QD5')A;G-F;W)M97(N<V5T2&5A9&EN9TYO*#$I(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS
M=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N<V5T0W5R<F5N
M=$-H:6QD3F\H,2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&15<FPH<W1R:6YG*"1C
M:&EL9')E;DAE861I;F=S+VAE861I;F<O0&9I;&4M=7(I*2(O/@H@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`@
M("`@/'AS;#II9B!T97-T/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y#
M<F5A=&EN9R!G;&]B86P@9&]C=6UE;G0@=F%R:6%B;&4@9F]R(&-H87!T97(@
M<F5L871I;VYS+BXN+CPO>'-L.FUE<W-A9V4^/"]X<VPZ:68^"B`@("`@("`@
M/'AS;#IV87)I86)L92!N86UE/2)C;VYT96YT5&%B;&5(96%D:6YG<T=L;V)A
M;$1A=&$M4E1&(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F-O
M;G1E;G0M=&%B;&4M:&5A9&EN9W,B/@H@("`@("`@("`@("`@("`@/"$M+2!A
M;&P@:&5A9&EN9W,@87)E(&QI;FME9"!F<F]M('1H92!C=7)R96YT(&=L;V)A
M;"!D;V-U;65N="!I;G!U="!F:6QE("TM/@H@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="UT86)L92UU<FPB/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]N=&5N=%1A
M8FQE55),(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"@H@
M("`@("`@("`@("`@("`@/"$M+2!H860@=&\@=7-E(&$@9F]R(&QO;W`L(&%S
M(&$@<F5C=7)S:6]N(&5N9',@=VET:"!A;B!S=&%C:V]V97)F;&]W(&5X8V5P
M=&EO;B!A9G1E<B!A8F]U="`V,#`@<F5C=7)S:79E(&-A;&QS("TM/@H@("`@
M("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R
M.F=E="UH96%D:6YG+6YO)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IF;W(M96%C:"!S96QE8W0](B1C:&%P=&5R4F5F<R]C:&%P=&5R+7)E
M9B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB<V5A<F-H2&5A9&EN9TEN0VAI;&1$;V-U;65N="(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-H87!T97)2969S(B`@("`@("`@('-E;&5C=#TB)&-H87!T97)2
M969S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-H:6QD<F5N2&5A9&EN9W,B("`@('-E;&5C=#TB
M)&-H:6QD<F5N2&5A9&EN9W,B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H87!T97)2
M969.;R(@<V5L96-T/2)P;W-I=&EO;B@I(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1(
M96%D:6YG3F\B("`@('-E;&5C=#TB<WAG:&5L<&5R.F=E="UH96%D:6YG+6YO
M*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8W5R<F5N=$-H:6QD55),(B`@("`@<V5L96-T/2)S
M>&=H96QP97(Z9V5T+6-U<G)E;G0M8VAI;&0M=7)L*"DB+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8W5R<F5N=$-H:6QD3F\B("`@("`@<V5L96-T/2)S>&=H96QP97(Z9V5T+6-U
M<G)E;G0M8VAI;&0M;F\H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U
M;F-T:6]N+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971(96%D:6YG3F\G*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&-H
M87!T97)2969S+V-H87!T97(M<F5F(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S96%R8VA(96%D:6YG
M26Y#:&EL9$1O8W5M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAA<'1E<E)E9G,B("`@("`@
M("`@<V5L96-T/2(D8VAA<'1E<E)E9G,B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R96Y(
M96%D:6YG<R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C=7)R96YT0VAA<'1E<E)E9DYO(B!S96QE8W0](G!O<VET:6]N*"DB
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8W5R<F5N=$AE861I;F=.;R(@("`@<V5L96-T/2)J879A
M.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R
M+F=E=$AE861I;F=.;R@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&EL9%523"(@
M("`@('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYG971#=7)R96YT0VAI;&15<FPH*2(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C=7)R96YT0VAI;&1.;R(@("`@("!S96QE8W0](FIA=F$Z8V]M+G-U
M;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T0W5R
M<F5N=$-H:6QD3F\H*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ9F]R+65A8V@^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*"B`@("`@("`@("`@(#PA+2T@861D:6YG('1H92!A
M;')E861Y(&5X:7-I=&EN9R!G;&]B86P@9&%T82!E;G9I<F]N;65N="`M+3X*
M("`@("`@("`@("`@/'AS;#IC;W!Y+6]F('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`\
M>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^/'AS;#IM97-S86=E/D9I;FES
M:&5D(&=L;V)A;"!D;V-U;65N="!V87)I86)L92!F;W(@8VAA<'1E<B!R96QA
M=&EO;G,A/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*"B`@("`@("`@/'AS;#IC
M:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA
M=F%I;&%B;&4H)WAT.FYO9&4M<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](G-T87)T+7-E;&8M86YD+6-H:6QD<F5N
M+71R86YS9F]R;6%T:6]N(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L
M96-T/2)X=#IN;V1E+7-E="@D8V]N=&5N=%1A8FQE2&5A9&EN9W-';&]B86Q$
M871A+5)41BDB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S970G
M*2(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M<W1A<G0M<V5L9BUA;F0M8VAI;&1R96XM=')A;G-F;W)M871I;VXB/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B`@("`@("!S96QE8W0](GAA;&%N.FYO9&5S970H)&-O
M;G1E;G1486)L94AE861I;F=S1VQO8F%L1&%T82U25$8I(B\^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L
M871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G-E87)C:$AE861I;F=)
M;D-H:6QD1&]C=6UE;G0B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8VAA
M<'1E<E)E9G,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-H:6QD<F5N
M2&5A9&EN9W,B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-U<G)E;G1#
M:&%P=&5R4F5F3F\B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-U<G)E
M;G1(96%D:6YG3F\B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-U<G)E
M;G1#:&EL9%523"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8W5R<F5N
M=$-H:6QD3F\B+SX*"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R
M<F5N=$-H87!T97)2968B("`@("`@<V5L96-T/2(D8VAA<'1E<E)E9G,O8VAA
M<'1E<BUR969;)&-U<G)E;G1#:&%P=&5R4F5F3F]=(B\^"B`@("`@("`@/'AS
M;#IV87)I86)L92!N86UE/2)C=7)R96YT0VAA<'1E<DE$(B`@("`@("!S96QE
M8W0](B1C=7)R96YT0VAA<'1E<E)E9B]`8V]N=&5N="UT86)L92UI9"(O/@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$-H87!T97)4:71L
M92(@("`@<V5L96-T/2(D8W5R<F5N=$-H87!T97)2968O0'1I=&QE(B\^"@H@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8W5R<F5N=$-H:6QD2&5A9&EN
M9R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R]H96%D:6YG6R1C=7)R
M96YT2&5A9&EN9TYO72(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M:&5A9&EN9U1I=&QE(B`@("`@("`@("`@<V5L96-T/2(D8W5R<F5N=$-H:6QD
M2&5A9&EN9R]`=&ET;&4B+SX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(FAE861I;F=,979E;"(@("`@("`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL
M9$AE861I;F<O0&QE=F5L(B\^"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)H96%D:6YG3F\B("`@("`@("`@("`@("!S96QE8W0](B1C=7)R96YT0VAI
M;&1(96%D:6YG+T!H96%D97(M;F\B+SX*("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](FYE=T-H:6QD55),(B`@("`@("`@("`@('-E;&5C=#TB)&-U<G)E
M;G1#:&EL9$AE861I;F<O0&9I;&4M=7)L(B\^"@H@("`@("`@(#QX<VPZ:68@
M=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@/'AS;#IM97-S86=E
M/BHJ*B!N97<@:&5A9&EN9R`\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M>'-L.FUE<W-A9V4^8W5R<F5N=$-H87!T97))1#H@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](B1C=7)R96YT0VAA<'1E<DE$(B\^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/'AS;#IM97-S86=E/F-U<G)E;G1#:&%P=&5R5&ET;&4Z
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H87!T97)4:71L92(O
M/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YC=7)R
M96YT0VAA<'1E<DE$.B`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E
M;G1#:&%P=&5R240B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L
M.FUE<W-A9V4^8W5R<F5N=$AE861I;F=.;SH@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](B1C=7)R96YT2&5A9&EN9TYO(B\^/"]X<VPZ;65S<V%G93X*("`@
M("`@("`@("`@/'AS;#IM97-S86=E/FAE861I;F=4:71L93H@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN9U1I=&QE(B\^/"]X<VPZ;65S
M<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/FAE861I;F=,979E;#H@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN9TQE=F5L(B\^
M/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E/FAE861I
M;F=.;SH@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A9&EN
M9TYO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM97-S86=E
M/FYE=T-H:6QD55),.B`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D
M;F5W0VAI;&154DPB+SX\+WAS;#IM97-S86=E/@H@("`@("`@(#PO>'-L.FEF
M/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F]U=$9I;&554DPB/@H@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB<W5B<W1R:6YG+6)E9F]R92@D;F5W0VAI;&154DPL)RYX
M;6PG*2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE
M8W0](F-O;F-A="AS=6)S=')I;F<M8F5F;W)E*"1N97=#:&EL9%523"PG+GAM
M;"<I+"<N:'1M)RDB+SX*("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)S=6)S=')I;F<M8F5F
M;W)E*"1N97=#:&EL9%523"PG+G-X)RDB/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H<W5B<W1R:6YG+6)E9F]R
M92@D;F5W0VAI;&154DPL)RYS>"<I+"<N:'1M)RDB+SX*("`@("`@("`@("`@
M("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)I<T-H87!T97)(96%D:6YG(B!S96QE8W0](B1H96%D:6YG5&ET;&4@
M/2`D8W5R<F5N=$-H87!T97)4:71L92(O/@H@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB:7-.97=&:6QE(B!S96QE8W0](G-T<FEN9R@D;F5W0VAI;&15
M4DPI("$]('-T<FEN9R@D8W5R<F5N=$-H:6QD55),*2(O/@H*"@H*("`@("`@
M("`\>'-L.FEF('1E<W0](B1I<TYE=T9I;&4B/@H@("`@("`@("`@("`\(2TM
M(')E<V5T(&]F('1H92!A;')E861Y(&-O;&QE8W1E9"!C:&EL9"!H96%D97)S
M("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8V%L
M8RUC:&%P=&5R+6YU;6)E<G,B/@H@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)L979E;"(@<V5L96-T/2(P(B\^"B`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)A8G-O;'5T94-H87!T97),979E;"(^
M"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C86QC+6-H
M87!T97(M;G5M8F5R<R(^"B`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](FQE=F5L(B!S96QE8W0](FYU;6)E<B@D:&5A9&EN9TQE=F5L
M*2(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M(#PO>'-L.G9A<FEA8FQE/@H*"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(FAE861I;F<B/@H@("`@("`@("`@("`\(2TM(&YE8V5S<V%R>2!T;R!A<R!)
M1"!F<F]M('1H92!C;VYT96YT('1A8FQE('1O(&=E="!T:&4@8V]R<F5C="!H
M96%D:6YG(&5L96UE;G0@*'1H92!B=6=G>2!54DP@=7-E9"!A<R!)1"DM+3X*
M("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB8V]N=&5N="UT86)L
M92UI9"(^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&ES0VAA<'1E<DAE861I;F<B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&-U<G)E;G1#:&%P=&5R240B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^;VYL>2!A(&AE
M861I;F<L(&)U="!N;W0@82!C:&%P=&5R/"]X<VPZ=&5X=#X*("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@/"$M+2!N;R!O9B!T:&4@=7-E9"!C:&EL9"P@;F5C97-S87)Y
M(&9O<B!Q=6EC:R!F:6YD:6YG(&]F(&-H87!T97)S(&]F(&YE>'0@9FEL92`@
M+2T^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F-H:6QD+61O
M8W5M96YT+6YO(CX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D:7-.97=&:6QE(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(B1C=7)R96YT0VAI;&1.;R`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)&-U<G)E;G1#:&EL9$YO(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#PA+2T@
M=&AE(%523"!O9B!T:&4@8VAI;&0@9&]C=6UE;G0@<V]U<F-E+"!C;VYT86EN
M:6YG('1H92!H96%D:6YG("TM/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)F:6QE+75R;"(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB)&YE=T-H:6QD55),(B\^"B`@("`@("`@("`@(#PO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB
M;W5T+69I;&4M=7)L(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D;W5T1FEL95523"(O/@H@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FQE=F5L
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D:&5A
M9&EN9TQE=F5L(B\^"B`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB=&ET;&4B/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1H96%D:6YG5&ET;&4B
M+SX*("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\
M>'-L.F%T=')I8G5T92!N86UE/2)E;F-O9&5D+71I=&QE(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8W5R<F5N=$-H:6QD2&5A
M9&EN9R]`96YC;V1E9"UT:71L92(O/@H@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F%B<V]L
M=71E+6-H87!T97(M;&5V96PB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](B1A8G-O;'5T94-H87!T97),979E;"(O/@H@("`@("`@
M("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*
M"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N="`A/2`D8W5R
M<F5N=$AE861I;F=.;R(^"B`@("`@("`@("`@("`@("`\(2TM('!R;V-E9&4@
M87,@;&]N9R!T:&4@;&ES="!O9B!C:&EL9')E;B!I<VXG;G0@=V]R:V5D('1H
M<F]U9V@@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&ES0VAA<'1E<DAE861I
M;F<B/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&=L;V)A;"!V87)I
M86)L97,@:&%V92!T;R!B92!S970L('-O('1H92!F;W(M96%C:"!L;V]P(&-A
M;B!A8V-E<W,@=&AE;2`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=S>&=H96QP97(Z<V5T+6AE
M861I;F<M;F\G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](G-X9VAE;'!E<CIS970M:&5A9&EN9RUN
M;R@D8W5R<F5N=$AE861I;F=.;R`K(#$I(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D:7-.97=&:6QE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](G-X9VAE;'!E<CIS970M8W5R<F5N="UC:&EL9"UN;R@D8W5R
M<F5N=$-H:6QD3F\@*R`Q*2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.G-E
M="UC=7)R96YT+6-H:6QD+75R;"AS=')I;F<H)&YE=T-H:6QD55),*2DB+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N
M+6%V86EL86)L92@G:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG
M0VAI;&14<F%N<V9O<FUE<BYS971(96%D:6YG3F\G*2(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FIA
M=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M
M97(N<V5T2&5A9&EN9TYO*"1C=7)R96YT2&5A9&EN9TYO("L@,2DB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](B1I
M<TYE=T9I;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L
M="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS971#=7)R96YT0VAI;&1.
M;R@D8W5R<F5N=$-H:6QD3F\@*R`Q*2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB:F%V83IC
M;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14<F%N<V9O<FUE<BYS
M971#=7)R96YT0VAI;&15<FPH)&YE=T-H:6QD55),*2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PA+2T@;F]T(&$@8VAA<'1E<B!H96%D
M:6YG+"!C86QL(&ET<V5L9B!U;G1I;"!A(&-H87!T97(@<F5F(&ES(&9O=6YD
M(&]R('1H92!E;F0@;V8@:&5A9&EN9W,@:7,@<F5A8VAE9"`M+3X*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G-E
M87)C:$AE861I;F=);D-H:6QD1&]C=6UE;G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-H87!T97)2969S
M(B`@("`@("`@('-E;&5C=#TB)&-H87!T97)2969S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8VAI;&1R
M96Y(96%D:6YG<R(@("`@<V5L96-T/2(D8VAI;&1R96Y(96%D:6YG<R(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-U<G)E;G1#:&%P=&5R4F5F3F\B('-E;&5C=#TB)&-U<G)E;G1#:&%P
M=&5R4F5F3F\B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C=7)R96YT2&5A9&EN9TYO(B`@("!S96QE8W0]
M(B1C=7)R96YT2&5A9&EN9TYO("L@,2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G1#:&EL9%52
M3"(@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9%523"(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E
M;G1#:&EL9$YO(B`@("`@('-E;&5C=#TB)&-U<G)E;G1#:&EL9$YO(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX
M<VPZ:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.FUE<W-A9V4^06QL(&-H:6QD(&1O8W5M96YT<R!H879E(&)E96X@
M=V%L:V5D('1H<F]U9V@@=VET:&]U="!F:6YD:6YG('1H92!C:&%P=&5R(&YA
M;64A/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.FUE
M<W-A9V4^("`@("`@(&-H:6QD<F5N2&5A9&EN9W,O:&5A9&EN9RUC;W5N=#H@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C:&EL9')E;DAE861I;F=S+VAE
M861I;F<M8V]U;G0B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ;65S<V%G93X@("`@("`@8W5R<F5N=$AE861I;F=.;SH@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&-U<G)E;G1(
M96%D:6YG3F\B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ:68^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\
M+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"@H)/"$M+2!#
M:&%P=&5R<R!F<F]M('1H92!#;VYT96YT(%1A8FQE(&AA=F4@8W5R<F5N=&QY
M(&YO(&%N8VAO<B!T;R!C:&EL9"!D;V-U;65N=',@:6X@3T]O(%A-3"X*"0D@
M07,@<V]L=71I;VXL('=H96YE=F5R(&$@82!G;&]B86P@9&]C=6UE;G0@(&5V
M97)Y(&AE861E<B!O9B!T:&4@2%1-3"!O=71P=70@9V5T<R!G970G<R!A;B!A
M;F-H;W(@:6X@=&AE(%1H97)E9F]R92TM/@H@("`@/'AS;#IT96UP;&%T92!N
M86UE/2)E;F-O9&4M<W1R:6YG(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F5N8V]D:6YG(B!S96QE8W0](B=55$8M."<B+SX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](G1E>'14;T)E16YC;V1E9"(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G=7)L96YC;V1E<CIE;F-O9&4G*2(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB=7)L96YC;V1E<CIE;F-O9&4H;F]R
M;6%L:7IE+7-P86-E*"1T97AT5&]"945N8V]D960I+"1E;F-O9&EN9RDB+SX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G:F%V83IJ879A+FYE="Y54DQ%
M;F-O9&5R+F5N8V]D92<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)J879A.FIA=F$N;F5T+E523$5N8V]D97(N96YC;V1E*'-T
M<FEN9RAN;W)M86QI>F4M<W!A8V4H)'1E>'14;T)E16YC;V1E9"DI+'-T<FEN
M9R@D96YC;V1I;F<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"B`@
M("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@(%1204Y3
M1D]234%424].($]&($%,3"!#2$E,1"!$3T-5345.5%,@3T8@5$A%($=,3T)!
M3"!$3T-5345.5%,@0ED@55-)3D<@02!%6%1%4DY!3"!(14Q015(@0TQ!4U,@
M("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*"3PA+2T@
M82!N97<@96QE;65N="`G8V]N=&5N=%1A8FQE2&5A9&EN9W,G('=I;&P@8F4@
M861D960@=&\@=&AE(&AE;'!E<B!V87)I86)L92!T:&4@9FER<W0@=&EM92!A
M(&-H:6QD('=I;&P@8F4@=')A;G-F;W)M960@+2T^"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](G1R86YS9F]R;2UG;&]B86PM9&]C=6UE;G0M86YD+6-H:6QD
M<F5N(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O8V]N=&5N="UT
M86)L92UH96%D:6YG<R(^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB<W1A<G0M8VAI;&0M=')A;G-F;W)M871I;VXB/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H)("`@("`@("`@("`@/"$M+2!4:&4@;F5C97-S87)Y(&%U>&EL:6%R>2!V
M87)I86)L92!H87-N)W0@8G5I;&0@>65T+@H)("`@("`@("`@("`@5&AI<R!V
M87)I86)L92!G;VYN82!S=&]R92!A;&P@:&5A9&5R<R`H=VET:"!C:&%P=&5R
M(&YU;6)E<G,I(&%N9"!T:&4@55),(&]F('1H96ER(&9I;&5S("TM/@H*("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)#<F5A=&4M
M:&5L<&5R+79A<FEA8FQE<RUF;W(M0V]N=&5N="U486)L92(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*"3QX<VPZ=&5M<&QA=&4@;F%M93TB<W1A
M<G0M<V5L9BUA;F0M8VAI;&1R96XM=')A;G-F;W)M871I;VXB/@H@("`@("`@
M(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*("`@
M("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)D96)U9RUC;VYT96YT+71A8FQE
M+6AE861I;F=S+79A<FEA8FQE(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C
M;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^4&%R<VEN9R!T
M:&4@9VQO8F%L(&1O8W5M96YT+BXN/"]X<VPZ;65S<V%G93X*("`@("`@("`\
M+WAS;#II9CX*"B`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*"B`@("`@("`@/'AS;#II9B!T97-T
M/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y087)S:6YG('1H92!C:&EL
M9"!D;V-U;65N=',N+BX\+WAS;#IM97-S86=E/CPO>'-L.FEF/@H@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)S=&%R="UC:&EL9"UT<F%N<V9O
M<FUA=&EO;B(^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"@D\+WAS;#IT
M96UP;&%T93X*"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G-T87)T+6-H
M:6QD+71R86YS9F]R;6%T:6]N(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#II9B!T97-T
M/2(D:7-$96)U9TUO9&4B/CQX<VPZ;65S<V%G93Y3=&%R=&EN9R!T:&4@8VAI
M;&0@=')A;G-F;W)M871I;VYS+BXN/"]X<VPZ;65S<V%G93X\+WAS;#II9CX*
M"B`@("`@("`@/"$M+2!!<R!T:&4@8VAI;&1S(&]F(&$@9VQO8F%L(&1O8W5M
M96YT("AW:71H('-U9F9I>"`N<WAG*2!D;R!N;W0@:VYO=R!A;GET:&EN9R!A
M8F]U="!T:&5I<B!G;&]B86P@<&%R96YT+`H@("`@("`@("`@("!T:&4@=')A
M;G-F;W)M871I;VX@;V8@9VQO8F%L(&1O8W5M96YT<R!C:&EL9')E;B!H879E
M('1O(&)E(&1O;F4@:6UP;&EZ:70N"B`@("`@("`@("`@($]T:&5R=VES92!T
M:&4@8VAA<'1E<B!N=6UB97(@;V8@=&AE(&-H:6QD<F5N('=I;&P@86QW87ES
M('-T87)T('=I=&@@>F5R;RP@87,@=&AE>2!D;R!N;W0@:VYO=R!A;GET:&EN
M9R!A8F]U="!T:&4*("`@("`@("`@("`@<')O8V5D:6YG(&-H87!T97)S+@H@
M("`@("`@("`@("!&=7)T:&5R;6]R92P@=&AE>2!D;VXG="!H879E(&%N>2!L
M:6YK<R!A8F]U="!P<F5C965D:6YG(&%N9"!F;VQL;W=I;F<@9&]C=6UE;G1S
M(&%N9"!N;R!L:6YK:6YG(&9O<B!U<V%B:6QI='D@<F5A<V]N<PH@("`@("`@
M("`@("!C;W5L9"!B92!D;VYE+B!4:&5R969O<F4@=&AE(&-H:6QD<F5N(&AA
M=F4@=&\@8F4@=')A;G-F;W)M960@9'5R:6YG('1H92!T<F%N<V9O<FUA=&EO
M;B!O9B!A(&=L;V)A;"`H<WAG*2!D;V-U;65N="`M+3X*"0D\>'-L.FEF('1E
M<W0](B1I<T1E8G5G36]D92(^"B`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1C;VQL96-T961';&]B
M86Q$871A+V-O;G1E;G0M=&%B;&4M:&5A9&EN9W,B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;65S<V%G93Y#;VYT96YT86)L92!D871A(&5X:7-T<R!A
M<R!G;&]B86P@9&%T82$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ;65S<V%G93Y.;R!#;VYT96YT86)L
M92!G;&]B86P@9&%T82!E>&ES=',A/"]X<VPZ;65S<V%G93X*("`@("`@("`@
M("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@("`@(#PO>'-L.FEF/@H*("`@("`@("`\(2TM(&-U<G)E;G1L
M>2!T:&ES(&9U;F-T:6]N(&]N;'D@=V]R:W,@=VET:"!N;V1E+7-E=',@9G)O
M;2!85"`M+3X*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.G1R
M86YS9F]R;2UC:&EL9')E;B<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ;65S
M<V%G93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB<WAG:&5L<&5R.G1R86YS9F]R;2UC:&EL9')E;B@@)&-O;&QE8W1E9$=L
M;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R:6YG*"1J87)E9%)O;W154DPI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=')I;F<H)&%B<V]L=71E4V]U<F-E1&ER
M4F5F*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG*"1O<'1I
M;VYA;%523%-U9F9I>"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<FEN9R@D9'!I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG
M*"1O=71P=714>7!E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&ES
M1&5B=6=-;V1E*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\>'-L.FUE<W-A9V4^2F%V82!M971H
M;V0@=')A;G-F;W)M0VAI;&1R96X@=&\@=')A;G-F;W)M(&%L;"!C:&EL9')E
M;B!O9B!A(&=L;V)A;"!D;V-U;65N="!C;W5L9"!N;W0@8F4@9F]U;F0N($)E
M('-U<F4@=&\@=7-E('1H92!85"!P<F]C97-S;W(N/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ
M*B`@0W)E871I;VX@;V8@:&5L<&5R('9A<FEA8FQE(&]F('1H92!H96%D:6YG
M<R!O9B!A;&P@8VAI;&1R96X@9&]C=6UE;G1S("`J*BH@+2T^"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@
M(#QX<VPZ=&5M<&QA=&4@;6%T8V@](B\J+V]F9FEC93IB;V1Y+W1E>'0Z<V5C
M=&EO;B(@;6]D93TB8W)E871I;VXM;V8M=F%R:6%B;&4B/@H@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G971#:&EL9%)O;W1.;V1E(B\^"@H@
M("`@("`@(#PA+2T@869T97(@=&AE(&QA<W0@8VAI;&0@9&]C=6UE;G0@=&AE
M(&=L;V)A;"!D;V-U;65N="!W:6QL(&)E('!A<G-E9"`M+3X*("`@("`@("`\
M>'-L.FEF('1E<W0](G!O<VET:6]N*"D@/2!L87-T*"DB/@H@("`@("`@("`@
M("`\(2TM('-E87)C:"!T:&4@9VQO8F%L(&1O8W5M96YT(&%F=&5R(&%L;"!C
M:&EL9"!D;V-U;65N=',@:&%V92!B965N('-E87)C:&5D"@I/1$L@4$%40T@@
M3D\@24Y$15@@14Q%345.5"!704Y4140@(2$@+2!N=6QL('!O:6YT97(@97AC
M97!T:6]N"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G
M9710<F5V:6]U<TAE861E<DYO(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)F:6QE55),(B`@("`@("`@("`@("`@("`@('-E;&5C
M=#TB)&-O;G1E;G1486)L95523"(O/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F%M;W5N=$]F0W5R<F5N=$AE861I;F<B("`@<V5L
M96-T/2)C;W5N="AF;VQL;W=I;F<M<VEB;&EN9SHZ=&5X=#IH*2(O/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C
M:$9O<DAE861I;F<B("`@<V5L96-T/2)F;VQL;W=I;F<M<VEB;&EN9SHZ=&5X
M=#IH(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"BTM/@H@
M("`@("`@("`@(#PA+2T@9V5T('1H92!O=F5R86QL($YO(&]F($AE861E<G,@
M+2T^"B`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E=$%L
M;$AE861E<DYO(B\^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP
M;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G971#:&EL9%)O;W1.
M;V1E(CX*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](F9I;&554DPB("`@
M('-E;&5C=#TB=&5X=#IS96-T:6]N+7-O=7)C92]`>&QI;FLZ:')E9B(O/@H*
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`)/"$M+2!I9B!A8G-O
M;'5T92!54DP@;W(@86)S;VQU=&4@1$]3(%!!5$@@;W(@86)S;VQU=&4@56YI
M>"!P871H("TM/@H)"0D\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)&9I;&55
M4DPL)R\O)RD@;W(@*'-U8G-T<FEN9R@D9FEL95523"PR+#$I(#T@)SHG*2!O
M<B!S=&%R=',M=VET:"@D9FEL95523"P@)R\G*2(^"B`@("`)"0D\>'-L.G9A
M<FEA8FQE(&YA;64](F-H:6QD4F]O=$YO9&4B('-E;&5C=#TB9&]C=6UE;G0H
M)&9I;&554DPI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB9V5T4')E=FEO=7-(96%D97).;R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&554DPB("`@("`@("`@
M("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@("`@("`@("`@(`D\
M(2TM($Y/(&%B<V]L=71E('-O=7)C92!P871H('=I;&P@8F4@861D960@87,@
M<')E9FEX("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)A;6]U;G1/9D-U<G)E;G1(96%D:6YG(B!S96QE8W0](F-O=6YT
M*"1C:&EL9%)O;W1.;V1E+RHO;V9F:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X
M=#IH*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)N;V1E5&]396%R8VA&;W)(96%D:6YG(B!S96QE8W0](B1C:&EL9%)O
M;W1.;V1E+RHO;V9F:6-E.F)O9'DO9&5S8V5N9&%N=#HZ=&5X=#IH(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M(`D)"3QX<VPZ=F%R:6%B;&4@;F%M93TB8VAI;&12;V]T3F]D92(@<V5L96-T
M/2)D;V-U;65N="AC;VYC870H)&%B<V]L=71E4V]U<F-E1&ER4F5F+"<O)RPD
M9FEL95523"DI(B\^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB9V5T4')E=FEO=7-(96%D97).;R(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F9I;&554DPB("`@("`@("`@
M("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@("`@("`@("`@(`D\
M(2TM('1H92!A8G-O;'5T92!S;W5R8V4@<&%T:"!W:6QL(&)E(&%D9&5D(&%S
M('!R969I>"`M+3X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB86UO=6YT3V9#=7)R96YT2&5A9&EN9R(@<V5L96-T/2)C;W5N
M="@D8VAI;&12;V]T3F]D92\J+V]F9FEC93IB;V1Y+V1E<V-E;F1A;G0Z.G1E
M>'0Z:"DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(@<V5L96-T/2(D8VAI;&12
M;V]T3F]D92\J+V]F9FEC93IB;V1Y+V1E<V-E;F1A;G0Z.G1E>'0Z:"(O/@H@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F=E
M=%!R979I;W5S2&5A9&5R3F\B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M9FEL95523"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB;F]D951O4V5A
M<F-H1F]R2&5A9&EN9R(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86UO
M=6YT3V9#=7)R96YT2&5A9&EN9R(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L
M92@G<WAG:&5L<&5R.F=E="UP<F5V:6]U<RUC:&EL9"UD;V-U;65N=',M:&5A
M9&EN9RUC;W5N="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A9&1(96%D:6YG26YF;R(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYO9&54;U-E87)C:$9O<DAE861I
M;F<B("`@<V5L96-T/2(D;F]D951O4V5A<F-H1F]R2&5A9&EN9R(O/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)F:6QE55),
M(B`@("`@("`@("`@("`@("`@('-E;&5C=#TB)&9I;&554DPB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<')E=FEO=7-(
M96%D97(B("`@("`@("`@("!S96QE8W0](G-X9VAE;'!E<CIG970M<')E=FEO
M=7,M8VAI;&0M9&]C=6UE;G1S+6AE861I;F<M8V]U;G0H)&%M;W5N=$]F0W5R
M<F5N=$AE861I;F<I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS
M=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=%!R
M979I;W5S0VAI;&1$;V-U;65N='-(96%D:6YG0V]U;G0G*2(^"B`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D2&5A9&EN9TEN
M9F\B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)N;V1E5&]396%R8VA&;W)(96%D:6YG(B`@('-E;&5C=#TB)&YO9&54;U-E
M87)C:$9O<DAE861I;F<B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB9FEL95523"(@("`@("`@("`@("`@("`@("!S96QE
M8W0](B1F:6QE55),(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](G!R979I;W5S2&5A9&5R(B`@("`@("`@("`@<V5L96-T
M/2)J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E<BY3>&=#:&EL9%1R86YS
M9F]R;65R+F=E=%!R979I;W5S0VAI;&1$;V-U;65N='-(96%D:6YG0V]U;G0H
M)&%M;W5N=$]F0W5R<F5N=$AE861I;F<I(B\^"B`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@(#PO>'-L.F-H;V]S93X*"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/'AS;#IT96UP;&%T92!N86UE/2)A9&1(96%D:6YG26YF;R(^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)F:6QE55),(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)P<F5V:6]U<TAE861E<B(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB;F]D951O4V5A<F-H1F]R2&5A9&EN9R(O/@H*("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](G!R979I;W5S2&5A9&5R,B(@<V5L96-T/2)N
M=6UB97(H)'!R979I;W5S2&5A9&5R*2(O/@H@("`@("`@(#QX<VPZ9F]R+65A
M8V@@<V5L96-T/2(D;F]D951O4V5A<F-H1F]R2&5A9&EN9R(^"@H@("`@("`@
M("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1I=&QE(B!S96QE8W0](FYO<FUA
M;&EZ92US<&%C92@N*2(O/@H*("`@("`@("`@("`@/'AS;#IV87)I86)L92!N
M86UE/2)E;F-O9&5D5&ET;&4B/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](F5N8V]D92US=')I;F<B/@H@("`@("`@("`@("`@
M("`@("`@(#PA+2T@=&AE('-P86-E(&AA<R!T;R!B92!N;W)M86QI>F5D+`H@
M("`@("`@("`@("`@("`@("`@("`@("!O=&AE<G=I<V4@86X@:6QL96=A;"!A
M<F=U;65N="!E>&-E<'1I;VX@=VEL;"!B92!T:')O=VX@9F]R(%A4+2T^"B`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T97AT
M5&]"945N8V]D960B('-E;&5C=#TB)'1I=&QE(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IV87)I
M86)L93X*"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)H96%D:6YG
M(CX*("`@("`@("`@("`@("`@(#PA+2T@;V1D(&)U="`G9&5S8V5N9&%N=#IT
M97AT*"DG(&1I9&XG="!W;W)K+"!B=70@)RXG+"!T;R!G970@86QL('1E>'0@
M;F]D97,@;V8@=&AE(&AE861E<B`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ
M871T<FEB=71E(&YA;64](G1I=&QE(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)'1I=&QE(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@/'AS
M;#IA='1R:6)U=&4@;F%M93TB96YC;V1E9"UT:71L92(^/'AS;#IV86QU92UO
M9B!S96QE8W0](B1E;F-O9&5D5&ET;&4B+SX\+WAS;#IA='1R:6)U=&4^"B`@
M("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)L979E;"(^/'AS
M;#IV86QU92UO9B!S96QE8W0](D!T97AT.FQE=F5L(B\^/"]X<VPZ871T<FEB
M=71E/@H@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB9FEL
M92UU<FPB/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D9FEL95523"(O/CPO>'-L
M.F%T=')I8G5T93X*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA
M;64](FAE861E<BUN;R(^/'AS;#IV86QU92UO9B!S96QE8W0](G!O<VET:6]N
M*"D@*R`D<')E=FEO=7-(96%D97(R(B\^/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F=E=$%L;$AE861E<DYO(CX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H
M)W-X9VAE;'!E<CIG970M86QL+6-H:6QD+61O8W5M96YT<RUH96%D:6YG+6-O
M=6YT)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F%D9$%L;$AE861E<DYO16QE;65N="(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$AE861E<B(@("!S96QE8W0]
M(G-X9VAE;'!E<CIG970M86QL+6-H:6QD+61O8W5M96YT<RUH96%D:6YG+6-O
M=6YT*"DB+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R
M+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T06QL0VAI;&1$
M;V-U;65N='-(96%D:6YG0V]U;G0G*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB861D06QL2&5A9&5R3F]%;&5M96YT(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL
M2&5A9&5R(B`@('-E;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP
M97(N4WAG0VAI;&14<F%N<V9O<FUE<BYG971!;&Q#:&EL9$1O8W5M96YT<TAE
M861I;F=#;W5N="@I(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#QX<VPZ=&5M<&QA
M=&4@;F%M93TB861D06QL2&5A9&5R3F]%;&5M96YT(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F%L;$AE861E<B(O/@H*("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB:&5A9&EN9RUC;W5N="(^"B`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2(D86QL2&5A9&5R(B\^"B`@("`@("`@/"]X<VPZ96QE
M;65N=#X*"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2`J*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@($-R96%T:6]N(&]F(&$@;&EN92!O
M9B!L:6YK<R!A="!T:&4@8F5G:6YN:6YG(&%N9"!E;F0@;V8@82!C:&EL9"!D
M;V-U;65N="!T;R!E;FAA;F-E('5S86)I;&ET>2`@*BHJ("TM/@H@("`@/"$M
M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB
M861D+6-H:6QD+61O8W5M96YT+75S86)I;&ET>2UL:6YK<R(^"B`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](F-E;G1E<B(^"B`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)S;6%L;"(^"B`@("`@("`@("`@("`@("`\>'-L.G1E
M>'0^6R`\+WAS;#IT97AT/@H*"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](F=L;V)A;$1O8W5M96YT1&ER(B!S96QE8W0](G-X9VAE;'!E
M<CIG970M9VQO8F%L+61O8W5M96YT+61I<B@I(B\^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](F-U<G)E;G1#:&EL9$YO(B!S96QE8W0]
M(FYU;6)E<B@D8V]N=&5N=%1A8FQE2&5A9&EN9W,O:&5A9&EN9ULD9VQO8F%L
M1&]C=6UE;G129694;T-U<G)E;G1&:6QE(#T@0&9I;&4M=7)L72]`8VAI;&0M
M9&]C=6UE;G0M;F\I(B\^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE
M(&YA;64](F5A<FQI97)$;V-54DPB('-E;&5C=#TB)&-O;G1E;G1486)L94AE
M861I;F=S+VAE861I;F=;*"1C=7)R96YT0VAI;&1.;R`M(#$I(#T@0&-H:6QD
M+61O8W5M96YT+6YO72]`;W5T+69I;&4M=7)L(B\^"CPA+2T*/'AS;#IM97-S
M86=E/F9R;VTZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D9VQO8F%L1&]C=6UE
M;G129694;T-U<G)E;G1&:6QE(B\^/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S
M86=E/G1O.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&5A<FQI97)$;V-54DPB
M+SX\+WAS;#IM97-S86=E/@H\>'-L.FUE<W-A9V4^27,Z(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S;W5R8V5&:6QE
M4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O0W5R<F5N=$9I;&4B
M+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M=&%R9V5T1FEL95)E9B(@<V5L96-T/2(D96%R;&EE<D1O8U523"(O/@H@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"CPO>'-L.FUE<W-A
M9V4^+2T^"@H*("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&5A<FQI
M97)$;V-54DPB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U
M=&4@;F%M93TB:')E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M(2TM('=H96X@=&AE(&QI;FMS('-T87)T<R!W:71H(&$@)R,G(&ET)W,@82!L
M:6YK('1O('1H92!#;VYT96YT(%1A8FQE+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB<W1A<G1S+7=I=&@H)&5A<FQI
M97)$;V-54DPL("<C)RDB/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E="UR96QA=&EV
M92UF:6QE+7)E9B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V]U<F-E1FEL95)E9B(@
M<V5L96-T/2(D9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB=&%R9V5T1FEL95)E9B(@<V5L96-T/2(N(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM
M=&5M<&QA=&4^"CPA+2T@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;VYC870H)&-O;G1E;G1486)L95523"P@)&5A<FQI97)$;V-54DPI(B\^+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)G970M<F5L871I=F4M9FEL92UR968B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E;&5C=#TB)&=L;V)A
M;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G1A<F=E=$9I;&52968B('-E;&5C=#TB)&5A<FQI97)$;V-54DPB+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*/"$M+0H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D9VQO8F%L1&]C
M=6UE;G1$:7(L("1E87)L:65R1&]C55),*2(O/BTM/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^4')E=FEO=7,@9&]C=6UE;G0\+WAS;#IT97AT
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=&5X=#X@?"`\+WAS;#IT97AT/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M
M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB
M=71E(&YA;64](FAR968B/@H@("`@("`@("`@("`@("`@("`@("`@("`\(2TM
M('=H96X@9VQO8F%L1&]C=6UE;G129694;T-U<G)E;G1&:6QE(&ES('5N<V5T
M('1H92!C=7)R96YT(&9I;&4@:7,@=&AE($-O;G1E;G0@5&%B;&4M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&=L;V)A;$1O8W5M
M96YT4F5F5&]#=7)R96YT1FEL92(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C;VYT96YT5&%B;&5$:7(B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB9V5T+6YA;64M;V8M=&%B;&4M;V8M8V]N=&5N
M="UD;V-U;65N="(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I
M;&4M<F5F(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-O=7)C949I;&52968B('-E;&5C=#TB
M)&=L;V)A;$1O8W5M96YT4F5F5&]#=7)R96YT1FEL92(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB=&%R9V5T1FEL95)E9B(@<V5L96-T/2(D8V]N=&5N=%1A8FQE1&ER(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H
M96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M(SPO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H
M;V]S93X*"CPA+2T@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@
M<V5L96-T/2(D8V]N=&5N=%1A8FQE55),(B\^+2T^"B`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=&5X=#Y#;VYT96YT(%1A8FQE/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB;F5X=$1O8U523"(@<V5L96-T/2(D8V]N=&5N=%1A8FQE
M2&5A9&EN9W,O:&5A9&EN9ULH)&-U<G)E;G1#:&EL9$YO("L@,2D@/2!`8VAI
M;&0M9&]C=6UE;G0M;F]=+T!O=70M9FEL92UU<FPB+SX*("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB)&YE>'1$;V-54DPB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#X@?"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IA='1R:6)U=&4@;F%M93TB:')E9B(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM('=H96X@=&AE(&QI;FMS('-T87)T
M<R!W:71H(&$@)R,G(&ET)W,@82!L:6YK('1O('1H92!#;VYT96YT(%1A8FQE
M+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB<W1A<G1S+7=I=&@H)&YE>'1$;V-54DPL("<C)RDB/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N=%)E9E1O
M0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&:6QE4F5F
M(B!S96QE8W0](BXB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*/"$M+2`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A
M="@D8V]N=&5N=%1A8FQE55),+"`D;F5X=$1O8U523"DB+SXM+3X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9V5T+7)E;&%T:79E+69I;&4M<F5F(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)S;W5R8V5&:6QE4F5F(B!S96QE8W0](B1G;&]B86Q$;V-U;65N
M=%)E9E1O0W5R<F5N=$9I;&4B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T87)G971&
M:6QE4F5F(B!S96QE8W0](B1N97AT1&]C55),(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"CPA
M+2T@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB8V]N8V%T*"1G;&]B86Q$;V-U;65N=$1I<BP@)&YE>'1$
M;V-54DPI(B\^+2T^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA
M='1R:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#Y.
M97AT(&1O8W5M96YT/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@
M("`@("`@("`@("`\>'-L.G1E>'0^(%T\+WAS;#IT97AT/@H@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)G970M
M<F5L871I=F4M9FEL92UR968B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB
M<V]U<F-E1FEL95)E9B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=&%R
M9V5T1FEL95)E9B(O/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L
M<&5R.F=E="UR96QA=&EV92UF:6QE+7)E9B<I(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>&=H96QP97(Z9V5T+7)E;&%T:79E
M+69I;&4M<F5F*'-T<FEN9R@D<V]U<F-E1FEL95)E9BDL('-T<FEN9R@D=&%R
M9V5T1FEL95)E9BDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA
M=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M
M97(N9V5T4F5L871I=F5&:6QE4F5F)RDB/@H@("`@("`@("`@("`@("`@/'AS
M;#IV86QU92UO9B!S96QE8W0](FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L
M<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N9V5T4F5L871I=F5&:6QE4F5F*'-T
M<FEN9R@D<V]U<F-E1FEL95)E9BDL('-T<FEN9R@D=&%R9V5T1FEL95)E9BDI
M(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E
M(&YA;64](F=E="UN86UE+6]F+71A8FQE+6]F+6-O;G1E;G0M9&]C=6UE;G0B
M/@H*("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F=E="UN86UE
M+6]F+71A8FQE+6]F+6-O;G1E;G0M9&]C=6UE;G0G*2(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB<WAG:&5L<&5R.F=E="UN86UE
M+6]F+71A8FQE+6]F+6-O;G1E;G0M9&]C=6UE;G0H*2(O/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N
M8W1I;VXM879A:6QA8FQE*"=J879A.F-O;2YS=6XN<W1A<BYX<VQT+FAE;'!E
M<BY3>&=#:&EL9%1R86YS9F]R;65R+F=E=$YA;65/9E1A8FQE3V9#;VYT96YT
M1&]C=6UE;G0G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB:F%V83IC;VTN<W5N+G-T87(N>'-L="YH96QP97(N4WAG0VAI;&14
M<F%N<V9O<FUE<BYG971.86UE3V9486)L94]F0V]N=&5N=$1O8W5M96YT*"DB
M+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O
M<V4^"@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"3QX<VPZ=&5M<&QA=&4@;F%M
M93TB9&5B=6<M8V]N=&5N="UT86)L92UH96%D:6YG<RUV87)I86)L92(^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^
M"@H@("`@("`@(#QX<VPZ;65S<V%G93X\>'-L.G1E>'0^*BHJ*B!42$4@2$5!
M1$E.1R!605))04),12`J*BHJ(#PO>'-L.G1E>'0^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`\>'-L.FUE<W-A9V4^8V]N=&5N="UT86)L92UU<FPZ(#QX<VPZ
M=F%L=64M;V8@<V5L96-T/2)C;VQL96-T961';&]B86Q$871A+V-O;G1E;G0M
M=&%B;&4M:&5A9&EN9W,O8V]N=&5N="UT86)L92UU<FPB+SX\+WAS;#IM97-S
M86=E/@H*("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$O8V]N=&5N="UT86)L92UH96%D:6YG<R]H96%D:6YG(CX*
M("`@("`@("`@("`@/'AS;#IM97-S86=E/CQX<VPZ=&5X=#XJ*BHJ(&YE=R!H
M96%D:6YG.B`@("`@("`@/"]X<VPZ=&5X=#X\+WAS;#IM97-S86=E/@H@("`@
M("`@("`@("`\>'-L.FUE<W-A9V4^8V]N=&5N="UT86)L92UI9#H@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB0&-O;G1E;G0M=&%B;&4M:60B+SX\+WAS
M;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^8VAI;&0M9&]C
M=6UE;G0M;F\Z("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&-H:6QD+61O
M8W5M96YT+6YO(B\^/"]X<VPZ;65S<V%G93X*("`@("`@("`@("`@/'AS;#IM
M97-S86=E/F9I;&4M=7)L.B`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](D!F:6QE+75R;"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@
M(#QX<VPZ;65S<V%G93YO=70M9FEL92UU<FPZ("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)`;W5T+69I;&4M=7)L(B\^/"]X<VPZ;65S<V%G93X*
M("`@("`@("`@("`@/'AS;#IM97-S86=E/FQE=F5L.B`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!L979E;"(O/CPO>'-L.FUE<W-A
M9V4^"B`@("`@("`@("`@(#QX<VPZ;65S<V%G93YT:71L93H@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)`=&ET;&4B+SX\+WAS;#IM
M97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^96YC;V1E9"UT:71L
M93H@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&5N8V]D960M=&ET
M;&4B+SX\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M86)S;VQU=&4M8VAA<'1E<BUL979E;#H\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M0&%B<V]L=71E+6-H87!T97(M;&5V96PB+SX\+WAS;#IM97-S86=E/@H@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H*"3PO>'-L.G1E;7!L871E/@H*"@D\(2TM
M(%1O(&UA:V4@=&AE(&AE861I;F=S('5N:7%U92P@=&AE(&%B<V]L=71E(&AE
M861I;F<@:7,@861D960@=&\@=&AE;0H)("`@("!%+F<N(%1H92!L979E;"`Q
M+C(N,RXT+B!W;W5L9"!R97-U;'0@:6YT;R!A(#$K,BLS*S0@<W1R:6YG("TM
M/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C86QC+6-H87!T97(M;G5M8F5R
M<R(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)L979E;"(O/@H*("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U
M;F-T:6]N+6%V86EL86)L92@G<WAG:&5L<&5R.F-A;&,M8VAA<'1E<BUN=6UB
M97)S)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G-X9VAE;'!E<CIC86QC+6-H87!T97(M;G5M8F5R<R@D;&5V96PI(B\^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)VIA=F$Z8V]M+G-U;BYS=&%R+GAS
M;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F;W)M97(N8V%L8T-H87!T97).=6UB
M97)S)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(FIA=F$Z8V]M+G-U;BYS=&%R+GAS;'0N:&5L<&5R+E-X9T-H:6QD5')A;G-F
M;W)M97(N8V%L8T-H87!T97).=6UB97)S*"1L979E;"DB+SX*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X
M<VPZ=&5M<&QA=&4^"@H*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X
M=#IP(B!M;V1E/2)C;VYT96YT+71A8FQE(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1O9F9I
M8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z;F%M92`]
M(&-U<G)E;G0H*2]`=&5X=#IS='EL92UN86UE72]S='EL93IP<F]P97)T:65S
M+W-T>6QE.G1A8BUS=&]P<R(O/@H*("`@("`@("`\>'-L.F5L96UE;G0@;F%M
M93TB=&%B;&4B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)B
M;W)D97(B/C`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](F-L87-S(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1E
M>'0Z<W1Y;&4M;F%M92(O/CPO>'-L.F%T=')I8G5T93X*/"$M+0H\>'-L.FUE
M<W-A9V4^*BHJ*BHJ*BHJ/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S86=E/E-T
M>6QE;F%M93H\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M
M92(O/CPO>'-L.FUE<W-A9V4^"CQX<VPZ;65S<V%G93YP;W-I=&EO;CH@/'AS
M;#IV86QU92UO9B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y;&5S+W-T
M>6QE.G1A8BUS=&]P*2(O/CPO>'-L.FUE<W-A9V4^"BTM/@H*("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](F-O;&=R;W5P(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M8V]L+65L96UE
M;G0B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)L87-T3F]D95!O<VET:6]N(B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P
M4W1Y;&5S+W-T>6QE.G1A8BUS=&]P*2(O/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE
M8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*
M"B`@("`@("`@("`@(#PA+2T@86QL(&5L96UE;G1S(&)E9F]R92!T:&4@9FER
M<W0@=&%B4W1O<"`M+3X*("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)T97-T3F\M4E1&(CX*("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M
M<&QA=&5S('-E;&5C=#TB;F]D92@I(B!M;V1E/2)C96QL+6-O;G1E;G0B+SX*
M("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V
M86EL86)L92@G>'0Z;F]D92US970G*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A<FEA8FQE(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB>'0Z
M;F]D92US970H)'1E<W1.;RU25$8I(B\^"@D)"3QX<VPZ96QE;65N="!N86UE
M/2)T<B(^"B`@("`@("`@("`@("`@(`D@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](F-R96%T92UT9"UE;&5M96YT<R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB('-E;&5C
M=#TB8V]U;G0H)&%L;%1A8E-T;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W`I(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O
M<VET:6]N(B`@("`@("`@('-E;&5C=#TB,2(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S
M96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G1A8DYO9&50;W-I=&EO;G,B('-E
M;&5C=#TB)'1A8DYO9&50;W-I=&EO;G,B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)F=6YC=&EO;BUA=F%I;&%B;&4H)WAA;&%N.FYO9&5S
M970G*2(^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A
M8DYO9&50;W-I=&EO;G,B('-E;&5C=#TB>&%L86XZ;F]D97-E="@D=&5S=$YO
M+5)41BDB+SX*"0D)/'AS;#IE;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@
M("`@("`@"2`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+71D+65L
M96UE;G1S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB;&%S=$YO9&50;W-I=&EO;B(@<V5L96-T/2)C;W5N="@D86QL5&%B
M4W1O<%-T>6QE<R]S='EL93IT86(M<W1O<"DB+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB("`@("`@("`@
M<V5L96-T/2(Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T
M;W!3='EL97,B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O
M<VET:6]N<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@
M("`@(#PA+2T@/'AS;#IV87)I86)L92!N86UE/2)T86).;V1E4&]S:71I;VYS
M(B!S96QE8W0](GAT.FYO9&4M<V5T*"1T97-T3F\M4E1&*2(O/@H*("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M=&0M96QE;65N=',B
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L
M87-T3F]D95!O<VET:6]N(B!S96QE8W0](F-O=6YT*"1A;&Q486)3=&]P4W1Y
M;&5S+W-T>6QE.G1A8BUS=&]P*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@("`@("`@("!S96QE8W0]
M(C$B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB86QL5&%B4W1O<%-T>6QE<R(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE
M<R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^+2T^"@H*("`@("`@("`\+WAS
M;#IE;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;F%M93TB8W)E871E+6-O;"UE;&5M96YT(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B+SX*"B`@("`@("`@/'AS
M;#IF;W(M96%C:"!S96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE.G1A
M8BUS=&]P(CX*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F-O;"(^
M"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.B`\+WAS;#IT
M97AT/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)G<F%P+6-E;&PM=VED=&@B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB("`@("`@("`@<V5L
M96-T/2)P;W-I=&EO;B@I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0]
M(B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\+WAS
M;#IF;W(M96%C:#X*"B`@("`\+WAS;#IT96UP;&%T93X*/"$M+0I38V5N87)I
M;W,@=&%B<W1O<',*"C$I('-T>6QE.G1Y<&4@;V8@<W1Y;&4Z=&%B+7-T;W`@
M:7,@)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(&YO="!R:6=H=`H@
M+3X@16%R;&EE<B!T97AT+6YO9&5S(&%N9"!F;VQL;W=I;F<@=&5X="UN;V1E
M<RP@=VEL;"!B92!P=70@:6YT;R!A;B!I;FYE<B!T86)L92P@=VET:"!T=V\@
M5$0@9FER<W0@86QI9VYE9"!L969T+"!W:71H('!R;V-E9&EN9R!T97AT;F]D
M97,L('1H92!L871T97(@86QI9VYE9"!R:6=H="X*"C(I('-T>6QE.G1Y<&4@
M:7,@)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(')I9VAT"B`M/B!F
M;VQL;W=I;F<@=&5X="UN;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A(')I9VAT
M(&%L:6=N960@5$0*"C,I('-T>6QE.G1Y<&4@:7,@)VYO;BUR:6=H="<@86YD
M(&5A<FQI97(@=&%B4W1O<"`G;F]N+7)I9VAT)R!A<R!W96QL"B`M/B!P=70@
M=&AE('!R96-E9&EN9R!T86(@<W1O<',@:6YT;R!A(%1$("AL969T(&%L:6=N
M960@:7,@9&5F875L="D*"C0I(&9I<G-T('-T>6QE.G1Y<&4@=V]U;&0@:&%V
M92!N;R!R:6=H="!P<F5C961I9VX@=&%B4W1O<`H@+3X@=V]R:W,@=V5L;"!W
M:71H(&9I<G-T('-C96%N<FEO<R`Q(&%N9"`S"@HU*2!L87-T('-T>6QE.G1Y
M<&4@=V]U;&0@8F4@82!S<&5C:6%L(&-A<V4L(&EF(&ET('=O=6QD(&)E(&QE
M9G0@86QI9VYE9"P@8G5T('1H:7,@=V]N)W0@:&%P<&5N(&EN(&]U<B!C87-E
M+BX@.D0*"E-C96YA<FEO<R!U;FUA=&-H960Z"BT@=&5X=#IS='EL97!O<VET
M:6]N("=C96YT97(G('=I;&P@;F]T(&)E(&UA=&-H960@:6X@;W5R(&-A<V4@
M*&5F9F]R="!F;W(@;F]T:&EN9RDL('1H97)E('=I;&P@8F4@;VYL>2`G<FEG
M:'0G(&%N9"!N;W0@)W)I9VAT)PHM($EF('1H92!L87-T('1A8E-T;W`@:7,@
M;F]T(&9R;VT@=&5X=#IS='EL97!O<W1I;VX@)W)I9VAT)RP@=&AE(&QE;F=T
M:"!O9B!T:&4@;&%S="!C96QL(&ES('5N9&5F:6YE9"!A;F0@82!D;V-U;65N
M="!L96YG=&@@;75S="!B92!F;W5N9"X*("!.;W0@:&%P<&5N<R!I;B!O=7(@
M9VQO8F%L(&1O8W5M96YT(&-A<V4N($%L<V\@=&AE(&%L9V]R:71H;2!B96QO
M=R!W;W5L9"!H879E('1O(&)E(&5X<&%N9&5D("AC<"X@<V-E;F%R:6\@-2DN
M"@HM+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+71D+65L96UE
M;G1S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](FQA<W1.;V1E4&]S
M:71I;VXB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G!O<VET:6]N(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B\^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B\^
M"CPA+2T*/'AS;#IM97-S86=E/BLK*RLK*RLK/"]X<VPZ;65S<V%G93X*/'AS
M;#IM97-S86=E/E!O<VET:6]N.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'!O
M<VET:6]N(B\^/"]X<VPZ;65S<V%G93X*/'AS;#IM97-S86=E/FQA<W1.;V1E
M4&]S:71I;VXZ(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;&%S=$YO9&50;W-I
M=&EO;B(O/CPO>'-L.FUE<W-A9V4^"BTM/@H*("`@("`@("`\>'-L.G9A<FEA
M8FQE(&YA;64](F-U<G)E;G13='EL951Y<&4B('-E;&5C=#TB)&%L;%1A8E-T
M;W!3='EL97,O<W1Y;&4Z=&%B+7-T;W!;)'!O<VET:6]N72]`<W1Y;&4Z='EP
M92(O/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB96%R;&EE<E-T>6QE
M5'EP92(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R]S='EL93IT86(M<W1O
M<%LD<&]S:71I;VX@+2`Q72]`<W1Y;&4Z='EP92(O/@H@("`@("`@(#QX<VPZ
M8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&-U<G)E;G13
M='EL951Y<&4@/2`G<FEG:'0G(CX*("`@("`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D96%R
M;&EE<E-T>6QE5'EP92`]("=R:6=H="<B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\(2TM"B`@("`@("`@("`@("`@("`@("`@("`@(#(I('-T>6QE.G1Y
M<&4@:7,@)W)I9VAT)R!A;F0@96%R;&EE<B!T86)3=&]P(&ES(')I9VAT"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`M/B!F;VQL;W=I;F<@=&5X="UN
M;V1E<RP@=VEL;"!B92!P=70@:6YT;R!A(')I9VAT(&%L:6=N960@5$0@+2T^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T
M9"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)S='EL92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IT97AT/F%L:6=N.B!R:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M9W)A<"UC96QL+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)E;F1I;F=486)3=&]P4&]S:71I;VXB("!S96QE
M8W0](B1P;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;&%S=$YO9&50;W-I=&EO
M;B(@<V5L96-T/2(D;&%S=$YO9&50;W-I=&EO;B(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).
M;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+0H@
M("`@("`@("`@("`@("`@("`@("`@("`Q*2!S='EL93IT>7!E(&]F('-T>6QE
M.G1A8BUS=&]P(&ES("=R:6=H="<@86YD(&5A<FQI97(@=&%B4W1O<"!I<R!N
M;W0@<FEG:'0*("`@("`@("`@("`@("`@("`@("`@("`@("T^($5A<FQI97(@
M=&5X="UN;V1E<R!A;F0@9F]L;&]W:6YG('1E>'0M;F]D97,L('=I;&P@8F4@
M<'5T(&EN=&\@86X@:6YN97(@=&%B;&4L('=I=&@@='=O(%1$(&9I<G-T(&%L
M:6=N960@;&5F="P@=VET:"!P<F]C961I;F<@=&5X=&YO9&5S+"!T:&4@;&%T
M=&5R(&%L:6=N960@<FEG:'0N+2T^"CPA+2T@=F%L:60@2%1-3"!B=70@8G)O
M=W-E<G,@;6%K92!A(&QI;F4@8G)E86L@*&)O<F1E<CTP(&%N9"!P87)A9W)A
M<&AS='EL92!A;'-O(&UI<W-I;F<I.@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB=&%B;&4B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB9W)A<"UC96QL+6-O;G1E;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I
M=&EO;B(@('-E;&5C=#TB)'!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T
M3F]D95!O<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E
M4&]S:71I;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB=&0B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/F%L
M:6=N.B!R:6=H=#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E
M;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB96YD:6YG5&%B4W1O<%!O<VET:6]N(B`@<V5L
M96-T/2(D<&]S:71I;VX@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O
M<VET:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)T86).;V1E4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I
M;VYS(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L
M96UE;G0^"BTM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G1D(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E
M;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E;&5C=#TB)'!O
M<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET:6]N(B!S96QE
M8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)T86).;V1E
M4&]S:71I;VYS(B!S96QE8W0](B1T86).;V1E4&]S:71I;VYS(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T
M93X*/"$M+2!/1$L@1D5!5%5212!.3R!004=%4PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)T9"(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=&5X=#YA;&EG;CH@<FEG:'0\+WAS;#IT97AT/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)G<F%P+6-E;&PM8V]N=&5N="UB969O
M<F4M=&%B+7-T;W`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)E;F1I;F=486)3=&]P4&]S:71I;VXB("!S96QE8W0](B1P
M;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)L87-T3F]D95!O<VET
M:6]N(B!S96QE8W0](B1L87-T3F]D95!O<VET:6]N(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET
M:6]N<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^("`@("`@("`@("TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E87)L:65R
M4W1Y;&54>7!E(#T@)W)I9VAT)R(^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`\(2TM"B`@("`@("`@("`@("`@("`@("`@
M("`@,RD@<W1Y;&4Z='EP92!I<R`G;F]N+7)I9VAT)R!A;F0@96%R;&EE<B!T
M86)3=&]P("=N;VXM<FEG:'0G(&%S('=E;&P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("T^('!U="!T:&4@<')E8V5D:6YG('1A8B!S=&]P<R!I;G1O
M(&$@5$0@*&QE9G0@86QI9VYE9"!I<R!D969A=6QT*2`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1D(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)G<F%P+6-E;&PM8V]N=&5N="UB969O<F4M=&%B+7-T;W`B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(@('-E
M;&5C=#TB)'!O<VET:6]N(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.;V1E4&]S:71I;VXB
M('-E;&5C=#TB)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=&%B3F]D
M95!O<VET:6]N<R(@<V5L96-T/2(D=&%B3F]D95!O<VET:6]N<R(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@(#QX<VPZ:68@=&5S=#TB
M)'!O<VET:6]N("$]("1L87-T3F]D95!O<VET:6]N(CX*("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UT9"UE;&5M96YT<R(^
M"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C
M=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O
M/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FQA<W1.
M;V1E4&]S:71I;VXB('-E;&5C=#TB)&QA<W1.;V1E4&]S:71I;VXB+SX*("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@
M("`@("`@("!S96QE8W0](B1P;W-I=&EO;B`K(#$B+SX*("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S
M96QE8W0](B1A;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(@<V5L96-T
M/2(D=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB9W)A<"UC96QL+6-O;G1E
M;G0M8F5F;W)E+71A8BUS=&]P(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F5N9&EN9U1A8E-T;W!0;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB=&%B3F]D95!O<VET:6]N<R(O/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB;&%S=$YO9&50;W-I=&EO;B(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1E;F1I;F=486)3
M=&]P4&]S:71I;VX@/2`Q(CX*("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM
M=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B('-E;&5C=#TB;F]D92@I
M6W!O<VET:6]N*"D@)FQT.R`D=&%B3F]D95!O<VET:6]N<R]T86(M<W1O<"UN
M;V1E+7!O<VET:6]N6R1E;F1I;F=486)3=&]P4&]S:71I;VY=72(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(B1E;F1I;F=486)3=&]P4&]S:71I;VX@/B`D;&%S=$YO9&50;W-I=&EO;B(^
M"B`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!M;V1E/2)C
M;VYT96YT+71A8FQE(B!S96QE8W0](FYO9&4H*5MP;W-I=&EO;B@I(#X@)'1A
M8DYO9&50;W-I=&EO;G,O=&%B+7-T;W`M;F]D92UP;W-I=&EO;ELD96YD:6YG
M5&%B4W1O<%!O<VET:6]N("T@,5U=(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L
M96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@
M/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#QX<VPZ87!P;'DM=&5M<&QA=&5S(&UO9&4](F-O;G1E;G0M=&%B;&4B('-E
M;&5C=#TB;F]D92@I6W!O<VET:6]N*"D@)FQT.R`D=&%B3F]D95!O<VET:6]N
M<R]T86(M<W1O<"UN;V1E+7!O<VET:6]N6R1E;F1I;F=486)3=&]P4&]S:71I
M;VY=75MP;W-I=&EO;B@I(#X@)'1A8DYO9&50;W-I=&EO;G,O=&%B+7-T;W`M
M;F]D92UP;W-I=&EO;ELD96YD:6YG5&%B4W1O<%!O<VET:6]N("T@,5U=(CX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L
M;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T
M82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!M
M;V1E/2)C;VYT96YT+71A8FQE(B!M871C:#TB=&5X=#IS(CX*("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E
M<W!A8V4B/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=VAI
M=&5S<&%C97,B('-E;&5C=#TB0'1E>'0Z8R(O/@H@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/'AS;#IT
M96UP;&%T92!M871C:#TB*B(@;6]D93TB8V5L;"UC;VYT96YT(CX*"B`@("`@
M("`@/'AS;#II9B!T97-T/2)N86UE*"D@/2`G=&5X=#IT86(M<W1O<"<@;W(@
M*EMN86UE*"D@/2`G=&5X=#IT86(M<W1O<"==(CX*("`@("`@("`@("`@/'AS
M;#IE;&5M96YT(&YA;64](G1A8BUS=&]P+6YO9&4M<&]S:71I;VXB/@H@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](G!O<VET:6]N*"DB
M+SX*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`\+WAS;#II
M9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F=R87`M8V5L;"UW:61T:"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE
M/2)P;W-I=&EO;B(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5&%B
M4W1O<%-T>6QE<R(O/@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G1A
M8E-T;W!0;W-I=&EO;B(@<V5L96-T/2(D86QL5&%B4W1O<%-T>6QE<R]S='EL
M93IT86(M<W1O<%LD<&]S:71I;VY=+T!S='EL93IP;W-I=&EO;B(O/@H@("`@
M("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M8V]N=&%I;G,H)'1A8E-T;W!0;W-I=&EO;BP@)V-M)RDB/@H@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC96QL+7=I
M9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB=VED=&@B("`@('-E;&5C=#TB;G5M8F5R*'-U8G-T<FEN9RUB969O<F4H
M)'1A8E-T;W!0;W-I=&EO;BPG8VTG*2DB+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@("`@('-E;&5C=#TB)V-M
M)R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@+2`Q(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%1A8E-T;W!3
M='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL97,B+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)C;VYT86EN<R@D
M=&%B4W1O<%!O<VET:6]N+"`G:6XG*2(^"B`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-E;&PM=VED=&@B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)W:61T:"(@
M("`@<V5L96-T/2)N=6UB97(H<W5B<W1R:6YG+6)E9F]R92@D=&%B4W1O<%!O
M<VET:6]N+"=I;B<I*2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)U;FET(B`@("`@<V5L96-T/2(G:6XG(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!O<VET:6]N
M(B!S96QE8W0](B1P;W-I=&EO;B`M(#$B+SX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5&%B4W1O<%-T>6QE<R(@<V5L
M96-T/2(D86QL5&%B4W1O<%-T>6QE<R(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](F-O;G1A:6YS*"1T86)3=&]P4&]S
M:71I;VXL("=C:"<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G=I9'1H(B`@("!S96QE8W0]
M(FYU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1T86)3=&]P4&]S:71I;VXL)V-H
M)RDI(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G5N:70B("`@("!S96QE8W0](B=C:"<B+SX*("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB('-E;&5C=#TB
M)'!O<VET:6]N("T@,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A;&Q4
M86)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H)'1A8E-T;W!0;W-I=&EO;BP@)W!T
M)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(F-R96%T92UC96QL+7=I9'1H(CX*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB=VED=&@B("`@('-E;&5C=#TB;G5M8F5R*'-U
M8G-T<FEN9RUB969O<F4H)'1A8E-T;W!0;W-I=&EO;BPG<'0G*2DB+SX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=6YI="(@
M("`@('-E;&5C=#TB)W!T)R(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)P;W-I=&EO;B(@<V5L96-T/2(D<&]S:71I;VX@
M+2`Q(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;%1A8E-T;W!3='EL97,B('-E;&5C=#TB)&%L;%1A8E-T;W!3='EL
M97,B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@
M("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H@("`@/'AS;#IT96UP;&%T92!N86UE/2)C
M<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)W
M:61T:"(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB=6YI="(O/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB<&]S:71I;VXB+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F%L;%1A8E-T;W!3='EL97,B+SX*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D<&]S:71I
M;VX@/B`Q(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)C<F5A=&4M8V5L;"UW:61T:"(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G=I9'1H(B`@("!S96QE8W0](B1W:61T
M:"`M(&YU;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1A;&Q486)3=&]P4W1Y;&5S
M+W-T>6QE.G1A8BUS=&]P6R1P;W-I=&EO;ETO0'-T>6QE.G!O<VET:6]N+"1U
M;FET*2DB+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=6YI="(@("`@('-E;&5C=#TB)'5N:70B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&]S:71I;VXB('-E;&5C
M=#TB)'!O<VET:6]N("T@,2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)A;&Q486)3=&]P4W1Y;&5S(B!S96QE8W0](B1A
M;&Q486)3=&]P4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB)'!O<VET:6]N(#T@,2(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"1W:61T:"`M(&YU
M;6)E<BAS=6)S=')I;F<M8F5F;W)E*"1A;&Q486)3=&]P4W1Y;&5S+W-T>6QE
M.G1A8BUS=&]P6R1P;W-I=&EO;ETO0'-T>6QE.G!O<VET:6]N+"1U;FET*2DL
M("1U;FET*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;VYC870H)'=I9'1H+"`D=6YI="DB+SX*("`@("`@("`@
M("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@
M(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E=#X`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]-24U%+U9I97=E<B]O;V\O=&%B;&5?<F]W<RYX<VP`````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q-S4R-2`Q,#4Q-30S-#$S-R`P,C4P,S0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/"$M+0H*("`@5&AE
M($-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B
M:F5C="!T;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I
M;F<@;&EC96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N97)A;"!0
M=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD
M=7-T<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@
M("!3=6X@36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.
M52!,97-S97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@
M("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*("`@0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC
M+@H@("`Y,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P
M,RP@55-!"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U
M(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E
M<B!T:&4@=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*
M("`@3&EC96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&
M<F5E(%-O9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@
M9&ES=')I8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U
M;"P*("`@8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@
M=&AE(&EM<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,2519(&]R
M($9)5$Y%4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'
M3E4*("`@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@
M9&5T86EL<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@
M;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A
M;&]N9R!W:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@
M1G)E92!3;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@
M4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@
M55-!"@H*("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS
M92!697)S:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES
M(&9I;&4@87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R
M9',*("`@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS
M92(I.R!9;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C
M;VUP;&EA;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@
M8V]P>2!O9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I
M8V4N;W)G+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N
M9&5R('1H:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A
M<VES+`H@("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(15(@
M15A04D534R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-
M251!5$E/3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)4R!&4D5%
M($]&($1%1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@
M3&EC96YS92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG
M('EO=7(@<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H
M92!3;V9T=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@
M3W)I9VEN86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@
M0V]P>7)I9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*
M("`@06QL(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\
M>'-L.G-T>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O
M<FTB"B`@("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@('AM;&YS
M.G-T>6QE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@
M("`@("`@("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R
M9R\R,#`P+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@
M("!X;6QN<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W
M:6YG(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM;&YS.GAL
M:6YK/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]D871A<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z
M+R]W=W<N=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M8VAA<G0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G
M+S(P,#`O9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z
M+R]W=W<N=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@("`@("`@
M("!X;6QN<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z
M8VQA<W,](G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB
M,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R
M9R]D8R]E;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T
M83TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@
M("`@("`@('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P
M,#$O8V]N9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM
M;&YS.GAT/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@
M("`@("!X;6QN<SIS>7-T96T](FAT='`Z+R]W=W<N:F-L87)K+F-O;2]X="]J
M879A+VIA=F$N;&%N9RY3>7-T96TB"B`@("`@("`@("`@("`@("!X;6QN<SIX
M86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAS;'0O
M:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT+7!R969I>&5S
M/2)J879A(CX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@=W)I=&4@
M*&5X<&QI8VET*2!R97!E871I;F<@=&%B;&4@<F]W<R`J*BH@+2T^"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G)E<&5A="UW<FET
M92UR;W<B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)N=6UB
M97(M<F]W<RUR97!E871E9"(@<V5L96-T/2(Q(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)M87A2;W=,96YG=&@B+SX*"B`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#PA+2T@=W)I=&4@86X@96YT<GD@;V8@82!R;W<@
M86YD(')E<&5A="!C86QL:6YG('1H:7,@;65T:&]D('5N=&EL(&%L;"!E;&5M
M96YT<R!A<F4@=W)I='1E;B!O=70@+2T^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2(D;G5M8F5R+7)O=W,M<F5P96%T960@/B`Q(&%N9"`H=&%B;&4Z
M=&%B;&4M8V5L;"]T97AT*"D@;W(@=&%B;&4Z=&%B;&4M8V5L;"\J*2(^"B`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M
M<F]W(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C
M=#TB)&%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@
M("`@("`@('-E;&5C=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM
M(#)$3SH@=&%K92!V87)I86)L92!F<F]M('1H92!O=71P=70@;V8@<F5P96%T
M960@=W)I=&4M<F]W(&%N9"!I=&5R871E(&=I=FEN9R!O=70@=&AE('9A<FEA
M8FQE("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G)E<&5A="UW<FET92UR;W<B/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@("`@
M("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE
M16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FUA
M>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X4F]W3&5N9W1H
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(FYU;6)E<BUR;W=S+7)E<&5A=&5D(B`@("`@<V5L96-T/2(D;G5M8F5R+7)O
M=W,M<F5P96%T960@+2`Q(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`\(2TM('=R:71E(&$@<VEN9VQE(&5N=')Y(&]F(&$@<F]W("TM/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)W<FET92UR;W<B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B`@("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O
M;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%
M;G1R:65S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FUA>%)O=TQE;F=T:"(@("`@("`@("`@("`@<V5L96-T/2(D;6%X
M4F]W3&5N9W1H(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](G=R:71E+7)O=R(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)A;&Q#;VQU;6Y3='EL945N=')I97,B+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](FUA>%)O=TQE;F=T:"(O/@H*"B`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](G1R(CX*("`@("`@("`@("`@/"$M+2!W<FET:6YG('1H
M92!S='EL92!O9B!T:&4@<F]W("TM/@H@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TG861D+7-T>6QE+7!R;W!E<G1I97,G/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@(#QX<VPZ
M:68@=&5S=#TB)&ES1&5B=6=-;V1E(CX*("`@("`@("`@("`@("`@(#QX<VPZ
M;65S<V%G93X**BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B=T<B<@96QE;65N
M="!H87,@8F5E;B!A9&1E9"$\+WAS;#IM97-S86=E/@H@("`@("`@("`@("`\
M+WAS;#II9CX*"B`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E
M;&5C=#TB=&%B;&4Z=&%B;&4M8V5L;"(^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@("`@("`@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE
M<R(@("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB;6%X4F]W3&5N9W1H
M(B`@("`@("`@("`@("!S96QE8W0](B1M87A2;W=,96YG=&@B+SX*("`@("`@
M("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($A%3%!%
M4CH@=&%B;&4@<W1Y;&5S("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F%D9"US='EL92UP<F]P97)T:65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB;F]D92UP;W-I=&EO;B(O/@H*("`@("`@("`\>'-L.F-H
M;V]S93X*("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'(%-4
M3%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52
M)R(^"B`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)C;&%S
M<R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(G1R86YS;&%T92A`=&%B;&4Z<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDB
M+SX*("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N
M,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@
M("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S='EL92(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1A8FQE
M.G-T>6QE+6YA;65=(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IA='1R:6)U
M=&4^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H\+WAS;#IS='EL97-H965T/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O+W-T>6QE
M7VEN;&EN960N>'-L````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-38S,C,@,3`U,34T,S0Q
M,S<@,#(U-3,T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I;&4@87)E
M(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F"B`@(&5I
M=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@("`@+2!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*
M("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC
M96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!);F,N+"!/
M8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI
M8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P(&)Y(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO(%)O860L
M(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R87)Y(&ES
M(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET(&%N9"]O
M<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&5S
M<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R+C$L(&%S
M('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+@H*
M("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H;W!E('1H
M870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.62!705)2
M04Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y(&]F"B`@
M($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)0U5,05(@
M4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L(%!U8FQI
M8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO=6QD(&AA
M=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E;F5R86P@
M4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A<GD[(&EF
M(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U;F1A=&EO
M;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O<W1O;BP*
M("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R>2!3=&%N
M9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!4
M:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O('1H92!3
M=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E(%9E<G-I
M;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E('1H:7,@
M9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,:6-E;G-E
M+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N<V4@870@
M:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN"@H@("!3
M;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@<')O=FED
M960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)204Y462!/
M1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@24Y#3%5$
M24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@5$A!5"!4
M2$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#2$%.5$%"
M3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/3BU)3D92
M24Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C:69I8R!P
M<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@;V)L:6=A
M=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@26YI=&EA
M;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U;B!-:6-R
M;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y(%-U;B!-
M:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V960N"@H@
M("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I;VX](C$N
M,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I8V4B"B`@
M("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO9F9I8V4N
M;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT97AT/2)H
M='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W1A
M8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@('AM;&YS
M.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B"B`@("`@
M("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY
M.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@("`@("`@
M("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V9R(*("`@
M("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R,V0](FAT
M='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@("`@("`@
M("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA=&@O36%T
M:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM;&YS.G-C
M<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T(@H@("`@
M("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@("`@("`@
M("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS
M.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*("`@("`@
M("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@("`@("`@
M('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+VAE;'`B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ8VQA<FLN
M8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H='1P.B\O
M=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A8VAE+F]R
M9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT='`Z+R]X
M;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@("!E>&-L
M=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*"B`@("`\(2TM("HJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*
M("`@(#PA+2T@*BHJ(&AA<F0@871T<FEB=71E9"`H:6YL:6YE9"D@<')O<&5R
M=&EE<R`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#PA+2T@4D535%))
M0U1)3TY3.@H@("`@("`@("`@("`Q*2`@07,@=&AE('-T>6QE<RUN;V1E+79A
M<FEA8FQE<R!A<F4@3D]4(&=L;V)A;"P@=&AE('-T>6QE('9A<FEA8FQE<R!A
M<F4@;F]T(&=L;V)A;"P@96ET:&5R(2$*("`@("`@("`@("`@,BD@($%S(&$@
M;&ES="!O9B!E;&5M96YT<R!C86X@;VYL>2!B92!A9&1E9"!T;R!A('9A<FEA
M8FQE(&%S(&$@<F5S=6QT('1R964@9G)A9VUE;G0@=&AE"B`@("`@("`@("`@
M("`@("!E>'1E;G-I;VX@:7,@;F5C8V5S<V%R>2$A"B`@("`M+3X*"B`@("`\
M(2TM(#)$3SH@26YL:6YE('-T>6QE<R!D;R!N;W0@:6YH97)I="!F<F]M(%A-
M3"!O9F9I8V4@9&5F875L=',@;F]R(&9O;G0Z9F%M:6QY(&1E9F%U;'1S(&%S
M('1H92!S='EL92!H96%D97(@9&]E<PH@("`@("`@("`@("`@("AC<"X@<W1Y
M;&5S:&5E="`G<W1Y;&5?:&5A9&5R+GAS;"<@86YD('1H92`G=W)I=&4M9&5F
M875L="US='EL97,G('1E;7!L871E*2`M+3X*"B`@("`\>'-L.G1E;7!L871E
M(&YA;64])V-R96%T92UA;&PM:6YL:6YE+7-T>6QE<R<^"@H@("`@("`@(#PA
M+2TJ*B!T<F%V97)S964@86QL('-T>6QE('1R965S(&%N9"!T:&5I<B!B<F%N
M8VAE<R!C;VQL96-T:6YG('-T>6QE('!R;W!E<G1I97,@*BHM+3X*("`@("`@
M("`\>'-L.F5L96UE;G0@;F%M93TB86QL<W1Y;&5S(CX*("`@("`@("`\(2TM
M*BH@=')A=F5R<V5E(&%L;"!O9F9I8V4Z<W1Y;&5S('1R965S(&)E9VEN;FEN
M9R!W:71H('1H92!T;W`M;&5V96P@<W1Y;&5S*BHM+3X*("`@("`@("`@("`@
M/'AS;#IF;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T
M>6QE6VYO="A`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64I72(^"@H@("`@("`@
M("`@("`@("`@/"$M+2HJ(&=I=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S
M(&]F('1H92!P87)E;G0@;F]D92`J*BTM/@H@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64])W=R:71E+6-U<G)E;G0M86YD+6EN:&5R
M:71E9"US='EL92UP<F]P97)T:65S)SX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@
M("`@("`@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R(O/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UF86UI;'DB("`@
M("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M
M92UT;VME;FEZ960B("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE
M.FYA;64L("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H*("`@("`@("`@("`@("`@(#PA+2TJ*B!A;&P@
M;V9F:6-E.G-T>6QE<R!C:&EL9')E;B!O9B!T:&4@8W5R<F5N="!T;W`M;&5V
M96P@;V9F:6-E.G-T>6QE<R`J*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64])V9O<BUA;&PM=&5M<&QA=&5S+6-H:6QD+7-T
M>6QE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!A<F5N=%-T>6QE3F%M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T
M>6QE.FYA;64B+SX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T
M/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@
M('-E;&5C=#TB=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G
M*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@
M("`@("`@("`@("`@("`\(2TM*BH@86QL(&]F9FEC93IA=71O;6%T:6,M<W1Y
M;&5S(&-H:6QD<F5N(&]F('1H92!C=7)R96YT('1O<"UL979E;"!S='EL92`J
M*BTM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M)V9O<BUA;&PM875T;VUA=&EC+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M
M92(@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y
M;&5&86UI;'DB("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T
M>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E
M*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"@H@("`@("`@(#PA+2TJ*B!T<F%V97)S964@86QL(&]F9FEC93IA
M=71O;6%T:6,M<W1Y;&5S('1R965S(&)E9VEN;FEN9R!W:71H('1H92!T;W`M
M;&5V96P@<W1Y;&5S("HJ+2T^"B`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@
M<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y;&5;
M;F]T*$!S='EL93IP87)E;G0M<W1Y;&4M;F%M92E=(CX*("`@("`@("`@("`@
M("`@(#PA+2TJ*B!G:79E(&]U="!T:&4@<W1Y;&4@<')O<&5R=&EE<R!O9B!T
M:&4@<&%R96YT(&YO9&4@*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L
M;"UT96UP;&%T92!N86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE<FET960M
M<W1Y;&4M<')O<&5R=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@
M('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+69A;6EL
M>2(@("`@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL
M92UN86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS;&%T92A`
M<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@("`@("`@
M(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@("`@("`@/"$M+2HJ
M(&%L;"!C:&EL9')E;B!O9B!T:&4@=&]P+6QE=F5L(&]F9FEC93IA=71O;6%T
M:6,M<W1Y;&5S<R`@*BHM+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2=F;W(M86QL+6%U=&]M871I8RUC:&EL9"US='EL97,G
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P
M87)E;G13='EL94YA;64B("`@("`@("`@("`@("!S96QE8W0](D!S='EL93IN
M86UE(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G!A<F5N=%-T>6QE1F%M:6QY(B`@("`@("`@("`@('-E;&5C=#TB0'-T
M>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)S='EL92UN86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE
M8W0](G1R86YS;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG
M9F]R+6%L;"UT96UP;&%T97,M8VAI;&0M<W1Y;&5S)SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](G!A<F5N=%-T>6QE3F%M92(O/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB+SX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B\^"@H@("`@("`@
M(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(N+B]S='EL93IS='EL95M`<W1Y;&4Z
M9F%M:6QY/21P87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US
M='EL92UN86UE/21P87)E;G13='EL94YA;65=(CX*("`@("`@("`@("`@/"$M
M+2HJ(&=I=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!C=7)R
M96YT(&YO9&4@*BHM+3X*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(GLD<W1Y;&4M;F%M92UT;VME;FEZ961](CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE
M<FET960M<W1Y;&4M<')O<&5R=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@
M("`@("`@('-E;&5C=#TB)&]F9FEC93IS='EL97,B+SX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B`@
M("`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE+6YA
M;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A;G-L871E*$!S='EL
M93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M"B`@("`@("`@("`@(#PA+2TJ*B!F;W(@86QL('1E;7!L871E+6-H:6QD<F5N
M(&]F('1H92!C=7)R96YT(&]F9FEC93IS='EL97,@("HJ+2T^"B`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2=F;W(M86QL+71E;7!L871E
M<RUC:&EL9"US='EL97,G/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@("`@("`@('-E;&5C
M=#TB)&]F9FEC93IS='EL97,B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B("`@("`@("`@("`@("!S
M96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@("`@("`@
M<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B("`@("`@
M("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H*2]<)RP@
M)R<I(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@
M("`@("`@("`\(2TM*BH@9F]R(&%L;"!A=71O;6%T:6,M8VAI;&1R96X@;V8@
M=&AE(&-U<G)E;G0@;V9F:6-E.G-T>6QE<R`@*BHM+3X*("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC+6-H
M:6QD+7-T>6QE<R<^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&5S+6YO9&4B("`@("`@("`@("`@("`@("`@<V5L96-T/2(D
M;V9F:6-E.F%U=&]M871I8RUS='EL97,B+SX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL94YA;64B("`@("`@("`@
M("`@("!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB("`@("`@
M("`@("`@<V5L96-T/2)`<W1Y;&4Z9F%M:6QY(B\^"B`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B
M("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'-T>6QE.FYA;64L("<N("4H
M*2]<)RP@)R<I(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64])V9O<BUA;&PM875T;VUA=&EC
M+6-H:6QD+7-T>6QE<R<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL
M97,M;F]D92(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<&%R96YT4W1Y
M;&5.86UE(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P87)E;G13='EL
M949A;6EL>2(O/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&4M;F%M
M92UT;VME;FEZ960B+SX*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z
M9F%M:6QY/21P87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N="US
M='EL92UN86UE/21P87)E;G13='EL94YA;65=(CX*("`@("`@("`@("`@/"$M
M+2HJ(&=I=F4@;W5T('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!C=7)R
M96YT(&YO9&4@*BHM+3X*("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(GLD<W1Y;&4M;F%M92UT;VME;FEZ961](CX*("`@("`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2=W<FET92UC=7)R96YT+6%N9"UI;FAE
M<FET960M<W1Y;&4M<')O<&5R=&EE<R<^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@("`@("`@("`@
M("`@("`@('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S(B\^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE
M+69A;6EL>2(@("`@("`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL
M>2(O/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL92UN86UE+71O:V5N:7IE9"(@("`@("`@("!S96QE8W0](G1R86YS
M;&%T92A`<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDB+SX*("`@("`@("`@
M("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"@H@("`@("`@("`@("`\(2TM*BH@9F]R(&%L;"!A=71O;6%T
M:6,M8VAI;&1R96X@;V8@=&AE(&-U<G)E;G0@;V9F:6-E.F%U=&]M871I8RUS
M='EL97,@("HJ+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2=F;W(M86QL+6%U=&]M871I8RUC:&EL9"US='EL97,G/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-T>6QE<RUN;V1E(B`@
M("`@("`@("`@("`@("`@('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y
M;&5S(B\^"B`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<&%R96YT4W1Y;&5.86UE(B`@("`@("`@("`@("`@<V5L96-T/2)`<W1Y;&4Z
M;F%M92(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G!A<F5N=%-T>6QE1F%M:6QY(B`@("`@("`@("`@('-E;&5C=#TB0'-T>6QE
M.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](G-T>6QE+6YA;64M=&]K96YI>F5D(B`@("`@("`@('-E;&5C=#TB=')A
M;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2(O/@H@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.F9O<BUE
M86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@
M;F%M93TG=W)I=&4M8W5R<F5N="UA;F0M:6YH97)I=&5D+7-T>6QE+7!R;W!E
M<G1I97,G/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY
M(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL97,M;F]D92(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB<W1Y;&4M;F%M92UT;VME;FEZ960B
M+SX*"B`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD<W1Y;&4M;F%M92UT
M;VME;FEZ961](CX*("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)C
M=7)R96YT+7-T>6QE+6YA;64B('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@
M("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<W1Y;&4M;F%M
M92(@<V5L96-T/2)`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64B+SX*"B`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6QI<W0B
M/@H@("`@("`@("`@("`@("`@/"$M+2HJ*B!#3TQ,14-4(%-464Q%($%45%))
M0E5415,@*&]N;'D@=&]P;&5V96PI("HJ*BTM/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE+7!R;W!E<G1I
M97,B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)S='EL94%T=')I8G5T95!A=&@B("`@<V5L96-T/2(D<W1Y;&5S+6YO9&4O
M<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD<W1Y;&4M9F%M:6QY(&%N9"!`
M<W1Y;&4Z;F%M93TD8W5R<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T
M:65S+T`J(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\(2TM*BHJ($!%;F0Z($=)5D4@
M3U54($%L;"!#3TQ,14-4140@4U193$4@05144DE"551%4R`H;VYL>2!T;W!L
M979E;"D@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M<W1R:6YG+6QE;F=T:"@D<&%R96YT+7-T>6QE+6YA;64I/3`B/@H@("`@("`@
M("`@("`@("`@/"$M+2HJ(&EF(&YO('-T>6QE4&%R96YT(&ES(&=I=F5N+"!T
M:&4@<')O<&5R=&EE<R!A<F4@9VEV96X@;W5T(&%T(&]N8V4@*BHM+3X*("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB;F]R;6%L
M:7IE+7-P86-E*"1N97<M<')O<&5R='DM;&ES="DB+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES
M93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE
M=RUP<F]P97)T>2UN86UE<R(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ9F]R+65A8V@@<V5L96-T/2(D<W1Y;&5S+6YO9&4O<W1Y;&4Z<W1Y;&5;
M0'-T>6QE.F9A;6EL>3TD<W1Y;&4M9F%M:6QY(&%N9"!`<W1Y;&4Z;F%M93TD
M8W5R<F5N="US='EL92UN86UE72]S='EL93IP<F]P97)T:65S+T`J(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)N86UE*"DB+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@
M("`@("`@("`@("`@("`@("`@/"$M+2HJ(&9U<G1H97(@871T<FEB=71E<R!O
M9B!T:&4@<&%R96YT('-T>6QE(&UU<W0@8F4@8V]L;&5C=&5D("HJ+2T^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D
M9"UP87)E;G0M<W1Y;&4M871T<FEB=71E<R(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P<F]P97)T>2UN86UE+6QI
M<W0B("`@("`@('-E;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]M
M<&QE=&4M<')O<&5R='DM;&ES="(@("!S96QE8W0](FYO<FUA;&EZ92US<&%C
M92@D;F5W+7!R;W!E<G1Y+6QI<W0I(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B
M("`@("`@('-E;&5C=#TB)&-U<G)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT
M+7-T>6QE+6YA;64B("`@("`@("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M
M92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@("!S96QE8W0](B1S='EL
M92UF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)A9&0M<&%R96YT+7-T>6QE+6%T=')I8G5T97,B/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB<')O<&5R='DM;F%M92UL:7-T(B\^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)C;VUP;&5T92UP<F]P97)T>2UL:7-T(B\^"B`@("`@
M("`@/'AS;#IP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@
M("`@("`\>'-L.G!A<F%M(&YA;64](G!A<F5N="US='EL92UN86UE(B\^"B`@
M("`@("`@/'AS;#IP87)A;2!N86UE/2)S='EL92UF86UI;'DB+SX*"B`@("`@
M("`@/"$M+2HJ*B!.97<@='=O(&)E(&%D9&5D('!R;W!E<G1Y(&YA;65S('=I
M;&P@8F4@8V]L;&5C=&5D("AO;FQY(&]N92!V87)I86)L92!P97(@=&5M<&QA
M=&4I("HJ*BTM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R
M;W!E<G1Y+6YA;65S(CX*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E
M(&YA;64](F=E="UN97<M<W1Y;&4M;F%M97,B/@H@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@
M("`@<V5L96-T/2(D<')O<&5R='DM;F%M92UL:7-T(B\^"B`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT+7-T>6QE+6YA;64B
M("`@("`@("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-U<G)E;G0M<W1Y;&4M
M;F%M92(@("`@("`@<V5L96-T/2(D8W5R<F5N="US='EL92UN86UE(B\^"B`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ
M=F%R:6%B;&4^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\
M(2TM*BHJ(&-H96-K(&EF('1H92!N97<@<&%R96YT('-T>6QE(&5X:7-T(&EN
M('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S96-T:6]N("AD969I;F5D
M(&)Y(&YA;64@86YD(&9A;6EL>2D@*BHJ+2T^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O<W1Y;&4Z<W1Y
M;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64]
M)&-U<G)E;G0M<W1Y;&4M;F%M95TB/@H@("`@("`@("`@("`@("`@/"$M+2HJ
M*B!214-54E-)3TXZ(&%D9&EN9R!N97<@<&%R96YT('-T>6QE(&%T=')I8G5T
M97,@=&\@=&AE(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UA='1R:6)U=&5S
M(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB9V5T+6YE=RUS='EL92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYE=RUP<F]P97)T>2UN
M86UE<R(@("`@("`@("`@('-E;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE<R(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M
M93TB8W5R<F5N="US='EL92UN86UE(B`@("`@("`@("`@<V5L96-T/2(D8W5R
M<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M92(@("`@("`@
M("`@("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@
M("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#PA+2TJ*BH@16YD
M($-/3D1)5$E/3CH@=&AE(&QA<W0@<W1Y;&4@<&%R96YT(&AA<R!A;')E861Y
M(&)E96X@97AE8W5T960@*BHJ+2T^"B`@("`@("`@("`@("`@("`\>'-L.G9A
M<FEA8FQE(&YA;64](FYE=RUP87)E;G0M<W1Y;&4M;F%M92(@('-E;&5C=#TB
M)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF
M86UI;'D])W!A<F%G<F%P:"<@86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y
M;&4M;F%M95TO0'-T>6QE.G!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@
M("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB<W1R:6YG+6QE;F=T:"@D;F5W+7!A<F5N="US='EL92UN
M86UE*3TP(CX*("`@("`@("`@("`@("`@("`@("`\(2TM*BH@;F\@9G5R=&AE
M<B!P87)E;G0@:7,@9F]U;F0L('1H92!G:79E;B!P87)A;65T97(@<')O<&5R
M='DM;F]D92!I<R!T:&4@9FEN86P@<W1Y;&4@+2T^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&-O;7!L
M971E+7!R;W!E<G1Y+6QI<W0L)&YE=RUP<F]P97)T>2UA='1R:6)U=&5S*2(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@
M/"$M+2HJ(&9U<G1H97(@871T<FEB=71E<R!O9B!T:&4@<&%R96YT('-T>6QE
M(&UU<W0@8F4@8V]L;&5C=&5D("HJ+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A9&0M<&%R96YT+7-T>6QE
M+6%T=')I8G5T97,B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G!R;W!E<G1Y+6YA;64M;&ES="(@("`@("`@
M<V5L96-T/2)C;VYC870H)'!R;W!E<G1Y+6YA;64M;&ES="P@)&YE=RUP<F]P
M97)T>2UN86UE<RDB+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VUP;&5T92UP<F]P97)T>2UL:7-T(B`@
M('-E;&5C=#TB8V]N8V%T*"1C;VUP;&5T92UP<F]P97)T>2UL:7-T+"1N97<M
M<')O<&5R='DM871T<FEB=71E<RDB+SX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA
M;64B("`@("`@('-E;&5C=#TB)'!A<F5N="US='EL92UN86UE(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M<&%R96YT+7-T>6QE+6YA;64B("`@("`@("!S96QE8W0](B1N97<M<&%R96YT
M+7-T>6QE+6YA;64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)S='EL92UF86UI;'DB("`@("`@("`@("`@
M('-E;&5C=#TB)'-T>6QE+69A;6EL>2(O/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TJ
M*B!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E9FEN960@8GD@;F%M92!A;F0@9F%M
M:6QY*2!M=7-T(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I
M;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/"$M+2HJ*B!214-54E-)3TXZ(&%D9&EN9R!N97<@<&%R96YT('-T
M>6QE(&%T=')I8G5T97,@=&\@=&AE(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@
M("`@("`@("`@("`@("`\(2TM*BHJ(&%D9&EN9R!N97<@<&%R96YT('-T>6QE
M(&%T=')I8G5T97,@=&\@=&AE(&-U<G)E;G0@<W1Y;&4@*BHJ+2T^"B`@("`@
M("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP<F]P97)T>2UA
M='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB9V5T+6YE=RUS='EL92UA='1R:6)U=&5S(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](FYE=RUP
M<F]P97)T>2UN86UE<R(@("`@("`@("`@('-E;&5C=#TB)&YE=RUP<F]P97)T
M>2UN86UE<R(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8W5R<F5N="US='EL92UN86UE(B`@("`@("`@("`@<V5L
M96-T/2(D8W5R<F5N="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G0M<W1Y;&4M;F%M
M92(@("`@("`@("`@("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@("`@("`@("`@(#PA
M+2TJ*BH@16YD($-/3D1)5$E/3CH@=&AE(&QA<W0@<W1Y;&4@<&%R96YT(&AA
M<R!A;')E861Y(&)E96X@97AE8W5T960@*BHJ+2T^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A<FEA8FQE(&YA;64](FYE=RUP87)E;G0M<W1Y;&4M;F%M92(@
M('-E;&5C=#TB)&]F9FEC93IS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A
M;6EL>3TG<&%R86=R87!H)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL
M92UN86UE72]`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64B+SX*("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)S=')I;F<M;&5N9W1H*"1N97<M<&%R96YT+7-T>6QE+6YA
M;64I/3`B/@H@("`@("`@("`@("`@("`@("`@(#PA+2TJ*B!N;R!F=7)T:&5R
M('!A<F5N="!I<R!F;W5N9"P@=&AE(&=I=F5N('!A<F%M971E<B!P<F]P97)T
M>2UN;V1E(&ES('1H92!F:6YA;"!S='EL92`M+3X*("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@D8V]M<&QE
M=&4M<')O<&5R='DM;&ES="PD;F5W+7!R;W!E<G1Y+6%T=')I8G5T97,I(B\^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\
M(2TM*BH@9G5R=&AE<B!A='1R:6)U=&5S(&]F('1H92!P87)E;G0@<W1Y;&4@
M;75S="!B92!C;VQL96-T960@*BH@("TM/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D+7!A<F5N="US='EL
M92UA='1R:6)U=&5S(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)P<F]P97)T>2UN86UE+6QI<W0B("`@("`@
M('-E;&5C=#TB8V]N8V%T*"1P<F]P97)T>2UN86UE+6QI<W0L("1N97<M<')O
M<&5R='DM;F%M97,I(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB8V]M<&QE=&4M<')O<&5R='DM;&ES="(@
M("!S96QE8W0](F-O;F-A="@D8V]M<&QE=&4M<')O<&5R='DM;&ES="PD;F5W
M+7!R;W!E<G1Y+6%T=')I8G5T97,I(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8W5R<F5N="US='EL92UN
M86UE(B`@("`@("!S96QE8W0](B1P87)E;G0M<W1Y;&4M;F%M92(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G!A<F5N="US='EL92UN86UE(B`@("`@("`@<V5L96-T/2(D;F5W+7!A<F5N
M="US='EL92UN86UE(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&4M9F%M:6QY(B`@("`@("`@("`@
M("!S96QE8W0](B1S='EL92UF86UI;'DB+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M
M<&QA=&4@;F%M93TB9V5T+6YE=RUS='EL92UN86UE<R(^"B`@("`@("`@/'AS
M;#IP87)A;2!N86UE/2)P<F]P97)T>2UN86UE+6QI<W0B+SX*("`@("`@("`\
M>'-L.G!A<F%M(&YA;64](G!A<F5N="US='EL92UN86UE(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@
M("`\(2TM*BH@=VAE<F4@=&\@9FEN9"!T:&4@<W!E8VEF:6,@<W1Y;&4@*&1E
M9FEN960@8GD@;F%M92!A;F0@9F%M:6QY*2!W:&5T97(@:6X@;V9F:6-E.F%U
M=&]M871I8RUS='EL97,@;W(@;V9F:6-E.G-T>6QE<R!S96-T:6]N("TM/@H@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*BH@:68@=&AE
M('-P96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL>2D@
M8V%N(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R!S
M96-T:6]N("TM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]F9FEC
M93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D]
M)W!A<F%G<F%P:"<@86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M;F%M
M95TB/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E
M;G0M<')O<&5R='DM;F]D92(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS
M='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R!A
M;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72]S='EL93IP<F]P
M97)T:65S(B\^"@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)N97<M<')O<&5R='DM;F%M92UL:7-T(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)'!A<F5N="UP<F]P97)T>2UN;V1E
M+T`J6VYO="AC;VYT86EN<R@D<')O<&5R='DM;F%M92UL:7-T+"!N86UE*"DI
M*5TB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB;F%M92@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D;F5W+7!R;W!E<G1Y
M+6YA;64M;&ES="(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@
M("`@("`\(2TM*BH@=&AE('-P96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA
M;64@86YD(&9A;6EL>2D@<VAO=6QD(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z
M<W1Y;&5S('-E8W1I;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M
M<')O<&5R='DM;F]D92(@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL93IS
M='EL95M`<W1Y;&4Z9F%M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M
M93TD<&%R96YT+7-T>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,B+SX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y
M+6YA;64M;&ES="(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C
M:"!S96QE8W0](B1P87)E;G0M<')O<&5R='DM;F]D92]`*EMN;W0H8V]N=&%I
M;G,H)'!R;W!E<G1Y+6YA;64M;&ES="P@;F%M92@I*2E=(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](FYA;64H*2(O
M/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ=F%R:6%B;&4^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB)&YE=RUP<F]P97)T>2UN86UE+6QI<W0B+SX*
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H
M;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT96UP;&%T
M92!N86UE/2)G970M;F5W+7-T>6QE+6%T=')I8G5T97,B/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;65S(B\^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)C=7)R96YT+7-T>6QE+6YA;64B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](G!A<F5N="US='EL92UN86UE(B\^"@H@("`@
M("`@(#PA+2TJ*B!W:&5R92!T;R!F:6YD('1H92!S<&5C:69I8R!S='EL92`H
M9&5F:6YE9"!B>2!N86UE(&%N9"!F86UI;'DI('=H971H97(@:6X@;V9F:6-E
M.F%U=&]M871I8RUS='EL97,@;W(@;V9F:6-E.G-T>6QE<R!S96-T:6]N("TM
M/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*BH@:68@
M=&AE('-P96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL
M>2D@8V%N(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z875T;VUA=&EC+7-T>6QE
M<R!S96-T:6]N("TM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]F
M9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI
M;'D])W!A<F%G<F%P:"<@86YD($!S='EL93IN86UE/21P87)E;G0M<W1Y;&4M
M;F%M95TB/@H@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P
M87)E;G0M<')O<&5R='DM;F]D92(@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I
M8RUS='EL97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H
M)R!A;F0@0'-T>6QE.FYA;64])'!A<F5N="US='EL92UN86UE72]S='EL93IP
M<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA
M;64](FYE=RUP<F]P97)T>2UN86UE+6QI<W0B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US='EL92UP<F]P
M97)T:65S(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G-T>6QE071T<FEB=71E4&%T:"(@("!S96QE8W0](B1P87)E
M;G0M<')O<&5R='DM;F]D92]`*EMC;VYT86EN<R@D;F5W+7!R;W!E<G1Y+6YA
M;65S+"!N86UE*"DI72(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IV87)I86)L93X*
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)N;W)M86QI
M>F4M<W!A8V4H)&YE=RUP<F]P97)T>2UN86UE+6QI<W0I(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PA+2TJ*B!O=&AE<G=I<V4@
M=&AE('-P96-I9FEC('-T>6QE("AD969I;F5D(&)Y(&YA;64@86YD(&9A;6EL
M>2D@<VAO=6QD(&)E(&9O=6YD(&EN('1H92!O9F9I8V4Z<W1Y;&5S('-E8W1I
M;VX@+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`@("`@/'AS;#IV87)I86)L92!N86UE/2)P87)E;G0M<')O<&5R='DM;F]D
M92(@<V5L96-T/2(D;V9F:6-E.G-T>6QE<R]S='EL93IS='EL95M`<W1Y;&4Z
M9F%M:6QY/2=P87)A9W)A<&@G(&%N9"!`<W1Y;&4Z;F%M93TD<&%R96YT+7-T
M>6QE+6YA;65=+W-T>6QE.G!R;W!E<G1I97,B+SX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB;F5W+7!R;W!E<G1Y+6YA;64M;&ES="(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(G=R:71E+7-T>6QE+7!R;W!E<G1I97,B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<W1Y;&5!='1R:6)U=&50871H
M(B`@('-E;&5C=#TB)'!A<F5N="UP<F]P97)T>2UN;V1E+T`J6V-O;G1A:6YS
M*"1N97<M<')O<&5R='DM;F%M97,L(&YA;64H*2E=(B\^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@
M(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](FYO<FUA;&EZ92US<&%C92@D;F5W+7!R;W!E<G1Y+6YA;64M
M;&ES="DB+SX*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"CPO>'-L.G-T
M>6QE<VAE970^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O
M+W1A8FQE7V-O;'5M;G,N>'-L````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C0V-#4@,3`U
M,34T,S0Q,S<@,#(U-3(S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I
M;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F
M"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@
M("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!)
M;F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO
M(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R
M87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET
M(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R
M+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T
M:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.
M62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y
M(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A
M<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R
M>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O
M('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E
M(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E
M('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,
M:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N
M<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN
M"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@
M<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)2
M04Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@
M24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@
M5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#
M2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/
M3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C
M:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@
M;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@
M26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V
M960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I
M8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT
M97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V
M9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA
M=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@
M("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*
M("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@
M("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H
M='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT
M='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@
M("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*("`@(#PA+2T@
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@
M+2T^"B`@("`\(2TM("HJ*B!#<F5A=&4@=&%B;&4@8V]L=6UN<R!S='EL92!V
M87)I86)L92`@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&5S+65N=')I97,B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL5&%B;&5#;VQU;6YS(B\^"@H@
M("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL5&%B;&5#;VQU;6YS
M(CX*"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB8V]L=6UN+7-T
M>6QE+65N=')Y(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T
M>6QE<R\J6VYA;64H*2`]('1R86YS;&%T92AC=7)R96YT*"DO0'1A8FQE.G-T
M>6QE+6YA;64L("<N("4H*2]<)RP@)R<I72(O/@H@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H
M0'1A8FQE.FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D*2(^"B`@("`@("`@("`@
M("`@("`@("`@/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C;VQU;6X@:6X@
M=&AE(&-O;'5M;G,M=F%R:6%B;&4@+2T^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&4M
M96YT<GDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B!S96QE8W0](B1C;VQU;6XM
M<W1Y;&4M96YT<GDB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@(#PA+2T@3F\@:&EG:&5R(')E<&5T:71I;VX@;V8@8V5L;',@
M9W)E871E<B!T:&%N(#0@9F]R('1H92!L87-T(&%N9"!S96-O;F0@;&%S="!C
M;VQU;6X@+2T^"B`@("`@("`@("`@("`@("`\(2TM(&$@:&%C:R!F;W(@=&AE
M('-A;7!L92!D;V-U;65N="`G5V%E:')U;F=S=6UR96-H;F5R+G-X8R!H879I
M;F<@,C,P(')E<&5A=&5D(&-O;'5M;G,@:6X@=&AE('-E8V]N9"!L87-T(&-O
M;'5M;B`M+3X*("`@("`@("`@("`@("`@(#PA+2T@/S\_(#QX<VPZ=VAE;B!T
M97-T/2(H<&]S:71I;VXH*2`](&QA<W0H*2!O<B`H<&]S:71I;VXH*2`]("AL
M87-T*"D@+2`Q*2D@86YD($!T86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E
M9"`F;'0[(#4I(CX@/S\_+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB<&]S:71I;VXH*2`](&QA<W0H*2!O<B!P;W-I=&EO;B@I(#T@*&QA
M<W0H*2`M(#$I(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0]
M(D!T86)L93IN=6UB97(M8V]L=6UN<RUR97!E871E9"`F;'0[(#4B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\(2TM('=R:71E<R!A;B!E;G1R>2!O9B!A
M(&-O;'5M;B!I;B!T:&4@8V]L=6UN<RUV87)I86)L92`M+3X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G)E<&5A
M="UA9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQU;6XM<W1Y
M;&4M96YT<GDB("`@("`@('-E;&5C=#TB)&-O;'5M;BUS='EL92UE;G1R>2(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D(B`@<V5L96-T/2(Q(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"$M+2!R97!E871E9"!C;VQU;7,@=VEL
M;"!B92!W<FET=&5N(&5X<&QI8VET('-E=F5R86P@=&EM97,@:6X@=&AE('9A
M<FEA8FQE+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](G)E<&5A="UA9&1I;F<M8V]L=6UN+7-T>6QE+65N=')Y(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;'5M;BUS='EL92UE;G1R>2(@("`@("`@("`@('-E;&5C=#TB)&-O;'5M
M;BUS='EL92UE;G1R>2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB;G5M8F5R+6-O;'5M;G,M<F5P96%T960B("`@
M("`@<V5L96-T/2)`=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P96%T960B+SX*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`\+WAS
M;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ9F]R+65A8V@^"B`@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#PA+2T@5U))5$53(%1(12!215!%051%1"!#3TQ5
M34X@4U193$4@15A03$E#250@05,@04X@14Q%345.5"!)3B!42$4@0T],54U.
M4RU605))04),12`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB<F5P96%T
M+6%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@(#QX<VPZ<&%R
M86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)N=6UB97(M8V]L=6UN<RUR97!E871E9"(O/@H*("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1N
M=6UB97(M8V]L=6UN<RUR97!E871E9"`^(#$B/@H@("`@("`@("`@("`@("`@
M/"$M+2!W<FET97,@86X@96YT<GD@;V8@82!C;VQU;6X@:6X@=&AE(&-O;'5M
M;G,M=F%R:6%B;&4@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB861D:6YG+6-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;'5M;BUS
M='EL92UE;G1R>2(@("!S96QE8W0](B1C;VQU;6XM<W1Y;&4M96YT<GDB+SX*
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`\(2TM(')E<&5A="!C86QL:6YG('1H:7,@;65T:&]D('5N=&EL
M(&%L;"!E;&5M96YT<R!W<FET=&5N(&]U="`M+3X*("`@("`@("`@("`@("`@
M(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M861D:6YG+6-O;'5M
M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;'5M;BUS='EL92UE;G1R>2(@("`@("`@<V5L96-T
M/2(D8V]L=6UN+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](FYU;6)E<BUC;VQU;6YS+7)E<&5A=&5D
M(B`@<V5L96-T/2(D;G5M8F5R+6-O;'5M;G,M<F5P96%T960@+2`Q(B\^"B`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@(#PA+2T@=W)I=&5S(&%N(&5N=')Y(&]F(&$@8V]L=6UN
M(&EN('1H92!C;VQU;6YS+79A<FEA8FQE("TM/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F%D9&EN9RUC;VQU;6XM<W1Y;&4M
M96YT<GDB/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB("`@<V5L96-T/2(D8V]L=6UN+7-T
M>6QE+65N=')Y(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X
M<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#PA+2T@5$A%
M($-/3%5-3BU35%E,12!74DE412U0051415).($9/4B!%04-(($-/3%5-3B!7
M4DE45$5.($E.($$@5D%224%"3$4@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA
M;64](F%D9&EN9RUC;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@(#QX<VPZ
M<&%R86T@;F%M93TB8V]L=6UN+7-T>6QE+65N=')Y(B\^"@H@("`@("`@(#QX
M<VPZ96QE;65N="!N86UE/2)C;VQU;6XM<W1Y;&4M96YT<GDB/@H@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T
M97-T/2)`=&%B;&4Z=FES:6)I;&ET>2`]("=C;VQL87!S92<@;W(@0'1A8FQE
M.G9I<VEB:6QI='D@/2`G9FEL=&5R)R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB8V]L=6UN+6AI9&1E;BUF;&%G(CYT<G5E
M/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@(&YA;64](G1A8FQE.G-T>6QE+6YA;64B
M("`@("`@("`@<V5L96-T/2)T<F%N<VQA=&4H0'1A8FQE.G-T>6QE+6YA;64L
M("<N("4H*2]<)RP@)R<I(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IA
M='1R:6)U=&4@;F%M93TB<W1Y;&4M;F%M92(^/'AS;#IV86QU92UO9B!S96QE
M8W0](B1T86)L93IS='EL92UN86UE(B\^/"]X<VPZ871T<FEB=71E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2(D8V]L=6UN
M+7-T>6QE+65N=')Y(B\^"B`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I
M<V4^"B`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"B`@("`\(2TM:7-$96)U
M9TUO9&4M4U1!4E0M+3X*("`@(#PA+2T@9VEV:6YG(&]U="!T:&4@)V%L;$-O
M;'5M;E-T>6QE)R!V87)I86)L93H*("`@("`@("!&;W(@96%C:"`G8V]L=6UN
M+7-T>6QE+65N=')Y)R!O9B!T:&4@)V%L;$-O;'5M;E-T>6QE16YT<FEE<R<@
M=F%R:6%B;&4@=&AE('-T>6QE+6YA;64@:7,@9VEV96X@;W5T+@H@("`@("`@
M($EN(&-A<V4@;V8@)V-O;'5M;BUH:61D96XM9FQA9R<@871T<FEB=71E('1H
M92!T97AT("=#;VQU;6X@:7,@:&ED9&5N(&ES(&=I=F5N(&]U="XM+3X*("`@
M(#QX<VPZ=&5M<&QA=&4@;F%M93TB=&%B;&4M9&5B=6<M86QL0V]L=6UN4W1Y
M;&5%;G1R:65S(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F%L;$-O;'5M
M;E-T>6QE16YT<FEE<R(O/@H*("`@("`@("`\(2TM(&1E8G5G(&]U='!U="!A
M<R!T86)L92!S=6UM87)Y(&%T=')I8G5T(&EN(&AT;6P@+2T^"B`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB<W5M;6%R>2(^"B`@("`@("`@("`@(#QX
M<VPZ8V%L;"UT96UP;&%T92!N86UE/2)T86)L92UD96)U9RUC;VQU;6XM;W5T
M(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A;&Q#
M;VQU;6Y3='EL945N=')I97,B('-E;&5C=#TB)&%L;$-O;'5M;E-T>6QE16YT
M<FEE<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`\(2TM(&1E8G5G(&]U='!U
M="!T;R!C;VYS;VQE("TM/@H@("`@("`@(#QX<VPZ;65S<V%G93X*("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G1A8FQE+61E8G5G+6-O
M;'5M;BUO=70B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@<V5L96-T/2(D86QL0V]L=6UN
M4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@/"]X<VPZ;65S<V%G93X*("`@(#PO>'-L.G1E;7!L871E
M/@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](G1A8FQE+61E8G5G+6-O;'5M
M;BUO=70B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB86QL0V]L=6UN4W1Y
M;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#QX<VPZ=&5X=#X*("`@("`@("`@
M("`@1&5B=6=);F9O<FUA=&EO;CH@1F]R(&5A8V@@)V-O;'5M;BUS='EL92UE
M;G1R>2<@;V8@=&AE("=A;&Q#;VQU;6Y3='EL945N=')I97,G('9A<FEA8FQE
M('1H92!S='EL92UN86UE(&ES(&=I=F5N(&]U="X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@26X@8V%S92!O9B`G8V]L=6UN+6AI9&1E;BUF;&%G
M)R!A='1R:6)U=&4@=&AE('1E>'0@)V-O;'5M;B!I<R!H:61D96XG(&ES(&=I
M=F5N(&]U="X*("`@("`@("`@("`@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@
M("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R
M:65S+V-O;'5M;BUS='EL92UE;G1R>2(^"B`@("`@("`@("`@("`@("`\>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`8V]L
M=6UN+6AI9&1E;BUF;&%G(CX*("`@("`@("`@("`@/'AS;#IT97AT/B`@/"]X
M<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'-T>6QE+6YA;64B+SX\
M>'-L.G1E>'0^8V]L=6UN(&ES(&AI9&1E;CPO>'-L.G1E>'0^/'AS;#IT97AT
M/@H@("`@("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X
M<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`\>'-L.G1E>'0^("`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`<W1Y;&4M;F%M92(O/CQX<VPZ=&5X=#X@/2`\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(N(B\^/'AS;#IT97AT/@H@("`@("`@
M("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*("`@(#PO>'-L.G1E
M;7!L871E/@H@("`@/"$M+6ES1&5B=6=-;V1E+45.1"TM/@H*/"]X<VPZ<W1Y
M;&5S:&5E=#X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M24U%+U9I97=E<B]O;V\O8V]M;6]N+GAS;```````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#$V-S`W,R`Q,#4Q-30S-#$S-R`P,C0Q-C<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/"$M+0H*("`@5&AE($-O;G1E
M;G1S(&]F('1H:7,@9FEL92!A<F4@;6%D92!A=F%I;&%B;&4@<W5B:F5C="!T
M;R!T:&4@=&5R;7,@;V8*("`@96ET:&5R(&]F('1H92!F;VQL;W=I;F<@;&EC
M96YS97,*"B`@("`@("`@("`M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,@
M3&EC96YS92!697)S:6]N(#(N,0H@("`@("`@("`@+2!3=6X@26YD=7-T<GD@
M4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"@H@("!3=6X@
M36EC<F]S>7-T96US($EN8RXL($]C=&]B97(L(#(P,#`*"B`@($=.52!,97-S
M97(@1V5N97)A;"!0=6)L:6,@3&EC96YS92!697)S:6]N(#(N,0H@("`]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*("`@
M0V]P>7)I9VAT(#(P,#`@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H@("`Y
M,#$@4V%N($%N=&]N:6\@4F]A9"P@4&%L;R!!;'1O+"!#02`Y-#,P,RP@55-!
M"@H@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S;V9T=V%R93L@>6]U(&-A;B!R
M961I<W1R:6)U=&4@:70@86YD+V]R"B`@(&UO9&EF>2!I="!U;F1E<B!T:&4@
M=&5R;7,@;V8@=&AE($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC
M96YS92!V97)S:6]N(#(N,2P@87,@<'5B;&ES:&5D(&)Y('1H92!&<F5E(%-O
M9G1W87)E($9O=6YD871I;VXN"@H@("!4:&ES(&QI8G)A<GD@:7,@9&ES=')I
M8G5T960@:6X@=&AE(&AO<&4@=&AA="!I="!W:6QL(&)E('5S969U;"P*("`@
M8G5T(%=)5$A/550@04Y9(%=!4E)!3E19.R!W:71H;W5T(&5V96X@=&AE(&EM
M<&QI960@=V%R<F%N='D@;V8*("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%
M4U,@1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@
M3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@9F]R(&UO<F4@9&5T86EL
M<RX*"B`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE
M($=.52!,97-S97(@1V5N97)A;"!0=6)L:6,*("`@3&EC96YS92!A;&]N9R!W
M:71H('1H:7,@;&EB<F%R>3L@:68@;F]T+"!W<FET92!T;R!T:&4@1G)E92!3
M;V9T=V%R90H@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L
M(%-U:71E(#,S,"P@0F]S=&]N+`H@("!-02`@,#(Q,3$M,3,P-R`@55-!"@H*
M("`@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R8V4@3&EC96YS92!697)S
M:6]N(#$N,0H@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"B`@(%1H92!C;VYT96YT<R!O9B!T:&ES(&9I;&4@
M87)E('-U8FIE8W0@=&\@=&AE(%-U;B!);F1U<W1R>2!3=&%N9&%R9',*("`@
M4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$@*'1H92`B3&EC96YS92(I.R!9
M;W4@;6%Y(&YO="!U<V4@=&AI<R!F:6QE"B`@(&5X8V5P="!I;B!C;VUP;&EA
M;F-E('=I=&@@=&AE($QI8V5N<V4N(%EO=2!M87D@;V)T86EN(&$@8V]P>2!O
M9B!T:&4*("`@3&EC96YS92!A="!H='1P.B\O=W=W+F]P96YO9F9I8V4N;W)G
M+VQI8V5N<V4N:'1M;"X*"B`@(%-O9G1W87)E('!R;W9I9&5D('5N9&5R('1H
M:7,@3&EC96YS92!I<R!P<F]V:61E9"!O;B!A;B`B05,@25,B(&)A<VES+`H@
M("!7251(3U54(%=!4E)!3E19($]&($%.62!+24Y$+"!%251(15(@15A04D53
M4R!/4B!)35!,245$+"!)3D-,541)3D<L"B`@(%=)5$A/550@3$E-251!5$E/
M3BP@5T%24D%.5$E%4R!42$%4(%1(12!33T945T%212!)4R!&4D5%($]&($1%
M1D5#5%,L"B`@($U%4D-(04Y404),12P@1DE4($9/4B!!(%!!4E1)0U5,05(@
M4%524$]312P@3U(@3D].+4E.1E))3D=)3D<N"B`@(%-E92!T:&4@3&EC96YS
M92!F;W(@=&AE('-P96-I9FEC('!R;W9I<VEO;G,@9V]V97)N:6YG('EO=7(@
M<FEG:'1S(&%N9`H@("!O8FQI9V%T:6]N<R!C;VYC97)N:6YG('1H92!3;V9T
M=V%R92X*"B`@(%1H92!);FET:6%L($1E=F5L;W!E<B!O9B!T:&4@3W)I9VEN
M86P@0V]D92!I<SH@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@0V]P>7)I
M9VAT(,*I(#(P,#(@8GD@4W5N($UI8W)O<WES=&5M<RP@26YC+@H*("`@06QL
M(%)I9VAT<R!297-E<G9E9"X*"B`@($-O;G1R:6)U=&]R*',I.B!?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U]?7U\*"BTM/@H\>'-L.G-T
M>6QE<VAE970@=F5R<VEO;CTB,2XP(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M>'-L/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]4<F%N<V9O<FTB"B`@
M("`@("`@("`@("`@("!X;6QN<SIO9F9I8V4](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+V]F9FEC92(*("`@("`@("`@("`@("`@('AM;&YS.G-T>6QE
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]S='EL92(*("`@("`@("`@
M("`@("`@('AM;&YS.G1E>'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+W1E>'0B"B`@("`@("`@("`@("`@("!X;6QN<SIT86)L93TB:'1T<#HO+V]P
M96YO9F9I8V4N;W)G+S(P,#`O=&%B;&4B"B`@("`@("`@("`@("`@("!X;6QN
M<SID<F%W/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<F%W:6YG(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N;W)G+S$Y
M.3DO6%-,+T9O<FUA="(*("`@("`@("`@("`@("`@('AM;&YS.GAL:6YK/2)H
M='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;G5M8F5R/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D871A
M<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIS=F<](FAT='`Z+R]W=W<N
M=S,N;W)G+S(P,#`O<W9G(@H@("`@("`@("`@("`@("`@>&UL;G,Z8VAA<G0]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V-H87)T(@H@("`@("`@("`@
M("`@("`@>&UL;G,Z9'(S9#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O
M9'(S9"(*("`@("`@("`@("`@("`@('AM;&YS.FUA=&@](FAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3@O36%T:"]-871H34PB"B`@("`@("`@("`@("`@("!X;6QN
M<SIF;W)M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]F;W)M(@H@("`@
M("`@("`@("`@("`@>&UL;G,Z<V-R:7!T/2)H='1P.B\O;W!E;F]F9FEC92YO
M<F<O,C`P,"]S8W)I<'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z8VQA<W,]
M(G1E>'0B"B`@("`@("`@("`@("`@("!O9F9I8V4Z=F5R<VEO;CTB,2XP(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z9&,](FAT='`Z+R]P=7)L+F]R9R]D8R]E
M;&5M96YT<R\Q+C$O(@H@("`@("`@("`@("`@("`@>&UL;G,Z;65T83TB:'1T
M<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;65T82(*("`@("`@("`@("`@("`@
M('AM;&YS.F-O;F9I9STB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#$O8V]N
M9FEG(@H@("`@("`@("`@("`@("`@>&UL;G,Z:&5L<#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O:&5L<"(*("`@("`@("`@("`@("`@('AM;&YS.GAT
M/2)H='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0B"B`@("`@("`@("`@("`@("!E
M>'1E;G-I;VXM96QE;65N="UP<F5F:7AE<STB>'0B"B`@("`@("`@("`@("`@
M("!X;6QN<SIX86QA;CTB:'1T<#HO+WAM;"YA<&%C:&4N;W)G+WAA;&%N(@H@
M("`@("`@("`@("`@("`@>&UL;G,Z:F%V83TB:'1T<#HO+WAM;"YA<&%C:&4N
M;W)G+WAS;'0O:F%V82(*("`@("`@("`@("`@("`@(&5X8VQU9&4M<F5S=6QT
M+7!R969I>&5S/2)J879A(CX*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@8F]D>2`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*B`M+3X*"@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB+RHO;V9F:6-E
M.F)O9'DB/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H*("`@("`@("`\(2TM(&ES1&5B=6=-;V1E+5-405)4.B!O
M;FQY(&ES1&5B=6=-;V1E('!U<G!O<V4Z('-H;W=S('1H92!I;FQI;F5D('-T
M>6QE(&%T=')I8G5T97,@;V8@=&AE('1E;7!O<F%R>2!V87)I86)L92`M+3X*
M("`@("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92!A;F0@;F]T*"1O
M=71P=714>7!E(#T@)T-34U](14%$15(G*2(^"B`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)D96)U9U]T<F5E7V]F7W-T>6QE<R(^/'AS;#IT97AT
M/@H@("`@("`@("`@("`\+WAS;#IT97AT/CQX<VPZ9F]R+65A8V@@<V5L96-T
M/2(D8V]L;&5C=&5D1VQO8F%L1&%T82]A;&QS='EL97,O*B(^"CQX<VPZ=&5X
M=#X@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=&5X=#X\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB;F%M92@I(B\^/'AS;#IT97AT/B`](#PO>'-L.G1E>'0^
M/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX\>'-L.G1E>'0^"B`@("`@("`@
M("`@(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@/"]X
M<VPZ:68^"B`@("`\(2TM(&ES1&5B=6=-;V1E+45.1"`M+3X*"@H)"3PA+2T@
M;F]T('5S:6YG(&]F("=A<'!L>2US='EL97,M86YD+6-O;G1E;G0G(&%S('1H
M92!C;VYT96YT('1A8FQE(&EN9F]R;6%T:6]N(&UI9W1H(&AA=F4@8F5E;B!A
M9&1E9"!T;R`G8V]L;&5C=&5D1VQO8F%L1&%T82<@=F%R:6%B;&4@+2T^"B`@
M("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)`=&5X=#IS='EL
M92UN86UE('P@0&1R87<Z<W1Y;&4M;F%M92!\($!D<F%W.G1E>'0M<W1Y;&4M
M;F%M92!\($!T86)L93IS='EL92UN86UE(CX\(2TM('P@0'!R97-E;G1A=&EO
M;CIS='EL92UN86UE("TM/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D
M1VQO8F%L1&%T82(O/@H@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E<SX*
M"@H@("`@("`@(#PA+2T@57-A8FEL:71Y(&9E871U<F4L(&$@;&EN:R!T;R!T
M:&4@0V]N=&5N="!T86QB92!A8F]V92!A;&P@;&5V96P@,2!H96%D97(@+2T^
M"B`@("`@("`@/'AS;#II9B!T97-T/2(D8V]N=&5N=%1A8FQE2&5A9&EN9W,B
M/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB861D+6-H
M:6QD+61O8W5M96YT+75S86)I;&ET>2UL:6YK<R(O/@H@("`@("`@(#PO>'-L
M.FEF/@H*"@D)/'AS;#IC:&]O<V4^"@D@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)N;W0H)&]U='!U=%1Y<&4@/2`G5TU,)RD@86YD(&YO="@D;W5T<'5T5'EP
M92`]("=004Q-)RDB/@H)("`@("`@("`)/'AS;#IC:&]O<V4^"@D)"2`@("`@
M("`@/"$M+4EF('1H92!I;G!U="!D;V-U;65N="!I<R!A(&=L;V)A;"!D;V-U
M;65N="!A;F0@96UB960@8VAI;&0@9&]C=6UE;G1S("AL:6YK<RD@=&AE('1R
M86YS9F]R;6%T:6]N(&]F('1H92!C:&EL9')E;B!W:6QL(&)E('-T87)T960@
M87,@=V5L;"X*"0D)("`@("`@("`@("`@5&AI<R!I<R!N96-E<W-A<GD@87,@
M8VAI;&0@9&]C=6UE;G1S(&1O(&YO="!K;F]W(&%N>71H:6YG(&%B;W5T('1H
M96ER(&5M8F5D9&EN9R!I;G1O(&$@9VQO8F%L(&1O8W5M96YT+B!#:&%P=&5R
M<R!O9B!C:&EL9',*"0D)("`@("`@("`@("`@86QW87ES('-T87)T('1O(&-O
M=6YT(&)Y('IE<F\@:6YS=&5A9"!O9B!C;VYT:6YO=7-L>2!N=6UB97)I;F<N
M"@D)"2`@("`@("`@("`@($9O<B!T:&ES+"!T:&4@8VAA<'1E<B!N=6UB97)S
M(&]F('1H92!C=7)R96YT(&1O8W5M96YT("AA<R!A('-E<75E;F-E(&]F(&$@
M9VQO8F%L(&1O8W5M96YT*2!I<R!D97!E;F1E;G0*"0D)("`@("`@("`@("`@
M;V8@=&AE(&YU;6)E<B!O9B!C:&%P=&5R(&]F('1H92!S86UE(&QE=F5L(&EN
M('!R96-E9&EN9R!D;V-U;65N=',N"@D)"2`@("`@("`@("`@($EN(&-A<V4@
M;V8@;75L=&EP;&4@8VAI;&1R96XL(&9O<B!U<V%B:6QI='D@<F5A<V]N<R!S
M;VUE(&QI;FMI;F<@:7,@9V]N;F$@8F4@;V9F97)E9"!A;F0@=&AE(%523',@
M;V8@=&AE(&-O;G1E;G0M=&%B;&4L"@D)"2`@("`@("`@("`@('!R96-E9&EN
M9R!A;F0@9F]L;&]W:6YG(&9I;&4@:&%V92!T;R!B92!G:79E;B!F;W(@=&AE
M('1R86YS9F]R;6%T:6]N+@H)"0D@("`@("`@("`@("`M+3X*"0D@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB+RHO0&]F9FEC93IC;&%S<STG=&5X="UG
M;&]B86PG(&%N9"`O*B]O9F9I8V4Z8F]D>2]T97AT.G-E8W1I;VXO=&5X=#IS
M96-T:6]N+7-O=7)C92]`>&QI;FLZ:')E9B(^"@D)"0D)"3PA+2T@=&AE(&-H
M:6QD<F5N('=I;&P@8F4@8V%L;&5D(&QA=&5R('=I=&@@82!M;V1I9FEE9"`G
M8V]L;&5C=&5D1VQO8F%L1&%T82<@=F%R:6%B;&4@+2T^"@D)("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)T<F%N<V9O<FTM9VQO
M8F%L+61O8W5M96YT+6%N9"UC:&EL9')E;B(^"@D)("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H)"2`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H)"2`@("`@("`@("`@(#PO
M>'-L.G=H96X^"@D)"0D)/'AS;#IO=&AE<G=I<V4^"@D)"0D@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S/@H)"0D)("`@("`@("`@("`@/'AS;#IW:71H
M+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*"0D)"2`@("`@("`@/"]X<VPZ87!P;'DM
M=&5M<&QA=&5S/@H)"0D)"3PO>'-L.F]T:&5R=VES93X*"0D)"3PO>'-L.F-H
M;V]S93X*"2`@("`@("`@/"]X<VPZ=VAE;CX*"0D)/'AS;#IO=&AE<G=I<V4^
M"@D)("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<SX*"0D@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H)"2`@("`@("`@/"]X
M<VPZ87!P;'DM=&5M<&QA=&5S/@H)"0D\+WAS;#IO=&AE<G=I<V4^"@D)/"]X
M<VPZ8VAO;W-E/@H*"@H@("`@("`@(#PA+2T@57-A8FEL:71Y(&9E871U<F4L
M(&$@;&EN:R!T;R!T:&4@0V]N=&5N="!T86QB92!A8F]V92!A;&P@;&5V96P@
M,2!H96%D97(@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2(D8V]N=&5N=%1A
M8FQE2&5A9&EN9W,B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB861D+6-H:6QD+61O8W5M96YT+75S86)I;&ET>2UL:6YK<R(O/@H@
M("`@("`@(#PO>'-L.FEF/@H*"B`@("`\+WAS;#IT96UP;&%T93X*"@H*"B`@
M("`\(2TM(&1E86-T:79A=&EN9R!D969A=6QT('1E;7!L871E("TM/@H@("`@
M/'AS;#IT96UP;&%T92!M871C:#TB*B(O/@H*"B`@("`\(2TM(&%L;&]W:6YG
M(&%L;"!M871C:&5D('1E>'0@;F]D97,@+2T^"B`@("`\>'-L.G1E;7!L871E
M(&UA=&-H/2)T97AT*"DB/@H\(2TM(%=-3"`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)N;W)M86QI>F4M<W!A8V4H+BDB+SX@+2T^"B`@("`@("`@
M/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX*("`@(#PO>'-L.G1E;7!L871E
M/@H*"@H@("`@/"$M+2`C(R,C(R,C(R,C(R,C(R,C(R,C("TM/@H@("`@/"$M
M+2`C(R,@24Y,24Y%+51%6%0@(R,C("TM/@H@("`@/"$M+2`C(R,C(R,C(R,C
M(R,C(R,C(R,C("TM/@H*"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M
M+3X*("`@(#PA+2T@*BHJ(%=H:71E<W!A8V4@*BHJ("TM/@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T
M8V@](G1E>'0Z<R(^"B`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64]
M(G=R:71E+6)R96%K86)L92UW:&ET97-P86-E(CX*("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G=H:71E<W!A8V5S(B!S96QE8W0](D!T97AT
M.F,B+SX*("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#PA+2UW<FET92!T:&4@;G5M8F5R(&]F("=W:&ET
M97-P86-E<R<@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64](G=R:71E+6)R
M96%K86)L92UW:&ET97-P86-E(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(G=H:71E<W!A8V5S(B\^"@H@("`@("`@(#PA+2UW<FET92!T=V\@<W!A8V4@
M8VAA<G,@87,@=&AE(&YO<FUA;"!W:&ET92!S<&%C92!C:&%R86-T97(@=VEL
M;"!B92!S=')I<'!E9`H@("`@("`@("`@("!A;F0@=&AE(&]T:&5R(&ES(&%B
M;&4@=&\@8G)E86L@+2T^"B`@("`@("`@/'AS;#IT97AT/B8C,38P.SPO>'-L
M.G1E>'0^"B`@("`@("`@/'AS;#II9B!T97-T/2(D=VAI=&5S<&%C97,@/CT@
M,B(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET
M92UB<F5A:V%B;&4M=VAI=&5S<&%C92TR(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)W:&ET97-P86-E<R(@<V5L96-T/2(D=VAI
M=&5S<&%C97,@+2`Q(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA
M=&4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@
M("`@/"$M+7=R:71E('1H92!N=6UB97(@;V8@)W=H:71E<W!A8V5S)R`M+3X*
M("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E
M<W!A8V4M,B(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)W:&ET97-P86-E
M<R(O/@H@("`@("`@(#PA+2UW<FET92!T=V\@<W!A8V4@8VAA<G,@87,@=&AE
M(&YO<FUA;"!W:&ET92!S<&%C92!C:&%R86-T97(@=VEL;"!B92!S=')I<'!E
M9`H@("`@("`@("`@("!A;F0@=&AE(&]T:&5R(&ES(&%B;&4@=&\@8G)E86L@
M+2T^"B`@("`@("`@/'AS;#IT97AT/B`\+WAS;#IT97AT/@H@("`@("`@(#QX
M<VPZ:68@=&5S=#TB)'=H:71E<W!A8V5S(#X](#(B/@H@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA8FQE+7=H:71E
M<W!A8V4B/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(G=H:71E<W!A8V5S(B!S96QE8W0](B1W:&ET97-P86-E<R`M(#$B+SX*("`@
M("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#II
M9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@5&5X=&)O>"`J*BH@+2T^"B`@("`\
M(2TM("HJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)D<F%W.G1E>'0M8F]X(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@("`@(#QX<VPZ8VAO
M;W-E/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK($-34R`H0T%30T%$24Y'
M(%-43%E%(%-(1454*2!(14%$15(@4U193$4@5T%9("LK*RLK+2T^"B`@("`@
M("`@("`@("`@("`\(2TM("`@("`@("`@("`@("`@(&]R("`@("`@("`@("`@
M("`@("`@+2T^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@2%1-3"`T+C`@
M24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<@;W(@)&]U='!U
M=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F5L96UE;G0@;F%M93TB<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ:68@=&5S=#TB0&9O.FUI;BUH96EG:'0@?"!`<W9G.G=I9'1H
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E
M(&YA;64](G-T>6QE(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](FYO="A`<W9G.G=I9'1H*2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^
M:&5I9VAT.B`\+WAS;#IT97AT/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`9F\Z
M;6EN+6AE:6=H="(O/CQX<VPZ=&5X=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)N;W0H0&9O.FUI;BUH96EG:'0I(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YW:61T:#H@/"]X<VPZ=&5X
M=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0'-V9SIW:61T:"(O/CQX<VPZ=&5X
M=#X[(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/FAE:6=H=#H@/"]X<VPZ
M=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB0&9O.FUI;BUH96EG:'0B+SX\
M>'-L.G1E>'0^.R`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IT97AT/G=I9'1H.B`\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`<W9G.G=I9'1H(B\^/'AS;#IT97AT
M/CL@/"]X<VPZ=&5X=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P
M;'DM=&5M<&QA=&5S('-E;&5C=#TB0&1R87<Z;F%M92(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM
M<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM(#)$3R!P<F]V92!B97-T('5S
M86=E(&9O<B!004Q-("TM/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK(%!!
M3$T@,RXR(%-50E-%5"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G-P86XB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM(#)$3R!P
M<F]V92!B97-T('5S86=E(&9O<B!734P@+2T^"B`@("`@("`@("`@("`@("`\
M(2TM*RLK*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@
M/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!N;R!N
M97-T960@<"!T86=S(&EN('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP
M87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US
M='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$
M871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*("`@(#PA+2T@240@+R!.
M04U%(&]F('1E>'0M8F]X("TM/@H@("`@/'AS;#IT96UP;&%T92!M871C:#TB
M0&1R87<Z;F%M92(^"@H@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FED
M(CX*("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](BXB+SX*("`@
M("`@("`\+WAS;#IA='1R:6)U=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*
M("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@/"$M+2`J*BH@
M4&%R86=R87!H<R`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G`@?"!D<F%W
M.G!A9V4B/@H@("`@("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(O/@H*("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%150I
M($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?2$5!1$52)R(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK($A434P@
M-"XP($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB
M87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@4$%,32`S
M+C(@4U5"4T54($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!I;B!P86QM('!A<F%G<F%P:',@8VAI;&1R96X@;V8@
M=&5X=#IL:7-T+6ET96US(&%R92!B971T97(@<VAO=VX@=VET:&]U="`G<"<@
M=&%G+2T^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)N86UE*'!A<F5N=#HZ*BD@/2`G=&5X=#IL:7-T+6ET96TG(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T
M961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L
M;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@
M("`\(2TM*RLK*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"$M+2!N
M;R!N97-T960@<"!T86=S(&EN('=M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A
M<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L
M>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T
M:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@(#PO
M>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(%1E>'0@4W!A;B`J
M*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z<W!A;B(^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)
M3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U](
M14%$15(G(CX*("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)S
M<&%N(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!
M62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P
M=714>7!E(#T@)T-34U])3DQ)3D5$)R(^"B`@("`@("`@("`@("`@("`\>'-L
M.F5L96UE;G0@;F%M93TB<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@/'AS
M;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N
M="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-
M(#,N,B!354)3150@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@
M(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y
M;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@*RLK*RLM+3X*("`@("`@("`@
M("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(&YO(&YE
M<W1E9"!P('1A9W,@:6X@=VUL,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@
M("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I;G,H)'=A<"UP87)A9W)A<&@M
M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N
M=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M
M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L
M;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@/"]X<VPZ
M;W1H97)W:7-E/@H@("`@("`@(#PO>'-L.F-H;V]S93X*("`@(#PO>'-L.G1E
M;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H@("`@
M/"$M+2`J*BH@2&5A9&EN9W,@*BHJ("TM/@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ("TM/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z:"(^
M"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A
M(B\^"@H@("`@("`@(#PA+2T@179E<GD@:&5A9&EN9R!E;&5M96YT('=I;&P@
M9V5T(&%N('5N:7%U92!A;F-H;W(@9F]R(&ET<R!F:6QE+"!F<F]M(&ET<R!H
M:65A<F-H>2!L979E;"!A;F0@;F%M93H*("`@("`@("`@("`@1F]R(&5X86UP
M;&4Z("!4:&4@:&5A9&EN9R!T:71L92`G37D@9F%V;W)I=&4@:&5A9&EN9R<@
M;6EG:'0@9V5T(#QA(&YA;64](C$K,BLR*TUY*V9A=F]R:71E*VAE861I;F<B
M+SX@+2T^"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D9&ES86)L94QI;FME9%1A8FQE3V9#;VYT96YT(&]R("1I
M<TIA=F%$:7-A8FQE9"!O<B!N;W0H)&]U='!U=%1Y<&4@/2`G0U-37TA%041%
M4B<I(CX*("`@("`@("`@("`@/"$M+2!4:&4@55),(&QI;FMI;F<@;V8@86X@
M=&%B;&4M;V8M8V]N=&5N="!I<R!D=64@=&\@82!B=6<@*&-M<"X@8G5G(&ED
M(R`Q,#(S,3$I(&YO="!M87!P960@87,@55),(&EN('1H92!834PN"B`@("`@
M("`@("`@("`@("`@3&EN:VEN9R!O9B!T:&4@=&%B;&4M;V8M8V]N=&5N="!C
M86X@=&AE<F5F;W)E(&]N;'D@8F4@87)C:&EE=F5D(&)Y(&$@=V]R:RUA<F]U
M;F0@:6X@2%1-3"`M+3X*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M:&5A9&EN9R(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@
M(#PA+2T@;F5C97-S87)Y(&%S(&%N8VAO<B!F;W(@=&AE(&-O;G1E;G0@=&%B
M;&4@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M
M93TB8W)E871E+6AE861I;F<M86YC:&]R(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@
M<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*"B`@("`@("`@("`@("`@("`\(2TM
M(&YO(&5M8F5D9&EN9R!T:&4@;W)G:6YA;"!H96%D97(L(&%S(&%N(&5X<&QI
M8VET(&%N8VAO<B!M:6=H="!B92!A;')E861Y('-E="`M+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M:&5A9&EN
M9R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^
M"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC
M:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H@("`@/"$M+2!D969A=6QT
M(&UA=&-H:6YG(&9O<B!H96%D97(@96QE;65N=',@+2T^"B`@("`\>'-L.G1E
M;7!L871E(&YA;64](F-R96%T92UH96%D:6YG(CX*("`@("`@("`\>'-L.G!A
M<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS
M;#IC:&]O<V4^"B`@("`@("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.
M1R!35$Q912!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%
M041%4B<B/@H*("`@("`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M:&5A9&5R='EP(B!S96QE8W0](F-O;F-A="@G:"<L($!T97AT.FQE=F5L*2(O
M/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](GLD:&5A9&5R
M='EP?2(^"@H@("`@("`@("`@("`@("`@("`@(#PA+2T@;W5T;&EN92!S='EL
M92`G=&5X=#IM:6XM;&%B96PM=VED=&@G(&ES(&EN=&5R<')E=&5D(&%S(&$@
M0U-3("=M87)G:6XM;&5F="<@871T<FEB=71E("TM/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB;6EN+6QA8F5L(B!S96QE8W0]
M(B1O9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI
M;F4M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z
M;&5V96Q=+W-T>6QE.G!R;W!E<G1I97,O0'1E>'0Z;6EN+6QA8F5L+7=I9'1H
M(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D;6EN+6QA
M8F5L(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA='1R:6)U=&4@
M;F%M93TB<W1Y;&4B/CQX<VPZ=&5X=#YM87)G:6XM;&5F=#H\+WAS;#IT97AT
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2(D;6EN+6QA8F5L(B\^/'AS;#IT97AT
M/CL\+WAS;#IT97AT/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@
M("`@("`\+WAS;#II9CX*"@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ871T
M<FEB=71E(&YA;64](F-L87-S(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB=')A
M;G-L871E*$!T97AT.G-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I(B\^/"]X
M<VPZ871T<FEB=71E/@H*("`@("`@("`@("`@("`@("`@("`\(2TM('=R:71I
M;F<@;W5T(&$@8VAA<'1E<B!N=6UB97(@:68@9&5S:7)E9"`H;F]T:6-A8FQE
M('=H96X@82!C;W)R97-P;VYD:6YG("=T97AT.F]U=&QI;F4M<W1Y;&4G(&5X
M:7-T("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB<W1R
M:6YG+6QE;F=T:"@D;V9F:6-E.G-T>6QE<R]T97AT.F]U=&QI;F4M<W1Y;&4O
M=&5X=#IO=71L:6YE+6QE=F5L+7-T>6QE6T!T97AT.FQE=F5L(#T@8W5R<F5N
M="@I+T!T97AT.FQE=F5L72]`<W1Y;&4Z;G5M+69O<FUA="D@(3T@,"(^"@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D9&ES86)L94QI
M;FME9%1A8FQE3V9#;VYT96YT(&]R("1I<TIA=F%$:7-A8FQE9"!O<B!N;W0H
M)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<I(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM('1H92!C:&%P=&5R(&YU;6)E<B!I<R!T
M:&4@<W5M(&]F("=T97AT.G-T87)T+79A;'5E)R!A;F0@<')E8V5D:6YG('-I
M8FQI;F=S(&]F("=T97AT.F@G('=I=&@@=&AE('-A;64@)W1E>'0Z;&5V96PG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9G5R=&AE
M<FUO<F4@=VAE;B!T:&4@8W5R<F5N="!D;V-U;65N="!I<R!R969E<F5N8V5D
M(&)Y(&$@9VQO8F%L(&1O8W5M96YT("T@87,@<&%R="!O9B!A('=H;VQE('-E
M<75E;F-E(&]F(&1O8W5M96YT<R`M+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(&-H87!T97(@;F\N(&ES(&1E<&5N9&5N="!O
M9B!T:&4@86UO=6YT(&]F('-T87)T960@:&5A9&5R<R!I;B!P<F5C961I;F<@
M9&]C=6UE;G1S+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@268@=&AE("=T97AT.G-T87)T+79A;'5E(&ES(&YO="!S970@=&AE(&1E
M9F%U;'0@=F%L=64@;V8@)S$G(&AA<R!T;R!B92!T86ME;BX@+2T^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I86)L92!N86UE
M/2)S=&%R=%9A;'5E(B!S96QE8W0](B1O9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T
M;&EN92US='EL92]T97AT.F]U=&QI;F4M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V
M96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=+T!T97AT.G-T87)T+79A;'5E
M(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2(D<W1A<G1686QU92(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB0'1E>'0Z;&5V96P])S$G(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0]
M(F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@
M/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P
M<F5C961I;F=#:&%P=&5R3&5V96PQ"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'-T87)T
M5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E
M;#TG,B<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D
M:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`
M=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T
M97),979E;#(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<S)R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ
M=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L,PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'1E>'0Z;&5V96P])S0G(CX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z
M;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PT"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@
M)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X
M=#IL979E;#TG-2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H
M<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E
M;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN
M9T-H87!T97),979E;#4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G1686QU92(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<V)R(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB
M;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE
M=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L
M-@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S<G(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU
M92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;
M0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PW"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@)'-T87)T5F%L=64B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)`=&5X=#IL979E;#TG."<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`]
M(&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R
M96-E9&EN9T-H87!T97),979E;#@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<W1A<G16
M86QU92(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L
M/2<Y)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I
M;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T
M97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L.0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K("1S=&%R=%9A;'5E(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S$P)R(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ
M=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L,3`*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*R`D<W1A<G1686QU92(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O
M<V4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE
M=F5L/2<Q)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C
M961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I
M+T!T97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA
M<'1E<DQE=F5L,0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E;#TG,B<B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E
M+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`
M=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#(*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V
M96P])S,G(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E
M9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO
M0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P
M=&5R3&5V96PS"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](D!T97AT.FQE=F5L/2<T)R(^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2)C;W5N="AP<F5C961I;F<M<VEB;&EN9SHZ=&5X=#IH6T!T
M97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE=F5L72D*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*R`D<')E8V5D:6YG0VAA<'1E<DQE=F5L-`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`K(#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`=&5X=#IL979E
M;#TG-2<B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E8V5D
M:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`
M=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("L@)'!R96-E9&EN9T-H87!T
M97),979E;#4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*R`Q(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P])S8G(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O=6YT*'!R96-E9&EN9RUS:6)L:6YG.CIT97AT.FA;0'1E
M>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V96Q=*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`K("1P<F5C961I;F=#:&%P=&5R3&5V96PV"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](D!T97AT.FQE=F5L
M/2<W)R(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;W5N="AP<F5C961I
M;F<M<VEB;&EN9SHZ=&5X=#IH6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T
M97AT.FQE=F5L72D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*R`D<')E8V5D:6YG0VAA<'1E
M<DQE=F5L-PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`K(#$B+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VAE;B!T97-T/2)`=&5X=#IL979E;#TG."<B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X
M=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*R`Q(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'1E>'0Z;&5V96P]
M)SDG(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O=6YT*'!R96-E9&EN
M9RUS:6)L:6YG.CIT97AT.FA;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E
M>'0Z;&5V96Q=*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`K("1P<F5C961I;F=#:&%P=&5R
M3&5V96PY"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("L@,2(O/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](D!T97AT.FQE=F5L/2<Q,"<B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X
M=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("L@)'!R96-E9&EN9T-H87!T97),979E;#$P"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("L@,2(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F=E
M="UA8G-O;'5T92UC:&%P=&5R+6YO(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!R96-E9&EN
M9T-H87!T97),979E;#$B("`@('-E;&5C=#TB)'!R96-E9&EN9T-H87!T97),
M979E;#$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@
M("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#X@)B,Q-C`[("8C,38P.SPO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H*("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"@H*("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.3$E.
M140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=F%R:6%B;&4@;F%M93TB:&5A9&5R='EP(B!S96QE8W0](F-O;F-A
M="@G:"<L($!T97AT.FQE=F5L*2(O/@H@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](GLD:&5A9&5R='EP?2(^"@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB0'1E>'0Z<W1Y;&4M
M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ87!P
M;'DM=&5M<&QA=&5S/@H*("`@("`@("`@("`@("`@("`@("`\(2TM('=R:71I
M;F<@;W5T(&$@8VAA<'1E<B!N=6UB97(@:68@9&5S:7)E9"`H;F]T:6-A8FQE
M('=H96X@82!C;W)R97-P;VYD:6YG("=T97AT.F]U=&QI;F4M<W1Y;&4G(&5X
M:7-T("TM/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB)&]F
M9FEC93IS='EL97,O=&5X=#IO=71L:6YE+7-T>6QE+W1E>'0Z;W5T;&EN92UL
M979E;"US='EL95M`=&5X=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E
M;%TO0'1E>'0Z<W1Y;&4M;F%M92(^"@H@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM('1H92!C:&%P=&5R(&YU;6)E<B!I<R!T:&4@<W5M(&]F("=T97AT
M.G-T87)T+79A;'5E)R!A;F0@<')E8V5D:6YG('-I8FQI;F=S(&]F("=T97AT
M.F@G('=I=&@@=&AE('-A;64@)W1E>'0Z;&5V96PG("TM/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]U;G0H<')E
M8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X=#IL979E;"`](&-U<G)E;G0H
M*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R`D;V9F:6-E.G-T>6QE<R]T97AT.F]U=&QI;F4M
M<W1Y;&4O=&5X=#IO=71L:6YE+6QE=F5L+7-T>6QE6T!T97AT.FQE=F5L(#T@
M8W5R<F5N="@I+T!T97AT.FQE=F5L72]`=&5X=#IS=&%R="UV86QU92(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^("8C,38P.R`F(S$V
M,#L\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*
M("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@(#PO
M>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM(#)$3SH@861D($-H87!T97(@
M3F\N(&9O<B!004Q-(&%N9"!734P@/"T^('!R;V)L96T@;F5S=&5D(&%P<&QY
M+71E;7!L871E<R`M+3X*"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N
M,B!354)3150@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](FAE861E<G1Y<"(@<V5L96-T
M/2)C;VYC870H)V@G+"!`=&5X=#IL979E;"DB+SX*("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)[)&AE861E<G1Y<'TB/@H*"B`@("`@("`@
M("`@("`@("`@("`@/"$M+2!!;&P@8VAI;&1R96X@8V]N=&5N="!H879E('1O
M(&)E(&YE<W1E9"!I;B!T:&4@<W1Y;&5S("AE+F<N(#QI/CQB/D%.62!#3TY4
M14Y4/"]B/CPO:3XI"B`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@=&AI
M<R!X<VPZ87!P;'DM=&5M<&QA=&5S('=I;&P@8F4@8V%L;&5D(&QA=&5R("\@
M:6UP;&EC:70@+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F-R96%T92UA='1R:6)U=&4M04Q)1TXB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM(&=E='1I;F<@=&AE(&-S<R!S='EL97,@
M9F]R('1H92!S='EL92!N86UE("AM87!P960@8GD@<W1Y;&4M;6%P<&EN9RYX
M<VPI("TM/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB<W1Y;&50<F]P97)T:65S(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A+V%L;'-T>6QE<R\J6VYA;64H*3UC=7)R96YT*"DO0'1E>'0Z
M<W1Y;&4M;F%M95TB+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!7
M34P@+R!705`@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/"$M+2!N;R!N97-T960@<"!T86=S(&EN('=M
M;#$N,2!A;&QO=V5D("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F%N8V5S=&]R
M.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S+"!N86UE*"DI
M72(^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<VEN8V4@;F\@:&5A
M9&5R('-T>6QE<R!E>&ES="P@86X@96UP:&%S:7,@:7,@=7-E9"`M+3X*("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F5M(CX*
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM('=R:71I;F<@;W5T
M(&$@8VAA<'1E<B!N=6UB97(@:68@9&5S:7)E9"`H;F]T:6-A8FQE('=H96X@
M82!C;W)R97-P;VYD:6YG("=T97AT.F]U=&QI;F4M<W1Y;&4G(&5X:7-T("TM
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#II9B!T97-T/2(D
M;V9F:6-E.G-T>6QE<R]T97AT.F]U=&QI;F4M<W1Y;&4O=&5X=#IO=71L:6YE
M+6QE=F5L+7-T>6QE6T!T97AT.FQE=F5L(#T@8W5R<F5N="@I+T!T97AT.FQE
M=F5L72]`=&5X=#IS='EL92UN86UE(CX*"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/"$M+2!T:&4@8VAA<'1E<B!N=6UB97(@:7,@=&AE('-U
M;2!O9B`G=&5X=#IS=&%R="UV86QU92<@86YD('!R96-E9&EN9R!S:6)L:6YG
M<R!O9B`G=&5X=#IH)R!W:71H('1H92!S86UE("=T97AT.FQE=F5L)R`M+3X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]U;G0H<')E8V5D:6YG+7-I8FQI;F<Z.G1E>'0Z:%M`=&5X
M=#IL979E;"`](&-U<G)E;G0H*2]`=&5X=#IL979E;%TI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`K("1O
M9F9I8V4Z<W1Y;&5S+W1E>'0Z;W5T;&EN92US='EL92]T97AT.F]U=&QI;F4M
M;&5V96PM<W1Y;&5;0'1E>'0Z;&5V96P@/2!C=7)R96YT*"DO0'1E>'0Z;&5V
M96Q=+T!T97AT.G-T87)T+79A;'5E(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IT97AT/B`F(S$V,#L@)B,Q-C`[/"]X<VPZ=&5X
M=#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ87!P;'DM=&5M<&QA=&5S
M('-E;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L
M871E<SX*"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@
M("`@/'AS;#IE;&5M96YT(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/"$M+2!S:6YC92!N;R!H96%D97(@<W1Y;&5S(&5X:7-T+"!A
M;B!E;7!H87-I<R!I<R!U<V5D("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](F5M(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P
M;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R
M=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T
M93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ
M($QI;FL@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@
M("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.F$@?"!D<F%W.F$B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H*
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;6UO
M;BUL:6YK(CX*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E+6-O
M;6UO;BUL:6YK(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H)&]U='!U=%1Y<&4@/2`G5TU,)RDB
M/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F$B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAR968B/CQX
M<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@("`@("`\(2TM/'AS;#IA='1R:6)U=&4@
M;F%M93TB8VQA<W,B/D-O;G1E;G1,:6YK/"]X<VPZ871T<FEB=71E/BTM/@H@
M("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A
M<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@(#PA+2T@
M;F\@;F5S=&5D('`@=&%G<R!I;B!W;6PQ+C$@86QL;W=E9"`M+3X*("`@("`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN<R@D=V%P+7!A<F%G
M<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB82(^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX\>'-L.G9A
M;'5E+6]F('-E;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R:6)U=&4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L
M871E<R!S96QE8W0](F1E<V-E;F1A;G0Z.G1E>'0H*2(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE
M;65N="!N86UE/2)A(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)H<F5F(CX\>'-L.G9A;'5E+6]F('-E
M;&5C=#TB0'AL:6YK.FAR968B+SX\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@
M<V5L96-T/2)D97-C96YD86YT.CIT97AT*"DB+SX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@/"]X
M<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@/"]X<VPZ8VAO
M;W-E/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*"@H*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ($EM86=E($QI;FL@("HJ
M*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\
M>'-L.G1E;7!L871E(&UA=&-H/2)D<F%W.FEM86=E(CX*("`@("`@("`\>'-L
M.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@
M/"$M+2!.3R!)34%'15,@4U504$Q)140@1D]2(%=!4"!/4B!004Q-("TM/@H@
M("`@("`@(#QX<VPZ:68@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%
M4B<@;W(@)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*"B`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)I;6<B/@H@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2)`<W9G.G=I9'1H(CX*("`@("`@("`@("`@("`@("`@
M("`\>'-L.F%T=')I8G5T92!N86UE/2)W:61T:"(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C;VYV97)T,G!I
M>&5L(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)V86QU92(@<V5L96-T/2)`<W9G.G=I9'1H(B\^"B`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@/"]X<VPZ:68^"B`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](D!S
M=F<Z:&5I9VAT(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)H96EG:'0B/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB8V]N=F5R=#)P:7AE;"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB=F%L
M=64B('-E;&5C=#TB0'-V9SIH96EG:'0B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M("`@("`@("`@("`@("`@(#QX<VPZ:68@=&5S=#TB<W9G.F1E<V,B/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](F%L="(^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S
M=F<Z9&5S8R(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I8G5T
M93X*("`@("`@("`@("`@("`@(#PO>'-L.FEF/@H@("`@("`@("`@("`@("`@
M/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`@("`@(#PA+2T@9F]R(&EM
M86=E<R!J87)E9"!I;B!O<&5N(&]F9FEC92!D;V-U;65N="`M+3X*("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB8V]N=&%I;G,H0'AL:6YK
M.FAR968L("<C4&EC='5R97,O)RDB/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM(&-R96%T:6YG(&%N(&%B<V]L=71E(&AT='`@55),('1O('1H92!P
M86-K960@:6UA9V4@9FEL92`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB<W)C(CX\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB8V]N8V%T*"1J87)E9%)O;W154DPL("<O4&EC='5R97,O)RP@<W5B<W1R
M:6YG+6%F=&5R*$!X;&EN:SIH<F5F+"`G(U!I8W1U<F5S+R<I+"`D;W!T:6]N
M86Q54DQ3=69F:7@I(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"CPA+2T@("`@("`@("`@("`@("`@("`@($1U
M92!T;R!A(%A4(&)U9R!N;R!$3U,@)SHG(&)E9F]R92!$4DE612!L971T97(@
M:7,@86QL;W=E9"P@:70@=V]U;&0@<F5S=6QT(&EN(&$@=6YK;W=N('!R;W1O
M8V\@97AC97!T:6]N+"!B=70@82!F:6QE(%523"!F;W(@82!$3U,*"0D)"0D)
M<&%T:"!N965D<R!T:&4@1%))5D4@;&5T=&5R+"!T:&5R969O<F4@86QL(')E
M;&%T:79E(%523',@<F5M86EN(')E;&%T:78*"@D)"0D)/'AS;#IW:&5N('1E
M<W0](F-O;G1A:6YS*$!X;&EN:SIH<F5F+"<O+R<I(&]R("AS=6)S=')I;F<H
M0'AL:6YK.FAR968L,BPQ*2`]("<Z)RD@;W(@<W1A<G1S+7=I=&@H0'AL:6YK
M.FAR968L("<O)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T
M=')I8G5T92!N86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI
M;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\(7Y^(&-R96%T:6YG(&$@
M86)S;VQU=&4@<&%T:"]54DP@9F]R('1H92!R969E<F5N8V5D(')E<V]U<F-E
M('Y^/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N
M86UE/2)S<F,B/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)&%B<V]L
M=71E4V]U<F-E1&ER4F5F+"!`>&QI;FLZ:')E9BP@)&]P=&EO;F%L55),4W5F
M9FEX*2(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IO=&AE<G=I<V4^"BTM/@H)"0D)"3QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE/2)S<F,B
M/CQX<VPZ=F%L=64M;V8@<V5L96-T/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T
M=')I8G5T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M
M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@
M(#PA+2T@861D:6YG(&$@;&EN92!B<F5A:R!T;R!M86ME('1H92!P<F5S96YT
M871I;VX@;6]R92!E=F5N('=I=&@@=&AE($]/;R!V:65W("TM/@H@("`@("`@
M("`@("`\>'-L.F5L96UE;G0@;F%M93TB8G(B+SX*("`@("`@("`\+WAS;#II
M9CX*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/"$M+2`J*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&]R9&5R960@;&ES="`J*BH@
M+2T^"B`@("`\(2TM("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM/@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z;W)D97)E9"UL:7-T(CX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@
M("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@/"$M+2LK
M*RLK($-34R`H0T%30T%$24Y'(%-43%E%(%-(1454*2!(14%$15(@4U193$4@
M5T%9("LK*RLK+2T^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB
M)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)O;"(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!
M62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D
M;W5T<'5T5'EP92`]("=#4U-?24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)O;"(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M
M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C
M=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*
M("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@04Y$
M(%=!4"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=004Q-)R(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F]L(CX*("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T
M82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@
M("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`\+WAS
M;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M+2LK*RLK(%=-3"`O(%=!4"`@
M*RLK*RLM+3X*("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\(2TM('-I;75L871I;F<@8V]N=&5N="!B<F5A:R!O9B!C87!S
M=6QA=&5D(&QI<W0@96QE;65N=',@+2T^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ=&5X=#IL:7-T+6ET96TB
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0]
M(F%N8V5S=&]R.CHJ6V-O;G1A:6YS*"1W87`M<&%R86=R87!H+65L96UE;G1S
M+"!N86UE*"DI72(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PA+2T@<VEM=6QA=&EN9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T
M960@;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F)R(CX\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT
M(&YA;64](G`B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"$M+2!S:6UU;&%T:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L
M871E9"!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F)R(CX\+WAS
M;#IE;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA
M;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*("`@(#PA
M+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ('5N
M;W)D97)E9"!L:7-T("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G5N
M;W)D97)E9"UL:7-T(CX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q912!32$5%5"D@
M2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G0U-37TA%041%4B<B/@H@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](G5L(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S
M+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB
M)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\
M+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE
M;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA
M+2TK*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U])3DQ)
M3D5$)R(^"B`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB=6PB
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L
M1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@
M("`@("`\+WAS;#IE;&5M96YT/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H*
M("`@("`@("`@("`@/"$M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!!3D0@5T%0
M($E.3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@
M=&5S=#TB)&]U='!U=%1Y<&4@/2`G4$%,32<B/@H@("`@("`@("`@("`@("`@
M/'AS;#IE;&5M96YT(&YA;64](G5L(CX*("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT
M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E
M9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL
M+71E;7!L871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@
M("`@("`@("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!7
M34P@+R!705`@("LK*RLK+2T^"B`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E
M/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@/"$M+2!S:6UU;&%T:6YG(&-O;G1E;G0@8G)E86L@;V8@8V%P<W5L
M871E9"!L:7-T(&5L96UE;G1S("TM/@H@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ=&5X=#IL:7-T+6ET96TB/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ*EMC
M;VYT86EN<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@<VEM=6QA=&EN
M9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T960@;&ES="!E;&5M96YT<R`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE
M;G0@;F%M93TB8G(B/CPO>'-L.F5L96UE;G0^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY
M+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961'
M;&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F]T:&5R=VES93X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@
M;F%M93TB<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#PA+2T@<VEM=6QA=&EN9R!C;VYT96YT(&)R96%K(&]F(&-A<'-U;&%T960@
M;&ES="!E;&5M96YT<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64](F)R(CX\+WAS;#IE;&5M96YT
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A
M;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@
M("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IO
M=&AE<G=I<V4^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT
M96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT
M96UP;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO
M>'-L.F]T:&5R=VES93X*("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ("TM
M/@H@("`@/"$M+2`J*BH@;&ES="!I=&5M("`J*BH@+2T^"B`@("`\(2TM("HJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H
M/2)T97AT.FQI<W0M:71E;2(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@
M("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)3D<@4U1,644@4TA%
M150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@("`@("`@("`@/'AS
M;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$15(G(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)L:2(^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T
M>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE
M8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@
M("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L
M.F5L96UE;G0^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@
M("`\(2TM*RLK*RL@2%1-3"`T+C`@24Y,24Y%1"!705D@("LK*RLK+2T^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?
M24Y,24Y%1"<B/@H@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(FQI(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@
M("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N,B!354)3150@04Y$
M(%=!4"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](B1O=71P=714>7!E(#T@)U!!3$TG(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ96QE;65N="!N86UE/2)L:2(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M
M8V]N=&5N="(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL
M96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"@H@("`@("`@("`@("`\(2TM*RLK
M*RL@5TU,("\@5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)A;F-E<W1O<CHZ*EMC;VYT86EN
M<R@D=V%P+7!A<F%G<F%P:"UE;&5M96YT<RP@;F%M92@I*5TB/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM('-I;75L871I;F<@;&ES="!E;&5M96YT
M<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S
M96QE8W0](F%N8V5S=&]R.CIT97AT.FQI<W0M:71E;2(^*CPO>'-L.F9O<BUE
M86-H/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G1E>'0^*B`\+WAS
M;#IT97AT/@H@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M
M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$
M871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@(#PA+2T@;&ES="!I=&5M
M(&)R96%K('-I;75L871I;VX@*&YO="!I;B!A('1A8FQE*2TM/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.FEF('1E<W0](FYO="AA;F-E<W1O<CHZ
M=&%B;&4Z=&%B;&4M8V5L;"D@;W(@9F]L;&]W:6YG+7-I8FQI;F<Z.G1E>'0Z
M;&ES="UI=&5M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M96QE;65N="!N86UE/2)B<B(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\
M+WAS;#II9CX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB<"(^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\(2TM('-I;75L871I;F<@;&ES="!E;&5M96YT
M<R`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A
M8V@@<V5L96-T/2)A;F-E<W1O<CHZ=&5X=#IL:7-T+6ET96TB/BH\+WAS;#IF
M;W(M96%C:#X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X
M=#XJ(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\
M>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT
M96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D
M8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PA+2T@;&ES="!I=&5M(&)R96%K('-I;75L871I;VX@*&YO
M="!I;B!A('1A8FQE*2TM/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#II9B!T97-T/2)N;W0H86YC97-T;W(Z.G1A8FQE.G1A8FQE+6-E;&PI
M(&]R(&9O;&QO=VEN9RUS:6)L:6YG.CIT97AT.FQI<W0M:71E;2(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE;&5M96YT(&YA;64]
M(F)R(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#II9CX*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*
M("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`\+WAS;#IT96UP;&%T93X*"@H*
M("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(%1E>'0@4V5C=&EO;B`H8V]N
M=&%I;G,Z(&1R87<Z=&5X="UB;W@I("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*
M"B`@("`@("`@/'AS;#IT96UP;&%T92!M871C:#TB=&5X=#IS96-T:6]N(CX*
M("`@("`@("`\>'-L.G!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*"B`@("`@("`@/'AS;#II9B!T97-T/2)N;W0H8V]N=&%I;G,H0'1E>'0Z
M9&ES<&QA>2P@)VYO;F4G*2DB/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@(#PA+2TK*RLK*R!#4U,@*$-!4T-!1$E.1R!35$Q9
M12!32$5%5"D@2$5!1$52(%-464Q%(%=!62`K*RLK*RTM/@H@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U](14%$
M15(G(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB
M<W!A;B(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O
M;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A
M=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP
M;&%T93X*("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M96YT/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@(#PA+2TK
M*RLK*R!(5$U,(#0N,"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*("`@("`@("`@
M("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]("=#4U-?24Y,
M24Y%1"<B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE
M/2)S<&%N(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E
M;7!L871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L
M1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@
M("`@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@/"$M
M+2LK*RLK(%!!3$T@,RXR(%-50E-%5"!)3DQ)3D5$(%=!62`@*RLK*RLM+3X*
M("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2(D;W5T<'5T5'EP92`]
M("=004Q-)R(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N86UE*'!A
M<F5N=#HZ*BD@/2`G=&5X=#IL:7-T+6ET96TG(CX*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B/@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T
M961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ96QE;65N="!N86UE/2)P(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB87!P;'DM<W1Y
M;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\(2TM*RLK*RL@5TU,("\@
M5T%0("`K*RLK*RTM/@H@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)N;W0H)&]U='!U=%1Y<&4@
M/2`G5TU,)RDB/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IE
M;&5M96YT(&YA;64](F$B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](FAR968B/CQX<VPZ=F%L=64M;V8@
M<V5L96-T/2)`>&QI;FLZ:')E9B(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@
M;F%M93TB87!P;'DM<W1Y;&5S+6%N9"UC;VYT96YT(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64]
M(F-O;&QE8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS
M;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ96QE;65N=#X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M=VAE;CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\(2TM(&YO(&YE<W1E9"!P
M('1A9W,@:6X@=VUL,2XQ(&%L;&]W960@+2T^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB86YC97-T;W(Z.BI;8V]N=&%I
M;G,H)'=A<"UP87)A9W)A<&@M96QE;65N=',L(&YA;64H*2E=(CX*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IO=&AE<G=I<V4^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)P(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A<'!L>2US='EL97,M86YD+6-O;G1E;G0B
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S
M96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE
M;&5M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W
M:7-E/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-H;V]S93X*("`@("`@
M("`@("`@("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ
M8VAO;W-E/@H@("`@("`@(#PO>'-L.FEF/@H@("`@/"]X<VPZ=&5M<&QA=&4^
M"@H*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.FQI;F4M8G)E86LB
M/@H@("`@("`@(#QX<VPZ96QE;65N="!N86UE/2)B<B(O/@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*/"$M+0H@("`@5$%"2$%.1$Q)3D<@4%)/0DQ%33H@5&%B
M<R!A<F4@<&]S<VEB;&4@=&\@8F4@<VAO=VX@:6X@=&AE($A434P@=&5X="!F
M:6QE+"!B=70@=VEL;"!B92!L871E<B!S=')I<'!E9"!A<R!W:&ET97-P86-E
M<RX*("`@("`@("!4;R!P<F5V96YT('1H:7,@;VYE('=A>2!W;W5L9"!B92!T
M:&4@4%)%('1A9R!W:&EC:"!U;F9O<G1U;F%T96QY($%,5T%94R!R97-U;'0@
M:6YT;R!A(&QI;F4M8G)E86LN($YO('-U<G)O=6YD:6YG($Y/0E(@=&%G<R!H
M96QP+@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z=&%B+7-T;W`B
M/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*'!R96-E9&EN9RUS:6)L:6YG
M.CIT97AT.G1A8BUS=&]P*2(^"B`@("`@("`@("`@(#QX<VPZ96QE;65N="!N
M86UE/2)P<F4B/CQX<VPZ=&5X=#XF(SD[/"]X<VPZ=&5X=#X\>'-L.F9O<BUE
M86-H('-E;&5C=#TB9F]L;&]W:6YG+7-I8FQI;F<Z.G1E>'0Z=&%B+7-T;W`B
M/CQX<VPZ=&5X=#XF(SD[/"]X<VPZ=&5X=#X\+WAS;#IF;W(M96%C:#X\+WAS
M;#IE;&5M96YT/@H@("`@("`@(#PO>'-L.FEF/@H@("`@(#PO>'-L.G1E;7!L
M871E/@H*("`@(#QX<VPZ=&5M<&QA=&4@;6%T8V@](G1E>'0Z=&%B+7-T;W`B
M/CQX<VPZ=&5X=#XF(SD[/"]X<VPZ=&5X=#X\+WAS;#IT96UP;&%T93X*+2T^
M"B`@("`\(2TM($A/5$9)6#H@."!N;VXM8G)E86MA8FQE+7-P86-E<R!I;G-T
M96%D(&]F(&$@5$%"(&ES(&$@:&%C:R!S;VUE=&EM97,@;&5S<R!486)S(&%R
M92!N965D960@86YD('1H92!C;V1E(&UO<F4@9&EF9FEC=6QT('1O(')E860@
M+2T^"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T97AT.G1A8BUS=&]P(CX*
M("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M8G)E86MA
M8FQE+7=H:71E<W!A8V4B/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB=VAI=&5S<&%C97,B('-E;&5C=#TB."(O/@H@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`\+WAS;#IT96UP;&%T93X*"B`@("`\(2TM
M(&-U<G)E;G1L>2!T:&5R92!H879E('1O(&)E(&%N(&5X<&QI8VET(&-A;&P@
M;V8@=&AE('-T>6QE(&%T=')I8G5T92!N;V1E<RP@;6%Y8F4@=&AE(&%T=')I
M8G5T97,@;F]D97,@:&%V92!N;R!P<FEO<FET>2!O;FQY(&]R9&5R(')E;&5V
M86YT+2T^"B`@("`\(2TM(%-44D%.1T4Z(&-H96-K960@=VET:"!B:6]R>71H
M;2YS>&,@82!S:6UP;&4@>'-L.F%P<&QY+71E;7!L871E<R!D:60@;F]T(')E
M8V]G;FEC92!T:&4@<W1Y;&5S+B!-87EB92!C875S960@8GD@=&AE('1E;7!L
M871E(&UA=&-H(&]R9&5R/R`@+2T^"B`@("`\>'-L.G1E;7!L871E(&YA;64]
M(F%P<&QY+7-T>6QE<RUA;F0M8V]N=&5N="(^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX<VPZ
M87!P;'DM=&5M<&QA=&5S('-E;&5C=#TB0'1E>'0Z<W1Y;&4M;F%M92!\($!D
M<F%W.G-T>6QE+6YA;64@?"!`9')A=SIT97AT+7-T>6QE+6YA;64@?"!`=&%B
M;&4Z<W1Y;&4M;F%M92(^/"$M+2!\($!P<F5S96YT871I;VXZ<W1Y;&4M;F%M
M92`M+3X*("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE
M8W1E9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B
M+SX*("`@("`@("`\+WAS;#IA<'!L>2UT96UP;&%T97,^"@H@("`@("`@(#QX
M<VPZ87!P;'DM=&5M<&QA=&5S/@H@("`@("`@("`@("`\>'-L.G=I=&@M<&%R
M86T@;F%M93TB8V]L;&5C=&5D1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C
M=&5D1VQO8F%L1&%T82(O/@H@("`@("`@(#PO>'-L.F%P<&QY+71E;7!L871E
M<SX*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L871E(&UA
M=&-H/2)`=&5X=#IS='EL92UN86UE('P@0&1R87<Z<W1Y;&4M;F%M92!\($!D
M<F%W.G1E>'0M<W1Y;&4M;F%M92!\($!T86)L93IS='EL92UN86UE(CX\(2TM
M('P@0'!R97-E;G1A=&EO;CIS='EL92UN86UE+2T^"B`@("`@("`@/'AS;#IP
M87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#QX
M<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM*RLK*RL@0U-3("A#05-#041)
M3D<@4U1,644@4TA%150I($A%041%4B!35%E,12!705D@*RLK*RLM+3X*("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@)T-34U](
M14%$15(G(CX*("`@("`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64]
M(F-L87-S(CX\>'-L.G9A;'5E+6]F('-E;&5C=#TB=')A;G-L871E*"XL("<N
M("4H*2]<)RP@)R<I(B\^/"]X<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\
M+WAS;#IW:&5N/@H*("`@("`@("`@("`@/"$M+2LK*RLK($A434P@-"XP($E.
M3$E.140@5T%9("`K*RLK*RTM/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB)&]U='!U=%1Y<&4@/2`G0U-37TE.3$E.140G(CX*("`@("`@("`@("`@
M("`@(#QX<VPZ871T<FEB=71E(&YA;64](G-T>6QE(CX\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$O86QL<W1Y;&5S+RI;;F%M
M92@I/6-U<G)E;G0H*2\N72(O/CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@
M("`@/"]X<VPZ=VAE;CX*"B`@("`@("`@("`@(#PA+2TK*RLK*R!004Q-(#,N
M,B!354)3150@24Y,24Y%1"!705D@(&%N9"`@5TU,("\@5T%0("`@*RLK*RLM
M+3X*("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](B1O=71P=714>7!E(#T@
M)U!!3$TG(&]R("1O=71P=714>7!E(#T@)U=-3"<B/@H@("`@("`@("`@("`@
M("`@/"$M+2!G971T:6YG('1H92!C<W,@<W1Y;&5S(&9O<B!T:&4@<W1Y;&4@
M;F%M92`H;6%P<&5D(&)Y('-T>6QE+6UA<'!I;F<N>'-L*2`M+3X*("`@("`@
M("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB<W1Y;&50<F]P97)T:65S
M(B!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A+V%L;'-T>6QE<R\J6VYA
M;64H*3UC=7)R96YT*"DO+ETB+SX*("`@("`@("`@("`@("`@(#PA+2T@8VAA
M;F=I;F<@=&AE(&-O;G1E>'0@;F]D92`M+3X*("`@("`@("`@("`@("`@(#QX
M<VPZ9F]R+65A8V@@<V5L96-T/2)P87)E;G0Z.BHB/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)C<F5A=&4M;F5S=&5D
M+69O<FUA="UT86=S(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](G-T>6QE4')O<&5R=&EE<R(@<V5L96-T/2(D<W1Y
M;&50<F]P97)T:65S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O
M<BUE86-H/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&UA=&-H/2)T97AT.G-E<75E;F-E(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*"B`@("`@("`@/'AS;#IA
M<'!L>2UT96UP;&%T97,^"B`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0](B1C;VQL96-T961'
M;&]B86Q$871A(B\^"B`@("`@("`@/"]X<VPZ87!P;'DM=&5M<&QA=&5S/@H@
M("`@/"]X<VPZ=&5M<&QA=&4^"@H*/"]X<VPZ<W1Y;&5S:&5E=#X*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TU)344O5FEE=V5R+V]O
M;R]T86)L92YX<VP`````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0S-S`P(#$P
M-3$U-#,T,3,W(#`R,S<U-``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\(2TM"@H@("!4:&4@0V]N=&5N=',@;V8@=&AI<R!F
M:6QE(&%R92!M861E(&%V86EL86)L92!S=6)J96-T('1O('1H92!T97)M<R!O
M9@H@("!E:71H97(@;V8@=&AE(&9O;&QO=VEN9R!L:6-E;G-E<PH*("`@("`@
M("`@("T@1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(%9E<G-I
M;VX@,BXQ"B`@("`@("`@("`M(%-U;B!);F1U<W1R>2!3=&%N9&%R9',@4V]U
M<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*"B`@(%-U;B!-:6-R;W-Y<W1E;7,@
M26YC+BP@3V-T;V)E<BP@,C`P,`H*("`@1TY5($QE<W-E<B!'96YE<F%L(%!U
M8FQI8R!,:6-E;G-E(%9E<G-I;VX@,BXQ"B`@(#T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@("!#;W!Y<FEG:'0@,C`P
M,"!B>2!3=6X@36EC<F]S>7-T96US+"!);F,N"B`@(#DP,2!386X@06YT;VYI
M;R!2;V%D+"!086QO($%L=&\L($-!(#DT,S`S+"!54T$*"B`@(%1H:7,@;&EB
M<F%R>2!I<R!F<F5E('-O9G1W87)E.R!Y;W4@8V%N(')E9&ES=')I8G5T92!I
M="!A;F0O;W(*("`@;6]D:69Y(&ET('5N9&5R('1H92!T97)M<R!O9B!T:&4@
M1TY5($QE<W-E<B!'96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E('9E<G-I;VX@
M,BXQ+"!A<R!P=6)L:7-H960@8GD@=&AE($9R964@4V]F='=A<F4@1F]U;F1A
M=&EO;BX*"B`@(%1H:7,@;&EB<F%R>2!I<R!D:7-T<FEB=71E9"!I;B!T:&4@
M:&]P92!T:&%T(&ET('=I;&P@8F4@=7-E9G5L+`H@("!B=70@5TE42$]55"!!
M3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE9"!W87)R86YT
M>2!O9@H@("!-15)#2$%.5$%"24Q)5%D@;W(@1DE43D534R!&3U(@02!005)4
M24-53$%2(%!54E!/4T4N("!3964@=&AE($=.50H@("!,97-S97(@1V5N97)A
M;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS+@H*("`@66]U('-H
M;W5L9"!H879E(')E8V5I=F5D(&$@8V]P>2!O9B!T:&4@1TY5($QE<W-E<B!'
M96YE<F%L(%!U8FQI8PH@("!,:6-E;G-E(&%L;VYG('=I=&@@=&AI<R!L:6)R
M87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E(%-O9G1W87)E"B`@($9O
M=6YD871I;VXL($EN8RXL(#4Y(%1E;7!L92!0;&%C92P@4W5I=&4@,S,P+"!"
M;W-T;VXL"B`@($U!("`P,C$Q,2TQ,S`W("!54T$*"@H@("!3=6X@26YD=7-T
M<GD@4W1A;F1A<F1S(%-O=7)C92!,:6-E;G-E(%9E<G-I;VX@,2XQ"B`@(#T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*("`@5&AE(&-O;G1E;G1S(&]F('1H:7,@9FEL92!A<F4@<W5B:F5C="!T
M;R!T:&4@4W5N($EN9'5S=')Y(%-T86YD87)D<PH@("!3;W5R8V4@3&EC96YS
M92!697)S:6]N(#$N,2`H=&AE("),:6-E;G-E(BD[(%EO=2!M87D@;F]T('5S
M92!T:&ES(&9I;&4*("`@97AC97!T(&EN(&-O;7!L:6%N8V4@=VET:"!T:&4@
M3&EC96YS92X@66]U(&UA>2!O8G1A:6X@82!C;W!Y(&]F('1H90H@("!,:6-E
M;G-E(&%T(&AT='`Z+R]W=W<N;W!E;F]F9FEC92YO<F<O;&EC96YS92YH=&UL
M+@H*("`@4V]F='=A<F4@<')O=FED960@=6YD97(@=&AI<R!,:6-E;G-E(&ES
M('!R;W9I9&5D(&]N(&%N(")!4R!)4R(@8F%S:7,L"B`@(%=)5$A/550@5T%2
M4D%.5%D@3T8@04Y9($M)3D0L($5)5$A%4B!%6%!215-3($]2($E-4$Q)140L
M($E.0TQ51$E.1RP*("`@5TE42$]55"!,24U)5$%424].+"!705)204Y42453
M(%1(050@5$A%(%-/1E1705)%($E3($92144@3T8@1$5&14-44RP*("`@3452
M0TA!3E1!0DQ%+"!&250@1D]2($$@4$%25$E#54Q!4B!055)03U-%+"!/4B!.
M3TXM24Y&4DE.1TE.1RX*("`@4V5E('1H92!,:6-E;G-E(&9O<B!T:&4@<W!E
M8VEF:6,@<')O=FES:6]N<R!G;W9E<FYI;F<@>6]U<B!R:6=H=',@86YD"B`@
M(&]B;&EG871I;VYS(&-O;F-E<FYI;F<@=&AE(%-O9G1W87)E+@H*("`@5&AE
M($EN:71I86P@1&5V96QO<&5R(&]F('1H92!/<FEG:6YA;"!#;V1E(&ES.B!3
M=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!#;W!Y<FEG:'0@PJD@,C`P,B!B
M>2!3=6X@36EC<F]S>7-T96US+"!);F,N"@H@("!!;&P@4FEG:'1S(%)E<V5R
M=F5D+@H*("`@0V]N=')I8G5T;W(H<RDZ(%]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?7PH*+2T^"CQX<VPZ<W1Y;&5S:&5E="!V97)S
M:6]N/2(Q+C`B"B`@("`@("`@("`@("`@("!X;6QN<SIX<VP](FAT='`Z+R]W
M=W<N=S,N;W)G+S$Y.3DO6%-,+U1R86YS9F]R;2(*("`@("`@("`@("`@("`@
M('AM;&YS.F]F9FEC93TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O;V9F
M:6-E(@H@("`@("`@("`@("`@("`@>&UL;G,Z<W1Y;&4](FAT='`Z+R]O<&5N
M;V9F:6-E+F]R9R\R,#`P+W-T>6QE(@H@("`@("`@("`@("`@("`@>&UL;G,Z
M=&5X=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O=&5X="(*("`@("`@
M("`@("`@("`@('AM;&YS.G1A8FQE/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O
M,C`P,"]T86)L92(*("`@("`@("`@("`@("`@('AM;&YS.F1R87<](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R87=I;F<B"B`@("`@("`@("`@("`@
M("!X;6QN<SIF;STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]84TPO1F]R;6%T
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&QI;FL](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO>&QI;FLB"B`@("`@("`@("`@("`@("!X;6QN<SIN=6UB97(]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1A=&%S='EL92(*("`@("`@
M("`@("`@("`@('AM;&YS.G-V9STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S
M=F<B"B`@("`@("`@("`@("`@("!X;6QN<SIC:&%R=#TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O8VAA<G0B"B`@("`@("`@("`@("`@("!X;6QN<SID
M<C-D/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]D<C-D(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z;6%T:#TB:'1T<#HO+W=W=RYW,RYO<F<O,3DY."]-
M871H+TUA=&A-3"(*("`@("`@("`@("`@("`@('AM;&YS.F9O<FT](FAT='`Z
M+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V9O<FTB"B`@("`@("`@("`@("`@("!X
M;6QN<SIS8W)I<'0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+W-C<FEP
M="(*("`@("`@("`@("`@("`@(&]F9FEC93IC;&%S<STB=&5X="(*("`@("`@
M("`@("`@("`@(&]F9FEC93IV97)S:6]N/2(Q+C`B"B`@("`@("`@("`@("`@
M("!X;6QN<SID8STB:'1T<#HO+W!U<FPN;W)G+V1C+V5L96UE;G1S+S$N,2\B
M"B`@("`@("`@("`@("`@("!X;6QN<SIM971A/2)H='1P.B\O;W!E;F]F9FEC
M92YO<F<O,C`P,"]M971A(@H@("`@("`@("`@("`@("`@>&UL;G,Z8V]N9FEG
M/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,2]C;VYF:6<B"B`@("`@("`@
M("`@("`@("!X;6QN<SIH96QP/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P
M,"]H96QP(@H@("`@("`@("`@("`@("`@>&UL;G,Z>'0](FAT='`Z+R]W=W<N
M:F-L87)K+F-O;2]X="(*("`@("`@("`@("`@("`@('AM;&YS.G-Y<W1E;3TB
M:'1T<#HO+W=W=RYJ8VQA<FLN8V]M+WAT+VIA=F$O:F%V82YL86YG+E-Y<W1E
M;2(*("`@("`@("`@("`@("`@('AM;&YS.GAA;&%N/2)H='1P.B\O>&UL+F%P
M86-H92YO<F<O>&%L86XB"B`@("`@("`@("`@("`@("!X;6QN<SIJ879A/2)H
M='1P.B\O>&UL+F%P86-H92YO<F<O>'-L="]J879A(@H@("`@("`@("`@("`@
M("`@97AC;'5D92UR97-U;'0M<')E9FEX97,](FIA=F$B/@H*"B`@("`\(2TM
M('1A8FQE(')O=R!H86YD;&EN9R`M+3X*("`@(#QX<VPZ:6YC;'5D92!H<F5F
M/2)T86)L95]R;W=S+GAS;"(O/@H@("`@/"$M+2!T86)L92!C;VQU;6X@:&%N
M9&QI;F<@+2T^"B`@("`\>'-L.FEN8VQU9&4@:')E9CTB=&%B;&5?8V]L=6UN
M<RYX<VPB+SX*("`@(#PA+2T@=&%B;&4@8V5L;"!H86YD;&EN9R`M+3X*("`@
M(#QX<VPZ:6YC;'5D92!H<F5F/2)T86)L95]C96QL<RYX<VPB+SX*"@H*("`@
M(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@*BHJ(&UA
M:6X@=&%B;&4@("HJ*B`M+3X*("`@(#PA+2T@*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ
M*B`M+3X*"B`@("`\>'-L.G1E;7!L871E(&UA=&-H/2)T86)L93IT86)L92!\
M('1A8FQE.G-U8BUT86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B\^"@H@("`@("`@(#PA+2T@82!T86)L92!W
M:6QL(&]N;'D@8F4@8W)E871E9"!I9B!T:&4@(G-C96YA<FEO(B!I<R!A8W1I
M=F4@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)S=')I;F<M;&5N9W1H*'1A
M8FQE.G-C96YA<FEO+T!T86)L93II<RUA8W1I=F4I(#T@,"(^"B`@("`@("`@
M("`@(#PA+2T@8V]L;&5C=&EN9R!A;&P@=FES:6)L92`B=&%B;&4Z=&%B;&4M
M<F]W(B!E;&5M96YT<R!O9B!T:&4@=&%B;&4@+2T^"B`@("`@("`@("`@(#QX
M<VPZ=F%R:6%B;&4@;F%M93TB86QL5FES:6)L951A8FQE4F]W<R(@<V5L96-T
M/2)T86)L93IT86)L92UR;W=;;F]T*$!T86)L93IV:7-I8FEL:71Y(#T@)V-O
M;&QA<'-E)R!O<B!`=&%B;&4Z=FES:6)I;&ET>2`]("=F:6QT97(G*5T*("`@
M("`@("`@("`@("`@("`@("!\("`@('1A8FQE.G1A8FQE+6AE861E<BUR;W=S
M+V1E<V-E;F1A;G0Z.G1A8FQE.G1A8FQE+7)O=UMN;W0H0'1A8FQE.G9I<VEB
M:6QI='D@/2`G8V]L;&%P<V4G(&]R($!T86)L93IV:7-I8FEL:71Y(#T@)V9I
M;'1E<B<I70H@("`@("`@("`@("`@("`@("`@('P@("`@=&%B;&4Z=&%B;&4M
M<F]W+6=R;W5P+V1E<V-E;F1A;G0Z.G1A8FQE.G1A8FQE+7)O=UMN;W0H0'1A
M8FQE.G9I<VEB:6QI='D@/2`G8V]L;&%P<V4G(&]R($!T86)L93IV:7-I8FEL
M:71Y(#T@)V9I;'1E<B<I72(O/@H@("`@("`@("`@("`\>'-L.F-H;V]S93X*
M("`@("`@("`@("`@("`@(#PA+2T@9F]R(&%L;"!B=70@5T%0+U=-3"!D979I
M8V5S(&$@=&%B;&4@8F]R9&5R(&-H96-K(&ES(&1O;F4@*&-P+B`B8VAE8VLM
M9F]R+71A8FQE+6)O<F1E<B(I("TM/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:&5N('1E<W0](FYO="@D;W5T<'5T5'EP92`]("=734PG*2(^"@H@("`@("`@
M("`@("`@("`@("`@(#PA+2T@07,@=&AE(&%L:6=N;65N="!O9B!A('1A8FQE
M(&ES(&)Y("=A;&EG;B<@871T<FEB=70@:7,@9&5P<F5C871E9"!A;F0@87,@
M=&AE($-34R`G9FQO870G(&%T=')I8G5T92!N;W0@=V5L;"!D:7-P;&%Y960L
M"B`@("`@("`@("`@("`@("`@("`@("`@("!W92!D;R!A(&QI='1L92!T<FEC
M:R!B>2!E;F-A<'-U;&%T:6YG('1H92!T86)L92!W:71H(&$@86QI9VYE9"`G
M9&EV)R!E;&5M96YT+2T^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)T86)L92UA;&EG;FUE;G0B('-E;&5C=#TB)&]F9FEC93IA
M=71O;6%T:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IN86UE(#T@8W5R
M<F5N="@I+T!T86)L93IS='EL92UN86UE72]S='EL93IP<F]P97)T:65S+T!T
M86)L93IA;&EG;B(O/@H*("`@("`@("`@("`@("`@("`@("`\>'-L.F-H;V]S
M93X*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](G-T
M<FEN9RUL96YG=&@H)'1A8FQE+6%L:6=N;65N="D@(3T@,"(^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F5L96UE;G0@;F%M93TB9&EV(CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)A;&EG;B(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0])R1T86)L92UA;&EG;FUE
M;G0](FQE9G0B(&]R("1T86)L92UA;&EG;FUE;G0](FUA<F=I;G,B)SX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IT97AT/FQE9G0\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2<D
M=&%B;&4M86QI9VYM96YT/2)R:6=H="(G/@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#YR:6=H=#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:&5N('1E<W0])R1T86)L92UA;&EG;FUE;G0](F-E
M;G1E<B(G/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=&5X=#YC96YT97(\+WAS;#IT97AT/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F%T=')I
M8G5T93X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB=&%B;&4B/@H*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IA<'!L>2UT96UP;&%T97,@<V5L96-T/2)`=&%B
M;&4Z<W1Y;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D1VQO
M8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT
M96UP;&%T97,^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\(2TM('=O<FMA<F]U;F0L('-E="!T86)L92!B;W)D97(@871T<FEB=70@
M:68@86YY(&-E;&PM8F]R9&5R(&5X:7-T<PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB8VAE
M8VLM9F]R+71A8FQE+6)O<F1E<B(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES
M:6)L951A8FQE4F]W<R(@<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O
M/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IC
M86QL+71E;7!L871E/B`M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-R96%T92UC;VQU
M;6XM<W1Y;&4M=F%R:6%B;&4B/@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%9I<VEB
M;&5486)L95)O=W,B('-E;&5C=#TB)&%L;%9I<VEB;&5486)L95)O=W,B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ
M=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B!S96QE8W0]
M(B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/"]X<VPZ96QE;65N=#X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F5L96UE;G0^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ;W1H97)W:7-E/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'AS;#IE;&5M96YT(&YA;64](G1A8FQE(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\>'-L.F%P<&QY+71E;7!L871E<R!S96QE
M8W0](D!T86)L93IS='EL92UN86UE(CX*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E
M9$=L;V)A;$1A=&$B('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IA<'!L>2UT
M96UP;&%T97,^"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PA
M+2T@=V]R:V%R;W5N9"P@<V5T('1A8FQE(&)O<F1E<B!A='1R:6)U="!I9B!A
M;GD@8V5L;"UB;W)D97(@97AI<W1S"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](F-H96-K+69O<BUT
M86)L92UB;W)D97(B/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL5FES:6)L951A8FQE4F]W
M<R(@<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^("`M
M+3X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\>'-L.F-A;&PM
M=&5M<&QA=&4@;F%M93TB8W)E871E+6-O;'5M;BUS='EL92UV87)I86)L92(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B!S96QE8W0](B1A
M;&Q6:7-I8FQE5&%B;&52;W=S(B\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB8V]L;&5C=&5D
M1VQO8F%L1&%T82(@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M
M<&QA=&4^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IE;&5M
M96YT/@H@("`@("`@("`@("`@("`@("`@("`@("`\+WAS;#IO=&AE<G=I<V4^
M"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ8VAO;W-E/@H*("`@("`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\>'-L.F]T:&5R
M=VES93X*("`@("`@("`@("`@("`@(#PA+2T@9F]R(%=-3"!D979I8V5S(&]N
M;'D@05-#24D@=&%B;&4@87)E('=R:71T96X@87,@=&%B;&5S(&%R92!N;W0@
M:6UP;&5M96YT960@=VED;&5Y+@H@("`@("`@("`@("`@("`@("`@("!"96=I
M;FYI;F<@9G)O;2`G<F5P96%T+7=R:71E+7)O=R<@=&AE('1E;7!L871E<R!A
M<F4@:&%N9&QE9"!B>2!T:&4@=&%B;&5?=VUL+GAS;"!S='EL97-H965T("TM
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)C<F5A=&4M8V]L=6UN+7-T>6QE+79A<FEA8FQE(CX*("`@("`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L
M;V)A;$1A=&$B("`@<V5L96-T/2(D8V]L;&5C=&5D1VQO8F%L1&%T82(O/@H@
M("`@("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB
M86QL5FES:6)L951A8FQE4F]W<R(@('-E;&5C=#TB)&%L;%9I<VEB;&5486)L
M95)O=W,B+SX*("`@("`@("`@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L
M871E/@H@("`@("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@
M("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS
M;#IT96UP;&%T93X*"@H*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TB8W)E871E
M+6-O;'5M;BUS='EL92UV87)I86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N
M86UE/2)C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A
M;2!N86UE/2)A;&Q6:7-I8FQE5&%B;&52;W=S(B\^"@H@("`@("`@(#PA+2T@
M86QL(&-O;'5M;G,@;V8@=&AE('1A8FQE("TM/@H@("`@("`@(#QX<VPZ=F%R
M:6%B;&4@;F%M93TB86QL5&%B;&5#;VQU;6YS(B!S96QE8W0](G1A8FQE.G1A
M8FQE+6-O;'5M;B!\"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&%B;&4Z=&%B;&4M8V]L=6UN+6=R;W5P
M+V1E<V-E;F1A;G0Z.G1A8FQE.G1A8FQE+6-O;'5M;B!\"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&%B
M;&4Z=&%B;&4M:&5A9&5R+6-O;'5M;G,O9&5S8V5N9&%N=#HZ=&%B;&4Z=&%B
M;&4M8V]L=6UN(B\^"B`@("`@("`@/"$M+2!A;&Q#;VQU;6Y3='EL945N=')I
M97,Z($-O;G1A:6YI;F<@86QL(&-O;'5M;G,@;V8@=&AE('1A8FQE+"!H:61D
M96X@86YD('9I97=E9"X*("`@("`@("`@("`@+2!I9B!A(&-O;'5M;B!I<R!H
M:61D96XL(&ET(&-O;G1A:6YS('1H92!H:61D96X@871T<FEB=71E+"!O=&AE
M<G=I<V4@=&AE('-T>6QE+7!R;W!E<G1I97,@=VEL;"!B92!S=&]R960*("`@
M("`@("`@("`@+2!I9B!A(&-O;'5M;B!I<R!B96EN9R!R97!E871E9"P@96%C
M:"!R97!E871E9"!C;VQU;6X@:7,@97AP;&EC:71L>2!W<FET=&5N(&%S(&5N
M=')Y(&EN('1H:7,@=F%R:6%B;&4N"B`@("`@("`@("`@("`@3&%T97(@*&1U
M<FEN9R!T96UP;&%T92`B=W)I=&4M8V5L;"(I('1H92!S='EL92!O9B!T:&4@
M8V]L=6UN('=I;&P@8F4@;6EX960@=VET:"!T:&4@8V5L;"US='EL92!B>2!U
M<VEN9PH@("`@("`@("`@("`@('1H92!P;W-I=&EO;B@I(&]F('1H92!C;VQU
M;6X@96YT<GD@86YD(&-O;7!A<FEN9R!I="!W:71H('1H92!I=&5R871I;F<@
M8V5L;"!N=6UB97(N("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB
M86QL0V]L=6UN4W1Y;&5%;G1R:65S+5)41B(^"B`@("`@("`@("`@(#QX<VPZ
M8V%L;"UT96UP;&%T92!N86UE/2)A9&1I;F<M8V]L=6UN+7-T>6QE<RUE;G1R
M:65S(CX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C
M;VQL96-T961';&]B86Q$871A(B`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A
M;$1A=&$B+SX*("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE
M/2)A;&Q486)L94-O;'5M;G,B("`@("`@<V5L96-T/2(D86QL5&%B;&5#;VQU
M;6YS(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"B`@("`@
M("`@/"]X<VPZ=F%R:6%B;&4^"@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA8FQE*"=X
M=#IN;V1E+7-E="<I(CX*("`@("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP
M;&%T92!N86UE/2)C<F5A=&4M=&%B;&4B/@H@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)C;VQL96-T961';&]B86Q$871A(B`@
M("`@("!S96QE8W0](B1C;VQL96-T961';&]B86Q$871A(B\^"B`@("`@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;%9I<VEB;&54
M86)L95)O=W,B("`@("`@<V5L96-T/2(D86QL5FES:6)L951A8FQE4F]W<R(O
M/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)A
M;&Q#;VQU;6Y3='EL945N=')I97,B("`@('-E;&5C=#TB>'0Z;F]D92US970H
M)&%L;$-O;'5M;E-T>6QE16YT<FEE<RU25$8I(B\^"B`@("`@("`@("`@("`@
M("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@("`@("`\+WAS;#IW:&5N
M/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I;VXM879A:6QA
M8FQE*"=X86QA;CIN;V1E<V5T)RDB/@H@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](F-R96%T92UT86)L92(^"B`@("`@("`@("`@
M("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](F-O;&QE8W1E9$=L;V)A
M;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE8W1E9$=L;V)A;$1A=&$B+SX*
M("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB86QL
M5FES:6)L951A8FQE4F]W<R(@("`@("!S96QE8W0](B1A;&Q6:7-I8FQE5&%B
M;&52;W=S(B\^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@<V5L96-T/2)X86QA
M;CIN;V1E<V5T*"1A;&Q#;VQU;6Y3='EL945N=')I97,M4E1&*2(O/@H@("`@
M("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`\+WAS;#IC:&]O<V4^"@H@("`@/"]X<VPZ
M=&5M<&QA=&4^"@H*"B`@("`\>'-L.G1E;7!L871E(&YA;64](F-R96%T92UT
M86)L92(^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)C;VQL96-T961';&]B
M86Q$871A(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q6:7-I8FQE
M5&%B;&52;W=S(B\^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)A;&Q#;VQU
M;6Y3='EL945N=')I97,B+SX*"@H@("`@("`@(#PA+2T@4V]M92!/9F9I8V4@
M0V%L8R!D;V-U;65N=',@<VEM=6QA=&4@82!B86-K9W)O=6YD(&)Y(')E<&5A
M=&EN9R!T:&4@;&%S="!C96QL('5N=&EL(&5N9"!O9B!S<&%C90H@("`@("`@
M("`@("`@*%1H92!V86QU92!O9B`B=&%B;&4Z;G5M8F5R+6-O;'5M;G,M<F5P
M96%T960B(&ES(&5N;W5R;6]U<RDN(%=R:71I;F<@;W5T(&%L;"!T:&5S92!C
M96QL<R!W;W5L9"!B92!F871A;"X*("`@("`@("`@("`@(%1H97)E9F]R92P@
M=&AI<R!G;&]B86P@=F%R:6%B;&4@<VAO=W,@=7,@=&AE(&QO;F=E<W0@<F]W
M('=I=&@@8V]N=&5N="X*"B`@("`@("`@16%R;&EE<B!O;FQY('1H92!V:65W
M86)L92!C;VQU;6YS('=E<F4@;&ES=&5D+"!B=70@:70@:7,@96%S:65R('1O
M(&AA;F1L92!W:71H(&%L;"!C;VQU;6YS.@H@("`@("`@(#QX<VPZ=F%R:6%B
M;&4@;F%M93TB;6%X4F]W3&5N9W1H(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU
M;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6VYO="A`8V]L=6UN
M+6AI9&1E;BUF;&%G*5TI(B\^("TM/@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB;6%X4F]W3&5N9W1H(B!S96QE8W0](F-O=6YT*"1A;&Q#;VQU;6Y3
M='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y*2(O/@H*"B`@("`@("`@
M/"$M+6ES1&5B=6=-;V1E+5-405)4+2T^"B`@("`@("`@/'AS;#II9B!T97-T
M/2(D:7-$96)U9TUO9&4B/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^;6%X
M4F]W3&5N9W1H.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&UA>%)O=TQE;F=T
M:"(O/CPO>'-L.FUE<W-A9V4^"B`@("`@("`@("`@(#QX<VPZ=F%R:6%B;&4@
M;F%M93TB;G5M8F5R3V9(:61D96Y#;VQU;6YS(B!S96QE8W0](F-O=6YT*"1A
M;&Q#;VQU;6Y3='EL945N=')I97,O8V]L=6UN+7-T>6QE+65N=')Y6T!C;VQU
M;6XM:&ED9&5N+69L86==*2(O/@H@("`@("`@("`@("`\>'-L.FUE<W-A9V4^
M;G5M8F5R3V9(:61D96Y#;VQU;6YS.B`\>'-L.G9A;'5E+6]F('-E;&5C=#TB
M)&YU;6)E<D]F2&ED9&5N0V]L=6UN<R(O/CPO>'-L.FUE<W-A9V4^"B`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)T86)L92UD96)U9RUA
M;&Q#;VQU;6Y3='EL945N=')I97,B/@H@("`@("`@("`@("`@("`@/'AS;#IW
M:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@<V5L96-T
M/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`@("`@/"$M
M+6ES1&5B=6=-;V1E+45.1"TM/@H@("`@("`@(#QX<VPZ8VAO;W-E/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB)&]U='!U=%1Y<&4@/2`G5TU,)R(^
M"B`@("`@("`@("`@("`@("`\(2TM(&UA=&-H:6YG(&%L;"!R;W=S("T@=V4@
M8V%N(&YO="!U<V4@>'-L.F%P<&QY+71E;7!L871E('=I=&@@82!N;V1E+7-E
M="!P87)A;65T97(@87,@8GD@82!B=6<@:6X@6%0@*$IA;65S($-L87)K*0H@
M("`@("`@("`@("`@("`@("`@("`H:&5R93H@86QL0V]L=6UN4W1Y;&5%;G1R
M:65S*2!W:6QL(&)E(&EN=&5R<')E=&5D(&%S(&$@<F5S=6QT('1R964@9G)A
M9VUE;G0L('=H97)E(&YO('-E87)C:"!E>'!R97-S:6]N("A84&%T:"D@8V%N
M(&)E('5S960*("`@("`@("`@("`@("`@("`@("`@,D1/.D-(14-+(%=)5$@@
M6$%,04XM+3X*("`@("`@("`@("`@("`@(#QX<VPZ9F]R+65A8V@@<V5L96-T
M/2(D86QL5FES:6)L951A8FQE4F]W<R(^"B`@("`@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G=M;"UR97!E870M=W)I=&4M<F]W
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA
M;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O;&QE
M8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@("`@
M<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M<F]W
M<RUR97!E871E9"(@("`@('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S+7)E
M<&5A=&5D(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP
M87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C=#TB
M)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.F-A
M;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C:#X*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IO=&AE
M<G=I<V4^"B`@("`@("`@("`@("`@("`\(2TM(&UA=&-H:6YG(&%L;"!R;W=S
M("T@=V4@8V%N(&YO="!U<V4@>'-L.F%P<&QY+71E;7!L871E('=I=&@@82!N
M;V1E+7-E="!P87)A;65T97(@87,@8GD@82!B=6<@:6X@6%0@*$IA;65S($-L
M87)K*0H@("`@("`@("`@("`@("`@("`@("`H:&5R93H@86QL0V]L=6UN4W1Y
M;&5%;G1R:65S*2!W:6QL(&)E(&EN=&5R<')E=&5D(&%S(&$@<F5S=6QT('1R
M964@9G)A9VUE;G0L('=H97)E(&YO('-E87)C:"!E>'!R97-S:6]N("A84&%T
M:"D@8V%N(&)E('5S960*("`@("`@("`@("`@("`@("`@("`@,D1/.D-(14-+
M(%=)5$@@6$%,04X@+2T^"B`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H
M('-E;&5C=#TB)&%L;%9I<VEB;&5486)L95)O=W,B/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)R97!E870M=W)I=&4M
M<F]W(CX*("`@("`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M
M(&YA;64](F-O;&QE8W1E9$=L;V)A;$1A=&$B("`@("`@('-E;&5C=#TB)&-O
M;&QE8W1E9$=L;V)A;$1A=&$B+SX*("`@("`@("`@("`@("`@("`@("`@("`@
M/'AS;#IW:71H+7!A<F%M(&YA;64](F%L;$-O;'5M;E-T>6QE16YT<FEE<R(@
M("`@<V5L96-T/2(D86QL0V]L=6UN4W1Y;&5%;G1R:65S(B\^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)N=6UB97(M
M<F]W<RUR97!E871E9"(@("`@('-E;&5C=#TB0'1A8FQE.FYU;6)E<BUR;W=S
M+7)E<&5A=&5D(B\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=VET
M:"UP87)A;2!N86UE/2)M87A2;W=,96YG=&@B("`@("`@("`@("`@('-E;&5C
M=#TB)&UA>%)O=TQE;F=T:"(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L
M.F-A;&PM=&5M<&QA=&4^"B`@("`@("`@("`@("`@("`\+WAS;#IF;W(M96%C
M:#X*("`@("`@("`@("`@/"]X<VPZ;W1H97)W:7-E/@H@("`@("`@(#PO>'-L
M.F-H;V]S93X*("`@(#PO>'-L.G1E;7!L871E/@H*"@H*"B`@("`\(2TM("HJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"B`@("`\(2TM("HJ*B!(
M14Q015(Z('1A8FQE(&)O<F1E<B`J*BH@+2T^"B`@("`\(2TM("HJ*BHJ*BHJ
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H@("`@/"$M+2!O;FQY(&]N92!T
M86)L92!B;W)D97(@9F]R($A434PT(&]R($-34R!D979I8V5S('=H:6-H(&-O
M;G1A:6X@;VYE(&]R(&UO<F4@)V9O.F)O<F1E<BUT;W`G(&%T=')I8G5T97,@
M*'!A<G,@<')O('1O=&\L(&EF(&]N92!E>&ES="!T:&4@;W1H97(@=7-U86QL
M>2!E>&ES="P@=&]O*2`M+3X*("`@(#PA+2T@=&AI<R!W87,@82!W;W)K+6%R
M;W5N9"!F;W(@=&AE(&YE='-C87!E(#0N>'@@8G5T(&YO="!L;VYG97(@;F5C
M97-S87)Y(&9O<B!-;WII;&QA("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE
M/2)C:&5C:RUF;W(M=&%B;&4M8F]R9&5R(CX*("`@("`@("`\>'-L.G!A<F%M
M(&YA;64](F%L;%9I<VEB;&5486)L95)O=W,B+SX*"B`@("`@("`@/'AS;#IV
M87)I86)L92!N86UE/2)S=&%R=%1I;64B/@H@("`@("`@("`@("`\>'-L.FEF
M('1E<W0](B1I<T1E8G5G36]D92!A;F0@;F]T*"1I<TIA=F%$:7-A8FQE9"DB
M/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@
M("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL86)L92@G<WES
M=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>7-T96TZ8W5R<F5N="UT
M:6UE+6UI;&QI<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ=VAE
M;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S=#TB9G5N8W1I
M;VXM879A:6QA8FQE*"=J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I
M;65-:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@(#QX<VPZ=F%L
M=64M;V8@<V5L96-T/2)J879A.FIA=F$N;&%N9RY3>7-T96TN8W5R<F5N=%1I
M;65-:6QL:7,H*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^
M"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@("`@("`@(#PO
M>'-L.FEF/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`\(2TM
M(&-H96-K<R!I9B!O;F4@8V5L;"`H=&%B;&4Z=&%B;&4M8V5L;"D@;V8@=&AE
M(')O=W,@;V8@=&AI<R!T86)L92`H86QL5FES:6)L951A8FQE4F]W<RD@8V]N
M=&%I;G,@82!B;W)D97(@<W1Y;&4@*&DN92X@9F\Z8F]R9&5R+71O<"D*("`@
M("`@("`@("`@($EF(&]N;'D@;VYE('-I;F=L92!B;W)D97(@96QE;65N="!E
M>&ES="P@=&AE('=H;VQE('1A8FQE('=I;&P@9V5T<R!P<F4M9&5F:6YE9"!B
M;W)D97)S("AS:6UP;&4@:&5U<FES=&EC(&9O<B!B971T97(@8G)O=W-E<B!D
M:7-P;&%Y*2`M+3X*("`@("`@("`\>'-L.FEF('1E<W0](B1A;&Q6:7-I8FQE
M5&%B;&52;W=S+W1A8FQE.G1A8FQE+6-E;&Q;0'1A8FQE.G-T>6QE+6YA;64]
M+RHO*B]S='EL93IS='EL95MS='EL93IP<F]P97)T:65S+T!F;SIB;W)D97(M
M=&]P72]`<W1Y;&4Z;F%M95TB/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)B;W)D97(B/C$\+WAS;#IA='1R:6)U=&4^"B`@("`@("`@("`@
M(#QX<VPZ871T<FEB=71E(&YA;64](F)O<F1E<F-O;&]R(CXC,#`P,#`P/"]X
M<VPZ871T<FEB=71E/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T92!N86UE
M/2)C96QL<&%D9&EN9R(^,CPO>'-L.F%T=')I8G5T93X*("`@("`@("`@("`@
M/'AS;#IA='1R:6)U=&4@;F%M93TB8V5L;'-P86-I;F<B/C`\+WAS;#IA='1R
M:6)U=&4^"B`@("`@("`@("`@(#QX<VPZ871T<FEB=71E(&YA;64](G!A9V4M
M8G)E86LM:6YS:61E(CYP86=E+6)R96%K+6EN<VED93IA=F]I9#PO>'-L.F%T
M=')I8G5T93X*("`@("`@("`\+WAS;#II9CX*"@H@("`@("`@(#PA+2T@8VAE
M8VL@=&AE('1I;64@9F]R(&)O<F1E<F-H96-K:6YG("AD96)U9RDM+3X*("`@
M("`@("`\>'-L.FEF('1E<W0](B1I<T1E8G5G36]D92!A;F0@;F]T*"1I<TIA
M=F%$:7-A8FQE9"DB/@H@("`@("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64]
M(F5N9%1I;64B/@H@("`@("`@("`@("`@("`@/'AS;#IC:&]O<V4^"B`@("`@
M("`@("`@("`@("`@("`@/'AS;#IW:&5N('1E<W0](F9U;F-T:6]N+6%V86EL
M86)L92@G<WES=&5M.F-U<G)E;G0M=&EM92UM:6QL:7,G*2(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)S>7-T96TZ
M8W5R<F5N="UT:6UE+6UI;&QI<R@I(B\^"B`@("`@("`@("`@("`@("`@("`@
M/"]X<VPZ=VAE;CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB9G5N8W1I;VXM879A:6QA8FQE*"=J879A.FIA=F$N;&%N9RY3>7-T96TN
M8W5R<F5N=%1I;65-:6QL:7,G*2(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)J879A.FIA=F$N;&%N9RY3>7-T96TN
M8W5R<F5N=%1I;65-:6QL:7,H*2(O/@H@("`@("`@("`@("`@("`@("`@(#PO
M>'-L.G=H96X^"B`@("`@("`@("`@("`@("`\+WAS;#IC:&]O<V4^"B`@("`@
M("`@("`@(#PO>'-L.G9A<FEA8FQE/@H@("`@("`@("`@("`\>'-L.FUE<W-A
M9V4^5&EM92!F;W(@8VAE8VMI;F<@0F]R9&5R4W1Y;&4Z(#QX<VPZ=F%L=64M
M;V8@<V5L96-T/2(H)&5N9%1I;64@+2`D<W1A<G14:6UE*2(O/B!M<SPO>'-L
M.FUE<W-A9V4^"B`@("`@("`@/"]X<VPZ:68^"B`@("`\+WAS;#IT96UP;&%T
M93X*"CPO>'-L.G-T>6QE<VAE970^"@``````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O34E-12]6:65W97(O;V]O
M+W-T>6QE7VAE861E<BYX<VP`````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#(S,S8@,3`U
M,34T,S0Q,S<@,#(U,S0Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#PA+2T*"B`@(%1H92!#;VYT96YT<R!O9B!T:&ES(&9I
M;&4@87)E(&UA9&4@879A:6QA8FQE('-U8FIE8W0@=&\@=&AE('1E<FUS(&]F
M"B`@(&5I=&AE<B!O9B!T:&4@9F]L;&]W:6YG(&QI8V5N<V5S"@H@("`@("`@
M("`@+2!'3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC($QI8V5N<V4@5F5R<VEO
M;B`R+C$*("`@("`@("`@("T@4W5N($EN9'5S=')Y(%-T86YD87)D<R!3;W5R
M8V4@3&EC96YS92!697)S:6]N(#$N,0H*("`@4W5N($UI8W)O<WES=&5M<R!)
M;F,N+"!/8W1O8F5R+"`R,#`P"@H@("!'3E4@3&5S<V5R($=E;F5R86P@4'5B
M;&EC($QI8V5N<V4@5F5R<VEO;B`R+C$*("`@/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"B`@($-O<'ER:6=H="`R,#`P
M(&)Y(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*("`@.3`Q(%-A;B!!;G1O;FEO
M(%)O860L(%!A;&\@06QT;RP@0T$@.30S,#,L(%5300H*("`@5&AI<R!L:6)R
M87)Y(&ES(&9R964@<V]F='=A<F4[('EO=2!C86X@<F5D:7-T<FEB=71E(&ET
M(&%N9"]O<@H@("!M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'
M3E4@3&5S<V5R($=E;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@=F5R<VEO;B`R
M+C$L(&%S('!U8FQI<VAE9"!B>2!T:&4@1G)E92!3;V9T=V%R92!&;W5N9&%T
M:6]N+@H*("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D(&EN('1H92!H
M;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@(&)U="!7251(3U54($%.
M62!705)204Y463L@=VET:&]U="!E=F5N('1H92!I;7!L:65D('=A<G)A;G1Y
M(&]F"B`@($U%4D-(04Y404))3$E462!O<B!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312X@(%-E92!T:&4@1TY5"B`@($QE<W-E<B!'96YE<F%L
M(%!U8FQI8R!,:6-E;G-E(&9O<B!M;W)E(&1E=&%I;',N"@H@("!9;W4@<VAO
M=6QD(&AA=F4@<F5C96EV960@82!C;W!Y(&]F('1H92!'3E4@3&5S<V5R($=E
M;F5R86P@4'5B;&EC"B`@($QI8V5N<V4@86QO;F<@=VET:"!T:&ES(&QI8G)A
M<GD[(&EF(&YO="P@=W)I=&4@=&\@=&AE($9R964@4V]F='=A<F4*("`@1F]U
M;F1A=&EO;BP@26YC+BP@-3D@5&5M<&QE(%!L86-E+"!3=6ET92`S,S`L($)O
M<W1O;BP*("`@34$@(#`R,3$Q+3$S,#<@(%5300H*"B`@(%-U;B!);F1U<W1R
M>2!3=&%N9&%R9',@4V]U<F-E($QI8V5N<V4@5F5R<VEO;B`Q+C$*("`@/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H@("!4:&4@8V]N=&5N=',@;V8@=&AI<R!F:6QE(&%R92!S=6)J96-T('1O
M('1H92!3=6X@26YD=7-T<GD@4W1A;F1A<F1S"B`@(%-O=7)C92!,:6-E;G-E
M(%9E<G-I;VX@,2XQ("AT:&4@(DQI8V5N<V4B*3L@66]U(&UA>2!N;W0@=7-E
M('1H:7,@9FEL90H@("!E>&-E<'0@:6X@8V]M<&QI86YC92!W:71H('1H92!,
M:6-E;G-E+B!9;W4@;6%Y(&]B=&%I;B!A(&-O<'D@;V8@=&AE"B`@($QI8V5N
M<V4@870@:'1T<#HO+W=W=RYO<&5N;V9F:6-E+F]R9R]L:6-E;G-E+FAT;6PN
M"@H@("!3;V9T=V%R92!P<F]V:61E9"!U;F1E<B!T:&ES($QI8V5N<V4@:7,@
M<')O=FED960@;VX@86X@(D%3($E3(B!B87-I<RP*("`@5TE42$]55"!705)2
M04Y462!/1B!!3ED@2TE.1"P@14E42$52($584%)%4U,@3U(@24U03$E%1"P@
M24Y#3%5$24Y'+`H@("!7251(3U54($Q)34E4051)3TXL(%=!4E)!3E1)15,@
M5$A!5"!42$4@4T]&5%=!4D4@25,@1E)%12!/1B!$149%0U13+`H@("!-15)#
M2$%.5$%"3$4L($9)5"!&3U(@02!005)424-53$%2(%!54E!/4T4L($]2($Y/
M3BU)3D9224Y'24Y'+@H@("!3964@=&AE($QI8V5N<V4@9F]R('1H92!S<&5C
M:69I8R!P<F]V:7-I;VYS(&=O=F5R;FEN9R!Y;W5R(')I9VAT<R!A;F0*("`@
M;V)L:6=A=&EO;G,@8V]N8V5R;FEN9R!T:&4@4V]F='=A<F4N"@H@("!4:&4@
M26YI=&EA;"!$979E;&]P97(@;V8@=&AE($]R:6=I;F%L($-O9&4@:7,Z(%-U
M;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($-O<'ER:6=H="#"J2`R,#`R(&)Y
M(%-U;B!-:6-R;W-Y<W1E;7,L($EN8RX*"B`@($%L;"!2:6=H=',@4F5S97)V
M960N"@H@("!#;VYT<FEB=71O<BAS*3H@7U]?7U]?7U]?7U]?7U]?7U]?7U]?
M7U]?7U]?7U]?7U]?7U]?7U]?"@HM+3X*/'AS;#IS='EL97-H965T('9E<G-I
M;VX](C$N,"(*("`@("`@("`@("`@("`@('AM;&YS.GAS;#TB:'1T<#HO+W=W
M=RYW,RYO<F<O,3DY.2]84TPO5')A;G-F;W)M(@H@("`@("`@("`@("`@("`@
M>&UL;G,Z;V9F:6-E/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]O9F9I
M8V4B"B`@("`@("`@("`@("`@("!X;6QN<SIS='EL93TB:'1T<#HO+V]P96YO
M9F9I8V4N;W)G+S(P,#`O<W1Y;&4B"B`@("`@("`@("`@("`@("!X;6QN<SIT
M97AT/2)H='1P.B\O;W!E;F]F9FEC92YO<F<O,C`P,"]T97AT(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z=&%B;&4](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R
M,#`P+W1A8FQE(@H@("`@("`@("`@("`@("`@>&UL;G,Z9')A=STB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9')A=VEN9R(*("`@("`@("`@("`@("`@
M('AM;&YS.F9O/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+UA33"]&;W)M870B
M"B`@("`@("`@("`@("`@("!X;6QN<SIX;&EN:STB:'1T<#HO+W=W=RYW,RYO
M<F<O,3DY.2]X;&EN:R(*("`@("`@("`@("`@("`@('AM;&YS.FYU;6)E<CTB
M:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O9&%T87-T>6QE(@H@("`@("`@
M("`@("`@("`@>&UL;G,Z<W9G/2)H='1P.B\O=W=W+G<S+F]R9R\R,#`P+W-V
M9R(*("`@("`@("`@("`@("`@('AM;&YS.F-H87)T/2)H='1P.B\O;W!E;F]F
M9FEC92YO<F<O,C`P,"]C:&%R="(*("`@("`@("`@("`@("`@('AM;&YS.F1R
M,V0](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P+V1R,V0B"B`@("`@("`@
M("`@("`@("!X;6QN<SIM871H/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DX+TUA
M=&@O36%T:$U,(@H@("`@("`@("`@("`@("`@>&UL;G,Z9F]R;3TB:'1T<#HO
M+V]P96YO9F9I8V4N;W)G+S(P,#`O9F]R;2(*("`@("`@("`@("`@("`@('AM
M;&YS.G-C<FEP=#TB:'1T<#HO+V]P96YO9F9I8V4N;W)G+S(P,#`O<V-R:7!T
M(@H@("`@("`@("`@("`@("`@;V9F:6-E.F-L87-S/2)T97AT(@H@("`@("`@
M("`@("`@("`@;V9F:6-E.G9E<G-I;VX](C$N,"(*("`@("`@("`@("`@("`@
M('AM;&YS.F1C/2)H='1P.B\O<'5R;"YO<F<O9&,O96QE;65N=',O,2XQ+R(*
M("`@("`@("`@("`@("`@('AM;&YS.FUE=&$](FAT='`Z+R]O<&5N;V9F:6-E
M+F]R9R\R,#`P+VUE=&$B"B`@("`@("`@("`@("`@("!X;6QN<SIC;VYF:6<]
M(FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`Q+V-O;F9I9R(*("`@("`@("`@
M("`@("`@('AM;&YS.FAE;'`](FAT='`Z+R]O<&5N;V9F:6-E+F]R9R\R,#`P
M+VAE;'`B"B`@("`@("`@("`@("`@("!X;6QN<SIX=#TB:'1T<#HO+W=W=RYJ
M8VQA<FLN8V]M+WAT(@H@("`@("`@("`@("`@("`@>&UL;G,Z<WES=&5M/2)H
M='1P.B\O=W=W+FIC;&%R:RYC;VTO>'0O:F%V82]J879A+FQA;F<N4WES=&5M
M(@H@("`@("`@("`@("`@("`@>&UL;G,Z>&%L86X](FAT='`Z+R]X;6PN87!A
M8VAE+F]R9R]X86QA;B(*("`@("`@("`@("`@("`@('AM;&YS.FIA=F$](FAT
M='`Z+R]X;6PN87!A8VAE+F]R9R]X<VQT+VIA=F$B"B`@("`@("`@("`@("`@
M("!E>&-L=61E+7)E<W5L="UP<F5F:7AE<STB:F%V82(^"@H*"B`@("`\(2TM
M("HJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*B`M+3X*("`@(#PA+2T@
M*BHJ('-T>6QE('-H965T('!R;V-E<W-I;F<@*BHJ("TM/@H@("`@/"$M+2`J
M*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BHJ*BH@+2T^"@H*("`@(#QX<VPZ
M=&5M<&QA=&4@;F%M93TG8W)E871E+6-S<RUS='EL96AE861E<B<^"B`@("`@
M("`@/'AS;#IC;VUM96YT/@H@("`@("`@("`@("`\>'-L.G1E>'0^5&AE($-3
M4R!S='EL92!H96%D97(@;65T:&]D(&9O<B!S971T:6YG('-T>6QE<SPO>'-L
M.G1E>'0^"B`@("`@("`@/"]X<VPZ8V]M;65N=#X*("`@("`@("`\>'-L.F5L
M96UE;G0@;F%M93TB<W1Y;&4B/@H@("`@("`@("`@("`\>'-L.F%T=')I8G5T
M92!N86UE/2)T>7!E(CYT97AT+V-S<SPO>'-L.F%T=')I8G5T93X*("`@("`@
M("`@("`@/'AS;#IC;VUM96YT/@H@("`@("`@("`@("`@("`@/'AS;#IT97AT
M/@H*("`@("`@("`\+WAS;#IT97AT/@H@("`@("`@("`@("`@("`@/'AS;#IC
M86QL+71E;7!L871E(&YA;64](G=R:71E+61E9F%U;'0M<W1Y;&5S(B\^"@H@
M("`@("`@("`@("`@("`@/"$M+2!42$4@4U193$4@4%)/4$525$E%4R!/1B!4
M2$4@1DE24U0@5U))5%1%3B!35%E,12`H4$%214Y4*2!)4R!'259%3B!/550@
M+2T^"@H@("`@("`@("`@("`@("`@/"$M+2`Q*2!S='EL97,@9G)O;2!O9F9I
M8V4Z<W1Y;&5S(&%R92!P;W-S:6)L92!P87)E;G0@9G)O;2!A;&P@*&ET<V5L
M9B!O<B!O9F9I8V4Z875T;VUA=&EC+7-T>6QE<RDN"B`@("`@("`@("`@("`@
M("`@("`@(%1H97)E9F]R92!T:&5Y(&%R92!C<F5A=&5D(&9I<G-T+@H@("`@
M("`@("`@("`@("`@("`@("!"96=I;FYI;F<@=VET:"!T:&4@=&]P+6QE=F5L
M('!A<F5N=',@*'1H92!S='EL97,@=VET:&]U="!A;GD@<&%R96YT*2X@+2T^
M"B`@("`@("`@("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC
M93IS='EL97,O<W1Y;&4Z<W1Y;&5;;F]T*$!S='EL93IP87)E;G0M<W1Y;&4M
M;F%M92E=(CX*"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(O/@H@("`@("`@
M("`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W<FET92US
M='EL97!R;W!E<G1Y+6QI;F5S+69O<BUC:&EL9')E;B(O/@H@("`@("`@("`@
M("`@("`@/"]X<VPZ9F]R+65A8V@^"@H@("`@("`@("`@("`@("`@/'AS;#IT
M97AT/B`\+WAS;#IT97AT/@H*("`@("`@("`@("`@("`@(#PA+2T@,BD@<W1Y
M;&5S(&9R;VT@;V9F:6-E.F%U=&]M871I8RUS='EL97,@8V%N(&]N;'D@8F4@
M<&%R96YT(&]F('-T>6QE<R!F<F]M('1H92!O9F9I8V4Z875T;VUA=&EC+7-T
M>6QE<R!S96-T:6]N+@H@("`@("`@("`@("`@("`@("`@("!"96=I;FYI;F<@
M=VET:"!T;W`M;&5V96P@<W1Y;&5S+"!A9V%I;BP@86QL(&-H:6QD<F5N('-T
M>6QE('=I;&P@8F4@<F5C=7)S:79L>2!T<F%V97)S960@+2T^"B`@("`@("`@
M("`@("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T
M:6,M<W1Y;&5S+W-T>6QE.G-T>6QE6VYO="A`<W1Y;&4Z<&%R96YT+7-T>6QE
M+6YA;64I72(^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L
M871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S96%R8VA/
M;FQY26Y!=71O;6%T:6-3='EL97,B('-E;&5C=#TB=')U92@I(B\^"B`@("`@
M("`@("`@("`@("`@("`@/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`@
M("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y
M;&5P<F]P97)T>2UL:6YE<RUF;W(M8VAI;&1R96XB/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN
M075T;VUA=&EC4W1Y;&5S(B\^"B`@("`@("`@("`@("`@("`@("`@/"]X<VPZ
M8V%L;"UT96UP;&%T93X*("`@("`@("`@("`@("`@(#PO>'-L.F9O<BUE86-H
M/@H@("`@("`@("`@("`O+SPO>'-L.F-O;6UE;G0^"B`@("`@("`@/"]X<VPZ
M96QE;65N=#X*("`@(#PO>'-L.G1E;7!L871E/@H*"B`@("`\>'-L.G1E;7!L
M871E(&YA;64])W=R:71E+7-T>6QE<')O<&5R='DM;&EN92<^"B`@("`@("`@
M/'AS;#IP87)A;2!N86UE/2)S96%R8VA/;FQY26Y!=71O;6%T:6-3='EL97,B
M+SX*"B`@("`@("`@/'AS;#IV87)I86)L92!N86UE/2)S='EL95!R;W!E<G1I
M97,B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I
M=&4M<W1Y;&4M<')O<&5R=&EE<R(^"B`@("`@("`@("`@("`@("`\>'-L.G=I
M=&@M<&%R86T@;F%M93TB<W1Y;&5!='1R:6)U=&50871H(B`@('-E;&5C=#TB
M8W5R<F5N="@I+W-T>6QE.G!R;W!E<G1I97,O0"HB+SX*("`@("`@("`@("`@
M/"]X<VPZ8V%L;"UT96UP;&%T93X*("`@("`@("`\+WAS;#IV87)I86)L93X*
M"B`@("`@("`@/"$M+2!D;R!N;W0@=W)I=&4@<W1Y;&5S('=I=&@@;F\@8W-S
M('!R;W!E<G1Y("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*'-T<FEN
M9RUL96YG=&@H)'-T>6QE4')O<&5R=&EE<RD@/2`P*2(^"B`@("`@("`@("`@
M(#PA+2T@=W)I=&4@;W5T('1H92!N86UE(&]F('1H92!C=7)R96YT("AP87)E
M;G0I('-T>6QE(&EN('1H92!#4U,@:&5A9&5R<V5C=&EO;B`H92YG+B`B<W!A
M;BYM>5-T>6QE(BD@+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)W<FET92US='EL92UN86UE(CX*("`@("`@("`@("`@("`@(#QX
M<VPZ=VET:"UP87)A;2!N86UE/2)I<RUP87)E;G0M<W1Y;&4B('-E;&5C=#TB
M=')U92@I(B\^"B`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@
M("`@("`@("`@("`\(2TM('1H92!N86UE<R!O9B!A;&P@<W1Y;&5S(&-H:6QD
M<F5N('=I;&P@8F4@=W)I='1E;B!O=70H;V9F:6-E.G-T>6QE($%.1"!O9F9I
M8V4Z875T;VUA=&EC+7-T>6QE*2`M+3X*("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G=R:71E+6-H:6QD<F5N+7-T>6QE+6YA;65S(CX*
M("`@("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13
M='EL94YA;64B("`@("`@("`@('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@
M("`@("`@("`@("`@(#QX<VPZ=VET:"UP87)A;2!N86UE/2)P87)E;G13='EL
M949A;6EL>2(@("`@("`@('-E;&5C=#TB0'-T>6QE.F9A;6EL>2(O/@H@("`@
M("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E)
M;D%U=&]M871I8U-T>6QE<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E
M;7!L871E/@H*("`@("`@("`\(2TM('1H92!S='EL92!P<F]P97)T:65S(&]F
M('1H92!F:7)S="!W<FET=&5N('-T>6QE("AP87)E;G0I(&ES(&=I=F5N(&]U
M="`M+3X*("`@("`@("`\>'-L.G1E>'0^('L*("`@("`@("`@("`@("`@(#PO
M>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C
M=#TB)'-T>6QE4')O<&5R=&EE<R(O/@H@("`@("`@(#QX<VPZ=&5X=#Y]"B`@
M("`@("`@/"]X<VPZ=&5X=#X*"B`@("`@("`@/"]X<VPZ:68^"@H*"B`@("`\
M+WAS;#IT96UP;&%T93X*"@H*"B`@("`\(2TM(%)%0U524TE/3B!7251(($5.
M1$-/3D1)5$]..B!A9&1I;F<@<W1Y;&4@8VQA<W-E<R!F;W(@86QL(&5X:7-T
M:6YG(&-H:6QD<R`M+3X*("`@(#QX<VPZ=&5M<&QA=&4@;F%M93TG=W)I=&4M
M<W1Y;&5P<F]P97)T>2UL:6YE<RUF;W(M8VAI;&1R96XG/@H@("`@("`@(#QX
M<VPZ<&%R86T@;F%M93TB<V5A<F-H3VYL>4EN075T;VUA=&EC4W1Y;&5S(B\^
M"@H@("`@("`@(#QX<VPZ=F%R:6%B;&4@;F%M93TB<&%R96YT4W1Y;&5.86UE
M(B`@("!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@/'AS;#IV87)I
M86)L92!N86UE/2)P87)E;G13='EL949A;6EL>2(@('-E;&5C=#TB0'-T>6QE
M.F9A;6EL>2(O/@H*("`@("`@("`\>'-L.FEF('1E<W0](FYO="AS96%R8VA/
M;FQY26Y!=71O;6%T:6-3='EL97,I(CX*("`@("`@("`@("`@/'AS;#IF;W(M
M96%C:"!S96QE8W0](BXN+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D])'!A
M<F5N=%-T>6QE1F%M:6QY(&%N9"!`<W1Y;&4Z<&%R96YT+7-T>6QE+6YA;64]
M)'!A<F5N=%-T>6QE3F%M95TB/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL
M+71E;7!L871E(&YA;64](G=R:71E+7-T>6QE<')O<&5R='DM;&EN92(O/@H@
M("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E
M+7-T>6QE<')O<&5R='DM;&EN97,M9F]R+6-H:6QD<F5N(B\^"B`@("`@("`@
M("`@(#PO>'-L.F9O<BUE86-H/@H@("`@("`@(#PO>'-L.FEF/@H@("`@("`@
M(#QX<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL
M97,O<W1Y;&4Z<W1Y;&5;0'-T>6QE.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI
M;'D@86YD($!S='EL93IP87)E;G0M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.
M86UE72(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N86UE/2)W
M<FET92US='EL97!R;W!E<G1Y+6QI;F4B/@H@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE
M<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M("`@("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M<W1Y;&5P<F]P
M97)T>2UL:6YE<RUF;W(M8VAI;&1R96XB/@H@("`@("`@("`@("`@("`@/'AS
M;#IW:71H+7!A<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE
M<R(O/@H@("`@("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@
M(#PO>'-L.F9O<BUE86-H/@H@("`@/"]X<VPZ=&5M<&QA=&4^"@H*("`@(#QX
M<VPZ=&5M<&QA=&4@;F%M93TB=W)I=&4M9&5F875L="US='EL97,B/@H*("`@
M("`@("`\(2TM('-O;64@9&5F875L="!A='1R:6)U=&5S(&EN('AM;"!H879E
M('1O(&)E(&5X<&QI8VET;'D@<V5T(&EN($A434P@*&4N9RX@;6%R9VEN+71O
M<#TB,"(I("TM/@H@("`@("`@(#QX<VPZ=&5X=#XJ+D]/;U]D969A=6QT<SPO
M>'-L.G1E>'0^"@H@("`@("`@("`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE
M8W0](B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE(CX*("`@("`@("`@("`@
M("`@("`@("`\>'-L.G1E>'0^+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN)RP@=')A
M;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*("`@("`@
M("`@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@("`@("`@("`@("`@(#QX
M<VPZ9F]R+65A8V@@<V5L96-T/2(D;V9F:6-E.F%U=&]M871I8RUS='EL97,O
M<W1Y;&4Z<W1Y;&4B/@H@("`@("`@("`@("`@("`@("`@(#QX<VPZ=&5X=#XL
M(#PO>'-L.G1E>'0^"B`@("`@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO
M9B!S96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H0'-T>6QE.FYA;64L
M("<N("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`@("`@/"]X<VPZ9F]R
M+65A8V@^"B`@("`@("`@/"$M+2`R1$\Z('1H92!D969A=6QT<R!M:6=H="!B
M92!B971T97(@8V]L;&5C=&5D(&%N9"!W<FET=&5N(&EN(&$@<V5P87)A=&5D
M("A834PI(&9I;&4@+2T^"CQX<VPZ=&5X=#X@>PH@("`@("`@("`@("`@("`@
M;6%R9VEN+71O<#HP8VT[(&UA<F=I;BUB;W1T;VTZ,&-M.R!]"B`@("`@("`@
M/"]X<VPZ=&5X=#X*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0](B1O
M9F9I8V4Z<W1Y;&5S+W-T>6QE.F1E9F%U;'0M<W1Y;&4B/@H@("`@("`@("`@
M("`\>'-L.F-A;&PM=&5M<&QA=&4@;F%M93TB=W)I=&4M9&5F875L="US='EL
M92(O/@H@("`@("`@(#PO>'-L.F9O<BUE86-H/@H*("`@("`@("`\>'-L.F9O
M<BUE86-H('-E;&5C=#TB)&]F9FEC93IA=71O;6%T:6,M<W1Y;&5S+W-T>6QE
M.F1E9F%U;'0M<W1Y;&4B/@H@("`@("`@("`@("`\>'-L.F-A;&PM=&5M<&QA
M=&4@;F%M93TB=W)I=&4M9&5F875L="US='EL92(O/@H@("`@("`@(#PO>'-L
M.F9O<BUE86-H/@H*("`@(#PO>'-L.G1E;7!L871E/@H*"@H@("`@/'AS;#IT
M96UP;&%T92!N86UE/2)W<FET92UD969A=6QT+7-T>6QE(CX*("`@("`@("`\
M>'-L.G9A<FEA8FQE(&YA;64](F9A;6EL>2US='EL92(@<V5L96-T/2)`<W1Y
M;&4Z9F%M:6QY(B\^"@H@("`@("`@(#PA+2T@<V]M92!D969A=6QT(&%T=')I
M8G5T97,@9F]R(&9O<FUA="!F86UI;&EE<R`H92YG+B!G<F%P:&EC<RP@<&%R
M86=R87!H<RP@971C+BD@=W)I='1E;B!A<R!S='EL93ID969A=6QT+7-T>6QE
M("TM/@H@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN
M)RP@=')A;G-L871E*"1F86UI;'DM<W1Y;&4L("<N("4H*2]<)RP@)R<I+"`G
M7V1E9F%U;'1S)RDB+SX*"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE8W0]
M(B1O9F9I8V4Z<W1Y;&5S+W-T>6QE.G-T>6QE6T!S='EL93IF86UI;'D@/2`D
M9F%M:6QY+7-T>6QE72(^"B`@("`@("`@("`@(#QX<VPZ=&5X=#XL(#PO>'-L
M.G1E>'0^"B`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC
M870H)RHN)RP@=')A;G-L871E*$!S='EL93IN86UE+"`G+B`E*"DO7"<L("<G
M*2DB+SX*("`@("`@("`\+WAS;#IF;W(M96%C:#X*"B`@("`@("`@/'AS;#IF
M;W(M96%C:"!S96QE8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL
M93IS='EL95M`<W1Y;&4Z9F%M:6QY(#T@)&9A;6EL>2US='EL95TB/@H@("`@
M("`@("`@("`\>'-L.G1E>'0^+"`\+WAS;#IT97AT/@H@("`@("`@("`@("`\
M>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92A`
M<W1Y;&4Z;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@/"]X<VPZ
M9F]R+65A8V@^"@H*("`@("`@("`\>'-L.G9A<FEA8FQE(&YA;64](G-T>6QE
M4')O<&5R=&EE<R(^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T92!N
M86UE/2)W<FET92US='EL92UP<F]P97)T:65S(CX*("`@("`@("`@("`@("`@
M(#QX<VPZ=VET:"UP87)A;2!N86UE/2)S='EL94%T=')I8G5T95!A=&@B("`@
M<V5L96-T/2)C=7)R96YT*"DO<W1Y;&4Z<')O<&5R=&EE<R]`*B(O/@H@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H@("`@("`@(#PO>'-L.G9A
M<FEA8FQE/@H*("`@("`@("`\(2TM(&1O(&YO="!W<FET92!S='EL97,@=VET
M:"!N;R!C<W,@<')O<&5R='D@+2T^"B`@("`@("`@/'AS;#II9B!T97-T/2)N
M;W0H<W1R:6YG+6QE;F=T:"@D<W1Y;&50<F]P97)T:65S*2`](#`I(CX*("`@
M("`@("`\(2TM('1H92!S='EL92!P<F]P97)T:65S(&]F('1H92!F:7)S="!W
M<FET=&5N('-T>6QE("AP87)E;G0I(&ES(&=I=F5N(&]U="`M+3X*("`@("`@
M("`\>'-L.G1E>'0^('L*("`@("`@("`@("`@("`@(#PO>'-L.G1E>'0^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB)'-T>6QE4')O
M<&5R=&EE<R(O/@H@("`@("`@(#QX<VPZ=&5X=#Y]"B`@("`@("`@/"]X<VPZ
M=&5X=#X*("`@("`@("`\+WAS;#II9CX*"B`@("`\+WAS;#IT96UP;&%T93X*
M"@H@("`@/"$M+2LK"B`@("`@("`@("!4:&4@<&%R96YT('-T>6QE('=I;&P@
M8F4@=W)I='1E;B!O=70A"B`@("`@("`@("!&;W(@96%C:"!3='EL93IF86UI
M;'D@82!P<F5F:7@@;75S="!B92!A9&1E9`H@("`@("`@("`@("`\(45.5$E4
M62`E('-T>6QE1F%M:6QY"B`@("`@("`@("`@("(H<&%R86=R87!H?'1E>'1\
M<V5C=&EO;GQT86)L97QT86)L92UC;VQU;6Y\=&%B;&4M<F]W?'1A8FQE+6-E
M;&Q\=&%B;&4M<&%G97QC:&%R='QG<F%P:&EC<WQD969A=6QT?&1R87=I;F<M
M<&%G97QP<F5S96YT871I;VY\8V]N=')O;"DB/@H@("`@("`@("LK+2T^"B`@
M("`\>'-L.G1E;7!L871E(&YA;64](G=R:71E+7-T>6QE+6YA;64B/@H@("`@
M("`@(#QX<VPZ<&%R86T@;F%M93TB:7,M<&%R96YT+7-T>6QE(B\^"@H@("`@
M("`@(#PA+2T@5&AI<R!C;VYS=')U8W0@:7,@9F]R(&QI<W0@96QE;65N=',N
M(%=H96YE=F5R(&$@<&%R86=R87!H(&5L96UE;G0@:7,@8F5I;F<@=7-E9"!A
M<R!C:&EL9"!O9B!A(&QI<W0@96QE;65N="!T:&4@;F%M92!P87)A9W)A<&@@
M<W1Y;&4@:7,@8F5E;B!U<V5D(&9O<@H@("`@("`@("`@("!T:&4@;&ES="!I
M=&5M+B!4:&ES(&-A;B!B92!S=VET8VAE9"!A<R!T:&4@<&%R86=A<&@@<W1Y
M;&4M;F%M92!A;F0@=&AE(&QI<W0M<W1Y;&4M;F%M92!A<F4@:6X@=&AE('-A
M;64@96QE;65N="X*("`@("`@("`@("`@3W1H97)W:7-E('1H97)E('=O=6QD
M(&)E(&9O<FUA='1I;F<@97)R;W)S("AE+F<N(&UA<F=I;BUL969T('=I;&P@
M8F4@=7-E9"!F;W(@=&AE(&-O;G1E;G0@:6X@=&AE(&QI<W0@96QM96YT(&%N
M9"!N;W0@9F]R('1H92!L:7-T(&5L96UE;G0@:71S96QF*2X@+2T^"B`@("`@
M("`@/'AS;#IV87)I86)L92!N86UE/2)S='EL92UN86UE(CX*("`@("`@("`@
M("`@/'AS;#IC:&]O<V4^"B`@("`@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB0'-T>6QE.FQI<W0M<W1Y;&4M;F%M92(^"B`@("`@("`@("`@("`@("`@
M("`@/'AS;#IV86QU92UO9B!S96QE8W0](D!S='EL93IL:7-T+7-T>6QE+6YA
M;64B+SX*("`@("`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@
M("`@("`\>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@("`@("`@
M("`@(#PO>'-L.F]T:&5R=VES93X*("`@("`@("`@("`@/"]X<VPZ8VAO;W-E
M/@H@("`@("`@(#PO>'-L.G9A<FEA8FQE/@H*("`@("`@("`\>'-L.FEF('1E
M<W0](FYO="@D:7,M<&%R96YT+7-T>6QE*2(^"B`@("`@("`@("`@(#QX<VPZ
M=&5X=#XL(#PO>'-L.G1E>'0^"B`@("`@("`@/"]X<VPZ:68^"@H@("`@("`@
M(#QX<VPZ8VAO;W-E/@H@("`@("`@("`@("`\(2TM(&YO<FUA;&QY("=P+B<@
M=V]U;&0@8F4@=7-E9"!A<R!#4U,@96QE;65N="P*("`@("`@("`@("`@("`@
M("!B=70@:&5A9&5R("AH,2P@:#(L+BXN*2!A<F4@86QS;R!F<F]M('1H92!S
M='EL93IF86UI;'D@<&%R86=R87!H("TM/@H@("`@("`@("`@("`\>'-L.G=H
M96X@=&5S=#TB0'-T>6QE.F9A;6EL>3TG<&%R86=R87!H)R(^"B`@("`@("`@
M("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R
M86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)`<W1Y;&4Z9F%M:6QY/2=T97AT)R(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y
M;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M
M:6QY/2=S96-T:6]N)R(^"B`@("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F
M('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@
M)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@
M("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T86)L
M92<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O
M;F-A="@G=&%B;&4N)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO
M7"<L("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@
M("`@/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])W1A8FQE+6-O;'5M
M;B<B/@H@("`@("`@("`@("`\(2TM(&%S(&-O;'5M;B!S='EL97,@:&%V92!T
M;R!B92!I;F-L=61E9"!A<R!S<&%N('-T>6QE<R!!1E1%4B!T:&4@=&%B;&4@
M*&YO('1W;R!C;&%S<R!A='1R:6)U=&5S(&EN(%1$(&%L;&]W960@+2T^"B`@
M("`@("`@("`@("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J
M+B<L('1R86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^
M"B`@("`@("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE
M;B!T97-T/2)`<W1Y;&4Z9F%M:6QY/2=T86)L92UR;W<G(CX*("`@("`@("`@
M("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)W1R+B<L('1R
M86YS;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@
M("`@("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T
M/2)`<W1Y;&4Z9F%M:6QY/2=T86)L92UC96QL)R(^"B`@("`@("`@("`@("`@
M("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T
M92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@
M(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y
M;&4Z9F%M:6QY/2=T86)L92UP86=E)R(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y
M;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`<W1Y;&4Z9F%M
M:6QY/2=C:&%R="<B/@H@("`@("`@("`@("`@("`@/'AS;#IV86QU92UO9B!S
M96QE8W0](F-O;F-A="@G*BXG+"!T<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N
M("4H*2]<)RP@)R<I*2(O/@H@("`@("`@("`@("`\+WAS;#IW:&5N/@H@("`@
M("`@("`@("`\>'-L.G=H96X@=&5S=#TB0'-T>6QE.F9A;6EL>3TG9W)A<&AI
M8W,G(CX*("`@("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C
M;VYC870H)RHN)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L
M("<G*2DB+SX*("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@
M/'AS;#IW:&5N('1E<W0](D!S='EL93IF86UI;'D])V1E9F%U;'0G(CX*("`@
M("`@("`@("`@("`@(#QX<VPZ=F%L=64M;V8@<V5L96-T/2)C;VYC870H)RHN
M)RP@=')A;G-L871E*"1S='EL92UN86UE+"`G+B`E*"DO7"<L("<G*2DB+SX*
M("`@("`@("`@("`@/"]X<VPZ=VAE;CX*("`@("`@("`@("`@/'AS;#IW:&5N
M('1E<W0](D!S='EL93IF86UI;'D])V1R87=I;F<M<&%G92<B/@H@("`@("`@
M("`@("`@("`@/'AS;#IV86QU92UO9B!S96QE8W0](F-O;F-A="@G*BXG+"!T
M<F%N<VQA=&4H)'-T>6QE+6YA;64L("<N("4H*2]<)RP@)R<I*2(O/@H@("`@
M("`@("`@("`\+WAS;#IW:&5N/@H@("`@("`@("`@("`\>'-L.G=H96X@=&5S
M=#TB0'-T>6QE.F9A;6EL>3TG<')E<V5N=&%T:6]N)R(^"B`@("`@("`@("`@
M("`@("`\>'-L.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS
M;&%T92@D<W1Y;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@
M("`@(#PO>'-L.G=H96X^"B`@("`@("`@("`@(#QX<VPZ=VAE;B!T97-T/2)`
M<W1Y;&4Z9F%M:6QY/2=C;VYT<F]L)R(^"B`@("`@("`@("`@("`@("`\>'-L
M.G9A;'5E+6]F('-E;&5C=#TB8V]N8V%T*"<J+B<L('1R86YS;&%T92@D<W1Y
M;&4M;F%M92P@)RX@)2@I+UPG+"`G)RDI(B\^"B`@("`@("`@("`@(#PO>'-L
M.G=H96X^"B`@("`@("`@/"]X<VPZ8VAO;W-E/@H@("`@/"]X<VPZ=&5M<&QA
M=&4^"@H*("`@(#PA+2T@9FEN9&EN9R!A;&P@<W1Y;&4@8VAI;&0@;V8@82!S
M96-T:6]N(&%N9"!G:79E('1H96ER('-T>6QE261E;G1I9FEE<B!T;R!T:&4@
M;W5T<'5T("TM/@H@("`@/'AS;#IT96UP;&%T92!N86UE/2=W<FET92UC:&EL
M9')E;BUS='EL92UN86UE<R<^"B`@("`@("`@/'AS;#IP87)A;2!N86UE/2)P
M87)E;G13='EL94YA;64B('-E;&5C=#TB0'-T>6QE.FYA;64B+SX*("`@("`@
M("`\>'-L.G!A<F%M(&YA;64](G!A<F5N=%-T>6QE1F%M:6QY(B!S96QE8W0]
M(D!S='EL93IF86UI;'DB+SX*("`@("`@("`\>'-L.G!A<F%M(&YA;64](G-E
M87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H*"B`@("`@("`@/"$M+2HJ
M('1H92!N86UE<R!O9B!A;&P@;V9F:6-E.G-T>6QE<R!C:&EL9')E;B!W:6QL
M(&)E('=R:71T96X@;W5T"B`@("`@("`@("`@("HJ("AA(&%U=&]M871I8R!S
M='EL92!C86X@;VYL>2!H879E(&-H:6QD<F5N(&EN('1H92!O9F9I8V4Z875T
M;VUA=&EC+7-T>6QE('-E8W1I;VXI("TM/@H*("`@("`@("`\(2TM(&EF($Y/
M5"!C86QL960@9G)O;2!A(&]F9FEC93IA=71O;6%T:6,M<W1Y;&4@<&%R96YT
M("TM/@H@("`@("`@(#QX<VPZ:68@=&5S=#TB;F]T*'-E87)C:$]N;'E);D%U
M=&]M871I8U-T>6QE<RDB/@H@("`@("`@("`@("`\(2TM(&9O<B!A;&P@8VAI
M;&1R96X@:6X@=&AE(&]F9FEC93IS='EL92!S96-T:6]N("TM/@H@("`@("`@
M("`@("`\>'-L.F9O<BUE86-H('-E;&5C=#TB+BXO<W1Y;&4Z<W1Y;&5;0'-T
M>6QE.F9A;6EL>3TD<&%R96YT4W1Y;&5&86UI;'D@86YD($!S='EL93IP87)E
M;G0M<W1Y;&4M;F%M93TD<&%R96YT4W1Y;&5.86UE72(^"B`@("`@("`@("`@
M("`@("`\(2TM('=R:71E('1H92!S='EL92!N86UE(&EN('1H92!C<W,@:&5A
M9&5R("TM/@H@("`@("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA
M;64](G=R:71E+7-T>6QE+6YA;64B+SX*"B`@("`@("`@("`@("`@("`\(2TM
M('-E87)C:"!F;W(@8VAI;&0@<W1Y;&5S("TM/@H@("`@("`@("`@("`@("`@
M/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E+6-H:6QD<F5N+7-T>6QE
M+6YA;65S(CX*("`@("`@("`@("`@("`@("`@("`\>'-L.G=I=&@M<&%R86T@
M;F%M93TB<&%R96YT4W1Y;&5.86UE(B!S96QE8W0](D!S='EL93IN86UE(B\^
M"B`@("`@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A<F%M(&YA;64](G!A
M<F5N=%-T>6QE1F%M:6QY(B!S96QE8W0](D!S='EL93IF86UI;'DB+SX*("`@
M("`@("`@("`@("`@(#PO>'-L.F-A;&PM=&5M<&QA=&4^"@H@("`@("`@("`@
M("`\+WAS;#IF;W(M96%C:#X*("`@("`@("`\+WAS;#II9CX*"B`@("`@("`@
M/"$M+2HJ('1H92!N86UE<R!O9B!A;&P@;V9F:6-E.F%U=&]M871I8RUS='EL
M97,@8VAI;&1R96X@=VEL;"!B92!W<FET=&5N(&]U="`M+3X*"B`@("`@("`@
M/"$M+2!F;W(@86QL(&-H:6QD<F5N(&EN('1H92!O9F9I8V4Z875T;VUA=&EC
M+7-T>6QE('-E8W1I;VX@+2T^"B`@("`@("`@/'AS;#IF;W(M96%C:"!S96QE
M8W0](B1O9F9I8V4Z875T;VUA=&EC+7-T>6QE<R]S='EL93IS='EL95M`<W1Y
M;&4Z9F%M:6QY/21P87)E;G13='EL949A;6EL>2!A;F0@0'-T>6QE.G!A<F5N
M="US='EL92UN86UE/21P87)E;G13='EL94YA;65=(CX*("`@("`@("`@("`@
M/"$M+2!W<FET92!T:&4@<W1Y;&4@;F%M92!I;B!T:&4@8W-S(&AE861E<B`M
M+3X*("`@("`@("`@("`@/'AS;#IC86QL+71E;7!L871E(&YA;64](G=R:71E
M+7-T>6QE+6YA;64B+SX*"B`@("`@("`@("`@(#PA+2T@<V5A<F-H(&9O<B!C
M:&EL9"!S='EL97,@+2T^"B`@("`@("`@("`@(#QX<VPZ8V%L;"UT96UP;&%T
M92!N86UE/2)W<FET92UC:&EL9')E;BUS='EL92UN86UE<R(^"B`@("`@("`@
M("`@("`@("`\>'-L.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5.86UE
M(B!S96QE8W0](D!S='EL93IN86UE(B\^"B`@("`@("`@("`@("`@("`\>'-L
M.G=I=&@M<&%R86T@;F%M93TB<&%R96YT4W1Y;&5&86UI;'DB('-E;&5C=#TB
M0'-T>6QE.F9A;6EL>2(O/@H@("`@("`@("`@("`@("`@/'AS;#IW:71H+7!A
M<F%M(&YA;64](G-E87)C:$]N;'E);D%U=&]M871I8U-T>6QE<R(O/@H@("`@
M("`@("`@("`\+WAS;#IC86QL+71E;7!L871E/@H*("`@("`@("`\+WAS;#IF
M;W(M96%C:#X*("`@(#PO>'-L.G1E;7!L871E/@H*/"]X<VPZ<W1Y;&5S:&5E
M=#X*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]L:6(O2&]R9&4O5&]K96XO9FEL92YP:'``````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,3`V-#0@,3`U,34T,S0Q,S<@,#(R,#8R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B!4;VME;B!T<F%C:VEN9R!I;7!L96UE;G1A=&EO;B!F;W(@;&]C
M86P@9FEL97,N"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@
M("`G=&]K96Y?9&ER)R`@5&AE(&1I<F5C=&]R>2!W:&5R92!T;R!K965P('1O
M:V5N(&9I;&5S+@H@*B`@("=T:6UE;W5T)R`@("!4:&4@<&5R:6]D("AI;B!S
M96-O;F1S*2!A9G1E<B!W:&EC:"!A;B!I9"!I<R!P=7)G960N"B`J("`@("`@
M("`@("`@("`@($1E9F%U;'1S('1O(#@V-#`P("AI+F4N(#(T(&AO=7)S*2X\
M+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&]K96XO5&]K96XO9FEL
M92YP:'`L=B`Q+C$Y+C8N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,Y(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($UA>"!+86QI:V$@/&UA>$!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-87@@2V%L
M:6MA(#QM87A`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@
M0'!A8VMA9V4@2&]R9&5?5&]K96X*("HO"F-L87-S($AO<F1E7U1O:V5N7V9I
M;&4@97AT96YD<R!(;W)D95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(86YD
M;&4@9F]R('1H92!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@("`J"B`@("`@
M*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V9D(#T@9F%L<V4[
M"@H@("`@+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@=VAE=&AE<B!O
M<B!N;W0@=V4@:&%V92!A;B!O<&5N(&9I;&4@9&5S8W)I<'1O<BX*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C
M=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!N97<@9FEL
M92!B87-E9"!T;VME;BUT<F%C:VEN9R!C;VYT86EN97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG('-T
M;W)A9V4@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?
M5&]K96Y?9FEL92@D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["@H@("`@("`@("\J($-H;V]S92!T
M:&4@9&ER96-T;W)Y('1O('-A=F4@=&AE('-T=6(@9FEL97,N("HO"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`](%5T
M:6PZ.F=E=%1E;7!$:7(H*3L*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T
M:6UE;W5T('1O(#(T(&AO=7)S(&EF(&YO="!S<&5C:69I960N("HO"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==(#T@.#8T,#`[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;&P@
M97AP:7)E9"!C;VYN96-T:6]N(&ED)W,@9G)O;2!T:&4@4U%,('-E<G9E<BX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@5')U92!O;B!S=6-C97-S
M+"!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!U<F=E*"D*("`@('L*("`@("`@("`O+R!-86ME('-U<F4@
M=V4@:&%V92!N;R!O<&5N(&9I;&4@9&5S8W)I<'1O<G,@8F5F;W)E('5N;&EN
M:VEN9PH@("`@("`@("\O(&9I;&5S+@H@("`@("`@(&EF("@A)'1H:7,M/E]D
M:7-C;VYN96-T*"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)U5N86)L92!T;R!C;&]S92!F:6QE(&1E<V-R:7!T;W)S)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!"=6EL9"!S='5B(&9I;&4@;&ES="X@*B\*
M("`@("`@("!I9B`H(2@D9&ER(#T@;W!E;F1I<B@D=&AI<RT^7W!A<F%M<ULG
M=&]K96Y?9&ER)UTI*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G56YA8FQE('1O(&]P96X@=&]K96X@9&ER96-T;W)Y)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!&:6YD(&5X<&ER960@<W1U8B!F:6QE<R`J
M+PH@("`@("`@('=H:6QE("@H)&1I<D5N=')Y(#T@<F5A9&1I<B@D9&ER*2D@
M(3T@)R<I('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>8V]N;E]<
M=WLX?21\)RP@)&1I<D5N=')Y*2`F)B`H=&EM92@I("T@9FEL96UT:6UE*"1T
M:&ES+3Y?<&%R86US6R=T;VME;E]D:7(G72`N("<O)R`N("1D:7)%;G1R>2D@
M/CT@)'1H:7,M/E]P87)A;7-;)W1I;65O=70G72DI('L*("`@("`@("`@("`@
M("`@(&EF("@A0'5N;&EN:R@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?9&ER)UT@
M+B`G+R<@+B`D9&ER16YT<GDI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!P=7)G92!T;VME;B!F
M:6QE+B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!C;&]S961I<B@D9&ER*3L*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("!F=6YC=&EO;B!E>&ES=',H)'1O:V5N240I"B`@
M("!["B`@("`@("`@:68@*&ES7V$H*"1R97-U;'0@/2`D=&AI<RT^7V-O;FYE
M8W0H)'1O:V5N240I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($9I;F0@86QR
M96%D>2!U<V5D($E$<RX@*B\*("`@("`@("`D9FEL94-O;G1E;G1S(#T@0&9I
M;&4H)'1H:7,M/E]P87)A;7-;)W1O:V5N7V1I<B==("X@)R]C;VYN7R<@+B`D
M=&AI<RT^96YC;V1E4F5M;W1E061D<F5S<R@I*3L*("`@("`@("!I9B`H)&9I
M;&5#;VYT96YT<RD@>PH@("`@("`@("`@("`D:4UA>"`](&-O=6YT*"1F:6QE
M0V]N=&5N=',I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D:4UA
M>#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@:68@*&-H;W`H)&9I;&5#;VYT
M96YT<ULD:5TI(#T]("1T;VME;DE$*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!F
M=6YC=&EO;B!A9&0H)'1O:V5N240I"B`@("!["B`@("`@("`@:68@*&ES7V$H
M*"1R97-U;'0@/2`D=&AI<RT^7V-O;FYE8W0H)'1O:V5N240I*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"@H@("`@("`@("\J(%=R:71E('1H92!E;G1R>2X@*B\*("`@("`@("!F
M=W)I=&4H)'1H:7,M/E]F9"P@(B1T;VME;DE$7&XB*3L*"B`@("`@("`@+RH@
M4F5T=7)N(&%N(&5R<F]R(&EF('1H92!U<&1A=&4@9F%I;',L('1O;RX@*B\*
M("`@("`@("!I9B`H(21T:&ES+3Y?9&ES8V]N;F5C="@I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=&86EL960@=&\@8VQO<V4@
M=&]K96X@9FEL92!C;&5A;FQY+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&9I;&4@
M9&5S8W)I<'1O<B!T;R!A(&YE=R!O<B!E>&ES=&EN9R!F:6QE+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C;VYN96-T*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("@A)'1H
M:7,M/E]C;VYN96-T960I('L*"B`@("`@("`@("`@("\O($]P96X@82!F:6QE
M(&1E<V-R:7!T;W(@=&\@=&AE('1O:V5N('-T=6(@9FEL92X*("`@("`@("`@
M("`@)'1H:7,M/E]F9"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M<ULG=&]K96Y?
M9&ER)UT@+B`G+V-O;FY?)R`N("1T:&ES+3YE;F-O9&5296UO=&5!9&1R97-S
M*"DL("=A)RD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]F9"D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T
M;R!O<&5N('1O:V5N(&9I;&4N)RD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V5S
M('1H92!F:6QE(&1E<V-R:7!T;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M
M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N(&9C;&]S
M92@D=&AI<RT^7V9D*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]4;VME;B]S<6PN<&AP````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q-#(T,"`Q,#4Q-30S-#$S-R`P,C$W,S8`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1O
M:V5N('1R86-K:6YG(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A
M=&%B87-E(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!P87)A
M;65T97)S.CQP<F4^"B`J("`@)W!H<'1Y<&4G("`@5&AE(&1A=&%B87-E('1Y
M<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X\+W!R93X*("H*("H@
M4F5Q=6ER960@8GD@<V]M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R
M93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N
M"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!D871A8F%S
M92!S97)V97(N"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@
M=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W
M;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G
M+@H@*B`@("=O<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S
M('1O('1H92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4:&4@5%19(&]N
M('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T
M)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^
M"B`J("`@)W1A8FQE)R`@("`@5&AE(&YA;64@;V8@=&AE('1O:V5N<R!T86)L
M92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M("=H;W)D95]T;VME;G,G+@H@*B`@("=T:6UE;W5T)R`@(%1H92!P97)I;V0@
M*&EN('-E8V]N9',I(&%F=&5R('=H:6-H(&%N(&ED(&ES('!U<F=E9"X*("H@
M("`@("`@("`@("`@("!$969A=6QT<R!T;R`X-C0P,"`H:2YE+B`R-"!H;W5R
M<RDN/"]P<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!T
M;VME;G,@:7,@87,@9F]L;&]W<SH*("H*("H@/'!R93X*("H@0U)%051%(%1!
M0DQ%(&AO<F1E7W1O:V5N<R`H"B`J("`@("!T;VME;E]A9&1R97-S("`@(%9!
M4D-(05(H,3`P*2!.3U0@3E5,3"P*("H@("`@('1O:V5N7VED("`@("`@("`@
M5D%20TA!4B@S,BD@3D]4($Y53$PL"B`J("`@("!T;VME;E]T:6UE<W1A;7`@
M($))1TE.5"!.3U0@3E5,3"P*("H*("H@("`@(%!224U!4ED@2T59("AT;VME
M;E]A9&1R97-S+"!T;VME;E]I9"D*("H@*3L*("H@/"]P<F4^"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U1O:V5N+U1O:V5N+W-Q;"YP:'`L=B`Q+C(S+C8N
M,3(@,C`P-B\P,2\Q."`Q.3HT,#HU,2!B96X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#$Y.3DM,C`P-B!-87@@2V%L:6MA(#QM87A`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%X($MA;&EK82`\;6%X0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E
M7U1O:V5N"B`J+PIC;&%S<R!(;W)D95]4;VME;E]S<6P@97AT96YD<R!(;W)D
M95]4;VME;B!["@H@("`@+RHJ"B`@("`@*B!(86YD;&4@9F]R('1H92!C=7)R
M96YT(&1A=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0'9A<B!$
M0@H@("`@("HO"B`@("!V87(@)%]D8B`]("<G.PH*("`@("\J*@H@("`@("H@
M0F]O;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE
M8W1E9"!T;R!T:&4@4U%,"B`@("`@*B!S97)V97(N"B`@("`@*@H@("`@("H@
M0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7V-O;FYE8W1E9"`](&9A
M;'-E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!344P@8V]N
M;F5C=&EO;B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@2&]R9&5?5&]K96Y?<W%L*"1P87)A
M;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M)'!A<F%M<SL*"B`@("`@("`@+RH@4V5T('1I;65O=70@=&\@,C0@:&]U<G,@
M:68@;F]T('-P96-I9FEE9"X@*B\*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?<&%R86US6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T:6UE;W5T)UT@/2`X-C0P,#L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S(&%L;"!E>'!I<F5D(&-O;FYE8W1I;VX@
M:60G<R!F<F]M('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!U<F=E*"D*
M("`@('L*("`@("`@("!I9B`H:7-?82@H)')E<W5L="`]("1T:&ES+3Y?8V]N
M;F5C="@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\J($)U:6QD(%-13"!Q=65R
M>2X@*B\*("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==("X@)R!72$5212`G.PH@("`@("`@("1Q=65R
M>2`N/2`G=&]K96Y?=&EM97-T86UP(#P@/R<["@H@("`@("`@("1V86QU97,@
M/2!A<G)A>2AT:6UE*"D@+2`D=&AI<RT^7W!A<F%M<ULG=&EM96]U="==*3L*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@
M)'9A;'5E<RD["@H@("`@("`@("\J(%)E='5R;B!A;B!E<G)O<B!I9B!T:&4@
M=7!D871E(&9A:6QS+"!T;V\N("HO"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&5X:7-T<R@D=&]K96Y)1"D*("`@('L*("`@("`@("!I9B`H
M:7-?82@H)')E<W5L="`]("1T:&ES+3Y?8V]N;F5C="@I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!"=6EL9"!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y
M("`]("=314Q%0U0@=&]K96Y?:60@1E)/32`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT["B`@("`@("`@)'%U97)Y("X]("<@5TA%4D4@=&]K96Y?861D
M<F5S<R`](#\G.PH@("`@("`@("1Q=65R>2`N/2`G($%.1"!T;VME;E]I9"`]
M(#\G.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F5N8V]D95)E
M;6]T94%D9')E<W,H*2P@)'1O:V5N240I.PH*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^9V5T3VYE*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N("%E;7!T>2@D<F5S=6QT*3L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@861D*"1T;VME;DE$*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M*"@D<F5S=6QT(#T@)'1H:7,M/E]C;VYN96-T*"DI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@
M("`@("`@+RH@0G5I;&0@4U%,('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`@
M/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?<&%R86US6R=T86)L92==("X@
M)R`H=&]K96Y?861D<F5S<RP@=&]K96Y?:60L('1O:V5N7W1I;65S=&%M<"D@
M)SL*("`@("`@("`D<75E<GD@+CT@)U9!3%5%4R`H/RP@/RP@/RDG.PH*("`@
M("`@("`D=F%L=65S(#T@87)R87DH)'1H:7,M/F5N8V]D95)E;6]T94%D9')E
M<W,H*2P@)'1O:V5N240L('1I;64H*2D["@H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS(&$@8V]N;F5C=&EO;B!T
M;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<RP@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("![
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`](%5T
M:6PZ.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@87)R87DH
M)W!H<'1Y<&4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T;VME;B!344PG+"!A<G)A>2@G9')I=F5R)R`]/B`G=&]K
M96XG*2D["B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@
M)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A
M;7-;)W5S97)N86UE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#T@)R<["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@
M)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==(#T@)VAO<F1E7W1O:V5N<R<["B`@("`@("`@?0H*("`@("`@("`O
M*B!#;VYN96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S=7!P;&EE
M9"!P87)A;65T97)S+B`J+PH@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP
M)SL*("`@("`@("`D=&AI<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?
M<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R
M<VES=&5N="==*2DI.PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?9&(L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&([
M"B`@("`@("`@?0H*("`@("`@("`O+R!3970@1$(@<&]R=&%B:6QI='D@;W!T
M:6]N<RX*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H<'1Y<&4I('L*
M("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@("1T:&ES+3Y?9&(M
M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465],3U=%
M4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,@?"!$0E]03U)404))3$E4
M65]25%))32D["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z
M"B`@("`@("`@("`@("1T:&ES+3Y?9&(M/G-E=$]P=&EO;B@G<&]R=&%B:6QI
M='DG+"!$0E]03U)404))3$E465],3U=%4D-!4T4@?"!$0E]03U)404))3$E4
M65]%4E)/4E,I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M960@/2!T<G5E.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E<G9E<B!A;F0@
M8VQE86X@=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1I<V-O;FYE
M8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O1F]R;2]4>7!E````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S<@,#(Q,3$R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M+T%C=&EO;@``
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$S-R`P,C$T,#8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO
M<F1E+T9O<FTO06-T:6]N+G!H<```````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$P-S`S(#$P-3$U-#,T,3,W(#`R,C$W-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M5&AE($AO<F1E7T9O<FU?06-T:6]N(&-L87-S('!R;W9I9&5S(&%N($%022!F
M;W(@861D:6YG(&%C=&EO;G,@=&\*("H@2&]R9&5?1F]R;2!V87)I86)L97,N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXN<&AP
M+'8@,2XQ.2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,3<@:F%N($5X<"`D"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?
M1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D
M7VED.PH@("`@=F%R("1?<&%R86US.PH@("`@=F%R("1?=')I9V=E<B`](&YU
M;&P["@H@("`@9G5N8W1I;VX@2&]R9&5?1F]R;5]!8W1I;VXH)'!A<F%M<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US
M.PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;71?<F%N9"@I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!G9714<FEG9V5R*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]T<FEG9V5R.PH@("`@?0H*("`@(&9U;F-T:6]N(&ED*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]I9#L*("`@('T*"B`@("!F
M=6YC=&EO;B!G971!8W1I;VY38W)I<'0H)&9O<FTL("1R96YD97)E<BP@)'9A
M<FYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@(&9U
M;F-T:6]N('!R:6YT2F%V85-C<FEP="@I"B`@("!["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W!R:6YT2F%V85-C<FEP=%-T87)T*"D*("`@('L*("`@("`@("!E
M8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(^/"$M+2<["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W!R:6YT2F%V85-C<FEP=$5N9"@I"B`@("![
M"B`@("`@("`@96-H;R`G+R\@+2T^/"]S8W)I<'0^)SL*("`@('T*"B`@("!F
M=6YC=&EO;B!G971487)G970H*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^7W!A<F%M<ULG=&%R9V5T)UTI(#\@)'1H:7,M/E]P87)A;7-;
M)W1A<F=E="==(#H@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B!S971686QU
M97,H)B1V87)S+"`D<V]U<F-E5F%L+"`D:6YD97@@/2!N=6QL+"`D87)R87E6
M86P@/2!F86QS92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M
M<'1S('1O(')E='5R;B!A(&-O;F-R971E($AO<F1E7T9O<FU?06-T:6]N(&EN
M<W1A;F-E"B`@("`@*B!B87-E9"!O;B`D9F]R;2X*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&9O<FT@("`@5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R
M9&5?1F]R;5]!8W1I;VX@<W5B8VQA<W,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!T;R!R971U<FXN($EF("1F;W)M(&ES(&%N(&%R<F%Y+"!T:&5N
M('=E('=I;&P@;&]O:PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EN
M("1F;W)M6S!=+VQI8B]&;W)M+T%C=&EO;B\@9F]R('1H92!S=6)C;&%S<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N(&YA
M;65D("1F;W)M6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US
M("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T
M:6]N(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!F;W)M(&UI9VAT
M(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]&;W)M7T%C=&EO
M;B`@5&AE(&-O;F-R971E($AO<F1E7T9O<FU?06-T:6]N(')E9F5R96YC92P@
M;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D86-T
M:6]N+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R
M87DH)&%C=&EO;BDI('L*("`@("`@("`@("`@)&%P<"`]("1A8W1I;VY;,%T[
M"B`@("`@("`@("`@("1A8W1I;VX@/2`D86-T:6]N6S%=.PH@("`@("`@('T*
M"B`@("`@("`@)&%C=&EO;B`](&)A<V5N86UE*"1A8W1I;VXI.PH@("`@("`@
M(&EF("AE;7!T>2@D86-T:6]N*2!\?"`H<W1R8VUP*"1A8W1I;VXL("=N;VYE
M)RD@/3T@,"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T-A;FYO="!I;G-T86YT:6%T92!A8G-T<F%C="!C;&%S<R!(;W)D95]&
M;W)M7T%C=&EO;BXG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)&%P<"DI('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("1'3$]"04Q36R=R
M96=I<W1R>2==+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+VQI8B]&;W)M
M+T%C=&EO;B\G("X@)&%C=&EO;B`N("<N<&AP)SL*("`@("`@("!](&5L<V5I
M9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%7U\I("X@)R]!8W1I;VXO
M)R`N("1A8W1I;VX@+B`G+G!H<"<I*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O06-T:6]N+R<@+B`D86-T:6]N
M("X@)RYP:'`G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G2&]R9&4O1F]R;2]!8W1I;VXO)R`N("1A8W1I;VX@+B`G+G!H
M<"<["B`@("`@("`@?0H*("`@("`@("`D8VQA<W,@/2`G2&]R9&5?1F]R;5]!
M8W1I;VY?)R`N("1A8W1I;VX["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D
M8VQA<W,I*2!["B`@("`@("`@("`@("1I;G-T86YC92`]("9N97<@)&-L87-S
M*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;G-T
M86YC92`](%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@
M)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1I;G-T86YC93L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(')E='5R;B!A(')E9F5R96YC92!T;R!A(&-O;F-R971E"B`@
M("`@*B!(;W)D95]&;W)M7T%C=&EO;B!I;G-T86YC92!B87-E9"!O;B`D86-T
M:6]N+B!)="!W:6QL(&]N;'D*("`@("`J(&-R96%T92!A(&YE=R!I;G-T86YC
M92!I9B!N;R!(;W)D95]&;W)M7T%C=&EO;B!I;G-T86YC92!W:71H"B`@("`@
M*B!T:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@
M*@H@("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!T>7!E
M<R!O9B!F;W)M(')E;F1E<F5R<R`H86YD+`H@("`@("H@=&AU<RP@;75L=&EP
M;&4@2&]R9&5?1F]R;5]!8W1I;VX@:6YS=&%N8V5S*2!A<F4@<F5Q=6ER960N
M"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S
M.B`D=F%R(#T*("`@("`J("9(;W)D95]&;W)M7T%C=&EO;CHZ<VEN9VQE=&]N
M*"D*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&%C=&EO;B`@5&AE('1Y
M<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R;5]!8W1I;VX@<W5B8VQA<W,@=&\@
M<F5T=7)N+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(%1H92!C;V1E
M(&ES(&1Y;F%M:6-A;&QY(&EN8VQU9&5D+B!)9B`D86-T:6]N(&ES(&%N(&%R
M<F%Y+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1H96X@=V4@=VEL
M;"!L;V]K(&EN("1A8W1I;VY;,%TO;&EB+T9O<FTO06-T:6]N+R!F;W(*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@<W5B8VQA<W,@:6UP;&5M
M96YT871I;VX@;F%M960@)&%C=&EO;ELQ72YP:'`N"B`@("`@*B!`<&%R86T@
M87)R87D@)'!A<F%M<R`@02!H87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N
M86P@8V]N9FEG=7)A=&EO;B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@9F]R;2!M:6=H="!N965D+@H@("`@("H*("`@("`J($!R971U<FX@2&]R
M9&5?1F]R;5]!8W1I;VX@(%1H92!C;VYC<F5T92!(;W)D95]&;W)M7T%C=&EO
M;B!R969E<F5N8V4L(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)G-I;F=L971O;B@D86-T:6]N+"`D<&%R86US(#T@;G5L;"D*("`@('L*("`@
M("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES<V5T*"1I
M;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA;&EZ92AA
M<G)A>2@D86-T:6]N+"`D<&%R86US*2D["B`@("`@("`@:68@*"%I<W-E="@D
M:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N
M8V5S6R1S:6=N871U<F5=(#T@)DAO<F1E7T9O<FU?06-T:6]N.CIF86-T;W)Y
M*"1A8W1I;VXL("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1F]R;2]2
M96YD97)E<BYP:'``````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-#0R,#0@,3`U,34T,S0Q,S<@,#(R-3,S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@2&]R9&5?
M1F]R;5]296YD97)E<B!C;&%S<R!P<F]V:61E<R!(5$U,(&%N9"!O=&AE<B!R
M96YD97)I;F=S(&]F"B`J(&9O<FUS(&9O<B!T:&4@2&]R9&5?1F]R;3HZ('!A
M8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]296YD
M97)E<BYP:'`L=B`Q+C$X-2XT+C$U(#(P,#8O,#0O,34@,3@Z,#4Z,#0@8VAU
M8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!2;V)E<G0@12X@
M0V]Y;&4@/')O8F5R=&5C;WEL94!H;W1M86EL+F-O;3X*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@(%)O8F5R="!%+B!#;WEL92`\<F]B97)T96-O>6QE
M0&AO=&UA:6PN8V]M/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J+PIC;&%S
M<R!(;W)D95]&;W)M7U)E;F1E<F5R('L*"B`@("!V87(@)%]N86UE.PH@("`@
M=F%R("1?<F5Q=6ER961,96=E;F0@/2!F86QS93L*("`@('9A<B`D7W)E<75I
M<F5D36%R:V5R(#T@)RHG.PH@("`@=F%R("1?:&5L<$UA<FME<B`]("<_)SL*
M("`@('9A<B`D7V]N3&]A9$I3(#T@87)R87DH*3L*("`@('9A<B`D7W-H;W=(
M96%D97(@/2!T<G5E.PH@("`@=F%R("1?8V]L<R`](#(["B`@("!V87(@)%]V
M87)296YD97)E<B`](&YU;&P["B`@("!V87(@)%]F:7)S=$9I96QD(#T@;G5L
M;#L*("`@('9A<B`D7W-T<FEP9612;W=S(#T@=')U93L*"B`@("`O*BH*("`@
M("`J($1O97,@=&AE('1I=&QE(&]F('1H92!F;W)M(&-O;G1A:6X@2%1-3#\@
M268@<V\L('EO=2!A<F4@<F5S<&]N<VEB;&4@9F]R"B`@("`@*B!D;VEN9R!A
M;GD@;F5E9&5D(&5S8V%P:6YG+W-A;FET:7IA=&EO;B!Y;W5R<V5L9BX@3W1H
M97)W:7-E('1H92!T:71L90H@("`@("H@=VEL;"!B92!R=6X@=&AR;W5G:"!H
M=&UL<W!E8VEA;&-H87)S*"D@8F5F;W)E(&)E:6YG(&]U='!U="X*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?96YC;V1E
M5&ET;&4@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5VED=&@@;V8@=&AE(&%T
M=')I8G5T97,@8V]L=6UN+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?871T<D-O
M;'5M;E=I9'1H(#T@)S$U)2<["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W0@
M82!N97<@2&]R9&5?1F]R;5]296YD97)E<CHZ+@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!4:&ES(&ES(&$@:&%S:"!O9B!R96YD97)E
M<BUS<&5C:69I8R!P87)A;65T97)S+@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(%!O<W-I8FQE(&ME>7,Z/&-O9&4^"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@)W9A<G)E;F1E<F5R7V1R:79E<B<Z('-P96-I9FEE<R!T
M:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('!A
M<F%M971E<B!T;R!(;W)D95]525]687)296YD97)E<CHZ9F%C=&]R>2@I+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("=E;F-O9&5?=&ET;&4G.B!`
M<V5E("1?96YC;V1E5&ET;&4\+V-O9&4^"B`@("`@*B\*("`@(&9U;F-T:6]N
M($AO<F1E7T9O<FU?4F5N9&5R97(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*("`@("`@("!I9B`H:7-S970H
M)')E9VES=')Y*2`F)B!I<U]A*"1R96=I<W1R>2P@)U)E9VES=')Y)RDI('L*
M("`@("`@("`@("`@+RH@4F5G:7-T<GD@879A:6QA8FQE+"!S;R!U<V4@82!P
M<F5T='D@:6UA9V4N("HO"B`@("`@("`@("`@("1T:&ES+3Y?<F5Q=6ER961-
M87)K97(@/2!(;W)D93HZ:6UG*"=R97%U:7)E9"YP;F<G+"`G*B<L("<G+"`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O*B!.;R!R96=I<W1R>2!A=F%I;&%B;&4L('5S
M92!S;VUE=&AI;F<@<&QA:6XN("HO"B`@("`@("`@("`@("1T:&ES+3Y?<F5Q
M=6ER961-87)K97(@/2`G*B<["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S
M970H)'!A<F%M<ULG96YC;V1E7W1I=&QE)UTI*2!["B`@("`@("`@("`@("1T
M:&ES+3YE;F-O9&54:71L92@D<&%R86US6R=E;F-O9&5?=&ET;&4G72D["B`@
M("`@("`@?0H*("`@("`@("`D9')I=F5R(#T@)VAT;6PG.PH@("`@("`@(&EF
M("AI<W-E="@D<&%R86US6R=V87)R96YD97)E<E]D<FEV97(G72DI('L*("`@
M("`@("`@("`@)&1R:79E<B`]("1P87)A;7-;)W9A<G)E;F1E<F5R7V1R:79E
M<B==.PH@("`@("`@('T*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U5)
M+U9A<E)E;F1E<F5R+G!H<"<["B`@("`@("`@)'1H:7,M/E]V87)296YD97)E
M<B`]("9(;W)D95]525]687)296YD97)E<CHZ9F%C=&]R>2@D9')I=F5R+"`D
M<&%R86US*3L*("`@('T*"B`@("!F=6YC=&EO;B!S:&]W2&5A9&5R*"1B;V]L
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<VAO=TAE861E<B`]("1B;V]L.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!O<B!R971U<FYS('=H971H97(@
M=&AE(&9O<FT@=&ET;&4@<VAO=6QD(&)E(&5N8V]D960@=VET:`H@("`@("H@
M:'1M;'-P96-I86QC:&%R<R@I+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L
M96%N("1E;F-O9&4@($EF('1R=64L('1H92!F;W)M('1I=&QE(&=E=',@96YC
M;V1E9"X@($EF(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!T:&4@=&ET;&4@8V%N(&-O;G1A:6X@2%1-3"P@8G5T('1H92!C;&%S<R!U
M<V5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!I<R!R97-P;VYS
M:6)L92!T;R!E;F-O9&4@86YY('-P96-I86P@8VAA<F%C=&5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AE(&9O<FT@=&ET
M;&4@<VAO=6QD(&)E(&5N8V]D960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N
M8V]D951I=&QE*"1E;F-O9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?;G5L;"@D96YC;V1E*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5N8V]D
M951I=&QE(#T@)&5N8V]D93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?96YC;V1E5&ET;&4@/2`D96YC;V1E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W!E8VEF>2!T:&4@=VED=&@@;V8@=&AE(&%T=')I8G5T92!C;VQU
M;6X@:6X@=&AE(')E;F1E<F5D(&9O<FTN"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D=VED=&@@(%1H92!W:61T:"!O9B!T:&4@871T<FEB=71E(&-O
M;'5M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T071T<D-O;'5M;E=I9'1H*"1W:61T:"D*("`@('L*("`@
M("`@("`D=&AI<RT^7V%T=')#;VQU;6Y7:61T:"`]("1W:61T:#L*("`@('T*
M"B`@("!F=6YC=&EO;B!O<&5N*"1A8W1I;VXL("1M971H;V0L("1N86UE+"`D
M96YC='EP92`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]N86UE(#T@
M)&YA;64["B`@("`@("`@)&YA;64@/2!H=&UL<W!E8VEA;&-H87)S*"1N86UE
M*3L*("`@("`@("!E8VAO("(\9F]R;2!A8W1I;VX]7"(D86-T:6]N7"(@;65T
M:&]D/5PB)&UE=&AO9%PB(B`N("AE;7!T>2@D;F%M92D@/R`G)R`Z("(@;F%M
M93U<(B1N86UE7"(@:60]7"(D;F%M95PB(BD@+B`H:7-?;G5L;"@D96YC='EP
M92D@/R`G)R`Z("(@96YC='EP93U<(B1E;F-T>7!E7"(B*2`N("(^7&XB.PH@
M("`@("`@(%5T:6PZ.G!F;W)M26YP=70H*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!B96=I;D%C=&EV92@D;F%M92P@)&5X=')A(#T@;G5L;"D*("`@('L*("`@
M("`@("`D=&AI<RT^7W)E;F1E<D)E9VEN06-T:79E*"1N86UE+"`D97AT<F$I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&)E9VEN26YA8W1I=F4H)&YA;64L("1E
M>'1R82`](&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/E]R96YD97)"96=I
M;DEN86-T:79E*"1N86UE+"`D97AT<F$I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)396-T:6]N5&%B<R@F)&9O<FTI"B`@("!["B`@("`@("`@+RH@
M268@:F%V87-C<FEP="!I<R!N;W0@879A:6QA8FQE+"!D;R!N;W0@<F5N9&5R
M('1A8G,N("HO"B`@("`@("`@:68@*"$D1TQ/0D%,4ULG8G)O=W-E<B==+3YH
M87-&96%T=7)E*"=J879A<V-R:7!T)RDI('L*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@)&]P96Y?<V5C=&EO;B`]("1F;W)M+3YG
M971/<&5N4V5C=&EO;B@I.PH*("`@("`@("`O*B!!9&0@=&AE(&IA=F%S8W)I
M<'0@9F]R('1H92!T;V=G;&EN9R!T:&4@<V5C=&EO;G,N("HO"B`@("`@("`@
M2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)V9O<FU?<V5C=&EO;G,N:G,G+"`G:&]R
M9&4G+"!T<G5E*3L*("`@("`@("!E8VAO("<\<V-R:7!T('1Y<&4](G1E>'0O
M:F%V87-C<FEP="(^)R`N(")<;B(["B`@("`@("`@<')I;G1F*"=V87(@<V5C
M=&EO;G-?)3$D<R`](&YE=R!(;W)D95]&;W)M7U-E8W1I;VYS*%PG)3$D<UPG
M+"!<)R4R)'-<)RD[)RP*("`@("`@("`@("`@("`@)&9O<FTM/F=E=$YA;64H
M*2P*("`@("`@("`@("`@("`@)&]P96Y?<V5C=&EO;BD["B`@("`@("`@96-H
M;R`B7&XB("X@)SPO<V-R:7!T/B<["@H@("`@("`@("\J($QO;W`@=&AR;W5G
M:"!T:&4@<V5C=&EO;G,@86YD('!R:6YT(&]U="!A('1A8B!F;W(@96%C:"X@
M*B\*("`@("`@("!E8VAO("(\9&EV(&-L87-S/5PB=&%B<V5T7"(^/'5L/EQN
M(CL*("`@("`@("!F;W)E86-H("@D9F]R;2T^7W-E8W1I;VYS(&%S("1S96-T
M:6]N(#T^("1V86PI('L*("`@("`@("`@("`@)&-L87-S(#T@*"1S96-T:6]N
M(#T]("1O<&5N7W-E8W1I;VXI(#\@)R!C;&%S<STB86-T:79E5&%B(B<@.B`G
M)SL*("`@("`@("`@("`@)&IS(#T@<W!R:6YT9B@G;VYC;&EC:STB<V5C=&EO
M;G-?)7,N=&]G9VQE*%PG)7-<)RD[(')E='5R;B!F86QS93LB)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R;2T^9V5T3F%M92@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S96-T:6]N*3L*("`@("`@("`@("`@<')I
M;G1F*"<\;&DE<R!I9#TB)7,B/CQA(&AR968](B,B("5S/B5S)7,\+V$^(#PO
M;&D^)R`N(")<;B(L"B`@("`@("`@("`@("`@("`@("`D8VQA<W,L("=?=&%B
M7R<@+B`D<V5C=&EO;BP@)&IS+`H@("`@("`@("`@("`@("`@("`@)&9O<FTM
M/F=E=%-E8W1I;VY);6%G92@D<V5C=&EO;BDL"B`@("`@("`@("`@("`@("`@
M("`D9F]R;2T^9V5T4V5C=&EO;D1E<V,H)'-E8W1I;VXI*3L*("`@("`@("!]
M"B`@("`@("`@96-H;R`B/"]U;#X\+V1I=CX\8G(@8VQA<W,]7")C;&5A<EPB
M("\^7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)396-T:6]N0F5G
M:6XH)B1F;W)M+"`D<V5C=&EO;BD*("`@('L*("`@("`@("`O+R!3=')I<&4@
M86QT97)N871E(')O=W,@:68@=&AA="!O<'1I;VX@:7,@='5R;F5D(&]N+@H@
M("`@("`@(&EF("@D=&AI<RT^7W-T<FEP9612;W=S*2!["B`@("`@("`@("`@
M($AO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R9&4G+"!T
M<G5E*3L*("`@("`@("`@("`@)&-L87-S(#T@)R!C;&%S<STB<W1R:7!E9"(G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;&%S<R`]("<G.PH@
M("`@("`@('T*"B`@("`@("`@)&]P96Y?<V5C=&EO;B`]("1F;W)M+3YG971/
M<&5N4V5C=&EO;B@I.PH@("`@("`@(&EF("AE;7!T>2@D;W!E;E]S96-T:6]N
M*2D@>PH@("`@("`@("`@("`D;W!E;E]S96-T:6]N(#T@)U]?8F%S92<["B`@
M("`@("`@?0H@("`@("`@('!R:6YT9B@G/&1I=B!I9#TB)7,B('-T>6QE/2)D
M:7-P;&%Y.B5S.R(^/'1A8FQE)7,@8V5L;'-P86-I;F<](C`B/B<L"B`@("`@
M("`@("`@("`@("=?<V5C=&EO;E\G("X@)'-E8W1I;VXL"B`@("`@("`@("`@
M("`@("@D;W!E;E]S96-T:6]N(#T]("1S96-T:6]N(#\@)V)L;V-K)R`Z("=N
M;VYE)RDL"B`@("`@("`@("`@("`@("1C;&%S<RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E-E8W1I;VY%;F0H*0H@("`@>PH@("`@("`@(&5C:&\@
M)SPO=&%B;&4^/"]D:78^)SL*("`@('T*"B`@("!F=6YC=&EO;B!E;F0H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<F5N9&5R16YD*"D["B`@("!]"@H@("`@
M9G5N8W1I;VX@8VQO<V4H)&9O8W5S(#T@=')U92D*("`@('L*("`@("`@("!E
M8VAO("(\+V9O<FT^7&XB.PH@("`@("`@(&EF("@D9F]C=7,@)B8@(65M<'1Y
M*"1T:&ES+3Y?9FER<W1&:65L9"DI('L*("`@("`@("`@("`@96-H;R`G/'-C
M<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@H\(2TM"G1R>2!["B`@("!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@B)R`N("1T:&ES+3Y?9FER<W1&:65L
M9"`N("<B*2YF;V-U<R@I.PI](&-A=&-H*&4I('M]"B\O+2T^"CPO<V-R:7!T
M/@HG.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!L:7-T1F]R;59A
M<G,H)B1F;W)M*0H@("`@>PH@("`@("`@("1V87)I86)L97,@/2`F)&9O<FTM
M/F=E=%9A<FEA8FQE<RAT<G5E+"!T<G5E*3L*("`@("`@("`D=F%R<R`](&%R
M<F%Y*"D["B`@("`@("`@:68@*"1V87)I86)L97,I('L*("`@("`@("`@("`@
M9F]R96%C:"`H)'9A<FEA8FQE<R!A<R`D=F%R*2!["B`@("`@("`@("`@("`@
M("!I9B`H:7-?;V)J96-T*"1V87(I*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*"$D=F%R+3YI<U)E861O;FQY*"DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'9A<G-;)'9A<BT^9V5T5F%R3F%M92@I72`](#$["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D=F%R<ULD=F%R72`](#$["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92].3%,N<&AP)SL*("`@("`@("!E8VAO("<\:6YP=70@='EP
M93TB:&ED9&5N(B!N86UE/2)?9F]R;79A<G,B('9A;'5E/2(G("X@0&AT;6QS
M<&5C:6%L8VAA<G,H<V5R:6%L:7IE*"1V87)S*2P@14Y47U%53U1%4RP@3DQ3
M.CIG971#:&%R<V5T*"DI("X@)R(@+SXG.PH@("`@?0H*("`@(&9U;F-T:6]N
M(')E;F1E<D9O<FU!8W1I=F4H)B1F;W)M+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]R96YD97)&;W)M*"1F;W)M+"`D=F%R<RP@=')U92D["B`@
M("!]"@H@("`@9G5N8W1I;VX@<F5N9&5R1F]R;4EN86-T:79E*"8D9F]R;2P@
M)B1V87)S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<F5N9&5R1F]R;2@D9F]R
M;2P@)'9A<G,L(&9A;'-E*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M1F]R;2@F)&9O<FTL("8D=F%R<RP@)&%C=&EV92D*("`@('L*("`@("`@("`O
M*B!)9B!H96QP(&ES('!R97-E;G0@,R!C;VQU;6YS(&%R92!N965D960N("HO
M"B`@("`@("`@)'1H:7,M/E]C;VQS(#T@)&9O<FTM/FAA<TAE;'`H*2`_(#,@
M.B`R.PH*("`@("`@("`D=F%R:6%B;&5S(#T@)B1F;W)M+3YG971687)I86)L
M97,H9F%L<V4I.PH*("`@("`@("`O*B!#:&5C:R!F;W(@82!F;W)M('1O:V5N
M(&5R<F]R+B`J+PH@("`@("`@(&EF("@H)'1O:V5N17)R;W(@/2`D9F]R;2T^
M9V5T17)R;W(H)U]?9F]R;51O:V5N)RDI("$]/2!N=6QL*2!["B`@("`@("`@
M("`@('!R:6YT9B@G/'1R('9A;&EG;CTB=&]P(CX\=&0@8V]L<W!A;CTB)60B
M/CQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXE<SPO<W!A;CX\+W1D/CPO='(^
M)RP*("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]L<RP*("`@("`@("`@
M("`@("`@("`@("1T;VME;D5R<F]R*3L*("`@("`@("!]"@H@("`@("`@("1E
M<G)O<E]S96-T:6]N(#T@;G5L;#L*("`@("`@("!R97-E="@D=F%R:6%B;&5S
M*3L*("`@("`@("!I9B`H8V]U;G0H)'9A<FEA8FQE<RD@/B`Q('Q\(&ME>2@D
M=F%R:6%B;&5S*2`A/2`G7U]B87-E)RD@>PH@("`@("`@("`@("`D=&AI<RT^
M7W)E;F1E<E-E8W1I;VY486)S*"1F;W)M*3L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1V87)I86)L97,@87,@)'-E8W1I;VY?:60@/3X@)'-E8W1I
M;VXI('L*("`@("`@("`@("`@)'1H:7,M/E]R96YD97)396-T:6]N0F5G:6XH
M)&9O<FTL("1S96-T:6]N7VED*3L*("`@("`@("`@("`@9F]R96%C:"`H)'-E
M8W1I;VX@87,@)'9A<BD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@/2`D=F%R
M+3YG9714>7!E3F%M92@I.PH*("`@("`@("`@("`@("`@('-W:71C:"`H)'1Y
M<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@)VAE861E<B<Z"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96YD97)(96%D97(H)'9A<BT^9V5T2'5M
M86Y.86UE*"DL("1F;W)M+3YG971%<G)O<B@D=F%R+3YG971687).86UE*"DI
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=D97-C<FEP=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R96YD97)$97-C<FEP=&EO;B@D=F%R+3YG971(=6UA;DYA;64H*2D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G<W!A8V5R)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E
M;F1E<E-P86-E<B@I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)&ES
M26YP=70@/2`H)&%C=&EV92`F)B`A)'9A<BT^:7-296%D;VYL>2@I*3L*("`@
M("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@)&ES26YP=70@/R`G26YP=70G
M(#H@)T1I<W!L87DG.PH@("`@("`@("`@("`@("`@("`@("1B96=I;B`](")?
M<F5N9&5R5F%R)'MF;W)M871]0F5G:6XB.PH@("`@("`@("`@("`@("`@("`@
M("1E;F0@/2`B7W)E;F1E<E9A<B1[9F]R;6%T?45N9"(["@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3XD8F5G:6XH)&9O<FTL("1V87(L("1V87)S*3L*
M"B`@("`@("`@("`@("`@("`@("`@96-H;R`D=&AI<RT^7W9A<E)E;F1E<F5R
M+3YR96YD97(H)&9O<FTL("1V87(L("1V87)S+"`D:7-);G!U="D["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/B1E;F0H)&9O<FTL("1V87(L("1V87)S
M*3L*"B`@("`@("`@("`@("`@("`@("`@+RH@4')I;G0@86YY(&IA=F%S8W)I
M<'0@:68@86-T:6]N<R!P<F5S96YT+B`J+PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D=F%R+3YH87-!8W1I;VXH*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=F%R+3Y?86-T:6]N+3YP<FEN=$IA=F%38W)I<'0H*3L*("`@("`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J($ME97`@
M9FER<W0@9FEE;&0N("HO"B`@("`@("`@("`@("`@("`@("`@:68@*"1A8W1I
M=F4@)B8@96UP='DH)'1H:7,M/E]F:7)S=$9I96QD*2`F)B`A)'9A<BT^:7-2
M96%D;VYL>2@I("8F("$D=F%R+3YI<TAI9&1E;B@I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9FER<W1&:65L9"`]("1V87(M/F=E=%9A
M<DYA;64H*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("\J($ME97`@<V5C=&EO;B!W:71H(&9I<G-T(&5R<F]R+B`J+PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1E<G)O<E]S96-T:6]N
M*2`F)B`D9F]R;2T^9V5T17)R;W(H)'9A<BDI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&5R<F]R7W-E8W1I;VX@/2`D<V5C=&EO;E]I9#L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R4V5C=&EO;D5N9"@I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1E<G)O<E]S96-T:6]N
M*2`F)B`D9F]R;2T^7W-E8W1I;VYS*2!["B`@("`@("`@("`@(&5C:&\@)SQS
M8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CXG("X*("`@("`@("`@("`@
M("`@(")<;B(@+B!S<')I;G1F*"=S96-T:6]N<U\E<RYT;V=G;&4H7"<E<UPG
M*3LG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FTM/F=E
M=$YA;64H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O
M<E]S96-T:6]N*2`N"B`@("`@("`@("`@("`@("`B7&X\+W-C<FEP=#XB.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S=6)M:70H)'-U8FUI="`]
M(&YU;&PL("1R97-E="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AI<U]N
M=6QL*"1S=6)M:70I('Q\(&5M<'1Y*"1S=6)M:70I*2!["B`@("`@("`@("`@
M("1S=6)M:70@/2!?*")3=6)M:70B*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1R97-E="`]/3T@=')U92D@>PH@("`@("`@("`@("`D<F5S970@/2!?*")2
M97-E="(I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W)E;F1E<E-U8FUI
M="@D<W5B;6ET+"`D<F5S970I.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP
M;&5M96YT871I;VX@<W!E8VEF:6,@8F5G:6X@9G5N8W1I;VXN"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]R96YD97)"96=I;D%C=&EV92@D;F%M92P@)&5X=')A
M*0H@("`@>PH@("`@("`@(&5C:&\@)SQD:78@8VQA<W,](F9O<FTB(&ED/2(G
M("X@:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7VYA;64I("X@)R(^)SL*("`@
M("`@("!I9B`H)'1H:7,M/E]S:&]W2&5A9&5R*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<V5C=&EO;DAE861E<B@D;F%M92P@)&5X=')A*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"1T:&ES+3Y?<F5Q=6ER961,96=E;F0I('L*("`@("`@
M("`@("`@96-H;R`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<@+B`D=&AI
M<RT^7W)E<75I<F5D36%R:V5R("X@)SPO<W!A;CX@/2`G("X@7R@B4F5Q=6ER
M960@1FEE;&0B*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!)
M;7!L96UE;G1A=&EO;B!S<&5C:69I8R!B96=I;B!F=6YC=&EO;BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W)E;F1E<D)E9VEN26YA8W1I=F4H)&YA;64L("1E
M>'1R82D*("`@('L*("`@("`@("!E8VAO("<\9&EV(&-L87-S/2)F;W)M(B!I
M9#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]N86UE*2`N("<B/B<[
M"B`@("`@("`@:68@*"1T:&ES+3Y?<VAO=TAE861E<BD@>PH@("`@("`@("`@
M("`D=&AI<RT^7W-E8W1I;VY(96%D97(H)&YA;64L("1E>'1R82D["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT871I;VX@<W!E
M8VEF:6,@96YD(&9U;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5N
M9&5R16YD*"D*("`@('L*("`@("`@("!E8VAO("<\+V1I=CXG("X@)'1H:7,M
M/E]V87)296YD97)E<BT^<F5N9&5R16YD*"D["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W)E;F1E<DAE861E<B@D:&5A9&5R+"`D97)R;W(@/2`G)RD*("`@('L*
M/SX\='(^/'1D(&-L87-S/2)C;VYT<F]L(B!W:61T:#TB,3`P)2(@8V]L<W!A
M;CTB/#]P:'`@96-H;R`D=&AI<RT^7V-O;',@/SXB('9A;&EG;CTB8F]T=&]M
M(CX\<W1R;VYG/CP_<&AP(&5C:&\@)&AE861E<B`_/CPO<W1R;VYG/CP_<&AP
M"B`@("`@("`@:68@*"%E;7!T>2@D97)R;W(I*2!["C\^/&)R("\^/'-P86X@
M8VQA<W,](F9O<FTM97)R;W(B/CP_<&AP(&5C:&\@)&5R<F]R(#\^/"]S<&%N
M/CP_<&AP"B`@("`@("`@?0H_/CPO=&0^/"]T<CX*/#]P:'`*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R1&5S8W)I<'1I;VXH)'1E>'0I"B`@("!["C\^
M/'1R/CQT9"!W:61T:#TB,3`P)2(@8V]L<W!A;CTB/#]P:'`@96-H;R`D=&AI
M<RT^7V-O;',@/SXB/CQP('-T>6QE/2)P861D:6YG.CAP>"(^/#]P:'`@96-H
M;R`D=&5X="`_/CPO<#X\+W1D/CPO='(^"CP_<&AP"B`@("!]"@H@("`@9G5N
M8W1I;VX@7W)E;F1E<E-P86-E<B@I"B`@("!["C\^/'1R/CQT9"!C;VQS<&%N
M/2(\/W!H<"!E8VAO("1T:&ES+3Y?8V]L<R`_/B(^)FYB<W`[/"]T9#X\+W1R
M/@H\/W!H<`H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)3=6)M:70H)'-U
M8FUI="P@)')E<V5T*0H@("`@>PH_/CQD:78@8VQA<W,](F-O;G1R;VPB/@H@
M(#P_<&AP(&EF("@A:7-?87)R87DH)'-U8FUI="DI("1S=6)M:70@/2!A<G)A
M>2@D<W5B;6ET*3L@9F]R96%C:"`H)'-U8FUI="!A<R`D<W5B;6ET8G5T=&]N
M*3H@/SX*("`@(#QI;G!U="!C;&%S<STB8G5T=&]N(B!N86UE/2)S=6)M:71B
M=71T;VXB('1Y<&4](G-U8FUI="(@=F%L=64](CP_<&AP(&5C:&\@)'-U8FUI
M=&)U='1O;B`_/B(@+SX*("`\/W!H<"!E;F1F;W)E86-H.R`_/@H@(#P_<&AP
M(&EF("@A96UP='DH)')E<V5T*2DZ(#\^"B`@("`\:6YP=70@8VQA<W,](F)U
M='1O;B(@;F%M93TB<F5S971B=71T;VXB('1Y<&4](G)E<V5T(B!V86QU93TB
M/#]P:'`@96-H;R`D<F5S970@/SXB("\^"B`@/#]P:'`@96YD:68[(#\^"CPO
M9&EV/@H\/W!H<`H@("`@?0H*("`@("\O($EM<&QE;65N=&%T:6]N('-P96-I
M9FEC<R`M+2!I;G!U="!V87)I86)L97,N"B`@("!F=6YC=&EO;B!?<F5N9&5R
M5F%R26YP=71"96=I;B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@
M("`@("`@)&UE<W-A9V4@/2`D9F]R;2T^9V5T17)R;W(H)'9A<BD["B`@("`@
M("`@)&ES=F%L:60@/2!E;7!T>2@D;65S<V%G92D["B`@("`@("`@96-H;R`B
M/'1R('9A;&EG;CU<(G1O<%PB/EQN(CL*("`@("`@("!P<FEN=&8H)R`@/'1D
M)7,@86QI9VX](G)I9VAT(CXE<R5S)7,E<SPO=&0^)R`N(")<;B(L"B`@("`@
M("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?871T<D-O;'5M;E=I9'1H*2`_("<G
M(#H@)R!W:61T:#TB)R`N("1T:&ES+3Y?871T<D-O;'5M;E=I9'1H("X@)R(G
M+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_("<G(#H@)SQS<&%N(&-L87-S
M/2)F;W)M+65R<F]R(CXG+`H@("`@("`@("`@("`@("`D=F%R+3YI<U)E<75I
M<F5D*"D@/R`G/'-P86X@8VQA<W,](F9O<FTM97)R;W(B/B<@+B`D=&AI<RT^
M7W)E<75I<F5D36%R:V5R("X@)SPO<W!A;CXF;F)S<#LG(#H@)R<L"B`@("`@
M("`@("`@("`@("1V87(M/F=E=$AU;6%N3F%M92@I+`H@("`@("`@("`@("`@
M("`D:7-V86QI9"`_("<G(#H@)SQB<B`O/B<@+B`D;65S<V%G92`N("<\+W-P
M86X^)RD["B`@("`@("`@<')I;G1F*"<@(#QT9"5S/B<L"B`@("`@("`@("`@
M("`@("@H(21V87(M/FAA<TAE;'`H*2`F)B`D9F]R;2T^:&%S2&5L<"@I*2`_
M("<@8V]L<W!A;CTB,B(G(#H@)R<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R5F%R26YP=71%;F0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@
M>PH@("`@("`@("\J($1I<W!L87D@86YY(&1E<V-R:7!T:6]N(&9O<B!T:&4@
M9FEE;&0N("HO"B`@("`@("`@:68@*"1V87(M/FAA<T1E<V-R:7!T:6]N*"DI
M('L*("`@("`@("`@("`@96-H;R`G/&)R("\^)R`N("1V87(M/F=E=$1E<V-R
M:7!T:6]N*"D["B`@("`@("`@?0H*("`@("`@("`O*B!$:7-P;&%Y(&%N>2!H
M96QP(&9O<B!T:&4@9FEE;&0N("HO"B`@("`@("`@:68@*"1V87(M/FAA<TAE
M;'`H*2D@>PH@("`@("`@("`@("!G;&]B86P@)')E9VES=')Y.PH@("`@("`@
M("`@("!I9B`H:7-S970H)')E9VES=')Y*2`F)B!I<U]A*"1R96=I<W1R>2P@
M)U)E9VES=')Y)RDI('L*("`@("`@("`@("`@("`@("1L:6YK(#T@2&5L<#HZ
M;&EN:R@D1TQ/0D%,4ULG<F5G:7-T<GDG72T^9V5T07!P*"DL("1V87(M/F=E
M=$AE;'`H*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D;&EN:R`]("<\82!H<F5F/2(C(B!O;F-L:6-K/2)A;&5R="A<)R<@+B!A
M9&1S;&%S:&5S*$!H=&UL<W!E8VEA;&-H87)S*"1V87(M/F=E=$AE;'`H*2DI
M("X@)UPG*3MR971U<FX@9F%L<V4[(CXG("X@)'1H:7,M/E]H96QP36%R:V5R
M("X@)SPO83XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@(CPO
M=&0^7&X@(#QT9"!S='EL93U<(G1E>'0M86QI9VXZ<FEG:'1<(CXD;&EN:R9N
M8G-P.R(["B`@("`@("`@?0H*("`@("`@("!E8VAO("(\+W1D/EQN/"]T<CY<
M;B(["B`@("!]"@H@("`@+R\@26UP;&5M96YT871I;VX@<W!E8VEF:6-S("TM
M(&1I<W!L87D@=F%R:6%B;&5S+@H@("`@9G5N8W1I;VX@7W)E;F1E<E9A<D1I
M<W!L87E"96=I;B@F)&9O<FTL("8D=F%R+"`F)'9A<G,I"B`@("!["B`@("`@
M("`@)&UE<W-A9V4@/2`D9F]R;2T^9V5T17)R;W(H)'9A<BD["B`@("`@("`@
M)&ES=F%L:60@/2!E;7!T>2@D;65S<V%G92D["B`@("`@("`@96-H;R`B/'1R
M('9A;&EG;CU<(G1O<%PB/EQN(CL*("`@("`@("!P<FEN=&8H)R`@/'1D)7,@
M86QI9VX](G)I9VAT(CXE<SQS=')O;F<^)7,\+W-T<F]N9SXE<SPO=&0^)R`N
M(")<;B(L"B`@("`@("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?871T<D-O;'5M
M;E=I9'1H*2`_("<G(#H@)R!W:61T:#TB)R`N("1T:&ES+3Y?871T<D-O;'5M
M;E=I9'1H("X@)R(G+`H@("`@("`@("`@("`@("`D:7-V86QI9"`_("<G(#H@
M)SQS<&%N(&-L87-S/2)F;W)M+65R<F]R(CXG+`H@("`@("`@("`@("`@("`D
M=F%R+3YG971(=6UA;DYA;64H*2P*("`@("`@("`@("`@("`@)&ES=F%L:60@
M/R`G)R`Z("<\8G(@+SXG("X@)&UE<W-A9V4@+B`G/"]S<&%N/B<I.PH@("`@
M("`@(&5C:&\@)R`@/'1D/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E9A<D1I<W!L87E%;F0H)B1F;W)M+"`F)'9A<BP@)B1V87)S*0H@("`@>PH@
M("`@("`@(&5C:&\@(CPO=&0^7&X\+W1R/EQN(CL*("`@('T*"B`@("!F=6YC
M=&EO;B!?<V5C=&EO;DAE861E<B@D=&ET;&4L("1E>'1R82`]("<G*0H@("`@
M>PH@("`@("`@(&EF("AS=')L96XH)'1I=&QE*2D@>PH@("`@("`@("`@("!E
M8VAO("<\9&EV(&-L87-S/2)H96%D97(B/B<["B`@("`@("`@("`@(&EF("@A
M96UP='DH)&5X=')A*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G/'-P86X@
M<W1Y;&4](F9L;V%T.G)I9VAT(CXG("X@)&5X=')A("X@)SPO<W!A;CXG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@)'1H:7,M/E]E;F-O9&54
M:71L92`_(&AT;6QS<&5C:6%L8VAA<G,H)'1I=&QE*2`Z("1T:71L93L*("`@
M("`@("`@("`@96-H;R`G/"]D:78^)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D
M95]&;W)M7U)E;F1E<F5R(&EN<W1A;F-E(&)A<V5D(&]N"B`@("`@*B`D<F5N
M9&5R97(N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1R96YD97)E<B`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@2&]R9&5?1F]R;5]296YD97)E<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@=&\@<F5T=7)N
M+B!4:&4@8V]D92!I<R!D>6YA;6EC86QL>0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@:6YC;'5D960N($EF("1R96YD97)E<B!I<R!A;B!A<G)A
M>2P@=&AE;B!W92!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!L;V]K(&EN("1R96YD97)E<ELP72]L:6(O1F]R;2]296YD97)E<B\@9F]R
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<W5B8VQA<W,@
M:6UP;&5M96YT871I;VX@;F%M960@)')E;F1E<F5R6S%=+G!H<"X*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US("`@($$@:&%S:"!C;VYT86EN:6YG(&%N
M>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@80H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R;2!M:6=H="!N965D+@H@("`@("H*("`@("`J
M($!R971U<FX@2&]R9&5?1F]R;5]296YD97)E<B`@5&AE(&-O;F-R971E($AO
M<F1E7T9O<FU?4F5N9&5R97(@<F5F97)E;F-E+`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O<B!F86QS92!O;B!A;B!E<G)O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)')E;F1E<F5R+"`D<&%R86US
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)')E;F1E<F5R
M*2D@>PH@("`@("`@("`@("`D87!P(#T@)')E;F1E<F5R6S!=.PH@("`@("`@
M("`@("`D<F5N9&5R97(@/2`D<F5N9&5R97);,5T["B`@("`@("`@?0H*("`@
M("`@("`O*B!2971U<FX@82!B87-E($AO<F1E7T9O<FU?4F5N9&5R97(@;V)J
M96-T(&EF(&YO(&1R:79E<B!I<PH@("`@("`@("`J('-P96-I9FEE9"X@*B\*
M("`@("`@("`D<F5N9&5R97(@/2!B87-E;F%M92@D<F5N9&5R97(I.PH@("`@
M("`@(&EF("AE;7!T>2@D<F5N9&5R97(I('Q\("AS=')C;7`H)')E;F1E<F5R
M+"`G;F]N92<I(#T](#`I*2!["B`@("`@("`@("`@("1F;W)M<F5N9&5R97(@
M/2`F;F5W($AO<F1E7T9O<FU?4F5N9&5R97(H)'!A<F%M<RD["B`@("`@("`@
M("`@(')E='5R;B`D9F]R;7)E;F1E<F5R.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D87!P*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@
M)$=,3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N
M("<O;&EB+T9O<FTO4F5N9&5R97(O)R`N("1R96YD97)E<B`N("<N<&AP)SL*
M("`@("`@("!](&5L<V5I9B`H0&9I;&5?97AI<W1S*&1I<FYA;64H7U]&24Q%
M7U\I("X@)R]296YD97)E<B\G("X@)')E;F1E<F5R("X@)RYP:'`G*2D@>PH@
M("`@("`@("`@("!I;F-L=61E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+U)E;F1E<F5R+R<@+B`D<F5N9&5R97(@+B`G+G!H<"<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@0&EN8VQU9&5?;VYC92`G2&]R9&4O1F]R;2]2
M96YD97)E<B\G("X@)')E;F1E<F5R("X@)RYP:'`G.PH@("`@("`@('T*("`@
M("`@("`D8VQA<W,@/2`G2&]R9&5?1F]R;5]296YD97)E<E\G("X@)')E;F1E
M<F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@
M("`@("`@("`D9F]R;7)E;F1E<F5R(#T@)FYE=R`D8VQA<W,H)'!A<F%M<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9O<FUR96YD97)E<B`]
M(%!%05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C
M;&%S<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1F;W)M<F5N9&5R97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!='1E
M;7!T<R!T;R!R971U<FX@82!R969E<F5N8V4@=&\@82!C;VYC<F5T92!(;W)D
M95]&;W)M7U)E;F1E<F5R"B`@("`@*B!I;G-T86YC92!B87-E9"!O;B`D<F5N
M9&5R97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@:68@
M;F\*("`@("`J($AO<F1E7T9O<FU?4F5N9&5R97(@:6YS=&%N8V4@=VET:"!T
M:&4@<V%M92!P87)A;65T97)S(&-U<G)E;G1L>2!E>&ES=',N"B`@("`@*@H@
M("`@("H@5&AI<R!S:&]U;&0@8F4@=7-E9"!I9B!M=6QT:7!L92!T>7!E<R!O
M9B!F;W)M(')E;F1E<F5R<R`H86YD+`H@("`@("H@=&AU<RP@;75L=&EP;&4@
M2&]R9&5?1F]R;5]296YD97)E<B!I;G-T86YC97,I(&%R92!R97%U:7)E9"X*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z
M("1V87(@/2`F2&]R9&5?1F]R;5]296YD97)E<CHZ<VEN9VQE=&]N*"D*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E;F1E<F5R("!4:&4@='EP92!O
M9B!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E<F5R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!S=6)C;&%S<R!T;R!R971U<FXN(%1H92!C;V1E
M(&ES(&1Y;F%M:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!I;F-L=61E9"X@268@)')E;F1E<F5R(&ES(&%N(&%R<F%Y+"!T:&5N('=E
M('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&QO;VL@:6X@
M)')E;F1E<F5R6S!=+VQI8B]&;W)M+U)E;F1E<F5R+R!F;W(@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!S=6)C;&%S<R!I;7!L96UE;G1A
M=&EO;B!N86UE9"`D<F5N9&5R97);,5TN<&AP+@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!A9&1I=&EO;F%L
M(&-O;F9I9W5R871I;VX@80H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&9O<FT@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N($AO<F1E
M7T9O<FU?4F5N9&5R97(@(%1H92!C;VYC<F5T92!(;W)D95]&;W)M7U)E;F1E
M<F5R(')E9F5R96YC92P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;W(@9F%L<V4@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9S:6YG;&5T;VXH)')E;F1E<F5R+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E<SL*("`@("`@("!I9B`H(6ES
M<V5T*"1I;G-T86YC97,I*2!["B`@("`@("`@("`@("1I;G-T86YC97,@/2!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)'-I9VYA='5R92`]('-E<FEA
M;&EZ92AA<G)A>2@D<F5N9&5R97(L("1P87)A;7,I*3L*("`@("`@("!I9B`H
M(6ES<V5T*"1I;G-T86YC97-;)'-I9VYA='5R95TI*2!["B`@("`@("`@("`@
M("1I;G-T86YC97-;)'-I9VYA='5R95T@/2`F2&]R9&5?1F]R;5]296YD97)E
M<CHZ9F%C=&]R>2@D<F5N9&5R97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7V5N86)L92YP:'``
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S-#$U(#$P-3$U-#,T,3,W(#`R-C`Q,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@2&]R9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N86Q?96YA8FQE(&ES
M(&$@2&]R9&5?1F]R;5]!8W1I;VX@=&AA=`H@*B!E;F%B;&5S(&]R(&1I<V%B
M;&5S(&%N(&5L96UE;G0@8F%S960@;VX@=&AE('9A;'5E(&]F(&%N;W1H97(@
M96QE;65N=`H@*@H@*B!&;W)M870@;V8@=&AE("1P87)A;7,@<&%S<V5D('1O
M('1H92!C;VYS=')U8W1O<CH*("H@/'!R93X*("H@("1P87)A;7,@/2!A<G)A
M>2@*("H@("`@("`G=&%R9V5T)R`@/3X@)UMN86UE(&]F(&5L96UE;G0@=&AI
M<R!I<R!C;VYD:71I;VYA;"!O;ETG+`H@*B`@("`@("=E;F%B;&5D)R`]/B`G
M=')U92<@?"`G9F%L<V4G+`H@*B`@("`@("=V86QU97,G("`]/B!A<G)A>2A;
M=&%R9V5T('9A;'5E<R!T;R!C:&5C:UTI"B`J("`I.PH@*B`\+W!R93X*("H*
M("H@4V\@)'!A<F%M<R`](&%R<F%Y*"=F;V\G+"`G=')U92<L(&%R<F%Y*#$L
M(#(I*2!W:6QL(&5N86)L92!T:&4@9FEE;&0@=&AI<PH@*B!A8W1I;VX@:7,@
M871T86-H960@=&\@:68@=&AE('9A;'5E(&]F("=F;V\G(&ES(#$@;W(@,BP@
M86YD(&1I<V%B;&4@:70*("H@;W1H97)W:7-E+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N+V-O;F1I=&EO;F%L7V5N86)L92YP
M:'`L=B`Q+C0N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X.C$W(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UA='0@2WEN87-T;VX@/&UA='1`
M:WEN>"YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T($MY
M;F%S=&]N(#QM871T0&MY;G@N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M
M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]C;VYD:71I;VYA;%]E;F%B
M;&4@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R("1?=')I
M9V=E<B`](&%R<F%Y*"=O;FQO860G*3L*"B`@("!F=6YC=&EO;B!G971!8W1I
M;VY38W)I<'0H)B1F;W)M+"`D<F5N9&5R97(L("1V87)N86UE*0H@("`@>PH@
M("`@("`@($AO<F1E.CIA9&138W)I<'1&:6QE*"=F;W)M7VAE;'!E<G,N:G,G
M+"`G:&]R9&4G+"!T<G5E*3L*"B`@("`@("`@)&9O<FU?;F%M92`]("1F;W)M
M+3YG971.86UE*"D["B`@("`@("`@)'1A<F=E="`]("1T:&ES+3Y?<&%R86US
M6R=T87)G970G73L*("`@("`@("`D96YA8FQE9"`]("1T:&ES+3Y?<&%R86US
M6R=E;F%B;&5D)UT["B`@("`@("`@:68@*"%I<U]S=')I;F<H)&5N86)L960I
M*2!["B`@("`@("`@("`@("1E;F%B;&5D(#T@*"1E;F%B;&5D*2`_("=T<G5E
M)R`Z("=F86QS92<["B`@("`@("`@?0H@("`@("`@("1V86QS(#T@)'1H:7,M
M/E]P87)A;7-;)W9A;'5E<R==.PH@("`@("`@("1V86QS(#T@*&ES7V%R<F%Y
M*"1V86QS*2D@/R`D=F%L<R`Z(&%R<F%Y*"1V86QS*3L*("`@("`@("`D87)G
M<R`]("(G)'9A<FYA;64G+"`D96YA8FQE9"P@)R(@+B!I;7!L;V1E*"(G+"<B
M+"`D=F%L<RD@+B`B)R(["@H@("`@("`@(')E='5R;B`B:68@*&%D9$5V96YT
M*&1O8W5M96YT+B1F;W)M7VYA;64N)'1A<F=E="P@)V]N8VAA;F=E)RP@7")C
M:&5C:T5N86)L960H=&AI<RP@)&%R9W,I.UPB*2D@>R`B"B`@("`@("`@("`@
M("X@(B`@8VAE8VM%;F%B;&5D*&1O8W5M96YT+B1F;W)M7VYA;64N)'9A<FYA
M;64L("1A<F=S*3L@(@H@("`@("`@("`@("`N("=].R<["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](
M;W)D92]&;W)M+T%C=&EO;B]R96QO860N<&AP````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,34W,R`Q,#4Q-30S-#$S-R`P,C,T-3(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M($AO<F1E7T9O<FU?06-T:6]N7W)E;&]A9"!I<R!A($AO<F1E7T9O<FT@06-T
M:6]N('1H870@<F5L;V%D<R!T:&4*("H@9F]R;2!W:71H('1H92!C=7)R96YT
M("AN;W0@=&AE(&]R:6=I;F%L*2!V86QU92!A9G1E<B!T:&4@9F]R;2!E;&5M
M96YT"B`J('1H870@=&AE(&%C=&EO;B!I<R!A='1A8VAE9"!T;R!I<R!M;V1I
M9FEE9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&;W)M+T%C=&EO
M;B]R96QO860N<&AP+'8@,2XW+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*86X@4V-H;F5I
M9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO
M<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@
M2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]!8W1I;VY?<F5L;V%D
M(&5X=&5N9',@2&]R9&5?1F]R;5]!8W1I;VX@>PH*("`@('9A<B`D7W1R:6=G
M97(@/2!A<G)A>2@G;VYC:&%N9V4G*3L*"B`@("!F=6YC=&EO;B!G971!8W1I
M;VY38W)I<'0H)&9O<FTL("1R96YD97)E<BP@)'9A<FYA;64I"B`@("!["B`@
M("`@("`@<F5T=7)N("=I9B`H=&AI<RYV86QU92D@>R!D;V-U;65N="XG("X@
M)&9O<FTM/F=E=$YA;64H*2`N("<N9F]R;6YA;64N=F%L=64]7"=<)SLG("X*
M("`@("`@("`@("`@)V1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I("X@
M)RYS=6)M:70H*2!])SL*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]&;W)M+T%C=&EO;B]C;VYD:71I;VYA;%]S971V86QU92YP
M:'`````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P-3`Q,"`Q,#4Q-30S-#$S-R`P,C8T,#4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($AO<F1E7T9O<FU?06-T:6]N7V-O;F1I=&EO;F%L7W-E='9A;'5E
M(&ES(&$@2&]R9&5?1F]R;5]!8W1I;VX@=&AA=`H@*B!S971S('1H92!V86QU
M92!O9B!O;F4@2&]R9&5?1F]R;2!V87)I86)L92!B87-E9"!O;B!T:&4@=F%L
M=64@;V8@=&AE"B`J('9A<FEA8FQE('1H92!A8W1I;VX@:7,@871T86-H960@
M=&\N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9O<FTO1F]R;2]!8W1I;VXO
M8V]N9&ET:6]N86Q?<V5T=F%L=64N<&AP+'8@,2XQ.2XQ,"XU(#(P,#8O,#$O
M,#$@,C$Z,C@Z,3<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P
M,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA<W,@2&]R
M9&5?1F]R;5]!8W1I;VY?8V]N9&ET:6]N86Q?<V5T=F%L=64@97AT96YD<R!(
M;W)D95]&;W)M7T%C=&EO;B!["@H@("`@+RHJ"B`@("`@*B!7:&EC:"!*4R!E
M=F5N=',@<VAO=6QD('1R:6=G97(@=&AI<R!A8W1I;VX_"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]T<FEG9V5R(#T@87)R
M87DH)V]N8VAA;F=E)RP@)V]N;&]A9"<I.PH*("`@(&9U;F-T:6]N(&=E=$%C
M=&EO;E-C<FEP="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@)VUA<"A<)R<@+B`D<F5N9&5R97(M/E]G96Y)1"@D
M=F%R;F%M92P@9F%L<V4I("X@(B<L("<B("X@)')E;F1E<F5R+3Y?9V5N240H
M)'1H:7,M/F=E=%1A<F=E="@I+"!F86QS92D@+B`G7"<I.R<["B`@("!]"@H@
M("`@9G5N8W1I;VX@<V5T5F%L=65S*"8D=F%R<RP@)'-O=7)C959A;"P@)&%R
M<F%Y5F%L(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&UA<"`]("1T:&ES+3Y?
M<&%R86US6R=M87`G73L*("`@("`@("`D=&%R9V5T(#T@)'1H:7,M/F=E=%1A
M<F=E="@I.PH*("`@("`@("!I9B`H)&%R<F%Y5F%L*2!["B`@("`@("`@("`@
M("1I(#T@,#L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;W5R8V5686PI
M*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D<V]U<F-E5F%L(&%S("1V
M86PI('L*("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1M87!;)'9A
M;%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1V87)S+3YS970H)'1A
M<F=E="P@)&UA<%LD=F%L72P@)&DI.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"%E;7!T>2@D;6%P6R1S;W5R8V5686Q=*2D@>PH@("`@("`@("`@("`@("`@
M)'9A<G,M/G-E="@D=&%R9V5T+"`D;6%P6R1S;W5R8V5686Q=*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$IA
M=F%38W)I<'0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<')I;G1*879A4V-R
M:7!T4W1A<G0H*3L*("`@("`@("`D;6%P(#T@)'1H:7,M/E]P87)A;7-;)VUA
M<"==.PH_/@H*=F%R(%]M87`@/2!N97<@07)R87DH/#]P:'`*)&D@/2`P.PIF
M;W)E86-H("@D;6%P(&%S("1V86PI('L*("`@(&EF("@D:2`^(#`I('L*("`@
M("`@("!E8VAO("<L("<["B`@("!]"B`@("!E8VAO("<B)R`N("1V86P@+B`G
M(B<["B`@("`D:2LK.PI]/SXI.PH*9G5N8W1I;VX@;6%P*'-O=7)C94ED+"!T
M87)G971)9"D*>PH@("`@=F%R(&YE=W9A;#L*("`@('9A<B!S;W5R8V4@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"AS;W5R8V5)9"D["B`@("!V87(@96QE
M;65N="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E=$ED*3L*("`@
M(&EF("AE;&5M96YT*2!["B`@("`@("`@:68@*%]M87!;<V]U<F-E+G-E;&5C
M=&5D26YD97A=*2!["B`@("`@("`@("`@(&YE=W9A;"`](%]M87!;<V]U<F-E
M+G-E;&5C=&5D26YD97A=.PH@("`@("`@("`@("!R97!L86-E(#T@=')U93L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!N97=V86P@/2`G)SL*("`@
M("`@("`@("`@<F5P;&%C92`](&9A;'-E.PH@("`@("`@("`@("!F;W(@*&D@
M/2`P.R!I(#P@7VUA<"YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("`@("`@
M:68@*&5L96UE;G0N=F%L=64@/3T@7VUA<%MI72D@>PH@("`@("`@("`@("`@
M("`@("`@(')E<&QA8V4@/2!T<G5E.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H<F5P;&%C92D@>PH@("`@("`@("`@("!E;&5M96YT
M+G9A;'5E(#T@;F5W=F%L.PH@("`@("`@('T*("`@('T*?3P_<&AP"B`@("`@
M("`@)'1H:7,M/E]P<FEN=$IA=F%38W)I<'1%;F0H*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO
M06-T:6]N+W-U8FUI="YP:'``````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,S<W(#$P-3$U-#,T,3,W(#`R,S4Q,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@2&]R9&5?1F]R
M;5]!8W1I;VY?<W5B;6ET(&ES(&$@2&]R9&5?1F]R;2!!8W1I;VX@=&AA="!S
M=6)M:71S('1H90H@*B!F;W)M(&%F=&5R('1H92!F;W)M(&5L96UE;G0@=&AA
M="!T:&4@86-T:6]N(&ES(&%T=&%C:&5D('1O(&ES"B`J(&UO9&EF:65D+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N+W-U8FUI
M="YP:'`L=B`Q+C$P+C$R+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G
M92!(;W)D95]&;W)M"B`J+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]S=6)M
M:70@97AT96YD<R!(;W)D95]&;W)M7T%C=&EO;B!["@H@("`@=F%R("1?=')I
M9V=E<B`](&%R<F%Y*"=O;F-H86YG92<I.PH*("`@(&9U;F-T:6]N(&=E=$%C
M=&EO;E-C<FEP="@D9F]R;2P@)')E;F1E<F5R+"`D=F%R;F%M92D*("`@('L*
M("`@("`@("!R971U<FX@)V1O8W5M96YT+B<@+B`D9F]R;2T^9V5T3F%M92@I
M("X@)RYS=6)M:70H*2<["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E
M+T9O<FTO06-T:6]N+W5P9&%T969I96QD+G!H<```````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`S-S`Q(#$P-3$U-#,T,3,W(#`R-#0V-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@2&]R
M9&5?1F]R;5]!8W1I;VY?=7!D871E9FEE;&0@:7,@82!(;W)D95]&;W)M7T%C
M=&EO;B!T:&%T('5P9&%T97,*("H@=&AE('9A;'5E(&]F(&]N92!(;W)D95]&
M;W)M('9A<FEA8FQE(&%S('1H92!V87)I86)L92!T:&4@86-T:6]N(&ES"B`J
M(&%T=&%C:&5D('1O(&ES('5P9&%T960N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T9O<FTO1F]R;2]!8W1I;VXO=7!D871E9FEE;&0N<&AP+'8@,2XU+C$R
M+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J
M+PIC;&%S<R!(;W)D95]&;W)M7T%C=&EO;E]U<&1A=&5F:65L9"!E>'1E;F1S
M($AO<F1E7T9O<FU?06-T:6]N('L*"B`@("!V87(@)%]T<FEG9V5R(#T@87)R
M87DH)V]N8VAA;F=E)RP@)V]N;&]A9"<L("=O;FME>75P)RD["@H@("`@9G5N
M8W1I;VX@9V5T06-T:6]N4V-R:7!T*"8D9F]R;2P@)B1R96YD97)E<BP@)'9A
M<FYA;64I"B`@("!["B`@("`@("`@<F5T=7)N("=U<&1A=&5&:65L9"<@+B`D
M=&AI<RT^:60H*2`N("<H*3LG.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%9A
M;'5E<R@F)'9A<G,L("1S;W5R8V5686PL("1A<G)A>59A;"`](&9A;'-E*0H@
M("`@>PH@("`@?0H*("`@(&9U;F-T:6]N('!R:6YT2F%V85-C<FEP="@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]P<FEN=$IA=F%38W)I<'13=&%R="@I.PH@
M("`@("`@("1P:65C97,@/2!E>'!L;V1E*"<E<R<L("1T:&ES+3Y?<&%R86US
M6R=F;W)M870G72D["B`@("`@("`@)&9I96QD<R`]("1T:&ES+3Y?<&%R86US
M6R=F:65L9',G73L*("`@("`@("`D=F%L7V9I<G-T(#T@*'-U8G-T<B@D=&AI
M<RT^7W!A<F%M<ULG9F]R;6%T)UTL(#`L(#(I(#T]("<E<R<I.PH@("`@("`@
M(&EF("@D=F%L7V9I<G-T*2!["B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1P
M:65C97,I.PH@("`@("`@('T*("`@("`@("!I9B`H<W5B<W1R*"1T:&ES+3Y?
M<&%R86US6R=F;W)M870G72P@+3(I(#T]("<E<R<I('L*("`@("`@("`@("`@
M87)R87E?<&]P*"1P:65C97,I.PH@("`@("`@('T*"B`@("`@("`@)&%R9W,@
M/2!A<G)A>2@I.PH@("`@("`@(&EF("@D=F%L7V9I<G-T*2!["B`@("`@("`@
M("`@("1A<F=S6UT@/2`B9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)R(@+B!A
M<G)A>5]S:&EF="@D9FEE;&1S*2`N("(G*2YV86QU92(["B`@("`@("`@?0H@
M("`@("`@('=H:6QE("AC;W5N="@D<&EE8V5S*2D@>PH@("`@("`@("`@("`D
M87)G<UM=(#T@(B<B("X@87)R87E?<VAI9G0H)'!I96-E<RD@+B`B)R(["B`@
M("`@("`@("`@("1A<F=S6UT@/2`B9&]C=6UE;G0N9V5T16QE;65N=$)Y260H
M)R(@+B!A<G)A>5]S:&EF="@D9FEE;&1S*2`N("(G*2YV86QU92(["B`@("`@
M("`@?0H_/@HO+R!5<&1A=&5R(&9O<B`\/W!H<"!E8VAO("1T:&ES+3YG9714
M87)G970H*2`_/BX*9G5N8W1I;VX@=7!D871E1FEE;&0\/W!H<"!E8VAO("1T
M:&ES+3YI9"@I(#\^*"D*>PH@("`@=F%R('1A<F=E="`](&1O8W5M96YT+F=E
M=$5L96UE;G1">4ED*"<\/W!H<"!E8VAO("1T:&ES+3YG971487)G970H*2`_
M/B<I.PH@("`@:68@*'1A<F=E="D@>PH@("`@("`@('1A<F=E="YV86QU92`]
M(#P_<&AP(&5C:&\@:6UP;&]D92@G("L@)RP@<W1R7W)E<&QA8V4H(EQN(BP@
M(EQ<;B(L("1A<F=S*2D@/SX["B`@("!]"GT\/W!H<`H@("`@("`@("1T:&ES
M+3Y?<')I;G1*879A4V-R:7!T16YD*"D["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]&;W)M
M+T%C=&EO;B]S=6U?9FEE;&1S+G!H<```````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C<V,"`Q,#4Q-30S-#$S-R`P,C0S,S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7T9O
M<FU?06-T:6]N7W-U;5]F:65L9',@:7,@82!(;W)D95]&;W)M7T%C=&EO;B!T
M:&%T('-E=',@=&AE('1A<F=E=`H@*B!F:65L9"!T;R!T:&4@<W5M(&]F(&]N
M92!O<B!M;W)E(&]T:&5R(&YU;65R:6,@9FEE;&1S+@H@*@H@*B!4:&4@<&%R
M86US(&%R<F%Y('-H;W5L9"!C;VYT86EN('1H92!N86UE<R!O9B!T:&4@9FEE
M;&1S('=H:6-H('=I;&P@8F4*("H@<W5M;65D+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]&;W)M+T9O<FTO06-T:6]N+W-U;5]F:65L9',N<&AP+'8@,2XU
M+C$P+C0@,C`P-B\P,2\P,2`R,3HR.#HQ-R!J86X@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!-871T($MY;F%S=&]N(#QM871T0&MY;G@N;W)G
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36%T="!+>6YA<W1O;B`\
M;6%T=$!K>6YX+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*8VQA
M<W,@2&]R9&5?1F]R;5]!8W1I;VY?<W5M7V9I96QD<R!E>'1E;F1S($AO<F1E
M7T9O<FU?06-T:6]N('L*"B`@("!V87(@)%]T<FEG9V5R(#T@87)R87DH)V]N
M;&]A9"<I.PH*("`@(&9U;F-T:6]N(&=E=$%C=&EO;E-C<FEP="@F)&9O<FTL
M("1R96YD97)E<BP@)'9A<FYA;64I"B`@("!["B`@("`@("`@2&]R9&4Z.F%D
M9%-C<FEP=$9I;&4H)V9O<FU?:&5L<&5R<RYJ<R<L("=H;W)D92<L('1R=64I
M.PH*("`@("`@("`D9F]R;5]N86UE(#T@)&9O<FTM/F=E=$YA;64H*3L*("`@
M("`@("`D9FEE;&1S(#T@(B<B("X@:6UP;&]D92@B)RPG(BP@)'1H:7,M/E]P
M87)A;7,I("X@(B<B.PH@("`@("`@("1J<R`](&%R<F%Y*"D["B`@("`@("`@
M)&IS6UT@/2!S<')I;G1F*"=D;V-U;65N="YF;W)M<UM<)R5S7"==+F5L96UE
M;G1S6UPG)7-<)UTN9&ES86)L960@/2!T<G5E.R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("1F;W)M7VYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<R!A
M<R`D9FEE;&0I('L*("`@("`@("`@("`@)&IS6UT@/2!S<')I;G1F*")A9&1%
M=F5N="AD;V-U;65N="YF;W)M<ULG)3%<)',G72YE;&5M96YT<ULG)3)<)',G
M72P@7")O;F-H86YG95PB+"!<(G-U;49I96QD<RAD;V-U;65N="YF;W)M<ULG
M)3%<)',G72P@)R4S7"1S)RP@)31<)',I.UPB*3LB+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<FU?;F%M92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F:65L9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1V87)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I96QD
M<RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@:6UP;&]D92@B7&XB+"`D
M:G,I.PH@("`@?0H*?0H`````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T9O<FTO5'EP92]T86)L97-E="YP:'``````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C,R(#$P-3$U-#,T,3,W(#`R
M,S4Q,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<["@HO*BH*
M("H@)$AO<F1E.B!F<F%M97=O<FLO1F]R;2]&;W)M+U1Y<&4O=&%B;&5S970N
M<&AP+'8@,2XS+C(N,2`R,#`U+S$P+S$X(#$Q.C`Q.C`X(&IA;B!%>'`@)`H@
M*@H@*B!`<&%C:V%G92!(;W)D95]&;W)M"B`J($!S:6YC92`@($AO<F1E(#,N
M,0H@*B\*8VQA<W,@2&]R9&5?1F]R;5]4>7!E7W1A8FQE<V5T(&5X=&5N9',@
M2&]R9&5?1F]R;5]4>7!E('L*"B`@("!V87(@)%]V86QU97,["B`@("!V87(@
M)%]H96%D97(["@H@("`@9G5N8W1I;VX@:6YI="@D=F%L=65S+"`D:&5A9&5R
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F%L=65S(#T@)'9A;'5E<SL*("`@
M("`@("`D=&AI<RT^7VAE861E<B`]("1H96%D97(["B`@("!]"@H@("`@9G5N
M8W1I;VX@:7-686QI9"@F)'9A<BP@)B1V87)S+"`D=F%L=64L("8D;65S<V%G
M92D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]V86QU97,I(#T]
M(#`@?'P@8V]U;G0H)'9A;'5E*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D=F%L=64@87,@
M)&ET96TI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W9A;'5E
M<ULD:71E;5TI*2!["B`@("`@("`@("`@("`@("`D97)R;W(@/2!T<G5E.PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"%I<W-E="@D97)R;W(I*2!["B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&UE<W-A9V4@/2!?*"))
M;G9A;&ED(&1A=&$@<W5B;6ET=&5D+B(I.PH@("`@("`@(')E='5R;B!F86QS
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971(96%D97(H*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^7VAE861E<CL*("`@('T*"B`@("!F=6YC=&EO
M;B!G971686QU97,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9A
M;'5E<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!I;F9O(&%B;W5T
M(&9I96QD('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%B;W5T*"D*("`@
M('L*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("=N86UE)R`]
M/B!?*")486)L92!3970B*2P*("`@("`@("`@("`@)W!A<F%M<R<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A<G)A>2@G;&%B96PG
M(#T^(%\H(E9A;'5E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1Y<&4G("`]/B`G<W1R:6YG;&ES="<I+`H@("`@("`@("`@("`@
M("`@)VAE861E<B<@/3X@87)R87DH)VQA8F5L)R`]/B!?*")(96%D97)S(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^
M("=S=')I;F=L:7-T)RDI+`H@("`@("`@("`@("`I.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E
M9G,O<W%L+G!H<```````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,S(Q-S,@,3`U,34T,S0Q,S<@,#(Q-S0R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G
M92!(;W)D95]0<F5F<PH@*B\*"B\J*@H@*B!014%2($1"(&QA>65R+@H@*B\*
M<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*+RHJ"B`J($AO<F1E7U-T<FEN9R!C
M;&%S<RX*("HO"G)E<75I<F5?;VYC92`G2&]R9&4O4W1R:6YG+G!H<"<["@HO
M*BH*("H@4')E9F5R96YC97,@<W1O<F%G92!I;7!L96UE;G1A=&EO;B!F;W(@
M4$A0)W,@4$5!4B!D871A8F%S90H@*B!A8G-T<F%C=&EO;B!L87EE<BX*("H*
M("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@
M(%1H92!D871A8F%S92!T>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C
M+BDN"B`J("`@)V-H87)S970G("`@5&AE(&1A=&%B87-E)W,@:6YT97)N86P@
M8VAA<G-E="X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E
M/@H@*B`@("=T86)L92<@("`@(%1H92!N86UE(&]F('1H92!P<F5F97)E;F-E
M<R!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("`@("`@("`@("`@($1%1D%5
M3%0Z("=H;W)D95]P<F5F<R<\+W!R93X*("H*("H@4F5Q=6ER960@8GD@<V]M
M92!D871A8F%S92!I;7!L96UE;G1A=&EO;G,Z/'!R93X*("H@("`G:&]S='-P
M96,G("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@
M("`G<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C
M<"<L("=U;FEX)RP@971C+BDN"B`J("`@)V1A=&%B87-E)R`@5&AE(&YA;64@
M;V8@=&AE(&1A=&%B87-E+@H@*B`@("=U<V5R;F%M92<@(%1H92!U<V5R;F%M
M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@
M("=P87-S=V]R9"<@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S
M97)N86UE)RX*("H@("`G;W!T:6]N<R<@("!!9&1I=&EO;F%L(&]P=&EO;G,@
M=&\@<&%S<R!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!O<G0G("`@("`@5&AE
M('!O<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J
M("`@)W1T>2<@("`@("`@5&AE(%1462!O;B!W:&EC:"!T;R!C;VYN96-T('1O
M('1H92!D871A8F%S92X\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R
M92!F;W(@=&AE(%!R969S('-Y<W1E;2!I<R!I;@H@*B!S8W)I<'1S+W-Q;"]H
M;W)D95]P<F5F<RYS<6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U!R969S
M+U!R969S+W-Q;"YP:'`L=B`Q+CDQ+C$P+C(P(#(P,#8O,#0O,3`@,34Z-3@Z
M,30@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@
M4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J+PIC;&%S<R!0
M<F5F<U]S<6P@97AT96YD<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@*B!(87-H
M(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H*("`@
M("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@
M9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1""B`@
M("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@0F]O;&5A;B!I
M;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E9"!T;R!T
M:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1S(&$@;F5W(%-13"!P<F5F97)E;F-E<R!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!U
M<V5R('=H;R!O=VYS('1H97-E('!R969E<F5N8V5S+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%S<W=O<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I
M=&@@)'5S97(N("A5;G5S960I"B`@("`@*B!`<&%R86T@<W1R:6YG("1S8V]P
M92`@("`@5&AE(&-U<G)E;G0@<')E9F5R96YC97,@<V-O<&4N"B`@("`@*B!`
M<&%R86T@87)R87D@)'!A<F%M<R`@("`@02!H87-H(&-O;G1A:6YI;F<@8V]N
M;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-A
M8VAI;F<@(%-H;W5L9"!C86-H:6YG(&)E('5S960_"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%!R969S7W-Q;"@D=7-E<BP@)'!A<W-W;W)D(#T@)R<L("1S8V]P
M92`]("<G+`H@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A
M>2@I+"`D8V%C:&EN9R`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M=7-E<B`]("1U<V5R.PH@("`@("`@("1T:&ES+3Y?<V-O<&4@/2`D<V-O<&4[
M"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@("1T
M:&ES+3Y?8V%C:&EN9R`]("1C86-H:6YG.PH*("`@("`@("!P87)E;G0Z.E!R
M969S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C:&%R
M<V5T('5S960@8GD@=&AE(&-O;F-R971E('!R969E<F5N8V4@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R969E<F5N8V4@
M8F%C:V5N9"=S(&-H87)S970N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-H
M87)S970H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!A<F%M<ULG
M8VAA<G-E="==.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!R97%U97-T960@<V5T(&]F('!R969E<F5N8V5S(&9R;VT@=&AE('5S97(G
M<R!D871A8F%S90H@("`@("H@96YT<GDN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P<F5F<R`@06X@87)R87D@;&ES=&EN9R!T:&4@<')E9F5R96YC
M97,@=&\@<F5T<FEE=F4N($EF"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!N;W0@<W!E8VEF:65D+"!R971R:65V92!A;&P@;V8@=&AE('!R969E<F5N
M8V5S"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!L:7-T960@:6X@=&AE
M("1P<F5F<R!H87-H+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I979E*"1P<F5F<R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@+RH@071T96UP="!T;R!P=6QL('1H92!V
M86QU97,@9G)O;2!T:&4@<V5S<VEO;B!C86-H92!F:7)S="X@*B\*("`@("`@
M("!I9B`H)'1H:7,M/F-A8VAE3&]O:W5P*"DI('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!,;V%D(&1E9F%U;'1S
M('1O(&UA:V4@<W5R92!W92!H879E(&%L;"!P<F5F97)E;F-E<RX@*B\*("`@
M("`@("!P87)E;G0Z.G)E=')I979E*"D["@H@("`@("`@("\J($UA:V4@<W5R
M92!W92=R92!C;VYN96-T960N("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T
M*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@
M("`@)'%U97)Y(#T@)U-%3$5#5"!P<F5F7W-C;W!E+"!P<F5F7VYA;64L('!R
M969?=F%L=64@1E)/32`G.PH@("`@("`@("1Q=65R>2`N/2`D=&AI<RT^7W!A
M<F%M<ULG=&%B;&4G72`N("<@)SL*("`@("`@("`D<75E<GD@+CT@)U=(15)%
M('!R969?=6ED(#T@/R<["B`@("`@("`@)'%U97)Y("X]("<@04Y$("AP<F5F
M7W-C;W!E(#T@/R<["B`@("`@("`@)'%U97)Y("X]("(@3U(@<')E9E]S8V]P
M92`]("=H;W)D92<I($]21$52($)9('!R969?<V-O<&4B.PH*("`@("`@("`D
M=F%L=65S(#T@87)R87DH)'1H:7,M/E]U<V5R+"`D=&AI<RT^7W-C;W!E*3L*
M"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y
M(&)Y(%!R969S7W-Q;#HZ<F5T<FEE=F4H*3H@)7,G+"`D<75E<GDI+"!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@
M17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@(&EF("AI
M<W-E="@D<F5S=6QT*2`F)B`A:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1R;W<@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&
M151#2$U/1$5?05-33T,I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F]W+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D<F]W+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J(%-E="!T:&4@<F5Q=65S=&5D('9A;'5E<R!I;B!T:&4@)'1H
M:7,M/E]P<F5F<R!H87-H"B`@("`@("`@("`@("`J(&)A<V5D(&]N('1H92!C
M;VYT96YT<R!O9B!T:&4@4U%,(')E<W5L="X*("`@("`@("`@("`@("H*("`@
M("`@("`@("`@("H@3F]T92!T:&%T(%!R969S.CIS971686QU92@I(&-A;B=T
M(&)E('5S960@:&5R92!B96-A=7-E"B`@("`@("`@("`@("`J(&]F('1H92!C
M:&5C:R!F;W(@=&AE(")C:&%N9V5A8FQE(B!B:70N(%=E('=A;G0@=&\*("`@
M("`@("`@("`@("H@;W9E<G)I9&4@=&AA="!C:&5C:R!W:&5N('!O<'5L871I
M;F<@=&AE("1T:&ES+3Y?<')E9G,*("`@("`@("`@("`@("H@:&%S:"!F<F]M
M('1H92!344P@<V5R=F5R+B`J+PH@("`@("`@("`@("!W:&EL92`H)')O=R`F
M)B`A:7-?82@D<F]W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`D;F%M92`]('1R:6TH)')O=ULG<')E9E]N86UE)UTI.PH@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<')E9G-;)&YA;65=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T5F%L=64H)&YA;64L("1R;W=;
M)W!R969?=F%L=64G72P@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T1&ER='DH)&YA;64L(&9A;'-E*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D
M9"@D;F%M92P@)')O=ULG<')E9E]V86QU92==+"`D<F]W6R=P<F5F7W-C;W!E
M)UT@/3T@)VAO<F1E)R`_(%]04D5&7U-(05)%1"`Z(#`I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)')O=R`]("1R97-U;'0M/F9E=&-H
M4F]W*$1"7T9%5$-(34]$15]!4U-/0RD["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\J($-A;&P@:&]O:W,N("HO"B`@("`@("`@("`@("1T:&ES+3Y?
M8V%L;$AO;VMS*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@2&]R
M9&4Z.FQO9TUE<W-A9V4H)TYO('!R969E<F5N8V5S('=E<F4@<F5T<FEE=F5D
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`O*B!5<&1A=&4@
M=&AE('-E<W-I;VX@8V%C:&4N("HO"B`@("`@("`@)'1H:7,M/F-A8VAE57!D
M871E*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W1O<F5S('!R969E<F5N8V5S('1O(%-13"!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<W1O<F4H*0H@("`@>PH@("`@("`@("\J($-H96-K(&9O<B!A;GD@
M(F1I<G1Y(B!P<F5F97)E;F-E<RX@268@;F\@(F1I<G1Y(@H@("`@("`@("`J
M('!R969E<F5N8V5S(&%R92!F;W5N9"P@=&AE<F4G<R!N;R!N965D('1O('5P
M9&%T92!T:&4@4U%,"B`@("`@("`@("H@<V5R=F5R+B!%>&ET('-U8V-E<W-F
M=6QL>2X@*B\*("`@("`@("`D9&ER='E?<')E9G,@/2`D=&AI<RT^7V1I<G1Y
M4')E9G,H*3L*("`@("`@("!I9B`H(6-O=6YT*"1D:7)T>5]P<F5F<RDI('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O
M*B!-86ME('-U<F4@=V4G<F4@8V]N;F5C=&5D+B`J+PH@("`@("`@("1T:&ES
M+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!,;V]P('1H<F]U9V@@=&AE(")D
M:7)T>2(@<')E9F5R96YC97,N("!)9B!A(')O=R!A;')E861Y"B`@("`@("`@
M("H@97AI<W1S(&9O<B!T:&ES('!R969E<F5N8V4L(&%T=&5M<'0@=&\@=7!D
M871E(&ET+@H@("`@("`@("`J($]T:&5R=VES92P@:6YS97)T(&$@;F5W(')O
M=RX@*B\*("`@("`@("!F;W)E86-H("@D9&ER='E?<')E9G,@87,@)&YA;64I
M('L*("`@("`@("`@("`@+R\@1&]N)W0@<W1O<F4@;&]C:V5D('!R969E<F5N
M8V5S+@H@("`@("`@("`@("!I9B`H)'1H:7,M/FES3&]C:V5D*"1N86UE*2D@
M>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1S8V]P92`]("1T:&ES+3YG97138V]P92@D;F%M92D["@H@
M("`@("`@("`@("`O*B!$;V5S(&%N(&5N=')Y(&%L<F5A9'D@97AI<W0@9F]R
M('1H:7,@<')E9F5R96YC93\@*B\*("`@("`@("`@("`@)'%U97)Y(#T@)U-%
M3$5#5"`Q($923TT@)SL*("`@("`@("`@("`@)'%U97)Y("X]("1T:&ES+3Y?
M<&%R86US6R=T86)L92==("X@)R`G.PH@("`@("`@("`@("`D<75E<GD@+CT@
M)U=(15)%('!R969?=6ED(#T@/R<["B`@("`@("`@("`@("1Q=65R>2`N/2`G
M($%.1"!P<F5F7VYA;64@/2`_)SL*("`@("`@("`@("`@)'%U97)Y("X]("<@
M04Y$("AP<F5F7W-C;W!E(#T@/R<["B`@("`@("`@("`@("1Q=65R>2`N/2`B
M($]2('!R969?<V-O<&4@/2`G:&]R9&4G*2(["@H@("`@("`@("`@("`D=F%L
M=65S(#T@87)R87DH)'1H:7,M/E]U<V5R+"`D;F%M92P@)'-C;W!E*3L*"B`@
M("`@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("`@
M("`D8VAE8VL@/2`D=&AI<RT^7V1B+3YG971/;F4H)'%U97)Y+"`D=F%L=65S
M*3L*"B`@("`@("`@("`@("\J(%)E='5R;B!A;B!E<G)O<B!I9B!T:&4@<75E
M<GD@9F%I;',N("HO"B`@("`@("`@("`@(&EF("AI<U]A*"1C:&5C:RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T9A:6QE9"!R971R:65V:6YG('!R969S(&9O<B`G("X@)'1H:7,M/E]U
M<V5R+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")&86EL960@
M<F5T<FEE=FEN9R!P<F5F97)E;F-E<RXB*2D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($ES('1H97)E(&%N(&5X:7-T:6YG(')O=R!F;W(@=&AI
M<R!P<F5F97)E;F-E/R`J+PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1C:&5C
M:RDI('L*("`@("`@("`@("`@("`@("\J(%5P9&%T92!T:&4@97AI<W1I;F<@
M<F]W+B`J+PH@("`@("`@("`@("`@("`@)'%U97)Y(#T@)U501$%412`G("X@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@+B`G("<["B`@("`@("`@("`@("`@
M("`D<75E<GD@+CT@)U-%5"!P<F5F7W9A;'5E(#T@/R<["B`@("`@("`@("`@
M("`@("`D<75E<GD@+CT@)R!72$5212!P<F5F7W5I9"`](#\G.PH@("`@("`@
M("`@("`@("`@)'%U97)Y("X]("<@04Y$('!R969?;F%M92`](#\G.PH@("`@
M("`@("`@("`@("`@)'%U97)Y("X]("<@04Y$('!R969?<V-O<&4@/2`_)SL*
M"B`@("`@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH*'-T<FEN9RDD=&AI
M<RT^9V5T5F%L=64H)&YA;64L(&9A;'-E*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W5S97(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&YA;64L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-C;W!E*3L*"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D=F%L=65S*3L*"B`@("`@("`@
M("`@("`@("`O*B!2971U<FX@86X@97)R;W(@:68@=&AE('5P9&%T92!F86EL
M<RX@*B\*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!(;W)D93HZ9F%T86PH
M)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\J($EN
M<V5R="!A(&YE=R!R;W<N("HO"B`@("`@("`@("`@("`@("`D<75E<GD@(#T@
M)TE.4T525"!)3E1/("<@+B`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`N("<@
M)SL*("`@("`@("`@("`@("`@("1Q=65R>2`N/2`G*'!R969?=6ED+"!P<F5F
M7W-C;W!E+"!P<F5F7VYA;64L('!R969?=F%L=64I(%9!3%5%4R<["B`@("`@
M("`@("`@("`@("`D<75E<GD@+CT@)R@_+"`_+"`_+"`_*2<["@H@("`@("`@
M("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?=7-E<BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<V-O<&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YA;64L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*'-T<FEN9RDD=&AI<RT^9V5T5F%L=64H)&YA;64L
M(&9A;'-E*2D["@H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?
M9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@("`@("`@("`@("`@("`@
M+RH@4F5T=7)N(&%N(&5R<F]R(&EF('1H92!I;G-E<G0@9F%I;',N("HO"B`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*"1R97-U;'0L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($UA<FL@=&AI<R!P<F5F97)E;F-E
M(&%S(")C;&5A;B(@;F]W+B`J+PH@("`@("`@("`@("`D=&AI<RT^<V5T1&ER
M='DH)&YA;64L(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("\J(%5P9&%T
M92!T:&4@<V5S<VEO;B!C86-H92X@*B\*("`@("`@("`D=&AI<RT^8V%C:&55
M<&1A=&4H*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!097)F;W)M(&-L96%N=7`@;W!E<F%T:6]N<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D86QL("!#;&5A;G5P(&%L;"!(;W)D92!P
M<F5F97)E;F-E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE86YU<"@D86QL
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@+RH@0VQO<V4@=&AE(&1A=&%B87-E
M(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]D:7-C;VYN96-T*"D[
M"@H@("`@("`@('!A<F5N=#HZ8VQE86YU<"@D86QL*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-L96%R<R!A;&P@<')E9F5R96YC97,@9G)O;2!T:&4@8F%C
M:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQE87(H*0H@("`@>PH@("`@
M("`@("\J($UA:V4@<W5R92!W92=R92!C;VYN96-T960N("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@
M<75E<GDN("HO"B`@("`@("`@)'%U97)Y(#T@)T1%3$5412!&4D]-("<@+B`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G73L*("`@("`@("`D<75E<GD@+CT@)R!7
M2$5212!P<F5F7W5I9"`](#\G.PH*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'1H:7,M/E]U<V5R*3L*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R
M:6YT9B@G4U%,(%%U97)Y(&)Y(%!R969S7W-Q;#HZ8VQE87(H*3H@)7,G+"`D
M<75E<GDI+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["@H@
M("`@("`@("\J($-L96%N=7`N("HO"B`@("`@("`@<&%R96YT.CIC;&5A<B@I
M.PH*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-O;G9E<G1S(&$@=F%L=64@9G)O;2!T:&4@9')I=F5R)W,@8VAA<G-E
M="!T;R!T:&4@<W!E8VEF:65D(&-H87)S970N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&UI>&5D("1V86QU92`@("`@02!V86QU92!T;R!C;VYV97)T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VAA<G-E="`@5&AE(&-H87)S970@=&\@8V]N
M=F5R="!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@8V]N
M=F5R=&5D('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T1G)O
M;41R:79E<B@D=F%L=64L("1C:&%R<V5T*0H@("`@>PH@("`@("`@('-T871I
M8R`D8V]N=F5R=&5D(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1V86QU92DI('L*("`@("`@("`@("`@<F5T=7)N(%-T<FEN9SHZ8V]N=F5R
M=$-H87)S970H)'9A;'5E+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==+"`D
M8VAA<G-E="D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?8F]O;"@D=F%L
M=64I*2!["B`@("`@("`@("`@(')E='5R;B`D=F%L=64["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES<V5T*"1C;VYV97)T961;)&-H87)S971=6R1V86QU
M95TI*2!["B`@("`@("`@("`@("1C;VYV97)T961;)&-H87)S971=6R1V86QU
M95T@/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86QU92P@)'1H:7,M/E]P
M87)A;7-;)V-H87)S970G72P@)&-H87)S970I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1C;VYV97)T961;)&-H87)S971=6R1V86QU95T["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A('9A;'5E(&9R;VT@=&AE('-P
M96-I9FEE9"!C:&%R<V5T('1O('1H92!D<FEV97(G<R!C:&%R<V5T+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D=F%L=64@($$@=F%L=64@=&\@8V]N
M=F5R="X*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@(%1H92!C:&%R
M<V5T('1O(&-O;G9E<G0@9G)O;2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@8V]N=F5R=&5D('9A;'5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VYV97)T5&]$<FEV97(H)'9A;'5E+"`D8VAA<G-E="D*("`@('L*("`@
M("`@("!R971U<FX@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D=F%L=64L("1C
M:&%R<V5T+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!P97)S:7-T96YT(&-O
M;FYE8W1I;VX@=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@
M("`@("\J($-H96-K('1O('-E92!I9B!W92!A<F4@86QR96%D>2!C;VYN96-T
M960N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@2&]R9&4Z
M.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@)W!R969S)RP*
M("`@("`@("`@("`@87)R87DH)W!H<'1Y<&4G+"`G8VAA<G-E="<I+`H@("`@
M("`@("`@("`G<')E9F5R96YC97,@4U%,)RD["@H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=D871A8F%S92==(#T@)R<["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==(#T@
M)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A
M;7-;)W!A<W-W;W)D)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US
M6R=P87-S=V]R9"==(#T@)R<["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==(#T@)R<["B`@("`@("`@?0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==(#T@)VAO<F1E
M7W!R969S)SL*("`@("`@("!]"@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE
M(%-13"!S97)V97(@=7-I;F<@=&AE('-U<'!L:65D('!A<F%M971E<G,N("HO
M"B`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A
M<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P97)S:7-T96YT)R`]/B`A96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I
M<W1E;G0G72DI*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V1B+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"@D=&AI<RT^
M7V1B+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@
M+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@<W=I=&-H
M("@D=&AI<RT^7V1B+3YP:'!T>7!E*2!["B`@("`@("`@8V%S92`G;7-S<6PG
M.@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL
M:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)
M5%E?15)23U)3('P@1$)?4$]25$%"24Q)5%E?4E1224TI.PH@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T
M(&9R;VT@=&AE(%-13"!S97)V97(@86YD(&-L96%N('5P('1H92!C;VYN96-T
M:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9&ES8V]N;F5C="@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]522YP:'``````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-#4U-B`Q,#4Q-30S-#$S
M-R`P,C$T-C<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($-L87-S(&9O<B!A=71O+6=E;F5R871I;F<@
M=&AE('!R969E<F5N8V5S('5S97(@:6YT97)F86-E(&%N9`H@*B!P<F]C97-S
M:6YG('1H92!F;W)M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O54DN<&AP+'8@,2XV,RXR+C$U(#(P,#8O,#$O,3(@,C(Z,C4Z,30@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,BXQ"B`J($!P86-K86=E($AO<F1E7U!R969S"B`J
M+PIC;&%S<R!0<F5F<U]522!["@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@
M=VAE=&AE<B!O<B!N;W0@82!P<F5F97)E;F-E<R!G<F]U<"!I<R!E9&ET86)L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U<"`@5&AE('!R
M969E<F5N8V5S(&=R;W5P('1O(&-H96-K+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&AE(&=R;W5P(&ES(&5D:71A
M8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!G<F]U<$ES161I=&%B;&4H)&=R
M;W5P*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,L("1P<F5F1W)O=7!S
M.PH*("`@("`@("!S=&%T:6,@)')E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@
M("!I9B`H(6ES<V5T*"1R97-U;'1S6R1G<F]U<%TI*2!["B`@("`@("`@("`@
M(&EF("@A96UP='DH)'!R969'<F]U<'-;)&=R;W5P75LG=7)L)UTI*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT<ULD9W)O=7!=(#T@=')U93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97-U;'1S6R1G<F]U
M<%T@/2!F86QS93L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<')E9D=R
M;W5P<ULD9W)O=7!=6R=M96UB97)S)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!R969'<F]U<'-;)&=R;W5P75LG;65M8F5R<R==(&%S
M("1P<F5F*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)'!R969S
M+3YI<TQO8VME9"@D<')E9BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1S6R1G<F]U<%T@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S
M=6QT<ULD9W)O=7!=.PH@("`@?0H*("`@("\J*@H@("`@("H@2&%N9&QE(&$@
M<')E9F5R96YC97,@9F]R;2!S=6)M:7-S:6]N(&EF('1H97)E(&ES(&]N92P@
M=7!D871I;F<*("`@("`J(&%N>2!P<F5F97)E;F-E<R!W:&EC:"!H879E(&)E
M96X@8VAA;F=E9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U
M<"`@5&AE('!R969E<F5N8V5S(&=R;W5P('1H870@=V%S(&5D:71E9"X*("`@
M("`J($!P87)A;2!O8FIE8W0@)'-A=F4@("!4:&4@;V)J96-T('=H97)E('1H
M92!C:&%N9V5D('9A;'5E<R!A<F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!S879E9"X@375S="!I;7!L96UE;G0@<V5T5F%L=64H<W1R:6YG+"!S
M=')I;F<I+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5VAE=&AE
M<B!P<F5F97)E;F-E<R!H879E(&)E96X@=7!D871E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@:&%N9&QE1F]R;2@F)&=R;W5P+"`F)'-A=F4I"B`@("!["B`@
M("`@("`@9VQO8F%L("1P<F5F<RP@)'!R969'<F]U<',L("1?<')E9G,L("1N
M;W1I9FEC871I;VXL("1R96=I<W1R>3L*"B`@("`@("`@)'5P9&%T960@/2!F
M86QS93L*"B`@("`@("`@+RH@4G5N('1H<F]U9V@@=&AE(&%C=&EO;B!H86YD
M;&5R<R`J+PH@("`@("`@(&EF("A5=&EL.CIG9710;W-T*"=A8W1I;VY)1"<I
M(#T]("=U<&1A=&5?<')E9G,G*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M9W)O=7`I("8F(%!R969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2D@
M>PH@("`@("`@("`@("`@("`@)'5P9&%T960@/2!F86QS93L*"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D<')E9D=R;W5P<ULD9W)O=7!=6R=M96UB97)S
M)UT@87,@)'!R968I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(21P<F5F
M<RT^:7-,;V-K960H)'!R968I('Q\"B`@("`@("`@("`@("`@("`@("`@("`@
M("@D7W!R969S6R1P<F5F75LG='EP92==(#T]("=S<&5C:6%L)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D7W!R969S6R1P<F5F75LG
M='EP92==*2!["@H@("`@("`@("`@("`@("`@("`@("`@("`O*B!4:&5S92!E
M:71H97(@87)E;B=T('-E="!O<B!A<F4@<V5T(&EN(&]T:&5R"B`@("`@("`@
M("`@("`@("`@("`@("`@("`J('!A<G1S(&]F('1H92!522X@*B\*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`G:6UP;&EC:70G.@H@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=L:6YK)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G<V5L96-T)SH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G=&5X
M="<Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W1E>'1A<F5A)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<&%S<W=O<F0G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'5P9&%T960@/2`D=7!D871E9"!\
M("1S879E+3YS971686QU92@D<')E9BP@571I;#HZ9V5T4&]S="@D<')E9BDI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E("=E;G5M)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1V86P@/2!5=&EL.CIG9710;W-T*"1P<F5F*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D7W!R969S6R1P
M<F5F75LG96YU;2==6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@?"`D<V%V92T^<V5T5F%L
M=64H)'!R968L("1V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*%\H(D%N(&EL;&5G86P@=F%L=64@=V%S('-P96-I
M9FEE9"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I96YU;2<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L<R`](%5T:6PZ.F=E=%!O
M<W0H)'!R968I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-E="`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YV86QI
M9"`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1V86QS*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1V86QS(&%S("1V86PI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?<')E9G-;)'!R969=
M6R=E;G5M)UU;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<V5T6UT@/2`D=F%L.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&EN=F%L:60@/2!T<G5E.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1I;G9A;&ED*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")!;B!I;&QE9V%L('9A;'5E('=A<R!S
M<&5C:69I960N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=7!D871E9"`]("1U<&1A=&5D('P@)'-A=F4M/G-E=%9A;'5E
M*"1P<F5F+"!`<V5R:6%L:7IE*"1S970I*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;G5M8F5R)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N=6T@/2!5=&EL.CIG9710;W-T
M*"1P<F5F*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI;G1V
M86PH)&YU;2D@(3T@)&YU;2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B5&AI<R!V86QU92!M=7-T
M(&)E(&$@;G5M8F5R+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D;G5M(#T](#`I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*%\H(E1H:7,@;G5M8F5R(&UU<W0@8F4@870@;&5A<W0@;VYE+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5P9&%T960@
M/2`D=7!D871E9"!\("1S879E+3YS971686QU92@D<')E9BP@)&YU;2D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)V-H96-K8F]X)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V
M86P@/2!5=&EL.CIG9710;W-T*"1P<F5F*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1U<&1A=&5D(#T@)'5P9&%T960@?"`D<V%V92T^<V5T5F%L
M=64H)'!R968L(&ES<V5T*"1V86PI(#\@,2`Z(#`I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E("=S<&5C:6%L)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\J($-O9&4@9F]R('-P96-I86P@96QE;65N=',@;75S="!B90H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("H@=W)I='1E;B!S<&5C:69I8V%L;'D@
M9F]R(&5A8V@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`J(&%P<&QI
M8V%T:6]N+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G:&%N9&QE7R<@+B`D<')E9BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=7!D871E9"`]("1U<&1A=&5D('P@
M8V%L;%]U<V5R7V9U;F,H)VAA;F1L95\G("X@)'!R968L("1U<&1A=&5D*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@(&EF("@D=7!D871E9"D@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)W!R969S7V-A;&QB86-K)RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@<')E9G-?8V%L;&)A8VLH*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)'!R969S+"`G4')E9G-?<V5S<VEO;B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B66]U<B!O<'1I;VYS
M(&AA=F4@8F5E;B!U<&1A=&5D(&9O<B!T:&4@9'5R871I;VX@;V8@=&AI<R!S
M97-S:6]N+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H7R@B66]U<B!O<'1I;VYS(&AA=F4@8F5E;B!U<&1A=&5D
M+B(I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D9W)O=7`@/2!N=6QL.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'5P9&%T960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T
M:&4@54D@9F]R('1H92!P<F5F97)E;F-E<R!I;G1E<F9A8V4L(&5I=&AE<B!F
M;W(@80H@("`@("H@<W!E8VEF:6,@9W)O=7`L(&]R('1H92!G<F]U<"!S96QE
M8W1I;VX@:6YT97)F86-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&=R;W5P("!4:&4@9W)O=7`@=&\@9V5N97)A=&4@=&AE(%5)(&9O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5522@D9W)O=7`@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E<BP@)&-O;F8L("1P<F5F<RP@
M)'!R969'<F]U<',L("1?<')E9G,L("1R96=I<W1R>2P@)&%P<#L*"B`@("`@
M("`@+RH@0VAE8VL@:68@86YY(&]P=&EO;G,@87)E(&%C='5A;&QY(&%V86EL
M86)L92X@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D<')E9D=R;W5P<RDI('L*
M("`@("`@("`@("`@)$=,3T)!3%-;)VYO=&EF:6-A=&EO;B==+3YP=7-H*%\H
M(E1H97)E(&%R92!N;R!O<'1I;VYS(&%V86EL86)L92XB*2P@)VAO<F1E+FUE
M<W-A9V4G*3L*("`@("`@("!]"@H@("`@("`@("\J(%-H;W<@=&AE(&AE861E
M<BX@*B\*("`@("`@("!0<F5F<U]523HZ9V5N97)A=&5(96%D97(H)&=R;W5P
M*3L*"B`@("`@("`@+RH@07-S:6=N('9A<FEA8FQE<R!T;R!H;VQD('-E;&5C
M="!L:7-T<RX@*B\*("`@("`@("!I9B`H(21P<F5F<RT^:7-,;V-K960H)VQA
M;F=U86=E)RDI('L*("`@("`@("`@("`@)$=,3T)!3%-;)VQA;F=U86=E7V]P
M=&EO;G,G72`]("1'3$]"04Q36R=N;',G75LG;&%N9W5A9V5S)UT["B`@("`@
M("`@("`@(&%R<F%Y7W5N<VAI9G0H)$=,3T)!3%-;)VQA;F=U86=E7V]P=&EO
M;G,G72P@7R@B1&5F875L="(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M96UP='DH)&=R;W5P*2`F)B!0<F5F<U]523HZ9W)O=7!)<T5D:71A8FQE*"1G
M<F]U<"DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'!R969'<F]U<'-;)&=R
M;W5P75LG;65M8F5R<R==(&%S("1P<F5F*2!["B`@("`@("`@("`@("`@("!I
M9B`H(21P<F5F<RT^:7-,;V-K960H)'!R968I*2!["B`@("`@("`@("`@("`@
M("`@("`@+RH@1V5T('1H92!H96QP(&QI;FLN("HO"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D7W!R969S6R1P<F5F75LG:&5L<"==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:&5L<&QI;FL@/2!(96QP.CIL:6YK
M*"%E;7!T>2@D7W!R969S6R1P<F5F75LG<VAA<F5D)UTI(#\@)VAO<F1E)R`Z
M("1R96=I<W1R>2T^9V5T07!P*"DL("1?<')E9G-;)'!R969=6R=H96QP)UTI
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1H96QP;&EN:R`](&YU;&P["B`@("`@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("`@("!S=VET8V@@*"1?<')E9G-;)'!R
M969=6R=T>7!E)UTI('L*("`@("`@("`@("`@("`@("`@("!C87-E("=I;7!L
M:6-I="<Z"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@("`@("!C87-E("=S<&5C:6%L)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M<&QA=&5S)RP@
M(65M<'1Y*"1?<')E9G-;)'!R969=6R=S:&%R960G72D@/R`G:&]R9&4G(#H@
M)')E9VES=')Y+3YG971!<'`H*2D@+B`B+W!R969S+R1P<F5F+FEN8R(["B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("`@("!R97%U:7)E
M("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O<')E
M9G,O)R`N("1?<')E9G-;)'!R969=6R=T>7!E)UT@+B`G+FEN8R<["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G
M*2`N("<O<')E9G,O96YD+FEN8R<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'-P86X@/2`Q,#`["B`@("`@("`@("`@("1C;VQU;6YS(#T@87)R
M87DH*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P<F5F1W)O=7!S*2D@
M>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!R969'<F]U<',@87,@)&=R
M;W5P(#T^("1G=F%L<RD@>PH@("`@("`@("`@("`@("`@("`@(&EF("A0<F5F
M<U]523HZ9W)O=7!)<T5D:71A8FQE*"1G<F]U<"DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;"`]("1G=F%L<ULG8V]L=6UN)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1G=F%L<ULG8V]L=6UN)UTI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8V]L=6UN<ULD8V]L75LD9W)O=7!=(#T@
M)&=V86QS.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D8V]L=6UN<RDI('L*("`@
M("`@("`@("`@("`@("`@("`D<W!A;B`](')O=6YD*#$P,"`O(&-O=6YT*"1C
M;VQU;6YS*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(')E<75I<F4@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L
M("=H;W)D92<I("X@)R]P<F5F<R]O=F5R=FEE=RYI;F,G.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!T:&4@=&AE(&9U;&P@
M:&5A9&5R(&]F(&$@<')E9F5R96YC92!S8W)E96X@:6YC;'5D:6YG"B`@("`@
M*B!M96YU(&%N9"!N879I9V%T:6]N(&)A<G,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9W)O=7`@(%1H92!G<F]U<"!T;R!G96YE<F%T92!T:&4@
M:&5A9&5R(&9O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5(96%D
M97(H)&=R;W5P(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES
M=')Y+"`D<')E9D=R;W5P<RP@)&%P<"P@)'!E<FUS+"`D<')E9G,L("1N;W1I
M9FEC871I;VX["@H@("`@("`@("1T:71L92`](%\H(E5S97(@3W!T:6]N<R(I
M.PH@("`@("`@(&EF("@D9W)O=7`@/3T@)VED96YT:71I97,G("8F("$D<')E
M9G,M/FES3&]C:V5D*"=D969A=6QT7VED96YT:71Y)RDI('L*("`@("`@("`@
M("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@G;F5W0VAO:6-E*"DG+"`G:F%V87-C
M<FEP="<I.PH@("`@("`@('T*("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^
M9V5T*"=T96UP;&%T97,G+"`D87!P*2`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PH@("`@("`@(&EF("AI<U]C86QL86)L92AA<G)A>2@D87!P+"`G9V5T365N
M=2<I*2D@>PH@("`@("`@("`@("`D;65N=2`](&-A;&Q?=7-E<E]F=6YC*&%R
M<F%Y*"1A<'`L("=G971-96YU)RDI.PH@("`@("`@("`@("!R97%U:7)E("1R
M96=I<W1R>2T^9V5T*"=T96UP;&%T97,G+"`G:&]R9&4G*2`N("<O;65N=2]M
M96YU+FEN8R<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E
M(&$@9&5F875L="!M96YU+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)TAO<F1E+TUE;G4N<&AP)SL*("`@("`@("`@("`@)&UE;G4@/2`F;F5W($UE
M;G4H*3L*("`@("`@("`@("`@<F5Q=6ER92`D<F5G:7-T<GDM/F=E="@G=&5M
M<&QA=&5S)RP@)VAO<F1E)RD@+B`G+VUE;G4O;65N=2YI;F,G.PH@("`@("`@
M('T*"B`@("`@("`@:68@*&ES7V-A;&QA8FQE*&%R<F%Y*"1A<'`L("=S=&%T
M=7,G*2DI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH)&%P
M<"P@)W-T871U<R<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M1TQ/0D%,4ULG;F]T:69I8V%T:6]N)UTM/FYO=&EF>2AA<G)A>2@G;&ES=&5N
M97)S)R`]/B`G<W1A='5S)RDI.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5T
M(&QI<W0@;V8@86-C97-S:6)L92!A<'!L:6-A=&EO;G,N("HO"B`@("`@("`@
M)&%P<',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1R96=I<W1R>2T^
M87!P;&EC871I;VYS(&%S("1A<'!L:6-A=&EO;B`]/B`D<&%R86US*2!["B`@
M("`@("`@("`@("\O($UA:V4@<W5R92!T:&4@87!P(&ES(&EN<W1A;&QE9"!A
M;F0@:&%S(&$@<')E9G,@9FEL92X*("`@("`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P;&EC871I;VXI
M("X@)R]C;VYF:6<O<')E9G,N<&AP)RDI('L*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)'!A<F%M
M<ULG<W1A='5S)UT@/3T@)VAE861I;F<G('Q\"B`@("`@("`@("`@("`@("`D
M<&%R86US6R=S=&%T=7,G72`]/2`G8FQO8VLG*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0VAE
M8VL@:68@=&AE(&-U<G)E;G0@=7-E<B!H87,@<&5R;6ES<V]N('1O('-E92!T
M:&ES"B`@("`@("`@("`@("`J(&%P<&QI8V%T:6]N+"!A;F0@:68@=&AE(&%P
M<&QI8V%T:6]N(&ES(&%C=&EV92X*("`@("`@("`@("`@("H@061M:6YI<W1R
M871O<G,@86QW87ES('-E92!A;&P@87!P;&EC871I;VYS+B`J+PH@("`@("`@
M("`@("!I9B`H*$%U=&@Z.FES061M:6XH*2`F)B`D<&%R86US6R=S=&%T=7,G
M72`A/2`G:6YA8W1I=F4G*2!\?`H@("`@("`@("`@("`@("`@*"1R96=I<W1R
M>2T^:&%S4&5R;6ES<VEO;B@D87!P;&EC871I;VXI("8F"B`@("`@("`@("`@
M("`@("`@*"1P87)A;7-;)W-T871U<R==(#T]("=A8W1I=F4G('Q\("1P87)A
M;7-;)W-T871U<R==(#T]("=N;W1O;VQB87(G*2DI('L*("`@("`@("`@("`@
M("`@("1A<'!S6R1A<'!L:6-A=&EO;ET@/2!?*"1P87)A;7-;)VYA;64G72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@87-O<G0H)&%P<',I
M.PH*("`@("`@("`O*B!3:&]W('1H92!C=7)R96YT(&%P<&QI8V%T:6]N(&%N
M9"!A(&9O<FT@9F]R('-W:71C:&EN9PH@("`@("`@("`J(&%P<&QI8V%T:6]N
M<RX@*B\*("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T
M97,G+"`G:&]R9&4G*2`N("<O<')E9G,O87!P+FEN8R<["@H@("`@("`@("\J
M($EF('1H97)E)W,@;VYL>2!O;F4@<')E9D=R;W5P+"!J=7-T('-H;W<@:70N
M("HO"B`@("`@("`@:68@*&5M<'1Y*"1G<F]U<"D@)B8@8V]U;G0H)'!R969'
M<F]U<',I(#T](#$I('L*("`@("`@("`@("`@)&=R;W5P(#T@87)R87E?:V5Y
M<R@D<')E9D=R;W5P<RD["B`@("`@("`@("`@("1G<F]U<"`](&%R<F%Y7W!O
M<"@D9W)O=7`I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D9W)O
M=7`I("8F(%!R969S7U5).CIG<F]U<$ES161I=&%B;&4H)&=R;W5P*2D@>PH@
M("`@("`@("`@("!R97%U:7)E("1R96=I<W1R>2T^9V5T*"=T96UP;&%T97,G
M+"`G:&]R9&4G*2`N("<O<')E9G,O8F5G:6XN:6YC)SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T92!T:&4@8V]N=&5N="!O9B!T
M:&4@=&ET;&4@8F%R(&YA=FEG871I;VX@8V5L;"`H<')E=FEO=7,@?"!N97AT
M"B`@("`@*B!O<'1I;VX@9W)O=7`I+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&=R;W5P("!#=7)R96YT(&]P=&EO;B!G<F]U<"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5N97)A=&5.879I9V%T:6]N0V5L;"@D9W)O=7`I"B`@
M("!["B`@("`@("`@9VQO8F%L("1P<F5F1W)O=7!S+"`D<F5G:7-T<GDL("1A
M<'`["@H@("`@("`@("\O(%-E87)C:"!F;W(@<')E=FEO=7,@86YD(&YE>'0@
M9W)O=7!S+@H@("`@("`@("1P<F5V:6]U<R`](&YU;&P["B`@("`@("`@)&YE
M>'0@/2!N=6QL.PH@("`@("`@("1L87-T(#T@;G5L;#L*("`@("`@("`D9FER
M<W0@/2!N=6QL.PH@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("1F
M:6YI<V@@/2!F86QS93L*("`@("`@("!F;W)E86-H("@D<')E9D=R;W5P<R!A
M<R`D<&=R;W5P(#T^("1G=F%L*2!["B`@("`@("`@("`@(&EF("A0<F5F<U]5
M23HZ9W)O=7!)<T5D:71A8FQE*"1P9W)O=7`I*2!["B`@("`@("`@("`@("`@
M("!I9B`H(21F:7)S="D@>PH@("`@("`@("`@("`@("`@("`@("1F:7)S="`]
M("1P9W)O=7`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H(21F;W5N9"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<&=R;W5P
M(#T]("1G<F]U<"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<')E=FEO
M=7,@/2`D;&%S=#L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@A)&9I;FES:"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9FEN:7-H(#T@=')U93L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&YE>'0@/2`D<&=R;W5P.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1L87-T(#T@)'!G<F]U<#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H(21P<F5V:6]U<RD@>PH@("`@("`@("`@("`D<')E=FEO=7,@
M/2`D;&%S=#L*("`@("`@("!]"B`@("`@("`@:68@*"$D;F5X="D@>PH@("`@
M("`@("`@("`D;F5X="`]("1F:7)S=#L*("`@("`@("!]"@H@("`@("`@("\J
M($1O;B=T(&QO;W`@:68@=&AE<F4G<R!O;FQY(&]N92!G<F]U<"X@*B\*("`@
M("`@("!I9B`H)&YE>'0@/3T@)'!R979I;W5S*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@(&5C:&\@)SQU;#X\;&D^)SL*("`@
M("`@("!I9B`H(65M<'1Y*"1P<F5F1W)O=7!S6R1P<F5V:6]U<UU;)W5R;"==
M*2D@>PH@("`@("`@("`@("!E8VAO($AO<F1E.CIL:6YK*$AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@D<')E9D=R;W5P<ULD<')E=FEO=7-=6R=U<FPG72DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B4')E=FEO=7,@;W!T:6]N
M<R(I*3L*("`@("`@("`@("`@96-H;R`G)FQT.R9L=#L@)R`N("1P<F5F1W)O
M=7!S6R1P<F5V:6]U<UU;)VQA8F5L)UT["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@96-H;R!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H
M2&]R9&4Z.G5R;"@D<F5G:7-T<GDM/F=E="@G=V5B<F]O="<L("=H;W)D92<I
M("X@)R]S97)V:6-E<R]P<F5F<RYP:'`G*2P@87)R87DH)V=R;W5P)R`]/B`D
M<')E=FEO=7,L("=A<'`G(#T^("1A<'`I*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?*")0<F5V:6]U<R!O<'1I;VYS(BDI.PH@("`@("`@("`@
M("!E8VAO("<F;'0[)FQT.R`G("X@)'!R969'<F]U<'-;)'!R979I;W5S75LG
M;&%B96PG73L*("`@("`@("!]"B`@("`@("`@96-H;R`G/"]A/B9N8G-P.WPF
M;F)S<#LG.PH@("`@("`@(&EF("@A96UP='DH)'!R969'<F]U<'-;)&YE>'1=
M6R=U<FPG72DI('L*("`@("`@("`@("`@96-H;R!(;W)D93HZ;&EN:RA(;W)D
M93HZ87!P;&EC871I;VY5<FPH)'!R969'<F]U<'-;)&YE>'1=6R=U<FPG72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7R@B3F5X="!O<'1I;VYS
M(BDI.PH@("`@("`@("`@("!E8VAO("1P<F5F1W)O=7!S6R1N97AT75LG;&%B
M96PG72`N("<@)F=T.R9G=#LG.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&5C:&\@2&]R9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*$AO<F1E
M.CIU<FPH)')E9VES=')Y+3YG970H)W=E8G)O;W0G+"`G:&]R9&4G*2`N("<O
M<V5R=FEC97,O<')E9G,N<&AP)RDL(&%R<F%Y*"=G<F]U<"<@/3X@)&YE>'0L
M("=A<'`G(#T^("1A<'`I*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?*").97AT(&]P=&EO;G,B*2D["B`@("`@("`@("`@(&5C:&\@)'!R969'
M<F]U<'-;)&YE>'1=6R=L86)E;"==("X@)R`F9W0[)F=T.R<["B`@("`@("`@
M?0H@("`@("`@(&5C:&\@)SPO83X\+VQI/CPO=6P^)SL*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@9&5F875L="!A<'!L:6-A=&EO;B!T;R!S:&]W
M('!R969E<F5N8V5S(&9O<BX@1&5F875L=',*("`@("`J('1O("=H;W)D92<N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1!<'`H*0H@("`@>PH@
M("`@("`@("1A<'!L:6-A=&EO;G,@/2`D1TQ/0D%,4ULG<F5G:7-T<GDG72T^
M;&ES=$%P<',H;G5L;"P@=')U92P@4$5235-?4D5!1"D["B`@("`@("`@<F5T
M=7)N(&ES<V5T*"1A<'!L:6-A=&EO;G-;)VAO<F1E)UTI(#\@)VAO<F1E)R`Z
M(&%R<F%Y7W-H:69T*"1A<'!L:6-A=&EO;G,I.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]0<F5F<R]K
M;VQA8BYP:'``````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,S,V-R`Q,#4Q-30S-#$S-R`P,C(R,S8`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R
M9&4O4')E9G,O;&1A<"YP:'`G.PH*+RHJ"B`J($MO;&%B(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!(;W)D92!P<F5F97)E;F-E('-Y<W1E;2X@1&5R:79E<R!F
M<F]M('1H90H@*B!0<F5F<U]L9&%P($Q$05`@875T:&5N=&EC871I;VX@;V)J
M96-T+"!A;F0@<VEM<&QY('!R;W9I9&5S('!A<F%M971E<G,@=&\@:70*("H@
M8F%S960@;VX@=&AE(&=L;V)A;"!+;VQA8B!C;VYF:6=U<F%T:6]N+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]K;VQA8BYP:'`L=B`Q
M+C$N,3`N."`R,#`V+S`V+S(Q(#(P.C`Y.C`W(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P-"TR,#`V(%-T=6%R="!":6YG92`\<RYB:6YG94!C;V1E
M9G5S:6]N+F-O+GIA/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4W1U
M87)T($)I;F=E(#QS+F)I;F=E0&-O9&5F=7-I;VXN8V\N>F$^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA
M<W,@4')E9G-?:V]L86(@97AT96YD<R!0<F5F<U]L9&%P('L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=',@82!N97<@2V]L86(@<')E9F5R96YC97,@;V)J
M96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!4
M:&4@=7-E<B!W:&\@;W=N<R!T:&5S92!P<F5F97)E;F-E<RX*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S;V-I871E
M9"!W:71H("1U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V-O<&4@("`@
M(%1H92!C=7)R96YT(&%P<&QI8V%T:6]N('-C;W!E+@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I
M;VX@<&%R86UE=&5R<RX*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H:6YG
M("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/PH@("`@("HO"B`@("!F=6YC=&EO
M;B!0<F5F<U]K;VQA8B@D=7-E<BP@)'!A<W-W;W)D+"`D<V-O<&4@/2`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I+"`D
M8V%C:&EN9R`](&9A;'-E*0H@("`@>PH@("`@("`@("1P87)A;7-;)VAO<W1S
M<&5C)UT@/2`D1TQ/0D%,4ULG8V]N9B==6R=K;VQA8B==6R=L9&%P)UU;)W-E
M<G9E<B==.PH@("`@("`@("1P87)A;7-;)W!O<G0G72`]("1'3$]"04Q36R=C
M;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG<&]R="==.PH@("`@("`@("1P87)A
M;7-;)W9E<G-I;VXG72`]("<S)SL*("`@("`@("`D<&%R86US6R=B87-E9&XG
M72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG8F%S961N
M)UT["B`@("`@("`@)'!A<F%M<ULG9F5T8VAD;B==(#T@=')U93L*("`@("`@
M("`D<&%R86US6R=S96%R8VAD;B==(#T@)$=,3T)!3%-;)V-O;F8G75LG:V]L
M86(G75LG;&1A<"==6R=P:'!D;B==.PH@("`@("`@("1P87)A;7-;)W-E87)C
M:'!A<W,G72`]("1'3$]"04Q36R=C;VYF)UU;)VMO;&%B)UU;)VQD87`G75LG
M<&AP<'<G73L*("`@("`@("`D<&%R86US6R=U:60G72`](&%R<F%Y*"=M86EL
M)RP@)W5I9"<I.PH*("`@("`@("!P87)E;G0Z.E!R969S7VQD87`H)'5S97(L
M("1P87-S=V]R9"P@)'-C;W!E+"`D<&%R86US+"`D8V%C:&EN9RD["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O;&1A<"YP
M:'``````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-3`Q,#,@
M,3`U,34T,S0Q,S<@,#(R,#4T`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@HO*BH*("H@2&]R9&5?4W1R:6YG(&-L
M87-S+@H@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]3=')I;F<N<&AP)SL*"B\J
M*@H@*B!0<F5F97)E;F-E<R!S=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O<B!0
M2%`G<R!,1$%0(&5X=&5N=&EO;BX*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=B87-E9&XG("`@(%1H92!B87-E($1.(&9O<B!T:&4@
M3$1!4"!S97)V97(N"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F
M('1H92!,1$%0('-E<G9E<BX*("H@("`G=6ED)R`@("`@("!4:&4@=7-E<FYA
M;64@<V5A<F-H(&ME>2X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=P87-S=V]R9"<@("=R;V]T9&XG<R!P87-S=V]R9"!F
M;W(@8FEN9"!A=71H96YT:6-A=&EO;BX*("H@("`G<&]R="<@("`@("!4:&4@
M<&]R="!O9B!T:&4@3$1!4"!S97)V97(N"B`J("`@("`@("`@("`@("`@1$5&
M055,5#H@,S@Y"B`J("`@)W)O;W1D;B<@("`@5&AE($1.(&]F('1H92!R;V]T
M("AA9&UI;FES=')A=&EV92D@86-C;W5N="!T;R!B:6YD(&9O<@H@*B`@("`@
M("`@("`@("`@('=R:71E(&]P97)A=&EO;G,N"B`J("`@)W5S97)N86UE)R`@
M5$]$3PH@*B`@("=V97)S:6]N)R`@(%1H92!V97)S:6]N(&]F('1H92!,1$%0
M('!R;W1O8V]L('1O('5S92X*("H@("`@("`@("`@("`@("!$149!54Q4.B!.
M3TY%("AS>7-T96T@9&5F875L="!W:6QL(&)E('5S960I/"]P<F4^"B`J"B`J
M($Y/5$4Z('!A<F%M971E<B`G=7-E<FYA;64G(&AA<R!B965N(&1E<')E8V%T
M960N(%5S92`G<F]O=&1N)RX*("H*("H*("H@268@<V5T=&EN9R!U<"!A<R!T
M:&4@2&]R9&4@<')E9F5R96YC92!H86YD;&5R(&EN(&-O;F8N<&AP+"!T:&4@
M9F]L;&]W:6YG"B`J(&ES(&%N(&5X86UP;&4@8V]N9FEG=7)A=&EO;BX*("H@
M5&AE('-C:&5M87,@;F5E9&5D(&9O<B!L9&%P(&%R92!I;B!H;W)D92]S8W)I
M<'1S+VQD87`N"B`J"B`J(#QP<F4^"B`J("`@)&-O;F9;)W!R969S)UU;)V1R
M:79E<B==(#T@)VQD87`G.PH@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A;7,G
M75LG:&]S='-P96,G72`]("=L;V-A;&AO<W0G.PH@*B`@("1C;VYF6R=P<F5F
M<R==6R=P87)A;7,G75LG<&]R="==(#T@)S,X.2<["B`J("`@)&-O;F9;)W!R
M969S)UU;)W!A<F%M<R==6R=B87-E9&XG72`]("=D8SUE>&%M<&QE+&1C/6]R
M9R<["B`J("`@)&-O;F9;)W!R969S)UU;)W!A<F%M<R==6R=U:60G72`]("=M
M86EL)SL*("H@/"]P<F4^"B`J"B`J(%1H92!F;VQL;W=I;F<@:7,@=F%L:60@
M8G5T('=O=6QD(&]N;'D@8F4@;F5C97-S87)Y(&EF('5S97)S"B`J(&1O($Y/
M5"!H879E('!E<FUI<W-I;VX@=&\@;6]D:69Y('1H96ER(&]W;B!,1$%0(&%C
M8V]U;G1S+@H@*@H@*B`\<')E/@H@*B`@("1C;VYF6R=P<F5F<R==6R=P87)A
M;7,G75LG<F]O=&1N)UT@/2`G8VX]36%N86=E<BQD8SUE>&%M<&QE+&1C/6]R
M9R<["B`J("`@)&-O;F9;)W!R969S)UU;)W!A<F%M<R==6R=P87-S=V]R9"==
M(#T@)W!A<W-W;W)D)SL*("H@/"]P<F4^"B`J"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U!R969S+U!R969S+VQD87`N<&AP+'8@,2XX-2XQ,"XR,"`R,#`V
M+S`V+S(Q(#(P.C`W.C4U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*
M("HO"F-L87-S(%!R969S7VQD87`@97AT96YD<R!0<F5F<R!["@H@("`@+RHJ
M"B`@("`@*B!(87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S
M+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M<&%R86US(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@
M=&AE(&-U<G)E;G0@3$1!4"!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!V
M87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&EO;CL*"B`@
M("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R(&]R(&YO
M="!W92=R92!C;VYN96-T960@=&\@=&AE($Q$05`@<V5R=F5R+@H@("`@("H*
M("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T
M960@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD:6YG('1H
M92!U<V5R)W,@1$XN"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?9&X@/2`G)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!N97<@3$1!4"!P<F5F97)E;F-E<R!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("`@(%1H92!U<V5R('=H;R!O=VYS
M('1H97-E('!R969E<F5N8V5S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%S
M<W=O<F0@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)'5S97(N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S8V]P92`@("`@5&AE(&-U<G)E;G0@87!P
M;&EC871I;VX@<V-O<&4N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@
M("`@02!H87-H(&-O;G1A:6YI;F<@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&-A8VAI;F<@(%-H;W5L9"!C86-H:6YG
M(&)E('5S960_"B`@("`@*B\*("`@(&9U;F-T:6]N(%!R969S7VQD87`H)'5S
M97(L("1P87-S=V]R9"P@)'-C;W!E(#T@)R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P87)A;7,@/2!A<G)A>2@I+"`D8V%C:&EN9R`](&9A;'-E*0H@
M("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=L9&%P
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R
M;W(H7R@B4')E9G-?;&1A<#H@4F5Q=6ER960@3$1!4"!E>'1E;G-I;VX@;F]T
M(&9O=6YD+B(I*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?=7-E<B`]("1U<V5R.PH@("`@("`@("1T:&ES+3Y?
M<V-O<&4@/2`D<V-O<&4["B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2`D<&%R
M86US.PH@("`@("`@("1T:&ES+3Y?8V%C:&EN9R`]("1C86-H:6YG.PH*("`@
M("`@("`O*B!)9B!A('9A;&ED('-E<G9E<B!P;W)T(&AA<R!N;W0@8F5E;B!S
M<&5C:69I960L('-E="!T:&4@9&5F875L="X@*B\*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=P;W)T)UTI('Q\("%I<U]I;G0H)'1H:7,M
M/E]P87)A;7-;)W!O<G0G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W!O<G0G72`](#,X.3L*("`@("`@("!]"@H@("`@("`@("\J($EF("1P
M87)A;7-;)W)O;W1D;B==(&ES(&5M<'1Y+"!A=71H96YT:6-A=&4@87,@=&AE
M(&-U<G)E;G0@=7-E<BX*("`@("`@("`@("!.;W1E.B!4:&ES(&%S<W5M97,@
M=&AE('5S97(@:7,@86QL;W=E9"!T;R!M;V1I9GD@=&AE:7(@;W=N($Q$05`*
M("`@("`@("`@("`@("`@("!E;G1R>2X@*B\*("`@("`@("!I9B`H96UP='DH
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI("8F"B`@("`@("`@("`@(&5M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=R;V]T9&XG72DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UT@/2`D=7-E<CL*("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UT@/2`D<&%S<W=O<F0["B`@
M("`@("`@?0H*("`@("`@("!P87)E;G0Z.E!R969S*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I;VX@=&\@=&AE($Q$05`@<V5R
M=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C;VYN96-T*"D*("`@('L*("`@("`@("`O*B!2971U<FX@:68@86QR96%D
M>2!C;VYN96-T960N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@2&]R9&4Z.F%S<V5R=$1R:79E<D-O;F9I9R@D=&AI<RT^7W!A<F%M<RP@
M)W!R969S)RP*("`@("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)V)A<V5D
M;B<L("=U:60G+"`G<&%S<W=O<F0G*2P*("`@("`@("`@("`@)W!R969E<F5N
M8V5S($Q$05`G*3L*"B`@("`@("`@+RH@06QL;W<@9F]R(&UU;'1I<&QE('5I
M9"!S96%R8V@@9FEE;&1S("HO"B`@("`@("`@:68@*"%I<U]A<G)A>2@D=&AI
M<RT^7W!A<F%M<ULG=6ED)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U:60G72`](&%R<F%Y*"1T:&ES+3Y?<&%R86US6R=U:60G72D["B`@
M("`@("`@?0H*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E<G9E
M<B!A;F]N>6UO=7-L>2X@*B\*("`@("`@("`D8V]N;B`](&QD87!?8V]N;F5C
M="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P@)'1H:7,M/E]P87)A;7-;
M)W!O<G0G72D["B`@("`@("`@:68@*"$D8V]N;BD@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H)T9A
M:6QE9"!T;R!O<&5N(&%N($Q$05`@8V]N;F5C=&EO;B!T;R`E<RXG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G
M72DL"B`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!3
M970@=&AE($Q$05`@<')O=&]C;VP@=F5R<VEO;BX@*B\*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI('L*("`@("`@("`@
M("`@:68@*"%L9&%P7W-E=%]O<'1I;VXH)&-O;FXL($Q$05!?3U!47U!23U1/
M0T],7U9%4E-)3TXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTI*2!["B`@("`@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@("`@("`@("`@("!S<')I
M;G1F*"=3970@3$1!4"!P<F]T;V-O;"!V97)S:6]N('1O("5D(&9A:6QE9#H@
M6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=F5R<VEO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;&1A<%]E<G)N;R@D=&AI<RT^7V-O;FYE8W1I;VXI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I
M;VXI*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J
M($EF(&YE8V5S<V%R>2P@8FEN9"!T;R!T:&4@3$1!4"!S97)V97(@87,@=&AE
M('5S97(@=VET:"!S96%R8V@*("`@("`@("`@*B!P97)M:7-S:6]N<RX@*B\*
M("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=S96%R8VAD;B==
M*2D@>PH@("`@("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)&-O;FXL("1T
M:&ES+3Y?<&%R86US6R=S96%R8VAD;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W-E87)C:'!A<W,G72D["B`@
M("`@("`@("`@(&EF("@A)&)I;F0I('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H)T)I;F0@=&\@<V5R=F5R("5S
M.B5D('=I=&@@1$X@)7,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=S96%R8VAD;B==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO
M*"1T:&ES+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M/E]C
M;VYN96-T:6]N*2DI.PH@("`@("`@("`@("!]"@E]"@H@("`@("`@("\J(%)E
M9VES=&5R(&]U<B!C86QL8F%C:R!F=6YC=&EO;B!T;R!H86YD;&4@<F5F97)R
M86QS+B`J+PH@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)VQD87!?<V5T
M7W)E8FEN9%]P<F]C)RD@)B8*("`@("`@("`@("`@(6QD87!?<V5T7W)E8FEN
M9%]P<F]C*"1C;VYN+"!A<G)A>2@D=&AI<RP@)U]R96)I;F10<F]C)RDI*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@
M("`@<W!R:6YT9B@G4V5T(')E8FEN9"!P<F]C(&9A:6QE9#H@6R5D72`E<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M/E]C
M;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)O
M<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@("`@("`@("`@(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\J(%-T;W)E('1H92!C;VYN96-T:6]N(&AA;F1L
M92!A="!T:&4@:6YS=&%N8V4@;&5V96PN("HO"B`@("`@("`@)'1H:7,M/E]C
M;VYN96-T:6]N(#T@)&-O;FX["B`@("`@("`@)'1H:7,M/E]C;VYN96-T960@
M/2!T<G5E.PH*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R86US6R=F971C:&1N
M)UTI('L*("`@("`@("`@("`@+RH@1&5F:6YE('1H92!$3B!O9B!T:&4@8W5R
M<F5N="!U<V5R+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1N(#T@<W!R:6YT
M9B@G)7,])7,L)7,G+"`D=&AI<RT^7W!A<F%M<ULG=6ED)UU;,%TL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)V)A<V5D;B==*3L*"B`@("`@("`@("`@("\J($%N9"!T:&4@1$X@;V8@=&AE
M(&%U=&AE;G1I8V%T:6YG('5S97(@*&UA>2!B92!T:&4@<V%M92!A<R!A8F]V
M92DN("HO"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;
M)W)O;W1D;B==*2D@>PH@("`@("`@("`@("`@("`@)&)I;F1?9&X@/2`D=&AI
M<RT^7W!A<F%M<ULG<F]O=&1N)UT["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D8FEN9%]D;B`]('-P<FEN=&8H)R5S/25S+"5S)RP@
M)'1H:7,M/E]P87)A;7-;)W5I9"==6S!=+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=B87-E9&XG72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($)I;F0@=&\@=&AE($Q$05`@<V5R=F5R(&%S('1H92!A=71H96YT:6-A=&EN
M9R!U<V5R+B`J+PH@("`@("`@("`@("`D8FEN9"`]($!L9&%P7V)I;F0H)'1H
M:7,M/E]C;VYN96-T:6]N+"`D8FEN9%]D;BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@
M("`@("`@("`@:68@*"$D8FEN9"D@>PH@("`@("`@("`@("`@("`@2&]R9&4Z
M.FQO9TUE<W-A9V4H"B`@("`@("`@("`@("`@("`@("`@<W!R:6YT9B@G0FEN
M9"!T;R!S97)V97(@)7,Z)60@=VET:"!$3B`E<R!F86EL960Z(%LE9%T@)7,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG<&]R="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&)I;F1?9&XL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P
M7V5R<FYO*"1T:&ES+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J(%-E87)C:"!F;W(@=&AE('5S97(G<R!F=6QL($1.
M+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=U:60G72!A
M<R`D=6ED7V9I96QD*2!["B`@("`@("`@("`@("1S96%R8V@@/2!L9&%P7W-E
M87)C:"@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?<&%R86US6R=B87-E
M9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U:61?
M9FEE;&0@+B`G/2<@+B`D=&AI<RT^7W5S97(L(&%R<F%Y*"=D;B<I*3L*("`@
M("`@("`@("`@:68@*"1S96%R8V@I('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/2!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'-E
M87)C:"D["B`@("`@("`@("`@("`@("!I9B`H)')E<W5L="`F)B`D<F5S=6QT
M6R=C;W5N="==(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&X@/2`D<F5S=6QT6S!=6R=D;B==.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^7W!A<F%M<ULG9F5T8VAD;B==*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%)E+6)I;F0@87,@=&AE('5S97(N"B`@("`@("`@("`@
M("`@("`@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^7V-O;FYE
M8W1I;VXL("1T:&ES+3Y?9&XL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@("`@("`@
M("`@<W!R:6YT9B@G1F%I;&5D('1O(')E=')I979E('5S97)<)W,@1$XZ(%LE
M9%T@)7,G+`H@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;F\H)'1H:7,M
M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<F]R
M*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@("`@("!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$:7-C;VYN96-T(&9R;VT@=&AE($Q$05`@<V5R=F5R(&%N
M9"!C;&5A;B!U<"!T:&4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI
M<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V1N(#T@)R<[
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@9F%L<V4["B`@("`@
M("`@("`@(')E='5R;B!L9&%P7V-L;W-E*"1T:&ES+3Y?8V]N;F5C=&EO;BD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0V%L;&)A8VL@9G5N8W1I
M;VX@9F]R($Q$05`@<F5F97)R86QS+B`@5&AI<R!F=6YC=&EO;B!I<R!C86QL
M960@=VAE;B!A;@H@("`@("H@3$1!4"!O<&5R871I;VX@<F5T=7)N<R!A(')E
M9F5R<F%L('1O(&%N(&%L=&5R;F%T92!S97)V97(N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("`Q(&]N(&5R<F]R+"`P(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]R96)I;F10<F]C*"1C;VYN+"`D=VAO*0H@("`@>PH@("`@("`@("\J
M(%-T<FEP(&]U="!T:&4@:&]S=&YA;64@=V4G<F4@8F5I;F<@<F5D:7)E8W1E
M9"!T;RX@*B\*("`@("`@("`D=VAO(#T@<')E9U]R97!L86-E*&%R<F%Y*"=\
M7BXJ.B\O?"<L("=\.EQD*B1\)RDL("<G+"`D=VAO*3L*"B`@("`@("`@+RH@
M1FEG=7)E(&]U="!T:&4@1$X@;V8@=&AE(&%U=&AE;G1I8V%T:6YG('5S97(N
M("HO"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F]O=&1N
M)UTI*2!["B`@("`@("`@("`@("1B:6YD7V1N(#T@)'1H:7,M/E]P87)A;7-;
M)W)O;W1D;B==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1B:6YD
M7V1N(#T@<W!R:6YT9B@G)7,])7,L)7,G+"`D=&AI<RT^7W!A<F%M<ULG=6ED
M)UU;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=7-E<FYA;64G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72D["B`@("`@("`@?0H*
M("`@("`@("`O*B!-86ME('-U<F4@=&AE('-E<G9E<B!W92=R92!B96EN9R!R
M961I<F5C=&5D('1O(&ES(&EN(&]U<B!L:7-T(&]F"B`@("`@("`@("`@=F%L
M:60@<V5R=F5R<RX@*B\*("`@("`@("!I9B`H<W1R<&]S*"1T:&ES+3Y?<&%R
M86US6R=H;W-T<W!E8R==+"`D=VAO*2`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H"B`@("`@("`@("`@("`@("!S<')I;G1F
M*"=2969E<G)A;"!T87)G970@)7,@9F]R($1.("5S(&ES(&YO="!I;B!T:&4@
M875T:&]R:7IE9"!S97)V97(@;&ES="$G+"`D=VAO+"`D8FEN9%]D;BDL"B`@
M("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@
M("!R971U<FX@,3L*("`@("`@("!]"@H@("`@("`@("\J($)I;F0@=&\@=&AE
M(&YE=R!S97)V97(N("HO"B`@("`@("`@)&)I;F0@/2!`;&1A<%]B:6YD*"1C
M;VYN+"`D8FEN9%]D;BP@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI.PH@
M("`@("`@(&EF("@A)&)I;F0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H"B`@("`@("`@("`@("`@("!S<')I;G1F*"=296)I;F0@=&\@<V5R
M=F5R("5S.B5D('=I=&@@1$X@)7,@9F%I;&5D.B!;)61=("5S)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("1B:6YD7V1N+`H@("`@("`@
M("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1T:&ES+3Y?8V]N;F5C=&EO
M;BDL"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)'1H:7,M
M/E]C;VYN96-T:6]N*2DL"B`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(')E<75E<W1E9"!S970@;V8@
M<')E9F5R96YC97,@9G)O;2!T:&4@=7-E<B=S($Q$05`@96YT<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<F5T<FEE=F4H*0H@("`@>PH@("`@("`@("\J($%T=&5M<'0@=&\@
M<'5L;"!T:&4@=F%L=65S(&9R;VT@=&AE('-E<W-I;VX@8V%C:&4@9FER<W0N
M("HO"B`@("`@("`@:68@*"1T:&ES+3YC86-H94QO;VMU<"@I*2!["B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]A
M9"!D969A=6QT<R!T;R!M86ME('-U<F4@=V4@:&%V92!A;&P@<')E9F5R96YC
M97,N("HO"B`@("`@("`@<&%R96YT.CIR971R:65V92@I.PH*("`@("`@("`O
M*B!-86ME('-U<F4@=V4@87)E(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI
M<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@3VYL>2!F971C:"!T:&4@9FEE
M;&1S(&9O<B!T:&4@871T<FEB=71E<R!W92!N965D+B`J+PH@("`@("`@("1A
M='1R<R`](&%R<F%Y*"=H;W)D95!R969S)RD["B`@("`@("`@:68@*'-T<F-M
M<"@D=&AI<RT^7W-C;W!E+"`G:&]R9&4G*2`A/2`P*2!["B`@("`@("`@("`@
M("1A='1R<UM=(#T@)'1H:7,M/E]S8V]P92`N("=0<F5F<R<["B`@("`@("`@
M?0H*("`@("`@("`O*B!396%R8V@@9F]R('1H92!M=6QT:2UV86QU960@9FEE
M;&0@8V]N=&%I;FEN9R!T:&4@87)R87D@;V8*("`@("`@("`@("!P<F5F97)E
M;F-E<RX@*B\*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F%M<ULG=6ED
M)UT@87,@)'5I9%]F:65L9"D@>PH@("`@("`@("`@("`D<V5A<F-H(#T@;&1A
M<%]S96%R8V@H)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7W!A<F%M<ULG
M8F%S961N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=6ED7V9I96QD("X@)STG("X@)'1H:7,M/E]U<V5R+"`D871T<G,I.PH@("`@
M("`@("`@("!I9B`H)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@)')E<W5L
M="`](&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]C;VYN96-T:6]N+"`D<V5A
M<F-H*3L*("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT("8F("1R97-U;'1;
M)V-O=6YT)UT@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D<F5S=6QT*2D@>PH@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@G1F%I;&5D('1O(&-O;FYE8W0@=&\@3$1!4"!P<F5F97)E
M;F-E<R!S97)V97(N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("\J(&QD87!?9V5T7V5N=')I97,H*2!C;VYV97)T<R!A='1R
M:6)U=&4@:6YD97AE<R!T;R!L;W=E<F-A<V4N("HO"B`@("`@("`@)&9I96QD
M(#T@4W1R:6YG.CIL;W=E<B@D=&AI<RT^7W-C;W!E("X@)W!R969S)RD["@H@
M("`@("`@(&EF("AI<W-E="@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*B!3
M970@=&AE(')E<75E<W1E9"!V86QU97,@:6X@=&AE("1T:&ES+3Y?<')E9G,@
M:&%S:"!B87-E9"!O;@H@("`@("`@("`@("`@("!T:&4@8V]N=&5N=',@;V8@
M=&AE($Q$05`@<F5S=6QT+@H*("`@("`@("`@("`@("`@4')E9F5R96YC97,@
M87)E('-T;W)E9"!A<R!C;VQO;BUS97!A<F%T960@;F%M93IV86QU92!P86ER
M<RX*("`@("`@("`@("`@("`@16%C:"!P86ER(&ES('-T;W)E9"!A<R!I=',@
M;W=N(&%T=')I8G5T92!O9F8@;V8@=&AE(&UU;'1I+0H@("`@("`@("`@("`@
M("!V86QU92!A='1R:6)U=&4@;F%M960@:6XZ("1T:&ES+3Y?<V-O<&4@+B`G
M4')E9G,G"@H@("`@("`@("`@("`@("!.;W1E('1H870@4')E9G,Z.G-E=%9A
M;'5E*"D@8V%N)W0@8F4@=7-E9"!H97)E(&)E8V%U<V4@;V8@=&AE"B`@("`@
M("`@("`@("`@(&-H96-K(&9O<B!T:&4@(F-H86YG96%B;&4B(&)I="X@(%=E
M('=A;G0@=&\@;W9E<G)I9&4@=&AA=`H@("`@("`@("`@("`@("!C:&5C:R!W
M:&5N('!O<'5L871I;F<@=&AE("1T:&ES+3Y?<')E9G,@:&%S:"!F<F]M('1H
M92!,1$%0"B`@("`@("`@("`@("`@('-E<G9E<BX*("`@("`@("`@("`@("HO
M"@H@("`@("`@("`@("`D<')E9G,@/2!A<G)A>2@I.PH*("`@("`@("`@("`@
M+RH@268@:&]R9&50<F5F<R!E>&ES=',L(&UE<F=E('1H96T@87,@=&AE(&)A
M<V4@;V8@=&AE('!R969S+B`J+PH@("`@("`@("`@("!I9B`H:7-S970H)')E
M<W5L=%LP75LG:&]R9&5P<F5F<R==*2D@>PH@("`@("`@("`@("`@("`@)'!R
M969S(#T@87)R87E?;65R9V4H)'!R969S+"`D<F5S=6QT6S!=6R=H;W)D97!R
M969S)UTI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)9B!T:&ES
M('-C;W!E)W,@<')E9G,@87)E(&%V86EL86)L92P@;65R9V4@=&AE;2!A<R!W
M:6QL+B`@1VEV90H@("`@("`@("`@("`@*B!T:&5M(&$@:&EG:&5R('!R96-E
M9&5N8V4@=&AA;B!H;W)D95!R969S+B`J+PH@("`@("`@("`@("!I9B`H<W1R
M8VUP*"1T:&ES+3Y?<V-O<&4L("=H;W)D92<I("$](#`I('L*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<F5S=6QT6S!=6R1F:65L9%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'!R969S(#T@87)R87E?;65R9V4H)'!R969S+"`D
M<F5S=6QT6S!=6R1F:65L9%TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D<')E9G,@87,@)'!R969S
M='(I('L*("`@("`@("`@("`@("`@("\J($EF('1H92!S=')I;F<@9&]E<VXG
M="!C;VYT86EN(&$@8V]L;VX@9&5L:6UI=&5R+"!S:VEP(&ET+B`J+PH@("`@
M("`@("`@("`@("`@:68@*'-U8G-T<E]C;W5N="@D<')E9G-T<BP@)SHG*2`]
M/2`P*2!["B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@4W!L:70@=&AE('-T<FEN
M9R!I;G1O(&ET<R!N86UE.G9A;'5E(&-O;7!O;F5N=',N("HO"B`@("`@("`@
M("`@("`@("!L:7-T*"1P<F5F+"`D=F%L*2`]('-P;&ET*"<Z)RP@)'!R969S
M='(L(#(I.PH*("`@("`@("`@("`@("`@("\J(%)E=')I979E('1H:7,@<')E
M9F5R96YC92X@*B\*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!R969S6R1P<F5F72DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E=%9A;'5E*"1P<F5F+"!B87-E-C1?9&5C;V1E*"1V86PI+"!F86QS92D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$1E9F%U;'0H)'!R968L
M(&9A;'-E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F%D9"@D<')E9BP@8F%S938T7V1E8V]D92@D=F%L
M*2P@7U!2149?4TA!4D5$*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@+RH@0V%L;"!H;V]K<RX@*B\*("`@("`@("`@
M("`@)'1H:7,M/E]C86QL2&]O:W,H*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G3F\@<')E9F5R96YC97,@=V5R
M92!R971R:65V960N)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@57!D871E('1H92!S
M97-S:6]N(&-A8VAE+B`J+PH@("`@("`@("1T:&ES+3YC86-H955P9&%T92@I
M.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-T;W)E<R!P<F5F97)E;F-E<R!T;R!T:&4@3$1!4"!S97)V97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<W1O<F4H*0H@("`@>PH@("`@("`@("1U<&1A=&5D(#T@=')U93L*
M"B`@("`@("`@+RH@0VAE8VL@9F]R(&%N>2`B9&ER='DB('!R969E<F5N8V5S
M+B!)9B!N;R`B9&ER='DB"B`@("`@("`@("H@<')E9F5R96YC97,@87)E(&9O
M=6YD+"!T:&5R92=S(&YO(&YE960@=&\@=7!D871E('1H92!,1$%0"B`@("`@
M("`@("H@<V5R=F5R+B!%>&ET('-U8V-E<W-F=6QL>2X@*B\*("`@("`@("`D
M9&ER='E?<')E9G,@/2`D=&AI<RT^7V1I<G1Y4')E9G,H*3L*("`@("`@("!I
M9B`H(6-O=6YT*"1D:7)T>5]P<F5F<RDI('L*("`@("`@("`@("`@<F5T=7)N
M('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!-86ME('-U<F4@=V4@87)E
M(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@
M("`@("`@+RH@0G5I;&0@82!H87-H(&]F('1H92!P<F5F97)E;F-E<R!A;F0@
M=&AE:7(@=F%L=65S('1H870@;F5E9`H@("`@("`@("`J('1O(&)E('-T;W)E
M9"!I;B!T:&4@3$1!4"!S97)V97(N($)E8V%U<V4@=V4@:&%V92!T;R!U<&1A
M=&4*("`@("`@("`@*B!A;&P@;V8@=&AE('9A;'5E<R!O9B!A(&UU;'1I+79A
M;'5E(&5N=')Y('=H;VQE<V%L92P@=V4*("`@("`@("`@*B!C86XG="!J=7-T
M('!I8VL@;W5T('1H92!D:7)T>2!P<F5F97)E;F-E<SL@=V4@;75S="!U<&1A
M=&4*("`@("`@("`@*B!E=F5R>71H:6YG+B`J+PH@("`@("`@("1N97=?=F%L
M=65S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T
M:&ES+3Y?<')E9G,I(&%S("1P<F5F*2!["B`@("`@("`@("`@("\O($1O;B=T
M('-T;W)E(&QO8VME9"!P<F5F97)E;F-E<RX*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^:7-,;V-K960H)'!R968I*2!["B`@("`@("`@("`@("`@("`D96YT
M<GD@/2`D<')E9B`N("<Z)R`N(&)A<V4V-%]E;F-O9&4H)'1H:7,M/F=E=%9A
M;'5E*"1P<F5F*2D["B`@("`@("`@("`@("`@("`D9FEE;&0@/2`D=&AI<RT^
M9V5T4V-O<&4H)'!R968I("X@)U!R969S)SL*("`@("`@("`@("`@("`@("1N
M97=?=F%L=65S6R1F:65L9%U;72`]("1E;G1R>3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+RH@16YT<FEE<R!M=7-T(&AA=F4@=&AE(&]B
M:F5C=&-L87-S97,@)W1O<"<@86YD("=H;W)D97!E<G-O;B<*("`@("`@("`@
M*B!T;R!S=6-C97-S9G5L;'D@<W1O<F4@3$1!4"!P<F5F<RX@0VAE8VL@9F]R
M(&)O=&@@;V8@=&AE;2P*("`@("`@("`@*B!A;F0@861D('1H96T@:68@;F5C
M97-S87)Y+B`J+PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%R86US6R=U
M:60G72!A<R`D=6ED7V9I96QD*2!["B`@("`@("`@("`@("1S96%R8V@@/2!L
M9&%P7W-E87)C:"@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?<&%R86US
M6R=B87-E9&XG72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1U:61?9FEE;&0@+B`G/2<@+B`D=&AI<RT^7W5S97(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;V)J96-T8VQA<W,G*2D[
M"B`@("`@("`@("`@(&EF("@D<V5A<F-H*2!["B`@("`@("`@("`@("`@("`D
M<F5S=6QT(#T@;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V-O;FYE8W1I;VXL
M("1S96%R8V@I.PH@("`@("`@("`@("`@("`@:68@*"1R97-U;'0@)B8@)')E
M<W5L=%LG8V]U;G0G72`^(#`I('L*("`@("`@("`@("`@("`@("`@("`D=&]P
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@)&AO<F1E<&5R<V]N(#T@
M9F%L<V4["@H@("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1R97-U;'1;,%U;)V]B:F5C=&-L87-S)UU;)V-O=6YT)UT[("1I*RLI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,%U;)V]B:F5C
M=&-L87-S)UU;)&E=(#T]("=T;W`G*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&]P(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*"1R97-U;'1;,%U;)V]B:F5C=&-L87-S)UU;)&E=(#T]("=H
M;W)D95!E<G-O;B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1H
M;W)D97!E<G-O;B`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\J
M($%D9"!A;GD@;6ES<VEN9R!O8FIE8W1C;&%S<V5S+B`J+PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A)'1O<"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!L9&%P7VUO9%]A9&0H)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7V1N
M+"!A<G)A>2@G;V)J96-T8VQA<W,G(#T^("=T;W`G*2D["B`@("`@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H(21H;W)D97!E
M<G-O;BD@>PH@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7VUO9%]A9&0H
M)'1H:7,M/E]C;VYN96-T:6]N+"`D=&AI<RT^7V1N+"!A<G)A>2@G;V)J96-T
M8VQA<W,G(#T^("=H;W)D95!E<G-O;B<I*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-E
M;F0@=&AE(&AA<V@@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@(&EF
M("AL9&%P7VUO9%]R97!L86-E*"1T:&ES+3Y?8V]N;F5C=&EO;BP@)'1H:7,M
M/E]D;BP@)&YE=U]V86QU97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M:7)T>5]P<F5F<R!A<R`D<')E9BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/G-E=$1I<G1Y*"1P<F5F+"!F86QS92D["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@*("`@
M("`@("`@("`@("`@<W!R:6YT9B@G56YA8FQE('1O(&UO9&EF>2!P<F5F97)E
M;F-E<SH@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@(&QD87!?
M97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI*2P*("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("1U
M<&1A=&5D(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!!='1E;7!T
M('1O(&-A8VAE('1H92!P<F5F97)E;F-E<R!I;B!T:&4@<V5S<VEO;BX@*B\*
M("`@("`@("`D=&AI<RT^8V%C:&55<&1A=&4H*3L*"B`@("`@("`@<F5T=7)N
M("1U<&1A=&5D.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQE87)S(&%L;"!P
M<F5F97)E;F-E<R!F<F]M('1H92!,1$%0(&)A8VME;F0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L96%R*"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@
M=V4@87)E(&-O;FYE8W1E9"X@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@)&%T=')S(#T@)$=,3T)!3%-;)W)E9VES=')Y)UTM/FQI
M<W1!<'!S*&%R<F%Y*"=I;F%C=&EV92<L("=A8W1I=F4G+"`G:&ED9&5N)RP@
M)VYO=&]O;&)A<B<L("=A9&UI;B<I*3L*("`@("`@("!F;W)E86-H("@D871T
M<G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1A='1R<ULD:V5Y
M72`]("1V86P@+B`G4')E9G,G.PH@("`@("`@('T*"B`@("`@("`@)'-E87)C
M:"`](&QD87!?<F5A9"@D=&AI<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?9&XL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;V)J96-T0VQA<W,]:&]R
M9&5097)S;VXG+"`D871T<G,L(#$I.PH*("`@("`@("!I9B`H)'-E87)C:"D@
M>PH@("`@("`@("`@("`D<F5S=6QT(#T@;&1A<%]G971?96YT<FEE<R@D=&AI
M<RT^7V-O;FYE8W1I;VXL("1S96%R8V@I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=&86EL960@=&\@8V]N;F5C
M="!T;R!,1$%0('!R969E<F5N8V5S('-E<G9E<BXG+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*
M("`@("`@("!I9B`H)')E<W5L="D@>PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D<F5S=6QT6S!=6R=C;W5N="==.R`D:2LK*2!["B`@("`@("`@
M("`@("`@("`D871T<G-;)')E<W5L=%LP75LD:5U=(#T@87)R87DH*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(6QD87!?;6]D7V1E;"@D=&AI
M<RT^7V-O;FYE8W1I;VXL("1T:&ES+3Y?9&XL("1A='1R<RDI('L*("`@("`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*`H@("`@("`@("`@("`@("`@
M("`@('-P<FEN=&8H)U5N86)L92!T;R!C;&5A<B!P<F5F97)E;F-E<SH@6R5D
M72`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO
M*"1T:&ES+3Y?8V]N;F5C=&EO;BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!L9&%P7V5R<F]R*"1T:&ES+3Y?8V]N;F5C=&EO;BDI+`H@("`@("`@
M("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H)U5N86)L92!T;R!C;&5A
M<B!P<F5F97)E;F-E<SH@6R5D72`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@(&QD87!?97)R;F\H)'1H:7,M/E]C;VYN96-T:6]N*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@;&1A<%]E<G)O<B@D=&AI<RT^7V-O;FYE8W1I;VXI
M*2P*("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^8VQE86YU<"AT<G5E*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%!E<F9O<FT@8VQE86YU<"!O<&5R871I;VYS+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1A;&P@($-L96%N=7`@86QL($AO
M<F1E('!R969E<F5N8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&5A;G5P
M*"1A;&P@/2!F86QS92D*("`@('L*("`@("`@("`O*B!#;&]S92!T:&4@3$1!
M4"!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?9&ES8V]N;F5C="@I
M.PH*("`@("`@("!P87)E;G0Z.F-L96%N=7`H)&%L;"D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4')E9G,O0V%T96=O<GE-86YA
M9V5R+G!H<```````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,30P-S0@,3`U,34T
M,S0Q,S<@,#(T,C$S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!#;&%S<R!F;W(@:&%N9&QI;F<@82!L
M:7-T(&]F(&-A=&5G;W)I97,@<W1O<F5D(&EN(&$@=7-E<B=S"B`J('!R969E
M<F5N8V5S+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]0<F5F<R]0<F5F<R]#
M871E9V]R>4UA;F%G97(N<&AP+'8@,2XQ,2XQ,"XU(#(P,#8O,#$O,#$@,C$Z
M,C@Z,S(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U!R
M969S"B`J+PIC;&%S<R!0<F5F<U]#871E9V]R>4UA;F%G97(@>PH*("`@("\J
M*@H@("`@("H@1V5T(&%L;"!C871E9V]R:65S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G970H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@
M("`@("1S=')I;F<@/2`D<')E9G,M/F=E=%9A;'5E*"=C871E9V]R:65S)RD[
M"B`@("`@("`@:68@*&5M<'1Y*"1S=')I;F<I*2!["B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@)&-A=&5G;W)I97,@
M/2!E>'!L;V1E*"=\)RP@)'-T<FEN9RD["B`@("`@("`@87-O<G0H)&-A=&5G
M;W)I97,I.PH*("`@("`@("!R971U<FX@)&-A=&5G;W)I97,["B`@("!]"@H@
M("`@9G5N8W1I;VX@9V5T4V5L96-T*"1I9"P@)&-U<G)E;G0@/2!N=6QL*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@("`@("`@("1H=&UL(#T@
M)SQS96QE8W0@:60](B<@+B!H=&UL<W!E8VEA;&-H87)S*"1I9"D@+B`G(B!N
M86UE/2(G("X@:'1M;'-P96-I86QC:&%R<R@D:60I("X@)R(^)SL*"B`@("`@
M("`@)&-A=&5G;W)I97,@/2!0<F5F<U]#871E9V]R>4UA;F%G97(Z.F=E="@I
M.PH@("`@("`@(&EF("@A:6Y?87)R87DH)&-U<G)E;G0L("1C871E9V]R:65S
M*2`F)B`A96UP='DH)&-U<G)E;G0I*2!["B`@("`@("`@("`@("1H=&UL("X]
M("<\;W!T:6]N('9A;'5E/2(J;F5W*B<@+B!H=&UL<W!E8VEA;&-H87)S*"1C
M=7)R96YT*2`N("<B/B<@+B!S<')I;G1F*%\H(E5S92!#=7)R96YT.B`E<R(I
M+"!H=&UL<W!E8VEA;&-H87)S*"1C=7)R96YT*2D@+B`G/"]O<'1I;VX^)R`N
M"B`@("`@("`@("`@("`@("`G/&]P=&EO;B!V86QU93TB(CXM+2TM/"]O<'1I
M;VX^)SL*("`@("`@("!]"@H@("`@("`@(&EF("@A)'!R969S+3YI<TQO8VME
M9"@G8V%T96=O<FEE<R<I*2!["B`@("`@("`@("`@("1H=&UL("X]("<\;W!T
M:6]N('9A;'5E/2(J;F5W*B(^)R`N(%\H(DYE=R!#871E9V]R>2(I("X@(CPO
M;W!T:6]N/EQN(B`N"B`@("`@("`@("`@("`@("`G/&]P=&EO;B!V86QU93TB
M(CXM+2TM/"]O<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@("\O($%L=V%Y
M<R!A9&0@86X@56YF:6QE9"!O<'1I;VXN"B`@("`@("`@)&AT;6P@+CT@)SQO
M<'1I;VX@=F%L=64](B(G("X*("`@("`@("`@("`@*&5M<'1Y*"1C=7)R96YT
M*2`_("<@<V5L96-T960](G-E;&5C=&5D(CXG(#H@)SXG*2`N"B`@("`@("`@
M("`@(&AT;6QS<&5C:6%L8VAA<G,H7R@B56YF:6QE9"(I*2`N("<\+V]P=&EO
M;CXG.PH*("`@("`@("!F;W)E86-H("@D8V%T96=O<FEE<R!A<R`D;F%M92D@
M>PH@("`@("`@("`@("`D:'1M;"`N/2`G/&]P=&EO;B!V86QU93TB)R`N(&AT
M;6QS<&5C:6%L8VAA<G,H)&YA;64I("X@)R(G("X*("`@("`@("`@("`@("`@
M("@D;F%M92`]/3T@)&-U<G)E;G0@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(^
M)R`Z("<^)RD@+@H@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D
M;F%M92D@+B`G/"]O<'1I;VX^)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D:'1M;"`N("<\+W-E;&5C=#XG.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=$IA=F%38W)I<'0H)&9O<FUN86UE+"`D96QE;65N=&YA;64I"B`@("!["B`@
M("`@("`@)'!R;VUP="`](&%D9'-L87-H97,H7R@B4&QE87-E('1Y<&4@=&AE
M(&YE=R!C871E9V]R>2!N86UE.B(I*3L*("`@("`@("`D97)R;W(@/2!A9&1S
M;&%S:&5S*%\H(EEO=2!M=7-T('1Y<&4@82!N97<@8V%T96=O<GD@;F%M92XB
M*2D["@H@("`@("`@(')E='5R;B`\/#Q*059!4T-225!4"@H\<V-R:7!T('1Y
M<&4](G1E>'0O:F%V87-C<FEP="(^"CPA+2T*9G5N8W1I;VX@8VAE8VM#871E
M9V]R>2@I"GL*("`@(&EF("AD;V-U;65N="XD9F]R;6YA;64N)&5L96UE;G1N
M86UE+G9A;'5E(#T]("<J;F5W*B<I('L*("`@("`@("!V87(@8V%T96=O<GD@
M/2!W:6YD;W<N<')O;7!T*"<D<')O;7!T)RP@)R<I.PH@("`@("`@(&EF("AC
M871E9V]R>2`A/2!N=6QL("8F(&-A=&5G;W)Y("$]("<G*2!["B`@("`@("`@
M("`@(&1O8W5M96YT+B1F;W)M;F%M92YN97=?8V%T96=O<GDN=F%L=64@/2!C
M871E9V]R>3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!W:6YD;W<N
M86QE<G0H)R1E<G)O<B<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?2!E;'-E(&EF("AD;V-U;65N="XD9F]R;6YA;64N)&5L
M96UE;G1N86UE+G9A;'5E+FEN9&5X3V8H)RIN97<J)RD@(3T@+3$I('L*("`@
M("`@("!D;V-U;65N="XD9F]R;6YA;64N;F5W7V-A=&5G;W)Y+G9A;'5E(#T@
M9&]C=6UE;G0N)&9O<FUN86UE+B1E;&5M96YT;F%M92YV86QU92YS=6)S='(H
M-2P@9&]C=6UE;G0N)&9O<FUN86UE+B1E;&5M96YT;F%M92YV86QU92YL96YG
M=&@I.PH@("`@?0H*("`@(')E='5R;B!T<G5E.PI]"B\O+2T^"CPO<V-R:7!T
M/@I*059!4T-225!4.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@;F5W
M(&-A=&5G;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-A=&5G
M;W)Y("!4:&4@;F%M92!O9B!T:&4@8V%T96=O<GD@=&\@861D+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H
M92!N97<@8V%T96=O<GDG<R!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M9&0H)&-A=&5G;W)Y*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<')E9G,["@H@
M("`@("`@(&EF("@D<')E9G,M/FES3&]C:V5D*"=C871E9V]R:65S)RD@?'P@
M96UP='DH)&-A=&5G;W)Y*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`D8V%T96=O<FEE<R`](%!R969S7T-A=&5G
M;W)Y36%N86=E<CHZ9V5T*"D["B`@("`@("`@:68@*&EN7V%R<F%Y*"1C871E
M9V]R>2P@)&-A=&5G;W)I97,I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"@H@("`@("`@("1C871E9V]R:65S6UT@/2`D8V%T96=O
M<GD["B`@("`@("`@)'!R969S+3YS971686QU92@G8V%T96=O<FEE<R<L(&EM
M<&QO9&4H)WPG+"`D8V%T96=O<FEE<RDI.PH*("`@("`@("!R971U<FX@)&-A
M=&5G;W)Y.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@8V%T96=O
M<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%T96=O<GD@(%1H
M92!C871E9V]R>2!T;R!R96UO=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;6]V92@D8V%T96=O<GDI"B`@("!["B`@
M("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@:68@*"1P<F5F<RT^:7-,
M;V-K960H)V-A=&5G;W)I97,G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D8V%T96=O<FEE<R`](%!R969S7T-A
M=&5G;W)Y36%N86=E<CHZ9V5T*"D["@H@("`@("`@("1K97D@/2!A<G)A>5]S
M96%R8V@H)&-A=&5G;W)Y+"`D8V%T96=O<FEE<RD["B`@("`@("`@:68@*"1K
M97D@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D:V5Y.PH@("`@
M("`@('T*"B`@("`@("`@=6YS970H)&-A=&5G;W)I97-;)&ME>5TI.PH@("`@
M("`@("1P<F5F<RT^<V5T5F%L=64H)V-A=&5G;W)I97,G+"!I;7!L;V1E*"=\
M)RP@)&-A=&5G;W)I97,I*3L*"B`@("`@("`@+R\@4F5M;W9E(&%N>2!C;VQO
M<B!S971T:6YG<R!F;W(@)&-A=&5G;W)Y+@H@("`@("`@("1C;VQO<G,@/2!0
M<F5F<U]#871E9V]R>4UA;F%G97(Z.F-O;&]R<R@I.PH@("`@("`@('5N<V5T
M*"1C;VQO<G-;)&-A=&5G;W)Y72D["B`@("`@("`@4')E9G-?0V%T96=O<GE-
M86YA9V5R.CIS971#;VQO<G,H)&-O;&]R<RD["@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]L;W(@
M9F]R(&5A8V@@;V8@=&AE('5S97(G<R!C871E9V]R:65S+@H@("`@("H*("`@
M("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!C;VQO<G,L(&ME>2!I<R!T
M:&4@8V%T96=O<GD@;F%M92P@=F%L=64@:7,@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("!(5$U,(&-O;&]R(&-O9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;&]R<R@I"B`@("!["B`@("`@("`@9VQO8F%L("1P<F5F<SL*"B`@("`@
M("`@+RH@1&5F875L="!V86QU97,@=&AA="!C86X@8F4@;W9E<G)I9&1E;B!B
M=70@;75S="!A;'=A>7,@8F4*("`@("`@("`@*B!P<F5S96YT+B`J+PH@("`@
M("`@("1C;VQO<G-;)U]D969A=6QT7R==(#T@)R-&1D9&1D8G.PH@("`@("`@
M("1C;VQO<G-;)U]U;F9I;&5D7R==(#T@)R-$1$1$1$0G.PH*("`@("`@("`D
M<&%I<G,@/2!E>'!L;V1E*"=\)RP@)'!R969S+3YG971686QU92@G8V%T96=O
M<GE?8V]L;W)S)RDI.PH@("`@("`@(&9O<F5A8V@@*"1P86ER<R!A<R`D<&%I
M<BD@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1P86ER*2D@>PH@("`@("`@
M("`@("`@("`@;&ES="@D8V%T96=O<GDL("1C;VQO<BD@/2!E>'!L;V1E*"<Z
M)RP@)'!A:7(I.PH@("`@("`@("`@("`@("`@)&-O;&]R<ULD8V%T96=O<GE=
M(#T@)&-O;&]R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D
M8V]L;W)S6R<G72`]("1C;VQO<G-;)U]U;F9I;&5D7R==.PH*("`@("`@("!R
M971U<FX@)&-O;&]R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&9O<F5G<F]U;F0@8V]L;W(@9F]R(&5A8V@@;V8@=&AE('5S97(G<R!C
M871E9V]R:65S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@;&ES
M="!O9B!C;VQO<G,L(&ME>2!I<R!T:&4@8V%T96=O<GD@;F%M92P@=F%L=64@
M:7,@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!(5$U,(&-O;&]R(&-O9&4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9G0V]L;W)S*"D*("`@('L*("`@("`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TEM86=E+G!H<"<["@H@("`@("`@("1C
M;VQO<G,@/2!0<F5F<U]#871E9V]R>4UA;F%G97(Z.F-O;&]R<R@I.PH@("`@
M("`@("1F9V-O;&]R<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)&-O
M;&]R<R!A<R`D;F%M92`]/B`D8V]L;W(I('L*("`@("`@("`@("`@)&9G8V]L
M;W)S6R1N86UE72`]($AO<F1E7TEM86=E.CIB<FEG:'1N97-S*"1C;VQO<BD@
M/"`Q,C@@/R`G(V8V9C9F-B<@.B`G(S`P,"<["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)&9G8V]L;W)S.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-O
M;&]R*"1C871E9V]R>2P@)&-O;&]R*0H@("`@>PH@("`@("`@("1C;VQO<G,@
M/2!0<F5F<U]#871E9V]R>4UA;F%G97(Z.F-O;&]R<R@I.PH@("`@("`@("1C
M;VQO<G-;)&-A=&5G;W)Y72`]("1C;VQO<CL*("`@("`@("!0<F5F<U]#871E
M9V]R>4UA;F%G97(Z.G-E=$-O;&]R<R@D8V]L;W)S*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!S971#;VQO<G,H)&-O;&]R<RD*("`@('L*("`@("`@("!G;&]B
M86P@)'!R969S.PH*("`@("`@("`D<&%I<G,@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<F5A8V@@*"1C;VQO<G,@87,@)&-A=&5G;W)Y(#T^("1C;VQO<BD@>PH@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1C871E9V]R>2DI('L*("`@("`@("`@
M("`@("`@("1P86ER<UM=(#T@(B1C871E9V]R>3HD8V]L;W(B.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<')E9G,M/G-E=%9A;'5E*"=C
M871E9V]R>5]C;VQO<G,G+"!I;7!L;V1E*"=\)RP@)'!A:7)S*2D["B`@("!]
M"@I]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!R969S
M+W-E<W-I;VXN<&AP````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`W,3$W(#$P-3$U-#,T,3,W(#`R,C8R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@4')E9F5R96YC
M97,@<W1O<F%G92!I;7!L96UE;G1A=&EO;B!F;W(@4$A0)W,@<V5S<VEO;B!I
M;7!L96UE;G1A=&EO;BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E9G,O
M4')E9G,O<V5S<VEO;BYP:'`L=B`Q+C,R+C$R+C<@,C`P-B\P-2\Q,2`Q-SHQ
M,SHR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!*;VX@
M4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F]N(%!A<FES92`\:F]N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@
M2&]R9&4@,2XS+C0*("H@0'!A8VMA9V4@2&]R9&5?4')E9G,*("HO"F-L87-S
M(%!R969S7W-E<W-I;VX@97AT96YD<R!0<F5F<R!["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1S(&$@;F5W('-E<W-I;VX@<')E9F5R96YC97,@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'5S97(@("`@("!4:&4@
M=7-E<B!W:&\@;W=N<R!T:&5S92!P<F5F97)E;F-E<RX@*%5N=7-E9"D*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("!4:&4@<&%S<W=O<F0@87-S
M;V-I871E9"!W:71H("1U<V5R+B`H56YU<V5D*0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<V-O<&4@("`@(%1H92!C=7)R96YT('!R969E<F5N8V5S('-C;W!E
M+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("`@($$@:&%S:"!C;VYT
M86EN:6YG(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*%5N=7-E9"D*("`@("`J($!P87)A;2!B;V]L
M96%N("1C86-H:6YG("!3:&]U;&0@8V%C:&EN9R!B92!U<V5D/R`H56YU<V5D
M*0H@("`@("H*("`@("`J+PH@("`@9G5N8W1I;VX@4')E9G-?<V5S<VEO;B@D
M=7-E<BP@)'!A<W-W;W)D(#T@)R<L("1S8V]P92`]("<G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US(#T@;G5L;"P@)&-A8VAI;F<@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S
M*"=S97-S:6]N)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z
M.G)A:7-E17)R;W(H7R@B4')E9G-?<V5S<VEO;CH@4F5Q=6ER960@<V5S<VEO
M;B!E>'1E;G-I;VX@;F]T(&9O=6YD+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V-O<&4@/2`D<V-O<&4[
M"@H@("`@("`@('!A<F5N=#HZ4')E9G,H*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E<R!T:&4@<F5Q=65S=&5D('-E="!O9B!P<F5F97)E;F-E
M<R!F<F]M('1H92!C=7)R96YT('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5T<FEE
M=F4H*0H@("`@>PH@("`@("`@("\J($QO860@9&5F875L=',@=&\@;6%K92!S
M=7)E('=E(&AA=F4@86QL('!R969E<F5N8V5S+B`J+PH@("`@("`@('!A<F5N
M=#HZ<F5T<FEE=F4H*3L*"B`@("`@("`@)&=L;V)A;%]P<F5F<R`](&%R<F%Y
M*"D["B`@("`@("`@)&QO8V%L7W!R969S(#T@87)R87DH*3L*"B`@("`@("`@
M+RH@4F5T<FEE=F4@9VQO8F%L(&%N9"!L;V-A;"!P<F5F97)E;F-E<R!F<F]M
M('1H92!S97-S:6]N('9A<FEA8FQE+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M7U-%4U-)3TY;)VAO<F1E7W!R969S)UU;)VAO<F1E)UTI*2!["B`@("`@("`@
M("`@("1G;&]B86Q?<')E9G,@/2`D7U-%4U-)3TY;)VAO<F1E7W!R969S)UU;
M)VAO<F1E)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D7U-%4U-)
M3TY;)VAO<F1E7W!R969S)UU;)'1H:7,M/E]S8V]P95TI*2!["B`@("`@("`@
M("`@("1L;V-A;%]P<F5F<R`]("1?4T534TE/3ELG:&]R9&5?<')E9G,G75LD
M=&AI<RT^7W-C;W!E73L*("`@("`@("!]"@H@("`@("`@("\J(%)E=')I979E
M(&%N9"!S=&]R92!T:&4@;&]C86P@86YD(&=L;V)A;"!P<F5F97)E;F-E<RX@
M*B\*("`@("`@("`D=&AI<RT^7W!R969S(#T@87)R87E?;65R9V4H)'1H:7,M
M/E]P<F5F<RP@)&=L;V)A;%]P<F5F<RP@)&QO8V%L7W!R969S*3L*"B`@("`@
M("`@+RH@0V%L;"!H;V]K<RX@*B\*("`@("`@("!I9B`H(6ES<V5T*"1?4T53
M4TE/3ELG:&]R9&5?<')E9G,G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M86QL2&]O:W,H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4W1O<F5S('!R969E<F5N8V5S(&EN('1H
M92!C=7)R96YT('-E<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1P<F5F<R`@06X@87)R87D@;&ES=&EN9R!T:&4@<')E9F5R96YC97,@=&\@
M8F4@<W1O<F5D+B!)9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@;F]T
M('-P96-I9FEE9"P@<W1O<F4@86QL('1H92!P<F5F97)E;F-E<R!L:7-T960@
M:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@('1H92`D<')E9G,@:&%S
M:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S=&]R92@D<')E9G,@/2!A<G)A>2@I*0H@("`@>PH@
M("`@("`@("\J($-R96%T92!A;F0@<F5G:7-T97(@=&AE('!R969E<F5N8V5S
M(&%R<F%Y+"!I9B!N96-E<W-A<GDN("HO"B`@("`@("`@:68@*"%I<W-E="@D
M7U-%4U-)3TY;)VAO<F1E7W!R969S)UTI*2!["B`@("`@("`@("`@("1?4T53
M4TE/3ELG:&]R9&5?<')E9G,G72`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@
M("`@("`O*B!#;W!Y('1H92!C=7)R96YT('!R969E<F5N8V5S(&EN=&\@=&AE
M('-E<W-I;VX@=F%R:6%B;&4N("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]P<F5F<R!A<R`D;F%M92`]/B`D<')E9BD@>PH@("`@("`@("`@("`D<V-O
M<&4@/2`D=&AI<RT^9V5T4V-O<&4H)&YA;64I.PH@("`@("`@("`@("`D7U-%
M4U-)3TY;)VAO<F1E7W!R969S)UU;)'-C;W!E75LD;F%M95T@/2`D<')E9CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4&5R9F]R;2!C;&5A;G5P(&]P97)A=&EO;G,N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&%L;"`@0VQE86YU<"!A;&P@2&]R9&4@
M<')E9F5R96YC97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L96%N=7`H)&%L
M;"`](&9A;'-E*0H@("`@>PH@("`@("`@("\J(%!E<F9O<FT@82!(;W)D92UW
M:61E(&-L96%N=7`_("HO"B`@("`@("`@:68@*"1A;&PI('L*("`@("`@("`@
M("`@=6YS970H)%]315-324].6R=H;W)D95]P<F5F<R==*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D7U-%4U-)3TY;)VAO<F1E7W!R
M969S)UU;)'1H:7,M/E]S8V]P95TI.PH@("`@("`@("`@("`D7U-%4U-)3TY;
M)VAO<F1E7W!R969S)UU;)U]F:6QL960G72`](&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@<&%R96YT.CIC;&5A;G5P*"1A;&PI.PH@("`@?0H*?0H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+U!R969S+VEM<W`N<&AP````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$P-S<P(#$P-3$U-#,T,3,W(#`R,C$Q,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@4')E9F5R96YC92!S=&]R86=E(&EM<&QE;65N=&%T:6]N(&9O
M<B!A;B!)35-0('-E<G9E<BX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4')E
M9G,O4')E9G,O:6US<"YP:'`L=B`Q+C$N,3`N,3$@,C`P-B\P,B\R."`P-3HU
M.3HQ.2!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@
M36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN<VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!2=6)I;G-K>2`\;7)U8FEN
M<VM`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!(;W)D95]0<F5F<PH@*B\*8VQA
M<W,@4')E9G-?:6US<"!E>'1E;F1S(%!R969S('L*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=&]R(&9U;F-T:6]N+@H@("`@("H@)'!A<F%M<R!M=7-T(&-O
M;G1A:6XZ"B`@("`@*B`G875T:%]M971H;V0G+"`G<V5R=F5R)RP@)W!O<G0G
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'5S97(@("`@(%5S97)N
M86UE(&]F(&-U<G)E;G0@=7-E<BX*("`@("`J($!P87)A;2!S=')I;F<@("1P
M87-S=V]R9"!087-S=V]R9"!F;W(@8W5R<F5N="!U<V5R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@)'-C;W!E("`@(%1H92!S8V]P92!F;W(@=&AE<V4@<')E
M9F5R96YC97,N"B`@("`@*B!`<&%R86T@87)R87D@("`D<&%R86US("`@5&AE
M('!A<F%M971E<G,@;F5E9&5D(&9O<B!T:&ES(&]B:F5C="X*("`@("`J($!P
M87)A;2!B;V]L96%N("1C86-H:6YG("!!<F4@=V4@=7-I;F<@<V5S<VEO;B!C
M86-H93\*("`@("`J+PH@("`@9G5N8W1I;VX@4')E9G-?:6US<"@D=7-E<BP@
M)'!A<W-W;W)D(#T@)R<L("1S8V]P92`]("<G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%R86US(#T@;G5L;"P@)&-A8VAI;F<@/2!T<G5E*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D8V]N9CL*"B`@("`@("`@<&%R96YT.CI0<F5F
M<R@I.PH@("`@("`@(')E<75I<F5?;VYC92`G3F5T+TE-4U`N<&AP)SL*"B`@
M("`@("`@)'1H:7,M/E]S8V]P92`]("1S8V]P93L*("`@("`@("`D=&AI<RT^
M7V-A8VAI;F<@/2`D8V%C:&EN9SL*("`@("`@("`D=&AI<RT^7W5S97(@/2`D
M=7-E<CL*("`@("`@("`D=&AI<RT^<&%R86US(#T@)'!A<F%M<SL*"B`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R\H7BXJ*4`O)RP@)'5S97(L("1M871C:&5S
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^<&%R86US6R=U<V5R;F%M92==(#T@
M)&UA=&-H97-;,5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/G!A<F%M<ULG=7-E<FYA;64G72`]("1U<V5R.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^<&%R86US6R=P87-S=V]R9"==(#T@)'!A<W-W;W)D.PH@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^<&%R86US6R=S;V-K970G72DI('L*
M("`@("`@("`@("`@)'1H:7,M/G!A<F%M<ULG<V]C:V5T)UT@/2`D<&%R86US
M6R=S;V-K970G72`N("=I;7-P7R<@+B`D=&AI<RT^<&%R86US6R=U<V5R;F%M
M92==("X@)RYS8VLG.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VEM<W`@
M/2`F3F5T7TE-4U`Z.G-I;F=L971O;B@G3W!T:6]N<R<L("1T:&ES+3YP87)A
M;7,I.PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7VEM<W`M/FEN:70H*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"@D<F5S=6QT+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VEM<W`M/G-E=$QO
M9V=E<B@D8V]N9ELG;&]G)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F5S('1H92!R97%U97-T960@<V5T(&]F('!R969E<F5N8V5S(&9R;VT@
M=&AE($E-4U`@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I979E*"D*("`@('L*
M("`@("`@("`O*B!'970@=&AE(&1E9F%U;'1S+B`J+PH@("`@("`@('!A<F5N
M=#HZ<F5T<FEE=F4H*3L*"B`@("`@("`@+RH@1V5T('1H92!S:&%R960@<')E
M9G,@86YD(')E;6]V92!T:&4@<V-O<&4@=F%L=64@9G)O;2!T:&4*("`@("`@
M("`@*B!S=')I;F<N("HO"B`@("`@("`@)&=L;V)A;%]P<F5F<R`]("1T:&ES
M+3Y?:6US<"T^9V5T*"=H;W)D92XJ)RD["B`@("`@("`@:68@*&ES7V$H)&=L
M;V)A;%]P<F5F<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&=L;V)A;%]P<F5F<SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1G;&]B86Q?<')E9G,@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@
M("1N97=+97D@/2!S=')?<F5P;&%C92@G:&]R9&4N)RP@)R<L("1K97DI.PH@
M("`@("`@("`@("!I9B`H)'9A;"`]/2`G+2<I('L*("`@("`@("`@("`@("`@
M("1V86P@/2`D=&AI<RT^9V5T1&5F875L="@D;F5W2V5Y*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<')E9G-;)&YE
M=TME>5TI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T5F%L=64H)&YE
M=TME>2P@)'9A;"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^861D*"1N97=+97DL("1V86PL(%]04D5&7U-(05)%1"D[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($1O;B=T(&9O<F=E="!T
M;R!C;&5A;B!I="X@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y*"1N
M97=+97DL(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("\J($YO=R!T:&4@
M87!P('-P96-I9FEC('!R969S+B`J+PH@("`@("`@("1L;V-A;%]P<F5F<R`]
M("1T:&ES+3Y?:6US<"T^9V5T*"1T:&ES+3Y?<V-O<&4@+B`G+BHG*3L*("`@
M("`@("!I9B`H:7-?82@D;&]C86Q?<')E9G,L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1L;V-A;%]P<F5F<SL*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1L;V-A;%]P<F5F<R!A<R`D:V5Y(#T^("1V86PI
M('L*("`@("`@("`@("`@)&YE=TME>2`]('-T<E]R97!L86-E*"1T:&ES+3Y?
M<V-O<&4@+B`G+B<L("<G+"`D:V5Y*3L*("`@("`@("`@("`@:68@*"1V86P@
M/3T@)RTG*2!["B`@("`@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/F=E=$1E
M9F%U;'0H)&YE=TME>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<')E9G-;)&YE=TME>5TI*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^<V5T5F%L=64H)&YE=TME>2P@)'9A;"D["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^861D*"1N97=+
M97DL("1V86PL(#`I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#
M;&5A;B!T:&4@<')E9BX@*B\*("`@("`@("`@("`@)'1H:7,M/G-E=$1I<G1Y
M*"1N97=+97DL(&9A;'-E*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8V%L;$AO;VMS*"D["B`@("`@("`@)'1H:7,M/F-A8VAE57!D871E*"D["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R
M97,@86QL(&1I<G1Y('!R969S('1O($E-4U`@<V5R=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-T;W)E*"D*("`@('L*("`@("`@("`D9&ER='E?<')E9G,@/2`D=&AI<RT^
M7V1I<G1Y4')E9G,H*3L*("`@("`@("!I9B`H(6-O=6YT*"1D:7)T>5]P<F5F
M<RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D9&ER='E?<')E9G,@87,@)&YA;64I('L*("`@("`@
M("`@("`@)'-C;W!E(#T@)'1H:7,M/F=E=%-C;W!E*"1N86UE*3L*("`@("`@
M("`@("`@)'9A;'5E(#T@)'1H:7,M/F=E=%9A;'5E*"1N86UE*3L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1V86QU92DI('L*("`@("`@("`@("`@("`@("1V
M86QU92`]("<M)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?:6US<"T^<V5T*"1S8V]P92`N("<N)R`N("1N86UE+"`D
M=F%L=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG;F]T:69I8V%T
M:6]N)UTM/G!U<V@H(E1H97)E('=A<R!A('!R;V)L96T@<V%V:6YG('1H92!P
M<F5F<F5N8V5S(BD["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0VQE86X@=&AE('!R968@
M<VEN8V4@:70@=V%S(&IU<W0@<V%V960N("HO"B`@("`@("`@("`@("1T:&ES
M+3YS971$:7)T>2@D;F%M92P@9F%L<V4I.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^8V%C:&55<&1A=&4H*3L*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"GT*``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R
M9&4O24U!4"]!0TP`````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S<@,#(P-#$S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%D;6EN+G!H<```````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S`U,2`Q,#4Q-30S-#$S-R`P
M,C$V-#``(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J(%1H92!)34%07T%D;6EN.CH@8VQA<W,@86QL;W<@
M;6%N86=I;F<@;V8@;6%I;&)O>&5S(&]N($E-05`@<V5R=F5R<RX*("H*("H@
M4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=A9&UI;E]U<V5R)R`@
M("`@(%1H92!N86UE(&]F(&$@=7-E<B!W:71H(&%D;6EN('!R:79I;&5G97,N
M"B`J("`@)V%D;6EN7W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&]F('1H92!A
M9&UI;G-T<F%T;W(N/"]P<F4^"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z
M/'!R93X*("H@("`G:&]S='-P96,G("`@("`@(%1H92!H;W-T;F%M92!O<B!)
M4"!A9&1R97-S(&]F('1H92!S97)V97(N"B`J("`@("`@("`@("`@("`@("`@
M("!$149!54Q4.B`G;&]C86QH;W-T)PH@*B`@("=P;W)T)R`@("`@("`@("`@
M5&AE('-E<G9E<B!P;W)T('1O('=H:6-H('=E('=I;&P@8V]N;F5C="X*("H@
M("`@("`@("`@("`@("`@("`@($E-05`@:7,@9V5N97)A;&QY(#$T,RP@=VAI
M;&4@24U!4"U34TP@:7,@9V5N97)A;&QY(#DY,RX*("H@("`@("`@("`@("`@
M("`@("`@($1%1D%53%0Z(#$T,PH@*B`@("=P<F]T;V-O;"<@("`@("`@5&AE
M(&-O;FYE8W1I;VX@<')O=&]C;VP@*&4N9RX@)VEM87`G+"`G<&]P,R<L("=N
M;G1P)RDN"B`J("`@("`@("`@("`@("`@("`@("!0<F]T;V-O;"!I<R!O;F4@
M;V8@)VEM87`O;F]T;',G("AO<B!O;FQY("=I;6%P)R!I9B!Y;W4*("H@("`@
M("`@("`@("`@("`@("`@(&AA=F4@82!C+6-L:65N="!V97)S:6]N(#(P,#!C
M(&]R(&]L9&5R*2P@)VEM87`O<W-L)RP*("H@("`@("`@("`@("`@("`@("`@
M(&]R("=I;6%P+W-S;"]N;W9A;&ED871E+6-E<G0G("AF;W(@82!S96QF+7-I
M9VYE9`H@*B`@("`@("`@("`@("`@("`@("`@8V5R=&EF:6-A=&4I+@H@*B`@
M("`@("`@("`@("`@("`@("`@1$5&055,5#H@)VEM87`G"B`J("`@)W5S97)H
M:65R87)C:'DG("!4:&4@:&EE<F%R8VAY('=H97)E('5S97(@;6%I;&)O>&5S
M(&%R92!S=&]R960N"B`J("`@("`@("`@("`@("`@("`@("!$149!54Q4.B`G
M=7-E<BXG"B`J("`@)V1S;B<@("`@("`@("`@("!4:&4@9G5L;"!)34%0(&-O
M;FYE8W1I;VX@<W1R:6YG+@H@*B`@("`@("`@("`@("`@("`@("`@268@;F]T
M('!R97-E;G0L('1H:7,@:7,@8G5I;'0@9G)O;2`G:&]S='-P96,G+"`G<&]R
M="<*("H@("`@("`@("`@("`@("`@("`@(&%N9"`G<')O=&]C;VPG('!A<F%M
M971E<G,N/"]P<F4^"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!
M4"]!9&UI;BYP:'`L=B`Q+C4N-BXY(#(P,#8O,#4O,S$@,3DZ,SDZ-#<@<VQU
M<V%R>B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@
M24U!4%]!9&UI;B!["@H@("`@+RHJ"B`@("`@*B!087)A;65T97(@:&%S:"X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A
M<F%M<SL*"B`@("`O*BH*("`@("`J($E-05`@<F5S;W5R8V4N"B`@("`@*@H@
M("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]I;6%P.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!W:71H(&%L;"!N96-E<W-A<GD@
M<&%R86UE=&5R<PH@("`@("HO"B`@("!F=6YC=&EO;B!)34%07T%D;6EN*"1P
M87)A;7,I"B`@("!["B`@("`@("`@)&1E9F%U;'1?<&%R86US(#T@87)R87DH
M"B`@("`@("`@("`@("=H;W-T<W!E8R<@/3X@)VQO8V%L:&]S="<L"B`@("`@
M("`@("`@("=P;W)T)R`]/B`G,30S)RP*("`@("`@("`@("`@)W!R;W1O8V]L
M)R`]/B`G:6UA<"<L"B`@("`@("`@("`@("=U<V5R:&EE<F%R8VAY)R`]/B`G
M=7-E<BXG"B`@("`@("`@*3L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`](&%R
M<F%Y7VUE<F=E*"1D969A=6QT7W!A<F%M<RP@)'!A<F%M<RD["@H@("`@("`@
M("\J($-R96%T92!$4TX@<W1R:6YG+B`J+PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P87)A;7-;)V1S;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG9'-N)UT@/2!S<')I;G1F*"=[)7,Z)60O)7-])RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG:&]S='-P96,G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&]R="==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*3L*("`@("`@("`@("`@)'1H:7,M
M/E]R968@/2`D=&AI<RT^7W!A<F%M<ULG9'-N)UT["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>>RA;7CI=*RDZ*%QD
M*RE<+RA;7GU=*RE]+R<L("1T:&ES+3Y?<&%R86US6R=D<VXG72P@)&UA=&-H
M97,I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P
M96,G72`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W!O<G0G72`]("1M871C:&5S6S)=.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W!R;W1O8V]L)UT@/2`D;6%T8VAE<ULS73L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5F(#T@<W!R:6YT9B@G>R5S.B5D+R5S
M?2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG<')O=&]C;VPG72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T<R!T;R!T:&4@24U!4"!S97)V
M97(@=VET:"!T:&4@<&%R86UE=&5R<R!P87-S960@=&\@=&AE"B`@("`@*B!C
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(')E<V]U<F-E?&]B
M:F5C="`@06X@24U!4"!R97-O=7)C92!O<B!A(%!%05)?17)R;W(@;VX@9F%I
M;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VEM87`I*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?:6UA<"`]($!I;6%P7V]P96XH)'1H:7,M/E]R968L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)V%D;6EN7W5S97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG861M:6Y?<&%S<W=O<F0G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/4%](04Q&
M3U!%3BD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]I;6%P*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEM87`@/2!014%2.CIR86ES945R<F]R*%\H
M(D%U=&AE;G1I8V%T:6]N(&%T($E-05`@<V5R=F5R(&9A:6QE9"XB*2P@)VAO
M<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:6UA<#L*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@82!M86EL8F]X+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UA
M:6QB;W@@("`@("!4:&4@;6%I;&)O>"!N86UE('1O(&%D9"X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9&1-86EL8F]X*"1M86EL8F]X*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M*"1I;6%P(#T@)'1H:7,M/E]C;VYN96-T*"DL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1I;6%P.PH@("`@("`@('T*("`@("`@("!I
M9B`H(4!I;6%P7V-R96%T96UA:6QB;W@H)&EM87`L("1T:&ES+3Y?<F5F("X@
M)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C:'DG72`N("1M86EL8F]X*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAI;6%P7VQA
M<W1?97)R;W(H*2P@)VAO<F1E+G=A<FYI;F<G*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V=R86YT061M:6Y097)M<R@D;6%I;&)O>"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'<F%N="!T:&4@861M:6X@=7-E<B!A
M;&P@<FEG:'1S(&]N('1H92!M86EL8F]X+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UA:6QB
M;W@@("`@("`@=&AE(&YA;64@;V8@=&AE(&UA:6QB;W@@;VX@=VAI8V@@=V4@
M=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!G<F%N
M="!T:&4@<&5R;6ES<VEO;@H@("`@("H@0')E='5R;B!M:7AE9"!4<G5E(&EF
M('-U8V-E<W-F=6PL(&]R(%!%05)?17)R;W(@;VX@9F%I;'5R90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9W)A;G1!9&UI;E!E<FUS*"1M86EL8F]X*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M04-,+G!H<"<["@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@G=7-E<FYA;64G
M(#T^("1T:&ES+3Y?<&%R86US6R=A9&UI;E]U<V5R)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("=P87-S=V]R9"<@/3X@)'1H:7,M/E]P87)A;7-;)V%D
M;6EN7W!A<W-W;W)D)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("=H;W-T
M<W!E8R<@/3X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("=P;W)T)R`]/B`D=&AI<RT^7W!A<F%M<ULG<&]R
M="==+`H@("`@("`@("`@("`@("`@("`@("`@("`G<')O=&]C;VPG(#T^("1T
M:&ES+3Y?<&%R86US6R=P<F]T;V-O;"==*3L*("`@("`@("`D86-L(#T@)DE-
M05!?04-,.CIF86-T;W)Y*"=R9F,R,#@V)RP@)'!A<F%M<RD["B`@("`@("`@
M)')E<W5L="`]("1A8VPM/F-R96%T94%#3"@D=&AI<RT^7W!A<F%M<ULG=7-E
M<FAI97)A<F-H>2==("X@)&UA:6QB;W@L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG861M:6Y?=7-E<B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VPG(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<B<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=S)R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W<G(#T^('1R=64L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:2<@/3X@=')U92P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P)R`]/B!T<G5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V,G
M(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G9"<@/3X@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=A)R`]/B!T<G5E*2D["B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@;6%I;&)O>"X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@;6%I;&)O>"!T;R!D
M96QE=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S
M=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E36%I;&)O>"@D;6%I;&)O>"D*("`@
M('L*("`@("`@("!I9B`H:7-?82@D:6UA<"`]("1T:&ES+3Y?8V]N;F5C="@I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6UA<#L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?9W)A;G1!9&UI;E!E<FUS*"1M
M86EL8F]X*3L*("`@("`@("!I9B`H(4!I;6%P7V1E;&5T96UA:6QB;W@H)&EM
M87`L("1T:&ES+3Y?<F5F("X@)'1H:7,M/E]P87)A;7-;)W5S97)H:65R87)C
M:'DG72`N("1M86EL8F]X*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAI;6%P7VQA<W1?97)R;W(H*2P@)VAO<F1E+G=A<FYI;F<G
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!,:7-T(&%L;"!M86EL8F]X97,N"B`@("`@*@H@("`@("H@
M3F]T92!T:&%T('1H:7,@9&]E<R!N;W0@=V]R:R!O;B!A('9I<G1U86PM9&]M
M86EN(&5N86)L960@0WER=7,@*&ET('=I;&P*("`@("`J(&]N;'D@<F5T=7)N
M(&UA:6QB;WAE<R!I;B!T:&4@9&5F875L="!D;VUA:6XI+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1H92!A<G)A>2!O9B!M86EL8F]X97,L(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@;&ES=$UA:6QB;WAE<R@I"B`@("!["B`@("`@("`@:68@*&ES
M7V$H)&EM87`@/2`D=&AI<RT^7V-O;FYE8W0H*2P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EM87`["B`@("`@("`@?0H*("`@("`@
M("`D;&ES="`]($!I;6%P7VQI<W0H)&EM87`L("1T:&ES+3Y?<F5F+"`D=&AI
M<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==("X@)R4G*3L*("`@("`@("!I
M9B`H(21L:7-T*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"<O+BHG("X@<')E
M9U]Q=6]T92@D=&AI<RT^7W!A<F%M<ULG=7-E<FAI97)A<F-H>2==+"`G+R<I
M("X@)R@N*BDO)RP@)UQ<,2<L("1L:7-T*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K('=H971H97(@82!M86EL8F]X(&5X:7-T<RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("`@5&AE(&UA:6QB;W@@=&\@
M8VAE8VLN"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&EF(&UA:6QB;W@@
M97AI<W1S+"!F86QS92!I9B!N;W0L(&]R(&$@4$5!4E]%<G)O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@;6%I;&)O>$5X:7-T<R@D;6%I;&)O>"D*("`@('L*
M("`@("`@("!I9B`H:7-?82@D:6UA<"`]("1T:&ES+3Y?8V]N;F5C="@I+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6UA<#L*("`@
M("`@("!]"@H@("`@("`@("1L:7-T(#T@0&EM87!?;&ES="@D:6UA<"P@)'1H
M:7,M/E]R968L("1T:&ES+3Y?<&%R86US6R=U<V5R:&EE<F%R8VAY)UT@+B`D
M;6%I;&)O>"D["B`@("`@("`@:68@*"1L:7-T(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!C;W5N="@D;&ES="D@/B`P.PH@("`@?0H*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O24U!4"]!
M0TPN<&AP````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3(W,34@,3`U,34T,S0Q,S<@,#(Q,C$Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!#;VYT86EN<R!F
M=6YC=&EO;G,@<F5L871E9"!T;R!M86YA9VEN9PH@*B!!8V-E<W,@0V]N=')O
M;"!,:7-T<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO24U!4"])34%0+T%#
M3"YP:'`L=B`Q+C(N,3(N,3`@,C`P-B\P,B\P,R`P,SHP-SHU-R!S96QS:WD@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:')I<R!(87-T:64@
M/&EM<$!O86LM=V]O9"YC;RYU:SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H<FES($AA<W1I92`\:6UP0&]A:RUW;V]D+F-O+G5K/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA
M<W,@24U!4%]!0TP@>PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG
M(&-O;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*B!";V]L96%N(&EN9&EC871I;F<@:68@=&AE(&1R:79E<B!I
M<R!S=7!P;W)T960@8GD@=&AE('-E<G9E<@H@("`@("H*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S=7!P;W)T960@/2!F86QS93L*
M"B`@("`O*BH*("`@("`J($%N>2!014%27T5R<F]R('1H870@;V-C=7)E9"!B
M=70@8V]U;&1N)W0@8F4@<F5T=7)N960@9&ER96-T;'DN"B`@("`@*@H@("`@
M("H@0'9A<B!014%27T5R<F]R"B`@("`@*B\*("`@('9A<B`D7V5R<F]R(#T@
M;G5L;#L*"B`@("`O*BH*("`@("`J($AA<V@@8V]N=&%I;FEN9R!T:&4@;&ES
M="!O9B!P;W-S:6)L92!R:6=H=',@86YD(&$@:'5M86X*("`@("`J(')E861A
M8FQE(&1E<V-R:7!T:6]N(&]F(&5A8V@*("`@("`J"B`@("`@*B!!<G)A>2`H
M"B`@("`@*B`@("`@<FEG:'0M:60@/3X@<FEG:'0M9&5S8W)I<'1I;VX*("`@
M("`J("D*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7W)I9VAT<TQI<W0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@07)R
M87D@8V]N=&%I;FEN9R!U<V5R(&YA;65S('1H870@8V%N;F]T(&AA=F4@=&AE
M:7(@86-C97-S"B`@("`@*B!R:6=H=',@8VAA;F=E9"X*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?<')O=&5C=&5D.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;7,@($AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-05!?04-,*"1P
M87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US
M(#T@)'!A<F%M<SL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(')E=')I979E('1H92!E>&ES=&EN9R!!0TP@9F]R(&$@9F]L9&5R(&9R;VT*
M("`@("`J('1H92!C=7)R96YT($E-05`@<V5R=F5R+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@9F]L9&5R("!4:&4@9F]L9&5R('1O(&=E="!T:&4@
M04-,(&9O<@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!C
M;VYT86EN:6YG(&EN9F]R;6%T:6]N(&]N('1H92!!0TP*("`@("`J("`@("`@
M("`@("`@("`@($%R<F%Y("@*("`@("`J("`@("`@("`@("`@("`@("`@("!U
M<V5R(#T^($%R<F%Y("@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R:6=H="`]/B`Q"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I"B`@("`@*B`@("`@("`@("`@("`@("`I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$%#3"@D9F]L9&5R*0H@("`@>PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE($%#3"!O
M;B!A;B!)34%0('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&9O;&1E<B`@5&AE(&9O;&1E<B!O;B!W:&EC:"!T;R!E9&ET('1H92!!0TP*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R95]U<V5R("!4:&4@
M=7-E<B!T;R!G<F%N="!R:6=H=',@=&\*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&%C;"`@06X@87)R87DL('1H92!K97ES(&]F('=H:6-H(&%R92!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("!R:6=H=',@=&\@8F4@9W)A
M;G1E9"`H<V5E(%)&0R`R,#@V*0H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92!U;FQE<W,*
M("`@("`J("`@("`@("`@("`@("`@('-E<G9E<B!D;V5S;B=T('-U<'!O<G0@
M04-,<RP@<F5T=7)N<R`G;F]?<W5P<&]R="<*("`@("`J+PH@("`@9G5N8W1I
M;VX@8W)E871E04-,*"1F;VQD97(L("1S:&%R95]U<V5R+"`D86-L*0H@("`@
M>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M($5D:71S(&%N($%#3"!O;B!A;B!)34%0('-E<G9E<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!O;B!W:&EC:"!T
M;R!E9&ET('1H92!!0TP*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M:&%R95]U<V5R("!4:&4@=7-E<B!T;R!G<F%N="!R:6=H=',@=&\*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)&%C;"`@06X@87)R87DL('1H92!K97ES
M(&]F('=H:6-H(&%R92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("!R
M:6=H=',@=&\@8F4@9W)A;G1E9"`H<V5E(%)&0R`R,#@V*0H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@
M9F%I;'5R92!U;FQE<W,*("`@("`J("`@("`@("`@("`@("`@('-E<G9E<B!D
M;V5S;B=T('-U<'!O<G0@04-,<RP@<F5T=7)N<R`G;F]?<W5P<&]R="<*("`@
M("`J+PH@("`@9G5N8W1I;VX@961I=$%#3"@D9F]L9&5R+"`D<VAA<F5?=7-E
M<BP@)&%C;"D*("`@('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#86X@82!U<V5R(&5D:70@=&AE($%#3"!F;W(@=&AI
M<R!F;VQD97(_(%)E='5R;G,@=')U92!I9B`D=7-E<@H@("`@("H@<&5R;6ES
M<VEO;B!T;R!E9&ET('1H92!!0TP@;VX@)&9O;&1E<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E<B!N86UE"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@02!U<V5R(&YA;64*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@)'5S97(@:&%S
M("=A)R!R:6=H=`H@("`@("HO"B`@("!F=6YC=&EO;B!C86Y%9&ET*"1F;VQD
M97(L("1U<V5R*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%)I9VAT<R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<FEG:'1S3&ES=#L*("`@('T*"B`@("!F=6YC=&EO;B!G9710
M<F]T96-T960H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!R;W1E
M8W1E9#L*("`@('T*"B`@("!F=6YC=&EO;B!I<U-U<'!O<G1E9"@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W5P<&]R=&5D.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$5R<F]R*"D*("`@('L*("`@("`@("`D97)R;W(@/2`D
M=&AI<RT^7V5R<F]R.PH@("`@("`@("1T:&ES+3Y?97)R;W(@/2!N=6QL.PH@
M("`@("`@(')E='5R;B`D97)R;W(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M='1E;7!T<R!T;R!R971U<FX@86X@04-,(&EN<W1A;F-E(&)A<V5D(&]N("1D
M<FEV97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I=F5R("!4
M:&4@='EP92!O9B!C;VYC<F5T92!!0TP@<W5B8VQA<W,@=&\@<F5T=7)N+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R<R!A('-U
M8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE(&YE=VQY(&-R96%T960@8V]N8W)E=&4@04-,(&EN<W1A;F-E+"!O
M<B!F86QS90H@("`@("H@("`@("`@("`@("`@("`@;VX@97)R;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1D<FEV97(L("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@("1D<FEV97(@/2!B87-E;F%M92@D9')I
M=F5R*3L*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+T%#3"\G("X@)&1R:79E<B`N("<N<&AP)SL*("`@("`@("`D8VQA<W,@
M/2`G24U!4%]!0TQ?)R`N("1D<FEV97(["B`@("`@("`@:68@*&-L87-S7V5X
M:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1A8VP@/2`F;F5W("1C;&%S
M<R@D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D86-L
M(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&%C;#L*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R
M96YC92!T;R!A(&-O;F-R971E($%#3"!I;G-T86YC90H@("`@("H@8F%S960@
M;VX@)&1R:79E<BX@($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N
M8V4@:68@;F\*("`@("`J($%#3"!I;G-T86YC92!W:71H('1H92!S86UE('!A
M<F%M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!M=7-T(&)E(&EN=F]K960@87,Z("1V87(@/2`F24U!4%]!0TPZ
M.G-I;F=L971O;B@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9')I
M=F5R("!4:&4@='EP92!O9B!C;VYC<F5T92!!0TP@<W5B8VQA<W,@=&\@<F5T
M=7)N+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@("!!(&AA<V@@8V]N
M=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R86UE=&5R
M<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5&AE(&-R96%T960@8V]N8W)E=&4@04-,(&EN<W1A;F-E+"!O
M<B!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L
M971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("!S=&%T:6,@)&EN<W1A;F-E<SL*"B`@("`@("`@:68@*"%I<W-E="@D:6YS
M=&%N8V5S*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S(#T@87)R87DH*3L*
M("`@("`@("!]"@H@("`@("`@("1S:6=N871U<F4@/2!S97)I86QI>F4H87)R
M87DH)&1R:79E<BP@)'!A<F%M<RDI.PH@("`@("`@(&EF("@A:7-S970H)&EN
M<W1A;F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@("`@("`@)&EN<W1A;F-E
M<ULD<VEG;F%T=7)E72`]("9)34%07T%#3#HZ9F%C=&]R>2@D9')I=F5R+"`D
M<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YS=&%N8V5S
M6R1S:6=N871U<F5=.PH@("`@?0H*?0H`````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O24U!4"]396%R8V@N<&AP````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#$S,#$@,3`U,34T,S0Q,S<@,#(R
M,#$P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!4:&4@24U!4%]396%R8V@Z.B!C;&%S<R!P97)F;W)M
M<R!C;VUP;&5X('-E87)C:&EN9R!O9B!A;B!)34%0(&UA:6QB;W@N"B`J"B`J
M($-L87-S97,@=&\@:&5L<"!W:71H(&-O;7!L97@@<V5A<F-H:6YG(&]F(&%N
M($E-05`@;6%I;&)O>"X@(%1H92!B=6EL="UI;@H@*B!02%`@<V5A<F-H*"D@
M9G5N8W1I;VX@;VYL>2!A;&QO=W,@24U!4'8R('-E87)C:"!Q=65R:65S("AS
M964@4D9#(#$Q-S8I+@H@*B!4:&ES(&QI8G)A<GD@86QL;W=S(&UO<F4@8V]M
M<&QE>"!S96%R8VAE<R!T;R!B92!C<F5A=&5D("AE+F<N($]2('-E87)C:&5S
M+`H@*B!S96%R8VAI;F<@<W!E8VEF:6,@:&5A9&5R<RDN"B`J"B`J("1(;W)D
M93H@9G)A;65W;W)K+TE-05`O24U!4"]396%R8V@N<&AP+'8@,2XR.2XQ,"XR
M-2`R,#`V+S`V+S`V(#$U.C0T.C(W('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG
M=V]R;2YC;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A'4$PI+B!)9B!Y
M;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U
M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!
M4`H@*B\*8VQA<W,@24U!4%]396%R8V@@>PH*("`@("\J*@H@("`@("H@5&AE
M(&AE861E<G,@8V%C:&4N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]H96%D97)S(#T@87)R87DH*3L*"B`@("`O*BH*("`@
M("`J(%1H92!R97-U;'1S(&-A8VAE+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?<F5S=6QT(#T@87)R87DH*3L*"B`@("`O
M*BH*("`@("`J(%1H92!P87)A;6%T97(@;&ES="X*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8VAA<G-E="!O9B!T:&4@<V5A<F-H('9A
M;'5E<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]C:&%R<V5T.PH*("`@("\J*@H@("`@("H@26YT97)N86P@9FQA9R!U
M<V5D(&)Y('-E87)C:$UA:6QB;W@H*2X*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1?<V5A<F-H9FQA9R`](#`["@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G;&]B86P@
M24U!4%]396%R8V@@;V)J96-T+"!O;FQY(&-R96%T:6YG(&ET"B`@("`@*B!I
M9B!I="!D;V5S;B=T(&%L<F5A9'D@97AI<W0N"B`@("`@*@H@("`@("H@5&AI
M<R!M971H;V0@;75S="!B92!I;G9O:V5D(&%S.CQC;V1E/@H@("`@("H@("`D
M:6UA<%]S96%R8V@@/2`F24U!4%]396%R8V@Z.G-I;F=L971O;B@I.SPO8V]D
M93X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@06YY('!A
M<F%M971E<G,@=&AE(&-O;G-T<G5C=&]R(&UA>2!N965D+@H@("`@("H*("`@
M("`J($!R971U<FX@24U!4%]396%R8V@@(%1H92!)34%07U-E87)C:"!I;G-T
M86YC92X*("`@("`J+PH@("`@9G5N8W1I;VX@)G-I;F=L971O;B@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=&%T:6,@)&]B:F5C=#L*"B`@
M("`@("`@:68@*"%I<W-E="@D;V)J96-T*2D@>PH@("`@("`@("`@("`D;V)J
M96-T(#T@;F5W($E-05!?4V5A<F-H*"1P87)A;7,I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1O8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M
M<R`@02!H87-H(&-O;G1A:6YI;F<@=&AE(&9O;&QO=VEN9R!E;G1R:65S.CQP
M<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@)W!O<#,G(#T^(&)O
M;VQE86X@*'5S:6YG(%!/4#,@8V]N;F5C=&EO;C\I"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@)V-H87)S970G(#T^('-T<FEN9R`H8VAA<G-E="!O
M9B!S96%R8V@@=F%L=65S*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("=N;U]I;6%P7W-E87)C:"<@/3X@=')U92!I9B!T:&4@24U!4"!S97)V97(@
M9&]E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@;F]T('-U<'!O<G0@=&AE(&-H87)S970@:6X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!S
M96%R8V@@8V]M;6%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(#PO
M<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U-E87)C:"@D<&%R86US
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P
M87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!M97-S86=E
M<R!B>2!!3$P@:&5A9&5R<R`H<F%T:&5R('1H86X@=&AE(&QI;6ET960@<V5T
M('!R;W9I9&5D"B`@("`@*B!B>2!I;6%P7W-E87)C:"@I*2X*("`@("`J"B`@
M("`@*B!`<&%R86T@24U!4%]396%R8VA?475E<GD@)'%U97)Y("!4:&4@<V5A
M<F-H('%U97)Y+@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1I;6%P("`@("`@
M("`@("`@06X@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1M8F]X("`@("`@("`@("`@("!4:&4@;F%M92!O9B!T:&4@;6%I
M;&)O>"!T;R!S96%R8V@N($9O<@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4$]0,RP@=&AI<R!S:&]U;&0@8F4@96UP='DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@:6YD:6-E
M<R!T:&%T(&UA=&-H('1H92!S96%R8V@@<G5L97,@:6X@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("!C=7)R96YT(&UA:6QB;W@N"B`@("`@*B`@("`@("`@
M("`@("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E87)C:$UA:6QB;W@H)'%U97)Y+"`D:6UA<"P@)&UB
M;W@I"B`@("!["B`@("`@("`@+RH@0VAE8VL@9F]R($E-05`@97AT96YS:6]N
M+B`J+PH@("`@("`@(&EF("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=I;6%P
M)RDI('L*("`@("`@("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R
M;W(H(E1H:7,@9G5N8W1I;VX@<F5Q=6ER97,@)VEM87`G('1O(&)E(&)U:6QT
M(&EN=&\@4$A0+B(I+"!?7T9)3$5?7RP@7U],24Y%7U\L(&9A;'-E*3L*("`@
M("`@("!]"@H@("`@("`@("\J($]P96X@=&\@=&AE(&-O<G)E8W0@;6%I;&)O
M>"X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?<&%R86US6R=P;W`S)UTI('L*
M("`@("`@("`@("`@:68@*"%`:6UA<%]R96]P96XH)&EM87`L("1M8F]X+"!/
M4%]214%$3TY,62DI('L*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!#;&5A<B!T
M:&4@<V5A<F-H(&9L86<N("HO"B`@("`@("`@)'1H:7,M/E]S96%R8VAF;&%G
M(#T@,#L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5A<F-H36%I;&)O>"@D
M<75E<GDL("1I;6%P+"`D;6)O>"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3
M96%R8VAE<R!T:&4@;6%I;&)O>"!A;F0@<V]R=',@=&AE(')E<W5L=',N"B`@
M("`@*@H@("`@("H@0'!A<F%M($E-05!?4V5A<F-H7U%U97)Y("1Q=65R>2`@
M5&AE('-E87)C:"!Q=65R>2X*("`@("`J($!P87)A;2!R97-O=7)C92`D:6UA
M<"`@("`@("`@("`@($%N($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;6)O>"`@("`@("`@("`@("`@5&AE(&YA;64@;V8@
M=&AE(&UA:6QB;W@@=&\@<V5A<F-H+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'-O<G1B>2`@("`@("`@("`@5&AE(&-R:71E<FEA('1O('-O<G0@8GD@*'-E
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UA
M<%]S;W)T*"DI+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-O<G1D:7(@("`@
M("`@("`@,2!F;W(@<F5V97)S92!S;W)T:6YG+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@(%1H92!L:7-T(&]F(&EN9&EC97,@=&AA="!M871C:"!T
M:&4@<V5A<F-H(')U;&5S(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@
M8W5R<F5N="!M86EL8F]X(&%N9"!S;W)T960N"B`@("`@*B`@("`@("`@("`@
M("`@("!2971U<FYS(%!%05)?17)R;W(@;VX@97)R;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E87)C:%-O<G1-86EL8F]X*"1Q=65R>2P@)&EM87`L("1M
M8F]X+"`D<V]R=&)Y+"`D<V]R=&1I<B`](#`I"B`@("!["B`@("`@("`@)&EN
M9&EC97,@/2`D=&AI<RT^<V5A<F-H36%I;&)O>"@D<75E<GDL("1I;6%P+"`D
M;6)O>"D["B`@("`@("`@:68@*&ES7V$H)&EN9&EC97,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;F1I8V5S.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1I;F1I8V5S7W-O<G0@/2!`:6UA<%]S;W)T
M*"1I;6%P+"`D<V]R=&)Y+"`D<V]R=&1I<BP@4T5?54E$*3L*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y7W9A;'5E<RAA<G)A>5]I;G1E<G-E8W0H)&EN9&EC
M97-?<V]R="P@)&EN9&EC97,I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!);G1E<FYA;"!W<F%P<&5R(&UE=&AO9"!T;R!I;6%P7W-E87)C
M:"!T:&%T(&%L;&]W<R!C:&%R<V5T(&%W87)E"B`@("`@*B!S96%R8VAE<R!I
M9B!A=F%I;&%B;&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]I;6%P4V5A<F-H*"1I;6%P+"`D8W)I=&5R
M:6$I"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W!A<F%M<ULG
M8VAA<G-E="==*2D@>PH@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P
M87)A;7-;)VYO7VEM87!?8VAA<G-E="==*2`F)@H@("`@("`@("`@("`@("`@
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,RXS)RP@)SX])RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B!`:6UA<%]S96%R8V@H)&EM87`L
M("1C<FET97)I82P@4T5?54E$+"`D=&AI<RT^7W!A<F%M<ULG8VAA<G-E="==
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C<FET
M97)I82`](%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-R:71E<FEA+"`D=&AI
M<RT^7W!A<F%M<ULG8VAA<G-E="==+"`G55,M05-#24DG*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N($!I;6%P7W-E87)C:"@D
M:6UA<"P@)&-R:71E<FEA+"!315]5240I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@26YT97)N86P@9G5N8W1I;VX@=&\@<V5A<F-H('1H92!M86EL8F]X+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<V5A<F-H36%I;&)O>"@D<75E<GDL("1I;6%P+"`D;6)O>"D*("`@
M('L*("`@("`@("`D:6YD:6-E<R`](&%R<F%Y*"D["@H@("`@("`@("1T:&ES
M+3Y?<V5A<F-H9FQA9R`](#`["@H@("`@("`@("\J($1O('1H92!S:6UP;&4@
M<V5A<F-H97,@=&AA="!I;6%P7W-E87)C:"@I(&-A;B!H86YD;&4N("HO"B`@
M("`@("`@:68@*"@D;V(@/2`D<75E<GDM/F)U:6QD*"DI*2!["B`@("`@("`@
M("`@(&EF("@D;V(M/FYO="D@>PH@("`@("`@("`@("`@("`@:68@*"$H)&EN
M9&EC97,Q(#T@)'1H:7,M/E]I;6%P4V5A<F-H*"1I;6%P+"`D;V(M/F9L86=S
M*2DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<S$@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"$H)&EN
M9&EC97,R(#T@)'1H:7,M/E]I;6%P4V5A<F-H*"1I;6%P+"`D;V(M/G%U97)Y
M*2DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<S(@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&EN9&EC97,@
M/2!A<G)A>5]D:69F*"1I;F1I8V5S,2P@)&EN9&EC97,R*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@A*"1I;F1I8V5S(#T@
M)'1H:7,M/E]I;6%P4V5A<F-H*"1I;6%P+"`D;V(M/F9U;&QQ=65R>2DI*2![
M"B`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!3
M970@=&AE('-E87)C:"!F;&%G+B`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]S96%R8VAF;&%G(#T](#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V5A<F-H9FQA9R`](#$["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\J(%!R;V-E<W,@97AT96YD960@<V5A<F-H97,N("HO"B`@("`@("`@
M:68@*"@D97AT96YD960@/2`D<75E<GDM/F5X=&5N9&5D4V5A<F-H*"DI*2![
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W-E87)C:%!(4"@D97AT
M96YD960L("1Q=65R>2T^9FQA9W,H*2P@)&EM87`L("1M8F]X*3L*("`@("`@
M("`@("`@+RH@4V5T('1H92!S96%R8V@@9FQA9RX@*B\*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2!["B`@("`@("`@("`@("`@
M("`D:6YD:6-E<R`]("1R97-U;'0["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-E87)C:&9L86<@/2`Q.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&EN9&EC97,@/2!A<G)A>5]V86QU97,H87)R87E?:6YT97)S
M96-T*"1I;F1I8V5S+"`D<F5S=6QT*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@("\J(%!R;V-E<W,@<VEZ92!S96%R8VAE<RX@*B\*("`@
M("`@("!I9B`H*"1S:7IE3V(@/2`D<75E<GDM/G-I>F5396%R8V@H*2DI('L*
M("`@("`@("`@("`@)&]V97)V:65W(#T@0&EM87!?9F5T8VA?;W9E<G9I97<H
M)&EM87`L(&EM<&QO9&4H)RPG+"`D:6YD:6-E<RDL($947U5)1"D["B`@("`@
M("`@("`@("1F=6YC(#T@8W)E871E7V9U;F-T:6]N*"<D82<L("=R971U<FX@
M*"1A("<@+B`D<VEZ94]B+3YS:7IE;W`@+B`G("<@+B`D<VEZ94]B+3YS:7IE
M("X@)RD[)RD["B`@("`@("`@("`@("1R97-U;'0@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W)E86-H("@D;W9E<G9I97<@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@:68@*"1F=6YC*"1V86PM/G-I>F4I*2!["B`@("`@("`@("`@
M("`@("`@("`@)')E<W5L=%M=(#T@)'9A;"T^=6ED.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-E
M87)C:&9L86<@/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S96%R
M8VAF;&%G(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D:6YD:6-E
M<R`](&%R<F%Y7W9A;'5E<RAA<G)A>5]I;G1E<G-E8W0H)&EN9&EC97,L("1R
M97-U;'0I*3L*("`@("`@("!]"@H@("`@("`@("\J(%!R;V-E<W,@04Y$('-E
M87)C:&5S(&YO=RX@*B\*("`@("`@("`D:6YD:6-E<R`]("1T:&ES+3Y?9&]!
M;F1/<E-E87)C:"@D<75E<GDM/F%N9%-E87)C:"@I+"`D:6UA<"P@)&UB;W@L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%N
M9"<L("1I;F1I8V5S*3L*"B`@("`@("`@+RH@4')O8V5S<R!/4B!S96%R8VAE
M<R!N;W<N("HO"B`@("`@("`@)&EN9&EC97,@/2`D=&AI<RT^7V1O06YD3W)3
M96%R8V@H)'%U97)Y+3YO<E-E87)C:"@I+"`D:6UA<"P@)&UB;W@L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]R)RP@)&EN
M9&EC97,I.PH*("`@("`@("!R971U<FX@)&EN9&EC97,["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!);G1E<FYA;"!F=6YC=&EO;B!T;R!S96%R8V@@=&AE(&UA
M:6QB;W@N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]D;T%N9$]R4V5A<F-H*"1Q=65R>2P@)&EM87`L("1M
M8F]X+"`D;6]D92P@)&EN9&EC97,L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8F%S92`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D:6YD:6-E<SL*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1Q=65R>2!A<R`D=F%L*2!["B`@("`@
M("`@("`@(&EF("AI<U]A*"1V86PL("=)34%07U-E87)C:%]1=65R>2<I*2![
M"B`@("`@("`@("`@("`@("`D<')E=G-E87)C:"`]("AE;7!T>2@D:6YD:6-E
M<RD@)B8@*"1T:&ES+3Y?<V5A<F-H9FQA9R`]/2`P*2D["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/E]S96%R8VA-86EL8F]X*"1V86PL("1I
M;6%P+"`D;6)O>"D["B`@("`@("`@("`@("`@("!I9B`H)&UO9&4@/3T@)V%N
M9"<I('L*("`@("`@("`@("`@("`@("`@("`O*B!)9B!T:&4@<F5S=6QT(&ES
M(&5M<'1Y(&EN(&%N($%.1"!S96%R8V@L('=E(&MN;W<@=&AA=`H@("`@("`@
M("`@("`@("`@("`@("`@('1H92!E;G1I<F4@04Y$('-E87)C:"!W:6QL(&)E
M(&5M<'1Y('-O(')E='5R;@H@("`@("`@("`@("`@("`@("`@("`@(&EM;65D
M:6%T96QY+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@
M("\J($EF('=E(&AA=F4@<F5A8VAE9"!T:&ES('!O:6YT+"!A;F0@:&%V92!N
M;W0@<&5R9F]R;65D(&$*("`@("`@("`@("`@("`@("`@("`@("!S96%R8V@@
M>65T+"!W92!M=7-T('5S92!T:&4@<F5S=6QT<R!A<R!T:&4@:6YD:6-E<PH@
M("`@("`@("`@("`@("`@("`@("`@(&QI<W0N(%=I=&AO=70@=&AI<R!C:&5C
M:RP@=&AE(&EN9&EC97,@;&ES="!W:6QL(&%L=V%Y<PH@("`@("`@("`@("`@
M("`@("`@("`@(&)E(&5M<'1Y(&EF(&%N($%.1"!S96%R8V@@:7,@=&AE(&9I
M<G-T('-E87)C:"X@*B\*("`@("`@("`@("`@("`@("`@("!I9B`H)'!R979S
M96%R8V@I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN9&EC97,@/2`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-E87)C
M:&9L86<@/2`Q.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F1I8V5S(#T@87)R87E?=F%L=65S*&%R
M<F%Y7VEN=&5R<V5C="@D:6YD:6-E<RP@)')E<W5L="DI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@A96UP='DH
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("`D:6YD:6-E<R`](&%R
M<F%Y7W5N:7%U92AA<G)A>5]M97)G92@D:6YD:6-E<RP@)')E<W5L="DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&EN9&EC97,@/2`D=&AI<RT^7V1O06YD3W)396%R8V@H)'9A
M;"P@)&EM87`L("1M8F]X+"`D;6]D92P@)&EN9&EC97,I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&EN9&EC97,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!5<V5S(%!(4"!B87-E9"!F=6YC=&EO;G,@=&\@
M<&5R9F]R;2!T:&4@<V5A<F-H+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=&1#;&%S<R`D:6UA<%]Q=65R
M>2`@4V5A<F-H('%U97)Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FQA9W,@
M("`@("`@("!!;GD@861D:71I;VYA;"!F;&%G<RX*("`@("`J($!P87)A;2!R
M97-O=7)C92`D:6UA<"`@("`@("`@06X@24U!4"!R97-O=7)C92!S=')E86TN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1M8F]X("`@("`@("`@(%1H92!N86UE
M(&]F('1H92!S96%R8V@@;6%I;&)O>"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!4:&4@;&ES="!O9B!I;F1I8V5S('1H870@;6%T8V@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]S96%R8VA02%`H)&EM87!?<75E<GDL("1F;&%G
M<RP@)&EM87`L("1M8F]X*0H@("`@>PH@("`@("`@("1I;F1I8V5S(#T@87)R
M87DH*3L*"B`@("`@("`@:68@*&5M<'1Y*"1F;&%G<RDI('L*("`@("`@("`@
M("`@)&9L86=S(#T@)T%,3"<["B`@("`@("`@?0H*("`@("`@("!I9B`H(65M
M<'1Y*"1T:&ES+3Y?<&%R86US6R=P;W`S)UTI*2!["B`@("`@("`@("`@("1M
M8F]X(#T@)U!/4#,G.PH@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VME>2`]
M("1M8F]X("X@)WPG("X@)&9L86=S.PH*("`@("`@("`O*B!792!H879E('1O
M('5S92!P87)S94U)345(96%D97)S*"D@=&\@9V5T(&5A8V@@:&5A9&5R(&%N
M9"!S964@:68@86YY"B`@("`@("`@("H@9FEE;&0@;6%T8VAE<RX@57-E(&EM
M87!?<V5A<F-H*"D@=&\@9V5T('1H92!L:7-T(&]F(&UE<W-A9V4@:6YD:6-E
M<PH@("`@("`@("`J(&]R(')E='5R;B!E;7!T>2!L:7-T(&EF(&YO('-E87)C
M:"!R97-U;'1S+B`J+PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R97-U
M;'1;)&-A8VAE7VME>5TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5S=6QT
M6R1C86-H95]K97E=(#T@0&EM87!?<V5A<F-H*"1I;6%P+"`D9FQA9W,L(%-%
M7U5)1"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!E;7!T>2!M97-S86=E
M(&QI<W0L(')E='5R;B!N;W<N("HO"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES
M+3Y?<F5S=6QT6R1C86-H95]K97E=*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(&EN8VQU9&5?;VYC92`G2&]R
M9&4O34E-12]3=')U8W1U<F4N<&AP)SL*"B`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7VAE861E<G-;)&UB;WA=*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VAE861E<G-;)&UB;WA=(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@
M("\J($=E="!T:&4@:&5A9&5R+W%U97)Y('1O('-E87)C:"!F;W(N("HO"B`@
M("`@("`@)'%U97)Y(#T@<F5S970H)&EM87!?<75E<GDM/G%U97)Y*3L*("`@
M("`@("`D:V5Y(#T@<W1R=&]L;W=E<BAK97DH)&EM87!?<75E<GDM/G%U97)Y
M*2D["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F5S=6QT6R1C86-H95]K
M97E=(&%S("1I;F1E>"D@>PH@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?:&5A9&5R<ULD;6)O>%U;)&EN9&5X72DI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:&5A9&5R<ULD;6)O>%U;)&EN9&5X72`]($U)345?4W1R=6-T
M=7)E.CIP87)S94U)345(96%D97)S*$!I;6%P7V9E=&-H:&5A9&5R*"1I;6%P
M+"`D:6YD97@L($947U5)1"DL(&YU;&PL('1R=64I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1H(#T@)B1T:&ES+3Y?:&5A9&5R<ULD;6)O>%U;)&EN
M9&5X73L*"B`@("`@("`@("`@("\J(%=E(&YE960@=&\@9&\@82!C87-E(&EN
M<V5N<VET:79E('-E87)C:"!O;B!T97AT(&)E8V%U<V4L(&9O<@H@("`@("`@
M("`@("`@*B!E>&%M<&QE+"!E+6UA:6P@861D<F5S<V5S(&UA>2!N;W0@8F4@
M8V%U9VAT(&-O<G)E8W1L>0H@("`@("`@("`@("`@*B`H9FEL=&5R:6YG(&9O
M<B!E>&%M<&QE0&5X86UP;&4N8V]M('=I;&P@;F]T(&-A=&-H"B`@("`@("`@
M("`@("`J(&5X06UP;&5`97AA;7!L92YC;VTI+B`J+PH@("`@("`@("`@("`D
M;6%T8VA?<W5C8V5S<R`](&9A;'-E.PH@("`@("`@("`@("!I9B`H:7-S970H
M)&A;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`D:&1R7V%R<F%Y(#T@*&ES
M7V%R<F%Y*"1H6R1K97E=*2D@/R`D:%LD:V5Y72`Z(&%R<F%Y*"1H6R1K97E=
M*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1H9')?87)R87D@87,@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AS=')I<W1R*"1V86PL('-T
M<G9A;"@D<75E<GDI*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&UA=&-H7W-U8V-E<W,@/2!T<G5E.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"@D:6UA
M<%]Q=65R>2T^;F]T("8F("$D;6%T8VA?<W5C8V5S<RD@?'P*("`@("`@("`@
M("`@("`@("@A)&EM87!?<75E<GDM/FYO="`F)B`D;6%T8VA?<W5C8V5S<RDI
M('L*("`@("`@("`@("`@("`@("1I;F1I8V5S6UT@/2`D:6YD97@["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D:6YD:6-E<SL*
M("`@('T*"GT*"B\J*@H@*B!4:&4@24U!4%]396%R8VA?3V)J96-T.CH@8VQA
M<W,@:7,@=7-E9"!T;R!F;W)M=6QA=&4@<75E<FEE<R!T;R!B92!U<V5D('=I
M=&@*("H@=&AE($E-05!?4V5A<F-H.CH@8VQA<W,N"B`J"B`J($!A=71H;W(@
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D
M=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-
M05`*("HO"F-L87-S($E-05!?4V5A<F-H7U%U97)Y('L*"B`@("!V87(@)%]A
M;F0@/2!A<G)A>2@I.PH@("`@=F%R("1?97AT96YD961396%R8V@@/2!A<G)A
M>2@I.PH@("`@=F%R("1?9FQA9W,@/2!A<G)A>2@I.PH@("`@=F%R("1?;F]T
M(#T@9F%L<V4["B`@("!V87(@)%]O<B`](&%R<F%Y*"D["B`@("!V87(@)%]Q
M=65R>2`](&YU;&P["B`@("!V87(@)%]S:7IE(#T@;G5L;#L*("`@('9A<B`D
M7W-I>F5O<"`](&YU;&P["@H@("`@9G5N8W1I;VX@24U!4%]396%R8VA?475E
M<GDH*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;GD@
M97AT96YD960@<V5A<F-H97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X=&5N
M9&5D4V5A<F-H*"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M97AT96YD961396%R8V@I*2!["B`@("`@("`@("`@("1S96%R8V@@/2`F;F5W
M('-T9$-L87-S.PH@("`@("`@("`@("`D<V5A<F-H+3YN;W0@/2`D=&AI<RT^
M7VYO=#L*("`@("`@("`@("`@)'-E87)C:"T^<75E<GD@/2`D=&AI<RT^7V5X
M=&5N9&5D4V5A<F-H.PH@("`@("`@("`@("!R971U<FX@)'-E87)C:#L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!P87)A;65T
M97)S(&9O<B!A('-I>F4@<V5A<F-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M:7IE4V5A<F-H*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D=&AI<RT^
M7W-I>F4I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*
M("`@("`@("`D;V(@/2`F;F5W('-T9$-L87-S.PH@("`@("`@("1O8BT^<VEZ
M92`]("AF;&]A="DD=&AI<RT^7W-I>F4["B`@("`@("`@)&]B+3YS:7IE;W`@
M/2`D=&AI<RT^7W-I>F5O<#L*"B`@("`@("`@<F5T=7)N("1O8CL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86YY($%.1"!S96%R8VAE<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@86YD4V5A<F-H*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]A;F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&%N>2!/4B!S96%R8VAE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;W)3
M96%R8V@H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V]R.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9FQA9W,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&9L86=S*"D*("`@('L*("`@("`@("!R971U<FX@*"AE
M;7!T>2@D=&AI<RT^7V9L86=S*2D@/R`G)R`Z(&EM<&QO9&4H)R`G+"`D=&AI
M<RT^7V9L86=S*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@=&AE
M($E-05`@<V5A<F-H('%U97)Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!B=6EL
M9"@I"B`@("!["B`@("`@("`@)'-E87)C:"`]("9N97<@<W1D0VQA<W,["@H@
M("`@("`@("1S96%R8V@M/FYO="`]("1T:&ES+3Y?;F]T.PH@("`@("`@("1S
M96%R8V@M/F9L86=S(#T@)'1H:7,M/F9L86=S*"D["@H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W%U97)Y*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y
M*"1T:&ES+3Y?;W(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)R<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'-E87)C:"T^<75E<GD@/2`G04Q,
M)SL*("`@("`@("`@("`@)'-E87)C:"T^;F]T(#T@9F%L<V4["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@:68@*"1S96%R8V@M/FYO="`F)B!E;7!T
M>2@D<V5A<F-H+3YF;&%G<RDI('L*("`@("`@("`@("`@("`@("1S96%R8V@M
M/F9L86=S(#T@)T%,3"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'-E
M87)C:"T^<75E<GD@/2`D=&AI<RT^7W%U97)Y.PH@("`@("`@('T*("`@("`@
M("`D<V5A<F-H+3YF=6QL<75E<GD@/2`H(65M<'1Y*"1S96%R8V@M/F9L86=S
M*2`_("1S96%R8V@M/F9L86=S("X@)R`G(#H@)R<I("X@)'-E87)C:"T^<75E
M<GD["@H@("`@("`@(')E='5R;B`D<V5A<F-H.PH@("`@?0H*("`@("\J($E-
M05`@<V5A<F-H(&UO9&EF:65R<RX@*B\*("`@(&9U;F-T:6]N(%]M;V1I9FEE
M<G,H)&]B+"`D8VUD*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1O8BP@)TE-
M05!?4V5A<F-H7U%U97)Y)RDI('L*("`@("`@("`@("`@)&]B(#T@87)R87DH
M)&]B*3L*("`@("`@("!]"B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^)&-M
M9"P@)&]B*3L*("`@('T*"B`@("!F=6YC=&EO;B!I;6%P06YD*"1O8BD*("`@
M('L*("`@("`@("`D=&AI<RT^7VUO9&EF:65R<R@D;V(L("=?86YD)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@:6UA<$]R*"1O8BD*("`@('L*("`@("`@("`D
M=&AI<RT^7VUO9&EF:65R<R@D;V(L("=?;W(G*3L*("`@('T*"B`@("`O*B!)
M34%0(%-E87)C:"!&;&%G<RX@*B\*("`@("\J(%1H97)E(&ES(&YO(&YE960@
M=&\@<W5P<&]R="!T:&4@2T595T]21"]53DM%65=/4D0@<75E<GD@<VEN8V4@
M=&AE"B`@("`@("!I;F1I=FED=6%L(&ME>7=O<F1S(&AA=F4@:61E;G1I8V%L
M(&9U;F-T:6]N86QI='DN("HO"B`@("!F=6YC=&EO;B!?:6UA<$9L86=S*"1F
M;&%G+"`D8VUD*0H@("`@>PH@("`@("`@("1C;60@/2`H)&9L86<I(#\@)&-M
M9"`Z("=53B<@+B`D8VUD.PH@("`@("`@("1T:&ES+3Y?9FQA9W-;72`]("1C
M;60["B`@("!]"@H@("`@9G5N8W1I;VX@86YS=V5R960H)&9L86<I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=!3E-715)%1"<I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&1E;&5T960H)&9L86<I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I;6%P1FQA9W,H)&9L86<L("=$14Q%5$5$)RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@9FQA9V=E9"@D9FQA9RD*("`@('L*("`@("`@
M("`D=&AI<RT^7VEM87!&;&%G<R@D9FQA9RP@)T9,04='140G*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!S965N*"1F;&%G*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:6UA<$9L86=S*"1F;&%G+"`G4T5%3B<I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(')E8V5N="@D9FQA9RD*("`@('L*("`@("`@("`D=&AI<RT^7VEM87!&
M;&%G<RAT<G5E+"`H*"1F;&%G*2`_("=214-%3E0G(#H@)T],1"<I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!I;6%P3F5W*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VEM87!&;&%G<RAT<G5E+"`G3D57)RD["B`@("!]"@H@("`@+RH@24U!
M4"!(96%D97(@4V5A<F-H+B`J+PH@("`@9G5N8W1I;VX@:&5A9&5R*"1H96%D
M97(L("1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@("`@("`@("1H96%D
M97(@/2!U8V9I<G-T*')T<FEM*"1H96%D97(L("<Z)RDI.PH@("`@("`@("1S
M=&1(9')S(#T@87)R87DH)U1O)RP@)T-C)RP@)T9R;VTG+"`G4W5B:F5C="<I
M.PH@("`@("`@(&EF("@D<75E<GD@(3T@)R<I('L*("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*"1H96%D97(L("1S=&1(9')S*2D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]Q=65R>2`](%-T<FEN9SHZ=7!P97(H)&AE861E<BD@+B`G
M("(G("X@861D<VQA<VAE<R@D<75E<GDI("X@)R(G.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'1E;F1E9%-E87)C
M:%LD:&5A9&5R72`]("1Q=65R>3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D=&AI<RT^7VYO="`]("1N;W0["B`@("`@("`@?0H@("`@?0H*("`@("\J
M($E-05`@1&%T92!396%R8V@N("HO"B`@("!F=6YC=&EO;B!?:6UA<$1A=&4H
M)&1A>2P@)&UO;G1H+"`D>65A<BP@)&-M9"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W%U97)Y(#T@)&-M9"`N("<@)R`N(&1A=&4H(F0M32UY(BP@;6MT:6UE
M*#`L(#`L(#`L("1M;VYT:"P@)&1A>2P@)'EE87(I*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!B969O<F4H)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@('L*("`@
M("`@("`D=&AI<RT^7VEM87!$871E*"1D87DL("1M;VYT:"P@)'EE87(L("="
M149/4D4G*3L*("`@('T*"B`@("!F=6YC=&EO;B!S:6YC92@D9&%Y+"`D;6]N
M=&@L("1Y96%R*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:6UA<$1A=&4H)&1A
M>2P@)&UO;G1H+"`D>65A<BP@)U-)3D-%)RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@;VXH)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@("`D=&AI
M<RT^7VEM87!$871E*"1D87DL("1M;VYT:"P@)'EE87(L("=/3B<I.PH@("`@
M?0H*("`@("\J($E-05`@5&5X="!S96%R8VAE<RX@*B\*("`@(&9U;F-T:6]N
M(&)O9'DH)'%U97)Y+"`D;F]T(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]Q=65R>2`]("="3T19("(G("X@)'%U97)Y("X@)R(G.PH@("`@("`@
M("1T:&ES+3Y?;F]T(#T@)&YO=#L*("`@('T*"B`@("!F=6YC=&EO;B!T97AT
M*"1Q=65R>2P@)&YO="`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<75E<GD@/2`G5$585"`B)R`N("1Q=65R>2`N("<B)SL*("`@("`@("`D=&AI
M<RT^7VYO="`]("1N;W0["B`@("!]"@H@("`@+RH@24U!4"!3:7IE('-E87)C
M:&5S+B`J+PH@("`@9G5N8W1I;VX@<VEZ92@D<VEZ92P@)&]P97)A=&]R*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?<VEZ92`]("1S:7IE.PH@("`@("`@("1T
M:&ES+3Y?<VEZ96]P(#T@)&]P97)A=&]R.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TE-05`O5')E92YP:'``````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,38U-#$S(#$P-3$U
M-#,T,3,W(#`R,34Q-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*B!#;VYS=&%N=',@9F]R(&UA:6QB;WA%;'0@
M871T<FEB=71E<RX*("H@06QL('9E<G-I;VYS(&]F(&,M8VQI96YT("AC+6-L
M:65N="]M86EL+F@I(&1E9FEN92!T:&5S92!C;VYS=&%N=',Z"B`J("`@3$%4
M5%].3TE.1D5224]24R`H;&]N9RD@,'@Q(#T@,0H@*B`@($Q!5%1?3D]314Q%
M0U0@*&QO;F<I(#!X,B`](#(*("H@("!,05147TU!4DM%1"`H;&]N9RD@,'@T
M(#T@-`H@*B`@($Q!5%1?54Y-05)+140@*&QO;F<I(#!X."`](#@*("H*("H@
M3F5W97(@=F5R<VEO;G,@;V8@8RUC;&EE;G0@*&EM87`M,C`P,B!A;F0@9W)E
M871E<BD@9&5F:6YE('1H97-E(&-O;G-T86YT<SH*("H@("!,05147U)%1D52
M4D%,("AL;VYG*2`P>#$P(#T@,38*("H@("!,05147TA!4T-(24Q$4D5.("AL
M;VYG*2`P>#(P(#T@,S(*("H@("!,05147TA!4TY/0TA)3$1214X@*&QO;F<I
M(#!X-#`@/2`V-`H@*B`N+BYB=70@=&AE<V4@8V]N<W1A;G0@;F%M97,@9&\@
M;F]T(&%P<&5A<B!I;B!02%`@=6YT:6P@4$A0(#0N,RXU(&%N9"`U+C`N"B`J
M+PII9B`H(61E9FEN960H)TQ!5%1?2$%30TA)3$1214XG*2D@>PH@("`@0&1E
M9FEN92@G3$%45%]2149%4E)!3"<L(#$V*3L*("`@($!D969I;F4H)TQ!5%1?
M2$%30TA)3$1214XG+"`S,BD["B`@("!`9&5F:6YE*"=,05147TA!4TY/0TA)
M3$1214XG+"`V-"D["GT*"B\J(%-T87)T(&%T(#$R."!F;W(@;W5R(&QO8V%L
M(&)I=&UA<VMS('1O(&%L;&]W(&9O<B!T:&4@8RUC;&EE;G0@3$%45%\J"B`@
M(&-O;G-T86YT<RX@*B\*9&5F:6YE*"=)34%05%)%15]%3%1?2$%37T-(24Q$
M4D5.)RP@,3(X*3L@+R\@1$504D5#051%1`ID969I;F4H)TE-05!44D5%7T5,
M5%])4U]/4$5.)RP@,C4V*3L*9&5F:6YE*"=)34%05%)%15]%3%1?25-?4U5"
M4T-224)%1"<L(#4Q,BD["F1E9FEN92@G24U!4%12145?14Q47TE37T1)4T-/
M5D52140G+"`Q,#(T*3L*9&5F:6YE*"=)34%05%)%15]%3%1?25-?4$],3$5$
M)RP@,C`T."D["F1E9FEN92@G24U!4%12145?14Q47TY%141?4T]25"<L(#0P
M.38I.PHO+R`G.#$Y,B<@:7,@=7-E9"!B>2!)35`@-"YX('-O(&1O(&YO="!U
M<V4@:70@:&5R90ID969I;F4H)TE-05!44D5%7T5,5%].04U%4U!!0T4G+"`Q
M-C,X-"D["@HO*B!4:&4@:7-/<&5N*"D@97AP86YD960@;6]D92!C;VYS=&%N
M=',N("HO"F1E9FEN92@G24U!4%12145?3U!%3E].3TY%)RP@,"D["F1E9FEN
M92@G24U!4%12145?3U!%3E]!3$PG+"`Q*3L*9&5F:6YE*"=)34%05%)%15]/
M4$5.7U5315(G+"`R*3L*"B\J(%=H:6-H(&UO9&4@;V8@24U!4"!A8V-E<W,@
M87)E('=E('5S:6YG+B`J+PID969I;F4H)TE-05!44D5%7TU/1$5?34%)3"<L
M(#`I.PID969I;F4H)TE-05!44D5%7TU/1$5?3D574R<L(#$I.PH*+RH@5&AE
M(&EN:71A;&EZ871I;VX@;6]D92!T;R!U<V4@=VAE;B!C<F5A=&EN9R!T:&4@
M=')E92X@*B\*9&5F:6YE*"=)34%05%)%15])3DE47U-50B<L(#$I.PID969I
M;F4H)TE-05!44D5%7TE.251?54Y354(G+"`R*3L*9&5F:6YE*"=)34%05%)%
M15])3DE47T9%5$-(04Q,)RP@-"D["@HO*B!4:&4@;6%N;F5R('1O('=H:6-H
M('1O('1R879E<G-E('1H92!T<F5E('=H96X@8V%L;&EN9R!N97AT*"DN("HO
M"F1E9FEN92@G24U!4%12145?3D585%]32$]70TQ/4T5$)RP@,2D["F1E9FEN
M92@G24U!4%12145?3D585%]32$]74U5")RP@,BD["@HO*B!4:&4@<W1R:6YG
M('5S960@=&\@:6YD:6-A=&4@=&AE(&)A<V4@;V8@=&AE('1R964N("HO"F1E
M9FEN92@G24U!4%12145?0D%315]%3%0G+"!N=6QL*3L*"B\J*@H@*B!4:&4@
M24U!4%]4<F5E(&-L87-S('!R;W9I9&5S(&$@=')E92!V:65W(&]F('1H92!F
M;VQD97)S('-U<'!O<G1E9"!W:71H"B`J('1H92!02%`@:6UA<"!E>'1E;G-I
M;VX@*$E-05`O4$]0,R].3E10(')E<&]S:71O<FEE<RDN("!)="!P<F]V:61E
M<R!A8V-E<W,*("H@9G5N8W1I;VYS('1O(&ET97)A=&4@=&AR;W5G:"!T:&ES
M('1R964@86YD('%U97)Y(&EN9F]R;6%T:6]N(&%B;W5T"B`J(&EN9&EV:61U
M86P@;6%I;&)O>&5S+V9O;&1E<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TE-05`O24U!4"]4<F5E+G!H<"QV(#$N-#@N,BXT,R`R,#`V+S`U+S$R(#$V
M.C(Y.C(Y('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#`M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0V]P>7)I
M9VAT(#(P,#`M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!#
M;W!Y<FEG:'0@,C`P,"TR,#`V($%N:6P@36%D:&%V87!E9&1Y(#QA=G-M0&AO
M<F1E+F]R9SX*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A
M<GH@/'-L=7-A<GI`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T
M:&]R("!*;VX@4&%R:7-E(#QJ;VY`:&]R9&4N;W)G/@H@*B!`875T:&]R("!!
M;FEL($UA9&AA=F%P961D>2`\879S;4!H;W)D92YO<F<^"B`J($!A=71H;W(@
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95])34%0"B`J+PIC;&%S
M<R!)34%07U1R964@>PH*("`@("\J*@H@("`@("H@07-S;V-I871I=F4@87)R
M87D@8V]N=&%I;FEN9R!T:&4@;6%I;&)O>"!T<F5E+@H@("`@("H*("`@("`J
M($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?=')E93L*"B`@("`O*BH*
M("`@("`J($QO8V%T:6]N(&]F(&-U<G)E;G0@96QE;65N="!I;B!T:&4@=')E
M92X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]C=7)R<&%R96YT(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($QO8V%T:6]N
M(&]F(&-U<G)E;G0@96QE;65N="!I;B!T:&4@=')E92X*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1?8W5R<FME>2`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!,;V-A=&EO;B!O9B!C=7)R96YT(&5L96UE
M;G0@:6X@=&AE('1R964N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]C=7)R<W1A8VL@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@4VAO=R!U;G-U8G-C<FEB960@;6%I;&)O>&5S/PH@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]S:&]W=6YS=6(@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J(%!A<F5N="!L:7-T+@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?<&%R96YT(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!C86-H960@;&ES="!O9B!M
M86EL8F]X97,@=&\@<&]L;"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D7W!O;&P@/2!N=6QL.PH*("`@("\J*@H@("`@("H@
M5&AE(&-A8VAE9"!L:7-T(&]F(&5X<&%N9&5D(&9O;&1E<G,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]E>'!A;F1E9"`]
M(&YU;&P["@H@("`@+RHJ"B`@("`@*B!#86-H960@;&ES="!O9B!S=6)S8W)I
M8F5D(&UA:6QB;WAE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7W-U8G-C<FEB960@/2!N=6QL.PH*("`@("\J*@H@("`@
M("H@0V%C:&5D(&QI<W0@;V8@=6YS=6)S8W)I8F5D(&UA:6QB;WAE<RX*("`@
M("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W5N<W5B
M<V-R:6)E9"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!);FET(&UO9&4@9FQA
M9RX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R
M("1?:6YI=&UO9&4@/2`P.PH*("`@("\J*@H@("`@("H@5')E92!C:&%N9V5D
M(&9L86<N("!3970@=VAE;B!S;VUE=&AI;F<@:6X@=&AE('1R964@:&%S(&)E
M96X@86QT97)E9"X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1?8VAA;F=E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M2&%V92!W92!S:&]W;B!U;G-U8G-C<FEB960@9F]L9&5R<R!P<F5V:6]U<VQY
M/PH@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@
M)%]U;G-U8G9I97<@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!)34%0
M7U-O<G0@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@24U!4%]3;W)T"B`@
M("`@*B\*("`@('9A<B`D7VEM87!?<V]R="`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*B!);G-E<G0@86X@96QE;65N="!I;B!T:&4@=')E92!T:&%T(&1O97-N
M)W0@87!P96%R(&]N('1H92!)34%0('-E<G9E<BX*("`@("`J($EF('-E="P@
M24U!4%]4<F5E.CH@=VEL;"!C86QL(%]G971.;VY)34%016QT*"D@=&\@;V)T
M86EN('1H92!E;&5M96YT"B`@("`@*B!T;R!A9&0@=&\@=&AE('1R964N"B`@
M("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*("`@('9A<B`D7VYO
M;FEM87!E;'0@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%1H92!N86UE('1O
M('5S92!W:&5N('-T;W)I;F<@=&AE(&]B:F5C="!I;B!T:&4@<V5S<VEO;BX*
M("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]C
M86-H96YA;64["@H@("`@+RHJ"B`@("`@*B!4:&4@87!P;&EC871I;VX@=&AA
M="!G96YE<F%T960@=&AI<R!T<F5E+@H@("`@("H@5$A)4R!32$]53$0@0D4@
M4T54($E.($5615)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%P<"`](&YU;&P[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@<V5R=F5R('-T<FEN9R!F;W(@=&AE(&-U
M<G)E;G0@<V5R=F5R+@H@("`@("H@5$A)4R!32$]53$0@0D4@4T54($E.($56
M15)9(%-50D-,05-3($-/3E-44E5#5$]2+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W-E<G9E<B`]("<G.PH*("`@("\J
M*@H@("`@("H@4VAO=6QD('=E('5S92`G;6%I;"<@;6]D92!O<B`G;F5W<R<@
M;6]D93\*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)3B!%5D5262!354)#
M3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1?;6]D92`](&YU;&P["@H@("`@+RHJ"B`@("`@
M*B!4:&4@;&ES="!O9B!N86UE<W!A8V5S('1O(&%D9"!T;R!T:&4@=')E92X*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7VYA
M;65S<&%C97,["B`@("`O*BH*("`@("`J($1O97,@=&AE($E-05`@<V5R=F5R
M('-U<'!O<G0@=&AE(&-H:6QD<F5N(&5X=&5N<VEO;C\*("`@("`J"B`@("`@
M*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?8VAI;&1R96YS=7!P
M;W)T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%5S960@=&\@9&5T97)M:6YE
M('1H92!L:7-T(&]F(&5L96UE;G0@8VAA;F=E<RX*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5L=&1I9F8@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@<F5F97)E;F-E
M('1O(&$@8V]N8W)E=&4@24U!4%]4<F5E(&EN<W1A;F-E+@H@("`@("H*("`@
M("`J($EF(&%N($E-05!?5')E92!O8FIE8W0@:7,@8W5R<F5N=&QY('-T;W)E
M9"!I;B!T:&4@;&]C86P@<V5S<VEO;BP*("`@("`J(')E8W)E871E('1H870@
M;V)J96-T+B`@16QS92P@:68@)&-R96%T92!I<R!T<G5E+"!W:6QL(&-R96%T
M92!A(&YE=PH@("`@("H@:6YS=&%N8V4N("!%;G-U<F5S('1H870@;VYL>2!O
M;F4@24U!4%]4<F5E(&EN<W1A;F-E(&ES(&%V86EL86)L90H@("`@("H@870@
M86YY('1I;64N"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@;75S="!B92!I
M;G9O:V5D(&%S.CQP<F4^"B`@("`@*B`@("1I;6%P7W1R964@/2`F24U!4%]4
M<F5E.CIS:6YG;&5T;VXH)&%P<"P@)&-L87-S;F%M92P@6R1C<F5A=&5;+"`D
M=6YS=6)=72D[/"]P<F4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M87!P("`@("`@("!4:&4@8W5R<F5N="!A<'!L:6-A=&EO;B!N86UE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8VQA<W-N86UE("!4:&4@8VQA<W,@;F%M92!T
M;R!U<V4@=VAE;B!I;G-T86YT:6%T:6YG(&$@;F5W"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&]B:F5C="X*("`@("`J($!P87)A;2!B;V]L
M96%N("1C<F5A=&4@("`@0W)E871E(&$@;F5W($E-05!?5')E92!I9B!I="!D
M;V5S;B=T(&5X:7-T(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1H92!S97-S:6]N/PH@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN:70@
M("`@("!4:&4@:6YI=&EA;&EZ871I;VX@;6]D92!T;R!U<V4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1C86-H96YA;64@(%1H92!N86UE('1O('5S92!W:&5N
M('-T;W)I;F<@:6X@=&AE('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R
M;B!)34%07U1R964@(%1H92!)34%07U1R964@;V)J96-T(&]R(&YU;&PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&%P<"P@)&-L87-S;F%M
M92P@)&-R96%T92`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YI="`]($E-05!44D5%7TE.251?4U5"+"`D8V%C:&5N86UE(#T@)VEM87!T
M<F5E)RD*("`@('L*("`@("`@("!S=&%T:6,@)&EN<W1A;F-E(#T@87)R87DH
M*3L*"B`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LD87!P72DI('L*("`@
M("`@("`@("`@<F5T=7)N("1I;G-T86YC95LD87!P73L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)%]315-324].6R1A<'!=6R1C86-H96YA;65=
M*2D@>PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-E<W-I;VY/
M8FIE8W1S+G!H<"<["B`@("`@("`@("`@("1C86-H95-E<W,@/2`F2&]R9&5?
M4V5S<VEO;D]B:F5C=',Z.G-I;F=L971O;B@I.PH@("`@("`@("`@("`D:6YS
M=&%N8V5;)&%P<%T@/2`F)&-A8VAE4V5S<RT^<75E<GDH)%]315-324].6R1A
M<'!=6R1C86-H96YA;65=*3L*("`@("`@("`@("`@<F5G:7-T97)?<VAU=&1O
M=VY?9G5N8W1I;VXH87)R87DH)B1I;G-T86YC95LD87!P72P@)U]S=&]R92<I
M*3L*("`@("`@("!](&5L<V5I9B`H)&-R96%T92D@>PH@("`@("`@("`@("`D
M:6YS=&%N8V5;)&%P<%T@/2`F;F5W("1C;&%S<VYA;64H)&EN:70L("1C86-H
M96YA;64I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G-T86YC95LD
M87!P73L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@
M("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;FET("`@("`@5&AE(&EN:71I
M86QI>F%T:6]N(&UO9&4@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V%C:&5N86UE("!4:&4@;F%M92!T;R!U<V4@=VAE;B!S=&]R:6YG(&EN('1H
M92!S97-S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U1R964H)&EN
M:70@/2!)34%05%)%15])3DE47U-50BP@)&-A8VAE;F%M92`]("=I;6%P=')E
M92<I"B`@("!["B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH
M87)R87DH)B1T:&ES+"`G7W-T;W)E)RDI.PH@("`@("`@("1T:&ES+3Y?8V%C
M:&5N86UE(#T@)&-A8VAE;F%M93L*("`@("`@("`D=&AI<RT^:6YI="@D:6YI
M="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A('-E<FEA;&EZ960@
M=F5R<VEO;B!O9B!O=7)S96QF(&EN('1H92!C=7)R96YT('-E<W-I;VXN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S=&]R92@I"B`@("!["B`@("`@("`@+RH@5V4@;VYL>2!N965D('1O
M(')E<W1O<F4@=&AE(&]B:F5C="!I9B!T:&4@=')E92!H87,@8VAA;F=E9"X@
M*B\*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?8VAA;F=E9"DI('L*("`@
M("`@("`@("`@+RH@1&]N)W0@<W1O<F4@)%]E>'!A;F1E9"!A;F0@)%]P;VQL
M("T@=&AE<V4@=F%L=65S(&%R92!H86YD;&5D"B`@("`@("`@("`@("`J(&)Y
M('1H92!S=6)C;&%S<V5S+@H@("`@("`@("`@("`@*B!$;VXG="!S=&]R92`D
M7VEM87!?<V]R="!O<B`D7V5L=&1I9F8@+2!T:&ES(&YE961S('1O(&)E"B`@
M("`@("`@("`@("`J(')E9V5N97)A=&5D(&9O<B!E86-H(')E<75E<W0N"B`@
M("`@("`@("`@("`J($1O;B=T('-T;W)E("1?8W5R<FME>2P@)%]C=7)R<&%R
M96YT+"!A;F0@)%]C=7)R4W1A8VL@<VEN8V4@=&AE"B`@("`@("`@("`@("`J
M('5S97(@35535"!C86QL(')E<V5T*"D@8F5F;W)E(&-Y8VQI;F<@=&AR;W5G
M:"!T:&4@=')E92X*("`@("`@("`@("`@("H@4F5S970@=&AE("1?8VAA;F=E
M9"!F;&%G+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2`D=&AI
M<RT^7V-U<G)P87)E;G0@/2`D=&AI<RT^7V5L=&1I9F8@/2`D=&AI<RT^7V5X
M<&%N9&5D(#T@)'1H:7,M/E]I;6%P7W-O<G0@/2`D=&AI<RT^7W!O;&P@/2!N
M=6QL.PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)3=&%C:R`](&%R<F%Y*"D[
M"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`](&9A;'-E.PH*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]397-S:6]N3V)J96-T<RYP:'`G
M.PH@("`@("`@("`@("`D8V%C:&5397-S(#T@)DAO<F1E7U-E<W-I;VY/8FIE
M8W1S.CIS:6YG;&5T;VXH*3L*"B`@("`@("`@("`@("\J(%)E=7-E(&]L9"!S
M97-S:6]N($E$(&EF('!O<W-I8FQE+B`J+PH@("`@("`@("`@("!I9B`H:7-S
M970H)%]315-324].6R1T:&ES+3Y?87!P75LD=&AI<RT^7V-A8VAE;F%M95TI
M*2!["B`@("`@("`@("`@("`@("`D8V%C:&5397-S+3YO=F5R=W)I=&4H)%]3
M15-324].6R1T:&ES+3Y?87!P75LD=&AI<RT^7V-A8VAE;F%M95TL("1T:&ES
M+"!F86QS92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1?4T534TE/3ELD=&AI<RT^7V%P<%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)%]315-324].6R1T:&ES+3Y?87!P72`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D7U-%4U-)
M3TY;)'1H:7,M/E]A<'!=6R1T:&ES+3Y?8V%C:&5N86UE72`]("1C86-H95-E
M<W,M/G-T;W)E3VED*"1T:&ES+"!F86QS92D["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@;&ES="!O
M9B!F;VQD97)S+VUA:6QB;WAE<R!M871C:&EN9R!A(&-E<G1A:6X@<&%T:"X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!4:&4@;6%I;&)O>"!P871H+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O9B!M86EL8F]X7V]B:F5C
M=',@=VAO<V4@;F%M92!M871C:&5D("1P871H+@H@("`@("H@("`@("`@("`@
M("`@("`@5&AE('-E<G9E<B!S=')I;F<@:&%S(&)E96X@<F5M;W9E9"!F<F]M
M('1H92!N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3&ES="@D<&%T
M:"D*("`@('L*("`@("`@("`D=6YI<75E(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*"$D=&AI<RT^7W-H;W=U;G-U8BD@>PH@("`@("`@("`@("`D=&AI<RT^
M7VEN:713=6)S8W)I8F5D*"D["B`@("`@("`@?0H@("`@("`@("1N97=B;WAE
M<R`]($!I;6%P7V=E=&UA:6QB;WAE<R@D=&AI<RT^7V=E=%-T<F5A;2@I+"`D
M=&AI<RT^7W-E<G9E<BP@)'!A=&@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M;F5W8F]X97,I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1N97=B;WAE<R!A
M<R`D8F]X*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]S:&]W=6YS
M=6(@?'P*("`@("`@("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/E]S=6)S
M8W)I8F5D6R1B;W@M/FYA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("\J
M(%-T<FEP(&]F9B!S97)V97(@<W1R:6YG+B`J+PH@("`@("`@("`@("`@("`@
M("`@("1B;W@@/2`D=&AI<RT^7W)E;6]V95-E<G9E<E-T<FEN9R@D8F]X*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&)O>"T^;F%M92`F)B`A:7-S970H
M)'5N:7%U95LD8F]X+3YN86UE72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'5N:7%U95LD8F]X+3YN86UE72`]("1B;W@["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)'5N:7%U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($UA:V4@82!S:6YG;&4@;6%I;&)O>"!T<F5E(&5L96UE;G0N"B`@
M("`@*B!!;B!E;&5M96YT(&-O;G-I<W1S(&]F('1H92!F;VQL;W=I;F<@:71E
M;7,@*'=E('5S92!S:6YG;&4@;&5T=&5R<R!H97)E"B`@("`@*B!T;R!S879E
M(&EN('-E<W-I;VX@<W1O<F%G92!S<&%C92DZ"B`@("`@*B`@("=A)R`@+2T@
M($%T=')I8G5T97,*("`@("`J("`@)V,G("`M+2`@3&5V96P@8V]U;G0*("`@
M("`J("`@)VPG("`M+2`@3&%B96P*("`@("`J("`@)W`G("`M+2`@4&%R96YT
M(&YO9&4*("`@("`J("`@)W8G("`M+2`@5F%L=64*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T('-T
M9$-L87-S("1O8B`@5&AE(&]B:F5C="!R971U<FYE9"!B>2!I;6%P7V=E=&UA
M:6QB;WAE<R@I+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%-E92!F
M;W)M870@86)O=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]M86ME36%I;&)O
M>%1R965%;'0H)&]B*0H@("`@>PH@("`@("`@("1E;'1;)V$G72`]("1O8BT^
M871T<FEB=71E<SL*("`@("`@("`D96QT6R=C)UT@/2`P.PH@("`@("`@("1E
M;'1;)W`G72`]($E-05!44D5%7T)!4T5?14Q4.PH@("`@("`@("1E;'1;)W8G
M72`]("1O8BT^;F%M93L*"B`@("`@("`@+RH@4V5T('-U8G-C<FEB960@=F%L
M=65S+B!-86ME('-U<F4@24Y"3U@@:7,@86QW87ES('-U8G-C<FEB960*("`@
M("`@("`@*B!T;R`H:68@=V]R:VEN9R!W:71H(&UA:6PI('-O('1H97)E(&ES
M(&%L=V%Y<R!A="!L96%S="`Q"B`@("`@("`@("H@=FEE=V%B;&4@96QE;65N
M="X@*B\*("`@("`@("!I9B`H)&5L=%LG=B==(#T]("=)3D)/6"<I('L*("`@
M("`@("`@("`@)'1H:7,M/E]S9713=6)S8W)I8F5D*"1E;'0L('1R=64I.PH@
M("`@("`@('T@96QS96EF("@A)'1H:7,M/FES4W5B<V-R:6)E9"@D96QT*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7VEN:713=6)S8W)I8F5D*"D["B`@("`@
M("`@("`@("1T:&ES+3Y?<V5T4W5B<V-R:6)E9"@D96QT+"!I<W-E="@D=&AI
M<RT^7W-U8G-C<FEB961;)&5L=%LG=B==72DI.PH@("`@("`@('T*"B`@("`@
M("`@+RH@0VAE8VL@9F]R('!O;&QE9"!S=&%T=7,N("HO"B`@("`@("`@:68@
M*"$D=&AI<RT^:7-0;VQL960H)&5L="DI('L*("`@("`@("`@("`@)'1H:7,M
M/F=E=%!O;&Q,:7-T*"D["B`@("`@("`@("`@("1T:&ES+3Y?<V5T4&]L;&5D
M*"1E;'0L(&ES<V5T*"1T:&ES+3Y?<&]L;%LD96QT6R=V)UU=*2D["B`@("`@
M("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@;W!E;B!S=&%T=7,N("HO"B`@
M("`@("`@)'1H:7,M/E]S971/<&5N*"1E;'0L("1T:&ES+3YI<T]P96XH)&5L
M="DI.PH*("`@("`@("`O*B!#;VUP=71E9"!V86QU97,N("HO"B`@("`@("`@
M)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D96QT6R=V)UTI.PH@
M("`@("`@("1T;7`@/2!E>'!L;V1E*"AI<U]N=6QL*"1N<U]I;F9O*2D@/R`D
M=&AI<RT^7V1E;&EM:71E<B`Z("1N<U]I;F9O6R=D96QI;6ET97(G72P@)&5L
M=%LG=B==*3L*("`@("`@("`D96QT6R=C)UT@/2!C;W5N="@D=&UP*2`M(#$[
M"B`@("`@("`@)&QA8F5L(#T@)&5L=%LG8R==.PH@("`@("`@(&EF("@A96UP
M='DH)&5L=%LG8R==*2`F)@H@("`@("`@("`@("`A<')E9U]M871C:"@B+UQ[
M+BIP;W`S+BI<?2\B+"`D;V(M/F9U;&Q397)V97)0871H*2D@>PH@("`@("`@
M("`@("`D96QT6R=P)UT@/2!I;7!L;V1E*"AI<U]N=6QL*"1N<U]I;F9O*2D@
M/R`D=&AI<RT^7V1E;&EM:71E<B`Z("1N<U]I;F9O6R=D96QI;6ET97(G72P@
M87)R87E?<VQI8V4H)'1M<"P@,"P@)&5L=%LG8R==*2D["B`@("`@("`@("`@
M("\J(%-T<FEP('!E<G-O;F%L(&YA;65S<&%C92X@*B\*("`@("`@("`@("`@
M:68@*"%I<U]N=6QL*"1N<U]I;F9O*2`F)@H@("`@("`@("`@("`@("`@(65M
M<'1Y*"1N<U]I;F9O6R=N86UE)UTI("8F"B`@("`@("`@("`@("`@("`H)&YS
M7VEN9F];)W1Y<&4G72`]/2`G<&5R<V]N86PG*2D@>PH@("`@("`@("`@("`@
M("`@)&5L=%LG8R==+2T["B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1E
M;'1;)W`G72P@)&YS7VEN9F];)V1E;&EM:71E<B==*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@("`@("`D96QT6R=P)UT@/2!)34%05%)%15]"05-%
M7T5,5#L*("`@("`@("`@("`@("`@('T@96QS96EF("AS=')P;W,H)&5L=%LG
M=B==+"`D;G-?:6YF;ULG;F%M92==("X@)TE.0D]8)R`N("1N<U]I;F9O6R=D
M96QI;6ET97(G72D@/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`D96QT
M6R=P)UT@/2`G24Y"3U@G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@("1E;'1;)VPG72`](%-T<FEN9SHZ8V]N
M=F5R=$-H87)S970H)'1M<%LD;&%B96Q=+"`G551&-RU)34%0)RD["@H@("`@
M("`@(')E='5R;B`D96QT.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI=&%L
M:7IE('1H92!L:7-T(&%T('1H92!T;W`@;&5V96P@;V8@=&AE(&AI97)A<F-H
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YI="`@5&AE(&EN
M:71I86QI>F%T:6]N(&UO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN:70H
M)&EN:70I"B`@("!["B`@("`@("`@+RH@4F5S970@86QL(&-L87-S('9A<FEA
M8FQE<R!T;R!T:&4@9&5F875L=',N("HO"B`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D(#T@=')U93L*("`@("`@("`D=&AI<RT^7V-U<G)K97D@/2!N=6QL.PH@
M("`@("`@("1T:&ES+3Y?8W5R<G!A<F5N="`](&YU;&P["B`@("`@("`@)'1H
M:7,M/E]C=7)R<W1A8VL@/2!A<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?=')E
M92`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/E]P87)E;G0@/2!A<G)A>2@I
M.PH@("`@("`@("1T:&ES+3Y?<VAO=W5N<W5B(#T@)'1H:7,M/E]U;G-U8G9I
M97<@/2`H)&EN:70@)B!)34%05%)%15])3DE47U5.4U5"*3L*("`@("`@("`D
M=&AI<RT^7W-U8G-C<FEB960@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?=6YS
M=6)S8W)I8F5D(#T@;G5L;#L*"B`@("`@("`@+RH@4V5T(&EN:71I86QI>F%T
M:6]N(&UO9&4N("HO"B`@("`@("`@)'1H:7,M/E]I;FET;6]D92`]("1I;FET
M.PH*("`@("`@("`O*B!'970@=&AE(&EN:71I86P@;&ES="!O9B!M86EL8F]X
M97,@9G)O;2!T:&4@<W5B8VQA<W,N("HO"B`@("`@("`@)&)O>&5S(#T@)'1H
M:7,M/E]I;FET*"D["@H@("`@("`@("\J($-R96%T92!A('!L86-E:&]L9&5R
M(&5L96UE;G0@=&\@=&AE(&)A<V4@;V8@=&AE('1R964@;&ES="!S;R!W92!C
M86X*("`@("`@("`@*B!K965P('1R86-K(&]F('=H971H97(@=&AE(&)A<V4@
M;&5V96P@;F5E9',@=&\@8F4@<V]R=&5D+B`J+PH@("`@("`@("1T:&ES+3Y?
M=')E95M)34%05%)%15]"05-%7T5,5%T@/2!A<G)A>2@G82<@/3X@24U!4%12
M145?14Q47TE37T1)4T-/5D52140I.PH*("`@("`@("`O*B!#:&5C:R!T;R!M
M86ME('-U<F4@86QL(&YA;65S<&%C92!E;&5M96YT<R!A<F4@:6X@=&AE('1R
M964N("HO"B`@("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E<RD@>PH@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7VYA;65S<&%C97,@87,@)&ME>2`]
M/B`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H)'9A;%LG='EP92==("$]
M("=P97)S;VYA;"<I('L*("`@("`@("`@("`@("`@("`@("`D;F%M92`]('-U
M8G-T<B@D:V5Y+"`P+"`M,2`J('-T<FQE;B@D=F%L6R=D96QI;6ET97(G72DI
M.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T<F5E
M6R1V86Q;)VYA;64G75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1O
M8B`]("9N97<@<W1D0VQA<W,["B`@("`@("`@("`@("`@("`@("`@("`@("1O
M8BT^9&5L:6UI=&5R(#T@)'9A;%LG9&5L:6UI=&5R)UT["B`@("`@("`@("`@
M("`@("`@("`@("`@("1O8BT^871T<FEB=71E<R`]($Q!5%1?3D]314Q%0U0@
M?"!)34%05%)%15]%3%1?3D%-15-004-%.PH@("`@("`@("`@("`@("`@("`@
M("`@("`O*B`D;V(M/F9U;&Q397)V97)0871H(&ES(&YO="!C;VUP;&5T96QY
M('-E="!H97)E+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D;V(M/F9U
M;&Q397)V97)0871H(#T@)&]B+3YN86UE(#T@)&YA;64["B`@("`@("`@("`@
M("`@("`@("`@("`@("1E;'0@/2`D=&AI<RT^7VUA:V5-86EL8F]X5')E945L
M="@D;V(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN<V5R
M=$5L="@D96QT*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($-R
M96%T92!T:&4@;&ES="`H24Y"3U@@86YD(&%N>2!O=&AE<B!H:65R87)C:&EE
M<RDN("HO"B`@("`@("`@)'1H:7,M/E]A9&1,979E;"@D8F]X97,I.PH*("`@
M("`@("`O*B!%;F0@:6YI=&EA;&EZ871I;VX@;6]D92X@*B\*("`@("`@("`D
M=&AI<RT^7VEN:71M;V1E(#T@,#L*("`@('T*"B`@("`O*BH*("`@("`J(%-U
M8F-L87-S('-P96-I9FEC(&EN:71I86QI>F%T:6]N('1A<VMS+@H@("`@("H@
M5$A)4R!-151(3T0@35535"!"12!$149)3D5$($E.($%,3"!354)#3$%34T53
M+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!I
M;FET:6%L(&QI<W0@;V8@96QE;65N=',@=&\@861D('1O('1H92!T<F5E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?:6YI="@I"B`@("!["B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%>'!A;F0@82!M
M86EL(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;VQD
M97(@("`@("!4:&4@9F]L9&5R(&YA;64@=&\@97AP86YD+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&5X<&%N9&%L;"`@17AP86YD(&%L;"!F;VQD97)S('5N
M9&5R('1H:7,@;VYE/PH@("`@("HO"B`@("!F=6YC=&EO;B!E>'!A;F0H)&9O
M;&1E<BP@)&5X<&%N9&%L;"`](&9A;'-E*0H@("`@>PH@("`@("`@("1F;VQD
M97(@/2`D=&AI<RT^7V-O;G9E<G1.86UE*"1F;VQD97(I.PH*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]C:&%N9V5D
M(#T@=')U93L*"B`@("`@("`@+RH@365R9V4@:6X@;F5X="!L979E;"!O9B!I
M;F9O<FUA=&EO;BX@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA<T-H:6QD<F5N
M*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI('L*("`@("`@("`@("`@:68@*"$D
M=&AI<RT^:7-$:7-C;W9E<F5D*"1T:&ES+3Y?=')E95LD9F]L9&5R72DI('L*
M("`@("`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/E]C:&EL9')E;DEN9F\H
M)&9O;&1E<BD["B`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F9O*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VEN:71M;V1E*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@H)'1H:7,M/E]I;FET;6]D
M92`F($E-05!44D5%7TE.251?1D540TA!3$PI('Q\"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^:7-/<&5N*"1T:&ES+3Y?=')E95LD9F]L
M9&5R72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D3&5V96PH)&EN9F\I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1,979E;"@D:6YF;RD["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D=&AI<RT^7W1R965;)&9O;&1E
M<ETL('1R=64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF
M("@A*"1T:&ES+3Y?:6YI=&UO9&4@)B!)34%05%)%15])3DE47T9%5$-(04Q,
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D=&AI
M<RT^7W1R965;)&9O;&1E<ETL('1R=64I.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("\J($5X<&%N9"!A;&P@8VAI;&1R96X@8F5N96%T
M:"!T:&ES(&]N92X@*B\*("`@("`@("`@("`@("`@(&EF("@D97AP86YD86QL
M("8F("%E;7!T>2@D=&AI<RT^7W!A<F5N=%LD9F]L9&5R72DI('L*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A<F5N=%LD9F]L9&5R
M72!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE
M>'!A;F0H)'1H:7,M/E]T<F5E6R1V86Q=6R=V)UTL('1R=64I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O;&QA<'-E(&$@
M;6%I;"!F;VQD97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]L
M9&5R("!4:&4@9F]L9&5R(&YA;64@=&\@8V]L;&%P<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;&QA<'-E*"1F;VQD97(I"B`@("!["B`@("`@("`@)&9O
M;&1E<B`]("1T:&ES+3Y?8V]N=F5R=$YA;64H)&9O;&1E<BD["@H@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]T<F5E6R1F;VQD97)=*2D@>PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG
M960@/2!T<G5E.PH*("`@("`@("`O*B!3970@=&AE(&9O;&1E<B!A='1R:6)U
M=&5S('1O(&YO="!E>'!A;F1E9"X@*B\*("`@("`@("`D=&AI<RT^7W-E=$]P
M96XH)'1H:7,M/E]T<F5E6R1F;VQD97)=+"!F86QS92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971S('1H92!I;G1E<FYA;"!A<G)A>2!P;VEN=&5R('1O
M('1H92!N97AT(&5L96UE;G0L(&%N9"!R971U<FYS('1H90H@("`@("H@;F5X
M="!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA<VL@
M($$@;6%S:R!W:71H('1H92!F;VQL;W=I;F<@96QE;65N=',Z"B`@("`@*B`\
M<')E/@H@("`@("H@24U!4%12145?3D585%]32$]70TQ/4T5$("T@1&]N)W0@
M:6=N;W)E(&-L;W-E9"!E;&5M96YT<RX*("`@("`J($E-05!44D5%7TY%6%1?
M4TA/5U-50B`M($]N;'D@<VAO=R!S=6)S8W)I8F5D(&5L96UE;G1S+@H@("`@
M("H@/"]P<F4^"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4F5T=7)N
M<R!T:&4@;F5X="!E;&5M96YT(&]R(&9A;'-E(&EF('1H92!E;&5M96YT(&1O
M97-N)W0*("`@("`J("`@("`@("`@("`@("`@(&5X:7-T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT*"1M87-K(#T@,"D*("`@('L*("`@("`@("!I9B`H
M:7-?;G5L;"@D=&AI<RT^7V-U<G)K97DI("8F(&ES7VYU;&PH)'1H:7,M/E]C
M=7)R<&%R96YT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`D8W5R<B`]("1T:&ES+3YC=7)R96YT*"D["@H@("`@
M("`@("1O;&1?<VAO=W5N<W5B(#T@)'1H:7,M/E]S:&]W=6YS=6(["B`@("`@
M("`@:68@*"1M87-K("8@24U!4%12145?3D585%]32$]74U5"*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<VAO=W5N<W5B(#T@9F%L<V4["B`@("`@("`@?0H@
M("`@("`@"B`@("`@("`@:68@*"1T:&ES+3Y?86-T:79E16QT*"1C=7)R*2`F
M)@H@("`@("`@("`@("`H*"1M87-K("8@24U!4%12145?3D585%]32$]70TQ/
M4T5$*2!\?"`D=&AI<RT^:7-/<&5N*"1C=7)R*2D@)B8*("`@("`@("`@("`@
M*"1T:&ES+3Y?8W5R<G!A<F5N="`A/2`D8W5R<ELG=B==*2D@>PH@("`@("`@
M("`@("`O*B!)9B!T:&4@8W5R<F5N="!E;&5M96YT(&ES(&]P96XL(&%N9"!C
M:&EL9')E;B!E>&ES="P@;6]V92!I;G1O"B`@("`@("`@("`@("`J(&ET+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^7V-U<G)S=&%C:UM=(#T@87)R87DH)VLG
M(#T^("1T:&ES+3Y?8W5R<FME>2P@)W`G(#T^("1T:&ES+3Y?8W5R<G!A<F5N
M="D["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<FME>2`](#`["B`@("`@("`@
M("`@("1T:&ES+3Y?8W5R<G!A<F5N="`]("1C=7)R6R=V)UT["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7VYE9613;W)T*"1T:&ES+3Y?=')E95LD8W5R<ELG
M=B==72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0H)'1H
M:7,M/E]P87)E;G1;)&-U<G);)W8G75TL(&ES7VYU;&PH)&-U<G);)W8G72DI
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S971.965D4V]R="@D=&AI<RT^
M7W1R965;)&-U<G);)W8G75TL(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O*B!%;'-E+"!I;F-R96UE;G0@=VET:&EN
M('1H92!C=7)R96YT('-U8F9O;&1E<BX@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R:V5Y*RL["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!T:&4@<&]I
M;G1E<B!D;V5S;B=T('!O:6YT('1O(&%N(&5L96UE;G0L('1R>2!T;R!M;W9E
M(&)A8VL@=&\*("`@("`@("`@("!T:&4@<')E=FEO=7,@<W5B9F]L9&5R+B`@
M268@=&AE<F4@:7,@;F\@<')E=FEO=7,@<W5B9F]L9&5R+`H@("`@("`@("`@
M(')E='5R;B!F86QS92X@*B\*("`@("`@("`D8W5R<B`]("1T:&ES+3YC=7)R
M96YT*"D["B`@("`@("`@:68@*"$D8W5R<B`F)@H@("`@("`@("`@("`H)&UA
M<VL@)B!)34%05%)%15].15A47U-(3U=#3$]3140I("8F"B`@("`@("`@("`@
M("$D=&AI<RT^:7-$:7-C;W9E<F5D*"1T:&ES+3Y?=')E95LD=&AI<RT^7V-U
M<G)P87)E;G1=*2`F)@H@("`@("`@("`@("`D=&AI<RT^:&%S0VAI;&1R96XH
M)'1H:7,M/E]T<F5E6R1T:&ES+3Y?8W5R<G!A<F5N=%TI*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?861D3&5V96PH)'1H:7,M/E]C:&EL9')E;DEN9F\H)'1H
M:7,M/E]T<F5E6R1T:&ES+3Y?8W5R<G!A<F5N=%U;)W8G72DI.PH@("`@("`@
M("`@("`D8W5R<B`]("1T:&ES+3YC=7)R96YT*"D["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7W-H;W=U;G-U8B`]("1O;&1?<VAO=W5N<W5B.PH*("`@
M("`@("!I9B`H(21C=7)R*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI
M<RT^7V-U<G)S=&%C:RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R
M<FME>2`](&YU;&P["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)P87)E
M;G0@/2!N=6QL.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9&\@>PH@("`@("`@
M("`@("`@("`@("`@("1O;&0@/2!A<G)A>5]P;W`H)'1H:7,M/E]C=7)R<W1A
M8VLI.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<FME>2`]("1O
M;&1;)VLG72`K(#$["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M<&%R96YT(#T@)&]L9%LG<"==.PH@("`@("`@("`@("`@("`@?2!W:&EL92`H
M*"@D8W5R<B`]("1T:&ES+3YC=7)R96YT*"DI(#T](&9A;'-E*2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@("`@8V]U;G0H)'1H:7,M/E]C=7)R<W1A8VLI
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D=&AI
M<RT^7V%C=&EV945L="@D8W5R<BDI('L*("`@("`@("`@("`@+RH@4VMI<"!T
M:&ES(&5N=')Y(&EF.@H@("`@("`@("`@("`@*B`Q+B!792!A<F4@;F]T('-H
M;W=I;F<@86QL(&5L96UE;G1S"B`@("`@("`@("`@("`J(#(N(%=E(&%R92!N
M;W0@<W5B<V-R:6)E9"!T;R!T:&ES(&5L96UE;G0*("`@("`@("`@("`@("H@
M,RX@270@:7,@;F]T(&$@8V]N=&%I;F5R("U/4BTL(&EF(&ET(&ES(&$@8V]N
M=&%I;F5R+"!I9B!T:&5R90H@("`@("`@("`@("`@*B`@("!A<F4@;F\@=FEE
M=V%B;&4@96QE;65N=',@=6YD97)N96%T:"!I="X*("`@("`@("`@("`@("H@
M-"X@5&AI<R!I<R!A;B!E;7!T>2!N86UE<W!A8V4@96QE;65N="X@*B\*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YN97AT*"1M87-K*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D8W5R<CL*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E="!I;G1E<FYA;"!P;VEN=&5R('1O('1H92!H96%D(&]F('1H92!T<F5E
M+@H@("`@("H@5&AI<R!-55-4(&)E(&-A;&QE9"!B969O<F4@>6]U(&-A;B!T
M<F%V97)S92!T:&4@=')E92!W:71H(&YE>'0H*2X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!2971U<FYS('1H92!E;&5M96YT(&%T('1H92!H96%D
M(&]F('1H92!T<F5E(&]R(&9A;'-E"B`@("`@*B`@("`@("`@("`@("`@("!I
M9B!T:&4@96QE;65N="!D;V5S;B=T(&5X:7-T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!R97-E="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]C=7)R:V5Y(#T@
M,#L*("`@("`@("`D=&AI<RT^7V-U<G)P87)E;G0@/2!)34%05%)%15]"05-%
M7T5,5#L*("`@("`@("`D=&AI<RT^7V-U<G)S=&%C:R`](&%R<F%Y*"D["@H@
M("`@("`@(&EF("@D=&AI<RT^7VYE9613;W)T*"1T:&ES+3Y?=')E95LD=&AI
M<RT^7V-U<G)P87)E;G1=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-O<G1,
M:7-T*"1T:&ES+3Y?<&%R96YT6R1T:&ES+3Y?8W5R<G!A<F5N=%TL(&ES7VYU
M;&PH)'1H:7,M/E]C=7)R<&%R96YT*2D["B`@("`@("`@("`@("1T:&ES+3Y?
M<V5T3F5E9%-O<G0H)'1H:7,M/E]T<F5E6R1T:&ES+3Y?8W5R<G!A<F5N=%TL
M(&9A;'-E*3L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@=')U93L*
M("`@("`@("!]"@H@("`@("`@("\J(%=H96X@<F5S971T:6YG(&EN(&YE=W,@
M;6]D92P@=&AE(&9I<G-T(&5L96UE;G0@;6%Y(&YO="!B90H@("`@("`@("`J
M('9I97=A8FQE("AU;FQI:V4@;6%I;"!M;V1E+"!W:&5R92!T:&4@9FER<W0@
M96QE;65N="!I<R!)3D)/6"!A;F0*("`@("`@("`@*B!I<R!A;'=A>7,@=FEE
M=V%B;&4I+B`@5&AE<F5F;W)E+"!W92!N965D('1O('-E87)C:"!F;W(@=&AE
M(&9I<G-T"B`@("`@("`@("H@=FEE=V%B;&4@:71E;2!A;F0@=&AA="!W:6QL
M(&)E('1H92!B87-E(&]F('1H92!V:65W86)L92!T<F5E+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^7VUO9&4@/3T@24U!4%12145?34]$15].15=3*2!["B`@
M("`@("`@("`@("1C=7)R(#T@)'1H:7,M/F-U<G)E;G0H*3L*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^7V%C=&EV945L="@D8W5R<BDI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YN97AT*"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^8W5R<F5N="@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N('1H92!C=7)R96YT('1R964@96QE;65N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@8W5R<F5N="!T<F5E
M(&5L96UE;G0@;W(@9F%L<V4@:68@=&AE<F4@:7,@;F\*("`@("`J("`@("`@
M("`@("`@("`@(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-U<G)E
M;G0H*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)E;G1;
M)'1H:7,M/E]C=7)R<&%R96YT75LD=&AI<RT^7V-U<G)K97E=*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'1H:7,M/E]A9&1!;&EA<V5S*"1T:&ES+3Y?=')E95LD=&AI<RT^7W!A
M<F5N=%LD=&AI<RT^7V-U<G)P87)E;G1=6R1T:&ES+3Y?8W5R<FME>5U=*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@=&AE<F4@87)E
M(&UO<F4@96QE;65N=',@:6X@=&AE(&-U<G)E;G0@=')E92!L979E;"X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@=&AE<F4@87)E
M(&UO<F4@96QE;65N=',L(&9A;'-E(&EF('1H:7,@:7,@=&AE"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&QA<W0@96QE;65N="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<&5E:R@I"B`@("!["B`@("`@("`@9F]R("@D:2`]("@D=&AI<RT^
M7V-U<G)K97D@*R`Q*3L@.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P87)E;G1;)'1H:7,M/E]C=7)R<&%R96YT75LD:5TI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?86-T:79E16QT*"1T:&ES+3Y?861D
M06QI87-E<R@D=&AI<RT^7W1R965;)'1H:7,M/E]P87)E;G1;)'1H:7,M/E]C
M=7)R<&%R96YT75LD:5U=*2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!A;&EA<V5S('1O(&$@=')E92!E;&5M96YT(&%N9"!R971U
M<FYS('1H92!R97-U;'1I;F<@87)R87DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<F]T96-T960*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@
M02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@
M02!T<F5E(&5L96UE;G0@=VET:"!T:&4@86QI87-E<R!A9&1E9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%D9$%L:6%S97,H)&5L="D*("`@('L*("`@("`@
M("`D96QT6R=L86)E;"==(#T@)&5L=%LG;"==.PH@("`@("`@("1E;'1;)VQE
M=F5L)UT@/2`D96QT6R=C)UT["B`@("`@("`@)&5L=%LG<&%R96YT)UT@/2`D
M96QT6R=P)UT["B`@("`@("`@)&5L=%LG=F%L=64G72`]("1E;'1;)W8G73L*
M"B`@("`@("`@<F5T=7)N("1E;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!R97%U97-T960@96QE;65N="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@;F%M92!O9B!T:&4@=')E92!E;&5M
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%)E='5R;G,@=&AE
M(')E<75E<W1E9"!E;&5M96YT(&]R(&9A;'-E(&EF(&YO="!F;W5N9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T*"1N86UE*0H@("`@>PH@("`@("`@("1N
M86UE(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D;F%M92D["@H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W1R965;)&YA;65=*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]A9&1!;&EA<V5S*"1T:&ES+3Y?=')E95LD;F%M95TI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!);G-E<G0@82!F;VQD
M97(O;6%I;&)O>"!I;G1O('1H92!T<F5E+@H@("`@("H*("`@("`J($!P87)A
M;2!M:7AE9"`D:60@(%1H92!N86UE(&]F('1H92!F;VQD97(@*&]R(&$@;&ES
M="!O9B!F;VQD97(@;F%M97,I"B`@("`@*B`@("`@("`@("`@("`@("`@("!T
M;R!A9&0@*&UU<W0@8F4@<')E<V5N="!O;B!T:&4@;6%I;"!S97)V97(I+@H@
M("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S
M+"!F86QS92!O;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@:6YS97)T
M*"1I9"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]M;V1E(#T]($E-05!4
M4D5%7TU/1$5?3D574RD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)&ED*2D@>PH@("`@("`@
M("`@("!I9B`H(21T:&ES+3Y?;F]N:6UA<&5L="D@>PH@("`@("`@("`@("`@
M("`@+RH@5V4@=V%N="!T;R!A9&0@9G)O;2!T:&4@0D%312!O9B!T:&4@=')E
M92!U<"!F;W(@969F:6-I96YC>0H@("`@("`@("`@("`@("`@("H@<V%K92X@
M*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]R=$QI<W0H)&ED*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I9"`]
M(&%R<F%Y*"1I9"D["B`@("`@("`@?0H*("`@("`@("`D861D<R`](&%R<F%Y
M*"D["@H@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@
M("`@("1N<U]I;F9O(#T@)'1H:7,M/E]G971.86UE<W!A8V4H)'9A;"D["B`@
M("`@("`@("`@(&EF("AI<U]N=6QL*"1N<U]I;F9O*2!\?"`D=&AI<RT^7VYO
M;FEM87!E;'0I('L*("`@("`@("`@("`@("`@("1A9&1S6UT@/2`D=F%L.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@0G)E86L@
M87!A<G0@=&AE(&YA;64@=FEA('1H92!D96QI;6ET97(@86YD(&=O('-T97`@
M8GD@<W1E<`H@("`@("`@("`@("`@("`@("H@=&AR;W5G:"!T:&4@;F%M92!T
M;R!M86ME('-U<F4@86QL('-U8F9O;&1E<G,@97AI<W0@:6X@=&AE"B`@("`@
M("`@("`@("`@("`@*B!T<F5E+B`J+PH@("`@("`@("`@("`@("`@)'!A<G1S
M(#T@97AP;&]D92@D;G-?:6YF;ULG9&5L:6UI=&5R)UTL("1V86PI.PH@("`@
M("`@("`@("`@("`@)'!A<G1S6S!=(#T@)'1H:7,M/E]C;VYV97)T3F%M92@D
M<&%R='-;,%TI.PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M8V]U;G0H)'!A<G1S*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1A
M9&1S6UT@/2!I;7!L;V1E*"1N<U]I;F9O6R=D96QI;6ET97(G72P@87)R87E?
M<VQI8V4H)'!A<G1S+"`P+"`D:2`K(#$I*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H87)R
M87E?=6YI<75E*"1A9&1S*2!A<R`D:60I('L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?=')E95LD:61=*2D@>PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9"`]('1R=64["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]N;VYI;6%P
M96QT*2!["B`@("`@("`@("`@("`@("`D96QT(#T@)'1H:7,M/E]G971.;VY)
M34%016QT*"1I9"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D;V(@/2`D=&AI<RT^7V=E=$QI<W0H)&ED*3L*("`@("`@("`@("`@
M("`@("1E;'0@/2`D=&AI<RT^7VUA:V5-86EL8F]X5')E945L="AR97-E="@D
M;V(I*3L*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FES4W5B<V-R:6)E
M9"@D96QT*2D@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!`:6UA<%]L
M<W5B*"1T:&ES+3Y?9V5T4W1R96%M*"DL("1T:&ES+3Y?<V5R=F5R+"`D96QT
M6R=V)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1M<"DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S9713=6)S8W)I
M8F5D*"1E;'0L('1R=64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?:6YS97)T16QT*"1E;'0I*2!["B`@("`@("`@("`@("`@("`O*B!7
M92!K;F]W('1H870@=&AE('!A<F5N="!F;VQD97(@:&%S(&-H:6QD<F5N+B`J
M+PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD96QT
M6R=P)UU=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T0VAI
M;&1R96XH)'1H:7,M/E]T<F5E6R1E;'1;)W`G75TL('1R=64I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\J($UA:V4@<W5R92!W92!A
M<F4@<V]R=&5D(&-O<G)E8W1L>2X@*B\*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=*2`^(#$I('L*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-E=$YE9613;W)T*"1T:&ES+3Y?=')E
M95LD96QT6R=P)UU=+"!T<G5E*3L*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O*B!!9&0@=&\@<W5B<V-R:6)E9"]U;G-U8G-C<FEB960@
M;&ES="X@*B\*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:7-3=6)S8W)I
M8F5D*"1E;'0I("8F"B`@("`@("`@("`@("`@("`@("`@(6ES7VYU;&PH)'1H
M:7,M/E]S=6)S8W)I8F5D*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<W5B<V-R:6)E9%LD96QT6R=V)UU=(#T@,3L*("`@("`@("`@("`@("`@
M('T@96QS96EF("@A)'1H:7,M/FES4W5B<V-R:6)E9"@D96QT*2`F)@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("%I<U]N=6QL*"1T:&ES+3Y?=6YS=6)S
M8W)I8F5D*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=6YS=6)S
M8W)I8F5D6R1E;'1;)W8G75T@/2`Q.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($EN<V5R="!A;B!E;&5M96YT(&EN=&\@=&AE
M('1R964N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@(%1H92!E;&5M96YT('1O(&EN<V5R
M="X@5&AE(&ME>2!I;B!T:&4@=')E92!I<R!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`G=B<@*'9A;'5E*2!E;&5M96YT(&]F('1H92!E;&5M96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!A9&1E
M9"!T;R!T:&4@=')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN<V5R=$5L
M="@D96QT*0H@("`@>PH@("`@("`@("\J($1O;B=T(&EN8VQU9&4@=&AE('!A
M<F5N="!D:7)E8W1O<FEE<R!T:&%T(%57('!A<W-E<R!B86-K(&EN"B`@("`@
M("`@("`@)2\E(&QI<W1S+B`J+PH@("`@("`@(&EF("AS=')L96XH)&5L=%LG
M;"==*2`F)@H@("`@("`@("`@("`H(6ES<V5T*"1T:&ES+3Y?=')E95LD96QT
M6R=V)UU=*2!\?`H@("`@("`@("`@("`@)'1H:7,M/FES0V]N=&%I;F5R*"1T
M:&ES+3Y?=')E95LD96QT6R=V)UU=*2D@)B8*("`@("`@("`@("`@+RH@5$]$
M3SH@4F5M;W9E(&1O=&9I;&5S(&9I;'1E<B!I;B!N97AT(&UA:F]R(')E;&5A
M<V4N("HO"B`@("`@("`@("`@("@D=&AI<RT^7V1O=&9I;&5S('Q\("@D96QT
M6R=L)UU;,%T@(3T@)RXG*2DI('L*("`@("`@("`@("`@+RH@4V5T('1H92!P
M87)E;G0@87)R87D@=&\@=&AE('9A;'5E(&EN("1E;'1;)W`G72X@*B\*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R96YT6R1E;'1;)W`G75TI
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F5N=%LD96QT6R=P)UU=
M(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7W!A<F5N=%LD96QT6R=P)UU=6UT@/2`D96QT6R=V)UT["B`@("`@("`@("`@
M("1T:&ES+3Y?=')E95LD96QT6R=V)UU=(#T@)&5L=#L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M;&5T92!A;B!E;&5M96YT(&9R;VT@=&AE('1R964N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&UI>&5D("1I9"`@5&AE(&5L96UE;G0@;F%M92!O<B!A;B!A<G)A
M>2!O9B!E;&5M96YT(&YA;65S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@4F5T=7)N('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T92@D:60I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@+RH@5V4@=V%N
M="!T;R!D96QE=&4@9G)O;2!T:&4@5$]0(&]F('1H92!T<F5E(&1O=VX@=&\@
M96YS=7)E('1H870*("`@("`@("`@("`@("H@<&%R96YT<R!H879E(&%N(&%C
M8W5R871E('9I97<@;V8@=VAA="!C:&EL9')E;B!A<F4@;&5F="X@*B\*("`@
M("`@("`@("`@)'1H:7,M/E]S;W)T3&ES="@D:60I.PH@("`@("`@("`@("`D
M:60@/2!A<G)A>5]R979E<G-E*"1I9"D["@H@("`@("`@("`@("`D<W5C8V5S
M<R`]('1R=64["B`@("`@("`@("`@(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2![
M"B`@("`@("`@("`@("`@("`D8W5R<G-U8V-E<W,@/2`D=&AI<RT^9&5L971E
M*"1V86PI.PH@("`@("`@("`@("`@("`@:68@*"$D8W5R<G-U8V-E<W,I('L*
M("`@("`@("`@("`@("`@("`@("`D<W5C8V5S<R`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M<W5C8V5S<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:60@/2`D
M=&AI<RT^7V-O;G9E<G1.86UE*"1I9"P@=')U92D["B`@("`@("`@?0H*("`@
M("`@("`D;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E*"1I9"D["@H@
M("`@("`@(&EF("@H)&ED(#T]("=)3D)/6"<I('Q\"B`@("`@("`@("`@("%I
M<W-E="@D=&AI<RT^7W1R965;)&ED72D@?'P*("`@("`@("`@("`@*"1I9"`]
M/2`D;G-?:6YF;ULG;F%M92==*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T<G5E
M.PH*("`@("`@("`D96QT(#T@)B1T:&ES+3Y?=')E95LD:61=.PH*("`@("`@
M("`O*B!$;R!N;W0@9&5L971E(&9R;VT@=')E92!I9B!T:&5R92!A<F4@8VAI
M;&0@96QE;65N=',@+2!I;G-T96%D+`H@("`@("`@("`J(&-O;G9E<G0@=&\@
M82!C;VYT86EN97(@96QE;65N="X@*B\*("`@("`@("!I9B`H)'1H:7,M/FAA
M<T-H:6QD<F5N*"1E;'0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T0V]N
M=&%I;F5R*"1E;'0L('1R=64I.PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!]"@H@("`@("`@("1P87)E;G0@/2`D96QT6R=P)UT["@H@("`@
M("`@("\J($1E;&5T92!T:&4@=')E92!E;G1R:65S+B`J+PH@("`@("`@('5N
M<V5T*"1T:&ES+3Y?=')E95LD:61=*3L*("`@("`@("!U;G-E="@D=&AI<RT^
M7W-U8G-C<FEB961;)&ED72D["B`@("`@("`@=6YS970H)'1H:7,M/E]U;G-U
M8G-C<FEB961;)&ED72D["@H@("`@("`@("\J($1E;&5T92!T:&4@96YT<GD@
M9G)O;2!T:&4@<&%R96YT('1R964N("HO"B`@("`@("`@)&ME>2`](&%R<F%Y
M7W-E87)C:"@D:60L("1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*("`@("`@
M("!U;G-E="@D=&AI<RT^7W!A<F5N=%LD<&%R96YT75LD:V5Y72D["@H@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F5N=%LD<&%R96YT72DI('L*("`@
M("`@("`@("`@+RH@5&AI<R!F;VQD97(@:7,@;F]W(&-O;7!L971E;'D@96UP
M='D@*&YO(&-H:6QD<F5N*2X@($EF('1H90H@("`@("`@("`@("`@*B!F;VQD
M97(@:7,@82!C;VYT86EN97(@;VYL>2P@=V4@<VAO=6QD(&1E;&5T92!T:&4@
M9F]L9&5R(&9R;VT*("`@("`@("`@("`@("H@=&AE('1R964N("HO"B`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*3L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD<&%R96YT72DI('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<V5T0VAI;&1R96XH)'1H:7,M/E]T<F5E
M6R1P87)E;G1=+"!N=6QL*3L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-#;VYT86EN97(H)'1H:7,M/E]T<F5E6R1P87)E;G1=*2`F)@H@("`@("`@
M("`@("`@("`@("`@("$D=&AI<RT^:7-.86UE<W!A8V4H)'1H:7,M/E]T<F5E
M6R1P87)E;G1=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD96QE
M=&4H)'!A<F5N="D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES
M+3YH87-#:&EL9')E;B@D=&AI<RT^7W1R965;)'!A<F5N=%TI*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI<W0H)'!A
M<F5N="D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971#:&EL9')E
M;B@D=&AI<RT^7W1R965;)'!A<F5N=%TL(&9A;'-E*3L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-E=$]P96XH)'1H:7,M/E]T<F5E6R1P87)E;G1=
M+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!296)U:6QD('1H92!P87)E
M;G0@=')E92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]P87)E;G1;)'!A<F5N
M=%T@/2!A<G)A>5]V86QU97,H)'1H:7,M/E]P87)E;G1;)'!A<F5N=%TI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@4F5M;W9E('1H92!M86EL8F]X(&9R;VT@
M=&AE(&5X<&%N9&5D(&9O;&1E<G,@;&ES="X@*B\*("`@("`@("`D=&AI<RT^
M7W)E;6]V945X<&%N9&5D3&ES="@D:60I.PH*("`@("`@("`O*B!296UO=F4@
M=&AE(&UA:6QB;W@@9G)O;2!T:&4@;F%V7W!O;&P@;&ES="X@*B\*("`@("`@
M("`D=&AI<RT^<F5M;W9E4&]L;$QI<W0H)&ED*3L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=6)S8W)I8F4@86X@96QE
M;65N="!T;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&ED("!4:&4@96QE;65N="!N86UE(&]R(&%N(&%R<F%Y(&]F(&5L96UE;G0@
M;F%M97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('-U8G-C<FEB92@D:60I"B`@
M("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D:60I*2!["B`@("`@("`@("`@
M("1I9"`](&%R<F%Y*"1I9"D["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H
M("@D:60@87,@)'9A;"D@>PH@("`@("`@("`@("`D=F%L(#T@)'1H:7,M/E]C
M;VYV97)T3F%M92@D=F%L*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?=')E95LD=F%L72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA
M;F=E9"`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=%-U8G-C
M<FEB960H)'1H:7,M/E]T<F5E6R1V86Q=+"!T<G5E*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<V5T0V]N=&%I;F5R*"1T:&ES+3Y?=')E95LD=F%L72P@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?
M<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-U
M8G-C<FEB961;)'9A;%T@/2`Q.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@=6YS970H)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A;%TI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FEN
M<V5R="@D=F%L*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%5N<W5B<V-R:6)E(&%N(&5L96UE;G0@9G)O;2!T:&4@
M=')E92X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&ED("!4:&4@96QE
M;65N="!N86UE(&]R(&%N(&%R<F%Y(&]F(&5L96UE;G0@;F%M97,N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('5N<W5B<V-R:6)E*"1I9"D*("`@('L*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1I9"DI('L*("`@("`@("`@("`@)&ED(#T@87)R
M87DH)&ED*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!792!W
M86YT('1O(&1E;&5T92!F<F]M('1H92!43U`@;V8@=&AE('1R964@9&]W;B!T
M;R!E;G-U<F4@=&AA=`H@("`@("`@("`@("`@*B!P87)E;G1S(&AA=F4@86X@
M86-C=7)A=&4@=FEE=R!O9B!W:&%T(&-H:6QD<F5N(&%R92!L969T+B`J+PH@
M("`@("`@("`@("`D=&AI<RT^7W-O<G1,:7-T*"1I9"D["B`@("`@("`@("`@
M("1I9"`](&%R<F%Y7W)E=F5R<V4H)&ED*3L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1I9"!A<R`D=F%L*2!["B`@("`@("`@("`@("1V86P@/2`D
M=&AI<RT^7V-O;G9E<G1.86UE*"1V86PI.PH*("`@("`@("`@("`@+RH@24Y"
M3U@@8V%N(&YE=F5R(&)E('5N<W5B<V-R:6)E9"!T;R`H:68@:6X@;6%I;"!M
M;V1E*2X@*B\*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?=')E95LD
M=F%L72D@)B8@*"1V86P@(3T@)TE.0D]8)RDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W5N<W5B=FEE=R`]('1R=64["@H@("`@("`@("`@("`@("`@)&5L="`]
M("8D=&AI<RT^7W1R965;)'9A;%T["@H@("`@("`@("`@("`@("`@+RH@1&\@
M;F]T(&1E;&5T92!F<F]M('1R964@:68@=&AE<F4@87)E(&-H:6QD(&5L96UE
M;G1S("T*("`@("`@("`@("`@("`@("`J(&EN<W1E860L(&-O;G9E<G0@=&\@
M82!C;VYT86EN97(@96QE;65N="X@*B\*("`@("`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]S:&]W=6YS=6(@)B8@)'1H:7,M/FAA<T-H:6QD<F5N*"1E;'0I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S971#;VYT86EN97(H
M)&5L="P@=')U92D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+RH@4V5T(&%S('5N<W5B<V-R:6)E9"P@861D('1O('5N<W5B<V-R:6)E
M9"!L:7-T+"!A;F0@<F5M;W9E"B`@("`@("`@("`@("`@("`@*B!F<F]M('-U
M8G-C<FEB960@;&ES="X@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T
M4W5B<V-R:6)E9"@D96QT+"!F86QS92D["B`@("`@("`@("`@("`@("!I9B`H
M(6ES7VYU;&PH)'1H:7,M/E]U;G-U8G-C<FEB960I*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]U;G-U8G-C<FEB961;)'9A;%T@/2`Q.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]S
M=6)S8W)I8F5D6R1V86Q=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9"!A;F]T:&5R(&QE=F5L(&]F(&AI97)A
M<F-H>2!T;R!T:&4@=')E92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&QI<W0@($$@;&ES="!O
M9B!S=&1#;&%S<R!O8FIE8W1S(&EN('1H92!F;W)M870@<F5T=7)N960*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@9G)O;2!I;6%P7V=E=&UA:6QB;WAE
M<R@I+@H@("`@("HO"B`@("!F=6YC=&EO;B!?861D3&5V96PH)&QI<W0I"B`@
M("!["B`@("`@("`@)&5X<&%N9&%L;"`]("@D=&AI<RT^7VEN:71M;V1E("8@
M24U!4%12145?24Y)5%]&151#2$%,3"D["@H@("`@("`@(&9O<F5A8V@@*"1L
M:7-T(&%S("1V86PI('L*("`@("`@("`@("`@)&5L="`]("1T:&ES+3Y?;6%K
M94UA:6QB;WA4<F5E16QT*"1V86PI.PH*("`@("`@("`@("`@)'!A<F5N="`]
M("1E;'1;)W`G73L*("`@("`@("`@("`@)'1H:7,M/E]I;G-E<G1%;'0H)&5L
M="D["B`@("`@("`@("`@("1T:&ES+3Y?8VAA;F=E9"`]('1R=64["@H@("`@
M("`@("`@("!I9B`H)&5X<&%N9&%L;"!\?"`D=&AI<RT^:7-/<&5N*"1E;'0I
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^97AP86YD*"1E;'1;)W8G72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%-O<G0@=&AE
M(&QI<W0N("HO"B`@("`@("`@:68@*"%E;7!T>2@D;&ES="D@)B8*("`@("`@
M("`@("`@(65M<'1Y*"1T:&ES+3Y?<&%R96YT6R1P87)E;G1=*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-E=$1I<V-O=F5R960H)'1H:7,M/E]T<F5E6R1P
M87)E;G1=+"!T<G5E*3L*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M<&%R96YT6R1P87)E;G1=*2`^(#$I('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V5T3F5E9%-O<G0H)'1H:7,M/E]T<F5E6R1P87)E;G1=+"!T<G5E*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E="!A;B!A='1R:6)U=&4@9F]R(&%N(&5L96UE;G0N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y
M("8D96QT("`@("!4:&4@=')E92!E;&5M96YT+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&-O;G-T("!4:&4@8V]N<W1A;G0@=&\@<V5T+W)E;6]V92!F<F]M
M('1H92!B:71M87-K+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&)O;VP@("!3
M:&]U;&0@=&AE(&%T=')I8G5T92!B92!S970_"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]S971!='1R:6)U=&4H)B1E;'0L("1C;VYS="P@)&)O;VPI"B`@("![
M"B`@("`@("`@:68@*"1B;V]L*2!["B`@("`@("`@("`@("1E;'1;)V$G72!\
M/2`D8V]N<W0["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&5L=%LG
M82==("8]('XD8V]N<W0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@1&]E<R!T:&4@96QE;65N="!H879E(&%N>2!A8W1I=F4@8VAI;&1R96X_
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T
M:&4@96QE;65N="!H87,@86-T:79E(&-H:6QD<F5N+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!H87-#:&EL9')E;B@D96QT*0H@("`@>PH@("`@("`@('-T871I
M8R`D:&%S0VAI;&1R96Y#86-H92`](&%R<F%Y*"D["@H@("`@("`@("1I<U]N
M<R`]("1T:&ES+3YI<TYA;65S<&%C92@D96QT*3L*"B`@("`@("`@+RH@1&]N
M)W0@9&\@=&AE(&9O;&QO=VEN9R!I9B!W92!A<F4@9&5A;&EN9R!W:71H(&$@
M;F%M97-P86-E"B`@("`@("`@("H@8V]N=&%I;F5R+B`J+PH@("`@("`@(&EF
M("@A)&ES7VYS*2!["B`@("`@("`@("`@("\J($YO="!A;&P@24U!4"!S97)V
M97)S('-U<'!O<G0@=&AE($A!4T-(24Q$4D5.(&9L86<@*&QI:V4@55<A*2!S
M;PH@("`@("`@("`@("`@*B!W92!N965D('1O('-K:7`@=&AI<R!C:&5C:R!I
M9B!T:&4@24U!4"!S97)V97(@9&]E<VXG="!S970*("`@("`@("`@("`@("H@
M96ET:&5R($A!4T-(24Q$4D5.(&]R($A!4TY/0TA)3$1214XN("HO"B`@("`@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]C:&EL9')E;G-U<'!O<G0I('Q\
M"B`@("`@("`@("`@("`@("`H:7-?;G5L;"@D=&AI<RT^7V-H:6QD<F5N<W5P
M<&]R="D@)B8*("`@("`@("`@("`@("`@("`H)&5L=%LG82==("8@3$%45%](
M05-#2$E,1%)%3BD@?'P*("`@("`@("`@("`@("`@("`H)&5L=%LG82==("8@
M3$%45%](05-.3T-(24Q$4D5.*2DI('L*("`@("`@("`@("`@("`@("1R970@
M/2`H)&5L=%LG82==("8@3$%45%](05-#2$E,1%)%3BD["@H@("`@("`@("`@
M("`@("`@+RH@0TA%0TLZ($EF('=E(&%R92!V:65W:6YG(&%L;"!F;VQD97)S
M+"!A;F0@=&AE<F4@:7,@82!F;VQD97(*("`@("`@("`@("`@("`@("`J(&QI
M<W1E9"!A<R!E>'!A;F1E9"!B=70@:70@9&]E<R!N;W0@8V]N=&%I;B!A;GD@
M8VAI;&1R96XL"B`@("`@("`@("`@("`@("`@*B!T:&5N('=E('-H;W5L9"!R
M96UO=F4@:70@9G)O;2!T:&4@97AP86YD960@;&ES="!S:6YC92!I=`H@("`@
M("`@("`@("`@("`@("H@9&]E<VXG="!E>&ES="!A;GEM;W)E+B`J+PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?<VAO=W5N<W5B("8F("$D<F5T*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;FET17AP86YD961,:7-T
M*"D["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V5X
M<&%N9&5D6R1E;'1;)W8G75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5M;W9E17AP86YD961,:7-T*"1E;'1;)W8G72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D=&AI<RT^7W1R
M965;)&5L=%LG=B==72P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H(21R970I
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@+RH@268@=V4@87)E('9I97=I
M;F<@86QL(&5L96UE;G1S("AS=6)S8W)I8F5D(&%N9"!U;G-U8G-C<FEB960I
M"B`@("`@("`@("`@("`@("`@*B!A;F0@=V4@<F5A8V@@=&AI<R!P;VEN="!W
M92!K;F]W('1H870@=&AE<F4@;75S="!B92!V:65W86)L90H@("`@("`@("`@
M("`@("`@("H@8VAI;&1R96X@<V\@<F5T=7)N('1R=64N("HO"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@0V%C:&4@<F5S=6QT<R!F
M<F]M(&)E;&]W('-I;F-E+"!M;W-T(&QI:V5L>2!I9B!W92!G970@=&AI<R!F
M87(L"B`@("`@("`@("H@=&AI<R!C;V1E('=I;&P@8F4@86-C97-S960@<V5V
M97)A;"!T:6UE<R!I;B!T:&4@8W5R<F5N="!R97%U97-T+B`J+PH@("`@("`@
M(&EF("AI<W-E="@D:&%S0VAI;&1R96Y#86-H95LD96QT6R=V)UU=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&AA<T-H:6QD<F5N0V%C:&5;)&5L=%LG=B==
M73L*("`@("`@("!]"@H@("`@("`@("\J($EF('=E(')E86-H('1H:7,@<&]I
M;G0L('1H96X@=V4@87)E(&5I=&AE<B!I;B!S=6)S8W)I8F4M;VYL>2!M;V1E
M"B`@("`@("`@("H@;W(@=V4@87)E(&1E86QI;F<@=VET:"!A(&YA;65S<&%C
M92!C;VYT86EN97(N($-H96-K(&9O<B!T:&4*("`@("`@("`@*B!E>&ES=&5N
M8V4@;V8@86YY('-U8G-C<FEB960@;6%I;&)O>&5S(&)E;&]W('1H92!C=7)R
M96YT(&YO9&4N("HO"B`@("`@("`@)'1H:7,M/E]I;FET4W5B<V-R:6)E9"@I
M.PH@("`@("`@("1F;VQD97)?;&ES="`]("1T:&ES+3Y?<W5B<V-R:6)E9#L*
M("`@("`@("!I9B`H)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@("`@
M)'1H:7,M/E]I;FET56YS=6)S8W)I8F5D*"D["B`@("`@("`@("`@("1F;VQD
M97)?;&ES="`K/2`D=&AI<RT^7W5N<W5B<V-R:6)E9#L*("`@("`@("!]"B`@
M("`@("`@)&YS7VEN9F\@/2`D=&AI<RT^7V=E=$YA;65S<&%C92@D96QT6R=V
M)UTI.PH@("`@("`@(&EF("@A:7-?;G5L;"@D;G-?:6YF;RDI('L*("`@("`@
M("`@("`@)'-E87)C:%]S='(@/2`D96QT6R=V)UT@+B`D;G-?:6YF;ULG9&5L
M:6UI=&5R)UT["B`@("`@("`@("`@(&EF("@H)&5L=%LG=B==(#T]("=)3D)/
M6"<I("8F"B`@("`@("`@("`@("`@("`H)&YS7VEN9F];)VYA;64G72`]/2`H
M)TE.0D]8)R`N("1N<U]I;F9O6R=D96QI;6ET97(G72DI*2!["B`@("`@("`@
M("`@("`@("`D<V5A<F-H7W-T<B`N/2`D;G-?:6YF;ULG;F%M92==.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)&9O
M;&1E<E]L:7-T*2!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1V86PL("1S96%R8VA?<W1R*2`]/3T@,"D@>PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?:&%S0VAI;&1R96Y#86-H95LD96QT6R=V)UU=(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+RH@1&\@;VYE(&9I;F%L(&-H96-K(&EF('1H:7,@:7,@82!N86UE<W!A8V4@
M8V]N=&%I;F5R("T@:68@=V4@9V5T"B`@("`@("`@("H@=&AI<R!F87(L(&%N
M9"!A<F4@=FEE=VEN9R!A;&P@9F]L9&5R<RP@=&AE;B!W92!K;F]W('=E(&AA
M=F4@;F\*("`@("`@("`@*B!C:&EL9')E;B!S;R!M86ME('-U<F4@=&AE(&5L
M96UE;G0@:7,@;F]T('-E="!T;R!E>'!A;F1E9"]O<&5N+B`J+PH@("`@("`@
M(&EF("@D:7-?;G,@)B8@)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@
M("`@)'1H:7,M/E]I;FET17AP86YD961,:7-T*"D["B`@("`@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]E>'!A;F1E9%LD96QT6R=V)UU=*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%>'!A;F1E9$QI<W0H)&5L=%LG
M=B==*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<V5T3W!E;B@D=&AI<RT^
M7W1R965;)&5L=%LG=B==72P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D:&%S0VAI;&1R96Y#86-H95LD96QT6R=V)UU=(#T@
M9F%L<V4["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T('1H92!C:&EL9')E;B!A='1R:6)U=&4@9F]R(&%N(&5L96UE
M;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M(&%R<F%Y("8D96QT("!!('1R964@96QE;65N="X*("`@("`J
M($!P87)A;2!M:7AE9"`D8F]O;"`@5&AE('-E='1I;F<N($EF(&YU;&PL(&-L
M96%R<R!T:&4@9FQA9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$-H:6QD
M<F5N*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D
M8F]O;"DI('L*("`@("`@("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L
M="P@3$%45%](05-#2$E,1%)%3BP@9F%L<V4I.PH@("`@("`@("`@("`D=&AI
M<RT^7W-E=$%T=')I8G5T92@D96QT+"!,05147TA!4TY/0TA)3$1214XL(&9A
M;'-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W-E
M=$%T=')I8G5T92@D96QT+"!,05147TA!4T-(24Q$4D5.+"`D8F]O;"D["B`@
M("`@("`@("`@("1T:&ES+3Y?<V5T071T<FEB=71E*"1E;'0L($Q!5%1?2$%3
M3D]#2$E,1%)%3BP@(21B;V]L*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!(87,@=&AE('1R964@96QE;65N="!B965N(&1I<V-O=F5R960_
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1E;'0@($$@=')E92!E;&5M
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@3F]N+7IE<F\@
M:68@=&AE(&5L96UE;G0@:&%S(&)E96X@9&ES8V]V97)E9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-$:7-C;W9E<F5D*"1E;'0I"B`@("!["B`@("`@("`@
M<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,5%])4U]$25-#3U9%4D5$
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D:7-C;W9E<F5D(&%T
M=')I8G5T92!F;W(@86X@96QE;65N="X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@("`@
M02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@
M5&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971$:7-C;W9E
M<F5D*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$%T
M=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?25-?1$E30T]615)%1"P@)&)O
M;VPI.PH@("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE('1R964@96QE;65N
M="!O<&5N/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!('1R
M964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1R
M=64@:68@=&AE(&5L96UE;G0@:7,@;W!E;BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7-/<&5N*"1E;'0I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7VEN
M:71M;V1E*2!["B`@("`@("`@("`@(')E='5R;B`H*"1E;'1;)V$G72`F($E-
M05!44D5%7T5,5%])4U]/4$5.*2`F)B`D=&AI<RT^:&%S0VAI;&1R96XH)&5L
M="DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('-W:71C:"`H)'1H
M:7,M/E]G971);FET17AP86YD961-;V1E*"DI('L*("`@("`@("`@("`@8V%S
M92!)34%05%)%15]/4$5.7TY/3D4Z"B`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A
M<V4@24U!4%12145?3U!%3E]!3$PZ"B`@("`@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92!)34%05%)%15]/4$5.7U5315(Z"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEN:71%>'!A;F1E9$QI<W0H*3L*("`@("`@("`@("`@("`@(')E='5R;B`A
M96UP='DH)'1H:7,M/E]E>'!A;F1E9%LD96QT6R=V)UU=*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T('1H92!O<&5N(&%T=')I8G5T92!F;W(@86X@
M96QE;65N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@("`@02!T<F5E(&5L96UE;G0N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@5&AE('-E='1I;F<N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]S971/<&5N*"8D96QT+"`D8F]O;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7W-E=$%T=')I8G5T92@D96QT+"!)34%05%)%
M15]%3%1?25-?3U!%3BP@)&)O;VPI.PH@("`@("`@(&EF("@A)'1H:7,M/E]I
M;FET;6]D92D@>PH@("`@("`@("`@("`D=&AI<RT^7VEN:71%>'!A;F1E9$QI
M<W0H*3L*("`@("`@("`@("`@:68@*"1B;V]L*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9$5X<&%N9&5D3&ES="@D96QT6R=V)UTI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]R96UO=F5%
M>'!A;F1E9$QI<W0H)&5L=%LG=B==*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H:7,@96QE;65N="!A(&-O
M;G1A:6YE<B!O;FQY+"!N;W0@82!M86EL8F]X("AM96%N:6YG('EO=2!C86X*
M("`@("`J(&YO="!O<&5N(&ET*3\*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4<G5E(&EF('1H92!E;&5M96YT(&ES(&$@8V]N=&%I;F5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;G1A:6YE<B@D96QT*0H@("`@
M>PH@("`@("`@(')E='5R;B`H*"1E;'1;)V$G72`F($Q!5%1?3D]314Q%0U0I
M('Q\"B`@("`@("`@("`@("`@("`H(21T:&ES+3Y?<VAO=W5N<W5B("8F"B`@
M("`@("`@("`@("`@("`@(21T:&ES+3YI<U-U8G-C<FEB960H)&5L="D@)B8*
M("`@("`@("`@("`@("`@("`D=&AI<RT^:&%S0VAI;&1R96XH)&5L="DI*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@96QE;65N="!A<R!A(&-O
M;G1A:6YE<C\*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@("`@02!T<F5E(&5L96UE;G0N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O;"`@27,@=&AE(&5L96UE;G0@
M82!C;VYT86EN97(_"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S971#;VYT86EN
M97(H)B1E;'0L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T071T
M<FEB=71E*"1E;'0L($Q!5%1?3D]314Q%0U0L("1B;V]L*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($ES('1H92!U<V5R('-U8G-C<FEB960@=&\@=&AI<R!E
M;&5M96YT/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D96QT("!!('1R
M964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1R
M=64@:68@=&AE('5S97(@:7,@<W5B<V-R:6)E9"!T;R!T:&4@96QE;65N="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-3=6)S8W)I8F5D*"1E;'0I"B`@("![
M"B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%7T5,5%])4U]3
M54)30U))0D5$.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!S=6)S
M8W)I<'1I;VX@<W1A='5S(&9O<B!A;B!E;&5M96YT+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F
M)&5L="`@("!!('1R964@96QE;65N="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1B;V]L("!)<R!T:&4@96QE;65N="!S=6)S8W)I8F5D('1O/PH@("`@("HO
M"B`@("!F=6YC=&EO;B!?<V5T4W5B<V-R:6)E9"@F)&5L="P@)&)O;VPI"B`@
M("!["B`@("`@("`@)'1H:7,M/E]S971!='1R:6)U=&4H)&5L="P@24U!4%12
M145?14Q47TE37U-50E-#4DE"140L("1B;V]L*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($ES('1H92!E;&5M96YT(&$@;F%M97-P86-E(&-O;G1A:6YE<C\*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE
M;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4<G5E(&EF('1H
M92!E;&5M96YT(&ES(&$@;F%M97-P86-E(&-O;G1A:6YE<C\*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-.86UE<W!A8V4H)&5L="D*("`@('L*("`@("`@("!R
M971U<FX@)&5L=%LG82==("8@24U!4%12145?14Q47TY!34534$%#13L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E;6]V92!T:&4@<V5R=F5R('-T<FEN9R!F
M<F]M('1H92`G;F%M92<@<&%R86UE=&5R+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@<W1D0VQA
M<W,@)&]B("!!;B!O8FIE8W0@<F5T=7)N960@9G)O;0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EM87!?9V5T;6%I;&)O>&5S*"DN"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=&1#;&%S<R`@5&AE(&]B:F5C="!R971U
M<FYE9"!W:71H('1H92!S97)V97(@<W1R:6YG('-T<FEP<&5D"B`@("`@*B`@
M("`@("`@("`@("`@("`@("!F<F]M('1H92`G;F%M92<@<&%R86UE=&5R+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<F5M;W9E4V5R=F5R4W1R:6YG*"1O8BD*
M("`@('L*("`@("`@("`D;V(M/F9U;&Q397)V97)0871H(#T@)&]B+3YN86UE
M.PH@("`@("`@("1O8BT^;F%M92`]("1T:&ES+3Y?8V]N=F5R=$YA;64H<W5B
M<W1R*"1O8BT^;F%M92P@<W1R<&]S*"1O8BT^;F%M92P@)WTG*2`K(#$I*3L*
M("`@("`@("!R971U<FX@)&]B.PH@("`@?0H*("`@("\J*@H@("`@("H@26YI
M=&EA;&EZ92!T:&4@97AP86YD960@9F]L9&5R(&QI<W0N"B`@("`@*B!42$E3
M($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*
M("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:71%>'!A;F1E9$QI
M<W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?97AP86YD960@/2!A<G)A>2@I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&%N(&5L96UE;G0@=&\@=&AE
M(&5X<&%N9&5D(&QI<W0N"B`@("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@
M1$5&24Y%1"!)3B!!3$P@4U5"0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S
M=')A8W0*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&5L96UE;G0@;F%M92!T;R!R
M96UO=F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]A9&1%>'!A;F1E9$QI<W0H
M)&ED*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E(&%N(&5L
M96UE;G0@9G)O;2!T:&4@97AP86YD960@;&ES="X*("`@("`J(%1(25,@3454
M2$]$(%-(3U5,1"!"12!$149)3D5$($E.($%,3"!354)#3$%34T53+@H@("`@
M("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@96QE
M;65N="!N86UE('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E
M;6]V945X<&%N9&5D3&ES="@D:60I"B`@("!["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);FET:6%L:7IE+V=E="!T:&4@;&ES="!O9B!E;&5M96YT<R!T;R!P
M;VQL+@H@("`@("H@5$A)4R!-151(3T0@4TA/54Q$($)%($1%1DE.140@24X@
M04Q,(%-50D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&QI<W0@;V8@96QE;65N=',@
M=&\@<&]L;"`H;F%M92!I;B!K97D@9FEE;&0I+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9710;VQL3&ES="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]P;VQL
M(#T@87)R87DH*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]P;VQL.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D(&5L96UE;G0@=&\@=&AE('!O;&P@;&ES
M="X*("`@("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$149)3D5$($E.($%,
M3"!354)#3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*
M("`@("`J($!P87)A;2!M:7AE9"`D:60@(%1H92!E;&5M96YT(&YA;64@;W(@
M82!L:7-T(&]F(&5L96UE;G0@;F%M97,@=&\@861D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A9&10;VQL3&ES="@D:60I"B`@("!["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296UO=F4@96QE;65N="!F<F]M('1H92!P;VQL(&QI<W0N"B`@
M("`@*B!42$E3($U%5$A/1"!32$]53$0@0D4@1$5&24Y%1"!)3B!!3$P@4U5"
M0TQ!4U-%4RX*("`@("`J"B`@("`@*B!`86)S=')A8W0*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&9O;&1E<B]M86EL8F]X(&]R(&$@
M;&ES="!O9B!F;VQD97)S+VUA:6QB;WAE<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@('1O(')E;6]V92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E
M4&]L;$QI<W0H)&ED*0H@("`@>PH@("`@?0H*("`@("\J*@H@("`@("H@1&]E
M<R!T:&4@=7-E<B!W86YT('1O('!O;&P@=&AI<R!M86EL8F]X(&9O<B!N97<O
M=6YS965N(&UE<W-A9V5S/PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M96QT("!!('1R964@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(%1R=64@:68@=&AE('5S97(@=V%N=',@=&\@<&]L;"!T:&4@96QE
M;65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-0;VQL960H)&5L="D*("`@
M('L*("`@("`@("!R971U<FX@)&5L=%LG82==("8@24U!4%12145?14Q47TE3
M7U!/3$Q%1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<&]L;&5D
M(&%T=')I8G5T92!F;W(@86X@96QE;65N="X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1E;'0@
M("`@02!T<F5E(&5L96UE;G0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8F]O
M;"`@5&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S9710;VQL
M960H)B1E;'0L("1B;V]L*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5T071T
M<FEB=71E*"1E;'0L($E-05!44D5%7T5,5%])4U]03TQ,140L("1B;V]L*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($9L86<@=&AE(&5L96UE;G0@87,@;F5E
M9&EN9R!I=',@8VAI;&1R96X@=&\@8F4@<V]R=&5D+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F
M)&5L="`@("!!('1R964@96QE;65N="X*("`@("`J($!P87)A;2!B;V]L96%N
M("1B;V]L("!4:&4@<V5T=&EN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E
M=$YE9613;W)T*"8D96QT+"`D8F]O;"D*("`@('L*("`@("`@("`D=&AI<RT^
M7W-E=$%T=')I8G5T92@D96QT+"!)34%05%)%15]%3%1?3D5%1%]33U)4+"`D
M8F]O;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$;V5S('1H:7,@96QE;65N
M="=S(&-H:6QD<F5N(&YE960@<V]R=&EN9S\*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)&5L="`@02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4<G5E(&EF('1H92!C:&EL9')E;B!N965D('1O
M(&)E('-O<G1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7VYE9613;W)T*"1E
M;'0I"B`@("!["B`@("`@("`@<F5T=7)N("1E;'1;)V$G72`F($E-05!44D5%
M7T5,5%].145$7U-/4E0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET:6%L
M:7IE('1H92!L:7-T(&]F('-U8G-C<FEB960@;6%I;&)O>&5S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M:6YI=%-U8G-C<FEB960H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T
M:&ES+3Y?<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@)'1H:7,M/E]C:&%N
M9V5D(#T@=')U93L*("`@("`@("`@("`@)'1H:7,M/E]S=6)S8W)I8F5D(#T@
M87)R87DH*3L*("`@("`@("`@("`@)'-U8FQI<W0@/2!A<G)A>2@I.PH*("`@
M("`@("`@("`@+RH@24Y"3U@@:7,@86QW87ES('-U8G-C<FEB960@=&\@:68@
M=V4@87)E(&EN(&UA:6P@;6]D92X@*B\*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?;6]D92`]/2!)34%05%)%15]-3T1%7TU!24PI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<W5B<V-R:6)E9%LG24Y"3U@G72`](#$["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VYA;65S<&%C97,I('L*
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;F%M97-P86-E<R!A
M<R`D=F%L*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]($!I;6%P7VQS
M=6(H)'1H:7,M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(L("1V86Q;
M)VYA;64G72`N("<J)RD["B`@("`@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W5B;&ES="`]
M(&%R<F%Y7VUE<F=E*"1S=6)L:7-T+"`D=&UP*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<W5B;&ES="`]($!I;6%P7VQS=6(H)'1H:7,M
M/E]G9713=')E86TH*2P@)'1H:7,M/E]S97)V97(L("1T:&ES+3Y?<')E9FEX
M("X@)RHG*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D<W5B;&ES="DI('L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S=6)L
M:7-T(&%S("1V86PI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-U
M8G-C<FEB961;<W5B<W1R*"1V86PL('-T<G!O<R@D=F%L+"`G?2<I("L@,2E=
M(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($EN:71I86QI>F4@=&AE(&QI<W0@
M;V8@=6YS=6)S8W)I8F5D(&UA:6QB;WAE<RX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN:715;G-U8G-C
M<FEB960H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?=6YS
M=6)S8W)I8F5D*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-H86YG960@/2!T
M<G5E.PH@("`@("`@("`@("`D=&AI<RT^7VEN:713=6)S8W)I8F5D*"D["B`@
M("`@("`@("`@("1T:&ES+3Y?=6YS=6)S8W)I8F5D(#T@87)R87DH*3L*("`@
M("`@("`@("`@)&%L;%]L:7-T(#T@87)R87DH*3L*"B`@("`@("`@("`@("\J
M($=E="!L:7-T(&]F(&%L;"!M86EL8F]X97,N("HO"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7VYA;65S<&%C97,I('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?;F%M97-P86-E<R!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1M<"`]($!I;6%P7VQI<W0H)'1H:7,M/E]G9713=')E86TH
M*2P@)'1H:7,M/E]S97)V97(L("1V86Q;)VYA;64G72`N("<J)RD["B`@("`@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D=&UP*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D86QL7VQI<W0@/2!A<G)A>5]M97)G92@D86QL7VQI
M<W0L("1T;7`I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1A
M;&Q?;&ES="`]($!I;6%P7VQI<W0H)'1H:7,M/E]G9713=')E86TH*2P@)'1H
M:7,M/E]S97)V97(L("1T:&ES+3Y?<')E9FEX("X@)RHG*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"%E;7!T>2@D86QL7VQI<W0I*2!["B`@
M("`@("`@("`@("`@("`O*B!&:6YD(&%L;"!M86EL8F]X97,@=&AA="!A<F5N
M)W0@:6X@=&AE('-U8G-C<FEB960@;&ES="X@*B\*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1A;&Q?;&ES="!A<R`D=F%L*2!["B`@("`@("`@("`@("`@
M("`@("`@)'9A;"`]('-U8G-T<B@D=F%L+"!S=')P;W,H)'9A;"P@)WTG*2`K
M(#$I.PH@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]S
M=6)S8W)I8F5D6R1V86Q=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W5N<W5B<V-R:6)E9%LD=F%L72`](#$["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4VAO=6QD('=E(&5X<&%N9"!A
M;&P@96QE;65N=',_"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&%N9$%L;"@I
M"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P87)E;G1;;G5L;%T@
M87,@)'9A;"D@>PH@("`@("`@("`@("`D=&AI<RT^97AP86YD*"1V86PL('1R
M=64I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-H;W5L9"!W
M92!C;VQL87!S92!A;&P@96QE;65N=',_"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;&QA<'-E06QL*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7W1R964@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("@D:V5Y
M("$]($E-05!44D5%7T)!4T5?14Q4*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^8V]L;&%P<V4H)'9A;%LG=B==*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@0VQE87(@86QL(&5N=')I97,@9G)O;2!T:&4@97AP
M86YD960@;&ES="X@*B\*("`@("`@("`D=&AI<RT^7VEN:71%>'!A;F1E9$QI
M<W0H*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V5X<&%N9&5D(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E;6]V945X<&%N
M9&5D3&ES="@D:V5Y*3L*("`@("`@("!]"@H@("`@?0H*("`@("\J*@H@("`@
M("H@4F5T=7)N('1H92!L:7-T(&]F(&UA:6QB;WAE<R!I;B!T:&4@;F5X="!L
M979E;"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE(&-U<G)E;G0@;6%I;&)O>"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@;6%I;&)O
M>"!O8FIE8W1S(&]R('1H92!E;7!T>2!L:7-T+@H@("`@("H@("`@("`@("`@
M("`@("`@4V5E(%]G971,:7-T*"D@9F]R(&9O<FUA="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-H:6QD<F5N26YF;R@D:60I"B`@("!["B`@("`@("`@)&EN
M9F\@/2!A<G)A>2@I.PH@("`@("`@("1N<U]I;F9O(#T@)'1H:7,M/E]G971.
M86UE<W!A8V4H)&ED*3L*"B`@("`@("`@:68@*&ES7VYU;&PH)&YS7VEN9F\I
M*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;SL*("`@("`@("!]"@H@("`@
M("`@(&EF("@H)&ED(#T]("=)3D)/6"<I("8F"B`@("`@("`@("`@("@D;G-?
M:6YF;ULG;F%M92==(#T]("@G24Y"3U@G("X@)&YS7VEN9F];)V1E;&EM:71E
M<B==*2DI('L*("`@("`@("`@("`@)'-E87)C:"`]("1I9"`N("1N<U]I;F9O
M6R=D96QI;6ET97(G72`N("1N<U]I;F9O6R=N86UE)UT["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'-E87)C:"`]("1I9"`N("1N<U]I;F9O6R=D
M96QI;6ET97(G73L*("`@("`@("!]"@H@("`@("`@("1I;F9O(#T@)'1H:7,M
M/E]G971,:7-T*"1S96%R8V@@+B`G)2<I.PH*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]T<F5E6R1I9%TI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5T
M0VAI;&1R96XH)'1H:7,M/E]T<F5E6R1I9%TL("%E;7!T>2@D:6YF;RDI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;F9O.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4W=I=&-H('-U8G-C<FEB960O=6YS=6)S8W)I8F5D('9I97=I
M;F<N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5N<W5B("!3:&]W
M('5N<W5B<V-R:6)E9"!E;&5M96YT<S\*("`@("`J+PH@("`@9G5N8W1I;VX@
M<VAO=U5N<W5B<V-R:6)E9"@D=6YS=6(I"B`@("!["B`@("`@("`@:68@*"1U
M;G-U8B`]/3T@)'1H:7,M/E]S:&]W=6YS=6(I('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]S:&]W=6YS=6(@/2`D
M=6YS=6(["B`@("`@("`@)'1H:7,M/E]C:&%N9V5D(#T@=')U93L*"B`@("`@
M("`@+RH@268@=V4@87)E('-W:71C:&EN9R!F<F]M('5N<W5B<V-R:6)E9"!T
M;R!S=6)S8W)I8F5D+"!N;R!N965D"B`@("`@("`@("H@=&\@9&\@86YY=&AI
M;F<@*'=E(&IU<W0@:6=N;W)E('5N<W5B<V-R:6)E9"!S='5F9BDN("HO"B`@
M("`@("`@:68@*"1U;G-U8B`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=V4@87)E('-W:71C:&EN
M9R!F<F]M('-U8G-C<FEB960@=&\@=6YS=6)S8W)I8F5D+"!W92!N965D"B`@
M("`@("`@("H@=&\@861D(&%L;"!U;G-U8G-C<FEB960@96QE;65N=',@=&AA
M="!L:79E(&EN(&-U<G)E;G1L>0H@("`@("`@("`J(&1I<V-O=F5R960@:71E
M;7,N("HO"B`@("`@("`@)'1H:7,M/E]U;G-U8G9I97<@/2!T<G5E.PH@("`@
M("`@("1T:&ES+3Y?:6YI=%5N<W5B<V-R:6)E9"@I.PH@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W5N<W5B<V-R:6)E9"DI('L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]I;FET;6]D92`]($E-
M05!44D5%7TE.251?54Y354(["B`@("`@("`@)'1H:7,M/FEN<V5R="AA<G)A
M>5]K97ES*"1T:&ES+3Y?=6YS=6)S8W)I8F5D*2D["B`@("`@("`@)'1H:7,M
M/E]I;FET;6]D92`](#`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M(&$@<F5F97)E;F-E('1O(&$@8W5R<F5N=&QY(&]P96X@24U!4"!S=')E86TN
M"B`@("`@*B!42$E3($U%5$A/1"!-55-4($)%($1%1DE.140@24X@04Q,(%-5
M0D-,05-315,N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!R97-O
M=7)C92`@06X@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9?9V5T4W1R96%M*"D*("`@('L*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!C=7)R96YT
M;'D@<V5L96-T960@:6YI=&EA;&EZ871I;VX@97AP86YD960@;6]D92X*("`@
M("`J(%1(25,@34542$]$(%-(3U5,1"!"12!$149)3D5$($E.($%,3"!354)#
M3$%34T53+@H@("`@("H*("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&-U<G)E;G0@:6YI=&EA;&EZ871I;VX@97AP86YD960@;6]D92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$EN:71%>'!A;F1E9$UO9&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!)34%05%)%15]/4$5.7TY/3D4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@:6YF;W)M871I;VX@86)O=70@;F5W+W5N
M<V5E;B]T;W1A;"!M97-S86=E<R!F;W(@=&AE(&=I=F5N(&5L96UE;G0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&5L96UE;G0@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!<G)A>2!W:71H
M('1H92!F;VQL;W=I;F<@9FEE;&1S.@H@("`@("H@/'!R93X*("`@("`J("=M
M97-S86=E<R<@("TM("!.=6UB97(@;V8@=&]T86P@;65S<V%G97,N"B`@("`@
M*B`G;F5W;7-G)R`@("`M+2`@3G5M8F5R(&]F(&YE=R!M97-S86=E<RX*("`@
M("`J("=U;G-E96XG("`@("TM("!.=6UB97(@;V8@=6YS965N(&UE<W-A9V5S
M+@H@("`@("H@/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$5L96UE
M;G1);F9O*"1N86UE*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2!A<G)A>2@I
M.PH*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O0V%C:&4N<&AP
M)SL*("`@("`@("`D:6UA<%]C86-H92`]("9)34%07T-A8VAE.CIS:6YG;&5T
M;VXH*3L*("`@("`@("`D<W1S(#T@)&EM87!?8V%C:&4M/F=E=%-T871U<R@D
M=&AI<RT^7V=E=%-T<F5A;2@I+"`D=&AI<RT^7W-E<G9E<B`N("1N86UE*3L*
M("`@("`@("!I9B`H(65M<'1Y*"1S=',I*2!["B`@("`@("`@("`@("1S=&%T
M=7-;)VUE<W-A9V5S)UT@/2`D<W1S+3YM97-S86=E<SL*("`@("`@("`@("`@
M)'-T871U<ULG=6YS965N)UT@/2!I<W-E="@D<W1S+3YU;G-E96XI(#\@)'-T
M<RT^=6YS965N(#H@,#L*("`@("`@("`@("`@)'-T871U<ULG;F5W;7-G)UT@
M/2!I<W-E="@D<W1S+3YR96-E;G0I(#\@)'-T<RT^<F5C96YT(#H@,#L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V]R=',@82!L:7-T(&]F(&UA:6QB;WAE<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)B1M8F]X("`@5&AE(&QI<W0@;V8@;6%I;&)O>&5S('1O('-O<G0N"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D8F%S92`@07)E('=E('-O<G1I;F<@82!L
M:7-T(&]F(&UA:6QB;WAE<R!I;B!T:&4@8F%S90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&]F('1H92!T<F5E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<V]R=$QI<W0H)B1M8F]X+"`D8F%S92`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?:6UA<%]S;W)T*2D@>PH@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TE-05`O4V]R="YP:'`G.PH@("`@
M("`@("`@("`D=&AI<RT^7VEM87!?<V]R="`]("9N97<@24U!4%]3;W)T*"1T
M:&ES+3Y?9&5L:6UI=&5R*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D8F%S
M92D@>PH@("`@("`@("`@("!F;W)E86-H("@D;6)O>"!A<R`D=F%L*2!["B`@
M("`@("`@("`@("`@("`D8F%S97-O<G1;)'9A;%T@/2`H)'9A;"`]/2`G24Y"
M3U@G*2`_("=)3D)/6"<@.B`D=&AI<RT^7W1R965;)'9A;%U;)VPG73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VEM87!?<V]R="T^<V]R
M=$UA:6QB;WAE<R@D8F%S97-O<G0L("@D=&AI<RT^7VUO9&4@/3T@24U!4%12
M145?34]$15]-04E,*2P@=')U92P@=')U92D["B`@("`@("`@("`@("1M8F]X
M(#T@87)R87E?:V5Y<R@D8F%S97-O<G0I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?:6UA<%]S;W)T+3YS;W)T36%I;&)O>&5S*"1M
M8F]X+"`H)'1H:7,M/E]M;V1E(#T]($E-05!44D5%7TU/1$5?34%)3"DI.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A($YO;BU)
M34%0(&UA:6QB;W@@96QE;65N="!G:79E;B!A;B!E;&5M96YT(&ED96YT:69I
M97(N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@
M(%1H92!E;&5M96YT(&ED96YT:69I97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@02!M86EL8F]X(&5L96UE;G0N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]G971.;VY)34%016QT*"1I9"D*("`@('L*("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($ES('1H92!G:79E;B!E
M;&5M96YT(&%N(")A8W1I=F4B(&5L96UE;G0@*&DN92X@86X@96QE;65N="!T
M:&%T('-H;W5L9`H@("`@("H@8F4@=V]R:V5D('=I=&@@9VEV96X@=&AE(&-U
M<G)E;G0@=FEE=VEN9R!P87)A;65T97)S*2X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&5L="`@
M02!T<F5E(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF(&ET(&ES(&%N(&%C=&EV92!E;&5M96YT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?86-T:79E16QT*"1E;'0I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3Y?<VAO=W5N<W5B("8F"B`@("`@("`@("`@("1T:&ES+3YI<TYA
M;65S<&%C92@D96QT*2D@>PH@("`@("`@("`@("!R971U<FX@*"1T:&ES+3YH
M87-#:&EL9')E;B@D96QT*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("@D=&AI<RT^7W-H;W=U;G-U8B!\?`H@("`@("`@("`@("`@
M("`@("`@("@D=&AI<RT^:7-3=6)S8W)I8F5D*"1E;'0I("8F("$D=&AI<RT^
M:7-#;VYT86EN97(H)&5L="DI('Q\"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FAA<T-H:6QD<F5N*"1E;'0I*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T(&$@;6%I;&)O>"!N86UE('1O('1H92!C;W)R
M96-T+"!I;G1E<FYA;"!N86UE("AI+F4N(&UA:V4@<W5R90H@("`@("H@24Y"
M3U@@:7,@86QW87ES(&-A<&ET86QI>F5D(&9O<B!)34%0('-E<G9E<G,I+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@(%1H92!M86EL8F]X(&YA;64N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;VYV97)T960@;F%M92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-O;G9E<G1.86UE*"1N86UE*0H@("`@>PH@
M("`@("`@(')E='5R;B`H*"1T:&ES+3Y?;6]D92`]/2!)34%05%)%15]-3T1%
M7TU!24PI("8F("AS=')C87-E8VUP*"1N86UE+"`G24Y"3U@G*2`]/2`P*2D@
M/R`G24Y"3U@G(#H@)&YA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M;F%M97-P86-E(&EN9F\@9F]R(&$@9G5L;"!F;VQD97(@<&%T:"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1M86EL8F]X("!4:&4@9F]L9&5R('!A=&@N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5&AE(&YA;65S<&%C92!I;F9O(&9O<B!T:&4@
M9F]L9&5R('!A=&@@;W(@;G5L;"!I9B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@('!A=&@@9&]E<VXG="!E>&ES="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$YA;65S<&%C92@D;6%I;&)O>"D*("`@('L*("`@("`@("!S=&%T:6,@
M)&YA;65S<&%C94-A8VAE(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES<V5T
M*"1N86UE<W!A8V5#86-H95LD;6%I;&)O>%TI*2!["B`@("`@("`@("`@(')E
M='5R;B`D;F%M97-P86-E0V%C:&5;)&UA:6QB;WA=.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7VYA;65S<&%C97,I*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;F%M97-P86-E<R!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@(&EF("@H*"1M86EL8F]X("X@)'9A
M;%LG9&5L:6UI=&5R)UTI(#T]("1K97DI('Q\"B`@("`@("`@("`@("`@("`@
M("`@*"%E;7!T>2@D:V5Y*2`F)B`H<W1R<&]S*"1M86EL8F]X+"`D:V5Y*2`]
M/3T@,"DI*2!["B`@("`@("`@("`@("`@("`@("`@)&YA;65S<&%C94-A8VAE
M6R1M86EL8F]X72`]("1V86P["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1V86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65S<&%C97-;)R==*2D@>PH@
M("`@("`@("`@("`@("`@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X72`]("1T
M:&ES+3Y?;F%M97-P86-E<ULG)UT["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]N86UE<W!A8V5S6R<G73L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&YA;65S<&%C94-A8VAE6R1M86EL8F]X72`](&YU;&P["B`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EF("AS=6)S='(H)'1H:7,M/E]P<F5F:7@L("TQ*2`]/2`D=&AI<RT^
M7V1E;&EM:71E<BD@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!S=6)S='(H
M)'1H:7,M/E]P<F5F:7@L(#`L('-T<FQE;B@D=&AI<RT^7W!R969I>"D@+2`Q
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1N86UE
M(#T@)'1H:7,M/E]P<F5F:7@["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)&YA;65S<&%C94-A8VAE6R1M86EL8F]X72`](&%R<F%Y*"=D96QI;6ET97(G
M(#T^("1T:&ES+3Y?9&5L:6UI=&5R+"`G;F%M92<@/3X@)&YA;64L("=T>7!E
M)R`]/B`G<&5R<V]N86PG*3L*("`@("`@("`@("`@<F5T=7)N("1N86UE<W!A
M8V5#86-H95LD;6%I;&)O>%T["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@1&]E<R!T:&4@24U!4"!S97)V97(@<W5P<&]R="!T:&4@)T-(24Q$
M4D5.)R!)34%0(&5X=&5N<VEO;C\*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<W5P<&]R="`@5')U92!I9B!T:&4@24U!4"!S97)V97(@<W5P<&]R
M=',@=&AE($-(24Q$4D5."B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@97AT96YS:6]N+"!F86QS92!I9B!I="!D;V5S;B=T+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!)34%08VAI;&1R96Y3=7!P;W)T*"1S=7!P;W)T*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y?8VAI;&1R96YS=7!P;W)T(#T@*&)O;VPI("1S
M=7!P;W)T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!S=&%R="!P
M;VEN="!F;W(@9&5T97)M:6YI;F<@96QE;65N="!D:69F97)E;F-E<R!V:6$@
M96QT1&EF9B@I+@H@("`@("H*("`@("`J($!S:6YC92!(;W)D92`S+C$*("`@
M("`J+PH@("`@9G5N8W1I;VX@96QT1&EF9E-T87)T*"D*("`@('L*("`@("`@
M("`D=&AI<RT^7V5L=&1I9F8@/2`D=&AI<RT^7W1R964["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(&QI<W0@;V8@96QE;65N=',@=&AA="!H
M879E(&-H86YG960@<VEN8V4@;F]D941I9F93=&%R="@I"B`@("`@*B!W87,@
M;&%S="!C86QL960N"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E(#,N,0H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($%N(&%R<F%Y('=I=&@@=&AE
M(&9O;&QO=VEN9R!K97ES.@H@("`@("H@/'!R93X*("`@("`J("=A)R`]/B!!
M(&QI<W0@;V8@96QE;65N=',@=&AA="!H879E(&)E96X@861D960N"B`@("`@
M*B`G8R<@/3X@02!L:7-T(&]F(&5L96UE;G1S('1H870@:&%V92!B965N(&-H
M86YG960N"B`@("`@*B`G9"<@/3X@02!L:7-T(&]F(&5L96UE;G1S('1H870@
M:&%V92!B965N(&1E;&5T960N"B`@("`@*B`\+W!R93X*("`@("`J("`@("`@
M("`@("`@("`@(%)E='5R;G,@9F%L<V4@:68@;F\@8VAA;F=E<R!H879E(&]C
M8W5R<F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!E;'1$:69F*"D*("`@('L*
M("`@("`@("!I9B`H(21T:&ES+3Y?8VAA;F=E9"!\?"`A)'1H:7,M/E]E;'1D
M:69F*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("1A9&1E9"`]("1C:&%N9V5D(#T@)&1E;&5T960@/2!A<G)A>2@I
M.PH*("`@("`@("`O*B!$971E<FUI;F4@=&AE(&1E;&5T960@:71E;7,N("HO
M"B`@("`@("`@)&1E;&5T960@/2!A<G)A>5]V86QU97,H87)R87E?9&EF9BAA
M<G)A>5]K97ES*"1T:&ES+3Y?96QT9&EF9BDL(&%R<F%Y7VME>7,H)'1H:7,M
M/E]T<F5E*2DI.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W1R964@87,@
M)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]E;'1D:69F6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@)&%D9&5D6UT@
M/2`D:V5Y.PH@("`@("`@("`@("!](&5L<V5I9B`H)'9A;"`A/2`D=&AI<RT^
M7V5L=&1I9F9;)&ME>5TI('L*("`@("`@("`@("`@("`@("1C:&%N9V5D6UT@
M/2`D:V5Y.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H
M96UP='DH)&%D9&5D*2`F)B!E;7!T>2@D8VAA;F=E9"D@)B8@96UP='DH)&1E
M;&5T960I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)V$G(#T^("1A9&1E
M9"P@)V,G(#T^("1C:&%N9V5D+"`G9"<@/3X@)&1E;&5T960I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BHJ*B!$97!R96-A=&5D('9A<FEA8FQE<R]F=6YC
M=&EO;G,N(%1H97-E(')E;6%I;B!F;W(@0D,@;VYL>2X@*BHJ*B\*"B`@("`O
M*BH*("`@("`J(%1H92!P<F5F:7@@=VET:&]U="!A('1R86EL:6YG(&1E;&EM
M:71E<BX*("`@("`J"B`@("`@*B!`9&5P<F5C871E9"!S:6YC92!(;W)D92`S
M+C$*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R969I
M>&YO9&5L:6T@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!S97)V97(@<W1R
M:6YG('5S960@9F]R('1H92!D96QI;6ET97(N"B`@("`@*B!42$E3(%-(3U5,
M1"!"12!3150@24X@159%4ED@4U5"0TQ!4U,@0T].4U1254-43U(N"B`@("`@
M*@H@("`@("H@0&1E<')E8V%T960@<VEN8V4@2&]R9&4@,RXQ"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]D96QI;6ET97(@/2`G+R<[
M"@H@("`@+RHJ"B`@("`@*B!7:&5R92!W92!S=&%R="!L:7-T:6YG(&9O;&1E
M<G,N"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@24X@159%4ED@4U5"0TQ!
M4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN
M8V4@2&]R9&4@,RXQ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]P<F5F:7@@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H92!L;V-A=&EO
M;B!O9B!T:&4@9FER<W0@;&5V96P@;V8@9F]L9&5R<R!B96QO=R!T:&4@24Y"
M3U@N"B`@("`@*B!42$E3(%-(3U5,1"!"12!3150@24X@159%4ED@4U5"0TQ!
M4U,@0T].4U1254-43U(N"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@<VEN
M8V4@2&]R9&4@,RXQ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]N86UE<W!A8V4@/2`G)SL*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D
M;W1F:6QE<R!B92!S:&]W;C\*("`@("`J(%1(25,@4TA/54Q$($)%(%-%5"!)
M3B!%5D5262!354)#3$%34R!#3TY35%)50U1/4BX*("`@("`J"B`@("`@*B!`
M=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?9&]T9FEL97,@/2!F86QS
M93L*"B`@("`O*BH*("`@("`J(%1H92!E>&ES=&5N8V4@;V8@=&AI<R!F=6YC
M=&EO;B!I;B!)34%07U1R964@:6YD:6-A=&5S('1H870@97AT96YD960*("`@
M("`J(&YA;65S<&%C92!S=7!P;W)T(&ES(&%V86EL86)L92X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@(%)E='5R;G,@=')U92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@97AT96YD961.86UE<W!A8V53=7!P;W)T*"D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@<')E9FEX+@H@("`@("H*("`@("`J($!D97!R96-A=&5D('-I
M;F-E($AO<F1E(#,N,0H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P<F5F
M:7@@=VAE<F4@9F]L9&5R<R!B96=I;B!T;R!B92!L:7-T960N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!R969I>"@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<')E9FEX.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&EN
M9F]R;6%T:6]N(&%B;W5T(&$@<W!E8VEF:6,@;6%I;&)O>"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!D97!R96-A=&5D('-I;F-E
M($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M(%1H92!M86EL8F]X('1O('%U97)Y+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1D0VQA<W,@(%-E92!I;6%P7V=E=&UA:6QB;WAE<R@I+B`@5&AE('-E<G9E
M<B!S=')I;F<@:&%S"B`@("`@*B`@("`@("`@("`@("`@("`@("!A;')E861Y
M(&)E96X@<F5M;W9E9"!F<F]M('1H92`G;F%M92<@<&%R86UE=&5R+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5T36%I;&)O>"@D<&%T:"D*("`@('L*("`@
M("`@("`D8F]X(#T@)'1H:7,M/E]G971,:7-T*"1P871H*3L*("`@("`@("!I
M9B`H96UP='DH)&)O>"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!R97-E="@D8F]X
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-86ME('-U<F4@
M=&AE<F4@:7,@;F\@=')A:6QI;F<@9&5L:6UI=&5R(&]N('1H92!E;&5M96YT
M(&YA;64N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&5L96UE;G0@;F%M92X*("`@("`J($!D97!R96-A=&5D('-I;F-E($AO<F1E
M(#,N,0H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@96QE;65N
M="!N86UE('=I=&@@86YY('1R86EL:6YG(&1E;&EM:71E<B!S=')I<'!E9`H@
M("`@("H@("`@("`@("`@("`@("`@(&]F9BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F]4<F%I;&EN9T1E;&EM:71E<B@D;F%M92D*("`@('L*("`@("`@("`D
M;G-?:6YF;R`]("1T:&ES+3Y?9V5T3F%M97-P86-E*"1N86UE*3L*("`@("`@
M("!I9B`H<W5B<W1R*"1N86UE+"`M,2D@/3T@)&YS7VEN9F];)V1E;&EM:71E
M<B==*2!["B`@("`@("`@("`@("1N86UE(#T@<W5B<W1R*"1N86UE+"`P+"!S
M=')L96XH)&YA;64I("T@,2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&YA;64["B`@("!]"@H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0+U1H<F5A9"YP:'``````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-30W-B`Q,#4Q-30S
M-#$S-R`P,C(P,S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J($E-05!?5&AR96%D('!R;W9I9&5S(&9U
M;F-T:6]N<R!F;W(@=V]R:VEN9R!W:71H(&EM87!?=&AR96%D*"D@;W5T<'5T
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R])34%0+TE-05`O5&AR96%D+G!H
M<"QV(#$N-"XQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C(Q(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($UI8VAA96P@4VQU<V%R>B`\<VQU
M<V%R>D!C=7)E8V%N=&DN;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!C=7)E8V%N=&DN;W)G/@H@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*
M8VQA<W,@24U!4%]4:')E860@>PH*("`@("\J*@H@("`@("H@:6UA<%]T:')E
M860H*2!O=71P=70N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO
M"B`@("!V87(@)%]T:')E861A<G)A>3L*"B`@("`O*BH*("`@("`J($EN=&5R
M;F%L('1H<F5A9"!D871A('-T<G5C='5R92X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7W1H<F5A9"`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!!<G)A>2!I;F1E>"!T;R!-97-S86=E(&EN9&5X(&QO
M;VMU<"!A<G)A>2X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7VQO;VMU<"`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]B("!/
M=71P=70@9G)O;2!I;6%P7W1H<F5A9"@I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!)34%07U1H<F5A9"@D;V(I"B`@("!["B`@("`@("`@)'1H:7,M/E]T:')E
M861A<G)A>2`]("1O8CL*("`@("`@("`D=&AI<RT^7W!R;V-E<W-3=')U8W1U
M<F4H*3L*("`@('T*"B`@("\J*@H@("`@("H@1V5T<R!T:&4@:6YD96YT:6]N
M(&QE=F5L(&9O<B!A;B!)34%0(&UE<W-A9V4@:6YD97@N"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X("!4:&4@24U!4"!M97-S86=E(&EN
M9&5X+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%)E='5R;G,@=&AE
M('1H<F5A9"!I;F1E;G0@;&5V96P@:68@)&EN9&5X(&9O=6YD+@H@("`@("H@
M("`@("`@("`@("`@("`@4F5T=7)N<R!F86QS92!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G9714:')E861);F1E;G0H)&EN9&5X*0H@("`@
M>PH@("`@("`@("1K97D@/2`D=&AI<RT^7V=E=$ME>2@D:6YD97@I.PH@("`@
M("`@(&EF("@A:7-?;G5L;"@D:V5Y*2D@>PH@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]T:')E861;)&ME>5U;)VQE=F5L)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]T:')E861;)&ME>5U;)VQE=F5L)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!B87-E('1H<F5A
M9"!I;F1E>"!F;W(@86X@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@;65S<V%G92!I
M;F1E>"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!2971U<FYS('1H
M92!B87-E($E-05`@:6YD97@@:68@)&EN9&5X(&ES('!A<G0@;V8@80H@("`@
M("H@("`@("`@("`@("`@("`@=&AR96%D+@H@("`@("H@("`@("`@("`@("`@
M("`@4F5T=7)N<R!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G9714:')E861"87-E*"1I;F1E>"D*("`@('L*("`@("`@("`D:V5Y
M(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@("`@("!I9B`H(6ES7VYU
M;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7W1H
M<F5A9%LD:V5Y75LG8F%S92==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?=&AR96%D6R1K97E=6R=B87-E)UT["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O
M*BH*("`@("`J($ES('1H:7,@:6YD97@@=&AE(&QA<W0@:6X@=&AE(&-U<G)E
M;G0@;&5V96P_"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&EN9&5X
M("!4:&4@24U!4"!M97-S86=E(&EN9&5X+@H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;&5A;B`@4F5T=7)N<R!T<G5E(&EF("1I;F1E>"!I<R!T:&4@;&%S
M="!E;&5M96YT(&EN('1H90H@("`@("H@("`@("`@("`@("`@("`@("!C=7)R
M96YT('1H<F5A9"!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@4F5T
M=7)N<R!F86QS92!I9B!N;W0L(&]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&QA<W1);DQE=F5L*"1I;F1E>"D*("`@('L*("`@("`@("`D
M:V5Y(#T@)'1H:7,M/E]G971+97DH)&EN9&5X*3L*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&ME>2DI('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7W1H<F5A9%LD:V5Y75LG;&%S="==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=&AR96%D6R1K97E=6R=L87-T)UT["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("`O*BH*("`@("`J($1O('1H92!M97-S86=E(&EN9&5X("T^(&%R<F%Y(&EN
M9&5X(&QO;VMU<"X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:6YD97@@(%1H92!)34%0(&UE
M<W-A9V4@:6YD97@N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M(&%R<F%Y(&EN9&5X('9A;'5E(&]R(&YU;&P@:68@;F\@:6YD97@N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]G971+97DH)&EN9&5X*0H@("`@>PH@("`@("`@
M(')E='5R;B`H:7-S970H)'1H:7,M/E]L;V]K=7!;)&EN9&5X72DI(#\@)'1H
M:7,M/E]L;V]K=7!;)&EN9&5X72`Z(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FX@=&AE('-O<G1E9"!L:7-T(&]F(&UE<W-A9V5S(&EN9&EC
M97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&YE=R`@5')U92!F
M;W(@;F5W97-T(&9I<G-T+"!F86QS92!F;W(@;VQD97-T(&9I<G-T+@H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!S;W)T960@;&ES="!O9B!M
M97-S86=E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@;65S<V%G94QI<W0H)&YE
M=RD*("`@('L*("`@("`@("!R971U<FX@*"1N97<I(#\@87)R87E?<F5V97)S
M92AA<G)A>5]K97ES*"1T:&ES+3Y?;&]O:W5P*2D@.B!A<G)A>5]K97ES*"1T
M:&ES+3Y?;&]O:W5P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&QI<W0@;V8@;65S<V%G97,@:6X@=&AE(&-U<G)E;G0@=&AR96%D+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1I;F1E>"`@5&AE($E-05`@
M:6YD97@@;V8@=&AE(&-U<G)E;G0@;65S<V%G92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@24U!4"!M97-S86=E(&EN9&EC97,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%1H<F5A9"@D:6YD97@I"B`@("![
M"B`@("`@("`@+RH@1FEN9"!T:&4@8F5G:6YN:6YG(&]F('1H92!T:')E860N
M("HO"B`@("`@("`@)&)E9VEN(#T@)'1H:7,M/F=E=%1H<F5A9$)A<V4H)&EN
M9&5X*3L*("`@("`@("`D:V5Y(#T@)'1H:7,M/E]G971+97DH)&)E9VEN*3L*
M("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y*2!\?"!E;7!T>2@D8F5G:6XI*2![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D:6YD97@I.PH@("`@("`@('T*
M"B`@("`@("`@+RH@5V]R:R!F;W)W87)D(&9R;VT@=&AE(&9I<G-T('1H<F5A
M9"!E;&5M96YT('1O(&9I;F0@=&AE(&5N9"!O9B!T:&4*("`@("`@("`@*B!T
M:')E860N("HO"B`@("`@("`@)'1H<F5A9%]L:7-T(#T@87)R87DH)'1H:7,M
M/E]T:')E861;)&ME>5U;)VEN9&5X)UTI.PH@("`@("`@('=H:6QE("@K*R1K
M97DI('L*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1H<F5A9%LD
M:V5Y72DI('L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1C=7)R(#T@)'1H:7,M/E]T:')E861;)&ME>5T["B`@
M("`@("`@("`@(&EF("@D8W5R<ELG8F%S92==(#T]("1B96=I;BD@>PH@("`@
M("`@("`@("`@("`@)'1H<F5A9%]L:7-T6UT@/2`D=&AI<RT^7W1H<F5A9%LD
M:V5Y75LG:6YD97@G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'1H<F5A9%]L:7-T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4')O8V5S<R!T:&4@;W5T<'5T(&9R;VT@:6UA<%]T:')E860H*2!I;G1O(&%N
M(&EN=&5R;F%L(&1A=&$@<W1R=6-T=7)E+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<')O8V5S<U-T<G5C
M='5R92@I"B`@("!["B`@("`@("`@)&-O;G1A:6YE<B`]("1C;VYT86EN97)?
M8F%S92`]("1L87-T7VEN9&5X(#T@)'1H<F5A9%]B87-E(#T@)'1H<F5A9%]B
M87-E7VED>"`]("!N=6QL.PH@("`@("`@("1I;F1I8V5S(#T@87)R87DH*3L*
M("`@("`@("`D:2`]("1L87-T7VD@/2`D;&5V96P@/2`P.PH*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^7W1H<F5A9&%R<F%Y(&%S("1K97D@/3X@)'9A;"D@
M>PH@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1K97DL("<N)RD["B`@("`@
M("`@("`@("1I;F1E>"`]('-U8G-T<B@D:V5Y+"`P+"`D<&]S*3L*("`@("`@
M("`@("`@)'1Y<&4@/2!S=6)S='(H)&ME>2P@)'!O<R`K(#$I.PH*("`@("`@
M("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C87-E("=N=6TG
M.@H@("`@("`@("`@("`@("`@:68@*"1V86P@/3T](#`I('L*("`@("`@("`@
M("`@("`@("`@("`D8V]N=&%I;F5R(#T@)&EN9&5X.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1C;VYT86EN97(I("8F(&5M<'1Y
M*"1L979E;"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H<F5A9%]B
M87-E(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H<F5A9%]B
M87-E7VED>"`]("1I;F1E>#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]L;V]K=7!;)'9A;%T@/2`D:6YD97@[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;)&EN9&5X72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T:')E861;
M)&EN9&5X75LG:6YD97@G72`]("1V86P["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)VYE>'0G
M.@H@("`@("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1C;VYT86EN97(I("8F
M("@D8V]N=&%I;F5R(#T]/2`D:6YD97@I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-O;G1A:6YE<E]B87-E(#T@)'1H:7,M/E]T:')E861A<G)A>5LD=F%L
M("X@)RYN=6TG73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7VYU;&PH)&-O;G1A:6YE<BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]T:')E861;)&EN9&5X75LG8F%S92==(#T@)&-O;G1A:6YE<E]B
M87-E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I;F1E>%U;)V)A<V4G72`]
M("@A96UP='DH)&QE=F5L*2!\?"`H)'9A;"`A/2`P*2D@/R`D=&AR96%D7V)A
M<V4@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D;&5V96PK*SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G8G)A;F-H)SH*("`@
M("`@("`@("`@("`@(&EF("@D8V]N=&%I;F5R(#T]/2`D:6YD97@I('L*("`@
M("`@("`@("`@("`@("`@("`D8V]N=&%I;F5R(#T@)&-O;G1A:6YE<E]B87-E
M(#T@;G5L;#L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1H<F5A9%LD
M;&%S=%]I;F1E>%U;)VQA<W0G72`]('1R=64["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&AR96%D6R1I
M;F1E>%U;)VQE=F5L)UT@/2`D;&5V96PM+3L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W1H<F5A9%LD:6YD97A=6R=L87-T)UT@/2`A*"%I<U]N=6QL
M*"1C;VYT86EN97(I("8F(&5M<'1Y*"1L979E;"DI.PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D:6YD97@@/3T]("1T:')E861?8F%S95]I9'@I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9&5X(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1L979E;"D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(6ES7VYU;&PH)&QA<W1?:6YD97@I
M("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES
M+3Y?=&AR96%D6R1L87-T7VEN9&5X72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]T:')E861;)&QA<W1?:6YD97A=6R=L87-T)UT@/2`H
M)&QA<W1?:2`]/2`H)&D@+2`Q*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&QA<W1?:6YD97@@
M/2`D:6YD97@["B`@("`@("`@("`@("`@("`D;&%S=%]I(#T@)&DK*SL*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92])34%0+U-O<G0N<&AP````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P-S$P-2`Q,#4Q-30S-#$S-R`P,C$U,S8`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J($E-05!?4V]R="!P<F]V:61E<R!F=6YC=&EO;G,@9F]R('-O<G1I
M;F<@;&ES=',@;V8@24U!4"!M86EL8F]X97,O9F]L9&5R<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO24U!4"])34%0+U-O<G0N<&AP+'8@,2XV+C@N,3,@
M,C`P-B\P,B\Q-2`Q.#HP-SHU,B!S;'5S87)Z($5X<"`D"B`J"B`J($-O<'ER
M:6=H="`R,#`T+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O
M<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($UI
M8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3X*
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TE-05`*
M("HO"F-L87-S($E-05!?4V]R="!["@H@("`@+RHJ"B`@("`@*B!4:&4@9&5L
M:6UI=&5R(&-H87)A8W1E<B!T;R!U<V4N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?9&5L:6UI=&5R.PH*("`@("\J*@H@
M("`@("H@4VAO=6QD('=E('-O<G0@=VET:"`G24Y"3U@G(&%T('1H92!F<F]N
M="!O9B!T:&4@;&ES=#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?<V]R=&EN8F]X.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5L:6UI
M=&5R("!4:&4@9&5L:6UI=&5R('5S960@=&\@<V5P87)A=&4@;6%I;&)O>&5S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07U-O<G0H)&1E;&EM:71E<BD*
M("`@('L*("`@("`@("`D=&AI<RT^7V1E;&EM:71E<B`]("1D96QI;6ET97([
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3;W)T(&$@;&ES="!O9B!M86EL8F]X
M97,@*&)Y('9A;'5E*2X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)B1M
M8F]X("`@(%1H92!L:7-T(&]F(&UA:6QB;WAE<R!T;R!S;W)T+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&EN8F]X("!7:&5N('-O<G1I;F<L(&%L=V%Y<R!P
M=70@)TE.0D]8)R!A="!T:&4@:&5A9"!O9@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@;&ES=#\*("`@("`J($!P87)A;2!B;V]L96%N("1I
M;F1E>"`@36%I;G1A:6X@:6YD97@@87-S;V-I871I;VX_"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-O<G1-86EL8F]X97,H)B1M8F]X+"`D:6YB;W@@/2!T<G5E
M+"`D:6YD97@@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W-O<G1I
M;F)O>"`]("1I;F)O>#L*("`@("`@("!I9B`H)&EN9&5X*2!["B`@("`@("`@
M("`@('5A<V]R="@D;6)O>"P@87)R87DH)B1T:&ES+"`G7VUB;WA?8VUP)RDI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5S;W)T*"1M8F]X+"!A
M<G)A>2@F)'1H:7,L("=?;6)O>%]C;7`G*2D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V]R="!A(&QI<W0@;V8@;6%I;&)O>&5S("AB>2!K
M97DI+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`F)&UB;W@@("`@5&AE
M(&QI<W0@;V8@;6%I;&)O>&5S('1O('-O<G0L('=I=&@@=&AE(&ME>7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@8F5I;F<@=&AE(&UA:6QB;W@@
M;F%M97,N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:6YB;W@@(%=H96X@<V]R
M=&EN9RP@86QW87ES('!U="`G24Y"3U@G(&%T('1H92!H96%D(&]F"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@('1H92!L:7-T/PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S;W)T36%I;&)O>&5S0GE+97DH)B1M8F]X+"`D:6YB;W@@
M/2!T<G5E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]R=&EN8F]X(#T@)&EN
M8F]X.PH@("`@("`@('5K<V]R="@D;6)O>"P@87)R87DH)B1T:&ES+"`G7VUB
M;WA?8VUP)RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@2&EE<F%R8VAI8V%L
M(&9O;&1E<B!S;W)T:6YG(&9U;F-T:6]N("AU<V5D('=I=&@@=7-O<G0H*2DN
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D82`@0V]M<&%R:7-O;B!I=&5M(#$N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1B("!#;VUP87)I<V]N(&ET96T@,BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN=&5G97(@(%-E92!U<V]R="@I+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;6)O>%]C;7`H)&$L("1B*0H@("`@>PH@("`@("`@("\J
M($%L=V%Y<R!R971U<FX@24Y"3U@@87,@(G-M86QL97(B+B`J+PH@("`@("`@
M(&EF("@D=&AI<RT^7W-O<G1I;F)O>"D@>PH@("`@("`@("`@("!I9B`H<W1R
M8V%S96-M<"@D82P@)TE.0D]8)RD@/3T@,"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("TQ.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@D
M8BP@)TE.0D]8)RD@/3T@,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(#$[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1A7W!A<G1S(#T@
M97AP;&]D92@D=&AI<RT^7V1E;&EM:71E<BP@)&$I.PH@("`@("`@("1B7W!A
M<G1S(#T@97AP;&]D92@D=&AI<RT^7V1E;&EM:71E<BP@)&(I.PH*("`@("`@
M("`D85]C;W5N="`](&-O=6YT*"1A7W!A<G1S*3L*("`@("`@("`D8E]C;W5N
M="`](&-O=6YT*"1B7W!A<G1S*3L*"B`@("`@("`@)&E-87@@/2!M:6XH)&%?
M8V]U;G0L("1B7V-O=6YT*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&E-87@[("1I*RLI('L*("`@("`@("`@("`@:68@*"1A7W!A<G1S6R1I72`A
M/2`D8E]P87)T<ULD:5TI('L*("`@("`@("`@("`@("`@("\J($EF(&]N;'D@
M;VYE(&]F('1H92!F;VQD97)S(&ES('5N9&5R($E.0D]8+"!R971U<FX@:70@
M87,*("`@("`@("`@("`@("`@("`J(")S;6%L;&5R(BX@*B\*("`@("`@("`@
M("`@("`@(&EF("@D=&AI<RT^7W-O<G1I;F)O>"`F)B`H)&D@/3T@,"DI('L*
M("`@("`@("`@("`@("`@("`@("`D85]B87-E(#T@*'-T<F-A<V5C;7`H)&%?
M<&%R='-;,%TL("=)3D)/6"<I(#T](#`I.PH@("`@("`@("`@("`@("`@("`@
M("1B7V)A<V4@/2`H<W1R8V%S96-M<"@D8E]P87)T<ULP72P@)TE.0D]8)RD@
M/3T@,"D["B`@("`@("`@("`@("`@("`@("`@:68@*"1A7V)A<V4@)B8@(21B
M7V)A<V4I('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("TQ.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS96EF("@A)&%?8F%S92`F)B`D8E]B
M87-E*2!["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`Q.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1C;7`@/2!S=')N871C87-E8VUP*"1A7W!A<G1S6R1I72P@)&)?
M<&%R='-;)&E=*3L*("`@("`@("`@("`@("`@(&EF("@D8VUP(#T](#`I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@<W1R8VUP*"1A7W!A<G1S6R1I
M72P@)&)?<&%R='-;)&E=*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(')E='5R;B`D8VUP.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@*"1A7V-O=6YT("T@)&)?8V]U;G0I.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T-A8VAE+G!H<```
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C$U-2`Q,#4Q
M-30S-#$S-R`P,C$V,3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H92!)34%07T-A8VAE.CH@8VQA
M<W,@9F%C:6QI=&%T97,@:6X@8V%C:&EN9R!O=71P=70@9G)O;2!T:&4@4$A0
M(&EM87`*("H@97AT96YS:6]N(&EN('1H92!C=7)R96YT('-E<W-I;VXN"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+TE-05`O24U!4"]#86-H92YP:'`L=B`Q
M+C0N,3(N,3$@,C`P-B\P-"\R."`Q-3HT,SHT,"!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S
M87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O9W!L+FAT;6PN"B`J"B`J($!A
M=71H;W(@($UI8VAA96P@4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R
M861O+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO
M<F1E7TE-05`*("HO"F-L87-S($E-05!?0V%C:&4@>PH*("`@("\J*@H@("`@
M("H@4&]I;G1E<B!T;R!T:&4@<V5S<VEO;B!C86-H92X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A8VAE.PH*("`@("\J
M*@H@("`@("H@5&AE(&-A8VAE9"!R97-U;'1S(&]F(&EM87!?<W1A='5S*"D@
M8V%L;',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)%]S=&%T=7-C86-H92`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&$@<F5F97)E;F-E('1O('1H92!G;&]B86P@24U!4%]#86-H92!O
M8FIE8W0L(&]N;'D@8W)E871I;F<*("`@("`J(&ET(&EF(&ET(&1O97-N)W0@
M86QR96%D>2!E>&ES="X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T
M(&)E(&EN=F]K960@87,Z"B`@("`@*B`@("1I;6%P7V-A8VAE(#T@)DE-05!?
M0V%C:&4Z.G-I;F=L971O;B@I.PH@("`@("H*("`@("`J($!R971U<FX@24U!
M4%]#86-H92`@5&AE($E-05!?0V%C:&4@:6YS=&%N8V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9S:6YG;&5T;VXH*0H@("`@>PH@("`@("`@('-T871I8R`D
M;V)J96-T.PH*("`@("`@("!I9B`H(6ES<V5T*"1O8FIE8W0I*2!["B`@("`@
M("`@("`@("1O8FIE8W0@/2!N97<@24U!4%]#86-H92@I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1O8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!)34%07T-A8VAE
M*"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1?4T534TE/3ELG:6UA<%]C
M86-H92==*2D@>PH@("`@("`@("`@("`D7U-%4U-)3TY;)VEM87!?8V%C:&4G
M72`](&%R<F%Y*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?8V%C:&4@
M/2`F)%]315-324].6R=I;6%P7V-A8VAE)UT["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!'970@9&%T82!F<F]M('1H92!C86-H92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)&EM87`@("!4:&4@24U!4"!R97-O=7)C92!S=')E
M86TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1M86EL8F]X("!4:&4@9G5L;"`H
M>VAO<W1N86UE?6UA:6QB;W@I(&UA:6QB;W@@;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&ME>2`@("`@(%1H92!N86UE(&]F(&$@<W!E8VEF:6,@96YT
M<GD@=&\@<F5T=7)N+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&-H96-K("`@
M0VAE8VL@9F]R('5P9&%T960@;6%I;&)O>#\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4:&4@9&%T82!R97%U97-T960L(&]R(&9A;'-E(&EF(&YO
M="!A=F%I;&%B;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A8VAE*"1I
M;6%P+"`D;6%I;&)O>"P@)&ME>2`](&YU;&PL("1C:&5C:R`]('1R=64I"B`@
M("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C:&5;)&UA:6QB;WA=
M*2D@>PH@("`@("`@("`@("!I9B`H(21C:&5C:R!\?"`D=&AI<RT^8VAE8VM#
M86-H92@D:6UA<"P@)&UA:6QB;W@I*2!["B`@("`@("`@("`@("`@("`D<'1R
M(#T@)B1T:&ES+3Y?8V%C:&5;)&UA:6QB;WA=.PH@("`@("`@("`@("`@("`@
M:68@*"%I<U]N=6QL*"1K97DI*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P=');)V0G75LD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1P=');)V0G75LD:V5Y73L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<'1R6R=D)UT["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@27,@=&AE(&-A8VAE(&EN9F]R;6%T:6]N
M('5P+71O+61A=&4_"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1I
M;6%P("`@5&AE($E-05`@<F5S;W5R8V4@<W1R96%M+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T;F%M97UM86EL8F]X
M*2!M86EL8F]X(&YA;64N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=7!D871E
M("!3:&]U;&0@=&AE(&-A8VAE($E$('-T<FEN9R!B92!U<&1A=&5D/PH@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!C86-H92!I;F9O
M<FUA=&EO;B!U<"UT;RUD871E+"!F86QS92!I9B!N;W0N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-H96-K0V%C:&4H)&EM87`L("1M86EL8F]X+"`D=7!D871E
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8V%C
M:&5;)&UA:6QB;WA=*2D@>PH@("`@("`@("`@("`D:60@/2`D=&AI<RT^7V=E
M=$-A8VAE240H)&EM87`L("1M86EL8F]X*3L*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?8V%C:&5;)&UA:6QB;WA=6R=K)UT@/3T@)&ED*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1U
M<&1A=&4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=&]R94-A8VAE*"1I
M;6%P+"`D;6%I;&)O>"D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I
M9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI<RT^<W1O<F5#86-H92@D
M:6UA<"P@)&UA:6QB;W@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!D871A(&EN('1H92!C
M86-H92X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)&EM87`@("!4
M:&4@24U!4"!R97-O=7)C92!S=')E86TN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1M86EL8F]X("!4:&4@9G5L;"`H>VAO<W1N86UE?6UA:6QB;W@I(&UA:6QB
M;W@@;F%M92X*("`@("`J($!P87)A;2!A<G)A>2`D=F%L=65S("`@(%1H92!D
M871A('1O(&%D9"!T;R!T:&4@8V%C:&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-T;W)E0V%C:&4H)&EM87`L("1M86EL8F]X+"`D=F%L=65S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8V%C:&5;)&UA
M:6QB;WA=*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1M86EL8F]X
M72`](&%R<F%Y*"=D)R`]/B!A<G)A>2@I*3L*("`@("`@("!]"B`@("`@("`@
M)'!T<B`]("8D=&AI<RT^7V-A8VAE6R1M86EL8F]X73L*("`@("`@("`D<'1R
M(#T@87)R87DH"B`@("`@("`@("`@("=K)R`]/B`D=&AI<RT^7V=E=$-A8VAE
M240H)&EM87`L("1M86EL8F]X*2P*("`@("`@("`@("`@)V0G(#T^(&%R<F%Y
M7VUE<F=E*"1P=');)V0G72P@)'9A;'5E<RD*("`@("`@("`I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;F0@8V%C:&5S('1H92!R97-U;'1S
M(&]F(&%N(&EM87!?<W1A='5S*"D@8V%L;"X*("`@("`J"B`@("`@*B!`<VEN
M8V4@2&]R9&4@,RXQ+C(*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@
M)&EM87`@("!4:&4@24U!4"!R97-O=7)C92!S=')I;F<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1M86EL8F]X("!4:&4@9G5L;"`H>VAO<W1N86UE?6UA:6QB
M;W@I(&UA:6QB;W@@;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T9$-L
M87-S("!4:&4@:6UA<%]S=&%T=7,H*2!O8FIE8W0@;W(@=&AE(&5M<'1Y('-T
M<FEN9RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1A='5S*"1I;6%P+"`D
M;6%I;&)O>"D*("`@('L*("`@("`@("`D=&AI<RT^7V=E=$-A8VAE240H)&EM
M87`L("1M86EL8F]X*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]S=&%T=7-C
M86-H95LD;6%I;&)O>%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'96YE<F%T
M92!T:&4@=6YI<75E($E$('-T<FEN9R!F;W(@=&AE(&UA:6QB;W@N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M(')E<V]U<F-E("1I;6%P("`@5&AE($E-05`@<F5S;W5R8V4@<W1R96%M+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6%I;&)O>"`@5&AE(&9U;&P@*'MH;W-T
M;F%M97UM86EL8F]X*2!M86EL8F]X(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@($$@=6YI<75E('-T<FEN9R!F;W(@=&AE(&-U<G)E;G0@
M<W1A=&4@;V8@=&AE(&UA:6QB;W@N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971#86-H94E$*"1I;6%P+"`D;6%I;&)O>"D*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<W1A='5S8V%C:&5;)&UA:6QB;WA=*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W-T871U<V-A8VAE6R1M86EL8F]X72`]($!I;6%P
M7W-T871U<R@D:6UA<"P@)&UA:6QB;W@L(%-!7T%,3"D["B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]S=&%T=7-C86-H95LD;6%I;&)O>%TI('L*("`@("`@
M("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*&EM87!?;&%S=%]E<G)O<B@I
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7TY/5$E#12D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A='5S
M8V%C:&5;)&UA:6QB;WA=*2!["B`@("`@("`@("`@("1O8B`]("1T:&ES+3Y?
M<W1A='5S8V%C:&5;)&UA:6QB;WA=.PH@("`@("`@("`@("!R971U<FX@:6UP
M;&]D92@G?"<L(&%R<F%Y*"1O8BT^;65S<V%G97,L("1O8BT^<F5C96YT+"`D
M;V(M/G5N<V5E;BP@)&]B+3YU:61N97AT+"`D;V(M/G5I9'9A;&ED:71Y*2D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1M86EL8F]X
M.PH@("`@("`@('T*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B](;W)D92])34%0+T%#3"]R9F,T,S$T+G!H<```````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-#(Q-B`Q,#4Q-30S-#$S-R`P,C(R-S0`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*"G)E
M<75I<F5?;VYC92`G2&]R9&4O24U!4"]!0TPO<F9C,C`X-BYP:'`G.PH*+RHJ
M"B`J($-O;G1A:6YS(&9U;F-T:6]N<R!R96QA=&5D('1O(&UA;F%G:6YG($%C
M8V5S<R!#;VYT<F]L($QI<W1S(&]N(&%N($E-05`*("H@<V5R=F5R('5S:6YG
M(%)&0R`T,S$T+@H@*@H@*B!297%U:7)E9"!P87)A;65T97)S.CQP<F4^"B`J
M("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE(&9O<B!T:&4@<V5R=F5R(&-O
M;FYE8W1I;VX*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S<W=O<F0@9F]R('1H
M92!S97)V97(@8V]N;F5C=&EO;@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T
M;F%M92!O<B!)4"!A9&1R97-S(&]F('1H92!S97)V97(N"B`J("`@("`@("`@
M("`@("`@1$5&055,5#H@)VQO8V%L:&]S="<*("H@("`G<&]R="<@("`@("!4
M:&4@<V5R=F5R('!O<G0@=&\@=VAI8V@@=V4@=VEL;"!C;VYN96-T+@H@*B`@
M("`@("`@("`@("`@($E-05`@:7,@9V5N97)A;&QY(#$T,RP@=VAI;&4@24U!
M4"U34TP@:7,@9V5N97)A;&QY(#DY,RX*("H@("`@("`@("`@("`@("!$149!
M54Q4.B`Q-#,*("H@("`G<')O=&]C;VPG("!4:&4@8V]N;F5C=&EO;B!P<F]T
M;V-O;"`H92YG+B`G:6UA<"<L("=P;W`S)RP@)VYN='`G*2X*("H@("`@("`@
M("`@("`@("!0<F]T;V-O;"!I<R!O;F4@;V8@)VEM87`O;F]T;',G("AO<B!O
M;FQY("=I;6%P)R!I9B!Y;W4*("H@("`@("`@("`@("`@("!H879E(&$@8RUC
M;&EE;G0@=F5R<VEO;B`R,#`P8R!O<B!O;&1E<BDL("=I;6%P+W-S;"<L(&]R
M"B`J("`@("`@("`@("`@("`@)VEM87`O<W-L+VYO=F%L:61A=&4M8V5R="<@
M*&9O<B!A('-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2X*("H@("`@("`@("`@
M("`@("!$149!54Q4.B`G:6UA<"<\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO24U!4"])34%0+T%#3"]R9F,T,S$T+G!H<"QV(#$N,BXR+C$@,C`P
M-B\P,B\P-B`R,SHR,3HQ.2!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#8@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T(%-E;'-K>2`\<V5L<VMY0&-O
M;'5M8FEA+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E
M($AO<F1E7TE-05`*("HO"F-L87-S($E-05!?04-,7W)F8S0S,30@97AT96YD
M<R!)34%07T%#3%]R9F,R,#@V('L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;GD@
M861D:71I;VYA;"!P87)A;65T97)S('1H:7,@9')I=F5R(&UA>2!N965D+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!)34%07T%#3%]R9F,T,S$T*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('!A<F5N=#HZ24U!4%]!0TQ?<F9C
M,C`X-B@D<&%R86US*3L*"B`@("`@("`@)'1H:7,M/E]R:6=H='-,:7-T(#T@
M87)R87DH"B`@("`@("`@("`@("`G;"<@/3X@7R@B3&ES="`M('5S97(@8V%N
M('-E92!T:&4@9F]L9&5R(BDL"B`@("`@("`@("`@("`G<B<@/3X@7R@B4F5A
M9"!M97-S86=E<R(I+`H@("`@("`@("`@("`@)W,G(#T^(%\H(DUA<FL@=VET
M:"!3965N+U5N<V5E;B!F;&%G<R(I+`H@("`@("`@("`@("`@)W<G(#T^(%\H
M(DUA<FL@=VET:"!O=&AE<B!F;&%G<R`H92YG+B!);7!O<G1A;G0O06YS=V5R
M960I(BDL"B`@("`@("`@("`@("`G:2<@/3X@7R@B26YS97)T(&UE<W-A9V5S
M(BDL"B`@("`@("`@("`@("`G<"<@/3X@7R@B4&]S="!T;R!T:&ES(&9O;&1E
M<B`H;F]T(&5N9F]R8V5D(&)Y($E-05`I(BDL"B`@("`@("`@("`@("`G:R<@
M/3X@7R@B0W)E871E('-U8B!F;VQD97)S(BDL"B`@("`@("`@("`@("`G>"<@
M/3X@7R@B1&5L971E('-U8B!F;VQD97)S(BDL"B`@("`@("`@("`@("`G="<@
M/3X@7R@B1&5L971E(&UE<W-A9V5S(BDL"B`@("`@("`@("`@("`G92<@/3X@
M7R@B4'5R9V4@;65S<V%G97,B*2P*("`@("`@("`@("`@("=A)R`]/B!?*")!
M9&UI;FES=&5R("T@<V5T('!E<FUI<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(I
M"B`@("`@("`@*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B](;W)D92])34%0+T%#3"]R9F,R,#@V+G!H<```````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,C0V-R`Q,#4Q-30S-#$S-R`P
M,C(S,3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($-O;G1A:6YS(&9U;F-T:6]N<R!R96QA=&5D('1O
M(&UA;F%G:6YG($%C8V5S<R!#;VYT<F]L($QI<W1S(&]N(&%N($E-05`*("H@
M<V5R=F5R('5S:6YG(%)&0R`R,#@V+@H@*@H@*B!297%U:7)E9"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE(&9O<B!T
M:&4@<V5R=F5R(&-O;FYE8W1I;VX*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S
M<W=O<F0@9F]R('1H92!S97)V97(@8V]N;F5C=&EO;@H@*B`@("=H;W-T<W!E
M8R<@(%1H92!H;W-T;F%M92!O<B!)4"!A9&1R97-S(&]F('1H92!S97)V97(N
M"B`J("`@("`@("`@("`@("`@1$5&055,5#H@)VQO8V%L:&]S="<*("H@("`G
M<&]R="<@("`@("!4:&4@<V5R=F5R('!O<G0@=&\@=VAI8V@@=V4@=VEL;"!C
M;VYN96-T+@H@*B`@("`@("`@("`@("`@($E-05`@:7,@9V5N97)A;&QY(#$T
M,RP@=VAI;&4@24U!4"U34TP@:7,@9V5N97)A;&QY(#DY,RX*("H@("`@("`@
M("`@("`@("!$149!54Q4.B`Q-#,*("H@("`G<')O=&]C;VPG("!4:&4@8V]N
M;F5C=&EO;B!P<F]T;V-O;"`H92YG+B`G:6UA<"<L("=P;W`S)RP@)VYN='`G
M*2X*("H@("`@("`@("`@("`@("!0<F]T;V-O;"!I<R!O;F4@;V8@)VEM87`O
M;F]T;',G("AO<B!O;FQY("=I;6%P)R!I9B!Y;W4*("H@("`@("`@("`@("`@
M("!H879E(&$@8RUC;&EE;G0@=F5R<VEO;B`R,#`P8R!O<B!O;&1E<BDL("=I
M;6%P+W-S;"<L(&]R"B`J("`@("`@("`@("`@("`@)VEM87`O<W-L+VYO=F%L
M:61A=&4M8V5R="<@*&9O<B!A('-E;&8M<VEG;F5D(&-E<G1I9FEC871E*2X*
M("H@("`@("`@("`@("`@("!$149!54Q4.B`G:6UA<"<\+W!R93X*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO24U!4"])34%0+T%#3"]R9F,R,#@V+G!H<"QV
M(#$N-BXX+C$R(#(P,#8O,#<O,C8@,3DZ,S0Z-#4@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:')I<R!(87-T:64@/&EM<$!O86LM
M=V]O9"YC;RYU:SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED
M"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H<FES
M($AA<W1I92`\:6UP0&]A:RUW;V]D+F-O+G5K/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?24U!4`H@*B\*8VQA<W,@24U!4%]!
M0TQ?<F9C,C`X-B!E>'1E;F1S($E-05!?04-,('L*"B`@("`O*BH*("`@("`J
M($E-05`@<F5S;W5R8V4N"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@
M("`@("HO"B`@("!V87(@)%]I;6%P.PH*("`@("\J*@H@("`@("H@3&ES="!O
M9B!S97)V97(G<R!C87!A8FEL:71I97,L(&]U='!U="!O9B!#05!!0DE,2519
M(&-O;6UA;F0N($9O<FUA=&5D"B`@("`@*B!A<R!A(&AA<V@*("`@("`J(#QC
M;V1E/@H@("`@("H@87)R87DH"B`@("`@*B`@("`@*F-A<&%B:6QI='DJ(#T^
M(#$*("`@("`J("D*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V-A<',@/2!A<G)A>2@I.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($%N>2!A9&1I=&EO;F%L('!A<F%M971E<G,@=&AI
M<R!D<FEV97(@;6%Y(&YE960N"B`@("`@*B\*("`@(&9U;F-T:6]N($E-05!?
M04-,7W)F8S(P.#8H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2!A<G)A>5]M97)G92AA<G)A>2@G:&]S='-P96,G
M(#T^("=L;V-A;&AO<W0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!O<G0G(#T^(#$T,RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P<F]T;V-O;"<@/3X@)VEM
M87`G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M87)A;7,I.PH*("`@("`@("`D=&AI<RT^7V-A<',@/2`D=&AI<RT^7V=E=$-A
M<&%B:6QI='DH*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7V-A<',L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B`]("1T
M:&ES+3Y?8V%P<SL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@:68@*'-U8G-T<B@D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72P@
M,"P@-"D@(3T@)VEM87`G*2!["B`@("`@("`@("`@("\J($YO('!O:6YT(&EN
M(&=O:6YG(&%N>2!F=7)T:&5R(&EF(&ET)W,@;F]T(&%N($E-05`@<V5R=F5R
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R(#T@4$5!4CHZ<F%I<V5%
M<G)O<BA?*")/;FQY($E-05`@<V5R=F5R<R!S=7!P;W)T('-H87)E9"!F;VQD
M97)S+B(I*3L*("`@("`@("`@("`@)'1H:7,M/E]S=7!P;W)T960@/2!F86QS
M93L*("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1T:&ES+3Y?8V%P<ULG86-L
M)UTI*2!["B`@("`@("`@("`@("\J($EF('=E(&-O=6QD;B=T(&=E="!T:&4@
M<V5R=F5R)W,@8V%P86)I;&ET>2P@=V4G;&P@87-S=6UE($%#3"!I<PH@("`@
M("`@("`@("`@("!N;W0@<W5P<&]R=&5D(&9O<B!N;W<N("HO"B`@("`@("`@
M("`@("1T:&ES+3Y?<W5P<&]R=&5D(#T@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/E]S=7!P;W)T960@/2!T<G5E.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]P<F]T96-T960@/2!A<G)A>2@D=&AI
M<RT^7W!A<F%M<ULG=7-E<FYA;64G72D["@H@("`@("`@("1T:&ES+3Y?<FEG
M:'1S3&ES="`](&%R<F%Y*`H@("`@("`@("`@("`@)VPG(#T^(%\H(DQI<W0@
M+2!U<V5R(&-A;B!S964@=&AE(&9O;&1E<B(I+`H@("`@("`@("`@("`@)W(G
M(#T^(%\H(E)E860@;65S<V%G97,B*2P*("`@("`@("`@("`@("=S)R`]/B!?
M*")-87)K('=I=&@@4V5E;B]5;G-E96X@9FQA9W,B*2P*("`@("`@("`@("`@
M("=W)R`]/B!?*")-87)K('=I=&@@;W1H97(@9FQA9W,@*&4N9RX@26UP;W)T
M86YT+T%N<W=E<F5D*2(I+`H@("`@("`@("`@("`@)VDG(#T^(%\H(DEN<V5R
M="!M97-S86=E<R(I+`H@("`@("`@("`@("`@)W`G(#T^(%\H(E!O<W0@=&\@
M=&AI<R!F;VQD97(@*&YO="!E;F9O<F-E9"!B>2!)34%0*2(I+`H@("`@("`@
M("`@("`@)V,G(#T^(%\H(D-R96%T92!S=6(@9F]L9&5R<R(I+`H@("`@("`@
M("`@("`@)V0G(#T^(%\H(D1E;&5T92!A;F0@<'5R9V4@;65S<V%G97,B*2P*
M("`@("`@("`@("`@("=A)R`]/B!?*")!9&UI;FES=&5R("T@<V5T('!E<FUI
M<W-I;VYS(&9O<B!O=&AE<B!U<V5R<R(I"B`@("`@("`@*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^7VEM87`I('L*("`@("`@("`@("`@)'1H:7,M/E]I;6%P(#T@0&EM87!?
M;W!E;BAS<')I;G1F*"=[)7,Z)60O)7-])RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=H
M;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W!O<G0G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=P<F]T;V-O;"==*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!/4%](04Q&3U!%3BD["B`@("`@("`@("`@(&EF("@A)'1H
M:7,M/E]I;6%P*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM87`@/2!0
M14%2.CIR86ES945R<F]R*&EM87!?;&%S=%]E<G)O<B@I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@(6ES7V$H)'1H:7,M/E]I
M;6%P+"`G4$5!4E]%<G)O<B<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M<R!T:&4@04-,(&]N(&%N($E-05`@<V5R=F5R+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O;&1E<B`@("`@(%1H92!F;VQD97(@;VX@=VAI8V@@
M=&\@961I="!T:&4@04-,+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<VAA<F5?
M=7-E<B`@5&AE('5S97(@=&\@9W)A;G0@<FEG:'1S('1O+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1A8VP@("`@("`@("`@06X@87)R87DL('1H92!K97ES(&]F
M('=H:6-H(&%R92!T:&4@<FEG:'1S('1O"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B92!G<F%N=&5D("AS964@4D9#(#(P.#8I+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@4$5!
M4E]%<G)O<B!O;B!F86EL=7)E(&]R(&EF('-E<G9E<@H@("`@("H@("`@("`@
M("`@("`@("`@9&]E<VXG="!S=7!P;W)T($%#3',N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-R96%T94%#3"@D9F]L9&5R+"`D<VAA<F5?=7-E<BP@)&%C;"D*
M("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C="@I*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7VEM87`["B`@("`@("`@?0H*("`@("`@
M("`D86-L7W-T<B`]("<G.PH@("`@("`@(&EF("@A96UP='DH)&%C;"DI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&%C;"!A<R`D:V5Y(#T^("1V86PI('L*
M("`@("`@("`@("`@("`@("1A8VQ?<W1R("X]("1K97D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($-A;B=T(&-A;&P@=&AI<R!A<R!`
M:6UA<%]S971A8VPH*2!A<R!S=7!P<F5S<VEN9R!E<G)O<G,@;&5A9',@=&\*
M("`@("`@("`@("!I;6%P7V5R<F]R<R@I(')E='5R;FEN9R!N;W1H:6YG+B`J
M+PH@("`@("`@("1R97-U;'0@/2!I;6%P7W-E=&%C;"@D=&AI<RT^7VEM87`L
M("1F;VQD97(L("1S:&%R95]U<V5R+"`D86-L7W-T<BD["@H@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("`D97)R;W)S(#T@:6UA<%]E<G)O
M<G,H*3L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G)O<G,I*2!["B`@
M("`@("`@("`@("`@("`D97)R;W)?<W1R:6YG(#T@)R<["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D97)R;W)S(&%S("1E<G(I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&5R<B`]/2`G04-,(&YO="!A=F%I;&%B;&4@;VX@=&AI
M<R!)34%0('-E<G9E<B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&5R
M<B`N/2!?*")4:&ES($E-05`@<V5R=F5R(&1O97,@;F]T('-U<'!O<G0@<VAA
M<FEN9R!F;VQD97)S+B(I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`D97)R;W)?<W1R:6YG("X]("1E<G(["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@D97)R;W)?<W1R:6YG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD;B=T
M(&=I=F4@=7-E<B!<(B5S7"(@=&AE(&9O;&QO=VEN9R!R:6=H=',@9F]R('1H
M92!F;VQD97(@7"(E<UPB.B`E<R(I+"`D<VAA<F5?=7-E<BP@)&9O;&1E<BP@
M)&%C;%]S='(I*3L*("`@("`@("!]"@H@("`@("`@("\J($EF(%!(4"`U(&ES
M;B=T(&%V86EL86)L92!W86ET(&$@8FET('1O(&5N<W5R92!!0TP@<')O<&%G
M871E<R!I;@H@("`@("`@("`J($-Y<G5S($UU<F1E<B!C;VYF:6=U<F%T:6]N
M+B`J+PH@("`@("`@(&EF("@A9G5N8W1I;VY?97AI<W1S*"=I;6%P7V=E=&%C
M;"<I*2!["B`@("`@("`@("`@('-L965P*#4I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%9&ET
M<R!A;B!!0TP@;VX@86X@24U!4"!S97)V97(N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9F]L9&5R("`@("`@5&AE(&9O;&1E<B!O;B!W:&EC:"!T
M;R!E9&ET('1H92!!0TPN"B`@("`@*B!`<&%R86T@<W1R:6YG("1S:&%R95]U
M<V5R("!4:&4@=7-E<B!T;R!G<F%N="!R:6=H=',@=&\N"B`@("`@*B!`<&%R
M86T@87)R87D@)&%C;"`@("`@("`@("!!;B!A<G)A>2P@=&AE(&ME>7,@;V8@
M=VAI8V@@87)E('1H92!R:6=H=',@=&\*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)E(&=R86YT960@*'-E92!21D,@,C`X-BDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!F86QS
M92!O;B!F86EL=7)E('5N;&5S<R!S97)V97(@9&]E<VXG=`H@("`@("H@("`@
M("`@("`@("`@("`@<W5P<&]R="!!0TQS+"!R971U<FYS("=N;U]S=7!P;W)T
M)PH@("`@("HO"B`@("!F=6YC=&EO;B!E9&ET04-,*"1F;VQD97(L("1S:&%R
M95]U<V5R+"`D86-L*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^8W)E
M871E04-,*"1F;VQD97(L("1S:&%R95]U<V5R+"`D86-L*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($%T=&5M<'1S('1O(&=E="!T:&4@<F5S=6QT(&]F(&$@
M0T%004))3$E462!C;VUM86YD('1O('1H92!C=7)R96YT($E-05`*("`@("`J
M('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!C;VYT86EN:6YG('1H
M92!S97)V97(G<R!C87!A8FEL:71I97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971#87!A8FEL:71Y*"D*("`@('L*("`@("`@("`D8V%P86)I;&ET:65S
M(#T@;G5L;#L*("`@("`@("`D<V5R=F5R(#T@)'1H:7,M/E]P87)A;7-;)VAO
M<W1S<&5C)UT["B`@("`@("`@)'-U8E]P<F]T;R`](&YU;&P["@H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"=\7EM>+UTK+W-S;'PG+"`D=&AI<RT^7W!A<F%M
M<ULG<')O=&]C;VPG72DI('L*("`@("`@("`@("`@)'-E<G9E<B`]("=S<VPZ
M+R\G("X@)'-E<G9E<CL*("`@("`@("!]"@H@("`@("`@("1I;6%P(#T@9G-O
M8VMO<&5N*"1S97)V97(L("1T:&ES+3Y?<&%R86US6R=P;W)T)UTL("1E<G)N
M;RP@)&5R<G-T<BP@,S`I.PH*("`@("`@("!I9B`H(21I;6%P*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R
M971R:65V92!S97)V97(G<R!C87!A8FEL:71I97,B*2`N("<@+2`G("X@*"1E
M<G)N;R`_(%\H(D-O;FYE8W1I;VX@9F%I;&5D.B`B*2`N("1E<G)N;R`N("<@
M.B`G("X@)&5R<G-T<B`Z(%\H(D-O;FYE8W1I;VX@9F%I;&5D+B(I*2D["B`@
M("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R97-P;VYS92`](&9G971S*"1I;6%P+"`T,#DV*3L*("`@("`@
M("`@("`@:68@*'!R96=?;6%T8V@H)R]>7"I<<RM/2R\G+"`D<F5S<&]N<V4I
M*2!["B`@("`@("`@("`@("`@("!F<'5T<R@D:6UA<"P@(G@@0T%004))3$E4
M65QR7&XB*3L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]('1R:6TH9F=E
M=',H)&EM87`L(#$P,C0I*3L*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"<O7EPJ7',K0T%004))3$E462\G+"`D<F5S<&]N<V4I*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<W!O;G-E7V%R<F%Y(#T@97AP;&]D92@G("<L
M("1R97-P;VYS92D["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E
M<W!O;G-E7V%R<F%Y(&%S("1V87(I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<R@D=F%R+"`G/2<I("$]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A<C(@/2!E>'!L;V1E*"<])RP@)'9A
M<BP@,BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V%P86)I;&ET
M:65S6U-T<FEN9SHZ;&]W97(H)'9A<C);,%TI75M3=')I;F<Z.FQO=V5R*"1V
M87(R6S%=*5T@/2`Q.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-A<&%B:6QI=&EE<UM3
M=')I;F<Z.FQO=V5R*"1V87(I72`](#$["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!F8VQO<V4@*"1I;6%P*3L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")#;W5L9"!N;W0@<F5T<FEE=F4@<V5R=F5R)W,@8V%P86)I;&ET:65S(BD@
M+B`G("T@)R`N(%\H(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@
M=&\Z("(I("X@)UPG>"!#05!!0DE,25197"<@.B`G("X@)')E<W!O;G-E*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@(&9C;&]S92`H)&EM87`I.PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E=')I979E('-E
M<G9E<B=S(&-A<&%B:6QI=&EE<R(I("X@)R`M("<@+B!?*")5;F5X<&5C=&5D
M(')E<W!O;G-E(&9R;VT@<V5R=F5R(&]N(&-O;FYE8W1I;VXZ("(I("X@)')E
M<W!O;G-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F8VQO<V4@*"1I
M;6%P*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8V%P86)I;&ET:65S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T<FEE=F4@
M=&AE(&5X:7-T:6YG($%#3"!F;W(@82!F;VQD97(@9G)O;2!T:&4@8W5R<F5N
M=`H@("`@("H@24U!4"!S97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!F;VQD97(@(%1H92!F;VQD97(@=&\@9V5T('1H92!!0TP@9F]R+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@:&%S:"!C;VYT86EN:6YG
M(&EN9F]R;6%T:6]N(&]N('1H92!!0TPN"B`@("`@*B`\<')E/@H@("`@("H@
M07)R87D@*`H@("`@("H@("!U<V5R(#T^($%R<F%Y("@*("`@("`J("`@("!R
M:6=H="`]/B`Q"B`@("`@*B`@("D*("`@("`J("D*("`@("`J(#PO<')E/@H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971!0TPH)&9O;&1E<BD*("`@('L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C87!S6R=A=71H)UU;)V1I9V5S="UM
M9#4G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T04-,*"1F
M;VQD97(L("=D:6=E<W0M;60U)RD["B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1T:&ES+3Y?8V%P<ULG875T:"==6R=C<F%M+6UD-2==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]G971!0TPH)&9O;&1E<BP@)V-R86TM;60U
M)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9V5T04-,*"1F;VQD97(L("=L;V=I;B<I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E=')I979E('1H92!E>&ES
M=&EN9R!!0TP@9F]R(&$@9F]L9&5R(&9R;VT@=&AE(&-U<G)E;G0*("`@("`J
M($E-05`@<V5R=F5R+@H@("`@("H*("`@("`J($Y".B!I9B!!=71H7U-!4TP@
M:7,@;F]T(&EN<W1A;&QE9"!T:&ES(&9U;F-T:6]N('=I;&P@<V5N9"!T:&4@
M=7-E<G,*("`@("`J('!A<W-W;W)D('1O('1H92!)34%0('-E<G9E<B!A<R!P
M;&%I;B!T97AT(2$*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&9O;&1E<B`@("!4:&4@9F]L9&5R
M('1O(&=E="!T:&4@04-,(&9O<BX*("`@("`J($!P87)A;2!S=')I;F<@875T
M:$UE8V@@(%1H92!A=71H;W)I<V%T:6]N(&UE8VAA;FES;2!T;R!U<V4N($]N
M92!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@8W)A;2UM9#4L
M(&1I9V5S="UM9#4@;W(@;&]G:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@02!H87-H(&-O;G1A:6YI;F<@:6YF;W)M871I;VX@;VX@=&AE($%#
M3`H@("`@("H@/'!R93X*("`@("`J($%R<F%Y("@*("`@("`J("`@=7-E<B`]
M/B!!<G)A>2`H"B`@("`@*B`@("`@<FEG:'0@/3X@,0H@("`@("H@("`I"B`@
M("`@*B`I"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E
M=$%#3"@D9F]L9&5R+"`D875T:$UE8V@I"B`@("!["B`@("`@("`@+RH@268@
M:6UA<%]G971A8VPH*2!I<R!A=F%I;&%B;&4L('5S92!I="`J+PH@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H)VEM87!?9V5T86-L)RDI('L*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7V-O;FYE8W0H*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?:6UA<#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)')E<W5L="`]($!I;6%P7V=E=&%C;"@D=&AI<RT^7VEM87`L("1F
M;VQD97(I.PH@("`@("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@
M("`@("`@("1E<G)O<G,@/2!I;6%P7V5R<F]R<R@I.PH@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1E<G)O<G,I*2!["B`@("`@("`@("`@("`@("`@
M("`@)&5R<F]R7W-T<FEN9R`]("<G.PH@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1E<G)O<G,@87,@)&5R<BD@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H)&5R<B`]/2`G04-,(&YO="!A=F%I;&%B;&4@;VX@=&AI<R!)
M34%0('-E<G9E<B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G(@+CT@7R@B5&AI<R!)34%0('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T('-H
M87)I;F<@9F]L9&5R<RXB*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("`D97)R;W)?<W1R:6YG("X]("1E<G([
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<E]S=')I;F<I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@<F5T<FEE=F4@04-,(BDI*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E='5R;D%#3"`](&%R<F%Y
M*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@)'5S97(@/3X@
M)')I9VAT<RD@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`L("1I36%X
M(#T@<W1R;&5N*"1R:6=H=',I.R`D:2`\("1I36%X.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E='5R;D%#3%LD=7-E<EU;)')I9VAT<ULD:5U=
M(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@<F5T=7)N("1R971U<FY!0TP["B`@("`@("`@?0H*("`@("`@("!G
M;&]B86P@)&YO=&EF:6-A=&EO;CL*"B`@("`@("`@)&AA=F5?<V%S;"`](&9A
M;'-E.PH@("`@("`@("1R971U<FY!0TP@/2!A<G)A>2@I.PH@("`@("`@("1S
M97)V97(@/2`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G73L*("`@("`@("`D
M<W5B7W!R;W1O(#T@;G5L;#L*("`@("`@("`D='AI9"`](#`["@H@("`@("`@
M("\J(%-I;&5N8V4@=V%R;FEN9W,@9'5R:6YG(&-H96-K(&EF($%U=&A?4T%3
M3"!M;V1U;&4@:7,@:6YS=&%L;&5D+B`J+PH@("`@("`@(&EF("A`:6YC;'5D
M95]O;F-E("=!=71H+U-!4TPN<&AP)RD@>PH@("`@("`@("`@("`D:&%V95]S
M87-L(#T@=')U93L*("`@("`@("!]"@H@("`@("`@("1P87-S(#T@)'1H:7,M
M/E]P87)A;7-;)W!A<W-W;W)D)UT["@H@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"=\7EM>+UTK+W-S;'PG+"`D=&AI<RT^7W!A<F%M<ULG<')O=&]C;VPG72DI
M('L*("`@("`@("`@("`@)'-E<G9E<B`]("=S<VPZ+R\G("X@)'-E<G9E<CL*
M("`@("`@("!]"@H@("`@("`@("\J(%%U;W1E('1H92!F;VQD97(@<W1R:6YG
M(&EF(&ET(&-O;G1A:6YS(&YO;B!A;'!H82UN=6UE<FEC"B`@("`@("`@("`@
M8VAA<F%C=&5R<RX@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+UQ7+R<L
M)&9O;&1E<BDI('L*("`@("`@("`@("`@)&9O;&1E<B`]("<B)R`N("1F;VQD
M97(@+B`G(B<["B`@("`@("`@?0H*("`@("`@("`D:6UA<"`](&9S;V-K;W!E
M;B@D<V5R=F5R+"`D=&AI<RT^7W!A<F%M<ULG<&]R="==+"`D97)R;F\L("1E
M<G)S='(L(#,P*3L*"B`@("`@("`@:68@*"$D:6UA<"D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T<FEE
M=F4@04-,(BD*("`@("`@("`@("`@("`@("X@)R`M("<@+B`H)&5R<FYO(#\@
M7R@B0V]N;F5C=&EO;B!F86EL960Z("(I("X@)&5R<FYO+B<@.B`G("X@)&5R
M<G-T<B`Z(%\H(D-O;FYE8W1I;VX@9F%I;&5D+B(I*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@9F=E=',H)&EM87`L(#0P
M.38I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS*T]++R<L
M("1R97-P;VYS92DI('L*"B`@("`@("`@("`@("`@("`O*B!L;V=I;B!U<VEN
M9R!T:&4@<')E9F5R<F5D(&UE8VAA;FES;2!D969A=6QT('1O(&QO9VEN(&EF
M"B`@("`@("`@("`@("`@("`@("!!=71H7U-!4TP@:7,@;F]T(&EN<W1A;&QE
M9"X@*B\*("`@("`@("`@("`@("`@(&EF("@D:&%V95]S87-L("8F("@D875T
M:$UE8V@@/3T@)V-R86TM;60U)RDI('L*("`@("`@("`@("`@("`@("`@("`D
M;&]G:6X@/2!!=71H7U-!4TPZ.F9A8W1O<GDH)V-R86UM9#4G*3L*"B`@("`@
M("`@("`@("`@("`@("`@9G!U=',H)&EM87`L("(D='AI9"!!551(14Y424-!
M5$4@0U)!32U-1#5<<EQN(BD["B`@("`@("`@("`@("`@("`@("`@)&-H86QL
M96YG92`](&5X<&QO9&4H)R`G+"!T<FEM*&9G971S*"1I;6%P+"`Q,#(T*2DI
M.PH*("`@("`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D;&]G:6XM/F=E
M=%)E<W!O;G-E*"1?4T534TE/3ELG:6UP)UU;)W5S97(G72P@)'!A<W,L(&)A
M<V4V-%]D96-O9&4H)&-H86QL96YG95LQ72DI.PH@("`@("`@("`@("`@("`@
M("`@(&9P=71S*"1I;6%P+"!B87-E-C1?96YC;V1E*"1R97-P;VYS92D@+B`B
M7')<;B(I.PH*("`@("`@("`@("`@("`@('T@96QS96EF*"1H879E7W-A<VP@
M)B8@*"1A=71H365C:"`]/2`G9&EG97-T+6UD-2<I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&QO9VEN(#T@075T:%]305-,.CIF86-T;W)Y*"=D:6=E<W1M
M9#4G*3L*"B`@("`@("`@("`@("`@("`@("`@9G!U=',H)&EM87`L("(D='AI
M9"!!551(14Y424-!5$4@1$E'15-4+4U$-5QR7&XB*3L*("`@("`@("`@("`@
M("`@("`@("`D8VAA;&QE;F=E(#T@97AP;&]D92@G("<L('1R:6TH9F=E=',H
M)&EM87`L(#$P,C0I*2D["@H@("`@("`@("`@("`@("`@("`@("1R97-P;VYS
M92`]("1L;V=I;BT^9V5T4F5S<&]N<V4H)%]315-324].6R=I;7`G75LG=7-E
M<B==+"`D<&%S<RP@8F%S938T7V1E8V]D92@D8VAA;&QE;F=E6S%=*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I;7`G75LG<V5R=F5R
M)UTL("1?4T534TE/3ELG:6UP)UU;)V)A<V5?<')O=&]C;VPG72D["@H@("`@
M("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"!B87-E-C1?96YC;V1E*"1R
M97-P;VYS92D@+B`B7')<;B(I.PH@("`@("`@("`@("`@("`@("`@("1R97-P
M;VYS92`](&5X<&QO9&4H)R`G+"!T<FEM*&9G971S*"1I;6%P+"`Q,#(T*2DI
M.PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS92`](&)A<V4V-%]D96-O
M9&4H)')E<W!O;G-E6S%=*3L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1R97-P;VYS92P@)W)S<&%U=&@])RD@/3T](&9A;'-E*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&9C;&]S92@D:6UA<"D["B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD
M(&YO="!R971R:65V92!!0TPB*0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G("T@)R`N(%\H(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V
M97(@=&\Z("(I("X@)T1I9V5S="U-1#4@<F5S<&]N<V4G+"`G:&]R9&4N=V%R
M;FEN9R<I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!F<'5T<R@D:6UA<"P@(EQR7&XB*3L*"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7%<O)RP@)'!A<W,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P87-S
M(#T@861D<VQA<VAE<R@D<&%S<RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87-S(#T@)R(G("X@)'!A<W,@+B`G(B<["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@(&9P=71S*"1I;6%P+"`B)'1X:60@
M3$]'24X@(B`N("1?4T534TE/3ELG:6UP)UU;)W5S97(G72`N("<@)R`N("1P
M87-S("X@(EQR7&XB*3L*"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D<F5S<&]N<V4@/2!T<FEM*&9G971S*"1I;6%P+"`Q,#(T*2D["B`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@B+UXD='AI9%QS3TLO(BP@
M)')E<W!O;G-E*2D@>PH@("`@("`@("`@("`@("`@("`@("1T>&ED*RL["B`@
M("`@("`@("`@("`@("`@("`@9G!U=',H)&EM87`L("(D='AI9"!'151!0TP@
M(B`N("1F;VQD97(@+B`B7')<;B(I.PH@("`@("`@("`@("`@("`@("`@("1R
M97-P;VYS92`]('1R:6TH9F=E=',H)&EM87`L(#0P.38I*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY<*EQS*T%#3%QS*R@N*BDO
M:2<L("1R97-P;VYS92P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1R97-?87)R(#T@)'1H:7,M/E]A=&]M:7-E*"1M871C:&5S6S%=
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<U]F;VQD97(@/2!A<G)A
M>5]S:&EF="@D<F5S7V%R<BD["B`@("`@("`@("`@("`@("`@("`@("`@("1I
M<U]K97D@/2`Q.PH@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@;G5L
M;#L*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E<U]A<G(@
M87,@)'9A<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1I
M<U]K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y
M(#T@)'9A<CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:7-?
M:V5Y(#T@,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!E<FUS(#T@<')E
M9U]S<&QI="@G+R\G+"`D=F%R+"`M,2P@4%)%1U]34$Q)5%].3U]%35!462D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!E
M<FUS(&%S("1P7VME>2`]/B`D<%]V87(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E='5R;D%#3%LD:V5Y75LD<%]V87)=(#T@
M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&ES7VME>2`](#$["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!F8VQO<V4H)&EM87`I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,(BD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`M
M("<@+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R=F5R('1O.B`B
M*2`N("(G)'1X:60@1T5404-,)R`Z("(@+B1R97-P;VYS92D["@H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@9F-L;W-E*"1I;6%P*3L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5T
M<FEE=F4@04-,(BD*("`@("`@("`@("`@("`@("`@("`@("`@+B`G("T@)R`N
M(%\H(E5N97AP96-T960@<F5S<&]N<V4@9G)O;2!S97)V97(@=&\Z("(I("X@
M)VQO9VEN(#H@)R`N("1R97-P;VYS92D["@H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F-L;W-E*"1I
M;6%P*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D-O=6QD(&YO="!R971R:65V92!!0TPB*0H@("`@("`@("`@("`@("`@
M("`@("X@)R`M("<@+B!?*")5;F5X<&5C=&5D(')E<W!O;G-E(&9R;VT@<V5R
M=F5R(&]N(&-O;FYE8W1I;VXZ("(I("X@)')E<W!O;G-E*3L*"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@9F-L;W-E*"1I;6%P*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D<F5T=7)N04-,.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V%N(&$@=7-E<B!E9&ET('1H92!!0TP@9F]R('1H:7,@9F]L9&5R/PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9O;&1E<B`@5&AE(&9O;&1E
M<B!N86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<B`@("!!('5S97(@
M;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@:68@
M)'5S97(@:&%S('!E<FUI<W-I;VX@=&\@961I="!T:&4@04-,(&]N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("1F;VQD97(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-A;D5D:70H)&9O;&1E<BP@)'5S97(I"B`@("!["B`@("`@("`@+RH@
M5V4@8V%N)W0@97-T86)L:7-H(&EF('1H92!U<V5R(&ES(&EN(&$@9W)O=7`@
M=VET:"!T:&4@)V$G"B`@("`@("`@("`@<')I=FEL96=E+"!S;R!J=7-T(')E
M='5R;B!T<G5E(&%N9"!L96%V92!T:&4@9&5C:7-I;VX@=&\@=&AE"B`@("`@
M("`@("`@<V5R=F5R("HO"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#<G5D96QY('-P;&ET(&$@<W1R:6YG(&EN=&\@)V%T
M;VUS)RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1I;B`@5&AE('-T<FEN9R!T;R!S<&QI="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B`G871O
M;7,G+@H@("`@("HO"B`@("!F=6YC=&EO;B!?871O;6ES92@D:6XI"B`@("![
M"B`@("`@("`@)&QE;F=T:"`]('-T<FQE;B@D:6XI.PH@("`@("`@("1Q="`]
M(&9A;'-E.PH@("`@("`@("1I9'@@/2`P.PH@("`@("`@("1O=70@/2!A<G)A
M>2@I.PH*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;&5N9W1H.R`D:2LK
M*2!["B`@("`@("`@("`@("1C:&%R(#T@<W5B<W1R*"1I;BP@)&DL(#$I.PH@
M("`@("`@("`@("!I9B`H*"1C:&%R(#T]("<B)RD@)B8@(21Q="D@>PH@("`@
M("`@("`@("`@("`@)'%T(#T@=')U93L*("`@("`@("`@("`@("`@("1I9'@K
M*SL*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!](&5L
M<V5I9B`H*"1C:&%R(#T]("<@)RD@)B8@(21Q="D@>PH@("`@("`@("`@("`@
M("`@)&ED>"LK.PH@("`@("`@("`@("!](&5L<V5I9B`H*"1C:&%R(#T]("<B
M)RD@)B8@)'%T*2!["B`@("`@("`@("`@("`@("`D<70@/2!F86QS93L*("`@
M("`@("`@("`@("`@("1I9'@K*SL*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&EF("AE;7!T>2@D;W5T6R1I9'A=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1O=71;)&ED>%T@/2`D8VAA<CL*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&]U=%LD:61X72`N
M/2`D8VAA<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1O=70["B`@("!]"@I]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92].;W1I9FEC871I;VXO3&ES=&5N97(`````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-R`P,C,U,#$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+TYO=&EF:6-A=&EO;B]%=F5N="YP:'``````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-3(T(#$P-3$U-#,T,3,W(#`R
M,S4W,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@5&AE($YO=&EF:6-A=&EO;E]%=F5N=#HZ(&-L87-S
M('!R;W9I9&5S(&$@8V]N=&%I;F5R(&9O<B!P87-S:6YG"B`J(&UE<W-A9V5S
M('1O($YO=&EF:6-A=&EO;E],:7-T96YE<B!C;&%S<V5S+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T:6]N+T5V96YT
M+G!H<"QV(#$N-2XR+C4@,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP("0*
M("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!(86YS($QE;&QE;&ED(#QH86YS
M0'9E;'5M+FYE=#X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($AA;G,@
M3&5L;&5L:60@/&AA;G-`=F5L=6TN;F5T/@H@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("H@0'!A8VMA9V4@2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S<R!.
M;W1I9FEC871I;VY?179E;G0@>PH*("`@("\J*@H@("`@("H@5&AE(&UE<W-A
M9V4@8F5I;F<@<&%S<V5D+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]M97-S86=E(#T@)R<[
M"@H@("`@+RHJ"B`@("`@*B!)9B!P87-S960L('-E=',@=&AE(&UE<W-A9V4@
M9F]R('1H:7,@979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;65S<V%G92`@5&AE('1E>'0@;65S<V%G92!F;W(@=&AI<R!E=F5N="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7T5V96YT*"1M97-S86=E
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES7VYU;&PH)&UE<W-A9V4I
M*2!["B`@("`@("`@("`@("1T:&ES+3YS971-97-S86=E*"1M97-S86=E*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!T97AT
M(&UE<W-A9V4@9F]R('1H:7,@979E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;65S<V%G92`@5&AE('1E>'0@;65S<V%G92!T;R!D:7-P;&%Y
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971-97-S86=E*"1M97-S86=E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?;65S<V%G92`]("1M97-S86=E.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@=&5X="!M97-S86=E(&9O<B!T
M:&ES(&5V96YT+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@
M=&5X="!M97-S86=E('1O(&1I<W!L87DN"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$UE<W-A9V4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VUE
M<W-A9V4["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T
M:69I8V%T:6]N+TQI<W1E;F5R+G!H<```````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#<V,C,@,3`U,34T,S0Q,S<@,#(T,S`Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@3F]T
M:69I8V%T:6]N7TQI<W1E;F5R.CH@8VQA<W,@<')O=FED97,@9G5N8W1I;VYA
M;&ET>2!F;W(@9&ES<&QA>6EN9PH@*B!M97-S86=E<R!F<F]M('1H92!M97-S
M86=E('-T86-K(&%S(&$@<W1A='5S(&QI;F4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I9FEC871I;VXO3&ES=&5N97(N<&AP
M+'8@,2XQ-BXR+C<@,C`P-B\P,2\P,2`R,3HR.#HR.2!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`R+C$*("H@0'!A8VMA9V4@2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S
M<R!.;W1I9FEC871I;VY?3&ES=&5N97(@>PH*("`@("\J*@H@("`@("H@07)R
M87D@;V8@;65S<V%G92!T>7!E<R!T:&%T('1H:7,@;&ES=&5N97(@:&%N9&QE
M<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M7VAA;F1L97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I8V%T:6]N7TQI<W1E;F5R
M*"D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J($1O97,@=&AI<R!L:7-T
M96YE<B!H86YD;&4@82!C97)T86EN('1Y<&4@;V8@;65S<V%G93\*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!4:&4@;65S<V%G92!T>7!E
M(&EN('%U97-T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5VAE=&AE<B!T:&ES(&QI<W1E;F5R(&AA;F1L97,@=&AE('1Y<&4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&AA;F1L97,H)'1Y<&4I"B`@("!["B`@("`@("`@
M<F5T=7)N(&ES<V5T*"1T:&ES+3Y?:&%N9&QE<ULD='EP95TI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N(&$@=6YI<75E(&ED96YT:69I97(@9F]R
M('1H:7,@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%5N:7%U92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&=E=%]C;&%S<R@D=&AI<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!/=71P=71S('1H92!S=&%T=7,@;&EN92P@<V5N9',@
M96UA:6QS+"!P86=E<RP@971C+BP@:68@=&AE<F4*("`@("`J(&%R92!A;GD@
M;65S<V%G97,@;VX@=&AI<R!L:7-T96YE<B=S(&UE<W-A9V4@<W1A8VLN"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D;65S<V%G95-T86-K("!4:&4@
M<W1A8VL@;V8@;65S<V%G97,N"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO
M;G,@("`@("`@($%N(&%R<F%Y(&]F(&]P=&EO;G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YO=&EF>2@F)&UE<W-A9V53=&%C:W,L("1O<'1I;VYS(#T@87)R
M87DH*2D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%!R;V-E<W-E<R!O
M;F4@;65S<V%G92!F<F]M('1H92!M97-S86=E('-T86-K+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D;65S<V%G92`@3VYE(&UE<W-A9V4@:&%S:"!F
M<F]M('1H92!S=&%C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T365S<V%G
M92@D;65S<V%G92D*("`@('L*("`@('T*"B`@("`O*BH*("`@("`J(%5N<V5R
M:6%L:7IE(&%N(&5V96YT(&9R;VT@=&AE(&UE<W-A9V4@<W1A8VLL(&-H96-K
M:6YG('1O('-E92!I9B!T:&4*("`@("`J(&%P<')O<')I871E(&-L87-S(&5X
M:7-T<R!A;F0@:VQU9&=I;F<@:70@:6YT;R!A(&)A<V4@3F]T:69I8V%T:6]N
M7T5V96YT"B`@("`@*B!O8FIE8W0@:68@;F]T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971%=F5N="@D;65S<V%G92D*("`@('L*("`@("`@("`D;V(@/2!F
M86QS93L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1M97-S86=E6R=C;&%S
M<R==*2D@>PH@("`@("`@("`@("`D;V(@/2!`=6YS97)I86QI>F4H)&UE<W-A
M9V5;)V5V96YT)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O179E;G0N<&AP)SL*
M("`@("`@("`@("`@)&]B(#T@0'5N<V5R:6%L:7IE*"1M97-S86=E6R=E=F5N
M="==*3L*("`@("`@("`@("`@:68@*"%M971H;V1?97AI<W1S*"1O8BP@)V=E
M=$UE<W-A9V4G*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O8BT^
M7VUE<W-A9V4I*2!["B`@("`@("`@("`@("`@("`@("`@)&]B(#T@)FYE=R!.
M;W1I9FEC871I;VY?179E;G0H)&]B+3Y?;65S<V%G92D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($EF
M('=E)W9E(&9A:6QE9"!T;R!C<F5A=&4@82!V86QI9"!.;W1I9FEC871I;VY?
M179E;G0@;V)J96-T"B`@("`@("`@("H@*&]R('-U8F-L87-S(&]B:F5C="D@
M<V\@9F%R+"!R971U<FX@82!014%27T5R<F]R+B`J+PH@("`@("`@(&EF("@A
M;65T:&]D7V5X:7-T<R@D;V(L("=G971-97-S86=E)RDI('L*("`@("`@("`@
M("`@)&]B(#T@4$5!4CHZ<F%I<V5%<G)O<B@G56YA8FQE('1O(&1E8V]D92!M
M97-S86=E(&5V96YT.B`G("X@)&UE<W-A9V5;)V5V96YT)UTI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4W!E8VEA;&QY(&AA;F1L92!014%27T5R<F]R(&]B
M:F5C=',@86YD(&%D9"!U<V5R:6YF;R!I9@H@("`@("`@("`J(&ET)W,@=&AE
M<F4N("HO"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)&]B+"`G9V5T57-E
M<DEN9F\G*2D@>PH@("`@("`@("`@("`D=7-E<FEN9F\@/2`D;V(M/F=E=%5S
M97));F9O*"D["B`@("`@("`@("`@(&EF("@D=7-E<FEN9F\I('L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=7-E<FEN9F\I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'5S97)I;F9O(#T@0&EM<&QO9&4H)RP@)RP@)'5S97)I
M;F9O*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1O8BT^
M7VUE<W-A9V4@/2`D;V(M/F=E=$UE<W-A9V4H*2`N("<@.B`G("X@)'5S97)I
M;F9O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)&]B.PH@("`@?0H*("`@("\J*@H@("`@("H@56YS97)I86QI>F4@86X@87)R
M87D@;V8@979E;G0@9FQA9W,@9G)O;2!T:&4@;65S<V%G92!S=&%C:RX@($EF
M('1H:7,*("`@("`J(&5V96YT(&AA<R!N;R!F;&%G<RP@;W(@=&AE(&9L86=S
M(&%R<F%Y(&-O=6QD(&YO="!B92!U;G-E<FEA;&EZ960L(&%N"B`@("`@*B!E
M;7!T>2!A<G)A>2!I<R!R971U<FYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!;B!A<G)A>2!O9B!F;&%G<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T1FQA9W,H)&UE<W-A9V4I"B`@("!["B`@("`@("`@+RH@268@=&AI
M<R!M97-S86=E(&1O97-N)W0@:&%V92!A;GD@9FQA9W,L(')E='5R;B!A;B!E
M;7!T>0H@("`@("`@("`J(&%R<F%Y+B`J+PH@("`@("`@(&EF("AE;7!T>2@D
M;65S<V%G95LG9FQA9W,G72DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"D["B`@("`@("`@?0H*("`@("`@("`O*B!5;G-E<FEA;&EZ92!T:&4@9FQA
M9W,@87)R87D@9G)O;2!T:&4@;65S<V%G92X@*B\*("`@("`@("`D9FQA9W,@
M/2!`=6YS97)I86QI>F4H)&UE<W-A9V5;)V9L86=S)UTI.PH*("`@("`@("`O
M*B!)9B!W92!C;W5L9&XG="!U;G-E<FEA;&EZ92!T:&4@9FQA9W,@87)R87DL
M(')E='5R;B!A;B!E;7!T>0H@("`@("`@("`J(&%R<F%Y+B`J+PH@("`@("`@
M(&EF("@A:7-?87)R87DH)&9L86=S*2D@>PH@("`@("`@("`@("!R971U<FX@
M87)R87DH*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9FQA9W,["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+VUO8FEL92YP
M:'``````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4T-#4@,3`U,34T,S0Q,S<@,#(U-34P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE
M<B]S=&%T=7,N<&AP)SL*"B\J*@H@*B!4:&4@3F]T:69I8V%T:6]N7TQI<W1E
M;F5R7VUO8FEL93HZ(&-L87-S('!R;W9I9&5S(&9U;F-T:6]N86QI='D@9F]R
M"B`J(&1I<W!L87EI;F<@;65S<V%G97,@9G)O;2!T:&4@;65S<V%G92!S=&%C
M:R!O;B!M;V)I;&4@9&5V:6-E<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M3F]T:69I8V%T:6]N+TYO=&EF:6-A=&EO;B],:7-T96YE<B]M;V)I;&4N<&AP
M+'8@,2XX+C$P+C@@,C`P-B\P,2\P,2`R,3HR.#HS,"!J86X@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?3F]T:69I8V%T:6]N"B`J+PIC;&%S
M<R!.;W1I9FEC871I;VY?3&ES=&5N97)?;6]B:6QE(&5X=&5N9',@3F]T:69I
M8V%T:6]N7TQI<W1E;F5R7W-T871U<R!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M2&]R9&5?36]B:6QE.CH@;V)J96-T('1H870@<W1A='5S(&QI;F5S('-H;W5L
M9"!B92!A9&1E9"!T;RX*("`@("`J"B`@("`@*B!`=F%R($AO<F1E7TUO8FEL
M90H@("`@("HO"B`@("!V87(@)%]M;V)I;&4@/2!N=6QL.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T:69I
M8V%T:6]N7TQI<W1E;F5R7VUO8FEL92@I"B`@("!["B`@("`@("`@)'1H:7,M
M/E]H86YD;&5S(#T@87)R87DH)VAO<F1E+F5R<F]R)R`@(#T^(%\H(D524B(I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YS=6-C
M97-S)R`]/B!?*")354-#15-3(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAO<F1E+G=A<FYI;F<G(#T^(%\H(E=!4DXB*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N;65S<V%G92<@/3X@
M7R@B35-'(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@07-S;V-I871E(&$@
M2&]R9&5?36]B:6QE.CH@;V)J96-T('=I=&@@=&AE(&QI<W1E;F5R+@H@("`@
M("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&4@(%1H92!(;W)D95]-;V)I
M;&4Z.B!O8FIE8W0@=&\@<V5N9"!S=&%T=7,@;&EN97,@=&\N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=$UO8FEL94]B:F5C="@F)&UO8FEL92D*("`@('L*
M("`@("`@("`D=&AI<RT^7VUO8FEL92`]("8D;6]B:6QE.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&$@=6YI<75E(&ED96YT:69I97(@9F]R('1H
M:7,@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%5N
M:7%U92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3F%M92@I"B`@("![
M"B`@("`@("`@<F5T=7)N("=M;V)I;&4G.PH@("`@?0H*("`@("\J*@H@("`@
M("H@3W5T<'5T<R!T:&4@<W1A='5S(&QI;F4@:68@=&AE<F4@87)E(&%N>2!M
M97-S86=E<R!O;B!T:&4@)VUO8FEL92<*("`@("`J(&UE<W-A9V4@<W1A8VLN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D;65S<V%G95-T86-K("!4
M:&4@<W1A8VL@;V8@;65S<V%G97,N"B`@("`@*B!`<&%R86T@87)R87D@)&]P
M=&EO;G,@("`@("`@($%N(&%R<F%Y(&]F(&]P=&EO;G,N($]P=&EO;G,Z("=N
M;W-P86-E)PH@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I9GDH)B1M97-S86=E
M4W1A8VLL("1O<'1I;VYS(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H
M(21T:&ES+3Y?;6]B:6QE*2!["B`@("`@("`@("`@('!A<F5N=#HZ3F]T:69I
M8V%T:6]N7TQI<W1E;F5R7W-T871U<R@I.PH@("`@("`@("`@("!R971U<FX@
M<&%R96YT.CIN;W1I9GDH)&UE<W-A9V53=&%C:RP@)&]P=&EO;G,I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&-O=6YT*"1M97-S86=E4W1A8VLI*2!["B`@
M("`@("`@("`@('=H:6QE("@D;65S<V%G92`](&%R<F%Y7W-H:69T*"1M97-S
M86=E4W1A8VLI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9V5T365S<V%G
M92@D;65S<V%G92D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'0@/2`F
M)'1H:7,M/E]M;V)I;&4M/F%D9"AN97<@2&]R9&5?36]B:6QE7W1E>'0H(EQN
M(BDI.PH@("`@("`@("`@("`D="T^<V5T*"=L:6YE8G)E86MS)RP@=')U92D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!O;F4@
M;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&UE<W-A9V4@
M($]N92!M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^7VUO8FEL92D@>PH@("`@("`@("`@("!P87)E;G0Z.DYO
M=&EF:6-A=&EO;E],:7-T96YE<E]S=&%T=7,H*3L*("`@("`@("`@("`@<F5T
M=7)N('!A<F5N=#HZ9V5T365S<V%G92@D;65S<V%G92D["B`@("`@("`@?0H*
M("`@("`@("`D979E;G0@/2`D=&AI<RT^9V5T179E;G0H)&UE<W-A9V4I.PH@
M("`@("`@("1T:&ES+3Y?;6]B:6QE+3YA9&0H;F5W($AO<F1E7TUO8FEL95]T
M97AT*'-P<FEN=&8H7R@B)7,Z("5S(BDL("1T:&ES+3Y?:&%N9&QE<ULD;65S
M<V%G95LG='EP92==72P@<W1R:7!?=&%G<R@D979E;G0M/F=E=$UE<W-A9V4H
M*2DI*2D["B`@("!]"@I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92].
M;W1I9FEC871I;VXO3&ES=&5N97(O875D:6\N<&AP````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,S0S-"`Q,#4Q-30S-#$S-R`P,C4S-S8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC
M92`G2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+G!H<"<["@HO*BH*("H@
M5&AE($YO=&EF:6-A=&EO;E],:7-T96YE<E]A=61I;SHZ(&-L87-S('!R;W9I
M9&5S(&9U;F-T:6]N86QI='D@9F]R"B`J(&EN<V5R=&EN9R!E;6)E9&1E9"!A
M=61I;R!N;W1I9FEC871I;VYS(&9R;VT@=&AE('-T86-K(&EN=&\@=&AE('!A
M9V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O875D:6\N<&AP+'8@,2XS+C(N,B`R,#`V+S`Q
M+S`Q(#(Q.C(X.C,P(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S>7,N8V]M+SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN($9E;&EC92`\
M:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@
M*B!`<&%C:V%G92!(;W)D95].;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF
M:6-A=&EO;E],:7-T96YE<E]A=61I;R!E>'1E;F1S($YO=&EF:6-A=&EO;E],
M:7-T96YE<B!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("HO
M"B`@("!F=6YC=&EO;B!.;W1I9FEC871I;VY?3&ES=&5N97)?875D:6\H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?:&%N9&QE<R`](&%R<F%Y*"=A=61I;R<@
M/3X@)R<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@=6YI<75E
M(&ED96YT:69I97(@9F]R('1H:7,@;&ES=&5N97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%5N:7%U92!I9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=A=61I;R<["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S('1H92!E;6)E9&1E9"!A=61I
M;R!C;V1E(&EF('1H97)E(&%R92!A;GD@;65S<V%G97,@;VX@=&AE"B`@("`@
M*B`G875D:6\G(&UE<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("8D;65S<V%G95-T86-K("`@("!4:&4@<W1A8VL@;V8@;65S<V%G
M97,N"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO;G,@($%N(&%R<F%Y(&]F
M(&]P=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@F)&UE<W-A
M9V53=&%C:RP@)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF
M("AC;W5N="@D;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("!W:&EL92`H
M)&UE<W-A9V4@/2!A<G)A>5]S:&EF="@D;65S<V%G95-T86-K*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F=E=$UE<W-A9V4H)&UE<W-A9V4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3W5T
M<'5T<R!O;F4@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&UE<W-A9V4@($]N92!M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A8VLN"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I"B`@("![
M"B`@("`@("`@)&5V96YT(#T@)'1H:7,M/F=E=$5V96YT*"1M97-S86=E*3L*
M("`@("`@("!E8VAO("<\96UB960@<W)C/2(G+"!H=&UL<W!E8VEA;&-H87)S
M*"1E=F5N="T^9V5T365S<V%G92@I*2P*("`@("`@("`@("`@("<B('=I9'1H
M/2(P(B!H96EG:'0](C`B(&%U=&]S=&%R=#TB=')U92(@+SXG.PH@("`@?0H*
M?0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O3F]T:69I
M8V%T:6]N+TQI<W1E;F5R+VIA=F%S8W)I<'0N<&AP````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#0P,30@,3`U,34T,S0Q,S<@,#(V-#,V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TAO
M<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`G.PH*+RHJ"B`J(%1H92!.
M;W1I9FEC871I;VY?3&ES=&5N97)?:F%V87-C<FEP=#HZ(&-L87-S('!R;W9I
M9&5S(&9U;F-T:6]N86QI='D@9F]R"B`J(&EN<V5R=&EN9R!J879A<V-R:7!T
M(&-O9&4@9G)O;2!T:&4@;65S<V%G92!S=&%C:R!I;G1O('1H92!P86=E+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R].;W1I9FEC871I;VXO3F]T:69I8V%T
M:6]N+TQI<W1E;F5R+VIA=F%S8W)I<'0N<&AP+'8@,2XW+C$P+C8@,C`P-B\P
M,2\P,2`R,3HR.#HS,"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TYO
M=&EF:6-A=&EO;@H@*B\*8VQA<W,@3F]T:69I8V%T:6]N7TQI<W1E;F5R7VIA
M=F%S8W)I<'0@97AT96YD<R!.;W1I9FEC871I;VY?3&ES=&5N97(@>PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@
M3F]T:69I8V%T:6]N7TQI<W1E;F5R7VIA=F%S8W)I<'0H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?:&%N9&QE<R`](&%R<F%Y*"=J879A<V-R:7!T)R`]/B`G
M)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!U;FEQ=64@:61E
M;G1I9FEE<B!F;W(@=&AI<R!L:7-T96YE<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@56YI<75E(&ED+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971.86UE*"D*("`@('L*("`@("`@("!R971U<FX@)VIA=F%S8W)I<'0G.PH@
M("`@?0H*("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@:F%V87-C<FEP="!C
M;V1E(&EF('1H97)E(&%R92!A;GD@;65S<V%G97,@;VX@=&AE"B`@("`@*B`G
M:F%V87-C<FEP="<@;65S<V%G92!S=&%C:R!A;F0@:68@=&AE("=N;W1I9GE?
M:F%V87-C<FEP="<@;W!T:6]N(&ES('-E="X*("`@("`J"B`@("`@*B!`<&%R
M86T@87)R87D@)B1M97-S86=E4W1A8VL@("`@(%1H92!S=&%C:R!O9B!M97-S
M86=E<RX*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N<R`@06X@87)R87D@
M;V8@;W!T:6]N<RX@3W!T:6]N<SH@)VYO<V-R:7!T)PH@("`@("HO"B`@("!F
M=6YC=&EO;B!N;W1I9GDH)B1M97-S86=E4W1A8VLL("1O<'1I;VYS(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H8V]U;G0H)&UE<W-A9V53=&%C:RDI
M('L*("`@("`@("`@("`@:68@*&5M<'1Y*"1O<'1I;VYS6R=N;W-C<FEP="==
M*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G/'-C<FEP="!T>7!E/2)T97AT
M+VIA=F%S8W)I<'0B/B<["B`@("`@("`@("`@("`@("!E8VAO(")<;CPA+2U<
M;B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1M97-S86=E
M(#T@87)R87E?<VAI9G0H)&UE<W-A9V53=&%C:RDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YG971-97-S86=E*"1M97-S86=E*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H96UP='DH)&]P=&EO;G-;)VYO<V-R:7!T)UTI
M*2!["B`@("`@("`@("`@("`@("!E8VAO("(O+RTM/EQN/"]S8W)I<'0^7&XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@3W5T<'5T<R!O;F4@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&UE<W-A9V4@($]N92!M97-S86=E(&AA<V@@9G)O;2!T:&4@<W1A
M8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H)&UE<W-A9V4I
M"B`@("!["B`@("`@("`@)&5V96YT(#T@)'1H:7,M/F=E=$5V96YT*"1M97-S
M86=E*3L*("`@("`@("!E8VAO("1E=F5N="T^9V5T365S<V%G92@I("X@(EQN
M(CL*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O3F]T:69I8V%T:6]N+TQI<W1E;F5R+W-T871U<RYP:'``````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#0U-S`@,3`U,34T,S0Q,S<@,#(U-C(R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@IR97%U
M:7)E7V]N8V4@)TAO<F1E+TYO=&EF:6-A=&EO;B],:7-T96YE<BYP:'`G.PH*
M+RHJ"B`J(%1H92!.;W1I9FEC871I;VY?3&ES=&5N97)?<W1A='5S.CH@8VQA
M<W,@<')O=FED97,@9G5N8W1I;VYA;&ET>2!F;W(*("H@9&ES<&QA>6EN9R!M
M97-S86=E<R!F<F]M('1H92!M97-S86=E('-T86-K(&%S(&$@<W1A='5S(&QI
M;F4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TYO=&EF:6-A=&EO;B].;W1I
M9FEC871I;VXO3&ES=&5N97(O<W1A='5S+G!H<"QV(#$N,CDN,BXU(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S`@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`Q
M+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#(N,0H@*B!`<&%C:V%G92!(;W)D95].
M;W1I9FEC871I;VX*("HO"F-L87-S($YO=&EF:6-A=&EO;E],:7-T96YE<E]S
M=&%T=7,@97AT96YD<R!.;W1I9FEC871I;VY?3&ES=&5N97(@>PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@3F]T
M:69I8V%T:6]N7TQI<W1E;F5R7W-T871U<R@I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]H86YD;&5S(#T@87)R87DH)VAO<F1E+F5R<F]R)R`@(#T^(&%R<F%Y
M*"=A;&5R=',O97)R;W(N<&YG)RP@7R@B17)R;W(B*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VAO<F1E+G-U8V-E<W,G(#T^(&%R<F%Y
M*"=A;&5R=',O<W5C8V5S<RYP;F<G+"!?*")3=6-C97-S(BDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H;W)D92YW87)N:6YG)R`]/B!A
M<G)A>2@G86QE<G1S+W=A<FYI;F<N<&YG)RP@7R@B5V%R;FEN9R(I*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&]R9&4N;65S<V%G92<@
M/3X@87)R87DH)V%L97)T<R]M97-S86=E+G!N9R<L(%\H(DUE<W-A9V4B*2DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&$@=6YI<75E(&ED96YT
M:69I97(@9F]R('1H:7,@;&ES=&5N97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@(%5N:7%U92!I9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M3F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("=S=&%T=7,G.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3W5T<'5T<R!T:&4@<W1A='5S(&QI;F4@:68@=&AE
M<F4@87)E(&%N>2!M97-S86=E<R!O;B!T:&4@)W-T871U<R<*("`@("`J(&UE
M<W-A9V4@<W1A8VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D;65S
M<V%G95-T86-K("!4:&4@<W1A8VL@;V8@;65S<V%G97,N"B`@("`@*B!`<&%R
M86T@87)R87D@)&]P=&EO;G,@("`@("`@($%N(&%R<F%Y(&]F(&]P=&EO;G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YO=&EF>2@F)&UE<W-A9V53=&%C:RP@
M)&]P=&EO;G,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D
M;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("!W:&EL92`H)&UE<W-A9V4@
M/2!A<G)A>5]S:&EF="@D;65S<V%G95-T86-K*2D@>PH@("`@("`@("`@("`@
M("`@96-H;R`D=&AI<RT^9V5T365S<V%G92@D;65S<V%G92D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96-H;R`G/&)R(&-L87-S/2)S<&%C97(B("\^
M)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P=71S(&]N
M92!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;65S<V%G
M92`@3VYE(&UE<W-A9V4@:&%S:"!F<F]M('1H92!S=&%C:RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T365S<V%G92@D;65S<V%G92D*("`@('L*("`@("`@
M("!G;&]B86P@)')E9VES=')Y.PH*("`@("`@("`D979E;G0@/2`D=&AI<RT^
M9V5T179E;G0H)&UE<W-A9V4I.PH@("`@("`@("1T97AT(#T@)&5V96YT+3YG
M971-97-S86=E*"D["@H@("`@("`@(&EF("@A:6Y?87)R87DH)V-O;G1E;G0N
M<F%W)RP@)'1H:7,M/F=E=$9L86=S*"1M97-S86=E*2DI('L*("`@("`@("`@
M("`@)'1E>'0@/2!H=&UL<W!E8VEA;&-H87)S*"1T97AT*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`G/'`@8VQA<W,](FYO=&EC92(^)R`N($AO<F1E
M.CII;6<H)'1H:7,M/E]H86YD;&5S6R1M97-S86=E6R=T>7!E)UU=6S!=+"`D
M=&AI<RT^7VAA;F1L97-;)&UE<W-A9V5;)W1Y<&4G75U;,5TL("<G+"`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2`N("<F;F)S<#LF;F)S<#LG
M("X@)'1E>'0@+B`G/"]P/B<["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;7ES<6PN<&AP````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C0R-#`@,3`U,34T,S0Q,S<@,#(T
M,30V`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N
M(&9O<B!->5-13"`H;F%T:79E*2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@("`M(%1H92!H;W-T;F%M92!O9B!T
M:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@("`M(%1H92!C
M;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*
M("H@("`G=7-E<FYA;64G("`@+2!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T
M;R!C;VYN96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("`@
M+2!4:&4@<&%S<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J
M("`@)V1A=&%B87-E)R`@("T@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@
M*B`@("=T86)L92<@("`@("`M(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T
M82!T86)L92!I;B`G9&%T86)A<V4G+@H@*B`@("=R;W=L;V-K:6YG)R`M(%=H
M971H97(@=&\@=7-E(')O=RUL979E;"!L;V-K:6YG(&%N9"!T<F%N<V%C=&EO
M;G,@*$EN;F]$0BD*("H@("`@("`@("`@("`@("`@("!O<B!T86)L92UL979E
M;"!L;V-K:6YG("A->4E304TI+CPO<')E/@H@*@H@*B!297%U:7)E9"!F;W(@
M<V]M92!C;VYF:6=U<F%T:6]N<SH\<')E/@H@*B`@("=P;W)T)R`@5&AE('!O
M<G0@;VX@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^
M"B`J"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R<VES
M=&5N="<@(%5S92!P97)S:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A
M;BD\+W!R93X*("H*("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE(%-E
M<W-I;VY(86YD;&5R(&-A;B!B92!F;W5N9"!I;@H@*B!H;W)D92]S8W)I<'1S
M+W-Q;"]H;W)D95]S97-S:6]N:&%N9&QE<BYS<6PN"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U-E<W-I;VY(86YD;&5R+U-E<W-I;VY(86YD;&5R+VUY<W%L
M+G!H<"QV(#$N,38N,3(N,30@,C`P-B\P,R\R.2`Q.3HP-CHT-B!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM
M:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H<F%M92`\;6EK94!G<F%F
M=&]N:&%L;"YC;RYN>CX*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N
M0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E
M($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE
M<E]M>7-Q;"!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@
M("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO
M;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A
M<B`D7V1B.PH*("`@("\J*@H@("`@("H@07)E('=E(&-O;FYE8W1E9"!T;R!T
M:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L
M<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@
M("!["B`@("`@("`@+RH@1&ES8V]N;F5C="!F<F]M(&1A=&%B87-E+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@
M0&UY<W%L7V-L;W-E*"1T:&ES+3Y?9&(I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D
M871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@
M("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O
M;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@
M("`@("\J(%-E<W-I;VX@=&EM96]U="P@9&]N)W0@<F5L>2!O;B!G87)B86=E
M(&-O;&QE8W1I;VXN("HO"B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@+2!I
M;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["@H@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E<R!7
M2$5212!S97-S:6]N7VED(#T@)7,G("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("<@04Y$('-E<W-I;VY?;&%S=&UO9&EF:65D(#X@)7,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W%U;W1E*"1I9"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="D["@H@("`@("`@(&EF
M("@A96UP='DH)'1H:7,M/E]P87)A;7-;)W)O=VQO8VMI;F<G72DI('L*("`@
M("`@("`@("`@+RH@4W1A<G0@82!T<F%N<V%C=&EO;BX@*B\*("`@("`@("`@
M("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G4U1!4E0@5%)!3E-!0U1)3TXG
M+"`D=&AI<RT^7V1B*3L*("`@("`@("`@("`@)'%U97)Y("X]("<@1D]2(%50
M1$%412<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E<W5L="`]
M($!M>7-Q;%]Q=65R>2@G3$]#2R!404),15,@)R`N("1T:&ES+3Y?<&%R86US
M6R=T86)L92==("X@)R!74DE412<L("1T:&ES+3Y?9&(I.PH@("`@("`@('T*
M("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%
M0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS
M<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;7ES<6PZ.G)E
M860H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'
M*3L*"B`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T
M:&ES+3Y?9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@<F5T<FEE=FEN9R!S97-S:6]N
M(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@0&UY<W%L7W)E<W5L="@D<F5S=6QT+"`P+"`P*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO
M;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A
M=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U
M8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@>PH@("`@("`@("\J($UA
M:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@
M*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I
M;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F
M*"=215!,04-%($E.5$\@)7,@*'-E<W-I;VY?:60L('-E<W-I;VY?9&%T82P@
M<V5S<VEO;E]L87-T;6]D:69I960I)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G(%9!3%5%4R`H)7,L("5S+"`E<RDG+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W%U;W1E*"1I9"DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W%U;W1E*"1S97-S:6]N7V1A=&$I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@=&EM92@I*3L*"B`@("`@("`@)')E
M<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<F]W;&]C:VEN9R==*2D@
M>PH@("`@("`@("`@("!`;7ES<6Q?<75E<GDH)U5.3$]#2R!404),15,@)R`N
M("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^7V1B*3L*("`@("`@
M("!]"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@($!M>7-Q
M;%]Q=65R>2@G4D],3$)!0TLG+"`D=&AI<RT^7V1B*3L*("`@("`@("`@("`@
M2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R('=R:71I;F<@<V5S<VEO;B!D871A
M)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!`;7ES<6Q?
M<75E<GDH)T-/34U)5"<L("1T:&ES+3Y?9&(I.PH*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A=&$@
M9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE"B`@
M("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F
M86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH
M)&ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L
M:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O
M;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$52
M12!S97-S:6]N7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("1T:&ES+3Y?<75O=&4H)&ED*2D[
M"@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V
M96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,
M(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7VUY<W%L.CID97-T<F]Y*"DZ('%U
M97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@
M/2!`;7ES<6Q?<75E<GDH)'%U97)Y+"`D=&AI<RT^7V1B*3L*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W)O=VQO8VMI;F<G72DI('L*("`@
M("`@("`@("`@0&UY<W%L7W%U97)Y*"=53DQ/0TL@5$%"3$53("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]D8BD["B`@("`@("`@?0H@
M("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!`;7ES<6Q?<75E
M<GDH)U)/3$Q"04-+)RP@)'1H:7,M/E]D8BD["B`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"=&86EL960@=&\@9&5L971E('-E<W-I;VX@*&ED(#T@
M)R`N("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!`;7ES<6Q?<75E<GDH)T-/34U)5"<L("1T:&ES+3Y?9&(I.PH*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A
M9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M
M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X
M;&EF971I;64@/2`S,#`I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E
M(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,
M('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&
M4D]-("5S(%=(15)%('-E<W-I;VY?;&%S=&UO9&EF:65D(#P@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL
M("AI;G0I*'1I;64H*2`M("1M87AL:69E=&EM92DI.PH*("`@("`@("`O*B!,
M;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@
M($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S
M:6]N2&%N9&QE<E]M>7-Q;#HZ9V,H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%
M7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@
M<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@D<75E
M<GDL("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@9V%R8F%G92!C;VQL
M96-T:6YG(&]L9"!S97-S:6]N<R<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N($!M>7-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES
M+3Y?9&(I.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!T
M:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S<VEO;B!I9&5N=&EF
M:65R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S<VEO;DE$<R@I"B`@
M("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A
M8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I
M.PH*("`@("`@("`O*B!397-S:6]N('1I;65O=70L(&1O;B=T(')E;'D@;VX@
M9V%R8F%G92!C;VQL96-T:6]N("HO"B`@("`@("`@)'1I;65O=70@/2!T:6UE
M*"D@+2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["@H@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7VED($923TT@
M)7,G("X*("`@("`@("`@("`@("`@("`@("`@("`@("<@5TA%4D4@<V5S<VEO
M;E]L87-T;6]D:69I960@/B`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:6UE;W5T*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A
M="!A($1%0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92AS<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;7ES
M<6PZ.F=E=%-E<W-I;VY)1',H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q
M=65R>2@D<75E<GDL("1T:&ES+3Y?9&(I.PH@("`@("`@(&EF("@A)')E<W5L
M="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G17)R;W(@9V5T
M=&EN9R!S97-S:6]N($E$<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'-E<W-I
M;VYS(#T@87)R87DH*3L*"B`@("`@("`@=VAI;&4@*"1R;W<@/2!M>7-Q;%]F
M971C:%]R;W<H)')E<W5L="DI"B`@("`@("`@("`@("1S97-S:6]N<UM=(#T@
M)')O=ULP73L*"B`@("`@("`@<F5T=7)N("1S97-S:6]N<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($5S8V%P92!A(&UY<W%L('-T<FEN9RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1V86QU92`@5&AE('-T<FEN9R!T;R!Q=6]T92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@5&AE('%U;W1E9"!S=')I;F<N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]Q=6]T92@D=F%L=64I"B`@("!["B`@("`@("`@<W=I
M=&-H("AS=')T;VQO=V5R*&=E='1Y<&4H)'9A;'5E*2DI('L*("`@("`@("!C
M87-E("=N=6QL)SH*("`@("`@("`@("`@<F5T=7)N("=.54Q,)SL*"B`@("`@
M("`@8V%S92`G:6YT96=E<B<Z"B`@("`@("`@("`@(')E='5R;B`D=F%L=64[
M"@H@("`@("`@(&-A<V4@)W-T<FEN9R<Z"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@<F5T=7)N("(G(B`N($!M>7-Q;%]R96%L7V5S8V%P95]S=')I
M;F<H)'9A;'5E+"`D=&AI<RT^7V1B*2`N("(G(CL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!O<&5N(&$@8V]N;F5C=&EO
M;B!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R
M0V]N9FEG*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@
M("`@("`@("!A<G)A>2@G:&]S='-P96,G+"`G=7-E<FYA;64G+"`G9&%T86)A
M<V4G*2P*("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!->5-13"<I.PH*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=P87-S=V]R9"==(#T@
M)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M86)L92==(#T@)VAO<F1E7W-E<W-I;VYH86YD;&5R)SL*("`@("`@("!]"@H@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==
M*2D@>PH@("`@("`@("`@("`D8V]N;F5C="`]("=M>7-Q;%]C;VYN96-T)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V]N;F5C="`]("=M>7-Q
M;%]P8V]N;F5C="<["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?
M9&(@/2!`)&-O;FYE8W0H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72DI('L*("`@("`@
M("`@("`@2&]R9&4Z.F9A=&%L*%!%05(Z.G)A:7-E17)R;W(H)T-O=6QD(&YO
M="!C;VYN96-T('1O(&1A=&%B87-E(&9O<B!344P@4V5S<VEO;DAA;F1L97(N
M)RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!I
M9B`H(4!M>7-Q;%]S96QE8W1?9&(H)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E
M)UTL("1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@($AO<F1E.CIF871A;"A0
M14%2.CIR86ES945R<F]R*'-P<FEN=&8H)T-O=6QD(&YO="!C;VYN96-T('1O
M('1A8FQE("5S(&9O<B!344P@4V5S<VEO;DAA;F1L97(N)RP@)'1H:7,M/E]P
M87)A;7-;)V1A=&%B87-E)UTI+"!?7T9)3$5?7RP@7U],24Y%7U\I*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE
M<B]N;VYE+G!H<```````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S4R,B`Q
M,#4Q-30S-#$S-R`P,C,W-#``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(%-E<W-I;VY(86YD;&5R(&EM
M<&QE;65N=&%T:6]N(&9O<B!02%`G<R!B=6EL="UI;B!S97-S:6]N(&AA;F1L
M97(N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("!.;VYE
M+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@
M3F]N92X\+W!R93X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4V5S<VEO;DAA
M;F1L97(O4V5S<VEO;DAA;F1L97(O;F]N92YP:'`L=B`Q+C,N,BXT(#(P,#8O
M,#$O,#$@,C$Z,C@Z,S0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`U
M+3(P,#8@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE9'4^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!-871T(%-E;'-K>2`\<V5L<VMY0&-O
M;'5M8FEA+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E
M($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE
M<E]N;VYE(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@("\J*@H@("`@
M("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E
M;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I
M;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D
M:60I"B`@("!["B`@("`@("`@)&9I;&4@/2!S97-S:6]N7W-A=F5?<&%T:"@I
M("X@1$E214-43U)97U-%4$%2051/4B`N("=S97-S7R<@+B`D:60["@H@("`@
M("`@("1S97-S:6]N7V1A=&$@/2!`9FEL95]G971?8V]N=&5N=',H)&9I;&4I
M.PH@("`@("`@(&EF("@D<V5S<VEO;E]D871A(#T]/2!F86QS92D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M<F5A9"!F:6QE.B`B*2`N("1F:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<V5S<VEO;E]D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@=F%L:60@<V5S
M<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4V5S
M<VEO;DE$<R@I"B`@("!["B`@("`@("`@)'-E<W-I;VYS(#T@87)R87DH*3L*
M"B`@("`@("`@)'!A=&@@/2!S97-S:6]N7W-A=F5?<&%T:"@I.PH@("`@("`@
M("1D(#T@9&ER*&5M<'1Y*"1P871H*2`_(%5T:6PZ.F=E=%1E;7!$:7(H*2`Z
M("1P871H*3L*"B`@("`@("`@=VAI;&4@*&9A;'-E("$]/2`H)&5N=')Y(#T@
M)&0M/G)E860H*2DI('L*("`@("`@("`@("`@+RH@36%K92!S=7)E('=E)W)E
M(&1E86QI;F<@=VET:"!F:6QE<R!T:&%T('-T87)T('=I=&@*("`@("`@("`@
M("`@("H@<V5S<U\N("HO"B`@("`@("`@("`@(&EF("AI<U]F:6QE*"1D+3YP
M871H("X@1$E214-43U)97U-%4$%2051/4B`N("1E;G1R>2D@)B8*("`@("`@
M("`@("`@("`@("%S=')N8VUP*"1E;G1R>2P@)W-E<W-?)RP@<W1R;&5N*"=S
M97-S7R<I*2D@>PH@("`@("`@("`@("`@("`@)'-E<W-I;VYS6UT@/2!S=6)S
M='(H)&5N=')Y+"!S=')L96XH)W-E<W-?)RDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;&1A
M<"YP:'``````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P-C<@,3`U,34T
M,S0Q,S<@,#(S-S(S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<B!I;7!L96UE
M;G1A=&EO;B!F;W(@3$1!4"!D:7)E8W1O<FEE<RX*("H*("H@4F5Q=6ER960@
M<&%R86UE=&5R<SH\<')E/@H@*B`@("=F;V\G("`@("`@(%1H92!F;V\N"B`J
M"B`J($]P=&EO;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P96,G
M("!4:&4@:&]S=&YA;64@;V8@=&AE(&QD87`@<V5R=F5R+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]L
M9&%P+G!H<"QV(#$N,BXR+C(@,C`P-2\Q,"\Q."`Q,3HP,3HR-R!J86X@17AP
M("0*("H*("H@5&AI<R!C;V1E(&ES(&%D87!T960@9G)O;2!T:&4@8V]M;65N
M=',@870*("H@:'1T<#HO+W=W=RYP:'`N;F5T+W-E<W-I;VXM<V5T+7-A=F4M
M:&%N9&QE<BX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!S:6YC92`@($AO<F1E(#,N
M,0H@*B!`<&%C:V%G92!(;W)D95]397-S:6]N2&%N9&QE<@H@*B\*8VQA<W,@
M4V5S<VEO;DAA;F1L97)?;&1A<"!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*
M"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A
M<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@
M("`@*B\*("`@('9A<B`D7V-O;FX["@H@("`@+RHJ"B`@("`@*B!/<&5N('1H
M92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'-A=F5?<&%T:"`@("`@5&AE('!A=&@@=&\@=&AE('-E<W-I
M;VX@;V)J96-T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]N86UE
M("!4:&4@;F%M92!O9B!T:&4@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"1S879E7W!A=&@L("1S97-S
M:6]N7VYA;64I"B`@("!["B`@("`@("`@)'1H:7,M/E]C;VYN(#T@0&QD87!?
M8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P@)'1H:7,M/E]P
M87)A;7-;)W!O<G0G72D["B`@("`@("`@<F5T=7)N($!L9&%P7V)I;F0H)'1H
M:7,M/E]C;VYN+"`D=&AI<RT^7W!A<F%M<ULG9&XG72P@)'1H:7,M/E]P87)A
M;7-;)W!A<W-W;W)D)UTI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V4@
M=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@
M(')E='5R;B!`;&1A<%]C;&]S92@D=&AI<RT^7V-O;FXI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E
M<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L
M97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@
M5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5A9"@D:60I"B`@("!["B`@("`@("`@)'-R(#T@0&QD87!?<V5A<F-H
M*"1T:&ES+3Y?8V]N;BP@)'1H:7,M/E]P87)A;7-;)V1N)UTL("(H8VX])&ED
M*2(I.PH@("`@("`@("1I;F9O(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M
M/E]C;VYN+"`D<W(I.PH@("`@("`@(&EF("@D:6YF;ULG8V]U;G0G72`^(#`I
M('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O6S!=6R=S97-S:6]N)UU;,%T[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E('-E<W-I;VX@9&%T
M82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@("`@(%1H92!S97-S:6]N(&ED
M96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97-S:6]N7V1A=&$@
M(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO;E]D871A*0H@("`@
M>PH@("`@("`@("1U<&1A=&4@/2!A<G)A>2@G;V)J96-T0VQA<W,G(#T^(&%R
M<F%Y*"=P:'!S97-S:6]N)RP@)W1O<"<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`G<V5S<VEO;B<@/3X@)'-E<W-I;VY?9&%T82D["B`@("`@("`@)&1N
M(#T@(F-N/21I9"PB("X@)'1H:7,M/E]P87)A;7-;)V1N)UT["B`@("`@("`@
M0&QD87!?9&5L971E*"1T:&ES+3Y?8V]N;BP@)&1N*3L*("`@("`@("!R971U
M<FX@0&QD87!?861D*"1T:&ES+3Y?8V]N;BP@)&1N+"`D=7!D871E*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@=&AE(&1A=&$@9F]R(&$@<&%R
M=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@:6X@=&AE"B`@("`@*B!397-S
M:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE
M<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E<W1R;WDH)&ED*0H@("`@
M>PH@("`@("`@("1D;B`](")C;CTD:60L(B`N("1T:&ES+3Y?<&%R86US6R=D
M;B==.PH@("`@("`@(')E='5R;B!`;&1A<%]D96QE=&4H)'1H:7,M/E]C;VYN
M+"`D9&XI.PH@("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T
M('-T86QE('-E<W-I;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI9F5T:6UE
M("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE
M<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E=&EM92`]
M(#,P,"D*("`@('L*("`@("`@("`D<W(@/2!`;&1A<%]S96%R8V@H)'1H:7,M
M/E]C;VYN+"`D=&AI<RT^7W!A<F%M<ULG9&XG72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)RAO8FIE8W1#;&%S<SUP:'!S97-S:6]N*2<L(&%R<F%Y
M*"<K)RP@)V-N)RDI.PH@("`@("`@("1I;F9O(#T@0&QD87!?9V5T7V5N=')I
M97,H)'1H:7,M/E]C;VYN+"`D<W(I.PH@("`@("`@(&EF("@D:6YF;ULG8V]U
M;G0G72`^(#`I('L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&EN
M9F];)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("1I9"`]("1I
M;F9O6R1I75LG8VXG75LP73L*("`@("`@("`@("`@("`@("1D;B`](")C;CTD
M:60L(B`N("1T:&ES+3Y?<&%R86US6R=D;B==.PH@("`@("`@("`@("`@("`@
M)&QD87!S=&%M<"`]("1I;F9O6R1I75LG;6]D:69Y=&EM97-T86UP)UU;,%T[
M"B`@("`@("`@("`@("`@("`D>65A<B`]('-U8G-T<B@D;&1A<'-T86UP+"`P
M+"`T*3L*("`@("`@("`@("`@("`@("1M;VYT:"`]('-U8G-T<B@D;&1A<'-T
M86UP+"`T+"`R*3L*("`@("`@("`@("`@("`@("1D87D@/2!S=6)S='(H)&QD
M87!S=&%M<"P@-BP@,BD["B`@("`@("`@("`@("`@("`D:&]U<B`]('-U8G-T
M<B@D;&1A<'-T86UP+"`X+"`R*3L*("`@("`@("`@("`@("`@("1M:6YU=&4@
M/2!S=6)S='(H)&QD87!S=&%M<"P@,3`L(#(I.PH@("`@("`@("`@("`@("`@
M)&UO9&EF:65D(#T@9VUM:W1I;64H)&AO=7(L("1M:6YU=&4L(#`L("1M;VYT
M:"P@)&1A>2P@)'EE87(I.PH@("`@("`@("`@("`@("`@:68@*'1I;64H*2`M
M("1M;V1I9FEE9"`^/2`D;6%X;&EF971I;64I('L*("`@("`@("`@("`@("`@
M("`@("!`;&1A<%]D96QE=&4H)'1H:7,M/E]C;VYN+"`D9&XI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]S87!D8BYP:'``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C,P-R`Q,#4Q-30S-#$S-R`P,C0P
M-S8`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O<W%L
M+G!H<"<["@HO*BH*("H@4V5S<VEO;DAA;F1L97(@:6UP;&5M96YT871I;VX@
M9F]R(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX@;&%Y97(N"B`J
M"B`J($EF('EO=2!A8V-E<W,@>6]U<B!D871A8F%S92!T:')O=6=H($]$0D,L
M('EO=2!W:6QL(&%L;6]S="!C97)T86EN;'D@;F5E9`H@*B!T;R!C:&%N9V4@
M4$A0)W,@9&5F875L="!V86QU92!F;W(@;V1B8RYD969A=6QT;')L("AT:&ES
M(&ES(&$@<&AP+FEN:0H@*B!S971T:6YG*2X@5&AE(&1E9F%U;'0@:7,@-#`Y
M-BP@=VAI8V@@:7,@=&]O('-M86QL("AY;W5R('-E<W-I;VX@9&%T82!W:6QL
M"B`J(&)E(&-H;W!P960@;V9F*2P@86YD('-E='1I;F<@:70@=&\@,"!$3T53
M($Y/5"!W;W)K("T@=&AA="!D;V5S;B=T(&UE86X@;F\*("H@;&EM:70L(&9O
M<B!S;VUE(')E87-O;BX@;V1B8RYD969A=6QT;')L(#T@,S(W-C@@<V5E;7,@
M=&\@=V]R:R!P<F5T='D@=V5L;`H@*B`H=7-I;F<@35-344PM,C`P,"DN"B`J
M"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R93X*("H@("`G:&]S='-P96,G
M("!4:&4@:&]S=&YA;64@;V8@=&AE(&1A=&%B87-E('-E<G9E<BX*("H@("`G
M<')O=&]C;VPG("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L
M("=U;FEX)RP@971C+BDN"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE
M('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@
M)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E
M<FYA;64G+@H@*B`@("=D871A8F%S92<@(%1H92!N86UE(&]F('1H92!D871A
M8F%S92X\+W!R93X*("H*("H@3W!T:6]N86P@<&%R86UE=&5R<SH\<')E/@H@
M*B`@("=T86)L92<@("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T
M86)L92!I;B`G9&%T86)A<V4G+B`@1&5F875L="!I<PH@*B`@("`@("`@("`@
M("`@("=H;W)D95]S97-S:6]N:&%N9&QE<B<N/"]P<F4^"B`J"B`J(%1H92!T
M86)L92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N2&%N9&QE<B!C86X@8F4@
M9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R9&5?<V5S<VEO;FAA
M;F1L97(N<V%P9&(N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]397-S
M:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]S87!D8BYP:'`L=B`Q+C$S+C$R
M+C@@,C`P-B\P,2\P,2`R,3HR.#HS-"!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL
M+F-O+FYZ/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EK92!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC
M;&%S<R!397-S:6]N2&%N9&QE<E]S87!D8B!E>'1E;F1S(%-E<W-I;VY(86YD
M;&5R7W-Q;"!["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W(%-1
M3"!397-S:6]N2&%N9&QE<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@
M<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4V5S<VEO;DAA;F1L
M97)?<V%P9&(H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'!A
M<F%M<ULG<&AP='EP92==(#T@)V]D8F,G.PH@("`@("`@('!A<F5N=#HZ4V5S
M<VEO;DAA;F1L97)?<W%L*"1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E
M;G1I9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N
M9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I
M;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D
M:60I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI
M9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N
M;F5C="@I.PH*("`@("`@("`O*B!"96=I;B!A('1R86YS86-T:6]N+B`J+PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YA=71O8V]M;6ET*&9A;'-E
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=314Q%0U0@<V5S
M<VEO;E]D871A($923TT@)7,@5TA%4D4@<V5S<VEO;E]I9"`]("5S)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<75O=&4H
M)&ED*2D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L
M;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT
M9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q;#HZ<F5A9"@I.B!Q
M=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`O*B!%>&5C=71E('1H92!Q=65R>2`J+PH@("`@("`@("1R97-U;'0@
M/2!O9&)C7V5X96,H)'1H:7,M/E]D8BT^8V]N;F5C=&EO;BP@)'%U97)Y*3L*
M("`@("`@("!O9&)C7VQO;F=R96%D;&5N*"1R97-U;'0L(#$P-#@U-S8I.PH*
M("`@("`@("`O*B!&971C:"!T:&4@=F%L=64@*B\*("`@("`@("!O9&)C7V9E
M=&-H7W)O=R@D<F5S=6QT+"`P*3L*("`@("`@("`D9&%T82`](&]D8F-?<F5S
M=6QT*"1R97-U;'0L("=S97-S:6]N7V1A=&$G*3L*"B`@("`@("`@+RH@0VQE
M86X@=7`@*B\*("`@("`@("!O9&)C7V9R965?<F5S=6QT*"1R97-U;'0I.PH*
M("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O<W%L+G!H<```````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C,W,#$@,3`U,34T,S0Q,S<@,#(S
M-C`Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<B!I;7!L96UE;G1A=&EO;B!F
M;W(@4$A0)W,@4$5!4B!D871A8F%S92!A8G-T<F%C=&EO;B!L87EE<BX*("H*
M("H@4F5Q=6ER960@<&%R86UE=&5R<SH\<')E/@H@*B`@("=P:'!T>7!E)R`@
M(%1H92!D871A8F%S92!T>7!E("AE+F<N("=P9W-Q;"<L("=M>7-Q;"<L(&5T
M8RXI+CPO<')E/@H@*@H@*B!297%U:7)E9"!B>2!S;VUE(&1A=&%B87-E(&EM
M<&QE;65N=&%T:6]N<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T
M;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@
M(%1H92!C;VUM=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E
M=&,N*2X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A
M<V4N"B`J("`@)W5S97)N86UE)R`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@
M=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@)W!A<W-W;W)D)R`@
M5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET:"`G=7-E<FYA;64G+@H@*B`@
M("=O<'1I;VYS)R`@($%D9&ET:6]N86P@;W!T:6]N<R!T;R!P87-S('1O('1H
M92!D871A8F%S92X*("H@("`G='1Y)R`@("`@("!4:&4@5%19(&]N('=H:6-H
M('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("=P;W)T)R`@("`@
M(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E
M+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@
M)W!E<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N="!$0B!C;VYN96-T:6]N<S\@
M*&)O;VQE86XI"B`J("`@)W1A8FQE)R`@("`@("!4:&4@;F%M92!O9B!T:&4@
M<V5S<VEO;F1A=&$@=&%B;&4@:6X@)V1A=&%B87-E)RX@($1E9F%U;'0*("H@
M("`@("`@("`@("`@("`@(&ES("=H;W)D95]S97-S:6]N:&%N9&QE<B<N/"]P
M<F4^"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N
M2&%N9&QE<B!C86X@8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO
M:&]R9&5?<V5S<VEO;FAA;F1L97(N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]S<6PN<&AP+'8@
M,2XR,BXQ,"XQ,R`R,#`V+S`Q+S`Q(#(Q.C(X.C,T(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`9W)A
M9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-
M:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?4V5S<VEO;DAA;F1L
M97(*("HO"F-L87-S(%-E<W-I;VY(86YD;&5R7W-Q;"!E>'1E;F1S(%-E<W-I
M;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U
M<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R
M($1""B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J*@H@("`@("H@0F]O
M;&5A;B!I;F1I8V%T:6YG('=H971H97(@;W(@;F]T('=E)W)E(&-O;FYE8W1E
M9"!T;R!T:&4@4U%,('-E<G9E<BX*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!#;&]S92!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S
M92@I"B`@("!["B`@("`@("`@+RH@1&ES8V]N;F5C="!F<F]M(&1A=&%B87-E
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@
M("`@("`O*B!#;&]S92!A;GD@;W!E;B!T<F%N<V%C=&EO;G,N("HO"B`@("`@
M("`@("`@("1T:&ES+3Y?9&(M/F-O;6UI="@I.PH@("`@("`@("`@("`D=&AI
M<RT^7V1B+3YA=71O0V]M;6ET*'1R=64I.PH*("`@("`@("`@("`@)'1H:7,M
M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&(M/F1I<V-O;FYE8W0H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!T:&4@9&%T82!F
M;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!F<F]M('1H90H@
M("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('-E<W-I;VX@9&%T82X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I"B`@("!["B`@("`@("`@
M+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T
M:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O
M*B!"96=I;B!A('1R86YS86-T:6]N+B`J+PH@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YA=71O8V]M;6ET*&9A;'-E*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@($AO<F1E
M.CIL;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*
M"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=(;W)D92]344PN<&AP)SL*("`@("`@("`D<F5S=6QT(#T@
M2&]R9&5?4U%,.CIR96%D0FQO8B@D=&AI<RT^7V1B+"`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)W-E<W-I;VY?9&%T82<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-E<W-I;VY?:60G(#T^("1I
M9"DI.PH*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A=&$@=&\@
M=&AE(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I9&5N=&EF
M:65R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4:&4@
M<V5S<VEO;B!D871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@
M5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@('L*("`@
M("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O
M;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@
M("`@("\J($)U:6QD('1H92!344P@<75E<GDN("HO"B`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G4T5,14-4('-E<W-I;VY?:60@1E)/32`E<R!72$5212!S
M97-S:6]N7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y
M*"1I9"D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L
M;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT
M9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q;#HZ=W)I=&4H*3H@
M<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L
M="`]("1T:&ES+3Y?9&(M/F=E=$]N92@D<75E<GDL("1V86QU97,I.PH@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+U-1
M3"YP:'`G.PH@("`@("`@(&EF("@D<F5S=6QT*2!["B`@("`@("`@("`@("1R
M97-U;'0@/2!(;W)D95]344PZ.G5P9&%T94)L;V(H)'1H:7,M/E]D8BP@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL("=S97-S:6]N7V1A=&$G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S97-S:6]N
M7V1A=&$L(&%R<F%Y*"=S97-S:6]N7VED)R`]/B`D:60I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S97-S
M:6]N7VQA<W1M;V1I9FEE9"<@/3X@=&EM92@I*2D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')E<W5L="`]($AO<F1E7U-13#HZ:6YS97)T0FQO
M8B@D=&AI<RT^7V1B+"`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)W-E<W-I
M;VY?9&%T82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-E<W-I;VY?9&%T82P@87)R87DH)W-E<W-I;VY?:60G(#T^
M("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5S<VEO;E]L87-T;6]D:69I
M960G(#T^('1I;64H*2DI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YR;VQL8F%C:R@I.PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YA=71O
M0V]M;6ET*'1R=64I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@D
M<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YC;VUM:70H*3L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?9&(M/F%U=&]#;VUM:70H=')U92D["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"1R97-U;'0L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]D8BT^875T;T-O;6UI="AT<G5E*3L*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@
M=&AE(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@
M:6X@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF
M:65R+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1E<W1R;WDH)&ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H
M879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D
M=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q
M=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/
M32`E<R!72$5212!S97-S:6]N7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D["B`@("`@("`@)'9A
M;'5E<R`](&%R<F%Y*"1I9"D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@
M870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q
M;#HZ9&5S=')O>2@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D
M=F%L=65S*3L*("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"1R97-U;'0L
M(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?9&(M/F-O;6UI="@I.PH@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($=A<F)A
M9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M('1H92!397-S:6]N2&%N
M9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M
M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F(&$@<V5S<VEO;BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@
M9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G8R@D;6%X
M;&EF971I;64@/2`S,#`I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E
M(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@
M("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,
M('%U97)Y+B`J+PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)T1%3$5412!&
M4D]-("5S(%=(15)%('-E<W-I;VY?;&%S=&UO9&EF:65D(#P@/R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72D[
M"B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*'1I;64H*2`M("1M87AL:69E=&EM
M92D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@
M;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G
M4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W-Q;#HZ9V,H*3H@<75E<GD@
M/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@
M+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@("`@("`@)')E<W5L="`]("1T
M:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!(
M;W)D93HZ;&]G365S<V%G92@D<F5S=6QT+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1V5T(&$@;&ES="!O9B!T:&4@=F%L:60@<V5S<VEO;B!I9&5N=&EF
M:65R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@
M=F%L:60@<V5S<VEO;B!I9&5N=&EF:65R<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4V5S<VEO;DE$<R@I"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E
M('=E(&AA=F4@82!V86QI9"!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@
M("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@("`D=&EM96]U="`]('1I
M;64H*2`M(&EN:5]G970H)W-E<W-I;VXN9V-?;6%X;&EF971I;64G*3L*"B`@
M("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E
M<GD@/2`G4T5,14-4('-E<W-I;VY?:60@1E)/32`G("X@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("<@5TA%4D4@<V5S<VEO
M;E]L87-T;6]D:69I960@/B`_)SL*("`@("`@("`D=F%L=65S(#T@87)R87DH
M)'1I;65O=70I.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"
M54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P
M<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]S<6PZ.F=E=%-E
M<W-I;VY)1',H*3H@<75E<GD@/2`B)7,B)RP@)'%U97)Y*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T1%0E5'*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN("HO"B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/F=E=$-O;"@D<75E<GDL(#`L
M("1V86QU97,I.PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L
M="P@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P
M96X@82!C;VYN96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S.R!E>&ET<R`H
M2&]R9&4Z.F9A=&%L*"DI(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V-O;FYE
M8W1E9"D@>PH@("`@("`@("`@("!(;W)D93HZ87-S97)T1')I=F5R0V]N9FEG
M*"1T:&ES+3Y?<&%R86US+"`G<V5S<VEO;FAA;F1L97(G+`H@("`@("`@("`@
M("`@("`@87)R87DH)W!H<'1Y<&4G*2P*("`@("`@("`@("`@("`@("=S97-S
M:6]N(&AA;F1L97(@4U%,)RD["@H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%R86US6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=U<V5R
M;F%M92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W5S
M97)N86UE)UT@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT@/2`G)SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72`]("=H;W)D95]S97-S:6]N:&%N9&QE<B<["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE(%-13"!S97)V
M97(@=7-I;F<@=&AE('-U<'!L:65D"B`@("`@("`@("`@("`J('!A<F%M971E
M<G,N("HO"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G1$(N<&AP)SL*("`@
M("`@("`@("`@)'1H:7,M/E]D8B`]("9$0CHZ8V]N;F5C="@D=&AI<RT^7W!A
M<F%M<RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<&5R<VES=&5N="<@/3X@(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P
M97)S:7-T96YT)UTI*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?
M9&(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@($AO<F1E.CIF
M871A;"@D=&AI<RT^7V1B+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^7V1B+3YS971/<'1I;VXH)W!O
M<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]2
M5$%"24Q)5%E?15)23U)3*3L*"B`@("`@("`@("`@("1T:&ES+3Y?8V]N;F5C
M=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O4V5S<VEO;DAA;F1L97(O;65M8V%C:&4N<&AP````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,38R,38@,3`U,34T,S0Q,S<@,#(T-30W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J*@H@*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O
M<B!M96UC86-H92X*("H@;65M8V%C:&4@=V5B<VET93H@:'1T<#HO+W=W=RYD
M86YG82YC;VTO;65M8V%C:&5D+PH@*@H@*B!297%U:7)E9"!P87)A;65T97)S
M.CQP<F4^"B`J("`@)VAO<W1S<&5C)R`@5&AE(&AO<W1N86UE(&]F('1H92!M
M96UC86-H92!S97)V97(N"B`J("`@)W!O<G0G("`@("`@5&AE('!O<G0@;VX@
M=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@;65M8V%C:&4@<V5R=F5R+CPO<')E
M/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T97)S.CQP<F4^"B`J("`@)W!E<G-I
M<W1E;G0G("!5<V4@<&5R<VES=&5N="!$0B!C;VYN96-T:6]N<S\@*&)O;VQE
M86XI"B`J("`@)V-O;7!R97-S:6]N)R!5<V4@8V]M<')E<W-I;VX@=VAE;B!S
M=&]R:6YG('-E<W-I;VYS+CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]M96UC86-H92YP:'`L
M=B`Q+C$N,BXQ(#(P,#8O,#4O,#(@,3<Z,C<Z-#D@8VAU8VL@17AP("0*("H*
M("H@0V]P>7)I9VAT(#(P,#4M,C`P-B!2;VYG+45N($9A;B`\<F%F86Y`:6YF
M;W(N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@4F]N9RU%;B!&
M86X@/')A9F%N0&EN9F]R+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J
M($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S
M:6]N2&%N9&QE<E]M96UC86-H92!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*
M"B`@("`O*BH*("`@("`J($-U<G)E;G0@;65M8V%C:&4@8V]N;F5C=&EO;BX*
M("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)%]D
M8CL*"B`@("`O*BH*("`@("`J($)O;VQE86X@:6YD:6-A=&EN9R!W:&5T:&5R
M(&]R(&YO="!W92=R92!C;VYN96-T960@=&\@=&AE"B`@("`@*B!M96UC86-H
M92!S97)V97(N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7V-O;FYE8W1E9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M3&]C:R!H86YD;&4N"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@
M("HO"B`@("!V87(@)%]F<#L*"B`@("`O*BH*("`@("`J($-L;W-E('1H92!3
M97-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]C;VYN96-T960I('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYN
M96-T960@/2!F86QS93L*("`@("`@("`@("`@0&UE;6-A8VAE7V-L;W-E*"1T
M:&ES+3Y?9&(I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]U;FQO8VM3
M97-S:6]N*"D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO
M;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B
M86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@
M<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M96%D*"1I9"D*("`@('L*("`@("`@("`O*B!/8G1A:6X@<V5S<VEO;B!L;V-K
M+B`J+PH@("`@("`@("1T:&ES+3Y?;&]C:U-E<W-I;VXH)&ED*3L*"B`@("`@
M("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!M96UC86-H92!C;VYN
M96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@("`@
M("`D<F5S=6QT(#T@0&UE;6-A8VAE7V=E="@D=&AI<RT^7V1B+"`D:60I.PH@
M("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G
M365S<V%G92@G17)R;W(@<F5T<FEE=FEN9R!S97-S:6]N(&1A=&$@*&ED(#T@
M)R`N("1I9"`N("<I)RP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%
M4E(I.PH@("`@("`@("`@("`D=&AI<RT^7W5N;&]C:U-E<W-I;VXH*3L*("`@
M("`@("`@("`@0'5N;&EN:R@D=&AI<RT^7W!A<F%M<ULG;&]C:U]D:7(G72`N
M("<O;&]C:U\G("X@)&ED*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U)E860@<V5S
M<VEO;B!D871A("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D871A('1O
M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@:61E;G1I
M9FEE<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T82`@5&AE
M('-E<W-I;VX@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!W<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@("!["B`@
M("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!M96UC86-H92!C
M;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I.PH*("`@
M("`@("`D;&EF971I;64@/2!I;FE?9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T
M:6UE)RD["B`@("`@("`@)&9L86=S(#T@)'1H:7,M/E]P87)A;7-;)V-O;7!R
M97-S:6]N)UT@/R!-14U#04-(15]#3TU04D534T5$(#H@,#L*("`@("`@("`D
M<F5S=6QT(#T@0&UE;6-A8VAE7W-E="@D=&AI<RT^7V1B+"`D:60L("1S97-S
M:6]N7V1A=&$L("1F;&%G<RP@)&QI9F5T:6UE*3L*"B`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=%<G)O
M<B!W<FET:6YG('-E<W-I;VX@9&%T82`H:60@/2`G("X@)&ED("X@)RDG+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H)U=R;W1E('-E<W-I;VX@9&%T82`H:60@/2`G("X@)&ED("X@)RDG
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$97-T<F]Y
M('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@<V5S<VEO;B!I9&5N=&EF:65R
M(&EN('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@:61E;G1I
M9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!D97-T<F]Y*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@
M:&%V92!A('9A;&ED(&UE;6-A8VAE(&-O;FYE8W1I;VXN("HO"B`@("`@("`@
M)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("1R97-U;'0@/2!`;65M8V%C
M:&5?9&5L971E*"1T:&ES+3Y?9&(L("1I9"D["@H@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I;&5D
M('1O(&1E;&5T92!S97-S:6]N("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,
M15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G1&5L971E9"!S97-S:6]N(&1A=&$@*&ED(#T@)R`N("1I9"`N("<I)RP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("1T:&ES+3Y?=6YL;V-K4V5S<VEO;B@I.PH@("`@("`@($!U;FQI;FLH)'1H
M:7,M/E]P87)A;7-;)VQO8VM?9&ER)UT@+B`G+VQO8VM?)R`N("1I9"D["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'87)B
M86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T:&4@4V5S<VEO;DAA
M;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A('-E<W-I;VXN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L
M(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V,H)&UA
M>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A(&-O;FYE
M8W1I;VX@=&\@=&AE(&UE;6-A8VAE('-E<G9E<BAS*2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE
M8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V-O;FYE8W1E9"D@>PH@
M("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G06QR96%D>2!C;VYN96-T
M960@=&\@82!M96UC86-H92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(
M86YD;&5R)R`L(%]?1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/1U]$14)51RD[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@($AO<F1E
M.CIA<W-E<G1$<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S97-S:6]N
M:&%N9&QE<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G:&]S='-P96,G+"`G<&]R="<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!M96UC86-H92<I.PH*
M("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G
M72DI('L*("`@("`@("`@("`@)&-O;FYE8W1?<&5R<VES=&5N="`](&9A;'-E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYN96-T7W!E<G-I
M<W1E;G0@/2!T<G5E.PH@("`@("`@('T*("`@("`@("`D8V]N(#T@;F5W($UE
M;6-A8VAE.PH*("`@("`@("!F;W(@*"1I(#T@,"P@)&X@/2!C;W5N="@D=&AI
M<RT^7W!A<F%M<ULG:&]S='-P96,G72D[("1I(#P@)&X[("LK)&DI('L*("`@
M("`@("`@("`@:68@*"%`)&-O;BT^861D4V5R=F5R*"1T:&ES+3Y?<&%R86US
M6R=H;W-T<W!E8R==6R1I72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UU;)&E=+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;FYE8W1?<&5R<VES=&5N="DI
M('L*("`@("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*"=#;W5L9"!N
M;W0@861D(%LG("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UU;)&E=("X@
M)SHG("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G75LD:5T@+B`G72!A<R!M96UC
M86-H92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD;&5R)R`L(%]?
M1DE,15]?+"!?7TQ)3D5?7RQ014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T%D
M9&5D(%LG("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UU;)&E=("X@)SHG
M("X@)'1H:7,M/E]P87)A;7-;)W!O<G0G75LD:5T@+B`G72!A<R!M96UC86-H
M92!S97)V97(@9F]R(&UE;6-A8VAE(%-E<W-I;VY(86YD;&5R)RP@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-O;FYE8W1E9"`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\J($-H96-K(&EF(&%N>2!O9B!T:&4@<&]O;&5D
M(&-O;FYE8W1I;VYS('=O<FMS+B`J+PH@("`@("`@(&EF("@D8V]N+3YG9716
M97)S:6]N*"DI('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("1C;VX["B`@
M("`@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T-O;FYE8W1E9"!T;R!A(&UE;6-A8VAE
M('-E<G9E<B!F;W(@;65M8V%C:&4@4V5S<VEO;DAA;F1L97(G("P@7U]&24Q%
M7U\L(%]?3$E.15]?+%!%05)?3$]'7T1%0E5'*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G0V]U;&0@;F]T(&-O;FYE8W0@
M=&\@86YY(&UE;6-A8VAE('-E<G9E<B!F;W(@;65M8V%C:&4@4V5S<VEO;DAA
M;F1L97(G("P@7U]&24Q%7U\L(%]?3$E.15]?+%!%05)?3$]'7T524BD["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]L;V-K4V5S<VEO;B@D:60I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]F<"`]($!F;W!E;B@D=&AI<RT^7W!A<F%M<ULG
M;&]C:U]D:7(G72`N("<O;&]C:U\G("X@)&ED+"`G=RLG*3L*("`@("`@("!I
M9B`H(21T:&ES+3Y?9G`I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A
M9V4H)T-O=6QD(&YO="!O<&5N('-E<W-I;VX@;&]C:R!F;W(@)R`N("1I9"P@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@A0&9L;V-K
M*"1T:&ES+3Y?9G`L($Q/0TM?15@I*2!["B`@("`@("`@("`@($AO<F1E.CIL
M;V=-97-S86=E*"=#;W5L9"!N;W0@;&]C:R!S97-S:6]N("<@+B`D:60L(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W5N;&]C:U-E<W-I;VXH*0H@("`@>PH@("`@("`@
M(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7V9P*2D@>PH@("`@("`@("`@("!I
M9B`H(4!F;&]C:R@D=&AI<RT^7V9P+"!,3T-+7U5.*2D@>PH@("`@("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T-O=6QD(&YO="!U;FQO8VL@<V5S
M<VEO;B<L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!`9F-L;W-E*"1T:&ES+3Y?9G`I.PH@
M("`@("`@('T*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]397-S:6]N2&%N9&QE<B]O8VDX+G!H<```````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-#`S,B`Q,#4Q-30S-#$S-R`P,C,V
M-#(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%-E<W-I;VY(86YD;&5R.CH@:6UP;&5M96YT871I;VX@
M9F]R($]R86-L92`X:2`H;F%T:79E*2X*("H*("H@4F5Q=6ER960@<&%R86UE
M=&5R<SH\<')E/@H@*B`@("=H;W-T<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T
M:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM
M=6YI8V%T:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G+"!E=&,N*2X*("H@
M("`G=7-E<FYA;64G("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN
M96-T('1O('1H92!D871A8F%S92X*("H@("`G<&%S<W=O<F0G("!4:&4@<&%S
M<W=O<F0@87-S;V-I871E9"!W:71H("=U<V5R;F%M92<N"B`J("`@)V1A=&%B
M87-E)R`@5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E+@H@*B`@("=T86)L92<@
M("`@(%1H92!N86UE(&]F('1H92!S97-S:6]N9&%T82!T86)L92!I;B`G9&%T
M86)A<V4G+CPO<')E/@H@*@H@*B!297%U:7)E9"!F;W(@<V]M92!C;VYF:6=U
M<F%T:6]N<SH\<')E/@H@*B`@("=P;W)T)R`@5&AE('!O<G0@;VX@=VAI8V@@
M=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N/"]P<F4^"B`J"B`J($]P=&EO
M;F%L('!A<F%M971E<G,Z/'!R93X*("H@("`G<&5R<VES=&5N="<@(%5S92!P
M97)S:7-T96YT($1"(&-O;FYE8W1I;VYS/R`H8F]O;&5A;BD\+W!R93X*("H*
M("H@5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE(%-E<W-I;VY(86YD;&5R
M(&-A;B!B92!F;W5N9"!I;@H@*B!H;W)D92]S8W)I<'1S+W-Q;"]H;W)D95]S
M97-S:6]N:&%N9&QE<BYO8VDX+G-Q;"X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4V5S<VEO;DAA;F1L97(O4V5S<VEO;DAA;F1L97(O;V-I."YP:'`L=B`Q
M+C@N-"XQ,2`R,#`V+S`R+S$P(#$X.C0V.C4S(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($QI86T@2&]E:V5N9V$@/&QI86UR0'5M:6-H
M+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C
M;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($QI86T@2&]E:V5N
M9V$@/&QI86UR0'5M:6-H+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,BXR"B`J
M($!P86-K86=E($AO<F1E7U-E<W-I;VY(86YD;&5R"B`J+PIC;&%S<R!397-S
M:6]N2&%N9&QE<E]O8VDX(&5X=&5N9',@4V5S<VEO;DAA;F1L97(@>PH*("`@
M("\J*@H@("`@("H@2&%N9&QE(&9O<B!T:&4@8W5R<F5N="!D871A8F%S92!C
M;VYN96-T:6]N+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J
M+PH@("`@=F%R("1?9&(["@H@("`@+RHJ"B`@("`@*B!!<F4@=V4@8V]N;F5C
M=&5D('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]C;VYN96-T960@/2!F86QS93L*"B`@
M("`O*BH*("`@("`J($-L;W-E('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-L
M;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]C;VYN96-T960I('L*
M("`@("`@("`@("`@)'1H:7,M/E]C;VYN96-T960@/2!F86QS93L*("`@("`@
M("`@("`@<F5T=7)N($]#24QO9T]F9B@D=&AI<RT^7V1B*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5A9"!T:&4@9&%T82!F;W(@82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I
M9FEE<B!F<F]M('1H90H@("`@("H@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@5&AE('-E<W-I;VX@
M:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M('-E<W-I;VX@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D:60I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D
M871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`D<V5L96-T7W%U97)Y(#T@<W!R:6YT9B@G4T5,14-4
M('-E<W-I;VY?9&%T82!&4D]-("5S(%=(15)%('-E<W-I;VY?:60@/2`E<R!&
M3U(@55!$051%)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)'1H:7,M/E]Q=6]T92@D:60I*3L*
M"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%0E5'(&QO9R!L979E
M;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS<')I;G1F*"=344P@
M475E<GD@8GD@4V5S<VEO;DAA;F1L97)?;V-I.#HZ<F5A9"@I.B!Q=65R>2`]
M("(E<R(G+"`D<V5L96-T7W%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@+RH@17AE8W5T92!Q=65R>2`J+PH@("`@("`@("1S96QE8W1?<W1A
M=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'-E;&5C=%]Q=65R>2D[
M"B`@("`@("`@3T-)17AE8W5T92@D<V5L96-T7W-T871E;65N="D["B`@("`@
M("`@:68@*"%/0TE&971C:$EN=&\H)'-E;&5C=%]S=&%T96UE;G0L("1R97-U
M;'0I*2!["B`@("`@("`@("`@("1I;G-E<G1?<75E<GD@/2!S<')I;G1F*"=)
M3E-%4E0@24Y43R`E<R`H<V5S<VEO;E]I9"P@<V5S<VEO;E]L87-T;6]D:69I
M960L('-E<W-I;VY?9&%T82D@5D%,5453("@E<RP@)7,L($5-4%197T),3T(H
M*2D@4D5455).24Y'('-E<W-I;VY?9&%T82!)3E1/(#IB;&]B)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<75O=&4H)&ED*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]Q=6]T92AT:6UE*"DI*3L*("`@("`@("`@
M("`@)&EN<V5R=%]S=&%T96UE;G0@/2!/0TE087)S92@D=&AI<RT^7V1B+"`D
M:6YS97)T7W%U97)Y*3L*("`@("`@("`@("`@)&QO8B`]($]#24YE=T1E<V-R
M:7!T;W(H)'1H:7,M/E]D8BD["B`@("`@("`@("`@($]#24)I;F1">4YA;64H
M)&EN<V5R=%]S=&%T96UE;G0L("<Z8FQO8B<L("1L;V(L("TQ+"!344Q47T),
M3T(I.PH@("`@("`@("`@("!/0TE%>&5C=71E*"1I;G-E<G1?<W1A=&5M96YT
M+"!/0TE?1$5&055,5"D["B`@("`@("`@("`@(&EF("@D<V5S<VEO;E]D871A
M*2!["B`@("`@("`@("`@("`@("`D;&]B+3YS879E*"1S97-S:6]N7V1A=&$I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!/0TE#;VUM
M:70H)'1H:7,M/E]D8BD["B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H
M)&EN<V5R=%]S=&%T96UE;G0I.PH@("`@("`@("`@("!/0TE%>&5C=71E*"1S
M96QE8W1?<W1A=&5M96YT*3L*("`@("`@("`@("`@3T-)1F5T8VA);G1O*"1S
M96QE8W1?<W1A=&5M96YT+"`D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@
M)'9A;'5E(#T@)')E<W5L=%LP72T^;&]A9"@I.PH@("`@("`@($]#249R9653
M=&%T96UE;G0H)'-E;&5C=%]S=&%T96UE;G0I.PH@("`@("`@(')E='5R;B@D
M=F%L=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@<V5S<VEO;B!D
M871A('1O('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@("`@5&AE('-E<W-I;VX@
M:61E;G1I9FEE<BX*("`@("`J($!P87)A;2!S=')I;F<@)'-E<W-I;VY?9&%T
M82`@5&AE('-E<W-I;VX@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!W<FET92@D:60L("1S97-S:6]N7V1A=&$I"B`@
M("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D871A
M8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C="@I
M.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)U501$%412`E<R!3150@<V5S<VEO;E]L87-T
M;6]D:69I960@/2`E<RP@<V5S<VEO;E]D871A(#T@14U05%E?0DQ/0B@I(%=(
M15)%('-E<W-I;VY?:60@/2`E<R!215154DY)3D<@<V5S<VEO;E]D871A($E.
M5$\@.F)L;V(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W%U;W1E*'1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W%U;W1E*"1I9"DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y
M(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*'-P<FEN=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]O
M8VDX.CIW<FET92@I.B!Q=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?1$5"54<I.PH*("`@("`@("`O*B!%>&5C=71E('%U97)Y("HO"B`@("`@
M("`@)'-T871E;65N="`]($]#25!A<G-E*"1T:&ES+3Y?9&(L("1Q=65R>2D[
M"B`@("`@("`@)&QO8B`]($]#24YE=T1E<V-R:7!T;W(H)'1H:7,M/E]D8BD[
M"B`@("`@("`@3T-)0FEN9$)Y3F%M92@D<W1A=&5M96YT+"`G.F)L;V(G+"`D
M;&]B+"`M,2P@4U%,5%]"3$]"*3L*("`@("`@("!/0TE%>&5C=71E*"1S=&%T
M96UE;G0L($]#25]$149!54Q4*3L*("`@("`@("!I9B`H)'-E<W-I;VY?9&%T
M82D@>PH@("`@("`@("`@("`D;&]B+3YS879E*"1S97-S:6]N7V1A=&$I.PH@
M("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES+3Y?
M9&(I.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D
M93HZ;&]G365S<V%G92@G17)R;W(@=W)I=&EN9R!S97-S:6]N(&1A=&$G+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5S=')O>2!T:&4@9&%T82!F;W(@
M82!P87)T:6-U;&%R('-E<W-I;VX@:61E;G1I9FEE<B!I;B!T:&4*("`@("`J
M(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5S=')O>2@D:60I
M"B`@("!["B`@("`@("`@+RH@36%K92!S=7)E('=E(&AA=F4@82!V86QI9"!D
M871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?8V]N;F5C
M="@I.PH*("`@("`@("`O*B!"=6EL9"!T:&4@4U%,('%U97)Y+B`J+PH@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H("=$14Q%5$4@1E)/32`E<R!72$5212!S
M97-S:6]N7VED(#T@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^7W%U;W1E*"1I9"DI.PH*
M("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L
M+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1
M=65R>2!B>2!397-S:6]N2&%N9&QE<E]O8VDX.CID97-T<F]Y*"DZ('%U97)Y
M(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1S=&%T96UE;G0@
M/2!/0TE087)S92@D=&AI<RT^7V1B+"`D<75E<GDI.PH@("`@("`@("1R97-U
M;'0@/2!/0TE%>&5C=71E*"1S=&%T96UE;G0I.PH@("`@("`@(&EF("@A)')E
M<W5L="D@>PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S=&%T96UE
M;G0I.PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I;&5D('1O
M(&1E;&5T92!S97-S:6]N("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@3T-)1G)E95-T871E;65N="@D
M<W1A=&5M96YT*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J($=A<F)A9V4@8V]L;&5C="!S=&%L92!S97-S:6]N<R!F<F]M
M('1H92!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P
M87)A;2!I;G1E9V5R("1M87AL:69E=&EM92`@5&AE(&UA>&EM=6T@86=E(&]F
M(&$@<V5S<VEO;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G8R@D;6%X;&EF971I;64@/2`Q*0H@("`@>PH@("`@("`@("\J
M($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO
M;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@
M0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*"=$14Q%5$4@1E)/32`E<R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE
M9"`\("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+"`D=&AI<RT^7W%U;W1E*'1I;64H*2`M("1M87AL:69E
M=&EM92DI.PH*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@
M;&]G(&QE=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN
M=&8H)U-13"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]O8VDX.CIG8R@I.B!Q
M=65R>2`]("(E<R(G+"`D<75E<GDI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`O*B!%>&5C=71E('1H92!Q=65R>2X@*B\*("`@("`@("`D<W1A=&5M
M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D
M<F5S=6QT(#T@3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A
M=&5M96YT*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R
M(&=A<F)A9V4@8V]L;&5C=&EN9R!O;&0@<V5S<VEO;G,G+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@($]#249R9653=&%T96UE;G0H)'-T
M871E;65N="D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'970@82!L:7-T(&]F('1H92!V86QI9"!S97-S:6]N(&ED96YT
M:69I97)S+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($$@;&ES="!O
M9B!V86QI9"!S97-S:6]N(&ED96YT:69I97)S+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!G971397-S:6]N241S*"D*("`@('L*("`@("`@("`O*B!-86ME('-U
M<F4@=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@
M("`@("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@("\J(%-E<W-I;VX@
M=&EM96]U="P@9&]N)W0@<F5L>2!O;B!G87)B86=E(&-O;&QE8W1I;VX@*B\*
M("`@("`@("`D=&EM96]U="`]('1I;64H*2`M(&EN:5]G970H)W-E<W-I;VXN
M9V-?;6%X;&EF971I;64G*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G
M4T5,14-4('-E<W-I;VY?:60@1E)/32`E<R<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@)R!72$5212!S97-S:6]N7VQA<W1M;V1I9FEE9"`^("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1I;65O=70I.PH*("`@
M("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE=F5L+B`J
M+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-13"!1=65R
M>2!B>2!397-S:6]N2&%N9&QE<E]O8VDX.CIG971397-S:6]N241S*"DZ('%U
M97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@<75E<GD@*B\*("`@("`@("`D<W1A=&5M96YT(#T@
M3T-)4&%R<V4H)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!/0TE%>&5C
M=71E*"1S=&%T96UE;G0I.PH*("`@("`@("`D<V5S<VEO;G,@/2!A<G)A>2@I
M.PH@("`@("`@('=H:6QE("A/0TE&971C:$EN=&\H)'-T871E;65N="P@)')O
M=RDI('L*("`@("`@("`@("`@)'-E<W-I;VYS6UT@/2`D<F]W6S!=.PH@("`@
M("`@('T*"B`@("`@("`@3T-)1G)E95-T871E;65N="@D<W1A=&5M96YT*3L*
M("`@("`@("!R971U<FX@)'-E<W-I;VYS.PH@("`@?0H*("`@("\J*@H@("`@
M("H@17-C87!E(&$@<W1R:6YG(&9O<B!I;G-E<G1I;VXN(%-T;VQE;B!F<F]M
M(%!%05(Z.D1"+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@=&\@<75O=&4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!Q=6]T960@<W1R
M:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75O=&4H)'9A;'5E*0H@("`@
M>PH@("`@("`@(')E='5R;B`H)'9A;'5E(#T]/2!N=6QL*2`_("=.54Q,)R`Z
M("(G(B`N('-T<E]R97!L86-E*"(G(BP@(B<G(BP@)'9A;'5E*2`N("(G(CL*
M("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(&]P96X@82!C;VYN
M96-T:6]N('1O('1H92!344P@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C="@I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3Y?8V]N;F5C=&5D*2!["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@($AO<F1E.CIA<W-E<G1$
M<FEV97)#;VYF:6<H)'1H:7,M/E]P87)A;7,L("=S97-S:6]N:&%N9&QE<B<L
M"B`@("`@("`@("`@(&%R<F%Y*"=H;W-T<W!E8R<L("=U<V5R;F%M92<L("=P
M87-S=V]R9"<I+`H@("`@("`@("`@("`G<V5S<VEO;B!H86YD;&5R($]R86-L
M92<I.PH*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`]
M("=H;W)D95]S97-S:6]N:&%N9&QE<B<["B`@("`@("`@?0H*("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=O8VE?8V]N;F5C="<I*2!["B`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R<VES=&5N="==*2D@
M>PH@("`@("`@("`@("`@("`@)&-O;FYE8W0@/2`G;V-I7V-O;FYE8W0G.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W0@
M/2`G;V-I7W!C;VYN96-T)SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A<F%M<ULG<&5R
M<VES=&5N="==*2D@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W0@/2`G3T-)
M3&]G;VXG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&-O;FYE8W0@/2`G3T-)4$QO9V]N)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^7V1B(#T@0"1C
M;VYN96-T*"1T:&ES+3Y?<&%R86US6R=U<V5R;F%M92==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VAO<W1S
M<&5C)UTI*2D@>PH@("`@("`@("`@("!(;W)D93HZ9F%T86PH4$5!4CHZ<F%I
M<V5%<G)O<B@G0V]U;&0@;F]T(&-O;FYE8W0@=&\@9&%T86)A<V4@9F]R(%-1
M3"!397-S:6]N2&%N9&QE<BXG*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U-E<W-I;VY(86YD;&5R
M+W!G<W%L+G!H<```````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(W-C4Q(#$P
M-3$U-#,T,3,W(#`R-#$T,``@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@4&]S=&=R95-13"!397-S:6]N
M($AA;F1L97(@9F]R(%!(4"`H;F%T:79E*2X*("H*("H@0V]P>7)I9VAT(#(P
M,#`M,C`P-B!*;VX@4&%R:7-E(#QJ;VY`8W-H+G)I="YE9'4^+B`@06QL(')I
M9VAT<R!R97-E<G9E9"X*("H*("H@(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@
M:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@
M*B`@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@
M=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J("!A<F4@;65T.@H@*B`@,2X@
M4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H
M92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@
M(#(N(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(@:6X@=&AE"B`J("`@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*@H@
M*B`@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@05542$]2($%.
M1"!#3TY44DE"551/4E,@8&!!4R!)4R<G($%.1`H@*B`@04Y9($584%)%4U,@
M3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@3$E-
M251%1"!43RP@5$A%"B`J("!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]3
M10H@*B`@05)%($1)4T-,04E-140N("!)3B!.3R!%5D5.5"!32$%,3"!42$4@
M05542$]2($]2($-/3E1224)55$]24R!"12!,24%"3$4*("H@($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4B!#3TY315%514Y424%,"B`J("!$04U!1T53("A)3D-,541)3D<L
M($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%54
M12!'3T]$4PH@*B`@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/
M4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI"B`J("!(3U=%
M5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(
M151(15(@24X@0T].5%)!0U0L(%-44DE#5`H@*B`@3$E!0DE,2519+"!/4B!4
M3U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)
M3D<@24X@04Y9(%=!60H@*B`@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1@H@
M*B`@4U5#2"!$04U!1T4N"B`J"B`J(%)E<75I<F5D('!A<F%M971E<G,Z/'!R
M93X*("H@("`G9&%T86)A<V4G("!4:&4@;F%M92!O9B!T:&4@9&%T86)A<V4N
M"B`J("`@)W!A<W-W;W)D)R`@5&AE('!A<W-W;W)D(&%S<V]C:6%T960@=VET
M:"`G=7-E<FYA;64G+@H@*B`@("=P<F]T;V-O;"<@(%1H92!C;VUM=6YI8V%T
M:6]N('!R;W1O8V]L("@G=&-P)RP@)W5N:7@G*2X*("H@("`G=7-E<FYA;64G
M("!4:&4@=7-E<FYA;64@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!D
M871A8F%S92X*("H*("H@4F5Q=6ER960@9F]R('-O;64@8V]N9FEG=7)A=&EO
M;G,@*&DN92X@)W!R;W1O8V]L)R`]("=T8W`G*3H\<')E/@H@*B`@("=H;W-T
M<W!E8R<@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@
M*B`@("=P;W)T)R`@("`@(%1H92!P;W)T(&]N('=H:6-H('1O(&-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E+CPO<')E/@H@*@H@*B!/<'1I;VYA;"!P87)A;65T
M97)S.CQP<F4^"B`J("`@)W!E<G-I<W1E;G0G("!5<V4@<&5R<VES=&5N="!$
M0B!C;VYN96-T:6]N<S\@*&)O;VQE86XI"B`J("`@("`@("`@("`@("`@("!$
M969A=6QT.B!.3PH@*B`@("=T86)L92<@("`@("`@5&AE(&YA;64@;V8@=&AE
M('-E<W-I;VYD871A('1A8FQE(&EN("=D871A8F%S92<N"B`J("`@("`@("`@
M("`@("`@("!$969A=6QT.B`G:&]R9&5?<V5S<VEO;FAA;F1L97(G/"]P<F4^
M"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H92!397-S:6]N2&%N
M9&QE<B!C86X@8F4@9F]U;F0@:6X*("H@:&]R9&4O<V-R:7!T<R]S<6PO:&]R
M9&5?<V5S<VEO;FAA;F1L97(N<&=S<6PN<W%L+@H@*@H@*B!#;VYT<FEB=71O
M<G,Z/'!R93X*("H@($IA<V]N($-A<FQS;VX@("`@("`@("`@(%)E='5R;B!A
M;B!E;7!T>2!S=')I;F<@;VX@9F%I;&5D(')E861S"B`J("!P871`<&-P<F]G
M<F%M;65R+F-O;2`@("!097)F;W)M('5P9&%T92!I;B!A('-I;F=L92!T<F%N
M<V%C=&EO;@H@*B`@2F]N871H86X@0W)O;7!T;VX@("`@("`@3&]C:R!R;W<@
M9F]R(&QI9F4@;V8@<V5S<VEO;CPO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]397-S:6]N2&%N9&QE<B]397-S:6]N2&%N9&QE<B]P9W-Q;"YP:'`L
M=B`Q+C$R+C$P+C$U(#(P,#8O,#,O,C,@,3@Z,#`Z,3<@:F%N($5X<"`D"B`J
M"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!C<V@N<FET+F5D=3X*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7U-E<W-I;VY(
M86YD;&5R"B`J+PIC;&%S<R!397-S:6]N2&%N9&QE<E]P9W-Q;"!E>'1E;F1S
M(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@
M=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@
M*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@("\J
M*@H@("`@("H@07)E('=E(&-O;FYE8W1E9"!T;R!T:&4@4U%,('-E<G9E<BX*
M("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?
M8V]N;F5C=&5D(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!#;&]S92!T:&4@
M4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@
M1&ES8V]N;F5C="!F<F]M(&1A=&%B87-E+B`J+PH@("`@("`@(&EF("@D=&AI
M<RT^7V-O;FYE8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;FYE8W1E
M9"`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@0'!G7V-L;W-E*"1T:&ES
M+3Y?9&(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296%D('1H92!D871A(&9O<B!A('!A<G1I8W5L
M87(@<V5S<VEO;B!I9&5N=&EF:65R(&9R;VT@=&AE"B`@("`@*B!397-S:6]N
M2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<V5S<VEO;B!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96%D*"1I9"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@
M=V4@:&%V92!A('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@
M("`@)'1H:7,M/E]C;VYN96-T*"D["@H@("`@("`@($!P9U]Q=65R>2@D=&AI
M<RT^7V1B+"`G0D5'24X[)RD["@H@("`@("`@("1T:6UE;W5T(#T@=&EM92@I
M("T@:6YI7V=E="@G<V5S<VEO;BYG8U]M87AL:69E=&EM92<I.PH@("`@("`@
M("1Q=65R>2`]('-P<FEN=&8H)U-%3$5#5"!S97-S:6]N7V1A=&$@1E)/32`E
M<R!72$5212`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("=S97-S:6]N
M7VED(#T@)7,@04Y$('-E<W-I;VY?;&%S=&UO9&EF:65D(#X]("5S("<@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@)T9/4B!54$1!5$4[)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G%U;W1E*"1I9"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="D["@H@("`@("`@("\J
M($QO9R!T:&4@<75E<GD@870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E
M<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=R96%D*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1R97-U;'0@/2!`<&=?<75E
M<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D9&%T82`]('!G7V9E
M=&-H7W)E<W5L="@D<F5S=6QT+"`P+"`G<V5S<VEO;E]D871A)RD["B`@("`@
M("`@<&=?9G)E95]R97-U;'0H)')E<W5L="D["@H@("`@("`@(')E='5R;B!P
M86-K*"=(*B<L("1D871A*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E
M('-E<W-I;VX@9&%T82!T;R!T:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@("`@("`@("`@(%1H
M92!S97-S:6]N(&ED96YT:69I97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M97-S:6]N7V1A=&$@(%1H92!S97-S:6]N(&1A=&$N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R
M=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&ED+"`D<V5S<VEO
M;E]D871A*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@
M=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^
M7V-O;FYE8W0H*3L*"B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@+2!I;FE?
M9V5T*"=S97-S:6]N+F=C7VUA>&QI9F5T:6UE)RD["B`@("`@("`@)'%U97)Y
M(#T@<W!R:6YT9B@G4T5,14-4('-E<W-I;VY?9&%T82!&4D]-("5S(%=(15)%
M("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@)W-E<W-I;VY?:60@/2`E
M<R!!3D0@<V5S<VEO;E]L87-T;6]D:69I960@/CT@)7,@)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G1D]2(%501$%412<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92@D:60I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1I;65O=70I.PH@("`@("`@("1R97-U;'0@/2!`
M<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("`D<F]W<R`]
M('!G7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@('!G7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH*("`@("`@("!I9B`H)')O=W,@/3T@,"D@>PH@("`@("`@
M("`@("`D<75E<GD@/2!S<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H<V5S<VEO
M;E]I9"P@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E<W-I
M;VY?;&%S=&UO9&EF:65D+"!S97-S:6]N7V1A=&$I("<@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=604Q515,@*"5S+"`E<RP@)7,I.R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G%U
M;W1E*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&EM92@I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92AB
M:6XR:&5X*"1S97-S:6]N7V1A=&$I*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G55!$051%("5S(%-%5"!S97-S
M:6]N7VQA<W1M;V1I9FEE9"`]("5S+"`G("X*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<V5S<VEO;E]D871A(#T@)7,@5TA%4D4@<V5S<VEO;E]I
M9"`]("5S.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&EM92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YQ=6]T92AB:6XR:&5X*"1S97-S:6]N7V1A=&$I*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<75O=&4H)&ED*2D["B`@("`@("`@
M?0H*("`@("`@("`O*B!,;V<@=&AE('%U97)Y(&%T(&$@1$5"54<@;&]G(&QE
M=F5L+B`J+PH@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-1
M3"!1=65R>2!B>2!397-S:6]N2&%N9&QE<E]P9W-Q;#HZ)R`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=W)I=&4H*3H@<75E<GD@/2`B
M)7,B)RP@)'%U97)Y*2P*("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)
M3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@)')E
M<W5L="`]($!P9U]Q=65R>2@D=&AI<RT^7V1B+"`D<75E<GDI.PH@("`@("`@
M(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G
M92@G17)R;W(@=W)I=&EN9R!S97-S:6]N(&1A=&$Z("<@+B!P9U]L87-T7V5R
M<F]R*"1T:&ES+3Y?9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@
M("`@("`@)')O=W,@/2!P9U]A9F9E8W1E9%]R;W=S*"1R97-U;'0I.PH@("`@
M("`@('!G7V9R965?<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!`<&=?<75E
M<GDH)'1H:7,M/E]D8BP@)T-/34U)5#LG*3L*"B`@("`@("`@:68@*"1R;W=S
M("$](#$I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R<F]R
M('=R:71I;F<@<V5S<VEO;B!D871A)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E<W1R;WD@=&AE
M(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@:6X@
M=&AE"B`@("`@*B!397-S:6]N2&%N9&QE<B!B86-K96YD+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&ED("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R
M+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C
M97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E
M<W1R;WDH)&ED*0H@("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E
M(&$@=F%L:60@9&%T86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI
M<RT^7V-O;FYE8W0H*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R
M>2X@*B\*("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E
M<R!72$5212!S97-S:6]N7VED(#T@)7,[)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==+"`D=&AI<RT^<75O=&4H
M)&ED*2D["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@870@82!$14)51R!L
M;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H<W!R:6YT
M9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W!G<W%L.CHG("X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D97-T<F]Y*"DZ('%U
M97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@
M/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*"B`@("`@("`@0'!G
M7W%U97)Y*"1T:&ES+3Y?9&(L("=#3TU-250[)RD["@H@("`@("`@(&EF("@A
M)')E<W5L="D@>PH@("`@("`@("`@("!P9U]F<F5E7W)E<W5L="@D<F5S=6QT
M*3L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T9A:6QE9"!T;R!D
M96QE=&4@<V5S<VEO;B`H:60@/2`G("X@)&ED("X@)RDG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?
M3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@('!G7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL
M96-T('-T86QE('-E<W-I;VYS(&9R;VT@=&AE(%-E<W-I;VY(86YD;&5R(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&UA>&QI9F5T
M:6UE("!4:&4@;6%X:6UU;2!A9V4@;V8@82!S97-S:6]N+@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=C*"1M87AL:69E=&EM
M92`](#,P,"D*("`@('L*("`@("`@("`O*B!-86ME('-U<F4@=V4@:&%V92!A
M('9A;&ED(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B`@("`@("`@)'1H:7,M
M/E]C;VYN96-T*"D["@H@("`@("`@("\J($)U:6QD('1H92!344P@<75E<GDN
M("HO"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@
M5TA%4D4@<V5S<VEO;E]L87-T;6]D:69I960@/"`E<R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=6]T92AT:6UE*"D@+2`D;6%X
M;&EF971I;64I*3L*"B`@("`@("`@+RH@3&]G('1H92!Q=65R>2!A="!A($1%
M0E5'(&QO9R!L979E;"X@*B\*("`@("`@("!(;W)D93HZ;&]G365S<V%G92AS
M<')I;G1F*"=344P@475E<GD@8GD@4V5S<VEO;DAA;F1L97)?<&=S<6PZ.B<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V=C*"DZ('%U
M97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@
M("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@("1R97-U;'0@
M/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U97)Y*3L*("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)T5R
M<F]R(&=A<F)A9V4@8V]L;&5C=&EN9R!O;&0@<V5S<VEO;G,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T524BD["B`@("`@("`@?0H*("`@("`@("!P9U]F<F5E7W)E<W5L
M="@D<F5S=6QT*3L*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($5S8V%P92!A('-T<FEN9R!F;W(@:6YS97)T:6]N(&EN
M=&\@=&AE(&1A=&%B87-E+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@=&\@
M<75O=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!Q=6]T
M960@<W1R:6YG+@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T92@D=F%L=64I
M"B`@("!["B`@("`@("`@<F5T=7)N("(G(B`N(&%D9'-L87-H97,H)'9A;'5E
M*2`N("(G(CL*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@
M=&AE('9A;&ED('-E<W-I;VX@:61E;G1I9FEE<G,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@02!L:7-T(&]F('9A;&ED('-E<W-I;VX@:61E;G1I
M9FEE<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-E<W-I;VY)1',H*0H@
M("`@>PH@("`@("`@("\J($UA:V4@<W5R92!W92!H879E(&$@=F%L:60@9&%T
M86)A<V4@8V]N;F5C=&EO;BX@*B\*("`@("`@("`D=&AI<RT^7V-O;FYE8W0H
M*3L*"B`@("`@("`@+RH@0G5I;&0@=&AE(%-13"!Q=65R>2X@*B\*("`@("`@
M("`D<75E<GD@/2`G4T5,14-4('-E<W-I;VY?:60@1E)/32`G("X@)'1H:7,M
M/E]P87)A;7-;)W1A8FQE)UT["@H@("`@("`@("\J($QO9R!T:&4@<75E<GD@
M870@82!$14)51R!L;V<@;&5V96PN("HO"B`@("`@("`@2&]R9&4Z.FQO9TUE
M<W-A9V4H<W!R:6YT9B@G4U%,(%%U97)Y(&)Y(%-E<W-I;VY(86YD;&5R7W!G
M<W%L.CHG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=G
M971397-S:6]N241S*"DZ('%U97)Y(#T@(B5S(B<L("1Q=65R>2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J
M+PH@("`@("`@("1R97-U;'0@/2!`<&=?<75E<GDH)'1H:7,M/E]D8BP@)'%U
M97)Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<&=?
M9G)E95]R97-U;'0H)')E<W5L="D["B`@("`@("`@("`@($AO<F1E.CIL;V=-
M97-S86=E*"=%<G)O<B!G971T:6YG('-E<W-I;VX@241S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H*("`@("`@("`D<V5S<VEO;G,@/2!A<G)A>2@I.PH@("`@("`@('=H:6QE
M("@D<F]W(#T@<&=?9F5T8VA?<F]W*"1R97-U;'0I*2!["B`@("`@("`@("`@
M("1S97-S:6]N<UM=(#T@)')O=ULP73L*("`@("`@("!]"@H@("`@("`@('!G
M7V9R965?<F5S=6QT*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@)'-E<W-I
M;VYS.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@;W!E;B!A
M(&-O;FYE8W1I;VX@=&\@=&AE(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,[(&5X:71S("A(;W)D
M93HZ9F%T86PH*2D@;VX@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?8V]N;F5C=&5D
M*2!["B`@("`@("`@("`@($AO<F1E.CIA<W-E<G1$<FEV97)#;VYF:6<H)'1H
M:7,M/E]P87)A;7,L("=S97-S:6]N:&%N9&QE<B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAO<W1S<&5C)RP@)W5S
M97)N86UE)RP@)V1A=&%B87-E)RP@)W!A<W-W;W)D)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-E<W-I;VX@:&%N9&QE<B!P
M9W-Q;"<I.PH*("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R86US
M6R=T86)L92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@/2`G:&]R9&5?<V5S<VEO;FAA;F1L97(G.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D8V]N;F5C="`](&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=P97)S:7-T96YT)UTI(#\*("`@("`@("`@("`@("`@("=P9U]C;VYN
M96-T)R`Z)W!G7W!C;VYN96-T)SL*"B`@("`@("`@("`@("1P87)A;7-T<B`]
M("<G.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W!R
M;W1O8V]L)UTI("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M<')O=&]C;VPG72`]/2`G=&-P)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M
M<W1R("X]("<@:&]S=#TG("X@)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UT[
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A;7-;)W!O
M<G0G72DI('L*("`@("`@("`@("`@("`@("`@("`D<&%R86US='(@+CT@)R!P
M;W)T/2<@+B`D=&AI<RT^7W!A<F%M<ULG<&]R="==.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1P87)A;7-T<B`N/2`G
M(&1B;F%M93TG("X@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@+@H@("`@
M("`@("`@("`@("`@)R!U<V5R/2<@+B`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA
M;64G72`N"B`@("`@("`@("`@("`@("`G('!A<W-W;W)D/2<@+B`D=&AI<RT^
M7W!A<F%M<ULG<&%S<W=O<F0G73L*"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]D8B`]($`D8V]N;F5C="@D<&%R86US='(I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T
M:&ES+3Y?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M2&]R9&4O4V5S<VEO;DAA;F1L97(O9&)M+G!H<```````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#8T,C,@,3`U,34T,S0Q,S<@,#(S-30V`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!397-S:6]N2&%N9&QE<CHZ(&EM<&QE;65N=&%T:6]N(&9O<B!$0DT@9FEL
M97,N"B`J($Y/5$4Z(%1H92!02%`@1$)-(&9U;F-T:6]N<R!A<F4@9&5P<F5C
M871E9"X*("H*("H@3F\@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N('!A<F%M
M971E<G,@;F5E9&5D+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]397-S:6]N
M2&%N9&QE<B]397-S:6]N2&%N9&QE<B]D8FTN<&AP+'8@,2XY+C$R+C<@,C`P
M-B\P,2\P,2`R,3HR.#HS-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P
M,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA
M9V4@2&]R9&5?4V5S<VEO;DAA;F1L97(*("HO"F-L87-S(%-E<W-I;VY(86YD
M;&5R7V1B;2!E>'1E;F1S(%-E<W-I;VY(86YD;&5R('L*"B`@("`O*BH*("`@
M("`J($]U<B!P;VEN=&5R('1O('1H92!$0DT@9FEL92P@:68@;W!E;BX*("`@
M("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7V1B
M;3L*"B`@("`O*BH*("`@("`J($]P96X@=&AE(%-E<W-I;VY(86YD;&5R(&)A
M8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V%V95]P871H
M("`@("!4:&4@<&%T:"!T;R!T:&4@<V5S<VEO;B!O8FIE8W0N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1S97-S:6]N7VYA;64@(%1H92!N86UE(&]F('1H92!S
M97-S:6]N+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O
M;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&]P96XH)'-A=F5?<&%T:"P@)'-E<W-I;VY?;F%M92D*("`@('L*("`@
M("`@("`D=&AI<RT^7V1B;2`]($!D8FUO<&5N*"(D<V%V95]P871H+R1S97-S
M:6]N7VYA;64B+"`G8R<I.PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1B;3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E('1H92!397-S:6]N2&%N9&QE
M<B!B86-K96YD+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!R971U<FX@0&1B;6-L;W-E
M*"1T:&ES+3Y?9&)M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E860@=&AE
M(&1A=&$@9F]R(&$@<&%R=&EC=6QA<B!S97-S:6]N(&ED96YT:69I97(@9G)O
M;2!T:&4*("`@("`J(%-E<W-I;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@(%1H92!S97-S:6]N(&ED96YT:69I
M97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!S97-S:6]N
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&ED*0H@("`@>PH@
M("`@("`@(&EF("@D9&%T82`](&1B;69E=&-H*"1T:&ES+3Y?9&)M+"`D:60I
M*2!["B`@("`@("`@("`@(')E='5R;B!B87-E-C1?9&5C;V1E*'-U8G-T<B@D
M9&%T82P@<W1R<&]S*"1D871A+"`G?"<I("L@,2DI.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!7<FET92!S97-S:6]N(&1A=&$@=&\@=&AE(%-E<W-I
M;VY(86YD;&5R(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D:60@("`@("`@("`@("!4:&4@<V5S<VEO;B!I9&5N=&EF:65R+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5S<VEO;E]D871A("!4:&4@<V5S<VEO;B!D
M871A+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S
M=6-C97-S+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('=R:71E*"1I9"P@)'-E<W-I;VY?9&%T82D*("`@('L*("`@("`@("!R971U
M<FX@0&1B;7)E<&QA8V4H)'1H:7,M/E]D8FTL("1I9"P@=&EM92@I("X@)WPG
M("X@8F%S938T7V5N8V]D92@D<V5S<VEO;E]D871A*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!$97-T<F]Y('1H92!D871A(&9O<B!A('!A<G1I8W5L87(@
M<V5S<VEO;B!I9&5N=&EF:65R(&EN('1H90H@("`@("H@4V5S<VEO;DAA;F1L
M97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`@
M5&AE('-E<W-I;VX@:61E;G1I9FEE<BX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;W1H97)W:7-E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D97-T<F]Y*"1I9"D*("`@('L*("`@("`@
M("!I9B`H(2A`9&)M9&5L971E*"1T:&ES+3Y?9&)M+"`D:60I*2D@>PH@("`@
M("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G1F%I;&5D('1O(&1E;&5T92!S
M97-S:6]N("AI9"`]("<@+B`D:60@+B`G*2<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!'87)B86=E(&-O;&QE8W0@<W1A;&4@<V5S<VEO;G,@9G)O;2!T
M:&4@4V5S<VEO;DAA;F1L97(@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D;6%X;&EF971I;64@(%1H92!M87AI;75M(&%G92!O9B!A
M('-E<W-I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E
M(&]N('-U8V-E<W,L(&9A;'-E(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V,H)&UA>&QI9F5T:6UE(#T@,S`P*0H@("`@>PH@("`@("`@("1E
M>'!I<F5D(#T@=&EM92@I("T@)&UA>&QI9F5T:6UE.PH@("`@("`@("1I9"`]
M(&1B;69I<G-T:V5Y*"1T:&ES+3Y?9&)M*3L*"B`@("`@("`@=VAI;&4@*"1I
M9"D@>PH@("`@("`@("`@("!I9B`H)&1A=&$@/2!D8FUF971C:"@D=&AI<RT^
M7V1B;2P@)&ED*2D@>PH@("`@("`@("`@("`@("`@)&%G92`]('-U8G-T<B@D
M=&UP+"`P+"!S=')P;W,H)&1A=&$L("=\)RDI.PH@("`@("`@("`@("`@("`@
M:68@*"1E>'!I<F5D(#X@)&%G92D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YD97-T<F]Y*"1I9"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1I9"`](&1B;6YE>'1K97DH)'1H:7,M/E]D
M8FTL("1I9"D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB
M+TAO<F1E+U!E<FUS+U5)+G!H<```````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#0U,C0S(#$P-3$U-#,T,3,W(#`R,30W,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@5&AE(%!E<FUS7U5).CH@8VQA<W,@<')O=FED97,@54D@;65T:&]D<R!F
M;W(@=&AE($AO<F1E('!E<FUI<W-I;VYS"B`J('-Y<W1E;2X*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO4&5R;7,O4&5R;7,O54DN<&AP+'8@,2XR-RXR+C@@
M,C`P-B\P,2\P,2`R,3HR.#HS,2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#$M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A
M8VMA9V4@2&]R9&5?4&5R;7,*("HO"F-L87-S(%!E<FUS7U5)('L*"B`@("`O
M*BH*("`@("`J(%1H92!097)M<R!O8FIE8W0@=V4G<F4@9&ES<&QA>6EN9R!5
M22!S='5F9B!F;W(N"B`@("`@*@H@("`@("H@0'9A<B!097)M<PH@("`@("HO
M"B`@("!V87(@)%]P97)M<SL*"B`@("`O*BH*("`@("`J(%1H92!(;W)D95]&
M;W)M(&]B:F5C="!T:&%T('=I;&P@8F4@=7-E9"!F;W(@9&ES<&QA>6EN9R!T
M:&4@961I="!F;W)M+@H@("`@("H*("`@("`J($!V87(@2&]R9&5?1F]R;0H@
M("`@("HO"B`@("!V87(@)%]F;W)M(#T@;G5L;#L*"B`@("`O*BH*("`@("`J
M(%1H92!687)I86)L97,@;V)J96-T('5S960@:6X@2&]R9&5?1F]R;2X*("`@
M("`J"B`@("`@*B!`=F%R(%9A<FEA8FQE<PH@("`@("HO"B`@("!V87(@)%]V
M87)S(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!P97)M:7-S:6]N('1Y
M<&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?='EP92`]("=M871R:7@G.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(N"B`@("`@*@H@("`@("H@0'!A<F%M(%!E<FUS("1P97)M<R`@5&AE(%!E
M<FUS(&]B:F5C="!T;R!D:7-P;&%Y(%5)('-T=69F(&9O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@4&5R;7-?54DH)B1P97)M<RD*("`@('L*("`@("`@("`D
M=&AI<RT^7W!E<FUS(#T@)B1P97)M<SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;B!A($AO<F1E7U1R964@<F5P<F5S96YT871I;VX@;V8@=&AE('!E
M<FUI<W-I;VYS('1R964N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!H=&UL('-H;W=I;F<@=&AE('!E<FUI<W-I;VYS(&%S(&$@2&]R9&5?
M5')E92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N9&5R5')E92@D8W5R<F5N
M="`]($1!5$%44D5%7U)/3U0I"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I
M<W1R>3L*"B`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]4<F5E+G!H<"<[
M"@H@("`@("`@("\J($=E="!T:&4@<&5R;7,@=')E92X@*B\*("`@("`@("`D
M;F]D97,@/2`F)'1H:7,M/E]P97)M<RT^9V5T5')E92@I.PH*("`@("`@("`D
M:6-O;F1I<B`](&%R<F%Y*"=I8V]N9&ER)R`]/B`D1TQ/0D%,4ULG<F5G:7-T
M<GDG72T^9V5T26UA9V5$:7(H*2D["B`@("`@("`@)'!E<FUS7VYO9&4@/2`D
M:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G<&5R;7,N<&YG)RD["B`@("`@
M("`@)&%D9"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O
M861D8VAI;&0N<&AP)RD["B`@("`@("`@)&5D:70@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)V%D;6EN+W!E<FUS+V5D:70N<&AP)RD["B`@("`@("`@)&1E
M;&5T92`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O9&5L
M971E+G!H<"<I.PH@("`@("`@("1E9&ET7VEM9R`]($AO<F1E.CII;6<H)V5D
M:70N<&YG)RP@7R@B161I="!097)M:7-S:6]N(BDI.PH@("`@("`@("1D96QE
M=&5?:6UG(#T@2&]R9&4Z.FEM9R@G9&5L971E+G!N9R<L(%\H(D1E;&5T92!0
M97)M:7-S:6]N(BDI.PH*("`@("`@("`O*B!3970@=7`@=&AE('1R964N("HO
M"B`@("`@("`@)'1R964@/2`F2&]R9&5?5')E93HZ<VEN9VQE=&]N*"=P97)M
M<U]U:2<L("=J879A<V-R:7!T)RD["B`@("`@("`@)'1R964M/G-E=$]P=&EO
M;BAA<G)A>2@G86QT97)N871E)R`]/B!T<G5E+"`G:&ED94AE861E<G,G(#T^
M('1R=64I*3L*("`@("`@("`D=')E92T^<V5T2&5A9&5R*&%R<F%Y*&%R<F%Y
M*"=W:61T:"<@/3X@)S4P)2<I*2D["@H@("`@("`@(&9O<F5A8V@@*"1N;V1E
M<R!A<R`D<&5R;5]I9"`]/B`D;F]D92D@>PH@("`@("`@("`@("`D;F]D95]C
M;&%S<R`]("@D8W5R<F5N="`]/2`D<&5R;5]I9"D@/R!A<G)A>2@G8VQA<W,G
M(#T^("=S96QE8W1E9"<I(#H@87)R87DH*3L*("`@("`@("`@("`@:68@*"1P
M97)M7VED(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@("`@("1A
M9&1?:6UG(#T@2&]R9&4Z.FEM9R@G<&5R;7,N<&YG)RP@7R@B061D($YE=R!0
M97)M:7-S:6]N(BDI.PH@("`@("`@("`@("`@("`@)&%D9%]L:6YK(#T@2&]R
M9&4Z.FQI;FLH571I;#HZ861D4&%R86UE=&5R*"1A9&0L("=P97)M7VED)RP@
M)'!E<FU?:60I+"!?*")!9&0@3F5W(%!E<FUI<W-I;VXB*2D@+B`D861D7VEM
M9R`N("<\+V$^)SL*("`@("`@("`@("`@("`@("1B87-E7VYO9&5?<&%R86US
M(#T@)&EC;VYD:7(@*R!A<G)A>2@G:6-O;B<@/3X@)V%D;6EN:7-T<F%T:6]N
M+G!N9R<I.PH*("`@("`@("`@("`@("`@("1T<F5E+3YA9&1.;V1E*"1P97)M
M7VED+"!N=6QL+"!?*")!;&P@4&5R;6ES<VEO;G,B*2P@,"P@=')U92P@)&)A
M<V5?;F]D95]P87)A;7,@*R`D;F]D95]C;&%S<RP@87)R87DH)&%D9%]L:6YK
M*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<&%R
M96YT7VED(#T@)'1H:7,M/E]P97)M<RT^7V1A=&%T<F5E+3YG971087)E;G0H
M)&YO9&4I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)'!A<F5N=%]I9"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@($AO<F1E.CIF
M871A;"@D<&%R96YT7VED+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1A9&1?:6UG(#T@2&]R9&4Z
M.FEM9R@G<&5R;7,N<&YG)RP@7R@B061D($-H:6QD(%!E<FUI<W-I;VXB*2D[
M"B`@("`@("`@("`@("`@("`D861D7VQI;FL@/2!(;W)D93HZ;&EN:RA5=&EL
M.CIA9&1087)A;65T97(H)&%D9"P@)W!E<FU?:60G+"`D<&5R;5]I9"DL(%\H
M(D%D9"!#:&EL9"!097)M:7-S:6]N(BDI("X@)&%D9%]I;6<@+B`G/"]A/B<[
M"B`@("`@("`@("`@("`@("`D961I=%]L:6YK(#T@2&]R9&4Z.FQI;FLH571I
M;#HZ861D4&%R86UE=&5R*"1E9&ET+"`G<&5R;5]I9"<L("1P97)M7VED*2P@
M7R@B161I="!097)M:7-S:6]N(BDI("X@)&5D:71?:6UG("X@)SPO83XG.PH@
M("`@("`@("`@("`@("`@)&1E;&5T95]L:6YK(#T@2&]R9&4Z.FQI;FLH571I
M;#HZ861D4&%R86UE=&5R*"1D96QE=&4L("=P97)M7VED)RP@)'!E<FU?:60I
M+"!?*")$96QE=&4@4&5R;6ES<VEO;B(I*2`N("1D96QE=&5?:6UG("X@)SPO
M83XG.PH@("`@("`@("`@("`@("`@)'!E<FUS7V5X=')A(#T@87)R87DH)&%D
M9%]L:6YK+"`D961I=%]L:6YK+"`D9&5L971E7VQI;FLI.PH@("`@("`@("`@
M("`@("`@)&YA;64@/2`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D;F]D92D[
M"@H@("`@("`@("`@("`@("`@)'1R964M/F%D9$YO9&4H)'!E<FU?:60L("1P
M87)E;G1?:60L("1N86UE+"!S=6)S=')?8V]U;G0H)&YO9&4L("<Z)RD@*R`Q
M+"!F86QS92P@)'!E<FUS7VYO9&4@*R`D;F]D95]C;&%S<RP@)'!E<FUS7V5X
M=')A*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1R964M
M/G-O<G0H)VQA8F5L)RD["@H@("`@("`@(')E='5R;B`D=')E92T^<F5N9&5R
M5')E92@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T(&%N(&5X:7-T:6YG
M(&9O<FT@;V)J96-T('1O('5S92!F;W(@=&AE(&5D:70@9F]R;2X*("`@("`J
M"B`@("`@*B!`<&%R86T@2&]R9&5?1F]R;2`D9F]R;2`@06X@97AI<W1I;F<@
M2&]R9&5?1F]R;2!O8FIE8W0@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971&;W)M*"8D9F]R;2D*("`@('L*("`@("`@("`D=&AI<RT^7V9O<FT@
M/2`F)&9O<FT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@86X@97AI<W1I
M;F<@=F%R<R!O8FIE8W0@=&\@=7-E(&9O<B!T:&4@961I="!F;W)M+@H@("`@
M("H*("`@("`J($!P87)A;2!687)I86)L97,@)'9A<G,@($%N(&5X:7-T:6YG
M(%9A<FEA8FQE<R!O8FIE8W0@=&\@=7-E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971687)S*"8D=F%R<RD*("`@('L*("`@("`@("`D=&AI<RT^7W9A<G,@
M/2`F)'9A<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!F;W)M
M('1O(&%D9"!A('!E<FUI<W-I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(%!E
M<FUS("1P97)M:7-S:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)C95]C
M:&]I8V4@($EF('1H92!P97)M:7-S:6]N('1O(&)E(&%D9&5D(&-A;B!B92!O
M;F4@;V8*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;6%N
M>2P@<V5T=&EN9R!T:&ES('=I;&P@9F]R8V4@=&AE(&-H;VEC92!T;PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O;F4@<&%R=&EC=6QA
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T=7!!9&1&;W)M*"1P97)M:7-S
M:6]N+"`D9F]R8V5?8VAO:6-E(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)
M;FET:6%L:7-E(&9O<FT@:68@<F5Q=6ER960N("HO"B`@("`@("`@)'1H:7,M
M/E]F;W)M26YI="@I.PH*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=%1I=&QE
M*'-P<FEN=&8H7R@B061D(&$@8VAI;&0@<&5R;6ES<VEO;B!T;R!<(B5S7"(B
M*2P@)'1H:7,M/E]P97)M<RT^9V5T5&ET;&4H)'!E<FUI<W-I;VXM/F=E=$YA
M;64H*2DI*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=$)U='1O;G,H7R@B
M061D(BDL('1R=64I.PH@("`@("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=P97)M
M7VED)RP@)'1H:7,M/E]P97)M<RT^9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S
M:6]N*2D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P
M97)M7VED)RP@)W1E>'0G+"!F86QS92D["@H@("`@("`@("\J(%-E="!U<"!T
M:&4@86-T=6%L(&-H:6QD(&%D9&EN9R!F:65L9"X@*B\*("`@("`@("`D8VAI
M;&1?<&5R;7,@/2`D=&AI<RT^7W!E<FUS+3YG971!=F%I;&%B;&4H)'!E<FUI
M<W-I;VXM/F=E=$YA;64H*2D["B`@("`@("`@:68@*"1C:&EL9%]P97)M<R`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@+RH@1F%L<V4L('-O(&YO(&-H:6QD
M<R!A<F4@=&\@8F4@861D960@8F5L;W<@=&AI<R!L979E;"X@*B\*("`@("`@
M("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92A?*")097)M:7-S:6]N
M(BDL("=C:&EL9"<L("=I;G9A;&ED)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R
M<F%Y*%\H(DYO(&-H:6QD<F5N(&-A;B!B92!A9&1E9"!T;R!T:&ES('!E<FUI
M<W-I;VXN(BDI*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&-H:6QD
M7W!E<FUS*2D@>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1F;W)C95]C:&]I
M8V4I*2!["B`@("`@("`@("`@("`@("`O*B!#:&]I8V4@87)R87D@879A:6QA
M8FQE+"!B=70@8VAO:6-E(&)E:6YG(&9O<F-E9"X@*B\*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?=F%R<RT^<V5T*"=C:&EL9"<L("1F;W)C95]C:&]I8V4I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92A?
M*")097)M:7-S:6]N<R(I+"`G8VAI;&0G+"`G96YU;2<L('1R=64L('1R=64L
M(&YU;&PL(&%R<F%Y*"1C:&EL9%]P97)M<RDI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@+RH@0VAO:6-E(&%R<F%Y(&%V86EL86)L
M92P@<V\@<V5T('5P(&5N=6T@9FEE;&0N("HO"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*%\H(E!E<FUI<W-I;VYS(BDL("=C
M:&EL9"<L("=E;G5M)RP@=')U92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C:&EL
M9%]P97)M<RDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@86YY(&%D9"!F;W)M
M(&EN<'5T+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($5I=&AE<B!F
M86QS92!I9B!T:&4@9F]R;2!D;V5S(&YO="!V86QI9&%T92!C;W)R96-T;'D@
M;W(*("`@("`J("`@("`@("`@("`@("`@(&%N(&%R<F%Y('=I=&@@86QL('1H
M92!F;W)M('9A;'5E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5!
M9&1&;W)M*"8D:6YF;RD*("`@('L*("`@("`@("!I9B`H(21T:&ES+3Y?9F]R
M;2T^=F%L:61A=&4H)'1H:7,M/E]V87)S*2D@>PH@("`@("`@("`@("!R971U
M<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V9O<FTM/F=E
M=$EN9F\H)'1H:7,M/E]V87)S+"`D:6YF;RD["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!P97)M:7-S:6]N
M(&5D:71I;F<@9F]R;2X*("`@("`J"B`@("`@*B!`<&%R86T@1&%T851R965/
M8FIE8W1?4&5R;6ES<VEO;B`D<&5R;6ES<VEO;@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971U<$5D:71&;W)M*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("\J($EN:71I86QI<V4@9F]R
M;2!I9B!R97%U:7)E9"X@*B\*("`@("`@("`D=&AI<RT^7V9O<FU);FET*"D[
M"@H@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N<RA?*")5<&1A=&4B
M*2P@=')U92D["B`@("`@("`@)'!E<FU?:60@/2`D=&AI<RT^7W!E<FUS+3YG
M971097)M:7-S:6]N260H)'!E<FUI<W-I;VXI.PH@("`@("`@("1T:&ES+3Y?
M9F]R;2T^861D2&ED9&5N*"<G+"`G<&5R;5]I9"<L("=T97AT)RP@9F%L<V4I
M.PH*("`@("`@("`O*B!'970@<&5R;6ES<VEO;B!C;VYF:6=U<F%T:6]N+B`J
M+PH@("`@("`@("1T:&ES+3Y?='EP92`]("1P97)M:7-S:6]N+3YG970H)W1Y
M<&4G*3L*("`@("`@("`D<&%R86US(#T@)'!E<FUI<W-I;VXM/F=E="@G<&%R
M86US)RD["@H@("`@("`@("\J($1E9F%U;'0@<&5R;6ES<VEO;G,N("HO"B`@
M("`@("`@)'!E<FU?=F%L(#T@)'!E<FUI<W-I;VXM/F=E=$1E9F%U;'1097)M
M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO;B@G
M9&5F875L="<L(%\H(D%L;"!!=71H96YT:6-A=&5D(%5S97)S(BDL($AO<F1E
M.CII;6<H)W!E<FUS+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G
M941I<B@G:&]R9&4G*2DL(&9A;'-E*3L*"B`@("`@("`@+RH@5V4@35535"!U
M<V4@)V1E9FQT)R!F;W(@=&AE('9A<FEA8FQE(&YA;64@8F5C875S92`G9&5F
M875L="<@:7,@80H@("`@("`@("`J(')E<V5R=F5D('=O<F0@:6X@2F%V85-C
M<FEP="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M871R:7@G
M*2!["B`@("`@("`@("`@("\J(%-E="!U<"!T:&4@8V]L=6UN<R!F;W(@=&AE
M('!E<FUI<W-I;VYS(&UA=')I>"X@*B\*("`@("`@("`@("`@)&-O;',@/2!0
M97)M<SHZ9V5T4&5R;7-!<G)A>2@I.PH*("`@("`@("`@("`@+RH@1&5F:6YE
M(&$@<VEN9VQE(&UA=')I>"!R;W<@9F]R(&1E9F%U;'0@<&5R;7,N("HO"B`@
M("`@("`@("`@("1M871R:7@@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T
M<FEX6S!=(#T@4&5R;7,Z.FEN=&5G97)4;T%R<F%Y*"1P97)M7W9A;"D["B`@
M("`@("`@("`@("1T:&ES+3Y?9F]R;2T^861D5F%R:6%B;&4H)R<L("=D969L
M="<L("=M871R:7@G+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS
M+"!A<G)A>2@P(#T^("<G*2P@)&UA=')I>"DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1V87(@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L
M92@G)RP@)V1E9FQT)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@9F%L<V4L(&YU
M;&PL("1P87)A;7,I.PH@("`@("`@("`@("`D=F%R+3YS971$969A=6QT*"1P
M97)M7W9A;"D["B`@("`@("`@?0H*("`@("`@("`O*B!'=65S="!P97)M:7-S
M:6]N<RX@*B\*("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T
M1W5E<W1097)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T
M4V5C=&EO;B@G9W5E<W0G+"!?*")'=65S="!097)M:7-S:6]N<R(I+"`G)RP@
M9F%L<V4I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]("=M871R:7@G
M*2!["B`@("`@("`@("`@("\J($1E9FEN92!A('-I;F=L92!M871R:7@@<F]W
M(&9O<B!G=65S="!P97)M<RX@*B\*("`@("`@("`@("`@)&UA=')I>"`](&%R
M<F%Y*"D["B`@("`@("`@("`@("1M871R:7A;,%T@/2!097)M<SHZ:6YT96=E
M<E1O07)R87DH)'!E<FU?=F%L*3L*("`@("`@("`@("`@)'1H:7,M/E]F;W)M
M+3YA9&1687)I86)L92@G)RP@)V=U97-T)RP@)VUA=')I>"<L(&9A;'-E+"!F
M86QS92P@;G5L;"P@87)R87DH)&-O;',L(&%R<F%Y*#`@/3X@)R<I+"`D;6%T
M<FEX*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'9A<B`]("8D
M=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G9W5E<W0G+"`D=&AI<RT^
M7W1Y<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@
M("`@("1V87(M/G-E=$1E9F%U;'0H)'!E<FU?=F%L*3L*("`@("`@("!]"@H@
M("`@("`@("\J($]B:F5C="!C<F5A=&]R('!E<FUI<W-I;VYS+B`J+PH@("`@
M("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG971#<F5A=&]R4&5R;6ES
M<VEO;G,H*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=%-E8W1I;VXH)V-R
M96%T;W(G+"!?*")#<F5A=&]R(%!E<FUI<W-I;VYS(BDL($AO<F1E.CII;6<H
M)W5S97(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H
M;W)D92<I*2P@9F%L<V4I.PH*("`@("`@("!I9B`H)'1H:7,M/E]T>7!E(#T]
M("=M871R:7@G*2!["B`@("`@("`@("`@("\J($1E9FEN92!A('-I;F=L92!M
M871R:7@@<F]W(&9O<B!C<F5A=&]R('!E<FUS+B`J+PH@("`@("`@("`@("`D
M;6%T<FEX(#T@87)R87DH*3L*("`@("`@("`@("`@)&UA=')I>%LP72`](%!E
M<FUS.CII;G1E9V5R5&]!<G)A>2@D<&5R;5]V86PI.PH@("`@("`@("`@("`D
M=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G8W)E871O<B<L("=M871R
M:7@G+"!F86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"!A<G)A>2@P
M(#T^("<G*2P@)&UA=')I>"DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1V87(@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@)V-R
M96%T;W(G+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS92P@;G5L;"P@)'!A
M<F%M<RD["B`@("`@("`@("`@("1V87(M/G-E=$1E9F%U;'0H)'!E<FU?=F%L
M*3L*("`@("`@("!]"@H@("`@("`@("\J(%5S97)S('!E<FUI<W-I;VYS+B`J
M+PH@("`@("`@("1P97)M7W9A;"`]("1P97)M:7-S:6]N+3YG9715<V5R4&5R
M;6ES<VEO;G,H*3L*("`@("`@("`D=&AI<RT^7V9O<FTM/G-E=%-E8W1I;VXH
M)W5S97)S)RP@7R@B26YD:79I9'5A;"!5<V5R<R(I+"!(;W)D93HZ:6UG*"=U
M<V5R+G!N9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R
M9&4G*2DL(&9A;'-E*3L*("`@("`@("`D875T:"`]("9!=71H.CIS:6YG;&5T
M;VXH)$=,3T)!3%-;)V-O;F8G75LG875T:"==6R=D<FEV97(G72D["B`@("`@
M("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T)RDI('L*("`@("`@
M("`@("`@+RH@5&AE(&%U=&@@9')I=F5R(&AA<R!L:7-T(&-A<&%B:6QI=&EE
M<R!S;R!S970@=7`@86X@87)R87D@=VAI8V@*("`@("`@("`@("`@("H@=&AE
M(&UA=')I>"!F:65L9"!T>7!E('=I;&P@<F5C;V=N:7-E('1O('-E="!U<"!A
M;B!E;G5M(&)O>"!F;W(*("`@("`@("`@("`@("H@861D:6YG(&YE=R!U<V5R
M<R!T;R!T:&4@<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D
M;F5W7W5S97)S(#T@87)R87DH*3L*("`@("`@("`@("`@)'5S97)?;&ES="`]
M("1A=71H+3YL:7-T57-E<G,H*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5S
M97)?;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&YE
M=U]U<V5R<R`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!S;W)T*"1U<V5R7VQI<W0I.PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'5S97)?;&ES="!A<R`D=7-E<BD@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'!E<FU?=F%L6R1U<V5R72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&YE=U]U<V5R<ULD=7-E<ET@/2`D=7-E<CL*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.;R!L:7-T
M(&-A<&%B:6QI=&EE<RP@<V5T=&EN9R!T;R!T<G5E('-O('1H870@=&AE(&UA
M=')I>"!F:65L9`H@("`@("`@("`@("`@*B!T>7!E('=I;&P@;V9F97(@82!T
M97AT(&EN<'5T(&)O>"!F;W(@861D:6YG(&YE=R!U<V5R<RX@*B\*("`@("`@
M("`@("`@)&YE=U]U<V5R<R`]('1R=64["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/E]T>7!E(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("\J
M(%-E="!U<"!T:&4@;6%T<FEX(&%R<F%Y+"!B<F5A:VEN9R!U<"!E86-H('!E
M<FUI<W-I;VX@:6YT96=E<@H@("`@("`@("`@("`@*B!I;G1O(&%N(&%R<F%Y
M+B`@5&AE(&ME>7,@;V8@=&AI<R!A<G)A>2!W:6QL(&)E('1H92!R;W<*("`@
M("`@("`@("`@("H@:&5A9&5R<RX@*B\*("`@("`@("`@("`@)')O=W,@/2!A
M<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX(#T@87)R87DH*3L*("`@("`@
M("`@("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1U7VED(#T^("1U7W!E<FUS
M*2!["B`@("`@("`@("`@("`@("`D<F]W<ULD=5]I9%T@/2`D=5]I9#L*("`@
M("`@("`@("`@("`@("1M871R:7A;)'5?:61=(#T@4&5R;7,Z.FEN=&5G97)4
M;T%R<F%Y*"1U7W!E<FUS*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7V9O<FTM/F%D9%9A<FEA8FQE*"<G+"`G=2<L("=M871R:7@G+"!F
M86QS92P@9F%L<V4L(&YU;&PL(&%R<F%Y*"1C;VQS+"`D<F]W<RP@)&UA=')I
M>"P@)&YE=U]U<V5R<RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EF("@D;F5W7W5S97)S*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)&YE=U]U<V5R<RDI('L*("`@("`@("`@("`@("`@("`@("`D=5]N(#T@
M571I;#HZ9V5T1F]R;41A=&$H)W5?;B<I.PH@("`@("`@("`@("`@("`@("`@
M("1U7VX@/2!E;7!T>2@D=5]N6R=U)UTI(#\@;G5L;"`Z("1U7VY;)W4G73L*
M("`@("`@("`@("`@("`@("`@("`D=7-E<E]H=&UL(#T@)SQS96QE8W0@;F%M
M93TB=5]N6W5=(CX\;W!T:6]N/B<@+B!?*"(M+2!S96QE8W0@+2TB*2`N("<\
M+V]P=&EO;CXG.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1N97=?
M=7-E<G,@87,@)&YE=U]U<V5R*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1U<V5R7VAT;6P@+CT@)SQO<'1I;VX@=F%L=64](B<@+B`D;F5W7W5S97(@
M+B`G(B<["B`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@+CT@
M)'5?;B`]/2`D;F5W7W5S97(@/R`G('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@
M)R<["B`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@+CT@)SXG
M("X@:'1M;'-P96-I86QC:&%R<R@D;F5W7W5S97(I("X@)SPO;W!T:6]N/B<[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1U
M<V5R7VAT;6P@+CT@)SPO<V5L96-T/B<["B`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("1U<V5R7VAT;6P@/2`G/&EN<'5T
M('1Y<&4](G1E>'0B(&YA;64](G5?;EMU72(@+SXG.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L
M92@D=7-E<E]H=&UL+"`G=5]N6W9=)RP@)'1H:7,M/E]T>7!E+"!F86QS92P@
M9F%L<V4L(&YU;&PL("1P87)A;7,I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1P97)M7W9A;"!A<R`D=5]I9"`]/B`D=5]P97)M<RD@
M>PH@("`@("`@("`@("`@("`@)'9A<B`]("8D=&AI<RT^7V9O<FTM/F%D9%9A
M<FEA8FQE*"1U7VED+"`G=5]V6R<@+B`D=5]I9"`N("==)RP@)'1H:7,M/E]T
M>7!E+"!F86QS92P@9F%L<V4L(&YU;&PL("1P87)A;7,I.PH@("`@("`@("`@
M("`@("`@)'9A<BT^<V5T1&5F875L="@D=5]P97)M<RD["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\J($=R;W5P<R!P97)M:7-S:6]N<RX@
M*B\*("`@("`@("`D<&5R;5]V86P@/2`D<&5R;6ES<VEO;BT^9V5T1W)O=7!0
M97)M:7-S:6]N<R@I.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T4V5C=&EO
M;B@G9W)O=7!S)RP@7R@B1W)O=7!S(BDL($AO<F1E.CII;6<H)V=R;W5P+G!N
M9R<L("<G+"`G)RP@)')E9VES=')Y+3YG971);6%G941I<B@G:&]R9&4G*2DL
M(&9A;'-E*3L*("`@("`@("!R97%U:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H
M<"<["B`@("`@("`@)&=R;W5P<R`]("9'<F]U<#HZ<VEN9VQE=&]N*"D["B`@
M("`@("`@)&=R;W5P7VQI<W0@/2`D9W)O=7!S+3YL:7-T1W)O=7!S*"D["B`@
M("`@("`@:68@*"%E;7!T>2@D9W)O=7!?;&ES="DI('L*("`@("`@("`@("`@
M+RH@5&AE<F4@:7,@86X@879A:6QA8FQE(&QI<W0@;V8@9W)O=7!S('-O('-E
M="!U<"!A;B!A<G)A>2!W:&EC:`H@("`@("`@("`@("`@*B!T:&4@;6%T<FEX
M(&9I96QD('1Y<&4@=VEL;"!R96-O9VYI<V4@=&\@<V5T('5P(&%N(&5N=6T@
M8F]X(&9O<@H@("`@("`@("`@("`@*B!A9&1I;F<@;F5W(&=R;W5P<R!T;R!T
M:&4@<&5R;6ES<VEO;G,@;6%T<FEX+B`J+PH@("`@("`@("`@("`D;F5W7V=R
M;W5P<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A8V@@*"1G<F]U<%]L
M:7-T(&%S("1G<F]U<$ED(#T^("1G<F]U<"D@>PH@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D<&5R;5]V86Q;)&=R;W5P261=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1N97=?9W)O=7!S6R1G<F]U<$ED72`]("1G<F]U<#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\J($1O(&YO="!O9F9E<B!A('1E>'0@8F]X('1O(&%D
M9"!N97<@9W)O=7!S+B`J+PH@("`@("`@("`@("`D;F5W7V=R;W5P<R`](&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?='EP92`]/2`G
M;6%T<FEX)RD@>PH@("`@("`@("`@("`O*B!3970@=7`@=&AE(&UA=')I>"!A
M<G)A>2P@8G)E86L@=7`@96%C:"!P97)M:7-S:6]N(&EN=&5G97(@:6YT;PH@
M("`@("`@("`@("`@*B!A;B!A<G)A>2X@5&AE(&ME>7,@;V8@=&AI<R!A<G)A
M>2!W:6QL(&)E('1H92!R;W<@:&5A9&5R<RX@*B\*("`@("`@("`@("`@)')O
M=W,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6%T<FEX(#T@87)R87DH*3L*
M("`@("`@("`@("`@9F]R96%C:"`H)'!E<FU?=F%L(&%S("1G7VED(#T^("1G
M7W!E<FUS*2!["B`@("`@("`@("`@("`@("`D<F]W<ULD9U]I9%T@/2!I<W-E
M="@D9W)O=7!?;&ES=%LD9U]I9%TI(#\@)&=R;W5P7VQI<W1;)&=?:61=(#H@
M)&=?:60["B`@("`@("`@("`@("`@("`D;6%T<FEX6R1G7VED72`](%!E<FUS
M.CII;G1E9V5R5&]!<G)A>2@D9U]P97)M<RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@G)RP@)V<G+"`G
M;6%T<FEX)RP@9F%L<V4L(&9A;'-E+"!N=6QL+"!A<G)A>2@D8V]L<RP@)')O
M=W,L("1M871R:7@L("1N97=?9W)O=7!S*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@:68@*"1N97=?9W)O=7!S*2!["B`@("`@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&YE=U]G<F]U<',I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&=?;B`](%5T:6PZ.F=E=$9O<FU$871A*"=G7VXG*3L*("`@("`@
M("`@("`@("`@("`@("`D9U]N(#T@96UP='DH)&=?;ELG9R==*2`_(&YU;&P@
M.B`D9U]N6R=G)UT["B`@("`@("`@("`@("`@("`@("`@)&=R;W5P7VAT;6P@
M/2`G/'-E;&5C="!N86UE/2)G7VY;9UTB/CQO<'1I;VX^)R`N(%\H(BTM('-E
M;&5C="`M+2(I("X@)SPO;W!T:6]N/B<["B`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&YE=U]G<F]U<',@87,@)&=R;W5P260@/3X@)&=R;W5P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%]H=&UL("X]("<\;W!T
M:6]N('9A;'5E/2(G("X@)&=R;W5P260@+B`G(B<["B`@("`@("`@("`@("`@
M("`@("`@("`@("1G<F]U<%]H=&UL("X]("1G7VX@/3T@)&=R;W5P260@/R`G
M('-E;&5C=&5D/2)S96QE8W1E9"(G(#H@)R<["B`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<%]H=&UL("X]("<^)R`N(&AT;6QS<&5C:6%L8VAA<G,H
M)&=R;W5P*2`N("<\+V]P=&EO;CXG.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D9W)O=7!?:'1M;"`N/2`G/"]S96QE8W0^
M)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)&=R;W5P7VAT;6P@/2`G/&EN<'5T('1Y<&4](G1E>'0B(&YA;64](F=?
M;EMG72(@+SXG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92@D9W)O=7!?:'1M;"P@)V=?;EMV
M72<L("1T:&ES+3Y?='EP92P@9F%L<V4L(&9A;'-E+"!N=6QL+"`D<&%R86US
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V
M86P@87,@)&=?:60@/3X@)&=?<&5R;7,I('L*("`@("`@("`@("`@("`@("1V
M87(@/2`F)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92AI<W-E="@D9W)O=7!?
M;&ES=%LD9U]I9%TI(#\@)&=R;W5P7VQI<W1;)&=?:61=(#H@)&=?:60L("=G
M7W9;)R`N("1G7VED("X@)UTG+"`D=&AI<RT^7W1Y<&4L(&9A;'-E+"!F86QS
M92P@;G5L;"P@)'!A<F%M<RD["B`@("`@("`@("`@("`@("`D=F%R+3YS971$
M969A=6QT*"1G7W!E<FUS*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+RH@4V5T(&9O<FT@=&ET;&4N("HO"B`@("`@("`@)'1H:7,M/E]F
M;W)M+3YS9714:71L92AS<')I;G1F*%\H(D5D:70@<&5R;6ES<VEO;G,@9F]R
M(%PB)7-<(B(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO
M;BT^9V5T3F%M92@I*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I
M;VX@=&\@=F%L:61A=&4@86YY(&5D:70@9F]R;2!I;G!U="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@9F%L<V4@:68@=&AE(&9O<FT@
M9&]E<R!N;W0@=F%L:61A=&4@8V]R<F5C=&QY(&]R"B`@("`@*B`@("`@("`@
M("`@("`@("!A;B!A<G)A>2!W:71H(&%L;"!T:&4@9F]R;2!V86QU97,N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('9A;&ED871E161I=$9O<FTH)B1I;F9O*0H@
M("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]F;W)M+3YV86QI9&%T92@D=&AI
M<RT^7W9A<G,I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?9F]R;2T^9V5T26YF;R@D=&AI<RT^7W9A
M<G,L("1I;F9O*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?='EP92`]/2`G;6%T
M<FEX)RD@>PH@("`@("`@("`@("`O*B!#;VQL87!S92!T:&4@87)R87D@9F]R
M(&1E9F%U;'0O9W5E<W0O8W)E871O<BX@*B\*("`@("`@("`@("`@)&EN9F];
M)V1E9FQT)UT@/2!I<W-E="@D:6YF;ULG9&5F;'0G75LP72D@/R`D:6YF;ULG
M9&5F;'0G75LP72`Z(&YU;&P["B`@("`@("`@("`@("1I;F9O6R=G=65S="==
M("`@/2!I<W-E="@D:6YF;ULG9W5E<W0G75LP72D@/R`D:6YF;ULG9W5E<W0G
M75LP72`Z(&YU;&P["B`@("`@("`@("`@("1I;F9O6R=C<F5A=&]R)UT@/2!I
M<W-E="@D:6YF;ULG8W)E871O<B==6S!=*2`_("1I;F9O6R=C<F5A=&]R)UU;
M,%T@.B!N=6QL.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U7VX@
M/2`D=&AI<RT^7W9A<G,M/F=E="@G=5]N)RD["B`@("`@("`@("`@("1I;F9O
M6R=U)UT@/2!A<G)A>2@D=5]N6R=U)UT@/3X@)&EN9F];)W5?;B==6R=V)UTI
M.PH@("`@("`@("`@("!U;G-E="@D:6YF;ULG=5]N)UTI.PH@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F];)W5?=B==*2D@>PH@("`@("`@("`@("`@("`@
M)&EN9F];)W4G72`](&%R<F%Y7VUE<F=E*"1I;F9O6R=U)UTL("1I;F9O6R=U
M7W8G72D["B`@("`@("`@("`@("`@("!U;G-E="@D:6YF;ULG=5]V)UTI.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1G7VX@/2`D=&AI<RT^7W9A<G,M
M/F=E="@G9U]N)RD["B`@("`@("`@("`@("1I;F9O6R=G)UT@/2!A<G)A>2@D
M9U]N6R=G)UT@/3X@)&EN9F];)V=?;B==6R=V)UTI.PH@("`@("`@("`@("!U
M;G-E="@D:6YF;ULG9U]N)UTI.PH@("`@("`@("`@("!I9B`H:7-S970H)&EN
M9F];)V=?=B==*2D@>PH@("`@("`@("`@("`@("`@)&EN9F];)V<G72`](&%R
M<F%Y7VUE<F=E*"1I;F9O6R=G)UTL("1I;F9O6R=G7W8G72D["B`@("`@("`@
M("`@("`@("!U;G-E="@D:6YF;ULG9U]V)UTI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("1I;F9O6R=D969A=6QT)UT@/2`D:6YF;ULG9&5F
M;'0G73L*("`@("`@("!U;G-E="@D:6YF;ULG9&5F;'0G72D["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&$@
M<&5R;6ES<VEO;B!D96QE=&EN9R!F;W)M+@H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W0@)'!E<FUI<W-I;VX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M=7!$96QE=&5&;W)M*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@("\J($EN
M:71I86QI<V4@9F]R;2!I9B!R97%U:7)E9"X@*B\*("`@("`@("`D=&AI<RT^
M7V9O<FU);FET*"D["@H@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T5&ET;&4H
M<W!R:6YT9BA?*")$96QE=&4@<&5R;6ES<VEO;G,@9F]R(%PB)7-<(B(I+"`D
M=&AI<RT^7W!E<FUS+3YG9714:71L92@D<&5R;6ES<VEO;BT^9V5T3F%M92@I
M*2DI.PH@("`@("`@("1T:&ES+3Y?9F]R;2T^<V5T0G5T=&]N<RAA<G)A>2A?
M*")$96QE=&4B*2P@7R@B1&\@;F]T(&1E;&5T92(I*2D["B`@("`@("`@)'1H
M:7,M/E]F;W)M+3YA9&1(:61D96XH)R<L("=P97)M7VED)RP@)W1E>'0G+"!F
M86QS92D["B`@("`@("`@)'1H:7,M/E]F;W)M+3YA9&1687)I86)L92AS<')I
M;G1F*%\H(D1E;&5T92!P97)M:7-S:6]N<R!F;W(@7"(E<UPB(&%N9"!A;GD@
M<W5B+7!E<FUI<W-I;VYS/R(I+"`D=&AI<RT^7W!E<FUS+3YG9714:71L92@D
M<&5R;6ES<VEO;BT^9V5T3F%M92@I*2DL("=P<F]M<'0G+"`G9&5S8W)I<'1I
M;VXG+"!F86QS92D["@H@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@
M=&\@=F%L:61A=&4@86YY(&1E;&5T92!F;W)M(&EN<'5T+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($EF('1H92!D96QE=&4@8G5T=&]N(&-O;F9I
M<FUA=&EO;B!H87,@8F5E;B!P<F5S<V5D(')E='5R;@H@("`@("H@("`@("`@
M("`@("`@("`@=')U92P@:68@86YY(&]T:&5R('-U8FUI="!B=71T;VX@:&%S
M(&)E96X@<')E<W-E9"!R971U<FX*("`@("`J("`@("`@("`@("`@("`@(&9A
M;'-E+B!)9B!F;W)M(&1I9"!N;W0@=F%L:61A=&4@<F5T=7)N(&YU;&PN"B`@
M("`@*B\*("`@(&9U;F-T:6]N('9A;&ED871E1&5L971E1F]R;2@F)&EN9F\I
M"B`@("!["B`@("`@("`@)&9O<FU?<W5B;6ET(#T@)'1H:7,M/E]V87)S+3YG
M970H)W-U8FUI=&)U='1O;B<I.PH*("`@("`@("!I9B`H)&9O<FU?<W5B;6ET
M(#T](%\H(D1E;&5T92(I*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^7V9O
M<FTM/G9A;&ED871E*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?9F]R;2T^9V5T26YF;R@D=&AI<RT^7W9A<G,L("1I;F9O*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E:68@*"%E;7!T>2@D9F]R;5]S=6)M:70I*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N9&5R<R!T:&4@961I
M="!F;W)M+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97)&;W)M*"1F;W)M
M7W-C<FEP="`]("=E9&ET+G!H<"<I"B`@("!["B`@("`@("`@<F5Q=6ER95]O
M;F-E("=(;W)D92]&;W)M+U)E;F1E<F5R+G!H<"<["B`@("`@("`@)')E;F1E
M<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R*"D["B`@("`@("`@)'1H
M:7,M/E]F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=&AI<RT^7W9A
M<G,L("1F;W)M7W-C<FEP="P@)W!O<W0G*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T97,@86YY(&9O<FT@;V)J96-T<R!I9B!T:&5Y(&AA=F4@;F]T
M(&)E96X@:6YI=&EA;&ES960@>65T+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9F]R;4EN:70H*0H@("`@
M>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?=F%R<RDI('L*("`@("`@
M("`@("`@+RH@3F\@97AI<W1I;F<@=F%R<R!S970L(&=E="!T:&5M(&YO=RX@
M*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=(;W)D92]687)I86)L97,N
M<&AP)SL*("`@("`@("`@("`@)'1H:7,M/E]V87)S(#T@)E9A<FEA8FQE<SHZ
M9V5T1&5F875L=%9A<FEA8FQE<R@I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]A*"1T:&ES+3Y?9F]R;2P@)TAO<F1E7T9O<FTG*2D@>PH@("`@("`@
M("`@("`O*B!.;R!E>&ES=&EN9R!V86QI9"!F;W)M(&]B:F5C="!S970@<V\@
M<V5T('5P(&$@;F5W(&]N92X@*B\*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=(;W)D92]&;W)M+G!H<"<["B`@("`@("`@("`@("1T:&ES+3Y?9F]R;2`]
M("9(;W)D95]&;W)M.CIS:6YG;&5T;VXH)R<L("1T:&ES+3Y?=F%R<RD["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+U!E<FUS
M+V1A=&%T<F5E+G!H<```````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#8V-S<U(#$P-3$U-#,T,3,W(#`R,C<V,@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=(
M;W)D92]$871A5')E92YP:'`G.PH*+RHJ"B`J(%1H92!097)M<U]D871A=')E
M93HZ(&-L87-S('!R;W9I9&5S(&$@1&%T851R964@9')I=F5R(&9O<B!T:&4@
M2&]R9&4*("H@<&5R;6ES<VEO;G,@<WES=&5M+@H@*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]097)M<R]097)M<R]D871A=')E92YP:'`L=B`Q+C8N,BXQ,B`R
M,#`V+S`W+S(P(#$X.C4P.C`U(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`Q+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*
M("H@0'!A8VMA9V4@2&]R9&5?4&5R;7,*("HO"F-L87-S(%!E<FUS7V1A=&%T
M<F5E(&5X=&5N9',@4&5R;7,@>PH*("`@("\J*@H@("`@("H@4&]I;G1E<B!T
M;R!A($1A=&%4<F5E(&EN<W1A;F-E('1O(&UA;F%G92!T:&4@9&EF9F5R96YT
M"B`@("`@*B!P97)M:7-S:6]N<RX*("`@("`J"B`@("`@*B!`=F%R($1A=&%4
M<F5E"B`@("`@*B\*("`@('9A<B`D7V1A=&%T<F5E.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%!E<FUS7V1A
M=&%T<F5E*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@
M(&EF("AE;7!T>2@D8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI*2!["B`@
M("`@("`@("`@($AO<F1E.CIF871A;"@G66]U(&UU<W0@8V]N9FEG=7)E(&$@
M1&%T851R964@8F%C:V5N9"!T;R!U<V4@=&AE(%!E<FUS($1A=&%4<F5E(&1R
M:79E<BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@
M("`@)&1R:79E<B`]("1C;VYF6R=D871A=')E92==6R=D<FEV97(G73L*("`@
M("`@("`D=&AI<RT^7V1A=&%T<F5E(#T@)D1A=&%4<F5E.CIS:6YG;&5T;VXH
M)&1R:79E<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87E?;65R9V4H2&]R9&4Z.F=E=$1R:79E<D-O;F9I
M9R@G9&%T871R964G+"`D9')I=F5R*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V=R;W5P)R`]/B`G:&]R9&4N<&5R;7,G*2DI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@879A:6QA8FQE('!E<FUI<W-I;VYS(&9O<B!A
M(&=I=F5N(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!P97)M:7-S:6]N)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!!;B!A<G)A>2!O9B!A=F%I;&%B;&4@<&5R;6ES<VEO;G,@
M86YD('1H96ER('1I=&QE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T079A
M:6QA8FQE*"1N86UE*0H@("`@>PH@("`@("`@(&EF("@D;F%M92`]/2!$051!
M5%)%15]23T]4*2!["B`@("`@("`@("`@("1N86UE(#T@)R<["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!P87)E;G0Z.F=E=$%V86EL86)L92@D;F%M92D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A('!E<FUI<W-I;VX@;F%M
M92P@<F5T=7)N<R!T:&4@=&ET;&4@9F]R('1H870@<&5R;6ES<VEO;B!B>0H@
M("`@("H@;&]O:VEN9R!I="!U<"!I;B!T:&4@87!P;&EC871I;VYS)W,@<&5R
M;6ES<VEO;B!A<&DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE('!E<FUI<W-I;VYS)W,@;F%M92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@5&AE('1I=&QE(&9O<B!T:&4@<&5R;6ES<VEO;BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H)&YA;64I"B`@("!["B`@("`@
M("`@:68@*"1N86UE(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@
M<F5T=7)N(%\H(D%L;"!097)M:7-S:6]N<R(I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@<&%R96YT.CIG9714:71L92@D;F%M92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS(&$@;F5W('!E<FUI<W-I;VYS(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@<&5R;6ES
M<VEO;B=S(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!$871A5')E94]B
M:F5C=%]097)M:7-S:6]N<R`@02!N97<@<&5R;6ES<VEO;G,@;V)J96-T+@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F;F5W4&5R;6ES<VEO;B@D;F%M92D*("`@
M('L*("`@("`@("!I9B`H96UP='DH)&YA;64I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=097)M:7-S:6]N(&YA;65S(&UU<W0@
M8F4@;F]N+65M<'1Y)RD["B`@("`@("`@?0H*("`@("`@("`D='EP92`]("=M
M871R:7@G.PH@("`@("`@("1P87)A;7,@/2!N=6QL.PH@("`@("`@(&EF("@D
M<&]S(#T@<W1R<&]S*"1N86UE+"`G.B<I*2!["B`@("`@("`@("`@("1I;F9O
M(#T@)'1H:7,M/F=E=$%P<&QI8V%T:6]N4&5R;6ES<VEO;G,H<W5B<W1R*"1N
M86UE+"`P+"`D<&]S*2D["B`@("`@("`@("`@(&EF("@A:7-?82@D:6YF;RP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I
M;F9O6R=T>7!E)UTI("8F(&ES<V5T*"1I;F9O6R=T>7!E)UU;)&YA;65=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)&EN9F];)W1Y<&4G75LD
M;F%M95T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&EN9F];)W!A<F%M<R==*2`F)B!I<W-E="@D:6YF;ULG<&%R86US
M)UU;)&YA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2`D
M:6YF;ULG<&%R86US)UU;)&YA;65=.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1P97)M(#T@)FYE=R!$871A
M5')E94]B:F5C=%]097)M:7-S:6]N*"1N86UE+"`D='EP92P@)'!A<F%M<RD[
M"B`@("`@("`@)'!E<FTM/G-E=$1A=&%4<F5E*"1T:&ES+3Y?9&%T871R964I
M.PH*("`@("`@("!R971U<FX@)'!E<FT["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&$@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!O8FIE8W0@
M8V]R<F5S<&]N9&EN9R!T;R!T:&4*("`@("`J(&YA;65D('!E<FUI<W-I;VXL
M('=I=&@@=&AE('5S97)S(&%N9"!O=&AE<B!D871A(')E=')I979E9`H@("`@
M("H@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@;F%M92!O9B!T:&4@<&5R;6ES<VEO;B!T;R!R971R:65V
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%!E<FUI<W-I;VXH)&YA;64I
M"B`@("!["B`@("`@("`@+RH@0V%C:&4@;V8@<')E=FEO=7-L>2!R971R:65V
M960@<&5R;6ES<VEO;G,N("HO"B`@("`@("`@<W1A=&EC("1P97)M<T-A8VAE
M(#T@87)R87DH*3L*"B`@("`@("`@:68@*&ES<V5T*"1P97)M<T-A8VAE6R1N
M86UE72DI('L*("`@("`@("`@("`@<F5T=7)N("1P97)M<T-A8VAE6R1N86UE
M73L*("`@("`@("!]"@H@("`@("`@("1P97)M<T-A8VAE6R1N86UE72`]("1T
M:&ES+3Y?9&%T871R964M/F=E=$]B:F5C="@D;F%M92P@)T1A=&%4<F5E3V)J
M96-T7U!E<FUI<W-I;VXG*3L*("`@("`@("!R971U<FX@)'!E<FUS0V%C:&5;
M)&YA;65=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A($1A=&%4
M<F5E3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T(&-O<G)E<W!O;F1I;F<@=&\@
M=&AE(&=I=F5N"B`@("`@*B!U;FEQ=64@240L('=I=&@@=&AE('5S97)S(&%N
M9"!O=&AE<B!D871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1C:60@(%1H92!U;FEQ=64@240@;V8@
M=&AE('!E<FUI<W-I;VX@=&\@<F5T<FEE=F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9G971097)M:7-S:6]N0GE)9"@D8VED*0H@("`@>PH@("`@("`@(&EF
M("@D8VED(#T]($1!5$%44D5%7U)/3U0I('L*("`@("`@("`@("`@)&]B:F5C
M="`]("8D=&AI<RT^;F5W4&5R;6ES<VEO;BA$051!5%)%15]23T]4*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;V)J96-T(#T@)B1T:&ES+3Y?
M9&%T871R964M/F=E=$]B:F5C=$)Y260H)&-I9"P@)T1A=&%4<F5E3V)J96-T
M7U!E<FUI<W-I;VXG*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O8FIE
M8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@<&5R;6ES<VEO;B!T
M;R!T:&4@<&5R;6ES<VEO;G,@<WES=&5M+B!4:&4@<&5R;6ES<VEO;B!M=7-T
M(&9I<G-T"B`@("`@*B!B92!C<F5A=&5D('=I=&@@4&5R;3HZ;F5W4&5R;6ES
M<VEO;B@I+"!A;F0@:&%V92!A;GD@:6YI=&EA;"!U<V5R<PH@("`@("H@861D
M960@=&\@:70L(&)E9F]R92!T:&ES(&9U;F-T:6]N(&ES(&-A;&QE9"X*("`@
M("`J"B`@("`@*B!`<&%R86T@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B`D
M<&5R;2`@5&AE(&YE=R!P97)M(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D4&5R;6ES<VEO;B@F)'!E<FTI"B`@("!["B`@("`@("`@:68@*"%I
M<U]A*"1P97)M+"`G1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B<I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=097)M:7-S:6]N
M<R!M=7-T(&)E($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T<R!O
M<B!E>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)'!E<FTI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5M;W9E<R!A('!E<FUI<W-I;VX@9G)O;2!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J($!P
M87)A;2!$871A5')E94]B:F5C=%]097)M:7-S:6]N("1P97)M("!4:&4@<&5R
M;6ES<VEO;B!T;R!R96UO=F4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R
M8V4@("`@("`@("`@("`@("`@("`@1F]R8V4@=&\@<F5M;W9E(&5V97)Y(&-H
M:6QD+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5097)M:7-S:6]N*"8D
M<&5R;2P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M*"1P97)M+"`G1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B<I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=097)M:7-S:6]N<R!M
M=7-T(&)E($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VX@;V)J96-T<R!O<B!E
M>'1E;F0@=&AA="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1A=&%T<F5E+3YR96UO=F4H)'!E<FTM/F=E=$YA;64H*2P@
M)&9O<F-E*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S(&]U="!W:&%T
M(')I9VAT<R!T:&4@9VEV96X@=7-E<B!H87,@=&\@=&AI<R!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1P97)M:7-S:6]N("!4:&4@9G5L
M;"!P97)M:7-S:6]N(&YA;64@;V8@=&AE(&]B:F5C="!T;PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C:&5C:R!T:&4@<&5R;6ES<VEO;G,@
M;V8L(&]R('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("!$
M871A5')E94]B:F5C=%]097)M:7-S:6]N(&]B:F5C="X*("`@("`J($!P87)A
M;2!S=')I;F<@)'5S97(@("`@("`@5&AE('5S97(@=&\@8VAE8VL@9F]R+B!$
M969A=6QT<R!T;R!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U<V5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8W)E871O
M<B`@("!4:&4@=7-E<B!W:&\@8W)E871E9"!T:&4@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@($$@8FET;6%S:R!O9B!P97)M:7-S:6]N
M<RP@82!P97)M:7-S:6]N('9A;'5E+"!O<B!A;B!A<G)A>0H@("`@("H@("`@
M("`@("`@("`@("`@;V8@<&5R;6ES<VEO;B!V86QU97,@=&AE('5S97(@:&%S
M+"!D97!E;F1I;F<@;VX@=&AE"B`@("`@*B`@("`@("`@("`@("`@("!P97)M
M:7-S:6]N('1Y<&4@86YD('=H971H97(@=&AE('!E<FUI<W-I;VX@=F%L=64@
M:7,*("`@("`J("`@("`@("`@("`@("`@(&%M8FEG=6]U<RX@1F%L<V4@:68@
M=&AE<F4@:7,@;F\@<W5C:"!P97)M<VES<VEO;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4&5R;6ES<VEO;G,H)'!E<FUI<W-I;VXL("1U<V5R(#T@;G5L
M;"P@)&-R96%T;W(@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M<&5R;6ES<VEO;BP@)T1A=&%4<F5E3V)J96-T7U!E<FUI<W-I;VXG*2D@>PH@
M("`@("`@("`@("`D<&5R;6ES<VEO;B`]("8D=&AI<RT^9V5T4&5R;6ES<VEO
M;B@D<&5R;6ES<VEO;BD["B`@("`@("`@("`@(&EF("AI<U]A*"1P97)M:7-S
M:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!(;W)D93HZ
M;&]G365S<V%G92@D<&5R;6ES<VEO;BP@7U]&24Q%7U\L(%]?3$E.15]?+"!0
M14%27TQ/1U]$14)51RD["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D=7-E<B`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D=7-E<B`]($%U=&@Z.F=E=$%U=&@H
M*3L*("`@("`@("!]"@H@("`@("`@("\O($EF('1H:7,@:7,@82!G=65S="!U
M<V5R+"!O;FQY(&-H96-K(&=U97-T('!E<FUI<W-I;VYS+@H@("`@("`@(&EF
M("AE;7!T>2@D=7-E<BDI('L*("`@("`@("`@("`@<F5T=7)N("1P97)M:7-S
M:6]N+3YG971'=65S=%!E<FUI<W-I;VYS*"D["B`@("`@("`@?0H*("`@("`@
M("`O+R!)9B`D8W)E871O<B!W87,@<W!E8VEF:65D+"!C:&5C:R!C<F5A=&]R
M('!E<FUI<W-I;VYS+@H@("`@("`@(&EF("@D8W)E871O<B`A/3T@;G5L;"D@
M>PH@("`@("`@("`@("`O+R!)9B!T:&4@=7-E<B!I<R!T:&4@8W)E871O<B!O
M9B!T:&4@979E;G0@<V5E(&EF('1H97)E"B`@("`@("`@("`@("\O(&%R92!C
M<F5A=&]R('!E<FUI<W-I;VYS+@H@("`@("`@("`@("!I9B`H<W1R;&5N*"1U
M<V5R*2`F)B`D=7-E<B`]/3T@)&-R96%T;W(@)B8*("`@("`@("`@("`@("`@
M("@D<&5R;7,@/2`D<&5R;6ES<VEO;BT^9V5T0W)E871O<E!E<FUI<W-I;VYS
M*"DI("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'!E<FUS
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!#:&5C:R!U
M<V5R+6QE=F5L('!E<FUI<W-I;VYS+@H@("`@("`@("1U<V5R<&5R;7,@/2`D
M<&5R;6ES<VEO;BT^9V5T57-E<E!E<FUI<W-I;VYS*"D["B`@("`@("`@:68@
M*&ES<V5T*"1U<V5R<&5R;7-;)'5S97)=*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'5S97)P97)M<ULD=7-E<ET["B`@("`@("`@?0H*("`@("`@("`O+R!)
M9B!N;R!U<V5R('!E<FUI<W-I;VYS(&%R92!F;W5N9"P@=')Y(&=R;W5P('!E
M<FUI<W-I;VYS+@H@("`@("`@(&EF("AI<W-E="@D<&5R;6ES<VEO;BT^9&%T
M85LG9W)O=7!S)UTI("8F"B`@("`@("`@("`@(&ES7V%R<F%Y*"1P97)M:7-S
M:6]N+3YD871A6R=G<F]U<',G72D@)B8*("`@("`@("`@("`@8V]U;G0H)'!E
M<FUI<W-I;VXM/F1A=&%;)V=R;W5P<R==*2D@>PH@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+T=R;W5P+G!H<"<["B`@("`@("`@("`@("1G<F]U
M<',@/2`F1W)O=7`Z.G-I;F=L971O;B@I.PH*("`@("`@("`@("`@)&-O;7!O
M<VET95]P97)M(#T@;G5L;#L*("`@("`@("`@("`@)'1Y<&4@/2`D<&5R;6ES
M<VEO;BT^9V5T*"=T>7!E)RD["B`@("`@("`@("`@(&9O<F5A8V@@*"1P97)M
M:7-S:6]N+3YD871A6R=G<F]U<',G72!A<R`D9W)O=7`@/3X@)'!E<FTI('L*
M("`@("`@("`@("`@("`@(&EF("@D9W)O=7!S+3YU<V5R27-);D=R;W5P*"1U
M<V5R+"`D9W)O=7`I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C;VUP
M;W-I=&5?<&5R;2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]M<&]S:71E7W!E<FT@/2`D='EP92`]/2`G;6%T<FEX)R`_(#`@.B!A
M<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1Y<&4@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;7!O<VET95]P97)M('P]("1P97)M.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M;VUP;W-I=&5?<&5R;5M=(#T@)'!E<FT["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&-O;7!O<VET95]P97)M("$]/2!N=6QL*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)&-O;7!O<VET95]P97)M.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!)9B!T:&5R92!A<F4@9&5F875L="!P97)M
M:7-S:6]N<RP@<F5T=7)N('1H96TN"B`@("`@("`@:68@*"@D<&5R;7,@/2`D
M<&5R;6ES<VEO;BT^9V5T1&5F875L=%!E<FUI<W-I;VYS*"DI("$]/2!N=6QL
M*2!["B`@("`@("`@("`@(')E='5R;B`D<&5R;7,["B`@("`@("`@?0H*("`@
M("`@("`O+R!/=&AE<G=I<V4L(&1E;GD@86QL('!E<FUI<W-I;VYS('1O('1H
M92!O8FIE8W0N"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=6YI<75E(&ED96YT:69I97(@;V8@=&AI
M<R!P97)M:7-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2!$871A5')E94]B
M:F5C=%]097)M:7-S:6]N("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!O
M8FIE8W0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!G970@=&AE($E$(&]F+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96=E<B`@5&AE('5N:7%U92!I9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T4&5R;6ES<VEO;DED*"1P97)M:7-S:6]N*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YG971)9"@D<&5R;6ES
M<VEO;BT^9V5T3F%M92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F1S
M(&]U="!I9B!T:&4@=7-E<B!H87,@=&AE('-P96-I9FEE9"!R:6=H=',@=&\@
M=&AE(&=I=F5N(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P97)M:7-S:6]N("!4:&4@<&5R;6ES<VEO;B!T;R!C:&5C:RX*("`@("`J
M($!P87)A;2!S=')I;F<@)'5S97(@("`@("`@(%1H92!U<V5R('1O(&-H96-K
M(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M("`@("`@(%1H92!P
M97)M:7-S:6]N(&QE=F5L('1H870@;F5E9',@=&\@8F4@8VAE8VME9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8W)E871O<B`@("`@5&AE(&-R96%T;W(@;V8@=&AE(&5V
M96YT"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M92!U<V5R(&AA<R!T:&4@<W!E8VEF:65D('!E<FUI<W-I;VYS+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!H87-097)M:7-S:6]N*"1P97)M:7-S:6]N+"`D=7-E
M<BP@)'!E<FTL("1C<F5A=&]R(#T@;G5L;"D*("`@('L*("`@("`@("!R971U
M<FX@*"1T:&ES+3YG971097)M:7-S:6]N<R@D<&5R;6ES<VEO;BP@)'5S97(L
M("1C<F5A=&]R*2`F("1P97)M*3L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M96-K<R!I9B!A('!E<FUI<W-I;VX@97AI<W1S(&EN('1H92!S>7-T96TN"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E
M<FUI<W-I;VX@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M96%N("!4<G5E(&EF('1H92!P97)M:7-S:6]N(&5X:7-T<RX*("`@("`J+PH@
M("`@9G5N8W1I;VX@97AI<W1S*"1P97)M:7-S:6]N*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1A=&%T<F5E+3YE>&ES=',H)'!E<FUI<W-I;VXI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A(&QI<W0@;V8@<&%R
M96YT('!E<FUI<W-I;VYS+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&-H:6QD("!4:&4@;F%M92!O9B!T:&4@8VAI;&0@=&\@<F5T<FEE=F4@<&%R
M96YT<R!F;W(N"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@02!H87-H
M('=I=&@@86QL('!A<F5N=',@:6X@82!T<F5E(&9O<FUA="X*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4&%R96YT<R@D8VAI;&0I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&%T871R964M/F=E=%!A<F5N=',H)&-H:6QD*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL('!E<FUI<W-I;VYS
M(&]F('1H92!S>7-T96T@:6X@82!T<F5E(&9O<FUA="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!A;&P@<&5R;6ES<VEO;G,@
M:6X@82!T<F5E(&9O<FUA="X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%1R
M964H*0H@("`@>PH@("`@("`@("1T<F5E(#T@)'1H:7,M/E]D871A=')E92T^
M9V5T*$1!5$%44D5%7T9/4DU!5%]&3$%4+"!$051!5%)%15]23T]4+"!T<G5E
M*3L*("`@("`@("!R971U<FX@)'1R964["B`@("!]"@I]"@HO*BH*("H@17AT
M96YS:6]N(&]F('1H92!$871A5')E94]B:F5C="!C;&%S<R!F;W(@<W1O<FEN
M9R!097)M:7-S:6]N(&EN9F]R;6%T:6]N(&EN"B`J('1H92!$871A5')E92!D
M<FEV97(N($EF('EO=2!W86YT('1O('-T;W)E('-P96-I86QI>F5D(%!E<FUI
M<W-I;VX*("H@:6YF;W)M871I;VXL('EO=2!S:&]U;&0@97AT96YD('1H:7,@
M8VQA<W,@:6YS=&5A9"!O9B!E>'1E;F1I;F<*("H@1&%T851R965/8FIE8W0@
M9&ER96-T;'DN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU
M8VM`:&]R9&4N;W)G/@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`
M:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`R+C$*("H@0'!A8VMA9V4@
M2&]R9&5?4&5R;7,*("HO"F-L87-S($1A=&%4<F5E3V)J96-T7U!E<FUI<W-I
M;VX@97AT96YD<R!$871A5')E94]B:F5C="!["@H@("`@+RHJ"B`@("`@*B!4
M:&4@1&%T851R965/8FIE8W1?4&5R;6ES<VEO;B!C;VYS=')U8W1O<BX@2G5S
M="!M86ME<R!S=7)E('1O(&-A;&P@=&AE"B`@("`@*B!P87)E;G0@8V]N<W1R
M=6-T;W(@<V\@=&AA="!T:&4@<&5R;2=S(&YA;64@:7,@<V5T('!R;W!E<FQY
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("!4:&4@;F%M
M92!O9B!T:&4@<&5R;2X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!4
M:&4@<&5R;6ES<VEO;B!T>7!E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A
M;7,@($$@:&%S:"!W:71H(&%N>2!P87)A;65T97)S('1H870@=&AE('!E<FUI
M<W-I;VX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T>7!E(&YE961S
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!$871A5')E94]B:F5C=%]097)M:7-S
M:6]N*"1N86UE+"`D='EP92`]("=M871R:7@G+"`D<&%R86US(#T@;G5L;"D*
M("`@('L*("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T*"1N86UE*3L*
M("`@("`@("`D=&AI<RT^9&%T85LG='EP92==(#T@)'1Y<&4["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("1T:&ES+3YD
M871A6R=P87)A;7,G72`]("1P87)A;7,["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T<R!O;F4@;V8@=&AE(&%T=')I8G5T97,@;V8@=&AE
M(&]B:F5C="P@;W(@;G5L;"!I9B!I="!I<VXG="!D969I;F5D+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&%T=')I8G5T92`@5&AE(&%T=')I8G5T
M92!T;R!G970N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('9A
M;'5E(&]F('1H92!A='1R:6)U=&4L(&]R(&YU;&PN"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E="@D871T<FEB=71E*0H@("`@>PH@("`@("`@("1V86QU92`]
M('!A<F5N=#HZ9V5T*"1A='1R:6)U=&4I.PH@("`@("`@(&EF("@D=F%L=64@
M/3T](&YU;&P@)B8@)&%T=')I8G5T92`]/2`G='EP92<I('L*("`@("`@("`@
M("`@)'9A;'5E(#T@)VUA=')I>"<["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!5<&1A=&5S('1H92!P
M97)M:7-S:6]N<R!B87-E9"!O;B!D871A('!A<W-E9"!I;B!T:&4@87)R87DN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1P97)M<R`@06X@87)R87D@
M8V]N=&%I;FEN9R!T:&4@<&5R;6ES<VEO;G,@=VAI8V@@87)E('1O(&)E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("!U<&1A=&5D+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!U<&1A=&5097)M:7-S:6]N<R@D<&5R;7,I"B`@("!["B`@
M("`@("`@)'1Y<&4@/2`D=&AI<RT^9V5T*"=T>7!E)RD["@H@("`@("`@(&EF
M("@D='EP92`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@("`O*B!!<G)A>2!O
M9B!P97)M:7-S:6]N('1Y<&5S('1O(&ET97)A=&4@=&AR;W5G:"X@*B\*("`@
M("`@("`@("`@)'!E<FU?='EP97,@/2!097)M<SHZ9V5T4&5R;7-!<G)A>2@I
M.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'!E<FUS(&%S("1P97)M
M7V-L87-S(#T^("1P97)M7W9A;'5E<RD@>PH@("`@("`@("`@("!S=VET8V@@
M*"1P97)M7V-L87-S*2!["B`@("`@("`@("`@(&-A<V4@)V1E9F%U;'0G.@H@
M("`@("`@("`@("!C87-E("=G=65S="<Z"B`@("`@("`@("`@(&-A<V4@)V-R
M96%T;W(G.@H@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=M871R:7@G
M*2!["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!E<FU?='EP97,@
M87,@)'9A;"`]/B`D;&%B96PI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%E;7!T>2@D<&5R;5]V86QU97-;)'9A;%TI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5R;2@D<&5R;5]C;&%S<RP@
M)'9A;"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5N<V5T4&5R
M;2@D<&5R;5]C;&%S<RP@)'9A;"P@9F%L<V4I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"%E;7!T>2@D<&5R;5]V86QU97,I*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-E=%!E<FTH)'!E<FU?8VQA<W,L("1P97)M
M7W9A;'5E<RP@9F%L<V4I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^=6YS971097)M*"1P97)M7V-L87-S
M+"!N=6QL+"!F86QS92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W4G.@H@("`@("`@("`@
M("!C87-E("=G)SH*("`@("`@("`@("`@("`@("1P97)M260@/2!A<G)A>2@G
M8VQA<W,G(#T^("1P97)M7V-L87-S(#T]("=U)R`_("=U<V5R<R<@.B`G9W)O
M=7!S)RD["B`@("`@("`@("`@("`@("`O*B!&:6=U<F4@;W5T('=H870@;F%M
M97,@=&AA="!A<F4@<W1O<F5D(&EN('1H:7,@<&5R;6ES<VEO;@H@("`@("`@
M("`@("`@("`@("H@8VQA<W,@:&%V92!N;W0@8F5E;B!S=6)M:71T960@9F]R
M(&%N('5P9&%T92P@:64N(&AA=F4@8F5E;@H@("`@("`@("`@("`@("`@("H@
M<F5M;W9E9"!E;G1I<F5L>2X@*B\*("`@("`@("`@("`@("`@("1C=7)R96YT
M7VYA;65S(#T@:7-S970H)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75TI
M"B`@("`@("`@("`@("`@("`@("`@/R!A<G)A>5]K97ES*"1T:&ES+3YD871A
M6R1P97)M261;)V-L87-S)UU=*0H@("`@("`@("`@("`@("`@("`@(#H@87)R
M87DH*3L*("`@("`@("`@("`@("`@("1U<&1A=&5D7VYA;65S(#T@87)R87E?
M:V5Y<R@D<&5R;5]V86QU97,I.PH@("`@("`@("`@("`@("`@)')E;6]V961?
M;F%M97,@/2!A<G)A>5]D:69F*"1C=7)R96YT7VYA;65S+"`D=7!D871E9%]N
M86UE<RD["@H@("`@("`@("`@("`@("`@+RH@4F5M;W9E(&%N>2!N86UE<R!T
M:&%T(&AA=F4@8F5E;B!C;VUP;&5T96QY('5N<V5T+B`J+PH@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)')E;6]V961?;F%M97,@87,@)&YA;64I('L*("`@
M("`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C
M;&%S<R==75LD;F%M95TI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\J($EF(&YO=&AI;F<@=&\@86-T=6%L;'D@=7!D871E(&9I;FES
M:"!W:71H('1H:7,@8V%S92X@*B\*("`@("`@("`@("`@("`@(&EF("@D<&5R
M;5]V86QU97,@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O*B!,
M;V]P('1H<F]U9V@@=&AE(&YA;65S(&%N9"!U<&1A=&4@<&5R;6ES<VEO;G,@
M9F]R(&5A8V@N("HO"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]V
M86QU97,@87,@)&YA;64@/3X@)&YA;65?=F%L=65S*2!["B`@("`@("`@("`@
M("`@("`@("`@)'!E<FU)9%LG;F%M92==(#T@)&YA;64["@H@("`@("`@("`@
M("`@("`@("`@(&EF("@D='EP92`]/2`G;6%T<FEX)RD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<&5R;5]T>7!E<R!A<R`D=F%L(#T^
M("1L86)E;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D;F%M95]V86QU97-;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G-E=%!E<FTH)'!E<FU)9"P@)'9A;"P@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6YS9710
M97)M*"1P97)M260L("1V86PL(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("@A96UP='DH)&YA;65?=F%L=65S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5T4&5R;2@D<&5R
M;4ED+"`D;F%M95]V86QU97,L(&9A;'-E*3L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6YS
M971097)M*"1P97)M260L(&YU;&PL(&9A;'-E*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!&25A-13H@;F5E9',@9&]C<PH@("`@("HO"B`@("!F=6YC=&EO;B!S
M971097)M*"1P97)M260L("1P97)M:7-S:6]N+"`D=7!D871E(#T@=')U92D*
M("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'!E<FU)9"DI('L*("`@("`@
M("`@("`@:68@*&5M<'1Y*"1P97)M261;)VYA;64G72DI('L*("`@("`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@("`@
M("`@("!I<W-E="@D=&AI<RT^9&%T85LD<&5R;4ED6R=C;&%S<R==75LD<&5R
M;4ED6R=N86UE)UU=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;
M)'!E<FU)9%LG8VQA<W,G75U;)'!E<FU)9%LG;F%M92==72!\/2`D<&5R;6ES
M<VEO;CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA;64G75T@
M/2`D<&5R;6ES<VEO;CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I
M>"<@)B8*("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YD871A6R1P97)M
M261=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%T@
M?#T@)'!E<FUI<W-I;VX["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^9&%T85LD<&5R;4ED72`]("1P97)M:7-S:6]N.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($9)6$U%.B!N965D<R!D;V-S"B`@("`@*B\*("`@
M(&9U;F-T:6]N('5N<V5T4&5R;2@D<&5R;4ED+"`D<&5R;6ES<VEO;BP@)'5P
M9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1P97)M
M260I*2!["B`@("`@("`@("`@(&EF("AE;7!T>2@D<&5R;4ED6R=N86UE)UTI
M*2!["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@
M>PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD871A6R1P97)M
M261;)V-L87-S)UU=6R1P97)M261;)VYA;64G75TI*2!["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F1A=&%;)'!E<FU)9%LG8VQA<W,G75U;)'!E<FU)
M9%LG;F%M92==72`F/2!^)'!E<FUI<W-I;VX["B`@("`@("`@("`@("`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P
M97)M261;)VYA;64G75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;)VYA
M;64G75TI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<V%V92@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3YD871A6R1P97)M261;)V-L87-S)UU=6R1P97)M261;
M)VYA;64G75TI.PH@("`@("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@>PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YD871A6R1P97)M261=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1P97)M261=("8]
M('XD<&5R;6ES<VEO;CL*("`@("`@("`@("`@("`@("`@("!I9B`H)'5P9&%T
M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD
M871A6R1P97)M261=*3L*("`@("`@("`@("`@("`@(&EF("@D=7!D871E*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=R86YT<R!A('5S97(@861D:71I;VYA;"!P97)M:7-S:6]N
M<R!T;R!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U<V5R("`@("`@("`@(%1H92!U<V5R('1O(&=R86YT(&%D9&ET:6]N86P@
M<&5R;6ES<VEO;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=&\N"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H
M92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D57-E<E!E<FUI<W-I;VXH)'5S97(L("1P97)M:7-S:6]N+"`D=7!D871E
M(#T@=')U92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'5S97(I*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)R`F)@H@("`@("`@("`@("!I<W-E
M="@D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI*2!["B`@("`@("`@("`@
M("1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R72!\/2`D<&5R;6ES<VEO;CL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG=7-E
M<G,G75LD=7-E<ET@/2`D<&5R;6ES<VEO;CL*("`@("`@("!]"@H@("`@("`@
M(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G1S(&=U97-T<R!A
M9&1I=&EO;F%L('!E<FUI<W-I;VYS('1O('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI
M<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I
M8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1'=65S
M=%!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T<G5E*0H@("`@
M>PH@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<@
M)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V=U97-T)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3YD871A6R=G=65S="==('P]("1P97)M:7-S
M:6]N.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YD871A
M6R=G=65S="==(#T@)'!E<FUI<W-I;VX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=R86YT<R!C<F5A=&]R<R!A
M9&1I=&EO;F%L('!E<FUI<W-I;VYS('1O('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI
M<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\@861D+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I
M8V%L;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1#<F5A
M=&]R4&5R;6ES<VEO;B@D<&5R;6ES<VEO;BP@)'5P9&%T92`]('1R=64I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX
M)R`F)@H@("`@("`@("`@("!I<W-E="@D=&AI<RT^9&%T85LG8W)E871O<B==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG8W)E871O<B==('P]("1P
M97)M:7-S:6]N.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YD871A6R=C<F5A=&]R)UT@/2`D<&5R;6ES<VEO;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("1T:&ES+3YS879E
M*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1W)A;G1S(&%D
M9&ET:6]N86P@9&5F875L="!P97)M:7-S:6]N<R!T;R!T:&ES(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H
M92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D1&5F875L=%!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@/2!T
M<G5E*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^9V5T*"=T>7!E)RD@/3T@
M)VUA=')I>"<@)B8*("`@("`@("`@("`@:7-S970H)'1H:7,M/F1A=&%;)V1E
M9F%U;'0G72DI('L*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V1E9F%U;'0G
M72!\/2`D<&5R;6ES<VEO;CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^9&%T85LG9&5F875L="==(#T@)'!E<FUI<W-I;VX["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'5P9&%T92D@>PH@("`@("`@("`@("`D=&AI
M<RT^<V%V92@I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=R
M86YT<R!A(&=R;W5P(&%D9&ET:6]N86P@<&5R;6ES<VEO;G,@=&\@=&AI<R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&=R;W5P260@
M("`@("!4:&4@:60@;V8@=&AE(&=R;W5P('1O(&=R86YT(&%D9&ET:6]N86P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&5R;6ES<VEO
M;G,@=&\N"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H
M92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O(&%D9"X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M861D1W)O=7!097)M:7-S:6]N*"1G<F]U<$ED+"`D<&5R;6ES<VEO;BP@)'5P
M9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1G<F]U<$ED
M*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I
M9B`H)'1H:7,M/F=E="@G='EP92<I(#T]("=M871R:7@G("8F"B`@("`@("`@
M("`@(&ES<V5T*"1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%TI*2![
M"B`@("`@("`@("`@("1T:&ES+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%T@
M?#T@)'!E<FUI<W-I;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72`]("1P97)M:7-S:6]N
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@
M("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F5S(&$@<&5R;6ES<VEO;B!T:&%T(&$@=7-E<B!C=7)R96YT
M;'D@:&%S(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'5S97(@("`@("`@("`@5&AE('5S97(@=&\@<F5M;W9E('1H92!P
M97)M:7-S:6]N(&9R;VTN"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI
M<W-I;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V92X*
M("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T
M;R!A=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@<F5M;W9E57-E<E!E<FUI<W-I;VXH)'5S97(L("1P97)M:7-S:6]N+"`D
M=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H96UP='DH)'5S97(I
M('Q\("%I<W-E="@D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI*2!["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI
M<RT^9V5T*"=T>7!E)RD@/3T@)VUA=')I>"<I('L*("`@("`@("`@("`@)'1H
M:7,M/F1A=&%;)W5S97)S)UU;)'5S97)=("8]('XD<&5R;6ES<VEO;CL*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YD871A6R=U<V5R<R==6R1U<V5R
M72DI('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R=U<V5R
M<R==6R1U<V5R72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LG=7-E<G,G75LD=7-E<ETI
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@
M("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296UO=F5S(&$@<&5R;6ES<VEO;B!T:&%T(&=U97-T<R!C=7)R96YT
M;'D@:&%V92!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M8V]N<W1A;G0@)'!E<FUI<W-I;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$
M14Q%5$4L(&5T8RXI('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E;6]V92X*("`@("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@
M("`@("`@5VAE=&AE<B!T;R!A=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E1W5E<W1097)M:7-S:6]N*"1P97)M
M:7-S:6]N+"`D=7!D871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YD871A6R=G=65S="==*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I
M(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=G=65S
M="==("8]('XD<&5R;6ES<VEO;CL*("`@("`@("`@("`@:68@*"1U<&1A=&4I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M9&%T85LG9W5E<W0G72D["B`@("`@("`@("`@(&EF("@D=7!D871E*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V%V92@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A('!E<FUI
M<W-I;VX@=&AA="!C<F5A=&]R<R!C=7)R96YT;'D@:&%V92!O;B!T:&ES(&]B
M:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@8V]N<W1A;G0@)'!E<FUI<W-I
M;VX@(%1H92!P97)M:7-S:6]N("A015)-4U]$14Q%5$4L(&5T8RXI('1O"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E;6]V92X*("`@
M("`J($!P87)A;2!B;V]L96%N("1U<&1A=&4@("`@("`@5VAE=&AE<B!T;R!A
M=71O;6%T:6-A;&QY('5P9&%T92!T:&4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%C:V5N9"X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5M;W9E0W)E871O<E!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL("1U<&1A=&4@
M/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1A=&%;
M)V-R96%T;W(G72DI('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3YG970H)W1Y<&4G*2`]/2`G;6%T<FEX)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LG8W)E871O<B==("8]('XD<&5R
M;6ES<VEO;CL*("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^9&%T85LG8W)E871O
M<B==*3L*("`@("`@("`@("`@:68@*"1U<&1A=&4I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YS879E*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@9&5F875L="!P97)M:7-S
M:6]N(&]N('1H:7,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!C;VYS
M=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@*%!%4DU37T1%3$54
M12P@971C+BD@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5M;W9E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'5P9&%T92`@("`@
M("!7:&5T:&5R('1O(&%U=&]M871I8V%L;'D@=7!D871E('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B86-K96YD+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96UO=F5$969A=6QT4&5R;6ES<VEO;B@D<&5R;6ES
M<VEO;BP@)'5P9&%T92`]('1R=64I"B`@("!["B`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^9&%T85LG9&5F875L="==*2D@>PH@("`@("`@("`@("!R971U
M<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F=E="@G='EP92<I
M(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("1T:&ES+3YD871A6R=D969A
M=6QT)UT@)CT@?B1P97)M:7-S:6]N.PH@("`@("`@("`@("!I9B`H)'5P9&%T
M92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3YD871A6R=D969A=6QT)UTI.PH@("`@("`@("`@("!I9B`H)'5P9&%T92D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-A=F4H*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E;6]V97,@82!P
M97)M:7-S:6]N('1H870@82!G<F]U<"!C=7)R96YT;'D@:&%S(&]N('1H:7,@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1G<F]U<$ED
M("`@("`@5&AE(&ED(&]F('1H92!G<F]U<"!T;R!R96UO=F4@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('!E<FUI<W-I;VX@9G)O
M;2X*("`@("`J($!P87)A;2!C;VYS=&%N="`D<&5R;6ES<VEO;B`@5&AE('!E
M<FUI<W-I;VX@*%!%4DU37T1%3$5412P@971C+BD@=&\*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5M;W9E+@H@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'5P9&%T92`@("`@("!7:&5T:&5R('1O(&%U=&]M871I8V%L
M;'D@=7!D871E('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B86-K96YD+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F5'<F]U
M<%!E<FUI<W-I;VXH)&=R;W5P260L("1P97)M:7-S:6]N+"`D=7!D871E(#T@
M=')U92D*("`@('L*("`@("`@("!I9B`H96UP='DH)&=R;W5P260I('Q\("%I
M<W-E="@D=&AI<RT^9&%T85LG9W)O=7!S)UU;)&=R;W5P261=*2D@>PH@("`@
M("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/F=E="@G='EP92<I(#T]("=M871R:7@G*2!["B`@("`@("`@("`@("1T:&ES
M+3YD871A6R=G<F]U<',G75LD9W)O=7!)9%T@)CT@?B1P97)M:7-S:6]N.PH@
M("`@("`@("`@("!I9B`H96UP='DH)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G
M<F]U<$ED72DI('L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A
M6R=G<F]U<',G75LD9W)O=7!)9%TI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V%V
M92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@=6YS970H)'1H:7,M/F1A=&%;)V=R;W5P<R==6R1G<F]U<$ED72D["B`@
M("`@("`@("`@(&EF("@D=7!D871E*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V%V92@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@=7-E<B!P97)M
M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D<&5R;2`@3&ES="!O;FQY('5S97)S('=I=&@@=&AI<R!P97)M
M:7-S:6]N(&QE=F5L+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($1E
M9F%U;'1S('1O(&%L;"!U<V5R<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!!;&P@=7-E<B!P97)M:7-S:6]N<R!F;W(@=&AI<R!O8FIE8W0L(&EN
M9&5X960@8GD@=7-E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T57-E<E!E
M<FUI<W-I;VYS*"1P97)M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YD871A6R=U<V5R<R==*2!\?"`A:7-?87)R87DH)'1H:7,M
M/F1A=&%;)W5S97)S)UTI*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I
M.PH@("`@("`@('T@96QS96EF("@A)'!E<FTI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YD871A6R=U<V5R<R==.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1U<V5R<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YD871A6R=U<V5R<R==(&%S("1U<V5R(#T^("1U<&5R;2D@
M>PH@("`@("`@("`@("`@("`@:68@*"1U<&5R;2`F("1P97)M*2!["B`@("`@
M("`@("`@("`@("`@("`@)'5S97)S6R1U<V5R72`]("1U<&5R;3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)'5S97)S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&=U97-T('!E<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@
M("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&=U97-T('!E<FUI<W-I
M;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'
M=65S=%!E<FUI<W-I;VYS*"D*("`@('L*("`@("`@("!R971U<FX@(65M<'1Y
M*"1T:&ES+3YD871A6R=G=65S="==*2`_"B`@("`@("`@("`@("1T:&ES+3YD
M871A6R=G=65S="==(#H*("`@("`@("`@("`@;G5L;#L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-R96%T;W(@<&5R;6ES<VEO;G,@;VX@
M=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4
M:&4@8W)E871O<B!P97)M:7-S:6]N<R!O;B!T:&ES(&]B:F5C="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0W)E871O<E!E<FUI<W-I;VYS*"D*("`@('L*
M("`@("`@("!R971U<FX@(65M<'1Y*"1T:&ES+3YD871A6R=C<F5A=&]R)UTI
M(#\*("`@("`@("`@("`@)'1H:7,M/F1A=&%;)V-R96%T;W(G72`Z"B`@("`@
M("`@("`@(&YU;&P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!D969A=6QT('!E<FUI<W-I;VYS(&]N('1H:7,@;V)J96-T+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(&1E9F%U;'0@<&5R;6ES<VEO
M;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E
M9F%U;'1097)M:7-S:6]N<R@I"B`@("!["B`@("`@("`@<F5T=7)N("%E;7!T
M>2@D=&AI<RT^9&%T85LG9&5F875L="==*2`_"B`@("`@("`@("`@("1T:&ES
M+3YD871A6R=D969A=6QT)UT@.@H@("`@("`@("`@("!N=6QL.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A>2!O9B!A;&P@9W)O=7`@
M<&5R;6ES<VEO;G,@;VX@=&AI<R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'!E<FT@($QI<W0@;VYL>2!U<V5R<R!W:71H('1H:7,@
M<&5R;6ES<VEO;B!L979E;"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!$969A=6QT<R!T;R!A;&P@=7-E<G,N"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@06QL(&=R;W5P('!E<FUI<W-I;VYS(&9O<B!T:&ES(&]B:F5C
M="P@:6YD97AE9"!B>2!G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1W)O=7!097)M:7-S:6]N<R@D<&5R;2`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9&%T85LG9W)O=7!S)UTI('Q\"B`@("`@("`@
M("`@("%I<U]A<G)A>2@D=&AI<RT^9&%T85LG9W)O=7!S)UTI*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T@96QS96EF("@A)'!E
M<FTI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD871A6R=G<F]U<',G
M73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9W)O=7!S(#T@87)R
M87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F1A=&%;)V=R;W5P
M<R==(&%S("1G<F]U<"`]/B`D9W!E<FTI('L*("`@("`@("`@("`@("`@(&EF
M("@D9W!E<FT@)B`D<&5R;2D@>PH@("`@("`@("`@("`@("`@("`@("1G<F]U
M<'-;)&=R;W5P72`]("1G<&5R;3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&=R;W5P<SL*("`@("`@("!]
M"B`@("!]"@I]"@```'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D
M92]);6%G92]R9V(N<&AP````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`T,C8W,2`Q,#4Q-30S-#$S-R`P,C$V-C0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%)'
M0B!C;VQO<B!N86UE<R]V86QU97,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+TEM86=E+TEM86=E+W)G8BYP:'`L=B`Q+C(N,3(N,2`R,#`U+S$P+S$X(#$Q
M.C`Q.C$S(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]);6%G90H@
M*B\*)$=,3T)!3%-;)VAO<F1E7VEM86=E7W)G8E]C;VQO<G,G72`](&%R<F%Y
M*`H@("`@)V%Q=6$G(#T^(&%R<F%Y*#`L(#(U-2P@,C4U*2P@"0D*("`@("=L
M:6UE)R`]/B!A<G)A>2@P+"`R-34L(#`I+"`)"0H@("`@)W1E86PG(#T^(&%R
M<F%Y*#`L(#$R."P@,3(X*2P*("`@("=W:&ET97-M;VME)R`]/B!A<G)A>2@R
M-#4L(#(T-2P@,C0U*2P*("`@("=G86EN<V)O<F\G(#T^(&%R<F%Y*#(R,"P@
M,C(P+"`R,C`I+`H@("`@)V]L9&QA8V4G(#T^(&%R<F%Y*#(U,RP@,C0U+"`R
M,S`I+`H@("`@)VQI;F5N)R`]/B!A<G)A>2@R-3`L(#(T,"P@,C,P*2P*("`@
M("=A;G1I<75E=VAI=&4G(#T^(&%R<F%Y*#(U,"P@,C,U+"`R,34I+`H@("`@
M)W!A<&%Y87=H:7`G(#T^(&%R<F%Y*#(U-2P@,C,Y+"`R,3,I+`H@("`@)V)L
M86YC:&5D86QM;VYD)R`]/B!A<G)A>2@R-34L(#(S-2P@,C`U*2P*("`@("=B
M:7-Q=64G(#T^(&%R<F%Y*#(U-2P@,C(X+"`Q.38I+`H@("`@)W!E86-H<'5F
M9B<@/3X@87)R87DH,C4U+"`R,3@L(#$X-2DL"B`@("`G;F%V86IO=VAI=&4G
M(#T^(&%R<F%Y*#(U-2P@,C(R+"`Q-S,I+`H@("`@)VUO8V-A<VEN)R`]/B!A
M<G)A>2@R-34L(#(R."P@,3@Q*2P*("`@("=C;W)N<VEL:R<@/3X@87)R87DH
M,C4U+"`R-#@L(#(R,"DL"B`@("`G:79O<GDG(#T^(&%R<F%Y*#(U-2P@,C4U
M+"`R-#`I+`H@("`@)VQE;6]N8VAI9F9O;B<@/3X@87)R87DH,C4U+"`R-3`L
M(#(P-2DL"B`@("`G<V5A<VAE;&PG(#T^(&%R<F%Y*#(U-2P@,C0U+"`R,S@I
M+`H@("`@)VUI;G1C<F5A;2<@/3X@87)R87DH,C0U+"`R-34L(#(U,"DL"B`@
M("`G87IU<F4G(#T^(&%R<F%Y*#(T,"P@,C4U+"`R-34I+`H@("`@)V%L:6-E
M8FQU92<@/3X@87)R87DH,C0P+"`R-#@L(#(U-2DL"B`@("`G;&%V96YD97(G
M(#T^(&%R<F%Y*#(S,"P@,C,P+"`R-3`I+`H@("`@)VQA=F5N9&5R8FQU<V@G
M(#T^(&%R<F%Y*#(U-2P@,C0P+"`R-#4I+`H@("`@)VUI<W1Y<F]S92<@/3X@
M87)R87DH,C4U+"`R,C@L(#(R-2DL"B`@("`G=VAI=&4G(#T^(&%R<F%Y*#(U
M-2P@,C4U+"`R-34I+`H@("`@)V)L86-K)R`]/B!A<G)A>2@P+"`P+"`P*2P*
M("`@("=D87)K<VQA=&5G<F%Y)R`]/B!A<G)A>2@T-RP@-SDL(#<Y*2P*("`@
M("=D:6UG<F%Y)R`]/B!A<G)A>2@Q,#4L(#$P-2P@,3`U*2P*("`@("=S;&%T
M96=R87DG(#T^(&%R<F%Y*#$Q,BP@,3(X+"`Q-#0I+`H@("`@)VQI9VAT<VQA
M=&5G<F%Y)R`]/B!A<G)A>2@Q,3DL(#$S-BP@,34S*2P*("`@("=G<F%Y)R`]
M/B!A<G)A>2@Q.3`L(#$Y,"P@,3DP*2P*("`@("=L:6=H=&=R87DG(#T^(&%R
M<F%Y*#(Q,2P@,C$Q+"`R,3$I+`H@("`@)VUI9&YI9VAT8FQU92<@/3X@87)R
M87DH,C4L(#(U+"`Q,3(I+`H@("`@)VYA=GDG(#T^(&%R<F%Y*#`L(#`L(#$R
M."DL"B`@("`G8V]R;F9L;W=E<F)L=64G(#T^(&%R<F%Y*#$P,"P@,30Y+"`R
M,S<I+`H@("`@)V1A<FMS;&%T96)L=64G(#T^(&%R<F%Y*#<R+"`V,2P@,3,Y
M*2P*("`@("=S;&%T96)L=64G(#T^(&%R<F%Y*#$P-BP@.3`L(#(P-2DL"B`@
M("`G;65D:75M<VQA=&5B;'5E)R`]/B!A<G)A>2@Q,C,L(#$P-"P@,C,X*2P*
M("`@("=L:6=H='-L871E8FQU92<@/3X@87)R87DH,3,R+"`Q,3(L(#(U-2DL
M"B`@("`G;65D:75M8FQU92<@/3X@87)R87DH,"P@,"P@,C`U*2P*("`@("=R
M;WEA;&)L=64G(#T^(&%R<F%Y*#8U+"`Q,#4L(#(R-2DL"B`@("`G8FQU92<@
M/3X@87)R87DH,"P@,"P@,C4U*2P*("`@("=D;V1G97)B;'5E)R`]/B!A<G)A
M>2@S,"P@,30T+"`R-34I+`H@("`@)V1E97!S:WEB;'5E)R`]/B!A<G)A>2@P
M+"`Q.3$L(#(U-2DL"B`@("`G<VMY8FQU92<@/3X@87)R87DH,3,U+"`R,#8L
M(#(S-2DL"B`@("`G;&EG:'1S:WEB;'5E)R`]/B!A<G)A>2@Q,S4L(#(P-BP@
M,C4P*2P*("`@("=S=&5E;&)L=64G(#T^(&%R<F%Y*#<P+"`Q,S`L(#$X,"DL
M"B`@("`G;&EG:'1R960G(#T^(&%R<F%Y*#(Q,2P@,38W+"`Q-C@I+`H@("`@
M)VQI9VAT<W1E96QB;'5E)R`]/B!A<G)A>2@Q-S8L(#$Y-BP@,C(R*2P*("`@
M("=L:6=H=&)L=64G(#T^(&%R<F%Y*#$W,RP@,C$V+"`R,S`I+`H@("`@)W!O
M=V1E<F)L=64G(#T^(&%R<F%Y*#$W-BP@,C(T+"`R,S`I+`H@("`@)W!A;&5T
M=7)Q=6]I<V4G(#T^(&%R<F%Y*#$W-2P@,C,X+"`R,S@I+`H@("`@)V1A<FMT
M=7)Q=6]I<V4G(#T^(&%R<F%Y*#`L(#(P-BP@,C`Y*2P*("`@("=M961I=6UT
M=7)Q=6]I<V4G(#T^(&%R<F%Y*#<R+"`R,#DL(#(P-"DL"B`@("`G='5R<75O
M:7-E)R`]/B!A<G)A>2@V-"P@,C(T+"`R,#@I+`H@("`@)V-Y86XG(#T^(&%R
M<F%Y*#`L(#(U-2P@,C4U*2P*("`@("=L:6=H=&-Y86XG(#T^(&%R<F%Y*#(R
M-"P@,C4U+"`R-34I+`H@("`@)V-A9&5T8FQU92<@/3X@87)R87DH.34L(#$U
M."P@,38P*2P*("`@("=M961I=6UA<75A;6%R:6YE)R`]/B!A<G)A>2@Q,#(L
M(#(P-2P@,3<P*2P*("`@("=A<75A;6%R:6YE)R`]/B!A<G)A>2@Q,C<L(#(U
M-2P@,C$R*2P*("`@("=D87)K9W)E96XG(#T^(&%R<F%Y*#`L(#$P,"P@,"DL
M"B`@("`G9&%R:V]L:79E9W)E96XG(#T^(&%R<F%Y*#@U+"`Q,#<L(#0W*2P*
M("`@("=D87)K<V5A9W)E96XG(#T^(&%R<F%Y*#$T,RP@,3@X+"`Q-#,I+`H@
M("`@)W-E86=R965N)R`]/B!A<G)A>2@T-BP@,3,Y+"`X-RDL"B`@("`G;65D
M:75M<V5A9W)E96XG(#T^(&%R<F%Y*#8P+"`Q-SDL(#$Q,RDL"B`@("`G;&EG
M:'1S96%G<F5E;B<@/3X@87)R87DH,S(L(#$W."P@,3<P*2P*("`@("=P86QE
M9W)E96XG(#T^(&%R<F%Y*#$U,BP@,C4Q+"`Q-3(I+`H@("`@)W-P<FEN9V=R
M965N)R`]/B!A<G)A>2@P+"`R-34L(#$R-RDL"B`@("`G;&%W;F=R965N)R`]
M/B!A<G)A>2@Q,C0L(#(U,BP@,"DL"B`@("`G9W)E96XG(#T^(&%R<F%Y*#`L
M(#(U-2P@,"DL"B`@("`G8VAA<G1R975S92<@/3X@87)R87DH,3(W+"`R-34L
M(#`I+`H@("`@)VUE9&EU;7-P<FEN9V=R965N)R`]/B!A<G)A>2@P+"`R-3`L
M(#$U-"DL"B`@("`G9W)E96YY96QL;W<G(#T^(&%R<F%Y*#$W,RP@,C4U+"`T
M-RDL"B`@("`G;&EM96=R965N)R`]/B!A<G)A>2@U,"P@,C`U+"`U,"DL"B`@
M("`G>65L;&]W9W)E96XG(#T^(&%R<F%Y*#$U-"P@,C`U+"`U,"DL"B`@("`G
M9F]R97-T9W)E96XG(#T^(&%R<F%Y*#,T+"`Q,SDL(#,T*2P*("`@("=O;&EV
M961R86(G(#T^(&%R<F%Y*#$P-RP@,30R+"`S-2DL"B`@("`G9&%R:VMH86MI
M)R`]/B!A<G)A>2@Q.#DL(#$X,RP@,3`W*2P*("`@("=K:&%K:2<@/3X@87)R
M87DH,C0P+"`R,S`L(#$T,"DL"B`@("`G<&%L96=O;&1E;G)O9"<@/3X@87)R
M87DH,C,X+"`R,S(L(#$W,"DL"B`@("`G;&EG:'1G;VQD96YR;V1Y96QL;W<G
M(#T^(&%R<F%Y*#(U,"P@,C4P+"`R,3`I+`H@("`@)VQI9VAT>65L;&]W)R`]
M/B!A<G)A>2@R-34L(#(U-2P@,C`P*2P*("`@("=Y96QL;W<G(#T^(&%R<F%Y
M*#(U-2P@,C4U+"`P*2P*("`@("=G;VQD)R`]/B!A<G)A>2@R-34L(#(Q-2P@
M,"DL"B`@("`G;&EG:'1G;VQD96YR;V0G(#T^(&%R<F%Y*#(S."P@,C(Q+"`Q
M,S`I+`H@("`@)V=O;&1E;G)O9"<@/3X@87)R87DH,C$X+"`Q-C4L(#,R*2P*
M("`@("=D87)K9V]L9&5N<F]D)R`]/B!A<G)A>2@Q.#0L(#$S-"P@,3$I+`H@
M("`@)W)O<WEB<F]W;B<@/3X@87)R87DH,3@X+"`Q-#,L(#$T,RDL"B`@("`G
M:6YD:6%N<F5D)R`]/B!A<G)A>2@R,#4L(#DR+"`Y,BDL"B`@("`G<V%D9&QE
M8G)O=VXG(#T^(&%R<F%Y*#$S.2P@-CDL(#$Y*2P*("`@("=S:65N;F$G(#T^
M(&%R<F%Y*#$V,"P@.#(L(#0U*2P*("`@("=P97)U)R`]/B!A<G)A>2@R,#4L
M(#$S,RP@-C,I+`H@("`@)V)U<FQY=V]O9"<@/3X@87)R87DH,C(R+"`Q.#0L
M(#$S-2DL"B`@("`G8F5I9V4G(#T^(&%R<F%Y*#(T-2P@,C0U+"`R,C`I+`H@
M("`@)W=H96%T)R`]/B!A<G)A>2@R-#4L(#(R,BP@,3<Y*2P*("`@("=S86YD
M>6)R;W=N)R`]/B!A<G)A>2@R-#0L(#$V-"P@.38I+`H@("`@)W1A;B<@/3X@
M87)R87DH,C$P+"`Q.#`L(#$T,"DL"B`@("`G8VAO8V]L871E)R`]/B!A<G)A
M>2@R,3`L(#$P-2P@,S`I+`H@("`@)V9I<F5B<FEC:R<@/3X@87)R87DH,3<X
M+"`S-"P@,S0I+`H@("`@)V)R;W=N)R`]/B!A<G)A>2@Q-C4L(#0R+"`T,BDL
M"B`@("`G9&%R:W-A;&UO;B<@/3X@87)R87DH,C,S+"`Q-3`L(#$R,BDL"B`@
M("`G<V%L;6]N)R`]/B!A<G)A>2@R-3`L(#$R."P@,3$T*2P*("`@("=L:6=H
M='-A;&UO;B<@/3X@87)R87DH,C4U+"`Q-C`L(#$R,BDL"B`@("`G;W)A;F=E
M)R`]/B!A<G)A>2@R-34L(#$V-2P@,"DL"B`@("`G9&%R:V]R86YG92<@/3X@
M87)R87DH,C4U+"`Q-#`L(#`I+`H@("`@)V-O<F%L)R`]/B!A<G)A>2@R-34L
M(#$R-RP@.#`I+`H@("`@)VQI9VAT8V]R86PG(#T^(&%R<F%Y*#(T,"P@,3(X
M+"`Q,C@I+`H@("`@)W1O;6%T;R<@/3X@87)R87DH,C4U+"`Y.2P@-S$I+`H@
M("`@)V]R86YG97)E9"<@/3X@87)R87DH,C4U+"`V.2P@,"DL"B`@("`G<F5D
M)R`]/B!A<G)A>2@R-34L(#`L(#`I+`H@("`@)VAO='!I;FLG(#T^(&%R<F%Y
M*#(U-2P@,3`U+"`Q.#`I+`H@("`@)V1E97!P:6YK)R`]/B!A<G)A>2@R-34L
M(#(P+"`Q-#<I+`H@("`@)W!I;FLG(#T^(&%R<F%Y*#(U-2P@,3DR+"`R,#,I
M+`H@("`@)VQI9VAT<&EN:R<@/3X@87)R87DH,C4U+"`Q.#(L(#$Y,RDL"B`@
M("`G<&%L979I;VQE=')E9"<@/3X@87)R87DH,C$Y+"`Q,3(L(#$T-RDL"B`@
M("`G;6%R;V]N)R`]/B!A<G)A>2@Q-S8L(#0X+"`Y-BDL"B`@("`G;65D:75M
M=FEO;&5T<F5D)R`]/B!A<G)A>2@Q.3DL(#(Q+"`Q,S,I+`H@("`@)W9I;VQE
M=')E9"<@/3X@87)R87DH,C`X+"`S,BP@,30T*2P*("`@("=M86=E;G1A)R`]
M/B!A<G)A>2@R-34L(#`L(#(U-2DL"B`@("`G=FEO;&5T)R`]/B!A<G)A>2@R
M,S@L(#$S,"P@,C,X*2P*("`@("=P;'5M)R`]/B!A<G)A>2@R,C$L(#$V,"P@
M,C(Q*2P*("`@("=O<F-H:60G(#T^(&%R<F%Y*#(Q."P@,3$R+"`R,30I+`H@
M("`@)VUE9&EU;6]R8VAI9"<@/3X@87)R87DH,3@V+"`X-2P@,C$Q*2P*("`@
M("=D87)K;W)C:&ED)R`]/B!A<G)A>2@Q-3,L(#4P+"`R,#0I+`H@("`@)V1A
M<FMV:6]L970G(#T^(&%R<F%Y*#$T."P@,"P@,C$Q*2P*("`@("=B;'5E=FEO
M;&5T)R`]/B!A<G)A>2@Q,S@L(#0S+"`R,C8I+`H@("`@)W!U<G!L92<@/3X@
M87)R87DH,38P+"`S,BP@,C0P*2P*("`@("=M961I=6UP=7)P;&4G(#T^(&%R
M<F%Y*#$T-RP@,3$R+"`R,3DI+`H@("`@)W1H:7-T;&4G(#T^(&%R<F%Y*#(Q
M-BP@,3DQ+"`R,38I+`H@("`@)W-N;W<Q)R`]/B!A<G)A>2@R-34L(#(U,"P@
M,C4P*2P*("`@("=S;F]W,B<@/3X@87)R87DH,C,X+"`R,S,L(#(S,RDL"B`@
M("`G<VYO=S,G(#T^(&%R<F%Y*#(P-2P@,C`Q+"`R,#$I+`H@("`@)W-N;W<T
M)R`]/B!A<G)A>2@Q,SDL(#$S-RP@,3,W*2P*("`@("=S96%S:&5L;#$G(#T^
M(&%R<F%Y*#(U-2P@,C0U+"`R,S@I+`H@("`@)W-E87-H96QL,B<@/3X@87)R
M87DH,C,X+"`R,CDL(#(R,BDL"B`@("`G<V5A<VAE;&PS)R`]/B!A<G)A>2@R
M,#4L(#$Y-RP@,3DQ*2P*("`@("=S96%S:&5L;#0G(#T^(&%R<F%Y*#$S.2P@
M,3,T+"`Q,S`I+`H@("`@)T%N=&EQ=657:&ET93$G(#T^(&%R<F%Y*#(U-2P@
M,C,Y+"`R,3DI+`H@("`@)T%N=&EQ=657:&ET93(G(#T^(&%R<F%Y*#(S."P@
M,C(S+"`R,#0I+`H@("`@)T%N=&EQ=657:&ET93,G(#T^(&%R<F%Y*#(P-2P@
M,3DR+"`Q-S8I+`H@("`@)T%N=&EQ=657:&ET930G(#T^(&%R<F%Y*#$S.2P@
M,3,Q+"`Q,C`I+`H@("`@)V)I<W%U93$G(#T^(&%R<F%Y*#(U-2P@,C(X+"`Q
M.38I+`H@("`@)V)I<W%U93(G(#T^(&%R<F%Y*#(S."P@,C$S+"`Q.#,I+`H@
M("`@)V)I<W%U93,G(#T^(&%R<F%Y*#(P-2P@,3@S+"`Q-3@I+`H@("`@)V)I
M<W%U930G(#T^(&%R<F%Y*#$S.2P@,3(U+"`Q,#<I+`H@("`@)W!E86-H4'5F
M9C$G(#T^(&%R<F%Y*#(U-2P@,C$X+"`Q.#4I+`H@("`@)W!E86-H<'5F9C(G
M(#T^(&%R<F%Y*#(S."P@,C`S+"`Q-S,I+`H@("`@)W!E86-H<'5F9C,G(#T^
M(&%R<F%Y*#(P-2P@,3<U+"`Q-#DI+`H@("`@)W!E86-H<'5F9C0G(#T^(&%R
M<F%Y*#$S.2P@,3$Y+"`Q,#$I+`H@("`@)VYA=F%J;W=H:71E,2<@/3X@87)R
M87DH,C4U+"`R,C(L(#$W,RDL"B`@("`G;F%V86IO=VAI=&4R)R`]/B!A<G)A
M>2@R,S@L(#(P-RP@,38Q*2P*("`@("=N879A:F]W:&ET93,G(#T^(&%R<F%Y
M*#(P-2P@,3<Y+"`Q,SDI+`H@("`@)VYA=F%J;W=H:71E-"<@/3X@87)R87DH
M,3,Y+"`Q,C$L(#DT*2P*("`@("=L96UO;F-H:69F;VXQ)R`]/B!A<G)A>2@R
M-34L(#(U,"P@,C`U*2P*("`@("=L96UO;F-H:69F;VXR)R`]/B!A<G)A>2@R
M,S@L(#(S,RP@,3DQ*2P*("`@("=L96UO;F-H:69F;VXS)R`]/B!A<G)A>2@R
M,#4L(#(P,2P@,38U*2P*("`@("=L96UO;F-H:69F;VXT)R`]/B!A<G)A>2@Q
M,SDL(#$S-RP@,3$R*2P*("`@("=I=F]R>3$G(#T^(&%R<F%Y*#(U-2P@,C4U
M+"`R-#`I+`H@("`@)VEV;W)Y,B<@/3X@87)R87DH,C,X+"`R,S@L(#(R-"DL
M"B`@("`G:79O<GDS)R`]/B!A<G)A>2@R,#4L(#(P-2P@,3DS*2P*("`@("=I
M=F]R>30G(#T^(&%R<F%Y*#$S.2P@,3,Y+"`Q,S$I+`H@("`@)VAO;F5Y9&5W
M)R`]/B!A<G)A>2@Q.3,L(#(P-2P@,3DS*2P*("`@("=L879E;F1E<F)L=7-H
M,2<@/3X@87)R87DH,C4U+"`R-#`L(#(T-2DL"B`@("`G;&%V96YD97)B;'5S
M:#(G(#T^(&%R<F%Y*#(S."P@,C(T+"`R,CDI+`H@("`@)VQA=F5N9&5R8FQU
M<V@S)R`]/B!A<G)A>2@R,#4L(#$Y,RP@,3DW*2P*("`@("=L879E;F1E<F)L
M=7-H-"<@/3X@87)R87DH,3,Y+"`Q,S$L(#$S-"DL"B`@("`G;6ES='ER;W-E
M,2<@/3X@87)R87DH,C4U+"`R,C@L(#(R-2DL"B`@("`G;6ES='ER;W-E,B<@
M/3X@87)R87DH,C,X+"`R,3,L(#(Q,"DL"B`@("`G;6ES='ER;W-E,R<@/3X@
M87)R87DH,C`U+"`Q.#,L(#$X,2DL"B`@("`G;6ES='ER;W-E-"<@/3X@87)R
M87DH,3,Y+"`Q,C4L(#$R,RDL"B`@("`G87IU<F4Q)R`]/B!A<G)A>2@R-#`L
M(#(U-2P@,C4U*2P*("`@("=A>G5R93(G(#T^(&%R<F%Y*#(R-"P@,C,X+"`R
M,S@I+`H@("`@)V%Z=7)E,R<@/3X@87)R87DH,3DS+"`R,#4L(#(P-2DL"B`@
M("`G87IU<F4T)R`]/B!A<G)A>2@Q,S$L(#$S.2P@,3,Y*2P*("`@("=S;&%T
M96)L=64Q)R`]/B!A<G)A>2@Q,S$L(#$Q,2P@,C4U*2P*("`@("=S;&%T96)L
M=64R)R`]/B!A<G)A>2@Q,C(L(#$P,RP@,C,X*2P*("`@("=S;&%T96)L=64S
M)R`]/B!A<G)A>2@Q,#4L(#@Y+"`R,#4I+`H@("`@)W-L871E8FQU930G(#T^
M(&%R<F%Y*#<Q+"`V,"P@,3,Y*2P*("`@("=R;WEA;&)L=64Q)R`]/B!A<G)A
M>2@W,BP@,3$X+"`R-34I+`H@("`@)W)O>6%L8FQU93(G(#T^(&%R<F%Y*#8W
M+"`Q,3`L(#(S."DL"B`@("`G<F]Y86QB;'5E,R<@/3X@87)R87DH-3@L(#DU
M+"`R,#4I+`H@("`@)W)O>6%L8FQU930G(#T^(&%R<F%Y*#,Y+"`V-"P@,3,Y
M*2P*("`@("=D;V1G97)B;'5E,2<@/3X@87)R87DH,S`L(#$T-"P@,C4U*2P*
M("`@("=D;V1G97)B;'5E,B<@/3X@87)R87DH,C@L(#$S-"P@,C,X*2P*("`@
M("=D;V1G97)B;'5E,R<@/3X@87)R87DH,C0L(#$Q-BP@,C`U*2P*("`@("=D
M;V1G97)B;'5E-"<@/3X@87)R87DH,38L(#<X+"`Q,SDI+`H@("`@)W-T965L
M8FQU93$G(#T^(&%R<F%Y*#DY+"`Q.#0L(#(U-2DL"B`@("`G<W1E96QB;'5E
M,B<@/3X@87)R87DH.3(L(#$W,BP@,C,X*2P*("`@("=S=&5E;&)L=64S)R`]
M/B!A<G)A>2@W.2P@,30X+"`R,#4I+`H@("`@)W-T965L8FQU930G(#T^(&%R
M<F%Y*#4T+"`Q,#`L(#$S.2DL"B`@("`G9&5E<'-K>6)L=64Q)R`]/B!A<G)A
M>2@P+"`Q.3$L(#(U-2DL"B`@("`G9&5E<'-K>6)L=64R)R`]/B!A<G)A>2@P
M+"`Q-S@L(#(S."DL"B`@("`G9&5E<'-K>6)L=64S)R`]/B!A<G)A>2@P+"`Q
M-30L(#(P-2DL"B`@("`G9&5E<'-K>6)L=64T)R`]/B!A<G)A>2@P+"`Q,#0L
M(#$S.2DL"B`@("`G<VMY8FQU93$G(#T^(&%R<F%Y*#$S-2P@,C`V+"`R-34I
M+`H@("`@)W-K>6)L=64R)R`]/B!A<G)A>2@Q,C8L(#$Y,BP@,C,X*2P*("`@
M("=S:WEB;'5E,R<@/3X@87)R87DH,3`X+"`Q-C8L(#(P-2DL"B`@("`G<VMY
M8FQU930G(#T^(&%R<F%Y*#<T+"`Q,3(L(#$S.2DL"B`@("`G;&EG:'1S:WEB
M;'5E,2<@/3X@87)R87DH,3<V+"`R,C8L(#(U-2DL"B`@("`G;&EG:'1S:WEB
M;'5E,B<@/3X@87)R87DH,38T+"`R,3$L(#(S."DL"B`@("`G;&EG:'1S:WEB
M;'5E,R<@/3X@87)R87DH,30Q+"`Q.#(L(#(P-2DL"B`@("`G;&EG:'1S:WEB
M;'5E-"<@/3X@87)R87DH.38L(#$R,RP@,3,Y*2P*("`@("=S;&%T96=R87DQ
M)R`]/B!A<G)A>2@Q.3@L(#(R-BP@,C4U*2P*("`@("=S;&%T96=R87DR)R`]
M/B!A<G)A>2@Q.#4L(#(Q,2P@,C,X*2P*("`@("=S;&%T96=R87DS)R`]/B!A
M<G)A>2@Q-3DL(#$X,BP@,C`U*2P*("`@("=S;&%T96=R87DT)R`]/B!A<G)A
M>2@Q,#@L(#$R,RP@,3,Y*2P*("`@("=L:6=H='-T965L8FQU93$G(#T^(&%R
M<F%Y*#(P,BP@,C(U+"`R-34I+`H@("`@)VQI9VAT<W1E96QB;'5E,B<@/3X@
M87)R87DH,3@X+"`R,3`L(#(S."DL"B`@("`G;&EG:'1S=&5E;&)L=64S)R`]
M/B!A<G)A>2@Q-C(L(#$X,2P@,C`U*2P*("`@("=L:6=H='-T965L8FQU930G
M(#T^(&%R<F%Y*#$Q,"P@,3(S+"`Q,SDI+`H@("`@)VQI9VAT8FQU93$G(#T^
M(&%R<F%Y*#$Y,2P@,C,Y+"`R-34I+`H@("`@)VQI9VAT8FQU93(G(#T^(&%R
M<F%Y*#$W."P@,C(S+"`R,S@I+`H@("`@)VQI9VAT8FQU93,G(#T^(&%R<F%Y
M*#$U-"P@,3DR+"`R,#4I+`H@("`@)VQI9VAT8FQU930G(#T^(&%R<F%Y*#$P
M-"P@,3,Q+"`Q,SDI+`H@("`@)VQI9VAT8WEA;C$G(#T^(&%R<F%Y*#(R-"P@
M,C4U+"`R-34I+`H@("`@)VQI9VAT8WEA;C(G(#T^(&%R<F%Y*#(P.2P@,C,X
M+"`R,S@I+`H@("`@)VQI9VAT8WEA;C,G(#T^(&%R<F%Y*#$X,"P@,C`U+"`R
M,#4I+`H@("`@)VQI9VAT8WEA;C0G(#T^(&%R<F%Y*#$R,BP@,3,Y+"`Q,SDI
M+`H@("`@)W!A;&5T=7)Q=6]I<V4Q)R`]/B!A<G)A>2@Q.#<L(#(U-2P@,C4U
M*2P*("`@("=P86QE='5R<75O:7-E,B<@/3X@87)R87DH,3<T+"`R,S@L(#(S
M."DL"B`@("`G<&%L971U<G%U;VES93,G(#T^(&%R<F%Y*#$U,"P@,C`U+"`R
M,#4I+`H@("`@)W!A;&5T=7)Q=6]I<V4T)R`]/B!A<G)A>2@Q,#(L(#$S.2P@
M,3,Y*2P*("`@("=C861E=&)L=64Q)R`]/B!A<G)A>2@Q-3(L(#(T-2P@,C4U
M*2P*("`@("=C861E=&)L=64R)R`]/B!A<G)A>2@Q-#(L(#(R.2P@,C,X*2P*
M("`@("=C861E=&)L=64S)R`]/B!A<G)A>2@Q,C(L(#$Y-RP@,C`U*2P*("`@
M("=C861E=&)L=64T)R`]/B!A<G)A>2@X,RP@,3,T+"`Q,SDI+`H@("`@)W1U
M<G%U;VES93$G(#T^(&%R<F%Y*#`L(#(T-2P@,C4U*2P*("`@("=T=7)Q=6]I
M<V4R)R`]/B!A<G)A>2@P+"`R,CDL(#(S."DL"B`@("`G='5R<75O:7-E,R<@
M/3X@87)R87DH,"P@,3DW+"`R,#4I+`H@("`@)W1U<G%U;VES930G(#T^(&%R
M<F%Y*#`L(#$S-"P@,3,Y*2P*("`@("=C>6%N,2<@/3X@87)R87DH,"P@,C4U
M+"`R-34I+`H@("`@)V-Y86XR)R`]/B!A<G)A>2@P+"`R,S@L(#(S."DL"B`@
M("`G8WEA;C,G(#T^(&%R<F%Y*#`L(#(P-2P@,C`U*2P*("`@("=C>6%N-"<@
M/3X@87)R87DH,"P@,3,Y+"`Q,SDI+`H@("`@)V1A<FMS;&%T96=R87DQ)R`]
M/B!A<G)A>2@Q-3$L(#(U-2P@,C4U*2P*("`@("=D87)K<VQA=&5G<F%Y,B<@
M/3X@87)R87DH,30Q+"`R,S@L(#(S."DL"B`@("`G9&%R:W-L871E9W)A>3,G
M(#T^(&%R<F%Y*#$R,2P@,C`U+"`R,#4I+`H@("`@)V1A<FMS;&%T96=R87DT
M)R`]/B!A<G)A>2@X,BP@,3,Y+"`Q,SDI+`H@("`@)V%Q=6%M87)I;F4Q)R`]
M/B!A<G)A>2@Q,C<L(#(U-2P@,C$R*2P*("`@("=A<75A;6%R:6YE,B<@/3X@
M87)R87DH,3$X+"`R,S@L(#$Y."DL"B`@("`G87%U86UA<FEN93,G(#T^(&%R
M<F%Y*#$P,BP@,C`U+"`Q-S`I+`H@("`@)V%Q=6%M87)I;F4T)R`]/B!A<G)A
M>2@V.2P@,3,Y+"`Q,38I+`H@("`@)V1A<FMS96%G<F5E;C$G(#T^(&%R<F%Y
M*#$Y,RP@,C4U+"`Q.3,I+`H@("`@)V1A<FMS96%G<F5E;C(G(#T^(&%R<F%Y
M*#$X,"P@,C,X+"`Q.#`I+`H@("`@)V1A<FMS96%G<F5E;C,G(#T^(&%R<F%Y
M*#$U-2P@,C`U+"`Q-34I+`H@("`@)V1A<FMS96%G<F5E;C0G(#T^(&%R<F%Y
M*#$P-2P@,3,Y+"`Q,#4I+`H@("`@)W-E86=R965N,2<@/3X@87)R87DH.#0L
M(#(U-2P@,34Y*2P*("`@("=S96%G<F5E;C(G(#T^(&%R<F%Y*#<X+"`R,S@L
M(#$T."DL"B`@("`G<V5A9W)E96XS)R`]/B!A<G)A>2@V-RP@,C`U+"`Q,C@I
M+`H@("`@)W-E86=R965N-"<@/3X@87)R87DH-#8L(#$S.2P@.#<I+`H@("`@
M)W!A;&5G<F5E;C$G(#T^(&%R<F%Y*#$U-"P@,C4U+"`Q-30I+`H@("`@)W!A
M;&5G<F5E;C(G(#T^(&%R<F%Y*#$T-"P@,C,X+"`Q-#0I+`H@("`@)W!A;&5G
M<F5E;C,G(#T^(&%R<F%Y*#$R-"P@,C`U+"`Q,C0I+`H@("`@)W!A;&5G<F5E
M;C0G(#T^(&%R<F%Y*#@T+"`Q,SDL(#@T*2P*("`@("=S<')I;F=G<F5E;C$G
M(#T^(&%R<F%Y*#`L(#(U-2P@,3(W*2P*("`@("=S<')I;F=G<F5E;C(G(#T^
M(&%R<F%Y*#`L(#(S."P@,3$X*2P*("`@("=S<')I;F=G<F5E;C,G(#T^(&%R
M<F%Y*#`L(#(P-2P@,3`R*2P*("`@("=S<')I;F=G<F5E;C0G(#T^(&%R<F%Y
M*#`L(#$S.2P@-CDI+`H@("`@)V-H87)T<F5U<V4Q)R`]/B!A<G)A>2@Q,C<L
M(#(U-2P@,"DL"B`@("`G8VAA<G1R975S93(G(#T^(&%R<F%Y*#$Q."P@,C,X
M+"`P*2P*("`@("=C:&%R=')E=7-E,R<@/3X@87)R87DH,3`R+"`R,#4L(#`I
M+`H@("`@)V-H87)T<F5U<V4T)R`]/B!A<G)A>2@V.2P@,3,Y+"`P*2P*("`@
M("=O;&EV961R86(Q)R`]/B!A<G)A>2@Q.3(L(#(U-2P@-C(I+`H@("`@)V]L
M:79E9')A8C(G(#T^(&%R<F%Y*#$W.2P@,C,X+"`U."DL"B`@("`G;VQI=F5D
M<F%B,R<@/3X@87)R87DH,34T+"`R,#4L(#4P*2P*("`@("=O;&EV961R86(T
M)R`]/B!A<G)A>2@Q,#4L(#$S.2P@,S0I+`H@("`@)V1A<FMO;&EV96=R965N
M,2<@/3X@87)R87DH,C`R+"`R-34L(#$Q,BDL"B`@("`G9&%R:V]L:79E9W)E
M96XR)R`]/B!A<G)A>2@Q.#@L(#(S."P@,3`T*2P*("`@("=D87)K;VQI=F5G
M<F5E;C,G(#T^(&%R<F%Y*#$V,BP@,C`U+"`Y,"DL"B`@("`G9&%R:V]L:79E
M9W)E96XT)R`]/B!A<G)A>2@Q,3`L(#$S.2P@-C$I+`H@("`@)VMH86MI,2<@
M/3X@87)R87DH,C4U+"`R-#8L(#$T,RDL"B`@("`G:VAA:VDR)R`]/B!A<G)A
M>2@R,S@L(#(S,"P@,3,S*2P*("`@("=K:&%K:3,G(#T^(&%R<F%Y*#(P-2P@
M,3DX+"`Q,34I+`H@("`@)VMH86MI-"<@/3X@87)R87DH,3,Y+"`Q,S0L(#<X
M*2P*("`@("=L:6=H=&=O;&1E;G)O9#$G(#T^(&%R<F%Y*#(U-2P@,C,V+"`Q
M,SDI+`H@("`@)VQI9VAT9V]L9&5N<F]D,B<@/3X@87)R87DH,C,X+"`R,C`L
M(#$S,"DL"B`@("`G;&EG:'1G;VQD96YR;V0S)R`]/B!A<G)A>2@R,#4L(#$Y
M,"P@,3$R*2P*("`@("=L:6=H=&=O;&1E;G)O9#0G(#T^(&%R<F%Y*#$S.2P@
M,3(Y+"`W-BDL"B`@("`G>65L;&]W,2<@/3X@87)R87DH,C4U+"`R-34L(#`I
M+`H@("`@)WEE;&QO=S(G(#T^(&%R<F%Y*#(S."P@,C,X+"`P*2P*("`@("=Y
M96QL;W<S)R`]/B!A<G)A>2@R,#4L(#(P-2P@,"DL"B`@("`G>65L;&]W-"<@
M/3X@87)R87DH,3,Y+"`Q,SDL(#`I+`H@("`@)V=O;&0Q)R`]/B!A<G)A>2@R
M-34L(#(Q-2P@,"DL"B`@("`G9V]L9#(G(#T^(&%R<F%Y*#(S."P@,C`Q+"`P
M*2P*("`@("=G;VQD,R<@/3X@87)R87DH,C`U+"`Q-S,L(#`I+`H@("`@)V=O
M;&0T)R`]/B!A<G)A>2@Q,SDL(#$Q-RP@,"DL"B`@("`G9V]L9&5N<F]D,2<@
M/3X@87)R87DH,C4U+"`Q.3,L(#,W*2P*("`@("=G;VQD96YR;V0R)R`]/B!A
M<G)A>2@R,S@L(#$X,"P@,S0I+`H@("`@)V=O;&1E;G)O9#,G(#T^(&%R<F%Y
M*#(P-2P@,34U+"`R.2DL"B`@("`G9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y
M+"`Q,#4L(#(P*2P*("`@("=D87)K9V]L9&5N<F]D,2<@/3X@87)R87DH,C4U
M+"`Q.#4L(#$U*2P*("`@("=D87)K9V]L9&5N<F]D,B<@/3X@87)R87DH,C,X
M+"`Q-S,L(#$T*2P*("`@("=D87)K9V]L9&5N<F]D,R<@/3X@87)R87DH,C`U
M+"`Q-#DL(#$R*2P*("`@("=D87)K9V]L9&5N<F]D-"<@/3X@87)R87DH,3,Y
M+"`Q,#$L(#@I+`H@("`@)W)O<WEB<F]W;C$G(#T^(&%R<F%Y*#(U-2P@,3DS
M+"`Q.3,I+`H@("`@)W)O<WEB<F]W;C(G(#T^(&%R<F%Y*#(S."P@,3@P+"`Q
M.#`I+`H@("`@)W)O<WEB<F]W;C,G(#T^(&%R<F%Y*#(P-2P@,34U+"`Q-34I
M+`H@("`@)W)O<WEB<F]W;C0G(#T^(&%R<F%Y*#$S.2P@,3`U+"`Q,#4I+`H@
M("`@)VEN9&EA;G)E9#$G(#T^(&%R<F%Y*#(U-2P@,3`V+"`Q,#8I+`H@("`@
M)VEN9&EA;G)E9#(G(#T^(&%R<F%Y*#(S."P@.3DL(#DY*2P*("`@("=I;F1I
M86YR960S)R`]/B!A<G)A>2@R,#4L(#@U+"`X-2DL"B`@("`G:6YD:6%N<F5D
M-"<@/3X@87)R87DH,3,Y+"`U."P@-3@I+`H@("`@)W-I96YN83$G(#T^(&%R
M<F%Y*#(U-2P@,3,P+"`W,2DL"B`@("`G<VEE;FYA,B<@/3X@87)R87DH,C,X
M+"`Q,C$L(#8V*2P*("`@("=S:65N;F$S)R`]/B!A<G)A>2@R,#4L(#$P-"P@
M-3<I+`H@("`@)W-I96YN830G(#T^(&%R<F%Y*#$S.2P@-S$L(#,X*2P*("`@
M("=B=7)L>7=O;V0Q)R`]/B!A<G)A>2@R-34L(#(Q,2P@,34U*2P*("`@("=B
M=7)L>7=O;V0R)R`]/B!A<G)A>2@R,S@L(#$Y-RP@,30U*2P*("`@("=B=7)L
M>7=O;V0S)R`]/B!A<G)A>2@R,#4L(#$W,"P@,3(U*2P*("`@("=B=7)L>7=O
M;V0T)R`]/B!A<G)A>2@Q,SDL(#$Q-2P@.#4I+`H@("`@)W=H96%T,2<@/3X@
M87)R87DH,C4U+"`R,S$L(#$X-BDL"B`@("`G=VAE870R)R`]/B!A<G)A>2@R
M,S@L(#(Q-BP@,3<T*2P*("`@("=W:&5A=#,G(#T^(&%R<F%Y*#(P-2P@,3@V
M+"`Q-3`I+`H@("`@)W=H96%T-"<@/3X@87)R87DH,3,Y+"`Q,C8L(#$P,BDL
M"B`@("`G=&%N,2<@/3X@87)R87DH,C4U+"`Q-C4L(#<Y*2P*("`@("=T86XR
M)R`]/B!A<G)A>2@R,S@L(#$U-"P@-S,I+`H@("`@)W1A;C,G(#T^(&%R<F%Y
M*#(P-2P@,3,S+"`V,RDL"B`@("`G=&%N-"<@/3X@87)R87DH,3,Y+"`Y,"P@
M-#,I+`H@("`@)V-H;V-O;&%T93$G(#T^(&%R<F%Y*#(U-2P@,3(W+"`S-BDL
M"B`@("`G8VAO8V]L871E,B<@/3X@87)R87DH,C,X+"`Q,3@L(#,S*2P*("`@
M("=C:&]C;VQA=&4S)R`]/B!A<G)A>2@R,#4L(#$P,BP@,CDI+`H@("`@)V-H
M;V-O;&%T930G(#T^(&%R<F%Y*#$S.2P@-CDL(#$Y*2P*("`@("=F:7)E8G)I
M8VLQ)R`]/B!A<G)A>2@R-34L(#0X+"`T."DL"B`@("`G9FER96)R:6-K,B<@
M/3X@87)R87DH,C,X+"`T-"P@-#0I+`H@("`@)V9I<F5B<FEC:S,G(#T^(&%R
M<F%Y*#(P-2P@,S@L(#,X*2P*("`@("=F:7)E8G)I8VLT)R`]/B!A<G)A>2@Q
M,SDL(#(V+"`R-BDL"B`@("`G8G)O=VXQ)R`]/B!A<G)A>2@R-34L(#8T+"`V
M-"DL"B`@("`G8G)O=VXR)R`]/B!A<G)A>2@R,S@L(#4Y+"`U.2DL"B`@("`G
M8G)O=VXS)R`]/B!A<G)A>2@R,#4L(#4Q+"`U,2DL"B`@("`G8G)O=VXT)R`]
M/B!A<G)A>2@Q,SDL(#,U+"`S-2DL"B`@("`G<V%L;6]N,2<@/3X@87)R87DH
M,C4U+"`Q-#`L(#$P-2DL"B`@("`G<V%L;6]N,B<@/3X@87)R87DH,C,X+"`Q
M,S`L(#DX*2P*("`@("=S86QM;VXS)R`]/B!A<G)A>2@R,#4L(#$Q,BP@.#0I
M+`H@("`@)W-A;&UO;C0G(#T^(&%R<F%Y*#$S.2P@-S8L(#4W*2P*("`@("=L
M:6=H='-A;&UO;C$G(#T^(&%R<F%Y*#(U-2P@,38P+"`Q,C(I+`H@("`@)VQI
M9VAT<V%L;6]N,B<@/3X@87)R87DH,C,X+"`Q-#DL(#$Q-"DL"B`@("`G;&EG
M:'1S86QM;VXS)R`]/B!A<G)A>2@R,#4L(#$R.2P@.3@I+`H@("`@)VQI9VAT
M<V%L;6]N-"<@/3X@87)R87DH,3,Y+"`X-RP@-C8I+`H@("`@)V]R86YG93$G
M(#T^(&%R<F%Y*#(U-2P@,38U+"`P*2P*("`@("=O<F%N9V4R)R`]/B!A<G)A
M>2@R,S@L(#$U-"P@,"DL"B`@("`G;W)A;F=E,R<@/3X@87)R87DH,C`U+"`Q
M,S,L(#`I+`H@("`@)V]R86YG930G(#T^(&%R<F%Y*#$S.2P@.3`L(#`I+`H@
M("`@)V1A<FMO<F%N9V4Q)R`]/B!A<G)A>2@R-34L(#$R-RP@,"DL"B`@("`G
M9&%R:V]R86YG93(G(#T^(&%R<F%Y*#(S."P@,3$X+"`P*2P*("`@("=D87)K
M;W)A;F=E,R<@/3X@87)R87DH,C`U+"`Q,#(L(#`I+`H@("`@)V1A<FMO<F%N
M9V4T)R`]/B!A<G)A>2@Q,SDL(#8Y+"`P*2P*("`@("=C;W)A;#$G(#T^(&%R
M<F%Y*#(U-2P@,3$T+"`X-BDL"B`@("`G8V]R86PR)R`]/B!A<G)A>2@R,S@L
M(#$P-BP@.#`I+`H@("`@)V-O<F%L,R<@/3X@87)R87DH,C`U+"`Y,2P@-CDI
M+`H@("`@)V-O<F%L-"<@/3X@87)R87DH,3,Y+"`V,BP@-#<I+`H@("`@)W1O
M;6%T;S$G(#T^(&%R<F%Y*#(U-2P@.3DL(#<Q*2P*("`@("=T;VUA=&\R)R`]
M/B!A<G)A>2@R,S@L(#DR+"`V-BDL"B`@("`G=&]M871O,R<@/3X@87)R87DH
M,C`U+"`W.2P@-3<I+`H@("`@)W1O;6%T;S0G(#T^(&%R<F%Y*#$S.2P@-30L
M(#,X*2P*("`@("=O<F%N9V5R960Q)R`]/B!A<G)A>2@R-34L(#8Y+"`P*2P*
M("`@("=O<F%N9V5R960R)R`]/B!A<G)A>2@R,S@L(#8T+"`P*2P*("`@("=O
M<F%N9V5R960S)R`]/B!A<G)A>2@R,#4L(#4U+"`P*2P*("`@("=O<F%N9V5R
M960T)R`]/B!A<G)A>2@Q,SDL(#,W+"`P*2P*("`@("=D965P<&EN:S$G(#T^
M(&%R<F%Y*#(U-2P@,C`L(#$T-RDL"B`@("`G9&5E<'!I;FLR)R`]/B!A<G)A
M>2@R,S@L(#$X+"`Q,S<I+`H@("`@)V1E97!P:6YK,R<@/3X@87)R87DH,C`U
M+"`Q-BP@,3$X*2P*("`@("=D965P<&EN:S0G(#T^(&%R<F%Y*#$S.2P@,3`L
M(#@P*2P*("`@("=H;W1P:6YK,2<@/3X@87)R87DH,C4U+"`Q,3`L(#$X,"DL
M"B`@("`G:&]T<&EN:S(G(#T^(&%R<F%Y*#(S."P@,3`V+"`Q-C<I+`H@("`@
M)VAO='!I;FLS)R`]/B!A<G)A>2@R,#4L(#DV+"`Q-#0I+`H@("`@)VAO='!I
M;FLT)R`]/B!A<G)A>2@Q,SDL(#4X+"`Y."DL"B`@("`G<&EN:S$G(#T^(&%R
M<F%Y*#(U-2P@,3@Q+"`Q.3<I+`H@("`@)W!I;FLR)R`]/B!A<G)A>2@R,S@L
M(#$V.2P@,3@T*2P*("`@("=P:6YK,R<@/3X@87)R87DH,C`U+"`Q-#4L(#$U
M."DL"B`@("`G<&EN:S0G(#T^(&%R<F%Y*#$S.2P@.3DL(#$P."DL"B`@("`G
M;&EG:'1P:6YK,2<@/3X@87)R87DH,C4U+"`Q-S0L(#$X-2DL"B`@("`G;&EG
M:'1P:6YK,B<@/3X@87)R87DH,C,X+"`Q-C(L(#$W,RDL"B`@("`G;&EG:'1P
M:6YK,R<@/3X@87)R87DH,C`U+"`Q-#`L(#$T.2DL"B`@("`G;&EG:'1P:6YK
M-"<@/3X@87)R87DH,3,Y+"`Y-2P@,3`Q*2P*("`@("=P86QE=FEO;&5T<F5D
M,2<@/3X@87)R87DH,C4U+"`Q,S`L(#$W,2DL"B`@("`G<&%L979I;VQE=')E
M9#(G(#T^(&%R<F%Y*#(S."P@,3(Q+"`Q-3DI+`H@("`@)W!A;&5V:6]L971R
M960S)R`]/B!A<G)A>2@R,#4L(#$P-"P@,3,W*2P*("`@("=P86QE=FEO;&5T
M<F5D-"<@/3X@87)R87DH,3,Y+"`W,2P@.3,I+`H@("`@)VUA<F]O;C$G(#T^
M(&%R<F%Y*#(U-2P@-3(L(#$W.2DL"B`@("`G;6%R;V]N,B<@/3X@87)R87DH
M,C,X+"`T."P@,38W*2P*("`@("=M87)O;VXS)R`]/B!A<G)A>2@R,#4L(#0Q
M+"`Q-#0I+`H@("`@)VUA<F]O;C0G(#T^(&%R<F%Y*#$S.2P@,C@L(#DX*2P*
M("`@("=V:6]L971R960Q)R`]/B!A<G)A>2@R-34L(#8R+"`Q-3`I+`H@("`@
M)W9I;VQE=')E9#(G(#T^(&%R<F%Y*#(S."P@-3@L(#$T,"DL"B`@("`G=FEO
M;&5T<F5D,R<@/3X@87)R87DH,C`U+"`U,"P@,3(P*2P*("`@("=V:6]L971R
M960T)R`]/B!A<G)A>2@Q,SDL(#,T+"`X,BDL"B`@("`G;6%G96YT83$G(#T^
M(&%R<F%Y*#(U-2P@,"P@,C4U*2P*("`@("=M86=E;G1A,B<@/3X@87)R87DH
M,C,X+"`P+"`R,S@I+`H@("`@)VUA9V5N=&$S)R`]/B!A<G)A>2@R,#4L(#`L
M(#(P-2DL"B`@("`G;6%G96YT830G(#T^(&%R<F%Y*#$S.2P@,"P@,3,Y*2P*
M("`@("=M961I=6UR960G(#T^(&%R<F%Y*#$T,"P@,S0L(#,T*2P*("`@("=O
M<F-H:60Q)R`]/B!A<G)A>2@R-34L(#$S,2P@,C4P*2P*("`@("=O<F-H:60R
M)R`]/B!A<G)A>2@R,S@L(#$R,BP@,C,S*2P*("`@("=O<F-H:60S)R`]/B!A
M<G)A>2@R,#4L(#$P-2P@,C`Q*2P*("`@("=O<F-H:60T)R`]/B!A<G)A>2@Q
M,SDL(#<Q+"`Q,S<I+`H@("`@)W!L=6TQ)R`]/B!A<G)A>2@R-34L(#$X-RP@
M,C4U*2P*("`@("=P;'5M,B<@/3X@87)R87DH,C,X+"`Q-S0L(#(S."DL"B`@
M("`G<&QU;3,G(#T^(&%R<F%Y*#(P-2P@,34P+"`R,#4I+`H@("`@)W!L=6TT
M)R`]/B!A<G)A>2@Q,SDL(#$P,BP@,3,Y*2P*("`@("=M961I=6UO<F-H:60Q
M)R`]/B!A<G)A>2@R,C0L(#$P,BP@,C4U*2P*("`@("=M961I=6UO<F-H:60R
M)R`]/B!A<G)A>2@R,#DL(#DU+"`R,S@I+`H@("`@)VUE9&EU;6]R8VAI9#,G
M(#T^(&%R<F%Y*#$X,"P@.#(L(#(P-2DL"B`@("`G;65D:75M;W)C:&ED-"<@
M/3X@87)R87DH,3(R+"`U-2P@,3,Y*2P*("`@("=D87)K;W)C:&ED,2<@/3X@
M87)R87DH,3DQ+"`V,BP@,C4U*2P*("`@("=D87)K;W)C:&ED,B<@/3X@87)R
M87DH,3<X+"`U."P@,C,X*2P*("`@("=D87)K;W)C:&ED,R<@/3X@87)R87DH
M,34T+"`U,"P@,C`U*2P*("`@("=D87)K;W)C:&ED-"<@/3X@87)R87DH,3`T
M+"`S-"P@,3,Y*2P*("`@("=P=7)P;&4Q)R`]/B!A<G)A>2@Q-34L(#0X+"`R
M-34I+`H@("`@)W!U<G!L93(G(#T^(&%R<F%Y*#$T-2P@-#0L(#(S."DL"B`@
M("`G<'5R<&QE,R<@/3X@87)R87DH,3(U+"`S."P@,C`U*2P*("`@("=P=7)P
M;&4T)R`]/B!A<G)A>2@X-2P@,C8L(#$S.2DL"B`@("`G;65D:75M<'5R<&QE
M,2<@/3X@87)R87DH,3<Q+"`Q,S`L(#(U-2DL"B`@("`G;65D:75M<'5R<&QE
M,B<@/3X@87)R87DH,34Y+"`Q,C$L(#(S."DL"B`@("`G;65D:75M<'5R<&QE
M,R<@/3X@87)R87DH,3,W+"`Q,#0L(#(P-2DL"B`@("`G;65D:75M<'5R<&QE
M-"<@/3X@87)R87DH.3,L(#<Q+"`Q,SDI+`H@("`@)W1H:7-T;&4Q)R`]/B!A
M<G)A>2@R-34L(#(R-2P@,C4U*2P*("`@("=T:&ES=&QE,B<@/3X@87)R87DH
M,C,X+"`R,3`L(#(S."DL"B`@("`G=&AI<W1L93,G(#T^(&%R<F%Y*#(P-2P@
M,3@Q+"`R,#4I+`H@("`@)W1H:7-T;&4T)R`]/B!A<G)A>2@Q,SDL(#$R,RP@
M,3,Y*2P*("`@("=G<F%Y,2<@/3X@87)R87DH,3`L(#$P+"`Q,"DL"B`@("`G
M9W)A>3(G(#T^(&%R<F%Y*#0P+"`T,"P@,S`I+`H@("`@)V=R87DS)R`]/B!A
M<G)A>2@W,"P@-S`L(#<P*2P*("`@("=G<F%Y-"<@/3X@87)R87DH,3`P+"`Q
M,#`L(#$P,"DL"B`@("`G9W)A>34G(#T^(&%R<F%Y*#$S,"P@,3,P+"`Q,S`I
M+`H@("`@)V=R87DV)R`]/B!A<G)A>2@Q-C`L(#$V,"P@,38P*2P*("`@("=G
M<F%Y-R<@/3X@87)R87DH,3DP+"`Q.3`L(#$Y,"DL"B`@("`G9W)A>3@G(#T^
M(&%R<F%Y*#(Q,"P@,C$P+"`R,3`I+`H@("`@)V=R87DY)R`]/B!A<G)A>2@R
M-#`L(#(T,"P@,C0P*2P*("`@("=D87)K9W)A>2<@/3X@87)R87DH,3`P+"`Q
M,#`L(#$P,"DL"B`@("`G9&%R:V)L=64G(#T^(&%R<F%Y*#`L(#`L(#$S.2DL
M"B`@("`G9&%R:V-Y86XG(#T^(&%R<F%Y*#`L(#$S.2P@,3,Y*2P*("`@("=D
M87)K;6%G96YT82<@/3X@87)R87DH,3,Y+"`P+"`Q,SDI+`H@("`@)V1A<FMR
M960G(#T^(&%R<F%Y*#$S.2P@,"P@,"DL"B`@("`G<VEL=F5R)R`]/B!A<G)A
M>2@Q.3(L("`Q.3(L("`Q.3(I+`H@("`@)V5G9W!L86YT)R`]/B!A<G)A>2@Q
M-#0L(#$W-BP@,38X*2P*("`@("=L:6=H=&=R965N)R`]/B!A<G)A>2@Q-#0L
M(#(S."P@,30T*0HI.PH`````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]S=F<N<&AP````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,38P,2`Q,#4Q
M-30S-#$S-R`P,C$W,#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,
M15]?*2`N("<O+BXO26UA9V4N<&AP)SL*<F5Q=6ER95]O;F-E("=834PO4U9'
M+G!H<"<["@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!(;W)D
M95]);6%G93HZ($%022!F;W(@4U9'+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]);6%G92]);6%G92]S=F<N<&AP+'8@,2XS,2XQ,"XV(#(P,#8O,#$O,#$@
M,C$Z,C@Z,C(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T
M:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T
M:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I
M;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL
M+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E
M7TEM86=E"B`J+PIC;&%S<R!(;W)D95]);6%G95]S=F<@97AT96YD<R!(;W)D
M95]);6%G92!["@H@("`@=F%R("1?<W9G.PH*("`@("\J*@H@("`@("H@0V%P
M86)I;&ET97,@;V8@=&AI<R!D<FEV97(N"B`@("`@*@H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)%]C87!A8FEL:71I97,@/2!A<G)A>2@G
M8V%N=F%S)RD["@H@("`@9G5N8W1I;VX@2&]R9&5?26UA9V5?<W9G*"1P87)A
M;7,I"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D95]);6%G92@D<&%R86US
M*3L*("`@("`@("`D=&AI<RT^7W-V9R`]("9N97<@6$U,7U-61U]$;V-U;65N
M="AA<G)A>2@G=VED=&@G(#T^("1T:&ES+3Y?=VED=&@L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAE:6=H
M="<@/3X@)'1H:7,M/E]H96EG:'0I*3L*("`@('T*"B`@("!F=6YC=&EO;B!G
M971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=I;6%G92]S
M=F<K>&UL)SL*("`@('T*"B`@("!F=6YC=&EO;B!G971,:6YK*"1U<FPL("1T
M:71L92`]("<G*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N(&1I<W!L87DH
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<W9G+3YP<FEN=$5L96UE;G0H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!T:&4@<F%W(&1A=&$@9F]R
M('1H:7,@:6UA9V4N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!R87<@:6UA9V4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F%W*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S=F<M/F)U9F9E<D]B:F5C
M="@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$9O;G0H)&9O;G0I"B`@("![
M"B`@("`@("`@<F5T=7)N("1F;VYT.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C
M<F5A=&53>6UB;VPH)',L("1I9"D*("`@('L*("`@("`@("`D<RT^<V5T4&%R
M86TH)VED)RP@)&ED*3L*("`@("`@("`D9&5F<R`]("9N97<@6$U,7U-61U]$
M969S*"D["B`@("`@("`@)&1E9G,M/F%D9$-H:6QD*"1S*3L*("`@("`@("`D
M=&AI<RT^7W-V9RT^861D0VAI;&0H)&1E9G,I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]C<F5A=&5$<F]P4VAA9&]W*"1I9"`]("=D<F]P4VAA9&]W)RD*("`@
M('L*("`@("`@("`D9&5F<R`]("9N97<@6$U,7U-61U]$969S*"D["B`@("`@
M("`@)&9I;'1E<B`]("9N97<@6$U,7U-61U]&:6QT97(H87)R87DH)VED)R`]
M/B`D:60I*3L*("`@("`@("`D9FEL=&5R+3YA9&10<FEM:71I=F4H)T=A=7-S
M:6%N0FQU<B<L(&%R<F%Y*"=I;B<@/3X@)U-O=7)C94%L<&AA)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=S=&1$979I871I;VXG(#T^(#(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F5S=6QT)R`]/B`G8FQU
M<B<I*3L*("`@("`@("`D9FEL=&5R+3YA9&10<FEM:71I=F4H)T]F9G-E="<L
M(&%R<F%Y*"=I;B<@/3X@)V)L=7(G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V1X)R`]/B`T+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1Y)R`]/B`T
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W)E<W5L="<@/3X@)V]F9G-E=$)L=7(G*2D["B`@("`@("`@)&UE<F=E
M(#T@)FYE=R!834Q?4U9'7T9I;'1E<E!R:6UI=&EV92@G365R9V4G*3L*("`@
M("`@("`D;65R9V4M/F%D9$UE<F=E3F]D92@G;V9F<V5T0FQU<B<I.PH@("`@
M("`@("1M97)G92T^861D365R9V5.;V1E*"=3;W5R8V5'<F%P:&EC)RD["@H@
M("`@("`@("1F:6QT97(M/F%D9$-H:6QD*"1M97)G92D["B`@("`@("`@)&1E
M9G,M/F%D9$-H:6QD*"1F:6QT97(I.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA
M9&1#:&EL9"@D9&5F<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A
M('1E>'0@<W1R:6YG(&]N('1H92!I;6%G92!I;B!A('-P96-I9FEE9"!L;V-A
M=&EO;BP@=VET:`H@("`@("H@=&AE('-P96-I9FEE9"!S='EL92!I;F9O<FUA
M=&EO;BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&5X="`@("`@
M("!4:&4@=&5X="!T;R!D<F%W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@
M("`@("`@("`@5&AE(&QE9G0@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="!O
M9B!T:&4@=&5X="!S=')I;F<N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@
M("`@("`@("!4:&4@=&]P('D@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0@;V8@
M=&AE('1E>'0@<W1R:6YG+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9O;G0@
M("`@("`@5&AE(&9O;G0@:61E;G1I9FEE<B!Y;W4@=V%N="!T;R!U<V4@9F]R
M('1H92!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("`@("`@
M5&AE(&-O;&]R('1H870@>6]U('=A;G0@=&AE('1E>'0@9&ES<&QA>65D(&EN
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@06X@:6YT96=E
M<B!T:&%T('-P96-I9FEE<R!T:&4@;W)I96YT871I;VX@;V8@=&AE('1E>'0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N('1E>'0H)'-T<FEN9RP@)'@L("1Y+"`D
M9F]N="`]("=M;VYO<W!A8V4G+"`D8V]L;W(@/2`G8FQA8VLG+"`D9&ER96-T
M:6]N(#T@,"D*("`@('L*("`@("`@("`D:&5I9VAT(#T@,3(["B`@("`@("`@
M)'-T>6QE(#T@)V9O;G0M9F%M:6QY.B<@+B`D9F]N="`N("<[9F]N="UH96EG
M:'0Z)R`N("1H96EG:'0@+B`G<'@[9FEL;#HG("X@)'1H:7,M/F=E=$AE>$-O
M;&]R*"1C;VQO<BD@+B`G.W1E>'0M86YC:&]R.G-T87)T.R<["B`@("`@("`@
M)'1R86YS9F]R;2`]("=R;W1A=&4H)R`N("1D:7)E8W1I;VX@+B`G+"<@+B`D
M>"`N("<L)R`N("1Y("X@)RDG.PH@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#
M:&EL9"AN97<@6$U,7U-61U]497AT*&%R<F%Y*"=T97AT)R`]/B`D<W1R:6YG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=X)R`]/B`H:6YT*21X+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Y)R`]/B`H:6YT
M*21Y("L@)&AE:6=H="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=')A;G-F;W)M)R`]/B`D=')A;G-F
M;W)M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=R!A(&-I<F-L92X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O;W)D:6YA=&4@;V8@=&AE(&-E
M;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@5&AE('D@8V]O
M<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D8V]L;W(@(%1H92!L:6YE(&-O;&]R(&]F('1H92!C:7)C
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;"`@(%1H92!C;VQO<B!T
M;R!F:6QL('1H92!C:7)C;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-I<F-L
M92@D>"P@)'DL("1R+"`D8V]L;W(L("1F:6QL(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H(65M<'1Y*"1F:6QL*2D@>PH@("`@("`@("`@("`D<W1Y;&4@
M/2`G9FEL;#HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1F:6QL*2`N("<[("<[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ
M;F]N93LG.PH@("`@("`@('T*("`@("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG
M("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED
M=&@Z,2<["@H@("`@("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,
M7U-61U]#:7)C;&4H87)R87DH)V-X)R`]/B`D>"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C>2<@
M/3X@)'DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<B<@/3X@)'(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G
M(#T^("1S='EL92DI*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!P
M;VQY9V]N(&)A<V5D(&]N(&$@<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@86YD
M('D@;&%B96QE9"!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("AE9RX@)'9E<G1I8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP75LG>2==
M+"`N+BXI+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O
M;&]R('EO=2!W86YT('1O(&1R87<@=&AE('!O;'EG;VX@=VET:"X*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H
M92!P;VQY9V]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T
M<RP@)&-O;&]R+"`D9FEL;"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%E
M;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N
M("1T:&ES+3YG971(97A#;VQO<B@D9FEL;"D@+B`G.R`G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1S='EL92`]("=F:6QL.FYO;F4[)SL*("`@
M("`@("!]"B`@("`@("`@)'-T>6QE("X]("=S=')O:V4Z)R`N("1T:&ES+3YG
M971(97A#;VQO<B@D8V]L;W(I("X@)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@
M("`@("`D<&]I;G1S(#T@)R<["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S
M("1V*2!["B`@("`@("`@("`@("1P;VEN=',@+CT@)'9;)W@G72`N("<L)R`N
M("1V6R=Y)UT@+B`G("<["B`@("`@("`@?0H@("`@("`@("1P;VEN=',@/2!T
M<FEM*"1P;VEN=',I.PH*("`@("`@("`D=&AI<RT^7W-V9RT^861D0VAI;&0H
M;F5W(%A-3%]35D=?4&]L>6=O;BAA<G)A>2@G<&]I;G1S)R`]/B`D<&]I;G1S
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S='EL92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@
M;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y("`@
M("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@=&AE
M(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@(%1H
M92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@
M9FEL;"!T:&4@<F5C=&%N9VQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-T
M86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<BP@)&9I;&P@
M/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)&9I;&PI*2!["B`@
M("`@("`@("`@("1S='EL92`]("=F:6QL.B<@+B`D=&AI<RT^9V5T2&5X0V]L
M;W(H)&9I;&PI("X@)SL@)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<W1Y;&4@/2`G9FEL;#IN;VYE.R<["B`@("`@("`@?0H@("`@("`@("1S
M='EL92`N/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H)&-O;&]R
M*2`N("<[('-T<F]K92UW:61T:#HQ)SL*"B`@("`@("`@)'1H:7,M/E]S=F<M
M/F%D9$-H:6QD*&YE=R!834Q?4U9'7U)E8W0H87)R87DH)W@G(#T^("1X+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=Y)R`]/B`D>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G=VED=&@G(#T^("1W:61T:"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:&5I9VAT)R`]/B`D:&5I9VAT+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL92<@
M/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E
M8W1A;F=L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@
M("!4:&4@;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN
M871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M=VED=&@@("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A
M;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R;W5N9"`@(%1H92!W:61T
M:"!O9B!T:&4@8V]R;F5R(')O=6YD:6YG+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&-O;&]R("`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(')E8W1A;F=L92X*
M("`@("`J($!P87)A;2!S=')I;F<@("1F:6QL("`@(%1H92!C;VQO<B!T;R!F
M:6QL('1H92!R96-T86YG;&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=6YD
M961296-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1R;W5N9"P@
M)&-O;&]R+"`D9FEL;"D*("`@('L*("`@("`@("!I9B`H(65M<'1Y*"1F:6QL
M*2D@>PH@("`@("`@("`@("`D<W1Y;&4@/2`G9FEL;#HG("X@)'1H:7,M/F=E
M=$AE>$-O;&]R*"1F:6QL*2`N("<[("<["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ;F]N93LG.PH@("`@("`@('T*("`@
M("`@("`D<W1Y;&4@+CT@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R
M*"1C;VQO<BD@+B`G.R!S=')O:V4M=VED=&@Z,2<["@H@("`@("`@("1T:&ES
M+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]296-T*&%R<F%Y*"=X)R`]
M/B`D>"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G>2<@/3X@)'DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)X)R`]/B`D<F]U
M;F0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)Y)R`]/B`D<F]U;F0L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=I9'1H)R`]
M/B`D=VED=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VAE:6=H="<@/3X@)&AE:6=H="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G<W1Y;&4G(#T^("1S='EL92DI*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1R87<@82!L:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M,"`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>3`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE
M('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q("`@("!4:&4@>"!C
M;V]R9&EN871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>3$@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&-O;&]R("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1W:61T:"`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;&EN92@D>#$L("1Y,2P@)'@R+"`D>3(L
M("1C;VQO<B`]("=B;&%C:R<L("1W:61T:"`](#$I"B`@("!["B`@("`@("`@
M)'-T>6QE(#T@)W-T<F]K93HG("X@)'1H:7,M/F=E=$AE>$-O;&]R*"1C;VQO
M<BD@+B`G.R!S=')O:V4M=VED=&@Z)R`N("AI;G0I)'=I9'1H.PH@("`@("`@
M("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U],:6YE*&%R<F%Y
M*"=X,2<@/3X@)'@Q+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=Y,2<@/3X@)'DQ+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X
M,B<@/3X@)'@R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=Y,B<@/3X@)'DR+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S='EL
M92<@/3X@)'-T>6QE*2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A
M(&1A<VAE9"!L:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M,"`@("`@("`@("`@5&AE('@@8V]O<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@("`@("`@(%1H92!Y(&-O;W)D
M:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@Q
M("`@("`@("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!E;F0N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>3$@("`@("`@("`@(%1H92!Y(&-O;W)D:6YA
M=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@("1C;VQO<B`@
M("`@("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M=VED=&@@("`@("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1D87-H7VQE;F=T:"`@5&AE(&QE;F=T:"!O9B!A(&1A
M<V@@;VX@=&AE(&1A<VAE9"!L:6YE"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M9&%S:%]S<&%C92`@(%1H92!L96YG=&@@;V8@82!S<&%C92!I;B!T:&4@9&%S
M:&5D(&QI;F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&%S:&5D3&EN92@D>#$L
M("1Y,2P@)'@R+"`D>3(L("1C;VQO<B`]("=B;&%C:R<L("1W:61T:"`](#$L
M("1D87-H7VQE;F=T:"`](#(L("1D87-H7W-P86-E(#T@,BD*("`@('L*("`@
M("`@("`D<W1Y;&4@/2`G<W1R;VME.B<@+B`D=&AI<RT^9V5T2&5X0V]L;W(H
M)&-O;&]R*2`N("<[('-T<F]K92UW:61T:#HG("X@*&EN="DD=VED=&@@+B`G
M.R!S=')O:V4M9&%S:&%R<F%Y.B<@+B`D9&%S:%]L96YG=&@@+B`G+"<@+B`D
M9&%S:%]S<&%C92`N("<[)SL*("`@("`@("`D=&AI<RT^7W-V9RT^861D0VAI
M;&0H;F5W(%A-3%]35D=?3&EN92AA<G)A>2@G>#$G(#T^("1X,2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G>3$G(#T^("1Y,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G>#(G(#T^("1X,BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M>3(G(#T^("1Y,BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY;&EN92`H82!N;VXM8VQO
M<V5D+"!N;VXM9FEL;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*("`@("`J('-E
M="!O9B!V97)T:6-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'9E
M<G1I8V5S("!!;B!A<G)A>2!O9B!X(&%N9"!Y(&QA8F5L960@87)R87ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`H96<N("1V97)T:6-E<ULP
M75LG>"==+"`D=F5R=&EC97-;,%U;)WDG72P@+BXN*2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-O;&]R("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W
M('1H92!L:6YE('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@
M("!4:&4@=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('!O;'EL:6YE*"1V97)T<RP@)&-O;&]R+"`D=VED=&@@/2`Q*0H@("`@>PH@
M("`@("`@("1S='EL92`]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO
M<B@D8V]L;W(I("X@)SL@<W1R;VME+7=I9'1H.B<@+B`D=VED=&@@+B`G.V9I
M;&PZ;F]N93LG.PH*("`@("`@("`O+R!#86QC=6QA=&4@=&AE('!A=&@@96YT
M<GDN"B`@("`@("`@)'!A=&@@/2`G)SL*"B`@("`@("`@)&9I<G-T(#T@=')U
M93L*("`@("`@("!F;W)E86-H("@D=F5R=',@87,@)'9E<G0I('L*("`@("`@
M("`@("`@:68@*"1F:7)S="D@>PH@("`@("`@("`@("`@("`@)&9I<G-T(#T@
M9F%L<V4["B`@("`@("`@("`@("`@("`D<&%T:"`N/2`G32`G("X@)'9E<G1;
M)W@G72`N("<L)R`N("1V97)T6R=Y)UT["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<&%T:"`N/2`G($P@)R`N("1V97)T6R=X)UT@
M+B`G+"<@+B`D=F5R=%LG>2==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7W-V9RT^861D0VAI;&0H;F5W(%A-3%]35D=?4&%T
M:"AA<G)A>2@G9"<@/3X@)'!A=&@L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`D<W1Y
M;&4I*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&%N(&%R8RX*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@(%1H92!X(&-O;W)D
M:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y
M("`@("`@5&AE('D@8V]O<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L
M92!O9B!T:&4@87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4
M:&4@96YD(&%N9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D8V]L;W(@(%1H92!L:6YE(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D9FEL;"`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A
M<F,@*&1E9F%U;'1S('1O(&YO;F4I+@H@("`@("HO"B`@("!F=6YC=&EO;B!A
M<F,H)'@L("1Y+"`D<BP@)'-T87)T+"`D96YD+"`D8V]L;W(@/2`G8FQA8VLG
M+"`D9FEL;"`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D9FEL
M;"DI('L*("`@("`@("`@("`@)'-T>6QE(#T@)V9I;&PZ)R`N("1T:&ES+3YG
M971(97A#;VQO<B@D9FEL;"D@+B`G.R`G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S='EL92`]("=F:6QL.FYO;F4[)SL*("`@("`@("!]"B`@
M("`@("`@)'-T>6QE("X]("=S=')O:V4Z)R`N("1T:&ES+3YG971(97A#;VQO
M<B@D8V]L;W(I("X@)SL@<W1R;VME+7=I9'1H.C$G.PH*("`@("`@("`D;6ED
M(#T@<F]U;F0H*"1S=&%R="`K("1E;F0I("\@,BD["@H@("`@("`@("\O($-A
M;&-U;&%T92!T:&4@<&%T:"!E;G1R>2X*("`@("`@("`D<&%T:"`]("<G.PH*
M("`@("`@("`O+R!)9B!F:6QL960L(&1R87<@=&AE(&]U=&QI;F4N"B`@("`@
M("`@:68@*"%E;7!T>2@D9FEL;"DI('L*("`@("`@("`@("`@+R\@4W1A<G0@
M870@=&AE(&-E;G1E<B!O9B!T:&4@96QL:7!S92!T:&4@87)C(&ES(&]N+@H@
M("`@("`@("`@("`D<&%T:"`N/2`B32`D>"PD>2`B.PH*("`@("`@("`@("`@
M+R\@1')A=R!O=70@=&\@96QL:7!S92!E9&=E+@H@("`@("`@("`@("!L:7-T
M*"1A<F-8+"`D87)C62D@/2`D=&AI<RT^7V-I<F-L95!O:6YT*"1S=&%R="P@
M)'(@*B`R*3L*("`@("`@("`@("`@)'!A=&@@+CT@)TP@)R`N(')O=6YD*"1X
M("L@)&%R8U@I("X@)RPG("X*("`@("`@("`@("`@("`@(')O=6YD*"1Y("L@
M)&%R8UDI("X@)R`G.PH@("`@("`@('T*"B`@("`@("`@+R\@1')A=R!A<F-S
M+@H@("`@("`@(&QI<W0H)&%R8U@L("1A<F-9*2`]("1T:&ES+3Y?8VER8VQE
M4&]I;G0H)&UI9"P@)'(@*B`R*3L*("`@("`@("`D<&%T:"`N/2`B02`D<BPD
M<B`P(#`@,2`B("X*("`@("`@("`@("`@<F]U;F0H)'@@*R`D87)C6"D@+B`G
M+"<@+@H@("`@("`@("`@("!R;W5N9"@D>2`K("1A<F-9*2`N("<@)SL*"B`@
M("`@("`@;&ES="@D87)C6"P@)&%R8UDI(#T@)'1H:7,M/E]C:7)C;&50;VEN
M="@D96YD+"`D<B`J(#(I.PH@("`@("`@("1P871H("X](")!("1R+"1R(#`@
M,"`Q("(@+@H@("`@("`@("`@("!R;W5N9"@D>"`K("1A<F-8*2`N("<L)R`N
M"B`@("`@("`@("`@(')O=6YD*"1Y("L@)&%R8UDI("X@)R`G.PH*("`@("`@
M("`O+R!)9B!F:6QL960L(&-L;W-E('1H92!O=71L:6YE+@H@("`@("`@(&EF
M("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@("1P871H("X]("=:)SL*
M("`@("`@("!]"@H@("`@("`@("1P871H(#T@=')I;2@D<&%T:"D["@H@("`@
M("`@("1T:&ES+3Y?<W9G+3YA9&1#:&EL9"AN97<@6$U,7U-61U]0871H*&%R
M<F%Y*"=D)R`]/B`D<&%T:"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("1S='EL92DI
M*3L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]S
M=V8N<&AP````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M-#<P-"`Q,#4Q-30S-#$S-R`P,C$W,3``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXO26UA9V4N<&AP)SL*"B\J*@H@*B!4:&ES
M(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E7TEM86=E.CH@05!)(&9O<B!3
M5T8L('5S:6YG('1H92!02%`*("H@36EN9R!E>'1E;G-I;VXN"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+TEM86=E+TEM86=E+W-W9BYP:'`L=B`Q+C(T+C$P
M+C8@,C`P-B\P,2\P,2`R,3HR.#HR,B!J86X@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?26UA9V4*("HO"F-L87-S($AO<F1E7TEM86=E7W-W
M9B!E>'1E;F1S($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@("`J($-A<&%B
M:6QI=&5S(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R87DH)V-A
M;G9A<R<I.PH*("`@("\J*@H@("`@("H@4U=&(')O;W0@;6]V:64N"B`@("`@
M*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)%]M;W9I
M93L*"B`@("!F=6YC=&EO;B!(;W)D95]);6%G95]S=V8H)'!A<F%M<RD*("`@
M('L*("`@("`@("!P87)E;G0Z.DAO<F1E7TEM86=E*"1P87)A;7,I.PH*("`@
M("`@("`D=&AI<RT^7VUO=FEE(#T@)FYE=R!35T9-;W9I92@I.PH@("`@("`@
M("1T:&ES+3Y?;6]V:64M/G-E=$1I;65N<VEO;B@D=&AI<RT^7W=I9'1H+"`D
M=&AI<RT^7VAE:6=H="D["@H@("`@("`@("\O($9)6$U%.B!H;VYO<B!T:&4@
M)V)A8VMG<F]U;F0G('!A<F%M971E<B!H97)E+@H@("`@("`@("1T:&ES+3Y?
M;6]V:64M/G-E=$)A8VMG<F]U;F0H,'AF9BP@,'AF9BP@,'AF9BD["B`@("`@
M("`@)'1H:7,M/E]M;W9I92T^<V5T4F%T92@S,"D["B`@("!]"@H@("`@9G5N
M8W1I;VX@9V5T0V]N=&5N=%1Y<&4H*0H@("`@>PH@("`@("`@(')E='5R;B`G
M87!P;&EC871I;VXO>"US:&]C:W=A=F4M9FQA<V@G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&ES<&QA>2!T:&4@;6]V:64N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1I<W!L87DH*0H@("`@>PH@("`@("`@("1T:&ES+3YH96%D97)S*"D[
M"B`@("`@("`@)'1H:7,M/E]M;W9I92T^;W5T<'5T*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@=&AE(')A=R!D871A(&9O<B!T:&ES(&EM86=E
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@<F%W(&EM86=E
M(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(')A=R@I"B`@("!["B`@("`@
M("`@;V)?<W1A<G0H*3L*("`@("`@("`D=&AI<RT^7VUO=FEE+3YO=71P=70H
M*3L*("`@("`@("`D9&%T82`](&]B7V=E=%]C;VYT96YT<R@I.PH@("`@("`@
M(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@8V]L;W(@=&AA="!C86X@8F4@
M86-C97-S960@:6X@=&AI<R!O8FIE8W0N(%=H96X@80H@("`@("H@8V]L;W(@
M:7,@<V5T+"!T:&4@<F=B82!V86QU97,@87)E(')E='5R;F5D(&EN(&%N(&%R
M<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N
M86UE(&]F('1H92!C;VQO<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!4:&4@<F5D+"!G<F5E;BP@8FQU92P@86QP:&$@=F%L=65S(&]F('1H92!C
M;VQO<BX*("`@("`J+PH@("`@9G5N8W1I;VX@86QL;V-A=&5#;VQO<B@D;F%M
M92D*("`@('L*("`@("`@("!L:7-T*"1R+"`D9RP@)&(I(#T@)'1H:7,M/F=E
M=%)'0B@D;F%M92D["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=R960G(#T^("1R
M+`H@("`@("`@("`@("`@("`@("`@("`G9W)E96XG(#T^("1G+`H@("`@("`@
M("`@("`@("`@("`@("`G8FQU92<@/3X@)&(L"B`@("`@("`@("`@("`@("`@
M("`@("=A;'!H82<@/3X@,C4U*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971&
M;VYT*"1F;VYT*0H@("`@>PH@("`@("`@('-W:71C:"`H)&9O;G0I('L*("`@
M("`@("!C87-E("=S86YS+7-E<FEF)SH*("`@("`@("`@("`@<F5T=7)N("=?
M<V%N<R<["@H@("`@("`@(&-A<V4@)W-E<FEF)SH*("`@("`@("`@("`@<F5T
M=7)N("=?<V5R:68G.PH*("`@("`@("!C87-E("=M;VYO<W!A8V4G.@H@("`@
M("`@("`@("!R971U<FX@)U]T>7!E=W)I=&5R)SL*"B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@<F5T=7)N("1F;VYT.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87=S(&$@=&5X="!S=')I;F<@;VX@=&AE(&EM
M86=E(&EN(&$@<W!E8VEF:65D(&QO8V%T:6]N+"!W:71H"B`@("`@*B!T:&4@
M<W!E8VEF:65D('-T>6QE(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@("1T97AT("`@("`@(%1H92!T97AT('1O(&1R87<N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("`@("!4:&4@;&5F="!X(&-O
M;W)D:6YA=&4@;V8@=&AE('-T87)T(&]F('1H92!T97AT('-T<FEN9RX*("`@
M("`J($!P87)A;2!I;G1E9V5R("1Y("`@("`@("`@(%1H92!T;W`@>2!C;V]R
M9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4@=&5X="!S=')I;F<N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("`D9F]N="`@("`@("!4:&4@9F]N="!I9&5N=&EF
M:65R('EO=2!W86YT('1O('5S92!F;W(@=&AE('1E>'0N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D8V]L;W(@("`@("!4:&4@8V]L;W(@=&AA="!Y;W4@=V%N
M="!T:&4@=&5X="!D:7-P;&%Y960@:6XN"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9&ER96-T:6]N("!!;B!I;G1E9V5R('1H870@<W!E8VEF:65S('1H92!O
M<FEE;G1A=&EO;B!O9B!T:&4@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=&5X="@D<W1R:6YG+"`D>"P@)'DL("1F;VYT(#T@)VUO;F]S<&%C92<L("1C
M;VQO<B`]("=B;&%C:R<L("1D:7)E8W1I;VX@/2`P*0H@("`@>PH@("`@("`@
M("1C;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["@H@("`@
M("`@(&EF("AS=6)S='(H4$A07T]3+"`P+"`S*2`]/2`G5TE.)RD@>PH@("`@
M("`@("`@("`D=&5X="`]("9N97<@4U=&5&5X=$9I96QD*%-71E1%6%1&245,
M1%].3T5$250I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T97AT
M(#T@)FYE=R!35T9497AT*"D["B`@("`@("`@?0H@("`@("`@("1T97AT+3YS
M971#;VQO<B@D8V]L;W);)W)E9"==+"`D8V]L;W);)V=R965N)UTL("1C;VQO
M<ELG8FQU92==+"`D8V]L;W);)V%L<&AA)UTI.PH@("`@("`@("1T97AT+3YA
M9&13=')I;F<H)'-T<FEN9RD["B`@("`@("`@)'1E>'0M/G-E=$9O;G0H;F5W
M(%-71D9O;G0H)'1H:7,M/F=E=$9O;G0H)&9O;G0I*2D["@H@("`@("`@("1T
M(#T@)'1H:7,M/E]M;W9I92T^861D*"1T97AT*3L*("`@("`@("`D="T^;6]V
M951O*"1X+"`D>2D["B`@("`@("`@)'0M/G)O=&%T92@D9&ER96-T:6]N*3L*
M"B`@("`@("`@<F5T=7)N("1T.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A
M=R!A(&-I<F-L92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@
M("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>2`@("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H
M92!C96YT<F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@(%1H92!R
M861I=7,@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I;F<@("1C
M;VQO<B`@5&AE(&QI;F4@8V]L;W(@;V8@=&AE(&-I<F-L92X*("`@("`J($!P
M87)A;2!S=')I;F<@("1F:6QL("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(&-I
M<F-L92X*("`@("`J+PH@("`@9G5N8W1I;VX@8VER8VQE*"1X+"`D>2P@)'(L
M("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@("`@)',@/2`F
M;F5W(%-71E-H87!E*"D["B`@("`@("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C
M871E0V]L;W(H)&-O;&]R*3L*("`@("`@("`D<RT^<V5T3&EN92@Q+"`D8V]L
M;W);)W)E9"==+"`D8V]L;W);)V=R965N)UTL("1C;VQO<ELG8FQU92==+"`D
M8V]L;W);)V%L<&AA)UTI.PH*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G
M*2!["B`@("`@("`@("`@("1F:6QL0V]L;W(@/2`D=&AI<RT^86QL;V-A=&5#
M;VQO<B@D9FEL;"D["B`@("`@("`@("`@("1F(#T@)',M/F%D9$9I;&PH)&9I
M;&Q#;VQO<ELG<F5D)UTL("1F:6QL0V]L;W);)V=R965N)UTL("1F:6QL0V]L
M;W);)V)L=64G72P@)&9I;&Q#;VQO<ELG86QP:&$G72D["B`@("`@("`@("`@
M("1S+3YS9712:6=H=$9I;&PH)&8I.PH@("`@("`@('T*"B`@("`@("`@)&$@
M/2`D<B`J(#`N-#$T,C$S-38R.R`O+R`]('1A;B@R,BXU(&1E9RD*("`@("`@
M("`D8B`]("1R("H@,"XW,#<Q,#8W.#$[("\O(#T@<W%R="@R*2\R(#T@<VEN
M*#0U(&1E9RD*"B`@("`@("`@)',M/FUO=F5096Y4;R@D>"`K("1R+"`D>2D[
M"@H@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`K("1R+"`D>2`M("1A+"`D
M>"`K("1B+"`D>2`M("1B*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@
M*R`D82P@)'D@+2`D<BP@)'@L("1Y("T@)'(I.PH@("`@("`@("1S+3YD<F%W
M0W5R=F54;R@D>"`M("1A+"`D>2`M("1R+"`D>"`M("1B+"`D>2`M("1B*3L*
M("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@+2`D<BP@)'D@+2`D82P@)'@@
M+2`D<BP@)'DI.PH@("`@("`@("1S+3YD<F%W0W5R=F54;R@D>"`M("1R+"`D
M>2`K("1A+"`D>"`M("1B+"`D>2`K("1B*3L*("`@("`@("`D<RT^9')A=T-U
M<G9E5&\H)'@@+2`D82P@)'D@*R`D<BP@)'@L("1Y("L@)'(I.PH@("`@("`@
M("1S+3YD<F%W0W5R=F54;R@D>"`K("1A+"`D>2`K("1R+"`D>"`K("1B+"`D
M>2`K("1B*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@@*R`D<BP@)'D@
M*R`D82P@)'@@*R`D<BP@)'DI.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]M
M;W9I92T^861D*"1S*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!P
M;VQY9V]N(&)A<V5D(&]N(&$@<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@86YD
M('D@;&%B96QE9"!A<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("AE9RX@)'9E<G1I8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP75LG>2==
M+"`N+BXI+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O
M;&]R('EO=2!W86YT('1O(&1R87<@=&AE('!O;'EG;VX@=VET:"X*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H
M92!P;VQY9V]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T
M<RP@)&-O;&]R+"`D9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D8V]L
M;W(@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D8V]L;W(I.PH*("`@("`@("!I
M9B`H:7-?87)R87DH)&-O;&]R*2`F)B!I<U]A<G)A>2@D=F5R=',I("8F("AS
M:7IE;V8H)'9E<G1S*2`^(#(I*2!["B`@("`@("`@("`@("1S:&%P92`]("9N
M97<@4U=&4VAA<&4H*3L*("`@("`@("`@("`@)'-H87!E+3YS971,:6YE*#$L
M("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E
M)UTL("1C;VQO<ELG86QP:&$G72D["@H@("`@("`@("`@("!I9B`H)&9I;&P@
M(3T@)VYO;F4G*2!["B`@("`@("`@("`@("`@("`D9FEL;$-O;&]R(#T@)'1H
M:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@("`@("`@("`@)&8@
M/2`D<VAA<&4M/F%D9$9I;&PH)&9I;&Q#;VQO<ELG<F5D)UTL("1F:6QL0V]L
M;W);)V=R965N)UTL("1F:6QL0V]L;W);)V)L=64G72P@)&9I;&Q#;VQO<ELG
M86QP:&$G72D["B`@("`@("`@("`@("`@("`D<VAA<&4M/G-E=%)I9VAT1FEL
M;"@D9BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:7)S=%]D;VYE
M(#T@9F%L<V4["B`@("`@("`@("`@(&9O<F5A8V@@*"1V97)T<R!A<R`D=F%L
M=64I('L*("`@("`@("`@("`@("`@(&EF("@A)&9I<G-T7V1O;F4I('L*("`@
M("`@("`@("`@("`@("`@("`D<VAA<&4M/FUO=F5096Y4;R@D=F%L=65;)W@G
M72P@)'9A;'5E6R=Y)UTI.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=%]D
M;VYE(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`D9FER<W1?>"`]("1V
M86QU95LG>"==.PH@("`@("`@("`@("`@("`@("`@("1F:7)S=%]Y(#T@)'9A
M;'5E6R=Y)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<VAA<&4M/F1R87=,:6YE5&\H)'9A;'5E6R=X)UTL("1V86QU95LG>2==*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D<VAA<&4M/F1R87=,:6YE5&\H
M)&9I<G-T7W@L("1F:7)S=%]Y*3L*"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUO=FEE+3YA9&0H)'-H87!E*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!)9B!T:&4@8V]L;W(@:7,@86X@87)R87D@86YD('1H92!V
M97)T:6-E<R!I<R!A(&%N(&%R<F%Y"B`@("`@("`@("`@("\O(&]F(&UO<F4@
M=&AA;B`R('!O:6YT<RX*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG;&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE
M9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T
M:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@
M5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("!4:&4@;&EN92!C;VQO<B!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@
M("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5C=&%N9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT
M+"`D8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@("1V97)T
M<ULP72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y*3L*("`@("`@("`D
M=F5R='-;,5T@/2!A<G)A>2@G>"<@/3X@)'@@*R`D=VED=&@L("=Y)R`]/B`D
M>2D["B`@("`@("`@)'9E<G1S6S)=(#T@87)R87DH)W@G(#T^("1X("L@)'=I
M9'1H+"`G>2<@/3X@)'D@*R`D:&5I9VAT*3L*("`@("`@("`D=F5R='-;,UT@
M/2!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2`K("1H96EG:'0I.PH*("`@
M("`@("!R971U<FX@)'1H:7,M/G!O;'EG;VXH)'9E<G1S+"`D8V]L;W(L("1F
M:6QL*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!R96-T86YG;&4N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@5&AE(&QE
M9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O<F1I;F%T92!O9B!T
M:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'=I9'1H("`@
M5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R96-T86YG;&4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<F]U;F0@("!4:&4@=VED=&@@;V8@=&AE
M(&-O<FYE<B!R;W5N9&EN9RX*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R
M("`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@
M<F5C=&%N9VQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;W5N9&5D4F5C=&%N
M9VQE*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D<F]U;F0L("1C;VQO<B`]
M("=B;&%C:R<L("1F:6QL(#T@)VYO;F4G*0H@("`@>PH@("`@("`@(&EF("@D
M<F]U;F0@/#T@,"D@>PH@("`@("`@("`@("`O+R!/<'1I;6EZ92!O=70@86YY
M(&-A;&QS('=I=&@@;F\@8V]R;F5R(')O=6YD:6YG+@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@)&AE:6=H
M="P@)&-O;&]R+"`D9FEL;"D["B`@("`@("`@?0H*("`@("`@("`D<R`]("9N
M97<@4U=&4VAA<&4H*3L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A
M=&5#;VQO<B@D8V]L;W(I.PH@("`@("`@("1S+3YS971,:6YE*#$L("1C;VQO
M<ELG<F5D)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C
M;VQO<ELG86QP:&$G72D["@H@("`@("`@(&EF("@D9FEL;"`A/2`G;F]N92<I
M('L*("`@("`@("`@("`@)&9I;&Q#;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1F:6QL*3L*("`@("`@("`@("`@)&8@/2`D<RT^861D1FEL;"@D9FEL
M;$-O;&]R6R=R960G72P@)&9I;&Q#;VQO<ELG9W)E96XG72P@)&9I;&Q#;VQO
M<ELG8FQU92==+"`D9FEL;$-O;&]R6R=A;'!H82==*3L*("`@("`@("`@("`@
M)',M/G-E=%)I9VAT1FEL;"@D9BD["B`@("`@("`@?0H*("`@("`@("`O+R!3
M970@8V]R;F5R('!O:6YT<R!T;R!A=F]I9"!L;W1S(&]F(')E9'5N9&%N="!M
M871H+@H@("`@("`@("1X,2`]("1X("L@)')O=6YD.PH@("`@("`@("1Y,2`]
M("1Y("L@)')O=6YD.PH*("`@("`@("`D>#(@/2`D>"`K("1W:61T:"`M("1R
M;W5N9#L*("`@("`@("`D>3(@/2`D>2`K("1R;W5N9#L*"B`@("`@("`@)'@S
M(#T@)'@@*R`D=VED=&@@+2`D<F]U;F0["B`@("`@("`@)'DS(#T@)'D@*R`D
M:&5I9VAT("T@)')O=6YD.PH*("`@("`@("`D>#0@/2`D>"`K("1R;W5N9#L*
M("`@("`@("`D>30@/2`D>2`K("1H96EG:'0@+2`D<F]U;F0["@H@("`@("`@
M("\O(%-T87)T(&EN('1H92!U<'!E<B!L969T+@H@("`@("`@("1P,2`]("1T
M:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,3@P+"`R,C4I.PH@("`@("`@("1P
M,B`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,C(U+"`R-S`I.PH*("`@
M("`@("`O+R!3=&%R="!A="!T:&4@;&]W97(@;&5F="!C;W)N97(@;V8@=&AE
M('1O<"!L969T(&-U<G9E+@H@("`@("`@("1S+3YM;W9E4&5N5&\H)'@Q("L@
M)'`Q6R=X,2==+"`D>3$@*R`D<#%;)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W
M('1H92!U<'!E<B!L969T(&-O<FYE<BX*("`@("`@("`D<RT^9')A=T-U<G9E
M5&\H)'@Q("L@)'`Q6R=X,R==+"`D>3$@*R`D<#%;)WDS)UTL("1X,2`K("1P
M,5LG>#(G72P@)'DQ("L@)'`Q6R=Y,B==*3L*("`@("`@("`D<RT^9')A=T-U
M<G9E5&\H)'@Q("L@)'`R6R=X,R==+"`D>3$@*R`D<#);)WDS)UTL("1X,2`K
M("1P,ELG>#(G72P@)'DQ("L@)'`R6R=Y,B==*3L*"B`@("`@("`@+R\@0V%L
M8W5L871E('1H92!U<'!E<B!R:6=H="!P;VEN=',N"B`@("`@("`@)'`S(#T@
M)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`R-S`L(#,Q-2D["B`@("`@("`@
M)'`T(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`S,34L(#,V,"D["@H@
M("`@("`@("\O($-O;FYE8W0@=&AE('1O<"!L969T(&%N9"!R:6=H="!C=7)V
M97,N"B`@("`@("`@)',M/F1R87=,:6YE5&\H)'@R("L@)'`S6R=X,2==+"`D
M>3(@*R`D<#-;)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W('1H92!U<'!E<B!R
M:6=H="!C;W)N97(N"B`@("`@("`@)',M/F1R87=#=7)V951O*"1X,B`K("1P
M,ULG>#,G72P@)'DR("L@)'`S6R=Y,R==+"`D>#(@*R`D<#-;)W@R)UTL("1Y
M,B`K("1P,ULG>3(G72D["B`@("`@("`@)',M/F1R87=#=7)V951O*"1X,B`K
M("1P-%LG>#,G72P@)'DR("L@)'`T6R=Y,R==+"`D>#(@*R`D<#1;)W@R)UTL
M("1Y,B`K("1P-%LG>3(G72D["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@
M;&]W97(@<FEG:'0@<&]I;G1S+@H@("`@("`@("1P-2`]("1T:&ES+3Y?87)C
M4&]I;G1S*"1R;W5N9"P@,"P@-#4I.PH@("`@("`@("1P-B`]("1T:&ES+3Y?
M87)C4&]I;G1S*"1R;W5N9"P@-#4L(#DP*3L*"B`@("`@("`@+R\@0V]N;F5C
M="!T:&4@=&]P(')I9VAT(&%N9"!L;W=E<B!R:6=H="!C=7)V97,N"B`@("`@
M("`@)',M/F1R87=,:6YE5&\H)'@S("L@)'`U6R=X,2==+"`D>3,@*R`D<#5;
M)WDQ)UTI.PH*("`@("`@("`O+R!$<F%W('1H92!L;W=E<B!R:6=H="!C;W)N
M97(N"B`@("`@("`@)',M/F1R87=#=7)V951O*"1X,R`K("1P-5LG>#,G72P@
M)'DS("L@)'`U6R=Y,R==+"`D>#,@*R`D<#5;)W@R)UTL("1Y,R`K("1P-5LG
M>3(G72D["B`@("`@("`@)',M/F1R87=#=7)V951O*"1X,R`K("1P-ELG>#,G
M72P@)'DS("L@)'`V6R=Y,R==+"`D>#,@*R`D<#9;)W@R)UTL("1Y,R`K("1P
M-ELG>3(G72D["@H@("`@("`@("\O($-A;&-U;&%T92!T:&4@;&]W97(@;&5F
M="!P;VEN=',N"B`@("`@("`@)'`W(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O
M=6YD+"`Y,"P@,3,U*3L*("`@("`@("`D<#@@/2`D=&AI<RT^7V%R8U!O:6YT
M<R@D<F]U;F0L(#$S-2P@,3@P*3L*"B`@("`@("`@+R\@0V]N;F5C="!T:&4@
M8F]T=&]M(')I9VAT(&%N9"!B;W1T;VT@;&5F="!C=7)V97,N"B`@("`@("`@
M)',M/F1R87=,:6YE5&\H)'@T("L@)'`W6R=X,2==+"`D>30@*R`D<#=;)WDQ
M)UTI.PH*("`@("`@("`O+R!$<F%W('1H92!L;W=E<B!L969T(&-O<FYE<BX*
M("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@T("L@)'`W6R=X,R==+"`D>30@
M*R`D<#=;)WDS)UTL("1X-"`K("1P-ULG>#(G72P@)'DT("L@)'`W6R=Y,B==
M*3L*("`@("`@("`D<RT^9')A=T-U<G9E5&\H)'@T("L@)'`X6R=X,R==+"`D
M>30@*R`D<#A;)WDS)UTL("1X-"`K("1P.%LG>#(G72P@)'DT("L@)'`X6R=Y
M,B==*3L*"B`@("`@("`@+R\@0VQO<V4@=&AE('-H87!E+@H@("`@("`@("1S
M+3YD<F%W3&EN951O*"1X,2`K("1P,5LG>#$G72P@)'DQ("L@)'`Q6R=Y,2==
M*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D9"@D<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@;&EN92X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>#`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F
M('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@5&AE
M('D@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'@Q("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'DQ("`@("!4:&4@>2!C;RUO<F1I;F%T
M92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("!4
M:&4@;&EN92!C;VQO<BX*("`@("`J($!P87)A;2!S=')I;F<@("1W:61T:"`@
M5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:6YE*"1X,2P@)'DQ+"`D>#(L("1Y,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I
M9'1H(#T@,2D*("`@('L*("`@("`@("`D8V]L;W(@/2`D=&AI<RT^86QL;V-A
M=&5#;VQO<B@D8V]L;W(I.PH*("`@("`@("!I9B`H:7-?87)R87DH)&-O;&]R
M*2D@>PH@("`@("`@("`@("`D<VAA<&4@/2`F;F5W(%-71E-H87!E*"D["B`@
M("`@("`@("`@("1S:&%P92T^<V5T3&EN92@D=VED=&@L("1C;VQO<ELG<F5D
M)UTL("1C;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG
M86QP:&$G72D["B`@("`@("`@("`@("1S:&%P92T^;6]V95!E;E1O*"1X,2P@
M)'DQ*3L*("`@("`@("`@("`@)'-H87!E+3YD<F%W3&EN951O*"1X,BP@)'DR
M*3L*"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE+3YA9&0H)'-H
M87!E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&1A
M<VAE9"!L:6YE+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@
M("`@("`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'DP("`@("`@("`@("!4:&4@>2!C;RUO<F1I
M;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>#$@
M("`@("`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F('1H92!E;F0N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>3$@("`@("`@("`@(%1H92!Y(&-O+6]R9&EN
M871E(&]F('1H92!E;F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@
M("`@("`@(%1H92!L:6YE(&-O;&]R+@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'=I9'1H("`@("`@("!4:&4@=VED=&@@;V8@=&AE(&QI;F4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D9&%S:%]L96YG=&@@(%1H92!L96YG=&@@;V8@82!D
M87-H(&]N('1H92!D87-H960@;&EN90H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&1A<VA?<W!A8V4@("!4:&4@;&5N9W1H(&]F(&$@<W!A8V4@:6X@=&AE(&1A
M<VAE9"!L:6YE"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A<VAE9$QI;F4H)'@P
M+"`D>3`L("1X,2P@)'DQ+"`D8V]L;W(@/2`G8FQA8VLG+"`D=VED=&@@/2`Q
M+"`D9&%S:%]L96YG=&@@/2`R+"`D9&%S:%]S<&%C92`](#(I"B`@("!["B`@
M("`@("`@+R\@1V5T('1H92!L96YG=&@@;V8@=&AE(&QI;F4@:6X@<&EX96QS
M+@H@("`@("`@("1L:6YE7VQE;F=T:"`](&UA>"AC96EL*'-Q<G0H<&]W*"@D
M>#$@+2`D>#`I+"`R*2`K('!O=R@H)'DQ("T@)'DP*2P@,BDI*2P@,BD["@H@
M("`@("`@("1C;W-4:&5T82`]("@D>#$@+2`D>#`I("\@)&QI;F5?;&5N9W1H
M.PH@("`@("`@("1S:6Y4:&5T82`]("@D>3$@+2`D>3`I("\@)&QI;F5?;&5N
M9W1H.PH@("`@("`@("1L87-T>"`]("1X,#L*("`@("`@("`D;&%S='D@/2`D
M>3`["@H@("`@("`@("\O($1R87<@=&AE(&1A<VAE9"!L:6YE+@H@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1L:6YE7VQE;F=T:#L@)&D@*ST@*"1D87-H
M7VQE;F=T:"`K("1D87-H7W-P86-E*2D@>PH@("`@("`@("`@("`D>"`]("@D
M9&%S:%]L96YG=&@@*B`D8V]S5&AE=&$I("L@)&QA<W1X.PH@("`@("`@("`@
M("`D>2`]("@D9&%S:%]L96YG=&@@*B`D<VEN5&AE=&$I("L@)&QA<W1Y.PH*
M("`@("`@("`@("`@)'1H:7,M/FQI;F4H)&QA<W1X+"`D;&%S='DL("1X+"`D
M>2P@)&-O;&]R*3L*"B`@("`@("`@("`@("1L87-T>"`]("1X("L@*"1D87-H
M7W-P86-E("H@)&-O<U1H971A*3L*("`@("`@("`@("`@)&QA<W1Y(#T@)'D@
M*R`H)&1A<VA?<W!A8V4@*B`D<VEN5&AE=&$I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY;&EN92`H82!N;VXM8VQO<V5D
M+"!N;VXM9FEL;&5D('!O;'EG;VXI(&)A<V5D(&]N(&$*("`@("`J('-E="!O
M9B!V97)T:6-E<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D=F5R
M=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A<G)A>7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@*&5G+B`D=F5R=&EC97-;
M,%U;)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D8V]L;W(@("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D
M<F%W('1H92!L:6YE('=I=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=VED
M=&@@("`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@<&]L>6QI;F4H)'9E<G1S+"`D8V]L;W(L("1W:61T:"`](#$I"B`@
M("!["B`@("`@("`@)&-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&-O
M;&]R*3L*"B`@("`@("`@)'-H87!E(#T@)FYE=R!35T93:&%P92@I.PH@("`@
M("`@("1S:&%P92T^<V5T3&EN92@D=VED=&@L("1C;VQO<ELG<F5D)UTL("1C
M;VQO<ELG9W)E96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G
M72D["@H@("`@("`@("1F:7)S=%]D;VYE(#T@9F%L<V4["B`@("`@("`@9F]R
M96%C:"`H)'9E<G1S(&%S("1V86QU92D@>PH@("`@("`@("`@("!I9B`H(21F
M:7)S=%]D;VYE*2!["B`@("`@("`@("`@("`@("`D<VAA<&4M/FUO=F5096Y4
M;R@D=F%L=65;)W@G72P@)'9A;'5E6R=Y)UTI.PH@("`@("`@("`@("`@("`@
M)&9I<G-T7V1O;F4@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1S:&%P92T^9')A=TQI;F54;R@D=F%L=65;)W@G72P@)'9A;'5E6R=Y)UTI
M.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6]V:64M/F%D
M9"@D<VAA<&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A;B!A<F,N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("!4:&4@>"!C
M;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'D@("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H
M92!A<F,N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R
M="!A;F=L92!O9B!T:&4@87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N
M9"`@("!4:&4@96YD(&%N9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;VQO<B`@(%1H92!L:6YE(&-O;&]R(&]F('1H92!A<F,N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@(%1H92!F:6QL(&-O;&]R(&]F
M('1H92!A<F,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%R8R@D>"P@)'DL("1R
M+"`D<W1A<G0L("1E;F0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@)VYO
M;F4G*0H@("`@>PH@("`@("`@("1S(#T@)FYE=R!35T93:&%P92@I.PH@("`@
M("`@("1C;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@
M("`@("`@)',M/G-E=$QI;F4H,2P@)&-O;&]R6R=R960G72P@)&-O;&]R6R=G
M<F5E;B==+"`D8V]L;W);)V)L=64G72P@)&-O;&]R6R=A;'!H82==*3L*"B`@
M("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@("`D9FEL
M;$-O;&]R(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI.PH@("`@("`@
M("`@("`D9B`]("1S+3YA9&1&:6QL*"1F:6QL0V]L;W);)W)E9"==+"`D9FEL
M;$-O;&]R6R=G<F5E;B==+"`D9FEL;$-O;&]R6R=B;'5E)UTL("1F:6QL0V]L
M;W);)V%L<&AA)UTI.PH@("`@("`@("`@("`D<RT^<V5T4FEG:'1&:6QL*"1F
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D96YD("T@)'-T87)T(#P](#0U
M*2!["B`@("`@("`@("`@("1P=',@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<BP@
M)'-T87)T+"`D96YD*3L*("`@("`@("`@("`@)',M/FUO=F5096Y4;R@D>"P@
M)'DI.PH@("`@("`@("`@("`D<RT^9')A=TQI;F54;R@D<'1S6R=X,2==("L@
M)'@L("1P='-;)WDQ)UT@*R`D>2D["B`@("`@("`@("`@("1S+3YD<F%W0W5R
M=F54;R@D<'1S6R=X,R==("L@)'@L("1P='-;)WDS)UT@*R`D>2P@)'!T<ULG
M>#(G72`K("1X+"`D<'1S6R=Y,B==("L@)'DI.PH@("`@("`@("`@("`D<RT^
M9')A=TQI;F54;R@D>"P@)'DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1S96-T:6]N<R`](&-E:6PH*"1E;F0@+2`D<W1A<G0I("\@-#4I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<V5C=&EO;G,[("1I*RLI
M('L*("`@("`@("`@("`@("`@("1P=',@/2`D=&AI<RT^7V%R8U!O:6YT<R@D
M<BP@)'-T87)T("L@*"1I("H@-#4I+"`H)'-T87)T("L@*"@D:2`K(#$I("H@
M-#4I(#X@)&5N9"D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`_("1E;F0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`Z("@D<W1A<G0@*R`H*"1I("L@,2D@*B`T-2DI*3L*"B`@
M("`@("`@("`@("`@("`O+R!)9B!W92!A<F4@;VX@=&AE(&9I<G-T('-E8W1I
M;VXL(&UO=F4@=&AE('!E;B!T;R!T:&4*("`@("`@("`@("`@("`@("\O(&-E
M;G1R92!A;F0@9')A=R!O=70@=&\@=&AE(&5D9V4N"B`@("`@("`@("`@("`@
M("!I9B`H)&D@/3T@,"`F)B`D9FEL;"`A/2`G;F]N92<I('L*("`@("`@("`@
M("`@("`@("`@("`D<RT^;6]V95!E;E1O*"1X+"`D>2D["B`@("`@("`@("`@
M("`@("`@("`@)',M/F1R87=,:6YE5&\H)'!T<ULG>#$G72`K("1X+"`D<'1S
M6R=Y,2==("L@)'DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D<RT^;6]V95!E;E1O*"1P='-;)W@Q)UT@*R`D>"P@
M)'!T<ULG>3$G72`K("1Y*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("`@("`O+R!$<F%W('1H92!A<F,N"B`@("`@("`@("`@("`@("`D<RT^
M9')A=T-U<G9E5&\H)'!T<ULG>#,G72`K("1X+"`D<'1S6R=Y,R==("L@)'DL
M("1P='-;)W@R)UT@*R`D>"P@)'!T<ULG>3(G72`K("1Y*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@
M("`@("`@("`@("`@+R\@1')A=R!A(&QI;F4@9G)O;2!T:&4@961G92!B86-K
M('1O('1H92!C96YT<F4@=&\@8VQO<V4*("`@("`@("`@("`@("`@("\O(&]F
M9B!T:&4@<V5G;65N="X*("`@("`@("`@("`@("`@("1S+3YD<F%W3&EN951O
M*"1X+"`D>2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7VUO=FEE+3YA9&0H)',I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1')A=R!A(')E8W1A;F=L92!F:6QL960@=VET:"!A(&=R861I96YT
M(&9R;VT@)&-O;&]R,2!T;PH@("`@("H@)&-O;&]R,BX*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@;&5F="!X+6-O;W)D:6YA
M=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y
M("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@("!4:&4@=VED=&@@;V8@
M=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I;G1E9V5R("1H96EG:'0@
M(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!S
M=')I;F<@("1C;VQO<B`@(%1H92!O=71L:6YE(&-O;&]R(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9FEL;#$@("!4:&4@;F%M
M92!O9B!T:&4@<W1A<G0@8V]L;W(@9F]R('1H92!G<F%D:65N="X*("`@("`J
M($!P87)A;2!S=')I;F<@("1F:6QL,B`@(%1H92!N86UE(&]F('1H92!E;F0@
M8V]L;W(@9F]R('1H92!G<F%D:65N="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9W)A9&EE;G1296-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C
M;VQO<B`]("=B;&%C:R<L("1F:6QL,2`]("=B;&%C:R<L("1F:6QL,B`]("=W
M:&ET92<I"B`@("!["B`@("`@("`@)',@/2`F;F5W(%-71E-H87!E*"D["@H@
M("`@("`@(&EF("@D8V]L;W(@(3T@)VYO;F4G*2!["B`@("`@("`@("`@("1C
M;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD["B`@("`@("`@
M("`@("1S+3YS971,:6YE*#$L("1C;VQO<ELG<F5D)UTL("1C;VQO<ELG9W)E
M96XG72P@)&-O;&]R6R=B;'5E)UTL("1C;VQO<ELG86QP:&$G72D["B`@("`@
M("`@?0H*("`@("`@("`D9FEL;#$@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M9FEL;#$I.PH@("`@("`@("1F:6QL,B`]("1T:&ES+3YA;&QO8V%T94-O;&]R
M*"1F:6QL,BD["B`@("`@("`@)&=R861I96YT(#T@)FYE=R!35T9'<F%D:65N
M="@I.PH@("`@("`@("1G<F%D:65N="T^861D16YT<GDH,"XP+"`D9FEL;#%;
M)W)E9"==+"`D9FEL;#%;)V=R965N)UTL("1F:6QL,5LG8FQU92==+"`D9FEL
M;#%;)V%L<&AA)UTI.PH@("`@("`@("1G<F%D:65N="T^861D16YT<GDH,2XP
M+"`D9FEL;#);)W)E9"==+"`D9FEL;#);)V=R965N)UTL("1F:6QL,ELG8FQU
M92==+"`D9FEL;#);)V%L<&AA)UTI.PH*("`@("`@("`D9B`]("1S+3YA9&1&
M:6QL*"1G<F%D:65N="P@4U=&1DE,3%],24Y%05)?1U)!1$E%3E0I.PH@("`@
M("`@("1F+3YS8V%L951O*"1W:61T:"`O("1T:&ES+3Y?=VED=&@I.PH@("`@
M("`@("1F+3YM;W9E5&\H)'@L("1Y*3L*("`@("`@("`D<RT^<V5T4FEG:'1&
M:6QL*"1F*3L*"B`@("`@("`@)'9E<G1S6S!=(#T@87)R87DH)W@G(#T^("1X
M+"`G>2<@/3X@)'DI.PH@("`@("`@("1V97)T<ULQ72`](&%R<F%Y*"=X)R`]
M/B`D>"`K("1W:61T:"P@)WDG(#T^("1Y*3L*("`@("`@("`D=F5R='-;,ET@
M/2!A<G)A>2@G>"<@/3X@)'@@*R`D=VED=&@L("=Y)R`]/B`D>2`K("1H96EG
M:'0I.PH@("`@("`@("1V97)T<ULS72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG
M(#T^("1Y("L@)&AE:6=H="D["@H@("`@("`@("1F:7)S=%]D;VYE(#T@9F%L
M<V4["B`@("`@("`@9F]R96%C:"`H)'9E<G1S(&%S("1V97)T*2!["B`@("`@
M("`@("`@(&EF("@A)&9I<G-T7V1O;F4I('L*("`@("`@("`@("`@("`@("1S
M+3YM;W9E4&5N5&\H)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@
M("`@("`@("`D9FER<W1?9&]N92`]('1R=64["B`@("`@("`@("`@("`@("`D
M9FER<W1?>"`]("1V97)T6R=X)UT["B`@("`@("`@("`@("`@("`D9FER<W1?
M>2`]("1V97)T6R=Y)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@)',M
M/F1R87=,:6YE5&\H)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@("`@("`@
M?0H@("`@("`@("1S+3YD<F%W3&EN951O*"1F:7)S=%]X+"`D9FER<W1?>2D[
M"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VUO=FEE+3YA9&0H)',I.PH@("`@
M?0H*?0H`````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L
M:6(O2&]R9&4O26UA9V4O9V0N<&AP````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q,#<V-#8@,3`U,34T,S0Q,S<@,#(Q-3$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@IR
M97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN+TEM86=E+G!H
M<"<["@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE;G1S('1H92!(;W)D95])
M;6%G93HZ($%022!F;W(@=&AE(%!(4"!'1`H@*B!E>'1E;G-I;VXN($ET(&UA
M:6YL>2!P<F]V:61E<R!S;VUE('5T:6QI='D@9G5N8W1I;VYS+"!S=6-H(&%S
M('1H90H@*B!A8FEL:71Y('1O(&UA:V4@<&EX96QS+"!F;W(@;F]W+@H@*@H@
M*B`D2&]R9&4Z(&9R86UE=V]R:R]);6%G92]);6%G92]G9"YP:'`L=B`Q+C0X
M+C$P+C$T(#(P,#8O,#$O,#$@,C$Z,C@Z,C(@:F%N($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J+PIC;&%S<R!(;W)D95]);6%G
M95]G9"!E>'1E;F1S($AO<F1E7TEM86=E('L*"B`@("`O*BH*("`@("`J($-A
M<&%B:6QI=&5S(&]F('1H:7,@9')I=F5R+@H@("`@("H*("`@("`J($!V87(@
M87)R87D*("`@("`J+PH@("`@=F%R("1?8V%P86)I;&ET:65S(#T@87)R87DH
M)W)E<VEZ92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8W)O
M<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<F]T871E)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F;&EP)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=M:7)R;W(G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V=R87ES8V%L92<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<V5P:6$G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)WEE;&QO=VEZ92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=V%T97)M87)K)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=C86YV87,G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@*3L*"B`@("`O*BH*("`@("`J(%=H870@:VEN9"!O9B!I;6%G97,@<VAO
M=6QD($=$(&=E;F5R871E/R!$969A=6QT<R!T;R`G<&YG)RX*("`@("`J"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T>7!E(#T@)W!N
M9R<["@H@("`@+RHJ"B`@("`@*B!'1"!);6%G92!R97-O=7)C92!F;W(@=&AE
M(&-U<G)E;G0@:6UA9V4@9&%T82X*("`@("`J"B`@("`@*B!`=F%R(')E<V]U
M<F-E"B`@("`@*B\*("`@('9A<B`D7VEM.PH*("`@("\J*@H@("`@("H@4W1R
M:6YG(&ED96YT:69I97(@;V8@=&AE(&-U<G)E;G0@:6UA9V4N($YE=R!I;6%G
M92!D871A('=I;&P@;F]T(&)E"B`@("`@*B!L;V%D960@:68@=&AE('-A;64@
M:60@:7,@86QR96%D>2!L;V%D960N"B`@("`@*@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?:60@/2`G)SL*"B`@("!F=6YC=&EO;B!(
M;W)D95]);6%G95]G9"@D<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ
M2&]R9&5?26UA9V4H)'!A<F%M<RD["B`@("`@("`@:68@*"%E;7!T>2@D<&%R
M86US6R=T>7!E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("1P
M87)A;7-;)W1Y<&4G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP='DH
M)'!A<F%M<ULG=VED=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I;2`]
M("8D=&AI<RT^7V-R96%T92@D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H
M="D["B`@("`@("`@("`@("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL)RP@87)R
M87DH)'1H:7,M/E]I;2P@,"P@,"P@)'1H:7,M/F%L;&]C871E0V]L;W(H)'1H
M:7,M/E]B86-K9W)O=6YD*2DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("=I
M;6%G92\G("X@)'1H:7,M/E]T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&ES<&QA>2!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&ES<&QA>2@I"B`@("!["B`@("`@("`@)'1H:7,M/FAE861E<G,H*3L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]C86QL*"=I;6%G92<@+B`D=&AI<RT^
M7W1Y<&4L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE(')A=R!D871A(&9O<B!T:&ES(&EM86=E+@H@("`@
M("H*("`@("`J($!P87)A;2!B;V]L96%N("1C;VYV97)T("!)9B!T<G5E+"!T
M:&4@:6UA9V4@9&%T82!W:6QL(&)E(')E='5R;F5D(&EN('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@('1A<F=E="!F;W)M870L(&EN9&5P
M96YD96YT;'D@9G)O;2!A;GD@:6UA9V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!O<&5R871I;VYS+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!4:&4@<F%W(&EM86=E(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(')A=R@D8V]N=F5R="`](&9A;'-E*0H@("`@>PH@("`@("`@(')E='5R
M;B!5=&EL.CIB=69F97)/=71P=70H)VEM86=E)R`N("1T:&ES+3Y?='EP92P@
M)'1H:7,M/E]I;2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E="!T:&4@
M:6UA9V4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S970H*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ<F5S970H*3L*("`@("`@("!I9B`H:7-?<F5S
M;W5R8V4H)'1H:7,M/E]I;2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V%L;"@G:6UA9V5$97-T<F]Y)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!T:&4@:&5I9VAT(&%N9"!W:61T:"!O9B!T:&4@8W5R<F5N
M="!I;6%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!H87-H
M('=I=&@@)W=I9'1H)R!C;VYT86EN:6YG('1H92!W:61T:"P*("`@("`J("`@
M("`@("`@("`@("`@("=H96EG:'0G(&-O;G1A:6YI;F<@=&AE(&AE:6=H="!O
M9B!T:&4@:6UA9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1I;65N<VEO
M;G,H*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?:6TL("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:6T["B`@
M("`@("`@?2!E;'-E:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?:6TI*2!["B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@G=VED=&@G(#T^("1T:&ES+3Y?8V%L
M;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("=H96EG:'0G(#T^("1T:&ES+3Y?8V%L;"@G:6UA9V53
M62<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*"=W:61T:"<@/3X@,"P@)VAE:6=H="<@
M/3X@,"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E
M<R!A(&-O;&]R('1H870@8V%N(&)E(&%C8V5S<V5D(&EN('1H:7,@;V)J96-T
M+B!7:&5N(&$*("`@("`J(&-O;&]R(&ES('-E="P@=&AE(&EN=&5G97(@<F5S
M;W5R8V4@;V8@:70@:7,@<F5T=7)N960N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&-O;&]R+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(')E<V]U<F-E(&]F('1H92!C
M;VQO<B!T:&%T(&-A;B!B92!P87-S960@=&\@1T0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&%L;&]C871E0V]L;W(H)&YA;64I"B`@("!["B`@("`@("`@<W1A
M=&EC("1C;VQO<G,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H96UP='DH)&-O
M;&]R<ULD;F%M95TI*2!["B`@("`@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@
M/2`D=&AI<RT^9V5T4D="*"1N86UE*3L*("`@("`@("`@("`@)&-O;&]R<ULD
M;F%M95T@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)!;&QO8V%T92<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1R+"`D9RP@)&(I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8V]L;W)S6R1N86UE73L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971&;VYT*"1F;VYT*0H@("`@>PH@("`@("`@('-W:71C:"`H)&9O;G0I
M('L*("`@("`@("!C87-E("=T:6YY)SH*("`@("`@("`@("`@<F5T=7)N(#$[
M"@H@("`@("`@(&-A<V4@)VUE9&EU;2<Z"B`@("`@("`@("`@(')E='5R;B`S
M.PH*("`@("`@("!C87-E("=L87)G92<Z"B`@("`@("`@("`@(')E='5R;B`T
M.PH*("`@("`@("!C87-E("=G:6%N="<Z"B`@("`@("`@("`@(')E='5R;B`U
M.PH*("`@("`@("!C87-E("=S;6%L;"<Z"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@<F5T=7)N(#(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@3&]A9"!T:&4@:6UA9V4@9&%T82!F<F]M(&$@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&ED("`@("`@("`@($%N(&%R8FET
M<F%R>2!I9"!F;W(@=&AE(&EM86=E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M:6UA9V5?9&%T82`@5&AE(&1A=&$@=&\@=7-E(&9O<B!T:&4@:6UA9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QO8613=')I;F<H)&ED+"`D:6UA9V5?9&%T
M82D*("`@('L*("`@("`@("!I9B`H)&ED("$]("1T:&ES+3Y?:60I('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?:6TI('L*("`@("`@("`@("`@("`@(&EF
M("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^<F5S970H*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES
M+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G94-R96%T949R;VU3=')I;F<G
M+"!A<G)A>2@D:6UA9V5?9&%T82DI.PH@("`@("`@("`@("`D=&AI<RT^7VED
M(#T@)&ED.PH@("`@("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I
M;3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($QO860@=&AE(&EM86=E(&1A=&$@9G)O;2!A(&9I;&4N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F=6QL('!A=&@@
M86YD(&9I;&5N86UE('1O('1H92!F:6QE('1O(&QO860*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@:6UA9V4@9&%T82!F<F]M+B!4:&4@
M9FEL96YA;64@=VEL;"!A;'-O(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@=7-E9"!F;W(@=&AE(&EM86=E(&ED+@H@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%!%05(@17)R;W(@:68@9FEL92!D;V5S(&YO="!E
M>&ES="!O<B!C;W5L9"!N;W0@8F4@;&]A9&5D"B`@("`@*B`@("`@("`@("`@
M("`@("!O=&AE<G=I<V4@3E5,3"!I9B!S=6-C97-S9G5L(&]R(&%L<F5A9'D@
M;&]A9&5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V%D1FEL92@D9FEL96YA
M;64I"B`@("!["B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YR
M97-E="@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)&EN9F\@/2`D
M=&AI<RT^7V-A;&PH)V=E=&EM86=E<VEZ92<L(&%R<F%Y*"1F:6QE;F%M92DI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D:6YF;SL*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF;RDI('L*("`@
M("`@("`@("`@<W=I=&-H("@D:6YF;ULR72D@>PH@("`@("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=I;6%G
M96-R96%T969R;VUG:68G*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUG:68G+"!A
M<G)A>2@D9FEL96YA;64I*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5C<F5A=&5F
M<F]M:G!E9R<L(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G96-R96%T969R;VUP;F<G
M+"!A<G)A>2@D9FEL96YA;64I*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E(#$U.@H@("`@("`@("`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G:6UA9V5C<F5A=&5F<F]M9W=B;7`G*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6T@/2`F)'1H:7,M/E]C86QL*"=I;6%G
M96-R96%T969R;VUG=V)M<"<L(&%R<F%Y*"1F:6QE;F%M92DI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M(&-A<V4@,38Z"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)B1T:&ES
M+3Y?8V%L;"@G:6UA9V5C<F5A=&5F<F]M>&)M)RP@87)R87DH)&9I;&5N86UE
M*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]I;2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7VEM*2D@>PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT
M(#T@<&%R96YT.CIL;V%D1FEL92@D9FEL96YA;64I.PH@("`@("`@(&EF("AI
M<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M7VEM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5#<F5A=&5&<F]M4W1R:6YG)RP@
M87)R87DH)'1H:7,M/E]D871A*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M97-I>F4@=&AE(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'=I9'1H("`@("`@5&AE(&YE=R!W:61T:"X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1H96EG:'0@("`@(%1H92!N97<@:&5I9VAT+@H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)')A=&EO("`@("`@36%I;G1A:6X@;W)I9VEN
M86P@87-P96-T(')A=&EO+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-I>F4H
M)'=I9'1H+"`D:&5I9VAT+"`D<F%T:6\@/2!T<G5E*0H@("`@>PH@("`@("`@
M("\J($%B;W)T(&EF('=E)W)E(&%S:V5D('1O(&1I=FED92!B>2!Z97)O+"!O
M<B!T<G5N8V%T92!T:&4*("`@("`@("`@*B!I;6%G92!C;VUP;&5T96QY(&EN
M(&5I=&AE<B!D:7)E8W1I;VXN("HO"B`@("`@("`@:68@*"$D=VED=&@@?'P@
M(21H96EG:'0I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1R871I;RD@>PH@("`@("`@("`@("!I9B`H)'=I9'1H("\@
M)&AE:6=H="`^("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES
M+3Y?:6TI*2`O("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES
M+3Y?:6TI*2D@>PH@("`@("`@("`@("`@("`@)'=I9'1H(#T@)&AE:6=H="`J
M("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*2`O
M("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1H96EG:'0@
M/2`D=VED=&@@*B`D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D=&AI
M<RT^7VEM*2D@+R`D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D=&AI
M<RT^7VEM*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I
M;2`]("1T:&ES+3Y?:6T["B`@("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^
M7V-R96%T92@D=VED=&@L("1H96EG:'0I.PH@("`@("`@(&EF("AI<U]A*"1T
M:&ES+3Y?:6TL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?:6T["B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;"<L(&%R<F%Y*"1T:&ES+3Y?
M:6TL(#`L(#`L("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<D%L;&]C871E)RP@
M87)R87DH)'1H:7,M/E]I;2P@,C4U+"`R-34L(#(U-2DI*2DL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y4F5S
M86UP;&5D)RP@87)R87DH)'1H:7,M/E]I;2P@)&EM+"`P+"`P+"`P+"`P+"`D
M=VED=&@L("1H96EG:'0L("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y
M*"1I;2DI+"`D=&AI<RT^7V-A;&PH)VEM86=E4UDG+"!A<G)A>2@D:6TI*2DI
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-A;&PH)VEM86=E0V]P>5)E<VEZ960G+"!A<G)A>2@D=&AI<RT^7VEM+"`D
M:6TL(#`L(#`L(#`L(#`L("1W:61T:"P@)&AE:6=H="P@)'1H:7,M/E]C86QL
M*"=I;6%G95-8)RP@87)R87DH)&EM*2DL("1T:&ES+3Y?8V%L;"@G:6UA9V53
M62<L(&%R<F%Y*"1I;2DI*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@0W)O<"!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>#$@(%1H92!T;W`@;&5F="!C;W)N97(@;V8@=&AE
M(&-R;W!P960@:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@(%1H
M92!T;W`@<FEG:'0@8V]R;F5R(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'@R("!4:&4@8F]T=&]M(&QE9G0@8V]R;F5R
M(&]F('1H92!C<F]P<&5D(&EM86=E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'DR("!4:&4@8F]T=&]M(')I9VAT(&-O<FYE<B!O9B!T:&4@8W)O<'!E9"!I
M;6%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)O<"@D>#$L("1Y,2P@)'@R
M+"`D>3(I"B`@("!["B`@("`@("`@)&EM(#T@)'1H:7,M/E]I;3L*("`@("`@
M("`D=&AI<RT^7VEM(#T@)B1T:&ES+3Y?8W)E871E*"1X,B`M("1X,2P@)'DR
M("T@)'DQ*3L*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEM.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]C86QL*"=I;6%G94-O<'DG
M+"!A<G)A>2@D=&AI<RT^7VEM+"`D:6TL(#`L(#`L("1X,2P@)'DQ+"`D>#(@
M+2`D>#$L("1Y,B`M("1Y,2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F]T
M871E('1H92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1A;F=L92`@("`@("!4:&4@86YG;&4@=&\@<F]T871E('1H92!I
M;6%G92!B>2P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M;B!T:&4@8VQO8VMW:7-E(&1I<F5C=&EO;@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)&)A8VMG<F]U;F0@(%1H92!B86-K9W)O=6YD(&-O;&]R('1O(&9I;&P@
M86YY('1R:6%N9VQE<PH@("`@("HO"B`@("!F=6YC=&EO;B!R;W1A=&4H)&%N
M9VQE+"`D8F%C:V=R;W5N9"`]("=W:&ET92<I"B`@("!["B`@("`@("`@:68@
M*"%F=6YC=&EO;E]E>&ES=',H)VEM86=E<F]T871E)RDI('L*("`@("`@("`@
M("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&)A8VMG<F]U;F0@/2`D
M=&AI<RT^86QL;V-A=&5#;VQO<B@D8F%C:V=R;W5N9"D["B`@("`@("`@:68@
M*&ES7V$H)&)A8VMG<F]U;F0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1B86-K9W)O=6YD.PH@("`@("`@('T*"B`@("`@("`@<W=I
M=&-H("@D86YG;&4I('L*("`@("`@("!C87-E("<Y,"<Z"B`@("`@("`@("`@
M("1X(#T@)'1H:7,M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I
M;2DI.PH@("`@("`@("`@("`D>2`]("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L
M(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*("`@("`@("`@("`@)'AY;6%X(#T@;6%X
M*"1X+"`D>2D["@H@("`@("`@("`@("`D:6T@/2`F)'1H:7,M/E]C<F5A=&4H
M)'AY;6%X+"`D>'EM87@I.PH@("`@("`@("`@("!I9B`H:7-?82@D:6TL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:6T["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R87DH)&EM+"`D=&AI<RT^7VEM
M+"`P+"`P+"`P+"`P+"`D>"P@)'DI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&EM(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V52;W1A=&4G+"!A
M<G)A>2@D:6TL(#(W,"P@)&)A8VMG<F]U;F0I*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&EM+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)&EM.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?
M:6T@/2`D:6T["B`@("`@("`@("`@("1I;2`]("8D=&AI<RT^7V-R96%T92@D
M>2P@)'@I.PH@("`@("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D:6T["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1X(#P@)'DI('L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]P>2<L
M(&%R<F%Y*"1I;2P@)'1H:7,M/E]I;2P@,"P@,"P@,"P@,"P@)'AY;6%X+"`D
M>'EM87@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V5I9B`H)'@@/B`D>2D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R87DH
M)&EM+"`D=&AI<RT^7VEM+"`P+"`P+"`D>'EM87@@+2`D>2P@)'AY;6%X("T@
M)'@L("1X>6UA>"P@)'AY;6%X*2DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7VEM(#T@)&EM
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@)'1H:7,M/E]I;2`]("8D=&AI<RT^7V-A;&PH)VEM86=E4F]T871E
M)RP@87)R87DH)'1H:7,M/E]I;2P@,S8P("T@)&%N9VQE+"`D8F%C:V=R;W5N
M9"DI.PH@("`@("`@("`@("!I9B`H:7-?82@D=&AI<RT^7VEM+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]I;3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!&;&EP('1H92!C=7)R96YT(&EM86=E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!F;&EP*"D*("`@('L*("`@("`@("`D>"`]
M("1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y*"1T:&ES+3Y?:6TI*3L*
M("`@("`@("`D>2`]("1T:&ES+3Y?8V%L;"@G:6UA9V5362<L(&%R<F%Y*"1T
M:&ES+3Y?:6TI*3L*"B`@("`@("`@)&EM(#T@)B1T:&ES+3Y?8W)E871E*"1X
M+"`D>2D["B`@("`@("`@:68@*&ES7V$H)&EM+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6T["B`@("`@("`@?0H@("`@("`@(&9O
M<B`H)&-U<ED@/2`P.R`D8W5R62`\("1Y.R`D8W5R62LK*2!["B`@("`@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]P
M>2<L(&%R<F%Y*"1I;2P@)'1H:7,M/E]I;2P@,"P@)'D@+2`H)&-U<ED@*R`Q
M*2P@,"P@)&-U<EDL("1X+"`Q*2DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("`D=&AI<RT^7VEM(#T@)&EM.PH@("`@?0H*("`@("\J
M*@H@("`@("H@36ER<F]R('1H92!C=7)R96YT(&EM86=E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!M:7)R;W(H*0H@("`@>PH@("`@("`@("1X(#T@)'1H:7,M
M/E]C86QL*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI.PH@("`@("`@
M("1Y(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H:7,M/E]I
M;2DI.PH*("`@("`@("`D:6T@/2`F)'1H:7,M/E]C<F5A=&4H)'@L("1Y*3L*
M("`@("`@("!I9B`H:7-?82@D:6TL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1I;3L*("`@("`@("!]"B`@("`@("`@9F]R("@D8W5R
M6"`](#`[("1C=7)8(#P@)'@[("1C=7)8*RLI('L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;W!Y)RP@87)R
M87DH)&EM+"`D=&AI<RT^7VEM+"`D>"`M("@D8W5R6"`K(#$I+"`P+"`D8W5R
M6"P@,"P@,2P@)'DI*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3Y?:6T@/2`D:6T["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T('1H92!C=7)R96YT(&EM86=E('1O(&=R87ES8V%L92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9W)A>7-C86QE*"D*("`@('L*("`@("`@("`D
M<F%T95(@/2`N,C(Y.PH@("`@("`@("1R871E1R`]("XU.#<["B`@("`@("`@
M)')A=&5"(#T@+C$Q-#L*("`@("`@("`D=VAI=&5N97-S(#T@,SL*"B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G:6UA9V5I<W1R=65C;VQO<B<I("8F
M("1T:&ES+3Y?8V%L;"@G:6UA9V5)<U1R=65#;VQO<B<L(&%R<F%Y*"1T:&ES
M+3Y?:6TI*2`]/3T@=')U92D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G951R=65#;VQO<E1O4&%L971T92<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL('1R=64L(#(U-BDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@)&-O;&]R<R`](&UI;B@R-38L("1T
M:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<G-4;W1A;"<L(&%R<F%Y*"1T:&ES+3Y?
M:6TI*2D["B`@("`@("`@9F]R("@D>"`](#`[("1X(#P@)&-O;&]R<SL@)'@K
M*RD@>PH@("`@("`@("`@("`D<W)C(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O
M;&]R<T9O<DEN9&5X)RP@87)R87DH)'1H:7,M/E]I;2P@)'@I*3L*("`@("`@
M("`@("`@:68@*&ES7V$H)'-R8RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1S<F,["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&YE=R`](&UI;B@R-34L(&%B<R@D<W)C6R=R960G72`J("1R871E4B`K
M("1S<F-;)V=R965N)UT@*B`D<F%T94<@*R`D<W)C6R=B;'5E)UT@*B`D<F%T
M94(I("L@)'=H:71E;F5S<RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E0V]L;W)3970G+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D>"P@)&YE=RP@)&YE=RP@)&YE=RDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E<&EA(&9I
M;'1E<BX*("`@("`J"B`@("`@*B!"87-I8V%L;'D@='5R;G,@=&AE(&EM86=E
M('1O(&=R87ES8V%L92!A;F0@=&AE;B!A9&1S('-O;64*("`@("`J(&1E9FEN
M960@=&EN="!O;B!I="`H4B`K/2`S,"P@1R`K/2`T,RP@0B`K/2`M,C,I('-O
M(&ET('=I;&P*("`@("`J(&%P<&5A<B!T;R!B92!A('9E<GD@;VQD('!I8W1U
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E<&EA*"D*("`@('L*("`@("`@
M("`D=&EN=%(@/2`X,#L*("`@("`@("`D=&EN=$<@/2`T,SL*("`@("`@("`D
M=&EN=$(@/2`M,C,["B`@("`@("`@)')A=&52(#T@+C(R.3L*("`@("`@("`D
M<F%T94<@/2`N-3@W.PH@("`@("`@("1R871E0B`]("XQ,30["B`@("`@("`@
M)'=H:71E;F5S<R`](#,["@H@("`@("`@(&EF("@D=&AI<RT^7V-A;&PH)VEM
M86=E27-4<G5E0V]L;W(G+"!A<G)A>2@D=&AI<RT^7VEM*2D@/3T]('1R=64I
M('L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3Y?8V%L
M;"@G:6UA9V54<G5E0V]L;W)4;U!A;&5T=&4G+"!A<G)A>2@D=&AI<RT^7VEM
M+"!T<G5E+"`R-38I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1C;VQO<G,@/2!M87@H,C4V+"`D=&AI<RT^7V-A;&PH)VEM86=E
M0V]L;W)S5&]T86PG+"!A<G)A>2@D=&AI<RT^7VEM*2DI.PH@("`@("`@(&9O
M<B`H)'@@/2`P.R`D>"`\("1C;VQO<G,[("1X*RLI('L*("`@("`@("`@("`@
M)'-R8R`]("1T:&ES+3Y?8V%L;"@G:6UA9V5#;VQO<G-&;W));F1E>"<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1X*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1S
M<F,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<W)C.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1N97<@/2!M:6XH,C4U
M+"!A8G,H)'-R8ULG<F5D)UT@*B`D<F%T95(@*R`D<W)C6R=G<F5E;B==("H@
M)')A=&5'("L@)'-R8ULG8FQU92==("H@)')A=&5"*2`K("1W:&ET96YE<W,I
M.PH@("`@("`@("`@("`D<B`](&UI;B@R-34L("1N97<@*R`D=&EN=%(I.PH@
M("`@("`@("`@("`D9R`](&UI;B@R-34L("1N97<@*R`D=&EN=$<I.PH@("`@
M("`@("`@("`D8B`](&UI;B@R-34L("1N97<@*R`D=&EN=$(I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O
M;&]R4V5T)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1R+"`D9RP@)&(I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!996QL;W=I>F4@9FEL=&5R+@H@("`@("H*("`@("`J($%D9',@82!L
M87EE<B!O9B!Y96QL;W<@=&AA="!C86X@8F4@=')A;G-P87)E;G0@;W(@<V]L
M:60N($EF"B`@("`@*B`D:6YT96YS:71Y02!I<R`R-34@=&AE(&EM86=E('=I
M;&P@8F4@,"4@=')A;G-P87)E;G0@*'-O;&ED*2X*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D:6YT96YS:71Y62`@2&]W('-T<F]N9R!S:&]U;&0@
M=&AE('EE;&QO=R`H<F5D(&%N9"!G<F5E;BD@8F4_("@P+3(U-2D*("`@("`J
M($!P87)A;2!I;G1E9V5R("1I;G1E;G-I='E"("!(;W<@=V5A:R!S:&]U;&0@
M=&AE(&)L=64@8F4_("@^/2`R+"!I;B!T:&4@<&]S:71I=F4@;&EM:70@:70@
M=VEL;"!B92!M86ME($),544@,"D*("`@("`J+PH@("`@9G5N8W1I;VX@>65L
M;&]W:7IE*"1I;G1E;G-I='E9(#T@-3`L("1I;G1E;G-I='E"(#T@,RD*("`@
M('L*("`@("`@("!I9B`H)'1H:7,M/E]C86QL*"=I;6%G94ES5')U94-O;&]R
M)RP@87)R87DH)'1H:7,M/E]I;2DI(#T]/2!T<G5E*2!["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E5')U94-O
M;&]R5&]086QE='1E)RP@87)R87DH)'1H:7,M/E]I;2P@=')U92P@,C4V*2DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V]L;W)S
M(#T@;6%X*#(U-BP@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R<U1O=&%L)RP@
M87)R87DH)'1H:7,M/E]I;2DI*3L*("`@("`@("!F;W(@*"1X(#T@,#L@)'@@
M/"`D8V]L;W)S.R`D>"LK*2!["B`@("`@("`@("`@("1S<F,@/2`D=&AI<RT^
M7V-A;&PH)VEM86=E0V]L;W)S1F]R26YD97@G+"!A<G)A>2@D=&AI<RT^7VEM
M+"`D>"DI.PH@("`@("`@("`@("!I9B`H:7-?82@D<W)C+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-R8SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D<B`](&UI;B@D<W)C6R=R960G72`K("1I;G1E
M;G-I='E9+"`R-34I.PH@("`@("`@("`@("`D9R`](&UI;B@D<W)C6R=G<F5E
M;B==("L@)&EN=&5N<VET>5DL(#(U-2D["B`@("`@("`@("`@("1B(#T@;6%X
M*"@D<B`K("1G*2`O(&UA>"@D:6YT96YS:71Y0BP@,BDL(#`I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O
M;&]R4V5T)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1R+"`D9RP@)&(I*2P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I
M;VX@=V%T97)M87)K*"1T97AT+"`D:&%L:6=N(#T@)W)I9VAT)RP@)'9A;&EG
M;B`]("=B;W1T;VTG+"`D9F]N="`]("=S;6%L;"<I"B`@("!["B`@("`@("`@
M)&-O;&]R(#T@)'1H:7,M/E]C86QL*"=I;6%G94-O;&]R0VQO<V5S="<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL(#(U-2P@,C4U+"`R-34I*3L*("`@("`@("!I9B`H
M:7-?82@D8V]L;W(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1C;VQO<CL*("`@("`@("!]"B`@("`@("`@)'-H861O=R`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V5#;VQO<D-L;W-E<W0G+"!A<G)A>2@D=&AI<RT^7VEM
M+"`P+"`P+"`P*2D["B`@("`@("`@:68@*&ES7V$H)'-H861O=RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)'-H861O=SL*("`@("`@
M("!]"@H@("`@("`@("\O(%-H861O=R!O9F9S970@:6X@<&EX96QS+@H@("`@
M("`@("1D<F]P(#T@,3L*"B`@("`@("`@+R\@36%X:6UU;2!T97AT('=I9'1H
M+@H@("`@("`@("1M87AW:61T:"`](#(P,#L*"B`@("`@("`@+R\@06UO=6YT
M(&]F('-P86-E('1O(&QE879E(&)E='=E96X@=&AE('1E>'0@86YD('1H92!I
M;6%G90H@("`@("`@("\O(&)O<F1E<BX*("`@("`@("`D<&%D9&EN9R`](#$P
M.PH*("`@("`@("`D9B`]("1T:&ES+3YG971&;VYT*"1F;VYT*3L*("`@("`@
M("`D9F]N='=I9'1H(#T@)'1H:7,M/E]C86QL*"=I;6%G949O;G17:61T:"<L
M(&%R<F%Y*"1F*2D["B`@("`@("`@:68@*&ES7V$H)&9O;G1W:61T:"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O;G1W:61T:#L*
M("`@("`@("!]"B`@("`@("`@)&9O;G1H96EG:'0@/2`D=&AI<RT^7V-A;&PH
M)VEM86=E1F]N=$AE:6=H="<L(&%R<F%Y*"1F*2D["B`@("`@("`@:68@*&ES
M7V$H)&9O;G1H96EG:'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1F;VYT:&5I9VAT.PH@("`@("`@('T*"B`@("`@("`@+R\@4V\@
M=&AA="!S:&%D;W<@:7,@;F]T(&]F9B!T:&4@:6UA9V4@=VET:"!R:6=H="!A
M;&EG;B!A;F0*("`@("`@("`O+R!B;W1T;VT@=F%L:6=N+@H@("`@("`@("1M
M87)G:6X@/2!F;&]O<B@D<&%D9&EN9R`K("1D<F]P*2`O(#(["@H@("`@("`@
M(&EF("@D;6%X=VED=&@I('L*("`@("`@("`@("`@)&UA>&-H87)S<&5R;&EN
M92`](&9L;V]R*"@D;6%X=VED=&@@+2`H)&UA<F=I;B`J(#(I*2`O("1F;VYT
M=VED=&@I.PH@("`@("`@("`@("`D=&5X="`]('=O<F1W<F%P*"1T97AT+"`D
M;6%X8VAA<G-P97)L:6YE+"`B7&XB+"`Q*3L*("`@("`@("!]"@H@("`@("`@
M("\O(%-P;&ET("1T97AT(&EN=&\@:6YD:79I9'5A;"!L:6YE<RX*("`@("`@
M("`D;&EN97,@/2!E>'!L;V1E*")<;B(L("1T97AT*3L*"B`@("`@("`@<W=I
M=&-H("@D=F%L:6=N*2!["B`@("`@("`@8V%S92`G8V5N=&5R)SH*("`@("`@
M("`@("`@)'D@/2`H)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R87DH)'1H
M:7,M/E]I;2DI("T@*"1F;VYT:&5I9VAT("H@8V]U;G0H)&QI;F5S*2DI("\@
M,CL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)V)O='1O;2<Z
M"B`@("`@("`@("`@("1Y(#T@)'1H:7,M/E]C86QL*"=I;6%G95-9)RP@87)R
M87DH)'1H:7,M/E]I;2DI("T@*"@D9F]N=&AE:6=H="`J(&-O=6YT*"1L:6YE
M<RDI("L@)&UA<F=I;BD["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`D>2`]("1M87)G:6X["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<W=I=&-H("@D:&%L:6=N*2![
M"B`@("`@("`@8V%S92`G<FEG:'0G.@H@("`@("`@("`@("!F;W)E86-H("@D
M;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R:6YG)RP@87)R87DH)'1H
M:7,M/E]I;2P@)&8L("@D=&AI<RT^7V-A;&PH)VEM86=E4U@G+"!A<G)A>2@D
M=&AI<RT^7VEM*2D@+2`D9F]N='=I9'1H("H@<W1R;&5N*"1L:6YE*2D@+2`D
M;6%R9VEN("L@)&1R;W`L("@D>2`K("1D<F]P*2P@)&QI;F4L("1S:&%D;W<I
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D
M=&AI<RT^7VEM+"`D9BP@*"1T:&ES+3Y?8V%L;"@G:6UA9V536"<L(&%R<F%Y
M*"1T:&ES+3Y?:6TI*2`M("1F;VYT=VED=&@@*B!S=')L96XH)&QI;F4I*2`M
M("1M87)G:6XL("1Y+"`D;&EN92P@)&-O;&]R*2D["B`@("`@("`@("`@("`@
M("`D>2`K/2`D9F]N=&AE:6=H=#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`G8V5N=&5R)SH*("`@("`@("`@("`@
M9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN9R<L
M(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"!F;&]O<B@H)'1H:7,M/E]C86QL*"=I
M;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J('-T
M<FQE;B@D;&EN92DI("\@,BD@*R`D9')O<"P@*"1Y("L@)&1R;W`I+"`D;&EN
M92P@)'-H861O=RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T<FEN
M9R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"!F;&]O<B@H)'1H:7,M/E]C86QL
M*"=I;6%G95-8)RP@87)R87DH)'1H:7,M/E]I;2DI("T@)&9O;G1W:61T:"`J
M('-T<FQE;B@D;&EN92DI("\@,BDL("1Y+"`D;&EN92P@)&-O;&]R*2D["B`@
M("`@("`@("`@("`@("`D>2`K/2`D9F]N=&AE:6=H=#L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@9F]R96%C:"`H)&QI;F5S(&%S("1L:6YE*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G95-T
M<FEN9R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1F+"`D;6%R9VEN("L@)&1R;W`L
M("@D>2`K("1D<F]P*2P@)&QI;F4L("1S:&%D;W<I*2P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?8V%L;"@G:6UA9V53=')I;F<G+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@
M)&UA<F=I;BP@)'DL("1L:6YE+"`D8V]L;W(I*3L*("`@("`@("`@("`@("`@
M("1Y("L]("1F;VYT:&5I9VAT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W<R!A('1E>'0@
M<W1R:6YG(&]N('1H92!I;6%G92!I;B!A('-P96-I9FEE9"!L;V-A=&EO;BP@
M=VET:`H@("`@("H@=&AE('-P96-I9FEE9"!S='EL92!I;F9O<FUA=&EO;BX*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D=&5X="`@("`@("!4:&4@
M=&5X="!T;R!D<F%W+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@("`@
M("`@5&AE(&QE9G0@>"!C;V]R9&EN871E(&]F('1H92!S=&%R="!O9B!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1E>'0@<W1R:6YG
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("`@("`@5&AE('1O<"!Y
M(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T(&]F('1H92!T97AT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D9F]N="`@("`@("!4:&4@9F]N="!I9&5N=&EF:65R('EO
M=2!W86YT('1O('5S92!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T97AT+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R
M("`@("`@5&AE(&-O;&]R('1H870@>6]U('=A;G0@=&AE('1E>'0@9&ES<&QA
M>65D(&EN+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1I<F5C=&EO;B`@06X@
M:6YT96=E<B!T:&%T('-P96-I9FEE<R!T:&4@;W)I96YT871I;VX@;V8*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!T97AT+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!T97AT*"1S=')I;F<L("1X+"`D>2P@)&9O;G0@
M/2`G;6]N;W-P86-E)RP@)&-O;&]R(#T@)V)L86-K)RP@)&1I<F5C=&EO;B`]
M(#`I"B`@("!["B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO<B@D
M8V]L;W(I.PH@("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"B`@("`@("`@)&8@
M/2`D=&AI<RT^9V5T1F]N="@D9F]N="D["B`@("`@("`@<W=I=&-H("@D9&ER
M96-T:6]N*2!["B`@("`@("`@8V%S92`M.3`Z"B`@("`@("`@8V%S92`R-S`Z
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E4W1R
M:6YG57`G+"!A<G)A>2@D=&AI<RT^7VEM+"`D9BP@)'@L("1Y+"`D<W1R:6YG
M+"`D8RDI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`P.@H@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V-A;&PH)VEM86=E4W1R:6YG)RP@87)R87DH)'1H:7,M/E]I;2P@)&8L("1X
M+"`D>2P@)'-T<FEN9RP@)&,I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(&-I<F-L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@5&AE('@@
M8V\M;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1Y("`@("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@
M("`@("H@0'!A<F%M(&EN=&5G97(@)'(@("`@(%1H92!R861I=7,@;V8@=&AE
M(&-I<F-L92X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("!4:&4@;&EN
M92!C;VQO<B!O9B!T:&4@8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9FEL;"`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!C:7)C;&4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-I<F-L92@D>"P@)'DL("1R+"`D8V]L;W(L("1F:6QL
M(#T@;G5L;"D*("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@
M("!I9B`H:7-?;G5L;"@D9FEL;"DI('L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3Y?8V%L;"@G:6UA9V5%;&QI<'-E)RP@87)R87DH)'1H:7,M/E]I
M;2P@)'@L("1Y+"`D<B`J(#(L("1R("H@,BP@)&,I*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H)&9I;&P@(3T]("1C;VQO<BD@>PH@("`@
M("`@("`@("`@("`@)&9I;&Q#;VQO<B`]("1T:&ES+3YA;&QO8V%T94-O;&]R
M*"1F:6QL*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1F:6QL0V]L;W(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&9I;&Q#;VQO<CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D
M16QL:7!S92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D
M<B`J(#(L("1F:6QL0V]L;W(I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5%;&QI<'-E)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L("1Y+"`D<B`J(#(L
M("1R("H@,BP@)&,I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E1FEL;&5D16QL
M:7!S92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R+"`D<B`J
M(#(L("1C*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$<F%W(&$@<&]L>6=O;B!B87-E9"!O;B!A('-E="!O9B!V97)T:6-E<RX*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)'9E<G1I8V5S("!!;B!A<G)A
M>2!O9B!X(&%N9"!Y(&QA8F5L960@87)R87ES"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`H96<N("1V97)T:6-E<ULP75LG>"==+"`D=F5R=&EC
M97-;,%U;)WDG72P@+BXN*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R
M("`@(%1H92!C;VQO<B!Y;W4@=V%N="!T;R!D<F%W('1H92!P;VQY9V]N('=I
M=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4:&4@8V]L;W(@
M=&\@9FEL;"!T:&4@<&]L>6=O;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<&]L
M>6=O;B@D=F5R=',L("1C;VQO<BP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@
M("`@("`@)'9E<G1I8V5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D
M=F5R=',@87,@)'9E<G0I('L*("`@("`@("`@("`@)'9E<G1I8V5S6UT@/2`D
M=F5R=%LG>"==.PH@("`@("`@("`@("`D=F5R=&EC97-;72`]("1V97)T6R=Y
M)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H)&9I;&P@(3T@)VYO;F4G*2![
M"B`@("`@("`@("`@("1F(#T@)'1H:7,M/F%L;&]C871E0V]L;W(H)&9I;&PI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D9BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1F.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E
M1FEL;&5D4&]L>6=O;B<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1V97)T:6-E<RP@
M8V]U;G0H)'9E<G1S*2P@)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@D9FEL;"`]/2`G;F]N92<@?'P@)&9I;&P@(3T@
M)&-O;&]R*2!["B`@("`@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L
M;W(H)&-O;&]R*3L*("`@("`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G95!O;'EG;VXG+"!A<G)A>2@D=&AI<RT^7VEM+"`D=F5R=&EC
M97,L(&-O=6YT*"1V97)T<RDL("1C*2DL("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1')A=R!A(')E8W1A;F=L
M92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>"`@("`@("!4:&4@
M;&5F="!X+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1Y("`@("`@(%1H92!T;W`@>2UC;V]R9&EN871E(&]F
M('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=VED=&@@
M("!4:&4@=VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1H96EG:'0@(%1H92!H96EG:'0@;V8@=&AE(')E8W1A;F=L92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL
M("`@("!4:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F5C=&%N9VQE('=I=&@N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E8W1A;F=L92@D>"P@)'DL("1W:61T:"P@
M)&AE:6=H="P@)&-O;&]R(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@
M("!["B`@("`@("`@:68@*"1F:6QL("$]("=N;VYE)RD@>PH@("`@("`@("`@
M("`D9B`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1F:6QL*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)&8L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9%)E8W1A
M;F=L92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'@@*R`D=VED=&@L
M("1Y("L@)&AE:6=H="P@)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@D9FEL;"`]/2`G;F]N92<@?'P@)&9I;&P@(3T@
M)&-O;&]R*2!["B`@("`@("`@("`@("1C(#T@)'1H:7,M/F%L;&]C871E0V]L
M;W(H)&-O;&]R*3L*("`@("`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C
M86QL*"=I;6%G95)E8W1A;F=L92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D
M>2P@)'@@*R`D=VED=&@L("1Y("L@)&AE:6=H="P@)&,I*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$<F%W
M(&$@<F]U;F1E9"!R96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@
M=&]P('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG
M;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT
M(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<F]U
M;F0@("!4:&4@=VED=&@@;V8@=&AE(&-O<FYE<B!R;W5N9&EN9RX*("`@("`J
M($!P87)A;2!S=')I;F<@)&-O;&]R("`@(%1H92!L:6YE(&-O;&]R(&]F('1H
M92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QL("`@("!4
M:&4@8V]L;W(@=&\@9FEL;"!T:&4@<F]U;F1E9"!R96-T86YG;&4@=VET:"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F]U;F1E9%)E8W1A;F=L92@D>"P@)'DL
M("1W:61T:"P@)&AE:6=H="P@)')O=6YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D
M9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("!I9B`H)')O=6YD(#P](#`I
M('L*("`@("`@("`@("`@+R\@3W!T:6UI>F4@;W5T(&%N>2!C86QL<R!W:71H
M(&YO(&-O<FYE<B!R;W5N9&EN9RX*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR96-T86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1C;VQO<BP@
M)&9I;&PI.PH@("`@("`@('T*"B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A
M=&5#;VQO<B@D8V]L;W(I.PH@("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"@H@
M("`@("`@("\O(%-E="!C;W)N97(@<&]I;G1S('1O(&%V;VED(&QO=',@;V8@
M<F5D=6YD86YT(&UA=&@N"B`@("`@("`@)'@Q(#T@)'@@*R`D<F]U;F0["B`@
M("`@("`@)'DQ(#T@)'D@*R`D<F]U;F0["@H@("`@("`@("1X,B`]("1X("L@
M)'=I9'1H("T@)')O=6YD.PH@("`@("`@("1Y,B`]("1Y("L@)')O=6YD.PH*
M("`@("`@("`D>#,@/2`D>"`K("1W:61T:"`M("1R;W5N9#L*("`@("`@("`D
M>3,@/2`D>2`K("1H96EG:'0@+2`D<F]U;F0["@H@("`@("`@("1X-"`]("1X
M("L@)')O=6YD.PH@("`@("`@("1Y-"`]("1Y("L@)&AE:6=H="`M("1R;W5N
M9#L*"B`@("`@("`@)'(@/2`D<F]U;F0@*B`R.PH*("`@("`@("`O+R!#86QC
M=6QA=&4@=&AE('5P<&5R(&QE9G0@87)C+@H@("`@("`@("1P,2`]("1T:&ES
M+3Y?87)C4&]I;G1S*"1R;W5N9"P@,3@P+"`R,C4I.PH@("`@("`@("1P,B`]
M("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@,C(U+"`R-S`I.PH*("`@("`@
M("`O+R!#86QC=6QA=&4@=&AE('5P<&5R(')I9VAT(&%R8RX*("`@("`@("`D
M<#,@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#(W,"P@,S$U*3L*("`@
M("`@("`D<#0@/2`D=&AI<RT^7V%R8U!O:6YT<R@D<F]U;F0L(#,Q-2P@,S8P
M*3L*"B`@("`@("`@+R\@0V%L8W5L871E('1H92!L;W=E<B!R:6=H="!A<F,N
M"B`@("`@("`@)'`U(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`P+"`T
M-2D["B`@("`@("`@)'`V(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O=6YD+"`T
M-2P@.3`I.PH*("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&QO=V5R(&QE9G0@
M87)C+@H@("`@("`@("1P-R`]("1T:&ES+3Y?87)C4&]I;G1S*"1R;W5N9"P@
M.3`L(#$S-2D["B`@("`@("`@)'`X(#T@)'1H:7,M/E]A<F-0;VEN=',H)')O
M=6YD+"`Q,S4L(#$X,"D["@H@("`@("`@("\O($1R87<@=&AE(&-O<FYE<G,@
M+2!U<'!E<B!L969T+"!U<'!E<B!R:6=H="P@;&]W97(@<FEG:'0L"B`@("`@
M("`@+R\@;&]W97(@;&5F="X*("`@("`@("!I9B`H:7-?82@D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X
M,2P@)'DQ+"`D<BP@)'(L(#$X,"P@,C<P+"`D8RDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R
M8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,BP@)'DR+"`D<BP@)'(L(#(W,"P@
M,S8P+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL
M("1X,RP@)'DS+"`D<BP@)'(L(#`L(#DP+"`D8RDI+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94%R
M8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X-"P@)'DT+"`D<BP@)'(L(#DP+"`Q
M.#`L("1C*2DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!$<F%W('1H92!C;VYN
M96-T:6YG('-I9&5S("T@=&]P+"!R:6=H="P@8F]T=&]M+"!L969T+@H@("`@
M("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN
M92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X,2`K("1P,ELG>#(G72P@)'DQ("L@
M)'`R6R=Y,B==+"`D>#(@*R`D<#-;)W@Q)UTL("1Y,B`K("1P,ULG>3$G72P@
M)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@)'@R
M("L@)'`T6R=X,B==+"`D>3(@*R`D<#1;)WDR)UTL("1X,R`K("1P-5LG>#$G
M72P@)'DS("L@)'`U6R=Y,2==+"`D8RDI+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G94QI;F4G+"!A
M<G)A>2@D=&AI<RT^7VEM+"`D>#,@*R`D<#9;)W@R)UTL("1Y,R`K("1P-ELG
M>3(G72P@)'@T("L@)'`W6R=X,2==+"`D>30@*R`D<#=;)WDQ)UTL("1C*2DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^
M7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X-"`K("1P
M.%LG>#(G72P@)'DT("L@)'`X6R=Y,B==+"`D>#$@*R`D<#%;)W@Q)UTL("1Y
M,2`K("1P,5LG>3$G72P@)&,I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M9FEL;"`A/2`G;F]N92<I('L*("`@("`@("`@("`@)&8@/2`D=&AI<RT^86QL
M;V-A=&5#;VQO<B@D9FEL;"D["B`@("`@("`@("`@(&EF("AI<U]A*"1F+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&8["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T
M:&ES+3Y?8V%L;"@G:6UA9V5&:6QL5&]";W)D97(G+"!A<G)A>2@D=&AI<RT^
M7VEM+"`D>"`K("@D=VED=&@@+R`R*2P@)'D@*R`H)&AE:6=H="`O(#(I+"`D
M8RP@)&8I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!$<F%W(&$@;&EN92X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>#`@("`@5&AE('@@8V\M;W)D:6YA=&4@;V8@=&AE('-T
M87)T+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DP("`@(%1H92!Y(&-O+6]R
M9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1X
M,2`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'DQ("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!E
M;F0N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@5&AE(&QI;F4@8V]L
M;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W:61T:"`@5&AE('=I9'1H(&]F
M('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:6YE*"1X,2P@)'DQ
M+"`D>#(L("1Y,BP@)&-O;&]R(#T@)V)L86-K)RP@)'=I9'1H(#T@,2D*("`@
M('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"1C;VQO<BD[
M"B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*"B`@("`@("`@+R\@1&]N)W0@
M;F5E9"!T;R!D;R!A;GET:&EN9R!S<&5C:6%L(&9O<B!S:6YG;&4M=VED=&@@
M;&EN97,N"B`@("`@("`@:68@*"1W:61T:"`]/2`Q*2!["B`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^7V-A;&PH)VEM86=E3&EN92<L(&%R<F%Y*"1T
M:&ES+3Y?:6TL("1X,2P@)'DQ+"`D>#(L("1Y,BP@)&,I*3L*("`@("`@("!]
M(&5L<V5I9B`H)'@Q(#T]("1X,BD@>PH@("`@("`@("`@("`O+R!&;W(@=F5R
M=&EC86P@;&EN97,L('=E(&-A;B!J=7-T(&1R87<@82!V97)T:6-A;`H@("`@
M("`@("`@("`O+R!R96-T86YG;&4N"B`@("`@("`@("`@("1L969T(#T@)'@Q
M("T@9FQO;W(H*"1W:61T:"`M(#$I("\@,BD["B`@("`@("`@("`@("1R:6=H
M="`]("1X,2`K(&9L;V]R*"1W:61T:"`O(#(I.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9%)E8W1A;F=L92<L(&%R
M<F%Y*"1T:&ES+3Y?:6TL("1L969T+"`D>3$L("1R:6=H="P@)'DR+"`D8RDI
M.PH@("`@("`@('T@96QS96EF("@D>3$@/3T@)'DR*2!["B`@("`@("`@("`@
M("\O($9O<B!H;W)I>F]N=&%L(&QI;F5S+"!W92!C86X@:G5S="!D<F%W(&$@
M:&]R:7IO;G1A;`H@("`@("`@("`@("`O+R!F:6QL960@<F5C=&%N9VQE+@H@
M("`@("`@("`@("`D=&]P(#T@)'DQ("T@9FQO;W(H)'=I9'1H("\@,BD["B`@
M("`@("`@("`@("1B;W1T;VT@/2`D>3$@*R!F;&]O<B@H)'=I9'1H("T@,2D@
M+R`R*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA
M9V5&:6QL961296-T86YG;&4G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>#$L("1T
M;W`L("1X,BP@)&)O='1O;2P@)&,I*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!!;F=L960@;&EN97,N"@H@("`@("`@("`@("`O+R!-86ME
M('-U<F4@=&AA="!T:&4@96YD('!O:6YT<R!O9B!T:&4@;&EN92!A<F4*("`@
M("`@("`@("`@+R\@<&5R<&5N9&EC=6QA<B!T;R!T:&4@;&EN92!I='-E;&8N
M"B`@("`@("`@("`@("1A(#T@871A;C(H)'DQ("T@)'DR+"`D>#(@+2`D>#$I
M.PH@("`@("`@("`@("`D9'@@/2`H<VEN*"1A*2`J("1W:61T:"`O(#(I.PH@
M("`@("`@("`@("`D9'D@/2`H8V]S*"1A*2`J("1W:61T:"`O(#(I.PH*("`@
M("`@("`@("`@)'9E<G1S(#T@87)R87DH)'@R("L@)&1X+"`D>3(@*R`D9'DL
M("1X,B`M("1D>"P@)'DR("T@)&1Y+"`D>#$@+2`D9'@L("1Y,2`M("1D>2P@
M)'@Q("L@)&1X+"`D>3$@*R`D9'DI.PH@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/E]C86QL*"=I;6%G949I;&QE9%!O;'EG;VXG+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D=F5R=',L(&-O=6YT*"1V97)T<RD@+R`R+"`D8RDI.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!$<F%W(&$@9&%S:&5D(&QI;F4N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'@P("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O
M9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3`@("`@("`@
M("`@(%1H92!Y(&-O+6]R9&EN871E(&]F('1H92!S=&%R="X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1X,2`@("`@("`@("`@5&AE('@@8V\M;W)D:6YA=&4@
M;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@("`@("`@
M("`@5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&-O;&]R("`@("`@("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1W:61T:"`@("`@("`@(%1H92!W:61T:"!O9B!T
M:&4@;&EN92X*("`@("`J($!P87)A;2!I;G1E9V5R("1D87-H7VQE;F=T:"`@
M5&AE(&QE;F=T:"!O9B!A(&1A<V@@;VX@=&AE(&1A<VAE9"!L:6YE"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D9&%S:%]S<&%C92`@(%1H92!L96YG=&@@;V8@
M82!S<&%C92!I;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&%S:&5D3&EN92@D>#`L("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B
M;&%C:R<L("1W:61T:"`](#$L("1D87-H7VQE;F=T:"`](#(L("1D87-H7W-P
M86-E(#T@,BD*("`@('L*("`@("`@("`D8R`]("1T:&ES+3YA;&QO8V%T94-O
M;&]R*"1C;VQO<BD["B`@("`@("`@:68@*&ES7V$H)&,L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C.PH@("`@("`@('T*("`@("`@
M("`D=R`]("1T:&ES+3YA;&QO8V%T94-O;&]R*"=W:&ET92<I.PH@("`@("`@
M(&EF("AI<U]A*"1W+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=SL*("`@("`@("!]"@H@("`@("`@("\O(%-E="!U<"!T:&4@<W1Y
M;&4@87)R87D@86-C;W)D:6YG('1O('1H92`D9&%S:%\J('!A<F%M971E<G,N
M"B`@("`@("`@)'-T>6QE(#T@87)R87DH*3L*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D9&%S:%]L96YG=&@[("1I*RLI('L*("`@("`@("`@("`@)'-T
M>6QE6UT@/2`D8SL*("`@("`@("!]"B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&1A<VA?<W!A8V4[("1I*RLI('L*("`@("`@("`@("`@)'-T>6QE6UT@
M/2`D=SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D
M=&AI<RT^7V-A;&PH)VEM86=E4V5T4W1Y;&4G+"!A<G)A>2@D=&AI<RT^7VEM
M+"`D<W1Y;&4I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V539714:&EC:VYE<W,G+"!A<G)A>2@D
M=&AI<RT^7VEM+"`D=VED=&@I*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8V%L;"@G:6UA9V5,:6YE)RP@87)R87DH)'1H:7,M/E]I;2P@
M)'@P+"`D>3`L("1X,2P@)'DQ+"!)34=?0T],3U)?4U193$5$*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$<F%W(&$@<&]L>6QI;F4@*&$@;F]N+6-L;W-E
M9"P@;F]N+69I;&QE9"!P;VQY9V]N*2!B87-E9"!O;B!A"B`@("`@*B!S970@
M;V8@=F5R=&EC97,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1V97)T
M:6-E<R`@06X@87)R87D@;V8@>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;
M)W@G72P@)'9E<G1I8V5S6S!=6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;VQO<B`@("!4:&4@8V]L;W(@>6]U('=A;G0@=&\@9')A=R!T
M:&4@;&EN92!W:71H+@H@("`@("H@0'!A<F%M('-T<FEN9R`D=VED=&@@("`@
M5&AE('=I9'1H(&]F('1H92!L:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M;VQY;&EN92@D=F5R=',L("1C;VQO<BP@)'=I9'1H(#T@,2D*("`@('L*("`@
M("`@("`D9FER<W0@/2!T<G5E.PH@("`@("`@(&9O<F5A8V@@*"1V97)T<R!A
M<R`D=F5R="D@>PH@("`@("`@("`@("!I9B`H(21F:7)S="D@>PH@("`@("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YL:6YE*"1L87-T
M6"P@)&QA<W19+"`D=F5R=%LG>"==+"`D=F5R=%LG>2==+"`D8V]L;W(L("1W
M:61T:"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1L87-T6"`]("1V97)T6R=X)UT["B`@
M("`@("`@("`@("1L87-T62`]("1V97)T6R=Y)UT["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1')A=R!A;B!A<F,N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'@@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O9B!T
M:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'D@("`@("!4:&4@
M>2!C;RUO<F1I;F%T92!O9B!T:&4@8V5N=')E+@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'(@("`@("!4:&4@<F%D:75S(&]F('1H92!A<F,N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D<W1A<G0@(%1H92!S=&%R="!A;F=L92!O9B!T:&4@
M87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&5N9"`@("!4:&4@96YD(&%N
M9VQE(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@
M(%1H92!L:6YE(&-O;&]R(&]F('1H92!A<F,N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`D9FEL;"`@(%1H92!F:6QL(&-O;&]R(&]F('1H92!A<F,@*&1E9F%U
M;'1S('1O(&YO;F4I+@H@("`@("HO"B`@("!F=6YC=&EO;B!A<F,H)'@L("1Y
M+"`D<BP@)'-T87)T+"`D96YD+"`D8V]L;W(@/2`G8FQA8VLG+"`D9FEL;"`]
M(&YU;&PI"B`@("!["B`@("`@("`@)&,@/2`D=&AI<RT^86QL;V-A=&5#;VQO
M<B@D8V]L;W(I.PH@("`@("`@(&EF("AI<U]A*"1C+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D8SL*("`@("`@("!]"B`@("`@("`@
M:68@*&ES7VYU;&PH)&9I;&PI*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V-A;&PH)VEM86=E07)C)RP@87)R87DH)'1H:7,M/E]I;2P@)'@L
M("1Y+"`D<B`J(#(L("1R("H@,BP@)'-T87)T+"`D96YD+"`D8RDI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D9FEL;"`A/3T@)&-O;&]R
M*2!["B`@("`@("`@("`@("`@("`D9B`]("1T:&ES+3YA;&QO8V%T94-O;&]R
M*"1F:6QL*3L*("`@("`@("`@("`@("`@(&EF("AI<U]A*"1F+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1F.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961!<F,G+"!A<G)A>2@D=&AI
M<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@*B`R+"`D<W1A<G0L("1E;F0L
M("1F+"!)34=?05)#7U!)12DI+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C86QL*"=I;6%G
M949I;&QE9$%R8R<L(&%R<F%Y*"1T:&ES+3Y?:6TL("1X+"`D>2P@)'(@*B`R
M+"`D<B`J(#(L("1S=&%R="P@)&5N9"P@)&,L($E-1U]!4D-?141'140@?"!)
M34=?05)#7TY/1DE,3"DI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?8V%L;"@G:6UA9V5&:6QL961!
M<F,G+"!A<G)A>2@D=&AI<RT^7VEM+"`D>"P@)'DL("1R("H@,BP@)'(@*B`R
M+"`D<W1A<G0L("1E;F0L("1C+"!)34=?05)#7U!)12DI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0W)E871E<R!A;B!I;6%G92!O9B!T:&4@9VEV96X@
M<VEZ92X*("`@("`J($EF('!O<W-I8FQE('1H92!F=6YC=&EO;B!R971U<FYS
M(&$@=')U92!C;VQO<B!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M96=E<B`D=VED=&@@("!4:&4@:6UA9V4@=VED=&@N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D:&5I9VAT("!4:&4@:6UA9V4@:&5I9VAT+@H@("`@("H*("`@
M("`J($!R971U<FX@<F5S;W5R8V5\;V)J96-T(%!%05(@17)R;W(@(%1H92!I
M;6%G92!H86YD;&5R(&]R(&$@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@97)R;W(N"B`@("`@*B\*
M("`@(&9U;F-T:6]N("9?8W)E871E*"1W:61T:"P@)&AE:6=H="D*("`@('L*
M("`@("`@("`D<F5S=6QT(#T@)B1T:&ES+3Y?8V%L;"@G:6UA9V5#<F5A=&54
M<G5E0V]L;W(G+"!A<G)A>2@D=VED=&@L("1H96EG:'0I*3L*("`@("`@("!I
M9B`H(6ES7W)E<V]U<F-E*"1R97-U;'0I*2!["B`@("`@("`@("`@("1R97-U
M;'0@/2`F)'1H:7,M/E]C86QL*"=I;6%G94-R96%T92<L(&%R<F%Y*"1W:61T
M:"P@)&AE:6=H="DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@('T*"B`@("`O*BH*("`@("`J(%=R87!S(&$@8V%L;"!T;R!A(&9U
M;F-T:6]N(&]F('1H92!G9"!E>'1E;G-I;VXN"B`@("`@*B!)9B!T:&4@8V%L
M;"!P<F]D=6-E<R!A;B!E<G)O<BP@82!014%27T5R<F]R(&ES(')E='5R;F5D
M+"!T:&4@9G5N8W1I;VX*("`@("`J(')E<W5L="!O=&AE<G=I<V4N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9G5N8W1I;VX@(%1H92!N86UE(&]F
M('1H92!F=6YC=&EO;B!T;R!W<F%P+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@("`@($%N(&%R<F%Y('=I=&@@86QL('!A<F%M971E<G,@9F]R('1H
M870@9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@16ET
M:&5R('1H92!F=6YC=&EO;B!R97-U;'0@;W(@82!014%27T5R<F]R(&EF(&%N
M(&5R<F]R"B`@("`@*B`@("`@("`@("`@("`@("!O8V-U<F5D('=H96X@97AE
M8W5T:6YG('1H92!F=6YC=&EO;BX*("`@("`J+PH@("`@9G5N8W1I;VX@)E]C
M86QL*"1F=6YC=&EO;BP@)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@
M=6YS970H)'!H<%]E<G)O<FUS9RD["B`@("`@("`@)'1R86-K(#T@:6YI7W-E
M="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@)')E<W5L="`]($!C86QL
M7W5S97)?9G5N8U]A<G)A>2@D9G5N8W1I;VXL("1P87)A;7,I.PH@("`@("`@
M(&EF("@D=')A8VL@(3T](&9A;'-E*2!["B`@("`@("`@("`@(&EN:5]S970H
M)W1R86-K7V5R<F]R<R<L("1T<F%C:RD["B`@("`@("`@?0H@("`@("`@(&EF
M("@A96UP='DH)'!H<%]E<G)O<FUS9RDI('L*("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@("1R97-U;'0@/2!014%2
M.CIR86ES945R<F]R*"1F=6YC=&EO;B`N("<Z("<@+B`D<&AP7V5R<F]R;7-G
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]);6%G92]I;2YP
M:'``````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S-S,T
M-B`Q,#4Q-30S-#$S-R`P,C$U,C(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G2&]R9&4O
M26UA9V4N<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE
M($AO<F1E7TEM86=E.CH@05!)(&9O<B!);6%G94UA9VEC:RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO26UA9V4O26UA9V4O:6TN<&AP+'8@,2XS-"XQ,"XQ
M,2`R,#`V+S`Q+S`Q(#(Q.C(X.C(R(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI:V5`
M9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0&%U=&AO
M<B`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TEM86=E"B`J
M+PIC;&%S<R!(;W)D95]);6%G95]I;2!E>'1E;F1S($AO<F1E7TEM86=E('L*
M"B`@("`O*BH*("`@("`J($-A<&%B:6QI=&5S(&]F('1H:7,@9')I=F5R+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?8V%P
M86)I;&ET:65S(#T@87)R87DH)W)E<VEZ92<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8W)O<"<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G<F]T871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=G<F%Y<V-A;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9L:7`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUI
M<G)O<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<V5P:6$G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-A;G9A<R<*("`@
M("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@+RHJ"B`@("`@*B!7:&%T
M(&MI;F0@;V8@:6UA9V5S('-H;W5L9"!);6%G94UA9VEC:R!G96YE<F%T93\@
M1&5F875L=',@=&\@)W!N9R<N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?='EP92`]("=P;F<G.PH*("`@("\J*@H@("`@
M("H@3W!E<F%T:6]N<R!T;R!B92!P97)F;W)M960N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O<&5R871I;VYS(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@<W1R;VME(&-O;&]R.R!C
M86-H960@<V\@=V4@9&]N)W0@:7-S=64@;6]R92`M<W1R;VME(&-O;6UA;F1S
M"B`@("`@*B!T:&%N(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)%]S=')O:V5#;VQO<B`](&YU;&P["@H@
M("`@+RHJ"B`@("`@*B!#=7)R96YT('-T<F]K92!W:61T:#L@8V%C:&5D('-O
M('=E(&1O;B=T(&ES<W5E(&UO<F4@+7-T<F]K97=I9'1H"B`@("`@*B!C;VUM
M86YD<R!T:&%N(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)%]S=')O:V57:61T:"`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!#=7)R96YT(&9I;&P@8V]L;W([(&-A8VAE9"!S;R!W92!D
M;VXG="!I<W-U92!M;W)E("UF:6QL(&-O;6UA;F1S('1H86X*("`@("`J(&YE
M8V5S<V%R>2X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]F:6QL0V]L;W(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@0V]N
M<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO<F1E7TEM86=E7VEM
M*"1P87)A;7,I"B`@("!["B`@("`@("`@<&%R96YT.CI(;W)D95]);6%G92@D
M<&%R86US*3L*"B`@("`@("`@:68@*"%E;7!T>2@D<&%R86US6R=T>7!E)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?='EP92`]("1P87)A;7-;)W1Y<&4G
M73L*("`@("`@("!]"@H@("`@("`@("\O($UA:V4@<W5R92!W92!S=&%R="!W
M:71H(&$@=VAI=&4@8F%C:V=R;W5N9"!T;R!B92!C;VYS:7-T96YT"B`@("`@
M("`@+R\@=VET:"!O=&AE<B!D<FEV97)S+@H@("`@("`@(&EF("@A96UP='DH
M)'!A<F%M<ULG8F%C:V=R;W5N9"==*2D@>PH@("`@("`@("`@("`D8F<@/2`D
M<&%R86US6R=B86-K9W)O=6YD)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&)G(#T@)W=H:71E)SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/G)E8W1A;F=L92@P+"`P+"`D=&AI<RT^7W=I9'1H+"`D=&AI<RT^7VAE:6=H
M="P@)&)G+"`D8F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H
M92!C;VYT96YT('1Y<&4@9F]R('1H:7,@:6UA9V4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!C;VYT96YT('1Y<&4@9F]R('1H:7,@:6UA
M9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E*"D*("`@
M('L*("`@("`@("!R971U<FX@)VEM86=E+R<@+B`D=&AI<RT^7W1Y<&4["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!R87<@9&%T82!F;W(@
M=&AI<R!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D8V]N
M=F5R="`@268@=')U92P@=&AE(&EM86=E(&1A=&$@=VEL;"!B92!R971U<FYE
M9"!I;B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T87)G
M970@9F]R;6%T+"!I;F1E<&5N9&5N=&QY(&9R;VT@86YY(&EM86=E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@;W!E<F%T:6]N<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D871A+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R87<H)&-O;G9E<G0@/2!F86QS92D*("`@
M('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@("`@("`@(&EF("@A96UP='DH
M)'1H:7,M/E]D871A*2D@>PH@("`@("`@("`@("`O+R!)9B!T:&5R92!A<F4@
M;F\@;W!E<F%T:6]N<RP@86YD('=E(&%L<F5A9'D@:&%V92!D871A+`H@("`@
M("`@("`@("`O+R!D;VXG="!B;W1H97(@=W)I=&EN9R!O=70@9FEL97,L(&IU
M<W0@<F5T=7)N('1H92!C=7)R96YT"B`@("`@("`@("`@("\O(&1A=&$N"B`@
M("`@("`@("`@(&EF("@A)&-O;G9E<G0@)B8@(6-O=6YT*"1T:&ES+3Y?;W!E
M<F%T:6]N<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1A
M=&$["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T;7!I;B`]("1T:&ES
M+3YT;T9I;&4H)'1H:7,M/E]D871A*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!#<F5A=&4@86X@96UP='D@4%!-(&9I;&4@=&\@;&]A9"X*
M("`@("`@("`@("`@)'1M<&EN(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM9R<L
M(&9A;'-E+"`D=&AI<RT^7W1M<&1I<BD["B`@("`@("`@("`@("1F<"`](&9O
M<&5N*"1T;7!I;BP@)W=B)RD["B`@("`@("`@("`@(&9W<FET92@D9G`L('-P
M<FEN=&8H(E`S7&XE9"`E9%QN,C4U7&X@(BP@)'1H:7,M/E]W:61T:"P@)'1H
M:7,M/E]H96EG:'0I*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@
M("`@?0H*("`@("`@("`D=&UP;W5T(#T@571I;#HZ9V5T5&5M<$9I;&4H)VEM
M9R<L(&9A;'-E+"`D=&AI<RT^7W1M<&1I<BD["@H@("`@("`@("1C;VUM86YD
M("`]("1C;VYF6R=I;6%G92==6R=C;VYV97)T)UT["B`@("`@("`@)&-O;6UA
M;F0@+CT@)R`G("X@:6UP;&]D92@G("<L("1T:&ES+3Y?;W!E<F%T:6]N<RD[
M"B`@("`@("`@)&-O;6UA;F0@+CT@)R`B)R`N("1T;7!I;B`N("<B("MP<F]F
M:6QE("(J(B`G("X@)'1H:7,M/E]T>7!E("X@)SHB)R`N("1T;7!O=70@+B`G
M(B`R/B8Q)SL*"B`@("`@("`@97AE8R@D8V]M;6%N9"P@)&]U='!U="P@)')E
M='9A;"D["@H@("`@("`@("1T:&ES+3Y?9&%T82`](&9I;&5?9V5T7V-O;G1E
M;G1S*"1T;7!O=70I.PH*("`@("`@("!`=6YL:6YK*"1T;7!I;BD["B`@("`@
M("`@0'5N;&EN:R@D=&UP;W5T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&%T83L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T('1H92!I;6%G92!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I"B`@("!["B`@("`@
M("`@<&%R96YT.CIR97-E="@I.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N
M<R`](&%R<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-I>F4@=&AE
M(&-U<G)E;G0@:6UA9V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'=I9'1H("`@5&AE(&YE=R!W:61T:"X*("`@("`J($!P87)A;2!I;G1E9V5R
M("1H96EG:'0@(%1H92!N97<@:&5I9VAT+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)')A=&EO("`@36%I;G1A:6X@;W)I9VEN86P@87-P96-T(')A=&EO+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!R97-I>F4H)'=I9'1H+"`D:&5I9VAT+"`D
M<F%T:6\@/2!T<G5E*0H@("`@>PH@("`@("`@(&EF("@D<F%T:6\I('L*("`@
M("`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+7-I>F4@>R1W:61T
M:'UX>R1H96EG:'1]("UR97-I>F4@>R1W:61T:'UX>R1H96EG:'1](CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;
M72`]("(M<VEZ92![)'=I9'1H?7A[)&AE:6=H='T@+7)E<VEZ92![)'=I9'1H
M?7A[)&AE:6=H='TA(CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F]P('1H92!C=7)R96YT(&EM86=E+@H@("`@("H*("`@("`J($!P87)A
M;2!I;G1E9V5R("1X,2`@5&AE('1O<"!L969T(&-O<FYE<B!O9B!T:&4@8W)O
M<'!E9"!I;6%G92X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,2`@5&AE('1O
M<"!R:6=H="!C;W)N97(@;V8@=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>#(@(%1H92!B;W1T;VT@;&5F="!C;W)N97(@;V8@
M=&AE(&-R;W!P960@:6UA9V4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3(@
M(%1H92!B;W1T;VT@<FEG:'0@8V]R;F5R(&]F('1H92!C<F]P<&5D(&EM86=E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F]P*"1X,2P@)'DQ+"`D>#(L("1Y
M,BD*("`@('L*("`@("`@("`D;&EN92`]("@D>#(@+2`D>#$I("X@)W@G("X@
M*"1Y,B`M("1Y,2D@+B`G*R<@+B`D>#$@+B`G*R<@+B`D>3(["B`@("`@("`@
M)'1H:7,M/E]O<&5R871I;VYS6UT@/2`G+6-R;W`@)R`N("1L:6YE.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F]T871E('1H92!C=7)R96YT(&EM86=E+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A;F=L92`@("`@("!4:&4@
M86YG;&4@=&\@<F]T871E('1H92!I;6%G92!B>2P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I;B!T:&4@8VQO8VMW:7-E(&1I<F5C=&EO
M;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1B86-K9W)O=6YD("!4:&4@8F%C
M:V=R;W5N9"!C;VQO<B!T;R!F:6QL(&%N>2!T<FEA;F=L97,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')O=&%T92@D86YG;&4L("1B86-K9W)O=6YD(#T@)W=H
M:71E)RD*("`@('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M
M<F]T871E('LD86YG;&5]("UB86-K9W)O=6YD("1B86-K9W)O=6YD(CL*("`@
M('T*"B`@("`O*BH*("`@("`J($9L:7`@=&AE(&-U<G)E;G0@:6UA9V4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9L:7`H*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?;W!E<F%T:6]N<UM=(#T@)RUF;&EP)SL*("`@('T*"B`@("`O*BH*("`@
M("`J($UI<G)O<B!T:&4@8W5R<F5N="!I;6%G92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;6ER<F]R*"D*("`@('L*("`@("`@("`D=&AI<RT^7V]P97)A=&EO
M;G-;72`]("<M9FQO<"<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T
M('1H92!C=7)R96YT(&EM86=E('1O(&=R87ES8V%L92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9W)A>7-C86QE*"D*("`@('L*("`@("`@("`D=&AI<RT^7V]P
M97)A=&EO;G-;72`]("<M8V]L;W)S<&%C92!'4D%9("UC;VQO<G,@,C4V)SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E<&EA(&9I;'1E<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5P:6$H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;W!E
M<F%T:6]N<UM=(#T@)RUM;V1U;&%T92`Q,3`@+6-O;&]R<W!A8V4@1U)!62`M
M8V]L;W)S(#(U-B`M9V%M;6$@,2XR-2\Q+S`N-C8G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1')A=W,@82!T97AT('-T<FEN9R!O;B!T:&4@:6UA9V4@:6X@
M82!S<&5C:69I960@;&]C871I;VXL('=I=&@*("`@("`J('1H92!S<&5C:69I
M960@<W1Y;&4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)'1E>'0@("`@("`@5&AE('1E>'0@=&\@9')A=RX*("`@("`J($!P
M87)A;2!I;G1E9V5R("1X("`@("`@("`@(%1H92!L969T('@@8V]O<F1I;F%T
M92!O9B!T:&4@<W1A<G0@;V8@=&AE('1E>'0@<W1R:6YG+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'D@("`@("`@("`@5&AE('1O<"!Y(&-O;W)D:6YA=&4@
M;V8@=&AE('-T87)T(&]F('1H92!T97AT('-T<FEN9RX*("`@("`J($!P87)A
M;2!S=')I;F<@("1F;VYT("`@("`@(%1H92!F;VYT(&ED96YT:69I97(@>6]U
M('=A;G0@=&\@=7-E(&9O<B!T:&4@=&5X="X*("`@("`J($!P87)A;2!S=')I
M;F<@("1C;VQO<B`@("`@(%1H92!C;VQO<B!T:&%T('EO=2!W86YT('1H92!T
M97AT(&1I<W!L87EE9"!I;BX*("`@("`J($!P87)A;2!I;G1E9V5R("1D:7)E
M8W1I;VX@($%N(&EN=&5G97(@=&AA="!S<&5C:69I97,@=&AE(&]R:65N=&%T
M:6]N(&]F('1H92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!T97AT*"1S
M=')I;F<L("1X+"`D>2P@)&9O;G0@/2`G7W-A;G,G+"`D8V]L;W(@/2`G8FQA
M8VLG+"`D9&ER96-T:6]N(#T@,"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T
M4W1R;VME0V]L;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME
M5VED=&@H,2D["@H@("`@("`@("1S=')I;F<@/2!A9&1S;&%S:&5S*"<B)R`N
M("1S=')I;F<@+B`G(B<I.PH@("`@("`@("1Y(#T@)'D@*R`Q,CL*("`@("`@
M("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<(G1E>'0@)'@L)'D@
M)'-T<FEN9UPB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!C:7)C
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@("`@(%1H92!X
M(&-O;W)D:6YA=&4@;V8@=&AE(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E
M9V5R("1Y("`@("!4:&4@>2!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D<B`@("`@5&AE(')A9&EU<R!O9B!T:&4@
M8VER8VQE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@(%1H92!L:6YE
M(&-O;&]R(&]F('1H92!C:7)C;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F
M:6QL("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(&-I<F-L92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8VER8VQE*"1X+"`D>2P@)'(L("1C;VQO<BP@)&9I;&P@
M/2`G;F]N92<I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R
M*"1C;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=$9I;&Q#;VQO<B@D9FEL;"D[
M"@H@("`@("`@("1X36%X(#T@)'@@*R`D<CL*("`@("`@("`D=&AI<RT^7V]P
M97)A=&EO;G-;72`]("(M9')A=R!<(F-I<F-L92`D>"PD>2`D>$UA>"PD>5PB
M(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!P;VQY9V]N(&)A<V5D
M(&]N(&$@<V5T(&]F('9E<G1I8V5S+@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D=F5R=&EC97,@($%N(&%R<F%Y(&]F('@@86YD('D@;&%B96QE9"!A
M<G)A>7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("AE9RX@)'9E
M<G1I8V5S6S!=6R=X)UTL("1V97)T:6-E<ULP75LG>2==+"`N+BXI+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]L;W(@("`@5&AE(&-O;&]R('EO=2!W86YT
M('1O(&1R87<@=&AE('!O;'EG;VX@=VET:"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&9I;&P@("`@(%1H92!C;VQO<B!T;R!F:6QL('1H92!P;VQY9V]N+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!P;VQY9V]N*"1V97)T<RP@)&-O;&]R+"`D
M9FEL;"`]("=N;VYE)RD*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME
M0V]L;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F
M:6QL*3L*"B`@("`@("`@)&-O;6UA;F0@/2`G)SL*("`@("`@("!F;W)E86-H
M("@D=F5R=',@87,@)'9E<G0I('L*("`@("`@("`@("`@)&-O;6UA;F0@+CT@
M<W!R:6YT9B@G("5D+"5D)RP@)'9E<G1;)W@G72P@)'9E<G1;)WDG72D["B`@
M("`@("`@?0H@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W
M(%PB<&]L>6=O;B`D8V]M;6%N9%PB(CL*("`@('T*"B`@("`O*BH*("`@("`J
M($1R87<@82!R96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'@@("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T
M86YG;&4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P
M('DM8V]O<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F
M('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@
M("!4:&4@;&EN92!C;VQO<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E
M8W1A;F=L92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5C=&%N9VQE*"1X+"`D
M>2P@)'=I9'1H+"`D:&5I9VAT+"`D8V]L;W(L("1F:6QL(#T@)VYO;F4G*0H@
M("`@>PH@("`@("`@("1T:&ES+3YS9713=')O:V5#;VQO<B@D8V]L;W(I.PH@
M("`@("`@("1T:&ES+3YS971&:6QL0V]L;W(H)&9I;&PI.PH*("`@("`@("`D
M>$UA>"`]("1X("L@)'=I9'1H.PH@("`@("`@("1Y36%X(#T@)'D@*R`D:&5I
M9VAT.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB
M<F5C=&%N9VQE("1X+"1Y("1X36%X+"1Y36%X7"(B.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1')A=R!A(')O=6YD960@<F5C=&%N9VQE+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("1X("`@("`@(%1H92!L969T('@M8V]O<F1I
M;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'D@("`@("`@5&AE('1O<"!Y+6-O;W)D:6YA=&4@;V8@=&AE(')E8W1A;F=L
M92X*("`@("`J($!P87)A;2!I;G1E9V5R("1W:61T:"`@(%1H92!W:61T:"!O
M9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&AE:6=H
M="`@5&AE(&AE:6=H="!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)')O=6YD("`@5&AE('=I9'1H(&]F('1H92!C;W)N97(@<F]U
M;F1I;F<N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8V]L;W(@("!4:&4@;&EN
M92!C;VQO<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`@)&9I;&P@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')O=6YD960@<F5C
M=&%N9VQE('=I=&@N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O=6YD961296-T
M86YG;&4H)'@L("1Y+"`D=VED=&@L("1H96EG:'0L("1R;W5N9"P@)&-O;&]R
M+"`D9FEL;"D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME0V]L;W(H
M)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"1F:6QL*3L*
M"B`@("`@("`@)'@Q(#T@)'@@*R`D=VED=&@["B`@("`@("`@)'DQ(#T@)'D@
M*R`D:&5I9VAT.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD
M<F%W(%PB<F]U;F1296-T86YG;&4@)'@L)'D@)'@Q+"1Y,2P@)')O=6YD+"1R
M;W5N9%PB(CL*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@82!L:6YE+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1X,"`@("`@5&AE('@@8V]O
M<F1I;F%T92!O9B!T:&4@<W1A<G0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D
M>3`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@
M0'!A<F%M(&EN=&5G97(@)'@Q("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H
M92!E;F0N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>3$@("`@(%1H92!Y(&-O
M;W)D:6YA=&4@;V8@=&AE(&5N9"X*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;&]R("`@5&AE(&QI;F4@8V]L;W(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1W
M:61T:"`@(%1H92!W:61T:"!O9B!T:&4@;&EN92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&EN92@D>#`L("1Y,"P@)'@Q+"`D>3$L("1C;VQO<B`]("=B;&%C
M:R<L("1W:61T:"`](#$I"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K
M94-O;&]R*"1C;VQO<BD["B`@("`@("`@)'1H:7,M/G-E=%-T<F]K95=I9'1H
M*"1W:61T:"D["B`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R
M87<@7")L:6YE("1X,"PD>3`@)'@Q+"1Y,5PB(CL*("`@('T*"B`@("`O*BH*
M("`@("`J($1R87<@82!D87-H960@;&EN92X*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D>#`@("`@("`@("`@(%1H92!X(&-O+6]R9&EN871E(&]F
M('1H92!S=&%R="X*("`@("`J($!P87)A;2!I;G1E9V5R("1Y,"`@("`@("`@
M("`@5&AE('D@8V\M;W)D:6YA=&4@;V8@=&AE('-T87)T+@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)'@Q("`@("`@("`@("!4:&4@>"!C;RUO<F1I;F%T92!O
M9B!T:&4@96YD+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'DQ("`@("`@("`@
M("!4:&4@>2!C;RUO<F1I;F%T92!O9B!T:&4@96YD+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8V]L;W(@("`@("`@("!4:&4@;&EN92!C;VQO<BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'=I9'1H("`@("`@("`@5&AE('=I9'1H(&]F('1H
M92!L:6YE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&1A<VA?;&5N9W1H("!4
M:&4@;&5N9W1H(&]F(&$@9&%S:"!O;B!T:&4@9&%S:&5D(&QI;F4*("`@("`J
M($!P87)A;2!I;G1E9V5R("1D87-H7W-P86-E("`@5&AE(&QE;F=T:"!O9B!A
M('-P86-E(&EN('1H92!D87-H960@;&EN90H@("`@("HO"B`@("!F=6YC=&EO
M;B!D87-H961,:6YE*"1X,"P@)'DP+"`D>#$L("1Y,2P@)&-O;&]R(#T@)V)L
M86-K)RP@)'=I9'1H(#T@,2P@)&1A<VA?;&5N9W1H(#T@,BP@)&1A<VA?<W!A
M8V4@/2`R*0H@("`@>PH@("`@("`@("1T:&ES+3YS9713=')O:V5#;VQO<B@D
M8V]L;W(I.PH@("`@("`@("1T:&ES+3YS9713=')O:V57:61T:"@D=VED=&@I
M.PH@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB;&EN
M92`D>#`L)'DP("1X,2PD>3%<(B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M<F%W(&$@<&]L>6QI;F4@*&$@;F]N+6-L;W-E9"P@;F]N+69I;&QE9"!P;VQY
M9V]N*2!B87-E9"!O;B!A"B`@("`@*B!S970@;V8@=F5R=&EC97,N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1V97)T:6-E<R`@06X@87)R87D@;V8@
M>"!A;F0@>2!L86)E;&5D(&%R<F%Y<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@*&5G+B`D=F5R=&EC97-;,%U;)W@G72P@)'9E<G1I8V5S6S!=
M6R=Y)UTL("XN+BDN"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4
M:&4@8V]L;W(@>6]U('=A;G0@=&\@9')A=R!T:&4@;&EN92!W:71H+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=VED=&@@("`@5&AE('=I9'1H(&]F('1H92!L
M:6YE+@H@("`@("HO"B`@("!F=6YC=&EO;B!P;VQY;&EN92@D=F5R=',L("1C
M;VQO<BP@)'=I9'1H(#T@,2D*("`@('L*("`@("`@("`D=&AI<RT^<V5T4W1R
M;VME0V]L;W(H)&-O;&]R*3L*("`@("`@("`D=&AI<RT^<V5T4W1R;VME5VED
M=&@H)'=I9'1H*3L*("`@("`@("`D=&AI<RT^<V5T1FEL;$-O;&]R*"=N;VYE
M)RD["@H@("`@("`@("1C;VUM86YD(#T@)R<["B`@("`@("`@9F]R96%C:"`H
M)'9E<G1S(&%S("1V97)T*2!["B`@("`@("`@("`@("1C;VUM86YD("X]('-P
M<FEN=&8H)R`E9"PE9"<L("1V97)T6R=X)UTL("1V97)T6R=Y)UTI.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9')A=R!<
M(G!O;'EL:6YE("1C;VUM86YD7"(B.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1')A=R!A;B!A<F,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@
M("`@("!4:&4@>"!C;V]R9&EN871E(&]F('1H92!C96YT<F4N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D>2`@("`@(%1H92!Y(&-O;W)D:6YA=&4@;V8@=&AE
M(&-E;G1R92X*("`@("`J($!P87)A;2!I;G1E9V5R("1R("`@("`@5&AE(')A
M9&EU<R!O9B!T:&4@87)C+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'-T87)T
M("!4:&4@<W1A<G0@86YG;&4@;V8@=&AE(&%R8RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("1E;F0@("`@5&AE(&5N9"!A;F=L92!O9B!T:&4@87)C+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&-O;&]R("!4:&4@;&EN92!C;VQO<B!O9B!T
M:&4@87)C+@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&9I;&P@("!4:&4@9FEL
M;"!C;VQO<B!O9B!T:&4@87)C("AD969A=6QT<R!T;R!N;VYE*2X*("`@("`J
M+PH@("`@9G5N8W1I;VX@87)C*"1X+"`D>2P@)'(L("1S=&%R="P@)&5N9"P@
M)&-O;&]R(#T@)V)L86-K)RP@)&9I;&P@/2`G;F]N92<I"B`@("!["B`@("`@
M("`@)'1H:7,M/G-E=%-T<F]K94-O;&]R*"1C;VQO<BD["B`@("`@("`@)'1H
M:7,M/G-E=$9I;&Q#;VQO<B@D9FEL;"D["@H@("`@("`@("\O(%-P;&ET('5P
M(&%R8W,@9W)E871E<B!T:&%N(#$X,"!D96=R965S(&EN=&\@='=O('!I96-E
M<RX*("`@("`@("`D;6ED(#T@<F]U;F0H*"1S=&%R="`K("1E;F0I("\@,BD[
M"B`@("`@("`@)'@@/2!R;W5N9"@D>"D["B`@("`@("`@)'D@/2!R;W5N9"@D
M>2D["B`@("`@("`@)'(@/2!R;W5N9"@D<BD["B`@("`@("`@:68@*"1M:60@
M/B`Y,"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M
M9')A=R!<(F5L;&EP<V4@)'@L)'D@)'(L)'(@)'-T87)T+"1M:61<(B(["B`@
M("`@("`@("`@("1T:&ES+3Y?;W!E<F%T:6]N<UM=(#T@(BUD<F%W(%PB96QL
M:7!S92`D>"PD>2`D<BPD<B`D;6ED+"1E;F1<(B(["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/E]O<&5R871I;VYS6UT@/2`B+61R87<@
M7")E;&QI<'-E("1X+"1Y("1R+"1R("1S=&%R="PD96YD7"(B.PH@("`@("`@
M('T*"B`@("`@("`@+R\@268@9FEL;&5D+"!D<F%W('1H92!O=71L:6YE+@H@
M("`@("`@(&EF("@A96UP='DH)&9I;&PI*2!["B`@("`@("`@("`@(&QI<W0H
M)'@Q+"`D>3$I(#T@)'1H:7,M/E]C:7)C;&50;VEN="@D<W1A<G0L("1R("H@
M,BD["B`@("`@("`@("`@(&QI<W0H)'@R+"`D>3(I(#T@)'1H:7,M/E]C:7)C
M;&50;VEN="@D;6ED+"`D<B`J(#(I.PH@("`@("`@("`@("!L:7-T*"1X,RP@
M)'DS*2`]("1T:&ES+3Y?8VER8VQE4&]I;G0H)&5N9"P@)'(@*B`R*3L*"B`@
M("`@("`@("`@("\O(%1H:7,@<V5E;7,@=&\@<F5S=6QT(&EN('-L:6=H=&QY
M(&)E='1E<B!P;&%C96UE;G0@;V8*("`@("`@("`@("`@+R\@<&EE('-L:6-E
M<RX*("`@("`@("`@("`@)'@K*SL*("`@("`@("`@("`@)'DK*SL*"B`@("`@
M("`@("`@("1V97)T<R`](&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X,RP@
M)WDG(#T^("1Y("L@)'DS*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)W@G(#T^("1X+"`G>2<@/3X@)'DI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G>"<@/3X@)'@@*R`D>#$L("=Y)R`]/B`D>2`K
M("1Y,2DI.PH*("`@("`@("`@("`@:68@*"1M:60@/B`Y,"D@>PH@("`@("`@
M("`@("`@("`@)'9E<G1S,2`](&%R<F%Y*&%R<F%Y*"=X)R`]/B`D>"`K("1X
M,BP@)WDG(#T^("1Y("L@)'DR*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G>"<@/3X@)'@L("=Y)R`]/B`D>2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W@G(#T^("1X("L@)'@Q
M+"`G>2<@/3X@)'D@*R`D>3$I*3L*("`@("`@("`@("`@("`@("1V97)T<S(@
M/2!A<G)A>2AA<G)A>2@G>"<@/3X@)'@@*R`D>#,L("=Y)R`]/B`D>2`K("1Y
M,RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W@G
M(#T^("1X+"`G>2<@/3X@)'DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=X)R`]/B`D>"`K("1X,BP@)WDG(#T^("1Y("L@)'DR
M*2D["@H@("`@("`@("`@("`@("`@)'1H:7,M/G!O;'EG;VXH)'9E<G1S,2P@
M)&9I;&PL("1F:6QL*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP;VQY9V]N
M*"1V97)T<S(L("1F:6QL+"`D9FEL;"D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]L>6=O;B@D=F5R=',L("1F:6QL
M+"`D9FEL;"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YP
M;VQY;&EN92@D=F5R=',L("1C;VQO<BD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@0VAA;F=E('1H92!C=7)R96YT('-T<F]K92!C;VQO<BX@
M5VEL;"!O;FQY(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@("H@<W1R:6YG(&EF
M("1S=')O:V4@:7,@9&EF9F5R96YT(&9R;VT@=&AE('!R979I;W5S('-T<F]K
M92!C;VQO<@H@("`@("H@*'-T;W)E9"!I;B`D=&AI<RT^7W-T<F]K94-O;&]R
M*2X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S964@
M)%]S=')O:V5#;VQO<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-O
M;&]R("!4:&4@;F5W('-T<F]K92!C;VQO<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T4W1R;VME0V]L;W(H)&-O;&]R*0H@("`@>PH@("`@("`@(&EF("@D
M8V]L;W(@(3T@)'1H:7,M/E]S=')O:V5#;VQO<BD@>PH@("`@("`@("`@("`D
M=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<W1R;VME("1C;VQO<B(["B`@("`@
M("`@("`@("1T:&ES+3Y?<W1R;VME0V]L;W(@/2`D8V]L;W(["B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@0VAA;F=E('1H92!C=7)R96YT('-T
M<F]K92!W:61T:"X@5VEL;"!O;FQY(&%F9F5C="!T:&4@8V]M;6%N9`H@("`@
M("H@<W1R:6YG(&EF("1W:61T:"!I<R!D:69F97)E;G0@9G)O;2!T:&4@<')E
M=FEO=7,@<W1R;VME('=I9'1H"B`@("`@*B`H<W1O<F5D(&EN("1T:&ES+3Y?
M<W1R;VME5VED=&@I+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H@0'-E92`D7W-T<F]K90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'=I9'1H("!4:&4@;F5W('-T<F]K92!W:61T:"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T4W1R;VME5VED=&@H)'=I9'1H*0H@("`@>PH@("`@("`@
M(&EF("@D=VED=&@@(3T@)'1H:7,M/E]S=')O:V57:61T:"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M<W1R;VME=VED=&@@)'=I
M9'1H(CL*("`@("`@("`@("`@)'1H:7,M/E]S=')O:V57:61T:"`]("1W:61T
M:#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V4@=&AE
M(&-U<G)E;G0@9FEL;"!C;VQO<BX@5VEL;"!O;FQY(&%F9F5C="!T:&4@8V]M
M;6%N9`H@("`@("H@<W1R:6YG(&EF("1C;VQO<B!I<R!D:69F97)E;G0@9G)O
M;2!T:&4@<')E=FEO=7,@9FEL;"!C;VQO<@H@("`@("H@*'-T;W)E9"!I;B`D
M=&AI<RT^7V9I;&Q#;VQO<BDN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B!`<V5E("1?9FEL;`H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;&]R("!4:&4@;F5W(&9I;&P@8V]L;W(N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=$9I;&Q#;VQO<B@D8V]L;W(I"B`@("!["B`@("`@("`@
M:68@*"1C;VQO<B`A/2`D=&AI<RT^7V9I;&Q#;VQO<BD@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]P97)A=&EO;G-;72`]("(M9FEL;"`D8V]L;W(B.PH@("`@
M("`@("`@("`D=&AI<RT^7V9I;&Q#;VQO<B`]("1C;VQO<CL*("`@("`@("!]
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+VQI8B](;W)D92]);6%G92]P;F<N<&AP````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`Q-34S,B`Q,#4Q-30S-#$S-R`P,C$V-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO26UA9V4N
M<&AP)SL*"B\J*@H@*B!4:&ES(&-L87-S(&EM<&QE;65N=',@=&AE($AO<F1E
M7TEM86=E.CH@05!)(&9O<B!03D<@:6UA9V5S+B!)=`H@*B!M86EN;'D@<')O
M=FED97,@<V]M92!U=&EL:71Y(&9U;F-T:6]N<RP@<W5C:"!A<R!T:&4@86)I
M;&ET>2!T;R!M86ME"B`J('!I>&5L<R!O<B!S;VQI9"!I;6%G97,@9F]R(&YO
M=RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO26UA9V4O26UA9V4O<&YG+G!H
M<"QV(#$N,3DN,3`N."`R,#`V+S`U+S,Q(#$W.C`V.C,V('-E;'-K>2!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UI:V4@0V]C:')A;F4@/&UI
M:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!-:6ME($-O8VAR86YE(#QM:6ME0&=R869T;VYH86QL+F-O+FYZ/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?26UA9V4*
M("HO"F-L87-S($AO<F1E7TEM86=E7W!N9R!E>'1E;F1S($AO<F1E7TEM86=E
M('L*"B`@("`O*BH*("`@("`J(%1H92!A<G)A>2!O9B!P:7AE;"!D871A+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?:6UG
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;&]R(&1E<'1H("AO;FQY
M(#@@86YD(#$V(&EM<&QE;65N=&5D*2X*("`@("`J"B`@("`@*B!`=F%R(&EN
M=&5G97(*("`@("`J+PH@("`@=F%R("1?8V]L;W)$97!T:"`](#@["@H@("`@
M+RHJ"B`@("`@*B!#;VQO<B!T>7!E("AO;FQY(#(@*'1R=64@8V]L;W(I(&EM
M<&QE;65N=&5D*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M+PH@("`@=F%R("1?8V]L;W)4>7!E(#T@,CL*"B`@("`O*BH*("`@("`J($-O
M;7!R97-S:6]N(&UE=&AO9"`H,"!I<R!T:&4@;VYL>2!C=7)R96YT('9A;&ED
M('9A;'5E*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?8V]M<')E<W-I;VY-971H;V0@/2`P.PH*("`@("\J*@H@("`@
M("H@1FEL=&5R(&UE=&AO9"`H,"!I<R!T:&4@;VYL>2!C=7)R96YT('9A;&ED
M('9A;'5E*2X*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?9FEL=&5R365T:&]D(#T@,#L*"B`@("`O*BH*("`@("`J($EN
M=&5R;&%C92!M971H;V0@*&]N;'D@,"`H;F\@:6YT97)L86-E*2!I;7!L96UE
M;G1E9"DN"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@
M('9A<B`D7VEN=&5R;&%C94UE=&AO9"`](#`["@H@("`@+RHJ"B`@("`@*B!0
M3D<@:6UA9V4@8V]N<W1R=6-T;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N($AO
M<F1E7TEM86=E7W!N9R@D<&%R86US*0H@("`@>PH@("`@("`@('!A<F5N=#HZ
M2&]R9&5?26UA9V4H)'!A<F%M<RD["@H@("`@("`@(&EF("@A96UP='DH)'!A
M<F%M<ULG=VED=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/G)E8W1A;F=L
M92@P+"`P+"`D<&%R86US6R=W:61T:"==+"`D<&%R86US6R=H96EG:'0G72P@
M)'1H:7,M/E]B86-K9W)O=6YD+"`D=&AI<RT^7V)A8VMG<F]U;F0I.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G971#;VYT96YT5'EP92@I"B`@
M("!["B`@("`@("`@<F5T=7)N("=I;6%G92]P;F<G.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N('1H92!R87<@9&%T82!F;W(@=&AI<R!I;6%G92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(')A=R!I;6%G92!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R87<H*0H@("`@>PH@("`@("`@
M(')E='5R;@H@("`@("`@("`@("`D=&AI<RT^7VAE861E<B@I("X*("`@("`@
M("`@("`@)'1H:7,M/E])2$12*"D@+@H*("`@("`@("`@("`@+RH@4V%Y('=H
M870@8W)E871E9"!T:&4@:6UA9V4@9FEL92X@*B\*("`@("`@("`@("`@)'1H
M:7,M/E]T15AT*"=3;V9T=V%R92<L("=(;W)D92!&<F%M97=O<FL@26UA9V5?
M<&YG($-L87-S)RD@+@H*("`@("`@("`@("`@+RH@4V5T('1H92!L87-T(&UO
M9&EF:65D(&1A=&4O=&EM92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]T24U%
M*"D@+@H*("`@("`@("`@("`@)'1H:7,M/E])1$%4*"D@+@H@("`@("`@("`@
M("`D=&AI<RT^7TE%3D0H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E<V5T
M('1H92!I;6%G92!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97-E="@I
M"B`@("!["B`@("`@("`@<&%R96YT.CIR97-E="@I.PH@("`@("`@("1T:&ES
M+3Y?:6UG(#T@87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J($1R87<@
M82!R96-T86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'@@
M("`@("`@5&AE(&QE9G0@>"UC;V]R9&EN871E(&]F('1H92!R96-T86YG;&4N
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D>2`@("`@("!4:&4@=&]P('DM8V]O
M<F1I;F%T92!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@)'=I9'1H("`@5&AE('=I9'1H(&]F('1H92!R96-T86YG;&4N"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`D:&5I9VAT("!4:&4@:&5I9VAT(&]F('1H92!R
M96-T86YG;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VQO<B`@("!4:&4@
M;&EN92!C;VQO<B!O9B!T:&4@<F5C=&%N9VQE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9FEL;"`@("`@5&AE(&-O;&]R('1O(&9I;&P@=&AE(')E8W1A;F=L
M92!W:71H+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96-T86YG;&4H)'@L("1Y
M+"`D=VED=&@L("1H96EG:'0L("1C;VQO<B`]("=B;&%C:R<L("1F:6QL(#T@
M)VYO;F4G*0H@("`@>PH@("`@("`@(&QI<W0H)'(L("1G+"`D8BD@/2`D=&AI
M<RT^9V5T4D="*"1C;VQO<BD["B`@("`@("`@:68@*"1F:6QL("$]("=N;VYE
M)RD@>PH@("`@("`@("`@("!L:7-T*"1F4BP@)&9'+"`D9D(I(#T@)'1H:7,M
M/F=E=%)'0B@D9FEL;"D["B`@("`@("`@?0H*("`@("`@("`D>#(@/2`D>"`K
M("1W:61T:#L*("`@("`@("`D>3(@/2`D>2`K("1H96EG:'0["@H@("`@("`@
M(&9O<B`H)&@@/2`D>3L@)&@@/#T@)'DR.R`D:"LK*2!["B`@("`@("`@("`@
M(&9O<B`H)'<@/2`D>#L@)'<@/#T@)'@R.R`D=RLK*2!["B`@("`@("`@("`@
M("`@("`O+R!3964@:68@=V4G<F4@;VX@86X@961G92X*("`@("`@("`@("`@
M("`@(&EF("@D=R`]/2`D>"!\?"`D:"`]/2`D>2!\?"`D=R`]/2`D>#(@?'P@
M)&@@/3T@)'DR*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;6=;
M)&A=6R1W72`](&%R<F%Y*"=R)R`]/B`D<BP@)V<G(#T^("1G+"`G8B<@/3X@
M)&(I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F:6QL("$]("=N;VYE
M)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6UG6R1H75LD=UT@
M/2!A<G)A>2@G<B<@/3X@)&92+"`G9R<@/3X@)&9'+"`G8B<@/3X@)&9"*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@4$Y'(&9I;&4@:&5A9&5R
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?:&5A9&5R*"D*("`@('L*("`@("`@
M("!R971U<FX@<&%C:R@G0T-#0T-#0T,G+"`Q,S<L(#@P+"`W."P@-S$L(#$S
M+"`Q,"P@,C8L(#$P*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!)
M;6%G92!(96%D97(@8FQO8VLN"B`@("`@*B\*("`@(&9U;F-T:6]N(%])2$12
M*"D*("`@('L*("`@("`@("`D9&%T82`]('!A8VLH)V$T3DY#0T-#0R<L("=)
M2$12)RP@)'1H:7,M/E]W:61T:"P@)'1H:7,M/E]H96EG:'0L("1T:&ES+3Y?
M8V]L;W)$97!T:"P@)'1H:7,M/E]C;VQO<E1Y<&4L("1T:&ES+3Y?8V]M<')E
M<W-I;VY-971H;V0L("1T:&ES+3Y?9FEL=&5R365T:&]D+"`D=&AI<RT^7VEN
M=&5R;&%C94UE=&AO9"D["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T
M<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@
M8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T92!)
M14Y$(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO;B!?245.1"@I"B`@("![
M"B`@("`@("`@)&1A=&$@/2`G245.1"<["B`@("`@("`@<F5T=7)N('!A8VLH
M)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T
M+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($-R96%T92!);6%G92!$871A(&)L;V-K+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?241!5"@I"B`@("!["B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("`D
M<')E=G-C86YL:6YE(#T@;G5L;#L*("`@("`@("`D9FEL=&5R(#T@,#L*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^7VAE:6=H=#L@)&DK*RD@
M>PH@("`@("`@("`@("`D<V-A;FQI;F4@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`D9&%T82`N/2!C:'(H)&9I;'1E<BD["B`@("`@("`@("`@(&9O<B`H)&H@
M/2`P.R`D:B`\("1T:&ES+3Y?=VED=&@[("1J*RLI('L*("`@("`@("`@("`@
M("`@(&EF("@D=&AI<RT^7V-O;&]R1&5P=&@@/3T@."D@>PH@("`@("`@("`@
M("`@("`@("`@("1S8V%N;&EN95LD:ET@/2!P86-K*"=#0T,G+"`D=&AI<RT^
M7VEM9ULD:5U;)&I=6R=R)UTL("1T:&ES+3Y?:6UG6R1I75LD:EU;)V<G72P@
M)'1H:7,M/E]I;6=;)&E=6R1J75LG8B==*3L*("`@("`@("`@("`@("`@('T@
M96QS96EF("@D=&AI<RT^7V-O;&]R1&5P=&@@/3T@,38I('L*("`@("`@("`@
M("`@("`@("`@("`D<V-A;FQI;F5;)&I=(#T@<&%C:R@G;FYN)RP@)'1H:7,M
M/E]I;6=;)&E=6R1J75LG<B==(#P\(#@L("1T:&ES+3Y?:6UG6R1I75LD:EU;
M)V<G72`\/"`X+"`D=&AI<RT^7VEM9ULD:5U;)&I=6R=B)UT@/#P@."D["B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1F:6QT97(@
M/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("\J($YO($9I;'1E<BX@*B\*
M("`@("`@("`@("`@("`@("`@("`D9&%T82`N/2`D<V-A;FQI;F5;)&I=.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1F:6QT97(@/3T@,BD@>PH@("`@
M("`@("`@("`@("`@("`@("\J(%5P($9I;'1E<BX@*B\*("`@("`@("`@("`@
M("`@("`@("`D<&EX96P@/2`D<V-A;FQI;F5;)&I=("T@)'!R979S8V%N;&EN
M95LD:ET["B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]L;W)$
M97!T:"`]/2`X*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1D871A("X]
M('!A8VLH)T-#0R<L("1P:7AE;"`^/B`Q-BP@*"1P:7AE;"`^/B`X*2`F(#!X
M1D8L("1P:7AE;"`F(#!X1D8I.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M96EF("@D=&AI<RT^7V-O;&]R1&5P=&@@/3T@,38I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1A=&$@+CT@<&%C:R@G;FYN)RP@*"1P:7AE;"`^/B`S
M,BDL("@D<&EX96P@/CX@,38I("8@,'A&1D9&+"`D<&EX96P@)B`P>$9&1D8I
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<')E=G-C86YL:6YE(#T@)'-C86YL
M:6YE.PH@("`@("`@('T*("`@("`@("`D8V]M<')E<W-E9"`](&=Z9&5F;&%T
M92@D9&%T82P@.2D["@H@("`@("`@("1D871A(#T@)TE$050G("X@<&%C:R@G
M0T-A)R`N('-T<FQE;B@D8V]M<')E<W-E9"D@+B`G830G+"`P>#<X+"`P>#`Q
M+"`D8V]M<')E<W-E9"P@)'1H:7,M/E]!9&QE<C,R*"1D871A*2D["B`@("`@
M("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T82D@+B`G3B<L('-T
M<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A=&$I*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-R96%T92!T15AT(&)L;V-K+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?=$58="@D:V5Y=V]R9"P@)'1E>'0I"B`@("!["B`@("`@
M("`@)&1A=&$@/2`G=$58="<@+B`D:V5Y=V]R9"`N(")<,"(@+B`D=&5X=#L*
M("`@("`@("!R971U<FX@<&%C:R@G3F$G("X@<W1R;&5N*"1D871A*2`N("=.
M)RP@<W1R;&5N*"1D871A*2`M(#0L("1D871A+"!C<F,S,B@D9&%T82DI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@0W)E871E(&QA<W0@;6]D:69I960@=&EM
M92!B;&]C:RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W1)344H)&1A=&4@/2!N
M=6QL*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1D871E*2D@>PH@("`@
M("`@("`@("`D9&%T92`]('1I;64H*3L*("`@("`@("!]"@H@("`@("`@("1D
M871A(#T@)W1)344G("X@<&%C:R@G;D-#0T-#)RP@:6YT=F%L*&1A=&4H)UDG
M+"`D9&%T92DI+"!I;G1V86PH9&%T92@G;2<L("1D871E*2DL(&EN='9A;"AD
M871E*"=J)RP@)&1A=&4I*2P@:6YT=F%L*&1A=&4H)T<G+"`D9&%T92DI+"!I
M;G1V86PH9&%T92@G:2<L("1D871E*2DL(&EN='9A;"AD871E*"=S)RP@)&1A
M=&4I*2D["B`@("`@("`@<F5T=7)N('!A8VLH)TYA)R`N('-T<FQE;B@D9&%T
M82D@+B`G3B<L('-T<FQE;B@D9&%T82D@+2`T+"`D9&%T82P@8W)C,S(H)&1A
M=&$I*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!A;B!!9&QE
M<C,R(&-H96-K<W5M(&9O<B!A('-T<FEN9RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@7T%D;&5R,S(H)&EN<'5T*0H@("`@>PH@("`@("`@("1S,2`](#$["B`@
M("`@("`@)',R(#T@,#L*("`@("`@("`D:4UA>"`]('-T<FQE;B@D:6YP=70I
M.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1I36%X.R`D:2LK*2!["B`@
M("`@("`@("`@("1S,2`]("@D<S$@*R!O<F0H)&EN<'5T6R1I72DI("4@,'A&
M1D8Q.PH@("`@("`@("`@("`D<S(@/2`H)',R("L@)',Q*2`E(#!X1D9&,3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N('!A8VLH)TXG+"`H*"1S,B`\/"`Q
M-BD@?"`D<S$I*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F]U
M<"]L9&%P+G!H<```````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`V,S$U-2`Q,#4Q-30S-#$S-R`P,C(Q,#0`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J(%1H92!'<F]U
M<%]L9&%P(&-L87-S('!R;W9I9&5S(&%N($Q$05`@8F%C:V5N9"!F;W(@=&AE
M($AO<F1E(&=R;W5P<PH@*B!S>7-T96TN"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T=R;W5P+T=R;W5P+VQD87`N<&AP+'8@,2XQ."XR+C(@,C`P-B\P,2\P
M,2`R,3HR.#HQ.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P
M-B!"96X@0VAA=F5T(#QB96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@0F5N($-H879E="`\8F5N0&AO<F1E+F]R9SX*("H@0'-I
M;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7T=R;W5P"B`J+PIC
M;&%S<R!'<F]U<%]L9&%P(&5X=&5N9',@1W)O=7`@>PH*("`@("\J*@H@("`@
M("H@3$1!4"!C;VYN96-T:6]N(&AA;F1L90H@("`@("HO"B`@("!V87(@)%]D
M<SL*"B`@("`O*BH*("`@("`J($QO8V%L(&-O<'D@;V8@=&AE(&=L;V)A;"`D
M8V]N9ELG9W)O=7`G75LG<&%R86US)UT@87)R87DN("!3:6UP;'D*("`@("`J
M(&9O<B!C;V1I;F<@8V]N=F5N:65N8V4N"B`@("`@*B\*("`@('9A<B`D7W!A
M<F%M<SL*"B`@("`O*BH*("`@("`J($=E;F5R871E9"!,1$%0(&9I;'1E<B!B
M87-E9"!O;B!T:&4@8V]N9FEG('!A<F%M971E<G,*("`@("`J+PH@("`@=F%R
M("1?9FEL=&5R.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@
M*B\*("`@(&9U;F-T:6]N($=R;W5P7VQD87`H*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D8V]N9CL*("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1C;VYF6R=G
M<F]U<"==6R=P87)A;7,G73L*"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)V=I
M9"==(#T@<W1R=&]L;W=E<B@D=&AI<RT^7W!A<F%M<ULG9VED)UTI.PH@("`@
M("`@("1T:&ES+3Y?<&%R86US6R=M96UB97)U:60G72`]('-T<G1O;&]W97(H
M)'1H:7,M/E]P87)A;7-;)VUE;6)E<G5I9"==*3L*("`@("`@("!F;W)E86-H
M("@D=&AI<RT^7W!A<F%M<ULG;F5W9W)O=7!?;V)J96-T8VQA<W,G72!A<R`D
M:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)VYE
M=V=R;W5P7V]B:F5C=&-L87-S)UU;)&ME>5T@/2!S=')T;VQO=V5R*"1V86PI
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1V5N97)A=&4@3$1!4"!S96%R8V@@
M9FEL=&5R+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P87)A;7-;
M)V9I;'1E<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V9I;'1E<B`]("1T
M:&ES+3Y?<&%R86US6R=F:6QT97(G73L*("`@("`@("!](&5L<V5I9B`H(6ES
M7V%R<F%Y*"1T:&ES+3Y?<&%R86US6R=O8FIE8W1C;&%S<R==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V9I;'1E<B`]("=O8FIE8W1C;&%S<STG("X@)'1H
M:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UT["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]F:6QT97(@/2`G)SL*("`@("`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]P87)A;7-;)V]B:F5C=&-L87-S)UT@87,@)&]B
M:F5C=&-L87-S*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;'1E<B`]
M("<H)B<@+B`D=&AI<RT^7V9I;'1E<CL*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9FEL=&5R("X]("<H;V)J96-T8VQA<W,])R`N("1O8FIE8W1C;&%S<R`N
M("<I*2<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1T:&ES
M+3Y?9FEL=&5R(#T@<W1R=&]L;W=E<B@D=&AI<RT^7V9I;'1E<BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T<R!T;R!T:&4@3$1!4"!S97)V97(N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]R($9A;'-E
M(&)A<V5D(&]N('-U8V-E<W,@;V8@8V]N;F5C="!A;F0@8FEN9"X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@("\J($-O
M;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1T:&ES+3Y?
M9',@/2!`;&1A<%]C;VYN96-T*"1T:&ES+3Y?<&%R86US6R=H;W-T<W!E8R==
M*3L*("`@("`@("!I9B`H(21T:&ES+3Y?9',I('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B1F%I;&5D('1O(&-O;FYE8W0@=&\@
M3$1!4"!S97)V97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"%L9&%P
M7W-E=%]O<'1I;VXH)'1H:7,M/E]D<RP@3$1!4%]/4%1?4%)/5$]#3TQ?5D52
M4TE/3BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@*("`@("`@("`@("`@("`@('-P<FEN=&8H)U-E="!,1$%0('!R;W1O
M8V]L('9E<G-I;VX@=&\@)60@9F%I;&5D.B!;)61=("5S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72P*("`@
M("`@("`@("`@("`@("`@("`@("`@;&1A<%]E<G)N;R@D8V]N;BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@(&QD87!?97)R;W(H)&-O;FXI+`H@("`@("`@
M("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\I*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG8FEN9&1N
M)UTI*2!["B`@("`@("`@("`@("1B:6YD(#T@0&QD87!?8FEN9"@D=&AI<RT^
M7V1S+"`D=&AI<RT^7W!A<F%M<ULG8FEN9&1N)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG<&%S<W=O<F0G72D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&)I;F0@/2!`;&1A<%]B
M:6YD*"1T:&ES+3Y?9',I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D8FEN
M9"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#
M;W5L9"!N;W0@8FEN9"!T;R!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M8W5R<VEV96QY(&1E;&5T97,@)&1N+B`D=&AI<RT^7V1S($U54U0@86QR96%D
M>2!B92!C;VYN96-T960N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@
M5')U92!I9B!D96QE=&4@=V%S('-U8V-E<W-F=6PL(%!%05)?17)R;W(@;W1H
M97)W:7-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5C=7)S:79E7V1E;&5T
M92@D9&XI"B`@("!["B`@("`@("`@)'-E87)C:"`]($!L9&%P7VQI<W0H)'1H
M:7,M/E]D<RP@)&1N+"`G;V)J96-T8VQA<W,]*B<L(&%R<F%Y*"<G*2D["B`@
M("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R96%C:"!T:&4@3$1!4"!S97)V
M97(N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&-H:6QD<F5N(#T@0&QD87!?
M9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D["B`@("`@("`@9F]R
M("@D:2`](#`[("1I(#P@)&-H:6QD<F5N6R=C;W5N="==.R`D:2LK*2!["B`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W)E8W5R<VEV95]D96QE=&4H
M)&-H:6QD<F5N6R1I75LG9&XG72D["B`@("`@("`@("`@(&EF("@A)')E<W5L
M="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S(BDL("1T:&ES+3YG971.86UE*"1C:&EL9')E;ELD:5U;)V1N)UTI*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2!`
M;&1A<%]D96QE=&4H)'1H:7,M/E]D<RP@)&1N*3L*("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L971E(&=R;W5P
M("5S(BDL("1D;BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!E>&ES=&EN9R!G
M<F]U<',@9F]R('1H92!H:6=H97-T(&=I9&YU;6)E<BP@86YD(')E='5R;G,*
M("`@("`J(&]N92!H:6=H97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]N97AT
M1VED*"D*("`@('L*("`@("`@("`O*B!#;VYN96-T('1O('1H92!,1$%0('-E
M<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S
M+3YG971-97-S86=E*"DI.PH@("`@("`@('T*"B`@("`@("`@)'-E87)C:"`]
M($!L9&%P7W-E87)C:"@D=&AI<RT^7V1S+"`D9&XL("1T:&ES+3Y?9FEL=&5R
M*3L*("`@("`@("!I9B`H(21S96%R8V@I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0
M('-E<G9E<BXB*2D["B`@("`@("`@?0H*("`@("`@("!`;&1A<%]S;W)T*"1T
M:&ES+3Y?9',L("1S96%R8V@L("=G:61N=6UB97(G*3L*("`@("`@("`D<F5S
M=6QT(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:"D[
M"B`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@(&EF
M("@A:7-?87)R87DH)')E<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I
M*2!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1R97-U;'1;)')E<W5L=%LG8V]U;G0G72`M(#%=6R=G:61N=6UB
M97(G75LP72`K(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!N
M97<@9W)O=7`@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@5&AE(&=R;W5P)W,@;F%M92X*("`@("`J($!P87)A;2!S=')I
M;F<@)'!A<F5N="`@5&AE(&=R;W5P)W,@<&%R96YT)W,@;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N($Q$05!?1W)O=7`@($$@;F5W(&=R;W5P(&]B:F5C
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@)FYE=T=R;W5P*"1N86UE+"`D<&%R
M96YT(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H96UP='DH)&YA;64I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D=R;W5P
M(&YA;65S(&UU<W0@8F4@;F]N+65M<'1Y(BDI.PH@("`@("`@('T*"B`@("`@
M("`@9VQO8F%L("1C;VYF.PH@("`@("`@(&EF("@A96UP='DH)&-O;F9;)VAO
M;VMS)UU;)V=R;W5P;&1A<"==*2D@>PH@("`@("`@("`@("!`:6YC;'5D92!(
M3U)$15]"05-%("X@)R]C;VYF:6<O:&]O:W,N<&AP)SL*("`@("`@("`@("`@
M:68@*&9U;F-T:6]N7V5X:7-T<R@G7VAO<F1E7VAO;VM?9W)O=7!L9&%P)RDI
M('L*("`@("`@("`@("`@("`@("1E;G1R>2`](&-A;&Q?=7-E<E]F=6YC*"=?
M:&]R9&5?:&]O:U]G<F]U<&QD87`G+"`D;F%M92P@)'!A<F5N="D["B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!4<GD@
M=&AI<R!S:6UP;&4@9&5F875L="!A;F0@:&]P92!I="!W;W)K<RX*("`@("`@
M("`@("`@)&5N=')Y6R1T:&ES+3Y?<&%R86US6R=G:60G75T@/2`D;F%M93L*
M("`@("`@("`@("`@)&5N=')Y6R=O8FIE8W1C;&%S<R==(#T@)'1H:7,M/E]P
M87)A;7-;)VYE=V=R;W5P7V]B:F5C=&-L87-S)UT["B`@("`@("`@("`@("1E
M;G1R>5LG9VED;G5M8F5R)UT@/2`D=&AI<RT^7VYE>'1':60H*3L*("`@("`@
M("!]"@H@("`@("`@("1G<F]U<"`]("9N97<@3$1!4%]'<F]U<"@D;F%M92P@
M)'!A<F5N="D["B`@("`@("`@)&=R;W5P+3Y?9G)O;4%T=')I8G5T97,H)&5N
M=')Y*3L*("`@("`@("`D9W)O=7`M/G-E=$=R;W5P3V(H)'1H:7,I.PH@("`@
M("`@(')E='5R;B`D9W)O=7`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FX@86X@3$1!4%]'<F]U<"!O8FIE8W0@8V]R<F5S<&]N9&EN9R!T;R!T:&4@
M;F%M960@9W)O=7`L('=I=&@@=&AE"B`@("`@*B!U<V5R<R!A;F0@;W1H97(@
M9&%T82!R971R:65V960@87!P<F]P<FEA=&5L>2X*("`@("`J"B`@("`@*B!.
M3U1%.B!G971'<F]U<$)Y260H*2!S:&]U;&0@8F4@=7-E9"!W:&5R92!P;W-S
M:6)L92!I;G-T96%D(&]F"B`@("`@*B!G971'<F]U<"@I(&)E8V%U<V4@9W)O
M=7`@;F%M97,@87)E('!O=&5N=&EA;&QY(&YO;BUU;FEQ=64@=F%L=65S+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F
M('1H92!G<F]U<"!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M($Q$05!?1W)O=7`@(%1H92!R97%U97-T960@9W)O=7`N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9G971'<F]U<"@D;F%M92D*("`@('L*("`@("`@("`D9&X@
M/2`D=&AI<RT^9V5T1W)O=7!)9"@D;F%M92D["B`@("`@("`@:68@*&ES7V$H
M)&1N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"1D;BT^9V5T365S<V%G92@I*3L*("`@("`@("!]"B`@
M("`@("`@)&=R;W5P(#T@)B1T:&ES+3YG971'<F]U<$)Y260H)&1N*3L*("`@
M("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&%N($Q$05!?3V)J96-T(&]B:F5C="!C;W)R97-P;VYD:6YG('1O('1H
M92!G:79E;B!D;BP@=VET:"!T:&4*("`@("`J('5S97)S(&%N9"!O=&AE<B!D
M871A(')E=')I979E9"!A<'!R;W!R:6%T96QY+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&1N("!4:&4@9&X@;V8@=&AE(&=R;W5P('1O(')E=')I
M979E+@H@("`@("H*("`@("`J($!R971U<FX@3$1!4%]/8FIE8W0@(%1H92!R
M97%U97-T960@9W)O=7`N"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971'<F]U
M<$)Y260H)&1N*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@
M("`@(&EF("@A:7-?87)R87DH)&-A8VAE*2D@>PH@("`@("`@("`@("`D8V%C
M:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D
M8V%C:&5;)&1N72DI('L*("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@
M3$1!4"!S97)V97(N("HO"B`@("`@("`@("`@("1S=6-C97-S(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1S=6-C97-S+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'-E87)C:"`]($!L9&%P7W-E87)C:"@D=&AI
M<RT^7V1S+"`D9&XL("1T:&ES+3Y?9FEL=&5R*3L*("`@("`@("`@("`@:68@
M*"$D<V5A<F-H*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$05`@<V5R=F5R+B(I
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<W5L="`]($!L9&%P
M7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I.PH@("`@("`@("`@
M("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@("`@("`@:68@*"%I
M<U]A<G)A>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L="D@/#T@,2DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D5M
M<'1Y(')E<W5L="XB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1A
M='1R:6)U=&5S(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)')E<W5L=%LP75LG8V]U;G0G73L@)&DK*RD@>PH@("`@("`@("`@
M("`@("`@:68@*"1R97-U;'1;,%U;)')E<W5L=%LP75LD:5U=6R=C;W5N="==
M(#X@,2D@>PH@("`@("`@("`@("`@("`@("`@("1A='1R:6)U=&5S6R1R97-U
M;'1;,%U;)&E=72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@9F]R
M("@D:B`](#`[("1J(#P@)')E<W5L=%LP75LD<F5S=6QT6S!=6R1I75U;)V-O
M=6YT)UT[("1J*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I
M8G5T97-;)')E<W5L=%LP75LD:5U=6UT@/2`D<F5S=6QT6S!=6R1R97-U;'1;
M,%U;)&E=75LD:ET["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D871T<FEB=71E
M<ULD<F5S=6QT6S!=6R1I75T@/2`D<F5S=6QT6S!=6R1R97-U;'1;,%U;)&E=
M75LP73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D871T<FEB=71E<ULG9&XG72`]("1R97-U;'1;,%U;)V1N)UT["@H@
M("`@("`@("`@("`D9W)O=7`@/2!N97<@3$1!4%]'<F]U<"@D=&AI<RT^9V5T
M1W)O=7!.86UE*"1D;BDI.PH@("`@("`@("`@("`D9W)O=7`M/E]F<F]M071T
M<FEB=71E<R@D871T<FEB=71E<RD["B`@("`@("`@("`@("1G<F]U<"T^<V5T
M1W)O=7!/8B@D=&AI<RD["B`@("`@("`@("`@("1C86-H95LD9&Y=(#T@)&=R
M;W5P.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-A8VAE6R1D;ET["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!G;&]B86QL>2!U;FEQ=64@240@
M9F]R(&$@9W)O=7`N("!4:&ES(')E86QL>2!J=7-T(')E='5R;G,@=&AE(&1N
M"B`@("`@*B!F;W(@=&AE(&=R;W5P+"!B=70@:7,@:6YC;'5D960@9F]R(&-O
M;7!A=&EB:6QI='D@=VET:"!T:&4@1W)O=7`@8VQA<W,N"B`@("`@*@H@("`@
M("H@0'!A<F%M($Q$05!?3V)J96-T("1G<F]U<"`@5&AE(&=R;W5P+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!A($=5240@<F5F97)R:6YG('1O
M("1G<F]U<"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1U5)1"@D9W)O=7`I
M"B`@("!["B`@("`@("`@<F5T=7)N("1G<F]U<"T^9V5T*"=D;B<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@061D(&$@9W)O=7`@=&\@=&AE(&=R;W5P<R!S
M>7-T96TN("!4:&4@9W)O=7`@;75S="!F:7)S="!B92!C<F5A=&5D('=I=&@*
M("`@("`J($=R;W5P7VQD87`Z.FYE=T=R;W5P*"DL(&%N9"!H879E(&%N>2!I
M;FET:6%L('5S97)S(&%D9&5D('1O(&ET+"!B969O<F4*("`@("`J('1H:7,@
M9G5N8W1I;VX@:7,@8V%L;&5D+@H@("`@("H*("`@("`J($!P87)A;2!,1$%0
M7T=R;W5P("1G<F]U<"`@5&AE(&YE=R!G<F]U<"!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@5')U92!I9B!S=6-C97-S9G5L+"!014%2
M7T5R<F]R(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@861D1W)O
M=7`H)&=R;W5P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$
M871A5')E94]B:F5C=%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"='<F]U<',@;75S="!B92!$871A5')E94]B:F5C
M=%]'<F]U<"!O8FIE8W1S(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@3$1!4"!S97)V97(N
M("HO"B`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T
M365S<V%G92@I*3L*("`@("`@("!]"@H@("`@("`@("1D;B`]("1G<F]U<"T^
M9V5T*"=D;B<I.PH*("`@("`@("`D96YT<GD@/2`D9W)O=7`M/E]T;T%T=')I
M8G5T97,H*3L*("`@("`@("`D<W5C8V5S<R`]($!L9&%P7V%D9"@D=&AI<RT^
M7V1S+"`D9&XL("1E;G1R>2D["@H@("`@("`@(&EF("@A)'-U8V-E<W,I('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@861D(&=R;W5P("5S+B!4:&ES(&ES
M('=H870@=&AE('-E<G9E<B!S86ED.B`B*2P@)&=R;W5P+3YG971.86UE*"DI
M("X@0&QD87!?97)R;W(H)'1H:7,M/E]D<RDI.PH@("`@("`@('T*"B`@("`@
M("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O<F4@=7!D871E9"!D871A
M("T@=7-E<G,L(&5T8RX@+2!O9B!A(&=R;W5P('1O('1H92!B86-K96YD('-Y
M<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@3$1!4%]/8FIE8W0@)&=R;W5P
M("!4:&4@9W)O=7`@=&\@=7!D871E"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&]T:&5R=VES92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E1W)O=7`H)&=R;W5P*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=$871A5')E94]B:F5C=%]'
M<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"='<F]U<',@;75S="!B92!$871A5')E94]B:F5C=%]'<F]U<"!O8FIE8W1S
M(&]R(&5X=&5N9"!T:&%T(&-L87-S+B<I.PH@("`@("`@('T*"B`@("`@("`@
M)&5N=')Y(#T@)&=R;W5P+3Y?=&]!='1R:6)U=&5S*"D["@H@("`@("`@("\J
M($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R+B`J+PH@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@
M("`@?0H*("`@("`@("`D<F5S=6QT(#T@0&QD87!?;6]D:69Y*"1T:&ES+3Y?
M9',L("1G<F]U<"T^9V5T260H*2P@)&5N=')Y*3L*("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@=7!D871E(&=R;W5P
M("5S(BDL("1G<F]U<"T^9V5T3F%M92@I*2D["B`@("`@("`@?0H*("`@("`@
M("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*"B`@("`@("`@+RH@3&]G('1H
M92!U<&1A=&4@;V8@=&AE(&=R;W5P('5S97)S(&]N('1H92!H:7-T;W)Y(&QO
M9RX@*B\*("`@("`@("`D:&ES=&]R>2`]("9(;W)D95](:7-T;W)Y.CIS:6YG
M;&5T;VXH*3L*("`@("`@("`D9W5I9"`]("1T:&ES+3YG971'54E$*"1G<F]U
M<"D["B`@("`@("`@9F]R96%C:"`H)&=R;W5P+3YG971!=61I=$QO9R@I(&%S
M("1U<V5R260@/3X@)&%C=&EO;BD@>PH@("`@("`@("`@("`D:&ES=&]R>2T^
M;&]G*"1G=6ED+"!A<G)A>2@G86-T:6]N)R`]/B`D86-T:6]N+"`G=7-E<B<@
M/3X@)'5S97))9"DL('1R=64I.PH@("`@("`@('T*("`@("`@("`D9W)O=7`M
M/F-L96%R075D:71,;V<H*3L*"B`@("`@("`@+RH@3&]G('1H92!G<F]U<"!M
M;V1I9FEC871I;VXN("HO"B`@("`@("`@)&AI<W1O<GDM/FQO9R@D9W5I9"P@
M87)R87DH)V%C=&EO;B<@/3X@)VUO9&EF>2<I+"!T<G5E*3L*("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG92!T
M:&4@;F%M92!O9B!A(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!$871A
M5')E94]B:F5C=%]'<F]U<"`D9W)O=7`@(%1H92!G<F]U<"!T;R!R96YA;64N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=.86UE("`@("`@("`@("`@("!4
M:&4@9W)O=7`G<R!N97<@;F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M86UE1W)O=7`H)&=R;W5P+"`D;F5W3F%M92D*("`@('L*("`@("`@("!I9B`H
M(6ES7V$H)&=R;W5P+"`G1&%T851R965/8FIE8W1?1W)O=7`G*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1W)O=7!S(&UU<W0@
M8F4@1&%T851R965/8FIE8W1?1W)O=7`@;V)J96-T<R!O<B!E>'1E;F0@=&AA
M="!C;&%S<RXG*3L*("`@("`@("!]"@H@("`@("`@("1G<F]U<"T^<V5T*"1T
M:&ES+3Y?<&%R86US6R=G:60G72P@)&YE=TYA;64I.PH@("`@("`@("1E;G1R
M>2`]("1G<F]U<"T^7W1O071T<FEB=71E<R@I.PH*("`@("`@("`O*B!#;VYN
M96-T('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`D<W5C8V5S<R`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1S=6-C97-S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W5L="`]($!L9&%P7VUO9&EF>2@D=&AI<RT^7V1S+"`D
M9W)O=7`M/F=E=$ED*"DL("1E;G1R>2D["B`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B1W)O=7!?;&1A<#H@56YA8FQE('1O('5P9&%T92!G<F]U<"`E<R(I
M+"`D9W)O=7`M/F=E=$YA;64H*2DI.PH@("`@("`@('T*"B`@("`@("`@0&QD
M87!?8VQO<V4H)'1H:7,M/E]D<RD["@H@("`@("`@("\J($AI<W1O<GD@3&]G
M('1H92!N86UE(&-H86YG92!O9B!T:&4@9W)O=7`N("HO"B`@("`@("`@)&AI
M<W1O<GD@/2`F2&]R9&5?2&ES=&]R>3HZ<VEN9VQE=&]N*"D["B`@("`@("`@
M)&AI<W1O<GDM/FQO9R@D9W)O=7`M/F=E="@G9&XG*2P@87)R87DH)V%C=&EO
M;B<@/3X@)W)E;F%M92<I+"!T<G5E*3L*("`@("`@("!R971U<FX@)')E<W5L
M=#L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@82!G<F]U<"!F<F]M
M('1H92!G<F]U<',@<WES=&5M('!E<FUA;F5N=&QY+@H@("`@("H*("`@("`J
M($!P87)A;2!,1$%07T=R;W5P("1G<F]U<"`@5&AE(&=R;W5P('1O(')E;6]V
M92X*("`@("`J($!P87)A;2!B;V]L96%N("1F;W)C92`@("`@4F5C=7)S:79E
M;'D@9&5L971E(&-H:6QD<F5N(&=R;W5P<R!I9B!T<G5E+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<RP@4$5!4E]%<G)O
M<B!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94=R;W5P
M*"1G<F]U<"P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%I
M<U]A*"1G<F]U<"P@)T1A=&%4<F5E3V)J96-T7T=R;W5P)RDI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T=R;W5P<R!M=7-T(&)E
M($1A=&%4<F5E3V)J96-T7T=R;W5P(&]B:F5C=',@;W(@97AT96YD('1H870@
M8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`D9&X@/2`D9W)O=7`M/F=E
M=$ED*"D["@H@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$05`@<V5R=F5R
M+B`J+PH@("`@("`@("1S=6-C97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'-U8V-E<W,M/F=E
M=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&9O<F-E*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)E8W5R<VEV95]D96QE=&4H
M)&1N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@
M0&QD87!?9&5L971E*"1T:&ES+3Y?9',L("1D;BD["B`@("`@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")'<F]U<%]L9&%P.B!5;F%B;&4@=&\@9&5L
M971E(&=R;W5P("5S(BDL("1D;BDI.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@=&AE(&YA;64@;V8@
M82!G<F]U<"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE
M(&1N(&]F('1H92!G<F]U<"!T;R!R971R:65V92!T:&4@;F%M92!F;W(N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!G<F]U<"=S(&YA;64N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$=R;W5P3F%M92@D9&XI"B`@("![
M"B`@("`@("`@)')E<W5L="`](&QD87!?97AP;&]D95]D;B@D9&XL(#$I.PH@
M("`@("`@(')E='5R;B`D<F5S=6QT6S!=.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&%T851R965/8FIE8W0@9G5L;"!N86UE<R!I;F-L=61E(')E9F5R96YC
M97,@=&\@<&%R96YT<RP@8G5T($Q$05`@9&]E<PH@("`@("H@;F]T(&AA=F4@
M=&AI<R!C;VYC97!T+B`@5&AI<R!F=6YC=&EO;B!S:6UP;'D@<F5T=7)N<R!T
M:&4@)&=R;W5P"B`@("`@*B!P87)A;65T97(@86YD(&ES(&EN8VQU9&5D(&9O
M<B!C;VUP871I8FEL:71Y('=I=&@@=&AE($=R;W5P(&-L87-S+@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P("!'<F]U<"!N86UE+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("`D9W)O=7`N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$=R;W5P4VAO<G1.86UE*"1G<F]U<"D*("`@('L*("`@
M("`@("!R971U<FX@)&=R;W5P.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M<FEE=F4@=&AE($E$(&]F('1H92!G:79E;B!G<F]U<"X*("`@("`J"B`@("`@
M*B!.3U1%.B!)9B!G:79E;B!A(&=R;W5P(&YA;64L('1H:7,@9G5N8W1I;VX@
M8V%N(&)E('5N<F5L:6%B;&4@:68@;6]R90H@("`@("H@=&AA;B!O;F4@9W)O
M=7`@97AI<W1S('=I=&@@=&AE('-A;64@;F%M92X*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)&=R;W5P("`@3$1!4%]'<F]U<"!O8FIE8W0L(&]R(&$@
M9W)O=7`@;F%M92`H<W1R:6YG*0H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!4:&4@9W)O=7`G<R!)1"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1W)O=7!)9"@D9W)O=7`I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&=R;W5P
M+"`G3$1!4%]'<F]U<"<I*2!["B`@("`@("`@("`@(')E='5R;B`D9W)O=7`M
M/F=E="@G9&XG*3L*("`@("`@("!]"@H@("`@("`@('-T871I8R`D8V%C:&4[
M"@H@("`@("`@(&EF("@A:7-?87)R87DH)&-A8VAE*2D@>PH@("`@("`@("`@
M("`D8V%C:&4@/2!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<W-E="@D8V%C:&5;)&=R;W5P72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C
M;VYN96-T*"D["B`@("`@("`@("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H
M)'1H:7,M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=G
M:60G72`N("<])R`N("1G<F]U<"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@D=&AI<RT^7W!A<F%M<ULG9VED)UTI*3L*("`@
M("`@("`@("`@:68@*"$D<V5A<F-H*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")#;W5L9"!N;W0@<F5A8V@@=&AE($Q$
M05`@<V5R=F5R+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E
M<W5L="`]($!L9&%P7V=E=%]E;G1R:65S*"1T:&ES+3Y?9',L("1S96%R8V@I
M.PH@("`@("`@("`@("!`;&1A<%]C;&]S92@D=&AI<RT^7V1S*3L*("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D<F5S=6QT*2!\?"`H8V]U;G0H)')E<W5L
M="D@/#T@,2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*%\H(D5M<'1Y(')E<W5L="XB*2D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&-A8VAE6R1G<F]U<%T@/2`D<F5S=6QT6S!=6R=D;B==.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C86-H95LD9W)O=7!=.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@82!G<F]U<"!E>&ES=',@:6X@
M=&AE('-Y<W1E;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1G<F]U
M<"`@5&AE(&=R;W5P(&YA;64@=&\@8VAE8VL@9F]R+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9W)O=7`@97AI<W1S+"!&
M86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X:7-T<R@D
M9W)O=7`I"B`@("!["B`@("`@("`@<W1A=&EC("1C86-H93L*"B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D8V%C:&4I*2!["B`@("`@("`@("`@("1C86-H92`]
M(&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C86-H
M95LD9W)O=7!=*2D@>PH@("`@("`@("`@("`O*B!#;VYN96-T('1O('1H92!,
M1$%0('-E<G9E<BX@*B\*("`@("`@("`@("`@)'-U8V-E<W,@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-U8V-E<W,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<V5A<F-H(#T@0&QD87!?<V5A<F-H*"1T:&ES
M+3Y?9',L("1D;BP@)R@F)R`N("1T:&ES+3Y?9FEL=&5R("X@)R@G("X@)'1H
M:7,M/E]P87)A;7-;)V=I9"==("X@)STG("X@)&=R;W5P("X@)RDI)RD["B`@
M("`@("`@("`@(&EF("@A)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,
M1$%0('-E<G9E<BXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R
M97-U;'0@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI<RT^7V1S+"`D<V5A<F-H
M*3L*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H:7,M/E]D<RD["B`@("`@
M("`@("`@("1C86-H95LD9W)O=7!=(#T@*&ES7V%R<F%Y*"1R97-U;'0I("8F
M("AC;W5N="@D<F5S=6QT(#X@,2DI*3L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D8V%C:&5;)&=R;W5P73L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!A(&QI<W0@;V8@=&AE('!A<F5N=',@;V8@82!C:&EL9"!G<F]U<"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N(&]F('1H92!C
M:&EL9"!G<F]U<"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@
M9&X@86YD(&YA;64@;V8@=&AE('!A<F5N="!G<F]U<"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1W)O=7!087)E;G1S*"1D;BD*("`@('L*("`@("`@("`D
M<&%R96YT(#T@)'1H:7,M/F=E=$=R;W5P4&%R96YT*"1D;BD["B`@("`@("`@
M<F5T=7)N(&%R<F%Y*"1P87)E;G0@/3X@)'1H:7,M/F=E=$=R;W5P3F%M92@D
M<&%R96YT*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('!A<F5N
M="!O9B!T:&4@9VEV96X@9W)O=7`N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@8VAI;&0@9W)O=7`N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!D;B!O9B!T:&4@<&%R96YT(&=R
M;W5P+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<%!A<F5N="@D9&XI
M"B`@("!["B`@("`@("`@)')E<W5L="`](&QD87!?97AP;&]D95]D;B@D9&XL
M(#`I.PH@("`@("`@('5N<V5T*"1R97-U;'1;)V-O=6YT)UTI.PH@("`@("`@
M('5N<V5T*"1R97-U;'1;,%TI.PH@("`@("`@("1P87)E;G1?9&X@/2!I;7!L
M;V1E*"<L)RP@)')E<W5L="D["@H@("`@("`@(&EF("@D<&%R96YT7V1N(#T]
M("1'3$]"04Q36R=C;VYF)UU;)V=R;W5P)UU;)W!A<F%M<R==6R=B87-E9&XG
M72D@>PH@("`@("`@("`@("!R971U<FX@1$%40512145?4D]/5#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'!A<F5N=%]D;CL*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F('!A
M<F5N=',@86QL('1H92!W87D@=7`@=&\@=&AE(')O;W0@;V)J96-T(&9O<B!T
M:&4@9VEV96X*("`@("`J(&=R;W5P+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&1N("!4:&4@9&X@;V8@=&AE(&=R;W5P+@H@("`@("H*("`@("`J
M($!R971U<FX@87)R87D@($$@9FQA="!L:7-T(&]F(&%L;"!O9B!T:&4@<&%R
M96YT<R!O9B!T:&4@9VEV96X@9W)O=7`L"B`@("`@*B`@("`@("`@("`@("`@
M("!H87-H960@:6X@)&1N(#T^("1N86UE(&9O<FUA="X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1W)O=7!087)E;G1,:7-T*"1D;BD*("`@('L*("`@("`@
M("`D<F5S=6QT(#T@;&1A<%]E>'!L;V1E7V1N*"1D;BP@,"D["B`@("`@("`@
M)&YU;2`]("1R97-U;'1;)V-O=6YT)UT["@H@("`@("`@('5N<V5T*"1R97-U
M;'1;)V-O=6YT)UTI.PH@("`@("`@('5N<V5T*"1R97-U;'1;,%TI.PH*("`@
M("`@("`D8V]U;G0@/2`P.PH@("`@("`@("1P87)E;G1S(#T@87)R87DH*3L*
M("`@("`@("`D<&%R96YT7V1N(#T@:6UP;&]D92@G+"<L("1R97-U;'0I.PH@
M("`@("`@('=H:6QE("@D<&%R96YT7V1N("$]("1T:&ES+3Y?<&%R86US6R=B
M87-E9&XG72`F)B`D8V]U;G0K*R`A/2`D;G5M*2!["B`@("`@("`@("`@("1P
M87)E;G1S6R1P87)E;G1?9&Y=(#T@)'1H:7,M/F=E=$=R;W5P3F%M92@D<&%R
M96YT7V1N*3L*("`@("`@("`@("`@=6YS970H)')E<W5L=%LD8V]U;G1=*3L*
M("`@("`@("`@("`@)'!A<F5N=%]D;B`](&EM<&QO9&4H)RPG+"`D<F5S=6QT
M*3L*("`@("`@("!]"B`@("`@("`@)'!A<F5N='-;1$%40512145?4D]/5%T@
M/2!$051!5%)%15]23T]4.PH*("`@("`@("!R971U<FX@)'!A<F5N=',["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y(&=R;W5P
M+"!I;B!T:&4@9F]R;6%T(&1N(#T^(&=R;W5P;F%M92X*("`@("`J"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D<F5F<F5S:"`@268@=')U92P@=&AE(&-A8VAE
M9"!V86QU92!I<R!I9VYO<F5D(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!G<F]U<"!L:7-T(&ES(')E9G)E<VAE9"!F<F]M('1H
M92!G<F]U<"!B86-K96YD+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M(&1N(#T^(&=R;W5P;F%M92!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M:7-T1W)O=7!S*"1R969R97-H(#T@9F%L<V4I"B`@("!["B`@("`@("`@<W1A
M=&EC("1G<F]U<',["@H@("`@("`@(&EF("@D<F5F<F5S:"!\?"!I<U]N=6QL
M*"1G<F]U<',I*2!["B`@("`@("`@("`@("\J($-O;FYE8W0@=&\@=&AE($Q$
M05`@<V5R=F5R+B`J+PH@("`@("`@("`@("`D<W5C8V5S<R`]("1T:&ES+3Y?
M8V]N;F5C="@I.PH@("`@("`@("`@("!I9B`H:7-?82@D<W5C8V5S<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)'-U8V-E<W,M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1S96%R8V@@/2!`;&1A<%]S96%R8V@H)'1H:7,M
M/E]D<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+"`D=&AI<RT^7V9I;'1E
M<BP@87)R87DH)'1H:7,M/E]P87)A;7-;)V=I9"==*2D["B`@("`@("`@("`@
M(&EF("@A)'-E87)C:"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E
M<BXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@($!L9&%P7W-O<G0H
M)'1H:7,M/E]D<RP@)'-E87)C:"P@)'1H:7,M/E]P87)A;7-;)V=I9"==*3L*
M"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?96YT<FEE<R@D=&AI
M<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD87!?8VQO<V4H)'1H
M:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')E<W5L="D@
M?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@87)R87DH*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&=R
M;W5P<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1R97-U;'1;)V-O=6YT)UT[("1I*RLI('L*("`@("`@("`@("`@("`@("1G
M<F]U<'-;)')E<W5L=%LD:5U;)V1N)UU=(#T@)')E<W5L=%LD:5U;)'1H:7,M
M/E]P87)A;7-;)V=I9"==75LP73L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N("1G<F]U<',["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!P87)T(&]F('1H
M92!S<&5C:69I960@9W)O=7`@86YD(&%N>0H@("`@("H@;V8@:71S('-U8F=R
M;W5P<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;B`@5&AE(&1N
M(&]F('1H92!P87)E;G0@9W)O=7`N"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@5&AE(&-O;7!L971E('5S97(@;&ES="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;&ES=$%L;%5S97)S*"1D;BD*("`@('L*("`@("`@("!S=&%T:6,@
M)&-A8VAE.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C86-H92DI('L*("`@
M("`@("`@("`@)&-A8VAE(#T@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-S970H)&-A8VAE6R1D;ETI*2!["B`@("`@("`@("`@("1S=6-C
M97-S(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@("`@(&EF("AI<U]A
M*"1S=6-C97-S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D<W5C8V5S<RT^9V5T365S<V%G92@I
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-E87)C:"`]($!L9&%P
M7W-E87)C:"@D=&AI<RT^7V1S+"`D=&AI<RT^9V5T1W)O=7!087)E;G0H)&1N
M*2P@)'1H:7,M/E]F:6QE<BD["B`@("`@("`@("`@(&EF("@A)'-E87)C:"D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M0V]U;&0@;F]T(')E86-H('1H92!,1$%0('-E<G9E<BXB*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1R97-U;'0@/2!`;&1A<%]G971?96YT<FEE
M<R@D=&AI<RT^7V1S+"`D<V5A<F-H*3L*("`@("`@("`@("`@0&QD87!?8VQO
M<V4H)'1H:7,M/E]D<RD["B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')E
M<W5L="D@?'P@*&-O=6YT*"1R97-U;'0I(#P](#$I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")%;7!T>2!R97-U;'0N
M(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=7-E<G,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D<F5S=6QT6R=C
M;W5N="==.R`D:2LK*2!["B`@("`@("`@("`@("`@("!F;W(@*"1J(#T@,#L@
M)&H@/"`D<F5S=6QT6R1I75LD=&AI<RT^7W!A<F%M<ULG;65M8F5R=6ED)UU=
M6R=C;W5N="==.R`D:BLK*2!["B`@("`@("`@("`@("`@("`@("`@)'5S97)S
M6UT@/2`D<F5S=6QT6R1I75LD=&AI<RT^7W!A<F%M<ULG;65M8F5R=6ED)UU=
M6R1J73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)&-A8VAE6R1D;ET@/2!A<G)A>5]U;FEQ=64H)'5S97)S*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D8V%C:&5;)&1N73L*("`@('T*"B`@
M("`O*BH*("`@("`J($=E="!A(&QI<W0@;V8@979E<GD@9W)O=7`@=&AA="!T
M:&4@9VEV96X@=7-E<B!I<R!A(&UE;6)E<B!O9BX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("`D=7-E<B`@("`@("`@("!4:&4@=7-E<B!T;R!G970@
M9W)O=7!S(&9O<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P87)E;G1'<F]U
M<',@($%L<V\@<F5T=7)N('1H92!P87)E;G1S(&]F(&%N>2!G<F]U<',_"B`@
M("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@86QL(&=R
M;W5P<R!T:&4@=7-E<B!I<R!I;BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M1W)O=7!-96UB97)S:&EP<R@D=7-E<BP@)'!A<F5N=$=R;W5P<R`](&9A;'-E
M*0H@("`@>PH@("`@("`@('-T871I8R`D8V%C:&4["@H@("`@("`@(&EF("AE
M;7!T>2@D8V%C:&5;)'5S97)=*2D@>PH@("`@("`@("`@("`O*B!#;VYN96-T
M('1O('1H92!,1$%0('-E<G9E<BX@*B\*("`@("`@("`@("`@)'-U8V-E<W,@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("`@("`@:68@*&ES7V$H)'-U
M8V-E<W,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"1S=6-C97-S+3YG971-97-S86=E*"DI.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<V5A<F-H(#T@0&QD87!?<V5A
M<F-H*"1T:&ES+3Y?9',L("1T:&ES+3Y?<&%R86US6R=B87-E9&XG72P@)R@G
M("X@)'1H:7,M/E]P87)A;7-;)VUE;6)E<G5I9"==("X@)STG("X@)'5S97(@
M+B`G*2<I.PH@("`@("`@("`@("!I9B`H(21S96%R8V@I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!R
M96%C:"!T:&4@3$1!4"!S97)V97(N(BDI.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<F5S=6QT(#T@0&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D
M<RP@)'-E87)C:"D["B`@("`@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?
M9',I.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R97-U;'0I('Q\("AC
M;W5N="@D<F5S=6QT*2`\/2`Q*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B16UP='D@<F5S=6QT+B(I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1R97-U;'1;)V-O=6YT)UT[("1I
M*RLI('L*("`@("`@("`@("`@("`@("1G<F]U<'-;)')E<W5L=%LD:5U;)V1N
M)UU=(#T@)')E<W5L=%LD:5U;)'1H:7,M/E]P87)A;7-;)V=I9"==75LP73L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&-A8VAE6R1U<V5R72`]("1G
M<F]U<',["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-A8VAE6R1U<V5R
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1R964@9&5P
M=&@@;V8@=&AE(&=I=F5N(&=R;W5P+"!R96QA=&EV92!T;R!T:&4@8F%S92!D
M;BX*("`@("`J(#`@:7,@<F5T=7)N960@9F]R(&%N>2!O8FIE8W0@9&ER96-T
M;'D@8F5L;W<@=&AE(&)A<V4@9&XN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D9&X@(%1H92!D;B!O9B!T:&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT96YG97(@(%1H92!T<F4@9&5P=&@@;V8@=&AE(&=R;W5P
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971,979E;"@D9&XI"B`@("!["B`@
M("`@("`@)&)A<V4@/2!`;&1A<%]E>'!L;V1E7V1N*"1T:&ES+3Y?<&%R86US
M6R=B87-E9&XG72P@,"D["B`@("`@("`@)&=R;W5P(#T@0&QD87!?97AP;&]D
M95]D;B@D9&XL(#`I.PH@("`@("`@(')E='5R;B`D9W)O=7!;)V-O=6YT)UT@
M+2`D8F%S95LG8V]U;G0G72`M(#$["B`@("!]"@I]"@HO*BH*("H@17AT96YS
M:6]N(&]F('1H92!$871A5')E94]B:F5C=%]'<F]U<"!C;&%S<R!F;W(@<W1O
M<FEN9R!G<F]U<"!I;F9O<FUA=&EO;@H@*B!I;B!A;B!,1$%0(&1I<F5C=&]R
M>2X*("H*("H@0&%U=&AO<B`@0F5N($-H879E="`\8F5N0&AO<F1E+F]R9SX*
M("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO<F1E7T=R;W5P
M"B`J+PIC;&%S<R!,1$%07T=R;W5P(&5X=&5N9',@1&%T851R965/8FIE8W1?
M1W)O=7`@>PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("!4:&4@;F%M92!O9B!T:&ES
M(&=R;W5P+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R96YT("!4:&4@9&X@
M;V8@=&AE('!A<F5N="!O9B!T:&ES(&=R;W5P+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!,1$%07T=R;W5P*"1N86UE+"`D<&%R96YT(#T@;G5L;"D*("`@('L*
M("`@("`@("!P87)E;G0Z.D1A=&%4<F5E3V)J96-T7T=R;W5P*"1N86UE*3L*
M("`@("`@("!I9B`H)'!A<F5N="D@>PH@("`@("`@("`@("`D=&AI<RT^9&%T
M85LG9&XG72`]('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G
M75LG<&%R86US)UU;)V=I9"==*2`N("<])R`N("1N86UE("X@)RPG("X@)'!A
M<F5N=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9&%T
M85LG9&XG72`]('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G
M75LG<&%R86US)UU;)V=I9"==*2`N("<])R`N("1N86UE("X*("`@("`@("`@
M("`@("`@("<L)R`N('-T<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O
M=7`G75LG<&%R86US)UU;)V)A<V5D;B==*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!'970@82!L:7-T(&]F(&5V97)Y('5S97(@=&AA="!I
M<R!P87)T(&]F('1H:7,@9W)O=7`@*&%N9"!O;FQY"B`@("`@*B!T:&ES(&=R
M;W5P*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@=7-E<B!L
M:7-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!L:7-T57-E<G,H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7V=R;W5P3V(M/FQI<W15<V5R<R@D=&AI
M<RT^9&%T85LG9&XG72D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@82!L
M:7-T(&]F(&5V97)Y('5S97(@=&AA="!I<R!A(&UE;6)E<B!O9B!T:&ES(&=R
M;W5P(&%N9"!A;GD@;V8*("`@("`J(&ET)W,@<W5B9W)O=7!S+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(%1H92!C;VUP;&5T92!U<V5R(&QI<W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1!;&Q5<V5R<R@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?9W)O=7!/8BT^;&ES=$%L;%5S97)S*"1T
M:&ES+3YD871A6R=D;B==*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@
M:6X@82!L:7-T(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@8F%C:V5N9"!A;F0@
M;6%P(&ET('1O(&]U<@H@("`@("H@:6YT97)N86P@9&%T82!A<G)A>2X*("`@
M("`J"B`@("`@*B!`<&%R86T@87)R87D@)&%T=')I8G5T97,@(%1H92!L:7-T
M(&]F(&%T=')I8G5T97,@9G)O;2!T:&4@8F%C:V5N9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V9R;VU!='1R:6)U=&5S*"1A='1R:6)U=&5S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("`D=&AI<RT^9&%T85LG=7-E<G,G72`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@:68@*"1K97D@/3T@<W1R=&]L;W=E<B@D
M1TQ/0D%,4ULG8V]N9B==6R=G<F]U<"==6R=P87)A;7,G75LG;65M8F5R=6ED
M)UTI*2!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;'5E*2D@
M>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D=7-E
M<BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&%T85LG=7-E
M<G,G75LD=7-E<ET@/2`G,2<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9&%T85LG=7-E<G,G75LD=F%L=65=(#T@)S$G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&ME>2`]/2`G;6%I;"<I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R=E;6%I;"==(#T@)'9A;'5E
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F1A=&%;)&ME>5T@/2`D=F%L=64["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-87`@=&AI<R!O8FIE8W0G<R!A='1R
M:6)U=&5S(&9R;VT@=&AE(&1A=&$@87)R87D@:6YT;R!A(&9O<FUA="!T:&%T
M"B`@("`@*B!C86X@8F4@<W1O<F5D(&EN(&%N($Q$05`@96YT<GDN"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&5N=')Y(&%R<F%Y+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?=&]!='1R:6)U=&5S*"D*("`@('L*("`@("`@
M("`D871T<FEB=71E<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/F1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@:68@
M*"1K97D@/3T@)W5S97)S)RD@>PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'9A;'5E(&%S("1U<V5R(#T^("1M96UB97)S:&EP*2!["B`@("`@("`@("`@
M("`@("`@("`@)&%T=')I8G5T97-;<W1R=&]L;W=E<B@D1TQ/0D%,4ULG8V]N
M9B==6R=G<F]U<"==6R=P87)A;7,G75LG;65M8F5R=6ED)UTI75M=(#T@)'5S
M97(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D
M:V5Y(#T]("=E;6%I;"<I('L*("`@("`@("`@("`@("`@("1A='1R:6)U=&5S
M6R=M86EL)UT@/2`A96UP='DH)'9A;'5E*2`_("1V86QU92`Z("<@)SL*("`@
M("`@("`@("`@?2!E;'-E:68@*"1K97D@(3T@)V1N)R`F)B`D:V5Y("$]('-T
M<G1O;&]W97(H)$=,3T)!3%-;)V-O;F8G75LG9W)O=7`G75LG<&%R86US)UU;
M)VUE;6)E<G5I9"==*2D@>PH@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;
M)&ME>5T@/2`A96UP='DH)'9A;'5E*2`_("1V86QU92`Z("<@)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1A='1R:6)U=&5S
M.PH@("`@?0H*?0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)O
M=7`O:&]O:W,N<&AP````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#8U-#0@,3`U,34T,S0Q,S<@,#(R,S`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!4:&4@1W)O
M=7!?:&]O:W,Z.B!C;&%S<R!P<F]V:61E<R!T:&4@2&]R9&4@9W)O=7!S('-Y
M<W1E;2!W:71H('1H90H@*B!A9&1I=&EO;B!O9B!A9&1I;F<@<W5P<&]R="!F
M;W(@:&]O:R!F=6YC=&EO;G,@=&\@9&5F:6YE(&EF(&$@=7-E<@H@*B!I<R!I
M;B!A(&=R;W5P+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F]U<"]'<F]U
M<"]H;V]K<RYP:'`L=B`Q+C<N,BXQ,"`R,#`V+S`Q+S`Q(#(Q.C(X.C$Y(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($IA<V]N(%)U<W0@
M/&IR=7-T0')U<W1Y<&%R=',N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F%S;VX@4G5S="`\:G)U<W1`<G5S='EP87)T<RYC;VT^"B`J($!S
M:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'<F]U<`H@*B\*
M8VQA<W,@1W)O=7!?:&]O:W,@97AT96YD<R!'<F]U<"!["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@1W)O=7!?
M:&]O:W,H*0H@("`@>PH@("`@("`@('!A<F5N=#HZ1W)O=7`H*3L*("`@("`@
M("!R97%U:7)E("1'3$]"04Q36R=R96=I<W1R>2==+3YG970H)V9I;&5R;V]T
M)RP@)VAO<F1E)RD@+B`G+V-O;F9I9R]H;V]K<RYP:'`G.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@;&ES="!O9B!E=F5R>2!G<F]U<"!T:&%T("1U
M<V5R(&ES(&EN+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1U<V5R
M("`@("`@("`@(%1H92!U<V5R('1O(&=E="!G<F]U<',@9F]R+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)'!A<F5N=$=R;W5P<R`@06QS;R!R971U<FX@=&AE
M('!A<F5N=',@;V8@86YY(&=R;W5P<S\*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!!;B!A<G)A>2!O9B!A;&P@9W)O=7!S('1H92!U<V5R(&ES(&EN
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971'<F]U<$UE;6)E<G-H:7!S*"1U
M<V5R+"`D<&%R96YT1W)O=7!S(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&UE
M;6)E<G-H:7!S(#T@<&%R96YT.CIG971'<F]U<$UE;6)E<G-H:7!S*"1U<V5R
M+"`D<&%R96YT1W)O=7!S*3L*("`@("`@("`D9W)O=7!S(#T@)'1H:7,M/FQI
M<W1'<F]U<',H*3L*("`@("`@("!F;W)E86-H("@D9W)O=7!S(&%S("1G:60@
M/3X@)&=R;W5P*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^:&%S2&]O:R@D
M9W)O=7`I("8F"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8R@D=&AI
M<RT^7V=E=$=R;W5P2&]O:TYA;64H)&=R;W5P*2P@)'5S97(I*2!["B`@("`@
M("`@("`@("`@("`D;65M8F5R<VAI<',@*ST@87)R87DH)&=I9"`]/B`D9W)O
M=7`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D<&%R96YT1W)O
M=7!S*2!["B`@("`@("`@("`@("`@("`D<&%R96YT<R`]("1T:&ES+3YG971'
M<F]U<%!A<F5N=$QI<W0H)&=I9"D["B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<&%R96YT<R!A<R`D<&ED(#T^("1P87)E;G0I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/FAA<TAO;VLH)'!A<F5N="D@)B8*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)'1H:7,M/E]G971'
M<F]U<$AO;VM.86UE*"1G<F]U<"DL("1U<V5R*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;65M8F5R<VAI<',@*ST@87)R87DH)'!I9"`]/B`D<&%R
M96YT*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;65M
M8F5R<VAI<',["B`@("!]"@H@("`@+RHJ"B`@("`@*B!387D@:68@82!U<V5R
M(&ES(&$@;65M8F5R(&]F(&$@9W)O=7`@;W(@;F]T+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1U<V5R("`@("`@(%1H92!N86UE(&]F('1H92!U
M<V5R+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&=I9"`@("`@("`@5&AE($E$
M(&]F('1H92!G<F]U<"X*("`@("`J($!P87)A;2!B;V]L96%N("1S=6)G<F]U
M<',@(%)E='5R;B!T<G5E(&EF('1H92!U<V5R(&ES(&EN(&%N>2!S=6)G<F]U
M<',*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]F("1G<F]U
M<"P@86QS;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=7-E<DES26Y'<F]U<"@D=7-E<BP@)&=I9"P@)'-U
M8F=R;W5P<R`]('1R=64I"B`@("!["B`@("`@("`@)&=R;W5P(#T@)'1H:7,M
M/F=E=$=R;W5P3F%M92@D9VED*3L*("`@("`@("!I9B`H)'1H:7,M/FAA<TAO
M;VLH)&=R;W5P*2D@>PH@("`@("`@("`@("!I9B`H8V%L;%]U<V5R7V9U;F,H
M)'1H:7,M/E]G971'<F]U<$AO;VM.86UE*"1G<F]U<"DL("1U<V5R*2D@>PH@
M("`@("`@("`@("`@("`@)&EN1W)O=7`@/2!T<G5E.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&EN1W)O=7`@/2!F86QS93L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1I;D=R
M;W5P(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H)&EN1W)O=7`@
M?'P@<&%R96YT.CIU<V5R27-);D=R;W5P*"1U<V5R+"`D9VED+"`D<W5B9W)O
M=7!S*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!I9B!A(&=R;W5P(&AA<R!A
M(&AO;VL@87-S;V-I871E9"!W:71H(&ET+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!G<F]U<"!N86UE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!I9B!T:&4@9W)O=7`@:&%S(&$@:&]O
M:RP@9F%L<V4@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA<TAO
M;VLH)&YA;64I"B`@("!["B`@("`@("`@<F5T=7)N(&9U;F-T:6]N7V5X:7-T
M<R@D=&AI<RT^7V=E=$=R;W5P2&]O:TYA;64H)&YA;64I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@=&AE(&AO;VL@9G5N
M8W1I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE
M(&=R;W5P(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H
M92!F=6YC=&EO;B!N86UE(&9O<B!T:&4@:&]O:R!F;W(@=&AI<R!G<F]U<`H@
M("`@("HO"B`@("!F=6YC=&EO;B!?9V5T1W)O=7!(;V]K3F%M92@D;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@)U]G<F]U<%]H;V]K7R<@+B!S=')?<F5P
M;&%C92@G.B<L("=?7R<L("1N86UE*3L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T=R
M87!H+U!L;W0`````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,3,W(#`R,3(T-0`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O1W)A<&@O0VAA<G0`````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S<@,#(Q,S<P
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]#:&%R="]P
M:64S9"YP:'``````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,V-R`Q
M,#4Q-30S-#$S-R`P,C,Q-S0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J(#-$(%!I92!G<F%P:"!I;7!L
M96UE;G1A=&EO;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+T=R87!H+T=R87!H+T-H87)T+W!I93-D+G!H
M<"QV(#$N,2XQ,"XT(#(P,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R
M9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D
M95]'<F%P:%]#:&%R=%]P:64S9"!["@H@("`@=F%R("1G<F%P:#L*"B`@("!V
M87(@)%]D871A<V5T.PH@("`@=F%R("1?<&%D9&EN9R`](#(P.PH@("`@=F%R
M("1?;W5T;&EN92`]('1R=64["B`@("!V87(@)%]C;VQO<G,@/2!A<G)A>2@G
M=&%N)RP@)W!A;&5G;VQD96YR;V0G+"`G;VQI=F5D<F%B)RP@)V)L=64G+"`G
M<F5D)RP@)V=R965N)RP@)WEE;&QO=R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`G;W)A;F=E)RP@)V=R87DG+"`G<'5R<&QE)RD["B`@("`O*BH*("`@
M("`@(C(U-2PQ-3,L,"(L"B`@("`@("(P+#(P-"PQ-3,B+`H@("`@("`B,C`T
M+#(U-2PQ,#(B+`H@("`@("`B,C4U+#$P,BPQ,#(B+`H@("`@("`B,3`R+#(P
M-"PR-34B+`H@("`@("`B,C`T+#$U,RPR-34B+`H@("`@("`B,C4U+#`L,"(L
M"B`@("`@("(U,2PP+#(U-2(L"B`@("`@("(R-34L-3$L,34S(BP*("`@("`@
M(C(P-"PP+#(U-2(L"B`@("`@("(R-34L,C4U+#4Q(BP*("`@("`@(C4Q+#(U
M-2PU,2(L"B`@("`@("(R-34L,3`R+#`B*3L*("`@("HO"@H@("`@9G5N8W1I
M;VX@2&]R9&5?1W)A<&A?0VAA<G1?<&EE,V0H)B1G<F%P:"P@)'!A<F%M<RD*
M("`@('L*("`@("`@("`D=&AI<RT^9W)A<&@@/2`F)&=R87!H.PH*("`@("`@
M("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@)'1H
M:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(&1R87<H*0H@("`@>PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+TAO<F1E+T=R87!H+T-H87)T+W!I92YP:'``````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$P-S$W(#$P-3$U-#,T,3,W(#`R,C<T,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@4&EE(&=R87!H(&EM<&QE;65N=&%T:6]N(&9O<B!T:&4@2&]R9&5?
M1W)A<&@@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1W)A<&@O
M1W)A<&@O0VAA<G0O<&EE+G!H<"QV(#$N,3`N,3`N-"`R,#`V+S`Q+S`Q(#(Q
M.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO
M<F<^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]'
M<F%P:`H@*B\*8VQA<W,@2&]R9&5?1W)A<&A?0VAA<G1?<&EE('L*"B`@("!V
M87(@)&=R87!H.PH*("`@('9A<B`D7V1A=&%S970["B`@("!V87(@)%]P861D
M:6YG(#T@,C`["B`@("!V87(@)%]O=71L:6YE(#T@=')U93L*("`@('9A<B`D
M7V-O;&]R<R`](&%R<F%Y*"=T86XG+"`G<&%L96=O;&1E;G)O9"<L("=O;&EV
M961R86(G+"`G8FQU92<L("=R960G+"`G9W)E96XG+"`G>65L;&]W)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("=O<F%N9V4G+"`G9W)A>2<L("=P=7)P
M;&4G*3L*("`@("\J*@H@("`@("`B,C4U+#$U,RPP(BP*("`@("`@(C`L,C`T
M+#$U,R(L"B`@("`@("(R,#0L,C4U+#$P,B(L"B`@("`@("(R-34L,3`R+#$P
M,B(L"B`@("`@("(Q,#(L,C`T+#(U-2(L"B`@("`@("(R,#0L,34S+#(U-2(L
M"B`@("`@("(R-34L,"PP(BP*("`@("`@(C4Q+#`L,C4U(BP*("`@("`@(C(U
M-2PU,2PQ-3,B+`H@("`@("`B,C`T+#`L,C4U(BP*("`@("`@(C(U-2PR-34L
M-3$B+`H@("`@("`B-3$L,C4U+#4Q(BP*("`@("`@(C(U-2PQ,#(L,"(I.PH@
M("`@*B\*"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:%]#:&%R=%]P:64H)B1G
M<F%P:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^9W)A<&@@/2`F
M)&=R87!H.PH*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]
M/B`D=F%L=64I('L*("`@("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*
M("`@("`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&1R87<H*0H@("`@>PH@("`@("`@("1D871A
M(#T@)'1H:7,M/F=R87!H+3Y?9&%T85LG>2==6R1T:&ES+3Y?9&%T87-E=%T[
M"@H@("`@("`@("\O($EN:71I86QI>F4@<V]M92!V87)I86)L97,N"B`@("`@
M("`@)&1I86UE=&5R(#T@;6EN*"1T:&ES+3YG<F%P:"T^7V=R87!H5VED=&@L
M("1T:&ES+3YG<F%P:"T^7V=R87!H2&5I9VAT*2`M("@D=&AI<RT^7W!A9&1I
M;F<@*B`R*3L*("`@("`@("`D<F%D:75S(#T@)&1I86UE=&5R("\@,CL*("`@
M("`@("`D8V]U;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@)'AC96YT97(@
M/2`D=&AI<RT^9W)A<&@M/E]G<F%P:$QE9G0@*R`D=&AI<RT^7W!A9&1I;F<@
M*R`H)'1H:7,M/F=R87!H+3Y?9W)A<&A7:61T:"`O(#(I.PH@("`@("`@("1Y
M8V5N=&5R(#T@)'1H:7,M/F=R87!H+3Y?9W)A<&A4;W`@*R`D=&AI<RT^7W!A
M9&1I;F<@*R`H)'1H:7,M/F=R87!H+3Y?9W)A<&A(96EG:'0@+R`R*3L*"B`@
M("`@("`@+R\@0V%L8W5L871E('1H92!S=6T@;V8@86QL('-L:6-E<RX*("`@
M("`@("`D<W5M(#T@,#L*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D>"D@
M>PH@("`@("`@("`@("`D<W5M("L]("1X.PH@("`@("`@('T*"B`@("`@("`@
M+R\@0V]N=F5R="!E86-H('-L:6-E(&EN=&\@=&AE(&-O<G)E<W!O;F1I;F<@
M<&5R8V5N=&%G92!O9B!A"B`@("`@("`@+R\@,S8P+61E9W)E92!C:7)C;&4N
M"B`@("`@("`@)&1E9T-O=6YT(#T@,#L*("`@("`@("`D<VQI8V5S(#T@87)R
M87DH*3L*("`@("`@("`D9&5G<F5E<R`](&%R<F%Y*"D["B`@("`@("`@9F]R
M96%C:"`H)&1A=&$@87,@)&D@/3X@)'DI('L*("`@("`@("`@("`@:68@*"@H
M)'D@+R`D<W5M*2`J(#,V,"D@/B`P*2!["B`@("`@("`@("`@("`@("`D9&5G
M<F5E<ULD9&5G0V]U;G1=(#T@*"1Y("\@)'-U;2D@*B`S-C`["B`@("`@("`@
M("`@("`@("`D<VQI8V5S6R1D96=#;W5N=%T@/2`D>3L*("`@("`@("`@("`@
M("`@("1N86UE<ULD9&5G0V]U;G1=(#T@:7-S970H)'1H:7,M/F=R87!H+3Y?
M9&%T85LG>"==6R1I72D@/R`D=&AI<RT^9W)A<&@M/E]D871A6R=X)UU;)&E=
M(#H@)R<["B`@("`@("`@("`@("`@("`D9&5G0V]U;G0K*SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@1')A=R!T:&4@8F%S96QI;F4N
M"B`@("`@("`@:68@*"1C;W5N="`^(#$I('L*("`@("`@("`@("`@)&QA<W1?
M86YG;&4@/2`P.PH@("`@("`@("`@("`D8V]U;G0@/2!C;W5N="@D9&5G<F5E
M<RD["B`@("`@("`@("`@(&9O<B`H)'H@/2`P.R`D>B`\("1C;W5N=#L@)'HK
M*RD@>PH@("`@("`@("`@("`@("`@+R\@0V%L8W5L871E(&%N9"!D<F%W(&%R
M8W,@8V]R<F5S<&]N9&EN9R!T;R!E86-H"B`@("`@("`@("`@("`@("`O+R!S
M;&EC92X*("`@("`@("`@("`@("`@("1C>B`]("1Z("4@8V]U;G0H)'1H:7,M
M/E]C;VQO<G,I.PH@("`@("`@("`@("`@("`@)'1H:7,M/F=R87!H+3YI;6<M
M/F%R8R@D>&-E;G1E<BP@)'EC96YT97(L("1R861I=7,L("1L87-T7V%N9VQE
M+"`H)&QA<W1?86YG;&4@*R`D9&5G<F5E<ULD>ETI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U=&QI;F4@/R`G
M8FQA8VLG(#H@)'1H:7,M/E]C;VQO<G-;)&-Z72P@)'1H:7,M/E]C;VQO<G-;
M)&-Z72D["B`@("`@("`@("`@("`@("`D;&%S=%]A;F=L92`]("1L87-T7V%N
M9VQE("L@)&1E9W)E97-;)'I=.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/F=R87!H+3YI;6<M/F-I<F-L92@D
M>&-E;G1E<BP@)'EC96YT97(L("1R861I=7,L("=B;&%C:R<L("1T:&ES+3Y?
M8V]L;W)S6S!=*3L*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!T:&4@
M8V]L;W(@:V5Y(&%N9"!S;&EC92!L86)E;',N"B`@("`@("`@)'E"87-E(#T@
M)'1H:7,M/F=R87!H+3Y?9W)A<&A4;W`["B`@("`@("`@)'A"87-E(#T@-3L*
M("`@("`@("`D;6%X(#T@<W1R;&5N*"AS=')I;F<I;6%X*"1D871A*2D["B`@
M("`@("`@9F]R("@D>B`](#`[("1Z(#P@)&1E9T-O=6YT.R`D>BLK*2!["B`@
M("`@("`@("`@("1C>B`]("1Z("4@8V]U;G0H)'1H:7,M/E]C;VQO<G,I.PH@
M("`@("`@("`@("`D<&5R8V5N="`]("@D9&5G<F5E<ULD>ET@+R`S-C`I("H@
M,3`P.PH@("`@("`@("`@("`D<&5R8V5N="`](')O=6YD*"1P97)C96YT+"`R
M*3L*("`@("`@("`@("`@)'E"87-E("L](#$U.PH*("`@("`@("`@("`@)'1H
M:7,M/F=R87!H+3YI;6<M/G)E8W1A;F=L92@D>$)A<V4L("1Y0F%S92P@,3(L
M(#$R+"`G8FQA8VLG+"`D=&AI<RT^7V-O;&]R<ULD8WI=*3L*("`@("`@("`@
M("`@:68@*"1S;&EC97-;)'I=(#X](#$P,#`@)B8@)'-L:6-E<ULD>ET@/"`Q
M,#`P,#`P*2!["B`@("`@("`@("`@("`@("`D<VQI8V5S6R1Z72`]("1S;&EC
M97-;)'I=("\@,3`P,#L*("`@("`@("`@("`@("`@("1S;&EC97-;)'I=(#T@
M)'-L:6-E<ULD>ET@+B`G:R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)')E<&5A="`]("1M87@@+2!S=')L96XH)'-L:6-E<ULD>ETI.PH@("`@("`@
M("`@("!I9B`H)')E<&5A="`\(#`I('L*("`@("`@("`@("`@("`@("1R97!E
M870@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S;&EC97-;)'I=
M(#T@<W1R7W)E<&5A="@G("<L("1R97!E870I("X@)'-L:6-E<ULD>ET["@H@
M("`@("`@("`@("`D=&AI<RT^9W)A<&@M/FEM9RT^=&5X="@D<VQI8V5S6R1Z
M72P@)'A"87-E("L@,C`L("@D>4)A<V4@*R`Q*2D["@H@("`@("`@("`@("`D
M;&%B96P@/2`D;F%M97-;)'I=("X@)R`H)R`N("1P97)C96YT("X@)R4I)SL*
M("`@("`@("`@("`@:68@*'-T<FQE;B@D;&%B96PI(#X@,C`I('L*("`@("`@
M("`@("`@("`@("1L86)E;',@/2!E>'!L;V1E*")<;B(L('=O<F1W<F%P*"1L
M86)E;"P@,C`I*3L*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L86)E;',@
M87,@)&D@/3X@)&QA8F5L*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1I
M(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D>4)A<V4@*ST@,34[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG<F%P:"T^:6UG+3YT97AT*"1L86)E;"P@)'A"87-E("L@,S4@*R`H
M)&UA>"`J(#0I+"`H)'E"87-E("L@,2DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F=R
M87!H+3YI;6<M/G1E>'0H)&QA8F5L+"`D>$)A<V4@*R`S-2`K("@D;6%X("H@
M-"DL("@D>4)A<V4@*R`Q*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@I]"@``````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O
M1W)A<&@O4&QO="]B87)G<F]U<&5D+G!H<```````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(U-S(@,3`U,34T,S0Q,S<@,#(T,3<U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+T=R87!H+U!L;W0O8F%R+G!H<"<["@HO*BH*("H@1W)O=7!E
M9"!B87(@9W)A<&@@:6UP;&5M96YT871I;VX@9F]R('1H92!(;W)D95]'<F%P
M:"!P86-K86=E+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]'<F%P:"]'<F%P
M:"]0;&]T+V)A<F=R;W5P960N<&AP+'8@,2XQ+C$P+C0@,C`P-B\P,2\P,2`R
M,3HR.#HQ."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P-B!#
M:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?
M1W)A<&@*("HO"F-L87-S($AO<F1E7T=R87!H7U!L;W1?8F%R9W)O=7!E9"!E
M>'1E;F1S($AO<F1E7T=R87!H7U!L;W1?8F%R('L*"B`@("!V87(@)%]S=&5P
M(#T@+C4["B`@("!V87(@)%]C;VQO<G,@/2!A<G)A>2@I.PH@("`@=F%R("1?
M9&%T87-E=',@/2!A<G)A>2@I.PH*("`@(&9U;F-T:6]N(&1R87<H*0H@("`@
M>PH@("`@("`@("\O($-A;&-U;&%T92!T:&4@<W1A<G1I;F<@;V9F<V5T(&9O
M<B!E86-H(&)A<BP@9G)O;2!W:&EC:"!W90H@("`@("`@("\O(&UO=F4@:70@
M;W9E<B!B>2`D=&AI<RT^7W-T97`N"B`@("`@("`@)&1A=&%S971S(#T@8V]U
M;G0H)'1H:7,M/E]D871A<V5T<RD["B`@("`@("`@)&=L;V)A;$]F9G-E="`]
M("1T:&ES+3Y?;V9F<V5T("T@*"@D=&AI<RT^7W-T97`@*B`H)&1A=&%S971S
M("T@,2DI("\@,BD["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1D871A
M<V5T<SL@)&DK*RD@>PH@("`@("`@("`@("`O+R!#86QC=6QA=&4@=&AE(&]F
M9G-E="!O9B!T:&ES('-E="!O9B!B87)S+@H@("`@("`@("`@("`D=&AI<RT^
M7V]F9G-E="`]("1G;&]B86Q/9F9S970@*R`H)'1H:7,M/E]S=&5P("H@)&DI
M.PH*("`@("`@("`@("`@+R\@4V5T(&)A<B!P87)A;65T97)S('1H870@8VAA
M;F=E('!E<BUG<F]U<"X*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M8V]L;W)S6R1I72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]L;W(@
M/2`D=&AI<RT^7V-O;&]R<ULD:5T["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/E]D871A<V5T(#T@)'1H:7,M/E]D871A<V5T<ULD:5T["@H@
M("`@("`@("`@("`O+R!$<F%W('1H:7,@9&%T87-E="X*("`@("`@("`@("`@
M<&%R96YT.CID<F%W*"D["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B](;W)D92]'<F%P:"]0;&]T+V)A<BYP:'``````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S`R,R`Q,#4Q-30S-#$S
M-R`P,C(U-S<`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J($)A<B!G<F%P:"!I;7!L96UE;G1A=&EO;B!F
M;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T=R87!H+T=R87!H+U!L;W0O8F%R+G!H<"QV(#$N-2XQ,BXT(#(P
M,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K
M86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T7V)A
M<B!["@H@("`@=F%R("1G<F%P:#L*"B`@("!V87(@)%]C;VQO<B`]("=B;'5E
M)SL*("`@('9A<B`D7V]U=&QI;F4@/2`G8FQA8VLG.PH@("`@=F%R("1?=VED
M=&@@/2`Q,#L*("`@('9A<B`D7V]F9G-E="`](#`["B`@("!V87(@)%]D871A
M<V5T.PH*("`@(&9U;F-T:6]N($AO<F1E7T=R87!H7U!L;W1?8F%R*"8D9W)A
M<&@L("1P87)A;7,I"B`@("!["B`@("`@("`@)'1H:7,M/F=R87!H(#T@)B1G
M<F%P:#L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@
M)'9A;'5E*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@+B`D<&%R86T["B`@
M("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!D<F%W*"1M:6Y9(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@)&1A=&$@/2`D=&AI<RT^9W)A<&@M/E]D871A6R=Y)UU;)'1H:7,M
M/E]D871A<V5T73L*"B`@("`@("`@)&)A<E=I9'1H(#T@)'1H:7,M/E]W:61T
M:#L*("`@("`@("`D8F%R3V9F<V5T(#T@)'1H:7,M/E]O9F9S970@*B`D8F%R
M5VED=&@["B`@("`@("`@)'4@/2`P.PH@("`@("`@("1V(#T@,#L*("`@("`@
M("`D8V]U;G0@/2!C;W5N="@D9&%T82D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1X(#T@)&D["B`@
M("`@("`@("`@(&EF("@D;6EN62`]/3T@9F%L<V4@?'P@)&1A=&%;)&E=(#X]
M("1M:6Y9*2!["B`@("`@("`@("`@("`@("`D>2`]("1D871A6R1I73L*("`@
M("`@("`@("`@("`@("1T:&ES+3YG<F%P:"T^=')A;G-L871E*"1X+"`D>2D[
M"B`@("`@("`@("`@("`@("`D>"`]("1X("T@*"1B87)7:61T:"`O(#(I("L@
M)&)A<D]F9G-E=#L*("`@("`@("`@("`@("`@("1H96EG:'0@/2`D=&AI<RT^
M9W)A<&@M/E]G<F%P:$)O='1O;2`M("1Y.PH*("`@("`@("`@("`@("`@("1T
M:&ES+3YG<F%P:"T^:6UG+3YR96-T86YG;&4H)'@L("1Y+"`D8F%R5VED=&@L
M("1H96EG:'0L("1T:&ES+3Y?;W5T;&EN92P@)'1H:7,M/E]C;VQO<BD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]B87)S=&%C:V5D+G!H<```
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$V,C4@,3`U,34T,S0Q,S<@,#(T
M,30T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J*@H@*B!3=&%C:V5D(&)A<B!G<F%P:"!I;7!L96UE;G1A=&EO
M;B!F;W(@=&AE($AO<F1E7T=R87!H('!A8VMA9V4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+T=R87!H+T=R87!H+U!L;W0O8F%R<W1A8VME9"YP:'`L=B`Q
M+C$N,3`N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C$X(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#,N
M,`H@*B!`<&%C:V%G92!(;W)D95]'<F%P:`H@*B\*8VQA<W,@2&]R9&5?1W)A
M<&A?4&QO=%]B87)S=&%C:V5D('L*"B`@("!V87(@)&=R87!H.PH*("`@('9A
M<B`D7V-O;&]R(#T@)V)L=64G.PH@("`@=F%R("1?;W5T;&EN92`]("=B;&%C
M:R<["B`@("!V87(@)%]W:61T:"`](#$P.PH@("`@=F%R("1?;V9F<V5T(#T@
M,#L*("`@('9A<B`D7V1A=&%S970["@H@("`@9G5N8W1I;VX@2&]R9&5?1W)A
M<&A?4&QO=%]B87)S=&%C:V5D*"8D9W)A<&@L("1P87)A;7,I"B`@("!["B`@
M("`@("`@)'1H:7,M/F=R87!H(#T@)B1G<F%P:#L*"B`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<R!A<R`D<&%R86T@/3X@)'9A;'5E*2!["B`@("`@("`@("`@
M("1K97D@/2`G7R<@+B`D<&%R86T["B`@("`@("`@("`@("1T:&ES+3XD:V5Y
M(#T@)'9A;'5E.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D<F%W
M*"D*("`@('L*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1W)A<&@O4&QO="]L:6YE+G!H<```
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R-3<@,3`U,34T,S0Q
M,S<@,#(R-S<S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!,:6YE(&=R87!H(&EM<&QE;65N=&%T:6]N
M(&9O<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F
M<F%M97=O<FLO1W)A<&@O1W)A<&@O4&QO="]L:6YE+G!H<"QV(#$N-"XQ,BXT
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T
M7VQI;F4@>PH*("`@('9A<B`D7V=R87!H.PH@("`@=F%R("1?8V]L;W(@/2`G
M8FQU92<["B`@("!V87(@)%]W:61T:"`](#$["B`@("!V87(@)%]D871A<V5T
M.PH*("`@(&9U;F-T:6]N($AO<F1E7T=R87!H7U!L;W1?;&EN92@F)&=R87!H
M+"`D<&%R86US*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9W)A<&@@/2`F)&=R
M87!H.PH*("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1P87)A;2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@)&ME>2`]("=?)R`N("1P87)A;3L*("`@
M("`@("`@("`@)'1H:7,M/B1K97D@/2`D=F%L=64["B`@("`@("`@?0H@("`@
M?0H*("`@(&9U;F-T:6]N(&1R87<H)&UI;ED@/2!F86QS92D*("`@('L*("`@
M("`@("`D9&%T82`]("1T:&ES+3Y?9W)A<&@M/E]D871A6R=Y)UU;)'1H:7,M
M/E]D871A<V5T73L*"B`@("`@("`@)&-O=6YT(#T@8V]U;G0H)&1A=&$I.PH@
M("`@("`@("1V97)T<R`](&%R<F%Y*"D["B`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1X(#T@)&D["B`@
M("`@("`@("`@(&EF("@D;6EN62`A/3T@9F%L<V4@)B8@)&1A=&%;)&E=(#P@
M)&UI;EDI('L*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D=F5R=',I(#T]
M(#$I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=R87!H+3YI;6<M
M/F-I<F-L92@D=F5R='-;,%U;)W@G72P@)'9E<G1S6S!=6R=Y)UTL("1T:&ES
M+3Y?=VED=&@L("1T:&ES+3Y?8V]L;W(L("1T:&ES+3Y?8V]L;W(I.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]G<F%P:"T^:6UG+3YP;VQY;&EN92@D=F5R
M=',L("1T:&ES+3Y?8V]L;W(L("1T:&ES+3Y?=VED=&@I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@)'9E<G1S(#T@87)R87DH*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M("1Y(#T@)&1A=&%;)&E=.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]G<F%P
M:"T^=')A;G-L871E*"1X+"`D>2D["B`@("`@("`@("`@("`@("`D=F5R='-;
M72`](&%R<F%Y*"=X)R`]/B`D>"P@)WDG(#T^("1Y*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]G<F%P:"T^:6UG+3YP;VQY
M;&EN92@D=F5R=',L("1T:&ES+3Y?8V]L;W(L("1T:&ES+3Y?=VED=&@I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O;&EB+TAO<F1E+T=R87!H+U!L;W0O<V-A='1E<BYP:'``````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#(Q(#$P-3$U-#,T,3,W(#`R
M,S4P,0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@4V-A='1E<B!P;&]T(&EM<&QE;65N=&%T:6]N(&9O
M<B!T:&4@2&]R9&5?1W)A<&@@<&%C:V%G92X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO1W)A<&@O1W)A<&@O4&QO="]S8V%T=&5R+G!H<"QV(#$N,RXQ,BXT
M(#(P,#8O,#$O,#$@,C$Z,C@Z,3@@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@
M/&-H=6-K0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P
M86-K86=E($AO<F1E7T=R87!H"B`J+PIC;&%S<R!(;W)D95]'<F%P:%]0;&]T
M7W-C871T97(@>PH*("`@('9A<B`D7V=R87!H.PH@("`@=F%R("1?8V]L;W(@
M/2`G8FQU92<["B`@("!V87(@)%]S:&%P92`]("=S<75A<F4G.PH@("`@=F%R
M("1?9&%T87-E=#L*"B`@("!F=6YC=&EO;B!(;W)D95]'<F%P:%]0;&]T7W-C
M871T97(H)B1G<F%P:"P@)'!A<F%M<RD*("`@('L*("`@("`@("`D=&AI<RT^
M7V=R87!H(#T@)B1G<F%P:#L*"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A
M<R`D<&%R86T@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1K97D@/2`G7R<@
M+B`D<&%R86T["B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)'9A;'5E.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!D<F%W*"1M:6Y9(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=R87!H+3Y?9&%T
M85LG>2==6R1T:&ES+3Y?9&%T87-E=%T["@H@("`@("`@("1C;W5N="`](&-O
M=6YT*"1D871A*3L*("`@("`@("`D=F5R=',@/2!A<G)A>2@I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@
M("`D>"`]("1I.PH@("`@("`@("`@("!I9B`H)&UI;ED@/3T](&9A;'-E('Q\
M("1D871A6R1I72`^/2`D;6EN62D@>PH@("`@("`@("`@("`@("`@)'D@/2`D
M9&%T85LD:5T["B`@("`@("`@("`@("`@("`D=&AI<RT^7V=R87!H+3YT<F%N
M<VQA=&4H)'@L("1Y*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9W)A<&@M
M/FEM9RT^8G)U<V@H)'@L("1Y+"`D=&AI<RT^7V-O;&]R+"`D=&AI<RT^7W-H
M87!E*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T
M82]O=71L;V]K8W-V+G!H<```````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#,T,C,@,3`U,34T,S0Q,S<@,#(S,30Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)TAO<F1E+T1A=&$O8W-V+G!H<"<["@HO*BH*("H@2&]R9&5?1&%T82!I;7!L
M96UE;G1A=&EO;B!F;W(@3W5T;&]O:R!C;VUM82US97!A<F%T960@9&%T82`H
M0U-6*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO1&%T82]$871A+V]U=&QO
M;VMC<W8N<&AP+'8@,2XS+C$P+C,@,C`P-2\Q,"\Q."`Q,3HP,3HP-"!J86X@
M17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B\*8VQA<W,@2&]R
M9&5?1&%T85]O=71L;V]K8W-V(&5X=&5N9',@2&]R9&5?1&%T85]C<W8@>PH*
M("`@("\J*@H@("`@("H@0G5I;&1S(&$@0U-6(&9I;&4@9G)O;2!A(&=I=F5N
M(&1A=&$@<W1R=6-T=7)E(&%N9"!R971U<FYS(&ET(&%S(&$*("`@("`J('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("`D9&%T82`@("`@
M("!!('1W;RUD:6UE;G-I;VYA;"!A<G)A>2!C;VYT86EN:6YG('1H92!D871A
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S970N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R("`@("!)9B!T<G5E+"!T:&4@<F]W
M<R!O9B`D9&%T82!A<F4@87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y<R!W:71H(&9I96QD(&YA;65S(&%S('1H
M96ER(&ME>7,N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!#
M4U8@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1&%T82@D9&%T
M82P@)&AE861E<B`](&9A;'-E+"`D97AP;W)T7VUA<'!I;F<@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I('Q\(&-O=6YT
M*"1D871A*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@
M("!]"@H@("`@("`@("1E>'!O<G0@/2`G)SL*("`@("`@("`D96]L(#T@(EQR
M7&XB.PH@("`@("`@("1H96%D(#T@87)R87E?:V5Y<RAC=7)R96YT*"1D871A
M*2D["B`@("`@("`@:68@*"1H96%D97(I('L*("`@("`@("`@("`@9F]R96%C
M:"`H)&AE860@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T
M>2@D:V5Y*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D97AP
M;W)T7VUA<'!I;F=;)&ME>5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1K97D@/2`D97AP;W)T7VUA<'!I;F=;)&ME>5T["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)R(G("X@
M)&ME>2`N("<B)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1E>'!O<G0@+CT@)RPG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1E
M>'!O<G0@/2!S=6)S='(H)&5X<&]R="P@,"P@+3$I("X@)&5O;#L*("`@("`@
M("!]"@H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1R;W<I('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&AE860@87,@)&ME>2D@>PH@("`@("`@("`@("`@
M("`@)&-E;&P@/2`D<F]W6R1K97E=.PH@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D8V5L;"D@?'P@)&-E;&P@/3T](#`I('L*("`@("`@("`@("`@("`@
M("`@("`D8V5L;"`]('!R96=?<F5P;&%C92@B+UPB+R(L(")<(EPB(BP@)&-E
M;&PI.PH@("`@("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)R(G("X@)&-E
M;&P@+B`G(B<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M97AP;W)T("X]("<L)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D97AP
M;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L("TQ*2`N("1E;VP["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&5X<&]R=#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+T1A=&$O=F-A
M<F0N<&AP````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,30S(#$P-3$U-#,T,3,W(#`R,C`R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E(&1I<FYA
M;64H7U]&24Q%7U\I("X@)R]I;6,N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]I0V%L96YD87(N<&AP)SL*"B\J*@H@*B!);7!L96UE;G0@=&AE($AO<F1E
M7T1A=&$Z.B!!4$D@9F]R('9#87)D(&1A=&$N"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T1A=&$O1&%T82]V8V%R9"YP:'`L=B`Q+C,S+C$P+C<@,C`P-B\P
M,2\P,2`R,3HR.#HQ,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7T1A
M=&$*("HO"F-L87-S($AO<F1E7T1A=&%?=F-A<F0@97AT96YD<R!(;W)D95]$
M871A7VEM8R!["@H@("`@+RHJ"B`@("`@*B!%>'!O<G1S('9C86QE;F1A<B!D
M871A(&%S(&$@<W1R:6YG+B!5;FQI:V4@=D5V96YT+"!V0V%R9"!D871A"B`@
M("`@*B!I<R!N;W0@96YC;&]S960@:6X@0D5'24Y\14Y$.G9#86QE;F1A<BX*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@("`@($%N(&%R<F%Y
M(&-O;G1A:6YI;F<@2&]R9&5?:4-A;&5N9&%R7W9C87)D"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@(&]B:F5C=',N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M971H;V0@(%1H92!I5&EP(&UE=&AO9"!T;R!U<V4N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@(%1H92!I0V%L96YD87(@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1&%T82@D9&%T82P@)&UE=&AO9"`]
M("=215%515-4)RD*("`@('L*("`@("`@("`D<R`]("<G.PH@("`@("`@(&9O
M<F5A8V@@*"1D871A(&%S("1V8V%R9"D@>PH@("`@("`@("`@("`D<RX]("1V
M8V%R9"T^97AP;W)T=D-A;&5N9&%R*"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D<SL*("`@('T*"GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]L:6(O2&]R9&4O1&%T82]V=&]D;RYP:'``````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,C$@,3`U,34T,S0Q,S<@,#(R,#4V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*BH@5V4@<F5L>2!O;B!T:&4@2&]R9&5?1&%T85]I;6,Z.B!A8G-T
M<F%C="!C;&%S<RX@*B\*<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]I;6,N<&AP)SL*"B\J*@H@*B!);7!L96UE;G0@=&AE($AO<F1E7T1A
M=&$Z.B!!4$D@9F]R('94;V1O(&1A=&$N"B`J"B`J("1(;W)D93H@9G)A;65W
M;W)K+T1A=&$O1&%T82]V=&]D;RYP:'`L=B`Q+C@N,3`N,R`R,#`V+S`Q+S`Q
M(#(Q.C(X.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`Q
M.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV
M92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O
M;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H
M=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("HO"F-L87-S($AO<F1E7T1A=&%?=G1O9&\@97AT
M96YD<R!(;W)D95]$871A7VEM8R!["@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O2&]R9&4O1&%T82]T<W8N<&AP````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C$P,S,@,3`U,34T,S0Q,S<@
M,#(Q-30R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!(;W)D95]$871A(&EM<&QE;65N=&%T:6]N(&9O
M<B!T86(M<V5P87)A=&5D(&1A=&$@*%135BDN"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+T1A=&$O1&%T82]T<W8N<&AP+'8@,2XR,RXQ,"XQ,"`R,#`V+S`X
M+S`S(#`R.C4P.C0P('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY
M.2TR,#`V($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E
M92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R
M;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES
M(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH
M=&UL+@H@*@H@*B!`875T:&]R("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N
M;W)G/@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E
M+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($AO<F1E
M7T1A=&$*("HO"F-L87-S($AO<F1E7T1A=&%?='-V(&5X=&5N9',@2&]R9&5?
M1&%T82!["@H@("`@=F%R("1?97AT96YS:6]N(#T@)W1S=B<["B`@("!V87(@
M)%]C;VYT96YT5'EP92`]("=T97AT+W1A8BUS97!A<F%T960M=F%L=65S)SL*
M"B`@("!F=6YC=&EO;B!I;7!O<G1$871A*"1C;VYT96YT<RP@)&AE861E<B`]
M(&9A;'-E+"`D9&5L:6UI=&5R(#T@(EQT(BD*("`@('L*("`@("`@("`D8V]N
M=&5N=',@/2!E>'!L;V1E*")<;B(L("1C;VYT96YT<RD["B`@("`@("`@)&1A
M=&$@/2!A<G)A>2@I.PH@("`@("`@(&EF("@D:&5A9&5R*2!["B`@("`@("`@
M("`@("1H96%D(#T@97AP;&]D92@D9&5L:6UI=&5R+"!A<G)A>5]S:&EF="@D
M8V]N=&5N=',I*3L*("`@("`@("!]"B`@("`@("`@9F]R96%C:"`H)&-O;G1E
M;G1S(&%S("1L:6YE*2!["B`@("`@("`@("`@(&EF("AT<FEM*"1L:6YE*2`]
M/2`G)RD@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&QI;F4@/2!E>'!L;V1E*"1D96QI;6ET97(L("1L
M:6YE*3L*("`@("`@("`@("`@:68@*"%I<W-E="@D:&5A9"DI('L*("`@("`@
M("`@("`@("`@("1D871A6UT@/2`D;&EN93L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1N97=L:6YE(#T@87)R87DH*3L*("`@("`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1H96%D*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@("`@("1N97=L:6YE6R1H96%D6R1I75T@
M/2!E;7!T>2@D;&EN95LD:5TI(#\@)R<@.B`D;&EN95LD:5T["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T85M=(#T@)&YE=VQI;F4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1D871A
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I;&1S(&$@5%-6(&9I;&4@9G)O
M;2!A(&=I=F5N(&1A=&$@<W1R=6-T=7)E(&%N9"!R971U<FYS(&ET(&%S(&$*
M("`@("`J('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1A
M=&$@("`@("!!('1W;RUD:6UE;G-I;VYA;"!A<G)A>2!C;VYT86EN:6YG('1H
M92!D871A('-E="X*("`@("`J($!P87)A;2!B;V]L96%N("1H96%D97(@($EF
M('1R=64L('1H92!R;W=S(&]F("1D871A(&%R92!A<W-O8VEA=&EV90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@9FEE;&0@
M;F%M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(%135B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O
M<G1$871A*"1D871A+"`D:&5A9&5R(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D9&%T82D@?'P@8V]U;G0H)&1A=&$I(#T](#`I('L*
M("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@("`@("`D97AP
M;W)T(#T@)R<["B`@("`@("`@)&AE860@/2!A<G)A>5]K97ES*&-U<G)E;G0H
M)&1A=&$I*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("`D
M97AP;W)T(#T@:6UP;&]D92@B7'0B+"`D:&5A9"D@+B`B7&XB.PH@("`@("`@
M('T*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D<F]W*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1H96%D(&%S("1K97DI('L*("`@("`@("`@("`@("`@
M("1C96QL(#T@)')O=ULD:V5Y73L*("`@("`@("`@("`@("`@(&EF("@A96UP
M='DH)&-E;&PI('Q\("1C96QL(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@
M("`@)&5X<&]R="`N/2`D8V5L;#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1E>'!O<G0@+CT@(EQT(CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D97AP;W)T(#T@<W5B<W1R*"1E>'!O<G0L(#`L("TQ*2`N(")<
M;B(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D97AP;W)T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0G5I;&1S(&$@5%-6(&9I;&4@9G)O;2!A(&=I=F5N
M(&1A=&$@<W1R=6-T=7)E(&%N9"!T<FEG9V5R<R!I=',@9&]W;FQO860N"B`@
M("`@*B!)="!$3T53($Y/5"!E>&ET('1H92!C=7)R96YT('-C<FEP="!B=70@
M;VYL>2!O=71P=71S('1H92!C;W)R96-T(&AE861E<G,*("`@("`J(&%N9"!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4
M:&4@;F%M92!O9B!T:&4@9FEL92!T;R!B92!D;W=N;&]A9&5D+@H@("`@("H@
M0'!A<F%M(&%R<F%Y("1D871A("`@("`@($$@='=O+61I;65N<VEO;F%L(&%R
M<F%Y(&-O;G1A:6YI;F<@=&AE(&1A=&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("!S970N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R
M("`@268@=')U92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S<V]C:6%T:79E
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@
M9FEE;&0@;F%M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@97AP;W)T1FEL92@D9FEL96YA;64L("1D871A+"`D:&5A9&5R(#T@9F%L
M<V4I"B`@("!["B`@("`@("`@)&5X<&]R="`]("1T:&ES+3YE>'!O<G1$871A
M*"1D871A+"`D:&5A9&5R*3L*("`@("`@("`D1TQ/0D%,4ULG8G)O=W-E<B==
M+3YD;W=N;&]A9$AE861E<G,H)&9I;&5N86UE+"`G=&5X="]T86(M<V5P87)A
M=&5D+79A;'5E<R<L(&9A;'-E+"!S=')L96XH)&5X<&]R="DI.PH@("`@("`@
M(&5C:&\@)&5X<&]R=#L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&%L
M;"!N96-E<W-A<GD@86-T:6]N<R!F;W(@=&AE(&=I=F5N(&EM<&]R="!S=&5P
M+"!P87)A;65T97)S(&%N9`H@("`@("H@9F]R;2!V86QU97,@86YD(')E='5R
M;G,@=&AE(&YE>'0@;F5C97-S87)Y('-T97`N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&%C=&EO;B`@5&AE(&-U<G)E;G0@<W1E<"X@3VYE(&]F
M('1H92!)35!/4E1?*B!C;VYS=&%N=',N"B`@("`@*B!`<&%R86T@87)R87D@
M)'!A<F%M("`@("!!;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG(&YE
M961E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M<R!F;W(@=&AE(&-U<G)E;G0@<W1E<"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!%:71H97(@=&AE(&YE>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O
M;G-T86YT(&]R(&EM<&]R=&5D"B`@("`@*B`@("`@("`@("`@("`@("!D871A
M('-E="!A9G1E<B!T:&4@9FEN86P@<W1E<"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M(#T@87)R87DH*2D*("`@('L*
M("`@("`@("!S=VET8V@@*"1A8W1I;VXI('L*("`@("`@("!C87-E($E-4$]2
M5%]&24Q%.@H@("`@("`@("`@("`D;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT
M4W1E<"@D86-T:6]N+"`D<&%R86TI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M;F5X=%]S=&5P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)&YE>'1?<W1E<#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M:68@*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9F]R;6%T)UT@/3T@)VUU
M;&)E<G)Y)R!\?`H@("`@("`@("`@("`@("`@)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=F;W)M870G72`]/2`G<&EN92<I('L*("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==(#T@)'1H:7,M/FEM
M<&]R=$9I;&4H)%]&24Q%4ULG:6UP;W)T7V9I;&4G75LG=&UP7VYA;64G72D[
M"B`@("`@("`@("`@("`@("`D9F]R;6%T(#T@)%]315-324].6R=I;7!O<G1?
M9&%T82==6R=F;W)M870G73L*("`@("`@("`@("`@("`@(&EF("@D9F]R;6%T
M(#T]("=M=6QB97)R>2<I('L*("`@("`@("`@("`@("`@("`@("`D87!P2V5Y
M<R`@/2!A<G)A>2@G86QI87,G+"`G;F%M92<L("=E;6%I;"<L("=C;VUP86YY
M)RP@)W=O<FM!9&1R97-S)RP@)W=O<FM0:&]N92<L("=H;VUE4&AO;F4G+"`G
M9F%X)RP@)VYO=&5S)RD["B`@("`@("`@("`@("`@("`@("`@)&1A=&%+97ES
M(#T@87)R87DH,"P@,2P@,BP@,RP@-"P@-2P@-BP@-RP@.2D["B`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&9O<FUA="`]/2`G<&EN92<I('L*("`@("`@
M("`@("`@("`@("`@("`D87!P2V5Y<R`](&%R<F%Y*"=A;&EA<R<L("=N86UE
M)RP@)V5M86EL)RP@)VYO=&5S)RD["B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%+97ES(#T@87)R87DH,"P@,2P@,BP@-"D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D87!P2V5Y<R!A<R`D:V5Y(#T^
M("1A<'`I('L*("`@("`@("`@("`@("`@("`@("`D;6%P6R1D871A2V5Y<ULD
M:V5Y75T@/2`D87!P.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&1A=&$@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=D871A)UT@87,@)')O=RD@>PH@
M("`@("`@("`@("`@("`@("`@("1H87-H(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&9O<FUA="`]/2`G;75L8F5R<GDG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7D=R<#HO(BP@
M)')O=ULP72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R;W=;,5T@/2!P<F5G7W)E<&QA8V4H)R]>*%M>+")=*RDL
M7',J*"XJ*20O)RP@)R0R("0Q)RP@)')O=ULQ72D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1D871A2V5Y<R!A<R`D:V5Y*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D
M:V5Y+"`D<F]W*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1H87-H6R1K97E=(#T@<W1R:7!S;&%S:&5S*'!R96=?<F5P;&%C92@G+UQ<
M7%QR+R<L(")<;B(L("1R;W=;)&ME>5TI*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("@D9F]R;6%T(#T]("=P:6YE)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)')O=RD@/"`S('Q\
M('!R96=?;6%T8V@H(B]>(T1%3$54140O(BP@)')O=ULP72D@?'P@<')E9U]M
M871C:"@B+ULH*5TO(BP@)')O=ULR72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R;W=;,5T@/2!P<F5G7W)E<&QA
M8V4H)R]>*%M>+")=*RDL7',J*"XJ*20O)RP@)R0R("0Q)RP@)')O=ULQ72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("\J($%D9')E<W,@8V%N(&)E(&$@
M9G5L;"!21D,X,C(@861D<F5S<R`J+PH@("`@("`@("`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A9&1R7V%R<B`]($UA:6Q?4D9#.#(R.CIP87)S94%D
M9')E<W-,:7-T*"1R;W=;,ETI.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&%D9')?87)R6S!=+3YM86EL8F]X*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@)')O=ULR72`]("1A
M9&1R7V%R<ELP72T^;6%I;&)O>"`N("=`)R`N("1A9&1R7V%R<ELP72T^:&]S
M=#L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1R;W=;,5TI
M("8F("%E;7!T>2@D861D<E]A<G);,%TM/G!E<G-O;F%L*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')O=ULQ72`]("1A9&1R7V%R<ELP72T^
M<&5R<V]N86P["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A=&%+97ES(&%S("1K97DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI
M<W1S*"1K97DL("1R;W<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&AA<VA;)&ME>5T@/2`D<F]W6R1K97E=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1D871A
M6UT@/2`D:&%S:#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9&%T82==(#T@)&1A=&$["B`@
M("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VUA<"==
M(#T@)&UA<#L*("`@("`@("`@("`@("`@("1R970@/2`D=&AI<RT^;F5X=%-T
M97`H24U03U)47T1!5$$L("1P87)A;2D["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@36]V92!U
M<&QO861E9"!F:6QE('-O('1H870@=V4@8V%N(')E860@:70@86=A:6X@:6X@
M=&AE(&YE>'0@<W1E<`H@("`@("`@("`@("`@("!A9G1E<B!T:&4@=7-E<B!G
M879E('-O;64@9F]R;6%T(&1E=&%I;',N("HO"B`@("`@("`@("`@("1U<&QO
M861E9"`]($)R;W=S97(Z.G=A<T9I;&55<&QO861E9"@G:6UP;W)T7V9I;&4G
M+"!?*")44U8@9FEL92(I*3L*("`@("`@("`@("`@:68@*&ES7V$H)'5P;&]A
M9&5D+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@D=7!L;V%D960M/F=E=$UE<W-A9V4H*2D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&9I;&5?;F%M92`]($AO<F1E.CIG
M971496UP1FEL92@G:6UP;W)T)RP@9F%L<V4I.PH@("`@("`@("`@("!I9B`H
M(6UO=F5?=7!L;V%D961?9FEL92@D7T9)3$536R=I;7!O<G1?9FEL92==6R=T
M;7!?;F%M92==+"`D9FEL95]N86UE*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE('5P;&]A9&5D(&9I;&4@8V]U
M;&0@;F]T(&)E('-A=F5D+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I;&5?;F%M92==(#T@)&9I
M;&5?;F%M93L*"B`@("`@("`@("`@("\J(%)E860@=&AE(&9I;&4G<R!F:7)S
M="!T=V\@;&EN97,@=&\@<VAO=R!T:&5M('1O('1H92!U<V5R+B`J+PH@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI;F5S
M)UT@/2`G)SL*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE7VYA;64L
M("=R)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@
M("1L:6YE7VYO(#T@,3L*("`@("`@("`@("`@("`@('=H:6QE("@D;&EN95]N
M;R`\(#,@)B8@)&QI;F4@/2!F9V5T<R@D9G`I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&YE=VQI;F4@/2!3=')I;F<Z.FQE;F=T:"@D;&EN92D@/B`Q,#`@
M/R`B7&XB(#H@)R<["B`@("`@("`@("`@("`@("`@("`@)%]315-324].6R=I
M;7!O<G1?9&%T82==6R=F:7)S=%]L:6YE<R==("X]('-U8G-T<B@D;&EN92P@
M,"P@,3`P*2`N("1N97=L:6YE.PH@("`@("`@("`@("`@("`@("`@("1L:6YE
M7VYO*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@<F5T=7)N($E-4$]25%]44U8["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E($E-4$]25%]44U8Z"B`@("`@("`@("`@("1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UT@/2!5=&EL.CIG971&;W)M1&%T
M82@G:&5A9&5R)RD["B`@("`@("`@("`@("1I;7!O<G1?9&%T82`]("1T:&ES
M+3YI;7!O<G1&:6QE*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FEL95]N
M86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTI.PH@
M("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G72`]
M("1I;7!O<G1?9&%T83L*("`@("`@("`@("`@=6YS970H)%]315-324].6R=I
M;7!O<G1?9&%T82==6R=M87`G72D["B`@("`@("`@("`@(')E='5R;B!)35!/
M4E1?34%04$5$.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ;F5X=%-T97`H)&%C=&EO
M;BP@)'!A<F%M*3L*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@
M?0H*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+VEC86QE;F1A<BYP
M:'``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(P-R`Q,#4Q
M-30S-#$S-R`P,C(V-3$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*B!792!R96QY(&]N('1H92!(;W)D95]$
M871A7VEM8SHZ(&%B<W1R86-T(&-L87-S+B`J+PIR97%U:7)E7V]N8V4@9&ER
M;F%M92A?7T9)3$5?7RD@+B`G+VEM8RYP:'`G.PH*+RHJ"B`J(%1H:7,@:7,@
M:4-A;&5N9&%R("AV0V%L96YD87(I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]$871A+T1A=&$O:6-A;&5N9&%R+G!H<"QV(#$N,S$N,3`N,R`R,#`V+S`Q
M+S`Q(#(Q.C(X.C$S(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3
M964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O
M<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI
M<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN
M:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&9O=7)M
M;VYT0&AO<F1E+F]R9SX*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("HO"F-L87-S($AO<F1E7T1A=&%?:6-A;&5N9&%R
M(&5X=&5N9',@2&]R9&5?1&%T85]I;6,@>PH*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]$871A+W9N;W1E
M+G!H<```````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,W
M,B`Q,#4Q-30S-#$S-R`P,C(P-C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE
M*%]?1DE,15]?*2`N("<O:6UC+G!H<"<["@HO*BH*("H@26UP;&5M96YT('1H
M92!(;W)D95]$871A.CH@05!)(&9O<B!V3F]T92!D871A+@H@*@H@*B`D2&]R
M9&4Z(&9R86UE=V]R:R]$871A+T1A=&$O=FYO=&4N<&AP+'8@,2XX+C$P+C4@
M,C`P-B\P,2\P,2`R,3HR.#HQ,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#$Y.3DM,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*B!#
M;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G
M96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!P86-K86=E($AO<F1E7T1A
M=&$*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!(;W)D95]$871A
M7W9N;W1E(&5X=&5N9',@2&]R9&5?1&%T85]I;6,@>PH*("`@("\J*@H@("`@
M("H@17AP;W)T<R!V8V%L96YD87(@9&%T82!A<R!A('-T<FEN9RX@56YL:6ME
M('9%=F5N="P@=DYO=&4@9&%T80H@("`@("H@:7,@;F]T(&5N8VQO<V5D(&EN
M($)%1TE.?$5.1#IV0V%L96YD87(N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1D871A("`@("!!;B!A<G)A>2!C;VYT86EN:6YG($AO<F1E7VE#86QE
M;F1A<E]V;F]T90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O8FIE
M8W1S+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("!4:&4@:51I<"!M
M971H;V0@=&\@=7-E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4
M:&4@:4-A;&5N9&%R(&1A=&$N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5X<&]R
M=$1A=&$H)&1A=&$L("1M971H;V0@/2`G4D5154535"<I"B`@("!["B`@("`@
M("`@9VQO8F%L("1P<F5F<SL*"B`@("`@("`@)'1H:7,M/E]I0V%L(#T@)FYE
M=R!(;W)D95]I0V%L96YD87(H*3L*"B`@("`@("`@)'1H:7,M/E]I0V%L+3YS
M971!='1R:6)U=&4H)TU%5$A/1"<L("1M971H;V0I.PH@("`@("`@("1S(#T@
M)R<["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&5V96YT*2!["B`@("`@
M("`@("`@("1S+CT@)&5V96YT+3YE>'!O<G1V0V%L96YD87(H*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1S.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+TAO<F1E+T1A=&$O:6UC+G!H<```````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V-#(W(#$P-3$U-#,T,3,W(#`R,34Q,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=(;W)D92]I0V%L96YD87(N<&AP)SL*"B\J*@H@
M*B!!8G-T<F%C="!I;7!L96UE;G1A=&EO;B!O9B!T:&4@2&]R9&5?1&%T83HZ
M($%022!F;W(@24U#(&1A=&$@+0H@*B!V0V%R9',@86YD(&E#86QE;F1A<B!D
M871A+"!E=&,N(%!R;W9I9&5S(&$@;G5M8F5R(&]F('5T:6QI='D*("H@;65T
M:&]D<R!T:&%T('9#87)D(&%N9"!I0V%L96YD87(@:6UP;&5M96YT871I;VX@
M8V%N('-H87)E(&%N9"!R96QY"B`J(&]N+@H@*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]$871A+T1A=&$O:6UC+G!H<"QV(#$N,S(N,3`N."`R,#`V+S`U+S`Y
M(#(S.C`V.C`Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P
M,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^
M"B`J($!P86-K86=E($AO<F1E7T1A=&$*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J+PIC;&%S<R!(;W)D95]$871A7VEM8R!E>'1E;F1S($AO<F1E7T1A=&$@
M>PH*("`@('9A<B`D7VE#86P@/2!F86QS93L*"B`@("!F=6YC=&EO;B!I;7!O
M<G1$871A*"1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:4-A;"`](&YE
M=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21T:&ES+3Y?:4-A
M;"T^<&%R<V5V0V%L96YD87(H)'1E>'0I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(E1H97)E('=A<R!A;B!E<G)O<B!I;7!O
M<G1I;F<@=&AE(&E#86QE;F1A<B!D871A+B(I*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^7VE#86PM/F=E=$-O;7!O;F5N=',H*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($)U:6QD<R!A;B!I0V%L96YD87(@9FEL92!F
M<F]M(&$@9VEV96X@9&%T82!S=')U8W1U<F4@86YD"B`@("`@*B!R971U<FYS
M(&ET(&%S(&$@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D
M9&%T82`@("`@06X@87)R87D@8V]N=&%I;FEN9R!(;W)D95]I0V%L96YD87)?
M=F5V96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&]B:F5C=',*
M("`@("`J($!P87)A;2!S=')I;F<@)&UE=&AO9"`@5&AE(&E4:7`@;65T:&]D
M('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&E#
M86QE;F1A<B!D871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!E>'!O<G1$871A
M*"1D871A+"`D;65T:&]D(#T@)U)%455%4U0G*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:4-A;"`](&YE=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("`D
M=&AI<RT^7VE#86PM/G-E=$%T=')I8G5T92@G34542$]$)RP@)&UE=&AO9"D[
M"@H@("`@("`@(&9O<F5A8V@@*"1D871A(&%S("1E=F5N="D@>PH@("`@("`@
M("`@("`D=&AI<RT^7VE#86PM/F%D9$-O;7!O;F5N="@D979E;G0I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:4-A;"T^97AP;W)T=D-A
M;&5N9&%R*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!"=6EL9',@86X@:4-A
M;&5N9&%R(&9I;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R=6-T=7)E(&%N9`H@
M("`@("H@=')I9V=E<G,@:71S(&1O=VYL;V%D+B`@270@1$]%4R!.3U0@97AI
M="!T:&4@8W5R<F5N="!S8W)I<'0@8G5T"B`@("`@*B!O;FQY(&]U='!U=',@
M=&AE(&-O<G)E8W0@:&5A9&5R<R!A;F0@9&%T82X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F:6QE;F%M92`@(%1H92!N86UE(&]F('1H92!F:6QE
M('1O(&)E(&1O=VYL;V%D960N"B`@("`@*B!`<&%R86T@87)R87D@)&1A=&$@
M("`@("`@($%N(&%R<F%Y(&-O;G1A:6YI;F<@2&]R9&5?:4-A;&5N9&%R7W9E
M=F5N=',*("`@("`J+PH@("`@9G5N8W1I;VX@97AP;W)T1FEL92@D9FEL96YA
M;64L("1D871A*0H@("`@>PH@("`@("`@("1E>'!O<G0@/2`D=&AI<RT^97AP
M;W)T1&%T82@D9&%T82D["B`@("`@("`@)$=,3T)!3%-;)V)R;W=S97(G72T^
M9&]W;FQO861(96%D97)S*"1F:6QE;F%M92P@)W1E>'0O8V%L96YD87(G+"!F
M86QS92P@<W1R;&5N*"1E>'!O<G0I*3L*("`@("`@("!E8VAO("1E>'!O<G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME<R!A;&P@;F5C97-S87)Y(&%C
M=&EO;G,@9F]R('1H92!G:79E;B!I;7!O<G0@<W1E<"P*("`@("`J('!A<F%M
M971E<G,@86YD(&9O<FT@=F%L=65S(&%N9"!R971U<FYS('1H92!N97AT(&YE
M8V5S<V%R>2!S=&5P+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1A
M8W1I;VX@(%1H92!C=7)R96YT('-T97`N($]N92!O9B!T:&4@24U03U)47RH@
M8V]N<W1A;G1S+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;2`@("`@06X@
M87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!N965D960*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@9F]R('1H92!C=7)R
M96YT('-T97`N"B`@("`@*B!`<F5T=7)N(&UI>&5D("!%:71H97(@=&AE(&YE
M>'0@<W1E<"!A<R!A;B!I;G1E9V5R(&-O;G-T86YT(&]R(&EM<&]R=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("!D871A('-E="!A9G1E<B!T:&4@9FEN86P@
M<W1E<"X*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%-T97`H)&%C=&EO;BP@
M)'!A<F%M(#T@87)R87DH*2D*("`@('L*("`@("`@("!S=VET8V@@*"1A8W1I
M;VXI('L*("`@("`@("!C87-E($E-4$]25%]&24Q%.@H@("`@("`@("`@("`D
M;F5X=%]S=&5P(#T@<&%R96YT.CIN97AT4W1E<"@D86-T:6]N+"`D<&%R86TI
M.PH@("`@("`@("`@("!I9B`H:7-?82@D;F5X=%]S=&5P+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&YE>'1?<W1E<#L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&EM<&]R=%]D871A(#T@)'1H:7,M
M/FEM<&]R=$9I;&4H)%]&24Q%4ULG:6UP;W)T7V9I;&4G75LG=&UP7VYA;64G
M72D["B`@("`@("`@("`@(&EF("AI<U]A*"1I;7!O<G1?9&%T82P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I;7!O<G1?9&%T
M83L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M:4-A;"T^9V5T0V]M<&]N96YT<R@I.PH@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@<F5T=7)N('!A<F5N=#HZ;F5X
M=%-T97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B](;W)D92]$871A+V-S=BYP:'``````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`R-C<T-R`Q,#4Q-30S-#$S-R`P,C$U-#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J($AO<F1E7T1A=&$@:6UP;&5M96YT871I;VX@9F]R(&-O;6UA
M+7-E<&%R871E9"!D871A("A#4U8I+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R
M:R]$871A+T1A=&$O8W-V+G!H<"QV(#$N,S`N,3`N."`R,#`V+S`Q+S(X(#$V
M.C(Q.C4X(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"B`J
M($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@
M*B!`<VEN8V4@("!(;W)D92`Q+C,*("H@0'!A8VMA9V4@2&]R9&5?1&%T80H@
M*B\*8VQA<W,@2&]R9&5?1&%T85]C<W8@97AT96YD<R!(;W)D95]$871A('L*
M"B`@("!V87(@)%]E>'1E;G-I;VX@/2`G8W-V)SL*("`@('9A<B`D7V-O;G1E
M;G14>7!E(#T@)W1E>'0O8V]M;6$M<V5P87)A=&5D+79A;'5E<R<["@H@("`@
M+RHJ"B`@("`@*B!4<FEE<R!T;R!D:7-C;W9E<B!T:&4@0U-6(&9I;&4G<R!P
M87)A;65T97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N
M86UE("!4:&4@;F%M92!O9B!T:&4@9FEL92!T;R!I;G9E<W1I9V%T92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;B!A<W-O8VEA=&EV92!A<G)A
M>2!W:71H('1H92!F;VQL;W=I;F<@<&]S<VEB;&4@:V5Y<SH*("`@("`J(#QP
M<F4^"B`@("`@*B`G<V5P)SH@("`@5&AE(&9I96QD('-E<&%R871O<@H@("`@
M("H@)W%U;W1E)SH@(%1H92!Q=6]T:6YG(&-H87)A8W1E<@H@("`@("H@)V9I
M96QD<R<Z(%1H92!N=6UB97(@;V8@9FEE;&1S("AC;VQU;6YS*0H@("`@("H@
M/"]P<F4^"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O=F5R1F]R;6%T*"1F
M:6QE;F%M92D*("`@('L*("`@("`@("!`:6YC;'5D95]O;F-E*"=&:6QE+T-3
M5BYP:'`G*3L*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"=&:6QE7T-35B<I
M*2!["B`@("`@("`@("`@(')E='5R;B!&:6QE7T-35CHZ9&ES8V]V97)&;W)M
M870H)&9I;&5N86UE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R
M971U<FX@87)R87DH)W-E<"<@/3X@)RPG*3L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!);7!O<G1S(&%N9"!P87)S97,@82!#4U8@9FEL92X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE(&YA
M;64@;V8@=&AE(&9I;&4@=&\@<&%R<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D:&5A9&5R("`@1&]E<R!T:&4@9FER<W0@;&EN92!C;VYT86EN('1H92!F
M:65L9"]C;VQU;6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N
M86UE<S\*("`@("`J($!P87)A;2!S=')I;F<@)'-E<"`@("`@("!4:&4@9FEE
M;&0O8V]L=6UN('-E<&%R871O<BX*("`@("`J($!P87)A;2!S=')I;F<@)'%U
M;W1E("`@("!4:&4@<75O=&EN9R!C:&%R86-T97(N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D9FEE;&1S("`@5&AE(&YU;6)E<B!O<B!F:65L9',O8V]L=6UN
M<RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H87)S970@("!4:&4@9FEL92=S
M(&-H87)S970N($!S:6YC92!(;W)D92`S+C$N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C<FQF("`@("`@5&AE(&9I;&4G<R!L:6YE9F5E9"!C:&%R86-T97)S
M+B!`<VEN8V4@2&]R9&4@,RXQ+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y(&]F(&%L;"!I;7!O<G1E9"!D
M871A(')O=W,N("!)9@H@("`@("H@("`@("`@("`@("`@("`@)&AE861E<B!W
M87,@=')U92!T:&4@<F]W<R!A<F4@87-S;V-I871I=F4@87)R87ES('=I=&@@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("!F:65L9"]C;VQU;6X@;F%M97,@
M87,@=&AE(&ME>7,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM<&]R=$9I;&4H
M)&9I;&5N86UE+"`D:&5A9&5R(#T@9F%L<V4L("1S97`@/2`G)RP@)'%U;W1E
M(#T@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9',@/2!N=6QL
M+"`D:6UP;W)T7VUA<'!I;F<@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`D8VAA<G-E="`](&YU;&PL("1C<FQF(#T@;G5L;"D*("`@('L*
M("`@("`@("!`:6YC;'5D95]O;F-E*"=&:6QE+T-35BYP:'`G*3L*"B`@("`@
M("`@)&1A=&$@/2!A<G)A>2@I.PH*("`@("`@("`O*B!&:6QE7T-35B!I<R!P
M<F5S96YT+B`J+PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)T9I;&5?0U-6
M)RDI('L*("`@("`@("`@("`@)'1H:7,M/E]W87)N:6YG<R`](&%R<F%Y*"D[
M"@H@("`@("`@("`@("`O*B!&:6QE7T-35B!I<R!A(&)I="!P:6-K>2!A="!W
M:&%T('!A<F%M971E<B!I="!E>'!E8W1S+B`J+PH@("`@("`@("`@("`D8V]N
M9B`](&%R<F%Y*"D["B`@("`@("`@("`@(&EF("@A96UP='DH)'%U;W1E*2D@
M>PH@("`@("`@("`@("`@("`@)&-O;F9;)W%U;W1E)UT@/2`D<75O=&4["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&5M<'1Y*"1S97`I*2!["B`@
M("`@("`@("`@("`@("`D8V]N9ELG<V5P)UT@/2`G+"<["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D8V]N9ELG<V5P)UT@/2`D<V5P
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9FEE;&1S*2!["B`@
M("`@("`@("`@("`@("`D8V]N9ELG9FEE;&1S)UT@/2`D9FEE;&1S.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1D871A
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP='DH)&-R;&8I
M*2!["B`@("`@("`@("`@("`@("`D8V]N9ELG8W)L9B==(#T@)&-R;&8["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%-T<FEP(&%N9"!K965P('1H
M92!F:7)S="!L:6YE(&EF(&ET(&-O;G1A:6YS('1H92!F:65L9`H@("`@("`@
M("`@("`@*B!N86UE<RX@*B\*("`@("`@("`@("`@:68@*"1H96%D97(I('L*
M("`@("`@("`@("`@("`@("1H96%D(#T@1FEL95]#4U8Z.G)E860H)&9I;&5N
M86UE+"`D8V]N9BD["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D:&5A9"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M:&5A9#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A
M96UP='DH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`@("`@)&AE860@
M/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1H96%D+"`D8VAA<G-E="P@3DQ3
M.CIG971#:&%R<V5T*"DI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!&:6QE7T-35CHZ<F5A
M9"@D9FEL96YA;64L("1C;VYF*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7V$H)&QI;F4L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)&QI;F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;&EN92P@)&-H
M87)S970L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&AE860I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;72`]("1L:6YE.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F5W;&EN92`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)&AE860I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:6UP;W)T7VUA<'!I;F=;)&AE861;)&E=72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1H96%D6R1I72`]("1I;7!O<G1?;6%P
M<&EN9ULD:&5A9%LD:5U=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C96QL(#T@)&QI;F5;)&E=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8V5L;"`]('!R96=?<F5P;&%C92@B+UPB
M7"(O(BP@(EPB(BP@)&-E;&PI.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;F5W;&EN95LD:&5A9%LD:5U=(#T@96UP='DH)&-E;&PI(#\@)R<@.B`D8V5L
M;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;72`]("1N97=L:6YE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D9G`@/2!&:6QE7T-35CHZ9V5T4&]I;G1E
M<B@D9FEL96YA;64L("1C;VYF*3L*("`@("`@("`@("`@:68@*"1F<"`F)B`A
M:7-?82@D9G`L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E
M=VEN9"@D9G`I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D=&AI<RT^
M7W=A<FYI;F=S(#T@1FEL95]#4U8Z.G=A<FYI;F<H*3L*"B`@("`@("`@+RH@
M1F%L;"!B86-K('1O(&9G971C<W8H*2X@*B\*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9G`@/2!F;W!E;B@D9FEL96YA;64L("=R)RD["B`@("`@
M("`@("`@(&EF("@A)&9P*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J(%-T<FEP(&%N9"!K
M965P('1H92!F:7)S="!L:6YE(&EF(&ET(&-O;G1A:6YS('1H92!F:65L9`H@
M("`@("`@("`@("`@("!N86UE<RX@*B\*("`@("`@("`@("`@:68@*"1H96%D
M97(I('L*("`@("`@("`@("`@("`@("1H96%D(#T@9F=E=&-S=B@D9G`L(#$P
M,C0L("1S97`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A96UP
M='DH)&-H87)S970I*2!["B`@("`@("`@("`@("`@("`D:&5A9"`](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)&AE860L("1C:&%R<V5T+"!.3%,Z.F=E=$-H
M87)S970H*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@=VAI;&4@*"1L
M:6YE(#T@9F=E=&-S=B@D9G`L(#$P,C0L("1S97`I*2!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1C:&%R<V5T*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1L:6YE(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;&EN92P@)&-H
M87)S970L($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&AE860I*2!["B`@("`@("`@
M("`@("`@("`@("`@)&1A=&%;72`]("1L:6YE.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D;F5W;&EN92`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U
M;G0H)&AE860I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D:6UP;W)T7VUA<'!I;F=;)&AE861;)&E=72DI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1H96%D6R1I72`]("1I;7!O<G1?;6%P
M<&EN9ULD:&5A9%LD:5U=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C96QL(#T@)&QI;F5;)&E=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D8V5L;"`]('!R96=?<F5P;&%C92@B+UPB
M+R(L(")<(EPB(BP@)&-E;&PI.PH@("`@("`@("`@("`@("`@("`@("`@("`D
M;F5W;&EN95LD:&5A9%LD:5U=(#T@96UP='DH)&-E;&PI(#\@)R<@.B`D8V5L
M;#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)&1A=&%;72`]("1N97=L:6YE.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@0G5I
M;&1S(&$@0U-6(&9I;&4@9G)O;2!A(&=I=F5N(&1A=&$@<W1R=6-T=7)E(&%N
M9"!R971U<FYS(&ET(&%S(&$*("`@("`J('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&1A=&$@("`@("!!('1W;RUD:6UE;G-I;VYA;"!A
M<G)A>2!C;VYT86EN:6YG('1H92!D871A('-E="X*("`@("`J($!P87)A;2!B
M;V]L96%N("1H96%D97(@($EF('1R=64L('1H92!R;W=S(&]F("1D871A(&%R
M92!A<W-O8VEA=&EV90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87ES('=I=&@@9FEE;&0@;F%M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE($-35B!D871A+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!E>'!O<G1$871A*"1D871A+"`D:&5A9&5R(#T@9F%L
M<V4L("1E>'!O<G1?;6%P<&EN9R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D9&%T82D@?'P@8V]U;G0H)&1A=&$I(#T](#`I('L*
M("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)&5X
M<&]R="`]("<G.PH@("`@("`@("1E;VP@/2`B7&XB.PH@("`@("`@("1H96%D
M(#T@87)R87E?:V5Y<RAC=7)R96YT*"1D871A*2D["B`@("`@("`@:68@*"1H
M96%D97(I('L*("`@("`@("`@("`@9F]R96%C:"`H)&AE860@87,@)&ME>2D@
M>PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:V5Y*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D97AP;W)T7VUA<'!I;F=;)&ME>5TI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1K97D@/2`D97AP;W)T7VUA
M<'!I;F=;)&ME>5T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("1E>'!O<G0@+CT@)R(G("X@)&ME>2`N("<B)SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1E>'!O<G0@+CT@)RPG.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1E>'!O<G0@/2!S=6)S='(H)&5X
M<&]R="P@,"P@+3$I("X@)&5O;#L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1D871A(&%S("1R;W<I('L*("`@("`@("`@("`@9F]R96%C:"`H)&AE
M860@87,@)&ME>2D@>PH@("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W6R1K
M97E=.PH@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D8V5L;"D@?'P@)&-E
M;&P@/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`D97AP;W)T("X]("<B
M)R`N("1C96QL("X@)R(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&5X<&]R="`N/2`G+"<["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)&5X<&]R="`]('-U8G-T<B@D97AP;W)T+"`P+"`M,2D@+B`D96]L.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E>'!O<G0["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!"=6EL9',@82!#4U8@9FEL92!F<F]M(&$@9VEV96X@9&%T
M82!S=')U8W1U<F4@86YD('1R:6=G97)S(&ET<PH@("`@("H@9&]W;FQO860N
M("!)="!$3T53($Y/5"!E>&ET('1H92!C=7)R96YT('-C<FEP="!B=70@;VYL
M>2!O=71P=71S('1H90H@("`@("H@8V]R<F5C="!H96%D97)S(&%N9"!D871A
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&5N86UE("!4:&4@
M;F%M92!O9B!T:&4@9FEL92!T;R!B92!D;W=N;&]A9&5D+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1D871A("`@("`@($$@='=O+61I;65N<VEO;F%L(&%R<F%Y
M(&-O;G1A:6YI;F<@=&AE(&1A=&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!S970N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D:&5A9&5R("`@
M268@=')U92P@=&AE(')O=W,@;V8@)&1A=&$@87)E(&%S<V]C:6%T:79E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87ES('=I=&@@9FEE
M;&0@;F%M97,@87,@=&AE:7(@:V5Y<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M97AP;W)T1FEL92@D9FEL96YA;64L("1D871A+"`D:&5A9&5R(#T@9F%L<V4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'!O<G1?;6%P<&EN9R`](&%R
M<F%Y*"DI"B`@("!["B`@("`@("`@)&5X<&]R="`]("1T:&ES+3YE>'!O<G1$
M871A*"1D871A+"`D:&5A9&5R+"`D97AP;W)T7VUA<'!I;F<I.PH@("`@("`@
M("1'3$]"04Q36R=B<F]W<V5R)UTM/F1O=VYL;V%D2&5A9&5R<R@D9FEL96YA
M;64L("=A<'!L:6-A=&EO;B]C<W8G+"!F86QS92P@<W1R;&5N*"1E>'!O<G0I
M*3L*("`@("`@("!E8VAO("1E>'!O<G0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!486ME<R!A;&P@;F5C97-S87)Y(&%C=&EO;G,@9F]R('1H92!G:79E;B!I
M;7!O<G0@<W1E<"P@<&%R86UE=&5R<R!A;F0*("`@("`J(&9O<FT@=F%L=65S
M(&%N9"!R971U<FYS('1H92!N97AT(&YE8V5S<V%R>2!S=&5P+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G1E9V5R("1A8W1I;VX@(%1H92!C=7)R96YT('-T
M97`N($]N92!O9B!T:&4@24U03U)47RH@8V]N<W1A;G1S+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1P87)A;2`@("`@06X@87-S;V-I871I=F4@87)R87D@8V]N
M=&%I;FEN9R!N965D960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M('!A<F%M971E<G,@9F]R('1H92!C=7)R96YT('-T97`N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@16ET:&5R('1H92!N97AT('-T97`@87,@86X@
M:6YT96=E<B!C;VYS=&%N="!O<B!I;7!O<G1E9`H@("`@("H@("`@("`@("`@
M("`@("`@9&%T82!S970@869T97(@=&AE(&9I;F%L('-T97`N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&YE>'13=&5P*"1A8W1I;VXL("1P87)A;2`](&%R<F%Y
M*"DI"B`@("!["B`@("`@("`@<W=I=&-H("@D86-T:6]N*2!["B`@("`@("`@
M8V%S92!)35!/4E1?1DE,13H*("`@("`@("`@("`@)&YE>'1?<W1E<"`]('!A
M<F5N=#HZ;F5X=%-T97`H)&%C=&EO;BP@)'!A<F%M*3L*("`@("`@("`@("`@
M:68@*&ES7V$H)&YE>'1?<W1E<"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1N97AT7W-T97`["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($UO=F4@=7!L;V%D960@9FEL92!S;R!T:&%T('=E(&-A
M;B!R96%D(&ET(&%G86EN(&EN('1H92!N97AT"B`@("`@("`@("`@("`@('-T
M97`@869T97(@=&AE('5S97(@9V%V92!S;VUE(&9O<FUA="!D971A:6QS+B`J
M+PH@("`@("`@("`@("`D9FEL95]N86UE(#T@2&]R9&4Z.F=E=%1E;7!&:6QE
M*"=I;7!O<G0G+"!F86QS92D["B`@("`@("`@("`@(&EF("@A;6]V95]U<&QO
M861E9%]F:6QE*"1?1DE,15-;)VEM<&]R=%]F:6QE)UU;)W1M<%]N86UE)UTL
M("1F:6QE7VYA;64I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BA?*")4:&4@=7!L;V%D960@9FEL92!C;W5L9"!N;W0@8F4@
M<V%V960N(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1?4T534TE/
M3ELG:6UP;W)T7V1A=&$G75LG9FEL95]N86UE)UT@/2`D9FEL95]N86UE.PH*
M("`@("`@("`@("`@+RH@5')Y('1O(&1I<V-O=F5R('1H92!F:6QE(&9O<FUA
M="!O=7)S96QV97,N("HO"B`@("`@("`@("`@("1C;VYF(#T@)'1H:7,M/F1I
M<V-O=F5R1F]R;6%T*"1F:6QE7VYA;64I.PH@("`@("`@("`@("!I9B`H(21C
M;VYF*2!["B`@("`@("`@("`@("`@("`D8V]N9B`](&%R<F%Y*"=S97`G(#T^
M("<L)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%]315-324].6R=I
M;7!O<G1?9&%T82==(#T@87)R87E?;65R9V4H)%]315-324].6R=I;7!O<G1?
M9&%T82==+"`D8V]N9BD["@H@("`@("`@("`@("`O*B!#:&5C:R!I9B!C:&%R
M<V5T('=A<R!S<&5C:69I960N("HO"B`@("`@("`@("`@("1?4T534TE/3ELG
M:6UP;W)T7V1A=&$G75LG8VAA<G-E="==(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V-H87)S970G*3L*"B`@("`@("`@("`@("\J(%)E860@=&AE(&9I;&4G<R!F
M:7)S="!T=V\@;&EN97,@=&\@<VAO=R!T:&5M('1O('1H92!U<V5R+B`J+PH@
M("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V9I<G-T7VQI
M;F5S)UT@/2`G)SL*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE7VYA
M;64L("=R)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@
M("`@("1L:6YE7VYO(#T@,3L*("`@("`@("`@("`@("`@('=H:6QE("@D;&EN
M95]N;R`\(#,@)B8@)&QI;F4@/2!F9V5T<R@D9G`I*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;
M)V-H87)S970G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F4@
M/2!3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1L:6YE+"`D7U-%4U-)3TY;)VEM
M<&]R=%]D871A)UU;)V-H87)S970G72P@3DQ3.CIG971#:&%R<V5T*"DI.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;F5W
M;&EN92`](%-T<FEN9SHZ;&5N9W1H*"1L:6YE*2`^(#$P,"`_(")<;B(@.B`G
M)SL*("`@("`@("`@("`@("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A
M)UU;)V9I<G-T7VQI;F5S)UT@+CT@<W5B<W1R*"1L:6YE+"`P+"`Q,#`I("X@
M)&YE=VQI;F4["B`@("`@("`@("`@("`@("`@("`@)&QI;F5?;F\K*SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@24U03U)47T-35CL*"B`@("`@("`@8V%S92!)35!/4E1?0U-6.@H@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)VAE861E<B==(#T@
M571I;#HZ9V5T1F]R;41A=&$H)VAE861E<B<I.PH@("`@("`@("`@("`D:6UP
M;W)T7VUA<'!I;F<@/2!A<G)A>2@I.PH@("`@("`@("`@("!I9B`H:7-S970H
M)'!A<F%M6R=I;7!O<G1?;6%P<&EN9R==*2D@>PH@("`@("`@("`@("`@("`@
M)&EM<&]R=%]M87!P:6YG(#T@)'!A<F%M6R=I;7!O<G1?;6%P<&EN9R==.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1I;7!O<G1?9&%T82`]("1T:&ES
M+3YI;7!O<G1&:6QE*"1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG9FEL95]N
M86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1?4T534TE/3ELG:6UP;W)T7V1A=&$G75LG:&5A9&5R)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%5T
M:6PZ.F=E=$9O<FU$871A*"=S97`G*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@571I;#HZ9V5T1F]R;41A=&$H)W%U
M;W1E)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%5T:6PZ.F=E=$9O<FU$871A*"=F:65L9',G*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EM<&]R=%]M
M87!P:6YG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V-H87)S970G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)%]315-324].6R=I;7!O<G1?9&%T82==6R=C<FQF)UTI.PH@("`@("`@("`@
M("`D7U-%4U-)3TY;)VEM<&]R=%]D871A)UU;)V1A=&$G72`]("1I;7!O<G1?
M9&%T83L*("`@("`@("`@("`@=6YS970H)%]315-324].6R=I;7!O<G1?9&%T
M82==6R=M87`G72D["B`@("`@("`@("`@(')E='5R;B!)35!/4E1?34%04$5$
M.PH*("`@("`@("!D969A=6QT.@H@("`@("`@("`@("!R971U<FX@<&%R96YT
M.CIN97AT4W1E<"@D86-T:6]N+"`D<&%R86TI.PH@("`@("`@('T*("`@('T*
M"GT*`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B](;W)D92]-;V)I;&4O4F5N9&5R97(`````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-R`P,C(R
M-#,`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+TAO<F1E+TUO8FEL92]296YD
M97)E<BYP:'``````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,C`V
M(#$P-3$U-#,T,3,W(#`R,S`S,P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@2&]R9&5?36]B:6QE7U)E
M;F1E<F5R.CH@9G)A;65W;W)K(&9O<B!M;V)I;&4@9&5V:6-E(&UA<FMU<`H@
M*B!R96YD97)E<G,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+TUO8FEL92]-
M;V)I;&4O4F5N9&5R97(N<&AP+'8@,2XQ-2XQ,"XX(#(P,#8O,#$O,#$@,C$Z
M,C@Z,C8@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU
M8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E($AO<F1E7TUO
M8FEL90H@*B\*8VQA<W,@2&]R9&5?36]B:6QE7U)E;F1E<F5R(&5X=&5N9',@
M2&]R9&5?36]B:6QE('L*"B`@("!V87(@)%]B<F]W<V5R.PH*("`@(&9U;F-T
M:6]N($AO<F1E7TUO8FEL95]296YD97)E<B@D8G)O=W-E<B`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*&ES7VYU;&PH)&)R;W=S97(I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8G)O=W-E<B`]("9N97<@0G)O=W-E<B@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8G)O=W-E<B`]("1B<F]W
M<V5R.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!I<T)R;W=S97(H
M)&%G96YT*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V)R;W=S97(M
M/FES0G)O=W-E<B@D86=E;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&AA<U%U
M:7)K*"1Q=6ER:RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]B<F]W
M<V5R+3YH87-1=6ER:R@D<75I<FLI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5N9&5R(&%N>2!(;W)D95]-;V)I;&5?96QE;65N="!O8FIE8W0N($QO;VMS
M(&9O<B!T:&4*("`@("`J(&%P<')O<')I871E(')E;F1E<FEN9R!F=6YC=&EO
M;B!I;B!T:&4@<F5N9&5R97([(&EF('1H97)E(&ES;B=T"B`@("`@*B!O;F4L
M('=E(&EG;F]R92!T:&ES(&5L96UE;G0N"B`@("`@*@H@("`@("H@0'!A<F%M
M($AO<F1E7TUO8FEL95]E;&5M96YT("1E;&5M96YT("!4:&4@96QE;65N="!T
M;R!R96YD97(N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;F1E<D5L96UE;G0H
M)B1E;&5M96YT*0H@("`@>PH@("`@("`@("1F=6YC(#T@)U]R96YD97(G("X@
M=6-F:7)S="AS=')?<F5P;&%C92@G:&]R9&5?;6]B:6QE7R<L("<G+"!S=')T
M;VQO=V5R*&=E=%]C;&%S<R@D96QE;65N="DI*2D["B`@("`@("`@:68@*&UE
M=&AO9%]E>&ES=',H)'1H:7,L("1F=6YC*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^)&9U;F,H)&5L96UE;G0I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R0FQO8VLH)B1B;&]C:RD*("`@('L*("`@("`@("!I9B`H
M8V]U;G0H)&)L;V-K+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@(&5C:&\@
M)SQP/B<["B`@("`@("`@("`@(&9O<F5A8V@@*"1B;&]C:RT^7V5L96UE;G1S
M(&%S("1B;&]C:T5L96UE;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YR
M96YD97)%;&5M96YT*"1B;&]C:T5L96UE;G0I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5C:&\@(CPO<#Y<;B(["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)&;W)M*"8D9F]R;2D*("`@('L*("`@("`@("!F
M;W)E86-H("@D9F]R;2T^7V5L96UE;G1S(&%S("1F;W)M16QE;65N="D@>PH@
M("`@("`@("`@("`D=&AI<RT^<F5N9&5R16QE;65N="@D9F]R;45L96UE;G0I
M.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5&%B;&4H
M)B1T86)L92D*("`@('L*("`@("`@("!F;W)E86-H("@D=&%B;&4M/E]R;W=S
M(&%S("1R;W<I('L*("`@("`@("`@("`@)'1H:7,M/E]R96YD97)2;W<H)')O
M=RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)2;W<H
M)B1R;W<I"B`@("!["B`@("`@("`@96-H;R`G/'1R/B<["B`@("`@("`@9F]R
M96%C:"`H)')O=RT^7V-O;'5M;G,@87,@)&-O;'5M;BD@>PH@("`@("`@("`@
M("!E8VAO("<\=&0^)SL*("`@("`@("`@("`@+R\@0V%L;"!C<F5A=&4@9G5N
M8W1I;VX@9F]R(&5A8V@@8V5L;&5L96UE;G0@=&AA="!I<R!A"B`@("`@("`@
M("`@("\O($AO<F1E7TUO8FEL92!O8FIE8W0N"B`@("`@("`@("`@(&EF("@A
M:7-?;G5L;"@D8V]L=6UN*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G)E
M;F1E<D5L96UE;G0H)&-O;'5M;BD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96-H;R`G/"]T9#XG.PH@("`@("`@('T*("`@("`@("!E8VAO("(\+W1R
M/EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R
M;B!A(&-O;F-R971E($AO<F1E7TUO8FEL95]296YD97)E<B!I;G-T86YC90H@
M("`@("H@8F%S960@;VX@)'1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@("`@(%1H92!K:6YD(&]F(&UA<FMU<"`H:'1M;"P@:&1M
M;"P@=VUL*2!W92!W86YT('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@9V5N97)A=&4N"B`@("`@*B!`<&%R86T@0G)O=W-E<B`D8G)O=W-E
M<B`@5&AE($)R;W=S97(@;V)J96-T('1O('5S92X*("`@("`J($!P87)A;2!A
M<G)A>2`D<&%R86US("`@("!!(&AA<V@@8V]N=&%I;FEN9R!A;GD@;W!T:6]N
M<R!F;W(@=&AE(')E;F1E<F5R+@H@("`@("H*("`@("`J($!R971U<FX@2&]R
M9&5?36]B:6QE7U)E;F1E<F5R("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($AO<F1E
M7TUO8FEL95]296YD97)E<B!I;G-T86YC92P@;W(@80H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?17)R;W(@;V)J96-T(&]N
M(&%N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D='EP
M92P@)&)R;W=S97(@/2!N=6QL+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*
M("`@("`@("`D='EP92`](&)A<V5N86UE*"1T>7!E*3L*"B`@("`@("`@:68@
M*$!F:6QE7V5X:7-T<RAD:7)N86UE*%]?1DE,15]?*2`N("<O4F5N9&5R97(O
M)R`N("1T>7!E("X@)RYP:'`G*2D@>PH@("`@("`@("`@("!I;F-L=61E7V]N
M8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+U)E;F1E<F5R+R<@+B`D='EP92`N
M("<N<&AP)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D
M95]O;F-E("=(;W)D92]-;V)I;&4O4F5N9&5R97(O)R`N("1T>7!E("X@)RYP
M:'`G.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S(#T@)TAO<F1E7TUO8FEL
M95]296YD97)E<E\G("X@)'1Y<&4["B`@("`@("`@:68@*&-L87-S7V5X:7-T
M<R@D8VQA<W,I*2!["B`@("`@("`@("`@("1R96YD97)E<B`]("9N97<@)&-L
M87-S*"1B<F]W<V5R+"`D<&%R86US*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5N9&5R97(@/2!014%2.CIR86ES945R<F]R*"=#;&%S<R!D
M969I;FET:6]N(&]F("<@+B`D8VQA<W,@+B`G(&YO="!F;W5N9"XG*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D<F5N9&5R97(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!C;VYC<F5T92!(;W)D
M95]-;V)I;&5?4F5N9&5R97(@:6YS=&%N8V4*("`@("`J(&)A<V5D(&]N("1T
M>7!E+B!)="!W:6QL(&]N;'D@8W)E871E(&$@;F5W(&EN<W1A;F-E(&EF(&YO
M"B`@("`@*B!R96YD97)E<B!W:71H('1H92!S86UE('!A<F%M971E<G,@8W5R
M<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("`@("`@5&AE(&MI;F0@;V8@;6%R:W5P("AH=&UL+"!H9&UL+"!W;6PI
M('=E('=A;G0@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!G
M96YE<F%T92X*("`@("`J($!P87)A;2!"<F]W<V5R("1B<F]W<V5R("!4:&4@
M0G)O=W-E<B!O8FIE8W0@=&\@=7-E+@H@("`@("H@0'!A<F%M(&%R<F%Y("1P
M87)A;7,@("`@($$@:&%S:"!C;VYT86EN:6YG(&%N>2!O<'1I;VYS(&9O<B!T
M:&4@<F5N9&5R97(N"B`@("`@*@H@("`@("H@0')E='5R;B!(;W)D95]-;V)I
M;&5?4F5N9&5R97(@(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@2&]R9&5?36]B:6QE
M7U)E;F1E<F5R(&EN<W1A;F-E+"!O<B!A"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@4$5!4E]%<G)O<B!O8FIE8W0@;VX@86X@97)R
M;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)'1Y<&4L("1B
M<F]W<V5R(#T@;G5L;"P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@<W1A=&EC("1I;G-T86YC97,@/2!A<G)A>2@I.PH*("`@("`@("`D<VEG
M;F%T=7)E(#T@;60U*'-E<FEA;&EZ92AA<G)A>2@D='EP92P@)&)R;W=S97(L
M("1P87)A;7,I*2D["B`@("`@("`@:68@*"%I<W-E="@D:6YS=&%N8V5S6R1S
M:6=N871U<F5=*2D@>PH@("`@("`@("`@("`D:6YS=&%N8V5S6R1S:6=N871U
M<F5=(#T@)DAO<F1E7TUO8FEL95]296YD97)E<CHZ9F%C=&]R>2@D='EP92P@
M)&)R;W=S97(L("1P87)A;7,I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1I;G-T86YC97-;)'-I9VYA='5R95T["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-;V)I
M;&4O4F5N9&5R97(O:'1M;"YP:'``````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`R-C0W,"`Q,#4Q-30S-#$S-R`P,C0P,3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E7TUO
M8FEL95]296YD97)E<CHZ(&]U='!U="!M;V1U;&4@9F]R('-I;7!L92!(5$U,
M(&%N9`H@*B!);6]D92]!=F%N=&=O+W-I;6EL87(@9&5V:6-E<RX*("H*("H@
M)$AO<F1E.B!F<F%M97=O<FLO36]B:6QE+TUO8FEL92]296YD97)E<B]H=&UL
M+G!H<"QV(#$N,C@N,3`N-B`R,#`V+S`Q+S`Q(#(Q.C(X.C(V(&IA;B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\
M8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@
M0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@
M($AO<F1E(#,N,`H@*B!`<&%C:V%G92!(;W)D95]-;V)I;&4*("HO"F-L87-S
M($AO<F1E7TUO8FEL95]296YD97)E<E]H=&UL(&5X=&5N9',@2&]R9&5?36]B
M:6QE7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J(%!R;W!E<FQY(&5N8V]D
M92!C:&%R86-T97)S(&9O<B!O=71P=70@=&\@86X@2%1-3"!B<F]W<V5R+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&EN<'5T("!#:&%R86-T97)S
M('1O(&5N8V]D92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE
M(&5N8V]D960@=&5X="X*("`@("`J+PH@("`@9G5N8W1I;VX@97-C87!E*"1I
M;G!U="D*("`@('L*("`@("`@("!R971U<FX@0&AT;6QS<&5C:6%L8VAA<G,H
M)&EN<'5T+"!%3E1?0T]-4$%4+"!.3%,Z.F=E=$-H87)S970H*2D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S('1H92!P86=E(&EN('1H92!A<'!R
M;W!R:6%T92!M87)K=7`N($1E<&5N9&EN9R!O;B!T:&4*("`@("`J(&-L:65N
M=',@8G)O=W-E<B!T>7!E('!U<F4@2%1-3"P@:&%N9&AE;&1F<FEE;F1L>2!!
M=F%N=$=O($A434PL"B`@("`@*B!I+6UO9&4@8TA434PL(&]R($U-3"!I<R!C
M<F5A=&5D+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&4@)&1E
M8VL@(%1H92!D96-K('1O(')E;F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5N9&5R*"8D9&5C:RD*("`@('L*("`@("`@("!I9B`H)&1E8VLM/E]D96)U
M9RD@>PH@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]P
M;&%I;CL@8VAA<G-E=#TG("X@3DQ3.CIG971#:&%R<V5T*"DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T
M97AT+VAT;6P[(&-H87)S970])R`N($Y,4SHZ9V5T0VAA<G-E="@I*3L*("`@
M("`@("!]"B`@("`@("`@:&5A9&5R*"=687)Y.B!!8V-E<'0M3&%N9W5A9V4G
M*3L*"B`@("`@("`@:68@*"$D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@
M("`@("`@("`@("!E8VAO("(\(41/0U194$4@:'1M;"!054),24,@7"(M+R]7
M,T,O+T141"!(5$U,(#0N,"!4<F%N<VET:6]N86PO+T5.7"(^7&XB.PH@("`@
M("`@('T*"B`@("`@("`@96-H;R`A96UP='DH)$=,3T)!3%-;)VQA;F=U86=E
M)UTI(#\@)SQH=&UL(&QA;F<](B<@+B!S=')T<B@D1TQ/0D%,4ULG;&%N9W5A
M9V4G72P@)U\G+"`G+2<I("X@)R(^)R`Z("<\:'1M;#XG.PH@("`@("`@(&5C
M:&\@)SQH96%D/B<["@H@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=A
M=F%N=&=O)RDI('L*("`@("`@("`@("`@96-H;R`G/&UE=&$@;F%M93TB2&%N
M9&AE;&1&<FEE;F1L>2(@8V]N=&5N=#TB5')U92(^)SL*("`@("`@("!]"@H@
M("`@("`@('!R:6YT9B@B/'1I=&QE/B5S/"]T:71L93Y<;B(L("1T:&ES+3YE
M<V-A<&4H)&1E8VLM/F=E="@G=&ET;&4G*2DI.PH*("`@("`@("!I9B`H)&1E
M8VLM/E]S:6UU;&%T;W(I('L*("`@("`@("`@("`@+R\@57-E('-I;75L871O
M<B`H;6]B:6QE('1H96UE*2!S='EL97-H965T+@H@("`@("`@("`@("!E8VAO
M($AO<F1E.CIS='EL97-H965T3&EN:R@G:&]R9&4G+"`G;6]B:6QE)RD["B`@
M("`@("`@?0H*("`@("`@("!E8VAO("<\+VAE860^/&)O9'D^)SL*"B`@("`@
M("`@:68@*"1D96-K+3Y?<VEM=6QA=&]R*2!["B`@("`@("`@("`@(&5C:&\@
M(CQC96YT97(^/&)R("\^7&XB.PH@("`@("`@("`@("`O+R!#<F5A=&4@9&5F
M875L="!D979I8V4@<VEM=6QA=&]R('1A8FQE(&QA>6]U="!W:71H"B`@("`@
M("`@("`@("\O(&-E;G1R86P@0U-3(&QA>6]U="X*("`@("`@("`@("`@96-H
M;R`B/'1A8FQE(&)O<F1E<CU<(C!<(B!C96QL<&%D9&EN9SU<(C!<(B!C96QL
M<W!A8VEN9SU<(C!<(CY<;B(["B`@("`@("`@("`@(&5C:&\@(CQT<CX\=&0@
M8V]L<W!A;CU<(C-<(B!C;&%S<SU<(G1O<%PB/B9N8G-P.SPO=&0^/"]T<CY<
M;B(["B`@("`@("`@("`@(&5C:&\@(CQT<CX\=&0@=F%L:6=N/5PB=&]P7"(@
M8VQA<W,]7")L969T7"(^)FYB<W`[/"]T9#Y<;B(["B`@("`@("`@("`@(&5C
M:&\@(CQT9"!V86QI9VX]7")T;W!<(B!C;&%S<SU<(F1I<W!L87E<(CY<;B([
M"B`@("`@("`@?0H*("`@("`@("`D9&EV<W1Y;&4@/2`G)SL*("`@("`@("!I
M9B`H)'1H:7,M/FAA<U%U:7)K*"=S8W)O;&Q?=&1S)RD@)B8@)&1E8VLM/E]S
M:6UU;&%T;W(I('L*("`@("`@("`@("`@+R\@36%K92!C;VYT96YT(&]F('1A
M8FQE(&5L96UE;G0@<V-R;VQL86)L92`H2&]R9&5?36]B:6QE"B`@("`@("`@
M("`@("\O('-I;75L871O<BDN"B`@("`@("`@("`@("1D:79S='EL92`]("<@
M8VQA<W,](G-I;61E=B(G.PH@("`@("`@('T*("`@("`@("!E8VAO("<\9&EV
M)R`N("1D:79S='EL92`N("<^)SL*"B`@("`@("`@:68@*"@D8VYT(#T@8V]U
M;G0H)&1E8VLM/E]C87)D<RDI("$]/2`P*2!["B`@("`@("`@("`@("1I(#T@
M,#L*("`@("`@("`@("`@9F]R96%C:"`H)&1E8VLM/E]C87)D<R!A<R`D8V%R
M9"D@>PH@("`@("`@("`@("`@("`@:68@*"1I("$](#`I('L*("`@("`@("`@
M("`@("`@("`@("!E8VAO("<\:'(@+SXG.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R96YD97)#87)D*"1C87)D*3L*("`@
M("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!F;W)E86-H("@D9&5C:RT^7V5L96UE;G1S(&%S
M("1P86=E7V5L96UE;G0I('L*("`@("`@("`@("`@("`@("1T:&ES+3YR96YD
M97)%;&5M96YT*"1P86=E7V5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!E8VAO("<\+V1I=CXG.PH*("`@("`@("!I9B`H)&1E
M8VLM/E]S:6UU;&%T;W(I('L*("`@("`@("`@("`@+R\@1&ES<&QA>2!L;W=E
M<B!P87)T(&]F($AO<F1E7TUO8FEL92!D969A=6QT(&1E=FEC90H@("`@("`@
M("`@("`O+R!S:6UU;&%T;W(N"B`@("`@("`@("`@(&5C:&\@)SPO=&0^/'1D
M('9A;&EG;CTB=&]P(B!C;&%S<STB<FEG:'0B/B9N8G-P.SPO=&0^/"]T<CX\
M='(^/'1D(&-O;'-P86X](C,B(&-L87-S/2)B;W1T;VTB/B9N8G-P.SPO=&0^
M/"]T<CX\+W1A8FQE/CPO8V5N=&5R/B<["B`@("`@("`@?0H*("`@("`@("!E
M8VAO("<\+V)O9'D^/"]H=&UL/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<D-A<F0H)B1C87)D*0H@("`@>PH@("`@("`@("1N86UE(#T@)&-A<F0M
M/F=E="@G;F%M92<I(#\@)R!N86UE/2(G("X@)'1H:7,M/F5S8V%P92@D8V%R
M9"T^9V5T*"=N86UE)RDI("X@)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\
M825S/B5S/"]A/B<L("1N86UE+"`D8V%R9"T^9V5T*"=T:71L92<I*3L*"B`@
M("`@("`@:68@*&-O=6YT*"1C87)D+3Y?<V]F=&ME>7,I*2!["B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C87)D+3Y?<V]F=&ME>7,@87,@)&ME>2D@>PH@("`@
M("`@("`@("`@("`@96-H;R`G('P@/&$@:')E9CTB)R`N("1K97E;)W5R;"==
M("X@)R(^)R`N("`D=&AI<RT^97-C87!E*"1K97E;)VQA8F5L)UTI("X@)SPO
M83XG.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!296YD
M97(@86QL('1A9W,N"B`@("`@("`@9F]R96%C:"`H)&-A<F0M/E]E;&5M96YT
M<R!A<R`D<&%G95]E;&5M96YT*2!["B`@("`@("`@("`@("1T:&ES+3YR96YD
M97)%;&5M96YT*"1P86=E7V5L96UE;G0I.PH@("`@("`@('T*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R3&EN:R@F)&QI;FLI"B`@("!["B`@("`@("`@
M:68@*"1L:6YK+3YG970H)W1I=&QE)RD@)B8*("`@("`@("`@("`@(21T:&ES
M+3YI<T)R;W=S97(H)V%V86YT9V\G*2`F)@H@("`@("`@("`@("`A)'1H:7,M
M/FES0G)O=W-E<B@G:6UO9&4G*2`F)@H@("`@("`@("`@("`A)'1H:7,M/FES
M0G)O=W-E<B@G;6UL)RDI('L*("`@("`@("`@("`@)'1I=&QE7V]P=&EO;B`]
M('-P<FEN=&8H)R!O;FUO=7-E;W9E<CTB<V5L9BYS=&%T=7,]7"<E<UPG.W)E
M='5R;B!T<G5E.R(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^97-C87!E*"1L:6YK+3YG970H)W1I=&QE)RDI*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&ET;&5?;W!T:6]N(#T@)R<[
M"B`@("`@("`@?0H*("`@("`@("`D86-C97-S:V5Y7V]P=&EO;B`]("<G.PH@
M("`@("`@(&EF("@D;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D@>PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/FES0G)O=W-E<B@G:6UO9&4G*2D@>PH@("`@("`@
M("`@("`@("`@)&%C8V5S<VME>5]O<'1I;VX@/2!S<')I;G1F*"<@86-C97-S
M:V5Y/2(E9"(G+"`D;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D["B`@("`@("`@
M("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@
M("`@("`@("`@("`@)&%C8V5S<VME>5]O<'1I;VX@/2!S<')I;G1F*"<@9&ER
M96-T:V5Y/2(E9"(G+"`D;&EN:RT^9V5T*"=A8V-E<W-K97DG*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@('!R:6YT9B@G/&$@:')E9CTB
M)7,B)7,E<SXE<SPO83XG+`H@("`@("`@("`@("`@("!S=')?<F5P;&%C92@G
M)F%M<#MA;7`[)RP@)R9A;7`[)RP@)'1H:7,M/F5S8V%P92@D;&EN:RT^9V5T
M*"=U<FPG*2DI+`H@("`@("`@("`@("`@("`D=&ET;&5?;W!T:6]N+"`D86-C
M97-S:V5Y7V]P=&EO;BP*("`@("`@("`@("`@("`@)'1H:7,M/F5S8V%P92@D
M;&EN:RT^9V5T*"=L86)E;"<I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E
M;F1E<DQI;FMS970H)B1L:6YK<V5T*0H@("`@>PH@("`@("`@(&EF("AC;W5N
M="@D;&EN:W-E="T^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!E8VAO("<\
M;VP^)SL*("`@("`@("`@("`@9F]R96%C:"`H)&QI;FMS970M/E]E;&5M96YT
M<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("!E8VAO("<\;&D^)SL*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R3&EN:R@D=F%L*3L*("`@("`@
M("`@("`@("`@(&5C:&\@)SPO;&D^)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E8VAO("<\+V]L/B<["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T
M:6]N(%]R96YD97)497AT*"8D96QE;65N="D*("`@('L*("`@("`@("!F;W)E
M86-H("@D96QE;65N="T^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@
M("`@("`@("`@("!E8VAO("<\)R`N("1A='1R:6)U=&4@+B`G/B<["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)&5L96UE;G0M/F=E="@G;&EN96)R96%K<R<I
M*2!["B`@("`@("`@("`@(&5C:&\@;FPR8G(H)'1H:7,M/F5S8V%P92@D96QE
M;65N="T^9V5T*"=T97AT)RDI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!E8VAO("1T:&ES+3YE<V-A<&4H)&5L96UE;G0M/F=E="@G=&5X="<I
M*3L*("`@("`@("!]"@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?<F5V
M97)S92@D96QE;65N="T^7V%T=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@
M*"1A='1R:6)U=&5S(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@96-H
M;R`G/"\G("X@)&%T=')I8G5T92`N("<^)SL*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@7W)E;F1E<DEM86=E*"8D:6UA9V4I"B`@("!["B`@("`@
M("`@)&%T=')I8G5T97,@/2`G)SL*("`@("`@("!F;W)E86-H("@D:6UA9V4M
M/E]A='1R:6)U=&5S(&%S("1A='1R:6)U=&4@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("1A='1R:6)U=&5S("X]('-P<FEN=&8H)R`E<STB)7,B)RP@)&%T
M=')I8G5T92P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@<')I;G1F*"<\
M:6UG('-R8STB)7,N<&YG(B5S("\^)RP@)&EM86=E+3Y?<W)C+"`D871T<FEB
M=71E<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D9O<FTH)B1F;W)M
M*0H@("`@>PH@("`@("`@('!R:6YT9B@G/&9O<FT@86-T:6]N/2(E<R(@;65T
M:&]D/2(E<R(^)RP@)&9O<FTM/F=E="@G=7)L)RDL("1F;W)M+3YG970H)VUE
M=&AO9"<I*3L*("`@("`@("!P87)E;G0Z.E]R96YD97)&;W)M*"1F;W)M*3L*
M("`@("`@("!E8VAO("<\+V9O<FT^)SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M<F5N9&5R26YP=70H)B1I;G!U="D*("`@('L*("`@("`@("`D='EP92`]("=T
M>7!E/2(G("X@)&EN<'5T+3YG970H)W1Y<&4G*2`N("<B)SL*("`@("`@("`D
M<VEZ92`]("1I;G!U="T^9V5T*"=S:7IE)RD@/R!S<')I;G1F*"=S:7IE/2(E
M9"(G+"`D:6YP=70M/F=E="@G<VEZ92<I*2`Z("<G.PH@("`@("`@("1M87AL
M96YG=&@@/2`D:6YP=70M/F=E="@G;6%X;&5N9W1H)RD@/R!S<')I;G1F*"=M
M87AL96YG=&@](B5D(B<L("1I;G!U="T^9V5T*"=M87AL96YG=&@G*2D@.B`G
M)SL*"B`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)VEM;V1E)RDI('L*
M("`@("`@("`@("`@)&UO9&4@/2!S<')I;G1F*"<@:7-T>6QE/2(E9"(G+"`D
M:6YP=70M/F=E="@G;6]D92<I*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M
M/FES0G)O=W-E<B@G;6UL)RDI('L*("`@("`@("`@("`@)&UO9&4@/2`D=&AI
M<RT^7V=E=$UO9&4H)&EN<'5T+3YG970H)VUO9&4G*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UO9&4@/2`G)SL*("`@("`@("!]"@H@("`@
M("`@("\O($-R96%T92!(5$U,(&EN<'5T+@H@("`@("`@('!R:6YT9B@G)7,@
M/&EN<'5T("5S(&YA;64](B5S(B!V86QU93TB)7,B)7,E<R5S+SXG+`H@("`@
M("`@("`@("`@("`D=&AI<RT^97-C87!E*"1I;G!U="T^9V5T*"=L86)E;"<I
M*2P@)'1Y<&4L"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)&EN<'5T
M+3YG970H)VYA;64G*2DL("1T:&ES+3YE<V-A<&4H)&EN<'5T+3YG970H)W9A
M;'5E)RDI+"`D<VEZ92P@)&UA>&QE;F=T:"P@)&UO9&4I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]R96YD97)497AT87)E82@F)'1E>'1A<F5A*0H@("`@>PH@
M("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I*2!["B`@("`@
M("`@("`@("1M;V1E(#T@<W!R:6YT9B@G(&ES='EL93TB)60B)RP@)'1H:7,M
M/FUO9&4I.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^:7-"<F]W<V5R*"=M
M;6PG*2D@>PH@("`@("`@("`@("`D;6]D92`]("1T:&ES+3Y?9V5T36]D92@D
M=&AI<RT^;6]D92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO
M9&4@/2`G)SL*("`@("`@("!]"@H@("`@("`@("1W<F%P(#T@)R<["B`@("`@
M("`@:68@*"$D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I("8F("$D=&AI<RT^
M:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@("`D=W)A<"`]("<@=W)A
M<#TB=FER='5A;"(G.PH@("`@("`@('T*"B`@("`@("`@<')I;G1F*"<E<SQB
M<B`O/CQT97AT87)E82!N86UE/2(E<R(@<F]W<STB)7,B(&-O;',](B5S(B5S
M)7,^)7,\+W1E>'1A<F5A/B<L"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A
M<&4H)'1E>'1A<F5A+3YG970H)VQA8F5L)RDI+"`D=&5X=&%R96$M/F=E="@G
M;F%M92<I+"`D=&5X=&%R96$M/F=E="@G<F]W<R<I+`H@("`@("`@("`@("`@
M("`D=&5X=&%R96$M/F=E="@G8V]L<R<I+"`D;6]D92P@)'=R87`L("1T97AT
M87)E82T^9V5T*"=V86QU92<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N
M9&5R4V5L96-T*"8D<V5L96-T*0H@("`@>PH@("`@("`@(&5C:&\@)SQS96QE
M8W0@;F%M93TB)R`N("1S96QE8W0M/F=E="@G;F%M92<I("X@)R(@<VEZ93TB
M,2(^)SL*("`@("`@("!F;W)E86-H("@D<V5L96-T+3Y?;W!T:6]N<R!A<R`D
M=F%L*2!["B`@("`@("`@("`@(&EF("@D=F%L6R=V86QU92==(#T]("1S96QE
M8W0M/E]V86QU92D@>PH@("`@("`@("`@("`@("`@)'-E;"`]("<@<V5L96-T
M960](G-E;&5C=&5D(B<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<V5L(#T@)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96-H;R`G/&]P=&EO;B<@+B`D<V5L("X@)R!V86QU93TB)R`N("1V86Q;)W9A
M;'5E)UT@+B`G(CXG("X@)'1H:7,M/F5S8V%P92@D=F%L6R=L86)E;"==*2`N
M("<\+V]P=&EO;CXG.PH@("`@("`@('T*("`@("`@("!E8VAO("<\+W-E;&5C
M=#XG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)2861I;R@F)')A9&EO
M*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1R861I;RT^7V)U='1O;G,@87,@
M)'9A;"D@>PH@("`@("`@("`@("`D<V5L(#T@*"1V86Q;)W9A;'5E)UT@/3T@
M)')A9&EO+3Y?=F%L=64I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@.B`G)SL*
M("`@("`@("`@("`@<')I;G1F*"<\:6YP=70@='EP93TB<F%D:6\B(&YA;64]
M(B5S(B5S('9A;'5E/2(E<R(@+SX@)7,\8G(@+SXG+`H@("`@("`@("`@("`@
M("`@("`@)')A9&EO+3YG970H)VYA;64G*2P@)'-E;"P@)'9A;%LG=F%L=64G
M72P*("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'9A;%LG;&%B
M96PG72DI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R
M0VAE8VMB;W@H)B1C:&5C:V)O>"D*("`@('L*("`@("`@("`D<W1A=&4@/2`D
M8VAE8VMB;W@M/FES0VAE8VME9"@I(#\@)R!C:&5C:V5D/2)C:&5C:V5D(B<@
M.B`G)SL*("`@("`@("!P<FEN=&8H)SQI;G!U="!T>7!E/2)C:&5C:V)O>"(@
M;F%M93TB)7,B)7,@=F%L=64](B5S(B`O/B`E<SQB<B`O/B<L"B`@("`@("`@
M("`@("`@("1C:&5C:V)O>"T^9V5T*"=N86UE)RDL("1S=&%T92P@)&-H96-K
M8F]X+3YG970H)W9A;'5E)RDL"B`@("`@("`@("`@("`@("1T:&ES+3YE<V-A
M<&4H)&-H96-K8F]X+3YG970H)VQA8F5L)RDI*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R4W5B;6ET*"8D<W5B;6ET*0H@("`@>PH@("`@("`@("1N
M86UE(#T@(65M<'1Y*"1S=6)M:70M/E]N86UE*2`_("<@;F%M93TB)R`N("1S
M=6)M:70M/E]N86UE("X@)R(G(#H@)R<["B`@("`@("`@<')I;G1F*"<\:6YP
M=70@='EP93TB<W5B;6ET(B5S('9A;'5E/2(E<R(@+SX\8G(@+SXG+`H@("`@
M("`@("`@("`@("`D;F%M92P@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3Y?;&%B
M96PI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R2&ED9&5N*"8D:&ED
M9&5N*0H@("`@>PH@("`@("`@('!R:6YT9B@G/&EN<'5T('1Y<&4](FAI9&1E
M;B(@;F%M93TB)7,B('9A;'5E/2(E<R(@+SXG+`H@("`@("`@("`@("`@("`D
M:&ED9&5N+3YG970H)VYA;64G*2P@)&AI9&1E;BT^9V5T*"=V86QU92<I*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R5&%B;&4H)B1T86)L92D*("`@
M('L*("`@("`@("`D8F]R9&5R(#T@)'1A8FQE+3YG970H)V)O<F1E<B<I.PH@
M("`@("`@("1P861D:6YG(#T@)'1A8FQE+3YG970H)W!A9&1I;F<G*3L*("`@
M("`@("`D<W!A8VEN9R`]("1T86)L92T^9V5T*"=S<&%C:6YG)RD["@H@("`@
M("`@(&5C:&\@)SQT86)L92<["B`@("`@("`@:68@*"%I<U]N=6QL*"1B;W)D
M97(I*2!["B`@("`@("`@("`@(&5C:&\@)R!B;W)D97(](B<@+B`D8F]R9&5R
M("X@)R(G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH)'!A9&1I
M;F<I*2!["B`@("`@("`@("`@(&5C:&\@)R!C96QL<&%D9&EN9STB)R`N("1P
M861D:6YG("X@)R(G.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES7VYU;&PH
M)'-P86-I;F<I*2!["B`@("`@("`@("`@(&5C:&\@)R!C96QL<W!A8VEN9STB
M)R`N("1S<&%C:6YG("X@)R(G.PH@("`@("`@('T*("`@("`@("!E8VAO("<^
M)SL*"B`@("`@("`@<&%R96YT.CI?<F5N9&5R5&%B;&4H)'1A8FQE*3L*"B`@
M("`@("`@+R\@5&5R;6EN871E('1A8FQE+@H@("`@("`@(&EF("@D=&AI<RT^
M:7-"<F]W<V5R*"=M;6PG*2D@>PH@("`@("`@("`@("!E8VAO("<\+W1A8FQE
M/CQB<B`O/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@34U,
M(&AA<R!P<F]B;&5M<R!W:71H('1H92!C;&5A<B!A='1R:6)U=&4N"B`@("`@
M("`@("`@(&5C:&\@)SPO=&%B;&4^/&)R(&-L96%R/2)A;&PB/B<["B`@("`@
M("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]R96YD97)0:&]N92@F)'!H;VYE
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:7-"<F]W<V5R*"=I;6]D92<I
M*2!["B`@("`@("`@("`@("\O($-R96%T92!P:&]N971O.B!L:6YK(&9O<B!I
M+4UO9&4N"B`@("`@("`@("`@('!R:6YT9B@G/'`^/&$@:')E9CTB<&AO;F5T
M;SHE<R(^)7,\+V$^/"]P/B<L"B`@("`@("`@("`@("`@("`@("`D<&AO;F4M
M/F=E="@G;G5M8F5R)RDL("1P:&]N92T^9V5T*"=L86)E;"<I*3L*("`@("`@
M("!](&5L<V5I9B`H)'1H:7,M/FES0G)O=W-E<B@G;6UL)RDI('L*("`@("`@
M("`@("`@+R\@0W)E871E('1E;#H@;&EN:R!F;W(@34U,+@H@("`@("`@("`@
M("!P<FEN=&8H)SQP/CQA(&AR968](G1E;#HE<R(^)7,\+V$^/"]P/B<L"B`@
M("`@("`@("`@("`@("`@("`D<&AO;F4M/F=E="@G;G5M8F5R)RDL("1P:&]N
M92T^9V5T*"=L86)E;"<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`O+R!$:7-P;&%Y('!H;VYE(&YU;6)E<B!A<R!P;&%I;B!T97AT+@H@("`@
M("`@("`@("!P<FEN=&8H)SQP/CQB:6<^)7,\+V)I9SX\+W`^)RP@)'!H;VYE
M+3YG970H)VQA8F5L)RDI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!?<F5N9&5R4G5L92@F)')U;&4I"B`@("!["B`@("`@("`@)'=I9'1H(#T@
M)')U;&4M/F=E="@G=VED=&@G*3L*("`@("`@("`D<VEZ92`]("1R=6QE+3YG
M970H)W-I>F4G*3L*"B`@("`@("`@96-H;R`G/&AR)R`N("@D=VED=&@@/R`G
M('=I9'1H/2(G("X@)'=I9'1H("X@)R(G(#H@)R<I("X@*"1S:7IE(#\@)R!S
M:7IE/2(G("X@)'-I>F4@+B`G(B<@.B`G)RD@+B`B("\^7&XB.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]G971-;V1E*"1M;V1E*0H@("`@>PH@("`@("`@('-W
M:71C:"`H)&UO9&4I('L*("`@("`@("!C87-E("=K871A:V%N82<Z"B`@("`@
M("`@("`@(')E='5R;B`G(&UO9&4](FMA=&%K86YA(B<["@H@("`@("`@(&-A
M<V4@)VAI<F%G86YA)SH*("`@("`@("`@("`@<F5T=7)N("<@;6]D93TB:&ER
M86=A;F$B)SL*"B`@("`@("`@8V%S92`G;G5M97)I8R<Z"B`@("`@("`@("`@
M(')E='5R;B`G(&UO9&4](FYU;65R:6,B)SL*"B`@("`@("`@8V%S92`G86QP
M:&$G.@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(')E='5R;B`G(&UO
M9&4](F%L<&AA8F5T(B<["B`@("`@("`@?0H@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B](;W)D92]-
M;V)I;&4O4F5N9&5R97(O=VUL+G!H<```````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R-C4R,R`Q,#4Q-30S-#$S-R`P,C,V-#(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($AO<F1E
M7TUO8FEL95]296YD97)E<CHZ(&]U='!U="!M;V1U;&4@9F]R(%=-3"`H5VER
M96QE<W,@36%R:W5P($QA;F=U86=E*2X*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO36]B:6QE+TUO8FEL92]296YD97)E<B]W;6PN<&AP+'8@,2XS,BXQ,"XW
M(#(P,#8O,#(O,C0@,C`Z-#`Z,S@@8VAU8VL@17AP("0*("H*("H@0V]P>7)I
M9VAT(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C
M:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@2&]R9&5?36]B:6QE"B`J+PIC;&%S<R!(;W)D95]-;V)I;&5?
M4F5N9&5R97)?=VUL(&5X=&5N9',@2&]R9&5?36]B:6QE7U)E;F1E<F5R('L*
M"B`@("`O*BH*("`@("`J(%!R;W!E<FQY(&5N8V]D92!C:&%R86-T97)S(&9O
M<B!O=71P=70@=&\@82!734P@9&5V:6-E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&EN<'5T("!#:&%R86-T97)S('1O(&5N8V]D92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&5N8V]D960@=&5X="X*("`@
M("`J+PH@("`@9G5N8W1I;VX@97-C87!E*"1I;G!U="D*("`@('L*("`@("`@
M("`O+R!%;F-O9&4@96YT:71I97,N"B`@("`@("`@)&]U='!U="`]($!H=&UL
M<W!E8VEA;&-H87)S*"1I;G!U="P@14Y47T-/35!!5"P@3DQ3.CIG971#:&%R
M<V5T*"DI.PH*("`@("`@("`O+R!%<V-A<&4@)"!C:&%R86-T97(@:6X@5TU,
M+@H@("`@("`@("1O=71P=70@/2!S=')?<F5P;&%C92@G)"<L("<D)"<L("1O
M=71P=70I.PH*("`@("`@("`O+R!'96YE<F%T92!55$8M."X*("`@("`@("`D
M;W5T<'5T(#T@4W1R:6YG.CIC;VYV97)T0VAA<G-E="@D;W5T<'5T+"!.3%,Z
M.F=E=$-H87)S970H*2P@)W5T9BTX)RD["@H@("`@("`@(')E='5R;B`D;W5T
M<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T:&4@<&%G92!I
M;B!734PL(&%L;&]W:6YG(&9O<B!D:69F97)E;G0@5TU,(&)R;W=S97(@<75I
M<FMS+@H@("`@("H*("`@("`J($!P87)A;2!(;W)D95]-;V)I;&4@)&1E8VL@
M(%1H92!D96-K('1O(')E;F1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M9&5R*"8D9&5C:RD*("`@('L*("`@("`@("!I9B`H)&1E8VLM/E]D96)U9RD@
M>PH@("`@("`@("`@("!H96%D97(H)T-O;G1E;G0M5'EP93H@=&5X="]P;&%I
M;CL@8VAA<G-E=#UU=&8M."<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&AE861E<B@G0V]N=&5N="U4>7!E.B!T97AT+W9N9"YW87`N=VUL.R!C
M:&%R<V5T/75T9BTX)RD["B`@("`@("`@?0H*("`@("`@("!E8VAO("(\/WAM
M;"!V97)S:6]N/5PB,2XP7"(_/EQN(CL*("`@("`@("!I9B`H)'1H:7,M/FAA
M<U%U:7)K*"=O=U]G=6E?,2XS)RDI('L*("`@("`@("`@("`@96-H;R`G/"%$
M3T-465!%('=M;"!054),24,@(BTO+U!(3TY%+D-/32\O1%1$(%=-3"`Q+C,O
M+T5.(B`B:'1T<#HO+W=W=RYO<&5N=V%V92YC;VTO9'1D+W=M;#$S+F1T9"(^
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<\(41/0U19
M4$4@=VUL(%!50DQ)0R`B+2\O5T%01D]254TO+T141"!734P@,2XQ+R]%3B(@
M(FAT='`Z+R]W=W<N=V%P9F]R=6TN;W)G+T141"]W;6Q?,2XQ+GAM;"(^)SL*
M("`@("`@("!]"B`@("`@("`@96-H;R`G/'=M;#XG.PH*("`@("`@("!I9B`H
M8V]U;G0H)&1E8VLM/E]C87)D<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)&1E8VLM/E]C87)D<R!A<R`D8V%R9"D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R96YD97)#87)D*"1C87)D*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:71L92`]("1D96-K+3YG970H)W1I
M=&QE)RD@/R`G('1I=&QE/2(G("X@)'1H:7,M/F5S8V%P92@D9&5C:RT^9V5T
M*"=T:71L92<I*2`N("<B)R`Z("<G.PH@("`@("`@("`@("!P<FEN=&8H)SQC
M87)D)7,^)RP@)'1I=&QE*3L*"B`@("`@("`@("`@("\O(%)E;F1E<B!A;&P@
M=&%G<RX*("`@("`@("`@("`@9F]R96%C:"`H)&1E8VLM/E]E;&5M96YT<R!A
M<R`D<&%G95]E;&5M96YT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5N
M9&5R16QE;65N="@D<&%G95]E;&5M96YT*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@96-H;R`G/"]C87)D/B<["B`@("`@("`@?0H*("`@("`@("`O
M+R!%;F0@=&AE(%=-3"!P86=E+@H@("`@("`@(&5C:&\@)SPO=VUL/B<["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D-A<F0H)B1C87)D*0H@("`@>PH@
M("`@("`@("1N86UE(#T@)&-A<F0M/F=E="@G;F%M92<I(#\@)R!I9#TB)R`N
M("1T:&ES+3YE<V-A<&4H)&-A<F0M/F=E="@G;F%M92<I*2`N("<B)R`Z("<G
M.PH@("`@("`@("1T:71L92`]("1C87)D+3YG970H)W1I=&QE)RD@/R`G('1I
M=&QE/2(G("X@)'1H:7,M/F5S8V%P92@D8V%R9"T^9V5T*"=T:71L92<I*2`N
M("<B)R`Z("<G.PH@("`@("`@('!R:6YT9B@G/&-A<F0E<R5S/B<L("1N86UE
M+"`D=&ET;&4I.PH*("`@("`@("`O+R!);FET:6%L:7IE(%=-3"!V87)I86)L
M97,@=VET:"!T:&5I<B!D969A=6QT('9A;'5E<RX*("`@("`@("!I9B`H(6ES
M7VYU;&PH)&-A<F0M/E]F;W)M*2D@>PH@("`@("`@("`@("!E8VAO("<\;VYE
M=F5N="!T>7!E/2)O;F5N=&5R9F]R=V%R9"(^/')E9G)E<V@^)SL*("`@("`@
M("`@("`@)&1E9F%U;'1S(#T@)&-A<F0M/E]F;W)M+3YG971$969A=6QT<R@I
M.PH@("`@("`@("`@("!F;W)E86-H("@D9&5F875L=',@87,@)&0I('L*("`@
M("`@("`@("`@("`@('!R:6YT9B@G/'-E='9A<B!N86UE/2)?)7,B('9A;'5E
M/2(E<R(O/B<L("1D6R=N86UE)UTL("1T:&ES+3YE<V-A<&4H)&1;)W9A;'5E
M)UTI*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E8VAO("<\+W)E9G)E
M<V@^/"]O;F5V96YT/B<["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H
M)&-A<F0M/E]S;V9T:V5Y<RDI('L*("`@("`@("`@("`@:68@*&-O=6YT*"1C
M87)D+3Y?<V]F=&ME>7,I(#T](#$I('L*("`@("`@("`@("`@("`@("\O($EF
M('1H97)E(&ES(&]N;'D@;VYE('-O9G1K97DL(&UA:V4@:70@;V8@='EP90H@
M("`@("`@("`@("`@("`@+R\@)V]P=&EO;G,G('-O('1H870@:70@86QW87ES
M('-H;W=S('5P(&]N('1H92!R:6=H="P*("`@("`@("`@("`@("`@("\O(&EN
M<W1E860@;V8@:&%V:6YG('1O('-H87)E('1H92!L969T('-O9G1K97D@=VET
M:`H@("`@("`@("`@("`@("`@+R\@86-T:79E(&QI;FMS+"!M86MI;F<@:70@
M;75C:"!H87)D97(@=&\@9V5T('1O+@H@("`@("`@("`@("`@("`@)'1Y<&4@
M/2`G;W!T:6]N<R<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D='EP92`]("=A8V-E<'0G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C87)D+3Y?<V]F=&ME>7,@87,@)&ME>2D@>PH@("`@
M("`@("`@("`@("`@96-H;R`G/&1O('1Y<&4](B<@+B`D='EP92`N("<B(&QA
M8F5L/2(G("X@)'1H:7,M/F5S8V%P92@D:V5Y6R=L86)E;"==*2`N("<B/CQG
M;R!H<F5F/2(G("X@)&ME>5LG=7)L)UT@+B`G(B\^/"]D;SXG.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!296YD97(@86QL('1A9W,N
M"B`@("`@("`@9F]R96%C:"`H)&-A<F0M/E]E;&5M96YT<R!A<R`D<&%G95]E
M;&5M96YT*2!["B`@("`@("`@("`@("1T:&ES+3YR96YD97)%;&5M96YT*"1P
M86=E7V5L96UE;G0I.PH@("`@("`@('T*"B`@("`@("`@96-H;R`G/"]C87)D
M/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DQI;FLH)B1L:6YK*0H@
M("`@>PH@("`@("`@("1T:71L95]O<'1I;VX@/2`D;&EN:RT^9V5T*"=T:71L
M92<I(#\@<W!R:6YT9B@G('1I=&QE/2(E<R(G+"`D=&AI<RT^97-C87!E*"1L
M:6YK+3YG970H)W1I=&QE)RDI*2`Z("<G.PH*("`@("`@("!P<FEN=&8H)SQA
M)7,@:')E9CTB)7,B/B5S/"]A/B<L"B`@("`@("`@("`@("`@("1T:71L95]O
M<'1I;VXL('-T<E]R97!L86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG+"`D=&AI
M<RT^97-C87!E*"1L:6YK+3YG970H)W5R;"<I*2DL"B`@("`@("`@("`@("`@
M("1T:&ES+3YE<V-A<&4H)&QI;FLM/F=E="@G;&%B96PG*2DI.PH@("`@?0H*
M("`@(&9U;F-T:6]N(%]R96YD97),:6YK<V5T*"8D;&EN:W-E="D*("`@('L*
M("`@("`@("!I9B`H8V]U;G0H)&QI;FMS970M/E]E;&5M96YT<RDI('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YI<T)R;W=S97(H)W5P)RDI('L*("`@("`@
M("`@("`@("`@(&5C:&\@)SQS96QE8W0^)SL*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1L:6YK<V5T+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:71L92`]("1V86PM/F=E="@G=&ET;&4G*2`_("<@
M=&ET;&4](B<@+B`D=&AI<RT^97-C87!E*"1V86PM/F=E="@G=&ET;&4G*2D@
M+B`G(B<@.B`G)SL*("`@("`@("`@("`@("`@("`@("!P<FEN=&8H)SQO<'1I
M;VX@;VYP:6-K/2(E<R(E<SXE<SPO;W!T:6]N/B<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<E]R97!L86-E*"<F86UP.V%M<#LG+"`G)F%M<#LG
M+"`D=&AI<RT^97-C87!E*"1V86PM/F=E="@G=7)L)RDI*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1I=&QE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^97-C87!E*"1V86PM/F=E="@G;&%B96PG*2DI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96-H;R`G/"]S96QE
M8W0^)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1L:6YK<V5T+3Y?96QE;65N=',@87,@)'9A;"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5N9&5R3&EN:R@D=F%L*3L*("`@("`@
M("`@("`@("`@("`@("!E8VAO("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(%]R96YD97)497AT*"8D96QE;65N="D*("`@('L*("`@("`@("!F;W)E86-H
M("@D96QE;65N="T^7V%T=')I8G5T97,@87,@)&%T=')I8G5T92D@>PH@("`@
M("`@("`@("!E8VAO("<\)R`N("1A='1R:6)U=&4@+B`G/B<["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&5L96UE;G0M/F=E="@G;&EN96)R96%K<R<I*2![
M"B`@("`@("`@("`@(&5C:&\@;FPR8G(H)'1H:7,M/F5S8V%P92@D96QE;65N
M="T^9V5T*"=T97AT)RDI*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!E8VAO("1T:&ES+3YE<V-A<&4H)&5L96UE;G0M/F=E="@G=&5X="<I*3L*
M("`@("`@("!]"@H@("`@("`@("1A='1R:6)U=&5S(#T@87)R87E?<F5V97)S
M92@D96QE;65N="T^7V%T=')I8G5T97,I.PH@("`@("`@(&9O<F5A8V@@*"1A
M='1R:6)U=&5S(&%S("1A='1R:6)U=&4I('L*("`@("`@("`@("`@96-H;R`G
M/"\G("X@)&%T=')I8G5T92`N("<^)SL*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<DEM86=E*"8D:6UA9V4I"B`@("!["B`@("`@("`@
M)&%T=')I8G5T97,@/2`G)SL*("`@("`@("!F;W)E86-H("@D:6UA9V4M/E]A
M='1R:6)U=&5S(&%S("1A='1R:6)U=&4@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("1A='1R:6)U=&5S("X]('-P<FEN=&8H)R`E<STB)7,B)RP@)&%T=')I
M8G5T92P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@<')I;G1F*"<\:6UG
M('-R8STB)7,N=V)M<"(E<R\^)RP@)&EM86=E+3Y?<W)C+"`D871T<FEB=71E
M<RD["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<DEN<'5T*"8D:6YP=70I
M"B`@("!["B`@("`@("`@)'1Y<&4@/2`G('1Y<&4](B<@+B`D:6YP=70M/F=E
M="@G='EP92<I("X@)R(G.PH@("`@("`@("1S:7IE(#T@)&EN<'5T+3YG970H
M)W-I>F4G*2`_('-P<FEN=&8H)R!S:7IE/2(E9"(G+"`D:6YP=70M/F=E="@G
M<VEZ92<I*2`Z("<G.PH@("`@("`@("1M87AL96YG=&@@/2`D:6YP=70M/F=E
M="@G;6%X;&5N9W1H)RD@/R!S<')I;G1F*"<@;6%X;&5N9W1H/2(E9"(G+"`D
M:6YP=70M/F=E="@G;6%X;&5N9W1H)RDI(#H@)R<["@H@("`@("`@('!R:6YT
M9B@G)7,\:6YP=70@96UP='EO:STB=')U92(@9F]R;6%T/2(E<R(E<R!N86UE
M/2)?)7,B('9A;'5E/2(E<R(E<R5S+SXG+`H@("`@("`@("`@("`@("`D=&AI
M<RT^97-C87!E*"1I;G!U="T^9V5T*"=L86)E;"<I*2P@)&EN<'5T+3YG970H
M)V9O<FUA="<I+`H@("`@("`@("`@("`@("`D='EP92P@)'1H:7,M/F5S8V%P
M92@D:6YP=70M/F=E="@G;F%M92<I*2P@)'1H:7,M/F5S8V%P92@D:6YP=70M
M/F=E="@G=F%L=64G*2DL("1S:7IE+"`D;6%X;&5N9W1H*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?<F5N9&5R5&5X=&%R96$H)B1T97AT87)E82D*("`@('L*
M("`@("`@("!P<FEN=&8H)R5S/&EN<'5T(&5M<'1Y;VL](G1R=64B(&YA;64]
M(E\E<R(@=F%L=64](B5S(B\^)RP*("`@("`@("`@("`@("`@)'1H:7,M/F5S
M8V%P92@D=&5X=&%R96$M/F=E="@G;&%B96PG*2DL"B`@("`@("`@("`@("`@
M("1T97AT87)E82T^9V5T*"=N86UE)RDL("1T97AT87)E82T^9V5T*"=V86QU
M92<I*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4V5L96-T*"8D<V5L
M96-T*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I<FLH)V]W7V=U
M:5\Q+C,G*2D@>PH@("`@("`@("`@("!S=VET8V@@*"1S96QE8W0M/F=E="@G
M='EP92<I*2!["B`@("`@("`@("`@(&-A<V4@)W-P:6XG.@H@("`@("`@("`@
M("`@("`@)'1Y<&5?;W!T:6]N(#T@)W1Y<&4](G-P:6XB)SL*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G<&]P=7`G.@H@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@)'1Y<&5?;W!T:6]N
M(#T@)W1Y<&4](G!O<'5P(B<["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@96-H;R`G/'-E;&5C="`G("X@)'1Y
M<&5?;W!T:6]N("X@)R!N86UE/2)?)R`N("1S96QE8W0M/F=E="@G;F%M92<I
M("X@)R(^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO("<\
M<V5L96-T(&YA;64](E\G("X@)'-E;&5C="T^9V5T*"=N86UE)RD@+B`G(CXG
M.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'-E;&5C="T^7V]P=&EO
M;G,@87,@)'9A;"D@>PH@("`@("`@("`@("!E8VAO("<\;W!T:6]N('9A;'5E
M/2(G("X@)'9A;%LG=F%L=64G72`N("<B/B<@+B`D=&AI<RT^97-C87!E*"1V
M86Q;)VQA8F5L)UTI("X@)SPO;W!T:6]N/B<["B`@("`@("`@?0H@("`@("`@
M(&5C:&\@)SPO<V5L96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E
M<E)A9&EO*"8D<F%D:6\I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YH87-1
M=6ER:R@G;W=?9W5I7S$N,R<I*2!["B`@("`@("`@("`@("\O($]P96YW879E
M($=522!E>'1E;G-I;VYS(&9O<B!734P@,2XS"B`@("`@("`@("`@('!R:6YT
M9B@G/'-E;&5C="!T>7!E/2)R861I;R(@;F%M93TB7R5S(CXG+"`D<F%D:6\M
M/F=E="@G;F%M92<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M+R!#;VYV96YT:6]N86P@5TU,("AS:6UI;&%R('1O($AO<F1E7TUO8FEL95]S
M96QE8W0I+@H@("`@("`@("`@("!P<FEN=&8H)SQS96QE8W0@;F%M93TB7R5S
M(CXG+"`D<F%D:6\M/F=E="@G;F%M92<I*3L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1R861I;RT^7V)U='1O;G,@87,@)'9A;"D@>PH@("`@("`@
M("`@("!P<FEN=&8H)SQO<'1I;VX@=F%L=64](B5S(CXE<SPO;W!T:6]N/B<L
M"B`@("`@("`@("`@("`@("`@("`D=F%L6R=V86QU92==+"`D=&AI<RT^97-C
M87!E*"1V86Q;)VQA8F5L)UTI*3L*("`@("`@("!]"@H@("`@("`@(&5C:&\@
M)SPO<V5L96-T/B<["B`@("!]"@H@("`@9G5N8W1I;VX@7W)E;F1E<D-H96-K
M8F]X*"8D8VAE8VMB;W@I"B`@("!["B`@("`@("`@<')I;G1F*"<\<V5L96-T
M(&YA;64](E\E<R(@;75L=&EP;&4](G1R=64B/B<L("1C:&5C:V)O>"T^9V5T
M*"=N86UE)RDI.PH@("`@("`@('!R:6YT9B@G/&]P=&EO;B!V86QU93TB)7,B
M/B5S/"]O<'1I;VX^/"]S96QE8W0^)RP*("`@("`@("`@("`@("`@)&-H96-K
M8F]X+3YG970H)W9A;'5E)RDL("1T:&ES+3YE<V-A<&4H)&-H96-K8F]X+3YG
M970H)VQA8F5L)RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4W5B
M;6ET*"8D<W5B;6ET*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:&%S475I
M<FLH)V]W7V=U:5\Q+C,G*2D@>PH@("`@("`@("`@("`O+R!#<F5A=&4@/&1O
M('1Y<&4](F)U='1O;B(^('-E<75E;F-E(&9O<B!/<&5N=V%V92!'54D*("`@
M("`@("`@("`@+R\@97AT96YS:6]N<R!734P@,2XS+@H@("`@("`@("`@("!P
M<FEN=&8H)SQD;R!T>7!E/2)B=71T;VXB(&QA8F5L/2(E<R(^)RP*("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E
M;"<I*2D["B`@("`@("`@("`@("1T86<@/2`G9&\G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O($-R96%T92`\86YC:&]R/B!S97%U96YC92!I
M;B!N;W)M86P@5TU,+@H@("`@("`@("`@("!P<FEN=&8H)SQA;F-H;W(@=&ET
M;&4](B5S(CXE<R<L"B`@("`@("`@("`@("`@("`@("`D=&AI<RT^97-C87!E
M*"1S=6)M:70M/F=E="@G;&%B96PG*2DL"B`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^97-C87!E*"1S=6)M:70M/F=E="@G;&%B96PG*2DI.PH@("`@("`@
M("`@("`D=&%G(#T@)V%N8VAO<B<["B`@("`@("`@?0H*("`@("`@("!I9B`H
M)'-U8FUI="T^7V9O<FTM/F=E="@G;65T:&]D)RD@/3T@)W!O<W0G*2!["B`@
M("`@("`@("`@('!R:6YT9B@G/&=O(&AR968](B5S(B!M971H;V0](G!O<W0B
M/B<L($AO<F1E.CIU<FPH)'-U8FUI="T^7V9O<FTM/F=E="@G=7)L)RDI*3L*
M"B`@("`@("`@("`@("\O(%9A;'5E(&9O<B!T:&ES('-U8FUI="!E;&5M96YT
M+"!O;FQY(&EF(&YO;BUE;7!T>2!N86UE+@H@("`@("`@("`@("!I9B`H)'-U
M8FUI="T^9V5T*"=N86UE)RDI('L*("`@("`@("`@("`@("`@('!R:6YT9B@G
M/'!O<W1F:65L9"!N86UE/2(E<R(@=F%L=64](B5S(B\^)RP@)'-U8FUI="T^
M9V5T*"=N86UE)RDL("1T:&ES+3YE<V-A<&4H)'-U8FUI="T^9V5T*"=L86)E
M;"<I*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1D969A=6QT<R`]
M("1S=6)M:70M/E]F;W)M+3YG971$969A=6QT<R@I.PH@("`@("`@("`@("!F
M;W)E86-H("@D9&5F875L=',@87,@)&0I('L*("`@("`@("`@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"=H:61D96XG+"`D9"DI('L*("`@("`@("`@
M("`@("`@("`@("!P<FEN=&8H)SQP;W-T9FEE;&0@;F%M93TB)7,B('9A;'5E
M/2(E<R(O/B<L("1D6R=N86UE)UTL("1T:&ES+3YE<V-A<&4H)&1;)W9A;'5E
M)UTI*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@<')I;G1F*"<\<&]S=&9I96QD(&YA;64](B5S(B!V86QU93TB)"A?
M)7,I(B\^)RP@)&1;)VYA;64G72P@)&1;)VYA;64G72D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`O+R!3=&%R="!W:71H('1H92!V86QU92!F;W(@=&AI<R!S=6)M:70@
M96QE;65N="X*("`@("`@("`@("`@)'%U97)Y7W-T<FEN9R`]("1S=6)M:70M
M/F=E="@G;F%M92<I("X@)STG("X@)'1H:7,M/F5S8V%P92@D<W5B;6ET+3YG
M970H)VQA8F5L)RDI("X@)R9A;7`[)SL*"B`@("`@("`@("`@("1G971V87)S
M(#T@)'-U8FUI="T^7V9O<FTM/F=E=$=E=%9A<G,H*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)&=E='9A<G,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@
M)'%U97)Y7W-T<FEN9R`N/2`D=F%L("X@)STD*%\G("X@)'9A;"`N("<I)F%M
M<#LG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1Q
M=65R>5]S=')I;F<L("TU*2`]/2`G)F%M<#LG*2!["B`@("`@("`@("`@("`@
M("`D<75E<GE?<W1R:6YG(#T@<W5B<W1R*"1Q=65R>5]S=')I;F<L(#`L('-T
M<FQE;B@D<75E<GE?<W1R:6YG*2`M(#4I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!P<FEN=&8H)SQG;R!H<F5F/2(E<S\E<R(^)RP@)'-U8FUI="T^
M7V9O<FTM/F=E="@G=7)L)RDL("1Q=65R>5]S=')I;F<I.PH@("`@("`@('T*
M"B`@("`@("`@96-H;R`B/"]G;SX\+R1T86<^(CL*("`@('T*"B`@("!F=6YC
M=&EO;B!?<F5N9&5R5&%B;&4H)B1T86)L92D*("`@('L*("`@("`@("`O+R!#
M;W5N="!M87AI;75M(&YU;6)E<B!O9B!C;VQU;6YS(&EN('1A8FQE+@H@("`@
M("`@("1M87@@/2`P.PH@("`@("`@(&9O<F5A8V@@*"1T86)L92T^7W)O=W,@
M87,@)')O=RD@>PH@("`@("`@("`@("`D;6%X(#T@;6%X*"1M87@L("1R;W<M
M/F=E=$-O;'5M;D-O=6YT*"DI.PH@("`@("`@('T*("`@("`@("!P<FEN=&8H
M)SQT86)L92!C;VQU;6YS/2(E9"(^)RP@)&UA>"D["@H@("`@("`@('!A<F5N
M=#HZ7W)E;F1E<E1A8FQE*"1T86)L92D["@H@("`@("`@("\O(%1E<FUI;F%T
M92!T86)L92X*("`@("`@("!E8VAO("<\+W1A8FQE/B<["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E;F1E<E!H;VYE*"8D<&AO;F4I"B`@("!["B`@("`@("`@
M)'1I=&QE(#T@)'!H;VYE+3YG970H)W1I=&QE)RD["B`@("`@("`@)'1I=&QE
M7V]P=&EO;B`]("@D=&ET;&4@/R!S<')I;G1F*"<@=&ET;&4](B5S(B<L("1T
M:&ES+3YE<V-A<&4H)'1I=&QE*2D@.B`G)RD["@H@("`@("`@('!R:6YT9B@G
M/&$E<R!H<F5F/2)W=&%I.B\O=W`O;6,[)7,B/B5S/"]A/B<L("1T:71L95]O
M<'1I;VXL"B`@("`@("`@("`@("`@('-T<E]R97!L86-E*"<K)RP@)R4R0B<L
M("1P:&]N92T^9V5T*"=N=6UB97(G*2DL("1P:&]N92T^9V5T*"=L86)E;"<I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5N9&5R4G5L92@F)')U;&4I"B`@
M("!["B`@("`@("`@:68@*"1T:&ES+3YH87-1=6ER:R@G;W=?9W5I7S$N,R<I
M*2!["B`@("`@("`@("`@("\O(%=!4"!D979I8V4@86-C97!T<R!/<&5N=V%V
M92!'54D@97AT96YS:6]N<R!F;W(@5TU,(#$N,PH@("`@("`@("`@("`D=VED
M=&@@/2`D<G5L92T^9V5T*"=W:61T:"<I.PH@("`@("`@("`@("`D<VEZ92`]
M("1R=6QE+3YG970H)W-I>F4G*3L*"B`@("`@("`@("`@(&5C:&\@)SQH<B<@
M+B`H)'=I9'1H(#\@)R!W:61T:#TB)R`N("1W:61T:"`N("<B)R`Z("<G*2`N
M("@D<VEZ92`_("<@<VEZ93TB)R`N("1S:7IE("X@)R(G(#H@)R<I("X@)R`O
M/B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@5T%0(&1E=FEC
M92!D;V5S(&YO="!U;F1E<G-T86YD(#QH<B`O/B!T86=S+@H@("`@("`@("`@
M("`O+R`]/3X@9')A=R!S;VUE(&YU;6)E<B!O9B!H>7!H96YS('1O(&-R96%T
M92!A(')U;&4*("`@("`@("`@("`@96-H;R`G+2TM+2TM+2TM+3QB<B`O/B<[
M"B`@("`@("`@?0H@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C
M:R]T:6UE+G!H<```````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S`T-R`Q,#4Q-30S-#$S-R`P,C$P,3$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B1B;&]C:U]N
M86UE(#T@7R@B0W5R<F5N="!4:6UE(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D
M92]L:6(O0FQO8VLO=&EM92YP:'`L=B`Q+C$V(#(P,#0O,3$O,C,@,34Z,3<Z
M-3,@8VAU8VL@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO
M"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7W1I;64@97AT96YD<R!(;W)D95]"
M;&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO
M;B!?<&%R86US*"D*("`@('L*("`@("`@("!R971U<FX@)'!A<F%M<R`](&%R
M<F%Y*"=T:6UE)R`]/B!A<G)A>2@G='EP92<@/3X@)V5N=6TG+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE
M)R`]/B!?*")4:6UE(&9O<FUA="(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B`G,C0M:&]U
M<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W9A;'5E<R<@/3X@87)R87DH)S(T+6AO=7(G(#T^(%\H(C(T($AO
M=7(@1F]R;6%T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S$R+6AO=7(G(#T^
M(%\H(C$R($AO=7(@1F]R;6%T(BDI*2D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")#
M=7)R96YT(%1I;64B*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!C;VYT
M96YT('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@("!4:&4@8V]N=&5N=`H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V]N=&5N="@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%R
M86US6R=T:6UE)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T
M:6UE)UT@/2`G,C0M:&]U<B<["B`@("`@("`@?0H*("`@("`@("`O+R!3970@
M=&AE('1I;65Z;VYE('9A<FEA8FQE+"!I9B!A=F%I;&%B;&4N"B`@("`@("`@
M3DQ3.CIS9714:6UE6F]N92@I.PH*("`@("`@("`D:'1M;"`]("<\=&%B;&4@
M=VED=&@](C$P,"4B(&AE:6=H=#TB,3`P)2(^/'1R/CQT9"!S='EL93TB9F]N
M="UF86UI;'DZ=F5R9&%N83MF;VYT+7-I>F4Z,3AP>#LB(&%L:6=N/2)C96YT
M97(B('9A;&EG;CTB;6ED9&QE(CXG.PH@("`@("`@("1H=&UL("X]('-T<F9T
M:6UE*"<E02P@)4(@)60L("59("<I.PH@("`@("`@(&EF("@D=&AI<RT^7W!A
M<F%M<ULG=&EM92==(#T]("<R-"UH;W5R)RD@>PH@("`@("`@("`@("`D:'1M
M;"`N/2!S=')F=&EM92@G)4@Z)4TG*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D:'1M;"`N/2!S=')F=&EM92@G)4DZ)4T@)7`G*3L*("`@("`@
M("!]"B`@("`@("`@)&AT;6P@+CT@)SPO=&0^/"]T<CX\+W1A8FQE/B<["@H@
M("`@("`@(')E='5R;B`D:'1M;#L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O0FQO8VLO=V5A
M=&AE<F1O=&-O;2YP:'``````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-#,V-30@,3`U,34T,S0Q,S<@,#(R-S,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*B!$:7-A8FQE(&)L
M;V-K(&EF(&YO="!C;VYF:6=U<F5D+B`J+PII9B`H(65M<'1Y*"1'3$]"04Q3
M6R=C;VYF)UU;)W=E871H97)D;W1C;VTG75LG<&%R=&YE<E]I9"==*2`F)@H@
M("`@(65M<'1Y*"1'3$]"04Q36R=C;VYF)UU;)W=E871H97)D;W1C;VTG75LG
M;&EC96YS95]K97DG72DI('L*("`@("1B;&]C:U]N86UE(#T@7R@B=V5A=&AE
M<BYC;VTB*3L*?0H*+RHJ"B`J(%1H92!(;W)D95]";&]C:U]W96%T:&5R9&]T
M8V]M(&-L87-S('!R;W9I9&5S(&%N(&%P<&QE="!F;W(@=&AE"B`J('!O<G1A
M;"!S8W)E96X@=&\@9&ES<&QA>2!W96%T:&5R(&%N9"!F;W)E8V%S="!D871A
M(&9R;VT@=V5A=&AE<BYC;VT*("H@9F]R(&$@<W!E8VEF:65D(&QO8V%T:6]N
M+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M
M+G!H<"QV(#$N,S<N-"XQ,R`R,#`U+S$R+S`U(#`S.C0Q.C`P(&-H=6-K($5X
M<"`D"B`J"B`J($!P86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D
M95]";&]C:U](;W)D95]W96%T:&5R9&]T8V]M(&5X=&5N9',@2&]R9&5?0FQO
M8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@+RHJ"B`@("`@
M*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")7
M96%T:&5R($9O<F5C87-T(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@
M<&%R86UE=&5R<R!T;R!G;R!W:71H('1H:7,@8FQO8VLN"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@8V]N=&%I;FEN9R!T:&4@<&%R
M86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("![
M"B`@("`@("`@:68@*"$H0&EN8VQU9&5?;VYC92`G4V5R=FEC97,O5V5A=&AE
M<BYP:'`G*2!\?`H@("`@("`@("`@("`A*$!I;F-L=61E7V]N8V4@)T-A8VAE
M+G!H<"<I('Q\"B`@("`@("`@("`@("$H0&EN8VQU9&5?;VYC92`G6$U,+U-E
M<FEA;&EZ97(N<&AP)RD@?'P*("`@("`@("`@("`@(6EN:5]G970H)V%L;&]W
M7W5R;%]F;W!E;B<I*2!["B`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E
M*"=4:&4@=V5A=&AE<BYC;VT@8FQO8VL@=VEL;"!N;W0@=V]R:R!W:71H;W5T
M(%!%05)<)W,@4V5R=FEC97-?5V5A=&AE<BP@0V%C:&4L(&%N9"!834Q?(%-E
M<FEA;&EZ97(@<&%C:V%G97,L(&%N9"!A;&QO=U]U<FQ?9F]P96X@96YA8FQE
M9"X@4G5N(&!P96%R(&EN<W1A;&P@4V5R=FEC97-?5V5A=&AE<B!#86-H92!8
M34Q?4V5R:6%L:7IE<K0@86YD(&5N<W5R92!T:&%T(&%L;&]W7W5R;%]F;W!E
M;B!I<R!E;F%B;&5D(&EN('!H<"YI;FDN)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("`D<&%R86US(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`G97)R;W(G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E
M)R`]/B`G97)R;W(G+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")%<G)O<B(I+`H@("`@("`@("`@("`@("`@("`@("=D969A=6QT)R`]/B!?
M*")4:&4@=V5A=&AE<BYC;VT@8FQO8VL@:7,@;F]T(&%V86EL86)L92XB*0H@
M("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("=L;V-A=&EO;B<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M+R\@)W1Y<&4G(#T^("=W96%T:&5R9&]T8V]M)RP*("`@("`@("`@("`@("`@
M("`@("`G='EP92<@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@("`@("`@("`@("`@("`@("=D
M969A=6QT)R`]/B`G0F]S=&]N+"!-02<*("`@("`@("`@("`@("`@("DL"B`@
M("`@("`@("`@("`@("`G=6YI=',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@("`@("`@("`@
M)VYA;64G(#T^(%\H(E5N:71S(BDL"B`@("`@("`@("`@("`@("`@("`@)V1E
M9F%U;'0G(#T^("=S=&%N9&%R9"<L"B`@("`@("`@("`@("`@("`@("`@)S`G
M(#T^("=N;VYE)RP*("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B!A
M<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W-T86YD87)D)R`]/B!?
M*")3=&%N9&%R9"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`G;65T<FEC
M)R`]/B!?*")-971R:6,B*0H@("`@("`@("`@("`@("`@("`@("D*("`@("`@
M("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`G9&%Y<R<@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*("`@("`@
M("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B1F]R96-A<W0@1&%Y<R`H;F]T
M92!T:&%T('1H92!R971U<FYE9"!F;W)E8V%S="!R971U<FYS(&)O=&@@9&%Y
M(&%N9"!N:6=H=#L@82!L87)G92!N=6UB97(@:&5R92!C;W5L9"!R97-U;'0@
M:6X@82!W:61E(&)L;V-K*2(I+`H@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`]/B`G,R<L"B`@("`@("`@("`@("`@("`@("`@)W9A;'5E<R<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("<Q)R`]/B`G,2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<R)R`]/B`G,B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("<S)R`]/B`G,R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<T)R`]/B`G-"<L"B`@("`@("`@("`@("`@("`@("`@("`@("<U)R`]
M/B`G-2<L"B`@("`@("`@("`@("`@("`@("`@("`@("<V)R`]/B`G-B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("<W)R`]/B`G-R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("<X)R`]/B`G."<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<Y)R`]/B`G.2<L"B`@("`@("`@("`@("`@("`@("`@("`@("<Q,"<@
M/3X@)S$P)PH@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@
M("DL"B`@("`@("`@("`@("`@("`G9&5T86EL961&;W)E8V%S="<@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=C:&5C:V)O>"<L
M"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(D1I<W!L87D@9&5T
M86EL960@9F]R96-A<W0B*2P*("`@("`@("`@("`@("`@("`@("`G9&5F875L
M="<@/3X@,`H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@(&EF("@A
M*$!I;F-L=61E7V]N8V4@)U-E<G9I8V5S+U=E871H97(N<&AP)RD@?'P*("`@
M("`@("`@("`@(2A`:6YC;'5D95]O;F-E("=#86-H92YP:'`G*2!\?`H@("`@
M("`@("`@("`A:6YI7V=E="@G86QL;W=?=7)L7V9O<&5N)RDI('L*("`@("`@
M("`@("`@2&]R9&4Z.FQO9TUE<W-A9V4H)U1H92!W96%T:&5R+F-O;2!B;&]C
M:R!W:6QL(&YO="!W;W)K('=I=&AO=70@=&AE(%!%05)397)V:6-E<U]796%T
M:&5R(&%N9"!#86-H92!P86-K86=E<RP@86YD(&%L;&]W7W5R;%]F;W!E;B!E
M;F%B;&5D+B!2=6X@<&5A<B!I;G-T86QL(%-E<G9I8V5S7U=E871H97(@0V%C
M:&4L(&%N9"!E;G-U<F4@=&AA="!A;&QO=U]U<FQ?9F]P96Y?=W)A<'!E<G,@
M:7,@96YA8FQE9"!I;B!P:'`N:6YI+B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*
M("`@("`@("`@("`@<F5T=7)N(%\H(E1H92!W96%T:&5R+F-O;2!B;&]C:R!I
M<R!N;W0@879A:6QA8FQE+B(I.PH@("`@("`@('T*"B`@("`@("`@9VQO8F%L
M("1C;VYF.PH*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)VQO
M8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B!?*").;R!L;V-A=&EO
M;B!I<R!S970N(BD["B`@("`@("`@?0H*("`@("`@("`D=V5A=&AE<D1O=$-O
M;2`]("9397)V:6-E<U]796%T:&5R.CIS97)V:6-E*"=796%T:&5R1&]T0V]M
M)RD["B`@("`@("`@)'=E871H97)$;W1#;VTM/G-E=$%C8V]U;G1$871A*`H@
M("`@("`@("`@("`H:7-S970H)&-O;F9;)W=E871H97)D;W1C;VTG75LG<&%R
M=&YE<E]I9"==*2`_("1C;VYF6R=W96%T:&5R9&]T8V]M)UU;)W!A<G1N97)?
M:60G72`Z("<G*2P*("`@("`@("`@("`@*&ES<V5T*"1C;VYF6R=W96%T:&5R
M9&]T8V]M)UU;)VQI8V5N<V5?:V5Y)UTI(#\@)&-O;F9;)W=E871H97)D;W1C
M;VTG75LG;&EC96YS95]K97DG72`Z("<G*2D["@H@("`@("`@("1C86-H941I
M<B`]($AO<F1E.CIG971496UP1&ER*"D["B`@("`@("`@:68@*"$D8V%C:&5$
M:7(I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F\@=&5M<&]R87)Y(&1I<F5C=&]R>2!A=F%I;&%B;&4@9F]R(&-A8VAE+B(I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=V5A=&AE<D1O=$-O;2T^<V5T0V%C:&4H)V9I;&4G+"!A<G)A>2@G8V%C
M:&5?9&ER)R`]/B`H)&-A8VAE1&ER("X@)R\G*2DI.PH@("`@("`@('T*("`@
M("`@("`D=V5A=&AE<D1O=$-O;2T^<V5T1&%T951I;65&;W)M870H)VTN9"Y9
M)RP@)T@Z:2<I.PH@("`@("`@("1W96%T:&5R1&]T0V]M+3YS9715;FET<T9O
M<FUA="@D=&AI<RT^7W!A<F%M<ULG=6YI=',G72D["B`@("`@("`@)'5N:71S
M(#T@)'=E871H97)$;W1#;VTM/F=E=%5N:71S1F]R;6%T*"D["@H@("`@("`@
M("\O($EF('1H92!U<V5R(&5N=&5R960@82!Z:7`@8V]D92!F;W(@=&AE(&QO
M8V%T:6]N+"!N;R!N965D('1O"B`@("`@("`@+R\@<V5A<F-H("AW96%T:&5R
M+F-O;2!A8V-E<'1S('II<"!C;V1E<R!A<R!L;V-A=&EO;B!)1',I+@H@("`@
M("`@("\O(%1H92!L;V-A=&EO;B!)1"!S:&]U;&0@86QR96%D>2!H879E(&)E
M96X@=F%L:61A=&5D(&EN"B`@("`@("`@+R\@9V5T4&%R86US+@H@("`@("`@
M("1S96%R8V@@/2`H<')E9U]M871C:"@G+UQB*#\Z7%QD>S5]*"U<7&1[-7TI
M/RE\*#\Z6T$M6EU[-'U<7&1[-'TI7&(O)RP*("`@("`@("`@("`@)'1H:7,M
M/E]P87)A;7-;)VQO8V%T:6]N)UTL("1M871C:&5S*2`_"B`@("`@("`@("`@
M("1M871C:&5S6S!=(#H*("`@("`@("`@("`@)'=E871H97)$;W1#;VTM/G-E
M87)C:$QO8V%T:6]N*"1T:&ES+3Y?<&%R86US6R=L;V-A=&EO;B==*2D["B`@
M("`@("`@:68@*&ES7V$H)'-E87)C:"P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!S=VET8V@@*"1S96%R8V@M/F=E=$-O9&4H*2D@>PH@("`@("`@
M("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?4T525DE#15].3U1?
M1D]53D0Z"B`@("`@("`@("`@("`@("!R971U<FX@7R@B4F5Q=65S=&5D('-E
M<G9I8V4@8V]U;&0@;F]T(&)E(&9O=6YD+B(I.PH@("`@("`@("`@("!C87-E
M(%-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3CH*("`@
M("`@("`@("`@("`@(')E='5R;B!?*")5;FMN;W=N(&QO8V%T:6]N('!R;W9I
M9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)2
M3U)?5U)/3D=?4T525D527T1!5$$Z"B`@("`@("`@("`@("`@("!R971U<FX@
M7R@B4V5R=F5R(&1A=&$@=W)O;F<@;W(@;F]T(&%V86EL86)L92XB*3L*("`@
M("`@("`@("`@8V%S92!315)624-%4U]714%42$527T524D]27T-!0TA%7TE.
M251?1D%)3$5$.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(D-A8VAE(&EN
M:70@=V%S(&YO="!C;VUP;&5T960N(BD["B`@("`@("`@("`@(&-A<V4@4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$.@H@("`@("`@
M("`@("`@("`@<F5T=7)N(%\H(DUE=&%R1$(@:7,@;F]T(&-O;FYE8W1E9"XB
M*3L*("`@("`@("`@("`@8V%S92!315)624-%4U]714%42$527T524D]27U5.
M2TY/5TY?15)23U(Z"B`@("`@("`@("`@("`@("!R971U<FX@7R@B06X@=6YK
M;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB*3L*("`@("`@("`@("`@8V%S92!3
M15)624-%4U]714%42$527T524D]27TY/7TQ/0T%424]..@H@("`@("`@("`@
M("`@("`@<F5T=7)N(%\H(DYO(&QO8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@
M("`@("`@("!C87-E(%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],
M3T-!5$E/3CH*("`@("`@("`@("`@("`@(')E='5R;B!?*"));G9A;&ED(&QO
M8V%T:6]N('!R;W9I9&5D+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T53
M7U=%051(15)?15)23U)?24Y604Q)1%]005)43D527TE$.@H@("`@("`@("`@
M("`@("`@<F5T=7)N(%\H(DEN=F%L:60@<&%R=&YE<B!I9"XB*3L*("`@("`@
M("`@("`@8V%S92!315)624-%4U]714%42$527T524D]27TE.5D%,241?4%)/
M1%5#5%]#3T1%.@H@("`@("`@("`@("`@("`@<F5T=7)N(%\H(DEN=F%L:60@
M<')O9'5C="!C;V1E+B(I.PH@("`@("`@("`@("!C87-E(%-%4E9)0T537U=%
M051(15)?15)23U)?24Y604Q)1%],24-%3E-%7TM%63H*("`@("`@("`@("`@
M("`@(')E='5R;B!?*"));G9A;&ED(&QI8V5N<V4@:V5Y+B(I.PH@("`@("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N("1S96%R8V@M
M/F=E=&UE<W-A9V4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@)&AT;6P@/2`G)SL*("`@("`@("!I9B`H:7-?87)R87DH)'-E87)C:"DI
M('L*("`@("`@("`@("`@+R\@4V5V97)A;"!L;V-A=&EO;G,@<F5T=7)N960@
M9'5E('1O(&EM<')E8VES92!L;V-A=&EO;@H@("`@("`@("`@("`O+R!P87)A
M;65T97(N"B`@("`@("`@("`@("1H=&UL(#T@7R@B4V5V97)A;"!L;V-A=&EO
M;G,@<&]S<VEB;&4@=VET:"!T:&4@<&%R86UE=&5R.B`B*2`N"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72`N"B`@("`@("`@
M("`@("`@("`G/&)R("\^/'5L/B<["B`@("`@("`@("`@(&9O<F5A8V@@*"1S
M96%R8V@@87,@)&ED7W=E871H97(]/B1R96%L7VQO8V%T:6]N*2!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2`B/&QI/B1R96%L7VQO8V%T:6]N("@D:61?
M=V5A=&AE<BD\+VQI/EQN(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M:'1M;"`N/2`G/"]U;#XG.PH@("`@("`@("`@("!R971U<FX@)&AT;6P["B`@
M("`@("`@?0H*("`@("`@("`D;&]C871I;VX@/2`D=V5A=&AE<D1O=$-O;2T^
M9V5T3&]C871I;VXH)'-E87)C:"D["B`@("`@("`@:68@*&ES7V$H)&QO8V%T
M:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D;&]C
M871I;VXM/F=E=&UE<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@)'=E871H
M97(@/2`D=V5A=&AE<D1O=$-O;2T^9V5T5V5A=&AE<B@D<V5A<F-H*3L*("`@
M("`@("!I9B`H:7-?82@D=V5A=&AE<BP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'=E871H97(M/F=E=&UE<W-A9V4H*3L*("`@("`@
M("!]"B`@("`@("`@)&9O<F5C87-T(#T@)'=E871H97)$;W1#;VTM/F=E=$9O
M<F5C87-T*"1S96%R8V@L("1T:&ES+3Y?<&%R86US6R=D87ES)UTI.PH@("`@
M("`@(&EF("AI<U]A*"1F;W)E8V%S="P@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&9O<F5C87-T+3YG971M97-S86=E*"D["B`@("`@
M("`@?0H*("`@("`@("`O+R!,;V-A=&EO;B!A;F0@;&]C86P@=&EM92X*("`@
M("`@("`D:'1M;"`N/2`G/&1I=B!C;&%S<STB8V]N=')O;"(^)R`N"B`@("`@
M("`@("`@("<\<W1R;VYG/B<@+B`D;&]C871I;VY;)VYA;64G72`N("<\+W-T
M<F]N9SX@)R`N(%\H(DQO8V%L('1I;64Z("(I("X@)&QO8V%T:6]N6R=T:6UE
M)UT@+@H@("`@("`@("`@("`G/"]D:78^)SL*"B`@("`@("`@+R\@4W5N<FES
M92]S=6YS970N"B`@("`@("`@)&AT;6P@+CT@)SQS=')O;F<^)R`N(%\H(E-U
M;G)I<V4Z("(I("X@)SPO<W1R;VYG/B<@+@H@("`@("`@("`@("!(;W)D93HZ
M:6UG*"=B;&]C:R]S=6YR:7-E+W-U;G)I<V4N<&YG)RP@7R@B4W5N<FES92(I
M*2`N"B`@("`@("`@("`@("1L;V-A=&EO;ELG<W5N<FES92==.PH@("`@("`@
M("1H=&UL("X]("<@/'-T<F]N9SXG("X@7R@B4W5N<V5T.B`B*2`N("<\+W-T
M<F]N9SXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO<W5N<FES
M92]S=6YS970N<&YG)RP@7R@B4W5N<V5T(BDI("X*("`@("`@("`@("`@)&QO
M8V%T:6]N6R=S=6YS970G73L*"B`@("`@("`@+R\@5&5M<&5R871U<F4N"B`@
M("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O;F<^)R`N(%\H(E1E;7!E<F%T
M=7)E.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@<F]U;F0H)'=E
M871H97);)W1E;7!E<F%T=7)E)UTI("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P
M97(H)'5N:71S6R=T96UP)UTI.PH*("`@("`@("`O+R!$97<@<&]I;G0N"B`@
M("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@+B!?*")$97<@<&]I;G0Z("(I
M("X@)SPO<W1R;VYG/B<@+@H@("`@("`@("`@("!R;W5N9"@D=V5A=&AE<ELG
M9&5W4&]I;G0G72D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;
M)W1E;7`G72D["@H@("`@("`@("\O($9E96QS(&QI:V4@=&5M<&5R871U<F4N
M"B`@("`@("`@)&AT;6P@+CT@)R`\<W1R;VYG/B<@+B!?*")&965L<R!L:6ME
M.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@<F]U;F0H)'=E871H
M97);)V9E;'1496UP97)A='5R92==*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P
M<&5R*"1U;FET<ULG=&5M<"==*3L*"B`@("`@("`@+R\@4')E<W-U<F4@86YD
M('1R96YD+@H@("`@("`@("1H=&UL("X]("<\8G(@+SX\<W1R;VYG/B<@+B!?
M*")0<F5S<W5R93H@(BD@+B`G/"]S=')O;F<^)SL*("`@("`@("`D=')E;F0@
M/2`D=V5A=&AE<ELG<')E<W-U<F54<F5N9"==.PH@("`@("`@("1H=&UL("X]
M('-P<FEN=&8H7R@B)60@)7,@86YD("5S(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("!R;W5N9"@D=V5A=&AE<ELG<')E<W-U<F4G72DL("1U;FET<ULG
M<')E<R==+`H@("`@("`@("`@("`@("`@("`@("`@("`@7R@D=')E;F0I*3L*
M"B`@("`@("`@+R\@5VEN9"X*("`@("`@("`D:'1M;"`N/2`G/&)R("\^/'-T
M<F]N9SXG("X@7R@B5VEN9#H@(BD@+B`G/"]S=')O;F<^)SL*("`@("`@("!I
M9B`H)'=E871H97);)W=I;F1$:7)E8W1I;VXG72`]/2`G5D%2)RD@>PH@("`@
M("`@("`@("`D:'1M;"`N/2!?*")687)I86)L92(I.PH@("`@("`@('T@96QS
M96EF("@D=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==(#T]("=#04Q-)RD@>PH@
M("`@("`@("`@("`D:'1M;"`N/2!?*")#86QM(BD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&AT;6P@+CT@7R@B1G)O;2!T:&4@(BD@+B`D=V5A
M=&AE<ELG=VEN9$1I<F5C=&EO;B==.PH@("`@("`@(&EF("AI<W-E="@D=V5A
M=&AE<ELG=VEN9$=U<W0G72D@)B8@)'=E871H97);)W=I;F1'=7-T)UT@/B`P
M*2!["B`@("`@("`@("`@("1H=&UL("X]("<L("<@+B!?*")G=7-T:6YG(BD@
M+B`G("<@+B`D=V5A=&AE<ELG=VEN9$=U<W0G72`N"B`@("`@("`@("`@("`@
M("`G("<@+B`D=6YI='-;)W=I;F0G73L*("`@("`@("!]"@H@("`@("`@("`@
M("`D:'1M;"`N/2`G("@G("X@)'=E871H97);)W=I;F1$96=R965S)UT@+B`G
M*2<["B`@("`@("`@?0H@("`@("`@("1H=&UL("X](%\H(B!A="`B*2`N(')O
M=6YD*"1W96%T:&5R6R=W:6YD)UTI("X@)R`G("X@)'5N:71S6R=W:6YD)UT[
M"@H@("`@("`@("\O($AU;6ED:71Y+@H@("`@("`@("1H=&UL("X]("<\8G(@
M+SX\<W1R;VYG/B<@+B!?*")(=6UI9&ET>3H@(BD@+B`G/"]S=')O;F<^)R`N
M"B`@("`@("`@("`@("1W96%T:&5R6R=H=6UI9&ET>2==("X@)R4G.PH*("`@
M("`@("`O+R!6:7-I8FEL:71Y+@H@("`@("`@("1H=&UL("X]("<@/'-T<F]N
M9SXG("X@7R@B5FES:6)I;&ET>3H@(BD@+B`G/"]S=')O;F<^)R`N"B`@("`@
M("`@("`@("AI<U]N=6UE<FEC*"1W96%T:&5R6R=V:7-I8FEL:71Y)UTI"B`@
M("`@("`@("`@("`_(')O=6YD*"1W96%T:&5R6R=V:7-I8FEL:71Y)UTI("X@
M)R`G("X@)'5N:71S6R=V:7,G70H@("`@("`@("`@("`@.B`D=V5A=&AE<ELG
M=FES:6)I;&ET>2==*3L*"B`@("`@("`@+R\@558@:6YD97@N"B`@("`@("`@
M)&AT;6P@+CT@)R`\<W1R;VYG/B<@+B!?*")5+E8N(&EN9&5X.B`B*2`N("<\
M+W-T<F]N9SXG.PH@("`@("`@("1U=B`]("1W96%T:&5R6R=U=E1E>'0G73L*
M("`@("`@("`D:'1M;"`N/2`D=V5A=&AE<ELG=79);F1E>"==("X@)R`M("<@
M+B!?*"1U=BD["@H@("`@("`@("\O($-U<G)E;G0@8V]N9&ET:6]N+@H@("`@
M("`@("1C;VYD:71I;VX@/2!I;7!L;V1E*"<@+R`G+"!A<G)A>5]M87`H)U\G
M+"!E>'!L;V1E*"<@+R`G+"`D=V5A=&AE<ELG8V]N9&ET:6]N)UTI*2D["B`@
M("`@("`@)&AT;6P@+CT@)SQB<B`O/CQS=')O;F<^)R`N(%\H(D-U<G)E;G0@
M8V]N9&ET:6]N.B`B*2`N("<\+W-T<F]N9SXG("X*("`@("`@("`@("`@2&]R
M9&4Z.FEM9R@G8FQO8VLO=V5A=&AE<F1O=&-O;2\S,G@S,B\G("X*("`@("`@
M("`@("`@("`@("`@("`@("`H)'=E871H97);)V-O;F1I=&EO;DEC;VXG72`]
M/2`G+2<@/R`G;F$G(#H@)'=E871H97);)V-O;F1I=&EO;DEC;VXG72D@+B`G
M+G!N9R<L"B`@("`@("`@("`@("`@("`@("`@("`@)&-O;F1I=&EO;BP*("`@
M("`@("`@("`@("`@("`@("`@("`G86QI9VX](FUI9&1L92(G*3L*("`@("`@
M("`D:'1M;"`N/2`G("<@+B`D8V]N9&ET:6]N.PH*("`@("`@("`O+R!$;R!T
M:&4@9F]R96-A<W0@;F]W("AI9B!R97%U97-T960I+@H@("`@("`@(&EF("@D
M=&AI<RT^7W!A<F%M<ULG9&%Y<R==(#X@,"D@>PH@("`@("`@("`@("`D:'1M
M;"`N/2`G/&1I=B!C;&%S<STB8V]N=')O;"(@<W1Y;&4](G1E>'0M86QI9VXZ
M8V5N=&5R(CX\<W1R;VYG/B<@+@H@("`@("`@("`@("`@("`@<W!R:6YT9BA?
M*"(E9"UD87D@9F]R96-A<W0B*2P@)'1H:7,M/E]P87)A;7-;)V1A>7,G72D@
M+@H@("`@("`@("`@("`@("`@)SPO<W1R;VYG/CPO9&EV/B<["@H@("`@("`@
M("`@("`D9G5T=7)E1&%Y<R`](#`["B`@("`@("`@("`@("1H=&UL("X]("<\
M=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(S(CXG.PH@("`@("`@
M("`@("`O+R!(96%D97)S+@H@("`@("`@("`@("`D:'1M;"`N/2`G/'1R/B<[
M"B`@("`@("`@("`@("1H=&UL("X]("<\=&@^)R`N(%\H(D1A>2(I("X@)SPO
M=&@^/'1H/B9N8G-P.SPO=&@^/'1H/B<@+@H@("`@("`@("`@("`@("`@<W!R
M:6YT9BA?*")496UP97)A='5R93QB<B`O/B@E<TAI)7,O)7-,;R5S*2`F9&5G
M.R5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("<\<W!A;B!S='EL93TB
M8V]L;W(Z<F5D(CXG+"`G/"]S<&%N/B<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU92(^)RP@)SPO<W!A;CXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("!3=')I;F<Z.G5P<&5R*"1U;FET<ULG
M=&5M<"==*2D@+@H@("`@("`@("`@("`@("`@)SPO=&@^/'1H/B<@+B!?*")#
M;VYD:71I;VXB*2`N("<\+W1H/B<@+@H@("`@("`@("`@("`@("`@)SQT:#XG
M("X@7R@B4')E8VEP:71A=&EO;CQB<B`O/F-H86YC92(I("X@)SPO=&@^)SL*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D971A:6QE
M9$9O<F5C87-T)UTI*2!["B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1H
M/B<@+B!?*")(=6UI9&ET>2(I("X@)SPO=&@^/'1H/B<@+B!?*")7:6YD(BD@
M+B`G/"]T:#XG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H=&UL("X]
M("<\+W1R/B<["@H@("`@("`@("`@("!F;W)E86-H("@D9F]R96-A<W1;)V1A
M>7,G72!A<R`D=VAI8V@@/3X@)&1A>2D@>PH@("`@("`@("`@("`@("`@)&AT
M;6P@+CT@)SQT<B!C;&%S<STB:71E;3`B/B<["@H@("`@("`@("`@("`@("`@
M+R\@1&%Y(&YA;64N"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D(')O
M=W-P86X](C(B('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M
M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`@("`@)SQS
M=')O;F<^)SL*("`@("`@("`@("`@("`@(&EF("@D=VAI8V@@/3T@,"D@>PH@
M("`@("`@("`@("`@("`@("`@("1H=&UL("X](%\H(E1O9&%Y(BD["B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)'=H:6-H(#T](#$I('L*("`@("`@("`@
M("`@("`@("`@("`D:'1M;"`N/2!?*")4;VUO<G)O=R(I.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!S
M=')F=&EM92@G)4$G+"!M:W1I;64H,"P@,"P@,"P@9&%T92@G;2<I+"!D871E
M*"=D)RD@*R`D9G5T=7)E1&%Y<RP@9&%T92@G62<I*2D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/"]S=')O;F<^/&)R
M("\^)R`N"B`@("`@("`@("`@("`@("`@("`@<W1R9G1I;64H)R5B("5D)RP@
M;6MT:6UE*#`L(#`L(#`L(&1A=&4H)VTG*2P@9&%T92@G9"<I("L@)&9U='5R
M941A>7,L(&1A=&4H)UDG*2DI("X*("`@("`@("`@("`@("`@("`@("`G/"]T
M9#XG("X*("`@("`@("`@("`@("`@("`@("`G/'1D('-T>6QE/2)B;W)D97(Z
M,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@
M("`@("`@("`@("`@("`G/'-P86X@<W1Y;&4](F-O;&]R.F]R86YG92(^)R`N
M"B`@("`@("`@("`@("`@("`@("`@7R@B1&%Y(BD@+B`G/"]S<&%N/CPO=&0^
M)SL*"B`@("`@("`@("`@("`@("`O+R!4:&4@9&%Y('!O<G1I;VX@;V8@=&AE
M(&9O<F5C87-T(&ES(&YO(&QO;F=E<B!A=F%I;&%B;&4@869T97(@,CHP,"!P
M+FTN(&QO8V%L('1O9&%Y+@H@("`@("`@("`@("`@("`@:68@*"1W:&EC:"`]
M/2`P("8F("AS=')T;W1I;64H)&QO8V%T:6]N6R=T:6UE)UTI(#X]('-T<G1O
M=&EM92@G,30Z,#`G*2DI('L*("`@("`@("`@("`@("`@("`@("`O+R!"86QA
M;F-E('1H92!G<FED+@H@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\
M=&0@8V]L<W!A;CTB)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`H
M*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D971A:6QE9$9O<F5C87-T)UTI(#\@
M)S4G(#H@)S,G*2`N("<B)RD@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N
M.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)FYB
M<W`[/&)R("\^)R`N(%\H(DEN9F]R;6%T:6]N(&YO(&QO;F=E<B!A=F%I;&%B
M;&4N(BD@+B`G/&)R("\^)FYB<W`[)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G/"]T9#XG.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`O+R!&;W)E8V%S="!C;VYD:71I;VXN"B`@("`@
M("`@("`@("`@("`@("`@)&-O;F1I=&EO;B`](&EM<&QO9&4H)R`O("<L(&%R
M<F%Y7VUA<"@G7R<L(&5X<&QO9&4H)R`O("<L("1D87E;)V1A>2==6R=C;VYD
M:71I;VXG72DI*3L*"B`@("`@("`@("`@("`@("`@("`@+R\@2&EG:"!T96UP
M97)A='5R92X*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D('-T
M>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R
M(CXG("X*("`@("`@("`@("`@("`@("`@("`@("`@)SQS<&%N('-T>6QE/2)C
M;VQO<CIR960B/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("!R;W5N9"@D
M9&%Y6R=T96UP97)A='5R94AI9V@G72D@+B`G/"]S<&%N/CPO=&0^)SL*"B`@
M("`@("`@("`@("`@("`@("`@+R\@0V]N9&ET:6]N+@H@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@
M(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@
M("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]W96%T:&5R9&]T8V]M+S(S>#(S
M+R<@+B`H)&1A>5LG9&%Y)UU;)V-O;F1I=&EO;DEC;VXG72`]/2`G+2<@/R`G
M;F$G(#H@)&1A>5LG9&%Y)UU;)V-O;F1I=&EO;DEC;VXG72D@+B`G+G!N9R<L
M("1C;VYD:71I;VXI("X*("`@("`@("`@("`@("`@("`@("`@("`@)SQB<B`O
M/B<@+B`D8V]N9&ET:6]N("X@)SPO=&0^)SL*"B`@("`@("`@("`@("`@("`@
M("`@+R\@4')E8VEP:71A=&EO;B!C:&%N8V4N"B`@("`@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R9&5R.C%P>"!S;VQI9"`C9&1D
M.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("1D87E;)V1A>2==6R=P<F5C:7!I=&%T:6]N)UT@+B`G)2<@+B`G/"]T
M9#XG.PH*("`@("`@("`@("`@("`@("`@("`O+R!)9B!A(&1E=&%I;&5D(&9O
M<F5C87-T('=A<R!R97%U97-T960L('-H;W<@:'5M:61I='D@86YD"B`@("`@
M("`@("`@("`@("`@("`@+R\@=VEN9',N"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=D971A:6QE9$9O<F5C87-T)UTI
M*2!["@H@("`@("`@("`@("`@("`@("`@("`@("`O+R!(=6UI9&ET>2X*("`@
M("`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@)SQT9"!S='EL93TB8F]R
M9&5R.C%P>"!S;VQI9"`C9&1D.R!T97AT+6%L:6=N.F-E;G1E<B(^)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%Y6R=D87DG75LG:'5M:61I
M='DG72`N("<E/"]T9#XG.PH*("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M5VEN9',N"B`@("`@("`@("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@
M<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@(V1D9"(^)R`N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?*")&<F]M('1H92`B*2`N("1D87E;)V1A>2==
M6R=W:6YD1&ER96-T:6]N)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7R@B(&%T("(I("X@)&1A>5LG9&%Y)UU;)W=I;F0G72`N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G("<@+B`D=6YI='-;)W=I;F0G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D87E;)V1A>2==6R=W
M:6YD1W5S="==*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M>5LG9&%Y)UU;)W=I;F1'=7-T)UT@/B`P*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:'1M;"`N/2!?*"(L(&=U<W1I;F<@(BD@+B`D9&%Y6R=D
M87DG75LG=VEN9$=U<W0G72`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R`G("X@)'5N:71S6R=W:6YD)UT["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\+W1R/B<["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@+R\@3FEG:'0@9F]R96-A<W0*("`@("`@("`@("`@
M("`@("1N:6=H="`](&EM<&QO9&4H)R`O("<L(&%R<F%Y7VUA<"@G7R<L(&5X
M<&QO9&4H)R`O("<L("1D87E;)VYI9VAT)UU;)V-O;F1I=&EO;B==*2DI.PH*
M("`@("`@("`@("`@("`@("\O(%-H861E(&ET(&9O<B!V:7-U86P@<V5P87)A
M=&EO;BX*("`@("`@("`@("`@("`@("1H=&UL("X]("<\='(@8VQA<W,](FET
M96TQ(CXG.PH*("`@("`@("`@("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4]
M(F)O<F1E<CHQ<'@@<V]L:60@(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@
M+@H@("`@("`@("`@("`@("`@("`@(%\H(DYI9VAT(BD@+B`G/"]T9#XG.PH*
M("`@("`@("`@("`@("`@("\O($QO=R!T96UP97)A='5R92X*("`@("`@("`@
M("`@("`@("1H=&UL("X]("<\=&0@<W1Y;&4](F)O<F1E<CHQ<'@@<V]L:60@
M(V1D9#L@=&5X="UA;&EG;CIC96YT97(B/B<@+@H@("`@("`@("`@("`@("`@
M("`@("<\<W!A;B!S='EL93TB8V]L;W(Z8FQU92(^)R`N"B`@("`@("`@("`@
M("`@("`@("`@<F]U;F0H)&1A>5LG=&5M<&5R871U<F5,;W<G72D@+B`G/"]S
M<&%N/CPO=&0^)SL*"B`@("`@("`@("`@("`@("`O+R!#;VYD:71I;VXN"B`@
M("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D('-T>6QE/2)B;W)D97(Z,7!X
M('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R(CXG("X*("`@("`@("`@
M("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]W96%T:&5R9&]T8V]M+S(S
M>#(S+R<@+B`H)&1A>5LG;FEG:'0G75LG8V]N9&ET:6]N26-O;B==(#T]("<M
M)R`_("=N82<@.B`D9&%Y6R=N:6=H="==6R=C;VYD:71I;VY)8V]N)UTI("X@
M)RYP;F<G+"`D;FEG:'0I("X*("`@("`@("`@("`@("`@("`@("`G/&)R("\^
M)R`N("1N:6=H="`N("<\+W1D/B<["@H@("`@("`@("`@("`@("`@+R\@4')E
M8VEP:71A=&EO;B!C:&%N8V4N"B`@("`@("`@("`@("`@("`D:'1M;"`N/2`G
M/'1D('-T>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ
M8V5N=&5R(CXG("X*("`@("`@("`@("`@("`@("`@("`D9&%Y6R=N:6=H="==
M6R=P<F5C:7!I=&%T:6]N)UT@+B`G)3PO=&0^)SL*"B`@("`@("`@("`@("`@
M("`O+R!)9B!A(&1E=&%I;&5D(&9O<F5C87-T('=A<R!R97%U97-T960L(&1I
M<W!L87D@:'5M:61I='D@86YD"B`@("`@("`@("`@("`@("`O+R!W:6YD<RX*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG9&5T
M86EL961&;W)E8V%S="==*2D@>PH*("`@("`@("`@("`@("`@("`@("`O+R!(
M=6UI9&ET>2X*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D('-T
M>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0[('1E>'0M86QI9VXZ8V5N=&5R
M(CXG("X*("`@("`@("`@("`@("`@("`@("`@("`@)&1A>5LG;FEG:'0G75LG
M:'5M:61I='DG72`N("<E/"]T9#XG.PH*("`@("`@("`@("`@("`@("`@("`O
M+R!7:6YD<RX*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2`G/'1D('-T
M>6QE/2)B;W)D97(Z,7!X('-O;&ED("-D9&0B/B<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("!?*")&<F]M('1H92`B*2`N("1D87E;)VYI9VAT)UU;)W=I
M;F1$:7)E8W1I;VXG72`N"B`@("`@("`@("`@("`@("`@("`@("`@(%\H(B!A
M="`B*2`N("1D87E;)VYI9VAT)UU;)W=I;F0G72`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("<@)R`N("1U;FET<ULG=VEN9"==.PH@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==*2`F
M)B`D9&%Y6R=N:6=H="==6R=W:6YD1W5S="==(#X@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D:'1M;"`N/2!?*"(L(&=U<W1I;F<@(BD@+B`D9&%Y
M6R=N:6=H="==6R=W:6YD1W5S="==("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<@)R`N("1U;FET<ULG=VEN9"==.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D:'1M
M;"`N/2`G/"]T<CXG.PH*("`@("`@("`@("`@("`@("\O(%!R97!A<F4@9F]R
M(&YE>'0@9&%Y+@H@("`@("`@("`@("`@("`@)&9U='5R941A>7,K*SL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D:'1M;"`N/2`G/"]T86)L93XG.PH@
M("`@("`@('T*"B`@("`@("`@+R\@1&ES<&QA>2!A(&)A<B!A="!T:&4@8F]T
M=&]M(&]F('1H92!B;&]C:R!W:71H('1H92!R97%U:7)E9`H@("`@("`@("\O
M(&%T=')I8G5T:6]N('1O('=E871H97(N8V]M(&%N9"!T:&4@;&]G;RP@8F]T
M:"!L:6YK960@=&\*("`@("`@("`O+R!W96%T:&5R+F-O;2!W:71H('1H92!P
M87)T;F5R($E$+@H@("`@("`@(')E='5R;B`D:'1M;"`N("<\9&EV(&-L87-S
M/2)R:6=H=$%L:6=N(&QI;F5D4F]W(CXG("X*("`@("`@("`@("`@7R@B5V5A
M=&AE<B!D871A('!R;W9I9&5D(&)Y(BD@+B`G("<@+@H@("`@("`@("`@("!(
M;W)D93HZ;&EN:RA(;W)D93HZ97AT97)N86Q5<FPH)VAT='`Z+R]W=W<N=V5A
M=&AE<BYC;VTO/W!R;V0]>&]A<"9A;7`[<&%R/2<@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`D=V5A=&AE<D1O=$-O;2T^7W!A<G1N97))1"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=W96%T:&5R+F-O;2<L("<G+"`G7V)L86YK
M)RP@)R<L("=W96%T:&5R+F-O;2<I("X*("`@("`@("`@("`@)SQE;3YW96%T
M:&5R+F-O;3PO96T^)G)E9SL@)R`N"B`@("`@("`@("`@($AO<F1E.CII;6<H
M)V)L;V-K+W=E871H97)D;W1C;VTO,S)X,S(O5%=#;&]G;U\S,G!X+G!N9R<L
M("=W96%T:&5R+F-O;2!L;V=O)RD@+@H@("`@("`@("`@("`G/"]A/CPO9&EV
M/B<["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]A8V-O
M=6YT+G!H<```````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`T,S<Q-2`Q,#4Q-30S-#$S-R`P,C$U,34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B1B;&]C:U]N86UE(#T@
M7R@B06-C;W5N="!);F9O<FUA=&EO;B(I.PH*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O;&EB+T)L;V-K+V%C8V]U;G0N<&AP+'8@,2XW+C(N-"`R,#`V+S`S+S$P
M(#$W.C(X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,2TR,#`V
M($5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T97AA
M<RYE9'4^"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/
M4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@
M9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N
M9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!S:6YC92`@($AO
M<F1E(#,N,0H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA<W,@2&]R
M9&5?0FQO8VM?2&]R9&5?86-C;W5N="!E>'1E;F1S($AO<F1E7T)L;V-K('L*
M"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@("\J*@H@("`@("H@5&AE
M('1I=&QE('1O(&=O(&EN('1H:7,@8FQO8VLN"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@("!4:&4@=&ET;&4@=&5X="X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W1I=&QE*"D*("`@('L*("`@("`@("!R971U<FX@7R@B37D@06-C
M;W5N="!);F9O<FUA=&EO;B(I.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE
M(&-O;G1E;G0@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!C;VYT96YT"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!G;&]B86P@)')E9VES=')Y
M+"`D8V]N9CL*"B`@("`@("`@<W=I=&-H("@D8V]N9ELG86-C;W5N=',G75LG
M9')I=F5R)UTI('L*("`@("`@("!C87-E("=N=6QL)SH*("`@("`@("`@("`@
M)&UY9')I=F5R(#T@)FYE=R!!8V-O=6YT<U]$<FEV97(H*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92`G;&]C86QH;W-T)SH*("`@("`@("!C
M87-E("=L9&%P)SH*("`@("`@("`@("`@)&-L87-S(#T@)T%C8V]U;G1S7T1R
M:79E<E\G("X@)&-O;F9;)V%C8V]U;G1S)UU;)V1R:79E<B==.PH@("`@("`@
M("`@("`D;7ED<FEV97(@/2`F;F5W("1C;&%S<R@D8V]N9ELG86-C;W5N=',G
M75LG<&%R86US)UTI.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@
M("`O+R!#:&5C:R!F;W(@<&%S<W=O<F0@<W1A='5S+@H@("`@("`@(&EF("AI
M<U]A*"1S=&%T=7,@/2`D;7ED<FEV97(M/F-H96-K4&%S<W=O<F13=&%T=7,H
M*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<W1A='5S(#T@)'-T
M871U<RT^9V5T365S<V%G92@I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7V$H)'5S97)N86UE(#T@)&UY9')I=F5R+3YG9715<V5R;F%M92@I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D=7-E<FYA;64M/F=E
M=$UE<W-A9V4H*3L*("`@("`@("!]"B`@("`@("`@)'1A8FQE(#T@87)R87DH
M7R@B3&]G:6XB*2`]/B`D=7-E<FYA;64I.PH@("`@("`@(&EF("AI<U]A*"1F
M=6QL;F%M92`]("1M>61R:79E<BT^9V5T1G5L;&YA;64H*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9U;&QN86UE+3YG971-97-S
M86=E*"D["B`@("`@("`@?2!E;'-E:68@*"1F=6QL;F%M92D@>PH@("`@("`@
M("`@("`D=&%B;&5;7R@B1G5L;"!.86UE(BE=(#T@)&9U;&QN86UE.PH@("`@
M("`@('T*("`@("`@("!I9B`H:7-?82@D:&]M92`]("1M>61R:79E<BT^9V5T
M2&]M92@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M:&]M92T^9V5T365S<V%G92@I.PH@("`@("`@('T@96QS96EF("@D:&]M92D@
M>PH@("`@("`@("`@("`D=&%B;&5;7R@B2&]M92!$:7)E8W1O<GDB*5T@/2`D
M:&]M93L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V$H)'-H96QL(#T@)&UY
M9')I=F5R+3YG9713:&5L;"@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<VAE;&PM/F=E=$UE<W-A9V4H*3L*("`@("`@("!](&5L
M<V5I9B`H)'-H96QL*2!["B`@("`@("`@("`@("1T86)L95M?*")$969A=6QT
M(%-H96QL(BE=(#T@)'-H96QL.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?
M82@D<75O=&$@/2`D;7ED<FEV97(M/F=E=%%U;W1A*"DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1Q=6]T82T^9V5T365S<V%G92@I
M.PH@("`@("`@('T@96QS96EF("@D<75O=&$I('L*("`@("`@("`@("`@)'1A
M8FQE6U\H(E%U;W1A(BE=(#T@<W!R:6YT9BA?*"(E+C)F34(@=7-E9"!O9B`E
M+C)F34(@86QL;W=E9"`H)2XR9B4E*2(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1Q=6]T85LG=7-E9"==("\@*"`Q,#(T
M("H@,3`R-"XP*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<75O=&%;)VQI;6ET)UT@+R`H(#$P,C0@*B`Q,#(T+C`I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D<75O
M=&%;)W5S960G72`J(#$P,"XP*2`O("1Q=6]T85LG;&EM:70G72D["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<U]A*"1L87-T8VAA;F=E(#T@)&UY9')I=F5R
M+3YG971087-S=V]R9$-H86YG92@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&%S=&-H86YG92T^9V5T365S<V%G92@I.PH@("`@
M("`@('T@96QS96EF("@D;&%S=&-H86YG92D@>PH@("`@("`@("`@("`D=&%B
M;&5;7R@B3&%S="!087-S=V]R9"!#:&%N9V4B*5T@/2`D;&%S=&-H86YG93L*
M("`@("`@("!]"@H@("`@("`@("1O=71P=70@/2`G/'1A8FQE(&-L87-S/2)I
M=&5M(B!W:61T:#TB,3`P)2(@8V5L;'-P86-I;F<](C$B/B<["@H@("`@("`@
M(&EF("@A96UP='DH)'-T871U<RDI('L*("`@("`@("`@("`@)&]U='!U="`N
M/2`G/'1R/CQT9"!C;VQS<&%N/2(R(CX\<"!C;&%S<STB;F]T:6-E(CXG("X*
M("`@("`@("`@("`@("`@($AO<F1E.CII;6<H)V%L97)T<R]W87)N:6YG+G!N
M9R<L(%\H(E=A<FYI;F<B*2D@+@H@("`@("`@("`@("`@("`@)R9N8G-P.R9N
M8G-P.R<@+B`D<W1A='5S("X@)SPO<#X\+W1D/CPO='(^)SL*("`@("`@("!]
M"@H@("`@("`@(&9O<F5A8V@@*"1T86)L92!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("`D;W5T<'5T("X]("(\='(@8VQA<W,]7")T97AT7"(^
M/'1D/B1K97D\+W1D/CQT9#XD=F%L=64\+W1D/CPO='(^7&XB.PH@("`@("`@
M('T*("`@("`@("`D;W5T<'5T("X]("(\+W1A8FQE/EQN(CL*"B`@("`@("`@
M:68@*"1R96=I<W1R>2T^9V5T*"=S=&%T=7,G+"`G9F]R=V%R9',G*2`A/2`G
M:6YA8W1I=F4G("8F"B`@("`@("`@("`@("1R96=I<W1R>2T^:&%S365T:&]D
M*"=S=6UM87)Y)RP@)V9O<G=A<F1S)RDI('L*("`@("`@("`@("`@)'-U;6UA
M<GD@/2`D<F5G:7-T<GDM/F-A;&Q">5!A8VMA9V4H)V9O<G=A<F1S)RP@)W-U
M;6UA<GDG*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1S=6UM87)Y+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("<\8G(@
M+SXG("X@)'-U;6UA<GD@+B`B7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&EF("@D<F5G:7-T<GDM/F=E="@G<W1A='5S)RP@)W9A8V%T
M:6]N)RD@(3T@)VEN86-T:79E)R`F)@H@("`@("`@("`@("`D<F5G:7-T<GDM
M/FAA<TUE=&AO9"@G<W5M;6%R>2<L("=V86-A=&EO;B<I*2!["B`@("`@("`@
M("`@("1S=6UM87)Y(#T@)')E9VES=')Y+3YC86QL0GE086-K86=E*"=V86-A
M=&EO;B<L("=S=6UM87)Y)RD["B`@("`@("`@("`@(&EF("@A:7-?82@D<W5M
M;6%R>2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2`G/&)R("\^)R`N("1S=6UM87)Y("X@(EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1O=71P=70["B`@("!]"@I]
M"@HO*BH*("H@06-C;W5N='-?1')I=F5R.CH@9&5F:6YE<R!A;B!!4$D@9F]R
M(&=E='1I;F<O9&ES<&QA>6EN9R!A8V-O=6YT(&EN9F]R;6%T:6]N"B`J(&9O
M<B!A('5S97(@9F]R('1H92!A8V-O=6YT<R!M;V1U;&4N"B`J"B`J($-O<'ER
M:6=H="`R,#`Q+3(P,#8@17)I8R!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R
M0'!H>7-I8W,N=71E>&%S+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E='1E<D!P:'ES:6-S+G5T
M97AA<RYE9'4^"B`J($!S:6YC92`@($AO<F1E(#,N,0H@*B!`<&%C:V%G92!(
M;W)D95]";&]C:PH@*B\*8VQA<W,@06-C;W5N='-?1')I=F5R('L*"B`@("`O
M*BH*("`@("`J($5R<F]R('-T<FEN9R!R971U<FYE9"!T;R!U<V5R(&EF(&%N
M(&5R<F]R(&]C8W5R<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)&5R<E]S='(["@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!U<V5R;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M5&AE(&QO=V5R8V%S960@=7-E<FYA;64N"B`@("`@*@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9715<V5R;F%M92@I"B`@("!["B`@("`@("`@)&%U=&@@/2!E
M>'!L;V1E*"=`)RP@075T:#HZ9V5T075T:"@I*3L*("`@("`@("!R971U<FX@
M4W1R:6YG.CIL;W=E<B@D875T:%LP72D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!U<V5R(')E86QM+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@=7-E<B!R96%L;2X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F5A;&TH*0H@("`@>PH@("`@("`@("1A=71H(#T@97AP;&]D92@G
M0"<L($%U=&@Z.F=E=$%U=&@H*2D["B`@("`@("`@<F5T=7)N(&ES<V5T*"1A
M=71H6S%=*2`_("1A=71H6S%=(#H@)R<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!U<V5R)W,@<75O=&$@:68@879A:6QA8FQE+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($$@<75O=&$@87)R87DL(&5L96UE
M;G1S(&%R92!U<V5D(&)Y=&5S(&%N9"!L:6UI="!B>71E<R!O;@H@("`@("H@
M("`@("`@("`@("`@("`@<W5C8V5S<RP@9F%L<V4@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T475O=&$H*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('5S97(G<R!F=6QL(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@5&AE('5S97(G<R!F=6QL(&YA;64@*'-T<FEN9RDL(&]R(&9A;'-E("AE
M<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9U;&QN86UE*"D*("`@
M('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('1H92!U<V5R)W,@:&]M92`H;&]G:6XI(&1I<F5C=&]R>2X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S(&1I<F5C
M=&]R>2`H<W1R:6YG*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T2&]M92@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&1E
M9F%U;'0@<VAE;&PN"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE
M('5S97(G<R!S:&5L;"`H<W1R:6YG*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4VAE;&PH*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(&1A=&4@;V8@=&AE('5S97(G<R!L87-T('!A<W-W;W)D(&-H86YG92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$871E('-T<FEN9R`H<W1R:6YG
M*2!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710
M87-S=V]R9$-H86YG92@I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W1A='5S(&]F('1H
M92!C=7)R96YT('!A<W-W;W)D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX
M960@($$@<W1R:6YG('=I=&@@82!W87)N:6YG(&UE<W-A9V4@:68@=&AE('!A
M<W-W;W)D(&ES(&%B;W5T"B`@("`@*B`@("`@("`@("`@("`@("!T;R!E>'!I
M<F4L(%!%05)?17)R;W(@;VX@97)R;W(@86YD(&9A;'-E(&]T:&5R=VES92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8VAE8VM087-S=V]R9%-T871U<R@I"B`@
M("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*?0H*+RHJ"B`J($EM
M<&QE;65N=',@=&AE($%C8V]U;G1S($%022!F;W(@<V5R=F5R<R!W:71H('5N
M:7@@86-C;W5N=',@;VX@=&AE(&QO8V%L:&]S=`H@*B!M86-H:6YE("AS86UE
M(&UA8VAI;F4@87,@=&AE('=E8B!S97)V97(I+B`@4VAO=6QD('=O<FL@9F]R
M(&QO8V%L('5N:7@*("H@86-C;W5N=',L(&YI<R]N:7,K(&%C8V]U;G1S+"!O
M<B!A;GD@4$%-(&]R:65N=&5D(&%C8V]U;G1S('1H870@87!P96%R(&%S"B`J
M(&QO8V%L(&%C8V]U;G1S(&]N('1H92!L;V-A;"!M86-H:6YE+B`@5&AE(&5X
M8V5P=&EO;B!I<R!T:&4@<75O=&$@<W5P<&]R="X*("H@4V5E('1H870@<F]U
M=&EN92!F;W(@861D:71I;VYA;"!C;VUM96YT<RX*("H*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!%<FEC($IO;B!2;W-T971T97(@/&5R:6,N<F]S=&5T=&5R
M0'!H>7-I8W,N=71E>&%S+F5D=3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1T=&5R0'!H>7-I8W,N=71E
M>&%S+F5D=3X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E($AO
M<F1E7T)L;V-K"B`J+PIC;&%S<R!!8V-O=6YT<U]$<FEV97)?;&]C86QH;W-T
M(&5X=&5N9',@06-C;W5N='-?1')I=F5R('L*"B`@("`O*BH*("`@("`J($AA
M<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'!A<F%M<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@2&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J+PH@("`@9G5N8W1I;VX@06-C
M;W5N='-?1')I=F5R7VQO8V%L:&]S="@D<&%R86US(#T@87)R87DH*2D*("`@
M('L*("`@("`@("`D=&AI<RT^<&%R86US(#T@)'!A<F%M<SL*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3YP87)A;7-;)W%U;W1A7W!A=&@G72DI('L*("`@
M("`@("`@("`@)'1H:7,M/G!A<F%M<ULG<75O=&%?<&%T:"==(#T@)W%U;W1A
M)SL*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^<&%R86US
M6R=G<F5P7W!A=&@G72DI('L*("`@("`@("`@("`@)'1H:7,M/G!A<F%M<ULG
M9W)E<%]P871H)UT@/2`G9W)E<"<["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B!A8V-O=6YT(&9R;VT@=&AE('!O
M<VEX(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@
M($$@:&%S:"!W:71H(&-O;7!L971E(&%C8V]U;G0@9&5T86EL<RX*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V=E=$%C8V]U;G0H*0H@("`@>PH@("`@("`@('-T
M871I8R`D:6YF;W)M871I;VX["@H@("`@("`@(&EF("@A:7-S970H)&EN9F]R
M;6%T:6]N*2D@>PH@("`@("`@("`@("`O+R!T:&ES('=O;B=T('=O<FL@:68@
M=V4@9&]N)W0@:&%V92!P;W-I>"!E>'1E;G-I;VYS"B`@("`@("`@("`@(&EF
M("@A571I;#HZ97AT96YS:6]N17AI<W1S*"=P;W-I>"<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")03U-)6"!E>'1E
M;G-I;VX@:7,@;6ES<VEN9R(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'5S97(@/2!3=')I;F<Z.FQO=V5R*"1T:&ES+3YG9715<V5R;F%M92@I
M*3L*("`@("`@("`@("`@)&EN9F]R;6%T:6]N(#T@<&]S:7A?9V5T<'=N86TH
M)'5S97(I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO
M;CL*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE;65N="!T:&4@475O=&$@
M05!)(&9O<B!)34%0('-E<G9E<G,@=VET:"!A('5N:7@@<75O=&$@8V]M;6%N
M9"X*("`@("`J(%1H:7,@;6%Y(')E<75I<F4@82!M;V1I9FEE9"`B<75O=&$B
M(&-O;6UA;F0@=&AA="!A;&QO=W,@=&AE(&AT='!D"B`@("`@*B!S97)V97(@
M86-C;W5N="!T;R!G970@<75O=&%S(&9O<B!O=&AE<B!U<V5R<RXN+B`@270@
M<F5Q=6ER97,@=&AA="!Y;W5R"B`@("`@*B!W96(@<V5R=F5R(&%N9"!U<V5R
M('-E<G9E<B!B92!T:&4@<V%M92!S97)V97(@;W(@870@;&5A<W0@:&%V92!S
M:&%R960*("`@("`J(&%U=&AE;G1I8V%T:6]N(&%N9"!F:6QE('-E<G9E<G,@
M*&4N9RX@=FEA($Y)4R].1E,I+B`@06YD(&QA<W0L(&ET("AA<PH@("`@("H@
M=W)I='1E;BD@<F5Q=6ER97,@=&AE('!O<VEX('!H<"!E>'1E;G-I;VYS+@H@
M("`@("H*("`@("`J($EF('EO=7(@<75O=&$@8V]M;6%N9"!W<F%P<R!T:&4@
M;W5T<'5T(&]N=&\@='=O(&QI;F5S+"!T:&5N('1H:7,@;6]D=6QE"B`@("`@
M*B!W:6QL(&]N;'D@=V]R:R!I9B!Y;W4@:&%V92!A(&=R97`@=VAI8V@@<W5P
M<&]R=',@=&AE("U!('-W:71C:"P@86YD('EO=0H@("`@("H@87!P96YD(&%N
M("U!,2!S=VET8V@@=&\@>6]U<B!G<F5P7W!A=&@@*&4N9RX@)R]B:6XO9W)E
M<"`M03$G*2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@<75O
M=&$@:&%S:"`H8GET97,@=7-E9"P@;&EM:70I(&]R(&9A;'-E(&9O<B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T475O=&$H*0H@("`@>PH@("`@
M("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@
M("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*"B`@
M("`@("`@)&AO;65D:7(@/2`D:6YF;W)M871I;VY;)V1I<B==.PH*("`@("`@
M("`O+R!)9B!W92!W86YT(&UO=6YT('!O:6YT('1R86YS;&%T:6]N<RP@=&AE
M;B!T<F%N<VQA=&4@=&AE(&QO9VEN(&1I<@H@("`@("`@("\O(&YA;64@=&\@
M82!M;W5N="!P;VEN="X@($EF(&YO="P@=&AE;B!S:6UP;'D@<&%R<V4@;W5T
M('1H92!D979I8V4*("`@("`@("`O+R!N86UE(&9R;VT@=&AE(&QO9VEN(&1I
M<F5C=&]R>2P@86YD('5S92!T:&%T(&EN<W1E860N"B`@("`@("`@:68@*"1T
M:&ES+3YP87)A;7-;)W1R86YS;&%T94UO=6YT4&]I;G0G72`F)@H@("`@("`@
M("`@("!F:6QE7V5X:7-T<R@D=&AI<RT^<&%R86US6R=T<F%N<VQA=&EO;E1A
M8FQE)UTI*0H@("`@("`@('L*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=&
M:6QE+T9S=&%B+G!H<"<["B`@("`@("`@("`@("1S>7-486(@/2!&:6QE7T9S
M=&%B.CIS:6YG;&5T;VXH)'1H:7,M/G!A<F%M<ULG=')A;G-L871I;VY486)L
M92==*3L*("`@("`@("`@("`@9&\@>PH@("`@("`@("`@("`@("`D96YT<GD@
M/2`F)'-Y<U1A8BT^9V5T16YT<GE&;W)0871H*"1H;VUE9&ER*3L*("`@("`@
M("`@("`@("`@)&AO;65D:7(@/2!D:7)N86UE*"1H;VUE9&ER*3L*("`@("`@
M("`@("`@("`@:68@*"1H;VUE9&ER(#T]("<N)R!\?"!E;7!T>2@D:&]M961I
M<BDI('L*("`@("`@("`@("`@("`@("`@("1H;VUE9&ER(#T@)R\G.PH@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@=VAI;&4@*&ES7V$H)&5N=')Y
M+"`G4$5!4E]%<G)O<B<I*3L*("`@("`@("`@("`@)&UO=6YT4&]I;G0@/2`D
M96YT<GDM/F1E=FEC93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("1H
M;VUE9&ER(#T@97AP;&]D92@G+R<L("1H;VUE9&ER*3L*("`@("`@("`@("`D
M;6]U;G10;VEN="`]("<O)R`N("1H;VUE9&ER6S%=.PH@("`@("`@('T*"B`@
M("`@("`@)&-M9&QI;F4@/2!S<')I;G1F*"<E<R`M=2`E<R`R/B8Q('P@)7,@
M)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&%R86US
M6R=Q=6]T85]P871H)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG9715<V5R3F%M92@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<&%R86US6R=G<F5P7W!A=&@G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&UO=6YT4&]I;G0I.PH@("`@("`@("1J=6YK(#T@97AE
M8R@D8VUD;&EN92P@)'%U;W1A7V1A=&$L("1R971U<FY?8V]D92D["B`@("`@
M("`@:68@*"1R971U<FY?8V]D92`]/2`P("8F("%E;7!T>2@D<75O=&%?9&%T
M85LP72DI('L*("`@("`@("`@("`O+R!);B!C87-E(&]F('%U;W1A(&]U='!U
M="!W<F%P<&EN9R!O;B!T=V\@;&EN97,L('=E(&-O;F-A="!T:&4*("`@("`@
M("`@("`O+R!S96-O;F0@;&EN92!O9B!R97-U;'1S+"!I9B!A;GDL(&AE<F4N
M"B`@("`@("`@("`@:68@*"%E;7!T>2@D<75O=&%?9&%T85LQ72DI('L*("`@
M("`@("`@("`@("`@)'%U;W1A7V1A=&%;,%T@+CT@)'%U;W1A7V1A=&%;,5T[
M"B`@("`@("`@("`@?0H@("`@("`@("`@("\O($YO=R!P87)S92!O=70@=&AE
M('%U;W1A(&EN9F\@86YD(')E='5R;B!I="X*("`@("`@("`@("`D<75O=&$@
M/2!P<F5G7W-P;&ET*"<O7',K+R<L('1R:6TH)'%U;W1A7V1A=&%;,%TI*3L*
M("`@("`@("`@("!R971U<FX@87)R87DH)W5S960G(#T^("1Q=6]T85LQ72`J
M(#$P,C0L("=L:6UI="<@/3X@)'%U;W1A6S)=("H@,3`R-"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('5S97(G<R!F=6QL(&YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5&AE('5S97(G<R!F=6QL(&YA;64@*'-T<FEN9RDL
M(&]R(&9A;'-E("AE<G)O<BDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9U
M;&QN86UE*"D*("`@('L*("`@("`@("`D:6YF;W)M871I;VX@/2`D=&AI<RT^
M7V=E=$%C8V]U;G0H*3L*("`@("`@("!I9B`H:7-?82@D:6YF;W)M871I;VXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O<FUA
M=&EO;CL*("`@("`@("!]"B`@("`@("`@)&=E8V]S7V%R<F%Y(#T@97AP;&]D
M92@G+"<L("1I;F9O<FUA=&EO;ELG9V5C;W,G72D["B`@("`@("`@<F5T=7)N
M("1G96-O<U]A<G)A>5LP73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('5S97(G<R!H;VUE("AL;V=I;BD@9&ER96-T;W)Y+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1H92!U<V5R)W,@9&ER96-T;W)Y("AS
M=')I;F<I+"!O<B!F86QS92`H97)R;W(I+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971(;VUE*"D*("`@('L*("`@("`@("`D:6YF;W)M871I;VX@/2`D=&AI
M<RT^7V=E=$%C8V]U;G0H*3L*("`@("`@("!I9B`H:7-?82@D:6YF;W)M871I
M;VXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1I;F9O
M<FUA=&EO;CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO
M;ELG9&ER)UT["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!U
M<V5R)W,@9&5F875L="!S:&5L;"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!4:&4@=7-E<B=S('-H96QL("AS=')I;F<I+"!O<B!F86QS92`H97)R
M;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9713:&5L;"@I"B`@("!["B`@
M("`@("`@)&EN9F]R;6%T:6]N(#T@)'1H:7,M/E]G971!8V-O=6YT*"D["B`@
M("`@("`@:68@*&ES7V$H)&EN9F]R;6%T:6]N+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D:6YF;W)M871I;VX["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D:6YF;W)M871I;VY;)W-H96QL)UT["B`@("!]"@I]
M"@HO*BH*("H@5&AE(&QD87`@8VQA<W,@871T96UP=',@=&\@<F5T=7)N('5S
M97(@:6YF;W)M871I;VX@<W1O<F5D(&EN(&%N(&QD87`*("H@9&ER96-T;W)Y
M('-E<G9I8V4N"B`J"B`J($-O<'ER:6=H="`R,#`Q+3(P,#8@17)I8R!2;W-T
M971T97(@/&5R:6,N<F]S=&5T=&5R0'!H>7-I8W,N=71E>&%S+F5D=3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($5R:6,@2F]N(%)O<W1E='1E<B`\
M97)I8RYR;W-T971T97)`<&AY<VEC<RYU=&5X87,N961U/@H@*B!`<VEN8V4@
M("!(;W)D92`S+C$*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S
M($%C8V]U;G1S7T1R:79E<E]L9&%P(&5X=&5N9',@06-C;W5N='-?1')I=F5R
M('L*"B`@("`O*BH*("`@("`J(%!O:6YT97(@=&\@=&AE(&QD87`@8V]N;F5C
M=&EO;BX*("`@("`J"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@
M('9A<B`D7V1S.PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&-O
M;FYE8W1I;VX@<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y
M"B`@("`@*B\*("`@('9A<B`D7W!A<F%M<SL*"B`@("`O*BH*("`@("`J($-O
M;G-T<G5C=',@82!N97<@06-C;W5N='-?1')I=F5R7VQD87`@;V)J96-T+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@8V]N
M=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N($%C8V]U;G1S7T1R:79E<E]L9&%P*"1P87)A;7,@/2!A<G)A>2@I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87E?;65R9V4H
M"B`@("`@("`@("`@(&%R<F%Y*"=H;W-T)R`]/B`G;&]C86QH;W-T)RP*("`@
M("`@("`@("`@("`@("`@)W!O<G0G(#T^(#,X.2P*("`@("`@("`@("`@("`@
M("`@)V)A<V5D;B<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("=A='1R)R`]
M/B`G=6ED)RP*("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("<S)RDL
M"B`@("`@("`@("`@("1P87)A;7,I.PH@("`@?0H*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('5S97(@86-C;W5N="!F<F]M('1H92!L9&%P('-O=7)C
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&AA<V@@=VET:"!C
M;VUP;&5T92!A8V-O=6YT(&1E=&%I;',N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]G971!8V-O=6YT*"D*("`@('L*("`@("`@("!S=&%T:6,@)&EN9F]R;6%T
M:6]N.PH*("`@("`@("!I9B`H(6ES<V5T*"1I;F9O<FUA=&EO;BDI('L*("`@
M("`@("`@("`@)'5S97)N86UE("`]("1T:&ES+3YG9715<V5R;F%M92@I.PH*
M("`@("`@("`@("`@+R\@8V]N;F5C="!T;R!T:&4@;&1A<"!S97)V97(*("`@
M("`@("`@("`@)'1H:7,M/E]D<R`](&QD87!?8V]N;F5C="@D=&AI<RT^7W!A
M<F%M<ULG:&]S="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%R86US6R=P;W)T)UTI.PH@("`@("`@("`@("!I
M9B`H(21T:&ES+3Y?9',I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*%\H(D-O=6QD(&YO="!C;VYN96-T('1O($Q$05`@<V5R
M=F5R+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P87)A;7-;)W9E<G-I;VXG72DI('L*("`@("`@("`@("`@("`@
M(&EF("@A;&1A<%]S971?;W!T:6]N*"1T:&ES+3Y?9',L($Q$05!?3U!47U!2
M3U1/0T],7U9%4E-)3TXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F5R<VEO;B==*2D@>PH@("`@("`@
M("`@("`@("`@("`@($AO<F1E.CIL;V=-97-S86=E*'-P<FEN=&8H)U-E="!,
M1$%0('!R;W1O8V]L('9E<G-I;VX@=&\@)60@9F%I;&5D.B!;)61=("5S)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%R86US6R=V97)S:6]N)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!L9&%P7V5R<FYO*"1C;VYN
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&QD87!?97)R;W(H)&-O;FXI*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("\O(&)I;F0@87,@86YO;GEM;W5S"B`@("`@("`@("`@("1R97-U;'0@/2!`
M;&1A<%]B:6YD*"1T:&ES+3Y?9',I.PH@("`@("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*%\H(D-O=6QD(&YO="!B:6YD('1O($Q$05`@<V5R=F5R+B(I*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@1V5T('1H92!F=6QL;F%M90H@("`@
M("`@("`@("`D<V5A<F-H4F5S=6QT(#T@;&1A<%]S96%R8V@H)'1H:7,M/E]D
M<RP@)'1H:7,M/E]P87)A;7-;)V)A<V5D;B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V%T='(G
M72`N("<])R`N("1U<V5R;F%M92D["B`@("`@("`@("`@("1I;F9O<FUA=&EO
M;B`](&QD87!?9V5T7V5N=')I97,H)'1H:7,M/E]D<RP@)'-E87)C:%)E<W5L
M="D["@H@("`@("`@("`@("`O+R!D:7-C;VYN96-T(&9R;VT@=&AE(&QD87`@
M<V5R=F5R"B`@("`@("`@("`@($!L9&%P7V-L;W-E*"1T:&ES+3Y?9',I.PH*
M("`@("`@("`@("`@:68@*"1I;F9O<FUA=&EO;ELG8V]U;G0G72`]/2`P*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5
M<V5R(&%C8V]U;G0@;F]T(&9O=6YD(BDI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=7-E<B=S(&9U;&P@;F%M92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4:&4@=7-E<B=S(&9U;&P@;F%M
M92`H<W1R:6YG*2P@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1G5L;&YA;64H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO
M;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I
M;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1I;F9O<FUA=&EO;ELP75LG8VX[;&%N9RUE<R==6S!=*2`F)@H@("`@("`@
M("`@("`D:6YF;W)M871I;VY;,%U;)V-N.VQA;F<M97,G75LP72`A/2`G)RD@
M>PH@("`@("`@("`@("`D;F%M92`]("1I;F9O<FUA=&EO;ELP75LG8VX[;&%N
M9RUE<R==6S!=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N86UE
M(#T@)&EN9F]R;6%T:6]N6S!=6R=C;B==6S!=.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("AE;7!T>2@D;F%M92D@/R!F86QS92`Z("1N86UE*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('5S97(G<R!H;VUE("AL
M;V=I;BD@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1H92!U<V5R)W,@9&ER96-T;W)Y("AS=')I;F<I+"!O<B!F86QS92`H97)R
M;W(I+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971(;VUE*"D*("`@('L*("`@
M("`@("`D:6YF;W)M871I;VX@/2`D=&AI<RT^7V=E=$%C8V]U;G0H*3L*("`@
M("`@("!I9B`H:7-?82@D:6YF;W)M871I;VXL("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1I;F9O<FUA=&EO;CL*("`@("`@("!]"B`@
M("`@("`@)&AO;65D:7(@/2`D:6YF;W)M871I;VY;,%U;)VAO;65D:7)E8W1O
M<GDG75LP73L*("`@("`@("!R971U<FX@*&5M<'1Y*"1H;VUE9&ER*2`_(&9A
M;'-E(#H@)&AO;65D:7(I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@=7-E<B=S(&1E9F%U;'0@<VAE;&PN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5&AE('5S97(G<R!S:&5L;"`H<W1R:6YG*2P@;W(@9F%L
M<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAE;&PH*0H@
M("`@>PH@("`@("`@("1I;F9O<FUA=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N
M="@I.PH@("`@("`@(&EF("AI<U]A*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN9F]R;6%T:6]N.PH@("`@
M("`@('T*("`@("`@("`D<VAE;&P@/2`D:6YF;W)M871I;VY;,%U;)VQO9VEN
M<VAE;&PG75LP73L*("`@("`@("!R971U<FX@*&5M<'1Y*"1S:&5L;"D@/R!F
M86QS92`Z("1S:&5L;"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!D871E(&]F('1H92!U<V5R)W,@;&%S="!P87-S=V]R9"!C:&%N9V4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1&%T92!S=')I;F<@*'-T
M<FEN9RD@;W(@9F%L<V4@*&5R<F]R*2X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&%S<W=O<F1#:&%N9V4H*0H@("`@>PH@("`@("`@("1I;F9O<FUA=&EO
M;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A*"1I
M;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T
M*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=*2D@>PH@
M("`@("`@("`@("`D;&%S=&-H86YG92`]('-T<F9T:6UE*"<E>"<L("1I;F9O
M<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=("H@.#8T,#`I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("AE;7!T>2@D;&%S=&-H86YG92D@
M/R!F86QS92`Z("1L87-T8VAA;F=E*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('-T871U<R!O9B!T:&4@8W5R<F5N="!P87-S=V]R9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!('-T<FEN9R!W:71H(&$@
M=V%R;FEN9R!M97-S86=E(&EF('1H92!P87-S=V]R9"!I<R!A8F]U=`H@("`@
M("H@("`@("`@("`@("`@("`@=&\@97AP:7)E+"!014%27T5R<F]R(&]N(&5R
M<F]R(&%N9"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-H96-K4&%S<W=O<F13=&%T=7,H*0H@("`@>PH@("`@("`@("1I;F9O<FUA
M=&EO;B`]("1T:&ES+3Y?9V5T06-C;W5N="@I.PH@("`@("`@(&EF("AI<U]A
M*"1I;F9O<FUA=&EO;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&EN9F]R;6%T:6]N.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;6%X)UU;,%TI("8F"B`@("`@
M("`@("`@(&ES<V5T*"1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG
M92==6S!=*2`F)@H@("`@("`@("`@("!I<W-E="@D:6YF;W)M871I;VY;,%U;
M)W-H861O=W=A<FYI;F<G75LP72DI('L*("`@("`@("`@("`@)'1O9&%Y(#T@
M9FQO;W(H=&EM92@I("\@.#8T,#`I.PH@("`@("`@("`@("`D=V%R;F1A>2`]
M("1I;F9O<FUA=&EO;ELP75LG<VAA9&]W;&%S=&-H86YG92==6S!=("L*("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;W)M871I;VY;,%U;)W-H861O=VUA
M>"==6S!=("T@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=W87)N:6YG)UU;,%T[
M"B`@("`@("`@("`@("1T;V5X<&ER92`]("1I;F9O<FUA=&EO;ELP75LG<VAA
M9&]W;&%S=&-H86YG92==6S!=("L@)&EN9F]R;6%T:6]N6S!=6R=S:&%D;W=M
M87@G75LP72`M("1T;V1A>3L*"B`@("`@("`@("`@(&EF("@D=&]D87D@/CT@
M)'=A<FYD87DI('L*("`@("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*%\H
M(B5D(&1A>7,@=6YT:6P@>6]U<B!P87-S=V]R9"!E>'!I<F5S+B(I+"`D=&]E
M>'!I<F4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K+V=O;V=L
M92YP:'``````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`S-C$S(#$P-3$U-#,T,3,W(#`R,3,R-@`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`H*)&)L;V-K7VYA;64@/2!?
M*")';V]G;&4@4V5A<F-H(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O
M0FQO8VLO9V]O9VQE+G!H<"QV(#$N,3`N,3`N,2`R,#`U+S$P+S$X(#$Q.C,S
M.C,Y(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*
M8VQA<W,@2&]R9&5?0FQO8VM?2&]R9&5?9V]O9VQE(&5X=&5N9',@2&]R9&5?
M0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@+RHJ"B`@
M("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?
M*")';V]G;&4@4V5A<F-H(BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@
M8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@("1H=&UL("`]("<\9F]R;2!N
M86UE/2)G;V]G;&4B(&]N<W5B;6ET/2)O<&5N7V=O;V=L95]W:6XH*3L@<F5T
M=7)N(&9A;'-E.R(^)SL*("`@("`@("`D:'1M;"`N/2`G/'1A8FQE('=I9'1H
M/2(Q,#`E(B!H96EG:'0](C$P,"4B/B<["B`@("`@("`@)&AT;6P@+CT@)SQT
M<CX\<V-R:7!T('1Y<&4](G1E>'0O:F%V87-C<FEP="(@<W)C/2(G("X@)$=,
M3T)!3%-;)W)E9VES=')Y)UTM/F=E="@G=V5B<F]O="<L("=H;W)D92<I("X@
M)R]S97)V:6-E<R]J879A<V-R:7!T+G!H<#]F:6QE/6]P96Y?9V]O9VQE7W=I
M;BYJ<R9A;7`[87!P/6AO<F1E(CX\+W-C<FEP=#XG.PH@("`@("`@("1H=&UL
M("X]("<\=&0^)R`N($AO<F1E.CII;6<H)V=O;V=L92YP;F<G+"`G1V]O9VQE
M)RD@+B`G/"]T9#X\+W1R/B<["B`@("`@("`@)&AT;6P@+CT@)SQT<CX\=&0^
M/&EN<'5T(&UA>$QE;F=T:#TB,C4V(B!S:7IE/2(T,"(@;F%M93TB<2(@=VED
M=&@](C$P,"4B("\^/"]T9#X\+W1R/B<["B`@("`@("`@)&AT;6P@+CT@)SQT
M<CX\=&0^/'1A8FQE('=I9'1H/2(Q,#`E(CX\='(^/'1D(&%L:6=N/2)C96YT
M97(B/CQI;G!U="!T>7!E/2)R861I;R(@;F%M93TB87)E82(@=F%L=64](G=E
M8B(@=VED=&@](C(P)2(@8VAE8VME9#TB8VAE8VME9"(@+SXG("X@7R@B5V5B
M(BD@+B`G/"]T9#XG.PH@("`@("`@("1H=&UL("X]("<\=&0@86QI9VX](F-E
M;G1E<B(^/&EN<'5T('1Y<&4](G)A9&EO(B!N86UE/2)A<F5A(B!V86QU93TB
M:6UA9V5S(B!W:61T:#TB,C`E(B`O/B<@+B!?*"));6%G97,B*2`N("<\+W1D
M/B<["B`@("`@("`@)&AT;6P@+CT@)SQT9"!A;&EG;CTB8V5N=&5R(CX\:6YP
M=70@='EP93TB<F%D:6\B(&YA;64](F%R96$B('9A;'5E/2)G<F]U<',B('=I
M9'1H/2(R,"4B("\^)R`N(%\H(D=R;W5P<R(I("X@)SPO=&0^)SL*("`@("`@
M("`D:'1M;"`N/2`G/'1D(&%L:6=N/2)C96YT97(B/CQI;G!U="!T>7!E/2)R
M861I;R(@;F%M93TB87)E82(@=F%L=64](F1I<F5C=&]R>2(@=VED=&@](C(P
M)2(@+SXG("X@7R@B1&ER96-T;W)Y(BD@+B`G/"]T9#XG.PH@("`@("`@("1H
M=&UL("X]("<\=&0@86QI9VX](F-E;G1E<B(^/&EN<'5T('1Y<&4](G)A9&EO
M(B!N86UE/2)A<F5A(B!V86QU93TB;F5W<R(@=VED=&@](C(P)2(@+SXG("X@
M7R@B3F5W<R(I("X@)SPO=&0^/"]T<CX\+W1A8FQE/CPO=&0^/"]T<CXG.PH@
M("`@("`@("1H=&UL("X]("<\='(^/'1D/CQI;G!U="!T>7!E/2)S=6)M:70B
M(&-L87-S/2)B=71T;VXB('9A;'5E/2(G("X@7R@B1V]O9VQE(%-E87)C:"(I
M("X@)R(@+SX\+W1D/CPO='(^)SL*("`@("`@("`D:'1M;"`N/2`G/"]T86)L
M93XG.PH@("`@("`@("1H=&UL("X]("<\+V9O<FT^)SL*("`@("`@("!R971U
M<FX@)&AT;6P["B`@("!]"@I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]S=6YR:7-E+G!H
M<```````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,38U
M-2`Q,#4Q-30S-#$S-R`P,C$U-#<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B1B;&]C:U]N86UE(#T@7R@B4W5N
M<FES92]3=6YS970B*3L*"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C
M:R]S=6YR:7-E+G!H<"QV(#$N,30N,3`N,R`R,#`U+S$P+S$X(#$Q.C,S.C,Y
M(&IA;B!%>'`@)`H@*@H@*B!`<&%C:V%G92!(;W)D95]";&]C:PH@*B\*8VQA
M<W,@2&]R9&5?0FQO8VM?2&]R9&5?<W5N<FES92!E>'1E;F1S($AO<F1E7T)L
M;V-K('L*"B`@("!V87(@)%]A<'`@/2`G:&]R9&4G.PH*("`@(&9U;F-T:6]N
M(%]T:71L92@I"B`@("!["B`@("`@("`@<F5T=7)N(%\H(E-U;G)I<V4O4W5N
M<V5T(BD["B`@("!]"@H@("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@
M("`@("`@)'!A<F%M<R`](&%R<F%Y*"=L;V-A=&EO;B<@/3X@87)R87DH)W1Y
M<&4G(#T^("=M;&5N=6TG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*"),;V-A=&EO;B(I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D969A
M=6QT)R`]/B`G-3$N-3$W.BTP+C$Q-R<I*3L*"B`@("`@("`@9VQO8F%L("1C
M;V]R9&EN871E<SL*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C;V]R9&EN871E
M<RDI('L*("`@("`@("`@("`@0&EN8VQU9&4@)TAO<F1E+TY,4R]C;V]R9&EN
M871E<RYP:'`G.PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C;V]R9&EN
M871E<RDI('L*("`@("`@("`@("`@("`@("1C;V]R9&EN871E<R`](&%R<F%Y
M*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)'!A<F%M<ULG
M;&]C871I;VXG75LG=F%L=65S)UT@/2`D8V]O<F1I;F%T97,["@H@("`@("`@
M(')E='5R;B`D<&%R86US.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C;VYT96YT
M*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)VQO
M8V%T:6]N)UTI*2!["B`@("`@("`@("`@(')E='5R;B!?*").;R!L;V-A=&EO
M;B!I<R!S970N(BD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@=&AE('1I
M;65Z;VYE('9A<FEA8FQE+"!I9B!A=F%I;&%B;&4N"B`@("`@("`@3DQ3.CIS
M9714:6UE6F]N92@I.PH*("`@("`@("!L:7-T*"1L870L("1L;VYG*2`](&5X
M<&QO9&4H)SHG+"`D=&AI<RT^7W!A<F%M<ULG;&]C871I;VXG72D["B`@("`@
M("`@)')I<V4@/2`D=&AI<RT^7V-A;&-U;&%T95-U;G-E="AT:6UE*"DL("1L
M870L("1L;VYG+"!F86QS92P@9FQO;W(H9&%T92@G6B<I("\@,S8P,"DI.PH@
M("`@("`@("1S970@/2`D=&AI<RT^7V-A;&-U;&%T95-U;G-E="AT:6UE*"DL
M("1L870L("1L;VYG+"!T<G5E+"!F;&]O<BAD871E*"=:)RD@+R`S-C`P*2D[
M"@H@("`@("`@("1L;V-A=&EO;B`]("<G.PH@("`@("`@(&=L;V)A;"`D8V]O
M<F1I;F%T97,["B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]O<F1I;F%T97,I
M*2!["B`@("`@("`@("`@(')E<75I<F4@)TAO<F1E+TY,4R]C;V]R9&EN871E
M<RYP:'`G.PH@("`@("`@('T*("`@("`@("!F;W)E86-H("@D8V]O<F1I;F%T
M97,@87,@)&-O=6YT<GDI('L*("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E
M>&ES=',H)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTL("1C;W5N=')Y*2D@
M>PH@("`@("`@("`@("`@("`@)&QO8V%T:6]N(#T@)&-O=6YT<GE;)'1H:7,M
M/E]P87)A;7-;)VQO8V%T:6]N)UU=.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`G/'1A
M8FQE('=I9'1H/2(Q,#`E(B!H96EG:'0](C$P,"4B(&-E;&QS<&%C:6YG/2(P
M(CX\='(^)R`N"B`@("`@("`@("`@("<\=&0@8V]L<W!A;CTB,B(@8VQA<W,]
M(F-O;G1R;VPB/CQS=')O;F<^)R`N("1L;V-A=&EO;B`N("<\+W-T<F]N9SX\
M+W1D/CPO='(^/'1R(&AE:6=H=#TB,3`P)2(^)R`N"B`@("`@("`@("`@("<\
M=&0@=VED=&@](C4P)2(@86QI9VX](F-E;G1E<B(^)R`N"B`@("`@("`@("`@
M($AO<F1E.CII;6<H)V)L;V-K+W-U;G)I<V4O<W5N<FES92YP;F<G+"!?*")3
M=6X@4FES92(I*2`N"B`@("`@("`@("`@("<\8G(@+SXG("X@)')I<V4@+B`G
M/"]T9#XG("X*("`@("`@("`@("`@)SQT9"!W:61T:#TB-3`E(B!A;&EG;CTB
M8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R9&4Z.FEM9R@G8FQO8VLO<W5N
M<FES92]S=6YS970N<&YG)RP@7R@B4W5N(%-E="(I*2`N"B`@("`@("`@("`@
M("<\8G(@+SXG("X@)'-E="`N("<\+W1D/B<@+B`G/"]T<CX\+W1A8FQE/B<[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!H='1P.B\O=W=W+GIE;F0N8V]M+V-O
M9&5X+G!H<#]I9#TQ,S4F<VEN9VQE/3$*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-A;&-U;&%T95-U;G-E="@D9&%T92P@)&QA=&ET=61E+"`D;&]N9VET=61E
M+"`D<W5N<V5T(#T@=')U92P@)'1I;65Z;VYE*0H@("`@>PH@("`@("`@("1Y
M9&%Y(#T@9&%T92@G>B<L("1D871E*3L*("`@("`@("`D;6]N(#T@9&%T92@G
M;B<L("1D871E*3L*("`@("`@("`D;61A>2`](&1A=&4H)VHG+"`D9&%T92D[
M"B`@("`@("`@)'EE87(@/2!D871E*"=9)RP@)&1A=&4I.PH*("`@("`@("!I
M9B`H)'1I;65Z;VYE(#T]("<Q,R<I('L*("`@("`@("`@("`@)'1I;65Z;VYE
M(#T@)RTQ,2<["B`@("`@("`@("`@("1M9&%Y*RL["B`@("`@("`@("`@("1Y
M9&%Y*RL["B`@("`@("`@?0H*("`@("`@("`D02`](#$N-3<P.#L*("`@("`@
M("`D0B`](#,N,30Q-3D["B`@("`@("`@)$,@/2`T+C<Q,C,Y.PH@("`@("`@
M("1$(#T@-BXR.#,Q.3L*("`@("`@("`D12`](#`N,#$W-#4S,R`J("1L871I
M='5D93L*("`@("`@("`D1B`](#`N,#$W-#4S,R`J("1L;VYG:71U9&4["B`@
M("`@("`@)$<@/2`P+C(V,3<Y.2`@*B`D=&EM97IO;F4["@H@("`@("`@("\O
M($9O<B!A<W1R;VYO;6EC86P@='=I;&EG:'0L('5S92!2(#T@+2XS,#DP,3<*
M("`@("`@("`O+R!&;W(@;F%U=&EC86P@='=I;&EG:'0L('5S92!2(#T@+2XR
M,#<Y,3(*("`@("`@("`O+R!&;W(@8VEV:6P@='=I;&EG:'0L('5S92!2(#T@
M+2XQ,#0U,C@*("`@("`@("`O+R!&;W(@<W5N<FES92!O<B!S=6YS970L('5S
M92!2(#T@+2XP,30U-#,Y"B`@("`@("`@)%(@/2`M+C`Q-#4T,SD["@H@("`@
M("`@(&EF("@D<W5N<V5T*2!["B`@("`@("`@("`@("1*(#T@)$,["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)$H@/2`D03L*("`@("`@("!]"@H@
M("`@("`@("1+(#T@)'ED87D@*R`H*"1*("T@)$8I("\@)$0I.PH@("`@("`@
M("1,(#T@*"1+("H@+C`Q-S(P,BD@+2`N,#4W-#`S.3L@("`@("`@("`@("`@
M("\O(%-O;&%R($UE86X@06YO;6]L>0H@("`@("`@("1-(#T@)$P@*R`N,#,S
M-#0P-2`J('-I;B@D3"D[("`@("`@("`@("`@("`@("\O(%-O;&%R(%1R=64@
M3&]N9VET=61E"B`@("`@("`@)$T@*ST@-"XY,S(X.2`K("@S+C0Y,#8V12TP
M-"D@*B!S:6XH,B`J("1,*3L@+R\@475A9')A;G0@1&5T97)M:6YA=&EO;@H@
M("`@("`@('=H:6QE("@D32`\(#`I('L*("`@("`@("`@("`@)$T@/2`H)$T@
M*R`D1"D["B`@("`@("`@?0H@("`@("`@('=H:6QE("@D32`^/2`D1"D@>PH@
M("`@("`@("`@("`D32`]("@D32`M("1$*3L*("`@("`@("!]"@H@("`@("`@
M(&EF("@H)$T@+R`D02D@+2!I;G1V86PH)$T@+R`D02D@/3T@,"D@>PH@("`@
M("`@("`@("`D32`K/2`T+C@T.#$T12TP-CL*("`@("`@("!]"@H@("`@("`@
M("10(#T@<VEN*"1-*2`O(&-O<R@D32D[("`@("`@("`@("`@("`@("`@("\O
M(%-O;&%R(%)I9VAT($%S8V5N<VEO;@H@("`@("`@("10(#T@871A;C(H+CDQ
M-S0V("H@)%`L(#$I.PH*("`@("`@("`O+R!1=6%D<F%N="!!9&IU<W1M96YT
M"B`@("`@("`@:68@*"1-(#X@)$,I('L*("`@("`@("`@("`@)%`@*ST@)$0[
M"B`@("`@("`@?2!E;'-E:68@*"1-(#X@)$$I('L*("`@("`@("`@("`@)%`@
M*ST@)$(["B`@("`@("`@?0H*("`@("`@("`D42`]("XS.3<X,B`J('-I;B@D
M32D[("`@("`@("`@("`@+R\@4V]L87(@1&5C;&EN871I;VX*("`@("`@("`D
M42`]("11("\@<W%R="@M)%$@*B`D42`K(#$I.R`@("`@+R\@5&AI<R!I<R!H
M;W<@=&AE(&]R:6=I;F%L(&%U=&AO<B!W<F]T92!I="$*("`@("`@("`D42`]
M(&%T86XR*"11+"`Q*3L*"B`@("`@("`@)%,@/2`D4B`M("AS:6XH)%$I("H@
M<VEN*"1%*2D["B`@("`@("`@)%,@/2`D4R`O("AC;W,H)%$I("H@8V]S*"1%
M*2D["@H@("`@("`@(&EF("AA8G,H)%,I(#X@,2D@>PH@("`@("`@("`@("!R
M971U<FX@)VYO;F4G.R`@("`@("`@("`@("`@("`O+R!.=6QL('!H96YO;65N
M;VX*("`@("`@("!]"@H@("`@("`@("13(#T@)%,@+R!S<7)T*"TD4R`J("13
M("L@,2D["B`@("`@("`@)%,@/2`D02`M(&%T86XR*"13+"`Q*3L*"B`@("`@
M("`@:68@*"$D<W5N<V5T*2!["B`@("`@("`@("`@("13(#T@)$0@+2`D4R`[
M"B`@("`@("`@?0H*("`@("`@("`D5"`]("13("L@)%`@+2`P+C`Q-S(P,C@@
M*B`D2R`M(#$N-S,S-C0[("\O($QO8V%L(&%P<&%R96YT('1I;64*("`@("`@
M("`D52`]("14("T@)$8[("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%5N:79E<G-A;"!T:6UE<@H@("`@("`@("16(#T@)%4@*R`D1SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@5V%L;"!C;&]C:R!T:6UE"@H@("`@
M("`@("\O(%%U861R86YT($1E=&5R;6EN871I;VX*("`@("`@("!W:&EL92`H
M)%8@/"`P*2!["B`@("`@("`@("`@("16(#T@*"16("L@)$0I.PH@("`@("`@
M('T*("`@("`@("!W:&EL92`H)%8@/CT@)$0I('L*("`@("`@("`@("`@)%8@
M/2`H)%8@+2`D1"D["B`@("`@("`@?0H@("`@("`@("16(#T@)%8@*B`S+C@Q
M.3<R.PH*("`@("`@("`D:&]U<B`](&EN='9A;"@D5BD["B`@("`@("`@)%8@
M("`M/2`D:&]U<CL*("`@("`@("`D;6EN("`](&EN='9A;"@D5B`J(#8P*3L*
M("`@("`@("`D5B`@("T]("1M:6X@+R`V,#L*("`@("`@("`D<V5C("`](&EN
M='9A;"@D5B`J(#,V,#`I.PH*("`@("`@("!R971U<FX@<W1R9G1I;64H)R58
M)RP@;6MT:6UE*"1H;W5R+"`D;6EN+"`D<V5C+"`D;6]N+"`D;61A>2P@)'EE
M87(I*3L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O0FQO8VLO;6]O
M;BYP:'``````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3<P,C4@,3`U,34T,S0Q,S<@,#(Q,#(T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HD8FQO8VM?;F%M92`]
M(%\H(DUO;VX@4&AA<V5S(BD["@HO*BH*("H@)$AO<F1E.B!H;W)D92]L:6(O
M0FQO8VLO;6]O;BYP:'`L=B`Q+C$V+C$P+C0@,C`P-2\Q,"\Q."`Q,3HS,SHS
M.2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L
M87-S($AO<F1E7T)L;V-K7TAO<F1E7VUO;VX@97AT96YD<R!(;W)D95]";&]C
M:R!["@H@("`@=F%R("1?87!P(#T@)VAO<F1E)SL*"B`@("!F=6YC=&EO;B!?
M=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")-;V]N(%!H87-E<R(I
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)A;7,H*0H@("`@>PH@("`@("`@
M(')E='5R;B!A<G)A>2@*("`@("`@("`@("`@)W!H87-E)R`]/B!A<G)A>2@*
M("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")7:&EC:"!P:&%S97,B*2P*
M("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G96YU;2<L"B`@("`@("`@("`@
M("`@("`G9&5F875L="<@/3X@)V-U<G)E;G0G+`H@("`@("`@("`@("`@("`@
M)W9A;'5E<R<@/3X@87)R87DH)V-U<G)E;G0G(#T^(%\H(D-U<G)E;G0@-"!0
M:&%S97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M97AT)R`]/B!?*").97AT(#0@4&AA<V5S(BDI*2P*("`@("`@("`@("`@)VAE
M;6ES<&AE<F4G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VYA;64G(#T^
M(%\H(DAE;6ES<&AE<F4B*2P*("`@("`@("`@("`@("`@("=T>7!E)R`]/B`G
M96YU;2<L"B`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)VYO<G1H97)N
M)RP*("`@("`@("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*"=N;W)T:&5R
M;B<@/3X@7R@B3F]R=&AE<FX@2&5M:7-P:&5R92(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W-O=71H97)N)R`]/B!?*")3;W5T:&5R
M;B!(96UI<W!H97)E(BDI*2P*("`@("`@("`@("`@*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!?8V]N=&5N="@I"B`@("!["B`@("`@("`@)'!H87-E<R`]("1T
M:&ES+3Y?8V%L8W5L871E36]O;E!H87-E<RAD871E*"=9)RDI.PH@("`@("`@
M("1N;W<@/2!T:6UE*"D["@H@("`@("`@("1L87-T3F5W(#T@,#L*("`@("`@
M("`D;&%S=$YE=U-T86UP(#T@,#L*("`@("`@("`D;V9F<V5T(#T@,#L*("`@
M("`@("!F;W)E86-H("@D<&AA<V5S(&%S("1K97D@/3X@)'9A;"D@>PH@("`@
M("`@("`@("!I9B`H)&ME>2`\("1N;W<@)B8@)&ME>2`^("1L87-T3F5W4W1A
M;7`@)B8@)'9A;"`]/2!?*").97<@36]O;B(I*2!["B`@("`@("`@("`@("`@
M("`D;&%S=$YE=R`]("1O9F9S970["B`@("`@("`@("`@("`@("`D;&%S=$YE
M=U-T86UP(#T@)&ME>3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;V9F
M<V5T*RL["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M87)A;7-;)W!H87-E)UTI("8F("1T:&ES+3Y?<&%R86US6R=P:&%S92==(#T]
M("=N97AT)RD@>PH@("`@("`@("`@("`D9&%T97,@/2!A<G)A>5]S;&EC92AA
M<G)A>5]K97ES*"1P:&%S97,I+"`D;&%S=$YE=R`K(#0L(#0I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1D871E<R`](&%R<F%Y7W-L:6-E*&%R
M<F%Y7VME>7,H)'!H87-E<RDL("1L87-T3F5W+"`T*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==
M*2`F)B`D=&AI<RT^7W!A<F%M<ULG:&5M:7-P:&5R92==(#T]("=N;W)T:&5R
M;B<I('L*("`@("`@("`@("`@)&QO8V%T:6]N(#T@7R@B3F]R=&AE<FX@2&5M
M:7-P:&5R92(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1L;V-A
M=&EO;B`](%\H(E-O=71H97)N($AE;6ES<&AE<F4B*3L*("`@("`@("!]"@H@
M("`@("`@("1H=&UL(#T@)SQT86)L92!W:61T:#TB,3`P)2(@:&5I9VAT/2(Q
M,#`E(B!C96QL<W!A8VEN9STB,"(^)R`N"B`@("`@("`@("`@("<\='(^/'1D
M(&-O;'-P86X](C0B(&-L87-S/2)C;VYT<F]L(CX\<W1R;VYG/B<@+B`D;&]C
M871I;VX@+B`G/"]S=')O;F<^/"]T9#X\+W1R/B<@+@H@("`@("`@("`@("`G
M/'1R(&AE:6=H=#TB,3`P)2(^/'1D('=I9'1H/2(R-24B(&%L:6=N/2)C96YT
M97(B/B<@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VYE
M=VUO;VXN<&YG)RP@7R@B3F5W($UO;VXB*2D@+@H@("`@("`@("`@("`G/&)R
M("\^)R`N('-T<F9T:6UE*"<E9"`E8B<L("1D871E<ULP72D@+@H@("`@("`@
M("`@("`G/"]T9#XG.PH*("`@("`@("`D:'1M;"`N/2`G/'1D('=I9'1H/2(R
M-24B(&%L:6=N/2)C96YT97(B/B<["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES+3Y?<&%R86US6R=H
M96UI<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@("`@("`@("`D:'1M
M;"`N/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+VQA<W1Q=6%R=&5R+G!N9R<L
M(%\H(D9I<G-T(%%U87)T97(B*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO;6]O;B]F:7)S='%U
M87)T97(N<&YG)RP@7R@B1FER<W0@475A<G1E<B(I*3L*("`@("`@("!]"B`@
M("`@("`@)&AT;6P@+CT@)SQB<B`O/B<@+B!S=')F=&EM92@G)60@)6(G+"`D
M9&%T97-;,5TI("X@)SPO=&0^)SL*"B`@("`@("`@)&AT;6P@+CT@)SQT9"!W
M:61T:#TB,C4E(B!A;&EG;CTB8V5N=&5R(CXG("X*("`@("`@("`@("`@2&]R
M9&4Z.FEM9R@G8FQO8VLO;6]O;B]F=6QL;6]O;BYP;F<G+"!?*")&=6QL($UO
M;VXB*2D@+@H@("`@("`@("`@("`G/&)R("\^)R`N('-T<F9T:6UE*"<E9"`E
M8B<L("1D871E<ULR72D@+B`G/"]T9#XG.PH*("`@("`@("`D:'1M;"`N/2`G
M/'1D('=I9'1H/2(R-24B(&%L:6=N/2)C96YT97(B/B<["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=H96UI<W!H97)E)UTI("8F("1T:&ES
M+3Y?<&%R86US6R=H96UI<W!H97)E)UT@/3T@)VYO<G1H97)N)RD@>PH@("`@
M("`@("`@("`D:'1M;"`N/2!(;W)D93HZ:6UG*"=B;&]C:R]M;V]N+V9I<G-T
M<75A<G1E<BYP;F<G+"!?*"),87-T(%%U87)T97(B*2D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&AT;6P@+CT@2&]R9&4Z.FEM9R@G8FQO8VLO
M;6]O;B]L87-T<75A<G1E<BYP;F<G+"!?*"),87-T(%%U87)T97(B*2D["B`@
M("`@("`@?0H@("`@("`@("1H=&UL("X]("<\8G(@+SXG("X@<W1R9G1I;64H
M)R5D("5B)RP@)&1A=&5S6S-=*2`N("<\+W1D/CPO='(^/"]T86)L93XG.PH*
M("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&%N(&%R<F%Y('=I=&@@86QL('1H92!P:&%S97,@;V8@=&AE(&UO
M;VX@9F]R(&$@=VAO;&4*("`@("`J('EE87(N"B`@("`@*@H@("`@("H@0F%S
M960@;VX@8V]D92!F<F]M"B`@("`@*B!H='1P.B\O=W=W+GIE;F0N8V]M+V-O
M9&5X+G!H<#]I9#TX,S`F<VEN9VQE/3$@8GD@07)E(%!E9&5R<V5N+@H@("`@
M("H*("`@("`J($-O;G9E<G1E9"!F<F]M($)A<VEC(&)Y(%)O9V5R(%<N(%-I
M;FYO="P@4VMY("8@5&5L97-C;W!E+"!-87)C:"`Q.3@U+@H@("`@("H@0V]N
M=F5R=&5D(&9R;VT@:F%V87-C<FEP="!B>2!!<F4@4&5D97)S96X@,C`P,@H@
M("`@("H@2F%V87-C<FEP="!F;W5N9"!A="!H='1P.B\O=W=W+G-T96QL869A
M;F4N8V]M+VUO;VY?<&AA<V4O;6]O;E]P:&%S92YH=&T*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT96=E<B`@("1Y96%R("`@5&AE(&9O=7(@9&EG:70@>65A
M<B!T;R!R971U<FX@=&AE(&UO;VX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!P:&%S97,@9F]R+@H@("`@("H*("`@("`J($!R971U<FX@87)R
M87D@("`@5&AE(&UO;VX@<&AA<V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M8V%L8W5L871E36]O;E!H87-E<R@D62D*("`@('L*("`@("`@("`D4C$@/2`S
M+C$T,34Y,C8U("\@,3@P.PH@("`@("`@("15("`](&9A;'-E.PH@("`@("`@
M("1+,"`](&EN='9A;"@H)%D@+2`Q.3`P*2`J(#$R+C,V.#4I.PH@("`@("`@
M("14("`]("@D62`M(#$X.3DN-2D@+R`Q,#`["B`@("`@("`@)%0R(#T@)%0@
M*B`D5#L*("`@("`@("`D5#,@/2`D5"`J("14("H@)%0["B`@("`@("`@)$HP
M(#T@,C0Q-3`R,"`K(#(Y("H@)$LP.PH@("`@("`@("1&,"`](#`N,#`P,3$W
M."`J("14,B`M(#`N,#`P,#`P,34U("H@)%0S.PH@("`@("`@("1&,"`K/2`H
M,"XW-3DS,R`K(#`N-3,P-3@X-C@J)$LP*3L*("`@("`@("`D1C`@+3T@*#`N
M,#`P.#,W("H@)%0@*R`P+C`P,#,S-2`J("14,BD["B`@("`@("`@)$TP("`]
M("1+,"`J(#`N,#@P.#0X,C$Q,S,["B`@("`@("`@)$TP("`](#,V,"`J("@D
M33`@+2!I;G1V86PH)$TP*2D@*R`S-3DN,C(T,CL*("`@("`@("`D33`@+3T@
M,"XP,#`P,S,S("H@)%0R.PH@("`@("`@("1-,"`M/2`P+C`P,#`P,S0W("H@
M)%0S.PH@("`@("`@("1-,2`@/2`D2S`@*B`P+C`W,3<Q,S8V,3(X.PH@("`@
M("`@("1-,2`@/2`S-C`@*B`H)$TQ("T@:6YT=F%L*"1-,2DI("L@,S`V+C`R
M-3,["B`@("`@("`@)$TQ("L](#`N,#$P-S,P-B`J("14,CL*("`@("`@("`D
M33$@*ST@,"XP,#`P,3(S-B`J("14,SL*("`@("`@("`D0C$@(#T@)$LP("H@
M,"XP.#4Q.34X-3$R.#L*("`@("`@("`D0C$@(#T@,S8P("H@*"1",2`M(&EN
M='9A;"@D0C$I*2`K(#(Q+C(Y-C0["B`@("`@("`@)$(Q("T](#`N,#`Q-C4R
M."`J("14,CL*("`@("`@("`D0C$@+3T@,"XP,#`P,#(S.2`J("14,SL*("`@
M("`@("!F;W(@*"1+.2`](#`[("1+.2`\/2`R.#L@)$LY(#T@)$LY("L@,"XU
M*2!["B`@("`@("`@("`@("1*(#T@)$HP("L@,30@*B`D2SD["B`@("`@("`@
M("`@("1&(#T@)$8P("L@,"XW-C4R.30@*B`D2SD["B`@("`@("`@("`@("1+
M(#T@)$LY("\@,CL*("`@("`@("`@("`@)$TU(#T@*"1-,"`K("1+("H@,CDN
M,3`U,S4V,#@I("H@)%(Q.PH@("`@("`@("`@("`D338@/2`H)$TQ("L@)$L@
M*B`S.#4N.#$V.3$X,#8I("H@)%(Q.PH@("`@("`@("`@("`D0C8@/2`H)$(Q
M("L@)$L@*B`S.3`N-C<P-3`V-#8I("H@)%(Q.PH@("`@("`@("`@("`D1B`M
M/2`P+C0P-C@@*B!S:6XH)$TV*3L*("`@("`@("`@("`@)$8@*ST@*#`N,3<S
M-"`M(#`N,#`P,SDS("H@)%0I("H@<VEN*"1--2D["B`@("`@("`@("`@("1&
M("L](#`N,#$V,2`J('-I;B@R("H@)$TV*3L*("`@("`@("`@("`@)$8@*ST@
M,"XP,3`T("H@<VEN*#(@*B`D0C8I.PH@("`@("`@("`@("`D1B`M/2`P+C`P
M-S0@*B!S:6XH)$TU("T@)$TV*3L*("`@("`@("`@("`@)$8@+3T@,"XP,#4Q
M("H@<VEN*"1--2`K("1--BD["B`@("`@("`@("`@("1&("L](#`N,#`R,2`J
M('-I;B@R("H@)$TU*3L*("`@("`@("`@("`@)$8@*ST@,"XP,#$P("H@<VEN
M*#(@*B`D0C8@+2`D338I.PH*("`@("`@("`@("`@+RH@061D(#$O,B!M:6YU
M=&4@9F]R('!R;W!E<B!R;W5N9&EN9R!T;R!M:6YU=&5S('!E<B!3:WD@)@H@
M("`@("`@("`@("`@*B!496P@87)T:6-L92X@*B\*("`@("`@("`@("`@)$8@
M*ST@,"XU("\@,30T,#L*("`@("`@("`@("`@)$H@*ST@:6YT=F%L*"1&*3L*
M("`@("`@("`@("`@)$8@+3T@:6YT=F%L*"1&*3L*"B`@("`@("`@("`@("\J
M($-O;G9E<G0@9G)O;2!*1"!T;R!#86QE;F1A<B!$871E+B`J+PH@("`@("`@
M("`@("`D:G5L:6%N(#T@)$H@*R!R;W5N9"@D1BD["B`@("`@("`@("`@("1P
M87)T<R`@/2!E>'!L;V1E*"<O)RP@)'1H:7,M/E]J9'1O9W)E9V]R:6%N*"1J
M=6QI86XI*3L*("`@("`@("`@("`@)'-T86UP("`](&=M;6MT:6UE*#`L(#`L
M(#`L("1P87)T<ULP72P@)'!A<G1S6S%=+"`D<&%R='-;,ETI.PH*("`@("`@
M("`@("`@+RH@:&%L9B!++B`J+PH@("`@("`@("`@("!I9B`H*"1+.2`M(&9L
M;V]R*"1+.2DI(#X@,"D@>PH@("`@("`@("`@("`@("`@:68@*"15*2!["B`@
M("`@("`@("`@("`@("`@("`@+RH@3F5W(&AA;&8N("HO"B`@("`@("`@("`@
M("`@("`@("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B1FER<W0@2&%L9B(I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O
M*B!&=6QL(&AA;&8N("HO"B`@("`@("`@("`@("`@("`@("`@)'!H87-E<ULD
M<W1A;7!=(#T@7R@B3&%S="!(86QF(BD["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!F=6QL($LN
M("HO"B`@("`@("`@("`@("`@("!I9B`H(215*2!["B`@("`@("`@("`@("`@
M("`@("`@)'!H87-E<ULD<W1A;7!=(#T@7R@B3F5W($UO;VXB*3L*("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!H87-E
M<ULD<W1A;7!=(#T@7R@B1G5L;"!-;V]N(BD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D52`]("$D53L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1P:&%S97,["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:W,@:68@=&AE(&ID=&]G<F5G;W)I86X@9G5N8W1I;VX@
M97AI<W1S+"!A;F0@:68@;F]T"B`@("`@*B!C86QC=6QA=&5S('1H92!G<F5G
M;W)I86X@9&%T92!M86YU86QL>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("1J=6QI86X@5&AE(&IU;&EA;B!D871E"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@;2]D+UD*("`@("`J+PH@("`@9G5N8W1I;VX@7VID=&]G<F5G
M;W)I86XH)&IU;&EA;BD*("`@('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI
M<W1S*"=J9'1O9W)E9V]R:6%N)RDI('L*("`@("`@("`@("`@<F5T=7)N(&ID
M=&]G<F5G;W)I86XH)&IU;&EA;BD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@1G)O;2!H='1P.B\O<&AP+FYE="]M86YU86PO96XO9G5N8W1I
M;VXN:F1T;V=R96=O<FEA;BYP:'`*("`@("`@("`@("`@)&IU;&EA;B`]("1J
M=6QI86X@+2`Q-S(Q,3$Y.PH@("`@("`@("`@("`D8V%L8S$@/2`T("H@)&IU
M;&EA;B`M(#$["B`@("`@("`@("`@("1Y96%R(#T@9FQO;W(H)&-A;&,Q("\@
M,30V,#DW*3L*("`@("`@("`@("`@)&IU;&EA;B`](&9L;V]R*"1C86QC,2`M
M(#$T-C`Y-R`J("1Y96%R*3L*("`@("`@("`@("`@)&1A>2`](&9L;V]R*"1J
M=6QI86X@+R`T*3L*("`@("`@("`@("`@)&-A;&,R(#T@-"`J("1D87D@*R`S
M.PH@("`@("`@("`@("`D:G5L:6%N(#T@9FQO;W(H)&-A;&,R("\@,30V,2D[
M"B`@("`@("`@("`@("1D87D@/2`D8V%L8S(@+2`Q-#8Q("H@)&IU;&EA;CL*
M("`@("`@("`@("`@)&1A>2`](&9L;V]R*"@D9&%Y("L@-"D@+R`T*3L*("`@
M("`@("`@("`@)&-A;&,S(#T@-2`J("1D87D@+2`S.PH@("`@("`@("`@("`D
M;6]N=&@@/2!F;&]O<B@D8V%L8S,@+R`Q-3,I.PH@("`@("`@("`@("`D9&%Y
M(#T@)&-A;&,S("T@,34S("H@)&UO;G1H.PH@("`@("`@("`@("`D9&%Y(#T@
M9FQO;W(H*"1D87D@*R`U*2`O(#4I.PH@("`@("`@("`@("`D>65A<B`](#$P
M,"`J("1Y96%R("L@)&IU;&EA;CL*"B`@("`@("`@("`@(&EF("@D;6]N=&@@
M/"`Q,"D@>PH@("`@("`@("`@("`@("`@)&UO;G1H(#T@)&UO;G1H("L@,SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;VYT:"`]
M("1M;VYT:"`M(#D["B`@("`@("`@("`@("`@("`D>65A<B`]("1Y96%R("L@
M,3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@(B1M;VYT:"\D
M9&%Y+R1Y96%R(CL*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+T)L;V-K+V9O<G1U;F4N<&AP````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,3$W(#$P-3$U-#,T,3,W(#`R,34S
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*)&)L;V-K7VYA;64@/2!?*")286YD;VT@1F]R='5N92(I.PH*+RHJ
M"B`J("1(;W)D93H@:&]R9&4O;&EB+T)L;V-K+V9O<G1U;F4N<&AP+'8@,2XQ
M-"XQ,"XR(#(P,#4O,3`O,3@@,3$Z,S,Z,SD@:F%N($5X<"`D"B`J"B`J($!P
M86-K86=E($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D
M95]F;W)T=6YE(&5X=&5N9',@2&]R9&5?0FQO8VL@>PH*("`@('9A<B`D7V%P
M<"`]("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@
M:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B!?*")&;W)T=6YE(BD["B`@("!]"@H@
M("`@9G5N8W1I;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@9VQO8F%L("1C
M;VYF.PH*("`@("`@("`D9&5S8W)I<'1I;VYS(#T@87)R87DH)V%R="<@/3X@
M7R@B07)T(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A<V-I
M:2UA<G0G(#T^(%\H(D%S8VEI($%R="(I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8F]F:"UE>&-U<V5S)R`]/B!?*")"3T9(($5X8W5S97,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;7!U=&5R<R<@
M/3X@7R@B0V]M<'5T97)S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=C;V]K:64G(#T^(%\H(D-O;VMI92(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&5F:6YI=&EO;G,G(#T^(%\H(D1E9FEN:71I;VYS
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=D<G5G<R<@/3X@
M7R@B1')U9W,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5D
M=6-A=&EO;B<@/3X@7R@B161U8V%T:6]N(BDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=E=&AN:6,G(#T^(%\H(D5T:&YI8R(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9F]O9"<@/3X@7R@B1F]O9"(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9F]R='5N97,G(#T^(%\H
M(D9O<G1U;F5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F
M;W)T=6YE<S(G(#T^(%\H(D9O<G1U;F5S(#(B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V=O961E;"<@/3X@7R@B1V]E9&5L(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H=6UO<FES=',G(#T^(%\H(DAU
M;6]R:7-T<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:V5R
M;F5L;F5W8FEE<R<@/3X@7R@B2V5R;F5L($YE=V)I97,B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VMI9',G(#T^(%\H(DMI9',B*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQA=R<@/3X@7R@B3&%W(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:6UE<FEC:R<@/3X@
M7R@B3&EM97)I8VLB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VQI;G5X8V]O:VEE)R`]/B!?*"),:6YU>"!#;V]K:64B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VQI=&5R871U<F4G(#T^(%\H(DQI=&5R
M871U<F4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQO=F4G
M(#T^(%\H(DQO=F4B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VUA9VEC)R`]/B!?*")-86=I8R(I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;65D:6-I;F4G(#T^(%\H(DUE9&EC:6YE(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=M:7-C96QL86YE;W5S)R`]/B!?*")-
M:7-C96QL86YE;W5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=N97=S)R`]/B!?*").97=S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=O<V9O<G1U;F4G(#T^(%\H(D]P97)A=&EN9R!3>7-T96TB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!E;W!L92<@/3X@7R@B
M4&5O<&QE(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P971S
M)R`]/B!?*")0971S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=P;&%T:71U9&5S)R`]/B!?*")0;&%T:71U9&5S(BDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=P;VQI=&EC<R<@/3X@7R@B4&]L:71I8W,B
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)I9&1L97,G(#T^
M(%\H(E)I9&1L97,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W-C:65N8V4G(#T^(%\H(E-C:65N8V4B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W-O;F=S+7!O96US)R`]/B!?*")3;VYG<R`F(%!O96US
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S<&]R=',G(#T^
M(%\H(E-P;W)T<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<W1A<G1R96LG(#T^(%\H(E-T87(@5')E:R(I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=')A;G-L871E+6UE)R`]/B!?*")4<F%N<VQA=&EO
M;G,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W=I<V1O;2<@
M/3X@7R@B5VES9&]M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=W;W)K)R`]/B!?*")7;W)K(BDL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=Z:7!P>2<@/3X@7R@B6FEP<'DB*2D["@H@("`@("`@("1V86QU
M97,@/2!N=6QL.PH@("`@("`@(&EF("AI<W-E="@D8V]N9ELG9F]R='5N92==
M6R=E>&5C7W!A=&@G72D@)B8*("`@("`@("`@("`@:7-?97AE8W5T86)L92@D
M8V]N9ELG9F]R='5N92==6R=E>&5C7W!A=&@G72DI('L*("`@("`@("`@("`@
M97AE8R@D8V]N9ELG9F]R='5N92==6R=E>&5C7W!A=&@G72`N("<@+68@,CXF
M,2<L("1O=71P=70L("1S=&%T=7,I.PH@("`@("`@("`@("!I9B`H(21S=&%T
M=7,I('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\(&-O=6YT
M*"1O=71P=70I.R`D:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&9O<G1U
M;F4@/2!S=6)S='(H)&]U='!U=%LD:5TL('-T<G)P;W,H)&]U='!U=%LD:5TL
M("<@)RD@*R`Q*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<V-R:7!T:6]N<ULD9F]R='5N95TI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1V86QU97-;)&9O<G1U;F5=(#T@)&1E<V-R:7!T:6]N<ULD9F]R='5N
M95T["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'9A;'5E<ULD9F]R='5N95T@/2`D9F]R='5N93L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES7VYU;&PH)'9A;'5E<RDI
M('L*("`@("`@("`@("`@)'9A;'5E<R`]("1D97-C<FEP=&EO;G,["B`@("`@
M("`@?0H@("`@("`@(&%S;W)T*"1V86QU97,I.PH@("`@("`@("1V86QU97,@
M/2!A<G)A>5]M97)G92AA<G)A>2@G)R`]/B!?*")!;&PB*2DL("1V86QU97,I
M.PH*("`@("`@("!R971U<FX@87)R87DH"B`@("`@("`@("`@("=O9F9E;F0G
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*
M("`@("`@("`@("`@("`@("=N86UE)R`]/B!?*")/9F9E;G-E(&9I;'1E<B(I
M+`H@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<G+`H@("`@("`@("`@
M("`@("`@)W9A;'5E<R<@/3X@87)R87DH)R<@/3X@7R@B3F\@;V9F96YS:79E
M(&9O<G1U;F5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<@+6\G(#T^(%\H(D]N;'D@;V9F96YS:79E(&9O<G1U;F5S(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@+6$G(#T^(%\H(D)O=&@B
M*2DI+`H@("`@("`@("`@("`G9F]R='5N92<@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`G='EP92<@/3X@)VUU;'1I96YU;2<L"B`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@7R@B1F]R='5N92!T>7!E(BDL"B`@("`@("`@("`@("`@
M("`G9&5F875L="<@/3X@87)R87DH)R<I+`H@("`@("`@("`@("`@("`@)W9A
M;'5E<R<@/3X@)'9A;'5E<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE
M(&-O;G1E;G0@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!C;VYT96YT"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!G;&]B86P@)&-O;F8["@H@
M("`@("`@(&EF("AI<W-E="@D8V]N9ELG9F]R='5N92==6R=E>&5C7W!A=&@G
M72D@)B8*("`@("`@("`@("`@:7-?97AE8W5T86)L92@D8V]N9ELG9F]R='5N
M92==6R=E>&5C7W!A=&@G72DI('L*("`@("`@("`@("`@)&-M9$QI;F4@/2`D
M8V]N9ELG9F]R='5N92==6R=E>&5C7W!A=&@G73L*("`@("`@("`@("`@)&-M
M9$QI;F4@+CT@)'1H:7,M/E]P87)A;7-;)V]F9F5N9"==.PH@("`@("`@("`@
M("`D8VUD3&EN92`N/2`G("<@+B!I;7!L;V1E*"<@)RP@)'1H:7,M/E]P87)A
M;7-;)V9O<G1U;F4G72D["B`@("`@("`@("`@(')E='5R;B!N;#)B<BAH=&UL
M<W!E8VEA;&-H87)S*'-H96QL7V5X96,H)&-M9$QI;F4I*2D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]W96%T:&5R9&]T8V]M7W-T<FEN9W,N
M<&AP```````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C8U-"`Q,#4Q-30S-#$S
M-R`P,C0T-S0`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RHJ"B`J(%!O<W-I8FQE('-T<FEN9W,@9G)O;2!W96%T
M:&5R+F-O;2P@:G5S="!T;R!H879E('1H96T@:6X@=&AE('-O=7)C92!F;W(*
M("H@;&]C86QI>F%T:6]N(')E87-O;G,N"B`J"B`J("1(;W)D93H@:&]R9&4O
M;&EB+T)L;V-K+W=E871H97)D;W1C;VU?<W1R:6YG<RYP:'`L=B`Q+C$N,BXV
M(#(P,#8O,#4O,#,@,3<Z,#<Z,C<@:F%N($5X<"`D"B`J+PH*7R@B04T@0VQO
M=61S(BD["E\H(D%-($QI9VAT(%)A:6XB*3L*7R@B04T@3&EG:'0@4VYO=R(I
M.PI?*")!32!286EN(BD["E\H(D%-(%-H;W=E<G,B*3L*7R@B04T@4VYO=R!3
M:&]W97)S(BD["E\H(D-L96%R(BD["E\H(D-L96%R:6YG($QA=&4B*3L*7R@B
M0VQO=61S($5A<FQY(BD["E\H(D-L;W5D>2(I.PI?*")&86ER(BD["E\H(D9E
M=R!3:&]W97)S(BD["E\H(D9E=R!3;F]W(%-H;W=E<G,B*3L*7R@B1F]G(BD[
M"E\H(D9R965Z:6YG($1R:7IZ;&4B*3L*7R@B2&%Z92(I.PI?*")(96%V>2!4
M+5-T;W)M(BD["E\H(DES;VQA=&5D(%0M4W1O<FUS(BD["E\H(DQI9VAT($1R
M:7IZ;&4B*3L*7R@B3&EG:'0@4F%I;B(I.PI?*"),:6=H="!286EN($5A<FQY
M(BD["E\H(DQI9VAT(%)A:6X@3&%T92(I.PI?*"),:6=H="!286EN(%-H;W=E
M<B(I.PI?*"),:6=H="!286EN('=I=&@@5&AU;F1E<B(I.PI?*"),:6=H="!3
M;F]W(BD["E\H(DQI9VAT(%-N;W<@4VAO=V5R(BD["E\H(DUO<W1L>2!#;&5A
M<B(I.PI?*")-;W-T;'D@0VQO=61Y(BD["E\H(DUO<W1L>2!#;&]U9'D@86YD
M(%=I;F1Y(BD["E\H(DUO<W1L>2!3=6YN>2(I.PI?*")087)T;'D@0VQO=61Y
M(BD["E\H(E!-($QI9VAT(%)A:6XB*3L*7R@B4$T@4F%I;B(I.PI?*")032!3
M:&]W97)S(BD["E\H(E!-(%-N;W<B*3L*7R@B4$T@4VYO=R!3:&]W97)S(BD[
M"E\H(E!-(%-U;B(I.PI?*")032!4+5-T;W)M<R(I.PI?*")286EN(BD["E\H
M(E)A:6X@16%R;'DB*3L*7R@B4F%I;B!,871E(BD["E\H(E)A:6X@4VAO=V5R
M(BD["E\H(E)A:6X@86YD(%-N;W<B*3L*7R@B4F%I;B!T;R!3;F]W(BD["E\H
M(E-C871T97)E9"!4+5-T;W)M<R(I.PI?*")3:&]W97)S(BD["E\H(E-H;W=E
M<G,@16%R;'DB*3L*7R@B4VAO=V5R<R!,871E(BD["E\H(E-H;W=E<G,@:6X@
M=&AE(%9I8VEN:71Y(BD["E\H(E-N;W<B*3L*7R@B4VYO=R!3:&]W97(B*3L*
M7R@B4VYO=R!3:&]W97)S(BD["E\H(E-N;W<@4VAO=V5R<R!%87)L>2(I.PI?
M*")3;F]W(%-H;W=E<G,@3&%T92(I.PI?*")3=6YN>2(I.PI?*")4+5-T;W)M
M(BD["E\H(E0M4W1O<FT@86YD(%=I;F1Y(BD["E\H(E0M4W1O<FUS(BD["E\H
M(E0M4W1O<FUS($5A<FQY(BD["E\H(E1H=6YD97(B*3L*7R@B5VEN9"(I.PI?
M*")7:6YD($5A<FQY(BD["E\H(DQO=R(I.PI?*")-;V1E<F%T92(I.PI?*")(
M:6=H(BD["E\H(E9E<GD@2&EG:"(I.PI?*")F86QL:6YG(BD["E\H(G-T96%D
M>2(I.PI?*")R:7-I;F<B*3L*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T)L;V-K
M+VEF<F%M92YP:'``````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`T,3$P(#$P-3$U-#,T,3,W(#`R,3,P-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*)&)L;V-K7VYA
M;64@/2!?*")6:65W(&%N(&5X=&5R;F%L('=E8B!P86=E(BD["@HO*BH*("H@
M)$AO<F1E.B!H;W)D92]L:6(O0FQO8VLO:69R86UE+G!H<"QV(#$N,3@N."XT
M(#(P,#8O,#(O,C$@,3`Z-3,Z-#4@:F%N($5X<"`D"B`J"B`J($!P86-K86=E
M($AO<F1E7T)L;V-K"B`J+PIC;&%S<R!(;W)D95]";&]C:U](;W)D95]I9G)A
M;64@97AT96YD<R!(;W)D95]";&]C:R!["@H@("`@=F%R("1?87!P(#T@)VAO
M<F1E)SL*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*("`@('L*("`@("`@("!R
M971U<FX@87)R87DH)VEF<F%M92<@/3X@87)R87DH)W1Y<&4G(#T^("=T97AT
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA
M;64G(#T^(%\H(E523"(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9&5F875L="<@/3X@)R<I+`H@("`@("`@("`@("`@("`@
M("`@("`G=&ET;&4G("`]/B!A<G)A>2@G='EP92<@/3X@)W1E>'0G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@
M7R@B5&ET;&4B*2DL"B`@("`@("`@("`@("`@("`@("`@("=H96EG:'0G(#T^
M(&%R<F%Y*"=T>7!E)R`]/B`G:6YT)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(DAE:6=H="(I*2D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B
M;&]C:RX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!T:71L
M92!T97AT+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@
M("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@("`@("1T:71L92`](&ES
M<V5T*"1T:&ES+3Y?<&%R86US6R=T:71L92==*0H@("`@("`@("`@("`_("1T
M:&ES+3Y?<&%R86US6R=T:71L92=="B`@("`@("`@("`@(#H@)'1H:7,M/E]P
M87)A;7-;)VEF<F%M92==.PH*("`@("`@("`D:'1M;"`]($AO<F1E.CIL:6YK
M*"1T:&ES+3Y?<&%R86US6R=I9G)A;64G72D@+B`D=&ET;&4@+@H@("`@("`@
M("`@("`G/"]A/B`Z.B`\<VUA;&P^)R`N"B`@("`@("`@("`@($AO<F1E.CIL
M:6YK*"1T:&ES+3Y?<&%R86US6R=I9G)A;64G72P@)R<L("<G+"`G7V)L86YK
M)RD@+@H@("`@("`@("`@("!(;W)D93HZ:6UG*"=W96)S:71E+G!N9R<L(%\H
M(D]P96X@:6X@82!N97<@=VEN9&]W(BDI("X@)R`G("X*("`@("`@("`@("`@
M7R@B3W!E;B!I;B!A(&YE=R!W:6YD;W<B*2`N("<\+V$^/"]S;6%L;#XG.PH*
M("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E;G0*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8G)O=W-E
M<CL*"B`@("`@("`@:68@*"$D8G)O=W-E<BT^:&%S1F5A='5R92@G:69R86UE
M<R<I*2!["B`@("`@("`@("`@(')E='5R;B!?*")9;W5R(&)R;W=S97(@9&]E
M<R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N(BD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7-;)VAE:6=H="==*2D@>PH@
M("`@("`@("`@("!I9B`H)&)R;W=S97(M/FES0G)O=W-E<B@G;7-I92<I('Q\
M("1B<F]W<V5R+3YI<T)R;W=S97(H)VMO;G%U97)O<B<I*2!["B`@("`@("`@
M("`@("`@("`D:&5I9VAT(#T@)R<["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D:&5I9VAT(#T@)R!H96EG:'0](C$P,"4B)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1H96EG
M:'0@/2`G(&AE:6=H=#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M/E]P
M87)A;7-;)VAE:6=H="==*2`N("<B)SL*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("<\:69R86UE('-R8STB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)'1H:7,M
M/E]P87)A;7-;)VEF<F%M92==*2`N("<B('=I9'1H/2(Q,#`E(B<@+B`D:&5I
M9VAT("X@)R!M87)G:6YH96EG:'0](C`B('-C<F]L;&EN9STB875T;R(@9G)A
M;65B;W)D97(](C`B/CPO:69R86UE/B<["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+T)L;V-K+VUE=&%R+G!H<```````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#0W,3,W(#$P-3$U-#,T,3,W(#`R,3$W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*)&)L;V-K7VYA;64@/2!?*")-971A<B!796%T:&5R(BD["@HO*BH*("H@
M5&AE($AO<F1E7T)L;V-K7VUE=&%R(&-L87-S('!R;W9I9&5S(&%N(&%P<&QE
M="!F;W(@=&AE('!O<G1A;`H@*B!S8W)E96X@=&\@9&ES<&QA>2!-151!4B!W
M96%T:&5R(&1A=&$@9F]R(&$@<W!E8VEF:65D(&QO8V%T:6]N"B`J("AC=7)R
M96YT;'D@86ER<&]R=',I+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VQI8B]";&]C
M:R]M971A<BYP:'`L=B`Q+C(R+C$P+C8@,C`P-B\P-B\R,R`Q.3HS,3HR."!J
M86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO"F-L87-S
M($AO<F1E7T)L;V-K7TAO<F1E7VUE=&%R(&5X=&5N9',@2&]R9&5?0FQO8VL@
M>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@=&ET;&4@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@(%1H92!T:71L92!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=&ET;&4H*0H@("`@>PH@("`@("`@(')E='5R;B!?*")#=7)R
M96YT(%=E871H97(B*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<&%R86US*"D*
M("`@('L*("`@("`@("!I9B`H(4!I;F-L=61E7V]N8V4@)U-E<G9I8V5S+U=E
M871H97(N<&AP)RD@>PH@("`@("`@("`@("!(;W)D93HZ;&]G365S<V%G92@G
M5&AE(&UE=&%R(&)L;V-K('=I;&P@;F]T('=O<FL@=VET:&]U="!397)V:6-E
M<U]796%T:&5R(&9R;VT@4$5!4BX@4G5N('!E87(@:6YS=&%L;"!397)V:6-E
M<U]796%T:&5R+B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?
M1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@
M<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@)V5R<F]R)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)V5R<F]R)RP*("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B17)R;W(B*2P*("`@("`@
M("`@("`@("`@("`@("`G9&5F875L="<@/3X@7R@B365T87(@8FQO8VL@;F]T
M(&%V86EL86)L92XB*0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&=L;V)A;"`D8V]N9CL*
M"B`@("`@("`@("`@("\O($=E="!L;V-A=&EO;G,@9G)O;2!T:&4@9&%T86)A
M<V4N"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`@
M("`@("`@)&1B(#T@)D1".CIC;VYN96-T*"1C;VYF6R=S<6PG72D["B`@("`@
M("`@("`@(&EF("AI<U]A*"1D8BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1D8CL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@4V5T($1"('!O<G1A8FEL:71Y(&]P=&EO;G,N"B`@("`@("`@("`@
M('-W:71C:"`H)&1B+3YP:'!T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)VUS
M<W%L)SH*("`@("`@("`@("`@("`@("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I
M;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,
M25197T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@)&1B+3YS971/<'1I;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"
M24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?15)23U)3*3L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)')E<W5L="`]("1D8BT^<75E<GDH
M)U-%3$5#5"!I8V%O+"!N86UE+"!C;W5N=')Y($923TT@;65T87)!:7)P;W)T
M<R!/4D1%4B!"62!C;W5N=')Y)RD["B`@("`@("`@("`@(&EF("AI<U]A*"1R
M97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D;&]C871I
M;VYS(#T@87)R87DH*3L*("`@("`@("`@("`@=VAI;&4@*"1R;W<@/2`D<F5S
M=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2!["B`@("`@("`@
M("`@("`@("`D;&]C871I;VYS6R1R;W=;)V-O=6YT<GDG75U;)')O=ULG:6-A
M;R==72`]("1R;W=;)VYA;64G73L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VQO8V%T:6]N)R`]
M/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G='EP92<@/3X@)VUL96YU
M;2<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(DQO8V%T:6]N
M(BDL"B`@("`@("`@("`@("`@("`@("`@)V1E9F%U;'0G(#T^("=+4T9")RP*
M("`@("`@("`@("`@("`@("`@("`G=F%L=65S)R`]/B`D;&]C871I;VYS+`H@
M("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=U;FET<R<@/3X@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=E;G5M)RP*
M("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@7R@B56YI=',B*2P*("`@
M("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@)W,G+`H@("`@("`@("`@
M("`@("`@("`@("=V86QU97,G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("`@("`@("`G<R<@/3X@7R@B4W1A;F1A<F0B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@)VTG(#T^(%\H(DUE=')I8R(I"B`@("`@("`@("`@("`@("`@
M("`@*0H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@("=K;F]T
M<R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^("=C
M:&5C:V)O>"<L"B`@("`@("`@("`@("`@("`@("`@)VYA;64G(#T^(%\H(E=I
M;F0@<W!E960@:6X@:VYO=',B*2P*("`@("`@("`@("`@("`@("`@("`G9&5F
M875L="<@/3X@,`H@("`@("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@
M("=T868G(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("=T>7!E)R`]
M/B`G8VAE8VMB;W@G+`H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")$:7-P;&%Y(&9O<F5C87-T("A4048I(BDL"B`@("`@("`@("`@("`@("`@
M("`@)V1E9F%U;'0G(#T^(#`*("`@("`@("`@("`@("`@("D*("`@("`@("`@
M("`@*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W)O=R@D;&%B
M96PL("1C;VYT96YT*0H@("`@>PH@("`@("`@(')E='5R;B`G/&)R("\^/'-T
M<F]N9SXG("X@)&QA8F5L("X@)SH\+W-T<F]N9SX@)R`N("1C;VYT96YT.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]S86UE4F]W*"1L86)E;"P@)&-O;G1E;G0I
M"B`@("!["B`@("`@("`@<F5T=7)N("<@/'-T<F]N9SXG("X@)&QA8F5L("X@
M)SH\+W-T<F]N9SX@)R`N("1C;VYT96YT.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AE(&-O;G1E;G0@=&\@9V\@:6X@=&AI<R!B;&]C:RX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C;VYT96YT"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]C;VYT96YT*"D*("`@('L*("`@("`@("!I9B`H(4!I;F-L
M=61E7V]N8V4@)U-E<G9I8V5S+U=E871H97(N<&AP)RD@>PH@("`@("`@("`@
M("!(;W)D93HZ;&]G365S<V%G92@G5&AE(&UE=&%R(&)L;V-K('=I;&P@;F]T
M('=O<FL@=VET:&]U="!397)V:6-E<U]796%T:&5R(&9R;VT@4$5!4BX@4G5N
M('!E87(@:6YS=&%L;"!397)V:6-E<U]796%T:&5R+B<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],
M3T=?15)2*3L*("`@("`@("`@("`@<F5T=7)N(%\H(DUE=&%R(&)L;V-K(&YO
M="!A=F%I;&%B;&4N($1E=&%I;',@:&%V92!B965N(&QO9V=E9"!F;W(@=&AE
M(&%D;6EN:7-T<F%T;W(N(BD["B`@("`@("`@?0H*("`@("`@("!G;&]B86P@
M)&-O;F8["B`@("`@("`@<W1A=&EC("1M971A<DQO8W,["@H@("`@("`@(&EF
M("@A:7-S970H)&-O;F9;)W-Q;"==*2D@>PH@("`@("`@("`@("!R971U<FX@
M7R@B02!D871A8F%S92!B86-K96YD(&ES(')E<75I<F5D(&9O<B!T:&ES(&)L
M;V-K+B(I.PH@("`@("`@('T*"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=L;V-A=&EO;B==*2D@>PH@("`@("`@("`@("!R971U<FX@7R@B
M3F\@;&]C871I;VX@:7,@<V5T+B(I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D;65T87),;V-S*2D@>PH@("`@("`@("`@("`D;65T87),
M;V-S(#T@)'1H:7,M/F=E=%!A<F%M<R@I.PH@("`@("`@('T*"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=397)V:6-E<R]796%T:&5R+G!H<"<["B`@("`@("`@
M)&UE=&%R(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H)TU%5$%2)RP@
M87)R87DH)V1E8G5G)R`]/B`P*2D["B`@("`@("`@)&UE=&%R+3YS971-971A
M<D1"*"1C;VYF6R=S<6PG72D["B`@("`@("`@)&UE=&%R+3YS9715;FET<T9O
M<FUA="@D=&AI<RT^7W!A<F%M<ULG=6YI=',G72D["B`@("`@("`@)&UE=&%R
M+3YS971$871E5&EM949O<FUA="@G32!J+"!9)RP@)T@Z:2<I.PH@("`@("`@
M("1M971A<BT^<V5T365T87)3;W5R8V4H)VAT='`G*3L*"B`@("`@("`@)'5N
M:71S(#T@)&UE=&%R+3YG9715;FET<T9O<FUA="@D=&AI<RT^7W!A<F%M<ULG
M=6YI=',G72D["B`@("`@("`@)'=E871H97(@/2`D;65T87(M/F=E=%=E871H
M97(H)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI.PH*("`@("`@("`D:'1M
M;"`]("<\=&%B;&4@=VED=&@](C$P,"4B(&-E;&QS<&%C:6YG/2(P(CXG("X*
M("`@("`@("`@("`@)SQT<CX\=&0@8VQA<W,](F-O;G1R;VPB/CQS=')O;F<^
M)R`N"B`@("`@("`@("`@('-P<FEN=&8H)R5S+"`E<R`H)7,I)RP*("`@("`@
M("`@("`@("`@("`@("`D;65T87),;V-S6R=L;V-A=&EO;B==6R=V86QU97,G
M75LD=&AI<RT^7W!A<F%M<ULG7U]L;V-A=&EO;B==75LD=&AI<RT^7W!A<F%M
M<ULG;&]C871I;VXG75TL"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)U]?;&]C871I;VXG72P*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG;&]C871I;VXG72D@+@H@("`@("`@("`@("`G/"]S=')O
M;F<^/"]T9#X\+W1R/CPO=&%B;&4^/'-T<F]N9SXG("X@7R@B3&%S="!5<&1A
M=&5D.B(I("X@)SPO<W1R;VYG/B`G("X*("`@("`@("`@("`@)'=E871H97);
M)W5P9&%T92==("X@)SQB<B`O/CQB<B`O/B<["@H@("`@("`@("\O(%=I;F0N
M"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R=W:6YD)UTI*2!["B`@("`@
M("`@("`@("1H=&UL("X]("<\<W1R;VYG/B<@+B!?*")7:6YD.B(I("X@)SPO
M<W1R;VYG/B`G.PH@("`@("`@("`@("!I9B`H)'=E871H97);)W=I;F1$:7)E
M8W1I;VXG72`]/2`G5F%R:6%B;&4G*2!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T<R==*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B)7,@870@)7,@)7,B*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97);)W=I;F1$:7)E8W1I
M;VXG72P*("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&UE=&%R+3YC
M;VYV97)T4W!E960H)'=E871H97);)W=I;F0G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1U;FET<ULG=VEN9"==+"`G:W0G*2DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("=K="<I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(B5S
M(&%T("5S("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R
M6R=W:6YD1&ER96-T:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@(')O
M=6YD*"1W96%T:&5R6R=W:6YD)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`D=6YI='-;)W=I;F0G72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS96EF("@H)'=E871H97);)W=I;F1$96=R965S)UT@/3T@)S`P
M,"<I("8F"B`@("`@("`@("`@("`@("`@("`@("`@("@D=V5A=&AE<ELG=VEN
M9"==(#T]("<P)RDI('L*("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN
M=&8H7R@B8V%L;2(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B9G)O;2!T:&4@)7,@*"5S*2!A
M="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=V5A=&AE<ELG=VEN9$1I<F5C=&EO;B==+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=V5A=&AE<ELG=VEN9$1E9W)E97,G72P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@96UP='DH)'1H:7,M/E]P87)A
M;7-;)VMN;W1S)UTI(#\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F]U;F0H)'=E871H97);)W=I;F0G72D@.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R;W5N9"@D;65T87(M/F-O;G9E<G13<&5E9"@D
M=V5A=&AE<ELG=VEN9"==+"`D=6YI='-;)W=I;F0G72P@)VMT)RDI+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W!A
M<F%M<ULG:VYO=',G72D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=6YI='-;)W=I;F0G72`Z"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=K="<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=VEN9$=U<W0G72DI('L*("`@("`@
M("`@("`@:68@*"1W96%T:&5R6R=W:6YD1W5S="==*2!["B`@("`@("`@("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=K;F]T<R==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1H=&UL("X]('-P<FEN=&8H7R@B+"!G=7-T
M:6YG("5S("5S(BDL"B`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1M
M971A<BT^8V]N=F5R=%-P965D*"1W96%T:&5R6R=W:6YD1W5S="==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72P@)VMT)RDI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`G:W0G*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&AT;6P@+CT@<W!R:6YT
M9BA?*"(L(&=U<W1I;F<@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@<F]U;F0H)'=E871H97);)W=I;F1'=7-T)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`D=6YI='-;)W=I;F0G72D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1W
M96%T:&5R6R=W:6YD5F%R:6%B:6QI='DG72DI('L*("`@("`@("`@("`@:68@
M*"1W96%T:&5R6R=W:6YD5F%R:6%B:6QI='DG75LG9G)O;2==*2!["B`@("`@
M("`@("`@("`@("`D:'1M;"`N/2!S<')I;G1F*%\H(BP@=F%R:6%B;&4@9G)O
M;2`E<R!T;R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("1W96%T:&5R6R=W
M:6YD5F%R:6%B:6QI='DG75LG9G)O;2==+`H@("`@("`@("`@("`@("`@("`@
M("1W96%T:&5R6R=W:6YD5F%R:6%B:6QI='DG75LG=&\G72D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%9I<VEB:6QI='DN"B`@("`@
M("`@:68@*&ES<V5T*"1W96%T:&5R6R=V:7-I8FEL:71Y)UTI*2!["B`@("`@
M("`@("`@("1H=&UL("X]("1T:&ES+3Y?<V%M95)O=RA?*")6:7-I8FEL:71Y
M(BDL("1W96%T:&5R6R=V:7-I8FEL:71Y)UT@+B`G("<@+B`D=6YI='-;)W9I
M<R==*3L*("`@("`@("!]"@H@("`@("`@("\O(%1E;7!E<F%T=7)E+T1E=U!O
M:6YT+@H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG=&5M<&5R871U<F4G
M72DI('L*("`@("`@("`@("`@)&AT;6P@+CT@)'1H:7,M/E]R;W<H7R@B5&5M
M<&5R871U<F4B*2P@<F]U;F0H)'=E871H97);)W1E;7!E<F%T=7)E)UTI("X@
M)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R=D97=0;VEN="==
M*2D@>PH@("`@("`@("`@("`D:'1M;"`N/2`D=&AI<RT^7W-A;652;W<H7R@B
M1&5W(%!O:6YT(BDL(')O=6YD*"1W96%T:&5R6R=D97=0;VEN="==*2`N("<F
M9&5G.R<@+B!3=')I;F<Z.G5P<&5R*"1U;FET<ULG=&5M<"==*2D["B`@("`@
M("`@?0H@("`@("`@(&EF("AI<W-E="@D=V5A=&AE<ELG9F5L=%1E;7!E<F%T
M=7)E)UTI*2!["B`@("`@("`@("`@("1H=&UL("X]("1T:&ES+3Y?<V%M95)O
M=RA?*")&965L<R!,:6ME(BDL(')O=6YD*"1W96%T:&5R6R=F96QT5&5M<&5R
M871U<F4G72D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E
M;7`G72DI.PH@("`@("`@('T*"B`@("`@("`@+R\@4')E<W-U<F4N"B`@("`@
M("`@:68@*&ES<V5T*"1W96%T:&5R6R=P<F5S<W5R92==*2D@>PH@("`@("`@
M("`@("`D:'1M;"`N/2`D=&AI<RT^7W)O=RA?*")0<F5S<W5R92(I+"`D=V5A
M=&AE<ELG<')E<W-U<F4G72`N("<@)R`N("1U;FET<ULG<')E<R==*3L*("`@
M("`@("!]"@H@("`@("`@("\O($AU;6ED:71Y+@H@("`@("`@(&EF("AI<W-E
M="@D=V5A=&AE<ELG:'5M:61I='DG72DI('L*("`@("`@("`@("`@)&AT;6P@
M+CT@)'1H:7,M/E]S86UE4F]W*%\H(DAU;6ED:71Y(BDL(')O=6YD*"1W96%T
M:&5R6R=H=6UI9&ET>2==*2`N("<E)RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!#;&]U9',N"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R6R=C;&]U9',G
M72DI('L*("`@("`@("`@("`@)&-L;W5D<R`]("<G.PH@("`@("`@("`@("!F
M;W)E86-H("@D=V5A=&AE<ELG8VQO=61S)UT@87,@)&-L;W5D*2!["B`@("`@
M("`@("`@("`@("`D8VQO=61S("X]("<\8G(@+SXG.PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1C;&]U9%LG:&5I9VAT)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@)&-L;W5D<R`N/2!S<')I;G1F*%\H(B5S(&%T("5S("5S(BDL
M("1C;&]U9%LG86UO=6YT)UTL("1C;&]U9%LG:&5I9VAT)UTL("1U;FET<ULG
M:&5I9VAT)UTI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D8VQO=61S("X]("1C;&]U9%LG86UO=6YT)UT["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&AT;6P@
M+CT@)'1H:7,M/E]R;W<H7R@B0VQO=61S(BDL("1C;&]U9',I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@0V]N9&ET:6]N<RX*("`@("`@("!I9B`H:7-S970H
M)'=E871H97);)V-O;F1I=&EO;B==*2D@>PH@("`@("`@("`@("`D:'1M;"`N
M/2`D=&AI<RT^7W)O=RA?*")#;VYD:71I;VYS(BDL("1W96%T:&5R6R=C;VYD
M:71I;VXG72D["B`@("`@("`@?0H*("`@("`@("`O+R!296UA<FMS+@H@("`@
M("`@(&EF("AI<W-E="@D=V5A=&AE<ELG<F5M87)K)UTI*2!["B`@("`@("`@
M("`@("1R96UA<FMS(#T@)R<["B`@("`@("`@("`@("1O=&AE<B`]("<G.PH@
M("`@("`@("`@("!F;W)E86-H("@D=V5A=&AE<ELG<F5M87)K)UT@87,@)')E
M;6%R:R`]/B`D=F%L=64I('L*("`@("`@("`@("`@("`@('-W:71C:"`H)')E
M;6%R:RD@>PH@("`@("`@("`@("`@("`@8V%S92`G<V5A<')E<W-U<F4G.@H@
M("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B
M4')E<W-U<F4@870@<V5A(&QE=F5L.B`B*2`N("1V86QU92`N("<@)R`N("1U
M;FET<ULG<')E<R==.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&-A<V4@)W!R96-I<&ET871I;VXG.@H@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D<')E8VEP*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1P<F5C:7!;)V%M
M;W5N="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;6%R
M:W,@+CT@)SQB<B`O/B<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('-P<FEN=&8H7R@B4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R
M*',I.B`B*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P<F5C:7!;)VAO=7)S)UTI("X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<')E8VEP6R=A;6]U;G0G72`N("<@)R`N("1U;FET<ULG
M<F%I;B==.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@+CT@)SQB<B`O/B<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H7R@B
M4')E8VEP:71A=&EO;B!F;W(@;&%S="`E<R!H;W5R*',I.B`B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5C:7!;)VAO
M=7)S)UTI("X@)'!R96-I<%LG86UO=6YT)UT["B`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G<VYO=V1E<'1H
M)SH*("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^)R`N
M(%\H(E-N;W<@9&5P=&@Z("(I("X@)'9A;'5E("X@)R`G("X@)'5N:71S6R=R
M86EN)UT["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@
M("`@("`@8V%S92`G<VYO=V5Q=6EV)SH*("`@("`@("`@("`@("`@("`@("`D
M<F5M87)K<R`N/2`G/&)R("\^)R`N(%\H(E-N;W<@97%U:79A;&5N="!I;B!W
M871E<CH@(BD@+B`D=F%L=64@+B`G("<@+B`D=6YI='-;)W)A:6XG73L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E
M("=S=6YD=7)A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@)')E;6%R:W,@
M+CT@)SQB<B`O/B<@+B!S<')I;G1F*%\H(B5S(&UI;G5T97,B*2P@)'9A;'5E
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("<Q:'1E;7`G.@H@("`@("`@("`@("`@("`@("`@("1R96UA<FMS
M("X]("<\8G(@+SXG("X@7R@B5&5M<"!F;W(@;&%S="!H;W5R.B`B*2`N(')O
M=6YD*"1V86QU92D@+B`G)F1E9SLG("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;
M)W1E;7`G72D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`@("`@8V%S92`G,6AD97<G.@H@("`@("`@("`@("`@("`@("`@("1R
M96UA<FMS("X]("<\8G(@+SXG("X@7R@B1&5W(%!O:6YT(&9O<B!L87-T(&AO
M=7(Z("(I("X@<F]U;F0H)'9A;'5E*2`N("<F9&5G.R<@+B!3=')I;F<Z.G5P
M<&5R*"1U;FET<ULG=&5M<"==*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("`@("!C87-E("<V:&UA>'1E;7`G.@H@("`@("`@
M("`@("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B36%X('1E
M;7`@;&%S="`V(&AO=7)S.B`B*2`N(')O=6YD*"1V86QU92D@+B`G)F1E9SLG
M("X@4W1R:6YG.CIU<'!E<B@D=6YI='-;)W1E;7`G72D["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G-FAM:6YT
M96UP)SH*("`@("`@("`@("`@("`@("`@("`D<F5M87)K<R`N/2`G/&)R("\^
M)R`N(%\H(DUI;B!T96UP(&QA<W0@-B!H;W5R<SH@(BD@+B!R;W5N9"@D=F%L
M=64I("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M(&-A<V4@)S(T:&UA>'1E;7`G.@H@("`@("`@("`@("`@("`@("`@("1R96UA
M<FMS("X]("<\8G(@+SXG("X@7R@B36%X('1E;7`@;&%S="`R-"!H;W5R<SH@
M(BD@+B!R;W5N9"@D=F%L=64I("X@)R9D96<[)R`N(%-T<FEN9SHZ=7!P97(H
M)'5N:71S6R=T96UP)UTI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&-A<V4@)S(T:&UI;G1E;7`G.@H@("`@("`@("`@
M("`@("`@("`@("1R96UA<FMS("X]("<\8G(@+SXG("X@7R@B36EN('1E;7`@
M;&%S="`R-"!H;W5R<SH@(BD@+B!R;W5N9"@D=F%L=64I("X@)R9D96<[)R`N
M(%-T<FEN9SHZ=7!P97(H)'5N:71S6R=T96UP)UTI.PH@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W-E;G-O<G,G
M.@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU92!A<R`D<V5N
M<V]R*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R96UA<FMS("X]("<\
M8G(@+SXG("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%\H(E-E;G-O
M<CH@(BD@+B`D<V5N<V]R.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@("`@("1O=&AE<B`N/2`G/&)R("\^)R`N("1V
M86QU93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&AT;6P@+CT@)'1H
M:7,M/E]R;W<H7R@B4F5M87)K<R(I+"`D<F5M87)K<R`N("1O=&AE<BD["B`@
M("`@("`@?0H*("`@("`@("`O+R!4048*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=T868G72DI('L*("`@("`@("`@("`@)'1A9B`]("1M
M971A<BT^9V5T1F]R96-A<W0H)'1H:7,M/E]P87)A;7-;)VQO8V%T:6]N)UTI
M.PH@("`@("`@("`@("!I9B`H(6ES7V$H)'1A9BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@)&9O<F5C87-T(#T@)SQT86)L92!W:61T:#TB
M,3`P)2(@8V5L;'-P86-I;F<](C`B/B<["B`@("`@("`@("`@("`@("`D9F]R
M96-A<W0@+CT@)SQT<CX\=&0@8VQA<W,](F-O;G1R;VPB(&-O;'-P86X](C(B
M/CQC96YT97(^/'-T<F]N9SXG("X@7R@B1F]R96-A<W0@*%1!1BDB*2`N("<\
M+W-T<F]N9SX\+W1D/CPO='(^/"]T86)L93XG.PH@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("<\<W1R;VYG/E9A;&ED.B`\+W-T<F]N9SXG("X@)'1A
M9ELG=F%L:61&<F]M)UT@+B`G("T@)R`N("1T869;)W9A;&ED5&\G72`N("<\
M8G(@+SX\8G(@+SXG.PH@("`@("`@("`@("`@("`@)&ET96T@/2`P.PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)'1A9ELG=&EM92==(&%S("1T:6UE(#T^
M("1E;G1R>2D@>PH@("`@("`@("`@("`@("`@("`@("1I=&5M*RL["B`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\=&%B;&4@=VED=&@](C$P
M,"4B(&-E;&QS<&%C:6YG/2(P(CXG.PH@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G/'1R(&-L87-S/2)I=&5M)R`N("@D:71E;2`E(#(I("X@
M)R(^)SL*("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQT9"!A
M;&EG;CTB8V5N=&5R(B!W:61T:#TB-3`B/B<@+B`D=&EM92`N("<\+W1D/CQT
M9#X\<W1R;VYG/E=I;F0Z/"]S=')O;F<^("<["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1E;G1R>5LG=VEN9"==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H)&5N=')Y6R=W:6YD1&ER96-T:6]N)UT@/3T@)U9A
M<FEA8FQE)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W!A<F%M<ULG:VYO=',G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@<W!R:6YT9BA?*"(E
M<R!A="`E<R`E<R(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')T;VQO=V5R*"1E;G1R>5LG=VEN9$1I<F5C=&EO;B==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F]U;F0H)&UE=&%R
M+3YC;VYV97)T4W!E960H)&5N=')Y6R=W:6YD)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72P@)VMT
M)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:W0G
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]('-P<FEN
M=&8H7R@B)7,@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5N=')Y6R=W:6YD1&ER96-T:6]N)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1E;G1R>5LG=VEN
M9"==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'5N
M:71S6R=W:6YD)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H*"1E;G1R>5LG=VEN
M9$1E9W)E97,G72`]/2`G,#`P)RD@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*"1E;G1R>5LG=VEN9"==(#T]("<P)RDI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2!S<')I;G1F
M*%\H(F-A;&TB*2D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@<W!R
M:6YT9BA?*")F<F]M('1H92`E<R`H)7,I(&%T("5S("5S(BDL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LG
M=VEN9$1I<F5C=&EO;B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D96YT<GE;)W=I;F1$96=R965S)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5M<'1Y
M*"1T:&ES+3Y?<&%R86US6R=K;F]T<R==*2`_"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(')O=6YD*"1E;G1R>5LG=VEN
M9"==*2`Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')O=6YD*"1M971A<BT^8V]N=F5R=%-P965D*"1E;G1R>5LG=VEN
M9"==+"`D=6YI='-;)W=I;F0G72P@)VMT)RDI+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2@D=&AI<RT^7W!A
M<F%M<ULG:VYO=',G72D@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=6YI='-;)W=I;F0G72`Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=K="<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W)E8V%S="`N/2`G/&)R("\^)SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG=&5M<&5R
M871U<F5,;W<G72D@?'P@:7-S970H)&5N=')Y6R=T96UP97)A='5R94AI9V@G
M72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\
M<W1R;VYG/E1E;7!E<F%T=7)E/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1E;G1R>5LG=&5M<&5R871U<F5,;W<G72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G
M/'-T<F]N9SX@3&]W.CPO<W1R;VYG/B<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)&5N=')Y6R=T96UP97)A='5R94QO=R==
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D96YT<GE;)W1E;7!E<F%T=7)E2&EG:"==*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\
M<W1R;VYG/B!(:6=H.CPO<W1R;VYG/B<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)&5N=')Y6R=T96UP97)A='5R94AI9V@G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)SQB<B`O/B<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;
M)W=I;F1S:&5A<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M96-A<W0@+CT@)SQS=')O;F<^5VEN9'-H96%R.CPO<W1R;VYG/B<["B`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2!S<')I;G1F*%\H(F9R
M;VT@=&AE("5S("@E<RD@870@)7,@)7,B*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LG=VEN9'-H96%R1&ER96-T
M:6]N)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D96YT<GE;)W=I;F1S:&5A<D1E9W)E97,G72P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>5LG=VEN9'-H96%R2&5I
M9VAT)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=6YI='-;)VAE:6=H="==*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<F5C87-T("X]("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=V:7-I8FEL
M:71Y)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N
M/2`G/'-T<F]N9SY6:7-I8FEL:71Y.CPO<W1R;VYG/B`G.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@<W1R=&]L;W=E<B@D96YT<GE;
M)W9I<U%U86QI9FEE<B==*2`N("<@)R`N("1E;G1R>5LG=FES:6)I;&ET>2==
M("X@)R`G("X@)'5N:71S6R=V:7,G73L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]("<\8G(@+SXG.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=C;VYD
M:71I;VXG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T
M("X]("<\<W1R;VYG/D-O;F1I=&EO;G,Z/"]S=')O;F<^("<["B`@("`@("`@
M("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`D96YT<GE;)V-O;F1I=&EO
M;B==.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)SQB
M<B`O/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2`G/'-T<F]N9SY#;&]U9',Z/"]S=')O;F<^("<[
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5N=')Y6R=C;&]U9',G
M72!A<R`D8VQO=61S*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D8VQO=61S6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R96-A<W0@+CT@)R`G("X@)&-L;W5D<ULG='EP92==.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S="`N/2`G("<@+B`D8VQO=61S6R=A;6]U;G0G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1C;&]U9'-;)VAE:6=H
M="==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T
M("X]("<@870@)R`N("1C;&]U9'-;)VAE:6=H="==("X@)R`G("X@)'5N:71S
M6R=H96EG:'0G73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G("<[
M"B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<\+W1D/CPO
M='(^)SL*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&5N=')Y6R=F
M;6,G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ET96TK*SL*("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5N=')Y6R=F;6,G72!A
M<R`D9FUC16YT<GDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G/'1R(&-L87-S/2)I=&5M)R`N("@D:71E;2`E(#(I("X@
M)R(^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N
M/2`G/'1D(&%L:6=N/2)C96YT97(B('=I9'1H/2(U,"(^)SL*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G*B`G("X@)&9M8T5N
M=')Y6R=F<F]M)UT@+B`G/&)R("\^("T@)R`N("1F;6-%;G1R>5LG=&\G72`N
M("<\+W1D/B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R96-A
M<W0@+CT@)SQT9#XG.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<F5C87-T("X]("<\<W1R;VYG/E1Y<&4Z(#PO<W1R;VYG/B<@+B`D9FUC16YT
M<GE;)W1Y<&4G73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D9FUC16YT<GE;)W!R;V)A8FEL:71Y)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@/'-T<F]N9SX@
M4')O8CH@/"]S=')O;F<^)R`N("1F;6-%;G1R>5LG<')O8F%B:6QI='DG72`N
M("<E)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FUC16YT<GE;)V-O;F1I
M=&EO;B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F
M;W)E8V%S="`N/2`G(#QS=')O;F<^($-O;F1I=&EO;G,Z(#PO<W1R;VYG/B<@
M+B`D9FUC16YT<GE;)V-O;F1I=&EO;B==.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1F;6-%;G1R>5LG8VQO=61S)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@/'-T<F]N9SY#;&]U9',Z
M/"]S=')O;F<^)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9FUC16YT<GE;)V-L;W5D<R==(&%S("1F;6-#;&]U9',I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1F;6-#;&]U9'-;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G("<@+B`D9FUC0VQO
M=61S6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1F;6-#;&]U9'-;)VAE:6=H="==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@)R`N
M("1F;6-#;&]U9'-;)V%M;W5N="==.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&9O<F5C87-T("X]("<@)R`N("1F;6-#;&]U
M9'-;)VAE:6=H="==.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O<F5C87-T("X]("<@)R`N("1U;FET<ULG:&5I9VAT)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M96-A<W0@+CT@)R`G("X@)&9M8T-L;W5D<ULG86UO=6YT)UT["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9M
M8T5N=')Y6R=V:7-1=6%L:69I97(G72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]R96-A<W0@+CT@)R`\<W1R;VYG/E9I<VEB:6QI
M='DZ/"]S=')O;F<^("<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]('-T<G1O;&]W97(H)&9M8T5N=')Y6R=V:7-1=6%L
M:69I97(G72D@+B`G("<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9O<F5C87-T("X]("1F;6-%;G1R>5LG=FES:6)I;&ET>2==("X@)R`G
M("X@)'5N:71S6R=V:7,G73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)E8V%S="`N/2`G
M/"]T9#X\+W1R/B<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&9O<F5C87-T("X]("<\+W1A8FQE/B<["@H@("`@("`@("`@("`@
M("`@)&AT;6P@+CT@)&9O<F5C87-T.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&AT;6P["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]";&]C:R]C;VQO<BYP:'``
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,38V
M-2`Q,#4Q-30S-#$S-R`P,C$Q-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\O(%1H:7,@8FQO8VL@:7,@86X@
M97AA;7!L92!A;F0@<')O8F%B;'D@;F]T('5S969U;"!T;R!U<V5R<RX*+R\@
M)&)L;V-K7VYA;64@/2!?*")#;VQO<B(I.PH*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O;&EB+T)L;V-K+V-O;&]R+G!H<"QV(#$N,3(@,C`P-"\P-B\P,2`Q,#HP
M-3HS,2!J86X@17AP("0*("H*("H@0'!A8VMA9V4@2&]R9&5?0FQO8VL*("HO
M"F-L87-S($AO<F1E7T)L;V-K7TAO<F1E7V-O;&]R(&5X=&5N9',@2&]R9&5?
M0FQO8VL@>PH*("`@('9A<B`D7V%P<"`]("=H;W)D92<["@H@("`@9G5N8W1I
M;VX@7W!A<F%M<R@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=T>7!E
M)R`]/B`G=&5X="<L"B`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B!?
M*")#;VQO<B(I+`H@("`@("`@("`@("`@("`@("`@("`G9&5F875L="<@/3X@
M)R-F9C`P,#`G*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!T:71L92!T
M;R!G;R!I;B!T:&ES(&)L;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("`@5&AE('1I=&QE('1E>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T
M:71L92@I"B`@("!["B`@("`@("`@<F5T=7)N(%\H(D-O;&]R(BD["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8V]N=&5N="!T;R!G;R!I;B!T:&ES(&)L
M;V-K+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("`@5&AE(&-O;G1E
M;G0*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G1E;G0H*0H@("`@>PH@("`@
M("`@("1H=&UL("`]("<\=&%B;&4@=VED=&@](C$P,"(@:&5I9VAT/2(Q,#`B
M(&)G8V]L;W(](B5S(CXG.PH@("`@("`@("1H=&UL("X]("<\='(^/'1D/B9N
M8G-P.SPO=&0^/"]T<CXG.PH@("`@("`@("1H=&UL("X]("<\+W1A8FQE/B<[
M"@H@("`@("`@(')E='5R;B!S<')I;G1F*"1H=&UL+"`D=&AI<RT^7W!A<F%M
M<ULG8V]L;W(G72D["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I
M=&5R````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S-B`P,C`U,3$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+U9&4R])4T]7<FET97(N<&AP````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V-3,W(#$P-3$U-#,T,3,V(#`R,3,Q-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`H*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["@HO*BH*("H@5D93($%022!F
M;W(@86)S=')A8W1E9"!C<F5A=&EO;B!O9B!)4T\@*$-$+5)/32D@9FEL97-Y
M<W1E;7,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4U])4T]7<FET97(O
M25-/5W)I=&5R+G!H<"QV(#$N,2XX+C<@,C`P-B\P,2\P,2`R,3HR.#HT,R!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@
M3$Q#(#QH='1P.B\O=W=W+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!*87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S
M>7,N8V]M/@H@*B!`<&%C:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E
M(#,N,`H@*B\*8VQA<W,@5D937TE33U=R:71E<B!["@H@("`@+RHJ"B`@("`@
M*B!!(%9&4R!O8FIE8W0@=7-E9"!F;W(@<F5A9&EN9R!T:&4@<V]U<F-E(&9I
M;&5S"B`@("`@*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@("`@=F%R("1?
M<V]U<F-E5F9S(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($$@5D93(&]B:F5C
M="!U<V5D(&9O<B!W<FET:6YG('1H92!)4T\@:6UA9V4*("`@("`J"B`@("`@
M*B!`=F%R(%9&4PH@("`@("HO"B`@("!V87(@)%]T87)G97169G,@/2!N=6QL
M.PH*("`@("\J*@H@("`@("H@2&%S:"!C;VYT86EN:6YG(&-O;FYE8W1I;VX@
M<&%R86UE=&5R<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7W!A<F%M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1S(&$@;F5W(%9&4U])4T]7<FET97(@;V)J96-T"B`@("`@*@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@($$@:&%S:"!C;VYT86EN:6YG
M('!A<F%M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9&4U])4T]7<FET
M97(H)B1S;W5R8V569G,L("8D=&%R9V5T5F9S+"`D<&%R86US*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<V]U<F-E5F9S(#T@)B1S;W5R8V569G,["B`@("`@
M("`@)'1H:7,M/E]T87)G97169G,@/2`F)'1A<F=E=%9F<SL*("`@("`@("`D
M=&AI<RT^7W!A<F%M<R`]("1P87)A;7,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&4@=&AE($E33R!I;6%G90H@("`@("H*("`@("`J($!A8G-T<F%C
M=`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($YU;&P@;W(@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!P<F]C97-S
M*"D*("`@('L*("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*").
M;W0@:6UP;&5M96YT960N(BDI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T
M96UP="!T;R!C<F5A=&4@82!C;VYC<F5T92!61E-?25-/5W)I=&5R('-U8F-L
M87-S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D('5S97,@:71S('!A<F%M
M971E<G,@86YD(&-H96-K<R!T:&4@<WES=&5M('1O(&1E=&5R;6EN90H@("`@
M("H@=&AE(&UO<W0@87!P<F]P<FEA=&4@<W5B8VQA<W,@=&\@=7-E(&9O<B!B
M=6EL9&EN9R!)4T\@:6UA9V5S+B`@268*("`@("`J(&YO;F4@:7,@9F]U;F0L
M(&%N(&5R<F]R(&ES(')A:7-E9"X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J
M96-T("8D<V]U<F-E5F9S("`@("`@4F5F97)E;F-E('1O('1H92!61E,@;V)J
M96-T(&9R;VT@=VAI8V@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@9FEL97,@=VEL;"!B92!R96%D('1O(&-R96%T92!T:&4*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!)4T\@:6UA
M9V4N"B`@("`@*B!`<&%R86T@;V)J96-T("8D=&%R9V5T5F9S("`@("`@4F5F
M97)E;F-E('1O('1H92!61E,@;V)J96-T('1O('=H:6-H('1H90H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($E33R!I;6%G92!W:6QL
M(&)E('=R:71T96XN"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@("`@
M("`@("`@2&%S:"!O9B!P87)A;65T97)S(&9O<B!C<F5A=&EN9R!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;6%G93H*("`@
M("`J("`@("`@("`@("`@("`G<V]U<F-E4F]O="<@/3X@("`@($$@9&ER96-T
M;W)Y(&EN('1H92!S;W5R8V4@5D93(&9O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9FEL97,@=&\@8F4@<F5A9"!F<F]M(&9O
M<B!T:&4@:6UA9V4N"B`@("`@*B`@("`@("`@("`@("`@)W1A<F=E=$9I;&4G
M(#T^("`@("!0871H(&%N9"!F:6QE;F%M92!O9B!T:&4@25-/(&9I;&4@=&\*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('=R:71E
M(&EN=&\@=&AE('1A<F=E="!61E,N"B`@("`@*@H@("`@("H@0')E='5R;B!O
M8FIE8W0@("`@("`@("`@("`@("`@($$@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!61E-?25-/5W)I=&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<W5B8VQA<W,L(&]R(&$@4$5!4E]%<G)O<B!O;B!A;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)B1S;W5R8V569G,L
M("8D=&%R9V5T5F9S+"`D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AE;7!T
M>2@D<&%R86US6R=T87)G971&:6QE)UTI*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!P<F]C965D('=I=&AO=70@
M)W1A<F=E=$9I;&4G('!A<F%M971E<BXB*2D["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D<&%R86US6R=S;W5R8V52;V]T)UTI*2!["B`@("`@("`@
M("`@("1P87)A;7-;)W-O=7)C95)O;W0G72`]("<O)SL*("`@("`@("!]"@H@
M("`@("`@("\J(%)I9VAT(&YO=RP@;6MI<V]F<R!I<R!T:&4@;VYL>2!D<FEV
M97(L(&)U="!M86ME('-U<F4@=V4@8V%N"B`@("`@("`@("H@<W5P<&]R="!I
M="X@*B\*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+TE33U=R:71E<B]M:VES;V9S+G!H<"<["B`@("`@("`@:68@*%9&4U])
M4T]7<FET97)?;6MI<V]F<SHZ<W1R871E9WE!=F%I;&%B;&4H*2D@>PH@("`@
M("`@("`@("`D:7-O=W)I=&5R(#T@)FYE=R!61E-?25-/5W)I=&5R7VUK:7-O
M9G,H)'-O=7)C959F<RP@)'1A<F=E=%9F<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,I.PH@
M("`@("`@("`@("!R971U<FX@)&ES;W=R:71E<CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO(&%V86EL86)L92!S
M=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N(BDI.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]61E,O3V)J96-T+G!H<```````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`R,3(R-2`Q,#4Q-30S-#$S-B`P,C`V-C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO5D93
M+G!H<"<["@HO*BH*("H@02!W<F%P<&5R(&9O<B!T:&4@5D93(&-L87-S('1O
M(')E='5R;B!O8FIE8W1S+"!I;G-T96%D(&]F(&%R<F%Y<RX*("H*("H@)$AO
M<F1E.B!F<F%M97=O<FLO5D93+U9&4R]/8FIE8W0N<&AP+'8@,2XQ,BXQ,"XQ
M,2`R,#`V+S`U+S,Q(#`T.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P-B!*;VX@5V]O9"`\:F]N0&IE;&QY8F]B+F-O+G5K
M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC
M96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E
M8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL
M969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F]N(%=O;V0@/&IO;D!J
M96QL>6)O8BYC;RYU:SX*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?
M3V)J96-T('L*"B`@("`O*BH*("`@("`J(%1H92!A8W1U86P@=F9S('1H870@
M9&]E<R!T:&4@=V]R:PH@("`@("H*("`@("`J($!V87(@5D93"B`@("`@*B\*
M("`@('9A<B`D7W9F<SL*"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT('!A
M=&@@=&AA="!H87,@8F5E;B!P87-S960@=&\@;&ES=$9O;&1E<BP@:68@=&AI
M<PH@("`@("H@8VAA;F=E<RP@=&AE(&QI<W0@=VEL;"!B92!R96)U:6QT+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-U
M<G)E;G10871H.PH*("`@("\J*@H@("`@("H@5&AE(')E='5R;B!V86QU92!F
M<F]M(&$@<W1A;F1A<F0@5D93(&QI<W1&;VQD97(@8V%L;"P@=&\*("`@("`J
M(&)E(')E860@=VET:"!T:&4@3V)J96-T(&QI<W1&;VQD97(N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]F;VQD97),:7-T
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@
M268@>6]U('!A<W,@:6X@86X@97AI<W1I;F<@5D93(&]B:F5C="P@:70@=VEL
M;"!B92!U<V5D(&%S('1H92!61E,*("`@("`J(&]B:F5C="!F;W(@=&AI<R!O
M8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(%9&4R`F)'9F<R`@5&AE(%9&
M4R!O8FIE8W0@=&\@=W)A<"X*("`@("`J+PH@("`@9G5N8W1I;VX@5D937T]B
M:F5C="@F)'9F<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'9F<RDI('L*
M("`@("`@("`@("`@)'1H:7,M/E]V9G,@/2`D=F9S.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(&-O;F-R
M971E(%9&4U]/8FIE8W0@:6YS=&%N8V4@8F%S960@;VX@)&1R:79E<BX*("`@
M("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1R:79E<B`@5&AE('1Y<&4@;V8@
M8V]N8W)E=&4@5D93('-U8F-L87-S('1O(')E='5R;BX@268*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`D9')I=F5R(&ES(&%N(&%R<F%Y('1H96X@
M=V4@=VEL;"!L;V]K(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M)&1R:79E<ELP72]L:6(O5D93+R!F;W(@=&AE('-U8F-L87-S"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@:6UP;&5M96YT871I;VX@;F%M960@)&1R
M:79E<ELQ72YP:'`N"B`@("`@*B!`<&%R86T@87)R87D@)'!A<F%M<R`@02!H
M87-H(&-O;G1A:6YI;F<@86YY(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;B!O
M<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W1I;VX@<&%R
M86UE=&5R<R!A('-U8F-L87-S(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@
M0')E='5R;B!61E-?3V)J96-T("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T
M92!61E-?3V)J96-T(&EN<W1A;F-E+"!O<@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("!F86QS92!O;B!A;B!E<G)O<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@)'9F<R`]("961E,Z.F9A8W1O<GDH)&1R:79E<BP@)'!A<F%M
M<R`](&%R<F%Y*"DI.PH@("`@("`@("1V9G-O8FIE8W0@/2`F;F5W(%9&4U]/
M8FIE8W0H)'9F<RD["B`@("`@("`@<F5T=7)N("1V9G-O8FIE8W0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T;R!R971U<FX@82!R969E<F5N
M8V4@=&\@82!C;VYC<F5T92!61E,@:6YS=&%N8V4*("`@("`J(&)A<V5D(&]N
M("1D<FEV97(N($ET('=I;&P@;VYL>2!C<F5A=&4@82!N97<@:6YS=&%N8V4@
M:68@;F\*("`@("`J(%9&4R!I;G-T86YC92!W:71H('1H92!S86UE('!A<F%M
M971E<G,@8W5R<F5N=&QY(&5X:7-T<RX*("`@("`J"B`@("`@*B!4:&ES('-H
M;W5L9"!B92!U<V5D(&EF(&UU;'1I<&QE('1Y<&5S(&]F(&9I;&4@8F%C:V5N
M9',@*&%N9"P*("`@("`J('1H=7,L(&UU;'1I<&QE(%9&4R!I;G-T86YC97,I
M(&%R92!R97%U:7)E9"X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M=7-T
M(&)E(&EN=F]K960@87,Z("1V87(@/2`F5D93.CIS:6YG;&5T;VXH*0H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`D9')I=F5R("!4:&4@='EP92!O9B!C
M;VYC<F5T92!61E,@<W5B8VQA<W,@=&\@<F5T=7)N+B!)9@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("1D<FEV97(@:7,@86X@87)R87D@=&AE;B!W
M92!W:6QL(&QO;VL@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`D
M9')I=F5R6S!=+VQI8B]61E,O(&9O<B!T:&4@<W5B8VQA<W,*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!I;7!L96UE;G1A=&EO;B!N86UE9"`D9')I
M=F5R6S%=+G!H<"X*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!(&AA
M<V@@8V]N=&%I;FEN9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N(&]R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@8V]N;F5C=&EO;B!P87)A
M;65T97)S(&$@<W5B8VQA<W,@;6EG:'0@;F5E9"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(%9&4U]/8FIE8W0@(%1H92!C;VYC<F5T92!61E-?3V)J96-T(')E
M9F5R96YC92P@;W(@9F%L<V4@;VX*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&1R
M:79E<BP@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'9F<R`]
M("961E,Z.G-I;F=L971O;B@D9')I=F5R+"`D<&%R86US(#T@87)R87DH*2D[
M"B`@("`@("`@)'9F<V]B:F5C="`]("9N97<@5D937T]B:F5C="@D=F9S*3L*
M("`@("`@("!R971U<FX@)'9F<V]B:F5C=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($-H96-K('1H92!C<F5D96YT:6%L<R!T:&%T('=E(&AA=F4@=&\@<V5E
M(&EF('1H97)E(&ES(&$@=F%L:60@;&]G:6XN"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R(&1E<V-R
M:6)I;F<@=&AE('!R;V)L96T*("`@("`J("`@("`@("`@("`@("`@(&EF('1H
M92!C<F5D96YT:6%L<R!A<F4@:6YV86QI9"X*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VAE8VM#<F5D96YT:6%L<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=F9S+3YC:&5C:T-R961E;G1I86QS*"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3970@8V]N9FEG=7)A=&EO;B!P87)A;65T97)S+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US("!!;B!A<W-O8VEA=&EV92!A
M<G)A>2!O9B!P87)A;65T97(@;F%M92]V86QU90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@('!A:7)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S9710
M87)A;7,H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M
M/E]V9G,M/G-E=%!A<F%M<R@D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E=')I979E(&$@9FEL92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F
M:6QE+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!D
M871A+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1P871H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^<F5A9"AD:7)N86UE*"1P871H
M*2P@8F%S96YA;64H)'!A=&@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-T
M;W)E(&$@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL
M92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@
M=&5M<&]R87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;R!B90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T;W)E9"X*("`@("`J
M($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R
M96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)'1M
M<$9I;&4L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=F9S+3YW<FET92AD:7)N86UE*"1P871H*2P@8F%S96YA
M;64H)'!A=&@I+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4@/2!F86QS92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&4R!F
M<F]M(')A=R!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@
M("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A
M+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I
M8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T
M82@D<&%T:"P@)&1A=&$L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YW<FET941A=&$H9&ER;F%M92@D
M<&%T:"DL(&)A<V5N86UE*"1P871H*2P@)&1A=&$L("1A=71O8W)E871E(#T@
M9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9FEL92!F
M<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T
M:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E;&5T949I;&4H)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=F9S+3YD96QE=&5&:6QE*&1I<FYA;64H)'!A=&@I+"!B87-E;F%M
M92@D<&%T:"DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5N86UE(&$@9FEL
M92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L
M9'!A=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I
M;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I
M;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@
M<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@)&YE=W!A=&@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F9S+3YR96YA;64H9&ER
M;F%M92@D;VQD<&%T:"DL(&)A<V5N86UE*"1O;&1P871H*2P@9&ER;F%M92@D
M;F5W<&%T:"DL(&)A<V5N86UE*"1N97=P871H*2D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&4@82!F;VQD97(@:6X@=&AE(%9&4RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!T:&4@9F]L
M9&5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]V9G,M/F-R96%T949O;&1E<BAD:7)N86UE
M*"1P871H*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9F]L
M9&5R(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H(%1H92!P871H(&]F('1H92!F;VQD97(@=&\@9&5L971E+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T949O;&1E<B@D<&%T:"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]V9G,M/F1E;&5T949O;&1E<BAD:7)N86UE*"1P871H*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@5D937TQI<W1)=&5M
M(&]B:F5C="!I9B!T:&4@9F]L9&5R(&-A;@H@("`@("H@8F4@<F5A9"P@;W(@
M82!014%27T5R<F]R(&EF(&ET(&-A;B=T(&)E+B!2971U<FYS(&9A;'-E(&]N
M8V4*("`@("`J('1H92!F;VQD97(@:&%S(&)E96X@8V]M<&QE=&5L>2!R96%D
M+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H
M(&]F('1H92!D:7)E=&]R>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!&:6QE(&QI<W0@*&%R<F%Y*2!O;B!S=6-C97-S+"!A(%!%05)?17)R;W(*
M("`@("`J("`@("`@("`@("`@("`@(&]B:F5C="!O;B!F86EL=7)E+"!O<B!F
M86QS92!I9B!T:&4@9F]L9&5R(&ES"B`@("`@*B`@("`@("`@("`@("`@("!C
M;VUP;&5T96QY(')E860N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD
M97(H)'!A=&@I"B`@("!["B`@("`@("`@:68@*"$H)'!A=&@@/3T]("1T:&ES
M+3Y?8W5R<F5N=%!A=&@I*2!["B`@("`@("`@("`@("1F;VQD97),:7-T(#T@
M)'1H:7,M/E]V9G,M/FQI<W1&;VQD97(H)'!A=&@I.PH@("`@("`@("`@("!I
M9B`H)&9O;&1E<DQI<W0I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9F]L
M9&5R3&ES="`]("1F;VQD97),:7-T.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)R96YT4&%T:"`]("1P871H.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT
M9BA?*")#;W5L9"!N;W0@<F5A9"`E<RXB*2P@)'!A=&@I*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R],:7-T271E;2YP:'`G.PH@("`@("`@(&EF("@D9FEL
M92`](&%R<F%Y7W-H:69T*"1T:&ES+3Y?9F]L9&5R3&ES="DI('L*("`@("`@
M("`@("`@)&9I;&4@/2`F;F5W(%9&4U],:7-T271E;2@D<&%T:"P@)&9I;&4I
M.PH@("`@("`@("`@("!R971U<FX@)&9I;&4["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($-H86YG97,@<&5R;6ES<VEO;G,@9F]R(&%N($ET96T@
M;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@("!(;VQD<R!T:&4@<&%T:"!O9B!D:7)E8W1O<GD@;V8@=&AE($ET
M96TN"B`@("`@*B!`<&%R86T@<W1R:6YG("1P97)M:7-S:6]N("!43T1/"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@8VAA;F=E4&5R;6ES<VEO;G,H)'!A=&@L("1P97)M:7-S:6]N
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^8VAA;F=E4&5R
M;6ES<VEO;G,H9&ER;F%M92@D<&%T:"DL(&)A<V5N86UE*"1P871H*2P@)'!E
M<FUI<W-I;VXI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N('1H92!L
M:7-T(&]F(&%D9&ET:6]N86P@8W)E9&5N=&EA;',@<F5Q=6ER960L(&EF(&%N
M>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!#<F5D96YT:6%L(&QI
M<W0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<75I<F5D0W)E9&5N=&EA
M;',H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^9V5T4F5Q
M=6ER961#<F5D96YT:6%L<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N('1H92!A<G)A>2!S<&5C:69I8WEI;F<@=VAA="!P97)M:7-S:6]N<R!A
M<F4@8VAA;F=E86)L92!F;W(@=&AI<PH@("`@("H@:6UP;&5M96YT871I;VXN
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@0VAA;F=E86)L92!P97)M
M:7-I;VYS+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971-;V1I9FEA8FQE4&5R
M;6ES<VEO;G,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W9F<RT^
M9V5T36]D:69I86)L95!E<FUI<W-I;VYS*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;&]S92!A;GD@<F5S;W5R8V5S('1H870@;F5E9"!T;R!B92!C;&]S
M960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D=&AI<RT^
M7W9F<RT^7V1I<V-O;FYE8W0H*3L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+U9&4R]S;6(N<&AP````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#4V,#$V(#$P-3$U-#,T,3,V
M(#`R,#(T,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@4W1A=&5L97-S(%9&4R!I;7!L96UE;G1A=&EO
M;B!F;W(@82!334(@<V5R=F5R+"!B87-E9"!O;B!S;6)C;&EE;G0N"B`J"B`J
M(%)E<75I<F5D('9A;'5E<R!F;W(@)'!A<F%M<SH*("H@/'!R93X*("H@("`G
M=7-E<FYA;64G("`M(%1H92!U<V5R;F%M92!W:71H('=H:6-H('1O(&-O;FYE
M8W0@=&\@=&AE(%--0B!S97)V97(N"B`J("`@)W!A<W-W;W)D)R`@+2!4:&4@
M<&%S<W=O<F0@=VET:"!W:&EC:"!T;R!C;VYN96-T('1O('1H92!334(@<V5R
M=F5R+@H@*B`@("=H;W-T<W!E8R<@("T@5&AE(%--0B!S97)V97(@=&\@8V]N
M;F5C="!T;RX*("H@("`G<&]R="<@("`@("`M(%1H92!334(@<&]R="!N=6UB
M97(@=&\@8V]N;F5C="!T;RX*("H@("`G<VAA<F4G("`@("`M(%1H92!S:&%R
M92!T;R!A8V-E<W,@;VX@=&AE(%--0B!S97)V97(N"B`J("`@)W-M8F-L:65N
M="<@+2!4:&4@<&%T:"!T;R!T:&4@)W-M8F-L:65N="<@97AE8W5T86)L92X*
M("H@/"]P<F4^"B`J"B`J($]P=&EO;F%L('9A;'5E<R!F;W(@)'!A<F%M<SH*
M("H@/'!R93X*("H@("`G:7!A9&1R97-S)R`M(%1H92!A9&1R97-S(&]F('1H
M92!S97)V97(@=&\@8V]N;F5C="!T;RX*("H@/"]P<F4^"B`J"B`J($9U;F-T
M:6]N<R!N;W0@:6UP;&5M96YT960Z"B`J("`@+2!C:&%N9V5097)M:7-S:6]N
M<R@I.B!4:&4@4TU"('!E<FUI<W-I;VX@<W1Y;&4@9&]E<R!N;W0@9FET('=I
M=&@@=&AE"B`J("`@("`@("`@("`@("`@("`@("`@("`@("!M;V1U;&4N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O<VUB+G!H<"QV(#$N,3$N
M,BXX(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@*B!#
M;V1E8F%S92!C;W!Y<FEG:'0@,C`P,B!0875L($=A<F5A=2`\<&%U;$!X:&%W
M:RYN970^+B`@061A<'1E9"!W:71H"B`J('!E<FUI<W-I;VX@8GD@4&%T<FEC
M92!,979E<W%U92`\=V%Y;F5`<'1A9F8N8V$^(&9R;VT@<&AP<VUB+3`N."!C
M;V1E+"!A;F0*("H@8V]N=F5R=&5D('1O('1H92!,1U!,+B`@4&QE87-E(&1O
M(&YO="!T875N="!O<FEG:6YA;"!A=71H;W(L(&-O;G1A8W0*("H@4&%T<FEC
M92!,979E<W%U92!O<B!D979`;&ES=',N:&]R9&4N;W)G+@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@4&%U;"!'87)E874@/'!A=6Q`>&AA=VLN;F5T
M/@H@*B!`875T:&]R("!0871R:6-E($QE=F5S<75E(#QW87EN94!P=&%F9BYC
M83X*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K86=E(%9&4PH@*B\*
M8VQA<W,@5D937W-M8B!E>'1E;F1S(%9&4R!["@H@("`@+RHJ"B`@("`@*B!,
M:7-T(&]F(&%D9&ET:6]N86P@8W)E9&5N=&EA;',@<F5Q=6ER960@9F]R('1H
M:7,@5D93(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)%]C<F5D96YT:6%L<R`](&%R<F%Y*"=U<V5R;F%M92<L
M("=P87-S=V]R9"<I.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!P97)M:7-S
M:6]N<R!A;F0@:68@=&AE>2!C86X@8F4@8VAA;F=E9"!I;B!T:&ES(%9&4R!B
M86-K96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?<&5R;6ES<VEO;G,@/2!A<G)A>2@*("`@("`@("`G;W=N97(G(#T^
M(&%R<F%Y*"=R96%D)R`]/B!F86QS92P@)W=R:71E)R`]/B!F86QS92P@)V5X
M96-U=&4G(#T^(&9A;'-E*2P*("`@("`@("`G9W)O=7`G(#T^(&%R<F%Y*"=R
M96%D)R`]/B!F86QS92P@)W=R:71E)R`]/B!F86QS92P@)V5X96-U=&4G(#T^
M(&9A;'-E*2P*("`@("`@("`G86QL)R`@(#T^(&%R<F%Y*"=R96%D)R`]/B!F
M86QS92P@)W=R:71E)R`]/B!F86QS92P@)V5X96-U=&4G(#T^(&9A;'-E*2D[
M"@H@("`@+RHJ"B`@("`@*B!!=71H96YT:6-A=&5S(&$@=7-E<B!O;B!T:&4@
M4TU"('-E<G9E<B!A;F0@<VAA<F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R
M;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@
M("`@("1C;60@/2!A<G)A>2@G<75I="<I.PH@("`@("`@("1E<G(@/2`D=&AI
M<RT^7V-O;6UA;F0H)R<L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H7R@B075T:&5N=&EC871I;VX@=&\@=&AE(%--0B!S97)V97(@
M9F%I;&5D+B(I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@82!F:6QE(&9R;VT@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@
M<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(')E860H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&QI<W0H
M)'!A=&@L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE;&Q#;VUM86YD*"1P
M871H+"`D;F%M92D["B`@("`@("`@)'1E;7`@/2`D=&AI<RT^7V=E=%1E;7!&
M:6QE*"D["B`@("`@("`@)&-M9"`](&%R<F%Y*"=G970@7"(G("X@)&YA;64@
M+B`G7"(@)R`N("1T96UP*3L*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM
M86YD*"1P871H+"`D8VUD*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@
M('T*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1T96UP*2D@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L
M92!T;R!O<&5N(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"B`@("`@("`@:68@*&9U;F-T
M:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@
M("`D9FEL92`](&9I;&5?9V5T7V-O;G1E;G1S*"1T96UP*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D9G`@/2!F;W!E;B@D=&5M<"P@)W(G*3L*
M("`@("`@("`@("`@)&9I;&4@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1T96UP
M*2D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*("`@("`@
M("!U;FQI;FLH)'1E;7`I.PH@("`@("`@(&EF("@D9FEL92D@>PH@("`@("`@
M("`@("!R971U<FX@)&9I;&4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@
M=&\@;W!E;B!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D
M<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4W1O<F5S(&$@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T
M:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@
M("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&UP1FEL92`@("`@(%1H92!T96UP;W)A<GD@9FEL92!C;VYT86EN:6YG('1H
M92!D871A('1O(&)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<W1O<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@
M($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R:65S/PH@("`@("H*("`@
M("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U8V-E
M<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('=R:71E*"1P871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E
M871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@1&]U8FQE('%U;W1E<R!N
M;W0@86QL;W=E9"!I;B!334(@9FEL96YA;64N"B`@("`@("`@)&YA;64@/2!S
M=')?<F5P;&%C92@G(B<L("(G(BP@)&YA;64I.PH*("`@("`@("!L:7-T*"1P
M871H+"`D;F%M92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T
M:"P@)&YA;64I.PH@("`@("`@("1C;60@/2!A<G)A>2@G<'5T(%PB)R`N("1T
M;7!&:6QE("X@)UPB(%PB)R`N("1N86UE("X@)UPB)RD["B`@("`@("`@+R\@
M9&\@=V4@;F5E9"!T;R!F:7)S="!A=71O8W)E871E('1H92!D:7)E8W1O<GD_
M"B`@("`@("`@:68@*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("1R97-U
M;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)'!A=&@I.PH@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D97)R(#T@)'1H:7,M/E]C;VUM86YD*"1P871H+"`D8VUD
M*3L*("`@("`@("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@
M:6X@=&AE(%9&4R!F<F]M(')A=R!D871A+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@
M9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4
M:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T
M82`@("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I
M97,_"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?17)R;W(@
M(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M92P@
M)&1A=&$L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1M
M<$9I;&4@/2`D=&AI<RT^7V=E=%1E;7!&:6QE*"D["B`@("`@("`@)&9P(#T@
M9F]P96XH)'1M<$9I;&4L("=W8B<I.PH@("`@("`@(&9W<FET92@D9G`L("1D
M871A*3L*("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/G=R:71E*"1P871H+"`D;F%M92P@)'1M<$9I;&4L("1A=71O8W)E
M871E*3L*("`@("`@("!U;FQI;FLH)'1M<$9I;&4I.PH@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A(&9I
M;&4@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@(%1H92!P871H('1O(&1E;&5T92!T:&4@9FEL92!F<F]M+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!D96QE=&5&:6QE*"1P871H+"`D;F%M92D*("`@
M('L*("`@("`@("!L:7-T*"1P871H+"`D;F%M92D@/2`D=&AI<RT^7V5S8V%P
M95-H96QL0V]M;6%N9"@D<&%T:"P@)&YA;64I.PH@("`@("`@("1C;60@/2!A
M<G)A>2@G9&5L(%PB)R`N("1N86UE("X@)UPB)RD["B`@("`@("`@)&5R<B`]
M("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@("`@:68@*&ES
M7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<CL*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!G:79E;B!P871H;F%M92!I<R!A
M(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%T:"!T;R!T:&4@9F]L9&5R+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&9I;&4@;W(@9F]L9&5R(&YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&ET(&ES(&$@9F]L9&5R+"!F86QS
M92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1F]L9&5R*"1P
M871H+"`D;F%M92D*("`@('L*("`@("`@("!L:7-T*"1P871H+"`D;F%M92D@
M/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T:"P@)&YA;64I.PH@
M("`@("`@("1C;60@/2!A<G)A>2@G<75I="<I.PH@("`@("`@("1E<G(@/2`D
M=&AI<RT^7V-O;6UA;F0H)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DL
M("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1E<G(L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T97,@
M82!F;VQD97(@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@(%1H92!P871H('1O(&1E;&5T92!T:&4@9F]L
M9&5R(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4
M:&4@;F%M92!O9B!T:&4@9F]L9&5R('1O(&1E;&5T92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1R96-U<G-I=F4@($9O<F-E(&$@<F5C=7)S:79E(&1E;&5T
M93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B`@
M5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!D96QE=&5&;VQD97(H)'!A=&@L("1N86UE
M+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&ES1&ER(#T@
M9F%L<V4["B`@("`@("`@)&1I<D-H96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H
M)'!A=&@I.PH@("`@("`@(&9O<F5A8V@@*"1D:7)#:&5C:R!A<R`D9FEL92D@
M>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92`F)B`D
M9FEL95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("1I
M<T1I<B`]('1R=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D:7-$:7(I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")<(B5S
M7"(@:7,@;F]T(&$@9&ER96-T;W)Y+B(I+"`D<&%T:"`N("<O)R`N("1N86UE
M*2D["B`@("`@("`@?0H*("`@("`@("`D9FEL95]L:7-T(#T@)'1H:7,M/FQI
M<W1&;VQD97(H)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI.PH@("`@
M("`@(&EF("AI<U]A*"1F:6QE7VQI<W0L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1F:6QE7VQI<W0["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&9I;&5?;&ES="`F)B`A)')E8W5R<VEV92D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!D96QE=&4@7"(E<UPB+"!T:&4@9&ER96-T;W)Y(&ES(&YO="!E;7!T>2XB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@('T*
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL92D@>PH@("`@
M("`@("`@("!I9B`H)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G*2!["B`@("`@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949O;&1E<B@D=&AI
M<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@)&9I;&5;)VYA;64G72P@)')E
M8W5R<VEV92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949I;&4H)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DL("1F:6QE6R=N86UE)UTI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!296%L;'D@9&5L971E('1H92!F
M;VQD97(N"B`@("`@("`@;&ES="@D<&%T:"P@)&YA;64I(#T@)'1H:7,M/E]E
M<V-A<&53:&5L;$-O;6UA;F0H)'!A=&@L("1N86UE*3L*("`@("`@("`D8VUD
M(#T@87)R87DH)W)M9&ER(%PB)R`N("1N86UE("X@)UPB)RD["B`@("`@("`@
M)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@("`@
M:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!D
M96QE=&4@5D93(&9O;&1E<B!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D
M<&%T:"P@)&YA;64I*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4F5N86UE<R!A(&9I;&4@:6X@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1O;&1P871H("!4:&4@;VQD('!A=&@@=&\@=&AE(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1N86UE("!4:&4@;VQD(&9I;&5N
M86UE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W<&%T:"`@5&AE(&YE=R!P
M871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F5W;F%M
M92`@5&AE(&YE=R!F:6QE;F%M92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86Y\4$5!4E]%<G)O<B`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YA;64H
M)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@)&YE=VYA;64I"B`@("![
M"B`@("`@("`@:68@*&ES7V$H)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E
M4&%T:"@D;F5W<&%T:"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("`O+R!$;W5B;&4@
M<75O=&5S(&YO="!A;&QO=V5D(&EN(%--0B!F:6QE;F%M92X*("`@("`@("`D
M;F5W;F%M92`]('-T<E]R97!L86-E*"<B)RP@(B<B+"`D;F5W;F%M92D["@H@
M("`@("`@(&QI<W0H)&9I;&4L("1N86UE*2`]("1T:&ES+3Y?97-C87!E4VAE
M;&Q#;VUM86YD*"1O;&1N86UE+"`D;F5W;F%M92D["B`@("`@("`@)&-M9"`]
M(&%R<F%Y*"=R96YA;64@7"(G("X@('-T<E]R97!L86-E*"<O)RP@)UQ<7%PG
M+"`D;VQD<&%T:"D@+B`G7%PG("X@)&9I;&4@+B`G7"(@7"(G("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H)R\G
M+"`G7%Q<7"<L("1N97=P871H*2`N("=<7"<@+B`D;F%M92`N("=<(B<I.PH@
M("`@("`@(&EF("AI<U]A*"1E<G(@/2`D=&AI<RT^7V-O;6UA;F0H)R<L("1C
M;60I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(')E;F%M92!61E,@
M9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($-R96%T97,@82!F;VQD97(@;VX@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!O9B!D
M:7)E8W1O<GD@=&\@8W)E871E(&9O;&1E<BX*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;&5A;GQ014%27T5R<F]R("!4<G5E(&]N('-U
M8V-E<W,@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@
M("`@("`@+R\@1&]U8FQE('%U;W1E<R!N;W0@86QL;W=E9"!I;B!334(@9FEL
M96YA;64N"B`@("`@("`@)&YA;64@/2!S=')?<F5P;&%C92@G(B<L("(G(BP@
M)&YA;64I.PH*("`@("`@("!L:7-T*"1D:7(L("1M:V1I<BD@/2`D=&AI<RT^
M7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T:"P@)&YA;64I.PH@("`@("`@("1C
M;60@/2!A<G)A>2@G;6MD:7(@7"(G("X@)&UK9&ER("X@)UPB)RD["B`@("`@
M("`@)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D9&ER+"`D8VUD*3L*("`@("`@
M("!I9B`H:7-?82@D97)R+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O
M(&-R96%T92!61E,@9F]L9&5R(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H
M*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N('5N<V]R=&5D
M(&9I;&4@;&ES="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H
M("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=&\@9V5T('1H92!F
M:6QE(&QI<W0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R
M+@H@("`@("H@0'!A<F%M(&UI>&5D("1F:6QT97(@("`@("!(87-H(&]F(&ET
M96US('1O(&9I;'1E<B!B87-E9"!O;B!F:6QE;F%M92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D;W1F:6QE<S\@5&AI<R!I<R!I
M<G)E;&5V86YT('=I=&@*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<VUB8VQI96YT+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N;'D@
M("!3:&]W(&1I<F5C=&]R:65S(&]N;'D_"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N?%!%05)?17)R;W(@($9I;&4@;&ES="!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD
M97(H)'!A=&@@/2`G)RP@)&9I;'1E<B`](&YU;&PL("1D;W1F:6QE<R`]('1R
M=64L("1D:7)O;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@;&ES="@D<&%T
M:"D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T:"D["B`@("`@
M("`@)&-M9"`](&%R<F%Y*"=L<R<I.PH@("`@("`@("1R97,@/2`D=&AI<RT^
M7V-O;6UA;F0H)'!A=&@L("1C;60I.PH@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?0H@("`@("`@("1N=6U?;&EN97,@/2!C;W5N="@D<F5S*3L*("`@
M("`@("`D9FEL97,@/2!A<G)A>2@I.PH@("`@("`@(&9O<B`H)'(@/2`P.R`D
M<B`\("1N=6U?;&EN97,[("1R*RLI('L*("`@("`@("`@("`@+R\@36%T8V@@
M9FEL92!L:7-T:6YG+@H@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH
M7'-<<RXK7'-[-BQ]*2\G+"`D<F5S6R1R72DI('L*("`@("`@("`@("`@("`@
M("\O(%-P;&ET(&EN=&\@8V]L=6UN<R!A="!E=F5R>2!S:7@@<W!A8V5S"B`@
M("`@("`@("`@("`@("`D<W!L:70Q(#T@<')E9U]S<&QI="@G+UQS>S8L?2\G
M+"!T<FEM*"1R97-;)')=*2D["B`@("`@("`@("`@("`@("`O+R!)9B!T:&4@
M9FEL92!N86UE(&ES;B=T("X@;W(@+BX*("`@("`@("`@("`@("`@(&EF("@D
M<W!L:70Q6S!=("$]("<N)R`F)B`D<W!L:70Q6S!=("$]("<N+B<I('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'-P;&ET,5LR72DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@268@=&AE<F4@:7,@82!S;6%L;"!F
M:6QE('-I>F4L(&EN9B!C;W5L9"!B92!S<&QI=`H@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!I;G1O(#,@8V]L<RX*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-P;&ET,5LQ72`N/2`G("<@+B`D<W!L:70Q6S)=.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R!3<&QI="!F:6QE
M(&EN9B!A="!E=F5R>2!O;F4@;W(@;6]R92!S<&%C97,N"B`@("`@("`@("`@
M("`@("`@("`@)'-P;&ET,B`]('!R96=?<W!L:70H)R]<<RLO)RP@)'-P;&ET
M,5LQ72D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)'-P
M;&ET,ELP72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@268@=&AE
M<F4@:7,@;F\@9FEL92!A='1R+"!S:&EF="!C;VQS(&]V97(N"B`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)'-P;&ET,BP@)R<I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D;7E?
M;F%M92`]("1S<&QI=#%;,%T["@H@("`@("`@("`@("`@("`@("`@("\O($9I
M;'1E<B!O=70@9&]T9FEL97,@:68@=&AE>2!A<F5N)W0@=V%N=&5D+@H@("`@
M("`@("`@("`@("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U8G-T<B@D;7E?
M;F%M92P@,"P@,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("`@("`@("`@)&UY7W-I>F4@/2`D<W!L:70R6S%=.PH@("`@("`@("`@("`@
M("`@("`@("1E>'1?;F%M92`](&5X<&QO9&4H)RXG+"`D;7E?;F%M92D["@H@
M("`@("`@("`@("`@("`@("`@(&EF("@H<W1R<&]S*"1S<&QI=#);,%TL("=$
M)RD@(3T](&9A;'-E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D;7E?
M='EP92`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`@("`@("`@("1M>5]S
M:7IE(#T@+3$["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&UY7W1Y<&4@/2!61E,Z.G-T<G1O;&]W97(H
M)&5X=%]N86UE6V-O=6YT*"1E>'1?;F%M92D@+2`Q72D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1M>5]D871E(#T@<W1R
M=&]T:6UE*"1S<&QI=#);-%T@+B`G("<@+B`D<W!L:70R6S-=("X@)R`G("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W!L
M:70R6S9=("X@)R`G("X@)'-P;&ET,ELU72D["B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5D871A(#T@87)R87DH)V]W;F5R)R`]/B`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9W)O=7`G(#T^("<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P97)M<R<@
M/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)VYA;64G(#T^("1M>5]N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=T>7!E)R`]/B`D;7E?='EP92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G9&%T92<@/3X@)&UY7V1A=&4L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-I>F4G
M(#T^("1M>5]S:7IE*3L*("`@("`@("`@("`@("`@("`@("`O+R!W871C:"!F
M;W(@9FEL=&5R<R!A;F0@9&ER;VYL>0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1M>5]N86UE*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&1I<F]N;'D@)B8@)&UY7W1Y
M<&4@(3T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)&9I;&4I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("1F
M:6QE<ULD9FEL961A=&%;)VYA;64G75T@/2`D9FEL961A=&$["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1F:6QE<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S
M;W)T960@;&ES="!O9B!F;VQD97)S(&EN('-P96-I9FEE9"!D:7)E8W1O<GDN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H
M92!P871H(&]F('1H92!D:7)E8W1O<GD@=&\@9V5T('1H90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1I<F5C=&]R>2!L:7-T(&9O<BX*
M("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@("!(87-H(&]F(&ET
M96US('1O(&9I;'1E<B!B87-E9"!O;B!F;VQD97)L:7-T+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&1O=&9O;&1E<G,@($EN8VQU9&4@9&]T9F]L9&5R<S\@
M27)R96QE=F%N="!F;W(@4TU"+@H@("`@("H*("`@("`J($!R971U<FX@8F]O
M;&5A;GQ014%27T5R<F]R("!&;VQD97(@;&ES="!O;B!S=6-C97-S(&]R(&$@
M4$5!4E]%<G)O<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD97)S
M*"1P871H(#T@)R<L("1F:6QT97(@/2!N=6QL+"`D9&]T9F]L9&5R<R`]('1R
M=64I"B`@("!["B`@("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@
M("1F;VQD97(@/2!A<G)A>2@I.PH*("`@("`@("`D9F]L9&5R3&ES="`]("1T
M:&ES+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"`D9&]T9F]L9&5R<RP@=')U
M92D["B`@("`@("`@:68@*&ES7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@("`@
M('T*"B`@("`@("`@+R\@9&ER;F%M92!W:6QL('-T<FEP(&QA<W0@8V]M<&]N
M96YT(&9R;VT@<&%T:"P@979E;B!O;B!A(&1I<F5C=&]R>0H@("`@("`@("1F
M;VQD97);)W9A;"==(#T@9&ER;F%M92@D<&%T:"D["B`@("`@("`@)&9O;&1E
M<ELG86)B<F5V)UT@/2`G+BXG.PH@("`@("`@("1F;VQD97);)VQA8F5L)UT@
M/2`G+BXG.PH*("`@("`@("`D9F]L9&5R<ULD9F]L9&5R6R=V86PG75T@/2`D
M9F]L9&5R.PH*("`@("`@("!F;W)E86-H("@D9F]L9&5R3&ES="!A<R`D9FEL
M97,I('L*("`@("`@("`@("`@)&9O;&1E<ELG=F%L)UT@/2`D=&AI<RT^7V=E
M=%!A=&@H)'!A=&@L("1F:6QE<ULG;F%M92==*3L*("`@("`@("`@("`@)&9O
M;&1E<ELG86)B<F5V)UT@/2`D9FEL97-;)VYA;64G73L*("`@("`@("`@("`@
M)&9O;&1E<ELG;&%B96PG72`]("1F;VQD97);)W9A;"==.PH*("`@("`@("`@
M("`@)&9O;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*("`@("`@
M("!]"@H@("`@("`@(&MS;W)T*"1F;VQD97)S*3L*("`@("`@("!R971U<FX@
M)&9O;&1E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W!I97,@82!F:6QE
M('1H<F]U9V@@=&AE(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@5&AE(&1E<W1I;F%T:6]N
M(&]F('1H92!F:6QE+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;GQ0
M14%27T5R<F]R("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O<'DH)'!A=&@L("1N
M86UE+"`D9&5S="D*("`@('L*("`@("`@("`D;W)I9R`]("1T:&ES+3Y?9V5T
M4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"=\
M7B<@+B!P<F5G7W%U;W1E*"1O<FEG*2`N("<O/R1\)RP@)&1E<W0I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(D-A;FYO="!C
M;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD(&1E<W1I;F%T:6]N(&%R92!T:&4@
M<V%M92XB*2D["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K(#T@)'1H
M:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL('1R=64I.PH@("`@("`@(&9O
M<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@
M*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B)7,@86QR96%D>2!E
M>&ES=',N(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1I<T1I<B`](&9A
M;'-E.PH@("`@("`@("1D:7)#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1P
M871H+"!N=6QL+"!F86QS92D["B`@("`@("`@9F]R96%C:"`H)&1I<D-H96-K
M(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]
M("1N86UE("8F("1F:6QE6R=T>7!E)UT@/3T@)RHJ9&ER)RD@>PH@("`@("`@
M("`@("`@("`@)&ES1&ER(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)&ES1&ER
M*2!["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E1F]L9&5R
M*"1D97-T+"`D;F%M92D["@H@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)')E
M<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5?;&ES="`]
M("1T:&ES+3YL:7-T1F]L9&5R*"1O<FEG*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9I;&5?;&ES="!A<R`D9FEL92D@>PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YC;W!Y*"1O<FEG+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UTL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710871H*"1D
M97-T+"`D;F%M92DI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1M<$9I;&4@/2`D=&AI<RT^
M7V-R96%T951E;7!&:6QE*"1P871H+"`D;F%M92D["B`@("`@("`@("`@(&EF
M("AI<U]A*"1T;7!&:6QE+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9A:6QE
M9"!T;R!R971R:65V93H@)7,B*2P@)&]R:6<I*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)')E<R`]("1T:&ES+3YW<FET92@D9&5S="P@)&YA;64L
M("1T;7!&:6QE*3L*("`@("`@("`@("`@=6YL:6YK*"1T;7!&:6QE*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")#;W!Y(&9A:6QE9#H@)7,B*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710871H*"1D97-T
M+"`D;F%M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!-;W9E<R!A(&9I
M;&4@=&AR;W5G:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U
M<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@9&5S=&EN871I
M;VX@;V8@=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M?%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@
M)&YA;64L("1D97-T*0H@("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G
M9710871H*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H
M)WQ>)R`N('!R96=?<75O=&4H)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T
M(&UO=F4@9FEL92AS*2`M(&1E<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N
M(BDI.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL
M:7-T1F]L9&5R*"1D97-T+"!N=6QL+"!T<G5E*3L*("`@("`@("!F;W)E86-H
M("@D9FEL94-H96-K(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D9FEL
M95LG;F%M92==(#T]("1N86UE*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(B5S(&%L<F5A9'D@97AI<W1S
M+B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D97)R(#T@)'1H:7,M/G)E
M;F%M92@D<&%T:"P@)&YA;64L("1D97-T+"`D;F%M92D["B`@("`@("`@:68@
M*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9A:6QE9"!T;R!M;W9E
M('1O(%PB)7-<(BXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V=E=%!A=&@H)&1E<W0L("1N86UE*2DI
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&9U;&P@<&%T:"!O9B!A;B!I=&5M+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H(&]F
M(&1I<F5C=&]R>2!O9B!T:&4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@(%1H92!N86UE(&]F('1H92!I=&5M+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@($9U;&P@<&%T:"!W:&5N("1P871H(&ES<V5T(&%N9"!J
M=7-T("1N86UE('=H96X@;F]T('-E="X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=%!A=&@H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@(&EF("@D<&%T
M:"`A/3T@)R<I('L*("`@("`@("`@("`@(')E='5R;B`H)'!A=&@@+B`G+R<@
M+B`D;F%M92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;F%M93L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E<&QA8V5M96YT(&9O<B!E<V-A<&5S:&5L
M;&-M9"@I+"!V87)I86)L92!L96YG=&@@87)G<RP@87,@=V4@;VYL>2!W86YT
M"B`@("`@*B!C97)T86EN(&-H87)A8W1E<G,@97-C87!E9"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@87)R
M87D@)&%R<F%Y("!3=')I;F=S('1O(&5S8V%P92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E<V-A<&53:&5L
M;$-O;6UA;F0H*0H@("`@>PH@("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@
M("`@("1A<F=S(#T@9G5N8U]G971?87)G<R@I.PH@("`@("`@(&9O<F5A8V@@
M*"1A<F=S(&%S("1A<F<I('L*("`@("`@("`@("`@)')E=%M=(#T@<W1R7W)E
M<&QA8V4H87)R87DH)SLG+"`G7%PG*2P@87)R87DH)UP[)RP@)UQ<7%PG*2P@
M)&%R9RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*
M("`@("\J*@H@("`@("H@17AE8W5T97,@82!C;VUM86YD(&%N9"!R971U<FYS
M(&]U='!U="!L:6YE<R!I;B!A<G)A>2X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;60@($-O
M;6UA;F0@=&\@8F4@97AE8W5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("!!<G)A>2!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?97AE8W5T92@D8VUD*0H@("`@>PH@("`@("`@
M("1C;60@/2!S=')?<F5P;&%C92@G(BU5)2(G+"`G+4XG+"`D8VUD*3L*("`@
M("`@("!E>&5C*"1C;60L("1O=70L("1R970I.PH*("`@("`@("`O+R!);B!S
M;VUE(&-A<V5S+"`H;&EK92!T<GEI;F<@=&\@9&5L971E(&$@;F]N97AI<W1A
M;G0@9FEL92DL"B`@("`@("`@+R\@<VUB8VQI96YT('=I;&P@<F5T=7)N('-U
M8V-E<W,@*&%T(&QE87-T(&]N(#(N,BXW('9E<G-I;VX@22=M"B`@("`@("`@
M+R\@=&5S=&EN9R!O;BDN(%-O('1R>2!T;R!M871C:"!E<G)O<B!S=')I;F=S
M+"!E=F5N(&%F=&5R('-U8V-E<W,N"B`@("`@("`@:68@*"1R970@(3T@,"D@
M>PH@("`@("`@("`@("`D97)R(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1O=70@87,@)&QI;F4I('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H
M)&QI;F4L("=5<V%G93HG*2`]/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1E<G(@/2`G0V]M;6%N9"!S>6YT87@@:6YC;W)R96-T)SL*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&EF("AS=')P;W,H)&QI;F4L("=%4E)34E8G*2`A/3T@9F%L<V4@
M?'P*("`@("`@("`@("`@("`@("`@("!S=')P;W,H)&QI;F4L("=%4E)$3U,G
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D97)R(#T@<')E
M9U]R97!L86-E*"<O+BI<*"@N*RE<*2XJ+R<L("=<7#$G+"`D;&EN92D["B`@
M("`@("`@("`@("`@("`@("`@:68@*"$D97)R*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1E<G(@/2`D;&EN93L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D97)R*2!["B`@("`@
M("`@("`@("`@("`D97)R(#T@)&]U="`_("1O=71;8V]U;G0H)&]U="D@+2`Q
M72`Z("1R970["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)&5R<BD["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!F;W(@97)R;W)S(&5V96X@;VX@<W5C8V5S<RX*("`@("`@("`D97)R
M(#T@)R<["B`@("`@("`@9F]R96%C:"`H)&]U="!A<R`D;&EN92D@>PH@("`@
M("`@("`@("!I9B`H<W1R<&]S*"1L:6YE+"`G3E1?4U1!5%537TY/7U-50TA?
M1DE,12<I("$]/2!F86QS92!\?`H@("`@("`@("`@("`@("`@<W1R<&]S*"1L
M:6YE+"`G3E1?4U1!5%537T]"2D5#5%].04U%7TY/5%]&3U5.1"<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@)&5R<B`](%\H(DYO('-U8V@@9FEL
M92(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T@96QS
M96EF("AS=')P;W,H)&QI;F4L("=.5%]35$%455-?04-#15-37T1%3DE%1"<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)&5R<B`](%\H(E!E<FUI
M<W-I;VX@1&5N:65D(BD["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1E<G(I('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<BD["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&]U=#L*("`@('T*"B`@("`O*BH*("`@("`J
M($5X96-U=&5S(%--0B!C;VUM86YD<R`M('=I=&AO=70@875T:&5N=&EC871I
M;VX@+2!A;F0@<F5T=7)N<R!O=71P=70*("`@("`J(&QI;F5S(&EN(&%R<F%Y
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%T:"`@0F%S92!P871H(&9O<B!C;VUM86YD+@H@
M("`@("H@0'!A<F%M(&%R<F%Y("1C;60@("!#;VUM86YD<R!T;R!B92!E>&5C
M=71E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!!<G)A>2!O;B!S
M=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?8V]M;6%N9"@D<&%T:"P@)&-M9"D*("`@('L*("`@("`@("!L:7-T*"1S
M:&%R92D@/2`D=&AI<RT^7V5S8V%P95-H96QL0V]M;6%N9"@D=&AI<RT^7W!A
M<F%M<ULG<VAA<F4G72D["B`@("`@("`@<'5T96YV*"=005-35T0])R`N("1T
M:&ES+3Y?<&%R86US6R=P87-S=V]R9"==*3L*("`@("`@("`D:7!O<'1I;VX@
M/2`H:7-S970H)'1H:7,M/E]P87)A;7-;)VEP861D<F5S<R==*2D@/R`H)R`M
M22`G("X@)'1H:7,M/E]P87)A;7-;)VEP861D<F5S<R==*2`Z(&YU;&P["B`@
M("`@("`@)&9U;&QC;60@/2`D=&AI<RT^7W!A<F%M<ULG<VUB8VQI96YT)UT@
M+@H@("`@("`@("`@("`G("(O+R<@+B`D=&AI<RT^7W!A<F%M<ULG:&]S='-P
M96,G72`N("<O)R`N("1S:&%R92`N("<B)R`N"B`@("`@("`@("`@("<@(BUP
M)R`N("1T:&ES+3Y?<&%R86US6R=P;W)T)UT@+B`G(B<@+@H@("`@("`@("`@
M("`G("(M52<@+B`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`N("<B)R`N
M"B`@("`@("`@("`@("<@+40@(B<@+B`D<&%T:"`N("<B("<@+@H@("`@("`@
M("`@("`D:7!O<'1I;VX@+@H@("`@("`@("`@("`G("UC("(G.PH@("`@("`@
M(&9O<F5A8V@@*"1C;60@87,@)&,I('L*("`@("`@("`@("`@)&9U;&QC;60@
M+CT@)&,@+B`B.R(["B`@("`@("`@?0H@("`@("`@("1F=6QL8VUD("X]("<B
M)SL*("`@("`@("!R971U<FX@)'1H:7,M/E]E>&5C=71E*"1F=6QL8VUD*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!A(&9I;&4@9G)O;2!T
M:&4@5D93(&%N9"!S=&]R97,@:70@=&\@82!T96UP;W)A<GD@9FEL92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T
M<FEE=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5&AE('1E;7!O
M<F%R>2!F:6QE;F%M92!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V-R96%T951E;7!&:6QE*"1P871H+"`D;F%M
M92D*("`@('L*("`@("`@("!L:7-T*"1P871H+"`D;F%M92D@/2`D=&AI<RT^
M7V5S8V%P95-H96QL0V]M;6%N9"@D<&%T:"P@)&YA;64I.PH@("`@("`@("1T
M96UP(#T@)'1H:7,M/E]G971496UP1FEL92@I.PH@("`@("`@("1C;60@/2!A
M<G)A>2@G9V5T(%PB)R`N("1N86UE("X@)UPB("<@+B`D=&5M<"D["B`@("`@
M("`@)&5R<B`]("1T:&ES+3Y?8V]M;6%N9"@D<&%T:"P@)&-M9"D["B`@("`@
M("`@:68@*&ES7V$H)&5R<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&5R<CL*("`@("`@("!]"B`@("`@("`@:68@*"%F:6QE7V5X
M:7-T<R@D=&5M<"DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!<(B5S
M7"(N(BDL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D=&5M<#L*("`@('T*"GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]'0RYP:'``````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C8V(#$P-3$U
M-#,T,3,V(#`Q-S<U-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*BH*("H@0VQA<W,@9F]R('!R;W9I9&EN9R!G
M87)B86=E(&-O;&QE8W1I;VX@9F]R(&%N>2!61E,@:6YS=&%N8V4N"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O1T,N<&AP+'8@,2XT+C$R+C@@
M,C`P-B\P,2\P,2`R,3HR.#HT,B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#,M,C`P-B!-:6-H865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC
M;VQO<F%D;RYE9'4^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!-:6-H
M865L(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D;RYE9'4^"B`J
M($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!61E,*("HO"F-L87-S
M(%9&4U]'0R!["@H@("`@+RHJ"B`@("`@*B!'87)B86=E(&-O;&QE8W0@9FEL
M97,@:6X@=&AE(%9&4R!S=&]R86=E('-Y<W1E;2X*("`@("`J"B`@("`@*B!`
M<&%R86T@5D93("8D=F9S("`@("`@5&AE(%9&4R!O8FIE8W0@=&\@<&5R9F]R
M;2!G87)B86=E(&-O;&QE8W1I;VX@;VXN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("`@5&AE(%9&4R!P871H('1O(&-L96%N+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)'-E8W,@(%1H92!M:6YI;75M(&%M;W5N="!O9B!T:6UE("AI
M;B!S96-O;F1S*2!R97%U:7)E9`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&)E9F]R92!A(&9I;&4@:7,@<F5M;W9E9"X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V,H)B1V9G,L("1P871H+"`D<V5C<R`](#,T-38P,"D*("`@('L*
M("`@("`@("`O*B!!(#$E(&-H86YC92!W92!W:6QL(')U;B!G87)B86=E(&-O
M;&QE8W1I;VX@9'5R:6YG(&$@8V%L;"X@*B\*("`@("`@("!I9B`H<F%N9"@P
M+"`Y.2D@/3T@,"D@>PH@("`@("`@("`@("`O*B!-86ME('-U<F4@8VQE86YI
M;F<@:7,@9&]N92!R96-U<G-I=F5L>2X@*B\*("`@("`@("`@("`@)&9I;&5S
M(#T@)'9F<RT^;&ES=$9O;&1E<B@D<&%T:"P@;G5L;"P@=')U92P@9F%L<V4L
M('1R=64I.PH@("`@("`@("`@("!I9B`H(6ES7V$H)&9I;&5S+"`G4$5!4E]%
M<G)O<B<I("8F(&ES7V%R<F%Y*"1F:6QE<RDI('L*("`@("`@("`@("`@("`@
M("1M;V1T:6UE(#T@=&EM92@I("T@)'-E8W,["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9FEL97,@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D=F%L6R=D871E)UT@/"`D;6]D=&EM92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F9S+3YD96QE=&5&:6QE*"1P871H+"`D=F%L6R=N86UE
M)UTI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M5D93+W-Q;"YP:'``````````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`Q,#0T,#<@,3`U,34T,S0Q,S8@,#(P,C4W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*BH*
M("H@1FEL92!V86QU92!F;W(@=F9S7W1Y<&4@8V]L=6UN+@H@*B\*9&5F:6YE
M*"=61E-?1DE,12<L(#$I.PH*+RHJ"B`J($9O;&1E<B!V86QU92!F;W(@=F9S
M7W1Y<&4@8V]L=6UN+@H@*B\*9&5F:6YE*"=61E-?1D],1$52)RP@,BD["@HO
M*BH*("H@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!02%`G<R!014%2(&1A=&%B
M87-E(&%B<W1R86-T:6]N(&QA>65R+@H@*@H@*B!297%U:7)E9"!V86QU97,@
M9F]R("1P87)A;7,Z/'!R93X*("H@("`@("`G<&AP='EP92<@("`@("`@5&AE
M(&1A=&%B87-E('1Y<&4@*&EE+B`G<&=S<6PG+"`G;7ES<6PG+"!E=&,N*2X\
M+W!R93X*("H*("H@3W!T:6]N86P@=F%L=65S.CQP<F4^"B`J("`@("`@)W1A
M8FQE)R`@("`@("`@(%1H92!N86UE(&]F('1H92!V9G,@=&%B;&4@:6X@)V1A
M=&%B87-E)RX@1&5F875L=',@=&\*("H@("`@("`@("`@("`@("`@("`@("`@
M)VAO<F1E7W9F<R<N/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T
M86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@("`@)VAO<W1S<&5C
M)R`@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@
M*B`@("`@("=P<F]T;V-O;"<@("`@("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T
M;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@("`@)V1A=&%B87-E
M)R`@("`@(%1H92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`@("`G=7-E
M<FYA;64G("`@("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C
M="!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W!A<W-W;W)D)R`@("`@(%1H
M92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`@
M("`G;W!T:6]N<R<@("`@("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@
M=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=T='DG("`@("`@("`@("!4:&4@
M5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@
M("`@("=P;W)T)R`@("`@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN
M96-T('1O('1H92!D871A8F%S92X\+W!R93X*("H*("H@5&AE('1A8FQE('-T
M<G5C='5R92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U;F0@:6X*("H@9&%T82]V
M9G,N<W%L+@H@*@H@*B!$871A8F%S92!S<&5C:69I8R!N;W1E<SH*("H*("H@
M35-344PZ"B`J(#QP<F4^"B`J("T@5&AE('9F<U]D871A(&9I96QD(&UU<W0@
M8F4@;V8@='EP92!)34%'12X*("H@+2!9;W4@;F5E9"!T:&4@9F]L;&]W:6YG
M('!H<"YI;FD@<V5T=&EN9W,Z"B`J("`@(#L@5F%L:60@<F%N9V4@,"`M(#(Q
M-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@*B`@("!M<W-Q;"YT97AT;&EM
M:70@/2`P(#L@>F5R;R!T;R!P87-S('1H<F]U9V@*("H*("H@("`@.R!686QI
M9"!R86YG92`P("T@,C$T-S0X,S8T-RX@1&5F875L="`](#0P.38N"B`J("`@
M(&US<W%L+G1E>'1S:7IE(#T@,"`[('IE<F\@=&\@<&%S<R!T:')O=6=H"B`J
M(#PO<')E/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+W-Q;"YP
M:'`L=B`Q+C@U+C0N,C8@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R
M("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H@0'!A8VMA
M9V4@5D93"B`J+PIC;&%S<R!61E-?<W%L(&5X=&5N9',@5D93('L*"B`@("`O
M*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4@8V]N
M;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@*B\*("`@('9A
M<B`D7V1B(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE
M(&9I;&5S:7IE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE
M=F4N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@5&AE(&9I;&4@<VEZ92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<VEZ92@D<&%T:"P@)&YA;64I"B`@("![
M"B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I
M9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D;&5N9W1H7V]P(#T@
M)'1H:7,M/E]G971&:6QE4VEZ94]P*"D["B`@("`@("`@)'-Q;"`]('-P<FEN
M=&8H"B`@("`@("`@("`@("=314Q%0U0@)7,H=F9S7V1A=&$I($923TT@)7,@
M5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@
M("`@("`D;&5N9W1H7V]P+`H@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M=&%B;&4G70H@("`@("`@("D["B`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T
M:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I+"`D;F%M92D["B`@("`@("`@)'1H
M:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)51RD["B`@("`@("`@)'-I>F4@
M/2`D=&AI<RT^7V1B+3YG971/;F4H)'-Q;"P@)'9A;'5E<RD["@H@("`@("`@
M(&EF("AI<U]N=6QL*"1S:7IE*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&5C:R!F:6QE
M('-I>F4@;V8@7"(E<R\E<UPB+B(I+"`D<&%T:"P@)&YA;64I*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B`D<VEZ93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-I>F4@;V8@82!F:6QE+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@5&AE('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N86UE("!4:&4@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G1E9V5R("!4:&4@<VEZ92!O9B!T:&4@9F]L9&5R(&EN(&)Y=&5S(&]R
M(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F]L9&5R4VEZ92@D<&%T:"`]
M(&YU;&PL("1N86UE(#T@;G5L;"D*("`@('L*("`@("`@("`D8V]N;B`]("1T
M:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@
M("!]"@H@("`@("`@("1W:&5R92`]("AI<U]N=6QL*"1P871H*2D@/R!N=6QL
M(#H@<W!R:6YT9B@G5TA%4D4@=F9S7W!A=&@@/2`E<R<L("@H(7-T<FQE;B@D
M<&%T:"DI(#\@)R(B)R`Z("1T:&ES+3Y?9&(M/G%U;W1E*"1T:&ES+3Y?8V]N
M=F5R=%!A=&@H)'!A=&@I*2DI.PH@("`@("`@("1L96YG=&A?;W`@/2`D=&AI
M<RT^7V=E=$9I;&53:7IE3W`H*3L*("`@("`@("`D<W%L(#T@<W!R:6YT9B@*
M("`@("`@("`@("`@)U-%3$5#5"!354TH)7,H=F9S7V1A=&$I*2!&4D]-("5S
M("5S)RP*("`@("`@("`@("`@)&QE;F=T:%]O<"P*("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("1W:&5R90H@("`@
M("`@("D["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)'-I>F4@/2`D=&AI<RT^7V1B+3YG971/;F4H)'-Q;"D[
M"@H@("`@("`@(')E='5R;B`D<VEZ92`A/3T@;G5L;"`_("1S:7IE(#H@,#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E(&$@9FEL92!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I979E+@H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!4:&4@9FEL92!D871A+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R96%D*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N
M;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7W)E861";&]B*"1T
M:&ES+3Y?<&%R86US6R=T86)L92==+"`G=F9S7V1A=&$G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=V9G-?<&%T:"<@/3X@)'1H
M:7,M/E]C;VYV97)T4&%T:"@D<&%T:"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9F<U]N86UE)R`]/B`D;F%M92DI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S(&$@<&%R="!O9B!A(&9I;&4@
M9G)O;2!T:&4@5D93+B!087)T:6-U;&%R;'D@=7-E9G5L"B`@("`@*B!W:&5N
M(')E861I;F<@;&%R9V4@9FEL97,@=VAI8V@@=V]U;&0@97AC965D('1H92!0
M2%`@;65M;W)Y"B`@("`@*B!L:6UI=',@:68@=&AE>2!W97)E('-T;W)E9"!I
M;B!A('-T<FEN9RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%T
M:"`@("`@("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("`D;F%M92`@("`@("!4:&4@9FEL96YA;64@=&\@<F5T<FEE
M=F4N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;V9F<V5T("`@("!4:&4@;V9F
M<V5T(&]F('1H92!P87)T+B`H5&AE(&YE=R!O9F9S970@=VEL;"!B90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1O<F5D(&EN(&AE<F4I
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&QE;F=T:"`@("`@5&AE(&QE;F=T
M:"!O9B!T:&4@<&%R="X@268@=&AE(&QE;F=T:"`]("TQ+"!T:&4*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('=H;VQE('!A<G0@869T97(@
M=&AE(&]F9G-E="!I<R!R971R:65V960N($EF"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!M;W)E(&)Y=&5S(&%R92!G:79E;B!A<R!E>&ES
M=',@869T97(@=&AE(&=I=F5N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!O9F9S970N($]N;'D@=&AE(&%V86EL86)L92!B>71E<R!A<F4@
M<F5A9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1R96UA:6YI;F<@(%1H92!B
M>71E<R!T:&%T(&%R92!L969T+"!A9G1E<B!T:&4@<&%R="!T:&%T(&ES"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971R:65V960N"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@5&AE(&9I;&4@9&%T82X*("`@
M("`J+PH@("`@9G5N8W1I;VX@<F5A9%!A<G0H)'!A=&@L("1N86UE+"`F)&]F
M9G-E="P@)&QE;F=T:"`]("TQ+"`F)')E;6%I;FEN9RD*("`@('L*("`@("`@
M("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A
M*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M8V]N;CL*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)'1H:7,M/E]R96%D
M0FQO8B@D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P@)W9F<U]D871A)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W9F<U]P871H
M)R`]/B`D=&AI<RT^7V-O;G9E<G10871H*"1P871H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9F<U]N86UE)R`]/B`D;F%M
M92DI.PH*("`@("`@("`O+R!#86QC=6QA=&4@:&]W(&UA;GD@8GET97,@3553
M5"!B92!R96%D+"!S;R!T:&4@<F5M86EN9VEN9PH@("`@("`@("\O(&)Y=&5S
M(&%N9"!T:&4@;F5W(&]F9G-E="!C86X@8F4@8V%L8W5L871E9"!C;W)R96-T
M;'DN"B`@("`@("`@)'-I>F4@/2!S=')L96X@*"1D871A*3L*("`@("`@("!I
M9B`H)&QE;F=T:"`]/2`M,2!\?"`H*"1L96YG=&@@*R`D;V9F<V5T*2`^("1S
M:7IE*2D@>PH@("`@("`@("`@("`D;&5N9W1H(#T@)'-I>F4@+2`D;V9F<V5T
M.PH@("`@("`@('T*("`@("`@("!I9B`H)')E;6%I;FEN9R`\(#`I('L*("`@
M("`@("`@("`@)')E;6%I;FEN9R`](#`["B`@("`@("`@?0H*("`@("`@("`D
M9&%T82`]('-U8G-T<B@D9&%T82P@)&]F9G-E="P@)&QE;F=T:"D["B`@("`@
M("`@)&]F9G-E="`]("1O9F9S970@*R`D;&5N9W1H.PH@("`@("`@("1R96UA
M:6YI;F<@/2`D<VEZ92`M("1O9F9S970["@H@("`@("`@(')E='5R;B`D9&%T
M83L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE
M(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@
M("`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*
M("`@("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R
M87)Y(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)E('-T;W)E9"X*("`@("`J($!P87)A
M;2!B;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D
M:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E
M(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T
M;7!&:6QE+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("\J
M($1O;B=T(&YE960@=&\@8VAE8VL@<75O=&$@:&5R92!S:6YC92!I="!W:6QL
M(&)E(&-H96-K960@=VAE;@H@("`@("`@("`J('=R:71E1&%T82@I(&ES(&-A
M;&QE9"X@*B\*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E
M=%]C;VYT96YT<R<I*2!["B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?
M8V]N=&5N=',H)'1M<$9I;&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1S:7IE(#T@9FEL97-I>F4H)'1M<$9I;&4I.PH@("`@("`@("`@("!I
M9B`H)'-I>F4@/3T](#`I('L*("`@("`@("`@("`@("`@("1D871A(#T@)R<[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&1A
M=&%&4"`]($!F;W!E;B@D=&UP1FEL92P@)W)B)RD["B`@("`@("`@("`@("`@
M("!I9B`H(21D871A1E`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E1H92!T96UP;W)A<GD@9FEL
M92!<(B5S7"(@9&]E<R!N;W0@97AI<W0N(BDL("1T;7!&:6QE*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T82`]($!F<F5A9"@D
M9&%T8490+"`D<VEZ92D["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1D871A
M1E`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M)'1H:7,M/G=R:71E1&%T82@D<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R
M96%T92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@
M=&AE(%9&4R!F<F]M(')A=R!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL
M92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@
M9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@
M("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A
M=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES
M+3Y?8VAE8VM1=6]T85=R:71E*"=S=')I;F<G+"`D9&%T82D["B`@("`@("`@
M:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@)'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1P871H*3L*
M"B`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF('1H92!D871A(&%L<F5A9'D@
M97AI<W1S+B`J+PH@("`@("`@("1S<6P@/2!S<')I;G1F*"=314Q%0U0@=F9S
M7VED($923TT@)7,@5TA%4D4@=F9S7W!A=&@@)7,@04Y$('9F<U]N86UE(#T@
M/R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@*&5M<'1Y*"1P871H*2`F
M)B`D=&AI<RT^7V1B+3YD8G-Y;G1A>"`]/2`G;V-I."<I(#\@)R!)4R!.54Q,
M)R`Z("<@/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H)'!A=&@I*3L*("`@("`@
M("`D=F%L=65S(#T@87)R87DH)&YA;64I.PH@("`@("`@("1T:&ES+3YL;V<H
M)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1I9"`]("1T:&ES+3Y?
M9&(M/F=E=$]N92@D<W%L+"`D=F%L=65S*3L*"B`@("`@("`@:68@*&ES7V$H
M)&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<H
M)&ED+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@)&ED.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<U]N=6QL*"1I9"DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?=7!D871E0FQO8B@D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72P@)W9F<U]D871A)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&%T82P@87)R87DH)W9F<U]I9"<@/3X@)&ED
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G=F9S7VUO9&EF:65D)R`]/B!T:6UE*"DI*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*B!#:&5C:R!T;R!S964@:68@=&AE(&9O;&1E<B!A
M;')E861Y(&5X:7-T<RX@*B\*("`@("`@("`@("`@)&1I<G,@/2!E>'!L;V1E
M*"<O)RP@)'!A=&@I.PH@("`@("`@("`@("`D<&%T:%]N86UE(#T@87)R87E?
M<&]P*"1D:7)S*3L*("`@("`@("`@("`@)'!A<F5N="`](&EM<&QO9&4H)R\G
M+"`D9&ER<RD["B`@("`@("`@("`@(&EF("@A)'1H:7,M/FES1F]L9&5R*"1P
M87)E;G0L("1P871H7VYA;64I*2!["B`@("`@("`@("`@("`@("!I9B`H(21A
M=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")&;VQD97(@)7,@9&]E<R!N;W0@97AI
M<W0B*2P@)'!A=&@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YA=71O8W)E871E4&%T:"@D<&%T:"D["B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1I9"`]("1T:&ES+3Y?9&(M/FYE>'1)9"@D=&AI<RT^7W!A<F%M
M<ULG=&%B;&4G72D["B`@("`@("`@("`@(&EF("AI<U]A*"1I9"P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@D:60L(%!%
M05)?3$]'7T524BD["B`@("`@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VEN<V5R=$)L
M;V(H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL("=V9G-?9&%T82<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&$L(&%R<F%Y
M*"=V9G-?:60G(#T^("1I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9F<U]T>7!E)R`]/B!61E-?1DE,
M12P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9F<U]P871H)R`]/B`D<&%T:"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9F<U]N86UE
M)R`]/B`D;F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W9F<U]M;V1I9FEE9"<@/3X@=&EM92@I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G=F9S7V]W;F5R)R`]/B`D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@1&5L971E(&$@9FEL
M92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<&%T:"`@5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&1E;&5T949I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M("1R97,@/2`D=&AI<RT^7V-H96-K475O=&%$96QE=&4H)'!A=&@L("1N86UE
M*3L*("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX[
M"B`@("`@("`@?0H*("`@("`@("`D<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A
M=&@H)'!A=&@I.PH*("`@("`@("`D<W%L(#T@<W!R:6YT9B@G1$5,151%($92
M3TT@)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T:"`E<R!!3D0@
M=F9S7VYA;64@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG=&%B;&4G72P*("`@("`@("`@("`@("`@("`@("`@("`H96UP
M='DH)'!A=&@I("8F("1T:&ES+3Y?9&(M/F1B<WEN=&%X(#T]("=O8VDX)RD@
M/R`G($E3($Y53$PG(#H@)R`]("<@+B`D=&AI<RT^7V1B+3YQ=6]T92@D<&%T
M:"DI.PH@("`@("`@("1V86QU97,@/2!A<G)A>2A61E-?1DE,12P@)&YA;64I
M.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<W%L+"`D=F%L
M=65S*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I
M(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;F%M92!A(&9I;&4@;W(@9F]L9&5R(&EN('1H92!61E,N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T:"`@5&AE(&]L9"!P871H('1O
M('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD;F%M92`@5&AE
M(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=W!A=&@@
M(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I
M;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA;64N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5N
M86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*0H@
M("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@
M("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*'-T<G!O
M<R@D;F5W<&%T:"P@)R\G*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)'!A
M<F5N="`]("<G.PH@("`@("`@("`@("`D<&%T:"`]("1N97=P871H.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&QI<W0H)'!A<F5N="P@)'!A=&@I
M(#T@97AP;&]D92@G+R<L("1N97=P871H+"`R*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"$D=&AI<RT^:7-&;VQD97(H)'!A<F5N="P@)'!A=&@I*2!["B`@
M("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T
M95!A=&@H)&YE=W!A=&@I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)&]L9'!A=&@@/2`D=&AI<RT^7V-O;G9E<G10871H*"1O;&1P
M871H*3L*("`@("`@("`D;F5W<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H
M)&YE=W!A=&@I.PH*("`@("`@("`D<W%L("`]("=54$1!5$4@)R`N("1T:&ES
M+3Y?<&%R86US6R=T86)L92==.PH@("`@("`@("1S<6P@+CT@)R!3150@=F9S
M7W!A=&@@/2`_+"!V9G-?;F%M92`](#\L('9F<U]M;V1I9FEE9"`](#\@5TA%
M4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M92`](#\G.PH@("`@("`@("1T
M:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("`D=F%L
M=65S(#T@87)R87DH)&YE=W!A=&@L("1N97=N86UE+"!T:6UE*"DL("1O;&1P
M871H+"`D;VQD;F%M92D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B
M+3YQ=65R>2@D<W%L+"`D=F%L=65S*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?
M9&(M/F%F9F5C=&5D4F]W<R@I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@9FEL
M92XB*2D["B`@("`@("`@?0H*("`@("`@("`D<F5N86UE(#T@)'1H:7,M/E]R
M96-U<G-I=F5296YA;64H)&]L9'!A=&@L("1O;&1N86UE+"`D;F5W<&%T:"P@
M)&YE=VYA;64I.PH@("`@("`@(&EF("AI<U]A*"1R96YA;64L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D<F5N86UE+"!014%2
M7TQ/1U]%4E(I.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!R96YA;64@5D93(&1I<F5C=&]R>3H@
M)7,N(BDL("1R96YA;64M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&5S(&$@9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@2&]L9',@=&AE('!A=&@@;V8@9&ER96-T;W)Y
M('1O(&-R96%T92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!(;VQD<R!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<F5A=&5&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C
M;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O
M;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN
M.PH@("`@("`@('T*"B`@("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^;F5X=$ED
M*"1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("!I9B`H:7-?82@D
M:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)'1H:7,M/FQO9R@D
M:60L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@(')E='5R;B`D:60["B`@
M("`@("`@?0H*("`@("`@("`D<W%L("`]("=)3E-%4E0@24Y43R`G("X@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@("`@)'-Q;"`N/2`G("AV9G-?
M:60L('9F<U]T>7!E+"!V9G-?<&%T:"P@=F9S7VYA;64L('9F<U]M;V1I9FEE
M9"P@=F9S7V]W;F5R*2!604Q515,@*#\L(#\L(#\L(#\L(#\L(#\I)SL*("`@
M("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@)'9A;'5E<R`](&%R<F%Y*"1I9"P@5D937T9/3$1%4BP@)'1H:7,M/E]C
M;VYV97)T4&%T:"@D<&%T:"DL("1N86UE+"!T:6UE*"DL("1T:&ES+3Y?<&%R
M86US6R=U<V5R)UTI.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^<75E
M<GDH)'-Q;"P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&4@82!F;VQD97(@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)'!A=&@@("`@("`@(%1H92!P871H(&]F('1H92!F;VQD97(N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@9F]L9&5R
M(&YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)')E8W5R<VEV
M92`@1F]R8V4@82!R96-U<G-I=F4@9&5L971E/PH@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T
M949O;&1E<B@D<&%T:"P@)&YA;64L("1R96-U<G-I=F4@/2!F86QS92D*("`@
M('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1P871H(#T@)'1H
M:7,M/E]C;VYV97)T4&%T:"@D<&%T:"D["@H@("`@("`@("1F;VQD97)0871H
M(#T@)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92D["@H@("`@
M("`@("\J($-H96-K(&EF(&YO="!R96-U<G-I=F4@86YD(&9A:6P@:68@9&ER
M96-T;W)Y(&YO="!E;7!T>2`J+PH@("`@("`@(&EF("@A)')E8W5R<VEV92D@
M>PH@("`@("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3YL:7-T1F]L9&5R
M*"1F;VQD97)0871H+"!N=6QL+"!T<G5E*3L*("`@("`@("`@("`@:68@*&ES
M7V$H)&9O;&1E<DQI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YL;V<H)&9O;&1E<DQI<W0L(%!%05)?3$]'7T524BD["B`@
M("`@("`@("`@("`@("!R971U<FX@)&9O;&1E<DQI<W0["B`@("`@("`@("`@
M('T@96QS96EF("@A96UP='DH)&9O;&1E<DQI<W0I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L
M92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y(BDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P871H("X@)R\G("X@)&YA;64I*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+RH@1FER<W0@9&5L971E(&5V97)Y=&AI;F<@8F5L
M;W<@=&AE(&9O;&1E<BP@<V\@:68@97)R;W(@=V4*("`@("`@("`@*B!G970@
M;F\@;W)P:&%N<R`J+PH@("`@("`@("1S<6P@/2!S<')I;G1F*"=$14Q%5$4@
M1E)/32`E<R!72$5212!V9G-?<&%T:"`E<R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@
M("`@("`@("`@*&5M<'1Y*"1F;VQD97)0871H*2`F)B`D=&AI<RT^7V1B+3YD
M8G-Y;G1A>"`]/2`G;V-I."<I(#\@)R!)4R!.54Q,)R`Z("<@3$E+12`G("X@
M)'1H:7,M/E]D8BT^<75O=&4H)'1H:7,M/E]G971.871I=F50871H*"1F;VQD
M97)0871H+"`G)2<I*2D["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%2
M7TQ/1U]$14)51RD["B`@("`@("`@)&1E;&5T94-O;G1E;G1S(#T@)'1H:7,M
M/E]D8BT^<75E<GDH)'-Q;"D["B`@("`@("`@:68@*&ES7V$H)&1E;&5T94-O
M;G1E;G1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YL
M;V<H)&1E;&5T94-O;G1E;G1S+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N86)L92!T
M;R!D96QE=&4@5D93(')E8W5R<VEV96QY.B`E<RXB*2P@)&1E;&5T94-O;G1E
M;G1S+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@("\J($YO
M=R!D96QE=&4@979E<GET:&EN9R!I;G-I9&4@=&AE(&9O;&1E<BX@*B\*("`@
M("`@("`D<W%L(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S
M7W!A=&@@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R
M86US6R=T86)L92==+`H@("`@("`@("`@("`@("`@("`@("`@("AE;7!T>2@D
M<&%T:"D@)B8@)'1H:7,M/E]D8BT^9&)S>6YT87@@/3T@)V]C:3@G*2`_("<@
M25,@3E5,3"<@.B`G(#T@)R`N("1T:&ES+3Y?9&(M/G%U;W1E*"1F;VQD97)0
M871H*2D["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L+"!014%27TQ/1U]$14)5
M1RD["B`@("`@("`@)&1E;&5T92`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S<6PI
M.PH@("`@("`@(&EF("AI<U]A*"1D96QE=&4L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`@("`@)'1H:7,M/FQO9R@D9&5L971E+"!014%27TQ/1U]%4E(I
M.PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>3H@)7,N(BDL("1D
M96QE=&4M/F=E=$UE<W-A9V4H*2DI.PH@("`@("`@('T*"B`@("`@("`@+RH@
M06QL(&]K(&YO=R!D96QE=&4@=&AE(&%C='5A;"!F;VQD97(@*B\*("`@("`@
M("`D<W%L(#T@<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S7W!A
M=&@@)7,@04Y$('9F<U]N86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTL"B`@("`@("`@("`@("`@("`@
M("`@("`@*&5M<'1Y*"1P871H*2`F)B`D=&AI<RT^7V1B+3YD8G-Y;G1A>"`]
M/2`G;V-I."<I(#\@)R!)4R!.54Q,)R`Z("<@/2`G("X@)'1H:7,M/E]D8BT^
M<75O=&4H)'!A=&@I*3L*("`@("`@("`D=F%L=65S(#T@87)R87DH)&YA;64I
M.PH@("`@("`@("1T:&ES+3YL;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@("1D96QE=&4@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<W%L+"`D=F%L
M=65S*3L*("`@("`@("!I9B`H:7-?82@D9&5L971E+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@("1T:&ES+3YL;V<H)&1E;&5T92P@4$5!4E],3T=?
M15)2*3L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDZ("5S+B(I
M+"`D9&5L971E+3YG971-97-S86=E*"DI*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D9&5L971E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M(&$@;&ES="!O9B!T:&4@8V]N=&5N=',@;V8@82!F;VQD97(N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("!4:&4@9&ER96-T;W)Y
M('!A=&@N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@(%-T<FEN
M9R]H87-H(&]F(&ET96US('1O(&9I;'1E<B!B87-E9"!O;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F:6QE;F%M92X*("`@("`J($!P87)A
M;2!B;V]L96%N("1D;W1F:6QE<R`@4VAO=R!D;W1F:6QE<S\*("`@("`J($!P
M87)A;2!B;V]L96%N("1D:7)O;FQY("`@4VAO=R!D:7)E8W1O<FEE<R!O;FQY
M/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@($9I;&4@;&ES="!O;B!S
M=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]L:7-T1F]L9&5R*"1P871H+"`D9FEL=&5R(#T@;G5L;"P@)&1O=&9I
M;&5S(#T@=')U92P*("`@("`@("`@("`@("`@("`@("`@("`@("1D:7)O;FQY
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE
M8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@
M("`D<&%T:"`]("1T:&ES+3Y?8V]N=F5R=%!A=&@H)'!A=&@I.PH*("`@("`@
M("`O+R!&:7@@9F]R($]R86-L92!N;W0@9&EF9F5R96YT:6%T:6YG(&)E='=E
M96X@)R<@86YD($Y53$PN"B`@("`@("`@:68@*&5M<'1Y*"1P871H*2`F)B`D
M=&AI<RT^7V1B+3YD8G-Y;G1A>"`]/2`G;V-I."<I('L*("`@("`@("`@("`@
M)'=H97)E(#T@)W9F<U]P871H($E3($Y53$PG.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1W:&5R92`]("=V9G-?<&%T:"`]("<@+B`D=&AI<RT^
M7V1B+3YQ=6]T92@D<&%T:"D["B`@("`@("`@?0H*("`@("`@("`D;&5N9W1H
M7V]P(#T@)'1H:7,M/E]G971&:6QE4VEZ94]P*"D["B`@("`@("`@)'-Q;"`]
M('-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M92P@=F9S7W1Y<&4L("5S*'9F<U]D
M871A*2P@=F9S7VUO9&EF:65D+"!V9G-?;W=N97(@1E)/32`E<R!72$5212`E
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@)&QE;F=T:%]O<"P*("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72P*("`@
M("`@("`@("`@("`@("`@("`@("`D=VAE<F4I.PH@("`@("`@("1T:&ES+3YL
M;V<H)'-Q;"P@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("1F:6QE3&ES="`]
M("1T:&ES+3Y?9&(M/F=E=$%L;"@D<W%L*3L*("`@("`@("!I9B`H:7-?82@D
M9FEL94QI<W0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1F:6QE3&ES=#L*("`@("`@("!]"@H@("`@("`@("1F:6QE<R`](&%R<F%Y
M*"D["B`@("`@("`@9F]R96%C:"`H)&9I;&5,:7-T(&%S("1L:6YE*2!["B`@
M("`@("`@("`@("\O($9I;'1E<B!O=70@9&]T9FEL97,@:68@=&AE>2!A<F5N
M)W0@=V%N=&5D+@H@("`@("`@("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S
M='(H)&QI;F5;,%TL(#`L(#$I(#T]("<N)RD@>PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE6R=N
M86UE)UT@/2`D;&EN95LP73L*"B`@("`@("`@("`@(&EF("@D;&EN95LQ72`]
M/2!61E-?1DE,12D@>PH@("`@("`@("`@("`@("`@)&YA;64@/2!E>'!L;V1E
M*"<N)RP@)&QI;F5;,%TI.PH*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D
M;F%M92D@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E
M)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`](%9&4SHZ<W1R=&]L;W=E
M<B@D;F%M95MC;W5N="@D;F%M92D@+2`Q72D["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("1L:6YE6S)=.PH@
M("`@("`@("`@("!](&5L<V5I9B`H)&QI;F5;,5T@/3T@5D937T9/3$1%4BD@
M>PH@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*F1I<B<["B`@
M("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@+3$["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1F:6QE6R=D871E)UT@/2`D;&EN95LS73L*("`@
M("`@("`@("`@)&9I;&5;)V]W;F5R)UT@/2`D;&EN95LT73L*("`@("`@("`@
M("`@)&9I;&5;)W!E<FUS)UT@/2`G)SL*("`@("`@("`@("`@)&9I;&5;)V=R
M;W5P)UT@/2`G)SL*"B`@("`@("`@("`@("\O(&9I;'1E<FEN9PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]F:6QT97)-871C:"@D9FEL=&5R+"`D9FEL95LG
M;F%M92==*2D@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@
M("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@:68@*"1D:7)O;FQY("8F("1F:6QE6R=T>7!E)UT@(3T]("<J*F1I<B<I
M('L*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE*3L*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D9FEL
M97-;)&9I;&5;)VYA;64G75T@/2`D9FEL93L*("`@("`@("`@("`@=6YS970H
M)&9I;&4I.PH@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L:7-T(&]F(&9O
M;&1E<G,@:6X@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@=&AE(&1I
M<F5C=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A<F%M(&UI
M>&5D("1F:6QT97(@("`@("`@(%-T<FEN9R]H87-H(&]F(&ET96US('1O(&9I
M;'1E<B!B87-E9"!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9&]T9F]L
M9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES
M=$9O;&1E<G,H)'!A=&@@/2`G)RP@)&9I;'1E<B`](&%R<F%Y*"DL("1D;W1F
M;VQD97)S(#T@=')U92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?
M8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@
M("`@("`@("1P871H(#T@)'1H:7,M/E]C;VYV97)T4&%T:"@D<&%T:"D["@H@
M("`@("`@("1S<6P@(#T@)U-%3$5#5"!V9G-?;F%M92P@=F9S7W!A=&@@1E)/
M32`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT["B`@("`@("`@)'-Q;"`N
M/2`G(%=(15)%('9F<U]P871H(#T@/R!!3D0@=F9S7W1Y<&4@/2`_)SL*("`@
M("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@
M("`@)'9A;'5E<R`](&%R<F%Y*"1P871H+"!61E-?1D],1$52*3L*"B`@("`@
M("`@)&9O;&1E<DQI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH)'-Q;"P@)'9A
M;'5E<RD["B`@("`@("`@:68@*&ES7V$H)&9O;&1E<DQI<W0L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1F;VQD97),:7-T.PH@("`@
M("`@('T*"B`@("`@("`@)&9O;&1E<G,@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*"1F;VQD97),:7-T(&%S("1L:6YE*2!["B`@("`@("`@("`@("1F
M;VQD97);)W9A;"==(#T@)'1H:7,M/E]G971.871I=F50871H*"1L:6YE6S%=
M+"`D;&EN95LP72D["B`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@
M)R<["B`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@/2`G)SL*"B`@("`@
M("`@("`@("1C;W5N="`]('-U8G-T<E]C;W5N="@D9F]L9&5R6R=V86PG72P@
M)R\G*3L*"B`@("`@("`@("`@("1X(#T@,#L*("`@("`@("`@("`@=VAI;&4@
M*"1X(#P@)&-O=6YT*2!["B`@("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R
M978G72`N/2`G("`@("<["B`@("`@("`@("`@("`@("`D9F]L9&5R6R=L86)E
M;"==("X]("<@("`@)SL*("`@("`@("`@("`@("`@("1X*RL["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==("X]("1L:6YE
M6S!=.PH@("`@("`@("`@("`D9F]L9&5R6R=L86)E;"==("X]("1L:6YE6S!=
M.PH*("`@("`@("`@("`@)'-T<FQE;B`](%9&4SHZ<W1R;&5N*"1F;VQD97);
M)VQA8F5L)UTI.PH@("`@("`@("`@("!I9B`H)'-T<FQE;B`^(#(V*2!["B`@
M("`@("`@("`@("`@("`D9F]L9&5R6R=A8F)R978G72`]('-U8G-T<B@D9F]L
M9&5R6R=L86)E;"==+"`P+"`H)&-O=6YT("H@-"DI.PH@("`@("`@("`@("`@
M("`@)&QE;F=T:"`]("@R.2`M("@D8V]U;G0@*B`T*2D@+R`R.PH@("`@("`@
M("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@<W5B<W1R*"1F;VQD97);
M)VQA8F5L)UTL("@D8V]U;G0@*B`T*2P@)&QE;F=T:"D["B`@("`@("`@("`@
M("`@("`D9F]L9&5R6R=A8F)R978G72`N/2`G+BXN)SL*("`@("`@("`@("`@
M("`@("1F;VQD97);)V%B8G)E=B==("X]('-U8G-T<B@D9F]L9&5R6R=L86)E
M;"==+"`M,2`J("1L96YG=&@L("1L96YG=&@I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`D9F]U;F0@/2!F86QS93L*("`@("`@("`@("`@9F]R96%C
M:"`H)&9I;'1E<B!A<R`D9FQT<BD@>PH@("`@("`@("`@("`@("`@:68@*"1F
M;VQD97);)W9A;"==(#T]("1F;'1R*2!["B`@("`@("`@("`@("`@("`@("`@
M)&9O=6YD(#T@=')U93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@
M("1F;VQD97)S6R1F;VQD97);)W9A;"==72`]("1F;VQD97(["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&MS;W)T*"1F;VQD97)S*3L*("`@
M("`@("!R971U<FX@)&9O;&1E<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M96YA;65S(&%L;"!C:&EL9"!P871H<RX*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%T:"!O9B!T:&4@9F]L9&5R('1O(')E;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@(%1H92!F;VQD97)N86UE('1O('5S92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!?<F5C=7)S:79E4F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE
M=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@("1O;&1P871H(#T@)'1H
M:7,M/E]C;VYV97)T4&%T:"@D;VQD<&%T:"D["B`@("`@("`@)&YE=W!A=&@@
M/2`D=&AI<RT^7V-O;G9E<G10871H*"1N97=P871H*3L*"B`@("`@("`@)'-Q
M;"`@/2`G4T5,14-4('9F<U]N86UE($923TT@)R`N("1T:&ES+3Y?<&%R86US
M6R=T86)L92==.PH@("`@("`@("1S<6P@+CT@)R!72$5212!V9G-?='EP92`]
M(#\@04Y$('9F<U]P871H(#T@/R<["B`@("`@("`@)'1H:7,M/FQO9R@D<W%L
M+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("1V86QU97,@/2!A<G)A>2A6
M1E-?1D],1$52+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&]L9'!A=&@L("1O
M;&1N86UE*2D["@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/E]D8BT^
M9V5T0V]L*"1S<6PL(#`L("1V86QU97,I.PH*("`@("`@("!F;W)E86-H("@D
M9F]L9&5R3&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<F5C=7)S:79E4F5N86UE*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;VQD<&%T
M:"P@)&]L9&YA;64I+"`D9F]L9&5R+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H
M)&YE=W!A=&@L("1N97=N86UE*2P@)&9O;&1E<BD["B`@("`@("`@?0H*("`@
M("`@("`D<W%L(#T@)U501$%412`G("X@)'1H:7,M/E]P87)A;7-;)W1A8FQE
M)UT@+B`G(%-%5"!V9G-?<&%T:"`](#\@5TA%4D4@=F9S7W!A=&@@/2`_)SL*
M("`@("`@("`D=&AI<RT^;&]G*"1S<6PL(%!%05)?3$]'7T1%0E5'*3L*"B`@
M("`@("`@)'9A;'5E<R`](&%R<F%Y*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D
M;F5W<&%T:"P@)&YE=VYA;64I+"`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&]L
M9'!A=&@L("1O;&1N86UE*2D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V1B+3YQ=65R>2@D<W%L+"`D=F%L=65S*3L*"B`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!F=6QL(&9I
M;&5N86UE(&]N('1H92!N871I=F4@9FEL97-Y<W1E;2P@9G)O;2!A(%9&4PH@
M("`@("H@<&%T:"!A;F0@;F%M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@
M5D93(&9I;&4@<&%T:"X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!61E,@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M(%1H92!F=6QL(&YA=&EV92!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M(&EF("AE;7!T>2@D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1N86UE
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"DI('L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=H;VUE)UTI("8F
M"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"=\7GXO/R@N*BDD?"<L("1P
M871H+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1P871H(#T@)'1H
M:7,M/E]P87)A;7-;)VAO;64G72`N("<O)R`N("1M871C:&5S6S%=.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'!A=&@@+B`G
M+R<@+B`D;F%M93L*("`@('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O
M(&]P96X@82!P97)S:7-T96YT(&-O;FYE8W1I;VX@=&\@=&AE(%-13"!S97)V
M97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V1B(#T]/2!F
M86QS92D@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T:&ES+3Y?<&%R
M86US*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S<&5C:69I960@
M9F]R(%-13"!61E,N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D
M<F5Q=6ER960@/2!A<G)A>2@G<&AP='EP92<I.PH@("`@("`@("`@("!F;W)E
M86-H("@D<F5Q=6ER960@87,@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7W!A<F%M<ULD=F%L72DI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E)E
M<75I<F5D(%PB)7-<(B!N;W0@<W!E8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T
M:6]N+B(I+"`D=F%L*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)V1A
M=&%B87-E)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG
M9&%T86)A<V4G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W5S97)N86UE)UTI*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<FYA;64G72`]("<G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M87)A;7-;)VAO<W1S<&5C)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A<F%M<ULG:&]S='-P96,G72`]("<G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72`]("=H
M;W)D95]V9G,G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!#;VYN
M96-T('1O('1H92!344P@<V5R=F5R('5S:6YG('1H92!S=7!P;&EE9"!P87)A
M;65T97)S+B`J+PH@("`@("`@("`@("!R97%U:7)E7V]N8V4@)T1"+G!H<"<[
M"B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2`F1$(Z.F-O;FYE8W0H)'1H:7,M
M/E]P87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)W!E<G-I<W1E;G0G(#T^("%E;7!T>2@D=&AI<RT^7W!A<F%M
M<ULG<&5R<VES=&5N="==*2DI.PH@("`@("`@("`@("!I9B`H:7-?82@D=&AI
M<RT^7V1B+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*"1T:&ES+3Y?9&(L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@
M("`@("`D97)R;W(@/2`D=&AI<RT^7V1B.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D8B`](&9A;'-E.PH@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("`@("`@?0H*"B`@("`@("`@("`@("\O(%-E="!$0B!P;W)T
M86)I;&ET>2!O<'1I;VYS+@H@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3Y?
M9&(M/G!H<'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G;7-S<6PG.@H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET
M>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,2519
M7T524D]24R!\($1"7U!/4E1!0DE,25197U)44DE-*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/
M4E1!0DE,25197TQ/5T520T%312!\($1"7U!/4E1!0DE,25197T524D]24RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W0@9G)O;2!T:&4@
M4U%,('-E<G9E<B!A;F0@8VQE86X@=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]D8BD@
M>PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YD:7-C;VYN96-T*"D["B`@("`@
M("`@("`@("1T:&ES+3Y?9&(@/2!F86QS93L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%B;&4@("`@(%1/
M1$\*("`@("`J($!P87)A;2!S=')I;F<@)&9I96QD("`@("!43T1/"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C<FET97)I82`@5$]$3PH@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E
M861";&]B*"1T86)L92P@)&9I96QD+"`D8W)I=&5R:6$I"B`@("!["B`@("`@
M("`@:68@*"%C;W5N="@D8W)I=&5R:6$I*2!["B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=9;W4@;75S="!S<&5C:69Y('1H92!F971C
M:"!C<FET97)I82<I.PH@("`@("`@('T*"B`@("`@("`@)'=H97)E(#T@)R<[
M"@H@("`@("`@('-W:71C:"`H)'1H:7,M/E]D8BT^9&)S>6YT87@I('L*("`@
M("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@9F]R96%C:"`H)&-R:71E
M<FEA(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1W:&5R92DI('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F4@
M+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@)'=H
M97)E("X]("1K97D@+B`G($E3($Y53$PG.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D=VAE<F4@+CT@)&ME>2`N("<@
M/2`G("X@)'1H:7,M/E]D8BT^<75O=&4H)'9A;'5E*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-T871E;65N="`]
M($]#25!A<G-E*"1T:&ES+3Y?9&(M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*"=314Q%0U0@)7,@1E)/
M32`E<R!72$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F:65L9"P@)'1A8FQE+"`D=VAE<F4I*3L*("`@("`@
M("`@("`@3T-)17AE8W5T92@D<W1A=&5M96YT*3L*("`@("`@("`@("`@:68@
M*$]#249E=&-H26YT;R@D<W1A=&5M96YT+"`D;&]B*2D@>PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1L;V);,%TM/FQO860H*3L*("`@("`@("`@("`@
M("`@(&EF("AI<U]N=6QL*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`@
M("`@)')E<W5L="`](%!%05(Z.G)A:7-E17)R;W(H)U5N86)L92!T;R!L;V%D
M(%-13"!D871A+B<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A:7-E
M17)R;W(H)U5N86)L92!T;R!L;V%D(%-13"!D871A+B<I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!F;W)E86-H("@D8W)I=&5R:6$@87,@)&ME>2`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("1W:&5R92`N/2`G($%.1"`G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'=H97)E("X]("1K97D@+B`G(#T@)R`N
M("1T:&ES+3Y?9&(M/G%U;W1E*"1V86QU92D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("1S<6P@/2!S<')I;G1F*"=314Q%0U0@)7,@1E)/32`E<R!7
M2$5212`E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P@
M)'1A8FQE+"`D=VAE<F4I.PH@("`@("`@("`@("`D=&AI<RT^;&]G*"1S<6PL
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3Y?9&(M/F=E=$]N92@D<W%L*3L*"B`@("`@("`@("`@(&EF("AI<U]N=6QL
M*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@G56YA8FQE('1O(&QO860@4U%,(&1A=&$N)RD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!S=VET8V@@*"1T:&ES
M+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@("`@("`@("`@("!C87-E("=P9W-Q
M;"<Z"B`@("`@("`@("`@("`@("`@("`@)')E<W5L="`]('!A8VLH)T@G("X@
M<W1R;&5N*"1R97-U;'0I+"`D<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%B;&4@("`@("`@5$]$3PH@
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@("`@("`@5$]$3PH@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("`@5$]$3PH@("`@("H@0'!A<F%M
M('-T<FEN9R`D871T<FEB=71E<R`@5$]$3PH@("`@("H*("`@("`J($!R971U
M<FX@;6EX960@(%1/1$\*("`@("`J+PH@("`@9G5N8W1I;VX@7VEN<V5R=$)L
M;V(H)'1A8FQE+"`D9FEE;&0L("1D871A+"`D871T<FEB=71E<RD*("`@('L*
M("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@("`@("`D=F%L=65S(#T@
M87)R87DH*3L*"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y;G1A
M>"D@>PH@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@("`@("`@("!F;W)E86-H
M("@D871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@
M("`@("`@)&9I96QD<UM=(#T@)&ME>3L*("`@("`@("`@("`@("`@("1V86QU
M97-;72`]("1T:&ES+3Y?9&(M/G%U;W1E4VUA<G0H)'9A;'5E*3L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@)'-T871E;65N="`]($]#25!A<G-E*"1T
M:&ES+3Y?9&(M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S<')I;G1F*"=)3E-%4E0@24Y43R`E<R`H)7,L("5S*2<@
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M(%9!3%5%4R`H)7,L($5-4%197T),3T(H*2D@4D5455).24Y'("5S($E.5$\@
M.F)L;V(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)&9I96QD<RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F:65L9"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G
M+"`G+"`D=F%L=65S*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9I96QD*2D["@H@("`@("`@("`@("`D;&]B(#T@3T-)
M3F5W1&5S8W)I<'1O<B@D=&AI<RT^7V1B+3YC;VYN96-T:6]N*3L*("`@("`@
M("`@("`@3T-)0FEN9$)Y3F%M92@D<W1A=&5M96YT+"`G.F)L;V(G+"`D;&]B
M+"`M,2P@4U%,5%]"3$]"*3L*("`@("`@("`@("`@3T-)17AE8W5T92@D<W1A
M=&5M96YT+"!/0TE?1$5&055,5"D["B`@("`@("`@("`@("1L;V(M/G-A=F4H
M)&1A=&$I.PH@("`@("`@("`@("`D<F5S=6QT(#T@3T-)0V]M;6ET*"1T:&ES
M+3Y?9&(M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`D;&]B+3YF<F5E*"D[
M"B`@("`@("`@("`@($]#249R9653=&%T96UE;G0H)'-T871E;65N="D["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT(#\@=')U92`Z(%!%05(Z.G)A:7-E
M17)R;W(H)U5N:VYO=VX@17)R;W(G*3L*"B`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L
M=64I('L*("`@("`@("`@("`@("`@("1F:65L9'-;72`]("1K97D["B`@("`@
M("`@("`@("`@("`D=F%L=65S6UT@/2`D=F%L=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)TE.4T525"!)3E1/("5S
M("@E<RP@)7,I(%9!3%5%4R`H)7,I)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:6UP;&]D92@G+"`G+"`D9FEE;&1S*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9FEE;&0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)S\G("X@<W1R7W)E<&5A="@G+"`_)RP@8V]U;G0H)'9A;'5E<RDI*3L*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1T
M:&ES+3Y?9&(M/F1B<WEN=&%X*2!["B`@("`@("`@8V%S92`G;7-S<6PG.@H@
M("`@("`@(&-A<V4@)W!G<W%L)SH*("`@("`@("`@("`@)'9A;'5E<UM=(#T@
M8FEN,FAE>"@D9&%T82D["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`D=F%L=65S6UT@/2`D9&%T83L*("`@("`@
M("!]"@H@("`@("`@("\J($5X96-U=&4@=&AE('%U97)Y+B`J+PH@("`@("`@
M("1T:&ES+3YL;V<H)'%U97)Y+"!014%27TQ/1U]$14)51RD["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q=65R>2P@)'9A;'5E<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!43T1/"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%B;&4@
M("`@("!43T1/"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9"`@("`@(%1/
M1$\*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$@("`@("`@5$]$3PH@("`@
M("H@0'!A<F%M('-T<FEN9R`D=VAE<F4@("`@("!43T1/"B`@("`@*B!`<&%R
M86T@87)R87D@)&%L<V]U<&1A=&4@(%1/1$\*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!43T1/"B`@("`@*B\*("`@(&9U;F-T:6]N(%]U<&1A=&5"
M;&]B*"1T86)L92P@)&9I96QD+"`D9&%T82P@)'=H97)E+"`D86QS;W5P9&%T
M92D*("`@('L*("`@("`@("`D9FEE;&1S(#T@87)R87DH*3L*("`@("`@("`D
M=F%L=65S(#T@87)R87DH*3L*"B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B
M+3YD8G-Y;G1A>"D@>PH@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@("`@("`@
M("`D=VAE<F5S=')I;F<@/2`G)SL*("`@("`@("`@("`@9F]R96%C:"`H)'=H
M97)E(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1W:&5R97-T<FEN9RDI('L*("`@("`@("`@("`@("`@("`@("`D
M=VAE<F5S=')I;F<@+CT@)R!!3D0@)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`D:V5Y("X@)R`]("<@+B`D
M=&AI<RT^7V1B+3YQ=6]T92@D=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D<W1A=&5M96YT(#T@3T-)4&%R<V4H)'1H:7,M/E]D8BT^8V]N
M;F5C=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-P
M<FEN=&8H)U-%3$5#5"`E<R!&4D]-("5S(%=(15)%("5S($9/4B!54$1!5$4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9FEE;&0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'=H97)E<W1R:6YG*2D["@H@("`@("`@("`@("!/0TE%>&5C
M=71E*"1S=&%T96UE;G0L($]#25]$149!54Q4*3L*("`@("`@("`@("`@3T-)
M1F5T8VA);G1O*"1S=&%T96UE;G0L("1L;V(I.PH@("`@("`@("`@("`D;&]B
M6S!=+3YS879E*"1D871A*3L*("`@("`@("`@("`@)')E<W5L="`]($]#24-O
M;6UI="@D=&AI<RT^7V1B+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)&QO
M8ELP72T^9G)E92@I.PH@("`@("`@("`@("!/0TE&<F5E4W1A=&5M96YT*"1S
M=&%T96UE;G0I.PH@("`@("`@("`@("!R971U<FX@)')E<W5L="`_('1R=64@
M.B!014%2.CIR86ES945R<F]R*"=5;FMN;W=N($5R<F]R)RD["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("1U<&1A=&5S=')I;F<@/2`G)SL*("`@
M("`@("`@("`@)'9A;'5E<R`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1A;'-O=7!D871E(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@
M("`@("`@("`D=7!D871E<W1R:6YG("X]("1K97D@+B`G(#T@/RP@)SL*("`@
M("`@("`@("`@("`@("1V86QU97-;72`]("1V86QU93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=7!D871E<W1R:6YG("X]("1F:65L9"`N("<@/2`_
M)SL*("`@("`@("`@("`@<W=I=&-H("@D=&AI<RT^7V1B+3YD8G-Y;G1A>"D@
M>PH@("`@("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@(&-A<V4@
M)W!G<W%L)SH*("`@("`@("`@("`@("`@("1V86QU97-;72`](&)I;C)H97@H
M)&1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@)'9A;'5E<UM=(#T@)&1A=&$["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1W:&5R97-T<FEN9R`]("<G.PH@
M("`@("`@("`@("!F;W)E86-H("@D=VAE<F4@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'=H97)E<W1R:6YG*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9R`N/2`G($%.1"`G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'=H97)E<W1R
M:6YG("X]("1K97D@+B`G(#T@/R<["B`@("`@("`@("`@("`@("`D=F%L=65S
M6UT@/2`D=F%L=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1Q=65R
M>2`]('-P<FEN=&8H)U501$%412`E<R!3150@)7,@5TA%4D4@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T86)L92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=7!D871E<W1R:6YG+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W:&5R97-T<FEN9RD["B`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@('T*"B`@("`@("`@+RH@17AE8W5T92!T:&4@<75E<GDN
M("HO"B`@("`@("`@)'1H:7,M/FQO9R@D<75E<GDL(%!%05)?3$]'7T1%0E5'
M*3L*("`@("`@("!R971U<FX@)'1H:7,M/E]D8BT^<75E<GDH)'%U97)Y+"`D
M=F%L=65S*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE('!A
M=&AN86UE(&9R;VT@<F5G=6QA<B!F:6QE<WES=&5M(&9O<FT@=&\@=&AE(&EN
M=&5R;F%L"B`@("`@*B!F;W)M870@;F5E9&5D('1O(&%C8V5S<R!T:&4@9FEL
M92!I;B!T:&4@9&%T86)A<V4N"B`@("`@*B!.86UE;'DL('=E('=I;&P@=')E
M870@)R\G(&%S(&$@8F%S92!D:7)E8W1O<GD@87,@=&AI<R!I<R!P<F5T='D@
M;75C:`H@("`@("H@=&AE('-T86YD87)D('=A>2!T;R!A8V-E<W,@8F%S92!D
M:7)E8W1O<FEE<R!O=F5R(&UO<W0@9FEL97-Y<W1E;7,N"GT@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@02!61E,@<&%T:"X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE('!A=&@@=VET:"!A;GD@8F5G:6YN:6YG('-L87-H('-T<FEP
M<&5D(&]F9BX*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;G9E<G10871H*"1P
M871H*0H@("`@>PH@("`@("`@(&EF("@A96UP='DH)'!A=&@I("8F("AS=')P
M;W,H)'!A=&@L("<O)RD@/3T](#`I*2!["B`@("`@("`@("`@("1P871H(#T@
M<W1R=F%L*'-U8G-T<B@D<&%T:"P@,2DI.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1P871H.PH@("`@?0H*("`@(&9U;F-T:6]N(%]G971&:6QE4VEZ
M94]P*"D*("`@('L*("`@("`@("!S=VET8V@@*"1T:&ES+3Y?9&(M/F1B<WEN
M=&%X*2!["B`@("`@("`@8V%S92`G;7ES<6PG.@H@("`@("`@("`@("!R971U
M<FX@)TQ%3D=42"<["@H@("`@("`@(&-A<V4@)V]C:3@G.@H@("`@("`@("`@
M("!R971U<FX@)TQ%3D=42$(G.PH*("`@("`@("!C87-E("=M<W-Q;"<Z"B`@
M("`@("`@8V%S92`G<WEB87-E)SH*("`@("`@("`@("`@<F5T=7)N("=$051!
M3$5.1U1()SL*"B`@("`@("`@8V%S92`G<&=S<6PG.@H@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@(')E='5R;B`G3T-4151?3$5.1U1()SL*("`@("`@
M("!]"B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O;75S<6PN<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,S8R-R`Q,#4Q-30S
M-#$S-B`P,C`V,C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?
M*2`N("<O<W%L+G!H<"<["@HO*BH*("H@4&5R;6ES<VEO;B!F;W(@<F5A9"!A
M8V-E<W,N"B`J+PID969I;F4H)U9&4U]&3$%'7U)%040G+"`Q*3L*"B\J*@H@
M*B!097)M:7-S:6]N(&9O<B!R96%D(&%C8V5S<RX*("HO"F1E9FEN92@G5D93
M7T9,04=?5U))5$4G+"`R*3L*"B\J*@H@*B!-=6QT:2!5<V5R(%9&4R!I;7!L
M96UE;G1A=&EO;B!F;W(@4$A0)W,@4$5!4B!D871A8F%S90H@*B!A8G-T<F%C
M=&EO;B!L87EE<BX*("H*("H@4F5Q=6ER960@=F%L=65S(&9O<B`D<&%R86US
M.CQP<F4^"B`J("`@("`@)W!H<'1Y<&4G("`@("`@(%1H92!D871A8F%S92!T
M>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN/"]P<F4^"B`J"B`J
M($]P=&EO;F%L('9A;'5E<SH\<')E/@H@*B`@("`@("=T86)L92<@("`@("`@
M("!4:&4@;F%M92!O9B!T:&4@=F9S('1A8FQE(&EN("=D871A8F%S92<N($1E
M9F%U;'1S('1O"B`J("`@("`@("`@("`@("`@("`@("`@("=H;W)D95]M=79F
M<R<N/"]P<F4^"B`J"B`J(%)E<75I<F5D(&)Y('-O;64@9&%T86)A<V4@:6UP
M;&5M96YT871I;VYS.CQP<F4^"B`J("`@("`@)VAO<W1S<&5C)R`@("`@(%1H
M92!H;W-T;F%M92!O9B!T:&4@9&%T86)A<V4@<V5R=F5R+@H@*B`@("`@("=P
M<F]T;V-O;"<@("`@("!4:&4@8V]M;75N:6-A=&EO;B!P<F]T;V-O;"`H)W1C
M<"<L("=U;FEX)RP@971C+BDN"B`J("`@("`@)V1A=&%B87-E)R`@("`@(%1H
M92!N86UE(&]F('1H92!D871A8F%S92X*("H@("`@("`G=7-E<FYA;64G("`@
M("`@5&AE('5S97)N86UE('=I=&@@=VAI8V@@=&\@8V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4N"B`J("`@("`@)W!A<W-W;W)D)R`@("`@(%1H92!P87-S=V]R
M9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N86UE)RX*("H@("`@("`G;W!T:6]N
M<R<@("`@("`@061D:71I;VYA;"!O<'1I;VYS('1O('!A<W,@=&\@=&AE(&1A
M=&%B87-E+@H@*B`@("`@("=T='DG("`@("`@("`@("!4:&4@5%19(&]N('=H
M:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=P;W)T
M)R`@("`@("`@("!4:&4@<&]R="!O;B!W:&EC:"!T;R!C;VYN96-T('1O('1H
M92!D871A8F%S92X\+W!R93X*("H*("H@2VYO=VX@27-S=65S.@H@*B!$96QE
M=&4@:7,@;F]T(')E8W5S:79E+"!S;R!F:6QE<R!A;F0@9F]L9&5R<R!T:&%T
M('5S960@=&\@8F4@:6X@82!F;VQD97(*("H@=&AA="!G971S(&1E;&5T960@
M;&EV92!F;W)E=F5R(&EN('1H92!D871A8F%S92P@;W(@<F4M87!P96%R('=H
M96X@=&AE(&9O;&1E<@H@*B!I<R!R96-R96%T960N"B`J(%)E;F%M92!H87,@
M=&AE('-A;64@:7-S=64L('-O(&9I;&5S(&%R92!L;W-T(&EF(&$@9F]L9&5R
M(&ES(')E;F%M960N"B`J"B`J(%1H92!T86)L92!S=')U8W1U<F4@9F]R('1H
M92!61E,@8V%N(&)E(&9O=6YD(&EN"B`J(&1A=&$O;75V9G,N<W%L+@H@*@H@
M*B!$871A8F%S92!S<&5C:69I8R!N;W1E<SH*("H*("H@35-344PZ"B`J("T@
M5&AE('9F<U]D871A(&9I96QD(&UU<W0@8F4@;V8@='EP92!)34%'12X*("H@
M+2!9;W4@;F5E9"!T:&4@9F]L;&]W:6YG('!H<"YI;FD@<V5T=&EN9W,Z"B`J
M(#QC;V1E/@H@*B`@("`[(%9A;&ED(')A;F=E(#`@+2`R,30W-#@S-C0W+B!$
M969A=6QT(#T@-#`Y-BX*("H@("`@;7-S<6PN=&5X=&QI;6ET(#T@,"`[('IE
M<F\@=&\@<&%S<R!T:')O=6=H"B`J"B`J("`@(#L@5F%L:60@<F%N9V4@,"`M
M(#(Q-#<T.#,V-#<N($1E9F%U;'0@/2`T,#DV+@H@*B`@("!M<W-Q;"YT97AT
M<VEZ92`](#`@.R!Z97)O('1O('!A<W,@=&AR;W5G:`H@*B`\+V-O9&4^"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O;75S<6PN<&AP+'8@,2XS
M,"XT+C$V(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@($UI:V4@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^"B`J($!P86-K86=E
M(%9&4PH@*B\*8VQA<W,@5D937VUU<W%L(&5X=&5N9',@5D937W-Q;"!["@H@
M("`@+RHJ"B`@("`@*B!,:7-T(&]F('!E<FUI<W-I;VYS(&%N9"!I9B!T:&5Y
M(&-A;B!B92!C:&%N9V5D(&EN('1H:7,@5D93"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P97)M:7-S:6]N<R`](&%R<F%Y
M*`H@("`@("`@("=O=VYE<B<@/3X@87)R87DH)W)E860G(#T^(&9A;'-E+"`G
M=W)I=&4G(#T^(&9A;'-E+"`G97AE8W5T92<@/3X@9F%L<V4I+`H@("`@("`@
M("=G<F]U<"<@/3X@87)R87DH)W)E860G(#T^(&9A;'-E+"`G=W)I=&4G(#T^
M(&9A;'-E+"`G97AE8W5T92<@/3X@9F%L<V4I+`H@("`@("`@("=A;&PG("`@
M/3X@87)R87DH)W)E860G(#T^('1R=64L("`G=W)I=&4G(#T^('1R=64L("`G
M97AE8W5T92<@/3X@9F%L<V4I"B`@("`I.PH*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE(&EN('1H92!61E,@9G)O;2!R87<@9&%T82X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&$@("`@("`@("!4:&4@9FEL92!D871A+@H@("`@("H@0'!A
M<F%M(&)O;VQE86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E
M(&1I<F5C=&]R:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R
M=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E1&%T82@D<&%T:"P@)&YA
M;64L("1D871A+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&-O;FXI*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*
M("`@("`@("!]"@H@("`@("`@("\J($UA:V4@<W5R92!W92!H879E('=R:71E
M(&%C8V5S<R!T;R!T:&ES(&%N9"!A;&P@<&%R96YT"B`@("`@("`@("H@<&%T
M:',N("HO"B`@("`@("`@:68@*"1P871H("$]("<G*2!["B`@("`@("`@("`@
M("1P871H<R`](&5X<&QO9&4H)R\G+"`D<&%T:"D["B`@("`@("`@("`@("1P
M871H7VYA;64@/2!A<G)A>5]P;W`H)'!A=&AS*3L*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^:7-&;VQD97(H:6UP;&]D92@G+R<L("1P871H<RDL("1P871H
M7VYA;64I*2!["B`@("`@("`@("`@("`@("!I9B`H(21A=71O8W)E871E*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M<W!R:6YT9BA?*")&;VQD97(@)7,@9&]E<R!N;W0@97AI<W0B*2P@)'!A=&@I
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E
M4&%T:"@D<&%T:"D["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'!A=&AS
M6UT@/2`D<&%T:%]N86UE.PH@("`@("`@("`@("`D<')E=FEO=7,@/2`G)SL*
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1P871H<R!A<R`D=&AI<W!A=&@I('L*
M("`@("`@("`@("`@("`@("1R97-U;'1S(#T@)'1H:7,M/E]D8BT^9V5T06QL
M*'-P<FEN=&8H)U-%3$5#5"!V9G-?;W=N97(L('9F<U]P97)M<R!&4D]-("5S
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE/2`_
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)'!R979I;W5S+"`D=&AI<W!A=&@I*3L*("`@("`@("`@("`@("`@(&EF("@A
M:7-?87)R87DH)')E<W5L=',I('Q\(&-O=6YT*"1R97-U;'1S*2`\(#$I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@8W)E871E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`D86QL;W=E9"`](&9A;'-E.PH@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)')E<W5L=',@87,@)')E<W5L="D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S!=(#T]("1T:&ES+3Y?
M<&%R86US6R=U<V5R)UT@?'P@)')E<W5L=%LQ72`F(%9&4U]&3$%'7U=2251%
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A;&QO=V5D(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF
M("@A)&%L;&]W960I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")!8V-E<W,@9&5N:65D(&-R96%T:6YG(%9&4R!F
M:6QE+B(I*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D
M<')E=FEO=7,@/2`D=&AI<W!A=&@["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!P87)E;G0Z.G=R:71E1&%T82@D<&%T:"P@)&YA
M;64L("1D871A+"`D875T;V-R96%T92D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$96QE=&4@82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL
M92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M
M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1FEL92@D<&%T:"P@)&YA;64I
M"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N;BDI('L*("`@("`@("`@("`@
M<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5,:7-T(#T@
M)'1H:7,M/E]D8BT^9V5T06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?:60L('9F
M<U]O=VYE<BP@=F9S7W!E<FUS($923TT@)7,*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S7W!A=&@@
M/2`_($%.1"!V9G-?;F%M93T@/R!!3D0@=F9S7W1Y<&4@/2`_)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H+"`D;F%M92P@5D937T9)3$4I
M*3L*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9FEL94QI<W0I('Q\(&-O=6YT
M*"1F:6QE3&ES="D@/"`Q*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&9I;&4N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@+RH@5&AE<F4@;6%Y(&)E(&]N92!O<B!M;W)E
M(&9I;&5S('=I=&@@=&AE('-A;64@;F%M92!B=70@=&AE"B`@("`@("`@("`@
M=7-E<B!M87D@;F]T(&AA=F4@<F5A9"!A8V-E<W,@=&\@=&AE;2P@<V\@9&]E
M<VXG="!S964*("`@("`@("`@("!T:&5M+B!3;R!W92!H879E('1O(&1E;&5T
M92!T:&4@;VYE('1H97D@:&%V92!A8V-E<W,@=&\N("HO"B`@("`@("`@9F]R
M96%C:"`H)&9I;&5,:7-T(&%S("1F:6QE*2!["B`@("`@("`@("`@(&EF("@D
M9FEL95LQ72`]/2`D=&AI<RT^7W!A<F%M<ULG=7-E<B==('Q\("1F:6QE6S)=
M("8@5D937T9,04=?5U))5$4I('L*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$14Q%5$4@1E)/32`E<R!7
M2$5212!V9G-?:60@/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D9FEL95LP72DI.PH*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V1B+3YA9F9E8W1E9%)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O
M(&1E;&5T92!61E,@9FEL92XB*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@+R\@1DE8344Z("=!8V-E<W,@1&5N:65D(&1E;&5T
M:6YG(&9I;&4@)7,O)7,G"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9FEL92XB*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296YA;64@82!F:6QE(&]R(&9O;&1E<B!I;B!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A=&@@(%1H
M92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@
M)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N86UE+@H@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O
M<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H
M+"`D;F5W;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N
M;F5C="@I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C;VYN*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D
M9FEL94QI<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4
M('9F<U]I9"P@=F9S7V]W;F5R+"!V9G-?<&5R;7,@1E)/32`E<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1O;&1P871H+"`D;VQD
M;F%M92DI.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@
M8V]U;G0H)&9I;&5,:7-T*2`\(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(')E;F%M92!61E,@9FEL92XB
M*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R<&]S*"1N97=P871H+"`G
M+R<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R96YT(#T@)R<["B`@
M("`@("`@("`@("1P871H(#T@)&YE=W!A=&@["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@;&ES="@D<&%R96YT+"`D<&%T:"D@/2!E>'!L;V1E*"<O
M)RP@)&YE=W!A=&@L(#(I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES
M+3YI<T9O;&1E<B@D<&%R96YT+"`D<&%T:"DI('L*("`@("`@("`@("`@:68@
M*&ES7V$H)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D;F5W<&%T
M:"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!4
M:&5R92!M87D@8F4@;VYE(&]R(&UO<F4@9FEL97,@=VET:"!T:&4@<V%M92!N
M86UE(&)U="!T:&4@=7-E<B!M87D*("`@("`@("`@*B!N;W0@:&%V92!R96%D
M(&%C8V5S<R!T;R!T:&5M+"!S;R!D;V5S;B=T('-E92!T:&5M+B!3;R!W92!H
M879E('1O"B`@("`@("`@("H@<F5N86UE('1H92!O;F4@=&AE>2!H879E(&%C
M8V5S<R!T;RX@*B\*("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&9I
M;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6S%=(#T]("1T:&ES+3Y?<&%R
M86US6R=U<V5R)UT@?'P@)&9I;&5;,ET@)B!61E-?1DQ!1U]74DE412D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P
M<FEN=&8H)U501$%412`E<R!3150@=F9S7W!A=&@@/2`_+"!V9G-?;F%M92`]
M(#\L('9F<U]M;V1I9FEE9"`](#\*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]I9"`](#\G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1N97=P
M871H+"`D;F5W;F%M92P@=&EM92@I+"`D9FEL95LP72DI.PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M56YA8FQE('1O(')E;F%M92!61E,@9FEL92`E<R\E<RXB*2P@)&]L9'!A=&@L
M("1O;&1N86UE*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<&%T:"`@2&]L9',@=&AE('!A=&@@;V8@9&ER96-T;W)Y('1O(&-R96%T
M92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!(;VQD<R!T
M:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&5&
M;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H
M:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O
M;FXI*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@
M("`@("`@("\J(&UA:V4@<W5R92!W92!H879E('=R:71E(&%C8V5S<R!T;R!T
M:&ES(&%N9"!A;&P@<&%R96YT('!A=&AS("HO"B`@("`@("`@:68@*"1P871H
M("$]("(B*2!["B`@("`@("`@("`@("1P871H<R`](&5X<&QO9&4H)R\G+"`D
M<&%T:"D["B`@("`@("`@("`@("1P<F5V:6]U<R`]("<G.PH*("`@("`@("`@
M("`@9F]R96%C:"`H)'!A=&AS(&%S("1T:&ES<&%T:"D@>PH@("`@("`@("`@
M("`@("`@)')E<W5L=',@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G
M4T5,14-4('9F<U]O=VYE<BP@=F9S7W!E<FUS($923TT@)7,*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@5TA%4D4@=F9S7W!A=&@@/2`_($%.1"!V9G-?;F%M93T@/R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"1P<F5V:6]U<RP@)'1H:7-P871H*2D["B`@("`@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1R97-U;'1S*2!\?"!C;W5N="@D<F5S=6QT<RD@
M/"`Q*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H7R@B56YA8FQE('1O(&-R96%T92!61E,@9&ER96-T;W)Y+B(I*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D86QL;W=E9"`]
M(&9A;'-E.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E<W5L=',@87,@
M)')E<W5L="D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S!=
M(#T]("1T:&ES+3Y?<&%R86US6R=U<V5R)UT@?'P@)')E<W5L=%LQ72`F(%9&
M4U]&3$%'7U=2251%*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A;&QO
M=V5D(#T@=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@(&EF("@A)&%L;&]W960I('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")!8V-E<W,@9&5N:65D(&-R
M96%T:6YG(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("1P<F5V:6]U<R`]("1T:&ES<&%T:#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^
M;F5X=$ED*"1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G24Y315)4($E.5$\@)7,@
M*'9F<U]I9"P@=F9S7W1Y<&4L('9F<U]P871H+"!V9G-?;F%M92P@=F9S7VUO
M9&EF:65D+"!V9G-?;W=N97(L('9F<U]P97)M<RD*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!604Q515,@*#\L(#\L(#\L(#\L
M(#\L(#\L(#\I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1I9"P@5D937T9/3$1%4BP@
M)'!A=&@L("1N86UE+"!T:6UE*"DL("1T:&ES+3Y?<&%R86US6R=U<V5R)UTL
M(#`I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9I;&4@9G)O
M;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@
M("`@("`@(%1H92!P871H('1O(&1E;&5T92!T:&4@9F]L9&5R(&9R;VTN"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@9F]L9&5R;F%M
M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E("!&
M;W)C92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1F]L
M9&5R*"1P871H+"`D;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-O;FXI*2!["B`@("`@("`@("`@(')E='5R;B`D
M8V]N;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D<F5C=7)S:79E*2!["B`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^96UP='E&;VQD97(H)'!A=&@@
M+B`G+R<@+B`D;F%M92D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&QI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D<&%T:"`N("<O)R`N("1N
M86UE*3L*("`@("`@("`@("`@:68@*&ES7V$H)&QI<W0L("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H8V]U;G0H)&QI<W0I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(E5N
M86)L92!T;R!D96QE=&4@)7,L('1H92!D:7)E8W1O<GD@:7,@;F]T(&5M<'1Y
M(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P871H("X@)R\G("X@)&YA;64I*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M/E]D8BT^9V5T
M06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?:60L('9F<U]O=VYE<BP@=F9S7W!E
M<FUS($923TT@)7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!3D0@
M=F9S7VYA;64](#\@04Y$('9F<U]T>7!E(#T@/R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1P871H+"`D;F%M92P@5D937T9/3$1%
M4BDI.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6QE3&ES="D@?'P@8V]U
M;G0H)&9I;&5,:7-T*2`\(#$I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y
M+B(I*3L*("`@("`@("!]"@H@("`@("`@("\J(%1H97)E(&UA>2!B92!O;F4@
M;W(@;6]R92!F;VQD97)S('=I=&@@=&AE('-A;64@;F%M92!B=70@87,@=&AE
M('5S97(*("`@("`@("`@*B!M87D@;F]T(&AA=F4@<F5A9"!A8V-E<W,@=&\@
M=&AE;2P@=&AE>2!D;VXG="!S964@=&AE;2X@4V\@=V4@:&%V92!T;PH@("`@
M("`@("`J(&1E;&5T92!T:&4@;VYE('1H97D@:&%V92!A8V-E<W,@=&\@*B\*
M("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&9I;&4I('L*("`@("`@
M("`@("`@:68@*"1F:6QE6S%=(#T]("1T:&ES+3Y?<&%R86US6R=U<V5R)UT@
M?'P@)&9I;&5;,ET@)B!61E-?1DQ!1U]74DE412D@>PH@("`@("`@("`@("`@
M("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H)T1%3$54
M12!&4D]-("5S(%=(15)%('9F<U]I9"`](#\G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1F:6QE6S!=*2D["@H@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I(#T](#`I('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")5;F%B;&4@=&\@9&5L971E(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!&25A-13H@)T%C
M8V5S<R!$96YI960@9&5L971I;F<@9F]L9&5R("5S+R5S)PH@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93
M(&1I<F5C=&]R>2XB*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M82!L:7-T(&]F('1H92!C;VYT96YT<R!O9B!A(&9O;&1E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@(%1H92!P871H(&]F('1H
M92!D:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@
M(%-T<FEN9R]H87-H('1O(&9I;'1E<B!F:6QE+V1I<FYA;64@;VXN"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@;VYL>2!D:7)E
M8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&:6QE(&QI
M<W0@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;&ES=$9O;&1E<B@D<&%T:"P@)&9I;'1E<B`](&YU;&PL
M("1D;W1F:6QE<R`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("`@("1D
M:7)O;FQY(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("`D;&5N9W1H7V]P(#T@)'1H:7,M/E]G971&:6QE4VEZ94]P*"D[
M"B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M/E]D8BT^9V5T06QL*'-P<FEN
M=&8H)U-%3$5#5"!V9G-?;F%M92P@=F9S7W1Y<&4L('9F<U]M;V1I9FEE9"P@
M=F9S7V]W;F5R+"!V9G-?<&5R;7,L("5S*'9F<U]D871A*2!&4D]-("5S"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M5TA%4D4@=F9S7W!A=&@@/2`_($%.1"`H=F9S7V]W;F5R(#T@/R!O<B!V9G-?
M<&5R;7,@)B8@/RDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1L96YG=&A?;W`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D<&%T:"P@)'1H:7,M/E]P87)A;7-;)W5S97(G72P@5D93
M7T9,04=?4D5!1"DI.PH@("`@("`@(&EF("AI<U]A*"1F:6QE3&ES="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5,:7-T.PH@
M("`@("`@('T*"B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*("`@("`@("!F
M;W)E86-H("@D9FEL94QI<W0@87,@)&QI;F4I('L*("`@("`@("`@("`@+R\@
M1FEL=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R96XG="!W86YT960N"B`@
M("`@("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U8G-T<B@D;&EN95LP72P@
M,"P@,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@)&9I;&5;)VYA;64G72`]('-T<FEP
M<VQA<VAE<R@D;&EN95LP72D["@H@("`@("`@("`@("!I9B`H)&QI;F5;,5T@
M/3T@5D937T9)3$4I('L*("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D
M92@G+B<L("1L:6YE6S!=*3L*"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)&YA;64I(#T](#$I('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP
M92==(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2!61E,Z.G-T<G1O;&]W
M97(H)&YA;65;8V]U;G0H)&YA;64I("T@,5TI.PH@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`D;&EN95LU73L*
M("`@("`@("`@("`@?2!E;'-E:68@*"1L:6YE6S%=(#T](%9&4U]&3TQ$15(I
M('L*("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G.PH@
M("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("TQ.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D9FEL95LG9&%T92==(#T@)&QI;F5;,ET["B`@
M("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&QI;F5;,UT["@H@("`@("`@
M("`@("`D;&EN95LT72`](&EN='9A;"@D;&EN95LT72D["B`@("`@("`@("`@
M("1F:6QE6R=P97)M<R==("`]("@D;&EN95LQ72`]/2!61E-?1D],1$52*2`_
M("=D)R`Z("<M)SL*("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@+CT@)W)W
M+2<["B`@("`@("`@("`@("1F:6QE6R=P97)M<R==("X]("@D;&EN95LT72`F
M(%9&4U]&3$%'7U)%040I(#\@)W(G(#H@)RTG.PH@("`@("`@("`@("`D9FEL
M95LG<&5R;7,G72`N/2`H)&QI;F5;-%T@)B!61E-?1DQ!1U]74DE412D@/R`G
M=R<@.B`G+2<["B`@("`@("`@("`@("1F:6QE6R=P97)M<R==("X]("<M)SL*
M("`@("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2`G)SL*"B`@("`@("`@("`@
M("\O(&9I;'1E<FEN9PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]F:6QT97)-
M871C:"@D9FEL=&5R+"`D9FEL95LG;F%M92==*2D@>PH@("`@("`@("`@("`@
M("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D:7)O;FQY("8F("1F:6QE
M6R=T>7!E)UT@(3T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@('5N<V5T
M*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D9FEL97-;)&9I;&5;)VYA;64G75T@/2`D9FEL
M93L*("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1F:6QE<SL*("`@('T*"B`@("`O*BH*("`@("`J($-H86YG
M97,@<&5R;6ES<VEO;G,@9F]R(&%N($ET96T@;VX@=&AE(%9&4RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!(;VQD<R!T:&4@<&%T:"!O
M9B!D:7)E8W1O<GD@;V8@=&AE($ET96TN"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!(;VQD<R!T:&4@;F%M92!O9B!T:&4@271E;2X*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%2
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C:&%N9V5097)M:7-S:6]N<R@D<&%T:"P@)&YA;64L("1P97)M:7-S:6]N
M*0H@("`@>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O;FXI*2!["B`@("`@("`@("`@
M(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1V86P@/2!I;G1V
M86PH<W5B<W1R*"1P97)M:7-S:6]N+"`M,2DI.PH@("`@("`@("1P97)M(#T@
M,#L*("`@("`@("`D<&5R;2!\/2`H)'9A;"`F(#0I(#\@5D937T9,04=?4D5!
M1"`Z(#`["B`@("`@("`@)'!E<FT@?#T@*"1V86P@)B`R*2`_(%9&4U]&3$%'
M7U=2251%(#H@,#L*"B`@("`@("`@)&9I;&5,:7-T(#T@)'1H:7,M/E]D8BT^
M9V5T06QL*'-P<FEN=&8H)U-%3$5#5"!V9G-?:60L('9F<U]O=VYE<BP@=F9S
M7W!E<FUS($923TT@)7,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%=(15)%('9F<U]P871H(#T@/R!!
M3D0@=F9S7VYA;64](#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@D<&%T:"P@)&YA;64I*3L*"B`@("`@("`@:68@*"%I<U]A<G)A
M>2@D9FEL94QI<W0I('Q\(&-O=6YT*"1F:6QE3&ES="D@/"`Q*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@+RH@5&AE
M<F4@;6%Y(&)E(&]N92!O<B!M;W)E(&9I;&5S('=I=&@@=&AE('-A;64@;F%M
M92!B=70@=&AE('5S97(@;6%Y"B`@("`@("`@("H@;F]T(&AA=F4@<F5A9"!A
M8V-E<W,@=&\@=&AE;2P@<V\@9&]E<VXG="!S964@=&AE;2X@4V\@=V4@:&%V
M92!T;PH@("`@("`@("`J(&-H;6]D('1H92!O;F4@=&AE>2!H879E(&%C8V5S
M<R!T;RX@*B\*("`@("`@("!F;W)E86-H("@D9FEL94QI<W0@87,@)&9I;&4I
M('L*("`@("`@("`@("`@:68@*"1F:6QE6S%=(#T]("1T:&ES+3Y?<&%R86US
M6R=U<V5R)UT@?'P@)&9I;&5;,ET@)B!61E-?1DQ!1U]74DE412D@>PH@("`@
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN
M=&8H)U501$%412`E<R!3150@=F9S7W!E<FUS(#T@/PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@
M=F9S7VED(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)'!E<FTL("1F:6QE6S!=*2D["B`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@
M8VAA;F=E('!E<FUI<W-I;VX@9F]R(%9&4R!F:6QE("5S+R5S+B(I+"`D<&%T
M:"P@)&YA;64I*3L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U9&4R]F='`N<&AP````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#<U,C,T(#$P-3$U-#,T
M,3,V(#`R,#(U-@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5D93(&EM<&QE;65N=&%T:6]N(&9O<B!A
M;B!&5%`@<V5R=F5R+@H@*@H@*B!297%U:7)E9"!V86QU97,@9F]R("1P87)A
M;7,Z/'!R93X*("H@("`@("`G=7-E<FYA;64G("`@("`@(%1H92!U<V5R;F%M
M92!W:71H('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&9T<"!S97)V97(N"B`J
M("`@("`@)W!A<W-W;W)D)R`@("`@("!4:&4@<&%S<W=O<F0@=VET:"!W:&EC
M:"!T;R!C;VYN96-T('1O('1H92!F='`@<V5R=F5R+@H@*B`@("`@("=H;W-T
M<W!E8R<@("`@("`@5&AE(&9T<"!S97)V97(@=&\@8V]N;F5C="!T;RX\+W!R
M93X*("H*("H@3W!T:6]N86P@=F%L=65S(&9O<B`D<&%R86US.CQP<F4^"B`J
M("`@("`@)VUA<&QO8V%L:61S)R`@("!)9B!T<G5E(&%N9"!T:&4@4$]325@@
M97AT96YS:6]N(&ES(&%V86EL86)L92P@=&AE"B`J("`@("`@("`@("`@("`@
M("`@("`@("!D<FEV97(@=VEL;"!M87`@=&AE('5S97(@86YD(&=R;W5P($E$
M<R!R971U<FYE9"!F<F]M"B`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M1E10('-E<G9E<B!W:71H('1H92!L;V-A;"!)1',@9G)O;2!T:&4@;&]C86P*
M("H@("`@("`@("`@("`@("`@("`@("`@('!A<W-W;W)D(&9I;&4N("!4:&ES
M(&ES('5S969U;"!O;FQY(&EF('1H92!&5%`@<V5R=F5R"B`J("`@("`@("`@
M("`@("`@("`@("`@("!I<R!R=6YN:6YG(&]N(&QO8V%L:&]S="!O<B!I9B!T
M:&4@;&]C86P@=7-E<B]G<F]U<`H@*B`@("`@("`@("`@("`@("`@("`@("`@
M241S(&%R92!I9&5N=&EC86P@=&\@=&AE(')E;6]T92!&5%`@<V5R=F5R+@H@
M*B`@("`@("=P87-V)R`@("`@("`@("`@268@=')U92P@8V]N;F5C=&EO;B!W
M:6QL(&)E('-E="!T;R!P87-S:79E(&UO9&4N"B`J("`@("`@)W!O<G0G("`@
M("`@("`@("!4:&4@<&]R="!U<V5D('1O(&-O;FYE8W0@=&\@=&AE(&9T<"!S
M97)V97(@:68@;W1H97(*("H@("`@("`@("`@("`@("`@("`@("`@('1H86X@
M,C$N"B`J("`@("`@)W-S;"<@("`@("`@("`@("!)9B!T<G5E+"!A;F0@4$A0
M(&AA9"!B965N(&-O;7!I;&5D('=I=&@@3W!E;E-33`H@*B`@("`@("`@("`@
M("`@("`@("`@("`@<W5P<&]R="P@5$Q3('1R86YS<&]R="UL979E;"!E;F-R
M>7!T:6]N('=I;&P@8F4*("H@("`@("`@("`@("`@("`@("`@("`@(&YE9V]T
M:6%T960@=VET:"!T:&4@<V5R=F5R+@H@*B`@("`@("=T:6UE;W5T)R`@("`@
M("`@268@9&5F:6YE9"P@=7-E('1H:7,@=F%L=64@87,@=&AE('1I;65O=70@
M9F]R('1H90H@*B`@("`@("`@("`@("`@("`@("`@("`@<V5R=F5R+CPO<')E
M/@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E,O5D93+V9T<"YP:'`L=B`Q
M+C<U+C0N,C$@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J
M"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J($-O<'ER:6=H="`R,#`R+3(P,#8@36EC:&%E;"!6
M87)G:&5S92`\;6EK92YV87)G:&5S94!A<V-E;&QA=&5C:"YC;VT^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX*("H@0&%U=&AO<B`@36EC:&%E;"!687)G:&5S92`\;6EK
M92YV87)G:&5S94!A<V-E;&QA=&5C:"YC;VT^"B`J($!P86-K86=E(%9&4PH@
M*B\*8VQA<W,@5D937V9T<"!E>'1E;F1S(%9&4R!["@H@("`@+RHJ"B`@("`@
M*B!,:7-T(&]F(&%D9&ET:6]N86P@8W)E9&5N=&EA;',@<F5Q=6ER960@9F]R
M('1H:7,@5D93(&)A8VME;F0N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]C<F5D96YT:6%L<R`](&%R<F%Y*"=U<V5R;F%M
M92<L("=P87-S=V]R9"<I.PH*("`@("\J*@H@("`@("H@3&ES="!O9B!P97)M
M:7-S:6]N<R!A;F0@:68@=&AE>2!C86X@8F4@8VAA;F=E9"!I;B!T:&ES(%9&
M4R!B86-K96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<&5R;6ES<VEO;G,@/2!A<G)A>2@*("`@("`@("`G;W=N97(G
M(#T^(&%R<F%Y*"=R96%D)R`]/B!T<G5E+"`G=W)I=&4G(#T^('1R=64L("=E
M>&5C=71E)R`]/B!T<G5E*2P*("`@("`@("`G9W)O=7`G(#T^(&%R<F%Y*"=R
M96%D)R`]/B!T<G5E+"`G=W)I=&4G(#T^('1R=64L("=E>&5C=71E)R`]/B!T
M<G5E*2P*("`@("`@("`G86QL)R`@(#T^(&%R<F%Y*"=R96%D)R`]/B!T<G5E
M+"`G=W)I=&4G(#T^('1R=64L("=E>&5C=71E)R`]/B!T<G5E*2D["@H@("`@
M+RHJ"B`@("`@*B!687)I86)L92!H;VQD:6YG('1H92!C;VYN96-T:6]N('1O
M('1H92!F='`@<V5R=F5R+@H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J+PH@("`@=F%R("1?<W1R96%M(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!,;V-A;"!C86-H92!A<G)A>2!F;W(@=7-E<B!)1',N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]U:61S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("`J($QO8V%L(&-A8VAE(&%R<F%Y(&9O<B!G
M<F]U<"!)1',N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]G:61S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE('-I>F4@;V8@82!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&@@;V8@=&AE(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R
M("!4:&4@<VEZ92!O9B!T:&4@9FEL92!I;B!B>71E<R!O<B!014%27T5R<F]R
M(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-I>F4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@
M("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H
M)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C
M;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D<VEZ92`]($!F='!?<VEZ
M92@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DI*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAE8VL@9FEL92!S:7IE
M(&]F(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M92DI
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<VEZ93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E=')I979E<R!A(&9I;&4@9G)O;2!T:&4@5D93+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M
M92!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H
M92!F:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5A9"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI
M<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@
M?0H*("`@("`@("`D=&UP1FEL92`]("1T:&ES+3Y?9V5T5&5M<$9I;&4H*3L*
M("`@("`@("`D9F5T8V@@/2!`9G1P7V=E="@D=&AI<RT^7W-T<F5A;2P@)'1M
M<$9I;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92DL($944%]"24Y!4EDI.PH@("`@("`@(&EF("@D
M9F5T8V@@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4@
M7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@
M("`@("`@('T*"B`@("`@("`@)'-I>F4@/2!F:6QE<VEZ92@D=&UP1FEL92D[
M"B`@("`@("`@:68@*"1S:7IE(#T]/2`P*2!["B`@("`@("`@("`@(')E='5R
M;B`G)SL*("`@("`@("!]"@H@("`@("`@(&EF("A/4U]724Y$3U=3*2!["B`@
M("`@("`@("`@("1M;V1E(#T@)W)B)SL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D;6]D92`]("=R)SL*("`@("`@("!]"@H@("`@("`@(&EF("AF
M=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L*("`@("`@
M("`@("`@)&1A=&$@/2!F:6QE7V=E=%]C;VYT96YT<R@D=&UP1FEL92D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9P(#T@9F]P96XH)'1M<$9I
M;&4L("1M;V1E*3L*("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L("1S
M:7IE*3L*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H@("`@
M("`@('5N;&EN:R@D=&UP1FEL92D["@H@("`@("`@(')E='5R;B`D9&%T83L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@=&AE(%9&
M4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@
M5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("`@("`@("`@5&AE(&9I;&5N86UE('1O('5S92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'1M<$9I;&4@("`@("!4:&4@=&5M<&]R87)Y
M(&9I;&4@8V]N=&%I;FEN9R!T:&4@9&%T82!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)E('-T;W)E9"X*("`@("`J($!P87)A;2!B
M;V]L96%N("1A=71O8W)E871E("!!=71O;6%T:6-A;&QY(&-R96%T92!D:7)E
M8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!W<FET92@D<&%T:"P@)&YA;64L("1T;7!&
M:6QE+"`D875T;V-R96%T92`](&9A;'-E*0H@("`@>PH@("`@("`@("1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@
M("`@("`@('T*"B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T85=R
M:71E*"=F:6QE)RP@)'1M<$9I;&4I.PH@("`@("`@(&EF("AI<U]A*"1R97,L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(4!F='!?<'5T*"1T:&ES+3Y?<W1R96%M
M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2P@)'1M<$9I;&4L($94
M4%]"24Y!4EDI*2!["B`@("`@("`@("`@(&EF("@D875T;V-R96%T92D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E4&%T
M:"@D<&%T:"D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M(4!F='!?<'5T*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A
M=&@L("1N86UE*2P@)'1M<$9I;&4L($944%]"24Y!4EDI*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^
M7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@=W)I=&4@5D93
M(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-T;W)E<R!A(&9I;&4@:6X@
M=&AE(%9&4R!F<F]M(')A=R!D871A+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'!A=&@@("`@("`@("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL
M92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@
M9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@
M("`@("`@(%1H92!F:6QE(&1A=&$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S
M(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@=W)I=&5$871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A
M=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES
M+3Y?8VAE8VM1=6]T85=R:71E*"=S=')I;F<G+"`D9&%T82D["B`@("`@("`@
M:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1T;7!&:6QE(#T@)'1H
M:7,M/E]G971496UP1FEL92@I.PH@("`@("`@("1F<"`](&9O<&5N*"1T;7!&
M:6QE+"`G=V(G*3L*("`@("`@("!F=W)I=&4H)&9P+"`D9&%T82D["B`@("`@
M("`@9F-L;W-E*"1F<"D["@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^=W)I
M=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4I.PH@("`@
M("`@('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@9FEL92!F<F]M('1H
M92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE
M('!A=&@@=&\@9&5L971E('1H92!F:6QE(&9R;VTN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@9&5L971E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E;&5T949I;&4H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1R
M97,@/2`D=&AI<RT^7V-H96-K475O=&%$96QE=&4H)'!A=&@L("1N86UE*3L*
M("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@)&-O;FX@
M/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(4!F='!?9&5L971E*"1T:&ES+3Y?<W1R
M96%M+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B
M;&4@=&\@9&5L971E(%9&4R!F:6QE(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&$@9VEV
M96X@:71E;2!I<R!A(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%R96YT(&9O;&1E<BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!I=&5M(&YA;64N"B`@("`@*@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&EF(&ET(&ES(&$@9F]L9&5R+"!F86QS92!O
M=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES1F]L9&5R*"1P871H
M+"`D;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C
M="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@
M("1R97-U;'0@/2!F86QS93L*("`@("`@("`D;VQD9&ER(#T@)'1H:7,M/F=E
M=$-U<G)E;G1$:7)E8W1O<GDH*3L*"B`@("`@("`@+RH@4V5E(&EF('=E(&-A
M;B!C:&%N9V4@=&\@=&AE(&=I=F5N('!A=&@N("HO"B`@("`@("`@:68@*$!F
M='!?8VAD:7(H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T:"@D<&%T
M:"P@)&YA;64I*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@=')U93L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?<V5T4&%T:"@D;VQD9&ER*3L*"B`@
M("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M96QE=&5S(&$@9F]L9&5R(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@<&%R96YT(&9O;&1E<BX*
M("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@(%1H92!N86UE(&]F
M('1H92!F;VQD97(@=&\@9&5L971E+@H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)')E8W5R<VEV92`@1F]R8V4@82!R96-U<G-I=F4@9&5L971E/PH@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&1E;&5T949O;&1E<B@D<&%T:"P@)&YA;64L("1R96-U<G-I=F4@/2!F
M86QS92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I
M.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1I
M<T1I<B`](&9A;'-E.PH@("`@("`@("1D:7)#:&5C:R`]("1T:&ES+3YL:7-T
M1F]L9&5R*"1P871H*3L*("`@("`@("!F;W)E86-H("@D9&ER0VAE8VL@87,@
M)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA
M;64@)B8@)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G*2!["B`@("`@("`@("`@
M("`@("`D:7-$:7(@/2!T<G5E.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D:7-$:7(I('L*
M("`@("`@("`@("`@)&9I;&5?;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1T
M:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*3L*("`@("`@("`@("`@:68@
M*&ES7V$H)&9I;&5?;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1F:6QE7VQI<W0["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("AC;W5N="@D9FEL95]L:7-T*2`F)B`A)')E8W5R<VEV92D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R
M:6YT9BA?*")5;F%B;&4@=&\@9&5L971E(%PB)7-<(BP@=&AE(&1I<F5C=&]R
M>2!I<R!N;W0@96UP='DN(BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@(&EF("@D
M9FEL95LG='EP92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F1E;&5T949O;&1E<B@D=&AI<RT^7V=E=%!A
M=&@H)'!A=&@L("1N86UE*2P@)&9I;&5;)VYA;64G72P@)')E8W5R<VEV92D[
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^9&5L971E1FEL92@D=&AI<RT^7V=E=%!A=&@H
M)'!A=&@L("1N86UE*2P@)&9I;&5;)VYA;64G72D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M(&EF("@A0&9T<%]R;61I<B@D=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]G9710
M871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-A;FYO="!R96UO=F4@9&ER
M96-T;W)Y(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92DI*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(&EF("@A0&9T<%]D96QE=&4H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?
M9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86YN;W0@9&5L971E
M(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE
M*2DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M97,@82!F:6QE(&EN
M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;VQD<&%T
M:"`@5&AE(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J($!P87)A
M;2!S=')I;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@9FEL92X*
M("`@("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@9FEL96YA
M;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M92P@)&YE
M=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1C;VYN
M(#T@)'1H:7,M/E]C;VYN96-T*"DL("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M7V$H)')E<W5L="`]("1T:&ES+3YA=71O8W)E871E4&%T:"@D;F5W<&%T:"DL
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!F='!?<F5N86UE*"1T:&ES+3Y?
M<W1R96%M+"`D=&AI<RT^7V=E=%!A=&@H)&]L9'!A=&@L("1O;&1N86UE*2P@
M)'1H:7,M/E]G9710871H*"1N97=P871H+"`D;F5W;F%M92DI*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA
M8FQE('1O(')E;F%M92!61E,@9FEL92!<(B5S7"(N(BDL("1T:&ES+3Y?9V5T
M4&%T:"@D;VQD<&%T:"P@)&]L9&YA;64I*2D["B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!F;VQD97(@;VX@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%R96YT(&9O;&1E<BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!N97<@9F]L9&5R+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A
M(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-R96%T949O;&1E<B@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@
M("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?
M82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-O;FX["B`@("`@("`@?0H*("`@("`@("!I9B`H(4!F='!?;6MD:7(H)'1H
M:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D@
M>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F
M*%\H(E5N86)L92!T;R!C<F5A=&4@5D93(&1I<F5C=&]R>2!<(B5S7"(N(BDL
M("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@)&YA;64I*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-H
M86YG97,@<&5R;6ES<VEO;G,@9F]R(&%N(&ET96T@;VX@=&AE(%9&4RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("!4:&4@<&%R
M96YT(&9O;&1E<B!O9B!T:&4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@
M)&YA;64@("`@("`@(%1H92!N86UE(&]F('1H92!I=&5M+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&5R;6ES<VEO;B`@5&AE('!E<FUI<W-I;VX@=&\@<V5T
M+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-H86YG95!E<FUI<W-I;VYS*"1P871H+"`D;F%M92P@
M)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O
M;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(4!F='!?<VET92@D=&AI<RT^7W-T<F5A;2P@)T-(34]$("<@
M+B`D<&5R;6ES<VEO;B`N("<@)R`N("1T:&ES+3Y?9V5T4&%T:"@D<&%T:"P@
M)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@
M5D93(&9I;&4@7"(E<UPB+B(I+"`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N
M86UE*2DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%N('5N<V]R=&5D(&9I;&4@
M;&ES="!O9B!T:&4@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@(%1H92!P871H(&]F('1H92!D
M:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@(%-T
M<FEN9R]H87-H('1O(&9I;'1E<B!F:6QE+V1I<FYA;64@;VXN"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@;VYL>2!D:7)E8W1O
M<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!&:6QE(&QI<W0@
M;VX@<W5C8V5S<R!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]L:7-T1F]L9&5R*"1P871H(#T@)R<L("1F:6QT97(@
M/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D8V]N;B`]
M("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@
M("`@("!]"@H@("`@("`@("1F:6QE<R`](&%R<F%Y*"D["B`@("`@("`@)'1Y
M<&4@/2!61E,Z.G-T<G1O;&]W97(H0&9T<%]S>7-T>7!E*"1T:&ES+3Y?<W1R
M96%M*2D["B`@("`@("`@:68@*"1T>7!E(#T]("=U;FMN;W=N)RD@>PH@("`@
M("`@("`@("`O+R!';R!W:71H('5N:7@M<W1Y;&4@;&ES=&EN9W,@8GD@9&5F
M875L="X*("`@("`@("`@("`@)'1Y<&4@/2`G=6YI>"<["B`@("`@("`@?2!E
M;'-E:68@*'-T<G!O<R@D='EP92P@)W=I;B<I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D='EP92`]("=W:6XG.PH@("`@("`@('T@96QS96EF("AS=')P
M;W,H)'1Y<&4L("=N971W87)E)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("1T>7!E(#T@)VYE='=A<F4G.PH@("`@("`@('T*"B`@("`@("`@)&]L9&1I
M<B`]("1T:&ES+3YG971#=7)R96YT1&ER96-T;W)Y*"D["B`@("`@("`@:68@
M*"%E;7!T>2@D<&%T:"DI('L*("`@("`@("`@("`@)')E<R`]("1T:&ES+3Y?
M<V5T4&%T:"@D<&%T:"D["B`@("`@("`@("`@(&EF("AI<U]A*"1R97,L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1Y<&4@/3T@
M)W5N:7@G*2!["B`@("`@("`@("`@("\O($EF('=E(&1O;B=T('=A;G0@9&]T
M9FEL97,L(%=E(&-A;B!S879E('=O<FL@:&5R92!B>2!N;W0*("`@("`@("`@
M("`@+R\@9&]I;F<@86X@;',@+6$@86YD('1H96X@;F]T(&1O:6YG('1H92!C
M:&5C:R!L871E<B`H8GD*("`@("`@("`@("`@+R\@<V5T=&EN9R`D9&]T9FEL
M97,@=&\@=')U92P@=&AE(&EF(&ES('-H;W)T+6-I<F-U:71E9"DN"B`@("`@
M("`@("`@(&EF("@D9&]T9FEL97,I('L*("`@("`@("`@("`@("`@("1L:7-T
M(#T@9G1P7W)A=VQI<W0H)'1H:7,M/E]S=')E86TL("<M86PG*3L*("`@("`@
M("`@("`@("`@("1D;W1F:6QE<R`]('1R=64["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;&ES="`](&9T<%]R87=L:7-T*"1T:&ES
M+3Y?<W1R96%M+"`G+6PG*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@)&QI<W0@/2!F='!?<F%W;&ES="@D=&AI<RT^7W-T
M<F5A;2P@)R<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<U]A<G)A>2@D
M;&ES="DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O;&1D:7(I*2!["B`@
M("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]S9710871H*"1O;&1D:7(I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!A
M<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@)VUA<&QO8V%L:61S
M)R!I<R!S970L(&-H96-K(&9O<B!T:&4@4$]325@@97AT96YS:6]N+B`J+PH@
M("`@("`@("1M87!I9',@/2!F86QS93L*("`@("`@("!I9B`H(65M<'1Y*"1T
M:&ES+3Y?<&%R86US6R=M87!L;V-A;&ED<R==*2`F)@H@("`@("`@("`@("!E
M>'1E;G-I;VY?;&]A9&5D*"=P;W-I>"<I*2!["B`@("`@("`@("`@("1M87!I
M9',@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@)&-U<G)T:6UE(#T@=&EM
M92@I.PH*("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D;&EN92D@>PH@("`@
M("`@("`@("`D9FEL92`](&%R<F%Y*"D["B`@("`@("`@("`@("1I=&5M(#T@
M<')E9U]S<&QI="@G+UQS*R\G+"`D;&EN92D["B`@("`@("`@("`@(&EF("@D
M='EP92`]/2`G=6YI>"<@?'P@*"1T>7!E(#T]("=W:6XG("8F("%P<F5G7VUA
M=&-H*"=\7&1<9"U<9%QD+5QD7&1\)RP@)&ET96U;,%TI*2D@>PH@("`@("`@
M("`@("`@("`@:68@*&-O=6YT*"1I=&5M*2`\(#@@?'P@<W5B<W1R*"1L:6YE
M+"`P+"`U*2`]/2`G=&]T86PG*2!["B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9FEL
M95LG<&5R;7,G72`]("1I=&5M6S!=.PH@("`@("`@("`@("`@("`@:68@*"1M
M87!I9',I('L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?=6ED<ULD:71E;5LR75TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1E;G1R>2`]('!O<VEX7V=E='!W=6ED*"1I=&5M6S)=*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U:61S6R1I=&5M6S)=72`]("AE;7!T
M>2@D96YT<GDI*2`_("1I=&5M6S)=(#H@)&5N=')Y6R=N86UE)UT["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1F:6QE6R=O
M=VYE<B==(#T@)'1H:7,M/E]U:61S6R1I=&5M6S)=73L*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=6ED<ULD:71E;5LS75TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E;G1R>2`]('!O<VEX7V=E=&=R
M9VED*"1I=&5M6S-=*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]U:61S6R1I=&5M6S-=72`]("AE;7!T>2@D96YT<GDI*2`_("1I=&5M6S-=
M(#H@)&5N=')Y6R=N86UE)UT["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("1F:6QE6R=G<F]U<"==(#T@)'1H:7,M/E]U:61S
M6R1I=&5M6S-=73L*"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&ET96U;,ET["B`@("`@
M("`@("`@("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2`D:71E;5LS73L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1F:6QE6R=N86UE)UT@
M/2!S=6)S='(H)&QI;F4L('-T<G!O<R@D;&EN92P@<W!R:6YT9B@B)7,@)3)S
M("4U<R(L("1I=&5M6S5=+"`D:71E;5LV72P@)&ET96U;-UTI*2`K(#$S*3L*
M"B`@("`@("`@("`@("`@("`O+R!&:6QT97(@;W5T("<N)R!A;F0@)RXN)R!E
M;G1R:65S+@H@("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7"Y<
M+C]<+S\D+R<L("1F:6QE6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@+R\@1FEL=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R96XG="!W86YT
M960N"B`@("`@("`@("`@("`@("!I9B`H(21D;W1F:6QE<R`F)B!S=6)S='(H
M)&9I;&5;)VYA;64G72P@,"P@,2D@/3T@)RXG*2!["B`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)'`Q(#T@<W5B<W1R*"1F:6QE6R=P97)M<R==+"`P+"`Q*3L*("`@
M("`@("`@("`@("`@(&EF("@D<#$@/3T]("=L)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=L:6YK)UT@/2!S=6)S='(H)&9I;&5;)VYA;64G72P@
M<W1R<&]S*"1F:6QE6R=N86UE)UTL("<M/B<I("L@,RD["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)VYA;64G72`]('-U8G-T<B@D9FEL95LG;F%M92==
M+"`P+"!S=')P;W,H)&9I;&5;)VYA;64G72P@)RT^)RD@+2`Q*3L*("`@("`@
M("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ<WEM)SL*"B`@("`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/FES1F]L9&5R*"<G+"`D9FEL95LG
M;&EN:R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG;&EN:W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A<G1S(#T@97AP;&]D92@G+R<L("1F:6QE6R=L:6YK)UTI.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&YA;64@/2!E>'!L;V1E*"<N)RP@87)R87E?<&]P*"1P87)T<RDI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&-O=6YT*"1N86UE*2`]/2`Q('Q\("@D;F%M95LP72`]/3T@
M)R<@)B8@8V]U;G0H)&YA;64I(#T](#(I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;
M)VQI;FMT>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9FEL95LG;&EN:W1Y<&4G72`](%9&4SHZ<W1R=&]L
M;W=E<BAA<G)A>5]P;W`H)&YA;64I*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1P,2`]/3T@)V0G*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y
M<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@97AP;&]D92@G+B<L("1F:6QE6R=N
M86UE)UTI.PH@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D;F%M92D@
M/3T@,2!\?"`H<W5B<W1R*"1F:6QE6R=N86UE)UTL(#`L(#$I(#T]/2`G+B<@
M)B8@8V]U;G0H)&YA;64I(#T](#(I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG
M='EP92==(#T@5D93.CIS=')T;VQO=V5R*"1N86UE6V-O=6YT*"1N86UE*2`M
M(#%=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5;)W1Y<&4G72`]/2`G*BID:7(G
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("TQ.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M9FEL95LG<VEZ92==(#T@)&ET96U;-%T["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1I=&5M6S==+"`G.B<I("$]/2!F
M86QS92D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=D871E)UT@/2!S
M=')T;W1I;64H)&ET96U;-UT@+B`G.C`P)R`N("1I=&5M6S5=("X@)R`G("X@
M)&ET96U;-ET@+B`G("<@+B!D871E*"=9)RP@)&-U<G)T:6UE*2D["B`@("`@
M("`@("`@("`@("`@("`@+R\@268@=&AE(&9T<"!S97)V97(@<F5P;W)T<R!A
M(&9I;&4@;6]D:69I8V%T:6]N(&1A=&4@;6]R90H@("`@("`@("`@("`@("`@
M("`@("\O(&QE<W,@=&AA;B!O;F4@9&%Y(&EN('1H92!F=71U<F4L(&1O;B=T
M('1R>2!T;R!S=6)T<F%C=`H@("`@("`@("`@("`@("`@("`@("\O(&$@>65A
M<B!F<F]M('1H92!D871E+B`@5&AE<F4@:7,@;F\@=V%Y('1O(&MN;W<L(&9O
M<@H@("`@("`@("`@("`@("`@("`@("\O(&5X86UP;&4L(&EF('1H92!61E,@
M<V5R=F5R(&%N9"!T:&4@9G1P('-E<G9E<B!R97-I9&4*("`@("`@("`@("`@
M("`@("`@("`O+R!I;B!D:69F97)E;G0@=&EM97IO;F5S+B`@5V4@<VAO=6QD
M('-I;7!L>2!R97!O<G0@=&\@=&AE"B`@("`@("`@("`@("`@("`@("`@+R\@
M('5S97(@=VAA="!T:&4@1E10('-E<G9E<B!I<R!R971U<FYI;F<N"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1F:6QE6R=D871E)UT@/B`H)&-U<G)T:6UE
M("L@.#8T,#`I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE6R=D
M871E)UT@/2!S=')T;W1I;64H)&ET96U;-UT@+B`G.C`P)R`N("1I=&5M6S5=
M("X@)R`G("X@)&ET96U;-ET@+B`G("<@+B`H9&%T92@G62<L("1C=7)R=&EM
M92D@+2`Q*2D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG9&%T92==
M(#T@<W1R=&]T:6UE*"<P,#HP,#HP,"<@+B`D:71E;5LU72`N("<@)R`N("1I
M=&5M6S9=("X@)R`G("X@)&ET96U;-UTI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)VYE='=A<F4G*2!["B`@
M("`@("`@("`@("`@("`D9FEL92`]($%R<F%Y*"D["B`@("`@("`@("`@("`@
M("`D9FEL95LG<&5R;7,G72`]("1I=&5M6S%=.PH@("`@("`@("`@("`@("`@
M)&9I;&5;)V]W;F5R)UT@/2`D:71E;5LR73L*("`@("`@("`@("`@("`@(&EF
M("@D:71E;5LP72`]/2`G9"<I('L*("`@("`@("`@("`@("`@("`@("`D9FEL
M95LG='EP92==(#T@)RHJ9&ER)SL*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9I;&5;)W-I
M>F4G72`]("1I=&5M6S-=.PH@("`@("`@("`@("`@("`@)&9I;&5;)VYA;64G
M72`]("1I=&5M6S==.PH@("`@("`@("`@("`@("`@)&EN9&5X(#T@.#L*("`@
M("`@("`@("`@("`@('=H:6QE("@D:6YD97@@/"!C;W5N="@D:71E;2DI('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==("X]("<@)R`N("1I
M=&5M6R1I;F1E>%T["B`@("`@("`@("`@("`@("`@("`@)&EN9&5X*RL["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`O*B!(86YD;&4@5VEN9&]W<R!&5%`@<V5R=F5R<R!R971U<FYI
M;F<@1$]3+7-T>6QE(&9I;&4*("`@("`@("`@("`@("`@("`J(&QI<W1I;F=S
M+B`J+PH@("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G)SL*("`@
M("`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)R<["B`@("`@("`@("`@
M("`@("`D9FEL95LG9W)O=7`G72`]("<G.PH@("`@("`@("`@("`@("`@)&9I
M;&5;)VYA;64G72`]("1I=&5M6S-=.PH@("`@("`@("`@("`@("`@)&EN9&5X
M(#T@-#L*("`@("`@("`@("`@("`@('=H:6QE("@D:6YD97@@/"!C;W5N="@D
M:71E;2DI('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG;F%M92==("X]
M("<@)R`N("1I=&5M6R1I;F1E>%T["B`@("`@("`@("`@("`@("`@("`@)&EN
M9&5X*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9FEL
M95LG9&%T92==(#T@<W1R=&]T:6UE*"1I=&5M6S!=("X@)R`G("X@)&ET96U;
M,5TI.PH@("`@("`@("`@("`@("`@:68@*"1I=&5M6S)=(#T]("<\1$E2/B<I
M('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER
M)SL*("`@("`@("`@("`@("`@("`@("`D9FEL95LG<VEZ92==(#T@+3$["B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=S:7IE)UT@/2`D:71E;5LR73L*("`@("`@("`@("`@("`@("`@("`D
M;F%M92`](&5X<&QO9&4H)RXG+"`D9FEL95LG;F%M92==*3L*("`@("`@("`@
M("`@("`@("`@("!I9B`H8V]U;G0H)&YA;64I(#T](#$@?'P@*'-U8G-T<B@D
M9FEL95LG;F%M92==+"`P+"`Q*2`]/3T@)RXG("8F(&-O=6YT*"1N86UE*2`]
M/2`R*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG='EP92==
M(#T@)RHJ;F]N92<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`](%9&4SHZ<W1R
M=&]L;W=E<B@D;F%M95MC;W5N="@D;F%M92D@+2`Q72D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O+R!&:6QT97)I;F<N"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F:6QE6R=N86UE)UTI*2!["B`@
M("`@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1I<F]N
M;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ9&ER)RD@>PH@("`@("`@("`@
M("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1F:6QE<ULD9FEL95LG;F%M
M92==72`]("1F:6QE.PH@("`@("`@("`@("!U;G-E="@D9FEL92D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)&]L9&1I<BDI('L*("`@("`@("`@
M("`@)')E<R`]("1T:&ES+3Y?<V5T4&%T:"@D;VQD9&ER*3L*("`@("`@("`@
M("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!S;W)T960@;&ES="!O9B!F;VQD97)S(&EN('1H92!S<&5C:69I
M960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('1O(&=E="!T
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D:7)E8W1O
M<GD@;&ES="!F;W(N"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@
M("`@2&%S:"!O9B!I=&5M<R!T;R!F:6QT97(@8F%S960@;VX@9F]L9&5R;&ES
M="X*("`@("`J($!P87)A;2!B;V]L96%N("1D;W1F;VQD97)S("!);F-L=61E
M(&1O=&9O;&1E<G,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1F]L
M9&5R(&QI<W0@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&QI<W1&;VQD97)S*"1P
M871H(#T@)R<L("1F:6QT97(@/2!N=6QL+"`D9&]T9F]L9&5R<R`]('1R=64I
M"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@
M("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R
M<R`](&%R<F%Y*"D["B`@("`@("`@)&9O;&1E<B`](&%R<F%Y*"D["@H@("`@
M("`@("1F;VQD97),:7-T(#T@)'1H:7,M/FQI<W1&;VQD97(H)'!A=&@L(&YU
M;&PL("1D;W1F;VQD97)S+"!T<G5E*3L*("`@("`@("!I9B`H:7-?82@D9F]L
M9&5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&9O;&1E<DQI<W0["B`@("`@("`@?0H*("`@("`@("`D9F]L9&5R6R=V86PG
M72`]("1T:&ES+3Y?<&%R96YT1&ER*"1P871H*3L*("`@("`@("`D9F]L9&5R
M6R=A8F)R978G72`]("<N+B<["B`@("`@("`@)&9O;&1E<ELG;&%B96PG72`]
M("<N+B<["@H@("`@("`@("1F;VQD97)S6R1F;VQD97);)W9A;"==72`]("1F
M;VQD97(["@H@("`@("`@(&9O<F5A8V@@*"1F;VQD97),:7-T(&%S("1F:6QE
M<RD@>PH@("`@("`@("`@("`D9F]L9&5R6R=V86PG72`]("1T:&ES+3Y?9V5T
M4&%T:"@D<&%T:"P@)&9I;&5S6R=N86UE)UTI.PH@("`@("`@("`@("`D9F]L
M9&5R6R=A8F)R978G72`]("1F:6QE<ULG;F%M92==.PH@("`@("`@("`@("`D
M9F]L9&5R6R=L86)E;"==(#T@)&9O;&1E<ELG=F%L)UT["@H@("`@("`@("`@
M("`D9F]L9&5R<ULD9F]L9&5R6R=V86PG75T@/2`D9F]L9&5R.PH@("`@("`@
M('T*"B`@("`@("`@:W-O<G0H)&9O;&1E<G,I.PH@("`@("`@(')E='5R;B`D
M9F]L9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J($-O<&EE<R!A(&9I;&4@
M=&AR;W5G:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:"!O9B!T:&4@;W)I9VEN86P@9FEL92X*("`@
M("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!N86UE(&]F('1H92!O<FEG
M:6YA;"!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D9&5S="`@5&AE(&YA
M;64@;V8@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R>2X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;W!Y*"1P871H+"`D;F%M92P@)&1E<W0I"B`@("!["B`@("`@("`@)&]R:6<@
M/2`D=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*3L*("`@("`@("!I9B`H
M<')E9U]M871C:"@G?%XG("X@<')E9U]Q=6]T92@D;W)I9RD@+B`G+S\D?"<L
M("1D97-T*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")#86YN;W0@8V]P>2!F:6QE*',I("T@<V]U<F-E(&%N9"!D97-T:6YA
M=&EO;B!A<F4@=&AE('-A;64N(BDI.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX[
M"B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K(#T@)'1H:7,M/FQI<W1&
M;VQD97(H)&1E<W0L(&YU;&PL('1R=64I.PH@("`@("`@(&EF("AI<U]A*"1F
M:6QE0VAE8VLL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1F:6QE0VAE8VL["B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1F:6QE
M0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@*"1F:6QE6R=N86UE
M)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B)7,@86QR96%D>2!E>&ES=',N(BDL("1T
M:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1I<T1I<B`](&9A;'-E.PH@("`@("`@("1D
M:7)#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H+"!N=6QL+"!F86QS
M92D["B`@("`@("`@:68@*&ES7V$H)&1I<D-H96-K+"`G4$5!4E]%<G)O<B<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D9&ER0VAE8VL["B`@("`@("`@?0H@
M("`@("`@(&9O<F5A8V@@*"1D:7)#:&5C:R!A<R`D9FEL92D@>PH@("`@("`@
M("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92`F)B`D9FEL95LG='EP
M92==(#T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@("1I<T1I<B`]('1R
M=64["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@:68@*"1I<T1I<BD@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F-R96%T949O;&1E<B@D9&5S="P@)&YA;64I.PH*("`@
M("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES=$9O;&1E<B@D
M=&AI<RT^7V=E=%!A=&@H)'!A=&@L("1N86UE*2D["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^8V]P>2@D=&AI<RT^7V=E=%!A=&@H)'!A=&@L
M("1N86UE*2P@)&9I;&5;)VYA;64G72P@)'1H:7,M/E]G9710871H*"1D97-T
M+"`D;F%M92DI.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1M<$9I;&4@/2`D=&AI<RT^7V=E
M=%1E;7!&:6QE*"D["B`@("`@("`@("`@("1F971C:"`]($!F='!?9V5T*"1T
M:&ES+3Y?<W1R96%M+"`D=&UP1FEL92P@)&]R:6<L($944%]"24Y!4EDI.PH@
M("`@("`@("`@("!I9B`H(21F971C:"D@>PH@("`@("`@("`@("`@("`@=6YL
M:6YK*"1T;7!&:6QE*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*'-P<FEN=&8H7R@B1F%I;&5D('1O(&-O<'D@9G)O;2!<(B5S
M7"(N(BDL("1O<FEG*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF
M("@A0&9T<%]P=70H)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?9V5T4&%T:"@D
M9&5S="P@)&YA;64I+"`D=&UP1FEL92P@1E107T))3D%262DI('L*("`@("`@
M("`@("`@("`@('5N;&EN:R@D=&UP1FEL92D["B`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D9A:6QE9"!T;R!C
M;W!Y('1O(%PB)7-<(BXB*2P@)'1H:7,M/E]G9710871H*"1D97-T+"`D;F%M
M92DI*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=6YL:6YK*"1T;7!&
M:6QE*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@36]V97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@;V8@=&AE(&]R:6=I;F%L(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1N86UE("!4:&4@;F%M92!O9B!T:&4@;W)I9VEN86P@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO;B!F:6QE(&YA
M;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@;6]V92@D<&%T:"P@)&YA;64L("1D97-T*0H@("`@
M>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G9710871H*"1P871H+"`D;F%M
M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N('!R96=?<75O=&4H
M)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&UO=F4@9FEL92AS*2`M(&1E
M<W1I;F%T:6]N(&ES('=I=&AI;B!S;W5R8V4N(BDI.PH@("`@("`@('T*"B`@
M("`@("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H
M:7-?82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D9FEL94-H96-K(#T@)'1H
M:7,M/FQI<W1&;VQD97(H)&1E<W0L(&YU;&PL('1R=64I.PH@("`@("`@(&9O
M<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@("`@("`@:68@
M*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B)7,@86QR96%D>2!E
M>&ES=',N(BDL("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A0&9T<%]R96YA
M;64H)'1H:7,M/E]S=')E86TL("1O<FEG+"`D=&AI<RT^7V=E=%!A=&@H)&1E
M<W0L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")&86EL960@=&\@;6]V92!T;R!<(B5S7"(N(BDL
M("1T:&ES+3Y?9V5T4&%T:"@D9&5S="P@)&YA;64I*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&-U<G)E;G0@=V]R:VEN9R!D:7)E8W1O<GD@;VX@=&AE($94
M4"!S97)V97(N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C
M=7)R96YT('=O<FMI;F<@9&ER96-T;W)Y+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971#=7)R96YT1&ER96-T;W)Y*"D*("`@('L*("`@("`@("!I9B`H:7-?
M82@D8V]N;F5C=&5D(#T@)'1H:7,M/E]C;VYN96-T*"DL("=014%27T5R<F]R
M)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN96-T960["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!F='!?<'=D*"1T:&ES+3Y?<W1R96%M*3L*("`@
M('T*"B`@("`O*BH*("`@("`J($-H86YG97,@=&AE(&-U<G)E;G0@9&ER96-T
M;W)Y(&]N('1H92!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A
M=&@@=&\@8VAA;F=E('1O+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M(%1R=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S9710871H*"1P871H*0H@("`@>PH@
M("`@("`@(&EF("@A0&9T<%]C:&1I<B@D=&AI<RT^7W-T<F5A;2P@)'!A=&@I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B56YA8FQE('1O(&-H86YG92!T;R`E<RXB*2P@)'!A=&@I*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!F=6QL('!A=&@@;V8@86X@:71E;2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@9&ER96-T;W)Y(&]F('1H92!I=&5M+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&YA;64@;V8@=&AE(&ET96TN
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1G5L;"!P871H('1O('1H
M92!F:6QE('=H96X@)'!A=&@@:7,@;F]T(&5M<'1Y(&%N9"!J=7-T"B`@("`@
M*B`@("`@("`@("`@("`@("`D;F%M92!W:&5N(&YO="!S970N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G9710871H*"1P871H+"`D;F%M92D*("`@('L*("`@
M("`@("!I9B`H)'!A=&@@(3T]("<G*2!["B`@("`@("`@("`@(')E='5R;B`H
M)'!A=&@@+B`G+R<@+B`D;F%M92D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`H)&YA;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@
M<&%R96YT(&1I<F5C=&]R>2!O9B!T:&4@<W!E8VEF:65D('!A=&@N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@9V5T('1H92!P87)E;G0@;V8N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!P87)E;G0@9&ER
M96-T;W)Y("AS=')I;F<I(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R"B`@
M("`@*B`@("`@("`@("`@("`@("`@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]P87)E;G1$:7(H)'!A=&@I"B`@("!["B`@("`@
M("`@)&-O;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?
M82@D8V]N;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&-O;FX["B`@("`@("`@?0H*("`@("`@("`D;VQD9&ER(#T@)'1H:7,M/F=E
M=$-U<G)E;G1$:7)E8W1O<GDH*3L*("`@("`@("!`9G1P7V-D=7`H)'1H:7,M
M/E]S=')E86TI.PH*("`@("`@("`D<&%R96YT(#T@)'1H:7,M/F=E=$-U<G)E
M;G1$:7)E8W1O<GDH*3L*("`@("`@("`D=&AI<RT^7W-E=%!A=&@H)&]L9&1I
M<BD["@H@("`@("`@(&EF("@A)'!A<F5N="D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5T97)M:6YE(&-U
M<G)E;G0@9&ER96-T;W)Y+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<&%R96YT.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M;W!E;B!A(&-O;FYE8W1I;VX@=&\@=&AE($944"!S97)V97(N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W-T<F5A;2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=F='`G*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5&AE
M($944"!E>'1E;G-I;VX@:7,@;F]T(&%V86EL86)L92XB*2D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'1H:7,M/E]P87)A
M;7,I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;R!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N('-P96-I9FEE9"!F
M;W(@1E10(%9&4RXB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R
M97%U:7)E9"`](&%R<F%Y*"=H;W-T<W!E8R<L("=U<V5R;F%M92<L("=P87-S
M=V]R9"<I.PH@("`@("`@("`@("!F;W)E86-H("@D<F5Q=6ER960@87,@)'9A
M;"D@>PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A<F%M
M<ULD=F%L72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(E)E<75I<F5D(%PB)7-<(B!N;W0@<W!E
M8VEF:65D(&EN(%9&4R!C;VYF:6=U<F%T:6]N+B(I+"`D=F%L*2D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($-O
M;FYE8W0@=&\@=&AE(&9T<"!S97)V97(@=7-I;F<@=&AE('-U<'!L:65D('!A
M<F%M971E<G,N("HO"B`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]P
M87)A;7-;)W-S;"==*2D@>PH@("`@("`@("`@("`@("`@:68@*&9U;F-T:6]N
M7V5X:7-T<R@G9G1P7W-S;%]C;VYN96-T)RDI('L*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W-T<F5A;2`]($!F='!?<W-L7V-O;FYE8W0H)'1H:7,M
M/E]P87)A;7-;)VAO<W1S<&5C)UTL("1T:&ES+3Y?<&%R86US6R=P;W)T)UTI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8V]N;F5C
M="!W:71H(%-33"XB*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T<F5A;2`]($!F
M='!?8V]N;F5C="@D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G72P@)'1H:7,M
M/E]P87)A;7-;)W!O<G0G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^7W-T<F5A;2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V]N;F5C=&EO;B!T;R!&5%`@<V5R=F5R
M(&9A:6QE9"XB*2D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C;VYN
M96-T960@/2!`9G1P7VQO9VEN*"1T:&ES+3Y?<W1R96%M+"`D=&AI<RT^7W!A
M<F%M<ULG=7-E<FYA;64G72P@)'1H:7,M/E]P87)A;7-;)W!A<W-W;W)D)UTI
M.PH@("`@("`@("`@("!I9B`H(21C;VYN96-T960I('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&ES8V]N;F5C="@I.PH@("`@("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B075T:&5N=&EC871I;VX@=&\@1E10
M('-E<G9E<B!F86EL960N(BDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=P87-V)UTI*2!["B`@("`@
M("`@("`@("`@("!`9G1P7W!A<W8H)'1H:7,M/E]S=')E86TL('1R=64I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M<&%R86US6R=T:6UE;W5T)UTI*2!["B`@("`@("`@("`@("`@("!F='!?<V5T
M7V]P=&EO;B@D=&AI<RT^7W-T<F5A;2P@1E107U1)345/551?4T5#+"`D=&AI
M<RT^7W!A<F%M<ULG=&EM96]U="==*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!$:7-C;VYN96-T<R!F<F]M('1H92!&5%`@<V5R=F5R(&%N9"!C;&5A;G,@
M=7`@=&AE(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*
M("`@("`@("!`9G1P7W%U:70H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("1T
M:&ES+3Y?<W1R96%M(#T@9F%L<V4["B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U9&4R]"<F]W<V5R+G!H<```````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C,V(#$P-3$U-#,T,3,V(#`R,3$P
M-``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@0VQA<W,@9F]R('!R;W9I9&EN9R!A(&=E;F5R:6,@54D@
M9F]R(&%N>2!61E,@:6YS=&%N8V4N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K
M+U9&4R]61E,O0G)O=W-E<BYP:'`L=B`Q+C@N,3`N.2`R,#`V+S`U+S,Q(#`T
M.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/@H@*B!`<&%C:V%G92!61E,*("HO"F-L87-S(%9&4U]"<F]W<V5R
M('L*"B`@("`O*BH*("`@("`J(%1H92!61E,@:6YS=&%N8V4@=&AA="!W92!A
M<F4@8G)O=W-I;F<N"B`@("`@*@H@("`@("H@0'9A<B!61E,*("`@("`J+PH@
M("`@=F%R("1?=F9S.PH*("`@("\J*@H@("`@("H@5&AE(&1I<F5C=&]R>2!W
M:&5R92!T:&4@=&5M<&QA=&5S('1O('5S92!A<F4N"B`@("`@*@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?=&5M<&QA=&5S.PH*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@
M5D93("8D=F9S("`@("`@("`@($$@5D93(&]B:F5C="X*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E;7!L871E<R`@5$]$3PH@("`@("HO"B`@("!F=6YC=&EO
M;B!61E-?0G)O=W-E<B@F)'9F<RP@)'1E;7!L871E<RD*("`@('L*("`@("`@
M("!I9B`H:7-S970H)'9F<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]V9G,@
M/2`D=F9S.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W1E;7!L871E<R`]
M("1T96UP;&%T97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(%9&
M4R!O8FIE8W0@:6X@=&AE(&QO8V%L(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@5D93("8D=F9S("!!(%9&4R!O8FIE8W0N"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=%9&4T]B:F5C="@F)'9F<RD*("`@('L*("`@("`@("`D=&AI
M<RT^7W9F<R`]("8D=F9S.PH@("`@?0H*("`@("\J*@H@("`@("H@5$]$3PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@5$]$3PH@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I;&5S("!43T1/"B`@("`@*B!`
M<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%1/1$\*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T54DH)'!A=&@L("1D;W1F:6QE<R`](&9A;'-E+"`D9&ER;VYL
M>2`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=F9S+3YL:7-T1F]L
M9&5R*"1P871H+"`D9&]T9FEL97,L("1D:7)O;FQY*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+W-Q;%]F:6QE
M+G!H<```````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-S(T-30@,3`U,34T,S0Q,S8@,#(Q,C8T`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@1FEL92!V86QU
M92!F;W(@=F9S7W1Y<&4@8V]L=6UN+@H@*B\*9&5F:6YE*"=61E-?1DE,12<L
M(#$I.PH*+RHJ"B`J($9O;&1E<B!V86QU92!F;W(@=F9S7W1Y<&4@8V]L=6UN
M+@H@*B\*9&5F:6YE*"=61E-?1D],1$52)RP@,BD["@HO*BH*("H@5D93.CH@
M:6UP;&5M96YT871I;VX@=7-I;F<@4$A0)W,@4$5!4B!D871A8F%S92!A8G-T
M<F%C=&EO;@H@*B!L87EE<B!A;F0@;&]C86P@9FEL92!S>7-T96T@9F]R(&9I
M;&4@<W1O<F%G92X*("H*("H@4F5Q=6ER960@=F%L=65S(&9O<B`D<&%R86US
M.CQP<F4^"B`J("`@("`@)W!H<'1Y<&4G("`@("`@(%1H92!D871A8F%S92!T
M>7!E("AI92X@)W!G<W%L)RP@)VUY<W%L)RP@971C+BDN"B`J("`@("`@)W9F
M<W)O;W0G("`@("`@(%1H92!R;V]T(&1I<F5C=&]R>2!O9B!W:&5R92!T:&4@
M9FEL97,@<VAO=6QD(&)E"B`J("`@("`@("`@("`@("`@("`@("`@(&%C='5A
M;&QY('-T;W)E9"X\+W!R93X*("H*("H@3W!T:6]N86P@=F%L=65S.CQP<F4^
M"B`J("`@("`@)W1A8FQE)R`@("`@("`@(%1H92!N86UE(&]F('1H92!V9G,@
M=&%B;&4@:6X@)V1A=&%B87-E)RX@1&5F875L=',@=&\*("H@("`@("`@("`@
M("`@("`@("`@("`@)VAO<F1E7W9F<R<N/"]P<F4^"B`J"B`J(%)E<75I<F5D
M(&)Y('-O;64@9&%T86)A<V4@:6UP;&5M96YT871I;VYS.CQP<F4^"B`J("`@
M("`@)VAO<W1S<&5C)R`@("`@(%1H92!H;W-T;F%M92!O9B!T:&4@9&%T86)A
M<V4@<V5R=F5R+@H@*B`@("`@("=P<F]T;V-O;"<@("`@("!4:&4@8V]M;75N
M:6-A=&EO;B!P<F]T;V-O;"`H)W1C<"<L("=U;FEX)RP@971C+BDN"B`J("`@
M("`@)V1A=&%B87-E)R`@("`@(%1H92!N86UE(&]F('1H92!D871A8F%S92X*
M("H@("`@("`G=7-E<FYA;64G("`@("`@5&AE('5S97)N86UE('=I=&@@=VAI
M8V@@=&\@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4N"B`J("`@("`@)W!A<W-W
M;W)D)R`@("`@(%1H92!P87-S=V]R9"!A<W-O8VEA=&5D('=I=&@@)W5S97)N
M86UE)RX*("H@("`@("`G;W!T:6]N<R<@("`@("`@061D:71I;VYA;"!O<'1I
M;VYS('1O('!A<W,@=&\@=&AE(&1A=&%B87-E+@H@*B`@("`@("=T='DG("`@
M("`@("`@("!4:&4@5%19(&]N('=H:6-H('1O(&-O;FYE8W0@=&\@=&AE(&1A
M=&%B87-E+@H@*B`@("`@("=P;W)T)R`@("`@("`@("!4:&4@<&]R="!O;B!W
M:&EC:"!T;R!C;VYN96-T('1O('1H92!D871A8F%S92X\+W!R93X*("H*("H@
M5&AE('1A8FQE('-T<G5C='5R92!F;W(@=&AE(%9&4R!C86X@8F4@9F]U;F0@
M:6X*("H@9&%T82]V9G,N<W%L+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]6
M1E,O5D93+W-Q;%]F:6QE+G!H<"QV(#$N-#0N-"XR,B`R,#`V+S`U+S,Q(#`T
M.C4P.C`R('-L=7-A<GH@17AP("0*("H*("H@0&%U=&AO<B`@36EC:&%E;"!6
M87)G:&5S92`\;6EK92YV87)G:&5S94!A<V-E;&QA=&5C:"YC;VT^"B`J($!P
M86-K86=E(%9&4PH@*B\*8VQA<W,@5D937W-Q;%]F:6QE(&5X=&5N9',@5D93
M('L*"B`@("`O*BH*("`@("`J($AA;F1L92!F;W(@=&AE(&-U<G)E;G0@9&%T
M86)A<V4@8V]N;F5C=&EO;BX*("`@("`J"B`@("`@*B!`=F%R($1""B`@("`@
M*B\*("`@('9A<B`D7V1B(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!S:7IE(&]F(&$@9FEL92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H
M92!P871H(&]F('1H92!F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M
M92`@5&AE(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE('-I>F4@;V8@=&AE(&9I;&4@:6X@8GET97,@;W(@4$5!4E]%<G)O
M<B!O;@H@("`@("H@("`@("`@("`@("`@("`@("!F86EL=7)E+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S:7IE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@
M("!I9B`H*"1S:7IE(#T@0&9I;&5S:7IE*"1T:&ES+3Y?9V5T3F%T:79E4&%T
M:"@D<&%T:"P@)&YA;64I*2D@/3T](&9A;'-E*7L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")5;F%B;&4@=&\@8VAE
M8VL@9FEL92!S:7IE(&]F(%PB)7,O)7-<(BXB+"`D<&%T:"P@)&YA;64I*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'-I>F4["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971R:65V92!A(&9I;&4@9G)O;2!T:&4@5D93+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H;F%M92!T
M;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F
M:6QE;F%M92!T;R!R971R:65V92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)&-O;FX@/2`D=&AI<RT^
M7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX["B`@("`@("`@?0H*
M("`@("`@("`D9FEL92`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@
M)&YA;64I.PH*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E
M=%]C;VYT96YT<R<I*2!["B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?
M8V]N=&5N=',H)&9I;&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1F<"`]($!F;W!E;B@D9FEL92P@)W)B)RD["B`@("`@("`@("`@(&EF("@A
M)&9P*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92XB*2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L(&9I;&5S:7IE*"1F
M:6QE*2D["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1D871A.PH@("`@?0H*("`@("\J*@H@("`@("H@4W1O
M<F4@82!F:6QE(&EN('1H92!61E,L('=I=&@@=&AE(&1A=&$@8V]P:65D(&9R
M;VT@82!T96UP;W)A<GD*("`@("`J(&9I;&4N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H('1O('-T;W)E('1H
M92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@("`@
M(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M;7!&:6QE("`@("`@5&AE('1E;7!O<F%R>2!F:6QE(&-O;G1A:6YI;F<@=&AE
M(&1A=&$@=&\@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=&]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@
M075T;VUA=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M=W)I=&4H)'!A=&@L("1N86UE+"`D=&UP1FEL92P@)&%U=&]C<F5A=&4@/2!F
M86QS92D*("`@('L*("`@("`@("`O*B!.;R!N965D('1O(&-H96-K('%U;W1A
M(&AE<F4@87,@=V4@=VEL;"!C:&5C:R!I="!W:&5N('=E(&-A;&P*("`@("`@
M("`@*B!W<FET941A=&$H*2X@*B\*"B`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("`D9&%T
M82`](&9I;&5?9V5T7V-O;G1E;G1S*"1T;7!&:6QE*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9&%T8490(#T@0&9O<&5N*"1T;7!&:6QE+"`G
M<F(G*3L*("`@("`@("`@("`@)&1A=&$@/2!`9G)E860H)&1A=&%&4"P@9FEL
M97-I>F4H)'1M<$9I;&4I*3L*("`@("`@("`@("`@9F-L;W-E*"1D871A1E`I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G=R:71E1&%T82@D
M<&%T:"P@)&YA;64L("1D871A+"`D875T;V-R96%T92D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3=&]R92!A(&9I;&4@:6X@=&AE(%9&4R!F<F]M(')A=R!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@
M("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D9&%T82`@("`@("`@(%1H92!F:6QE(&1A
M=&$N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA
M=&EC86QL>2!C<F5A=&4@9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&5$
M871A*"1P871H+"`D;F%M92P@)&1A=&$L("1A=71O8W)E871E(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@)')E<R`]("1T:&ES+3Y?8VAE8VM1=6]T85=R:71E
M*"=S=')I;F<G+"`D9&%T82D["B`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@
M("!]"@H@("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)'!A=&@L("1N86UE*2P@)W<G*3L*("`@("`@("!I9B`H(21F<"D@>PH@
M("`@("`@("`@("!I9B`H)&%U=&]C<F5A=&4I('L*("`@("`@("`@("`@("`@
M("1R97-U;'0@/2`D=&AI<RT^875T;V-R96%T95!A=&@H)'!A=&@I.PH@("`@
M("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES
M+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I+"`G=R<I.PH@("`@("`@
M("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL
M92!F;W(@=W)I=&EN9RXB*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BA?*")5;F%B;&4@=&\@;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN
M9RXB*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M0&9W<FET92@D9G`L("1D871A*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@9&%T
M82XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D=&AI<RT^7W=R
M:71E4U%,1&%T82@D<&%T:"P@)&YA;64L("1A=71O8W)E871E*2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?9V5T3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I*3L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O('=R:71E(%9&4R!F:6QE(&1A
M=&$N(BDI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UO=F5S
M(&$@9FEL92!I;B!T:&4@9&%T86)A<V4@86YD('1H92!F:6QE('-Y<W1E;2X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T
M;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1D
M97-T("!4:&4@;F5W(&9I;&5N86UE+@H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO=F4H)'!A=&@L
M("1N86UE+"`D9&5S="D*("`@('L*("`@("`@("`D;W)I9R`]("1T:&ES+3Y?
M9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E*"1O<FEG*2`N("<O/R1\)RP@)&1E
M<W0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H
M(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO;B!I<R!W:71H:6X@
M<V]U<F-E+B(I*3L*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T
M+"!N=6QL+"!F86QS92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A
M<R`D9FEL92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D
M;F%M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R<&]S*"1D97-T+"`D=&AI
M<RT^7V=E=%-13$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2D@(3T](&9A;'-E
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N
M86)L92!T;R!M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F5N86UE*"1P871H+"`D;F%M92P@)&1E<W0L("1N
M86UE*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O<&EE<R!A(&9I;&4@=&AR
M;W5G:"!T:&4@8F%C:V5N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("!4:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J
M($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D97-T("!4:&4@9&5S=&EN871I;VX@;V8@
M=&AE(&9I;&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@8V]P>2@D<&%T:"P@)&YA;64L("1D97-T
M*0H@("`@>PH@("`@("`@("1O<FEG(#T@)'1H:7,M/E]G971.871I=F50871H
M*"1P871H+"`D;F%M92D["B`@("`@("`@:68@*'!R96=?;6%T8V@H)WQ>)R`N
M('!R96=?<75O=&4H)&]R:6<I("X@)R\_)'PG+"`D9&5S="DI('L*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&-O<'D@
M9FEL92AS*2`M('-O=7)C92!A;F0@9&5S=&EN871I;VX@87)E('1H92!S86UE
M+B(I*3L*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN
M96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@
M("`@)&9I;&5#:&5C:R`]("1T:&ES+3YL:7-T1F]L9&5R*"1D97-T+"!N=6QL
M+"!F86QS92D["B`@("`@("`@9F]R96%C:"`H)&9I;&5#:&5C:R!A<R`D9FEL
M92D@>PH@("`@("`@("`@("!I9B`H)&9I;&5;)VYA;64G72`]/2`D;F%M92D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(BDI.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!I9B`H<W1R<&]S*"1D97-T+"`D=&AI<RT^7V=E
M=%-13$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2D@(3T](&9A;'-E*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T
M;R!C;W!Y(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI
M<U]D:7(H)&]R:6<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)E
M8W5R<VEV94-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(4!C;W!Y*"1O<FEG+"`D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)&1E<W0L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-O<'D@5D93(&9I;&4N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^;F5X=$ED*"1T
M:&ES+3Y?<&%R86US6R=T86)L92==*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@G24Y315)4($E.5$\@)7,@*'9F<U]I9"P@=F9S7W1Y<&4L('9F<U]P
M871H+"!V9G-?;F%M92P@=F9S7VUO9&EF:65D+"!V9G-?;W=N97(I(%9!3%5%
M4R`H/RP@/RP@/RP@/RP@/RP@/RDG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI.PH@("`@("`@("1V86QU97,@
M/2!A<G)A>2@D:60L(%9&4U]&24Q%+"`D9&5S="P@)&YA;64L('1I;64H*2P@
M)'1H:7,M/E]P87)A;7-;)W5S97(G72D["@H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V1B+3YQ=65R>2@D<75E<GDL("1V86QU97,I.PH*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M('5N;&EN:R@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&1E<W0L("1N86UE*2D[
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@9F]L9&5R(&]N('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@2&]L9',@=&AE('!A=&@@;V8@9&ER96-T;W)Y('1O(&-R
M96%T92!F;VQD97(N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!(;VQD
M<R!T:&4@;F%M92!O9B!T:&4@;F5W(&9O;&1E<BX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A
M=&5&;VQD97(H)'!A=&@L("1N86UE*0H@("`@>PH@("`@("`@("1C;VYN(#T@
M)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@
M("`@('T*"B`@("`@("`@)&ED(#T@)'1H:7,M/E]D8BT^;F5X=$ED*"1T:&ES
M+3Y?<&%R86US6R=T86)L92==*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^<75E<GDH<W!R:6YT9B@G24Y315)4($E.5$\@)7,@*'9F<U]I9"P@
M=F9S7W1Y<&4L('9F<U]P871H+"!V9G-?;F%M92P@=F9S7VUO9&EF:65D+"!V
M9G-?;W=N97(I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@5D%,5453("@_+"`_+"`_+"`_+"`_+"`_*2<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@D:60L(%9&4U]&3TQ$15(L("1P871H+"`D;F%M92P@
M=&EM92@I+"`D=&AI<RT^7W!A<F%M<ULG=7-E<B==*2D["B`@("`@("`@:68@
M*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&UK9&ER
M*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT9B@G
M1$5,151%($923TT@)7,@5TA%4D4@=F9S7VED(#T@/R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=T86)L92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"1I9"DI.PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8W)E871E(%9&4R!D:7)E
M8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!296YA;64@82!F:6QE(&]R(&9O;&1E<B!I
M;B!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]L9'!A
M=&@@(%1H92!O;&0@<&%T:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!S
M=')I;F<@)&]L9&YA;64@(%1H92!O;&0@9FEL96YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9I;&4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4:&4@;F5W(&9I;&5N
M86UE+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')E;F%M92@D;VQD<&%T:"P@)&]L9&YA;64L("1N
M97=P871H+"`D;F5W;F%M92D*("`@('L*("`@("`@("`D8V]N;B`]("1T:&ES
M+3Y?8V]N;F5C="@I.PH@("`@("`@(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D8V]N;CL*("`@("`@("!]
M"@H@("`@("`@(&EF("AS=')P;W,H)&YE=W!A=&@L("<O)RD@/3T](&9A;'-E
M*2!["B`@("`@("`@("`@("1P87)E;G0@/2`G)SL*("`@("`@("`@("`@)'!A
M=&@@/2`D;F5W<&%T:#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!L
M:7-T*"1P87)E;G0L("1P871H*2`](&5X<&QO9&4H)R\G+"`D;F5W<&%T:"P@
M,BD["B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M/FES1F]L9&5R*"1P
M87)E;G0L("1P871H*2D@>PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT
M(#T@)'1H:7,M/F%U=&]C<F5A=&50871H*"1N97=P871H*2P@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M7V1B+3YQ=65R>2AS<')I;G1F*"=54$1!5$4@)7,@4T54('9F<U]P871H(#T@
M/RP@=F9S7VYA;64@/2`_+"!V9G-?;6]D:69I960@/2`_"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=F9S7W!A
M=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)&YE=W!A=&@L("1N97=N86UE+"!T:6UE*"DL("1O;&1P871H+"`D;VQD
M;F%M92DI.PH*("`@("`@("!I9B`H)'1H:7,M/E]D8BT^869F96-T9612;W=S
M*"D@/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*")5;F%B;&4@=&\@<F5N86UE(%9&4R!F:6QE+B(I*3L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<U]A*"1T:&ES+3Y?<F5C=7)S:79E4U%,4F5N86UE
M*"1O;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*2P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH<W!R:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`](#\L
M('9F<U]N86UE(#T@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N
M86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1O;&1P
M871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*2D["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R96YA
M;64@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(4!I<U]D:7(H)'1H:7,M/E]G971.871I=F50871H*"1N97=P871H*2DI('L*
M("`@("`@("`@("`@:68@*&ES7V$H)')E<R`]("1T:&ES+3YA=71O8W)E871E
M4&%T:"@D;F5W<&%T:"DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(4!R96YA;64H)'1H:7,M/E]G971.871I=F50871H*"1O;&1P
M871H+"`D;VQD;F%M92DL("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D;F5W<&%T
M:"P@)&YE=VYA;64I*2D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/E]D8BT^<75E<GDH<W!R:6YT9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`]
M(#\L('9F<U]N86UE(#T@/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!72$5212!V9G-?<&%T:"`](#\@04Y$('9F
M<U]N86UE(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L92==*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1O
M;&1P871H+"`D;VQD;F%M92P@)&YE=W!A=&@L("1N97=N86UE*2D["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!R
M96YA;64@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F;VQD97(@
M9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A
M=&@@("`@("`@(%1H92!P871H('1O(&1E;&5T92!T:&4@9F]L9&5R(&9R;VTN
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@9F]L9&5R
M;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S:79E
M("!&;W)C92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E
M1F]L9&5R*"1P871H+"`D;F%M92P@)')E8W5R<VEV92`](&9A;'-E*0H@("`@
M>PH@("`@("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@
M:68@*&ES7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R96-U<G-I
M=F4I('L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YE;7!T>49O;&1E
M<B@D<&%T:"`N("<O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@*&ES7V$H
M)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;&ES="`]("1T:&ES+3YL:7-T1F]L9&5R*"1P871H("X@
M)R\G("X@)&YA;64I.PH@("`@("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AC;W5N="@D;&ES="DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN
M=&8H7R@B56YA8FQE('1O(&1E;&5T92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N
M;W0@96UP='DB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A=&@@+B`G+R<@+B`D;F%M92DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D
M8BT^<75E<GDH<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S7W1Y
M<&4@/2`_($%.1"!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE(#T@/R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2A61E-?1D],1$52+"`D<&%T:"P@)&YA;64I
M*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?9&(M/F%F9F5C=&5D4F]W<R@I(#T]
M(#`@?'P@:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE
M=&4@5D93(&1I<F5C=&]R>2XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M:7-?82@D=&AI<RT^7W)E8W5R<VEV95-13$1E;&5T92@D<&%T:"P@)&YA;64I
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R
M96-U<G-I=F5L>2XB*2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?82@D
M=&AI<RT^7W)E8W5R<VEV94Q&4T1E;&5T92@D<&%T:"P@)&YA;64I+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93(&1I<F5C=&]R>2!R96-U<G-I
M=F5L>2XB*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*
M("`@('T*"B`@("`O*BH*("`@("`J($1E;&5T92!A(&9I;&4@9G)O;2!T:&4@
M5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P
M871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@5&AE(&9I;&5N86UE('1O('5S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE
M=&5&:6QE*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("`D<F5S(#T@)'1H
M:7,M/E]C:&5C:U%U;W1A1&5L971E*"1P871H+"`D;F%M92D["B`@("`@("`@
M:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("1C;VYN(#T@)'1H:7,M
M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@("`@('T*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*'-P<FEN=&8H
M)T1%3$5412!&4D]-("5S(%=(15)%('9F<U]T>7!E(#T@/R!!3D0@=F9S7W!A
M=&@@/2`_($%.1"!V9G-?;F%M92`](#\G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US6R=T86)L
M92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH5D937T9)3$4L("1P871H+"`D;F%M92DI.PH*("`@("`@("!I9B`H)'1H
M:7,M/E]D8BT^869F96-T9612;W=S*"D@/3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@9&5L971E(%9&
M4R!F:6QE+B(I*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]A*"1R97-U
M;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U
M;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H(4!U;FQI;FLH)'1H:7,M/E]G
M971.871I=F50871H*"1P871H+"`D;F%M92DI*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!D96QE=&4@5D93
M(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!L:7-T(&]F('1H92!C;VYT
M96YT<R!O9B!A(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("`@("`@(%1H92!D:7)E8W1O<GD@<&%T:"X*("`@("`J($!P87)A
M;2!M:7AE9"`D9FEL=&5R("`@("`@4W1R:6YG+VAA<V@@;V8@:71E;7,@=&\@
M9FEL=&5R(&)A<V5D(&]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9I;&5N86UE+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9I;&5S
M("!3:&]W(&1O=&9I;&5S/PH@("`@("H@0'!A<F%M(&)O;VQE86X@)&1I<F]N
M;'D@("!3:&]W(&1I<F5C=&]R:65S(&]N;'D_"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@1FEL92!L:7-T(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VQI<W1&;VQD97(H)'!A
M=&@L("1F:6QT97(@/2!N=6QL+"`D9&]T9FEL97,@/2!T<G5E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`D9&ER;VYL>2`](&9A;'-E*0H@("`@>PH@("`@
M("`@("1C;VYN(#T@)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES
M7V$H)&-O;FXL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1C;VYN.PH@("`@("`@('T*"B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L*
M("`@("`@("`D9FEL94QI<W0@/2!A<G)A>2@I.PH*("`@("`@("`D9FEL94QI
M<W0@/2`D=&AI<RT^7V1B+3YG971!;&PH<W!R:6YT9B@G4T5,14-4('9F<U]N
M86UE+"!V9G-?='EP92P@=F9S7VUO9&EF:65D+"!V9G-?;W=N97(@1E)/32`E
M<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%=(15)%('9F<U]P871H(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A
M8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@D<&%T:"DI.PH@("`@("`@(&EF("AI<U]A*"1F:6QE3&ES="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I;&5,:7-T
M.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)&9I;&5,:7-T(&%S("1L
M:6YE*2!["B`@("`@("`@("`@("\O($9I;'1E<B!O=70@9&]T9FEL97,@:68@
M=&AE>2!A<F5N)W0@=V%N=&5D+@H@("`@("`@("`@("!I9B`H(21D;W1F:6QE
M<R`F)B!S=6)S='(H)&QI;F5;,%TL(#`L(#$I(#T]("<N)RD@>PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1F:6QE6R=N86UE)UT@/2`D;&EN95LP73L*"B`@("`@("`@("`@(&EF("@D
M;&EN95LQ72`]/2!61E-?1DE,12D@>PH@("`@("`@("`@("`@("`@)&YA;64@
M/2!E>'!L;V1E*"<N)RP@)&QI;F5;,%TI.PH*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D;F%M92D@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@("1F
M:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`](%9&4SHZ
M<W1R=&]L;W=E<B@D;F%M95MC;W5N="@D;F%M92D@+2`Q72D["B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`](&9I
M;&5S:7IE*"1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&QI;F5;,%TI
M*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1L:6YE6S%=(#T](%9&4U]&3TQ$
M15(I('L*("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BID:7(G
M.PH@("`@("`@("`@("`@("`@)&9I;&5;)W-I>F4G72`]("TQ.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D9FEL95LG9&%T92==(#T@)&QI;F5;,ET[
M"B`@("`@("`@("`@("1F:6QE6R=O=VYE<B==(#T@)&QI;F5;,UT["B`@("`@
M("`@("`@("1F:6QE6R=P97)M<R==(#T@)R<["B`@("`@("`@("`@("1F:6QE
M6R=G<F]U<"==(#T@)R<["@H@("`@("`@("`@("`O+R!&:6QT97)I;F<N"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V9I;'1E<DUA=&-H*"1F:6QT97(L("1F
M:6QE6R=N86UE)UTI*2!["B`@("`@("`@("`@("`@("!U;G-E="@D9FEL92D[
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)&1I<F]N;'D@)B8@)&9I;&5;)W1Y<&4G72`A/3T@)RHJ
M9&ER)RD@>PH@("`@("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@
M("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1F:6QE<ULD9FEL95LG;F%M92==72`]("1F:6QE.PH@("`@("`@("`@("!U
M;G-E="@D9FEL92D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('-O<G1E9"!L:7-T
M(&]F(&9O;&1E<G,@:6X@<W!E8VEF:65D(&1I<F5C=&]R>2X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@("`@5&AE('!A=&@@;V8@
M=&AE(&1I<F5C=&]R>2!T;R!G970@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9&ER96-T;W)Y(&QI<W0@9F]R+@H@("`@("H@0'!A
M<F%M(&UI>&5D("1F:6QT97(@("`@("`@(%-T<FEN9R]H87-H(&]F(&ET96US
M('1O(&9I;'1E<B!B87-E9"!O;@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9O;&1E<FQI<W0N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M9&]T9F]L9&5R<R`@26YC;'5D92!D;W1F;VQD97)S/PH@("`@("H*("`@("`J
M($!R971U<FX@;6EX960@($9O;&1E<B!L:7-T(&]N('-U8V-E<W,@;W(@82!0
M14%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!L:7-T1F]L9&5R<R@D<&%T:"`]("<G+"`D9FEL=&5R(#T@87)R87DH
M*2P@)&1O=&9O;&1E<G,@/2!T<G5E*0H@("`@>PH@("`@("`@("1C;VYN(#T@
M)'1H:7,M/E]C;VYN96-T*"D["B`@("`@("`@:68@*&ES7V$H)&-O;FXL("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N("1C;VYN.PH@("`@
M("`@('T*"B`@("`@("`@)'-Q;"`]('-P<FEN=&8H)U-%3$5#5"!V9G-?;F%M
M92P@=F9S7W!A=&@@1E)/32`E<R!72$5212!V9G-?<&%T:"`](#\@04Y$('9F
M<U]T>7!E(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P
M87)A;7-;)W1A8FQE)UTI.PH*("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES
M+3Y?9&(M/F=E=$%L;"@D<W%L+"!A<G)A>2@D<&%T:"P@)%9&4U]&3TQ$15(I
M*3L*("`@("`@("!I9B`H:7-?82@D9F]L9&5R3&ES="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&9O;&1E<DQI<W0["B`@("`@("`@
M?0H*("`@("`@("`D9F]L9&5R<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C
M:"`H)&9O;&1E<DQI<W0@87,@)&QI;F4I('L*("`@("`@("`@("`@)&9O;&1E
M<ELG=F%L)UT@/2`D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&QI;F5;,5TL("1L
M:6YE6S!=*3L*("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@/2`G)SL*
M("`@("`@("`@("`@)&9O;&1E<ELG;&%B96PG72`]("<G.PH*("`@("`@("`@
M("`@)&-O=6YT(#T@<W5B<W1R7V-O=6YT*"1F;VQD97);)W9A;"==+"`G+R<I
M.PH*("`@("`@("`@("`@)'@@/2`P.PH@("`@("`@("`@("!W:&EL92`H)'@@
M/"`D8V]U;G0I('L*("`@("`@("`@("`@("`@("1F;VQD97);)V%B8G)E=B==
M("X]("<@("`@)SL*("`@("`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@
M+CT@)R`@("`G.PH@("`@("`@("`@("`@("`@)'@K*SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@)&9O;&1E<ELG86)B<F5V)UT@+CT@)&QI;F5;,%T[
M"B`@("`@("`@("`@("1F;VQD97);)VQA8F5L)UT@+CT@)&QI;F5;,%T["@H@
M("`@("`@("`@("`D<W1R;&5N(#T@5D93.CIS=')L96XH)&9O;&1E<ELG;&%B
M96PG72D["B`@("`@("`@("`@(&EF("@D<W1R;&5N(#X@,C8I('L*("`@("`@
M("`@("`@("`@("1F;VQD97);)V%B8G)E=B==(#T@<W5B<W1R*"1F;VQD97);
M)VQA8F5L)UTL(#`L("@D8V]U;G0@*B`T*2D["B`@("`@("`@("`@("`@("`D
M;&5N9W1H(#T@*#(Y("T@*"1C;W5N="`J(#0I*2`O(#(["B`@("`@("`@("`@
M("`@("`D9F]L9&5R6R=A8F)R978G72`N/2!S=6)S='(H)&9O;&1E<ELG;&%B
M96PG72P@*"1C;W5N="`J(#0I+"`D;&5N9W1H*3L*("`@("`@("`@("`@("`@
M("1F;VQD97);)V%B8G)E=B==("X]("<N+BXG.PH@("`@("`@("`@("`@("`@
M)&9O;&1E<ELG86)B<F5V)UT@+CT@<W5B<W1R*"1F;VQD97);)VQA8F5L)UTL
M("TQ("H@)&QE;F=T:"P@)&QE;F=T:"D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H("@D
M9FEL=&5R(&%S("1F;'1R*2!["B`@("`@("`@("`@("`@("!I9B`H)&9O;&1E
M<ELG=F%L)UT@/3T@)&9L='(I('L*("`@("`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H(21F;W5N9"D@>PH@("`@("`@("`@("`@("`@)&9O
M;&1E<G-;)&9O;&1E<ELG=F%L)UU=(#T@)&9O;&1E<CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:W-O<G0H)&9O;&1E<G,I.PH@("`@("`@
M(')E='5R;B`D9F]L9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E8W5R
M<VEV96QY(&-O<&EE<R!T:&4@8V]N=&5N=',@;V8@82!F;VQD97(@=&\@82!D
M97-T:6YA=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!S
M=&]R92!T:&4@9&ER96-T;W)Y(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@5&AE(&YA;64@;V8@=&AE(&1I<F5C=&]R>2X*("`@("`J($!P87)A
M;2!S=')I;F<@)&1E<W0@(%1H92!D97-T:6YA=&EO;B!O9B!T:&4@9&ER96-T
M;W)Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]R96-U<G-I=F5#;W!Y*"1P871H+"`D;F%M92P@
M)&1E<W0I"B`@("!["B`@("`@("`@)')E<W5L="`]("1T:&ES+3YC<F5A=&5&
M;VQD97(H)&1E<W0L("1N86UE*3L*"B`@("`@("`@:68@*&ES7V$H)')E<W5L
M="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("!]"@H@("`@("`@("1F:6QE7VQI<W0@/2`D=&AI<RT^;&ES
M=$9O;&1E<B@D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H)'!A=&@L("1N86UE
M*2D["@H@("`@("`@(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*
M("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YC;W!Y*"1T:&ES+3Y?9V5T
M4U%,3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I+"`D9FEL95LG;F%M92==+"`D
M=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H)&1E<W0L("1N86UE*2D["@H@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3=&]R92!A(&9I;&5S(&EN9F]R;6%T:6]N('=I=&AI;B!T:&4@
M9&%T86)A<V4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H
M('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D875T;V-R96%T92`@075T;VUA=&EC86QL>2!C<F5A=&4@
M9&ER96-T;W)I97,_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W=R:71E4U%,1&%T82@D<&%T:"P@
M)&YA;64L("1A=71O8W)E871E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&-O
M;FX@/2`D=&AI<RT^7V-O;FYE8W0H*3L*("`@("`@("!I9B`H:7-?82@D8V]N
M;BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&-O;FX[
M"B`@("`@("`@?0H*("`@("`@("`O+R!&:6QE(&%L<F5A9'D@97AI<W1S(&EN
M(&1A=&%B87-E"B`@("`@("`@:68@*"1T:&ES+3YE>&ES=',H)'!A=&@L("1N
M86UE*2D@>PH@("`@("`@("`@("`D<75E<GD@/2`G55!$051%("<@+B`D=&AI
M<RT^7W!A<F%M<ULG=&%B;&4G72`N"B`@("`@("`@("`@("`@("`@("`@("<@
M4T54('9F<U]M;V1I9FEE9"`](#\G("X*("`@("`@("`@("`@("`@("`@("`@
M)R!72$5212!V9G-?<&%T:"`](#\@04Y$('9F<U]N86UE(#T@/R<["B`@("`@
M("`@("`@("1V86QU97,@/2!A<G)A>2AT:6UE*"DL("1P871H+"`D;F%M92D[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&ED(#T@)'1H:7,M/E]D
M8BT^;F5X=$ED*"1T:&ES+3Y?<&%R86US6R=T86)L92==*3L*"B`@("`@("`@
M("`@("1Q=65R>2`]("=)3E-%4E0@24Y43R`G("X@)'1H:7,M/E]P87)A;7-;
M)W1A8FQE)UT@+@H@("`@("`@("`@("`@("`@("`@("`G("AV9G-?:60L('9F
M<U]T>7!E+"!V9G-?<&%T:"P@=F9S7VYA;64L('9F<U]M;V1I9FEE9"PG("X*
M("`@("`@("`@("`@("`@("`@("`@)R!V9G-?;W=N97(I(%9!3%5%4R`H/RP@
M/RP@/RP@/RP@/RP@/RDG.PH@("`@("`@("`@("`D=F%L=65S(#T@87)R87DH
M)&ED+"!61E-?1DE,12P@)'!A=&@L("1N86UE+"!T:6UE*"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=7-E<B==*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9&(M/G%U97)Y*"1Q
M=65R>2P@)'9A;'5E<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296YA;65S
M(&%L;"!C:&EL9"!P871H<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1O;&1P871H("!4:&4@
M;VQD('!A=&@@;V8@=&AE(&9O;&1E<B!T;R!R96YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1O;&1N86UE("!4:&4@;VQD(&YA;64N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N97=P871H("!4:&4@;F5W('!A=&@@;V8@=&AE(&9O;&1E
M<B!T;R!R96YA;64N"B`@("`@*B!`<&%R86T@<W1R:6YG("1N97=N86UE("!4
M:&4@;F5W(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U
M92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W)E8W5R<VEV95-13%)E;F%M92@D
M;VQD<&%T:"P@)&]L9&YA;64L("1N97=P871H+"`D;F5W;F%M92D*("`@('L*
M("`@("`@("`D9F]L9&5R3&ES="`]("1T:&ES+3Y?9&(M/F=E=$-O;"AS<')I
M;G1F*"=314Q%0U0@=F9S7VYA;64@1E)/32`E<R!72$5212!V9G-?='EP92`]
M(#\@04Y$('9F<U]P871H(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B
M;&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2A61E-?1D],1$52+"`D=&AI<RT^7V=E=%-13$YA=&EV95!A=&@H
M)&]L9'!A=&@L("1O;&1N86UE*2DI.PH*("`@("`@("!F;W)E86-H("@D9F]L
M9&5R3&ES="!A<R`D9F]L9&5R*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F5C
M=7)S:79E4U%,4F5N86UE*"1T:&ES+3Y?9V5T4U%,3F%T:79E4&%T:"@D;VQD
M<&%T:"P@)&]L9&YA;64I+"`D9F]L9&5R+"`D=&AI<RT^7V=E=%-13$YA=&EV
M95!A=&@H)&YE=W!A=&@L("1N97=N86UE*2P@)&9O;&1E<BD["B`@("`@("`@
M?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH<W!R:6YT
M9B@G55!$051%("5S(%-%5"!V9G-?<&%T:"`](#\@5TA%4D4@=F9S7W!A=&@@
M/2`_)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A<F%M<ULG=&%B;&4G72DL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?9V5T4U%,3F%T
M:79E4&%T:"@D;F5W<&%T:"P@)&YE=VYA;64I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=%-13$YA=&EV
M95!A=&@H)&]L9'!A=&@L("1O;&1N86UE*2DI.PH*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M;&5T92!A(&9O;&1E<G,@8V]N=&5N=',@9G)O;2!T:&4@5D93(&EN('1H92!3
M44P@9&%T86)A<V4L"B`@("`@*B!R96-U<G-I=F5L>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P871H("!4:&4@<&%T:"!O9B!T:&4@9F]L9&5R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@5&AE(&9O;&1E<FYA;64@=&\@=7-E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%
M05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]R96-U<G-I=F5344Q$96QE=&4H)'!A=&@L("1N86UE*0H@("`@>PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2AS<')I;G1F*"=$
M14Q%5$4@1E)/32`E<R!72$5212!V9G-?='EP92`](#\@04Y$('9F<U]P871H
M(#T@/R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2A61E-?1DE,12P@)'1H:7,M
M/E]G971344Q.871I=F50871H*"1P871H+"`D;F%M92DI*3L*("`@("`@("!I
M9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)&9O;&1E<DQI
M<W0@/2`D=&AI<RT^7V1B+3YG971#;VPH<W!R:6YT9B@G4T5,14-4('9F<U]N
M86UE($923TT@)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.1"!V9G-?<&%T:"`]
M(#\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)W1A8FQE)UTI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#`L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH5D937T9/3$1%
M4BP@)'1H:7,M/E]G971344Q.871I=F50871H*"1P871H+"`D;F%M92DI*3L*
M"B`@("`@("`@9F]R96%C:"`H)&9O;&1E<DQI<W0@87,@)&9O;&1E<BD@>PH@
M("`@("`@("`@("`D=&AI<RT^7W)E8W5R<VEV95-13$1E;&5T92@D=&AI<RT^
M7V=E=%-13$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2P@)&9O;&1E<BD["B`@
M("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH
M<W!R:6YT9B@G1$5,151%($923TT@)7,@5TA%4D4@=F9S7W1Y<&4@/2`_($%.
M1"!V9G-?;F%M92`](#\@04Y$('9F<U]P871H(#T@/R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)A
M;7-;)W1A8FQE)UTI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2A61E-?1D],1$52+"`D;F%M92P@)'!A=&@I*3L*"B`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE
M=&4@82!F;VQD97)S(&-O;G1E;G1S(&9R;VT@=&AE(%9&4RP@<F5C=7)S:79E
M;'DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@;V8@=&AE(&9O;&1E
M<BX*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@(%1H92!F;VQD97)N86UE
M('1O('5S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!4<G5E(&]N
M('-U8V-E<W,@;W(@82!014%27T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!?<F5C=7)S:79E3$931&5L971E*"1P871H
M+"`D;F%M92D*("`@('L*("`@("`@("`D9&ER(#T@)'1H:7,M/E]G971.871I
M=F50871H*"1P871H+"`D;F%M92D["B`@("`@("`@)&1H(#T@0&]P96YD:7(H
M)&1I<BD["@H@("`@("`@('=H:6QE("AF86QS92`A/3T@*"1F:6QE(#T@<F5A
M9&1I<B@D9&@I*2D@>PH@("`@("`@("`@("!I9B`H)&9I;&4@(3T@)RXG("8F
M("1F:6QE("$]("<N+B<I('L*("`@("`@("`@("`@("`@(&EF("AI<U]D:7(H
M)&1I<B`N("<O)R`N("1F:6QE*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5C=7)S:79E3$931&5L971E*&5M<'1Y*"1P871H*2`_("1N86UE
M(#H@)'!A=&@@+B`G+R<@+B`D;F%M92P@)&9I;&4I.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!`=6YL:6YK*"1D:7(@
M+B`G+R<@+B`D9FEL92D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@0&-L;W-E9&ER*"1D:"D["@H@("`@("`@
M(')E='5R;B!R;61I<B@D9&ER*3L*("`@('T*"B`@("`O*BH*("`@("`J($%T
M=&5M<'1S('1O(&]P96X@82!P97)S:7-T96YT(&-O;FYE8W1I;VX@=&\@=&AE
M(%-13"!S97)V97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R
M(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-O;FYE8W0H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M7V1B(#T]/2!F86QS92D@>PH@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T
M:&ES+3Y?<&%R86US*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B3F\@8V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!S
M<&5C:69I960@9F]R(%-13"U&:6QE(%9&4RXB*2D["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("1R97%U:7)E9"`](&%R<F%Y*"=P:'!T>7!E)RP@)W9F
M<W)O;W0G*3L*("`@("`@("`@("`@9F]R96%C:"`H)')E<75I<F5D(&%S("1V
M86PI('L*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A
M;7-;)'9A;%TI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H<W!R:6YT9BA?*")297%U:7)E9"!<(B5S7"(@;F]T('-P
M96-I9FEE9"!I;B!61E,@8V]N9FEG=7)A=&EO;BXB*2P@)'9A;"DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?<&%R86US6R=D871A8F%S92==*2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)A;7-;)V1A=&%B87-E)UT@/2`G)SL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A
M<F%M<ULG=7-E<FYA;64G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%R86US6R=U<V5R;F%M92==(#T@)R<["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P87)A;7-;)VAO<W1S<&5C)UTI
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG:&]S='-P96,G
M72`]("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%R86US6R=T86)L92==*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7-;)W1A8FQE)UT@/2`G:&]R9&5?=F9S)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N;F5C="!T;R!T:&4@4U%,('-E
M<G9E<B!U<VEN9R!T:&4@<W5P<&QI960@<&%R86UE=&5R<RX@*B\*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH@("`@("`@("`@("`D=&AI
M<RT^7V1B(#T@)D1".CIC;VYN96-T*"1T:&ES+3Y?<&%R86US+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P97)S:7-T
M96YT)R`]/B`A96UP='DH)'1H:7,M/E]P87)A;7-;)W!E<G-I<W1E;G0G72DI
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M/E]D8BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@)'1H:7,M/E]D8CL*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&(@/2!F86QS93L*("`@("`@("`@
M("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O(%-E="!$0B!P;W)T86)I;&ET>2!O<'1I;VYS+@H@("`@("`@("`@
M("!S=VET8V@@*"1T:&ES+3Y?9&(M/G!H<'1Y<&4I('L*("`@("`@("`@("`@
M8V%S92`G;7-S<6PG.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T
M3W!T:6]N*"=P;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12!\($1"7U!/4E1!0DE,25197T524D]24R!\($1"7U!/4E1!0DE,25197U)4
M4DE-*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]D8BT^<V5T3W!T:6]N*"=P
M;W)T86)I;&ET>2<L($1"7U!/4E1!0DE,25197TQ/5T520T%312!\($1"7U!/
M4E1!0DE,25197T524D]24RD["B`@("`@("`@("`@('T*"B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($1I
M<V-O;FYE8W0@9G)O;2!T:&4@4U%,('-E<G9E<B!A;F0@8VQE86X@=7`@=&AE
M(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]D:7-C;VYN96-T*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/E]D8BD@>PH@("`@("`@("`@("`D=&AI<RT^7V1B+3YD
M:7-C;VYN96-T*"D["B`@("`@("`@("`@("1T:&ES+3Y?9&(@/2!F86QS93L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!F=6QL
M(&9I;&5N86UE(&]N('1H92!N871I=F4@9FEL97-Y<W1E;2P@9G)O;2!A(%9&
M4PH@("`@("H@<&%T:"!A;F0@;F%M92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@5D93(&9I;&4@<&%T:"X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@
M(%1H92!61E,@9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!F=6QL(&YA=&EV92!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*0H@("`@>PH@("`@
M("`@(&EF("@A96UP='DH)&YA;64I*2!["B`@("`@("`@("`@("1N86UE(#T@
M)R\G("X@)&YA;64["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D<&%T
M:"DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%R86US6R=H
M;VUE)UTI("8F"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"=\7GXO/R@N
M*BDD?"<L("1P871H+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@("`@("1P
M871H(#T@)'1H:7,M/E]P87)A;7-;)VAO;64G72`@+B`G+R<@+B`D;6%T8VAE
M<ULQ73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%R86US6R=V9G-R;V]T)UT@+B`G+R<@+B`D<&%T:"`N("1N86UE.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M<F%M<ULG=F9S<F]O="==("X@)&YA;64["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N(&$@9G5L;"!344P@9FEL96YA;64@;VX@=&AE
M(&YA=&EV92!F:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@("`@*B!P871H(&%N
M9"!N86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!61E,@9FEL92!P871H
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(%9&4R!F:6QE;F%M
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@;F%T
M:79E(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T4U%,3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1P871H*2D@>PH@("`@("`@("`@("!R971U<FX@)&YA;64["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'!A=&@@+B`G+R<@+B`D;F%M93L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]L:6(O5D93+V9I;&4N<&AP````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-34T,#$@,3`U,34T,S0Q
M,S8@,#(P,S<V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B!61E,@:6UP;&5M96YT871I;VX@9F]R(&$@
M<W1A;F1A<F0@9FEL97-Y<W1E;2X*("H*("H@4F5Q=6ER960@<&%R86UE=&5R
M<SH\<')E/@H@*B`@("=V9G-R;V]T)R`@5&AE(')O;W0@<&%T:#PO<')E/@H@
M*@H@*B!.;W1E.B!4:&4@=7-E<B!T:&%T('EO=7(@=V5B<V5R=F5R(')U;G,@
M87,@*&-O;6UO;FQY("=N;V)O9'DG+`H@*B`G87!A8VAE)RP@;W(@)W=W=RUD
M871A)RD@35535"!H879E(')E860O=W)I=&4@<&5R;6ES<VEO;B!T;R!T:&4*
M("H@9&ER96-T;W)Y('EO=2!S<&5C:69Y(&%S('1H92`G=F9S<F]O="<N"B`J
M"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O9FEL92YP:'`L=B`Q+C8S
M+C0N,C$@,C`P-B\P-2\S,2`P-#HU,#HP,B!S;'5S87)Z($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`R+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!#:'5C:R!(
M86=E;F)U8V@*("H@0'!A8VMA9V4@5D93"B`J+PIC;&%S<R!61E-?9FEL92!E
M>'1E;F1S(%9&4R!["@H@("`@+RHJ"B`@("`@*B!,:7-T(&]F('!E<FUI<W-I
M;VYS(&%N9"!I9B!T:&5Y(&-A;B!B92!C:&%N9V5D(&EN('1H:7,@5D93"B`@
M("`@*B!B86-K96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<&5R;6ES<VEO;G,@/2!A<G)A>2@*("`@("`@("`G;W=N
M97(G(#T^(&%R<F%Y*"=R96%D)R`]/B!T<G5E+"`G=W)I=&4G(#T^('1R=64L
M("=E>&5C=71E)R`]/B!T<G5E*2P*("`@("`@("`G9W)O=7`G(#T^(&%R<F%Y
M*"=R96%D)R`]/B!T<G5E+"`G=W)I=&4G(#T^('1R=64L("=E>&5C=71E)R`]
M/B!T<G5E*2P*("`@("`@("`G86QL)R`@(#T^(&%R<F%Y*"=R96%D)R`]/B!T
M<G5E+"`G=W)I=&4G(#T^('1R=64L("=E>&5C=71E)R`]/B!T<G5E*0H@("`@
M*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@1FEL97-Y<W1E
M;2!B87-E9"!61E,@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A
M>2`D<&%R86US("!!(&AA<V@@8V]N=&%I;FEN9R!C;VYN96-T:6]N('!A<F%M
M971E<G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%9&4U]F:6QE*"1P87)A;7,@
M/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('!A<F5N=#HZ5D93*"1P87)A;7,I
M.PH*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T
M)UTI*2!["B`@("`@("`@("`@(&EF("AS=6)S='(H)'1H:7,M/E]P87)A;7-;
M)W9F<W)O;W0G72P@+3$I(#T]("<O)R!\?`H@("`@("`@("`@("`@("`@<W5B
M<W1R*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UTL("TQ*2`]/2`G7%PG*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==(#T@
M<W5B<W1R*"1T:&ES+3Y?<&%R86US6R=V9G-R;V]T)UTL(#`L('-T<FQE;B@D
M=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==*2`M(#$I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!F:6QE<VEZ92!F<F]M('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<&%T:"`@5&AE('!A=&AN86UE('1O('1H92!F:6QE+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&5N86UE('1O(')E=')I
M979E+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B!4:&4@9FEL92!S
M:7IE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S:7IE*"1P871H+"`D;F%M92D*
M("`@('L*("`@("`@("`D<VEZ92`]($!F:6QE<VEZ92@D=&AI<RT^7V=E=$YA
M=&EV95!A=&@H)'!A=&@L("1N86UE*2D["B`@("`@("`@:68@*"1S:7IE(#T]
M/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BAS<')I;G1F*%\H(E5N86)L92!T;R!C:&5C:R!F:6QE('-I>F4@;V8@7"(E
M<R\E<UPB+B(I+"`D<&%T:"P@)&YA;64I*3L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1S:7IE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F4@
M82!F:6QE(&9R;VT@=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H("!4:&4@<&%T:&YA;64@=&\@=&AE(&9I;&4N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@<F5T<FEE=F4N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F:6QE(&1A=&$N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E860H)'!A=&@L("1N86UE*0H@("`@
M>PH@("`@("`@("1F:6QE(#T@)'1H:7,M/E]G971.871I=F50871H*"1P871H
M+"`D;F%M92D["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G
M971?8V]N=&5N=',G*2D@>PH@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T
M7V-O;G1E;G1S*"1F:6QE*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)&9I;&4L("=R8B<I.PH@("`@("`@("`@("!I9B`H
M(21F<"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&]P96X@5D93(&9I;&4N(BDI.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1F:6QE<VEZ92`](&9I;&5S:7IE*"1F:6QE*3L*
M("`@("`@("`@("`@:68@*"1F:6QE<VEZ92`]/2`P*2!["B`@("`@("`@("`@
M("`@("`D9&%T82`]("<G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L("1F:6QE<VEZ92D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971R:65V97,@82!P87)T(&]F(&$@9FEL92!F<F]M('1H92!61E,N(%!A<G1I
M8W5L87)L>2!U<V5F=6P@=VAE;@H@("`@("H@<F5A9&EN9R!L87)G92!F:6QE
M<R!W:&EC:"!W;W5L9"!E>&-E960@=&AE(%!(4"!M96UO<GD@;&EM:71S(&EF
M('1H97D*("`@("`J('=E<F4@<W1O<F5D(&EN(&$@<W1R:6YG+@H@("`@("H*
M("`@("`J($!A8G-T<F%C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M("1P871H("`@("`@(%1H92!P871H;F%M92!T;R!T:&4@9FEL92X*("`@("`J
M($!P87)A;2!S=')I;F<@("1N86UE("`@("`@(%1H92!F:6QE;F%M92!T;R!R
M971R:65V92X*("`@("`J($!P87)A;2!I;G1E9V5R("1O9F9S970@("`@(%1H
M92!O9F9S970@;V8@=&AE('!A<G0N("A4:&4@;F5W(&]F9G-E="!W:6QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B92!S=&]R960@:6X@
M:&5R92DN"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&5N9W1H("`@("!4:&4@
M;&5N9W1H(&]F('1H92!P87)T+B!)9B!T:&4@;&5N9W1H(#T@+3$L"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@=VAO;&4@<&%R="!A
M9G1E<B!T:&4@;V9F<V5T(&ES(')E=')I979E9"X*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@($EF(&UO<F4@8GET97,@87)E(&=I=F5N(&%S
M(&5X:7-T<R!A9G1E<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&=I=F5N(&]F9G-E="X@3VYL>2!T:&4@879A:6QA8FQE(&)Y=&5S
M(&%R90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5A9"X*
M("`@("`J($!P87)A;2!I;G1E9V5R("1R96UA:6YI;F<@(%1H92!B>71E<R!T
M:&%T(&%R92!L969T+"!A9G1E<B!T:&4@<&%R="!T:&%T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I<R!R971R:65V960N"B`@("`@*@H@
M("`@("H@0')E='5R;B!S=')I;F<@5&AE(&9I;&4@9&%T82X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5A9$)Y=&5286YG92@D<&%T:"P@)&YA;64L("8D;V9F
M<V5T+"`D;&5N9W1H(#T@+3$L("8D<F5M86EN:6YG*0H@("`@>PH@("`@("`@
M(&EF("@D;V9F<V5T(#P@,"D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*%\H(E=R;VYG(&]F9G-E="`E9"!W:&EL92!R
M96%D:6YG(&$@5D93(&9I;&4N(BDL("1O9F9S970I*3L*("`@("`@("!]"@H@
M("`@("`@("\O($-A;&-U;&%T92!H;W<@;6%N>2!B>71E<R!-55-4(&)E(')E
M860L('-O('1H92!R96UA:6YG:6YG"B`@("`@("`@+R\@8GET97,@86YD('1H
M92!N97<@;V9F<V5T(&-A;B!B92!C86QC=6QA=&5D(&-O<G)E8W1L>2X*("`@
M("`@("`D9FEL92`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA
M;64I.PH@("`@("`@("1S:7IE(#T@9FEL97-I>F4@*"1F:6QE*3L*("`@("`@
M("!I9B`H)&QE;F=T:"`]/2`M,2!\?"`H*"1L96YG=&@@*R`D;V9F<V5T*2`^
M("1S:7IE*2D@>PH@("`@("`@("`@("`D;&5N9W1H(#T@)'-I>F4@+2`D;V9F
M<V5T.PH@("`@("`@('T*("`@("`@("!I9B`H)')E;6%I;FEN9R`\(#`I('L*
M("`@("`@("`@("`@)')E;6%I;FEN9R`](#`["B`@("`@("`@?0H*("`@("`@
M("`D9G`@/2!`9F]P96XH)&9I;&4L("=R8B<I.PH@("`@("`@(&EF("@A)&9P
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N
M86)L92!T;R!O<&5N(%9&4R!F:6QE+B(I*3L*("`@("`@("!]"B`@("`@("`@
M9G-E96LH)&9P+"`D;V9F<V5T*3L*("`@("`@("`D9&%T82`](&9R96%D*"1F
M<"P@)&QE;F=T:"D["B`@("`@("`@)&]F9G-E="`](&9T96QL*"1F<"D["B`@
M("`@("`@)')E;6%I;FEN9R`]("1S:7IE("T@)&]F9G-E=#L*"B`@("`@("`@
M9F-L;W-E*"1F<"D["@H@("`@("`@(')E='5R;B`D9&%T83L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I;B!T:&4@5D93+"!W:71H('1H
M92!D871A(&-O<&EE9"!F<F]M(&$@=&5M<&]R87)Y"B`@("`@*B!F:6QE+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("`@("!4:&4@
M<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S=')I
M;F<@)&YA;64@("`@("`@("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=&UP1FEL92`@("`@(%1H92!T96UP;W)A<GD@9FEL
M92!C;VYT86EN:6YG('1H92!D871A('1O(&)E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1O<F5D+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&%U=&]C<F5A=&4@($%U=&]M871I8V%L;'D@8W)E871E(&1I<F5C=&]R
M:65S/PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E*"1P871H+"`D;F%M92P@)'1M<$9I;&4L
M("1A=71O8W)E871E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(4!I<U]D
M:7(H)'1H:7,M/E]G971.871I=F50871H*"1P871H*2DI('L*("`@("`@("`@
M("`@:68@*"1A=71O8W)E871E*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@
M)'1H:7,M/F%U=&]C<F5A=&50871H*"1P871H*3L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E9&4R!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(BDI
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H
M:7,M/E]C:&5C:U%U;W1A5W)I=&4H)V9I;&4G+"`D=&UP1FEL92D["B`@("`@
M("`@:68@*&ES7V$H)')E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@("\O(%-I;F-E('=E
M(&%L<F5A9'D@:&%V92!T:&4@9&%T82!I;B!A(&9I;&4L(&1O;B=T(')E860@
M:70*("`@("`@("`O+R!I;G1O(%!(4"=S(&UE;6]R>2!A="!A;&P@+2!J=7-T
M(&-O<'DH*2!I="!T;R!T:&4@;F5W"B`@("`@("`@+R\@;&]C871I;VXN(%=E
M(&QE879E(&ET('1O('1H92!C86QL97(@=&\@8VQE86X@=7`@=&AE"B`@("`@
M("`@+R\@=&5M<&]R87)Y(&9I;&4L('-O('=E(&1O;B=T('5S92!R96YA;64H
M*2X*("`@("`@("!I9B`H0&-O<'DH)'1M<$9I;&4L("1T:&ES+3Y?9V5T3F%T
M:79E4&%T:"@D<&%T:"P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@
M=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@=W)I=&4@5D93(&9I;&4@*&-O
M<'DH*2!F86EL960I+B(I*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!-;W9E<R!A(&9I;&4@:6X@=&AE(&1A=&%B87-E(&%N9"!T:&4@9FEL
M92!S>7-T96TN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M5&AE('!A=&@@=&\@<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1N86UE("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&UO=F4H)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@("`@("`D;W)I
M9R`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E*"1O<FEG*2`N
M("<O/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D-A;FYO="!M;W9E(&9I;&4H<RD@+2!D97-T:6YA=&EO
M;B!I<R!W:71H:6X@<V]U<F-E+B(I*3L*("`@("`@("!]"@H@("`@("`@("1F
M:6QE0VAE8VL@/2`D=&AI<RT^;&ES=$9O;&1E<B@D9&5S="P@9F%L<V4I.PH@
M("`@("`@(&9O<F5A8V@@*"1F:6QE0VAE8VL@87,@)&9I;&4I('L*("`@("`@
M("`@("`@:68@*"1F:6QE6R=N86UE)UT@/3T@)&YA;64I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T;R!M
M;W9E(%9&4R!F:6QE+B(I*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@:68@*"%`<F5N86UE*"1O<FEG+"`D=&AI<RT^7V=E=$YA=&EV95!A
M=&@H)&1E<W0L("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&UO=F4@5D93(&9I;&4N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;W!I97,@82!F:6QE('1H<F]U9V@@=&AE(&)A8VME;F0N"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@5&AE('!A=&@@=&\@
M<W1O<F4@=&AE(&9I;&4@:6XN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("!4:&4@9FEL96YA;64@=&\@=7-E+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9&5S="`@5&AE(&1E<W1I;F%T:6]N(&]F('1H92!F:6QE+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O<'DH)'!A=&@L("1N86UE+"`D9&5S="D*("`@('L*("`@("`@("`D;W)I
M9R`]("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@D<&%T:"P@)&YA;64I.PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"=\7B<@+B!P<F5G7W%U;W1E*"1O<FEG*2`N
M("<O/R1\)RP@)&1E<W0I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(D-A;FYO="!C;W!Y(&9I;&4H<RD@+2!S;W5R8V4@86YD
M(&1E<W1I;F%T:6]N(&%R92!T:&4@<V%M92XB*2D["B`@("`@("`@?0H*("`@
M("`@("`D9FEL94-H96-K(#T@)'1H:7,M/FQI<W1&;VQD97(H)&1E<W0L(&9A
M;'-E*3L*("`@("`@("!F;W)E86-H("@D9FEL94-H96-K(&%S("1F:6QE*2![
M"B`@("`@("`@("`@(&EF("@D9FEL95LG;F%M92==(#T]("1N86UE*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B
M;&4@=&\@8V]P>2!61E,@9FEL92XB*2D["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@(&EF("@A0&-O<'DH)&]R:6<L("1T:&ES+3Y?9V5T3F%T
M:79E4&%T:"@D9&5S="P@)&YA;64I*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@8V]P>2!61E,@9FEL92XB
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-T;W)E(&$@9FEL92!I;B!T:&4@5D93(&9R;VT@<F%W
M(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@("`@
M("`@(%1H92!P871H('1O('-T;W)E('1H92!F:6QE(&EN+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;F%M92`@("`@("`@(%1H92!F:6QE;F%M92!T;R!U<V4N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("`@("`@("`@5&AE(&9I;&4@
M9&%T82X*("`@("`J($!P87)A;2!B;V]L96%N("1A=71O8W)E871E("!!=71O
M;6%T:6-A;&QY(&-R96%T92!D:7)E8W1O<FEE<S\*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET
M941A=&$H)'!A=&@L("1N86UE+"`D9&%T82P@)&%U=&]C<F5A=&4@/2!T<G5E
M*0H@("`@>PH@("`@("`@(&EF("@A0&ES7V1I<B@D=&AI<RT^7V=E=$YA=&EV
M95!A=&@H)'!A=&@I*2D@>PH@("`@("`@("`@("!I9B`H)&%U=&]C<F5A=&4I
M('L*("`@("`@("`@("`@("`@("1R97,@/2`D=&AI<RT^875T;V-R96%T95!A
M=&@H)'!A=&@I.PH@("`@("`@("`@("`@("`@:68@*&ES7V$H)')E<RP@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B5D93(&1I
M<F5C=&]R>2!D;V5S(&YO="!E>&ES="XB*2D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("\O(%1R96%T(&%N(&%T=&5M<'0@=&\@=W)I=&4@
M86X@96UP='D@9FEL92!A<R!A('1O=6-H*"D@8V%L;"P*("`@("`@("`O+R!S
M:6YC92!O=&AE<G=I<V4@=&AE(&9I;&4@=VEL;"!N;W0@8F4@8W)E871E9"!A
M="!A;&PN"B`@("`@("`@:68@*"%S=')L96XH)&1A=&$I*2!["B`@("`@("`@
M("`@(&EF("A`=&]U8V@H)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D
M;F%M92DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*%\H(E5N86)L92!T;R!C<F5A=&4@96UP='D@5D93(&9I;&4N
M(BDI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@
M)'1H:7,M/E]C:&5C:U%U;W1A5W)I=&4H)W-T<FEN9R<L("1D871A*3L*("`@
M("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*"B`@("`@("`@+R\@3W1H97)W
M:7-E('=E(&=O(&%H96%D(&%N9"!T<GD@=&\@=W)I=&4@;W5T('1H92!F:6QE
M+@H@("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V=E=$YA=&EV95!A=&@H
M)'!A=&@L("1N86UE*2P@)W<G*3L*("`@("`@("!I9B`H(21F<"D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@
M;W!E;B!61E,@9FEL92!F;W(@=W)I=&EN9RXB*2D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(4!F=W)I=&4H)&9P+"`D9&%T82DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O('=R:71E(%9&
M4R!F:6QE(&1A=&$N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F:6QE(&9R;VT@
M=&AE(%9&4RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1P871H("!4
M:&4@<&%T:"!T;R!S=&]R92!T:&4@9FEL92!I;BX*("`@("`J($!P87)A;2!S
M=')I;F<@)&YA;64@(%1H92!F:6QE;F%M92!T;R!U<V4N"B`@("`@*@H@("`@
M("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9&5L971E1FEL92@D<&%T:"P@)&YA;64I"B`@("!["B`@("`@("`@)')E<R`]
M("1T:&ES+3Y?8VAE8VM1=6]T841E;&5T92@D<&%T:"P@)&YA;64I.PH@("`@
M("`@(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@("`@("!I9B`H(4!U;FQI
M;FLH)'1H:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DI*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E5N86)L92!T
M;R!D96QE=&4@5D93(&9I;&4N(BDI.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$96QE=&4@82!F;VQD
M97(@9G)O;2!T:&4@5D93+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'!A=&@@("`@("`@(%1H92!P871H('1O(&1E;&5T92!T:&4@9F]L9&5R(&9R
M;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@("!4:&4@9F]L
M9&5R;F%M92!T;R!U<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<F5C=7)S
M:79E("!&;W)C92!A(')E8W5R<VEV92!D96QE=&4_"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!4<G5E(&]N('-U8V-E<W,@;W(@82!014%27T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D96QE
M=&5&;VQD97(H)'!A=&@L("1N86UE+"`D<F5C=7)S:79E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"1R96-U<G-I=F4I('L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YE;7!T>49O;&1E<B@D<&%T:"`N("<O)R`N("1N86UE
M*3L*("`@("`@("`@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&ES="`]("1T
M:&ES+3YL:7-T1F]L9&5R*"1P871H("X@)R\G("X@)&YA;64I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D;&ES="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1L:7-T.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("AC;W5N="@D;&ES="DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T
M92`E<RP@=&AE(&1I<F5C=&]R>2!I<R!N;W0@96UP='DB*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A=&@@
M+B`G+R<@+B`D;F%M92DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H(4!R;61I<B@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L
M("1N86UE*2DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H7R@B56YA8FQE('1O(&1E;&5T92!61E,@9&ER96-T;W)Y+B(I*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0W)E871E<R!A(&9O;&1E<B!O;B!T:&4@5D93+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!P871H('1O(&1E;&5T92!T
M:&4@9F]L9&5R(&9R;VTN"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("!4
M:&4@9F]L9&5R;F%M92!T;R!U<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"`@5')U92!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E1F]L9&5R
M*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!I9B`H(4!M:V1I<B@D=&AI
M<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA8FQE('1O(&-R96%T
M92!61E,@9&ER96-T;W)Y+B(I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@82!G:79E
M;B!P871H;F%M92!I<R!A(&9O;&1E<BX*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1P871H("!4:&4@<&%T:"!T;R!T:&4@9F]L9&5R+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(&9I;&4O9F]L9&5R(&YA;64N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF(&ET(&ES(&$@
M9F]L9&5R+"!F86QS92!O=&AE<G=I<V4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&ES1F]L9&5R*"1P871H+"`D;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M0&ES7V1I<B@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)'!A=&@L("1N86UE*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S('!E<FUI<W-I;VYS(&9O
M<B!A;B!I=&5M(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%T:"`@("`@("`@(%1H92!P871H(&]F(&1I<F5C=&]R>2!O9B!T
M:&4@:71E;2X*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@("`@("`@("!4
M:&4@;F%M92!O9B!T:&4@:71E;2X*("`@("`J($!P87)A;2!I;G1E9V5R("1P
M97)M:7-S:6]N("!4:&4@;V-T86P@=F%L=64@;V8@=&AE(&YE=R!P97)M:7-S
M:6]N+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1R=64@;VX@<W5C
M8V5S<R!O<B!A(%!%05)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-H86YG95!E<FUI<W-I;VYS*"1P871H+"`D;F%M
M92P@)'!E<FUI<W-I;VXI"B`@("!["B`@("`@("`@:68@*"%`8VAM;V0H)'1H
M:7,M/E]G971.871I=F50871H*"1P871H+"`D;F%M92DL("1P97)M:7-S:6]N
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I
M;G1F*%\H(E5N86)L92!T;R!C:&%N9V4@<&5R;6ES<VEO;B!F;W(@5D93(&9I
M;&4@)7,O)7,N(BDL("1P871H+"`D;F%M92DI.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@
M82!L:7-T(&]F('1H92!C;VYT96YT<R!O9B!A(&9O;&1E<BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P871H("`@("`@(%1H92!P871H(&]F('1H
M92!D:7)E8W1O<GDN"B`@("`@*B!`<&%R86T@;6EX960@)&9I;'1E<B`@("`@
M(%-T<FEN9R]H87-H('1O(&9I;'1E<B!F:6QE+V1I<FYA;64@;VXN"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`D9&]T9FEL97,@(%-H;W<@9&]T9FEL97,_"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B`D9&ER;VYL>2`@(%-H;W<@;VYL>2!D:7)E
M8W1O<FEE<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!&:6QE(&QI
M<W0@;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VQI<W1&;VQD97(H)'!A=&@L("1F:6QT97(@/2!N=6QL
M+"`D9&]T9FEL97,@/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1I<F]N;'D@/2!F86QS92D*("`@('L*("`@("`@("`D9FEL97,@/2!A<G)A
M>2@I.PH@("`@("`@("1P871H(#T@:7-S970H)'!A=&@I(#\@)'1H:7,M/E]G
M971.871I=F50871H*"1P871H*2`Z("1T:&ES+3Y?9V5T3F%T:79E4&%T:"@I
M.PH*("`@("`@("!I9B`H(4!I<U]D:7(H)'!A=&@I*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(DYO="!A(&1I<F5C=&]R>2(I
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&-H9&ER*"1P871H*2D@>PH@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@
M=&\@86-C97-S(%9&4R!D:7)E8W1O<GDN(BDI.PH@("`@("`@('T*"B`@("`@
M("`@)&AA;F1L92`](&]P96YD:7(H)'!A=&@I.PH@("`@("`@('=H:6QE("@H
M)&5N=')Y(#T@<F5A9&1I<B@D:&%N9&QE*2D@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("\O($9I;'1E<B!O=70@)RXG(&%N9"`G+BXG(&5N=')I97,N"B`@
M("`@("`@("`@(&EF("@D96YT<GD@/3T@)RXG('Q\("1E;G1R>2`]/2`G+BXG
M*2!["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@1FEL=&5R(&]U="!D;W1F:6QE<R!I9B!T:&5Y(&%R
M96XG="!W86YT960N"B`@("`@("`@("`@(&EF("@A)&1O=&9I;&5S("8F('-U
M8G-T<B@D96YT<GDL(#`L(#$I(#T]("<N)RD@>PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($9I;&4@
M;F%M90H@("`@("`@("`@("`D9FEL95LG;F%M92==(#T@)&5N=')Y.PH*("`@
M("`@("`@("`@+R\@56YI>"!S='EL92!F:6QE('!E<FUI<W-I;VYS"B`@("`@
M("`@("`@("1F:6QE6R=P97)M<R==(#T@)'1H:7,M/E]G9715;FEX4&5R;7,H
M9FEL97!E<FUS*"1E;G1R>2DI.PH*("`@("`@("`@("`@+R\@3W=N97(*("`@
M("`@("`@("`@)&9I;&5;)V]W;F5R)UT@/2!F:6QE;W=N97(H)&5N=')Y*3L*
M("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G<&]S:7A?9V5T<'=U
M:60G*2D@>PH@("`@("`@("`@("`@("`@)&]W;F5R(#T@<&]S:7A?9V5T<'=U
M:60H)&9I;&5;)V]W;F5R)UTI.PH@("`@("`@("`@("`@("`@)&9I;&5;)V]W
M;F5R)UT@/2`D;W=N97);)VYA;64G73L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@1W)O=7`*("`@("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2!F
M:6QE9W)O=7`H)&5N=')Y*3L*("`@("`@("`@("`@:68@*&9U;F-T:6]N7V5X
M:7-T<R@G<&]S:7A?9V5T9W)G:60G*2D@>PH@("`@("`@("`@("`@("`@)&=R
M;W5P(#T@<&]S:7A?9V5T9W)G:60H)&9I;&5;)V=R;W5P)UTI.PH@("`@("`@
M("`@("`@("`@)&9I;&5;)V=R;W5P)UT@/2`D9W)O=7!;)VYA;64G73L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4VEZ90H@("`@("`@("`@("`D
M9FEL95LG<VEZ92==(#T@9FEL97-I>F4H)&5N=')Y*3L*"B`@("`@("`@("`@
M("\O($1A=&4*("`@("`@("`@("`@)&9I;&5;)V1A=&4G72`](&9I;&5M=&EM
M92@D96YT<GDI.PH*("`@("`@("`@("`@+R\@5'EP90H@("`@("`@("`@("!I
M9B`H0&ES7V1I<B@D96YT<GDI("8F("%I<U]L:6YK*"1E;G1R>2DI('L*("`@
M("`@("`@("`@("`@("1F:6QE6R=P97)M<R==(#T@)V0G("X@)&9I;&5;)W!E
M<FUS)UT["B`@("`@("`@("`@("`@("`D9FEL95LG='EP92==(#T@)RHJ9&ER
M)SL*("`@("`@("`@("`@("`@("1F:6QE6R=S:7IE)UT@/2`M,3L*("`@("`@
M("`@("`@?2!E;'-E:68@*&ES7VQI;FLH)&5N=')Y*2D@>PH@("`@("`@("`@
M("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G;"<@+B`D9FEL95LG<&5R;7,G73L*
M("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BIS>6TG.PH@("`@
M("`@("`@("`@("`@)&9I;&5;)VQI;FLG72`](')E861L:6YK*"1E;G1R>2D[
M"B`@("`@("`@("`@("`@("`D9FEL95LG;&EN:W1Y<&4G72`]("<J*FYO;F4G
M.PH@("`@("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE6R=L:6YK
M)UTI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V1I<B@D9FEL95LG
M;&EN:R==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95LG;&EN
M:W1Y<&4G72`]("<J*F1I<B<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&ES7VQI;FLH)&9I;&5;)VQI;FLG72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G*BIS>6TG.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<U]F:6QE*"1F:6QE6R=L:6YK)UTI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1E>'0@/2!E>'!L;V1E*"<N
M)RP@)&9I;&5;)VQI;FLG72D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A*&-O=6YT*"1E>'0I(#T](#$@?'P@*"1E>'1;,%T@/3T]("<G("8F(&-O
M=6YT*"1E>'0I(#T](#(I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&9I;&5;)VQI;FMT>7!E)UT@/2!61E,Z.G-T<G1O;&]W97(H)&5X=%MC
M;W5N="@D97AT*2`M(#%=*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&5;)VQI;FMT>7!E)UT@/2`G*BIB
M<F]K96XG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V5I
M9B`H:7-?9FEL92@D96YT<GDI*2!["B`@("`@("`@("`@("`@("`D9FEL95LG
M<&5R;7,G72`]("<M)R`N("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@
M("`@)&5X="`](&5X<&QO9&4H)RXG+"`D96YT<GDI.PH*("`@("`@("`@("`@
M("`@(&EF("AC;W5N="@D97AT*2`]/2`Q('Q\("AS=6)S='(H)&9I;&5;)VYA
M;64G72P@,"P@,2D@/3T]("<N)R`F)B!C;W5N="@D97AT*2`]/2`R*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1F:6QE6R=T>7!E)UT@/2`G*BIN;VYE)SL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)W1Y<&4G72`](%9&4SHZ<W1R=&]L;W=E<B@D97AT6V-O=6YT*"1E
M>'0I("T@,5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&9I;&5;)W1Y<&4G72`]("<J*FYO;F4G
M.PH@("`@("`@("`@("`@("`@:68@*"AF:6QE<&5R;7,H)&5N=')Y*2`F(#!X
M0S`P,"D@/3T@,'A#,#`P*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5;
M)W!E<FUS)UT@/2`G<R<@+B`D9FEL95LG<&5R;7,G73L*("`@("`@("`@("`@
M("`@('T@96QS96EF("@H9FEL97!E<FUS*"1E;G1R>2D@)B`P>#8P,#`I(#T]
M(#!X-C`P,"D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE6R=P97)M<R==
M(#T@)V(G("X@)&9I;&5;)W!E<FUS)UT["B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H*&9I;&5P97)M<R@D96YT<GDI("8@,'@R,#`P*2`]/2`P>#(P,#`I
M('L*("`@("`@("`@("`@("`@("`@("`D9FEL95LG<&5R;7,G72`]("=C)R`N
M("1F:6QE6R=P97)M<R==.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"AF
M:6QE<&5R;7,H)&5N=')Y*2`F(#!X,3`P,"D@/3T@,'@Q,#`P*2!["B`@("`@
M("`@("`@("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G<"<@+B`D9FEL95LG
M<&5R;7,G73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&9I;&5;)W!E<FUS)UT@/2`G/R<@+B`D9FEL95LG<&5R;7,G
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@+R\@1FEL=&5R:6YG+@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]F:6QT
M97)-871C:"@D9FEL=&5R+"`D9FEL95LG;F%M92==*2D@>PH@("`@("`@("`@
M("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1D:7)O;FQY("8F("1F
M:6QE6R=T>7!E)UT@(3T]("<J*F1I<B<I('L*("`@("`@("`@("`@("`@('5N
M<V5T*"1F:6QE*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D9FEL97-;)&9I;&5;)VYA;64G75T@/2`D
M9FEL93L*("`@("`@("`@("`@=6YS970H)&9I;&4I.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@82!S;W)T960@;&ES="!O9B!F;VQD97)S(&EN('-P96-I9FEE9"!D
M:7)E8W1O<GDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"`@
M("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@=&\@9V5T('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1I<F5C=&]R>2!L
M:7-T(&9O<BX*("`@("`J($!P87)A;2!M:7AE9"`D9FEL=&5R("`@("`@("!(
M87-H(&]F(&ET96US('1O(&9I;'1E<B!B87-E9"!O;B!F;VQD97)L:7-T+@H@
M("`@("H@0'!A<F%M(&)O;VQE86X@)&1O=&9O;&1E<G,@($EN8VQU9&4@9&]T
M9F]L9&5R<S\*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!&;VQD97(@
M;&ES="!O;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@;&ES=$9O;&1E<G,H)'!A=&@@
M/2`G)RP@)&9I;'1E<B`](&YU;&PL("1D;W1F;VQD97)S(#T@=')U92D*("`@
M('L*("`@("`@("`D8V]N;B`]("1T:&ES+3Y?8V]N;F5C="@I.PH@("`@("`@
M(&EF("AI<U]A*"1C;VYN+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M(')E='5R;B`D8V]N;CL*("`@("`@("!]"@H@("`@("`@("1F;VQD97)S(#T@
M87)R87DH*3L*("`@("`@("`D9F]L9&5R<UMD:7)N86UE*"1P871H*5T@/2!A
M<G)A>2@G=F%L)R`]/B!D:7)N86UE*"1P871H*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G86)B<F5V)R`]/B`G+BXG+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L86)E
M;"<@/3X@)RXN)RD["@H@("`@("`@("1F;VQD97),:7-T(#T@)'1H:7,M/FQI
M<W1&;VQD97(H)'!A=&@L(&YU;&PL("1D;W1F;VQD97)S+"!T<G5E*3L*("`@
M("`@("!I9B`H:7-?82@D9F]L9&5R3&ES="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&9O;&1E<DQI<W0["B`@("`@("`@?0H*("`@
M("`@("!F;W)E86-H("@D9F]L9&5R3&ES="!A<R`D;F%M92`]/B`D9FEL97,I
M('L*("`@("`@("`@("`@)&9O;&1E<G-;)&YA;65=(#T@87)R87DH)W9A;"<@
M/3X@)'!A=&@@+B`G+R<@+B`D9FEL97-;)VYA;64G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%B8G)E=B<@/3X@)&9I;&5S6R=N
M86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L
M86)E;"<@/3X@)'!A=&@@+B`G+R<@+B`D9FEL97-;)VYA;64G72D["B`@("`@
M("`@?0H*("`@("`@("!K<V]R="@D9F]L9&5R<RD["@H@("`@("`@(')E='5R
M;B`D9F]L9&5R<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!5;FEX
M('-T>6QE('!E<FUS+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1P97)M<R`@5&AE('!E<FUI
M<W-I;VYS('1O('-E="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M56YI>"!S='EL92!P97)M<RX*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%5N
M:7A097)M<R@D<&5R;7,I"B`@("!["B`@("`@("`@+R\@1&5T97)M:6YE('!E
M<FUI<W-I;VYS"B`@("`@("`@)&]W;F5R6R=R96%D)UT@("`@/2`H)'!E<FUS
M("8@,#`T,#`I(#\@)W(G(#H@)RTG.PH@("`@("`@("1O=VYE<ELG=W)I=&4G
M72`@(#T@*"1P97)M<R`F(#`P,C`P*2`_("=W)R`Z("<M)SL*("`@("`@("`D
M;W=N97);)V5X96-U=&4G72`]("@D<&5R;7,@)B`P,#$P,"D@/R`G>"<@.B`G
M+2<["B`@("`@("`@)&=R;W5P6R=R96%D)UT@("`@/2`H)'!E<FUS("8@,#`P
M-#`I(#\@)W(G(#H@)RTG.PH@("`@("`@("1G<F]U<%LG=W)I=&4G72`@(#T@
M*"1P97)M<R`F(#`P,#(P*2`_("=W)R`Z("<M)SL*("`@("`@("`D9W)O=7!;
M)V5X96-U=&4G72`]("@D<&5R;7,@)B`P,#`Q,"D@/R`G>"<@.B`G+2<["B`@
M("`@("`@)'=O<FQD6R=R96%D)UT@("`@/2`H)'!E<FUS("8@,#`P,#0I(#\@
M)W(G(#H@)RTG.PH@("`@("`@("1W;W)L9%LG=W)I=&4G72`@(#T@*"1P97)M
M<R`F(#`P,#`R*2`_("=W)R`Z("<M)SL*("`@("`@("`D=V]R;&1;)V5X96-U
M=&4G72`]("@D<&5R;7,@)B`P,#`P,2D@/R`G>"<@.B`G+2<["@H@("`@("`@
M("\O($%D:G5S="!F;W(@4U5)1"P@4T=)1"!A;F0@<W1I8VMY(&)I=`H@("`@
M("`@(&EF("@D<&5R;7,@)B`P>#@P,"D@>PH@("`@("`@("`@("`D;W=N97);
M)V5X96-U=&4G72`]("@D;W=N97);)V5X96-U=&4G72`]/2`G>"<I(#\@)W,G
M(#H@)U,G.PH@("`@("`@('T*("`@("`@("!I9B`H)'!E<FUS("8@,'@T,#`I
M('L*("`@("`@("`@("`@)&=R;W5P6R=E>&5C=71E)UT@/2`H)&=R;W5P6R=E
M>&5C=71E)UT@/3T@)W@G*2`_("=S)R`Z("=3)SL*("`@("`@("!]"B`@("`@
M("`@:68@*"1P97)M<R`F(#!X,C`P*2!["B`@("`@("`@("`@("1W;W)L9%LG
M97AE8W5T92==(#T@*"1W;W)L9%LG97AE8W5T92==(#T]("=X)RD@/R`G="<@
M.B`G5"<["B`@("`@("`@?0H*("`@("`@("`D=6YI>%!E<FUS(#T@)&]W;F5R
M6R=R96%D)UT@+B`D;W=N97);)W=R:71E)UT@+B`D;W=N97);)V5X96-U=&4G
M72`N"B`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG<F5A9"==("X@)&=R
M;W5P6R=W<FET92==("X@)&=R;W5P6R=E>&5C=71E)UT@+@H@("`@("`@("`@
M("`@("`@("`@("`D=V]R;&1;)W)E860G72`N("1W;W)L9%LG=W)I=&4G72`N
M("1W;W)L9%LG97AE8W5T92==.PH*("`@("`@("!R971U<FX@)'5N:7A097)M
M<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E;F%M92!A(&9I;&4@;W(@9F]L
M9&5R(&EN('1H92!61E,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M;VQD<&%T:"`@5&AE(&]L9"!P871H('1O('1H92!F:6QE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;VQD;F%M92`@5&AE(&]L9"!F:6QE;F%M92X*("`@("`J
M($!P87)A;2!S=')I;F<@)&YE=W!A=&@@(%1H92!N97<@<&%T:"!O9B!T:&4@
M9FEL92X*("`@("`J($!P87)A;2!S=')I;F<@)&YE=VYA;64@(%1H92!N97<@
M9FEL96YA;64N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O
M;B!S=6-C97-S(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5N86UE*"1O;&1P871H+"`D;VQD;F%M
M92P@)&YE=W!A=&@L("1N97=N86UE*0H@("`@>PH@("`@("`@(&EF("@A0&ES
M7V1I<B@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&YE=W!A=&@I*2D@>PH@("`@
M("`@("`@("!I9B`H:7-?82@D<F5S(#T@)'1H:7,M/F%U=&]C<F5A=&50871H
M*"1N97=P871H*2P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(&EF("@A0')E;F%M92@D=&AI<RT^7V=E=$YA=&EV95!A=&@H)&]L9'!A=&@L
M("1O;&1N86UE*2P*("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971.
M871I=F50871H*"1N97=P871H+"`D;F5W;F%M92DI*2!["B`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B56YA8FQE('1O
M(')E;F%M92!61E,@9FEL92`E<R\E<RXB*2P@)&]L9'!A=&@L("1O;&1N86UE
M*2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A(&9U;&P@9FEL96YA;64@;VX@=&AE(&YA
M=&EV92!F:6QE<WES=&5M+"!F<F]M(&$@5D93"B`@("`@*B!P871H(&%N9"!N
M86UE+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A=&@@(%1H92!61E,@9FEL92!P871H+@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE(%9&4R!F:6QE;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE(&9U;&P@;F%T:79E
M(&9I;&5N86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5T3F%T:79E4&%T
M:"@D<&%T:"`]("<G+"`D;F%M92`]("<G*0H@("`@>PH@("`@("`@("1N86UE
M(#T@8F%S96YA;64H)&YA;64I.PH@("`@("`@(&EF("@A96UP='DH)&YA;64I
M*2!["B`@("`@("`@("`@("1N86UE(#T@<W1R7W)E<&QA8V4H)RXN)RP@)R<L
M("1N86UE*3L*("`@("`@("`@("`@:68@*'-U8G-T<B@D;F%M92P@,"P@,2D@
M(3T@)R\G*2!["B`@("`@("`@("`@("`@("`D;F%M92`]("<O)R`N("1N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y
M*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P87)A
M;7-;)VAO;64G72D@)B8*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)WQ>
M?B\_*"XJ*21\)RP@)'!A=&@L("1M871C:&5S*2D@>PH@("`@("`@("`@("`@
M("`@)'!A=&@@/2`D=&AI<RT^7W!A<F%M<ULG:&]M92==("X@)R\G("X@)&UA
M=&-H97-;,5T["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1P871H(#T@
M<W1R7W)E<&QA8V4H)RXN)RP@)R<L("1P871H*3L*("`@("`@("`@("`@:68@
M*'-U8G-T<B@D<&%T:"P@,"P@,2D@/3T@)R\G*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72`N("1P871H("X@
M)&YA;64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72`N("<O)R`N("1P871H
M("X@)&YA;64["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]P87)A;7-;)W9F<W)O;W0G72`N("1N
M86UE.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-T=6(@=&\@
M8VAE8VL@:68@=V4@:&%V92!A('9A;&ED(&-O;FYE8W1I;VXN($UA:V5S('-U
M<F4@=&AA=`H@("`@("H@=&AE('9F<W)O;W0@:7,@<F5A9&%B;&4N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@5')U92!I9B!V9G-R;V]T(&ES(')E861A8FQE+"!014%27T5R
M<F]R(&EF(&ET(&ES;B=T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C
M="@I"B`@("!["B`@("`@("`@:68@*"A`:7-?9&ER*"1T:&ES+3Y?<&%R86US
M6R=V9G-R;V]T)UTI("8F"B`@("`@("`@("`@("!`:7-?<F5A9&%B;&4H)'1H
M:7,M/E]P87)A;7-;)W9F<W)O;W0G72DI('Q\"B`@("`@("`@("`@($!M:V1I
M<B@D=&AI<RT^7W!A<F%M<ULG=F9S<F]O="==*2D@>PH@("`@("`@("`@("!R
M971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BA?*")5;F%B;&4@=&\@<F5A9"!T:&4@=F9S
M<F]O="!D:7)E8W1O<GDN(BDI.PH@("`@("`@('T*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+U9&4R],:7-T271E;2YP:'``````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`T-3,T(#$P-3$U-#,T,3,V(#`R,3(Q,@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@06X@:71E;2!R971U<FYE9"!F<F]M(&$@9F]L9&5R(&QI<W0N
M"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4R]61E,O3&ES=$ET96TN<&AP
M+'8@,2XQ,2XQ,"XW(#(P,#8O,#4O,S$@,#0Z-3`Z,#(@<VQU<V%R>B!%>'`@
M)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,BTR,#`V($IO;B!7;V]D(#QJ;VY`:F5L
M;'EB;V(N8V\N=6L^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*;VX@
M5V]O9"`\:F]N0&IE;&QY8F]B+F-O+G5K/@H@*B!`<&%C:V%G92!61E,*("HO
M"F-L87-S(%9&4U],:7-T271E;2!["@H@("`@+RHJ"B`@("`@*B!61E,@<&%T
M:`H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7W!A=&@["@H@("`@+RHJ"B`@("`@*B!&:6QE;F%M90H@("`@("H*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VYA;64["@H@("`@+RHJ
M"B`@("`@*B!&:6QE('!E<FUI<W-I;VYS("@J;FEX(&9O<FUA=#H@9')W>')W
M>')W>"D*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)%]P97)M<SL*"B`@("`O*BH*("`@("`J($]W;F5R('5S97(*("`@("`J
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]O=VYE<CL*
M"B`@("`O*BH*("`@("`J($]W;F5R(&=R;W5P"B`@("`@*@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9W)O=7`["@H@("`@+RHJ"B`@
M("`@*B!3:7IE+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7W-I>F4["@H@("`@+RHJ"B`@("`@*B!,87-T(&UO9&EF:65D
M(&1A=&4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?9&%T93L*"B`@("`O*BH*("`@("`J(%1Y<&4*("`@("`J("`@+BH@
M("`@("`M+2`@1FEL92!E>'1E;G-I;VX*("`@("`J("`@*BIN;VYE("`M+2`@
M56YR96-O9VYI>F5D('1Y<&4*("`@("`J("`@*BIS>6T@("`M+2`@4WEM;&EN
M:PH@("`@("H@("`J*F1I<B`@("TM("!$:7)E8W1O<GD*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T>7!E.PH*("`@("\J
M*@H@("`@("H@5'EP92!O9B!T87)G970@:68@='EP92!I<R`G*BIS>6TG+@H@
M("`@("H@3D(N($YO="!A;&P@8F%C:V5N9',@87)E(&-A<&%B;&4@;V8@9&ES
M=&EN9W5I<VAI;F<@86QL(&]F('1H97-E+@H@("`@("H@("`N*B`@("`@("`@
M+2T@($9I;&4@97AT96YS:6]N"B`@("`@*B`@("HJ;F]N92`@("`M+2`@56YR
M96-O9VYI>F5D('1Y<&4*("`@("`J("`@*BIS>6T@("`@("TM("!3>6UL:6YK
M('1O(&$@<WEM;&EN:PH@("`@("H@("`J*F1I<B`@("`@+2T@($1I<F5C=&]R
M>0H@("`@("H@("`J*F)R;VME;B`@+2T@(%1A<F=E="!N;W0@9F]U;F0@+2!B
M<F]K96X@;&EN:PH@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D7VQI;FMT>7!E.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M;W(*("`@("`J"B`@("`@*B!297%U:7)E<R!T:&4@<&%T:"!T;R!T:&4@9FEL
M92P@86YD(&ET)W,@87)R87D@;V8@<')O<&5R=&EE<RP*("`@("`J(')E='5R
M;F5D(&9R;VT@82!S=&%N9&%R9"!61E,Z.FQI<W1&;VQD97(H*2!C86QL+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'!A=&@@("`@("!4:&4@<&%T
M:"!T;R!T:&4@9FEL92X*("`@("`J($!P87)A;2!A<G)A>2`D9FEL94%R<F%Y
M("!!;B!A<G)A>2!O9B!F:6QE('!R;W!E<G1I97,N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%9&4U],:7-T271E;2@D<&%T:"P@)&9I;&5!<G)A>2D*("`@('L*
M("`@("`@("`D=&AI<RT^7W!A=&@@/2`D<&%T:"`N("<O)R`N("1F:6QE07)R
M87E;)VYA;64G73L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D9FEL94%R<F%Y
M6R=N86UE)UT["B`@("`@("`@)'1H:7,M/E]D:7)N86UE(#T@)'!A=&@["B`@
M("`@("`@)'1H:7,M/E]P97)M<R`]("1F:6QE07)R87E;)W!E<FUS)UT["B`@
M("`@("`@)'1H:7,M/E]O=VYE<B`]("1F:6QE07)R87E;)V]W;F5R)UT["B`@
M("`@("`@)'1H:7,M/E]G<F]U<"`]("1F:6QE07)R87E;)V=R;W5P)UT["B`@
M("`@("`@)'1H:7,M/E]S:7IE(#T@)&9I;&5!<G)A>5LG<VEZ92==.PH@("`@
M("`@("1T:&ES+3Y?9&%T92`]("1F:6QE07)R87E;)V1A=&4G73L*("`@("`@
M("`D=&AI<RT^7W1Y<&4@/2`D9FEL94%R<F%Y6R=T>7!E)UT["B`@("`@("`@
M)'1H:7,M/E]L:6YK='EP92`]("1F:6QE07)R87E;)VQI;FMT>7!E)UT["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$]U='!U=%-T
M<F%T96=Y````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,V(#`R-#,T,``@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5D93+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>0``````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S8@,#(T,3,W`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2YP:'``
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-3,U-2`Q,#4Q-30S-#$S-B`P,C4Q-#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J*@H@*B!%;F-A<'-U;&%T92!S=')A=&5G:65S(&9O<B!A8FEL:71Y
M('1O('=R:71E(&]U='!U="!T;R!R96%L(&9I;&4N"B`J"B`J("1(;W)D93H@
M9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713
M=')A=&5G>2YP:'`L=B`Q+C$N."XW(#(P,#8O,#$O,#$@,C$Z,C@Z-#,@:F%N
M($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L($Q,
M0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES
M+F-O;3X*("H@0'!A8VMA9V4@5D937TE33PH@*B!`<VEN8V4@("!(;W)D92`S
M+C`*("HO"F-L87-S(%9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y
M('L*"B`@("`O*BH*("`@("`J(%1H92!61E,@=&\@=VAI8V@@=V4@=VEL;"!W
M<FET92!T:&4@9FEL92X*("`@("`J"B`@("`@*B!`=F%R(%9&4PH@("`@("HO
M"B`@("!V87(@)%]T87)G97169G,["@H@("`@+RHJ"B`@("`@*B!7:&5R92!T
M;R!S=&]R92!T:&4@9FEL92!I;B!T:&4@5D93+@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=$9I;&4["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!O
M8FIE8W0@)B1T87)G97169G,@("`@("`@(%1H92!61E,@=&\@=VAI8V@@=V4@
M=VEL;"!W<FET92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9I;&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T87)G971&
M:6QE("`@("`@("!4:&4@<&%T:"!A;F0@;F%M92!O9B!F:6QE('1O('=R:71E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!61E-?25-/5W)I=&5R7U)E86Q/=71P
M=713=')A=&5G>2@F)'1A<F=E=%9F<RP@)'1A<F=E=$9I;&4I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]T87)G97169G,@/2`F)'1A<F=E=%9F<SL*("`@("`@
M("`D=&AI<RT^7W1A<F=E=$9I;&4@/2`D=&%R9V5T1FEL93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E;&5C="!A;F0@8W)E871E(&$@8V]N8W)E=&4@<W1R
M871E9WD@9F]R('5S:6YG(&$@<F5A;"!O=71P=70@9FEL92X*("`@("`J"B`@
M("`@*B!`<&%R86T@;V)J96-T("8D=&%R9V5T5F9S("`@("`@("!4:&4@5D93
M('1O('=H:6-H('=E('=I;&P@=W)I=&4@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R97-U;'0N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1T87)G971&:6QE("`@("`@("!4:&4@<&%T:"!A;F0@9FEL96YA
M;64@;V8@=&AE('1A<F=E=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9FEL92!W:71H:6X@=&AE(%9&4RX*("`@("`J($!R971U
M<FX@;V)J96-T("`@02!C;VYC<F5T92!O=71P=70@<W1R871E9WD@;V)J96-T
M(&]R(%!%05)?17)R;W(@;VX*("`@("`J("`@("`@("`@("`@("`@("`@9F%I
M;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)B1T87)G9716
M9G,L("1T87)G971&:6QE*0H@("`@>PH@("`@("`@(&EF("AS=')T;VQO=V5R
M*&=E=%]C;&%S<R@D=&%R9V5T5F9S*2D@/3T@)W9F<U]F:6QE)RD@>PH@("`@
M("`@("`@("`D;65T:&]D(#T@)V1I<F5C="<["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&UE=&AO9"`]("=C;W!Y)SL*("`@("`@("!]"@H@("`@
M("`@(&EN8VQU9&5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O4F5A;$]U
M='!U=%-T<F%T96=Y+R<@+B`D;65T:&]D("X*("`@("`@("`@("`@("`@("`@
M("`@("<N<&AP)SL*("`@("`@("`D8VQA<W,@/2`G5D937TE33U=R:71E<E]2
M96%L3W5T<'5T4W1R871E9WE?)R`N("1M971H;V0["B`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!L;V%D('-T<F%T
M96=Y(%PB)7-<(BXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;65T:&]D*2D["B`@("`@("`@?0H*("`@("`@("`D
M<W1R871E9WD@/2`F;F5W("1C;&%S<R@D=&%R9V5T5F9S+"`D=&%R9V5T1FEL
M92D["B`@("`@("`@<F5T=7)N("1S=')A=&5G>3L*("`@('T*"B`@("`O*BH*
M("`@("`J($=E="!A(')E86P@9FEL97-Y<W1E;2!F:6QE;F%M92!W92!C86X@
M=W)I=&4@=&\N"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@(%1H92!F:6QE;F%M92!O<B!014%27T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E86Q&:6QE;F%M92@I
M"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B3F]T
M(&EM<&QE;65N=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($EN9&EC
M871E('1H870@=V4G<F4@9&]N92!W<FET:6YG('1O('1H92!R96%L(&9I;&4N
M"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("`@($YU;&P@;W(@4$5!4E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!F:6YI<VAE9"@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H7R@B3F]T(&EM<&QE;65N=&5D+B(I*3L*("`@('T*
M"GT*"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7
M<FET97(O;6MI<V]F<RYP:'``````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`T-S`W(#$P-3$U-#,T,3,V(#`R,C<V-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RHJ"B`J($1R:79E
M<B!F;W(@=7-I;F<@;6MI<V]F<R!F;W(@8W)E871I;F<@25-/(&EM86=E<RX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5D937TE33U=R:71E<B])4T]7<FET
M97(O;6MI<V]F<RYP:'`L=B`Q+C$N."XU(#(P,#8O,#$O,#$@,C$Z,C@Z-#,@
M:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0W)O;F]S>7,L
M($Q,0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO
M<WES+F-O;3X*("H@0'!A8VMA9V4@5D937TE33PH@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("HO"F-L87-S(%9&4U])4T]7<FET97)?;6MI<V]F<R!E>'1E;F1S
M(%9&4U])4T]7<FET97(@>PH*("`@(&9U;F-T:6]N('!R;V-E<W,H*0H@("`@
M>PH@("`@("`@(')E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M4F5A;$EN<'5T4W1R871E9WDN<&AP)SL*("`@("`@("`D:6YP=713=')A=&5G
M>2`]("961E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y.CIF86-T;W)Y
M*"1T:&ES+3Y?<V]U<F-E5F9S+"`D=&AI<RT^7W!A<F%M<ULG<V]U<F-E4F]O
M="==*3L*("`@("`@("!I9B`H:7-?82@D:6YP=713=')A=&5G>2P@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&EN<'5T4W1R871E9WD[
M"B`@("`@("`@?0H*("`@("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)
M3$5?7RD@+B`G+U)E86Q/=71P=713=')A=&5G>2YP:'`G.PH@("`@("`@("1O
M=71P=713=')A=&5G>2`]("961E-?25-/5W)I=&5R7U)E86Q/=71P=713=')A
M=&5G>3HZ9F%C=&]R>2@D=&AI<RT^7W1A<F=E=%9F<RP@)'1H:7,M/E]P87)A
M;7-;)W1A<F=E=$9I;&4G72D["B`@("`@("`@:68@*&ES7V$H)&]U='!U=%-T
M<F%T96=Y+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D
M;W5T<'5T4W1R871E9WD["B`@("`@("`@?0H*("`@("`@("`D8VUD(#T@<W!R
M:6YT9B@G;6MI<V]F<R`M<75I970@+7(@+4H@+6\@)7,@)7,@/B]D978O;G5L
M;"<L"B`@("`@("`@("`@("`@("`@("`@("`@97-C87!E<VAE;&QA<F<H)&]U
M='!U=%-T<F%T96=Y+3YG971296%L1FEL96YA;64H*2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@97-C87!E<VAE;&QA<F<H)&EN<'5T4W1R871E9WDM/F=E
M=%)E86Q0871H*"DI*3L*("`@("`@("`D<F5S(#T@<WES=&5M*"1C;60L("1E
M8RD["@H@("`@("`@("\J($-O=6QD(&)E(&$@;&]T(&]F('-P86-E('5S960N
M("!':79E(&)O=&@@82!C:&%N8V4@=&\@8VQE86X@=7`@979E;@H@("`@("`@
M("`J(&EF(&]N92!E<G)O<G,@;W5T+B`J+PH@("`@("`@("1F:6Y297,Q(#T@
M)&EN<'5T4W1R871E9WDM/F9I;FES:&5D*"D["B`@("`@("`@)&9I;E)E<S(@
M/2`D;W5T<'5T4W1R871E9WDM/F9I;FES:&5D*"D["B`@("`@("`@:68@*&ES
M7V$H)&9I;E)E<S$L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T
M=7)N("1F:6Y297,Q.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?82@D9FEN
M4F5S,BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9I
M;E)E<S(["B`@("`@("`@?0H*("`@("`@("!I9B`H)')E<R`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B56YA
M8FQE('1O(')U;B`G;6MI<V]F<R<N(BDI.PH@("`@("`@('T*("`@("`@("!I
M9B`H)&5C("$](#`I('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")M:VES;V9S(&5R<F]R(&-O9&4@)60@=VAI;&4@
M;6%K:6YG($E33RXB*2P@)&5C*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE(&EF('=E(&-A;B!U<V4@=&AI<R!D<FEV97(@
M=&\@;6%K92!I;6%G97,*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!7:&5T:&5R('=E(&-A;B!U<V4@=&AI
M<R!S=')A=&5G>2!F;W(@;6%K:6YG($E33R!I;6%G97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-T<F%T96=Y079A:6QA8FQE*"D*("`@('L*("`@("`@("`O
M*B!#:&5C:R!I9B!W92!C86X@9FEN9"!A;F0@97AE8W5T92!T:&4@8&UK:7-O
M9G,G(&-O;6UA;F0N("HO"B`@("`@("`@)')E<R`]('-Y<W1E;2@B;6MI<V]F
M<R`M:&5L<"`^+V1E=B]N=6QL(#(^)C$B+"`D96,I.PH@("`@("`@(&EF("@D
M<F5S(#T]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@("`@(&EF("@D96,@(3T@,"D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*?0H*````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E9WDN<&AP````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`T-C<W(#$P-3$U-#,T,3,V(#`R-#<T-0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J($5N8V%P<W5L871E('-T<F%T96=I97,@9F]R(&=E='1I;F<@82!R
M96%L+"!L;V-A;"!F:6QE<WES=&5M('-T<G5C='5R92!F<F]M"B`J(&$@5D93
M+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]61E-?25-/5W)I=&5R+TE33U=R
M:71E<B]296%L26YP=713=')A=&5G>2YP:'`L=B`Q+C$N."XW(#(P,#8O,#$O
M,#$@,C$Z,C@Z-#,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ
M9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5D937TE33PH@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S(%9&4U])4T]7<FET97)?4F5A
M;$EN<'5T4W1R871E9WD@>PH*("`@("\J*@H@("`@("H@02!R969E<F5N8V4@
M=&\@=&AE('-O=7)C92!61E,@=V4@=V%N="!T;R!R96%D+@H@("`@("H*("`@
M("`J($!V87(@5D93"B`@("`@*B\*("`@('9A<B`D7W-O=7)C959F<R`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@<F]O="!D:7)E8W1O<GD@=VET:&EN
M('1H92!S;W5R8V4@5D93"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?<V]U<F-E4F]O=#L*"B`@("!F=6YC=&EO;B!61E-?
M25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y*"8D<V]U<F-E5F9S+"`D<V]U
M<F-E4F]O="D*("`@('L*("`@("`@("`D=&AI<RT^7W-O=7)C959F<R`]("8D
M<V]U<F-E5F9S.PH@("`@("`@("1T:&ES+3Y?<V]U<F-E4F]O="`]("8D<V]U
M<F-E4F]O=#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A(')E86P@<&%T
M:"!T;R!T:&4@:6YP=70@=')E92X*("`@("`J"B`@("`@*B!`86)S=')A8W0*
M("`@("`J($!R971U<FX@;6EX960@("`@02!S=')I;F<@=VET:"!T:&4@<F5A
M;"!P871H+"!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=%)E86Q0871H*"D*("`@('L*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<BA?*").;W0@:6UP;&5M96YT960N(BDI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@26YD:6-A=&4@=V4@87)E(&9I;FES:&5D('=I
M=&@@=&AI<R!I;G!U="!S=')A=&5G>2X*("`@("`J"B`@("`@*B!`86)S=')A
M8W0*("`@("`J($!R971U<FX@;6EX960@("`@("`@($YU;&P@;W(@4$5!4E]%
M<G)O<B!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!F:6YI<VAE
M9"@I"B`@("!["B`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B
M3F]T(&EM<&QE;65N=&5D+B(I*3L*("`@('T*"B`@("`O*BH*("`@("`J($1E
M8VED92!W:&EC:"!S=')A=&5G>2!T;R!U<V4@=&\@9V5T(&$@<F5A;"!&4R!A
M;F0@8W)E871E(&ET+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@
M("`@*B!`<&%R86T@;V)J96-T("8D<V]U<F-E5F9S("`@("`@("!4:&4@5D93
M('=E('=A;G0@=&\@<F5A9"!F<F]M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V]U<F-E4F]O="`@("`@("`@5&AE(')O;W0@9&ER96-T;W)Y(&EN('1H870@
M5D93+@H@("`@("H@0')E='5R;B!O8FIE8W0@("!!(&-O;F-R971E('-T<F%T
M96=Y(&]R(%!%05)?17)R;W(@:68@;F\@<W1R871E9WD@:7,*("`@("`J("`@
M("`@("`@("`@("`@("`@879A:6QA8FQE+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!F86-T;W)Y*"8D<V]U<F-E5F9S+"`D<V]U<F-E4F]O="D*("`@('L*("`@
M("`@("!I9B`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'-O=7)C959F<RDI(#T]
M("=V9G-?9FEL92<I('L*("`@("`@("`@("`@)&UE=&AO9"`]("=D:7)E8W0G
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M971H;V0@/2`G8V]P
M>2<["B`@("`@("`@?0H*("`@("`@("!`:6YC;'5D95]O;F-E(&1I<FYA;64H
M7U]&24Q%7U\I("X@)R]296%L26YP=713=')A=&5G>2\G("X@)&UE=&AO9"`N
M"B`@("`@("`@("`@("`@("`@("`@("`G+G!H<"<["B`@("`@("`@)&-L87-S
M(#T@)U9&4U])4T]7<FET97)?4F5A;$EN<'5T4W1R871E9WE?)R`N("1M971H
M;V0["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-O
M=6QD(&YO="!L;V%D('-T<F%T96=Y(%PB)7-<(BXB*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65T:&]D*2D["B`@
M("`@("`@?0H*("`@("`@("`D<W1R871E9WD@/2`F;F5W("1C;&%S<R@D<V]U
M<F-E5F9S+"`D<V]U<F-E4F]O="D["B`@("`@("`@<F5T=7)N("1S=')A=&5G
M>3L*("`@('T*"GT*"@``````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+U9&4R])4T]7<FET97(O4F5A;$EN<'5T4W1R871E
M9WDO8V]P>2YP:'```````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q-3$V(#$P-3$U-#,T,3,V
M(#`R-3<P-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RHJ"B`J(%-T<F%T96=Y(&9O<B!C;W!Y:6YG(&EN<'5T
M('1R964@;W5T(&]F(&$@5D93"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&
M4U])4T]7<FET97(O25-/5W)I=&5R+U)E86Q);G!U=%-T<F%T96=Y+V-O<'DN
M<&AP+'8@,2XQ+C@N-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0T(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z
M+R]W=W<N8W)O;F]S>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H
M;W(@($IA<V]N($TN($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J
M($!P86-K86=E(%9&4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC
M;&%S<R!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y7V-O<'D@97AT
M96YD<R!61E-?25-/5W)I=&5R7U)E86Q);G!U=%-T<F%T96=Y('L*"B`@("!V
M87(@)%]T96UP4&%T:"`](&YU;&P["@H@("`@9G5N8W1I;VX@9V5T4F5A;%!A
M=&@H*0H@("`@>PH@("`@("`@(&EF("AI<U]N=6QL*"1T:&ES+3Y?=&5M<%!A
M=&@I*2!["B`@("`@("`@("`@("1T;7!?;&]C871I;VYS(#T@87)R87DH)R]T
M;7`G+"`G+W9A<B]T;7`G+"`G8SI<5U5496UP)RP@)V,Z7'1E;7`G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C.EQW:6YD;W=S7'1E
M;7`G+"`G8SI<=VEN;G1<=&5M<"<I.PH*("`@("`@("`@("`@+RH@1FER<W0L
M('1R>2!02%`G<R!U<&QO861?=&UP7V1I<B!D:7)E8W1I=F4N("HO"B`@("`@
M("`@("`@("1T;7`@/2!I;FE?9V5T*"=U<&QO861?=&UP7V1I<B<I.PH*("`@
M("`@("`@("`@+RH@3W1H97)W:7-E+"!T<GD@=&\@9&5T97)M:6YE('1H92!4
M35!$25(@96YV:7)O;FUE;G0*("`@("`@("`@("`@("H@=F%R:6%B;&4N("HO
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@
M("`@)'1M<"`](&=E=&5N=B@G5$U01$E2)RD["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($EF('=E('-T:6QL(&-A;FYO="!D971E<FUI;F4@82!V
M86QU92P@=&AE;B!C>6-L92!T:')O=6=H(&$*("`@("`@("`@("`@("H@;&ES
M="!O9B!P<F5S970@<&]S<VEB:6QI=&EE<RX@*B\*("`@("`@("`@("`@=VAI
M;&4@*&5M<'1Y*"1T;7`I("8F(&-O=6YT*"1T;7!?;&]C871I;VYS*2D@>PH@
M("`@("`@("`@("`@("`@)'1M<%]C:&5C:R`](&%R<F%Y7W-H:69T*"1T;7!?
M;&]C871I;VYS*3L*("`@("`@("`@("`@("`@(&EF("A`:7-?9&ER*"1T;7!?
M8VAE8VLI*2!["B`@("`@("`@("`@("`@("`@("`@)'1M<"`]("1T;7!?8VAE
M8VL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N;F]T(&9I;F0@82!T96UP;W)A<GD@
M9&ER96-T;W)Y+B(I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H
M:7,M/E]T96UP4&%T:"`]('1E;7!N86TH)'1M<"P@)VES;V0G*3L*("`@("`@
M("`@("`@0'5N;&EN:R@D=&AI<RT^7W1E;7!0871H*3L*"B`@("`@("`@("`@
M("1R97,@/2`D=&AI<RT^7V-O<'E4;U1E;7!0871H*"D["B`@("`@("`@("`@
M(&EF("AI<U]A*"1R97,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)'1H:7,M/E]T96UP4&%T:#L*("`@('T*"B`@("!F=6YC
M=&EO;B!F:6YI<VAE9"@I"B`@("!["B`@("`@("`@<F5T=7)N(%9&4U])4T]7
M<FET97)?4F5A;$EN<'5T4W1R871E9WE?8V]P>3HZ7W)E;6]V95)E8W5R<VEV
M92@D=&AI<RT^7W1E;7!0871H*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<F5M
M;W9E4F5C=7)S:79E*"1P871H*0H@("`@>PH@("`@("`@("1D:"`]($!O<&5N
M9&ER*"1P871H*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1D:"DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?
M*")#;W5L9"!N;W0@;W!E;B!D:7)E8W1O<GD@7"(E<UPB+B(I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P871H*2D[
M"B`@("`@("`@?0H@("`@("`@('=H:6QE("@H)&5N="`](')E861D:7(H)&1H
M*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@(&EF("@D96YT(#T]("<N)R!\
M?"`D96YT(#T]("<N+B<I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D9G5L;"`]('-P<FEN=&8H)R5S
M+R5S)RP@)'!A=&@L("1E;G0I.PH@("`@("`@("`@("!I9B`H:7-?9&ER*"1F
M=6QL*2D@>PH@("`@("`@("`@("`@("`@)')E<R`](%9&4U])4T]7<FET97)?
M4F5A;$EN<'5T4W1R871E9WE?8V]P>3HZ7W)E;6]V95)E8W5R<VEV92@D9G5L
M;"D["B`@("`@("`@("`@("`@("!I9B`H:7-?82@D<F5S+"`G4$5!4E]%<G)O
M<B<I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!I9B`H(4!U;FQI;FLH)&9U;&PI*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N
M;W0@=6YL:6YK(%PB)7-<(BXB*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F=6QL*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@8VQO
M<V5D:7(H)&1H*3L*"B`@("`@("`@:68@*"%`<FUD:7(H)'!A=&@I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*'-P<FEN=&8H7R@B
M0V]U;&0@;F]T(')M9&ER(%PB)7-<(BXB*2P@)&9U;&PI*3L*("`@("`@("!]
M"B`@("!]"@H@("`@9G5N8W1I;VX@7V-O<'E4;U1E;7!0871H*"D*("`@('L*
M("`@("`@("`D9&ER4W1A8VL@/2!A<G)A>2@G)RD["@H@("`@("`@('=H:6QE
M("AC;W5N="@D9&ER4W1A8VLI(#X@,"D@>PH@("`@("`@("`@("`D9&ER(#T@
M87)R87E?<VAI9G0H)&1I<E-T86-K*3L*("`@("`@("`@("`@:68@*&5M<'1Y
M*"1D:7(I*2!["B`@("`@("`@("`@("`@("`D=&%R9V5T(#T@)'1H:7,M/E]T
M96UP4&%T:#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1T87)G970@/2!S<')I;G1F*"<E<R\E<R<L("1T:&ES+3Y?=&5M<%!A=&@L
M("1D:7(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A0&UK9&ER
M*"1T87)G970I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<BAS<')I;G1F*%\H(D-O=6QD(&YO="!M:V1I<B!<(B5S7"(N(BDL
M("1T87)G970I*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-O=7)C
M95!A=&@@/2`D=&AI<RT^7W-O=7)C95)O;W0["B`@("`@("`@("`@(&EF("@A
M96UP='DH)&1I<BDI('L*("`@("`@("`@("`@("`@("1S;W5R8V50871H("X]
M("<O)R`N("1D:7(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L:7-T
M(#T@)'1H:7,M/E]S;W5R8V569G,M/FQI<W1&;VQD97(H)'-O=7)C95!A=&@L
M(&YU;&PL('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D;&ES="P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1L:7-T.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!F;W)E86-H("@D;&ES="!A<R`D
M96YT<GDI('L*("`@("`@("`@("`@("`@(&EF("@D96YT<GE;)W1Y<&4G72`]
M/2`G*BID:7(G*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1D
M:7(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1D:7)3=&%C:UM=(#T@
M)&5N=')Y6R=N86UE)UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1I<E-T86-K6UT@/2!S<')I;G1F
M*"<E<R\E<R<L("1D:7(L("1E;G1R>5LG;F%M92==*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1D871A(#T@)'1H:7,M/E]S;W5R8V569G,M/G)E860H)'-O
M=7)C95!A=&@L("1E;G1R>5LG;F%M92==*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D9&%T82P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("`@("`D=&%R9V5T1FEL92`]('-P<FEN
M=&8H)R5S+R5S)RP@)'1A<F=E="P@)&5N=')Y6R=N86UE)UTI.PH@("`@("`@
M("`@("`@("`@("`@("1F:"`]($!F;W!E;B@D=&%R9V5T1FEL92P@)W<G*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1F:"DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@;W!E;B!<(B5S7"(@9F]R('=R:71I
M;F<N(BDL("1T87)G971&:6QE*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&EF("AF=W)I=&4H)&9H+"`D9&%T82D@(3T@
M<W1R;&5N*"1D871A*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D5R<F]R('=R:71I;F<@
M7"(E<UPB+B(I+"`D=&%R9V5T1FEL92DI.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9H*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E86Q);G!U
M=%-T<F%T96=Y+V1I<F5C="YP:'``````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3,T-B`Q,#4Q
M-30S-#$S-B`P,C8R,#4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!3=')A=&5G>2!F;W(@9&ER96-T
M;'D@86-C97-S:6YG(&EN<'5T('1R964@:6X@82`G9FEL92<@5D93"B`J"B`J
M("1(;W)D93H@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/5W)I=&5R+U)E
M86Q);G!U=%-T<F%T96=Y+V1I<F5C="YP:'`L=B`Q+C$N."XT(#(P,#8O,#$O
M,#$@,C$Z,C@Z-#0@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P
M,#8@0W)O;F]S>7,L($Q,0R`\:'1T<#HO+W=W=RYC<F]N;W-Y<RYC;VTO/@H@
M*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS
M92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ
M9F5L:6-E0&-R;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5D937TE33PH@*B!`
M<VEN8V4@("!(;W)D92`S+C`*("HO"F-L87-S(%9&4U])4T]7<FET97)?4F5A
M;$EN<'5T4W1R871E9WE?9&ER96-T(&5X=&5N9',@5D937TE33U=R:71E<E]2
M96%L26YP=713=')A=&5G>2!["@H@("`@9G5N8W1I;VX@9V5T4F5A;%!A=&@H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W-O=7)C959F<RT^7V=E
M=$YA=&EV95!A=&@H)'1H:7,M/E]S;W5R8V52;V]T*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!F:6YI<VAE9"@I"B`@("!["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O25-/5W)I=&5R+U)E
M86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<```````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#<V
M,2`Q,#4Q-30S-#$S-B`P,C8Q,3(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!3=')A=&5G>2!F;W(@
M=W)I=&EN9R!F:6QE('1O('1E;7!O<F%R>2!D:7)E8W1O<GDL('1H96X@8V]P
M>6EN9R!T;R!61E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4U])4T]7
M<FET97(O25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]C;W!Y+G!H<"QV
M(#$N,2XX+C0@,C`P-B\P,2\P,2`R,3HR.#HT-"!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#0M,C`P-B!#<F]N;W-Y<RP@3$Q#(#QH='1P.B\O=W=W
M+F-R;VYO<WES+F-O;2\^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!*
M87-O;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*B!`<&%C
M:V%G92!61E-?25-/"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B\*8VQA<W,@
M5D937TE33U=R:71E<E]296%L3W5T<'5T4W1R871E9WE?8V]P>2!E>'1E;F1S
M(%9&4U])4T]7<FET97)?4F5A;$]U='!U=%-T<F%T96=Y('L*"B`@("!V87(@
M)%]T96UP1FEL96YA;64@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1V5T(&$@
M<F5A;"!F:6QE;F%M92!T;R!W:&EC:"!W92!C86X@=W)I=&4N"B`@("`@*@H@
M("`@("H@26X@=&AI<R!I;7!L96UE;G1A=&EO;BP@=V4@8W)E871E(&%N9"!S
M=&]R92!A('1E;7!O<F%R>2!F:6QE;F%M92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L
M;"@D=&AI<RT^7W1E;7!&:6QE;F%M92DI('L*"B`@("`@("`@("`@("1T;7!?
M;&]C871I;VYS(#T@87)R87DH)R]T;7`G+"`G+W9A<B]T;7`G+"`G8SI<5U54
M96UP)RP@)V,Z7'1E;7`G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C.EQW:6YD;W=S7'1E;7`G+"`G8SI<=VEN;G1<=&5M<"<I.PH*
M("`@("`@("`@("`@+RH@1FER<W0L('1R>2!02%`G<R!U<&QO861?=&UP7V1I
M<B!D:7)E8W1I=F4N("HO"B`@("`@("`@("`@("1T;7`@/2!I;FE?9V5T*"=U
M<&QO861?=&UP7V1I<B<I.PH*("`@("`@("`@("`@+RH@3W1H97)W:7-E+"!T
M<GD@=&\@9&5T97)M:6YE('1H92!435!$25(@96YV:7)O;FUE;G0*("`@("`@
M("`@("`@("H@=F%R:6%B;&4N("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D
M=&UP*2D@>PH@("`@("`@("`@("`@("`@)'1M<"`](&=E=&5N=B@G5$U01$E2
M)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF('=E('-T:6QL
M(&-A;FYO="!D971E<FUI;F4@82!V86QU92P@=&AE;B!C>6-L92!T:')O=6=H
M(&$*("`@("`@("`@("`@("H@;&ES="!O9B!P<F5S970@<&]S<VEB:6QI=&EE
M<RX@*B\*("`@("`@("`@("`@=VAI;&4@*&5M<'1Y*"1T;7`I("8F(&-O=6YT
M*"1T;7!?;&]C871I;VYS*2D@>PH@("`@("`@("`@("`@("`@)'1M<%]C:&5C
M:R`](&%R<F%Y7W-H:69T*"1T;7!?;&]C871I;VYS*3L*("`@("`@("`@("`@
M("`@(&EF("A`:7-?9&ER*"1T;7!?8VAE8VLI*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1M<"`]("1T;7!?8VAE8VL["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&UP*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H7R@B0V%N
M;F]T(&9I;F0@82!T96UP;W)A<GD@9&ER96-T;W)Y+B(I*3L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]T96UP1FEL96YA;64@/2!T96UP
M;F%M*"1T;7`L("=I<V\G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7W1E;7!&:6QE;F%M93L*("`@('T*"B`@("!F=6YC=&EO;B!F:6YI
M<VAE9"@I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=&5M<$9I
M;&5N86UE*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/E]T96UP1FEL96YA;64I*2![
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<A7B@N*BDO*%M>+UTJ*20A)RP@)'1H:7,M/E]T87)G971&
M:6QE+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@)&1I<B`]("1M871C:&5S
M6S%=.PH@("`@("`@("`@("`D9FEL92`]("1M871C:&5S6S)=.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1D:7(@/2`G)SL*("`@("`@("`@("`@
M)&9I;&4@/2`D=&AI<RT^7W1A<F=E=$9I;&4["B`@("`@("`@?0H*("`@("`@
M("`D<F5S(#T@)'1H:7,M/E]T87)G97169G,M/G=R:71E*"1D:7(L("1F:6QE
M+"`D=&AI<RT^7W1E;7!&:6QE;F%M92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('1R=64I.PH@("`@("`@($!U;FQI;FLH)'1H
M:7,M/E]T96UP1FEL96YA;64I.PH@("`@("`@("1T:&ES+3Y?=&5M<$9I;&5N
M86UE(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"GT*"@``
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]61E,O
M25-/5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C4Q-"`Q,#4Q-30S-#$S-B`P,C8T,#0`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*"B\J*@H@*B!3
M=')A=&5G>2!F;W(@9&ER96-T;'D@=W)I=&EN9R!O=71P=70@9FEL92!T;R!6
M1E,N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U9&4U])4T]7<FET97(O25-/
M5W)I=&5R+U)E86Q/=71P=713=')A=&5G>2]D:7)E8W0N<&AP+'8@,2XQ+C@N
M-2`R,#`V+S`Q+S`Q(#(Q.C(X.C0T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-"TR,#`V($-R;VYO<WES+"!,3$,@/&AT='`Z+R]W=W<N8W)O;F]S
M>7,N8V]M+SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($IA<V]N($TN
M($9E;&EC92`\:F9E;&EC94!C<F]N;W-Y<RYC;VT^"B`J($!P86-K86=E(%9&
M4U])4T\*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J+PIC;&%S<R!61E-?25-/
M5W)I=&5R7U)E86Q/=71P=713=')A=&5G>5]D:7)E8W0@97AT96YD<R!61E-?
M25-/5W)I=&5R7U)E86Q/=71P=713=')A=&5G>2!["@H@("`@9G5N8W1I;VX@
M9V5T4F5A;$9I;&5N86UE*"D*("`@('L*("`@("`@("`O*B!3;R!W92!S:&]U
M;&1N)W0@8F4@86-C97-S:6YG(%]G971.871I=F50871H*"DN("!)9B!W92!H
M860@<F5A;`H@("`@("`@("`J(&%C8V5S<R!C;VYT<F]L+"!T:&%T('=O=6QD
M(&)E('!R;W1E8W1E9"!A;F0@=V4G9"!B92!A(&9R:65N9"P@87,*("`@("`@
M("`@*B!T:&%T(&ES('1H92!P;VEN="!O9B!T:&ES(&5X8V5R8VES92X@*B\*
M("`@("`@("`D9FEL96YA;64@/2`D=&AI<RT^7W1A<F=E=%9F<RT^7V=E=$YA
M=&EV95!A=&@H)'1H:7,M/E]T87)G971&:6QE*3L*"B`@("`@("`@+RH@36%K
M92!S=7)E('1H92!P871H('1O('1H92!F:6QE(&5X:7-T<RX@*B\*("`@("`@
M("`D9&ER(#T@9&ER;F%M92@D9FEL96YA;64I.PH@("`@("`@('=H:6QE("@A
M0&ES7V1I<B@D9&ER*2D@>PH@("`@("`@("`@("!I9B`H(4!M:V1I<B@D9&ER
M+"`P-S4U*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H<W!R:6YT9BA?*")#;W5L9"!N;W0@;6MD:7(@7"(E<UPB+B(I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&ER*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&1I<B`](&1I
M<FYA;64H)&1I<BD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5N
M86UE.PH@("`@?0H*("`@(&9U;F-T:6]N(&9I;FES:&5D*"D*("`@('L*("`@
M("`@("`O*B!.;W1H:6YG('1O(&1O+B`J+PH@("`@?0H*?0H*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3```````````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,V(#`Q-S4U-0`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U-61RYP
M:'``````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P-3,R,38@,3`U,34T,S0Q,S8@,#(P,3(R`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!834Q?4U9'
M"B`J"B`J(%=R87!P97(@8VQA<W,@=&AA="!P<F]V:61E<R!S;VUE(&5X86UP
M;&5S(&%N9"!A(&9E=R!C;VYV96YI96YC90H@*B!M971H;V1S+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]834Q?4U9'+U-61RYP:'`L=B`Q+C$W+C$P+C0@
M,C`P-B\P,2\P,2`R,3HR.#HT-"!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#(M,C`P-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S
M(%A-3%]35D<@>PH*("`@(&9U;F-T:6]N(&5X86UP;&4H*0H@("`@>PH@("`@
M("`@("\O($-R96%T92!A;B!I;G-T86YC92!O9B!834Q?4U9'7T1O8W5M96YT
M+B!!;&P@;W1H97(@;V)J96-T<PH@("`@("`@("\O('=I;&P@8F4@861D960@
M=&\@=&AI<R!I;G-T86YC92!F;W(@<')I;G1I;F<N(%-E="!T:&4@:&5I9VAT
M"B`@("`@("`@+R\@86YD('=I9'1H(&]F('1H92!V:65W<&]R="X*("`@("`@
M("`D<W9G(#T@)FYE=R!834Q?4U9'7T1O8W5M96YT*&%R<F%Y*"=W:61T:"<@
M/3X@-#`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VAE:6=H="<@/3X@,C`P*2D["@H@("`@("`@("\O($-R96%T92!A
M;B!I;G-T86YC92!O9B!834Q?4U9'7T=R;W5P+B!3970@=&AE('-T>6QE+`H@
M("`@("`@("\O('1R86YS9F]R;7,@9F]R(&-H:6QD(&]B:F5C=',N"B`@("`@
M("`@)&<@/2`F;F5W(%A-3%]35D=?1W)O=7`H87)R87DH)W-T>6QE)R`]/B`G
M<W1R;VME.F)L86-K)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=')A;G-F;W)M)R`]/B`G=')A;G-L871E*#(P,"`Q,#`I)RDI
M.PH*("`@("`@("`O+R!!9&0@82!P87)E;G0@=&\@=&AE(&<@:6YS=&%N8V4N
M"B`@("`@("`@)&<M/F%D9%!A<F5N="@D<W9G*3L*"B`@("`@("`@+R\@5&AE
M('-A;64@<F5S=6QT<R!C86X@8F4@86-C;VUP;&ES:&5D(&)Y(&UA:VEN9R!G
M(&$@8VAI;&0@;V8@=&AE('-V9RX*("`@("`@("`O+R`D<W9G+3YA9&1#:&EL
M9"@D9RD["@H@("`@("`@("\O($-R96%T92!A;F0@86YI;6%T92!A(&-I<F-L
M92X*("`@("`@("`D8VER8VQE(#T@)FYE=R!834Q?4U9'7T-I<F-L92AA<G)A
M>2@G8W@G(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8WDG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<B<@/3X@,3`P+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`G<W1R
M;VME+7=I9'1H.C,G*2D["B`@("`@("`@)&-I<F-L92T^861D0VAI;&0H;F5W
M(%A-3%]35D=?06YI;6%T92AA<G)A>2@G871T<FEB=71E3F%M92<@/3X@)W(G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V%T=')I8G5T951Y<&4G(#T^("=834PG+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V9R
M;VTG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=&\G(#T^(#<U+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1U<B<@/3X@
M)S-S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=F:6QL)R`]/B`G9G)E97IE)RDI*3L*("`@("`@("`D
M8VER8VQE+3YA9&1#:&EL9"AN97<@6$U,7U-61U]!;FEM871E*&%R<F%Y*"=A
M='1R:6)U=&5.86UE)R`]/B`G9FEL;"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB=71E5'EP
M92<@/3X@)T-34R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G9G)O;2<@/3X@)V=R965N)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=T;R<@/3X@)W)E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9'5R)R`]/B`G,W,G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V9I;&PG(#T^("=F<F5E>F4G*2DI.PH*("`@("`@("`O+R!-86ME('1H92!C
M:7)C;&4@82!C:&EL9"!O9B!G+@H@("`@("`@("1G+3YA9&1#:&EL9"@D8VER
M8VQE*3L*"B`@("`@("`@+R\@0W)E871E(&%N9"!A;FEM871E('-O;64@=&5X
M="X*("`@("`@("`D=&5X="`]("9N97<@6$U,7U-61U]497AT*&%R<F%Y*"=T
M97AT)R`]/B`G4U9'(&-H87)T(2<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=X)R`]/B`P+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G>2<@/3X@,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W-T>6QE)R`]/B`G9F]N="US:7IE
M.C(P.W1E>'0M86YC:&]R.FUI9&1L93LG*2D["B`@("`@("`@)'1E>'0M/F%D
M9$-H:6QD*&YE=R!834Q?4U9'7T%N:6UA=&4H87)R87DH)V%T=')I8G5T94YA
M;64G(#T^("=F;VYT+7-I>F4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&54>7!E)R`]/B`G
M875T;R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9R;VTG(#T^(#`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1O)R`]/B`R,"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9'5R)R`]/B`G,W,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=F:6QL)R`]/B`G9G)E97IE)RDI*3L*
M"B`@("`@("`@+R\@36%K92!T:&4@=&5X="!A(&-H:6QD(&]F(&<N"B`@("`@
M("`@)&<M/F%D9$-H:6QD*"1T97AT*3L*"B`@("`@("`@+R\@4V5N9"!A(&UE
M<W-A9V4@=&\@=&AE('-V9R!I;G-T86YC92!T;R!S=&%R="!P<FEN=&EN9RX*
M("`@("`@("`D<W9G+3YP<FEN=$5L96UE;G0H*3L*("`@('T*"GT*"B\J*@H@
M*B!834Q?4U9'7T5L96UE;G0*("H*("H@5&AI<R!I<R!T:&4@8F%S92!C;&%S
M<R!F;W(@=&AE(&1I9F9E<F5N="!35D<@16QE;65N=`H@*B!/8FIE8W1S+B!%
M>'1E;F0@=&AI<R!C;&%S<R!T;R!C<F5A=&4@82!N97<@4U9'($5L96UE;G0N
M"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?16QE
M;65N="!["@H@("`@=F%R("1?96QE;65N=',@/2!N=6QL.PH@("`@=F%R("1?
M<W1Y;&4@/2!N=6QL.PH@("`@=F%R("1?=')A;G-F;W)M(#T@;G5L;#L*("`@
M('9A<B`D7VED(#T@;G5L;#L*"B`@("!F=6YC=&EO;B!834Q?4U9'7T5L96UE
M;G0H)'!A<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@9F]R96%C:"`H
M)'!A<F%M<R!A<R`D<"`]/B`D=BD@>PH@("`@("`@("`@("`D<&%R86T@/2`G
M7R<@+B`D<#L*("`@("`@("`@("`@)'1H:7,M/B1P87)A;2`]("1V.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($UO<W0@4U9'(&5L96UE;G1S
M(&-A;B!C;VYT86EN(&-H:6QD(&5L96UE;G1S+B!4:&ES(&UE=&AO9"!C86QL
M<PH@("`@("H@=&AE('!R:6YT16QE;65N="!M971H;V0@;V8@86YY(&-H:6QD
M(&5L96UE;G0@861D960@=&\@=&AI<PH@("`@("H@;V)J96-T(&)Y('5S92!O
M9B!T:&4@861D0VAI;&0@;65T:&]D+@H@("`@("HO"B`@("!F=6YC=&EO;B!P
M<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@("\O($QO;W`@86YD(&-A;&PN
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?96QE;65N=',@87,@)&-H:6QD
M*2!["B`@("`@("`@("`@("`@("`D8VAI;&0M/G!R:6YT16QE;65N="@I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!M971H;V0@861D<R!A;B!O8FIE8W0@<F5F97)E;F-E("AO<B!V86QU
M92P@:68@)&-O<'D@:7,*("`@("`J('1R=64I('1O('1H92!?96QE;65N=',@
M87)R87DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-H:6QD*"8D96QE;65N
M="P@)&-O<'D@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H)&-O<'DI('L*
M("`@("`@("`@("`@)'1H:7,M/E]E;&5M96YT<UM=(#T@)B1E;&5M96YT+3YC
M;W!Y*"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]E
M;&5M96YT<UM=(#T@)B1E;&5M96YT.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%1H:7,@;65T:&]D('-E;F1S(&$@;65S<V%G92!T;R!T:&4@
M<&%S<V5D(&5L96UE;G0@<F5Q=65S=&EN9R!T;PH@("`@("H@8F4@861D960@
M87,@82!C:&EL9"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D4&%R96YT*"8D
M<&%R96YT*0H@("`@>PH@("`@("`@(&EF("AI<U]S=6)C;&%S<U]O9B@D<&%R
M96YT+"`G6$U,7U-61U]%;&5M96YT)RDI('L*("`@("`@("`@("`@)'!A<F5N
M="T^861D0VAI;&0H)'1H:7,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!C;W!Y*"D*("`@('L*("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E
M*'IE;F1?=F5R<VEO;B@I+"`G,B<L("<^)RDI('L*("`@("`@("`@("`@<F5T
M=7)N(&-L;VYE*"1T:&ES*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D>&UL7W-V9R`]("1T:&ES.PH@("`@("`@("`@("!R971U<FX@)'AM;%]S
M=F<["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4')I;G0@96%C
M:"!O9B!T:&4@<&%S<V5D('!A<F%M971E<G,L(&EF('1H97D@87)E('-E="X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<')I;G1087)A;7,H*0H@("`@>PH@("`@
M("`@(&9O<F5A8V@@*&9U;F-?9V5T7V%R9W,H*2!A<R`D<&%R86TI('L*("`@
M("`@("`@("`@)%]P87)A;2`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3XD7W!A<F%M*2D@>PH@("`@("`@("`@("`@("`@
M<W=I=&-H("@D<&%R86TI('L*("`@("`@("`@("`@("`@(&-A<V4@)V9I;'1E
M<B<Z"B`@("`@("`@("`@("`@("`@("`@96-H;R`G(&9I;'1E<CTB=7)L*",G
M("X@)'1H:7,M/B1?<&%R86T@+B`G*2(G.PH@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M("`@("`@("`@96-H;R`G("<@+B!S=')?<F5P;&%C92@G7R<L("<M)RP@)'!A
M<F%M*2`N("<](B<@+B`D=&AI<RT^)%]P87)A;2`N("<B)SL*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@('T*"B`@("`O+R!3970@86YY(&YA;65D(&%T
M=')I8G5T92!O9B!A;B!E;&5M96YT('1O(&$@=F%L=64N"B`@("!F=6YC=&EO
M;B!S971087)A;2@D<&%R86TL("1V86QU92D*("`@('L*("`@("`@("`D871T
M<B`]("=?)R`N("1P87)A;3L*("`@("`@("`D=&AI<RT^)&%T='(@/2`D=F%L
M=64["B`@("!]"@H@("`@+R\@1V5T(&%N>2!N86UE9"!A='1R:6)U=&4@;V8@
M86X@96QE;65N="X*("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1P87)A;2D*("`@
M('L*("`@("`@("`D871T<B`]("=?)R`N("1P87)A;3L*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/B1A='1R*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/B1A='1R.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!0<FEN="!O=70@=&AE
M(&]B:F5C="!F;W(@9&5B=6=G:6YG+@H@("`@9G5N8W1I;VX@9&5B=6<H*0H@
M("`@>PH@("`@("`@(&5C:&\@)SQP<F4^)SL@=F%R7V1U;7`H)'1H:7,I.R!E
M8VAO("<\+W!R93XG.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?1G)A9VUE
M;G0*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]&
M<F%G;65N="!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?
M=VED=&@["B`@("!V87(@)%]H96EG:'0["B`@("!V87(@)%]V:65W0F]X.PH@
M("`@=F%R("1?>#L*("`@('9A<B`D7WD["@H@("`@9G5N8W1I;VX@<')I;G1%
M;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\<W9G)SL*("`@("`@("`D
M=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W=I9'1H)RP@)VAE:6=H="<L("=X
M)RP@)WDG+"`G=FEE=T)O>"<L("=S='EL92<I.PH@("`@("`@(&5C:&\@)R!X
M;6QN<STB:'1T<#HO+W=W=RYW,RYO<F<O,C`P,"]S=F<B('AM;&YS.GAL:6YK
M/2)H='1P.B\O=W=W+G<S+F]R9R\Q.3DY+WAL:6YK(CXG("X@(EQN(CL*("`@
M("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO
M<W9G/EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!B=69F97)/8FIE8W0H*0H@
M("`@>PH@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@)'1H:7,M/G!R:6YT
M16QE;65N="@I.PH@("`@("`@("1O=71P=70@/2!O8E]G971?8V]N=&5N=',H
M*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@<F5T=7)N("1O
M=71P=70["B`@("!]"GT*"B\J*@H@*B!834Q?4U9'7T1O8W5M96YT"B`J"B`J
M(%1H:7,@97AT96YD<R!T:&4@6$U,7U-61U]&<F%G;65N="!C;&%S<RX@270@
M=W)A<',@=&AE(%A-3%]35D=?1G)A;65N="!O=71P=70*("H@=VET:"!A(&-O
M;G1E;G0@:&5A9&5R+"!X;6P@9&5F:6YI=&EO;B!A;F0@9&]C='EP92X*("H*
M("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]$;V-U;65N
M="!E>'1E;F1S(%A-3%]35D=?1G)A9VUE;G0@>PH*("`@(&9U;F-T:6]N('!R
M:6YT16QE;65N="@I"B`@("!["B`@("`@("`@:&5A9&5R*"=#;VYT96YT+51Y
M<&4Z(&EM86=E+W-V9RMX;6PG*3L*"B`@("`@("`@<')I;G0H)SP_>&UL('9E
M<G-I;VX](C$N,"(@96YC;V1I;F<](FES;RTX.#4Y+3$B/SXG+B)<;B(I.PH@
M("`@("`@('!R:6YT*"<\(41/0U194$4@<W9G(%!50DQ)0R`B+2\O5S-#+R]$
M5$0@4U9'(#$N,"\O14XB"@D@("`@("`@(")H='1P.B\O=W=W+G<S+F]R9R]4
M4B\R,#`Q+U)%0RU35D<M,C`P,3`Y,#0O1%1$+W-V9S$P+F1T9"(^)R`N(")<
M;B(I.PH*("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@?0H*
M?0H*+RHJ"B`J(%A-3%]35D=?1W)O=7`*("H*("H@0'!A8VMA9V4@6$U,7U-6
M1PH@*B\*8VQA<W,@6$U,7U-61U]'<F]U<"!E>'1E;F1S(%A-3%]35D=?16QE
M;65N="!["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@
M("`@("!E8VAO("<\9R<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I
M9"<L("=S='EL92<L("=T<F%N<V9O<FTG+"`G9FEL=&5R)RD["B`@("`@("`@
M<')I;G0H(CY<;B(I.PH@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D[
M"B`@("`@("`@<')I;G0H(CPO9SY<;B(I.PH@("`@?0H*?0H*+RHJ"B`J(%A-
M3%]35D=?5&5X='!A=&@*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA
M<W,@6$U,7U-61U]497AT<&%T:"!E>'1E;F1S(%A-3%]35D=?16QE;65N="![
M"@H@("`@=F%R("1?=&5X=#L*("`@('9A<B`D7W@["B`@("!V87(@)%]Y.PH@
M("`@=F%R("1?9'@["B`@("!V87(@)%]D>3L*("`@('9A<B`D7W)O=&%T93L*
M("`@('9A<B`D7W1E>'1,96YG=&@["B`@("!V87(@)%]L96YG=&A!9&IU<W0[
M"B`@("!V87(@)%]C:&%R<V5T.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@D96QE;65N="`]("=T97AT<&%T:"<I"B`@("!["B`@("`@("`@96-H;R`G
M/"<@+B`D96QE;65N=#L*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED
M)RP@)W@G+"`G>2<L("=D>"<L("=D>2<L("=R;W1A=&4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=&5X=$QE;F=T:"<L("=L96YG=&A!9&IU<W0G
M+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@96-H;R`G/B<["B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G-E="DI('L*("`@("`@("`@
M("`@96-H;R!`:'1M;'-P96-I86QC:&%R<R@D=&AI<RT^7W1E>'0L($5.5%]#
M3TU0050L("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1T:&ES+3Y?=&5X="D[
M"B`@("`@("`@?0H@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@
M("`@("`@96-H;R`B/"\D96QE;65N=#Y<;B(["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T4VAA<&4H)'@L("1Y+"`D=&5X="D*("`@('L*("`@("`@("`D=&AI
M<RT^7W@@/2`D>#L*("`@("`@("`D=&AI<RT^7WD@/2`D>3L*("`@("`@("`D
M=&AI<RT^7W1E>'0@/2`D=&5X=#L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'
M7U1E>'0*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-6
M1U]497AT(&5X=&5N9',@6$U,7U-61U]497AT<&%T:"!["@H@("`@9G5N8W1I
M;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!P87)E;G0Z.G!R:6YT
M16QE;65N="@G=&5X="<I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E
M*"1X+"`D>2P@)'1E>'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@[
M"B`@("`@("`@)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]T97AT
M(#T@)'1E>'0["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]4<W!A;@H@*@H@
M*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U1S<&%N(&5X
M=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]T97AT.PH@("`@
M=F%R("1?>#L*("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*("`@('9A<B`D
M7V1Y.PH@("`@=F%R("1?<F]T871E.PH@("`@=F%R("1?=&5X=$QE;F=T:#L*
M("`@('9A<B`D7VQE;F=T:$%D:G5S=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L
M96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQT<W!A;B<["B`@("`@("`@
M)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=X)RP@)WDG+"`G9'@G+"`G9'DG
M+"`G<F]T871E)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)W1E>'1,
M96YG=&@G+"`G;&5N9W1H061J=7-T)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I
M.PH@("`@("`@(&5C:&\@)SXG("X@)'1H:7,M/E]T97AT.PH@("`@("`@(&EF
M("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("!P
M87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@('T*("`@("`@("!E8VAO
M("(\+W1S<&%N/EQN(CL*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D
M>"P@)'DL("1T97AT*0H@("`@>PH@("`@("`@("1T:&ES+3Y?>"`]("1X.PH@
M("`@("`@("1T:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T:&ES+3Y?=&5X="`@
M/2`D=&5X=#L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T-I<F-L90H@*@H@
M*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T-I<F-L92!E
M>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?8W@["B`@("!V
M87(@)%]C>3L*("`@('9A<B`D7W(["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M
M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\8VER8VQE)SL*"B`@("`@("`@
M)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=C>"<L("=C>2<L("=R)RP@)W-T
M>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI
M<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E
M;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@("`@("`@(&5C:&\@(CY<;B([
M"B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@
M("`@(&5C:&\@(CPO8VER8VQE/EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N"B`@("`@("`@("`@(&5C:&\@
M(B\^7&XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P
M92@D8W@L("1C>2P@)'(I"B`@("!["B`@("`@("`@)'1H:7,M/E]C>"`]("1C
M>#L*("`@("`@("`D=&AI<RT^7V-Y(#T@)&-Y.PH@("`@("`@("1T:&ES+3Y?
M<B`@/2`D<CL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7TQI;F4*("H*("H@
M0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U],:6YE(&5X=&5N
M9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]X,3L*("`@('9A<B`D
M7WDQ.PH@("`@=F%R("1?>#(["B`@("!V87(@)%]Y,CL*"B`@("!F=6YC=&EO
M;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQL:6YE)SL*
M("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W@Q)RP@)WDQ)RP@
M)W@R)RP@)WDR)RP@)W-T>6QE)RD["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T
M:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD
M<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@<')I;G0H(CY<
M;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@
M("`@("`@("!P<FEN="@B/"]L:6YE/EQN(BD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!P
M<FEN="@B+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S
M9713:&%P92@D>#$L("1Y,2P@)'@R+"`D>3(I"B`@("!["B`@("`@("`@)'1H
M:7,M/E]X,2`]("1X,3L*("`@("`@("`D=&AI<RT^7WDQ(#T@)'DQ.PH@("`@
M("`@("1T:&ES+3Y?>#(@(#T@)'@R.PH@("`@("`@("1T:&ES+3Y?>3(@(#T@
M)'DR.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?4F5C=`H@*@H@*B!`<&%C
M:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7U)E8W0@97AT96YD<R!8
M34Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W@["B`@("!V87(@)%]Y.PH@
M("`@=F%R("1?=VED=&@["B`@("!V87(@)%]H96EG:'0["B`@("!V87(@)%]R
M>#L*("`@('9A<B`D7W)Y.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I
M"B`@("!["B`@("`@("`@96-H;R`G/')E8W0G.PH@("`@("`@("1T:&ES+3YP
M<FEN=%!A<F%M<R@G:60G+"`G>"<L("=Y)RP@)W=I9'1H)RP@)VAE:6=H="<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("=R>"<L("=R>2<L("=S='EL
M92<I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@
M>PH@("`@("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N
M9"!T86<N"B`@("`@("`@("`@('!R:6YT*"(^7&XB*3L*("`@("`@("`@("`@
M<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@("`@<')I;G0H(CPO
M<F5C=#Y<;B(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%!R
M:6YT('-H;W)T('1A9RX*("`@("`@("`@("`@<')I;G0H(B\^7&XB*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@<V5T4VAA<&4H)'@L("1Y+"`D
M=VED=&@L("1H96EG:'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]X(#T@)'@[
M"B`@("`@("`@)'1H:7,M/E]Y(#T@)'D["B`@("`@("`@)'1H:7,M/E]W:61T
M:"`@/2`D=VED=&@["B`@("`@("`@)'1H:7,M/E]H96EG:'0@(#T@)&AE:6=H
M=#L*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7T5L;&EP<V4*("H*("H@0'!A
M8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]%;&QI<'-E(&5X=&5N
M9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]C>#L*("`@('9A<B`D
M7V-Y.PH@("`@=F%R("1?<G@["B`@("!V87(@)%]R>3L*"B`@("!F=6YC=&EO
M;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQE;&QI<'-E
M)SL*("`@("`@("`D=&AI<RT^<')I;G1087)A;7,H)VED)RP@)V-X)RP@)V-Y
M)RP@)W)X)RP@)W)Y)RP@)W-T>6QE)RP@)W1R86YS9F]R;2<I.PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@
M("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@
M("`@("`@('!R:6YT*"(^7&XB*3L*("`@("`@("`@("`@<&%R96YT.CIP<FEN
M=$5L96UE;G0H*3L*("`@("`@("`@("`@<')I;G0H(CPO96QL:7!S93Y<;B(I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%!R:6YT('-H;W)T
M('1A9RX*("`@("`@("`@("`@<')I;G0H(B`O/EQN(BD["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E*"1C>"P@)&-Y+"`D<G@L("1R
M>2D*("`@('L*("`@("`@("`D=&AI<RT^7V-X(#T@)&-X.PH@("`@("`@("1T
M:&ES+3Y?8WD@/2`D8WD["B`@("`@("`@)'1H:7,M/E]R>"`@/2`D<G@["B`@
M("`@("`@)'1H:7,M/E]R>2`@/2`D<GD["B`@("!]"@I]"@HO*BH*("H@6$U,
M7U-61U]0;VQY;&EN90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S
M<R!834Q?4U9'7U!O;'EL:6YE(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*
M"B`@("!V87(@)%]P;VEN=',["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT
M*"D*("`@('L*("`@("`@("!E8VAO("<\<&]L>6QI;F4G.PH@("`@("`@("1T
M:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<&]I;G1S)RP@)W-T>6QE)RP@)W1R
M86YS9F]R;2<I.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M
M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T87)T
M(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!P<FEN="@B/EQN(BD["B`@("`@
M("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@('!R
M:6YT*"(\+W!O;'EL:6YE/EQN(BD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!P<FEN="@B
M+SY<;B(I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P
M92@D<&]I;G1S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<&]I;G1S(#T@)'!O
M:6YT<SL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U!O;'EG;VX*("H*("H@
M0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]0;VQY9V]N(&5X
M=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]P;VEN=',["@H@
M("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO
M("<\<&]L>6=O;B<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L
M("=P;VEN=',G+"`G<W1Y;&4G+"`G=')A;G-F;W)M)RD["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T:&ES+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O
M(%!R:6YT(&-H:6QD<F5N+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@
M("`@<')I;G0H(CY<;B(I.PH@("`@("`@("`@("!P87)E;G0Z.G!R:6YT16QE
M;65N="@I.PH@("`@("`@("`@("!P<FEN="@B/"]P;VQY9V]N/EQN(BD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4')I;G0@<VAO<G0@=&%G
M+@H@("`@("`@("`@("!P<FEN="@B+SY<;B(I.PH@("`@("`@('T*("`@('T*
M"B`@("!F=6YC=&EO;B!S9713:&%P92@D<&]I;G1S*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<&]I;G1S(#T@)'!O:6YT<SL*("`@('T*"GT*"B\J*@H@*B!8
M34Q?4U9'7U!A=&@*("H*("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@
M6$U,7U-61U]0871H(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V
M87(@)%]D.PH*("`@(&9U;F-T:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@
M("`@("`@96-H;R`G/'!A=&@G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M
M<R@G:60G+"`G9"<L("=S='EL92<L("=T<F%N<V9O<FTG*3L*("`@("`@("!I
M9B`H:7-?87)R87DH)'1H:7,M/E]E;&5M96YT<RDI('L*("`@("`@("`@("`@
M+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@=&%G+@H@("`@("`@
M("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%
M;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT*"(\+W!A=&@^7&XB*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!0<FEN="!S:&]R="!T86<N
M"B`@("`@("`@("`@('!R:6YT*"(O/EQN(BD["B`@("`@("`@?0H@("`@?0H*
M("`@(&9U;F-T:6]N('-E=%-H87!E*"1D*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?9"`]("1D.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?26UA9V4*("H*
M("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]);6%G92!E
M>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?>#L*("`@('9A
M<B`D7WD["B`@("!V87(@)%]W:61T:#L*("`@('9A<B`D7VAE:6=H=#L*("`@
M('9A<B`D7VAR968["@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@
M('L*("`@("`@("!E8VAO("<\:6UA9V4G.PH@("`@("`@("1T:&ES+3YP<FEN
M=%!A<F%M<R@G:60G+"`G>"<L("=Y)RP@)W=I9'1H)RP@)VAE:6=H="<L("=S
M='EL92<I.PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]H<F5F*2D@>PH@
M("`@("`@("`@("!E8VAO("<@>&QI;FLZ:')E9CTB)R`N("1T:&ES+3Y?:')E
M9B`N("<B)SL*("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES
M+3Y?96QE;65N=',I*2!["B`@("`@("`@("`@("\O(%!R:6YT(&-H:6QD<F5N
M+"!S=&%R="!A;F0@96YD('1A9RX*("`@("`@("`@("`@96-H;R`B/EQN(CL*
M("`@("`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("`@
M("`@96-H;R`B/"]I;6%G93Y<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@4')I;G0@<VAO<G0@=&%G+@H@("`@("`@("`@("!E8VAO("(@
M+SY<;B(["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H87!E
M*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?>"`]("1X.PH@("`@("`@("1T:&ES+3Y?>2`]("1Y.PH@("`@("`@("1T
M:&ES+3Y?=VED=&@@(#T@)'=I9'1H.PH@("`@("`@("1T:&ES+3Y?:&5I9VAT
M("`]("1H96EG:'0["B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]!;FEM871E
M"B`J"B`J($!P86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?06YI
M;6%T92!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R("1?871T
M<FEB=71E3F%M93L*("`@('9A<B`D7V%T=')I8G5T951Y<&4["B`@("!V87(@
M)%]F<F]M.PH@("`@=F%R("1?=&\["B`@("!V87(@)%]B96=I;CL*("`@('9A
M<B`D7V1U<CL*("`@('9A<B`D7V9I;&P["@H@("`@9G5N8W1I;VX@<')I;G1%
M;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\86YI;6%T92<["B`@("`@
M("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L("=A='1R:6)U=&5.86UE)RP@
M)V%T=')I8G5T951Y<&4G+"`G9G)O;2<L("=T;R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=B96=I;B<L("=D=7(G+"`G9FEL;"<I.PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@("`@("`@
M("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N"B`@("`@
M("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@("`@('!A<F5N=#HZ<')I;G1%
M;&5M96YT*"D["B`@("`@("`@("`@(&5C:&\@(CPO86YI;6%T93Y<;B(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@96-H;R`B("\^7&XB.PH@("`@
M("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!S9713:&%P92@D871T<FEB=71E
M3F%M92P@)&%T=')I8G5T951Y<&4@/2`G)RP@)&9R;VT@/2`G)RP*("`@("`@
M("`@("`@("`@("`@("`@("1T;R`]("<G+"`D8F5G:6X@/2`G)RP@)&1U<B`]
M("<G+"`D9FEL;"`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?871T<FEB
M=71E3F%M92`]("1A='1R:6)U=&5.86UE.PH@("`@("`@("1T:&ES+3Y?871T
M<FEB=71E5'EP92`]("1A='1R:6)U=&54>7!E.PH@("`@("`@("1T:&ES+3Y?
M9G)O;2`@/2`D9G)O;3L*("`@("`@("`D=&AI<RT^7W1O(#T@)'1O.PH@("`@
M("`@("1T:&ES+3Y?8F5G:6X@/2`D8F5G:6X["B`@("`@("`@)'1H:7,M/E]D
M=7(@/2`D9'5R.PH@("`@("`@("1T:&ES+3Y?9FEL;"`]("1F:6QL.PH@("`@
M?0H*?0H*+RHJ"B`J(%A-3%]35D=?1FEL=&5R"B`J"B`J($!P86-K86=E(%A-
M3%]35D<*("HO"F-L87-S(%A-3%]35D=?1FEL=&5R(&5X=&5N9',@6$U,7U-6
M1U]%;&5M96YT('L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@
M>PH@("`@("`@(&5C:&\@)SQF:6QT97(G.PH@("`@("`@("1T:&ES+3YP<FEN
M=%!A<F%M<R@G:60G*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E
M;&5M96YT<RDI('L*("`@("`@("`@("`@+R\@4')I;G0@8VAI;&1R96XL('-T
M87)T(&%N9"!E;F0@=&%G+@H@("`@("`@("`@("!E8VAO("(^7&XB.PH@("`@
M("`@("`@("!P87)E;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@("`@("!E
M8VAO("(\+V9I;'1E<CY<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@96-H;R`B("\^7&XB.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!A9&10<FEM:71I=F4H)'!R:6UI=&EV92P@)'!A<F%M<RD*("`@('L*("`@
M("`@("`D=&AI<RT^861D0VAI;&0H;F5W(%A-3%]35D=?1FEL=&5R4')I;6ET
M:79E*"1P<FEM:71I=F4L("1P87)A;7,I*3L*("`@('T*"GT*"B\J*@H@*B!8
M34Q?4U9'7T9I;'1E<E!R:6UI=&EV90H@*@H@*B!`<&%C:V%G92!834Q?4U9'
M"B`J+PIC;&%S<R!834Q?4U9'7T9I;'1E<E!R:6UI=&EV92!E>'1E;F1S(%A-
M3%]35D=?16QE;65N="!["@H@("`@=F%R("1?<')I;6ET:79E<R`](&%R<F%Y
M*"=";&5N9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T-O;&]R
M36%T<FEX)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G0V]M<&]N
M96YT5')A;G-F97(G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=#
M;VUP;W-I=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=#;VYV
M;VQV94UA=')I>"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T1I
M9F9U<V5,:6=H=&EN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)T1I<W!L86-E;65N=$UA<"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)T9L;V]D)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1V%U
M<W-I86Y";'5R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G26UA
M9V4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=-97)G92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)TUO<G!H;VQO9WDG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=/9F9S970G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=3<&5C=6QA<DQI9VAT:6YG)RP*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G5&EL92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)U1U<F)U;&5N8V4G*3L*"B`@("!V87(@)%]P<FEM
M:71I=F4["@H@("`@=F%R("1?:6X["B`@("!V87(@)%]I;C(["B`@("!V87(@
M)%]R97-U;'0["B`@("!V87(@)%]X.PH@("`@=F%R("1?>3L*("`@('9A<B`D
M7V1X.PH@("`@=F%R("1?9'D["B`@("!V87(@)%]W:61T:#L*("`@('9A<B`D
M7VAE:6=H=#L*("`@('9A<B`D7VUO9&4["B`@("!V87(@)%]T>7!E.PH@("`@
M=F%R("1?=F%L=65S.PH@("`@=F%R("1?;W!E<F%T;W(["B`@("!V87(@)%]K
M,3L*("`@('9A<B`D7VLR.PH@("`@=F%R("1?:S,["B`@("!V87(@)%]K-#L*
M("`@('9A<B`D7W-U<F9A8V538V%L93L*("`@('9A<B`D7V1I9F9U<V5#;VYS
M=&%N=#L*("`@('9A<B`D7VME<FYE;%5N:71,96YG=&@["B`@("!V87(@)%]F
M;&]O<E]C;VQO<CL*("`@('9A<B`D7V9L;V]D7V]P86-I='D["@H@("`@9G5N
M8W1I;VX@6$U,7U-61U]&:6QT97)0<FEM:71I=F4H)'!R:6UI=&EV92P@)'!A
M<F%M<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI834Q?4U9'
M7T5L96UE;G0H)'!A<F%M<RD["B`@("`@("`@)'1H:7,M/E]P<FEM:71I=F4@
M/2`D<')I;6ET:79E.PH@("`@?0H*("`@(&9U;F-T:6]N('!R:6YT16QE;65N
M="@I"B`@("!["B`@("`@("`@)&YA;64@/2`G9F4G("X@)'1H:7,M/E]P<FEM
M:71I=F4["B`@("`@("`@96-H;R`G/"<@+B`D;F%M93L*("`@("`@("`D=&AI
M<RT^<')I;G1087)A;7,H)VED)RP@)W@G+"`G>2<L("=D>"<L("=D>2<L("=W
M:61T:"<L("=H96EG:'0G+"`G:6XG+"`G:6XR)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W)E<W5L="<L("=M;V1E)RP@)W1Y<&4G+"`G=F%L=65S
M)RP@)V]P97)A=&]R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)VLQ
M)RP@)VLR)RP@)VLS)RP@)VLT)RP@)W-U<F9A8V538V%L92<L("=S=&1$979I
M871I;VXG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&EF9G5S94-O
M;G-T86YT)RP@)VME<FYE;%5N:71,96YG=&@G+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9FQO;V1?8V]L;W(G+"`G9FQO;V1?;W!A8VET>2<I.PH@
M("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7V5L96UE;G1S*2D@>PH@("`@
M("`@("`@("`O+R!0<FEN="!C:&EL9')E;BP@<W1A<G0@86YD(&5N9"!T86<N
M"B`@("`@("`@("`@(&5C:&\@(CY<;B(["B`@("`@("`@("`@('!A<F5N=#HZ
M<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@(&5C:&\@)SPO)R`N("1N86UE
M("X@)SXG.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@)R\^
M)SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;W(@9F5-97)G
M92!E;&5M96YT<RX*("`@("`J+PH@("`@9G5N8W1I;VX@861D365R9V5.;V1E
M*"1I;BD*("`@('L*("`@("`@("`D=&AI<RT^861D0VAI;&0H;F5W(%A-3%]3
M5D=?1FEL=&5R365R9V5.;V1E*&%R<F%Y*"=I;B<@/3X@)&EN*2DI.PH@("`@
M?0H*?0H*+RHJ"B`J(%A-3%]35D=?1FEL=&5R365R9V5.;V1E"B`J"B`J($!P
M86-K86=E(%A-3%]35D<*("HO"F-L87-S(%A-3%]35D=?1FEL=&5R365R9V5.
M;V1E(&5X=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]I;CL*
M"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@(&5C
M:&\@)SQF94UE<F=E3F]D92<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US
M*"=I;B<I.PH@("`@("`@(&5C:&\@)R\^)SL*("`@('T*"GT*"B\J*@H@*B!8
M34Q?4U9'7U5S90H@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!8
M34Q?4U9'7U5S92!E>'1E;F1S(%A-3%]35D=?16QE;65N="!["@H@("`@=F%R
M("1?<WEM8F]L.PH*("`@(&9U;F-T:6]N(%A-3%]35D=?57-E*"1S>6UB;VPL
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('!A<F5N=#HZ6$U,
M7U-61U]%;&5M96YT*"1P87)A;7,I.PH@("`@("`@("1T:&ES+3Y?<WEM8F]L
M(#T@)'-Y;6)O;#L*("`@('T*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H
M*0H@("`@>PH@("`@("`@(&5C:&\@)SQU<V4@>&QI;FLZ:')E9CTB(R<@+B`D
M=&AI<RT^7W-Y;6)O;"`N("<B+SXG.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]3
M5D=?1&5F<PH@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?
M4U9'7T1E9G,@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@(&9U;F-T
M:6]N('!R:6YT16QE;65N="@I"B`@("!["B`@("`@("`@96-H;R`G/&1E9G,G
M.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G+"`G
M=')A;G-F;W)M)RD["B`@("`@("`@96-H;R`B/EQN(CL*("`@("`@("!P87)E
M;G0Z.G!R:6YT16QE;65N="@I.PH@("`@("`@(&5C:&\@(CPO9&5F<SY<;B([
M"B`@("!]"@I]"@HO*BH*("H@6$U,7U-61U]-87)K97(*("H*("H@0'!A8VMA
M9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]-87)K97(@97AT96YD<R!8
M34Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7W)E9E@["B`@("!V87(@)%]R
M9699.PH@("`@=F%R("1?;6%R:V5R56YI=',["B`@("!V87(@)%]M87)K97)7
M:61T:#L*("`@('9A<B`D7VUA<FME<DAE:6=H=#L*("`@('9A<B`D7V]R:65N
M=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L96UE;G0H*0H@("`@>PH@("`@("`@
M(&5C:&\@)SQM87)K97(G.PH@("`@("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G
M:60G+"`G<F5F6"<L("=R9699)RP@)VUA<FME<E5N:71S)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VUA<FME<E=I9'1H)RP@)VUA<FME<DAE:6=H
M="<L("=O<FEE;G0G*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]E
M;&5M96YT<RDI('L@+R\@4')I;G0@8VAI;&1R96XL('-T87)T(&%N9"!E;F0@
M=&%G+@H@("`@("`@("`@("!P<FEN="@B/EQN(BD["B`@("`@("`@("`@('!A
M<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@("`@('!R:6YT*"(\+VUA
M<FME<CY<;B(I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT
M*"(O/EQN(BD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-H
M87!E*"1R9698(#T@)R<L("1R9699(#T@)R<L("1M87)K97)5;FET<R`]("<G
M+`H@("`@("`@("`@("`@("`@("`@("`@)&UA<FME<E=I9'1H(#T@)R<L("1M
M87)K97)(96EG:'0@/2`G)RP@)&]R:65N="`]("<G*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<F5F6"`]("1R9698.PH@("`@("`@("1T:&ES+3Y?<F5F62`@
M/2`D<F5F63L*("`@("`@("`D=&AI<RT^7VUA<FME<E5N:71S(#T@)&UA<FME
M<E5N:71S.PH@("`@("`@("1T:&ES+3Y?;6%R:V5R5VED=&@@/2`D;6%R:V5R
M5VED=&@["B`@("`@("`@)'1H:7,M/E]M87)K97)(96EG:'0@/2`D;6%R:V5R
M2&5I9VAT.PH@("`@("`@("1T:&ES+3Y?;W)I96YT(#T@)&]R:65N=#L*("`@
M('T*"GT*"B\J*@H@*B!834Q?4U9'7U1I=&QE"B`J"B`J($!P86-K86=E(%A-
M3%]35D<**B\*8VQA<W,@6$U,7U-61U]4:71L92!E>'1E;F1S(%A-3%]35D=?
M16QE;65N="!["@H@("`@=F%R("1?=&ET;&4["@H@("`@9G5N8W1I;VX@<')I
M;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E8VAO("<\=&ET;&4G.PH@("`@
M("`@("1T:&ES+3YP<FEN=%!A<F%M<R@G:60G+"`G<W1Y;&4G*3L*("`@("`@
M("!P<FEN="@B/EQN(BD["B`@("`@("`@<')I;G0H)'1H:7,M/E]T:71L92D[
M"B`@("`@("`@<&%R96YT.CIP<FEN=$5L96UE;G0H*3L*("`@("`@("!P<FEN
M="@B/"]T:71L93Y<;B(I.PH@("`@?0H*?0H*+RHJ"B`J(%A-3%]35D=?1&5S
M8PH@*@H@*B!`<&%C:V%G92!834Q?4U9'"B`J+PIC;&%S<R!834Q?4U9'7T1E
M<V,@97AT96YD<R!834Q?4U9'7T5L96UE;G0@>PH*("`@('9A<B`D7V1E<V,[
M"@H@("`@9G5N8W1I;VX@<')I;G1%;&5M96YT*"D*("`@('L*("`@("`@("!E
M8VAO("<\9&5S8R<["B`@("`@("`@)'1H:7,M/G!R:6YT4&%R86US*"=I9"<L
M("=S='EL92<I.PH@("`@("`@(&5C:&\@)SXG("X@)'1H:7,M/E]D97-C.PH@
M("`@("`@('!A<F5N=#HZ<')I;G1%;&5M96YT*"D["B`@("`@("`@96-H;R`B
M/"]D97-C/EQN(CL*("`@('T*"GT*"B\J*@H@*B!834Q?4U9'7U1R968*("H*
M("H@0'!A8VMA9V4@6$U,7U-61PH@*B\*8VQA<W,@6$U,7U-61U]4<F5F(&5X
M=&5N9',@6$U,7U-61U]%;&5M96YT('L*"B`@("!V87(@)%]T97AT.PH@("`@
M=F%R("1?>#L*("`@('9A<B`D7WD["B`@("!V87(@)%]D>#L*("`@('9A<B`D
M7V1Y.PH@("`@=F%R("1?<F]T871E.PH@("`@=F%R("1?=&5X=$QE;F=T:#L*
M("`@('9A<B`D7VQE;F=T:$%D:G5S=#L*"B`@("!F=6YC=&EO;B!P<FEN=$5L
M96UE;G0H*0H@("`@>PH@("`@("`@(&5C:&\@)SQT<F5F)SL*("`@("`@("`D
M=&AI<RT^<')I;G1087)A;7,H)VED)RP@)W@G+"`G>2<L("=D>"<L("=D>2<L
M("=R;W1A=&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5X=$QE
M;F=T:"<L("=L96YG=&A!9&IU<W0G+"`G<W1Y;&4G*3L*("`@("`@("!E8VAO
M("<^)R`N("1T:&ES+3Y?=&5X=#L*("`@("`@("!P87)E;G0Z.G!R:6YT16QE
M;65N="@I.PH@("`@("`@(&5C:&\@(CPO=')E9CY<;B(["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="6$U,
M+G!H<```````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,C(R,#8@,3`U,34T,S0Q,S8@,#(P,S0W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*BH*("H@0V]N<W1A
M;G1S(&%R92!F<F]M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF
M:6-A=&EO;B!697)S:6]N"B`J(#$N,RP@,C4@2G5L>2`R,#`Q(&9O=6YD(&%T
M(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J+PH*+RHJ"B`J($9R;VT@-RXQ
M($=L;V)A;"!4;VME;G,N"B`J+PH*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,
M7U1/2T5.7U-7251#2%]004=%)RP@,"D[("`O+R`P>#`P"F1E9FEN92@G6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%3D0G+"`Q*3L@("`@("`@("`@+R\@,'@P
M,0ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?14Y42519)RP@,BD[
M("`@("`@("\O(#!X,#(*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.
M7U-44E]))RP@,RD[("`@("`@("`O+R`P>#`S"F1E9FEN92@G6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E],251%4D%,)RP@-"D[("`@("`@+R\@,'@P-`H*9&5F
M:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S`G+"`V-"D[("`@
M("`O+R`P>#0P"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?
M25\Q)RP@-C4I.R`@("`@+R\@,'@T,0ID969I;F4H)UA-3%]70EA-3%]'3$]"
M04Q?5$]+14Y?15A47TE?,B<L(#8V*3L@("`@("\O(#!X-#(*9&5F:6YE*"=8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7U!))RP@-C<I.R`@("`@("`@("`O+R`P
M>#0S"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T,G
M+"`V."D[("`@+R\@,'@T-`H*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/
M2T5.7T585%]47S`G+"`Q,C@I.R`@("`O+R`P>#@P"F1E9FEN92@G6$U,7U="
M6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\Q)RP@,3(Y*3L@("`@+R\@,'@X,0ID
M969I;F4H)UA-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47U1?,B<L(#$S,"D[
M("`@("\O(#!X.#(*9&5F:6YE*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-4
M4E]4)RP@,3,Q*3L@("`@("`O+R`P>#@S"F1E9FEN92@G6$U,7U="6$U,7T=,
M3T)!3%]43TM%3E],251%4D%,7T$G+"`Q,S(I.R`@+R\@,'@X-`H*9&5F:6YE
M*"=834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\P)RP@,3DR*3L@("`@("`O
M+R`P>$,P"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,2<L
M(#$Y,RD[("`@("`@+R\@,'A#,0ID969I;F4H)UA-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?15A47S(G+"`Q.30I.R`@("`@("\O(#!X0S(*9&5F:6YE*"=834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T]005%512<L(#$Y-2D[("`@("`O+R`P>$,S
M"F1E9FEN92@G6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T%#)RP@
M,3DV*3L@+R\@,'A#-`H*+RHJ"B`J($YO="!S=7)E('=H97)E(&1E9FEN960N
M"B`J($%$1"!#2$%05$52"B`J+PID969I;F4H)T1025]$5$1?5TU,7S%?,"<L
M("<M+R]705!&3U)532\O1%1$(%=-3"`Q+C`O+T5.)RD["F1E9FEN92@G1%!)
M7T141%]75$%?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@5U1!(#$N,"\O14XG
M*3L*9&5F:6YE*"=$4$E?1%1$7U=-3%\Q7S$G+"`G+2\O5T%01D]254TO+T14
M1"!734P@,2XQ+R]%3B<I.PID969I;F4H)T1025]$5$1?4TE?,5\Q)RP@)RTO
M+U=!4$9/4E5-+R]$5$0@4TD@,2XQ+R]%3B<I.PID969I;F4H)T1025]$5$1?
M4TQ?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@4TP@,2XP+R]%3B<I.PID969I
M;F4H)T1025]$5$1?0T]?,5\P)RP@)RTO+U=!4$9/4E5-+R]$5$0@0T\@,2XP
M+R]%3B<I.PID969I;F4H)T1025]$5$1?0TA!3DY%3%\Q7S$G+"`G+2\O5T%0
M1D]254TO+T141"!#2$%.3D5,(#$N,2\O14XG*3L*9&5F:6YE*"=$4$E?1%1$
M7U=-3%\Q7S(G+"`G+2\O5T%01D]254TO+T141"!734P@,2XR+R]%3B<I.PID
M969I;F4H)T1025]$5$1?5TU,7S%?,R<L("<M+R]705!&3U)532\O1%1$(%=-
M3"`Q+C,O+T5.)RD["F1E9FEN92@G1%!)7T141%]04D]67S%?,"<L("<M+R]7
M05!&3U)532\O1%1$(%!23U8@,2XP+R]%3B<I.PID969I;F4H)T1025]$5$1?
M5U1!7U=-3%\Q7S(G+"`G+2\O5T%01D]254TO+T141"!75$$M5TU,(#$N,B\O
M14XG*3L*9&5F:6YE*"=$4$E?1%1$7T-(04Y.14Q?,5\R)RP@)RTO+U=!4$9/
M4E5-+R]$5$0@0TA!3DY%3"`Q+C(O+T5.)RD["F1E9FEN92@G1%!)7T141%]3
M64Y#34Q?,5\P)RP@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RD[
M"F1E9FEN92@G1%!)7T141%]$159)3D9?,5\P)RP@)RTO+U-93D--3"\O1%1$
M($1E=DEN9B`Q+C`O+T5.)RD["F1E9FEN92@G1%!)7T141%]364Y#34Q?,5\Q
M)RP@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.)RD["F1E9FEN92@G
M1%!)7T141%]$159)3D9?,5\Q)RP@)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q
M+C$O+T5.)RD["@HO*BH*("H@3VYL>2!D969A=6QT(&-H87)A8W1E<B!E;F-O
M9&EN9W,@9G)O;2!*,E-%(&%R92!C=7)R96YT;'D@<W5P<&]R=&5D+@H@*B\*
M9&5F:6YE*"=#2$%24T547U537T%30TE))RP@)U53+4%30TE))RD["F1E9FEN
M92@G0TA!4E-%5%])4T]?.#@U.5\Q)RP@)TE33RTX.#4Y+3$G*3L*9&5F:6YE
M*"=#2$%24T547U541E\X)RP@)U541BTX)RD["F1E9FEN92@G0TA!4E-%5%]5
M5$9?,39"12<L("=55$8M,39"12<I.PID969I;F4H)T-(05)3151?551&7S$V
M3$4G+"`G551&+3$V3$4G*3L*9&5F:6YE*"=#2$%24T547U541E\Q-B<L("=5
M5$8M,38G*3L*"B\J*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@
M36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+G!H<"QV(#$N
M,3,N,3(N."`R,#`V+S`S+S$S(#`Y.C$V.C(U(&IA;B!%>'`@)`H@*@H@*B!`
M<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3"!["@H@("`@
M+RHJ"B`@("`@*B!$96-O9&EN9R!-=6QT:2UB>71E($EN=&5G97)S(&9R;VT@
M4V5C=&EO;B`U+C$*("`@("`J"B`@("`@*B!5<V4@;&]N9R!B96-A=7-E(&ET
M(&ES('5N<VEG;F5D+@H@("`@("HO"B`@("!F=6YC=&EO;B!-0E5);G0S,E1O
M26YT*"1I;BP@)B1P;W,I"B`@("!["B`@("`@("`@)'9A;"`](#`["@H@("`@
M("`@(&1O('L*("`@("`@("`@("`@)&(@/2!O<F0H)&EN6R1P;W,K*UTI.PH@
M("`@("`@("`@("`D=F%L(#P\/2`W.R`O+R!":71S:&EF="!L969T(#<@8FET
M<RX*("`@("`@("`@("`@)'9A;"`K/2`H)&(@)B`Q,C<I.PH@("`@("`@('T@
M=VAI;&4@*"@D8B`F(#$R."D@(3T@,"D["@H@("`@("`@(')E='5R;B`D=F%L
M.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1I;F<@375L=&DM8GET92!)
M;G1E9V5R<R!F<F]M(%-E8W1I;VX@-2XQ"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&EN=%1O34)526YT,S(H)B1O=70L("1I*0H@("`@>PH@("`@("`@(&EF("@D
M:2`^(#(V.#0S-30U-2D@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-
M3%]70EA-3#HZ9V5T0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E<S$@
M/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,2P@)&DI.PH@("`@("`@("`@
M("`D8GET97,R(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#(L("1I*3L*
M("`@("`@("`@("`@)&)Y=&5S,R`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET
M<R@S+"`D:2D["B`@("`@("`@("`@("1B>71E<S0@/2`Q,C@@?"!834Q?5T)8
M34PZ.F=E=$)I=',H-"P@)&DI.PH*("`@("`@("`@("`@)&]U="`N/2!C:'(H
M)&)Y=&5S-"D@+B!C:'(H)&)Y=&5S,RD@+B!C:'(H)&)Y=&5S,BD@+B!C:'(H
M)&)Y=&5S,2D@+B!C:'(H)&)Y=&5S,"D["B`@("`@("`@?2!E;'-E:68@*"1I
M(#X@,C`Y-S$U,2D@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-3%]7
M0EA-3#HZ9V5T0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E<S$@/2`Q
M,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,2P@)&DI.PH@("`@("`@("`@("`D
M8GET97,R(#T@,3(X('P@6$U,7U="6$U,.CIG971":71S*#(L("1I*3L*("`@
M("`@("`@("`@)&)Y=&5S,R`](#$R."!\(%A-3%]70EA-3#HZ9V5T0FET<R@S
M+"`D:2D["@H@("`@("`@("`@("`D;W5T("X](&-H<B@D8GET97,S*2`N(&-H
M<B@D8GET97,R*2`N(&-H<B@D8GET97,Q*2`N(&-H<B@D8GET97,P*3L*("`@
M("`@("!](&5L<V5I9B`H)&D@/B`Q-C,X,RD@>PH@("`@("`@("`@("`D8GET
M97,P(#T@,"!\(%A-3%]70EA-3#HZ9V5T0FET<R@P+"`D:2D["B`@("`@("`@
M("`@("1B>71E<S$@/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,2P@)&DI
M.PH@("`@("`@("`@("`D8GET97,R(#T@,3(X('P@6$U,7U="6$U,.CIG971"
M:71S*#(L("1I*3L*"B`@("`@("`@("`@("1O=70@+CT@8VAR*"1B>71E<S(I
M("X@8VAR*"1B>71E<S$I("X@8VAR*"1B>71E<S`I.PH@("`@("`@('T@96QS
M96EF("@D:2`^(#$R-RD@>PH@("`@("`@("`@("`D8GET97,P(#T@,"!\(%A-
M3%]70EA-3#HZ9V5T0FET<R@P+"`D:2D["B`@("`@("`@("`@("1B>71E<S$@
M/2`Q,C@@?"!834Q?5T)834PZ.F=E=$)I=',H,2P@)&DI.PH*("`@("`@("`@
M("`@)&]U="`N/2!C:'(H)&)Y=&5S,2D@+B!C:'(H)&)Y=&5S,"D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&)Y=&5S,"`](#`@?"!834Q?5T)8
M34PZ.F=E=$)I=',H,"P@)&DI.PH*("`@("`@("`@("`@)&]U="`N/2!C:'(H
M)&)Y=&5S,"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&=E=$)I
M=',H)&YU;2P@)&PI"B`@("!["B`@("`@("`@<W=I=&-H("@D;G5M*2!["B`@
M("`@("`@8V%S92`P.@H@("`@("`@("`@("!R971U<FX@)&P@)B`Q,C<[("\O
M(#!X-T8*"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("!R971U<FX@*"1L
M(#X^(#<I("8@,3(W.R`O+R`P>#=&"@H@("`@("`@(&-A<V4@,CH*("`@("`@
M("`@("`@<F5T=7)N("@D;"`^/B`Q-"D@)B`Q,C<[("\O(#!X-T8*"B`@("`@
M("`@8V%S92`S.@H@("`@("`@("`@("!R971U<FX@*"1L(#X^(#(Q*2`F(#$R
M-SL@+R\@,'@W1@H*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@(')E='5R
M;B`H)&P@/CX@,C@I("8@,3(W.R`O+R`P>#=&"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@,#L*("`@('T*"B`@("!F=6YC=&EO;B!G971$4$E3=')I;F<H
M)&DI"B`@("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@041$($-(05!415(*
M("`@("`@("`@*B\*("`@("`@("`D1%!)4W1R:6YG(#T@87)R87DH,B`]/B!$
M4$E?1%1$7U=-3%\Q7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#,@
M/3X@1%!)7T141%]75$%?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`T(#T^($1025]$5$1?5TU,7S%?,2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@-2`]/B!$4$E?1%1$7U-)7S%?,2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@-B`]/B!$4$E?1%1$7U-,7S%?,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@-R`]/B!$4$E?1%1$7T-/7S%?,"P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@."`]/B!$4$E?1%1$7T-(04Y.14Q?,5\Q+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`Y(#T^($1025]$5$1?5TU,7S%?,BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@,3`@/3X@1%!)7T141%]734Q?
M,5\S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,2`]/B!$4$E?1%1$
M7U!23U9?,5\P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`Q,B`]/B!$
M4$E?1%1$7U=405]734Q?,5\R+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`Q,R`]/B!$4$E?1%1$7T-(04Y.14Q?,5\R+`H*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@3F]T(&%L;"!3>6YC34P@8VQI96YT<R!K;F]W('1H
M:7,L('-O('=E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('-H;W5L
M9"!U<V4@=&AE('-T<FEN9R!T86)L92X*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@,'A&1#$@/3X@1%!)7T141%]364Y#34Q?,5\Q+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`T,#0Y(#T^($1025]$5$1?4UE.0TU,7S%?
M,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@-#`U,"`]/B!$4$E?1%1$
M7T1%5DE.1E\Q7S`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#0P-3$@
M/3X@1%!)7T141%]364Y#34Q?,5\Q+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`T,#4R(#T^($1025]$5$1?1$5624Y&7S%?,2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("!R971U<FX@:7-S970H)$1025-T
M<FEN9ULD:5TI(#\@)$1025-T<FEN9ULD:5T@.B!N=6QL.PH@("`@?0H*("`@
M(&9U;F-T:6]N(&=E=$1024EN="@D9'!I*0H@("`@>PH@("`@("`@("\J*@H@
M("`@("`@("`J($%$1"!#2$%05$52"B`@("`@("`@("HO"B`@("`@("`@)$10
M24EN="`](&%R<F%Y*$1025]$5$1?5TU,7S%?,"`]/B`R+`H@("`@("`@("`@
M("`@("`@("`@("`@("!$4$E?1%1$7U=405\Q7S`@/3X@,RP*("`@("`@("`@
M("`@("`@("`@("`@("`@1%!)7T141%]734Q?,5\Q(#T^(#0L"B`@("`@("`@
M("`@("`@("`@("`@("`@($1025]$5$1?4TE?,5\Q(#T^(#4L"B`@("`@("`@
M("`@("`@("`@("`@("`@($1025]$5$1?4TQ?,5\P(#T^(#8L"B`@("`@("`@
M("`@("`@("`@("`@("`@($1025]$5$1?0T]?,5\P(#T^(#<L"B`@("`@("`@
M("`@("`@("`@("`@("`@($1025]$5$1?0TA!3DY%3%\Q7S$@/3X@."P*("`@
M("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]734Q?,5\R(#T^(#DL"B`@
M("`@("`@("`@("`@("`@("`@("`@($1025]$5$1?5TU,7S%?,R`]/B`Q,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]04D]67S%?,"`]/B`Q
M,2P*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]75$%?5TU,7S%?
M,B`]/B`Q,BP*("`@("`@("`@("`@("`@("`@("`@("`@1%!)7T141%]#2$%.
M3D5,7S%?,B`]/B`Q,RP*"B`@("`@("`@("`@("`@("`@("`@("`@("\O($YO
M="!A;&P@4WEN8TU,(&-L:65N=',@:VYO=R!T:&ES+"!S;R!M87EB92!W90H@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!S:&]U;&0@=7-E('1H92!S=')I
M;F<@=&%B;&4N"B`@("`@("`@("`@("`@("`@("`@("`@($1025]$5$1?4UE.
M0TU,7S%?,"`]/B`T,#0Y+`H@("`@("`@("`@("`@("`@("`@("`@("!$4$E?
M1%1$7T1%5DE.1E\Q7S`@/3X@-#`U,"P*("`@("`@("`@("`@("`@("`@("`@
M("`@1%!)7T141%]364Y#34Q?,5\Q(#T^(#0P-3$L"B`@("`@("`@("`@("`@
M("`@("`@("`@($1025]$5$1?1$5624Y&7S%?,2`]/B`T,#4R"B`@("`@("`@
M("`@("`@("`@("`@("`@("\O($1025]$5$1?4UE.0TU,7S%?,2`]/B`P>$9$
M,2P*("`@("`@("`@("`@("`@("`@("`@("`@+R\@1%!)7T141%]$159)3D9?
M,5\Q(#T^(#!X1D0R+`H@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("!R971U<FX@:7-S970H)$1024EN=%LD9'!I72D@/R`D1%!)26YT6R1D
M<&E=(#H@,#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-H
M87)A8W1E<B!E;F-O9&EN9RX*("`@("`J(&]N;'D@9&5F875L="!C:&%R86-T
M97(@96YC;V1I;F=S(&9R;VT@2C)312!A<F4@<W5P<&]R=&5D"B`@("`@*B!F
M<F]M(&AT='`Z+R]W=W<N:6%N82YO<F<O87-S:6=N;65N=',O8VAA<F%C=&5R
M+7-E=',*("`@("`J(&%N9"!H='1P.B\O:F%V82YS=6XN8V]M+VHR<V4O,2XT
M+C(O9&]C<R]A<&DO:F%V82]N:6\O8VAA<G-E="]#:&%R<V5T+FAT;6P*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T0VAA<G-E=%-T<FEN9R@D8W,I"B`@("![
M"B`@("`@("`@+RHJ"B`@("`@("`@("H@1G)O;2!H='1P.B\O=W=W+FEA;F$N
M;W)G+V%S<VEG;FUE;G1S+V-H87)A8W1E<BUS971S"B`@("`@("`@("HO"B`@
M("`@("`@)&-H87)S9713=')I;F<@/2!A<G)A>2@S(#T^("=54RU!4T-)22<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`T(#T^("=)4T\M.#@U
M.2TQ)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$P-B`]/B`G
M551&+3@G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,3`Q,R`]
M/B`G551&+3$V0D4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M,3`Q-"`]/B`G551&+3$V3$4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@,3`Q-2`]/B`G551&+3$V)RD["@H@("`@("`@(')E='5R;B!I<W-E
M="@D8VAA<G-E=%-T<FEN9ULD8W-=*2`_("1C:&%R<V5T4W1R:6YG6R1C<UT@
M.B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8VAA
M<F%C=&5R(&5N8V]D:6YG+@H@("`@("H*("`@("`J($]N;'D@9&5F875L="!C
M:&%R86-T97(@96YC;V1I;F=S(&9R;VT@2C)312!A<F4@<W5P<&]R=&5D+@H@
M("`@("H*("`@("`J($9R;VT@:'1T<#HO+W=W=RYI86YA+F]R9R]A<W-I9VYM
M96YT<R]C:&%R86-T97(M<V5T<R!A;F0*("`@("`J(&AT='`Z+R]J879A+G-U
M;BYC;VTO:C)S92\Q+C0N,B]D;V-S+V%P:2]J879A+VYI;R]C:&%R<V5T+T-H
M87)S970N:'1M;`H@("`@("HO"B`@("!F=6YC=&EO;B!G971#:&%R<V5T26YT
M*"1C<RD*("`@('L*("`@("`@("`O*BH*("`@("`@("`@*B!&<F]M(&AT='`Z
M+R]W=W<N:6%N82YO<F<O87-S:6=N;65N=',O8VAA<F%C=&5R+7-E=',*("`@
M("`@("`@*B\*("`@("`@("`D8VAA<G-E=$EN="`](&%R<F%Y*"=54RU!4T-)
M22<@/3X@,RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=)4T\M.#@U
M.2TQ)R`]/B`T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U541BTX
M)R`]/B`Q,#8L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G551&+3$V
M0D4G(#T^(#$P,3,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G551&
M+3$V3$4G(#T^(#$P,30L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M551&+3$V)R`]/B`Q,#$U*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1C:&%R
M<V5T26YT6R1C<UTI(#\@)&-H87)S971);G1;)&-S72`Z(&YU;&P["B`@("!]
M"@I]"@HO*BH*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?
M5T)834Q?2&%S:%1A8FQE('L*"B`@("!V87(@)%]H.PH*("`@(&9U;F-T:6]N
M('-E="@D:RP@)'8I"B`@("!["B`@("`@("`@)'1H:7,M/E]H6R1K72`]("1V
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E="@D:RD*("`@('L*("`@("`@("!R
M971U<FX@:7-S970H)'1H:7,M/E]H6R1K72D@/R`D=&AI<RT^7VA;)&M=(#H@
M;G5L;#L*("`@('T*"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0`````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,V
M(#`R,#$W,``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="6$U,+T-O
M;G1E;G1(86YD;&5R+G!H<```````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#8P-S$@,3`U,34T,S0Q,S8@,#(S,C8Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&9R
M86UE=V]R:R]834Q?5T)834PO5T)834PO0V]N=&5N=$AA;F1L97(N<&AP+'8@
M,2XY+C$P+C<@,C`P-B\P-2\P,2`Q,CHP-3HQ-2!J86X@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER
M86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4@9&ED
M"B`J(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R;VT@0FEN87)Y(%A-
M3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R
M-2!*=6QY(#(P,#$*("H@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO
M<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)8
M34Q?0V]N=&5N=$AA;F1L97(@>PH*("`@('9A<B`D7V-U<G)E;G15<FD["B`@
M("!V87(@)%]O=71P=70@/2`G)SL*"B`@("!V87(@)%]O<&%Q=65(86YD;&5R
M.PH*("`@("\J*@H@("`@("H@0VAA<G-E="X*("`@("`J+PH@("`@=F%R("1?
M8VAA<G-E="`]("=55$8M."<["@H@("`@+RHJ"B`@("`@*B!70EA-3"!697)S
M:6]N+@H@("`@("H@,2P@,BP@;W(@,R!S=7!P;W)T960*("`@("`J+PH@("`@
M=F%R("1?=V)X;6Q697)S:6]N(#T@,CL*"B`@("!F=6YC=&EO;B!834Q?5T)8
M34Q?0V]N=&5N=$AA;F1L97(H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8W5R
M<F5N=%5R:2`]("9N97<@6$U,7U="6$U,7TQI9F]1=65U92@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R<F]R*0H@("`@>PH@("`@("`@
M(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"1E<G)O<BD["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M0VAA<G-E=%-T<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA
M<G-E=#L*("`@('T*"B`@("!F=6YC=&EO;B!S971#:&%R<V5T*"1C<RD*("`@
M('L*("`@("`@("`D=&AI<RT^7V-H87)S970@/2`D8W,["B`@("!]"@H@("`@
M9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?=V)X;6Q697)S:6]N.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%9E
M<G-I;VXH)'8I"B`@("!["B`@("`@("`@)'1H:7,M/E]W8GAM;%9E<G-I;VX@
M/2`R.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U="@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;W5T<'5T.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$]U='!U=%-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B!S=')L
M96XH)'1H:7,M/E]O=71P=70I.PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T
M16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?;W5T<'5T("X]("<\)R`N("1E;&5M96YT.PH*("`@("`@("`D
M8W5R<F5N=%5R:2`]("1T:&ES+3Y?8W5R<F5N=%5R:2T^=&]P*"D["@H@("`@
M("`@(&EF("@H*"$D8W5R<F5N=%5R:2D@?'P@*"1C=7)R96YT57)I("$]("1U
M<FDI*2`F)B`D=7)I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]
M("<@>&UL;G,](B<@+B`D=7)I("X@)R(G.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]C=7)R96YT57)I+3YP=7-H*"1U<FDI.PH*("`@("`@("!F;W)E
M86-H("@D871T<G,@87,@)&%T='(I('L*("`@("`@("`@("`@)'1H:7,M/E]O
M=71P=70@+CT@)R`G("X@)&%T=');)V%T=')I8G5T92==("X@)STB)R`N("1A
M='1R6R=V86QU92==("X@)R(G.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M
M/E]O=71P=70@+CT@)SXG.PH@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE
M;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=71P
M=70@+CT@)SPO)R`N("1E;&5M96YT("X@)SXG.PH*("`@("`@("`D=&AI<RT^
M7V-U<G)E;G15<FDM/G!O<"@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&-H87)A
M8W1E<G,H)'-T<BD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2`D
M<W1R.PH@("`@?0H*("`@(&9U;F-T:6]N(&]P87%U92@D;RD*("`@('L*("`@
M("`@("`D=&AI<RT^7V]U='!U="`N/2`D;SL*("`@('T*"B`@("!F=6YC=&EO
M;B!S971/<&%Q=65(86YD;&5R*"1O<&%Q=65(86YD;&5R*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W!A<75E2&%N9&QE<B`]("1O<&%Q=65(86YD;&5R.PH@
M("`@?0H*("`@(&9U;F-T:6]N(')E;6]V94]P87%U94AA;F1L97(H*0H@("`@
M>PH@("`@("`@('5N<V5T*"1T:&ES+3Y?;W!A<75E2&%N9&QE<BD["B`@("!]
M"@H@("`@9G5N8W1I;VX@8W)E871E4W5B2&%N9&QE<B@I"B`@("!["B`@("`@
M("`@)&YA;64@/2!G971?8VQA<W,H)'1H:7,I.R`O+R!C;&]N92!C=7)R96YT
M(&-L87-S"B`@("`@("`@)'-H(#T@)FYE=R`D;F%M92@I.PH@("`@("`@("1S
M:"T^<V5T0VAA<G-E="@D=&AI<RT^9V5T0VAA<G-E=%-T<B@I*3L*("`@("`@
M("`D<V@M/G-E=%9E<G-I;VXH)'1H:7,M/F=E=%9E<G-I;VXH*2D["B`@("`@
M("`@<F5T=7)N("1S:#L*("`@('T*"GT*"F-L87-S(%A-3%]70EA-3%],:69O
M475E=64@>PH*("`@('9A<B`D7W%U975E(#T@87)R87DH*3L*"B`@("!F=6YC
M=&EO;B!834Q?5T)834Q?3&EF;U%U975E*"D*("`@('L*("`@('T*"B`@("!F
M=6YC=&EO;B!P=7-H*"1O8FHI"B`@("!["B`@("`@("`@)'1H:7,M/E]Q=65U
M95M=(#T@)&]B:CL*("`@('T*"B`@("!F=6YC=&EO;B!P;W`H*0H@("`@>PH@
M("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W%U975E*2D@>PH@("`@("`@("`@
M("!R971U<FX@87)R87E?<&]P*"1T:&ES+3Y?<75E=64I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!T;W`H*0H@("`@>PH@("`@("`@(&EF("@D8V]U
M;G0@/2!C;W5N="@D=&AI<RT^7W%U975E*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]Q=65U95LD8V]U;G0@+2`Q73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$
M5$0N<&AP````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`V-C0W(#$P-3$U-#,T,3,V(#`R,#<W-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!F
M<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T141"YP:'`L=B`Q+C8N,3(N-2`R
M,#`V+S`S+S$Q(#`Y.C4U.C`Q(&IA;B!%>'`@)`H@*@H@*B!&<F]M($)I;F%R
M>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N
M,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R
M=6TN;W)G"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL
M<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-3%]70EA-3%]$5$0@>PH*
M("`@('9A<B`D=F5R<VEO;CL*("`@('9A<B`D:6YT5&%G<SL*("`@('9A<B`D
M:6YT071T<FEB=71E<SL*("`@('9A<B`D<W1R5&%G<SL*("`@('9A<B`D<W1R
M071T<FEB=71E<SL*("`@('9A<B`D:6YT0V]D95!A9V5S.PH@("`@=F%R("1S
M=')#;V1E4&%G97,["B`@("!V87(@)'-T<D-O9&5086=E<U5223L*("`@('9A
M<B`D55)).PH@("`@=F%R("1834Q.4SL*("`@('9A<B`D1%!).PH*("`@(&9U
M;F-T:6]N(%A-3%]70EA-3%]$5$0H)'8I"B`@("!["B`@("`@("`@)'1H:7,M
M/G9E<G-I;VX@/2`D=CL*("`@("`@("`D=&AI<RT^:6YI="@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&EN:70H*0H@("`@>PH@("`@?0H*("`@(&9U;F-T:6]N
M('-E=$%T=')I8G5T92@D:6YT071T<FEB=71E+"`D<W1R071T<FEB=71E*0H@
M("`@>PH@("`@("`@("1T:&ES+3YS=')!='1R:6)U=&5S6R1S=')!='1R:6)U
M=&5=(#T@)&EN=$%T=')I8G5T93L*("`@("`@("`D=&AI<RT^:6YT071T<FEB
M=71E<ULD:6YT071T<FEB=71E72`]("1S=')!='1R:6)U=&4["B`@("!]"@H@
M("`@9G5N8W1I;VX@<V5T5&%G*"1I;G1486<L("1S=')486<I"B`@("!["B`@
M("`@("`@)'1H:7,M/G-T<E1A9W-;)'-T<E1A9UT@/2`D:6YT5&%G.PH@("`@
M("`@("1T:&ES+3YI;G1486=S6R1I;G1486==(#T@)'-T<E1A9SL*("`@('T*
M"B`@("!F=6YC=&EO;B!S971#;V1E4&%G92@D:6YT0V]D95!A9V4L("1S=')#
M;V1E4&%G92P@)'-T<D-O9&5086=E55))*0H@("`@>PH@("`@("`@("1T:&ES
M+3YS=')#;V1E4&%G97-54DE;)'-T<D-O9&5086=E55))72`]("1I;G1#;V1E
M4&%G93L*("`@("`@("`D=&AI<RT^<W1R0V]D95!A9V5S6R1S=')#;V1E4&%G
M95T@/2`D:6YT0V]D95!A9V4["B`@("`@("`@)'1H:7,M/FEN=$-O9&5086=E
M<ULD:6YT0V]D95!A9V5=(#T@)'-T<D-O9&5086=E.PH@("`@?0H*("`@(&9U
M;F-T:6]N('1O5&%G4W1R*"1T86<I"B`@("!["B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3YI;G1486=S6R1T86==*2`_("1T:&ES+3YI;G1486=S6R1T
M86==(#H@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]!='1R:6)U=&53
M='(H)&%T=')I8G5T92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/FEN=%1A9W-;)&%T=')I8G5T95TI(#\@)'1H:7,M/FEN=%1A9W-;)&%T
M=')I8G5T95T@.B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!T;T-O9&50
M86=E4W1R*"1C;V1E4&%G92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H
M)'1H:7,M/FEN=$-O9&5086=E<ULD8V]D95!A9V5=*2`_("1T:&ES+3YI;G1#
M;V1E4&%G97-;)&-O9&5086=E72`Z(&9A;'-E.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1O5&%G26YT*"1T86<I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T
M*"1T:&ES+3YS=')486=S6R1T86==*2`_("1T:&ES+3YS=')486=S6R1T86==
M(#H@9F%L<V4["B`@("!]"@H@("`@9G5N8W1I;VX@=&]!='1R:6)U=&5);G0H
M)&%T=')I8G5T92D*("`@('L*("`@("`@("!R971U<FX@:7-S970H)'1H:7,M
M/G-T<D%T=')I8G5T97-;)&%T=')I8G5T95TI(#\@)'1H:7,M/G-T<D%T=')I
M8G5T97-;)&%T=')I8G5T95T@.B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO
M;B!T;T-O9&5086=E26YT*"1C;V1E4&%G92D*("`@('L*("`@("`@("!R971U
M<FX@:7-S970H)'1H:7,M/G-T<D-O9&5086=E<ULD8V]D95!A9V5=*2`_("1T
M:&ES+3YS=')#;V1E4&%G97-;)&-O9&5086=E72`Z(&9A;'-E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('1O0V]D95!A9V554DDH)'5R:2D*("`@('L*("`@("`@
M("`D=7)I(#T@<W1R=&]L;W=E<B@D=7)I*3L*("`@("`@("!I9B@A:7-S970H
M)'1H:7,M/G-T<D-O9&5086=E<U5225LD=7)I72DI('L*("`@("`@("`@("`@
M9&EE*")U;F%B;&4@=&\@9FEN9"!C;V1E<&%G92!F;W(@)'5R:2%<;B(I.PH@
M("`@("`@('T*"B`@("`@("`@)')E="`](&ES<V5T*"1T:&ES+3YS=')#;V1E
M4&%G97-54DE;)'5R:5TI(#\@)'1H:7,M/G-T<D-O9&5086=E<U5225LD=7)I
M72`Z(&9A;'-E.PH*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("`O
M*BH*("`@("`J($=E='1E<B!F;W(@<')O<&5R='D@=F5R<VEO;BX*("`@("`J
M($!R971U<FX@5F%L=64@;V8@<')O<&5R='D@=F5R<VEO;BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YV97)S:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R
M(&9O<B!P<F]P97)T>2!V97)S:6]N+@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)'8@($YE=R!V86QU92!O9B!P<F]P97)T>2!V97)S:6]N+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971697)S:6]N*"1V*0H@("`@>PH@("`@("`@("1T:&ES
M+3YV97)S:6]N(#T@)'8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971T97(@
M9F]R('!R;W!E<G1Y(%5222X*("`@("`J($!R971U<FX@5F%L=64@;V8@<')O
M<&5R='D@55))+@H@("`@("HO"B`@("!F=6YC=&EO;B!G97154DDH*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^55)).PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!54DDN"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1U("!.97<@=F%L=64@;V8@<')O<&5R='D@55))+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S97154DDH)'4I"B`@("!["B`@("`@("`@)'1H:7,M
M/E5222`]("1U.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T=&5R(&9O<B!P
M<F]P97)T>2!$4$DN"B`@("`@*B!`<F5T=7)N(%9A;'5E(&]F('!R;W!E<G1Y
M($1022X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1%!)*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/D1023L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E='1E<B!F;W(@<')O<&5R='D@1%!)+@H@("`@("H@0'!A<F%M($1022!.
M97<@=F%L=64@;V8@<')O<&5R='D@1%!)+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971$4$DH)&0I"B`@("!["B`@("`@("`@)'1H:7,M/D1022`]("1D.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]834PO5T)834PO
M1%1$36%N86=E<BYP:'``````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-3$U-2`Q,#4Q-30S-#$S-B`P,C(R-C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G
M6$U,+U="6$U,+T141"]3>6YC34PN<&AP)SL*:6YC;'5D95]O;F-E("=834PO
M5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP:'`G.PII;F-L=61E7V]N8V4@)UA-
M3"]70EA-3"]$5$0O4WEN8TU,1&5V26YF+G!H<"<["@HO*BH*("H@)$AO<F1E
M.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T141$UA;F%G97(N<&AP+'8@
M,2XS+C$R+C$Q(#(P,#8O,#4O,#$@,3(Z,#4Z,34@:F%N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y
M<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!&<F]M($)I;F%R>2!8
M34P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@
M,C4@2G5L>0H@*B`R,#`Q(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN
M;W)G"B`J"B`J($!P86-K86=E(%A-3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="
M6$U,7T141$UA;F%G97(@>PH*("`@("\J*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]S=')$5$0@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]S=')$5$154DD@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?
M5T)834Q?1%1$36%N86=E<B@I"B`@("!["B`@("`@("`@)'1H:7,M/G)E9VES
M=&5R1%1$*"<M+R]364Y#34PO+T141"!3>6YC34P@,2XP+R]%3B<L("=S>6YC
M;6PZ<WEN8VUL,2XP)RP@;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,*#`I*3L*
M("`@("`@("`D=&AI<RT^<F5G:7-T97)$5$0H)RTO+U-93D--3"\O1%1$(%-Y
M;F--3"`Q+C$O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C$G+"!N97<@6$U,7U="
M6$U,7T141%]3>6YC34PH,2DI.PH*("`@("`@("`D=&AI<RT^<F5G:7-T97)$
M5$0H)RTO+U-93D--3"\O1%1$($UE=$EN9B`Q+C`O+T5.)RP@)W-Y;F-M;#IM
M971I;F8Q+C`G+"!N97<@6$U,7U="6$U,7T141%]3>6YC34Q-971);F8H,"DI
M.PH@("`@("`@("1T:&ES+3YR96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@
M365T26YF(#$N,2\O14XG+"`G<WEN8VUL.FUE=&EN9C$N,2<L(&YE=R!834Q?
M5T)834Q?1%1$7U-Y;F--3$UE=$EN9B@Q*2D["@H@("`@("`@("1T:&ES+3YR
M96=I<W1E<D141"@G+2\O4UE.0TU,+R]$5$0@1&5V26YF(#$N,"\O14XG+"`G
M<WEN8VUL.F1E=FEN9C$N,"<L(&YE=R!834Q?5T)834Q?1%1$7U-Y;F--3$1E
M=DEN9B@P*2D["B`@("`@("`@)'1H:7,M/G)E9VES=&5R1%1$*"<M+R]364Y#
M34PO+T141"!$979);F8@,2XQ+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XQ)RP@
M;F5W(%A-3%]70EA-3%]$5$1?4WEN8TU,1&5V26YF*#$I*3L*("`@('T*"B`@
M("`O*BH*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$EN<W1A;F-E*"1P=6)L
M:6-)9&5N=&EF:65R*0H@("`@>PH@("`@("`@("1P=6)L:6-)9&5N=&EF:65R
M(#T@<W1R=&]L;W=E<B@D<'5B;&EC261E;G1I9FEE<BD["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<W1R1%1$6R1P=6)L:6-)9&5N=&EF:65R72DI('L*
M("`@("`@("`@("`@)&1T9"`]("8D=&AI<RT^7W-T<D141%LD<'5B;&EC261E
M;G1I9FEE<ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1T9"`]
M(&YU;&P["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D9'1D.PH@("`@?0H*
M("`@("\J*@H@("`@("HO"B`@("!F=6YC=&EO;B`F9V5T26YS=&%N8V554DDH
M)'5R:2D*("`@('L*("`@("`@("`D=7)I(#T@<W1R=&]L;W=E<B@D=7)I*3L*
M"B`@("`@("`@+R\@<V]M92!M86YU86P@:&%C:W,Z"B`@("`@("`@:68@*"1U
M<FD@/3T@)W-Y;F-M;#IS>6YC;6PG*2!["B`@("`@("`@("`@("1U<FD@/2`G
M<WEN8VUL.G-Y;F-M;#$N,"<["B`@("`@("`@?0H@("`@("`@(&EF("@D=7)I
M(#T]("=S>6YC;6PZ;65T:6YF)RD@>PH@("`@("`@("`@("`D=7)I(#T@)W-Y
M;F-M;#IM971I;F8Q+C`G.PH@("`@("`@('T*("`@("`@("!I9B`H)'5R:2`]
M/2`G<WEN8VUL.F1E=FEN9B<I('L*("`@("`@("`@("`@)'5R:2`]("=S>6YC
M;6PZ9&5V:6YF,2XP)SL*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W-T<D141%5225LD=7)I72DI('L*("`@("`@("`@("`@)&1T9"`]
M("8D=&AI<RT^7W-T<D141%5225LD=7)I73L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D9'1D(#T@;G5L;#L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1D=&0["B`@("!]"@H@("`@+RHJ"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E9VES=&5R1%1$*"1P=6)L:6-)9&5N=&EF:65R+"`D=7)I+"`F)&1T9"D*
M("`@('L*("`@("`@("`D<'5B;&EC261E;G1I9FEE<B`]('-T<G1O;&]W97(H
M)'!U8FQI8TED96YT:69I97(I.PH@("`@("`@("1D=&0M/G-E=$1022@D<'5B
M;&EC261E;G1I9FEE<BD["@H@("`@("`@("1T:&ES+3Y?<W1R1%1$6R1P=6)L
M:6-)9&5N=&EF:65R72`]("1D=&0["B`@("`@("`@)'1H:7,M/E]S=')$5$15
M4DE;<W1R=&]L;W=E<B@D=7)I*5T@/2`D9'1D.PH@("`@?0H*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]%;F-O9&5R+G!H<```````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(W-S(P(#$P-3$U-#,T
M,3,V(#`R,3<S-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PN<&AP)SL*
M:6YC;'5D95]O;F-E("=834PO5T)834PO0V]N=&5N=$AA;F1L97(N<&AP)SL*
M:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$36%N86=E<BYP:'`G.PII;F-L
M=61E7V]N8V4@)TAO<F1E+U-T<FEN9RYP:'`G.PH*+RHJ"B`J("1(;W)D93H@
M9G)A;65W;W)K+UA-3%]70EA-3"]70EA-3"]%;F-O9&5R+G!H<"QV(#$N,C4N
M,3`N,3,@,C`P-B\P-2\S,2`Q-SHP-CHS-R!S96QS:WD@17AP("0*("H*("H@
M0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER
M86UI9#8N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.
M1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($9R;VT@0FEN87)Y(%A-
M3"!#;VYT96YT($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R
M-2!*=6QY"B`J(#(P,#$@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO
M<F<*("H*("H@0'!A8VMA9V4@6$U,7U="6$U,"B`J+PIC;&%S<R!834Q?5T)8
M34Q?16YC;V1E<B!E>'1E;F1S(%A-3%]70EA-3%]#;VYT96YT2&%N9&QE<B![
M"@H@("`@=F%R("1?<W1R:6YG<R`](&%R<F%Y*"D["@H@("`@=F%R("1?<W1R
M:6YG5&%B;&4["@H@("`@=F%R("1?:&%S5W)I='1E;DAE861E<B`](&9A;'-E
M.PH*("`@('9A<B`D7V1T9#L*"B`@("!V87(@)%]O=71P=70@/2`G)SL*"B`@
M("!V87(@)%]U<FES(#T@87)R87DH*3L*"B`@("!V87(@)%]U<FE.=6US(#T@
M87)R87DH*3L*"B`@("!V87(@)%]C=7)R96YT55)).PH*("`@('9A<B`D7W-U
M8E!A<G-E<B`](&YU;&P["B`@("!V87(@)%]S=6)087)S97)3=&%C:R`](#`[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@6$U,('!A<G-E<BX*("`@("`J"B`@("`@
M*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W!A<G-E<CL*"B`@
M("`O*BH*("`@("`J(%1H92!$5$0@36%N86=E<BX*("`@("`J"B`@("`@*B!`
M=F%R(%A-3%]70EA-3%]$5$1-86YA9V5R"B`@("`@*B\*("`@('9A<B`D7V1T
M9$UA;F%G97(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@6$U,7U="6$U,7T5N8V]D97(H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="6$U,7T141$UA
M;F%G97(H*3L*("`@("`@("`D=&AI<RT^7W-T<FEN9U1A8FQE(#T@)FYE=R!8
M34Q?5T)834Q?2&%S:%1A8FQE*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M86ME('1H92!I;G!U="`D>&UL(&%N9"!T=7)N(&ET(&EN=&\@5T)834PN(%1H
M:7,@:7,@7VYO=%\@=&AE"B`@("`@*B!I;G1E;F1E9"!W87D@;V8@=7-I;F<@
M=&AI<R!C;&%S<RX@270@:7,@9&5R:79E9"!F<F]M"B`@("`@*B!#;VYT96YT
M:&%N9&QE<B!A;F0@;VYE('-H;W5L9"!U<V4@:70@87,@82!#;VYT96YT2&%N
M9&QE<B!A;F0*("`@("`J('!R;V1U8V4@=&AE(%A-3"US=')U8W1U<F4@=VET
M:"!S=&%R=$5L96UE;G0H*2P@96YD16QE;65N="@I+`H@("`@("H@86YD(&-H
M87)A8W1E<G,H*2X*("`@("`J+PH@("`@9G5N8W1I;VX@96YC;V1E*"1X;6PI
M"B`@("!["B`@("`@("`@+R\@0W)E871E('1H92!834P@<&%R<V5R(&%N9"!S
M970@;65T:&]D(')E9F5R96YC97,N"B`@("`@("`@)'1H:7,M/E]P87)S97(@
M/2!X;6Q?<&%R<V5R7V-R96%T95]N<R@D=&AI<RT^7V-H87)S970I.PH@("`@
M("`@('AM;%]S971?;V)J96-T*"1T:&ES+3Y?<&%R<V5R+"`D=&AI<RD["B`@
M("`@("`@>&UL7W!A<G-E<E]S971?;W!T:6]N*"1T:&ES+3Y?<&%R<V5R+"!8
M34Q?3U!424].7T-!4T5?1D],1$E.1RP@9F%L<V4I.PH@("`@("`@('AM;%]S
M971?96QE;65N=%]H86YD;&5R*"1T:&ES+3Y?<&%R<V5R+"`G7W-T87)T16QE
M;65N="<L("=?96YD16QE;65N="<I.PH@("`@("`@('AM;%]S971?8VAA<F%C
M=&5R7V1A=&%?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)U]C:&%R86-T97)S
M)RD["B`@("`@("`@>&UL7W-E=%]P<F]C97-S:6YG7VEN<W1R=6-T:6]N7VAA
M;F1L97(H)'1H:7,M/E]P87)S97(L("<G*3L*("`@("`@("!X;6Q?<V5T7V5X
M=&5R;F%L7V5N=&ET>5]R969?:&%N9&QE<B@D=&AI<RT^7W!A<G-E<BP@)R<I
M.PH*("`@("`@("!I9B`H(7AM;%]P87)S92@D=&AI<RT^7W!A<G-E<BP@)'AM
M;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P
M<FEN=&8H)UA-3"!E<G)O<CH@)7,@870@;&EN92`E9"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM;%]E<G)O<E]S
M=')I;F<H>&UL7V=E=%]E<G)O<E]C;V1E*"1T:&ES+3Y?<&%R<V5R*2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('AM
M;%]G971?8W5R<F5N=%]L:6YE7VYU;6)E<B@D=&AI<RT^7W!A<G-E<BDI*3L*
M("`@("`@("!]"@H@("`@("`@('AM;%]P87)S97)?9G)E92@D=&AI<RT^7W!A
M<G-E<BD["@H@("`@("`@(')E='5R;B`D=&AI<RT^7V]U='!U=#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!W<FET92!T:&4@8V]R<F5C="!H
M96%D97)S+@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94AE861E<B@D=7)I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9'1D(#T@)B1T:&ES+3Y?9'1D36%N
M86=E<BT^9V5T26YS=&%N8V554DDH)'5R:2D["B`@("`@("`@:68@*"$D=&AI
M<RT^7V1T9"D@>PH@("`@("`@("`@("`O+R!43T1/.B!P<F]P97(@97)R;W(@
M:&%N9&QI;F<*("`@("`@("`@("`@9&EE*"=5;F%B;&4@=&\@9FEN9"!D=&0@
M9F]R("<@+B`D=7)I*3L*("`@("`@("!]"B`@("`@("`@)&1P:5-T<FEN9R`]
M("1T:&ES+3Y?9'1D+3YG971$4$DH*3L*"B`@("`@("`@+R\@4V5T(%9E<G-I
M;VX@3G5M8F5R(&9R;VT@4V5C=&EO;B`U+C0*("`@("`@("`O+R!V97)S:6]N
M(#T@=5]I;G0X"B`@("`@("`@+R\@8W5R<F5N=&QY(#$L(#(@;W(@,PH@("`@
M("`@("1T:&ES+3YW<FET959E<G-I;VY.=6UB97(H)'1H:7,M/E]W8GAM;%9E
M<G-I;VXI.PH*("`@("`@("`O+R!3970@1&]C=6UE;G0@4'5B;&EC($ED971I
M9FEE<B!F<F]M(%-E8W1I;VX@-2XU"B`@("`@("`@+R\@<'5B;&EC:60@/2!M
M8E]U7VEN=#,R('P@*"!Z97)O(&EN9&5X("D*("`@("`@("`O+R!Z97)O(#T@
M=5]I;G0X"B`@("`@("`@+R\@8V]N=&%I;FEN9R!T:&4@=F%L=64@>F5R;R`H
M,"D*("`@("`@("`O+R!4:&4@86-T=6%L($1022!I<R!D971E<FUI;F5D(&%F
M=&5R('1H92!3=')I;F<@5&%B;&4@:7,@<F5A9"X*("`@("`@("`D=&AI<RT^
M=W)I=&5$;V-U;65N=%!U8FQI8TED96YT:69I97(H)&1P:5-T<FEN9RP@)'1H
M:7,M/E]S=')I;F=S*3L*"B`@("`@("`@+R\@4V5T($-H87)S970@9G)O;2`U
M+C8*("`@("`@("`O+R!C:&%R<V5T(#T@;6)?=5]I;G0S,@H@("`@("`@("1T
M:&ES+3YW<FET94-H87)S970H)'1H:7,M/E]C:&%R<V5T*3L*"B`@("`@("`@
M+R\@4V5T(%-T<FEN9R!486)L92!F<F]M(#4N-PH@("`@("`@("\O('-T<F(Q
M(#T@;&5N9W1H("IB>71E"B`@("`@("`@)'1H:7,M/G=R:71E4W1R:6YG5&%B
M;&4H)'1H:7,M/E]S=')I;F=S+"`D=&AI<RT^7V-H87)S970L("1T:&ES+3Y?
M<W1R:6YG5&%B;&4I.PH*("`@("`@("`D=&AI<RT^7V-U<G)E;G154DD@/2`D
M=7)I.PH*("`@("`@("`D=&AI<RT^7VAA<U=R:71T96Y(96%D97(@/2!T<G5E
M.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E5F5R<VEO;DYU;6)E<B@D=F5R
M<VEO;BD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H)'9E
M<G-I;VXI.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E1&]C=6UE;G10=6)L
M:6-)9&5N=&EF:65R*"1D<&E3=')I;F<L("8D<W1R:6YG<RD*("`@('L*("`@
M("`@("`D:2`](%A-3%]70EA-3#HZ9V5T1%!)26YT*"1D<&E3=')I;F<I.PH*
M("`@("`@("!I9B`H)&D@/3T@,"D@>PH@("`@("`@("`@("`D<W1R:6YG<ULP
M72`]("1D<&E3=')I;F<["B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X]
M(&-H<B@P*3L*("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*#`I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(%A-3%]70EA-3#HZ:6YT
M5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@)&DI.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!W<FET94-H87)S970H)&-H87)S970I"B`@("![
M"B`@("`@("`@)&-S(#T@6$U,7U="6$U,.CIG971#:&%R<V5T26YT*"1C:&%R
M<V5T*3L*"B`@("`@("`@:68@*"1C<R`]/2`P*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YS=7!P;W)T960@0VAA<G-E=#H@
M)R`N("1C:&%R<V5T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!8
M34Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L("1C<RD[
M"B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('=R:71E4W1R:6YG5&%B
M;&4H)'-T<FEN9W,L("1C:&%R<V5T+"`D<W1R:6YG5&%B;&4I"B`@("!["B`@
M("`@("`@)'-T<FEN9T)Y=&5S(#T@87)R87DH*3L*("`@("`@("`D8V]U;G0@
M/2`P.PH@("`@("`@(&9O<F5A8V@@*"1S=')I;F=S(&%S("1S='(I('L*("`@
M("`@("`@("`@)&)Y=&5S(#T@)'1H:7,M/E]G971">71E<R@D<W1R+"`D8VAA
M<G-E="D["B`@("`@("`@("`@("1S=')I;F=">71E<R`](&%R<F%Y7VUE<F=E
M*"1S=')I;F=">71E<RP@)&)Y=&5S*3L*("`@("`@("`@("`@)&YU;&Q,96YG
M=&@@/2`D=&AI<RT^7V%D9$YU;&Q">71E*"1B>71E<RD["B`@("`@("`@("`@
M("1T:&ES+3Y?<W1R:6YG5&%B;&4M/G-E="@D<W1R+"`D8V]U;G0I.PH@("`@
M("`@("`@("`D8V]U;G0@*ST@8V]U;G0H)&)Y=&5S*2`K("1N=6QL3&5N9W1H
M.PH@("`@("`@('T*"B`@("`@("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R
M*"1T:&ES+3Y?;W5T<'5T+"!C;W5N="@D<W1R:6YG0GET97,I*3L*("`@("`@
M("`D=&AI<RT^7V]U='!U="`N/2!I;7!L;V1E*"<G+"`D<W1R:6YG0GET97,I
M.PH@("`@?0H*("`@(&9U;F-T:6]N('=R:71E4W1R:6YG*"1S='(L("1C<RD*
M("`@('L*("`@("`@("`D8GET97,@/2`D=&AI<RT^7V=E=$)Y=&5S*"1S='(L
M("1C<RD["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@:6UP;&]D92@G)RP@
M)&)Y=&5S*3L*("`@("`@("`D=&AI<RT^=W)I=&5.=6QL*"1C<RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@=W)I=&5.=6QL*"1C:&%R<V5T*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@P*3L*("`@("`@("!R971U<FX@
M,3L*("`@('T*"B`@("!F=6YC=&EO;B!?861D3G5L;$)Y=&4H)B1B>71E<RD*
M("`@('L*("`@("`@("`D8GET97-;72`](&-H<B@P*3L*("`@("`@("!R971U
M<FX@,3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T0GET97,H)'-T<FEN9RP@
M)&-S*0H@("`@>PH@("`@("`@("1S=')I;F<@/2!3=')I;F<Z.F-O;G9E<G1#
M:&%R<V5T*"1S=')I;F<L("1C<RP@)W5T9BTX)RD["B`@("`@("`@)&YB>71E
M<R`]('-T<FQE;B@D<W1R:6YG*3L*"B`@("`@("`@)&)Y=&5S(#T@87)R87DH
M*3L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D;F)Y=&5S.R`D:2LK*2![
M"B`@("`@("`@("`@("1B>71E<UM=(#T@)'-T<FEN9WLD:7T["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&)Y=&5S.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]S<&QI=%5222@D=&%G*0H@("`@>PH@("`@("`@("1P87)T<R`](&5X<&QO
M9&4H)SHG+"`D=&%G*3L*("`@("`@("`D;F%M92`](&%R<F%Y7W!O<"@D<&%R
M=',I.PH@("`@("`@("1U<FD@/2!I;7!L;V1E*"<Z)RP@)'!A<G1S*3L*("`@
M("`@("!R971U<FX@87)R87DH)'5R:2P@)&YA;64I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-T87)T16QE;65N="@D=7)I+"`D;F%M92P@)&%T=')I8G5T97,I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?<W5B4&%R<V5R(#T](&YU;&PI
M('L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7VAA<U=R:71T96Y(96%D97(I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3YW<FET94AE861E<B@D=7)I*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C=7)R96YT
M55))("$]("1U<FDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YC:&%N9V5C
M;V1E<&%G92@D=7)I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G=R:71E5&%G*"1N86UE+"`D871T<FEB=71E<RP@=')U92P@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YS=&%R=$5L96UE;G0H)'5R:2PD
M;F%M92P@)&%T=')I8G5T97,I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97)3=&%C:RLK.PH@
M("`@("`@("`@("`D=&AI<RT^7W-U8E!A<G-E<BT^<W1A<G1%;&5M96YT*"1U
M<FDL)&YA;64L)&%T=')I8G5T97,I.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?<W1A<G1%;&5M96YT*"1P87)S97(L("1T86<L("1A='1R:6)U
M=&5S*0H@("`@>PH@("`@("`@(&QI<W0H)'5R:2P@)&YA;64I(#T@)'1H:7,M
M/E]S<&QI=%5222@D=&%G*3L*"B`@("`@("`@)'1H:7,M/G-T87)T16QE;65N
M="@D=7)I+"`D;F%M92P@)&%T=')I8G5T97,I.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&]P87%U92@D;RD*("`@('L*("`@("`@("`D=&AI<RT^7V]U='!U="`N
M/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1544I.PH@("`@("`@
M(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@<W1R
M;&5N*"1O*2D["B`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@)&\["B`@("!]
M"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R<R@D8VAA<G,I"B`@("!["B`@("`@
M("`@)&-H87)S(#T@=')I;2@D8VAA<G,I.PH*("`@("`@("!I9B`H<W1R;&5N
M*"1C:&%R<RDI('L*("`@("`@("`@("`@+RH@5V4@9&5F:6YI=&5L>2!D;VXG
M="!W86YT(&%N>2!W:&ET97-P86-E+B`J+PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]S=6)087)S97(@/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@)&D@
M/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG970H)&-H87)S*3L*("`@("`@("`@
M("`@("`@(&EF("@D:2`A/2!N=6QL*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?
M4U127U0I.PH@("`@("`@("`@("`@("`@("`@(%A-3%]70EA-3#HZ:6YT5&]-
M0E5);G0S,B@D=&AI<RT^7V]U='!U="P@)&DI.PH@("`@("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N
M/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?22D["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G=R:71E4W1R:6YG*"1C:&%R<RP@)'1H:7,M
M/E]C:&%R<V5T*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YC:&%R
M86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M"@H@("`@9G5N8W1I;VX@7V-H87)A8W1E<G,H)'!A<G-E<BP@)&-H87)S*0H@
M("`@>PH@("`@("`@("1T:&ES+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("!]
M"@H@("`@9G5N8W1I;VX@=W)I=&5486<H)&YA;64L("1A='1R<RP@)&AA<T-O
M;G1E;G0L("1C<RD*("`@('L*("`@("`@("!I9B`H)&%T=')S("$](&YU;&P@
M)B8@(6-O=6YT*"1A='1R<RDI('L*("`@("`@("`@("`@)&%T=')S(#T@;G5L
M;#L*("`@("`@("!]"@H@("`@("`@("1T(#T@)'1H:7,M/E]D=&0M/G1O5&%G
M26YT*"1N86UE*3L*("`@("`@("!I9B`H)'0@/3T@+3$I('L*("`@("`@("`@
M("`@)&D@/2`D=&AI<RT^7W-T<FEN9U1A8FQE+3YG970H)&YA;64I.PH@("`@
M("`@("`@("!I9B`H)&D@/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1N86UE("X@)R!I<R!N;W0@9F]U;F0@
M:6X@4W1R:6YG(%1A8FQE(&]R($141"<I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:68@*"1A='1R<R`]/2!N=6QL("8F("$D:&%S
M0V]N=&5N="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PI.PH@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*"1A='1R<R`]/2!N=6QL("8F("1H87-#
M;VYT96YT*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@
M+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]!*3L*("`@
M("`@("`@("`@("`@('T@96QS96EF("@D871T<G,@(3T@;G5L;"`F)B`D:&%S
M0V]N=&5N="D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T
M("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204Q?0RD["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S("$](&YU;&P@)B8@(21H
M87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P
M=70@+CT@8VAR*%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E415)!3%]!0RD[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@6$U,7U="6$U,
M.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D:2D["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H)&%T=')S
M(#T](&YU;&P@)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]U='!U="`N/2!C:'(H)'0I.PH@("`@("`@("`@("!](&5L<V5I
M9B`H)&%T=')S(#T](&YU;&P@)B8@)&AA<T-O;G1E;G0I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<B@D="!\(#8T*3L*("`@("`@
M("`@("`@?2!E;'-E:68@*"1A='1R<R`A/2!N=6QL("8F("1H87-#;VYT96YT
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H)'0@
M?"`Q,C@I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&%T=')S("$](&YU;&P@
M)B8@(21H87-#;VYT96YT*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M='!U="`N/2!C:'(H)'0@?"`Q.3(I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)&%T=')S("$](&YU;&P@)B8@:7-?87)R87DH)&%T
M=')S*2`F)B!C;W5N="@D871T<G,I(#X@,"D@>PH@("`@("`@("`@("`D=&AI
M<RT^=W)I=&5!='1R:6)U=&5S*"1A='1R<RP@)&-S*3L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@=W)I=&5!='1R:6)U=&5S*"1A='1R<RP@)&-S
M*0H@("`@>PH@("`@("`@(&9O<F5A8V@@*"1A='1R<R!A<R`D;F%M92`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@)'1H:7,M/G=R:71E071T<FEB=71E*"1N
M86UE+"`D=F%L=64L("1C<RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7V]U='!U="`N/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%3D0I.PH@
M("`@?0H*("`@(&9U;F-T:6]N('=R:71E071T<FEB=71E*"1N86UE+"`D=F%L
M=64L("1C<RD*("`@('L*("`@("`@("`D82`]("1T:&ES+3Y?9'1D+3YT;T%T
M=')I8G5T92@D;F%M92D["B`@("`@("`@:68@*"1A(#T]("TQ*2!["B`@("`@
M("`@("`@("1I(#T@)'1H:7,M/E]S=')I;F=486)L92T^9V5T*"1N86UE*3L*
M("`@("`@("`@("`@:68@*"1I(#T](&YU;&PI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D;F%M92`N("<@:7,@;F]T(&9O
M=6YD(&EN(%-T<FEN9R!486)L92!O<B!$5$0G*3L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H<BA8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7TQ)5$5204PI.PH@("`@("`@("`@("`@
M("`@6$U,7U="6$U,.CII;G14;TU"54EN=#,R*"1T:&ES+3Y?;W5T<'5T+"`D
M:2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]U='!U="`N/2`D83L*("`@("`@("!]"@H@("`@("`@("1I
M(#T@)'1H:7,M/E]S=')I;F=486)L92T^9V5T*"1N86UE*3L*("`@("`@("!I
M9B`H)&D@(3T@;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N
M/2!C:'(H6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5"D["B`@("`@("`@
M("`@(%A-3%]70EA-3#HZ:6YT5&]-0E5);G0S,B@D=&AI<RT^7V]U='!U="P@
M)&DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M<'5T("X](&-H<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E])*3L*("`@
M("`@("`@("`@)'1H:7,M/G=R:71E4W1R:6YG*"1V86QU92P@)&-S*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D=7)I+"`D
M;F%M92D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]S=6)087)S97(@/3T@
M;G5L;"D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U='!U="`N/2!C:'(H6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%3D0I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R+3YE;F1%;&5M96YT*"1U<FDL
M("1N86UE*3L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S97)3=&%C:RTM
M.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W5B4&%R<V5R4W1A8VL@/3T@
M,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*%A-
M3%]70EA-3%]'3$]"04Q?5$]+14Y?3U!!455%*3L*"B`@("`@("`@("`@("`@
M("!834Q?5T)834PZ.FEN=%1O34)526YT,S(H)'1H:7,M/E]O=71P=70L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R;&5N
M*"1T:&ES+3Y?<W5B4&%R<V5R+3YG971/=71P=70H*2DI.PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@)'1H:7,M/E]S=6)087)S97(M/F=E
M=$]U='!U="@I.PH*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R
M(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?96YD16QE;65N="@D<&%R<V5R+"`D=&%G*0H@("`@>PH@("`@
M("`@(&QI<W0H)'5R:2P@)&YA;64I(#T@)'1H:7,M/E]S<&QI=%5222@D=&%G
M*3L*("`@("`@("`D=&AI<RT^96YD16QE;65N="@D=7)I+"`D;F%M92D["B`@
M("!]"@H@("`@9G5N8W1I;VX@8VAA;F=E8V]D97!A9V4H)'5R:2D*("`@('L*
M("`@("`@("`O+R!`=&]D;SH@=&AI<R!I<R!A(&AA8VLA"B`@("`@("`@:68@
M*"1T:&ES+3Y?9'1D+3YG971697)S:6]N*"D@/3T@,2`F)B`A<')E9U]M871C
M:"@G+S%<+C$D+R<L("1U<FDI*2!["B`@("`@("`@("`@("1U<FD@+CT@)S$N
M,2<["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7V1T9"T^9V5T5F5R
M<VEO;B@I(#T](#`@)B8@(7!R96=?;6%T8V@H)R\Q7"XP)"\G+"`D=7)I*2D@
M>PH@("`@("`@("`@("`D=7)I("X]("<Q+C`G.PH@("`@("`@('T*("`@("`@
M("`*("`@("`@("`D8W`@/2`D=&AI<RT^7V1T9"T^=&]#;V1E4&%G955222@D
M=7)I*3L*("`@("`@("!I9B`H<W1R;&5N*"1C<"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]D=&0@/2`F)'1H:7,M/E]D=&1-86YA9V5R+3YG971);G-T86YC
M955222@D=7)I*3L*"B`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T("X](&-H
M<BA834Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-7251#2%]004=%*3L*("`@("`@
M("`@("`@)'1H:7,M/E]O=71P=70@+CT@8VAR*"1C<"D["B`@("`@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=%5222`]("1U<FD["@H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?<W5B4&%R<V5R(#T@)FYE=R!834Q?5T)8
M34Q?16YC;V1E<BAT<G5E*3L*("`@("`@("`@("`@)'1H:7,M/E]S=6)087)S
M97)3=&%C:R`](#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T=&5R(&9O<B!P<F]P97)T>2!O=71P=70N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$]U='!U="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M;W5T<'5T.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]U='!U=%-I>F4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!S=')L96XH)'1H:7,M/E]O=71P=70I.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O6$U,+U="
M6$U,+T1E8V]D97(N<&AP````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P-#<W,3<@,3`U,34T,S0Q,S8@,#(Q-S,R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@II;F-L=61E7V]N
M8V4@)UA-3"]70EA-3"YP:'`G.PII;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$
M5$1-86YA9V5R+G!H<"<["FEN8VQU9&5?;VYC92`G6$U,+U="6$U,+T-O;G1E
M;G1(86YD;&5R+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,
M7U="6$U,+U="6$U,+T1E8V]D97(N<&AP+'8@,2XR,BXQ,"XX(#(P,#8O,#$O
M,#$@,C$Z,C@Z-#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P
M,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!&<F]M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@
M4W!E8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@,C4@2G5L>0H@*B`R,#`Q(&9O
M=6YD(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J($!P86-K86=E
M(%A-3%]70EA-3`H@*B\*8VQA<W,@6$U,7U="6$U,7T1E8V]D97(@97AT96YD
M<R!834Q?5T)834Q?0V]N=&5N=$AA;F1L97(@>PH*("`@("\J*@H@("`@("H@
M1&]C=6UE;G0@4'5B;&EC($ED96YT:69I97(@='EP90H@("`@("H@,2!M8E]U
M7VEN=#,R('=E;&P@:VYO=VX@='EP90H@("`@("H@,B!S=')I;F<@=&%B;&4*
M("`@("`J(&9R;VT@<W!E8R!B=70@8V]N=F5R=&5D(&EN=&\@82!S=')I;F<N
M"B`@("`@*@H@("`@("H@1&]C=6UE;G0@4'5B;&EC($ED96YT:69I97(*("`@
M("`J(%5S960@=VET:"!D<&E4>7!E+@H@("`@("HO"B`@("!V87(@)%]D<&D[
M"@H@("`@+RHJ"B`@("`@*B!3=')I;F<@=&%B;&4@87,@9&5F:6YE9"!I;B`U
M+C<*("`@("`J+PH@("`@=F%R("1?<W1R:6YG5&%B;&4@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V]N=&5N="!H86YD;&5R+@H@("`@("H@0W5R<F5N
M=&QY(&IU<W0@;W5T<'5T<R!R87<@6$U,+@H@("`@("HO"B`@("!V87(@)%]C
M:#L*"B`@("!V87(@)%]T86=$5$0["@H@("`@=F%R("1?<')E=D%T=')I8G5T
M94141#L*"B`@("!V87(@)%]A='1R:6)U=&5$5$0["@H@("`@+RHJ"B`@("`@
M*B!3=&%T92!V87)I86)L97,N"B`@("`@*B\*("`@('9A<B`D7W1A9U-T86-K
M(#T@87)R87DH*3L*("`@('9A<B`D7VES071T<FEB=71E.PH@("`@=F%R("1?
M:7-$871A(#T@9F%L<V4["@H@("`@=F%R("1?97)R;W(@/2!F86QS93L*"B`@
M("`O*BH*("`@("`J(%1H92!$5$0@36%N86=E<BX*("`@("`J"B`@("`@*B!`
M=F%R(%A-3%]70EA-3%]$5$1-86YA9V5R"B`@("`@*B\*("`@('9A<B`D7V1T
M9$UA;F%G97(["@H@("`@+RHJ"B`@("`@*B!4:&4@<W1R:6YG('!O<VET:6]N
M+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@
M)%]S=')P;W,["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@6$U,7U="6$U,7T1E8V]D97(H*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?9'1D36%N86=E<B`]("9N97<@6$U,7U="6$U,7T141$UA
M;F%G97(H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&-O;G1E
M;G1(86YD;&5R('1H870@=VEL;"!R96-E:79E('1H92!O=71P=70@;V8@=&AE
M"B`@("`@*B!D96-O9&EN9RX*("`@("`J"B`@("`@*B!`<&%R86T@6$U,7U="
M6$U,7T-O;G1E;G1(86YD;&5R("1C:"!4:&4@8V]N=&5N=$AA;F1L97(*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T0V]N=&5N=$AA;F1L97(H)B1C:"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V-H(#T@)B1C:#L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;B!O;F4@8GET92!F<F]M('1H92!I;G!U="!S=')E86TN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:6YP=70@(%1H92!70EA-
M3"!I;G!U="!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$)Y=&4H
M)&EN<'5T*0H@("`@>PH@("`@("`@(')E='5R;B!O<F0H)&EN<'5T>R1T:&ES
M+3Y?<W1R<&]S*RM]*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V5S(&$@
M5T)834P@:6YP=70@9&]C=6UE;G0@86YD(')E='5R;G,@9&5C;V1E9"!834PN
M"B`@("`@*B!(;W=E=F5R('1H92!P<F5F97)R960@86YD(&UO<F4@969F96-I
M96YT(&UE=&AO9"!I<R!T;PH@("`@("H@=7-E(&1E8V]D92@I(')A=&AE<B!T
M:&%N(&1E8V]D951O4W1R:6YG*"D@86YD(&AA=F4@86X*("`@("`J(&%P<')O
M<')I871E(&-O;G1E;G1(86YD;&5R(&1E86P@=VET:"!T:&4@9&5C;V1E9"!D
M871A+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'=B>&UL("!4:&4@
M5T)834P@9&]C=6UE;G0@=&\@9&5C;V1E+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!4:&4@9&5C;V1E9"!834P@9&]C=6UE;G0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&1E8V]D951O4W1R:6YG*"1W8GAM;"D*("`@('L*("`@
M("`@("`D=&AI<RT^7V-H(#T@)FYE=R!834Q?5T)834Q?0V]N=&5N=$AA;F1L
M97(H*3L*"B`@("`@("`@)'(@/2`D=&AI<RT^9&5C;V1E*"1W8GAM;"D["B`@
M("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M
M/E]C:"T^9V5T3W5T<'5T*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME
M<R!A(%="6$U,(&EN<'5T(&1O8W5M96YT(&%N9"!D96-O9&5S(&ET+@H@("`@
M("H@1&5C;V1I;F<@<F5S=6QT(&ES(&1I<F5C=&QY('!A<W-E9"!T;R!T:&4@
M8V]N=&5N=$AA;F1L97(N"B`@("`@*B!!(&-O;G1E;G1H86YD;&5R(&UU<W0@
M8F4@<V5T('5S:6YG('-E=$-O;G1E;G1(86YD;&5R"B`@("`@*B!P<FEO<B!T
M;R!I;G9O8V%T:6]N(&]F('1H:7,@;65T:&]D"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=V)X;6P@(%1H92!70EA-3"!D;V-U;65N="!T;R!D96-O
M9&4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@5')U92!O;B!S=6-C
M97-S(&]R(%!%05)?17)R;W(N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D
M92@D=V)X;6PI"B`@("!["B`@("`@("`@)'1H:7,M/E]E<G)O<B`](&9A;'-E
M.R`O+R!R97-E="!S=&%T90H*("`@("`@("`D=&AI<RT^7W-T<G!O<R`](#`[
M"@H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V-H*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TYO($-O;G1E;G1H86YD;&5R
M(&1E9FEN960N)RD["B`@("`@("`@?0H*("`@("`@("`O+R!'970@5F5R<VEO
M;B!.=6UB97(@9G)O;2!396-T:6]N(#4N-`H@("`@("`@("\O('9E<G-I;VX@
M/2!U7VEN=#@*("`@("`@("`O+R!C=7)R96YT;'D@,2P@,B!O<B`S"B`@("`@
M("`@)'1H:7,M/E]W8GAM;%9E<G-I;VX@/2`D=&AI<RT^9V5T5F5R<VEO;DYU
M;6)E<B@D=V)X;6PI.PH*("`@("`@("`O+R!'970@1&]C=6UE;G0@4'5B;&EC
M($ED971I9FEE<B!F<F]M(%-E8W1I;VX@-2XU"B`@("`@("`@+R\@<'5B;&EC
M:60@/2!M8E]U7VEN=#,R('P@*'IE<F\@:6YD97@I"B`@("`@("`@+R\@>F5R
M;R`]('5?:6YT.`H@("`@("`@("\O($-O;G1A:6YI;F<@=&AE('9A;'5E('IE
M<F\@*#`I"B`@("`@("`@+R\@5&AE(&%C='5A;"!$4$D@:7,@9&5T97)M:6YE
M9"!A9G1E<B!T:&4@4W1R:6YG(%1A8FQE(&ES(')E860N"B`@("`@("`@)&1P
M:5-T<G5C="`]("1T:&ES+3YG971$;V-U;65N=%!U8FQI8TED96YT:69I97(H
M)'=B>&UL*3L*"B`@("`@("`@+R\@1V5T($-H87)S970@9G)O;2`U+C8*("`@
M("`@("`O+R!C:&%R<V5T(#T@;6)?=5]I;G0S,@H@("`@("`@("1T:&ES+3Y?
M8VAA<G-E="`]("1T:&ES+3YG971#:&%R<V5T*"1W8GAM;"D["@H@("`@("`@
M("\O($=E="!3=')I;F<@5&%B;&4@9G)O;2`U+C<*("`@("`@("`O+R!S=')B
M,2`](&QE;F=T:"`J8GET90H@("`@("`@("1T:&ES+3YR971R:65V95-T<FEN
M9U1A8FQE*"1W8GAM;"D["@H@("`@("`@("\O($=E="!$;V-U;65N="!0=6)L
M:6,@261E=&EF:65R(&9R;VT@4V5C=&EO;B`U+C4N"B`@("`@("`@)'1H:7,M
M/E]D<&D@/2`D=&AI<RT^9V5T1&]C=6UE;G10=6)L:6-)9&5N=&EF:65R26UP
M;"@D9'!I4W1R=6-T6R=D<&E4>7!E)UTL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'!I
M4W1R=6-T6R=D<&E.=6UB97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<W1R:6YG5&%B;&4I.PH*("`@("`@("`O+R!.;W<@=&AE(')E86P@9G5N(&)E
M9VEN<RX*("`@("`@("`O+R!&<F]M(%-E8W1I;VYS(#4N,B!A;F0@-2XX"@H*
M("`@("`@("`O+R!$969A=6QT(&-O;G1E;G0@:&%N9&QE<BX*("`@("`@("`D
M=&AI<RT^7V1T9$UA;F%G97(@/2`F;F5W(%A-3%]70EA-3%]$5$1-86YA9V5R
M*"D["@H@("`@("`@("\O($=E="!T:&4@<W1A<G1I;F<@1%1$+@H@("`@("`@
M("1T:&ES+3Y?=&%G1%1$(#T@)'1H:7,M/E]D=&1-86YA9V5R+3YG971);G-T
M86YC92@D=&AI<RT^7V1P:2D["@H@("`@("`@(&EF("@A)'1H:7,M/E]T86=$
M5$0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=.
M;R!$5$0@9F]U;F0@9F]R("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("1T:&ES+3Y?9'!I("X@)R\G"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D9'!I4W1R=6-T6R=D<&E.=6UB97(G72D["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^7V%T=')I8G5T94141"`]("1T:&ES+3Y?=&%G1%1$
M.PH*("`@("`@("!W:&EL92`H96UP='DH)'1H:7,M/E]E<G)O<BD@)B8@)'1H
M:7,M/E]S=')P;W,@/"!S=')L96XH)'=B>&UL*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V1E8V]D92@D=V)X;6PI.PH@("`@("`@('T*("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?97)R;W(I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V5R<F]R.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971697)S:6]N3G5M8F5R*"1I;G!U="D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$)Y=&4H)&EN<'5T*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971$;V-U;65N=%!U8FQI8TED96YT:69I
M97(H)&EN<'5T*0H@("`@>PH@("`@("`@("1I(#T@6$U,7U="6$U,.CI-0E5)
M;G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I.PH@("`@("`@(&EF
M("@D:2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G9'!I5'EP
M92<@/3X@,BP*("`@("`@("`@("`@("`@("`@("`@("`@("=D<&E.=6UB97(G
M(#T^("1T:&ES+3YG971">71E*"1I;G!U="DI.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G9'!I5'EP92<@/3X@,2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("=D<&E.=6UB97(G(#T^("1I*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1&]C=6UE;G10=6)L:6-)
M9&5N=&EF:65R26UP;"@D9'!I5'EP92P@)&1P:4YU;6)E<BD*("`@('L*("`@
M("`@("!I9B`H)&1P:51Y<&4@/3T@,2D@>PH@("`@("`@("`@("!R971U<FX@
M6$U,7U="6$U,.CIG971$4$E3=')I;F<H)&1P:4YU;6)E<BD["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG9713=')I;F=4
M86)L945N=')Y*"1D<&E.=6UB97(I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&-H87)A8W1E<B!E;F-O9&EN9RX@3VYL
M>2!D969A=6QT(&-H87)A8W1E<@H@("`@("H@96YC;V1I;F=S(&9R;VT@2C)3
M12!A<F4@<W5P<&]R=&5D+B`@1G)O;0H@("`@("H@:'1T<#HO+W=W=RYI86YA
M+F]R9R]A<W-I9VYM96YT<R]C:&%R86-T97(M<V5T<R!A;F0*("`@("`J(&AT
M='`Z+R]J879A+G-U;BYC;VTO:C)S92\Q+C0N,B]D;V-S+V%P:2]J879A+VYI
M;R]C:&%R<V5T+T-H87)S970N:'1M;`H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971#:&%R<V5T*"1I;G!U="D*("`@('L*("`@("`@("`D8W,@/2!834Q?5T)8
M34PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RD["B`@
M("`@("`@<F5T=7)N(%A-3%]70EA-3#HZ9V5T0VAA<G-E=%-T<FEN9R@D8W,I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!S=')I;F<@
M=&%B;&4N"B`@("`@*B!4:&4@<W1R:6YG('1A8FQE(&-O;G-I<W1S(&]F(&%N
M(&UB7W5?:6YT,S(@;&5N9W1H"B`@("`@*B!A;F0@=&AE;B!L96YG=&@@8GET
M97,@9F]R;6EN9R!T:&4@=&%B;&4N"B`@("`@*B!2969E<F5N8V5S('1O('1H
M92!S=')I;F<@=&%B;&4@<F5F97(@=&\@=&AE"B`@("`@*B!S=&%R=&EN9R!P
M;W-I=&EO;B!O9B!T:&4@*&YU;&P@=&5R;6EN871E9"D*("`@("`J('-T<FEN
M9R!I;B!T:&ES('1A8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R971R:65V
M95-T<FEN9U1A8FQE*"1I;G!U="D*("`@('L*("`@("`@("`D<VEZ92`](%A-
M3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S
M*3L*("`@("`@("`D=&AI<RT^7W-T<FEN9U1A8FQE(#T@<W5B<W1R*"1I;G!U
M="P@)'1H:7,M/E]S=')P;W,L("1S:7IE*3L*("`@("`@("`D=&AI<RT^7W-T
M<G!O<R`K/2`D<VEZ93L*("`@("`@("`O+R!P<FEN="`B<W1R:6YG=&%B;&4H
M)'-I>F4I.B(@+B`D=&AI<RT^7W-T<FEN9U1A8FQE("XB7&XB.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&=E=%-T<FEN9U1A8FQE16YT<GDH)&EN9&5X*0H@("`@
M>PH@("`@("`@(&EF("@D:6YD97@@/CT@<W1R;&5N*"1T:&ES+3Y?<W1R:6YG
M5&%B;&4I*2!["B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(@/0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C:"T^<F%I<V5%<G)O<B@G26YV86QI9"!O9F9S
M970@)R`N("1I;F1E>`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`G('9A;'5E(&5N8V]U;G1E<F5D(&%R;W5N9"!P;W-I=&EO;B`G
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES
M+3Y?<W1R<&]S"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("<N($)R;VME;B!W8GAM;#\G*3L*("`@("`@("`@("`@<F5T=7)N("<G
M.PH@("`@("`@('T*"B`@("`@("`@+R\@8V]P>2!O9B!M971H;V0@=&5R;7-T
M<B!B=70@=VET:&]U="!M;V1I9FEC871I;VX@;V8@=&AI<RT^7W-T<G!O<PH*
M("`@("`@("`D<W1R(#T@)R,G.R`O+R!M=7-T('-T87)T('=I=&@@;F]N96UP
M='D@<W1R:6YG('1O(&%L;&]W(&%R<F%Y(&%C8V5S<PH*("`@("`@("`D:2`]
M(#`["B`@("`@("`@)&-H(#T@)'1H:7,M/E]S=')I;F=486)L95LD:6YD97@K
M*UT["B`@("`@("`@:68@*&]R9"@D8V@I(#T](#`I('L*("`@("`@("`@("`@
M<F5T=7)N("<G.R`O+R!D;VXG="!R971U<FX@)R,G"B`@("`@("`@?0H*("`@
M("`@("!W:&EL92`H;W)D*"1C:"D@(3T@,"D@>PH@("`@("`@("`@("`D<W1R
M6R1I*RM=(#T@)&-H.PH@("`@("`@("`@("!I9B`H)&EN9&5X(#X]('-T<FQE
M;B@D=&AI<RT^7W-T<FEN9U1A8FQE*2D@>PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-H(#T@)'1H:7,M/E]S
M=')I;F=486)L95LD:6YD97@K*UT["B`@("`@("`@?0H@("`@("`@("\O('!R
M:6YT(")S=')I;F<@=&%B;&4@96YT<GDZ("1S=')<;B(["B`@("`@("`@<F5T
M=7)N("1S='(["@H@("`@?0H*("`@(&9U;F-T:6]N(%]D96-O9&4H)&EN<'5T
M*0H@("`@>PH@("`@("`@("1T;VME;B`]("1T:&ES+3YG971">71E*"1I;G!U
M="D["B`@("`@("`@)'-T<B`]("<G.PH*("`@("`@("`O+R!P<FEN="`B<&]S
M:71I;VXZ("(@+B`D=&AI<RT^7W-T<G!O<R`N("(@=&]K96XZ("(@+B`D=&]K
M96X@+B`B('-T<C$P.B`B("X@<W5B<W1R*"1I;G!U="P@)'1H:7,M/E]S=')P
M;W,L(#$P*2`N(")<;B([("\O($!T;V1O.B!R96UO=F4@9&5B=6<@;W5T<'5T
M"@H@("`@("`@('-W:71C:"`H)'1O:V5N*2!["B`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]).@H@("`@("`@("`@("`O+R!396-T
M:6]N(#4N."XT+C$*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YT97)M<W1R
M*"1I;G!U="D["B`@("`@("`@("`@("1T:&ES+3Y?8V@M/F-H87)A8W1E<G,H
M)'-T<BD["B`@("`@("`@("`@("\O('!R:6YT(")S='(Z)'-T<EQN(CL@+R\@
M0%1/1$\@4F5M;W9E(&1E8G5G(&-O9&4*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]35%)?5#H*("`@
M("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@("`@("1X(#T@
M6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P
M;W,I.PH@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN9U1A8FQE
M16YT<GDH)'@I.PH@("`@("`@("`@("`D=&AI<RT^7V-H+3YC:&%R86-T97)S
M*"1S='(I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S`Z"B`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S$Z"B`@("`@("`@8V%S92!834Q?
M5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S(Z"B`@("`@("`@("`@("\O(%-E
M8W1I;VX@-2XX+C0N,@H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/G1E<FUS
M='(H)&EN<'5T*3L*("`@("`@("`@("`@)'1H:7,M/E]C:"T^8VAA<F%C=&5R
M<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\P.@H@("`@("`@(&-A<V4@6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\Q.@H@("`@("`@(&-A<V4@6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?5%\R.@H@("`@("`@("`@("`O+R!3
M96-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)'-T<B`]("1T:&ES+3YG9713
M=')I;F=486)L945N='DH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U
M="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/E]C:"T^
M8VAA<F%C=&5R<R@D<W1R*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?,#H*("`@("`@("!C
M87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47S$Z"B`@("`@("`@8V%S
M92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%\R.@H@("`@("`@("`@("`O
M+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@)&5X=&5N<VEO;B`]("1T
M:&ES+3YG971">71E*"1I;G!U="D["B`@("`@("`@("`@("1T:&ES+3Y?8V@M
M/F-H87)A8W1E<G,H)&5X=&5N<VEO;BD["B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?14Y42519.@H@
M("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C,*("`@("`@("`@("`@+R\@
M54-3+30@8VAR86-T97(@96YC;V1I;F<_"B`@("`@("`@("`@("1E;G1I='D@
M/2`D=&AI<RT^96YT:71Y*%A-3%]70EA-3#HZ34)526YT,S)4;TEN="@D:6YP
M=70L("1T:&ES+3Y?<W1R<&]S*2D["@H@("`@("`@("`@("`D=&AI<RT^7V-H
M+3YC:&%R86-T97)S*"<F(R<@+B`D96YT:71Y("X@)SLG*3L*("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%
M3E]023H*("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XT"B`@("`@("`@
M("`@("\O('1H<F]W(&YE=R!)3T5X8V5P=&EO;@H@("`@("`@("`@("`O+R!D
M:64H(E="6$U,(&=L;V)A;"!T;VME;B!P<F]C97-S:6YG(&EN<W1R=6-T:6]N
M*%!)+"`B("L@=&]K96X@*R`B*2!I<R!U;G-U<'!O<G1E9"%<;B(I.PH@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,
M7U1/2T5.7TQ)5$5204PZ"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N
M-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT
M<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S
M=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G*"1I;G!U="P@
M)'-T<BP@9F%L<V4L(&9A;'-E*3L*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]43TM%3E],251%4D%,7T$Z"B`@
M("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-0H@("`@("`@("`@("`D<W1R
M(#T@)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5)
M;G0S,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@
M("`@)'1H:7,M/G!A<G-E5&%G*"1I;G!U="P@)'-T<BP@=')U92P@9F%L<V4I
M.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92!834Q?5T)834Q?
M1TQ/0D%,7U1/2T5.7TQ)5$5204Q?04,Z"B`@("`@("`@("`@("\O(%-E8W1I
M;VX@-2XX+C0N-0H@("`@("`@("`@("`D<W1R(#T@)'1H:7,M/F=E=%-T<FEN
M9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT*"1I;G!U="P@
M)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@)'1H:7,M/G!A<G-E5&%G
M*"1I;G!U="P@)'-T<FEN9RP@=')U92P@=')U92D["B`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?3$E4
M15)!3%]#.@H@("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C4*("`@("`@
M("`@("`@)'-T<B`]("1T:&ES+3YG9713=')I;F=486)L945N=')Y*%A-3%]7
M0EA-3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*2D[
M"B`@("`@("`@("`@("1T:&ES+3YP87)S951A9R@D:6YP=70L("1S='(L(&9A
M;'-E+"!T<G5E*3L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M6$U,7U="6$U,7T=,3T)!3%]43TM%3E]/4$%1544Z"B`@("`@("`@("`@("\O
M(%-E8W1I;VX@-2XX+C0N-@H@("`@("`@("`@("`D<VEZ92`](%A-3%]70EA-
M3#HZ34)526YT,S)4;TEN="@D:6YP=70L("1T:&ES+3Y?<W1R<&]S*3L*("`@
M("`@("`@("`@+R\@<')I;G0@(F]P87%U92!O9B!S:7IE("1S:7IE7&XB.R`O
M+R!`=&]D;R!R96UO=F4@9&5B=6<*("`@("`@("`@("`@)&(@/2!S=6)S='(H
M)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RP@)'-I>F4I.PH@("`@("`@("`@("`D
M=&AI<RT^7W-T<G!O<R`K/2`D<VEZ93L*"B`@("`@("`@("`@("\O(&]P87%U
M92!D871A(&EN<VED92!A(#QD871A/B!E;&5M96YT(&UA>2!O<B!M87D@;F]T
M(&)E"B`@("`@("`@("`@("\O(&$@;F5S=&5D('=B>&UL(&1O8W5M96YT("AF
M;W(@97AA;7!L92!D979I;F8@9&%T82DN"B`@("`@("`@("`@("\O(%=E(&9I
M;F0@;W5T(&)Y(&-H96-K:6YG('1H92!F:7)S="!B>71E(&]F('1H92!D871A
M.B!I9B!I="=S"B`@("`@("`@("`@("\O(#$L(#(@;W(@,R!W92!E>'!E8W0@
M:70@=&\@8F4@=&AE('9E<G-I;VX@;G5M8F5R(&]F(&$@=V)X;6P*("`@("`@
M("`@("`@+R\@9&]C=6UE;G0@86YD('1H=7,@<W1A<G0@82!N97<@=V)X;6P@
M9&5C;V1E<B!I;G-T86YC92!O;B!I="X*"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7VES1&%T82`F)B!O<F0H)&(I(#P](#$P*2!["B`@("`@("`@("`@("`@
M("`D9&5C;V1E<B`]("9N97<@6$U,7U="6$U,7T1E8V]D97(H=')U92D["B`@
M("`@("`@("`@("`@("`D9&5C;V1E<BT^<V5T0V]N=&5N=$AA;F1L97(H)'1H
M:7,M/E]C:"D["B`@("`@("`@("`@("`@("`D<R`]("1D96-O9&5R+3YD96-O
M9&4H)&(I.PH@("`@("`@("\O("`@("`@("`@("`@("`@("\J("\O($!T;V1O
M.B!&25A-12!C=7)R96YT;'D@=V4@8V%N)W0@9&5C;V1E($YO:VEA"B`@("`@
M("`@("`@("`@("`O+R!$979);F8@9&%T82X@4V\@:6=N;W)E(&5R<F]R(&9O
M<B!T:&4@=&EM92!B965I;F<N"B`@("`@("`@:68@*&ES7V$H)',L("=014%2
M7T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R
M(#T@)',["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@+R\@*B\*("`@("`@("`@("`@("`@
M("\O("1T:&ES+3Y?8V@M/F-H87)A8W1E<G,H)',I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@;F]R;6%L(&]P87%U92!B96AA
M=FEO=7(Z(&IU<W0@8V]P>2!T:&4@<F%W(&1A=&$Z("HO"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-H+3YC:&%R86-T97)S*"`D8BD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("\O(&]L9"!A<'!R;V%C:"!T;R!D96%L('=I=&@@
M;W!A<75E(&1A=&$@:6YS:61E($-O;G1E;G1(86YD;&5R.@H@("`@("`@("`@
M("`O+R!&25A-12!/<&%Q=64@:7,@=7-E9"!B>2!364Y#34PN("!/<&%Q=64@
M9&%T82!T:&%T(&1E<&5N9',@;VX@=&AE(&-O;G1E>'0*("`@("`@("`@("`@
M+R\@:68@*&-O;G1E;G1(86YD;&5R(&EN<W1A;F-E;V8@3W!A<75E0V]N=&5N
M=$AA;F1L97(I('L*("`@("`@("`@("`@+R\@("`@("@H3W!A<75E0V]N=&5N
M=$AA;F1L97(I8V]N=&5N=$AA;F1L97(I+F]P87%U92AB*3L*("`@("`@("`@
M("`@+R\@?2!E;'-E('L*("`@("`@("`@("`@+R\@("`@(%-T<FEN9R!S='(@
M/2!N97<@4W1R:6YG*&(L(#`L('-I>F4L(&-H87)S970I.PH@("`@("`@("`@
M("`O+R`@("`@8VAA<EM=(&-H87)S(#T@<W1R+G1O0VAA<D%R<F%Y*"D["@H@
M("`@("`@("`@("`O+R`@("`@8V]N=&5N=$AA;F1L97(N8VAA<F%C=&5R<RAC
M:&%R<RP@,"P@8VAA<G,N;&5N9W1H*3L*("`@("`@("`@("`@+R\@?0H*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!
M3%]43TM%3E]%3D0Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N-RXQ
M"B`@("`@("`@("`@("1S='(@/2`D=&AI<RT^96YD5&%G*"D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+
M14Y?4U=)5$-(7U!!1T4Z"B`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N
M-RXR"B`@("`@("`@("`@("1C;V1E4&%G92`]("1T:&ES+3YG971">71E*"1I
M;G!U="D["B`@("`@("`@("`@("\O('!R:6YT(")S=VET8V@@=&\@8V]D97!A
M9V4@)&-O9&5086=E7&XB.R`O+R!`=&]D;SH@<F5M;W9E(&1E8G5G(&-O9&4*
M("`@("`@("`@("`@)'1H:7,M/G-W:71C:$5L96UE;G1#;V1E4&%G92@D8V]D
M95!A9V4I.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N,@H@("`@("`@("`@("`O+R!3
M96-T:6]N(#4N."XS"B`@("`@("`@("`@("1H87-!='1R:6)U=&5S(#T@*"@D
M=&]K96X@)B`P>#@P*2`A/2`P*3L*("`@("`@("`@("`@)&AA<T-O;G1E;G0@
M/2`H*"1T;VME;B`F(#!X-#`I("$](#`I.PH@("`@("`@("`@("`D<F5A;%1O
M:V5N(#T@)'1O:V5N("8@,'@S1CL*("`@("`@("`@("`@)'-T<B`]("1T:&ES
M+3YG971486<H)')E86Q4;VME;BD["@H@("`@("`@("`@("`O+R!P<FEN="`B
M96QE;65N=#HD<W1R7&XB.R`O+R!`5$]$3R!296UO=F4@9&5B=6<@8V]D90H@
M("`@("`@("`@("`D=&AI<RT^<&%R<V5486<H)&EN<'5T+"`D<W1R+"`D:&%S
M071T<FEB=71E<RP@)&AA<T-O;G1E;G0I.PH*("`@("`@("`@("`@:68@*"1R
M96%L5&]K96X@/3T@,'@P9BD@>PH@("`@("`@("`@("`@("`@+R\@<W1O<F4@
M:68@=V4G<F4@:6YS:61E(&$@1&%T82!T86<N(%1H:7,@;6%Y(&-O;G1A:6X*
M("`@("`@("`@("`@("`@("\O(&%N(&%D9&ET:6]N86P@96YC;&]S960@=V)X
M;6P@9&]C=6UE;G0@;VX@=VAI8V@@=V4@:&%V90H@("`@("`@("`@("`@("`@
M+R\@=&\@<G5N(&$@<V5P97)A=&4@96YC;V1E<@H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I<T1A=&$@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I<T1A=&$@/2!F86QS93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@<&%R<V5486<H)&EN<'5T+"`D=&%G+"`D:&%S071T<FEB
M=71E<RP@)&AA<T-O;G1E;G0I"B`@("!["B`@("`@("`@)&%T=')S(#T@87)R
M87DH*3L*("`@("`@("!I9B`H)&AA<T%T=')I8G5T97,I('L*("`@("`@("`@
M("`@)&%T=')S(#T@)'1H:7,M/F=E=$%T=')I8G5T97,H)&EN<'5T*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3Y?8V@M/G-T87)T16QE;65N="@D=&AI
M<RT^9V5T0W5R<F5N=%5222@I+"`D=&%G+"`D871T<G,I.PH*("`@("`@("!I
M9B`H)&AA<T-O;G1E;G0I('L*("`@("`@("`@("`@+R\@1DE8344@22!F;W)G
M;W0@=VAA="!D;V5S('1H:7,@9&]E<RX@3F]T('-U<F4@:68@=&AI<R!I<PH@
M("`@("`@("`@("`O+R!R:6=H=#\*("`@("`@("`@("`@)'1H:7,M/E]T86=3
M=&%C:UM=(#T@)'1A9SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&AI<RT^7V-H+3YE;F1%;&5M96YT*"1T:&ES+3YG971#=7)R96YT55))*"DL
M("1T86<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!E;F1486<H
M*0H@("`@>PH@("`@("`@(&EF("AC;W5N="@D=&AI<RT^7W1A9U-T86-K*2D@
M>PH@("`@("`@("`@("`D=&%G(#T@87)R87E?<&]P*"1T:&ES+3Y?=&%G4W1A
M8VLI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86<@/2`G56YK
M;F]W;B<["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H+3YE;F1%;&5M
M96YT*"1T:&ES+3YG971#=7)R96YT55))*"DL("1T86<I.PH*("`@("`@("!R
M971U<FX@)'1A9SL*("`@('T*"B`@("!F=6YC=&EO;B!G971!='1R:6)U=&5S
M*"1I;G!U="D*("`@('L*("`@("`@("`D=&AI<RT^<W1A<G1'971!='1R:6)U
M=&5S*"D["B`@("`@("`@)&AA<TUO<F5!='1R:6)U=&5S(#T@=')U93L*"B`@
M("`@("`@)&%T=')S(#T@87)R87DH*3L*("`@("`@("`D871T<B`](&YU;&P[
M"B`@("`@("`@)'9A;'5E(#T@;G5L;#L*("`@("`@("`D=&]K96X@/2!N=6QL
M.PH*("`@("`@("!W:&EL92`H)&AA<TUO<F5!='1R:6)U=&5S*2!["B`@("`@
M("`@("`@("1T;VME;B`]("1T:&ES+3YG971">71E*"1I;G!U="D["@H@("`@
M("`@("`@("!S=VET8V@@*"1T;VME;BD@>PH@("`@("`@("`@("`O+R!!='1R
M:6)U=&4@<W!E8VEF:65D+@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'
M3$]"04Q?5$]+14Y?3$E415)!3#H*("`@("`@("`@("`@("`@("\O(%-E8W1I
M;VX@-2XX+C0N-0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1A='1R<UM=(#T@87)R87DH)V%T=')I
M8G5T92<@/3X@)&%T='(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F%L=64G(#T^("1V86QU92D["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)&%T='(@/2`D=&AI<RT^9V5T4W1R:6YG5&%B
M;&5%;G1R>2A834Q?5T)834PZ.DU"54EN=#,R5&]);G0H)&EN<'5T+"`D=&AI
M<RT^7W-T<G!O<RDI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("`O+R!686QU92!S<&5C:69I960N"B`@("`@("`@("`@(&-A<V4@6$U,
M7U="6$U,7T=,3T)!3%]43TM%3E]%6%1?25\P.@H@("`@("`@("`@("!C87-E
M(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?15A47TE?,3H*("`@("`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T585%])7S(Z"B`@("`@("`@
M("`@("`@("`O+R!396-T:6]N(#4N."XT+C(*("`@("`@("`@("`@("`@("1V
M86QU92`N/2`D=&AI<RT^=&5R;7-T<B@D:6YP=70I.PH@("`@("`@("`@("`@
M("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?
M5$]+14Y?15A47U1?,#H*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/
M0D%,7U1/2T5.7T585%]47S$Z"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,
M7T=,3T)!3%]43TM%3E]%6%1?5%\R.@H@("`@("`@("`@("`@("`@+R\@4V5C
M=&EO;B`U+C@N-"XR"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@)'1H:7,M
M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT
M*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.
M7T585%\P.@H@("`@("`@("`@("!C87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+
M14Y?15A47S$Z"B`@("`@("`@("`@(&-A<V4@6$U,7U="6$U,7T=,3T)!3%]4
M3TM%3E]%6%1?,CH*("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX+C0N
M,@H@("`@("`@("`@("`@("`@)'9A;'5E("X]("1I;G!U=%LD=&AI<RT^7W-T
M<G!O<RLK73L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.5$E463H*("`@("`@("`@
M("`@("`@("\O(%-E8W1I;VX@-2XX+C0N,PH@("`@("`@("`@("`@("`@)'9A
M;'5E("X]("1T:&ES+3YE;G1I='DH6$U,7U="6$U,.CI-0E5);G0S,E1O26YT
M*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,7U1/2T5.
M7U-44E]).@H@("`@("`@("`@("`@("`@+R\@4V5C=&EO;B`U+C@N-"XQ"B`@
M("`@("`@("`@("`@("`D=F%L=64@+CT@)'1H:7,M/G1E<FUS='(H)&EN<'5T
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7U-44E]4.@H@("`@("`@("`@("`@("`@
M+R\@4V5C=&EO;B`U+C@N-"XQ"B`@("`@("`@("`@("`@("`D=F%L=64@+CT@
M)'1H:7,M/F=E=%-T<FEN9U1A8FQE16YT<GDH6$U,7U="6$U,.CI-0E5);G0S
M,E1O26YT*"1I;G!U="P@)'1H:7,M/E]S=')P;W,I*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!834Q?5T)834Q?1TQ/0D%,
M7U1/2T5.7T]005%513H*("`@("`@("`@("`@("`@("\O(%-E8W1I;VX@-2XX
M+C0N-@H@("`@("`@("`@("`@("`@)'-I>F4@/2!834Q?5T)834PZ.DU"54EN
M=#,R5&]);G0H)&EN<'5T+"`D=&AI<RT^7W-T<G!O<RD["B`@("`@("`@("`@
M("`@("`D8B`]('-U8G-T<B@D:6YP=70L("1T:&ES+3Y?<W1R<&]S+"`D=&AI
M<RT^7W-T<G!O<R`K("1S:7IE*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<W1R<&]S("L]("1S:7IE.PH*("`@("`@("`@("`@("`@("1V86QU92`N/2`D
M8CL*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92!8
M34Q?5T)834Q?1TQ/0D%,7U1/2T5.7T5.1#H*("`@("`@("`@("`@("`@("\O
M(%-E8W1I;VX@-2XX+C0N-RXQ"B`@("`@("`@("`@("`@("`D:&%S36]R94%T
M=')I8G5T97,@/2!F86QS93L*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<BDI('L*("`@("`@("`@("`@("`@("`@("`D871T<G-;72`](&%R<F%Y
M*"=A='1R:6)U=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W9A;'5E)R`]/B`D=F%L=64I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E(%A-3%]70EA-3%]'3$]"04Q?5$]+14Y?4U=)5$-(7U!!1T4Z"B`@("`@
M("`@("`@("`@("`O+R!396-T:6]N(#4N."XT+C<N,@H@("`@("`@("`@("`@
M("`@)&-O9&5086=E(#T@)'1H:7,M/F=E=$)Y=&4H)&EN<'5T*3L*("`@("`@
M("`@("`@("`@(&EF("@A)'1H:7,M/E]P<F5V071T<FEB=71E1%1$*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F5V071T<FEB=71E1%1$(#T@
M)'1H:7,M/E]A='1R:6)U=&5$5$0["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)'1H:7,M/G-W:71C:$%T=')I8G5T94-O9&5086=E*"1C
M;V1E4&%G92D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!I9B`H)'1O:V5N(#X@,3(X*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<G-;72`](&%R<F%Y*"=A='1R:6)U
M=&4G(#T^("1A='1R+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=V86QU92<@/3X@)'9A;'5E*3L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&%T='(@/2`D=&AI<RT^7V%T
M=')I8G5T94141"T^=&]!='1R:6)U=&4H)'1O:V5N*3L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@+R\@5F%L=64N"B`@
M("`@("`@("`@("`@("`@("`@)'9A;'5E("X]("1T:&ES+3Y?871T<FEB=71E
M1%1$+3YT;T%T=')I8G5T92@D=&]K96XI.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(&EF("@A)'1H:7,M/E]P<F5V071T<FEB=71E1%1$*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?871T<FEB=71E1%1$(#T@)'1H:7,M/E]P<F5V
M071T<FEB=71E1%1$.PH@("`@("`@("`@("`D=&AI<RT^7W!R979!='1R:6)U
M=&5$5$0@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YS=&]P
M1V5T071T<FEB=71E<R@I.PH@("`@?0H*("`@(&9U;F-T:6]N('-T87)T1V5T
M071T<FEB=71E<R@I"B`@("!["B`@("`@("`@)'1H:7,M/E]I<T%T=')I8G5T
M92`]('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@<W1O<$=E=$%T=')I8G5T
M97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:7-!='1R:6)U=&4@/2!F86QS
M93L*("`@('T*"B`@("!F=6YC=&EO;B!G971#=7)R96YT55))*"D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/E]I<T%T=')I8G5T92D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]T86=$5$0M/F=E=%5222@I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V%T=')I8G5T9414
M1"T^9V5T55))*"D["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('=R
M:71E4W1R:6YG*"1S='(I"B`@("!["B`@("`@("`@)'1H:7,M/E]C:"T^8VAA
M<F%C=&5R<R@D<W1R*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971486<H)'1A
M9RD*("`@('L*("`@("`@("`O+R!3:&]U;&0@:VYO=R!W:&EC:"!S=&%T92!I
M="!I<R!I;BX*("`@("`@("!R971U<FX@)'1H:7,M/E]T86=$5$0M/G1O5&%G
M4W1R*"1T86<I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$%T=')I8G5T92@D
M871T<FEB=71E*0H@("`@>PH@("`@("`@("\O(%-H;W5L9"!K;F]W('=H:6-H
M('-T871E(&ET(&ES(&EN+@H@("`@("`@("1T:&ES+3Y?871T<FEB=71E1%1$
M+3YT;T%T=')I8G5T94EN="@D871T<FEB=71E*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!S=VET8VA%;&5M96YT0V]D95!A9V4H)&-O9&5086=E*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?=&%G1%1$(#T@)B1T:&ES+3Y?9'1D36%N86=E<BT^
M9V5T26YS=&%N8V4H)'1H:7,M/E]T86=$5$0M/G1O0V]D95!A9V53='(H)&-O
M9&5086=E*2D["B`@("`@("`@)'1H:7,M/G-W:71C:$%T=')I8G5T94-O9&50
M86=E*"1C;V1E4&%G92D["B`@("!]"@H@("`@9G5N8W1I;VX@<W=I=&-H071T
M<FEB=71E0V]D95!A9V4H)&-O9&5086=E*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?871T<FEB=71E1%1$(#T@)B1T:&ES+3Y?9'1D36%N86=E<BT^9V5T26YS
M=&%N8V4H)'1H:7,M/E]A='1R:6)U=&5$5$0M/G1O0V]D95!A9V53='(H)&-O
M9&5086=E*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@=&AE(&AE
M>"!V97)S:6]N(&]F('1H92!B87-E(#$P("1E;G1I='DN"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&5N=&ET>2@D96YT:71Y*0H@("`@>PH@("`@("`@(')E='5R
M;B!D96-H97@H)&5N=&ET>2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D
M<R!A(&YU;&P@=&5R;6EN871E9"!S=')I;F<N"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1E<FUS='(H)&EN<'5T*0H@("`@>PH@("`@("`@("1S='(@/2`G(R<[
M("\O(&UU<W0@<W1A<G0@=VET:"!N;VYE;7!T>2!S=')I;F<@=&\@86QL;W<@
M87)R87D@86-C97-S"B`@("`@("`@)&D@/2`P.PH@("`@("`@("1C:"`]("1I
M;G!U=%LD=&AI<RT^7W-T<G!O<RLK73L*("`@("`@("!I9B`H;W)D*"1C:"D@
M/3T@,"D@>PH@("`@("`@("`@("!R971U<FX@)R<[("\O(&1O;B=T(')E='5R
M;B`G(R<*("`@("`@("!]"B`@("`@("`@=VAI;&4@*&]R9"@D8V@I("$](#`I
M('L*("`@("`@("`@("`@)'-T<ELD:2LK72`]("1C:#L*("`@("`@("`@("`@
M)&-H(#T@)&EN<'5T6R1T:&ES+3Y?<W1R<&]S*RM=.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1S='(["B`@("!]"@I]"@H`````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O;&EB+UA-3"]70EA-3"]$5$0O4WEN8TU,1&5V26YF+G!H
M<````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-S0P(#$P-3$U-#,T,3,V
M(#`R,S(R-P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*:6YC;'5D95]O;F-E("=834PO5T)834PO1%1$+G!H<"<[
M"@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO6$U,7U="6$U,+U="6$U,+T14
M1"]3>6YC34Q$979);F8N<&AP+'8@,2XT+C$R+C4@,C`P-B\P,R\Q,2`P.3HU
M-3HR,R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!;G1H
M;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!&<F]M($)I
M;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E8VEF:6-A=&EO;B!697)S:6]N
M(#$N,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD(&%T(&AT='`Z+R]W=W<N=V%P
M9F]R=6TN;W)G"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0'!A8VMA9V4@6$U,7U="
M6$U,"B`J+PIC;&%S<R!834Q?5T)834Q?1%1$7U-Y;F--3$1E=DEN9B!E>'1E
M;F1S(%A-3%]70EA-3%]$5$0@>PH*("`@(&9U;F-T:6]N(&EN:70H*0H@("`@
M>PH@("`@("`@("\J('1H:7,@8V]D92!T86)L92!H87,@8F5E;B!E>'1R86-T
M960@9G)O;2!L:6)W8GAM;`H@("`@("`@("`J("AS964@:'1T<#HO+VQI8G=B
M>&UL+F%Y;65R:6-K+F-O;2\I(&)Y('5S:6YG"B`@("`@("`@("H*("`@("`@
M("`@*B!G<F5P("=<(EM>7")=*EPB+"`J,'@N+BP@,'@N+B!]+"<@=V)X;6Q?
M=&%B;&5S+F,*("`@("`@("`@*B!\('-E9"`M92`G<R->+BI<(EPH6UY<(ETJ
M7"E<(BP@*EPH,'@N+EPI+"!<*#!X+BY<*2!]+"XJ)",@("`@("`@(%PD=&AI
M<RT^<V5T5&%G7"A<,RP@7")<,5PB7"D[("\O(%PR(V<G"B`@("`@("`@("HO
M"@H@("`@("`@("1T:&ES+3YS971486<H,'@P-2P@(D-40V%P(BD[("\O(#!X
M,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,#8L(")#5%1Y<&4B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P-RP@(D1A=&%3=&]R92(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#`X+"`B1&%T851Y
M<&4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P.2P@(D1E
M=DE$(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&$L(")$
M979);F8B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@P8BP@
M(D1E=E1Y<"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!C
M+"`B1&ES<&QA>4YA;64B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@P9"P@(D13365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T
M5&%G*#!X,&4L(")%>'0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@P9BP@(D9W5B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A
M9R@P>#$P+"`B2'=6(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G
M*#!X,3$L(")-86XB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H
M,'@Q,BP@(DUA>$=52413:7IE(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,3,L(")-87A)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#$T+"`B36%X365M(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,34L(")-;V0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@Q-BP@(D]%32(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#$W+"`B4&%R86U.86UE(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,3@L(")0<F]P3F%M92(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$Y+"`B4G@B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@Q82P@(E)X+5!R968B*3L@+R\@,'@P,`H@("`@
M("`@("1T:&ES+3YS971486<H,'@Q8BP@(E-H87)E9$UE;2(I.R`O+R`P>#`P
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%C+"`B4VEZ92(I.R`O+R`P>#`P
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%D+"`B4V]U<F-E4F5F(BD[("\O
M(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,64L(")3=U8B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q9BP@(E-Y;F-#87`B*3L@
M+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,"P@(E-Y;F-4>7!E
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,C$L(")4>"(I
M.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(R+"`B5'@M4')E
M9B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(S+"`B5F%L
M16YU;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(T+"`B
M5F5R0U0B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R-2P@
M(E9E<D141"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(V
M+"`B6$YA;2(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(W
M+"`B6%9A;"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#(X
M+"`B551#(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,CDL
M(")3=7!P;W)T3G5M8F5R3V9#:&%N9V5S(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,F$L(")3=7!P;W)T3&%R9V5/8FIS(BD[("\O(#!X
M,#`*"B`@("`@("`@:68@*"1T:&ES+3YV97)S:6]N(#T](#`I('L*("`@("`@
M("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#`L("<M+R]364Y#34PO+T141"!$
M979);F8@,2XP+R]%3B<L("=S>6YC;6PZ9&5V:6YF,2XP)RD["B`@("`@("`@
M("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#ID979I;F8Q+C`G*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@
M)RTO+U-93D--3"\O1%1$($1E=DEN9B`Q+C$O+T5.)RP@)W-Y;F-M;#ID979I
M;F8Q+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=%5222@G<WEN8VUL.F1E
M=FEN9C$N,2<I.PH@("`@("`@('T*("`@('T*"GT*````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M6$U,+U="6$U,+T141"]3>6YC34Q-971);F8N<&AP````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#0T,C,@,3`U,34T,S0Q,S8@,#(S,C,S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@II;F-L
M=61E7V]N8V4@)UA-3"]70EA-3"]$5$0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z
M(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO1%1$+U-Y;F--3$UE=$EN9BYP
M:'`L=B`Q+C0N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C,S(&IA;B!%>'`@)`H@
M*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL
M<T!P>7)A;6ED-BYC;VT^"B`J"B`J($9R;VT@0FEN87)Y(%A-3"!#;VYT96YT
M($9O<FUA="!3<&5C:69I8V%T:6]N(%9E<G-I;VX@,2XS+"`R-2!*=6QY(#(P
M,#$*("H@9F]U;F0@870@:'1T<#HO+W=W=RYW87!F;W)U;2YO<F<*("H*("H@
M4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF
M;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L87-S(%A-
M3%]70EA-3%]$5$1?4WEN8TU,365T26YF(&5X=&5N9',@6$U,7U="6$U,7T14
M1"!["@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@+RH@=&AI
M<R!C;V1E('1A8FQE(&AA<R!B965N(&5X=')A8W1E9"!F<F]M(&QI8G=B>&UL
M"B`@("`@("`@("H@*'-E92!H='1P.B\O;&EB=V)X;6PN87EM97)I8VLN8V]M
M+RD@8GD@=7-I;F<*("`@("`@("`@*@H@("`@("`@("`J(&=R97`@)UPB6UY<
M(ETJ7"(L("HP>"XN+"`P>"XN('TL)R!W8GAM;%]T86)L97,N8PH@("`@("`@
M("`J('P@<V5D("UE("=S(UXN*EPB7"A;7EPB72I<*5PB+"`J7"@P>"XN7"DL
M(%PH,'@N+EPI('TL+BHD(R`@("`@("`@7"1T:&ES+3YS971486=<*%PS+"!<
M(EPQ7")<*3L@+R\@7#(C9R<*("`@("`@("`@*B\*"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#`U+"`B06YC:&]R(BD[("\O(#!X,#$*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,#8L(")%34DB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES
M+3YS971486<H,'@P-RP@(D9O<FUA="(I.R`O+R`P>#`Q"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#`X+"`B1G)E94E$(BD[("\O(#!X,#$*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,#DL(")&<F5E365M(BD[("\O(#!X,#$*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,&$L("),87-T(BD[("\O(#!X,#$*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,&(L(")-87)K(BD[("\O(#!X,#$*("`@("`@
M("`D=&AI<RT^<V5T5&%G*#!X,&,L(")-87A-<V=3:7IE(BD[("\O(#!X,#$*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,34L(")-87A/8FI3:7IE(BD[("\O
M(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,&0L(")-96TB*3L@+R\@
M,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@P92P@(DUE=$EN9B(I.R`O
M+R`P>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#!F+"`B3F5X="(I.R`O
M+R`P>#`Q"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#$P+"`B3F5X=$YO;F-E
M(BD[("\O(#!X,#$*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3$L(")3:&%R
M961-96TB*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q,BP@
M(E-I>F4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q,RP@
M(E1Y<&4B*3L@+R\@,'@P,0H@("`@("`@("1T:&ES+3YS971486<H,'@Q-"P@
M(E9E<G-I;VXB*3L@+R\@,'@P,0H*("`@("`@("!I9B`H)'1H:7,M/G9E<G-I
M;VX@/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@
M)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C`O+T5.)RP@)W-Y;F-M;#IS>6YC
M;6PQ+C`G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#$L("<M
M+R]364Y#34PO+T141"!-971);F8@,2XP+R]%3B<L("=S>6YC;6PZ;65T:6YF
M,2XP)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#IM971I
M;F8Q+C`G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^
M<V5T0V]D95!A9V4H,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.
M)RP@)W-Y;F-M;#IS>6YC;6PQ+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E
M=$-O9&5086=E*#$L("<M+R]364Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L
M("=S>6YC;6PZ;65T:6YF,2XQ)RD["B`@("`@("`@("`@("1T:&ES+3YS9715
M4DDH)W-Y;F-M;#IM971I;F8Q+C$G*3L*("`@("`@("`@("`@+R\D=&AI<RT^
M<V5T55))*"=S>6YC;6PZ;65T:6YF)RD[("\O(&9O<B!S;VUE(&9U;FYY(')E
M87-O;BP@;&EB=V)X;6P@<')O9'5C97,@;F\@.FUE=&EN9C$N,2!H97)E"B`@
M("`@("`@?0H@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O6$U,+U="6$U,+T141"]3>6YC34PN<&AP````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<Q,S,@,3`U,34T,S0Q,S8@,#(R
M,3,Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@II;F-L=61E7V]N8V4@)UA-3"]70EA-3"]$5$0N<&AP)SL*"B\J
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]834Q?5T)834PO5T)834PO1%1$+U-Y
M;F--3"YP:'`L=B`Q+C8N,3(N-2`R,#`V+S`S+S$Q(#`Y.C4U.C$R(&IA;B!%
M>'`@)`H@*@H@*B!&<F]M($)I;F%R>2!834P@0V]N=&5N="!&;W)M870@4W!E
M8VEF:6-A=&EO;B!697)S:6]N(#$N,RP@,C4@2G5L>2`R,#`Q"B`J(&9O=6YD
M(&%T(&AT='`Z+R]W=W<N=V%P9F]R=6TN;W)G"B`J"B`J($-O<'ER:6=H="`R
M,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`<&%C:V%G92!834Q?5T)834P*("HO"F-L
M87-S(%A-3%]70EA-3%]$5$1?4WEN8TU,(&5X=&5N9',@6$U,7U="6$U,7T14
M1"!["@H@("`@9G5N8W1I;VX@:6YI="@I"B`@("!["B`@("`@("`@+RH@=&AI
M<R!C;V1E('1A8FQE(&AA<R!B965N(&5X=')A8W1E9"!F<F]M(&QI8G=B>&UL
M"B`@("`@("`@("H@*'-E92!H='1P.B\O;&EB=V)X;6PN87EM97)I8VLN8V]M
M+RD@8GD@=7-I;F<*("`@("`@("`@*@H@("`@("`@("`J(&=R97`@)UPB6UY<
M(ETJ7"(L("HP>"XN+"`P>"XN('TL)R!W8GAM;%]T86)L97,N8PH@("`@("`@
M("`J('P@<V5D("UE("=S(UXN*EPB7"A;7EPB72I<*5PB+"`J7"@P>"XN7"DL
M(%PH,'@N+EPI('TL+BHD(R`@("`@("`@7"1T:&ES+3YS971486=<*%PS+"!<
M(EPQ7")<*3L@+R\@7#(C9R<*("`@("`@("`@*B\*"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#`U+"`B061D(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^
M<V5T5&%G*#!X,#8L(")!;&5R="(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#`W+"`B07)C:&EV92(I.R`O+R`P>#`P"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#`X+"`B071O;6EC(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,#DL(")#:&%L(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,&$L(")#;60B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@P8BP@(D-M9$E$(BD[("\O(#!X,#`*("`@("`@("`D
M=&AI<RT^<V5T5&%G*#!X,&,L(")#;612968B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@P9"P@(D-O<'DB*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@P92P@(D-R960B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@P9BP@(D1A=&$B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@Q,"P@(D1E;&5T92(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$Q+"`B17AE8R(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$R+"`B1FEN86PB*3L@+R\@,'@P,`H@("`@
M("`@("1T:&ES+3YS971486<H,'@Q,RP@(D=E="(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$T+"`B271E;2(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$U+"`B3&%N9R(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#$V+"`B3&]C3F%M92(I.R`O+R`P>#`P"B`@
M("`@("`@)'1H:7,M/G-E=%1A9R@P>#$W+"`B3&]C55))(BD[("\O(#!X,#`*
M("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,3@L(")-87`B*3L@+R\@,'@P,`H@
M("`@("`@("1T:&ES+3YS971486<H,'@Q.2P@(DUA<$ET96TB*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q82P@(DUE=&$B*3L@+R\@,'@P
M,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q8BP@(DUS9TE$(BD[("\O(#!X
M,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,6,L(")-<V=2968B*3L@+R\@
M,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@Q9"P@(DYO4F5S<"(I.R`O
M+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#%E+"`B3F]297-U;'1S
M(BD[("\O(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,68L(")0=70B
M*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,"P@(E)E<&QA
M8V4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,2P@(E)E
M<W!54DDB*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R,BP@
M(E)E<W5L=',B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R
M,RP@(E-E87)C:"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P
M>#(T+"`B4V5Q=65N8V4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES+3YS9714
M86<H,'@R-2P@(E-E<W-I;VY)1"(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M
M/G-E=%1A9R@P>#(V+"`B4V9T1&5L(BD[("\O(#!X,#`*("`@("`@("`D=&AI
M<RT^<V5T5&%G*#!X,C<L(")3;W5R8V4B*3L@+R\@,'@P,`H@("`@("`@("1T
M:&ES+3YS971486<H,'@R."P@(E-O=7)C95)E9B(I.R`O+R`P>#`P"B`@("`@
M("`@)'1H:7,M/G-E=%1A9R@P>#(Y+"`B4W1A='5S(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,F$L(")3>6YC(BD[("\O(#!X,#`*("`@
M("`@("`D=&AI<RT^<V5T5&%G*#!X,F(L(")3>6YC0F]D>2(I.R`O+R`P>#`P
M"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#)C+"`B4WEN8TAD<B(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#)D+"`B4WEN8TU,(BD[("\O
M(#!X,#`*("`@("`@("`D=&AI<RT^<V5T5&%G*#!X,F4L(")487)G970B*3L@
M+R\@,'@P,`H@("`@("`@("1T:&ES+3YS971486<H,'@R9BP@(E1A<F=E=%)E
M9B(I.R`O+R`P>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#,P+"`B4F5S
M97)V960@9F]R(&9U='5R92!U<V4B*3L@+R\@,'@P,`H@("`@("`@("1T:&ES
M+3YS971486<H,'@S,2P@(E9E<D141"(I.R`O+R`P>#`P"B`@("`@("`@)'1H
M:7,M/G-E=%1A9R@P>#,R+"`B5F5R4')O=&\B*3L@+R\@,'@P,`H@("`@("`@
M("1T:&ES+3YS971486<H,'@S,RP@(DYU;6)E<D]F0VAA;F=E9"(I.R`O+R`P
M>#`P"B`@("`@("`@)'1H:7,M/G-E=%1A9R@P>#,T+"`B36]R941A=&$B*3L@
M+R\@,'@P,`H*("`@("`@("!I9B`H)'1H:7,M/G9E<G-I;VX@/3T@,"D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H,"P@)RTO+U-93D--3"\O
M1%1$(%-Y;F--3"`Q+C`O+T5.)RP@)W-Y;F-M;#IS>6YC;6PQ+C`G*3L*("`@
M("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#$L("<M+R]364Y#34PO+T14
M1"!-971);F8@,2XP+R]%3B<L("=S>6YC;6PZ;65T:6YF,2XP)RD["B`@("`@
M("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#IS>6YC;6PQ+C`G*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T0V]D95!A9V4H
M,"P@)RTO+U-93D--3"\O1%1$(%-Y;F--3"`Q+C$O+T5.)RP@)W-Y;F-M;#IS
M>6YC;6PQ+C$G*3L*("`@("`@("`@("`@)'1H:7,M/G-E=$-O9&5086=E*#$L
M("<M+R]364Y#34PO+T141"!-971);F8@,2XQ+R]%3B<L("=S>6YC;6PZ;65T
M:6YF,2XQ)RD["B`@("`@("`@("`@("1T:&ES+3YS97154DDH)W-Y;F-M;#IS
M>6YC;6PQ+C$G*3L*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O5&5X="]R95-4````````
M````````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q,S8@,#(P,#(U`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI
M8B]497AT+T1I9F8`````````````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-B`P,C`P,C``(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9BYP:'``````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8S-34T(#$P-3$U-#,T
M,3,V(#`R,#8R-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&5X=%]$:69F"B`J"B`J($=E;F5R86P@
M05!)(&9O<B!G96YE<F%T:6YG(&%N9"!F;W)M871T:6YG(&1I9F9S("T@=&AE
M(&1I9F9E<F5N8V5S(&)E='=E96X*("H@='=O('-E<75E;F-E<R!O9B!S=')I
M;F=S+@H@*@H@*B!4:&4@4$A0(&1I9F8@8V]D92!U<V5D(&EN('1H:7,@<&%C
M:V%G92!W87,@;W)I9VEN86QL>2!W<FET=&5N(&)Y($=E;V9F<F5Y"B`J(%0N
M($1A:7)I:VD@86YD(&ES('5S960@=VET:"!H:7,@<&5R;6ES<VEO;BX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8N<&AP+'8@,2XQ
M,2XR+C<@,C`P-B\P,B\P-B`P,#HR-3HU,B!J86X@17AP("0*("H*("H@0'!A
M8VMA9V4@5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I
M:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J+PIC;&%S<R!497AT7T1I9F8@
M>PH*("`@("\J*@H@("`@("H@07)R87D@;V8@8VAA;F=E<RX*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V5D:71S.PH*("`@
M("\J*@H@("`@("H@0V]M<'5T97,@9&EF9G,@8F5T=V5E;B!S97%U96YC97,@
M;V8@<W1R:6YG<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&9R;VU?
M;&EN97,@($%N(&%R<F%Y(&]F('-T<FEN9W,N("!4>7!I8V%L;'D@=&AE<V4@
M87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI;F5S(&9R
M;VT@82!F:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("1T;U]L:6YE<R`@("!!
M;B!A<G)A>2!O9B!S=')I;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT
M7T1I9F8H)&9R;VU?;&EN97,L("1T;U]L:6YE<RD*("`@('L*("`@("`@("!A
M<G)A>5]W86QK*"1F<F]M7VQI;F5S+"!A<G)A>2@D=&AI<RP@)U]T<FEM3F5W
M;&EN97,G*2D["B`@("`@("`@87)R87E?=V%L:R@D=&]?;&EN97,L(&%R<F%Y
M*"1T:&ES+"`G7W1R:6U.97=L:6YE<R<I*3L*"B`@("`@("`@:68@*&5X=&5N
M<VEO;E]L;V%D960H)WAD:69F)RDI('L*("`@("`@("`@("`@)&5N9VEN92`]
M("9N97<@5&5X=%]$:69F7T5N9VEN95]X9&EF9B@I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1E;F=I;F4@/2`F;F5W(%1E>'1?1&EF9E]%;F=I
M;F5?;F%T:79E*"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V5D:71S
M(#T@)&5N9VEN92T^9&EF9B@D9G)O;5]L:6YE<RP@)'1O7VQI;F5S*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&%R<F%Y(&]F(&1I9F9E
M<F5N8V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971$:69F*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]E9&ET<SL*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;7!U=&5S(&$@<F5V97)S960@9&EF9BX*("`@("`J"B`@("`@
M*B!%>&%M<&QE.@H@("`@("H@/&-O9&4^"B`@("`@*B`D9&EF9B`]("9N97<@
M5&5X=%]$:69F*"1L:6YE<S$L("1L:6YE<S(I.PH@("`@("H@)')E=B`]("1D
M:69F+3YR979E<G-E*"D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@
M0')E='5R;B!497AT7T1I9F8@($$@1&EF9B!O8FIE8W0@<F5P<F5S96YT:6YG
M('1H92!I;G9E<G-E(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@
M(&]R:6=I;F%L(&1I9F8N("!.;W1E('1H870@=V4@<'5R<&]S96QY(&1O;B=T
M(')E='5R;B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@<F5F97)E;F-E
M(&AE<F4L('-I;F-E('1H:7,@97-S96YT:6%L;'D@:7,@82!C;&]N92@I"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@;65T:&]D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!R979E<G-E*"D*("`@('L*("`@("`@("!I9B`H=F5R<VEO;E]C
M;VUP87)E*'IE;F1?=F5R<VEO;B@I+"`G,B<L("<^)RDI('L*("`@("`@("`@
M("`@)')E=B`](&-L;VYE*"1T:&ES*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5V(#T@)'1H:7,["B`@("`@("`@?0H@("`@("`@("1R978M
M/E]E9&ET<R`](&%R<F%Y*"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]E
M9&ET<R!A<R`D961I="D@>PH@("`@("`@("`@("`D<F5V+3Y?961I='-;72`]
M("1E9&ET+3YR979E<G-E*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<F5V.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&9O<B!A;B!E;7!T
M>2!D:69F+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U92!I
M9B!T=V\@<V5Q=65N8V5S('=E<F4@:61E;G1I8V%L+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!I<T5M<'1Y*"D*("`@('L*("`@("`@("!F;W)E86-H("@D=&AI
M<RT^7V5D:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@(&EF("@A:7-?82@D
M961I="P@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($-O;7!U=&5S
M('1H92!L96YG=&@@;V8@=&AE($QO;F=E<W0@0V]M;6]N(%-U8G-E<75E;F-E
M("A,0U,I+@H@("`@("H*("`@("`J(%1H:7,@:7,@;6]S=&QY(&9O<B!D:6%G
M;F]S=&EC('!U<G!O<V5S+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E
M<B`@5&AE(&QE;F=T:"!O9B!T:&4@3$-3+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!L8W,H*0H@("`@>PH@("`@("`@("1L8W,@/2`P.PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@:68@
M*&ES7V$H)&5D:70L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@
M("`@("`@("`D;&-S("L](&-O=6YT*"1E9&ET+3YO<FEG*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)&QC<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&]R:6=I;F%L('-E="!O9B!L:6YE<RX*
M("`@("`J"B`@("`@*B!4:&ES(')E8V]N<W1R=6-T<R!T:&4@)&9R;VU?;&EN
M97,@<&%R86UE=&5R('!A<W-E9"!T;R!T:&4@8V]N<W1R=6-T;W(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>2`@5&AE(&]R:6=I;F%L('-E<75E;F-E
M(&]F('-T<FEN9W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$]R:6=I;F%L
M*"D*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A>2@I.PH@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@("`@
M:68@*"1E9&ET+3YO<FEG*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S<&QI
M8V4H)&QI;F5S+"!C;W5N="@D;&EN97,I+"`P+"`D961I="T^;W)I9RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&9I;F%L('-E="!O9B!L
M:6YE<RX*("`@("`J"B`@("`@*B!4:&ES(')E8V]N<W1R=6-T<R!T:&4@)'1O
M7VQI;F5S('!A<F%M971E<B!P87-S960@=&\@=&AE(&-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%1H92!S97%U96YC92!O9B!S
M=')I;F=S+@H@("`@("HO"B`@("!F=6YC=&EO;B!G971&:6YA;"@I"B`@("![
M"B`@("`@("`@)&QI;F5S(#T@87)R87DH*3L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V5D:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@(&EF("@D961I
M="T^9FEN86PI('L*("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D;&EN
M97,L(&-O=6YT*"1L:6YE<RDL(#`L("1E9&ET+3YF:6YA;"D["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1L:6YE<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E;6]V97,@=')A:6QI;F<@;F5W;&EN97,@9G)O
M;2!A(&QI;F4@;V8@=&5X="X@5&AI<R!I<R!M96%N="!T;R!B92!U<V5D"B`@
M("`@*B!W:71H(&%R<F%Y7W=A;&LH*2X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1L:6YE("!4:&4@;&EN92!T;R!T<FEM+@H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&ME>2`@5&AE(&EN9&5X(&]F('1H92!L:6YE(&EN('1H92!A
M<G)A>2X@3F]T('5S960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T<FEM3F5W
M;&EN97,H)B1L:6YE+"`D:V5Y*0H@("`@>PH@("`@("`@("1L:6YE(#T@<W1R
M7W)E<&QA8V4H87)R87DH(EQN(BP@(EQR(BDL("<G+"`D;&EN92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@82!D:69F(&9O<B!V86QI9&ET>2X*
M("`@("`J"B`@("`@*B!4:&ES(&ES(&AE<F4@;VYL>2!F;W(@9&5B=6=G:6YG
M('!U<G!O<V5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VLH)&9R;VU?
M;&EN97,L("1T;U]L:6YE<RD*("`@('L*("`@("`@("!I9B`H<V5R:6%L:7IE
M*"1F<F]M7VQI;F5S*2`A/2!S97)I86QI>F4H)'1H:7,M/F=E=$]R:6=I;F%L
M*"DI*2!["B`@("`@("`@("`@('1R:6=G97)?97)R;W(H(E)E8V]N<W1R=6-T
M960@;W)I9VEN86P@9&]E<VXG="!M871C:"(L($5?55-%4E]%4E)/4BD["B`@
M("`@("`@?0H@("`@("`@(&EF("AS97)I86QI>F4H)'1O7VQI;F5S*2`A/2!S
M97)I86QI>F4H)'1H:7,M/F=E=$9I;F%L*"DI*2!["B`@("`@("`@("`@('1R
M:6=G97)?97)R;W(H(E)E8V]N<W1R=6-T960@9FEN86P@9&]E<VXG="!M871C
M:"(L($5?55-%4E]%4E)/4BD["B`@("`@("`@?0H*("`@("`@("`D<F5V(#T@
M)'1H:7,M/G)E=F5R<V4H*3L*("`@("`@("!I9B`H<V5R:6%L:7IE*"1T;U]L
M:6YE<RD@(3T@<V5R:6%L:7IE*"1R978M/F=E=$]R:6=I;F%L*"DI*2!["B`@
M("`@("`@("`@('1R:6=G97)?97)R;W(H(E)E=F5R<V5D(&]R:6=I;F%L(&1O
M97-N)W0@;6%T8V@B+"!%7U5315)?15)23U(I.PH@("`@("`@('T*("`@("`@
M("!I9B`H<V5R:6%L:7IE*"1F<F]M7VQI;F5S*2`A/2!S97)I86QI>F4H)')E
M=BT^9V5T1FEN86PH*2DI('L*("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B
M4F5V97)S960@9FEN86P@9&]E<VXG="!M871C:"(L($5?55-%4E]%4E)/4BD[
M"B`@("`@("`@?0H*("`@("`@("`D<')E=G1Y<&4@/2!N=6QL.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?961I=',@87,@)&5D:70I('L*("`@("`@("`@
M("`@:68@*"1P<F5V='EP92`]/2!G971?8VQA<W,H)&5D:70I*2!["B`@("`@
M("`@("`@("`@("!T<FEG9V5R7V5R<F]R*")%9&ET('-E<75E;F-E(&ES(&YO
M;BUO<'1I;6%L(BP@15]54T527T524D]2*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D<')E=G1Y<&4@/2!G971?8VQA<W,H)&5D:70I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]"@HO*BH*("H@)$AO
M<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8N<&AP+'8@,2XQ,2XR+C<@
M,C`P-B\P,B\P-B`P,#HR-3HU,B!J86X@17AP("0*("H*("H@0'!A8VMA9V4@
M5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A
M:7)I:VE`9&%I<FEK:2YO<F<^"B`J+PIC;&%S<R!497AT7TUA<'!E9$1I9F8@
M97AT96YD<R!497AT7T1I9F8@>PH*("`@("\J*@H@("`@("H@0V]M<'5T97,@
M82!D:69F(&)E='=E96X@<V5Q=65N8V5S(&]F('-T<FEN9W,N"B`@("`@*@H@
M("`@("H@5&AI<R!C86X@8F4@=7-E9"!T;R!C;VUP=71E('1H:6YG<R!L:6ME
M(&-A<V4M:6YS96YS:71V92!D:69F<RP@;W(@9&EF9G,*("`@("`J('=H:6-H
M(&EG;F]R92!C:&%N9V5S(&EN('=H:71E+7-P86-E+@H@("`@("H*("`@("`J
M($!P87)A;2!A<G)A>2`D9G)O;5]L:6YE<R`@("`@("`@($%N(&%R<F%Y(&]F
M('-T<FEN9W,N"B`@("`@*B!`<&%R86T@87)R87D@)'1O7VQI;F5S("`@("`@
M("`@("!!;B!A<G)A>2!O9B!S=')I;F=S+@H@("`@("H@0'!A<F%M(&%R<F%Y
M("1M87!P961?9G)O;5]L:6YE<R`@5&AI<R!A<G)A>2!S:&]U;&0@:&%V92!T
M:&4@<V%M92!S:7IE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N=6UB97(@;V8@96QE;65N=',@87,@)&9R;VU?;&EN97,N("!4
M:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5L
M96UE;G1S(&EN("1M87!P961?9G)O;5]L:6YE<R!A;F0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M87!P961?=&]?;&EN97,@
M87)E('=H870@:7,@86-T=6%L;'D*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-O;7!A<F5D('=H96X@8V]M<'5T:6YG('1H92!D
M:69F+@H@("`@("H@0'!A<F%M(&%R<F%Y("1M87!P961?=&]?;&EN97,@("`@
M5&AI<R!A<G)A>2!S:&]U;&0@:&%V92!T:&4@<V%M92!N=6UB97(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&]F(&5L96UE;G1S
M(&%S("1T;U]L:6YE<RX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]-87!P
M961$:69F*"1F<F]M7VQI;F5S+"`D=&]?;&EN97,L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&UA<'!E9%]F<F]M7VQI;F5S+"`D;6%P<&5D7W1O
M7VQI;F5S*0H@("`@>PH@("`@("`@(&%S<V5R="AC;W5N="@D9G)O;5]L:6YE
M<RD@/3T@8V]U;G0H)&UA<'!E9%]F<F]M7VQI;F5S*2D["B`@("`@("`@87-S
M97)T*&-O=6YT*"1T;U]L:6YE<RD@/3T@8V]U;G0H)&UA<'!E9%]T;U]L:6YE
M<RDI.PH*("`@("`@("!P87)E;G0Z.E1E>'1?1&EF9B@D;6%P<&5D7V9R;VU?
M;&EN97,L("1M87!P961?=&]?;&EN97,I.PH*("`@("`@("`D>&D@/2`D>6D@
M/2`P.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?
M961I=',I.R`D:2LK*2!["B`@("`@("`@("`@("1O<FEG(#T@)B1T:&ES+3Y?
M961I='-;)&E=+3YO<FEG.PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)&]R
M:6<I*2!["B`@("`@("`@("`@("`@("`D;W)I9R`](&%R<F%Y7W-L:6-E*"1F
M<F]M7VQI;F5S+"`D>&DL(&-O=6YT*"1O<FEG*2D["B`@("`@("`@("`@("`@
M("`D>&D@*ST@8V]U;G0H)&]R:6<I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D9FEN86P@/2`F)'1H:7,M/E]E9&ET<ULD:5TM/F9I;F%L.PH@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)&9I;F%L*2D@>PH@("`@("`@("`@("`@
M("`@)&9I;F%L(#T@87)R87E?<VQI8V4H)'1O7VQI;F5S+"`D>6DL(&-O=6YT
M*"1F:6YA;"DI.PH@("`@("`@("`@("`@("`@)'EI("L](&-O=6YT*"1F:6YA
M;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@
M0VQA<W,@=7-E9"!I;G1E<FYA;&QY(&)Y($1I9F8@=&\@86-T=6%L;'D@8V]M
M<'5T92!T:&4@9&EF9G,N("!4:&ES(&-L87-S"B`J('5S97,@=&AE('AD:69F
M(%!%0TP@<&%C:V%G92`H:'1T<#HO+W!E8VPN<&AP+FYE="]P86-K86=E+WAD
M:69F*2!T;R!C;VUP=71E"B`J('1H92!D:69F97)E;F-E<R!B971W965N('1H
M92!T=V\@:6YP=70@87)R87ES+@H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E
M(#QJ;VY`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H*("H@
M0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F9?16YG:6YE7WAD
M:69F('L*"B`@("!F=6YC=&EO;B!D:69F*"1F<F]M7VQI;F5S+"`D=&]?;&EN
M97,I"B`@("!["B`@("`@("`@+RH@0V]N=F5R="!T:&4@='=O(&EN<'5T(&%R
M<F%Y<R!I;G1O('-T<FEN9W,@9F]R('AD:69F('!R;V-E<W-I;F<N("HO"B`@
M("`@("`@)&9R;VU?<W1R:6YG(#T@:6UP;&]D92@B7&XB+"`D9G)O;5]L:6YE
M<RD["B`@("`@("`@)'1O7W-T<FEN9R`](&EM<&QO9&4H(EQN(BP@)'1O7VQI
M;F5S*3L*"B`@("`@("`@+RH@1&EF9B!T:&4@='=O('-T<FEN9W,@86YD(&-O
M;G9E<G0@=&AE(')E<W5L="!T;R!A;B!A<G)A>2X@*B\*("`@("`@("`D9&EF
M9B`]('AD:69F7W-T<FEN9U]D:69F*"1F<F]M7W-T<FEN9RP@)'1O7W-T<FEN
M9RP@8V]U;G0H)'1O7VQI;F5S*2D["B`@("`@("`@)&1I9F8@/2!E>'!L;V1E
M*")<;B(L("1D:69F*3L*"B`@("`@("`@+RH@5V%L:R!T:')O=6=H('1H92!D
M:69F(&]N92!L:6YE(&%T(&$@=&EM92X@(%=E(&)U:6QD('1H92`D961I=',*
M("`@("`@("`@*B!A<G)A>2!O9B!D:69F(&]P97)A=&EO;G,@8GD@<F5A9&EN
M9R!T:&4@9FER<W0@8VAA<F%C=&5R(&]F('1H90H@("`@("`@("`J('AD:69F
M(&]U='!U="`H=VAI8V@@:7,@:6X@=&AE(")U;FEF:65D(&1I9F8B(&9O<FUA
M="DN"B`@("`@("`@("H*("`@("`@("`@*B!.;W1E('1H870@=V4@9&]N)W0@
M:&%V92!E;F]U9V@@:6YF;W)M871I;VX@=&\@9&5T96-T(")C:&%N9V5D(@H@
M("`@("`@("`J(&QI;F5S('5S:6YG('1H:7,@87!P<F]A8V@L('-O('=E(&-A
M;B=T(&%D9"!497AT7T1I9F9?3W!?8VAA;F=E9`H@("`@("`@("`J(&EN<W1A
M;F-E<R!T;R!T:&4@)&5D:71S(&%R<F%Y+B`@5&AE(')E<W5L="!I<R!S=&EL
M;"!P97)F96-T;'D*("`@("`@("`@*B!V86QI9"P@86QB96ET(&$@;&ET=&QE
M(&QE<W,@9&5S8W)I<'1I=F4@86YD(&5F9FEC:65N="X@*B\*("`@("`@("`D
M961I=',@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1D:69F(&%S("1L
M:6YE*2!["B`@("`@("`@("`@('-W:71C:"`H)&QI;F5;,%TI('L*("`@("`@
M("`@("`@8V%S92`G("<Z"B`@("`@("`@("`@("`@("`D961I='-;72`]("9N
M97<@5&5X=%]$:69F7T]P7V-O<'DH87)R87DH<W5B<W1R*"1L:6YE+"`Q*2DI
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("<K
M)SH*("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!497AT7T1I9F9?
M3W!?861D*&%R<F%Y*'-U8G-T<B@D;&EN92P@,2DI*3L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G+2<Z"B`@("`@("`@("`@
M("`@("`D961I='-;72`]("9N97<@5&5X=%]$:69F7T]P7V1E;&5T92AA<G)A
M>2AS=6)S='(H)&QI;F4L(#$I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E9&ET
M<SL*("`@('T*"GT*"B\J*@H@*B!#;&%S<R!U<V5D(&EN=&5R;F%L;'D@8GD@
M1&EF9B!T;R!A8W1U86QL>2!C;VUP=71E('1H92!D:69F<RX@(%1H:7,@8VQA
M<W,@:7,*("H@:6UP;&5M96YT960@=7-I;F<@;F%T:79E(%!(4"!C;V1E+@H@
M*@H@*B!4:&4@86QG;W)I=&AM('5S960@:&5R92!I<R!M;W-T;'D@;&EF=&5D
M(&9R;VT@=&AE('!E<FP@;6]D=6QE"B`J($%L9V]R:71H;3HZ1&EF9B`H=F5R
M<VEO;B`Q+C`V*2!B>2!.960@2V]N>BP@=VAI8V@@:7,@879A:6QA8FQE(&%T
M.@H@*B!H='1P.B\O=W=W+G!E<FPN8V]M+T-004XO875T:&]R<R]I9"].+TY%
M+TY%1$M/3EHO06QG;W)I=&AM+41I9F8M,2XP-BYZ:7`*("H*("H@36]R92!I
M9&5A<R!A<F4@=&%K96X@9G)O;3H*("H@:'1T<#HO+W=W=RYI8W,N=6-I+F5D
M=2]^97!P<W1E:6XO,38Q+SDV,#(R.2YH=&UL"B`J"B`J(%-O;64@:61E87,@
M*&%N9"!A(&)I="!O9B!C;V1E*2!A<F4@=&%K96X@9G)O;2!A;F%L>7IE+F,L
M(&]F($=.50H@*B!D:69F=71I;',M,BXW+"!W:&EC:"!C86X@8F4@9F]U;F0@
M870Z"B`J(&9T<#HO+V=N=61I<W0N9VYU+F]R9R]P=6(O9VYU+V1I9F9U=&EL
M<R]D:69F=71I;',M,BXW+G1A<BYG>@H@*@H@*B!3;VUE(&ED96%S("AS=6)D
M:79I<VEO;B!B>2!.0TA53DM3(#X@,BP@86YD('-O;64@;W!T:6UI>F%T:6]N
M<RD@87)E(&9R;VT*("H@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D
M86ER:6MI+F]R9SXN(%1H92!O<FEG:6YA;"!02%`@=F5R<VEO;B!O9B!T:&ES
M"B`J(&-O9&4@=V%S('=R:71T96X@8GD@:&EM+"!A;F0@:7,@=7-E9"]A9&%P
M=&5D('=I=&@@:&ES('!E<FUI<W-I;VXN"B`J"B`J($!A=71H;W(@($=E;V9F
M<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^"B`J($!P86-K
M86=E(%1E>'1?1&EF9@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S
M(%1E>'1?1&EF9E]%;F=I;F5?;F%T:79E('L*"B`@("!F=6YC=&EO;B!D:69F
M*"1F<F]M7VQI;F5S+"`D=&]?;&EN97,I"B`@("!["B`@("`@("`@)&Y?9G)O
M;2`](&-O=6YT*"1F<F]M7VQI;F5S*3L*("`@("`@("`D;E]T;R`](&-O=6YT
M*"1T;U]L:6YE<RD["@H@("`@("`@("1T:&ES+3YX8VAA;F=E9"`]("1T:&ES
M+3YY8VAA;F=E9"`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/GAV(#T@)'1H
M:7,M/GEV(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^>&EN9"`]("1T:&ES
M+3YY:6YD(#T@87)R87DH*3L*("`@("`@("!U;G-E="@D=&AI<RT^<V5Q*3L*
M("`@("`@("!U;G-E="@D=&AI<RT^:6Y?<V5Q*3L*("`@("`@("!U;G-E="@D
M=&AI<RT^;&-S*3L*"B`@("`@("`@+R\@4VMI<"!L96%D:6YG(&-O;6UO;B!L
M:6YE<RX*("`@("`@("!F;W(@*"1S:VEP(#T@,#L@)'-K:7`@/"`D;E]F<F]M
M("8F("1S:VEP(#P@)&Y?=&\[("1S:VEP*RLI('L*("`@("`@("`@("`@:68@
M*"1F<F]M7VQI;F5S6R1S:VEP72`A/3T@)'1O7VQI;F5S6R1S:VEP72D@>PH@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)'1H:7,M/GAC:&%N9V5D6R1S:VEP72`]("1T:&ES+3YY8VAA;F=E9%LD
M<VMI<%T@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O(%-K:7`@=')A
M:6QI;F<@8V]M;6]N(&QI;F5S+@H@("`@("`@("1X:2`]("1N7V9R;VT[("1Y
M:2`]("1N7W1O.PH@("`@("`@(&9O<B`H)&5N9'-K:7`@/2`P.R`M+21X:2`^
M("1S:VEP("8F("TM)'EI(#X@)'-K:7`[("1E;F1S:VEP*RLI('L*("`@("`@
M("`@("`@:68@*"1F<F]M7VQI;F5S6R1X:5T@(3T]("1T;U]L:6YE<ULD>6E=
M*2!["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("`D=&AI<RT^>&-H86YG961;)'AI72`]("1T:&ES+3YY8VAA;F=E
M9%LD>6E=(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!)9VYO<F4@
M;&EN97,@=VAI8V@@9&\@;F]T(&5X:7-T(&EN(&)O=&@@9FEL97,N"B`@("`@
M("`@9F]R("@D>&D@/2`D<VMI<#L@)'AI(#P@)&Y?9G)O;2`M("1E;F1S:VEP
M.R`D>&DK*RD@>PH@("`@("`@("`@("`D>&AA<VA;)&9R;VU?;&EN97-;)'AI
M75T@/2`Q.PH@("`@("`@('T*("`@("`@("!F;W(@*"1Y:2`]("1S:VEP.R`D
M>6D@/"`D;E]T;R`M("1E;F1S:VEP.R`D>6DK*RD@>PH@("`@("`@("`@("`D
M;&EN92`]("1T;U]L:6YE<ULD>6E=.PH@("`@("`@("`@("!I9B`H*"1T:&ES
M+3YY8VAA;F=E9%LD>6E=(#T@96UP='DH)'AH87-H6R1L:6YE72DI*2!["B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D>6AA<VA;)&QI;F5=(#T@,3L*("`@("`@("`@("`@)'1H:7,M/GEV
M6UT@/2`D;&EN93L*("`@("`@("`@("`@)'1H:7,M/GEI;F1;72`]("1Y:3L*
M("`@("`@("!]"B`@("`@("`@9F]R("@D>&D@/2`D<VMI<#L@)'AI(#P@)&Y?
M9G)O;2`M("1E;F1S:VEP.R`D>&DK*RD@>PH@("`@("`@("`@("`D;&EN92`]
M("1F<F]M7VQI;F5S6R1X:5T["B`@("`@("`@("`@(&EF("@H)'1H:7,M/GAC
M:&%N9V5D6R1X:5T@/2!E;7!T>2@D>6AA<VA;)&QI;F5=*2DI('L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T:&ES+3YX=EM=(#T@)&QI;F4["B`@("`@("`@("`@("1T:&ES+3YX:6YD
M6UT@/2`D>&D["B`@("`@("`@?0H*("`@("`@("`O+R!&:6YD('1H92!,0U,N
M"B`@("`@("`@)'1H:7,M/E]C;VUP87)E<V5Q*#`L(&-O=6YT*"1T:&ES+3YX
M=BDL(#`L(&-O=6YT*"1T:&ES+3YY=BDI.PH*("`@("`@("`O+R!-97)G92!E
M9&ET<R!W:&5N('!O<W-I8FQE+@H@("`@("`@("1T:&ES+3Y?<VAI9G1";W5N
M9&%R:65S*"1F<F]M7VQI;F5S+"`D=&AI<RT^>&-H86YG960L("1T:&ES+3YY
M8VAA;F=E9"D["B`@("`@("`@)'1H:7,M/E]S:&EF=$)O=6YD87)I97,H)'1O
M7VQI;F5S+"`D=&AI<RT^>6-H86YG960L("1T:&ES+3YX8VAA;F=E9"D["@H@
M("`@("`@("\O($-O;7!U=&4@=&AE(&5D:70@;W!E<F%T:6]N<RX*("`@("`@
M("`D961I=',@/2!A<G)A>2@I.PH@("`@("`@("1X:2`]("1Y:2`](#`["B`@
M("`@("`@=VAI;&4@*"1X:2`\("1N7V9R;VT@?'P@)'EI(#P@)&Y?=&\I('L*
M("`@("`@("`@("`@87-S97)T*"1Y:2`\("1N7W1O('Q\("1T:&ES+3YX8VAA
M;F=E9%LD>&E=*3L*("`@("`@("`@("`@87-S97)T*"1X:2`\("1N7V9R;VT@
M?'P@)'1H:7,M/GEC:&%N9V5D6R1Y:5TI.PH*("`@("`@("`@("`@+R\@4VMI
M<"!M871C:&EN9R`B<VYA:V4B+@H@("`@("`@("`@("`D8V]P>2`](&%R<F%Y
M*"D["B`@("`@("`@("`@('=H:6QE("@D>&D@/"`D;E]F<F]M("8F("1Y:2`\
M("1N7W1O"B`@("`@("`@("`@("`@("`@("`F)B`A)'1H:7,M/GAC:&%N9V5D
M6R1X:5T@)B8@(21T:&ES+3YY8VAA;F=E9%LD>6E=*2!["B`@("`@("`@("`@
M("`@("`D8V]P>5M=(#T@)&9R;VU?;&EN97-;)'AI*RM=.PH@("`@("`@("`@
M("`@("`@*RLD>6D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1C
M;W!Y*2!["B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X=%]$
M:69F7T]P7V-O<'DH)&-O<'DI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+R!&:6YD(&1E;&5T97,@)B!A9&1S+@H@("`@("`@("`@("`D9&5L971E
M(#T@87)R87DH*3L*("`@("`@("`@("`@=VAI;&4@*"1X:2`\("1N7V9R;VT@
M)B8@)'1H:7,M/GAC:&%N9V5D6R1X:5TI('L*("`@("`@("`@("`@("`@("1D
M96QE=&5;72`]("1F<F]M7VQI;F5S6R1X:2LK73L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&%D9"`](&%R<F%Y*"D["B`@("`@("`@("`@('=H:6QE
M("@D>6D@/"`D;E]T;R`F)B`D=&AI<RT^>6-H86YG961;)'EI72D@>PH@("`@
M("`@("`@("`@("`@)&%D9%M=(#T@)'1O7VQI;F5S6R1Y:2LK73L*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@:68@*"1D96QE=&4@)B8@)&%D9"D@>PH@
M("`@("`@("`@("`@("`@)&5D:71S6UT@/2`F;F5W(%1E>'1?1&EF9E]/<%]C
M:&%N9V4H)&1E;&5T92P@)&%D9"D["B`@("`@("`@("`@('T@96QS96EF("@D
M9&5L971E*2!["B`@("`@("`@("`@("`@("`D961I='-;72`]("9N97<@5&5X
M=%]$:69F7T]P7V1E;&5T92@D9&5L971E*3L*("`@("`@("`@("`@?2!E;'-E
M:68@*"1A9&0I('L*("`@("`@("`@("`@("`@("1E9&ET<UM=(#T@)FYE=R!4
M97AT7T1I9F9?3W!?861D*"1A9&0I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&5D:71S.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&EV:61E<R!T:&4@3&%R9V5S="!#;VUM;VX@4W5B<V5Q=65N8V4@*$Q#
M4RD@;V8@=&AE('-E<75E;F-E<R`H6$]&1BP*("`@("`J(%A,24TI(&%N9"`H
M64]&1BP@64Q)32D@:6YT;R!.0TA53DM3(&%P<')O>&EM871E;'D@97%U86QL
M>2!S:7IE9`H@("`@("H@<V5G;65N=',N"B`@("`@*@H@("`@("H@4F5T=7)N
M<R`H3$-3+"!05%,I+B`@3$-3(&ES('1H92!L96YG=&@@;V8@=&AE($Q#4RX@
M4%13(&ES(&%N(&%R<F%Y(&]F"B`@("`@*B!.0TA53DM3*S$@*%@L(%DI(&EN
M9&5X97,@9VEV:6YG('1H92!D:79I;F<@<&]I;G1S(&)E='=E96X@<W5B"B`@
M("`@*B!S97%U96YC97,N("!4:&4@9FER<W0@<W5B+7-E<75E;F-E(&ES(&-O
M;G1A:6YE9"!I;B`H6#`L(%@Q*2P@*%DP+"!9,2DL"B`@("`@*B!T:&4@<V5C
M;VYD(&EN("A8,2P@6#(I+"`H63$L(%DR*2!A;F0@<V\@;VXN("!.;W1E('1H
M870@*%@P+"!9,"D@/3T*("`@("`J("A83T9&+"!93T9&*2!A;F0@*%A;3D-(
M54Y+4UTL(%E;3D-(54Y+4UTI(#T]("A83$E-+"!93$E-*2X*("`@("`J"B`@
M("`@*B!4:&ES(&9U;F-T:6]N(&%S<W5M97,@=&AA="!T:&4@9FER<W0@;&EN
M97,@;V8@=&AE('-P96-I9FEE9"!P;W)T:6]N<R!O9@H@("`@("H@=&AE('1W
M;R!F:6QE<R!D;R!N;W0@;6%T8V@L(&%N9"!L:6ME=VES92!T:&%T('1H92!L
M87-T(&QI;F5S(&1O(&YO=`H@("`@("H@;6%T8V@N("!4:&4@8V%L;&5R(&UU
M<W0@=')I;2!M871C:&EN9R!L:6YE<R!F<F]M('1H92!B96=I;FYI;F<@86YD
M(&5N9`H@("`@("H@;V8@=&AE('!O<G1I;VYS(&ET(&ES(&=O:6YG('1O('-P
M96-I9GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]D:6%G("@D>&]F9BP@)'AL
M:6TL("1Y;V9F+"`D>6QI;2P@)&YC:'5N:W,I"B`@("!["B`@("`@("`@)&9L
M:7`@/2!F86QS93L*"B`@("`@("`@:68@*"1X;&EM("T@)'AO9F8@/B`D>6QI
M;2`M("1Y;V9F*2!["B`@("`@("`@("`@("\J(%1H:6YG<R!S965M<R!F87-T
M97(@*$DG;2!N;W0@<W5R92!)('5N9&5R<W1A;F0@=VAY*2!W:&5N('1H90H@
M("`@("`@("`@("`@*B!S:&]R=&5S="!S97%U96YC92!I<R!I;B!8+B`J+PH@
M("`@("`@("`@("`D9FQI<"`]('1R=64["B`@("`@("`@("`@(&QI<W0@*"1X
M;V9F+"`D>&QI;2P@)'EO9F8L("1Y;&EM*0H@("`@("`@("`@("`@("`@/2!A
M<G)A>2@D>6]F9BP@)'EL:6TL("1X;V9F+"`D>&QI;2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&9L:7`I('L*("`@("`@("`@("`@9F]R("@D:2`]("1Y
M;&EM("T@,3L@)&D@/CT@)'EO9F8[("1I+2TI('L*("`@("`@("`@("`@("`@
M("1Y;6%T8VAE<ULD=&AI<RT^>'9;)&E=75M=(#T@)&D["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!F;W(@*"1I(#T@)'EL
M:6T@+2`Q.R`D:2`^/2`D>6]F9CL@)&DM+2D@>PH@("`@("`@("`@("`@("`@
M)'EM871C:&5S6R1T:&ES+3YY=ELD:5U=6UT@/2`D:3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FQC<R`](#`["B`@("`@("`@
M)'1H:7,M/G-E<5LP73T@)'EO9F8@+2`Q.PH@("`@("`@("1T:&ES+3YI;E]S
M97$@/2!A<G)A>2@I.PH@("`@("`@("1Y;6ED<ULP72`](&%R<F%Y*"D["@H@
M("`@("`@("1N=6UE<B`]("1X;&EM("T@)'AO9F8@*R`D;F-H=6YK<R`M(#$[
M"B`@("`@("`@)'@@/2`D>&]F9CL*("`@("`@("!F;W(@*"1C:'5N:R`](#`[
M("1C:'5N:R`\("1N8VAU;FMS.R`D8VAU;FLK*RD@>PH@("`@("`@("`@("!I
M9B`H)&-H=6YK(#X@,"D@>PH@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[
M("1I(#P]("1T:&ES+3YL8W,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`D>6UI9'-;)&E=6R1C:'5N:R`M(#%=(#T@)'1H:7,M/G-E<5LD:5T["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1X
M,2`]("1X;V9F("L@*&EN="DH*"1N=6UE<B`K("@D>&QI;2TD>&]F9BDJ)&-H
M=6YK*2`O("1N8VAU;FMS*3L*("`@("`@("`@("`@9F]R("@[("1X(#P@)'@Q
M.R`D>"LK*2!["B`@("`@("`@("`@("`@("`D;&EN92`]("1F;&EP(#\@)'1H
M:7,M/GEV6R1X72`Z("1T:&ES+3YX=ELD>%T["B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)'EM871C:&5S6R1L:6YE72DI('L*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("1M871C:&5S(#T@)'EM871C:&5S6R1L:6YE73L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1M871C:&5S(&%S("1Y*2!["B`@("`@("`@("`@("`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3YI;E]S97%;)'E=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D:R`]("1T:&ES+3Y?;&-S4&]S*"1Y*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@87-S97)T*"1K(#X@,"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1Y;6ED<ULD:UT@/2`D>6UI9'-;)&L@+2`Q73L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@('=H
M:6QE("AL:7-T*"1J=6YK+"`D>2D@/2!E86-H*"1M871C:&5S*2D@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D>2`^("1T:&ES+3YS97%;)&L@+2`Q72D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("!A<W-E<G0H)'D@/"`D=&AI<RT^
M<V5Q6R1K72D["B`@("`@("`@("`@("`@("`@("`@("`@("\J($]P=&EM:7IA
M=&EO;CH@=&AI<R!I<R!A(&-O;6UO;B!C87-E.B!N97AT(&UA=&-H(&ES"B`@
M("`@("`@("`@("`@("`@("`@("`@("`J(&IU<W0@<F5P;&%C:6YG('!R979I
M;W5S(&UA=&-H+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M:6Y?<V5Q6R1T:&ES+3YS97%;)&M=72`](&9A;'-E.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<V5Q6R1K72`]("1Y.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^:6Y?<V5Q6R1Y72`](#$["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1T:&ES+3YI;E]S97%;)'E=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D:R`]("1T:&ES+3Y?;&-S4&]S
M*"1Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@87-S97)T*"1K(#X@,"D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1Y;6ED<ULD:UT@/2`D>6UI9'-;
M)&L@+2`Q73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1S97!S6UT@
M/2`D9FQI<"`_(&%R<F%Y*"1Y;V9F+"`D>&]F9BD@.B!A<G)A>2@D>&]F9BP@
M)'EO9F8I.PH@("`@("`@("1Y;6ED(#T@)'EM:61S6R1T:&ES+3YL8W-=.PH@
M("`@("`@(&9O<B`H)&X@/2`P.R`D;B`\("1N8VAU;FMS("T@,3L@)&XK*RD@
M>PH@("`@("`@("`@("`D>#$@/2`D>&]F9B`K("AI;G0I*"@D;G5M97(@*R`H
M)'AL:6T@+2`D>&]F9BD@*B`D;BD@+R`D;F-H=6YK<RD["B`@("`@("`@("`@
M("1Y,2`]("1Y;6ED6R1N72`K(#$["B`@("`@("`@("`@("1S97!S6UT@/2`D
M9FQI<"`_(&%R<F%Y*"1Y,2P@)'@Q*2`Z(&%R<F%Y*"1X,2P@)'DQ*3L*("`@
M("`@("!]"B`@("`@("`@)'-E<'-;72`]("1F;&EP(#\@87)R87DH)'EL:6TL
M("1X;&EM*2`Z(&%R<F%Y*"1X;&EM+"`D>6QI;2D["@H@("`@("`@(')E='5R
M;B!A<G)A>2@D=&AI<RT^;&-S+"`D<V5P<RD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7VQC<U!O<R@D>7!O<RD*("`@('L*("`@("`@("`D96YD(#T@)'1H:7,M
M/FQC<SL*("`@("`@("!I9B`H)&5N9"`]/2`P('Q\("1Y<&]S(#X@)'1H:7,M
M/G-E<5LD96YD72D@>PH@("`@("`@("`@("`D=&AI<RT^<V5Q6RLK)'1H:7,M
M/FQC<UT@/2`D>7!O<SL*("`@("`@("`@("`@)'1H:7,M/FEN7W-E<5LD>7!O
M<UT@/2`Q.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FQC<SL*("`@("`@
M("!]"@H@("`@("`@("1B96<@/2`Q.PH@("`@("`@('=H:6QE("@D8F5G(#P@
M)&5N9"D@>PH@("`@("`@("`@("`D;6ED(#T@*&EN="DH*"1B96<@*R`D96YD
M*2`O(#(I.PH@("`@("`@("`@("!I9B`H)'EP;W,@/B`D=&AI<RT^<V5Q6R1M
M:61=*2!["B`@("`@("`@("`@("`@("`D8F5G(#T@)&UI9"`K(#$["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D96YD(#T@)&UI9#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@87-S97)T*"1Y<&]S
M("$]("1T:&ES+3YS97%;)&5N9%TI.PH*("`@("`@("`D=&AI<RT^:6Y?<V5Q
M6R1T:&ES+3YS97%;)&5N9%U=(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/G-E
M<5LD96YD72`]("1Y<&]S.PH@("`@("`@("1T:&ES+3YI;E]S97%;)'EP;W-=
M(#T@,3L*("`@("`@("!R971U<FX@)&5N9#L*("`@('T*"B`@("`O*BH*("`@
M("`J($9I;F1S($Q#4R!O9B!T=V\@<V5Q=65N8V5S+@H@("`@("H*("`@("`J
M(%1H92!R97-U;'1S(&%R92!R96-O<F1E9"!I;B!T:&4@=F5C=&]R<R`D=&AI
M<RT^>W@L>7UC:&%N9V5D6UTL(&)Y"B`@("`@*B!S=&]R:6YG(&$@,2!I;B!T
M:&4@96QE;65N="!F;W(@96%C:"!L:6YE('1H870@:7,@86X@:6YS97)T:6]N
M(&]R"B`@("`@*B!D96QE=&EO;B`H:64N(&ES(&YO="!I;B!T:&4@3$-3*2X*
M("`@("`J"B`@("`@*B!4:&4@<W5B<V5Q=65N8V4@;V8@9FEL92`P(&ES("A8
M3T9&+"!83$E-*2!A;F0@;&EK97=I<V4@9F]R(&9I;&4@,2X*("`@("`J"B`@
M("`@*B!.;W1E('1H870@6$Q)32P@64Q)32!A<F4@97AC;'5S:79E(&)O=6YD
M<RX@($%L;"!L:6YE(&YU;6)E<G,@87)E"B`@("`@*B!O<FEG:6XM,"!A;F0@
M9&ES8V%R9&5D(&QI;F5S(&%R92!N;W0@8V]U;G1E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-O;7!A<F5S97$@*"1X;V9F+"`D>&QI;2P@)'EO9F8L("1Y
M;&EM*0H@("`@>PH@("`@("`@("\J(%-L:61E(&1O=VX@=&AE(&)O='1O;2!I
M;FET:6%L(&1I86=O;F%L+B`J+PH@("`@("`@('=H:6QE("@D>&]F9B`\("1X
M;&EM("8F("1Y;V9F(#P@)'EL:6T*("`@("`@("`@("`@("`@)B8@)'1H:7,M
M/GAV6R1X;V9F72`]/2`D=&AI<RT^>79;)'EO9F9=*2!["B`@("`@("`@("`@
M("LK)'AO9F8["B`@("`@("`@("`@("LK)'EO9F8["B`@("`@("`@?0H*("`@
M("`@("`O*B!3;&ED92!U<"!T:&4@=&]P(&EN:71I86P@9&EA9V]N86PN("HO
M"B`@("`@("`@=VAI;&4@*"1X;&EM(#X@)'AO9F8@)B8@)'EL:6T@/B`D>6]F
M9@H@("`@("`@("`@("`@("`F)B`D=&AI<RT^>'9;)'AL:6T@+2`Q72`]/2`D
M=&AI<RT^>79;)'EL:6T@+2`Q72D@>PH@("`@("`@("`@("`M+21X;&EM.PH@
M("`@("`@("`@("`M+21Y;&EM.PH@("`@("`@('T*"B`@("`@("`@:68@*"1X
M;V9F(#T]("1X;&EM('Q\("1Y;V9F(#T]("1Y;&EM*2!["B`@("`@("`@("`@
M("1L8W,@/2`P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%1H
M:7,@:7,@860@:&]C(&)U="!S965M<R!T;R!W;W)K('=E;&PN("`D;F-H=6YK
M<R`]"B`@("`@("`@("`@("`J('-Q<G0H;6EN*"1X;&EM("T@)'AO9F8L("1Y
M;&EM("T@)'EO9F8I("\@,BXU*3L@)&YC:'5N:W,@/0H@("`@("`@("`@("`@
M*B!M87@H,BQM:6XH."PH:6YT*21N8VAU;FMS*2D[("HO"B`@("`@("`@("`@
M("1N8VAU;FMS(#T@;6EN*#<L("1X;&EM("T@)'AO9F8L("1Y;&EM("T@)'EO
M9F8I("L@,3L*("`@("`@("`@("`@;&ES="@D;&-S+"`D<V5P<RD*("`@("`@
M("`@("`@("`@(#T@)'1H:7,M/E]D:6%G*"1X;V9F+"`D>&QI;2P@)'EO9F8L
M("1Y;&EM+"`D;F-H=6YK<RD["B`@("`@("`@?0H*("`@("`@("!I9B`H)&QC
M<R`]/2`P*2!["B`@("`@("`@("`@("\J(%@@86YD(%D@<V5Q=65N8V5S(&AA
M=F4@;F\@8V]M;6]N('-U8G-E<75E;F-E.B!M87)K(&%L;`H@("`@("`@("`@
M("`@*B!C:&%N9V5D+B`J+PH@("`@("`@("`@("!W:&EL92`H)'EO9F8@/"`D
M>6QI;2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/GEC:&%N9V5D6R1T:&ES
M+3YY:6YD6R1Y;V9F*RM=72`](#$["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@=VAI;&4@*"1X;V9F(#P@)'AL:6TI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YX8VAA;F=E9%LD=&AI<RT^>&EN9%LD>&]F9BLK75T@/2`Q.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@57-E
M('1H92!P87)T:71I;VYS('1O('-P;&ET('1H:7,@<')O8FQE;2!I;G1O('-U
M8G!R;V)L96US+B`J+PH@("`@("`@("`@("!R97-E="@D<V5P<RD["B`@("`@
M("`@("`@("1P=#$@/2`D<V5P<ULP73L*("`@("`@("`@("`@=VAI;&4@*"1P
M=#(@/2!N97AT*"1S97!S*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M;VUP87)E<V5Q("@D<'0Q6S!=+"`D<'0R6S!=+"`D<'0Q6S%=+"`D<'0R6S%=
M*3L*("`@("`@("`@("`@("`@("1P=#$@/2`D<'0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@061J=7-T<R!I;G-E
M<G1S+V1E;&5T97,@;V8@:61E;G1I8V%L(&QI;F5S('1O(&IO:6X@8VAA;F=E
M<R!A<R!M=6-H(&%S"B`@("`@*B!P;W-S:6)L92X*("`@("`J"B`@("`@*B!7
M92!D;R!S;VUE=&AI;F<@=VAE;B!A(')U;B!O9B!C:&%N9V5D(&QI;F5S(&EN
M8VQU9&4@82!L:6YE(&%T(&]N92!E;F0*("`@("`J(&%N9"!H87,@86X@97AC
M;'5D960L(&ED96YT:6-A;"!L:6YE(&%T('1H92!O=&AE<BX@(%=E(&%R92!F
M<F5E('1O"B`@("`@*B!C:&]O<V4@=VAI8V@@:61E;G1I8V%L(&QI;F4@:7,@
M:6YC;'5D960N("!@8V]M<&%R97-E<2<@=7-U86QL>2!C:&]O<V5S"B`@("`@
M*B!T:&4@;VYE(&%T('1H92!B96=I;FYI;F<L(&)U="!U<W5A;&QY(&ET(&ES
M(&-L96%N97(@=&\@8V]N<VED97(@=&AE"B`@("`@*B!F;VQL;W=I;F<@:61E
M;G1I8V%L(&QI;F4@=&\@8F4@=&AE(")C:&%N9V4B+@H@("`@("H*("`@("`J
M(%1H:7,@:7,@97AT<F%C=&5D('9E<F)A=&EM(&9R;VT@86YA;'EZ92YC("A'
M3E4@9&EF9G5T:6QS+3(N-RDN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:&EF
M=$)O=6YD87)I97,H)&QI;F5S+"`F)&-H86YG960L("1O=&AE<E]C:&%N9V5D
M*0H@("`@>PH@("`@("`@("1I(#T@,#L*("`@("`@("`D:B`](#`["@H@("`@
M("`@(&%S<V5R="@G8V]U;G0H)&QI;F5S*2`]/2!C;W5N="@D8VAA;F=E9"DG
M*3L*("`@("`@("`D;&5N(#T@8V]U;G0H)&QI;F5S*3L*("`@("`@("`D;W1H
M97)?;&5N(#T@8V]U;G0H)&]T:&5R7V-H86YG960I.PH*("`@("`@("!W:&EL
M92`H,2D@>PH@("`@("`@("`@("`O*B!38V%N(&9O<G=A<F0@=&\@9FEN9"!T
M:&4@8F5G:6YN:6YG(&]F(&%N;W1H97(@<G5N(&]F"B`@("`@("`@("`@("`J
M(&-H86YG97,N($%L<V\@:V5E<"!T<F%C:R!O9B!T:&4@8V]R<F5S<&]N9&EN
M9R!P;VEN="!I;B!T:&4*("`@("`@("`@("`@("H@;W1H97(@9FEL92X*("`@
M("`@("`@("`@("H*("`@("`@("`@("`@("H@5&AR;W5G:&]U="!T:&ES(&-O
M9&4L("1I(&%N9"`D:B!A<F4@861J=7-T960@=&]G971H97(@<V\@=&AA=`H@
M("`@("`@("`@("`@*B!T:&4@9FER<W0@)&D@96QE;65N=',@;V8@)&-H86YG
M960@86YD('1H92!F:7)S="`D:B!E;&5M96YT<R!O9@H@("`@("`@("`@("`@
M*B`D;W1H97)?8VAA;F=E9"!B;W1H(&-O;G1A:6X@=&AE('-A;64@;G5M8F5R
M(&]F('IE<F]S("AU;F-H86YG960*("`@("`@("`@("`@("H@;&EN97,I+@H@
M("`@("`@("`@("`@*@H@("`@("`@("`@("`@*B!&=7)T:&5R;6]R92P@)&H@
M:7,@86QW87ES(&ME<'0@<V\@=&AA="`D:B`]/2`D;W1H97)?;&5N(&]R"B`@
M("`@("`@("`@("`J("1O=&AE<E]C:&%N9V5D6R1J72`]/2!F86QS92X@*B\*
M("`@("`@("`@("`@=VAI;&4@*"1J(#P@)&]T:&5R7VQE;B`F)B`D;W1H97)?
M8VAA;F=E9%LD:ETI('L*("`@("`@("`@("`@("`@("1J*RL["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@('=H:6QE("@D:2`\("1L96X@)B8@(2`D8VAA
M;F=E9%LD:5TI('L*("`@("`@("`@("`@("`@(&%S<V5R="@G)&H@/"`D;W1H
M97)?;&5N("8F("$@)&]T:&5R7V-H86YG961;)&I=)RD["B`@("`@("`@("`@
M("`@("`D:2LK.R`D:BLK.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1J(#P@
M)&]T:&5R7VQE;B`F)B`D;W1H97)?8VAA;F=E9%LD:ETI('L*("`@("`@("`@
M("`@("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"@H@("`@("`@("`@("!I9B`H)&D@/3T@)&QE;BD@>PH@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1S=&%R
M="`]("1I.PH*("`@("`@("`@("`@+RH@1FEN9"!T:&4@96YD(&]F('1H:7,@
M<G5N(&]F(&-H86YG97,N("HO"B`@("`@("`@("`@('=H:6QE("@K*R1I(#P@
M)&QE;B`F)B`D8VAA;F=E9%LD:5TI('L*("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!D;R!["B`@("`@("`@
M("`@("`@("`O*B!296-O<F0@=&AE(&QE;F=T:"!O9B!T:&ES(')U;B!O9B!C
M:&%N9V5S+"!S;R!T:&%T('=E(&-A;@H@("`@("`@("`@("`@("`@("H@;&%T
M97(@9&5T97)M:6YE('=H971H97(@=&AE(')U;B!H87,@9W)O=VXN("HO"B`@
M("`@("`@("`@("`@("`D<G5N;&5N9W1H(#T@)&D@+2`D<W1A<G0["@H@("`@
M("`@("`@("`@("`@+RH@36]V92!T:&4@8VAA;F=E9"!R96=I;VX@8F%C:RP@
M<V\@;&]N9R!A<R!T:&4@<')E=FEO=7,*("`@("`@("`@("`@("`@("`J('5N
M8VAA;F=E9"!L:6YE(&UA=&-H97,@=&AE(&QA<W0@8VAA;F=E9"!O;F4N("!4
M:&ES(&UE<F=E<PH@("`@("`@("`@("`@("`@("H@=VET:"!P<F5V:6]U<R!C
M:&%N9V5D(')E9VEO;G,N("HO"B`@("`@("`@("`@("`@("!W:&EL92`H)'-T
M87)T(#X@,"`F)B`D;&EN97-;)'-T87)T("T@,5T@/3T@)&QI;F5S6R1I("T@
M,5TI('L*("`@("`@("`@("`@("`@("`@("`D8VAA;F=E9%LM+21S=&%R=%T@
M/2`Q.PH@("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6RTM)&E=(#T@9F%L
M<V4["B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1S=&%R="`^(#`@)B8@
M)&-H86YG961;)'-T87)T("T@,5TI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T87)T+2T["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&%S<V5R="@G)&H@/B`P)RD["B`@("`@("`@("`@("`@("`@
M("`@=VAI;&4@*"1O=&AE<E]C:&%N9V5D6RTM)&I=*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!A<W-E<G0H)R1J(#X](#`@)B8@(21O=&AE
M<E]C:&%N9V5D6R1J72<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("\J(%-E="!#3U)215-03TY$24Y'('1O('1H92!E;F0@;V8@=&AE
M(&-H86YG960@<G5N+"!A="!T:&4*("`@("`@("`@("`@("`@("`J(&QA<W0@
M<&]I;G0@=VAE<F4@:70@8V]R<F5S<&]N9',@=&\@82!C:&%N9V5D(')U;B!I
M;B!T:&4*("`@("`@("`@("`@("`@("`J(&]T:&5R(&9I;&4N($-/4E)%4U!/
M3D1)3D<@/3T@3$5.(&UE86YS(&YO('-U8V@@<&]I;G0@:&%S"B`@("`@("`@
M("`@("`@("`@*B!B965N(&9O=6YD+B`J+PH@("`@("`@("`@("`@("`@)&-O
M<G)E<W!O;F1I;F<@/2`D:B`\("1O=&AE<E]L96X@/R`D:2`Z("1L96X["@H@
M("`@("`@("`@("`@("`@+RH@36]V92!T:&4@8VAA;F=E9"!R96=I;VX@9F]R
M=V%R9"P@<V\@;&]N9R!A<R!T:&4@9FER<W0*("`@("`@("`@("`@("`@("`J
M(&-H86YG960@;&EN92!M871C:&5S('1H92!F;VQL;W=I;F<@=6YC:&%N9V5D
M(&]N92X@(%1H:7,*("`@("`@("`@("`@("`@("`J(&UE<F=E<R!W:71H(&9O
M;&QO=VEN9R!C:&%N9V5D(')E9VEO;G,N("!$;R!T:&ES('-E8V]N9"P@<V\*
M("`@("`@("`@("`@("`@("`J('1H870@:68@=&AE<F4@87)E(&YO(&UE<F=E
M<RP@=&AE(&-H86YG960@<F5G:6]N(&ES(&UO=F5D"B`@("`@("`@("`@("`@
M("`@*B!F;W)W87)D(&%S(&9A<B!A<R!P;W-S:6)L92X@*B\*("`@("`@("`@
M("`@("`@('=H:6QE("@D:2`\("1L96X@)B8@)&QI;F5S6R1S=&%R=%T@/3T@
M)&QI;F5S6R1I72D@>PH@("`@("`@("`@("`@("`@("`@("1C:&%N9V5D6R1S
M=&%R="LK72`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("1C:&%N9V5D
M6R1I*RM=(#T@,3L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&D@/"`D
M;&5N("8F("1C:&%N9V5D6R1I72D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D:2LK.PH@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`@("`@87-S97)T*"<D:B`\("1O=&AE<E]L96X@)B8@(2`D;W1H97)?8VAA
M;F=E9%LD:ETG*3L*("`@("`@("`@("`@("`@("`@("`D:BLK.PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D:B`\("1O=&AE<E]L96X@)B8@)&]T:&5R7V-H
M86YG961;)&I=*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C;W)R97-P
M;VYD:6YG(#T@)&D["B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE("@D
M:B`\("1O=&AE<E]L96X@)B8@)&]T:&5R7V-H86YG961;)&I=*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:BLK.PH@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]('=H:6QE("@D<G5N;&5N9W1H("$]("1I("T@
M)'-T87)T*3L*"B`@("`@("`@("`@("\J($EF('!O<W-I8FQE+"!M;W9E('1H
M92!F=6QL>2UM97)G960@<G5N(&]F(&-H86YG97,@8F%C:R!T;R!A"B`@("`@
M("`@("`@("`J(&-O<G)E<W!O;F1I;F<@<G5N(&EN('1H92!O=&AE<B!F:6QE
M+B`J+PH@("`@("`@("`@("!W:&EL92`H)&-O<G)E<W!O;F1I;F<@/"`D:2D@
M>PH@("`@("`@("`@("`@("`@)&-H86YG961;+2TD<W1A<G1=(#T@,3L*("`@
M("`@("`@("`@("`@("1C:&%N9V5D6RTM)&E=(#T@,#L*("`@("`@("`@("`@
M("`@(&%S<V5R="@G)&H@/B`P)RD["B`@("`@("`@("`@("`@("!W:&EL92`H
M)&]T:&5R7V-H86YG961;+2TD:ETI('L*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&%S
M<V5R="@G)&H@/CT@,"`F)B`A)&]T:&5R7V-H86YG961;)&I=)RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@
M5&5X=%]$:69F"B`J($!A=71H;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A
M:7)I:VE`9&%I<FEK:2YO<F<^"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*
M8VQA<W,@5&5X=%]$:69F7T]P('L*"B`@("!V87(@)&]R:6<["B`@("!V87(@
M)&9I;F%L.PH*("`@(&9U;F-T:6]N(')E=F5R<V4H*0H@("`@>PH@("`@("`@
M('1R:6=G97)?97)R;W(H)T%B<W1R86-T(&UE=&AO9"<L($5?55-%4E]%4E)/
M4BD["B`@("!]"@H@("`@9G5N8W1I;VX@;F]R:6<H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^;W)I9R`_(&-O=6YT*"1T:&ES+3YO<FEG*2`Z(#`[
M"B`@("!]"@H@("`@9G5N8W1I;VX@;F9I;F%L*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/F9I;F%L(#\@8V]U;G0H)'1H:7,M/F9I;F%L*2`Z(#`[
M"B`@("!]"@I]"@HO*BH*("H@0'!A8VMA9V4@5&5X=%]$:69F"B`J($!A=71H
M;W(@($=E;V9F<F5Y(%0N($1A:7)I:VD@/&1A:7)I:VE`9&%I<FEK:2YO<F<^
M"B`J"B`J($!A8V-E<W,@<')I=F%T90H@*B\*8VQA<W,@5&5X=%]$:69F7T]P
M7V-O<'D@97AT96YD<R!497AT7T1I9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E
M>'1?1&EF9E]/<%]C;W!Y*"1O<FEG+"`D9FEN86P@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1F:6YA;"DI('L*("`@("`@("`@("`@
M)&9I;F%L(#T@)&]R:6<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YO<FEG
M(#T@)&]R:6<["B`@("`@("`@)'1H:7,M/F9I;F%L(#T@)&9I;F%L.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9R979E<G-E*"D*("`@('L*("`@("`@("`D<F5V
M97)S92`]("9N97<@5&5X=%]$:69F7T]P7V-O<'DH)'1H:7,M/F9I;F%L+"`D
M=&AI<RT^;W)I9RD["B`@("`@("`@<F5T=7)N("1R979E<G-E.PH@("`@?0H*
M?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F
M9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`
M86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9E]/<%]D96QE=&4@
M97AT96YD<R!497AT7T1I9F9?3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF
M9E]/<%]D96QE=&4H)&QI;F5S*0H@("`@>PH@("`@("`@("1T:&ES+3YO<FEG
M(#T@)&QI;F5S.PH@("`@("`@("1T:&ES+3YF:6YA;"`](&9A;'-E.PH@("`@
M?0H*("`@(&9U;F-T:6]N("9R979E<G-E*"D*("`@('L*("`@("`@("`D<F5V
M97)S92`]("9N97<@5&5X=%]$:69F7T]P7V%D9"@D=&AI<RT^;W)I9RD["B`@
M("`@("`@<F5T=7)N("1R979E<G-E.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K
M86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E>2!4+B!$86ER:6MI
M(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*@H@*B!`86-C97-S('!R:79A=&4*
M("HO"F-L87-S(%1E>'1?1&EF9E]/<%]A9&0@97AT96YD<R!497AT7T1I9F9?
M3W`@>PH*("`@(&9U;F-T:6]N(%1E>'1?1&EF9E]/<%]A9&0H)&QI;F5S*0H@
M("`@>PH@("`@("`@("1T:&ES+3YF:6YA;"`]("1L:6YE<SL*("`@("`@("`D
M=&AI<RT^;W)I9R`](&9A;'-E.PH@("`@?0H*("`@(&9U;F-T:6]N("9R979E
M<G-E*"D*("`@('L*("`@("`@("`D<F5V97)S92`]("9N97<@5&5X=%]$:69F
M7T]P7V1E;&5T92@D=&AI<RT^9FEN86PI.PH@("`@("`@(')E='5R;B`D<F5V
M97)S93L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@
M0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI
M+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I
M9F9?3W!?8VAA;F=E(&5X=&5N9',@5&5X=%]$:69F7T]P('L*"B`@("!F=6YC
M=&EO;B!497AT7T1I9F9?3W!?8VAA;F=E*"1O<FEG+"`D9FEN86PI"B`@("![
M"B`@("`@("`@)'1H:7,M/F]R:6<@/2`D;W)I9SL*("`@("`@("`D=&AI<RT^
M9FEN86P@/2`D9FEN86P["B`@("!]"@H@("`@9G5N8W1I;VX@)G)E=F5R<V4H
M*0H@("`@>PH@("`@("`@("1R979E<G-E(#T@)FYE=R!497AT7T1I9F9?3W!?
M8VAA;F=E*"1T:&ES+3YF:6YA;"P@)'1H:7,M/F]R:6<I.PH@("`@("`@(')E
M='5R;B`D<F5V97)S93L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T9L;W=E9"YP:'``````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-C<R,2`Q,#4Q-30S
M-#$S-B`P,C$Q-S``(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%1H92!497AT7T9L;W=E9#HZ(&-L87-S
M('!R;W9I9&5S(&-O;6UO;B!M971H;V1S(&9O<B!M86YI<'5L871I;F<@=&5X
M=`H@*B!U<VEN9R!T:&4@96YC;V1I;F<@9&5S8W)I8F5D(&EN(%)&0R`S-C<V
M("@G9FQO=V5D)R!T97AT*2X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X
M=%]&;&]W960O1FQO=V5D+G!H<"QV(#$N,30N,3`N,3<@,C`P-B\P,R\Q,2`P
M.3HU,#HR,B!J86X@17AP("0*("H*("H@5&AI<R!C;&%S<R!I<R!B87-E9"!O
M;B!T:&4@5&5X=#HZ1FQO=V5D('!E<FP@;6]D=6QE("A697)S:6]N(#`N,30I
M(&9O=6YD"B`J(&EN('1H92!#4$%.('!E<FP@<F5P;W-I=&]R>2X@(%1H:7,@
M;6]D=6QE(&ES(')E;&5A<V5D('5N9&5R('1H92!097)L"B`J(&QI8V5N<V4L
M('=H:6-H(&ES(&-O;7!A=&EB;&4@=VET:"!T:&4@3$=03"X*("H*("H@0V]P
M>7)I9VAT(#(P,#(M,C`P,R!0:&EL:7`@36%K"B`J($-O<'ER:6=H="`R,#`T
M+3(P,#8@36EC:&%E;"!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U=&AO<B`@36EC:&%E;"!3
M;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A9&\N961U/@H@*B!`<VEN
M8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@2&]R9&5?5&5X=`H@*B\*8VQA
M<W,@5&5X=%]&;&]W960@>PH*("`@("\J*@H@("`@("H@5&AE(&UA>&EM=6T@
M;&5N9W1H('1H870@82!L:6YE(&ES(&%L;&]W960@=&\@8F4@*'5N;&5S<R!F
M86-E9"!W:71H"B`@("`@*B!W:71H(&$@=V]R9"!T:&%T(&ES('5N<F5A<V]N
M86)L>2!L;VYG*2X@5&AI<R!C;&%S<R!W:6QL(')E+7=R87`@80H@("`@("H@
M;&EN92!I9B!I="!E>&-E961S('1H:7,@;&5N9W1H+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]M87AL96YG=&@@/2`W
M.#L*"B`@("`O*BH*("`@("`J(%=H96X@=&AI<R!C;&%S<R!W<F%P<R!A(&QI
M;F4L('1H92!N97=L>2!C<F5A=&5D(&QI;F5S('=I;&P@8F4@<W!L:70*("`@
M("`J(&%T('1H:7,@;&5N9W1H+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]O<'1L96YG=&@@/2`W,CL*"B`@("`O*BH*
M("`@("`J(%1H92!T97AT('1O(&)E(&9O<FUA='1E9"X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T97AT.PH*("`@("\J
M*@H@("`@("H@5&AE(&-A8VAE9"!O=71P=70@;V8@=&AE(&9O<FUA='1I;F<N
M"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O
M=71P=70@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5&AE(&-H87)A8W1E<B!S
M970@;V8@=&AE('1E>'0N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1?8VAA<G-E=#L*"B`@("`O*BH*("`@("`J($-O;G9E
M<G0@=&5X="!U<VEN9R!$96Q3<#\*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE
M86X*("`@("`J+PH@("`@=F%R("1?9&5L<W`@/2!F86QS93L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)'1E>'0@("`@(%1H92!T97AT('1O('!R;V-E<W,N"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1C:&%R<V5T("!4:&4@8VAA<F%C=&5R('-E="!O9B`D=&5X
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]&;&]W960H)'1E>'0L("1C
M:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D
M=&5X=#L*("`@("`@("`D=&AI<RT^7V-H87)S970@/2`D8VAA<G-E=#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@;6%X:6UU;2!L96YG=&@@;V8@
M82!L:6YE(&]F('1E>'0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M)&UA>"`@02!N97<@=F%L=64@9F]R("1?;6%X;&5N9W1H+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971-87A,96YG=&@H)&UA>"D*("`@('L*("`@("`@("`D
M=&AI<RT^7VUA>&QE;F=T:"`]("1M87@["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@=&AE(&]P=&EM86P@;&5N9W1H(&]F(&$@;&EN92!O9B!T97AT+@H@
M("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1M87@@($$@;F5W('9A;'5E
M(&9O<B`D7V]P=&QE;F=T:"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T
M3&5N9W1H*"1O<'0I"B`@("!["B`@("`@("`@)'1H:7,M/E]O<'1L96YG=&@@
M/2`D;W!T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('=H971H97(@=&\@
M9F]R;6%T('1E<W0@=7-I;F<@1&5L4W`N"B`@("`@*@H@("`@("H@0'-I;F-E
M($AO<F1E(#,N,0H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1D96QS
M<"`@57-E($1E;%-P/PH@("`@("HO"B`@("!F=6YC=&EO;B!S971$96Q3<"@D
M9&5L<W`I"B`@("!["B`@("`@("`@)'1H:7,M/E]D96QS<"`]("AB;V]L*2`D
M9&5L<W`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2969O<FUA=',@=&AE(&EN
M<'5T('-T<FEN9RP@=VAE<F4@=&AE('-T<FEN9R!I<R`G9F]R;6%T/69L;W=E
M9"<@<&QA:6X*("`@("`J('1E>'0@87,@9&5S8W)I8F5D(&EN(%)&0R`R-C0V
M+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1Q=6]T92`@061D(&QE
M=F5L(&]F('%U;W1I;F<@=&\@96%C:"!L:6YE/PH@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@=&5X="!C;VYV97)T960@=&\@4D9#(#(V-#8@
M)V9I>&5D)R!F;W)M870N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O1FEX960H
M)'%U;W1E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1X="`]("<G.PH*("`@
M("`@("`D=&AI<RT^7W)E9F]R;6%T*&9A;'-E+"`D<75O=&4I.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?;W5T<'5T(&%S("1V86PI('L*("`@("`@("`@
M("`@)'1X="`N/2`D=F%L6R=T97AT)UT@+B`B7&XB.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@<G1R:6TH)'1X="D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2969O<FUA=',@=&AE(&EN<'5T('-T<FEN9RP@86YD(')E='5R;G,@=&AE
M(&]U='!U="!I;B!A;B!A<G)A>2!F;W)M870*("`@("`J('=I=&@@<75O=&4@
M;&5V96P@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)'%U;W1E("!!9&0@;&5V96P@;V8@<75O=&EN9R!T;R!E86-H(&QI;F4_
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@06X@87)R87D@;V8@87)R
M87ES('=I=&@@=&AE(&9O;&QO=VEN9R!E;&5M96YT<SH*("`@("`J(#QP<F4^
M"B`@("`@*B`G;&5V96PG("T@5&AE('%U;W1E(&QE=F5L(&]F('1H92!C=7)R
M96YT(&QI;F4N"B`@("`@*B`G=&5X="<@("T@5&AE('1E>'0@9F]R('1H92!C
M=7)R96YT(&QI;F4N"B`@("`@*B`\+W!R93X*("`@("`J+PH@("`@9G5N8W1I
M;VX@=&]&:7AE9$%R<F%Y*"1Q=6]T92`](&9A;'-E*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?<F5F;W)M870H9F%L<V4L("1Q=6]T92D["B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5F
M;W)M871S('1H92!I;G!U="!S=')I;F<L('=H97)E('1H92!S=')I;F<@:7,@
M)V9O<FUA=#UF:7AE9"<@<&QA:6X*("`@("`J('1E>'0@87,@9&5S8W)I8F5D
M(&EN(%)&0R`R-C0V+@H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1Q
M=6]T92`@061D(&QE=F5L(&]F('%U;W1I;F<@=&\@96%C:"!L:6YE/PH@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=&5X="!C;VYV97)T960@
M=&\@4D9#(#(V-#8@)V9L;W=E9"<@9F]R;6%T+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!T;T9L;W=E9"@D<75O=&4@/2!F86QS92D*("`@('L*("`@("`@("`D
M='AT(#T@)R<["@H@("`@("`@("1T:&ES+3Y?<F5F;W)M870H=')U92P@)'%U
M;W1E*3L*("`@("`@("!F;W)E86-H("@D=&AI<RT^7V]U='!U="!A<R`D=F%L
M*2!["B`@("`@("`@("`@("1T>'0@+CT@)'9A;%LG=&5X="==("X@(EQN(CL*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T>'0["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2969O<FUA=',@=&AE(&EN<'5T('-T<FEN9RP@=VAE<F4@=&AE
M('-T<FEN9R!I<R`G9F]R;6%T/69L;W=E9"<@<&QA:6X*("`@("`J('1E>'0@
M87,@9&5S8W)I8F5D(&EN(%)&0R`R-C0V+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!B;V]L96%N("1T;V9L
M;W=E9"`@0V]N=F5R="!T;R!F;&]W960_"B`@("`@*B!`<&%R86T@8F]O;&5A
M;B`D<75O=&4@("`@($%D9"!L979E;"!O9B!Q=6]T:6YG('1O(&5A8V@@;&EN
M93\*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!(&QI<W0@;V8@87)R
M87ES+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<F5F;W)M870H)'1O9FQO=V5D
M+"`D<75O=&4I"B`@("!["B`@("`@("`@:68@*"%I<U]N=6QL*"1T:&ES+3Y?
M;W5T<'5T*2D@>PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7V]U='!U="`](&%R<F%Y*"D["B`@("`@("`@)'1E>'0@
M/2!E>'!L;V1E*")<;B(L("1T:&ES+3Y?=&5X="D["@H@("`@("`@("\J(%-E
M="!V87)I86)L97,@=7-E9"!I;B!R96=E>'!S+B`J+PH@("`@("`@("1D96QS
M<"`]("@D=&]F;&]W960@)B8@)'1H:7,M/E]D96QS<"D@/R`Q(#H@,#L*("`@
M("`@("`D;W!T(#T@)'1H:7,M/E]O<'1L96YG=&@@+2`Q("T@)&1E;'-P.PH*
M("`@("`@("`O*B!0<F]C97-S(&UE<W-A9V4@;&EN92!B>2!L:6YE+B`J+PH@
M("`@("`@(&1O('L*("`@("`@("`@("`@)&QI;F4@/2!A<G)A>5]S:&EF="@D
M=&5X="D["@H@("`@("`@("`@("`O*B!097(@4D9#(#(V-#8@6S0N,UTL('1H
M92`G57-E;F5T(%-I9VYA='5R92!#;VYV96YT:6]N)R!L:6YE"B`@("`@("`@
M("`@("`J("A$05-(($1!4T@@4U`I(&ES(&YO="!C;VYS:61E<F5D(&9L;W=E
M9"X@(%=A=&-H(&9O<B!T:&ES('=H96X*("`@("`@("`@("`@("H@9&5A;&EN
M9R!W:71H('!O=&5N=&EA;&QY(&9L;W=E9"!L:6YE<RX@*B\*"B`@("`@("`@
M("`@("\J(%1H92!N97AT('1H<F5E('-T97!S(&-O;64@9G)O;2!21D,@,C8T
M-B!;-"XR72X@*B\*("`@("`@("`@("`@+RH@4U1%4"`Q.B!$971E<FUI;F4@
M<75O=&4@;&5V96P@9F]R(&QI;F4N("HO"B`@("`@("`@("`@(&EF("@H)&YU
M;5]Q=6]T97,@/2`D=&AI<RT^7VYU;7%U;W1E<R@D;&EN92DI*2!["B`@("`@
M("`@("`@("`@("`D;&EN92`]('-U8G-T<B@D;&EN92P@)&YU;5]Q=6]T97,I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!/;FQY(&-O;6)I;F4@
M;&EN97,@:68@=V4@87)E(&-O;G9E<G1I;F<@=&\@9FQO=V5D(&]R(&EF('1H
M90H@("`@("`@("`@("`@*B!C=7)R96YT(&QI;F4@:7,@<75O=&5D+B`J+PH@
M("`@("`@("`@("!I9B`H(21T;V9L;W=E9"!\?"`D;G5M7W%U;W1E<RD@>PH@
M("`@("`@("`@("`@("`@+RH@4U1%4"`R.B!296UO=F4@<W!A8V4@<W1U9F9I
M;F<@9G)O;2!L:6YE+B`J+PH@("`@("`@("`@("`@("`@)&QI;F4@/2`D=&AI
M<RT^7W5N<W1U9F8H)&QI;F4I.PH*("`@("`@("`@("`@("`@("\J(%-415`@
M,SH@4VAO=6QD('=E(&EN=&5R<')E="!T:&ES(&QI;F4@87,@9FQO=V5D/PH@
M("`@("`@("`@("`@("`@("H@5VAI;&4@;&EN92!I<R!F;&]W960@*&YO="!E
M;7!T>2!A;F0@=&AE<F4@:7,@82!S<&%C90H@("`@("`@("`@("`@("`@("H@
M870@=&AE(&5N9"!O9B!T:&4@;&EN92DL(&%N9"!T:&5R92!I<R!A(&YE>'0@
M;&EN92P@86YD('1H90H@("`@("`@("`@("`@("`@("H@;F5X="!L:6YE(&AA
M<R!T:&4@<V%M92!Q=6]T92!D97!T:"P@861D('1O('1H92!C=7)R96YT"B`@
M("`@("`@("`@("`@("`@*B!L:6YE+B!!(&QI;F4@:7,@;F]T(&9L;W=E9"!I
M9B!I="!I<R!A('-I9VYA='5R92!L:6YE+B`J+PH@("`@("`@("`@("`@("`@
M=VAI;&4@*"%E;7!T>2@D;&EN92D@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`H)&QI;F4@(3T@)RTM("<I("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M*"1L:6YE>W-T<FQE;B@D;&EN92DM,7T@/3T@)R`G*2`F)@H@("`@("`@("`@
M("`@("`@("`@("`@("%E;7!T>2@D=&5X="D@)B8*("`@("`@("`@("`@("`@
M("`@("`@("`H)'1H:7,M/E]N=6UQ=6]T97,H)'1E>'1;,%TI(#T]("1N=6U?
M<75O=&5S*2D@>PH@("`@("`@("`@("`@("`@("`@("\J($EF($1E;%-P(&ES
M('EE<R!A;F0@=&AI<R!I<R!F;&]W960@:6YP=70L('=E(&YE960@=&\*("`@
M("`@("`@("`@("`@("`@("`@*B!R96UO=F4@=&AE('1R86EL:6YG('-P86-E
M+B`J+PH@("`@("`@("`@("`@("`@("`@(&EF("@A)'1O9FQO=V5D("8F("1T
M:&ES+3Y?9&5L<W`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F4@
M/2!S=6)S='(H)&QI;F4L(#`L("TQ*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)&QI;F4@+CT@)'1H:7,M/E]U;G-T=69F
M*'-U8G-T<BAA<G)A>5]S:&EF="@D=&5X="DL("1N=6U?<75O=&5S*2D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J
M($5N<W5R92!L:6YE(&ES(&9I>&5D+"!S:6YC92!W92!A;')E861Y(&IO:6YE
M9"!A;&P@9FQO=V5D"B`@("`@("`@("`@("`J(&QI;F5S+B!296UO=F4@86QL
M('1R86EL:6YG("<@)R!F<F]M('1H92!L:6YE+B`J+PH@("`@("`@("`@("!I
M9B`H)&QI;F4@(3T@)RTM("<I('L*("`@("`@("`@("`@("`@("1L:6YE(#T@
M<G1R:6TH)&QI;F4I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!)
M;F-R96UE;G0@<75O=&4@9&5P=&@@:68@=V4G<F4@<75O=&EN9RX@*B\*("`@
M("`@("`@("`@:68@*"1Q=6]T92D@>PH@("`@("`@("`@("`@("`@)&YU;5]Q
M=6]T97,K*SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@5&AE('%U
M;W1E('!R969I>"!F;W(@=&AE(&QI;F4N("HO"B`@("`@("`@("`@("1Q=6]T
M97-T<B`]('-T<E]R97!E870H)SXG+"`D;G5M7W%U;W1E<RD["@H@("`@("`@
M("`@("!I9B`H96UP='DH)&QI;F4I*2!["B`@("`@("`@("`@("`@("`O*B!,
M:6YE(&ES(&5M<'1Y+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=71P
M=71;72`](&%R<F%Y*"=T97AT)R`]/B`D<75O=&5S='(L("=L979E;"<@/3X@
M)&YU;5]Q=6]T97,I.PH@("`@("`@("`@("!](&5L<V5I9B`H96UP='DH)'1H
M:7,M/E]M87AL96YG=&@I('Q\("@H4W1R:6YG.CIL96YG=&@H)&QI;F4L("1T
M:&ES+3Y?8VAA<G-E="D@*R`D;G5M7W%U;W1E<RD@/#T@)'1H:7,M/E]M87AL
M96YG=&@I*2!["B`@("`@("`@("`@("`@("`O*B!,:6YE(&1O97,@;F]T(')E
M<75I<F4@<F5W<F%P<&EN9RX@*B\*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T<'5T6UT@/2!A<G)A>2@G=&5X="<@/3X@)'%U;W1E<W1R("X@)'1H:7,M
M/E]S='5F9B@D;&EN92P@)&YU;5]Q=6]T97,L("1T;V9L;W=E9"DL("=L979E
M;"<@/3X@)&YU;5]Q=6]T97,I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)&UI;B`]("1N=6U?<75O=&5S("L@,3L*"B`@("`@("`@
M("`@("`@("`O*B!297=R87`@=&AI<R!P87)A9W)A<&@N("HO"B`@("`@("`@
M("`@("`@("!W:&EL92`H)&QI;F4I('L*("`@("`@("`@("`@("`@("`@("`O
M*B!3='5F9B!A;F0@<F4M<75O=&4@=&AE(&QI;F4N("HO"B`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@/2`D<75O=&5S='(@+B`D=&AI<RT^7W-T=69F*"1L
M:6YE+"`D;G5M7W%U;W1E<RP@)'1O9FQO=V5D*3L*("`@("`@("`@("`@("`@
M("`@("`D;&EN95]L96YG=&@@/2!3=')I;F<Z.FQE;F=T:"@D;&EN92P@)'1H
M:7,M/E]C:&%R<V5T*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&QI;F5?
M;&5N9W1H(#P]("1T:&ES+3Y?;W!T;&5N9W1H*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\J(%)E;6%I;FEN9R!S96-T:6]N(&]F(&QI;F4@:7,@<VAO
M<G0@96YO=6=H+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V]U='!U=%M=(#T@87)R87DH)W1E>'0G(#T^("1L:6YE+"`G;&5V96PG(#T^
M("1N=6U?<75O=&5S*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1M(#T@4W1R:6YG.CIR
M96=E>$UA=&-H*"1L:6YE+"!A<G)A>2@G7B@N>R<@+B`D;6EN("X@)RPG("X@
M)&]P="`N("=]*2`H+BHI)RP@)UXH+GLG("X@)&UI;B`N("<L)R`N("1T:&ES
M+3Y?;6%X;&5N9W1H("X@)WTI("@N*BDG+"`G7B@N>R<@+B`D;6EN("X@)RQ]
M*3\@*"XJ*2<I+"`D=&AI<RT^7V-H87)S970I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\J(%=E(&YE960@=&\@=W)A<"!T97AT(&%T(&$@8V5R=&%I
M;B!N=6UB97(@;V8*("`@("`@("`@("`@("`@("`@("`@("`@("H@*F-H87)A
M8W1E<G,J+"!N;W0@82!C97)T86EN(&YU;6)E<B!O9B`J8GET97,J.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@*B!T:'5S('1H92!N965D(&9O<B!A(&UU
M;'1I8GET92!C87!A8FQE(')E9V5X+@H@("`@("`@("`@("`@("`@("`@("`@
M("`@*B!)9B!A(&UU;'1I8GET92!R96=E>"!I<VXG="!A=F%I;&%B;&4L('=E
M(&%R92!S='5C:PH@("`@("`@("`@("`@("`@("`@("`@("`@*B!W:71H('!R
M96=?;6%T8V@H*2`H=&AE(&9U;F-T:6]N('=I;&P@<W1I;&P@=V]R:R`M"B`@
M("`@("`@("`@("`@("`@("`@("`@("`J('=E('=I;&P@:G5S="!B92!L969T
M('=I=&@@<VAO<G1E<B!R;W=S('1H86X@97AP96-T960*("`@("`@("`@("`@
M("`@("`@("`@("`@("H@:68@;75L=&EB>71E(&-H87)A8W1E<G,@97AI<W0@
M:6X@=&AE(')O=RDN"B`@("`@("`@("`@("`@("`@("`@("`@("`J"B`@("`@
M("`@("`@("`@("`@("`@("`@("`J($%L9V]R:71H:6TZ"B`@("`@("`@("`@
M("`@("`@("`@("`@("`J(#$N(%1R>2!T;R!F:6YD(&$@<W1R:6YG(&%S(&QO
M;F<@87,@7V]P=&QE;F=T:"X*("`@("`@("`@("`@("`@("`@("`@("`@("H@
M,BX@5')Y('1O(&9I;F0@82!S=')I;F<@87,@;&]N9R!A<R!?;6%X;&5N9W1H
M+@H@("`@("`@("`@("`@("`@("`@("`@("`@*B`S+B!486ME('1H92!F:7)S
M="!W;W)D+B`J+PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH
M)&U;,5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;5LQ72`]
M("1M6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&U;,ET@/2`G
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]U='!U=%M=(#T@87)R87DH)W1E>'0G(#T^("1M
M6S%=("X@)R`G("X@*"@D9&5L<W`I(#\@)R`G(#H@)R<I+"`G;&5V96PG(#T^
M("1N=6U?<75O=&5S*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&QI;F4@
M/2`D;5LR73L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`O*B!/;F4@97AC97-S:79E;'D@;&]N9R!W;W)D
M(&QE9G0@;VX@;&EN92X@($)E"B`@("`@("`@("`@("`@("`@("`@("`@("`J
M(&%B<V]L=71E;'D@<W5R92!I="!D;V5S(&YO="!E>&-E960@.3DX(&-H87)A
M8W1E<G,*("`@("`@("`@("`@("`@("`@("`@("`@("H@:6X@;&5N9W1H(&]R
M(&5L<V4@=V4@;75S="!T<G5N8V%T92X@*B\*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1L:6YE7VQE;F=T:"`^(#DY."D@>R`*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T<'5T6UT@/2!A<G)A>2@G=&5X
M="<@/3X@4W1R:6YG.CIS=6)S='(H)&QI;F4L(#`L(#DY."P@)'1H:7,M/E]C
M:&%R<V5T*2P@)VQE=F5L)R`]/B`D;G5M7W%U;W1E<RD["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;&EN92`](%-T<FEN9SHZ<W5B<W1R*"1L:6YE
M+"`Y.3@L(&YU;&PL("1T:&ES+3Y?8VAA<G-E="D["B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V]U='!U=%M=(#T@87)R87DH)W1E>'0G(#T^("1L:6YE+"`G
M;&5V96PG(#T^("1N=6U?<75O=&5S*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?2!W:&EL92`H(65M<'1Y*"1T97AT*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N=6UB97(@;V8@;&5A9&EN9R`G
M/B<@8VAA<F%C=&5R<R!I;B!T:&4@=&5X="!I;G!U="X*("`@("`J("<^)R!C
M:&%R86-T97)S(&%R92!D969I;F5D(&)Y(%)&0R`R-C0V('1O(&EN9&EC871E
M(&$@<75O=&5D(&QI;F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&5X="`@5&AE('1E>'0@
M=&\@86YA;'EZ92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!N=6UB97(@;V8@;&5A9&EN9R!Q=6]T92!C:&%R86-T97)S+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!?;G5M<75O=&5S*"1T97AT*0H@("`@>PH@("`@("`@
M(')E='5R;B!S=')S<&XH)'1E>'0L("<^)RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3<&%C92US='5F9G,@:68@:70@<W1A<G1S('=I=&@@)R`G(&]R("<^
M)R!O<B`G1G)O;2`G+"!O<B!I9@H@("`@("H@<75O=&4@9&5P=&@@:7,@;F]N
M+7IE<F\@*&9O<B!A97-T:&5T:6,@<F5A<V]N<R!S;R!T:&%T('1H97)E(&ES
M(&$*("`@("`J('-P86-E(&%F=&5R('1H92`G/B<I+@H@("`@("H*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'1E>'0@("`@("`@(%1H92!T97AT('1O('-T=69F+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;G5M7W%U;W1E<R`@5&AE('%U;W1E+6QE=F5L(&]F('1H:7,@
M;&EN92X*("`@("`J($!P87)A;2!B;V]L96%N("1T;V9L;W=E9"`@($%R92!W
M92!C;VYV97)T:6YG('1O(&9L;W=E9"!T97AT/PH@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!4:&4@<W1U9F9E9"!T97AT+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<W1U9F8H)'1E>'0L("1N=6U?<75O=&5S+"`D=&]F;&]W960I
M"B`@("!["B`@("`@("`@:68@*"1T;V9L;W=E9"`F)@H@("`@("`@("`@("`H
M)&YU;5]Q=6]T97,@?'P@<')E9U]M871C:"@B+UXH/SH@?#Y\1G)O;2!\1G)O
M;20I+R(L("1T97AT*2DI('L*("`@("`@("`@("`@<F5T=7)N("<@)R`N("1T
M97AT.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1E>'0["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!5;G-T=69F<R!A('-P86-E('-T=69F960@;&EN92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!T;R!U;G-T=69F+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=6YS='5F9F5D('1E>'0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%]U;G-T=69F*"1T97AT*0H@("`@>PH@
M("`@("`@(&EF("@A96UP='DH)'1E>'0I("8F("@D=&5X='LP?2`]/2`G("<I
M*2!["B`@("`@("`@("`@("1T97AT(#T@<W5B<W1R*"1T97AT+"`Q*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T97AT.PH@("`@?0H*?0H`````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I9F8S+G!H<```````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3(V,B`Q,#4Q
M-30S-#$S-B`P,C`W,#$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"G)E<75I<F5?;VYC92`G5&5X="]$:69F+G!H
M<"<["@HO*BH*("H@02!C;&%S<R!F;W(@8V]M<'5T:6YG('1H<F5E('=A>2!D
M:69F<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]$:69F+T1I9F8S
M+G!H<"QV(#$N,BXQ,"XS(#(P,#4O,3`O,3@@,3$Z,#$Z,S$@:F%N($5X<"`D
M"B`J"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T:&]R("!'96]F9G)E
M>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G/@H@*B\*8VQA<W,@
M5&5X=%]$:69F,R!E>'1E;F1S(%1E>'1?1&EF9B!["@H@("`@+RHJ"B`@("`@
M*B!#;VYF;&EC="!C;W5N=&5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E
M<@H@("`@("HO"B`@("!V87(@)%]C;VYF;&EC=&EN9T)L;V-K<R`](#`["@H@
M("`@+RHJ"B`@("`@*B!#;VUP=71E<R!D:69F(&)E='=E96X@,R!S97%U96YC
M97,@;V8@<W1R:6YG<RX*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&]R
M:6<@("`@5&AE(&]R:6=I;F%L(&QI;F5S('1O('5S92X*("`@("`J($!P87)A
M;2!A<G)A>2`D9FEN86PQ("!4:&4@9FER<W0@=F5R<VEO;B!T;R!C;VUP87)E
M('1O+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:6YA;#(@(%1H92!S96-O;F0@
M=F5R<VEO;B!T;R!C;VUP87)E('1O+@H@("`@("HO"B`@("!F=6YC=&EO;B!4
M97AT7T1I9F8S*"1O<FEG+"`D9FEN86PQ+"`D9FEN86PR*0H@("`@>PH@("`@
M("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*"=X9&EF9B<I*2!["B`@("`@("`@
M("`@("1E;F=I;F4@/2`F;F5W(%1E>'1?1&EF9E]%;F=I;F5?>&1I9F8H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D96YG:6YE(#T@)FYE=R!4
M97AT7T1I9F9?16YG:6YE7VYA=&EV92@I.PH@("`@("`@('T*"B`@("`@("`@
M)'1H:7,M/E]E9&ET<R`]("1T:&ES+3Y?9&EF9C,H)&5N9VEN92T^9&EF9B@D
M;W)I9RP@)&9I;F%L,2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5N9VEN92T^9&EF9B@D;W)I9RP@)&9I;F%L,BDI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&UE<F=E9$]U='!U="@D;&%B96PQ(#T@9F%L<V4L
M("1L86)E;#(@/2!F86QS92D*("`@('L*("`@("`@("`D;&EN97,@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?961I=',@87,@)&5D:70I
M('L*("`@("`@("`@("`@:68@*"1E9&ET+3YI<T-O;F9L:6-T*"DI('L*("`@
M("`@("`@("`@("`@("\J($9)6$U%.B!T:&ES('-H;W5L9"!P<F]B86)L>2!B
M92!M;W9E9"!S;VUE=VAE<F4@96QS92X@*B\*("`@("`@("`@("`@("`@("1L
M:6YE<R`](&%R<F%Y7VUE<F=E*"1L:6YE<RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<\/#P\/#P\)R`N("@D;&%B96PQ
M(#\@)R`G("X@)&QA8F5L,2`Z("<G*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D961I="T^9FEN86PQ+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH(CT]/3T]/3TB*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E9&ET+3YF:6YA
M;#(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G/CX^/CX^/B<@+B`H)&QA8F5L,B`_("<@)R`N("1L86)E;#(@.B`G)RDI
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N9FQI8W1I;F=";&]C:W,K
M*SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1L:6YE
M<R`](&%R<F%Y7VUE<F=E*"1L:6YE<RP@)&5D:70M/FUE<F=E9"@I*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1L:6YE<SL*
M("`@('T*"B`@("`O*BH*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9&EF9C,H)&5D:71S,2P@)&5D:71S,BD*("`@('L*
M("`@("`@("`D961I=',@/2!A<G)A>2@I.PH@("`@("`@("1B8B`]("9N97<@
M5&5X=%]$:69F,U]";&]C:T)U:6QD97(H*3L*"B`@("`@("`@)&4Q(#T@8W5R
M<F5N="@D961I=',Q*3L*("`@("`@("`D93(@/2!C=7)R96YT*"1E9&ET<S(I
M.PH@("`@("`@('=H:6QE("@D93$@?'P@)&4R*2!["B`@("`@("`@("`@(&EF
M("@D93$@)B8@)&4R("8F(&ES7V$H)&4Q+"`G5&5X=%]$:69F7T]P7V-O<'DG
M*2`F)B!I<U]A*"1E,BP@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@
M("`@("`@("`@("\J(%=E(&AA=F4@8V]P>2!B;&]C:W,@9G)O;2!B;W1H(&1I
M9F9S+B!4:&ES(&ES('1H92`H;VYL>2D*("`@("`@("`@("`@("`@("`J('1I
M;64@=V4@=V%N="!T;R!E;6ET(&$@9&EF9C,@8V]P>2!B;&]C:RX@($9L=7-H
M(&-U<G)E;G0*("`@("`@("`@("`@("`@("`J(&1I9F8S(&1I9F8@8FQO8VLL
M(&EF(&%N>2X@*B\*("`@("`@("`@("`@("`@(&EF("@D961I="`]("1B8BT^
M9FEN:7-H*"DI('L*("`@("`@("`@("`@("`@("`@("`D961I='-;72`]("1E
M9&ET.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1N8V]P
M>2`](&UI;B@D93$M/FYO<FEG*"DL("1E,BT^;F]R:6<H*2D["B`@("`@("`@
M("`@("`@("!A<W-E<G0H)&YC;W!Y(#X@,"D["B`@("`@("`@("`@("`@("`D
M961I='-;72`]("9N97<@5&5X=%]$:69F,U]/<%]C;W!Y*&%R<F%Y7W-L:6-E
M*"1E,2T^;W)I9RP@,"P@)&YC;W!Y*2D["@H@("`@("`@("`@("`@("`@:68@
M*"1E,2T^;F]R:6<H*2`^("1N8V]P>2D@>PH@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y7W-P;&EC92@D93$M/F]R:6<L(#`L("1N8V]P>2D["B`@("`@("`@
M("`@("`@("`@("`@87)R87E?<W!L:6-E*"1E,2T^9FEN86PL(#`L("1N8V]P
M>2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1E,2`](&YE>'0H)&5D:71S,2D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@:68@*"1E,BT^;F]R:6<H*2`^("1N8V]P>2D@>PH@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7W-P;&EC92@D93(M/F]R:6<L(#`L
M("1N8V]P>2D["B`@("`@("`@("`@("`@("`@("`@87)R87E?<W!L:6-E*"1E
M,BT^9FEN86PL(#`L("1N8V]P>2D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1E,B`](&YE>'0H)&5D:71S,BD["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("!I9B`H)&4Q("8F("1E,BD@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D93$M/F]R:6<@)B8@)&4R+3YO<FEG*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1N;W)I9R`](&UI;B@D93$M/FYO<FEG*"DL("1E,BT^;F]R
M:6<H*2D["B`@("`@("`@("`@("`@("`@("`@("`@("1O<FEG(#T@87)R87E?
M<W!L:6-E*"1E,2T^;W)I9RP@,"P@)&YO<FEG*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87E?<W!L:6-E*"1E,BT^;W)I9RP@,"P@)&YO<FEG*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&)B+3YI;G!U="@D;W)I9RD["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-?82@D93$L("=497AT7T1I9F9?3W!?8V]P>2<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1B8BT^;W5T,2AA<G)A>5]S<&QI8V4H)&4Q+3YF:6YA
M;"P@,"P@)&YO<FEG*2D["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?82@D93(L("=497AT7T1I9F9?3W!?8V]P
M>2<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1B8BT^;W5T,BAA<G)A
M>5]S<&QI8V4H)&4R+3YF:6YA;"P@,"P@)&YO<FEG*2D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M(&EF("@D93$@)B8@(2`D93$M/F]R:6<I('L*("`@("`@("`@("`@("`@("`@
M("`D8F(M/F]U=#$H)&4Q+3YF:6YA;"D["B`@("`@("`@("`@("`@("`@("`@
M)&4Q(#T@;F5X="@D961I=',Q*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("@D93(@)B8@(2`D93(M/F]R:6<I('L*("`@("`@("`@
M("`@("`@("`@("`D8F(M/F]U=#(H)&4R+3YF:6YA;"D["B`@("`@("`@("`@
M("`@("`@("`@)&4R(#T@;F5X="@D961I=',R*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1E9&ET
M(#T@)&)B+3YF:6YI<V@H*2D@>PH@("`@("`@("`@("`D961I='-;72`]("1E
M9&ET.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1E9&ET<SL*("`@('T*
M"GT*"B\J*@H@*B!`<&%C:V%G92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O
M9F9R97D@5"X@1&%I<FEK:2`\9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@
M0&%C8V5S<R!P<FEV871E"B`J+PIC;&%S<R!497AT7T1I9F8S7T]P('L*"B`@
M("!F=6YC=&EO;B!497AT7T1I9F8S7T]P*"1O<FEG(#T@9F%L<V4L("1F:6YA
M;#$@/2!F86QS92P@)&9I;F%L,B`](&9A;'-E*0H@("`@>PH@("`@("`@("1T
M:&ES+3YO<FEG(#T@)&]R:6<@/R`D;W)I9R`Z(&%R<F%Y*"D["B`@("`@("`@
M)'1H:7,M/F9I;F%L,2`]("1F:6YA;#$@/R`D9FEN86PQ(#H@87)R87DH*3L*
M("`@("`@("`D=&AI<RT^9FEN86PR(#T@)&9I;F%L,B`_("1F:6YA;#(@.B!A
M<G)A>2@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&UE<F=E9"@I"B`@("!["B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7VUE<F=E9"DI('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YF:6YA;#$@/3T]("1T:&ES+3YF:6YA;#(I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;65R9V5D(#T@)B1T:&ES+3YF:6YA;#$[
M"B`@("`@("`@("`@('T@96QS96EF("@D=&AI<RT^9FEN86PQ(#T]/2`D=&AI
M<RT^;W)I9RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97)G960@/2`F
M)'1H:7,M/F9I;F%L,CL*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YF
M:6YA;#(@/3T]("1T:&ES+3YO<FEG*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUE<F=E9"`]("8D=&AI<RT^9FEN86PQ.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97)G960@/2!F86QS93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;65R9V5D.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9FQI8W0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;65R9V5D*"D@/3T](&9A;'-E
M.PH@("`@?0H*?0H*+RHJ"B`J($!P86-K86=E(%1E>'1?1&EF9@H@*B!`875T
M:&]R("!'96]F9G)E>2!4+B!$86ER:6MI(#QD86ER:6MI0&1A:7)I:VDN;W)G
M/@H@*@H@*B!`86-C97-S('!R:79A=&4*("HO"F-L87-S(%1E>'1?1&EF9C-?
M3W!?8V]P>2!E>'1E;F1S(%1E>'1?1&EF9C-?3W`@>PH*("`@(&9U;F-T:6]N
M(%1E>'1?1&EF9C-?3W!?0V]P>2@D;&EN97,@/2!F86QS92D*("`@('L*("`@
M("`@("`D=&AI<RT^;W)I9R`]("1L:6YE<R`_("1L:6YE<R`Z(&%R<F%Y*"D[
M"B`@("`@("`@)'1H:7,M/F9I;F%L,2`]("8D=&AI<RT^;W)I9SL*("`@("`@
M("`D=&AI<RT^9FEN86PR(#T@)B1T:&ES+3YO<FEG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&UE<F=E9"@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YO
M<FEG.PH@("`@?0H*("`@(&9U;F-T:6]N(&ES0V]N9FQI8W0H*0H@("`@>PH@
M("`@("`@(')E='5R;B!F86QS93L*("`@('T*"GT*"B\J*@H@*B!`<&%C:V%G
M92!497AT7T1I9F8*("H@0&%U=&AO<B`@1V5O9F9R97D@5"X@1&%I<FEK:2`\
M9&%I<FEK:4!D86ER:6MI+F]R9SX*("H*("H@0&%C8V5S<R!P<FEV871E"B`J
M+PIC;&%S<R!497AT7T1I9F8S7T)L;V-K0G5I;&1E<B!["@H@("`@9G5N8W1I
M;VX@5&5X=%]$:69F,U]";&]C:T)U:6QD97(H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:6YI="@I.PH@("`@?0H*("`@(&9U;F-T:6]N(&EN<'5T*"1L:6YE
M<RD*("`@('L*("`@("`@("!I9B`H)&QI;F5S*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?87!P96YD*"1T:&ES+3YO<FEG+"`D;&EN97,I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!O=70Q*"1L:6YE<RD*("`@('L*("`@("`@
M("!I9B`H)&QI;F5S*2!["B`@("`@("`@("`@("1T:&ES+3Y?87!P96YD*"1T
M:&ES+3YF:6YA;#$L("1L:6YE<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U
M;F-T:6]N(&]U=#(H)&QI;F5S*0H@("`@>PH@("`@("`@(&EF("@D;&EN97,I
M('L*("`@("`@("`@("`@)'1H:7,M/E]A<'!E;F0H)'1H:7,M/F9I;F%L,BP@
M)&QI;F5S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@:7-%;7!T
M>2@I"B`@("!["B`@("`@("`@<F5T=7)N("$D=&AI<RT^;W)I9R`F)B`A)'1H
M:7,M/F9I;F%L,2`F)B`A)'1H:7,M/F9I;F%L,CL*("`@('T*"B`@("!F=6YC
M=&EO;B!F:6YI<V@H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^:7-%;7!T
M>2@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D961I="`]("9N97<@5&5X=%]$:69F,U]/<"@D
M=&AI<RT^;W)I9RP@)'1H:7,M/F9I;F%L,2P@)'1H:7,M/F9I;F%L,BD["B`@
M("`@("`@("`@("1T:&ES+3Y?:6YI="@I.PH@("`@("`@("`@("!R971U<FX@
M)&5D:70["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(%]I;FET*"D*
M("`@('L*("`@("`@("`D=&AI<RT^;W)I9R`]("1T:&ES+3YF:6YA;#$@/2`D
M=&AI<RT^9FEN86PR(#T@87)R87DH*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M87!P96YD*"8D87)R87DL("1L:6YE<RD*("`@('L*("`@("`@("!A<G)A>5]S
M<&QI8V4H)&%R<F%Y+"!S:7IE;V8H)&%R<F%Y*2P@,"P@)&QI;F5S*3L*("`@
M('T*"GT*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VQI8B]497AT+W)E4U0N<&AP````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-S$W,B`Q,#4Q-30S-#$S-B`P,C`V,C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J(%1H92!497AT7W)E4U0Z.B!C;&%S<R!R97!R97-E;G1S(&$@
M<&%R<V4@;F]D92!O9B!A(')E4W1R=6-T=7)E9%1E>'0*("H@9&]C=6UE;G0@
M86YD('!R;W9I9&5S(&%N($%022!F;W(@<&%R<VEN9R!R95-T<G5C='5R9614
M97AT(&1O8W5M96YT<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]R
M95-4+W)E4U0N<&AP+'8@,2XU+C$P+C<@,C`P-B\P,2\P,2`R,3HR.#HS."!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&
M96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*
M("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES
M+F-O;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!497AT7W)E
M4U0@>PH*("`@("\J*@H@("`@("H@5&AE('!A<G-E(&YO9&4@='EP92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!!;B!A
M<G)A>2!O9B!T:&4@<&%R<V4@;F]D92=S(&-H:6QD<F5N+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1?8VAI;&1R96X@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@02!H87-H(&]F('!A<G-E(&YO9&4@<')O<&5R=&EE<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1?<')O<&5R=&EE<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("!4:&ES(&ES('1H92!N;V1E('1Y<&4N("!4:&4@9&5F875L="!I
M<R`G1&]C=6UE;G0G+@H@("`@("HO"B`@("!F=6YC=&EO;B!497AT7W)E4U0H
M)'1Y<&4@/2`G1&]C=6UE;G0G*0H@("`@>PH@("`@("`@("1T:&ES+3Y?='EP
M92`]("1T>7!E.PH@("`@?0H*("`@("\J*@H@("`@("H@07!P96YD<R!A(&-H
M:6QD('!A<G-E(&YO9&4@=&\@=&AI<R!P87)S92!N;V1E+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F=\5&5X=%]R95-4("8D8VAI;&0@(%1H:7,@:7,@
M=&AE('-T<FEN9R!O<B!O8FIE8W0@8VAI;&0*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1O(&%P<&5N9"!T;R!T:&ES('!A<G-E
M(&YO9&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%P<&5N9$-H:6QD*"8D8VAI
M;&0I"B`@("!["B`@("`@("`@)&X@/2!C;W5N="@D=&AI<RT^7V-H:6QD<F5N
M*3L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1C:&EL9"D@)B8@)&X@/B`P("8F
M(&ES7W-T<FEN9R@D=&AI<RT^7V-H:6QD<F5N6R1N("T@,5TI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&X@+2`Q72`N/2`D8VAI;&0["B`@
M("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D8VAI;&0I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?8VAI;&1R96Y;72`]("1C:&EL9#L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V-H:6QD<F5N6UT@/2`F)&-H:6QD
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE('9A
M;'5E(&]F(&$@<&%R<V4@;F]D92!P<F]P97)T>2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1N86UE("`@5&AE('!R;W!E<G1Y)W,@;F%M92X*("`@
M("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!4:&4@<')O<&5R='DG<R!V86QU
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4')O<&5R='DH)&YA;64L("1V
M86QU92D*("`@('L*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)&YA;65=
M(#T@)'9A;'5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H
M92!V86QU92!O9B!A('!A<G-E(&YO9&4@<')O<&5R='DN"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;F%M92`@5&AE('!R;W!E<G1Y)W,@;F%M92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@5&AE('!R;W!E<G1Y)W,@
M=F%L=64N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R;W!E<G1Y*"1N86UE
M*0H@("`@>PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D;F%M92P@
M)'1H:7,M/E]P<F]P97)T:65S*2D@>PH@("`@("`@("`@("!R971U<FX@;G5L
M;#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<')O<&5R=&EE
M<ULD;F%M95T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!$=6UP<R!T:&ES('!A
M<G-E(&YO9&4@86YD(&ET<R!C:&EL9')E;BX*("`@("`J(%1H:7,@;65T:&]D
M(&ES(&9O<B!D96)U9V=I;F<@<'5R<&]S97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M(&EN=&5G97(@)&QE=F5L("!4:&ES(&ES('1H92!I;F1E;G0@;&5V96P@
M;V8@=&AI<R!P87)S92!N;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!D=6UP
M*"1L979E;"`](#`I"B`@("!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M)&QE=F5L.R`D:2LK*2!["B`@("`@("`@("`@(&5C:&\@)R`@)SL*("`@("`@
M("!]"B`@("`@("`@96-H;R`D=&AI<RT^7W1Y<&4L("<Z.B<["B`@("`@("`@
M:W-O<G0H)'1H:7,M/E]P<F]P97)T:65S*3L*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W!R;W!E<G1I97,@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@(&5C:&\@)R`G+"`D;F%M92P@)STB)RP@<')E9U]R97!L86-E*"<O
M6R)<7%Q<72\G+"`G7%PD,2<L("1V86QU92DL"B`@("`@("`@("`@("`@("`G
M(B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@(EQN(CL*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7V-H:6QD<F5N(&%S("1C:&EL9"D@>PH@("`@("`@("`@
M("!I9B`H:7-?<W1R:6YG*"1C:&EL9"DI('L*("`@("`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\("@D;&5V96P@*R`Q*3L@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@("`@(&5C:&\@)R`@)SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&5C:&\@)R(G+"!P<F5G7W)E<&QA8V4H)R];(EQ<7%Q=
M+R<L("=<7"0Q)RP@)&-H:6QD*2P@(EPB7&XB.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&-H:6QD+3YD=6UP*"1L979E;"`K(#$I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4&%R<V5S(&$@<F53=')U8W1U<F5D5&5X="!D;V-U;65N="X*("`@("`J
M"B`@("`@*B!`<W1A=&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&5X="`@5&AI<R!I<R!T:&4@=&5X="!O9B!T:&4@9&]C=6UE;G0@=V4@=V%N
M="!T;R!P87)S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535"`@
M5&AE('!A<G-E9"!D;V-U;65N="!O<B!014%27T5R<F]R(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9P87)S92@D=&5X="D*("`@('L*("`@
M("`@("!R97%U:7)E7V]N8V4@9&ER;F%M92A?7T9)3$5?7RD@+B`G+W)E4U0O
M4&%R<V5R+G!H<"<["B`@("`@("`@)'!A<G-E<B`]("9N97<@5&5X=%]R95-4
M7U!A<G-E<B@I.PH@("`@("`@(')E='5R;B`D<&%R<V5R+3YP87)S92@D=&5X
M="D["B`@("!]"@I]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+T1I9F8O4F5N9&5R97(`
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$S-B`P,C$U-C8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E
M>'0O1&EF9B]296YD97)E<BYP:'``````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$R-C,S(#$P-3$U-#,T,3,V(#`R,C,V,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M02!C;&%S<R!T;R!R96YD97(@1&EF9G,@:6X@9&EF9F5R96YT(&9O<FUA=',N
M"B`J"B`J(%1H:7,@8VQA<W,@<F5N9&5R<R!T:&4@9&EF9B!I;B!C;&%S<VEC
M(&1I9F8@9F]R;6%T+B!)="!I<R!I;G1E;F1E9"!T:&%T"B`J('1H:7,@8VQA
M<W,@8F4@8W5S=&]M:7IE9"!V:6$@:6YH97)I=&%N8V4L('1O(&]B=&%I;B!F
M86YC:65R(&]U='!U=',N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?
M1&EF9B]$:69F+U)E;F1E<F5R+G!H<"QV(#$N-2XQ,"XW(#(P,#4O,3(O,38@
M,3$Z-#0Z,#`@:F%N($5X<"`D"B`J"B`J($!P86-K86=E(%1E>'1?1&EF9@H@
M*B\*8VQA<W,@5&5X=%]$:69F7U)E;F1E<F5R('L*"B`@("`O*BH*("`@("`J
M($YU;6)E<B!O9B!L96%D:6YG(&-O;G1E>'0@(FQI;F5S(B!T;R!P<F5S97)V
M92X*("`@("`J"B`@("`@*B!4:&ES('-H;W5L9"!B92!L969T(&%T('IE<F\@
M9F]R('1H:7,@8VQA<W,L(&)U="!S=6)C;&%S<V5S(&UA>2!W86YT('1O"B`@
M("`@*B!S970@=&AI<R!T;R!O=&AE<B!V86QU97,N"B`@("`@*B\*("`@('9A
M<B`D7VQE861I;F=?8V]N=&5X=%]L:6YE<R`](#`["@H@("`@+RHJ"B`@("`@
M*B!.=6UB97(@;V8@=')A:6QI;F<@8V]N=&5X="`B;&EN97,B('1O('!R97-E
M<G9E+@H@("`@("H*("`@("`J(%1H:7,@<VAO=6QD(&)E(&QE9G0@870@>F5R
M;R!F;W(@=&AI<R!C;&%S<RP@8G5T('-U8F-L87-S97,@;6%Y('=A;G0@=&\*
M("`@("`J('-E="!T:&ES('1O(&]T:&5R('9A;'5E<RX*("`@("`J+PH@("`@
M=F%R("1?=')A:6QI;F=?8V]N=&5X=%]L:6YE<R`](#`["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]$
M:69F7U)E;F1E<F5R*"1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@
M(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`D=B`]("=?)R`N("1P87)A;3L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3XD=BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3XD=B`]
M("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($=E="!A;GD@<F5N9&5R97(@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!!;&P@<&%R86UE=&5R<R!O9B!T:&ES
M(')E;F1E<F5R(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4&%R
M86US*"D*("`@('L*("`@("`@("`D<&%R86US(#T@87)R87DH*3L*("`@("`@
M("!F;W)E86-H("AG971?;V)J96-T7W9A<G,H)'1H:7,I(&%S("1K(#T^("1V
M*2!["B`@("`@("`@("`@(&EF("@D:WLP?2`]/2`G7R<I('L*("`@("`@("`@
M("`@("`@("1P87)A;7-;<W5B<W1R*"1K+"`Q*5T@/2`D=CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1P87)A;7,["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!296YD97)S(&$@9&EF9BX*("`@("`J"B`@("`@
M*B!`<&%R86T@5&5X=%]$:69F("1D:69F("!!(%1E>'1?1&EF9B!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@(%1H92!F;W)M871T960@
M;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96YD97(H)&1I9F8I"B`@
M("!["B`@("`@("`@)'AI(#T@)'EI(#T@,3L*("`@("`@("`D8FQO8VL@/2!F
M86QS93L*("`@("`@("`D8V]N=&5X="`](&%R<F%Y*"D["@H@("`@("`@("1N
M;&5A9"`]("1T:&ES+3Y?;&5A9&EN9U]C;VYT97AT7VQI;F5S.PH@("`@("`@
M("1N=')A:6P@/2`D=&AI<RT^7W1R86EL:6YG7V-O;G1E>'1?;&EN97,["@H@
M("`@("`@("1O=71P=70@/2`D=&AI<RT^7W-T87)T1&EF9B@I.PH*("`@("`@
M("`D9&EF9G,@/2`D9&EF9BT^9V5T1&EF9B@I.PH@("`@("`@(&9O<F5A8V@@
M*"1D:69F<R!A<R`D:2`]/B`D961I="D@>PH@("`@("`@("`@("!I9B`H:7-?
M82@D961I="P@)U1E>'1?1&EF9E]/<%]C;W!Y)RDI('L*("`@("`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D8FQO8VLI*2!["B`@("`@("`@("`@("`@("`@
M("`@)&ME97`@/2`D:2`]/2!C;W5N="@D9&EF9G,I("T@,2`_("1N=')A:6P@
M.B`D;FQE860@*R`D;G1R86EL.PH@("`@("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D961I="T^;W)I9RD@/#T@)&ME97`I('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&)L;V-K6UT@/2`D961I=#L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&YT<F%I
M;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E>'0@/2!A
M<G)A>5]S;&EC92@D961I="T^;W)I9RP@,"P@)&YT<F%I;"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8FQO8VM;72`]("9N97<@5&5X=%]$:69F
M7T]P7V-O<'DH)&-O;G1E>'0I.PH@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/E]B
M;&]C:R@D>#`L("1N=')A:6P@*R`D>&D@+2`D>#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>3`L("1N=')A
M:6P@*R`D>6D@+2`D>3`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8FQO8VLI.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8FQO8VL@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8V]N=&5X="`]
M("1E9&ET+3YO<FEG.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D8FQO8VLI*2!["B`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E>'0@/2!A<G)A>5]S;&EC92@D8V]N=&5X="P@8V]U;G0H
M)&-O;G1E>'0I("T@)&YL96%D*3L*("`@("`@("`@("`@("`@("`@("`D>#`@
M/2`D>&D@+2!C;W5N="@D8V]N=&5X="D["B`@("`@("`@("`@("`@("`@("`@
M)'DP(#T@)'EI("T@8V]U;G0H)&-O;G1E>'0I.PH@("`@("`@("`@("`@("`@
M("`@("1B;&]C:R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1C;VYT97AT*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C:UM=
M(#T@)FYE=R!497AT7T1I9F9?3W!?8V]P>2@D8V]N=&5X="D["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)&)L;V-K6UT@/2`D961I=#L*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@:68@*"1E9&ET+3YO<FEG*2!["B`@("`@("`@("`@("`@("`D>&D@*ST@
M8V]U;G0H)&5D:70M/F]R:6<I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D961I="T^9FEN86PI('L*("`@("`@("`@("`@("`@("1Y:2`K/2!C
M;W5N="@D961I="T^9FEN86PI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-?87)R87DH)&)L;V-K*2D@>PH@("`@("`@("`@("`D
M;W5T<'5T("X]("1T:&ES+3Y?8FQO8VLH)'@P+"`D>&D@+2`D>#`L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>3`L("1Y:2`M("1Y
M,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1B;&]C
M:RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]U='!U="`N("1T:&ES
M+3Y?96YD1&EF9B@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B;&]C:R@D>&)E
M9RP@)'AL96XL("1Y8F5G+"`D>6QE;BP@)B1E9&ET<RD*("`@('L*("`@("`@
M("`D;W5T<'5T(#T@)'1H:7,M/E]S=&%R=$)L;V-K*"1T:&ES+3Y?8FQO8VM(
M96%D97(H)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI*3L*"B`@("`@("`@
M9F]R96%C:"`H)&5D:71S(&%S("1E9&ET*2!["B`@("`@("`@("`@('-W:71C
M:"`H<W1R=&]L;W=E<BAG971?8VQA<W,H)&5D:70I*2D@>PH@("`@("`@("`@
M("!C87-E("=T97AT7V1I9F9?;W!?8V]P>2<Z"B`@("`@("`@("`@("`@("`D
M;W5T<'5T("X]("1T:&ES+3Y?8V]N=&5X="@D961I="T^;W)I9RD["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W1E>'1?9&EF
M9E]O<%]A9&0G.@H@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^
M7V%D9&5D*"1E9&ET+3YF:6YA;"D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@(&-A<V4@)W1E>'1?9&EF9E]O<%]D96QE=&4G.@H@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^7V1E;&5T960H)&5D:70M
M/F]R:6<I.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=T97AT7V1I9F9?;W!?8VAA;F=E)SH*("`@("`@("`@("`@("`@("1O
M=71P=70@+CT@)'1H:7,M/E]C:&%N9V5D*"1E9&ET+3YO<FEG+"`D961I="T^
M9FEN86PI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;W5T<'5T("X@)'1H:7,M/E]E
M;F1";&]C:R@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]S=&%R=$1I9F8H*0H@
M("`@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*"B`@("!F=6YC=&EO;B!?
M96YD1&EF9B@I"B`@("!["B`@("`@("`@<F5T=7)N("<G.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]B;&]C:TAE861E<B@D>&)E9RP@)'AL96XL("1Y8F5G+"`D
M>6QE;BD*("`@('L*("`@("`@("!I9B`H)'AL96X@/B`Q*2!["B`@("`@("`@
M("`@("1X8F5G("X]("<L)R`N("@D>&)E9R`K("1X;&5N("T@,2D["B`@("`@
M("`@?0H@("`@("`@(&EF("@D>6QE;B`^(#$I('L*("`@("`@("`@("`@)'EB
M96<@+CT@)RPG("X@*"1Y8F5G("L@)'EL96X@+2`Q*3L*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D>&)E9R`N("@D>&QE;B`_("@D>6QE;B`_("=C)R`Z
M("=D)RD@.B`G82<I("X@)'EB96<["B`@("!]"@H@("`@9G5N8W1I;VX@7W-T
M87)T0FQO8VLH)&AE861E<BD*("`@('L*("`@("`@("!R971U<FX@)&AE861E
M<B`N(")<;B(["B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9$)L;V-K*"D*("`@
M('L*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@9G5N8W1I;VX@7VQI
M;F5S*"1L:6YE<RP@)'!R969I>"`]("<@)RD*("`@('L*("`@("`@("!R971U
M<FX@)'!R969I>"`N(&EM<&QO9&4H(EQN)'!R969I>"(L("1L:6YE<RD@+B`B
M7&XB.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C;VYT97AT*"1L:6YE<RD*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D;&EN97,I.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]A9&1E9"@D;&EN97,I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?;&EN97,H)&QI;F5S+"`G/B<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]D96QE=&5D*"1L:6YE<RD*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]L:6YE<R@D;&EN97,L("<\)RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@7V-H86YG960H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]D96QE=&5D*"1O<FEG*2`N("(M+2U<;B(@+B`D=&AI
M<RT^7V%D9&5D*"1F:6YA;"D["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O1&EF9B]296YD97)E<B]I;FQI
M;F4N<&AP````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-#4U(#$P-3$U
M-#,T,3,V(#`R,S8T,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=497AT+T1I9F8O4F5N
M9&5R97(N<&AP)SL*"B\J*@H@*B`B26YL:6YE(B!D:69F(')E;F1E<F5R+@H@
M*@H@*B!4:&ES(&-L87-S(')E;F1E<G,@9&EF9G,@:6X@=&AE(%=I:VDM<W1Y
M;&4@(FEN;&EN92(@9F]R;6%T+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]4
M97AT7T1I9F8O1&EF9B]296YD97)E<B]I;FQI;F4N<&AP+'8@,2XT+C$P+C$Q
M(#(P,#8O,#8O,38@,30Z,#@Z,34@8VAU8VL@17AP("0*("H*("H@0&%U=&AO
M<B`@0VEP<FEA;B!0;W!O=FEC:0H@*B!`<&%C:V%G92!497AT7T1I9F8*("HO
M"F-L87-S(%1E>'1?1&EF9E]296YD97)E<E]I;FQI;F4@97AT96YD<R!497AT
M7T1I9F9?4F5N9&5R97(@>PH*("`@("\J*@H@("`@("H@3G5M8F5R(&]F(&QE
M861I;F<@8V]N=&5X="`B;&EN97,B('1O('!R97-E<G9E+@H@("`@("HO"B`@
M("!V87(@)%]L96%D:6YG7V-O;G1E>'1?;&EN97,@/2`Q,#`P,#L*"B`@("`O
M*BH*("`@("`J($YU;6)E<B!O9B!T<F%I;&EN9R!C;VYT97AT(")L:6YE<R(@
M=&\@<')E<V5R=F4N"B`@("`@*B\*("`@('9A<B`D7W1R86EL:6YG7V-O;G1E
M>'1?;&EN97,@/2`Q,#`P,#L*"B`@("`O*BH*("`@("`J(%!R969I>"!F;W(@
M:6YS97)T960@=&5X="X*("`@("`J+PH@("`@=F%R("1?:6YS7W!R969I>"`]
M("<\:6YS/B<["@H@("`@+RHJ"B`@("`@*B!3=69F:7@@9F]R(&EN<V5R=&5D
M('1E>'0N"B`@("`@*B\*("`@('9A<B`D7VEN<U]S=69F:7@@/2`G/"]I;G,^
M)SL*"B`@("`O*BH*("`@("`J(%!R969I>"!F;W(@9&5L971E9"!T97AT+@H@
M("`@("HO"B`@("!V87(@)%]D96Q?<')E9FEX(#T@)SQD96P^)SL*"B`@("`O
M*BH*("`@("`J(%-U9F9I>"!F;W(@9&5L971E9"!T97AT+@H@("`@("HO"B`@
M("!V87(@)%]D96Q?<W5F9FEX(#T@)SPO9&5L/B<["@H@("`@+RHJ"B`@("`@
M*B!(96%D97(@9F]R(&5A8V@@8VAA;F=E(&)L;V-K+@H@("`@("HO"B`@("!V
M87(@)%]B;&]C:U]H96%D97(@/2`G)SL*"B`@("`O*BH*("`@("`J(%=H870@
M87)E('=E(&-U<G)E;G1L>2!S<&QI='1I;F<@;VX_(%5S960@=&\@<F5C=7)S
M92!T;R!S:&]W('=O<F0M;&5V96P*("`@("`J(&-H86YG97,N"B`@("`@*B\*
M("`@('9A<B`D7W-P;&ET7VQE=F5L(#T@)VQI;F5S)SL*"B`@("!F=6YC=&EO
M;B!?8FQO8VM(96%D97(H)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8FQO8VM?:&5A9&5R.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]S=&%R=$)L;V-K*"1H96%D97(I"B`@("!["B`@
M("`@("`@<F5T=7)N("1H96%D97(["B`@("!]"@H@("`@9G5N8W1I;VX@7VQI
M;F5S*"1L:6YE<RP@)'!R969I>"`]("<@)RP@)&5N8V]D92`]('1R=64I"B`@
M("!["B`@("`@("`@:68@*"1E;F-O9&4I('L*("`@("`@("`@("`@87)R87E?
M=V%L:R@D;&EN97,L(&%R<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/E]S<&QI=%]L979E;"`]/2`G=V]R
M9',G*2!["B`@("`@("`@("`@(')E='5R;B!I;7!L;V1E*"<G+"`D;&EN97,I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!I;7!L;V1E
M*")<;B(L("1L:6YE<RD@+B`B7&XB.PH@("`@("`@('T*("`@('T*"B`@("!F
M=6YC=&EO;B!?861D960H)&QI;F5S*0H@("`@>PH@("`@("`@(&%R<F%Y7W=A
M;&LH)&QI;F5S+"!A<G)A>2@F)'1H:7,L("=?96YC;V1E)RDI.PH@("`@("`@
M("1L:6YE<ULP72`]("1T:&ES+3Y?:6YS7W!R969I>"`N("1L:6YE<ULP73L*
M("`@("`@("`D;&EN97-;8V]U;G0H)&QI;F5S*2`M(#%=("X]("1T:&ES+3Y?
M:6YS7W-U9F9I>#L*("`@("`@("!R971U<FX@)'1H:7,M/E]L:6YE<R@D;&EN
M97,L("<@)RP@9F%L<V4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]D96QE=&5D
M*"1L:6YE<RP@)'=O<F1S(#T@9F%L<V4I"B`@("!["B`@("`@("`@87)R87E?
M=V%L:R@D;&EN97,L(&%R<F%Y*"8D=&AI<RP@)U]E;F-O9&4G*2D["B`@("`@
M("`@)&QI;F5S6S!=(#T@)'1H:7,M/E]D96Q?<')E9FEX("X@)&QI;F5S6S!=
M.PH@("`@("`@("1L:6YE<UMC;W5N="@D;&EN97,I("T@,5T@+CT@)'1H:7,M
M/E]D96Q?<W5F9FEX.PH@("`@("`@(')E='5R;B`D=&AI<RT^7VQI;F5S*"1L
M:6YE<RP@)R`G+"!F86QS92D["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H86YG
M960H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@("`O*B!)9B!W92=V92!A
M;')E861Y('-P;&ET(&]N('=O<F1S+"!D;VXG="!T<GD@=&\@9&\@<V\@86=A
M:6X@+2!J=7-T"B`@("`@("`@("H@9&ES<&QA>2X@*B\*("`@("`@("!I9B`H
M)'1H:7,M/E]S<&QI=%]L979E;"`]/2`G=V]R9',G*2!["B`@("`@("`@("`@
M("1P<F5F:7@@/2`G)SL*("`@("`@("`@("`@=VAI;&4@*"1O<FEG6S!=("$]
M/2!F86QS92`F)B`D9FEN86Q;,%T@(3T](&9A;'-E("8F"B`@("`@("`@("`@
M("`@("`@("!S=6)S='(H)&]R:6=;,%TL(#`L(#$I(#T]("<@)R`F)@H@("`@
M("`@("`@("`@("`@("`@<W5B<W1R*"1F:6YA;%LP72P@,"P@,2D@/3T@)R`G
M*2!["B`@("`@("`@("`@("`@("`D<')E9FEX("X]('-U8G-T<B@D;W)I9ULP
M72P@,"P@,2D["B`@("`@("`@("`@("`@("`D;W)I9ULP72`]('-U8G-T<B@D
M;W)I9ULP72P@,2D["B`@("`@("`@("`@("`@("`D9FEN86Q;,%T@/2!S=6)S
M='(H)&9I;F%L6S!=+"`Q*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)'!R969I>"`N("1T:&ES+3Y?9&5L971E9"@D;W)I9RD@+B`D=&AI
M<RT^7V%D9&5D*"1F:6YA;"D["B`@("`@("`@?0H*("`@("`@("`D=&5X=#$@
M/2!I;7!L;V1E*")<;B(L("1O<FEG*3L*("`@("`@("`D=&5X=#(@/2!I;7!L
M;V1E*")<;B(L("1F:6YA;"D["@H@("`@("`@("\J($YO;BUP<FEN=&EN9R!N
M97=L:6YE(&UA<FME<BX@*B\*("`@("`@("`D;FP@/2`B7#`B.PH*("`@("`@
M("`O*B!792!W86YT('1O('-P;&ET(&]N('=O<F0@8F]U;F1A<FEE<RP@8G5T
M('=E(&YE960@=&\*("`@("`@("`@*B!P<F5S97)V92!W:&ET97-P86-E(&%S
M('=E;&PN(%1H97)E9F]R92!W92!S<&QI="!O;B!W;W)D<RP*("`@("`@("`@
M*B!B=70@:6YC;'5D92!A;&P@8FQO8VMS(&]F('=H:71E<W!A8V4@:6X@=&AE
M('=O<F1L:7-T+B`J+PH@("`@("`@("1D:69F(#T@)FYE=R!497AT7T1I9F8H
M)'1H:7,M/E]S<&QI=$]N5V]R9',H)'1E>'0Q+"`D;FPI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S<&QI=$]N5V]R9',H)'1E
M>'0R+"`D;FPI*3L*"B`@("`@("`@+RH@1V5T('1H92!D:69F(&EN(&EN;&EN
M92!F;W)M870N("HO"B`@("`@("`@)')E;F1E<F5R(#T@)FYE=R!497AT7T1I
M9F9?4F5N9&5R97)?:6YL:6YE*&%R<F%Y7VUE<F=E*"1T:&ES+3YG971087)A
M;7,H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)W-P;&ET7VQE=F5L)R`]
M/B`G=V]R9',G*2DI.PH*("`@("`@("`O*B!2=6X@=&AE(&1I9F8@86YD(&=E
M="!T:&4@;W5T<'5T+B`J+PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@D
M;FPL(")<;B(L("1R96YD97)E<BT^<F5N9&5R*"1D:69F*2D@+B`B7&XB.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]S<&QI=$]N5V]R9',H)'-T<FEN9RP@)&YE
M=VQI;F5%<V-A<&4@/2`B7&XB*0H@("`@>PH@("`@("`@("\O($EG;F]R92!<
M,#L@;W1H97)W:7-E('1H92!W:&EL92!L;V]P('=I;&P@;F5V97(@9FEN:7-H
M+@H@("`@("`@("1S=')I;F<@/2!S=')?<F5P;&%C92@B7#`B+"`G)RP@)'-T
M<FEN9RD["@H@("`@("`@("1W;W)D<R`](&%R<F%Y*"D["B`@("`@("`@)&QE
M;F=T:"`]('-T<FQE;B@D<W1R:6YG*3L*("`@("`@("`D<&]S(#T@,#L*"B`@
M("`@("`@=VAI;&4@*"1P;W,@/"`D;&5N9W1H*2!["B`@("`@("`@("`@("\O
M($5A="!A('=O<F0@=VET:"!A;GD@<')E8V5D:6YG('=H:71E<W!A8V4N"B`@
M("`@("`@("`@("1S<&%C97,@/2!S=')S<&XH<W5B<W1R*"1S=')I;F<L("1P
M;W,I+"`B(%QN(BD["B`@("`@("`@("`@("1N97AT<&]S(#T@<W1R8W-P;BAS
M=6)S='(H)'-T<FEN9RP@)'!O<R`K("1S<&%C97,I+"`B(%QN(BD["B`@("`@
M("`@("`@("1W;W)D<UM=(#T@<W1R7W)E<&QA8V4H(EQN(BP@)&YE=VQI;F5%
M<V-A<&4L('-U8G-T<B@D<W1R:6YG+"`D<&]S+"`D<W!A8V5S("L@)&YE>'1P
M;W,I*3L*("`@("`@("`@("`@)'!O<R`K/2`D<W!A8V5S("L@)&YE>'1P;W,[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'=O<F1S.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]E;F-O9&4H)B1S=')I;F<I"B`@("!["B`@("`@("`@)'-T
M<FEN9R`](&AT;6QS<&5C:6%L8VAA<G,H)'-T<FEN9RD["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O5&5X="]$:69F+U)E;F1E<F5R+W5N:69I960N<&AP````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#`@,3`U,34T,S0Q,S8@,#(S
M-S<R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@IR97%U:7)E7V]N8V4@)U1E>'0O1&EF9B]296YD97)E<BYP:'`G
M.PH*+RHJ"B`J(")5;FEF:65D(B!D:69F(')E;F1E<F5R+@H@*@H@*B!4:&ES
M(&-L87-S(')E;F1E<G,@=&AE(&1I9F8@:6X@8VQA<W-I8R`B=6YI9FEE9"!D
M:69F(B!F;W)M870N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U1E>'1?1&EF
M9B]$:69F+U)E;F1E<F5R+W5N:69I960N<&AP+'8@,2XS+C$P+C,@,C`P-B\P
M,2\P."`P,3HS-SHR,"!J86X@17AP("0*("H*("H@0'!A8VMA9V4@5&5X=%]$
M:69F"B`J+PIC;&%S<R!497AT7T1I9F9?4F5N9&5R97)?=6YI9FEE9"!E>'1E
M;F1S(%1E>'1?1&EF9E]296YD97)E<B!["@H@("`@+RHJ"B`@("`@*B!.=6UB
M97(@;V8@;&5A9&EN9R!C;VYT97AT(")L:6YE<R(@=&\@<')E<V5R=F4N"B`@
M("`@*B\*("`@('9A<B`D7VQE861I;F=?8V]N=&5X=%]L:6YE<R`](#0["@H@
M("`@+RHJ"B`@("`@*B!.=6UB97(@;V8@=')A:6QI;F<@8V]N=&5X="`B;&EN
M97,B('1O('!R97-E<G9E+@H@("`@("HO"B`@("!V87(@)%]T<F%I;&EN9U]C
M;VYT97AT7VQI;F5S(#T@-#L*"B`@("!F=6YC=&EO;B!?8FQO8VM(96%D97(H
M)'AB96<L("1X;&5N+"`D>6)E9RP@)'EL96XI"B`@("!["B`@("`@("`@:68@
M*"1X;&5N("$](#$I('L*("`@("`@("`@("`@)'AB96<@+CT@)RPG("X@)'AL
M96X["B`@("`@("`@?0H@("`@("`@(&EF("@D>6QE;B`A/2`Q*2!["B`@("`@
M("`@("`@("1Y8F5G("X]("<L)R`N("1Y;&5N.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@(D!`("TD>&)E9R`K)'EB96<@0$`B.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]A9&1E9"@D;&EN97,I"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?;&EN97,H)&QI;F5S+"`G*R<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(%]D96QE=&5D*"1L:6YE<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]L:6YE<R@D;&EN97,L("<M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V-H
M86YG960H)&]R:6<L("1F:6YA;"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]D96QE=&5D*"1O<FEG*2`N("1T:&ES+3Y?861D960H)&9I;F%L*3L*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O
M1F]R;6%T=&5R````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S-B`P,C$W-S``(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+U1E>'0O<F535"]087)S97(N<&AP````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#8Q-S0P(#$P-3$U-#,T,3,V(#`R,C`V,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE(%1E>'1?<F535%]087)S97(Z.B!C;&%S<R!I;7!L96UE
M;G1S(&$@<&%R<V5R(&9O<B!R95-T<G5C='5R961497AT"B`J(&1O8W5M96YT
M<RX*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]R95-4+W)E4U0O4&%R
M<V5R+G!H<"QV(#$N."XR+C@@,C`P-B\P,2\P,2`R,3HR.#HS.2!J86X@17AP
M("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI8V4@
M/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@0&%U
M=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O;3X*
M("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!497AT7W)E4U1?4&%R
M<V5R('L*"B`@("`O*BH*("`@("`J(%1H92!P87)S92!T<F5E+@H@("`@("H*
M("`@("`J($!V87(@5&5X=%]R95-4"B`@("`@*B\*("`@('9A<B`D7V1O8W5M
M96YT.PH*("`@("\J*@H@("`@("H@02!H87-H(&]F(&%D;W)N;65N="!L979E
M;',N"B`@("`@*@H@("`@("H@5&AE(&ME>7,@87)E(&]N92UC:&%R86-T97(@
M;W(@='=O+6-H87)A8W1E<B!S=')I;F=S+B`@5&AE(&]N92UC:&%R86-T97(*
M("`@("`J('-T<FEN9W,@<F5P<F5S96YT('5N9&5R;&EN92!A9&]R;FUE;G1S
M(&]F('1H92!S<&5C:69I960@8VAA<F%C=&5R+"!A;F0*("`@("`J('1H92!D
M;W5B;&4M8VAA<F%C=&5R(&ME>7,@87)E('1H92!U;F1E<FQI;F4M86YD+6]V
M97)L:6YE('-T>6QE<RX@(%1H90H@("`@("H@=F%L=65S(&%S<V]C:6%T960@
M=VET:"!T:&4@:V5Y<R!A<F4@:6YT96=E<G,@<F5P<F5S96YT:6YG('1H90H@
M("`@("H@861O<FYM96YT)W,@:&5A9&EN9R!L979E;"X*("`@("`J"B`@("`@
M*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V%D;W)N;65N=$QE=F5L
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@5&5X=%]R95-47U!A<G-E<B@I"B`@("!["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<&%R<V4@=')E92!R97!R
M97-E;G1I;F<@82!D;V-U;65N="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1T97AT("!4:&ES(&ES('1H92!T97AT(&]F('1H92!D;V-U;65N="!T
M;R!P87)S92X*("`@("`J"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535"`@5&AE
M('!A<G-E('1R964N"B`@("`@*B\*("`@(&9U;F-T:6]N("9P87)S92@D=&5X
M="D*("`@('L*("`@("`@("`D=&AI<RT^7W1E>'0@/2`D=&5X=#L*"B`@("`@
M("`@<F5Q=6ER95]O;F-E(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B]R95-4
M+G!H<"<["@H@("`@("`@("1T:&ES+3Y?9&]C=6UE;G0@/2`F;F5W(%1E>'1?
M<F535"@G1&]C=6UE;G0G*3L*("`@("`@("`D=&AI<RT^7W!U<VA3=&%T92@D
M=&AI<RT^7V1O8W5M96YT+"`G4V5C=&EO;B<L(#`I.PH*("`@("`@("!W:&EL
M92`H)'1H:7,M/E]N97AT*"DI('L*"B`@("`@("`@("`@("\O"B`@("`@("`@
M("`@("\O(%!A<G-E(&$@8"XN)R!D:7)E8W1I=F4N("!792!R97=R:71E(&%N
M(&!?7R<@9&ER96-T:79E('1O(&$*("`@("`@("`@("`@+R\@8"XN(%]?.B`G
M(&1I<F5C=&EV92!H97)E+@H@("`@("`@("`@("`O+PH@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@G+UXH7"Y<+GQ?7RE<<RLH+BH_*5QS*B0O)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6S!=
M+"`D;2DI('L*("`@("`@("`@("`@("`@(&EF("@D;5LQ72`]/2`G7U\G*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2`G7U\Z("<@+B`D;5LR73L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('=H:6QE("@D=&AI<RT^7V5N<W5R94QI;F5S*#(I("8F"B`@("`@("`@
M("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UX@("A;7EQS72XJ/RE<<RHD
M+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQI;F5"=69F97);,5TL("1M*2D@>PH@("`@("`@("`@("`@("`@("`@("1T
M97AT("X]("<@)RXD;5LQ73L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VYE>'0H*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%R<V5$:7)E8W1I=F4H)'1E>'0I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O"B`@("`@
M("`@("`@("\O($QO;VL@9F]R(&]V97)L:6YE+6%N9"UU;F1E<FQI;F4@:&5A
M9&EN9W,N"B`@("`@("`@("`@("\O"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M7V5N<W5R94QI;F5S*#,I("8F"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H
M*"<O7B@N*S\I7',J)"\G+"`D=&AI<RT^7VQI;F5"=69F97);,5TL("1L:6YE
M36%T8V@I("8F"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-H96-K061O<FYM
M96YT*&%R<F%Y*#`L(#(I+"!S=')L96XH)&QI;F5-871C:%LQ72DI*2!["@H@
M("`@("`@("`@("`@("`@)&%D;W)N;65N=%1Y<&4@/2`D=&AI<RT^7VQI;F5"
M=69F97);,%U[,'T["B`@("`@("`@("`@("`@("`D861O<FYM96YT5'EP92`N
M/2`D861O<FYM96YT5'EP93L*"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYE
M>'0H*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5X="@I.PH*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V%D;W)N;65N=$QE=F5L<ULD
M861O<FYM96YT5'EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@)&YE=TQE
M=F5L(#T@)'1H:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N;65N=%1Y<&5=
M.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&]P5&],979E;"@G4V5C
M=&EO;B<L("1N97=,979E;"`M(#$I.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D;F5W3&5V96P@/2`D=&AI<RT^7V=E
M=%-T871E3&5V96PH)U-E8W1I;VXG*2`K(#$["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A9&]R;FUE;G1,979E;'-;)&%D;W)N;65N=%1Y<&5=(#T@
M)&YE=TQE=F5L.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)&YO9&4@/2`F)'1H:7,M/E]M86ME3F]D92@D=&AI<RT^7V-U<G)E;G1.;V1E
M+"`G4V5C=&EO;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=L979E;"<@/3X@)&YE=TQE=F5L*2D["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!U<VA3=&%T92@D;F]D92P@)U-E8W1I;VXG
M+"`D;F5W3&5V96PI.PH@("`@("`@("`@("`@("`@<')E9U]M871C:"@G+UY<
M<RHH+BH_*5QS*B0O)RP@)&QI;F5-871C:%LQ72P@)&QI;F5-871C:"D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VUA:V5.;V1E*"1T:&ES+3Y?8W5R<F5N
M=$YO9&4L("=(96%D:6YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)VQE=F5L)R`]/B`D;F5W3&5V96PI+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;&EN94UA=&-H6S%=*3L*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`O+PH@("`@("`@("`@("`O+R!,;V]K(&9O<B!U;F1E<FQI;F4@:&5A9&EN
M9W,N"B`@("`@("`@("`@("\O"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V5N
M<W5R94QI;F5S*#(I("8F"B`@("`@("`@("`@("`@("!P<F5G7VUA=&-H*"<O
M7BA;7EQS72XJ/RE<<RHD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&EN94)U9F9E<ELP72P@)&QI;F5-871C:"D@)B8*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAE8VM!9&]R;FUE;G0H87)R87DH,2DL('-T
M<FQE;B@D;&EN94UA=&-H6S%=*2DI('L*"B`@("`@("`@("`@("`@("`D861O
M<FYM96YT5'EP92`]("1T:&ES+3Y?;&EN94)U9F9E<ELQ77LP?3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?;F5X="@I.PH@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?861O<FYM96YT3&5V96QS6R1A9&]R;FUE;G14>7!E
M72DI('L*("`@("`@("`@("`@("`@("`@("`D;F5W3&5V96P@/2`D=&AI<RT^
M7V%D;W)N;65N=$QE=F5L<ULD861O<FYM96YT5'EP95T["B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P;W!4;TQE=F5L*"=396-T:6]N)RP@)&YE=TQE
M=F5L("T@,2D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1N97=,979E;"`]("1T:&ES+3Y?9V5T4W1A=&5,979E;"@G
M4V5C=&EO;B<I("L@,3L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M;W)N;65N=$QE=F5L<ULD861O<FYM96YT5'EP95T@/2`D;F5W3&5V96P["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;F]D92`]("8D=&AI
M<RT^7VUA:V5.;V1E*"1T:&ES+3Y?8W5R<F5N=$YO9&4L("=396-T:6]N)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VQE=F5L)R`]/B`D;F5W3&5V96PI*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<'5S:%-T871E*"1N;V1E+"`G4V5C=&EO;B<L("1N97=,979E;"D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUA:V5.;V1E*"1T:&ES+3Y?8W5R
M<F5N=$YO9&4L("=(96%D:6YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)VQE=F5L)R`]/B`D;F5W3&5V96PI+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;&EN94UA=&-H6S%=*3L*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+PH@("`@("`@("`@("`O+R!087)S92!A(&`Z.B<@<&%R86=R87!H
M+@H@("`@("`@("`@("`O+PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G
M+UY<<RHZ.EQS*B0O)RP@)'1H:7,M/E]L:6YE0G5F9F5R6S!=*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]N97AT*"D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!A<G-E3&ET97)A;$)L;V-K*"D["B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\*("`@("`@
M("`@("`@+R\@4&%R<V4@82!P87)A9W)A<&@N("!792!E;F0@=&AE('!A<F%G
M<F%P:"!W:&5N('=E(')E='5R;B!T;PH@("`@("`@("`@("`O+R!A(&QO=V5R
M(&EN9&5N=&%T:6]N(&QE=F5L(&]R(&5N8V]U;G1E<B!A(&)L86YK(&QI;F4N
M"B`@("`@("`@("`@("\O"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7BA<<RHI*%M>7'-=+BH_*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6S!=+"`D;2DI('L*("`@("`@("`@
M("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@("`@("`D;&5V96P@
M/2!S=')L96XH)&U;,5TI.PH@("`@("`@("`@("`@("`@=VAI;&4@*"1T:&ES
M+3Y?96YS=7)E3&EN97,H,BD@)B8*("`@("`@("`@("`@("`@("`@("`@("!P
M<F5G7VUA=&-H*"<O7BA<<RHI*%M>7'-=+BH_*5QS*B0O)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;&EN94)U9F9E<ELQ
M72P@)&TI*2!["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D;5LQ
M72D@/"`D;&5V96PI('L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T
M97AT("X]("<@)R`N("1M6S)=.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;F5X="@I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1T<F%I;&EN9TQI=&5R86P@/2!F86QS93L*("`@("`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7B@N*EM>7'-=.BDZ7',J)"\G+"`D=&5X="P@)&TI
M*2!["B`@("`@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LQ73L*("`@("`@
M("`@("`@("`@("`@("`D=')A:6QI;F=,:71E<F%L(#T@=')U93L*("`@("`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7B@N*C\I7',J.CI<
M<RHD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("`@("`D=&5X
M="`]("1M6S%=.PH@("`@("`@("`@("`@("`@("`@("1T<F%I;&EN9TQI=&5R
M86P@/2!T<G5E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;6%K94YO9&4H)'1H:7,M/E]C=7)R96YT3F]D92P@)U!A<F%G
M<F%P:"<L(&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T97AT*3L*"B`@("`@("`@("`@("`@("!I9B`H)'1R86EL:6YG3&ET
M97)A;"D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;F5X="@I.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5,:71E<F%L0FQO8VLH
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!86%@Z($AA;F1L92!G
M87)B86=E(&QI;F4N"@H@("`@("`@('T["@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1O8W5M96YT.PH@("`@?0H*("`@(&9U;F-T:6]N("9?;6%K94YO9&4H
M)B1P87)E;G0L("1T>7!E+"`D<')O<',@/2!A<G)A>2@I+"`D8VAI;&1497AT
M(#T@;G5L;"D*("`@('L*("`@("`@("`D;F]D92`]("9N97<@5&5X=%]R95-4
M*"1T>7!E*3L*("`@("`@("!F;W)E86-H("@D<')O<',@87,@)&YA;64@/3X@
M)'9A;'5E*2!["B`@("`@("`@("`@("1N;V1E+3YS9710<F]P97)T>2@D;F%M
M92P@)'9A;'5E*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL*"1P
M87)E;G0I*2!["B`@("`@("`@("`@("1P87)E;G0M/F%P<&5N9$-H:6QD*"1N
M;V1E*3L*("`@("`@("!]"B`@("`@("`@:68@*"%I<U]N=6QL*"1C:&EL9%1E
M>'0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5);FQI;F4H)&YO9&4L
M("1C:&EL9%1E>'0I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&YO9&4[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:W,@;75L=&EP;&4@861O<FYE
M;6YT(&QI;F5S(&EN('1H92!L:6YE(&)U9F9E<B!A;F0@;6%K97,@<W5R92!T
M:&5Y"B`@("`@*B!A<F4@861O<FYM96YT<R!A;F0@=&AA="!A;&P@87)E(&ED
M96YT:6-A;"!A9&]R;FUE;G1S+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I
M=F%T90H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D;&EN97,@("`@("`@
M($%N(&%R<F%Y(&]F(&QI;F4@;G5M8F5R<R!T;R!C:&5C:R!I9B!T:&5Y(&%R
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@861O<FYM96YT
M<RX*("`@("`J($!P87)A;2!I;G1E9V5R("1M:6Y,96YG=&@@(%1H92!M:6YI
M;75M(&QE;F=T:"!F;W(@=&AI<R!A9&]R;FUE;G0N("!4:&4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0@:7,@,2X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H97(@=&AI<R!L:6YE(&ES
M(&%N(&%D;W)N;65N="!W:&EC:"!M871C:&5S('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("!A8F]V92!C<FET97)I82X*("`@("`J+PH@("`@9G5N8W1I
M;VX@7V-H96-K061O<FYM96YT*"1L:6YE<R`](&%R<F%Y*#`I+"`D;6EN3&5N
M9W1H(#T@,2D*("`@('L*("`@("`@("`D8VAR(#T@;G5L;#L*("`@("`@("!F
M;W)E86-H("@D;&EN97,@87,@)&DI('L*("`@("`@("`@("`@:68@*"%P<F5G
M7VUA=&-H*"<O7BA;7F$M>D$M6C`M.5QX-V8M7'AF9EQS72LI7',J)"\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R
M6R1I72P@)&TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&-H<BDI('L*
M("`@("`@("`@("`@("`@(&EF("AS=')L96XH)&U;,5TI(#P@)&UI;DQE;F=T
M:"D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("1C:'(@/2`D;5LQ77LP?3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("AS=')L
M96XH)&U;,5TI("$]("1M:6Y,96YG=&@I('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&UI;DQE;F=T:"`]('-T<FQE;B@D;5LQ72D["B`@
M("`@("`@("`@(&9O<B`H)&H@/2`P.R`D:B`\('-T<FQE;B@D;5LQ72D[("1J
M*RLI('L*("`@("`@("`@("`@("`@(&EF("@D;5LQ77LD:GT@(3T@)&-H<BD@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*"B`@("!F=6YC=&EO;B`F7W!A<G-E26YL:6YE*"8D
M;F]D92P@)'1E>'0I"B`@("!["B`@("`@("`@<W1A=&EC("1A;&EA<V5S(#T@
M87)R87DH)W-U<"<@/3X@)W-U<&5R<V-R:7!T)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<W5B)R`]/B`G<W5B<V-R:7!T)RD["B`@("`@
M("`@<W1A=&EC("1S8VAE;6%S(#T@87)R87DH)VAT='`G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=H='1P<R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V9T<"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VER8R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W1E;&YE="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VYE=W,G*3L*"B`@("`@("`@=VAI;&4@*'-T<FQE;B@D=&5X="D@/B`P
M*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EPJ7"HH*#\Z7%Q<
M7"Y\6UY<7%Q<72DJ/RE<*EPJ*"XJ*20O)RP@)'1E>'0L("1M*2D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TEN=&5R<')E
M=&5D+51E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G<F]L92<@/3X@)W-T<F]N9R<I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]
M("1M6S)=.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UY<
M*B@H/SI<7%Q<+GQ;7EQ<7%Q=*2H_*5PJ*"XJ*20O)RP@)'1E>'0L("1M*2D@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TEN
M=&5R<')E=&5D+51E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@G<F]L92<@/3X@)V5M<&AA<VES)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1M6S%=*3L*("`@("`@("`@("`@("`@
M("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA
M=&-H*"<O7F!@*"XJ/RE@8"@N*BDD+R<L("1T97AT+"`D;2DI('L*("`@("`@
M("`@("`@("`@("1S=6(@/2`F)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TEN
M=&5R<')E=&5D+51E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=R;VQE)R`]/B`G;&ET97)A;"<I*3L*("`@
M("`@("`@("`@("`@("1S=6(M/F%P<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@
M("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7CHH6V$M>BU=*RDZ8"@H/SI<7%Q<+GQ;7EQ<7%Q=
M*2H_*6`H+BHI)"\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<F]L92`]("1M6S%=
M.PH@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;&EA<V5S6R1M6S%=72DI
M('L*("`@("`@("`@("`@("`@("`@("`D<F]L92`]("1A;&EA<V5S6R1M6S%=
M73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S=6(@/2`F
M)'1H:7,M/E]M86ME3F]D92@D;F]D92P@)TEN=&5R<')E=&5D+51E>'0G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=R;VQE)R`]/B`D<F]L92DI.PH@("`@("`@("`@("`@("`@:68@*"1R;VQE
M(#T]("=L:71E<F%L)RD@>PH@("`@("`@("`@("`@("`@("`@("1S=6(M/F%P
M<&5N9$-H:6QD*"1M6S)=*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P87)S94EN;&EN92@D<W5B+"`D
M;5LR72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&5X
M="`]("1M6S-=.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G
M+UY@*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I8#HH6V$M>BU=*RDZ*"XJ*20O)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1E>'0L("1M*2D@
M>PH@("`@("`@("`@("`@("`@)')O;&4@/2`D;5LR73L*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D86QI87-E<ULD;5LR75TI*2!["B`@("`@("`@("`@
M("`@("`@("`@)')O;&4@/2`D86QI87-E<ULD;5LR75T["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<W5B(#T@)B1T:&ES+3Y?;6%K94YO
M9&4H)&YO9&4L("=);G1E<G!R971E9"U497AT)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L92<@/3X@)')O
M;&4I*3L*("`@("`@("`@("`@("`@(&EF("@D<F]L92`]/2`G;&ET97)A;"<I
M('L*("`@("`@("`@("`@("`@("`@("`D<W5B+3YA<'!E;F1#:&EL9"@D;5LQ
M72D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%R<V5);FQI;F4H)'-U8BP@)&U;,5TI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LS73L*("`@
M("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H)R]>8"@H/SI<7%Q<+GQ;
M7EQ<7%Q=*2H_*6!?7R@N*BDD+R<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R<V5,:6YK*"1N;V1E+"`D;5LQ72P@=')U92D["B`@("`@("`@("`@
M("`@("`D=&5X="`]("1M6S)=.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E
M9U]M871C:"@G+UY@*"@_.EQ<7%PN?%M>7%Q<7%TI*C\I8%\H+BHI)"\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A<G-E3&EN:R@D;F]D92P@)&U;
M,5TL(&9A;'-E*3L*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@
M("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7F`H*#\Z7%Q<7"Y\
M6UY<7%Q<72DJ/RE@*"XJ*20O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]M86ME3F]D92@D;F]D92P@)TEN=&5R<')E=&5D+51E>'0G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<F]L92<@/3X@)W1I
M=&QE+7)E9F5R96YC92<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=.PH@
M("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UXH*#\Z)R`N(&IO
M:6XH)WPG+"`D<V-H96UA<RD@+B`@)RDZ7"]<+ULM,"TY82UZ(R4F*RY<+SH[
M/U]<7'Y=*ULM,"TY82UZ(R4F*UPO7UQ<?ETI*"XJ*20O:2<L("1T97AT+"`D
M;2DI('L*("`@("`@("`@("`@("`@("1S=6(@/2`F)'1H:7,M/E]M86ME3F]D
M92@D;F]D92P@)TQI;FLG+"!A<G)A>2@G:')E9B<@/3X@)&U;,5TI*3L*("`@
M("`@("`@("`@("`@("1S=6(M/F%P<&5N9$-H:6QD*"1M6S%=*3L*("`@("`@
M("`@("`@("`@("1T97AT(#T@)&U;,ET["B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7BA;82UZ,"TY+5TK0%MA+7HP+3DM7"Y=*UPN6V$M
M>C`M.2U=*RDH+BHI)"]I)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`@("`@)'-U8B`]("8D
M=&AI<RT^7VUA:V5.;V1E*"1N;V1E+"`G3&EN:R<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VAR968G(#T^("=M
M86EL=&\Z)R`N("1M6S%=*2D["B`@("`@("`@("`@("`@("`D<W5B+3YA<'!E
M;F1#:&EL9"@D;5LQ72D["B`@("`@("`@("`@("`@("`D=&5X="`]("1M6S)=
M.PH@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G+UXH7'<K*5]<
M8B@N*BDD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&%R<V5,:6YK*"1N;V1E+"`D;5LQ72P@9F%L<V4I.PH@("`@("`@("`@
M("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>7%Q<7%QS*"XJ*20O)RP@)'1E>'0L("1M*2D@>PH@("`@
M("`@("`@("`@("`@+R\@0F%C:W-L87-H+65S8V%P960@=VAI=&5S<&%C92!C
M:&%R86-T97)S(&%R92!R96UO=F5D(&9R;VT*("`@("`@("`@("`@("`@("\O
M('1H92!D;V-U;65N="X*("`@("`@("`@("`@("`@("1T97AT(#T@)&U;,5T[
M"B`@("`@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H*"<O7EQ<7%PH+BDH
M+BHI)"\G+"`D=&5X="P@)&TI*2!["B`@("`@("`@("`@("`@("`D8R`]("1M
M6S%=.PH@("`@("`@("`@("`@("`@)'1E>'0@/2`D;5LR73L*("`@("`@("`@
M("`@("`@("1N;V1E+3YA<'!E;F1#:&EL9"@D8RD["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`O+R!86%@Z(%=E('-H;W5L9"!T<GD@
M=&\@=7-E(&$@<F5G97AP('1O(&=R86(@87,@;75C:"!T97AT(&%S"B`@("`@
M("`@("`@("`@("`O+R!P;W-S:6)L92P@=&AE;B!F86QL('1H<F]U9V@@=&\@
M=&AE('-I;F=L92UC:&%R86-T97(@8V%S90H@("`@("`@("`@("`@("`@+R\@
M:68@=V4@8V%N)W0@9V5T(&%N>71H:6YG+@H*("`@("`@("`@("`@("`@("1C
M(#T@<W5B<W1R*"1T97AT+"`P+"`Q*3L*("`@("`@("`@("`@("`@("1T97AT
M(#T@<W5B<W1R*"1T97AT+"`Q*3L*("`@("`@("`@("`@("`@("1N;V1E+3YA
M<'!E;F1#:&EL9"@D8RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D8F]D>3L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E
M<R!A;B!A;F]N>6UO=7,@;W(@;F%M960@;&EN:RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@5&5X=%]R95-4
M("`@("`@("`@("!4:&4@<&%R96YT(&YO9&4@9F]R('1H92!L:6YK+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D=&5X="`@("`@("`@5&AE('1E>'0@=&\@<&%R
M<V4N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D86YO;GEM;W5S("!7:&5T:&5R
M('1H:7,@:7,@86X@86YO;GEM;W5S(&QI;FLN"B`@("`@*@H@("`@("H@0')E
M='5R;B!497AT7W)E4U0@(%1H92!N97<@;&EN:R!N;V1E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B`F7W!A<G-E3&EN:R@F)&YO9&4L("1T97AT+"`D86YO;GEM
M;W5S(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&QI;FL@/2`F)'1H:7,M/E]M
M86ME3F]D92@D;F]D92P@)TQI;FLG*3L*"B`@("`@("`@:68@*'!R96=?;6%T
M8V@H)R\\*"XJ*3XO)RP@)'1E>'0L("1M*2D@>PH@("`@("`@("`@("`D;&EN
M:RT^<V5T4')O<&5R='DH)VAR968G+"`D;5LQ72D["B`@("`@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"<O7BA;7CQ=*S\I7',J/"\G+"`D=&5X="P@)&TI*2![
M"B`@("`@("`@("`@("`@("`D;&EN:RT^87!P96YD0VAI;&0H)&U;,5TI.PH@
M("`@("`@("`@("`@("`@:68@*"$D86YO;GEM;W5S*2!["B`@("`@("`@("`@
M("`@("`@("`@)&QI;FLM/G-E=%!R;W!E<G1Y*"=N86UE)RP@)'1H:7,M/E]N
M;W)M86QI>F5.86UE*"1M6S%=*2D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(21A
M;F]N>6UO=7,I('L*("`@("`@("`@("`@("`@("1L:6YK+3YS9710<F]P97)T
M>2@G;F%M92<L("1T:&ES+3Y?;F]R;6%L:7IE3F%M92@D=&5X="DI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1L:6YK+3YA<'!E;F1#:&EL9"@D=&5X
M="D["B`@("`@("`@?0H*("`@("`@("!I9B`H)&%N;VYY;6]U<R`F)B!I<U]N
M=6QL*"1L:6YK+3YG9710<F]P97)T>2@G:')E9B<I*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W%U975E06YO;GEM;W5S4F5F97)E;F-E*"1L:6YK+"`G;&EN
M:R<I.PH@("`@("`@('T@96QS96EF("@A)&%N;VYY;6]U<R`F)B`A:7-?;G5L
M;"@D;&EN:RT^9V5T4')O<&5R='DH)VYA;64G*2DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]P=71.86UE9%)E9F5R96YC92@D;&EN:RP@)VQI;FLG*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D;&EN:SL*("`@('T*"B`@("`O*BH*
M("`@("`J($YO<FUA;&EZ97,@86X@;V)J96-T(&YA;64N"B`@("`@*B!4:&ES
M(&UE86YS('1H870@=V4@;&]W97)C87-E(&ET(&%N9"!N;W)M86QI>F4@86YY
M('=H:71E<W!A8V4@:6X@:70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@02!N86UE('1O(&YO<FUA;&EZ92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@5&AE(&YO<FUA;&EZ960@;F%M92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@7VYO<FUA;&EZ94YA;64H)&YA;64I"B`@("!["B`@("`@
M("`@<F5T=7)N('!R96=?<F5P;&%C92@G+UQS*R\G+"`G("<L('-T<G1O;&]W
M97(H)&YA;64I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!A;F0@
M97AE8W5T97,@82!@+BXG(&1I<F5C=&EV92X*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT
M("!!(&1I<F5C=&EV92!T;R!E>&5C=71E+"!L97-S('1H92!L96%D:6YG(&`N
M+B`G+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R<V5$:7)E8W1I=F4H)'1E
M>'0I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7U\Z7',J*"XJ
M/RE<<RHD+R<L("1T97AT+"`D;2DI('L*("`@("`@("`@("`@+R\*("`@("`@
M("`@("`@+R\@06YO;GEM;W5S(&QI;FL@9&5F:6YI=&EO;@H@("`@("`@("`@
M("`O+PH@("`@("`@("`@("`D9&5F;B`]("9N97<@5&5X=%]R95-4*"=,:6YK
M)RD["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7EMA+7HP+3DM72M`
M6V$M>C`M.2U<+ETK7"Y;82UZ,"TY+5TK)"]I)RP@)&U;,5TI*2!["B`@("`@
M("`@("`@("`@("`D;5LQ72`]("=M86EL=&\Z)R`N("1M6S%=.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1D969N+3YS9710<F]P97)T>2@G:')E9B<L
M("1M6S%=*3L*("`@("`@("`@("`@)'1H:7,M/E]Q=65U94%N;VYY;6]U<T1E
M9FEN:71I;VXH)&1E9FXL("=L:6YK)RD["B`@("`@("`@?2!E;'-E:68@*'!R
M96=?;6%T8V@H)R]>7',J7R@N*C\I.EQS*B@N*C\I7',J)"\G+"`D=&5X="P@
M)&TI*2!["B`@("`@("`@("`@("\O"B`@("`@("`@("`@("\O($YA;65D(&QI
M;FL@9&5F:6YI=&EO;@H@("`@("`@("`@("`O+PH@("`@("`@("`@("`D9&5F
M;B`]("9N97<@5&5X=%]R95-4*"=,:6YK)RD["B`@("`@("`@("`@("1D969N
M+3YS9710<F]P97)T>2@G;F%M92<L("1T:&ES+3Y?;F]R;6%L:7IE3F%M92@D
M;5LQ72DI.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;82UZ,"TY
M+5TK0%MA+7HP+3DM7"Y=*UPN6V$M>C`M.2U=*R0O:2<L("1M6S)=*2D@>PH@
M("`@("`@("`@("`@("`@)&U;,ET@/2`G;6%I;'1O.B<@+B`D;5LR73L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D9&5F;BT^<V5T4')O<&5R='DH)VAR
M968G+"`D;5LR72D["B`@("`@("`@("`@("1T:&ES+3Y?<'5T3F%M961$969I
M;FET:6]N*"1D969N+"`G;&EN:R<I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-K:7!S(&)L86YK(&QI;F5S('5N=&EL('=E(&9I;F0@;VYE
M('=E(&-A;B!G970@=&AE(&EN9&5N=&%T:6]N(&QE=F5L"B`@("`@*B!F<F]M
M+"!T:&5N+"!G871H97)S(&QI;F5S('5N=&EL('=E(&AA=F4@82!D:69F97)E
M;G0@;&5V96PN"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94QI=&5R86Q"
M;&]C:R@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V5N<W5R94QI;F5S
M*#$I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"<O7EQS*B0O)RP@)'1H:7,M/E]L
M:6YE0G5F9F5R6S!=*2D@>PH@("`@("`@("`@("!I9B`H(21T:&ES+3Y?;F5X
M="@I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A<')E9U]M871C:"@G+UXH
M7',K*2@N*C\I7',J)"\G+"`D=&AI<RT^7VQI;F5"=69F97);,%TL("1M*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@
M("1L979E;"`]('-T<FQE;B@D;5LQ72D["B`@("`@("`@)'1E>'0@/2`D;5LR
M73L*"B`@("`@("`@:68@*"1T:&ES+3Y?;F5X="@I*2!["B`@("`@("`@("`@
M("1R92`]("<O7B@_.B![)R`N("1L979E;"`N("=]*"XJ/RE\*"DI7',J)"\G
M.PH@("`@("`@("`@("!W:&EL92`H<')E9U]M871C:"@D<F4L("1T:&ES+3Y?
M;&EN94)U9F9E<ELP72P@)&TI*2!["B`@("`@("`@("`@("`@("`D=&5X="`N
M/2`B7&XB("X@)&U;,5T["B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M;F5X="@I*2!["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1L
M(#T@)B1T:&ES+3Y?;6%K94YO9&4H)'1H:7,M/E]C=7)R96YT3F]D92P@)TQI
M=&5R86PM0FQO8VLG+"!A<G)A>2@I*3L*("`@("`@("`D;"T^87!P96YD0VAI
M;&0H<')E9U]R97!L86-E*"<O7',K)"]S)RP@)R<L("1T97AT*2D["@H@("`@
M("`@("\O(%A86#H@1&ER='D@:&%C:R$*("`@("`@("!A<G)A>5]U;G-H:69T
M*"1T:&ES+3Y?;&EN94)U9F9E<BP@)R<I.PH@("`@?0H*("`@("\O+2TM+0H@
M("`@+R\@3&EN92UR96%D:6YG(&UE;6)E<G,*("`@("\O+2TM+0H*("`@("\J
M*@H@("`@("H@5&AE(')E;6%I;F1E<B!O9B!T:&4@=&5X="!W92!A<F4@<&%R
M<VEN9RP@8F5I;F<@;6]D:69I960@8GD@7V=E=$QI;F4H*0H@("`@("H@86YD
M(%]N97AT*"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]T97AT.PH*("`@("\J
M*@H@("`@("H@06X@87)R87D@;V8@=&AE(&QI;F5S('=E(&AA=F4@<&5E:V5D
M(&%T+@H@("`@("H*("`@("`J(%1H92!F:7)S="!E;&5M96YT(&ES('1H92!L
M:6YE('=E(&%R92!C=7)R96YT;'D@=V]R:VEN9R!W:71H(&%N9"!S;R!O;BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?;&EN94)U9F9E<B`](&%R<F%Y*"D["@H@
M("`@+RHJ"B`@("`@*B!2971R:65V97,@=&AE(&YE>'0@;&EN92!F<F]M(&$@
M8FQO8VL@;V8@=&5X="X*("`@("`J"B`@("`@*B!792!R97!L86-E('1A8G,@
M=VET:"`X('-P86-E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$QI;F4H*0H@("`@>PH@("`@("`@
M(&EF("AS=')L96XH)'1H:7,M/E]T97AT*2`]/2`P*2!["B`@("`@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("`D:2`]('-T<G!O<R@D
M=&AI<RT^7W1E>'0L(")<;B(I.PH@("`@("`@(&EF("@D:2`A/3T@9F%L<V4I
M('L*("`@("`@("`@("`@)&QI;F4@/2!S=6)S='(H)'1H:7,M/E]T97AT+"`P
M+"`D:2D["B`@("`@("`@("`@("1T:&ES+3Y?=&5X="`]('-U8G-T<B@D=&AI
M<RT^7W1E>'0L("1I("L@,2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&QI;F4@/2`D=&AI<RT^7W1E>'0["B`@("`@("`@("`@("1T:&ES+3Y?
M=&5X="`]("<G.PH@("`@("`@('T*("`@("`@("!R971U<FX@<')E9U]R97!L
M86-E*"<O7'0O)RP@)R`@("`@("`@)RP@)&QI;F4I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0G5M<',@=&\@=&AE(&YE>'0@;&EN92!I;B!T:&4@:6YP=70N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]N97AT*"D*("`@('L*("`@("`@("`O+R!3<&5C:6%L(&-A<V4@
M=&AE(&9I<G-T('1I;64@)W)O=6YD+@H@("`@("`@(&EF("AC;W5N="@D=&AI
M<RT^7VQI;F5"=69F97(I(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?96YS=7)E3&EN97,H,2D["B`@("`@("`@?0H*("`@("`@("!I9B`H
M(21T:&ES+3Y?96YS=7)E3&EN97,H,BDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*("`@("`@("!A<G)A>5]S:&EF="@D=&AI<RT^
M7VQI;F5"=69F97(I.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@36%K97,@<W5R92!T:&5R92!I<R!A(&-E<G1A:6X@;G5M
M8F5R(&]F(&QI;F5S(&%T(&UI;FEM=6T@:6X@=&AE(&QI;F4*("`@("`J(&)U
M9F9E<BX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D8V]U;G0@(%1H:7,@:7,@=&AE(&YU;6)E
M<B!O9B!L:6YE<R!W:&EC:"!M=7-T(&)E(&EN('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("!B=69F97(N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!7:&5T:&5R(&]R(&YO="!W92!S=6-C965D960N("!792!C
M86X@9F%I;"!A=`H@("`@("H@("`@("`@("`@("`@("`@("!E;F0M;V8M9FEL
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V5N<W5R94QI;F5S*"1C;W5N="`]
M(#$I"B`@("!["B`@("`@("`@=VAI;&4@*&-O=6YT*"1T:&ES+3Y?;&EN94)U
M9F9E<BD@/"`D8V]U;G0I('L*("`@("`@("`@("`@)&QI;F4@/2`D=&AI<RT^
M7V=E=$QI;F4H*3L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)&QI;F4I*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/E]L:6YE0G5F9F5R6UT@/2`D;&EN93L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\M+2TM
M"B`@("`O+R!!;F]N>6UO=7,@<F5F97)E;F-E<R!A;F0@9&5F:6YI=&EO;G,*
M("`@("\O+2TM+0H*("`@('9A<B`D7V%N;VYY;6]U<U)E9F5R96YC97,@/2!A
M<G)A>2@I.PH@("`@=F%R("1?86YO;GEM;W5S1&5F:6YI=&EO;G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@4VEN8V4@86YO;GEM;W5S(')E9F5R96YC
M97,@86YD(&1E9FEN:71I;VYS("AE+F<N(&9O;W1N;W1E<RP@;&EN:W,I(&1O
M"B`@("`@*B!N;W0@;F5E9"!T;R!B92!D969I;F5D(")I;B!L;V-K<W1E<"(@
M86-C;W)D:6YG('1O('1H92!S<&5C+"!W92!C<F5A=&4*("`@("`J('1H92!P
M87)T:6%L('!A<G-E(&YO9&4@:6X@8F]T:"!P;&%C97,@86YD('5S92!T:&ES
M(&YI9G1Y('-Y<W1E;2!T;PH@("`@("H@<75E=64@;W(@;65R9V4@:6X@96%C
M:"!P;&%C92X@($YO=&4@=&AA="!T:&4@<F5F97)E;F-E(&ES('1H92`B;6%S
M=&5R(@H@("`@("H@;F]D92X@(%1H92!D969I;FET:6]N(&=E=',@=&AR;W=N
M(&%W87D@<VEN8V4@:70@<F5A;&QY(&ES;B=T(&EN('1H90H@("`@("H@<&%R
M<V4@=')E92!A;GEW87DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`F)&YO9&4@(%1H92!N;V1E
M('1O('%U975E(&]R(&UE<F=E('1O+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M='EP92`@(%1H92!T>7!E(&]F(&%N;VYY;6]U<R!O8FIE8W0N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]Q=65U94%N;VYY;6]U<U)E9F5R96YC92@F)&YO9&4L
M("1T>7!E*0H@("`@>PH@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@D
M='EP92P@)'1H:7,M/E]A;F]N>6UO=7-$969I;FET:6]N<RDI('L*("`@("`@
M("`@("`@)'1H:7,M/E]A;F]N>6UO=7-$969I;FET:6]N<ULD='EP95T@/2!A
M<G)A>2@I.PH@("`@("`@('T*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]A
M;F]N>6UO=7-$969I;FET:6]N<ULD='EP95TI(#X@,"D@>PH@("`@("`@("`@
M("`D9&5F;B`]("8D=&AI<RT^7V%N;VYY;6]U<T1E9FEN:71I;VYS6R1T>7!E
M75LP73L*("`@("`@("`@("`@87)R87E?<VAI9G0H)'1H:7,M/E]A;F]N>6UO
M=7-$969I;FET:6]N<ULD='EP95TI.PH@("`@("`@("`@("`D=&AI<RT^7VUE
M<F=E3F]D95!R;W!E<G1I97,H)&YO9&4L("1D969N*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V%N;VYY;6]U<U)E9F5R96YC97-;
M)'1Y<&5=6UT@/2`F)&YO9&4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@2&%N9&QE<R!A;B!A;F]N>6UO=7,@9&5F:6YI=&EO;BX*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@
M;V)J96-T("8D;F]D92`@5&AE(&YO9&4@=&\@<75E=64@;W(@;65R9V4@9G)O
M;2X*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("!4:&4@='EP92!O9B!A
M;F]N>6UO=7,@;V)J96-T+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<75E=65!
M;F]N>6UO=7-$969I;FET:6]N*"8D;F]D92P@)'1Y<&4I"B`@("!["B`@("`@
M("`@:68@*"%A<G)A>5]K97E?97AI<W1S*"1T>7!E+"`D=&AI<RT^7V%N;VYY
M;6]U<U)E9F5R96YC97,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?86YO;GEM
M;W5S4F5F97)E;F-E<ULD='EP95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@
M("`@("!I9B`H8V]U;G0H)'1H:7,M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T
M>7!E72D@/B`P*2!["B`@("`@("`@("`@("1R968@/2`F)'1H:7,M/E]A;F]N
M>6UO=7-2969E<F5N8V5S6R1T>7!E75LP73L*("`@("`@("`@("`@87)R87E?
M<VAI9G0H)'1H:7,M/E]A;F]N>6UO=7-2969E<F5N8V5S6R1T>7!E72D["B`@
M("`@("`@("`@("1T:&ES+3Y?;65R9V5.;V1E4')O<&5R=&EE<R@D<F5F+"`D
M;F]D92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]A
M;F]N>6UO=7-$969I;FET:6]N<ULD='EP95U;72`]("8D;F]D93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!-97)G97,@=&AE('!R;W!E<G1I
M97,@9G)O;2!E86-H(&YO9&4@:6YT;R!T:&4@;W1H97(@;F]D92X*("`@("`J
M"B`@("`@*B!4:&4@;F]D92!T>7!E(&ES(&YO="!C:&%N9V5D("AF;W(@=&AE
M(&-A<V4@=VAE<F4@=V4@:&%V92!A(&9O;W1N;W1E"B`@("`@*B!R969E<F5N
M8V4@86YD(&$@9F]O=&YO=&4@9&5F:6YI=&EO;BDL(&)U="!B;W1H(&YO9&5S
M('=I;&P@:&%V92!A;&P*("`@("`J('!R;W!E<G1I97,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M="`F)&YO9&4@(%1H92!R969E<F5N8V4@;F]D92X*("`@("`J($!P87)A;2!O
M8FIE8W0@)B1D969N("!4:&4@9&5F:6YI=&EO;B!N;V1E+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;65R9V5.;V1E4')O<&5R=&EE<R@F)&YO9&4L("8D9&5F
M;BD*("`@('L*("`@("`@("`O+R!86%@Z(%=E('-H;W5L9"!M86ME('-U<F4@
M=&AE<F4@:7,@;F\@8V]L;&ES:6]N+@H@("`@("`@(&9O<F5A8V@@*"1D969N
M+3Y?<')O<&5R=&EE<R!A<R`D;F%M92`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@)&YO9&4M/G-E=%!R;W!E<G1Y*"1N86UE+"`D=F%L=64I.PH@("`@("`@
M('T*("`@("`@("!F;W)E86-H("@D;F]D92T^7W!R;W!E<G1I97,@87,@)&YA
M;64@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1D969N+3YS9710<F]P97)T
M>2@D;F%M92P@)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\M+2TM
M"B`@("`O+R!.86UE9"!R969E<F5N8V5S(&%N9"!D969I;FET:6]N<PH@("`@
M+R\M+2TM"@H@("`@=F%R("1?;F%M9612969E<F5N8V5S(#T@87)R87DH*3L*
M("`@('9A<B`D7VYA;65D1&5F:6YI=&EO;G,@/2!A<G)A>2@I.PH*("`@("\J
M*@H@("`@("H@4W1O<F5S(&$@;F%M960@<F5F97)E;F-E('!A<G-E(&YO9&4@
M:6X@82!H87-H('-O('=E(&-A;B!L871E<B!M97)G90H@("`@("H@<')O<&5R
M=&EE<R!W:71H(&$@9&5F:6YI=&EO;BX@($EF('=E(&%L<F5A9'D@:&%V92!A
M(&1E9FEN:71I;VXL(&1O"B`@("`@*B!T:&4@;65R9V4@;F]W+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($!P87)A;2!4
M97AT7W)E4U0@)B1N;V1E("!4:&4@<&%R<V4@=')E92!N;V1E+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D='EP92`@("`@(%1H92!T>7!E(&]F(&YA;65D(')E
M9F5R96YC92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%=H971H
M97(@;W(@;F]T('=E('-U8V-E<W-F=6QL>2!A9&1E9"!T:&4@<F5F97)E;F-E
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<'5T3F%M9612969E<F5N8V4H)B1N
M;V1E+"`D='EP92D*("`@('L*("`@("`@("`D;F%M92`]("1N;V1E+3YG9710
M<F]P97)T>2@G;F%M92<I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA
M;65D4F5F97)E;F-E<ULD='EP95U;)&YA;65=*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;F%M9612
M969E<F5N8V5S6R1T>7!E75LD;F%M95T@/2`F)&YO9&4["B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;F%M961$969I;FET:6]N<ULD='EP95U;)&YA;65=
M*2D@>PH@("`@("`@("`@("`D9&5F;B`]("8D=&AI<RT^7VYA;65D1&5F:6YI
M=&EO;G-;)'1Y<&5=6R1N86UE73L*("`@("`@("`@("`@)'1H:7,M/E]M97)G
M94YO9&50<F]P97)T:65S*"1N;V1E+"`D9&5F;BD["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&EN
M=F5R<V4@;V8@>T!L:6YK(%]P=71.86UE9%)E9F5R96YC92@I?2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W!U=$YA;65D1&5F:6YI=&EO;B@F)&YO9&4L("1T>7!E*0H@("`@>PH@("`@
M("`@("1N86UE(#T@)&YO9&4M/F=E=%!R;W!E<G1Y*"=N86UE)RD["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?;F%M961$969I;FET:6]N<ULD='EP95U;
M)&YA;65=*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@("1T:&ES+3Y?;F%M961$969I;FET:6]N<ULD='EP95U;)&YA
M;65=(#T@)B1N;V1E.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65D
M4F5F97)E;F-E<ULD='EP95U;)&YA;65=*2D@>PH@("`@("`@("`@("`D<F5F
M(#T@)B1T:&ES+3Y?;F%M9612969E<F5N8V5S6R1T>7!E75LD;F%M95T["B`@
M("`@("`@("`@("1T:&ES+3Y?;65R9V5.;V1E4')O<&5R=&EE<R@D<F5F+"`D
M;F]D92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\O+2TM+0H@("`@+R\@4W1A=&4@<W1A8VL@;6%N86=E;65N=`H@("`@
M+R\M+2TM"@H@("`@+RHJ"B`@("`@*B!4:&4@<W1A=&4@<W1A8VLN"B`@("`@
M*@H@("`@("H@270@:7,@=7-E9"!T;R!K965P('1R86-K(&]F(&YE<W1E9"!B
M;V1Y+6QE=F5L(&5L96UE;G1S(&%N9"!H;W<@=&AE>0H@("`@("H@;6EG:'0@
M96YD+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1?<W1A=&53=&%C:R`](&%R<F%Y*"D["@H@("`@=F%R("1?8W5R<F5N=$YO
M9&4["@H@("`@9G5N8W1I;VX@7W!U<VA3=&%T92@F)&YO9&4L("1S=&%T951Y
M<&4L("1L979E;"D*("`@('L*("`@("`@("`D<W1A=&4@/2`F;F5W(%1E>'1?
M<F535%]087)S97)?<W1A=&4H)&YO9&4L("1S=&%T951Y<&4L("1L979E;"D[
M"B`@("`@("`@)'1H:7,M/E]S=&%T95-T86-K6UT@/2`F)'-T871E.PH@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=$YO9&4@/2`F)&YO9&4["B`@("!]"@H@("`@
M9G5N8W1I;VX@7V=E=%-T871E3&5V96PH)'-T871E5'EP92D*("`@('L*("`@
M("`@("!F;W(@*"1I(#T@8V]U;G0H)'1H:7,M/E]S=&%T95-T86-K*2`M(#$[
M("1I(#X](#`[("1I+2TI('L*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<W1A
M=&53=&%C:ULD:5TM/G-T871E5'EP92`]/2`D<W1A=&54>7!E*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]S=&%T95-T86-K6R1I72T^;&5V
M96P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(#`[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7W!O<%1O3&5V96PH)'-T871E5'EP92P@
M)&QE=F5L*0H@("`@>PH@("`@("`@('=H:6QE("@D=&AI<RT^7V=E=%-T871E
M3&5V96PH)'-T871E5'EP92D@/B`D;&5V96PI('L*("`@("`@("`@("`@)'1H
M:7,M/E]P;W`H*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7W!O
M<"@I"B`@("!["B`@("`@("`@87)R87E?<&]P*"1T:&ES+3Y?<W1A=&53=&%C
M:RD["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?<W1A=&53=&%C:RDI('L*
M("`@("`@("`@("`@)'-T871E(#T@)B1T:&ES+3Y?<W1A=&53=&%C:UMC;W5N
M="@D=&AI<RT^7W-T871E4W1A8VLI("T@,5T["B`@("`@("`@("`@("1T:&ES
M+3Y?8W5R<F5N=$YO9&4@/2`F)'-T871E+3YN;V1E.PH@("`@("`@('T*("`@
M('T*"GT*"B\J*@H@*B!4:&ES(&-L87-S(')E<')E<V5N=',@82!N;V1E(&]N
M('1H92!P87)S97(G<R!S=&%T92!S=&%C:RX*("H*("H@0'!A8VMA9V4@5&5X
M=%]R95-4"B`J+PIC;&%S<R!497AT7W)E4U1?4&%R<V5R7W-T871E('L*"B`@
M("!V87(@)&YO9&4["B`@("!V87(@)'-T871E5'EP93L*("`@('9A<B`D;&5V
M96P["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@;V)J96-T("8D;F]D92`@("`@(%1H:7,@:7,@=&AE('!A<G-E
M(&YO9&4@87-S;V-I871E9"!W:71H('1H:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1A=&4N("!";&]C:RUL979E;"!E;&5M96YT<R!P
M87)S960@:6X@=&AI<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=&%T92!W:6QL(&)E(&-H:6QD<F5N(&]F('1H:7,@;F]D92X*("`@("`J
M($!P87)A;2!S=')I;F<@)'-T871E5'EP92`@0W5R<F5N=&QY(&]N;'D@)U-E
M8W1I;VXG+@H@("`@("H@0'!A<F%M(&UI>&5D("1L979E;"`@("`@("!4:&ES
M(&ES('1H92!N97-T:6YG(&QE=F5L(&]F('1H:7,@<W1A=&4@='EP92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@5&5X=%]R95-47U!A<G-E<E]S=&%T92@F)&YO
M9&4L("1S=&%T951Y<&4L("1L979E;"D*("`@('L*("`@("`@("`D=&AI<RT^
M;F]D92`]("8D;F]D93L*("`@("`@("`D=&AI<RT^<W1A=&54>7!E(#T@)'-T
M871E5'EP93L*("`@("`@("`D=&AI<RT^;&5V96P@/2`D;&5V96P["B`@("!]
M"@I]"@``````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O;&EB+U1E>'0O<F535"]&;W)M871T97(N<&AP````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#,T(#$P-3$U-#,T
M,3,V(#`R,C4V-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO*BH*("H@5&AE(%1E>'1?<F535%]&;W)M871T97(Z
M.B!C;&%S<R!I<R!T:&4@9G)A;65W;W)K(&9O<B!R96YD97)I;F<*("H@<F53
M=')U8W1U<F5D5&5X="!D;V-U;65N=',@=&\@9&EF9F5R96YT(&UE9&EA("AE
M+F<N($A434PI+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]497AT7W)E4U0O
M<F535"]&;W)M871T97(N<&AP+'8@,2XU+C$P+CD@,C`P-B\P,2\P,2`R,3HR
M.#HS.2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O
M;B!-+B!&96QI8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R
M;VYO<WES+F-O;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!4
M97AT7W)E4U1?1F]R;6%T=&5R('L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F
M(&1R:79E<BUS<&5C:69I8R!P87)A;65T97)S(&9O<B!F;W)M871T:6YG+@H@
M("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?87)G
M<SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C="!A(&YE=R!F;W)M871T97(N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&%R9W,@($%R9W5M96YT<R!S<&5C:69I8R!T;R!T
M:&ES(&9O<FUA='1E<BX*("`@("`J+PH@("`@9G5N8W1I;VX@5&5X=%]R95-4
M7T9O<FUA='1E<B@D87)G<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H
M:7,M/E]A<F=S(#T@)&%R9W,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYS
M=')U8W0@82!N97<@9F]R;6%T=&5R+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&1R:79E<B`@3F%M92!O9B!T:&4@9F]R;6%T=&EN9R!D<FEV97(@
M=&\@8V]N<W1R=6-T+@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<F=S("`@("!!
M;B!A<G)A>2!O9B!D<FEV97(M<W!E8VEF:6,@<&%R86UE=&5R<RX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(%1E>'1?<F535%]&;W)M871T97(@(%1H92!F;W)M
M871T97(*("`@("`J+PH@("`@9G5N8W1I;VX@)F9A8W1O<GDH)&1R:79E<BP@
M)&%R9W,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M9')I=F5R*2D@>PH@("`@("`@("`@("!L:7-T*"1P871H+"`D9')I=F5R*2`]
M("1D<FEV97(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A=&@@
M/2!D:7)N86UE*%]?1DE,15]?*2`N("<O1F]R;6%T=&5R+R<["B`@("`@("`@
M?0H@("`@("`@("1C;&%S<R`]("=497AT7W)E4U1?1F]R;6%T=&5R7R<@+B`D
M9')I=F5R.PH@("`@("`@(')E<75I<F5?;VYC92`D<&%T:"`N("1D<FEV97(@
M+B`G+G!H<"<["B`@("`@("`@)&9O<FUA='1E<B`]("9N97<@)&-L87-S*"1A
M<F=S*3L*("`@("`@("!R971U<FX@)&9O<FUA='1E<CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E;F1E<B!T:&4@9&]C=6UE;G0N"B`@("`@*@H@("`@("H@
M0&%B<W1R86-T"B`@("`@*@H@("`@("H@0'!A<F%M(%1E>'1?<F535"`D9&]C
M=6UE;G0@(%1H92!D;V-U;65N="!W92!W:6QL(')E;F1E<BX*("`@("`J($!P
M87)A;2!S=')I;F<@)&-H87)S970@("`@("!4:&4@;W5T<'5T(&-H87)S970N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FUA="@F)&1O8W5M96YT+"`D8VAA
M<G-E="`](&YU;&PI"B`@("!["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]497AT+W)E4U0O1F]R;6%T=&5R+VAT;6PN<&AP````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C$P,2`Q,#4Q-30S-#$S-B`P
M,C,U,C(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*"G)E<75I<F5?;VYC92!D:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO1F]R;6%T=&5R+G!H<"<["@HO*BH*("H@5&AE(%1E>'1?<F535%]&;W)M
M871T97)?:'1M;#HZ(&-L87-S(&ES('1H92!(5$U,(&9O<FUA='1E<BX*("H*
M("H@)$AO<F1E.B!F<F%M97=O<FLO5&5X=%]R95-4+W)E4U0O1F]R;6%T=&5R
M+VAT;6PN<&AP+'8@,2XV+C$R+C4@,C`P-B\P,2\P,2`R,3HR.#HS.2!J86X@
M17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!*87-O;B!-+B!&96QI
M8V4@/&IF96QI8V5`8W)O;F]S>7,N8V]M/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@
M0&%U=&AO<B`@2F%S;VX@32X@1F5L:6-E(#QJ9F5L:6-E0&-R;VYO<WES+F-O
M;3X*("H@0'!A8VMA9V4@5&5X=%]R95-4"B`J+PIC;&%S<R!497AT7W)E4U1?
M1F]R;6%T=&5R7VAT;6P@97AT96YD<R!497AT7W)E4U1?1F]R;6%T=&5R('L*
M"B`@("`O*BH*("`@("`J(%1H92!C=7)R96YT(&]U='!U="!C:&%R<V5T+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V-H
M87)S970@/2!N=6QL.PH*("`@(&9U;F-T:6]N(&9O<FUA="@F)&YO9&4L("1C
M:&%R<V5T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1C:&%R
M<V5T*2D@>PH@("`@("`@("`@("`D8VAA<G-E="`]("1T:&ES+3Y?8VAA<G-E
M=#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<U]S=')I;F<H)&YO9&4I*2![
M"B`@("`@("`@("`@(&EF("AI<W-E="@D8VAA<G-E="DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!`:'1M;'-P96-I86QC:&%R<R@D;F]D92P@14Y47U%5
M3U1%4RP@)&-H87)S970I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&AT;6QS<&5C:6%L8VAA<G,H)&YO9&4L($5.5%]1
M54]415,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=VET
M8V@@*"1N;V1E+3Y?='EP92D@>PH@("`@("`@(&-A<V4@)T1O8W5M96YT)SH*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I.PH*
M("`@("`@("!C87-E("=(96%D:6YG)SH*("`@("`@("`@("`@)&QE=F5L(#T@
M)&YO9&4M/F=E=%!R;W!E<G1Y*"=L979E;"<I.PH@("`@("`@("`@("!R971U
M<FX@)SQH)R`N("1L979E;"`N("<^)R`N("1T:&ES+3Y?8VAI;&1R96XH)&YO
M9&4I("X@)SPO:"<@+@H@("`@("`@("`@("`@("`@)&QE=F5L("X@)SXG.PH*
M("`@("`@("!C87-E("=,:6YK)SH*("`@("`@("`@("`@<F5T=7)N("<\82!H
M<F5F/2(G("X*("`@("`@("`@("`@("`@("AI<W-E="@D8VAA<G-E="D@/PH@
M("`@("`@("`@("`@("`@($!H=&UL<W!E8VEA;&-H87)S*"1N;V1E+3YG9710
M<F]P97)T>2@G:')E9B<I+"!%3E1?455/5$53+"`D8VAA<G-E="D@.@H@("`@
M("`@("`@("`@("`@(&AT;6QS<&5C:6%L8VAA<G,H)&YO9&4M/F=E=%!R;W!E
M<G1Y*"=H<F5F)RDL($5.5%]154]415,I*2`N"B`@("`@("`@("`@("`@("`G
M(CXG("X*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAI;&1R96XH)&YO9&4I
M("X@)SPO83XG.PH*("`@("`@("!C87-E("=,:71E<F%L+4)L;V-K)SH*("`@
M("`@("`@("`@;&ES="@D=&5X="D@/2`D;F]D92T^7V-H:6QD<F5N.PH@("`@
M("`@("`@("!R971U<FX@)SQP<F4^)R`N("AI<W-E="@D8VAA<G-E="D@/PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`:'1M;'-P96-I86QC:&%R
M<R@D=&5X="P@14Y47U%53U1%4RP@)&-H87)S970I(#H*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:'1M;'-P96-I86QC:&%R<R@D=&5X="P@14Y4
M7U%53U1%4RDI("X@)SPO<')E/B<["@H@("`@("`@(&-A<V4@)U!A<F%G<F%P
M:"<Z"B`@("`@("`@("`@(')E='5R;B`B/'`^(B`N("1T:&ES+3Y?8VAI;&1R
M96XH)&YO9&4I("X@(CPO<#XB.PH*("`@("`@("!C87-E("=);G1E<G!R971E
M9"U497AT)SH*("`@("`@("`@("`@<W=I=&-H("@D;F]D92T^9V5T4')O<&5R
M='DH)W)O;&4G*2D@>PH@("`@("`@("`@("!C87-E("=E;7!H87-I<R<Z"B`@
M("`@("`@("`@("`@("!R971U<FX@)SQE;3XG("X@)'1H:7,M/E]C:&EL9')E
M;B@D;F]D92D@+B`G/"]E;3XG.PH*("`@("`@("`@("`@8V%S92`G;&ET97)A
M;"<Z"B`@("`@("`@("`@("`@("!R971U<FX@)SQT=#XG("X@)'1H:7,M/E]C
M:&EL9')E;B@D;F]D92D@+B`G/"]T=#XG.PH*("`@("`@("`@("`@8V%S92`G
M<W1R;VYG)SH*("`@("`@("`@("`@("`@(')E='5R;B`G/'-T<F]N9SXG("X@
M)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]S=')O;F<^)SL*"B`@("`@
M("`@("`@(&-A<V4@)W-U<&5R<V-R:7!T)SH*("`@("`@("`@("`@("`@(')E
M='5R;B`G/'-U<#XG("X@)'1H:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]S
M=7`^)SL*"B`@("`@("`@("`@(&-A<V4@)W-U8G-C<FEP="<Z"B`@("`@("`@
M("`@("`@("!R971U<FX@)SQS=6(^)R`N("1T:&ES+3Y?8VAI;&1R96XH)&YO
M9&4I("X@)SPO<W5B/B<["@H@("`@("`@("`@("!C87-E("=T:71L92UR969E
M<F5N8V4G.@H@("`@("`@("`@("`@("`@<F5T=7)N("<\8VET93XG("X@)'1H
M:7,M/E]C:&EL9')E;B@D;F]D92D@+B`G/"]C:71E/B<["@H@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@+R\@6%A8.B!)<W-U92!A('=A
M<FYI;F<N"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&EL9')E
M;B@D;F]D92D["B`@("`@("`@("`@('T*"B`@("`@("`@8V%S92`G4V5C=&EO
M;B<Z"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H:6QD<F5N*"1N;V1E
M*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7V-H:6QD<F5N*"8D
M;F]D92D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)R<["B`@("`@("`@9F]R
M96%C:"`H)&YO9&4M/E]C:&EL9')E;B!A<R`D8VAI;&0I('L*("`@("`@("`@
M("`@)')E<W5L="`N/2`D=&AI<RT^9F]R;6%T*"1C:&EL9"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]L:6(O1FEL92]01$8`````````````````````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S8@
M,#$W-3$T`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1BYP:'``
M````````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#(W
M,C`R-R`Q,#4Q-30S-#$S-B`P,C`S,38`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J($9I;&5?4$1&.CH*
M("H*("H@5&AE($9I;&5?4$1&.CH@8VQA<W,@<')O=FED97,@82!02%`M;VYL
M>2!I;7!L96UE;G1A=&EO;B!O9B!A(%!$1B!L:6)R87)Y+@H@*B!.;R!E>'1E
M<FYA;"!L:6)S(&]R(%!(4"!E>'1E;G-I;VYS(&%R92!R97%U:7)E9"X*("H*
M("H@0F%S960@;VX@=&AE($901$8@8VQA<W,@8GD@3VQI=FEE<B!0;&%T:&5Y
M("AH='1P.B\O=W=W+F9P9&8N;W)G*2X*("H*("H@0V]P>7)I9VAT(#(P,#,M
M,C`P-B!/;&EV:65R(%!L871H97D@/&]L:79I97)`9G!D9BYO<F<^"B`J($-O
M<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+T9I;&5?
M4$1&+U!$1BYP:'`L=B`Q+C$X+C$P+C$R(#(P,#8O,#$O,#$@,C$Z,C@Z,34@
M:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($]L:79I97(@4&QA=&AE>2`\;VQI
M=FEE<D!F<&1F+F]R9SX*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K
M;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@1FEL95]01$8*("HO"F-L87-S($9I
M;&5?4$1&('L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@<&%G92!N=6UB97(N
M"B`@("`@*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D
M7W!A9V4@/2`P.PH*("`@("\J*@H@("`@("H@0W5R<F5N="!O8FIE8W0@;G5M
M8F5R+@H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V
M87(@)%]N(#T@,CL*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(&]B:F5C="!O
M9F9S971S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1?;V9F<V5T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!"=69F
M97(@:&]L9&EN9R!I;BUM96UO<GD@4$1&+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V)U9F9E<B`]("<G.PH*("`@("\J
M*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!T:&4@<&%G97,N"B`@("`@*@H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]P86=E<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&1O8W5M96YT('-T871E
M+@H@("`@("H@("`P("T@:6YI=&EA;"!S=&%T90H@("`@("H@("`Q("T@9&]C
M=6UE;G0@;W!E;F5D"B`@("`@*B`@(#(@+2!P86=E(&]P96YE9`H@("`@("H@
M("`S("T@9&]C=6UE;G0@8VQO<V5D"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D7W-T871E(#T@,#L*"B`@("`O*BH*("`@
M("`J($9L86<@:6YD:6-A=&EN9R!I9B!01$8@9FEL92!I<R!T;R!B92!C;VUP
M<F5S<V5D(&]R(&YO="X*("`@("`J"B`@("`@*B!`=F%R(&)O;VQE86X*("`@
M("`J+PH@("`@=F%R("1?8V]M<')E<W,["@H@("`@+RHJ"B`@("`@*B!4:&4@
M9&5F875L="!P86=E(&]R:65N=&%T:6]N+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V1E9F%U;'1?;W)I96YT871I;VX[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@8W5R<F5N="!P86=E(&]R:65N=&%T:6]N
M+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7V-U<G)E;G1?;W)I96YT871I;VX["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!I
M;F1I8V%T:6YG(&]R:65N=&%T:6]N(&-H86YG97,N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]O<FEE;G1A=&EO;E]C:&%N
M9V5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-U<G)E;G0@=VED=&@@
M;V8@<&%G92!F;W)M870@:6X@<&]I;G1S+@H@("`@("H*("`@("`J($!V87(@
M9FQO870*("`@("`J+PH@("`@=F%R("1F=U!T.PH*("`@("\J*@H@("`@("H@
M0W5R<F5N="!H96EG:'0@;V8@<&%G92!F;W)M870@:6X@<&]I;G1S+@H@("`@
M("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1F:%!T.PH*
M("`@("\J*@H@("`@("H@0W5R<F5N="!W:61T:"!O9B!P86=E(&9O<FUA="!I
M;B!U<V5R('5N:71S+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J
M+PH@("`@=F%R("1F=SL*"B`@("`O*BH*("`@("`J($-U<G)E;G0@:&5I9VAT
M(&]F('!A9V4@9F]R;6%T(&EN('5S97(@=6YI=',N"B`@("`@*@H@("`@("H@
M0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)&9H.PH*("`@("\J*@H@("`@
M("H@0W5R<F5N="!W:61T:"!O9B!P86=E(&EN('!O:6YT<RX*("`@("`J"B`@
M("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D=U!T.PH*("`@("\J
M*@H@("`@("H@0W5R<F5N="!H96EG:'0@;V8@<&%G92!I;B!P;VEN=',N"B`@
M("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)&A0=#L*
M"B`@("`O*BH*("`@("`J($-U<G)E;G0@=VED=&@@;V8@<&%G92!I;B!U<V5R
M('5N:71S"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V
M87(@)'<["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&AE:6=H="!O9B!P86=E
M(&EN('5S97(@=6YI=',*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@
M*B\*("`@('9A<B`D:#L*"B`@("`O*BH*("`@("`J(%-C86QE(&9A8W1O<B`H
M;G5M8F5R(&]F('!O:6YT<R!I;B!U<V5R('5N:71S*2X*("`@("`J"B`@("`@
M*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7W-C86QE.PH*("`@("\J
M*@H@("`@("H@3&5F="!P86=E(&UA<F=I;B!S:7IE+@H@("`@("H*("`@("`J
M($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?;&5F=%]M87)G:6X["@H@
M("`@+RHJ"B`@("`@*B!4;W`@<&%G92!M87)G:6X@<VEZ92X*("`@("`J"B`@
M("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D7W1O<%]M87)G:6X[
M"@H@("`@+RHJ"B`@("`@*B!2:6=H="!P86=E(&UA<F=I;B!S:7IE+@H@("`@
M("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?<FEG:'1?
M;6%R9VEN.PH*("`@("\J*@H@("`@("H@0G)E86L@<&%G92!M87)G:6X@<VEZ
M92P@=&AE(&)O='1O;2!M87)G:6X@=VAI8V@@=')I9V=E<G,@82!P86=E(&)R
M96%K+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R
M("1?8G)E86M?;6%R9VEN.PH*("`@("\J*@H@("`@("H@0V5L;"!M87)G:6X@
M<VEZ92X*("`@("`J"B`@("`@*B!`=F%R(&9L;V%T"B`@("`@*B\*("`@('9A
M<B`D7V-E;&Q?;6%R9VEN.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@
M:&]R:7IO;G1A;"!P;W-I=&EO;B!F;W(@8V5L;"!P;W-I=&EO;FEN9RX*("`@
M("`J(%9A;'5E(&ES('-E="!I;B!U<V5R('5N:71S(&%N9"!I<R!C86QC=6QA
M=&5D(&9R;VT@=&AE('1O<"!L969T(&-O<FYE<@H@("`@("H@87,@;W)I9VEN
M+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1X
M.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@=F5R=&EC86P@<&]S:71I
M;VX@9F]R(&-E;&P@<&]S:71I;VYI;F<N"B`@("`@*B!686QU92!I<R!S970@
M:6X@=7-E<B!U;FET<R!A;F0@:7,@8V%L8W5L871E9"!F<F]M('1H92!T;W`@
M;&5F="!C;W)N97(*("`@("`J(&%S(&]R:6=I;BX*("`@("`J"B`@("`@*B!`
M=F%R(&9L;V%T"B`@("`@*B\*("`@('9A<B`D>3L*"B`@("`O*BH*("`@("`J
M(%1H92!H96EG:'0@;V8@=&AE(&QA<W0@8V5L;"!P<FEN=&5D+@H@("`@("H*
M("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?;&%S=%]H96EG
M:'0["@H@("`@+RHJ"B`@("`@*B!,:6YE('=I9'1H(&EN('5S97(@=6YI=',N
M"B`@("`@*@H@("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]L
M:6YE7W=I9'1H.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@<W1A;F1A
M<F0@9F]N="!N86UE<RX*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B\*("`@('9A<B`D7V-O<F5?9F]N=',@/2!A<G)A>2@G8V]U<FEE<B<@("`@
M("`]/B`G0V]U<FEE<B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V-O=7)I97)")R`@("`@/3X@)T-O=7)I97(M0F]L9"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V-O=7)I97)))R`@("`@/3X@)T-O=7)I97(M
M3V)L:7%U92<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O=7)I
M97)"22<@("`@/3X@)T-O=7)I97(M0F]L9$]B;&EQ=64G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=H96QV971I8V$G("`@(#T^("=(96QV971I
M8V$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=H96QV971I8V%"
M)R`@(#T^("=(96QV971I8V$M0F]L9"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)VAE;'9E=&EC84DG("`@/3X@)TAE;'9E=&EC82U/8FQI<75E
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:&5L=F5T:6-A0DDG
M("`]/B`G2&5L=F5T:6-A+4)O;&1/8FQI<75E)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=&EM97,G("`@("`@("`]/B`G5&EM97,M4F]M86XG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T:6UE<T(G("`@("`@
M(#T^("=4:6UE<RU";VQD)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G=&EM97-))R`@("`@("`]/B`G5&EM97,M271A;&EC)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G=&EM97-"22<@("`@("`]/B`G5&EM97,M
M0F]L9$ET86QI8R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W-Y
M;6)O;"<@("`@("`@/3X@)U-Y;6)O;"<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)WIA<&9D:6YG8F%T<R<@/3X@)UIA<&9$:6YG8F%T<R<I.PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@;V8@=7-E9"!F;VYT<RX*("`@("`J
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D7V9O;G1S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($%N(&%R<F%Y(&]F(&9O;G0@9FEL
M97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@
M)%]F;VYT7V9I;&5S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($%N(&%R
M<F%Y(&]F(&5N8V]D:6YG(&1I9F9E<F5N8V5S+@H@("`@("H*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1?9&EF9G,@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@06X@87)R87D@;V8@=7-E9"!I;6%G97,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]I;6%G97,@
M/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@06X@87)R87D@;V8@;&EN:W,@
M:6X@<&%G97,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)%]P86=E7VQI;FMS.PH*("`@("\J*@H@("`@("H@06X@87)R87D@
M;V8@:6YT97)N86P@;&EN:W,N"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@
M("`@("HO"B`@("!V87(@)%]L:6YK<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!#=7)R96YT(&9O;G0@9F%M:6QY+@H@("`@("H*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V9O;G1?9F%M:6QY(#T@)R<["@H@
M("`@+RHJ"B`@("`@*B!#=7)R96YT(&9O;G0@<W1Y;&4N"B`@("`@*@H@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9F]N=%]S='EL92`]
M("<G.PH*("`@("\J*@H@("`@("H@56YD97)L:6YI;F<@9FQA9RX*("`@("`J
M"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1?=6YD97)L
M:6YE(#T@9F%L<V4["@H@("`@+RHJ"B`@("`@*B!!;B!A<G)A>2!C;VYT86EN
M:6YG(&-U<G)E;G0@9F]N="!I;F9O+@H@("`@("H*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1?8W5R<F5N=%]F;VYT.PH*("`@("\J*@H@
M("`@("H@0W5R<F5N="!F;VYT('-I>F4@:6X@<&]I;G1S+@H@("`@("H*("`@
M("`J($!V87(@9FQO870*("`@("`J+PH@("`@=F%R("1?9F]N=%]S:7IE7W!T
M(#T@,3(["@H@("`@+RHJ"B`@("`@*B!#=7)R96YT(&9O;G0@<VEZ92!I;B!U
M<V5R('5N:71S+@H@("`@("H*("`@("`J($!V87(@9FQO870*("`@("`J+PH@
M("`@=F%R("1?9F]N=%]S:7IE.PH*("`@("\J*@H@("`@("H@0V]M;6%N9',@
M9F]R(&9I;&QI;F<@8V]L;W(N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?9FEL;%]C;VQO<B`]("<P(&<G.PH*("`@("\J
M*@H@("`@("H@0V]M;6%N9',@9F]R(&1R87=I;F<@8V]L;W(N"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?9')A=U]C;VQO
M<B`]("<P($<G.PH*("`@("\J*@H@("`@("H@5V]R9"!S<&%C:6YG+@H@("`@
M("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)%]W;W)D
M7W-P86-I;F<@/2`P.PH*("`@("\J*@H@("`@("H@075T;VUA=&EC('!A9V4@
M8G)E86MI;F<N"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N"B`@("`@*B\*
M("`@('9A<B`D7V%U=&]?<&%G95]B<F5A:SL*"B`@("`O*BH*("`@("`J(%1H
M<F5S:&]L9"!U<V5D('1O('1R:6=G97(@<&%G92!B<F5A:W,N"B`@("`@*@H@
M("`@("H@0'9A<B!F;&]A=`H@("`@("HO"B`@("!V87(@)%]P86=E7V)R96%K
M7W1R:6=G97(["@H@("`@+RHJ"B`@("`@*B!&;&%G('-E="!W:&5N('!R;V-E
M<W-I;F<@9F]O=&5R+@H@("`@("H*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("HO"B`@("!V87(@)%]I;E]F;V]T97(@/2!F86QS93L*"B`@("`O*BH*("`@
M("`J(%IO;VT@9&ES<&QA>2!M;V1E+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B\*("`@('9A<B`D7WIO;VU?;6]D93L*"B`@("`O*BH*("`@
M("`J($QA>6]U="!D:7-P;&%Y(&UO9&4N"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?;&%Y;W5T7VUO9&4["@H@("`@+RHJ
M"B`@("`@*B!!;B!A<G)A>2!C;VYT86EN:6YG('1H92!D;V-U;65N="!I;F9O
M+"!C;VYS:7-T:6YG(&]F.@H@("`@("H@("`M('1I=&QE"B`@("`@*B`@("T@
M<W5B:F5C=`H@("`@("H@("`M(&%U=&AO<@H@("`@("H@("`M(&ME>7=O<F1S
M"B`@("`@*B`@("T@8W)E871O<@H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1?:6YF;R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@
M("`@*B!!;&EA<R!F;W(@=&]T86P@;G5M8F5R(&]F('!A9V5S+@H@("`@("H*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V%L:6%S7VYB
M7W!A9V5S(#T@)WMN8GTG.PH*("`@("\J*@H@("`@("H@071T96UP=',@=&\@
M<F5T=7)N(&$@8V]N<F5T92!01$8@:6YS=&%N8V4N($ET(&%L;&]W<R!T;R!S
M970@=7`@=&AE('!A9V4*("`@("`J(&9O<FUA="P@=&AE(&]R:65N=&%T:6]N
M(&%N9"!T:&4@=6YI=',@;V8@;65A<W5R96UE;G0@=7-E9"!I;B!A;&P@=&AE
M"B`@("`@*B!M971H;V1S("AE>&-E<'0@9F]R('1H92!F;VYT('-I>F5S*2X*
M("`@("`J"B`@("`@*B!%>&%M<&QE.CQP<F4^"B`@("`@*B`D<&1F(#T@)D9I
M;&5?4$1&.CIF86-T;W)Y*&%R<F%Y*"=O<FEE;G1A=&EO;B<@/3X@)U`G+`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=6YI="<@
M/3X@)VUM)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V9O<FUA="<@/3X@)T$T)RDI.SPO<')E/@H@("`@("H*("`@("`J($!P
M87)A;2!A<G)A>2`D<&%R86US("!!(&AA<V@@=VET:"!P87)A;65T97)S(&9O
M<B!T:&4@8W)E871E9"!01$8@;V)J96-T+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(%!O<W-I8FQE('!A<F%M971E<G,@87)E.@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@(&]R:65N=&%T:6]N("T@1&5F875L="!P86=E
M(&]R:65N=&%T:6]N+B!0;W-S:6)L90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@('9A;'5E<R!A<F4@*&-A<V4@:6YS96YS:71I=F4I.@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(#QP<F4^"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`M(%`@;W(@4&]R=')A:70@*&1E9F%U;'0I"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M($P@;W(@3&%N9'-C87!E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@/"]P<F4^"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@=6YI="`M(%5S97(@;65A<W5R92!U;FET<RX@
M4&]S<VEB;&4@=F%L=65S('9A;'5E<PH@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&%R93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`\<')E
M/@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!P=#H@<&]I;G0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@;6TZ(&UI;&QI;65T
M97(@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M
M(&-M.B!C96YT:6UE=&5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`M(&EN.B!I;F-H"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@/"]P
M<F4^"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@02!P;VEN="!E<75A
M;',@,2\W,B!O9B!I;F-H+"!T:&%T(&ES('1O('-A>2!A8F]U=`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@(#`N,S4@;6T@*&%N(&EN8V@@8F5I;F<@
M,BXU-"!C;2DN(%1H:7,@:7,@82!V97)Y"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@8V]M;6]N('5N:70@:6X@='EP;V=R87!H>3L@9F]N="!S:7IE
M<R!A<F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!E>'!R97-S960@
M:6X@=&AA="!U;FET+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&9O
M<FUA="`M(%1H92!F;W)M870@=7-E9"!F;W(@<&%G97,N($ET(&-A;B!B90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5I=&AE<B!O;F4@;V8@=&AE
M(&9O;&QO=VEN9R!V86QU97,@*&-A<V4*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@/'!R93X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@
M03,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@030@*&1E9F%U
M;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($$U"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M($QE='1E<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!,96=A;`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(#PO<')E/@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@(&]R(&$@8W5S=&]M(&9O<FUA="!I;B!T:&4@9F]R;2!O9B!A('1W;RUE
M;&5M96YT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@87)R87D@8V]N
M=&%I;FEN9R!T:&4@=VED=&@@86YD('1H92!H96EG:'0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`H97AP<F5S<V5D(&EN('1H92!U;FET(&=I=F5N
M(&)Y('1H92!U;FET"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<&%R
M86UE=&5R*2X*("`@("`J($!P87)A;2!S=')I;F<@)&-L87-S("!4:&4@8V]N
M8W)E=&4@8VQA<W,@;F%M92!T;R!R971U<FX@86X@:6YS=&%N8V4@;V8N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@1&5F875L=',@=&\@1FEL95]0
M1$8N"B`@("`@*B\*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1P87)A;7,@/2!A
M<G)A>2@I+"`D8VQA<W,@/2`G1FEL95]01$8G*0H@("`@>PH@("`@("`@("\J
M($-H96-K(&9O<B!02%`@;&]C86QE+7)E;&%T960@8G5G+B`J+PH@("`@("`@
M(&EF("@Q+C$@/3T@,2D@>PH@("`@("`@("`@("!R971U<FX@1FEL95]01$8Z
M.G)A:7-E17)R;W(H)T1O(&YO="!A;'1E<B!T:&4@;&]C86QE(&)E9F]R92!I
M;F-L=61I;F<@=&AE(&-L87-S(&9I;&4N)RD["B`@("`@("`@?0H*("`@("`@
M("`O*B!$969A=6QT('!A<F%M971E<G,N("HO"B`@("`@("`@)&1E9F%U;'1S
M(#T@87)R87DH)V]R:65N=&%T:6]N)R`]/B`G4"<L("=U;FET)R`]/B`G;6TG
M+"`G9F]R;6%T)R`]/B`G030G*3L*"B`@("`@("`@+RH@0F%C:W=A<F0@8V]M
M<&%T:6)I;&ET>2!W:71H(&]L9"!M971H;V0@<VEG;F%T=7)E+B`J+PH@("`@
M("`@("\J(%-H;W5L9"!B92!R96UO=F5D(&$@9F5W('9E<G-I;VYS(&QA=&5R
M+B`J+PH@("`@("`@(&EF("@A:7-?87)R87DH)'!A<F%M<RDI('L*("`@("`@
M("`@("`@)&-L87-S(#T@)T9I;&5?4$1&)SL*("`@("`@("`@("`@)'!A<F%M
M<R`]("1D969A=6QT<SL*("`@("`@("`@("`@)&YA;65S(#T@87)R87E?:V5Y
M<R@D9&5F875L=',I.PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!F
M=6YC7VYU;5]A<F=S*"D[("1I*RLI('L*("`@("`@("`@("`@("`@("1P87)A
M;7-;)&YA;65S6R1I75T@/2!F=6YC7V=E=%]A<F<H)&DI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A<F%M<R`](&%R
M<F%Y7VUE<F=E*"1D969A=6QT<RP@)'!A<F%M<RD["B`@("`@("`@?0H*("`@
M("`@("`O*B!#<F5A=&4@=&AE(%!$1B!O8FIE8W0N("HO"B`@("`@("`@)'!D
M9B`]("9N97<@)&-L87-S*"D["@H@("`@("`@("\J(%-C86QE(&9A8W1O<BX@
M*B\*("`@("`@("!I9B`H)'!A<F%M<ULG=6YI="==(#T]("=P="<I('L*("`@
M("`@("`@("`@)'!D9BT^7W-C86QE(#T@,3L*("`@("`@("!](&5L<V5I9B`H
M)'!A<F%M<ULG=6YI="==(#T]("=M;2<I('L*("`@("`@("`@("`@)'!D9BT^
M7W-C86QE(#T@-S(@+R`R-2XT.PH@("`@("`@('T@96QS96EF("@D<&%R86US
M6R=U;FET)UT@/3T@)V-M)RD@>PH@("`@("`@("`@("`D<&1F+3Y?<V-A;&4@
M/2`W,B`O(#(N-30["B`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;)W5N:70G
M72`]/2`G:6XG*2!["B`@("`@("`@("`@("1P9&8M/E]S8V%L92`](#<R.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!&:6QE7U!$1CHZ
M<F%I<V5%<G)O<BAS<')I;G1F*"=);F-O<G)E8W0@=6YI=',Z("5S)RP@)'!A
M<F%M<ULG=6YI="==*2D["B`@("`@("`@?0H@("`@("`@("\J(%!A9V4@9F]R
M;6%T+B`J+PH@("`@("`@(&EF("AI<U]S=')I;F<H)'!A<F%M<ULG9F]R;6%T
M)UTI*2!["B`@("`@("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@<W1R=&]L
M;W=E<B@D<&%R86US6R=F;W)M870G72D["B`@("`@("`@("`@(&EF("@D<&%R
M86US6R=F;W)M870G72`]/2`G83,G*2!["B`@("`@("`@("`@("`@("`D<&%R
M86US6R=F;W)M870G72`](&%R<F%Y*#@T,2XX.2P@,3$Y,"XU-2D["B`@("`@
M("`@("`@('T@96QS96EF("@D<&%R86US6R=F;W)M870G72`]/2`G830G*2![
M"B`@("`@("`@("`@("`@("`D<&%R86US6R=F;W)M870G72`](&%R<F%Y*#4Y
M-2XR."P@.#0Q+C@Y*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7-;
M)V9O<FUA="==(#T]("=A-2<I('L*("`@("`@("`@("`@("`@("1P87)A;7-;
M)V9O<FUA="==(#T@87)R87DH-#(P+CDT+"`U.34N,C@I.PH@("`@("`@("`@
M("!](&5L<V5I9B`H)'!A<F%M<ULG9F]R;6%T)UT@/3T@)VQE='1E<B<I('L*
M("`@("`@("`@("`@("`@("1P87)A;7-;)V9O<FUA="==(#T@87)R87DH-C$R
M+"`W.3(I.PH@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M<ULG9F]R;6%T
M)UT@/3T@)VQE9V%L)RD@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULG9F]R
M;6%T)UT@/2!A<G)A>2@V,3(L(#$P,#@I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N($9I;&5?4$1&.CIR86ES945R<F]R
M*'-P<FEN=&8H)U5N:VYO=VX@<&%G92!F;W)M870Z("5S)RP@)'!A<F%M<ULG
M9F]R;6%T)UTI*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<&1F+3YF
M=U!T(#T@)'!A<F%M<ULG9F]R;6%T)UU;,%T["B`@("`@("`@("`@("1P9&8M
M/F9H4'0@/2`D<&%R86US6R=F;W)M870G75LQ73L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D<&1F+3YF=U!T(#T@)'!A<F%M<ULG9F]R;6%T)UU;
M,%T@*B`D<&1F+3Y?<V-A;&4["B`@("`@("`@("`@("1P9&8M/F9H4'0@/2`D
M<&%R86US6R=F;W)M870G75LQ72`J("1P9&8M/E]S8V%L93L*("`@("`@("!]
M"B`@("`@("`@)'!D9BT^9G<@/2`D<&1F+3YF=U!T("\@)'!D9BT^7W-C86QE
M.PH@("`@("`@("1P9&8M/F9H(#T@)'!D9BT^9FA0="`O("1P9&8M/E]S8V%L
M93L*"B`@("`@("`@+RH@4&%G92!O<FEE;G1A=&EO;BX@*B\*("`@("`@("`D
M<&%R86US6R=O<FEE;G1A=&EO;B==(#T@<W1R=&]L;W=E<B@D<&%R86US6R=O
M<FEE;G1A=&EO;B==*3L*("`@("`@("!I9B`H)'!A<F%M<ULG;W)I96YT871I
M;VXG72`]/2`G<"<@?'P@)'!A<F%M<ULG;W)I96YT871I;VXG72`]/2`G<&]R
M=')A:70G*2!["B`@("`@("`@("`@("1P9&8M/E]D969A=6QT7V]R:65N=&%T
M:6]N(#T@)U`G.PH@("`@("`@("`@("`D<&1F+3YW4'0@/2`D<&1F+3YF=U!T
M.PH@("`@("`@("`@("`D<&1F+3YH4'0@/2`D<&1F+3YF:%!T.PH@("`@("`@
M('T@96QS96EF("@D<&%R86US6R=O<FEE;G1A=&EO;B==(#T]("=L)R!\?"`D
M<&%R86US6R=O<FEE;G1A=&EO;B==(#T]("=L86YD<V-A<&4G*2!["B`@("`@
M("`@("`@("1P9&8M/E]D969A=6QT7V]R:65N=&%T:6]N(#T@)TPG.PH@("`@
M("`@("`@("`D<&1F+3YW4'0@/2`D<&1F+3YF:%!T.PH@("`@("`@("`@("`D
M<&1F+3YH4'0@/2`D<&1F+3YF=U!T.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!&:6QE7U!$1CHZ<F%I<V5%<G)O<BAS<')I;G1F*"=)
M;F-O<G)E8W0@;W)I96YT871I;VXZ("5S)RP@)'!A<F%M<ULG;W)I96YT871I
M;VXG72DI.PH@("`@("`@('T*("`@("`@("`D<&1F+3Y?8W5R<F5N=%]O<FEE
M;G1A=&EO;B`]("1P9&8M/E]D969A=6QT7V]R:65N=&%T:6]N.PH@("`@("`@
M("1P9&8M/G<@/2`D<&1F+3YW4'0@+R`D<&1F+3Y?<V-A;&4["B`@("`@("`@
M)'!D9BT^:"`]("1P9&8M/FA0="`O("1P9&8M/E]S8V%L93L*"B`@("`@("`@
M+RH@4&%G92!M87)G:6YS("@Q(&-M*2`J+PH@("`@("`@("1M87)G:6X@/2`R
M."XS-2`O("1P9&8M/E]S8V%L93L*("`@("`@("`D<&1F+3YS971-87)G:6YS
M*"1M87)G:6XL("1M87)G:6XI.PH*("`@("`@("`O*B!);G1E<FEO<B!C96QL
M(&UA<F=I;B`H,2!M;2D@*B\*("`@("`@("`D<&1F+3Y?8V5L;%]M87)G:6X@
M/2`D;6%R9VEN("\@,3`["@H@("`@("`@("\J($QI;F4@=VED=&@@*#`N,B!M
M;2D@*B\*("`@("`@("`D<&1F+3Y?;&EN95]W:61T:"`]("XU-C<@+R`D<&1F
M+3Y?<V-A;&4["@H@("`@("`@("\J($%U=&]M871I8R!P86=E(&)R96%K("HO
M"B`@("`@("`@)'!D9BT^<V5T075T;U!A9V5"<F5A:RAT<G5E+"`R("H@)&UA
M<F=I;BD["@H@("`@("`@("\J($9U;&P@=VED=&@@9&ES<&QA>2!M;V1E("HO
M"B`@("`@("`@)'!D9BT^<V5T1&ES<&QA>4UO9&4H)V9U;&QW:61T:"<I.PH*
M("`@("`@("`O*B!#;VUP<F5S<VEO;B`J+PH@("`@("`@("1P9&8M/G-E=$-O
M;7!R97-S:6]N*'1R=64I.PH*("`@("`@("!R971U<FX@)'!D9CL*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@82!014%27T5R<F]R(&]B:F5C="X@
M5W)A<',@87)O=6YD(%!%05(Z.G)A:7-E17)R;W(H*2!T;PH@("`@("H@879O
M:60@:&%V:6YG('1O(&EN8VQU9&4@4$5!4BYP:'`@=6YL97-S(&%N(&5R<F]R
M(&]C8W5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&5R<F]R("!4
M:&4@97)R;W(@;65S<V%G92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C
M="!014%27T5R<F]R"B`@("`@*B\*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H
M)&5R<F]R*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PH@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"1E<G)O<BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!L969T+"!T;W`@86YD
M(')I9VAT(&UA<F=I;G,N($)Y(&1E9F%U;'0L('1H97D@97%U86P*("`@("`J
M(#$@8VTN("!#86QL('1H:7,@;65T:&]D('1O(&-H86YG92!T:&5M+@H@("`@
M("H*("`@("`J($!P87)A;2!F;&]A="`D;&5F="`@($QE9G0@;6%R9VEN+@H@
M("`@("H@0'!A<F%M(&9L;V%T("1T;W`@("`@5&]P(&UA<F=I;BX*("`@("`J
M($!P87)A;2!F;&]A="`D<FEG:'0@(%)I9VAT(&UA<F=I;BX@268@;F]T('-P
M96-I9FEE9"!D969A=6QT('1O('1H92!V86QU90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@;V8@=&AE(&QE9G0@;VYE+@H@("`@("H*("`@("`J($!S
M964@1FEL95]01$8Z.G-E=$%U=&]086=E0G)E86L*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$QE9G1-87)G:6X*("`@("`J($!S964@1FEL95]01$8Z.G-E
M=%)I9VAT36%R9VEN"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9714;W!-87)G
M:6X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T36%R9VEN<R@D;&5F="P@)'1O
M<"P@)')I9VAT(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!3970@;&5F="!A
M;F0@=&]P(&UA<F=I;G,N("HO"B`@("`@("`@)'1H:7,M/E]L969T7VUA<F=I
M;B`@/2`D;&5F=#L*("`@("`@("`D=&AI<RT^7W1O<%]M87)G:6X@("`]("1T
M;W`["B`@("`@("`@+RH@268@;F\@<FEG:'0@;6%R9VEN('-E="!D969A=6QT
M('1O('-A;64@87,@;&5F="X@*B\*("`@("`@("`D=&AI<RT^7W)I9VAT7VUA
M<F=I;B`]("AI<U]N=6QL*"1R:6=H="D@/R`D;&5F="`Z("1R:6=H="D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!L969T(&UA<F=I;BX@
M5&AE(&UE=&AO9"!C86X@8F4@8V%L;&5D(&)E9F]R92!C<F5A=&EN9R!T:&4*
M("`@("`J(&9I<G-T('!A9V4N"B`@("`@*B!)9B!T:&4@8W5R<F5N="!A8G-C
M:7-S82!G971S(&]U="!O9B!P86=E+"!I="!I<R!B<F]U9VAT(&)A8VL@=&\@
M=&AE"B`@("`@*B!M87)G:6XN"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T
M("1M87)G:6X@("!4:&4@;6%R9VEN+@H@("`@("H*("`@("`J($!S964@1FEL
M95]01$8Z.G-E=$%U=&]086=E0G)E86L*("`@("`J($!S964@1FEL95]01$8Z
M.G-E=$UA<F=I;G,*("`@("`J($!S964@1FEL95]01$8Z.G-E=%)I9VAT36%R
M9VEN"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS9714;W!-87)G:6X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3&5F=$UA<F=I;B@D;6%R9VEN*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?;&5F=%]M87)G:6X@/2`D;6%R9VEN.PH@("`@("`@
M("\J($EF('1H97)E(&ES(&$@8W5R<F5N="!P86=E(&%N9"!T:&4@8W5R<F5N
M="!8('!O<VET:6]N(&ES(&QE<W,@=&AA;@H@("`@("`@("`J(&UA<F=I;B!S
M970@=&AE(%@@<&]S:71I;VX@=&\@=&AE(&UA<F=I;B!V86QU92X@*B\*("`@
M("`@("!I9B`H)'1H:7,M/E]P86=E(#X@,"`F)B`D=&AI<RT^>"`\("1M87)G
M:6XI('L*("`@("`@("`@("`@)'1H:7,M/G@@/2`D;6%R9VEN.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE('1O<"!M87)G
M:6XN(%1H92!M971H;V0@8V%N(&)E(&-A;&QE9"!B969O<F4@8W)E871I;F<@
M=&AE"B`@("`@*B!F:7)S="!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!F
M;&]A="`D;6%R9VEN("!4:&4@;6%R9VEN+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S9714;W!-87)G:6XH)&UA<F=I;BD*("`@('L*("`@("`@("`D=&AI<RT^
M7W1O<%]M87)G:6X@/2`D;6%R9VEN.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5F:6YE<R!T:&4@<FEG:'0@;6%R9VEN+B!4:&4@;65T:&]D(&-A;B!B92!C
M86QL960@8F5F;W)E(&-R96%T:6YG('1H90H@("`@("H@9FER<W0@<&%G92X*
M("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)&UA<F=I;B`@5&AE(&UA<F=I
M;BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4FEG:'1-87)G:6XH)&UA<F=I
M;BD*("`@('L*("`@("`@("`D=&AI<RT^7W)I9VAT7VUA<F=I;B`]("1M87)G
M:6X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S
M('1H92!A=71O;6%T:6,@<&%G92!B<F5A:VEN9R!M;V1E+B!7:&5N(&5N86)L
M:6YG+`H@("`@("H@=&AE('-E8V]N9"!P87)A;65T97(@:7,@=&AE(&1I<W1A
M;F-E(&9R;VT@=&AE(&)O='1O;2!O9B!T:&4@<&%G92!T:&%T"B`@("`@*B!D
M969I;F5S('1H92!T<FEG9V5R:6YG(&QI;6ET+B!">2!D969A=6QT+"!T:&4@
M;6]D92!I<R!O;B!A;F0@=&AE(&UA<F=I;@H@("`@("H@:7,@,B!C;2X*("`@
M("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B!A=71O("`@0F]O;&5A;B!I;F1I
M8V%T:6YG(&EF(&UO9&4@<VAO=6QD(&)E(&]N(&]R(&]F9BX*("`@("`J($!P
M87)A;2!F;&]A="`D;6%R9VEN("!$:7-T86YC92!F<F]M('1H92!B;W1T;VT@
M;V8@=&AE('!A9V4N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$%U=&]086=E
M0G)E86LH)&%U=&\L("1M87)G:6X@/2`P*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?875T;U]P86=E7V)R96%K("`@(#T@)&%U=&\["B`@("`@("`@)'1H:7,M
M/E]B<F5A:U]M87)G:6X@("`@("`@/2`D;6%R9VEN.PH@("`@("`@("1T:&ES
M+3Y?<&%G95]B<F5A:U]T<FEG9V5R(#T@)'1H:7,M/F@@+2`D;6%R9VEN.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5F:6YE<R!T:&4@=V%Y('1H92!D;V-U
M;65N="!I<R!T;R!B92!D:7-P;&%Y960@8GD@=&AE('9I97=E<BX@5&AE('IO
M;VT*("`@("`J(&QE=F5L(&-A;B!B92!S970Z('!A9V5S(&-A;B!B92!D:7-P
M;&%Y960@96YT:7)E;'D@;VX@<V-R965N+"!O8V-U<'D@=&AE"B`@("`@*B!F
M=6QL('=I9'1H(&]F('1H92!W:6YD;W<L('5S92!R96%L('-I>F4L(&)E('-C
M86QE9"!B>2!A('-P96-I9FEC"B`@("`@*B!Z;V]M:6YG(&9A8W1O<B!O<B!U
M<V4@=FEE=V5R(&1E9F%U;'0@*&-O;F9I9W5R960@:6X@=&AE(%!R969E<F5N
M8V5S"B`@("`@*B!M96YU(&]F($%C<F]B870I+B!4:&4@<&%G92!L87EO=70@
M8V%N(&)E('-P96-I9FEE9"!T;V\Z('-I;F=L92!A="!O;F-E+`H@("`@("H@
M8V]N=&EN=6]U<R!D:7-P;&%Y+"!T=V\@8V]L=6UN<R!O<B!V:65W97(@9&5F
M875L="X*("`@("`J($)Y(&1E9F%U;'0L(&1O8W5M96YT<R!U<V4@=&AE(&9U
M;&P@=VED=&@@;6]D92!W:71H(&-O;G1I;G5O=7,@9&ES<&QA>2X*("`@("`J
M"B`@("`@*B!`<&%R86T@;6EX960@)'IO;VT@("`@("`@("`@("`@5&AE('IO
M;VT@=&\@=7-E+B!)="!C86X@8F4@;VYE(&]F('1H90H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&9O;&QO=VEN9R!S=')I;F<@=F%L
M=65S.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!F=6QL<&%G93H@96YT:7)E('!A9V4@;VX@<V-R965N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`M(&9U;&QW:61T:#H@;6%X
M:6UU;2!W:61T:"!O9B!W:6YD;W<*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("T@<F5A;#H@=7-E<R!R96%L('-I>F4@*#$P,"4@
M>F]O;2D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("T@9&5F875L=#H@=7-E<R!V:65W97(@9&5F875L="!M;V1E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;W(@82!N=6UB97(@:6YD
M:6-A=&EN9R!T:&4@>F]O;6EN9R!F86-T;W(N"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&QA>6]U="`@5&AE('!A9V4@;&%Y;W5T+B!0;W-S:6)L92!V86QU97,@
M87)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!S:6YG;&4Z
M(&]N92!P86=E(&%T(&]N8V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("T@8V]N=&EN=6]U<SH@<&%G97,@:6X@8V]N=&EN=6]U<VQY"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M('1W;SH@='=O('!A9V5S(&]N
M('1W;R!C;VQU;6YS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M
M(&1E9F%U;'0Z('5S97,@=FEE=V5R(&1E9F%U;'0@;6]D90H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@1&5F875L="!V86QU92!I<R!C;VYT:6YU
M;W5S+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971$:7-P;&%Y36]D92@D>F]O
M;2P@)&QA>6]U="`]("=C;VYT:6YU;W5S)RD*("`@('L*("`@("`@("`D>F]O
M;2`]('-T<G1O;&]W97(H)'IO;VTI.PH@("`@("`@(&EF("@D>F]O;2`]/2`G
M9G5L;'!A9V4G('Q\("1Z;V]M(#T]("=F=6QL=VED=&@G('Q\("1Z;V]M(#T]
M("=R96%L)PH@("`@("`@("`@("!\?"`D>F]O;2`]/2`G9&5F875L="<@?'P@
M(6ES7W-T<FEN9R@D>F]O;2DI('L*("`@("`@("`@("`@)'1H:7,M/E]Z;V]M
M7VUO9&4@/2`D>F]O;3L*("`@("`@("!](&5L<V5I9B`H)'IO;VT@/3T@)WIO
M;VTG*2!["B`@("`@("`@("`@("1T:&ES+3Y?>F]O;5]M;V1E(#T@)&QA>6]U
M=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H<W!R:6YT9B@G26YC;W)R96-T('IO;VT@9&ES<&QA>2!M
M;V1E.B`E<R<L("1Z;V]M*2D["B`@("`@("`@?0H*("`@("`@("`D;&%Y;W5T
M(#T@<W1R=&]L;W=E<B@D;&%Y;W5T*3L*("`@("`@("!I9B`H)&QA>6]U="`]
M/2`G<VEN9VQE)R!\?"`D;&%Y;W5T(#T]("=C;VYT:6YU;W5S)R!\?"`D;&%Y
M;W5T(#T]("=T=V\G"B`@("`@("`@("`@('Q\("1L87EO=70@/3T@)V1E9F%U
M;'0G*2!["B`@("`@("`@("`@("1T:&ES+3Y?;&%Y;W5T7VUO9&4@/2`D;&%Y
M;W5T.PH@("`@("`@('T@96QS96EF("@D>F]O;2`A/2`G>F]O;2<I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)TEN
M8V]R<F5C="!L87EO=70@9&ES<&QA>2!M;V1E.B`E<R<L("1L87EO=70I*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!8W1I=F%T97,@;W(@
M9&5A8W1I=F%T97,@<&%G92!C;VUP<F5S<VEO;BX@5VAE;B!A8W1I=F%T960L
M('1H92!I;G1E<FYA;`H@("`@("H@<F5P<F5S96YT871I;VX@;V8@96%C:"!P
M86=E(&ES(&-O;7!R97-S960L('=H:6-H(&QE861S('1O(&$@8V]M<')E<W-I
M;VX*("`@("`J(')A=&EO(&]F(&%B;W5T(#(@9F]R('1H92!R97-U;'1I;F<@
M9&]C=6UE;G0N"B`@("`@*B!#;VUP<F5S<VEO;B!I<R!O;B!B>2!D969A=6QT
M+@H@("`@("H@3F]T93H@=&AE(%IL:6(@97AT96YS:6]N(&ES(')E<75I<F5D
M(&9O<B!T:&ES(&9E871U<F4N($EF(&YO="!P<F5S96YT+`H@("`@("H@8V]M
M<')E<W-I;VX@=VEL;"!B92!T=7)N960@;V9F+@H@("`@("H*("`@("`J($!P
M87)A;2!B;V]L96%N("1C;VUP<F5S<R`@0F]O;&5A;B!I;F1I8V%T:6YG(&EF
M(&-O;7!R97-S:6]N(&UU<W0@8F4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@96YA8FQE9"!O<B!N;W0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M('-E=$-O;7!R97-S:6]N*"1C;VUP<F5S<RD*("`@('L*("`@("`@("`O*B!)
M9B!N;R!G>F-O;7!R97-S(&9U;F-T:6]N(&ES(&%V86EL86)L92!T:&5N(&1E
M9F%U;'0@=&\@9F%L<V4N("HO"B`@("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]
M("AF=6YC=&EO;E]E>&ES=',H)V=Z8V]M<')E<W,G*2`_("1C;VUP<F5S<R`Z
M(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@:6YF;R!T
M;R!A(&1O8W5M96YT+B!0;W-S:6)L92!I;F9O('-E='1I;F=S(&%R93H*("`@
M("`J("`@+2!T:71L90H@("`@("H@("`M('-U8FIE8W0*("`@("`J("`@+2!A
M=71H;W(*("`@("`J("`@+2!K97EW;W)D<PH@("`@("H@("`M(&-R96%T;W(*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN9F\@("`@268@<&%S<V5D
M(&%S(&%N(&%R<F%Y('1H96X@=&AE(&-O;7!L971E(&AA<V@*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!C;VYT86EN:6YG('1H92!I;F9O('1O(&)E
M(&EN<V5R=&5D(&EN=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@9&]C=6UE;G0N($]T:&5R=VES92!T:&4@;F%M92!O9B!S971T:6YG('1O
M(&)E('-E="X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("!4:&4@=F%L
M=64@;V8@=&AE('-E='1I;F<N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$EN
M9F\H)&EN9F\L("1V86QU92`]("<G*0H@("`@>PH@("`@("`@(&EF("AI<U]A
M<G)A>2@D:6YF;RDI('L*("`@("`@("`@("`@)'1H:7,M/E]I;F9O(#T@)&EN
M9F\["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]I;F9O
M6R1I;F9O72`]("1V86QU93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!$969I;F5S(&%N(&%L:6%S(&9O<B!T:&4@=&]T86P@;G5M8F5R(&]F
M('!A9V5S+B!)="!W:6QL(&)E('-U8G-T:71U=&5D"B`@("`@*B!A<R!T:&4@
M9&]C=6UE;G0@:7,@8VQO<V5D+@H@("`@("H*("`@("`J($5X86UP;&4Z"B`@
M("`@*B!C;&%S<R!->5]&:6QE7U!$1B!E>'1E;F1S($9I;&5?4$1&('L*("`@
M("`J("`@("!F=6YC=&EO;B!F;V]T97(H*0H@("`@("H@("`@('L*("`@("`J
M("`@("`@("`@+R\@1V\@=&\@,2XU(&-M(&9R;VT@8F]T=&]M"B`@("`@*B`@
M("`@("`@("1T:&ES+3YS9719*"TQ-2D["B`@("`@*B`@("`@("`@("\O(%-E
M;&5C="!!<FEA;"!I=&%L:6,@.`H@("`@("H@("`@("`@("`D=&AI<RT^<V5T
M1F]N="@G07)I86PG+"`G22<L(#@I.PH@("`@("H@("`@("`@("`O+R!0<FEN
M="!C=7)R96YT(&%N9"!T;W1A;"!P86=E(&YU;6)E<G,*("`@("`J("`@("`@
M("`@)'1H:7,M/F-E;&PH,"P@,3`L("=086=E("<@+B`D=&AI<RT^9V5T4&%G
M94YO*"D@+B`G+WMN8GTG+"`P+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`P+"`G0R<I.PH@("`@("H@("`@('T*("`@("`J('T*("`@("`J("1P9&8@
M/2`F37E?1FEL95]01$8Z.F9A8W1O<GDH*3L*("`@("`J("1P9&8M/F%L:6%S
M3F)086=E<R@I.PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&%L:6%S
M("!4:&4@86QI87,N($1E9F%U;'0@=F%L=64Z('MN8GTN"B`@("`@*@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ9V5T4&%G94YO"B`@("`@*B!`<V5E($9I;&5?
M4$1&.CIF;V]T97(*("`@("`J+PH@("`@9G5N8W1I;VX@86QI87-.8E!A9V5S
M*"1A;&EA<R`]("=[;F)])RD*("`@('L*("`@("`@("`D=&AI<RT^7V%L:6%S
M7VYB7W!A9V5S(#T@)&%L:6%S.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI
M<R!M971H;V0@8F5G:6YS('1H92!G96YE<F%T:6]N(&]F('1H92!01$8@9&]C
M=6UE;G0[(&ET(&UU<W0@8F4*("`@("`J(&-A;&QE9"!B969O<F4@86YY(&]U
M='!U="!C;VUM86YD<RX@3F\@<&%G92!I<R!C<F5A=&5D(&)Y('1H:7,@;65T
M:&]D+`H@("`@("H@=&AE<F5F;W)E(&ET(&ES(&YE8V5S<V%R>2!T;R!C86QL
M($9I;&5?4$1&.CIA9&1086=E+@H@("`@("H*("`@("`J($!S964@1FEL95]0
M1$8Z.F%D9%!A9V4*("`@("`J($!S964@1FEL95]01$8Z.F-L;W-E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M8F5G:6Y$;V,H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1E<FUI;F%T97,@
M=&AE(%!$1B!D;V-U;65N="X@270@:7,@;F]T(&YE8V5S<V%R>2!T;R!C86QL
M('1H:7,@;65T:&]D"B`@("`@*B!E>'!L:6-I=&QY(&)E8V%U<V4@1FEL95]0
M1$8Z.F]U='!U="!D;V5S(&ET(&%U=&]M871I8V%L;'DN"B`@("`@*B!)9B!T
M:&4@9&]C=6UE;G0@8V]N=&%I;G,@;F\@<&%G92P@1FEL95]01$8Z.F%D9%!A
M9V4@:7,@8V%L;&5D('1O('!R979E;G0*("`@("`J(&9R;VT@9V5T=&EN9R!A
M;B!I;G9A;&ED(&1O8W5M96YT+@H@("`@("H*("`@("`J($!S964@1FEL95]0
M1$8Z.F]P96X*("`@("`J($!S964@1FEL95]01$8Z.F]U='!U=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@5&5R;6EN
M871E(&1O8W5M96YT("HO"B`@("`@("`@:68@*"1T:&ES+3Y?<&%G92`]/2`P
M*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1086=E*"D["B`@("`@("`@?0H@
M("`@("`@("\J(%!A9V4@9F]O=&5R("HO"B`@("`@("`@)'1H:7,M/E]I;E]F
M;V]T97(@/2!T<G5E.PH@("`@("`@("1T:&ES+3YF;V]T97(H*3L*("`@("`@
M("`D=&AI<RT^7VEN7V9O;W1E<B`](&9A;'-E.PH@("`@("`@("\J($-L;W-E
M('!A9V4@*B\*("`@("`@("`D=&AI<RT^7V5N9%!A9V4H*3L*("`@("`@("`O
M*B!#;&]S92!D;V-U;65N="`J+PH@("`@("`@("1T:&ES+3Y?96YD1&]C*"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@;F5W('!A9V4@=&\@=&AE
M(&1O8W5M96YT+B!)9B!A('!A9V4@:7,@86QR96%D>2!P<F5S96YT+"!T:&4*
M("`@("`J($9I;&5?4$1&.CIF;V]T97(@;65T:&]D(&ES(&-A;&QE9"!F:7)S
M="!T;R!O=71P=70@=&AE(&9O;W1E<BX@5&AE;B!T:&4*("`@("`J('!A9V4@
M:7,@861D960L('1H92!C=7)R96YT('!O<VET:6]N('-E="!T;R!T:&4@=&]P
M+6QE9G0@8V]R;F5R(&%C8V]R9&EN9PH@("`@("H@=&\@=&AE(&QE9G0@86YD
M('1O<"!M87)G:6YS+"!A;F0@1FEL95]01$8Z.FAE861E<B!I<R!C86QL960@
M=&\@9&ES<&QA>0H@("`@("H@=&AE(&AE861E<BX*("`@("`J(%1H92!F;VYT
M('=H:6-H('=A<R!S970@8F5F;W)E(&-A;&QI;F<@:7,@875T;VUA=&EC86QL
M>2!R97-T;W)E9"X@5&AE<F4*("`@("`J(&ES(&YO(&YE960@=&\@8V%L;"!&
M:6QE7U!$1CHZ<V5T1F]N="!A9V%I;B!I9B!Y;W4@=V%N="!T;R!C;VYT:6YU
M92!W:71H"B`@("`@*B!T:&4@<V%M92!F;VYT+B!4:&4@<V%M92!I<R!T<G5E
M(&9O<B!C;VQO<G,@86YD(&QI;F4@=VED=&@N"B`@("`@*B!4:&4@;W)I9VEN
M(&]F('1H92!C;V]R9&EN871E('-Y<W1E;2!I<R!A="!T:&4@=&]P+6QE9G0@
M8V]R;F5R(&%N9`H@("`@("H@:6YC<F5A<VEN9R!O<F1I;F%T97,@9V\@9&]W
M;G=A<F1S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&]R:65N=&%T
M:6]N("!086=E(&]R:65N=&%T:6]N+B!0;W-S:6)L92!V86QU97,*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<F4@*&-A<V4@:6YS96YS
M:71I=F4I.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!0(&]R(%!O<G1R86ET"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`M($P@;W(@3&%N9'-C87!E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@5&AE(&1E9F%U;'0@=F%L=64@:7,@=&AE(&]N92!P
M87-S960@=&\@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M4$1&"B`@("`@*B!`<V5E($9I;&5?4$1&.CIH96%D97(*("`@("`J($!S964@
M1FEL95]01$8Z.F9O;W1E<@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T36%R
M9VEN<PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1086=E*"1O<FEE;G1A=&EO
M;B`]("<G*0H@("`@>PH@("`@("`@("\J($9O<B!G;V]D(&UE87-U<F4@;6%K
M92!S=7)E('1H:7,@:7,@8V%L;&5D+B`J+PH@("`@("`@("1T:&ES+3Y?8F5G
M:6Y$;V,H*3L*"B`@("`@("`@+RH@4V%V92!S='EL92!S971T:6YG<R!S;R!T
M:&%T('1H97D@87)E(&YO="!O=F5R<FED9&5N(&)Y"B`@("`@("`@("H@:&5A
M9&5R*"DN("HO"B`@("`@("`@)&QW(#T@)'1H:7,M/E]L:6YE7W=I9'1H.PH@
M("`@("`@("1D8R`]("1T:&ES+3Y?9')A=U]C;VQO<CL*("`@("`@("`D9F,@
M/2`D=&AI<RT^7V9I;&Q?8V]L;W(["B`@("`@("`@:68@*"1T:&ES+3Y?<&%G
M92`^(#`I('L*("`@("`@("`@("`@+RH@4&%G92!F;V]T97(N("HO"B`@("`@
M("`@("`@("1T:&ES+3Y?:6Y?9F]O=&5R(#T@=')U93L*("`@("`@("`@("`@
M)'1H:7,M/F9O;W1E<B@I.PH@("`@("`@("`@("`D=&AI<RT^7VEN7V9O;W1E
M<B`](&9A;'-E.PH@("`@("`@("`@("`O*B!#;&]S92!P86=E+B`J+PH@("`@
M("`@("`@("`D=&AI<RT^7V5N9%!A9V4H*3L*("`@("`@("!]"B`@("`@("`@
M+RH@4W1A<G0@;F5W('!A9V4N("HO"B`@("`@("`@)'1H:7,M/E]B96=I;E!A
M9V4H)&]R:65N=&%T:6]N*3L*("`@("`@("`O*B!3970@;&EN92!C87`@<W1Y
M;&4@=&\@<W%U87)E+B`J+PH@("`@("`@("1T:&ES+3Y?;W5T*"<R($HG*3L*
M("`@("`@("`O*B!3970@;&EN92!W:61T:"X@*B\*("`@("`@("`D=&AI<RT^
M7VQI;F5?=VED=&@@/2`D;'<["B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT
M9B@G)2XR9B!W)RP@)&QW("H@)'1H:7,M/E]S8V%L92DI.PH@("`@("`@("\J
M(%-E="!F;VYT(&9O<B!T:&4@8F5G:6YN:6YG(&]F('1H92!P86=E+B`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7V9O;G1?9F%M:6QY*2!["B`@("`@("`@("`@
M("1T:&ES+3YS971&;VYT*"1T:&ES+3Y?9F]N=%]F86UI;'DL("1S='EL92P@
M)'1H:7,M/E]F;VYT7W-I>F5?<'0I.PH@("`@("`@("`@("`D9F]N=%]F86UI
M;'D@/2`D=&AI<RT^7V9O;G1?9F%M:6QY.PH@("`@("`@("`@("`D9F]N=%]S
M='EL92`]("1T:&ES+3Y?9F]N=%]S='EL92`N("@D=&AI<RT^7W5N9&5R;&EN
M92`_("=5)R`Z("<G*3L*("`@("`@("`@("`@)&9O;G1?<VEZ92`@/2`D=&AI
M<RT^7V9O;G1?<VEZ95]P=#L*("`@("`@("!]"B`@("`@("`@+RH@4V5T(&-O
M;&]R<RX@*B\*("`@("`@("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2`D9F,["B`@
M("`@("`@+RH@0VAE8VL@:68@9FEL;"!C;VQO<B!H87,@8F5E;B!S970@8F5F
M;W)E('1H:7,@<&%G92X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]F:6QL7V-O
M;&]R("$]("<P(&<G*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1T:&ES
M+3Y?9FEL;%]C;VQO<BD["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?9')A
M=U]C;VQO<B`]("1D8SL*("`@("`@("`O*B!#:&5C:R!I9B!D<F%W(&-O;&]R
M(&AA<R!B965N('-E="!B969O<F4@=&AI<R!P86=E+B`J+PH@("`@("`@(&EF
M("@D=&AI<RT^7V1R87=?8V]L;W(@(3T@)S`@1R<I('L*("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)'1H:7,M/E]D<F%W7V-O;&]R*3L*("`@("`@("!]"B`@
M("`@("`@+RH@4&%G92!H96%D97(N("HO"B`@("`@("`@)'1H:7,M/FAE861E
M<B@I.PH@("`@("`@("\J(%)E<W1O<F4@;&EN92!W:61T:"X@*B\*("`@("`@
M("!I9B`H)'1H:7,M/E]L:6YE7W=I9'1H("$]("1L=RD@>PH@("`@("`@("`@
M("`D=&AI<RT^7VQI;F5?=VED=&@@/2`D;'<["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*'-P<FEN=&8H)R4N,F8@=R<L("1L=R`J("1T:&ES+3Y?<V-A;&4I
M*3L*("`@("`@("!]"B`@("`@("`@+RH@36%K92!S=7)E('1H92!F;VYT(&ES
M('-E="!F;W(@=&AI<R!P86=E(&%S(&ET('=A<R!B969O<F4@=&AE"B`@("`@
M("`@("H@:&5A9&5R+B`J+PH@("`@("`@(&EF("@D9F]N=%]F86UI;'DI('L*
M("`@("`@("`@("`@)'1H:7,M/G-E=$9O;G0H)&9O;G1?9F%M:6QY+"`D9F]N
M=%]S='EL92P@)&9O;G1?<VEZ92P@=')U92D["B`@("`@("`@?0H@("`@("`@
M("\J(%)E<W1O<F4@8V]L;W)S+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7V1R
M87=?8V]L;W(@(3T@)&1C*2!["B`@("`@("`@("`@("1T:&ES+3Y?9')A=U]C
M;VQO<B`]("1D8SL*("`@("`@("`@("`@)'1H:7,M/E]O=70H)&1C*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?9FEL;%]C;VQO<B`A/2`D9F,I
M('L*("`@("`@("`@("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@)&9C.PH@("`@
M("`@("`@("`D=&AI<RT^7V]U="@D9F,I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H:7,@;65T:&]D(&ES('5S960@=&\@<F5N9&5R('1H
M92!P86=E(&AE861E<BX@270@:7,@875T;VUA=&EC86QL>0H@("`@("H@8V%L
M;&5D(&)Y($9I;&5?4$1&.CIA9&1086=E(&%N9"!S:&]U;&0@;F]T(&)E(&-A
M;&QE9"!D:7)E8W1L>2!B>2!T:&4*("`@("`J(&%P<&QI8V%T:6]N+B!4:&4@
M:6UP;&5M96YT871I;VX@:6X@1FEL95]01$8Z.B!I<R!E;7!T>2P@<V\@>6]U
M(&AA=F4@=&\*("`@("`J('-U8F-L87-S(&ET(&%N9"!O=F5R<FED92!T:&4@
M;65T:&]D(&EF('EO=2!W86YT(&$@<W!E8VEF:6,@<')O8V5S<VEN9RX*("`@
M("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H*("`@("`J(&-L87-S($UY7T9I
M;&5?4$1&(&5X=&5N9',@1FEL95]01$8@>PH@("`@("H@("`@(&9U;F-T:6]N
M(&AE861E<B@I"B`@("`@*B`@("`@>PH@("`@("H@("`@("`@("`O+R!396QE
M8W0@07)I86P@8F]L9"`Q-0H@("`@("H@("`@("`@("`D=&AI<RT^<V5T1F]N
M="@G07)I86PG+"`G0B<L(#$U*3L*("`@("`J("`@("`@("`@+R\@36]V92!T
M;R!T:&4@<FEG:'0*("`@("`J("`@("`@("`@)'1H:7,M/F-E;&PH.#`I.PH@
M("`@("H@("`@("`@("`O+R!&<F%M960@=&ET;&4*("`@("`J("`@("`@("`@
M)'1H:7,M/F-E;&PH,S`L(#$P+"`G5&ET;&4G+"`Q+"`P+"`G0R<I.PH@("`@
M("H@("`@("`@("`O+R!,:6YE(&)R96%K"B`@("`@*B`@("`@("`@("1T:&ES
M+3YN97=,:6YE*#(P*3L*("`@("`J("`@("!]"B`@("`@*B!]"B`@("`@*@H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ9F]O=&5R"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&AE861E<B@I"B`@("!["B`@("`@("`@+RH@5&\@8F4@:6UP;&5M96YT
M960@:6X@>6]U<B!O=VX@:6YH97)I=&5D(&-L87-S+B`J+PH@("`@?0H*("`@
M("\J*@H@("`@("H@5&AI<R!M971H;V0@:7,@=7-E9"!T;R!R96YD97(@=&AE
M('!A9V4@9F]O=&5R+B!)="!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B!C86QL
M960@8GD@1FEL95]01$8Z.F%D9%!A9V4@86YD($9I;&5?4$1&.CIC;&]S92!A
M;F0@<VAO=6QD(&YO="!B92!C86QL960*("`@("`J(&1I<F5C=&QY(&)Y('1H
M92!A<'!L:6-A=&EO;BX@5&AE(&EM<&QE;65N=&%T:6]N(&EN($9I;&5?4$1&
M.CH@:7,@96UP='DL"B`@("`@*B!S;R!Y;W4@:&%V92!T;R!S=6)C;&%S<R!I
M="!A;F0@;W9E<G)I9&4@=&AE(&UE=&AO9"!I9B!Y;W4@=V%N="!A('-P96-I
M9FEC"B`@("`@*B!P<F]C97-S:6YG+@H@("`@("H*("`@("`J($5X86UP;&4Z
M"B`@("`@*@H@("`@("H@8VQA<W,@37E?1FEL95]01$8@97AT96YD<R!&:6QE
M7U!$1B!["B`@("`@*B`@("!F=6YC=&EO;B!F;V]T97(H*0H@("`@("H@("`@
M>PH@("`@("H@("`@("`@("\O($=O('1O(#$N-2!C;2!F<F]M(&)O='1O;0H@
M("`@("H@("`@("`@("1T:&ES+3YS9719*"TQ-2D["B`@("`@*B`@("`@("`@
M+R\@4V5L96-T($%R:6%L(&ET86QI8R`X"B`@("`@*B`@("`@("`@)'1H:7,M
M/G-E=$9O;G0H)T%R:6%L)RP@)TDG+"`X*3L*("`@("`J("`@("`@("`O+R!0
M<FEN="!C96YT97)E9"!P86=E(&YU;6)E<@H@("`@("H@("`@("`@("1T:&ES
M+3YC96QL*#`L(#$P+"`G4&%G92`G("X@)'1H:7,M/F=E=%!A9V5.;R@I+"`P
M+"`P+"`G0R<I.PH@("`@("H@("`@?0H@("`@("H@?0H@("`@("H*("`@("`J
M($!S964@1FEL95]01$8Z.FAE861E<@H@("`@("HO"B`@("!F=6YC=&EO;B!F
M;V]T97(H*0H@("`@>PH@("`@("`@("\J(%1O(&)E(&EM<&QE;65N=&5D(&EN
M('EO=7(@;W=N(&EN:&5R:71E9"!C;&%S<RX@*B\*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@<&%G92!N=6UB97(N"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*@H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ86QI87-.8E!A9V5S"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=%!A9V5.;R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%G93L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&9I;&P@8V]L;W(N(%-P
M96-I9FEE<R!T:&4@8V]L;W(@9F]R(&)O=&@@9FEL;&5D(&%R96%S(&%N9`H@
M("`@("H@=&5X="X@1&5P96YD:6YG(&]N('1H92!C;VQO<G-P86-E(&-A;&QE
M9"P@=&AE(&YU;6)E<B!O9B!C;VQO<B!C;VUP;VYE;G0*("`@("`J('!A<F%M
M971E<G,@<F5Q=6ER960@8V%N(&)E(&5I=&AE<B`Q+"`S(&]R(#0N(%1H92!M
M971H;V0@8V%N(&)E(&-A;&QE9`H@("`@("H@8F5F;W)E('1H92!F:7)S="!P
M86=E(&ES(&-R96%T960@86YD('1H92!C;VQO<B!I<R!R971A:6YE9"!F<F]M
M('!A9V4@=&\*("`@("`J('!A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8W,@($EN9&EC871E<R!T:&4@8V]L;W)S<&%C92!W:&EC:"!C86X@
M8F4@96ET:&5R("=R9V(G+`H@("`@("H@("`@("`@("`@("`@("`@("`@("=C
M;7EK)R!O<B`G9W)A>2<N($1E9F%U;'1S('1O("=R9V(G+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1C,2`@($9I<G-T(&-O;&]R(&-O;7!O;F5N="P@9FQO871I
M;F<@<&]I;G0@=F%L=64@8F5T=V5E;B`P"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@86YD(#$N(%)E<75I<F5D(&9O<B!G<F%Y+"!R9V(@86YD(&-M>6LN
M"B`@("`@*B!`<&%R86T@9FQO870@)&,R("`@4V5C;VYD(&-O;&]R(&-O;7!O
M;F5N="P@9FQO871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD
M(&-M>6LN"B`@("`@*B!`<&%R86T@9FQO870@)&,S("`@5&AI<F0@8V]L;W(@
M8V]M<&]N96YT+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@,"!A;F0@,2X@4F5Q=6ER960@9F]R(')G
M8B!A;F0@8VUY:RX*("`@("`J($!P87)A;2!F;&]A="`D8S0@("!&;W5R=&@@
M8V]L;W(@8V]M<&]N96YT+"!F;&]A=&EN9R!P;VEN="!V86QU92!B971W965N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@,"!A;F0@,2X@4F5Q=6ER960@
M9F]R(&-M>6LN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1')A
M=T-O;&]R"B`@("`@*B!`<V5E($9I;&5?4$1&.CIR96-T"B`@("`@*B!`<V5E
M($9I;&5?4$1&.CIC96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E
M;&P*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1FEL;$-O;&]R*"1C<R`]("=R
M9V(G+"`D8S$L("1C,B`](#`L("1C,R`](#`L("1C-"`](#`I"B`@("!["B`@
M("`@("`@)&-S(#T@<W1R=&]L;W=E<B@D8W,I.PH@("`@("`@(&EF("@D8W,@
M/3T@)W)G8B<I('L*("`@("`@("`@("`@)'1H:7,M/E]F:6QL7V-O;&]R(#T@
M<W!R:6YT9B@G)2XS9B`E+C-F("4N,V8@<F<G+"`D8S$L("1C,BP@)&,S*3L*
M("`@("`@("!](&5L<V5I9B`H)&-S(#T]("=C;7EK)RD@>PH@("`@("`@("`@
M("`D=&AI<RT^7V9I;&Q?8V]L;W(@/2!S<')I;G1F*"<E+C-F("4N,V8@)2XS
M9B`E+C-F(&LG+"`D8S$L("1C,BP@)&,S+"`D8S0I.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3Y?9FEL;%]C;VQO<B`]('-P<FEN=&8H
M)R4N,V8@9R<L("1C,2D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^
M7W!A9V4@/B`P*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"1T:&ES+3Y?
M9FEL;%]C;VQO<BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M4V5T<R!T:&4@9')A=R!C;VQO<BP@=7-E9"!W:&5N(&1R87=I;F<@;&EN97,N
M($1E<&5N9&EN9R!O;B!T:&4*("`@("`J(&-O;&]R<W!A8V4@8V%L;&5D+"!T
M:&4@;G5M8F5R(&]F(&-O;&]R(&-O;7!O;F5N="!P87)A;65T97)S(')E<75I
M<F5D"B`@("`@*B!C86X@8F4@96ET:&5R(#$L(#,@;W(@-"X@5&AE(&UE=&AO
M9"!C86X@8F4@8V%L;&5D(&)E9F]R92!T:&4@9FER<W0@<&%G90H@("`@("H@
M:7,@8W)E871E9"!A;F0@=&AE(&-O;&]R(&ES(')E=&%I;F5D(&9R;VT@<&%G
M92!T;R!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&-S("!)
M;F1I8V%T97,@=&AE(&-O;&]R<W!A8V4@=VAI8V@@8V%N(&)E(&5I=&AE<B`G
M<F=B)RP*("`@("`J("`@("`@("`@("`@("`@("`@("`G8VUY:R<@;W(@)V=R
M87DG+B!$969A=6QT<R!T;R`G<F=B)RX*("`@("`J($!P87)A;2!F;&]A="`D
M8S$@("!&:7)S="!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T:6YG('!O:6YT('9A
M;'5E(&)E='=E96X@,`H@("`@("H@("`@("`@("`@("`@("`@("`@(&%N9"`Q
M+B!297%U:7)E9"!F;W(@9W)A>2P@<F=B(&%N9"!C;7EK+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1C,B`@(%-E8V]N9"!C;VQO<B!C;VUP;VYE;G0L(&9L;V%T
M:6YG('!O:6YT('9A;'5E(&)E='=E96X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`P(&%N9"`Q+B!297%U:7)E9"!F;W(@<F=B(&%N9"!C;7EK+@H@("`@
M("H@0'!A<F%M(&9L;V%T("1C,R`@(%1H:7)D(&-O;&]R(&-O;7!O;F5N="P@
M9FQO871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;B`P"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@86YD(#$N(%)E<75I<F5D(&9O<B!R9V(@86YD(&-M>6LN
M"B`@("`@*B!`<&%R86T@9FQO870@)&,T("`@1F]U<G1H(&-O;&]R(&-O;7!O
M;F5N="P@9FQO871I;F<@<&]I;G0@=F%L=64@8F5T=V5E;@H@("`@("H@("`@
M("`@("`@("`@("`@("`@(#`@86YD(#$N(%)E<75I<F5D(&9O<B!C;7EK+@H@
M("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9I;&Q#;VQO<@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ;&EN90H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M<F5C=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L;`H@("`@("H@0'-E92!&
M:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1R
M87=#;VQO<B@D8W,@/2`G<F=B)RP@)&,Q+"`D8S(@/2`P+"`D8S,@/2`P+"`D
M8S0@/2`P*0H@("`@>PH@("`@("`@("1C<R`]('-T<G1O;&]W97(H)&-S*3L*
M("`@("`@("!I9B`H)&-S(#T]("=R9V(G*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?9')A=U]C;VQO<B`]('-P<FEN=&8H)R4N,V8@)2XS9B`E+C-F(%)')RP@
M)&,Q+"`D8S(L("1C,RD["B`@("`@("`@?2!E;'-E:68@*"1C<R`]/2`G8VUY
M:R<I('L*("`@("`@("`@("`@)'1H:7,M/E]D<F%W7V-O;&]R(#T@<W!R:6YT
M9B@G)2XS9B`E+C-F("4N,V8@)2XS9B!+)RP@)&,Q+"`D8S(L("1C,RP@)&,T
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V1R87=?
M8V]L;W(@/2!S<')I;G1F*"<E+C-F($<G+"`D8S$I.PH@("`@("`@('T*("`@
M("`@("!I9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@("`@("`@("`D=&AI
M<RT^7V]U="@D=&AI<RT^7V1R87=?8V]L;W(I.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&QE;F=T:"!O9B!A('1E>'0@
M<W1R:6YG+B!!(&9O;G0@;75S="!B92!S96QE8W1E9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1T97AT("!4:&4@=&5X="!W:&]S92!L96YG=&@@
M:7,@=&\@8F4@8V]M<'5T960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D<'0@
M("!";V]L96%N('1O(&EN9&EC871E(&EF('1H92!W:61T:"!S:&]U;&0@8F4@
M<F5T=7)N960*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&EN('!O:6YT
M<R!O<B!U<V5R('5N:71S+B!$969A=6QT(&ES("=F86QS92<N"B`@("`@*@H@
M("`@("H@0')E='5R;B!F;&]A=`H@("`@("HO"B`@("!F=6YC=&EO;B!G9713
M=')I;F=7:61T:"@D=&5X="P@)'!T(#T@9F%L<V4I"B`@("!["B`@("`@("`@
M)'1E>'0@/2`H<W1R:6YG*21T97AT.PH@("`@("`@("1W:61T:"`](#`["B`@
M("`@("`@)&QE;F=T:"`]('-T<FQE;B@D=&5X="D["B`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&QE;F=T:#L@)&DK*RD@>PH@("`@("`@("`@("`D=VED
M=&@@*ST@)'1H:7,M/E]C=7)R96YT7V9O;G1;)V-W)UU;)'1E>'1[)&E]73L*
M("`@("`@("!]"@H@("`@("`@("\J($%D:G5S="!F;W(@=V]R9"!S<&%C:6YG
M+B`J+PH@("`@("`@("1W:61T:"`K/2`D=&AI<RT^7W=O<F1?<W!A8VEN9R`J
M('-U8G-T<E]C;W5N="@D=&5X="P@)R`G*2`J("1T:&ES+3Y?8W5R<F5N=%]F
M;VYT6R=C=R==6R<@)UT["@H@("`@("`@(&EF("@D<'0I('L*("`@("`@("`@
M("`@<F5T=7)N("1W:61T:"`J("1T:&ES+3Y?9F]N=%]S:7IE7W!T("\@,3`P
M,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'=I9'1H
M("H@)'1H:7,M/E]F;VYT7W-I>F4@+R`Q,#`P.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&QI;F4@=VED=&@N($)Y(&1E
M9F%U;'0L('1H92!V86QU92!E<75A;',@,"XR(&UM+B!4:&4@;65T:&]D"B`@
M("`@*B!C86X@8F4@8V%L;&5D(&)E9F]R92!T:&4@9FER<W0@<&%G92!I<R!C
M<F5A=&5D(&%N9"!T:&4@=F%L=64@:7,*("`@("`J(')E=&%I;F5D(&9R;VT@
M<&%G92!T;R!P86=E+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D=VED
M=&@@(%1H92!W:61T:"X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIL
M:6YE"B`@("`@*B!`<V5E($9I;&5?4$1&.CIR96-T"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIC96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T3&EN95=I9'1H*"1W:61T:"D*("`@
M('L*("`@("`@("`D=&AI<RT^7VQI;F5?=VED=&@@/2`D=VED=&@["B`@("`@
M("`@:68@*"1T:&ES+3Y?<&%G92`^(#`I('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H<W!R:6YT9B@G)2XR9B!W)RP@)'=I9'1H("H@)'1H:7,M/E]S8V%L
M92DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1R87=S(&$@
M;&EN92!B971W965N('1W;R!P;VEN=',N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&9L;V%T("1X,2`@06)S8VES<V$@;V8@9FER<W0@<&]I;G0N"B`@("`@*B!`
M<&%R86T@9FQO870@)'DQ("!/<F1I;F%T92!O9B!F:7)S="!P;VEN="X*("`@
M("`J($!P87)A;2!F;&]A="`D>#(@($%B<V-I<W-A(&]F('-E8V]N9"!P;VEN
M="X*("`@("`J($!P87)A;2!F;&]A="`D>3(@($]R9&EN871E(&]F('-E8V]N
M9"!P;VEN="X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971,:6YE
M5VED=&@*("`@("`J($!S964@1FEL95]01$8Z.G-E=$1R87=#;VQO<BX*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&EN92@D>#$L("1Y,2P@)'@R+"`D>3(I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XR9B`E+C)F(&T@
M)2XR9B`E+C)F(&P@4R<L("1X,2`J("1T:&ES+3Y?<V-A;&4L("@D=&AI<RT^
M:"`M("1Y,2D@*B`D=&AI<RT^7W-C86QE+"`D>#(@*B`D=&AI<RT^7W-C86QE
M+"`H)'1H:7,M/F@@+2`D>3(I("H@)'1H:7,M/E]S8V%L92DI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@3W5T<'5T<R!A(')E8W1A;F=L92X@270@8V%N(&)E
M(&1R87=N("AB;W)D97(@;VYL>2DL(&9I;&QE9"`H=VET:"!N;PH@("`@("H@
M8F]R9&5R*2!O<B!B;W1H+@H@("`@("H*("`@("`J($!P87)A;2!F;&]A="`D
M>"`@("`@("!!8G-C:7-S82!O9B!U<'!E<BUL969T(&-O<FYE<BX*("`@("`J
M($!P87)A;2!F;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!U<'!E<BUL969T
M(&-O<FYE<BX*("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@("!7:61T:"X*
M("`@("`J($!P87)A;2!F;&]A="`D:&5I9VAT("!(96EG:'0N"B`@("`@*B!`
M<&%R86T@9FQO870@)'-T>6QE("`@4W1Y;&4@;V8@<F5N9&5R:6YG+B!0;W-S
M:6)L92!V86QU97,@87)E.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@+2!$(&]R(&5M<'1Y('-T<FEN9SH@9')A=R`H9&5F875L="D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("T@1CH@9FEL;`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@+2!$1B!O<B!&1#H@9')A=R!A;F0@9FEL
M;`H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$QI;F57:61T:`H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1')A=T-O;&]R"B`@("`@*B!`<V5E
M($9I;&5?4$1&.CIS971&:6QL0V]L;W(*("`@("`J+PH@("`@9G5N8W1I;VX@
M<F5C="@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)'-T>6QE(#T@)R<I"B`@
M("!["B`@("`@("`@)'-T>6QE(#T@<W1R=&]U<'!E<B@D<W1Y;&4I.PH@("`@
M("`@(&EF("@D<W1Y;&4@/3T@)T8G*2!["B`@("`@("`@("`@("1O<"`]("=F
M)SL*("`@("`@("!](&5L<V5I9B`H)'-T>6QE(#T]("=&1"<@?'P@)'-T>6QE
M(#T]("=$1B<I('L*("`@("`@("`@("`@)&]P(#T@)T(G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1O<"`]("=3)SL*("`@("`@("!]"@H@("`@
M("`@("1X("`@("`@/2`D=&AI<RT^7W1O4'0H)'@I.PH@("`@("`@("1Y("`@
M("`@/2`D=&AI<RT^7W1O4'0H)'DI.PH@("`@("`@("1W:61T:"`@/2`D=&AI
M<RT^7W1O4'0H)'=I9'1H*3L*("`@("`@("`D:&5I9VAT(#T@)'1H:7,M/E]T
M;U!T*"1H96EG:'0I.PH*("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"<E
M+C)F("4N,F8@)2XR9B`E+C)F(')E("5S)RP@)'@L("1T:&ES+3YH4'0@+2`D
M>2P@)'=I9'1H+"`M)&AE:6=H="P@)&]P*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!/=71P=71S(&$@8VER8VQE+B!)="!C86X@8F4@9')A=VX@*&)O<F1E
M<B!O;FQY*2P@9FEL;&5D("AW:71H(&YO"B`@("`@*B!B;W)D97(I(&]R(&)O
M=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@("`@($%B<V-I
M<W-A(&]F('1H92!C96YT97(@;V8@=&AE(&-I<F-L92X*("`@("`J($!P87)A
M;2!F;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!T:&4@8V5N=&5R(&]F('1H
M92!C:7)C;&4N"B`@("`@*B!`<&%R86T@9FQO870@)'(@("`@("`@0VER8VQE
M(')A9&EU<RX*("`@("`J($!P87)A;2!S=')I;F<@)'-T>6QE("!3='EL92!O
M9B!R96YD97)I;F<N(%!O<W-I8FQE('9A;'5E<R!A<F4Z"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`M($0@;W(@96UP='D@<W1R:6YG.B!D<F%W
M("AD969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!&
M.B!F:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($1&(&]R
M($9$.B!D<F%W(&%N9"!F:6QL"B`@("`@*B\*("`@(&9U;F-T:6]N(&-I<F-L
M92@D>"P@)'DL("1R+"`D<W1Y;&4@/2`G)RD*("`@('L*("`@("`@("`D<W1Y
M;&4@/2!S=')T;VQO=V5R*"1S='EL92D["B`@("`@("`@:68@*"1S='EL92`]
M/2`G9B<I('L*("`@("`@("`@("`@)&]P(#T@)V8G.R`@("`@("\O(%-T>6QE
M(&ES(&9I;&P@;VYL>2X*("`@("`@("!](&5L<V5I9B`H)'-T>6QE(#T]("=F
M9"<@?'P@)'-T>6QE(#T]("=D9B<I('L*("`@("`@("`@("`@)&]P(#T@)T(G
M.R`@("`@("\O(%-T>6QE(&ES(&9I;&P@86YD('-T<F]K92X*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D;W`@/2`G4R<[("`@("`@+R\@4W1Y;&4@
M:7,@<W1R;VME(&]N;'DN"B`@("`@("`@?0H*("`@("`@("`D>"`]("1T:&ES
M+3Y?=&]0="@D>"D["B`@("`@("`@)'D@/2`D=&AI<RT^7W1O4'0H)'DI.PH@
M("`@("`@("1R(#T@)'1H:7,M/E]T;U!T*"1R*3L*"B`@("`@("`@+RH@26YV
M97)T('1H92!Y('-C86QE+B`J+PH@("`@("`@("1Y(#T@)'1H:7,M/FA0="`M
M("1Y.PH@("`@("`@("\J($QE;F=T:"!O9B!T:&4@0F5Z:65R(&-O;G1R;VPN
M("HO"B`@("`@("`@)&(@/2`D<B`J(#`N-34R.PH*("`@("`@("`O*B!-;W9E
M(&9R;VT@=&AE(&=I=F5N(&]R:6=I;B!A;F0@<V5T('1H92!C=7)R96YT('!O
M:6YT"B`@("`@("`@("H@=&\@=&AE('-T87)T(&]F('1H92!F:7)S="!"97II
M97(@8W5R=F4N("HO"B`@("`@("`@)&,@/2!S<')I;G1F*"<E+C)F("4N,F8@
M;2<L("1X("T@)'(L("1Y*3L*("`@("`@("`D>"`]("1X("T@)'(["B`@("`@
M("`@+RH@1FER<W0@8VER8VQE('%U87)T97(N("HO"B`@("`@("`@)&,@+CT@
M<W!R:6YT9B@G("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F(&,G+`H@
M("`@("`@("`@("`@("`@("`@("`@)'@L("1Y("L@)&(L("`@("`@("`@("`O
M+R!&:7)S="!C;VYT<F]L('!O:6YT+@H@("`@("`@("`@("`@("`@("`@("`@
M)'@@*R`D<B`M("1B+"`D>2`K("1R+"`O+R!396-O;F0@8V]N=')O;"!P;VEN
M="X*("`@("`@("`@("`@("`@("`@("`@("1X("L@)'(L("1Y("L@)'(I.R`@
M("`@+R\@1FEN86P@<&]I;G0N"B`@("`@("`@+RH@4V5T('@O>2!T;R!T:&4@
M9FEN86P@<&]I;G0N("HO"B`@("`@("`@)'@@/2`D>"`K("1R.PH@("`@("`@
M("1Y(#T@)'D@*R`D<CL*("`@("`@("`O*B!396-O;F0@8VER8VQE('%U87)T
M97(N("HO"B`@("`@("`@)&,@+CT@<W!R:6YT9B@G("4N,F8@)2XR9B`E+C)F
M("4N,F8@)2XR9B`E+C)F(&,G+`H@("`@("`@("`@("`@("`@("`@("`@)'@@
M*R`D8BP@)'DL"B`@("`@("`@("`@("`@("`@("`@("`D>"`K("1R+"`D>2`M
M("1R("L@)&(L"B`@("`@("`@("`@("`@("`@("`@("`D>"`K("1R+"`D>2`M
M("1R*3L*("`@("`@("`O*B!3970@>"]Y('1O('1H92!F:6YA;"!P;VEN="X@
M*B\*("`@("`@("`D>"`]("1X("L@)'(["B`@("`@("`@)'D@/2`D>2`M("1R
M.PH@("`@("`@("\J(%1H:7)D(&-I<F-L92!Q=6%R=&5R+B`J+PH@("`@("`@
M("1C("X]('-P<FEN=&8H)R`E+C)F("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR
M9B!C)RP*("`@("`@("`@("`@("`@("`@("`@("1X+"`D>2`M("1B+`H@("`@
M("`@("`@("`@("`@("`@("`@)'@@+2`D<B`K("1B+"`D>2`M("1R+`H@("`@
M("`@("`@("`@("`@("`@("`@)'@@+2`D<BP@)'D@+2`D<BD["B`@("`@("`@
M+RH@4V5T('@O>2!T;R!T:&4@9FEN86P@<&]I;G0N("HO"B`@("`@("`@)'@@
M/2`D>"`M("1R.PH@("`@("`@("1Y(#T@)'D@+2`D<CL*("`@("`@("`O*B!&
M;W5R=&@@8VER8VQE('%U87)T97(N("HO"B`@("`@("`@)&,@+CT@<W!R:6YT
M9B@G("4N,F8@)2XR9B`E+C)F("4N,F8@)2XR9B`E+C)F(&,@)7,G+`H@("`@
M("`@("`@("`@("`@("`@("`@)'@@+2`D8BP@)'DL"B`@("`@("`@("`@("`@
M("`@("`@("`D>"`M("1R+"`D>2`K("1R("T@)&(L"B`@("`@("`@("`@("`@
M("`@("`@("`D>"`M("1R+"`D>2`K("1R+`H@("`@("`@("`@("`@("`@("`@
M("`@)&]P*3L*("`@("`@("`O*B!/=71P=70@=&AE('=H;VQE('-T<FEN9RX@
M*B\*("`@("`@("`D=&AI<RT^7V]U="@D8RD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);7!O<G1S(&$@5')U951Y<&4@;W(@5'EP93$@9F]N="!A;F0@;6%K
M97,@:70@879A:6QA8FQE+B!)="!I<PH@("`@("H@;F5C97-S87)Y('1O(&=E
M;F5R871E(&$@9F]N="!D969I;FET:6]N(&9I;&4@9FER<W0@=VET:"!T:&4*
M("`@("`J(&UA:V5F;VYT+G!H<"!U=&EL:71Y+@H@("`@("H@5&AE(&QO8V%T
M:6]N(&]F('1H92!D969I;FET:6]N(&9I;&4@*&%N9"!T:&4@9F]N="!F:6QE
M(&ET<V5L9B!W:&5N"B`@("`@*B!E;6)E9&1I;F<I(&UU<W0@8F4@9F]U;F0@
M870@=&AE(&9U;&P@<&%T:"!N86UE(&EN8VQU9&5D+@H@("`@("H*("`@("`J
M($5X86UP;&4Z"B`@("`@*B`D<&1F+3YA9&1&;VYT*"=#;VUI8R<L("=))RD[
M"B`@("`@*B!I<R!E<75I=F%L96YT('1O.@H@("`@("H@)'!D9BT^861D1F]N
M="@G0V]M:6,G+"`G22<L("=C;VUI8VDN<&AP)RD["B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F%M:6QY("!&;VYT(&9A;6EL>2X@5&AE(&YA;64@
M8V%N(&)E(&-H;W-E;B!A<F)I=')A<FEL>2X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@268@:70@:7,@82!S=&%N9&%R9"!F86UI;'D@;F%M92P@
M:70@=VEL;`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O=F5R<FED
M92!T:&4@8V]R<F5S<&]N9&EN9R!F;VYT+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<W1Y;&4@("!&;VYT('-T>6QE+B!0;W-S:6)L92!V86QU97,@87)E("AC
M87-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@(&EN<V5N<VET:79E
M*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M(&5M<'1Y('-T
M<FEN9SH@<F5G=6QA<B`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`M($(Z(&)O;&0*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`M($DZ(&ET86QI8PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("T@0DD@;W(@24(Z(&)O;&0@:71A;&EC"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1F:6QE("`@(%1H92!F;VYT(&1E9FEN:71I;VX@9FEL92X@0GD@
M9&5F875L="P@=&AE(&YA;64@:7,*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@8G5I;'0@9G)O;2!T:&4@9F%M:6QY(&%N9"!S='EL92P@:6X@;&]W
M97(@8V%S90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!W:71H(&YO
M('-P86-E+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D1F]N="@D9F%M:6QY+"`D<W1Y;&4@
M/2`G)RP@)&9I;&4@/2`G)RD*("`@('L*("`@("`@("`D9F%M:6QY(#T@<W1R
M=&]L;W=E<B@D9F%M:6QY*3L*("`@("`@("!I9B`H)&9A;6EL>2`]/2`G87)I
M86PG*2!["B`@("`@("`@("`@("1F86UI;'D@/2`G:&5L=F5T:6-A)SL*("`@
M("`@("!]"@H@("`@("`@("1S='EL92`]('-T<G1O=7!P97(H)'-T>6QE*3L*
M("`@("`@("!I9B`H)'-T>6QE(#T]("=)0B<I('L*("`@("`@("`@("`@)'-T
M>6QE(#T@)T)))SL*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?9F]N='-;)&9A;6EL>2`N("1S='EL95TI*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=&;VYT(&%L<F5A9'D@
M861D960Z("5S("5S)RP@)&9A;6EL>2P@)'-T>6QE*2D["B`@("`@("`@?0H@
M("`@("`@(&EF("@D9FEL92`]/2`G)RD@>PH@("`@("`@("`@("`D9FEL92`]
M('-T<E]R97!L86-E*"<@)RP@)R<L("1F86UI;'DI("X@<W1R=&]L;W=E<B@D
M<W1Y;&4I("X@)RYP:'`G.PH@("`@("`@('T*("`@("`@("!I;F-L=61E*"1F
M:6QE*3L*("`@("`@("!I9B`H(6ES<V5T*"1N86UE*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-O=6QD(&YO="!I;F-L=61E
M(&9O;G0@9&5F:6YI=&EO;B!F:6QE+B<I.PH@("`@("`@('T*("`@("`@("`D
M:2`](&-O=6YT*"1T:&ES+3Y?9F]N=',I("L@,3L*("`@("`@("`D=&AI<RT^
M7V9O;G1S6R1F86UI;'D@+B`D<W1Y;&5=(#T@87)R87DH)VDG(#T^("1I+"`G
M='EP92<@/3X@)'1Y<&4L("=N86UE)R`]/B`D;F%M92P@)V1E<V,G(#T^("1D
M97-C+"`G=7`G(#T^("1U<"P@)W5T)R`]/B`D=70L("=C=R<@/3X@)&-W+"`G
M96YC)R`]/B`D96YC+"`G9FEL92<@/3X@)&9I;&4I.PH@("`@("`@(&EF("@D
M9&EF9BD@>PH@("`@("`@("`@("`O*B!396%R8V@@97AI<W1I;F<@96YC;V1I
M;F=S+B`J+PH@("`@("`@("`@("`D9"`](#`["B`@("`@("`@("`@("1N8B`]
M(&-O=6YT*"1T:&ES+3Y?9&EF9G,I.PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,3L@)&D@/#T@)&YB.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]D:69F<ULD:5T@/3T@)&1I9F8I('L*("`@("`@("`@("`@("`@("`@
M("`D9"`]("1I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D9"`]
M/2`P*2!["B`@("`@("`@("`@("`@("`D9"`]("1N8B`K(#$["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V1I9F9S6R1D72`]("1D:69F.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1T:&ES+3Y?9F]N='-;)&9A;6EL>2XD<W1Y;&5=
M6R=D:69F)UT@/2`D9#L*("`@("`@("!]"B`@("`@("`@:68@*"1F:6QE*2![
M"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G5')U951Y<&4G*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V9O;G1?9FEL97-;)&9I;&5=(#T@87)R87DH
M)VQE;F=T:#$G(#T^("1O<FEG:6YA;'-I>F4I.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]F;VYT7V9I;&5S6R1F:6QE
M72`](&%R<F%Y*"=L96YG=&@Q)R`]/B`D<VEZ93$L("=L96YG=&@R)R`]/B`D
M<VEZ93(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!T:&4@9F]N="!U<V5D('1O('!R:6YT(&-H87)A8W1E
M<B!S=')I;F=S+B!)="!I<R!M86YD871O<GD@=&\@8V%L;`H@("`@("H@=&AI
M<R!M971H;V0@870@;&5A<W0@;VYC92!B969O<F4@<')I;G1I;F<@=&5X="!O
M<B!T:&4@<F5S=6QT:6YG"B`@("`@*B!D;V-U;65N="!W;W5L9"!N;W0@8F4@
M=F%L:60N(%1H92!F;VYT(&-A;B!B92!E:71H97(@82!S=&%N9&%R9"!O;F4@
M;W(@80H@("`@("H@9F]N="!A9&1E9"!V:6$@=&AE($9I;&5?4$1&.CIA9&1&
M;VYT(&UE=&AO9"X@4W1A;F1A<F0@9F]N=',@=7-E(%=I;F1O=W,*("`@("`J
M(&5N8V]D:6YG(&-P,3(U,B`H5V5S=&5R;B!%=7)O<&4I+@H@("`@("H@5&AE
M(&UE=&AO9"!C86X@8F4@8V%L;&5D(&)E9F]R92!T:&4@9FER<W0@<&%G92!I
M<R!C<F5A=&5D(&%N9"!T:&4@9F]N=`H@("`@("H@:7,@<F5T86EN960@9G)O
M;2!P86=E('1O('!A9V4N"B`@("`@*B!)9B!Y;W4@:G5S="!W:7-H('1O(&-H
M86YG92!T:&4@8W5R<F5N="!F;VYT('-I>F4L(&ET(&ES('-I;7!L97(@=&\@
M8V%L;`H@("`@("H@1FEL95]01$8Z.G-E=$9O;G13:7IE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&9A;6EL>2`@1F%M:6QY(&9O;G0N($ET(&-A
M;B!B92!E:71H97(@82!N86UE(&1E9FEN960@8GD*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@1FEL95]01$8Z.F%D9$9O;G0@;W(@;VYE(&]F('1H
M92!S=&%N9&%R9"!F86UI;&EE<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`H8V%S92!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@+2!#;W5R:65R("AF:7AE9"UW:61T:"D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`M($AE;'9E=&EC82!O<B!!<FEA;"`H
M<V%N<R!S97)I9BD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`M
M(%1I;65S("AS97)I9BD*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`M(%-Y;6)O;"`H<WEM8F]L:6,I"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@+2!:87!F1&EN9V)A=',@*'-Y;6)O;&EC*0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!)="!I<R!A;'-O('!O<W-I8FQE('1O('!A
M<W,@86X@96UP='D@<W1R:6YG+B!);@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("!T:&%T(&-A<V4L('1H92!C=7)R96YT(&9A;6EL>2!I<R!R971A
M:6YE9"X*("`@("`J($!P87)A;2!S=')I;F<@)'-T>6QE("`@1F]N="!S='EL
M92X@4&]S<VEB;&4@=F%L=65S(&%R92`H8V%S90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("!I;G-E;G-I=&EV92DZ"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@+2!E;7!T>2!S=')I;F<Z(')E9W5L87(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`M($(Z(&)O;&0*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`M($DZ(&ET86QI8PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("T@53H@=6YD97)L:6YE"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@(&]R(&%N>2!C;VUB:6YA=&EO;BX@5&AE
M(&1E9F%U;'0@=F%L=64@:7,@<F5G=6QA<BX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@0F]L9"!A;F0@:71A;&EC('-T>6QE<R!D;R!N;W0@87!P
M;'D@=&\@4WEM8F]L(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("!:87!F1&EN9V)A=',N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D<VEZ92`@
M($9O;G0@<VEZ92!I;B!P;VEN=',N(%1H92!D969A=6QT('9A;'5E(&ES('1H
M90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!C=7)R96YT('-I>F4N
M($EF(&YO('-I>F4@:&%S(&)E96X@<W!E8VEF:65D('-I;F-E"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!B96=I;FYI;F<@;V8@=&AE(&1O
M8W5M96YT+"!T:&4@=F%L=64@=&%K96X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@:7,@,3(N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D9F]R8V4@
M($9O<F-E('1H92!S971T:6YG(&]F('1H92!F;VYT+B!%86-H(&YE=R!P86=E
M('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER92!A
M(&YE=R!C86QL('1O($9I;&5?4$1&.CIS971&;VYT(&%N9`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("!S971T:6YG<R!T:&ES('1O('1R=64@=VEL
M;"!M86ME('-U<F4@=&AA="!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@8VAE8VMS(&9O<B!S86UE(&9O;G0@8V%L;',@=VEL;"!B92!S:VEP
M<&5D+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.F%D9$9O;G0*("`@
M("`J($!S964@1FEL95]01$8Z.G-E=$9O;G13:7IE"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIC96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*
M("`@("`J($!S964@1FEL95]01$8Z.E=R:71E"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$9O;G0H)&9A;6EL>2P@)'-T>6QE(#T@)R<L("1S:7IE(#T@;G5L
M;"P@)&9O<F-E(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9A;6EL>2`]('-T
M<G1O;&]W97(H)&9A;6EL>2D["B`@("`@("`@:68@*"1F86UI;'D@/3T@)V%R
M:6%L)RD@>PH@("`@("`@("`@("`O*B!5<V4@:&5L=F5T:6-A(&EN<W1E860@
M;V8@87)I86PN("HO"B`@("`@("`@("`@("1F86UI;'D@/2`G:&5L=F5T:6-A
M)SL*("`@("`@("!](&5L<V5I9B`H)&9A;6EL>2`]/2`G<WEM8F]L)R!\?"`D
M9F%M:6QY(#T]("=Z87!F9&EN9V)A=',G*2!["B`@("`@("`@("`@("\J(%1H
M97-E('1W;R!F;VYT<R!D;R!N;W0@:&%V92!S='EL97,@879A:6QA8FQE+B`J
M+PH@("`@("`@("`@("`D<W1Y;&4@/2`G)SL*("`@("`@("!]"@H@("`@("`@
M("1S='EL92`]('-T<G1O=7!P97(H)'-T>6QE*3L*"B`@("`@("`@+RH@56YD
M97)L:6YE(&ES(&AA;F1L960@<V5P87)A=&5L>2P@:68@<W!E8VEF:65D(&EN
M('1H92!S='EL92!V87(*("`@("`@("`@*B!R96UO=F4@:70@9G)O;2!T:&4@
M<W1Y;&4@86YD('-E="!T:&4@=6YD97)L:6YE(&9L86<N("HO"B`@("`@("`@
M:68@*'-T<G!O<R@D<W1Y;&4L("=5)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?=6YD97)L:6YE(#T@=')U93L*("`@("`@("`@("`@)'-T
M>6QE(#T@<W1R7W)E<&QA8V4H)U4G+"`G)RP@)'-T>6QE*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W5N9&5R;&EN92`](&9A;'-E
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1S='EL92`]/2`G24(G*2!["B`@
M("`@("`@("`@("1S='EL92`]("="22<["B`@("`@("`@?0H*("`@("`@("`O
M*B!)9B!N;R!S:7IE('-P96-I9FEE9"P@=7-E(&-U<G)E;G0@<VEZ92X@*B\*
M("`@("`@("!I9B`H:7-?;G5L;"@D<VEZ92DI('L*("`@("`@("`@("`@)'-I
M>F4@/2`D=&AI<RT^7V9O;G1?<VEZ95]P=#L*("`@("`@("!]"@H@("`@("`@
M("\J($EF(&9O;G0@<F5Q=65S=&5D(&ES(&%L<F5A9'D@=&AE(&-U<G)E;G0@
M9F]N="!A;F0@;F\@9F]R8V4@<V5T=&EN9PH@("`@("`@("`J(&]F('1H92!F
M;VYT(&ES(')E<75E<W1E9"`H96<N('=H96X@861D:6YG(&$@;F5W('!A9V4I
M(&1O;B=T(&)O=&AE<@H@("`@("`@("`J('=I=&@@=&AE(')E<W0@;V8@=&AE
M(&9U;F-T:6]N(&%N9"!S:6UP;'D@<F5T=7)N+B`J+PH@("`@("`@(&EF("@D
M=&AI<RT^7V9O;G1?9F%M:6QY(#T]("1F86UI;'D@)B8@)'1H:7,M/E]F;VYT
M7W-T>6QE(#T]("1S='EL92`F)@H@("`@("`@("`@("`D=&AI<RT^7V9O;G1?
M<VEZ95]P="`]/2`D<VEZ92`F)B`A)&9O<F-E*2!["B`@("`@("`@("`@(')E
M='5R;CL*("`@("`@("!]"@H@("`@("`@("\J(%-E="!T:&4@9F]N="!K97DN
M("HO"B`@("`@("`@)&9O;G1K97D@/2`D9F%M:6QY("X@)'-T>6QE.PH*("`@
M("`@("`O*B!497-T(&EF(&%L<F5A9'D@8V%C:&5D+B`J+PH@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]F;VYT<ULD9F]N=&ME>5TI*2!["B`@("`@("`@
M("`@("\J($=E="!T:&4@8VAA<F%C=&5R('=I9'1H(&1E9FEN:71I;VX@9FEL
M92X@*B\*("`@("`@("`@("`@)&9O;G1?=VED=&AS(#T@)D9I;&5?4$1&.CI?
M9V5T1F]N=$9I;&4H)&9O;G1K97DI.PH@("`@("`@("`@("!I9B`H:7-?82@D
M9F]N=%]W:61T:',L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D9F]N=%]W:61T:',["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1I(#T@8V]U;G0H)'1H:7,M/E]F;VYT<RD@*R`Q.PH@("`@("`@("`@
M("`D=&AI<RT^7V9O;G1S6R1F;VYT:V5Y72`](&%R<F%Y*`H@("`@("`@("`@
M("`@("`@)VDG("`@(#T^("1I+`H@("`@("`@("`@("`@("`@)W1Y<&4G(#T^
M("=C;W)E)RP*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D=&AI<RT^7V-O
M<F5?9F]N='-;)&9O;G1K97E=+`H@("`@("`@("`@("`@("`@)W5P)R`@(#T^
M("TQ,#`L"B`@("`@("`@("`@("`@("`G=70G("`@/3X@-3`L"B`@("`@("`@
M("`@("`@("`G8W<G("`@/3X@)&9O;G1?=VED=&AS6R1F;VYT:V5Y72D["B`@
M("`@("`@?0H*("`@("`@("`O*B!3=&]R92!F;VYT(&EN9F]R;6%T:6]N(&%S
M(&-U<G)E;G0@9F]N="X@*B\*("`@("`@("`D=&AI<RT^7V9O;G1?9F%M:6QY
M("`]("1F86UI;'D["B`@("`@("`@)'1H:7,M/E]F;VYT7W-T>6QE("`@/2`D
M<W1Y;&4["B`@("`@("`@)'1H:7,M/E]F;VYT7W-I>F5?<'0@/2`D<VEZ93L*
M("`@("`@("`D=&AI<RT^7V9O;G1?<VEZ92`@("`]("1S:7IE("\@)'1H:7,M
M/E]S8V%L93L*("`@("`@("`D=&AI<RT^7V-U<G)E;G1?9F]N="`]("8D=&AI
M<RT^7V9O;G1S6R1F;VYT:V5Y73L*"B`@("`@("`@+RH@3W5T<'5T(&9O;G0@
M:6YF;W)M871I;VX@:68@870@;&5A<W0@;VYE('!A9V4@:&%S(&)E96X@9&5F
M:6YE9"X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@
M("`@("`@("`D=&AI<RT^7V]U="AS<')I;G1F*"="5"`O1B5D("4N,F8@5&8@
M150G+"`D=&AI<RT^7V-U<G)E;G1?9F]N=%LG:2==+"`D=&AI<RT^7V9O;G1?
M<VEZ95]P="DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($1E
M9FEN97,@=&AE('-I>F4@;V8@=&AE(&-U<G)E;G0@9F]N="X*("`@("`J"B`@
M("`@*B!`<&%R86T@9FQO870@)'-I>F4@(%1H92!S:7IE("AI;B!P;VEN=',I
M+@H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T1F]N=%-I>F4H)'-I>F4I"B`@("!["B`@("`@
M("`@+RH@268@=&AE(&9O;G0@<VEZ92!I<R!A;')E861Y('1H92!C=7)R96YT
M(&9O;G0@<VEZ92P@:G5S="!R971U<FXN("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?9F]N=%]S:7IE7W!T(#T]("1S:7IE*2!["B`@("`@("`@("`@(')E='5R
M;CL*("`@("`@("!]"B`@("`@("`@+RH@4V5T('1H92!C=7)R96YT(&9O;G0@
M<VEZ92P@8F]T:"!I;B!P;VEN=',@86YD('-C86QE9"!T;R!U<V5R"B`@("`@
M("`@("H@=6YI=',N("HO"B`@("`@("`@)'1H:7,M/E]F;VYT7W-I>F5?<'0@
M/2`D<VEZ93L*("`@("`@("`D=&AI<RT^7V9O;G1?<VEZ92`]("1S:7IE("\@
M)'1H:7,M/E]S8V%L93L*"B`@("`@("`@+RH@3W5T<'5T(&9O;G0@:6YF;W)M
M871I;VX@:68@870@;&5A<W0@;VYE('!A9V4@:&%S(&)E96X@9&5F:6YE9"X@
M*B\*("`@("`@("!I9B`H)'1H:7,M/E]P86=E(#X@,"D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]U="AS<')I;G1F*"="5"`O1B5D("4N,F8@5&8@150G+"`D
M=&AI<RT^7V-U<G)E;G1?9F]N=%LG:2==+"`D=&AI<RT^7V9O;G1?<VEZ95]P
M="DI.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!N97<@:6YT97)N86P@;&EN:R!A;F0@<F5T=7)N<R!I=',@:61E;G1I9FEE
M<BX@06X@:6YT97)N86P*("`@("`J(&QI;FL@:7,@82!C;&EC:V%B;&4@87)E
M82!W:&EC:"!D:7)E8W1S('1O(&%N;W1H97(@<&QA8V4@=VET:&EN('1H90H@
M("`@("H@9&]C=6UE;G0N"B`@("`@*B!4:&4@:61E;G1I9FEE<B!C86X@=&AE
M;B!B92!P87-S960@=&\@1FEL95]01$8Z.F-E;&PL($9I;&5?4$1&.CIW<FET
M92P*("`@("`J($9I;&5?4$1&.CII;6%G92!O<B!&:6QE7U!$1CHZ;&EN:RX@
M5&AE(&1E<W1I;F%T:6]N(&ES(&1E9FEN960@=VET:`H@("`@("H@1FEL95]0
M1$8Z.G-E=$QI;FLN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ8V5L
M;`H@("`@("H@0'-E92!&:6QE7U!$1CHZ5W)I=&4*("`@("`J($!S964@1FEL
M95]01$8Z.FEM86=E"B`@("`@*B!`<V5E($9I;&5?4$1&.CI,:6YK"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CI3971,:6YK"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%D9$QI;FLH*0H@("`@>PH@("`@("`@("1N(#T@8V]U;G0H)'1H:7,M/E]L
M:6YK<RD@*R`Q.PH@("`@("`@("1T:&ES+3Y?;&EN:W-;)&Y=(#T@87)R87DH
M,"P@,"D["B`@("`@("`@<F5T=7)N("1N.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5F:6YE<R!T:&4@<&%G92!A;F0@<&]S:71I;VX@82!L:6YK('!O:6YT
M<R!T;RX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;&EN:R`@5&AE
M(&QI;FL@:61E;G1I9FEE<B!R971U<FYE9"!B>2!&:6QE7U!$1CHZ861D3&EN
M:RX*("`@("`J($!P87)A;2!F;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!T
M87)G970@<&]S:71I;VX[("TQ(&EN9&EC871E<R!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("!C=7)R96YT('!O<VET:6]N+B!4:&4@9&5F875L
M="!V86QU92!I<R`P("AT;W`@;V8*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("!P86=E*2X*("`@("`J($!P87)A;2!I;G1E9V5R("1P86=E("!.=6UB
M97(@;V8@=&%R9V5T('!A9V4[("TQ(&EN9&EC871E<R!T:&4@8W5R<F5N=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@('!A9V4N(%1H:7,@:7,@=&AE
M(&1E9F%U;'0@=F%L=64N"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M861D3&EN:PH@("`@("HO"B`@("!F=6YC=&EO;B!S971,:6YK*"1L:6YK+"`D
M>2`](#`L("1P86=E(#T@+3$I"B`@("!["B`@("`@("`@:68@*"1Y(#T]("TQ
M*2!["B`@("`@("`@("`@("1Y(#T@)'1H:7,M/GD["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<&%G92`]/2`M,2D@>PH@("`@("`@("`@("`D<&%G92`]("1T
M:&ES+3Y?<&%G93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]L:6YK<ULD
M;&EN:UT@/2!A<G)A>2@D<&%G92P@)'DI.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4'5T<R!A(&QI;FL@;VX@82!R96-T86YG=6QA<B!A<F5A(&]F('1H92!P
M86=E+B!497AT(&]R(&EM86=E(&QI;FMS(&%R90H@("`@("H@9V5N97)A;&QY
M('!U="!V:6$@1FEL95]01$8Z.F-E;&PL($9I;&5?4$1&.CI7<FET92!O<B!&
M:6QE7U!$1CHZ:6UA9V4L"B`@("`@*B!B=70@=&AI<R!M971H;V0@8V%N(&)E
M('5S969U;"!F;W(@:6YS=&%N8V4@=&\@9&5F:6YE(&$@8VQI8VMA8FQE(&%R
M96$*("`@("`J(&EN<VED92!A;B!I;6%G92X*("`@("`J"B`@("`@*B!`<&%R
M86T@9FQO870@)'@@("`@("`@06)S8VES<V$@;V8@=&AE('5P<&5R+6QE9G0@
M8V]R;F5R(&]F('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@9FQO870@
M)'D@("`@("`@3W)D:6YA=&4@;V8@=&AE('5P<&5R+6QE9G0@8V]R;F5R(&]F
M('1H92!R96-T86YG;&4N"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@
M5VED=&@@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A;2!F;&]A="`D
M:&5I9VAT("!(96EG:'0@;V8@=&AE(')E8W1A;F=L92X*("`@("`J($!P87)A
M;2!M:7AE9"`D;&EN:R`@("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE9"!B
M>2!&:6QE7U!$1CHZ861D3&EN:RX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?
M4$1&.CIA9&1,:6YK"B`@("`@*B!`<V5E($9I;&5?4$1&.CIC96QL"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CI7<FET90H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M:6UA9V4*("`@("`J+PH@("`@9G5N8W1I;VX@;&EN:R@D>"P@)'DL("1W:61T
M:"P@)&AE:6=H="P@)&QI;FLI"B`@("!["B`@("`@("`@+RH@4V5T('5P('1H
M92!C;V]R9&EN871E<R!W:71H(&-O<G)E8W0@<V-A;&EN9R!I;B!P="X@*B\*
M("`@("`@("`D>"`@("`@(#T@)'1H:7,M/E]T;U!T*"1X*3L*("`@("`@("`D
M>2`@("`@(#T@)'1H:7,M/FA0="`M("1T:&ES+3Y?=&]0="@D>2D["B`@("`@
M("`@)'=I9'1H("`]("1T:&ES+3Y?=&]0="@D=VED=&@I.PH@("`@("`@("1H
M96EG:'0@/2`D=&AI<RT^7W1O4'0H)&AE:6=H="D["@H@("`@("`@("\J(%-A
M=F4@;&EN:R!T;R!P86=E(&QI;FMS(&%R<F%Y+B`J+PH@("`@("`@("1T:&ES
M+3Y?;&EN:R@D>"P@)'DL("1W:61T:"P@)&AE:6=H="P@)&QI;FLI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4')I;G1S(&$@8VAA<F%C=&5R('-T<FEN9RX@
M5&AE(&]R:6=I;B!I<R!O;B!T:&4@;&5F="!O9B!T:&4@9FER<W0*("`@("`J
M(&-H87)A8W1E<BP@;VX@=&AE(&)A<V5L:6YE+B!4:&ES(&UE=&AO9"!A;&QO
M=W,@=&\@<&QA8V4@82!S=')I;F<*("`@("`J('!R96-I<V5L>2!O;B!T:&4@
M<&%G92P@8G5T(&ET(&ES('5S=6%L;'D@96%S:65R('1O('5S92!&:6QE7U!$
M1CHZ8V5L;"P*("`@("`J($9I;&5?4$1&.CIM=6QT:4-E;&P@;W(@1FEL95]0
M1$8Z.E=R:71E('=H:6-H(&%R92!T:&4@<W1A;F1A<F0@;65T:&]D<R!T;PH@
M("`@("H@<')I;G0@=&5X="X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@
M)'@@("`@("!!8G-C:7-S82!O9B!T:&4@;W)I9VEN+@H@("`@("H@0'!A<F%M
M(&9L;V%T("1Y("`@("`@3W)D:6YA=&4@;V8@=&AE(&]R:6=I;BX*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@(%-T<FEN9R!T;R!P<FEN="X*("`@("`J
M"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971&;VYT"B`@("`@*B!`<V5E($9I
M;&5?4$1&.CIC96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CIM=6QT:4-E;&P*
M("`@("`J($!S964@1FEL95]01$8Z.E=R:71E"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1E>'0H)'@L("1Y+"`D=&5X="D*("`@('L*("`@("`@("`O*B!38V%L
M92!C;V]R9&EN871E<R!I;G1O('!O:6YT<R!A;F0@<V5T(&-O<G)E8W0@62!P
M;W-I=&EO;BX@*B\*("`@("`@("`D>"`]("1T:&ES+3Y?=&]0="@D>"D["B`@
M("`@("`@)'D@/2`D=&AI<RT^:%!T("T@)'1H:7,M/E]T;U!T*"1Y*3L*"B`@
M("`@("`@+RH@17-C87!E(&%N>2!P;W1E;G1I86QL>2!H87)M9G5L(&-H87)A
M8W1E<G,N("HO"B`@("`@("`@)'1E>'0@/2`D=&AI<RT^7V5S8V%P92@D=&5X
M="D["@H@("`@("`@("1O=70@/2!S<')I;G1F*"="5"`E+C)F("4N,F8@5&0@
M*"5S*2!4:B!%5"<L("1X+"`D>2P@)'1E>'0I.PH@("`@("`@(&EF("@D=&AI
M<RT^7W5N9&5R;&EN92`F)B`D=&5X="`A/2`G)RD@>PH@("`@("`@("`@("`D
M;W5T("X]("<@)R`N("1T:&ES+3Y?9&]5;F1E<FQI;F4H)'@L("1Y+"`D=&5X
M="D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;W5T*"1O=70I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5VAE;F5V97(@82!P86=E(&)R96%K(&-O;F1I
M=&EO;B!I<R!M970L('1H92!M971H;V0@:7,@8V%L;&5D+"!A;F0@=&AE"B`@
M("`@*B!B<F5A:R!I<R!I<W-U960@;W(@;F]T(&1E<&5N9&EN9R!O;B!T:&4@
M<F5T=7)N960@=F%L=64N(%1H92!D969A=6QT"B`@("`@*B!I;7!L96UE;G1A
M=&EO;B!R971U<FYS(&$@=F%L=64@86-C;W)D:6YG('1O('1H92!M;V1E('-E
M;&5C=&5D(&)Y"B`@("`@*B!&:6QE7U!$1CIS971!=71O4&%G94)R96%K+@H@
M("`@("H@5&AI<R!M971H;V0@:7,@8V%L;&5D(&%U=&]M871I8V%L;'D@86YD
M('-H;W5L9"!N;W0@8F4@8V%L;&5D(&1I<F5C=&QY"B`@("`@*B!B>2!T:&4@
M87!P;&EC871I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@
M("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T075T;U!A9V5"<F5A:RX*
M("`@("`J+PH@("`@9G5N8W1I;VX@86-C97!T4&%G94)R96%K*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]A=71O7W!A9V5?8G)E86L["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!0<FEN=',@82!C96QL("AR96-T86YG=6QA<B!A
M<F5A*2!W:71H(&]P=&EO;F%L(&)O<F1E<G,L(&)A8VMG<F]U;F0*("`@("`J
M(&-O;&]R(&%N9"!C:&%R86-T97(@<W1R:6YG+B!4:&4@=7!P97(M;&5F="!C
M;W)N97(@;V8@=&AE(&-E;&P*("`@("`J(&-O<G)E<W!O;F1S('1O('1H92!C
M=7)R96YT('!O<VET:6]N+B!4:&4@=&5X="!C86X@8F4@86QI9VYE9"!O<@H@
M("`@("H@8V5N=&5R960N($%F=&5R('1H92!C86QL+"!T:&4@8W5R<F5N="!P
M;W-I=&EO;B!M;W9E<R!T;R!T:&4@<FEG:'0@;W(@=&\*("`@("`J('1H92!N
M97AT(&QI;F4N($ET(&ES('!O<W-I8FQE('1O('!U="!A(&QI;FL@;VX@=&AE
M('1E>'0N"B`@("`@*B!)9B!A=71O;6%T:6,@<&%G92!B<F5A:VEN9R!I<R!E
M;F%B;&5D(&%N9"!T:&4@8V5L;"!G;V5S(&)E>6]N9"!T:&4*("`@("`J(&QI
M;6ET+"!A('!A9V4@8G)E86L@:7,@9&]N92!B969O<F4@;W5T<'5T=&EN9RX*
M("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@0V5L;"!W:61T
M:"X@268@,"P@=&AE(&-E;&P@97AT96YD<R!U<"!T;R!T:&4@<FEG:'0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!M87)G:6XN"B`@("`@*B!`<&%R
M86T@9FQO870@)&AE:6=H="`@0V5L;"!H96EG:'0N($1E9F%U;'0@=F%L=64Z
M(#`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1T97AT("`@4W1R:6YG('1O('!R
M:6YT+B!$969A=6QT('9A;'5E.B!E;7!T>2X*("`@("`J($!P87)A;2!M:7AE
M9"`D8F]R9&5R("!);F1I8V%T97,@:68@8F]R9&5R<R!M=7-T(&)E(&1R87=N
M(&%R;W5N9"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!C96QL
M+B!4:&4@=F%L=64@8V%N(&)E(&5I=&AE<B!A(&YU;6)E<CH*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("T@,#H@;F\@8F]R9&5R("AD969A=6QT
M*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`Q.B!F<F%M90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&]R(&$@<W1R:6YG(&-O;G1A
M:6YI;F<@<V]M92!O<B!A;&P@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@9F]L;&]W:6YG(&-H87)A8W1E<G,@*&EN(&%N>2!O<F1E<BDZ
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($PZ(&QE9G0*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@5#H@=&]P"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`M(%(Z(')I9VAT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`M($(Z(&)O='1O;0H@("`@("H@0'!A<F%M
M(&EN=&5G97(@)&QN("`@($EN9&EC871E<R!W:&5R92!T:&4@8W5R<F5N="!P
M;W-I=&EO;B!S:&]U;&0@9V\*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!A9G1E<B!T:&4@8V%L;"X@4&]S<VEB;&4@=F%L=65S(&%R93H*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("T@,#H@=&\@=&AE(')I9VAT("AD
M969A=6QT*0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`Q.B!T
M;R!T:&4@8F5G:6YN:6YG(&]F('1H92!N97AT(&QI;F4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("T@,CH@8F5L;W<*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!0=71T:6YG(#$@:7,@97%U:79A;&5N="!T;R!P=71T
M:6YG(#`@86YD(&-A;&QI;F<*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!&:6QE7U!$1CHZ;F5W3&EN92!J=7-T(&%F=&5R+@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D86QI9VX@($%L;&]W<R!T;R!C96YT97(@;W(@86QI9VX@=&AE
M('1E>'0N(%!O<W-I8FQE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M=F%L=65S(&%R93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@
M3"!O<B!E;7!T>2!S=')I;F<Z(&QE9G0@*&1E9F%U;'0I"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`M($,Z(&-E;G1E<@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@+2!2.B!R:6=H=`H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&9I;&P@($EN9&EC871E<R!I9B!T:&4@8V5L;"!F:6QL('1Y<&4N
M(%!O<W-I8FQE('9A;'5E<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M(&%R93H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@,#H@=')A
M;G-P87)E;G0@*&1E9F%U;'0I"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`M(#$Z('!A:6YT960*("`@("`J($!P87)A;2!S=')I;F<@)&QI;FL@
M("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE9"!B>0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@($9I;&5?4$1&.F%D9$QI;FLN"B`@
M("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1F]N=`H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T1')A=T-O;&]R"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIS971&:6QL0V]L;W(*("`@("`J($!S964@1FEL95]01$8Z.G-E=$QI;F57
M:61T:`H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@("`@("H@0'-E
M92!&:6QE7U!$1CHZ;F5W3&EN90H@("`@("H@0'-E92!&:6QE7U!$1CHZ;75L
M=&E#96QL"B`@("`@*B!`<V5E($9I;&5?4$1&.CI7<FET90H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ<V5T075T;U!A9V5"<F5A:PH@("`@("HO"B`@("!F=6YC
M=&EO;B!C96QL*"1W:61T:"P@)&AE:6=H="`](#`L("1T97AT(#T@)R<L("1B
M;W)D97(@/2`P+"`D;&X@/2`P+"`D86QI9VX@/2`G)RP@)&9I;&P@/2`P+"`D
M;&EN:R`]("<G*0H@("`@>PH@("`@("`@("1K(#T@)'1H:7,M/E]S8V%L93L*
M("`@("`@("!I9B`H)'1H:7,M/GD@*R`D:&5I9VAT(#X@)'1H:7,M/E]P86=E
M7V)R96%K7W1R:6=G97(@)B8@(21T:&ES+3Y?:6Y?9F]O=&5R("8F("1T:&ES
M+3Y!8V-E<'1086=E0G)E86LH*2D@>PH@("`@("`@("`@("`D>"`]("1T:&ES
M+3YX.PH@("`@("`@("`@("`D=W,@/2`D=&AI<RT^7W=O<F1?<W!A8VEN9SL*
M("`@("`@("`@("`@:68@*"1W<R`^(#`I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=V]R9%]S<&%C:6YG(#T@,#L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"<P(%1W)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/F%D9%!A9V4H)'1H:7,M/E]C=7)R96YT7V]R:65N=&%T:6]N*3L*("`@
M("`@("`@("`@)'1H:7,M/G@@/2`D>#L*("`@("`@("`@("`@:68@*"1W<R`^
M(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@
M)'=S.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT9B@G)2XS
M9B!4=R<L("1W<R`J("1K*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("`@("`@:68@*"1W:61T:"`]/2`P*2!["B`@("`@("`@("`@("1W:61T:"`]
M("1T:&ES+3YW("T@)'1H:7,M/E]R:6=H=%]M87)G:6X@+2`D=&AI<RT^>#L*
M("`@("`@("!]"B`@("`@("`@)',@/2`G)SL*("`@("`@("!I9B`H)&9I;&P@
M/3T@,2!\?"`D8F]R9&5R(#T](#$I('L*("`@("`@("`@("`@:68@*"1F:6QL
M(#T](#$I('L*("`@("`@("`@("`@("`@("1O<"`]("@D8F]R9&5R(#T](#$I
M(#\@)T(G(#H@)V8G.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&]P(#T@)U,G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1S
M(#T@<W!R:6YT9B@G)2XR9B`E+C)F("4N,F8@)2XR9B!R92`E<R`G+"`D=&AI
M<RT^>"`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D:RP@)'=I9'1H
M("H@)&LL("TD:&5I9VAT("H@)&LL("1O<"D["B`@("`@("`@?0H@("`@("`@
M(&EF("AI<U]S=')I;F<H)&)O<F1E<BDI('L*("`@("`@("`@("`@:68@*'-T
M<G!O<R@D8F]R9&5R+"`G3"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@)',@+CT@<W!R:6YT9B@G)2XR9B`E+C)F(&T@)2XR9B`E+C)F(&P@4R`G
M+"`D=&AI<RT^>"`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@*B`D:RP@
M)'1H:7,M/G@@*B`D:RP@*"1T:&ES+3YH("T@*"1T:&ES+3YY("L@)&AE:6=H
M="DI("H@)&LI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')P
M;W,H)&)O<F1E<BP@)U0G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("1S("X]('-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@)RP@
M)'1H:7,M/G@@*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI("H@)&LL("@D
M=&AI<RT^>"`K("1W:61T:"D@*B`D:RP@*"1T:&ES+3YH("T@)'1H:7,M/GDI
M("H@)&LI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AS=')P;W,H
M)&)O<F1E<BP@)U(G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1S
M("X]('-P<FEN=&8H)R4N,F8@)2XR9B!M("4N,F8@)2XR9B!L(%,@)RP@*"1T
M:&ES+3YX("L@)'=I9'1H*2`J("1K+"`H)'1H:7,M/F@@+2`D=&AI<RT^>2D@
M*B`D:RP@*"1T:&ES+3YX("L@)'=I9'1H*2`J("1K+"`H)'1H:7,M/F@@+2`H
M)'1H:7,M/GD@*R`D:&5I9VAT*2D@*B`D:RD["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*'-T<G!O<R@D8F]R9&5R+"`G0B<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@)',@+CT@<W!R:6YT9B@G)2XR9B`E+C)F(&T@
M)2XR9B`E+C)F(&P@4R`G+"`D=&AI<RT^>"`J("1K+"`H)'1H:7,M/F@@+2`H
M)'1H:7,M/GD@*R`D:&5I9VAT*2D@*B`D:RP@*"1T:&ES+3YX("L@)'=I9'1H
M*2`J("1K+"`H)'1H:7,M/F@@+2`H)'1H:7,M/GD@*R`D:&5I9VAT*2D@*B`D
M:RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1T97AT
M("$]("<G*2!["B`@("`@("`@("`@(&EF("@D86QI9VX@/3T@)U(G*2!["B`@
M("`@("`@("`@("`@("`D9'@@/2`D=VED=&@@+2`D=&AI<RT^7V-E;&Q?;6%R
M9VEN("T@)'1H:7,M/F=E=%-T<FEN9U=I9'1H*"1T97AT*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*"1A;&EG;B`]/2`G0R<I('L*("`@("`@("`@("`@("`@
M("1D>"`]("@D=VED=&@@+2`D=&AI<RT^9V5T4W1R:6YG5VED=&@H)'1E>'0I
M*2`O(#(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M9'@@/2`D=&AI<RT^7V-E;&Q?;6%R9VEN.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)RDG+"`G7%PI)RP@<W1R7W)E
M<&QA8V4H)R@G+"`G7%PH)RP@<W1R7W)E<&QA8V4H)UQ<)RP@)UQ<7%PG+"`D
M=&5X="DI*3L*("`@("`@("`@("`@)'1E<W0R(#T@*"@N-2`J("1H96EG:'0I
M("L@*"XS("H@)'1H:7,M/E]F;VYT7W-I>F4I*3L*("`@("`@("`@("`@)'1E
M<W0Q(#T@)'1H:7,M/F9H4'0@+2`H*"1T:&ES+3YY("L@)'1E<W0R*2`J("1K
M*3L*("`@("`@("`@("`@)',@+CT@<W!R:6YT9B@G0E0@)2XR9B`E+C)F(%1D
M("@E<RD@5&H@150G+"`H)'1H:7,M/G@@*R`D9'@I("H@)&LL("@D=&AI<RT^
M:"`M("@D=&AI<RT^>2`K("XU("H@)&AE:6=H="`K("XS("H@)'1H:7,M/E]F
M;VYT7W-I>F4I*2`J("1K+"`D=&5X="D["B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7W5N9&5R;&EN92D@>PH@("`@("`@("`@("`@("`@)',@+CT@)R`G("X@
M)'1H:7,M/E]D;U5N9&5R;&EN92@D=&AI<RT^>"`K("1D>"P@)'1H:7,M/GD@
M*R`N-2`J("1H96EG:'0@*R`N,R`J("1T:&ES+3Y?9F]N=%]S:7IE+"`D=&5X
M="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1L:6YK*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&EN:R@D=&AI<RT^>"`K("1D>"P@)'1H
M:7,M/GD@*R`N-2`J("1H96EG:'0M+C4@*B`D=&AI<RT^7V9O;G1?<VEZ92P@
M)'1H:7,M/F=E=%-T<FEN9U=I9'1H*"1T97AT*2P@)'1H:7,M/E]F;VYT7W-I
M>F4L("1L:6YK*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H)',I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)',I.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7VQA<W1?:&5I9VAT(#T@)&AE:6=H=#L*("`@
M("`@("!I9B`H)&QN(#X@,"D@>PH@("`@("`@("`@("`O*B!';R!T;R!N97AT
M(&QI;F4N("HO"B`@("`@("`@("`@("1T:&ES+3YY("L]("1H96EG:'0["B`@
M("`@("`@("`@(&EF("@D;&X@/3T@,2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G@@*ST@)'=I9'1H
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D
M(&%L;&]W<R!P<FEN=&EN9R!T97AT('=I=&@@;&EN92!B<F5A:W,N(%1H97D@
M8V%N(&)E"B`@("`@*B!A=71O;6%T:6,@*&%S('-O;VX@87,@=&AE('1E>'0@
M<F5A8VAE<R!T:&4@<FEG:'0@8F]R9&5R(&]F('1H92!C96QL*2!O<@H@("`@
M("H@97AP;&EC:70@*'9I82!T:&4@7&X@8VAA<F%C=&5R*2X@07,@;6%N>2!C
M96QL<R!A<R!N96-E<W-A<GD@87)E(&]U='!U="P*("`@("`J(&]N92!B96QO
M=R!T:&4@;W1H97(N"B`@("`@*B!497AT(&-A;B!B92!A;&EG;F5D+"!C96YT
M97)E9"!O<B!J=7-T:69I960N(%1H92!C96QL(&)L;V-K(&-A;B!B90H@("`@
M("H@9G)A;65D(&%N9"!T:&4@8F%C:V=R;W5N9"!P86EN=&5D+@H@("`@("H*
M("`@("`J($!P87)A;2!F;&]A="`D=VED=&@@("!7:61T:"!O9B!C96QL<RX@
M268@,"P@=&AE>2!E>'1E;F0@=7`@=&\@=&AE(')I9VAT"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@;6%R9VEN(&]F('1H92!P86=E+@H@("`@("H@
M0'!A<F%M(&9L;V%T("1H96EG:'0@($AE:6=H="!O9B!C96QL<RX*("`@("`J
M($!P87)A;2!S=')I;F<@)'1E>'0@("!3=')I;F<@=&\@<')I;G0N"B`@("`@
M*B!`<&%R86T@;6EX960@)&)O<F1E<B`@26YD:6-A=&5S(&EF(&)O<F1E<G,@
M;75S="!B92!D<F%W;B!A<F]U;F0@=&AE(&-E;&P*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!B;&]C:RX@5&AE('9A;'5E(&-A;B!B92!E:71H97(@
M82!N=6UB97(Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M(#`Z
M(&YO(&)O<F1E<B`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("T@,3H@9G)A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("!O<B!A('-T<FEN9R!C;VYT86EN:6YG('-O;64@;W(@86QL(&]F('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&9O;&QO=VEN9R!C:&%R86-T
M97)S("AI;B!A;GD@;W)D97(I.@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("T@3#H@;&5F=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("T@5#H@=&]P"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M+2!2.B!R:6=H=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("T@
M0CH@8F]T=&]M"B`@("`@*B!`<&%R86T@<W1R:6YG("1A;&EG;B`@4V5T<R!T
M:&4@=&5X="!A;&EG;FUE;G0N(%!O<W-I8FQE('9A;'5E<R!A<F4Z"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`M($PZ(&QE9G0@86QI9VYM96YT
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`M($,Z(&-E;G1E<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2!2.B!R:6=H="!A;&EG
M;FUE;G0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@2CH@:G5S
M=&EF:6-A=&EO;B`H9&5F875L="!V86QU92D*("`@("`J($!P87)A;2!I;G1E
M9V5R("1F:6QL("!);F1I8V%T97,@:68@=&AE(&-E;&P@8F%C:V=R;W5N9"!M
M=7-T.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@+2`P.B!T<F%N
M<W!A<F5N="`H9&5F875L="D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("T@,3H@<&%I;G1E9`H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z
M.G-E=$9O;G0*("`@("`J($!S964@1FEL95]01$8Z.G-E=$1R87=#;VQO<@H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T1FEL;$-O;&]R"B`@("`@*B!`<V5E
M($9I;&5?4$1&.CIS971,:6YE5VED=&@*("`@("`J($!S964@1FEL95]01$8Z
M.F-E;&P*("`@("`J($!S964@1FEL95]01$8Z.G=R:71E"B`@("`@*B!`<V5E
M($9I;&5?4$1&.CIS971!=71O4&%G94)R96%K"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UU;'1I0V5L;"@D=VED=&@L("1H96EG:'0L("1T97AT+"`D8F]R9&5R
M(#T@,"P@)&%L:6=N(#T@)THG+"`D9FEL;"`](#`I"B`@("!["B`@("`@("`@
M)&-W(#T@)B1T:&ES+3Y?8W5R<F5N=%]F;VYT6R=C=R==.PH@("`@("`@(&EF
M("@D=VED=&@@/3T@,"D@>PH@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^
M=R`M("1T:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@
M?0H@("`@("`@("1W;6%X(#T@*"1W:61T:"TR("H@)'1H:7,M/E]C96QL7VUA
M<F=I;BD@*B`Q,#`P("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@("`@("`@)',@
M/2!S=')?<F5P;&%C92@B7'(B+"`G)RP@)'1E>'0I.PH@("`@("`@("1N8B`]
M('-T<FQE;B@D<RD["B`@("`@("`@:68@*"1N8B`^(#`@)B8@)'-;)&YB+3%=
M(#T](")<;B(I('L*("`@("`@("`@("`@)&YB+2T["B`@("`@("`@?0H@("`@
M("`@("1B(#T@,#L*("`@("`@("!I9B`H)&)O<F1E<BD@>PH@("`@("`@("`@
M("!I9B`H)&)O<F1E<B`]/2`Q*2!["B`@("`@("`@("`@("`@("`D8F]R9&5R
M(#T@)TQ44D(G.PH@("`@("`@("`@("`@("`@)&(@/2`G3%)4)SL*("`@("`@
M("`@("`@("`@("1B,B`]("=,4B<["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D8C(@/2`G)SL*("`@("`@("`@("`@("`@(&EF("AS
M=')P;W,H)&)O<F1E<BP@)TPG*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@
M("`@("`@("`D8C(@+CT@)TPG.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@:68@*'-T<G!O<R@D8F]R9&5R+"`G4B<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("`@("`@("`@("1B,B`N/2`G4B<["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D8B`]("AS=')P;W,H)&)O<F1E<BP@
M)U0G*2`A/3T@9F%L<V4I(#\@)&(R("X@)U0G(#H@)&(R.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@("1S97`@/2`M,3L*("`@("`@("`D:2`@
M(#T@,#L*("`@("`@("`D:B`@(#T@,#L*("`@("`@("`D;"`@(#T@,#L*("`@
M("`@("`D;G,@(#T@,#L*("`@("`@("`D;FP@(#T@,3L*("`@("`@("!W:&EL
M92`H)&D@/"`D;F(I('L*("`@("`@("`@("`@+RH@1V5T(&YE>'0@8VAA<F%C
M=&5R+B`J+PH@("`@("`@("`@("`D8R`]("1S6R1I73L*("`@("`@("`@("`@
M:68@*"1C(#T](")<;B(I('L*("`@("`@("`@("`@("`@("\J($5X<&QI8VET
M(&QI;F4@8G)E86LN("HO"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]W
M;W)D7W-P86-I;F<@/B`P*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]W;W)D7W-P86-I;F<@/2`P.PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"<P(%1W)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=&AI<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@
M)&HL("1I+21J*2P@)&(L(#(L("1A;&EG;BP@)&9I;&PI.PH@("`@("`@("`@
M("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*("`@("`@
M("`@("`@("`@("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`](#`["B`@
M("`@("`@("`@("`@("`D;G,@/2`P.PH@("`@("`@("`@("`@("`@)&YL*RL[
M"B`@("`@("`@("`@("`@("!I9B`H)&)O<F1E<B`F)B`D;FP@/3T@,BD@>PH@
M("`@("`@("`@("`@("`@("`@("1B(#T@)&(R.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"1C(#T]("<@)RD@>PH@("`@("`@("`@("`@("`@)'-E
M<"`]("1I.PH@("`@("`@("`@("`@("`@)&QS(#T@)&P["B`@("`@("`@("`@
M("`@("`D;G,K*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;"`K/2`D
M8W=;)&-=.PH@("`@("`@("`@("!I9B`H)&P@/B`D=VUA>"D@>PH@("`@("`@
M("`@("`@("`@+RH@075T;VUA=&EC(&QI;F4@8G)E86LN("HO"B`@("`@("`@
M("`@("`@("!I9B`H)'-E<"`]/2`M,2D@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D:2`]/2`D:BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:2LK
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]W;W)D7W-P86-I;F<@/B`P*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=V]R9%]S<&%C:6YG(#T@,#L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)S`@5'<G*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-E;&PH
M)'=I9'1H+"`D:&5I9VAT+"!S=6)S='(H)',L("1J+"`D:2`M("1J*2P@)&(L
M(#(L("1A;&EG;BP@)&9I;&PI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&%L:6=N(#T]("=*)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W=O<F1?<W!A8VEN9R`]("@D
M;G,^,2D@/R`H)'=M87@@+2`D;',I+S$P,#`@*B`D=&AI<RT^7V9O;G1?<VEZ
M92`O("@D;G,@+2`Q*2`Z(#`["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;W5T*'-P<FEN=&8H)R4N,V8@5'<G+"`D=&AI<RT^7W=O<F1?<W!A
M8VEN9R`J("1T:&ES+3Y?<V-A;&4I*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-E;&PH)'=I9'1H+"`D:&5I
M9VAT+"!S=6)S='(H)',L("1J+"`D<V5P("T@)&HI+"`D8BP@,BP@)&%L:6=N
M+"`D9FEL;"D["B`@("`@("`@("`@("`@("`@("`@)&D@/2`D<V5P("L@,3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1S97`@/2`M,3L*
M("`@("`@("`@("`@("`@("1J(#T@)&D["B`@("`@("`@("`@("`@("`D;"`]
M(#`["B`@("`@("`@("`@("`@("`D;G,@/2`P.PH@("`@("`@("`@("`@("`@
M)&YL*RL["B`@("`@("`@("`@("`@("!I9B`H)&)O<F1E<B`F)B`D;FP@/3T@
M,BD@>PH@("`@("`@("`@("`@("`@("`@("1B(#T@)&(R.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M)&DK*SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O*B!,87-T
M(&-H=6YK+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W=O<F1?<W!A8VEN9R`^
M(#`I('L*("`@("`@("`@("`@)'1H:7,M/E]W;W)D7W-P86-I;F<@/2`P.PH@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G,"!4=R<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H)&)O<F1E<B`F)B!S=')P;W,H)&)O<F1E<BP@)T(G*2`A/3T@
M9F%L<V4I('L*("`@("`@("`@("`@)&(@+CT@)T(G.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^8V5L;"@D=VED=&@L("1H96EG:'0L('-U8G-T<B@D<RP@
M)&HL("1I*2P@)&(L(#(L("1A;&EG;BP@)&9I;&PI.PH@("`@("`@("1T:&ES
M+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@;65T:&]D('!R:6YT<R!T97AT(&9R;VT@=&AE(&-U<G)E;G0@
M<&]S:71I;VXN(%=H96X@=&AE(')I9VAT"B`@("`@*B!M87)G:6X@:7,@<F5A
M8VAE9"`H;W(@=&AE(%QN(&-H87)A8W1E<B!I<R!M970I(&$@;&EN92!B<F5A
M:R!O8V-U<G,@86YD"B`@("`@*B!T97AT(&-O;G1I;G5E<R!F<F]M('1H92!L
M969T(&UA<F=I;BX@57!O;B!M971H;V0@97AI="P@=&AE(&-U<G)E;G0*("`@
M("`J('!O<VET:6]N(&ES(&QE9G0@:G5S="!A="!T:&4@96YD(&]F('1H92!T
M97AT+@H@("`@("H@270@:7,@<&]S<VEB;&4@=&\@<'5T(&$@;&EN:R!O;B!T
M:&4@=&5X="X*("`@("`J"B`@("`@*B!%>&%M<&QE.@H@("`@("H@+R]"96=I
M;B!W:71H(')E9W5L87(@9F]N=`H@("`@("H@)'!D9BT^<V5T1F]N="@G07)I
M86PG+"<G+#$T*3L*("`@("`J("1P9&8M/G=R:71E*#4L)U9I<VET("<I.PH@
M("`@("H@+R]4:&5N('!U="!A(&)L=64@=6YD97)L:6YE9"!L:6YK"B`@("`@
M*B`D<&1F+3YS971497AT0V]L;W(H,"PP+#(U-2D["B`@("`@*B`D<&1F+3YS
M971&;VYT*"<G+"=5)RD["B`@("`@*B`D<&1F+3YW<FET92@U+"=W=W<N9G!D
M9BYO<F<G+"=H='1P.B\O=W=W+F9P9&8N;W)G)RD["B`@("`@*@H@("`@("H@
M0'!A<F%M(&9L;V%T("1H96EG:'0@($QI;F4@:&5I9VAT+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D=&5X="`@(%-T<FEN9R!T;R!P<FEN="X*("`@("`J($!P
M87)A;2!M:7AE9"`D;&EN:R`@("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE
M9"!B>2!!9&1,:6YK*"DN"B`@("`@*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M<V5T1F]N=`H@("`@("H@0'-E92!&:6QE7U!$1CHZ861D3&EN:PH@("`@("H@
M0'-E92!&:6QE7U!$1CHZ;75L=&E#96QL"B`@("`@*B!`<V5E($9I;&5?4$1&
M.CIS971!=71O4&%G94)R96%K"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E
M*"1H96EG:'0L("1T97AT+"`D;&EN:R`]("<G*0H@("`@>PH@("`@("`@("1C
M=R`]("8D=&AI<RT^7V-U<G)E;G1?9F]N=%LG8W<G73L*("`@("`@("`D=VED
M=&@@/2`D=&AI<RT^=R`M("1T:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M
M/G@["B`@("`@("`@)'=M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L
M;%]M87)G:6XI("H@,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@
M("1S(#T@<W1R7W)E<&QA8V4H(EQR(BP@)R<L("1T97AT*3L*("`@("`@("`D
M;F(@/2!S=')L96XH)',I.PH@("`@("`@("1S97`@/2`M,3L*("`@("`@("`D
M:2`](#`["B`@("`@("`@)&H@/2`P.PH@("`@("`@("1L(#T@,#L*("`@("`@
M("`D;FP@/2`Q.PH@("`@("`@('=H:6QE("@D:2`\("1N8BD@>PH@("`@("`@
M("`@("`O*B!'970@;F5X="!C:&%R86-T97(N("HO"B`@("`@("`@("`@("1C
M(#T@)'-[)&E].PH@("`@("`@("`@("!I9B`H)&,@/3T@(EQN(BD@>PH@("`@
M("`@("`@("`@("`@+RH@17AP;&EC:70@;&EN92!B<F5A:RX@*B\*("`@("`@
M("`@("`@("`@("1T:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R
M*"1S+"`D:BP@)&D@+2`D:BDL(#`L(#(L("<G+"`P+"`D;&EN:RD["B`@("`@
M("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@)'-E<"`]("TQ.PH@
M("`@("`@("`@("`@("`@)&H@/2`D:3L*("`@("`@("`@("`@("`@("1L(#T@
M,#L*("`@("`@("`@("`@("`@(&EF("@D;FP@/3T@,2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I;CL*("`@
M("`@("`@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M("1T:&ES+3Y?
M<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@("`@("`@("`@("`@
M)'=M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M87)G:6XI("H@
M,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&YL*RL["B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&,@/3T@)R`G*2![
M"B`@("`@("`@("`@("`@("`D<V5P(#T@)&D["B`@("`@("`@("`@("`@("`D
M;',@/2`D;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;"`K/2`D8W=;
M)&-=.PH@("`@("`@("`@("!I9B`H)&P@/B`D=VUA>"D@>PH@("`@("`@("`@
M("`@("`@+RH@075T;VUA=&EC(&QI;F4@8G)E86LN("HO"B`@("`@("`@("`@
M("`@("!I9B`H)'-E<"`]/2`M,2D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^>"`^("1T:&ES+3Y?;&5F=%]M87)G:6XI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+RH@36]V92!T;R!N97AT(&QI;F4N("HO"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA
M<F=I;CL*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/GD@*ST@)&AE
M:6=H=#L*("`@("`@("`@("`@("`@("`@("`@("`@)'=I9'1H(#T@)'1H:7,M
M/G<@+2`D=&AI<RT^7W)I9VAT7VUA<F=I;B`M("1T:&ES+3YX.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D=VUA>"`]("@D=VED=&@@+2`R("H@)'1H:7,M
M/E]C96QL7VUA<F=I;BD@*B`Q,#`P("\@)'1H:7,M/E]F;VYT7W-I>F4["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@("`@
M("`@("`@("1N;"LK.PH@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1I(#T]("1J*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I*RL[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC96QL*"1W:61T:"P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@)&D@
M+2`D:BDL(#`L(#(L("<G+"`P+"`D;&EN:RD["B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC96QL*"1W:61T
M:"P@)&AE:6=H="P@<W5B<W1R*"1S+"`D:BP@)'-E<"`M("1J*2P@,"P@,BP@
M)R<L(#`L("1L:6YK*3L*("`@("`@("`@("`@("`@("`@("`D:2`]("1S97`@
M*R`Q.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-E<"`]
M("TQ.PH@("`@("`@("`@("`@("`@)&H@/2`D:3L*("`@("`@("`@("`@("`@
M("1L(#T@,#L*("`@("`@("`@("`@("`@(&EF("@D;FP@/3T@,2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YX(#T@)'1H:7,M/E]L969T7VUA<F=I
M;CL*("`@("`@("`@("`@("`@("`@("`D=VED=&@@/2`D=&AI<RT^=R`M("1T
M:&ES+3Y?<FEG:'1?;6%R9VEN("T@)'1H:7,M/G@["B`@("`@("`@("`@("`@
M("`@("`@)'=M87@@/2`H)'=I9'1H("T@,B`J("1T:&ES+3Y?8V5L;%]M87)G
M:6XI("H@,3`P,"`O("1T:&ES+3Y?9F]N=%]S:7IE.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&YL*RL["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("!]
M"B`@("`@("`@+RH@3&%S="!C:'5N:RX@*B\*("`@("`@("!I9B`H)&D@(3T@
M)&HI('L*("`@("`@("`@("`@)'1H:7,M/F-E;&PH)&P@+R`Q,#`P("H@)'1H
M:7,M/E]F;VYT7W-I>F4L("1H96EG:'0L('-U8G-T<B@D<RP@)&HL("1I*2P@
M,"P@,"P@)R<L(#`L("1L:6YK*3L*("`@("`@("!]"B`@("!]"@H@("`@("\J
M*@H@("`@("H@=W)I=&4@4F]T871E9"!497AT+@H@("`@("H*("`@("`J(%=R
M:71E('1E>'0@870@86X@86YG;&4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)'@@("`@("`@("!8(&-O;W)D:6YA=&4N"B`@("`@*B!`<&%R86T@
M:6YT96=E<B`D>2`@("`@("`@(%D@8V]O<F1I;F%T92X*("`@("`J($!P87)A
M;2!S=')I;F<@)'1E>'0@("`@("`@5&5X="!T;R!W<FET92X*("`@("`J($!P
M87)A;2!F;&]A="`D=&5X=%]A;F=L92`@06YG;&4@=&\@<F]T871E("A%9RX@
M.3`@/2!B;W1T;VT@=&\@=&]P*2X*("`@("`J($!P87)A;2!F;&]A="`D9F]N
M=%]A;F=L92`@4F]T871E(&-H87)A8W1E<G,@87,@=V5L;"!A<R!T97AT+@H@
M("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=$9O;G0*("`@("`J+PH@
M("`@(&9U;F-T:6]N('=R:71E4F]T871E9"@D>"P@)'DL("1T97AT+"`D=&5X
M=%]A;F=L92P@)&9O;G1?86YG;&4@/2`P*0H@("`@('L*("`@("`@("`@+RH@
M17-C87!E('1E>'0N("HO"B`@("`@("`@("1T97AT(#T@)'1H:7,M/E]E<V-A
M<&4H)'1E>'0I.PH*("`@("`@("`@)&9O;G1?86YG;&4@*ST@.3`@*R`D=&5X
M=%]A;F=L93L*("`@("`@("`@)'1E>'1?86YG;&4@*CT@35]022`O(#$X,#L*
M("`@("`@("`@)&9O;G1?86YG;&4@*CT@35]022`O(#$X,#L*"B`@("`@("`@
M("1T97AT7V1X(#T@8V]S*"1T97AT7V%N9VQE*3L*("`@("`@("`@)'1E>'1?
M9'D@/2!S:6XH)'1E>'1?86YG;&4I.PH@("`@("`@("`D9F]N=%]D>"`](&-O
M<R@D9F]N=%]A;F=L92D["B`@("`@("`@("1F;VYT7V1Y(#T@<VEN*"1F;VYT
M7V%N9VQE*3L*"B`@("`@("`@("1S/2!S<')I;G1F*"="5"`E+C)F("4N,F8@
M)2XR9B`E+C)F("4N,F8@)2XR9B!4;2`H)7,I(%1J($54)RP*("`@("`@("`@
M("`@("`@("`@("`@)'1E>'1?9'@L("1T97AT7V1Y+"`D9F]N=%]D>"P@)&9O
M;G1?9'DL"B`@("`@("`@("`@("`@("`@("`@("1X("H@)'1H:7,M/E]S8V%L
M92P@*"1T:&ES+3YH+21Y*2`J("1T:&ES+3Y?<V-A;&4L("1T97AT*3L*"B`@
M("`@("`@(&EF("@@)'1H:7,M/E]D<F%W7V-O;&]R*2!["B`@("`@("`@("`@
M("`D<STG<2`G("X@)'1H:7,M/E]D<F%W7V-O;&]R("X@)R`G("X@)',@+B`G
M(%$G.PH@("`@("`@("!]"B`@("`@("`@("1T:&ES+3Y?;W5T*"1S*3L*("`@
M("!]"@H@("`@+RHJ"B`@("`@*B!0<FEN=',@86X@:6UA9V4@:6X@=&AE('!A
M9V4N(%1H92!U<'!E<BUL969T(&-O<FYE<B!A;F0@870@;&5A<W0@;VYE(&]F
M"B`@("`@*B!T:&4@9&EM96YS:6]N<R!M=7-T(&)E('-P96-I9FEE9#L@=&AE
M(&AE:6=H="!O<B!T:&4@=VED=&@@8V%N(&)E"B`@("`@*B!C86QC=6QA=&5D
M(&%U=&]M871I8V%L;'D@:6X@;W)D97(@=&\@:V5E<"!T:&4@:6UA9V4@<')O
M<&]R=&EO;G,N"B`@("`@*B!3=7!P;W)T960@9F]R;6%T<R!A<F4@2E!%1R!A
M;F0@4$Y'+@H@("`@("H*("`@("`J($9O<B!*4$5'+"!A;&P@9FQA=F]R<R!A
M<F4@86QL;W=E9#H*("`@("`J("`@+2!G<F%Y('-C86QE<PH@("`@("H@("`M
M('1R=64@8V]L;W)S("@R-"!B:71S*0H@("`@("H@("`M($--64L@*#,R(&)I
M=',I"B`@("`@*@H@("`@("H@1F]R(%!.1RP@87)E(&%L;&]W960Z"B`@("`@
M*B`@("T@9W)A>2!S8V%L97,@;VX@870@;6]S="`X(&)I=',@*#(U-B!L979E
M;',I"B`@("`@*B`@("T@:6YD97AE9"!C;VQO<G,*("`@("`J("`@+2!T<G5E
M(&-O;&]R<R`H,C0@8FET<RD*("`@("`J(&)U="!A<F4@;F]T('-U<'!O<G1E
M9#H*("`@("`J("`@+2!);G1E<FQA8VEN9PH@("`@("H@("`M($%L<&AA(&-H
M86YN96P*("`@("`J"B`@("`@*B!)9B!A('1R86YS<&%R96YT(&-O;&]R(&ES
M(&1E9FEN960L(&ET('=I;&P@8F4@=&%K96X@:6YT;R!A8V-O=6YT("AB=70*
M("`@("`J('=I;&P@8F4@;VYL>2!I;G1E<G!R971E9"!B>2!!8W)O8F%T(#0@
M86YD(&%B;W9E*2X*("`@("`J(%1H92!F;W)M870@8V%N(&)E('-P96-I9FEE
M9"!E>'!L:6-I=&QY(&]R(&EN9F5R<F5D(&9R;VT@=&AE(&9I;&4*("`@("`J
M(&5X=&5N<VEO;BX*("`@("`J($ET(&ES('!O<W-I8FQE('1O('!U="!A(&QI
M;FL@;VX@=&AE(&EM86=E+@H@("`@("H*("`@("`J(%)E;6%R:SH@:68@86X@
M:6UA9V4@:7,@=7-E9"!S979E<F%L('1I;65S+"!O;FQY(&]N92!C;W!Y('=I
M;&P@8F4*("`@("`J(&5M8F5D9&5D(&EN('1H92!F:6QE+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&9I;&4@("!.86UE(&]F('1H92!F:6QE(&-O
M;G1A:6YI;F<@=&AE(&EM86=E+@H@("`@("H@0'!A<F%M(&9L;V%T("1X("`@
M("`@($%B<V-I<W-A(&]F('1H92!U<'!E<BUL969T(&-O<FYE<BX*("`@("`J
M($!P87)A;2!F;&]A="`D>2`@("`@("!/<F1I;F%T92!O9B!T:&4@=7!P97(M
M;&5F="!C;W)N97(N"B`@("`@*B!`<&%R86T@9FQO870@)'=I9'1H("`@5VED
M=&@@;V8@=&AE(&EM86=E(&EN('1H92!P86=E+B!)9B!E<75A;"!T;R!Z97)O
M+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&ET(&ES(&%U=&]M871I
M8V%L;'D@8V%L8W5L871E9"!T;R!K965P('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@(&]R:6=I;F%L('!R;W!O<G1I;VYS+@H@("`@("H@0'!A
M<F%M(&9L;V%T("1H96EG:'0@($AE:6=H="!O9B!T:&4@:6UA9V4@:6X@=&AE
M('!A9V4N($EF(&YO="!S<&5C:69I960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("!O<B!E<75A;"!T;R!Z97)O+"!I="!I<R!A=71O;6%T:6-A;&QY
M(&-A;&-U;&%T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!T;R!K
M965P('1H92!O<FEG:6YA;"!P<F]P;W)T:6]N<RX*("`@("`J($!P87)A;2!S
M=')I;F<@)'1Y<&4@("!);6%G92!F;W)M870N(%!O<W-I8FQE('9A;'5E<R!A
M<F4@*&-A<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!I;G-E;G-I
M=&EV92D@.B!*4$<L($I014<L(%!.1RX@268@;F]T('-P96-I9FEE9"P*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("!T:&4@='EP92!I<R!I;F9E<G)E
M9"!F<F]M('1H92!F:6QE(&5X=&5N<VEO;BX*("`@("`J($!P87)A;2!M:7AE
M9"`D;&EN:R`@("!54DP@;W(@:61E;G1I9FEE<B!R971U<FYE9"!B>2!&:6QE
M7U!$1CHZ861D3&EN:RX*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIA
M9&1,:6YK"B`@("`@*B\*("`@(&9U;F-T:6]N(&EM86=E*"1F:6QE+"`D>"P@
M)'DL("1W:61T:"`](#`L("1H96EG:'0@/2`P+"`D='EP92`]("<G+"`D;&EN
M:R`]("<G*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]I;6%G
M97-;)&9I;&5=*2D@>PH@("`@("`@("`@("`O*B!&:7)S="!U<V4@;V8@:6UA
M9V4L(&=E="!S;VUE(&9I;&4@:6YF;RX@*B\*("`@("`@("`@("`@:68@*"1T
M>7!E(#T]("<G*2!["B`@("`@("`@("`@("`@("`D<&]S(#T@<W1R<G!O<R@D
M9FEL92P@)RXG*3L*("`@("`@("`@("`@("`@(&EF("@D<&]S(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<BAS<')I;G1F*"=);6%G92!F:6QE(&AA<R!N;R!E>'1E;G-I;VX@86YD
M(&YO('1Y<&4@=V%S('-P96-I9FEE9#H@)7,G+"`D9FEL92DI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1Y<&4@/2!S=6)S='(H)&9I
M;&4L("1P;W,@*R`Q*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D='EP
M92`]('-T<G1O;&]W97(H)'1Y<&4I.PH@("`@("`@("`@("`D;7%R(#T@9V5T
M7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"D["B`@("`@("`@("`@('-E=%]M86=I
M8U]Q=6]T97-?<G5N=&EM92@P*3L*("`@("`@("`@("`@:68@*"1T>7!E(#T]
M("=J<&<G('Q\("1T>7!E(#T]("=J<&5G)RD@>PH@("`@("`@("`@("`@("`@
M)&EN9F\@/2`D=&AI<RT^7W!A<G-E2E!'*"1F:6QE*3L*("`@("`@("`@("`@
M?2!E;'-E:68@*"1T>7!E(#T]("=P;F<G*2!["B`@("`@("`@("`@("`@("`D
M:6YF;R`]("1T:&ES+3Y?<&%R<V503D<H)&9I;&4I.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*'-P<FEN=&8H)U5N<W5P<&]R=&5D(&EM86=E(&9I;&4@='EP93H@)7,G
M+"`D='EP92DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('-E=%]M86=I
M8U]Q=6]T97-?<G5N=&EM92@D;7%R*3L*("`@("`@("`@("`@)&EN9F];)VDG
M72`](&-O=6YT*"1T:&ES+3Y?:6UA9V5S*2`K(#$["B`@("`@("`@("`@("1T
M:&ES+3Y?:6UA9V5S6R1F:6QE72`]("1I;F9O.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/E]I;6%G97-;)&9I;&5=.PH@
M("`@("`@('T*"B`@("`@("`@+RH@36%K92!S=7)E(&%L;"!V87)S(&%R92!C
M;VYV97)T960@=&\@<'0@<V-A;&4N("HO"B`@("`@("`@)'@@("`@("`]("1T
M:&ES+3Y?=&]0="@D>"D["B`@("`@("`@)'D@("`@("`]("1T:&ES+3Y?=&]0
M="@D>2D["B`@("`@("`@)'=I9'1H("`]("1T:&ES+3Y?=&]0="@D=VED=&@I
M.PH@("`@("`@("1H96EG:'0@/2`D=&AI<RT^7W1O4'0H)&AE:6=H="D["@H@
M("`@("`@("\J($EF(&YO="!S<&5C:69I960@9&\@875T;VUA=&EC('=I9'1H
M(&%N9"!H96EG:'0@8V%L8W5L871I;VYS+B`J+PH@("`@("`@(&EF("AE;7!T
M>2@D=VED=&@I("8F(&5M<'1Y*"1H96EG:'0I*2!["B`@("`@("`@("`@("1W
M:61T:"`]("1I;F9O6R=W)UT["B`@("`@("`@("`@("1H96EG:'0@/2`D:6YF
M;ULG:"==.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D=VED=&@I*2!["B`@
M("`@("`@("`@("1W:61T:"`]("1H96EG:'0@*B`D:6YF;ULG=R==("\@)&EN
M9F];)V@G73L*("`@("`@("!](&5L<V5I9B`H96UP='DH)&AE:6=H="DI('L*
M("`@("`@("`@("`@)&AE:6=H="`]("1W:61T:"`J("1I;F9O6R=H)UT@+R`D
M:6YF;ULG=R==.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]O=70H<W!R
M:6YT9B@G<2`E+C)F(#`@,"`E+C)F("4N,F8@)2XR9B!C;2`O225D($1O(%$G
M+"`D=VED=&@L("1H96EG:'0L("1X+"`D=&AI<RT^:%!T("T@*"1Y("L@)&AE
M:6=H="DL("1I;F9O6R=I)UTI*3L*"B`@("`@("`@+RH@4V5T(&%N>2!L:6YK
M(&EF(')E<75E<W1E9"X@*B\*("`@("`@("!I9B`H)&QI;FLI('L*("`@("`@
M("`@("`@)'1H:7,M/E]L:6YK*"1X+"`D>2P@)'=I9'1H+"`D:&5I9VAT+"`D
M;&EN:RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4&5R9F]R
M;7,@82!L:6YE(&)R96%K+B!4:&4@8W5R<F5N="!A8G-C:7-S82!G;V5S(&)A
M8VL@=&\@=&AE(&QE9G0*("`@("`J(&UA<F=I;B!A;F0@=&AE(&]R9&EN871E
M(&EN8W)E87-E<R!B>2!T:&4@86UO=6YT('!A<W-E9"!I;B!P87)A;65T97(N
M"B`@("`@*@H@("`@("H@0'!A<F%M(&9L;V%T("1H96EG:'0@(%1H92!H96EG
M:'0@;V8@=&AE(&)R96%K+B!">2!D969A=6QT+"!T:&4@=F%L=64*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!E<75A;',@=&AE(&AE:6=H="!O9B!T
M:&4@;&%S="!P<FEN=&5D(&-E;&PN"B`@("`@*@H@("`@("H@0'-E92!&:6QE
M7U!$1CHZ8V5L;`H@("`@("HO"B`@("!F=6YC=&EO;B!N97=,:6YE*"1H96EG
M:'0@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^>"`]("1T:&ES+3Y?;&5F
M=%]M87)G:6X["B`@("`@("`@:68@*&ES7W-T<FEN9R@D:&5I9VAT*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^>2`K/2`D=&AI<RT^7VQA<W1?:&5I9VAT.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YY("L]("1H96EG
M:'0["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@86)S8VES<V$@;V8@=&AE(&-U<G)E;G0@<&]S:71I;VX@:6X@=7-E<B!U
M;FET<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&9L;V%T"B`@("`@*@H@("`@
M("H@0'-E92!&:6QE7U!$1CHZ<V5T6`H@("`@("H@0'-E92!&:6QE7U!$1CHZ
M9V5T60H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T60H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9718*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G@[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$969I;F5S('1H92!A8G-C:7-S82!O
M9B!T:&4@8W5R<F5N="!P;W-I=&EO;BX@268@=&AE('!A<W-E9"!V86QU92!I
M<PH@("`@("H@;F5G871I=F4L(&ET(&ES(')E;&%T:79E('1O('1H92!R:6=H
M="!O9B!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO870@)'@@
M(%1H92!V86QU92!O9B!T:&4@86)S8VES<V$N"B`@("`@*@H@("`@("H@0'-E
M92!&:6QE7U!$1CHZ9V5T6`H@("`@("H@0'-E92!&:6QE7U!$1CHZ9V5T60H@
M("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T60H@("`@("H@0'-E92!&:6QE7U!$
M1CHZ<V5T6%D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T6"@D>"D*("`@('L*
M("`@("`@("!I9B`H)'@@/CT@,"D@>PH@("`@("`@("`@("`O*B!!8G-O;'5T
M92!V86QU92X@*B\*("`@("`@("`@("`@)'1H:7,M/G@@/2`D>#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`O*B!.96=A=&EV92P@<V\@<F5L871I
M=F4@=&\@<FEG:'0@961G92!O9B!T:&4@<&%G92X@*B\*("`@("`@("`@("`@
M)'1H:7,M/G@@/2`D=&AI<RT^=R`K("1X.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&]R9&EN871E(&]F('1H92!C=7)R
M96YT('!O<VET:6]N(&EN('5S97(@=6YI=',N"B`@("`@*@H@("`@("H@0')E
M='5R;B!F;&]A=`H@("`@("H*("`@("`J($!S964@1FEL95]01$8Z.G-E=%D*
M("`@("`J($!S964@1FEL95]01$8Z.F=E=%@*("`@("`J($!S964@1FEL95]0
M1$8Z.G-E=%@*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T62@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YY.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1&5F:6YE<R!T:&4@;W)D:6YA=&4@;V8@=&AE(&-U<G)E;G0@<&]S:71I;VXN
M($EF('1H92!P87-S960@=F%L=64@:7,*("`@("`J(&YE9V%T:79E+"!I="!I
M<R!R96QA=&EV92!T;R!T:&4@8F]T=&]M(&]F('1H92!P86=E+@H@("`@("H*
M("`@("`J($!P87)A;2!F;&]A="`D>2`@5&AE('9A;'5E(&]F('1H92!O<F1I
M;F%T92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIG9718"B`@("`@
M*B!`<V5E($9I;&5?4$1&.CIG9719"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS
M9719"B`@("`@*B!`<V5E($9I;&5?4$1&.CIS971860H@("`@("HO"B`@("!F
M=6YC=&EO;B!S9719*"1Y*0H@("`@>PH@("`@("`@(&EF("@D>2`^/2`P*2![
M"B`@("`@("`@("`@("1T:&ES+3YY(#T@)'D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/GD@/2`D=&AI<RT^:"`K("1Y.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($1E9FEN97,@=&AE(&%B<V-I<W-A
M(&%N9"!O<F1I;F%T92!O9B!T:&4@8W5R<F5N="!P;W-I=&EO;BX@268@=&AE
M"B`@("`@*B!P87-S960@=F%L=65S(&%R92!N96=A=&EV92P@=&AE>2!A<F4@
M<F5L871I=F4@<F5S<&5C=&EV96QY('1O('1H92!R:6=H=`H@("`@("H@86YD
M(&)O='1O;2!O9B!T:&4@<&%G92X*("`@("`J"B`@("`@*B!`<&%R86T@9FQO
M870@)'@@(%1H92!V86QU92!O9B!T:&4@86)S8VES<V$N"B`@("`@*B!`<&%R
M86T@9FQO870@)'D@(%1H92!V86QU92!O9B!T:&4@;W)D:6YA=&4N"B`@("`@
M*@H@("`@("H@0'-E92!&:6QE7U!$1CHZ<V5T6`H@("`@("H@0'-E92!&:6QE
M7U!$1CHZ<V5T60H@("`@("HO"B`@("!F=6YC=&EO;B!S971862@D>"P@)'DI
M"B`@("!["B`@("`@("`@)'1H:7,M/G-E=%DH)'DI.PH@("`@("`@("1T:&ES
M+3YS9718*"1X*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M(')A=R!01$8@9FEL92X*("`@("`J"B`@("`@*B!`<V5E($9I;&5?4$1&.CIO
M=71P=70*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3W5T<'5T*"D*("`@('L*
M("`@("`@("`O*B!#:&5C:R!W:&5T:&5R(&9I;&4@:&%S(&)E96X@8VQO<V5D
M+B`J+PH@("`@("`@(&EF("@D=&AI<RT^7W-T871E(#P@,RD@>PH@("`@("`@
M("`@("`D=&AI<RT^8VQO<V4H*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D=&AI<RT^7V)U9F9E<CL*("`@('T*"B`@("`O*BH*("`@("`J($9U;F-T
M:6]N('1O(&]U='!U="!T:&4@8G5F9F5R960@9&%T82!T;R!T:&4@8G)O=W-E
M<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE;F%M92`@5&AE
M(&9I;&5N86UE(&9O<B!T:&4@;W5T<'5T(&9I;&4N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D:6YL:6YE("`@5')U92!I9B!I;FQI;F4L(&9A;'-E(&EF(&%T
M=&%C:&UE;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U="@D9FEL96YA
M;64@/2`G=6YK;F]W;BYP9&8G+"`D:6YL:6YE(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@+RH@0VAE8VL@=VAE=&AE<B!F:6QE(&AA<R!B965N(&-L;W-E9"X@
M*B\*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`\(#,I('L*("`@("`@("`@
M("`@)'1H:7,M/F-L;W-E*"D["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!(
M5%107T1O=VYL;V%D(&ES(&YO="!A=F%I;&%B;&4@<F5T=7)N(%!%05)?17)R
M;W(N("HO"B`@("`@("`@:68@*"%`:6YC;'5D95]O;F-E("=(5%10+T1O=VYL
M;V%D+G!H<"<I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=-:7-S:6YG(%!%05(@<&%C:V%G92!(5%107T1O=VYL;V%D+B<I.PH@
M("`@("`@('T*"B`@("`@("`@+RH@0VAE8VL@:68@:&5A9&5R<R!H879E(&)E
M96X@<V5N="X@*B\*("`@("`@("!I9B`H:&5A9&5R<U]S96YT*"DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;F%B;&4@=&\@
M<V5N9"!01$8@9FEL92P@<V]M92!D871A(&AA<R!A;')E861Y(&)E96X@;W5T
M<'5T('1O(&)R;W=S97(N)RD["B`@("`@("`@?0H*("`@("`@("`O*B!087)A
M;7,@9F]R('1H92!O=71P=70N("HO"B`@("`@("`@)&1I<W!O<VET:6]N(#T@
M*"$D:6YL:6YE*2`_($A45%!?1$]73DQ/041?051404-(345.5"`Z($A45%!?
M1$]73DQ/041?24Y,24Y%.PH@("`@("`@("1P87)A;7,@/2!A<G)A>2@G9&%T
M82<@("`@("`@("`@("`@("`]/B`D=&AI<RT^7V)U9F9E<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@)V-O;G1E;G1T>7!E)R`@("`@("`@/3X@)V%P<&QI
M8V%T:6]N+W!D9B<L"B`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT
M9&ES<&]S:71I;VXG(#T^(&%R<F%Y*"1D:7-P;W-I=&EO;BP@)&9I;&5N86UE
M*2D["B`@("`@("`@+RH@3W5T<'5T('1H92!F:6QE+B`J+PH@("`@("`@(')E
M='5R;B!(5%107T1O=VYL;V%D.CIS=&%T:6-396YD*"1P87)A;7,I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@<V%V92!T:&4@4$1&(&9I
M;&4@<V]M97=H97)E(&QO8V%L('1O('1H92!S97)V97(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE;F%M92!F;W(@
M=&AE(&]U='!U="!F:6QE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1F
M:6QE;F%M92`]("=U;FMN;W=N+G!D9B<I"B`@("!["B`@("`@("`@+RH@0VAE
M8VL@=VAE=&AE<B!F:6QE(&AA<R!B965N(&-L;W-E9"X@*B\*("`@("`@("!I
M9B`H)'1H:7,M/E]S=&%T92`\(#,I('L*("`@("`@("`@("`@)'1H:7,M/F-L
M;W-E*"D["B`@("`@("`@?0H*("`@("`@("`D9B`](&9O<&5N*"1F:6QE;F%M
M92P@)W=B)RD["B`@("`@("`@:68@*"$D9BD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G56YA8FQE('1O('-A=F4@
M4$1&(&9I;&4Z("5S)RP@)&9I;&5N86UE*2D["B`@("`@("`@?0H@("`@("`@
M(&9W<FET92@D9BP@)'1H:7,M/E]B=69F97(L('-T<FQE;B@D=&AI<RT^7V)U
M9F9E<BDI.PH@("`@("`@(&9C;&]S92@D9BD["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W1O4'0H)'9A;"D*("`@('L*("`@("`@("!R971U<FX@)'9A;"`J("1T
M:&ES+3Y?<V-A;&4["B`@("!]"@H@("`@9G5N8W1I;VX@)E]G971&;VYT1FEL
M92@D9F]N=&ME>2P@)'!A=&@@/2`G)RD*("`@('L*("`@("`@("!S=&%T:6,@
M)&9O;G1?=VED=&AS.PH*("`@("`@("!I9B`H(6ES<V5T*"1F;VYT7W=I9'1H
M<ULD9F]N=&ME>5TI*2!["B`@("`@("`@("`@(&EF("@A96UP='DH)'!A=&@I
M*2!["B`@("`@("`@("`@("`@("`D9FEL92`]("1P871H("X@<W1R=&]L;W=E
M<B@D9F]N=&ME>2D@+B`G+G!H<"<["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D9FEL92`]("=&:6QE+U!$1B]F;VYT<R\G("X@<W1R
M=&]L;W=E<B@D9F]N=&ME>2D@+B`G+G!H<"<["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@0')E<75I<F4@)&9I;&4["B`@("`@("`@("`@(&EF("@A:7-S
M970H)&9O;G1?=VED=&AS6R1F;VYT:V5Y72DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS<')I;G1F*"=#;W5L9"!N;W0@
M:6YC;'5D92!F;VYT(&UE=')I8R!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D9F]N=%]W:61T
M:',["B`@("!]"@H@("`@9G5N8W1I;VX@7VQI;FLH)'@L("1Y+"`D=VED=&@L
M("1H96EG:'0L("1L:6YK*0H@("`@>PH@("`@("`@("\J(%-A=F4@;&EN:R!T
M;R!P86=E(&QI;FMS(&%R<F%Y+B`J+PH@("`@("`@("1T:&ES+3Y?<&%G95]L
M:6YK<ULD=&AI<RT^7W!A9V5=6UT@/2!A<G)A>2@D>"P@)'DL("1W:61T:"P@
M)&AE:6=H="P@)&QI;FLI.PH@("`@?0H*("`@(&9U;F-T:6]N(%]B96=I;D1O
M8R@I"B`@("!["B`@("`@("`@+RH@4W1A<G0@9&]C=6UE;G0L(&)U="!O;FQY
M(&EF(&YO="!Y970@<W1A<G1E9"X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]S
M=&%T92`\(#$I('L*("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`](#$["B`@
M("`@("`@("`@("1T:&ES+3Y?;W5T*"<E4$1&+3$N,R<I.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!?<'5T4&%G97,H*0H@("`@>PH@("`@("`@
M("1N8B`]("1T:&ES+3Y?<&%G93L*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?86QI87-?;F)?<&%G97,I*2!["B`@("`@("`@("`@("\J(%)E<&QA8V4@
M;G5M8F5R(&]F('!A9V5S+B`J+PH@("`@("`@("`@("!F;W(@*"1N(#T@,3L@
M)&X@/#T@)&YB.R`D;BLK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M9V5S6R1N72`]('-T<E]R97!L86-E*"1T:&ES+3Y?86QI87-?;F)?<&%G97,L
M("1N8BP@)'1H:7,M/E]P86=E<ULD;ETI.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("@D=&AI<RT^7V1E9F%U;'1?;W)I96YT871I;VX@
M/3T@)U`G*2!["B`@("`@("`@("`@("1W4'0@/2`D=&AI<RT^9G=0=#L*("`@
M("`@("`@("`@)&A0="`]("1T:&ES+3YF:%!T.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1W4'0@/2`D=&AI<RT^9FA0=#L*("`@("`@("`@("`@
M)&A0="`]("1T:&ES+3YF=U!T.PH@("`@("`@('T*("`@("`@("`D9FEL=&5R
M(#T@*"1T:&ES+3Y?8V]M<')E<W,I(#\@)R]&:6QT97(@+T9L871E1&5C;V1E
M("<@.B`G)SL*("`@("`@("!F;W(@*"1N(#T@,3L@)&X@/#T@)&YB.R`D;BLK
M*2!["B`@("`@("`@("`@("\J(%!A9V4@*B\*("`@("`@("`@("`@)'1H:7,M
M/E]N97=O8FHH*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y<&4@
M+U!A9V4G*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]087)E;G0@,2`P
M(%(G*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W)I96YT871I
M;VY?8VAA;F=E<ULD;ETI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U
M="AS<')I;G1F*"<O365D:6%";W@@6S`@,"`E+C)F("4N,F9=)RP@)&A0="P@
M)'=0="DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"<O4F5S;W5R8V5S(#(@,"!2)RD["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A9V5?;&EN:W-;)&Y=*2D@>PH@("`@("`@("`@("`@("`@+RH@
M3&EN:W,@*B\*("`@("`@("`@("`@("`@("1A;FYO=',@/2`G+T%N;F]T<R!;
M)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%G95]L:6YK
M<ULD;ET@87,@)'!L*2!["B`@("`@("`@("`@("`@("`@("`@)')E8W0@/2!S
M<')I;G1F*"<E+C)F("4N,F8@)2XR9B`E+C)F)RP@)'!L6S!=+"`D<&Q;,5TL
M("1P;%LP72`K("1P;%LR72P@)'!L6S%=("T@)'!L6S-=*3L*("`@("`@("`@
M("`@("`@("`@("`D86YN;W1S("X]("<\/"]4>7!E("]!;FYO="`O4W5B='EP
M92`O3&EN:R`O4F5C="!;)R`N("1R96-T("X@)UT@+T)O<F1E<B!;,"`P(#!=
M("<["B`@("`@("`@("`@("`@("`@("`@:68@*&ES7W-T<FEN9R@D<&Q;-%TI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A;FYO=',@+CT@)R]!(#P\
M+U,@+U5222`O55))("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'!L6S1=*2`N
M("<^/CX^)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D;"`]("1T:&ES+3Y?;&EN:W-;)'!L6S1=73L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&AE:6=H="`](&ES<V5T*"1T:&ES
M+3Y?;W)I96YT871I;VY?8VAA;F=E<ULD;%LP75TI(#\@)'=0="`Z("1H4'0[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A;FYO=',@+CT@<W!R:6YT9B@G
M+T1E<W0@6R5D(#`@4B`O6%E:(#`@)2XR9B!N=6QL73X^)RP@,2`K(#(@*B`D
M;%LP72P@)&AE:6=H="`M("1L6S%=("H@)'1H:7,M/E]S8V%L92D["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]O=70H)&%N;F]T<RXG72<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O0V]N=&5N=',@)R`N("@D=&AI
M<RT^7VX@*R`Q*2`N("<@,"!2/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)V5N9&]B:B<I.PH@("`@("`@("`@("`O*B!086=E(&-O;G1E;G0@*B\*
M("`@("`@("`@("`@)'`@/2`H)'1H:7,M/E]C;VUP<F5S<RD@/R!G>F-O;7!R
M97-S*"1T:&ES+3Y?<&%G97-;)&Y=*2`Z("1T:&ES+3Y?<&%G97-;)&Y=.PH@
M("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`D=&AI
M<RT^7V]U="@G/#PG("X@)&9I;'1E<B`N("<O3&5N9W1H("<@+B!S=')L96XH
M)'`I("X@)SX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?<'5T4W1R96%M*"1P
M*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B:B<I.PH@("`@("`@
M('T*("`@("`@("`O*B!086=E<R!R;V]T("HO"B`@("`@("`@)'1H:7,M/E]O
M9F9S971S6S%=(#T@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D
M=&AI<RT^7V]U="@G,2`P(&]B:B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\
M/"]4>7!E("]086=E<R<I.PH@("`@("`@("1K:61S(#T@)R]+:61S(%LG.PH@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1N8CL@)&DK*RD@>PH@("`@("`@
M("`@("`D:VED<R`N/2`H,R`K(#(@*B`D:2D@+B`G(#`@4B`G.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7V]U="@D:VED<R`N("==)RD["B`@("`@("`@
M)'1H:7,M/E]O=70H)R]#;W5N="`G("X@)&YB*3L*("`@("`@("`D=&AI<RT^
M7V]U="AS<')I;G1F*"<O365D:6%";W@@6S`@,"`E+C)F("4N,F9=)RP@)'=0
M="P@)&A0="DI.PH@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@
M("1T:&ES+3Y?;W5T*"=E;F1O8FHG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M<'5T1F]N=',H*0H@("`@>PH@("`@("`@("1N9B`]("1T:&ES+3Y?;CL*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V1I9F9S(&%S("1D:69F*2!["B`@("`@
M("`@("`@("\J($5N8V]D:6YG<R`J+PH@("`@("`@("`@("`D=&AI<RT^7VYE
M=V]B:B@I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G/#PO5'EP92`O16YC
M;V1I;F<@+T)A<V5%;F-O9&EN9R`O5VEN06YS:45N8V]D:6YG("]$:69F97)E
M;F-E<R!;)R`N("1D:69F("X@)UT^/B<I.PH@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G96YD;V)J)RD["B`@("`@("`@?0H@("`@("`@("1M<7(@/2!G971?
M;6%G:6-?<75O=&5S7W)U;G1I;64H*3L*("`@("`@("!S971?;6%G:6-?<75O
M=&5S7W)U;G1I;64H,"D["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]F;VYT
M7V9I;&5S(&%S("1F:6QE(#T^("1I;F9O*2!["B`@("`@("`@("`@("\J($9O
M;G0@9FEL92!E;6)E9&1I;F<N("HO"B`@("`@("`@("`@("1T:&ES+3Y?;F5W
M;V)J*"D["B`@("`@("`@("`@("1T:&ES+3Y?9F]N=%]F:6QE<ULD9FEL95U;
M)VXG72`]("1T:&ES+3Y?;CL*("`@("`@("`@("`@)'-I>F4@/2!F:6QE<VEZ
M92@D9FEL92D["B`@("`@("`@("`@(&EF("@A)'-I>F4I('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G1F]N="!F:6QE(&YO
M="!F;W5N9"XG*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G/#PO3&5N9W1H("<@+B`D<VEZ92D["B`@("`@("`@("`@(&EF("AS
M=6)S='(H)&9I;&4L("TR*2`]/2`G+GHG*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V]U="@G+T9I;'1E<B`O1FQA=&5$96-O9&4G*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TQE;F=T:#$@)R`N("1I
M;F9O6R=L96YG=&@Q)UTI.PH@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];
M)VQE;F=T:#(G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O
M3&5N9W1H,B`G("X@)&EN9F];)VQE;F=T:#(G72`N("<@+TQE;F=T:#,@,"<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I
M.PH@("`@("`@("`@("`D9B`](&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@
M("`@("`@)'1H:7,M/E]P=713=')E86TH9G)E860H)&8L("1S:7IE*2D["B`@
M("`@("`@("`@(&9C;&]S92@D9BD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T
M*"=E;F1O8FHG*3L*("`@("`@("!]"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E
M<U]R=6YT:6UE*"1M<7(I.PH@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9F]N
M=',@87,@)&L@/3X@)&9O;G0I('L*("`@("`@("`@("`@+RH@1F]N="!O8FIE
M8W1S("HO"B`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@
M("`@("1T:&ES+3Y?9F]N='-;)&M=6R=N)UT@/2`D=&AI<RT^7VX["B`@("`@
M("`@("`@("1N86UE(#T@)&9O;G1;)VYA;64G73L*("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)SP\+U1Y<&4@+T9O;G0G*3L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]"87-E1F]N="`O)R`N("1N86UE*3L*("`@("`@("`@("`@:68@
M*"1F;VYT6R=T>7!E)UT@/3T@)V-O<F4G*2!["B`@("`@("`@("`@("`@("`O
M*B!3=&%N9&%R9"!F;VYT+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O
M=70H)R]3=6)T>7!E("]4>7!E,2<I.PH@("`@("`@("`@("`@("`@:68@*"1N
M86UE("$]("=3>6UB;VPG("8F("1N86UE("$]("=:87!F1&EN9V)A=',G*2![
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]%;F-O9&EN9R`O
M5VEN06YS:45N8V]D:6YG)RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O*B!!9&1I=&EO;F%L(&9O
M;G0N("HO"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U-U8G1Y<&4@
M+R<@+B`D9F]N=%LG='EP92==*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"<O1FER<W1#:&%R(#,R)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G+TQA<W1#:&%R(#(U-2<I.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]7:61T:',@)R`N("@D=&AI<RT^7VX@*R`Q*2`N("<@,"!2)RD[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T9O;G1$97-C<FEP=&]R
M("<@+B`H)'1H:7,M/E]N("L@,BD@+B`G(#`@4B<I.PH@("`@("`@("`@("`@
M("`@:68@*"1F;VYT6R=E;F,G72D@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9F]N=%LG9&EF9B==*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V]U="@G+T5N8V]D:6YG("<@+B`H)&YF("L@)&9O;G1;
M)V1I9F8G72DN)R`P(%(G*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T5N8V]D
M:6YG("]7:6Y!;G-I16YC;V1I;F<G*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E
M;F1O8FHG*3L*("`@("`@("`@("`@:68@*"1F;VYT6R=T>7!E)UT@(3T@)V-O
M<F4G*2!["B`@("`@("`@("`@("`@("`O*B!7:61T:',N("HO"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`@("`@)&-W
M(#T@)B1F;VYT6R=C=R==.PH@("`@("`@("`@("`@("`@)',@/2`G6R<["B`@
M("`@("`@("`@("`@("!F;W(@*"1I(#T@,S([("1I(#P](#(U-3L@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@("`@("1S("X]("1C=UMC:'(H)&DI72`N("<@
M)SL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"1S("X@)UTG*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E
M;F1O8FHG*3L*("`@("`@("`@("`@("`@("\J($1E<V-R:7!T;W(N("HO"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("`@("`@
M("`@)',@/2`G/#PO5'EP92`O1F]N=$1E<V-R:7!T;W(@+T9O;G1.86UE("\G
M("X@)&YA;64["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9F]N=%LG9&5S
M8R==(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@)',@+CT@
M)R`O)R`N("1K("X@)R`G("X@)'8["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D9FEL92`]("1F;VYT6R=F:6QE)UT["B`@("`@("`@("`@
M("`@("!I9B`H)&9I;&4I('L*("`@("`@("`@("`@("`@("`@("`D<R`N/2`G
M("]&;VYT1FEL92<@+B`H)&9O;G1;)W1Y<&4G72`]/2`G5'EP93$G(#\@)R<@
M.B`G,B<I("X@)R`G("X@)'1H:7,M/E]F;VYT7V9I;&5S6R1F:6QE75LG;B==
M("X@)R`P(%(G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O=70H)',@+B`G/CXG*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"=E;F1O8FHG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!?<'5T26UA9V5S*"D*("`@('L*("`@("`@("`D
M9FEL=&5R(#T@*"1T:&ES+3Y?8V]M<')E<W,I(#\@)R]&:6QT97(@+T9L871E
M1&5C;V1E("<@.B`G)SL*("`@("`@("!F;W)E86-H("@D=&AI<RT^7VEM86=E
M<R!A<R`D9FEL92`]/B`D:6YF;RD@>PH@("`@("`@("`@("`D=&AI<RT^7VYE
M=V]B:B@I.PH@("`@("`@("`@("`D=&AI<RT^7VEM86=E<ULD9FEL95U;)VXG
M72`]("1T:&ES+3Y?;CL*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SP\+U1Y
M<&4@+UA/8FIE8W0G*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]3=6)T
M>7!E("]);6%G92<I.PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+U=I9'1H
M("<@+B`D:6YF;ULG=R==*3L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R](
M96EG:'0@)R`N("1I;F9O6R=H)UTI.PH@("`@("`@("`@("!I9B`H)&EN9F];
M)V-S)UT@/3T@)TEN9&5X960G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V]U="@G+T-O;&]R4W!A8V4@6R]);F1E>&5D("]$979I8V521T(@)R`N("AS
M=')L96XH)&EN9F];)W!A;"==*2\S("T@,2D@+B`G("<@+B`H)'1H:7,M/E]N
M("L@,2DN)R`P(%)=)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V]U="@G+T-O;&]R4W!A8V4@+R<@+B`D:6YF;ULG
M8W,G72D["B`@("`@("`@("`@("`@("!I9B`H)&EN9F];)V-S)UT@/3T@)T1E
M=FEC94--64LG*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)R]$96-O9&4@6S$@,"`Q(#`@,2`P(#$@,%TG*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T)I
M='-097)#;VUP;VYE;G0@)R`N("1I;F9O6R=B<&,G72D["B`@("`@("`@("`@
M("1T:&ES+3Y?;W5T*"<O1FEL=&5R("\G("X@)&EN9F];)V8G72D["B`@("`@
M("`@("`@(&EF("AI<W-E="@D:6YF;ULG<&%R;7,G72DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;W5T*"1I;F9O6R=P87)M<R==*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)W1R;G,G72D@)B8@
M:7-?87)R87DH)&EN9F];)W1R;G,G72DI('L*("`@("`@("`@("`@("`@("1T
M<FYS(#T@)R<["B`@("`@("`@("`@("`@("`D:5]M87@@/2!C;W5N="@D:6YF
M;ULG=')N<R==*3L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1I7VUA>#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1T<FYS("X]
M("1I;F9O6R=T<FYS)UU;)&E=("X@)R`G("X@)&EN9F];)W1R;G,G75LD:5TN
M)R`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]-87-K(%LG("X@)'1R;G,@+B`G72<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O3&5N9W1H("<@+B!S=')L96XH
M)&EN9F];)V1A=&$G72D@+B`G/CXG*3L*("`@("`@("`@("`@)'1H:7,M/E]P
M=713=')E86TH)&EN9F];)V1A=&$G72D["B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"=E;F1O8FHG*3L*"B`@("`@("`@("`@("\J(%!A;&5T=&4N("HO"B`@
M("`@("`@("`@(&EF("@D:6YF;ULG8W,G72`]/2`G26YD97AE9"<I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?;F5W;V)J*"D["B`@("`@("`@("`@("`@
M("`D<&%L(#T@*"1T:&ES+3Y?8V]M<')E<W,I(#\@9WIC;VUP<F5S<R@D:6YF
M;ULG<&%L)UTI(#H@)&EN9F];)W!A;"==.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)SP\)R`N("1F:6QT97(@+B`G+TQE;F=T:"`G("X@<W1R;&5N
M*"1P86PI("X@)SX^)RD["B`@("`@("`@("`@("`@("`D=&AI<RT^7W!U=%-T
M<F5A;2@D<&%L*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1O
M8FHG*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!?<'5T4F5S;W5R8V5S*"D*("`@('L*("`@("`@("`D=&AI<RT^7W!U
M=$9O;G1S*"D["B`@("`@("`@)'1H:7,M/E]P=71);6%G97,H*3L*("`@("`@
M("`O*B!297-O=7)C92!D:6-T:6]N87)Y("HO"B`@("`@("`@)'1H:7,M/E]O
M9F9S971S6S)=(#T@<W1R;&5N*"1T:&ES+3Y?8G5F9F5R*3L*("`@("`@("`D
M=&AI<RT^7V]U="@G,B`P(&]B:B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\
M/"]0<F]C4V5T(%LO4$1&("]497AT("]);6%G94(@+TEM86=E0R`O26UA9V5)
M72<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<O1F]N="`\/"<I.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?9F]N=',@87,@)&9O;G0I('L*("`@("`@("`@
M("`@)'1H:7,M/E]O=70H)R]&)R`N("1F;VYT6R=I)UT@+B`G("<@+B`D9F]N
M=%LG;B==("X@)R`P(%(G*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]O
M=70H)SX^)RD["B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?:6UA9V5S*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+UA/8FIE8W0@/#PG*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]I;6%G97,@87,@)&EM86=E*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]U="@G+TDG("X@)&EM86=E6R=I
M)UT@+B`G("<@+B`D:6UA9V5;)VXG72`N("<@,"!2)RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]O=70H)SX^)RD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@("1T:&ES+3Y?;W5T
M*"=E;F1O8FHG*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<'5T26YF;R@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]O=70H)R]0<F]D=6-E<B`G("X@)'1H:7,M
M/E]T97AT4W1R:6YG*"=(;W)D92!01$8G*2D["B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7VEN9F];)W1I=&QE)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;W5T*"<O5&ET;&4@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D=&AI<RT^
M7VEN9F];)W1I=&QE)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^7VEN9F];)W-U8FIE8W0G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]O=70H)R]3=6)J96-T("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H
M:7,M/E]I;F9O6R=S=6)J96-T)UTI*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7VEN9F];)V%U=&AO<B==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]U="@G+T%U=&AO<B`G("X@)'1H:7,M/E]T97AT4W1R:6YG
M*"1T:&ES+3Y?:6YF;ULG875T:&]R)UTI*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"%E;7!T>2@D=&AI<RT^:V5Y=V]R9',I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;W5T*"<O2V5Y=V]R9',@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@D
M=&AI<RT^:V5Y=V]R9',I*3L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T
M>2@D=&AI<RT^8W)E871O<BDI('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H
M)R]#<F5A=&]R("<@+B`D=&AI<RT^7W1E>'13=')I;F<H)'1H:7,M/F-R96%T
M;W(I*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]O=70H)R]#<F5A=&EO
M;D1A=&4@)R`N("1T:&ES+3Y?=&5X=%-T<FEN9R@G1#HG("X@9&%T92@G66UD
M2&ES)RDI*3L*("`@('T*"B`@("!F=6YC=&EO;B!?<'5T0V%T86QO9R@I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]O=70H)R]4>7!E("]#871A;&]G)RD["B`@
M("`@("`@)'1H:7,M/E]O=70H)R]086=E<R`Q(#`@4B<I.PH@("`@("`@(&EF
M("@D=&AI<RT^7WIO;VU?;6]D92`]/2`G9G5L;'!A9V4G*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?;W5T*"<O3W!E;D%C=&EO;B!;,R`P(%(@+T9I=%TG*3L*
M("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]Z;V]M7VUO9&4@/3T@)V9U;&QW
M:61T:"<I('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H)R]/<&5N06-T:6]N
M(%LS(#`@4B`O1FET2"!N=6QL72<I.PH@("`@("`@('T@96QS96EF("@D=&AI
M<RT^7WIO;VU?;6]D92`]/2`G<F5A;"<I('L*("`@("`@("`@("`@)'1H:7,M
M/E]O=70H)R]/<&5N06-T:6]N(%LS(#`@4B`O6%E:(&YU;&P@;G5L;"`Q72<I
M.PH@("`@("`@('T@96QS96EF("@A:7-?<W1R:6YG*"1T:&ES+3Y?>F]O;5]M
M;V1E*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V]U="@G+T]P96Y!8W1I;VX@
M6S,@,"!2("]865H@;G5L;"!N=6QL("<@+B`H)'1H:7,M/E]Z;V]M7VUO9&4@
M+R`Q,#`I+B==)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^7VQA
M>6]U=%]M;V1E(#T]("=S:6YG;&4G*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M;W5T*"<O4&%G94QA>6]U="`O4VEN9VQE4&%G92<I.PH@("`@("`@('T@96QS
M96EF("@D=&AI<RT^7VQA>6]U=%]M;V1E(#T]("=C;VYT:6YU;W5S)RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V]U="@G+U!A9V5,87EO=70@+T]N94-O;'5M
M;B<I.PH@("`@("`@('T@96QS96EF("@D=&AI<RT^7VQA>6]U=%]M;V1E(#T]
M("=T=V\G*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W5T*"<O4&%G94QA>6]U
M="`O5'=O0V]L=6UN3&5F="<I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!?<'5T5')A:6QE<B@I"B`@("!["B`@("`@("`@)'1H:7,M/E]O=70H
M)R]3:7IE("<@+B`H)'1H:7,M/E]N("L@,2DI.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"<O4F]O="`G("X@)'1H:7,M/E]N("X@)R`P(%(G*3L*("`@("`@("`D
M=&AI<RT^7V]U="@G+TEN9F\@)R`N("@D=&AI<RT^7VX@+2`Q*2`N("<@,"!2
M)RD["B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9$1O8R@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]P=71086=E<R@I.PH@("`@("`@("1T:&ES+3Y?<'5T4F5S
M;W5R8V5S*"D["B`@("`@("`@+RH@26YF;R`J+PH@("`@("`@("1T:&ES+3Y?
M;F5W;V)J*"D["B`@("`@("`@)'1H:7,M/E]O=70H)SP\)RD["B`@("`@("`@
M)'1H:7,M/E]P=71);F9O*"D["B`@("`@("`@)'1H:7,M/E]O=70H)SX^)RD[
M"B`@("`@("`@)'1H:7,M/E]O=70H)V5N9&]B:B<I.PH@("`@("`@("\J($-A
M=&%L;V<@*B\*("`@("`@("`D=&AI<RT^7VYE=V]B:B@I.PH@("`@("`@("1T
M:&ES+3Y?;W5T*"<\/"<I.PH@("`@("`@("1T:&ES+3Y?<'5T0V%T86QO9R@I
M.PH@("`@("`@("1T:&ES+3Y?;W5T*"<^/B<I.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"=E;F1O8FHG*3L*("`@("`@("`O*B!#<F]S<RUR968@*B\*("`@("`@
M("`D;R`]('-T<FQE;B@D=&AI<RT^7V)U9F9E<BD["B`@("`@("`@)'1H:7,M
M/E]O=70H)WAR968G*3L*("`@("`@("`D=&AI<RT^7V]U="@G,"`G("X@*"1T
M:&ES+3Y?;B`K(#$I*3L*("`@("`@("`D=&AI<RT^7V]U="@G,#`P,#`P,#`P
M,"`V-34S-2!F("<I.PH@("`@("`@(&9O<B`H)&D@/2`Q.R`D:2`\/2`D=&AI
M<RT^7VX[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/E]O=70H<W!R:6YT
M9B@G)3`Q,&0@,#`P,#`@;B`G+"`D=&AI<RT^7V]F9G-E='-;)&E=*2D["B`@
M("`@("`@?0H@("`@("`@("\J(%1R86EL97(@*B\*("`@("`@("`D=&AI<RT^
M7V]U="@G=')A:6QE<B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"<\/"<I.PH@
M("`@("`@("1T:&ES+3Y?<'5T5')A:6QE<B@I.PH@("`@("`@("1T:&ES+3Y?
M;W5T*"<^/B<I.PH@("`@("`@("1T:&ES+3Y?;W5T*"=S=&%R='AR968G*3L*
M("`@("`@("`D=&AI<RT^7V]U="@D;RD["B`@("`@("`@)'1H:7,M/E]O=70H
M)R4E14]&)RD["B`@("`@("`@)'1H:7,M/E]S=&%T92`](#,["B`@("!]"@H@
M("`@9G5N8W1I;VX@7V)E9VEN4&%G92@D;W)I96YT871I;VXI"B`@("!["B`@
M("`@("`@)'1H:7,M/E]P86=E*RL["B`@("`@("`@)'1H:7,M/E]P86=E<ULD
M=&AI<RT^7W!A9V5=(#T@)R<["B`@("`@("`@)'1H:7,M/E]S=&%T92`](#([
M"B`@("`@("`@)'1H:7,M/G@@/2`D=&AI<RT^7VQE9G1?;6%R9VEN.PH@("`@
M("`@("1T:&ES+3YY(#T@)'1H:7,M/E]T;W!?;6%R9VEN.PH@("`@("`@("1T
M:&ES+3Y?;&%S=%]H96EG:'0@/2`P.PH@("`@("`@("\J(%!A9V4@;W)I96YT
M871I;VX@*B\*("`@("`@("!I9B`H(21O<FEE;G1A=&EO;BD@>PH@("`@("`@
M("`@("`D;W)I96YT871I;VX@/2`D=&AI<RT^7V1E9F%U;'1?;W)I96YT871I
M;VX["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&]R:65N=&%T:6]N
M(#T@<W1R=&]U<'!E<B@D;W)I96YT871I;VY[,'TI.PH@("`@("`@("`@("!I
M9B`H)&]R:65N=&%T:6]N("$]("1T:&ES+3Y?9&5F875L=%]O<FEE;G1A=&EO
M;BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]O<FEE;G1A=&EO;E]C:&%N
M9V5S6R1T:&ES+3Y?<&%G95T@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(&EF("@D;W)I96YT871I;VX@(3T@)'1H:7,M/E]C=7)R
M96YT7V]R:65N=&%T:6]N*2!["B`@("`@("`@("`@("\J($-H86YG92!O<FEE
M;G1A=&EO;B`J+PH@("`@("`@("`@("!I9B`H)&]R:65N=&%T:6]N(#T]("=0
M)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G=0="`]("1T:&ES+3YF=U!T
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/FA0="`]("1T:&ES+3YF:%!T.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/G<@("`]("1T:&ES+3YF=SL*("`@("`@
M("`@("`@("`@("1T:&ES+3YH("`@/2`D=&AI<RT^9F@["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^=U!T(#T@)'1H:7,M
M/F9H4'0["B`@("`@("`@("`@("`@("`D=&AI<RT^:%!T(#T@)'1H:7,M/F9W
M4'0["B`@("`@("`@("`@("`@("`D=&AI<RT^=R`@(#T@)'1H:7,M/F9H.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/F@@("`]("1T:&ES+3YF=SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7W!A9V5?8G)E86M?=')I9V=E
M<B`]("1T:&ES+3YH("T@)'1H:7,M/E]B<F5A:U]M87)G:6X["B`@("`@("`@
M("`@("1T:&ES+3Y?8W5R<F5N=%]O<FEE;G1A=&EO;B`]("1O<FEE;G1A=&EO
M;CL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@7V5N9%!A9V4H*0H@
M("`@>PH@("`@("`@("\J($5N9"!O9B!P86=E(&-O;G1E;G1S("HO"B`@("`@
M("`@)'1H:7,M/E]S=&%T92`](#$["B`@("!]"@H@("`@9G5N8W1I;VX@7VYE
M=V]B:B@I"B`@("!["B`@("`@("`@+RH@0F5G:6X@82!N97<@;V)J96-T("HO
M"B`@("`@("`@)'1H:7,M/E]N*RL["B`@("`@("`@)'1H:7,M/E]O9F9S971S
M6R1T:&ES+3Y?;ET@/2!S=')L96XH)'1H:7,M/E]B=69F97(I.PH@("`@("`@
M("1T:&ES+3Y?;W5T*"1T:&ES+3Y?;B`N("<@,"!O8FHG*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!?9&]5;F1E<FQI;F4H)'@L("1Y+"`D=&5X="D*("`@('L*
M("`@("`@("`O*B!3970@=&AE(')E8W1A;F=L92!W:61T:"!A8V-O<F1I;F<@
M=&\@=&5X="!W:61T:"X@*B\*("`@("`@("`D=VED=&@@(#T@)'1H:7,M/F=E
M=%-T<FEN9U=I9'1H*"1T97AT+"!T<G5E*3L*"B`@("`@("`@+RH@4V5T(')E
M8W1A;F=L92!P;W-I=&EO;B!A;F0@:&5I9VAT+"!U<VEN9R!U;F1E<FQI;F4@
M<&]S:71I;VX@86YD"B`@("`@("`@("H@=&AI8VMN97-S('-E='1I;F=S('-C
M86QE9"!B>2!T:&4@9F]N="!S:7IE+B`J+PH@("`@("`@("1Y(#T@)'D@*R`H
M)'1H:7,M/E]C=7)R96YT7V9O;G1;)W5P)UT@*B`D=&AI<RT^7V9O;G1?<VEZ
M95]P="`O(#$P,#`I.PH@("`@("`@("1H96EG:'0@/2`M)'1H:7,M/E]C=7)R
M96YT7V9O;G1;)W5T)UT@*B`D=&AI<RT^7V9O;G1?<VEZ95]P="`O(#$P,#`[
M"@H@("`@("`@(')E='5R;B!S<')I;G1F*"<E+C)F("4N,F8@)2XR9B`E+C)F
M(')E(&8G+"`D>"P@)'DL("1W:61T:"P@)&AE:6=H="D["B`@("!]"@H@("`@
M9G5N8W1I;VX@7W!A<G-E2E!'*"1F:6QE*0H@("`@>PH@("`@("`@("\J($5X
M=')A8W0@:6YF;R!F<F]M(&$@2E!%1R!F:6QE+B`J+PH@("`@("`@("1I;6<@
M/2!`9V5T:6UA9V5S:7IE*"1F:6QE*3L*("`@("`@("!I9B`H(21I;6<I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H
M)TUI<W-I;F<@;W(@:6YC;W)R96-T(&EM86=E(&9I;&4Z("5S)RP@)&9I;&4I
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I;6=;,ET@(3T@,BD@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G3F]T
M(&$@2E!%1R!F:6QE.B`E<R<L("1F:6QE*2D["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-S970H)&EM9ULG8VAA;FYE;',G72D@?'P@)&EM9ULG8VAA;FYE
M;',G72`]/2`S*2!["B`@("`@("`@("`@("1C;VQS<&%C92`]("=$979I8V52
M1T(G.PH@("`@("`@('T@96QS96EF("@D:6UG6R=C:&%N;F5L<R==(#T](#0I
M('L*("`@("`@("`@("`@)&-O;'-P86-E(#T@)T1E=FEC94--64LG.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1C;VQS<&%C92`]("=$979I8V5'
M<F%Y)SL*("`@("`@("!]"B`@("`@("`@)&)P8R`](&ES<V5T*"1I;6=;)V)I
M=',G72D@/R`D:6UG6R=B:71S)UT@.B`X.PH*("`@("`@("`O*B!296%D('=H
M;VQE(&9I;&4N("HO"B`@("`@("`@)&8@/2!F;W!E;B@D9FEL92P@)W)B)RD[
M"B`@("`@("`@)&1A=&$@/2!F<F5A9"@D9BP@9FEL97-I>F4H)&9I;&4I*3L*
M("`@("`@("!F8VQO<V4H)&8I.PH*("`@("`@("!R971U<FX@87)R87DH)W<G
M(#T^("1I;6=;,%TL("=H)R`]/B`D:6UG6S%=+"`G8W,G(#T^("1C;VQS<&%C
M92P@)V)P8R<@/3X@)&)P8RP@)V8G(#T^("=$0U1$96-O9&4G+"`G9&%T82<@
M/3X@)&1A=&$I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P87)S95!.1R@D9FEL
M92D*("`@('L*("`@("`@("`O*B!%>'1R86-T(&EN9F\@9G)O;2!A(%!.1R!F
M:6QE+B`J+PH@("`@("`@("1F(#T@9F]P96XH)&9I;&4L("=R8B<I.PH@("`@
M("`@(&EF("@A)&8I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*'-P<FEN=&8H)U5N86)L92!T;R!O<&5N(&EM86=E(&9I;&4Z("5S
M)RP@)&9I;&4I*3L*("`@("`@("!]"@H@("`@("`@("\J($-H96-K('-I9VYA
M='5R92X@*B\*("`@("`@("!I9B`H9G)E860H)&8L(#@I("$](&-H<B@Q,S<I
M("X@)U!.1R<@+B!C:'(H,3,I("X@8VAR*#$P*2`N(&-H<B@R-BD@+B!C:'(H
M,3`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS
M<')I;G1F*"=.;W0@82!03D<@9FEL93H@)7,G+"`D9FEL92DI.PH@("`@("`@
M('T*"B`@("`@("`@+RH@4F5A9"!H96%D97(@8VAU;FLN("HO"B`@("`@("`@
M9G)E860H)&8L(#0I.PH@("`@("`@(&EF("AF<F5A9"@D9BP@-"D@(3T@)TE(
M1%(G*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAS
M<')I;G1F*"=);F-O<G)E8W0@4$Y'(&9I;&4Z("5S)RP@)&9I;&4I*3L*("`@
M("`@("!]"B`@("`@("`@)'=I9'1H(#T@)'1H:7,M/E]F<F5A9$EN="@D9BD[
M"B`@("`@("`@)&AE:6=H="`]("1T:&ES+3Y?9G)E861);G0H)&8I.PH@("`@
M("`@("1B<&,@/2!O<F0H9G)E860H)&8L(#$I*3L*("`@("`@("!I9B`H)&)P
M8R`^(#@I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*'-P<FEN=&8H)S$V+6)I="!D97!T:"!N;W0@<W5P<&]R=&5D.B`E<R<L("1F
M:6QE*2D["B`@("`@("`@?0H@("`@("`@("1C="`](&]R9"AF<F5A9"@D9BP@
M,2DI.PH@("`@("`@(&EF("@D8W0@/3T@,"D@>PH@("`@("`@("`@("`D8V]L
M<W!A8V4@/2`G1&5V:6-E1W)A>2<["B`@("`@("`@?2!E;'-E:68@*"1C="`]
M/2`R*2!["B`@("`@("`@("`@("1C;VQS<&%C92`]("=$979I8V521T(G.PH@
M("`@("`@('T@96QS96EF("@D8W0@/3T@,RD@>PH@("`@("`@("`@("`D8V]L
M<W!A8V4@/2`G26YD97AE9"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)T%L<&AA(&-H
M86YN96P@;F]T('-U<'!O<G1E9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*
M("`@("`@("!I9B`H;W)D*&9R96%D*"1F+"`Q*2D@(3T@,"D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G56YK;F]W
M;B!C;VUP<F5S<VEO;B!M971H;V0Z("5S)RP@)&9I;&4I*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&]R9"AF<F5A9"@D9BP@,2DI("$](#`I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*'-P<FEN=&8H)U5N:VYO
M=VX@9FEL=&5R(&UE=&AO9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@
M("`@("!I9B`H;W)D*&9R96%D*"1F+"`Q*2D@(3T@,"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H<W!R:6YT9B@G26YT97)L86-I
M;F<@;F]T('-U<'!O<G1E9#H@)7,G+"`D9FEL92DI.PH@("`@("`@('T*("`@
M("`@("!F<F5A9"@D9BP@-"D["B`@("`@("`@)'!A<FUS(#T@)R]$96-O9&50
M87)M<R`\/"]0<F5D:6-T;W(@,34@+T-O;&]R<R`G("X@*"1C="`]/2`R(#\@
M,R`Z(#$I+B<@+T)I='-097)#;VUP;VYE;G0@)R`N("1B<&,@+B`G("]#;VQU
M;6YS("<@+B`D=VED=&@N)SX^)SL*("`@("`@("`O*B!38V%N(&-H=6YK<R!L
M;V]K:6YG(&9O<B!P86QE='1E+"!T<F%N<W!A<F5N8WD@86YD(&EM86=E(&1A
M=&$N("HO"B`@("`@("`@)'!A;"`]("<G.PH@("`@("`@("1T<FYS(#T@)R<[
M"B`@("`@("`@)&1A=&$@/2`G)SL*("`@("`@("!D;R!["B`@("`@("`@("`@
M("1N(#T@)'1H:7,M/E]F<F5A9$EN="@D9BD["B`@("`@("`@("`@("1T>7!E
M(#T@9G)E860H)&8L(#0I.PH@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)U!,
M5$4G*2!["B`@("`@("`@("`@("`@("`O*B!296%D('!A;&5T=&4@*B\*("`@
M("`@("`@("`@("`@("1P86P@/2!F<F5A9"@D9BP@)&XI.PH@("`@("`@("`@
M("`@("`@9G)E860H)&8L(#0I.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1Y
M<&4@/3T@)W123E,G*2!["B`@("`@("`@("`@("`@("`O*B!296%D('1R86YS
M<&%R96YC>2!I;F9O("HO"B`@("`@("`@("`@("`@("`D="`](&9R96%D*"1F
M+"`D;BD["B`@("`@("`@("`@("`@("!I9B`H)&-T(#T](#`I('L*("`@("`@
M("`@("`@("`@("`@("`D=')N<R`](&%R<F%Y*&]R9"AS=6)S='(H)'0L(#$L
M(#$I*2D["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-T(#T](#(I('L*
M("`@("`@("`@("`@("`@("`@("`D=')N<R`](&%R<F%Y*&]R9"AS=6)S='(H
M)'0L(#$L(#$I*2P@;W)D*'-U8G-T<B@D="P@,RP@,2DI+"!O<F0H<W5B<W1R
M*"1T+"`U+"`Q*2DI.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`D<&]S(#T@<W1R<&]S*"1T+"!C:'(H,"DI.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]I;G0H)'!O<RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1R;G,@/2!A<G)A>2@D<&]S*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!F<F5A9"@D9BP@-"D["B`@("`@("`@("`@('T@96QS96EF("@D='EP92`]
M/2`G241!5"<I('L*("`@("`@("`@("`@("`@("\J(%)E860@:6UA9V4@9&%T
M82!B;&]C:R`J+PH@("`@("`@("`@("`@("`@)&1A=&$@+CT@9G)E860H)&8L
M("1N*3L*("`@("`@("`@("`@("`@(&9R96%D*"1F+"`T*3L*("`@("`@("`@
M("`@?2!E;'-E:68@*"1T>7!E(#T]("=)14Y$)RD@>PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("!F<F5A9"@D9BP@)&X@*R`T*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*"1N*3L*"B`@("`@("`@:68@*"1C;VQS<&%C92`]/2`G26YD97AE
M9"<@)B8@96UP='DH)'!A;"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*'-P<FEN=&8H)TUI<W-I;F<@<&%L971T92!I;CH@)7,G
M+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@("!F8VQO<V4H)&8I.PH*("`@
M("`@("!R971U<FX@87)R87DH)W<G(#T^("1W:61T:"P@)V@G(#T^("1H96EG
M:'0L("=C<R<@/3X@)&-O;'-P86-E+"`G8G!C)R`]/B`D8G!C+"`G9B<@/3X@
M)T9L871E1&5C;V1E)RP@)W!A<FUS)R`]/B`D<&%R;7,L("=P86PG(#T^("1P
M86PL("=T<FYS)R`]/B`D=')N<RP@)V1A=&$G(#T^("1D871A*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?9G)E861);G0H)&8I"B`@("!["B`@("`@("`@+RH@
M4F5A9"!A(#0M8GET92!I;G1E9V5R(&9R;VT@9FEL92X@*B\*("`@("`@("`D
M:2`@/2!O<F0H9G)E860H)&8L(#$I*2`\/"`R-#L*("`@("`@("`D:2`K/2!O
M<F0H9G)E860H)&8L(#$I*2`\/"`Q-CL*("`@("`@("`D:2`K/2!O<F0H9G)E
M860H)&8L(#$I*2`\/"`X.PH@("`@("`@("1I("L](&]R9"AF<F5A9"@D9BP@
M,2DI.PH@("`@("`@(')E='5R;B`D:3L*("`@('T*"B`@("!F=6YC=&EO;B!?
M=&5X=%-T<FEN9R@D<RD*("`@('L*("`@("`@("`O*B!&;W)M870@82!T97AT
M('-T<FEN9R`J+PH@("`@("`@(')E='5R;B`G*"<@+B`D=&AI<RT^7V5S8V%P
M92@D<RD@+B`G*2<["B`@("!]"@H@("`@9G5N8W1I;VX@7V5S8V%P92@D<RD*
M("`@('L*("`@("`@("`O*B!!9&0@7"!B969O<F4@7"P@*"!A;F0@*2`J+PH@
M("`@("`@(')E='5R;B!S=')?<F5P;&%C92AA<G)A>2@G*2<L)R@G+"=<7"<I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G7%PI)RPG7%PH
M)RPG7%Q<7"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`D<RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@7W!U=%-T<F5A;2@D<RD*("`@('L*("`@("`@
M("`D=&AI<RT^7V]U="@G<W1R96%M)RD["B`@("`@("`@)'1H:7,M/E]O=70H
M)',I.PH@("`@("`@("1T:&ES+3Y?;W5T*"=E;F1S=')E86TG*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!?;W5T*"1S*0H@("`@>PH@("`@("`@("\J($%D9"!A
M(&QI;F4@=&\@=&AE(&1O8W5M96YT+B`J+PH@("`@("`@(&EF("@D=&AI<RT^
M7W-T871E(#T](#(I('L*("`@("`@("`@("`@)'1H:7,M/E]P86=E<ULD=&AI
M<RT^7W!A9V5=("X]("1S("X@(EQN(CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^7V)U9F9E<B`N/2`D<R`N(")<;B(["B`@("`@("`@
M?0H@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]#4U8N<&AP
M````````````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-#`S-#8@,3`U,34T,S0Q,S8@,#(P,S,U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U!%
M05(N<&AP)SL*<F5Q=6ER95]O;F-E("=&:6QE+G!H<"<["@HO*BH*("H@5&AE
M($9I;&5?0U-6('!A8VMA9V4@86QL;W=S(')E861I;F<@86YD(&-R96%T:6YG
M(&]F($-35B!D871A(&%N9"!F:6QE<RX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO1FEL95]#4U8O0U-6+G!H<"QV(#$N-"XR+C<@,C`P-B\P,R\S,"`Q,#HQ
M-3HR.2!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#(M,C`P,R!4
M;VUA<R!6;VX@5F5S8VAL97(@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($-O
M<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@=&AA="!I<PH@*B!B=6YD;&5D
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R!A=F%I;&%B;&4@870@=&AR;W5G:`H@*B!T:&4@=V]R;&0M=VED92UW96(@
M870@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y
M;W4@9&ED(&YO=`H@*B!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE"B`J
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A"B`J(&-O<'D@:6UM961I
M871E;'DN"B`J"B`J($!A=71H;W(@(%1O;6%S(%9O;B!697-C:&QE<B!#;W@@
M/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@2F%N(%-C:&YE:61E<B`\
M:F%N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXQ"B`J($!P86-K
M86=E($9I;&5?0U-6"B`J+PIC;&%S<R!&:6QE7T-35B!["@H@("`@+RHJ"B`@
M("`@*B!$:7-C;W9E<G,@=&AE(&9O<FUA="!O9B!A($-35B!F:6QE("AT:&4@
M;G5M8F5R(&]F(&9I96QD<RP@=&AE('-E<&%R871O<BP*("`@("`J('1H92!Q
M=6]T92!S=')I;F<L(&%N9"!T:&4@;&EN92!B<F5A:RDN"B`@("`@*@H@("`@
M("H@5V4@8V%N)W0@=7-E('1H92!A=71O7V1E=&5C=%]L:6YE7V5N9&EN9W,@
M4$A0('-E='1I;F<L(&)E8V%U<V4@:70G<R!N;W0*("`@("`J('-U<'!O<G1E
M9"!B>2!F9V5T<R@I(&-O;G1R87)Y('1O('=H870@=&AE(&UA;G5A;"!S87ES
M+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("!4:&4@0U-6(&9I;&4@;F%M90H@("`@("H@0'!A<F%M(&%R<F%Y
M("`@17AT<F$@<V5P87)A=&]R<R!T:&%T('-H;W5L9"!B92!C:&5C:V5D(&9O
M<BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!4:&4@9F]R;6%T(&AA
M<V@N"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O=F5R1F]R;6%T*"1F:6QE
M+"`D97AT<F%397!S(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H(21F
M<"`]($!F;W!E;B@D9FEL92P@)W(G*2D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&]P96X@9FEL93H@)R`N("1F
M:6QE*3L*("`@("`@("!]"@H@("`@("`@("1S97!S(#T@87)R87DH(EQT(BP@
M)SLG+"`G.B<L("<L)RD["B`@("`@("`@)'-E<',@/2!A<G)A>5]M97)G92@D
M<V5P<RP@)&5X=')A4V5P<RD["B`@("`@("`@)&UA=&-H97,@/2!A<G)A>2@I
M.PH@("`@("`@("1C<FQF(#T@;G5L;#L*("`@("`@("`D8V]N9B`](&%R<F%Y
M*"D["@H@("`@("`@("\J(%1A:V4@=&AE(&9I<G-T(#$P(&QI;F5S(&%N9"!S
M=&]R92!T:&4@;G5M8F5R(&]F(&]C=7)R96YC97,@9F]R(&5A8V@*("`@("`@
M("`@*B!S97!A<F%T;W(@:6X@96%C:"!L:6YE+B`J+PH@("`@("`@(&9O<B`H
M)&D@/2`P.R`H)&D@/"`Q,"D@)B8@*"1L:6YE(#T@9F=E=',H)&9P*2D[*2![
M"B`@("`@("`@("`@("\J($1O('=E(&AA=F4@36%C(&QI;F4@96YD:6YG<S\@
M*B\*("`@("`@("`@("`@)&QI;F5S(#T@<')E9U]S<&QI="@G+UQR*#\A7&XI
M+R<L("1L:6YE+"`Q,"D["B`@("`@("`@("`@("1J(#T@,#L*("`@("`@("`@
M("`@)&,@/2!C;W5N="@D;&EN97,I.PH@("`@("`@("`@("!I9B`H)&,@/B`Q
M*2!["B`@("`@("`@("`@("`@("`D8W)L9B`](")<<B(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@=VAI;&4@*"1I(#P@,3`@)B8@)&H@/"`D8RD@>PH@
M("`@("`@("`@("`@("`@)&QI;F4@/2`D;&EN97-;)&I=.PH@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D8W)L9BDI('L*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("AA<G)A>2@B7')<;B(L(")<;B(I(&%S("1C*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L("US=')L96XH
M)&,I*2`]/2`D8RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-R
M;&8@/2`D8SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&DK*SL*("`@
M("`@("`@("`@("`@("1J*RL["B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<V5P<R!A<R`D<V5P*2!["B`@("`@("`@("`@("`@("`@("`@)&UA=&-H97-;
M)'-E<%U;)&E=(#T@<W5B<W1R7V-O=6YT*"1L:6YE+"`D<V5P*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I
M9B`H:7-S970H)&-R;&8I*2!["B`@("`@("`@("`@("1C;VYF6R=C<FQF)UT@
M/2`D8W)L9CL*("`@("`@("!]"@H@("`@("`@("\J($=R;W5P('1H92!R97-U
M;'1S(&)Y(&%M;W5N="!O9B!E<75A;"!O8W5R<F5N8V5S+B`J+PH@("`@("`@
M("1F:65L9',@/2!A<G)A>2@I.PH@("`@("`@("1A;6]U;G0@/2!A<G)A>2@I
M.PH@("`@("`@(&9O<F5A8V@@*"1M871C:&5S(&%S("1S97`@/3X@)&QI;F5S
M*2!["B`@("`@("`@("`@("1T:6UE<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1T:6UE<ULP72`](#`["B`@("`@("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A
M<R`D;G5M*2!["B`@("`@("`@("`@("`@("!I9B`H)&YU;2`^(#`I('L*("`@
M("`@("`@("`@("`@("`@("`D=&EM97-;)&YU;5T@/2`H:7-S970H)'1I;65S
M6R1N=6U=*2D@/R`D=&EM97-;)&YU;5T@*R`Q(#H@,3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!A<G-O<G0H)'1I;65S
M*3L*("`@("`@("`@("`@)&9I96QD<ULD<V5P72`](&ME>2@D=&EM97,I.PH@
M("`@("`@("`@("`D86UO=6YT6R1S97!=(#T@)'1I;65S6VME>2@D=&EM97,I
M73L*("`@("`@("!]"B`@("`@("`@87)S;W)T*"1A;6]U;G0I.PH@("`@("`@
M("1S97`@/2!K97DH)&%M;W5N="D["@H@("`@("`@("1C;VYF6R=F:65L9',G
M72`]("1F:65L9'-;)'-E<%T@*R`Q.PH@("`@("`@("1C;VYF6R=S97`G72`@
M("`]("1S97`["@H@("`@("`@("\J(%1E<W0@:68@=&AE<F4@87)E(&9I96QD
M<R!W:71H('%U;W1E<R!A<G)O=6YD(&EN('1H92!F:7)S="`U"B`@("`@("`@
M("H@;&EN97,N("HO"B`@("`@("`@)'%U;W1E<R`]("<B7"<G.PH@("`@("`@
M("1Q=6]T92`@/2`G)SL*("`@("`@("!R97=I;F0H)&9P*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@*"1I(#P@-2D@)B8@*"1L:6YE(#T@9F=E=',H)&9P*2D[
M("1I*RLI('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H(GPD<V5P*%LD
M<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<'Q5(BP@)&QI;F4L("1M871C:"DI
M('L*("`@("`@("`@("`@("`@(&EF("@D;6%T8VA;,5T@/3T@)&UA=&-H6S)=
M*2!["B`@("`@("`@("`@("`@("`@("`@)'%U;W1E(#T@)&UA=&-H6S%=.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*")\7BA;
M)'%U;W1E<UTI+BHH6R1Q=6]T97-=*21S97!\(BP@)&QI;F4L("1M871C:"D@
M?'P*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H(GPH6R1Q=6]T97-=*2XJ
M*%LD<75O=&5S72DD<V5P7',D?%5S(BP@)&QI;F4L("1M871C:"DI"B`@("`@
M("`@("`@('L*("`@("`@("`@("`@("`@(&EF("@D;6%T8VA;,5T@/3T@)&UA
M=&-H6S)=*2!["B`@("`@("`@("`@("`@("`@("`@)'%U;W1E(#T@)&UA=&-H
M6S%=.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1C;VYF6R=Q
M=6]T92==(#T@)'%U;W1E.PH*("`@("`@("!F8VQO<V4H)&9P*3L*"B`@("`@
M("`@+R\@6%A8(%=H870@86)O=70@=')Y:6YG('1O(&1I<V-O=F5R('1H92`B
M:&5A9&5R(C\*("`@("`@("!R971U<FX@)&-O;F8["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!296%D<R!A(')O=R!F<F]M(&$@0U-6(&9I;&4@86YD(')E='5R
M;G,@:70@87,@86X@87)R87DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9FEL92`@5&AE(&YA;64@;V8@=&AE($-35B!F:6QE+@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1C;VYF("`@5&AE(&-O;F9I9W5R871I;VX@9F]R('1H92!#
M4U8@9FEL92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&)O;VQE86X@
M(%1H92!#4U8@9&%T82!O<B!F86QS92!I9B!N;R!M;W)E(&1A=&$@879A:6QA
M8FQE+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%D*"1F:6QE+"`F)&-O;F8I
M"B`@("!["B`@("`@("`@)&9P(#T@1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I
M;&4L("1C;VYF+"!&24Q%7TU/1$5?4D5!1"D["B`@("`@("`@:68@*&ES7V$H
M)&9P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;B`D9G`[
M"B`@("`@("`@?0H*("`@("`@("`D;&EN92`](&9G971S*"1F<"D["B`@("`@
M("`@:68@*"$D;&EN92D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H*("`@("`@("`O*B!5<V4@<F5A9%%U;W1E9"@I(&EF('=E(&AA
M=F4@36%C(&QI;F4@96YD:6YG<RX@*B\*("`@("`@("!I9B`H<')E9U]M871C
M:"@G+UQR*#\A7&XI+R<L("1L:6YE*2D@>PH@("`@("`@("`@("!F<V5E:R@D
M9G`L("US=')L96XH)&QI;F4I+"!3145+7T-54BD["B`@("`@("`@("`@(')E
M='5R;B!&:6QE7T-35CHZ<F5A9%%U;W1E9"@D9FEL92P@)&-O;F8I.PH@("`@
M("`@('T*"B`@("`@("`@1FEL95]#4U8Z.E]L:6YE*$9I;&5?0U-6.CI?;&EN
M92@I("L@,2D["@H@("`@("`@(&EF("@D8V]N9ELG9FEE;&1S)UT@/3T@,2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87DH)&QI;F4I.PH@("`@("`@('T*
M"B`@("`@("`@)&9I96QD<R`](&5X<&QO9&4H)&-O;F9;)W-E<"==+"`D;&EN
M92D["B`@("`@("`@:68@*"1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@("`@
M("1L87-T(#T@)B1F:65L9'-;8V]U;G0H)&9I96QD<RD@+2`Q73L*("`@("`@
M("`@("`@+RH@1F%L;&)A8VL@=&\@<F5A9"!T:&4@;&EN92!W:71H(')E8611
M=6]T960H*2!W:&5N(&=U97-S('1H870@=&AE"B`@("`@("`@("`@("`J('-I
M;7!L92!E>'!L;V1E('=O;B=T('=O<FL@<FEG:'0N("HO"B`@("`@("`@("`@
M(&EF("@H<W5B<W1R*"1L87-T+"`M<W1R;&5N*"1C;VYF6R=C<FQF)UTI*2`]
M/2`D8V]N9ELG8W)L9B==("8F"B`@("`@("`@("`@("`@("`@)&QA<W1[,'T@
M/3T@)&-O;F9;)W%U;W1E)UT@)B8*("`@("`@("`@("`@("`@("`D;&%S='MS
M=')L96XH<G1R:6TH)&QA<W0I*2`M(#%]("$]("1C;VYF6R=Q=6]T92==*2!\
M?`H@("`@("`@("`@("`@("`@*&-O=6YT*"1F:65L9',I("$]("1C;VYF6R=F
M:65L9',G72D*("`@("`@("`@("`@("`@("`@("`O+R!86%@@<&5R:&%P<R!T
M:&5R92!I<R!A('-E<&%R871O<B!I;G-I9&4@82!Q=6]T960@9FEE;&0*("`@
M("`@("`@("`@("`@("`@("`O+W!R96=?;6%T8V@H(GQ[)&-O;F9;)W%U;W1E
M)UU]+BI[)&-O;F9;)W-E<"==?2XJ>R1C;VYF6R=Q=6]T92==?7Q5(BP@)&QI
M;F4I"B`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@('L*("`@("`@("`@
M("`@("`@(&9S965K*"1F<"P@+7-T<FQE;B@D;&EN92DL(%-%14M?0U52*3L*
M("`@("`@("`@("`@("`@(')E='5R;B!&:6QE7T-35CHZ<F5A9%%U;W1E9"@D
M9FEL92P@)&-O;F8I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&QA<W0@/2!R=')I;2@D;&%S="D["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D9FEE;&1S(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@
M("`@("`@)&9I96QD<ULD:UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D=BP@)&-O
M;F9;)W%U;W1E)UTL("1C;VYF6R=C<FQF)UTI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&9I96QD<UMC;W5N="@D9FEE;&1S*2`M,5T@/2!R=')I;2@D9FEE;&1S6V-O
M=6YT*"1F:65L9',I("TQ72D["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U
M;G0H)&9I96QD<RD@/"`D8V]N9ELG9FEE;&1S)UTI('L*("`@("`@("`@("`@
M1FEL95]#4U8Z.G=A<FYI;F<H<W!R:6YT9BA?*")7<F]N9R!N=6UB97(@;V8@
M9FEE;&1S(&EN(&QI;F4@)60N($5X<&5C=&5D("5D+"!F;W5N9"`E9"XB*2P@
M1FEL95]#4U8Z.E]L:6YE*"DL("1C;VYF6R=F:65L9',G72P@8V]U;G0H)&9I
M96QD<RDI*3L*("`@("`@("`@("`@)&9I96QD<R`](&%R<F%Y7VUE<F=E*"1F
M:65L9',L(&%R<F%Y7V9I;&PH,"P@)&-O;F9;)V9I96QD<R==("T@8V]U;G0H
M)&9I96QD<RDL("<G*2D["B`@("`@("`@?2!E;'-E:68@*&-O=6YT*"1F:65L
M9',I(#X@)&-O;F9;)V9I96QD<R==*2!["B`@("`@("`@("`@($9I;&5?0U-6
M.CIW87)N:6YG*'-P<FEN=&8H7R@B36]R92!F:65L9',@9F]U;F0@:6X@;&EN
M92`E9"!T:&%N('1H92!E>'!E8W1E9"`E9"XB*2P@1FEL95]#4U8Z.E]L:6YE
M*"DL("1C;VYF6R=F:65L9',G72DI.PH@("`@("`@("`@("!A<G)A>5]S<&QI
M8V4H)&9I96QD<RP@)&-O;F9;)V9I96QD<R==*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9FEE;&1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A
M9',@82!R;W<@9G)O;2!A($-35B!F:6QE(&%N9"!R971U<FYS(&ET(&%S(&%N
M(&%R<F%Y+@H@("`@("H@5&AI<R!M971H;V0@:7,@86)L92!T;R!R96%D(&9I
M96QD<R!W:71H(&UU;'1I;&EN92!D871A(&%N9"!N;W)M86QI>F5S"B`@("`@
M*B!L:6YE8G)E86MS('1O('-I;F=L92!N97=L:6YE(&-H87)A8W1E<G,@*#!X
M,&$I+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@(%1H92!N
M86UE(&]F('1H92!#4U8@9FEL92X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N
M9B`@(%1H92!C;VYF:6=U<F%T:6]N(&9O<B!T:&4@0U-6(&9I;&4N"B`@("`@
M*@H@("`@("H@0')E='5R;B!A<G)A>7QB;V]L96%N("!4:&4@0U-6(&1A=&$@
M;W(@9F%L<V4@:68@;F\@;6]R92!D871A(&%V86EL86)L92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F5A9%%U;W1E9"@D9FEL92P@)B1C;VYF*0H@("`@>PH@
M("`@("`@("1F<"`]($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N
M9BP@1DE,15]-3T1%7U)%040I.PH@("`@("`@(&EF("AI<U]A*"1F<"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@
M('T*"B`@("`@("`@+RH@02!B=69F97(@=VET:"!A;&P@8VAA<F%C=&5R<R!O
M9B!T:&4@8W5R<F5N="!F:65L9"!R96%D('-O(&9A<BX@*B\*("`@("`@("`D
M8G5F9B`]("<G.PH@("`@("`@("\J(%1H92!C=7)R96YT(&-H87)A8W1E<BX@
M*B\*("`@("`@("`D8R`](&YU;&P["B`@("`@("`@+RH@5&AE(')E860@9FEE
M;&1S+B`J+PH@("`@("`@("1R970@/2!A<G)A>2@I.PH@("`@("`@("\J(%1H
M92!N=6UB97(@;V8@=&AE(&-U<G)E;G0@9FEE;&0N("HO"B`@("`@("`@)&D@
M/2`Q.PH@("`@("`@("\J($%R92!W92!I;G-I9&4@82!Q=6]T960@9FEE;&0_
M("HO"B`@("`@("`@)&EN7W%U;W1E(#T@9F%L<V4["@H@("`@("`@('=H:6QE
M("@H)&-H(#T@9F=E=&,H)&9P*2D@(3T](&9A;'-E*2!["B`@("`@("`@("`@
M("\J(%!R979I;W5S(&-H87)A8W1E<BX@*B\*("`@("`@("`@("`@)'!R978@
M/2`D8SL*("`@("`@("`@("`@+RH@0W5R<F5N="!C:&%R86-T97(N("HO"B`@
M("`@("`@("`@("1C(#T@)&-H.PH*("`@("`@("`@("`@+RH@4VEM<&QE(&-H
M87)A8W1E<BX@*B\*("`@("`@("`@("`@:68@*"1C("$]("1C;VYF6R=Q=6]T
M92==("8F"B`@("`@("`@("`@("`@("`D8R`A/2`D8V]N9ELG<V5P)UT@)B8*
M("`@("`@("`@("`@("`@('-T<G!O<R@D8V]N9ELG8W)L9B==+"`D8RD@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D8G5F9B`N/2`D8SL*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H)&-O;F9;)W%U;W1E)UT@)B8@)&,@/3T@)&-O;F9;)W%U;W1E)UT@
M)B8*("`@("`@("`@("`@("`@("@D<')E=B`]/2`D8V]N9ELG<V5P)UT@?'P*
M("`@("`@("`@("`@("`@("`D<')E=B`]/2!S=6)S='(H)&-O;F9;)V-R;&8G
M72P@+3$I('Q\"B`@("`@("`@("`@("`@("`@)'!R978@/3T](&YU;&PI*0H@
M("`@("`@("`@("!["B`@("`@("`@("`@("`@("`O*B!1=6]T92!B96=I;BX@
M*B\*("`@("`@("`@("`@("`@("1I;E]Q=6]T92`]('1R=64["B`@("`@("`@
M("`@('T@96QS96EF("@D:6Y?<75O=&4I('L*("`@("`@("`@("`@("`@("\J
M(%%U;W1E(&5N9#\@*B\*("`@("`@("`@("`@("`@(&EF("@D8R`]/2`D8V]N
M9ELG<V5P)UT@)B8@)'!R978@/3T@)&-O;F9;)W%U;W1E)UTI('L*("`@("`@
M("`@("`@("`@("`@("`D:6Y?<75O=&4@/2!F86QS93L*("`@("`@("`@("`@
M("`@('T@96QS96EF("@D8R`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3$I
M*2!["B`@("`@("`@("`@("`@("`@("`@)'-U8B`]("AS=')L96XH)&-O;F9;
M)V-R;&8G72D@/B`Q("8F"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')E=B`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3(L(#$I*0H@("`@("`@
M("`@("`@("`@("`@("`@("`_(#(*("`@("`@("`@("`@("`@("`@("`@("`@
M.B`Q.PH@("`@("`@("`@("`@("`@("`@(&EF("@H<W1R;&5N*"1B=69F*2`^
M/2`D<W5B*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`H)&)U9F9[<W1R
M;&5N*"1B=69F*2`M("1S=6)](#T]("1C;VYF6R=Q=6]T92==*2D*("`@("`@
M("`@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`@("`@("`@("1I;E]Q
M=6]T92`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@($9I;&5?0U-6.CI?;&EN92A&:6QE7T-3
M5CHZ7VQI;F4H*2`K(#$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@16YD
M(&]F(&QI;F4@;W(@96YD(&]F(&9I96QD+B`J+PH@("`@("`@("`@("!I9B`H
M(21I;E]Q=6]T92`F)@H@("`@("`@("`@("`@("`@*"1C(#T]("1C;VYF6R=S
M97`G72!\?"`D8R`]/2!S=6)S='(H)&-O;F9;)V-R;&8G72P@+3$I*2D@>PH@
M("`@("`@("`@("`@("`@+RH@36]R92!F:65L9',@=&AA;B!E>'!E8W1E9"X@
M*B\*("`@("`@("`@("`@("`@(&EF("@D8R`]/2`D8V]N9ELG<V5P)UT@)B8*
M("`@("`@("`@("`@("`@("`@("`H8V]U;G0H)')E="D@*R`Q*2`]/2`D8V]N
M9ELG9FEE;&1S)UTI('L*("`@("`@("`@("`@("`@("`@("!W:&EL92`H)&,@
M(3T](&9A;'-E("8F("1C("$]('-U8G-T<B@D8V]N9ELG8W)L9B==+"`M,2DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&,@/2!F9V5T8R@D9G`I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!&:6QE
M7T-35CHZ=V%R;FEN9RAS<')I;G1F*%\H(DUO<F4@9FEE;&1S(&9O=6YD(&EN
M(&QI;F4@)60@=&AA;B!T:&4@97AP96-T960@)60N(BDL($9I;&5?0U-6.CI?
M;&EN92@I+"`D8V]N9ELG9FEE;&1S)UTI*3L*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("!I9B`H)'!R978@/3T@<W5B<W1R*"1C;VYF6R=C
M<FQF)UTL("TR+"`Q*2D@>PH@("`@("`@("`@("`@("`@("`@("1B=69F(#T@
M<W5B<W1R*"1B=69F+"`P+"`M,2D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@+RH@3&5S<R!F:65L9',@=&AA;B!E>'!E8W1E9"X@*B\*
M("`@("`@("`@("`@("`@(&EF("@H)&,@/3T@<W5B<W1R*"1C;VYF6R=C<FQF
M)UTL("TQ*2D@)B8*("`@("`@("`@("`@("`@("`@("`H)&D@(3T@)&-O;F9;
M)V9I96QD<R==*2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D:2`]/2`Q
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("\J(%-K:7`@96UP='D@;&EN
M97,N("HO"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!&:6QE
M7T-35CHZ=V%R;FEN9RAS<')I;G1F*%\H(E=R;VYG(&YU;6)E<B!O9B!F:65L
M9',@:6X@;&EN92`E9"X@17AP96-T960@)60L(&9O=6YD("5D+B(I+"!&:6QE
M7T-35CHZ7VQI;F4H*2P@)&-O;F9;)V9I96QD<R==+"`D:2DI.PH*("`@("`@
M("`@("`@("`@("`@("`D<F5T6UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D8G5F
M9BP@)&-O;F9;)W%U;W1E)UTL("1C;VYF6R=C<FQF)UTI.PH@("`@("`@("`@
M("`@("`@("`@("1R970@/2!A<G)A>5]M97)G92@D<F5T+"!A<G)A>5]F:6QL
M*#`L("1C;VYF6R=F:65L9',G72`M("1I+"`G)RDI.PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1R971;72`]($9I;&5?0U-6.CIU;G%U;W1E*"1B=69F+"`D
M8V]N9ELG<75O=&4G72P@)&-O;F9;)V-R;&8G72D["B`@("`@("`@("`@("`@
M("!I9B`H8V]U;G0H)')E="D@/3T@)&-O;F9;)V9I96QD<R==*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)&)U9F8@/2`G)SL*("`@("`@("`@("`@("`@
M("1I*RL["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D8G5F9B`N/2`D8SL*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!F96]F*"1F<"D@/R!F86QS92`Z("1R970["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!7<FET97,@82!H87-H(&EN=&\@82!#4U8@9FEL92X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("`@5&AE(&YA;64@;V8@
M=&AE($-35B!F:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("1F:65L9',@(%1H
M92!#4U8@9&%T82X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("!4:&4@
M8V]N9FEG=7)A=&EO;B!F;W(@=&AE($-35B!F:6QE+@H@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B`@5')U92!O;B!S=6-C97-S+"!014%27T5R<F]R
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E*"1F:6QE
M+"`D9FEE;&1S+"`F)&-O;F8I"B`@("!["B`@("`@("`@:68@*&ES7V$H)&9P
M(#T@1FEL95]#4U8Z.F=E=%!O:6YT97(H)&9I;&4L("1C;VYF+"!&24Q%7TU/
M1$5?5U))5$4I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B`D9G`["B`@("`@("`@?0H*("`@("`@("!I9B`H8V]U;G0H)&9I96QD<RD@
M(3T@)&-O;F9;)V9I96QD<R==*2!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*'-P<FEN=&8H7R@B5W)O;F<@;G5M8F5R(&]F(&9I96QD
M<RX@17AP96-T960@)60L(&9O=6YD("5D+B(I+"`D8V]N9ELG9FEE;&1S)UTL
M(&-O=6YT*"1F:65L9',I*2D["B`@("`@("`@?0H*("`@("`@("`D=W)I=&4@
M/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D9FEE;&1S
M*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H(6ES7VYU;65R:6,H)&9I96QD
M<ULD:5TI("8F("1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@("`@("`@("`D
M=W)I=&4@+CT@)&-O;F9;)W%U;W1E)UT@+B`D9FEE;&1S6R1I72`N("1C;VYF
M6R=Q=6]T92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'=R:71E("X]("1F:65L9'-;)&E=.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D:2`\("AC;W5N="@D9FEE;&1S*2`M(#$I*2!["B`@("`@
M("`@("`@("`@("`D=W)I=&4@+CT@)&-O;F9;)W-E<"==.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1C;VYF6R=C
M<FQF)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A
M9G=R:71E*"1F<"P@)'=R:71E*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<BAS<')I;G1F*%\H(D-A;FYO="!W<FET92!T;R!F:6QE
M(%PB)7-<(B(I+"`D9FEL92DI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S('-U<G)O=6YD
M:6YG('%U;W1E<R!F<F]M(&$@<W1R:6YG(&%N9"!N;W)M86QI>F5S(&QI;F5B
M<F5A:W,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9FEE;&0@(%1H
M92!S=')I;F<@=&\@=6YQ=6]T92X*("`@("`J($!P87)A;2!S=')I;F<@)'%U
M;W1E("!4:&4@<75O=&4@8VAA<F%C=&5R+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8W)L9B`@(%1H92!L:6YE8G)E86L@8VAA<F%C=&5R+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!4:&4@=6YQ=6]T960@9&%T82X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=6YQ=6]T92@D9FEE;&0L("1Q=6]T92P@)&-R;&8I
M"B`@("!["B`@("`@("`@+RH@4VMI<"!E;7!T>2!F:65L9',@*&9O<FTZ(#L[
M*2`J+PH@("`@("`@(&EF("@A<W1R;&5N*"1F:65L9"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1F:65L9#L*("`@("`@("!]"B`@("`@("`@:68@*"1Q=6]T
M92`F)B`D9FEE;&1[,'T@/3T@)'%U;W1E("8F("1F:65L9'MS=')L96XH)&9I
M96QD*2TQ?2`]/2`D<75O=&4I('L*("`@("`@("`@("`@<F5T=7)N('-T<E]R
M97!L86-E*"1C<FQF+"`B7&XB+"!S=6)S='(H)&9I96QD+"`Q+"`M,2DI.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&9I96QD.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V5T<R!O<B!G971S('1H92!C=7)R96YT(&QI;F4@8F5I;F<@
M<&%R<V5D+@H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1L:6YE("!)
M9B!S<&5C:69I960L('1H92!C=7)R96YT(&QI;F4N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G1E9V5R("!4:&4@8W5R<F5N="!L:6YE+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?;&EN92@D;&EN92`](&YU;&PI"B`@("!["B`@("`@("`@
M<W1A=&EC("1C=7)R96YT7VQI;F4@/2`P.PH*("`@("`@("!I9B`H(6ES7VYU
M;&PH)&QI;F4I*2!["B`@("`@("`@("`@("1C=7)R96YT7VQI;F4@/2`D;&EN
M93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D8W5R<F5N=%]L:6YE.PH@
M("`@?0H*("`@("\J*@H@("`@("H@061D<R!A('=A<FYI;F<@=&\@;W(@<F5T
M<FEE=F5S(&%N9"!R97-E=',@=&AE('=A<FYI;F<@<W1A8VLN"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@02!W87)N:6YG('-T<FEN9RX@($EF(&YO
M="!S<&5C:69I960L('1H92!E>&ES=&EN9PH@("`@("H@("`@("`@("`@("`@
M("`@=V%R;FEN9W,@=VEL;"!B92!R971U<FYE9"!I;G-T96%D(&%N9"!T:&4@
M=V%R;FEN9R!S=&%C:PH@("`@("H@("`@("`@("`@("`@("`@9V5T<R!E;7!T
M:65D+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D@($EF(&YO('!A<F%M
M971E<B!H87,@8F5E;B!S<&5C:69I960L('1H92!L:7-T(&]F(&5X:7-T:6YG
M"B`@("`@*B`@("`@("`@("`@("`@("!W87)N:6YG<RX*("`@("`J+PH@("`@
M9G5N8W1I;VX@=V%R;FEN9R@D=V%R;FEN9R`](&YU;&PI"B`@("!["B`@("`@
M("`@<W1A=&EC("1W87)N:6YG<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI
M<U]N=6QL*"1W87)N:6YG*2D@>PH@("`@("`@("`@("`D<F5T=7)N(#T@)'=A
M<FYI;F=S.PH@("`@("`@("`@("`D=V%R;FEN9W,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!R971U<FX@)')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1W
M87)N:6YG<UM=(#T@)'=A<FYI;F<["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&]R(&-R96%T97,@=&AE(&9I;&4@9&5S8W)I<'1O<B!A<W-O8VEA
M=&5D('=I=&@@82!F:6QE+@H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE("!4:&4@;F%M92!O9B!T:&4@
M9FEL90H@("`@("H@0'!A<F%M(&%R<F%Y("1C;VYF("`@5&AE(&-O;F9I9W5R
M871I;VX*("`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@(%1H92!O<&5N(&UO
M9&4N($9)3$5?34]$15]214%$(&]R($9)3$5?34]$15]74DE412X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(')E<V]U<F-E("!4:&4@9FEL92!R97-O=7)C92!O
M<B!014%27T5R<F]R(&]N(&5R<F]R+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710;VEN=&5R*"1F:6QE+"`F)&-O;F8L("1M;V1E(#T@1DE,15]-3T1%7U)%
M040I"B`@("!["B`@("`@("`@<W1A=&EC("1R97-O=7)C97,@/2!A<G)A>2@I
M.PH@("`@("`@('-T871I8R`D8V]N9FEG(#T@87)R87DH*3L*"B`@("`@("`@
M)'-I9VYA='5R92`]("1F:6QE("X@<V5R:6%L:7IE*"1C;VYF*3L*("`@("`@
M("!I9B`H:7-S970H)')E<V]U<F-E<ULD<VEG;F%T=7)E72DI('L*("`@("`@
M("`@("`@)&-O;F8@/2`D8V]N9FEG6R1S:6=N871U<F5=.PH@("`@("`@("`@
M("!R971U<FX@)')E<V]U<F-E<ULD<VEG;F%T=7)E73L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES7V$H)&5R<F]R(#T@1FEL95]#4U8Z.E]C:&5C:T-O;F9I
M9R@D8V]N9BDL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@)&-O;F9I9ULD<VEG;F%T=7)E
M72`]("1C;VYF.PH*("`@("`@("`D9G`@/2!`9F]P96XH)&9I;&4L("1M;V1E
M*3L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1F<"DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9BA?*")#86XG="!O
M<&5N(&9I;&4@7"(E<UPB+B(I+"`D9FEL92DI.PH@("`@("`@('T*("`@("`@
M("`D<F5S;W5R8V5S6R1S:6=N871U<F5=(#T@)&9P.PH@("`@("`@($9I;&5?
M0U-6.CI?;&EN92@P*3L*"B`@("`@("`@:68@*"1M;V1E(#T]($9)3$5?34]$
M15]214%$("8F("%E;7!T>2@D8V]N9ELG:&5A9&5R)UTI*2!["B`@("`@("`@
M("`@(&EF("AI<U]A*"1H96%D97(@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@
M)&-O;F8I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)&AE861E<CL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1F<#L*("`@('T*"B`@("`O*BH*("`@("`J($-H96-K<R!T:&4@
M8V]N9FEG=7)A=&EO;B!G:79E;B!B>2!T:&4@=7-E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@87)R87D@)&-O;F8@("`@5&AE(&-O;F9I9W5R871I;VX@87-S
M;V,@87)R87D*("`@("`J($!P87)A;2!S=')I;F<@)&5R<F]R("!4:&4@97)R
M;W(@=VEL;"!B92!W<FET=&5N(&AE<F4@:68@86YY"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]C:&5C:T-O;F9I9R@F)&-O;F8I"B`@("!["B`@("`@("`@+R\@
M8VAE8VL@8V]N9@H@("`@("`@(&EF("@A:7-?87)R87DH)&-O;F8I*2!["B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(&-O
M;F9I9W5R871I;VXN)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T
M*"1C;VYF6R=F:65L9',G72D@?'P@(6ES7VYU;65R:6,H)&-O;F9;)V9I96QD
M<R==*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BA?
M*")4:&4@;G5M8F5R(&]F(&9I96QD<R!M=7-T(&)E(&YU;65R:6,N(BDI.PH@
M("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=S97`G72DI('L*
M("`@("`@("`@("`@:68@*'-T<FQE;B@D8V]N9ELG<V5P)UTI("$](#$I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H
M92!S97!A<F%T;W(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H)&-O;F9;)V9I96QD
M<R==(#X@,2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<BA?*").;R!S97!A<F%T;W(@<W!E8VEF:65D+B(I*3L*("`@("`@("!]"@H@
M("`@("`@(&EF("@A96UP='DH)&-O;F9;)W%U;W1E)UTI*2!["B`@("`@("`@
M("`@(&EF("AS=')L96XH)&-O;F9;)W%U;W1E)UTI("$](#$I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*%\H(E1H92!Q=6]T
M92!C:&%R86-T97(@;75S="!B92!O;F4@<VEN9VQE(&-H87)A8W1E<BXB*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M8V]N9ELG<75O=&4G72`]("<G.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I
M<W-E="@D8V]N9ELG8W)L9B==*2D@>PH@("`@("`@("`@("`D8V]N9ELG8W)L
M9B==(#T@(EQN(CL*("`@("`@("!]"B`@("!]"@I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT<P``````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$S-B`P,C`V-#4`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I
M;&4O4$1&+V9O;G1S+V-O=7)I97(N<&AP````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-#$V(#$P-3$U-#,T,3,V(#`R,S$P-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M0'!A8VMA9V4@1FEL95]01$8*("HO"F9O<B`H)&D@/2`P.R`D:2`\/2`R-34[
M("1I*RLI('L*("`@("1F;VYT7W=I9'1H<ULG8V]U<FEE<B==6V-H<B@D:2E=
M(#T@-C`P.PI]"B1F;VYT7W=I9'1H<ULG8V]U<FEE<D(G72`]("1F;VYT7W=I
M9'1H<ULG8V]U<FEE<B==.PHD9F]N=%]W:61T:'-;)V-O=7)I97)))UT@/2`D
M9F]N=%]W:61T:'-;)V-O=7)I97(G73L*)&9O;G1?=VED=&AS6R=C;W5R:65R
M0DDG72`]("1F<&1F7W=I9'1H<ULG8V]U<FEE<B==.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F;VYT
M<R]H96QV971I8V%B:2YP:'``````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C(Q,"`Q,#4Q-30S-#$S-B`P,C,W,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E($9I
M;&5?4$1&"B`J+PHD9F]N=%]W:61T:'-;)VAE;'9E=&EC84)))UT@/2!A<G)A
M>2@*("`@(&-H<B@P*3T^,C<X+&-H<B@Q*3T^,C<X+&-H<B@R*3T^,C<X+&-H
M<B@S*3T^,C<X+&-H<B@T*3T^,C<X+&-H<B@U*3T^,C<X+&-H<B@V*3T^,C<X
M+&-H<B@W*3T^,C<X+&-H<B@X*3T^,C<X+&-H<B@Y*3T^,C<X+&-H<B@Q,"D]
M/C(W."QC:'(H,3$I/3XR-S@L8VAR*#$R*3T^,C<X+&-H<B@Q,RD]/C(W."QC
M:'(H,30I/3XR-S@L8VAR*#$U*3T^,C<X+&-H<B@Q-BD]/C(W."QC:'(H,3<I
M/3XR-S@L8VAR*#$X*3T^,C<X+&-H<B@Q.2D]/C(W."QC:'(H,C`I/3XR-S@L
M8VAR*#(Q*3T^,C<X+`H@("`@8VAR*#(R*3T^,C<X+&-H<B@R,RD]/C(W."QC
M:'(H,C0I/3XR-S@L8VAR*#(U*3T^,C<X+&-H<B@R-BD]/C(W."QC:'(H,C<I
M/3XR-S@L8VAR*#(X*3T^,C<X+&-H<B@R.2D]/C(W."QC:'(H,S`I/3XR-S@L
M8VAR*#,Q*3T^,C<X+"<@)ST^,C<X+"<A)ST^,S,S+"<B)ST^-#<T+"<C)ST^
M-34V+"<D)ST^-34V+"<E)ST^.#@Y+"<F)ST^-S(R+"=<)R<]/C(S."PG*"<]
M/C,S,RPG*2<]/C,S,RPG*B<]/C,X.2PG*R<]/C4X-"P*("`@("<L)ST^,C<X
M+"<M)ST^,S,S+"<N)ST^,C<X+"<O)ST^,C<X+"<P)ST^-34V+"<Q)ST^-34V
M+"<R)ST^-34V+"<S)ST^-34V+"<T)ST^-34V+"<U)ST^-34V+"<V)ST^-34V
M+"<W)ST^-34V+"<X)ST^-34V+"<Y)ST^-34V+"<Z)ST^,S,S+"<[)ST^,S,S
M+"<\)ST^-3@T+"<])ST^-3@T+"<^)ST^-3@T+"<_)ST^-C$Q+"=`)ST^.3<U
M+"=!)ST^-S(R+`H@("`@)T(G/3XW,C(L)T,G/3XW,C(L)T0G/3XW,C(L)T4G
M/3XV-C<L)T8G/3XV,3$L)T<G/3XW-S@L)T@G/3XW,C(L)TDG/3XR-S@L)THG
M/3XU-38L)TLG/3XW,C(L)TPG/3XV,3$L)TTG/3XX,S,L)TXG/3XW,C(L)T\G
M/3XW-S@L)U`G/3XV-C<L)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XV-C<L)U0G
M/3XV,3$L)U4G/3XW,C(L)U8G/3XV-C<L)U<G/3XY-#0L"B`@("`G6"<]/C8V
M-RPG62<]/C8V-RPG6B<]/C8Q,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS
M,S,L)UXG/3XU.#0L)U\G/3XU-38L)V`G/3XS,S,L)V$G/3XU-38L)V(G/3XV
M,3$L)V,G/3XU-38L)V0G/3XV,3$L)V4G/3XU-38L)V8G/3XS,S,L)V<G/3XV
M,3$L)V@G/3XV,3$L)VDG/3XR-S@L)VHG/3XR-S@L)VLG/3XU-38L)VPG/3XR
M-S@L)VTG/3XX.#DL"B`@("`G;B<]/C8Q,2PG;R<]/C8Q,2PG<"<]/C8Q,2PG
M<2<]/C8Q,2PG<B<]/C,X.2PG<R<]/C4U-BPG="<]/C,S,RPG=2<]/C8Q,2PG
M=B<]/C4U-BPG=R<]/C<W."PG>"<]/C4U-BPG>2<]/C4U-BPG>B<]/C4P,"PG
M>R<]/C,X.2PG?"<]/C(X,"PG?2<]/C,X.2PG?B<]/C4X-"QC:'(H,3(W*3T^
M,S4P+&-H<B@Q,C@I/3XU-38L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,C<X
M+&-H<B@Q,S$I/3XU-38L"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ
M,#`P+&-H<B@Q,S0I/3XU-38L8VAR*#$S-2D]/C4U-BQC:'(H,3,V*3T^,S,S
M+&-H<B@Q,S<I/3XQ,#`P+&-H<B@Q,S@I/3XV-C<L8VAR*#$S.2D]/C,S,RQC
M:'(H,30P*3T^,3`P,"QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR
M*#$T,RD]/C,U,"QC:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XR-S@L8VAR*#$T
M-BD]/C(W."QC:'(H,30W*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]
M/C,U,"QC:'(H,34P*3T^-34V+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS
M,S,L8VAR*#$U,RD]/C$P,#`L"B`@("!C:'(H,34T*3T^-34V+&-H<B@Q-34I
M/3XS,S,L8VAR*#$U-BD]/CDT-"QC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XU
M,#`L8VAR*#$U.2D]/C8V-RQC:'(H,38P*3T^,C<X+&-H<B@Q-C$I/3XS,S,L
M8VAR*#$V,BD]/C4U-BQC:'(H,38S*3T^-34V+&-H<B@Q-C0I/3XU-38L8VAR
M*#$V-2D]/C4U-BQC:'(H,38V*3T^,C@P+&-H<B@Q-C<I/3XU-38L8VAR*#$V
M."D]/C,S,RQC:'(H,38Y*3T^-S,W+&-H<B@Q-S`I/3XS-S`L8VAR*#$W,2D]
M/C4U-BQC:'(H,3<R*3T^-3@T+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<S
M-RQC:'(H,3<U*3T^,S,S+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^
M-3@T+&-H<B@Q-S@I/3XS,S,L8VAR*#$W.2D]/C,S,RQC:'(H,3@P*3T^,S,S
M+&-H<B@Q.#$I/3XV,3$L8VAR*#$X,BD]/C4U-BQC:'(H,3@S*3T^,C<X+&-H
M<B@Q.#0I/3XS,S,L8VAR*#$X-2D]/C,S,RQC:'(H,3@V*3T^,S8U+&-H<B@Q
M.#<I/3XU-38L8VAR*#$X."D]/C@S-"QC:'(H,3@Y*3T^.#,T+&-H<B@Q.3`I
M/3XX,S0L8VAR*#$Y,2D]/C8Q,2QC:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW
M,C(L8VAR*#$Y-"D]/C<R,BQC:'(H,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L
M8VAR*#$Y-RD]/C<R,BP*("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW
M,C(L8VAR*#(P,"D]/C8V-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L
M8VAR*#(P,RD]/C8V-RQC:'(H,C`T*3T^,C<X+&-H<B@R,#4I/3XR-S@L8VAR
M*#(P-BD]/C(W."QC:'(H,C`W*3T^,C<X+&-H<B@R,#@I/3XW,C(L8VAR*#(P
M.2D]/C<R,BQC:'(H,C$P*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]
M/C<W."QC:'(H,C$S*3T^-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4X
M-"QC:'(H,C$V*3T^-S<X+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC
M:'(H,C$Y*3T^-S(R+`H@("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-C8W
M+&-H<B@R,C(I/3XV-C<L8VAR*#(R,RD]/C8Q,2QC:'(H,C(T*3T^-34V+&-H
M<B@R,C4I/3XU-38L8VAR*#(R-BD]/C4U-BQC:'(H,C(W*3T^-34V+&-H<B@R
M,C@I/3XU-38L8VAR*#(R.2D]/C4U-BQC:'(H,C,P*3T^.#@Y+&-H<B@R,S$I
M/3XU-38L8VAR*#(S,BD]/C4U-BQC:'(H,C,S*3T^-34V+&-H<B@R,S0I/3XU
M-38L8VAR*#(S-2D]/C4U-BQC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L
M8VAR*#(S."D]/C(W."QC:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XV,3$L8VAR
M*#(T,2D]/C8Q,2P*("`@(&-H<B@R-#(I/3XV,3$L8VAR*#(T,RD]/C8Q,2QC
M:'(H,C0T*3T^-C$Q+&-H<B@R-#4I/3XV,3$L8VAR*#(T-BD]/C8Q,2QC:'(H
M,C0W*3T^-3@T+&-H<B@R-#@I/3XV,3$L8VAR*#(T.2D]/C8Q,2QC:'(H,C4P
M*3T^-C$Q+&-H<B@R-3$I/3XV,3$L8VAR*#(U,BD]/C8Q,2QC:'(H,C4S*3T^
M-34V+&-H<B@R-30I/3XV,3$L8VAR*#(U-2D]/C4U-BD["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O9F]N
M=',O=&EM97,N<&AP````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#8Q-S<@,3`U,34T,S0Q,S8@,#(R-3<Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G92!&
M:6QE7U!$1@H@*B\*)&9O;G1?=VED=&AS6R=T:6UE<R==(#T@87)R87DH"B`@
M("!C:'(H,"D]/C(U,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H,RD]
M/C(U,"QC:'(H-"D]/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC:'(H
M-RD]/C(U,"QC:'(H."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR-3`L
M8VAR*#$Q*3T^,C4P+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR*#$T
M*3T^,C4P+&-H<B@Q-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^,C4P
M+&-H<B@Q."D]/C(U,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H<B@R
M,2D]/C(U,"P*("`@(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR*#(T
M*3T^,C4P+&-H<B@R-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^,C4P
M+&-H<B@R."D]/C(U,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H<B@S
M,2D]/C(U,"PG("<]/C(U,"PG(2<]/C,S,RPG(B<]/C0P."PG(R<]/C4P,"PG
M)"<]/C4P,"PG)2<]/C@S,RPG)B<]/C<W."PG7"<G/3XQ.#`L)R@G/3XS,S,L
M)RDG/3XS,S,L)RHG/3XU,#`L)RLG/3XU-C0L"B`@("`G+"<]/C(U,"PG+2<]
M/C,S,RPG+B<]/C(U,"PG+R<]/C(W."PG,"<]/C4P,"PG,2<]/C4P,"PG,B<]
M/C4P,"PG,R<]/C4P,"PG-"<]/C4P,"PG-2<]/C4P,"PG-B<]/C4P,"PG-R<]
M/C4P,"PG."<]/C4P,"PG.2<]/C4P,"PG.B<]/C(W."PG.R<]/C(W."PG/"<]
M/C4V-"PG/2<]/C4V-"PG/B<]/C4V-"PG/R<]/C0T-"PG0"<]/CDR,2PG02<]
M/C<R,BP*("`@("=")ST^-C8W+"=#)ST^-C8W+"=$)ST^-S(R+"=%)ST^-C$Q
M+"=&)ST^-34V+"=')ST^-S(R+"=()ST^-S(R+"=))ST^,S,S+"=*)ST^,S@Y
M+"=+)ST^-S(R+"=,)ST^-C$Q+"=-)ST^.#@Y+"=.)ST^-S(R+"=/)ST^-S(R
M+"=0)ST^-34V+"=1)ST^-S(R+"=2)ST^-C8W+"=3)ST^-34V+"=4)ST^-C$Q
M+"=5)ST^-S(R+"=6)ST^-S(R+"=7)ST^.30T+`H@("`@)U@G/3XW,C(L)UDG
M/3XW,C(L)UHG/3XV,3$L)ULG/3XS,S,L)UQ<)ST^,C<X+"==)ST^,S,S+"=>
M)ST^-#8Y+"=?)ST^-3`P+"=@)ST^,S,S+"=A)ST^-#0T+"=B)ST^-3`P+"=C
M)ST^-#0T+"=D)ST^-3`P+"=E)ST^-#0T+"=F)ST^,S,S+"=G)ST^-3`P+"=H
M)ST^-3`P+"=I)ST^,C<X+"=J)ST^,C<X+"=K)ST^-3`P+"=L)ST^,C<X+"=M
M)ST^-S<X+`H@("`@)VXG/3XU,#`L)V\G/3XU,#`L)W`G/3XU,#`L)W$G/3XU
M,#`L)W(G/3XS,S,L)W,G/3XS.#DL)W0G/3XR-S@L)W4G/3XU,#`L)W8G/3XU
M,#`L)W<G/3XW,C(L)W@G/3XU,#`L)WDG/3XU,#`L)WHG/3XT-#0L)WLG/3XT
M.#`L)WPG/3XR,#`L)WTG/3XT.#`L)WXG/3XU-#$L8VAR*#$R-RD]/C,U,"QC
M:'(H,3(X*3T^-3`P+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]/C,S,RQC:'(H
M,3,Q*3T^-3`P+`H@("`@8VAR*#$S,BD]/C0T-"QC:'(H,3,S*3T^,3`P,"QC
M:'(H,3,T*3T^-3`P+&-H<B@Q,S4I/3XU,#`L8VAR*#$S-BD]/C,S,RQC:'(H
M,3,W*3T^,3`P,"QC:'(H,3,X*3T^-34V+&-H<B@Q,SDI/3XS,S,L8VAR*#$T
M,"D]/C@X.2QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV,3$L8VAR*#$T,RD]
M/C,U,"QC:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XS,S,L8VAR*#$T-BD]/C,S
M,RQC:'(H,30W*3T^-#0T+&-H<B@Q-#@I/3XT-#0L8VAR*#$T.2D]/C,U,"QC
M:'(H,34P*3T^-3`P+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS,S,L8VAR
M*#$U,RD]/CDX,"P*("`@(&-H<B@Q-30I/3XS.#DL8VAR*#$U-2D]/C,S,RQC
M:'(H,34V*3T^-S(R+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]/C0T-"QC:'(H
M,34Y*3T^-S(R+&-H<B@Q-C`I/3XR-3`L8VAR*#$V,2D]/C,S,RQC:'(H,38R
M*3T^-3`P+&-H<B@Q-C,I/3XU,#`L8VAR*#$V-"D]/C4P,"QC:'(H,38U*3T^
M-3`P+&-H<B@Q-C8I/3XR,#`L8VAR*#$V-RD]/C4P,"QC:'(H,38X*3T^,S,S
M+&-H<B@Q-CDI/3XW-C`L8VAR*#$W,"D]/C(W-BQC:'(H,3<Q*3T^-3`P+&-H
M<B@Q-S(I/3XU-C0L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^-S8P+&-H<B@Q
M-S4I/3XS,S,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I/3XU-C0L8VAR
M*#$W."D]/C,P,"QC:'(H,3<Y*3T^,S`P+&-H<B@Q.#`I/3XS,S,L8VAR*#$X
M,2D]/C4P,"QC:'(H,3@R*3T^-#4S+&-H<B@Q.#,I/3XR-3`L8VAR*#$X-"D]
M/C,S,RQC:'(H,3@U*3T^,S`P+&-H<B@Q.#8I/3XS,3`L8VAR*#$X-RD]/C4P
M,"QC:'(H,3@X*3T^-S4P+&-H<B@Q.#DI/3XW-3`L8VAR*#$Y,"D]/C<U,"QC
M:'(H,3DQ*3T^-#0T+&-H<B@Q.3(I/3XW,C(L8VAR*#$Y,RD]/C<R,BQC:'(H
M,3DT*3T^-S(R+&-H<B@Q.34I/3XW,C(L8VAR*#$Y-BD]/C<R,BQC:'(H,3DW
M*3T^-S(R+`H@("`@8VAR*#$Y."D]/C@X.2QC:'(H,3DY*3T^-C8W+&-H<B@R
M,#`I/3XV,3$L8VAR*#(P,2D]/C8Q,2QC:'(H,C`R*3T^-C$Q+&-H<B@R,#,I
M/3XV,3$L8VAR*#(P-"D]/C,S,RQC:'(H,C`U*3T^,S,S+&-H<B@R,#8I/3XS
M,S,L8VAR*#(P-RD]/C,S,RQC:'(H,C`X*3T^-S(R+&-H<B@R,#DI/3XW,C(L
M8VAR*#(Q,"D]/C<R,BQC:'(H,C$Q*3T^-S(R+&-H<B@R,3(I/3XW,C(L8VAR
M*#(Q,RD]/C<R,BQC:'(H,C$T*3T^-S(R+&-H<B@R,34I/3XU-C0L8VAR*#(Q
M-BD]/C<R,BQC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L8VAR*#(Q.2D]
M/C<R,BP*("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C<R,BQC:'(H,C(R
M*3T^-34V+&-H<B@R,C,I/3XU,#`L8VAR*#(R-"D]/C0T-"QC:'(H,C(U*3T^
M-#0T+&-H<B@R,C8I/3XT-#0L8VAR*#(R-RD]/C0T-"QC:'(H,C(X*3T^-#0T
M+&-H<B@R,CDI/3XT-#0L8VAR*#(S,"D]/C8V-RQC:'(H,C,Q*3T^-#0T+&-H
M<B@R,S(I/3XT-#0L8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^-#0T+&-H<B@R
M,S4I/3XT-#0L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X+&-H<B@R,S@I
M/3XR-S@L8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H<B@R-#$I/3XU
M,#`L"B`@("!C:'(H,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L8VAR*#(T-"D]
M/C4P,"QC:'(H,C0U*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR*#(T-RD]/C4V
M-"QC:'(H,C0X*3T^-3`P+&-H<B@R-#DI/3XU,#`L8VAR*#(U,"D]/C4P,"QC
M:'(H,C4Q*3T^-3`P+&-H<B@R-3(I/3XU,#`L8VAR*#(U,RD]/C4P,"QC:'(H
M,C4T*3T^-3`P+&-H<B@R-34I/3XU,#`I.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&+V9O
M;G1S+WIA<&9D:6YG8F%T<RYP:'``````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`V,#,P(#$P-3$U-#,T,3,V(#`R-#$Q,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/W!H<`HO*BH*("H@0'!A8VMA9V4@
M1FEL95]01$8*("HO"B1F;VYT7W=I9'1H<ULG>F%P9F1I;F=B871S)UT@/2!A
M<G)A>2@*("`@(&-H<B@P*3T^,"QC:'(H,2D]/C`L8VAR*#(I/3XP+&-H<B@S
M*3T^,"QC:'(H-"D]/C`L8VAR*#4I/3XP+&-H<B@V*3T^,"QC:'(H-RD]/C`L
M8VAR*#@I/3XP+&-H<B@Y*3T^,"QC:'(H,3`I/3XP+&-H<B@Q,2D]/C`L8VAR
M*#$R*3T^,"QC:'(H,3,I/3XP+&-H<B@Q-"D]/C`L8VAR*#$U*3T^,"QC:'(H
M,38I/3XP+&-H<B@Q-RD]/C`L8VAR*#$X*3T^,"QC:'(H,3DI/3XP+&-H<B@R
M,"D]/C`L8VAR*#(Q*3T^,"P*("`@(&-H<B@R,BD]/C`L8VAR*#(S*3T^,"QC
M:'(H,C0I/3XP+&-H<B@R-2D]/C`L8VAR*#(V*3T^,"QC:'(H,C<I/3XP+&-H
M<B@R."D]/C`L8VAR*#(Y*3T^,"QC:'(H,S`I/3XP+&-H<B@S,2D]/C`L)R`G
M/3XR-S@L)R$G/3XY-S0L)R(G/3XY-C$L)R,G/3XY-S0L)R0G/3XY.#`L)R4G
M/3XW,3DL)R8G/3XW.#DL)UPG)ST^-SDP+"<H)ST^-SDQ+"<I)ST^-CDP+"<J
M)ST^.38P+"<K)ST^.3,Y+`H@("`@)RPG/3XU-#DL)RTG/3XX-34L)RXG/3XY
M,3$L)R\G/3XY,S,L)S`G/3XY,3$L)S$G/3XY-#4L)S(G/3XY-S0L)S,G/3XW
M-34L)S0G/3XX-#8L)S4G/3XW-C(L)S8G/3XW-C$L)S<G/3XU-S$L)S@G/3XV
M-S<L)SDG/3XW-C,L)SHG/3XW-C`L)SLG/3XW-3DL)SPG/3XW-30L)STG/3XT
M.30L)SXG/3XU-3(L)S\G/3XU,S<L)T`G/3XU-S<L)T$G/3XV.3(L"B`@("`G
M0B<]/C<X-BPG0R<]/C<X."PG1"<]/C<X."PG12<]/C<Y,"PG1B<]/C<Y,RPG
M1R<]/C<Y-"PG2"<]/C@Q-BPG22<]/C@R,RPG2B<]/C<X.2PG2R<]/C@T,2PG
M3"<]/C@R,RPG32<]/C@S,RPG3B<]/C@Q-BPG3R<]/C@S,2PG4"<]/CDR,RPG
M42<]/C<T-"PG4B<]/C<R,RPG4R<]/C<T.2PG5"<]/C<Y,"PG52<]/C<Y,BPG
M5B<]/C8Y-2PG5R<]/C<W-BP*("`@("=8)ST^-S8X+"=9)ST^-SDR+"=:)ST^
M-S4Y+"=;)ST^-S`W+"=<7"<]/C<P."PG72<]/C8X,BPG7B<]/C<P,2PG7R<]
M/C@R-BPG8"<]/C@Q-2PG82<]/C<X.2PG8B<]/C<X.2PG8R<]/C<P-RPG9"<]
M/C8X-RPG92<]/C8Y-BPG9B<]/C8X.2PG9R<]/C<X-BPG:"<]/C<X-RPG:2<]
M/C<Q,RPG:B<]/C<Y,2PG:R<]/C<X-2PG;"<]/C<Y,2PG;2<]/C@W,RP*("`@
M("=N)ST^-S8Q+"=O)ST^-S8R+"=P)ST^-S8R+"=Q)ST^-S4Y+"=R)ST^-S4Y
M+"=S)ST^.#DR+"=T)ST^.#DR+"=U)ST^-S@X+"=V)ST^-S@T+"=W)ST^-#,X
M+"=X)ST^,3,X+"=Y)ST^,C<W+"=Z)ST^-#$U+"=[)ST^,SDR+"=\)ST^,SDR
M+"=])ST^-C8X+"=^)ST^-C8X+&-H<B@Q,C<I/3XP+&-H<B@Q,C@I/3XS.3`L
M8VAR*#$R.2D]/C,Y,"QC:'(H,3,P*3T^,S$W+&-H<B@Q,S$I/3XS,3<L"B`@
M("!C:'(H,3,R*3T^,C<V+&-H<B@Q,S,I/3XR-S8L8VAR*#$S-"D]/C4P.2QC
M:'(H,3,U*3T^-3`Y+&-H<B@Q,S8I/3XT,3`L8VAR*#$S-RD]/C0Q,"QC:'(H
M,3,X*3T^,C,T+&-H<B@Q,SDI/3XR,S0L8VAR*#$T,"D]/C,S-"QC:'(H,30Q
M*3T^,S,T+&-H<B@Q-#(I/3XP+&-H<B@Q-#,I/3XP+&-H<B@Q-#0I/3XP+&-H
M<B@Q-#4I/3XP+&-H<B@Q-#8I/3XP+&-H<B@Q-#<I/3XP+&-H<B@Q-#@I/3XP
M+&-H<B@Q-#DI/3XP+&-H<B@Q-3`I/3XP+&-H<B@Q-3$I/3XP+&-H<B@Q-3(I
M/3XP+&-H<B@Q-3,I/3XP+`H@("`@8VAR*#$U-"D]/C`L8VAR*#$U-2D]/C`L
M8VAR*#$U-BD]/C`L8VAR*#$U-RD]/C`L8VAR*#$U."D]/C`L8VAR*#$U.2D]
M/C`L8VAR*#$V,"D]/C`L8VAR*#$V,2D]/C<S,BQC:'(H,38R*3T^-30T+&-H
M<B@Q-C,I/3XU-#0L8VAR*#$V-"D]/CDQ,"QC:'(H,38U*3T^-C8W+&-H<B@Q
M-C8I/3XW-C`L8VAR*#$V-RD]/C<V,"QC:'(H,38X*3T^-S<V+&-H<B@Q-CDI
M/3XU.34L8VAR*#$W,"D]/C8Y-"QC:'(H,3<Q*3T^-C(V+&-H<B@Q-S(I/3XW
M.#@L8VAR*#$W,RD]/C<X."QC:'(H,3<T*3T^-S@X+&-H<B@Q-S4I/3XW.#@L
M"B`@("!C:'(H,3<V*3T^-S@X+&-H<B@Q-S<I/3XW.#@L8VAR*#$W."D]/C<X
M."QC:'(H,3<Y*3T^-S@X+&-H<B@Q.#`I/3XW.#@L8VAR*#$X,2D]/C<X."QC
M:'(H,3@R*3T^-S@X+&-H<B@Q.#,I/3XW.#@L8VAR*#$X-"D]/C<X."QC:'(H
M,3@U*3T^-S@X+&-H<B@Q.#8I/3XW.#@L8VAR*#$X-RD]/C<X."QC:'(H,3@X
M*3T^-S@X+&-H<B@Q.#DI/3XW.#@L8VAR*#$Y,"D]/C<X."QC:'(H,3DQ*3T^
M-S@X+&-H<B@Q.3(I/3XW.#@L8VAR*#$Y,RD]/C<X."QC:'(H,3DT*3T^-S@X
M+&-H<B@Q.34I/3XW.#@L8VAR*#$Y-BD]/C<X."QC:'(H,3DW*3T^-S@X+`H@
M("`@8VAR*#$Y."D]/C<X."QC:'(H,3DY*3T^-S@X+&-H<B@R,#`I/3XW.#@L
M8VAR*#(P,2D]/C<X."QC:'(H,C`R*3T^-S@X+&-H<B@R,#,I/3XW.#@L8VAR
M*#(P-"D]/C<X."QC:'(H,C`U*3T^-S@X+&-H<B@R,#8I/3XW.#@L8VAR*#(P
M-RD]/C<X."QC:'(H,C`X*3T^-S@X+&-H<B@R,#DI/3XW.#@L8VAR*#(Q,"D]
M/C<X."QC:'(H,C$Q*3T^-S@X+&-H<B@R,3(I/3XX.30L8VAR*#(Q,RD]/C@S
M."QC:'(H,C$T*3T^,3`Q-BQC:'(H,C$U*3T^-#4X+&-H<B@R,38I/3XW-#@L
M8VAR*#(Q-RD]/CDR-"QC:'(H,C$X*3T^-S0X+&-H<B@R,3DI/3XY,3@L"B`@
M("!C:'(H,C(P*3T^.3(W+&-H<B@R,C$I/3XY,C@L8VAR*#(R,BD]/CDR."QC
M:'(H,C(S*3T^.#,T+&-H<B@R,C0I/3XX-S,L8VAR*#(R-2D]/C@R."QC:'(H
M,C(V*3T^.3(T+&-H<B@R,C<I/3XY,C0L8VAR*#(R."D]/CDQ-RQC:'(H,C(Y
M*3T^.3,P+&-H<B@R,S`I/3XY,S$L8VAR*#(S,2D]/C0V,RQC:'(H,C,R*3T^
M.#@S+&-H<B@R,S,I/3XX,S8L8VAR*#(S-"D]/C@S-BQC:'(H,C,U*3T^.#8W
M+&-H<B@R,S8I/3XX-C<L8VAR*#(S-RD]/C8Y-BQC:'(H,C,X*3T^-CDV+&-H
M<B@R,SDI/3XX-S0L8VAR*#(T,"D]/C`L8VAR*#(T,2D]/C@W-"P*("`@(&-H
M<B@R-#(I/3XW-C`L8VAR*#(T,RD]/CDT-BQC:'(H,C0T*3T^-S<Q+&-H<B@R
M-#4I/3XX-C4L8VAR*#(T-BD]/C<W,2QC:'(H,C0W*3T^.#@X+&-H<B@R-#@I
M/3XY-C<L8VAR*#(T.2D]/C@X."QC:'(H,C4P*3T^.#,Q+&-H<B@R-3$I/3XX
M-S,L8VAR*#(U,BD]/CDR-RQC:'(H,C4S*3T^.3<P+&-H<B@R-30I/3XY,3@L
M8VAR*#(U-2D]/C`I.PH`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$1B]F
M;VYT<R]T:6UE<V(N<&AP````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-C(P-2`Q,#4Q-30S-#$S-B`P,C(W,C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*+RHJ"B`J($!P86-K86=E
M($9I;&5?4$1&"B`J+PHD9F]N=%]W:61T:'-;)W1I;65S0B==(#T@87)R87DH
M"B`@("!C:'(H,"D]/C(U,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U,"QC:'(H
M,RD]/C(U,"QC:'(H-"D]/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]/C(U,"QC
M:'(H-RD]/C(U,"QC:'(H."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H,3`I/3XR
M-3`L8VAR*#$Q*3T^,C4P+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR-3`L8VAR
M*#$T*3T^,C4P+&-H<B@Q-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR*#$W*3T^
M,C4P+&-H<B@Q."D]/C(U,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^,C4P+&-H
M<B@R,2D]/C(U,"P*("`@(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR-3`L8VAR
M*#(T*3T^,C4P+&-H<B@R-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR*#(W*3T^
M,C4P+&-H<B@R."D]/C(U,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^,C4P+&-H
M<B@S,2D]/C(U,"PG("<]/C(U,"PG(2<]/C,S,RPG(B<]/C4U-2PG(R<]/C4P
M,"PG)"<]/C4P,"PG)2<]/C$P,#`L)R8G/3XX,S,L)UPG)ST^,C<X+"<H)ST^
M,S,S+"<I)ST^,S,S+"<J)ST^-3`P+"<K)ST^-3<P+`H@("`@)RPG/3XR-3`L
M)RTG/3XS,S,L)RXG/3XR-3`L)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L
M)S(G/3XU,#`L)S,G/3XU,#`L)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L
M)S<G/3XU,#`L)S@G/3XU,#`L)SDG/3XU,#`L)SHG/3XS,S,L)SLG/3XS,S,L
M)SPG/3XU-S`L)STG/3XU-S`L)SXG/3XU-S`L)S\G/3XU,#`L)T`G/3XY,S`L
M)T$G/3XW,C(L"B`@("`G0B<]/C8V-RPG0R<]/C<R,BPG1"<]/C<R,BPG12<]
M/C8V-RPG1B<]/C8Q,2PG1R<]/C<W."PG2"<]/C<W."PG22<]/C,X.2PG2B<]
M/C4P,"PG2R<]/C<W."PG3"<]/C8V-RPG32<]/CDT-"PG3B<]/C<R,BPG3R<]
M/C<W."PG4"<]/C8Q,2PG42<]/C<W."PG4B<]/C<R,BPG4R<]/C4U-BPG5"<]
M/C8V-RPG52<]/C<R,BPG5B<]/C<R,BPG5R<]/C$P,#`L"B`@("`G6"<]/C<R
M,BPG62<]/C<R,BPG6B<]/C8V-RPG6R<]/C,S,RPG7%PG/3XR-S@L)UTG/3XS
M,S,L)UXG/3XU.#$L)U\G/3XU,#`L)V`G/3XS,S,L)V$G/3XU,#`L)V(G/3XU
M-38L)V,G/3XT-#0L)V0G/3XU-38L)V4G/3XT-#0L)V8G/3XS,S,L)V<G/3XU
M,#`L)V@G/3XU-38L)VDG/3XR-S@L)VHG/3XS,S,L)VLG/3XU-38L)VPG/3XR
M-S@L)VTG/3XX,S,L"B`@("`G;B<]/C4U-BPG;R<]/C4P,"PG<"<]/C4U-BPG
M<2<]/C4U-BPG<B<]/C0T-"PG<R<]/C,X.2PG="<]/C,S,RPG=2<]/C4U-BPG
M=B<]/C4P,"PG=R<]/C<R,BPG>"<]/C4P,"PG>2<]/C4P,"PG>B<]/C0T-"PG
M>R<]/C,Y-"PG?"<]/C(R,"PG?2<]/C,Y-"PG?B<]/C4R,"QC:'(H,3(W*3T^
M,S4P+&-H<B@Q,C@I/3XU,#`L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^,S,S
M+&-H<B@Q,S$I/3XU,#`L"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I/3XQ
M,#`P+&-H<B@Q,S0I/3XU,#`L8VAR*#$S-2D]/C4P,"QC:'(H,3,V*3T^,S,S
M+&-H<B@Q,S<I/3XQ,#`P+&-H<B@Q,S@I/3XU-38L8VAR*#$S.2D]/C,S,RQC
M:'(H,30P*3T^,3`P,"QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV-C<L8VAR
M*#$T,RD]/C,U,"QC:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XS,S,L8VAR*#$T
M-BD]/C,S,RQC:'(H,30W*3T^-3`P+&-H<B@Q-#@I/3XU,#`L8VAR*#$T.2D]
M/C,U,"QC:'(H,34P*3T^-3`P+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q-3(I/3XS
M,S,L8VAR*#$U,RD]/C$P,#`L"B`@("!C:'(H,34T*3T^,S@Y+&-H<B@Q-34I
M/3XS,S,L8VAR*#$U-BD]/C<R,BQC:'(H,34W*3T^,S4P+&-H<B@Q-3@I/3XT
M-#0L8VAR*#$U.2D]/C<R,BQC:'(H,38P*3T^,C4P+&-H<B@Q-C$I/3XS,S,L
M8VAR*#$V,BD]/C4P,"QC:'(H,38S*3T^-3`P+&-H<B@Q-C0I/3XU,#`L8VAR
M*#$V-2D]/C4P,"QC:'(H,38V*3T^,C(P+&-H<B@Q-C<I/3XU,#`L8VAR*#$V
M."D]/C,S,RQC:'(H,38Y*3T^-S0W+&-H<B@Q-S`I/3XS,#`L8VAR*#$W,2D]
M/C4P,"QC:'(H,3<R*3T^-3<P+&-H<B@Q-S,I/3XS,S,L8VAR*#$W-"D]/C<T
M-RQC:'(H,3<U*3T^,S,S+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^
M-3<P+&-H<B@Q-S@I/3XS,#`L8VAR*#$W.2D]/C,P,"QC:'(H,3@P*3T^,S,S
M+&-H<B@Q.#$I/3XU-38L8VAR*#$X,BD]/C4T,"QC:'(H,3@S*3T^,C4P+&-H
M<B@Q.#0I/3XS,S,L8VAR*#$X-2D]/C,P,"QC:'(H,3@V*3T^,S,P+&-H<B@Q
M.#<I/3XU,#`L8VAR*#$X."D]/C<U,"QC:'(H,3@Y*3T^-S4P+&-H<B@Q.3`I
M/3XW-3`L8VAR*#$Y,2D]/C4P,"QC:'(H,3DR*3T^-S(R+&-H<B@Q.3,I/3XW
M,C(L8VAR*#$Y-"D]/C<R,BQC:'(H,3DU*3T^-S(R+&-H<B@Q.38I/3XW,C(L
M8VAR*#$Y-RD]/C<R,BP*("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q.3DI/3XW
M,C(L8VAR*#(P,"D]/C8V-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I/3XV-C<L
M8VAR*#(P,RD]/C8V-RQC:'(H,C`T*3T^,S@Y+&-H<B@R,#4I/3XS.#DL8VAR
M*#(P-BD]/C,X.2QC:'(H,C`W*3T^,S@Y+&-H<B@R,#@I/3XW,C(L8VAR*#(P
M.2D]/C<R,BQC:'(H,C$P*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR*#(Q,BD]
M/C<W."QC:'(H,C$S*3T^-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q-2D]/C4W
M,"QC:'(H,C$V*3T^-S<X+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC
M:'(H,C$Y*3T^-S(R+`H@("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-S(R
M+&-H<B@R,C(I/3XV,3$L8VAR*#(R,RD]/C4U-BQC:'(H,C(T*3T^-3`P+&-H
M<B@R,C4I/3XU,#`L8VAR*#(R-BD]/C4P,"QC:'(H,C(W*3T^-3`P+&-H<B@R
M,C@I/3XU,#`L8VAR*#(R.2D]/C4P,"QC:'(H,C,P*3T^-S(R+&-H<B@R,S$I
M/3XT-#0L8VAR*#(S,BD]/C0T-"QC:'(H,C,S*3T^-#0T+&-H<B@R,S0I/3XT
M-#0L8VAR*#(S-2D]/C0T-"QC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L
M8VAR*#(S."D]/C(W."QC:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XU,#`L8VAR
M*#(T,2D]/C4U-BP*("`@(&-H<B@R-#(I/3XU,#`L8VAR*#(T,RD]/C4P,"QC
M:'(H,C0T*3T^-3`P+&-H<B@R-#4I/3XU,#`L8VAR*#(T-BD]/C4P,"QC:'(H
M,C0W*3T^-3<P+&-H<B@R-#@I/3XU,#`L8VAR*#(T.2D]/C4U-BQC:'(H,C4P
M*3T^-34V+&-H<B@R-3$I/3XU-38L8VAR*#(U,BD]/C4U-BQC:'(H,C4S*3T^
M-3`P+&-H<B@R-30I/3XU-38L8VAR*#(U-2D]/C4P,"D["@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]01$8O
M9F]N=',O=&EM97-I+G!H<```````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#8Q-S8@,3`U,34T,S0Q,S8@,#(R-S0Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C:V%G
M92!&:6QE7U!$1@H@*B\*)&9O;G1?=VED=&AS6R=T:6UE<TDG72`](&%R<F%Y
M*`H@("`@8VAR*#`I/3XR-3`L8VAR*#$I/3XR-3`L8VAR*#(I/3XR-3`L8VAR
M*#,I/3XR-3`L8VAR*#0I/3XR-3`L8VAR*#4I/3XR-3`L8VAR*#8I/3XR-3`L
M8VAR*#<I/3XR-3`L8VAR*#@I/3XR-3`L8VAR*#DI/3XR-3`L8VAR*#$P*3T^
M,C4P+&-H<B@Q,2D]/C(U,"QC:'(H,3(I/3XR-3`L8VAR*#$S*3T^,C4P+&-H
M<B@Q-"D]/C(U,"QC:'(H,34I/3XR-3`L8VAR*#$V*3T^,C4P+&-H<B@Q-RD]
M/C(U,"QC:'(H,3@I/3XR-3`L8VAR*#$Y*3T^,C4P+&-H<B@R,"D]/C(U,"QC
M:'(H,C$I/3XR-3`L"B`@("!C:'(H,C(I/3XR-3`L8VAR*#(S*3T^,C4P+&-H
M<B@R-"D]/C(U,"QC:'(H,C4I/3XR-3`L8VAR*#(V*3T^,C4P+&-H<B@R-RD]
M/C(U,"QC:'(H,C@I/3XR-3`L8VAR*#(Y*3T^,C4P+&-H<B@S,"D]/C(U,"QC
M:'(H,S$I/3XR-3`L)R`G/3XR-3`L)R$G/3XS,S,L)R(G/3XT,C`L)R,G/3XU
M,#`L)R0G/3XU,#`L)R4G/3XX,S,L)R8G/3XW-S@L)UPG)ST^,C$T+"<H)ST^
M,S,S+"<I)ST^,S,S+"<J)ST^-3`P+"<K)ST^-C<U+`H@("`@)RPG/3XR-3`L
M)RTG/3XS,S,L)RXG/3XR-3`L)R\G/3XR-S@L)S`G/3XU,#`L)S$G/3XU,#`L
M)S(G/3XU,#`L)S,G/3XU,#`L)S0G/3XU,#`L)S4G/3XU,#`L)S8G/3XU,#`L
M)S<G/3XU,#`L)S@G/3XU,#`L)SDG/3XU,#`L)SHG/3XS,S,L)SLG/3XS,S,L
M)SPG/3XV-S4L)STG/3XV-S4L)SXG/3XV-S4L)S\G/3XU,#`L)T`G/3XY,C`L
M)T$G/3XV,3$L"B`@("`G0B<]/C8Q,2PG0R<]/C8V-RPG1"<]/C<R,BPG12<]
M/C8Q,2PG1B<]/C8Q,2PG1R<]/C<R,BPG2"<]/C<R,BPG22<]/C,S,RPG2B<]
M/C0T-"PG2R<]/C8V-RPG3"<]/C4U-BPG32<]/C@S,RPG3B<]/C8V-RPG3R<]
M/C<R,BPG4"<]/C8Q,2PG42<]/C<R,BPG4B<]/C8Q,2PG4R<]/C4P,"PG5"<]
M/C4U-BPG52<]/C<R,BPG5B<]/C8Q,2PG5R<]/C@S,RP*("`@("=8)ST^-C$Q
M+"=9)ST^-34V+"=:)ST^-34V+"=;)ST^,S@Y+"=<7"<]/C(W."PG72<]/C,X
M.2PG7B<]/C0R,BPG7R<]/C4P,"PG8"<]/C,S,RPG82<]/C4P,"PG8B<]/C4P
M,"PG8R<]/C0T-"PG9"<]/C4P,"PG92<]/C0T-"PG9B<]/C(W."PG9R<]/C4P
M,"PG:"<]/C4P,"PG:2<]/C(W."PG:B<]/C(W."PG:R<]/C0T-"PG;"<]/C(W
M."PG;2<]/C<R,BP*("`@("=N)ST^-3`P+"=O)ST^-3`P+"=P)ST^-3`P+"=Q
M)ST^-3`P+"=R)ST^,S@Y+"=S)ST^,S@Y+"=T)ST^,C<X+"=U)ST^-3`P+"=V
M)ST^-#0T+"=W)ST^-C8W+"=X)ST^-#0T+"=Y)ST^-#0T+"=Z)ST^,S@Y+"=[
M)ST^-#`P+"=\)ST^,C<U+"=])ST^-#`P+"=^)ST^-30Q+&-H<B@Q,C<I/3XS
M-3`L8VAR*#$R."D]/C4P,"QC:'(H,3(Y*3T^,S4P+&-H<B@Q,S`I/3XS,S,L
M8VAR*#$S,2D]/C4P,"P*("`@(&-H<B@Q,S(I/3XU-38L8VAR*#$S,RD]/C@X
M.2QC:'(H,3,T*3T^-3`P+&-H<B@Q,S4I/3XU,#`L8VAR*#$S-BD]/C,S,RQC
M:'(H,3,W*3T^,3`P,"QC:'(H,3,X*3T^-3`P+&-H<B@Q,SDI/3XS,S,L8VAR
M*#$T,"D]/CDT-"QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XU-38L8VAR*#$T
M,RD]/C,U,"QC:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XS,S,L8VAR*#$T-BD]
M/C,S,RQC:'(H,30W*3T^-34V+&-H<B@Q-#@I/3XU-38L8VAR*#$T.2D]/C,U
M,"QC:'(H,34P*3T^-3`P+&-H<B@Q-3$I/3XX.#DL8VAR*#$U,BD]/C,S,RQC
M:'(H,34S*3T^.3@P+`H@("`@8VAR*#$U-"D]/C,X.2QC:'(H,34U*3T^,S,S
M+&-H<B@Q-38I/3XV-C<L8VAR*#$U-RD]/C,U,"QC:'(H,34X*3T^,S@Y+&-H
M<B@Q-3DI/3XU-38L8VAR*#$V,"D]/C(U,"QC:'(H,38Q*3T^,S@Y+&-H<B@Q
M-C(I/3XU,#`L8VAR*#$V,RD]/C4P,"QC:'(H,38T*3T^-3`P+&-H<B@Q-C4I
M/3XU,#`L8VAR*#$V-BD]/C(W-2QC:'(H,38W*3T^-3`P+&-H<B@Q-C@I/3XS
M,S,L8VAR*#$V.2D]/C<V,"QC:'(H,3<P*3T^,C<V+&-H<B@Q-S$I/3XU,#`L
M8VAR*#$W,BD]/C8W-2QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I/3XW-C`L8VAR
M*#$W-2D]/C,S,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W-RD]/C8W-2QC
M:'(H,3<X*3T^,S`P+&-H<B@Q-SDI/3XS,#`L8VAR*#$X,"D]/C,S,RQC:'(H
M,3@Q*3T^-3`P+&-H<B@Q.#(I/3XU,C,L8VAR*#$X,RD]/C(U,"QC:'(H,3@T
M*3T^,S,S+&-H<B@Q.#4I/3XS,#`L8VAR*#$X-BD]/C,Q,"QC:'(H,3@W*3T^
M-3`P+&-H<B@Q.#@I/3XW-3`L8VAR*#$X.2D]/C<U,"QC:'(H,3DP*3T^-S4P
M+&-H<B@Q.3$I/3XU,#`L8VAR*#$Y,BD]/C8Q,2QC:'(H,3DS*3T^-C$Q+&-H
M<B@Q.30I/3XV,3$L8VAR*#$Y-2D]/C8Q,2QC:'(H,3DV*3T^-C$Q+&-H<B@Q
M.3<I/3XV,3$L"B`@("!C:'(H,3DX*3T^.#@Y+&-H<B@Q.3DI/3XV-C<L8VAR
M*#(P,"D]/C8Q,2QC:'(H,C`Q*3T^-C$Q+&-H<B@R,#(I/3XV,3$L8VAR*#(P
M,RD]/C8Q,2QC:'(H,C`T*3T^,S,S+&-H<B@R,#4I/3XS,S,L8VAR*#(P-BD]
M/C,S,RQC:'(H,C`W*3T^,S,S+&-H<B@R,#@I/3XW,C(L8VAR*#(P.2D]/C8V
M-RQC:'(H,C$P*3T^-S(R+&-H<B@R,3$I/3XW,C(L8VAR*#(Q,BD]/C<R,BQC
M:'(H,C$S*3T^-S(R+&-H<B@R,30I/3XW,C(L8VAR*#(Q-2D]/C8W-2QC:'(H
M,C$V*3T^-S(R+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]/C<R,BQC:'(H,C$Y
M*3T^-S(R+`H@("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q*3T^-34V+&-H<B@R
M,C(I/3XV,3$L8VAR*#(R,RD]/C4P,"QC:'(H,C(T*3T^-3`P+&-H<B@R,C4I
M/3XU,#`L8VAR*#(R-BD]/C4P,"QC:'(H,C(W*3T^-3`P+&-H<B@R,C@I/3XU
M,#`L8VAR*#(R.2D]/C4P,"QC:'(H,C,P*3T^-C8W+&-H<B@R,S$I/3XT-#0L
M8VAR*#(S,BD]/C0T-"QC:'(H,C,S*3T^-#0T+&-H<B@R,S0I/3XT-#0L8VAR
M*#(S-2D]/C0T-"QC:'(H,C,V*3T^,C<X+&-H<B@R,S<I/3XR-S@L8VAR*#(S
M."D]/C(W."QC:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XU,#`L8VAR*#(T,2D]
M/C4P,"P*("`@(&-H<B@R-#(I/3XU,#`L8VAR*#(T,RD]/C4P,"QC:'(H,C0T
M*3T^-3`P+&-H<B@R-#4I/3XU,#`L8VAR*#(T-BD]/C4P,"QC:'(H,C0W*3T^
M-C<U+&-H<B@R-#@I/3XU,#`L8VAR*#(T.2D]/C4P,"QC:'(H,C4P*3T^-3`P
M+&-H<B@R-3$I/3XU,#`L8VAR*#(U,BD]/C4P,"QC:'(H,C4S*3T^-#0T+&-H
M<B@R-30I/3XU,#`L8VAR*#(U-2D]/C0T-"D["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O4$1&
M+V9O;G1S+VAE;'9E=&EC86(N<&AP````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`V,C`W(#$P-3$U-#,T,3,V(#`R,S4U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@0'!A8VMA
M9V4@1FEL95]01$8*("HO"B1F;VYT7W=I9'1H<ULG:&5L=F5T:6-A0B==(#T@
M87)R87DH"B`@("!C:'(H,"D]/C(W."QC:'(H,2D]/C(W."QC:'(H,BD]/C(W
M."QC:'(H,RD]/C(W."QC:'(H-"D]/C(W."QC:'(H-2D]/C(W."QC:'(H-BD]
M/C(W."QC:'(H-RD]/C(W."QC:'(H."D]/C(W."QC:'(H.2D]/C(W."QC:'(H
M,3`I/3XR-S@L8VAR*#$Q*3T^,C<X+&-H<B@Q,BD]/C(W."QC:'(H,3,I/3XR
M-S@L8VAR*#$T*3T^,C<X+&-H<B@Q-2D]/C(W."QC:'(H,38I/3XR-S@L8VAR
M*#$W*3T^,C<X+&-H<B@Q."D]/C(W."QC:'(H,3DI/3XR-S@L8VAR*#(P*3T^
M,C<X+&-H<B@R,2D]/C(W."P*("`@(&-H<B@R,BD]/C(W."QC:'(H,C,I/3XR
M-S@L8VAR*#(T*3T^,C<X+&-H<B@R-2D]/C(W."QC:'(H,C8I/3XR-S@L8VAR
M*#(W*3T^,C<X+&-H<B@R."D]/C(W."QC:'(H,CDI/3XR-S@L8VAR*#,P*3T^
M,C<X+&-H<B@S,2D]/C(W."PG("<]/C(W."PG(2<]/C,S,RPG(B<]/C0W-"PG
M(R<]/C4U-BPG)"<]/C4U-BPG)2<]/C@X.2PG)B<]/C<R,BPG7"<G/3XR,S@L
M)R@G/3XS,S,L)RDG/3XS,S,L)RHG/3XS.#DL)RLG/3XU.#0L"B`@("`G+"<]
M/C(W."PG+2<]/C,S,RPG+B<]/C(W."PG+R<]/C(W."PG,"<]/C4U-BPG,2<]
M/C4U-BPG,B<]/C4U-BPG,R<]/C4U-BPG-"<]/C4U-BPG-2<]/C4U-BPG-B<]
M/C4U-BPG-R<]/C4U-BPG."<]/C4U-BPG.2<]/C4U-BPG.B<]/C,S,RPG.R<]
M/C,S,RPG/"<]/C4X-"PG/2<]/C4X-"PG/B<]/C4X-"PG/R<]/C8Q,2PG0"<]
M/CDW-2PG02<]/C<R,BP*("`@("=")ST^-S(R+"=#)ST^-S(R+"=$)ST^-S(R
M+"=%)ST^-C8W+"=&)ST^-C$Q+"=')ST^-S<X+"=()ST^-S(R+"=))ST^,C<X
M+"=*)ST^-34V+"=+)ST^-S(R+"=,)ST^-C$Q+"=-)ST^.#,S+"=.)ST^-S(R
M+"=/)ST^-S<X+"=0)ST^-C8W+"=1)ST^-S<X+"=2)ST^-S(R+"=3)ST^-C8W
M+"=4)ST^-C$Q+"=5)ST^-S(R+"=6)ST^-C8W+"=7)ST^.30T+`H@("`@)U@G
M/3XV-C<L)UDG/3XV-C<L)UHG/3XV,3$L)ULG/3XS,S,L)UQ<)ST^,C<X+"==
M)ST^,S,S+"=>)ST^-3@T+"=?)ST^-34V+"=@)ST^,S,S+"=A)ST^-34V+"=B
M)ST^-C$Q+"=C)ST^-34V+"=D)ST^-C$Q+"=E)ST^-34V+"=F)ST^,S,S+"=G
M)ST^-C$Q+"=H)ST^-C$Q+"=I)ST^,C<X+"=J)ST^,C<X+"=K)ST^-34V+"=L
M)ST^,C<X+"=M)ST^.#@Y+`H@("`@)VXG/3XV,3$L)V\G/3XV,3$L)W`G/3XV
M,3$L)W$G/3XV,3$L)W(G/3XS.#DL)W,G/3XU-38L)W0G/3XS,S,L)W4G/3XV
M,3$L)W8G/3XU-38L)W<G/3XW-S@L)W@G/3XU-38L)WDG/3XU-38L)WHG/3XU
M,#`L)WLG/3XS.#DL)WPG/3XR.#`L)WTG/3XS.#DL)WXG/3XU.#0L8VAR*#$R
M-RD]/C,U,"QC:'(H,3(X*3T^-34V+&-H<B@Q,CDI/3XS-3`L8VAR*#$S,"D]
M/C(W."QC:'(H,3,Q*3T^-34V+`H@("`@8VAR*#$S,BD]/C4P,"QC:'(H,3,S
M*3T^,3`P,"QC:'(H,3,T*3T^-34V+&-H<B@Q,S4I/3XU-38L8VAR*#$S-BD]
M/C,S,RQC:'(H,3,W*3T^,3`P,"QC:'(H,3,X*3T^-C8W+&-H<B@Q,SDI/3XS
M,S,L8VAR*#$T,"D]/C$P,#`L8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^-C$Q
M+&-H<B@Q-#,I/3XS-3`L8VAR*#$T-"D]/C,U,"QC:'(H,30U*3T^,C<X+&-H
M<B@Q-#8I/3XR-S@L8VAR*#$T-RD]/C4P,"QC:'(H,30X*3T^-3`P+&-H<B@Q
M-#DI/3XS-3`L8VAR*#$U,"D]/C4U-BQC:'(H,34Q*3T^,3`P,"QC:'(H,34R
M*3T^,S,S+&-H<B@Q-3,I/3XQ,#`P+`H@("`@8VAR*#$U-"D]/C4U-BQC:'(H
M,34U*3T^,S,S+&-H<B@Q-38I/3XY-#0L8VAR*#$U-RD]/C,U,"QC:'(H,34X
M*3T^-3`P+&-H<B@Q-3DI/3XV-C<L8VAR*#$V,"D]/C(W."QC:'(H,38Q*3T^
M,S,S+&-H<B@Q-C(I/3XU-38L8VAR*#$V,RD]/C4U-BQC:'(H,38T*3T^-34V
M+&-H<B@Q-C4I/3XU-38L8VAR*#$V-BD]/C(X,"QC:'(H,38W*3T^-34V+&-H
M<B@Q-C@I/3XS,S,L8VAR*#$V.2D]/C<S-RQC:'(H,3<P*3T^,S<P+&-H<B@Q
M-S$I/3XU-38L8VAR*#$W,BD]/C4X-"QC:'(H,3<S*3T^,S,S+&-H<B@Q-S0I
M/3XW,S<L8VAR*#$W-2D]/C,S,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR*#$W
M-RD]/C4X-"QC:'(H,3<X*3T^,S,S+&-H<B@Q-SDI/3XS,S,L8VAR*#$X,"D]
M/C,S,RQC:'(H,3@Q*3T^-C$Q+&-H<B@Q.#(I/3XU-38L8VAR*#$X,RD]/C(W
M."QC:'(H,3@T*3T^,S,S+&-H<B@Q.#4I/3XS,S,L8VAR*#$X-BD]/C,V-2QC
M:'(H,3@W*3T^-34V+&-H<B@Q.#@I/3XX,S0L8VAR*#$X.2D]/C@S-"QC:'(H
M,3DP*3T^.#,T+&-H<B@Q.3$I/3XV,3$L8VAR*#$Y,BD]/C<R,BQC:'(H,3DS
M*3T^-S(R+&-H<B@Q.30I/3XW,C(L8VAR*#$Y-2D]/C<R,BQC:'(H,3DV*3T^
M-S(R+&-H<B@Q.3<I/3XW,C(L"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H,3DY
M*3T^-S(R+&-H<B@R,#`I/3XV-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^
M-C8W+&-H<B@R,#,I/3XV-C<L8VAR*#(P-"D]/C(W."QC:'(H,C`U*3T^,C<X
M+&-H<B@R,#8I/3XR-S@L8VAR*#(P-RD]/C(W."QC:'(H,C`X*3T^-S(R+&-H
M<B@R,#DI/3XW,C(L8VAR*#(Q,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H<B@R
M,3(I/3XW-S@L8VAR*#(Q,RD]/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R,34I
M/3XU.#0L8VAR*#(Q-BD]/C<W."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW
M,C(L8VAR*#(Q.2D]/C<R,BP*("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]
M/C8V-RQC:'(H,C(R*3T^-C8W+&-H<B@R,C,I/3XV,3$L8VAR*#(R-"D]/C4U
M-BQC:'(H,C(U*3T^-34V+&-H<B@R,C8I/3XU-38L8VAR*#(R-RD]/C4U-BQC
M:'(H,C(X*3T^-34V+&-H<B@R,CDI/3XU-38L8VAR*#(S,"D]/C@X.2QC:'(H
M,C,Q*3T^-34V+&-H<B@R,S(I/3XU-38L8VAR*#(S,RD]/C4U-BQC:'(H,C,T
M*3T^-34V+&-H<B@R,S4I/3XU-38L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^
M,C<X+&-H<B@R,S@I/3XR-S@L8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-C$Q
M+&-H<B@R-#$I/3XV,3$L"B`@("!C:'(H,C0R*3T^-C$Q+&-H<B@R-#,I/3XV
M,3$L8VAR*#(T-"D]/C8Q,2QC:'(H,C0U*3T^-C$Q+&-H<B@R-#8I/3XV,3$L
M8VAR*#(T-RD]/C4X-"QC:'(H,C0X*3T^-C$Q+&-H<B@R-#DI/3XV,3$L8VAR
M*#(U,"D]/C8Q,2QC:'(H,C4Q*3T^-C$Q+&-H<B@R-3(I/3XV,3$L8VAR*#(U
M,RD]/C4U-BQC:'(H,C4T*3T^-C$Q+&-H<B@R-34I/3XU-38I.PH`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE+U!$
M1B]F;VYT<R]H96QV971I8V%I+G!H<```````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-C(Q,"`Q,#4Q-30S-#$S-B`P,C,U-3$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J($!P86-K
M86=E($9I;&5?4$1&"B`J+PHD9F]N=%]W:61T:'-;)VAE;'9E=&EC84DG72`]
M(&%R<F%Y*`H@("`@8VAR*#`I/3XR-S@L8VAR*#$I/3XR-S@L8VAR*#(I/3XR
M-S@L8VAR*#,I/3XR-S@L8VAR*#0I/3XR-S@L8VAR*#4I/3XR-S@L8VAR*#8I
M/3XR-S@L8VAR*#<I/3XR-S@L8VAR*#@I/3XR-S@L8VAR*#DI/3XR-S@L8VAR
M*#$P*3T^,C<X+&-H<B@Q,2D]/C(W."QC:'(H,3(I/3XR-S@L8VAR*#$S*3T^
M,C<X+&-H<B@Q-"D]/C(W."QC:'(H,34I/3XR-S@L8VAR*#$V*3T^,C<X+&-H
M<B@Q-RD]/C(W."QC:'(H,3@I/3XR-S@L8VAR*#$Y*3T^,C<X+&-H<B@R,"D]
M/C(W."QC:'(H,C$I/3XR-S@L"B`@("!C:'(H,C(I/3XR-S@L8VAR*#(S*3T^
M,C<X+&-H<B@R-"D]/C(W."QC:'(H,C4I/3XR-S@L8VAR*#(V*3T^,C<X+&-H
M<B@R-RD]/C(W."QC:'(H,C@I/3XR-S@L8VAR*#(Y*3T^,C<X+&-H<B@S,"D]
M/C(W."QC:'(H,S$I/3XR-S@L)R`G/3XR-S@L)R$G/3XR-S@L)R(G/3XS-34L
M)R,G/3XU-38L)R0G/3XU-38L)R4G/3XX.#DL)R8G/3XV-C<L)UPG)ST^,3DQ
M+"<H)ST^,S,S+"<I)ST^,S,S+"<J)ST^,S@Y+"<K)ST^-3@T+`H@("`@)RPG
M/3XR-S@L)RTG/3XS,S,L)RXG/3XR-S@L)R\G/3XR-S@L)S`G/3XU-38L)S$G
M/3XU-38L)S(G/3XU-38L)S,G/3XU-38L)S0G/3XU-38L)S4G/3XU-38L)S8G
M/3XU-38L)S<G/3XU-38L)S@G/3XU-38L)SDG/3XU-38L)SHG/3XR-S@L)SLG
M/3XR-S@L)SPG/3XU.#0L)STG/3XU.#0L)SXG/3XU.#0L)S\G/3XU-38L)T`G
M/3XQ,#$U+"=!)ST^-C8W+`H@("`@)T(G/3XV-C<L)T,G/3XW,C(L)T0G/3XW
M,C(L)T4G/3XV-C<L)T8G/3XV,3$L)T<G/3XW-S@L)T@G/3XW,C(L)TDG/3XR
M-S@L)THG/3XU,#`L)TLG/3XV-C<L)TPG/3XU-38L)TTG/3XX,S,L)TXG/3XW
M,C(L)T\G/3XW-S@L)U`G/3XV-C<L)U$G/3XW-S@L)U(G/3XW,C(L)U,G/3XV
M-C<L)U0G/3XV,3$L)U4G/3XW,C(L)U8G/3XV-C<L)U<G/3XY-#0L"B`@("`G
M6"<]/C8V-RPG62<]/C8V-RPG6B<]/C8Q,2PG6R<]/C(W."PG7%PG/3XR-S@L
M)UTG/3XR-S@L)UXG/3XT-CDL)U\G/3XU-38L)V`G/3XS,S,L)V$G/3XU-38L
M)V(G/3XU-38L)V,G/3XU,#`L)V0G/3XU-38L)V4G/3XU-38L)V8G/3XR-S@L
M)V<G/3XU-38L)V@G/3XU-38L)VDG/3XR,C(L)VHG/3XR,C(L)VLG/3XU,#`L
M)VPG/3XR,C(L)VTG/3XX,S,L"B`@("`G;B<]/C4U-BPG;R<]/C4U-BPG<"<]
M/C4U-BPG<2<]/C4U-BPG<B<]/C,S,RPG<R<]/C4P,"PG="<]/C(W."PG=2<]
M/C4U-BPG=B<]/C4P,"PG=R<]/C<R,BPG>"<]/C4P,"PG>2<]/C4P,"PG>B<]
M/C4P,"PG>R<]/C,S-"PG?"<]/C(V,"PG?2<]/C,S-"PG?B<]/C4X-"QC:'(H
M,3(W*3T^,S4P+&-H<B@Q,C@I/3XU-38L8VAR*#$R.2D]/C,U,"QC:'(H,3,P
M*3T^,C(R+&-H<B@Q,S$I/3XU-38L"B`@("!C:'(H,3,R*3T^,S,S+&-H<B@Q
M,S,I/3XQ,#`P+&-H<B@Q,S0I/3XU-38L8VAR*#$S-2D]/C4U-BQC:'(H,3,V
M*3T^,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H<B@Q,S@I/3XV-C<L8VAR*#$S.2D]
M/C,S,RQC:'(H,30P*3T^,3`P,"QC:'(H,30Q*3T^,S4P+&-H<B@Q-#(I/3XV
M,3$L8VAR*#$T,RD]/C,U,"QC:'(H,30T*3T^,S4P+&-H<B@Q-#4I/3XR,C(L
M8VAR*#$T-BD]/C(R,BQC:'(H,30W*3T^,S,S+&-H<B@Q-#@I/3XS,S,L8VAR
M*#$T.2D]/C,U,"QC:'(H,34P*3T^-34V+&-H<B@Q-3$I/3XQ,#`P+&-H<B@Q
M-3(I/3XS,S,L8VAR*#$U,RD]/C$P,#`L"B`@("!C:'(H,34T*3T^-3`P+&-H
M<B@Q-34I/3XS,S,L8VAR*#$U-BD]/CDT-"QC:'(H,34W*3T^,S4P+&-H<B@Q
M-3@I/3XU,#`L8VAR*#$U.2D]/C8V-RQC:'(H,38P*3T^,C<X+&-H<B@Q-C$I
M/3XS,S,L8VAR*#$V,BD]/C4U-BQC:'(H,38S*3T^-34V+&-H<B@Q-C0I/3XU
M-38L8VAR*#$V-2D]/C4U-BQC:'(H,38V*3T^,C8P+&-H<B@Q-C<I/3XU-38L
M8VAR*#$V."D]/C,S,RQC:'(H,38Y*3T^-S,W+&-H<B@Q-S`I/3XS-S`L8VAR
M*#$W,2D]/C4U-BQC:'(H,3<R*3T^-3@T+&-H<B@Q-S,I/3XS,S,L8VAR*#$W
M-"D]/C<S-RQC:'(H,3<U*3T^,S,S+`H@("`@8VAR*#$W-BD]/C0P,"QC:'(H
M,3<W*3T^-3@T+&-H<B@Q-S@I/3XS,S,L8VAR*#$W.2D]/C,S,RQC:'(H,3@P
M*3T^,S,S+&-H<B@Q.#$I/3XU-38L8VAR*#$X,BD]/C4S-RQC:'(H,3@S*3T^
M,C<X+&-H<B@Q.#0I/3XS,S,L8VAR*#$X-2D]/C,S,RQC:'(H,3@V*3T^,S8U
M+&-H<B@Q.#<I/3XU-38L8VAR*#$X."D]/C@S-"QC:'(H,3@Y*3T^.#,T+&-H
M<B@Q.3`I/3XX,S0L8VAR*#$Y,2D]/C8Q,2QC:'(H,3DR*3T^-C8W+&-H<B@Q
M.3,I/3XV-C<L8VAR*#$Y-"D]/C8V-RQC:'(H,3DU*3T^-C8W+&-H<B@Q.38I
M/3XV-C<L8VAR*#$Y-RD]/C8V-RP*("`@(&-H<B@Q.3@I/3XQ,#`P+&-H<B@Q
M.3DI/3XW,C(L8VAR*#(P,"D]/C8V-RQC:'(H,C`Q*3T^-C8W+&-H<B@R,#(I
M/3XV-C<L8VAR*#(P,RD]/C8V-RQC:'(H,C`T*3T^,C<X+&-H<B@R,#4I/3XR
M-S@L8VAR*#(P-BD]/C(W."QC:'(H,C`W*3T^,C<X+&-H<B@R,#@I/3XW,C(L
M8VAR*#(P.2D]/C<R,BQC:'(H,C$P*3T^-S<X+&-H<B@R,3$I/3XW-S@L8VAR
M*#(Q,BD]/C<W."QC:'(H,C$S*3T^-S<X+&-H<B@R,30I/3XW-S@L8VAR*#(Q
M-2D]/C4X-"QC:'(H,C$V*3T^-S<X+&-H<B@R,3<I/3XW,C(L8VAR*#(Q."D]
M/C<R,BQC:'(H,C$Y*3T^-S(R+`H@("`@8VAR*#(R,"D]/C<R,BQC:'(H,C(Q
M*3T^-C8W+&-H<B@R,C(I/3XV-C<L8VAR*#(R,RD]/C8Q,2QC:'(H,C(T*3T^
M-34V+&-H<B@R,C4I/3XU-38L8VAR*#(R-BD]/C4U-BQC:'(H,C(W*3T^-34V
M+&-H<B@R,C@I/3XU-38L8VAR*#(R.2D]/C4U-BQC:'(H,C,P*3T^.#@Y+&-H
M<B@R,S$I/3XU,#`L8VAR*#(S,BD]/C4U-BQC:'(H,C,S*3T^-34V+&-H<B@R
M,S0I/3XU-38L8VAR*#(S-2D]/C4U-BQC:'(H,C,V*3T^,C<X+&-H<B@R,S<I
M/3XR-S@L8VAR*#(S."D]/C(W."QC:'(H,C,Y*3T^,C<X+&-H<B@R-#`I/3XU
M-38L8VAR*#(T,2D]/C4U-BP*("`@(&-H<B@R-#(I/3XU-38L8VAR*#(T,RD]
M/C4U-BQC:'(H,C0T*3T^-34V+&-H<B@R-#4I/3XU-38L8VAR*#(T-BD]/C4U
M-BQC:'(H,C0W*3T^-3@T+&-H<B@R-#@I/3XV,3$L8VAR*#(T.2D]/C4U-BQC
M:'(H,C4P*3T^-34V+&-H<B@R-3$I/3XU-38L8VAR*#(U,BD]/C4U-BQC:'(H
M,C4S*3T^-3`P+&-H<B@R-30I/3XU-38L8VAR*#(U-2D]/C4P,"D["@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O1FEL92]0
M1$8O9F]N=',O=&EM97-B:2YP:'``````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#8R,#(@,3`U,34T,S0Q,S8@,#(S,#<Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J*@H@*B!`<&%C
M:V%G92!&:6QE7U!$1@H@*B\*)&9O;G1?=VED=&AS6R=T:6UE<T)))UT@/2!A
M<G)A>2@*("`@(&-H<B@P*3T^,C4P+&-H<B@Q*3T^,C4P+&-H<B@R*3T^,C4P
M+&-H<B@S*3T^,C4P+&-H<B@T*3T^,C4P+&-H<B@U*3T^,C4P+&-H<B@V*3T^
M,C4P+&-H<B@W*3T^,C4P+&-H<B@X*3T^,C4P+&-H<B@Y*3T^,C4P+&-H<B@Q
M,"D]/C(U,"QC:'(H,3$I/3XR-3`L8VAR*#$R*3T^,C4P+&-H<B@Q,RD]/C(U
M,"QC:'(H,30I/3XR-3`L8VAR*#$U*3T^,C4P+&-H<B@Q-BD]/C(U,"QC:'(H
M,3<I/3XR-3`L8VAR*#$X*3T^,C4P+&-H<B@Q.2D]/C(U,"QC:'(H,C`I/3XR
M-3`L8VAR*#(Q*3T^,C4P+`H@("`@8VAR*#(R*3T^,C4P+&-H<B@R,RD]/C(U
M,"QC:'(H,C0I/3XR-3`L8VAR*#(U*3T^,C4P+&-H<B@R-BD]/C(U,"QC:'(H
M,C<I/3XR-3`L8VAR*#(X*3T^,C4P+&-H<B@R.2D]/C(U,"QC:'(H,S`I/3XR
M-3`L8VAR*#,Q*3T^,C4P+"<@)ST^,C4P+"<A)ST^,S@Y+"<B)ST^-34U+"<C
M)ST^-3`P+"<D)ST^-3`P+"<E)ST^.#,S+"<F)ST^-S<X+"=<)R<]/C(W."PG
M*"<]/C,S,RPG*2<]/C,S,RPG*B<]/C4P,"PG*R<]/C4W,"P*("`@("<L)ST^
M,C4P+"<M)ST^,S,S+"<N)ST^,C4P+"<O)ST^,C<X+"<P)ST^-3`P+"<Q)ST^
M-3`P+"<R)ST^-3`P+"<S)ST^-3`P+"<T)ST^-3`P+"<U)ST^-3`P+"<V)ST^
M-3`P+"<W)ST^-3`P+"<X)ST^-3`P+"<Y)ST^-3`P+"<Z)ST^,S,S+"<[)ST^
M,S,S+"<\)ST^-3<P+"<])ST^-3<P+"<^)ST^-3<P+"<_)ST^-3`P+"=`)ST^
M.#,R+"=!)ST^-C8W+`H@("`@)T(G/3XV-C<L)T,G/3XV-C<L)T0G/3XW,C(L
M)T4G/3XV-C<L)T8G/3XV-C<L)T<G/3XW,C(L)T@G/3XW-S@L)TDG/3XS.#DL
M)THG/3XU,#`L)TLG/3XV-C<L)TPG/3XV,3$L)TTG/3XX.#DL)TXG/3XW,C(L
M)T\G/3XW,C(L)U`G/3XV,3$L)U$G/3XW,C(L)U(G/3XV-C<L)U,G/3XU-38L
M)U0G/3XV,3$L)U4G/3XW,C(L)U8G/3XV-C<L)U<G/3XX.#DL"B`@("`G6"<]
M/C8V-RPG62<]/C8Q,2PG6B<]/C8Q,2PG6R<]/C,S,RPG7%PG/3XR-S@L)UTG
M/3XS,S,L)UXG/3XU-S`L)U\G/3XU,#`L)V`G/3XS,S,L)V$G/3XU,#`L)V(G
M/3XU,#`L)V,G/3XT-#0L)V0G/3XU,#`L)V4G/3XT-#0L)V8G/3XS,S,L)V<G
M/3XU,#`L)V@G/3XU-38L)VDG/3XR-S@L)VHG/3XR-S@L)VLG/3XU,#`L)VPG
M/3XR-S@L)VTG/3XW-S@L"B`@("`G;B<]/C4U-BPG;R<]/C4P,"PG<"<]/C4P
M,"PG<2<]/C4P,"PG<B<]/C,X.2PG<R<]/C,X.2PG="<]/C(W."PG=2<]/C4U
M-BPG=B<]/C0T-"PG=R<]/C8V-RPG>"<]/C4P,"PG>2<]/C0T-"PG>B<]/C,X
M.2PG>R<]/C,T."PG?"<]/C(R,"PG?2<]/C,T."PG?B<]/C4W,"QC:'(H,3(W
M*3T^,S4P+&-H<B@Q,C@I/3XU,#`L8VAR*#$R.2D]/C,U,"QC:'(H,3,P*3T^
M,S,S+&-H<B@Q,S$I/3XU,#`L"B`@("!C:'(H,3,R*3T^-3`P+&-H<B@Q,S,I
M/3XQ,#`P+&-H<B@Q,S0I/3XU,#`L8VAR*#$S-2D]/C4P,"QC:'(H,3,V*3T^
M,S,S+&-H<B@Q,S<I/3XQ,#`P+&-H<B@Q,S@I/3XU-38L8VAR*#$S.2D]/C,S
M,RQC:'(H,30P*3T^.30T+&-H<B@Q-#$I/3XS-3`L8VAR*#$T,BD]/C8Q,2QC
M:'(H,30S*3T^,S4P+&-H<B@Q-#0I/3XS-3`L8VAR*#$T-2D]/C,S,RQC:'(H
M,30V*3T^,S,S+&-H<B@Q-#<I/3XU,#`L8VAR*#$T."D]/C4P,"QC:'(H,30Y
M*3T^,S4P+&-H<B@Q-3`I/3XU,#`L8VAR*#$U,2D]/C$P,#`L8VAR*#$U,BD]
M/C,S,RQC:'(H,34S*3T^,3`P,"P*("`@(&-H<B@Q-30I/3XS.#DL8VAR*#$U
M-2D]/C,S,RQC:'(H,34V*3T^-S(R+&-H<B@Q-3<I/3XS-3`L8VAR*#$U."D]
M/C,X.2QC:'(H,34Y*3T^-C$Q+&-H<B@Q-C`I/3XR-3`L8VAR*#$V,2D]/C,X
M.2QC:'(H,38R*3T^-3`P+&-H<B@Q-C,I/3XU,#`L8VAR*#$V-"D]/C4P,"QC
M:'(H,38U*3T^-3`P+&-H<B@Q-C8I/3XR,C`L8VAR*#$V-RD]/C4P,"QC:'(H
M,38X*3T^,S,S+&-H<B@Q-CDI/3XW-#<L8VAR*#$W,"D]/C(V-BQC:'(H,3<Q
M*3T^-3`P+&-H<B@Q-S(I/3XV,#8L8VAR*#$W,RD]/C,S,RQC:'(H,3<T*3T^
M-S0W+&-H<B@Q-S4I/3XS,S,L"B`@("!C:'(H,3<V*3T^-#`P+&-H<B@Q-S<I
M/3XU-S`L8VAR*#$W."D]/C,P,"QC:'(H,3<Y*3T^,S`P+&-H<B@Q.#`I/3XS
M,S,L8VAR*#$X,2D]/C4W-BQC:'(H,3@R*3T^-3`P+&-H<B@Q.#,I/3XR-3`L
M8VAR*#$X-"D]/C,S,RQC:'(H,3@U*3T^,S`P+&-H<B@Q.#8I/3XS,#`L8VAR
M*#$X-RD]/C4P,"QC:'(H,3@X*3T^-S4P+&-H<B@Q.#DI/3XW-3`L8VAR*#$Y
M,"D]/C<U,"QC:'(H,3DQ*3T^-3`P+&-H<B@Q.3(I/3XV-C<L8VAR*#$Y,RD]
M/C8V-RQC:'(H,3DT*3T^-C8W+&-H<B@Q.34I/3XV-C<L8VAR*#$Y-BD]/C8V
M-RQC:'(H,3DW*3T^-C8W+`H@("`@8VAR*#$Y."D]/CDT-"QC:'(H,3DY*3T^
M-C8W+&-H<B@R,#`I/3XV-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R*3T^-C8W
M+&-H<B@R,#,I/3XV-C<L8VAR*#(P-"D]/C,X.2QC:'(H,C`U*3T^,S@Y+&-H
M<B@R,#8I/3XS.#DL8VAR*#(P-RD]/C,X.2QC:'(H,C`X*3T^-S(R+&-H<B@R
M,#DI/3XW,C(L8VAR*#(Q,"D]/C<R,BQC:'(H,C$Q*3T^-S(R+&-H<B@R,3(I
M/3XW,C(L8VAR*#(Q,RD]/C<R,BQC:'(H,C$T*3T^-S(R+&-H<B@R,34I/3XU
M-S`L8VAR*#(Q-BD]/C<R,BQC:'(H,C$W*3T^-S(R+&-H<B@R,3@I/3XW,C(L
M8VAR*#(Q.2D]/C<R,BP*("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R,2D]/C8Q
M,2QC:'(H,C(R*3T^-C$Q+&-H<B@R,C,I/3XU,#`L8VAR*#(R-"D]/C4P,"QC
M:'(H,C(U*3T^-3`P+&-H<B@R,C8I/3XU,#`L8VAR*#(R-RD]/C4P,"QC:'(H
M,C(X*3T^-3`P+&-H<B@R,CDI/3XU,#`L8VAR*#(S,"D]/C<R,BQC:'(H,C,Q
M*3T^-#0T+&-H<B@R,S(I/3XT-#0L8VAR*#(S,RD]/C0T-"QC:'(H,C,T*3T^
M-#0T+&-H<B@R,S4I/3XT-#0L8VAR*#(S-BD]/C(W."QC:'(H,C,W*3T^,C<X
M+&-H<B@R,S@I/3XR-S@L8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^-3`P+&-H
M<B@R-#$I/3XU-38L"B`@("!C:'(H,C0R*3T^-3`P+&-H<B@R-#,I/3XU,#`L
M8VAR*#(T-"D]/C4P,"QC:'(H,C0U*3T^-3`P+&-H<B@R-#8I/3XU,#`L8VAR
M*#(T-RD]/C4W,"QC:'(H,C0X*3T^-3`P+&-H<B@R-#DI/3XU-38L8VAR*#(U
M,"D]/C4U-BQC:'(H,C4Q*3T^-34V+&-H<B@R-3(I/3XU-38L8VAR*#(U,RD]
M/C0T-"QC:'(H,C4T*3T^-3`P+&-H<B@R-34I/3XT-#0I.PH`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+T9I;&4O
M4$1&+V9O;G1S+VAE;'9E=&EC82YP:'``````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`V,C`W(#$P-3$U-#,T,3,V(#`R,S0P-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*BH*("H@0'!A
M8VMA9V4@1FEL95]01$8*("HO"B1F;VYT7W=I9'1H<ULG:&5L=F5T:6-A)UT@
M/2!A<G)A>2@*("`@(&-H<B@P*3T^,C<X+&-H<B@Q*3T^,C<X+&-H<B@R*3T^
M,C<X+&-H<B@S*3T^,C<X+&-H<B@T*3T^,C<X+&-H<B@U*3T^,C<X+&-H<B@V
M*3T^,C<X+&-H<B@W*3T^,C<X+&-H<B@X*3T^,C<X+&-H<B@Y*3T^,C<X+&-H
M<B@Q,"D]/C(W."QC:'(H,3$I/3XR-S@L8VAR*#$R*3T^,C<X+&-H<B@Q,RD]
M/C(W."QC:'(H,30I/3XR-S@L8VAR*#$U*3T^,C<X+&-H<B@Q-BD]/C(W."QC
M:'(H,3<I/3XR-S@L8VAR*#$X*3T^,C<X+&-H<B@Q.2D]/C(W."QC:'(H,C`I
M/3XR-S@L8VAR*#(Q*3T^,C<X+`H@("`@8VAR*#(R*3T^,C<X+&-H<B@R,RD]
M/C(W."QC:'(H,C0I/3XR-S@L8VAR*#(U*3T^,C<X+&-H<B@R-BD]/C(W."QC
M:'(H,C<I/3XR-S@L8VAR*#(X*3T^,C<X+&-H<B@R.2D]/C(W."QC:'(H,S`I
M/3XR-S@L8VAR*#,Q*3T^,C<X+"<@)ST^,C<X+"<A)ST^,C<X+"<B)ST^,S4U
M+"<C)ST^-34V+"<D)ST^-34V+"<E)ST^.#@Y+"<F)ST^-C8W+"=<)R<]/C$Y
M,2PG*"<]/C,S,RPG*2<]/C,S,RPG*B<]/C,X.2PG*R<]/C4X-"P*("`@("<L
M)ST^,C<X+"<M)ST^,S,S+"<N)ST^,C<X+"<O)ST^,C<X+"<P)ST^-34V+"<Q
M)ST^-34V+"<R)ST^-34V+"<S)ST^-34V+"<T)ST^-34V+"<U)ST^-34V+"<V
M)ST^-34V+"<W)ST^-34V+"<X)ST^-34V+"<Y)ST^-34V+"<Z)ST^,C<X+"<[
M)ST^,C<X+"<\)ST^-3@T+"<])ST^-3@T+"<^)ST^-3@T+"<_)ST^-34V+"=`
M)ST^,3`Q-2PG02<]/C8V-RP*("`@("=")ST^-C8W+"=#)ST^-S(R+"=$)ST^
M-S(R+"=%)ST^-C8W+"=&)ST^-C$Q+"=')ST^-S<X+"=()ST^-S(R+"=))ST^
M,C<X+"=*)ST^-3`P+"=+)ST^-C8W+"=,)ST^-34V+"=-)ST^.#,S+"=.)ST^
M-S(R+"=/)ST^-S<X+"=0)ST^-C8W+"=1)ST^-S<X+"=2)ST^-S(R+"=3)ST^
M-C8W+"=4)ST^-C$Q+"=5)ST^-S(R+"=6)ST^-C8W+"=7)ST^.30T+`H@("`@
M)U@G/3XV-C<L)UDG/3XV-C<L)UHG/3XV,3$L)ULG/3XR-S@L)UQ<)ST^,C<X
M+"==)ST^,C<X+"=>)ST^-#8Y+"=?)ST^-34V+"=@)ST^,S,S+"=A)ST^-34V
M+"=B)ST^-34V+"=C)ST^-3`P+"=D)ST^-34V+"=E)ST^-34V+"=F)ST^,C<X
M+"=G)ST^-34V+"=H)ST^-34V+"=I)ST^,C(R+"=J)ST^,C(R+"=K)ST^-3`P
M+"=L)ST^,C(R+"=M)ST^.#,S+`H@("`@)VXG/3XU-38L)V\G/3XU-38L)W`G
M/3XU-38L)W$G/3XU-38L)W(G/3XS,S,L)W,G/3XU,#`L)W0G/3XR-S@L)W4G
M/3XU-38L)W8G/3XU,#`L)W<G/3XW,C(L)W@G/3XU,#`L)WDG/3XU,#`L)WHG
M/3XU,#`L)WLG/3XS,S0L)WPG/3XR-C`L)WTG/3XS,S0L)WXG/3XU.#0L8VAR
M*#$R-RD]/C,U,"QC:'(H,3(X*3T^-34V+&-H<B@Q,CDI/3XS-3`L8VAR*#$S
M,"D]/C(R,BQC:'(H,3,Q*3T^-34V+`H@("`@8VAR*#$S,BD]/C,S,RQC:'(H
M,3,S*3T^,3`P,"QC:'(H,3,T*3T^-34V+&-H<B@Q,S4I/3XU-38L8VAR*#$S
M-BD]/C,S,RQC:'(H,3,W*3T^,3`P,"QC:'(H,3,X*3T^-C8W+&-H<B@Q,SDI
M/3XS,S,L8VAR*#$T,"D]/C$P,#`L8VAR*#$T,2D]/C,U,"QC:'(H,30R*3T^
M-C$Q+&-H<B@Q-#,I/3XS-3`L8VAR*#$T-"D]/C,U,"QC:'(H,30U*3T^,C(R
M+&-H<B@Q-#8I/3XR,C(L8VAR*#$T-RD]/C,S,RQC:'(H,30X*3T^,S,S+&-H
M<B@Q-#DI/3XS-3`L8VAR*#$U,"D]/C4U-BQC:'(H,34Q*3T^,3`P,"QC:'(H
M,34R*3T^,S,S+&-H<B@Q-3,I/3XQ,#`P+`H@("`@8VAR*#$U-"D]/C4P,"QC
M:'(H,34U*3T^,S,S+&-H<B@Q-38I/3XY-#0L8VAR*#$U-RD]/C,U,"QC:'(H
M,34X*3T^-3`P+&-H<B@Q-3DI/3XV-C<L8VAR*#$V,"D]/C(W."QC:'(H,38Q
M*3T^,S,S+&-H<B@Q-C(I/3XU-38L8VAR*#$V,RD]/C4U-BQC:'(H,38T*3T^
M-34V+&-H<B@Q-C4I/3XU-38L8VAR*#$V-BD]/C(V,"QC:'(H,38W*3T^-34V
M+&-H<B@Q-C@I/3XS,S,L8VAR*#$V.2D]/C<S-RQC:'(H,3<P*3T^,S<P+&-H
M<B@Q-S$I/3XU-38L8VAR*#$W,BD]/C4X-"QC:'(H,3<S*3T^,S,S+&-H<B@Q
M-S0I/3XW,S<L8VAR*#$W-2D]/C,S,RP*("`@(&-H<B@Q-S8I/3XT,#`L8VAR
M*#$W-RD]/C4X-"QC:'(H,3<X*3T^,S,S+&-H<B@Q-SDI/3XS,S,L8VAR*#$X
M,"D]/C,S,RQC:'(H,3@Q*3T^-34V+&-H<B@Q.#(I/3XU,S<L8VAR*#$X,RD]
M/C(W."QC:'(H,3@T*3T^,S,S+&-H<B@Q.#4I/3XS,S,L8VAR*#$X-BD]/C,V
M-2QC:'(H,3@W*3T^-34V+&-H<B@Q.#@I/3XX,S0L8VAR*#$X.2D]/C@S-"QC
M:'(H,3DP*3T^.#,T+&-H<B@Q.3$I/3XV,3$L8VAR*#$Y,BD]/C8V-RQC:'(H
M,3DS*3T^-C8W+&-H<B@Q.30I/3XV-C<L8VAR*#$Y-2D]/C8V-RQC:'(H,3DV
M*3T^-C8W+&-H<B@Q.3<I/3XV-C<L"B`@("!C:'(H,3DX*3T^,3`P,"QC:'(H
M,3DY*3T^-S(R+&-H<B@R,#`I/3XV-C<L8VAR*#(P,2D]/C8V-RQC:'(H,C`R
M*3T^-C8W+&-H<B@R,#,I/3XV-C<L8VAR*#(P-"D]/C(W."QC:'(H,C`U*3T^
M,C<X+&-H<B@R,#8I/3XR-S@L8VAR*#(P-RD]/C(W."QC:'(H,C`X*3T^-S(R
M+&-H<B@R,#DI/3XW,C(L8VAR*#(Q,"D]/C<W."QC:'(H,C$Q*3T^-S<X+&-H
M<B@R,3(I/3XW-S@L8VAR*#(Q,RD]/C<W."QC:'(H,C$T*3T^-S<X+&-H<B@R
M,34I/3XU.#0L8VAR*#(Q-BD]/C<W."QC:'(H,C$W*3T^-S(R+&-H<B@R,3@I
M/3XW,C(L8VAR*#(Q.2D]/C<R,BP*("`@(&-H<B@R,C`I/3XW,C(L8VAR*#(R
M,2D]/C8V-RQC:'(H,C(R*3T^-C8W+&-H<B@R,C,I/3XV,3$L8VAR*#(R-"D]
M/C4U-BQC:'(H,C(U*3T^-34V+&-H<B@R,C8I/3XU-38L8VAR*#(R-RD]/C4U
M-BQC:'(H,C(X*3T^-34V+&-H<B@R,CDI/3XU-38L8VAR*#(S,"D]/C@X.2QC
M:'(H,C,Q*3T^-3`P+&-H<B@R,S(I/3XU-38L8VAR*#(S,RD]/C4U-BQC:'(H
M,C,T*3T^-34V+&-H<B@R,S4I/3XU-38L8VAR*#(S-BD]/C(W."QC:'(H,C,W
M*3T^,C<X+&-H<B@R,S@I/3XR-S@L8VAR*#(S.2D]/C(W."QC:'(H,C0P*3T^
M-34V+&-H<B@R-#$I/3XU-38L"B`@("!C:'(H,C0R*3T^-34V+&-H<B@R-#,I
M/3XU-38L8VAR*#(T-"D]/C4U-BQC:'(H,C0U*3T^-34V+&-H<B@R-#8I/3XU
M-38L8VAR*#(T-RD]/C4X-"QC:'(H,C0X*3T^-C$Q+&-H<B@R-#DI/3XU-38L
M8VAR*#(U,"D]/C4U-BQC:'(H,C4Q*3T^-34V+&-H<B@R-3(I/3XU-38L8VAR
M*#(U,RD]/C4P,"QC:'(H,C4T*3T^-34V+&-H<B@R-34I/3XU,#`I.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]&:6QE
M+U!$1B]F;VYT<R]S>6UB;VPN<&AP````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P-C`W,R`Q,#4Q-30S-#$S-B`P,C(W-3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J($!P
M86-K86=E($9I;&5?4$1&"B`J+PHD9F]N=%]W:61T:'-;)W-Y;6)O;"==(#T@
M87)R87DH"B`@("!C:'(H,"D]/C(U,"QC:'(H,2D]/C(U,"QC:'(H,BD]/C(U
M,"QC:'(H,RD]/C(U,"QC:'(H-"D]/C(U,"QC:'(H-2D]/C(U,"QC:'(H-BD]
M/C(U,"QC:'(H-RD]/C(U,"QC:'(H."D]/C(U,"QC:'(H.2D]/C(U,"QC:'(H
M,3`I/3XR-3`L8VAR*#$Q*3T^,C4P+&-H<B@Q,BD]/C(U,"QC:'(H,3,I/3XR
M-3`L8VAR*#$T*3T^,C4P+&-H<B@Q-2D]/C(U,"QC:'(H,38I/3XR-3`L8VAR
M*#$W*3T^,C4P+&-H<B@Q."D]/C(U,"QC:'(H,3DI/3XR-3`L8VAR*#(P*3T^
M,C4P+&-H<B@R,2D]/C(U,"P*("`@(&-H<B@R,BD]/C(U,"QC:'(H,C,I/3XR
M-3`L8VAR*#(T*3T^,C4P+&-H<B@R-2D]/C(U,"QC:'(H,C8I/3XR-3`L8VAR
M*#(W*3T^,C4P+&-H<B@R."D]/C(U,"QC:'(H,CDI/3XR-3`L8VAR*#,P*3T^
M,C4P+&-H<B@S,2D]/C(U,"PG("<]/C(U,"PG(2<]/C,S,RPG(B<]/C<Q,RPG
M(R<]/C4P,"PG)"<]/C4T.2PG)2<]/C@S,RPG)B<]/C<W."PG7"<G/3XT,SDL
M)R@G/3XS,S,L)RDG/3XS,S,L)RHG/3XU,#`L)RLG/3XU-#DL"B`@("`G+"<]
M/C(U,"PG+2<]/C4T.2PG+B<]/C(U,"PG+R<]/C(W."PG,"<]/C4P,"PG,2<]
M/C4P,"PG,B<]/C4P,"PG,R<]/C4P,"PG-"<]/C4P,"PG-2<]/C4P,"PG-B<]
M/C4P,"PG-R<]/C4P,"PG."<]/C4P,"PG.2<]/C4P,"PG.B<]/C(W."PG.R<]
M/C(W."PG/"<]/C4T.2PG/2<]/C4T.2PG/B<]/C4T.2PG/R<]/C0T-"PG0"<]
M/C4T.2PG02<]/C<R,BP*("`@("=")ST^-C8W+"=#)ST^-S(R+"=$)ST^-C$R
M+"=%)ST^-C$Q+"=&)ST^-S8S+"=')ST^-C`S+"=()ST^-S(R+"=))ST^,S,S
M+"=*)ST^-C,Q+"=+)ST^-S(R+"=,)ST^-C@V+"=-)ST^.#@Y+"=.)ST^-S(R
M+"=/)ST^-S(R+"=0)ST^-S8X+"=1)ST^-S0Q+"=2)ST^-34V+"=3)ST^-3DR
M+"=4)ST^-C$Q+"=5)ST^-CDP+"=6)ST^-#,Y+"=7)ST^-S8X+`H@("`@)U@G
M/3XV-#4L)UDG/3XW.34L)UHG/3XV,3$L)ULG/3XS,S,L)UQ<)ST^.#8S+"==
M)ST^,S,S+"=>)ST^-C4X+"=?)ST^-3`P+"=@)ST^-3`P+"=A)ST^-C,Q+"=B
M)ST^-30Y+"=C)ST^-30Y+"=D)ST^-#DT+"=E)ST^-#,Y+"=F)ST^-3(Q+"=G
M)ST^-#$Q+"=H)ST^-C`S+"=I)ST^,S(Y+"=J)ST^-C`S+"=K)ST^-30Y+"=L
M)ST^-30Y+"=M)ST^-3<V+`H@("`@)VXG/3XU,C$L)V\G/3XU-#DL)W`G/3XU
M-#DL)W$G/3XU,C$L)W(G/3XU-#DL)W,G/3XV,#,L)W0G/3XT,SDL)W4G/3XU
M-S8L)W8G/3XW,3,L)W<G/3XV.#8L)W@G/3XT.3,L)WDG/3XV.#8L)WHG/3XT
M.30L)WLG/3XT.#`L)WPG/3XR,#`L)WTG/3XT.#`L)WXG/3XU-#DL8VAR*#$R
M-RD]/C`L8VAR*#$R."D]/C`L8VAR*#$R.2D]/C`L8VAR*#$S,"D]/C`L8VAR
M*#$S,2D]/C`L"B`@("!C:'(H,3,R*3T^,"QC:'(H,3,S*3T^,"QC:'(H,3,T
M*3T^,"QC:'(H,3,U*3T^,"QC:'(H,3,V*3T^,"QC:'(H,3,W*3T^,"QC:'(H
M,3,X*3T^,"QC:'(H,3,Y*3T^,"QC:'(H,30P*3T^,"QC:'(H,30Q*3T^,"QC
M:'(H,30R*3T^,"QC:'(H,30S*3T^,"QC:'(H,30T*3T^,"QC:'(H,30U*3T^
M,"QC:'(H,30V*3T^,"QC:'(H,30W*3T^,"QC:'(H,30X*3T^,"QC:'(H,30Y
M*3T^,"QC:'(H,34P*3T^,"QC:'(H,34Q*3T^,"QC:'(H,34R*3T^,"QC:'(H
M,34S*3T^,"P*("`@(&-H<B@Q-30I/3XP+&-H<B@Q-34I/3XP+&-H<B@Q-38I
M/3XP+&-H<B@Q-3<I/3XP+&-H<B@Q-3@I/3XP+&-H<B@Q-3DI/3XP+&-H<B@Q
M-C`I/3XW-3`L8VAR*#$V,2D]/C8R,"QC:'(H,38R*3T^,C0W+&-H<B@Q-C,I
M/3XU-#DL8VAR*#$V-"D]/C$V-RQC:'(H,38U*3T^-S$S+&-H<B@Q-C8I/3XU
M,#`L8VAR*#$V-RD]/C<U,RQC:'(H,38X*3T^-S4S+&-H<B@Q-CDI/3XW-3,L
M8VAR*#$W,"D]/C<U,RQC:'(H,3<Q*3T^,3`T,BQC:'(H,3<R*3T^.3@W+&-H
M<B@Q-S,I/3XV,#,L8VAR*#$W-"D]/CDX-RQC:'(H,3<U*3T^-C`S+`H@("`@
M8VAR*#$W-BD]/C0P,"QC:'(H,3<W*3T^-30Y+&-H<B@Q-S@I/3XT,3$L8VAR
M*#$W.2D]/C4T.2QC:'(H,3@P*3T^-30Y+&-H<B@Q.#$I/3XW,3,L8VAR*#$X
M,BD]/C0Y-"QC:'(H,3@S*3T^-#8P+&-H<B@Q.#0I/3XU-#DL8VAR*#$X-2D]
M/C4T.2QC:'(H,3@V*3T^-30Y+&-H<B@Q.#<I/3XU-#DL8VAR*#$X."D]/C$P
M,#`L8VAR*#$X.2D]/C8P,RQC:'(H,3DP*3T^,3`P,"QC:'(H,3DQ*3T^-C4X
M+&-H<B@Q.3(I/3XX,C,L8VAR*#$Y,RD]/C8X-BQC:'(H,3DT*3T^-SDU+&-H
M<B@Q.34I/3XY.#<L8VAR*#$Y-BD]/C<V."QC:'(H,3DW*3T^-S8X+`H@("`@
M8VAR*#$Y."D]/C@R,RQC:'(H,3DY*3T^-S8X+&-H<B@R,#`I/3XW-C@L8VAR
M*#(P,2D]/C<Q,RQC:'(H,C`R*3T^-S$S+&-H<B@R,#,I/3XW,3,L8VAR*#(P
M-"D]/C<Q,RQC:'(H,C`U*3T^-S$S+&-H<B@R,#8I/3XW,3,L8VAR*#(P-RD]
M/C<Q,RQC:'(H,C`X*3T^-S8X+&-H<B@R,#DI/3XW,3,L8VAR*#(Q,"D]/C<Y
M,"QC:'(H,C$Q*3T^-SDP+&-H<B@R,3(I/3XX.3`L8VAR*#(Q,RD]/C@R,RQC
M:'(H,C$T*3T^-30Y+&-H<B@R,34I/3XR-3`L8VAR*#(Q-BD]/C<Q,RQC:'(H
M,C$W*3T^-C`S+&-H<B@R,3@I/3XV,#,L8VAR*#(Q.2D]/C$P-#(L"B`@("!C
M:'(H,C(P*3T^.3@W+&-H<B@R,C$I/3XV,#,L8VAR*#(R,BD]/CDX-RQC:'(H
M,C(S*3T^-C`S+&-H<B@R,C0I/3XT.30L8VAR*#(R-2D]/C,R.2QC:'(H,C(V
M*3T^-SDP+&-H<B@R,C<I/3XW.3`L8VAR*#(R."D]/C<X-BQC:'(H,C(Y*3T^
M-S$S+&-H<B@R,S`I/3XS.#0L8VAR*#(S,2D]/C,X-"QC:'(H,C,R*3T^,S@T
M+&-H<B@R,S,I/3XS.#0L8VAR*#(S-"D]/C,X-"QC:'(H,C,U*3T^,S@T+&-H
M<B@R,S8I/3XT.30L8VAR*#(S-RD]/C0Y-"QC:'(H,C,X*3T^-#DT+&-H<B@R
M,SDI/3XT.30L8VAR*#(T,"D]/C`L8VAR*#(T,2D]/C,R.2P*("`@(&-H<B@R
M-#(I/3XR-S0L8VAR*#(T,RD]/C8X-BQC:'(H,C0T*3T^-C@V+&-H<B@R-#4I
M/3XV.#8L8VAR*#(T-BD]/C,X-"QC:'(H,C0W*3T^,S@T+&-H<B@R-#@I/3XS
M.#0L8VAR*#(T.2D]/C,X-"QC:'(H,C4P*3T^,S@T+&-H<B@R-3$I/3XS.#0L
M8VAR*#(U,BD]/C0Y-"QC:'(H,C4S*3T^-#DT+&-H<B@R-30I/3XT.30L8VAR
M*#(U-2D]/C`I.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN
M8TU,+T1E=FEC90``````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S8@,#(P-3<P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9```````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-B`P
M,C`W-#<`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O;&EB+U-Y;F--3"]3=&%T92YP
M:'``````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(T
M,3$T(#$P-3$U-#,T,3,V(#`R,3(T,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=3>6YC
M34PO1&5V:6-E26YF;RYP:'`G.PIR97%U:7)E7V]N8V4@)U-Y;F--3"]$979I
M8V4N<&AP)SL*<F5Q=6ER95]O;F-E("=3>6YC34PO0V]N<W1A;G1S+G!H<"<[
M"@HO*BH*("H@5&AE(%-Y;F--3%]3=&%T92!C;&%S<R!P<F]V:61E<R!A(%-Y
M;F--3"!S=&%T92!O8FIE8W0N"B`J"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y
M;F--3"]3>6YC34PO4W1A=&4N<&AP+'8@,2XQ-RXR+C@@,C`P-B\P,2\P,2`R
M,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#,M,C`P-B!!
M;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*@H@*B!3964@
M=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA
M=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F
M:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M
M;"X*("H*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M
M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y
M;F--3`H@*B\*8VQA<W,@4WEN8TU,7U-T871E('L*"B`@("`O*BH*("`@("`J
M(%-E<W-I;VX@:60@;V8@=&AI<R!S97-S:6]N+@H@("`@("HO"B`@("!V87(@
M)%]S97-S:6]N240["@H@("`@+RHJ"B`@("`@*B!)9"!O9B!C=7)R96YT(&UE
M<W-A9V4N"B`@("`@*B\*("`@('9A<B`D7VUS9TE$.PH*("`@("\J*@H@("`@
M("H@5&AE('1A<F=E="!54DD@87,@<V5N="!B>2!T:&4@8VQI96YT+B!4:&ES
M(&ES(&YO<FUA;&QY('1H92!54DP*("`@("`J(&]F('1H92!(;W)D92!R<&,@
M<V5R=F5R+B!(;W=E=F5R('1H92!C;&EE;G0@:7,@9G)E92!T;R!S96YD"B`@
M("`@*B!A;GET:&EN9SH@<WEN8S1J(&9O<B!E>&%M<&QE(&1O97,@;F]T('-E
M;F0@=&AE('!A=&@@<&%R="X*("`@("`J+PH@("`@=F%R("1?=&%R9V5T55))
M.PH*("`@("\J*@H@("`@("H@5&AE('-O=7)C92!54DD@87,@<V5N="!B>2!T
M:&4@8VQI96YT+B!#86X@8F4@=7-E9"!T;R!I9&5N=&EF>0H@("`@("H@=&AE
M(&-L:65N=#L@=&AE('-E<W-I;VX@:60@:7,@8V]N<W1R=6-T960@;6%I;FQY
M(&9R;VT@=&AI<PH@("`@("H@9&%T82X*("`@("`J+PH@("`@=F%R("1?<V]U
M<F-E55)).PH*("`@("\J*@H@("`@("H@,"!F;W(@<WEN8VUL(#$N,"P@,2!F
M;W(@<WEN8VUL(#$N,2X*("`@("`J+PH@("`@=F%R("1?=F5R<VEO;CL*"B`@
M("`O*BH*("`@("`J(%5S97)N86UE('5S960@=&\@875T:"!W:71H('1H92!B
M86-K96YD+@H@("`@("HO"B`@("!V87(@)%]L;V-.86UE.PH*("`@("\J*@H@
M("`@("H@4&%S<W=O<F0@=7-E9"!T;R!A=71H('=I=&@@=&AE(&)A8VME;F0N
M"B`@("`@*B\*("`@('9A<B`D7W!A<W-W;W)D.PH*("`@("\J*@H@("`@("H@
M5')U92!M96%N<R!T:&%T('1H:7,@<V5S<VEO;B!H87,@875T:&5N=&EC871E
M9"!S=6-C97-S9G5L;'DN"B`@("`@*B\*("`@('9A<B`D7VES075T:&]R:7IE
M9#L*"B`@("`O*BH*("`@("`J($YA;65S<&%C92!I;F9O<FUA=&EO;BX*("`@
M("`J+PH@("`@=F%R("1?=7)I.PH*("`@("\J*@H@("`@("H@3F%M97-P86-E
M(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@("!V87(@)%]U<FE-971A.PH*("`@
M("\J*@H@("`@("H@3F%M97-P86-E(&EN9F]R;6%T:6]N+@H@("`@("HO"B`@
M("!V87(@)%]U<FE$979);F8["@H@("`@=F%R("1?=V)X;6P[("\O(&)O;VQE
M86X*"B`@("!V87(@)%]M87A-<V=3:7IE.PH*("`@('9A<B`D7W-Y;F-S(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%=R:71T96X@=&\@9&(@869T97(@
M<W5C8V5S<V9U;"!S>6YC+@H@("`@("HO"B`@("!V87(@)%]C;&EE;G1!;F-H
M;W).97AT(#T@87)R87DH*3L*"B`@("!V87(@)%]S97)V97)!;F-H;W),87-T
M(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%=R:71T96X@=&\@9&(@869T
M97(@<W5C8V5S<V9U;"!S>6YC+@H@("`@("HO"B`@("!V87(@)%]S97)V97)!
M;F-H;W).97AT(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-M86QL(&AA
M<V@@=&\@<W1O<F4@=&AE(&YU;6)E<B!O9B!A9&1S+"!D96QE=&5S+"!E=&,N
M(&1U<FEN9R!A"B`@("`@*B!S97-S:6]N(&9O<B!C<F5A=&EO;B!O9B!S=6UM
M87)Y(&9O<B!L;V=F:6QE+@H@("`@("HO"B`@("!V87(@)%]L;V<@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%-Y;F--3%]$979I8V4@8VQA<W,@
M9&5F:6YE9"!I;B!$979I8V4N<&AP+B!4:&ES(&-L87-S"B`@("`@*B!H86YD
M;&5S(&1E8VEC92!S<&5C:69I8R!S='5F9BX*("`@("`J+PH@("`@=F%R("1?
M9&5V:6-E.PH*("`@("\J*@H@("`@("H@1&5V:6-E(&EN9F\@<')O=FED960@
M8GD@=&AE(%-Y;F--3"!$979);F8@9&%T82X@36%I;FQY('5S960@8GD*("`@
M("`J('1H92!3>6YC34Q?1&5V:6-E(&-L87-S+@H@("`@("HO"B`@("!V87(@
M)%]D979I8V5);F9O.PH*("`@("\J*@H@("`@("H@268@=V4@87)E(&5X<&5C
M=&EN9R!A(%)E<W5L="!P86-K970L('1H:7,@<W1O<F5S('=H97)E('1O"B`@
M("`@*B!R;W5T92!I="X*("`@("`J+PH@("`@=F%R("1?97AP96-T961297-U
M;'0@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!I
M;G-T86YC92!O9B!3>6YC34Q?4W1A=&4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%-Y;F--3%]3=&%T92@D<V]U<F-E55))+"`D;&]C3F%M92P@)'-E<W-I;VY)
M1"P@)'!A<W-W;W)D(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/G-E
M=%-O=7)C955222@D<V]U<F-E55))*3L*("`@("`@("`D=&AI<RT^<V5T3&]C
M3F%M92@D;&]C3F%M92D["B`@("`@("`@)'1H:7,M/G-E=%-E<W-I;VY)1"@D
M<V5S<VEO;DE$*3L*("`@("`@("!I9B`H)'!A<W-W;W)D*2!["B`@("`@("`@
M("`@("1T:&ES+3YS971087-S=V]R9"@D<&%S<W=O<F0I.PH@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/FES075T:&]R:7IE9"`](&9A;'-E.PH*("`@("`@
M("`O+R!#<F5A=&4@96UP='D@9'5M;7D@9&5V:6-E(&EN9F\N(%=I;&P@8F4@
M<F5P;&%C960@=VET:"!R96%L"B`@("`@("`@+R\@1&5V26YF(&EN9F]R;6%T
M:6]N(&EF('1H97D@87)E('1R86YS9F5R<F5D+@H@("`@("`@("1T:&ES+3Y?
M9&5V:6-E26YF;R`]("9N97<@4WEN8TU,7T1E=FEC94EN9F\H*3L*"B`@("`@
M("`@+RH@86QL;W<@=F5R>2!B:6<@;65S<V%G97,@=6YL97-S('1O;&0@;W1H
M97)W:7-E.B`J+PH@("`@("`@("1T:&ES+3YS971-87A-<V=3:7IE*#$P,#`P
M,#`P,#`I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$1E=FEC94EN9F\H)&1I
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&5V:6-E26YF;R`]("1D:3L*("`@
M('T*"B`@("!F=6YC=&EO;B!G971$979I8V5);F9O*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]D979I8V5);F9O.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$QO8TYA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M7VQO8TYA;64["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V]U<F-E55))*"D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S;W5R8V554DD["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T5&%R9V5T55))*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@
M9V5T5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F5R
M<VEO;CL*("`@('T*"B`@("!F=6YC=&EO;B!G971-<V=)1"@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?;7-G240["B`@("!]"@H@("`@9G5N8W1I
M;VX@<V5T5T)834PH)'=B>&UL*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=V)X
M;6P@/2`D=V)X;6P["B`@("!]"@H@("`@9G5N8W1I;VX@:7-70EA-3"@I"B`@
M("!["B`@("`@("`@<F5T=7)N("%E;7!T>2@D=&AI<RT^7W=B>&UL*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!S971-87A-<V=3:7IE*"1S*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?;6%X37-G4VEZ92`]("1S.PH@("`@?0H*("`@(&9U;F-T
M:6]N(&=E=$UA>$US9U-I>F4H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7VUA>$US9U-I>F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@
M9F]R('!R;W!E<G1Y(&US9TE$+@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&US9TE$("!.97<@=F%L=64@;V8@<')O<&5R='D@;7-G240N"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$US9TE$*"1M<V=)1"D*("`@('L*("`@("`@
M("`D=&AI<RT^7VUS9TE$(#T@)&US9TE$.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T=&5R(&9O<B!P<F]P97)T>2!L;V-.86UE+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&QO8TYA;64@($YE=R!V86QU92!O9B!P<F]P97)T
M>2!L;V-.86UE+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971,;V-.86UE*"1L
M;V-.86UE*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;&]C3F%M92`]("1L;V-.
M86UE.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%!A<W-W;W)D*"1P87-S=V]R
M9"D*("`@('L*("`@("`@("`D=&AI<RT^7W!A<W-W;W)D(#T@)'!A<W-W;W)D
M.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%-O=7)C955222@D<V]U<F-E55))
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V]U<F-E55))(#T@)'-O=7)C9552
M23L*("`@('T*"B`@("!F=6YC=&EO;B!S971487)G97154DDH)'1A<F=E=%52
M22D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`]("1T87)G9715
M4DD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T5F5R<VEO;B@D=F5R<VEO;BD*
M("`@('L*("`@("`@("`D=&AI<RT^7W9E<G-I;VX@/2`D=F5R<VEO;CL*"B`@
M("`@("`@:68@*"1V97)S:6]N(#T](#`I('L*("`@("`@("`@("`@)'1H:7,M
M/E]U<FD@/2!.04U%7U-004-%7U5225]364Y#34P["B`@("`@("`@("`@("1T
M:&ES+3Y?=7)I365T82`]($Y!345?4U!!0T5?55))7TU%5$E.1CL*("`@("`@
M("`@("`@)'1H:7,M/E]U<FE$979);F8@/2!.04U%7U-004-%7U5225]$159)
M3D8["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]U<FD@
M/2!.04U%7U-004-%7U5225]364Y#34Q?,5\Q.PH@("`@("`@("`@("`D=&AI
M<RT^7W5R:4UE=&$@/2!.04U%7U-004-%7U5225]-151)3D9?,5\Q.PH@("`@
M("`@("`@("`D=&AI<RT^7W5R:41E=DEN9B`]($Y!345?4U!!0T5?55))7T1%
M5DE.1E\Q7S$["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N('-E=%-E
M<W-I;VY)1"@D<V5S<VEO;DE$*0H@("`@>PH@("`@("`@("1T:&ES+3Y?<V5S
M<VEO;DE$(#T@)'-E<W-I;VY)1#L*("`@('T*"B`@("!F=6YC=&EO;B!I<T%U
M=&AO<FEZ960H*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]I<T%U=&AO
M<FEZ960@)B8@(65M<'1Y*"1T:&ES+3Y?<&%S<W=O<F0I*2!["B`@("`@("`@
M("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)V-H96-K:6YG
M(&%U=&@@9F]R('5S97(])PH@("`@("`@("`@("`N("1T:&ES+3Y?;&]C3F%M
M92P*("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?
M1$5"54<I.PH*("`@("`@("`@("`@)&%U=&@@/2`F075T:#HZ<VEN9VQE=&]N
M*"1'3$]"04Q36R=C;VYF)UU;)V%U=&@G75LG9')I=F5R)UTI.PH@("`@("`@
M("`@("`D=&AI<RT^7VES075T:&]R:7IE9"`]("1A=71H+3YA=71H96YT:6-A
M=&4H)'1H:7,M/E]L;V-.86UE+"!A<G)A>2@G<&%S<W=O<F0G(#T^("1T:&ES
M+3Y?<&%S<W=O<F0I*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI
M<RT^7VES075T:&]R:7IE9#L*("`@('T*"B`@("!F=6YC=&EO;B!S9713>6YC
M*"1T87)G970L("8D<WEN8RD*("`@('L*("`@("`@("`D=&AI<RT^7W-Y;F-S
M6R1T87)G971=(#T@)B1S>6YC.PH@("`@?0H*("`@(&9U;F-T:6]N("9G9713
M>6YC*"1T87)G970I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<WEN8W-;)'1A<F=E=%TI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W-Y;F-S6R1T87)G971=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1F86QS92`](&9A;'-E.PH@("`@("`@("`@("!R971U<FX@)&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!G97154DDH*0H@("`@>PH@
M("`@("`@("\J"B`@("`@("`@("H@5&AE(&YO;B!70EA-3"!D979I8V5S("AN
M;W1A8FQY(%`Y,#`@86YD(%-Y;F,T:B!S965M('1O(&=E="!C;VYF=7-E9`H@
M("`@("`@("`J(&)Y(&$@/%-Y;F--3"!X;6QN<STB<WEN8VUL.E-93D--3#$N
M,2(^(&5L96UE;G0N(%1H97D@<F5Q=6ER90H@("`@("`@("`J(&IU<W0@/%-Y
M;F--3#XN(%-O(&1O;B=T('5S92!A;B!N<R!F;W(@;F]N('=B>&UL(&1E=FEC
M97,N"B`@("`@("`@("HO"B`@("`@("`@:68@*"1T:&ES+3YI<U="6$U,*"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=7)I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]
M"B`@("!F=6YC=&EO;B!G97154DE-971A*"D*("`@('L*("`@("`@("!R971U
M<FX@)'1H:7,M/E]U<FE-971A.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%52
M241E=DEN9B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=7)I1&5V
M26YF.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=$-L:65N=$%N8VAO<DYE>'0H
M)'1Y<&4L("1A*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VQI96YT06YC:&]R
M3F5X=%LD='EP95T@/2`D83L*("`@('T*"B`@("!F=6YC=&EO;B!S971397)V
M97)!;F-H;W),87-T*"1T>7!E+"`D82D*("`@('L*("`@("`@("`D=&AI<RT^
M7W-E<G9E<D%N8VAO<DQA<W1;)'1Y<&5=(#T@)&$["B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T4V5R=F5R06YC:&]R3F5X="@D='EP92P@)&$I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]S97)V97)!;F-H;W).97AT6R1T>7!E72`]("1A.PH@
M("`@?0H*("`@(&9U;F-T:6]N(&=E=$-L:65N=$%N8VAO<DYE>'0H)'1Y<&4I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VQI96YT06YC:&]R3F5X
M=%LD='EP95T["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T4V5R=F5R06YC:&]R
M3F5X="@D='EP92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]S97)V
M97)!;F-H;W).97AT6R1T>7!E73L*("`@('T*"B`@("!F=6YC=&EO;B!G9713
M97)V97)!;F-H;W),87-T*"1T>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W-E<G9E<D%N8VAO<DQA<W1;)'1Y<&5=.PH@("`@?0H*("`@("\J
M*@H@("`@("H@5&AE(&QO9R!S:6UP;'D@8V]U;G1S('1H92!E;G1R:65S(&9O
M<B!E86-H('1O<&EC+@H@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)'1O<&EC
M*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VQO9ULD=&]P:6-=
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO9ULD=&]P:6-=("L](#$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]L;V=;)'1O<&EC
M72`](#$["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AE($QO
M9R!I<R!A;B!A<G)A>2!W:&5R92!T:&4@:V5Y(&ES('1H92!E=F5N="!N86UE
M(&%N9"!T:&4*("`@("`J('9A;'5E('-A>7,@:&]W(&]F=&5N('1H:7,@979E
M;G0@;V-C=7)E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]G*"D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]L;V<["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&%N(&ED96YT:69I97(@=7-E9"!T;R!I9&5N=&EF
M>2!T:&4@<WEN8R!D979I8V4@:6X@=&AE"B`@("`@*B!M87`N($-U<G)E;G1L
M>2`B;&]C;F%M93IS;W5R8V554DDB+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713>6YC261E;G1I9FEE<B@I"B`@("!["B`@("`@("`@<F5T=7)N('-T<E]R
M97!L86-E*"<Z)RP@)U\G+"`D=&AI<RT^7VQO8TYA;64I"B`@("`@("`@("`@
M("`@("`N("<Z)PH@("`@("`@("`@("`@("`@+B!S=')?<F5P;&%C92@G.B<L
M("=?)RP@)'1H:7,M/E]S;W5R8V554DDI.PH@("`@?0H*("`@(&9U;F-T:6]N
M("9G971$979I8V4H*0H@("`@>PH@("`@("`@(')E='5R;B!3>6YC34Q?1&5V
M:6-E.CIS:6YG;&5T;VXH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@=&AE(&5X<&5C=&5D(')E<W5L="!T>7!E(&9O<B!A(%)E<W5L=',@=&%G
M+"!U<V5D('1O(')E9&ER96-T('1H90H@("`@("H@:6YC;VUI;F<@8V]M;6%N
M9"!S;VUE=VAE<F4@<W!E8VEA;"X@($9O<B!E>&%M<&QE+"!I9B!W92!H879E
M(')E<75E<W1E9`H@("`@("H@9&5V:6-E(&EN9F\L('1H92!297-U;'1S('1A
M9R!S:&]U;&0@8F4@<V5N="!T;R!T:&4@4'5T(&-O;6UA;F0@<V\@=V4@8V%N
M"B`@("`@*B!R96%D(&ET(&EN+@H@("`@("H*("`@("`J($-L96%R<R!T:&4@
M:&%S:"!O9B!T:&ES($-O;6UA;F0@4F5F97)E;F-E(&)E9F]R92!R971U<FYI
M;F<@82!V86QU92X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`D8VUD
M4F5F("!4:&4@0VUD4F5F(&]F('1H92!I;F-O;6EN9R!C;VUM86YD+@H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@8V]M;6%N9"!T>7!E('1O
M(')E9&ER96-T('1O+"!O<@H@("`@("H@("`@("`@("`@("`@("`@('5N9&5F
M:6YE9"!I9B!N;R!R961I<F5C="!R96=I<W1E<F5D+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971%>'!E8W1E9%)E<W5L=%1Y<&4H)&-M9%)E9BD*("`@('L*
M("`@("`@("!I9B`H(&ES<V5T*"1T:&ES+3Y?97AP96-T961297-U;'1;)&-M
M9%)E9ETI("D@>PH@("`@("`@("`@("`D8VUD5'EP92`]("1T:&ES+3Y?97AP
M96-T961297-U;'1;)&-M9%)E9ET["B`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?97AP96-T961297-U;'1;)&-M9%)E9ETI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&-M9%1Y<&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S
M('5P(&$@8V]M;6%N9"!R961I<F5C=&EO;B!F;W(@82!F=71U<F4@4F5S=6QT
M(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@)&-M9$E$
M("`@(%1H92!#;61)1"!O9B!T:&4@8V]M;6%N9"!W92!A<F4@<V5N9&EN9R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!C;&EE;G0N
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D8VUD5'EP92`@5&AE('1Y<&4@;V8@
M8V]M;6%N9"!T;R!R961I<F5C="!T;R!W:&5N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@=&AE(%)E<W5L=',@8V]M;6%N9"!I<R!R96-E:79E
M9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T17AP96-T961297-U;'14>7!E
M*"1C;61)1"P@)&-M9%1Y<&4I"B`@("!["B`@("`@("`@)'1H:7,M/E]E>'!E
M8W1E9%)E<W5L=%LD8VUD241=(#T@)&-M9%1Y<&4["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#:&5C:R!I9B!T:&5R92!A<F4@86YY('!E;F1I;F<@96QE;65N
M=',@=&AA="!H879E(&YO="!B965N('-E;G0@=&\@9'5E"B`@("`@*B!T;R!M
M97-S86=E('-I='IE(')E<W1R:6-T:6]N<RX@5&AE<V4@=VEL;"!B92!S96YT
M(&EN="!T:&4@;F5X="!M<V<N"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO
M;B!H87-096YD:6YG16QE;65N=',H*0H@("`@>PH*("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]S>6YC<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]S>6YC<R!A<R`D<WEN8RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1S>6YC+3YH87-096YD:6YG16QE;65N=',H*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@86QL('-Y;F-S('=H:6-H(&AA=F4@
M<&5N9&EN9R!E;&5M96YT<R!L969T+@H@("`@("H@4F5T=7)N<R!A;B!A<G)A
M>2!O9B!487)G971,;V-54DES('=H:6-H(&-A;B!B92!U<V5D"B`@("`@*B!A
M<R!A(&ME>2!I;B!G9713>6YC(&-A;&QS+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971096YD:6YG4WEN8W,H*0H@("`@>PH@("`@("`@("1R(#T@87)R87DH
M*3L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]S>6YC<RDI('L*("`@
M("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]S>6YC<R!A<R`D=&%R9V5T(#T^
M("1S>6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)'-Y;F,M/FAA<U!E;F1I
M;F=%;&5M96YT<R@I*2!["B`@("`@("`@("`@("`@("`@("`@)');72`]("1T
M87)G970["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R.PH@("`@?0I]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O
M4WEN8TU,+T)A8VME;F0N<&AP````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-3<T-30@,3`U,34T,S0Q,S8@,#(Q-3(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!3>6YC34P@0F%C:V5N9"!F;W(@=&AE($AO<F1E($%P<&QI8V%T:6]N(&9R
M86UE=V]R:RX*("H*("H@5&AE(&)A8VME;F0@<')O=FED97,@=&AE(&9O;&QO
M=VEN9R!F=6YC=&EO;F%L:71Y.@H@*@H@*B`Q*2!H86YD;&EN9R!O9B!T:&4@
M86-T=6%L(&1A=&$L(&DN92X*("H@("`@82D@861D+W)E<&QA8V4O9&5L971E
M(&5N=')I97,@=&\@86YD(')E=')I979E(&5N=')I97,@9G)O;2!T:&4*("H@
M("`@("`@8F%C:V5N9`H@*B`@("!B*2!R971R:65V92!H:7-T;W)Y('1O(&9I
M;F0@;W5T('=H870@96YT<FEE<R!H879E(&)E96X@8VAA;F=E9`H@*B`R*2!M
M86YA9VEN9R!O9B!T:&4@;6%P(&)E='=E96X@8VQI96YD($E$<R!A;F0@<V5R
M=F5R($E$<PH@*B`S*2!S=&]R92!I;F9O<FUA=&EO;B!A8F]U="!S>6YC(&%N
M8VAO<G,@*'1I;65S=&%M<',I(&]F('!R979I;W5S"B`J("`@('-U8V-E<W-F
M=6QS('-Y;F,@<V5S<VEO;G,*("H@-"D@<V5S<VEO;B!H86YD;&EN9R`H;F]T
M('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@-2D@875T:&]R:7-A=&EO;B`H
M;F]T('EE="P@<W1I;&P@=&\@8F4@9&]N92D*("H@-BD@;&]G9VEN9PH@*@H@
M*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T
M96Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]0
M64E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D
M:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M
M97=O<FLO4WEN8TU,+U-Y;F--3"]"86-K96YD+G!H<"QV(#$N."XR+C@@,C`P
M-B\P-R\Q."`Q,CHP,#HU-B!J86X@17AP("0*("H*("H@0&%U=&AO<B`@2V%R
M<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E
M(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T)A8VME;F1?2&]R9&4@>PH*("`@
M("\J*@H@("`@("H@06X@87)R87D@87,@=F%L=64@:6YD:6-A=&5S('1H870@
M9F]R('1H:7,@8VQI96YT(&-A=&5G;W)Y(&YO"B`@("`@*B!S97)V97(@8V%T
M96=O<GD@:7,@9&5F:6YE9"!Y970N(%1H92!A<G)A>2!C;VYT96YT(&ES('1H
M90H@("`@("H@<W5M;6%R>2!T97AT(&]F('1H92!L87-T(&5N8V]U;G1E<F5D
M(&-L:65N="!E;G1R>2!T:&%T('5S960*("`@("`J('1H:7,@8V%T96=O<GDN
M"B`@("`@*@H@("`@("H@("!K97DZ("`@8VQI96YT0V%T96=O<GD*("`@("`J
M("`@=F%L=64Z('-E<G9E<D-A=&5G;W)Y"B`@("`@*B\*("`@('9A<B`D7V-A
M=&5G;W)I97--87`["@H@("`@+RHJ"B`@("`@*B!397)V97(@8V%T96=O<FEE
M<R!M:7-S:6YG(&]N('1H92!C;&EE;G0N"B`@("`@*@H@("`@("H@("!K97DZ
M("`@<V5R=F5R0V%T96=O<GD*("`@("`J("`@=F%L=64Z('-U;6UA<GD@;V8@
M;&%S="!E;G1R>2!W:71H('1H:7,@8V%T96=O<GD*("`@("`J+PH@("`@=F%R
M("1?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,["@H@("`@=F%R("1?9&%T871R
M964["@H@("`@+RHJ"B`@("`@*B!#86-H92!F;W(@1&%T871R964@=F%L=65S
M"B`@("`@*B\*("`@("`*("`@('9A<B`D7V-A8VAE.PH@("`@"B`@("!F=6YC
M=&EO;B!3>6YC34Q?0F%C:V5N9%](;W)D92@I"B`@("!["B`@("`@("`@)&1R
M:79E<B`]("1'3$]"04Q36R=C;VYF)UU;)V1A=&%T<F5E)UU;)V1R:79E<B==
M.PH@("`@("`@("1P87)A;7,@/2!(;W)D93HZ9V5T1')I=F5R0V]N9FEG*"=D
M871A=')E92<L("1D<FEV97(I.PH@("`@("`@("1P87)A;7,@/2!A<G)A>5]M
M97)G92@D<&%R86US+"!A<G)A>2@G9W)O=7`G(#T^("=S>6YC;6PG*2D["@H@
M("`@("`@("1T:&ES+3Y?9&%T871R964@/28@1&%T851R964Z.G-I;F=L971O
M;B@D9')I=F5R+"`D<&%R86US*3L*("`@("`@("`D=&AI<RT^7V-A8VAE(#T@
M87)R87DH*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E=')I979E<R!A;B!E
M;G1R>2!F<F]M('1H92!B86-K96YD+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&1A=&%B87-E("`@1&%T86)A<V4@=&\@<V-A;BX@:2YE+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C
M;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D<W5I9"`@("`@
M("!397)V97(@=6YI<75E(&ED(&]F('1H92!E;G1R>3H@9F]R(&AO<F1E"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@('1H:7,@:7,@=&AE(&=U
M:60N"B`@("`@*B!`<&%R86T@<W1R:6YG(&-O;G1E;G14>7!E($-O;G1E;G0M
M5'EP93H@=&AE(&UI;64@='EP92!I;B!W:&EC:"!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9G5N8W1I;VX@<VAA;&P@<F5T=7)N('1H
M92!D871A"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@("`@("`@("`@
M("!!('-T<FEN9R!W:71H('1H92!D871A(&5N=')Y(&]R"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&]R(&$@4$5!4E]%<G)O<B!O8FIE8W0N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E=')I979E16YT<GDH)&1A=&%B87-E
M+"`D<W5I9"P@)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(')E='5R;B`D
M1TQ/0D%,4ULG<F5G:7-T<GDG72T^8V%L;"@D9&%T86)A<V4@+B`G+V5X<&]R
M="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=G=6ED)R`]/B`D<W5I9"P@)V-O;G1E;G14>7!E)R`]/B`D8V]N
M=&5N=%1Y<&4I*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!E;G1R:65S
M('1H870@:&%V92!B965N(&UO9&EF:65D(&EN('1H92!S97)V97(@9&%T86)A
M<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<WEN8TED96YT:69I
M97(@($ED96YT:69I97,@=&AE(&-L:65N="!D979I8V4@=&\@86QL;W<@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E<B!T
M;R!S>6YC('=I=&@@9&EF9F5R96YT(&1E=FEC97,N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@3F]R;6%L;'D@=&AE(%-O=7)C9552
M22!F<F]M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%-Y;F-(96%D97(*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&%B87-E
M("`@("`@("!$871A8F%S92!T;R!S8V%N+B!I+F4N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%L96YD87(O=&%S:W,O8V]N=&%C
M=',O;F]T97,*("`@("`J($!P87)A;2!I;G1E9V5R("1F<F]M7W1S("`@("`@
M("!3=&%R="!T:6UE<W1A;7`N"B`@("`@*B!`<&%R86T@:6YT96=E<B`D=&]?
M=',@("`@("`@("`@17AC;'5S:79E(&5N9"!T:6UE<W1A;7`N($YO="!Y970*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I;7!L96UE
M;G1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!014%27T5R<F]R
M(&]R(&%S<V]C(&%R<F%Y(&]F(&-H86YG97,@=VET:"!K97D]<W5I9"P*("`@
M("`J("`@("`@("`@("`@("`@('9A;'5E/6-U:60N($EF(&YO(&-U:60@8V%N
M(&)E(&9O=6YD(&9O<B!A('-U:60L('9A;'5E(&ES"B`@("`@*B`@("`@("`@
M("`@("`@("!N=6QL+B!4:&5N(&$@4WEN8R!!9&0@8V]M;6%N9"!H87,@=&\@
M8F4@8W)E871E9"!T;R!A9&0*("`@("`J("`@("`@("`@("`@("`@('1H:7,@
M96YT<GD@:6X@=&AE(&-L:65N="!D871A8F%S92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T4V5R=F5R36]D:69I8V%T:6]N<R@D<WEN8TED96YT:69I97(L
M("1D871A8F%S92P@)&9R;VU?=',L("1T;U]T<RD*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("!I9B`H)&9R;VU?=',@/3T@,"D@
M>PH@("`@("`@("`@("`O+R!#;VUP;&5T92!S>6YC.B!E=F5R>71H:6YG(&ES
M('-E;G0@9'5R:6YG"B`@("`@("`@("`@("\O(&=E=%-E<G9E<D%D9&ET:6]N
M<RX@3F\@;F5E9"!T;R!S96YD(&UO9&EF:6-A=&EO;G,N"B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T(&-H
M86YG97,N"B`@("`@("`@)&-H86YG97,@/2`D<F5G:7-T<GDM/F-A;&PH)&1A
M=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A8W1I;VXG(#T^("=M;V1I9GDG
M+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI.PH@("`@("`@(&EF("AI<U]A
M*"1C:&%N9V5S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T:&ES
M+3YL;V=-97-S86=E*")3>6YC34PZ("1D871A8F%S92]L:7-T0GD@9F%I;&5D
M(&9O<B!M;V1I9GDZ(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N
M("1C:&%N9V5S+3YG971-97-S86=E*"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?5T%23DE.
M1RD["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*"B`@
M("`@("`@)'(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D8VAA;F=E
M<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D<W5I9%]T<R`]("1R96=I<W1R
M>2T^8V%L;"@D9&%T86)A<V4@+B`G+V=E=$%C=&EO;E1I;65S=&%M<"<L(&%R
M<F%Y*"1S=6ED+"`G;6]D:69Y)RDI.PH@("`@("`@("`@("`D<WEN8U]T<R`]
M("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D871A8F%S
M92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y;F-?=',@)B8@)'-Y;F-?
M=',@/CT@)'-U:61?=',I('L*("`@("`@("`@("`@("`@("\O($-H86YG92!W
M87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@8VQI96YT+@H@("`@("`@
M("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@8F%C:R!T;R!T:&4@8VQI
M96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(F-H86YG
M93H@)'-U:60@:6=N;W)E9"P@8V%M92!F<F]M(&-L:65N="(L(%]?1DE,15]?
M+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-U:60@/2`D
M=&AI<RT^9V5T0W5I9"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)'-U
M:60I.PH@("`@("`@("`@("!I9B`H(21C=6ED*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G365S<V%G92@B56YA8FQE('1O(&-R96%T92!C:&%N9V4@
M9F]R("1S=6ED.B!C;&EE;G0M:60@;F]T(&9O=6YD(&EN(&UA<"X@5')Y:6YG
M(&%D9"!I;G-T96%D+B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@
M("`@("`@("`@("`@("`@)');)'-U:61=(#T@;G5L;#L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1R6R1S=6ED72`]("1C=6ED.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@96YT<FEE<R!T:&%T(&AA=F4@8F5E
M;B!D96QE=&5D(&9R;VT@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1D871A8F%S92`@1&%T86)A<V4@=&\@<V-A
M;BX@:2YE+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N
M9&%R+W1A<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@:6YT96=E
M<B`D9G)O;5]T<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'1O7W1S("`@($5X
M8VQU<VEV90H@("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!%05)?17)R
M;W(@;W(@87-S;V,@87)R87D@;V8@9&5L971I;VYS('=I=&@@:V5Y/7-U:60L
M"B`@("`@*B`@("`@("`@("`@("`@("!V86QU93UC=6ED+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971397)V97)$96QE=&EO;G,H)'-Y;F-)9&5N=&EF:65R
M+"`D9&%T86)A<V4L("1F<F]M7W1S+"`D=&]?=',I"B`@("!["B`@("`@("`@
M9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@:68@*"1F<F]M7W1S(#T](#`I
M('L*("`@("`@("`@("`@+R\@0V]M<&QE=&4@<WEN8SH@979E<GET:&EN9R!I
M<R!S96YT(&1U<FEN9PH@("`@("`@("`@("`O+R!G971397)V97)!9&1I=&EO
M;G,N("!.;R!N965D('1O('-E;F0@9&5L971I;VYS+@H@("`@("`@("`@("!R
M971U<FX@87)R87DH*3L*("`@("`@("!]"@H@("`@("`@("\O($=E="!D96QE
M=&EO;G,N"B`@("`@("`@)&1E;&5T97,@/2`D<F5G:7-T<GDM/F-A;&PH)&1A
M=&%B87-E+B`G+VQI<W1">2<L(&%R<F%Y*"=A8W1I;VXG(#T^("=D96QE=&4G
M+"`G=&EM97-T86UP)R`]/B`D9G)O;5]T<RDI.PH*("`@("`@("!I9B`H:7-?
M82@D9&5L971E<RP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^;&]G365S<V%G92@B4WEN8TU,.B`D9&%T86)A<V4O;&ES=$)Y(&9A:6QE
M9"!F;W(@9&5L971E.B(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`D9&5L971E<RT^9V5T365S<V%G92@I+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7U=!4DY)
M3D<I.PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*("`@("`@("!]"@H@
M("`@("`@("1R(#T@87)R87DH*3L*"B`@("`@("`@9F]R96%C:"`H)&1E;&5T
M97,@87,@)'-U:60I('L*("`@("`@("`@("`@)'-U:61?=',@/2`D<F5G:7-T
M<GDM/F-A;&PH)&1A=&%B87-E+B`G+V=E=$%C=&EO;E1I;65S=&%M<"<L(&%R
M<F%Y*"1S=6ED+"`G9&5L971E)RDI.PH@("`@("`@("`@("`D<WEN8U]T<R`]
M("1T:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D871A8F%S
M92P@)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y;F-?=',@)B8@)'-Y;F-?
M=',@/CT@)'-U:61?=',I('L*("`@("`@("`@("`@("`@("\O($-H86YG92!W
M87,@9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@8VQI96YT+@H@("`@("`@
M("`@("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@8F%C:R!T;R!T:&4@8VQI
M96YT+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(E-Y;F--
M3#H@9&5L971E("1S=6ED(&EG;F]R960L(&-A;64@9G)O;2!C;&EE;G0B+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C
M=6ED(#T@)'1H:7,M/F=E=$-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A
M<V4L("1S=6ED*3L*("`@("`@("`@("`@:68@*"$D8W5I9"D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(E5N86)L92!T;R!C<F5A=&4@
M9&5L971E(&9O<B`D<W5I9#H@;&]C:60@;F]T(&9O=6YD(&EN(&UA<"(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("`@("`@8V]N
M=&EN=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1R6R1S=6ED72`]
M("1C=6ED.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T(&5N=')I97,@=&AA="!H879E(&)E96X@861D
M960@=&\@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1D871A8F%S92`@1&%T86)A<V4@=&\@<V-A;BX@:2YE+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N9&%R+W1A<VMS
M+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@:6YT96=E<B`D9G)O;5]T
M<PH@("`@("H@0'!A<F%M(&EN=&5G97(@)'1O7W1S("`@($5X8VQU<VEV90H@
M("`@("H*("`@("`J($!R971U<FX@87)R87D@(%!%05)?17)R;W(@;W(@87-S
M;V,@87)R87D@;V8@9&5L971I;VYS('=I=&@@:V5Y/7-U:60L"B`@("`@*B`@
M("`@("`@("`@("`@("!V86QU93TP+B`H87)R87D@<W1Y;&4@:7,@8VAO<V5N
M('1O(&UA=&-H(&-H86YG92`F(&1E;"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4V5R=F5R061D:71I;VYS*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E
M+"`D9G)O;5]T<RP@)'1O7W1S*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G
M:7-T<GD["@H@("`@("`@(&EF("@D9G)O;5]T<R`]/2`P*2!["B`@("`@("`@
M("`@("\O(%)E='5R;B!A;&P@9&(@96YT<FEE<R!D:7)E8W1L>2!R871H97(@
M=&AA;B!B;W1H97(*("`@("`@("`@("`@+R\@:&ES=&]R>3H*("`@("`@("`@
M("`@)&%D9',@/2`D<F5G:7-T<GDM/F-A;&PH)&1A=&%B87-E+B`G+VQI<W0G
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D861D<R`]("1R96=I
M<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O;&ES=$)Y)RP@87)R87DH)V%C=&EO
M;B<@/3X@)V%D9"<L("=T:6UE<W1A;7`G(#T^("1F<F]M7W1S*2D["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?82@D861D<RP@)U!%05)?17)R;W(G*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B4WEN8TU,.B`D9&%T
M86)A<V4O;&ES=$)Y(&9A:6QE9"!F;W(@861D.B(*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`D861D<RT^9V5T365S<V%G92@I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7U=!4DY)3D<I.PH@("`@("`@("`@("!R971U<FX@87)R87DH*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=A9&0@;6]D
M:69I8V%T:6]N<R!R971R:65V960N(&-O=6YT/2<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`N(&-O=6YT*"1A9&1S*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M"B`@("`@("`@)'(@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E86-H("@D861D
M<R!A<R`D<W5I9"D@>PH@("`@("`@("`@("`D<W5I9%]T<R`]("1R96=I<W1R
M>2T^8V%L;"@D9&%T86)A<V4@+B`G+V=E=$%C=&EO;E1I;65S=&%M<"<L(&%R
M<F%Y*"1S=6ED+"`G861D)RDI.PH@("`@("`@("`@("`D<WEN8U]T<R`]("1T
M:&ES+3YG971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@
M)'-U:60I.PH@("`@("`@("`@("!I9B`H)'-Y;F-?=',@)B8@)'-Y;F-?=',@
M/CT@)'-U:61?=',I('L*("`@("`@("`@("`@("`@("\O($-H86YG92!W87,@
M9&]N92!B>2!U<R!U<&]N(')E<75E<W0@;V8@8VQI96YT+@H@("`@("`@("`@
M("`@("`@+R\@1&]N)W0@;6ER<F]R('1H870@8F%C:R!T;R!T:&4@8VQI96YT
M+@H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(F%D9#H@)'-U
M:60@:6=N;W)E9"P@8V%M92!F<F]M(&-L:65N="(L(%]?1DE,15]?+"!?7TQ)
M3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`@("`@8V]N=&EN
M=64["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C=6ED(#T@)'1H:7,M
M/F=E=$-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1S=6ED*3L*
M"B`@("`@("`@("`@(&EF("@D8W5I9"`F)B`D9G)O;5]T<R`]/2`P*2!["B`@
M("`@("`@("`@("`@("`O+R!&;W(@<VQO=R!S>6YC("AT<R`](#`I+"!D;R!N
M;W0@861D(&1A=&$@9F]R('=H:6-H"B`@("`@("`@("`@("`@("`O+R!W92!H
M879E(&$@;&]C:60@86=A:6XN(%1H:7,@:7,@82!H975R:7-T:6,@=&\*("`@
M("`@("`@("`@("`@("\O(&%V;VED(&1U<&QI8V%T:6]N(&]F(&5N=')I97,N
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B<VMI<'!I;F<@
M861D(&]F(&=U:60@)'-U:60@87,@=&AE<F4@86QR96%D>2!I<R!A(&-U:60@
M)&-U:60B+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@("1R6R1S=6ED72`](#`["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&5N=')Y(&EN
M=&\@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1D871A8F%S92`@("`@1&%T86)A<V4@=VAE<F4@=&\@861D+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-A;&5N9&%R+W1A
M<VMS+V-O;G1A8W1S+VYO=&5S"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT("`@("`@5&AE(&%C='5A;"!D871A"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1C;VYT96YT5'EP92`@36EM971Y<&4@;V8@)&-O;G1E;G0*("`@("`J($!P
M87)A;2!S=')I;F<@)&-U:60@("`@("`@("!#;&EE;G0@240@;V8@=&AI<R!E
M;G1R>2`H9F]R(&UA<"D*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0
M14%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&YE=R!E;G1R>0H@
M("`@("HO"B`@("!F=6YC=&EO;B!I;7!O<G1%;G1R>2@D<WEN8TED96YT:69I
M97(L("1D871A8F%S92P@)&-O;G1E;G0L("1C;VYT96YT5'EP92P@)&-U:60I
M"B`@("!["B`@("`@("`@9VQO8F%L("1R96=I<W1R>3L*"B`@("`@("`@)'1A
M<VMS86YD8V%L96YD87)C;VUB:6YE9"`](&9A;'-E.PH*("`@("`@("`O+R!#
M:&5C:W,@:68@=&AE(&-L:65N="!S96YD<R!U<R!A('9T;V1O(&EN(&$@8V%L
M96YD87(@<WEN8SH*("`@("`@("!I9B`H)&1A=&%B87-E(#T]("=C86QE;F1A
M<B<*("`@("`@("`@("`@("8F('!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE"
M14=)3EM>.ETJ.E943T1/+R<L(")<;B(@+B`D8V]N=&5N="DI('L*("`@("`@
M("`@("`@)'-E<G9E<F1A=&%B87-E(#T@)W1A<VMS)SL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D<V5R=F5R9&%T86)A<V4@/2`D9&%T86)A<V4[
M"B`@("`@("`@?0H*("`@("`@("`D<W5I9"`]("1R96=I<W1R>2T^8V%L;"@D
M<V5R=F5R9&%T86)A<V4@+B`G+VEM<&]R="<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92DI
M.PH*("`@("`@("`D=&AI<RT^;&]G365S<V%G92@B861D('1O('-E<G9E<B!D
M8B`D<V5R=F5R9&%T86)A<V4@8W5I9"`D8W5I9"`M/B!S=6ED("1S=6ED(BP@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@
M(&EF("@A:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D=',@/2`D<F5G:7-T<GDM/F-A;&PH)'-E<G9E<F1A=&%B87-E+B`G+V=E
M=$%C=&EO;E1I;65S=&%M<"<L(&%R<F%Y*"1S=6ED+"`G861D)RDI.PH@("`@
M("`@("`@("!I9B`H(21T<RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9TUE<W-A9V4H)U5N86)L92!T;R!F:6YD(&%D9"UT<R!F;W(@)R`N("1S=6ED
M("X@)R!A="`G("X@)'1S+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'
M7T524BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F-R96%T
M955I9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-U:60L("1S
M=6ED+"`D=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S=6ED.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1&5L971E<R!A;B!E;G1R>2!F<F]M('1H
M92!S97)V97(@9&%T86)A<V4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9&%T86)A<V4@($1A=&%B87-E('=H97)E('1O(&%D9"X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!C86QE;F1A<B]T87-K<R]C;VYT86-T
M<R]N;W1E<PH@("`@("H@0'!A<F%M('-T<FEN9R`D8W5I9"`@("`@($-L:65N
M="!)1"!O9B!T:&4@96YT<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!014%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&1E;&5T960@
M96YT<GDN"B`@("`@*B\*("`@(&9U;F-T:6]N(&1E;&5T945N=')Y*"1S>6YC
M261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I9"D*("`@('L*("`@("`@("!G
M;&]B86P@)')E9VES=')Y.PH*("`@("`@("`O+R!&:6YD('-E<G9E<B!)1"!F
M;W(@=&AI<R!E;G1R>3H*("`@("`@("`D<W5I9"`]("1T:&ES+3YG9713=6ED
M*"1S>6YC261E;G1I9FEE<BP@)&1A=&%B87-E+"`D8W5I9"D["B`@("`@("`@
M:68@*"%I<U]A*"1S=6ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@
M("1R96=I<W1R>2T^8V%L;"@D9&%T86)A<V4N("<O9&5L971E)RP@87)R87DH
M)'-U:60I*3L*("`@("`@("`@("`@)'1S(#T@)')E9VES=')Y+3YC86QL*"1D
M871A8F%S92`N("<O9V5T06-T:6]N5&EM97-T86UP)RP@87)R87DH)'-U:60L
M("=D96QE=&4G*2D["B`@("`@("`@("`@("\O(%=E(&-A;B=T(')E;6]V92!T
M:&4@;6%P<&EN9R!E;G1R>2!A<R!W92!N965D('1O(&ME97`*("`@("`@("`@
M("`@+R\@=&AE('1I;65S=&%M<"!I;F9O<FUA=&EO;BX*("`@("`@("`@("`@
M)'1H:7,M/F-R96%T955I9$UA<"@D<WEN8TED96YT:69I97(L("1D871A8F%S
M92P@)&-U:60L("1S=6ED+"`D=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S=6ED.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5P;&%C97,@86X@
M96YT<GD@:6X@=&AE('-E<G9E<B!D871A8F%S92X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1D871A8F%S92`@("`@1&%T86)A<V4@=VAE<F4@=&\@
M<F5P;&%C92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M86QE;F1A<B]T87-K<R]C;VYT86-T<R]N;W1E<PH@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]N=&5N="`@("`@(%1H92!A8W1U86P@9&%T80H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@($UI;65T>7!E(&]F("1C;VYT96YT
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1C=6ED("`@("`@("`@0VQI96YT($E$
M(&]F('1H:7,@96YT<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!0
M14%27T5R<F]R(&]R('-U:60@*$AO<F1E(&=U:60I(&]F(&UO9&EF:65D(&5N
M=')Y+@H@("`@("HO"B`@("!F=6YC=&EO;B!R97!L86-E16YT<GDH)'-Y;F-)
M9&5N=&EF:65R+"`D9&%T86)A<V4L("1C;VYT96YT+"`D8V]N=&5N=%1Y<&4L
M("1C=6ED*0H@("`@>PH@("`@("`@(&=L;V)A;"`D<F5G:7-T<GD["@H@("`@
M("`@("\O($-H96-K<R!I9B!T:&4@8VQI96YT('-E;F1S('5S(&$@=G1O9&\@
M:6X@82!C86QE;F1A<B!S>6YC.@H@("`@("`@(&EF("@D9&%T86)A<V4@/3T@
M)V-A;&5N9&%R)PH@("`@("`@("`@("`@)B8@<')E9U]M871C:"@G+RA<<EQN
M?%QR?%QN*4)%1TE.6UXZ72HZ5E1/1$\O)RP@(EQN(B`N("1C;VYT96YT*2D@
M>PH@("`@("`@("`@("`D<V5R=F5R9&%T86)A<V4@/2`G=&%S:W,G.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1S97)V97)D871A8F%S92`]("1D
M871A8F%S93L*("`@("`@("!]"@H@("`@("`@("1S=6ED(#T@)'1H:7,M/F=E
M=%-U:60H)'-Y;F-)9&5N=&EF:65R+"`D9&%T86)A<V4L("1C=6ED*3L*"B`@
M("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H(G)E<&QA8V4@:6X@9&(@)'-E<G9E
M<F1A=&%B87-E(&-U:60@)&-U:60@<W5I9"`D<W5I9"(L(%]?1DE,15]?+"!?
M7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@("`@("!I9B`H)'-U:60I
M('L*("`@("`@("`@("`@+R\@16YT<GD@97AI<W1S.B!R97!L86-E(&-U<G)E
M;G0@;VYE+@H@("`@("`@("`@("`D;VL@/2`D<F5G:7-T<GDM/F-A;&PH)'-E
M<G9E<F1A=&%B87-E("X@)R]R97!L86-E)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"1S=6ED+"`D8V]N=&5N="P@)&-O;G1E
M;G14>7!E*2D["B`@("`@("`@("`@(&EF("AI<U]A*"1O:RP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1O:SL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D=',@/2`D<F5G:7-T<GDM/F-A;&PH)'-E<G9E
M<F1A=&%B87-E("X@)R]G971!8W1I;VY4:6UE<W1A;7`G+"!A<G)A>2@D<W5I
M9"P@)VUO9&EF>2<I*3L*("`@("`@("`@("`@)'1H:7,M/F-R96%T955I9$UA
M<"@D<WEN8TED96YT:69I97(L("1D871A8F%S92P@)&-U:60L("1S=6ED+"`D
M=',I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!M87`@96YT<GD@9F]U;F0G*3L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D<W5I9#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E=')I979E<R!I;F9O<FUA=&EO;B!A8F]U="!T:&4@<')E=FEO=7,@<WEN
M8R!I9B!A;GDN(%)E='5R;G,*("`@("`J(&9A;'-E(&EF(&YO(&EN9F\@9F]U
M;F0@;W(@82!$871E5')E94]B:F5C="!W:71H(&%T(&QE87-T('1H90H@("`@
M("H@9F]L;&]W:6YG(&%T=')I8G5T97,Z"B`@("`@*@H@("`@("H@0VQI96YT
M06YC:&]R.B!T:&4@8VQI96YT<R!.97AT($%N8VAO<B!O9B!T:&4@<')E=FEO
M=7,@<WEN8RX*("`@("`J(%-E<G9E<D%N8VAO<CH@=&AE(%-E<G9E<B!.97AT
M($%N8VAO<B!O9B!T:&4@<')E=FEO=7,@<WEN8RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F=E=%-Y;F-3=6UM87)Y*"1S>6YC261E;G1I9FEE<BP@)'1Y<&4I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?9V5T3V(H)'-Y;F-)9&5N
M=&EF:65R("X@)SIS=6UM87)Y.B<@+B`D='EP92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!9G1E<B!A('-U8V-E<W-F=6P@<WEN8RP@=&AE(&-L:65N="!A
M;F0@<V5R=F5R)W,@3F5X="!!;F-H;W)S"B`@("`@*B!A<F4@=W)I='1E;B!T
M;R!T:&4@9&%T86)A<V4@<V\@=&AE>2!C86X@8F4@=7-E9"!T;R!N96=O=&EA
M=&4*("`@("`J('5P8V]M:6YG('-Y;F-S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!W<FET95-Y;F-3=6UM87)Y*"1S>6YC261E;G1I9FEE<BP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-L:65N=$%N8VAO<DYE>'0L("1S97)V
M97)!;F-H;W).97AT*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'-E<G9E
M<D%N8VAO<DYE>'0I('Q\("%I<U]A<G)A>2@D<V5R=F5R06YC:&]R3F5X="DI
M('L*("`@("`@("`@("`@)'1H:7,M/FQO9TUE<W-A9V4H)U-Y;F--3"!I;G1E
M<FYA;"!E<G)O<CH@;F\@86YC:&]R('!R;W9I9&5D("<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+B`G:6X@=W)I=&53>6YC4W5M;6%R>2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("`@("`@9&EE*"=3>6YC34P@:6YT
M97)N86P@97)R;W(Z(&YO(&%N8VAO<B!P<F]V:61E9"!I;B!W<FET95-Y;F-3
M=6UM87)Y)RD["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("AA<G)A>5]K
M97ES*"1S97)V97)!;F-H;W).97AT*2!A<R`D='EP92D@>PH@("`@("`@("`@
M("`D<R`]("1S>6YC261E;G1I9FEE<B`N("<Z<W5M;6%R>3HG("X@)'1Y<&4[
M"@H@("`@("`@("`@("`O+R!3970@)&QO8VED+@H@("`@("`@("`@("`D:6YF
M;R`]("9N97<@1&%T851R965/8FIE8W0H)',I.PH@("`@("`@("`@("`D:6YF
M;RT^<V5T*"=#;&EE;G1!;F-H;W(G+"`D8VQI96YT06YC:&]R3F5X="D["B`@
M("`@("`@("`@("1I;F9O+3YS970H)U-E<G9E<D%N8VAO<B<L("1S97)V97)!
M;F-H;W).97AT*3L*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E
M+3YA9&0H)&EN9F\I.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@
M97AI<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&%T871R964M/G5P9&%T941A=&$H)&EN9F\I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1T:&ES+3Y?8V%C:&5;)&EN9F\M/F=E=$YA;64H*5T@
M/2`D:6YF;SL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A
M=&4@82!M87`@96YT<FEE<R!T;R!M87`@8F5T=V5E;B!S97)V97(@86YD(&-L
M:65N="!)1',N"B`@("`@*@H@("`@("H@4'5T<R!A(&=I=F5N(&-L:65N="`D
M8W5I9"!A;F0@2&]R9&4@<V5R=F5R("1S=6ED('!A:7(@:6YT;R!T:&4*("`@
M("`J(&UA<"!T86)L92!T;R!A;&QO=R!M87!P:6YG(&)E='=E96X@=&AE(&-L
M:65N="=S(&%N9"!S97)V97(G<PH@("`@("H@241S+B`@06-T=6%L;'D@=&AE
M<F4@87)E('1W;R!M87!S.B!F<F]M('1H92!S=6ED('1O('1H92!C=6ED"B`@
M("`@*B!A;F0@=FEC92!V97)S82X*("`@("`J($EF(&%N(&5N=')Y(&%L<F5A
M9'D@97AI<W1S+"!I="!I<R!O=F5R=W)I='1E;BX*("`@("`J+PH@("`@9G5N
M8W1I;VX@8W)E871E56ED36%P*"1S>6YC261E;G1I9FEE<BP@)'1Y<&4L("1C
M=6ED+"`D<W5I9"P@)'1S/3`I"B`@("!["B`@("`@("`@+R\@4V5T("1C=6ED
M+@H@("`@("`@("1G:60@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1S>6YC261E
M;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@
M("1G:60M/G-E="@G9&%T87-T;W)E)RP@)'1Y<&4I.PH@("`@("`@("1G:60M
M/G-E="@G8W5I9"<L("1C=6ED*3L*("`@("`@("`D9VED+3YS970H)W1S)RP@
M)'1S*3L*"B`@("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YA9&0H)&=I
M9"D["B`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@
M("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@97AI<W1S.B!U<&1A=&4@:6YS
M=&5A9"X*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7V1A=&%T<F5E+3YU<&1A
M=&5$871A*"1G:60I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V-A8VAE
M6R1G:60M/F=E=$YA;64H*5T@/2`D9VED.PH@("`@("`@("1T:&ES+3YD:65/
M;D5R<F]R*"1R+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`O+R!3
M970@)&=L;V)A;'5I9`H@("`@("`@("1L:60@/2`F;F5W($1A=&%4<F5E3V)J
M96-T*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+B`G.F-U:60R<W5I9#HG("X@)&-U
M:60I.PH@("`@("`@("1L:60M/G-E="@G<W5I9"<L("1S=6ED*3L*("`@("`@
M("`D<B`]("1T:&ES+3Y?9&%T871R964M/F%D9"@D;&ED*3L*("`@("`@("!I
M9B`H:7-?82@D<BP@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`O+R!/
M8FIE8W0@86QR96%D>2!E>&ES=',Z('5P9&%T92!I;G-T96%D+@H@("`@("`@
M("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M/G5P9&%T941A=&$H)&QI9"D[
M"B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?8V%C:&5;)&QI9"T^9V5T3F%M
M92@I72`]("1L:60["B`@("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("\O($EF('1A<VMS(&%N9"!E
M=F5N=',@87)E(&AA;F1L960@870@;VYC92P@=V4@;F5E9"!T;R!S=&]R90H@
M("`@("`@("\O('1H92!M87`@96YT<GD@:6X@8F]T:"!D871A8F%S97,Z"B`@
M("`@("`@)'-E<W-I;VX@/28@)%]315-324].6R=3>6YC34PN<W1A=&4G73L*
M("`@("`@("`D9&5V:6-E(#TF("1S97-S:6]N+3YG971$979I8V4H*3L*"B`@
M("`@("`@:68@*"1D979I8V4M/FAA;F1L951A<VMS26Y#86QE;F1A<B@I"B`@
M("`@("`@("`@("8F("@D='EP92`]/2`G=&%S:W,G('Q\("1T>7!E(#T]("=C
M86QE;F1A<B<I("D@>PH@("`@("`@("`@("`D='EP92`]("1T>7!E(#T]("=T
M87-K<R<@/R`G8V%L96YD87(G(#H@)W1A<VMS)R`[("\O('1H92!O=&AE<B!O
M;F4*"B`@("`@("`@("`@("\O(%-E="`D8W5I9"X*("`@("`@("`@("`@)&=I
M9"`]("9N97<@1&%T851R965/8FIE8W0H)'-Y;F-)9&5N=&EF:65R("X@)SHG
M("X@)'1Y<&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G.G-U:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@("`@("`D9VED
M+3YS970H)V1A=&%S=&]R92<L("1T>7!E*3L*("`@("`@("`@("`@)&=I9"T^
M<V5T*"=C=6ED)RP@)&-U:60I.PH@("`@("`@("`@("`D9VED+3YS970H)W1S
M)RP@)'1S*3L*"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]D871A=')E92T^
M861D*"1G:60I.PH@("`@("`@("`@("!I9B`H:7-?82@D<BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@("`@("`@("`@("`@+R\@3V)J96-T(&%L<F5A9'D@97AI
M<W1S.B!U<&1A=&4@:6YS=&5A9"X*("`@("`@("`@("`@("`@("1R(#T@)'1H
M:7,M/E]D871A=')E92T^=7!D871E1&%T82@D9VED*3L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7V-A8VAE6R1G:60M/F=E=$YA;64H*5T@
M/2`D9VED.PH@("`@("`@("`@("`D=&AI<RT^9&EE3VY%<G)O<B@D<BP@7U]&
M24Q%7U\L(%]?3$E.15]?*3L*"B`@("`@("`@("`@("\O(%-E="`D9VQO8F%L
M=6ED"B`@("`@("`@("`@("1L:60@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1S
M>6YC261E;G1I9FEE<B`N("<Z)R`N("1T>7!E"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)SIC=6ED,G-U:60Z)R`N("1C=6ED
M*3L*("`@("`@("`@("`@)&QI9"T^<V5T*"=S=6ED)RP@)'-U:60I.PH@("`@
M("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M/F%D9"@D;&ED*3L*("`@
M("`@("`@("`@:68@*&ES7V$H)'(L("=014%27T5R<F]R)RDI('L*("`@("`@
M("`@("`@("`@("\O($]B:F5C="!A;')E861Y(&5X:7-T<SH@=7!D871E(&EN
M<W1E860N"B`@("`@("`@("`@("`@("`D<B`]("1T:&ES+3Y?9&%T871R964M
M/G5P9&%T941A=&$H)&QI9"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/E]C86-H95LD;&ED+3YG971.86UE*"E=(#T@)&QI9#L*("`@("`@
M("`@("`@)'1H:7,M/F1I94]N17)R;W(H)'(L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@=&EM97-T86UP("AI9B!S970I(&]F('1H92!L87-T(&-H86YG92!T;R!T
M:&4*("`@("`J(&]B:CIG=6ED+"!T:&%T('=A<R!C875S960@8GD@=&AE(&-L
M:65N="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@
M("`@*B!4:&ES(&ES('-T;W)E9"!T;PH@("`@("H@879O:60@;6ER<F]R:6YG
M('1H97-E(&-H86YG97,@8F%C:R!T;R!T:&4@8VQI96YT+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971#:&%N9V544R@D<WEN8TED96YT:69I97(L("1D871A
M8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@)&=I9"`])B`D=&AI<RT^7V=E
M=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1D871A8F%S92`N("<Z<W5I
M9#)C=6ED.B<@+B`D<W5I9"D["B`@("`@("`@:68@*&ES7V$H)&=I9"P@)U!%
M05)?17)R;W(G*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&=I9"T^9V5T*"=T<R<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T<FEE=F5S('1H92!(;W)D92!S97)V97(@9W5I
M9"`H;&EK90H@("`@("H@:W)O;F]L:71H.C!D,6(T,35F8S$R-&0S-#(W-S(R
M93DU9C!E.3(V8C<U*2!F;W(@82!G:79E;B!C;&EE;G0*("`@("`J(&-U:60N
M(%)E='5R;G,@9F%L<V4@:68@;F\@<W5C:"!I9"!I<R!S=&]R960@>65T+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H*("`@("`J($]P
M<&]S:71E(&]F(&=E=$QO8TED('=H:6-H(')E='5R;G,@=&AE(&QO8VED(&9O
M<B!A(&=I=F5N(&=U:60N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-U:60H
M)'-Y;F-)9&5N=&EF:65R+"`D='EP92P@)&-U:60I"B`@("!["B`@("`@("`@
M)&QI9"`])B`D=&AI<RT^7V=E=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N
M("1T>7!E("X@)SIC=6ED,G-U:60Z)R`N("1C=6ED*3L*("`@("`@("!I9B`H
M:7-?82@D;&ED+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D;&ED+3YG970H
M)W-U:60G*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@<W5I
M9"!S97)V97(@:60@*&DN92X@2&]R9&4@1U5)1"D@=&\@82!C=6ED(&-L:65N
M="!)1`H@("`@("H@87,@=7-E9"!B>2!T:&4@<WEN8R!C;&EE;G0@*&QI:V4@
M,3(I(')E='5R;G,@9F%L<V4@:68@;F\@<W5C:`H@("`@("H@:60@:7,@<W1O
M<F5D('EE="X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T0W5I9"@D<WEN8TED96YT:69I97(L("1D871A
M8F%S92P@)'-U:60I"B`@("!["B`@("`@("`@)&=I9"`])B`D=&AI<RT^7V=E
M=$]B*"1S>6YC261E;G1I9FEE<B`N("<Z)R`N("1D871A8F%S92`@+B`G.G-U
M:60R8W5I9#HG("X@)'-U:60I.PH@("`@("`@(&EF("AI<U]A*"1G:60L("=0
M14%27T5R<F]R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1G:60M/F=E="@G8W5I9"<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3&]G<R!A(&UE<W-A9V4@:6X@=&AE(&)A8VME
M;F0N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("1M97-S86=E("`@("!%
M:71H97(@82!S=')I;F<@;W(@82!014%27T5R<F]R(&]B:F5C="X*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I;&4@("`@("`@5VAA="!F:6QE('=A<R!T:&4@
M;&]G(&9U;F-T:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("AE+F<N(%]?1DE,15]?*3\*("`@("`J($!P87)A;2!I
M;G1E9V5R("1L:6YE("`@("`@5VAA="!L:6YE('=A<R!T:&4@;&]G(&9U;F-T
M:6]N(&-A;&QE9"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AE+F<N(%]?3$E.15]?*3\*("`@("`J($!P87)A;2!I;G1E9V5R("1P
M<FEO<FET>2`@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B!/;F4@;V8Z
M"B`@("`@*B`\<')E/@H@("`@("H@4$5!4E],3T=?14U%4D<*("`@("`J(%!%
M05)?3$]'7T%,15)4"B`@("`@*B!014%27TQ/1U]#4DE4"B`@("`@*B!014%2
M7TQ/1U]%4E(*("`@("`J(%!%05)?3$]'7U=!4DY)3D<*("`@("`J(%!%05)?
M3$]'7TY/5$E#10H@("`@("H@4$5!4E],3T=?24Y&3PH@("`@("H@4$5!4E],
M3T=?1$5"54<*("`@("`J(#PO<')E/@H@("`@("HO"B`@("!F=6YC=&EO;B!L
M;V=-97-S86=E*"1M97-S86=E+"`D9FEL92`](%]?1DE,15]?+"`D;&EN92`]
M(%]?3$E.15]?+`H@("`@("`@("`@("`@("`@("`@("`@("`D<')I;W)I='D@
M/2!014%27TQ/1U])3D9/*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H
M)&UE<W-A9V4I*2!["B`@("`@("`@("`@("1M97-S86=E(#T@(E-Y;F--3#H@
M(B`N("1M97-S86=E.PH@("`@("`@('T*("`@("`@("!(;W)D93HZ;&]G365S
M<V%G92@D;65S<V%G92P@)&9I;&4L("1L:6YE+"`D<')I;W)I='DI.PH@("`@
M?0H*("`@(&9U;F-T:6]N(&UA<$-L:65N=$-A=&5G;W)Y,E-E<G9E<B@D8VQI
M96YT0V%T96=O<GDL("1S=6UM87)Y("`]("=U;FMN;W=N)RD@>PH*("`@("`@
M("!I9B`H96UP='DH)&-L:65N=$-A=&5G;W)Y*2D@>PH@("`@("`@("`@("!R
M971U<FX@)R<["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y?;&]A9$-A=&5G
M;W)I97--87`H*3L*"B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V-A=&5G
M;W)I97--87!;)&-L:65N=$-A=&5G;W)Y72D@)B8*("`@("`@("`@("`@(6ES
M7V%R<F%Y*"1T:&ES+3Y?8V%T96=O<FEE<TUA<%LD8VQI96YT0V%T96=O<GE=
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C871E9V]R:65S36%P
M6R1C;&EE;G1#871E9V]R>5T["B`@("`@("`@?0H*("`@("`@("`O*B!S=&]R
M92!T:&4@8VQI96YT0V%T96=O<GD@87,@;&%C:VEN9R!A(&UA<"X@*B\*("`@
M("`@("`D=&AI<RT^7V-A=&5G;W)I97--87!;)&-L:65N=$-A=&5G;W)Y72`]
M(&%R<F%Y*"1S=6UM87)Y*3L*("`@("`@("`D=&AI<RT^7W-T;W)E0V%T96=O
M<FEE<TUA<"@I.PH@("`@("`@(')E='5R;B`D8VQI96YT0V%T96=O<GD["B`@
M("!]"@H@("`@9G5N8W1I;VX@;6%P4V5R=F5R0V%T96=O<GDR0VQI96YT*"1S
M97)V97)#871E9V]R>2P@)'-U;6UA<GD@/2`G=6YK;F]W;B<I('L*"B`@("`@
M("`@:68@*&5M<'1Y*"1S97)V97)#871E9V]R>2DI('L*("`@("`@("`@("`@
M<F5T=7)N("<G.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]L;V%D0V%T
M96=O<FEE<TUA<"@I.PH*("`@("`@("`D8R`](&%R<F%Y7W-E87)C:"@D<V5R
M=F5R0V%T96=O<GDL("1T:&ES+3Y?8V%T96=O<FEE<TUA<"D["B`@("`@("`@
M:68@*"%E;7!T>2@D8RD@)B8@(6ES7V%R<F%Y*"1C*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&,["B`@("`@("`@?0H*("`@("`@("`O*B!3=&]R92!T:&4@
M<V5R=F5R0V%T96=O<GD@87,@;&%C:VEN9R!A(&UA<"X@*B\*("`@("`@("`D
M=&AI<RT^7VUI<W-I;F=397)V97)#871E9V]R:65S6R1S97)V97)#871E9V]R
M>5T@/2`D<W5M;6%R>3L*("`@("`@("`D=&AI<RT^7W-T;W)E0V%T96=O<FEE
M<TUA<"@I.PH*("`@("`@("!R971U<FX@)'-E<G9E<D-A=&5G;W)Y.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]L;V%D0V%T96=O<FEE<TUA<"@I"B`@("!["B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?8V%T96=O<FEE<TUA<"DI('L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)&UA<"`]
M)B`D=&AI<RT^7V=E=$]B*"1?4T534TE/3ELG4WEN8TU,+G-T871E)UTM/F=E
M=%-Y;F-)9&5N=&EF:65R*"D@+B`G.F-A=&5G;W)I97,G*3L*("`@("`@("!I
M9B`H:7-?82@D;6%P+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?8V%T96=O<FEE<TUA<"`](&%R<F%Y*"D["B`@("`@("`@("`@("1T
M:&ES+3Y?;6ES<VEN9U-E<G9E<D-A=&5G;W)I97,@/2!A<G)A>2@I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?8V%T96=O<FEE<TUA
M<"`]("1M87`M/F=E="@G;6%P)RD["B`@("`@("`@("`@("1T:&ES+3Y?;6ES
M<VEN9U-E<G9E<D-A=&5G;W)I97,@/2`D;6%P+3YG970H)VUI<W-I;F=397)V
M97)#871E9V]R:65S)RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(%]S=&]R94-A=&5G;W)I97--87`H*0H@("`@>PH@("`@("`@(&EF("@A:7-?
M87)R87DH)'1H:7,M/E]C871E9V]R:65S36%P*2D@>PH@("`@("`@("`@("!R
M971U<FX[("\O(&YO=&AI;F<@=&\@9&\*("`@("`@("!]"@H@("`@("`@("1M
M87`@/2`F;F5W($1A=&%4<F5E3V)J96-T*"1?4T534TE/3ELG4WEN8TU,+G-T
M871E)UTM/F=E=%-Y;F-)9&5N=&EF:65R*"D*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("<Z8V%T96=O<FEE<R<I.PH@("`@("`@("1M
M87`M/G-E="@G;6%P)RP@)'1H:7,M/E]C871E9V]R:65S36%P*3L*("`@("`@
M("`D;6%P+3YS970H)VUI<W-I;F=397)V97)#871E9V]R:65S)RP@)'1H:7,M
M/E]M:7-S:6YG4V5R=F5R0V%T96=O<FEE<RD["@H@("`@("`@("1R(#T@)'1H
M:7,M/E]D871A=')E92T^861D*"1M87`I.PH@("`@("`@(&EF("AI<U]A*"1R
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("\O($]B:F5C="!A;')E
M861Y(&5X:7-T<SH@=7!D871E(&EN<W1E860N"B`@("`@("`@("`@("1R(#T@
M)'1H:7,M/E]D871A=')E92T^=7!D871E1&%T82@D;6%P*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]C86-H95LD;6%P+3YG971.86UE*"E=(#T@)&UA
M<#L*("`@("`@("`D=&AI<RT^9&EE3VY%<G)O<B@D<BP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@:7,@82!S;6%L
M;"!H96QP97(@9G5N8W1I;VX@=&AA="!C86X@8F4@:6YC;'5D960@=&\@8VAE
M8VL*("`@("`J('=H971H97(@82!G:79E;B`D;V)J(&ES(&$@4$5!4E]%<G)O
M<B!O<B!N;W0N($EF('-O+"!I="!L;V=S"B`@("`@*B!T;R!D96)U9RP@=F%R
M7V1U;7!S('1H92`D;V)J(&%N9"!E>&ET<RX*("`@("`J+PH@("`@9G5N8W1I
M;VX@9&EE3VY%<G)O<B@D;V)J+"`D9FEL92`](%]?1DE,15]?+"`D;&EN92`]
M(%]?3$E.15]?*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;V)J+"`G4$5!
M4E]%<G)O<B<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=3>6YC34PZ(%!%05(@17)R;W(Z
M("<@+B`D;V)J+3YG971-97-S86=E*"DL("1F:6QE+"`D;&EN92P@4$5!4E],
M3T=?15)2*3L*("`@("`@("!P<FEN="`B4$5!4B!%4E)/4EQN7&XB.PH@("`@
M("`@('9A<E]D=6UP*"1O8FHI.PH@("`@?0H*("`@(&9U;F-T:6]N("9?9V5T
M3V(H)&YA;64I"B`@("!["B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-A
M8VAE6R1N86UE72DI('L*("`@("`@("`@("`@)'1H:7,M/E]C86-H95LD;F%M
M95T@/28@)'1H:7,M/E]D871A=')E92T^9V5T3V)J96-T*"1N86UE*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%C:&5;)&YA;65=.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+G!H<```````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`S,S(P-R`Q,#4Q
M-30S-#$S-B`P,C$S-C4`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"@HO*BH*("H@5&AE(%-Y;F--3%]$979I8V4Z
M.B!C;&%S<R!P<F]V:61E<R!F=6YC=&EO;F%L:71Y('1H870@:7,*("H@<&]T
M96YT:6%L;'D@*&-L:65N="D@9&5V:6-E(&1E<&5N9&%N="X*("H*("H@4V\@
M:68@82!S>6YC(&-L:65N="!N965D<R!A;GD@:VEN9"!O9B!S<&5C:6%L(&1A
M=&$@;V8@=&AE(&1A=&$@<V5N=`H@*B!T;R!I="!O<B!R96-E:79E9"!F<F]M
M(&ET+"!T:&ES(&ES(&1O;F4@:&5R92X@5&AE<F4@87)E('1W;R!S;W5R8V4*
M("H@;V8@:6YF;W)M871I;VX@=&\@:61E;G1I9GD@86X@9&5V:6-E.B!4:&4@
M9FER<W0@*&%N9"!B971T97(I(&]N92!I<PH@*B!T:&4@1&5V26YF(&1E=FEC
M92!I;F9O('-E;G0@8GD@=&AE(&1E=FEC92!U<&]N(&$@9V5T(')E<75E<W0N
M($EF"B`J($1E=DEN9B!I<R!N;W0@<W5P<&]R=&5D(&]R('-E;G0@8GD@=&AE
M(&-L:65N="P@=&AE(%-O=7)C955222!O9B!T:&4*("H@9&5V:6-E(&UA>2!B
M92!S=69F:6-E;G0@=&\@:61E;G1I9GD@:70N"B`J"B`J($EN9F]R;6%T:6]N
M(&%B;W5T(&$@9F5W(&1E=FEC97,@86QR96%D>2!W;W)K:6YG('=I=&@@4WEN
M8TU,.CH*("H*("H@4#@P,"]0.3`P+U`Y,3`Z"B`J("TM+2TM+2TM+2TM+2TM
M+0H@*B!#:&%R<V5T.@H@*B!4:&ES(&1E=FEC92!I<R!A8FQE('1O(&AA;F1L
M92!55$8M."!A;F0@<V5N9',@:71S(%A-3"!P86-K86=E<R!I;B!55$8X+@H@
M*B!(;W=E=F5R(&5V96X@=&AO=6=H('1H92!834P@:71S96QF(&ES(%541BTX
M+"!I="!E>'!E8W1S('1H92!E;F-L;W-E9`H@*B!V8V%R9"UD871A('1O(&)E
M($E33RTX.#4Y+3$@=6YL97-S(&5X<&QI8VET;'D@<W1A=&5D(&]T:&5R=VES
M92`H=7-I;F<@=&AE"B`J($-(05)3150@;W!T:6]N+"!W:&EC:"!I<R!D97!R
M96-A=&5D(&9O<B!60T%21"`S+C`I"B`J"B`J($5N8V]D:6YG.@H@*B!3=')I
M;F<@=F%L=65S(&%R92!E;F-O9&5D(")154]4140M4%))3E1!0DQ%(@H@*@H@
M*B!/=&AE<CH*("H@5&AI<R!D979I8V5S(&AA;F1L97,@=&%S:W,@86YD(&5V
M96YT<R!I;B!O;F4@9&%T86)A<V4N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P
M,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,
M+T1E=FEC92YP:'`L=B`Q+C<N,BXX(#(P,#8O,#4O,#,@,C$Z-#(Z-30@:F%N
M($5X<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T
M96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y
M;F--3%]$979I8V4@>PH*("`@(&9U;F-T:6]N("9F86-T;W)Y*"D*("`@('L*
M("`@("`@("`D<VD@/2!3>6YC34Q?1&5V:6-E.CIS;W5R8V554DDH*3L*("`@
M("`@("`D9&D@/2!3>6YC34Q?1&5V:6-E.CID979I8V5);F9O*"D["@H@("`@
M("`@(&EF("AS=')I<W1R*"1S:2P@)W-Y;F,T:B<I("$]/2!F86QS92!\?"!S
M=')I<W1R*"1S:2P@)W-C+7!I;2<I("$]/2!F86QS92D@>PH@("`@("`@("`@
M("!I;F-L=61E7V]N8V4@)U-Y;F--3"]$979I8V4O4WEN8S1J+G!H<"<["B`@
M("`@("`@("`@("1D979I8V4@/2`F;F5W(%-Y;F--3%]$979I8V5?<WEN8S1J
M*"D["B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D9&DM/E]-86XI("8F('-T
M<FES='(H)&1I+3Y?36%N+"`G4V]N>2!%<FEC<W-O;B<I("$]/2!F86QS92D@
M>PH@("`@("`@("`@("!I;F-L=61E7V]N8V4@)U-Y;F--3"]$979I8V4O4#@P
M,"YP:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@)FYE=R!3>6YC34Q?1&5V
M:6-E7U`X,#`H*3L*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1D:2T^7TUA
M;BD@)B8@<W1R:7-T<B@D9&DM/E]-86XL("=S>6YT:&5S:7,G*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E("=3>6YC34PO1&5V:6-E
M+U-Y;G1H97-I<RYP:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@)FYE=R!3
M>6YC34Q?1&5V:6-E7U-Y;G1H97-I<R@I.PH@("`@("`@('T@96QS96EF("@A
M96UP='DH)&1I+3Y?36%N*2`F)B!S=')I<W1R*"1D:2T^7TUA;BP@)VYO:VEA
M)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4WEN
M8TU,+T1E=FEC92].;VMI82YP:'`G.PH@("`@("`@("`@("`D9&5V:6-E(#T@
M)FYE=R!3>6YC34Q?1&5V:6-E7TYO:VEA*"D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&1E=FEC92`]("9N97<@4WEN8TU,7T1E=FEC92@I.PH@
M("`@("`@('T*"B`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S
M<V%G92@G57-I;F<@9&5V:6-E(&-L87-S("<@+B!G971?8VQA<W,H)&1E=FEC
M92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@
M<F5T=7)N("1D979I8V4["B`@("!]"@H@("`@9G5N8W1I;VX@)G-I;F=L971O
M;B@I"B`@("!["B`@("`@("`@<W1A=&EC("1I;G-T86YC93L*"B`@("`@("`@
M:68@*"%I<W-E="@D:6YS=&%N8V4I*2!["B`@("`@("`@("`@("1I;G-T86YC
M92`](%-Y;F--3%]$979I8V4Z.F9A8W1O<GDH*3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D:6YS=&%N8V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!3;W5R8V554DD@9G)O;2!S=&%T92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V]U<F-E55))*"D*("`@('L*("`@("`@("!R971U<FX@)%]3
M15-324].6R=3>6YC34PN<W1A=&4G72T^9V5T4V]U<F-E55))*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!$979);F8@8VQA<W,@9G)O
M;2!S=&%T92X*("`@("`J+PH@("`@9G5N8W1I;VX@9&5V:6-E26YF;R@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1?4T534TE/3ELG4WEN8TU,+G-T871E)UTM
M/F=E=$1E=FEC94EN9F\H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%=H96X@
M82!C;&EE;G0@<V5N9',@9&%T82!D=7)I;F<@82!S>6YC(&)U="!D;V5S(&YO
M="!P<F]V:61E"B`@("`@*B!I;F9O<FUA=&EO;B!A8F]U="!T:&4@8V]N=&5N
M='1Y<&4@=VET:"!T:&ES(&EN9&EV:61U86P@:71E;2P*("`@("`J('1H:7,@
M9G5N8W1I;VX@<F5T=7)N<R!T:&4@8V]N=&5N='1Y<&4@=&AE(&ET96T@:7,@
M<W5P<&]S960@=&\@8F4@:6XN"B`@("`@*@H@("`@("H@07,@=&AI<R!I<R!O
M;FQY('5S960@=&\@<&%R<V4@=&\@=&AE(&AO<F1E)W,@:6UP;W)T9&%T82!A
M<&D@9G5N8W1I;VYS+`H@("`@("H@<V]M92!S:6UP;&4@9W5E<W-E<R!F;W(@
M=&AE(&-O;G1E;G1T>7!E(&%R92!C;VUP;&5T96QY('-U9F9I8VEE;G0Z"B`@
M("`@*B!(;W)D92!D;V5S(&YO="!C87)E('=H971H97(@9&%T82!I<R!T97AT
M+W@M=F-A;&5N9&%R(&]R('1E>'0O8V%L96YD87(N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%!R969E<G)E9$-O;G1E;G14>7!E*"1T>7!E*0H@("`@>PH@
M("`@("`@(&EF("@D='EP92`]/2`G8V]N=&%C=',G*2!["B`@("`@("`@("`@
M(')E='5R;B`G=&5X="]X+79C87)D)SL*("`@("`@("!](&5L<V5I9B`H)'1Y
M<&4@/3T@)VYO=&5S)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O>"UV
M;F]T92<["B`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=T87-K<R<I('L*
M("`@("`@("`@("`@<F5T=7)N("=T97AT+V-A;&5N9&%R)SL*("`@("`@("!]
M(&5L<V5I9B`H)'1Y<&4@/3T@)V-A;&5N9&%R)RD@>PH@("`@("`@("`@("!R
M971U<FX@)W1E>'0O8V%L96YD87(G.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('!R969E<G)R960@8V]N=&5N='1Y<&4@
M;V8@=&AE(&-L:65N="!F;W(@=&AE(&=I=F5N"B`@("`@*B!S>6YC(&1A=&$@
M='EP92`H8V]N=&%C=',O=&%S:W,O;F]T97,O8V%L96YD87(I+@H@("`@("H*
M("`@("`J(%1H92!R97-U;'0@:7,@<&%S<V5D(&%S(&%N(&]P=&EO;B!T;R!T
M:&4@2&]R9&4@05!)(&5X<&]R="!F=6YC=&EO;G,N"B`@("`@*B!0;&5A<V4@
M;F]T92!T:&%T('1H:7,@:7,@;F]T('1H92!C;VYT96YT5'EP92!U;'1I;6%T
M96QY('!A<W-E9"!T;R!T:&4*("`@("`J(&-L:65N="!B=70@<F%T:&5R('1H
M92!C;VYT96YT5'EP92!P<F5S96YT960@=&\@=&AE($AO<F1E($%022!E>'!O
M<G0*("`@("`J(&9U;F-T:6]N<RX@1F]R(&5X86UP;&4@=&AE(&-O;G1A8W0@
M87!I('-U<'!O<G1S(&$@8V]N=&5N='1Y<&4@"B`@("`@*B!T97AT+W@M=F-A
M<F0[=F5R<VEO;CTR+C$@=&\@8W)E871E(&$@=F-A<F0@:6X@=F-A<F0@,BXQ
M(&9O<FUA="X*("`@("`J"B`@("`@*B!!9G1E<B!T:&4@9&%T82!I<R!R971R
M:65V960@9G)O;2!H;W)D92P@8V]N=F5R=%-E<G9E<C)#;&EE;G0@8V%N(&1O
M"B`@("`@*B!S;VUE('!O<W0M<')O8V5S<VEN9R!A;F0@<V5T('1H92!C;W)R
M96-T(&-O;G1E;G14>7!E(&%C8V5P=&%B;&4@9F]R"B`@("`@*B!T:&4@8VQI
M96YT(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!4:&4@9&5F875L="!I
M;7!L96UE;G1A=&EO;B!T<FEE<R!T;R!E>'1R86-T('1H92!C;VYT96YT='EP
M92!F<F]M('1H90H@("`@("H@<')E<V5N=&5D(&1E=FEC92!I;F9O+B!)9B!T
M:&ES(&1O97,@;F]T('=O<FLL('-O;64@9&5F875L="!A<F4@=7-E9"X*("`@
M("`J"B`@("`@*B!)9B!T:&4@8VQI96YT(&1O97,@;F]T('!R;W9I8V4@<')O
M<&5R($1E=DEN9B!D871A+"!T:&ES(&9U;F-T:6]N(&UA>0H@("`@("H@:&%V
M92!T;R!B92!O=F5R=W)I='1E;B!T;R!R971U<FX@=&AE(&-O<G)E8W0@=F%L
M=65S+@H@("`@("H*("`@("`J(%-E<G9E<E-Y;F-54DDZ(%1H92!S97)V97(@
M9&%T86)A<V4@;V8@=&AE('-Y;F,Z"B`@("`@*B`@("`@("`@("`@("`@("!C
M;VYT86-T<WQN;W1E<WQC86QE;F1A<GQT87-K<PH@("`@("H@<V]U<F-E4WEN
M8U5223H@5&AE(%5222!F;W(@=&AE(&-L:65N="!D871A8F%S92X@5&AI<R!I
M<R!N965D960@87,*("`@("`J("`@("`@("`@("`@("`@('1H92!$979);F8@
M:7,@87)R86YG960@8GD@<V]U<F-E4WEN8U5227,*("`@("`J+PH@("`@(`H@
M("`@9G5N8W1I;VX@9V5T4')E9F5R<F5D0V]N=&5N=%1Y<&5#;&EE;G0H)'-E
M<G9E<E-Y;F-54DDL("1S;W5R8V53>6YC55))*0H@("`@>PH@("`@("`@("1D
M:2`]("1T:&ES+3YD979I8V5);F9O*"D["B`@("`@("`@)&1S(#T@)&1I+3YG
M971$871A4W1O<F4H)'-O=7)C95-Y;F-54DDI.PH@("`@("`@(&EF("@A96UP
M='DH)&1S*2D@>PH@("`@("`@("`@("`D<B`]("1D<RT^9V5T4')E9F5R<F5D
M4EA#;VYT96YT5'EP92@I.PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1D<RDI
M('L*("`@("`@("`@("`@("`@(&EF("@D<B`]/2`G=&5X="]X+79C87)D)R`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`D9',M/F=E=%!R969E<G)E9%)8
M0V]N=&5N=%1Y<&5697)S:6]N*"D@/3T@)S(N,2<I('L*("`@("`@("`@("`@
M("`@("`@("`O*B!3<&5C:6%L(&-U<W1O;2!M:6UE='EP92!W:&EC:"!M86ME
M<R!T:&4@:&]R9&4@='5R8F$@05!)"B`@("`@("`@("`@("`@("`@("`@("H@
M<F5T=7)N(&$@=F5R<VEO;B`R+C$@<F%T:&5R('1H86X@,RXP('9C87)D+@H@
M("`@("`@("`@("`@("`@("`@("`J+PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`G=&5X="]X+79C87)D.W9E<G-I;VX],BXQ)SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D<CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+RH@3F\@26YF;R!I;B!$979);F8N(%5S
M92!D969A=6QT<SH@*B\*("`@("`@("!I9B`H)'-E<G9E<E-Y;F-54DD@/3T@
M)V-O;G1A8W1S)RD@>PH@("`@("`@("`@("!R971U<FX@)W1E>'0O>"UV8V%R
M9"<["B`@("`@("`@?2!E;'-E:68@*"1S97)V97)3>6YC55))(#T]("=N;W1E
M<R<I('L*("`@("`@("`@("`@<F5T=7)N("=T97AT+W@M=FYO=&4G.PH@("`@
M("`@('T@96QS96EF("@D<V5R=F5R4WEN8U5222`]/2`G=&%S:W,G*2!["B`@
M("`@("`@("`@(')E='5R;B`G=&5X="]X+79T;V1O)SL*("`@("`@("!](&5L
M<V5I9B`H)'-E<G9E<E-Y;F-54DD@/3T@)V-A;&5N9&%R)RD@>PH@("`@("`@
M("`@("!R971U<FX@)W1E>'0O8V%L96YD87(G.PH@("`@("`@('T*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&-O;G1E;G0@<F5C96EV960@
M9G)O;2!T:&4@8VQI96YT(&9O<B!T:&4@:&]R9&4@8F%C:V5N9"X*("`@("`J
M"B`@("`@*B!#=7)R96YT;'D@<W1R:7!S('5I9"`H<')I;6%R>2!K97DI(&EN
M9F]R;6%T:6]N(&%S(&-L:65N="!A;F0*("`@("`J('-E<G9E<B!M:6=H="!U
M<V4@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0VAA<G-E="!C;VYV
M97)S:6]N<R!M:6=H="!B92!A9&1E9"!H97)E('1O;RX*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VYT96YT("`@("`@(%1H92!C;VYT96YT('1O
M(&-O;G9E<G0*("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@
M5&AE(&-O;G1E;G14>7!E(&]F('1H92!C;VYT96YT"B`@("`@*@H@("`@("H@
M0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N=&5N
M="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY(&-H
M86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M8V]N=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*
M("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["B`@("`@("`@:68@*$1%
M0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@("`@(&EF
M("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B7&YI;G!U
M="!R96-E:79E9"!F<F]M(&-L:65N="`H)&-O;G1E;G14>7!E*5QN(BD["B`@
M("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1C;VYT96YT5'EP92PG<VEF+R<I
M("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@("`@("\O('-Y;F,T9FH@
M<VEF+RH@9&%T82!I<R!B87-E-C1?96YC;V1E9"X*("`@("`@("`@("`@("`@
M("`@("!`9G=R:71E*"1F<"P@8F%S938T7V1E8V]D92@D8V]N=&5N="D@+B`B
M7&XB*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@0&9W<FET92@D9G`L("1C;VYT96YT("X@(EQN(BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($%L=V%Y<R!R96UO=F4@
M8VQI96YT(%5)1"X@54E$('=I;&P@8F4@<V5P97)A=&5L>2!P87-S960@:6X*
M("`@("`@("`O+R!834PN"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA
M8V4H)R\H7')<;GQ<<GQ<;BE5240Z+BH_*%QR7&Y\7')\7&XI+R<L("=<,2<L
M("1C;VYT96YT+"`Q*3L*"B`@("`@("`@:68@*"1T:&ES+3YN965D<T-A=&5G
M;W)Y36%P<&EN9R@I("8F"B`@("`@("`@("`@('!R96=?;6%T8V@H)R\H7')<
M;GQ<<GQ<;BE#051%1T]224536UY<.ETJ.B@N*C\I*%QR7&Y\7')\7&XI+R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@
M("`@("`@("`D8V%T<R`](&5X<&QO9&4H)RPG+"`D;5LR72D["B`@("`@("`@
M("`@(&EF*"!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI4U5-34%265M>7#I=
M*CHH+BH_*2A<<EQN?%QR?%QN*2\G+`H@("`@("`@("`@("`@("`@("`@("`@
M("1C;VYT96YT+"`D;2DI('L*("`@("`@("`@("`@("`@("1S=6UM87)Y(#T@
M)&U;,ET["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<W5M;6%R>2`]("=U;FMN;W=N)SL*("`@("`@("`@("`@?0H*"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1C871S(&%S("1C870I('L*("`@("`@("`@("`@("`@
M("1R97-U;'1S6UT@/2`D8F%C:V5N9"T^;6%P0VQI96YT0V%T96=O<GDR4V5R
M=F5R*"1C870L("1S=6UM87)Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN0T%414=/
M4DE%4UM>7#I=*CHI*"XJ/RDH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)R0Q)R`N(&EM<&QO9&4H)RPG+"1R
M97-U;'1S*2`N("<D,R<L("1C;VYT96YT*3L*"B`@("`@("`@?0H@("`@("`@
M("\O($5N<W5R92!V86QI9"!N97=L:6YE('1E<FUI;F%T:6]N+@H@("`@("`@
M(&EF("AS=6)S='(H)&-O;G1E;G0L("TQ*2`A/2`B7&XB("8F('-U8G-T<B@D
M8V]N=&5N="P@+3$I("$](")<<B(I('L*("`@("`@("`@("`@)&-O;G1E;G0@
M+CT@(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1C
M;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0V]N=F5R=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N9"!T;R!A(&9O
M<FUA="!S=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@9&5V:6-E+@H@
M("`@("H*("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y(&ME>2D@:6YF
M;W)M871I;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@=7-E"B`@("`@
M*B!D:69F97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!#:&%R<V5T(&-O;G9E
M<G-I;VYS(&UI9VAT(&)E(&%D9&5D(&AE<F4@=&]O+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E;G0@=&\@
M8V]N=F5R=`H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@("!4
M:&4@8V]N=&5N=%1Y<&4@;V8@8V]N=&5N="!A<R!R971U<FYE9"!F<F]M"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!B86-K96YD
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@("`@(&%R<F%Y*"1N
M97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I.@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T:&4@8V]N=F5R=&5D(&-O;G1E;G0@86YD
M('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H<&]S
M<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14>7!E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E
M;G14>7!E*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*("`@("`@
M("!I9B`H:7-?87)R87DH)&-O;G1E;G14>7!E*2D@>PH@("`@("`@("`@("`D
M8V]N=&5N=%1Y<&4@/2`D8V]N=&5N=%1Y<&5;)T-O;G1E;G14>7!E)UT["B`@
M("`@("`@?0H*("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@
M>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT
M)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@
M("`@0&9W<FET92@D9G`L(")<;F]U='!U="!R96-E:79E9"!F<F]M(&AO<F1E
M(&)A8VME;F0@(B`N"B`@("`@("`@("`@("`@("`@("`@("`@("(H)&-O;G1E
M;G14>7!E*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L)&-O
M;G1E;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO<V4H)&9P*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+RH@4F5M;W9E('-P
M96-I86P@=F5R<VEO;CTR+C$@:6YD:6-A=&]R('5S960@9F]R(&AO<F1E(&%P
M:2X@*B\*("`@("`@("!I9B`H)&-O;G1E;G14>7!E(#T]("=T97AT+W@M=F-A
M<F0[=F5R<VEO;CTR+C$G*2!["B`@("`@("`@("`@("1C;VYT96YT5'EP92`]
M("=T97AT+W@M=F-A<F0G.PH@("`@("`@('T*"B`@("`@("`@+RH@06QW87ES
M(')E;6]V92!S97)V97(@54E$+B!5240@=VEL;"!B92!S97!E<F%T96QY('!A
M<W-E9"!I;B!834PN("HO"B`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA
M8V4H)R\H7')<;GQ<<GQ<;BE5240Z+BH_*%QR7&Y\7')\7&XI+R<L("=<,2<L
M("1C;VYT96YT+"`Q*3L*"B`@("`@("`@)&1I(#T@)'1H:7,M/F1E=FEC94EN
M9F\H*3L*"B`@("`@("`@:68@*"1T:&ES+3YN965D<T-A=&5G;W)Y36%P<&EN
M9R@I("8F"B`@("`@("`@("`@('!R96=?;6%T8V@H)R\H7')<;GQ<<GQ<;BE#
M051%1T]224536UY<.ETJ.B@N*C\I*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@("`@("`D
M8V%T<R`](&5X<&QO9&4H)RPG+"`D;5LR72D["@H@("`@("`@("`@("!I9B@@
M<')E9U]M871C:"@G+RA<<EQN?%QR?%QN*5-534U!4EE;7EPZ72HZ*"XJ/RDH
M7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N
M="P@)&TI*2!["B`@("`@("`@("`@("`@("`D<W5M;6%R>2`]("1M6S)=.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-U;6UA<GD@
M/2`G=6YK;F]W;B<["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1C871S(&%S("1C870I('L*("`@("`@("`@("`@("`@("1R97-U;'1S
M6UT@/2`D8F%C:V5N9"T^;6%P4V5R=F5R0V%T96=O<GDR0VQI96YT*"1C870L
M("1S=6UM87)Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!P<F5G7W)E
M<&QA8V4H)R\H7')<;GQ<<GQ<;D-!5$5'3U))15-;7EPZ72HZ*2@N*C\I*%QR
M7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G)#$G("X@
M:6UP;&]D92@G+"<L)')E<W5L=',I("X@)R0R)RP@)&-O;G1E;G0I.PH@("`@
M("`@('T*"B`@("`@("`@<W=I=&-H("@D8V]N=&5N=%1Y<&4I('L*("`@("`@
M("!C87-E("=T97AT+V-A;&5N9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X
M+6EC86QE;F1A<B<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"UV8V%L96YD87(G
M(#H*("`@("`@("!C87-E("=T97AT+W@M=F5V96YT)R`Z"B`@("`@("`@8V%S
M92`G=&5X="]X+79T;V1O)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+79N;W1E
M)SH*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W1E>'0O>"UV
M8V%R9"<@.@H@("`@("`@("`@("`O+R!)9B!W92!C86X@97AT<F%C="!F<F]M
M('1H92!$979I8V4@26YF;RP@=&AA="!T:&4@8VQI96YT"B`@("`@("`@("`@
M("\O('5S97,@5$5,.U=/4DLZ(#`X,#`@,3(S(&EN<W1E860@;V8@5$5,.U19
M4$4]5T]22SH*("`@("`@("`@("`@+R\@,#@P,#$R,RP@8V]N=F5R="!T:&4@
M9&%T82!A8V-O<F1I;F=L>2X*("`@("`@("`@("`@:68@*"%E;7!T>2@D9&DM
M/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)U1%3"==*2`F)@H@("`@("`@("`@
M("`@("`@96UP='DH)&1I+3Y?0U1#87!;)W1E>'0O>"UV8V%R9"==6R=414PG
M72T^7W!A<F%M<ULG5%E012==*2`F)@H@("`@("`@("`@("`@("`@(65M<'1Y
M*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG5$5,)UTM/E]P87)A;7-;
M)U9/24-%)UTI*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?
M<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/4A/344O)RP@)UPQ5$5,
M.TA/344[5D])0T4G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D
M8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%
M/5=/4DLO)RP@)UPQ5$5,.U=/4DL[5D])0T4G+"`D8V]N=&5N="P@,2D["B`@
M("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN
M?%QR?%QN*51%3#M465!%/4-%3$PO)RP@)UPQ5$5,.U9/24-%.T-%3$PG+"`D
M8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?
M<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/49!6"\G+"`G7#%414P[
M5T]22SM&05@G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*51%3#M465!%/5!!
M1T52+R<L("=<,51%3#M004=%4CM73U)+)RP@)&-O;G1E;G0L(#$I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!)9B!W92!C86X@97AT<F%C="!F
M<F]M('1H92!$979I8V4@26YF;RP@=&AA="!T:&4@8VQI96YT"B`@("`@("`@
M("`@("\O('5S97,@0412.U=/4DLZ("XN+B!I;G-T96%D(&]F($%$4CM465!%
M/5=/4DLZ(#`X,#`Q,C,L"B`@("`@("`@("`@("\O(&-O;G9E<G0@=&AE(&1A
M=&$@86-C;W)D:6YG;'DN"B`@("`@("`@("`@(&EF("@A96UP='DH)&1I+3Y?
M0U1#87!;)W1E>'0O>"UV8V%R9"==6R=!1%(G72D@)B8*("`@("`@("`@("`@
M("`@(&5M<'1Y*"1D:2T^7T-40V%P6R=T97AT+W@M=F-A<F0G75LG0412)UTM
M/E]P87)A;7-;)U194$4G72D@)B8*("`@("`@("`@("`@("`@("%E;7!T>2@D
M9&DM/E]#5$-A<%LG=&5X="]X+79C87)D)UU;)T%$4B==+3Y?<&%R86US6R=7
M3U)+)UTI*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P
M;&%C92@G+RA<<EQN?%QR?%QN*4%$4CM465!%/5=/4DLO)RP@)UPQ0412.U=/
M4DLG+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*4%$4CM465!%/4A/344O)RP@
M)UPQ0412.TA/344G+"`D8V]N=&5N="P@,2D["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4V]M92!D979I8V5S(&QI:V4@=&AE(%-O;GD@17)I8W-S;VX@4#@P
M,"]0.3`P+U`Y,3`@:&%N9&QE"B`@("`@*B!V=&]D;W,@*'1A<VMS*2!A;F0@
M=F5V96YT<R!I;B!T:&4@<V%M92`B8V%L96YD87(B('-Y;F,N("!4:&ES"B`@
M("`@*B!R97%U:7)E<R!S<&5C:6%L(&%C=&EO;G,@;VX@;W5R('-I9&4@87,@
M=V4@<W1O<F4@=&AI<R!I;@H@("`@("H@9&EF9F5R96YT(&1A=&%B87-E<R`H
M;F%G(&%N9"!K<F]N;VQI=&@I+B`@5&AI<R!F=6YC=&EO;@H@("`@("H@9&5T
M97)M:6YE<R!W:&5T:&5R('1H92!C;&EE;G0@9&]E<R!I="!L:6ME('1H870N
M("!#=7)R96YT;'D*("`@("`J('1H:7,@:7,@9&]N92!B>2!C:&5C:VEN9R!T
M:&4@1&5V26YF(&EN9F]R;6%T:6]N+B!&;W(@9&EF9F5R96YT"B`@("`@*B!C
M;&EE;G1S('1H97)E(&UA>2!B92!D:69F97)E;G0@=V%Y<R!T;R!F:6YD(&]U
M="!H;W<@=&AE(&-L:65N=`H@("`@("H@;&EK97,@:71S('1A<VMS+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!H86YD;&5487-K<TEN0V%L96YD87(H*0H@("`@
M>PH@("`@("`@("\O($1E9F%U;'0Z('1A<VMS(&%N9"!E=F5N=',@87)E('-E
M<&5R871E(&1A=&%B87-E<RX*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3;VUE(&1E=FEC97,@;F5E9"!A(&UA<'!I;F<@
M;V8@8VQI96YT('9S+B!S97)V97(@8V%T96=O<FEE(&YA;65S+@H@("`@("H@
M5&AE(&)A8VME;F0@<')O=FED97,@82!M96-H86YI<VT@9F]R('1H:7,@;6%P
M<&EN9RX@270@:7,@=7-E9`H@("`@("H@=VAE;B!T:&ES(&YE961S0V%T96=O
M<GE-87!P:6YG(')E='5R;G,@=')U92X*("`@("`J($9O<B!S<&5C:6%L(&-A
M<V5S('1H92!M87!P:6YG(&UA>2!A;'-O(&)E(&EM<&QE;65N=&5D(&1I<F5C
M=&QY(&EN"B`@("`@*B!C;VYV97)T0VQI96YT,E-E<G9E<B!A;F0@8V]N=F5R
M=%-E<G9E<C)#;&EE;G0N($EN('1H:7,@8V%S90H@("`@("H@;F5E9'-#871E
M9V]R>4UA<'!I;F<@;6%Y(')E='5R;B!F86QS92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5E9'-#871E9V]R>4UA<'!I;F<H*0H@("`@>PH@("`@("`@(')E
M='5R;B!F86QS93L*("`@('T*"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+U-Y;F,N<&AP````````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#`V-#,@,3`U,34T
M,S0Q,S8@,#(Q,3`T`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC
M34PO4WEN8TU,+U-Y;F,N<&AP+'8@,2XX+C0N.2`R,#`V+S`U+S`Q(#$R.C`U
M.C$T(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO
M;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B!`875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N
M8V]M/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,
M"B`J+PIC;&%S<R!3>6YC34Q?4WEN8R!["@H@("`@+RHJ"B`@("`@*B!487)G
M970Z(&-O;G1A8W1S+"!N;W1E<RP@8V%L96YD87(L('1A<VMS+`H@("`@("HO
M"B`@("!V87(@)%]T87)G971,;V-54DD[("\O('1A<F=E="!M96%N<R!S97)V
M97(@:&5R90H*("`@('9A<B`D7W-O=7)C94QO8U5223L@+R\@<V]U<F-E(&UE
M86YS(&-L:65N="!H97)E"@H@("`@=F%R("1?86QE<G0["@H@("`@+RHJ"B`@
M("`@*B!4<G5E(&EN9&EC871E<R!T:&%T('1H97)E(&%R92!S=&EL;"!S>6YC
M(&5L96UE;G1S('1H870@:&%V92!N;W0@8F5E;@H@("`@("H@<V5N="!Y970@
M9'5E('1O(&UE<W-A9V4@<VEZ92!L:6UI=&%T:6]N<R!A;F0@:&%V92!T;R!B
M92!S96YT(&EN('1H92!N97AT"B`@("`@*B!M97-S86=E+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]P96YD:6YG16QE
M;65N=',["@H@("`@+RHJ"B`@("`@*B!296UE;6)E<B!E;G1R:65S('=E(&AA
M=F4@:&%N9&QE9"!A;')E861Y.B!O;F-E('=E('-E;F0@82!D96QE=&4@9F]R
M(&%N"B`@("`@*B!E;G1R>2P@=V4@9&]N)W0@=V%N="!T;R!S96YD(&%N(&%D
M9"!A9G1E<G=A<F1S+B!4:&ES(&%R<F%Y(&ES(&%L<V\@=7-E9`H@("`@("H@
M:68@82!S>6YC(&ES('-E;G0@:6X@;75L=&EP;&4@;65S<V%G97,@9'5E('1O
M(&UE<W-A9V4@<VEZ92!R97-T<FEC=&EO;G,N"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]D;VYE.PH*("`@(&9U;F-T:6]N
M(%-Y;F--3%]3>6YC*"1A;&5R="P@)'-E<G9E<E5222P@)&-L:65N=%5222D*
M("`@('L*("`@("`@("`D=&AI<RT^7V%L97)T(#T@)&%L97)T.PH@("`@("`@
M("1T:&ES+3Y?<&5N9&EN9T5L96UE;G1S(#T@9F%L<V4["B`@("`@("`@)'1H
M:7,M/E]D;VYE(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W1A<F=E=$QO
M8U5222`](&)A<V5N86UE*"1S97)V97)54DDI.PH@("`@("`@("1T:&ES+3Y?
M<V]U<F-E3&]C55))(#T@)&-L:65N=%5223L*("`@("`@("!G;&]B86P@)&)A
M8VME;F0["B`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(F-R96%T92!F
M;W(@<WEN8U1Y<&4])'-E<G9E<E5222(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@
M4$5!4E],3T=?1$5"54<I.PH@("`@?0H*("`@("\J*@H@("`@("H@2&5R92=S
M('=H97)E('1H92!A8W1U86P@<')O8V5S<VEN9R!O9B!A(&-L:65N="US96YT
M(%-Y;F,*("`@("`J($ET96T@=&%K97,@<&QA8V4N($5N=')I97,@87)E(&%D
M9&5D+"!D96QE=&5D(&]R(')E<&QA8V5D"B`@("`@*B!F<F]M('1H92!S97)V
M97(@9&%T86)A<V4@8GD@=7-I;F<@2&]R9&4@05!)("A296=I<W1R>2D@8V%L
M;',N"B`@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L95-Y;F-)=&5M*"1I=&5M
M*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@)'-T
M871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["B`@("`@("`@)&1E
M=FEC92`]("8D<W1A=&4M/F=E=$1E=FEC92@I.PH@("`@("`@("1S>6YC261E
M;G1I9FEE<B`]("1S=&%T92T^9V5T4WEN8TED96YT:69I97(H*3L*"B`@("`@
M("`@)&AO<F1E5'EP92`]("1T>7!E(#T@)'1H:7,M/E]T87)G971,;V-54DD[
M"@H@("`@("`@("\O(%5S92!C;VYT96YT5'EP92!E>'!L:6-I=&QY('-P96-I
M9FEE9"!I;B!T:&ES('-Y;F,@8V]M;6%N9"X*("`@("`@("`D8V]N=&5N=%1Y
M<&4@/2`D:71E;2T^9V5T0V]N=&5N=%1Y<&4H*3L*"B`@("`@("`@+R\@268@
M;F]T('!R;W9I9&5D+"!U<V4@9&5F875L="!F<F]M(&1E=FEC92!I;F9O+@H@
M("`@("`@(&EF("@A)&-O;G1E;G14>7!E*2!["B`@("`@("`@("`@("1C;VYT
M96YT5'EP92`]("1D979I8V4M/F=E=%!R969E<G)E9$-O;G1E;G14>7!E*"1T
M>7!E*3L*("`@("`@("!]"@H@("`@("`@(&QI<W0H)&-O;G1E;G0L("1C;VYT
M96YT5'EP92D@/0H@("`@("`@("`@("`D9&5V:6-E+3YC;VYV97)T0VQI96YT
M,E-E<G9E<B@D:71E;2T^9V5T0V]N=&5N="@I+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N=%1Y<&4I.PH@("`@
M("`@("1C=6ED(#T@)&ET96TM/F=E=$-U:60H*3L*("`@("`@("`D<W5I9"`]
M(&9A;'-E.PH*("`@("`@("`O+R!(86YD;&4@8VQI96YT(&%D9"!R97%U97-T
M<RX*("`@("`@("!I9B`H)&ET96TM/F=E=$5L96UE;G14>7!E*"D@/3TG061D
M)RD@>PH@("`@("`@("`@("`D<W5I9"`]("1B86-K96YD+3YI;7!O<G1%;G1R
M>2@D<WEN8TED96YT:69I97(L("1H;W)D951Y<&4L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT+"`D8V]N=&5N
M=%1Y<&4L("1C=6ED*3L*("`@("`@("`@("`@:68@*"%I<U]A*"1S=6ED+"`G
M4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D<W1A=&4M/FQO9R@B
M0VQI96YT+4%D9"(I.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE
M<W-A9V4H)V%D9&5D(&-L:65N="!E;G1R>2!A<R`G("X@)'-U:60L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*")#;&EE;G0M061D1F%I;'5R
M92(I.PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)T5R
M<F]R(&EN(&%D9&EN9R!C;&EE;G0@96YT<GDZ)R`N("1S=6ED+3YM97-S86=E
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@
M("`@('T*"B`@("`@("`@+R\@2&%N9&QE(&-L:65N="!D96QE=&4@<F5Q=65S
M=',N"B`@("`@("`@?2!E;'-E:68@*"1I=&5M+3YG971%;&5M96YT5'EP92@I
M(#T])T1E;&5T92<I('L*("`@("`@("`@("`@)'-U:60@/2`D8F%C:V5N9"T^
M9&5L971E16YT<GDH)'-Y;F-)9&5N=&EF:65R+"`D='EP92P@)&-U:60I.PH@
M("`@("`@("`@("!I9B`H)'1Y<&4@/3T@)V-A;&5N9&%R)PH@("`@("`@("`@
M("`@("`@)B8@)&1E=FEC92T^:&%N9&QE5&%S:W-);D-A;&5N9&%R*"DI('L*
M("`@("`@("`@("`@("`@("\O(&1E;&5T945N=')Y(&1O97,@;F]T(&YE960@
M=&\@<F5T=7)N(&%N(&5R<F]R(&]N"B`@("`@("`@("`@("`@("`O+R!D96QE
M=&EO;B!O9B!N;VYE>&ES=&5N="!E;G1R:65S+B!3;R!J=7-T('1O(&)E('-U
M<F4*("`@("`@("`@("`@("`@("\O('=E(&AA=F4@=&\@9&5L971E(&9R;VT@
M=&AE('1A<VMS(&1A=&%B87-E(&%S('=E;&PZ"B`@("`@("`@("`@("`@("`D
M8F%C:V5N9"T^;&]G365S<V%G92@G<W!E8VEA;"!T87-K<R!D96QE=&4@)R`N
M("1S=6ED("X@)R!D=64@=&\@8VQI96YT(')E<75E<W0G+"!?7T9)3$5?7RP@
M7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@("`@("1S
M=6ED(#T@)&)A8VME;F0M/F1E;&5T945N=')Y*"1S>6YC261E;G1I9FEE<BP@
M)W1A<VMS)RP@)&-U:60I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@A:7-?82@D<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@
M("`@)'-T871E+3YL;V<H(D-L:65N="U$96QE=&4B*3L*("`@("`@("`@("`@
M("`@("1B86-K96YD+3YL;V=-97-S86=E*"=D96QE=&5D(&5N=')Y("<@+B`D
M<W5I9"`N("<@9'5E('1O(&-L:65N="!R97%U97-T)RP@7U]&24Q%7U\L(%]?
M3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<W1A=&4M/FQO9R@B0VQI96YT+41E;&5T949A
M:6QU<F4B*3L*("`@("`@("`@("`@("`@("1T:&ES+3YL;V=-97-S86=E*"=&
M86EL=7)E(&1E;&5T:6YG(&-L:65N="!E;G1R>2P@;6%Y8F4@9V]N92!A;')E
M861Y(&]N('-E<G9E<BX@;7-G.B<N("1S=6ED+3YM97-S86=E+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@("`@("`@('T*"B`@
M("`@("`@+R\@2&%N9&QE(&-L:65N="!R97!L86-E(')E<75E<W1S+@H@("`@
M("`@('T@96QS96EF("@D:71E;2T^9V5T16QE;65N=%1Y<&4H*2`]/2`G4F5P
M;&%C92<I('L*("`@("`@("`@("`@)'-U:60@/2`D8F%C:V5N9"T^<F5P;&%C
M945N=')Y*"1S>6YC261E;G1I9FEE<BP@)&AO<F1E5'EP92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT+"`D
M8V]N=&5N=%1Y<&4L("1C=6ED*3L*"B`@("`@("`@("`@(&EF("@A:7-?82@D
M<W5I9"P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)'-T871E
M+3YL;V<H(D-L:65N="U297!L86-E(BD["B`@("`@("`@("`@("`@("`D8F%C
M:V5N9"T^;&]G365S<V%G92@G<F5P;&%C960@96YT<GD@)R`N("1S=6ED("X@
M)R!D=64@=&\@8VQI96YT(')E<75E<W0G+"!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"1S=6ED+3YM97-S86=E
M+"!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@
M("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"1S=6ED+"!?7T9)3$5?
M7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("`@
M("`O+R!%;G1R>2!M87D@:&%V92!B965N(&1E;&5T960[('1R>2!A9&1I;F<@
M:70N"B`@("`@("`@("`@("`@("`D<W5I9"`]("1B86-K96YD+3YI;7!O<G1%
M;G1R>2@D<WEN8TED96YT:69I97(L("1H;W)D951Y<&4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]N=&5N="P@
M)&-O;G1E;G14>7!E+"`D8W5I9"D["B`@("`@("`@("`@("`@("!I9B`H(6ES
M7V$H)'-U:60L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("`@
M("`D<W1A=&4M/FQO9R@B0VQI96YT+4%D9%)E<&QA8V4B*3L*("`@("`@("`@
M("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G861D960@8VQI96YT
M(&5N=')Y(&1U92!T;R!R97!L86-E(')E<75E<W0@87,@)R`N("1S=6ED+"!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'-T871E+3YL
M;V<H(D-L:65N="U!9&1&86EL=7)E(BD["B`@("`@("`@("`@("`@("`@("`@
M)&)A8VME;F0M/FQO9TUE<W-A9V4H)T5R<F]R(&EN(&%D9&EN9R!C;&EE;G0@
M96YT<GD@9'5E('1O(')E<&QA8V4@<F5Q=65S=#HG("X@)'-U:60M/FUE<W-A
M9V4L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*"=5;F5X<&5C=&5D(&5L
M96UE;G14>7!E.B`G("X@)&ET96TM/F=E=$5L96UE;G14>7!E*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?15)2*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<W5I9#L*("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82`F;'0[4WEN
M8R9G=#L@;W5T<'5T+@H@("`@("HO"B`@("!F=6YC=&EO;B!C<F5A=&53>6YC
M3W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@
M("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@
M("1A='1R<R`](&%R<F%Y*"D["@H@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G4WEN8R<L("1A='1R<RD["B`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#
M;61)1"<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D
M8W5R<F5N=$-M9$E$*3L*("`@("`@("`D8W5R<F5N=$-M9$E$*RL["B`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD
M240G*3L*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=487)G970G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T
M=')S*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?<V]U
M<F-E3&]C55))*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T
M92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G970G*3L*"B`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R
M8V4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T=')S*3L*("`@("`@("`D
M;W5T<'5T+3YC:&%R86-T97)S*"1T:&ES+3Y?=&%R9V5T3&]C55))*3L*("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,
M;V-54DDG*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=3;W5R8V4G*3L*"B`@("`@("`@)'-Y;F-4>7!E(#T@)'1H
M:7,M/E]T87)G971,;V-54DD["@H@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*
M("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B:&%N9&QE4WEN8R!F;W(@
M<WEN8U1Y<&4])'-Y;F-4>7!E(BP@7U]&24Q%7U\L(%]?3$E.15]?+"!014%2
M7TQ/1U]$14)51RD["@H@("`@("`@("\O($AE<F4G<R!W:&5R92!S97)V97(@
M;6]D:69I8V%T:6]N<R!A<F4@<V5N="!T;R!T:&4@8VQI96YT.@H@("`@("`@
M("1R969T<R`]("1S=&%T92T^9V5T4V5R=F5R06YC:&]R3&%S="@D<WEN8U1Y
M<&4I.PH@("`@("`@("1C=7)R96YT0VUD240@/2`D=&AI<RT^:&%N9&QE4WEN
M8R@D8W5R<F5N=$-M9$E$+"`D<WEN8U1Y<&4L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70L("1R969T<RD["@H@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)U-Y;F,G*3L*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!396YD<R!S97)V97(@8VAA;F=E<R!T;R!T:&4@
M8VQI96YT+@H@("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&53>6YC*"1C=7)R
M96YT0VUD240L("1S>6YC5'EP92P@)B1O=71P=70L("1R969T<RP@)&5N9%]T
M<R`](#`I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH@("`@("`@
M(&=L;V)A;"`D;65S<V%G949U;&P["@H@("`@("`@("\J("1M97-S86=E1G5L
M;"!W:6QL(&)E('-E="!T;R!T<G5E('1O(&EN9&EC871E('1H870@=&AE<F4G
M<R!N;R!R;V]M"B`@("`@("`@("H@9F]R(&]T:&5R(&1A=&$@:6X@=&AI<R!M
M97-S86=E+B!)9B!I="=S(&9A;'-E("AE;7!T>2D@86YD('1H97)E"B`@("`@
M("`@("H@87)E('!E;F1I;F<@4WEN8R!D871A+"!T:&4@9FEN86P@8V]M;6%N
M9"!W:6QL('-E;G0@=&AE('!E;F1I;F<@9&%T82X*("`@("`@("`@*B!4:&ES
M(&=L;V)A;"!D871A('-H;W5L9"!B92!M;W9E9"!T;R!A(&=L;V)A;"!O8FIE
M8W0L('1O9V5T:&5R"B`@("`@("`@("H@=VET:"!C=7)R96YT0VUD240@86YD
M("1O=71P=70N("HO"B`@("`@("`@)&UE<W-A9V5&=6QL(#T@9F%L<V4["@H@
M("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@
M("`@("`@("1D979I8V4@/2`F)'-T871E+3YG971$979I8V4H*3L*("`@("`@
M("`D<WEN8TED96YT:69I97(@/2`D<W1A=&4M/F=E=%-Y;F-)9&5N=&EF:65R
M*"D["B`@("`@("`@)&-O;G1E;G14>7!E(#T@)&1E=FEC92T^9V5T4')E9F5R
M<F5D0V]N=&5N=%1Y<&5#;&EE;G0H)'-Y;F-4>7!E+"`D=&AI<RT^7W-O=7)C
M94QO8U5222D["@H@("`@("`@("\J(%=E(&9A:71H9G5L;'D@97AP96-T('1O
M(&1E86P@=VET:"!A;&P@<F5M86EN:6YG(&5L96UE;G1S+B!7:6QL(&)E"B`@
M("`@("`@("H@<V5T('1O('1R=64@:68@=V4@<G5N(&]U="!O9B!S<&%C92!F
M;W(@;65S<V%G92!C<F5A=&EO;BX@*B\*("`@("`@("`D=&AI<RT^<V5T4&5N
M9&EN9T5L96UE;G1S*&9A;'-E*3L*"B`@("`@("`@+R\@2&%N9&QE(&1E;&5T
M:6]N<RX*("`@("`@("`D9&5L971I;VYS(#T@)&)A8VME;F0M/F=E=%-E<G9E
M<D1E;&5T:6]N<R@D<WEN8TED96YT:69I97(L("1S>6YC5'EP92P@)')E9G1S
M+"`D96YD7W1S*3L*"B`@("`@("`@:68@*"1R969T<R`^(#`I('L*("`@("`@
M("`@("`@+R\@1&]N)W0@<V5N9"!D96QE=&5S(&]N(%-L;W=3>6YC+@H@("`@
M("`@("`@("!F;W)E86-H("@D9&5L971I;VYS(&%S("1S=6ED(#T^("1C=6ED
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O;F5;)'-U:61=(#T@=')U
M93L*("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E*")D96QE
M=&4Z(&-U:60])&-U:60@<W5I9#TD<W5I9"!R969T<SH@)')E9G1S(BP@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("`@("`O+R!#<F5A=&4@82!$96QE=&4@<F5Q=65S="!F;W(@8VQI96YT+@H@
M("`@("`@("`@("`@("`@)&-U<G)E;G1#;61)1"`]("1T:&ES+3YO=71P=71#
M;VUM86YD*"1C=7)R96YT0VUD240L("1O=71P=70L("=$96QE=&4G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&YU;&PL(&YU;&PL("1C=6ED+"!N=6QL*3L*("`@("`@("`@("`@("`@
M("1S=&%T92T^;&]G*"=397)V97(M1&5L971E)RD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@+R\@2&%N9&QE(&%D9&ET:6]N<RX*("`@("`@
M("`D861D<R`]("1B86-K96YD+3YG971397)V97)!9&1I=&EO;G,H)'-Y;F-)
M9&5N=&EF:65R+"`D<WEN8U1Y<&4L("1R969T<RP@)&5N9%]T<RD["B`@("`@
M("`@9F]R96%C:"`H)&%D9',@87,@)'-U:60@/3X@)&-U:60I('L*("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V1O;F5;)'-U:61=*2D@>PH@("`@
M("`@("`@("`@("`@+R\@06QR96%D>2!S96YT(&1E;&5T92P@;F\@;F5E9"!T
M;R!A9&0N"B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B861D.B`D<W5I
M9"(L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH*("`@
M("`@("`@("`@)&,@/2`D8F%C:V5N9"T^<F5T<FEE=F5%;G1R>2@D<WEN8U1Y
M<&4L("1S=6ED+"`D8V]N=&5N=%1Y<&4I.PH@("`@("`@("`@("!I9B`H(6ES
M7V$H)&,L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("\O($ET
M96T@:6X@:&ES=&]R>2!B=70@;F]T(&EN(&1A=&%B87-E+B!3=')A;F=E+"!B
M=70@8V%N(&AA<'!E;BX*("`@("`@("`@("`@("`@(&QI<W0H)&-L:65N=$-O
M;G1E;G0L("1C;&EE;G1#;VYT96YT5'EP92D@/0H@("`@("`@("`@("`@("`@
M("`@("1D979I8V4M/F-O;G9E<G1397)V97(R0VQI96YT*"1C+"`D8V]N=&5N
M=%1Y<&4I.PH@("`@("`@("`@("`@("`@+R\@0VAE8VL@:68@=V4@:&%V92!S
M<&%C92!L969T(&EN('1H92!M97-S86=E+@H@("`@("`@("`@("`@("`@:68@
M*"@D<W1A=&4M/F=E=$UA>$US9U-I>F4H*0H@("`@("`@("`@("`@("`@("`@
M("T@)&]U='!U="T^9V5T3W5T<'5T4VEZ92@I"B`@("`@("`@("`@("`@("`@
M("`@+2!S=')L96XH)&-L:65N=$-O;G1E;G0I*2`\(#4P*2!["B`@("`@("`@
M("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)VUA>"!M97-S86=E
M('-I>F4@<F5A8VAE9"!C=7)S:7IE/2<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("1O=71P=70M/F=E=$]U='!U=%-I>F4H
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?
M7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@
M("`@("`@("`@("`D;65S<V%G949U;&P@/2!T<G5E.PH@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971096YD:6YG16QE;65N=',H=')U92D["B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O;F5;)'-U:61=
M(#T@=')U93L*("`@("`@("`@("`@("`@("1C=7)R96YT0VUD240@/2`D=&AI
M<RT^;W5T<'5T0V]M;6%N9"@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=!9&0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;&EE;G1#;VYT96YT+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;&EE;G1#;VYT96YT5'EP92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=6ED
M*3L*("`@("`@("`@("`@("`@("1S=&%T92T^;&]G*"=397)V97(M061D)RD[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D8F%C:V5N
M9"T^;&]G365S<V%G92@G87!I(&5X<&]R="!C86QL(&9O<B`G("X@)'-U:60@
M+B`G(&9A:6QE9#H@("<@+B`D8RT^9V5T365S<V%G92@I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\O($AA;F1L92!C:&%N9V5S+@H@("`@("`@(&EF("@D<F5F=',@
M(3T@,"D@>PH@("`@("`@("`@("`O+R!$;VXG="!S96YD(&-H86YG97,@9F]R
M(%-L;W=3>6YC+"!C;VYF=7-E<R!S;VUE(&-L:65N=',N"B`@("`@("`@("`@
M("1E;F1?=',@/2!T:6UE*"D["B`@("`@("`@("`@("1C:&%N9V5S(#T@)&)A
M8VME;F0M/F=E=%-E<G9E<DUO9&EF:6-A=&EO;G,H)'-Y;F-)9&5N=&EF:65R
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S>6YC5'EP92P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5F=',L("1E
M;F1?=',I.PH@("`@("`@("`@("!I9B`H:7-?82@D8VAA;F=E<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A
M9V4H)&-H86YG97,L(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?15)2
M*3L*("`@("`@("`@("`@("`@(')E='5R;B`D8VAA;F=E<SL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H)&-H86YG97,@87,@)'-U:60@
M/3X@)&-U:60I('L*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)'1H:7,M
M/E]D;VYE6R1S=6ED72DI('L*("`@("`@("`@("`@("`@("`@("`O+R!!;')E
M861Y('-E;G0@9&5L971E(&]R(&%D9"P@;F\@;F5E9"!T;R!M;V1I9GDN"B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@:68@*"$D8W5I9"D@>PH@("`@("`@("`@("`@
M("`@("`@("\O(%1/1$\Z(&-R96%T92!A;B`B861D(B!H97)E(&EN<W1E860_
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)&,@/2`D8F%C:V5N9"T^<F5T<FEE=F5%
M;G1R>2@D<WEN8U1Y<&4L("1S=6ED+"`D8V]N=&5N=%1Y<&4I.PH@("`@("`@
M("`@("`@("`@:68@*"%I<U]A*"1C+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H(F-H86YG93H@
M)'-U:60B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@("`@
M("`@("`@("`@("`@("`@(&QI<W0H)&-L:65N=$-O;G1E;G0L("1C;&EE;G1#
M;VYT96YT5'EP92D@/0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5V:6-E
M+3YC;VYV97)T4V5R=F5R,D-L:65N="@D8RP@)&-O;G1E;G14>7!E*3L*("`@
M("`@("`@("`@("`@("`@("`O+R!#:&5C:R!I9B!W92!H879E('-P86-E(&QE
M9G0@:6X@=&AE(&UE<W-A9V4N"B`@("`@("`@("`@("`@("`@("`@:68@*"@D
M<W1A=&4M/F=E=$UA>$US9U-I>F4H*0H@("`@("`@("`@("`@("`@("`@("`@
M("`@+2`D;W5T<'5T+3YG971/=71P=713:7IE*"D*("`@("`@("`@("`@("`@
M("`@("`@("`@("T@<W1R;&5N*"1C;&EE;G1#;VYT96YT*2D@/"`U,"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@G
M;6%X(&UE<W-A9V4@<VEZ92!R96%C:&5D(&-U<G-I>F4])PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1O=71P=70M
M/F=E=$]U='!U=%-I>F4H*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/
M1U]$14)51RD["B`@("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E1G5L
M;"`]('1R=64["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS9710
M96YD:6YG16QE;65N=',H=')U92D["B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O;F5;)'-U:61=(#T@=')U
M93L*("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'1H:7,M
M/F]U='!U=$-O;6UA;F0H)&-U<G)E;G1#;61)1"P@)&]U='!U="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)U)E<&QA8V4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8VQI96YT0V]N=&5N="P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-L:65N=$-O;G1E;G14>7!E+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8W5I9"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"D["B`@("`@("`@("`@("`@("`@("`@
M)'-T871E+3YL;V<H)U-E<G9E<BU297!L86-E)RD["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O($ET96T@:6X@:&ES
M=&]R>2!B=70@;F]T(&EN(&1A=&%B87-E+B!3=')A;F=E+"!B=70*("`@("`@
M("`@("`@("`@("`@("`O+R!C86X@:&%P<&5N+@H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!)9B!T87-K
M<R!A<F4@:&%N9&QE9"!I;G-I9&4@8V%L96YD87(L(&1O('1H92!S86UE(&%G
M86EN(&9O<@H@("`@("`@("\O('1A<VMS+@H@("`@("`@(&EF("@D<WEN8U1Y
M<&4@/3T@)V-A;&5N9&%R)R`F)B`D9&5V:6-E+3YH86YD;&5487-K<TEN0V%L
M96YD87(H*2D@>PH@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B
M:&%N9&QI;F<@=&%S:W,@:6X@8V%L96YD87(@<WEN8R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!
M4E],3T=?1$5"54<I.PH*("`@("`@("`@("`@)&-U<G)E;G1#;61)1"`]("1T
M:&ES+3YH86YD;&53>6YC*"1C=7)R96YT0VUD240L("=T87-K<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W5T
M<'5T+"`D<F5F=',L("1E;F1?=',I.PH@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@("`@+RHJ"B`@("`@*B!/=71P
M=70@82!S:6YG;&4@4WEN8R!C;VUM86YD("A!9&0L($1E;&5T92P@4F5P;&%C
M92DN"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U=$-O;6UA;F0H)&-U<G)E
M;G1#;61)1"P@)B1O=71P=70L("1C;VUM86YD+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D8V]N=&5N="P@)&-O;G1E;G14>7!E(#T@;G5L;"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U:60@/2!N=6QL+"`D<W5I9"`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'-T871E(#T@)B1?4T534TE/3ELG4WEN
M8TU,+G-T871E)UT["@H@("`@("`@("1A='1R<R`](&%R<F%Y*"D["B`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("1C
M;VUM86YD+"`D871T<G,I.PH*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)T-M9$E$)RP@)&%T=')S*3L*("`@("`@
M("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@("`@("`@("1O=71P=70M/F-H
M87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<I.PH*("`@("`@("!I9B`H:7-S
M970H)&-O;G1E;G14>7!E*2D@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUE=&$G+"`D871T<G,I.PH@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DE-971A*"DL("=4>7!E)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U
M="T^8VAA<F%C=&5R<R@D8V]N=&5N=%1Y<&4I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))365T82@I+"`G5'EP92<I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=-971A)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H
M)&-O;G1E;G0I"B`@("`@("`@("`@('Q\(&ES<V5T*"1C=6ED*2!\?"!I<W-E
M="@D<W5I9"DI('L*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*("`@("`@("`@
M("`@:68@*"1S=6ED("$](&YU;&PI('L*("`@("`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E)RP@
M)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T=')S*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)'-U:60I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G3&]C55)))RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R8V4G*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*"1C=6ED("$](&YU;&PI('L*("`@("`@("`@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G5&%R9V5T)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G3&]C55)))RP@)&%T
M=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-U
M:60I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%5222@I+"`G3&]C55)))RD["B`@("`@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G970G*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&-O;G1E;G0I
M*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)T1A=&$G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8V]N=&5N="D["B`@("`@("`@("`@
M("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=$
M871A)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<I.PH@("`@("`@('T*
M"B`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`D8V]M;6%N9"D["@H@("`@("`@("1C=7)R96YT0VUD240K*SL*"B`@("`@
M("`@<F5T=7)N("1C=7)R96YT0VUD240["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T4&5N9&EN9T5L96UE;G1S*"1E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<&5N9&EN9T5L96UE;G1S(#T@)&4["B`@("!]"@H@("`@9G5N8W1I;VX@:&%S
M4&5N9&EN9T5L96UE;G1S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]P96YD:6YG16QE;65N=',["B`@("!]"@I]"@``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]N<W1A;G1S+G!H<```````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S$Q,B`Q,#4Q-30S-#$S-B`P
M,C(Q,S,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RHJ"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&
M;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J("1(;W)D93H@9G)A
M;65W;W)K+U-Y;F--3"]3>6YC34PO0V]N<W1A;G1S+G!H<"QV(#$N,2XR+C0@
M,C`P-B\P-2\P,2`Q,CHP-3HQ-"!J86X@17AP("0*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N
M;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F1E9FEN92@G04Q%4E1?1$E3
M4$Q!62<L(#$P,"D["@HO+R!.;W0@:6UP;&5M96YT960N"F1E9FEN92@G04Q%
M4E1?5%=/7U=!62<L(#(P,"D["F1E9FEN92@G04Q%4E1?4TQ/5U]364Y#)RP@
M,C`Q*3L*9&5F:6YE*"=!3$525%]/3D5?5T%97T923TU?0TQ)14Y4)RP@,C`R
M*3L*9&5F:6YE*"=!3$525%]2149215-(7T923TU?0TQ)14Y4)RP@,C`S*3L*
M9&5F:6YE*"=!3$525%]/3D5?5T%97T923TU?4T525D52)RP@,C`T*3L*9&5F
M:6YE*"=!3$525%]2149215-(7T923TU?4T525D52)RP@,C`U*3L*"B\O($YO
M="!I;7!L96UE;G1E9"X*9&5F:6YE*"=!3$525%]45T]?5T%97T)97U-%4E9%
M4B<L(#(P-BD["F1E9FEN92@G04Q%4E1?3TY%7U=!65]&4D]-7T-,245.5%]"
M65]315)615(G+"`R,#<I.PID969I;F4H)T%,15)47U)%1E)%4TA?1E)/35]#
M3$E%3E1?0EE?4T525D52)RP@,C`X*3L*9&5F:6YE*"=!3$525%]/3D5?5T%9
M7T923TU?4T525D527T)97U-%4E9%4B<L(#(P.2D["F1E9FEN92@G04Q%4E1?
M4D5&4D532%]&4D]-7U-%4E9%4E]"65]315)615(G+"`R,3`I.PH*9&5F:6YE
M*"=!3$525%]215-53%1?04Q%4E0G+"`R,C$I.PID969I;F4H)T%,15)47TY%
M6%1?34534T%'12<L(#(R,BD["F1E9FEN92@G04Q%4E1?3D]?14Y$7T]&7T1!
M5$$G+"`R,C,I.PH*9&5F:6YE*"=-24U%7U-93D--3%]834PG+"`G87!P;&EC
M871I;VXO=FYD+G-Y;F-M;"MX;6PG*3L*9&5F:6YE*"=-24U%7U-93D--3%]7
M0EA-3"<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL*W=B>&UL)RD["@ID969I
M;F4H)TU)345?4UE.0TU,7T1%5DE#15])3D9/7UA-3"<L("=A<'!L:6-A=&EO
M;B]V;F0N<WEN8VUL+61E=FEN9BMX;6PG*3L*9&5F:6YE*"=-24U%7U-93D--
M3%]$159)0T5?24Y&3U]70EA-3"<L("=A<'!L:6-A=&EO;B]V;F0N<WEN8VUL
M+61E=FEN9BMW8GAM;"<I.PH*9&5F:6YE*"=-24U%7U1%6%1?4$Q!24XG+"`G
M=&5X="]P;&%I;B<I.PID969I;F4H)TU)345?5D-!4D1?5C(Q)RP@)W1E>'0O
M>"UV8V%R9"<I.PID969I;F4H)TU)345?5D-!4D1?5C,P)RP@)W1E>'0O=F-A
M<F0G*3L*"F1E9FEN92@G34E-15]60T%,14Y$05(G+"`G=&5X="]X+79C86QE
M;F1A<B<I.PID969I;F4H)TU)345?24-!3$5.1$%2)RP@)W1E>'0O8V%L96YD
M87(G*3L*9&5F:6YE*"=-24U%7UA-3%])0T%,14Y$05(G+"`G87!P;&EC871I
M;VXO=FYD+G-Y;F-M;"UX8V%L)RD["@ID969I;F4H)TU)345?34534T%'12<L
M("=T97AT+VUE<W-A9V4G*3L*"F1E9FEN92@G34E-15]364Y#34Q?6$U,7T5-
M04E,)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PM>&US9R<I.PID969I;F4H
M)TU)345?4UE.0TU,7UA-3%]"3T]+34%22R<L("=A<'!L:6-A=&EO;B]V;F0N
M<WEN8VUL+7AB;V]K;6%R:R<I.PID969I;F4H)TU)345?4UE.0TU,7U)%3$%4
M24].04Q?3T)*14-4)RP@)V%P<&QI8V%T:6]N+W9N9"YS>6YC;6PM>')E;&%T
M:6]N86PG*3L*"F1E9FEN92@G4D534$].4T5?24Y?4%)/1U)%4U,G+"`Q,#$I
M.PH*9&5F:6YE*"=215-03TY315]/2R<L(#(P,"D["F1E9FEN92@G4D534$].
M4T5?251%35]!1$1%1"<L(#(P,2D["F1E9FEN92@G4D534$].4T5?04-#15!4
M141?1D]27U!23T-%4U-)3D<G+"`R,#(I.PID969I;F4H)U)%4U!/3E-%7TY/
M3D%55$A/4DE!5$%4259%7U)%4U!/3E-%)RP@,C`S*3L*9&5F:6YE*"=215-0
M3TY315].3U]#3TY414Y4)RP@,C`T*3L*9&5F:6YE*"=215-03TY315]215-%
M5%]#3TY414Y4)RP@,C`U*3L*9&5F:6YE*"=215-03TY315]005)424%,7T-/
M3E1%3E0G+"`R,#8I.PID969I;F4H)U)%4U!/3E-%7T-/3D9,24-47U)%4T],
M5D5$7U=)5$A?34521T4G+"`R,#<I.PID969I;F4H)U)%4U!/3E-%7T-/3D9,
M24-47U)%4T],5D5$7U=)5$A?0TQ)14Y47U=)3DY)3D<G+"`R,#@I.PID969I
M;F4H)U)%4U!/3E-%7T-/3D9)3$-47U)%4T],5D5$7U=)5$A?1%503$E#051%
M)RP@,C`Y*3L*9&5F:6YE*"=215-03TY315]$14Q%5$5?5TE42$]55%]!4D-(
M259%)RP@,C$P*3L*9&5F:6YE*"=215-03TY315])5$5-7TY/7T1%3$54140G
M+"`R,3$I.PID969I;F4H)U)%4U!/3E-%7T%55$A%3E1)0T%424].7T%#0T50
M5$5$)RP@,C$R*3L*9&5F:6YE*"=215-03TY315]#2%5.2T5$7TE414U?04-#
M15!4141?04Y$7T)51D9%4D5$)RP@,C$S*3L*9&5F:6YE*"=215-03TY315]/
M4$52051)3TY?0T%.0T5,3$5$)RP@,C$T*3L*9&5F:6YE*"=215-03TY315].
M3U]%6$5#551%1"<L(#(Q-2D["F1E9FEN92@G4D534$].4T5?051/34E#7U)/
M3$Q?0D%#2U]/2R<L(#(Q-BD["@ID969I;F4H)U)%4U!/3E-%7TU53%1)4$Q%
M7T-(3TE#15,G+"`S,#`I.PHO+R!.965D('1O(&-H86YG92!N86UE<RX*+R\@
M9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`Q*3L*+R\@
M9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`R*3L*+R\@
M9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`S*3L*+R\@
M9&5F:6YE*"=215-03TY315]-54Q425!,15]#2$])0T53)RP@,S`T*3L*9&5F
M:6YE*"=215-03TY315]54T5?4%)/6%DG+"`S,#4I.PH*9&5F:6YE*"=215-0
M3TY315]"041?4D5154535"<L(#0P,"D["F1E9FEN92@G4D534$].4T5?24Y6
M04Q)1%]#4D5$14Y424%,4R<L(#0P,2D["B\O($YE960@=&\@8VAA;F=E(&YA
M;65S+@HO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G
M+"`T,#(I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!
M3%,G+"`T,#,I.PID969I;F4H)U)%4U!/3E-%7TY/5%]&3U5.1"<L(#0P-"D[
M"B\O($YE960@=&\@8VAA;F=E(&YA;65S+@HO+R!D969I;F4H)U)%4U!/3E-%
M7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#4I.PHO+R!D969I;F4H)U)%4U!/
M3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#8I.PID969I;F4H)U)%4U!/
M3E-%7T-2141%3E1)04Q37TU)4U-)3D<G+"`T,#<I.PHO+R!D969I;F4H)U)%
M4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#@I.PHO+R!D969I;F4H
M)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,#DI.PHO+R!D969I
M;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,3`I.PHO+R!D
M969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,3$I.PHO
M+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T,3(I
M.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G+"`T
M,3,I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,G
M+"`T,30I.PHO+R!D969I;F4H)U)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!
M3%,G+"`T,34I.PID969I;F4H)U)%4U!/3E-%7U)%455%4U1?4TE:15]43T]?
M0DE')RP@-#$V*3L*+R\@3F5E9"!T;R!C:&%N9V4@;F%M97,N"B\O(&1E9FEN
M92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0Q-RD["B\O(&1E
M9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0Q."D["B\O
M(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0Q.2D[
M"B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L(#0R
M,"D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4R<L
M(#0R,2D["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,
M4R<L(#0R,BD["B\O(&1E9FEN92@G4D534$].4T5?24Y604Q)1%]#4D5$14Y4
M24%,4R<L(#0R,RD["F1E9FEN92@G4D534$].4T5?4TE:15]-25--051#2"<L
M(#0R-"D["@ID969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3`P
M*3L*+R\@3F5E9"!T;R!C:&%N9V4@;F%M97,N"B\O(&1E9FEN92@G4D534$].
M4T5?0T]-34%.1%]&04E,140G+"`U,#$I.PHO+R!D969I;F4H)U)%4U!/3E-%
M7T-/34U!3D1?1D%)3$5$)RP@-3`R*3L*+R\@9&5F:6YE*"=215-03TY315]#
M3TU-04Y$7T9!24Q%1"<L(#4P,RD["B\O(&1E9FEN92@G4D534$].4T5?0T]-
M34%.1%]&04E,140G+"`U,#0I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!
M3D1?1D%)3$5$)RP@-3`U*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$
M7T9!24Q%1"<L(#4P-BD["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&
M04E,140G+"`U,#<I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)
M3$5$)RP@-3`X*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%
M1"<L(#4P.2D["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,140G
M+"`U,3`I.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@
M-3$Q*3L*+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4Q
M,BD["B\O(&1E9FEN92@G4D534$].4T5?0T]-34%.1%]&04E,140G+"`U,3,I
M.PHO+R!D969I;F4H)U)%4U!/3E-%7T-/34U!3D1?1D%)3$5$)RP@-3$T*3L*
M+R\@9&5F:6YE*"=215-03TY315]#3TU-04Y$7T9!24Q%1"<L(#4Q-2D["B\O
M(&1E9FEN92@G4D534$].4T5?051/34E#7U)/3$Q?0D%#2U]&04E,140G+"`U
M,38I.PH*9&5F:6YE*"=.04U%7U-004-%7U5225]364Y#34Q?,5\Q)RP@)W-Y
M;F-M;#IS>6YC;6PQ+C$G*3L*9&5F:6YE*"=.04U%7U-004-%7U5225]364Y#
M34PG+"`G<WEN8VUL.G-Y;F-M;"<I.PID969I;F4H)TY!345?4U!!0T5?55))
M7TU%5$E.1B<L("=S>6YC;6PZ;65T:6YF)RD["F1E9FEN92@G3D%-15]34$%#
M15]54DE?345424Y&7S%?,2<L("=S>6YC;6PZ;65T:6YF)RD["F1E9FEN92@G
M3D%-15]34$%#15]54DE?1$5624Y&)RP@)W-Y;F-M;#ID979I;F8G*3L*9&5F
M:6YE*"=.04U%7U-004-%7U5225]$159)3D9?,5\Q)RP@)W-Y;F-M;#ID979I
M;F8G*3L*"B\J*@H@*B!)9B!S970@=&\@=')U92P@;&]G<R!A;&P@:6YC;VUI
M;F<@86YD(&]U=&=O=6YD(&EC86QE;F1A<B]V8V%R9"!D871A"B`J('1O("]T
M;7`O<WEN8R]L;V<N='AT+B!4:&4@=V5B('-E<G9E<B!U<V5R("AL:6ME('=W
M=W)U;BD@;75S="!H879E"B`J('=R:71E(&%C8V5S<R!T;R!T:&ES(&9I;&4N
M"B`J+PID969I;F4H)T1%0E5'3$]'7TE#04Q%3D1!4D1!5$$G+"!T<G5E*3L*
M"B\J*@H@*B!)9B!S970@=&\@=')U92P@82!C;W!Y(&]F(&%N>2!$979);F8@
M<F5C96EV960@9G)O;2!C;&EE;G1S"B`J(&ES('-A=F5D('1O("]T;7`O<WEN
M8R]D979I;F8N='AT+@H@*B!4:&4@=V5B('-E<G9E<B!U<V5R("AL:6ME('=W
M=W)U;BD@;75S="!H879E"B`J('=R:71E(&%C8V5S<R!T;R!T:&ES(&9I;&4N
M"B`J+PH*9&5F:6YE*"=$14)51TQ/1U]$159)3D8G+"!T<G5E*3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O;&EB+U-Y;F--3"]$979I8V5);F9O+G!H<```````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q,C<V(#$P-3$U-#,T,3,V(#`R,C(P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*BH*("H@4WEN8TU,7T1E=FEC94EN9F\@<F5P<F5S96YT<R!A(&1E
M=FEC92!I;F9O<FUA=&EO;B!S970@86-C;W)D:6YG('1O('1H90H@*B!3>6YC
M34P@<W!E8RX*("H*("H@4V5E(&AT='`Z+R]W=W<N<WEN8VUL+F]R9R]D;V-S
M+W-Y;F-M;%]D979I;F9?=C$Q7S(P,#(P,C$U+G!D9@H@*@H@*B!!($1E=FEC
M94EN9F\@;V)J96-T(&ES(&-R96%T960@8GD@0V]M;6%N9"]0=70Z.E-Y;F--
M3%]#;VUM86YD7U!U="!F<F]M(&%N"B`J(&%P<')O<')I871E(%A-3"!M97-S
M86=E+B!3>6YC34Q?0V]M;6%N9%]0=70@9&ER96-T;'D@<&]P=6QA=&5S('1H
M92!M96UB97)S"B`J('9A<FEA8FQE<RX*("H*("H@5&AE(&-U<G)E;G0@:6UP
M;&5M96YT871I;VX@<VAO=6QD(&AA;F1L92!A;&P@1&5V26YF(#$N,2!$5$0@
M96QE;65N=',*("H@97AP8V5P="!$4TUE;2!E;G1R:65S+@H@*@H@*B!#;W!Y
M<FEG:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R
M9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F
M;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G
M+V-O<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO
M4WEN8TU,+U-Y;F--3"]$979I8V5);F9O+G!H<"QV(#$N,BXR+C8@,C`P-B\P
M-2\P-2`R,3HQ-#HT-2!K87)S=&5N($5X<"`D"B`J"B`J($!A=71H;W(@($MA
M<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G
M92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]$979I8V5);F9O('L*"B`@("!V
M87(@)%]697)$5$0["B`@("!V87(@)%]-86X["B`@("!V87(@)%]-;V0["B`@
M("!V87(@)%]/14T["B`@("!V87(@)%]&=U8["B`@("!V87(@)%]3=U8["B`@
M("!V87(@)%](=U8["B`@("!V87(@)%]$979)1#L*("`@('9A<B`D7T1E=E1Y
M<#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&]F(%-Y;F--3%]$871A4W1O<F4@
M;V)J96-T<RX*("`@("`J+PH@("`@=F%R("1?1&%T85-T;W)E.PH*("`@("\J
M*@H@("`@("H@07)R87DZ($-45'EP92`]/B!A<G)A>3H@4')O<&5R='E.86UE
M(#T^(%-Y;F--3%]0<F]P97)T>2!O8FIE8W0N"B`@("`@*B\*("`@('9A<B`D
M7T-40V%P.PH*("`@("\J*@H@("`@("H@07)R87D@6$YA;2`]/B!A<G)A>2!O
M9B!8=F%L(&5N=')I97,N"B`@("`@*B\*("`@('9A<B`D7T5X=#L*"B`@("`O
M*BH*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]55$,[
M"@H@("`@+RHJ"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R
M("1?4W5P<&]R=$QA<F=E3V)J<SL*"B`@("`O*BH*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]3=7!P;W)T3G5M8F5R3V9#:&%N9V5S
M.PH*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE($1E=DEN9B!D871A(&9O
M<B!A(&1A=&%S=&]R92!I9&5N=&EF:65D(&)Y("1S;W5R8V554DD*("`@("`J
M("A?4V]U<F-E4F5F('!A<F%M971E<BDN("!2971U<FYS(&$@4WEN8TU,7T1A
M=&%3=&]R92!O8FIE8W0@;W(@;G5L;"!I9@H@("`@("H@;F\@<W5C:"!D871A
M<W1O<F4@97AI<W1S+@H@("`@("HO(`H@("`@9G5N8W1I;VX@9V5T1&%T85-T
M;W)E*"1S;W5R8V554DDI"B`@("!["@H@("`@("`@(&EF("AI<U]A<G)A>2@D
M=&AI<RT^7T1A=&%3=&]R92DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]$871A4W1O<F4@87,@)'8I('L*("`@("`@("`@("`@("`@(&EF("@D
M=BT^7U-O=7)C95)E9B`]/2`D<V]U<F-E55))*2!["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1V.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0I]"@HO
M*BH*("H@5&AE(%-Y;F--3%]$871A4W1O<F4@8VQA<W,@9&5S8W)I8F5S(&]N
M92!O9B!T:&4@<&]S<VEB;&4@9&%T87-T;W)E<PH@*B`H:2YE+B!D871A8F%S
M97,I(&]F('1H92!D979I8V4N("!-;W-T(&EM<&]R=&%N="!A='1R:6)U=&5S
M(&%R92!T:&4*("H@<')E9F5R<F5D($UI;64@5'EP97,@9F]R('-E;F1I;F<@
M86YD(')E8V5I=FEN9R!D871A(&9O<B!T:&ES(&1A=&%S=&]R93H*("H@7U1X
M+5!R968@86YD(%]2>"U0<F5F"B`J"B`J($!P86-K86=E(%-Y;F--3`H@*B\*
M8VQA<W,@4WEN8TU,7T1A=&%3=&]R92!["@H@("`@+RHJ"B`@("`@*B!4:&4@
M;&]C86P@55))(&]F('1H92!D871A<W1O<F4N"B`@("`@*B\*("`@('9A<B`D
M7U-O=7)C95)E9CL*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@("`@("HO
M"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"B`@("`O*BH*("`@("`J($]P=&EO
M;F%L+@H@("`@("HO"B`@("!V87(@)%]-87A'54E$4VEZ93L*"B`@("`O*BH*
M("`@("`J($]N92!E;&5M96YT(&%R<F%Y(&]F($-45'EP92`]/B!697)#5`H@
M("`@("HO"B`@("!V87(@)%]2>%]0<F5F.PH*("`@("\J*@H@("`@("H@07)R
M87D@;V8@0U14>7!E(#T^(%9E<D-4"B`@("`@*B\*("`@('9A<B`D7U)X.PH*
M("`@("\J*@H@("`@("H@3VYE(&5L96UE;G0@87)R87D@;V8@0U14>7!E(#T^
M(%9E<D-4"B`@("`@*B\*("`@('9A<B`D7U1X7U!R968["@H@("`@+RHJ"B`@
M("`@*B!!<G)A>2!O9B!#5%1Y<&4@/3X@5F5R0U0*("`@("`J+PH@("`@=F%R
M("1?5'@["@H@("`@+RHJ"B`@("`@*B!/<'1I;VYA;"X*("`@("`J+PH@("`@
M=F%R("1?1%--96T["@H@("`@+RHJ"B`@("`@*B!!<G)A>2!3>6YC5'EP92`]
M/B!T<G5E"B`@("`@*B\*("`@('9A<B`D7U-Y;F-#87`["@H@("`@+RHJ"B`@
M("`@*B!2971U<FYS('1H92!P<F5F97)R960@8V]N=&5N='EP92!T:&4@8VQI
M96YT('=A;G1S('1O(')E8V5I=F4@*%)8*2X@3W(*("`@("`J($Y53$P@:68@
M;F]T('-P96-I9FEE9"`H=VAI8V@@:7,@;F]T(&%L;&]W960@8GD@<')O=&]C
M;VPI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G9710<F5F97)R96126$-O;G1E
M;G14>7!E*"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]2
M>%]0<F5F*2D@>PH@("`@("`@("`@("`D<B`](&%R<F%Y7VME>7,H)'1H:7,M
M/E]2>%]0<F5F*3L*("`@("`@("`@("`@<F5T=7)N("1R6S!=.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE('9E<G-I;VX@;V8@=&AE('!R969E<G)E9"!C;VYT96YT
M>7!E('1H92!C;&EE;G0@=V%N=',@=&\*("`@("`J(')E8V5I=F4@*%)8*2X@
M3W(@3E5,3"!I9B!N;W0@<W!E8VEF:65D("AW:&EC:"!I<R!N;W0@86QL;W=E
M9"!B>0H@("`@("H@<')O=&]C;VPI+@H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9710<F5F97)R96126$-O;G1E;G14>7!E5F5R<VEO;B@I"B`@("!["B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?4GA?4')E9BDI('L*("`@("`@("`@
M("`@)'(@/2!A<G)A>5]V86QU97,H)'1H:7,M/E]2>%]0<F5F*3L*("`@("`@
M("`@("`@<F5T=7)N("1R6S!=.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M3E5,3#L*("`@('T*?0H*+RHJ"B`J(%1H92!C;&%S<R!3>6YC34Q?4')O<&5R
M='D@:7,@=7-E9"!T;R!D969I;F4@82!S:6YG;&4@<')O<&5R='D@;V8@82!V
M8V%R9`H@*B!E;&5M96YT+B`@5&AE(&-O;G1E;G1S(&]F(&$@4')O<&5R='D@
M8V%N(&)E(&1E9FEN960@8GD@86X@96YU;65R871I;VX@;V8*("H@=F%L:60@
M=F%L=65S("A?5F%L16YU;2D@;W(@8GD@82!$871A5'EP92]3:7IE(&-O;6)I
M;F%T:6]N+"!O<B!N;W0@870@86QL+@H@*@H@*B!`<&%C:V%G92!3>6YC34P*
M("HO"F-L87-S(%-Y;F--3%]0<F]P97)T>2!["@H@("`@+RHJ"B`@("`@*B!!
M<G)A>2!O9B!V86QI9"!V86QU97,@/3X@=')U90H@("`@("HO"B`@("!V87(@
M)%]686Q%;G5M.PH*("`@("\J*@H@("`@("H@268@;F]T(%9A;$5N=6TN"B`@
M("`@*B\*("`@('9A<B`D7T1A=&%4>7!E.PH*("`@("\J*@H@("`@("H@268@
M;F]T(%9A;$5N=6TL(&]P=&EO;F%L+@H@("`@("HO"B`@("!V87(@)%]3:7IE
M.PH*("`@("\J*@H@("`@("H@3W!T:6]N86PN"B`@("`@*B\*("`@('9A<B`D
M7T1I<W!L87E.86UE.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@4&%R86U.
M86UE(#T^(%-Y;F--3%]0<F]P97)T>5!A<F%M971E<@H@("`@("HO"B`@("!V
M87(@)%]P87)A;7,["@I]"@HO*BH*("H@5&AE(&-L87-S(%-Y;F--3%]0<F]P
M97)T>5!A<F%M971E<B!I<R!U<V5D('1O(&1E9FEN92!A('-I;F=L92!P87)A
M;65T97(@;V8*("H@82!P<F]P97)T>2!O9B!A('9C87)D(&5L96UE;G0N("!4
M:&4@8V]N=&5N=',@;V8@82!0<F]P97)T>5!A<F%M971E<B!C86X@8F4*("H@
M9&5F:6YE9"!B>2!A;B!E;G5M97)A=&EO;B!O9B!V86QI9"!V86QU97,@*%]6
M86Q%;G5M*2!O<B!B>2!A($1A=&%4>7!E+U-I>F4*("H@8V]M8FEN871I;VXL
M(&]R(&YO="!A="!A;&PN"B`J"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA
M<W,@4WEN8TU,7U!R;W!E<G1Y4&%R86UE=&5R('L*"B`@("`O*BH*("`@("`J
M($EF('!R;W9I9&5D.B!A<G)A>2!O9B!686Q%;G5M(#T^('1R=64*("`@("`J
M+PH@("`@=F%R("1?5F%L16YU;3L*"B`@("`O*BH*("`@("`J($EF(&YO="!6
M86Q%;G5M+@H@("`@("HO"B`@("!V87(@)%]$871A5'EP93L*"B`@("`O*BH*
M("`@("`J($EF(&YO="!686Q%;G5M+"!O<'1I;VYA;"X*("`@("`J+PH@("`@
M=F%R("1?4VEZ93L*"B`@("`O*BH*("`@("`J($]P=&EO;F%L+@H@("`@("HO
M"B`@("!V87(@)%]$:7-P;&%Y3F%M93L*"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"YP:'``````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S4V-2`Q,#4Q-30S-#$S
M-B`P,C$U-3``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,+U-T871E+G!H<"<[
M"@HO*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD(&-L87-S('!R;W9I9&5S(&$@
M<W5P97(@8VQA<W,@9F\@4WEN8T)O9'D*("H@8V]M;6%N9',N"B`J"B`J("1(
M;W)D93H@9G)A;65W;W)K+U-Y;F--3"]3>6YC34PO0V]M;6%N9"YP:'`L=B`Q
M+C0N,3`N-R`R,#`V+S`Q+S`Q(#(Q.C(X.C,V(&IA;B!%>'`@)`H@*@H@*B!#
M;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A
M;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I
M9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!!;G1H;VYY
M($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@*B!`<VEN8V4@("!(;W)D
M92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M
M;6%N9"!["@H@("`@+RHJ"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1?8VUD240["@H@("`@+RHJ"B`@("`@*B!);G1E<FYA;"!S=')U
M8W1U<F4@=7-E9"!D=7)I;F<@6$U,('!A<G-I;F<N"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)%]3=&%C:R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)%]C:&%R<SL*"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D8V]M;6%N9"P@)'!A
M<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@:6YC;'5D95]O;F-E("=3>6YC
M34PO0V]M;6%N9"\G("X@)&-O;6UA;F0@+B`G+G!H<"<["B`@("`@("`@)&-L
M87-S(#T@)U-Y;F--3%]#;VUM86YD7R<@+B`D8V]M;6%N9#L*("`@("`@("!I
M9B`H8VQA<W-?97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@)&-M9"`]
M("9N97<@)&-L87-S*"1P87)A;7,I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1'3$]"04Q36R=B86-K96YD)UTM/FQO9TUE<W-A9V4H)T-L87-S
M(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S<R`N("<@;F]T(&9O=6YD+B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("!I
M;F-L=61E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@)&-M9"`](%!%
M05(Z.G)A:7-E17)R;W(H)T-L87-S(&1E9FEN:71I;VX@;V8@)R`N("1C;&%S
M<R`N("<@;F]T(&9O=6YD+B<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M("1C;60["B`@("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD
M240L("1O=71P=70I"B`@("!["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%
M;&5M96YT*"1U<FDL("1L;V-A;$YA;64L("1A='1R<RD*("`@('L*("`@("`@
M("`D=&AI<RT^7U-T86-K6UT@/2`D;&]C86Q.86UE.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@
M("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A
M<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=#;61)1"<I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VUD240@/2!I;G1V86PH=')I;2@D
M=&AI<RT^7V-H87)S*2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V-H87)S(#T@)R<["B`@
M("`@("`@87)R87E?<&]P*"1T:&ES+3Y?4W1A8VLI.PH@("`@?0H*("`@(&9U
M;F-T:6]N(&-H87)A8W1E<G,H)'-T<BD*("`@('L*("`@("`@("`D=&AI<RT^
M7V-H87)S("X]("1S='(["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O1FEN86PN<&AP````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<U,3$@,3`U,34T,S0Q,S8@,#(R
M-3<T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO
M*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD7T9I;F%L(&-L87-S+@H@*@H@*B`D
M2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O1FEN86PN
M<&AP+'8@,2XQ,"XQ,"XU(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X<"`D
M"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI
M;&QS0'!Y<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE
M($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y
M;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W
M=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@
M($%N=&AO;GD@36EL;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC
M92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y
M;F--3%]#;VUM86YD7T9I;F%L(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*
M("`@("\J*@H@("`@("H@0W)E871E('1H92!R97-P;VYS92!F;W(@82!F:6YA
M;"!T86<*("`@("`J+PH@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD
M240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%4U-)
M3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("1A='1R<R`](&%R<F%Y*"D[
M"@H@("`@("`@("\O($EF('1H92!C;&EE;G0@:&%S;B=T('-E;G0@=7,@9&5V
M:6-E(&EN9F\L(')E<75E<W0@:70@;F]W+@H@("`@("`@("1D:2`](%-Y;F--
M3%]$979I8V4Z.F1E=FEC94EN9F\H*3L*("`@("`@("!I9B`H96UP='DH)&1I
M+3Y?36%N*2D@>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)T=E="<L("1A='1R<RD["@H@("`@("`@("`@
M("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T-M
M9$E$)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S(#T@)&-U<G)E;G1#
M;61)1#L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I
M.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=#;61)1"<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%
M;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-971A)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M365T82@I+"`G5'EP92<L("1A='1R<RD["B`@("`@("`@("`@("1A='1R<R`]
M(&%R<F%Y*"D["B`@("`@("`@("`@(&EF("AI<U]A*"1O=71P=70L("=834Q?
M5T)834Q?16YC;V1E<B<I*2!["B`@("`@("`@("`@("`@("`D8VAA<G,@/2!-
M24U%7U-93D--3%]$159)0T5?24Y&3U]70EA-3#L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1C:&%R<R`]($U)345?4UE.0TU,7T1%
M5DE#15])3D9/7UA-3#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W5T
M<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1Y<&4G*3L*("`@("`@
M("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G
M365T82<I.PH*("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=)=&5M)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G
M970G+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@
M("`@("`@("1C:&%R<R`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P*2`_
M("<N+V1E=FEN9C$P)R`Z("<N+V1E=FEN9C$Q)SL*("`@("`@("`@("`@)&]U
M='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T<'5T
M+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG*3L*("`@
M("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G5&%R9V5T)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TET96TG*3L*"B`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T=E="<I.PH*("`@
M("`@("`@("`@+R\@36%R:R!T:&ES(&ED(&1O=VX@87,@;F5E9&EN9R!A(')E
M<W5L=',@<&%C:V5T(')O=71E9"!T;PH@("`@("`@("`@("`O+R!T:&4@4'5T
M(&-O;6UA;F0N"B`@("`@("`@("`@("1S=&%T92T^<V5T17AP96-T961297-U
M;'14>7!E*"1C=7)R96YT0VUD240L("=0=70G*3L*"B`@("`@("`@("`@("1C
M=7)R96YT0VUD240K*SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C=7)R
M96YT0VUD240["B`@("!]"B`@("`O*BH*("`@("`J($-R96%T92!A("9L=#M&
M:6YA;"9G=#L@;W5T<'5T+@H@("`@("H@0F5F;W)E('1H870@8V]N=&EN=64@
M82!S>6YC(&EF('1H97)E(&%R92!P96YD:6YG(&5N=')I97,N"B`@("`@*B!3
M=&%T:6,@;65T:&]D"B`@("`@*B\*("`@(&9U;F-T:6]N(&]U='!U=$9I;F%L
M*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T
M92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T92==.PH@("`@("`@("1A='1R
M<R`](&%R<F%Y*"D["@H@("`@("`@(&=L;V)A;"`D;65S<V%G949U;&P["B`@
M("`@("`@+RH@268@=&AE<F4G<R!P96YD:6YG('-Y;F,@9&%T82!A;F0@<W!A
M8V4@;&5F="!I;B!T:&4@;65S<V%G93H*("`@("`@("`@*B!S96YD(&1A=&$@
M;F]W+B`J+PH@("`@("`@(&EF("@A)&UE<W-A9V5&=6QL("8F"B`@("`@("`@
M("`@("`@("!C;W5N="@D<"`]("1S=&%T92T^9V5T4&5N9&EN9U-Y;F-S*"DI
M(#X@,"D@>PH@("`@("`@("`@("!F;W)E86-H("@D<"!A<R`D<&5N9&EN9U-Y
M;F,I('L*("`@("`@("`@("`@("`@(&EF("@A)&UE<W-A9V5&=6QL*2!["B`@
M("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==+3YL;V=-97-S
M86=E*"=C;VYT:6YU92!S>6YC(&9O<B!S>6YC5'EP93TG("X@)'!E;F1I;F=3
M>6YC+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&
M24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@("`@("`@
M("`@("`@("`@)'-Y;F,@/2`F("1S=&%T92T^9V5T4WEN8R@D<&5N9&EN9U-Y
M;F,I.PH@("`@("`@("`@("`@("`@("`@("1C=7)R96YT0VUD240@/2`D<WEN
M8RT^8W)E871E4WEN8T]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@("`@
M("`@+RH*("`@("`@("`@*B!$;VXG="!S96YD('1H92!F:6YA;"!T86<@:68@
M=V4@:&%V96XG="!S96YT(&%L;"!S>6YC(&1A=&$@>65T+@H@("`@("`@("`J
M+PH@("`@("`@(&EF("@A)'-T871E+3YH87-096YD:6YG16QE;65N=',H*2D@
M>PH@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG
M97154DDH*2P@)T9I;F%L)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1FEN86PG*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D1TQ/0D%,4ULG8F%C:V5N9"==
M+3YL;V=-97-S86=E*"=P96YD:6YG(&5L96UE;G1S+"!N;W0@<V5N9&EN9R!F
M:6YA;"!T86<G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O
M4'5T+G!H<```````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C$P
M,#$@,3`U,34T,S0Q,S8@,#(R,S`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@II;F-L=61E7V]N8V4@)U-Y;F--
M3"]#;VUM86YD+G!H<"<["@HO*BH*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN
M8TU,+U-Y;F--3"]#;VUM86YD+U!U="YP:'`L=B`Q+C$R+C$P+C<@,C`P-B\P
M-2\S,2`Q-SHP-CHS-B!S96QS:WD@17AP("0*("H*("H@5&AE(%-Y;F--3%]#
M;VUM86YD7U!U=#HZ(&-L87-S(&AA;F1L97,@1&5V26YF(&1E=FEC92!I;F9O
M<FUA=&EO;@H@*B!S96YT(&)Y('1H92!C;&EE;G0N(%1H92!D871A(&ES('-T
M;W)E9"!I;B!A(%-Y;F--3%]$979I8V5);F9O"B`J(&]B:F5C="!W:&EC:"!I
M<R!D969I;F5D(&EN($1E=FEC92YP:'`@86YD('1H96X@<W1O<F5D(&EN"B`J
M(%-Y;F--3%]$979I8V4@87,@86X@871T<FEB=71E+@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-2TR,#`V($-U8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT
M(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4'5T
M(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@('9A<B`D7V1E=FEN9CL*
M"B`@("`O*BH*("`@("`J($QO8V%L('9A<G,@=&\@<F5M96UB97(@<W1A=&4N
M"B`@("`@*B\*("`@('9A<B`D7V-U<G)E;G1$4SL*("`@('9A<B`D7T-45'EP
M93L*("`@('9A<B`D7U9E<D-4.PH*("`@('9A<B`D7V-U<G)E;G10<F]P3F%M
M93L*("`@('9A<B`D7V-U<G)E;G1087)A;4YA;64["B`@("!V87(@)%]C=7)R
M96YT0U14>7!E.PH*("`@('9A<B`D7V-U<G)E;G183F%M.PH*("`@(&9U;F-T
M:6]N('-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*0H@("`@
M>PH@("`@("`@('!A<F5N=#HZ<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT
M+"`D871T<G,I.PH@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C
M:RDI('L*("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@("1T:&ES+3Y?9&5V
M:6YF(#T@)FYE=R!3>6YC34Q?1&5V:6-E26YF;R@I.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`U.@H@("`@("`@("`@("!I9B`H)&5L96UE
M;G0@/3T@)T1A=&%3=&]R92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8W5R<F5N=$13(#T@)FYE=R!3>6YC34Q?1&%T85-T;W)E*"D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@?0H*("`@
M(&9U;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@
M("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("`D9&D@/2`F)'1H:7,M
M/E]D979I;F8["B`@("`@("`@<W=I=&-H("AC;W5N="@D=&AI<RT^7U-T86-K
M*2D@>PH@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)%]315-324].6R=3
M>6YC34PN<W1A=&4G72T^<V5T1&5V:6-E26YF;R@D9&DI.PH@("`@("`@("`@
M("!I9B`H1$5"54=,3T=?1$5624Y&*2!["B`@("`@("`@("`@("`@("`D9G`@
M/2!`9F]P96XH)R]T;7`O<WEN8R]D979I;F8N='AT)RP@)V$G*3L*("`@("`@
M("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@("`@("!`9G=R
M:71E*"1F<"P@=F%R7V5X<&]R="@D9&DL('1R=64I*3L*("`@("`@("`@("`@
M("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@8V%S92`U.@H@("`@("`@("`@("!S=VET8V@@
M*"1E;&5M96YT*2!["B`@("`@("`@("`@(&-A<V4@)U9E<D141"<Z"B`@("`@
M("`@("`@("`@("`D9&DM/E]697)$5$0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=-
M86XG.@H@("`@("`@("`@("`@("`@)&1I+3Y?36%N(#T@=')I;2@D=&AI<RT^
M7V-H87)S*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`G36]D)SH*("`@("`@("`@("`@("`@("1D:2T^7TUO9"`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@("`@(&-A<V4@)T]%32<Z"B`@("`@("`@("`@("`@("`D9&DM/E]/14T@
M/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=&=U8G.@H@("`@("`@("`@("`@("`@)&1I
M+3Y?1G=6(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4W=6)SH*("`@("`@("`@("`@
M("`@("1D:2T^7U-W5B`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)TAW5B<Z"B`@("`@
M("`@("`@("`@("`D9&DM/E](=U8@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=$979)
M1"<Z"B`@("`@("`@("`@("`@("`D9&DM/E]$979)1"`]('1R:6TH)'1H:7,M
M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)T1E=E1Y<"<Z"B`@("`@("`@("`@("`@("`D9&DM/E]$9794>7`@
M/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=55$,G.@H@("`@("`@("`@("`@("`@)&1I
M+3Y?551#(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G4W5P<&]R=$QA<F=E3V)J<R<Z"B`@("`@("`@("`@("`@
M("`D9&DM/E]3=7!P;W)T3&%R9V5/8FIS(#T@=')U93L*("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G4W5P<&]R=$YU;6)E<D]F
M0VAA;F=E<R<Z"B`@("`@("`@("`@("`@("`D9&DM/E]3=7!P;W)T3G5M8F5R
M3V9#:&%N9V5S(#T@=')U93L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G1&%T85-T;W)E)SH*("`@("`@("`@("`@("`@("1D
M:2T^7T1A=&%3=&]R95M=(#T@)'1H:7,M/E]C=7)R96YT1%,["B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)T-40V%P)SH*("`@
M("`@("`@("`@8V%S92`G17AT)SH*("`@("`@("`@("`@("`@("\O($%U=&]M
M871I8V%L;'D@:&%N9&QE9"!B>2!S=6)E;&5M96YT<RX*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("!C87-E(#8Z"B`@("`@("`@("`@(&EF("@D=&AI<RT^7U-T86-K
M6S1=(#T]("=$871A4W1O<F4G*2!["B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1E;&5M96YT*2!["B`@("`@("`@("`@("`@("!C87-E("=3;W5R8V52968G
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13+3Y?4V]U
M<F-E4F5F(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=$:7-P;&%Y3F%M
M92<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT1%,M/E]$
M:7-P;&%Y3F%M92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G36%X1U5)
M1%-I>F4G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=$13
M+3Y?36%X1U5)1%-I>F4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)T13
M365M)SH*("`@("`@("`@("`@("`@("`@("`O+R!#=7)R96YT;'D@:6=N;W)E
M9"P@=&\@8F4@9&]N92X*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=3>6YC0V%P)SH*("`@("`@("`@("`@("`@
M("`@("`O+R!!=71O;6%T:6-A;&QY(&AA;F1L960@8GD@4WEN8U1Y<&4@<W5B
M96QE;65N="X*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!C87-E("=2>"U0<F5F)SH*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-U<G)E;G1$4RT^7U)X7U!R969;)'1H:7,M/E]#5%1Y<&5=(#T@
M)'1H:7,M/E]697)#5#L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=2>"<Z"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R96YT1%,M/E]2>%LD=&AI<RT^7T-45'EP95T@/2`D=&AI
M<RT^7U9E<D-4.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)U1X+5!R968G.@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8W5R<F5N=$13+3Y?5'A?4')E9ELD=&AI<RT^7T-45'EP95T@
M/2`D=&AI<RT^7U9E<D-4.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@("`@(&-A<V4@)U1X)SH*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-U<G)E;G1$4RT^7U1X6R1T:&ES+3Y?0U14>7!E72`]("1T
M:&ES+3Y?5F5R0U0["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7U-T86-K6S1=(#T]("=#5$-A<"<I('L*("`@("`@("`@("`@("`@
M('-W:71C:"`H)&5L96UE;G0I('L*("`@("`@("`@("`@("`@(&-A<V4@)T-4
M5'EP92<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT0U14
M>7!E(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=0<F]P3F%M92<Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4')O<$YA;64@/2!T
M<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@("\O(%)E
M<V5T('!A<F%M('-T871E+@H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92D["B`@("`@("`@("`@("`@("`@("`@
M)&1I+3Y?0U1#87!;)'1H:7,M/E]C=7)R96YT0U14>7!E75LD=&AI<RT^7V-U
M<G)E;G10<F]P3F%M95T@/2`F;F5W(%-Y;F--3%]0<F]P97)T>2@I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@
M)U!A<F%M3F%M92<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R
M96YT4&%R86U.86UE(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@
M("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U<G)E;G1#5%1Y<&5=
M6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M<ULD=&AI<RT^7V-U
M<G)E;G1087)A;4YA;65=(#T@)FYE=R!3>6YC34Q?4')O<&5R='E087)A;65T
M97(H*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M("`@("!C87-E("=686Q%;G5M)SH*("`@("`@("`@("`@("`@("`@("!I9B`H
M(65M<'1Y*"1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@5V4G<F4@:6X@<&%R86UE=&5R(&UO9&4N"B`@
M("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES+3Y?8W5R
M<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?<&%R86US
M6R1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M95TM/E]686Q%;G5M6W1R:6TH)'1H
M:7,M/E]C:&%R<RE=(#T@=')U93L*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI
M<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^
M7U9A;$5N=6U;=')I;2@D=&AI<RT^7V-H87)S*5T@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=$871A5'EP92<Z"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E
M<B!M;V1E+@H@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD
M=&AI<RT^7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE
M72T^7W!A<F%M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?1&%T851Y
M<&4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P
M6R1T:&ES+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA
M;65=+3Y?1&%T851Y<&4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=3:7IE)SH*("`@("`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M92DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@5V4G<F4@:6X@<&%R86UE=&5R(&UO
M9&4N"B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES
M+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?
M<&%R86US6R1T:&ES+3Y?8W5R<F5N=%!A<F%M3F%M95TM/E]3:7IE(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^
M7V-U<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7U-I
M>F4@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("!C87-E("=$:7-P;&%Y3F%M92<Z"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7V-U<G)E;G1087)A;4YA;64I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%=E)W)E(&EN('!A<F%M971E<B!M;V1E+@H@
M("`@("`@("`@("`@("`@("`@("`@("`D9&DM/E]#5$-A<%LD=&AI<RT^7V-U
M<G)E;G1#5%1Y<&5=6R1T:&ES+3Y?8W5R<F5N=%!R;W!.86UE72T^7W!A<F%M
M<ULD=&AI<RT^7V-U<G)E;G1087)A;4YA;65=+3Y?1&ES<&QA>4YA;64@/2!T
M<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("1D:2T^7T-40V%P6R1T:&ES
M+3Y?8W5R<F5N=$-45'EP95U;)'1H:7,M/E]C=7)R96YT4')O<$YA;65=+3Y?
M1&ES<&QA>4YA;64@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?4W1A8VM;-%T@/3T@)T5X="<@)B8@)&5L96UE;G0@/3T@)UA.86TG
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<G)E;G183F%M(#T@=')I
M;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]3=&%C:ULT72`]/2`G17AT)R`F)B`D96QE;65N="`]/2`G
M6%9A;"<I('L*("`@("`@("`@("`@("`@("1D:2T^7T5X=%LD=&AI<RT^7V-U
M<G)E;G183F%M75M=(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`W.@H@("`@
M("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U9E<D-4)RD@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]697)#5"`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@
M("`@("`@("`@('T@96QS96EF("@D96QE;65N="`]/2`G0U14>7!E)RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]#5%1Y<&4@/2!T<FEM*"1T:&ES+3Y?
M8VAA<G,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE;G0@/3T@)U-Y
M;F-4>7!E)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT1%,M
M/E]3>6YC0V%P6W1R:6TH)'1H:7,M/E]C:&%R<RE=(#T@=')U93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@
M('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@("!]"@H@
M("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T<'5T*0H@
M("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;)U-Y;F--3"YS=&%T
M92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3
M=&%T=7,H*"@D<W1A=&4M/FES075T:&]R:7IE9"@I*2`_(%)%4U!/3E-%7T]+
M(#H@4D534$].4T5?24Y604Q)1%]#4D5$14Y424%,4RDL("=0=70G*3L*("`@
M("`@("`D<W1A='5S+3YS971#;612968H)'1H:7,M/E]C;61)1"D["@H@("`@
M("`@("1R968@/2`H)'-T871E+3YG971697)S:6]N*"D@/3T@,"D@/R`G+B]D
M979I;F8Q,"<@.B`G+B]D979I;F8Q,2<["@H@("`@("`@("1S=&%T=7,M/G-E
M=%-O=7)C95)E9B@D<F5F*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M/F]U
M='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO
M0V]M;6%N9"]297-U;'1S+G!H<```````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-C<P-2`Q,#4Q-30S-#$S-B`P,C,R,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC
M92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B`D2&]R9&4Z(&9R86UE
M=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O4F5S=6QT<RYP:'`L=B`Q+C$Q
M+C$P+C8@,C`P-B\P-R\P,B`Q,#HT.#HR,"!K87)S=&5N($5X<"`D"B`J"B`J
M($-O<'ER:6=H="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y
M<F%M:60V+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)
M3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($YA=&AA
M;B!0(%-H87)P"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C:V%G92!3
M>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U)E<W5L=',@97AT96YD
M<R!3>6YC34Q?0V]M;6%N9"!["@H@("`@=F%R("1?<W5B0V]M;6%N9#L*("`@
M('9A<B`D7W-A=F5D57)I.PH@("`@=F%R("1?<V%V961%;&5M96YT.PH@("`@
M=F%R("1?<V%V961!='1R<SL*("`@('9A<B`D7W-A=F5D0VUD240["B`@("!V
M87(@)%]C:&%R<SL*"B`@("!F=6YC=&EO;B!S=&%R=$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0L("1A='1R<RD*("`@('L*("`@("`@("!P87)E;G0Z.G-T87)T
M16QE;65N="@D=7)I+"`D96QE;65N="P@)&%T=')S*3L*"B`@("`@("`@<W=I
M=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,3H*
M("`@("`@("`@("`@+R\@4V%V92!T:&4@:6YF;RP@=V4@;6%Y(&AA=F4@=&\@
M<F4M<V5N9"!T:&ES('-T87)T16QE;65N=`H@("`@("`@("`@("`O+R!T;R!T
M:&4@<W5B+6-O;6UA;F0@;&%T97(N"B`@("`@("`@("`@("1T:&ES+3Y?<V%V
M9615<FD@/2`D=7)I.PH@("`@("`@("`@("`D=&AI<RT^7W-A=F5D16QE;65N
M="`]("1E;&5M96YT.PH@("`@("`@("`@("`D=&AI<RT^7W-A=F5D071T<G,@
M/2`D871T<G,["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]S=6)#;VUM86YD+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L
M96UE;G0L("1A='1R<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N
M(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@<W=I
M=&-H("AC;W5N="@D=&AI<RT^7U-T86-K*2D@>PH@("`@("`@(&-A<V4@,CH*
M("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=#;61)1"<@)B8@(6ES<V5T
M*"1T:&ES+3Y?<W5B0V]M;6%N9"DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V%V961#;61)1"`](&EN='9A;"AT<FEM*"1T:&ES+3Y?8VAA<G,I*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=#
M;612968G*2!["B`@("`@("`@("`@("`@("`D8VUD4F5F(#T@:6YT=F%L*'1R
M:6TH)'1H:7,M/E]C:&%R<RDI.PH@("`@("`@("`@("`@("`@)'-T871E(#T@
M)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("`@("`@("`@
M+R\@268@=&AI<R!R97-U;'0@<&%C:V5T(&ES(')E;&%T960@=&\@<V]M971H
M:6YG(&%N9`H@("`@("`@("`@("`@("`@+R\@;F5E9',@=&\@8F4@<F]U=&5D
M('1O(&$@<&%R=&EC=6QA<B!C;VUM86YD(&]B:F5C="P*("`@("`@("`@("`@
M("`@("\O(&1O(&ET(&YO=RX*("`@("`@("`@("`@("`@("1C;614>7!E(#T@
M)'-T871E+3YG971%>'!E8W1E9%)E<W5L=%1Y<&4H)&-M9%)E9BD["B`@("`@
M("`@("`@("`@("!I9B`H(65M<'1Y*"1C;614>7!E*2D@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<W5B0V]M;6%N9"`]("93>6YC34Q?0V]M;6%N
M9#HZ9F%C=&]R>2@D8VUD5'EP92D["B`@("`@("`@("`@("`@("`@("`@+R\@
M5&AI<R!I<VXG="!T;W1A;&QY('1E8VAN:6-A;&QY(&-O<G)E8W0@8F5C875S
M90H@("`@("`@("`@("`@("`@("`@("\O('1H92!834P@8V]U;&0@:&%V92!B
M965N(&]U="!O9B!O<F1E<B!A;F0@=V4*("`@("`@("`@("`@("`@("`@("`O
M+R!M:6=H="!H879E(&UI<W-E9"!S;VUE('-T=69F+"!B=70@:6X@<F5A;&ET
M>2P*("`@("`@("`@("`@("`@("`@("`O+R!I="!P<F]B86)L>2!W;VXG="!H
M87!P96XN"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=6)#;VUM86YD
M+3YS=&%R=$5L96UE;G0H"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V%V9615<FDL"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<V%V961%;&5M96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-A=F5D071T<G,I.PH@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W-A=F5D0VUD240I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("\O($9)6$U%.B!3:&]U;&1N)W0@8F4@86-C97-S:6YG('1H:7,@<')I=F%T
M90H@("`@("`@("`@("`@("`@("`@("`@("`O+R!M96UB97(N"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<W5B0V]M;6%N9"T^7V-M9$E$(#T@
M)'1H:7,M/E]S879E9$-M9$E$.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@1F%L;"!T:')O=6=H('1O
M('1H92!D969A=6QT(&-A<V4N"@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-U8D-O;6UA;F0M/F5N9$5L96UE;G0H)'5R:2P@
M)&5L96UE;G0I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*"B`@("`@("`@<&%R96YT.CIE;F1%;&5M96YT*"1U<FDL("1E
M;&5M96YT*3L*("`@('T*"B`@("!F=6YC=&EO;B!C:&%R86-T97)S*"1S='(I
M"B`@("!["B`@("`@("`@<&%R96YT.CIC:&%R86-T97)S*"1S='(I.PH@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W-U8D-O;6UA;F0I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<W5B0V]M;6%N9"T^8VAA<F%C=&5R<R@D<W1R*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD
M240L("8D;W5T<'5T*0H@("`@>PH@("`@("`@("1S=&%T92`]("8D7U-%4U-)
M3TY;)U-Y;F--3"YS=&%T92==.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3
M>6YC34Q?0V]M;6%N9%]3=&%T=7,H4D534$].4T5?3TLL("=297-U;'1S)RD[
M"B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*
M("`@("`@("`D<F5F(#T@*"1S=&%T92T^9V5T5F5R<VEO;B@I(#T](#`I(#\@
M)RXO9&5V:6YF,3`G(#H@)RXO9&5V:6YF,3$G.PH@("`@("`@("1S=&%T=7,M
M/G-E=%-O=7)C95)E9B@D<F5F*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M
M/F]U='!U="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"GT*````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,
M+T-O;6UA;F0O36%P+G!H<```````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,3`U,C(@,3`U,34T,S0Q,S8@,#(R,C4T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@II;F-L=61E7V]N
M8V4@)U-Y;F--3"]#;VUM86YD+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]-
M87`@8VQA<W,@<')O=FED97,@82!3>6YC34P@:6UP;&5M96YT871I;VX@;V8*
M("H@=&AE($UA<"!C;VUM86YD(&%S(&1E9FEN960@:6X@4WEN8TU,(%)E<')E
M<V5N=&%T:6]N(%!R;W1O8V]L+`H@*B!V97)S:6]N(#$N,"XQ(#4N-2XX+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T-O;6UA;F0O
M36%P+G!H<"QV(#$N,2XQ,"XV(#(P,#8O,#$O,#$@,C$Z,C@Z,S8@:F%N($5X
M<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@2V%R<W1E;B!&;W5R;6]N
M="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@
M9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@
M268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P
M.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T
M:&]R("!+87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@
M0'-I;F-E("`@2&]R9&4@,RXP"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA
M<W,@4WEN8TU,7T-O;6UA;F1?36%P(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@
M>PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1?<V]U<F-E3&]C55)).PH*("`@("\J*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1?=&%R9V5T3&]C55)).PH*("`@('9A<B`D7VUA
M<%1A<F=E=#L*("`@('9A<B`D7VUA<%-O=7)C93L*"B`@("!F=6YC=&EO;B!O
M=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@("!["B`@("`@("`@
M)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@)'-T871E(#T@)B1?4T534TE/
M3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1S=&%T=7,@/2`F;F5W(%-Y
M;F--3%]#;VUM86YD7U-T871U<R@D<W1A=&4M/FES075T:&]R:7IE9"@I(#\@
M4D534$].4T5?3TL@.B!215-03TY315])3E9!3$E$7T-2141%3E1)04Q3+"`G
M36%P)RD["B`@("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD
M240I.PH@("`@("`@(&EF("@D=&AI<RT^7W-O=7)C94QO8U5222`A/2!N=6QL
M*2!["B`@("`@("`@("`@("1S=&%T=7,M/G-E=%-O=7)C95)E9B@D=&AI<RT^
M7W-O=7)C94QO8U5222D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^
M7W1A<F=E=$QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("1S=&%T=7,M
M/G-E=%1A<F=E=%)E9B@D=&AI<RT^7W1A<F=E=$QO8U5222D["B`@("`@("`@
M?0H*("`@("`@("`D8W5R<F5N=$-M9$E$(#T@)'-T871U<RT^;W5T<'5T*"1C
M=7)R96YT0VUD240L("1O=71P=70I.PH*("`@("`@("!R971U<FX@)&-U<G)E
M;G1#;61)1#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O
M<&5R='D@<V]U<F-E55))+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'-O=7)C955222`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('-O=7)C955222X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V]U<F-E3&]C55))*"1S;W5R8V55
M4DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]S;W5R8V554DD@/2`D<V]U<F-E
M55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%1A<F=E=$QO8U5222@I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&%R9V5T55)).PH@("`@?0H*
M("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!T87)G97154DDN
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T55))("!.97<@
M=F%L=64@;V8@<')O<&5R='D@=&%R9V5T55))+@H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971487)G97154DDH)'1A<F=E=%5222D*("`@('L*("`@("`@("`D
M=&AI<RT^7W1A<F=E=%5222`]("1T87)G97154DD["B`@("!]"@H@("`@9G5N
M8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@
M("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE
M;G0L("1A='1R<RD["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3
M=&%C:RDI('L*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE
M;65N="`]/2`G36%P271E;2<I('L*("`@("`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?;6%P5&%R9V5T*3L*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES
M+3Y?;6%P4V]U<F-E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@96YD16QE;65N="@D
M=7)I+"`D96QE;65N="D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0[
M"@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@
M("`@("!C87-E(#$Z"B`@("`@("`@("`@("1S=&%T92`]("8D7U-%4U-)3TY;
M)U-Y;F--3"YS=&%T92==.PH@("`@("`@("`@("`D<WEN8R`]("8@)'-T871E
M+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C55))*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M
M96YT(#T]("=-87!)=&5M)RD@>PH@("`@("`@("`@("`@("`@)'-T871E(#T@
M)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["B`@("`@("`@("`@("`@("`D
M<WEN8R`]("8@)'-T871E+3YG9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C55))
M*3L*("`@("`@("`@("`@("`@(&EF("@A)'-T871E+3YI<T%U=&AO<FEZ960H
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL;V=-97-S86=E
M*"=.;W0@075T:&]R:7IE9"!I;B!-87!)=&5M(2<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L(%]?3$E.15]?
M+"!014%27TQ/1U]%4E(I.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`O+R!/=F5R=W)I=&4@97AI<W1I;F<@9&%T82!B
M>2!R96UO=FEN9R!I="!F:7)S="X*("`@("`@("`@("`@("`@("`@("`D8F%C
M:V5N9"T^8W)E871E56ED36%P*"1S=&%T92T^9V5T4WEN8TED96YT:69I97(H
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=&%R9V5T3&]C55))+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]M87!3;W5R8V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7VUA<%1A<F=E="D["@H@("`@("`@("`@("`@("`@("`@("1B86-K96YD+3YL
M;V=-97-S86=E*"=C<F5A=&5D($UA<"!F;W(@<V]U<F-E/2<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?;6%P
M4V]U<F-E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G(&%N9"!T87)G970])R`N("1T:&ES+3Y?;6%P5&%R9V5T"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&EN(&1B
M("<@+B`D=&AI<RT^7W1A<F=E=$QO8U5222P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%
M05)?3$]'7T1%0E5'*3L*"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@,SH*("`@("`@
M("`@("`@:68@*"1E;&5M96YT(#T]("=,;V-54DDG*2!["B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G4V]U<F-E)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E3&]C55))(#T@=')I;2@D
M=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@('T@96QS96EF("@D=&AI
M<RT^7U-T86-K6S%=(#T]("=487)G970G*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]T87)G971,;V-54DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@(&EF("@D96QE
M;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?4W1A8VM;,ET@/3T@)U-O=7)C92<I('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7VUA<%-O=7)C92`]('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]3=&%C:ULR72`]/2`G
M5&%R9V5T)RD@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;6%P5&%R
M9V5T(#T@=')I;2@D=&AI<RT^7V-H87)S*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D=7)I+"`D96QE;65N="D["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N9"]3
M>6YC16QE;65N="YP:'``````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,38S
M-"`Q,#4Q-30S-#$S-B`P,C,W-S(`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN8TU,
M+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B!4:&4@8VQA<W,@4WEN8TU,7T-O;6UA
M;F1?4WEN8T5L96UE;G0@<W1O<F5S(&EN9F]R;6%T:6]N(&9R;VT@=&AE($%D
M9"P*("H@1&5L971E(&%N9"!297!L86-E(&5L96UE;G1S(&9O=6YD(&EN<VED
M92!A('-Y;F,@8V]M;6%N9"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN
M8TU,+U-Y;F--3"]#;VUM86YD+U-Y;F-%;&5M96YT+G!H<"QV(#$N,RXR+C,@
M,C`P-B\P,2\P,2`R,3HR.#HS-B!J86X@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#4M,C`P-B!4:&4@:&]R9&4@<')O:F5C="`H=W=W+FAO<F1E+F]R9RD*
M("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N
M<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E
M:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F
M="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<VEN8V4@("!(;W)D92`S+C`*("H@
M0'!A8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?0V]M;6%N9%]3>6YC
M16QE;65N="!E>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("`O*BH*("`@
M("`J($%D9"P@1&5L971E(&]R(%)E<&QA8V4N"B`@("`@*B\*("`@('9A<B`D
M7V5L96UE;G14>7!E.PH*("`@("\J*@H@("`@("H@07)R87D@;V8@4WEN8TU,
M7U-Y;F-)=&5M(&5N=')I97,N"B`@("`@*B\*("`@('9A<B`D7VET96US(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J($UI;65T>7!E(&9O<B!A;&P@:71E
M;7,N"B`@("`@*B\*("`@('9A<B`D7V-O;G1E;G14>7!E.PH*("`@("\J*@H@
M("`@("H@5&5M<"!D871A(&9O<B!C<F5A=&EO;B!O9B!I;F1I=FED=6%L(&ET
M96US+@H@("`@("HO"B`@("!V87(@)%]C;VYT96YT.PH*("`@('9A<B`D7V-U
M:60["@H@("`@+RHJ"B`@("`@*B!-:6UE='EP92!F;W(@:6YD:79I9'5A;"!I
M=&5M+@H@("`@("HO"B`@("!V87(@)%]I=&5M0V]N96YT5'EP93L*"B`@("`O
M*BH*("`@("`J($-R96%T97,@82!3>6YC($5L96UE;G0N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R!E;&5M96YT5'EP92!E:71H97(@061D+"!$96QE
M=&4@;W(@4F5P;&%C90H@("`@("HO"B`@("!F=6YC=&EO;B!3>6YC34Q?0V]M
M;6%N9%]3>6YC16QE;65N="@D96QE;65N=%1Y<&4I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]E;&5M96YT5'EP92`]("1E;&5M96YT5'EP93L*("`@('T*"B`@
M("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I"B`@
M("!["B`@("`@("`@<W=I=&-H("@D=&AI<RT^7V5L96UE;G14>7!E*2!["B`@
M("`@("`@8V%S92`G061D)SH*("`@("`@("`@("`@)')E<W!O;G-E(#T@4D53
M4$].4T5?251%35]!1$1%1#L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&-A<V4@)T1E;&5T92<Z"B`@("`@("`@("`@("1R97-P;VYS92`](%)%4U!/
M3E-%7T]+.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G4F5P
M;&%C92<Z"B`@("`@("`@("`@("1R97-P;VYS92`](%)%4U!/3E-%7T]+.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@("1S=&%T=7,@
M/2`F;F5W(%-Y;F--3%]#;VUM86YD7U-T871U<R@D<F5S<&]N<V4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?96QE;65N=%1Y<&4I.PH@("`@("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D
M=&AI<RT^7V-M9$E$*3L*"B`@("`@("`@<F5T=7)N("1S=&%T=7,M/F]U='!U
M="@D8W5R<F5N=$-M9$E$+"`D;W5T<'5T*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!S=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD*("`@('L*
M("`@("`@("!P87)E;G0Z.G-T87)T16QE;65N="@D=7)I+"`D96QE;65N="P@
M)&%T=')S*3L*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?4W1A8VLI
M*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`D=&AI<RT^7V-U:60@
M/2!N=6QL.PH@("`@("`@("`@("`D=&AI<RT^7V-O;G1E;G0@/2!N=6QL.PH@
M("`@("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP92`](&YU;&P["B`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO
M;B!E;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*0H@("`@>PH@("`@("`@('-W
M:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI('L*("`@("`@("!C87-E(#$Z
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#(Z"B`@("`@("`@
M("`@(&EF("@D96QE;65N="`]/2`G271E;2<I('L*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^7VET96U#;VYT96YT5'EP92D*("`@("`@("`@
M("`@("`@("`@("`F)B`A96UP='DH)'1H:7,M/E]C;VYT96YT5'EP92DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP92`]
M("1T:&ES+3Y?8V]N=&5N=%1Y<&4["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]I=&5M<UM=(#T@)FYE=R!3>6YC34Q?4WEN
M8TET96TH)'1H:7,M/E]E;&5M96YT5'EP92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V]N=&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:71E;4-O;G1E;G14>7!E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C=6ED*3L*("`@("`@("`@("`@?0H*("`@("`@
M("!C87-E(#,Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]/2`G5'EP92<I
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y<&4@/2!T<FEM
M*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!](&5L<V5I9B`H)&5L96UE
M;G0@/3T@)T1A=&$G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E
M;G0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("!C87-E(#0Z"B`@("`@("`@("`@(&EF
M("@D96QE;65N="`]/2`G3&]C55)))RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?4W1A8VM;,ET@/3T@)U-O=7)C92<I('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-U:60@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;,ET@/3T@
M)U1A<F=E="<I('L*("`@("`@("`@("`@("`@("`@("`O+R!.;W0@=7-E9#H@
M=V4@:6=N;W)E(")S=6ED('!R;W!O<V%L<R(@9G)O;0H@("`@("`@("`@("`@
M("`@("`@("\O(&-L:65N="X*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`U.@H@("`@
M("`@("`@("!I9B`H)&5L96UE;G0@/3T@)U1Y<&4G*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7VET96U#;VYT96YT5'EP92`]('1R:6TH)'1H:7,M/E]C
M:&%R<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("!P87)E;G0Z.F5N9$5L96UE;G0H)'5R:2P@)&5L96UE
M;G0I.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$ET96US*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/E]I=&5M<SL*("`@('T*"B`@("!F=6YC=&EO
M;B!G971#;VYT96YT5'EP92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?8V]N=&5N=%1Y<&4["B`@("!]"@I]"@HO*BH*("H@5&AE(&-L87-S(%-Y
M;F--3%]#;VUM86YD7U-Y;F-%;&5M96YT('-T;W)E<R!I;F9O<FUA=&EO;B!A
M8F]U=`H@*B!T:&4@:71E;7,@:6YS:61E(&$@<WEN8R!E;&5M96YT("A!9&1\
M1&5L971E?%)E<&QA8V4I+@H@*@H@*B!!('-I;F=L92!3>6YC16QE;65N="!C
M86X@8V]N=&%I;B!M=6QT:7!L92!I=&5M<RX*("H*("H@26YS=&%N8V5S(&]F
M('1H:7,@8VQA<W,@87)E(&-R96%T960@9'5R:6YG('1H92!834P@<&%R<VEN
M9R!B>0H@*B!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N="X*("H*("H@0'!A
M8VMA9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?4WEN8TET96T@>PH*("`@
M("\J*@H@("`@("H@061D+"!$96QE=&4@;W(@4F5P;&%C92P@:6YH97)I=&5D
M(&9R;VT*("`@("`J(%-Y;F--3%]#;VUM86YD7U-Y;F-%;&5M96YT+@H@("`@
M("HO"B`@("!V87(@)%]E;&5M96YT5'EP93L*"B`@("!V87(@)%]C=6ED.PH*
M("`@("\J*@H@("`@("H@3W!T:6]N86PL(&UA>2!B92!P<F]V:61E9"!B>2!P
M87)E;G0@96QE;65N="!O<B!E=F5N(&YO="!A="!A;&PN"B`@("`@*B\*("`@
M('9A<B`D7V-O;G1E;G14>7!E.PH*("`@('9A<B`D7V-O;G1E;G0["@H@("`@
M9G5N8W1I;VX@4WEN8TU,7U-Y;F-)=&5M*"1E;&5M96YT5'EP92P@)&-O;G1E
M;G0@/2!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT
M96YT5'EP92`](&YU;&PL("1C=6ED(#T@;G5L;"D*("`@('L*("`@("`@("`D
M=&AI<RT^7V5L96UE;G14>7!E(#T@)&5L96UE;G14>7!E.PH@("`@("`@("1T
M:&ES+3Y?8W5I9"`]("1C=6ED.PH@("`@("`@("1T:&ES+3Y?8V]N=&5N=%1Y
M<&4@/2`D8V]N=&5N=%1Y<&4["B`@("`@("`@)'1H:7,M/E]C;VYT96YT(#T@
M)&-O;G1E;G0["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T0W5I9"@I"B`@("![
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?8W5I9#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971#;VYT96YT*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]C;VYT96YT.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$-O;G1E;G14>7!E
M*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]C;VYT96YT5'EP93L*
M("`@('T*"B`@("!F=6YC=&EO;B!G971%;&5M96YT5'EP92@I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?96QE;65N=%1Y<&4["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O
M;6UA;F0O4W1A='5S+G!H<```````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,38Q,3`@,3`U,34T,S0Q,S8@,#(S,#(Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@
M)U-Y;F--3"]#;VUM86YD+G!H<"<["G)E<75I<F5?;VYC92`G4WEN8TU,+T-O
M;G-T86YT<RYP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K+U-Y;F--
M3"]3>6YC34PO0V]M;6%N9"]3=&%T=7,N<&AP+'8@,2XQ-2XQ,"XV(#(P,#8O
M,#$O,S$@,3<Z-34Z,3D@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S
M+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H*
M("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@
M:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($%N=&AO;GD@36EL;',@/&%M:6QL
M<T!P>7)A;6ED-BYC;VT^"B`J($!S:6YC92`@($AO<F1E(#,N,`H@*B!`<&%C
M:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--3%]#;VUM86YD7U-T871U<R!E
M>'1E;F1S(%-Y;F--3%]#;VUM86YD('L*"B`@("!V87(@)%]R97-P;VYS93L*
M"B`@("!V87(@)%]C;612968["@H@("`@+RHJ"B`@("`@*B!-=7-T(&)E('!R
M97-E;G0N"B`@("`@*B\*("`@('9A<B`D7V-M9#L*"B`@("!V87(@)%]S;W5R
M8V52968["@H@("`@=F%R("1?=&%R9V5T4F5F.PH*("`@('9A<B`D7V-H86Q-
M971A1F]R;6%T.PH*("`@('9A<B`D7V-H86Q-971A5'EP93L*"B`@("!V87(@
M)%]C:&%L365T84YE>'1.;VYC93L*"B`@("!V87(@)%]I=&5M1&%T84%N8VAO
M<DYE>'0["@H@("`@=F%R("1?:71E;41A=&%!;F-H;W),87-T.PH*("`@(&9U
M;F-T:6]N(%-Y;F--3%]#;VUM86YD7U-T871U<R@D<F5S<&]N<V4@/2!N=6QL
M+"`D8VUD(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)')E<W!O;G-E("$]
M(&YU;&PI('L*("`@("`@("`@("`@)'1H:7,M/E]R97-P;VYS92`]("1R97-P
M;VYS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D8VUD("$](&YU;&PI('L*
M("`@("`@("`@("`@)'1H:7,M/E]C;60@/2`D8VUD.PH@("`@("`@('T*("`@
M('T*"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P
M=70I"B`@("!["B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@
M)'-T871E(#T@)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@
M(&EF("@D=&AI<RT^7V-M9"`A/2!N=6QL*2!["B`@("`@("`@("`@("1A='1R
M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G4W1A='5S)RP@)&%T=')S*3L*"B`@("`@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G0VUD240G+"`D871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D8W5R
M<F5N=$-M9$E$.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C
M:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)T-M9$E$)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<L("1A='1R
M<RD["B`@("`@("`@("`@("1C:&%R<R`]("1S=&%T92T^9V5T37-G240H*3L*
M("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@
M("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=-<V=2968G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G0VUD4F5F)RP@)&%T=')S*3L*("`@("`@
M("`@("`@)&-H87)S(#T@)'1H:7,M/E]C;612968["B`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD4F5F)RD["@H@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DDH*2P@)T-M9"<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1T
M:&ES+3Y?8VUD.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C
M:&%R<RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)T-M9"<I.PH*("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?=&%R9V5T4F5F*2D@>PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=487)G9712968G+"`D
M871T<G,I.PH@("`@("`@("`@("`@("`@)&-H87)S(#T@)'1H:7,M/E]T87)G
M9712968["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C
M:&%R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=487)G9712968G*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<V]U<F-E4F5F*2D@>PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=3;W5R8V52968G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@)&-H87)S(#T@)'1H:7,M/E]S;W5R8V52968["B`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@("`@("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=3;W5R
M8V52968G*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@268@=V4@
M87)E(')E<W!O;F1I;F<@=&\@=&AE(%-Y;F-(9'(@86YD('=E(&%R92!N;W0*
M("`@("`@("`@("`@+R\@875T:&]R:7IE9"!T:&5N(')E<75E<W0@8F%S:6,@
M875T:&]R:7IA=&EO;BX*("`@("`@("`@("`@+R\*("`@("`@("`@("`@+R\@
M1DE8344Z(%)I9VAT(&YO=R!W92!A;'=A>7,@<V5N9"!T:&ES+"!I9VYO<FEN
M9R!T:&4*("`@("`@("`@("`@+R\@:7-!=71H;W)I>F5D*"D@=&5S="X@27,@
M=&AA="!C;W)R96-T/PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;60@/3T@
M)U-Y;F-(9'(G("8F("$D<W1A=&4M/FES075T:&]R:7IE9"@I*2!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7V-H86Q-971A1F]R;6%T(#T@)V(V-"<["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-H86Q-971A5'EP92`]("=S>6YC;6PZ
M875T:"UB87-I8R<["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E<W!O;G-E
M(#T@4D534$].4T5?0U)%1$5.5$E!3%-?34E34TE.1SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;$UE=&%&;W)M
M870I("8F(&ES<V5T*"1T:&ES+3Y?8VAA;$UE=&%4>7!E*2D@>PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))
M*"DL("=#:&%L)RP@)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L("1A='1R
M<RD["@H@("`@("`@("`@("`@("`@)&UE=&%I;F9U<FD@/2`D<W1A=&4M/F=E
M=%5224UE=&$H*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)&UE=&%I;F9U<FDL("=4>7!E)RP@)&%T=')S*3L*("`@("`@("`@
M("`@("`@("1C:&%R<R`]("1T:&ES+3Y?8VAA;$UE=&%4>7!E.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@
M("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D;65T86EN9G5R:2P@)U1Y
M<&4G*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)&UE=&%I;F9U<FDL("=&;W)M870G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@)&-H87)S(#T@)'1H:7,M/E]C:&%L365T849O<FUA=#L*("`@("`@("`@
M("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=&;W)M
M870G*3L*"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))*"DL("=-971A)RD["B`@("`@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#:&%L)RD["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<L("1A='1R<RD["B`@("`@("`@
M("`@("1C:&%R<R`]("1T:&ES+3Y?<F5S<&]N<V4["B`@("`@("`@("`@("1O
M=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<I.PH*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?:71E;41A=&%!;F-H;W).97AT
M*2!\?"!I<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3&%S="DI('L*("`@
M("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G271E;2<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T
M<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G+"`D
M871T<G,I.PH*("`@("`@("`@("`@("`@("1M971A:6YF=7)I(#T@)'-T871E
M+3YG97154DE-971A*"D["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R
M=$5L96UE;G0H)&UE=&%I;F9U<FDL("=!;F-H;W(G+"`D871T<G,I.PH*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R
M3&%S="DI('L*"B`@("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D;65T86EN9G5R:2P@)TQA<W0G+"`D871T<G,I.PH@("`@("`@("`@
M("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7VET96U$871A06YC:&]R3&%S=#L*
M("`@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I
M.PH@("`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M971A
M:6YF=7)I+"`G3&%S="<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VET96U$871A06YC:&]R3F5X="DI
M('L*"B`@("`@("`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M;65T86EN9G5R:2P@)TYE>'0G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@
M("`D8VAA<G,@/2`D=&AI<RT^7VET96U$871A06YC:&]R3F5X=#L*("`@("`@
M("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@
M("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1M971A:6YF=7)I
M+"`G3F5X="<I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1O=71P=70M/F5N9$5L96UE;G0H)&UE=&%I;F9U<FDL("=!;F-H;W(G*3L*
M"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=$871A)RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RD["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E
M+3YG97154DDH*2P@)U-T871U<R<I.PH*("`@("`@("`@("`@)&-U<G)E;G1#
M;61)1"LK.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C=7)R96YT0VUD
M240["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y
M(')E<W!O;G-E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)')E<W!O
M;G-E("!.97<@=F%L=64@;V8@<')O<&5R='D@<F5S<&]N<V4N"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%)E<W!O;G-E*"1R97-P;VYS92D*("`@('L*("`@
M("`@("`D=&AI<RT^7W)E<W!O;G-E(#T@)')E<W!O;G-E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!C;60N"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D8VUD("!.97<@=F%L=64@;V8@<')O<&5R
M='D@8VUD+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971#;60H)&-M9"D*("`@
M('L*("`@("`@("`D=&AI<RT^7V-M9"`]("1C;60["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(&-M9%)E9BX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1C;612968@($YE=R!V86QU92!O9B!P<F]P
M97)T>2!C;612968N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-M9%)E9B@D
M8VUD4F5F*0H@("`@>PH@("`@("`@("1T:&ES+3Y?8VUD4F5F(#T@)&-M9%)E
M9CL*("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@
M<V]U<F-E4F5F+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-O=7)C
M95)E9B`@3F5W('9A;'5E(&]F('!R;W!E<G1Y('-O=7)C95)E9BX*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T4V]U<F-E4F5F*"1S;W5R8V52968I"B`@("![
M"B`@("`@("`@)'1H:7,M/E]S;W5R8V52968@/2`D<V]U<F-E4F5F.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P<F]P97)T>2!T87)G9712
M968N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%R9V5T4F5F("!.
M97<@=F%L=64@;V8@<')O<&5R='D@=&%R9V5T4F5F+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S971487)G9712968H)'1A<F=E=%)E9BD*("`@('L*("`@("`@
M("`D=&AI<RT^7W1A<F=E=%)E9B`]("1T87)G9712968["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!3971T97(@9F]R('!R;W!E<G1Y(&ET96U$871A06YC:&]R
M3F5X="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I=&5M1&%T84%N
M8VAO<DYE>'0@($YE=R!V86QU92!O9B!P<F]P97)T>2!I=&5M1&%T84%N8VAO
M<DYE>'0N"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ET96U$871A06YC:&]R
M3F5X="@D:71E;41A=&%!;F-H;W).97AT*0H@("`@>PH@("`@("`@("1T:&ES
M+3Y?:71E;41A=&%!;F-H;W).97AT(#T@)&ET96U$871A06YC:&]R3F5X=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E='1E<B!F;W(@<')O<&5R='D@:71E
M;41A=&%!;F-H;W),87-T+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)&ET96U$871A06YC:&]R3&%S="`@3F5W('9A;'5E(&]F('!R;W!E<G1Y(&ET
M96U$871A06YC:&]R3&%S="X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T271E
M;41A=&%!;F-H;W),87-T*"1I=&5M1&%T84%N8VAO<DQA<W0I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]I=&5M1&%T84%N8VAO<DQA<W0@/2`D:71E;41A=&%!
M;F-H;W),87-T.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO
M0V]M;6%N9"]!;&5R="YP:'``````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R-3`R-2`Q,#4Q-30S-#$S-B`P,C(V,3(`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC
M92`G4WEN8TU,+T-O;6UA;F0N<&AP)SL*"B\J*@H@*B!4:&4@4WEN8TU,7T%L
M97)T(&-L87-S('!R;W9I9&5S(&$@4WEN8TU,(&EM<&QE;65N=&%T:6]N(&]F
M"B`J('1H92!!;&5R="!C;VUM86YD(&%S(&1E9FEN960@:6X@4WEN8TU,(%)E
M<')E<V5N=&%T:6]N(%!R;W1O8V]L+`H@*B!V97)S:6]N(#$N,2`U+C4N,BX*
M("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD
M+T%L97)T+G!H<"QV(#$N,3@N,3`N.2`R,#`V+S`Q+S,Q(#$W.C4U.C,Q(&IA
M;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($%N=&AO;GD@36EL
M;',@/&%M:6QL<T!P>7)A;6ED-BYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S
M960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,
M*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H
M='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B!`
M875T:&]R("!!;G1H;VYY($UI;&QS(#QA;6EL;'-`<'ER86UI9#8N8V]M/@H@
M*B!`<VEN8V4@("!(;W)D92`S+C`*("H@0'!A8VMA9V4@4WEN8TU,"B`J+PIC
M;&%S<R!3>6YC34Q?0V]M;6%N9%]!;&5R="!E>'1E;F1S(%-Y;F--3%]#;VUM
M86YD('L*"B`@("`O*BH*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@
M("!V87(@)%]A;&5R=#L*"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B\*("`@('9A<B`D7W-O=7)C94QO8U5223L*"B`@("`O*BH*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W1A<F=E=$QO8U5223L*
M"B`@("`O*BH*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7VUE=&%!;F-H;W).97AT.PH*("`@("\J*@H@("`@("H@0'9A<B!I;G1E9V5R
M"B`@("`@*B\*("`@('9A<B`D7VUE=&%!;F-H;W),87-T.PH*("`@("\J*@H@
M("`@("H@0W)E871E<R!A(&YE=R!I;G-T86YC92!O9B!!;&5R="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@4WEN8TU,7T-O;6UA;F1?06QE<G0H)&%L97)T(#T@
M;G5L;"D*("`@('L*("`@("`@("!I9B`H)&%L97)T("$](&YU;&PI('L*("`@
M("`@("`@("`@)'1H:7,M/E]A;&5R="`]("1A;&5R=#L*("`@("`@("!]"B`@
M("!]"@H@("`@9G5N8W1I;VX@;W5T<'5T*"1C=7)R96YT0VUD240L("8D;W5T
M<'5T*0H@("`@>PH@("`@("`@(&=L;V)A;"`D8F%C:V5N9#L*"B`@("`@("`@
M)&%T=')S(#T@87)R87DH*3L*("`@("`@("`D<W1A=&4@/2`F)%]315-324].
M6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@+R\@2&%N9&QE('5N875T:&]R
M:7IE9"!F:7)S="X*("`@("`@("!I9B`H(21S=&%T92T^:7-!=71H;W)I>F5D
M*"DI('L*("`@("`@("`@("`@)'-T871U<R`]("9N97<@4WEN8TU,7T-O;6UA
M;F1?4W1A='5S*%)%4U!/3E-%7TE.5D%,241?0U)%1$5.5$E!3%,L("=!;&5R
M="<I.PH@("`@("`@("`@("`D<W1A='5S+3YS971#;612968H)'1H:7,M/E]C
M;61)1"D["B`@("`@("`@("`@("1C=7)R96YT0VUD240@/2`D<W1A='5S+3YO
M=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("`@("`@("`@(')E
M='5R;B`D8W5R<F5N=$-M9$E$.PH@("`@("`@('T*"B`@("`@("`@)&1A=&%B
M87-E(#T@)'1H:7,M/E]T87)G971,;V-54DD["@H@("`@("`@("\O(%-T;W)E
M(&-L:65N="=S($YE>'0@06YC:&]R(&EN(%-T871E+B`@069T97(@<W5C8V5S
M<V9U;"!S>6YC"B`@("`@("`@+R\@=&AI<R!I<R!T:&5N('=R:71T96X@=&\@
M<&5R<VES=&5N8V4@9F]R(&YE9V]T:6%T:6]N(&]F"B`@("`@("`@+R\@9G5R
M=&AE<B!S>6YC<RX*("`@("`@("`D<W1A=&4M/G-E=$-L:65N=$%N8VAO<DYE
M>'0H)&1A=&%B87-E+"`D=&AI<RT^7VUE=&%!;F-H;W).97AT*3L*"B`@("`@
M("`@)&EN9F\@/2`D8F%C:V5N9"T^9V5T4WEN8U-U;6UA<GDH)'-T871E+3YG
M9713>6YC261E;G1I9FEE<B@I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))*3L*"B`@("`@
M("`@:68@*&ES7V$H)&EN9F\L("=$871A5')E94]B:F5C="<I*2!["B`@("`@
M("`@("`@("1X(#T@)&EN9F\M/F=E="@G0VQI96YT06YC:&]R)RD["B`@("`@
M("`@("`@("1C;&EE;G1L87-T(#T@)'A;)&1A=&%B87-E73L*("`@("`@("`@
M("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H<W!R:6YT9B@G<')E=FEO=7,@<WEN
M8R!F;W5N9"!F;W(@9&%T86)A<V4Z("5S.R!C;&EE;G0M=',Z("5S)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T86)A
M<V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-L:65N=&QA<W0I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@
M("`@("`@)'@@/2`D:6YF;RT^9V5T*"=397)V97)!;F-H;W(G*3L*("`@("`@
M("`@("`@)'-T871E+3YS971397)V97)!;F-H;W),87-T*"1D871A8F%S92P@
M)'A;)&1A=&%B87-E72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&)A8VME;F0M/FQO9TUE<W-A9V4H<W!R:6YT9B@G4WEN8TU,.B!.;R!I;F9O
M(&%B;W5T('!R979I;W5S('-Y;F-S(&9O=6YD(&9O<B!I9"`E<R!A;F0@9&%T
M86)A<V4@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S=&%T92T^9V5T4WEN8TED96YT:69I97(H*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T86)A<V4I+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],
M24Y%7U\L(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)&-L:65N=&QA
M<W0@/2`P.PH@("`@("`@("`@("`D<W1A=&4M/G-E=%-E<G9E<D%N8VAO<DQA
M<W0H)&1A=&%B87-E+"`P*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E="!3
M97)V97(@06YC:&]R(&9O<B!T:&ES('-Y;F,@=&\@8W5R<F5N="!T:6UE+@H@
M("`@("`@("1S=&%T92T^<V5T4V5R=F5R06YC:&]R3F5X="@D9&%T86)A<V4L
M('1I;64H*2D["B`@("`@("`@:68@*"@D8VQI96YT;&%S="!\?"`D8VQI96YT
M;&%S="`]/3T@)S`G*0H@("`@("`@("`@("`@("`@("8F("1C;&EE;G1L87-T
M(#T]("1T:&ES+3Y?;65T84%N8VAO<DQA<W0I('L*("`@("`@("`@("`@+R\@
M3&%S="!3>6YC($%N8VAO<B!M871C:&5S+"!4=V]787E3>6YC('=I;&P@9&\N
M"B`@("`@("`@("`@("1C;V1E(#T@4D534$].4T5?3TL["B`@("`@("`@("`@
M("1B86-K96YD+3YL;V=-97-S86=E*")3>6YC34PZ($%N8VAO<B!M871C:"P@
M5'=O5V%Y4WEN8R!S:6YC92`B"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D8VQI96YT;&%S="P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?7RP@4$5!4E],3T=?1$5"54<I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@D8VQI96YT;&%S="D@
M>PH@("`@("`@("`@("`@("`@)&)A8VME;F0M/FQO9TUE<W-A9V4H)V-L:65N
M="!R97%U97-T960@<WEN8R!W:71H(&%N8VAO<B!T<R`G("X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?;65T84%N8VAO
M<DQA<W0@+B`G(&)U="!S97)V97(@)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G:&%S('1I;65S=&%M<"<@+B`D8VQI96YT;&%S
M="`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(&]N
M(&9I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M7U]&24Q%7U\L(%]?3$E.15]?+"!014%27TQ/1U])3D9/*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G92@B4WEN8TU,
M.B!!;F-H;W(@;6ES;6%T8V@L(&5N9F]R8VEN9R!3;&]W4WEN8R(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%]?1DE,15]?+"!?7TQ)3D5?
M7RP@4$5!4E],3T=?1$5"54<I.PH@("`@("`@("`@("`D8VQI96YT;&%S="`]
M(#`["B`@("`@("`@("`@("1S=&%T92T^<V5T4V5R=F5R06YC:&]R3&%S="@D
M9&%T86)A<V4L(#`I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]A;&5R="`]
M/2`R,#$I('L*("`@("`@("`@("`@("`@("\J(%-L;W=S>6YC(')E<75E<W1E
M9"!F<F]M(&-L:65N="!A;GEW87DZ(&IU<W0@86-K;F]W;&5D9V4N("HO"B`@
M("`@("`@("`@("`@("`D8V]D92`](%)%4U!/3E-%7T]+.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+RH@36ES;6%T8V@L(&5N9F]R
M8V4@<VQO=R!S>6YC+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A;&5R
M="`](#(P,3L*("`@("`@("`@("`@("`@("1C;V1E(#T@-3`X.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<W1A='5S(#T@)FYE=R!3>6YC
M34Q?0V]M;6%N9%]3=&%T=7,H)&-O9&4L("=!;&5R="<I.PH@("`@("`@("1S
M=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^7V-M9$E$*3L*("`@("`@("!I9B`H
M)'1H:7,M/E]S;W5R8V5,;V-54DD@(3T@;G5L;"D@>PH@("`@("`@("`@("`D
M<W1A='5S+3YS9713;W5R8V52968H)'1H:7,M/E]S;W5R8V5,;V-54DDI.PH@
M("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]T87)G971,;V-54DD@(3T@
M;G5L;"D@>PH@("`@("`@("`@("`D<W1A='5S+3YS971487)G9712968H)'1H
M:7,M/E]T87)G971,;V-54DDI.PH@("`@("`@('T*"B`@("`@("`@+R\@36ER
M<F]R($YE>'0@06YC:&]R(&9R;VT@8VQI96YT(&)A8VL@=&\@8VQI96YT+@H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VUE=&%!;F-H;W).97AT*2D@>PH@
M("`@("`@("`@("`D<W1A='5S+3YS971)=&5M1&%T84%N8VAO<DYE>'0H)'1H
M:7,M/E]M971A06YC:&]R3F5X="D["B`@("`@("`@?0H*("`@("`@("`O+R!-
M:7)R;W(@3&%S="!!;F-H;W(@9G)O;2!C;&EE;G0@8F%C:R!T;R!C;&EE;G0N
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;65T84%N8VAO<DQA<W0I*2![
M"B`@("`@("`@("`@("1S=&%T=7,M/G-E=$ET96U$871A06YC:&]R3&%S="@D
M=&AI<RT^7VUE=&%!;F-H;W),87-T*3L*("`@("`@("!]"@H@("`@("`@("1C
M=7)R96YT0VUD240@/2`D<W1A='5S+3YO=71P=70H)&-U<G)E;G1#;61)1"P@
M)&]U='!U="D["@H@("`@("`@(&EF("@D<W1A=&4M/FES075T:&]R:7IE9"@I
M*2!["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G06QE<G0G+"`D871T<G,I.PH*("`@("`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=#;61)1"<L
M("1A='1R<RD["B`@("`@("`@("`@("1C:&%R<R`]("1C=7)R96YT0VUD240[
M"B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@
M("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I
M+"`G0VUD240G*3L*"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N
M="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<L("1A='1R<RD["B`@("`@("`@
M("`@("1C:&%R<R`]("1T:&ES+3Y?86QE<G0["B`@("`@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G1&%T82<I.PH*("`@("`@
M("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL
M("=)=&5M)RP@)&%T=')S*3L*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W-O
M=7)C94QO8U5222`A/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)U1A<F=E="<L("1A
M='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@
M("`@("`@("`D8VAA<G,@/2`D=&AI<RT^7W-O=7)C94QO8U5223L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TQO8U5222<I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE
M;65N="@D<W1A=&4M/F=E=%5222@I+"`G5&%R9V5T)RD["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W1A<F=E=$QO8U5222`A/2!N
M=6QL*2!["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)U-O=7)C92<L("1A='1R<RD["B`@("`@("`@
M("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH
M*2P@)TQO8U5222<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D8VAA<G,@
M/2`D=&AI<RT^7W1A<F=E=$QO8U5223L*("`@("`@("`@("`@("`@("1O=71P
M=70M/F-H87)A8W1E<G,H)&-H87)S*3L*("`@("`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)TQO8U5222<I.PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G4V]U<F-E)RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T
M82<L("1A='1R<RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE-971A*"DL("=!;F-H;W(G+"`D871T<G,I.PH*
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))365T82@I+"`G3&%S="<L("1A='1R<RD["B`@("`@("`@("`@("1C:&%R
M<R`]("1S=&%T92T^9V5T4V5R=F5R06YC:&]R3&%S="@D9&%T86)A<V4I.PH@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-971A
M*"DL("=,87-T)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE
M;G0H)'-T871E+3YG97154DE-971A*"DL("=.97AT)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&-H87)S(#T@)'-T871E+3YG971397)V97)!;F-H;W).97AT
M*"1D871A8F%S92D["B`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H
M)&-H87)S*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A
M=&4M/F=E=%5224UE=&$H*2P@)TYE>'0G*3L*"B`@("`@("`@("`@("1O=71P
M=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-971A*"DL("=!;F-H;W(G
M*3L*("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G365T82<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M
M96YT*"1S=&%T92T^9V5T55))*"DL("=)=&5M)RD["B`@("`@("`@("`@("1O
M=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T%L97)T)RD[
M"@H@("`@("`@("`@("`D8W5R<F5N=$-M9$E$*RL["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)&-U<G)E;G1#;61)1#L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E='1E<B!F;W(@<')O<&5R='D@<V]U<F-E55))+@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)'-O=7)C955222`@3F5W('9A;'5E(&]F('!R
M;W!E<G1Y('-O=7)C955222X*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T4V]U
M<F-E3&]C55))*"1S;W5R8V554DDI"B`@("!["B`@("`@("`@)'1H:7,M/E]S
M;W5R8V554DD@/2`D<V]U<F-E55)).PH@("`@?0H*("`@(&9U;F-T:6]N(&=E
M=%1A<F=E=$QO8U5222@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=&%R9V5T55)).PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T=&5R(&9O<B!P
M<F]P97)T>2!T87)G97154DDN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&%R9V5T55))("!.97<@=F%L=64@;V8@<')O<&5R='D@=&%R9V5T55))
M+@H@("`@("HO"B`@("!F=6YC=&EO;B!S971487)G97154DDH)'1A<F=E=%52
M22D*("`@('L*("`@("`@("`D=&AI<RT^7W1A<F=E=%5222`]("1T87)G9715
M4DD["B`@("!]"@H@("`@9G5N8W1I;VX@<W1A<G1%;&5M96YT*"1U<FDL("1E
M;&5M96YT+"`D871T<G,I"B`@("!["B`@("`@("`@<&%R96YT.CIS=&%R=$5L
M96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R<RD["@H@("`@?0H*("`@(&9U
M;F-T:6]N(&5N9$5L96UE;G0H)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@
M("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1T
M:&ES+3Y?4W1A8VLI*2!["B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`D
M<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?=&%R9V5T3&]C55))("$]("=T87-K<R<*("`@("`@
M("`@("`@("`@("8F("1T:&ES+3Y?=&%R9V5T3&]C55))("$]("=C86QE;F1A
M<B<*("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?=&%R9V5T3&]C55))("$]
M("=N;W1E<R<*("`@("`@("`@("`@("`@("8F("1T:&ES+3Y?=&%R9V5T3&]C
M55))("$]("=C;VYT86-T<R<I('L*("`@("`@("`@("`@("`@("1B86-K96YD
M+3YL;V=-97-S86=E*"=%<G)O<B$@26YV86QI9"!D871A8F%S93H@)PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7W1A
M<F=E=$QO8U5220H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G+B!/;FQY('1A<VMS+"!C86QE;F1A<BP@;F]T97,L)PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&%N9"!C;VYT86-T
M<R!A;&QO=V5D(2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD["B`@("`@
M("`@("`@("`@("!D:64H(F5R<F]R.B!I;G9A;&ED(&1A=&%B87-E(2(I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D8F%C:V5N9"T^;&]G365S<V%G
M92@G;&]O:VEN9R!F;W(@<WEN8R!F;W(@)R`N"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L
M(%!%05)?3$]'7T1%0E5'*3L*("`@("`@("`@("`@)'-Y;F,@/2`F("1S=&%T
M92T^9V5T4WEN8R@D=&AI<RT^7W1A<F=E=$QO8U5222D["@H@("`@("`@("`@
M("!I9B`H(21S>6YC*2!["B`@("`@("`@("`@("`@("`D8F%C:V5N9"T^;&]G
M365S<V%G92@G0W)E871E(&YE=R!S>6YC(&9O<B`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%R9V5T3&]C55))
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L(%]?3$E.15]?+"!014%27TQ/1U]$14)51RD["@H@("`@("`@("`@("`@
M("`@)'-Y;F,@/2`F;F5W(%-Y;F--3%]3>6YC*"1T:&ES+3Y?86QE<G0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]T87)G971,;V-54DDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V5,;V-54DDI.PH@("`@("`@("`@
M("`@("`@)'-T871E+3YS9713>6YC*"1T:&ES+3Y?=&%R9V5T3&]C55))+"`D
M<WEN8RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@,CH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=$871A
M)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A;&5R="`](&EN='9A;"AT
M<FEM*"1T:&ES+3Y?8VAA<G,I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`T.@H@("`@("`@("`@("!I9B`H)&5L
M96UE;G0@/3T@)TQO8U5222<I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^7U-T86-K6S)=(#T]("=3;W5R8V4G*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]S;W5R8V5,;V-54DD@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I
M.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?4W1A8VM;,ET@
M/3T@)U1A<F=E="<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W1A
M<F=E=$QO8U5222`](&)A<V5N86UE*'!R96=?<F5P;&%C92@G+UP_+BHD+R<L
M("<G+"!T<FEM*"1T:&ES+3Y?8VAA<G,I*2D["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A
M<V4@-3H*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T]("=.97AT)RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]M971A06YC:&]R3F5X="`]('1R:6TH
M)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@('T@96QS96EF("@D96QE;65N
M="`]/2`G3&%S="<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;65T84%N
M8VAO<DQA<W0@/2!T<FEM*"1T:&ES+3Y?8VAA<G,I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@<&%R96YT
M.CIE;F1%;&5M96YT*"1U<FDL("1E;&5M96YT*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!G971!;&5R="@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M86QE<G0["B`@("!]"@H@("`@9G5N8W1I;VX@<V5T06QE="@D86QE<G0I"B`@
M("!["B`@("`@("`@)'1H:7,M/E]A;&5R="`]("1A;&5R=#L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,+T-O;6UA;F0O1V5T+G!H
M<```````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C$V,38@,3`U
M,34T,S0Q,S8@,#(R,C8T`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)U-Y;F--3"]#;VUM
M86YD+G!H<"<["@HO*BH*("H@5&AE(%-Y;F--3%]#;VUM86YD7T=E="!C;&%S
M<RX*("H*("H@5&AI<R!C;&%S<R!R97-P;VYD<R!T;R!A(&-L:65N="!G970@
M<F5Q=65S="!A;F0@<F5T=7)N<R!T:&4@1&5V26YF"B`J(&EN9F]R;6%T:6]N
M(&9O<B!T:&4@4WEN8TU,('-E<G9E<BX*("H*("H@)$AO<F1E.B!F<F%M97=O
M<FLO4WEN8TU,+U-Y;F--3"]#;VUM86YD+T=E="YP:'`L=B`Q+C$T+C$P+C$P
M(#(P,#8O,#4O,CD@,38Z-#`Z,S<@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`R,#`S+3(P,#8@06YT:&]N>2!-:6QL<R`\86UI;&QS0'!Y<F%M:60V+F-O
M;3X*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO
M;G0@/&9O=7)M;VYT0&=M>"YD93X*("H@0&%U=&AO<B`@06YT:&]N>2!-:6QL
M<R`\86UI;&QS0'!Y<F%M:60V+F-O;3X*("H@0'-I;F-E("`@2&]R9&4@,RXP
M"B`J($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?
M1V5T(&5X=&5N9',@4WEN8TU,7T-O;6UA;F0@>PH*("`@(&9U;F-T:6]N(&]U
M='!U="@D8W5R<F5N=$-M9$E$+"`F)&]U='!U="D*("`@('L*("`@("`@("`D
M<W1A=&4@/2`F)%]315-324].6R=3>6YC34PN<W1A=&4G73L*"B`@("`@("`@
M)')E9B`]("@D<W1A=&4M/F=E=%9E<G-I;VXH*2`]/2`P*2`_("<N+V1E=FEN
M9C$P)R`Z("<N+V1E=FEN9C$Q)SL*"B`@("`@("`@)'-T871U<R`]("9N97<@
M4WEN8TU,7T-O;6UA;F1?4W1A='5S*"@D<W1A=&4M/FES075T:&]R:7IE9"@I
M(#\@4D534$].4T5?3TL@.B!215-03TY315])3E9!3$E$7T-2141%3E1)04Q3
M*2P@)T=E="<I.PH@("`@("`@("1S=&%T=7,M/G-E=$-M9%)E9B@D=&AI<RT^
M7V-M9$E$*3L*("`@("`@("`D<W1A='5S+3YS971487)G9712968H)')E9BD[
M"B`@("`@("`@)&-U<G)E;G1#;61)1"`]("1S=&%T=7,M/F]U='!U="@D8W5R
M<F5N=$-M9$E$+"`D;W5T<'5T*3L*"B`@("`@("`@:68@*"1S=&%T92T^:7-!
M=71H;W)I>F5D*"DI('L*("`@("`@("`@("`@)&%T=')S(#T@87)R87DH*3L*
M("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T
M55))*"DL("=297-U;'1S)RP@)&%T=')S*3L*"B`@("`@("`@("`@("1O=71P
M=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G0VUD240G+"`D
M871T<G,I.PH@("`@("`@("`@("`D8VAA<G,@/2`D8W5R<F5N=$-M9$E$.PH@
M("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1C:&%R<RD["B`@("`@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T-M9$E$)RD["@H@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DDH*2P@)TUS9U)E9B<L("1A='1R<RD["B`@("`@("`@
M("`@("1C:&%R<R`]("1S=&%T92T^9V5T37-G240H*3L*("`@("`@("`@("`@
M)&]U='!U="T^8VAA<F%C=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=-<V=2968G*3L*
M"B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%5222@I+"`G0VUD4F5F)RP@)&%T=')S*3L*("`@("`@("`@("`@)&-H87)S
M(#T@)'1H:7,M/E]C;61)1#L*("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C
M=&5R<R@D8VAA<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))*"DL("=#;612968G*3L*"B`@("`@("`@("`@("1O
M=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G365T82<L
M("1A='1R<RD["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D
M<W1A=&4M/F=E=%5224UE=&$H*2P@)U1Y<&4G+"`D871T<G,I.PH@("`@("`@
M("`@("!I9B`H:7-?82@D;W5T<'5T+"`G6$U,7U="6$U,7T5N8V]D97(G*2D@
M>PH@("`@("`@("`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<RA-24U%7U-9
M3D--3%]$159)0T5?24Y&3U]70EA-3"D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*$U)345?4UE.
M0TU,7T1%5DE#15])3D9/7UA-3"D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE-971A*"DL
M("=4>7!E)RD["B`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DDH*2P@)TUE=&$G*3L*"B`@("`@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E;2<L("1A='1R
M<RD["B`@("`@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%5222@I+"`G4V]U<F-E)RP@)&%T=')S*3L*("`@("`@("`@("`@)&]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))*"DL("=,;V-54DDG
M+"`D871T<G,I.PH@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1R
M968I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=,;V-54DDG*3L*("`@("`@("`@("`@)&]U='!U="T^96YD
M16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G4V]U<F-E)RD["@H@("`@("`@
M("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DDH*2P@
M)T1A=&$G+"`D871T<G,I.PH*("`@("`@("`@("`@+RH@1&5V26YF(&1A=&$@
M:7,@<W1O<F5D(&EN('=B>&UL(&YO="!A<R!A('-E<&5R871E(&-O9&5P86=E
M(&)U=`H@("`@("`@("`@("`@*B!R871H97(@87,@82!C;VUP;&5T92!W8GAM
M;"!S=')E86T@87,@;W!A<75E(&1A=&$N("!3;R!W92!N965D(&$*("`@("`@
M("`@("`@("H@;F5W($AA;F1L97(N("HO"B`@("`@("`@("`@("1D979I;F9O
M=71P=70@/2`D;W5T<'5T+3YC<F5A=&53=6)(86YD;&5R*"D["B`@("`@("`@
M("`@(`H@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=$979);F8G+"`D871T<G,I.PH@
M("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E
M+3YG97154DE$979);F8H*2`L("=697)$5$0G+"`D871T<G,I.PH@("`@("`@
M("`@("`D9&5V:6YF;W5T<'5T+3YC:&%R86-T97)S*"@D<W1A=&4M/F=E=%9E
M<G-I;VXH*2`]/2`P*2`_("<Q+C`G(#H@)S$N,2<I.PH@("`@("`@("`@("`D
M9&5V:6YF;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF
M*"D@+"`G5F5R1%1$)RP@)&%T=')S*3L*("`@("`@("`@("`@)&1E=FEN9F]U
M='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G
M36%N)RP@)&%T=')S*3L*("`@("`@("`@("`@)&1E=FEN9F]U='!U="T^8VAA
M<F%C=&5R<R@G5&AE($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N
M;W)G*2<I.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G36%N)RP@)&%T=')S*3L*("`@
M("`@("`@("`@)&1E=FEN9F]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^
M9V5T55))1&5V26YF*"D@+"`G1&5V240G+"`D871T<G,I.PH@("`@("`@("`@
M("`D9&5V:6YF;W5T<'5T+3YC:&%R86-T97)S*"1?4T525D526R=(5%107TA/
M4U0G72D["B`@("`@("`@("`@("1D979I;F9O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=$979)1"<L("1A='1R<RD["B`@
M("`@("`@("`@("1D979I;F9O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M
M/F=E=%52241E=DEN9B@I("P@)T1E=E1Y<"<L("1A='1R<RD["B`@("`@("`@
M("`@("1D979I;F9O=71P=70M/F-H87)A8W1E<G,H)W-E<G9E<B<I.PH@("`@
M("`@("`@("`D9&5V:6YF;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T
M55))1&5V26YF*"D@+"`G1&5V5'EP)RP@)&%T=')S*3L*("`@("`@("`@("`@
M)'1H:7,M/E]W<FET941A=&%3=&]R92@G;F]T97,G+"`G=&5X="]X+79N;W1E
M)RP@)S$N,2<L("1D979I;F9O=71P=70L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W1E>'0O<&QA:6XG(#T^("<Q+C`G*2D[
M"B`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5$871A4W1O<F4H)V-O;G1A8W1S
M)RP@)W1E>'0O>"UV8V%R9"<L("<S+C`G+"`D9&5V:6YF;W5T<'5T+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T97AT+W@M
M=F-A<F0G(#T^("<R+C$G*2D["B`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5$
M871A4W1O<F4H)W1A<VMS)RP@)W1E>'0O8V%L96YD87(G+"`G,BXP)RP@)&1E
M=FEN9F]U='!U="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@G=&5X="]X+79C86QE;F1A<B<@/3X@)S$N,"<I*3L*("`@("`@
M("`@("`@)'1H:7,M/E]W<FET941A=&%3=&]R92@G8V%L96YD87(G+"`G=&5X
M="]C86QE;F1A<B<L("<R+C`G+"`D9&5V:6YF;W5T<'5T+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=T97AT+W@M=F-A;&5N
M9&%R)R`]/B`G,2XP)RDI.PH@("`@("`@("`@("`D9&5V:6YF;W5T<'5T+3YE
M;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G1&5V26YF)RP@
M)&%T=')S*3L*"B`@("`@("`@("`@("1O=71P=70M/F]P87%U92@D9&5V:6YF
M;W5T<'5T+3YG971/=71P=70H*2D["B`@("`@("`@("`@("1O=71P=70M/F5N
M9$5L96UE;G0H)'-T871E+3YG97154DDH*2P@)T1A=&$G*3L*("`@("`@("`@
M("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%5222@I+"`G271E
M;2<I.PH@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^
M9V5T55))*"DL("=297-U;'1S)RD["@H@("`@("`@("`@("`D8W5R<F5N=$-M
M9$E$*RL["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&-U<G)E;G1#;61)
M1#L*("`@('T*"B`@("`O*BH*("`@("`J(%=R:71E<R!$979);F8@9&%T82!F
M;W(@;VYE($1A=&%3=&]R92X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S;W5R8V5R968Z(&1A=&$@9F]R(%-O=7)C95)E9B!E;&5M96YT+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;6EM971Y<&4Z(&1A=&$@9F]R("9L=#LH4GQ4
M*7@M4')E9B9G=#LF;'0[0U14>7!E)F=T.PH@("`@("H@0'!A<F%M('-T<FEN
M9R`D=F5R<VEO;CH@9&%T82!F;W(@)FQT.RA2?%0I>"U0<F5F)F=T.R9L=#M6
M97)#5"9G=#L*("`@("`J($!P87)A;2!S=')I;F<@)B1O=71P=70@8V]N=&5N
M=&AA;F1L97(@=&AA="!W:6QL(')E8V5I=F5D('1H92!O=71P=70N"B`@("`@
M*B!`<&%R86T@87)R87D@)&%D9&ET:6]N86QT>7!E<SH@87)R87D@;V8@861D
M:71I;VYA;"!T>7!E<R!F;W(@5'@@86YD(%)X.PH@("`@("H@("`@("`@("`@
M("`@(&9O<FUA="!A<G)A>2@G=&5X="]V8V%R9"<@/3X@)S(N,"<I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]W<FET941A=&%3=&]R92@D<V]U<F-E<F5F+"`D
M;6EM971Y<&4L("1V97)S:6]N+"`F)&]U='!U="P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D861D:71I;VYA;'1Y<&5S(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)&%T=')S(#T@87)R87DH*3L*"B`@("`@("`@)'-T871E(#T@
M)B1?4T534TE/3ELG4WEN8TU,+G-T871E)UT["@H@("`@("`@("1O=71P=70M
M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T1A=&%3
M=&]R92<L("1A='1R<RD["B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT
M*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4V]U<F-E4F5F)RP@)&%T=')S
M*3L*("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S*"1S;W5R8V5R968I.PH@
M("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979)
M;F8H*2`L("=3;W5R8V52968G+"`D871T<G,I.PH*("`@("`@("`D;W5T<'5T
M+3YS=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=2>"U0
M<F5F)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@
M("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&UI;65T>7!E*3L*("`@("`@
M("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@
M+"`G0U14>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YS=&%R=$5L
M96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#5"<L("1A='1R
M<RD["B`@("`@("`@)&]U='!U="T^8VAA<F%C=&5R<R@D=F5R<VEO;BD["B`@
M("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN
M9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T+3YE;F1%
M;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4G@M4')E9B<L("1A
M='1R<RD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D861D:71I;VYA;'1Y<&5S
M*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D861D:71I;VYA;'1Y<&5S(&%S
M("1C="`]/B`D8W1V97(I>PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A
M<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G4G@G+"`D871T
M<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G0U14>7!E)RP@)&%T=')S*3L*("`@
M("`@("`@("`@("`@("1O=71P=70M/F-H87)A8W1E<G,H)&-T*3L*("`@("`@
M("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$
M979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@
M+"`G5F5R0U0G+"`D871T<G,I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M8VAA<F%C=&5R<R@D8W1V97(I.PH@("`@("`@("`@("`@("`@)&]U='!U="T^
M96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@
M)&%T=')S*3L*("`@("`@("`@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=2>"<L("1A='1R<RD["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1O=71P=70M/G-T87)T16QE
M;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U1X+5!R968G+"`D871T
M<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E
M=%52241E=DEN9B@I("P@)T-45'EP92<L("1A='1R<RD["B`@("`@("`@)&]U
M='!U="T^8VAA<F%C=&5R<R@D;6EM971Y<&4I.PH@("`@("`@("1O=71P=70M
M/F5N9$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=#5%1Y<&4G
M+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A
M=&4M/F=E=%52241E=DEN9B@I("P@)U9E<D-4)RP@)&%T=')S*3L*("`@("`@
M("`D;W5T<'5T+3YC:&%R86-T97)S*"1V97)S:6]N*3L*("`@("`@("`D;W5T
M<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R
M0U0G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F5N9$5L96UE;G0H)'-T
M871E+3YG97154DE$979);F8H*2`L("=4>"U0<F5F)RP@)&%T=')S*3L*"B`@
M("`@("`@:68@*&ES7V%R<F%Y*"1A9&1I=&EO;F%L='EP97,I*2!["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1A9&1I=&EO;F%L='EP97,@87,@)&-T(#T^("1C
M='9E<BE["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H
M)'-T871E+3YG97154DE$979);F8H*2`L("=4>"<L("1A='1R<RD["B`@("`@
M("`@("`@("`@("`D;W5T<'5T+3YS=&%R=$5L96UE;G0H)'-T871E+3YG9715
M4DE$979);F8H*2`L("=#5%1Y<&4G+"`D871T<G,I.PH@("`@("`@("`@("`@
M("`@)&]U='!U="T^8VAA<F%C=&5R<R@D8W0I.PH@("`@("`@("`@("`@("`@
M)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@
M)T-45'EP92<L("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YS
M=&%R=$5L96UE;G0H)'-T871E+3YG97154DE$979);F8H*2`L("=697)#5"<L
M("1A='1R<RD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YC:&%R86-T97)S
M*"1C='9E<BD["B`@("`@("`@("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT
M*"1S=&%T92T^9V5T55))1&5V26YF*"D@+"`G5F5R0U0G+"`D871T<G,I.PH@
M("`@("`@("`@("`@("`@)&]U='!U="T^96YD16QE;65N="@D<W1A=&4M/F=E
M=%52241E=DEN9B@I("P@)U1X)RP@)&%T=')S*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T
M92T^9V5T55))1&5V26YF*"D@+"`G4WEN8T-A<"<L("1A='1R<RD["B`@("`@
M("`@)&]U='!U="T^<W1A<G1%;&5M96YT*"1S=&%T92T^9V5T55))1&5V26YF
M*"D@+"`G4WEN8U1Y<&4G+"`D871T<G,I.PH@("`@("`@("1O=71P=70M/F-H
M87)A8W1E<G,H)S$G*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S
M=&%T92T^9V5T55))1&5V26YF*"D@+"`G4WEN8U1Y<&4G+"`D871T<G,I.PH@
M("`@("`@("1O=71P=70M/G-T87)T16QE;65N="@D<W1A=&4M/F=E=%52241E
M=DEN9B@I("P@)U-Y;F-4>7!E)RP@)&%T=')S*3L*("`@("`@("`D;W5T<'5T
M+3YC:&%R86-T97)S*"<R)RD["B`@("`@("`@)&]U='!U="T^96YD16QE;65N
M="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)U-Y;F-4>7!E)RP@)&%T=')S
M*3L*("`@("`@("`D;W5T<'5T+3YE;F1%;&5M96YT*"1S=&%T92T^9V5T55))
M1&5V26YF*"D@+"`G4WEN8T-A<"<L("1A='1R<RD["B`@("`@("`@)&]U='!U
M="T^96YD16QE;65N="@D<W1A=&4M/F=E=%52241E=DEN9B@I("P@)T1A=&%3
M=&]R92<L("1A='1R<RD["B`@("!]"@I]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VQI8B]3>6YC34PO0V]M;6%N
M9"]3>6YC+G!H<```````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M,3(R-B`Q,#4Q-30S-#$S-B`P,C(T-34`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"FEN8VQU9&5?;VYC92`G4WEN
M8TU,+T-O;6UA;F0N<&AP)SL*:6YC;'5D95]O;F-E("=3>6YC34PO0V]M;6%N
M9"]3>6YC16QE;65N="YP:'`G.PH*+RHJ"B`J("1(;W)D93H@9G)A;65W;W)K
M+U-Y;F--3"]3>6YC34PO0V]M;6%N9"]3>6YC+G!H<"QV(#$N,3<N,3`N."`R
M,#`V+S`Q+S$Q(#$X.C,Y.C(X('-E;'-K>2!%>'`@)`H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N
M;W)G/@H@*@H@*B!4:&4@8V]M;6%N9"!H86YD;&5R(&9O<B!T:&4@)F=T.U-Y
M;F,F;'0[(&-O;6UA;F0@:7,@=&AE(&-E;G1R86P*("H@8VQA<W,@=&\@9&ES
M<&%T8V@@<WEN8R!M97-S86=E<RX*("H*("H@1'5R:6YG('!A<G-I;F<@;V8@
M=&AE(')E8V5I=F5D(%A-3"P@=&AE(&%C='5A;"!S>6YC(&-O;6UA;F1S("A!
M9&0L"B`J(%)E<&QA8V4L($1E;&5T92D@9G)O;2!T:&4@8VQI96YT(&%R92!S
M=&]R960@:6X@=&AE(%]S>6YC16QE;65N=',*("H@871T<FEB=71E+B`@5VAE
M;B!T:&4@;W5T<'5T(&UE=&AO9"!O9B!3>6YC34Q?0V]M;6%N9%]3>6YC(&ES
M"B`J(&-A;&QE9"P@=&AE<V4@96QE;65N=',@87)E('!R;V-E<W-E9"!A;F0@
M=&AE(')E<W5L=&EN9R!S=&%T=7,*("H@;65S<V%G97,@8W)E871E9"X*("H*
M("H@5&AE;B!T:&4@<V5R=F5R(&UO9&EF:6-A=&EO;G,@87)E('-E;G0@8F%C
M:R!T;R!T:&4@8VQI96YT(&)Y('1H90H@*B!H86YD;&53>6YC(&UE=&AO9"!W
M:&EC:"!I<R!C86QL960@9G)O;2!W:71H:6X@=&AE(&]U='!U="!M971H;V0N
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*@H@*B!`875T:&]R("!+87)S=&5N($9O=7)M;VYT
M(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'-I;F-E("`@2&]R9&4@,RXP"B`J
M($!P86-K86=E(%-Y;F--3`H@*B\*8VQA<W,@4WEN8TU,7T-O;6UA;F1?4WEN
M8R!E>'1E;F1S(%-Y;F-M;%]#;VUM86YD"GL*("`@("\J*@H@("`@("H@0'9A
M<B!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N=`H@("`@("HO"B`@("!V87(@
M)%]C=7)R96YT4WEN8T5L96UE;G0["@H@("`@+RHJ"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7W-Y;F-%;&5M96YT<R`](&%R<F%Y*"D[
M"@H@("`@+RHJ"B`@("`@*B!C;VYT86-T<RP@8V%L96YD87(L('1A<VMS(&]R
M(&YO=&5S"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?=&%R9V5T55)).PH*("`@("\J*@H@("`@("H@0W)E871E<R!A(')E
M<W!O;G-E('1O(&$@<WEN8R!C;VUM86YD+@H@("`@("H@0W5R<F5N=&QY('1H
M870G<R!T:&4@<&QA8V4@=VAE<F4@=V4@86QS;R!C<F5A=&4*("`@("`J('1H
M92`F;'0[<WEN8R9G=#L@=VET:"!T:&4@<V5R=F5R(&-H86YG97,@=&AA=`H@
M("`@("H@;F5E9',@=&\@8F4@<V5N9"!T;R!T:&4@8VQI96YT+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!O=71P=70H)&-U<G)E;G1#;61)1"P@)B1O=71P=70I
M"B`@("!["B`@("`@("`@)'-T871E(#TF("1?4T534TE/3ELG4WEN8TU,+G-T
M871E)UT["B`@("`@("`@)'-Y;F,@/28@)'-T871E+3YG9713>6YC*"1T:&ES
M+3Y?=&%R9V5T55))*3L*("`@("`@("!I9B`H(6ES7V]B:F5C="@D<WEN8RDI
M('L*("`@("`@("`@("`@)$=,3T)!3%-;)V)A8VME;F0G72T^;&]G365S<V%G
M92@G3F\@<WEN8R!O8FIE8W0@9F]U;F0@9F]R(%5222`]("<@+B`D=&AI<RT^
M7W1A<F=E=%5222P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!?7T9)3$5?7RP@7U],24Y%7U\L(%!%05)?3$]'7T524BD[
M"B`@("`@("`@("`@("\O($!43T1/.B!C<F5A=&4@;65A;FEN9V9U;"!S=&%T
M=7,@8V]D92!H97)E+@H@("`@("`@('T*"B`@("`@("`@+R\@2&5R92=S('=H
M97)E(&-L:65N="!M;V1I9FEC871I;VYS(&%R92!P<F]C97-S960Z"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]S>6YC16QE;65N=',@87,@)&5L96UE;G0I
M('L*("`@("`@("`@("`@9F]R96%C:"`H)&5L96UE;G0M/F=E=$ET96US*"D@
M87,@)&ET96TI('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D<WEN8RT^
M:&%N9&QE4WEN8TET96TH)&ET96TI.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1C=7)R96YT0VUD240@/2`D96QE;65N="T^;W5T<'5T*"1C=7)R96YT
M0VUD240L("1O=71P=70I.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]W('-E
M;F0@8VQI96YT(&-H86YG97,@=&\@<V5R=F5R.B!T:&ES('=I;&P@<')E8V5D
M92!T:&4*("`@("`@("`@*B`\<WEN8SX@<F5S<&]N<V4Z("HO"B`@("`@("`@
M)&-U<G)E;G1#;61)1"`]("1S>6YC+3YC<F5A=&53>6YC3W5T<'5T*"1C=7)R
M96YT0VUD240L("1O=71P=70I.PH*("`@("`@("`D<W1A='5S(#T@)FYE=R!3
M>6YC34Q?0V]M;6%N9%]3=&%T=7,H4D534$].4T5?3TLL("=3>6YC)RD["B`@
M("`@("`@)'-T871U<RT^<V5T0VUD4F5F*"1T:&ES+3Y?8VUD240I.PH*("`@
M("`@("!I9B`H)'1H:7,M/E]T87)G97154DD@(3T@;G5L;"D@>PH@("`@("`@
M("`@("`D<W1A='5S+3YS971487)G9712968H)'1H:7,M/E]T87)G97154DDI
M.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?<V]U<F-E55))("$]
M(&YU;&PI('L*("`@("`@("`@("`@)'-T871U<RT^<V5T4V]U<F-E4F5F*"1T
M:&ES+3Y?<V]U<F-E55))*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M<W1A='5S+3YO=71P=70H)&-U<G)E;G1#;61)1"P@)&]U='!U="D["B`@("!]
M"@H@("`@9G5N8W1I;VX@9V5T5&%R9V5T55))*"D*("`@('L*("`@("`@("!R
M971U<FX@)'1H:7,M/E]T87)G97154DD["B`@("!]"@H@("`@9G5N8W1I;VX@
M<W1A<G1%;&5M96YT*"1U<FDL("1E;&5M96YT+"`D871T<G,I"B`@("!["B`@
M("`@("`@<&%R96YT.CIS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A
M='1R<RD["@H@("`@("`@('-W:71C:"`H8V]U;G0H)'1H:7,M/E]3=&%C:RDI
M('L*("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@(&EF("@D96QE;65N="`]
M/2`G4F5P;&%C92<@?'P@)&5L96UE;G0@/3T@)T%D9"<@?'P@)&5L96UE;G0@
M/3T@)T1E;&5T92<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N
M=%-Y;F-%;&5M96YT(#T@)FYE=R!3>6YC34Q?0V]M;6%N9%]3>6YC16QE;65N
M="@D96QE;65N="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C=7)R96YT
M4WEN8T5L96UE;G0I*2!["B`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%-Y
M;F-%;&5M96YT+3YS=&%R=$5L96UE;G0H)'5R:2P@)&5L96UE;G0L("1A='1R
M<RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&5N9$5L96UE;G0H
M)'5R:2P@)&5L96UE;G0I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?8W5R<F5N=%-Y;F-%;&5M96YT*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7V-U<G)E;G13>6YC16QE;65N="T^96YD16QE;65N="@D=7)I+"`D96QE;65N
M="D["B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*&-O=6YT*"1T:&ES+3Y?
M4W1A8VLI*2!["B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!I9B`H)&5L
M96UE;G0@/3T@)U)E<&QA8V4G('Q\("1E;&5M96YT(#T]("=!9&0G('Q\("1E
M;&5M96YT(#T]("=$96QE=&4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-Y;F-%;&5M96YT<UM=(#T@)'1H:7,M/E]C=7)R96YT4WEN8T5L96UE;G0[
M"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7V-U<G)E;G13>6YC16QE
M;65N="D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@(&-A<V4@,SH*("`@("`@("`@("`@:68@*"1E;&5M96YT(#T@)TQO8U52
M22<@)B8@(6ES<V5T*"1T:&ES+3Y?8W5R<F5N=%-Y;F-%;&5M96YT*2D@>PH@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?4W1A8VM;,5T@/3T@)U-O=7)C
M92<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-O=7)C955222`]
M('1R:6TH)'1H:7,M/E]C:&%R<RD["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]3=&%C:ULQ72`]/2`G5&%R9V5T)RD@>PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=&%R9V5T55))(#T@8F%S96YA;64H<')E9U]R
M97!L86-E*"<O7#\N*B0O)RP@)R<L('1R:6TH)'1H:7,M/E]C:&%R<RDI*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("!]"@H@("`@("`@('!A<F5N=#HZ96YD16QE;65N="@D
M=7)I+"`D96QE;65N="D["B`@("!]"@H@("`@9G5N8W1I;VX@8VAA<F%C=&5R
M<R@D<W1R*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-U<G)E
M;G13>6YC16QE;65N="DI('L*("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT
M4WEN8T5L96UE;G0M/F-H87)A8W1E<G,H)'-T<BD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA<G,I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V-H87)S(#T@)'1H:7,M/E]C:&%R<R`N
M("1S='(["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-H87)S(#T@)'-T<CL*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"GT*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN8TU,
M+T1E=FEC92]3>6YC-&HN<&AP````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P-30U-C,@,3`U,34T,S0Q,S8@,#(R-30W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TAO<F1E+VE#86QE;F1A<BYP:'`G.PH*+RHJ"B`J(%-Y;F,T:B`H=W=W
M+G-Y;F,T:BYO<F<I"B`J"B`J(%1H92!3>6YC-$H@;W5T;&]O:R!C;VYV97)T
M97(@=7-E<R!I=',@;F%T:79E(%-)1B!F;W)M870@9F]R(&1A=&$*("H@97AC
M:&%N9V4N($-O;G9E<G-I;VX@=&\@=&5X="]V8V%L96YD87(@971C+B!I<R!D
M;VYE(&)Y"B`J(%-I9D-O;G9E<G1E<BYP:'`@5&AE(&-O;FYE8W1O<B!S965M
M<R!N;W0@<W5P<&]R="!$979);F8*("H@:6YF;W)M871I;VXL('-O(%-Y;F--
M3%]$979I8V4@8V%N(&]N;'D@9&5T96-T(&ET(&)Y('1H92!D96-I8V4@240Z
M"B`J('-O(&EN('1H92!C;VYN96-T;W(@8V]N9FEG=7)A=&EO;B!T:&4@9&5V
M:6-E($E$(&UU<W0@8F4@<V5T('1O"B`J("=S8RUP:6TM/'1Y<&4^)R!W:&EC
M:"!S:&]U;&0@8F4@=&AE(&1E9F%U;'0@86YY:&]W+@H@*@H@*B!#;W!Y<FEG
M:'0@,C`P-2TR,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N
M;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN
M8TU,+U-Y;F--3"]$979I8V4O4WEN8S1J+G!H<"QV(#$N."XR+C0@,C`P-B\P
M,2\P,2`R,3HR.#HS-R!J86X@17AP("0*("H*("H@0&%U=&AO<B`@2V%R<W1E
M;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J($!P86-K86=E(%-Y
M;F--3`H@*B\*8VQA<W,@4WEN8TU,7T1E=FEC95]S>6YC-&H@97AT96YD<R!3
M>6YC34Q?1&5V:6-E('L*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&-O
M;G1E;G0N"B`@("`@*@H@("`@("H@0W5R<F5N=&QY('-T<FEP<R!U:60@*'!R
M:6UA<GD@:V5Y*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD"B`@("`@*B!S
M97)V97(@;6EG:'0@=7-E(&1I9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J
M($-H87)S970@8V]N=F5R<VEO;G,@;6EG:'0@8F4@861D960@:&5R92!T;V\N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1#;&EE;G0R4V5R=F5R*"1C
M;VYT96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@;&ES="@D8V]N
M=&5N="P@)&-O;G1E;G14>7!E*2`]"B`@("`@("`@("`@('!A<F5N=#HZ8V]N
M=F5R=$-L:65N=#)397)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D["@H@
M("`@("`@('-W:71C:"`H)&-O;G1E;G14>7!E*2!["B`@("`@("`@8V%S92`G
M<VEF+VYO=&4G(#H*("`@("`@("!C87-E("=T97AT+W@M<S1J+7-I9FXG(#H*
M("`@("`@("`@("`@)&-O;G1E;G0@/2`D=&AI<RT^<VEF,G9N;W1E*&)A<V4V
M-%]D96-O9&4H)&-O;G1E;G0I*3L*("`@("`@("`@("`@)&-O;G1E;G14>7!E
M(#T@)W1E>'0O>"UV;F]T92<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("!C87-E("=S:68O8V]N=&%C="<@.@H@("`@("`@(&-A<V4@)W1E>'0O>"US
M-&HM<VEF8R<@.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES+3YS:68R
M=F-A<F0H8F%S938T7V1E8V]D92@D8V]N=&5N="DI.PH@("`@("`@("`@("`D
M8V]N=&5N=%1Y<&4@/2`G=&5X="]X+79C87)D)SL*("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@(&-A<V4@)W-I9B]C86QE;F1A<B<@.@H@("`@("`@(&-A
M<V4@)W1E>'0O>"US-&HM<VEF92<@.@H@("`@("`@("`@("`D8V]N=&5N="`]
M("1T:&ES+3YS:68R=F5V96YT*&)A<V4V-%]D96-O9&4H)&-O;G1E;G0I*3L*
M("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@)W1E>'0O>"UV979E;G0G.PH@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G<VEF+W1A<VLG(#H*
M("`@("`@("!C87-E("=T97AT+W@M<S1J+7-I9G0G(#H*("`@("`@("`@("`@
M)&-O;G1E;G0@/2`D=&AI<RT^<VEF,G9T;V1O*&)A<V4V-%]D96-O9&4H)&-O
M;G1E;G0I*3L*("`@("`@("`@("`@)&-O;G1E;G14>7!E(#T@)W1E>'0O>"UV
M=&]D;R<["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@
M:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!5$$I('L*("`@("`@("`@("`@)&9P
M(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G+G1X="<L("=A)RD["B`@("`@("`@
M("`@(&EF("@D9G`I('L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"`B
M7&YI;G!U="!C;VYV97)T960@9F]R('-E<G9E<CH@)&-O;G1E;G14>7!E7&XB
M*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"1C;VYT96YT("X@(EQN
M(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N=&5N="P@
M)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G1S
M('1H92!C;VYT96YT(&9R;VT@=&AE(&)A8VME;F0@=&\@82!F;W)M870@<W5I
M=&%B;&4@9F]R('1H90H@("`@("H@8VQI96YT(&1E=FEC92X*("`@("`J"B`@
M("`@*B!3=')I<',@=&AE('5I9"`H<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N
M(&%S(&-L:65N="!A;F0@<V5R=F5R(&UI9VAT('5S90H@("`@("H@9&EF9F5R
M96YT(&]N97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N
M="`@("`@("!4:&4@8V]N=&5N="!T;R!C;VYV97)T"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C;VYT96YT5'EP92!O9B!C;VYT
M96YT(&%S(')E='5R;F5D(&9R;VT*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=&AE(&)A8VME;F0*("`@("`J($!R971U<FX@87)R87D@
M("`@("`@("`@("`@("`@87)R87DH)&YE=V-O;G1E;G0L("1N97=C;VYT96YT
M5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("AP;W-S:6)L>2!C:&%N9V5D*2!N97<@0V]N
M=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;G9E<G1397)V97(R
M0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I"B`@("!["B`@("`@("`@
M9VQO8F%L("1B86-K96YD.PH*("`@("`@("!L:7-T*"1C;VYT96YT+"`D8V]N
M=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R96YT.CIC;VYV97)T4V5R=F5R
M,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*"B`@("`@("`@<W=I
M=&-H("@D8V]N=&5N=%1Y<&4I('L*("`@("`@("!C87-E("=T97AT+V-A;&5N
M9&%R)R`Z"B`@("`@("`@8V%S92`G=&5X="]X+6EC86QE;F1A<B<@.@H@("`@
M("`@(&-A<V4@)W1E>'0O>"UV8V%L96YD87(G(#H*("`@("`@("!C87-E("=T
M97AT+W@M=F5V96YT)R`Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)'1H:7,M
M/G9E=F5N=#)S:68H)&-O;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N="`]
M(&)A<V4V-%]E;F-O9&4H)&-O;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N
M=%1Y<&4@/2`G<VEF+V-A;&5N9&%R)SL*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)W1E>'0O>"UV=&]D;R<@.@H@("`@("`@("`@("`D8V]N
M=&5N="`]("1T:&ES+3YV=&]D;S)S:68H)&-O;G1E;G0I.PH@("`@("`@("`@
M("`D8V]N=&5N="`](&)A<V4V-%]E;F-O9&4H)&-O;G1E;G0I.PH@("`@("`@
M("`@("`D8V]N=&5N=%1Y<&4@/2`G<VEF+W1A<VLG.PH@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@8V%S92`G=&5X="]X+79C87)D)R`Z"B`@("`@("`@
M("`@("1C;VYT96YT(#T@)'1H:7,M/G9C87)D,G-I9B@D8V]N=&5N="D["B`@
M("`@("`@("`@("1C;VYT96YT(#T@8F%S938T7V5N8V]D92@D8V]N=&5N="D[
M"B`@("`@("`@("`@("1C;VYT96YT5'EP92`]("=S:68O8V]N=&%C="<["B`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=T97AT+W@M=FYO=&4G
M.@H@("`@("`@("`@("`D8V]N=&5N="`]("1T:&ES+3YV;F]T93)S:68H)&-O
M;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N="`](&)A<V4V-%]E;F-O9&4H
M)&-O;G1E;G0I.PH@("`@("`@("`@("`D8V]N=&5N=%1Y<&4@/2`G<VEF+VYO
M=&4G.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@("`@("`@(&EF
M("A$14)51TQ/1U])0T%,14Y$05)$051!*2!["B`@("`@("`@("`@("1F<"`]
M($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G+"`G82<I.PH@("`@("`@("`@
M("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@("!`9G=R:71E*"1F<"P@<V5R
M:6%L:7IE*"1C;VYT96YT5'EP92DI.PH@("`@("`@("`@("`@("`@0&9W<FET
M92@D9G`L(")<;F-O;G9E<G1E9"!F;W(@<WEN8S1J(&-L:65N=#H@)&-O;G1E
M;G14>7!E7&XB*3L*("`@("`@("`@("`@("`@($!F=W)I=&4H)&9P+"!B87-E
M-C1?9&5C;V1E*"1C;VYT96YT*2`N(")<;B(I.PH@("`@("`@("`@("`@("`@
M0&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@87)R87DH)&-O;G1E;G0L("1C;VYT96YT5'EP92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!$96-O9&5S(&$@<VEF('AM;"!S=')I;F<@=&\@
M86X@87-S;V-I871I=F4@87)R87DN"B`@("`@*@H@("`@("H@475I8VL@:&%C
M:R!T;R!C;VYV97)T(&9R;VT@=&5X="]V8V%R9"!A;F0@=&5X="]V8V%L96YD
M87(@=&\*("`@("`J(%-Y;F,T2B=S('!R;W!R:65T97)Y('-I9B!D871A='EP
M97,@86YD('9I8V4@=F5R<V$N("!&;W(@9&5T86EL<PH@("`@("H@86)O=70@
M=&AE('-I9B!F;W)M870@<V5E('1H92!A<'!E;F1I>"!O9B!T:&4@9&5V96QO
M<&5R(&=U:61E(&]N"B`@("`@*B!W=W<N<WEN8S1J+F]R9RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1S:68@($$@<VEF('-T<FEN9R!L:6ME(#QK,3YV,29G=#L\+VLQ/CQK
M,CYV,CPO:S(^"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@07-S;V,@
M87)R87D@:6X@=71F."!L:6ME(&%R<F%Y("@G:S$G(#T^("=V,3XG+"`G:S(G
M(#T^("=V,B<I.PH@("`@("HO"B`@("!F=6YC=&EO;B!S:68R87)R87DH)'-I
M9BD*("`@('L*("`@("`@("`D<B`](&%R<F%Y*"D["B`@("`@("`@:68@*'!R
M96=?;6%T8VA?86QL*"<O/"A;7CY=*BD^*%M>/%TJ*3Q<+UPQ/B]S:2<L("1S
M:68L("1M871C:&5S+"!04D5'7U-%5%]/4D1%4BDI('L*("`@("`@("`@("`@
M9F]R96%C:"`H)&UA=&-H97,@87,@)&UA=&-H*2!["B`@("`@("`@("`@("`@
M("`D<ELD;6%T8VA;,5U=(#T@:'1M;%]E;G1I='E?9&5C;V1E*"1M871C:%LR
M72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M.PH@("`@?0H*("`@("\J*@H@("`@("H@16YC;V1E<R!A;B!A<W-O8RX@87)R
M87D@=&\@<VEF('AM;`H@("`@("H*("`@("`J(%%U:6-K(&AA8VL@=&\@8V]N
M=F5R="!F<F]M('1E>'0O=F-A<F0@86YD('1E>'0O=F-A;&5N9&%R('1O"B`@
M("`@*B!3>6YC-$HG<R!P<F]P<FEE=&5R>2!S:68@9&%T871Y<&5S(&%N9"!V
M:6-E('9E<G-A+B`@1F]R(&1E=&%I;',*("`@("`J(&%B;W5T('1H92!S:68@
M9F]R;6%T('-E92!T:&4@87!P96YD:7@@;V8@=&AE(&1E=F5L;W!E<B!G=6ED
M92!O;@H@("`@("H@=W=W+G-Y;F,T:BYO<F<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1A<G)A
M>2`@06X@87-S;V,@87)R87DN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I
M;F<@(%1H92!R97-U;'1I;F<@6$U,('-T<FEN9RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@87)R87DR<VEF*"1A<G)A>2P@)'!R93TG)RP@)'!O<W0])R<I"B`@
M("!["B`@("`@("`@)'-E87)C:"`](&%R<F%Y*"<\)RP@)SXG*3L*("`@("`@
M("`D<F5P;&%C92`](&%R<F%Y*"<F;'0[)RP@)R9G=#LG*3L*"B`@("`@("`@
M)'(@/2`D<')E.PH@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^
M("1V86QU92D@>PH@("`@("`@("`@("`D<B`N/2`G/"<@+B`D:V5Y("X@)SXG
M("X*("`@("`@("`@("`@("`@('-T<E]R97!L86-E*"1S96%R8V@L("1R97!L
M86-E+"`D=F%L=64I("X*("`@("`@("`@("`@("`@("<\+R<@+B`D:V5Y("X@
M)SXG.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R("X@)'!O<W0["B`@
M("!]"@H@("`@9G5N8W1I;VX@<VEF,G9N;W1E*"1S:68I"B`@("!["B`@("`@
M("`@)&$@/2`D=&AI<RT^<VEF,F%R<F%Y*"1S:68I.PH*("`@("`@("`D:4-A
M;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@("`@("`@)&E#86PM/G-E
M=$%T=')I8G5T92@G5D524TE/3B<L("<Q+C$G*3L*("`@("`@("`D:4-A;"T^
M<V5T071T<FEB=71E*"=04D]$240G+"`G+2\O5&AE($AO<F1E(%!R;VIE8W0O
M+TUN96UO("\O14XG*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=-
M151(3T0G+"`G4%5"3$E32"<I.PH*("`@("`@("`D=FYO=&4@/2`F2&]R9&5?
M:4-A;&5N9&%R.CIN97=#;VUP;VYE;G0H)W9N;W1E)RP@)&E#86PI.PH@("`@
M("`@("1V;F]T92T^<V5T071T<FEB=71E*"="3T19)RP@:7-S970H)&%;)T)O
M9'DG72D@/R`D85LG0F]D>2==(#H@)R<I.PH*("`@("`@("!R971U<FX@)'9N
M;W1E+3YE>'!O<G1V0V%L96YD87(H*3L*("`@('T*"B`@("!F=6YC=&EO;B!S
M:68R=F-A<F0H)'-I9BD*("`@('L*("`@("`@("`D82`]("1T:&ES+3YS:68R
M87)R87DH)'-I9BD["@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L
M96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=615)324].
M)RP@)S(N,2<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)U!23T1)
M1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C="\O36YE;6\@+R]%3B<I.PH@("`@
M("`@("1I0V%L+3YS971!='1R:6)U=&4H)TU%5$A/1"<L("=054),25-()RD[
M"@H@("`@("`@("1V8V%R9"`]("9(;W)D95]I0V%L96YD87(Z.FYE=T-O;7!O
M;F5N="@G=F-A<F0G+"`D:4-A;"D["@H@("`@("`@("1V8V%R9"T^<V5T071T
M<FEB=71E*"=&3B<L("1A6R=&:6QE07,G72D["B`@("`@("`@)'9C87)D+3YS
M971!='1R:6)U=&4H)TY)0TM.04U%)RP@)&%;)TYI8VM.86UE)UTI.PH@("`@
M("`@("1V8V%R9"T^<V5T071T<FEB=71E*"=414PG+"`D85LG2&]M951E;&5P
M:&]N94YU;6)E<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=465!%)ST^)TA/344G*2D["B`@("`@("`@)'9C87)D+3YS971!='1R
M:6)U=&4H)U1%3"<L("1A6R="=7-I;F5S<U1E;&5P:&]N94YU;6)E<B==+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=465!%)ST^)U=/
M4DLG*2D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)U1%3"<L("1A
M6R=-;V)I;&5496QE<&AO;F5.=6UB97(G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G5%E012<]/B=#14Q,)RDI.PH@("`@("`@("1V
M8V%R9"T^<V5T071T<FEB=71E*"=414PG+"`D85LG0G5S:6YE<W-&87A.=6UB
M97(G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G5%E0
M12<]/B=&05@G*2D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)T5-
M04E,)RP@)&%;)T5M86EL,4%D9')E<W,G72D["B`@("`@("`@)'9C87)D+3YS
M971!='1R:6)U=&4H)U1)5$Q%)RP@)&%;)TIO8E1I=&QE)UTI.PH@("`@("`@
M("1V8V%R9"T^<V5T071T<FEB=71E*"=/4D<G+"`D85LG0V]M<&%N>4YA;64G
M72D["B`@("`@("`@)'9C87)D+3YS971!='1R:6)U=&4H)TY/5$4G+"`D85LG
M0F]D>2==*3L*("`@("`@("`D=F-A<F0M/G-E=$%T=')I8G5T92@G55),)RP@
M)&%;)U=E8E!A9V4G72D["@H@("`@("`@("1V(#T@87)R87DH"B`@("`@("`@
M("`@(%9#05)$7TY?1D%-24Q9("`@("`@/3X@)&%;)TQA<W1.86UE)UTL"B`@
M("`@("`@("`@(%9#05)$7TY?1TE614X@("`@("`@/3X@)&%;)T9I<G-T3F%M
M92==+`H@("`@("`@("`@("!60T%21%].7T%$1$P@("`@("`@(#T^("1A6R=-
M:61D;&5.86UE)UTL"B`@("`@("`@("`@(%9#05)$7TY?4%)%1DE8("`@("`@
M/3X@)&%;)U1I=&QE)UTL"B`@("`@("`@("`@(%9#05)$7TY?4U5&1DE8("`@
M("`@/3X@)&%;)U-U9F9I>"=="B`@("`@("`@*3L*("`@("`@("`D=F-A<F0M
M/G-E=$%T=')I8G5T92@G3B<L(&EM<&QO9&4H)SLG+"`D=BDL(&%R<F%Y*"DL
M(&9A;'-E+"`D=BD["@H@("`@("`@("1V(#T@87)R87DH"B`@("`@("`@("`@
M(%9#05)$7T%$4E]03T(@("`@("`@("`@(#T^("1A6R=(;VUE061D<F5S<U!O
M<W1/9F9I8V5";W@G72P*("`@("`@("`@("`@5D-!4D1?04127T585$5.1"`@
M("`@("`@/3X@)R<L"B`@("`@("`@("`@(%9#05)$7T%$4E]35%)%150@("`@
M("`@(#T^("1A6R=(;VUE061D<F5S<U-T<F5E="==+`H@("`@("`@("`@("!6
M0T%21%]!1%)?3$]#04Q)5%D@("`@("`]/B`D85LG2&]M94%D9')E<W-#:71Y
M)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]214=)3TX@("`@("`@(#T^("1A
M6R=(;VUE061D<F5S<U-T871E)UTL"B`@("`@("`@("`@(%9#05)$7T%$4E]0
M3U-40T]$12`@("`@(#T^("1A6R=(;VUE061D<F5S<U!O<W1A;$-O9&4G72P*
M("`@("`@("`@("`@5D-!4D1?04127T-/54Y44ED@("`@("`@/3X@)&%;)TAO
M;65!9&1R97-S0V]U;G1R>2==+`H@("`@("`@("D["B`@("`@("`@)'9C87)D
M+3YS971!='1R:6)U=&4H)T%$4B<L(&EM<&QO9&4H)SLG+"`D=BDL(&%R<F%Y
M*"=465!%)R`]/B`G2$]-12<@*2P@=')U92P@)'8I.PH*("`@("`@("`D=B`]
M(&%R<F%Y*`H@("`@("`@("`@("!60T%21%]!1%)?4$]"("`@("`@("`@("`]
M/B`D85LG0G5S:6YE<W-!9&1R97-S4&]S=$]F9FEC94)O>"==+`H@("`@("`@
M("`@("!60T%21%]!1%)?15A414Y$("`@("`@("`]/B`G)RP*("`@("`@("`@
M("`@5D-!4D1?04127U-44D5%5"`@("`@("`@/3X@)&%;)T)U<VEN97-S061D
M<F5S<U-T<F5E="==+`H@("`@("`@("`@("!60T%21%]!1%)?3$]#04Q)5%D@
M("`@("`]/B`D85LG0G5S:6YE<W-!9&1R97-S0VET>2==+`H@("`@("`@("`@
M("!60T%21%]!1%)?4D5'24].("`@("`@("`]/B`D85LG0G5S:6YE<W-!9&1R
M97-S4W1A=&4G72P*("`@("`@("`@("`@5D-!4D1?04127U!/4U1#3T1%("`@
M("`@/3X@)&%;)T)U<VEN97-S061D<F5S<U!O<W1A;$-O9&4G72P*("`@("`@
M("`@("`@5D-!4D1?04127T-/54Y44ED@("`@("`@/3X@)&%;)T)U<VEN97-S
M061D<F5S<T-O=6YT<GDG72P*("`@("`@("`I.PH*("`@("`@("`D=F-A<F0M
M/G-E=$%T=')I8G5T92@G0412)RP@:6UP;&]D92@G.R<L("1V*2P@87)R87DH
M)U194$4G(#T^("=73U)+)R`I+"!T<G5E+"`D=BD["@H@("`@("`@(')E='5R
M;B`D=F-A<F0M/F5X<&]R='9#86QE;F1A<B@I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('-I9C)V979E;G0H)'-I9BD*("`@('L*("`@("`@("`D82`]("1T:&ES
M+3YS:68R87)R87DH)'-I9BD["@H@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D
M95]I0V%L96YD87(H*3L*("`@("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=6
M15)324].)RP@)S$N,"<I.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H
M)U!23T1)1"<L("<M+R]4:&4@2&]R9&4@4')O:F5C="\O36YE;6\@+R]%3B<I
M.PH@("`@("`@("1I0V%L+3YS971!='1R:6)U=&4H)TU%5$A/1"<L("=054),
M25-()RD["@H@("`@("`@("1V179E;G0@/2`F2&]R9&5?:4-A;&5N9&%R.CIN
M97=#;VUP;VYE;G0H)W9E=F5N="<L("1I0V%L*3L*"B`@("`@("`@:68@*"1A
M6R=!;&Q$87E%=F5N="==(#T]("=4<G5E)RD@>PH@("`@("`@("`@("`D="`]
M("1I0V%L+3Y?<&%R<V5$871E5&EM92@D85LG4W1A<G0G72D["B`@("`@("`@
M("`@("1V179E;G0M/G-E=$%T=')I8G5T92@G1%135$%25"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G>65A<B<@/3X@9&%T
M92@G62<L("1T*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=M;VYT:"<@/3X@9&%T92@G;2<L("1T*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B!D871E*"=D
M)RPD="DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)U9!3%5%)R`]/B`G1$%412<I*3L*("`@("`@("`@("`@)'0@/2`D:4-A
M;"T^7W!A<G-E1&%T951I;64H)&%;)T5N9"==*3L*("`@("`@("`@("`@)'9%
M=F5N="T^<V5T071T<FEB=71E*"=$5$5.1"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G>65A<B<@/3X@9&%T92@G62<L("1T
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=M
M;VYT:"<@/3X@9&%T92@G;2<L("1T*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=M9&%Y)R`]/B!D871E*"=D)RPD="DI+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)U9!3%5%
M)R`]/B`G1$%412<I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=D5V96YT+3YS971!='1R:6)U=&4H)T144U1!4E0G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&E#86PM/E]P87)S941A=&54:6UE*"1A
M6R=3=&%R="==*2D["B`@("`@("`@("`@("1V179E;G0M/G-E=$%T=')I8G5T
M92@G1%1%3D0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&E#86PM/E]P87)S941A=&54:6UE*"1A6R=%;F0G72DI.PH@("`@("`@('T*
M"B`@("`@("`@)'9%=F5N="T^<V5T071T<FEB=71E*"=$5%-404U0)RP@=&EM
M92@I*3L*("`@("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)U-534U!4EDG
M+"`D85LG4W5B:F5C="==*3L*("`@("`@("`D=D5V96YT+3YS971!='1R:6)U
M=&4H)T1%4T-225!424].)RP@)&%;)T)O9'DG72D["B`@("`@("`@+R\@)'9%
M=F5N="T^<V5T071T<FEB=71E*"=#051%1T]22453)RP@)&%;)R==*3L*("`@
M("`@("`D=D5V96YT+3YS971!='1R:6)U=&4H)TQ/0T%424].)RP@)&%;)TQO
M8V%T:6]N)UTI.PH*("`@("`@("!R971U<FX@)'9%=F5N="T^97AP;W)T=D-A
M;&5N9&%R*"D["B`@("!]"@H@("`@9G5N8W1I;VX@<VEF,G9T;V1O*"1S:68I
M"B`@("!["B`@("`@("`@)&$@/2`D=&AI<RT^<VEF,F%R<F%Y*"1S:68I.PH*
M("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A;&5N9&%R*"D["B`@("`@
M("`@)&E#86PM/G-E=$%T=')I8G5T92@G5D524TE/3B<L("<Q+C`G*3L*("`@
M("`@("`D:4-A;"T^<V5T071T<FEB=71E*"=04D]$240G+"`G+2\O5&AE($AO
M<F1E(%!R;VIE8W0O+TUN96UO("\O14XG*3L*("`@("`@("`D:4-A;"T^<V5T
M071T<FEB=71E*"=-151(3T0G+"`G4%5"3$E32"<I.PH*("`@("`@("`D=G1O
M9&\@/2`F2&]R9&5?:4-A;&5N9&%R.CIN97=#;VUP;VYE;G0H)W9T;V1O)RP@
M)&E#86PI.PH*("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G4U5-34%2
M62<L("1A6R=3=6)J96-T)UTI.PH@("`@("`@("1V=&]D;RT^<V5T071T<FEB
M=71E*"=$15-#4DE05$E/3B<L("1A6R=";V1Y)UTI.PH@("`@("`@(&EF("@D
M85LG26UP;W)T86YC92==(#T](#`I('L*("`@("`@("`@("`@)'9T;V1O+3YS
M971!='1R:6)U=&4H)U!224]22519)RP@-2D["B`@("`@("`@?2!E;'-E:68@
M*"1A6R=);7!O<G1A;F-E)UT@/3T@,BD@>PH@("`@("`@("`@("`D=G1O9&\M
M/G-E=$%T=')I8G5T92@G4%))3U))5%DG+"`Q*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=G1O9&\M/G-E=$%T=')I8G5T92@G4%))3U))5%DG
M+"`S*3L*("`@("`@("!]"B`@("`@("`@:68@*"1A6R=$=65$871E)UT@(3T@
M)S0U,#`Q,C,Q5#(S,#`P,%HG*2!["B`@("`@("`@("`@("1V=&]D;RT^<V5T
M071T<FEB=71E*"=$544G+"`D:4-A;"T^7W!A<G-E1&%T951I;64H)&%;)T1U
M941A=&4G72DI.PH@("`@("`@('T*("`@("`@("`D=G1O9&\M/G-E=$%T=')I
M8G5T92@G0T]-4$Q%5$5$)RP@)&%;)T-O;7!L971E)UT@/3T@)U1R=64G(#\@
M,2`Z(#`I.PH*("`@("`@("!R971U<FX@)'9T;V1O+3YE>'!O<G1V0V%L96YD
M87(H*3L*("`@('T*"B`@("!F=6YC=&EO;B!V;F]T93)S:68H)'9N;W1E*0H@
M("`@>PH@("`@("`@("1I0V%L(#T@)FYE=R!(;W)D95]I0V%L96YD87(H*3L*
M("`@("`@("!I9B`H(21I0V%L+3YP87)S979#86QE;F1A<B@D=FYO=&4I*2![
M"B`@("`@("`@("`@(&1I92@B5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN
M9R!T:&4@9&%T82XB*3L*("`@("`@("!]"@H@("`@("`@("1C;VUP;VYE;G1S
M(#T@)&E#86PM/F=E=$-O;7!O;F5N=',H*3L*"B`@("`@("`@<W=I=&-H("AC
M;W5N="@D8V]M<&]N96YT<RDI('L*("`@("`@("!C87-E(#`Z"B`@("`@("`@
M("`@(&1I92@B3F\@9&%T82!W87,@9F]U;F0N(BD["@H@("`@("`@(&-A<V4@
M,3H*("`@("`@("`@("`@)&-O;G1E;G0@/2`D8V]M<&]N96YT<ULP73L*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M(&1I92@B375L=&EP;&4@8V]M<&]N96YT<R!F;W5N9#L@;VYL>2!O;F4@:7,@
M<W5P<&]R=&5D+B(I.PH@("`@("`@('T*"B`@("`@("`@)&$@/2!A<G)A>2@G
M0F]D>2<@/3X@)&-O;G1E;G0M/F=E=$%T=')I8G5T92@G0D]$62<I*3L*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YA<G)A>3)S:68H"B`@("`@("`@("`@("1A
M+`H@("`@("`@("`@("`G/#]X;6P@=F5R<VEO;CTB,2XP(C\^/&YO=&4^)RP*
M("`@("`@("`@("`@)SQ#871E9V]R:65S/CPO0V%T96=O<FEE<SXG"B`@("`@
M("`@("`@("X@)SQ3=6)J96-T/CPO4W5B:F5C=#X\0V]L;W(^/"]#;VQO<CX\
M2&5I9VAT/CPO2&5I9VAT/CQ7:61T:#X\+U=I9'1H/CQ,969T/CPO3&5F=#X\
M5&]P/CPO5&]P/B<*("`@("`@("`@("`@+B`G/"]N;W1E/B<I.PH@("`@?0H*
M("`@(&9U;F-T:6]N('9C87)D,G-I9B@D=F-A<F0I"B`@("!["B`@("`@("`@
M)&E#86P@/2`F;F5W($AO<F1E7VE#86QE;F1A<B@I.PH@("`@("`@(&EF("@A
M)&E#86PM/G!A<G-E=D-A;&5N9&%R*"1V8V%R9"DI('L*("`@("`@("`@("`@
M9&EE*")4:&5R92!W87,@86X@97)R;W(@:6UP;W)T:6YG('1H92!D871A+B(I
M.PH@("`@("`@('T*"B`@("`@("`@)&-O;7!O;F5N=',@/2`D:4-A;"T^9V5T
M0V]M<&]N96YT<R@I.PH*("`@("`@("!S=VET8V@@*&-O=6YT*"1C;VUP;VYE
M;G1S*2D@>PH@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@9&EE*").;R!D
M871A('=A<R!F;W5N9"XB*3L*"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@
M("`D8V]N=&5N="`]("1C;VUP;VYE;G1S6S!=.PH@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@9&EE*")-=6QT:7!L
M92!C;VUP;VYE;G1S(&9O=6YD.R!O;FQY(&]N92!I<R!S=7!P;W)T960N(BD[
M"B`@("`@("`@?0H*("`@("`@("`O+R!F<F]M(&AE<F4@;VXL('1H92!C;V1E
M(&ES('1A:V5N(&9R;VT*("`@("`@("`O+R!4=7)B85]$<FEV97(Z.G1O2&%S
M:"P@=B`Q+C8U(#(P,#4O,#,O,3(*("`@("`@("`O+R!A;F0@;6]D:69I960@
M9F]R('1H92!3>6YC-$H@871T<FEB=71E(&YA;65S+@H@("`@("`@("1A='1R
M(#T@)&-O;G1E;G0M/F=E=$%L;$%T=')I8G5T97,H*3L*("`@("`@("!F;W)E
M86-H("@D871T<B!A<R`D:71E;2D@>PH@("`@("`@("`@("!S=VET8V@@*"1I
M=&5M6R=N86UE)UTI('L*("`@("`@("`@("`@8V%S92`G1DXG.@H@("`@("`@
M("`@("`@("`@)&AA<VA;)T9I;&5!<R==(#T@)&ET96U;)W9A;'5E)UT["B`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)TXG.@H@
M("`@("`@("`@("`@("`@)&YA;64@/2`D:71E;5LG=F%L=65S)UT["B`@("`@
M("`@("`@("`@("`D:&%S:%LG3&%S=$YA;64G72`]("1N86UE6U9#05)$7TY?
M1D%-24Q973L*("`@("`@("`@("`@("`@("1H87-H6R=&:7)S=$YA;64G72`]
M("1N86UE6U9#05)$7TY?1TE614Y=.PH@("`@("`@("`@("`@("`@)&AA<VA;
M)TUI9&1L94YA;64G72`]("1N86UE6U9#05)$7TY?041$3%T["B`@("`@("`@
M("`@("`@("`D:&%S:%LG5&ET;&4G72`]("1N86UE6U9#05)$7TY?4%)%1DE8
M73L*("`@("`@("`@("`@("`@("1H87-H6R=3=69F:7@G72`]("1N86UE6U9#
M05)$7TY?4U5&1DE873L*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G3DE#2TY!344G.@H@("`@("`@("`@("`@("`@)&AA<VA;
M)TYI8VM.86UE)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@+R\@1F]R('9#87)D(#,N,"X*("`@("`@
M("`@("`@8V%S92`G0412)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M:71E;5LG<&%R86US)UU;)U194$4G72DI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1I=&5M6R=P87)A;7,G75LG5%E012==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:71E;5LG<&%R86US)UU;)U194$4G
M72`](&%R<F%Y*"1I=&5M6R=P87)A;7,G75LG5%E012==*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1I=&5M6R=P87)A;7,G75LG5%E012==(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M
M<R==6R=73U)+)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M
M6R=P87)A;7,G75LG5%E012==6UT@/2`G5T]22R<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:71E;5LG
M<&%R86US)UU;)TA/344G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&ET96U;)W!A<F%M<R==6R=465!%)UU;72`]("=(3TU%)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@)&%D9')E<W,@/2`D:71E;5LG=F%L=65S)UT["B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D:71E;5LG<&%R86US)UU;)U194$4G72!A<R`D861R*2![
M"B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("A3=')I;F<Z.G5P<&5R*"1A
M9'(I*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92`G2$]-12<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1P<F5F:7@@/2`G2&]M94%D9')E<W,G.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G5T]22R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1P
M<F5F:7@@/2`G5V]R:T%D9')E<W,G.PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!R969I>"`]("=(;VUE061D<F5S<R<["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H
M)'!R969I>"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD<')E
M9FEX("X@)U-T<F5E="==(#T@:7-S970H)&%D9')E<W-;5D-!4D1?04127U-4
M4D5%5%TI(#\@)&%D9')E<W-;5D-!4D1?04127U-44D5%5%T@.B!N=6QL.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD<')E9FEX("X@)T-I='DG
M72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$4E],3T-!3$E465TI(#\@)&%D
M9')E<W-;5D-!4D1?04127TQ/0T%,251972`Z(&YU;&P["B`@("`@("`@("`@
M("`@("`@("`@("`@("1H87-H6R1P<F5F:7@@+B`G4W1A=&4G72`](&ES<V5T
M*"1A9&1R97-S6U9#05)$7T%$4E]214=)3TY=*2`_("1A9&1R97-S6U9#05)$
M7T%$4E]214=)3TY=(#H@;G5L;#L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&AA<VA;)'!R969I>"`N("=0;W-T86Q#;V1E)UT@/2!I<W-E="@D861D<F5S
M<UM60T%21%]!1%)?4$]35$-/1$5=*2`_("1A9&1R97-S6U9#05)$7T%$4E]0
M3U-40T]$15T@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S
M:%LD<')E9FEX("X@)T-O=6YT<GDG72`](&ES<V5T*"1A9&1R97-S6U9#05)$
M7T%$4E]#3U5.5%)972D@/R`D861D<F5S<UM60T%21%]!1%)?0T]53E1265T@
M.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LD<')E9FEX
M("X@)U!O<W1/9F9I8V5";W@G72`](&ES<V5T*"1A9&1R97-S6U9#05)$7T%$
M4E]03T)=*2`_("1A9&1R97-S6U9#05)$7T%$4E]03T)=(#H@;G5L;#L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U1%3"<Z"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&ET96U;)W!A<F%M<R==6R=&05@G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG0G5S:6YE<W-&87A.=6UB
M97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1I=&5M6R=P87)A;7,G75LG5%E012==*2D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&ET96U;)W!A<F%M<R==6R=4
M65!%)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I=&5M6R=P87)A
M;7,G75LG5%E012==(#T@87)R87DH)&ET96U;)W!A<F%M<R==6R=465!%)UTI
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O
M+R!&;W(@=D-A<F0@,RXP+@H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1I=&5M6R=P87)A;7,G75LG5%E012==(&%S("1T96PI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*%-T<FEN9SHZ=7!P97(H)'1E;"D@/3T@)U=/
M4DLG*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:&%S:%LG0G5S
M:6YE<W-496QE<&AO;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H4W1R:6YG.CIU<'!E<B@D
M=&5L*2`]/2`G2$]-12<I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1H87-H6R=(;VUE5&5L97!H;VYE3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G
M73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*%-T<FEN9SHZ
M=7!P97(H)'1E;"D@/3T@)T-%3$PG*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG36]B:6QE5&5L97!H;VYE3G5M8F5R)UT@/2`D:71E
M;5LG=F%L=64G73L*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*%-T<FEN9SHZ=7!P97(H)'1E;"D@/3T@)T9!6"<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1H87-H6R="=7-I;F5S<T9A>$YU;6)E<B==(#T@
M)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:71E;5LG<&%R86US)UU;
M)TA/344G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)TAO
M;65496QE<&AO;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D:71E;5LG<&%R86US)UU;
M)U=/4DLG72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T)U
M<VEN97-S5&5L97!H;VYE3G5M8F5R)UT@/2`D:71E;5LG=F%L=64G73L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)&ET96U;)W!A<F%M
M<R==6R=#14Q,)UTI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1H87-H
M6R=-;V)I;&5496QE<&AO;F5.=6UB97(G72`]("1I=&5M6R=V86QU92==.PH@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1H87-H6R=(;VUE5&5L97!H;VYE3G5M8F5R)UT@/2`D:71E;5LG
M=F%L=64G73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)T5-04E,)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:71E;5LG<&%R
M86US)UU;)U!2148G72D@?'P@(6ES<V5T*"1H87-H6R=E;6%I;"==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1H87-H6R=%;6%I;#%!9&1R97-S)UT@/2!(
M;W)D95]I0V%L96YD87)?=F-A<F0Z.F=E=$)A<F5%;6%I;"@D:71E;5LG=F%L
M=64G72D["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;)T5M86EL,4%D9')E
M<W-4>7!E)UT@/2`G4TU44"<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U1)5$Q%)SH*("`@
M("`@("`@("`@("`@("1H87-H6R=*;V)4:71L92==(#T@)&ET96U;)W9A;'5E
M)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)T]21R<Z"B`@("`@("`@("`@("`@("`D:&%S:%LG0V]M<&%N>4YA;64G72`]
M("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!C87-E("=.3U1%)SH*("`@("`@("`@("`@("`@("1H87-H6R="
M;V1Y)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@8V%S92`G55),)SH*("`@("`@("`@("`@("`@("1H
M87-H6R=796)086=E)UT@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'1H:7,M/F%R<F%Y,G-I9B@*("`@("`@("`@("`@)&AA<V@L"B`@
M("`@("`@("`@("<\/WAM;"!V97)S:6]N/2(Q+C`B/SX\8V]N=&%C=#XG+`H@
M("`@("`@("`@("`G/"]C;VYT86-T/B<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('9E=F5N=#)S:68H)'9C87)D*0H@("`@>PH@("`@("`@("1I0V%L(#T@)FYE
M=R!(;W)D95]I0V%L96YD87(H*3L*("`@("`@("!I9B`H(21I0V%L+3YP87)S
M979#86QE;F1A<B@D=F-A<F0I*2!["B`@("`@("`@("`@(&1I92@B5&AE<F4@
M=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T82XB*3L*("`@("`@("!]
M"@H@("`@("`@("1C;VUP;VYE;G1S(#T@)&E#86PM/F=E=$-O;7!O;F5N=',H
M*3L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D8V]M<&]N96YT<RDI('L*("`@
M("`@("!C87-E(#`Z"B`@("`@("`@("`@(&1I92@B3F\@9&%T82!W87,@9F]U
M;F0N(BD["@H@("`@("`@(&-A<V4@,3H*("`@("`@("`@("`@)&-O;G1E;G0@
M/2`D8V]M<&]N96YT<ULP73L*("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@(&1I92@B375L=&EP;&4@8V]M<&]N96YT
M<R!F;W5N9#L@;VYL>2!O;F4@:7,@<W5P<&]R=&5D+B(I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@27,@=&AE<F4@82!R96%L(&YE960@=&\@<')O=FED92!T
M:&4@8V]R<F5C="!V86QU93\*("`@("`@("`D9'5R871I;VX@/2`P.PH*("`@
M("`@("`D871T<B`]("1C;VYT96YT+3YG971!;&Q!='1R:6)U=&5S*"D["B`@
M("`@("`@9F]R96%C:"`H)&%T='(@87,@)&ET96TI('L*("`@("`@("`@("`@
M<W=I=&-H("@D:71E;5LG;F%M92==*2!["B`@("`@("`@("`@(&-A<V4@)T14
M4U1!4E0G.@H@("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D:71E;5LG<&%R
M86US)UU;)U9!3%5%)UTI("8F("1I=&5M6R=P87)A;7,G75LG5D%,544G72`]
M/2`B1$%412(I('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG06QL1&%Y
M179E;G0G72`](")4<G5E(CL*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG
M4W1A<G0G72`]($AO<F1E7VE#86QE;F1A<CHZ7V5X<&]R=$1A=&54:6UE*"1I
M=&5M6R=V86QU92==*3L*("`@("`@("`@("`@("`@("`@("`D9'5R871I;VX@
M/2`Q-#0P.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D:&%S:%LG06QL1&%Y179E;G0G72`](")&86QS92(["B`@("`@
M("`@("`@("`@("`@("`@)&AA<VA;)U-T87)T)UT@/2!(;W)D95]I0V%L96YD
M87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L=64G72D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)T1414Y$)SH*("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&ET
M96U;)W!A<F%M<R==6R=604Q512==*2`F)B`D:71E;5LG<&%R86US)UU;)U9!
M3%5%)UT@/3T@(D1!5$4B*2!["B`@("`@("`@("`@("`@("`@("`@)&AA<VA;
M)T%L;$1A>45V96YT)UT@/2`B5')U92(["B`@("`@("`@("`@("`@("`@("`@
M)&AA<VA;)T5N9"==(#T@2&]R9&5?:4-A;&5N9&%R.CI?97AP;W)T1&%T951I
M;64H)&ET96U;)W9A;'5E)UTI.PH@("`@("`@("`@("`@("`@("`@("1D=7)A
M=&EO;B`](#$T-#`["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("1H87-H6R=!;&Q$87E%=F5N="==(#T@(D9A;'-E(CL*
M("`@("`@("`@("`@("`@("`@("`D:&%S:%LG16YD)UT@/2!(;W)D95]I0V%L
M96YD87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L=64G72D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)U-534U!4EDG.@H@("`@("`@("`@("`@("`@)&AA<VA;)U-U
M8FIE8W0G72`]("1I=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("!C87-E("=$15-#4DE05$E/3B<Z"B`@("`@("`@
M("`@("`@("`D:&%S:%LG0F]D>2==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)TQ/0T%424].
M)SH*("`@("`@("`@("`@("`@("1H87-H6R=,;V-A=&EO;B==(#T@)&ET96U;
M)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YA<G)A>3)S:68H
M"B`@("`@("`@("`@("1H87-H+`H@("`@("`@("`@("`G/#]X;6P@=F5R<VEO
M;CTB,2XP(C\^/&%P<&]I;G1M96YT/CQ$=7)A=&EO;CXG"B`@("`@("`@("`@
M("X@)&1U<F%T:6]N("X@)SPO1'5R871I;VX^)RP*("`@("`@("`@("`@)SQ)
M<U)E8W5R<FEN9SY&86QS93PO27-296-U<G)I;F<^/$UE971I;F=3=&%T=7,^
M,#PO365E=&EN9U-T871U<SX\0G5S>5-T871U<SXR/"]"=7-Y4W1A='5S/CPO
M87!P;VEN=&UE;G0^)RD["B`@("!]"@H@("`@9G5N8W1I;VX@=G1O9&\R<VEF
M*"1V8V%R9"D*("`@('L*("`@("`@("`D:4-A;"`]("9N97<@2&]R9&5?:4-A
M;&5N9&%R*"D["B`@("`@("`@:68@*"$D:4-A;"T^<&%R<V5V0V%L96YD87(H
M)'9C87)D*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G5&AE<F4@=V%S(&%N(&5R<F]R(&EM<&]R=&EN9R!T:&4@9&%T82XG*3L*
M("`@("`@("!]"@H@("`@("`@("1C;VUP;VYE;G1S(#T@)&E#86PM/F=E=$-O
M;7!O;F5N=',H*3L*"B`@("`@("`@<W=I=&-H("AC;W5N="@D8V]M<&]N96YT
M<RDI('L*("`@("`@("!C87-E(#`Z"B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*"=.;R!D871A('=A<R!F;W5N9"<I.PH*("`@("`@("!C
M87-E(#$Z"B`@("`@("`@("`@("1C;VYT96YT(#T@)&-O;7!O;F5N='-;,%T[
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!D969A=6QT.@H@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G375L=&EP;&4@8V]M<&]N
M96YT<R!F;W5N9#L@;VYL>2!O;F4@:7,@<W5P<&]R=&5D+B<I.PH@("`@("`@
M('T*"B`@("`@("`@)&AA<VA;)T-O;7!L971E)UT@/2`G1F%L<V4G.PH@("`@
M("`@("\O($]U=&QO;VLG<R!D969A=6QT(&9O<B!N;R!D=64@9&%T90H@("`@
M("`@("1H87-H6R=$=65$871E)UT@/2`G-#4P,#$R,S%4,C,P,#`P6B<["@H@
M("`@("`@("1A='1R(#T@)&-O;G1E;G0M/F=E=$%L;$%T=')I8G5T97,H*3L*
M("`@("`@("!F;W)E86-H("@D871T<B!A<R`D:71E;2D@>PH@("`@("`@("`@
M("!S=VET8V@@*"1I=&5M6R=N86UE)UTI('L*("`@("`@("`@("`@8V%S92`G
M1%5%)SH*("`@("`@("`@("`@("`@("1H87-H6R=$=65$871E)UT@/2!(;W)D
M95]I0V%L96YD87(Z.E]E>'!O<G1$871E5&EM92@D:71E;5LG=F%L=64G72D[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U-5
M34U!4EDG.@H@("`@("`@("`@("`@("`@)&AA<VA;)U-U8FIE8W0G72`]("1I
M=&5M6R=V86QU92==.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@
M("`@("!C87-E("=$15-#4DE05$E/3B<Z"B`@("`@("`@("`@("`@("`D:&%S
M:%LG0F]D>2==(#T@)&ET96U;)W9A;'5E)UT["B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)U!224]22519)SH*("`@("`@("`@
M("`@("`@(&EF("@D:71E;5LG=F%L=64G72`]/2`Q*2!["B`@("`@("`@("`@
M("`@("`@("`@)&AA<VA;)TEM<&]R=&%N8V4G72`](#(["B`@("`@("`@("`@
M("`@("!](&5L<V5I9B`H)&ET96U;)W9A;'5E)UT@/3T@-2D@>PH@("`@("`@
M("`@("`@("`@("`@("1H87-H6R=);7!O<G1A;F-E)UT@/2`P.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D:&%S:%LG
M26UP;W)T86YC92==(#T@,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G0T]-4$Q%5$5$)SH*
M("`@("`@("`@("`@("`@("1H87-H6R=#;VUP;&5T92==(#T@)&ET96U;)W9A
M;'5E)UT@/R`G5')U92<@.B`G1F%L<V4G.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^87)R87DR<VEF*`H@("`@("`@("`@("`D:&%S:"P*("`@("`@("`@
M("`@)SP_>&UL('9E<G-I;VX](C$N,"(_/CQT87-K/B<L"B`@("`@("`@("`@
M("<\+W1A<VL^)RD["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+VQI8B]3>6YC34PO1&5V:6-E+U`X,#`N<&AP````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S0U,B`Q,#4Q-30S-#$S-B`P,C(P
M,30`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J(%`X,#`O4#DP,"]0.3$P.@H@*B`M+2TM+2TM+2TM+2TM
M+2T*("H@0VAA<G-E=#H*("H@5&AI<R!D979I8V4@:7,@86)L92!T;R!H86YD
M;&4@551&+3@@86YD('-E;F1S(&ET<R!834P@<&%C:V%G97,@:6X@551&."X*
M("H@2&]W979E<B!E=F5N('1H;W5G:"!T:&4@6$U,(&ET<V5L9B!I<R!55$8M
M."P@:70@97AP96-T<R!T:&4@96YC;&]S960*("H@=F-A<F0M9&%T82!T;R!B
M92!)4T\M.#@U.2TQ('5N;&5S<R!E>'!L:6-I=&QY('-T871E9"!O=&AE<G=I
M<V4@*'5S:6YG('1H90H@*B!#2$%24T54(&]P=&EO;BP@=VAI8V@@:7,@9&5P
M<F5C871E9"!F;W(@5D-!4D0@,RXP*0H@*@H@*B!%;F-O9&EN9SH*("H@4W1R
M:6YG('9A;'5E<R!A<F4@96YC;V1E9"`B455/5$5$+5!224Y404),12(*("H*
M("H@3W1H97(Z"B`J(%1H:7,@9&5V:6-E<R!H86YD;&5S('1A<VMS(&%N9"!E
M=F5N=',@:6X@;VYE(&1A=&%B87-E+@H@*@H@*B!!<R!T:&4@4#@P,"!W87,@
M=&AE(&9I<G-T(&1E=FEC92!T;R!W;W)K('=I=&@@<&%C:V%G92P@;6]S="!O
M9B!T:&4*("H@<F5Q=6ER960@8V]N=F5R<VEO;G,@87)E(&EN($1E=FEC92YP
M:'`G<R!D969A=6QT(&AA;F1L:6YG+@H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR
M,#`V($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("H*("H@)$AO<F1E.B!F<F%M97=O<FLO4WEN8TU,+U-Y;F--
M3"]$979I8V4O4#@P,"YP:'`L=B`Q+C<N,BXU(#(P,#8O,#4O,#$@,3(Z,#4Z
M,30@:F%N($5X<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@
M/&MA<G-T96Y`:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L
M87-S(%-Y;F--3%]$979I8V5?4#@P,"!E>'1E;F1S(%-Y;F--3%]$979I8V4@
M>PH*("`@("\J*@H@("`@("H@0V]N=F5R="!T:&4@8V]N=&5N="X*("`@("`J
M"B`@("`@*B!#=7)R96YT;'D@<W1R:7!S('5I9"`H<')I;6%R>2!K97DI(&EN
M9F]R;6%T:6]N(&%S(&-L:65N="!A;F0*("`@("`J('-E<G9E<B!M:6=H="!U
M<V4@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T;R!C;VYV97)T+@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@("!4:&4@8V]N=&5N=%1Y
M<&4@;V8@=&AE(&-O;G1E;G0N"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@
M("`@("`@("`@(&%R<F%Y*"1N97=C;VYT96YT+"`D;F5W8V]N=&5N=%1Y<&4I
M.@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@8V]N
M=F5R=&5D(&-O;G1E;G0@86YD('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`H<&]S<VEB;'D@8VAA;F=E9"D@;F5W($-O;G1E;G14
M>7!E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYV97)T0VQI96YT,E-E<G9E
M<B@D8V]N=&5N="P@)&-O;G1E;G14>7!E*0H@("`@>PH@("`@("`@(&QI<W0H
M)&-O;G1E;G0L("1C;VYT96YT5'EP92D@/0H@("`@("`@("`@("!P87)E;G0Z
M.F-O;G9E<G1#;&EE;G0R4V5R=F5R*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I
M.PH*("`@("`@("`O*B!0.#`P('-E;F1S(&-A=&5G;W)I97,@87,@(E@M0V%T
M96=O<GDB+B!296UO=F4@=&AE(")8+2(Z("HO"B`@("`@("`@)&-O;G1E;G0@
M/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE#051%1T]22453.E@M+R<L
M("=<,4-!5$5'3U))15,Z)RP@)&-O;G1E;G0L(#$I.PH*("`@("`@("`O*B!0
M.#`P('-E;F1S(&%L;"!D87D@979E;G1S(&%S(',N=&@N(&QI:V4*("`@("`@
M("`@*B!$5%-405)4.C(P,#4P-3`U5#`P,#`P,%I>30H@("`@("`@("`J($14
M14Y$.C(P,#4P-3`U5#(T,#`P,%I>30H@("`@("`@("`J(%1H:7,@:7,@;F\@
M;&]N9V5R(&%N(&%L;"!D87D@979E;G0@=VAE;B!C;VYV97)T960@=&\@;&]C
M86P@=&EM97IO;F4N"B`@("`@("`@("H@4V\@;6%N=6%L;'D@:&%N9&QE('1H
M:7,N"B`@("`@("`@("H@*B\*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA<
M<EQN?%QR?%QN*4144U1!4E0Z+BI4,#`P,#`P6BA<<EQN?%QR?%QN*2\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT*0H@("`@("`@("`@("`F
M)B!P<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI1%1%3D0Z*%QD7&1<9%QD*2A<
M9%QD*2A<9%QD*50R-#`P,#!:*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;G1E;G0L("1M*2D@>PH@("`@("`@("`@("`D
M8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*4144U1!4E0Z
M*"XJ*50P,#`P,#!:*%QR7&Y\7')\7&XI+R<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("(D,4144U1!4E0[5D%,544]1$%413HD,B0S
M(BP@)&-O;G1E;G0I.PH@("`@("`@("`@("`O*B!%;F0@=&EM97-T86UP(&UU
M<W0@8F4@8V]N=F5R=&5D('1O(&YE>'0@9&%Y)W,@9&%T92X@*B\*("`@("`@
M("`@("`@)',@/2!D871E*"=9;60G+"!M:W1I;64H,"P@,"P@,"P@)&U;,UTL
M("1M6S1=+"`D;5LR72D@*R`R-"HS-C`P*3L*("`@("`@("`@("`@)&-O;G1E
M;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE$5$5.1#HH+BHI5#(T
M,#`P,%HH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(B0Q1%1%3D0[5D%,544]1$%413HD<R0S(BP@)&-O;G1E
M;G0I.PH@("`@("`@('T*"B`@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!
M4D1!5$$I('L*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O
M;&]G+G1X="<L("=A)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@
M("`@("`@("`@($!F=W)I=&4H)&9P+"`B7&YI;G!U="!C;VYV97)T960@9F]R
M('-E<G9E<CH@)&-O;G1E;G14>7!E7&XB*3L*("`@("`@("`@("`@("`@($!F
M=W)I=&4H)&9P+"1C;VYT96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`
M9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H92!C;VYT96YT(&9R;VT@=&AE
M(&)A8VME;F0@=&\@82!F;W)M870@<W5I=&%B;&4@9F]R('1H90H@("`@("H@
M8VQI96YT(&1E=FEC92X*("`@("`J"B`@("`@*B!3=')I<',@=&AE('5I9"`H
M<')I;6%R>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N="!A;F0@<V5R=F5R
M(&UI9VAT('5S90H@("`@("H@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T
M;R!C;VYV97)T+@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]N=&5N=%1Y<&4@
M("!4:&4@8V]N=&5N=%1Y<&4@;V8@8V]N=&5N="!A<R!R971U<FYE9"!F<F]M
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!B86-K
M96YD+@H@("`@("H@0')E='5R;B!A<G)A>2`@("`@("`@("`@("`@("!A<G)A
M>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E;G14>7!E*3H*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&-O;G9E<G1E9"!C;VYT96YT
M(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M*'!O<W-I8FQY(&-H86YG960I(&YE=R!#;VYT96YT5'EP92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]N=F5R=%-E<G9E<C)#;&EE;G0H)&-O;G1E;G0L("1C
M;VYT96YT5'EP92D*("`@('L*("`@("`@("!G;&]B86P@)&)A8VME;F0["@H@
M("`@("`@(&QI<W0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D@/0H@("`@("`@
M("`@("!P87)E;G0Z.F-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D
M8V]N=&5N=%1Y<&4I.PH*("`@("`@("`O*B!#;VYV97)T(&%L;"!D87D@979E
M;G1S+B`J+PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%QR7&Y\7')\7&XI
M1%135$%25#M604Q513U$051%.BA<9'LX?2DO)RP*("`@("`@("`@("`@("`@
M("`@("`@("`D8V]N=&5N="D*("`@("`@("`@("`@)B8@<')E9U]M871C:"@G
M+RA<<EQN?%QR?%QN*41414Y$.U9!3%5%/41!5$4Z*%QD7&1<9%QD*2A<9%QD
M*2A<9%QD*2\G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT
M+"`D;2DI('L*("`@("`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H
M)R\H7')<;GQ<<GQ<;BE$5%-405)4.U9!3%5%/41!5$4Z*%QD>SA]*2\G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)#%$5%-405)4
M.B0R5#`P,#`P,%HB+"`D8V]N=&5N="D["B`@("`@("`@("`@("\J($5N9"!D
M871E(&UU<W0@8F4@8V]N=F5R=&5D('1O('1I;65S=&%M<"X@*B\*("`@("`@
M("`@("`@)',@/2!D871E*"=9;60G+"!M:W1I;64H,"P@,"P@,"P@)&U;,UTL
M("1M6S1=+"`D;5LR72D@+2`R-"HS-C`P*3L*("`@("`@("`@("`@)&-O;G1E
M;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<<GQ<;BE$5$5.1#M604Q513U$
M051%.BA<9'LX?2DO)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(B0Q1%1%3D0[.B1[<WU4,C0P,#`P6B(L("1C;VYT96YT*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("A$14)51TQ/1U])0T%,14Y$05)$051!*2![
M"B`@("`@("`@("`@("1F<"`]($!F;W!E;B@G+W1M<"]S>6YC+VQO9RYT>'0G
M+"`G82<I.PH@("`@("`@("`@("!I9B`H)&9P*2!["B`@("`@("`@("`@("`@
M("!`9G=R:71E*"1F<"P@(EQN;W5T<'5T(&-O;G9E<G1E9"!F;W(@8VQI96YT
M("@D8V]N=&5N=%1Y<&4I.EQN(BD["B`@("`@("`@("`@("`@("!`9G=R:71E
M*"1F<"P@)&-O;G1E;G0@+B`B7&XB*3L*("`@("`@("`@("`@("`@($!F8VQO
M<V4H)&9P*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N(&%R<F%Y*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4V]M92!D979I8V5S(&QI:V4@=&AE(%-O;GD@17)I8W-S
M;VX@4#@P,"]0.3`P+U`Y,3`@:&%N9&QE('9T;V1O<R`H=&%S:W,I"B`@("`@
M*B!A;F0@=F5V96YT<R!I;B!T:&4@<V%M92`B8V%L96YD87(B('-Y;F,N"B`@
M("`@*B!4:&ES(')E<75I<F5S('-P96-I86P@86-T:6]N<R!O;B!O=7(@<VED
M92!A<R!W92!S=&]R92!T:&ES(&EN(&1I9F9E<F5N=`H@("`@("H@9&%T86)A
M<V5S("AN86<@86YD(&MR;VYO;&ET:"DN"B`@("`@*B!4:&ES(&9U;F-T:6]N
M(&-O=6QD(&1I<F5C=&QY(')E='5R;B!T<G5E(&)U="!T<FEE<R!T;R!B92!A
M(&)I="!M;W)E"B`@("`@*B!G96YE<FEC('-O(&ET(&UI9VAT('=O<FL@9F]R
M(&]T:&5R('!H;VYE<R!A<R!W96QL+@H@("`@("HO"B`@("!F=6YC=&EO;B!H
M86YD;&5487-K<TEN0V%L96YD87(H*0H@("`@>PH@("`@("`@("1D:2`]("1T
M:&ES+3YD979I8V5);F9O*"D["@H@("`@("`@(&EF("@A96UP='DH)&1I+3Y?
M0U1#87!;)W1E>'0O>"UV8V%L96YD87(G75LG0D5'24XG72T^7U9A;$5N=6U;
M)U9%5D5.5"==*2`F)@H@("`@("`@("`@("`A96UP='DH)&1I+3Y?0U1#87!;
M)W1E>'0O>"UV8V%L96YD87(G75LG0D5'24XG72T^7U9A;$5N=6U;)U943T1/
M)UTI*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('!A<F5N=#HZ:&%N9&QE5&%S:W-);D-A;&5N9&%R*"D[
M"B`@("!]"@H@("`@9G5N8W1I;VX@;F5E9'-#871E9V]R>4UA<'!I;F<H*0H@
M("`@>PH@("`@("`@("\O(%`X,#`@=7-E<R!N=6UE<FEC(&-A=&5G;W)Y(&-O
M9&5S+@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O;&EB+U-Y;F--3"]$979I8V4O4WEN=&AE<VES+G!H<```````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$P-C0W(#$P-3$U-#,T,3,V(#`R,S,V,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AE(%-Y;F--3%]$979I8V5?4WEN=&AE<VES.CH@8VQA<W,@
M<')O=FED97,@9G5N8W1I;VYA;&ET>2!T:&%T(&ES"B`J('-P96-I9FEC('1O
M('1H92!3>6YT:&5S:7,N8V@@4WEN8TU,(&-L:65N=',N"B`J"B`J($-O<'ER
M:6=H="`R,#`U+3(P,#8@2V%R<W1E;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3
M>6YC34PO4WEN8TU,+T1E=FEC92]3>6YT:&5S:7,N<&AP+'8@,2XR+C(N-2`R
M,#`V+S`U+S`Q(#$R.C`U.C$T(&IA;B!%>'`@)`H@*@H@*B!`875T:&]R("!+
M87)S=&5N($9O=7)M;VYT(#QK87)S=&5N0&AO<F1E+F]R9SX*("H@0'!A8VMA
M9V4@4WEN8TU,"B`J+PIC;&%S<R!3>6YC34Q?1&5V:6-E7U-Y;G1H97-I<R!E
M>'1E;F1S(%-Y;F--3%]$979I8V4@>PH*("`@("\J*@H@("`@("H@0V]N=F5R
M=',@=&AE(&-O;G1E;G0@9G)O;2!T:&4@8F%C:V5N9"!T;R!A(&9O<FUA="!S
M=6ET86)L92!F;W(@=&AE"B`@("`@*B!C;&EE;G0@9&5V:6-E+@H@("`@("H*
M("`@("`J(%-T<FEP<R!T:&4@=6ED("AP<FEM87)Y(&ME>2D@:6YF;W)M871I
M;VX@87,@8VQI96YT(&%N9"!S97)V97(@;6EG:'0@=7-E"B`@("`@*B!D:69F
M97)E;G0@;VYE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT
M96YT("`@("`@(%1H92!C;VYT96YT('1O(&-O;G9E<G0*("`@("`J($!P87)A
M;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E;G14>7!E(&]F(&-O
M;G1E;G0@87,@<F5T=7)N960@9G)O;0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T:&4@8F%C:V5N9`H@("`@("H@0')E='5R;B!A<G)A
M>2`@("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E
M;G14>7!E*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AE(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY(&-H86YG960I(&YE=R!#
M;VYT96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=%-E<G9E
M<C)#;&EE;G0H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*("`@('L*("`@("`@
M("!G;&]B86P@)&)A8VME;F0["@H@("`@("`@(&QI<W0H)&-O;G1E;G0L("1C
M;VYT96YT5'EP92D@/0H@("`@("`@("`@("!P87)E;G0Z.F-O;G9E<G1397)V
M97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I.PH*"B`@("`@("`@
M+R\@4V]M92!S<&5C:6%L('!R:6]R:71Y(&AA;F1L:6YG(&ES(')E<75I<F5D
M+B!3>6YT:&5S:7,@=7-E<PH@("`@("`@("\O(#$@*&AI9V@I+"`R("AM961I
M=6TI+"`S*&QO=RDL(&%T(&QE87-T(&9O<B!M>2!W:6YD;W=S(&UO8FEL92!D
M979I8V4N"B`@("`@("`@+R\@8V]N=F5R="!T:&5S92!T;R!V86QI9"!P<FEO
M<FET>2!S971T:6YG<SH*("`@("`@("`D8V]N=&5N="`]('!R96=?<F5P;&%C
M92@G+RA<<EQN?%QR?%QN*5!224]22519.ELQ+3)=*%QR7&Y\7')\7&XI+R<L
M("=<,5!224]22519.C%<,B<L("1C;VYT96YT+"`Q*3L*("`@("`@("`D8V]N
M=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*5!224]22519.ELS
M72A<<EQN?%QR?%QN*2\G+"`G7#%04DE/4DE463HR7#(G+"`D8V]N=&5N="P@
M,2D["B`@("`@("`@)&-O;G1E;G0@/2!P<F5G7W)E<&QA8V4H)R\H7')<;GQ<
M<GQ<;BE04DE/4DE463I;-"TY72A<<EQN?%QR?%QN*2\G+"`G7#%04DE/4DE4
M63HS7#(G+"`D8V]N=&5N="P@,2D["B`@("`@(`H*("`@("`@("`O+R!7:6YD
M;W=S($UO8FEL92!A;'-O(&5X<&5C=',@1%5%($1!5$53(&QI:V4@1%5%.C(P
M,#8P-#$Y5#`P,#`P,`H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%QR7&Y\
M7')\7&XI1%5%.B@N+BXN+BXN+E0N+BXN+BY:*2A<<EQN?%QR?%QN*2\G+`H@
M("`@("`@("`@("`@("`@)&-O;G1E;G0L)&TI*2!["B`@("`@("`@("`@("1M
M6S)=(#T@)'1H:7,M/E540S),;V-A;$1A=&4H)&U;,ETI.PH@("`@("`@("`@
M("`D8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*41513HH
M+BXN+BXN+BY4+BXN+BXN6BDH7')<;GQ<<GQ<;BDO)RP*("`@("`@("`@("`@
M("`@("=<,41513HG("X@)&U;,ET@+B`G7#,G+"`D8V]N=&5N="P@,2D["B`@
M("`@("`@?0H*("`@("`@("`*("`@("`@("!I9B`H1$5"54=,3T=?24-!3$5.
M1$%21$%402D@>PH@("`@("`@("`@("`D9G`@/2!`9F]P96XH)R]T;7`O<WEN
M8R]L;V<N='AT)RP@)V$G*3L*("`@("`@("`@("`@:68@*"1F<"D@>PH@("`@
M("`@("`@("`@("`@0&9W<FET92@D9G`L(")<;F]U='!U="!C;VYV97)T960@
M9F]R(&-L:65N="`H)&-O;G1E;G14>7!E*3I<;B(I.PH@("`@("`@("`@("`@
M("`@0&9W<FET92@D9G`L("1C;VYT96YT("X@(EQN(BD["B`@("`@("`@("`@
M("`@("!`9F-L;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&AE(&-O;G1E;G0N"B`@
M("`@*@H@("`@("H@0W5R<F5N=&QY('-T<FEP<R!U:60@*'!R:6UA<GD@:V5Y
M*2!I;F9O<FUA=&EO;B!A<R!C;&EE;G0@86YD"B`@("`@*B!S97)V97(@;6EG
M:'0@=7-E(&1I9F9E<F5N="!O;F5S+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)&-O;G1E;G0@("`@("`@5&AE(&-O;G1E;G0@=&\@8V]N=F5R="X*
M("`@("`J($!P87)A;2!S=')I;F<@)&-O;G1E;G14>7!E("`@5&AE(&-O;G1E
M;G14>7!E(&]F('1H92!C;VYT96YT+@H@("`@("H@0')E='5R;B!A<G)A>2`@
M("`@("`@("`@("`@("!A<G)A>2@D;F5W8V]N=&5N="P@)&YE=V-O;G1E;G14
M>7!E*3H*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&-O;G9E<G1E9"!C;VYT96YT(&%N9"!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*'!O<W-I8FQY(&-H86YG960I(&YE=R!#;VYT
M96YT5'EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N=F5R=$-L:65N=#)3
M97)V97(H)&-O;G1E;G0L("1C;VYT96YT5'EP92D*("`@('L*("`@("`@("!L
M:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R
M96YT.CIC;VYV97)T0VQI96YT,E-E<G9E<B@D8V]N=&5N="P@)&-O;G1E;G14
M>7!E*3L*"B`@("`@("`@+R\@4V]M92!S<&5C:6%L('!R:6]R:71Y(&AA;F1L
M:6YG(&ES(')E<75I<F5D+B!3>6YT:&5S:7,@=7-E<PH@("`@("`@("\O(#$@
M*&AI9V@I+"`R("AM961I=6TI+"`S*&QO=RDL(&%T(&QE87-T(&9O<B!M>2!W
M:6YD;W=S(&UO8FEL92!D979I8V4N"B`@("`@("`@+R\@8V]N=F5R="!T:&5S
M92!T;R!V86QI9"!P<FEO<FET>2!S971T:6YG<SH*("`@("`@("`D8V]N=&5N
M="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*5!224]22519.C,H7')<
M;GQ<<GQ<;BDO)RP@)UPQ4%))3U))5%DZ-5PR)RP@)&-O;G1E;G0L(#$I.PH@
M("`@("`@("1C;VYT96YT(#T@<')E9U]R97!L86-E*"<O*%QR7&Y\7')\7&XI
M4%))3U))5%DZ,BA<<EQN?%QR?%QN*2\G+"`G7#%04DE/4DE463HS7#(G+"`D
M8V]N=&5N="P@,2D["@H@("`@("`@:68@*$1%0E5'3$]'7TE#04Q%3D1!4D1!
M5$$I('L*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"<O=&UP+W-Y;F,O;&]G
M+G1X="<L("=A)RD["B`@("`@("`@("`@(&EF("@D9G`I('L*("`@("`@("`@
M("`@("`@($!F=W)I=&4H)&9P+"`B7&YI;G!U="!C;VYV97)T960@9F]R('-E
M<G9E<CH@)&-O;G1E;G14>7!E7&XB*3L*("`@("`@("`@("`@("`@($!F=W)I
M=&4H)&9P+"1C;VYT96YT("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L
M;W-E*"1F<"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B!A<G)A>2@D8V]N=&5N="P@)&-O;G1E;G14>7!E*3L*("`*("`@('T*
M("`@(`H@("`@"B`@("`O*B!3=&%T:6,@:&5L<&5R(&9U;F-T:6]N.B!C;VYV
M97)T<R!A(%540R!4:6UE<W1A;7`@;&EK92`R,#`V,#0Q.%0R,C`P,#!:"B`@
M("`@*B!I;G1O(&$@;&]C86P@9&%T92!L:6ME(#(P,#8P-#$Y5#`P,#`P,"X@
M5&AI<R!I<R!A8W1U86QL>2!M;W)E('1H86X*("`@("`J('-T<FEP<&EN9R!T
M:&4@=&EM92!P87)T.B!W92!N965D('1O(&-O;G9E<G0@=&\@;&]C86P@=&EM
M92!F:7)S="!T;R!E;G-U<F4*("`@("`J('=E(&=E="!T:&4@<FEG:'0@9&%T
M92$*("`@("`J+PH@("`@9G5N8W1I;VX@551#,DQO8V%L1&%T92@D<RD*("`@
M('L*("`@("`@("`D="`]($AO<F1E7VE#86QE;F1A<CHZ7W!A<G-E1&%T951I
M;64H)',I.PH@("`@("`@(')E='5R;B!D871E*"=9;60G+"`D="D@+B`G5#`P
M,#`P,"<["B`@("!]"GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]L:6(O4WEN
M8TU,+T1E=FEC92].;VMI82YP:'``````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#0U-34@,3`U,34T,S0Q,S8@,#(R-#,R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&4@4WEN8TU,7T1E=FEC95].;VMI83HZ(&-L87-S('!R;W9I9&5S(&9U;F-T
M:6]N86QI='D@=&AA="!I<PH@*B!S<&5C:69I8R!T;R!T:&4@3F]K:6$@4WEN
M8TU,(&-L:65N=',N"B`J"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2V%R<W1E
M;B!&;W5R;6]N="`\:V%R<W1E;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@
M96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N
M("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*@H@*B`D2&]R9&4Z(&9R86UE=V]R:R]3>6YC34PO4WEN8TU,+T1E=FEC92].
M;VMI82YP:'`L=B`Q+C(N,BXS(#(P,#8O,#4O,#$@,3(Z,#4Z,30@:F%N($5X
M<"`D"B`J"B`J($!A=71H;W(@($MA<G-T96X@1F]U<FUO;G0@/&MA<G-T96Y`
M:&]R9&4N;W)G/@H@*B!`<&%C:V%G92!3>6YC34P*("HO"F-L87-S(%-Y;F--
M3%]$979I8V5?3F]K:6$@97AT96YD<R!3>6YC34Q?1&5V:6-E('L*"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S('1H92!C;VYT96YT(&9R;VT@=&AE(&)A8VME
M;F0@=&\@82!F;W)M870@<W5I=&%B;&4@9F]R('1H90H@("`@("H@8VQI96YT
M(&1E=FEC92X*("`@("`J"B`@("`@*B!3=')I<',@=&AE('5I9"`H<')I;6%R
M>2!K97DI(&EN9F]R;6%T:6]N(&%S(&-L:65N="!A;F0@<V5R=F5R(&UI9VAT
M('5S90H@("`@("H@9&EF9F5R96YT(&]N97,N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D8V]N=&5N="`@("`@("!4:&4@8V]N=&5N="!T;R!C;VYV
M97)T"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;VYT96YT5'EP92`@(%1H92!C
M;VYT96YT5'EP92!O9B!C;VYT96YT(&%S(')E='5R;F5D(&9R;VT*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=&AE(&)A8VME;F0*("`@
M("`J($!R971U<FX@87)R87D@("`@("`@("`@("`@("`@87)R87DH)&YE=V-O
M;G1E;G0L("1N97=C;VYT96YT5'EP92DZ"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1H92!C;VYV97)T960@8V]N=&5N="!A;F0@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("AP;W-S:6)L
M>2!C:&%N9V5D*2!N97<@0V]N=&5N=%1Y<&4N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-O;G9E<G1397)V97(R0VQI96YT*"1C;VYT96YT+"`D8V]N=&5N=%1Y
M<&4I"B`@("!["B`@("`@("`@9VQO8F%L("1B86-K96YD.PH*("`@("`@("!L
M:7-T*"1C;VYT96YT+"`D8V]N=&5N=%1Y<&4I(#T*("`@("`@("`@("`@<&%R
M96YT.CIC;VYV97)T4V5R=F5R,D-L:65N="@D8V]N=&5N="P@)&-O;G1E;G14
M>7!E*3L*"B`@("`@("`@+R\@1DE8344Z(&IU<W0@<W=A<'!I;F<@;W5T('1H
M92!V97)S:6]N(&YU;6)E<B!I;B!T:&4@:&5A9&5R"B`@("`@("`@+R\@<V\@
M=&AA="!T:&4@8VQI96YT(&1O97-N)W0@:6UM961I871E;'D@9&5N>2!W:71H
M(&$@(D9O<FUA=`H@("`@("`@("\O(&YO="!S=7!P;W)T960B+B!3964@:'1T
M<#HO+V)U9W,N:&]R9&4N;W)G+W1I8VME="\_:60],3@X,2X*("`@("`@("`D
M8V]N=&5N="`]('!R96=?<F5P;&%C92@G+RA<<EQN?%QR?%QN*59%4E-)3TXZ
M,BXP+R<L("=<,59%4E-)3TXZ,2XP)RP@)&-O;G1E;G0L(#$I.PH*("`@("`@
M("!I9B`H1$5"54=,3T=?24-!3$5.1$%21$%402D@>PH@("`@("`@("`@("`D
M9G`@/2!`9F]P96XH)R]T;7`O<WEN8R]L;V<N='AT)RP@)V$G*3L*("`@("`@
M("`@("`@:68@*"1F<"D@>PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L
M(")<;F]U='!U="!C;VYV97)T960@9F]R(&-L:65N="`H)&-O;G1E;G14>7!E
M*3I<;B(I.PH@("`@("`@("`@("`@("`@0&9W<FET92@D9G`L("1C;VYT96YT
M("X@(EQN(BD["B`@("`@("`@("`@("`@("!`9F-L;W-E*"1F<"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!A<G)A>2@D8V]N
M=&5N="P@)&-O;G1E;G14>7!E*3L*("`@('T*"B`@("`O*B!.;VMI82!C=7)R
M96YT;'D@97AP96-T<R!N;W1E<R!A<R!T97AT+W!L86EN+B!-87EB92!W92!C
M86X@97AT<F%C=`H@("`@("H@=&AI<R!F<F]M($1E=DEN9B!R871H97(@=&AA
M;B!H87)D8V]D92!I="X*("`@("`J+PH*("`@9G5N8W1I;VX@9V5T4')E9F5R
M<F5D0V]N=&5N=%1Y<&4H)'1Y<&4I"B`@("!["B`@("`@("`@(&EF("@D='EP
M92`]/2`G;F]T97,G*2!["B`@("`@("`@("`@(')E='5R;B`G=&5X="]P;&%I
M;B<["B`@("`@("`@?0H@("`@("`@(')E='5R;B!P87)E;G0Z.F=E=%!R969E
M<G)E9$-O;G1E;G14>7!E*"1T>7!E*3L*("`@('T*"B`@(&9U;F-T:6]N(&AA
M;F1L951A<VMS26Y#86QE;F1A<B@I"B`@('L*("`@("`@<F5T=7)N('1R=64[
M("`@("`@"B`@('T*?0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]J<R]T86)L97,N:G,`````````````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,C(V,C<@,3`U,34T,S0Q,S8@,#$W-S<R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M*@H@*B!*879A<V-R:7!T(&-O9&4@9F]R(&9I;F1I;F<@86QL('1A8FQE<R!W
M:71H(&-L87-S;F%M92`B<W1R:7!E9"(@86YD"B`J(&1Y;F%M:6-A;&QY('-T
M<FEP:6YG('1H96ER(')O=R!C;VQO<G,L(&%N9"!F:6YD:6YG(&%L;"!T86)L
M97,@=VET:`H@*B!C;&%S<VYA;64@(G-O<G1A8FQE(B!A;F0@;6%K:6YG('1H
M96T@9'EN86UI8V%L;'D@<V]R=&%B;&4N"B`J"B`J("1(;W)D93H@:&]R9&4O
M:G,O=&%B;&5S+FIS+'8@,2XT+C(N,R`R,#`U+S$R+S`Q(#(R.C4X.C(V(&-H
M=6-K($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N
M;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO
M<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"B\J(%=E(&1O(&5V97)Y=&AI
M;F<@;VYL;V%D('-O('1H870@=&AE(&5N=&ER92!D;V-U;65N="!I<R!P<F5S
M96YT"B`J(&)E9F]R92!W92!S=&%R="!S96%R8VAI;F<@:70@9F]R('1A8FQE
M<RX@*B\*:68@*'=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*2!["B`@("!W:6YD
M;W<N861D179E;G1,:7-T96YE<B@G;&]A9"<L('1A8FQE7VEN:70L(&9A;'-E
M*3L*?2!E;'-E(&EF("AW:6YD;W<N871T86-H179E;G0I('L*("`@('=I;F1O
M=RYA='1A8VA%=F5N="@G;VYL;V%D)RP@=&%B;&5?:6YI="D["GT@96QS92!I
M9B`H=VEN9&]W+F]N;&]A9"`A/2!N=6QL*2!["B`@("!V87(@;VQD7V]N;&]A
M9"`]('=I;F1O=RYO;FQO860["B`@("!W:6YD;W<N;VYL;V%D(#T@9G5N8W1I
M;VXH92D*("`@('L*("`@("`@("!O;&1?;VYL;V%D*&4I.PH@("`@("`@('1A
M8FQE7VEN:70H*3L*("`@('T["GT@96QS92!["B`@("!W:6YD;W<N;VYL;V%D
M(#T@=&%B;&5?:6YI=#L*?0H*=F%R(%-/4E1?0T],54U.7TE.1$58.PH*9G5N
M8W1I;VX@=&%B;&5?:6YI="@I"GL*("`@(&EF("@A9&]C=6UE;G0N9V5T16QE
M;65N='-">51A9TYA;64I('L*("`@("`@("!R971U<FX["B`@("!]"B`@("!T
M86)L97,@/2!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@G=&%B;&4G
M*3L*("`@(&9O<B`H:2`](#`[(&D@/"!T86)L97,N;&5N9W1H.R!I*RLI('L*
M("`@("`@("!I9B`H:&%S0VQA<W,H=&%B;&5S6VE=+"`G<W1R:7!E9"<I*2![
M"B`@("`@("`@("`@('1A8FQE7W-T<FEP92AT86)L97-;:5TI.PH@("`@("`@
M('T*("`@("`@("!I9B`H:&%S0VQA<W,H=&%B;&5S6VE=+"`G<V]R=&%B;&4G
M*2`F)B!T86)L97-;:5TN:60I('L*("`@("`@("`@("`@=&%B;&5?;6%K95-O
M<G1A8FQE*'1A8FQE<UMI72D["B`@("`@("`@?0H@("`@?0I]"@IF=6YC=&EO
M;B!T86)L95]S=')I<&4H=&%B;&4I"GL*("`@("\O(%1H92!F;&%G('=E)VQL
M('5S92!T;R!K965P('1R86-K(&]F('=H971H97(@=&AE(&-U<G)E;G0@<F]W
M(&ES"B`@("`O+R!O9&0@;W(@979E;BX*("`@('9A<B!E=F5N(#T@9F%L<V4[
M"@H@("`@+R\@5&%B;&5S(&-A;B!H879E(&UO<F4@=&AA;B!O;F4@=&)O9'D@
M96QE;65N=#L@9V5T(&%L;"!C:&EL9`H@("`@+R\@=&)O9'D@=&%G<R!A;F0@
M:6YT97)A=&4@=&AR;W5G:"!T:&5M+@H@("`@=F%R('1B;V1I97,@/2!T86)L
M92YC:&EL9$YO9&5S.PH@("`@9F]R("AV87(@8R`](#`[(&,@/"!T8F]D:65S
M+FQE;F=T:#L@8RLK*2!["B`@("`@("`@:68@*'1B;V1I97-;8UTN=&%G3F%M
M92`A/2`G5$)/1%DG*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@
M('T*"B`@("`@("`@=F%R('1R<R`]('1B;V1I97-;8UTN8VAI;&1.;V1E<SL*
M("`@("`@("!F;W(@*'9A<B!I(#T@,#L@:2`\('1R<RYL96YG=&@[(&DK*RD@
M>PH@("`@("`@("`@("!I9B`H=')S6VE=+G1A9TYA;64@/3T@)U12)RD@>PH@
M("`@("`@("`@("`@("`@<F5M;W9E0VQA<W,H=')S6VE=+"`G<F]W179E;B<I
M.PH@("`@("`@("`@("`@("`@<F5M;W9E0VQA<W,H=')S6VE=+"`G<F]W3V1D
M)RD["B`@("`@("`@("`@("`@("!A9&1#;&%S<RAT<G-;:5TL(&5V96X@/R`G
M<F]W179E;B<@.B`G<F]W3V1D)RD["@H@("`@("`@("`@("`@("`@+R\@1FQI
M<"!F<F]M(&]D9"!T;R!E=F5N+"!O<B!V:6-E+79E<G-A+@H@("`@("`@("`@
M("`@("`@979E;B`]("%E=F5N.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@?0I]"@IF=6YC=&EO;B!T86)L95]M86ME4V]R=&%B;&4H=&%B;&4I"GL*
M("`@(&EF("AT86)L92YR;W=S("8F('1A8FQE+G)O=W,N;&5N9W1H(#X@,"D@
M>PH@("`@("`@('9A<B!F:7)S=%)O=R`]('1A8FQE+G)O=W-;,%T["B`@("!]
M"B`@("!I9B`H(69I<G-T4F]W*2!["B`@("`@("`@<F5T=7)N.PH@("`@?0H*
M("`@("\O(%=E(&AA=F4@82!F:7)S="!R;W<Z(&%S<W5M92!I="=S('1H92!H
M96%D97(L(&%N9"!M86ME(&ET<PH@("`@+R\@8V]N=&5N=',@8VQI8VMA8FQE
M(&QI;FMS+@H@("`@9F]R("AV87(@:2`](#`[(&D@/"!F:7)S=%)O=RYC96QL
M<RYL96YG=&@[(&DK*RD@>PH@("`@("`@('9A<B!C96QL(#T@9FER<W12;W<N
M8V5L;'-;:5T["B`@("`@("`@:68@*&AA<T-L87-S*&-E;&PL("=N;W-O<G0G
M*2D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]"@H@("`@("`@
M(&-E;&PN8V]L=6UN26YD97@@/2!I.PH@("`@("`@(&-E;&PN<W1Y;&4N8W5R
M<V]R(#T@)W!O:6YT97(G.PH@("`@("`@(&-E;&PN;VYC;&EC:R`](&9U;F-T
M:6]N*&4I"B`@("`@("`@>PH@("`@("`@("`@("!V87(@92`](&4@?'P@=VEN
M9&]W+F5V96YT.PH*("`@("`@("`@("`@:68@*&4N=&%R9V5T*2!["B`@("`@
M("`@("`@("`@("!I9B`H92YT87)G970N;F]D951Y<&4@/3T@,RD@>PH@("`@
M("`@("`@("`@("`@("`@(&4N=&%R9V5T(#T@92YT87)G970N<&%R96YT3F]D
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E(&EF("AE
M+G-R8T5L96UE;G0I('L*("`@("`@("`@("`@("`@(&4N=&%R9V5T(#T@92YS
M<F-%;&5M96YT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!E;"`](&AA
M<U!A<F5N="AE+G1A<F=E="P@)T$G+"`G5$@G*3L*("`@("`@("`@("`@:68@
M*&5L("8F("%H87-#;&%S<RAE;"P@)W-O<G1L:6YK)RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!T86)L95]R97-O<G1486)L92AG971087)E;G0H92YT87)G970L("=42"<I
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*
M?0H*9G5N8W1I;VX@=&%B;&5?9V5T26YN97)497AT*&5L*0I["B`@("!I9B`H
M='EP96]F(&5L(#T]("=S=')I;F<G*2!["B`@("`@("`@<F5T=7)N(&5L.PH@
M("`@?0H@("`@:68@*'1Y<&5O9B!E;"`]/2`G=6YD969I;F5D)RD@>PH@("`@
M("`@(')E='5R;B!E;#L*("`@('T*("`@(&EF("AE;"YI;FYE<E1E>'0I('L*
M("`@("`@("`O+R!.;W0@;F5E9&5D(&)U="!I="!I<R!F87-T97(N"B`@("`@
M("`@<F5T=7)N(&5L+FEN;F5R5&5X=#L*("`@('T*"B`@("!V87(@<W1R(#T@
M(B(["B`@("!V87(@8W,@/2!E;"YC:&EL9$YO9&5S.PH@("`@=F%R(&P@/2!C
M<RYL96YG=&@["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&P[(&DK*RD@>PH@
M("`@("`@('-W:71C:"`H8W-;:5TN;F]D951Y<&4I('L*("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@("\O($5,14U%3E1?3D]$10H@("`@("`@("`@("!S
M='(@*ST@=&%B;&5?9V5T26YN97)497AT*&-S6VE=*3L*("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@(&-A<V4@,SH*("`@("`@("`@("`@+R\@5$585%].
M3T1%"B`@("`@("`@("`@('-T<B`K/2!C<UMI72YN;V1E5F%L=64["B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"B`@("!R971U<FX@<W1R
M.PI]"@IF=6YC=&EO;B!T86)L95]R97-O<G1486)L92AT:"D*>PH@("`@=&%B
M;&4@/2!G971087)E;G0H=&@L("=404),12<I.PH@("`@<V]R=$-O;'5M;B`]
M('1H+F-O;'5M;DEN9&5X.PH@("`@<V]R=$1O=VX@/2`P.PH*("`@("\O($QO
M;W`@=&AR;W5G:"`\=&AE860^('1O(&9I;F0@=&AE(&-U<G)E;G0@<V]R="!C
M;VQU;6X@86YD"B`@("`O+R!D:7)E8W1I;VXN"B`@("!T:&5A9',@/2!T86)L
M92YT2&5A9"YG971%;&5M96YT<T)Y5&%G3F%M92@G=&@G*3L*("`@(&9O<B`H
M:2`](#`[(&D@/"!T:&5A9',N;&5N9W1H.R!I*RLI('L*("`@("`@("!I9B`H
M=&@@/3T@=&AE861S6VE=*2!["B`@("`@("`@("`@(&EF("AH87-#;&%S<RAT
M:&5A9'-;:5TL("=S;W)T=7`G*2D@>PH@("`@("`@("`@("`@("`@<F5M;W9E
M0VQA<W,H=&AE861S6VE=+"`G<V]R='5P)RD["B`@("`@("`@("`@("`@("!A
M9&1#;&%S<RAT:&5A9'-;:5TL("=S;W)T9&]W;B<I.PH@("`@("`@("`@("!]
M(&5L<V4@:68@*&AA<T-L87-S*'1H96%D<UMI72P@)W-O<G1D;W=N)RDI('L*
M("`@("`@("`@("`@("`@(')E;6]V94-L87-S*'1H96%D<UMI72P@)W-O<G1D
M;W=N)RD["B`@("`@("`@("`@("`@("!A9&1#;&%S<RAT:&5A9'-;:5TL("=S
M;W)T=7`G*3L*("`@("`@("`@("`@("`@('-O<G1$;W=N(#T@,3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&%D9$-L87-S*'1H96%D
M<UMI72P@)W-O<G1D;W=N)RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R96UO=F5#;&%S<RAT:&5A9'-;:5TL("=S;W)T
M=7`G*3L*("`@("`@("`@("`@<F5M;W9E0VQA<W,H=&AE861S6VE=+"`G<V]R
M=&1O=VXG*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@5V]R:R!O=70@82!T
M>7!E(&9O<B!T:&4@8V]L=6UN"B`@("!I9B`H=&%B;&4N<F]W<RYL96YG=&@@
M/#T@,2D@>PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!V87(@:71M(#T@
M=&%B;&5?9V5T26YN97)497AT*'1A8FQE+G)O=W-;,5TN8V5L;'-;<V]R=$-O
M;'5M;ETI.PH@("`@<V]R=&9N(#T@=&%B;&5?<V]R=%]C87-E:6YS96YS:71I
M=F4["B`@("!I9B`H:71M+FUA=&-H*"]>7&1<9%M<+RU=7&1<9%M<+RU=7&1<
M9%QD7&0D+RDI('L*("`@("`@("!S;W)T9FX@/2!T86)L95]S;W)T7V1A=&4[
M"B`@("!]"B`@("!I9B`H:71M+FUA=&-H*"]>7&1<9%M<+RU=7&1<9%M<+RU=
M7&1<9"0O*2D@>PH@("`@("`@('-O<G1F;B`]('1A8FQE7W-O<G1?9&%T93L*
M("`@('T*("`@(&EF("AI=&TN;6%T8V@H+UY;HR1=+RDI('L*("`@("`@("!S
M;W)T9FX@/2!T86)L95]S;W)T7V-U<G)E;F-Y.PH@("`@?0H@("`@:68@*&ET
M;2YM871C:"@O7EM<9%PN72LD+RDI('L*("`@("`@("!S;W)T9FX@/2!T86)L
M95]S;W)T7VYU;65R:6,["B`@("!]"@H@("`@4T]25%]#3TQ534Y?24Y$15@@
M/2!S;W)T0V]L=6UN.PH*("`@("\O($1O;B=T(&UI>"!U<"!S97!E<F%T92!T
M8F]D:65S.R!S;W)T(&5A8V@@:6X@='5R;BX*("`@(&9O<B`H:2`](#`[(&D@
M/"!T86)L92YT0F]D:65S+FQE;F=T:#L@:2LK*2!["B`@("`@("`@=')S(#T@
M=&%B;&4N=$)O9&EE<UMI72YG971%;&5M96YT<T)Y5&%G3F%M92@G='(G*3L*
M("`@("`@("!N97=2;W=S(#T@;F5W($%R<F%Y*"D["B`@("`@("`@9F]R("AJ
M(#T@,#L@:B`\('1R<RYL96YG=&@[(&HK*RD@>PH@("`@("`@("`@("!N97=2
M;W=S6VI=(#T@=')S6VI=.PH@("`@("`@('T*"B`@("`@("`@;F5W4F]W<RYS
M;W)T*'-O<G1F;BD["B`@("`@("`@:68@*'-O<G1$;W=N*2!["B`@("`@("`@
M("`@(&YE=U)O=W,N<F5V97)S92@I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M5V4@87!P96YD0VAI;&0@<F]W<R!T:&%T(&%L<F5A9'D@97AI<W0@=&\@=&AE
M('1B;V1Y+"!S;R!I=`H@("`@("`@("\O(&UO=F5S('1H96T@<F%T:&5R('1H
M86X@8W)E871I;F<@;F5W(&]N97,N($1O;B=T(&1O"B`@("`@("`@+R\@<V]R
M=&)O='1O;2!R;W=S+@H@("`@("`@(&9O<B`H:B`](#`[(&H@/"!N97=2;W=S
M+FQE;F=T:#L@:BLK*2!["B`@("`@("`@("`@(&EF("@A:&%S0VQA<W,H;F5W
M4F]W<UMJ72P@)W-O<G1B;W1T;VTG*2D@>PH@("`@("`@("`@("`@("`@=&%B
M;&4N=$)O9&EE<UMI72YA<'!E;F1#:&EL9"AN97=2;W=S6VI=*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@1&\@<V]R=&)O='1O;2!R
M;W=S(&]N;'DN"B`@("`@("`@9F]R("AJ(#T@,#L@:B`\(&YE=U)O=W,N;&5N
M9W1H.R!J*RLI('L*("`@("`@("`@("`@:68@*&AA<T-L87-S*&YE=U)O=W-;
M:ETL("=S;W)T8F]T=&]M)RDI('L*("`@("`@("`@("`@("`@('1A8FQE+G1"
M;V1I97-;:5TN87!P96YD0VAI;&0H;F5W4F]W<UMJ72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@268@=V4@:G5S="!R97-O<G1E
M9"!A('-T<FEP960@=&%B;&4L(')E+7-T<FEP92!I="X*("`@(&EF("AH87-#
M;&%S<RAT86)L92P@)W-T<FEP960G*2D@>PH@("`@("`@('1A8FQE7W-T<FEP
M92AT86)L92D["B`@("!]"@H@("`@+R\@1FEN86QL>2P@<V5E(&EF('=E(&AA
M=F4@82!C86QL8F%C:R!F=6YC=&EO;B!T;R!T<FEG9V5R+@H@("`@:68@*'1Y
M<&5O9BAT86)L95]S;W)T0V%L;&)A8VLI(#T]("=F=6YC=&EO;B<I('L*("`@
M("`@("!T86)L95]S;W)T0V%L;&)A8VLH=&%B;&4N:60L('1H+FED+"!S;W)T
M1&]W;BD["B`@("!]"GT*"F9U;F-T:6]N(&=E=%!A<F5N="AE;"P@<%1A9TYA
M;64I"GL*("`@(&EF("AE;"`]/2!N=6QL*2!["B`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("!](&5L<V4@:68@*'!486=.86UE(#T](&YU;&PI('L*("`@("`@
M("!R971U<FX@96PN<&%R96YT3F]D93L*("`@('T@96QS92!I9B`H96PN;F]D
M951Y<&4@/3T@,2`F)B!E;"YT86=.86UE+G1O3&]W97)#87-E*"D@/3T@<%1A
M9TYA;64N=&],;W=E<D-A<V4H*2D@>PH@("`@("`@("\O($=E8VMO(&)U9RP@
M<W5P<&]S960@=&\@8F4@=7!P97)C87-E+@H@("`@("`@(')E='5R;B!E;#L*
M("`@('T@96QS92!["B`@("`@("`@<F5T=7)N(&=E=%!A<F5N="AE;"YP87)E
M;G1.;V1E+"!P5&%G3F%M92D["B`@("!]"GT*"F9U;F-T:6]N('1A8FQE7W-O
M<G1?9&%T92AA+"!B*0I["B`@("`O+R!4=V\@9&EG:70@>65A<G,@;&5S<R!T
M:&%N(#4P(&%R92!T<F5A=&5D(&%S(#(P6%@L(&=R96%T97(@=&AA;@H@("`@
M+R\@-3`@87)E('1R96%T960@87,@,3E86"X*("`@(&%A(#T@=&%B;&5?9V5T
M26YN97)497AT*&$N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*3L*("`@(&)B
M(#T@=&%B;&5?9V5T26YN97)497AT*&(N8V5L;'-;4T]25%]#3TQ534Y?24Y$
M15A=*3L*("`@(&EF("AA82YL96YG=&@@/3T@,3`I('L*("`@("`@("!D=#$@
M/2!A82YS=6)S='(H-BP@-"D@*R!A82YS=6)S='(H,RP@,BD@*R!A82YS=6)S
M='(H,"P@,BD["B`@("!](&5L<V4@>PH@("`@("`@('ER(#T@86$N<W5B<W1R
M*#8L(#(I.PH@("`@("`@(&EF("AP87)S94EN="AY<BD@/"`U,"D@>PH@("`@
M("`@("`@("!Y<B`]("<R,"<@*R!Y<CL*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!Y<B`]("<Q.2<@*R!Y<CL*("`@("`@("!]"B`@("`@("`@9'0Q
M(#T@>7(K86$N<W5B<W1R*#,L(#(I("L@86$N<W5B<W1R*#`L(#(I.PH@("`@
M?0H@("`@:68@*&)B+FQE;F=T:"`]/2`Q,"D@>PH@("`@("`@(&1T,B`](&)B
M+G-U8G-T<B@V+"`T*2`K(&)B+G-U8G-T<B@S+"`R*2`K(&)B+G-U8G-T<B@P
M+"`R*3L*("`@('T@96QS92!["B`@("`@("`@>7(@/2!B8BYS=6)S='(H-BP@
M,BD["B`@("`@("`@:68@*'!A<G-E26YT*'ER*2`\(#4P*2!["B`@("`@("`@
M("`@('ER(#T@)S(P)R`K('ER.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@('ER(#T@)S$Y)R`K('ER.PH@("`@("`@('T*("`@("`@("!D=#(@/2!Y
M<B`K(&)B+G-U8G-T<B@S+"`R*2`K(&)B+G-U8G-T<B@P+"`R*3L*("`@('T*
M("`@(&EF("AD=#$@/3T@9'0R*2!["B`@("`@("`@<F5T=7)N(#`["B`@("!]
M(&5L<V4@:68@*&1T,2`\(&1T,BD@>PH@("`@("`@(')E='5R;B`M,3L*("`@
M('T*("`@(')E='5R;B`Q.PI]"@IF=6YC=&EO;B!T86)L95]S;W)T7V-U<G)E
M;F-Y*&$L(&(I"GL*("`@(&%A(#T@=&%B;&5?9V5T26YN97)497AT*&$N8V5L
M;'-;4T]25%]#3TQ534Y?24Y$15A=*2YR97!L86-E*"];7C`M.2Y=+V<L("<G
M*3L*("`@(&)B(#T@=&%B;&5?9V5T26YN97)497AT*&(N8V5L;'-;4T]25%]#
M3TQ534Y?24Y$15A=*2YR97!L86-E*"];7C`M.2Y=+V<L("<G*3L*("`@(')E
M='5R;B!P87)S949L;V%T*&%A*2`M('!A<G-E1FQO870H8F(I.PI]"@IF=6YC
M=&EO;B!T86)L95]S;W)T7VYU;65R:6,H82P@8BD*>PH@("`@86$@/2!P87)S
M949L;V%T*'1A8FQE7V=E=$EN;F5R5&5X="AA+F-E;&QS6U-/4E1?0T],54U.
M7TE.1$5872DI.PH@("`@:68@*&ES3F%.*&%A*2D@>PH@("`@("`@(&%A(#T@
M,#L*("`@('T*("`@(&)B(#T@<&%R<V5&;&]A="AT86)L95]G971);FYE<E1E
M>'0H8BYC96QL<UM33U)47T-/3%5-3E])3D1%6%TI*3L*("`@(&EF("AI<TYA
M3BAB8BDI('L*("`@("`@("!B8B`](#`["B`@("!]"B`@("!R971U<FX@86$@
M+2!B8CL*?0H*9G5N8W1I;VX@=&%B;&5?<V]R=%]C87-E:6YS96YS:71I=F4H
M82P@8BD*>PH@("`@86$@/2!T86)L95]G971);FYE<E1E>'0H82YC96QL<UM3
M3U)47T-/3%5-3E])3D1%6%TI+G1O3&]W97)#87-E*"D["B`@("!B8B`]('1A
M8FQE7V=E=$EN;F5R5&5X="AB+F-E;&QS6U-/4E1?0T],54U.7TE.1$5872DN
M=&],;W=E<D-A<V4H*3L*("`@(&EF("AA82`]/2!B8BD@>PH@("`@("`@(')E
M='5R;B`P.PH@("`@?2!E;'-E(&EF("AA82`\(&)B*2!["B`@("`@("`@<F5T
M=7)N("TQ.PH@("`@?0H@("`@<F5T=7)N(#$["GT*"F9U;F-T:6]N('1A8FQE
M7W-O<G1?9&5F875L="AA+&(I"GL*("`@(&%A(#T@=&%B;&5?9V5T26YN97)4
M97AT*&$N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*3L*("`@(&)B(#T@=&%B
M;&5?9V5T26YN97)497AT*&(N8V5L;'-;4T]25%]#3TQ534Y?24Y$15A=*3L*
M("`@(&EF("AA82`]/2!B8BD@>PH@("`@("`@(')E='5R;B`P.PH@("`@?2!E
M;'-E(&EF("AA82`\(&)B*2!["B`@("`@("`@<F5T=7)N("TQ.PH@("`@?0H@
M("`@<F5T=7)N(#$["GT*"B\J*@H@*B!$3TT@=71I;&ET>2!F=6YC=&EO;G,N
M"B`J+PIF=6YC=&EO;B!H87-087)E;G0H96PL('1A9TYA;64L('1A9U-T;W`I
M"GL*("`@(&EF("AE;"YT86=.86UE(#T]('1A9TYA;64I('L*("`@("`@("!R
M971U<FX@96P["B`@("!](&5L<V4@:68@*'1A9U-T;W`@(3T@;G5L;"`F)B!E
M;"YT86=.86UE(#T]('1A9U-T;W`I('L*("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("!](&5L<V4@>PH@("`@("`@(')E='5R;B!H87-087)E;G0H9V5T4&%R
M96YT*&5L*2P@=&%G3F%M92P@=&%G4W1O<"D["B`@("!]"GT*"F9U;F-T:6]N
M(&%D9$-L87-S*&5L+"!C;&%S<TYA;64I"GL*("`@(&5L+F-L87-S3F%M92`K
M/2!E;"YC;&%S<TYA;64@/R`G("<@*R!C;&%S<TYA;64@.B!C;&%S<TYA;64[
M"GT*"F9U;F-T:6]N(')E;6]V94-L87-S*&5L+"!C;&%S<TYA;64I"GL*("`@
M(&5L+F-L87-S3F%M92`](&5L+F-L87-S3F%M92YR97!L86-E*&YE=R!296=%
M>'`H)R`_)R`K(&-L87-S3F%M92`K("<@/R<I+"`G)RD["GT*"F9U;F-T:6]N
M(&AA<T-L87-S*&5L+"!C;&%S<TYA;64I"GL*("`@(')E='5R;B`H96PN8VQA
M<W-.86UE+FEN9&5X3V8H8VQA<W-.86UE*2`A/2`M,2D["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O<W1R:7!E+FIS````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`T,3`Q(#$P-3$U-#,T,3,V(#`R,#`Q,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@2F%V87-C<FEP="!C;V1E
M(&9O<B!F:6YD:6YG(&%L;"!T86)L97,@=VET:"!C;&%S<VYA;64@(G-T<FEP
M960B(&%N9`H@*B!D>6YA;6EC86QL>2!S=')I<&EN9R!T:&5I<B!R;W<@8V]L
M;W)S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+W-T<FEP92YJ<RQV(#$N,RXR
M+C(@,C`P-2\Q,"\Q."`Q,3HS,SHS."!J86X@17AP("0*("H*("H@4V5E('1H
M92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I
M;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL
M92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN
M"B`J+PH*+RH@5V4@9&\@979E<GET:&EN9R!O;FQO860@<V\@=&AA="!T:&4@
M96YT:7)E(&1O8W5M96YT(&ES('!R97-E;G0*("H@8F5F;W)E('=E('-T87)T
M('-E87)C:&EN9R!I="!F;W(@=&%B;&5S+B`J+PII9B`H=VEN9&]W+F%D9$5V
M96YT3&ES=&5N97(I('L*("`@('=I;F1O=RYA9&1%=F5N=$QI<W1E;F5R*"=L
M;V%D)RP@9FEN9%-T<FEP961486)L97,L(&9A;'-E*3L*?2!E;'-E(&EF("AW
M:6YD;W<N871T86-H179E;G0I('L*("`@('=I;F1O=RYA='1A8VA%=F5N="@G
M;VYL;V%D)RP@9FEN9%-T<FEP961486)L97,I.PI](&5L<V4@:68@*'=I;F1O
M=RYO;FQO860@(3T@;G5L;"D@>PH@("`@=F%R(&]L9$]N3&]A9"`]('=I;F1O
M=RYO;FQO860["B`@("!W:6YD;W<N;VYL;V%D(#T@9G5N8W1I;VXH92D*("`@
M('L*("`@("`@("!O;&1/;DQO860H92D["B`@("`@("`@9FEN9%-T<FEP9614
M86)L97,H*3L*("`@('T["GT@96QS92!["B`@("!W:6YD;W<N;VYL;V%D(#T@
M9FEN9%-T<FEP961486)L97,["GT*"F9U;F-T:6]N(&9I;F13=')I<&5D5&%B
M;&5S*"D*>PH@("`@:68@*"%D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M
M92D@>PH@("`@("`@(')E='5R;CL*("`@('T*("`@('1A8FQE<R`](&1O8W5M
M96YT+F=E=$5L96UE;G1S0GE486=.86UE*"=T86)L92<I.PH@("`@9F]R("AI
M(#T@,#L@:2`\('1A8FQE<RYL96YG=&@[(&DK*RD@>PH@("`@("`@(&EF("AT
M86)L97-;:5TN8VQA<W-.86UE+FEN9&5X3V8H)W-T<FEP960G*2`A/2`M,2D@
M>PH@("`@("`@("`@("!S=')I<&4H=&%B;&5S6VE=*3L*("`@("`@("!]"B`@
M("!]"GT*"F9U;F-T:6]N('-T<FEP92AT86)L92D*>PH@("`@+R\@5&AE(&9L
M86<@=V4G;&P@=7-E('1O(&ME97`@=')A8VL@;V8@=VAE=&AE<B!T:&4@8W5R
M<F5N="!R;W<@:7,*("`@("\O(&]D9"!O<B!E=F5N+@H@("`@=F%R(&5V96X@
M/2!F86QS93L*"B`@("`O+R!486)L97,@8V%N(&AA=F4@;6]R92!T:&%N(&]N
M92!T8F]D>2!E;&5M96YT.R!G970@86QL(&-H:6QD"B`@("`O+R!T8F]D>2!T
M86=S(&%N9"!I;G1E<F%T92!T:')O=6=H('1H96TN"B`@("!V87(@=&)O9&EE
M<R`]('1A8FQE+F-H:6QD3F]D97,["B`@("!F;W(@*'9A<B!C(#T@,#L@8R`\
M('1B;V1I97,N;&5N9W1H.R!C*RLI('L*("`@("`@("!I9B`H=&)O9&EE<UMC
M72YT86=.86UE(#T]("=40D]$62<I('L*("`@("`@("`@("`@=F%R('1R<R`]
M('1B;V1I97-;8UTN8VAI;&1.;V1E<SL*("`@("`@("`@("`@9F]R("AV87(@
M:2`](#`[(&D@/"!T<G,N;&5N9W1H.R!I*RLI('L*("`@("`@("`@("`@("`@
M(&EF("AT<G-;:5TN=&%G3F%M92`]/2`G5%(G*2!["B`@("`@("`@("`@("`@
M("`@("`@=')S6VE=+F-L87-S3F%M92`]('1R<UMI72YC;&%S<TYA;64N<F5P
M;&%C92@O(#]R;W=%=F5N(#\O+"`G)RDN<F5P;&%C92@O(#]R;W=/9&0@/R\L
M("<G*3L*("`@("`@("`@("`@("`@("`@("!I9B`H=')S6VE=+F-L87-S3F%M
M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!T<G-;:5TN8VQA<W-.86UE
M("L]("<@)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@=')S6VE=+F-L87-S3F%M92`K/2!E=F5N(#\@)W)O=T5V96XG(#H@
M)W)O=T]D9"<["@H@("`@("`@("`@("`@("`@("`@("\O($9L:7`@9G)O;2!O
M9&0@=&\@979E;BP@;W(@=FEC92UV97)S82X*("`@("`@("`@("`@("`@("`@
M("!E=F5N(#T@(65V96X["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O
M:&]R9&4N:64N:G,`````````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`Q,C$P(#$P-3$U-#,T,3,V(#`R,#$W-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````O*BH*("H@1V5N
M97)A;"!(;W)D92!522!E9F9E8W1S(&IA=F%S8W)I<'0@+2!F:7AE<R!F;W(@
M244@=&AA="!C86XG=`H@*B!E87-I;'D@8F4@9&]N92!W:71H;W5T(&)R;W=S
M97(@9&5T96-T:6]N+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+VAO<F1E+FEE
M+FIS+'8@,2XQ+C(N,B`R,#`V+S`Q+S(Y(#$P.C$X.C(P(&-H=6-K($5X<"`D
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"E1O;VQ4:7!S7T]P=&EO;E]7:6YD;W=E9%]#
M;VYT<F]L<R`](#$["@II9B`H='EP96]F($%R<F%Y+G!R;W1O='EP92YP=7-H
M(#T]("=U;F1E9FEN960G*2!["B`@("`@07)R87DN<')O=&]T>7!E+G!U<V@@
M/2!F=6YC=&EO;B@I('L*("`@("`@("`@=F%R(&P@/2!T:&ES+FQE;F=T:#L*
M("`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!A<F=U;65N=',N;&5N9W1H
M.R!I*RLI('L*("`@("`@("`@("`@('1H:7-;;"`K(&E=(#T@87)G=6UE;G1S
M6VE=.PH@("`@("`@("!]"B`@("`@("`@(')E='5R;B!T:&ES+FQE;F=T:`H@
M("`@('T*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O:G,O<V]R=&5R+FIS````````````````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`V-3,V(#$P-3$U-#,T,3,V(#`R,#`S-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````O*BH*
M("H@2&]R9&4@1F]R;2!3;W)T97(@1FEE;&0@2F%V87-C<FEP="!#;&%S<PH@
M*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S<R!T;R!A8V-O;7!A
M;GD@=&AE($AO<F1E7T9O<FT@<V]R=&5R"B`J(&9I96QD+@H@*@H@*B`D2&]R
M9&4Z(&AO<F1E+VIS+W-O<G1E<BYJ<RQV(#$N,BXQ,"XS(#(P,#8O,#$O,#$@
M,C$Z,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@
M36%R:V\@1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*B\*"F9U;F-T:6]N($AO<F1E7T9O<FU?4V]R=&5R*&EN<W1A;F-E3F%M92P@
M=F%R3F%M92P@:&5A9&5R*0I["B`@("`O*B!3970@=7`@=&AI<R!C;&%S<R!I
M;G-T86YC92!F;W(@9G5N8W1I;VX@8V%L;',@9G)O;2!T:&4@<&%G92X@*B\*
M("`@('1H:7,N7VEN<W1A;F-E3F%M92`](&EN<W1A;F-E3F%M93L*"B`@("!T
M:&ES+E]V87).86UE(#T@=F%R3F%M93L*"B`@("`O*B!3;W)T97(@=F%R:6%B
M;&5S+B`J+PH@("`@=&AI<RY?:&5A9&5R(#T@)R<["B`@("!T:&ES+FUI;DQE
M;F=T:"`](#`["B`@("!I9B`H:&5A9&5R("$]("<G*2!["B`@("`@("`@=&AI
M<RY?:&5A9&5R(#T@:&5A9&5R.PH@("`@("`@('1H:7,N;6EN3&5N9W1H(#T@
M,3L*("`@('T*("`@('1H:7,N<V]R=&5R3&ES="`](&1O8W5M96YT+F=E=$5L
M96UE;G1">4ED*'1H:7,N7W9A<DYA;64@*R`G6VQI<W1=)RD["B`@("!T:&ES
M+G-O<G1E<D%R<F%Y(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H=&AI<RY?
M=F%R3F%M92`K("=;87)R87E=)RD["@H@("`@=&AI<RYD97-E;&5C=$AE861E
M<B`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!I9B`H=&AI<RY?:&5A9&5R
M("$]("<G*2!["B`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES=%LP72YS96QE
M8W1E9"`](&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("!T:&ES+G-E=$AI
M9&1E;B`](&9U;F-T:6]N*"D*("`@('L*("`@("`@("!V87(@=&UP07)R87D@
M/2!N97<@07)R87DH*3L*"B`@("`@("`@9F]R("AV87(@:2`]('1H:7,N;6EN
M3&5N9W1H.R!I(#P@=&AI<RYS;W)T97),:7-T+FQE;F=T:#L@:2LK*2!["B`@
M("`@("`@("`@(&EF("AT:&ES+G-O<G1E<DQI<W1;:5TN=F%L=64I('L*("`@
M("`@("`@("`@("`@('1M<$%R<F%Y6VD@+2!T:&ES+FUI;DQE;F=T:%T@/2!T
M:&ES+G-O<G1E<DQI<W1;:5TN=F%L=64["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@('1H:7,N<V]R=&5R07)R87DN=F%L=64@/2!T;7!!<G)A
M>2YJ;VEN*")<="(I.PH@("`@?0H*("`@('1H:7,N;6]V94-O;'5M;E5P(#T@
M9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('9A<B!S96P@/2!T:&ES+G-O<G1E
M<DQI<W0N<V5L96-T961);F1E>#L*"B`@("`@("`@:68@*'-E;"`\/2!T:&ES
M+FUI;DQE;F=T:"!\?"!T:&ES+G-O<G1E<DQI<W0N;&5N9W1H(#P]('1H:7,N
M;6EN3&5N9W1H("L@,2D@<F5T=7)N.PH*("`@("`@("`O*B!$97-E;&5C="!E
M=F5R>71H:6YG(&)U="!T:&4@9FER<W0@<V5L96-T960@:71E;2X@*B\*("`@
M("`@("!T:&ES+G-O<G1E<DQI<W0N<V5L96-T961);F1E>"`]('-E;#L*("`@
M("`@("!V87(@=7`@/2!T:&ES+G-O<G1E<DQI<W1;<V5L72YV86QU93L*"B`@
M("`@("`@=&UP(#T@;F5W($%R<F%Y*"D["B`@("`@("`@9F]R("AI(#T@=&AI
M<RYM:6Y,96YG=&@[(&D@/"!T:&ES+G-O<G1E<DQI<W0N;&5N9W1H.R!I*RLI
M('L*("`@("`@("`@("`@=&UP6VD@+2!T:&ES+FUI;DQE;F=T:%T@/2!N97<@
M3W!T:6]N*'1H:7,N<V]R=&5R3&ES=%MI72YT97AT+"!T:&ES+G-O<G1E<DQI
M<W1;:5TN=F%L=64I"B`@("`@("`@?0H*("`@("`@("!F;W(@*&D@/2`P.R!I
M(#P@=&UP+FQE;F=T:#L@:2LK*2!["B`@("`@("`@("`@(&EF("AI("L@=&AI
M<RYM:6Y,96YG=&@@/3T@<V5L("T@,2D@>PH@("`@("`@("`@("`@("`@=&AI
M<RYS;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@/2!T;7!;:2`K(#%=
M.PH@("`@("`@("`@("!](&5L<V4@:68@*&D@*R!T:&ES+FUI;DQE;F=T:"`]
M/2!S96PI('L*("`@("`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES=%MI("L@
M=&AI<RYM:6Y,96YG=&A=(#T@=&UP6VD@+2`Q73L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@('1H:7,N<V]R=&5R3&ES=%MI("L@=&AI
M<RYM:6Y,96YG=&A=(#T@=&UP6VE=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!T:&ES+G-O<G1E<DQI<W0N<V5L96-T961);F1E>"`]('-E
M;"`M(#$["@H@("`@("`@('1H:7,N<V5T2&ED9&5N*"D["B`@("!]"@H@("`@
M=&AI<RYM;W9E0V]L=6UN1&]W;B`](&9U;F-T:6]N*"D*("`@('L*("`@("`@
M("!V87(@<V5L(#T@=&AI<RYS;W)T97),:7-T+G-E;&5C=&5D26YD97@["@H@
M("`@("`@(&EF("AS96P@/3T@+3$@?'P@<V5L(#T]('1H:7,N<V]R=&5R3&ES
M="YL96YG=&@@+2`Q*2!R971U<FX["@H@("`@("`@("\J($1E<V5L96-T(&5V
M97)Y=&AI;F<@8G5T('1H92!F:7)S="!S96QE8W1E9"!I=&5M+B`J+PH@("`@
M("`@('1H:7,N<V]R=&5R3&ES="YS96QE8W1E9$EN9&5X(#T@<V5L.PH@("`@
M("`@('9A<B!D;W=N(#T@=&AI<RYS;W)T97),:7-T6W-E;%TN=F%L=64["@H@
M("`@("`@('1M<"`](&YE=R!!<G)A>2@I.PH@("`@("`@(&9O<B`H:2`]('1H
M:7,N;6EN3&5N9W1H.R!I(#P@=&AI<RYS;W)T97),:7-T+FQE;F=T:#L@:2LK
M*2!["B`@("`@("`@("`@('1M<%MI("T@=&AI<RYM:6Y,96YG=&A=(#T@;F5W
M($]P=&EO;BAT:&ES+G-O<G1E<DQI<W1;:5TN=&5X="P@=&AI<RYS;W)T97),
M:7-T6VE=+G9A;'5E*0H@("`@("`@('T*"B`@("`@("`@9F]R("AI(#T@,#L@
M:2`\('1M<"YL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!I9B`H:2`K('1H
M:7,N;6EN3&5N9W1H(#T]('-E;"D@>PH@("`@("`@("`@("`@("`@=&AI<RYS
M;W)T97),:7-T6VD@*R!T:&ES+FUI;DQE;F=T:%T@/2!T;7!;:2`K(#%=.PH@
M("`@("`@("`@("!](&5L<V4@:68@*&D@*R!T:&ES+FUI;DQE;F=T:"`]/2!S
M96P@*R`Q*2!["B`@("`@("`@("`@("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K
M('1H:7,N;6EN3&5N9W1H72`]('1M<%MI("T@,5T["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!T:&ES+G-O<G1E<DQI<W1;:2`K('1H
M:7,N;6EN3&5N9W1H72`]('1M<%MI73L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@=&AI<RYS;W)T97),:7-T+G-E;&5C=&5D26YD97@@/2!S
M96P@*R`Q.PH*("`@("`@("!T:&ES+G-E=$AI9&1E;B@I.PH@("`@?0I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VIS+V9O<FU?:&5L<&5R<RYJ<P``````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q,34U-"`Q,#4Q-30S-#$S-B`P,C$R,#(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RHJ
M"B`J($IA=F%S8W)I<'0@=&\@861D(&5V96YT<R!T;R!F;W)M(&5L96UE;G1S
M"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O9F]R;5]H96QP97)S+FIS+'8@,2XS
M+C0N-B`R,#`V+S`S+S(T(#`U.C$W.C4Y(&-H=6-K($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`R,#`T+3(P,#8@36%T="!+>6YA<W1O;B`\;6%T=$!K>6YX+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*+RHJ"B`J($%D9',@=&AE(&=I=F5N(&5V
M96YT('1O(&%N(&5L96UE;G0N($EF('1H92!E;&5M96YT(&%L<F5A9'D@:&%S
M"B`J('-C<FEP="!F;W(@=&AE(&5V96YT+"!T:&4@;F5W(&5V96YT(&ES(&%P
M<&5N9&5D+@H@*@H@*B!`<&%R86T@;V)J96-T(&5L96UE;G0@("!4:&4@96QE
M;65N="!T;R!A9&0@=&AE(&5V96YT('1O+@H@*B!`<&%R86T@<W1R:6YG(&5V
M96YT("`@("!4:&4@;F%M92!O9B!T:&4@979E;G0N"B`J($!P87)A;2!S=')I
M;F=\9G5N8W1I;VX@9G5N8W1I;VX@(%1H92!J879A<V-R:7!T('1O(&5X96-U
M=&4N"B`J+PIF=6YC=&EO;B!A9&1%=F5N="AE;&5M96YT+"!E=F5N="P@8V]D
M92D*>PH@("`@:68@*"%E;&5M96YT*2!["B`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@?0H*("`@("\O($%S<VEG;B!N97<@86YO;GEM;W5S(&9U;F-T:6]N
M(&EF('=E)W)E('!A<W-E9"!A(&IS('-T<FEN9PH@("`@+R\@:6YS=&5A9"!O
M9B!A(&9U;F-T:6]N(')E9F5R96YC92X*("`@(&EF("AT>7!E;V8@8V]D92`]
M/2`G<W1R:6YG)RD@>PH@("`@("`@(&-O9&4@/2!N97<@1G5N8W1I;VXH8V]D
M92D["B`@("!]"@H@("`@:68@*&5L96UE;G0N861D179E;G1,:7-T96YE<BD@
M>PH@("`@("`@(&5L96UE;G0N861D179E;G1,:7-T96YE<BAE=F5N="YR97!L
M86-E*"]O;B\L("<G*2P@8V]D92P@9F%L<V4I.PH@("`@?2!E;'-E(&EF("AE
M;&5M96YT+F%T=&%C:$5V96YT*2!["B`@("`@("`@96QE;65N="YA='1A8VA%
M=F5N="AE=F5N="P@8V]D92D["B`@("!](&5L<V4@:68@*&5L96UE;G0N;VYL
M;V%D("$](&YU;&PI('L*("`@("`@("!V87(@3VQD179E;G0@/2!E;&5M96YT
M6V5V96YT73L*("`@("`@("!N97=#;V1E(#T@1G5N8W1I;VXH92D*("`@("`@
M("!["B`@("`@("`@("`@(&]L9$5V96YT*&4I.PH@("`@("`@("`@("!C;V1E
M*"D["B`@("`@("`@?3L*("`@("`@("!E;&5M96YT6V5V96YT72`](&YE=T-O
M9&4["B`@("!](&5L<V4@>PH@("`@("`@(&5L96UE;G1;979E;G1=(#T@8V]D
M93L*("`@('T*"B`@("!R971U<FX@=')U93L*?0H*+RHJ"B`J(%)E='5R;G,@
M9VEV96X@=F%L=64@87,@82!N=6UB97(L(&]R('IE<F\@:68@3F%.+@H@*@H@
M*B!`<&%R86T@;6EX960@('9A;`H@*@H@*B!`<F5T=7)N(&YU;6)E<@H@*B\*
M9G5N8W1I;VX@=&].=6UB97(H=F%L*0I["B`@("!I9B`H:7-.84XH=F%L*2D@
M>PH@("`@("`@(')E='5R;B`P.PH@("`@?2!E;'-E('L*("`@("`@("!R971U
M<FX@3G5M8F5R*'9A;"D["B`@("!]"GT*"B\J*@H@*B!3971S('1H92!E;F%B
M;&5D('-T871E(&]F(&]N92!E;&5M96YT(&)A<V5D(&]N('1H92!V86QU97,@
M;V8@86YO=&AE<BX*("H*("H@5&%K97,@9F]U<B!O<B!M;W)E(&%R9W5M96YT
M<RP@:6X@=&AE(&9O<FTZ"B`J("`@8VAE8VM%;F%B;&5D*'-O=7)C92P@=&%R
M9V5T+"!T<G5E+"!V86QU93$L('9A;'5E,BP@=F%L=64S+BXN*0H@*@H@*B!`
M<&%R86T@;V)J96-T("`@5&AE(&5L96UE;G0@=&\@8VAE8VL*("H@0'!A<F%M
M('-T<FEN9R`@(%1H92!E;&5M96YT('1O(&5N86)L92]D:7-A8FQE"B`J($!P
M87)A;2!B;V]L96%N("!7:&5T:&5R('1O(&5N86)L92!O<B!D:7-A8FQE('1H
M92!T87)G970*("H@0'!A<F%M(&UI>&5D("`@(%1H92!V86QU92!T;R!C:&5C
M:R!A9V%I;G-T"B`J+PIF=6YC=&EO;B!C:&5C:T5N86)L960H*0I["B`@("!I
M9B`H87)G=6UE;G1S+FQE;F=T:"`^(#(I('L*("`@("`@("!O8FI3<F,@/2!A
M<F=U;65N='-;,%T["B`@("`@("`@;V)J5&%R9V5T(#T@;V)J4W)C+F9O<FTN
M96QE;65N='-;87)G=6UE;G1S6S%=73L*("`@("`@("!E;F%B;&5D(#T@87)G
M=6UE;G1S6S)=.PH@("`@("`@('1O9V=L92`](&9A;'-E.PH@("`@("`@(&EF
M("AO8FI487)G970I('L*("`@("`@("`@("`@<W=I=&-H("AO8FI3<F,N='EP
M92YT;TQO=V5R0V%S92@I*2!["B`@("`@("`@("`@(&-A<V4@)W-E;&5C="UO
M;F4G(#H*("`@("`@("`@("`@("`@('9A;"`](&]B:E-R8RYO<'1I;VYS6V]B
M:E-R8RYS96QE8W1E9$EN9&5X72YV86QU93L*("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@8V%S92`G<V5L96-T+6UU;'1I<&QE)R`Z"B`@
M("`@("`@("`@("`@("!V86P@/2!N97<@07)R87DH*3L*("`@("`@("`@("`@
M("`@(&-O=6YT(#T@,#L*("`@("`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`P
M.R!I(#P@;V)J4W)C+FQE;F=T:#L@*RMI*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&]B:E-R8RYO<'1I;VYS6VE=+G-E;&5C=&5D*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@('9A;%MC;W5N=%T@/2!O8FI3<F,N;W!T:6]N<UMI
M72YV86QU93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@
M)V-H96-K8F]X)R`Z"B`@("`@("`@("`@("`@("!I9B`H;V)J4W)C+F-H96-K
M960I('L*("`@("`@("`@("`@("`@("`@("!V86P@/2!O8FI3<F,N=F%L=64[
M"B`@("`@("`@("`@("`@("`@("`@=&]G9VQE(#T@=')U93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M9&5F875L="`Z"B`@("`@("`@("`@("`@("!V86P@/2!O8FI3<F,N=F%L=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&9O<B`H=F%R(&D@/2`S.R!I
M(#P@87)G=6UE;G1S+FQE;F=T:#L@*RMI*2!["B`@("`@("`@("`@("`@("!I
M9B`H='EP96]F*'9A;"D@/3T@)V]B:F5C="<@)B8@*&%R9W5M96YT<UMI72!I
M;B!V86PI*2!["B`@("`@("`@("`@("`@("`@("`@=&]G9VQE(#T@=')U93L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@('T@
M96QS92!I9B`H87)G=6UE;G1S6VE=(#T]('9A;"D@>PH@("`@("`@("`@("`@
M("`@("`@('1O9V=L92`]('1R=64["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&]B:E1A<F=E="YD:7-A8FQE9"`]('1O9V=L92`_("%E;F%B;&5D(#H@
M96YA8FQE9#L*("`@("`@("`@("`@:68@*"%O8FI487)G970N9&ES86)L960I
M('L*("`@("`@("`@("`@("`@(&]B:E1A<F=E="YF;V-U<R@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@?0I]"@HO*BH*("H@4V5T<R!T:&4@=&%R
M9V5T(&9I96QD('1O('1H92!S=6T@;V8@82!R86YG92!O9B!F:65L9',N"B`J
M"B`J(%1A:V5S('1H<F5E(&]R(&UO<F4@87)G=6UE;G1S+"!I;B!T:&4@9F]R
M;3H*("H@("`@<W5M1FEE;&1S*&9O<FTL('1A<F=E="P@9FEE;&0Q+"!F:65L
M9#(L(&9I96QD,RXN+BD*("H*("H@0'!A<F%M(&]B:F5C="`@5&AE(&9O<FT@
M=&\@8VAE8VL*("H@0'!A<F%M('-T<FEN9R`@5&AE(&YA;64@;V8@=&AE('1A
M<F=E="!E;&5M96YT"B`J($!P87)A;2!S=')I;F<@($]N92!O<B!M;W)E(&9I
M96QD(&YA;65S('1O('-U;0H@*B\*9G5N8W1I;VX@<W5M1FEE;&1S*"D*>PH@
M("`@:68@*&%R9W5M96YT<RYL96YG=&@@/B`R*2!["B`@("`@("`@;V)J1G)M
M(#T@87)G=6UE;G1S6S!=.PH@("`@("`@(&]B:E1A<F=E="`](&]B:D9R;2YE
M;&5M96YT<UMA<F=U;65N='-;,5U=.PH@("`@("`@('-U;2`](#`["B`@("`@
M("`@:68@*&]B:E1A<F=E="D@>PH@("`@("`@("`@("!F;W(@*'9A<B!I(#T@
M,CL@:2`\(&%R9W5M96YT<RYL96YG=&@[("LK:2D@>PH@("`@("`@("`@("`@
M("`@;V)J4W)C(#T@;V)J1G)M+F5L96UE;G1S6V%R9W5M96YT<UMI75T["B`@
M("`@("`@("`@("`@("!I9B`H;V)J4W)C*2!["B`@("`@("`@("`@("`@("`@
M("`@<W=I=&-H("AO8FI3<F,N='EP92YT;TQO=V5R0V%S92@I*2!["B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<V5L96-T+6]N92<Z"B`@("`@("`@("`@
M("`@("`@("`@("`@('-U;2`K/2!T;TYU;6)E<BAO8FI3<F,N;W!T:6]N<UMO
M8FI3<F,N<V5L96-T961);F1E>%TN=F%L=64I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("`@("`@8V%S92`G<V5L
M96-T+6UU;'1I<&QE)R`Z"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H
M=F%R(&H@/2`P.R!J(#P@;V)J4W)C+FQE;F=T:#L@*RMJ*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!S=6T@*ST@=&].=6UB97(H;V)J4W)C+F]P
M=&EO;G-;:ETN=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@
M("`@("!C87-E("=C:&5C:V)O>"<@.@H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H;V)J4W)C+F-H96-K960I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-U;2`K/2!T;TYU;6)E<BAO8FI3<F,N=F%L=64I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH*("`@("`@("`@("`@("`@("`@("!D969A=6QT(#H*("`@("`@("`@
M("`@("`@("`@("`@("`@<W5M("L]('1O3G5M8F5R*&]B:E-R8RYV86QU92D[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!O8FI487)G970N=F%L=64@/2!S=6T[
M"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]J<R]H='1P8VQI96YT+FIS````````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$P-S8@,3`U,34T,S0Q,S8@
M,#(P-C<R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J*@H@*B!*879A<V-R:7!T(&QI8G)A<GD@9F]R('=O<FMI;F<@=VET
M:"!8;6Q(='1P4F5Q=65S="!O8FIE8W1S(&%N9`H@*B!(;W)D92X*("H*("H@
M)$AO<F1E.B!H;W)D92]J<R]H='1P8VQI96YT+FIS+'8@,2XR+C$P+C,@,C`P
M-2\Q,"\Q."`Q,3HS,SHS."!J86X@17AP("0*("H*("H@4V5E('1H92!E;F-L
M;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'
M4$PI+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E
M(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*
M+R\@0V]N<W1R=6-T;W(@9F]R(&=E;F5R:6,@2%144"!C;&EE;G0N"F9U;F-T
M:6]N($A45%!#;&EE;G0H*2![?3L*"B\O($%D9"!M971H;V1S(&%N9"!P<F]P
M97)T:65S(&%S(&%R<F%Y+@I(5%100VQI96YT+G!R;W1O='EP92`]('L*("`@
M('5R;#H@;G5L;"P*"B`@("`O+R!);G-T86YC92!O9B!834Q(='1P4F5Q=65S
M="X*("`@(')E<75E<W0Z(&YU;&PL"@H@("`@+R\@57-E9"!T;R!M86ME('-U
M<F4@;75L=&EP;&4@8V%L;',@87)E(&YO="!P;&%C960@=VET:"!T:&4@<V%M
M90H@("`@+R\@8VQI96YT(&]B:F5C="!W:&EL92!A;F]T:&5R(&EN('!R;V=R
M97-S+@H@("`@8V%L;$EN4')O9W)E<W,Z(&9A;'-E+`H*("`@("\O(%1H92!U
M<V5R(&1E9FEN960@:&%N9&QE<B`M('-E92!->4AA;F1L97(@8F5L;W<N"B`@
M("!U<V5R:&%N9&QE<CH@;G5L;"P*"B`@("!I;FET.B!F=6YC=&EO;BAU<FPI
M"B`@("!["B`@("`@("`@=&AI<RYU<FP@/2!U<FP["@H@("`@("`@('1R>2![
M"B`@("`@("`@("`@("\O($UO>FEL;&$L(%-A9F%R:2X*("`@("`@("`@("`@
M=&AI<RYR97%U97-T(#T@;F5W(%A-3$AT='!297%U97-T*"D["B`@("`@("`@
M?2!C871C:"`H92D@>PH@("`@("`@("`@("`O+R!)12X*("`@("`@("`@("`@
M=F%R($U36$U,7UA-3$A45%!?4%)/1TE$4R`](&YE=R!!<G)A>2@*("`@("`@
M("`@("`@("`@(")-4UA-3#(N6$U,2%144"XT+C`B+`H@("`@("`@("`@("`@
M("`@(DU36$U,,BY834Q(5%10+C,N,"(L"B`@("`@("`@("`@("`@("`B35-8
M34PR+EA-3$A45%`B+`H@("`@("`@("`@("`@("`@(DUI8W)O<V]F="Y834Q(
M5%10(@H@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@=F%R('-U8V-E
M<W,@/2!F86QS93L*("`@("`@("`@("`@9F]R("AV87(@:2`](#`[(&D@/"!-
M4UA-3%]834Q(5%107U!23T=)1%,N;&5N9W1H("8F("%S=6-C97-S.R!I*RLI
M('L*("`@("`@("`@("`@("`@('1R>2!["B`@("`@("`@("`@("`@("`@("`@
M=&AI<RYR97%U97-T(#T@;F5W($%C=&EV95A/8FIE8W0H35-834Q?6$U,2%14
M4%]04D]'24136VE=*3L*("`@("`@("`@("`@("`@("`@("!S=6-C97-S(#T@
M=')U93L*("`@("`@("`@("`@("`@('T@8V%T8V@@*&4I('M]"B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"%S=6-C97-S*2!["B`@("`@("`@("`@
M("`@("!T:')O=R`B56YA8FQE('1O(&-R96%T92!834Q(='1P4F5Q=65S="XB
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2P*"B`@("`O+R!(86YD
M;&5R(&%R9W5M96YT(&ES(&$@=7-E<B!D969I;F5D(&]B:F5C="!T;R!B92!C
M86QL960N"B`@("!A<WEN8T=%5#H@9G5N8W1I;VXH:&%N9&QE<BD*("`@('L*
M("`@("`@("`O+R!$96=R861E(&]R('-O;64@<W5C:"X*("`@("`@("!I9B`H
M(71H:7,N<F5Q=65S="D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?3L*"B`@("`@("`@+R\@4')E=F5N="!M=6QT:7!L92!C86QL<PH@
M("`@("`@(&EF("AT:&ES+F-A;&Q);E!R;V=R97-S*2!["B`@("`@("`@("`@
M('1H<F]W(")#86QL(&EN('!R;V=R97-S(CL*("`@("`@("!].PH*("`@("`@
M("!T:&ES+F-A;&Q);E!R;V=R97-S(#T@=')U93L*"B`@("`@("`@=&AI<RYU
M<V5R:&%N9&QE<B`](&AA;F1L97(["@H@("`@("`@("\O($]P96X@86X@87-Y
M;F,@<F5Q=65S="`M('1H:7)D(&%R9W5M96YT(&UA:V5S(&ET"B`@("`@("`@
M+R\@87-Y;F-H<F]N;W5S+@H@("`@("`@('1H:7,N<F5Q=65S="YO<&5N*"='
M150G+"!T:&ES+G5R;"P@=')U92D["@H@("`@("`@("\O($AA=F4@=&\@87-S
M:6=N(")T:&ES(B!T;R!A('9A<FEA8FQE+@H@("`@("`@('9A<B!S96QF(#T@
M=&AI<SL*"B`@("`@("`@+R\@07-S:6=N(&$@8VQO<W5R92!T;R!T:&4@;VYR
M96%D>7-T871E8VAA;F=E(&-A;&QB86-K+@H@("`@("`@('1H:7,N<F5Q=65S
M="YO;G)E861Y<W1A=&5C:&%N9V4@/2!F=6YC=&EO;B@I"B`@("`@("`@>PH@
M("`@("`@("`@("!S96QF+G-T871E0VAA;F=E0V%L;&)A8VLH<V5L9BD["B`@
M("`@("`@?0H*("`@("`@("!T:&ES+G)E<75E<W0N<V5N9"AN=6QL*3L*("`@
M('TL"@H@("`@<W1A=&5#:&%N9V5#86QL8F%C:SH@9G5N8W1I;VXH8VQI96YT
M*0H@("`@>PH@("`@("`@('-W:71C:"`H8VQI96YT+G)E<75E<W0N<F5A9'E3
M=&%T92D@>PH@("`@("`@("`@("`O+R!297%U97-T(&YO="!Y970@;6%D92X*
M("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("!T<GD@>PH@("`@("`@
M("`@("`@("`@8VQI96YT+G5S97)H86YD;&5R+F]N26YI="@I.PH@("`@("`@
M("`@("!](&-A=&-H("AE*2![("\J($AA;F1L97(@;65T:&]D(&YO="!D969I
M;F5D+B`J+R!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@
M0V]N=&%C="!E<W1A8FQI<VAE9"!W:71H('-E<G9E<B!B=70@;F]T:&EN9R!D
M;W=N;&]A9&5D"B`@("`@("`@("`@("\O('EE="X*("`@("`@("`@("`@8V%S
M92`R.@H@("`@("`@("`@("!T<GD@>PH@("`@("`@("`@("`@("`@<W1A='5S
M(#T@8VQI96YT+G)E<75E<W0N<W1A='5S.PH@("`@("`@("`@("`@("`@+R\@
M0VAE8VL@9F]R($A45%`@<W1A='5S(#(P,"X*("`@("`@("`@("`@("`@(&EF
M("AS=&%T=7,@(3T@,C`P*2!["B`@("`@("`@("`@("`@("`@("`@8VQI96YT
M+G5S97)H86YD;&5R+F]N17)R;W(H"B`@("`@("`@("`@("`@("`@("`@("`@
M('-T871U<RP*("`@("`@("`@("`@("`@("`@("`@("`@8VQI96YT+G)E<75E
M<W0N<W1A='5S5&5X=`H@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`@("`@("`@("`@("`O+R!!8F]R="!T:&4@<F5Q=65S="X*("`@("`@
M("`@("`@("`@("`@("!C;&EE;G0N<F5Q=65S="YA8F]R="@I.PH*("`@("`@
M("`@("`@("`@("`@("`O+R!#86QL(&YO(&QO;F=E<B!I;B!P<F]G<F5S<RX*
M("`@("`@("`@("`@("`@("`@("!C;&EE;G0N8V%L;$EN4')O9W)E<W,@/2!F
M86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!C871C:"`H
M92D@>PH@("`@("`@("`@("`@("`@+RH@35-834Q(5%10(#,N>"L@9&]E<VXG
M="!P;W!U;&%T92!S=&%T=7,@=6YT:6P*("`@("`@("`@("`@("`@("`J(')E
M861Y4W1A=&4@-"X@*B\*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A
M:SL*"B`@("`@("`@("`@("\O($-A;&QE9"!M=6QT:7!L92!T:6UE<R!W:&EL
M92!D;W=N;&]A9"!I<R!I;B!P<F]G<F5S<RX*("`@("`@("`@("`@8V%S92`S
M.@H@("`@("`@("`@("`O+R!.;W1I9GD@=7-E<B!H86YD;&5R(&]F(&1O=VYL
M;V%D('!R;V=R97-S+@H@("`@("`@("`@("!T<GD@>PH@("`@("`@("`@("`@
M("`@+R\@1V5T('1H92!T;W1A;"!C;VYT96YT(&QE;F=T:"`H=7-E9G5L('1O
M('=O<FL*("`@("`@("`@("`@("`@("\O(&]U="!H;W<@;75C:"!H87,@8F5E
M;B!D;W=N;&]A9&5D*2X*("`@("`@("`@("`@("`@('1R>2!["B`@("`@("`@
M("`@("`@("`@("`@=F%R(&-O;G1E;G1,96YG=&@@/0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;&EE;G0N<F5Q=65S="YG971297-P;VYS94AE861E<B@B
M0V]N=&5N="U,96YG=&@B*3L*("`@("`@("`@("`@("`@('T@8V%T8V@@*&4I
M('L*("`@("`@("`@("`@("`@("`@("!V87(@8V]N=&5N=$QE;F=T:"`]($YA
M3CL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!#86QL
M('1H92!P<F]G<F5S<R!H86YD;&5R('=I=&@@=VAA="!W92=V92!G;W0N"B`@
M("`@("`@("`@("`@("!C;&EE;G0N=7-E<FAA;F1L97(N;VY0<F]G<F5S<R@*
M("`@("`@("`@("`@("`@("`@("!C;&EE;G0N<F5Q=65S="YR97-P;VYS951E
M>'0L"B`@("`@("`@("`@("`@("`@("`@8V]N=&5N=$QE;F=T:`H@("`@("`@
M("`@("`@("`@("`@("D["@H@("`@("`@("`@("!](&-A=&-H("AE*2![("\J
M($AA;F1L97(@;65T:&]D(&YO="!D969I;F5D+B`J+R!]"B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("`@("`@+R\@1&]W;FQO860@8V]M<&QE=&4N"B`@
M("`@("`@("`@(&-A<V4@-#H*("`@("`@("`@("`@=')Y('L*("`@("`@("`@
M("`@("`@(&-L:65N="YU<V5R:&%N9&QE<BYO;DQO860H8VQI96YT+G)E<75E
M<W0N<F5S<&]N<V5497AT*3L*("`@("`@("`@("`@?2!C871C:"`H92D@>PH@
M("`@("`@("`@("`@("`@+RH@2&%N9&QE<B!M971H;V0@;F]T(&1E9FEN960N
M("HO"B`@("`@("`@("`@('T@9FEN86QL>2!["B`@("`@("`@("`@("`@("`O
M+R!#86QL(&YO(&QO;F=E<B!I;B!P<F]G<F5S<RX*("`@("`@("`@("`@("`@
M(&-L:65N="YC86QL26Y0<F]G<F5S<R`](&9A;'-E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O:G,O:65%<V-'=6%R9"YJ<P``````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#0Q(#$P-3$U
M-#,T,3,V(#`R,#4R-``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````O*BH*("H@2F%V87-C<FEP="!C;V1E(&9O<B!A='1A8VAI
M;F<@86X@;VYK97ED;W=N(&QI<W1E;F5R('1O('1E>'1A<F5A(&%N9`H@*B!T
M97AT(&EN<'5T(&5L96UE;G1S('1O('!R979E;G0@;&]S<R!O9B!D871A('=H
M96X@=&AE('5S97(@:&ET<R!T:&4*("H@15-#(&ME>2X*("H*("H@)$AO<F1E
M.B!H;W)D92]J<R]I945S8T=U87)D+FIS+'8@,2XQ+C(N,R`R,#`U+S$P+S$X
M(#$Q.C,S.C,X(&IA;B!%>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I
M;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF
M('EO=2!D:60@;F]T"B`J(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO
M+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*B!4:&ES
M(&-O9&4@:7,@;VYL>2!R96QE=F%N="!F;W(@244N(%1H97)E9F]R92!T<GD@
M;F]T('1O(&1O(&%N>71H:6YG"B`J(&EF('1H92!U<V5R(&ES;B=T('5S:6YG
M($E%+"!E=F5N(&EF('1H:7,@<V-R:7!T(&ES(&EN8VQU9&5D+B!4:&ES"B`J
M(&-H96-K('=I;&P@8V%T8V@@<V]M92!B<F]W<V5R<R!T:&%T(&%R92!N;W0@
M244@8G5T(&ED96YT:69Y"B`J('1H96US96QV97,@87,@244N($AO<&5F=6QL
M>2!I9B!T:&5Y('!A<W,@=&AR;W5G:"!T:&5Y('-U<'!O<G0@=VAA=`H@*B!)
M12!S=7!P;W)T<RX@*B\*:68@*&YA=FEG871O<BYA<'!697)S:6]N+FEN9&5X
M3V8H)TU3244G*2`A/2`M,2`F)B!D;V-U;65N="YA;&PI('L*("`@("\J(%=E
M(&1O(&5V97)Y=&AI;F<@;VYL;V%D('-O('1H870@=&AE(&5N=&ER92!D;V-U
M;65N="!I<R!P<F5S96YT"B`@("`@*B!B969O<F4@=V4@<W1A<G0@<V5A<F-H
M:6YG(&ET+B`J+PH@("`@=VEN9&]W+F%T=&%C:$5V96YT*"=O;FQO860G+"!G
M=6%R9"D["GT*"B\J*@H@*B!&:6YD<R!A;&P@=&5X="!I;G!U=',@*&EN<'5T
M('1Y<&4](G1E>'0B*2!A;F0@=&5X=&%R96$@=&%G<RP@86YD"B`J(&%T=&%C
M:&5S('1H92!O;FME>61O=VX@;&ES=&5N97(@=&\@=&AE;2!T;R!A=F]I9"!%
M4T,@8VQE87)I;F<@=&AE"B`J('1E>'0N"B`J+PIF=6YC=&EO;B!G=6%R9"@I
M"GL*("`@("\J($9I;F1S(&%L;"!T97AT87)E87,N("HO"B`@("!V87(@=&5X
M=&%R96%S(#T@9&]C=6UE;G0N86QL+G1A9W,H)U1%6%1!4D5!)RD["B`@("!F
M;W(@*'9A<B!I(#T@,#L@:2`\('1E>'1A<F5A<RYL96YG=&@[(&DK*RD@>PH@
M("`@("`@('1E>'1A<F5A<UMI72YA='1A8VA%=F5N="@G;VYK97ED;W=N)RP@
M9&ES86)L945S8V%P92D["B`@("!]"@H@("`@+RH@1FEN9',@7V%L;%\@/&EN
M<'5T/B!T86=S+B`J+PH@("`@=F%R(&EN<'5T<R`](&1O8W5M96YT+F%L;"YT
M86=S*"=)3E!55"<I.PH@("`@9F]R("AV87(@:2`](#`[(&D@/"!I;G!U=',N
M;&5N9W1H.R!I*RLI('L*("`@("`@("`O*B!/;FQY(&%T=&%C:"!T;R`\:6YP
M=70@='EP93TB=&5X="(^('1A9W,N("HO"B`@("`@("`@:68@*&EN<'5T<UMI
M72YT>7!E(#T]("=T97AT)RD@>PH@("`@("`@("`@("!I;G!U='-;:5TN871T
M86-H179E;G0H)V]N:V5Y9&]W;B<L(&1I<V%B;&5%<V-A<&4I.PH@("`@("`@
M('T*("`@('T*?0H*+RHJ"B`J(%)E='5R;G,@9F%L<V4@:68@=&AE('5S97(@
M:&ET('1H92!%4T,@:V5Y+"!P<F5V96YT:6YG($E%(&9R;VT*("H@8FQA;FMI
M;F<@=&AE(&9I96QD+B!/=&AE<G=I<V4@<F5T=7)N<R!T<G5E+@H@*@H@*B!R
M971U<FX@8F]O;&5A;B`@5VAE=&AE<B!O<B!N;W0@=&\@86QL;W<@=&AE(&ME
M>2!E=F5N="X*("HO"F9U;F-T:6]N(&1I<V%B;&5%<V-A<&4H*0I["B`@("!R
M971U<FX@=VEN9&]W+F5V96YT+FME>4-O9&4@(3T@,C<["GT*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+VIS+V9O<FU?<V5C=&EO;G,N:G,`````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S4R-"`Q,#4Q-30S-#$S
M-B`P,C$S-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+RHJ"B`J($AO<F1E($9O<FT@4V5C=&EO;G,@2F%V87-C<FEP="!#
M;&%S<PH@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP="!C;&%S<R!F;W(@
M:&%N9&QI;F<@=&%B8F5D('-E8W1I;VYS(&EN($AO<F1E($9O<FUS+@H@*@H@
M*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\;6%R:V]`;V)L
M;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*
M("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS+V9O
M<FU?<V5C=&EO;G,N:G,L=B`Q+C$N,BXR(#(P,#8O,#0O,34@,C(Z,C,Z,S8@
M8VAU8VL@17AP("0*("H*("H@0&%U=&AO<B`@36%R:V\@1&IU:VEC(#QM87)K
M;T!O8FQO+F-O;3X*("H@0'!A8VMA9V4@2&]R9&5?1F]R;0H@*B\*9G5N8W1I
M;VX@2&]R9&5?1F]R;5]396-T:6]N<RAI;G-T86YC94YA;64L(&]P96Y396-T
M:6]N*0I["B`@("`O*B!3970@=7`@=&AI<R!C;&%S<R!I;G-T86YC92!F;W(@
M9G5N8W1I;VX@8V%L;',@9G)O;2!T:&4@<&%G92X@*B\*("`@('1H:7,N7VEN
M<W1A;F-E3F%M92`](&EN<W1A;F-E3F%M93L*"B`@("`O*B!4:&4@8W5R<F5N
M=&QY('-H;W=E9"!S96-T:6]N+B`J+PH@("`@=F%R(%]O<&5N4V5C=&EO;CL*
M"B`@("!T:&ES+G1O9V=L92`](&9U;F-T:6]N*'-E8W1I;VY)9"D*("`@('L*
M("`@("`@("`O*B!'970@=&AE(&-U<G)E;G1L>2!O<&5N('-E8W1I;VX@;V)J
M96-T+B`J+PH@("`@("`@(&]P96Y396-T:6]N260@/2!T:&ES+E]G970H*3L*
M("`@("`@("!I9B`H9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)U]S96-T:6]N
M7R<@*R!O<&5N4V5C=&EO;DED*2D@>PH@("`@("`@("`@("!D;V-U;65N="YG
M971%;&5M96YT0GE)9"@G7W-E8W1I;VY?)R`K(&]P96Y396-T:6]N260I+G-T
M>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("`@("`@?0H@("`@("`@(&1O8W5M
M96YT+F=E=$5L96UE;G1">4ED*"=?=&%B7R<@*R!O<&5N4V5C=&EO;DED*2YC
M;&%S<TYA;64@/2!N=6QL.PH*("`@("`@("`O*B!'970@=&AE(&YE=VQY(&]P
M96YE9"!S96-T:6]N(&]B:F5C="X@*B\*("`@("`@("!I9B`H9&]C=6UE;G0N
M9V5T16QE;65N=$)Y260H)U]S96-T:6]N7R<@*R!S96-T:6]N260I*2!["B`@
M("`@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=?<V5C=&EO;E\G
M("L@<V5C=&EO;DED*2YS='EL92YD:7-P;&%Y(#T@)V)L;V-K)SL*("`@("`@
M("!]"B`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)U]T86)?)R`K
M('-E8W1I;VY)9"DN8VQA<W-.86UE(#T@)V%C=&EV951A8B<["@H@("`@("`@
M("\J(%-T;W)E('1H92!N97=L>2!O<&5N960@<V5C=&EO;BX@*B\*("`@("`@
M("!T:&ES+E]S970H<V5C=&EO;DED*3L*("`@('T*"B`@("!T:&ES+E]G970@
M/2!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N('1H:7,N7V]P96Y3
M96-T:6]N.PH@("`@?0H*("`@('1H:7,N7W-E="`](&9U;F-T:6]N*'-E8W1I
M;VY)9"D*("`@('L*("`@("`@("!V87(@9F]R;2`](&5V86PH)V1O8W5M96YT
M+B<@*R!T:&ES+E]I;G-T86YC94YA;64I.PH@("`@("`@(&EF("AF;W)M("$]
M(&YU;&P@)B8*("`@("`@("`@("`@='EP96]F(&9O<FTN7U]F;W)M3W!E;E-E
M8W1I;VX@(3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@("`@9F]R;2Y?7V9O
M<FU/<&5N4V5C=&EO;BYV86QU92`](&5S8V%P92AS96-T:6]N260I.PH@("`@
M("`@('T*("`@("`@("!T:&ES+E]O<&5N4V5C=&EO;B`]('-E8W1I;VY)9#L*
M("`@('T*"B`@("!T:&ES+E]S970H;W!E;E-E8W1I;VXI.PI]"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]J<R]E;G1E<E]K97E?=')A<"YJ<P``````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P,#<@,3`U,34T,S0Q,S8@,#(Q
M-3(P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\J*@H@*B!*879A<V-R:7!T('1O('1R87`@9F]R('1H92!E;G1E<B!K97DN
M"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O96YT97)?:V5Y7W1R87`N:G,L=B`Q
M+C(N,3`N,R`R,#`V+S`U+S`U(#$U.C,S.C,T(&-H=6-K($5X<"`D"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I9"!N;W0*("H@<F5C96EV92!T
M:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P
M;"YH=&UL+@H@*B\*9G5N8W1I;VX@96YT97)?:V5Y7W1R87`H979E;G0I"GL*
M("`@('9A<B!K97D["B`@("!I9B`H979E;G0N:V5Y0V]D92D@>PH@("`@("`@
M(&ME>2`](&5V96YT+FME>4-O9&4["B`@("!](&5L<V4@:68@*&5V96YT+G=H
M:6-H*2!["B`@("`@("`@:V5Y(#T@979E;G0N=VAI8V@["B`@("!](&5L<V4@
M>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("!R971U<FX@*&ME
M>2`]/2`Q,"!\?"!K97D@/3T@,3,I.PI]"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]J<R]H:61E86)L92YJ<P``````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(V,C<@,3`U,34T,S0Q
M,S8@,#(P,C4S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J*@H@*B!*879A<V-R:7!T(&]B:F5C="!F;W(@:&ED:6YG("8@
M<VAO=VEN9R!$3TT@96QE;65N=',N"B`J"B`J("1(;W)D93H@:&]R9&4O:G,O
M:&ED96%B;&4N:G,L=B`Q+C(@,C`P-"\Q,"\Q.2`Q.3HP.#HU,R!C:'5C:R!%
M>'`@)`H@*@H@*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@
M;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN($EF('EO=2!D:60@;F]T"B`J
M(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O
M<'EL969T+VQG<&PN:'1M;"X*("HO"@HO*BH*("H@0V]N<W1R=6-T;W(@9F]R
M($AO<F1E($AI9&5A8FQE($1/32!E;&5M96YT<RX*("H*("H@0'!A<F%M(&ED
M("`@("`@("`@("`@5&AE($1/32!I9"!O9B!T:&4@96QE;65N="!W92!W86YT
M('1O('=O<FL@=VET:"X*("H@0'!A<F%M(&1I<W!L87E3='EL92`@5VAA="!D
M:7-P;&%Y('-T>6QE('-H;W=S('1H:7,@96QE;65N=#\@1&5F875L=',*("H@
M("`@("`@("`@("`@("`@("`@("`@=&\@)V)L;V-K)RX*("HO"F9U;F-T:6]N
M($AO<F1E7TAI9&5A8FQE*"D*>PH@("`@=&AI<RYI9"`](&%R9W5M96YT<ULP
M73L*("`@('1H:7,N96QE;65N="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED
M*'1H:7,N:60I.PH*("`@(&EF("AA<F=U;65N=',N;&5N9W1H(#T](#(I('L*
M("`@("`@("!T:&ES+F1I<W!L87E3='EL92`](&%R9W5M96YT<ULQ73L*("`@
M('T*?3L*"DAO<F1E7TAI9&5A8FQE+G!R;W1O='EP92`]('L*"B`@("`O*BH*
M("`@("`J($ED(&]F('1H92!$3TT@96QE;65N="X*("`@("`J($!V87(@:60*
M("`@("`J+PH@("`@:60Z(&YU;&PL"@H@("`@+RHJ"B`@("`@*B!$3TT@96QE
M;65N="!R969E<F5N8V4N"B`@("`@*B!`=F%R(&5L96UE;G0*("`@("`J+PH@
M("`@96QE;65N=#H@;G5L;"P*"B`@("`O*BH*("`@("`J(%1H92!D:7-P;&%Y
M('-T>6QE('1O('5S92X@1&5F875L="!I<R`G8FQO8VLG+@H@("`@("H@0'9A
M<B!D:7-P;&%Y4W1Y;&4*("`@("`J+PH@("`@9&ES<&QA>5-T>6QE.B`G8FQO
M8VLG+`H*("`@('-H;W=N.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@<F5T
M=7)N('1H:7,N96QE;65N="YS='EL92YD:7-P;&%Y("$]("=N;VYE)SL*("`@
M('TL"@H@("`@:&ED93H@9G5N8W1I;VXH*0H@("`@>PH@("`@("`@('1H:7,N
M96QE;65N="YS='EL92YD:7-P;&%Y(#T@)VYO;F4G.PH@("`@("`@(')E='5R
M;B!T:&ES.PH@("`@?2P*"B`@("!S:&]W.B!F=6YC=&EO;B@I"B`@("!["B`@
M("`@("`@=&AI<RYE;&5M96YT+G-T>6QE+F1I<W!L87D@/2!T:&ES+F1I<W!L
M87E3='EL93L*("`@("`@("!R971U<FX@=&AI<SL*("`@('TL"@H@("`@=&]G
M9VQE.B!F=6YC=&EO;B@I"B`@("!["B`@("`@("`@<F5T=7)N('1H:7,N<VAO
M=VXH*2`_('1H:7,N:&ED92@I(#H@=&AI<RYS:&]W*"D["B`@("!]"@I]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+W1O;VQT
M:7`N:G,`````````````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P-#(W-"`Q,#4Q-30S-#$S-B`P,C`R,3``(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+RHJ"B`J($AO<F1E(%1O
M;VQT:7`@2F%V87-C<FEP=`H@*@H@*B!0<F]V:61E<R!T:&4@:F%V87-C<FEP
M="!T;R!D:7-P;&%Y('1O;VQT:7!S+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+VIS
M+W1O;VQT:7`N:G,L=B`Q+C(N,3`N,B`R,#`U+S`U+S`Q(#$V.C4S.C,P(&-H
M=6-K($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D
M:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N
M;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IV87(@86-T:79E5&EM96]U
M=#L*"FEF("AT>7!E;V8@9&]C=6UE;G0N8V%P='5R945V96YT<R`A/2`G=6YD
M969I;F5D)RD@>PH@("`@9&]C=6UE;G0N8V%P='5R945V96YT<RA%=F5N="Y-
M3U5314U/5D4I.PH@("`@9&]C=6UE;G0N;VYM;W5S96UO=F4@/2!M;W5S95!O
M<SL*("`@('9A<B!N9718+"!N9719.PI]"@IF=6YC=&EO;B!P;W-8*"D*>PH@
M("`@=&5M<%@@/2!D;V-U;65N="YB;V1Y+G-C<F]L;$QE9G0@*R!E=F5N="YC
M;&EE;G18.PH@("`@:68@*'1E;7!8(#P@,"D@>PH@("`@("`@('1E;7!8(#T@
M,#L*("`@('T*("`@(')E='5R;B!T96UP6#L*?0H*9G5N8W1I;VX@<&]S62@I
M"GL*("`@('1E;7!9(#T@9&]C=6UE;G0N8F]D>2YS8W)O;&Q4;W`@*R!E=F5N
M="YC;&EE;G19.PH@("`@:68@*'1E;7!9(#P@,"D@>PH@("`@("`@('1E;7!9
M(#T@,#L*("`@('T*("`@(')E='5R;B!T96UP63L*?0H*9G5N8W1I;VX@;6]U
M<V50;W,H92D*>PH@("`@;F5T6"`](&4N<&%G95@["B`@("!N9719(#T@92YP
M86=E63L*?0H*9G5N8W1I;VX@=&]O;'1I<%-H;W<H<%@L('!9+"!S<F,I"GL*
M("`@(&EF("AP6"`\(#$I('L*("`@("`@("!P6"`](#$["B`@("!]"B`@("!I
M9B`H<%D@/"`Q*2!["B`@("`@("`@<%D@/2`Q.PH@("`@?0H@("`@:68@*&1O
M8W5M96YT+F=E=$5L96UE;G1">4ED*2!["B`@("`@("`@='0@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G=&]O;'1I<"<I.PH@("`@("`@('1T+G-T>6QE
M+FQE9G0@/2!P6"`K("=P>"<["B`@("`@("`@='0N<W1Y;&4N=&]P(#T@<%D@
M*R`G<'@G.PH@("`@("`@('1T+G-T>6QE+G9I<VEB:6QI='D@/2`G=FES:6)L
M92<["B`@("`@("`@='0N:6YN97)(5$U,(#T@<W)C.PH@("`@?2!E;'-E('L*
M("`@("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YS='EL92YL969T(#T@<%@@
M*R`G<'@G.PH@("`@("`@(&1O8W5M96YT+F%L;"YT;V]L=&EP+G-T>6QE+G1O
M<"`]('!9("L@)W!X)SL*("`@("`@("!D;V-U;65N="YA;&PN=&]O;'1I<"YS
M='EL92YV:7-I8FEL:71Y(#T@)W9I<VEB;&4G.PH@("`@("`@(&1O8W5M96YT
M+F%L;"YT;V]L=&EP+FEN;F5R2%1-3"`]('-R8SL*("`@('T*?0H*9G5N8W1I
M;VX@=&]O;'1I<$-L;W-E*"D*>PH@("`@:68@*&1O8W5M96YT+F=E=$5L96UE
M;G1">4ED*2!["B`@("`@("`@='0@/2!D;V-U;65N="YG971%;&5M96YT0GE)
M9"@G=&]O;'1I<"<I.PH@("`@("`@('1T+G-T>6QE+G9I<VEB:6QI='D@/2`G
M:&ED9&5N)SL*("`@("`@("!T="YI;FYE<DA434P@/2`G)SL*("`@('T@96QS
M92!["B`@("`@("`@9&]C=6UE;G0N86QL+G1O;VQT:7`N<W1Y;&4N=FES:6)I
M;&ET>2`]("=H:61D96XG.PH@("`@("`@(&1O8W5M96YT+F%L;"YT;V]L=&EP
M+FEN;F5R2%1-3"`]("<G.PH@("`@?0H@("`@8VQE87)4:6UE;W5T*&%C=&EV
M951I;65O=70I.PH@("`@=VEN9&]W+G-T871U<R`]("<G.PI]"@IF=6YC=&EO
M;B!T;V]L=&EP3&EN:RAT;V]L=&5X="P@<W1A='5S;&EN92D*>PH@("`@=&5X
M="`]("<\9&EV(&-L87-S/2)T;V]L=&EP(CXG("L@=&]O;'1E>'0@*R`G/"]D
M:78^)SL*("`@(&EF("AT>7!E;V8@9&]C=6UE;G0N8V%P='5R945V96YT<R`A
M/2`G=6YD969I;F5D)RD@>PH@("`@("`@('AP;W,@/2!N9718.PH@("`@("`@
M('EP;W,@/2!N9719.PH@("`@?2!E;'-E('L*("`@("`@("!X<&]S(#T@<&]S
M6"@I.PH@("`@("`@('EP;W,@/2!P;W-9*"D["B`@("!]"B`@("!A8W1I=F54
M:6UE;W5T(#T@<V5T5&EM96]U="@G=&]O;'1I<%-H;W<H>'!O<R`M(#$Q,"P@
M>7!O<R`K(#$U+"!T97AT*3LG+"`S,#`I.PH@("`@=VEN9&]W+G-T871U<R`]
M('-T871U<VQI;F4["GT*"F1O8W5M96YT+G=R:71E*"<\9&EV(&ED/2)T;V]L
M=&EP(B!S='EL93TB<&]S:71I;VXZ86)S;VQU=&4[('9I<VEB:6QI='DZ:&ED
M9&5N.R(^/"]D:78^)RD["@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+VIS+W!O<'5P+FIS````````````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<U,B`Q,#4Q-30S-#$S-B`P,3<V-3<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+RHJ
M"B`J($AO<F1E(%!O<'5P($IA=F%38W)I<'0N"B`J"B`J(%!R;W9I9&5S('1H
M92!J879A<V-R:7!T('1O(&]P96X@<&]P=7`@=VEN9&]W<RX*("H*("H@)$AO
M<F1E.B!H;W)D92]J<R]P;W!U<"YJ<RQV(#$N,BXQ,"XT(#(P,#8O,#(O,3`@
M,3@Z,30Z-30@8VAU8VL@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E9"!F
M:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)
M9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z
M+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PIF=6YC=&EO
M;B!P;W!U<"AU<FPL('=I9'1H+"!H96EG:'0I"GL*("`@(&EF("@A=VED=&@I
M('L*("`@("`@("!W:61T:"`](#8P,#L*("`@('T*("`@(&EF("@A:&5I9VAT
M*2!["B`@("`@("`@:&5I9VAT(#T@-3`P.PH@("`@?0H*("`@('9A<B!N86UE
M(#T@*&YE=R!$871E*"DI+F=E=%1I;64H*3L*("`@('9A<B!P87)A;2`](")T
M;V]L8F%R/6YO+&QO8V%T:6]N/6YO+'-T871U<SUY97,L<V-R;VQL8F%R<SUY
M97,L<F5S:7IA8FQE/7EE<RQW:61T:#TB("L@=VED=&@@*R`B+&AE:6=H=#TB
M("L@:&5I9VAT("L@(BQL969T/3`L=&]P/3`B.PH@("`@=F%R('=I;B`]('=I
M;F1O=RYO<&5N*'5R;"P@;F%M92P@<&%R86TI.PH@("`@:68@*"%W:6XI('L*
M("`@("`@("!A;&5R="@B02!P;W!U<"!W:6YD;W<@8V]U;&0@;F]T(&)E(&]P
M96YE9"X@66]U<B!B<F]W<V5R(&UA>2!B92!B;&]C:VEN9R!P;W!U<',@9F]R
M('1H:7,@87!P;&EC871I;VXN(BD["B`@("!](&5L<V4@>PH@("`@("`@(&EF
M("AT>7!E;V8@=VEN+FYA;64@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@
M("`@=VEN+FYA;64@/2!N86UE.PH@("`@("`@('T*("`@("`@("!I9B`H='EP
M96]F('=I;BYO<&5N97(@/3T@)W5N9&5F:6YE9"<I('L*("`@("`@("`@("`@
M=VEN+F]P96YE<B`]('-E;&8["B`@("`@("`@?0H@("`@?0H*("`@(')E='5R
M;B!W:6X["GT*`````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+VIS+V9O<FU?87-S:6=N+FIS````````````````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#$S,"`Q,#4Q-30S-#$S-B`P
M,C$P,30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````+RHJ"B`J($AO<F1E($9O<FT@07-S:6=N($9I96QD($IA=F%S8W)I<'0@
M0VQA<W,*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I<'0@8VQA<W,@=&\@
M86-C;VUP86YY('1H92!(;W)D95]&;W)M(&%S<VEG;B!F:65L9"X*("H*("H@
M)$AO<F1E.B!H;W)D92]J<R]F;W)M7V%S<VEG;BYJ<RQV(#$N,BXQ,"XT(#(P
M,#8O,#,O,C0@,#4Z,3<Z-3D@8VAU8VL@17AP("0*("H*("H@0V]P>7)I9VAT
M(#(P,#0M,C`P-B!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@
M*B!3964@=&AE(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I
M;F9O<FUA=&EO;B`H3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E
M('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L
M9W!L+FAT;6PN"B`J+PH*2&]R9&5?1F]R;5]!<W-I9VX@/2!N97<@3V)J96-T
M*"D["@I(;W)D95]&;W)M7T%S<VEG;BYD97-E;&5C=$AE861E<G,@/2!F=6YC
M=&EO;BAN86UE+"!S:61E*0I["B`@("!I9B`H<VED92D@>PH@("`@("`@(&1O
M8W5M96YT6VYA;64@*R`G7U]R:6=H="==6S!=+G-E;&5C=&5D(#T@9F%L<V4[
M"B`@("!](&5L<V4@>PH@("`@("`@(&1O8W5M96YT6VYA;64@*R`G7U]L969T
M)UU;,%TN<V5L96-T960@/2!F86QS93L*("`@('T*?0H*2&]R9&5?1F]R;5]!
M<W-I9VXN;6]V92`](&9U;F-T:6]N*&YA;64L(&1I<F5C=&EO;BD*>PH@("`@
M=F%R(&QE9G0@/2!D;V-U;65N=%MN86UE("L@)U]?;&5F="==.PH@("`@=F%R
M(')I9VAT(#T@9&]C=6UE;G1;;F%M92`K("=?7W)I9VAT)UT["@H@("`@:68@
M*&1I<F5C=&EO;BD@>PH@("`@("`@('9A<B!F<F]M(#T@<FEG:'0["B`@("`@
M("`@=F%R('1O(#T@;&5F=#L*("`@('T@96QS92!["B`@("`@("`@=F%R(&9R
M;VT@/2!L969T.PH@("`@("`@('9A<B!T;R`](')I9VAT.PH@("`@?0H*("`@
M(&9O<B`H=F%R(&D@/2`P.R!I(#P@9G)O;2YL96YG=&@[("LK:2D@>PH@("`@
M("`@(&EF("AF<F]M6VE=+G-E;&5C=&5D*2!["B`@("`@("`@("`@('1O6W1O
M+FQE;F=T:%T@/2!N97<@3W!T:6]N*&9R;VU;:5TN=&5X="P@9G)O;5MI72YV
M86QU92D["B`@("`@("`@("`@('1O6W1O+FQE;F=T:"`M(#%=+F]N9&)L8VQI
M8VL@/2!F=6YC=&EO;B@I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M($AO<F1E7T9O<FU?07-S:6=N+FUO=F4H;F%M92P@,2`M(&1I<F5C=&EO;BD[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@9G)O;5MI72`](&YU;&P["B`@
M("`@("`@("`@("TM:3L*("`@("`@("!]"B`@("!]"@H@("`@=&AI<RYS971&
M:65L9"AN86UE*3L*?0H*2&]R9&5?1F]R;5]!<W-I9VXN<V5T1FEE;&0@/2!F
M=6YC=&EO;BAN86UE*0I["B`@("!V87(@;&5F="`](&1O8W5M96YT6VYA;64@
M*R`G7U]L969T)UT["B`@("!V87(@<FEG:'0@/2!D;V-U;65N=%MN86UE("L@
M)U]?<FEG:'0G73L*"B`@("!V87(@=F%L=65S(#T@)R<["B`@("!V87(@:&ET
M(#T@9F%L<V4["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(&QE9G0N;W!T:6]N
M<RYL96YG=&@[("LK:2D@>PH@("`@("`@(&EF("AI(#T](#`@)B8@(6QE9G1;
M:5TN=F%L=64I('L*("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@?0H@
M("`@("`@('9A;'5E<R`K/2!L969T+F]P=&EO;G-;:5TN=F%L=64@*R`G7'0G
M.PH@("`@("`@(&AI="`]('1R=64["B`@("!]"B`@("!I9B`H:&ET*2!["B`@
M("`@("`@=F%L=65S(#T@=F%L=65S+G-U8G-T<FEN9R@P+"!V86QU97,N;&5N
M9W1H("T@,2D["B`@("!]"B`@("!V86QU97,@*ST@)UQT7'0G.PH@("`@:&ET
M(#T@9F%L<V4["B`@("!F;W(@*'9A<B!I(#T@,#L@:2`\(')I9VAT+F]P=&EO
M;G,N;&5N9W1H.R`K*VDI('L*("`@("`@("!I9B`H:2`]/2`P("8F("%R:6=H
M=%MI72YV86QU92D@>PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("!]
M"B`@("`@("`@=F%L=65S("L](')I9VAT+F]P=&EO;G-;:5TN=F%L=64@*R`G
M7'0G.PH@("`@("`@(&AI="`]('1R=64["B`@("!]"B`@("!I9B`H:&ET*2![
M"B`@("`@("`@=F%L=65S(#T@=F%L=65S+G-U8G-T<FEN9R@P+"!V86QU97,N
M;&5N9W1H("T@,2D["B`@("!]"B`@("!D;V-U;65N=%MN86UE("L@)U]?=F%L
M=65S)UTN=F%L=64@/2!V86QU97,["GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+VIS+V%L<&AA26UA9V5,;V%D97(N<&AP
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<W-R`Q
M,#4Q-30S-#$S-B`P,C(P-38`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O:G,O
M86QP:&%);6%G94QO861E<BYP:'`L=B`Q+C(N."XT(#(P,#8O,#$O,#$@,C$Z
M,CDZ,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`T+3(P,#8@0VAA
M<FQE<R!*+B!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V-O<F4N<&AP)SL*"B1R96=I<W1R>2`]("9296=I<W1R>3HZ<VEN9VQE=&]N
M*$A/4D1%7U-%4U-)3TY?3D].12D["@HO*B!4:&ES('-H;W5L9"!B92!C86-H
M960N("HO"B1M;V1?9VUT(#T@9VUD871E*"=$+"!D($T@62!(.FDZ<R<L(&9I
M;&5M=&EM92A?7T9)3$5?7RDI("X@)R!'350G.PIH96%D97(H)TQA<W0M36]D
M:69I960Z("<@+B`D;6]D7V=M="D["FAE861E<B@G0V%C:&4M0V]N=')O;#H@
M<'5B;&EC+"!M87@M86=E/3@V-#`P)RD["FAE861E<B@G0V]N=&5N="U4>7!E
M.B!T97AT+W@M8V]M<&]N96YT)RD["@H_/@H\<'5B;&EC.F-O;7!O;F5N=#X*
M/'!U8FQI8SIA='1A8V@@979E;G0](F]N<')O<&5R='EC:&%N9V4B(&9O<CTB
M96QE;65N="(@;VY%=F5N=#TB<')O<&5R='E#:&%N9V5D*"DB("\^"CQS8W)I
M<'0^"@IV87(@=')A;G-P87)E;G1);6%G92`]("(\/W!H<"!E8VAO("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RD@/SXO8FQA;FLN9VEF(CL*"G!N
M9TAA8VLH*3L*"F9U;F-T:6]N('!R;W!E<G1Y0VAA;F=E9"@I"GL*("`@(&EF
M("AE=F5N="YP<F]P97)T>4YA;64@/3T@(G-R8R(I('L*("`@("`@("!P;F=(
M86-K*"D["B`@("!]"GT*"F9U;F-T:6]N('!N9TAA8VLH*0I["B`@("!V87(@
M=R`](&5L96UE;G0N=VED=&@["B`@("!V87(@:"`](&5L96UE;G0N:&5I9VAT
M.PH@("`@=F%R('-R8R`](&5L96UE;G0N<W)C.PH@("`@:68@*'-R8RYI;F1E
M>$]F*'1R86YS<&%R96YT26UA9V4I("$]("TQ*2!["B`@("`@("`@+R\@06QR
M96%D>2!F:7AE9"X*("`@("`@("!R971U<FX["B`@("!]"@H@("`@:68@*'-R
M8RYI;F1E>$]F*")P;F<B*2`]/2`M,2D@>PH@("`@("`@(&5L96UE;G0N<G5N
M=&EM95-T>6QE+F9I;'1E<B`]("(B.PH@("`@("`@(')E='5R;CL*("`@('T*
M"B`@("!E;&5M96YT+G-R8R`]('1R86YS<&%R96YT26UA9V4["B`@("!E;&5M
M96YT+G=I9'1H(#T@=SL*("`@(&5L96UE;G0N:&5I9VAT(#T@:#L*("`@(&5L
M96UE;G0N<G5N=&EM95-T>6QE+F9I;'1E<B`](")P<F]G:60Z1%A);6%G951R
M86YS9F]R;2Y-:6-R;W-O9G0N06QP:&%);6%G94QO861E<BAS<F,])R(@*R!S
M<F,@*R`B)RQS:7II;F=-971H;V0])W-C86QE)RDB.PI]"@H\+W-C<FEP=#X*
M/"]P=6)L:6,Z8V]M<&]N96YT/@H`=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M:G,O:&]R9&4N:G,`````````````````````````````````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#$U-C,V(#$P-3$U-#,T,3,V(#`Q-S8R,P`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````O*BH*("H@
M1V5N97)A;"!(;W)D92!522!E9F9E8W1S(&IA=F%S8W)I<'0N"B`J"B`J("1(
M;W)D93H@:&]R9&4O:G,O:&]R9&4N:G,L=B`Q+C$T+C(N-2`R,#`V+S`U+S(U
M(#$X.C`W.C(V('-L=7-A<GH@17AP("0*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*=F%R
M(%1O;VQ4:7!S(#T@>PH@("`@0U524D5.5#H@;G5L;"P*("`@(%1)345/550Z
M(&YU;&PL"B`@("!,24Y+.B!N=6QL+`H*("`@(&%T=&%C:$)E:&%V:6]R.B!F
M=6YC=&EO;B@I"B`@("!["B`@("`@("`@;&EN:W,@/2!D;V-U;65N="YG971%
M;&5M96YT<T)Y5&%G3F%M92@G82<I.PH@("`@("`@(&9O<B`H:2`](#`[(&D@
M/"!L:6YK<RYL96YG=&@[(&DK*RD@>PH@("`@("`@("`@("!I9B`H;&EN:W-;
M:5TN=&ET;&4I('L*("`@("`@("`@("`@("`@(&QI;FMS6VE=+G-E=$%T=')I
M8G5T92@G;FEC971I=&QE)RP@;&EN:W-;:5TN=&ET;&4I.PH@("`@("`@("`@
M("`@("`@;&EN:W-;:5TN<F5M;W9E071T<FEB=71E*"=T:71L92<I.PH*("`@
M("`@("`@("`@("`@(&%D9$5V96YT*&QI;FMS6VE=+"`G;6]U<V5O=F5R)RP@
M5&]O;%1I<',N;W9E<BD["B`@("`@("`@("`@("`@("!A9&1%=F5N="AL:6YK
M<UMI72P@)VUO=7-E;W5T)RP@5&]O;%1I<',N;W5T*3L*("`@("`@("`@("`@
M("`@(&%D9$5V96YT*&QI;FMS6VE=+"`G9F]C=7,G+"!4;V]L5&EP<RYO=F5R
M*3L*("`@("`@("`@("`@("`@(&%D9$5V96YT*&QI;FMS6VE=+"`G8FQU<B<L
M(%1O;VQ4:7!S+F]U="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]
M+`H*("`@(&]V97(Z(&9U;F-T:6]N*&4I"B`@("!["B`@("`@("`@:68@*'1Y
M<&5O9B!4;V]L5&EP<R`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@("`@("!R
M971U<FX["B`@("`@("`@?0H*("`@("`@("!I9B`H5&]O;%1I<',N5$E-14]5
M5"D@>PH@("`@("`@("`@("!W:6YD;W<N8VQE87)4:6UE;W5T*%1O;VQ4:7!S
M+E1)345/550I.PH@("`@("`@('T*"B`@("`@("`@:68@*'=I;F1O=RYE=F5N
M="`F)B!W:6YD;W<N979E;G0N<W)C16QE;65N="D@>PH@("`@("`@("`@("!4
M;V]L5&EP<RY,24Y+(#T@=VEN9&]W+F5V96YT+G-R8T5L96UE;G0["B`@("`@
M("`@?2!E;'-E(&EF("AE("8F(&4N=&%R9V5T*2!["B`@("`@("`@("`@(%1O
M;VQ4:7!S+DQ)3DL@/2!E+G1A<F=E=#L*("`@("`@("!]"@H@("`@("`@(%1O
M;VQ4:7!S+E1)345/550@/2!W:6YD;W<N<V5T5&EM96]U="@G5&]O;%1I<',N
M<VAO=R@I)RP@,S`P*0H@("`@?2P*"B`@("!O=70Z(&9U;F-T:6]N*"D*("`@
M('L*("`@("`@("!I9B`H='EP96]F(%1O;VQ4:7!S(#T]("=U;F1E9FEN960G
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&EF
M("A4;V]L5&EP<RY424U%3U54*2!["B`@("`@("`@("`@('=I;F1O=RYC;&5A
M<E1I;65O=70H5&]O;%1I<',N5$E-14]55"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H5&]O;%1I<',N0U524D5.5"D@>PH@("`@("`@("`@("!D;V-U;65N
M="YG971%;&5M96YT<T)Y5&%G3F%M92@G8F]D>2<I6S!=+G)E;6]V94-H:6QD
M*%1O;VQ4:7!S+D-54E)%3E0I.PH@("`@("`@("`@("!4;V]L5&EP<RY#55)2
M14Y4(#T@;G5L;#L*"B`@("`@("`@("`@('9A<B!I9G)A;64@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G:69R86UE7W1T)RD["B`@("`@("`@("`@(&EF
M("AI9G)A;64@(3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@:69R86UE+G-T
M>6QE+F1I<W!L87D@/2`G;F]N92<["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]+`H*("`@('-H;W<Z(&9U;F-T:6]N*"D*("`@('L*("`@("`@("!I
M9B`H='EP96]F(%1O;VQ4:7!S(#T]("=U;F1E9FEN960G('Q\("%4;V]L5&EP
M<RY,24Y+*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@
M("`@(&EF("A4;V]L5&EP<RY#55)214Y4*2!["B`@("`@("`@("`@(%1O;VQ4
M:7!S+F]U="@I.PH@("`@("`@('T*"B`@("`@("`@;&EN:R`](%1O;VQ4:7!S
M+DQ)3DL["B`@("`@("`@=VAI;&4@*"%L:6YK+F=E=$%T=')I8G5T92@G;FEC
M971I=&QE)RD@)B8@;&EN:RYN;V1E3F%M92YT;TQO=V5R0V%S92@I("$]("=B
M;V1Y)RD@>PH@("`@("`@("`@("!L:6YK(#T@;&EN:RYP87)E;G1.;V1E.PH@
M("`@("`@('T*("`@("`@("!N:6-E=&ET;&4@/2!L:6YK+F=E=$%T=')I8G5T
M92@G;FEC971I=&QE)RD["B`@("`@("`@:68@*"%N:6-E=&ET;&4I('L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@9"`](&1O8W5M
M96YT+F-R96%T945L96UE;G0H)V1I=B<I.PH@("`@("`@(&0N8VQA<W-.86UE
M(#T@)VYI8V5T:71L92<["B`@("`@("`@9"YI;FYE<DA434P@/2!N:6-E=&ET
M;&4["@H@("`@("`@(%-41%]724142"`](#$P,#L*("`@("`@("!-05A?5TE$
M5$@@/2`V,#`["B`@("`@("`@:68@*'=I;F1O=RYI;FYE<E=I9'1H*2!["B`@
M("`@("`@("`@($U!6%]724142"`]($UA=&@N;6EN*$U!6%]724142"P@=VEN
M9&]W+FEN;F5R5VED=&@@+2`R,"D["B`@("`@("`@?0H@("`@("`@(&EF("AD
M;V-U;65N="YB;V1Y("8F(&1O8W5M96YT+F)O9'DN<V-R;VQL5VED=&@I('L*
M("`@("`@("`@("`@34%87U=)1%1((#T@36%T:"YM:6XH34%87U=)1%1(+"!D
M;V-U;65N="YB;V1Y+G-C<F]L;%=I9'1H("T@,C`I.PH@("`@("`@('T*"B`@
M("`@("`@;FEC971I=&QE7VQE;F=T:"`](#`["B`@("`@("`@;&EN97,@/2!N
M:6-E=&ET;&4N<F5P;&%C92@O/&)R(#]<+SXO9RP@(EQN(BDN<W!L:70H(EQN
M(BD["B`@("`@("`@9F]R("AI(#T@,#L@:2`\(&QI;F5S+FQE;F=T:#L@:2LK
M*2!["B`@("`@("`@("`@(&YI8V5T:71L95]L96YG=&@@/2!-871H+FUA>"AN
M:6-E=&ET;&5?;&5N9W1H+"!L:6YE<UMI72YL96YG=&@I.PH@("`@("`@('T*
M"B`@("`@("`@:%]P:7AE;',@/2!N:6-E=&ET;&5?;&5N9W1H("H@-SL*("`@
M("`@("!T7W!I>&5L<R`](&YI8V5T:71L95]L96YG=&@@*B`Q,#L*"B`@("`@
M("`@:68@*&A?<&EX96QS(#X@4U1$7U=)1%1(*2!["B`@("`@("`@("`@('<@
M/2!H7W!I>&5L<SL*("`@("`@("!](&5L<V4@:68@*%-41%]724142"`^('1?
M<&EX96QS*2!["B`@("`@("`@("`@('<@/2!T7W!I>&5L<SL*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!W(#T@4U1$7U=)1%1(.PH@("`@("`@('T*
M"B`@("`@("`@;7!O<R`](&9I;F10;W,H;&EN:RD["B`@("`@("`@;7@@/2!M
M<&]S6S!=.PH@("`@("`@(&UY(#T@;7!O<ULQ73L*"B`@("`@("`@;&5F="`]
M(&UX("L@,C`["B`@("`@("`@:68@*'=I;F1O=RYI;FYE<E=I9'1H("8F("@H
M;&5F="`K('<I(#X@=VEN9&]W+FEN;F5R5VED=&@I*2!["B`@("`@("`@("`@
M(&QE9G0@/2!W:6YD;W<N:6YN97)7:61T:"`M('<@+2`T,#L*("`@("`@("!]
M"B`@("`@("`@:68@*&1O8W5M96YT+F)O9'D@)B8@9&]C=6UE;G0N8F]D>2YS
M8W)O;&Q7:61T:"`F)B`H*&QE9G0@*R!W*2`^(&1O8W5M96YT+F)O9'DN<V-R
M;VQL5VED=&@I*2!["B`@("`@("`@("`@(&QE9G0@/2!D;V-U;65N="YB;V1Y
M+G-C<F]L;%=I9'1H("T@=R`M(#(U.PH@("`@("`@('T*"B`@("`@("`@9"YI
M9"`]("=T;V]L5&EP)SL*("`@("`@("!D+G-T>6QE+FQE9G0@/2!-871H+FUA
M>"AL969T+"`U*2`K("=P>"<["B`@("`@("`@9"YS='EL92YW:61T:"`]($UA
M=&@N;6EN*'<L($U!6%]724142"D@*R`G<'@G.PH@("`@("`@(&0N<W1Y;&4N
M=&]P(#T@*&UY("L@,C`I("L@)W!X)SL*("`@("`@("!D+G-T>6QE+F1I<W!L
M87D@/2`B8FQO8VLB.PH*("`@("`@("!T<GD@>PH@("`@("`@("`@("!D;V-U
M;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@G8F]D>2<I6S!=+F%P<&5N9$-H
M:6QD*&0I.PH@("`@("`@("`@("!4;V]L5&EP<RY#55)214Y4(#T@9#L*"B`@
M("`@("`@("`@(&EF("AT>7!E;V8@5&]O;%1I<'-?3W!T:6]N7U=I;F1O=V5D
M7T-O;G1R;VQS("$]("=U;F1E9FEN960G*2!["B`@("`@("`@("`@("`@("!V
M87(@:69R86UE(#T@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)VEF<F%M95]T
M="<I.PH@("`@("`@("`@("`@("`@:68@*&EF<F%M92`]/2!N=6QL*2!["B`@
M("`@("`@("`@("`@("`@("`@:69R86UE(#T@9&]C=6UE;G0N8W)E871E16QE
M;65N="@B/&EF<F%M92!S<F,])VIA=F%S8W)I<'0Z9F%L<V4[)R!N86UE/2=I
M9G)A;65?='0G(&ED/2=I9G)A;65?='0G('-C<F]L;&EN9STG;F\G(&9R86UE
M8F]R9&5R/2<P)R!S='EL93TG<&]S:71I;VXZ86)S;VQU=&4[('1O<#HP<'@[
M(&QE9G0Z,'!X.R!D:7-P;&%Y.FYO;F4[)SX\+VEF<F%M93XB*3L*("`@("`@
M("`@("`@("`@("`@("!D;V-U;65N="YG971%;&5M96YT<T)Y5&%G3F%M92@G
M8F]D>2<I6S!=+F%P<&5N9$-H:6QD*&EF<F%M92D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!I9G)A;64N<W1Y;&4N=VED=&@@/2!D+F]F
M9G-E=%=I9'1H.PH@("`@("`@("`@("`@("`@:69R86UE+G-T>6QE+FAE:6=H
M="`](&0N;V9F<V5T2&5I9VAT.PH@("`@("`@("`@("`@("`@:69R86UE+G-T
M>6QE+G1O<"`](&0N<W1Y;&4N=&]P.PH@("`@("`@("`@("`@("`@:69R86UE
M+G-T>6QE+FQE9G0@/2!D+G-T>6QE+FQE9G0["B`@("`@("`@("`@("`@("!I
M9G)A;64N<W1Y;&4N<&]S:71I;VX@/2`B86)S;VQU=&4B.PH@("`@("`@("`@
M("`@("`@:69R86UE+G-T>6QE+F1I<W!L87D@/2`B8FQO8VLB.PH@("`@("`@
M("`@("`@("`@9"YS='EL92YZ26YD97@@/2`Q,#`["B`@("`@("`@("`@("`@
M("!I9G)A;64N<W1Y;&4N>DEN9&5X(#T@.3D["B`@("`@("`@("`@('T*("`@
M("`@("!](&-A=&-H("AE*2!["B`@("`@("`@?0H@("`@?0H*?3L*"B\J*@H@
M*B!2971U<FX@=&AE(%MX+'E=('!O<VET:6]N(&]F(&%N(&]B:F5C="X*("HO
M"F9U;F-T:6]N(&9I;F10;W,H;V)J*0I["B`@("!I9B`H;V)J+F]F9G-E=%!A
M<F5N="D@>PH@("`@("`@(&9O<B`H<&]S6"`](#`L('!O<UD@/2`P.R!O8FHN
M;V9F<V5T4&%R96YT.R!O8FH@/2!O8FHN;V9F<V5T4&%R96YT*2!["B`@("`@
M("`@("`@('!O<U@@*ST@;V)J+F]F9G-E=$QE9G0["B`@("`@("`@("`@('!O
M<UD@*ST@;V)J+F]F9G-E=%1O<#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(%MP;W-8+"!P;W-973L*("`@('T@96QS92!["B`@("`@("`@<F5T=7)N(%MO
M8FHN>"P@;V)J+GE=.PH@("`@?0I]"@HO*BH*("H@061D(&%N(&5V96YT(&QI
M<W1E;F5R(&%S(&QO;F<@87,@=&AE(&)R;W=S97(@<W5P<&]R=',@:70N($1I
M9F9E<F5N=`H@*B!B<F]W<V5R<R!S=&EL;"!H86YD;&4@=&AE<V4@979E;G1S
M('-L:6=H=&QY(&1I9F9E<F5N=&QY.R!I;@H@*B!P87)T:6-U;&%R(&%V;VED
M('5S:6YG(")T:&ES(B!I;B!E=F5N="!F=6YC=&EO;G,N"B`J"B`J($!A=71H
M;W(@4V-O='0@06YD<F5W"B`J($!A=71H;W(@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J+PIF=6YC=&EO;B!A9&1%=F5N="AO8FHL(&5V
M5'EP92P@9FXI"GL*("`@(&EF("AO8FHN861D179E;G1,:7-T96YE<BD@>PH@
M("`@("`@(&]B:BYA9&1%=F5N=$QI<W1E;F5R*&5V5'EP92P@9FXL('1R=64I
M.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2!E;'-E(&EF("AO8FHN871T
M86-H179E;G0I('L*("`@("`@("!V87(@<B`](&]B:BYA='1A8VA%=F5N="@G
M;VXG("L@9794>7!E+"!F;BD["B`@("`@("`@179E;G1#86-H92YA9&0H;V)J
M+"!E=E1Y<&4L(&9N*3L*("`@("`@("!R971U<FX@<CL*("`@('T@96QS92![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0I]"@IV87(@179E;G1#86-H
M92`](&9U;F-T:6]N*"D*>PH@("`@=F%R(&QI<W1%=F5N=',@/2!;73L*"B`@
M("!R971U<FX@>PH@("`@("`@(&QI<W1%=F5N=',Z(&QI<W1%=F5N=',L"@H@
M("`@("`@(&%D9#H@9G5N8W1I;VXH;F]D92P@<T5V96YT3F%M92P@9DAA;F1L
M97(L(&)#87!T=7)E*0H@("`@("`@('L*("`@("`@("`@("`@;&ES=$5V96YT
M<RYP=7-H*&%R9W5M96YT<RD["B`@("`@("`@?2P*"B`@("`@("`@9FQU<V@Z
M(&9U;F-T:6]N*"D*("`@("`@("!["B`@("`@("`@("`@('9A<B!I+"!I=&5M
M.PH@("`@("`@("`@("!F;W(@*&D@/2!L:7-T179E;G1S+FQE;F=T:"`M(#$[
M(&D@/CT@,#L@:2`](&D@+2`Q*2!["B`@("`@("`@("`@("`@("!I=&5M(#T@
M;&ES=$5V96YT<UMI73L*"B`@("`@("`@("`@("`@("!I9B`H:71E;5LP72YR
M96UO=F5%=F5N=$QI<W1E;F5R*2!["B`@("`@("`@("`@("`@("`@("`@:71E
M;5LP72YR96UO=F5%=F5N=$QI<W1E;F5R*&ET96U;,5TL(&ET96U;,ETL(&ET
M96U;,UTI.PH@("`@("`@("`@("`@("`@?3L*"B`@("`@("`@("`@("`@("`O
M*B!&<F]M('1H:7,@<&]I;G0@;VX@=V4@;F5E9"!T:&4@979E;G0@;F%M97,@
M=&\@8F4*("`@("`@("`@("`@("`@("`J('!R969I>&5D('=I=&@@)V]N)RX@
M*B\*("`@("`@("`@("`@("`@(&EF("AI=&5M6S%=+G-U8G-T<FEN9R@P+"`R
M*2`A/2`G;VXG*2!["B`@("`@("`@("`@("`@("`@("`@:71E;5LQ72`]("=O
M;B<@*R!I=&5M6S%=.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("AI=&5M6S!=+F1E=&%C:$5V96YT*2!["B`@("`@("`@("`@("`@
M("`@("`@:71E;5LP72YD971A8VA%=F5N="AI=&5M6S%=+"!I=&5M6S)=*3L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I=&5M6S!=6VET
M96U;,5U=(#T@;G5L;#L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T[
M"GTH*3L*"FEF("AD;V-U;65N="YC<F5A=&5%;&5M96YT("8F(&1O8W5M96YT
M+F=E=$5L96UE;G1S0GE486=.86UE*2!["B`@("!A9&1%=F5N="AW:6YD;W<L
M("=L;V%D)RP@5&]O;%1I<',N871T86-H0F5H879I;W(I.PH@("`@861D179E
M;G0H=VEN9&]W+"`G=6YL;V%D)RP@5&]O;%1I<',N;W5T*3L*("`@(&%D9$5V
M96YT*'=I;F1O=RP@)W5N;&]A9"<L($5V96YT0V%C:&4N9FQU<V@I.PI]"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O:G,O;W!E;E]C;VQO<G!I
M8VME<BYJ<P``````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`U-34P(#$P-3$U-#,T,3,V(#`R,C`U,0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````O*BH*("H@2&]R9&4@0V]L;W)P:6-K
M97(@2F%V85-C<FEP="X*("H*("H@4')O=FED97,@=&AE(&IA=F%S8W)I<'0@
M=&\@8W)E871E(&$@8V]L;W)P:6-K97(N"B`J"B`J("1(;W)D93H@:&]R9&4O
M:G,O;W!E;E]C;VQO<G!I8VME<BYJ<RQV(#$N,B`R,#`T+S$P+S$Y(#$Y.C`X
M.C4S(&-H=6-K($5X<"`D"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U
M(&1I9"!N;W0*("H@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W
M+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F9U;F-T:6]N(&]P
M96Y#;VQO<E!I8VME<BAT87)G970I"GL*("`@('9A<B!L87D@/2!D;V-U;65N
M="YG971%;&5M96YT0GE)9"@G8V]L;W)P:6-K97)?)R`K('1A<F=E="D["B`@
M("!I9B`H;&%Y+G-T>6QE+F1I<W!L87D@/3T@)V)L;V-K)RD@>PH@("`@("`@
M(&QA>2YS='EL92YD:7-P;&%Y(#T@)VYO;F4G.PH@("`@("`@(')E='5R;B!F
M86QS93L*("`@('T*"B`@("!I9B`H;&%Y+F9I<G-T0VAI;&0I('L*("`@("`@
M("!I9B`H;&%Y+F9I<G-T0VAI;&0N;F]D951Y<&4@/3T@,2D@>PH@("`@("`@
M("`@("!L87DN<W1Y;&4N9&ES<&QA>2`]("=B;&]C:R<["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&QA>2YR96UO=F5#:&EL9"AL87DN9FER<W1#:&EL9"D["B`@("`@
M("`@?0H@("`@?0H*("`@('9A<B!T86)L92`](&1O8W5M96YT+F-R96%T945L
M96UE;G0H)W1A8FQE)RD["B`@("!V87(@=&)O9'D@/2!D;V-U;65N="YC<F5A
M=&5%;&5M96YT*"=T8F]D>2<I.PH@("`@=&%B;&4N87!P96YD0VAI;&0H=&)O
M9'DI.PH@("`@=&%B;&4N8V5L;%-P86-I;F<@/2`P.PH@("`@=&%B;&4N8F]R
M9&5R(#T@,#L*("`@('1A8FQE+G-T>6QE+F-U<G-O<B`]("=C<F]S<VAA:7(G
M.PH@("`@=&%B;&4N;VYM;W5S96]U="`](&9U;F-T:6]N*"D@>PH@("`@("`@
M(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=C;VQO<F1E;6]?)R`K('1A<F=E
M="DN<W1Y;&4N8F%C:V=R;W5N9$-O;&]R(#T@9&]C=6UE;G0N9V5T16QE;65N
M=$)Y260H=&%R9V5T*2YV86QU93L*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@+R\@5&AE('!A;&5T=&4*("`@('(@/2`P.R!G(#T@,#L@8B`]
M(#`["B`@("!F;W(@*&(@/2`P.R!B(#P@-CL@8BLK*2!["B`@("`@("`@<F]W
M(#T@9&]C=6UE;G0N8W)E871E16QE;65N="@G='(G*3L*("`@("`@("!C;VQO
M<B`](&UA:V5#;VQO<BAB("H@-3$L(&(@*B`U,2P@8B`J(#4Q*3L*("`@("`@
M("!C96QL(#T@;6%K94-E;&PH=&%R9V5T+"!C;VQO<BD["B`@("`@("`@<F]W
M+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@("`@(&9O<B`H9R`](#`[(&<@/"`V
M.R!G*RLI('L*("`@("`@("`@("`@9F]R("AR(#T@,#L@<B`\(#8[('(K*RD@
M>PH@("`@("`@("`@("`@("`@:68@*'(@(3T@8B`F)B!B("$](&<I('L*("`@
M("`@("`@("`@("`@("`@("!C;VQO<B`](&UA:V5#;VQO<BAR("H@-3$L(&<@
M*B`U,2P@8B`J(#4Q*3L*("`@("`@("`@("`@("`@("`@("!C96QL(#T@;6%K
M94-E;&PH=&%R9V5T+"!C;VQO<BD["B`@("`@("`@("`@("`@("`@("`@<F]W
M+F%P<&5N9$-H:6QD*&-E;&PI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@('1B;V1Y+F%P<&5N9$-H:6QD*')O
M=RD["B`@("!]"@H@("`@=&%B;&4N87!P96YD0VAI;&0H=&)O9'DI.PH@("`@
M;&%Y+F%P<&5N9$-H:6QD*'1A8FQE*3L*("`@(&QA>2YS='EL92YD:7-P;&%Y
M(#T@)V)L;V-K)SL*?0H*9G5N8W1I;VX@;6%K94-E;&PH=&%R9V5T+"!C;VQO
M<BD*>PH@("`@8V5L;"`](&1O8W5M96YT+F-R96%T945L96UE;G0H)W1D)RD[
M"B`@("!C96QL+FAE:6=H="`](#,["B`@("!C96QL+G=I9'1H(#T@-CL*("`@
M(&-E;&PN:60@/2!C;VQO<CL*("`@(&-E;&PN<W1Y;&4N8F%C:V=R;W5N9$-O
M;&]R(#T@8V]L;W(["B`@("!C96QL+F]N;6]U<V5O=F5R(#T@9G5N8W1I;VXH
M*2!["B`@("`@("`@9&]C=6UE;G0N9V5T16QE;65N=$)Y260H)V-O;&]R9&5M
M;U\G("L@=&%R9V5T*2YS='EL92YB86-K9W)O=6YD0V]L;W(@/2!T:&ES+G-T
M>6QE+F)A8VMG<F]U;F1#;VQO<CL*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"B`@("!C96QL+F]N8VQI8VL@/2!F=6YC=&EO;B@I('L*("`@("`@("!D
M;V-U;65N="YG971%;&5M96YT0GE)9"@G8V]L;W)D96UO7R<@*R!T87)G970I
M+G-T>6QE+F)A8VMG<F]U;F1#;VQO<B`]('1H:7,N<W1Y;&4N8F%C:V=R;W5N
M9$-O;&]R.PH@("`@("`@(&1O8W5M96YT+F=E=$5L96UE;G1">4ED*'1A<F=E
M="DN=F%L=64@/2!T:&ES+FED.PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("!R971U<FX@8V5L;#L*?0H*9G5N8W1I;VX@;6%K94-O;&]R*'(L
M(&<L(&(I"GL*("`@(&-O;&]R(#T@(B,B.PH@("`@8V]L;W(@*ST@:&5X*$UA
M=&@N9FQO;W(H<B`O(#$V*2D["B`@("!C;VQO<B`K/2!H97@H<B`E(#$V*3L*
M("`@(&-O;&]R("L](&AE>"A-871H+F9L;V]R*&<@+R`Q-BDI.PH@("`@8V]L
M;W(@*ST@:&5X*&<@)2`Q-BD["B`@("!C;VQO<B`K/2!H97@H36%T:"YF;&]O
M<BAB("\@,38I*3L*("`@(&-O;&]R("L](&AE>"AB("4@,38I.PH@("`@<F5T
M=7)N(&-O;&]R.PI]"@IF=6YC=&EO;B!H97@H1&5C*0I["B`@("!I9B`H1&5C
M(#T](#$P*2!R971U<FX@(F$B.PH@("`@:68@*$1E8R`]/2`Q,2D@<F5T=7)N
M(")B(CL*("`@(&EF("A$96,@/3T@,3(I(')E='5R;B`B8R(["B`@("!I9B`H
M1&5C(#T](#$S*2!R971U<FX@(F0B.PH@("`@:68@*$1E8R`]/2`Q-"D@<F5T
M=7)N(")E(CL*("`@(&EF("A$96,@/3T@,34I(')E='5R;B`B9B(["B`@("!R
M971U<FX@(B(@*R!$96,["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]J<R]I;6%G92YJ<P``````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,T-#(@,3`U,34T,S0Q
M,S8@,#$W-3<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J*@H@*B!(;W)D92!);6%G92!*879A<V-R:7!T"B`J"B`J(%!R
M;W9I9&5S('1H92!J879A<V-R:7!T('1O(&AE;'`@9'5R:6YG('1H92!U<&QO
M861I;F<@;V8@:6UA9V5S(&EN($AO<F1E7T9O<FTN"B`J"B`J("1(;W)D93H@
M:&]R9&4O:G,O:6UA9V4N:G,L=B`Q+C,N-"XS(#(P,#8O,#$O,#$@,C$Z,CDZ
M,#(@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`R,#`S+3(P,#8@36%R:V\@
M1&IU:VEC(#QM87)K;T!O8FQO+F-O;3X*("H*("H@4V5E('1H92!E;F-L;W-E
M9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI
M+B!)9B!Y;W4@9&ED(&YO=`H@*B!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT
M='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*+RHJ
M"B`J($-H86YG97,@=&AE('-R8R!O9B!A;B!I;6%G92!T87)G970L(&]P=&EO
M;F%L;'D@871T86-H:6YG(&$@=&EM92!V86QU92!T;R!T:&4*("H@55),('1O
M(&UA:V4@<W5R92!T:&%T('1H92!I;6%G92!D;V5S('5P9&%T92!A;F0@;F]T
M('5S92!T:&4@8G)O=W-E<B!C86-H92X*("H*("H@0'!A<F%M('-T<FEN9R!S
M<F,@("`@("`@("`@("`@(%1H92!S<F]U8V4@=&\@:6YS97)T960@:6YT;R!T
M:&4@:6UA9V4@96QE;65N="X*("H@0'!A<F%M('-T<FEN9R!T87)G970@("`@
M("`@("`@(%1H92!T87)G970@96QE;65N="X*("H@0'!A<F%M(&]P=&EO;F%L
M(&)O;VP@;F]?8V%C:&4@($EF('-E="!T;R!T<G5E('=I;&P@87!P96YD('1H
M92!T:6UE+@H@*@H@*B!`<F5T=7)N(&)O;VP@($9A;'-E('1O('-T;W`@=&AE
M(&)R;W=S97(@;&]A9&EN9R!A;GET:&EN9RX*("HO"F9U;F-T:6]N('-H;W=)
M;6%G92AS<F,L('1A<F=E="P@;F]?8V%C:&4I"GL*("`@('9A<B!I;6<@/2!D
M;V-U;65N="YG971%;&5M96YT0GE)9"AT87)G970I.PH@("`@:68@*'1Y<&5O
M9B!N;U]C86-H92`]/2`G=6YD969I;F5D)RD@>PH@("`@("`@('9A<B!N;U]C
M86-H92`](&9A;'-E.PH@("`@?0H*("`@(&EF("AN;U]C86-H92D@>PH@("`@
M("`@('9A<B!N;W<@/2!N97<@1&%T92@I.PH@("`@("`@('-R8R`]('-R8R`K
M("<F)R`K(&YO=RYG9714:6UE*"D["B`@("!]"@H@("`@:6UG+G-R8R`]('-R
M8SL*"B`@("!R971U<FX@9F%L<V4["GT*"B\J*@H@*B!!9&1S('1O('1H92!G
M:79E;B!S;W5R8V4@=&AE(&AE:6=H="]W:61T:"!F:65L9"!V86QU97,@9F]R
M('1H92!G:79E;B!T87)G970N"B`J"B`J($!P87)A;2!S=')I;F<@<W)C("`@
M("`@("`@("!4:&4@<W)O=6-E('1O(&%P<&5N9"!T;R!T:&4@<F5S:7IE('!A
M<F%M<RX*("H@0'!A<F%M('-T<FEN9R!T87)G970@("`@("`@(%1H92!T87)G
M970@96QE;65N="X*("H@0'!A<F%M(&]P=&EO;F%L(&)O;VP@<F%T:6\@($EF
M('-E="!T;R!T<G5E('=I;&P@87!P96YD(&9I>"!T:&4@<F%T:6\N"B`J"B`J
M($!R971U<FX@<W1R:6YG("!4:&4@;6]D:69I960@<V]U<F-E('1O(&EN8VQU
M9&4@=&AE(')E<VEZ92!D871A+@H@*B\*9G5N8W1I;VX@9V5T4F5S:7IE4W)C
M*'-R8RP@=&%R9V5T+"!R871I;RD*>PH@("`@=F%R('=I9'1H(#T@9&]C=6UE
M;G0N9V5T16QE;65N=$)Y260H)U]W7R<@*R!T87)G970I+G9A;'5E.PH@("`@
M=F%R(&AE:6=H="`](&1O8W5M96YT+F=E=$5L96UE;G1">4ED*"=?:%\G("L@
M=&%R9V5T*2YV86QU93L*("`@(&EF("AT>7!E;V8@<F%T:6\@/3T@)W5N9&5F
M:6YE9"<I('L*("`@("`@("!V87(@<F%T:6\@/2`P.PH@("`@?0H*("`@('-R
M8R`]('-R8R`K("<F)R`K("=V/2<@*R!W:61T:"`K("<N)R`K(&AE:6=H="`K
M("<N)R`K(')A=&EO.PH*("`@(')E='5R;B!S<F,["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O:G,O861D179E;G0N<&AP````````````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-C0R(#$P-3$U-#,T,3,V(#`R
M,#0R,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```O*BH*("H@1V5N97)I8R!F=6YC=&EO;B!T;R!A9&0@86X@979E;G0@:&%N
M9&QE<B!T;R!A;GD@1$]-(&5L96UE;G0N"B`J"B`J("1(;W)D93H@:&]R9&4O
M:G,O861D179E;G0N<&AP+'8@,2XQ+C(N,B`R,#`V+S`Q+S`Q(#(Q.C(Y.C`R
M(&IA;B!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($-H=6-K($AA
M9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO
M<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=0
M3"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@
M:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@HO
M*BH*("H@061D<R!T:&4@9VEV96X@979E;G0@=&\@86X@96QE;65N="X@268@
M=&AE(&5L96UE;G0@86QR96%D>2!H87,*("H@:&%N9&QE<G,@9F]R('1H92!E
M=F5N="P@=&AE(&YE=R!E=F5N="!I<R!A<'!E;F1E9"X*("H*("H@0'!A<F%M
M(&]B:F5C="!E;&5M96YT("`@5&AE(&5L96UE;G0@=&\@861D('1H92!E=F5N
M="!T;RX*("H@0'!A<F%M('-T<FEN9R!E=F5N="`@("`@5&AE(&YA;64@;V8@
M=&AE(&5V96YT+@H@*B!`<&%R86T@<W1R:6YG?&9U;F-T:6]N(&9U;F-T:6]N
M("!4:&4@:F%V87-C<FEP="!T;R!E>&5C=71E+@H@*B\*9G5N8W1I;VX@861D
M179E;G0H96QE;65N="P@979E;G0L(&-O9&4I"GL*("`@(&EF("@A96QE;65N
M="D@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!!<W-I
M9VX@;F5W(&%N;VYY;6]U<R!F=6YC=&EO;B!I9B!W92=R92!P87-S960@82!J
M<R!S=')I;F<*("`@("\O(&EN<W1E860@;V8@82!F=6YC=&EO;B!R969E<F5N
M8V4N"B`@("!I9B`H='EP96]F(&-O9&4@/3T@)W-T<FEN9R<I('L*("`@("`@
M("!C;V1E(#T@;F5W($9U;F-T:6]N*&-O9&4I.PH@("`@?0H*("`@(&EF("AE
M;&5M96YT+F%D9$5V96YT3&ES=&5N97(I('L*("`@("`@("!E;&5M96YT+F%D
M9$5V96YT3&ES=&5N97(H979E;G0N<F5P;&%C92@O;VXO+"`G)RDL(&-O9&4L
M(&9A;'-E*3L*("`@('T@96QS92!I9B`H96QE;65N="YA='1A8VA%=F5N="D@
M>PH@("`@("`@(&5L96UE;G0N871T86-H179E;G0H979E;G0L(&-O9&4I.PH@
M("`@?2!E;'-E(&EF("AE;&5M96YT+F]N;&]A9"`A/2!N=6QL*2!["B`@("`@
M("`@979A;"@G=F%R($]L9$5V96YT(#T@96QE;65N="XG("L@979E;G0I.PH@
M("`@("`@(&YE=T-O9&4@/2!&=6YC=&EO;BAE*0H@("`@("`@('L*("`@("`@
M("`@("`@;VQD179E;G0H92D["B`@("`@("`@("`@(&-O9&4H*3L*("`@("`@
M("!].PH@("`@("`@(&5V86PH)V5L96UE;G0N)R`K(&5V96YT("L@)R`](&YE
M=T-O9&4G*3L*("`@('T@96QS92!["B`@("`@("`@979A;"@G96QE;65N="XG
M("L@979E;G0@*R`G(#T@8V]D92<I.PH@("`@?0H*("`@(')E='5R;B!T<G5E
M.PI]"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]L;V-A;&4`
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S8@,#(P,#`U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V%D;6EN+W!E<FUS````````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-B`P,3<V-S0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<V5T=7``````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,V(#`Q-S<P-@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P
M:'!S:&5L;"YP:'``````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#4U-#,@,3`U,34T,S0Q,S8@,#(Q,38T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B`D
M2&]R9&4Z(&AO<F1E+V%D;6EN+W!H<'-H96QL+G!H<"QV(#$N,C0N,3`N."`R
M,#`V+S`R+S(T(#(R.C0X.C(Y(&-H=6-K($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E
M;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N;W0@<F5C
M96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE
M9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!
M4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N
M=2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N<&AP)SL*"FEF("@A
M075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&
M86EL=7)E4F5D:7)E8W0H*3L*?0H*)'1I=&QE(#T@7R@B4$A0(%-H96QL(BD[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8R<["@HD87!P<U]T;7`@/2`D<F5G:7-T<GDM/FQI<W1!<'!S
M*"D["B1A<'!S(#T@87)R87DH*3L*9F]R96%C:"`H)&%P<'-?=&UP(&%S("1A
M<'`I('L*("`@("1A<'!S6R1A<'!=(#T@)')E9VES=')Y+3YG970H)VYA;64G
M+"`D87!P*3L*?0IA<V]R="@D87!P<RD["B1A<'!L:6-A=&EO;B`](%5T:6PZ
M.F=E=$9O<FU$871A*"=A<'`G+"`G:&]R9&4G*3L*/SX*/&1I=B!S='EL93TB
M<&%D9&EN9SHQ,'!X(CX*/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO("1?4T52
M5D526R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B/@H\/W!H<"!5=&EL
M.CIP9F]R;4EN<'5T*"D@/SX*"CQH,2!C;&%S<STB:&5A9&5R(CX\/W!H<"!E
M8VAO(%\H(D%P<&QI8V%T:6]N(BD@/SX\+V@Q/CQB<B`O/@H\<V5L96-T(&YA
M;64](F%P<"(^"CP_<&AP(&9O<F5A8V@@*"1A<'!S(&%S("1A<'`@/3X@)&YA
M;64I.B`_/@H@(#QO<'1I;VX@=F%L=64](CP_<&AP(&5C:&\@)&%P<"`_/B(\
M/W!H<"!I9B`H)&%P<&QI8V%T:6]N(#T]("1A<'`I(&5C:&\@)R!S96QE8W1E
M9#TB<V5L96-T960B)R`_/CX\/W!H<"!E8VAO("1N86UE(#\^/"]O<'1I;VX^
M"CP_<&AP(&5N9&9O<F5A8V@[(#\^"CPO<V5L96-T/CQB<B`O/CQB<B`O/@H\
M/W!H<`H*:68@*"1C;VUM86YD(#T@=')I;2A5=&EL.CIG971&;W)M1&%T82@G
M<&AP)RDI*2!["B`@("!I9B`H0&9I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T
M*"=F:6QE<F]O="<L("1A<'!L:6-A=&EO;BD@+B`G+VQI8B]B87-E+G!H<"<I
M*2!["B`@("`@("`@:6YC;'5D92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G
M+"`D87!P;&EC871I;VXI("X@)R]L:6(O8F%S92YP:'`G.PH@("`@?2!E;'-E
M('L*("`@("`@("`D<F5G:7-T<GDM/G!U<VA!<'`H)&%P<&QI8V%T:6]N*3L*
M("`@('T*"B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O5FEE=V5R+G!H
M<"<["B`@("!R97%U:7)E7V]N8V4@)TAO<F1E+TU)344O5FEE=V5R+W-O=7)C
M92YP:'`G.PH@("`@)'!R971T>2`](&AI9VAL:6=H=%]S=')I;F<H)SP_<&AP
M("<@+B`D8V]M;6%N9"P@=')U92D["B`@("`D<')E='1Y(#T@<W1R7W)E<&QA
M8V4H87)R87DH)R9L=#L_<&AP("<L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)SQF;VYT(&-O;&]R/2(C,#`P,#`P(CX\9F]N="!C;VQO<CTB
M(S`P-S<P,"(^)FQT.S\\+V9O;G0^/&9O;G0@8V]L;W(](B,P,#`P0D(B/G!H
M<"`\+V9O;G0^)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B
M7')<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQR(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B7&XB+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("<\8G(@+SXG*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`B7&XB*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<')E='1Y*3L*("`@("1P<F5T='D@/2!-24U%7U9I97=E
M<E]3;W5R8V4Z.FQI;F5.=6UB97(H=')I;2@D<')E='1Y*2D["@H@("`@96-H
M;R`G/&@Q(&-L87-S/2)H96%D97(B/B<@+B!?*")02%`@0V]D92(I("X@)SPO
M:#$^/&)R("\^)SL*("`@(&5C:&\@)'!R971T>3L*"B`@("!E8VAO("<\8G(@
M+SX\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(E)E<W5L=',B*2`N("<\+V@Q
M/CQB<B`O/B<["B`@("!E8VAO("<\<')E(&-L87-S/2)T97AT(CXG.PH@("`@
M979A;"@D8V]M;6%N9"D["B`@("!E8VAO("<\+W!R93X\8G(@+SXG.PI]"C\^
M"@H\=&5X=&%R96$@8VQA<W,](F9I>&5D(B!N86UE/2)P:'`B(')O=W,](C$P
M(B!C;VQS/2(V,"(^"CP_<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*2!E8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)&-O;6UA;F0I(#\^/"]T97AT87)E83X*/&)R
M("\^"CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E
M/2(\/W!H<"!E8VAO(%\H(D5X96-U=&4B*2`_/B(@+SX*/#]P:'`@96-H;R!(
M96QP.CIL:6YK*"=A9&UI;B<L("=A9&UI;BUP:'!S:&5L;"<I(#\^"@H\+V9O
M<FT^"CPO9&EV/@H\/W!H<`H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VEN9&5X+G!H<```````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(U-R`Q
M,#4Q-30S-#$S-B`P,C`T-3(`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O861M
M:6XO:6YD97@N<&AP+'8@,2XQ-2XX+C,@,C`P-B\P,2\P,2`R,3HR.#HP-2!J
M86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R;&5S($HN
M($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N
M8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H
M3$=03"DN("!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@
M<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J
M+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%7U\I("X@
M)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["@II9B`H(4%U
M=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN
M)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0H*)'1I=&QE(#T@7R@B061M:6YI
M<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D
M;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W5S97(N<&AP````
M````````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R
M,S<W-R`Q,#4Q-30S-#$S-B`P,C`S,S0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R
M9&4O861M:6XO=7-E<BYP:'`L=B`Q+C0W+C$P+C<@,C`P-B\P,2\P,2`R,3HR
M.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E('1H92!E
M;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@
M*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!T:&ES(&9I;&4L
M('-E92!H='1P.B\O=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@
M*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N
M("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E
M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+T9O<FTN<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]6
M87)I86)L97,N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+U)E;F1E
M<F5R+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<[
M"@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&
M;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*?0HD875T:"`]("9!
M=71H.CIS:6YG;&5T;VXH)&-O;F9;)V%U=&@G75LG9')I=F5R)UTI.PH*:68@
M*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`F)B`D8V]N9ELG<VEG;G5P)UU;
M)V%P<')O=F4G72D@>PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]!=71H+U-I
M9VYU<"YP:'`G.PH@("`@)'-I9VYU<"`]("9!=71H7U-I9VYU<#HZ<VEN9VQE
M=&]N*"D["GT*"B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA
M8FQE<R@I.PHD861D1F]R;2`]("9N97<@2&]R9&5?1F]R;2@D=F%R<RP@7R@B
M061D(&$@;F5W('5S97(Z(BDL("=A9&1U<V5R)RD["B1A9&1&;W)M+3YS971"
M=71T;VYS*%\H(D%D9"!U<V5R(BDL(%\H(E)E<V5T(BDI.PH*)'9A<G,M/G-E
M="@G9F]R;2<L("=A9&0G*3L*)&%D9$9O<FTM/F%D9$AI9&1E;B@G)RP@)V9O
M<FTG+"`G=&5X="<L('1R=64L('1R=64I.PHD861D1F]R;2T^861D5F%R:6%B
M;&4H7R@B57-E<FYA;64B*2P@)W5S97)?;F%M92<L("=T97AT)RP@=')U92D[
M"B1A9&1&;W)M+3YA9&1687)I86)L92A?*")087-S=V]R9"(I+"`G<&%S<W=O
M<F0G+"`G<&%S<W=O<F1C;VYF:7)M)RP@9F%L<V4L(&9A;'-E+"!?*")T>7!E
M('1H92!P87-S=V]R9"!T=VEC92!T;R!C;VYF:7)M(BDI.PH*+RH@57-E(&AO
M;VMS(&=E="!A;GD@97AT<F$@9FEE;&1S(&9O<B!N97<@86-C;W5N=',N("HO
M"B1E>'1R82`]($AO<F1E.CIC86QL2&]O:R@G7VAO<F1E7VAO;VM?<VEG;G5P
M7V=E=&5X=')A)RD["FEF("@A:7-?82@D97AT<F$L("=014%27T5R<F]R)RD@
M)B8@(65M<'1Y*"1E>'1R82DI('L*("`@(&9O<F5A8V@@*"1E>'1R82!A<R`D
M9FEE;&1?;F%M92`]/B`D9FEE;&0I('L*("`@("`@("`D<F5A9&]N;'D@/2!I
M<W-E="@D9FEE;&1;)W)E861O;FQY)UTI(#\@)&9I96QD6R=R96%D;VYL>2==
M(#H@;G5L;#L*("`@("`@("`D9&5S8R`](&ES<V5T*"1F:65L9%LG9&5S8R==
M*2`_("1F:65L9%LG9&5S8R==(#H@;G5L;#L*("`@("`@("`D9FEE;&1?<&%R
M86US(#T@:7-S970H)&9I96QD6R=P87)A;7,G72D@/R`D9FEE;&1;)W!A<F%M
M<R==(#H@87)R87DH*3L*"B`@("`@("`@)&%D9$9O<FTM/F%D9%9A<FEA8FQE
M*"1F:65L9%LG;&%B96PG72P@)V5X=')A6R<@+B`D9FEE;&1?;F%M92`N("==
M)RP@)&9I96QD6R=T>7!E)UTL("1F:65L9%LG<F5Q=6ER960G72P@)')E861O
M;FQY+"`D9&5S8RP@)&9I96QD7W!A<F%M<RD["B`@("!]"GT*"@HO+R!0<F]C
M97-S(&9O<FUS+B!5<V4@571I;#HZ9V5T4&]S="@I(&EN<W1E860@;V8@571I
M;#HZ9V5T1F]R;41A=&$H*0HO+R!F;W(@82!L;W0@;V8@=&AE(&1A=&$@8F5C
M875S92!W92!W86YT('1O(&%C=&EV96QY(&EG;F]R92!'150@9&%T80HO+R!I
M;B!S;VUE(&-A<V5S("T@861D:6YG+VUO9&EF>6EN9R!U<V5R<R`M(&%S(&$@
M<V5C=7)I='D@<')E8V%U=&EO;BX*<W=I=&-H("A5=&EL.CIG971&;W)M1&%T
M82@G9F]R;2<I*2!["F-A<V4@)V%D9"<Z"B`@("`D861D1F]R;2T^=F%L:61A
M=&4H)'9A<G,I.PH*("`@(&EF("@D861D1F]R;2T^:7-686QI9"@I("8F("1V
M87)S+3YG970H)V9O<FUN86UE)RD@/3T@)V%D9'5S97(G*2!["B`@("`@("`@
M)&%D9$9O<FTM/F=E=$EN9F\H)'9A<G,L("1I;F9O*3L*"B`@("`@("`@:68@
M*&5M<'1Y*"1I;F9O6R=U<V5R7VYA;64G72DI('L*("`@("`@("`@("`@)&YO
M=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@;75S="!S<&5C:69Y('1H92!U<V5R
M;F%M92!T;R!A9&0N(BDL("=H;W)D92YE<G)O<B<I.PH*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D8W)E9&5N=&EA;',@/2!A<G)A>2@G<&%S<W=O
M<F0G(#T^("1I;F9O6R=P87-S=V]R9"==*3L*("`@("`@("`@("`@:68@*&ES
M<V5T*"1I;F9O6R=E>'1R82==*2D@>PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&EN9F];)V5X=')A)UT@87,@)&9I96QD(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@("`@("1C<F5D96YT:6%L<ULD9FEE;&1=(#T@)'9A;'5E
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H:7-?82@D<F5T(#T@)&%U=&@M/F%D9%5S97(H)&EN9F];)W5S97)?
M;F%M92==+"`D8W)E9&5N=&EA;',I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE
M<F4@=V%S(&$@<')O8FQE;2!A9&1I;F<@7"(E<UPB('1O('1H92!S>7-T96TZ
M("5S(BDL("1I;F9O6R=U<V5R7VYA;64G72P@)')E="T^9V5T365S<V%G92@I
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&EN9F];)V5X=')A)UTI*2!["B`@("`@
M("`@("`@("`@("`@("`@)')E<W5L="`]($AO<F1E.CIC86QL2&]O:R@G7VAO
M<F1E7VAO;VM?<VEG;G5P7V%D9&5X=')A)RP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1I;F9O6R=U<V5R
M7VYA;64G72P@)&EN9F];)V5X=')A)UTI*3L*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")!9&1E9"!<(B5S7"(@=&\@=&AE('-Y<W1E;2P@8G5T(&-O=6QD(&YO="!A
M9&0@861D:71I;VYA;"!S:6=N=7`@:6YF;W)M871I;VXZ("5S+B(I+"`D:6YF
M;ULG=7-E<E]N86UE)UTL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D
M92YW87)N:6YG)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@:68@*%5T:6PZ.F=E=$9O<FU$871A
M*"=R96UO=F51=65U9613:6=N=7`G*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1S:6=N=7`M/G)E;6]V95%U975E9%-I9VYU<"@D:6YF;ULG=7-E<E]N86UE
M)UTI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!A9&1E9"!<
M(B5S7"(@=&\@=&AE('-Y<W1E;2XB*2P@)&EN9F];)W5S97)?;F%M92==*2P@
M)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@("1A9&1&;W)M+3YU
M;G-E=%9A<G,H)'9A<G,I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M?0H@("`@8G)E86L["@IC87-E("=R96UO=F5?9B<Z"B`@("`D9E]U<V5R7VYA
M;64@/2!5=&EL.CIG971&;W)M1&%T82@G=7-E<E]N86UE)RD["B`@("`D<F5M
M;W9E7V9O<FT@/2!T<G5E.PH@("`@8G)E86L["@IC87-E("=R96UO=F4G.@H@
M("`@)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M
M92<I.PH@("`@:68@*&5M<'1Y*"1F7W5S97)?;F%M92DI('L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*%\H(EEO=2!M=7-T('-P96-I9GD@82!U<V5R
M;F%M92!T;R!R96UO=F4N(BDL("=H;W)D92YM97-S86=E)RD["B`@("!](&5L
M<V5I9B`H571I;#HZ9V5T1F]R;41A=&$H)W-U8FUI="<I("$]/2!?*")#86YC
M96PB*2D@>PH@("`@("`@(&EF("AI<U]A*"1R97-U;'0@/2`D875T:"T^<F5M
M;W9E57-E<B@D9E]U<V5R7VYA;64I+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")4:&5R92!W
M87,@82!P<F]B;&5M(')E;6]V:6YG(%PB)7-<(B!F<F]M('1H92!S>7-T96TZ
M("(I("X@)')E<W5L="T^9V5T365S<V%G92@I+"`D9E]U<V5R7VYA;64I+"`G
M:&]R9&4N97)R;W(G*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY(')E
M;6]V960@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB*2P@)&9?=7-E<E]N86UE
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"B`@("!]"B`@("`D=F%R
M<RT^<F5M;W9E*"=U<V5R7VYA;64G*3L*("`@(&)R96%K.PH*8V%S92`G8VQE
M87)?9B<Z"B`@("`D9E]U<V5R7VYA;64@/2!5=&EL.CIG971&;W)M1&%T82@G
M=7-E<E]N86UE)RD["B`@("`D8VQE87)?9F]R;2`]('1R=64["B`@("!B<F5A
M:SL*"F-A<V4@)V-L96%R)SH*("`@("1F7W5S97)?;F%M92`](%5T:6PZ.F=E
M=$9O<FU$871A*"=U<V5R7VYA;64G*3L*("`@(&EF("AE;7!T>2@D9E]U<V5R
M7VYA;64I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9;W4@
M;75S="!S<&5C:69Y(&$@=7-E<FYA;64@=&\@8VQE87(@;W5T+B(I+"`G:&]R
M9&4N;65S<V%G92<I.PH@("`@?2!E;'-E:68@*%5T:6PZ.F=E=$9O<FU$871A
M*"=S=6)M:70G*2`A/3T@7R@B0V%N8V5L(BDI('L*("`@("`@("!I9B`H:7-?
M82@D<F5S=6QT(#T@)&%U=&@M/G)E;6]V955S97)$871A*"1F7W5S97)?;F%M
M92DL("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO
M;BT^<'5S:"AS<')I;G1F*%\H(E1H97)E('=A<R!A('!R;V)L96T@8VQE87)I
M;F<@9&%T82!F;W(@=7-E<B!<(B5S7"(@9G)O;2!T:&4@<WES=&5M.B`B*2`N
M("1R97-U;'0M/F=E=$UE<W-A9V4H*2P@)&9?=7-E<E]N86UE*2P@)VAO<F1E
M+F5R<F]R)RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E-U8V-E<W-F=6QL>2!C;&5A<F5D
M(&1A=&$@9F]R('5S97(@7"(E<UPB(&9R;VT@=&AE('-Y<W1E;2XB*2P@)&9?
M=7-E<E]N86UE*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("!]"B`@("!]
M"B`@("`D=F%R<RT^<F5M;W9E*"=U<V5R7VYA;64G*3L*("`@(&)R96%K.PH*
M8V%S92`G=7!D871E7V8G.@H@("`@)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T
M1F]R;41A=&$H)W5S97)?;F%M92<I.PH@("`@)'5P9&%T95]F;W)M(#T@=')U
M93L*("`@(&)R96%K.PH*8V%S92`G=7!D871E)SH*("`@("1U<V5R7VYA;65?
M,2`](%5T:6PZ.F=E=%!O<W0H)W5S97)?;F%M92<I.PH@("`@)'5S97)?;F%M
M95\R(#T@571I;#HZ9V5T4&]S="@G=7-E<E]N86UE,B<L("1U<V5R7VYA;65?
M,2D["B`@("`D9G5L;&YA;64@/2!5=&EL.CIG9710;W-T*"=U<V5R7V9U;&QN
M86UE)RD["B`@("`D96UA:6P@/2!5=&EL.CIG9710;W-T*"=U<V5R7V5M86EL
M)RD["@H@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=U<&1A=&4G*2D@
M>PH@("`@("`@("1U<V5R7W!A<W-?,2`](%5T:6PZ.F=E=%!O<W0H)W5S97)?
M<&%S<U\Q)RD["B`@("`@("`@)'5S97)?<&%S<U\R(#T@571I;#HZ9V5T4&]S
M="@G=7-E<E]P87-S7S(G*3L*"B`@("`@("`@:68@*&5M<'1Y*"1U<V5R7VYA
M;65?,2DI('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")9
M;W4@;75S="!S<&5C:69Y('1H92!U<V5R;F%M92!T;R!U<&1A=&4N(BDL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS96EF("AE;7!T>2@D=7-E<E]P
M87-S7S$I('Q\(&5M<'1Y*"1U<V5R7W!A<W-?,BDI('L*("`@("`@("`@("`@
M+R\@1&]N)W0@=7!D871E+"!B=70@9&]N)W0@8V]M<&QA:6XN"B`@("`@("`@
M?2!E;'-E:68@*"1U<V5R7W!A<W-?,2`A/2`D=7-E<E]P87-S7S(I('L*("`@
M("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")087-S=V]R9',@;75S
M="!M871C:"XB*2P@)VAO<F1E+F5R<F]R)RD["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')E<W5L="`]("1A=71H+3YU<&1A=&55<V5R*"1U<V5R
M7VYA;65?,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1U<V5R7VYA;65?,BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=P87-S=V]R9"<@/3X@)'5S97)?<&%S<U\Q
M*2D["B`@("`@("`@?0H@("`@?0H*("`@(&EF("AI<W-E="@D<F5S=6QT*2`F
M)B!I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B5&AE<F4@=V%S(&$@<')O8FQE
M;2!U<&1A=&EN9R!<(B5S7"(Z("5S(BDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1U<V5R7VYA;65?,2P@)')E<W5L="T^9V5T365S
M<V%G92@I*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@
M(')E<75I<F5?;VYC92`G2&]R9&4O261E;G1I='DN<&AP)SL*("`@("`@("`D
M:61E;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1U<V5R
M7VYA;65?,2D["B`@("`@("`@)&ED96YT:71Y+3YS971686QU92@G9G5L;&YA
M;64G+"`D9G5L;&YA;64I.PH@("`@("`@("1I9&5N=&ET>2T^<V5T5F%L=64H
M)V9R;VU?861D<B<L("1E;6%I;"D["B`@("`@("`@)&ED96YT:71Y+3YS879E
M*"D["@H@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3
M=6-C97-S9G5L;'D@=7!D871E9"!<(B5S7"(B*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'5S97)?;F%M95\R*2P@)VAO<F1E+G-U
M8V-E<W,G*3L*("`@('T*("`@("1V87)S+3YR96UO=F4H)W5S97)?;F%M92<I
M.PH@("`@8G)E86L["@IC87-E("=A<'!R;W9E7V8G.@H@("`@)'1H:7-3:6=N
M=7`@/2`D<VEG;G5P+3YG9711=65U9613:6=N=7`H571I;#HZ9V5T1F]R;41A
M=&$H)W5S97)?;F%M92<I*3L*("`@("1I;F9O(#T@)'1H:7-3:6=N=7`M/F=E
M=$1A=&$H*3L*"B`@("`D=F%R<RT^<V5T*"=P87-S=V]R9"<L"B`@("`@("`@
M("`@("`@(&%R<F%Y*"=O<FEG:6YA;"<@/3X@)&EN9F];)W!A<W-W;W)D)UTL
M"B`@("`@("`@("`@("`@("`@("`@("=C;VYF:7)M)R`]/B`D:6YF;ULG<&%S
M<W=O<F0G72DI.PH@("`@=6YS970H)&EN9F];)W!A<W-W;W)D)UTI.PH@("`@
M)'9A<G,M/G-E="@G97AT<F$G+"`D:6YF;RD["@H@("`@)'9A<G,M/G-E="@G
M<F5M;W9E475E=65D4VEG;G5P)RP@=')U92D["B`@("`D861D1F]R;2T^861D
M2&ED9&5N*"<G+"`G<F5M;W9E475E=65D4VEG;G5P)RP@)V)O;VQE86XG+"!T
M<G5E*3L*("`@(&)R96%K.PH*8V%S92`G<F5M;W9E<75E=65D7V8G.@H@("`@
M)&9?=7-E<E]N86UE(#T@571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M92<I
M.PH@("`@)')E;6]V97%U975E9%]F;W)M(#T@=')U93L*("`@(&)R96%K.PH*
M8V%S92`G<F5M;W9E<75E=65D)SH*("`@("1R97-U;'0@/2`D<VEG;G5P+3YR
M96UO=F51=65U9613:6=N=7`H571I;#HZ9V5T1F]R;41A=&$H)W5S97)?;F%M
M92<I*3L*("`@(&EF("AI<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*"1R97-U;'0I.PH@("`@?2!E
M;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M5&AE('-I9VYU<"!R97%U97-T(&9O<B`E<R!H87,@8F5E;B!R96UO=F5D+B(I
M+"!5=&EL.CIG971&;W)M1&%T82@G=7-E<E]N86UE)RDI*3L*("`@('T*("`@
M(&)R96%K.PI]"@HD=&ET;&4@/2!?*")5<V5R($%D;6EN:7-T<F%T:6]N(BD[
M"DAO<F1E.CIA9&138W)I<'1&:6QE*"=S=')I<&4N:G,G+"`G:&]R9&4G+"!T
M<G5E*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUH96%D
M97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V%D;6EN+V-O
M;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^;F]T:69Y*&%R<F%Y
M*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["@II9B`H:7-S970H)'5P9&%T
M95]F;W)M*2`F)B`D875T:"T^:&%S0V%P86)I;&ET>2@G;&ES="<I*2!["B`@
M("!R97%U:7)E7V]N8V4@)TAO<F1E+TED96YT:71Y+G!H<"<["B`@("`D:61E
M;G1I='D@/2`F261E;G1I='DZ.G-I;F=L971O;B@G;F]N92<L("1F7W5S97)?
M;F%M92D["B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO
M=7-E<B]U<&1A=&4N:6YC)SL*?2!E;'-E:68@*&ES<V5T*"1R96UO=F5?9F]R
M;2D@)B8@)&%U=&@M/FAA<T-A<&%B:6QI='DH)VQI<W0G*2`F)B`D875T:"T^
M:&%S0V%P86)I;&ET>2@G<F5M;W9E)RDI('L*("`@(')E<75I<F4@2$]21$5?
M5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+W)E;6]V92YI;F,G.PI](&5L<V5I
M9B`H:7-S970H)&-L96%R7V9O<FTI*2!["B`@("!R97%U:7)E($A/4D1%7U1%
M35!,051%4R`N("<O861M:6XO=7-E<B]C;&5A<BYI;F,G.PI](&5L<V5I9B`H
M:7-S970H)')E;6]V97%U975E9%]F;W)M*2D@>PH@("`@<F5Q=6ER92!(3U)$
M15]414U03$%415,@+B`G+V%D;6EN+W5S97(O<F5M;W9E<75E=65D+FEN8R<[
M"GT@96QS96EF("@D875T:"T^:&%S0V%P86)I;&ET>2@G861D)RDI('L*("`@
M(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+V%D9"YI
M;F,G.PH@("`@:68@*"1C;VYF6R=S:6=N=7`G75LG86QL;W<G72`F)B`D8V]N
M9ELG<VEG;G5P)UU;)V%P<')O=F4G72D@>PH@("`@("`@(')E<75I<F4@2$]2
M1$5?5$5-4$Q!5$53("X@)R]A9&UI;B]U<V5R+V%P<')O=F4N:6YC)SL*("`@
M('T*?2!E;'-E('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A
M9&UI;B]U<V5R+VYO861D+FEN8R<["GT*"FEF("@D875T:"T^:&%S0V%P86)I
M;&ET>2@G;&ES="<I*2!["@H@("`@+RH@268@=V4@87)E;B=T('-U<'!L:65D
M('=I=&@@82!P86=E(&YU;6)E<BP@9&5F875L="!T;R!P86=E(#`N("HO"B`@
M("`D<&%G92`](%5T:6PZ.F=E=$9O<FU$871A*"=P86=E)RP@,"D["B`@("`D
M<V5A<F-H7W!A='1E<FX@/2!5=&EL.CIG971&;W)M1&%T82@G<V5A<F-H7W!A
M='1E<FXG+"`G)RD["@H@("`@)'5S97)S(#T@)&%U=&@M/FQI<W15<V5R<R@I
M.PH@("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@2&]R9&4Z.F9A=&%L*"1U<V5R<RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@('T*"B`@("`O*B!2971U<FYS(&]N;'D@=7-E<G,@=&AA="!M871C:"!T
M:&4@<W!E8VEF:65D('!A='1E<FXN("HO"B`@("!R97%U:7)E7V]N8V4@)TAO
M<F1E+T%R<F%Y+G!H<"<["B`@("`D=7-E<G,@/2!P<F5G7V=R97`H)R\G("X@
M)'-E87)C:%]P871T97)N("X@)R\G+"`D=7-E<G,I.PH@("`@<V]R="@D=7-E
M<G,I.PH*("`@(')E<75I<F5?;VYC92`G2&]R9&4O54DO4&%G97(N<&AP)SL*
M("`@("1V:65W=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"=A9&UI;B]U<V5R
M+G!H<"<L("=S96%R8VA?<&%T=&5R;B<L("1S96%R8VA?<&%T=&5R;BD["@H@
M("`@)&YU;6ET96T@/2!C;W5N="@D=7-E<G,I.PH@("`@)'!E<G!A9V4@/2`R
M,#L*"B`@("`D;6EN(#T@)'!A9V4@*B`D<&5R<&%G93L*("`@('=H:6QE("@D
M;6EN(#X@)&YU;6ET96TI('L*("`@("`@("`D<&%G92TM.PH@("`@("`@("1M
M:6X@/2`D<&%G92`J("1P97)P86=E.PH@("`@?0H@("`@)&UA>"`]("1M:6X@
M*R`D<&5R<&%G93L*"B`@("`D<W1A<G0@/2`H)'!A9V4@*B`D<&5R<&%G92D@
M*R`Q.PH@("`@)&5N9"`](&UI;B@D;G5M:71E;2P@)'-T87)T("L@)'!E<G!A
M9V4@+2`Q*3L*"B`@("!R97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M
M:6XO=7-E<B]L:7-T+FEN8R<["GT@96QS92!["B`@("!R97%U:7)E($A/4D1%
M7U1%35!,051%4R`N("<O861M:6XO=7-E<B]N;VQI<W0N:6YC)SL*?0H*<F5Q
M=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+V-M9'-H96QL+G!H<```
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,S(U
M,R`Q,#4Q-30S-#$S-B`P,C$Q,S0`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M861M:6XO8VUD<VAE;&PN<&AP+'8@,2XY+C$P+C8@,C`P-B\P,B\R-"`R,CHT
M.#HR.2!C:'5C:R!%>'`@)`H@*@H@*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H
M=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE
M(&5N8VQO<V5D(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO
M;B`H3$=03"DN($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE
M+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*
M("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@
M+B`G+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S
M92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92](96QP+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH
M*2D@>PH@("`@2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*?0H*)'1I=&QE(#T@7R@B0V]M;6%N9"!3:&5L;"(I.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,G.PH*96-H;R`G/&1I=B!S='EL93TB<&%D9&EN9SHQ,'!X(CXG
M.PII9B`H)&-O;6UA;F0@/2!T<FEM*%5T:6PZ.F=E=$9O<FU$871A*"=C;60G
M*2DI('L*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B0V]M
M;6%N9"(I("X@)SH\+V@Q/CQB<B`O/B<["B`@("!E8VAO("<\<"!C;&%S<STB
M=&5X="(^/&-O9&4^)R`N(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H)&-O;6UA
M;F0I*2`N("<\+V-O9&4^/"]P/B<["@H@("`@96-H;R`G/&)R("\^/&@Q(&-L
M87-S/2)H96%D97(B/B<@+B!?*")297-U;'1S(BD@+B`G.CPO:#$^/&)R("\^
M)SL*("`@(&5C:&\@)SQP<F4@8VQA<W,](G1E>'0B/B<["@H@("`@)&-M9',@
M/2!E>'!L;V1E*")<;B(L("1C;VUM86YD*3L*("`@(&9O<F5A8V@@*"1C;61S
M(&%S("1C;60I('L*("`@("`@("`D8VUD(#T@=')I;2@D8VUD*3L*("`@("`@
M("!I9B`H<W1R;&5N*"1C;60I*2!["B`@("`@("`@("`@('5N<V5T*"1R97-U
M;'1S*3L*("`@("`@("`@("`@9FQU<V@H*3L*("`@("`@("`@("`@96-H;R!H
M=&UL<W!E8VEA;&-H87)S*'-H96QL7V5X96,H)&-M9"DI.PH@("`@("`@('T*
M("`@('T*"B`@("!E8VAO("<\+W!R93X\8G(@+SXG.PI]"C\^"@H\9F]R;2!A
M8W1I;VX](CP_<&AP(&5C:&\@)%]315)615);)U!(4%]314Q&)UT@/SXB(&UE
M=&AO9#TB<&]S="(^"CP_<&AP(%5T:6PZ.G!F;W)M26YP=70H*2`_/@H\=&5X
M=&%R96$@8VQA<W,](F9I>&5D(B!N86UE/2)C;60B(')O=W,](C$P(B!C;VQS
M/2(V,"(^"CP_<&AP(&EF("@A96UP='DH)&-O;6UA;F0I*2!E8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)&-O;6UA;F0I(#\^/"]T97AT87)E83X*/&)R("\^"CQI
M;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(D5X96-U=&4B*2`_/B(@+SX*/#]P:'`@96-H;R!(96QP.CIL
M:6YK*"=A9&UI;B<L("=A9&UI;BUC;61S:&5L;"<I(#\^"@H\+V9O<FT^"CPO
M9&EV/@H\/W!H<`H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO
M;BUF;V]T97(N:6YC)SL*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]D871A=')E92YP:'``````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0W,C,@,3`U
M,34T,S0Q,S8@,#(Q,3,U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN
M+V1A=&%T<F5E+G!H<"QV(#$N-RXR+C0@,C`P-B\P,B\P,2`P.3HS,#HT-B!S
M96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#0M,C`P-B!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/@H@*@H@*B!3964@=&AE(&5N8VQO<V5D
M(&9I;&4@0T]064E.1R!F;W(@;&EC96YS92!I;F9O<FUA=&EO;B`H3$=03"DN
M($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T
M<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@IF=6YC
M=&EO;B!A9&14<F5E*"1P87)E;G0L("1P87)E;G1?:60L("1I;F1E;G0@/2`Q
M*0I["B`@("!G;&]B86P@)&1A=&%T<F5E+"`D=')E93L*"B`@("`D;F]D97,@
M/2`D9&%T871R964M/F=E=$)Y260H1$%40512145?1D]234%47T9,050L("1P
M87)E;G1?:60L('1R=64L("1P87)E;G0L(#$I.PH@("`@)&5X<&%N9&5D(#T@
M)'1R964M/FES17AP86YD960H)'!A<F5N="D["B`@("`D=7)L(#T@2&]R9&4Z
M.G5R;"@G9&%T871R964N<&AP)RD["B`@("!F;W)E86-H("@D;F]D97,@87,@
M)&ED(#T^("1N;V1E*2!["B`@("`@("`@:68@*"1I9"`]/2`D<&%R96YT7VED
M*2!["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D
M=')E92T^861D3F]D92@D<&%R96YT("X@)SHG("X@)&ED+"`D<&%R96YT+"`D
M9&%T871R964M/F=E=%-H;W)T3F%M92@D;F]D92DL("1I;F1E;G0L(&9A;'-E
M+"!A<G)A>2@G=7)L)R`]/B!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)W-H
M;W<G+"`D9&%T871R964M/F=E=%!A<F%M*"=G<F]U<"<I("X@)SHG("X@)&ED
M*2`N("<C<VAO=R<I*3L*("`@("`@("!I9B`H)&5X<&%N9&5D*2!["B`@("`@
M("`@("`@(&%D9%1R964H)'!A<F5N="`N("<Z)R`N("1I9"P@)&ED+"`D:6YD
M96YT("L@,2D["B`@("`@("`@?0H@("`@?0I]"@I`9&5F:6YE*"=(3U)$15]"
M05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I<F5?;VYC
M92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@
M)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92](96QP+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5')E92YP:'`G.PIR97%U:7)E7V]N
M8V4@)TAO<F1E+T1A=&%4<F5E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH
M*2D@>PH@("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T
M*"D["GT*"B1T<F5E(#T@)DAO<F1E7U1R964Z.F9A8W1O<GDH)V1A=&%T<F5E
M)RP@)VAT;6PG*3L*)'1R964M/G-E=$]P=&EO;B@G86QT97)N871E)RP@=')U
M92D["@HD9')I=F5R(#T@)&-O;F9;)V1A=&%T<F5E)UU;)V1R:79E<B==.PHD
M8V]N9FEG(#T@2&]R9&4Z.F=E=$1R:79E<D-O;F9I9R@G9&%T871R964G+"`D
M8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI.PHD9&%T871R964@/2`F1&%T
M851R964Z.G-I;F=L971O;B@D8V]N9ELG9&%T871R964G75LG9')I=F5R)UTI
M.PHD<F]O=',@/2`D9&%T871R964M/F=E=$=R;W5P<R@I.PH*:68@*&ES7V$H
M)')O;W1S+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*"1R;V]T<RD["GT@96QS92!["B`@("!F;W)E86-H("@D<F]O=',@87,@
M)')O;W0I('L*("`@("`@("`D=')E92T^861D3F]D92@D<F]O="P@;G5L;"P@
M)')O;W0L(#`L(&9A;'-E*3L*("`@("`@("`D9&%T871R964@/2`F1&%T851R
M964Z.G-I;F=L971O;B@D9')I=F5R+"!A<G)A>5]M97)G92@D8V]N9FEG+"!A
M<G)A>2@G9W)O=7`G(#T^("1R;V]T*2DI.PH@("`@("`@(&%D9%1R964H)')O
M;W0L($1!5$%44D5%7U)/3U0I.PH@("`@?0I]"@II9B`H)'-H;W<@/2!5=&EL
M.CIG971&;W)M1&%T82@G<VAO=R<I*2!["B`@("!L:7-T*"1R;V]T+"`D:60I
M(#T@97AP;&]D92@G.B<L("1S:&]W*3L*("`@("1D871A=')E92`]("9$871A
M5')E93HZ<VEN9VQE=&]N*"1D<FEV97(L(&%R<F%Y7VUE<F=E*"1C;VYF:6<L
M(&%R<F%Y*"=G<F]U<"<@/3X@)')O;W0I*2D["B`@("`D9&%T82`]("1D871A
M=')E92T^9V5T1&%T82@D:60I.PH@("`@)&%T=')I8G5T97,@/2`D9&%T871R
M964M/F=E=$%T=')I8G5T97,H)&ED*3L*?0H*)'1I=&QE(#T@7R@B1&%T851R
M964@0G)O=W-E<B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I
M9GDH*3L*)'1R964M/G)E;F1E<E1R964H*3L*:68@*"1S:&]W*2!["B`@("!E
M8VAO("<\8G(@+SX\9&EV(&-L87-S/2)T97AT(B!S='EL93TB=VAI=&4M<W!A
M8V4Z<')E(CX\82!I9#TB<VAO=R(^/"]A/B<["B`@("!P<FEN=%]R*"1D871A
M*3L*("`@('!R:6YT7W(H)&%T=')I8G5T97,I.PH@("`@96-H;R`G/"]D:78^
M)SL*?0IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O;W1E
M<BYI;F,G.PH`````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]S97-S:6]N
M<RYP:'``````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#0P,C0@,3`U,34T,S0Q,S8@,#(Q,C`T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z
M(&AO<F1E+V%D;6EN+W-E<W-I;VYS+G!H<"QV(#$N,BXR+C,@,C`P-B\P,2\P
M,2`R,3HR.#HP-2!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#(P,#4M,C`P
M-B!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*("H*("H@4V5E
M('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI8V5N<V4@:6YF;W)M
M871I;VX@*$Q'4$PI+B!)9B!Y;W4*("H@9&ED(&YO="!R96-E:79E('1H:7,@
M9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y;&5F="]L9W!L+FAT
M;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I<FYA;64H7U]&24Q%
M7U\I("X@)R\N+B<I.PIR97%U:7)E7V]N8V4@2$]21$5?0D%312`N("<O;&EB
M+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]-96YU+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O4V5S<VEO;DAA;F1L97(N<&AP)SL*"FEF("@A
M075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ875T:&5N=&EC871I;VY&
M86EL=7)E4F5D:7)E8W0H*3L*?0H*)'1Y<&4@/2`A96UP='DH)&-O;F9;)W-E
M<W-I;VYH86YD;&5R)UU;)W1Y<&4G72D@/R`D8V]N9ELG<V5S<VEO;FAA;F1L
M97(G75LG='EP92==(#H@)VYO;F4G.PII9B`H)'1Y<&4@/3T@)V5X=&5R;F%L
M)RD@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#86XG="!A9&UI;FES
M=&5R(&5X=&5R;F%L('-E<W-I;VX@:&%N9&QE<G,N(BDL("=H;W)D92YE<G)O
M<B<I.PI](&5L<V4@>PH@("`@)'-H(#T@)E-E<W-I;VY(86YD;&5R.CIS:6YG
M;&5T;VXH)'1Y<&4I.PI]"@HD=&ET;&4@/2!?*")397-S:6]N($%D;6EN(BD[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN
M8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM
M:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A>2@G;&ES
M=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*:68@*"%E;7!T>2@D<V@I*2!["B`@
M("`D=7-E<G,@/2`D<V@M/FQI<W1!=71H96YT:6-A=&5D57-E<G,H*3L*("`@
M("1C;W5N="`]("1S:"T^8V]U;G1!=71H96YT:6-A=&5D57-E<G,H*3L*("`@
M(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B0W5R<F5N="!5<V5R
M<R(I.PH@("`@:68@*&ES7V$H)'5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@96-H;R`G/"]H,3X\<"!C;&%S<STB:&5A9&5R8F]X(CX\96T^)R`N
M('-P<FEN=&8H7R@B3&ES=&EN9R!U<V5R<R!F86EL960Z("5S(BDL("1U<V5R
M<RT^9V5T365S<V%G92@I*2`N("<\+V5M/CPO<#XG.PH@("`@?2!E;'-E('L*
M("`@("`@("!E8VAO("<@*"<@+B`D8V]U;G0@+B`G*3PO:#$^)SL*("`@("`@
M("!E8VAO("<\=6P@8VQA<W,](FAE861E<F)O>"!L:6YE9%)O=R(^)SL*("`@
M("`@("!F;W)E86-H("@D=7-E<G,@87,@)'5S97(I('L*("`@("`@("`@("`@
M96-H;R`G/&QI/B<@+B!H=&UL<W!E8VEA;&-H87)S*"1U<V5R*2`N("<\+VQI
M/B<["B`@("`@("`@?0H@("`@("`@(&5C:&\@)SPO=6P^)SL*("`@('T*"B`@
M("!E8VAO("<\8G(@+SXG.PH*("`@("1I9',@/2`D<V@M/F=E=%-E<W-I;VY)
M1',H*3L*("`@(&5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@7R@B0W5R
M<F5N="!397-S:6]N<R(I("X@)SPO:#$^)SL*("`@(&EF("AI<U]A*"1I9',L
M("=014%27T5R<F]R)RDI('L*("`@("`@("!E8VAO("<\<"!C;&%S<STB:&5A
M9&5R8F]X(CX\96T^)R`N('-P<FEN=&8H7R@B3&ES=&EN9R!S97-S:6]N<R!F
M86EL960Z("5S(BDL("1I9',M/F=E=$UE<W-A9V4H*2D@+B`G/"]E;3X\+W`^
M)SL*("`@('T@96QS92!["B`@("`@("`@96-H;R`G/'5L(&-L87-S/2)H96%D
M97)B;W@@;&EN9612;W<B/B<["B`@("`@("`@9F]R96%C:"`H)&ED<R!A<R`D
M=7-E<BD@>PH@("`@("`@("`@("!E8VAO("<\;&D^)R`N(&AT;6QS<&5C:6%L
M8VAA<G,H)'5S97(I("X@)SPO;&D^)SL*("`@("`@("!]"B`@("`@("`@96-H
M;R`G/"]U;#XG.PH@("`@?0I]"@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N
M("<O8V]M;6]N+69O;W1E<BYI;F,G.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A
M9&UI;B]S<6QS:&5L;"YP:'``````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3,S,3(@,3`U,34T,S0Q,S8@,#(Q,38U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-Q;'-H96QL+G!H<"QV(#$N,3@N
M,3`N.2`R,#`V+S`R+S(T(#(R.C0X.C(Y(&-H=6-K($5X<"`D"B`J"B`J($-O
M<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D
M92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O
M<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%7T)!4T4G
M+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXG*3L*<F5Q=6ER95]O;F-E($A/
M4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?;VYC92`G2&]R
M9&4O365N=2YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TAE;'`N<&AP)SL*
M<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI
M('L*("`@($AO<F1E.CIF871A;"@G1F]R8FED9&5N+B<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["GT*"B1T:71L92`](%\H(E-13"!3:&5L;"(I.PI(;W)D93HZ
M861D4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U92D["G)E
M<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<[
M"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A
M9&5R+FEN8R<["@H_/@H\9&EV('-T>6QE/2)P861D:6YG.C$P<'@B/@H\9F]R
M;2!N86UE/2)S<6QS:&5L;"(@86-T:6]N/2(\/W!H<"!E8VAO("1?4T525D52
M6R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B/@H\/W!H<"!5=&EL.CIP
M9F]R;4EN<'5T*"D@/SX*"CP_<&AP"@HD9&)H(#T@)D1".CIC;VYN96-T*"1C
M;VYF6R=S<6PG72D["FEF("AI<U]A*"1D8F@L("=014%27T5R<F]R)RDI('L*
M("`@($AO<F1E.CIF871A;"@D9&)H+"!?7T9)3$5?7RP@7U],24Y%7U\I.PI]
M"B1D8F@M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E4
M65],3U=%4D-!4T4@?"!$0E]03U)404))3$E465]%4E)/4E,I.PH*:68@*%5T
M:6PZ.F=E=$9O<FU$871A*"=L:7-T+71A8FQE<R<I*2!["B`@("`D9&5S8W)I
M<'1I;VX@/2`G3$E35"!404),15,G.PH@("`@)')E<W5L="`]("1D8F@M/F=E
M=$QI<W1/9B@G=&%B;&5S)RD["GT@96QS96EF("A5=&EL.CIG971&;W)M1&%T
M82@G;&ES="UD8G,G*2D@>PH@("`@)&1E<V-R:7!T:6]N(#T@)TQ)4U0@1$%4
M04)!4T53)SL*("`@("1R97-U;'0@/2`D9&)H+3YG971,:7-T3V8H)V1A=&%B
M87-E<R<I.PI](&5L<V5I9B`H)&-O;6UA;F0@/2!T<FEM*%5T:6PZ.F=E=$9O
M<FU$871A*"=S<6PG*2DI('L*("`@("\O($ME97`@82!C86-H92!O9B!P<FEO
M<B!Q=65R:65S(&9O<B!C;VYV96YI96YC92X*("`@(&EF("@A:7-S970H)%]3
M15-324].6R=?<W%L7W%U97)Y7V-A8VAE)UTI*2!["B`@("`@("`@)%]315-3
M24].6R=?<W%L7W%U97)Y7V-A8VAE)UT@/2!A<G)A>2@I.PH@("`@?0H@("`@
M:68@*"@D:V5Y(#T@87)R87E?<V5A<F-H*"1C;VUM86YD+"`D7U-%4U-)3TY;
M)U]S<6Q?<75E<GE?8V%C:&4G72DI("$]/2!F86QS92D@>PH@("`@("`@('5N
M<V5T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==6R1K97E=*3L*("`@
M('T*("`@(&%R<F%Y7W5N<VAI9G0H)%]315-324].6R=?<W%L7W%U97)Y7V-A
M8VAE)UTL("1C;VUM86YD*3L*("`@('=H:6QE("AC;W5N="@D7U-%4U-)3TY;
M)U]S<6Q?<75E<GE?8V%C:&4G72D@/B`R,"D@>PH@("`@("`@(&%R<F%Y7W!O
M<"@D7U-%4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72D["B`@("!]"@H@("`@
M+R\@4&%R<V4@;W5T('1H92!Q=65R>2!R97-U;'1S+@H@("`@)')E<W5L="`]
M("1D8F@M/G%U97)Y*%-T<FEN9SHZ8V]N=F5R=$-H87)S970H)&-O;6UA;F0L
M($Y,4SHZ9V5T0VAA<G-E="@I+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI
M.PI]"@II9B`H:7-S970H)')E<W5L="DI('L*("`@(&EF("AI<W-E="@D8V]M
M;6%N9"DI('L*("`@("`@("!E8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N
M(%\H(E%U97)Y(BD@+B`G/"]H,3X\8G(@+SX\<')E(&-L87-S/2)T97AT(CXG
M("X@:'1M;'-P96-I86QC:&%R<R@D8V]M;6%N9"D@+B`G/"]P<F4^)SL*("`@
M('T*"B`@("!E8VAO("<\:#$@8VQA<W,](FAE861E<B(^)R`N(%\H(E)E<W5L
M=',B*2`N("<\+V@Q/CQB<B`O/B<["@H@("`@:68@*&ES7V$H)')E<W5L="P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@(&5C:&\@)SQP<F4@8VQA<W,](G1E
M>'0B/B<[('9A<E]D=6UP*"1R97-U;'0I.R!E8VAO("<\+W!R93XG.PH@("`@
M?2!E;'-E('L*("`@("`@("!I9B`H:7-?;V)J96-T*"1R97-U;'0I*2!["B`@
M("`@("`@("`@(&5C:&\@)SQT86)L92!C96QL<W!A8VEN9STB,2(@8VQA<W,]
M(FET96T@<W1R:7!E9"(^)SL*("`@("`@("`@("`@)&9I<G-T(#T@=')U93L*
M("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!W:&EL92`H)')O=R`]
M("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI('L*("`@
M("`@("`@("`@("`@(&EF("@D9FER<W0I('L*("`@("`@("`@("`@("`@("`@
M("!E8VAO("<\='(^)SL*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<F]W(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!E8VAO("<\=&@@86QI9VX](FQE9G0B/B<@+B`H96UP='DH)&ME>2D@/R`G
M)FYB<W`[)R`Z(&AT;6QS<&5C:6%L8VAA<G,H4W1R:6YG.CIC;VYV97)T0VAA
M<G-E="@D:V5Y+"`D8V]N9ELG<W%L)UU;)V-H87)S970G72DI*2`N("<\+W1H
M/B<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M(&5C:&\@)SPO='(^)SL*("`@("`@("`@("`@("`@("`@("`D9FER<W0@/2!F
M86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5C:&\@
M)SQT<CXG.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)')O=R!A<R`D=F%L
M*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`G/'1D(&-L87-S/2)F:7AE
M9"(^)R`N("AE;7!T>2@D=F%L*2`_("<F;F)S<#LG(#H@:'1M;'-P96-I86QC
M:&%R<RA3=')I;F<Z.F-O;G9E<G1#:&%R<V5T*"1V86PL("1C;VYF6R=S<6PG
M75LG8VAA<G-E="==*2DI("X@)SPO=&0^)SL*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5C:&\@)SPO='(^)SL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E8VAO("<\+W1A8FQE/B<["B`@("`@("`@?2!E;'-E:68@
M*&ES7V%R<F%Y*"1R97-U;'0I*2!["B`@("`@("`@("`@(&5C:&\@)SQT86)L
M92!C96QL<W!A8VEN9STB,2(@8VQA<W,](FET96T@<W1R:7!E9"(^)SL*("`@
M("`@("`@("`@)&9I<G-T(#T@=')U93L*("`@("`@("`@("`@)&D@/2`P.PH@
M("`@("`@("`@("!F;W)E86-H("@D<F5S=6QT(&%S("1V86PI('L*("`@("`@
M("`@("`@("`@(&EF("@D9FER<W0I('L*("`@("`@("`@("`@("`@("`@("!E
M8VAO("<\='(^/'1H(&%L:6=N/2)L969T(CXG("X@*&ES<V5T*"1D97-C<FEP
M=&EO;BD@/R!H=&UL<W!E8VEA;&-H87)S*"1D97-C<FEP=&EO;BD@.B`G)FYB
M<W`[)RD@+B`G/"]T:#X\+W1R/B<["B`@("`@("`@("`@("`@("`@("`@)&9I
M<G-T(#T@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!E8VAO("<\='(^/'1D(&-L87-S/2)F:7AE9"(^)R`N("AE;7!T>2@D=F%L
M*2`_("<F;F)S<#LG(#H@:'1M;'-P96-I86QC:&%R<RA3=')I;F<Z.F-O;G9E
M<G1#:&%R<V5T*"1V86PL("1C;VYF6R=S<6PG75LG8VAA<G-E="==*2DI("X@
M)SPO=&0^/"]T<CXG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5C:&\@
M)SPO=&%B;&4^)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!E8VAO
M("<\<W1R;VYG/B<@+B!?*")3=6-C97-S(BD@+B`G/"]S=')O;F<^)SL*("`@
M("`@("!]"B`@("!]"@H@("`@96-H;R`G/&)R("\^)SL*?0H_/@H*/#]P:'`@
M:68@*&ES<V5T*"1?4T534TE/3ELG7W-Q;%]Q=65R>5]C86-H92==*2`F)@H@
M("`@("`@("`@8V]U;G0H)%]315-324].6R=?<W%L7W%U97)Y7V-A8VAE)UTI
M*3H@/SX*("`\<V5L96-T(&YA;64](G%U97)Y7V-A8VAE(B!O;F-H86YG93TB
M9&]C=6UE;G0N<W%L<VAE;&PN<W%L+G9A;'5E(#T@9&]C=6UE;G0N<W%L<VAE
M;&PN<75E<GE?8V%C:&5;9&]C=6UE;G0N<W%L<VAE;&PN<75E<GE?8V%C:&4N
M<V5L96-T961);F1E>%TN=F%L=64[(CX*("`\/W!H<"!F;W)E86-H("@D7U-%
M4U-)3TY;)U]S<6Q?<75E<GE?8V%C:&4G72!A<R`D<75E<GDI.B`_/@H@("`@
M/&]P=&EO;B!V86QU93TB/#]P:'`@96-H;R!H=&UL<W!E8VEA;&-H87)S*"1Q
M=65R>2D@/SXB/CP_<&AP(&5C:&\@:'1M;'-P96-I86QC:&%R<R@D<75E<GDI
M(#\^/"]O<'1I;VX^"B`@/#]P:'`@96YD9F]R96%C:#L@/SX*("`\+W-E;&5C
M=#X*("`\:6YP=70@='EP93TB8G5T=&]N(B!V86QU93TB/#]P:'`@96-H;R!?
M*")087-T92(I(#\^(B!C;&%S<STB8G5T=&]N(B!O;F-L:6-K/2)D;V-U;65N
M="YS<6QS:&5L;"YS<6PN=F%L=64@/2!D;V-U;65N="YS<6QS:&5L;"YQ=65R
M>5]C86-H95MD;V-U;65N="YS<6QS:&5L;"YQ=65R>5]C86-H92YS96QE8W1E
M9$EN9&5X72YV86QU93LB("\^"B`@/&EN<'5T('1Y<&4](F)U='1O;B(@=F%L
M=64](CP_<&AP(&5C:&\@7R@B4G5N(BD@/SXB(&-L87-S/2)B=71T;VXB(&]N
M8VQI8VL](F1O8W5M96YT+G-Q;'-H96QL+G-Q;"YV86QU92`](&1O8W5M96YT
M+G-Q;'-H96QL+G%U97)Y7V-A8VAE6V1O8W5M96YT+G-Q;'-H96QL+G%U97)Y
M7V-A8VAE+G-E;&5C=&5D26YD97A=+G9A;'5E.R!D;V-U;65N="YS<6QS:&5L
M;"YS=6)M:70H*3LB("\^"B`@/&)R("\^"CP_<&AP(&5N9&EF.R`_/@H*/'1E
M>'1A<F5A(&-L87-S/2)F:7AE9"(@;F%M93TB<W%L(B!R;W=S/2(Q,"(@8V]L
M<STB-C`B/@H\/W!H<"!I9B`H(65M<'1Y*"1C;VUM86YD*2D@96-H;R!H=&UL
M<W!E8VEA;&-H87)S*"1C;VUM86YD*2`_/CPO=&5X=&%R96$^"CQB<B`O/@H\
M:6YP=70@='EP93TB<W5B;6ET(B!C;&%S<STB8G5T=&]N(B!V86QU93TB/#]P
M:'`@96-H;R!?*")%>&5C=71E(BD@/SXB("\^"CQI;G!U="!T>7!E/2)B=71T
M;VXB(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H<"!E8VAO(%\H(D-L96%R
M(%%U97)Y(BD@/SXB(&]N8VQI8VL](F1O8W5M96YT+G-Q;'-H96QL+G-Q;"YV
M86QU93TG)R(@+SX*/#]P:'`@:68@*"%E;7!T>2@D8V]M;6%N9"DI.B`_/@H\
M:6YP=70@='EP93TB<F5S970B(&-L87-S/2)B=71T;VXB('9A;'5E/2(\/W!H
M<"!E8VAO(%\H(E)E<W1O<F4@3&%S="!1=65R>2(I(#\^(B`O/@H\/W!H<"!E
M;F1I9CL@/SX*/#]P:'`@:68@*"1D8F@M/F=E=%-P96-I86Q1=65R>2@G=&%B
M;&5S)RD@(3T](&YU;&PI.B`_/CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S
M/2)B=71T;VXB(&YA;64](FQI<W0M=&%B;&5S(B!V86QU93TB/#]P:'`@96-H
M;R!?*"),:7-T(%1A8FQE<R(I(#\^(B`O/B`\/W!H<"!E;F1I9CL@/SX*/#]P
M:'`@:68@*"1D8F@M/F=E=%-P96-I86Q1=65R>2@G9&%T86)A<V5S)RD@(3T]
M(&YU;&PI.B`_/CQI;G!U="!T>7!E/2)S=6)M:70B(&-L87-S/2)B=71T;VXB
M(&YA;64](FQI<W0M9&)S(B!V86QU93TB/#]P:'`@96-H;R!?*"),:7-T($1A
M=&%B87-E<R(I(#\^(B`O/B`\/W!H<"!E;F1I9CL@/SX*/#]P:'`@96-H;R!(
M96QP.CIL:6YK*"=A9&UI;B<L("=A9&UI;BUS<6QS:&5L;"<I(#\^"@H\+V9O
M<FT^"CPO9&EV/@H\/W!H<`H*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN
M+W1E;7!L871E<RYP:'``````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q-3$S-B`Q,#4Q-30S-#$S-B`P,C$S-#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M($AO<F1E(%1E;7!L871E($%D;6EN"B`J"B`J("1(;W)D93H@:&]R9&4O861M
M:6XO=&5M<&QA=&5S+G!H<"QV(#$N,34N,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X
M.C`U(&IA;B!%>'`@)`H@*@H@*B!&:7)S="!S=&%B(&%T(&$@=&5M<&QA=&4@
M;&]A9&5R(&9O<B!H;W)D92P@=&\@8F4@=7-E9"!B>2!T:&4@:&]R9&4*("H@
M861M:6X@=&\@;&]A9"!A;'1E<FYA=&4@:6YD:79I9'5A;"!T96UP;&%T97,@
M;W(@96YT:7)E('1H96UE<R!F;W(@=&AE"B`J($AO<F1E7U1E;7!L871E('-Y
M<W1E;2X*("H@+2!G:79E<R!A(&QI<W0@;V8@86-T:79E(&AO<F1E(&%P<',@
M86YD('1H96ER("]T96UP;&%T97,@9&ER96-T;W)Y"B`J("`@8V]N=&5N=',@
M=&\@8VAO;W-E(&9R;VT*("H@+2!U<V5R(&-A;B!D<FEL;"!D;W=N('1O(&$@
M<W!E8VEF:6,@9FEL92!A;F0@;&]A9"!A<R!M86YY(&%L=&5R;F%T90H@*B`@
M('1E;7!L871E<R!A<R!R97%U:7)E9`H@*B`M(&ET(&%L;&]W<R!S879I;F<@
M;V8@=&5M<&QA=&5S(&]N;'D@;VX@86-T=6%L(&9I;&5S("AA;F0@;F]T"B`J
M("`@9&ER96-T;W)I97,I(&%N9"!D;V5S(&YO="!S:&]W(&AI9&1E;B!F:6QE
M<RX*("H@+2!T:&4@86QT97)N871E('1E;7!L871E<R!A<F4@<W1O<F5D(&EN
M('1H92!61E,@=6YD97(@=&AE(&1I<F5C=&]R>0H@*B`@('!A=&@Z"B`J("`@
M("`@+FAO<F1E7W1E;7!L871E<R\D87!P+W-O;65T96UP;&%T961I<B]T96UP
M;&%T969I;&4*("H@("!S;R!T:&%T(&1I<F5C=&]R>2!W;W5L9"!C;VYT86EN
M(&%L;"!T:&4@86QT97)N871I=F5S(&9O<B!T:&%T"B`J("`@=&5M<&QA=&4N
M"B`J("T@5$]$3SH@9&]N)W0@<VAO=R!C97)T86EN(&]T:&5R(&9I;&5S+"!L
M:6ME($-64R!D:7)E8W1O<FEE<SL@8V]M;65N=',["B`J("`@=&AE;64@<V5L
M96-T:6]N(&%N9"!S=&]R:6YG(&EN('1H92!61E,@=6YD97(Z"B`J("`@("`@
M+FAO<F1E7W1E;7!L871E<R\D87!P+U]T:&5M97,O)'1H96UE+W-O;65T96UP
M;&%T961I<B]T96UP;&%T969I;&4*("H@("!T;R!B92!A8FQE('1O(&-A;&P@
M=7`@86X@96YT:7)E('1H96UE(&=R;W5P(&]F('1E;7!L871E<S\@8F5T=&5R
M(&5R<F]R"B`J("`@8VAE8VMI;F<[(&1O=VYL;V%D:6YG(&]F(&]R:6=I;F%L
M('1E;7!L871E<SL@=&AE(&%P<&QI8V%T:6]N('-I9&4@;V8*("H@("!A;&QO
M=VEN9R!A(&1I9F9E<F5N="!T96UP;&%T92!T;R!B92!C:&]S96XO<')E9G,O
M971C+@H@*@H@*B!#;W!Y<FEG:'0@,C`P,RTR,#`V($UA<FMO($1J=6MI8R`\
M;6%R:V]`;V)L;RYC;VT^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#
M3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO
M=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W
M=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(
M3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G+RXN)RD["G)E<75I
M<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E
M7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]6
M87)I86)L97,N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(
M;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PI]"B1A=71H(#T@)D%U=&@Z.G-I;F=L971O;B@D8V]N9ELG875T:"==6R=D
M<FEV97(G72D["@IF=6YC=&EO;B!?<V5T5F%L=65S5&]+97ES*"1I;BD@>PH@
M("`@)&]U="`](&%R<F%Y*"D["B`@("!F;W)E86-H("@D:6X@87,@)'9A;'5E
M*2!["B`@("`@("`@)&]U=%LD=F%L=65=(#T@)'9A;'5E.PH@("`@?0H@("`@
M87-O<G0H)&]U="D["B`@("!R971U<FX@)&]U=#L*?0H*+RH@4V5T('5P(%9&
M4RX@*B\*<F5Q=6ER95]O;F-E("=61E,N<&AP)SL*)'9F<U]T>7!E(#T@)&-O
M;F9;)W9F<R==6R=T>7!E)UT["B1V9G-?87)G<R`]($AO<F1E.CIG971$<FEV
M97)#;VYF:6<H)W9F<R<L("1V9G-?='EP92D["B1V9G-?87)G<ULG=7-E<B==
M(#T@075T:#HZ9V5T075T:"@I.PHD=F9S(#T@)E9&4SHZ<VEN9VQE=&]N*"1V
M9G-?='EP92P@)'9F<U]A<F=S*3L*"D!D969I;F4H)U1%35!,051%4U]61E-?
M4$%42"<L("<N:&]R9&5?=&5M<&QA=&5S)RD["@HO*B!297%U:7)E($AO<F1E
M7T9O<FT@;&EB<RX@*B\*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<[
M"G)E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP:'`G.PIR97%U
M:7)E7V]N8V4@)TAO<F1E+T9O<FTO06-T:6]N+G!H<"<["@HO*B!3970@=7`@
M2&]R9&5?1F]R;2X@*B\*)'9A<G,@/2`F5F%R:6%B;&5S.CIG971$969A=6QT
M5F%R:6%B;&5S*"D["B1F;W)M(#T@)DAO<F1E7T9O<FTZ.G-I;F=L971O;B@G
M5&5M<&QA=&5S1F]R;2<L("1V87)S*3L*)&%C=&EO;B`]("9(;W)D95]&;W)M
M7T%C=&EO;CHZ9F%C=&]R>2@G<W5B;6ET)RD["@HO*B!3970@=7`@9F]R;2!F
M:65L9',N("HO"B1A<'!S(#T@7W-E=%9A;'5E<U1O2V5Y<R@D<F5G:7-T<GDM
M/FQI<W1!<'!S*"DI.PHD<V5L96-T7V%P<"`]("8D9F]R;2T^861D5F%R:6%B
M;&4H7R@B07!P;&EC871I;VXB*2P@)V%P<"<L("=E;G5M)RP@=')U92P@9F%L
M<V4L(&YU;&PL(&%R<F%Y*"1A<'!S*2D["B1S96QE8W1?87!P+3YS971!8W1I
M;VXH)&%C=&EO;BD["B1F;W)M+3YA9&1(:61D96XH)R<L("=O;&1?87!P)RP@
M)W1E>'0G+"!F86QS92P@9F%L<V4I.PH*+RH@4V5T('5P('-O;64@=F%R:6%B
M;&5S+B`J+PHD9F]R;6YA;64@/2`D=F%R<RT^9V5T*"=F;W)M;F%M92<I.PHD
M87!P(#T@)'9A<G,M/F=E="@G87!P)RD["B1O;&1?87!P(#T@)'9A<G,M/F=E
M="@G;VQD7V%P<"<I.PHD=&5M<&QA=&5?<&%T:"`]("1V87)S+3YG970H)W1E
M;7!L871E7W!A=&@G*3L*)'1E;7!L871E7V]R:6<@/2`D=F%R<RT^9V5T*"=T
M96UP;&%T95]O<FEG)RD["B1O;&1?=&5M<&QA=&5?;W)I9R`]("1V87)S+3YG
M970H)V]L9%]T96UP;&%T95]O<FEG)RD["B1H87-?8VAA;F=E9"`](&9A;'-E
M.PH*:68@*"1A<'`@(3T@)&]L9%]A<'`I('L*("`@("1H87-?8VAA;F=E9"`]
M('1R=64["B`@("`D=&5M<&QA=&5?<&%T:"`]("<G.PH@("`@)'1E;7!L871E
M7V]R:6<@/2`G)SL*("`@("1O;&1?=&5M<&QA=&5?;W)I9R`]("<G.PI]"B1V
M87)S+3YS970H)V]L9%]A<'`G+"`D87!P*3L*:68@*"1T96UP;&%T95]O<FEG
M("$]("1O;&1?=&5M<&QA=&5?;W)I9RD@>PH@("`@)&AA<U]C:&%N9V5D(#T@
M=')U93L*?0HD=F%R<RT^<V5T*"=O;&1?=&5M<&QA=&5?;W)I9R<L("1T96UP
M;&%T95]O<FEG*3L*"FEF("@A:7-?;G5L;"@D87!P*2D@>PH@("`@:68@*"1T
M96UP;&%T95]O<FEG(#T]("<N+B<I('L*("`@("`@("`D<&%T:%]P87)T<R`]
M(&5X<&QO9&4H)R\G+"`D=&5M<&QA=&5?<&%T:"D["B`@("`@("`@87)R87E?
M<&]P*"1P871H7W!A<G1S*3L*("`@("`@("`D=&5M<&QA=&5?<&%T:"`](&EM
M<&QO9&4H)R\G+"`D<&%T:%]P87)T<RD["B`@("`@("`@)'1E;7!L871E7V]R
M:6<@/2`G)SL*("`@('T*"B`@("`O*B!'970@=&AE(&9U;&P@=&5M<&QA=&4@
M<&%T:"!O;B!T:&4@9FEL92!S>7-T96TN("HO"B`@("`D=&5M<&QA=&5?<&%T
M:%]F=6QL(#T@)')E9VES=')Y+3YG970H)W1E;7!L871E<R<L("1A<'`I("X@
M)R\G("X@)'1E;7!L871E7W!A=&@["@H@("`@+RH@268@<V5L96-T960@=&5M
M<&QA=&4@:7,@9&ER96-T;W)Y(&%D9"!T;R!T96UP;&%T92!P871H+B`J+PH@
M("`@:68@*"%E;7!T>2@D=&5M<&QA=&5?;W)I9RD@)B8*("`@("`@("!I<U]D
M:7(H)'1E;7!L871E7W!A=&A?9G5L;"`N("<O)R`N("1T96UP;&%T95]O<FEG
M*2D@>PH@("`@("`@("1T96UP;&%T95]P871H("X]("<O)R`N("1T96UP;&%T
M95]O<FEG.PH@("`@("`@("1T96UP;&%T95]P871H7V9U;&P@+CT@)R\G("X@
M)'1E;7!L871E7V]R:6<["B`@("!]"@H@("`@)&9O<FTM/F%D9%9A<FEA8FQE
M*'-P<FEN=&8H7R@B3W)I9VEN86P@=&5M<&QA=&5S(&EN("5S.B(I+"`D=&5M
M<&QA=&5?<&%T:"DL("=O<FEG7W1E;7!L871E<U]H96%D97(G+"`G:&5A9&5R
M)RP@9F%L<V4L(&9A;'-E*3L*"B`@("`O*B!!9&0@=&AE('!A=&@@=&\@=&AE
M(&AI9&1E;B!V87(@:6X@=&AE(&9O<FTN("HO"B`@("`D9F]R;2T^861D2&ED
M9&5N*"<G+"`G=&5M<&QA=&5?<&%T:"<L("=T97AT)RP@9F%L<V4L(&9A;'-E
M*3L*("`@("1V87)S+3YS970H)W1E;7!L871E7W!A=&@G+"`D=&5M<&QA=&5?
M<&%T:"D["@H@("`@+RH@1V5T(&1I<F5C=&]R>2!L:7-T(&9O<B!C:&]S96X@
M9&ER96-T;W)Y(&EN('1E;7!L871E<RX@*B\*("`@(&EF("@D=&5M<&QA=&5S
M7V1I<B`](&]P96YD:7(H)'1E;7!L871E7W!A=&A?9G5L;"DI('L*("`@("`@
M("!W:&EL92`H9F%L<V4@(3T]("@D9FEL92`](')E861D:7(H)'1E;7!L871E
M<U]D:7(I*2D@>PH@("`@("`@("`@("`O*B!$;VXG="!S:&]W(&-U<G)E;G0@
M9&ER+"!H:61D96X@9FEL97,@86YD(&]N;'D@<VAO=R`G+BXG"B`@("`@("`@
M("`@("`J(&EF(&YO="!I;B!R;V]T(&1I<B!O9B!A;B!A<'`G<R!T96UP;&%T
M97,N("HO"B`@("`@("`@("`@(&EF("@D9FEL92`A/2`B+B(@)B8@(2@D9FEL
M92`]/2`G+BXG("8F(&5M<'1Y*"1T96UP;&%T95]P871H*2D@)B8*("`@("`@
M("`@("`@("`@("$H)&9I;&4@(3T@)RXN)R`F)B!S=6)S='(H)&9I;&4L(#`L
M(#$I(#T]("<N)RDI('L*("`@("`@("`@("`@("`@("1T96UP;&%T97-;72`]
M("1F:6QE.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&-L;W-E
M9&ER*"1T96UP;&%T97-?9&ER*3L*("`@("`@("`D=&5M<&QA=&5S(#T@7W-E
M=%9A;'5E<U1O2V5Y<R@D=&5M<&QA=&5S*3L*("`@("`@("`D=B`]("8D9F]R
M;2T^861D5F%R:6%B;&4H7R@B3W)I9VEN86P@87!P;&EC871I;VX@=&5M<&QA
M=&4B*2P@)W1E;7!L871E7V]R:6<G+"`G96YU;2<L('1R=64L(&9A;'-E+"!N
M=6QL+"!A<G)A>2@D=&5M<&QA=&5S*2D["B`@("`@("`@)'8M/G-E=$%C=&EO
M;B@D86-T:6]N*3L*("`@("`@("`D9F]R;2T^861D2&ED9&5N*"<G+"`G;VQD
M7W1E;7!L871E7V]R:6<G+"`G=&5X="<L(&9A;'-E+"!F86QS92D["B`@("!]
M"@H@("`@+RH@3VYL>2!S970@=7`@=&AE<V4@=F%R<R!I9B!T:&4@8VAO<V5N
M('1E;7!L871E(&ES(&$@9FEL92X@*B\*("`@(&EF("AI<U]F:6QE*"1T96UP
M;&%T95]P871H7V9U;&P@+B`G+R<@+B`D=&5M<&QA=&5?;W)I9RDI('L*("`@
M("`@("`D9F]R;2T^861D5F%R:6%B;&4H7R@B06QT97)N871E('1E;7!L871E
M<R(I+"`G86QT7W1E;7!L871E<U]H96%D97(G+"`G:&5A9&5R)RP@9F%L<V4L
M(&9A;'-E*3L*"B`@("`@("`@+RH@1V5T('1H92!A;')E861Y('-A=F5D(&%L
M=&5R;F%T92!T96UP;&%T97,N("HO"B`@("`@("`@)'9F<U]P871H(#T@5$5-
M4$Q!5$537U9&4U]0051(("X@)R\G("X@)&%P<"`N("1T96UP;&%T95]P871H
M("X@)R\G("X@)'1E;7!L871E7V]R:6<["B`@("`@("`@)'1E;7!L871E<U]A
M;'0@/2!A<G)A>5]K97ES*"1V9G,M/FQI<W1&;VQD97(H)'9F<U]P871H+"!N
M=6QL+"!F86QS92DI.PH@("`@("`@("1T96UP;&%T97-?86QT(#T@87)R87DH
M)R<@/3X@)R<I("L@7W-E=%9A;'5E<U1O2V5Y<R@D=&5M<&QA=&5S7V%L="D[
M"B`@("`@("`@)&9O<FTM/F%D9%9A<FEA8FQE*%\H(D1E;&5T92!E>&ES=&EN
M9R!A;'1E<FYA=&4@=&5M<&QA=&4B*2P@)V1E;&5T95]T96UP;&%T95]A;'0G
M+"`G96YU;2<L(&9A;'-E+"!F86QS92P@;G5L;"P@87)R87DH)'1E;7!L871E
M<U]A;'0I*3L*"B`@("`@("`@)&9O<FTM/F%D9%9A<FEA8FQE*%\H(DEN<V5R
M="!A;'1E<FYA=&4@=&5M<&QA=&4B*2P@)W1E;7!L871E7V%L="<L("=F:6QE
M)RP@9F%L<V4L(&9A;'-E*3L*("`@('T*?0H*:68@*"1F;W)M;F%M92`F)B`A
M)&AA<U]C:&%N9V5D*2!["B`@("`O*B!);G-E<G1I;F<@82!N97<@86QT97)N
M871E('1E;7!L871E+B`J+PH@("`@)&9O<FTM/G9A;&ED871E*"1V87)S*3L*
M"B`@("!I9B`H)&9O<FTM/FES5F%L:60H*2D@>PH@("`@("`@("1F;W)M+3YG
M971);F9O*"1V87)S+"`D:6YF;RD["B`@("`@("`@:68@*"%E;7!T>2@D:6YF
M;ULG9&5L971E7W1E;7!L871E7V%L="==*2D@>PH@("`@("`@("`@("`D=F9S
M+3YD96QE=&5&:6QE*"1V9G-?<&%T:"P@)&EN9F];)V1E;&5T95]T96UP;&%T
M95]A;'0G72D["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&EN9F];
M)W1E;7!L871E7V%L="==6R=S:7IE)UTI*2!["B`@("`@("`@("`@("1V9G,M
M/G=R:71E*"1V9G-?<&%T:"P@)&EN9F];)W1E;7!L871E7V%L="==6R=N86UE
M)UTL("1I;F9O6R=T96UP;&%T95]A;'0G75LG=&UP7VYA;64G72P@=')U92D[
M"B`@("`@("`@?0H@("`@?0I]"@HD=&ET;&4@/2!?*")496UP;&%T92!!9&UI
M;FES=')A=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*"B\J(%)E;F1E
M<B!T:&4@9F]R;2X@*B\*)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E
M;F1E<F5R*"D["B1F;W)M+3YR96YD97)!8W1I=F4H)')E;F1E<F5R+"`D=F%R
M<RP@)W1E;7!L871E<RYP:'`G+"`G<&]S="<I.PH*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+V=R;W5P<RYP:'``````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,#$T
M,B`Q,#4Q-30S-#$S-B`P,C`V-30`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(;W)D93H@:&]R9&4O
M861M:6XO9W)O=7!S+G!H<"QV(#$N-3`N,BXV(#(P,#8O,#<O,3,@,#DZ,#$Z
M-3,@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY+3(P,#8@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC
M;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,
M1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S
M964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("HO
M"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?7T9)3$5?7RD@+B`G
M+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%("X@)R]L:6(O8F%S92YP
M:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+TUE;G4N<&AP)SL*<F5Q=6ER95]O
M;F-E("=(;W)D92]'<F]U<"YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1R
M964N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@("!(;W)D93HZ
M875T:&5N=&EC871I;VY&86EL=7)E4F5D:7)E8W0H*3L*?0H*)&=R;W5P<R`]
M("9'<F]U<#HZ<VEN9VQE=&]N*"D["B1A=71H(#T@)D%U=&@Z.G-I;F=L971O
M;B@D8V]N9ELG875T:"==6R=D<FEV97(G72D["@HD9F]R;2`](&YU;&P["B1R
M96QO860@/2!F86QS93L*)&%C=&EO;DE$(#T@571I;#HZ9V5T1F]R;41A=&$H
M)V%C=&EO;DE$)RD["B1C:60@/2!5=&EL.CIG971&;W)M1&%T82@G8VED)RD[
M"@IS=VET8V@@*"1A8W1I;VY)1"D@>PIC87-E("=A9&1C:&EL9"<Z"B`@("!I
M9B`H)&-I9"`]/2!$051!5%)%15]23T]4*2!["B`@("`@("`@)&9O<FT@/2`G
M861D8VAI;&0N:6YC)SL*("`@("`@("`D9VYA;64@/2!?*")!;&P@1W)O=7!S
M(BD["B`@("!](&5L<V4@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YG
M971'<F]U<$)Y260H)&-I9"D["B`@("`@("`@:68@*"%I<U]A*"1G<F]U<"P@
M)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9VYA;64@/2`D9W)O=7`M
M/F=E=%-H;W)T3F%M92@I.PH@("`@("`@("`@("`D9F]R;2`]("=A9&1C:&EL
M9"YI;F,G.PH@("`@("`@('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G861D
M8VAI;&1F;W)M)SH*("`@("1P87)E;G0@/2`D8VED.PH@("`@:68@*"1P87)E
M;G0@/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1C:&EL9"`]("8D9W)O
M=7!S+3YN97='<F]U<"A5=&EL.CIG971&;W)M1&%T82@G8VAI;&0G*2D["B`@
M("`@("`@)')E<W5L="`]("1G<F]U<',M/F%D9$=R;W5P*"1C:&EL9"D["B`@
M("!](&5L<V4@>PH@("`@("`@("1C:&EL9"`]("8D9W)O=7!S+3YN97='<F]U
M<"A5=&EL.CIG971&;W)M1&%T82@G8VAI;&0G*2P@)'!A<F5N="D["B`@("`@
M("`@)')E<W5L="`]("1G<F]U<',M/F%D9$=R;W5P*"1C:&EL9"D["B`@("!]
M"B`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@
M("`@2&]R9&4Z.FQO9TUE<W-A9V4H)')E<W5L="P@7U]&24Q%7U\L(%]?3$E.
M15]?+"!014%27TQ/1U]%4E(I.PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U
M<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&YO="!C<F5A=&5D.B`E<RXB*2P@
M)&-H:6QD+3YG9713:&]R=$YA;64H*2P@)')E<W5L="T^9V5T365S<V%G92@I
M*2P@)VAO<F1E+F5R<F]R)RD["B`@("!](&5L<V4@>PH@("`@("`@("1N;W1I
M9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@=V%S(&%D9&5D('1O
M('1H92!G<F]U<',@<WES=&5M+B(I+"`D8VAI;&0M/F=E=%-H;W)T3F%M92@I
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D9W)O=7`@/2`D8VAI;&0[
M"B`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@("`@("1R96QO860@
M/2!T<G5E.PH@("`@?0H@("`@8G)E86L["@IC87-E("=D96QE=&4G.@H@("`@
M)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*("`@(&EF
M("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*("`@("`@("`D9F]R
M;2`]("=D96QE=&4N:6YC)SL*("`@('T*("`@(&)R96%K.PH*8V%S92`G9&5L
M971E9F]R;2<Z"B`@("!I9B`H571I;#HZ9V5T1F]R;41A=&$H)V-O;F9I<FTG
M*2`]/2!?*")$96QE=&4B*2D@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S
M+3YG971'<F]U<$)Y260H)&-I9"D["B`@("`@("`@:68@*&ES7V$H)&=R;W5P
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@("`@("1N;W1I9FEC871I;VXM
M/G!U<V@H7R@B071T96UP="!T;R!D96QE=&4@82!N;VXM97AI<W1E;G0@9W)O
M=7`N(BDL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R97-U;'0@/2`D9W)O=7!S+3YR96UO=F5'<F]U<"@D9W)O=7`L
M('1R=64I.PH@("`@("`@("`@("!I9B`H:7-?82@D<F5S=6QT+"`G4$5!4E]%
M<G)O<B<I*2!["B`@("`@("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H
M*'-P<FEN=&8H7R@B56YA8FQE('1O(&1E;&5T92!<(B5S7"(Z("5S+B(I+"`D
M9W)O=7`M/F=E=%-H;W)T3F%M92@I+"`D<F5S=6QT+3YG971-97-S86=E*"DI
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C
M8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB+B(I+"`D9W)O=7`M/F=E=%-H;W)T
M3F%M92@I*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`@("`@("`@("1C
M:60@/2!N=6QL.PH@("`@("`@("`@("`@("`@)')E;&]A9"`]('1R=64["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("!B<F5A:SL*"F-A<V4@
M)V5D:70G.@H@("`@)&=R;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D
M8VED*3L*("`@(&EF("@A:7-?82@D9W)O=7`L("=014%27T5R<F]R)RDI('L*
M("`@("`@("`D9F]R;2`]("=E9&ET+FEN8R<["B`@("!](&5L<V5I9B`H*"1C
M871E9V]R>2`](%5T:6PZ.F=E=$9O<FU$871A*"=C871E9V]R>2<I*2`A/3T@
M;G5L;"D@>PH@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YG971'<F]U<"@D
M8V%T96=O<GDI.PH@("`@("`@(&EF("@A:7-?82@D9W)O=7`L("=014%27T5R
M<F]R)RDI('L*("`@("`@("`@("`@)&9O<FT@/2`G961I="YI;F,G.PH@("`@
M("`@('T@96QS96EF("A5=&EL.CIG971&;W)M1&%T82@G875T;V-R96%T92<I
M*2!["B`@("`@("`@("`@("1P87)E;G0@/2!5=&EL.CIG971&;W)M1&%T82@G
M<&%R96YT)RD["B`@("`@("`@("`@("1G<F]U<"`]("8D9W)O=7!S+3YN97='
M<F]U<"@D8V%T96=O<GDI.PH@("`@("`@("`@("`D<F5S=6QT(#T@)&=R;W5P
M<RT^861D1W)O=7`H)&=R;W5P+"`D<&%R96YT*3L*("`@("`@("`@("`@:68@
M*"%I<U]A*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@
M("`@("1F;W)M(#T@)V5D:70N:6YC)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*("`@(&)R96%K.PH*8V%S92`G961I=&9O<FTG.@H@("`@)&=R
M;W5P(#T@)B1G<F]U<',M/F=E=$=R;W5P0GE)9"@D8VED*3L*"B`@("`O+R!M
M86ME(&$@8V]P>2!O9B!T:&4@9W)O=7`@<V\@=V4@8V%N(')E<W1O<F4@:70@
M:68@=&AE<F4@:7,@86X@97)R;W(N"B`@("`D<F5S=&]R92`]("1G<F]U<#L*
M"B`@("`O+R!!9&0@86YY(&YE=R!U<V5R<RX*("`@("1N97=U<V5R(#T@571I
M;#HZ9V5T1F]R;41A=&$H)VYE=U]U<V5R)RD["B`@("!I9B`H(65M<'1Y*"1N
M97=U<V5R*2D@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D;F5W=7-E<BDI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&YE=W5S97(@87,@)&YE=RD@>PH@("`@
M("`@("`@("`@("`@)&=R;W5P+3YA9&15<V5R*"1N97<L(&9A;'-E*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1G<F]U
M<"T^861D57-E<B@D;F5W=7-E<BP@9F%L<V4I.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!296UO=F4@86YY('5S97)S(&UA<FME9"!F;W(@<'5R9VEN9RX*
M("`@("1R96UO=F5S(#T@571I;#HZ9V5T1F]R;41A=&$H)W)E;6]V92<I.PH@
M("`@:68@*"%E;7!T>2@D<F5M;W9E<RD@)B8@:7-?87)R87DH)')E;6]V97,I
M*2!["B`@("`@("`@9F]R96%C:"`H)')E;6]V97,@87,@)'5S97(@/3X@)&IU
M;FLI('L*("`@("`@("`@("`@)&=R;W5P+3YR96UO=F55<V5R*"1U<V5R+"!F
M86QS92D["B`@("`@("`@?0H@("`@?0H*("`@("\O(%-E="!T:&4@96UA:6P@
M861D<F5S<R!O9B!T:&4@9W)O=7`N"B`@("`D9W)O=7`M/G-E="@G96UA:6PG
M+"!5=&EL.CIG971&;W)M1&%T82@G96UA:6PG*2D["@H@("`@+R\@4V%V92!T
M:&4@9W)O=7`@=&\@=&AE(&)A8VME;F0N"B`@("`D<F5S=6QT(#T@)&=R;W5P
M+3YS879E*"D["@H@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G
M*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)')E<W5L="T^9V5T
M365S<V%G92@I+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`O+R!R97-T;W)E
M(&)A8VMU<"!C;W!Y"B`@("`@("`@)&=R;W5P(#T@)')E<W1O<F4["B`@("!]
M(&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?
M*")5<&1A=&5D(%PB)7-<(BXB*2P@)&=R;W5P+3YG9713:&]R=$YA;64H*2DL
M("=H;W)D92YS=6-C97-S)RD["B`@("!]"@H@("`@)&9O<FT@/2`G961I="YI
M;F,G.PH@("`@)')E;&]A9"`]('1R=64["B`@("!B<F5A:SL*?0H*<W=I=&-H
M("@D9F]R;2D@>PIC87-E("=A9&1C:&EL9"YI;F,G.@H@("`@)&YO=&EF:6-A
M=&EO;BT^<'5S:"@G9&]C=6UE;G0N861D7V-H:6QD+F-H:6QD+F9O8W5S*"DG
M+"`G:F%V87-C<FEP="<I.PH@("`@8G)E86L["@IC87-E("=E9&ET+FEN8R<Z
M"B`@("`O*B!3970@=7`@=&AE(&QI<W1S+B`J+PH@("`@)'5S97)S(#T@)&=R
M;W5P+3YL:7-T57-E<G,H*3L*("`@(&EF("AI<U]A*"1U<V5R<RP@)U!%05)?
M17)R;W(G*2D@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H)'5S97)S
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`D=7-E<G,@/2!A<G)A>2@I.PH@
M("`@?0H@("`@)&%L;%]U<V5R<R`]("1G<F]U<"T^;&ES=$%L;%5S97)S*"D[
M"B`@("!I9B`H:7-?82@D86QL7W5S97)S+"`G4$5!4E]%<G)O<B<I*2!["B`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D86QL7W5S97)S+"`G:&]R9&4N
M97)R;W(G*3L*("`@("`@("`D86QL7W5S97)S(#T@87)R87DH*3L*("`@('T*
M("`@("1I;FAE<FET961?=7-E<G,@/2!A<G)A>5]D:69F*"1A;&Q?=7-E<G,L
M("1U<V5R<RD["@H@("`@:68@*"1A=71H+3YH87-#87!A8FEL:71Y*"=L:7-T
M)RDI('L*("`@("`@("`D=7-E<E]L:7-T(#T@)&%U=&@M/FQI<W15<V5R<R@I
M.PH@("`@("`@(&EF("AI<U]A*"1U<V5R7VQI<W0L("=014%27T5R<F]R)RDI
M('L*("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"@D=7-E<E]L:7-T
M+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("`@("`@)'5S97)?;&ES="`](&%R
M<F%Y*"D["B`@("`@("`@?0H@("`@("`@('-O<G0H)'5S97)?;&ES="D["B`@
M("!](&5L<V4@>PH@("`@("`@("1U<V5R7VQI<W0@/2!A<G)A>2@I.PH@("`@
M?0H@("`@8G)E86L["@I]"@HD=&ET;&4@/2!?*")'<F]U<"!!9&UI;FES=')A
M=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE
M861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO
M8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R
M87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*:68@*"%E;7!T>2@D9F]R
M;2DI('L*("`@(')E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]G
M<F]U<',O)R`N("1F;W)M.PI]"@HO*B!'970@=&AE('!E<FUS('1R964N("HO
M"B1N;V1E<R`]("1G<F]U<',M/FQI<W1'<F]U<',H=')U92D["B1N;V1E<UM$
M051!5%)%15]23T]472`]($1!5$%44D5%7U)/3U0["@HO*B!3970@=7`@<V]M
M92!N;V1E('!A<F%M<RX@*B\*)'-P86-E<B`]("<F;F)S<#LF;F)S<#LF;F)S
M<#LF;F)S<#LG.PHD:6-O;F1I<B`](&%R<F%Y*"=I8V]N9&ER)R`]/B`D<F5G
M:7-T<GDM/F=E=$EM86=E1&ER*"DI.PHD9W)O=7!?;F]D92`]("1I8V]N9&ER
M("L@87)R87DH)VEC;VXG(#T^("=G<F]U<"YP;F<G*3L*)&%D9"`]($AO<F1E
M.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO9W)O=7!S+G!H<#]A8W1I;VY)1#UA
M9&1C:&EL9"<I.PHD961I="`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M
M:6XO9W)O=7!S+G!H<#]A8W1I;VY)1#UE9&ET)RD["B1D96QE=&4@/2!(;W)D
M93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+V=R;W5P<RYP:'`_86-T:6]N240]
M9&5L971E)RD["B1E9&ET7VEM9R`]($AO<F1E.CII;6<H)V5D:70N<&YG)RP@
M7R@B161I="!'<F]U<"(I*3L*)&1E;&5T95]I;6<@/2!(;W)D93HZ:6UG*"=D
M96QE=&4N<&YG)RP@7R@B1&5L971E($=R;W5P(BDI.PH*+RH@4V5T('5P('1H
M92!T<F5E+B`J+PHD=')E92`]($AO<F1E7U1R964Z.F9A8W1O<GDH)V%D;6EN
M7V=R;W5P<R<L("=J879A<V-R:7!T)RD["B1T<F5E+3YS971/<'1I;VXH87)R
M87DH)V%L=&5R;F%T92<@/3X@=')U92P@)VAI9&5(96%D97)S)R`]/B!T<G5E
M*2D["B1T<F5E+3YS971(96%D97(H87)R87DH87)R87DH)W=I9'1H)R`]/B`G
M-3`E)RDI*3L*"B\J($5X<&QI8VET;'D@8VAE8VL@9F]R(#X@,"!S:6YC92!W
M92!C86X@8F4@8V%L;&5D('=I=&@@8W5R<F5N="`]("TQ"B`J(&9O<B!T:&4@
M<F]O="!N;V1E+B`J+PII9B`H)&-I9"`^(#`I('L*("`@("1C:61?<&%R96YT
M<R`]("1G<F]U<',M/F=E=$=R;W5P4&%R96YT3&ES="@D8VED*3L*("`@(&EF
M("AI<U]A*"1C:61?<&%R96YT<RP@)U!%05)?15)R;W(G*2D@>PH@("`@("`@
M($AO<F1E.CIF871A;"@D8VED7W!A<F5N=',L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("!]"GT*"F9O<F5A8V@@*"1N;V1E<R!A<R`D:60@/3X@)&YO9&4I
M('L*("`@("1N;V1E7W!A<F%M<R`]("@D8VED(#T]("1I9"D@/R!A<G)A>2@G
M8VQA<W,G(#T^("=S96QE8W1E9"<I(#H@87)R87DH*3L*("`@(&EF("@D:60@
M/3T@1$%40512145?4D]/5"D@>PH@("`@("`@("1A9&1?:6UG(#T@2&]R9&4Z
M.FEM9R@G9W)O=7`N<&YG)RP@7R@B061D($YE=R!'<F]U<"(I*3L*("`@("`@
M("`D861D7VQI;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H
M)&%D9"P@)V-I9"<L("1I9"DL(%\H(D%D9"!.97<@1W)O=7`B*2D@+B`D861D
M7VEM9R`N("<\+V$^)SL*"B`@("`@("`@)&)A<V5?;F]D95]P87)A;7,@/2`D
M:6-O;F1I<B`K(&%R<F%Y*"=I8V]N)R`]/B`G861M:6YI<W1R871I;VXN<&YG
M)RD["B`@("`@("`@)'1R964M/F%D9$YO9&4H)&ED+"!N=6QL+"!?*")!;&P@
M1W)O=7!S(BDL(#`L('1R=64L("1B87-E7VYO9&5?<&%R86US("L@)&YO9&5?
M<&%R86US+"!A<G)A>2@D<W!A8V5R+"`D861D7VQI;FLI*3L*("`@('T@96QS
M92!["B`@("`@("`@)&YO9&5?<&%R86US6R=U<FPG72`](%5T:6PZ.F%D9%!A
M<F%M971E<B@D961I="P@)V-I9"<L("1I9"D["B`@("`@("`@)&%D9%]I;6<@
M/2!(;W)D93HZ:6UG*"=G<F]U<"YP;F<G+"!?*")!9&0@0VAI;&0@1W)O=7`B
M*2D["B`@("`@("`@)&%D9%]L:6YK(#T@2&]R9&4Z.FQI;FLH571I;#HZ861D
M4&%R86UE=&5R*"1A9&0L("=C:60G+"`D:60I+"!?*")!9&0@0VAI;&0@1W)O
M=7`B*2D@+B`D861D7VEM9R`N("<\+V$^)SL*("`@("`@("`D9&5L971E7VQI
M;FL@/2!(;W)D93HZ;&EN:RA5=&EL.CIA9&1087)A;65T97(H)&1E;&5T92P@
M)V-I9"<L("1I9"DL(%\H(D1E;&5T92!'<F]U<"(I*2`N("1D96QE=&5?:6UG
M("X@)SPO83XG.PH*("`@("`@("`D<&%R96YT7VED(#T@)&=R;W5P<RT^9V5T
M1W)O=7!087)E;G0H)&ED*3L*("`@("`@("`D9W)O=7!?97AT<F$@/2!A<G)A
M>2@D<W!A8V5R+"`D861D7VQI;FLL("1D96QE=&5?;&EN:RD["B`@("`@("`@
M)'1R964M/F%D9$YO9&4H)&ED+"`D<&%R96YT7VED+"`D9W)O=7!S+3YG971'
M<F]U<%-H;W)T3F%M92@D;F]D92DL("1G<F]U<',M/F=E=$QE=F5L*"1I9"D@
M*R`Q+"`H:7-S970H)&-I9%]P87)E;G1S6R1I9%TI*2`_('1R=64@.B!F86QS
M92P@)&=R;W5P7VYO9&4@*R`D;F]D95]P87)A;7,L("1G<F]U<%]E>'1R82D[
M"B`@("!]"GT*"F5C:&\@)SQH,2!C;&%S<STB:&5A9&5R(CXG("X@2&]R9&4Z
M.FEM9R@G9W)O=7`N<&YG)RD@+B`G("<@+B!?*")'<F]U<',B*2`N("<\+V@Q
M/B<["B1T<F5E+3YR96YD97)4<F5E*"D["G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+V%D;6EN+W-E='5P+V1I9F8N<&AP````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C4P-R`Q,#4Q-30S
M-#$S-B`P,C$T,38`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J(%-C<FEP="!T;R!S:&]W('1H92!D:69F
M97)E;F-E<R!B971W965N('1H92!C=7)R96YT;'D@<V%V960@86YD('1H92!N
M97=L>0H@*B!G96YE<F%T960@8V]N9FEG=7)A=&EO;BX*("H*("H@)$AO<F1E
M.B!H;W)D92]A9&UI;B]S971U<"]D:69F+G!H<"QV(#$N-"XQ,"XU(#(P,#8O
M,#4O,C,@,#(Z,3,Z-#(@<V5L<VMY($5X<"`D"B`J"B`J($-O<'ER:6=H="`R
M,#`T+3(P,#8@5&AE($AO<F1E(%!R;VIE8W0@*&AT='`Z+R]W=W<N:&]R9&4N
M;W)G+RD*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R
M(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B`@268@>6]U"B`J(&1I9"!N
M;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S9BYO<F<O
M8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"F1E9FEN92@G2$]21$5?0D%312<L
M(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@
M2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(
M;W)D92]&;W)M+G!H<"<["G)E<75I<F5?;VYC92`G2&]R9&4O0V]N9FEG+G!H
M<"<["G)E<75I<F5?;VYC92`G2&]R9&4O5&5M<&QA=&4N<&AP)SL*:6YC;'5D
M95]O;F-E("=497AT+T1I9F8N<&AP)SL*:6YC;'5D95]O;F-E("=497AT+T1I
M9F8O4F5N9&5R97(N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@
M("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PI]"@HO*B!3970@=7`@=&AE(&1I9F8@<F5N9&5R97(N("HO"B1R96YD
M97)?='EP92`](%5T:6PZ.F=E=$9O<FU$871A*"=R96YD97(G+"`G:6YL:6YE
M)RD["FEN8VQU9&5?;VYC92`G5&5X="]$:69F+U)E;F1E<F5R+R<@+B`D<F5N
M9&5R7W1Y<&4@+B`G+G!H<"<["B1C;&%S<R`]("=497AT7T1I9F9?4F5N9&5R
M97)?)R`N("1R96YD97)?='EP93L*)')E;F1E<F5R(#T@)FYE=R`D8VQA<W,H
M*3L*"B\J*@H@*B!0<FEV871E(&9U;F-T:6]N('1O(')E;F1E<B!T:&4@9&EF
M9F5R96YC97,@9F]R(&$@<W!E8VEF:6,@87!P+@H@*B\*9G5N8W1I;VX@7V=E
M=$1I9F8H)&%P<"D*>PH@("`@9VQO8F%L("1R96YD97)E<BP@)')E9VES=')Y
M.PH*("`@("\J(%)E860@=&AE(&5X:7-T:6YG(&-O;F9I9W5R871I;VXN("HO
M"B`@("`D8W5R<F5N=%]C;VYF:6<@/2`G)SL*("`@("1P871H(#T@)')E9VES
M=')Y+3YG970H)V9I;&5R;V]T)RP@)&%P<"D@+B`G+V-O;F9I9R<["B`@("`D
M8W5R<F5N=%]C;VYF:6<@/2!`9FEL95]G971?8V]N=&5N=',H)'!A=&@@+B`G
M+V-O;F8N<&AP)RD["@H@("`@+RH@0V%L8W5L871E('1H92!D:69F97)E;F-E
M<RX@*B\*("`@("1D:69F(#T@)FYE=R!497AT7T1I9F8H97AP;&]D92@B7&XB
M+"`D8W5R<F5N=%]C;VYF:6<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("!E>'!L;V1E*")<;B(L("1?4T534TE/3ELG7V-O;F9I9R==6R1A<'!=*2D[
M"B`@("`D9&EF9B`]("1R96YD97)E<BT^<F5N9&5R*"1D:69F*3L*("`@(&EF
M("@A96UP='DH)&1I9F8I*2!["B`@("`@("`@<F5T=7)N("1D:69F.PH@("`@
M?2!E;'-E('L*("`@("`@("!R971U<FX@7R@B3F\@8VAA;F=E+B(I.PH@("`@
M?0I]"@HD9&EF9G,@/2!A<G)A>2@I.PHO*B!/;FQY(&)O=&AE<B!T;R!D;R!A
M;GET:&EN9R!I9B!T:&5R92!I<R!A;GD@8V]N9FEG+B`J+PII9B`H(65M<'1Y
M*"1?4T534TE/3ELG7V-O;F9I9R==*2D@>PH@("`@+RH@4V5T('5P('1H92!T
M;V=G;&4@8G5T=&]N(&9O<B!I;FQI;F4O=6YI9FEE9"X@*B\*("`@("1U<FP@
M/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+V1I9F8N<&AP
M)RD["B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U<FPL("=R96YD
M97(G+"`H)')E;F1E<E]T>7!E(#T]("=I;FQI;F4G*2`_("=U;FEF:65D)R`Z
M("=I;FQI;F4G*3L*"B`@("!I9B`H)&%P<"`](%5T:6PZ.F=E=$9O<FU$871A
M*"=A<'`G*2D@>PH@("`@("`@("\J($AA;F1L92!A('-I;F=L92!A<'`@<F5Q
M=65S="X@*B\*("`@("`@("`D=&]G9VQE7W)E;F1E<F5R(#T@2&]R9&4Z.FQI
M;FLH)'5R;"`N("<C)R`N("1A<'`I("X@*"@D<F5N9&5R7W1Y<&4@/3T@)VEN
M;&EN92<I(#\@7R@B=6YI9FEE9"(I(#H@7R@B:6YL:6YE(BDI("X@)SPO83XG
M.PH@("`@("`@("1D:69F(#T@7V=E=$1I9F8H)&%P<"D["B`@("`@("`@:68@
M*"1R96YD97)?='EP92`A/2`G:6YL:6YE)RD@>PH@("`@("`@("`@("`D9&EF
M9B`](&AT;6QS<&5C:6%L8VAA<G,H)&1I9F8I.PH@("`@("`@('T*("`@("`@
M("`D9&EF9G-;72`](&%R<F%Y*"=A<'`G("`]/B`D87!P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)V1I9F8G(#T^("1D:69F+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1O9V=L95]R96YD97)E<B<@/3X@)'1O9V=L95]R96YD
M97)E<BD["B`@("!](&5L<V4@>PH@("`@("`@("\J($QI<W0@86QL('1H92!A
M<'!S('=I=&@@9V5N97)A=&5D(&-O;F9I9W5R871I;VXN("HO"B`@("`@("`@
M:W-O<G0H)%]315-324].6R=?8V]N9FEG)UTI.PH@("`@("`@(&9O<F5A8V@@
M*"1?4T534TE/3ELG7V-O;F9I9R==(&%S("1A<'`@/3X@)&-O;F9I9RD@>PH@
M("`@("`@("`@("`D=&]G9VQE7W)E;F1E<F5R(#T@2&]R9&4Z.FQI;FLH)'5R
M;"`N("<C)R`N("1A<'`I("X@*"@D<F5N9&5R7W1Y<&4@/3T@)VEN;&EN92<I
M(#\@7R@B=6YI9FEE9"(I(#H@7R@B:6YL:6YE(BDI("X@)SPO83XG.PH@("`@
M("`@("`@("`D9&EF9B`](%]G971$:69F*"1A<'`I.PH@("`@("`@("`@("!I
M9B`H)')E;F1E<E]T>7!E("$]("=I;FQI;F4G*2!["B`@("`@("`@("`@("`@
M("`D9&EF9B`](&AT;6QS<&5C:6%L8VAA<G,H)&1I9F8I.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1D:69F<UM=(#T@87)R87DH)V%P<"<@(#T^("1A
M<'`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1I9F8G(#T^("1D
M:69F+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T;V=G;&5?<F5N
M9&5R97(G(#T^("1T;V=G;&5?<F5N9&5R97(I.PH@("`@("`@('T*("`@('T*
M?0H*+RH@4V5T('5P('1H92!T96UP;&%T92X@*B\*)'1E;7!L871E(#T@)FYE
M=R!(;W)D95]496UP;&%T92@I.PHD=&5M<&QA=&4M/G-E=$]P=&EO;B@G9V5T
M=&5X="<L('1R=64I.PHD=&5M<&QA=&4M/G-E="@G9&EF9G,G+"`D9&EF9G,L
M('1R=64I.PH*)'1I=&QE(#T@7R@B0V]N9FEG=7)A=&EO;B!$:69F97)E;F-E
M<R(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E
M<BYI;F,G.PIE8VAO("1T96UP;&%T92T^9F5T8V@H2$]21$5?5$5-4$Q!5$53
M("X@)R]A9&UI;B]S971U<"]D:69F+FAT;6PG*3L*<F5Q=6ER92!(3U)$15]4
M14U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]A9&UI;B]S971U<"]C;VYF:6<N<&AP````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$V-S$@,3`U,34T
M,S0Q,S8@,#(Q-S4Q`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W-E
M='5P+V-O;F9I9RYP:'`L=B`Q+C(T+C0N,3`@,C`P-B\P,R\S,"`Q,#HQ-3HS
M,"!S96QS:WD@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M92A?
M7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"05-%
M("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTN
M<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+T%C=&EO;BYP:'`G.PIR
M97%U:7)E7V]N8V4@)TAO<F1E+T9O<FTO4F5N9&5R97(N<&AP)SL*<F5Q=6ER
M95]O;F-E("=(;W)D92]#;VYF:6<N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]687)I86)L97,N<&AP)SL*"FEF("@A075T:#HZ:7-!9&UI;B@I*2!["B`@
M("!(;W)D93HZ9F%T86PH)T9O<F)I9&1E;BXG+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PI]"@II9B`H(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9&]M>&UL)RD@
M)B8@(55T:6PZ.F5X=&5N<VEO;D5X:7-T<R@G9&]M)RDI('L*("`@($AO<F1E
M.CIF871A;"@G66]U(&YE960@=&AE(&1O;7AM;"!O<B!D;VT@4$A0(&5X=&5N
M<VEO;B!T;R!U<V4@=&AE(&-O;F9I9W5R871I;VX@=&]O;"XG+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PI]"@HD87!P(#T@571I;#HZ9V5T1F]R;41A=&$H)V%P
M<"<I.PHD87!P;F%M92`]("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)&%P<"D[
M"B1T:71L92`]('-P<FEN=&8H7R@B)7,@4V5T=7`B*2P@)&%P<&YA;64I.PH*
M:68@*"1A<'`@/3T](&YU;&P@)B8*("`@(&EN7V%R<F%Y*"1A<'`L("1R96=I
M<W1R>2T^;&ES=$%P<',H87)R87DH)VEN86-T:79E)RP@)VAI9&1E;B<L("=N
M;W1O;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RDI*2D@>PH@("`@)&YO=&EF
M:6-A=&EO;BT^<'5S:"A?*"));G9A;&ED(&%P<&QI8V%T:6]N+B(I+"`G:&]R
M9&4N97)R;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH
M)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@:&5A9&5R*"=,
M;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*)'9A<G,@/2!687)I
M86)L97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*)&9O<FT@/2`F;F5W($-O
M;F9I9T9O<FTH)'9A<G,L("1A<'`I.PHD9F]R;2T^<V5T0G5T=&]N<RAS<')I
M;G1F*%\H(D=E;F5R871E("5S($-O;F9I9W5R871I;VXB*2P@)&%P<&YA;64I
M*3L*:68@*&9I;&5?97AI<W1S*"1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L
M("1A<'`I("X@)R]C;VYF:6<O8V]N9BYP:'`N8F%K)RDI('L*("`@("1F;W)M
M+3YA<'!E;F1"=71T;VYS*%\H(E)E=F5R="!#;VYF:6=U<F%T:6]N(BDI.PI]
M"@HD<&AP(#T@)R<["FEF("A5=&EL.CIG971&;W)M1&%T82@G<W5B;6ET8G5T
M=&]N)RD@/3T@7R@B4F5V97)T($-O;F9I9W5R871I;VXB*2D@>PH@("`@)'!A
M=&@@/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N
M9FEG)SL*("`@(&EF("A`8V]P>2@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RP@
M)'!A=&@@+B`G+V-O;F8N<&AP)RDI('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*%\H(E-U8V-E<W-F=6QL>2!R979E<G1E9"!C;VYF:6=U<F%T:6]N
M+B!296QO860@=&\@<V5E(&-H86YG97,N(BDL("=H;W)D92YS=6-C97-S)RD[
M"B`@("`@("`@0'5N;&EN:R@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RD["B`@
M("!](&5L<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H7R@B0V]U
M;&0@;F]T(')E=F5R="!C;VYF:6=U<F%T:6]N+B(I+"`G:&]R9&4N97)R;W(G
M*3L*("`@('T*?2!E;'-E:68@*"1F;W)M+3YV86QI9&%T92@D=F%R<RDI('L*
M("`@("1C;VYF:6<@/2`F;F5W($AO<F1E7T-O;F9I9R@D87!P*3L*("`@("1P
M:'`@/2`D8V]N9FEG+3YG96YE<F%T95!(4$-O;F9I9R@D=F%R<RD["B`@("`D
M<&%T:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C
M;VYF:6<G.PH@("`@:68@*&9I;&5?97AI<W1S*"1P871H("X@)R]C;VYF+G!H
M<"<I*2!["B`@("`@("`@:68@*$!C;W!Y*"1P871H("X@)R]C;VYF+G!H<"<L
M("1P871H("X@)R]C;VYF+G!H<"YB86LG*2D@>PH@("`@("`@("`@("`D;F]T
M:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY('-A=F5D
M('1H92!B86-K=7`@8V]N9FEG=7)A=&EO;B!F:6QE("5S+B(I+"!5=&EL.CIR
M96%L4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`N8F%K)RDI+"`G:&]R9&4N<W5C
M8V5S<R<I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1N;W1I9FEC
M871I;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V92!T:&4@8F%C
M:W5P(&-O;F9I9W5R871I;VX@9FEL92`E<RXB*2P@571I;#HZ<F5A;%!A=&@H
M)'!A=&@@+B`G+V-O;F8N<&AP+F)A:R<I*2P@)VAO<F1E+G=A<FYI;F<G*3L*
M("`@("`@("!]"B`@("!]"B`@("!I9B`H)&9P(#T@0&9O<&5N*"1P871H("X@
M)R]C;VYF+G!H<"<L("=W)RDI('L*("`@("`@("`O*B!#86X@=W)I=&4L('-O
M(&]U='!U="!T;R!F:6QE+B`J+PH@("`@("`@(&9W<FET92@D9G`L(%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H)'!H<"P@3DQ3.CIG971#:&%R<V5T*"DL("=I
M<V\M.#@U.2TQ)RDI.PH@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("1N
M;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S9G5L;'D@=W)O
M=&4@)7,B*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@+B`G+V-O;F8N<&AP)RDI
M+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("1R96=I<W1R>2T^8VQE87)#
M86-H92@I.PH@("`@("`@(&AE861E<B@G3&]C871I;VXZ("<@+B!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I
M*3L*("`@("`@("!E>&ET.PH@("`@?2!E;'-E('L*("`@("`@("`O*B!#86YN
M;W0@=W)I=&4N("HO"B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I
M;G1F*%\H(D-O=6QD(&YO="!S879E('1H92!C;VYF:6=U<F%T:6]N(&9I;&4@
M)7,N(%EO=2!C86X@96ET:&5R('5S92!O;F4@;V8@=&AE(&]P=&EO;G,@=&\@
M<V%V92!T:&4@8V]D92!B86-K(&]N("5S(&]R(&-O<'D@;6%N=6%L;'D@=&AE
M(&-O9&4@8F5L;W<@=&\@)7,N(BDL(%5T:6PZ.G)E86Q0871H*"1P871H("X@
M)R]C;VYF+G!H<"<I+"!(;W)D93HZ;&EN:RA(;W)D93HZ=7)L*"=I;F1E>"YP
M:'`G*2`N("<C=7!D871E)RP@7R@B4V5T=7`B*2D@+B!?*")3971U<"(I("X@
M)SPO83XG+"!5=&EL.CIR96%L4&%T:"@D<&%T:"`N("<O8V]N9BYP:'`G*2DL
M("=H;W)D92YW87)N:6YG)RP@87)R87DH)V-O;G1E;G0N<F%W)RDI.PH@("`@
M("`@("\J(%-A=F4@=&\@<V5S<VEO;BX@*B\*("`@("`@("`D7U-%4U-)3TY;
M)U]C;VYF:6<G75LD87!P72`]("1P:'`["B`@("!]"GT@96QS96EF("@D9F]R
M;2T^:7-3=6)M:71T960H*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?
M*")4:&5R92!W87,@86X@97)R;W(@:6X@=&AE(&-O;F9I9W5R871I;VX@9F]R
M;2X@4&5R:&%P<R!Y;W4@;&5F="!O=70@82!R97%U:7)E9"!F:65L9"XB*2P@
M)VAO<F1E+F5R<F]R)RD["GT*"B\J(%)E;F1E<B!T:&4@8V]N9FEG=7)A=&EO
M;B!F;W)M+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+U5)+U9A<E)E;F1E<F5R
M+G!H<"<["B1R96YD97)E<B`]("9N97<@2&]R9&5?1F]R;5]296YD97)E<B@I
M.PHD<F5N9&5R97(M/G-E=$%T=')#;VQU;6Y7:61T:"@G-3`E)RD["B1F;W)M
M(#T@571I;#HZ8G5F9F5R3W5T<'5T*&%R<F%Y*"1F;W)M+"`G<F5N9&5R06-T
M:79E)RDL("1R96YD97)E<BP@)'9A<G,L("=C;VYF:6<N<&AP)RP@)W!O<W0G
M*3L*"@HO*B!3970@=7`@=&AE('1E;7!L871E+B`J+PIR97%U:7)E7V]N8V4@
M)TAO<F1E+U1E;7!L871E+G!H<"<["B1T96UP;&%T92`]("9N97<@2&]R9&5?
M5&5M<&QA=&4H*3L*)'1E;7!L871E+3YS970H)W!H<"<L(&AT;6QS<&5C:6%L
M8VAA<G,H)'!H<"DL('1R=64I.PHO*B!#<F5A=&4@=&AE(&QI;FL@9F]R('1H
M92!D:69F('!O<'5P(&]N;'D@:68@<W1O<F5D(&EN('-E<W-I;VXN("HO"FEF
M("@A96UP='DH)%]315-324].6R=?8V]N9FEG)UU;)&%P<%TI*2!["B`@("!(
M;W)D93HZ861D4V-R:7!T1FEL92@G<&]P=7`N:G,G+"`G:&]R9&4G+"!T<G5E
M*3L*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E
M='5P+V1I9F8N<&AP)RD["B`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R
M*"1U<FPL("=A<'`G+"`D87!P*3L*("`@("1L:6YK(#T@2&]R9&4Z.FQI;FLH
M)R,G+"`G)RP@)R<L("<G+"`G<&]P=7`H7"<G("X@)'5R;"`N("=<)RP@-C0P
M+"`T.#`I.R!R971U<FX@9F%L<V4[)RD@+B!?*")S:&]W(&1I9F9E<F5N8V5S
M(BD@+B`G/"]A/B<["B`@("`D=&5M<&QA=&4M/G-E="@G9&EF9E]P;W!U<"<L
M("1L:6YK*3L*?0HD=&5M<&QA=&4M/G-E="@G9F]R;2<L("1F;W)M*3L*)'1E
M;7!L871E+3YS970H)VYO=&EF>2<L(%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A
M>2@D;F]T:69I8V%T:6]N+"`G;F]T:69Y)RDI*3L*)'1E;7!L871E+3YS971/
M<'1I;VXH)V=E='1E>'0G+"!T<G5E*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!
M5$53("X@)R]C;VUM;VXM:&5A9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-
M4$Q!5$53("X@)R]A9&UI;B]C;VUM;VXM:&5A9&5R+FEN8R<["F5C:&\@)'1E
M;7!L871E+3YF971C:"A(3U)$15]414U03$%415,@+B`G+V%D;6EN+W-E='5P
M+V-O;F9I9RYH=&UL)RD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C
M;VUM;VXM9F]O=&5R+FEN8R<["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO<V5T=7`O:6YD97@N<&AP
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(R,C4Q
M(#$P-3$U-#,T,3,V(#`R,38P-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*BH*("H@)$AO<F1E.B!H;W)D92]A
M9&UI;B]S971U<"]I;F1E>"YP:'`L=B`Q+C(X+C0N,3(@,C`P-B\P,R\R."`Q
M,CHS,3HP."!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#
M:&%R;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J
M"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E
M(&EN9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T
M+VQG<&PN:'1M;"X*("HO"@I`9&5F:6YE*"=(3U)$15]"05-%)RP@9&ER;F%M
M92A?7T9)3$5?7RD@+B`G+RXN+RXN)RD["G)E<75I<F5?;VYC92!(3U)$15]"
M05-%("X@)R]L:6(O8F%S92YP:'`G.PIR97%U:7)E7V]N8V4@)TAO<F1E+U1E
M;7!L871E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R
M9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M?0H*+RHJ"B`J(%)E='5R;G,@=&AE($-64R!V97)S:6]N(&9O<B!A(&=I=F5N
M(&9I;&4N"B`J+PIF=6YC=&EO;B!?9V5T5F5R<VEO;B@D9FEL92D*>PH@("`@
M)'-I>F4@/2!`9FEL97-I>F4H)&9I;&4I.PH@("`@:68@*"$D<VEZ92!\?"`A
M:7-?<F5S;W5R8V4H)&9P(#T@0&9O<&5N*"1F:6QE+"`G<B<I*2D@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*("`@("1D871A(#T@0&9R96%D*"1F
M<"P@)'-I>F4I.PH@("`@:68@*'!R96=?;6%T8V@H)R]<)"XJ/V-O;F9<+GAM
M;"QV("@N*C\I("XJ7"0O)RP@)&1A=&$L("1M871C:"DI('L*("`@("`@("!R
M971U<FX@)&UA=&-H6S%=.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"GT*"B\J*@H@*B!$;V5S(&%N($944"!U<&QO860@=&\@
M<V%V92!T:&4@8V]N9FEG=7)A=&EO;BX*("HO"F9U;F-T:6]N(%]U<&QO861&
M5%`H)'!A<F%M<RD*>PH@("`@9VQO8F%L("1R96=I<W1R>2P@)&YO=&EF:6-A
M=&EO;CL*"B`@("!R97%U:7)E7V]N8V4@)U9&4RYP:'`G.PH@("`@)'!A<F%M
M<ULG:&]S='-P96,G72`]("=L;V-A;&AO<W0G.PH@("`@)'9F<R`]("961E,Z
M.G-I;F=L971O;B@G9G1P)RP@)'!A<F%M<RD["B`@("!I9B`H:7-?82@D=F9S
M+"`G4$5!4E]%<G)O<B<I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S
M:"AS<')I;G1F*%\H(D-O=6QD(&YO="!C;VYN96-T('1O('-E<G9E<B!<(B5S
M7"(@=7-I;F<@1E10.B`E<R(I+"`D<&%R86US6R=H;W-T<W!E8R==+"`D=F9S
M+3YG971-97-S86=E*"DI+"`G:&]R9&4N97)R;W(G*3L*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RH@3&]O<"!T:')O=6=H('1H92!C;VYF
M:6<@86YD('=R:71E('1O($944"X@*B\*("`@("1N;U]E<G)O<G,@/2!T<G5E
M.PH@("`@9F]R96%C:"`H)%]315-324].6R=?8V]N9FEG)UT@87,@)&%P<"`]
M/B`D8V]N9FEG*2!["B`@("`@("`@)'!A=&@@/2`D<F5G:7-T<GDM/F=E="@G
M9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG)SL*("`@("`@("`O*B!4<GD@
M=&\@8F%C:R!U<"!T:&4@8W5R<F5N="!C;VYF+G!H<"X@*B\*("`@("`@("!I
M9B`H)'9F<RT^97AI<W1S*"1P871H+"`G8V]N9BYP:'`G*2D@>PH@("`@("`@
M("`@("!I9B`H*"1R97-U;'0@/2`D=F9S+3YR96YA;64H)'!A=&@L("=C;VYF
M+G!H<"<L("1P871H+"`G+V-O;F8N<&AP+F)A:R<I*2`]/3T@=')U92D@>PH@
M("`@("`@("`@("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")3=6-C97-S
M9G5L;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(BDL("=H;W)D92YS
M=6-C97-S)RD["B`@("`@("`@("`@('T@96QS96EF("AI<U]A*"1R97-U;'0L
M("=014%27T5R<F]R)RDI('L*("`@("`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@<V%V92!A(&)A8VMU<"!C
M;VYF:6=U871I;VXZ("5S(BDL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H
M;W)D92YE<G)O<B<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*")#;W5L9"!N;W0@<V%V92!A
M(&)A8VMU<"!C;VYF:6=U871I;VXN(BDL("=H;W)D92YE<G)O<B<I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=W)I=&4@/2`D=F9S+3YW
M<FET941A=&$H)'!A=&@L("=C;VYF+G!H<"<L("1C;VYF:6<I.PH@("`@("`@
M(&EF("AI<U]A*"1W<FET92P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@
M("`D;F]?97)R;W)S(#T@9F%L<V4["B`@("`@("`@("`@("1N;W1I9FEC871I
M;VXM/G!U<V@H<W!R:6YT9BA?*")#;W5L9"!N;W0@=W)I=&4@8V]N9FEG=7)A
M=&EO;B!F;W(@7"(E<UPB.B`E<R(I+"`D87!P+"`D=W)I=&4M/F=E=$UE<W-A
M9V4H*2DL("=H;W)D92YE<G)O<B<I.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")3=6-C97-S
M9G5L;'D@=W)O=&4@)7,B*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@@+B`G+V-O
M;F8N<&AP)RDI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@("`@("`@("!U;G-E
M="@D7U-%4U-)3TY;)U]C;VYF:6<G75LD87!P72D["B`@("`@("`@?0H@("`@
M?0H@("`@)')E9VES=')Y+3YC;&5A<D-A8VAE*"D["B`@("!R971U<FX@)&YO
M7V5R<F]R<SL*?0H*+RH@4V5T('5P('-O;64@:6-O;G,N("HO"B1S=6-C97-S
M(#T@2&]R9&4Z.FEM9R@G86QE<G1S+W-U8V-E<W,N<&YG)RP@)R<L("<G+"`D
M<F5G:7-T<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*3L*)'=A<FYI;F<@/2!(
M;W)D93HZ:6UG*"=A;&5R=',O=V%R;FEN9RYP;F<G+"`G)RP@)R<L("1R96=I
M<W1R>2T^9V5T26UA9V5$:7(H)VAO<F1E)RDI.PHD97)R;W(@/2!(;W)D93HZ
M:6UG*"=A;&5R=',O97)R;W(N<&YG)RP@)R<L("<G+"`D<F5G:7-T<GDM/F=E
M=$EM86=E1&ER*"=H;W)D92<I*3L*"B1C;VYF7W5R;"`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O8V]N9FEG+G!H<"<I.PHD82`]("1R
M96=I<W1R>2T^;&ES=$%P<',H87)R87DH)VEN86-T:79E)RP@)VAI9&1E;B<L
M("=N;W1O;VQB87(G+"`G86-T:79E)RP@)V%D;6EN)RDI.PHD87!P<R`](&%R
M<F%Y*"D["B1I(#T@+3$["F9O<F5A8V@@*"1A(&%S("1A<'`I('L*("`@("\J
M(%-K:7`@87!P(&EF(&YO(&-O;F8N>&UL(&9I;&4N("HO"B`@("`D<&%T:"`]
M("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF:6<G
M.PH@("`@:68@*"%F:6QE7V5X:7-T<R@D<&%T:"`N("<O8V]N9BYX;6PG*2D@
M>PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@("1I*RL["B`@("`D<&%T
M:"`]("1R96=I<W1R>2T^9V5T*"=F:6QE<F]O="<L("1A<'`I("X@)R]C;VYF
M:6<G.PH*("`@("1C;VYF7VQI;FL@/2!5=&EL.CIA9&1087)A;65T97(H)&-O
M;F9?=7)L+"`G87!P)RP@)&%P<"D["B`@("`D8V]N9E]L:6YK(#T@2&]R9&4Z
M.FQI;FLH)&-O;F9?;&EN:RP@<W!R:6YT9BA?*")#;VYF:6=U<F4@)7,B*2P@
M)&%P<"DI.PH@("`@)&%P<'-;)&E=6R=S;W)T)UT@/2`D<F5G:7-T<GDM/F=E
M="@G;F%M92<L("1A<'`I("X@)R`H)R`N("1A<'`@+B`G*2<["B`@("`D87!P
M<ULD:5U;)VYA;64G72`]("1C;VYF7VQI;FL@+B`D87!P<ULD:5U;)W-O<G0G
M72`N("<\+V$^)SL*("`@("1A<'!S6R1I75LG=F5R<VEO;B==(#T@)R<["B`@
M("!I9B`H:7-?<F5A9&%B;&4H)')E9VES=')Y+3YG970H)V9I;&5R;V]T)RP@
M)&%P<"D@+B`G+VQI8B]V97)S:6]N+G!H<"<I*2!["B`@("`@("`@<F5Q=6ER
M92`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O;&EB+W9E
M<G-I;VXN<&AP)SL*("`@("`@("`D=F5R<VEO;E]C;VYS=&%N="`](%-T<FEN
M9SHZ=7!P97(H)&%P<"D@+B`G7U9%4E-)3TXG.PH@("`@("`@(&EF("AD969I
M;F5D*"1V97)S:6]N7V-O;G-T86YT*2D@>PH@("`@("`@("`@("`D87!P<ULD
M:5U;)W9E<G-I;VXG72`](&-O;G-T86YT*"1V97)S:6]N7V-O;G-T86YT*3L*
M("`@("`@("!]"B`@("!]"B`@("!I9B`H(69I;&5?97AI<W1S*"1P871H("X@
M)R]C;VYF+G!H<"<I*2!["B`@("`@("`@+RH@3F\@8V]N9BYP:'`@97AI<W1S
M+B`J+PH@("`@("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O;F9?;&EN:R`N
M("1E<G)O<B`N("<\+V$^)SL*("`@("`@("`D87!P<ULD:5U;)W-T871U<R==
M(#T@7R@B36ES<VEN9R!C;VYF:6=U<F%T:6]N+B!9;W4@:&%V92!T;R!G96YE
M<F%T92!I="!N;W<@:68@>6]U('=A;G0@=&\@=7-E('1H:7,@87!P;&EC871I
M;VXN(BD["B`@("!](&5L<V4@>PH@("`@("`@("\J($$@8V]N9BYP:'`@97AI
M<W1S+"!G970@=&AE('AM;"!V97)S:6]N+B`J+PH@("`@("`@(&EF("@H)'AM
M;%]V97(@/2!?9V5T5F5R<VEO;B@D<&%T:"`N("<O8V]N9BYX;6PG*2D@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("1A<'!S6R1I75LG8V]N9B==(#T@)&-O
M;F9?;&EN:R`N("1W87)N:6YG("X@)SPO83XG.PH@("`@("`@("`@("`D87!P
M<ULD:5U;)W-T871U<R==(#T@7R@B3F\@=F5R<VEO;B!F;W5N9"!I;B!O<FEG
M:6YA;"!C;VYF:6=U<F%T:6]N+B!296=E;F5R871E(&-O;F9I9W5R871I;VXN
M(BD["B`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`O
M*B!'970@=&AE(&=E;F5R871E9"!P:'`@=F5R<VEO;BX@*B\*("`@("`@("!I
M9B`H*"1P:'!?=F5R(#T@7V=E=%9E<G-I;VXH)'!A=&@@+B`G+V-O;F8N<&AP
M)RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`O*B!.;R!V97)S:6]N(&9O
M=6YD(&EN(&=E;F5R871E9"!P:'`L('-U9V=E<W0@<F5G96YA<F%T:6YG"B`@
M("`@("`@("`@("`J(&IU<W0@:6X@8V%S92X@*B\*("`@("`@("`@("`@)&%P
M<'-;)&E=6R=C;VYF)UT@/2`D8V]N9E]L:6YK("X@)'=A<FYI;F<@+B`G/"]A
M/B<["B`@("`@("`@("`@("1A<'!S6R1I75LG<W1A='5S)UT@/2!?*").;R!V
M97)S:6]N(&9O=6YD(&EN('EO=7(@8V]N9FEG=7)A=&EO;BX@4F5G96YE<F%T
M92!C;VYF:6=U<F%T:6]N+B(I.PH@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D>&UL7W9E<B`A/2`D<&AP7W9E<BD@>PH@
M("`@("`@("`@("`O*B!697)S:6]N<R!A<F4@;F]T('1H92!S86UE+"!C;VYF
M:6=U<F%T:6]N(&ES(&]U="!O9B!D871E+B`J+PH@("`@("`@("`@("`D87!P
M<ULD:5U;)V-O;F8G72`]("1C;VYF7VQI;FL@+B`D97)R;W(@+B`G/"]A/B<[
M"B`@("`@("`@("`@("1A<'!S6R1I75LG<W1A='5S)UT@/2!?*")#;VYF:6=U
M<F%T:6]N(&ES(&]U="!O9B!D871E+B(I.PH@("`@("`@("`@("!C;VYT:6YU
M93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!#;VYF:6=U<F%T
M:6]N(&ES(&]K+B`J+PH@("`@("`@("`@("`D87!P<ULD:5U;)V-O;F8G72`]
M("1C;VYF7VQI;FL@+B`D<W5C8V5S<R`N("<\+V$^)SL*("`@("`@("`@("`@
M)&%P<'-;)&E=6R=S=&%T=7,G72`](%\H(D%P<&QI8V%T:6]N(&ES(')E861Y
M+B(I.PH@("`@("`@('T*("`@('T*?0H*+RH@4V]R="!T:&4@87!P<R!B>2!N
M86UE+B`J+PIR97%U:7)E7V]N8V4@)TAO<F1E+T%R<F%Y+G!H<"<["DAO<F1E
M7T%R<F%Y.CIA<G)A>5-O<G0H)&%P<',L("=S;W)T)RD["@HO*B!3970@=7`@
M86YY(&%C=&EO;G,@=&AA="!M87D@8F4@;V9F97)E9"X@*B\*)&%C=&EO;G,@
M/2!A<G)A>2@I.PHD9G1P9F]R;2`]("<G.PII9B`H(65M<'1Y*"1?4T534TE/
M3ELG7V-O;F9I9R==*2D@>PH@("`@2&]R9&4Z.F%D9%-C<FEP=$9I;&4H)W!O
M<'5P+FIS)RP@)VAO<F1E)RP@=')U92D["B`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]S971U<"]D:69F+G!H<"<I.PH@("`@)&%C
M=&EO;B`](%\H(E-H;W<@9&EF9F5R96YC97,@8F5T=V5E;B!C=7)R96YT;'D@
M<V%V960@86YD('1H92!N97=L>2!G96YE<F%T960@8V]N9FEG=7)A=&EO;BXB
M*3L*("`@("1A8W1I;VYS6UT@/2!A<G)A>2@G:6-O;B<@/3X@2&]R9&4Z.FEM
M9R@G<V5A<F-H+G!N9R<L("<G+"`G86QI9VX](FUI9&1L92(G+"`D<F5G:7-T
M<GDM/F=E=$EM86=E1&ER*"=H;W)D92<I*2P*("`@("`@("`@("`@("`@("`@
M("`@("`G;&EN:R<@/3X@2&]R9&4Z.FQI;FLH)R,G+"`G)RP@)R<L("<G+"`G
M<&]P=7`H7"<G("X@)'5R;"`N("=<)RPV-#`L(#0X,"D[(')E='5R;B!F86QS
M93LG*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH*("`@("1U<FP@/2!(;W)D93HZ
M87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+W-C<FEP=',N<&AP)RD["B`@
M("`O*B!!8W1I;VX@=&\@9&]W;FQO860@=&AE(&-O;F9I9W5R871I;VX@=7!G
M<F%D92!02%`@<V-R:7!T+B`J+PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M
M971E<B@D=7)L+"!A<G)A>2@G<V5T=7`G(#T^("=C;VYF)RP@)W1Y<&4G(#T^
M("=P:'`G*2D["B`@("`D86-T:6]N(#T@7R@B1&]W;FQO860@9V5N97)A=&5D
M(&-O;F9I9W5R871I;VX@87,@4$A0('-C<FEP="XB*3L*("`@("1A8W1I;VYS
M6UT@/2!A<G)A>2@G:6-O;B<@/3X@2&]R9&4Z.FEM9R@G9&]W;FQO860N<&YG
M)RP@)R<L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$
M:7(H)VAO<F1E)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]
M/B!(;W)D93HZ;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH@("`@
M+RH@06-T:6]N('1O('-A=F4@=&AE(&-O;F9I9W5R871I;VX@=7!G<F%D92!0
M2%`@<V-R:7!T+B`J+PH@("`@)'5R;"`](%5T:6PZ.F%D9%!A<F%M971E<B@D
M=7)L+"`G<V%V92<L("=T;7`G*3L*("`@("1A8W1I;VX@/2!?*")3879E(&=E
M;F5R871E9"!C;VYF:6=U<F%T:6]N(&%S(&$@4$A0('-C<FEP="!T;R!Y;W5R
M('-E<G9E<B=S('1E;7!O<F%R>2!D:7)E8W1O<GDN(BD["B`@("`D86-T:6]N
M<UM=(#T@87)R87DH)VEC;VXG(#T^($AO<F1E.CII;6<H)W-A=F4N<&YG)RP@
M)R<L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(
M;W)D93HZ;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PH*("`@("\J
M(%-E="!U<"!T:&4@9F]R;2!F;W(@1E10('5P;&]A9"!O9B!S8W)I<'1S+B`J
M+PH@("`@<F5Q=6ER95]O;F-E("=(;W)D92]&;W)M+G!H<"<["B`@("!R97%U
M:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PH*("`@("1V87)S(#T@
M)E9A<FEA8FQE<SHZ9V5T1&5F875L=%9A<FEA8FQE<R@I.PH@("`@)&9T<&9O
M<FT@/2`F2&]R9&5?1F]R;3HZ<VEN9VQE=&]N*"<G+"`D=F%R<RD["B`@("`D
M9G1P9F]R;2T^<V5T5&ET;&4H7R@B1E10('5P;&]A9"!O9B!S971U<"(I*3L*
M("`@("1F='!F;W)M+3YS971"=71T;VYS*%\H(E5P;&]A9"(I+"!T<G5E*3L*
M("`@("1F='!F;W)M+3YA9&1687)I86)L92A?*")5<V5R;F%M92(I+"`G=7-E
M<FYA;64G+"`G=&5X="<L('1R=64L(&9A;'-E+"!N=6QL+"!A<G)A>2@G)RP@
M,C`I*3L*("`@("1F='!F;W)M+3YA9&1687)I86)L92A?*")087-S=V]R9"(I
M+"`G<&%S<W=O<F0G+"`G<&%S<W=O<F0G+"!F86QS92D["@H@("`@:68@*"1F
M='!F;W)M+3YV86QI9&%T92@D=F%R<RDI('L*("`@("`@("`D9G1P9F]R;2T^
M9V5T26YF;R@D=F%R<RP@)&EN9F\I.PH@("`@("`@("1U<&QO860@/2!?=7!L
M;V%D1E10*"1I;F9O*3L*("`@("`@("!I9B`H)'5P;&]A9"D@>PH@("`@("`@
M("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*%\H(E5P;&]A9&5D(&%L;"!A<'!L
M:6-A=&EO;B!S971U<"!F:6QE<R!T;R!T:&4@<V5R=F5R+B(I+"`G:&]R9&4N
M<W5C8V5S<R<I.PH@("`@("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"=A9&UI;B]S971U<"]I;F1E>"YP:'`G+"!T<G5E*3L*("`@("`@
M("`@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@("`@
M("!E>&ET.PH@("`@("`@('T*("`@('T*("`@("\J(%)E;F1E<B!T:&4@9F]R
M;2X@*B\*("`@(')E<75I<F5?;VYC92`G2&]R9&4O1F]R;2]296YD97)E<BYP
M:'`G.PH@("`@)')E;F1E<F5R(#T@)FYE=R!(;W)D95]&;W)M7U)E;F1E<F5R
M*"D["B`@("`D9G1P9F]R;2`](%5T:6PZ.F)U9F9E<D]U='!U="AA<G)A>2@D
M9G1P9F]R;2P@)W)E;F1E<D%C=&EV92<I+"`D<F5N9&5R97(L("1V87)S+"`G
M:6YD97@N<&AP)RP@)W!O<W0G*3L*?0H*:68@*&9I;&5?97AI<W1S*$AO<F1E
M.CIG971496UP1&ER*"D@+B`G+VAO<F1E7W-E='5P7W5P9W)A9&4N<&AP)RDI
M('L*("`@("\J($%C=&EO;B!T;R!R96UO=F4@=&AE(&-O;F9I9W5R871I;VX@
M=7!G<F%D92!02%`@<V-R:7!T+B`J+PH@("`@)'5R;"`]($AO<F1E.CIA<'!L
M:6-A=&EO;E5R;"@G861M:6XO<V5T=7`O<V-R:7!T<RYP:'`G*3L*("`@("1U
M<FP@/2!5=&EL.CIA9&1087)A;65T97(H)'5R;"P@)V-L96%N)RP@)W1M<"<I
M.PH@("`@)&%C=&EO;B`](%\H(E)E;6]V92!S879E9"!S8W)I<'0@9G)O;2!S
M97)V97(G<R!T96UP;W)A<GD@9&ER96-T;W)Y+B(I.PH@("`@)&%C=&EO;G-;
M72`](&%R<F%Y*"=I8V]N)R`]/B!(;W)D93HZ:6UG*"=D96QE=&4N<&YG)RP@
M)R<L("=A;&EG;CTB;6ED9&QE(B<L("1R96=I<W1R>2T^9V5T26UA9V5$:7(H
M)VAO<F1E)RDI+`H@("`@("`@("`@("`@("`@("`@("`@("=L:6YK)R`]/B!(
M;W)D93HZ;&EN:R@D=7)L*2`N("1A8W1I;VX@+B`G/"]A/B<I.PI]"@HO*B!3
M970@=7`@=&AE('1E;7!L871E+B`J+PHD=&5M<&QA=&4@/2`F;F5W($AO<F1E
M7U1E;7!L871E*"D["B1T96UP;&%T92T^<V5T*"=A<'!S)RP@)&%P<',I.PHD
M=&5M<&QA=&4M/G-E="@G86-T:6]N<R<L("1A8W1I;VYS+"!T<G5E*3L*)'1E
M;7!L871E+3YS970H)V9T<&9O<FTG+"`D9G1P9F]R;2P@=')U92D["B1T96UP
M;&%T92T^<V5T*"=N;W1I9GDG+"!5=&EL.CIB=69F97)/=71P=70H87)R87DH
M)&YO=&EF:6-A=&EO;BP@)VYO=&EF>2<I*2D["B1T96UP;&%T92T^<V5T3W!T
M:6]N*"=G971T97AT)RP@=')U92D["@HD=&ET;&4@/2!S<')I;G1F*%\H(B5S
M(%-E='5P(BDL("1R96=I<W1R>2T^9V5T*"=N86UE)RP@)VAO<F1E)RDI.PI(
M;W)D93HZ861D4V-R:7!T1FEL92@G<W1R:7!E+FIS)RP@)VAO<F1E)RP@=')U
M92D["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A9&5R
M+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C;VUM
M;VXM:&5A9&5R+FEN8R<["F5C:&\@)'1E;7!L871E+3YF971C:"A(3U)$15]4
M14U03$%415,@+B`G+V%D;6EN+W-E='5P+VEN9&5X+FAT;6PG*3L*<F5Q=6ER
M92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V%D;6EN+W-E='5P+W-C<FEP=',N<&AP````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#4Q,B`Q,#4Q-30S-#$S-B`P,C(Q-C0`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J($=E;F5R871E<R!U<&=R861E('-C<FEP=',@9F]R($AO<F1E
M)W,@<V5T=7`N($-U<G)E;G1L>2!A;&QO=W,@=&AE(&=E;F5R871I;VX*("H@
M;V8@4$A0('5P9W)A9&4@<V-R:7!T<R!F;W(@8V]N9BYP:'`@9FEL97,@96ET
M:&5R(&%S(&1O=VYL;V%D(&]R('-A=F5D('1O('1H90H@*B!S97)V97(G<R!T
M96UP;W)A<GD@9&ER96-T;W)Y+@H@*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN
M+W-E='5P+W-C<FEP=',N<&AP+'8@,2XY+C$P+C8@,C`P-B\P-B\Q-B`P.#HR
M-#HR-R!J86X@17AP("0*("H*("H@0V]P>7)I9VAT(#$Y.3DM,C`P-B!#:&%R
M;&5S($HN($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!#;W!Y<FEG
M:'0@,3DY.2TR,#`V($IO;B!087)I<V4@/&IO;D!H;W)D92YO<F<^"B`J"B`J
M(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN
M9F]R;6%T:6]N("A,1U!,*2X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@
M=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF<V8N;W)G+V-O<'EL969T+VQG
M<&PN:'1M;"X*("HO"@ID969I;F4H)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?
M1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@
M+B`G+VQI8B]B87-E+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@
M("`@2&]R9&4Z.F9A=&%L*"=&;W)B:61D96XN)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*?0H*+RH@1V5T(&9O<FT@9&%T82X@*B\*)'-E='5P(#T@571I;#HZ
M9V5T1F]R;41A=&$H)W-E='5P)RD["B1T>7!E(#T@571I;#HZ9V5T1F]R;41A
M=&$H)W1Y<&4G*3L*)'-A=F4@/2!5=&EL.CIG971&;W)M1&%T82@G<V%V92<I
M.PHD8VQE86X@/2!5=&EL.CIG971&;W)M1&%T82@G8VQE86XG*3L*"B1F:6QE
M;F%M92`]("=H;W)D95]S971U<%]U<&=R861E+G!H<"<["@HO*B!#:&5C:R!I
M9B!T:&ES(&ES(&]N;'D@82!R97%U97-T('1O(&-L96%N('5P+B`J+PII9B`H
M)&-L96%N(#T]("=T;7`G*2!["B`@("`D=&UP7V1I<B`]($AO<F1E.CIG9714
M96UP1&ER*"D["B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H*"1T;7!?9&ER
M("X@)R\G("X@)&9I;&5N86UE*3L*("`@(&EF("AU;FQI;FLH)'1M<%]D:7(@
M+B`G+R<@+B`D9FEL96YA;64I*2!["B`@("`@("`@)&YO=&EF:6-A=&EO;BT^
M<'5S:"AS<')I;G1F*%\H(D1E;&5T960@<V5T=7`@=7!G<F%D92!S8W)I<'0@
M7"(E<UPB+B(I+"`D<&%T:"DL("=H;W)D92YS=6-C97-S)RD["B`@("!](&5L
M<V4@>PH@("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")#
M;W5L9"!N;W0@9&5L971E('-E='5P('5P9W)A9&4@<V-R:7!T(%PB)7-<(BXB
M*2P@571I;#HZ<F5A;%!A=&@H)'!A=&@I*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("!]"B`@("`D<F5G:7-T<GDM/F-L96%R0V%C:&4H*3L*("`@("1U<FP@/2!(
M;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L
M('1R=64I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@
M97AI=#L*?0H*)&1A=&$@/2`G)SL*:68@*"1S971U<"`]/2`G8V]N9B<@)B8@
M)'1Y<&4@/3T@)W!H<"<I('L*("`@("\J($$@8FET('5G;'D@:&5R92P@<V%V
M92!02%`@8V]D92!I;G1O(&$@<W1R:6YG(&9O<B!C<F5A=&EN9R!T:&4@<V-R
M:7!T"B`@("`@*B!T;R!B92!R=6X@870@=&AE(&-O;6UA;F0@<')O;7!T+B`J
M+PH@("`@)&1A=&$@/2`G(R$O=7-R+V)I;B]P:'`G("X@(EQN(CL*("`@("1D
M871A("X]("<\/W!H<"<@+B`B7&XB.PH@("`@9F]R96%C:"`H)%]315-324].
M6R=?8V]N9FEG)UT@87,@)&%P<"`]/B`D<&AP*2!["B`@("`@("`@)'!A=&@@
M/2`D<F5G:7-T<GDM/F=E="@G9FEL97)O;W0G+"`D87!P*2`N("<O8V]N9FEG
M)SL*("`@("`@("`O*B!!9&0@8V]D92!T;R!S879E(&)A8VMU<"X@*B\*("`@
M("`@("`D9&%T82`N/2`G:68@*&9I;&5?97AI<W1S*%PG)R`N("1P871H("X@
M)R]C;VYF+G!H<%PG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@
M("`@:68@*$!C;W!Y*%PG)R`N("1P871H("X@)R]C;VYF+G!H<%PG+"!<)R<@
M+B`D<&%T:"`N("<O8V]N9BYP:'`N8F%K7"<I*2![)R`N(")<;B(["B`@("`@
M("`@)&1A=&$@+CT@)R`@("`@("`@96-H;R!<)R<@+B!?*")3=6-C97-S9G5L
M;'D@<V%V960@8F%C:W5P(&-O;F9I9W5R871I;VXN(BD@+B`G7"<@+B`B7&XB
M.R<@+B`B7&XB.PH@("`@("`@("1D871A("X]("<@("`@?2!E;'-E('LG("X@
M(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@("`@("!E8VAO(%PG)R`N(%\H
M(D-O=6QD(&YO="!S879E(&$@8F%C:W5P(&-O;F9I9W5A=&EO;BXB*2`N("=<
M)R`N(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!])R`N
M(")<;B(["B`@("`@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*"B`@("`@("`@
M)&1A=&$@+CT@)VEF("@D9G`@/2!`9F]P96XH7"<G("X@)'!A=&@@+B`G+V-O
M;F8N<&AP7"<L(%PG=UPG*2D@>R<@+B`B7&XB.PH@("`@("`@("1D871A("X]
M("<@("`@9G=R:71E*"1F<"P@7"<G.PH@("`@("`@("1D871A("X](%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H<W1R7W)E<&QA8V4H87)R87DH)UQ<)RP@)UPG
M)RDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G7%Q<7"<L("=<7%PG)RDL"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&AP
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($Y,
M4SHZ9V5T0VAA<G-E="@I+"`G:7-O+3@X-3DM,2<I.PH@("`@("`@("1D871A
M("X]("=<)RD[)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!F8VQO
M<V4H)&9P*3LG("X@(EQN(CL*("`@("`@("`D9&%T82`N/2`G("`@(&5C:&\@
M7"<G("X@<W!R:6YT9BA?*")3879E9"`E<R!C;VYF:6=U<F%T:6]N+B(I+"`D
M87!P*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@
M)WT@96QS92![)R`N(")<;B(["B`@("`@("`@)&1A=&$@+CT@)R`@("!E8VAO
M(%PG)R`N('-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@)7,@8V]N9FEG=7)A
M=&EO;BXB*2P@)&%P<"D@+B`G7"<@+B`B7&XB.R<@+B`B7&XB.PH@("`@("`@
M("1D871A("X]("=])R`N(")<;EQN(CL*("`@('T*?0H*:68@*"1S879E(#T]
M("=T;7`G*2!["B`@("`D=&UP7V1I<B`]($AO<F1E.CIG971496UP1&ER*"D[
M"B`@("`O*B!!9&0@<V5L9BUD97-T<G5C="!C;V1E+B`J+PH@("`@)&1A=&$@
M+CT@)V5C:&\@7"=396QF+61E<W1R=6-T:6YG+BXN7"<@+B`B7&XB.R<@+B`B
M7&XB.PH@("`@)&1A=&$@+CT@)VEF("AU;FQI;FLH7U]&24Q%7U\I*2![)R`N
M(")<;B(["B`@("`D9&%T82`N/2`G("`@(&5C:&\@7"<G("X@7R@B57!G<F%D
M92!S8W)I<'0@9&5L971E9"XB*2`N("=<)R`N(")<;B([)R`N(")<;B(["B`@
M("`D9&%T82`N/2`G?2!E;'-E('LG("X@(EQN(CL*("`@("1D871A("X]("<@
M("`@96-H;R!<)R<@+B!S<')I;G1F*%\H(E=!4DY)3D<A(2$@4D5-3U9%(%-#
M4DE05"!-04Y504Q,62!&4D]-("5S+B(I+"`D=&UP7V1I<BD@+B`G7"<@+B`B
M7&XB.R<@+B`B7&XB.PH@("`@)&1A=&$@+CT@)WTG("X@(EQN(CL*("`@("\J
M(%1H92!S8W)I<'0@<VAO=6QD(&)E('-A=F5D('1O('-E<G9E<B=S('1E;7!O
M<F%R>2!D:7)E8W1O<GDN("HO"B`@("`D<&%T:"`](%5T:6PZ.G)E86Q0871H
M*"1T;7!?9&ER("X@)R\G("X@)&9I;&5N86UE*3L*("`@(&EF("@D9G`@/2!`
M9F]P96XH)'1M<%]D:7(@+B`G+R<@+B`D9FEL96YA;64L("=W)RDI('L["B`@
M("`@("`@9G=R:71E*"1F<"P@)&1A=&$I.PH@("`@("`@(&9C;&]S92@D9G`I
M.PH@("`@("`@(&-H;6]D*"1T;7!?9&ER("X@)R\G("X@)&9I;&5N86UE+"`P
M-S<W*3L*("`@("`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B
M4V%V960@<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A
M=&@I+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@?2!E;'-E('L*("`@("`@("`D
M;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B0V]U;&0@;F]T('-A=F4@
M<V5T=7`@=7!G<F%D92!S8W)I<'0@=&\Z(%PB)7-<(BXB*2P@)'!A=&@I+"`G
M:&]R9&4N97)R;W(G*3L*("`@('T*("`@("1U<FP@/2!(;W)D93HZ87!P;&EC
M871I;VY5<FPH)V%D;6EN+W-E='5P+VEN9&5X+G!H<"<L('1R=64I.PH@("`@
M:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?2!E;'-E
M('L*("`@("\J($]U='!U="!S8W)I<'0@=&\@8G)O=W-E<B!F;W(@9&]W;FQO
M860N("HO"B`@("`D8G)O=W-E<BT^9&]W;FQO861(96%D97)S*"1F:6QE;F%M
M92P@)W1E>'0O<&QA:6XG+"!F86QS92P@<W1R;&5N*"1D871A*2D["B`@("!E
M8VAO("1D871A.PI]"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO
M<&5R;7,O961I="YP:'``````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$P-C4V(#$P-3$U-#,T,3,V(#`R,30R,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AO<F1E.B!H;W)D92]A9&UI;B]P97)M<R]E9&ET+G!H<"QV(#$N,S@N,BXU
M(#(P,#8O,#$O,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H
M="`Q.3DY+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^
M"B`J($-O<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO
M<F1E+F]R9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J
M(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R
M9R]C;W!Y;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%3
M12<L(&1I<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N
M8V4@2$]21$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E
M("=(;W)D92]-96YU+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@
M("`@2&]R9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*
M"B\J(%-E="!U<"!T:&4@9F]R;2!V87)I86)L97,N("HO"G)E<75I<F5?;VYC
M92`G2&]R9&4O5F%R:6%B;&5S+G!H<"<["B1V87)S(#T@)E9A<FEA8FQE<SHZ
M9V5T1&5F875L=%9A<FEA8FQE<R@I.PHD<&5R;5]I9"`]("1V87)S+3YG970H
M)W!E<FU?:60G*3L*)&-A=&5G;W)Y(#T@)'9A<G,M/F=E="@G8V%T96=O<GDG
M*3L*"B\J(%-E92!I9B!W92!N965D('1O("AA;F0@87)E('-U<'!O<V5D('1O
M*2!A=71O8W)E871E('1H92!P97)M:7-S:6]N+B`J+PII9B`H)&-A=&5G;W)Y
M("$]/2!N=6QL*2!["B`@("`D<&5R;6ES<VEO;B`]("8D<&5R;7,M/F=E=%!E
M<FUI<W-I;VXH)&-A=&5G;W)Y*3L*("`@(&EF("AI<U]A*"1P97)M:7-S:6]N
M+"`G4$5!4E]%<G)O<B<I("8F(%5T:6PZ.F=E=$9O<FU$871A*"=A=71O8W)E
M871E)RDI('L*"B`@("`@("`@+RH@0VAE8VL@=&\@<V5E(&EF('1H92!P97)M
M:7-S:6]N('=E(&%R92!C;W!Y:6YG(&9R;VT@97AI<W1S(&)E9F]R92!W90H@
M("`@("`@("`J(&%U=&]C<F5A=&4N("HO"B`@("`@("`@)&-O<'E&<F]M(#T@
M571I;#HZ9V5T1F]R;41A=&$H)V%U=&]C<F5A=&5?8V]P>2<I.PH@("`@("`@
M(&EF("@D8V]P>49R;VT@)B8@(21P97)M<RT^97AI<W1S*"1C;W!Y1G)O;2DI
M('L*("`@("`@("`@("`@)&-O<'E&<F]M(#T@;G5L;#L*("`@("`@("!]"@H@
M("`@("`@("1P87)E;G0@/2`D=F%R<RT^9V5T*"=P87)E;G0G*3L*("`@("`@
M("`D<&5R;6ES<VEO;B`]("8D<&5R;7,M/FYE=U!E<FUI<W-I;VXH)&-A=&5G
M;W)Y*3L*("`@("`@("`D<F5S=6QT(#T@)'!E<FUS+3YA9&1097)M:7-S:6]N
M*"1P97)M:7-S:6]N+"`D<&%R96YT*3L*("`@("`@("!I9B`H(6ES7V$H)')E
M<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@("`@("`D9F]R;2`]("=E
M9&ET+FEN8R<["B`@("`@("`@("`@("1P97)M7VED(#T@)'!E<FUS+3YG9710
M97)M:7-S:6]N260H)'!E<FUI<W-I;VXI.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"1C;W!Y1G)O;2D@>PH@("`@("`@("`@("`O*B!792!H879E(&%U=&]C
M<F5A=&5D('1H92!P97)M:7-S:6]N(&%N9"!W92!H879E(&)E96X@=&]L9"!T
M;PH@("`@("`@("`@("`@*B!C;W!Y(&%N(&5X:7-T:6YG('!E<FUI<W-I;VX@
M9F]R('1H92!D969A=6QT<RX@*B\*("`@("`@("`@("`@)&-O<'E&<F]M3V)J
M(#T@)B1P97)M<RT^9V5T4&5R;6ES<VEO;B@D8V]P>49R;VTI.PH@("`@("`@
M("`@("`D<&5R;6ES<VEO;BT^861D1W5E<W1097)M:7-S:6]N*"1C;W!Y1G)O
M;4]B:BT^9V5T1W5E<W1097)M:7-S:6]N<R@I+"!F86QS92D["B`@("`@("`@
M("`@("1P97)M:7-S:6]N+3YA9&1$969A=6QT4&5R;6ES<VEO;B@D8V]P>49R
M;VU/8FHM/F=E=$1E9F%U;'1097)M:7-S:6]N<R@I+"!F86QS92D["B`@("`@
M("`@("`@("1P97)M:7-S:6]N+3YA9&1#<F5A=&]R4&5R;6ES<VEO;B@D8V]P
M>49R;VU/8FHM/F=E=$-R96%T;W)097)M:7-S:6]N<R@I+"!F86QS92D["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1C;W!Y1G)O;4]B:BT^9V5T57-E<E!E<FUI
M<W-I;VYS*"D@87,@)'5S97(@/3X@)'5P97)M*2!["B`@("`@("`@("`@("`@
M("`D<&5R;6ES<VEO;BT^861D57-E<E!E<FUI<W-I;VXH)'5S97(L("1U<&5R
M;2P@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1C;W!Y1G)O;4]B:BT^9V5T1W)O=7!097)M:7-S:6]N<R@I(&%S("1G<F]U
M<"`]/B`D9W!E<FTI('L*("`@("`@("`@("`@("`@("1P97)M:7-S:6]N+3YA
M9&1'<F]U<%!E<FUI<W-I;VXH)&=R;W5P+"`D9W!E<FTL(&9A;'-E*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\J(%=E
M(&AA=F4@875T;V-R96%T960@=&AE('!E<FUI<W-I;VX@86YD('=E(&1O;B=T
M(&AA=F4@86X*("`@("`@("`@("`@("H@97AI<W1I;F<@<&5R;6ES<VEO;B!T
M;R!C;W!Y+B`@4V5E(&EF('-O;64@9&5F875L=',@=V5R90H@("`@("`@("`@
M("`@*B!S=7!P;&EE9"X@*B\*("`@("`@("`@("`@)&%D9%!E<FUS(#T@571I
M;#HZ9V5T1F]R;41A=&$H)V%U=&]C<F5A=&5?9W5E<W0G*3L*("`@("`@("`@
M("`@:68@*"1A9&1097)M<RD@>PH@("`@("`@("`@("`@("`@)'!E<FUI<W-I
M;VXM/F%D9$=U97-T4&5R;6ES<VEO;B@D861D4&5R;7,L(&9A;'-E*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D861D4&5R;7,@/2!5=&EL.CIG971&
M;W)M1&%T82@G875T;V-R96%T95]D969A=6QT)RD["B`@("`@("`@("`@(&EF
M("@D861D4&5R;7,I('L*("`@("`@("`@("`@("`@("1P97)M:7-S:6]N+3YA
M9&1$969A=6QT4&5R;6ES<VEO;B@D861D4&5R;7,L(&9A;'-E*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D861D4&5R;7,@/2!5=&EL.CIG971&;W)M
M1&%T82@G875T;V-R96%T95]C<F5A=&]R)RD["B`@("`@("`@("`@(&EF("@D
M861D4&5R;7,I('L*("`@("`@("`@("`@("`@("1P97)M:7-S:6]N+3YA9&1#
M<F5A=&]R4&5R;6ES<VEO;B@D861D4&5R;7,L(&9A;'-E*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("`D<&5R;6ES<VEO;BT^<V%V92@I.PH@
M("`@?2!E;'-E('L*("`@("`@("`D<&5R;5]I9"`]("1P97)M<RT^9V5T4&5R
M;6ES<VEO;DED*"1P97)M:7-S:6]N*3L*("`@('T*("`@("1V87)S+3YS970H
M)W!E<FU?:60G+"`D<&5R;5]I9"D["GT@96QS92!["B`@("`D<&5R;6ES<VEO
M;B`]("8D<&5R;7,M/F=E=%!E<FUI<W-I;VY">4ED*"1P97)M7VED*3L*?0H*
M+RH@268@=&AE('!E<FUI<W-I;VX@9F5T8VAE9"!I<R!A;B!E<G)O<B!R971U
M<FX@=&\@=&AE('!E<FUI<W-I;VYS(&QI<W0N("HO"FEF("AI<U]A*"1P97)M
M:7-S:6]N+"`G4$5!4E]%<G)O<B<I*2!["B`@("`D;F]T:69I8V%T:6]N+3YP
M=7-H*%\H(D%T=&5M<'0@=&\@961I="!A(&YO;BUE>&ES=&5N="!P97)M:7-S
M:6]N+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("1U<FP@/2!(;W)D93HZ87!P
M;&EC871I;VY5<FPH)V%D;6EN+W!E<FUS+VEN9&5X+G!H<"<L('1R=64I.PH@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@97AI=#L*?0H*
M<F5Q=6ER95]O;F-E("=(;W)D92]097)M<R]522YP:'`G.PHD=6D@/2`F;F5W
M(%!E<FUS7U5)*"1P97)M<RD["B1U:2T^<V5T5F%R<R@D=F%R<RD["B1U:2T^
M<V5T=7!%9&ET1F]R;2@D<&5R;6ES<VEO;BD["@II9B`H)'5I+3YV86QI9&%T
M945D:71&;W)M*"1I;F9O*2D@>PH@("`@+RH@57!D871E(&%N9"!S879E('1H
M92!P97)M:7-S:6]N<RX@*B\*("`@("1P97)M:7-S:6]N+3YU<&1A=&5097)M
M:7-S:6]N<R@D:6YF;RD["B`@("`D<&5R;6ES<VEO;BT^<V%V92@I.PH@("`@
M)&YO=&EF:6-A=&EO;BT^<'5S:"AS<')I;G1F*%\H(E5P9&%T960@7"(E<UPB
M+B(I+"`D<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S:6]N+3YG971.86UE*"DI
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("1U<FP@/2!5=&EL.CIA9&1087)A
M;65T97(H)V%D;6EN+W!E<FUS+V5D:70N<&AP)RP@)W!E<FU?:60G+"`D<&5R
M;6ES<VEO;BT^9V5T260H*2D["B`@("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T
M:6]N57)L*"1U<FPL('1R=64I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N
M("1U<FPI.PH@("`@97AI=#L*?0H*)'1I=&QE(#T@7R@B4&5R;6ES<VEO;G,@
M061M:6YI<W1R871I;VXB*3L*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G
M+V-O;6UO;BUH96%D97(N:6YC)SL*<F5Q=6ER92!(3U)$15]414U03$%415,@
M+B`G+V%D;6EN+V-O;6UO;BUH96%D97(N:6YC)SL*)&YO=&EF:6-A=&EO;BT^
M;F]T:69Y*&%R<F%Y*"=L:7-T96YE<G,G(#T^("=S=&%T=7,G*2D["@HO*B!2
M96YD97(@=&AE(&9O<FT@86YD('1R964N("HO"B1U:2T^<F5N9&5R1F]R;2@G
M961I="YP:'`G*3L*96-H;R`G/&)R("\^)SL*)'5I+3YR96YD97)4<F5E*"1P
M97)M7VED*3L*"G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM
M9F]O=&5R+FEN8R<["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]P97)M<R]A9&1C
M:&EL9"YP:'``````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#0V,S,@,3`U,34T,S0Q,S8@,#(R,C(V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\J*@H@*B`D2&]R9&4Z(&AO
M<F1E+V%D;6EN+W!E<FUS+V%D9&-H:6QD+G!H<"QV(#$N,C<N,BXT(#(P,#8O
M,#$O,#$@,C$Z,C@Z,#4@:F%N($5X<"`D"B`J"B`J($-O<'ER:6=H="`Q.3DY
M+3(P,#8@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($-O
M<'ER:6=H="`R,#`U+3(P,#8@2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R
M9SX*("H*("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@9F]R(&QI
M8V5N<V4@:6YF;W)M871I;VX@*$Q'4$PI+B!)9B!Y;W4@9&ED"B`J(&YO="!R
M96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F+F]R9R]C;W!Y
M;&5F="]L9W!L+FAT;6PN"B`J+PH*0&1E9FEN92@G2$]21$5?0D%312<L(&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B\N+B<I.PIR97%U:7)E7V]N8V4@2$]2
M1$5?0D%312`N("<O;&EB+V)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=(;W)D
M92]-96YU+G!H<"<["@II9B`H(4%U=&@Z.FES061M:6XH*2D@>PH@("`@2&]R
M9&4Z.F%U=&AE;G1I8V%T:6]N1F%I;'5R95)E9&ER96-T*"D["GT*"B\J(%-E
M="!U<"!T:&4@9F]R;2!V87)I86)L97,N("HO"G)E<75I<F5?;VYC92`G2&]R
M9&4O5F%R:6%B;&5S+G!H<"<["B1V87)S(#T@)E9A<FEA8FQE<SHZ9V5T1&5F
M875L=%9A<FEA8FQE<R@I.PHD<&5R;5]I9"`]("1V87)S+3YG970H)W!E<FU?
M:60G*3L*"B1P97)M:7-S:6]N(#T@)B1P97)M<RT^9V5T4&5R;6ES<VEO;D)Y
M260H)'!E<FU?:60I.PII9B`H:7-?82@D<&5R;6ES<VEO;BP@)U!%05)?17)R
M;W(G*2D@>PH@("`@)&YO=&EF:6-A=&EO;BT^<'5S:"A?*"));G9A;&ED('!A
M<F5N="!P97)M:7-S:6]N+B(I+"`G:&]R9&4N97)R;W(G*3L*("`@("1U<FP@
M/2!(;W)D93HZ87!P;&EC871I;VY5<FPH)V%D;6EN+W!E<FUS+VEN9&5X+G!H
M<"<L('1R=64I.PH@("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@
M("`@97AI=#L*?0H*+RH@4V5T('5P(&9O<FTN("HO"G)E<75I<F5?;VYC92`G
M2&]R9&4O4&5R;7,O54DN<&AP)SL*)'5I(#T@)FYE=R!097)M<U]522@D<&5R
M;7,I.PHD=6DM/G-E=%9A<G,H)'9A<G,I.PHD=6DM/G-E='5P061D1F]R;2@D
M<&5R;6ES<VEO;BD["@II9B`H)'5I+3YV86QI9&%T94%D9$9O<FTH)&EN9F\I
M*2!["B`@("!I9B`H)&EN9F];)W!E<FU?:60G72`]/2!$051!5%)%15]23T]4
M*2!["B`@("`@("`@)&-H:6QD(#T@)B1P97)M<RT^;F5W4&5R;6ES<VEO;B@D
M:6YF;ULG8VAI;&0G72D["B`@("`@("`@)')E<W5L="`]("1P97)M<RT^861D
M4&5R;6ES<VEO;B@D8VAI;&0I.PH@("`@?2!E;'-E('L*("`@("`@("`D<$]B
M(#T@)B1P97)M<RT^9V5T4&5R;6ES<VEO;D)Y260H)&EN9F];)W!E<FU?:60G
M72D["B`@("`@("`@)&YA;64@/2`D<$]B+3YG971.86UE*"D@+B`G.B<@+B!$
M871A5')E93HZ96YC;V1E3F%M92@D:6YF;ULG8VAI;&0G72D["B`@("`@("`@
M)&-H:6QD(#T@)B1P97)M<RT^;F5W4&5R;6ES<VEO;B@D;F%M92D["B`@("`@
M("`@)')E<W5L="`]("1P97)M<RT^861D4&5R;6ES<VEO;B@D8VAI;&0I.PH@
M("`@?0H@("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@
M("`@("`@("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")<(B5S7"(@
M=V%S(&YO="!C<F5A=&5D.B`E<RXB*2P@)'!E<FUS+3YG9714:71L92@D8VAI
M;&0M/F=E=$YA;64H*2DL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D
M92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B7"(E<UPB('=A<R!A9&1E9"!T;R!T:&4@<&5R
M;6ES<VEO;G,@<WES=&5M+B(I+"`D<&5R;7,M/F=E=%1I=&QE*"1C:&EL9"T^
M9V5T3F%M92@I*2DL("=H;W)D92YS=6-C97-S)RD["B`@("`@("`@)'5R;"`]
M($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O961I="YP:'`G
M+"!T<G5E*3L*("`@("`@("`D=7)L(#T@571I;#HZ861D4&%R86UE=&5R*"1U
M<FPL("=P97)M7VED)RP@)&-H:6QD+3YG971)9"@I+"!F86QS92D["B`@("`@
M("`@:&5A9&5R*"=,;V-A=&EO;CH@)R`N("1U<FPI.PH@("`@("`@(&5X:70[
M"B`@("!]"GT*"B1T:71L92`](%\H(E!E<FUI<W-I;VYS($%D;6EN:7-T<F%T
M:6]N(BD["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]C;VUM;VXM:&5A
M9&5R+FEN8R<["G)E<75I<F4@2$]21$5?5$5-4$Q!5$53("X@)R]A9&UI;B]C
M;VUM;VXM:&5A9&5R+FEN8R<["B1N;W1I9FEC871I;VXM/FYO=&EF>2AA<G)A
M>2@G;&ES=&5N97)S)R`]/B`G<W1A='5S)RDI.PH*+RH@4F5N9&5R('1H92!F
M;W)M(&%N9"!T<F5E+B`J+PHD=6DM/G)E;F1E<D9O<FTH)V%D9&-H:6QD+G!H
M<"<I.PIE8VAO("<\8G(@+SXG.PHD=6DM/G)E;F1E<E1R964H)'!E<FU?:60I
M.PH*<F5Q=6ER92!(3U)$15]414U03$%415,@+B`G+V-O;6UO;BUF;V]T97(N
M:6YC)SL*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]A9&UI
M;B]P97)M<R]I;F1E>"YP:'``````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#$V-3(@,3`U,34T,S0Q,S8@,#(Q-3<W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W!E<FUS+VEN9&5X+G!H<"QV(#$N,3`N
M,3`N,R`R,#`V+S`Q+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@*B!#;W!Y
M<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N
M;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED97(@/&IA
M;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!9
M24Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U(&1I
M9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O=W=W+F9S
M9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H)TA/4D1%
M7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*<F5Q=6ER
M95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E<75I<F5?
M;VYC92`G2&]R9&4O365N=2YP:'`G.PH*:68@*"%!=71H.CII<T%D;6EN*"DI
M('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I<F5C="@I
M.PI]"@HD<&5R;5]I9"`](%5T:6PZ.F=E=$9O<FU$871A*"=P97)M7VED)RD[
M"@HD=&ET;&4@/2!?*")097)M:7-S:6]N<R!!9&UI;FES=')A=&EO;B(I.PIR
M97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+6AE861E<BYI;F,G
M.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O861M:6XO8V]M;6]N+6AE
M861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I9GDH87)R87DH)VQI<W1E
M;F5R<R<@/3X@)W-T871U<R<I*3L*"G)E<75I<F5?;VYC92`G2&]R9&4O4&5R
M;7,O54DN<&AP)SL*)'5I(#T@)FYE=R!097)M<U]522@D<&5R;7,I.PHD=6DM
M/G)E;F1E<E1R964H)'!E<FU?:60I.PH*<F5Q=6ER92!(3U)$15]414U03$%4
M15,@+B`G+V-O;6UO;BUF;V]T97(N:6YC)SL*````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]A9&UI;B]P97)M<R]D96QE=&4N<&AP````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#0V,38@,3`U,34T,S0Q,S8@,#(Q-S,U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&]R9&4Z(&AO<F1E+V%D;6EN+W!E<FUS+V1E;&5T92YP:'`L
M=B`Q+C$Y+C@N-"`R,#`V+S`Q+S`Q(#(Q.C(X.C`U(&IA;B!%>'`@)`H@*@H@
M*B!#;W!Y<FEG:'0@,3DY.2TR,#`V($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/@H@*B!#;W!Y<FEG:'0@,C`P-2TR,#`V($IA;B!38VAN96ED
M97(@/&IA;D!H;W)D92YO<F<^"B`J"B`J(%-E92!T:&4@96YC;&]S960@9FEL
M92!#3U!924Y'(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@
M>6]U(&1I9`H@*B!N;W0@<F5C96EV92!T:&ES(&9I;&4L('-E92!H='1P.B\O
M=W=W+F9S9BYO<F<O8V]P>6QE9G0O;&=P;"YH=&UL+@H@*B\*"D!D969I;F4H
M)TA/4D1%7T)!4T4G+"!D:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*3L*
M<F5Q=6ER95]O;F-E($A/4D1%7T)!4T4@+B`G+VQI8B]B87-E+G!H<"<["G)E
M<75I<F5?;VYC92`G2&]R9&4O365N=2YP:'`G.PH*:68@*"%!=71H.CII<T%D
M;6EN*"DI('L*("`@($AO<F1E.CIA=71H96YT:6-A=&EO;D9A:6QU<F52961I
M<F5C="@I.PI]"@HO*B!3970@=7`@=&AE(&9O<FT@=F%R:6%B;&5S+B`J+PIR
M97%U:7)E7V]N8V4@)TAO<F1E+U9A<FEA8FQE<RYP:'`G.PHD=F%R<R`]("96
M87)I86)L97,Z.F=E=$1E9F%U;'1687)I86)L97,H*3L*)'!E<FU?:60@/2`D
M=F%R<RT^9V5T*"=P97)M7VED)RD["B1C871E9V]R>2`]("1V87)S+3YG970H
M)V-A=&5G;W)Y)RD["B1P97)M:7-S:6]N(#T@)B1P97)M<RT^9V5T4&5R;6ES
M<VEO;D)Y260H)'!E<FU?:60I.PH*+RH@268@=&AE('!E<FUI<W-I;VX@9F5T
M8VAE9"!I<R!A;B!E<G)O<B!R971U<FX@=&\@<&5R;6ES<VEO;G,@;&ES="X@
M*B\*:68@*&ES7V$H)'!E<FUI<W-I;VXL("=014%27T5R<F]R)RDI('L*("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H7R@B071T96UP="!T;R!D96QE=&4@82!N
M;VXM97AI<W1E;G0@<&5R;6ES<VEO;BXB*2P@)VAO<F1E+F5R<F]R)RD["B`@
M("`D=7)L(#T@2&]R9&4Z.F%P<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]I
M;F1E>"YP:'`G+"!T<G5E*3L*("`@(&AE861E<B@G3&]C871I;VXZ("<@+B`D
M=7)L*3L*("`@(&5X:70["GT*"B\J(%-E="!U<"!F;W)M+B`J+PIR97%U:7)E
M7V]N8V4@)TAO<F1E+U!E<FUS+U5)+G!H<"<["B1U:2`]("9N97<@4&5R;7-?
M54DH)'!E<FUS*3L*)'5I+3YS971687)S*"1V87)S*3L*)'5I+3YS971U<$1E
M;&5T949O<FTH)'!E<FUI<W-I;VXI.PH*:68@*"1C;VYF:7)M960@/2`D=6DM
M/G9A;&ED871E1&5L971E1F]R;2@D:6YF;RDI('L*("`@("1R97-U;'0@/2`D
M<&5R;7,M/G)E;6]V95!E<FUI<W-I;VXH)'!E<FUI<W-I;VXL('1R=64I.PH@
M("`@:68@*&ES7V$H)')E<W5L="P@)U!%05)?17)R;W(G*2D@>PH@("`@("`@
M("1N;W1I9FEC871I;VXM/G!U<V@H<W!R:6YT9BA?*")5;F%B;&4@=&\@9&5L
M971E(%PB)7-<(CH@)7,N(BDL("1P97)M<RT^9V5T5&ET;&4H)'!E<FUI<W-I
M;VXM/F=E=$YA;64H*2DL("1R97-U;'0M/F=E=$UE<W-A9V4H*2DL("=H;W)D
M92YE<G)O<B<I.PH@("`@?2!E;'-E('L*("`@("`@("`D;F]T:69I8V%T:6]N
M+3YP=7-H*'-P<FEN=&8H7R@B4W5C8V5S<V9U;&QY(&1E;&5T960@7"(E<UPB
M+B(I+"`D<&5R;7,M/F=E=%1I=&QE*"1P97)M:7-S:6]N+3YG971.86UE*"DI
M*2P@)VAO<F1E+G-U8V-E<W,G*3L*("`@("`@("`D=7)L(#T@2&]R9&4Z.F%P
M<&QI8V%T:6]N57)L*"=A9&UI;B]P97)M<R]I;F1E>"YP:'`G+"!T<G5E*3L*
M("`@("`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R;"D["B`@("`@("`@
M97AI=#L*("`@('T*?2!E;'-E:68@*"1C;VYF:7)M960@/3T](&9A;'-E*2![
M"B`@("`D;F]T:69I8V%T:6]N+3YP=7-H*'-P<FEN=&8H7R@B4&5R;6ES<VEO
M;B!<(B5S7"(@;F]T(&1E;&5T960N(BDL("1P97)M<RT^9V5T5&ET;&4H)'!E
M<FUI<W-I;VXM/F=E=$YA;64H*2DI+"`G:&]R9&4N<W5C8V5S<R<I.PH@("`@
M)'5R;"`]($AO<F1E.CIA<'!L:6-A=&EO;E5R;"@G861M:6XO<&5R;7,O:6YD
M97@N<&AP)RP@=')U92D["B`@("!H96%D97(H)TQO8V%T:6]N.B`G("X@)'5R
M;"D["B`@("!E>&ET.PI]"@HD=&ET;&4@/2!?*")097)M:7-S:6]N<R!!9&UI
M;FES=')A=&EO;B(I.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M
M;6]N+6AE861E<BYI;F,G.PIR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O
M861M:6XO8V]M;6]N+6AE861E<BYI;F,G.PHD;F]T:69I8V%T:6]N+3YN;W1I
M9GDH87)R87DH)VQI<W1E;F5R<R<@/3X@)W-T871U<R<I*3L*"B\J(%)E;F1E
M<B!T:&4@9F]R;2!A;F0@=')E92X@*B\*)'5I+3YR96YD97)&;W)M*"=D96QE
M=&4N<&AP)RD["F5C:&\@)SQB<B`O/B<["B1U:2T^<F5N9&5R5')E92@D<&5R
M;5]I9"D["@IR97%U:7)E($A/4D1%7U1%35!,051%4R`N("<O8V]M;6]N+69O
M;W1E<BYI;F,G.PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]A9&UI;B]L;V-A;&4O96Y?55,`````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M,S8@,#(Q,#$V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V%D;6EN+VQO8V%L92]F
M:5]&20``````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S-B`P,C`W-C$`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O861M:6XO;&]C86QE+VAU7TA5````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,V(#`R,3`Q-0`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]A9&UI;B]L;V-A;&4O:'5?2%4O:&5L<"YX
M;6P`````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,W-C,@,3`U
M,34T,S0Q,S8@,#(R-34W`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](FES
M;RTX.#4Y+3(B/SX*/"$M+2!(;W)D92`S+C$@061M:6X@:&5L<#H@:'5?2%4@
M)$AO<F1E.B!H;W)D92]A9&UI;B]L;V-A;&4O:'5?2%4O:&5L<"YX;6PL=B`Q
M+C$N,BXQ(#(P,#8O,#,O,#,@,3,Z-#0Z,3$@:F%N($5X<"`D("TM/@H\:&5L
M<#X*("`\96YT<GD@:60](F%D;6EN+7!H<'-H96QL(B!S=&%T93TB=7!T;V1A
M=&4B(&UD-3TB9#4P,3<U.3%E9C1A,V8S.60Y-S@W8C4X,6$P86)B834B/@H@
M("`@/'1I=&QE/D%D;6EN:7-Z='+A8VGS<R!E<WIK]GKV:SH@82!02%`@4VAE
M;&P\+W1I=&QE/@H@("`@/&AE861I;F<^02!02%`@4VAE;&P@:&%S>F[A;&%T
M83PO:&5A9&EN9SX*("`@(#QP87)A/D$@4$A0('!A<F%N8W/I<G1E;&UE>O4@
M<V5G[71SZ6?I=F5L('1E='-Z]6QE9V5S(%!(4"!P87)A;F-S;VMA=`H@("`@
M("`@("`@:&%J=&AA="!VZ6=R92!A('-Z97)V97)E;BX@17IE:V5T(&$@<&%R
M86YC<V]K870@82!GZ7`@87H@"B`@("`@("`@("`\8V]D93YE=F%L*"D\+V-O
M9&4^(&;\9V=VZ6YY('-E9^UT<^EGZ79E;"P@87H@86MT=>%L:7-A;B#I<G;I
M;GEE<PH@("`@("`@("`@<V5S<VEO;B!K97)E=.EB96X@:&%J=&IA(';I9W)E
M+B!%('!A<F%N8W/I<G1E;&UE>O4@8^EL:F$L(&AO9WD*("`@("`@("`@(&MI
M('1U9&IU;FL@<'+S8N%L;FD@=&5T<WKU;&5G97,L(&5G>7-Z97+[8F(@:_-D
M<NES>FQE=&5K970N(`H@("`@("`@("`@06AH;WH@87IO;F)A;BP@:&]G>2!B
MX7)M:6QY96X@;W5T<'5T;W0@;.%S<W5N:RP@82!K\V1N86L@96-H;PH@("`@
M("`@("`@=F%G>2!P<FEN="!P87)A;F-S;VMA="!K96QL('1A<G1A;&UA>FYI
M82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F%D;6EN+7-Q
M;'-H96QL(B!S=&%T93TB=7!T;V1A=&4B(&UD-3TB-6)D,F9C8CEC.38W.&4V
M,F-A,30Q-38V86(X9C1C-&8B/@H@("`@/'1I=&QE/D%D;6EN:7-Z='+A8VGS
M<R!E<WIK]GKV:SH@87H@4U%,(%-H96QL/"]T:71L93X*("`@(#QH96%D:6YG
M/D%Z(%-13"!3:&5L;"!H87-Z;N%L871A/"]H96%D:6YG/@H@("`@/'!A<F$^
M07H@4U%,('!A<F%N8W/I<G1E;&UE>O4@<V5G[71SZ6?I=F5L('1E='-Z]6QE
M9V5S(%-13"!P87)A;F-S;W0*("`@("`@("`@(&AA:G1H870@=NEG<F4@87H@
M861A=&+A>FES;VXN($5Z96ME="!A('!A<F%N8W-O:V%T(&$@9^EP(&$@4$5!
M4CHZ1$(*("`@("`@("`@('+I=NEN(&AA:G1J82!VZ6=R92!A("1C;VYF6R=S
M<6PG72UB96X@;65G861O='0@861A=&)A>FES;VXN"B`@("`@("`@("!%>GIE
M;"!A>B!E<WIK]GIZ96P@;&5KZ7)D97KI<V5K970L(&)O;GEO;'5L="!344P@
M;?-D;W/M=.%S;VMA="P*("`@("`@("`@('3V<FSI<V5K970@:&%J=&AA="!V
MZ6=R92P@=F%G>2!A9&%T;VMA="!G>?MJ=&AE="X@07H@4U%,('!A<F%N8W-O
M:V%T"B`@("`@("`@("!K]GIV971L96[\;"!A>B!A9&%T8N%Z:7-N86L@:_QL
M9&DL(&UA:F0@=FES<WIA861J82!A>B!E<F5D;>EN>6OS9&]K870*("`@("`@
M("`@(&EL;"X@82!K87!O='0@861A=&]K870N"B`@("`\+W!A<F$^"CPO96YT
M<GD^"B`@/&5N=')Y(&ED/2)A9&UI;BUC;61S:&5L;"(@<W1A=&4](G5P=&]D
M871E(B!M9#4](CED8F)E-3DS-S,U965B8F(S-&1E.3DQ834W8CDX8CEF(CX*
M("`@(#QT:71L93Y!9&UI;FES>G1RX6-I\W,@97-Z:_9Z]FLZ(&$@<&%R86YC
M<W-O<CPO=&ET;&4^"B`@("`\:&5A9&EN9SY!('!A<F%N8W-S;W(@:&%S>F[A
M;&%T83PO:&5A9&EN9SX*("`@(#QP87)A/D$@<&%R86YC<W-O<B!S96?M='/I
M9^EV96P@<&%R86YC<V]K870@:&%J=&AA="!VZ6=R92!A('-Z97)V97)E;BX*
M("`@("`@("`@($5Z(&5G>2UE9WD@<&%R86YC<R!G>6]R<R!VZ6=R96AA:G3A
M<^%R82!J\RP@=F%G>2!A<G)A(&%Z(&5S971R92P@:&$*("`@("`@("`@(&WA
M<R!M\V1O;B!N96T@:^EP97,@82!S>F5R=F5R('!A<F%N8W/I<G1E;&UE>O5J
MZ6AE>B`H0V]M;6%N9"!3:&5L;"D*("`@("`@("`@(&IU=&YI82X*("`@(#PO
M<&%R83X*/"]E;G1R>3X*/"]H96QP/@H`````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O861M:6XO;&]C86QE+V9I7T9)+VAE;'`N>&UL````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,C8Q(#$P-3$U-#,T
M,3,V(#`R,C4Q-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/WAM;"!V97)S:6]N/2(Q+C`B/SX*/"$M+2`D2&]R9&4Z(&AO
M<F1E+V%D;6EN+VQO8V%L92]F:5]&22]H96QP+GAM;"QV(#$N,2XQ,BXR(#(P
M,#8O,#(O,C@@,30Z,#(Z,S4@:F%N($5X<"`D("TM/@H\:&5L<#X*("`\96YT
M<GD@:60](F%D;6EN+7!H<'-H96QL(B!M9#4](F0U,#$W-3DQ968T83-F,SED
M.3<X-V(U.#%A,&%B8F$U(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE
M/EEL;"8C>$4T.W!I9&]N('1Y)B-X1C8[:V%L=70Z(%!(4"UK;VUE;G1O='5L
M:VMI/"]T:71L93X*("`@(#QH96%D:6YG/DUI=&5N(%!(4"UK;VUE;G1O='5L
M:VMI82!K)B-X130[>71E="8C>$4T.R8C>$4T.VX\+VAE861I;F<^"B`@("`\
M<&%R83X*("`@(%!(4"UK;VUE;G1O='5L:VMI<W-A('9O:2!S=6]R:71T86$@
M<&%L=F5L:6UE;&QA(&UI="8C>$4T.R!T86AA;G-A"B`@("!02%`M:V]M96YT
M;VIA+B!.)B-X130[;28C>$4T.R!K;VUE;FYO="!S=6]R:71E=&%A;B`\8V]D
M93YE=F%L*"D\+V-O9&4^"B`@("!F=6YK=&EO;B!S:7,F(WA%-#ML;"8C>$4T
M.R!J82!N>6MY:7-E;B!I<W1U;FYO;B!K;VYT96MS=&ES<V$N(%0F(WA%-#MM
M)B-X130["B`@("!K;VUE;G1O='5L:VMI(&]N(&5N<VES:6IA:7-E<W1I('1A
M<FMO:71E='1U('-Y;G1A:W-I;@H@("`@=&%R:VES='5K<V5E;B!J82!Y:W-I
M;FME<G1A:7-E;B!K;V]D:6X@<W5O<FET=6MS965N+B!(=6]M86$L"B`@("!E
M='0F(WA%-#L@='5L;W-T86%K<V5S:2!J;W1A:VEN+"!N:6EN('-I;G5N('!I
M="8C>$4T.R8C>$4T.R!K)B-X130[>71T)B-X130[)B-X130[(&5C:&\@:F$*
M("`@('!R:6YT(&MO;65N=&]J82X*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\
M96YT<GD@:60](F%D;6EN+7-Q;'-H96QL(B!M9#4](C5B9#)F8V(Y8SDV-SAE
M-C)C83$T,34V-F%B.&8T8S1F(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I
M=&QE/EEL;"8C>$4T.W!I9&]N('1Y)B-X1C8[:V%L=70Z(%-13"UK;VUE;G1O
M='5L:VMI/"]T:71L93X*("`@(#QH96%D:6YG/DUI=&5N(%-13"UK;VUE;G1O
M='5L:VMI82!K)B-X130[>71E="8C>$4T.R8C>$4T.VX\+VAE861I;F<^"B`@
M("`\<&%R83X*("`@(%-13"UK;VUE;G1O='5L:VES<V$@=F]I('-U;W)I='1A
M82!M:70F(WA%-#L@=&%H86YS82!344PM;&%U<V5K:V5I=&$L(&IO=&MA"B`@
M("!S=6]R:71E=&%A;B!T:65T;VMA;FYA<W-A+B!+)B-X130[>71E='0F(WA%
M-#MV)B-X130[('1I971O:V%N=&$@;VX*("`@(&TF(WA%-#LF(WA%-#MR:71E
M;'1Y("1C;VYF6R=S<6PG72!J82!S:70F(WA%-#L@:R8C>$4T.WET970F(WA%
M-#LF(WA%-#MN(%!%05(Z1$(M;'5O:V%N"B`@("!A=G5L;&$N("!6;VET(&LF
M(WA%-#MY='0F(WA%-#LF(WA%-#L@="8C>$4T.W0F(WA%-#L@='DF(WA&-CMK
M86QU:F$@=&5H9"8C>$4T.VMS97-I(&MY<V5L>6HF(WA%-#L*("`@('1I971O
M:V%N=&%A;BP@<"8C>$4T.VEV:71T)B-X130[)B-X130[:W-E<VD@=&EE=&]J
M82!T:65T;VMA;FYA<W-A+`H@("`@<&]I<W1A86MS97-I('1I971O:F$@=&EE
M=&]K86YN87-T82!J;F4N('1A:2!H86ME82!T:65T;VIA"B`@("!T:65T;VMA
M;FYA<W1A+B!344PM:V]M96YN;W0@;"8C>$4T.VAE=&5T)B-X130[)B-X130[
M;B!S=6]R86%N('1I971O:V%N;F%L;&4*("`@(&IA('!A;'5U87)V;VYA('1U
M;&5E('-T871U<VMO;V1I(&IA(&MY<V5L>6X@<&%L875T=&%M80H@("`@87)V
M;RX*("`@(#PO<&%R83X*/"]E;G1R>3X*("`\96YT<GD@:60](F%D;6EN+6-M
M9'-H96QL(B!M9#4](CED8F)E-3DS-S,U965B8F(S-&1E.3DQ834W8CDX8CEF
M(B!S=&%T93TB=7!T;V1A=&4B/@H@("`@/'1I=&QE/EEL;"8C>$4T.W!I9&]N
M('1Y)B-X1C8[:V%L=70Z($MO;65N=&]T=6QK:VD\+W1I=&QE/@H@("`@/&AE
M861I;F<^36ET96X@:V]M96YT;W1U;&MK:6$@:R8C>$4T.WET970F(WA%-#LF
M(WA%-#MN/"]H96%D:6YG/@H@("`@/'!A<F$^"B`@("!+;VUE;G1O='5L:VEN
M(&%V=6QL82!V;VET('-U;W)I='1A82!K;VUE;G1O:F$@=W=W+7!A;'9E;&EM
M96QL82X@5F]I="!K)B-X130[>71T)B-X130[)B-X130[('0F(WA%-#MT)B-X
M130[('1O:6UI;G1O82!K=6X@:&%L=6%T(&YO<&5A<W1I('-U;W)I='1A82!J
M;VYK=6X@:V]M96YN;VX@<&%L=F5L:6UE;&QA(&IA(&MO;65N=&]T=6QK:VD@
M96D@;VQE(&UU=71E;B!K)B-X130[>71E='0F(WA%-#MV:7-S)B-X130[+@H@
M("`@/"]P87)A/@H\+V5N=')Y/@H\+VAE;'`^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O861M:6XO;&]C86QE+V5N7U53
M+VAE;'`N>&UL````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M,C$V(#$P-3$U-#,T,3,V(#`R,C4U,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/WAM;"!V97)S:6]N/2<Q+C`G/SX*/"$M
M+2`D2&]R9&4Z(&AO<F1E+V%D;6EN+VQO8V%L92]E;E]54R]H96QP+GAM;"QV
M(#$N,R`R,#`S+S`V+S$T(#`T.C(X.C(Q(&-H=6-K($5X<"`D("TM/@H\:&5L
M<#X*"CQE;G1R>2!I9#TB861M:6XM<&AP<VAE;&PB/@H@("`@/'1I=&QE/D%D
M;6EN(%1O;VQS.B!02%`@4VAE;&P\+W1I=&QE/@H@("`@/&AE861I;F<^2&]W
M('1O('5S92!T:&4@4$A0(%-H96QL/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE
M(%!(4"!C;VUM86YD('-H96QL(&QE=',@>6]U(&5X96-U=&4@87)B:71R87)Y
M(%!(4`H@("`@("`@("`@<W1A=&5M96YT<R!O;B!T:&4@<V5R=F5R+B!4:&5S
M92!C;VUM86YD<R!A<F4@97AE8W5T960@=7-I;F<*("`@("`@("`@('1H92`\
M8V]D93YE=F%L*"D\+V-O9&4^(&9U;F-T:6]N+"!A;F0@97AE8W5T92!I;B!T
M:&4@8V]N=&5X=`H@("`@("`@("`@;V8@=&AE(&-U<G)E;G0@<V5S<VEO;BX@
M5&AI<R!S:&5L;"!I<R!I;G1E;F1E9"!T;R!T<GD@;W5T"B`@("`@("`@("!S
M>6YT87@@86YD(&5X96-U=&4@<V]M92!S:6UP;&4@87)B:71R87)Y(&-O9&4N
M($YO=&4@=&AA="!T;PH@("`@("`@("`@9V5T(&%N>2!O=71P=70L('EO=2!M
M=7-T(&5C:&\@;W(@<')I;G0@<V]M971H:6YG(&EN('EO=7(*("`@("`@("`@
M(&-O9&4@9G)A9VUE;G0N/"]P87)A/@H\+V5N=')Y/@H*/&5N=')Y(&ED/2)A
M9&UI;BUS<6QS:&5L;"(^"B`@("`\=&ET;&4^061M:6X@5&]O;',Z(%-13"!3
M:&5L;#PO=&ET;&4^"B`@("`\:&5A9&EN9SY(;W<@=&\@=7-E('1H92!344P@
M4VAE;&P\+VAE861I;F<^"B`@("`\<&%R83Y4:&4@4U%,('%U97)Y('-H96QL
M(&QE=',@>6]U(&5X96-U=&4@87)B:71R87)Y(%-13`H@("`@("`@("`@<W1A
M=&5M96YT<R!O;B!Y;W5R(&1A=&%B87-E+B!4:&5S92!C;VUM86YD<R!A<F4@
M97AE8W5T960*("`@("`@("`@(&%G86EN<W0@=&AE(&1A=&%B87-E(&1E9FEN
M960@:6X@)&-O;F9;)W-Q;"==('5S:6YG('1H90H@("`@("`@("`@4$5!4CHZ
M1$(@8VQA<W-E<RX@66]U(&-A;B!U<V4@=&AI<R!T;V]L('1O(&1O('%U97)I
M97,@:6YT;PH@("`@("`@("`@=&AE(&1A=&%B87-E+"!T;R!D;R!C;VUP;&EC
M871E9"!344P@=7!D871E<RP@9&5L971E<RP@971C+BP*("`@("`@("`@(&]R
M('1O(&1O('-I;7!L92!D871A(&-O;&QE8W1I;VXN($ET('-E;F1S(%-13"!Q
M=65R:65S('1O('1H90H@("`@("`@("`@9&%T86)A<V4@9&ER96-T;'DL(&%N
M9"!W:6QL(')E<&]R="!R971U<FX@8V]D97,@86YD(&-O;7!L971E"B`@("`@
M("`@("!R97-U;'0@<V5T<RX\+W!A<F$^"CPO96YT<GD^"@H\96YT<GD@:60]
M(F%D;6EN+6-M9'-H96QL(CX*("`@(#QT:71L93Y!9&UI;B!4;V]L<SH@0V]M
M;6%N9"!3:&5L;#PO=&ET;&4^"B`@("`\:&5A9&EN9SY(;W<@=&\@=7-E('1H
M92!#;VUM86YD(%-H96QL/"]H96%D:6YG/@H@("`@/'!A<F$^5&AE(&-O;6UA
M;F0@<VAE;&P@;&5T<R!Y;W4@97AE8W5T92!A<F)I=')A<GD@<VAE;&P*("`@
M("`@("`@(&-O;6UA;F1S(&]N('EO=7(@<V5R=F5R+B!9;W4@8V%N('5S92!T
M:&ES('1O(&1O('%U:6-K"B`@("`@("`@("!S:&5L;"!O<&5R871I;VYS(&]R
M('=H96X@82!S:&5L;"!I<R!N;W0@;W1H97)W:7-E(&%V86EL86)L92X*("`@
M("`@("`@(#PO<&%R83X*/"]E;G1R>3X*"CPO:&5L<#X*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O0T]064E.1P``````````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V,3(W,R`Q
M,#4Q-30S-#$S-2`P,3<U,S``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````"0D@($=.52!,24)205)9($=%3D5204P@4%5"3$E#
M($Q)0T5.4T4*"0D@("`@("`@5F5R<VEO;B`R+"!*=6YE(#$Y.3$*"B!#;W!Y
M<FEG:'0@*$,I(#$Y.3$@1G)E92!3;V9T=V%R92!&;W5N9&%T:6]N+"!);F,N
M"B`@("`)"2`@("`U.2!496UP;&4@4&QA8V4L(%-U:71E(#,S,"P@0F]S=&]N
M+"!-02`@,#(Q,3$M,3,P-R`@55-!"B!%=F5R>6]N92!I<R!P97)M:71T960@
M=&\@8V]P>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,*(&]F('1H
M:7,@;&EC96YS92!D;V-U;65N="P@8G5T(&-H86YG:6YG(&ET(&ES(&YO="!A
M;&QO=V5D+@H*6U1H:7,@:7,@=&AE(&9I<G-T(')E;&5A<V5D('9E<G-I;VX@
M;V8@=&AE(&QI8G)A<GD@1U!,+B`@270@:7,*(&YU;6)E<F5D(#(@8F5C875S
M92!I="!G;V5S('=I=&@@=F5R<VEO;B`R(&]F('1H92!O<F1I;F%R>2!'4$PN
M70H*"0D)("`@(%!R96%M8FQE"@H@(%1H92!L:6-E;G-E<R!F;W(@;6]S="!S
M;V9T=V%R92!A<F4@9&5S:6=N960@=&\@=&%K92!A=V%Y('EO=7(*9G)E961O
M;2!T;R!S:&%R92!A;F0@8VAA;F=E(&ET+B`@0GD@8V]N=')A<W0L('1H92!'
M3E4@1V5N97)A;"!0=6)L:6,*3&EC96YS97,@87)E(&EN=&5N9&5D('1O(&=U
M87)A;G1E92!Y;W5R(&9R965D;VT@=&\@<VAA<F4@86YD(&-H86YG90IF<F5E
M('-O9G1W87)E+2UT;R!M86ME('-U<F4@=&AE('-O9G1W87)E(&ES(&9R964@
M9F]R(&%L;"!I=',@=7-E<G,N"@H@(%1H:7,@;&EC96YS92P@=&AE($QI8G)A
M<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@87!P;&EE<R!T;R!S;VUE"G-P
M96-I86QL>2!D97-I9VYA=&5D($9R964@4V]F='=A<F4@1F]U;F1A=&EO;B!S
M;V9T=V%R92P@86YD('1O(&%N>0IO=&AE<B!L:6)R87)I97,@=VAO<V4@875T
M:&]R<R!D96-I9&4@=&\@=7-E(&ET+B`@66]U(&-A;B!U<V4@:70@9F]R"GEO
M=7(@;&EB<F%R:65S+"!T;V\N"@H@(%=H96X@=V4@<W!E86L@;V8@9G)E92!S
M;V9T=V%R92P@=V4@87)E(')E9F5R<FEN9R!T;R!F<F5E9&]M+"!N;W0*<')I
M8V4N("!/=7(@1V5N97)A;"!0=6)L:6,@3&EC96YS97,@87)E(&1E<VEG;F5D
M('1O(&UA:V4@<W5R92!T:&%T('EO=0IH879E('1H92!F<F5E9&]M('1O(&1I
M<W1R:6)U=&4@8V]P:65S(&]F(&9R964@<V]F='=A<F4@*&%N9"!C:&%R9V4@
M9F]R"G1H:7,@<V5R=FEC92!I9B!Y;W4@=VES:"DL('1H870@>6]U(')E8V5I
M=F4@<V]U<F-E(&-O9&4@;W(@8V%N(&=E="!I=`II9B!Y;W4@=V%N="!I="P@
M=&AA="!Y;W4@8V%N(&-H86YG92!T:&4@<V]F='=A<F4@;W(@=7-E('!I96-E
M<R!O9B!I=`II;B!N97<@9G)E92!P<F]G<F%M<SL@86YD('1H870@>6]U(&MN
M;W<@>6]U(&-A;B!D;R!T:&5S92!T:&EN9W,N"@H@(%1O('!R;W1E8W0@>6]U
M<B!R:6=H=',L('=E(&YE960@=&\@;6%K92!R97-T<FEC=&EO;G,@=&AA="!F
M;W)B:60*86YY;VYE('1O(&1E;GD@>6]U('1H97-E(')I9VAT<R!O<B!T;R!A
M<VL@>6]U('1O('-U<G)E;F1E<B!T:&4@<FEG:'1S+@I4:&5S92!R97-T<FEC
M=&EO;G,@=')A;G-L871E('1O(&-E<G1A:6X@<F5S<&]N<VEB:6QI=&EE<R!F
M;W(@>6]U(&EF"GEO=2!D:7-T<FEB=71E(&-O<&EE<R!O9B!T:&4@;&EB<F%R
M>2P@;W(@:68@>6]U(&UO9&EF>2!I="X*"B`@1F]R(&5X86UP;&4L(&EF('EO
M=2!D:7-T<FEB=71E(&-O<&EE<R!O9B!T:&4@;&EB<F%R>2P@=VAE=&AE<B!G
M<F%T:7,*;W(@9F]R(&$@9F5E+"!Y;W4@;75S="!G:79E('1H92!R96-I<&EE
M;G1S(&%L;"!T:&4@<FEG:'1S('1H870@=V4@9V%V90IY;W4N("!9;W4@;75S
M="!M86ME('-U<F4@=&AA="!T:&5Y+"!T;V\L(')E8V5I=F4@;W(@8V%N(&=E
M="!T:&4@<V]U<F-E"F-O9&4N("!)9B!Y;W4@;&EN:R!A('!R;V=R86T@=VET
M:"!T:&4@;&EB<F%R>2P@>6]U(&UU<W0@<')O=FED90IC;VUP;&5T92!O8FIE
M8W0@9FEL97,@=&\@=&AE(')E8VEP:65N=',@<V\@=&AA="!T:&5Y(&-A;B!R
M96QI;FL@=&AE;0IW:71H('1H92!L:6)R87)Y+"!A9G1E<B!M86MI;F<@8VAA
M;F=E<R!T;R!T:&4@;&EB<F%R>2!A;F0@<F5C;VUP:6QI;F<*:70N("!!;F0@
M>6]U(&UU<W0@<VAO=R!T:&5M('1H97-E('1E<FUS('-O('1H97D@:VYO=R!T
M:&5I<B!R:6=H=',N"@H@($]U<B!M971H;V0@;V8@<')O=&5C=&EN9R!Y;W5R
M(')I9VAT<R!H87,@='=O('-T97!S.B`H,2D@8V]P>7)I9VAT"G1H92!L:6)R
M87)Y+"!A;F0@*#(I(&]F9F5R('EO=2!T:&ES(&QI8V5N<V4@=VAI8V@@9VEV
M97,@>6]U(&QE9V%L"G!E<FUI<W-I;VX@=&\@8V]P>2P@9&ES=')I8G5T92!A
M;F0O;W(@;6]D:69Y('1H92!L:6)R87)Y+@H*("!!;'-O+"!F;W(@96%C:"!D
M:7-T<FEB=71O<B=S('!R;W1E8W1I;VXL('=E('=A;G0@=&\@;6%K92!C97)T
M86EN"G1H870@979E<GEO;F4@=6YD97)S=&%N9',@=&AA="!T:&5R92!I<R!N
M;R!W87)R86YT>2!F;W(@=&AI<R!F<F5E"FQI8G)A<GDN("!)9B!T:&4@;&EB
M<F%R>2!I<R!M;V1I9FEE9"!B>2!S;VUE;VYE(&5L<V4@86YD('!A<W-E9"!O
M;BP@=V4*=V%N="!I=',@<F5C:7!I96YT<R!T;R!K;F]W('1H870@=VAA="!T
M:&5Y(&AA=F4@:7,@;F]T('1H92!O<FEG:6YA;`IV97)S:6]N+"!S;R!T:&%T
M(&%N>2!P<F]B;&5M<R!I;G1R;V1U8V5D(&)Y(&]T:&5R<R!W:6QL(&YO="!R
M969L96-T(&]N"G1H92!O<FEG:6YA;"!A=71H;W)S)R!R97!U=&%T:6]N<RX*
M#`H@($9I;F%L;'DL(&%N>2!F<F5E('!R;V=R86T@:7,@=&AR96%T96YE9"!C
M;VYS=&%N=&QY(&)Y('-O9G1W87)E"G!A=&5N=',N("!792!W:7-H('1O(&%V
M;VED('1H92!D86YG97(@=&AA="!C;VUP86YI97,@9&ES=')I8G5T:6YG(&9R
M964*<V]F='=A<F4@=VEL;"!I;F1I=FED=6%L;'D@;V)T86EN('!A=&5N="!L
M:6-E;G-E<RP@=&AU<R!I;B!E9F9E8W0*=')A;G-F;W)M:6YG('1H92!P<F]G
M<F%M(&EN=&\@<')O<')I971A<GD@<V]F='=A<F4N("!4;R!P<F5V96YT('1H
M:7,L"G=E(&AA=F4@;6%D92!I="!C;&5A<B!T:&%T(&%N>2!P871E;G0@;75S
M="!B92!L:6-E;G-E9"!F;W(@979E<GEO;F4G<PIF<F5E('5S92!O<B!N;W0@
M;&EC96YS960@870@86QL+@H*("!-;W-T($=.52!S;V9T=V%R92P@:6YC;'5D
M:6YG('-O;64@;&EB<F%R:65S+"!I<R!C;W9E<F5D(&)Y('1H92!O<F1I;F%R
M>0I'3E4@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@=VAI8V@@=V%S(&1E<VEG
M;F5D(&9O<B!U=&EL:71Y('!R;V=R86US+B`@5&AI<PIL:6-E;G-E+"!T:&4@
M1TY5($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92P@87!P;&EE<R!T
M;R!C97)T86EN"F1E<VEG;F%T960@;&EB<F%R:65S+B`@5&AI<R!L:6-E;G-E
M(&ES('%U:71E(&1I9F9E<F5N="!F<F]M('1H92!O<F1I;F%R>0IO;F4[(&)E
M('-U<F4@=&\@<F5A9"!I="!I;B!F=6QL+"!A;F0@9&]N)W0@87-S=6UE('1H
M870@86YY=&AI;F<@:6X@:70@:7,*=&AE('-A;64@87,@:6X@=&AE(&]R9&EN
M87)Y(&QI8V5N<V4N"@H@(%1H92!R96%S;VX@=V4@:&%V92!A('-E<&%R871E
M('!U8FQI8R!L:6-E;G-E(&9O<B!S;VUE(&QI8G)A<FEE<R!I<R!T:&%T"G1H
M97D@8FQU<B!T:&4@9&ES=&EN8W1I;VX@=V4@=7-U86QL>2!M86ME(&)E='=E
M96X@;6]D:69Y:6YG(&]R(&%D9&EN9R!T;R!A"G!R;V=R86T@86YD('-I;7!L
M>2!U<VEN9R!I="X@($QI;FMI;F<@82!P<F]G<F%M('=I=&@@82!L:6)R87)Y
M+"!W:71H;W5T"F-H86YG:6YG('1H92!L:6)R87)Y+"!I<R!I;B!S;VUE('-E
M;G-E('-I;7!L>2!U<VEN9R!T:&4@;&EB<F%R>2P@86YD(&ES"F%N86QO9V]U
M<R!T;R!R=6YN:6YG(&$@=71I;&ET>2!P<F]G<F%M(&]R(&%P<&QI8V%T:6]N
M('!R;V=R86TN("!(;W=E=F5R+"!I;@IA('1E>'1U86P@86YD(&QE9V%L('-E
M;G-E+"!T:&4@;&EN:V5D(&5X96-U=&%B;&4@:7,@82!C;VUB:6YE9"!W;W)K
M+"!A"F1E<FEV871I=F4@;V8@=&AE(&]R:6=I;F%L(&QI8G)A<GDL(&%N9"!T
M:&4@;W)D:6YA<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS90IT<F5A=',@:70@
M87,@<W5C:"X*"B`@0F5C875S92!O9B!T:&ES(&)L=7)R960@9&ES=&EN8W1I
M;VXL('5S:6YG('1H92!O<F1I;F%R>2!'96YE<F%L"E!U8FQI8R!,:6-E;G-E
M(&9O<B!L:6)R87)I97,@9&ED(&YO="!E9F9E8W1I=F5L>2!P<F]M;W1E('-O
M9G1W87)E"G-H87)I;F<L(&)E8V%U<V4@;6]S="!D979E;&]P97)S(&1I9"!N
M;W0@=7-E('1H92!L:6)R87)I97,N("!790IC;VYC;'5D960@=&AA="!W96%K
M97(@8V]N9&ET:6]N<R!M:6=H="!P<F]M;W1E('-H87)I;F<@8F5T=&5R+@H*
M("!(;W=E=F5R+"!U;G)E<W1R:6-T960@;&EN:VEN9R!O9B!N;VXM9G)E92!P
M<F]G<F%M<R!W;W5L9"!D97!R:79E('1H90IU<V5R<R!O9B!T:&]S92!P<F]G
M<F%M<R!O9B!A;&P@8F5N969I="!F<F]M('1H92!F<F5E('-T871U<R!O9B!T
M:&4*;&EB<F%R:65S('1H96US96QV97,N("!4:&ES($QI8G)A<GD@1V5N97)A
M;"!0=6)L:6,@3&EC96YS92!I<R!I;G1E;F1E9"!T;PIP97)M:70@9&5V96QO
M<&5R<R!O9B!N;VXM9G)E92!P<F]G<F%M<R!T;R!U<V4@9G)E92!L:6)R87)I
M97,L('=H:6QE"G!R97-E<G9I;F<@>6]U<B!F<F5E9&]M(&%S(&$@=7-E<B!O
M9B!S=6-H('!R;V=R86US('1O(&-H86YG92!T:&4@9G)E90IL:6)R87)I97,@
M=&AA="!A<F4@:6YC;W)P;W)A=&5D(&EN('1H96TN("`H5V4@:&%V92!N;W0@
M<V5E;B!H;W<@=&\@86-H:65V90IT:&ES(&%S(')E9V%R9',@8VAA;F=E<R!I
M;B!H96%D97(@9FEL97,L(&)U="!W92!H879E(&%C:&EE=F5D(&ET(&%S(')E
M9V%R9',*8VAA;F=E<R!I;B!T:&4@86-T=6%L(&9U;F-T:6]N<R!O9B!T:&4@
M3&EB<F%R>2XI("!4:&4@:&]P92!I<R!T:&%T('1H:7,*=VEL;"!L96%D('1O
M(&9A<W1E<B!D979E;&]P;65N="!O9B!F<F5E(&QI8G)A<FEE<RX*"B`@5&AE
M('!R96-I<V4@=&5R;7,@86YD(&-O;F1I=&EO;G,@9F]R(&-O<'EI;F<L(&1I
M<W1R:6)U=&EO;B!A;F0*;6]D:69I8V%T:6]N(&9O;&QO=RX@(%!A>2!C;&]S
M92!A='1E;G1I;VX@=&\@=&AE(&1I9F9E<F5N8V4@8F5T=V5E;B!A"B)W;W)K
M(&)A<V5D(&]N('1H92!L:6)R87)Y(B!A;F0@82`B=V]R:R!T:&%T('5S97,@
M=&AE(&QI8G)A<GDB+B`@5&AE"F9O<FUE<B!C;VYT86EN<R!C;V1E(&1E<FEV
M960@9G)O;2!T:&4@;&EB<F%R>2P@=VAI;&4@=&AE(&QA='1E<B!O;FQY"G=O
M<FMS('1O9V5T:&5R('=I=&@@=&AE(&QI8G)A<GDN"@H@($YO=&4@=&AA="!I
M="!I<R!P;W-S:6)L92!F;W(@82!L:6)R87)Y('1O(&)E(&-O=F5R960@8GD@
M=&AE(&]R9&EN87)Y"D=E;F5R86P@4'5B;&EC($QI8V5N<V4@<F%T:&5R('1H
M86X@8GD@=&AI<R!S<&5C:6%L(&]N92X*#`H)"2`@1TY5($Q)0E)!4ED@1T5.
M15)!3"!054),24,@3$E#14Y310H@("!415)-4R!!3D0@0T].1$E424].4R!&
M3U(@0T]064E.1RP@1$E35%))0E5424].($%.1"!-3T1)1DE#051)3TX*"B`@
M,"X@5&AI<R!,:6-E;G-E($%G<F5E;65N="!A<'!L:65S('1O(&%N>2!S;V9T
M=V%R92!L:6)R87)Y('=H:6-H"F-O;G1A:6YS(&$@;F]T:6-E('!L86-E9"!B
M>2!T:&4@8V]P>7)I9VAT(&AO;&1E<B!O<B!O=&AE<B!A=71H;W)I>F5D"G!A
M<G1Y('-A>6EN9R!I="!M87D@8F4@9&ES=')I8G5T960@=6YD97(@=&AE('1E
M<FUS(&]F('1H:7,@3&EB<F%R>0I'96YE<F%L(%!U8FQI8R!,:6-E;G-E("AA
M;'-O(&-A;&QE9"`B=&AI<R!,:6-E;G-E(BDN("!%86-H(&QI8V5N<V5E(&ES
M"F%D9')E<W-E9"!A<R`B>6]U(BX*"B`@02`B;&EB<F%R>2(@;65A;G,@82!C
M;VQL96-T:6]N(&]F('-O9G1W87)E(&9U;F-T:6]N<R!A;F0O;W(@9&%T80IP
M<F5P87)E9"!S;R!A<R!T;R!B92!C;VYV96YI96YT;'D@;&EN:V5D('=I=&@@
M87!P;&EC871I;VX@<')O9W)A;7,**'=H:6-H('5S92!S;VUE(&]F('1H;W-E
M(&9U;F-T:6]N<R!A;F0@9&%T82D@=&\@9F]R;2!E>&5C=71A8FQE<RX*"B`@
M5&AE("),:6)R87)Y(BP@8F5L;W<L(')E9F5R<R!T;R!A;GD@<W5C:"!S;V9T
M=V%R92!L:6)R87)Y(&]R('=O<FL*=VAI8V@@:&%S(&)E96X@9&ES=')I8G5T
M960@=6YD97(@=&AE<V4@=&5R;7,N("!!(")W;W)K(&)A<V5D(&]N('1H90I,
M:6)R87)Y(B!M96%N<R!E:71H97(@=&AE($QI8G)A<GD@;W(@86YY(&1E<FEV
M871I=F4@=V]R:R!U;F1E<@IC;W!Y<FEG:'0@;&%W.B!T:&%T(&ES('1O('-A
M>2P@82!W;W)K(&-O;G1A:6YI;F<@=&AE($QI8G)A<GD@;W(@80IP;W)T:6]N
M(&]F(&ET+"!E:71H97(@=F5R8F%T:6T@;W(@=VET:"!M;V1I9FEC871I;VYS
M(&%N9"]O<B!T<F%N<VQA=&5D"G-T<F%I9VAT9F]R=V%R9&QY(&EN=&\@86YO
M=&AE<B!L86YG=6%G92X@("A(97)E:6YA9G1E<BP@=')A;G-L871I;VX@:7,*
M:6YC;'5D960@=VET:&]U="!L:6UI=&%T:6]N(&EN('1H92!T97)M(")M;V1I
M9FEC871I;VXB+BD*"B`@(E-O=7)C92!C;V1E(B!F;W(@82!W;W)K(&UE86YS
M('1H92!P<F5F97)R960@9F]R;2!O9B!T:&4@=V]R:R!F;W(*;6%K:6YG(&UO
M9&EF:6-A=&EO;G,@=&\@:70N("!&;W(@82!L:6)R87)Y+"!C;VUP;&5T92!S
M;W5R8V4@8V]D92!M96%N<PIA;&P@=&AE('-O=7)C92!C;V1E(&9O<B!A;&P@
M;6]D=6QE<R!I="!C;VYT86EN<RP@<&QU<R!A;GD@87-S;V-I871E9`II;G1E
M<F9A8V4@9&5F:6YI=&EO;B!F:6QE<RP@<&QU<R!T:&4@<V-R:7!T<R!U<V5D
M('1O(&-O;G1R;VP@8V]M<&EL871I;VX*86YD(&EN<W1A;&QA=&EO;B!O9B!T
M:&4@;&EB<F%R>2X*"B`@06-T:79I=&EE<R!O=&AE<B!T:&%N(&-O<'EI;F<L
M(&1I<W1R:6)U=&EO;B!A;F0@;6]D:69I8V%T:6]N(&%R92!N;W0*8V]V97)E
M9"!B>2!T:&ES($QI8V5N<V4[('1H97D@87)E(&]U='-I9&4@:71S('-C;W!E
M+B`@5&AE(&%C="!O9@IR=6YN:6YG(&$@<')O9W)A;2!U<VEN9R!T:&4@3&EB
M<F%R>2!I<R!N;W0@<F5S=')I8W1E9"P@86YD(&]U='!U="!F<F]M"G-U8V@@
M82!P<F]G<F%M(&ES(&-O=F5R960@;VYL>2!I9B!I=',@8V]N=&5N=',@8V]N
M<W1I='5T92!A('=O<FL@8F%S960*;VX@=&AE($QI8G)A<GD@*&EN9&5P96YD
M96YT(&]F('1H92!U<V4@;V8@=&AE($QI8G)A<GD@:6X@82!T;V]L(&9O<@IW
M<FET:6YG(&ET*2X@(%=H971H97(@=&AA="!I<R!T<G5E(&1E<&5N9',@;VX@
M=VAA="!T:&4@3&EB<F%R>2!D;V5S"F%N9"!W:&%T('1H92!P<F]G<F%M('1H
M870@=7-E<R!T:&4@3&EB<F%R>2!D;V5S+@H@(`H@(#$N(%EO=2!M87D@8V]P
M>2!A;F0@9&ES=')I8G5T92!V97)B871I;2!C;W!I97,@;V8@=&AE($QI8G)A
M<GDG<PIC;VUP;&5T92!S;W5R8V4@8V]D92!A<R!Y;W4@<F5C96EV92!I="P@
M:6X@86YY(&UE9&EU;2P@<')O=FED960@=&AA=`IY;W4@8V]N<W!I8W5O=7-L
M>2!A;F0@87!P<F]P<FEA=&5L>2!P=6)L:7-H(&]N(&5A8V@@8V]P>2!A;@IA
M<'!R;W!R:6%T92!C;W!Y<FEG:'0@;F]T:6-E(&%N9"!D:7-C;&%I;65R(&]F
M('=A<G)A;G1Y.R!K965P(&EN=&%C=`IA;&P@=&AE(&YO=&EC97,@=&AA="!R
M969E<B!T;R!T:&ES($QI8V5N<V4@86YD('1O('1H92!A8G-E;F-E(&]F(&%N
M>0IW87)R86YT>3L@86YD(&1I<W1R:6)U=&4@82!C;W!Y(&]F('1H:7,@3&EC
M96YS92!A;&]N9R!W:71H('1H90I,:6)R87)Y+@H*("!9;W4@;6%Y(&-H87)G
M92!A(&9E92!F;W(@=&AE('!H>7-I8V%L(&%C="!O9B!T<F%N<V9E<G)I;F<@
M82!C;W!Y+`IA;F0@>6]U(&UA>2!A="!Y;W5R(&]P=&EO;B!O9F9E<B!W87)R
M86YT>2!P<F]T96-T:6]N(&EN(&5X8VAA;F=E(&9O<B!A"F9E92X*#`H@(#(N
M(%EO=2!M87D@;6]D:69Y('EO=7(@8V]P>2!O<B!C;W!I97,@;V8@=&AE($QI
M8G)A<GD@;W(@86YY('!O<G1I;VX*;V8@:70L('1H=7,@9F]R;6EN9R!A('=O
M<FL@8F%S960@;VX@=&AE($QI8G)A<GDL(&%N9"!C;W!Y(&%N9`ID:7-T<FEB
M=71E('-U8V@@;6]D:69I8V%T:6]N<R!O<B!W;W)K('5N9&5R('1H92!T97)M
M<R!O9B!396-T:6]N(#$*86)O=F4L('!R;W9I9&5D('1H870@>6]U(&%L<V\@
M;65E="!A;&P@;V8@=&AE<V4@8V]N9&ET:6]N<SH*"B`@("!A*2!4:&4@;6]D
M:69I960@=V]R:R!M=7-T(&ET<V5L9B!B92!A('-O9G1W87)E(&QI8G)A<GDN
M"@H@("`@8BD@66]U(&UU<W0@8V%U<V4@=&AE(&9I;&5S(&UO9&EF:65D('1O
M(&-A<G)Y('!R;VUI;F5N="!N;W1I8V5S"B`@("!S=&%T:6YG('1H870@>6]U
M(&-H86YG960@=&AE(&9I;&5S(&%N9"!T:&4@9&%T92!O9B!A;GD@8VAA;F=E
M+@H*("`@(&,I(%EO=2!M=7-T(&-A=7-E('1H92!W:&]L92!O9B!T:&4@=V]R
M:R!T;R!B92!L:6-E;G-E9"!A="!N;PH@("`@8VAA<F=E('1O(&%L;"!T:&ER
M9"!P87)T:65S('5N9&5R('1H92!T97)M<R!O9B!T:&ES($QI8V5N<V4N"@H@
M("`@9"D@268@82!F86-I;&ET>2!I;B!T:&4@;6]D:69I960@3&EB<F%R>2!R
M969E<G,@=&\@82!F=6YC=&EO;B!O<B!A"B`@("!T86)L92!O9B!D871A('1O
M(&)E('-U<'!L:65D(&)Y(&%N(&%P<&QI8V%T:6]N('!R;V=R86T@=&AA="!U
M<V5S"B`@("!T:&4@9F%C:6QI='DL(&]T:&5R('1H86X@87,@86X@87)G=6UE
M;G0@<&%S<V5D('=H96X@=&AE(&9A8VEL:71Y"B`@("!I<R!I;G9O:V5D+"!T
M:&5N('EO=2!M=7-T(&UA:V4@82!G;V]D(&9A:71H(&5F9F]R="!T;R!E;G-U
M<F4@=&AA="P*("`@(&EN('1H92!E=F5N="!A;B!A<'!L:6-A=&EO;B!D;V5S
M(&YO="!S=7!P;'D@<W5C:"!F=6YC=&EO;B!O<@H@("`@=&%B;&4L('1H92!F
M86-I;&ET>2!S=&EL;"!O<&5R871E<RP@86YD('!E<F9O<FUS('=H871E=F5R
M('!A<G0@;V8*("`@(&ET<R!P=7)P;W-E(')E;6%I;G,@;65A;FEN9V9U;"X*
M"B`@("`H1F]R(&5X86UP;&4L(&$@9G5N8W1I;VX@:6X@82!L:6)R87)Y('1O
M(&-O;7!U=&4@<W%U87)E(')O;W1S(&AA<PH@("`@82!P=7)P;W-E('1H870@
M:7,@96YT:7)E;'D@=V5L;"UD969I;F5D(&EN9&5P96YD96YT(&]F('1H90H@
M("`@87!P;&EC871I;VXN("!4:&5R969O<F4L(%-U8G-E8W1I;VX@,F0@<F5Q
M=6ER97,@=&AA="!A;GD*("`@(&%P<&QI8V%T:6]N+7-U<'!L:65D(&9U;F-T
M:6]N(&]R('1A8FQE('5S960@8GD@=&AI<R!F=6YC=&EO;B!M=7-T"B`@("!B
M92!O<'1I;VYA;#H@:68@=&AE(&%P<&QI8V%T:6]N(&1O97,@;F]T('-U<'!L
M>2!I="P@=&AE('-Q=6%R90H@("`@<F]O="!F=6YC=&EO;B!M=7-T('-T:6QL
M(&-O;7!U=&4@<W%U87)E(')O;W1S+BD*"E1H97-E(')E<75I<F5M96YT<R!A
M<'!L>2!T;R!T:&4@;6]D:69I960@=V]R:R!A<R!A('=H;VQE+B`@268*:61E
M;G1I9FEA8FQE('-E8W1I;VYS(&]F('1H870@=V]R:R!A<F4@;F]T(&1E<FEV
M960@9G)O;2!T:&4@3&EB<F%R>2P*86YD(&-A;B!B92!R96%S;VYA8FQY(&-O
M;G-I9&5R960@:6YD97!E;F1E;G0@86YD('-E<&%R871E('=O<FMS(&EN"G1H
M96US96QV97,L('1H96X@=&AI<R!,:6-E;G-E+"!A;F0@:71S('1E<FUS+"!D
M;R!N;W0@87!P;'D@=&\@=&AO<V4*<V5C=&EO;G,@=VAE;B!Y;W4@9&ES=')I
M8G5T92!T:&5M(&%S('-E<&%R871E('=O<FMS+B`@0G5T('=H96X@>6]U"F1I
M<W1R:6)U=&4@=&AE('-A;64@<V5C=&EO;G,@87,@<&%R="!O9B!A('=H;VQE
M('=H:6-H(&ES(&$@=V]R:R!B87-E9`IO;B!T:&4@3&EB<F%R>2P@=&AE(&1I
M<W1R:6)U=&EO;B!O9B!T:&4@=VAO;&4@;75S="!B92!O;B!T:&4@=&5R;7,@
M;V8*=&AI<R!,:6-E;G-E+"!W:&]S92!P97)M:7-S:6]N<R!F;W(@;W1H97(@
M;&EC96YS965S(&5X=&5N9"!T;R!T:&4*96YT:7)E('=H;VQE+"!A;F0@=&AU
M<R!T;R!E86-H(&%N9"!E=F5R>2!P87)T(')E9V%R9&QE<W,@;V8@=VAO('=R
M;W1E"FET+@H*5&AU<RP@:70@:7,@;F]T('1H92!I;G1E;G0@;V8@=&AI<R!S
M96-T:6]N('1O(&-L86EM(')I9VAT<R!O<B!C;VYT97-T"GEO=7(@<FEG:'1S
M('1O('=O<FL@=W)I='1E;B!E;G1I<F5L>2!B>2!Y;W4[(')A=&AE<BP@=&AE
M(&EN=&5N="!I<R!T;PIE>&5R8VES92!T:&4@<FEG:'0@=&\@8V]N=')O;"!T
M:&4@9&ES=')I8G5T:6]N(&]F(&1E<FEV871I=F4@;W(*8V]L;&5C=&EV92!W
M;W)K<R!B87-E9"!O;B!T:&4@3&EB<F%R>2X*"DEN(&%D9&ET:6]N+"!M97)E
M(&%G9W)E9V%T:6]N(&]F(&%N;W1H97(@=V]R:R!N;W0@8F%S960@;VX@=&AE
M($QI8G)A<GD*=VET:"!T:&4@3&EB<F%R>2`H;W(@=VET:"!A('=O<FL@8F%S
M960@;VX@=&AE($QI8G)A<GDI(&]N(&$@=F]L=6UE(&]F"F$@<W1O<F%G92!O
M<B!D:7-T<FEB=71I;VX@;65D:75M(&1O97,@;F]T(&)R:6YG('1H92!O=&AE
M<B!W;W)K('5N9&5R"G1H92!S8V]P92!O9B!T:&ES($QI8V5N<V4N"@H@(#,N
M(%EO=2!M87D@;W!T('1O(&%P<&QY('1H92!T97)M<R!O9B!T:&4@;W)D:6YA
M<GD@1TY5($=E;F5R86P@4'5B;&EC"DQI8V5N<V4@:6YS=&5A9"!O9B!T:&ES
M($QI8V5N<V4@=&\@82!G:79E;B!C;W!Y(&]F('1H92!,:6)R87)Y+B`@5&\@
M9&\*=&AI<RP@>6]U(&UU<W0@86QT97(@86QL('1H92!N;W1I8V5S('1H870@
M<F5F97(@=&\@=&AI<R!,:6-E;G-E+"!S;PIT:&%T('1H97D@<F5F97(@=&\@
M=&AE(&]R9&EN87)Y($=.52!'96YE<F%L(%!U8FQI8R!,:6-E;G-E+"!V97)S
M:6]N(#(L"FEN<W1E860@;V8@=&\@=&AI<R!,:6-E;G-E+B`@*$EF(&$@;F5W
M97(@=F5R<VEO;B!T:&%N('9E<G-I;VX@,B!O9B!T:&4*;W)D:6YA<GD@1TY5
M($=E;F5R86P@4'5B;&EC($QI8V5N<V4@:&%S(&%P<&5A<F5D+"!T:&5N('EO
M=2!C86X@<W!E8VEF>0IT:&%T('9E<G-I;VX@:6YS=&5A9"!I9B!Y;W4@=VES
M:"XI("!$;R!N;W0@;6%K92!A;GD@;W1H97(@8VAA;F=E(&EN"G1H97-E(&YO
M=&EC97,N"@P*("!/;F-E('1H:7,@8VAA;F=E(&ES(&UA9&4@:6X@82!G:79E
M;B!C;W!Y+"!I="!I<R!I<G)E=F5R<VEB;&4@9F]R"G1H870@8V]P>2P@<V\@
M=&AE(&]R9&EN87)Y($=.52!'96YE<F%L(%!U8FQI8R!,:6-E;G-E(&%P<&QI
M97,@=&\@86QL"G-U8G-E<75E;G0@8V]P:65S(&%N9"!D97)I=F%T:79E('=O
M<FMS(&UA9&4@9G)O;2!T:&%T(&-O<'DN"@H@(%1H:7,@;W!T:6]N(&ES('5S
M969U;"!W:&5N('EO=2!W:7-H('1O(&-O<'D@<&%R="!O9B!T:&4@8V]D92!O
M9@IT:&4@3&EB<F%R>2!I;G1O(&$@<')O9W)A;2!T:&%T(&ES(&YO="!A(&QI
M8G)A<GDN"@H@(#0N(%EO=2!M87D@8V]P>2!A;F0@9&ES=')I8G5T92!T:&4@
M3&EB<F%R>2`H;W(@82!P;W)T:6]N(&]R"F1E<FEV871I=F4@;V8@:70L('5N
M9&5R(%-E8W1I;VX@,BD@:6X@;V)J96-T(&-O9&4@;W(@97AE8W5T86)L92!F
M;W)M"G5N9&5R('1H92!T97)M<R!O9B!396-T:6]N<R`Q(&%N9"`R(&%B;W9E
M('!R;W9I9&5D('1H870@>6]U(&%C8V]M<&%N>0II="!W:71H('1H92!C;VUP
M;&5T92!C;W)R97-P;VYD:6YG(&UA8VAI;F4M<F5A9&%B;&4@<V]U<F-E(&-O
M9&4L('=H:6-H"FUU<W0@8F4@9&ES=')I8G5T960@=6YD97(@=&AE('1E<FUS
M(&]F(%-E8W1I;VYS(#$@86YD(#(@86)O=F4@;VX@80IM961I=6T@8W5S=&]M
M87)I;'D@=7-E9"!F;W(@<V]F='=A<F4@:6YT97)C:&%N9V4N"@H@($EF(&1I
M<W1R:6)U=&EO;B!O9B!O8FIE8W0@8V]D92!I<R!M861E(&)Y(&]F9F5R:6YG
M(&%C8V5S<R!T;R!C;W!Y"F9R;VT@82!D97-I9VYA=&5D('!L86-E+"!T:&5N
M(&]F9F5R:6YG(&5Q=6EV86QE;G0@86-C97-S('1O(&-O<'D@=&AE"G-O=7)C
M92!C;V1E(&9R;VT@=&AE('-A;64@<&QA8V4@<V%T:7-F:65S('1H92!R97%U
M:7)E;65N="!T;PID:7-T<FEB=71E('1H92!S;W5R8V4@8V]D92P@979E;B!T
M:&]U9V@@=&AI<F0@<&%R=&EE<R!A<F4@;F]T"F-O;7!E;&QE9"!T;R!C;W!Y
M('1H92!S;W5R8V4@86QO;F<@=VET:"!T:&4@;V)J96-T(&-O9&4N"@H@(#4N
M($$@<')O9W)A;2!T:&%T(&-O;G1A:6YS(&YO(&1E<FEV871I=F4@;V8@86YY
M('!O<G1I;VX@;V8@=&AE"DQI8G)A<GDL(&)U="!I<R!D97-I9VYE9"!T;R!W
M;W)K('=I=&@@=&AE($QI8G)A<GD@8GD@8F5I;F<@8V]M<&EL960@;W(*;&EN
M:V5D('=I=&@@:70L(&ES(&-A;&QE9"!A(")W;W)K('1H870@=7-E<R!T:&4@
M3&EB<F%R>2(N("!3=6-H(&$*=V]R:RP@:6X@:7-O;&%T:6]N+"!I<R!N;W0@
M82!D97)I=F%T:79E('=O<FL@;V8@=&AE($QI8G)A<GDL(&%N9`IT:&5R969O
M<F4@9F%L;',@;W5T<VED92!T:&4@<V-O<&4@;V8@=&AI<R!,:6-E;G-E+@H*
M("!(;W=E=F5R+"!L:6YK:6YG(&$@(G=O<FL@=&AA="!U<V5S('1H92!,:6)R
M87)Y(B!W:71H('1H92!,:6)R87)Y"F-R96%T97,@86X@97AE8W5T86)L92!T
M:&%T(&ES(&$@9&5R:79A=&EV92!O9B!T:&4@3&EB<F%R>2`H8F5C875S92!I
M=`IC;VYT86EN<R!P;W)T:6]N<R!O9B!T:&4@3&EB<F%R>2DL(')A=&AE<B!T
M:&%N(&$@(G=O<FL@=&AA="!U<V5S('1H90IL:6)R87)Y(BX@(%1H92!E>&5C
M=71A8FQE(&ES('1H97)E9F]R92!C;W9E<F5D(&)Y('1H:7,@3&EC96YS92X*
M4V5C=&EO;B`V('-T871E<R!T97)M<R!F;W(@9&ES=')I8G5T:6]N(&]F('-U
M8V@@97AE8W5T86)L97,N"@H@(%=H96X@82`B=V]R:R!T:&%T('5S97,@=&AE
M($QI8G)A<GDB('5S97,@;6%T97)I86P@9G)O;2!A(&AE861E<B!F:6QE"G1H
M870@:7,@<&%R="!O9B!T:&4@3&EB<F%R>2P@=&AE(&]B:F5C="!C;V1E(&9O
M<B!T:&4@=V]R:R!M87D@8F4@80ID97)I=F%T:79E('=O<FL@;V8@=&AE($QI
M8G)A<GD@979E;B!T:&]U9V@@=&AE('-O=7)C92!C;V1E(&ES(&YO="X*5VAE
M=&AE<B!T:&ES(&ES('1R=64@:7,@97-P96-I86QL>2!S:6=N:69I8V%N="!I
M9B!T:&4@=V]R:R!C86X@8F4*;&EN:V5D('=I=&AO=70@=&AE($QI8G)A<GDL
M(&]R(&EF('1H92!W;W)K(&ES(&ET<V5L9B!A(&QI8G)A<GDN("!4:&4*=&AR
M97-H;VQD(&9O<B!T:&ES('1O(&)E('1R=64@:7,@;F]T('!R96-I<V5L>2!D
M969I;F5D(&)Y(&QA=RX*"B`@268@<W5C:"!A;B!O8FIE8W0@9FEL92!U<V5S
M(&]N;'D@;G5M97)I8V%L('!A<F%M971E<G,L(&1A=&$*<W1R=6-T=7)E(&QA
M>6]U=',@86YD(&%C8V5S<V]R<RP@86YD('-M86QL(&UA8W)O<R!A;F0@<VUA
M;&P@:6YL:6YE"F9U;F-T:6]N<R`H=&5N(&QI;F5S(&]R(&QE<W,@:6X@;&5N
M9W1H*2P@=&AE;B!T:&4@=7-E(&]F('1H92!O8FIE8W0*9FEL92!I<R!U;G)E
M<W1R:6-T960L(')E9V%R9&QE<W,@;V8@=VAE=&AE<B!I="!I<R!L96=A;&QY
M(&$@9&5R:79A=&EV90IW;W)K+B`@*$5X96-U=&%B;&5S(&-O;G1A:6YI;F<@
M=&AI<R!O8FIE8W0@8V]D92!P;'5S('!O<G1I;VYS(&]F('1H90I,:6)R87)Y
M('=I;&P@<W1I;&P@9F%L;"!U;F1E<B!396-T:6]N(#8N*0H*("!/=&AE<G=I
M<V4L(&EF('1H92!W;W)K(&ES(&$@9&5R:79A=&EV92!O9B!T:&4@3&EB<F%R
M>2P@>6]U(&UA>0ID:7-T<FEB=71E('1H92!O8FIE8W0@8V]D92!F;W(@=&AE
M('=O<FL@=6YD97(@=&AE('1E<FUS(&]F(%-E8W1I;VX@-BX*06YY(&5X96-U
M=&%B;&5S(&-O;G1A:6YI;F<@=&AA="!W;W)K(&%L<V\@9F%L;"!U;F1E<B!3
M96-T:6]N(#8L"G=H971H97(@;W(@;F]T('1H97D@87)E(&QI;FME9"!D:7)E
M8W1L>2!W:71H('1H92!,:6)R87)Y(&ET<V5L9BX*#`H@(#8N($%S(&%N(&5X
M8V5P=&EO;B!T;R!T:&4@4V5C=&EO;G,@86)O=F4L('EO=2!M87D@86QS;R!C
M;VUP:6QE(&]R"FQI;FL@82`B=V]R:R!T:&%T('5S97,@=&AE($QI8G)A<GDB
M('=I=&@@=&AE($QI8G)A<GD@=&\@<')O9'5C92!A"G=O<FL@8V]N=&%I;FEN
M9R!P;W)T:6]N<R!O9B!T:&4@3&EB<F%R>2P@86YD(&1I<W1R:6)U=&4@=&AA
M="!W;W)K"G5N9&5R('1E<FUS(&]F('EO=7(@8VAO:6-E+"!P<F]V:61E9"!T
M:&%T('1H92!T97)M<R!P97)M:70*;6]D:69I8V%T:6]N(&]F('1H92!W;W)K
M(&9O<B!T:&4@8W5S=&]M97(G<R!O=VX@=7-E(&%N9"!R979E<G-E"F5N9VEN
M965R:6YG(&9O<B!D96)U9V=I;F<@<W5C:"!M;V1I9FEC871I;VYS+@H*("!9
M;W4@;75S="!G:79E('!R;VUI;F5N="!N;W1I8V4@=VET:"!E86-H(&-O<'D@
M;V8@=&AE('=O<FL@=&AA="!T:&4*3&EB<F%R>2!I<R!U<V5D(&EN(&ET(&%N
M9"!T:&%T('1H92!,:6)R87)Y(&%N9"!I=',@=7-E(&%R92!C;W9E<F5D(&)Y
M"G1H:7,@3&EC96YS92X@(%EO=2!M=7-T('-U<'!L>2!A(&-O<'D@;V8@=&AI
M<R!,:6-E;G-E+B`@268@=&AE('=O<FL*9'5R:6YG(&5X96-U=&EO;B!D:7-P
M;&%Y<R!C;W!Y<FEG:'0@;F]T:6-E<RP@>6]U(&UU<W0@:6YC;'5D92!T:&4*
M8V]P>7)I9VAT(&YO=&EC92!F;W(@=&AE($QI8G)A<GD@86UO;F<@=&AE;2P@
M87,@=V5L;"!A<R!A(')E9F5R96YC90ID:7)E8W1I;F<@=&AE('5S97(@=&\@
M=&AE(&-O<'D@;V8@=&AI<R!,:6-E;G-E+B`@06QS;RP@>6]U(&UU<W0@9&\@
M;VYE"F]F('1H97-E('1H:6YG<SH*"B`@("!A*2!!8V-O;7!A;GD@=&AE('=O
M<FL@=VET:"!T:&4@8V]M<&QE=&4@8V]R<F5S<&]N9&EN9PH@("`@;6%C:&EN
M92UR96%D86)L92!S;W5R8V4@8V]D92!F;W(@=&AE($QI8G)A<GD@:6YC;'5D
M:6YG('=H871E=F5R"B`@("!C:&%N9V5S('=E<F4@=7-E9"!I;B!T:&4@=V]R
M:R`H=VAI8V@@;75S="!B92!D:7-T<FEB=71E9"!U;F1E<@H@("`@4V5C=&EO
M;G,@,2!A;F0@,B!A8F]V92D[(&%N9"P@:68@=&AE('=O<FL@:7,@86X@97AE
M8W5T86)L92!L:6YK960*("`@('=I=&@@=&AE($QI8G)A<GDL('=I=&@@=&AE
M(&-O;7!L971E(&UA8VAI;F4M<F5A9&%B;&4@(G=O<FL@=&AA=`H@("`@=7-E
M<R!T:&4@3&EB<F%R>2(L(&%S(&]B:F5C="!C;V1E(&%N9"]O<B!S;W5R8V4@
M8V]D92P@<V\@=&AA="!T:&4*("`@('5S97(@8V%N(&UO9&EF>2!T:&4@3&EB
M<F%R>2!A;F0@=&AE;B!R96QI;FL@=&\@<')O9'5C92!A(&UO9&EF:65D"B`@
M("!E>&5C=71A8FQE(&-O;G1A:6YI;F<@=&AE(&UO9&EF:65D($QI8G)A<GDN
M("`H270@:7,@=6YD97)S=&]O9`H@("`@=&AA="!T:&4@=7-E<B!W:&\@8VAA
M;F=E<R!T:&4@8V]N=&5N=',@;V8@9&5F:6YI=&EO;G,@9FEL97,@:6X@=&AE
M"B`@("!,:6)R87)Y('=I;&P@;F]T(&YE8V5S<V%R:6QY(&)E(&%B;&4@=&\@
M<F5C;VUP:6QE('1H92!A<'!L:6-A=&EO;@H@("`@=&\@=7-E('1H92!M;V1I
M9FEE9"!D969I;FET:6]N<RXI"@H@("`@8BD@06-C;VUP86YY('1H92!W;W)K
M('=I=&@@82!W<FET=&5N(&]F9F5R+"!V86QI9"!F;W(@870*("`@(&QE87-T
M('1H<F5E('EE87)S+"!T;R!G:79E('1H92!S86UE('5S97(@=&AE(&UA=&5R
M:6%L<PH@("`@<W!E8VEF:65D(&EN(%-U8G-E8W1I;VX@-F$L(&%B;W9E+"!F
M;W(@82!C:&%R9V4@;F\@;6]R90H@("`@=&AA;B!T:&4@8V]S="!O9B!P97)F
M;W)M:6YG('1H:7,@9&ES=')I8G5T:6]N+@H*("`@(&,I($EF(&1I<W1R:6)U
M=&EO;B!O9B!T:&4@=V]R:R!I<R!M861E(&)Y(&]F9F5R:6YG(&%C8V5S<R!T
M;R!C;W!Y"B`@("!F<F]M(&$@9&5S:6=N871E9"!P;&%C92P@;V9F97(@97%U
M:79A;&5N="!A8V-E<W,@=&\@8V]P>2!T:&4@86)O=F4*("`@('-P96-I9FEE
M9"!M871E<FEA;',@9G)O;2!T:&4@<V%M92!P;&%C92X*"B`@("!D*2!697)I
M9GD@=&AA="!T:&4@=7-E<B!H87,@86QR96%D>2!R96-E:79E9"!A(&-O<'D@
M;V8@=&AE<V4*("`@(&UA=&5R:6%L<R!O<B!T:&%T('EO=2!H879E(&%L<F5A
M9'D@<V5N="!T:&ES('5S97(@82!C;W!Y+@H*("!&;W(@86X@97AE8W5T86)L
M92P@=&AE(')E<75I<F5D(&9O<FT@;V8@=&AE(")W;W)K('1H870@=7-E<R!T
M:&4*3&EB<F%R>2(@;75S="!I;F-L=61E(&%N>2!D871A(&%N9"!U=&EL:71Y
M('!R;V=R86US(&YE961E9"!F;W(*<F5P<F]D=6-I;F<@=&AE(&5X96-U=&%B
M;&4@9G)O;2!I="X@($AO=V5V97(L(&%S(&$@<W!E8VEA;"!E>&-E<'1I;VXL
M"G1H92!S;W5R8V4@8V]D92!D:7-T<FEB=71E9"!N965D(&YO="!I;F-L=61E
M(&%N>71H:6YG('1H870@:7,@;F]R;6%L;'D*9&ES=')I8G5T960@*&EN(&5I
M=&AE<B!S;W5R8V4@;W(@8FEN87)Y(&9O<FTI('=I=&@@=&AE(&UA:F]R"F-O
M;7!O;F5N=',@*&-O;7!I;&5R+"!K97)N96PL(&%N9"!S;R!O;BD@;V8@=&AE
M(&]P97)A=&EN9R!S>7-T96T@;VX*=VAI8V@@=&AE(&5X96-U=&%B;&4@<G5N
M<RP@=6YL97-S('1H870@8V]M<&]N96YT(&ET<V5L9B!A8V-O;7!A;FEE<PIT
M:&4@97AE8W5T86)L92X*"B`@270@;6%Y(&AA<'!E;B!T:&%T('1H:7,@<F5Q
M=6ER96UE;G0@8V]N=')A9&EC=',@=&AE(&QI8V5N<V4*<F5S=')I8W1I;VYS
M(&]F(&]T:&5R('!R;W!R:65T87)Y(&QI8G)A<FEE<R!T:&%T(&1O(&YO="!N
M;W)M86QL>0IA8V-O;7!A;GD@=&AE(&]P97)A=&EN9R!S>7-T96TN("!3=6-H
M(&$@8V]N=')A9&EC=&EO;B!M96%N<R!Y;W4@8V%N;F]T"G5S92!B;W1H('1H
M96T@86YD('1H92!,:6)R87)Y('1O9V5T:&5R(&EN(&%N(&5X96-U=&%B;&4@
M=&AA="!Y;W4*9&ES=')I8G5T92X*#`H@(#<N(%EO=2!M87D@<&QA8V4@;&EB
M<F%R>2!F86-I;&ET:65S('1H870@87)E(&$@=V]R:R!B87-E9"!O;B!T:&4*
M3&EB<F%R>2!S:61E+6)Y+7-I9&4@:6X@82!S:6YG;&4@;&EB<F%R>2!T;V=E
M=&AE<B!W:71H(&]T:&5R(&QI8G)A<GD*9F%C:6QI=&EE<R!N;W0@8V]V97)E
M9"!B>2!T:&ES($QI8V5N<V4L(&%N9"!D:7-T<FEB=71E('-U8V@@82!C;VUB
M:6YE9`IL:6)R87)Y+"!P<F]V:61E9"!T:&%T('1H92!S97!A<F%T92!D:7-T
M<FEB=71I;VX@;V8@=&AE('=O<FL@8F%S960@;VX*=&AE($QI8G)A<GD@86YD
M(&]F('1H92!O=&AE<B!L:6)R87)Y(&9A8VEL:71I97,@:7,@;W1H97)W:7-E
M"G!E<FUI='1E9"P@86YD('!R;W9I9&5D('1H870@>6]U(&1O('1H97-E('1W
M;R!T:&EN9W,Z"@H@("`@82D@06-C;VUP86YY('1H92!C;VUB:6YE9"!L:6)R
M87)Y('=I=&@@82!C;W!Y(&]F('1H92!S86UE('=O<FL*("`@(&)A<V5D(&]N
M('1H92!,:6)R87)Y+"!U;F-O;6)I;F5D('=I=&@@86YY(&]T:&5R(&QI8G)A
M<GD*("`@(&9A8VEL:71I97,N("!4:&ES(&UU<W0@8F4@9&ES=')I8G5T960@
M=6YD97(@=&AE('1E<FUS(&]F('1H90H@("`@4V5C=&EO;G,@86)O=F4N"@H@
M("`@8BD@1VEV92!P<F]M:6YE;G0@;F]T:6-E('=I=&@@=&AE(&-O;6)I;F5D
M(&QI8G)A<GD@;V8@=&AE(&9A8W0*("`@('1H870@<&%R="!O9B!I="!I<R!A
M('=O<FL@8F%S960@;VX@=&AE($QI8G)A<GDL(&%N9"!E>'!L86EN:6YG"B`@
M("!W:&5R92!T;R!F:6YD('1H92!A8V-O;7!A;GEI;F<@=6YC;VUB:6YE9"!F
M;W)M(&]F('1H92!S86UE('=O<FLN"@H@(#@N(%EO=2!M87D@;F]T(&-O<'DL
M(&UO9&EF>2P@<W5B;&EC96YS92P@;&EN:R!W:71H+"!O<B!D:7-T<FEB=71E
M"G1H92!,:6)R87)Y(&5X8V5P="!A<R!E>'!R97-S;'D@<')O=FED960@=6YD
M97(@=&AI<R!,:6-E;G-E+B`@06YY"F%T=&5M<'0@;W1H97)W:7-E('1O(&-O
M<'DL(&UO9&EF>2P@<W5B;&EC96YS92P@;&EN:R!W:71H+"!O<@ID:7-T<FEB
M=71E('1H92!,:6)R87)Y(&ES('9O:60L(&%N9"!W:6QL(&%U=&]M871I8V%L
M;'D@=&5R;6EN871E('EO=7(*<FEG:'1S('5N9&5R('1H:7,@3&EC96YS92X@
M($AO=V5V97(L('!A<G1I97,@=VAO(&AA=F4@<F5C96EV960@8V]P:65S+`IO
M<B!R:6=H=',L(&9R;VT@>6]U('5N9&5R('1H:7,@3&EC96YS92!W:6QL(&YO
M="!H879E('1H96ER(&QI8V5N<V5S"G1E<FUI;F%T960@<V\@;&]N9R!A<R!S
M=6-H('!A<G1I97,@<F5M86EN(&EN(&9U;&P@8V]M<&QI86YC92X*"B`@.2X@
M66]U(&%R92!N;W0@<F5Q=6ER960@=&\@86-C97!T('1H:7,@3&EC96YS92P@
M<VEN8V4@>6]U(&AA=F4@;F]T"G-I9VYE9"!I="X@($AO=V5V97(L(&YO=&AI
M;F<@96QS92!G<F%N=',@>6]U('!E<FUI<W-I;VX@=&\@;6]D:69Y(&]R"F1I
M<W1R:6)U=&4@=&AE($QI8G)A<GD@;W(@:71S(&1E<FEV871I=F4@=V]R:W,N
M("!4:&5S92!A8W1I;VYS(&%R90IP<F]H:6)I=&5D(&)Y(&QA=R!I9B!Y;W4@
M9&\@;F]T(&%C8V5P="!T:&ES($QI8V5N<V4N("!4:&5R969O<F4L(&)Y"FUO
M9&EF>6EN9R!O<B!D:7-T<FEB=71I;F<@=&AE($QI8G)A<GD@*&]R(&%N>2!W
M;W)K(&)A<V5D(&]N('1H90I,:6)R87)Y*2P@>6]U(&EN9&EC871E('EO=7(@
M86-C97!T86YC92!O9B!T:&ES($QI8V5N<V4@=&\@9&\@<V\L(&%N9`IA;&P@
M:71S('1E<FUS(&%N9"!C;VYD:71I;VYS(&9O<B!C;W!Y:6YG+"!D:7-T<FEB
M=71I;F<@;W(@;6]D:69Y:6YG"G1H92!,:6)R87)Y(&]R('=O<FMS(&)A<V5D
M(&]N(&ET+@H*("`Q,"X@16%C:"!T:6UE('EO=2!R961I<W1R:6)U=&4@=&AE
M($QI8G)A<GD@*&]R(&%N>2!W;W)K(&)A<V5D(&]N('1H90I,:6)R87)Y*2P@
M=&AE(')E8VEP:65N="!A=71O;6%T:6-A;&QY(')E8V5I=F5S(&$@;&EC96YS
M92!F<F]M('1H90IO<FEG:6YA;"!L:6-E;G-O<B!T;R!C;W!Y+"!D:7-T<FEB
M=71E+"!L:6YK('=I=&@@;W(@;6]D:69Y('1H92!,:6)R87)Y"G-U8FIE8W0@
M=&\@=&AE<V4@=&5R;7,@86YD(&-O;F1I=&EO;G,N("!9;W4@;6%Y(&YO="!I
M;7!O<V4@86YY(&9U<G1H97(*<F5S=')I8W1I;VYS(&]N('1H92!R96-I<&EE
M;G1S)R!E>&5R8VES92!O9B!T:&4@<FEG:'1S(&=R86YT960@:&5R96EN+@I9
M;W4@87)E(&YO="!R97-P;VYS:6)L92!F;W(@96YF;W)C:6YG(&-O;7!L:6%N
M8V4@8GD@=&AI<F0@<&%R=&EE<R!T;PIT:&ES($QI8V5N<V4N"@P*("`Q,2X@
M268L(&%S(&$@8V]N<V5Q=65N8V4@;V8@82!C;W5R="!J=61G;65N="!O<B!A
M;&QE9V%T:6]N(&]F('!A=&5N=`II;F9R:6YG96UE;G0@;W(@9F]R(&%N>2!O
M=&AE<B!R96%S;VX@*&YO="!L:6UI=&5D('1O('!A=&5N="!I<W-U97,I+`IC
M;VYD:71I;VYS(&%R92!I;7!O<V5D(&]N('EO=2`H=VAE=&AE<B!B>2!C;W5R
M="!O<F1E<BP@86=R965M96YT(&]R"F]T:&5R=VES92D@=&AA="!C;VYT<F%D
M:6-T('1H92!C;VYD:71I;VYS(&]F('1H:7,@3&EC96YS92P@=&AE>2!D;R!N
M;W0*97AC=7-E('EO=2!F<F]M('1H92!C;VYD:71I;VYS(&]F('1H:7,@3&EC
M96YS92X@($EF('EO=2!C86YN;W0*9&ES=')I8G5T92!S;R!A<R!T;R!S871I
M<V9Y('-I;75L=&%N96]U<VQY('EO=7(@;V)L:6=A=&EO;G,@=6YD97(@=&AI
M<PI,:6-E;G-E(&%N9"!A;GD@;W1H97(@<&5R=&EN96YT(&]B;&EG871I;VYS
M+"!T:&5N(&%S(&$@8V]N<V5Q=65N8V4@>6]U"FUA>2!N;W0@9&ES=')I8G5T
M92!T:&4@3&EB<F%R>2!A="!A;&PN("!&;W(@97AA;7!L92P@:68@82!P871E
M;G0*;&EC96YS92!W;W5L9"!N;W0@<&5R;6ET(')O>6%L='DM9G)E92!R961I
M<W1R:6)U=&EO;B!O9B!T:&4@3&EB<F%R>2!B>0IA;&P@=&AO<V4@=VAO(')E
M8V5I=F4@8V]P:65S(&1I<F5C=&QY(&]R(&EN9&ER96-T;'D@=&AR;W5G:"!Y
M;W4L('1H96X*=&AE(&]N;'D@=V%Y('EO=2!C;W5L9"!S871I<V9Y(&)O=&@@
M:70@86YD('1H:7,@3&EC96YS92!W;W5L9"!B92!T;PIR969R86EN(&5N=&ER
M96QY(&9R;VT@9&ES=')I8G5T:6]N(&]F('1H92!,:6)R87)Y+@H*268@86YY
M('!O<G1I;VX@;V8@=&AI<R!S96-T:6]N(&ES(&AE;&0@:6YV86QI9"!O<B!U
M;F5N9F]R8V5A8FQE('5N9&5R(&%N>0IP87)T:6-U;&%R(&-I<F-U;7-T86YC
M92P@=&AE(&)A;&%N8V4@;V8@=&AE('-E8W1I;VX@:7,@:6YT96YD960@=&\@
M87!P;'DL"F%N9"!T:&4@<V5C=&EO;B!A<R!A('=H;VQE(&ES(&EN=&5N9&5D
M('1O(&%P<&QY(&EN(&]T:&5R(&-I<F-U;7-T86YC97,N"@I)="!I<R!N;W0@
M=&AE('!U<G!O<V4@;V8@=&AI<R!S96-T:6]N('1O(&EN9'5C92!Y;W4@=&\@
M:6YF<FEN9V4@86YY"G!A=&5N=',@;W(@;W1H97(@<')O<&5R='D@<FEG:'0@
M8VQA:6US(&]R('1O(&-O;G1E<W0@=F%L:61I='D@;V8@86YY"G-U8V@@8VQA
M:6US.R!T:&ES('-E8W1I;VX@:&%S('1H92!S;VQE('!U<G!O<V4@;V8@<')O
M=&5C=&EN9R!T:&4*:6YT96=R:71Y(&]F('1H92!F<F5E('-O9G1W87)E(&1I
M<W1R:6)U=&EO;B!S>7-T96T@=VAI8V@@:7,*:6UP;&5M96YT960@8GD@<'5B
M;&EC(&QI8V5N<V4@<')A8W1I8V5S+B`@36%N>2!P96]P;&4@:&%V92!M861E
M"F=E;F5R;W5S(&-O;G1R:6)U=&EO;G,@=&\@=&AE('=I9&4@<F%N9V4@;V8@
M<V]F='=A<F4@9&ES=')I8G5T960*=&AR;W5G:"!T:&%T('-Y<W1E;2!I;B!R
M96QI86YC92!O;B!C;VYS:7-T96YT(&%P<&QI8V%T:6]N(&]F('1H870*<WES
M=&5M.R!I="!I<R!U<"!T;R!T:&4@875T:&]R+V1O;F]R('1O(&1E8VED92!I
M9B!H92!O<B!S:&4@:7,@=VEL;&EN9PIT;R!D:7-T<FEB=71E('-O9G1W87)E
M('1H<F]U9V@@86YY(&]T:&5R('-Y<W1E;2!A;F0@82!L:6-E;G-E92!C86YN
M;W0*:6UP;W-E('1H870@8VAO:6-E+@H*5&AI<R!S96-T:6]N(&ES(&EN=&5N
M9&5D('1O(&UA:V4@=&AO<F]U9VAL>2!C;&5A<B!W:&%T(&ES(&)E;&EE=F5D
M('1O"F)E(&$@8V]N<V5Q=65N8V4@;V8@=&AE(')E<W0@;V8@=&AI<R!,:6-E
M;G-E+@H*("`Q,BX@268@=&AE(&1I<W1R:6)U=&EO;B!A;F0O;W(@=7-E(&]F
M('1H92!,:6)R87)Y(&ES(')E<W1R:6-T960@:6X*8V5R=&%I;B!C;W5N=')I
M97,@96ET:&5R(&)Y('!A=&5N=',@;W(@8GD@8V]P>7)I9VAT960@:6YT97)F
M86-E<RP@=&AE"F]R:6=I;F%L(&-O<'ER:6=H="!H;VQD97(@=VAO('!L86-E
M<R!T:&4@3&EB<F%R>2!U;F1E<B!T:&ES($QI8V5N<V4@;6%Y(&%D9`IA;B!E
M>'!L:6-I="!G96]G<F%P:&EC86P@9&ES=')I8G5T:6]N(&QI;6ET871I;VX@
M97AC;'5D:6YG('1H;W-E(&-O=6YT<FEE<RP*<V\@=&AA="!D:7-T<FEB=71I
M;VX@:7,@<&5R;6ET=&5D(&]N;'D@:6X@;W(@86UO;F<@8V]U;G1R:65S(&YO
M="!T:'5S"F5X8VQU9&5D+B`@26X@<W5C:"!C87-E+"!T:&ES($QI8V5N<V4@
M:6YC;W)P;W)A=&5S('1H92!L:6UI=&%T:6]N(&%S(&EF"G=R:71T96X@:6X@
M=&AE(&)O9'D@;V8@=&AI<R!,:6-E;G-E+@H*("`Q,RX@5&AE($9R964@4V]F
M='=A<F4@1F]U;F1A=&EO;B!M87D@<'5B;&ES:"!R979I<V5D(&%N9"]O<B!N
M97<*=F5R<VEO;G,@;V8@=&AE($QI8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC
M96YS92!F<F]M('1I;64@=&\@=&EM92X*4W5C:"!N97<@=F5R<VEO;G,@=VEL
M;"!B92!S:6UI;&%R(&EN('-P:7)I="!T;R!T:&4@<')E<V5N="!V97)S:6]N
M+`IB=70@;6%Y(&1I9F9E<B!I;B!D971A:6P@=&\@861D<F5S<R!N97<@<')O
M8FQE;7,@;W(@8V]N8V5R;G,N"@I%86-H('9E<G-I;VX@:7,@9VEV96X@82!D
M:7-T:6YG=6ES:&EN9R!V97)S:6]N(&YU;6)E<BX@($EF('1H92!,:6)R87)Y
M"G-P96-I9FEE<R!A('9E<G-I;VX@;G5M8F5R(&]F('1H:7,@3&EC96YS92!W
M:&EC:"!A<'!L:65S('1O(&ET(&%N9`HB86YY(&QA=&5R('9E<G-I;VXB+"!Y
M;W4@:&%V92!T:&4@;W!T:6]N(&]F(&9O;&QO=VEN9R!T:&4@=&5R;7,@86YD
M"F-O;F1I=&EO;G,@96ET:&5R(&]F('1H870@=F5R<VEO;B!O<B!O9B!A;GD@
M;&%T97(@=F5R<VEO;B!P=6)L:7-H960@8GD*=&AE($9R964@4V]F='=A<F4@
M1F]U;F1A=&EO;BX@($EF('1H92!,:6)R87)Y(&1O97,@;F]T('-P96-I9GD@
M80IL:6-E;G-E('9E<G-I;VX@;G5M8F5R+"!Y;W4@;6%Y(&-H;V]S92!A;GD@
M=F5R<VEO;B!E=F5R('!U8FQI<VAE9"!B>0IT:&4@1G)E92!3;V9T=V%R92!&
M;W5N9&%T:6]N+@H,"B`@,30N($EF('EO=2!W:7-H('1O(&EN8V]R<&]R871E
M('!A<G1S(&]F('1H92!,:6)R87)Y(&EN=&\@;W1H97(@9G)E90IP<F]G<F%M
M<R!W:&]S92!D:7-T<FEB=71I;VX@8V]N9&ET:6]N<R!A<F4@:6YC;VUP871I
M8FQE('=I=&@@=&AE<V4L"G=R:71E('1O('1H92!A=71H;W(@=&\@87-K(&9O
M<B!P97)M:7-S:6]N+B`@1F]R('-O9G1W87)E('=H:6-H(&ES"F-O<'ER:6=H
M=&5D(&)Y('1H92!&<F5E(%-O9G1W87)E($9O=6YD871I;VXL('=R:71E('1O
M('1H92!&<F5E"E-O9G1W87)E($9O=6YD871I;VX[('=E('-O;65T:6UE<R!M
M86ME(&5X8V5P=&EO;G,@9F]R('1H:7,N("!/=7(*9&5C:7-I;VX@=VEL;"!B
M92!G=6ED960@8GD@=&AE('1W;R!G;V%L<R!O9B!P<F5S97)V:6YG('1H92!F
M<F5E('-T871U<PIO9B!A;&P@9&5R:79A=&EV97,@;V8@;W5R(&9R964@<V]F
M='=A<F4@86YD(&]F('!R;VUO=&EN9R!T:&4@<VAA<FEN9PIA;F0@<F5U<V4@
M;V8@<V]F='=A<F4@9V5N97)A;&QY+@H*"0D)("`@($Y/(%=!4E)!3E19"@H@
M(#$U+B!"14-!55-%(%1(12!,24)205)9($E3($Q)0T5.4T5$($92144@3T8@
M0TA!4D=%+"!42$5212!)4R!.3PI705)204Y462!&3U(@5$A%($Q)0E)!4EDL
M(%1/(%1(12!%6%1%3E0@4$5234E45$5$($)9($%04$Q)0T%"3$4@3$%7+@I%
M6$-%4%0@5TA%3B!/5$A%4E=)4T4@4U1!5$5$($E.(%=2251)3D<@5$A%($-/
M4%E224=(5"!(3TQ$15)3($%.1"]/4@I/5$A%4B!005)42453(%!23U9)1$4@
M5$A%($Q)0E)!4ED@(D%3($E3(B!7251(3U54(%=!4E)!3E19($]&($%.60I+
M24Y$+"!%251(15(@15A04D534T5$($]2($E-4$Q)140L($E.0TQ51$E.1RP@
M0E54($Y/5"!,24U)5$5$(%1/+"!42$4*24U03$E%1"!705)204Y42453($]&
M($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2
M"E!54E!/4T4N("!42$4@14Y425)%(%))4TL@05,@5$\@5$A%(%%504Q)5%D@
M04Y$(%!%4D9/4DU!3D-%($]&(%1(10I,24)205)9($E3(%=)5$@@64]5+B`@
M4TA/54Q$(%1(12!,24)205)9(%!23U9%($1%1D5#5$E612P@64]5($%34U5-
M10I42$4@0T]35"!/1B!!3$P@3D5#15-305)9(%-%4E9)0TE.1RP@4D5004E2
M($]2($-/4E)%0U1)3TXN"@H@(#$V+B!)3B!.3R!%5D5.5"!53DQ%4U,@4D51
M54E2140@0ED@05!03$E#04),12!,05<@3U(@04=2145$(%1/($E."E=2251)
M3D<@5TE,3"!!3ED@0T]065))1TA4($A/3$1%4BP@3U(@04Y9($]42$52(%!!
M4E19(%=(3R!-05D@34]$2499"D%.1"]/4B!2141)4U1224)55$4@5$A%($Q)
M0E)!4ED@05,@4$5234E45$5$($%"3U9%+"!"12!,24%"3$4@5$\@64]5"D9/
M4B!$04U!1T53+"!)3D-,541)3D<@04Y9($=%3D5204PL(%-014-)04PL($E.
M0TE$14Y404P@3U(*0T].4T51545.5$E!3"!$04U!1T53($%225-)3D<@3U54
M($]&(%1(12!54T4@3U(@24Y!0DE,2519(%1/(%5312!42$4*3$E"4D%262`H
M24Y#3%5$24Y'($)55"!.3U0@3$E-251%1"!43R!,3U-3($]&($1!5$$@3U(@
M1$%402!"14E.1PI214Y$15)%1"!)3D%#0U52051%($]2($Q/4U-%4R!355-4
M04E.140@0ED@64]5($]2(%1(25)$(%!!4E1)15,@3U(@00I&04E,55)%($]&
M(%1(12!,24)205)9(%1/($]015)!5$4@5TE42"!!3ED@3U1(15(@4T]&5%=!
M4D4I+"!%5D5.($E&"E-50T@@2$],1$52($]2($]42$52(%!!4E19($A!4R!"
M145.($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@*1$%-04=%
M4RX*"@D)("`@("!%3D0@3T8@5$5235,@04Y$($-/3D1)5$E/3E,*#`H@("`@
M("`@("`@($AO=R!T;R!!<'!L>2!4:&5S92!497)M<R!T;R!9;W5R($YE=R!,
M:6)R87)I97,*"B`@268@>6]U(&1E=F5L;W`@82!N97<@;&EB<F%R>2P@86YD
M('EO=2!W86YT(&ET('1O(&)E(&]F('1H92!G<F5A=&5S=`IP;W-S:6)L92!U
M<V4@=&\@=&AE('!U8FQI8RP@=V4@<F5C;VUM96YD(&UA:VEN9R!I="!F<F5E
M('-O9G1W87)E('1H870*979E<GEO;F4@8V%N(')E9&ES=')I8G5T92!A;F0@
M8VAA;F=E+B`@66]U(&-A;B!D;R!S;R!B>2!P97)M:71T:6YG"G)E9&ES=')I
M8G5T:6]N('5N9&5R('1H97-E('1E<FUS("AO<BP@86QT97)N871I=F5L>2P@
M=6YD97(@=&AE('1E<FUS(&]F('1H90IO<F1I;F%R>2!'96YE<F%L(%!U8FQI
M8R!,:6-E;G-E*2X*"B`@5&\@87!P;'D@=&AE<V4@=&5R;7,L(&%T=&%C:"!T
M:&4@9F]L;&]W:6YG(&YO=&EC97,@=&\@=&AE(&QI8G)A<GDN("!)="!I<PIS
M869E<W0@=&\@871T86-H('1H96T@=&\@=&AE('-T87)T(&]F(&5A8V@@<V]U
M<F-E(&9I;&4@=&\@;6]S="!E9F9E8W1I=F5L>0IC;VYV97D@=&AE(&5X8VQU
M<VEO;B!O9B!W87)R86YT>3L@86YD(&5A8V@@9FEL92!S:&]U;&0@:&%V92!A
M="!L96%S="!T:&4*(F-O<'ER:6=H="(@;&EN92!A;F0@82!P;VEN=&5R('1O
M('=H97)E('1H92!F=6QL(&YO=&EC92!I<R!F;W5N9"X*"B`@("`\;VYE(&QI
M;F4@=&\@9VEV92!T:&4@;&EB<F%R>2=S(&YA;64@86YD(&$@8G)I968@:61E
M82!O9B!W:&%T(&ET(&1O97,N/@H@("`@0V]P>7)I9VAT("A#*2`\>65A<CX@
M(#QN86UE(&]F(&%U=&AO<CX*"B`@("!4:&ES(&QI8G)A<GD@:7,@9G)E92!S
M;V9T=V%R93L@>6]U(&-A;B!R961I<W1R:6)U=&4@:70@86YD+V]R"B`@("!M
M;V1I9GD@:70@=6YD97(@=&AE('1E<FUS(&]F('1H92!'3E4@3&EB<F%R>2!'
M96YE<F%L(%!U8FQI8PH@("`@3&EC96YS92!A<R!P=6)L:7-H960@8GD@=&AE
M($9R964@4V]F='=A<F4@1F]U;F1A=&EO;CL@96ET:&5R"B`@("!V97)S:6]N
M(#(@;V8@=&AE($QI8V5N<V4L(&]R("AA="!Y;W5R(&]P=&EO;BD@86YY(&QA
M=&5R('9E<G-I;VXN"@H@("`@5&AI<R!L:6)R87)Y(&ES(&1I<W1R:6)U=&5D
M(&EN('1H92!H;W!E('1H870@:70@=VEL;"!B92!U<V5F=6PL"B`@("!B=70@
M5TE42$]55"!!3ED@5T%24D%.5%D[('=I=&AO=70@979E;B!T:&4@:6UP;&EE
M9"!W87)R86YT>2!O9@H@("`@34520TA!3E1!0DE,2519(&]R($9)5$Y%4U,@
M1D]2($$@4$%25$E#54Q!4B!055)03U-%+B`@4V5E('1H92!'3E4*("`@($QI
M8G)A<GD@1V5N97)A;"!0=6)L:6,@3&EC96YS92!F;W(@;6]R92!D971A:6QS
M+@H*("`@(%EO=2!S:&]U;&0@:&%V92!R96-E:79E9"!A(&-O<'D@;V8@=&AE
M($=.52!,:6)R87)Y($=E;F5R86P@4'5B;&EC"B`@("!,:6-E;G-E(&%L;VYG
M('=I=&@@=&AI<R!L:6)R87)Y.R!I9B!N;W0L('=R:71E('1O('1H92!&<F5E
M"B`@("!&;W5N9&%T:6]N+"!);F,N+"`U.2!496UP;&4@4&QA8V4L(%-U:71E
M(#,S,"P@0F]S=&]N+"!-02`@,#(Q,3$M,3,P-R`@55-!"@I!;'-O(&%D9"!I
M;F9O<FUA=&EO;B!O;B!H;W<@=&\@8V]N=&%C="!Y;W4@8GD@96QE8W1R;VYI
M8R!A;F0@<&%P97(@;6%I;"X*"EEO=2!S:&]U;&0@86QS;R!G970@>6]U<B!E
M;7!L;WEE<B`H:68@>6]U('=O<FL@87,@82!P<F]G<F%M;65R*2!O<B!Y;W5R
M"G-C:&]O;"P@:68@86YY+"!T;R!S:6=N(&$@(F-O<'ER:6=H="!D:7-C;&%I
M;65R(B!F;W(@=&AE(&QI8G)A<GDL(&EF"FYE8V5S<V%R>2X@($AE<F4@:7,@
M82!S86UP;&4[(&%L=&5R('1H92!N86UE<SH*"B`@66]Y;V1Y;F4L($EN8RXL
M(&AE<F5B>2!D:7-C;&%I;7,@86QL(&-O<'ER:6=H="!I;G1E<F5S="!I;B!T
M:&4*("!L:6)R87)Y(&!&<F]B)R`H82!L:6)R87)Y(&9O<B!T=V5A:VEN9R!K
M;F]B<RD@=W)I='1E;B!B>2!*86UE<R!286YD;VT@2&%C:V5R+@H*("`\<VEG
M;F%T=7)E(&]F(%1Y($-O;VX^+"`Q($%P<FEL(#$Y.3`*("!4>2!#;V]N+"!0
M<F5S:61E;G0@;V8@5FEC90H*5&AA="=S(&%L;"!T:&5R92!I<R!T;R!I="$*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O4D5!1$U%
M````````````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-C<S,B`Q,#4Q-30S-#$S-2`P,3<S-30`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````5VAA="!I<R!(;W)D93\*/3T]
M/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D1&%T93H@,C`P-2\Q,"\Q
M."`Q,3HS,SHS-2`D"CI2979I<VEO;CH@("`@("`D4F5V:7-I;VXZ(#(N,3,N
M,3`N,2`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L:7-T<RYH;W)D92YO<F<*
M"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z
M.@H*5&AE($AO<F1E(%!R;VIE8W0@:7,@82!G<F]U<"!O9B!D979E;&]P97)S
M('=H;R!W<FET92!796(@87!P;&EC871I;VYS('5S:6YG"G1H92!(;W)D92!!
M<'!L:6-A=&EO;B!&<F%M97=O<FLL(&ET<V5L9B!A('!R;V1U8W0@;V8@=&AE
M(%!R;VIE8W0N"@I4:&4@2&]R9&4@07!P;&EC871I;VX@1G)A;65W;W)K(&ES
M('=R:71T96X@:6X@4$A0+"!A;F0@<')O=FED97,@=&AE(&-O;6UO;@IT;V]L
M<R!A(%=E8B!A<'!L:6-A=&EO;B!R97%U:7)E<SH@8VQA<W-E<R!F;W(@9&5A
M;&EN9R!W:71H('!R969E<F5N8V5S+`IC;VUP<F5S<VEO;BP@8G)O=W-E<B!D
M971E8W1I;VXL(&-O;FYE8W1I;VX@=')A8VMI;F<L($U)344L(&%N9"!M;W)E
M+@H*5&AE($AO<F1E($9R86UE=V]R:RP@8GD@:71S96QF+"!D;V5S(&YO="!P
M<F]V:61E(&%N>2!S:6=N:69I8V%N="!E;F0@=7-E<@IF=6YC=&EO;F%L:71Y
M.R!I="!P<F]V:61E<R!A(&)A<V4@9F]R(&]T:&5R(&%P<&QI8V%T:6]N<R!A
M;F0@=&]O;',@9F]R"F1E=F5L;W!E<G,N(%EO=2!W:6QL('!R;V)A8FQY('=A
M;G0@=&\@:6YS=&%L;"!S;VUE(&]F('1H92!A=F%I;&%B;&4@2&]R9&4*87!P
M;&EC871I;VYS+"!S=6-H(&%S($E-4"`H82!W96)M86EL(&-L:65N="DL(&]R
M($MR;VYO;&ET:"`H82!C86QE;F1A<BDN(%1H97)E"FES(&$@;&ES="!O9B!(
M;W)D92!A<'!L:6-A=&EO;G,@86YD('!R;VIE8W1S(&%T"FAT='`Z+R]W=W<N
M:&]R9&4N;W)G+W!R;VIE8W1S+G!H<"X*"E1H:7,@<V]F='=A<F4@:7,@3U-)
M($-E<G1I9FEE9"!/<&5N(%-O=7)C92!3;V9T=V%R92X@($]322!#97)T:69I
M960@:7,@80IC97)T:69I8V%T:6]N(&UA<FL@;V8@=&AE(&!/<&5N(%-O=7)C
M92!);FET:6%T:79E8%\N"@HN+B!?8$]P96X@4V]U<F-E($EN:71I871I=F5@
M.B!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+PH*"D]B=&%I;FEN9R!(;W)D
M90HM+2TM+2TM+2TM+2TM+2T*"D9U<G1H97(@:6YF;W)M871I;VX@;VX@2&]R
M9&4@86YD('1H92!L871E<W0@=F5R<VEO;B!C86X@8F4@;V)T86EN960@870*
M"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R9&4O"@I);F9O<FUA=&EO;B!O
M;B!A<'!L:6-A=&EO;G,@=&AA="!U<V4@=&AE($AO<F1E(&9R86UE=V]R:R!C
M86X@8F4@9F]U;F0@870*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O<')O:F5C
M=',N<&AP"@H*1&]C=6UE;G1A=&EO;@HM+2TM+2TM+2TM+2TM"@I4:&4@9F]L
M;&]W:6YG(&1O8W5M96YT871I;VX@:7,@879A:6QA8FQE(&EN('1H92!(;W)D
M92!D:7-T<FEB=71I;VXZ"@HZ4D5!1$U%7SH@("`@("`@("`@("`@("`@("`@
M5&AI<R!F:6QE"CI#3U!924Y'7SH@("`@("`@("`@("`@("`@("!#;W!Y<FEG
M:'0@86YD(&QI8V5N<V4@:6YF;W)M871I;VX*.F!D;V-S+T-(04Y'15-@7SH@
M("`@("`@("`@($-H86YG97,@8GD@<F5L96%S90HZ8&1O8W,O0T]$24Y'7U-4
M04Y$05)$4V!?.B`@0V]D:6YG('-T86YD87)D<R!F;W(@2&]R9&4@<')O:F5C
M=',*.F!D;V-S+T-/3E1224)55$E.1V!?.B`@("`@($AO=R!T;R!C;VYT<FEB
M=71E('1O($AO<F1E"CI@9&]C<R]#4D5$25138%\Z("`@("`@("`@("!0<F]J
M96-T(&1E=F5L;W!E<G,*.F!D;V-S+TA!0TM)3D=@7SH@("`@("`@("`@($AO
M=R!T;R!G970@2&]R9&4@=FEA($-64PHZ8&1O8W,O24Y35$%,3&!?.B`@("`@
M("`@("`@26YS=&%L;&%T:6]N(&EN<W1R=6-T:6]N<R!A;F0@;F]T97,*.F!D
M;V-S+U!%4D9/4DU!3D-%8%\Z("`@("`@(%!E<F9O<FUA;F-E(&=U:61E"CI@
M9&]C<R]214Q%05-%8%\Z("`@("`@("`@("!296QE87-E('!R;V-E<W,@;F]T
M97,*.F!D;V-S+U-%0U5225198%\Z("`@("`@("`@(%-E8W5R:71Y(&YO=&5S
M"CI@9&]C<R]43T1/8%\Z("`@("`@("`@("`@("!$979E;&]P;65N="!43T1/
M(&QI<W0*.F!D;V-S+U501U)!1$E.1V!?.B`@("`@("`@(%!O:6YT97)S(&]N
M('5P9W)A9&EN9R!F<F]M('!R979I;W5S($AO<F1E('9E<G-I;VYS"@H*26YS
M=&%L;&%T:6]N"BTM+2TM+2TM+2TM+0H*26YS=')U8W1I;VYS(&9O<B!I;G-T
M86QL:6YG($AO<F1E(&-A;B!B92!F;W5N9"!I;B!T:&4@9FEL92!)3E-404Q,
M7R!I;B!T:&4*8&!D;V-S+V!@(&1I<F5C=&]R>2!O9B!T:&4@2&]R9&4@9&ES
M=')I8G5T:6]N+@H*"D%S<VES=&%N8V4*+2TM+2TM+2TM+0H*268@>6]U(&5N
M8V]U;G1E<B!P<F]B;&5M<R!W:71H($AO<F1E+"!H96QP(&ES(&%V86EL86)L
M92$@"@I4:&4@2&]R9&4@1G)E<75E;G1L>2!!<VME9"!1=65S=&EO;G,@3&ES
M="`H1D%1*2P@879A:6QA8FQE(&]N('1H92!796(@870*(`H@(&AT='`Z+R]W
M=W<N:&]R9&4N;W)G+V9A<2\*"E1H92!(;W)D92!0<F]J96-T(')U;G,@82!N
M=6UB97(@;V8@;6%I;&EN9R!L:7-T<RP@9F]R(&EN9&EV:61U86P@87!P;&EC
M871I;VYS"F%N9"!F;W(@:7-S=65S(')E;&%T:6YG('1O('1H92!P<F]J96-T
M(&%S(&$@=VAO;&4N("!);F9O<FUA=&EO;BP@87)C:&EV97,L(&%N9`IS=6)S
M8W)I<'1I;VX@:6YF;W)M871I;VX@8V%N(&)E(&9O=6YD(&%T"@H@(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VUA:6PO"@I,87-T;'DL($AO<F1E(&1E=F5L;W!E
M<G,L(&-O;G1R:6)U=&]R<R!A;F0@=7-E<G,@86QS;R!M86ME(&]C8V%S:6]N
M86P*87!P96%R86YC97,@;VX@25)#+"!O;B!T:&4@8VAA;FYE;"`C:&]R9&4@
M;VX@=&AE(&9R965N;V1E($YE='=O<FL**&ER8RYF<F5E;F]D92YN970I+@H*
M"DQI8V5N<VEN9PHM+2TM+2TM+2T*"D9O<B!L:6-E;G-I;F<@86YD(&-O<'ER
M:6=H="!I;F9O<FUA=&EO;BP@<&QE87-E('-E92!T:&4@9FEL92!#3U!924Y'
M7R!I;B!T:&4*2&]R9&4@9&ES=')I8G5T:6]N+@H*5&AA;FMS+`H*5&AE($AO
M<F1E('1E86T*"@HN+B!?4D5!1$U%.B`_9CU214%$344N:'1M;`HN+B!?0T]0
M64E.1SH@:'1T<#HO+W=W=RYH;W)D92YO<F<O;&EC96YS97,O;&=P;"YP:'`*
M+BX@7V1O8W,O0TA!3D=%4SH@/V8]0TA!3D=%4RYH=&UL"BXN(%]D;V-S+T-/
M1$E.1U]35$%.1$%21%,Z(#]F/4-/1$E.1U]35$%.1$%21%,N:'1M;`HN+B!?
M9&]C<R]#3TY44DE"551)3D<Z(#]F/4-/3E1224)55$E.1RYH=&UL"BXN(%]D
M;V-S+T-2141)5%,Z(#]F/4-2141)5%,N:'1M;`HN+B!?9&]C<R](04-+24Y'
M.B`_9CU(04-+24Y'+FAT;6P*+BX@7TE.4U1!3$PZ"BXN(%]D;V-S+TE.4U1!
M3$PZ(#]F/4E.4U1!3$PN:'1M;`HN+B!?9&]C<R]015)&3U)-04Y#13H@/V8]
M4$521D]234%.0T4N:'1M;`HN+B!?9&]C<R]214Q%05-%.B`_9CU214Q%05-%
M+FAT;6P*+BX@7V1O8W,O4T5#55))5%DZ(#]F/5-%0U522519+FAT;6P*+BX@
M7V1O8W,O5$]$3SH@/V8]5$]$3RYH=&UL"BXN(%]D;V-S+U501U)!1$E.1SH@
M/V8]55!'4D%$24Y'+FAT;6P*````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D;V-S+T-(04Y'
M15,`````````````````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`R,C4W-S,@,3`U,34T,S0Q,S4@,#$W-#<W`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM+2TM+0IV,RXQ+C,*+2TM
M+2TM"@I;8VIH72!314-54DE463H@5F%L:61A=&4@1T54+6)A<V5D(%523"!P
M87)A;65T97)S('!R;W9I9&5D('1O($AO<F1E)W,*("`@("`@:6YD97@N<&AP
M+@I;:F%N72!3=7!P;W)T(&EM<&]R=&EN9R!O9B!C;VUB:6YE9"!D871E+W1I
M;64@9FEE;&1S("A"=6<@(S,Q,38I+@I;:F%N72!,;V<@82!W87)N:6YG(&EF
M('5S:6YG('-E='1I;F=S('1H870@8G)E86L@<V5S<VEO;G,N"EMJ86Y=($9I
M>"!P87)S92!E<G)O<B!T:&%T(&)R;VME(%-Y;F--3"!S>6YC:')O;FEZ871I
M;VX@*$)U9R`C-#$V."DN"EMJ86Y=(%-U<'!O<G0@2V]L86(@9W)O=7`@04-,
M<R`H8W-A8V-A0'1H96-S;"YO<F<L(%)E<75E<W0@(S(R-S`I+@I;:F%N72!&
M:7@@=6YS97)I86QI>F4H*2!E<G)O<G,@:6X@<V5S<VEO;B!V:65W97(@*$)U
M9R`C,S4X-BDN"@H*+2TM+2TM"G8S+C$N,@HM+2TM+2T*"EMC:FA=(%-%0U52
M2519.B!296UO=F4@=6YU<V5D(&EM86=E('!R;WAY(&-O9&4@9G)O;2!D97)E
M9F5R<F5R+@I;8VIH72!314-54DE463H@0VQO<V4@6%-3('!R;V)L96US(&EN
M(&1E<F5F97)R97(@*$E%(&]N;'DI+"!H96QP('9I97=E<B!A;F0*("`@("`@
M<')O8FQE;2!R97!O<G1I;F<@<V-R965N+@I;8VIH72!(86YD;&4@97)R;W)S
M(&=E;F5R871E9"!D=7)I;F<@6$U,+5)00R!C86QL<R!P<F]P97)L>0H@("`@
M("`H0F5N($ML86YG(#QB96Y`86QK86QO:60N;F5T/BP@0G5G(",T,#DW*2X*
M6VIA;ET@061D(&%D9&ET:6]N86P@:6YD97AE<R!T;R!P<F5F97)E;F-E('1A
M8FQE("AJ+F)E;F]I=$!F<F5E+F9R+"!"=6<@(S0P-SDI+@I;:F%N72!&:7@@
M<')E9F5R96YC92!C86-H92`H0G5G(",T,#<Y*2X*6VIA;ET@061D(&-O;F9I
M9W5R871I;VX@;W!T:6]N('1O(&1I<V%B;&4@1T54+6)A<V5D('-E<W-I;VYS
M+@I;:F%N72!&:7@@<')E9F5R96YC97,@86-C97-S(&9O<B!S<&5C:6%L($MO
M;&%B('5S97)S("AW<F]B96Q`9V5N=&]O+F]R9RP*("`@("`@0G5G(",T,#0Y
M*2X*6VUM<UT@1FEX('-E='1I;F<@9&5F875L="!C:&%R<V5T(&9O<B!N;VXM
M34E-12!M97-S86=E<R`H0G5G(",S.#`T*2X*6VIA;ET@061D('-E=F5R86P@
M;65T:&]D<R!T;R!M86YI<'5L871E(&=R;W5P<R!A;F0@<VAA<F5S('1O($AO
M<F1E)W,@05!)+@I;:F%N72!2971U<FX@<V5R:6%L:7IE9"!02%`@=F%L=65S
M('1H<F]U9V@@=&AE(%)%4U0@:6YT97)F86-E(&EF('!A<W-I;F<@80H@("`@
M("!R97-T0V]N=&5N=%1Y<&4@<&%R86UE=&5R(&]F("=A<'!L:6-A=&EO;B]X
M+6AT='!D+7!H<"<N"EMC:FA=($]N;'D@86QL;W<@=7-E<G,@=&\@87-S:6=N
M(%-H87)E('!E<FUI<W-I;VYS(&9O<B!G<F]U<',@=&AE>2!A<F4*("`@("`@
M;65M8F5R<R!O9BX*6VIA;ET@06QL;W<@=&\@9&ES86)L92!61E,@8F%C:V5N
M9',@:6X@=&AE(&%P<&QI8V%T:6]N<R<@8V]N9FEG=7)A=&EO;G,N"EMM;7-=
M(%5P9&%T92!T:&4@34E-12!#;VYT96YT+51Y<&4@8VAA<G-E="!P87)A;65T
M97(@:6X@82!-24U%(&UE<W-A9V4@=VAE;B!W90H@("`@("!C;VYV97)T('1H
M92!C;VYT96YT<R!F;W(@=FEE=VEN9R!I;B!T:&4@8G)O=W-E<B`H0G5G(",S
M-S(Y*2X*6V-J:%T@1FEX($AO<F1E7T9O<FU?5'EP95]A<W-I9VX@:F%V87-C
M<FEP="`H0G5G(",S-S0P*2X*6VIA;ET@061D('5P9W)A9&4@<V-R:7!T<R!F
M;W(@3W)A8VQE+@I;8VIH72!);F-L=61E(%!!5$A?24Y&3R!W:&5N979E<B!1
M545265]35%))3D<@:7,@<F5Q=65S=&5D(&EN($AO<F1E.CIS96QF57)L*"D*
M("`@("`@*$)U9R`C,S<P,RDN"EMJ86Y=($%D9"!G96YE<FEC(%-13"!U<&=R
M861E('-C<FEP="`H1&%N:65L($$N(%)A;6%L97D*("`@("`@/&1A;FEE;"YR
M86UA;&5Y0&1R86ME+F5D=3XI+@H*"BTM+2TM+0IV,RXQ+C$*+2TM+2TM"@I;
M8VIH72!314-54DE463H@1FEX(')E;6]T92!C;V1E(&5X96-U=&EO;B!V=6QN
M97)A8FEL:71Y(&9O=6YD(&)Y($IA;B!38VAN96ED97(N"EMC:FA=($9I>"!E
M>'!O<G0@86YD('-Y;F-H<F]N:7IA=&EO;B!O9B!E=F5N=',@86-R;W-S(&1A
M>6QI9VAT('-A=FEN9R!T:6UE"B`@("`@(&-H86YG97,N"EMJ86Y=($%D9"!P
M<F]P97(@;&]C:VEN9R!T;R!M>7-Q;"!S97-S:6]N(&AA;F1L97(@*$)U9R`C
M,S8V,"DN"EMC:FA=(&EE+F-S<R!I<R!N;W0@;F5C97-S87)Y(&9O<B!)13<L
M('-O(')E;F%M92!A<'!R;W!R:6%T96QY("A"=6<@(S,V-S$I+@I;:F%N72!&
M:7@@<75O=&$@<W5P<&]R="!F;W(@<V]M92!61E,@9')I=F5R<R`H0G5G(",S
M-C0W*2X*6V-J:%T@0F5T=&5R($]P97)A($UI;FD@9&5T96-T:6]N("A"=6<@
M(S(Y-C$I+@I;:F%N72!&:7@@;65N=2!W<F%P<&EN9R!W:71H($MO;&%B(&%N
M9"!0=7)P;&4@=&AE;64@*$)U9R`C,S4Y-"DN"@H*+2TM+0IV,RXQ"BTM+2T*
M"EMC:FA=(%)E;6]V92!B;V=U<R!#;VYT96YT+4QO8V%T:6]N(&AE861E<B!I
M;B!T:&4@5TU,($UO8FEL92!R96YD97)E<@H@("`@("`H0G5G(",S-#<V*2X*
M6VIA;ET@061D(&]P=&EO;B!T;R!B;&]C:R!+;VQA8B!A=71H96YT:6-A=&EO
M;B!A9G1E<B!F86EL960@;&]G:6YS"B`@("`@("AT;VMO94!K9&4N;W)G+"!2
M97%U97-T(",S-#<T*2X*6VIA;ET@06QL;W<@=&\@<V5T(&AE:6=H="!O9B!I
M9G)A;64@<&]R=&%L(&)L;V-K("AT979A;G-`=&%C:&]M971R>2YC;VTL"B`@
M("`@(%)E<75E<W0@(S,U,#0I+@I;8VIH72!5<&1A=&4@5&]O;%1I<',@2F%V
M85-C<FEP="!O8FIE8W0@=&\@86QL;W<@=&]O;'1I<',@;VX@;F]N+3QA/B!E
M;&5M96YT<RX*6VUM<UT@4V]R="!A;B!)34%07U1R964@;V)J96-T(&)Y(&1I
M<W!L87D@;F%M92P@;F]T(&9U;&P@;6%I;&)O>"!N86UE+@I;;6%S72!-86ME
M('-U<F4@9&%T86)A<V4@<&]R=&%B:6QI='D@;W!T:6]N<R!A<F4@87!P;&EE
M9"!I;B!(:7-T;W)Y(&UO9'5L92X*("`@("`@*$)U9R`C,S0X,BD*"@HM+2TM
M+2TM+0IV,RXQ+5)#,PHM+2TM+2TM+0H*6VIA;ET@36%K92!S=7)E('1H870@
M2V]L86(@=7-E<G,@86QW87ES(&AA=F4@=&AE('-A;64@=7-E<B!N86UE("A"
M=6<@(S$S,3<I+@I;:F%N72!&:7@@;6]V:6YG(&]B:F5C=',@=VET:"!+;VQA
M8B!D<FEV97)S("AT;VMO94!K9&4N;W)G+"!"=6<@(S(X,3$I+@I;:F%N72!!
M9&0@<F5S970@8G5T=&]N('1O(&EM86=E(&9O<FT@9FEE;&1S+@I;:F%N72!&
M:7@@<V5L96-T:6]N(&]F(&1E9F%U;'0@:61E;G1I='D@*$)U9R`C,S0Q-BDN
M"EMM87-=($%D9"!(96)R97<@=')A;G-L871I;VXN"EMM87-=($%D9"!S=7!P
M;W)T(&9O<B!21D,@-#,Q-"US='EL92!)34%0($%#3',N"EMM;7-=($-O<G)E
M8W1L>2!E;F-O9&4@-RUB:70@34E-12!M97-S86=E<R!W:71H($Y53$P@8VAA
M<F%C=&5R<R`H0G5G(",S,SDU*2X*6VIA;ET@2&ED92!A<'!L:6-A=&EO;G,@
M=VET:"!S=&%T=7,@)VYO=&]O;&)A<B<@9G)O;2!O<'1I;VYS(&UE;G4@*$)U
M9R`C,S,X,RDN"@H*+2TM+2TM+2T*=C,N,2U20S(*+2TM+2TM+2T*"EMJ86Y=
M($%D9"!+:&UE<B!T<F%N<VQA=&EO;B`H3&5A;F<@0VAU;7-O8F5N(#QS;V)E
M;D!K:&UE<F]S+FEN9F\^*2X*6VUM<UT@2&%N9&QE('%U;W1E9"!T97AT('=H
M96X@<&%R<VEN9R!-1$X@<F5Q=65S=',@*$)U9R`C,S,T,"DN"EMB96Y=($)E
M='1E<B!S=7!P;W)T(&9O<B!-4RU344PN"EMJ86Y=(%-H;W<@8V]R<F5C="!A
M9&1R97-S(&EN(&QA<W0M;&]G:6X@;65S<V%G92!I9B!C;VYN96-T:6YG('1H
M<F]U9V@@82!P<F]X>0H@("`@("`H0G5G(",S,C@X*2X*6VUM<UT@06QL;W<@
M861M:6X@=&\@9&ES86)L92!B<F]W<V5R('-T<FEN9R!C:&5C:W,@*$)U9R`C
M,S(X,BDN"EMJ86Y=($-O<G)E8W1L>2!E;F-O9&4@96UA:6P@9W)O=7`@;F%M
M97,@*$)U9R`C,S(S-"DN"EMC:FA=($%D9"!A(&1I<W!L87D@;65T:&]D(&9O
M<B!H;W5R36EN=71E4V5C;VYD(&9O<FT@9FEE;&1S("A"=6<@(S,Q-C4I+@I;
M8VIH72!(;W)D92=S('!R969E<F5N8V5S(&YO=R!A<F4@<F5F97)R960@=&\@
M87,@1VQO8F%L($]P=&EO;G,@<V\@=&AE('5S97(*("`@("`@9&]E<VXG="!N
M965D('1O(&MN;W<@=VAA="!(;W)D92!I<RP@86YD(&%L=V%Y<R!A<'!E87(@
M870@=&AE('1O<"!O9@H@("`@("!L:7-T<R!O9B!A<'!S(&9O<B!W:&EC:"!P
M<F5F97)E;F-E<R!A<F4@879A:6QA8FQE+@I;:F%N72!!9&0@=7!G<F%D92!I
M;G-T<G5C=&EO;G,@*$ME=FEN($UY97(@:V5V:6Y?;7EE<D!I=3$S+F]R9RP@
M0G5G(",S,C(R*2X*6V-J:%T@07!P;&EC871I;VYS('=H:6-H(&1O(&YO="!H
M879E(&$@8V]N9FEG+W!R969S+G!H<"!F:6QE(&YO(&QO;F=E<@H@("`@("!A
M<'!E87(@:6X@;&ES=',@;V8@87!P;&EC871I;VYS('1O('-E="!O<'1I;VYS
M(&9O<B!T;R!A=F]I9"!C;VYF=7-I;VXN"@H*+2TM+2TM+2T*=C,N,2U20S$*
M+2TM+2TM+2T*"EMC:FA=($UA:V4@=&AE(&QO8VL@9&ER96-T;W)Y(&9O<B!T
M:&4@;65M8V%C:&5D(%-E<W-I;VY(86YD;&5R(&-O;F9I9W5R86)L90H@("`@
M("`H0G5G(",S,3(P*2X*6VUM<UT@57!D871E(%1E>'1?1FQO=V5D.CH@=&\@
M<W5P<&]R="!21D,@,S8W-BX*6V-J:%T@1FEX(&]U='!U="!E<V-A<&EN9R!O
M9B!(;W)D95]&;W)M7U1Y<&5?8V5L;'!H;VYE(&EN(%5)7U9A<E)E;F1E<F5R
M7VAT;6PN"EMC:FA=($%L;&]W(&-H;V]S:6YG(%M.;VYE72!A<R!A(&1A=&%B
M87-E(&9O<B`D8V]N9ELG<W%L)UT@*$)U9R`C,C<U-"DN"EMJ86Y=($%D9"!)
M8V5L86YD:6,@=')A;G-L871I;VX@*$)J;W)N($1A=FED<W-O;B`\8FIO<W-I
M0'-N97)P82YI<SXI+@I;;6US72!7;W)K(&%R;W5N9"!B<F]K96X@:6UA<%\X
M8FET*"D@:6UP;&5M96YT871I;VX@:6X*("`@("`@34E-13HZ<75O=&5D4')I
M;G1A8FQE16YC;V1E("A"=6<@(S(Y-S4I+@I;;6US72!!9&0@9V%R8F%G92!C
M;VQL96-T:6]N('1O($AO<F1E7T-A8VAE+@I;8VIH72!&:7@@1W)O=7`Z.FQI
M<W1!;&Q5<V5R<R`H0V%R;&]S(%!E9')I;F%C:2P@0G5G(",R.3,W*2X*6VIA
M;ET@061D(&AI9V@@8V]N=')A<W0@=&AE;64@*'1M97)R:71T0&5M86EL+F%R
M:7IO;F$N961U+"!297%U97-T(",Q-3DX*2X*6VIA;ET@2V5E<',@<VED96)A
M<B!E>'!A;G-I;VX@<W1A=&4@86-R;W-S('-E<W-I;VYS("A297%U97-T(",Q
M-38T*2X*6VIA;ET@061D(&-O;F9I9W5R871I;VX@9F]R(&UA:6P@9&]M86EN
M('5S960@9F]R('!R;V)L96T@<F5P;W)T<PH@("`@("`H9'5S=&EN0'EW;&-S
M+F]R9RP@4F5Q=65S="`C,3,W-BDN"EMC:FA=($%D9"!D>6YA;6EC('1A8FQE
M(')E+7-O<G1I;F<@=&AR;W5G:"!J879A<V-R:7!T+@I;8VIH72!);G-P96-T
M(&UE=&AO9"!S:6=N871U<F5S('-O('1H870@=&AE(%)%4U0@9')I=F5R(&ES
M;B=T(&1E<&5N9&5N="!O;@H@("`@("!T:&4@;W)D97(@;V8@1T54('!A<F%M
M971E<G,N"EMC:FA=($%D9"!H;W)D92]G9710<F5F97)E;F-E(&%N9"!H;W)D
M92]S9710<F5F97)E;F-E($%022!M971H;V1S+@I;8VIH72!!9&0@82!L:7-T
M(&]F(&%C=&EV92!U<V5R<R!A;F0@86-T:79E('-E<W-I;VYS('1O('1H92!A
M9&UI;B!A<F5A+@I;8VIH72!!9&0@=6YO8G1R=7-I=F4@:F%V87-C<FEP="!T
M;V]L=&EP<R!B87-E9"!O;B!T:&4@=&ET;&4@871T<FEB=71E+@I;:F%N72!-
M;W9E('-I9&5B87(@8V]L;&%P<V4O97AP86YD(&)U='1O;B!B96QO=R!T:&4@
M;65N=2!B87(@*$]L:79E<B!+=6AL"B`@("`@(#QO:W5H;$!N971C;VQO9VYE
M+F1E/BDN"EMJ86Y=($%D9"!)9&5A<R!T:&5M92`H4F]E;"!';&]U9&5M86YS
M(#QR;V5L0&=L;W5D96UA;G,N:6YF;SXI+@I;8VIH72!-;W9E($AO<F1E7TAI
M<W1O<GD@9&%T82!T;R!I=',@;W=N(%-13"!T86)L92`H0G5G(",R,CDX*2X*
M6VIA;ET@061D($AO<F1E7T9O<FU?='EP95]F:6=L970@9F]R($-!4%1#2$$@
M9FEE;&1S('=I=&@@9FEG;&5T(&9O;G1S+@I;:F%N72!!9&0@2&]R9&5?1F]R
M;5]4>7!E7V1B;&]O:W5P(&9O<B!F;W)M(&9I96QD<R!W:71H(&1A=&%B87-E
M(&QO;VMU<',*("`@("`@*%)E<75E<W0@(S,R,BDN"EMJ86Y=($%D9"!C;VYF
M:6=U<F%T:6]N('1O(&1I<V%B;&4@(D%B;W5T(B!L:6YK<R!I;B!H96QP('=I
M;F1O=W,@*")-871T:&5W"B`@("`@($TN($=A;6)L92(@/&AO<F1E+61E=D!M
M9V%M8FQE+F-A/BDN"EMC:FA=($%L;&]W('-E;F1I;F<@<')O8FQE;2!R97!O
M<G1S('1O(&$@=&EC:V5T('-Y<W1E;2!U<VEN9R!T:&4*("`@("`@=&EC:V5T
M<R]A9&14:6-K970@05!)(&-A;&P@*$)U9R`C,3DQ-RDN"EMC:FA=($1E9FEN
M92!25$P@<W1Y;&5S('9I82!A;B!A9&1I=&EO;F%L('-T>6QE<VAE970N"EMC
M:FA=(%5S86)I;&ET>2!I;7!R;W9E;65N=',@=&\@=&AE(&ED96YT:71I97,@
M;6%N86=E;65N="!P86=E("A"=6<@(S$X-#8I+@I;8F5N72!!9&0@3$1!4"!S
M=7!P;W)T('1O($=R;W5P('!A8VMA9V4N"EMC:FA=($%D9"!334(@9')I=F5R
M('1O(%9&4R!P86-K86=E+@I;8VIH72!!;&QO=R!C<F5A=&EO;B!O9B!E>'!I
M<FEN9R!A8V-O=6YT<R!I;B!,1$%0"B`@("`@("A2;V5L($=L;W5D96UA;G,@
M/')O96Q`9VQO=61E;6%N<RYI;F9O/BDN"EMC:FA=($%D9"!C;VYF:6=U<F%T
M:6]N(&]P=&EO;B!T;R!S96%R8V@@9F]R('1H92!U<V5R)W,@1$X@:6X@=&AE
M(%!R969S7VQD87`*("`@("`@9')I=F5R("A"=6<@(S$W.#8I+@I;:F%N72!!
M;&QO=R!T;R!S<&5C:69Y('1H92!O8FIE8W1C;&%S<R!F;W(@;F5W('5S97)S
M(&%D9&5D('1H<F]U9V@@3$1!4`H@("`@("`H4F]E;"!';&]U9&5M86YS(#QR
M;V5L0&=L;W5D96UA;G,N:6YF;SXI+@I;:F%N72!!9&0@<&%S<W=O<F0@97AP
M:7)A=&EO;B!A;F0@<&%S<W=O<F0@96YC<GEP=&EO;B!T;R!,1$%0(&%U=&AE
M;G1I8V%T:6]N"B`@("`@(&1R:79E<B`H4F]E;"!';&]U9&5M86YS(#QR;V5L
M0&=L;W5D96UA;G,N:6YF;SXI+@I;:F%N72!!9&0@<&5R;6ES<VEO;G,@=&\@
M<F5S=')I8W0@;G5M8F5R(&]F('!O<G1A;"!B;&]C:W,N"EMJ86Y=($%D9"!C
M;VYF:6=U<F%T:6]N(&9O<B!F:7AE9"!P;W)T86P@8FQO8VMS+@I;:FUF72!!
M9&0@875D:6\@;F]T:69I8V%T:6]N(&QI<W1E;F5R+"!M86ME('!O<G1A;"!H
M86YD;&4@875D:6\@;F]T:69I8V%T:6]N<PH@("`@("!B>2!B;&]C:W,@*&4N
M9RX@=&AE($E-4"!F;VQD97(@<W5M;6%R>2DN"EMM;7-=($-A8VAE(&-E<G1A
M:6X@<F5G:7-T<GD@9&%T82!T;R!P<F5V96YT('5N;F5E9&5D(&9I;&4@;&]A
M9&EN9R]P87)S:6YG"B`@("`@(&%F=&5R('1H92!I;FET:6%L(&QO9VEN+@I;
M;6%S72!!9&0@<W5P<&]R="!F;W(@8V]U;G1I;F<@875T:&5N=&EC871E9"!S
M97-S:6]N<R!V:6$@4V5S<VEO;DAA;F1L97)S+@I;8VIH72!292UW;W)K(%1A
M8G,@<V\@=&AA="!B86-K9W)O=6YD(&EM86=E<R!C86X@8F4@=7-E9"!I;B!C
M<F5A=&EV92!W87ES+@I;:F%N72!!9&0@(DUY($%C8V]U;G0@26YF;W)M871I
M;VXB(&)L;V-K('1H870@;6EM:6-S('1H92!!8V-O=6YT<R!M;V1U;&4N"EMJ
M86Y=($EM<')O=F4@<F5N9&5R:6YG(&9O<B!R:6=H="UT;RUL969T(&QA;F=U
M86=E<R`H06UI<FMA8FER($UE=&%.150@3'1D+BDN"EMJ86Y=($%D9"!S=7!P
M;W)T(&9O<B!A<F)I=')A<GDL(&YO;BUB;V]L96%N('!E<FUI<W-I;VX@=F%L
M=65S+@I;8F5N72!!9&0@86QT97)N871E7VQO9VEN(&%N9"!R961I<F5C=%]O
M;E]L;V=O=70@9F5A='5R97,N"EMJ86Y=($%D9"!G96YE<FEC(%--5%`@9')I
M=F5R('1O($YE=%]335,@<&%C:V%G92`H26%N($5U<F4@/&EE=7)E0'!H<"YN
M970^*2X*6VUJ<ET@3F5T7TE-4U`@=VEL;"!N;W<@875T;VUA=&EC86QL>2!C
M<F5A=&4@=7-E<B=S(&1E9F%U;'0@861D<F5S<V)O;VL@:68*("`@("`@:70@
M9&]E<R!N;W0@86QR96%D>2!E>&ES="!I;G-T96%D(&]F(&IU<W0@8V]M<&QA
M:6YI;F<@86)O=70@:70N"EMC:FA=($%D9"!S96QE8W0@86QL+"!N;VYE+"!A
M;F0@:6YV97)T(&]P=&EO;F%L;'D@=&\@2&]R9&5?1F]R;5]4>7!E7W-E=`H@
M("`@("!F:65L9',@*$1U8VL@/&1U8VM`;V)A;&$N;F5T/BDN"EMC:FA=(%!R
M969E<F5N8V5S(&]V97)V:65W(&ES(&YO=R!B=6EL="!W:71H(&$@9&5F:6YI
M=&EO;B!L:7-T("@\9&P^*2!S='EL960*("`@("`@=VET:"!#4U,N"EMJ86Y=
M($%D9"!S;W)T*"D@;65T:&]D('1O($AO<F1E7U1R964@8VQA<W,N"EMM9&I=
M($-H86YG92!A;GD@;W5T<'5T(&]F(#QB/B!A;F0@/&D^('1A9W,@=&\@/'-T
M<F]N9SX@86YD(#QE;3X@9F]R(&)E='1E<@H@("`@("!A8V-E<W-I8FEL:71Y
M('-U<'!O<G0N"EMJ;69=($%L;&]W($AO<F1E('1E;7!L871E<R!T;R!I;F-L
M=61E(&%P<&QI8V%T:6]N(&)L;V-K<RX*6VIA;ET@061D(&5X=&5N9&5D(&9O
M<F5C87-T<R!T;R!W96%T:&5R9&]T8V]M($)L;V-K("A2:6-K($5M97)Y"B`@
M("`@(#QR:6-K0&5M97)Y+FAO;65L:6YU>"YN970^*2X*6V-J:%T@06QL;W<@
M9F]R(&%R8FET<F%R>2!A='1R:6)U=&4@9FEL=&5R<R!W:&5N(&QI<W1I;F<@
M;W(@8V]U;G1I;F<@4VAA<F4*("`@("`@;V)J96-T<R`H1'5C:R`\9'5C:T!O
M8F%L82YN970^*2X*6V-J:%T@061D($1A=&%4<F5E.CIG9713;W)T9614<F5E
M*"D@*$1U8VL@/&1U8VM`;V)A;&$N;F5T/BDN"EMM:G)=(%-U<'!O<G0@9F]R
M(&EM=&5S="!A=71H96YT:6-A=&EO;B!A9&1E9"!T;R!0<F5F<U]I;7-P+@I;
M8VIH72!!9&0@4D535"!24$,@9')I=F5R("AS<G)A9F%`=7-C+F5S+"!"=6<@
M(S$U,#`I+@I;8VIH72!!9&0@<W5P<&]R="!F;W(@9F5T8VAI;F<@=&AE(&AI
M9VAE<W0@86YD(&QO=V5S="!I9',@:6X@86YY($1A=&%4<F5E"B`@("`@(&=R
M;W5P("A$=6-K(#QD=6-K0&]B86QA+FYE=#XI+@I;8VIH72!!9&0@1&%T851R
M964Z.G-O<G1">4%T=')I8G5T97,H*2!F;W(@<V]R=&EN9R!$871A5')E94]B
M:F5C=',@8F%S960@;VX*("`@("`@=&AE:7(@871T<FEB=71E<R`H1'5C:R`\
M9'5C:T!O8F%L82YN970^*2X*6VUJ<ET@26YI=&EA;"!S=7!P;W)T(&%D9&5D
M('1O($YE=%])35-0(&9O<B!I;71E<W0@9')I=F5R("AP<F]V:61E<R!P97)S
M:7-T96YT"B`@("`@($E-4U`@8V]N;F5C=&EO;G,@=7-I;F<@0WER=7,@:6UT
M97-T('5T:6QI='DI+@I;:F%N72!!9&0@;6%P(&QI;FMS('1O(%5+(&%N9"!!
M=7-T<F%L:6%N(&%D9')E<W,@9FEE;&1S"B`@("`@("AT=7)B82YL:7-T0'-U
M8F]R8FET+F-O;2P@0G5G(",Q-#8Q*2X*6VUM<UT@1&5T96-T:6]N(&]F(")P
M:&ES:&EN9R(@=&%C=&EC<R!I;B!T:&4@2%1-3"!-24U%7U9I97=E<B`H5&]D
M9"!-97)R:71T"B`@("`@(#QT;65R<FET=$!E;6%I;"YA<FEZ;VYA+F5D=3XL
M($)U9R`C,30S-"DN"EMM;7-=(%1E>'1?1FQO=V5D('!A8VMA9V4@;F]W(&-O
M<G)E8W1L>2!H86YD;&5S(&UU;'1I8GET92!C:&%R86-T97)S+@I;;6US72!-
M86EN=&5N86YC92!C;VYF:7)M871I;VX@<&%G97,@;F]W(')E;F1E<F5D('9I
M82!(;W)D95]496UP;&%T92`H5FEL:75S"B`@("`@(%-U;7-K87,@/'9I;&EU
M<T!L;FLN;'0^*2X*6VIA;ET@06QL;W<@=&\@<W!E8VEF>2!C:&%R<V5T(&]F
M(&EM<&]R=&5D($-35B!F:6QE<RX*6VIA;ET@061D($9I;&5?0U-6('!A8VMA
M9V4N"EMJ86Y=(%-H;W<@87!P;&EC871I;VX@;F%M97,@:6X@<&5R;6ES<VEO
M;G,@861M:6YI<W1R871I;VXN"EMJ;69=($%L;&]W('1H92!A=71H(&)A8VME
M;F0@=&\@<F5Q=65S="!A('!A<W-W;W)D(&-H86YG92P@<W5P<&]R="!E>'!I
M<FEN9PH@("`@("!P87-S=V]R9"!I;B!T:&4@4U%,(&)A8VME;F0N"EMC:FA=
M(%-H;W<@;65N=2!C:&EL9')E;B!F;W(@979E<GD@87!P;&EC871I;VX@=VET
M:"!P<F5F97)E;F-E<R!U;F1E<B!/<'1I;VYS"B`@("`@(&EN('1H92!S:61E
M8F%R(&UE;G4@*$)U9R`C,3`U."DN"EMM;7-=($%L;&]W(&EN9&EV:61U86P@
M34E-15]6:65W97)S('1O(&]V97)R:61E('1H92!#;VYT96YT+41I<W!O<VET
M:6]N($U)344*("`@("`@<&%R86UE=&5R(&%N9"!F;W)C92!V:65W:6YG(&EN
M;&EN92X*"@HM+2TM+2TM"G8S+C`N,3$*+2TM+2TM+0H*6V-J:%T@4T5#55))
M5%DZ(%)E;6]V92!U;G5S960@:6UA9V4@<')O>'D@8V]D92!F<F]M(&1E<F5F
M97)R97(N"EMC:FA=(%-%0U522519.B!#;&]S92!84U,@<')O8FQE;7,@:6X@
M9&5R969E<G)E<B`H244@;VYL>2DL(&AE;'`@=FEE=V5R(&%N9`H@("`@("!P
M<F]B;&5M(')E<&]R=&EN9R!S8W)E96XN"@H*+2TM+2TM+0IV,RXP+C$P"BTM
M+2TM+2T*"EMC:FA=(%-%0U522519.B!&:7@@<F5M;W1E(&-O9&4@97AE8W5T
M:6]N('9U;&YE<F%B:6QI='D@9F]U;F0@8GD@2F%N(%-C:&YE:61E<BX*"@HM
M+2TM+2T*=C,N,"XY"BTM+2TM+0H*6V-J:%T@1FEX('-H;W=S=&]P<&5R(&)U
M9R!I;B!(;W)D95]&;W)M('-E;&5C="!F:65L9',@*$)U9R`C,S$R,RDN"@H*
M+2TM+2TM"G8S+C`N.`HM+2TM+2T*"EMC:FA=(%=H96X@9&5L971I;F<@86X@
M:61E;G1I='DL(&1O;B=T('-H;W<@=&AE(&1E;&5T960@:61E;G1I='D*("`@
M("`@:6X@=&AE(&1E9F%U;'0@:61E;G1I='D@<V5L96-T(&1R;W!D;W=N(&]N
M('1H92!N97AT('!A9V4@;&]A9"X*6V-J:%T@1FEX(&5S8V%P:6YG(&]F(&1A
M=&$@:6X@=&AE('!R969E<F5N8V5S('1E;7!L871E<RX*6V-J:%T@1FEX(&5S
M8V%P:6YG(&]F(&1A=&$@:6X@=&AE(&1A=&$@:6UP;W)T('1E;7!L871E<RX*
M6V-J:%T@1FEX(&]U='!U="!E<V-A<&EN9R!O9B!(;W)D95]&;W)M7U1Y<&5?
M8V5L;'!H;VYE(&EN(%5)7U9A<E)E;F1E<F5R7VAT;6PN"EMC:FA=(%-%0U52
M2519.B!#;&]S92!S979E<F%L(%A34R!P<F]B;&5M<R!I;B!T:&4@<VAA<F4@
M961I="!W:6YD;W<N"EMJ86Y=($9I>"!W96%T:&5R+F-O;2!P;W)T86P@8FQO
M8VLN"@H*+2TM+2TM"G8S+C`N-PHM+2TM+2T*"EMJ86Y=(%-%0U522519.B!&
M:7@@6%-3('9U;&YE<F%B:6QI=&EE<R!I;B!G>FEP+W1A<B!A;F0@8W-S($U)
M344@=FEE=V5R<RX*6V-J:%T@061D(&UI<W-I;F<@0T]-34E4(&EN($UY4U%,
M(%-E<W-I;VY(86YD;&5R(&1R:79E<@H@("`@("`H9&=E:&Q`:6YV97)S92YC
M82P@0G5G(",R-S,Q*2X*"@HM+2TM+2T*=C,N,"XV"BTM+2TM+0H*6VIA;ET@
M4&%S<R!A;&P@55),('!A<F%M971E<G,@=VAE<F4@;&EN:VEN9R!E;6%I;"!A
M9&1R97-S97,@*%)E<75E<W0@(S$U,S`I+@I;:F%N72!3:&]W(%=O<F0@=FEE
M=V5R(&-O;G1E;G0@=VET:"!C;W)R96-T(&-H87)S970@*'-G<F]N9&EN0&-S
M8F8N<6,N8V$L"B`@("`@($)U9R`C,C<S-RDN"@H*+2TM+2TM+2TM+0IV,RXP
M+C8M4D,Q"BTM+2TM+2TM+2T*"EMC:FA=($9I>"!T<F%N<V%C=&EO;G,@86YD
M(&)I;F%R>2!D871A(&EN(%!O<W1G<F5344P@<V5S<VEO;B!H86YD;&5R"B`@
M("`@("AC8G-`8W1S+G5C;&$N961U+"!"=6<@(S(W-#DL(",R-S@Y*2X*6VIA
M;ET@1FEX('-I9&5B87(@;65N=2!L87EO=70@9F]R($]P97)A("A"=6<@(S(W
M,C(I+@I;8VIH72!!9&0@/'!R93X@=&\@<W5P<&]R=&5D(&AE;'`@=&%G<R`H
M=FEJ87DN;6%H<G)A0&5S+F5A<WEN970N;F5T+`H@("`@("!"=6<@(S(V,S,I
M+@I;8VIH72!&:7@@=F%L:61A=&EO;B!O;B!I<&%D9')E<W,@2&]R9&5?1F]R
M;2!F:65L9',@*$)U9R`C,C4X,RDN"EMC:FA=($%D9"!!=71H.CIG971!=71H
M1&]M86EN*"D@*$)U9R`C,C4W,RDN"EMM:G)=($%D9"!A8FEL:71Y('1O(&5N
M86)L92]D:7-A8FQE($E-4U`@9VQO8F%L;'D@=FEA(&-O;F9I9W5R871I;VX@
M<V5T=&EN9W,N"EMJ86Y=($9I>"!C86QE;F1A<B!P;W!U<"!W:71H(%-A9F%R
M:2!B<F]W<V5R<R`H="YZ96QL0&=M>"YD92P@0G5G(",R-#0X*2X*6V-J:%T@
M5VAE;B!U<VEN9R!#1TD@4$A0+"!30U))4%1?3D%-12!M87D@8V]N=&%I;B!T
M:&4@<&%T:"!T;R!T:&4@4$A0(&)I;F%R>0H@("`@("!I;G-T96%D(&]F('1H
M92!S8W)I<'0@8F5I;F<@<G5N.R!U<V4@4$A07U-%3$8@:6YS=&5A9"`H0G5G
M(",R-#`Q*2X*6VIA;ET@1FEX('-H87)I;F<@=VET:"!G<F]U<',@:68@=7-I
M;F<@9W)O=7`@:&]O:W,@*$)U9R`C,C(Y,BDN"@H*+2TM+2TM"G8S+C`N-0HM
M+2TM+2T*"EMM;7-=($9I>"!61E,G<R!A=71O8W)E871E4&%T:"@I(&9O<B!D
M:7)E8W1O<GD@<&%T:',@8V]N=&%I;FEN9R!T:&4@<F]O=`H@("`@("!D:7)E
M8W1O<GDN"EMJ86Y=($9I>"!C>7)S<6P@875T:&5N=&EC871I;VX@9')I=F5R
M('=I=&@@=6YI>&AI97)A<F-H>7-E<"!E;F%B;&5D"B`@("`@("AS9W)O;F1I
M;D!C<V)F+G%C+F-A+"!"=6<@(S(S-C<I+@I;;6US72!&:7@@;F5S=&5D($E-
M05`@04Y$('-E87)C:&5S+@I;;6US72!);B!S<6P@5D93(&1R:79E<BP@86QL
M;W<@=&AE('5S92!O9B`G+R<@870@=&AE(&)E9VEN;FEN9R!O9B!A('!A=&@@
M=&\*("`@("`@:6YD:6-A=&4@=&AE(&)A<V4@9&ER96-T;W)Y+@I;:F%N72!&
M:7@@<F5T=7)N:6YG('1O(&QA<W0@<&%G92!A9G1E<B!S96YD:6YG('!R;V)L
M96T@<F5P;W)T("A"=6<@(S(S-3`I+@I;;6US72!&:7@@82!B=6<@=&AA="!C
M875S960@:&]O:R!C;V1E('1O(&)E(')U;B!U;FYE8V5S<V%R:6QY(&%F=&5R
M(&$@=7-E<@H@("`@("!I<R!A;')E861Y(&QO9V=E9"!I;BX*"@HM+2TM+2TM
M+2TM"G8S+C`N-2U20S(*+2TM+2TM+2TM+0H*6V-J:%T@1FEX(&$@9F%R+7)E
M86-H:6YG($1A=&%4<F5E(&)U9R!I;B!L;V%D:6YG('!A<F5N="!I9',@*$)U
M9R`C,C(P,RDN"@H*+2TM+2TM+2TM+0IV,RXP+C4M4D,Q"BTM+2TM+2TM+2T*
M"EMJ86Y=($%D9"!";W-N:6%N('1R86YS;&%T:6]N("A6961R86X@3&IU8F]V
M:6,@/'9L:G5B;W9I8T!S;6%R=&YE="YB83XI+@I;8VIH72!,970@2&]R9&5?
M5')E92!H86YD;&4@86QL(&EN9&5N="!C86QC=6QA=&EO;B!B87-E9"!O;B!P
M87)E;G0O8VAI;&0*("`@("`@<F5L871I;VYS:&EP<R`H0G5G(",R,3DX*2X*
M6V-J:%T@061D(&EN:71I86P@3$1!4"!397-S:6]N2&%N9&QE<B!D<FEV97(N
M"EMC:FA=(%5S92!R;W<M;&5V96P@;&]C:VEN9R!O<B!T<F%N<V%C=&EO;G,@
M=VAE<F4@<&]S<VEB;&4@=&\@879O:60*("`@("`@<V5S<VEO;B!C;W)R=7!T
M:6]N(&EN(%-E<W-I;VY(86YD;&5R("A"=6<@(S$U.#`I+@I;;6US72!!9&0@
M=&AE(&UE;6-A8VAE9"!397-S:6]N2&%N9&QE<CHZ(&1R:79E<B`H4F]N9RU%
M;B!&86X@/')A9F%N0&-S:64N;W)G/BDN"EMM;7-=($9I>"!V97)I9FEC871I
M;VX@;V8@34E-12!S=')I;F=S('=I=&@@97-C87!E9"!Q=6]T97,@*$)U9R`C
M,C$V."DN"EMJ86Y=($9I>"!G96YE<F%T:6]N(&]F(&9R964@<&5R:6]D<R!I
M;B!F<F5E+V)U<WD@8V]D92!W:71H(&]V97)L87!P:6YG(&5V96YT<RX*6VIA
M;ET@1&]N)W0@<VAO=R!/<'1I;VYS(&)U='1O;B!I;B!P<F]B;&5M(')E<&]R
M=&EN9R!P86=E+@I;:F%N72!!9&0@571I;#HZ<F5A;%!A=&@H*2!M971H;V0N
M"EMM87-=($EN8VQU9&4@=F5R<VEO;B!N=6UB97)S(&9O<B!A<'!L:6-A=&EO
M;G,@;VX@061M:6X@4V5T=7`@<V-R965N+B`H0G5G"B`@("`@(",Q-#(P*0I;
M;6%S72!#:&%N9V4@24U!4"!!=71H(&1R:79E<B!T;R!U<V4@:6UA<"]N;W1L
M<R!B>2!D969A=6QT(&EN(&YO;BU$4TX@;6]D92!T;PH@("`@("!M871C:"!$
M4TX@;6]D92X*6VUA<UT@061D('1L<R!A;F0@<V5L9BUS:6=N960@8V5R=&EF
M:6-A=&4@8V]N9FEG=7)A=&EO;B!O<'1I;VYS('1O($E-05`@075T:`H@("`@
M("!D<FEV97(N("A"=6<@(S$S-3<I"EMC:FA=(%)E8V]G;FEZ92!/<&5R82`X
M*R!A<R!P<F]V:61I;F<@861V86YC960@9F5A='5R97,@*$)U9R`C,C`V-BDN
M"EMC:FA=($9I>"!R96%D:6YG(&]F(&)I;F%R>2!F:6QE<R!O;B!7:6YD;W=S
M(&EN(%9#7W-V;B`H0G5G(",R,#,V*2X*6VUA<UT@1FEX(%-13"`G3$E+12<@
M8V%S92UI;G-E;G-I=&EV92!C;VUP87)I<V]N+B`H0G5G(",R,#,P*0I;:F%N
M72!!;&QO=R!C:&%R<V5T(&%W87)E($E-05`@<V5A<F-H97,N"EMJ86Y=($9I
M>"!';V]G;&4@<V5A<F-H(&)L;V-K(&9O<B!N;VXM87-C:6D@8VAA<F%C=&5R
M<R`H0G5G(",Q,S(Y*2X*6VIA;ET@061D('%U:6-K+6EN<W1A;&P@:6YS=')U
M8W1I;VYS+@I;:F%N72!);7!R;W9E('!E<F9O<FUA;F-E(&]F('-E=F5R86P@
M9G)A;65W;W)K('!A8VMA9V5S+@I;;6US72!&:7@@34E-15]#;VYT96YT<SHZ
M(&-A8VAI;F<@:6X@4$A0(#4@*$)U9R`C,30Q,"DN"EMJ86Y=($9I>"!60R!3
M5DX@8F%C:V5N9"!T;R!S=7!P;W)T('5S97(@;F%M97,@=VET:"!S<&%C97,*
M("`@("`@*'-H:6UM86YN:6YG0&=M86EL+F-O;2P@0G5G(",Q.3$Y*2X*6V-J
M:%T@17-C87!E($A434P@:6X@:61E;G1I='D@;F%M97,@*$)U9R`C,3DQ,"DN
M"EMM87-=(%5S92!U<&1A=&5D(%!O<W1G<F5344P@9G5N8W1I;VX@;F%M97,N
M"EMB96Y=(%5P9&%T92!A<'!L:6-A=&EO;B!L:7-T(&EN(&AO<F1E)W,@3$1!
M4"!S8VAE;6$*6V-J:%T@16YF;W)C92!M87AL96YG=&@@<F5S=')I8W1I;VYS
M(&EN($AO<F1E7T9O<FT@=F%L:61A=&EO;B`H0G5G(",Q.#DU*2X*6VIA;ET@
M1&ES86)L92!W96%T:&5R+F-O;2!";&]C:R!I9B!N;W0@8V]N9FEG=7)E9"X*
M6V-J:%T@26YC;'5D92!S;W5R8V5R;V]T(&EN(%9#(&-A8VAE(&ME>7,@*$)U
M9R`C,3<X,RDN"EMJ86Y=($%D9"!344P@<V-R:7!T(&%N9"!I;G-T<G5C=&EO
M;G,@9F]R($U31$4@9&%T86)A<V5S("A"=6=S(",Q.#8R+"`C,3@W,"P*("`@
M("`@:F5F9D!I;6%G92US<F,N8V]M*2X*6VIA;ET@06QL;W<@<&]R=&%L(&)L
M;V-K<R!T;R!B92!L87)G97(@=&AA;B!T=V\@8V]L=6UN+W)O=W,@*$)U9W,@
M(S$Q.#DL(#$V,S(I+@I;:F%N72!!9&0@4TU44"!A=71H96YT:6-A=&EO;B!T
M;R!P<F]B;&5M(')E<&]R=&EN9R`H0G5G(",Q,3(X*2X*6VIA;ET@4W5P<&]R
M="!H96QP(&9I;&5S(&EN(&%D;6EN(&1I<F5C=&]R>2!W:71H('1R86YS;&%T
M:6]N<RYP:'`@*$)U9R`C,3,T-"DN"EMJ86Y=($9I>&5D(%-13"!B:6YD:6YG
M(&9O<B!/1$)#(&%N9"!-4U-13"!D<FEV97)S("A"=6<@(S$X,38I+@I;:F%N
M72!!9&0@8V]N9FEG=7)A=&EO;B!O<'1I;VX@=&\@<V5T(&QO8V%T:6]N(&]F
M($U)344@;6%G:6,@9&%T86)A<V4N"EMM;7-=($UA:V4@<W5R92!H96%D97)S
M(&EN(&$@34E-15]087)T(&%R92!E;F-O9&5D('=I=&@@=&AE('-A;64@8VAA
M<F%C=&5R"B`@("`@('-E="!U<V5D(&EN('1H870@34E-15]087)T("A"=6<@
M(S$U.3$I+@I;;6US72!!9&0@3&ES="U(96%D97)S(&QI<W1E9"!I;B!21D,@
M,C,V.2!T;R!T:&4@;&ES="!O9B!-24U%($AE861E<G,@=&AA=`H@("`@("!C
M86X@;VYL>2!A<'!E87(@;VYC92!I;B!A('-I;F=L92!H96%D97(@*$)U9R`C
M,3<V-BDN"EMC:FA=($9I>"!T>7!O(&EN('!A<G-I;F<@;V8@1E)%14)54UD@
M9&%T82`H0G5G(",Q-3DP*2X*6VIA;ET@4W5P<&]R="!344QI=&4@86YD($]R
M86-L92!I;B!A;&P@4U%,(&)A8VME;F0@8V]N9FEG=7)A=&EO;G,N"EMC:FA=
M(%5S92!B:6YD('9A<FEA8FQE<R!I;B!T:&4@075T:"P@5D93+"!A;F0@4V5S
M<VEO;DAA;F1L97(@4U%,(&1R:79E<G,L"B`@("`@(&%N9"!I;B!S8W)I<'1S
M+W)E;6]V95]P<F5F<RYP:'`@*'-E;'-K>4!C;VQU;6)I82YE9'4L($)U9W,@
M(S$V-C4L"B`@("`@(",Q-C8V+"`C,38V-RP@(S$V-C@L(",Q-C<W*2X*6V-J
M:%T@<V5S<VEO;E]S971?8V]O:VEE7W!A<F%M<R@I(&5X<&5C=',@82!R96QA
M=&EV92!T:6UE;W5T.R!S971C;V]K:64@=V%N=',*("`@("`@86)S;VQU=&4N
M($=O(&)A8VL@=&\@82!C;VYF:6=I;G1E9V5R(&9O<B`D8V]N9ELG<V5S<VEO
M;B==6R=T:6UE;W5T)UT@86YD"B`@("`@(&%D9"!T:6UE*"D@=&\@=&AA="!V
M86QU92!I;B!S971C;V]K:64H*2!C86QL<R`H0G5G<R`C,3,P,BP@(S$V-3@I
M+@H@("`@("!42$E3($U!62!"4D5!2R!#3TY&24=54D%424].4R!3150@5$\@
M55-%(%!(4"!#3T1%+B!-04M%(%-54D4@5$\@55!$051%"B`@("`@(%E/55(@
M)&-O;F9;)W-E<W-I;VXG75LG=&EM96]U="==(%-%5%1)3D<@049415(@55!'
M4D%$24Y'+@I;8VIH72!5<V4@8FEN9"!V87)I86)L97,@:6X@=&AE(%!R969S
M(&%N9"!4;VME;B!344P@9')I=F5R<PH@("`@("`H<V5L<VMY0&-O;'5M8FEA
M+F5D=2P@0G5G<R`C,38U,BP@(S$V-3,I+@I;;6US72!0<G5N92!E>'!A;F1E
M9"!F;VQD97)S('1H870@;F\@;&]N9V5R(&5X:7-T(&EN($E-05!?5')E92`H
M0G5G(",Q-3$W*2X*6V-J:%T@1&]N)W0@=')Y('1O(&-O;7!R97-S(&]U='!U
M="!I9B!:4%,@8V]M<')E<W-I;VX@:7,@;VX@*$)U9R`C,38R-BDN"EMC:FA=
M($EF(&%N(&%P<"!O;FQY(&AA<R!O;F4@<')E9D=R;W5P+"!A;'=A>7,@<VAO
M=R!T:&%T('!R969'<F]U<"!I;G-T96%D"B`@("`@(&]F('-H;W=I;F<@86X@
M;W9E<G9I97<@<V-R965N('=I=&@@;VYL>2!O;F4@96YT<GDN"@H*+2TM+2TM
M"G8S+C`N-`HM+2TM+2T*"EMC:FA=(%5S92!F=6QL>2!Q=6%L:69I960@55),
M<R!I;B!T:&4@06YS96Q);6%G92!(5$U,07)E82!P;'5G:6X@*$)U9R`C,3(U
M.2DN"EMC:FA=(%-%0U522519.B!#;&]S92!84U,@=VAE;B!S971T:6YG('1H
M92!P87)E;G0@9G)A;64G<R!P86=E('1I=&QE(&)Y"B`@("`@(&IA=F%S8W)I
M<'0N"EMB;&-=($%D9"!0;W-T9W)E4U%,('5P9W)A9&4@<V-R:7!T("A"<F%D
M(%=I='1E(#QB<F%D0&1I<W1A;G1H87IE+F-O;2D*6V-J:%T@079O:60@9&EV
M:7-I;VX@8GD@>F5R;R!I9B!A;&P@<')E9F5R96YC97,@87)E(&QO8VME9"`H
M0G5G(",Q-C(W*2X*6VIA;ET@1FEX('-I9&5B87(@<F5F<F5S:&EN9R!W:71H
M($]P97)A+@H*"BTM+2TM+2TM+2T*=C,N,"XT+5)#,@HM+2TM+2TM+2TM"@I;
M:F%N72!);7!R;W9E(")L;V=I;B(@875T:&5N=&EC871I;VX@9')I=F5R("A"
M=6<@(S$U-S$I+@I;:F%N72!3:&]W(&1A=&%B87-E('-P96-I9FEC(&-O;FYE
M8W1I;VX@<&%R86UE=&5R<R!I;B!G;&]B86P@4U%,(&-O;F9I9W5R871I;VX*
M("`@("`@=&]O+@I;:F%N72!&:7@@;&5F="!M96YU(&]V97)F;&]W(&EN($E%
M(&%N9"!3869A<FD@*$)U9R`C,34R-BDN"EMJ86Y=($9I>"!A=71O8W)E871I
M;F<@;V8@9&ER96-T;W)I97,@86YD('5P9&%T:6YG(&]F(&5X:7-T:6YG(&9I
M;&5S(&EN('1H90H@("`@("!S<6Q?9FEL92!61E,@9')I=F5R("AE9&1I94!O
M;65G87=A<F4N8V]M+"!"=6=S(",Q-34R(&%N9"`C,34U,RDN"EMJ86Y=($UA
M:V4@=W)A<'!I;F<@;65N=7,@=FES:6)L92!W:71H($=E8VMO(#$N-"!B<F]W
M<V5R<R`H92YG+B!.971S8V%P92`W+C$I+@I;:F%N72!5<V4@4U%,(&)I;F1I
M;F<@9F]R('-O;64@1&%T851R964@;W!E<F%T:6]N<RX*6VIA;ET@1FEX($1A
M=&%4<F5E(%-13"!S=7!P;W)T(&9O<B!/<F%C;&4N"EMJ86Y=($9I>"!344P@
M8V]N9FEG=7)A=&EO;B!F;W(@3W)A8VQE+@I;;6US72!-86ME('-U<F4@5D93
M(&=A<F)A9V4@8V]L;&5C=&EO;B!I<R!D;VYE(')E8W5R<VEV96QY+@H*"BTM
M+2TM+2TM+2T*=C,N,"XT+5)#,0HM+2TM+2TM+2TM"@I;:F%N72!!9&0@2&]R
M9&5?5')E95]S96QE8W0@8VQA<W,@*$)E;B!#:&%V970@/&)E;D!H;W)D92YO
M<F<^*2X*6VUJ<ET@1FEX($YE=%])35-0('1O('!R;W!E<FQY(&AA;F1L92!M
M=6QT:7!L92!L:6YE<R!I;B!A9&1R97-S8F]O:R!F:65L9',N"EMJ86Y=($9I
M>"!-24U%(&1E8V]D:6YG(&]F('-T<FEN9W,@=&AA="!C;VYT86EN("(E(B!I
M;B!M=6QT:6)Y=&4@<V5Q=65N8V5S"B`@("`@("A"=6<@(S$T,C,I+@I;8VIH
M72!#;VYT<F]L('-P86-E('5N9&5R('1H92!M96YU(&)A<B!W:71H(&$@=&AE
M;65A8FQE('-T>6QE("A"=6<@(S$T,C$I+@I;8VIH72!&:7@@2&]R9&5?5')E
M92!W:71H('1H92!M=6QT:6QI;F4@;W!T:6]N('-O('1H870@<F]W('-T>6QE
M<R!E>'1E;F0@;W9E<@H@("`@("!T:&4@=VAO;&4@:&5I9VAT(&]F('1H92!R
M;W<N"EMC:FA=($EF(&-O;F9I9W5R871I;VX@9FEL97,@=&AA="!H879E(&$@
M+F1I<W0@=F5R<VEO;B!A<F4@;6ES<VEN9RP*("`@("`@2&]R9&5?5&5S=#HZ
M8V]N9FEG1FEL97--:7-S:6YG*"D@=VEL;"!C;W!Y('1H92!D969A=6QT<R!O
M=F5R(&EF($AO<F1E"B`@("`@(&-A;B!W<FET92!T;R!T:&4@9FEL97-Y<W1E
M;2`H0G5G(",Q,#$U*2X*6V-J:%T@1FEX($%N<V5L26UA9V4@2%1-3$%R96$@
M<&QU9VEN("A"=6<@(S$T-S`I+@I;8VIH72!*=7-T(')E=')I979E('5I9"!W
M:&5N(&QI<W1I;F<@=7-E<G,@:6X@=&AE($Q$05`@075T:&5N=&EC871I;VX@
M9')I=F5R+@I;8VIH72!!9&0@8VAO<F%0<F5F<R!T;R!T:&4@:&]R9&5097)S
M;VX@3$1!4"!S8VAE;6$@*$)U9R`C,30U,BDN"EMC:FA=("=R;V]T9&XG(&ES
M(&YO="!R97%U:7)E9"!F;W(@3$1!4"!P<F5F97)E;F-E<R`H0G5G(",Q-#4S
M*2X*6VUM<UT@1FEX($E-05`@=&AR96%D(&-R96%T:6]N('=H96X@=&AE(&)A
M<V4@;&5V96P@8V]N=&%I;G,@;6]R92!T:&%N(&]N90H@("`@("!M97-S86=E
M+@I;:F%N72!!;&QO=R!V0V%R9',@=VET:"!L;W=E<F-A<V4@9FEE;&0@9&5S
M8W)I<'1O<G,N"EMJ86Y=($EM<')O=F4@=&%R+V=Z:7`@34E-12!V:65W97(@
M=&\@8F5T=&5R('-H;W<@=6YZ:7!P960@8V]N=&5N="X*6VUJ<ET@0F5T=&5R
M(&5R<F]R(&AA;F1L:6YG(&EN($YE=%])35-0+@I;;6US72!3<&5E9"!I;7!R
M;W9E;65N=',@86YD('-O<G1I;F<@9FEX97,@9F]R($E-05!?5')E92X*6VUM
M<UT@24U!4%]4<F5E(&YO=R!H86YD;&5S(&YO;BUU<'!E<F-A<V5D("=)3D)/
M6"<@<W1R:6YG<R!R971U<FYE9"!F<F]M('1H90H@("`@("!M86EL('-E<G9E
M<B`H0G5G(",Q.3DI+@I;;6US72!296)U:6QD(&-E<G1A:6X@:6YT97)N86P@
M34E-15]087)T(&1A=&$@=VAE;B!R971R:65V:6YG(&9R;VT@82!C86-H92X*
M6VIA;ET@4VAO=R!D871A8F%S92!S<&5C:69I8R!C;VYN96-T:6]N('!A<F%M
M971E<G,@:6X@8V]N9FEG=7)A=&EO;B!S8W)E96XN"EMM;7-=($E-05!?5')E
M92!N;W<@8V]R<F5C=&QY('5P9&%T960@=VAE;B!S=6)S8W)I8FEN9R]U;G-U
M8G-C<FEB:6YG(&9R;VT@80H@("`@("!M86EL8F]X("A"=6<@(S$Q,3$I+@I;
M;6US72!-86ME($E-05`@<V5A<F-H97,@;V8@;F]N+2)S=&%N9&%R9"(@:&5A
M9&5R<R!W;W)K('=I=&@@=&AE($Y/5"!D:7)E8W1I=F4*("`@("`@*$)U9R`C
M,3,V."DN"EMJ86Y=($9I>&5D(&1O=6)L92!L:6YE(&YU;6)E<G,@:6X@4V]U
M<F-E+6AI9VAL:6=H="!-24U%('9I97=E<B`H0G5G(",Q,S@S*2X*6VUM<UT@
M1FEX($E-05!?5&AR96%D('=H96X@9&5A;&EN9R!W:71H('1H92!F:7)S="!M
M97-S86=E(&EN('1H92!M86EL8F]X"B`@("`@("A"=6<@(S$R-3<I+@I;8VIH
M72!&:7@@;65N=2!H96EG:'1S(&EN(%-A9F%R:2X*6VIA;ET@0V%T8V@@97)R
M;W)S(&9R;VT@8V]N9FEG=7)A=&EO;B!F:6QE<R!T;R!A=F]I9"!B;&%N:R!P
M86=E<RX*6VIA;ET@4W5P<&]R="!M:6UE7VUA9VEC(&5X=&5N<VEO;B!A9V%I
M;B!I9B!F:6QE:6YF;R!I<R!N;W0@<')E<V5N="X*"@HM+2TM+2T*=C,N,"XS
M"BTM+2TM+0H*6VUJ<ET@3F5T7TE-4U`@;F]W(&-O<G)E8W1L>2!H86YD;&5S
M(&%D9')E<W-B;V]K(&YA;65S(&-O;G1A:6YI;F<@<W!A8V5S"B`@("`@("A"
M=6<@(S$R.#8I+@I;8VIH72!);7!L96UE;G0@8VQE87(H*2!I;B!T:&4@3$1!
M4"!P<F5F<R!D<FEV97(@*$)U9R`C,3,S-2DN"EMC:FA=($1O;B=T(&QI<W0@
M=6YI;G-T86QL960@87!P;&EC871I;VYS(&%S(&EN:71I86Q?87!P;&EC871I
M;VX@;W!T:6]N<PH@("`@("`H0G5G(",Q,S(T*2X*6VIA;ET@1FEX('!O<W1A
M=71H96YT:6-A=&4@:&]O:RP@;F]T(&-O;7!L971E;'D@9&5N>6EN9R!A8V-E
M<W,@869T97(@82!F86EL960*("`@("`@;&]G:6X@*$)U9R`C,3,R,"DN"EMJ
M86Y=($-H96-K8F]X97,@:6X@<&]R=&%L(&)L;V-K('-E='5P(&9O<FUS(&%R
M92!C;W)R96-T;'D@8VAE8VME9"!N;W<*("`@("`@*$)U9R`C,3(T-RDN"EMM
M;7-=($%L;&]W($E-05`@<V5A<F-H97,@=&\@=V]R:R!O;B!H96%D97)S('=I
M=&@@;75L=&EP;&4@96YT<FEE<PH@("`@("`H:V]L8D!B:71L86(N:'4I("A"
M=6<@(S$S,S`I+@I;;6US72!#;W)R96-T;'D@<V]R="!)3D)/6"!S=6)F;VQD
M97)S(&EN($E-05!?4V]R="`H0G5G(",Q,CDQ*2X*6V-J:%T@5'5R;B!O9F8@
M1F]R;2!4;VME;G,@:6X@=&AE(&-O;F9I9W5R871I;VX@:6YT97)F86-E+@I;
M:F%N72!3;W)T('5S97(@86YD(&=R;W5P(&QI<W1S(&EN('!E<FUI<W-I;VYS
M(&EN=&5R9F%C92`H0G5G(",Q,S`U*2X*6VIA;ET@06QL;W<@=&\@96YT97(@
M4$A0(&-O9&4@:6X@=&AE('-E<W-I;VX@=&EM96]U="!C;VYF:6=U<F%T:6]N
M("A"=6<@(S$S,#(I+@H*"BTM+2TM+2TM+2T*=C,N,"XS+5)#,0HM+2TM+2TM
M+2TM"@I;;6US72!&:7@@8G5G(&EN(%1E>'1?1FQO=V5D('=H97)E('5N<75O
M=&5D(&QI;F5S(&-O=6QD(&YO="!B92!F;&]W960N"EMC:FA=($9I>"!L;V=I
M8R!P<F]B;&5M<R!W:71H('1H92!->5-13"!A;F0@3T-)."!S97-S:6]N(&AA
M;F1L97)S('1H870*("`@("`@<')E=F5N=&5D('1H96T@9G)O;2!H86YD;&EN
M9R!R97-T87)T:6YG(&$@<V5S<VEO;B!C;&5A;FQY("A"=6<@(S$P.3<I+@I;
M8VIH72!&:7@@<&5R<VES=&5N8V4@;V8@)&-O;F9;)VUA:6QE<B==6R=P87)A
M;7,G75LG875T:"==(&EN('1H92!3971U<"!520H@("`@("`H0G5G(",Q,C@W
M*2X*6VIA;ET@26UP<F]V92!P97)F;W)M86YC92!O9B!$871A5')E92!O<&5R
M871I;VYS(&QI:V4@<F5A9&EN9R!E;6%I;"!M97-S86=E"B`@("`@(&AI<W1O
M<FEE<RX*6VIA;ET@3&]G('-U8V-E<W-F=6P@;&]G:6YS(&%N9"!L;V=O=71S
M('=I=&@@=&AE($Y/5$E#12!L979E;"`H5FEL:75S(%-U;7-K87,*("`@("`@
M/'9I;&EU<T!L;FLN;'0^*2X*6V-J:%T@16YC;V1E($A434P@96YT:71I97,@
M:6X@2&]R9&5?1F]R;5]4>7!E7VQO;F=T97AT(&1I<W!L87D@*$)U9R`C,3(V
M-RDN"EMM;7-=($9I>"!S97-S:6]N(&AA;F1L:6YG('1O(&5N<W5R92!V87)I
M86)L97,@87)E('!E<G-I<W1E;G0@86-R;W-S(&9U;F-T:6]N"B`@("`@(&-A
M;&QS("A'87)Y(%=I;F1H86T@/'=I;F1H86UG0&5M86EL+F%R:7IO;F$N961U
M/BDN"EMM;7-=($EM<')O=F5M96YT<R!T;R!796)#4%`@34E-15]6:65W97(@
M<F5N9&5R960@;W5T<'5T+@I;;6US72!-;W)E(&9I>&5S(&9O<B!54DQS('=I
M=&@@)R9A;7`G('=H96X@<&%S<VEN9R!T:')O=6=H('1H92!S86YI=&EZ97(N
M"EMJ86Y=($UA:V4@=W)A<'!I;F<@;65N=7,@;&]O:VEN9R!N:6-E<B!I;B!'
M96-K;R!A;F0@2TA434P@8F%S960@8G)O=W-E<G,N"EMJ86Y=($9I>"!-24U%
M('9I97=E<B!F;W(@9WII<"!F:6QE<R!T:&%T(&1O;B=T(&-O;G1A:6X@=&%R
M(&9I;&5S+@I;8VIH72!&:7@@=FES:6)I;&ET>2!O9B`\82`^('1A9W,@:6YS
M:61E('-M86QL:&5A9&5R(&)L;V-K<R!F;W(@=&AE($-O<FYF;&]W97(*("`@
M("`@=&AE;64@*$)U9R`C,3(P-BDN"EMC:FA=($1O(&YO="!C86-H92!J879A
M<V-R:7!T('-E<G9E9"!V:6$@<V5R=FEC97,O:F%V87-C<FEP="YP:'`@*$)U
M9R`C,3$T,"DN"EMC:FA=($9I>"!M86YA9V5M96YT(&]F(&-A=&5G;W)I97,@
M=&AA="!C;VYT86EN('%U;W1E<R`H0G5G(",Q,C`R*2X*6V-J:%T@2&%N9&QE
M(&%D9')E<W-E<R!T:&%T(&%R92!A;')E861Y('-U<G)O=6YD960@8GD@<75O
M=&5S(&EN"B`@("`@($U)344Z.E]R9F,X,C)%;F-O9&4H*2`H0G5G(",Q,30S
M*2X*6V-J:%T@1FEX(%9#7W-V;B=S(&AA;F1L:6YG(&]F(&1I<F5C=&]R>2!N
M86UE<R!W:71H('-P86-E<R`H0G5G(",Q,3(S*2X*6V-J:%T@1FEX(&-A8VAI
M;F<@;&]G:6,@=&AA="!W87,@8V%U<VEN9R!60R!T;R!N;W0@<')O<&5R;'D@
M<F5F<F5S:"!O8FIE8W1S(&EN"B`@("`@(&$@=&EM96QY(&UA;FYE<BX*6VIA
M;ET@06QL;W<@=&\@<V5T(&9I>&5D('1A8FQE(&-E;&P@=VED=&AS(&EN(%=9
M4TE764<@961I=&]R+@H*"BTM+2TM+0IV,RXP+C(*+2TM+2TM"@I;8VIH72!-
M86ME('-U<F4@;F]T('1O('1H<F]W(&5R<F]R<R!W:&5N(&)A9"!E;6%I;',@
M87)E('-U<'!L:65D(&EN"B`@("`@('-E<G9I8V5S+W!R;V)L96TN<&AP("A"
M=6<@(S$P-S`I+@I;:F%N72!&:7@@=W)O;F<@8VAA<G-E="!O9B!R969R97-H
M960@;65N=2!F<F%M92!I9B!N;W0@=7-I;F<@551&+3@@*$)U9W,*("`@("`@
M(S$P-3(L(",Q,#4U*2X*6VIA;ET@1FEX(&QE9G0@;65N=2!T<F5E(&-O;&QA
M<'-I;F<@869T97(@96%C:"!R969R97-H("A"=6<@(S$P-S(I+@I;:F%N72!&
M:7@@<VED96)A<B!B96EN9R!L;V%D960@='=I8V4@:68@;F]T('5S:6YG(&-O
M;VMI97,@*$)U9R`C,3`W-BDN"@H*+2TM+2TM"G8S+C`N,0HM+2TM+2T*"EMJ
M86Y=(%1E<W0@9F]R('-E<W-I;VXN875T;U]S=&%R="X*6VUM<UT@1FEX('!A
M<G-I;F<@;V8@:&5A9&5R('=I=&@@=6YD:7-C;&]S960M<F5C:7!I96YT<R`H
M0G5G(",Q,#4W*2X*6V-J:%T@061D(&$@8G)O=W-E<B!Q=6ER:R!F;W(@8G)O
M=W-E<G,@=&AA="!D;VXG="!S=7!P;W)T(&]V97)F;&]W.FAI9&1E;B!I;@H@
M("`@("!T86)L92!C96QL<R`H2TA434PI+@I;:F%N72!&:7@@87!P;&EC871I
M;VX@;&EN:W,@:68@;F]T('5S:6YG(&-O;VMI97,@*$)U9R`C,3`R.2DN"EMM
M;7-=($9I>"!D:7-A8FQI;F<@;V8@;6%I;G1E;F%N8V4@8V]N9FER;6%T:6]N
M<R`H0G5G(",Q,#(W*2X*6V-J:%T@1FEX(&%L:6=N;65N="!O9B!(96QP('=I
M;F1O=R!H96%D97(@:6X@35-)12`H0G5G(",Q,#(S*2X*6V-J:%T@1FEX('1H
M92!(;W)D95]";&]C:R!G<F%P:&EC<R!T;R!B92!I;F1E>&5D+"!N;W0@9W)A
M>7-C86QE("A"=6<@(S$P-3$I+@I;8VIH72!314-54DE463H@0VQO<V4@<V5V
M97)A;"!84U,@=G5L;F5R86)I;&ET:65S+@I;;6US72!-86ME('-U<F4@97AT
M97)N86P@55),)W,@=V]R:R!C;W)R96-T;'D@=VAE;B!T:&4@55),(&-O;G1A
M:6YS("<F86UP)R!A<PH@("`@("!T:&4@9&5L:6UI=&5R+@I;8VIH72!&:7@@
M:6YF:6YI=&4@;&]O<"!W:71H($%U=&A?87!P;&EC871I;VX@9')I=F5R("A"
M=6<@(S$P,#0I+@I;8VIH72!.979E<B!S970@86X@96UP='D@2&]R9&5?5')E
M92!C;V]K:64@*$)U9R`C,3`R,BDN"EMM;7-=($9I>"!D:7-P;&%Y:6YG(&]F
M(&9O;&1E<G,@:6X@24U!4%]4<F5E.CH@9F]R($E-05`@<V5R=F5R<R!T:&%T
M(&1O;B=T('5S90H@("`@("`G24Y"3U@G(&%S('1H96ER(&1E;&EM:71E<B`H
M0G5G(",Q,#$T*2X*6V-J:%T@2$]21$5?345.55]-05-+7TY/3D4@;F]W(')E
M86QL>2!M96%N<R!O;FQY(&5X<&QI8VET;'D@861D960@;65N=2!I=&5M<PH@
M("`@("!A<F4@9&ES<&QA>65D+@I;8VIH72!)9VYO<F4@2#,@:6X@=F5R<VEO
M;B!C;VUP87)I<V]N<R`H0G5G(",Q,#$W*2X*6V-J:%T@1&%T851R965?;G5L
M;"!N;W<@<W1U8G,@;W5T('1H92!F=6QL($1A=&%4<F5E($%022!T;R!A=F]I
M9"!F871A;"!E<G)O<G,*("`@("`@=VAE;B!N;W0@=7-I;F<@82!P97)M86YE
M;G0@8F%C:V5N9"X*6VIA;ET@1FEX(&1E;&5T:6YG(&]F(&ED96YT:71I97,@
M*$)U9R`C,3`Q."DN"@H*+2TM+0IV,RXP"BTM+2T*"EMC:FA=(%1R>2!T;R!C
M871C:"!D86YG97)O=7,@55),<R!I;B!T:&4@9&5R969E<G)E<B`H9V\N<&AP
M*2X*6V-J:%T@26UP<F]V92!T<F5E(&=R87!H:6-S(&9O<B!R:6=H="UT;RUL
M969T(&QA;F=U86=E<R`H5F%H:60@1VAA9F%R<&]U<@H@("`@("`\=F%H:61`
M9VAA9F%R<&]U<BYC;VT^*2X*6VUM<UT@1FEX($E-05!?5')E92!D:7-P;&%Y
M(&EF(&9O;&1E<B!C;VYT86EN<R!T:&4@=&5X="`G<&]P,R<N"EMC:FA=($9I
M>"!T:&4@2&]R9&5?1F]R;2!D871E('!I8VME<B!P;W!U<"!I;B!+;VYQ=65R
M;W(O4V%F87)I("A"=6<@(SDV,RDN"EMJ86Y=(%-P86-E<R!I;B!T<F5E('9I
M97=S('=I=&@@26YT97)N970@17AP;&]R97(@:&%V92!B965N(&9I>&5D+@H*
M"BTM+2TM+2TM"G8S+C`M4D,S"BTM+2TM+2TM"@I;8VIH72!!;'=A>7,@<F5L
M;V%D(&9R86UE<V5T(&%F=&5R(&QO9V=I;F<@:6X@*$)U9R`C.#$T*2X*6V-J
M:%T@1FEX(&UE;G4@<F5N9&5R:6YG(&9O<B!)12`U+C`O36%C+@I;8VIH72!4
M=7)N(&]F9B!03D<@=')A;G-P87)E;F-Y(&9O<B!)12!B>2!D969A=6QT+@I;
M8VIH72!!;&QO=R!T;R!P87-S(&%N(&%R<F%Y(&]F(&%T=')I8G5T97,@=&\@
M2&]R9&4Z.FEM9R@I+@I;8VIH72!!;&QO=R!T;R!S970@82!P87-S=V]R9"!F
M;W(@=&AE(&%U=&\@875T:&5N=&EC871I;VX@9')I=F5R+@I;:F%N72!!9&0@
M;W!T:6]N(&9O<B!N=6QL(&1R:79E<B!T;R!M86EL97(@8V]N9FEG=7)A=&EO
M;BX*6VIA;ET@1FEX(&-O;F9I9W5R871I;VX@;V8@6E!3(&-A8VAE+@I;:F%N
M72!&:7@@<V]M92!J879A<V-R:7!T(&5R<F]R<R!W:71H($E%(#4N,"X*6V-J
M:%T@5&AE(")(;W)D92!0=7)P;&4B('1H96UE(&ES(&YO=R!S:6UP;'D@86YO
M=&AE<B!T:&5M92!T:&%T(&EN:&5R:71S(&9R;VT*("`@("`@=&AE(&=L;V)A
M;"!#4U,@<V5T=&EN9W,L(&EN<W1E860@;V8@8F5I;F<@8F]T:"!T:&4@<&%R
M96YT('1H96UE(&%S('=E;&P*("`@("`@87,@82!U<V5R+6-H;V]S96%B;&4@
M;W!T:6]N+B`@5&AE(&1E9F%U;'0@9W)A<&AI8W,@87)E(&YO=R!I;B!A"B`@
M("`@('1O<"UL979E;"!T:&5M97,O9W)A<&AI8W,@9&ER96-T;W)Y(&%S('=E
M;&P@9F]R('5S92!B>2!A;&P@=&AE;65S+@H*"BTM+2TM+2TM"G8S+C`M4D,R
M"BTM+2TM+2TM"@I;:F%N72!3:&]W('1A8B!W:71H('1H92!F:65L9"!T:&%T
M(&1I9&XG="!V86QI9&%T92!O;B!S=6)M:71T960@9F]R;7,N"EMM;7-=($%D
M9"!A(&=E;F5R:6,@34E-15]6:65W97(@=&AA="!W:6QL(&1I<W!L87D@=&AE
M(')A=R!T97AT(&]F('1E>'0O*@H@("`@("!P87)T<R!T:&%T('=E(&1O(&YO
M="!H879E(&$@<W!E8VEF:6,@=FEE=V5R(&9O<BX*"@HM+2TM+2TM+0IV,RXP
M+5)#,0HM+2TM+2TM+0H*6V-J:%T@57-E($A/4D1%7TU%3E5?34%32U\J(&-O
M;G-T86YT<R!F;W(@9&5T97)M:6YI;F<@=VAA="!L:6YK<R!A<F4@<VAO=VX*
M("`@("`@;VX@;65N=7,N"EMJ86Y=($-R96%T92!D969A=6QT('!A<F%M971E
M<G,@=VAE;B!A9&1I;F<@82!N97<@8FQO8VL@=&\@=&AE('!O<G1A;"X*6VUM
M<UT@075T;V1E=&5C="!E>&%C="!V97)S:6]N(&]F($E%("@U+C`K*2!O;B!L
M;V=I;B!A;F0@='5R;B!O9F8@8V]M<')E<W-I;VX*("`@("`@;VYL>2!F;W(@
M8G5G9WD@=F5R<VEO;G,N"EMC:FA=(%5S92!A;B!)12!B96AA=FEO<B!F;W(@
M:&%N9&QI;F<@86QP:&$@=')A;G-P87)E;F-Y('=I=&@@4$Y'(&EM86=E<PH@
M("`@("!I;G-T96%D(&]F(&%N(&]N;&]A9"!H86YD;&5R+@I;;6US72!!;&QO
M=R!A;&P@9F]L9&5R<R!T;R!B92!P<F4M9F5T8VAE9"!W:&5N(&EN=&EA;&EZ
M:6YG($E-05!?5')E93HZ+@I;;6US72!!9&1E9"!E>'1E;G-I;VYS('1O('1H
M92!F;W)M(')E;F1E<F5R(&9O<B!T:&4@9FEL92!S96QE8W1I;VX@05!)+@I;
M8VIH72!296YD97(@86QL(&UE;G5S(&%S(#QU;#X@=&%G<RP@9F]R;6%T=&5D
M('=I=&@@0U-3+@I;;6US72!!9&1E9"!E>&%M<&QE(&]F(%]I;7!?:&]O:U]S
M<&%M7V)O=6YC92!T;R!C;VYF:6<O:&]O:W,N<&AP+F1I<W0N"@H*+2TM+2TM
M+2TM"G8S+C`M0D5400HM+2TM+2TM+2T*"EMC:FA=($%L;&]W('1O(&EN<V5R
M="!I;6%G97,@9G)O;2!G86QL97)I97,@:6X@=&AE(%=94TE764<@2%1-3"!E
M9&ET;W(@*$1U8VL*("`@("`@/&1U8VM`;V)A;&$N;F5T/BP@4F]E;"!';&]U
M9&5M86YS(#QR;V5L0&=L;W5D96UA;G,N:6YF;SXI+@I;;61J72!!;&P@2&]R
M9&4@:6-O;G,@8VAA;F=E9"!F<F]M($=)1B!T;R!03D<N"EMM9&I=($%D9"`O
M=&AE;65S(&1I<F5C=&]R>2!A;F0@9W)O=7`@86QL(&]F(&5A8V@@=&AE;64G
M<R!F:6QE<R!U;F1E<B!A('-U8F1I<@H@("`@("!O9B!T:&ES(&1I<F5C=&]R
M>2X*6VIA;ET@4W=I=&-H(&9R;VT@9'EN86UI8R!T;R!S=&%T:6,@0U-3(&9I
M;&5S+@I;;6US72!!9&0@<W5P<&]R="!F;W(@365S<V%G92!$:7-P;W-I=&EO
M;B!.;W1I9FEC871I;VYS("A21D,@,C(Y."DN"EMJ86Y=($%D9"!486)L94]P
M97)A=&EO;G,L($-O;G1E>'1-96YU(&%N9"!,:7-T5'EP92!P;'5G:6YS('1O
M(')I8V@@=&5X=`H@("`@("!E9&ET;W(N"EMJ86Y=($%D9"!$871A5')E92!B
M<F]W<V5R('1O(&%D;6EN(&EN=&5R9F%C92X*6V-J:%T@5&AE($AO<F1E7T-A
M8VAE.CH@05!)(&AA<R!B965N(&-O;7!L971E;'D@<F5W<FET=&5N('1O('1A
M:V4*("`@("`@861V86YT86=E(&]F('1H92!N97<@6E!3-"!A<&D@9F]R(&-O
M;G1E;G0@8V%C:&EN9RP@=VAI8V@@86QL;W=S"B`@("`@(&$@;6]R92!F86UI
M;&EA<B!C86-H:6YG($%022!O=F5R86QL+B!4:&4@;VQD('IP<R!D<FEV97(@
M:&%S(&)E96X*("`@("`@9')O<'!E9"!B96-A=7-E(&]F('1H:7,N"EMJ86Y=
M($%D9"!097)S:6%N("A797-T97)N*2!T<F%N<VQA=&EO;B`H5F%H:60@1VAA
M9F%R<&]U<@H@("`@("`\=F%H:61`9VAA9F%R<&]U<BYC;VT^*2X*6VIA;ET@
M1')O<"!U<V%G92!O9B!A<F=?<V5P87)A=&]R+F]U='!U="X*6VIA;ET@36%K
M92!S:61E8F%R('=I9'1H(&$@<')E9F5R96YC92`H4FEC:R!%;65R>2`\<FEC
M:T!E;65R>2YH;VUE;&EN=7@N;F5T/BDN"EMC:FA=(%1H92!0<F5F<U]S<6P@
M9')I=F5R(&YO=R!U<V5S($1".CIP<F5P87)E+T1".CIE>&5C=71E(&9O<B!B
M971T97(@<W5P<&]R=`H@("`@("!O9B!L87)G92!F:65L9',@;VX@9&%T86)A
M<V4@8F%C:V5N9',@<W5C:"!A<R!/<F%C;&4N"EMC:FA=(%-U<'!O<G0@8W5S
M=&]M(&9I96QD(&UA<'!I;F=S(&EN($-35B!E>'!O<G1S+"!A;F0@861D(&%N
M($]U=&QO;VL@97AP;W)T"B`@("`@('1Y<&4N"EMC:FA=(%1H92!(;W)D92!S
M:61E8F%R(&UE;G4@:7,@;F]W(&)U:6QT('=I=&@@2&]R9&5?5')E92X*6VIA
M;ET@4T5#55))5%DZ($-L;W-E(&%N(%A34R!H;VQE(&EN('1H92!(5$U,('9I
M97=E<BP@82!V87)I871I;VX@=&\@=&AE(&]N90H@("`@("!R97!O<G1E9"!I
M;B!H='1P.B\O=W=W+F=R97EM86=I8RYC;VTO<V5C=7)I='DO861V:7-O<FEE
M<R]G;3`P-2UM8R\N"EMJ86Y=($%D9"!C;VYF:6=U<F%T:6]N(&]P=&EO;B!T
M;R!E;F%B;&4@4U-,(&9O<B!L;V=I;G,@;VYL>2X*6VIA;ET@4F5M;W9E('-H
M87)E('1Y<&4@*'!R:79A=&4O<'5B;&EC*2X*6VIA;ET@061D(&9R86UE=V]R
M:R!T;R!C;&5A<B!O=70@=7-E<B!D871A+"!E+F<N('=H96X@<F5M;W9I;F<@
M=7-E<G,N"EMJ86Y=($%D9"!A8V-E<W,@:V5Y<RX*6VIA;ET@1&]N)W0@<F5Q
M=6ER92!B;&]C:W,@=&\@8F4@<F5G:7-T97)E9"!I;B!T:&4@87!P;&EC871I
M;VYS)R!!4$ES+@I;8VIH72!);G1R;V1U8V4@82`G7V1E9F%U;'1?)R!C;VQO
M<B!A;F0@8F5T=&5R(&AA;F1L:6YG(&]F('5S97(M<W!E8VEF:65D"B`@("`@
M(%5N9FEL960@8V]L;W)S+@I;:F%N72!!;&QO=R!T:&5M97,@=&\@=7-E('1H
M96ER(&]W;B!I8V]N('-E=',N"EMC:FA=($-A=&5G;W)I97,@86YD(&-A=&5G
M;W)Y(&-O;&]R(&QA8F5L<R!A<F4@;F]W(&AA;F1L960@9VQO8F%L;'D@8GD@
M2&]R9&4L"B`@("`@(&%N9"!P<F]V:61E9"!T;R!A;&P@87!P;&EC871I;VYS
M('1H870@=7-E('1H96TN"EMJ86Y=($ED96YT:71I97,@87)E(&YO=R!M86YA
M9V5D('=I=&@@=&AE('!R969E<F5N8V5S(&-O9&4@86YD(&-A;B!B92!A8V-E
M<W-E9`H@("`@("!F<F]M(&5V97)Y(&%P<&QI8V%T:6]N+@I;;6US72!(86YD
M;&4@4D9#(#(R,S$@96YC;V1E9"!P87)A;65T97(@=F%L=65S+@I;;6US72!!
M9&0@24U!4%]3;W)T(&-L87-S('1O('!R;W9I9&4@<V]R=&EN9R!F;W(@24U!
M4"!M86EL8F]X(&QI<W1S+@I;:F%N72!!9&0@=7-E<B!M86YA9V5M96YT('1O
M($E-05`@875T:&5N=&EC871I;VX@9')I=F5R+@I;:F%N72!!9&0@24U!4%]!
M9&UI;B!C;&%S<R!T;R!M86YA9V4@24U!4"!M86EL8F]X97,N"EMM;7-=($%D
M9&5D(&$@9V5N97)I8R!T97AT+VAT;6P@34E-15]6:65W97(@9')I=F5R(&9O
M<B!A;&P@2&]R9&4@87!P;&EC871I;VYS"B`@("`@('1H870@871T96UP=',@
M=&\@<V%N:71I>F4@;6%L:6-I;W5S(&-O9&4@:&ED9&5N(&EN($A434PN"EMM
M;7-=($%D9&5D(&$@9V5N97)I8R!M97-S86=E+W)F8S@R,B!-24U%7U9I97=E
M<B!D<FEV97(N"EMC:FA=(%)E;6]V92!(3U)$15],24)3(&-O;G-T86YT(&%N
M9"!A<W-U;64@;&EB<F%R:65S(&%R92!I;B!T:&4@:6YC;'5D95]P871H+@I;
M:F%N72!!9&0@<V5A<F-H:6YG(&%N9"!P86=I;F<@=&\@=&AE('5S97(@861M
M:6YI<W1R871I;VX@:6YT97)F86-E("A*;V5L"B`@("`@(%9A;F1A;"`\:G9A
M;F1A;$!I;F9O=&5C:RYQ8RYC83XI+@H*"BTM+2TM+2TM+2T*=C,N,"U!3%!(
M00HM+2TM+2TM+2TM"@I;:F%N72!!8V-E<W,@:V5Y<R!A<F4@;F\@;&]N9V5R
M(&=E;F5R871E9"!A=71O;6%T:6-A;&QY(&)U="!D969I;F5D(&)Y('1H90H@
M("`@("!D979E;&]P97)S(&%N9"!T<F%N<VQA=&]R<RX*6V-J:%T@5&AE(&YE
M=R!S97)V:6-E<R]P<F5F<RYP:'`@9FEL92!I<R!N;W<@=&AE(&]N;'D@54D@
M<&%G92!N96-E<W-A<GD*("`@("`@9F]R('!R969E<F5N8V5S(&9O<B!A;&P@
M87!P;&EC871I;VYS("T@86QL(&%P<"]P<F5F<RYP:'`@9FEL97,*("`@("`@
M87)E(&YO=R!O8G-O;&5T92X*6V-J:%T@4')E9G,Z.F=E=%!R968H*2!H87,@
M8F5E;B!D97!R96-A=&5D(&%N9"!I<R!N;R!L;VYG97(@<')E<V5N="X*6V-J
M:%T@2&]R9&4Z.BP@4F5G:7-T<GDZ.BP@86YD('1H92!L87-T(&]F('1H92!L
M:6)S('1H870@87)E(&UO=FEN9R!S:&]U;&0@8F4*("`@("`@;6]V960@=&\@
M9G)A;65W;W)K('!A8VMA9V5S(&YO=RX*6V-J:%T@161I=&]R.CHL($UE;G4N
M<&AP+"!.3%,Z.BP@86YD(%-I9VYU<"YP:'`@:&%V92!A;&P@8F5E;B!M;W9E
M9"!T;PH@("`@("!F<F%M97=O<FL@<&%C:V%G97,N"EMM;7-=($UO=F5D('1H
M92!)34%0(%1R964@9V5N97)A=&EO;B!C;&%S<R!F<F]M($E-4"!T;R!F<F%M
M97=O<FL@<V\@:70@8V%N"B`@("`@(&)E('5S960@8GD@;W1H97(@87!P;&EC
M871I;VYS+@I;;61J72!3971U<"!N;W<@:&%S(&$@;6]R92!I;F9O<FUA=&EV
M92!F;W)M870N(%1H92!#5E,@=F5R<VEO;B!T86<@:7,@8V]P:65D"B`@("`@
M(&9R;VT@=&AE(&-O;F8N>&UL(&9I;&4@:6YT;R!T:&4@8V]N9BYP:'`@9FEL
M92!S;R!T:&%T(&ET(&)E('5S960@=&\@=V%R;@H@("`@("!W:&EC:"!A<'!L
M:6-A=&EO;G,@;F5E9"!T:&5I<B!C;VYF('5P9&%T960N"EMC:FA=(%5S92!J
M879A<V-R:7!T('1O(&%U=&]D971E8W0@=VAE=&AE<B!O<B!N;W0@=&AE(&9R
M86UE<V5T(&ES('!R97-E;G0N"EMC:FA=($AO<F1E7TAI<W1O<GDL($AO<F1E
M7TQI;FMS+"!A;F0@2&]R9&5?4V5A<F-H(&AA=F4@8F5E;B!M;W9E9"!T;PH@
M("`@("!F<F%M97=O<FL@<&%C:V%G97,N"EMC:FA=($%L;&]W(&%P<',@:6YC
M;'5D:6YG(&AO<F1E+VQI8B]B87-E+G!H<"!T;R!S<&5C:69Y('1H870@82!D
M:69F97)E;G0*("`@("`@<F5G:7-T<GD@87!P;&EC871I;VX@<VAO=6QD(&%C
M='5A;&QY(&)E('!U<VAE9"!O;G1O('1H92!296=I<W1R>0H@("`@("!A<'!L
M:6-A=&EO;B!S=&%C:RX@5&AI<R!L971S('1H92!F:6-T:6]N(&]F('!R;V)L
M96TN<&AP(&)E:6YG(&ET<PH@("`@("!O=VX@87!P;&EC871I;VX@<&QA>2!N
M:6-E;'D@=VET:"!T:&4@;F5W('!E<FUI<W-I;VYS(&-H96-K:6YG+@I;8VIH
M72!4:&4@;F5W(&%P<&QI8V%T:6]N('!E<FUI<W-I;VYS(&-H96-K:6YG(&AA
M<R!B965N(&UO9&EF:65D('1O"B`@("`@(&%L;&]W(&%C8V5S<R!T;R!A;&P@
M875T:&5N=&EC871E9"!U<V5R<R!B>2!D969A=6QT+"!A;F0@=&\@9&5N>0H@
M("`@("!G=65S="!A8V-E<W,@8GD@9&5F875L="X@06QL('9A<FEA=&EO;G,@
M;VX@=&AA="!M=7-T(&)E('-E=`H@("`@("!E>'!L:6-I=&QY+@I;8VIH72!2
M96UO=F4@=&AE($=U97-T(%-E<G9I8V5S(&QI;FL[(&ET)W,@8F5E;B!O8G-O
M;&5T960@8GD*("`@("`@)&-O;F9;)VUE;G4G75LG86QW87ES)UTN"EMC:FA=
M(%9A<FEO=7,@)&YO7V%U=&@@86YD("1S96QF7V-O;G1A:6YE9%]A=71H(&9L
M86=S(&AA=F4@8F5E;B!S=&%N9&%R9&EZ960*("`@("`@:6YT;R!A;B!!551(
M7TA!3D1,15(@8V]N<W1A;G0L('=H:6-H(&EF(&1E9FEN960@<VEG;F%L<R!T
M:&4@87!P;&EC871I;VX*("`@("`@=&AA="!I="!S:&]U;&0@;F]T(&-H96-K
M('!E<FUI<W-I;VYS('5P;VX@8V%L;&EN9R`D<F5G:7-T<GDM/G!U<VA!<'`H
M*2P*("`@("`@87,@=&AE(&-A;&QI;F<@<V-R:7!T('=I;&P@:&%N9&QE('1H
M870@:71S96QF+"!O<B!I<R!A('-Y<W1E;2UL979E;"!C<F]N"B`@("`@(&IO
M8B]S8W)I<'0O971C+@I;8VIH72!!9&0@86X@;W!T:6]N('1O("1R96=I<W1R
M>2T^<'5S:$%P<"@I('1O('-P96-I9GD@=VAE=&AE<B!O<B!N;W0@=&\@8VAE
M8VL*("`@("`@87!P;&EC871I;VX@<&5R;6ES<VEO;G,N"EMC:FA=(%1H92`G
M86QL;W=?9W5E<W1S)R!S971T:6YG+"!A;F0@)')E9VES=')Y+3YA;&QO=T=U
M97-T<R@I+"!H879E(&)E96X*("`@("`@<F5M;W9E9"!I;B!F879O<B!O9B!(
M;W)D95]097)M<R!A<'!L:6-A=&EO;B!P97)M:7-S:6]N<RX*6VUM<UT@061D
M960@=&AE('1E>'0O<FEC:'1E>'0@34E-15]6:65W97(N"EMJ86Y=($EN<W1A
M;G1I871E('1H92!G;&]B86P@4&5R;7,@;V)J96-T(&EN(%)E9VES=')Y+G!H
M<"X*6V-J:%T@0V%T96=O<GD@:&%S(&)E96X@;6]V960@=&\@82!F<F%M97=O
M<FL@<&%C:V%G92P@86YD(&%L<V\@<F5N86UE9`H@("`@("!T;R!$871A5')E
M92!S;R!T:&%T(&ET(&AA<R!A(&UO<F4@:6YT=6ET:79E(&YA;64@9F]R('1H
M92!!4$DN"EMJ86Y=($%D9"!);F1O;F5S:6%N(&QA;F=U86=E("A3;&%M:6X@
M/'-L86UI;D!U;F5J+F%C+FED/BDN"EMJ86Y=($%D9"!!=71H7VQO9VEN(&-L
M87-S+@I;:F%N72!!9&0@2&]R9&4Z.F5X=&5R;F%L57)L*"DN"EMM9&I=(%!E
M<FUS(&ES(&YO=R!A(&=L;V)A;&QY(&%V86EL86)L92!O8FIE8W0L('-E="!B
M>2!T:&4@<F5G:7-T<GDG<PH@("`@("!L;V%D4&5R;7,H*2X*6VIA;ET@061D
M(")!8F]U="(@<&%G92!F;W(@=&AE(&AE;'`@<WES=&5M+@I;:F%N72!!9&0@
M4T]!4"!S97)V97(@=&\@4E!#(&9R86UE=V]R:RX*6V-J:%T@36]V92!0<F5F
M<U5)('1O(%!R969S+U5)+G!H<"!F;W(@<&%C:V%G92!C;VYS:7-T96YC>2X*
M6VUM<UT@061D960@3DQ37T=E;TE0.CH@=&\@9&\@2&]S=&YA;64@+3X@0V]U
M;G1R>2!L;V]K=7!S+B`@3DQ3.CH@=VEL;"!D;PH@("`@("!L;V]K=7!S(&)Y
M(&1E9F%U;'0@;F]W('5S:6YG(&-O=6YT<GD@5$Q$(&-O9&5S+@I;;6ER72!!
M9&0@<')E<')O8V5S<R!H;V]K(&9O<B!3:6=N=7`@<WES=&5M+@I;:F%N72!-
M;W9E($AO<F1E7T-,22P@2&]R9&5?0V%C:&4L($AO<F1E7T-I<&AE<BP@2&]R
M9&5?0V]M<')E<W,L"B`@("`@($AO<F1E7U1O:V5N(&%N9"!(;W)D95]5=&EL
M('!A8VMA9V5S('1O('1H92!F<F%M97=O<FL@;6]D=6QE+@I;8VIH72!296]R
M9V%N:7IE(&$@;G5M8F5R(&]F(&9I;&5S(&9R;VT@=&AE('1O<"!L979E;"!A
M;F0@9G)O;2!U=&EL+R!I;G1O(&$*("`@("`@;F5W('-E<G9I8V5S+R!D:7)E
M8W1O<GD@86YD(&$@;G5M8F5R(&]F('-E<G9I8V5S+RH@<W5B9&ER96-T;W)I
M97,N"B`@("`@(%1H:7,@<VAO=6QD(&=I=F4@=7,@82!B971T97(@8F%S92!F
M;W(@97AP86YD:6YG('1H92!S97)V:6-E<R!P<F]V:61E9`H@("`@("!B>2!T
M:&4@8V]R92!(;W)D92!M;V1U;&4@:6X@=&AE(&9U='5R92X*6VUA>%T@061D
M('-U<'!O<G0@9F]R(#QB/B!A;F0@/&D^('1A9W,@=&\@=&AE($AE;'`@>&UL
M('!A<G-E<BX*6V-J:%T@061D('1H92!(;W)D95](:7-T;W)Y($%022P@9F]R
M('-T;W)I;F<@=&EM97-T86UP960@979E;G1S(&9O<@H@("`@("!A<F)I=')A
M<GD@;V)J96-T<RX*6V-J:%T@2&]R9&5?5&5M<&QA=&4@;F]W(&%L;&]W<R!I
M9CH@8V]N9&ET:6]N<R!O;B!A<G)A>2!V86QU97,*("`@("`@*$YU;F\@3&]U
M<F5I<F\@/&YU;F]`8V\N<V%P;RYP=#XI+@I;:F%N72!4:&4@861M:6YI<W1R
M871O<B!C86X@;F]W(&9O<F-E('1H92!D969A=6QT(&QA;F=U86=E(&EN(&YL
M<RYP:'`*("`@("`@*$5T:65N;F4@1V]Y97(@/&5T:65N;F4N9V]Y97)`;&EN
M=7AQ=65B96,N8V]M/BDN"EMM9&I=($AO<F1E7T9O<FT@;F]W('-U<'!O<G1S
M('-E='1I;F<@;V8@82!H96QP(&EC;VX@;&EN:V5D('1O(&AE;'`N>&UL+@I;
M8VIH72!M:6UE7VUA<'!I;F<N<&AP(&ES(&YO(&QO;F=E<B!A(&-O;F9I9R!F
M:6QE.R!R97!L86-E9"!W:71H"B`@("`@(&UI;64N;6%P<&EN9RYP:'`@:6YS
M:61E('1H92!-24U%('!A8VMA9V4N"EMC:FA=($%D9"!';V]G;&4@<V5A<F-H
M(&%P<&QE="`H2F]E(%=I;'-O;B`\:F]E+G=I;'-O;D!M:6YD8V%N9'DN;W)G
M/BDN"EMJ86Y=(%541BTX('-U<'!O<G0@:7,@96YA8FQE9"!B>2!D969A=6QT
M(&YO=RX*6VIA;ET@5&AE;65S(&%R92!N;W<@875T;VUA=&EC86QL>2!R96%D
M(&9R;VT@=&AE(&-O;F9I9R]T:&5M97,@9&ER96-T;W)Y+@I;8VIH72!!9&0@
M<W5P<&]R="!F;W(@;W1H97(@:VEN9',@;V8@<V5R=F5R<R!A;F0@;W1H97(@
M:VEN9',@;V8@<F5S<&]N<V5S('1O"B`@("`@(')P8RYP:'`@86YD('1H92!2
M4$,Z.B!!4$DN"EMJ=VU=($%D9"!S=7!P;W)T(&9O<B!A<'!R;W9I;F<@<75E
M=65D('-I9VYU<"!A<'!L:6-A=&EO;G,N"EMC:FA=($=R;W5P<R!C86X@;F]W
M(&AA=F4@86X@96UA:6P@861D<F5S<R!A<W-O8VEA=&5D('=I=&@@=&AE;2X*
M6V-J:%T@36%K92!(;W)D92UL979E;"!";&]C:W,@8V]N9FEG=7)A8FQE('1H
M<F]U9V@@=&AE(')E9VES=')Y+"!A;&QO=VEN9PH@("`@("!E87-I97(@861D
M:6YG(&]F(&YE=R!B;&]C:W,@*$IO92!7:6QS;VX@/&IO92YW:6QS;VY`;6EN
M9&-A;F1Y+F]R9SXI+@I;8VIH72!#871E9V]R>51R964@:7,@;F]W(&1E<')E
M8V%T960@:6X@9F%V;W(@;V8@2&]R9&5?5')E92X*6V-J:%T@36]V92!T:&4@
M861M:6X@<&5R;6ES<VEO;G,@86YD(&=R;W5P<R!P86=E<R!T;R!U<V4@2&]R
M9&5?5')E92X*6VUA>%T@061D(%]C;VUP87)E4&%S<W=O<F1S*"D@9G5N8W1I
M;VX@=&\@075T:%]S<6P@=&\@8V]R<F5C=&QY(&-O;7!A<F4*("`@("`@86QL
M(&-R>7!T960@<&%S<W=O<F1S('-I;6EL87(@=&\@=&AE(%!A<W-W9"!M;V1U
M;&4N"EMM87A=($%D9"!C<GEP="UD97,@*'=H:6-H(&ES('1H92!S86UE(&%S
M(&-R>7!T*2P@8W)Y<'0M;60U+"!A;F0@8W)Y<'0M8FQO=V9I<V@*("`@("`@
M96YC<GEP=&EO;B!T>7!E<RP@=&\@;6%T8V@@4&%S<W=D(&UO9'5L92X*6VUA
M>%T@061D(&]P=&EO;F%L('-H;W=?96YC<GEP=&EO;B!P87)A;2!T;R!!=71H
M7W-Q;"P@=&\@;6%T8V@@4&%S<W=D(&UO9'5L92X*6VUM<UT@061D960@25`@
M061D<F5S<R!C:&5C:R!T;R!!=71H.CIA=71H96YT:6-A=&4H*2!T;R!I;F-R
M96%S92!S96-U<FET>2X*6VIA;ET@4F5M;W9E($Y,4SHZ9&5C:6UA;$9R;VU,
M;V-A;&4H*2!A;F0@3DQ3.CID96-I;6%L5&],;V-A;&4H*2X*6V-J:%T@2&]R
M9&5?5D93.CH@:7,@;F]W(%9&4SHZ(&%G86EN+"!A;F0@:&%S(&YO(&5X=&5R
M;F%L($AO<F1E(&1E<&5N9&%N8VEE<RX*6V-J:%T@4F]U;F0@;W5T('1H92!V
M87)I;W5S('-H96QL('1O;VQS('=I=&@@82!C;VUM86YD('-H96QL+@I;8VIH
M72!!9&0@<VED96)A<BYP:'`@86YD(&%P<')O<')I871E('!R969S(&5N=')I
M97,@9F]R('5S:6YG($AO<F1E('=I=&@@=&AE"B`@("`@(&UE;G4@87,@82!-
M;WII;&QA('-I9&5B87(N"EMM;7-=($%D9"!)34%07T-A8VAE.CH@8VQA<W,@
M=&\@:&%N9&QE(&-A8VAE9"!)34%0('-E<G9E<B!D871A+@I;8VIH72!-86ME
M(&=E=$-A=&5G;W)I97-">4%T=')I8G5T97,H*2!M=6-H(&UO<F4@<V]P:&ES
M=&EC871E9"`M(&ET(&-A;@H@("`@("!N;W<@:&%N9&QE(&$@<')E='1Y(&UU
M8V@@87)B:71R87)Y(&QO9VEC('1R964@+2!A;F0@=7-E(&ET('1O(&]P=&EM
M:7IE"B`@("`@($AO<F1E7U-H87)E.CIL:7-T4VAA<F5S*"DN"EMC:FA=($%D
M9"!G971#871E9V]R:65S0GE!='1R:6)U=&5S*"DL(&%N9"!U<V4@:70@:6X*
M("`@("`@1W)O=7`Z.F=E=$=R;W5P365M8F5R<VAI<',H*2X*6V-J:%T@061D
M(&-O9&4@=&AA="!L971S(&$@0V%T96=O<GE/8FIE8W0@<W5B8VQA<W,@9&5F
M:6YE(&$@;6%P<&EN9R!F<F]M(&ET<PH@("`@("!I;G1E<FYA;"!D871A('1O
M('1H92!N97<@:&]R9&5?8V%T96=O<GE?871T<FEB=71E<R!T86)L92X*6VUM
M<UT@24U!4%]396%R8V@Z.B!N;W<@=7-E<R!A($E-05!?4V5A<F-H7U%U97)Y
M.CH@;V)J96-T('1O(&)U:6QD('1H90H@("`@("!A8W1U86P@24U!4"!S96%R
M8V@N"EMM;7-=($%D9&5D(&$@<V5C=7)E(&1E;&5T92!T96UP(&9I;&4@;W!T
M:6]N('1H870@=VEL;"!O=F5R=W)I=&4@86YY('1E;7`@9FEL90H@("`@("!W
M:71H(')A;F1O;2!D871A(&)E9F]R92!U;FQI;FMI;F<N"EMJ86Y=($%D9"!,
M879E;F1E<B!T:&5M92`H6FEA=7(@4F%H;6%N(#QZ:6%`<6%L86-O;2YC;VT^
M*2X*6V-J:%T@2&]R9&5?5&5M<&QA=&4Z.B!I<R!N;W<@8V%P86)L92!O9B!T
M<F%N<VQA=&EN9R!T97AT(&EN<VED90H@("`@("`\9V5T=&5X=#X\+V=E='1E
M>'0^('1A9W,N"EMC:FA=($AO<F1E7TUO8FEL93HZ(&YO=R!P<F]P97)L>2!S
M=7!P;W)T<R!M=6QT:7!L92!S=6)M:70@96QE;65N=',@:6X@9F]R;7,N"EMM
M86-=($%D9"!G96YE<FEC($-Y<G5S(&%U=&@@9')I=F5R+"!!=71H7V-Y<G5S
M+@I;;6%C72!!9&0@;W!T:6]N86P@96YC<GEP=&EO;B!P87)A;2!T;R!!=71H
M7W-Q;"P@=&\@;6%T8V@@4&%S<W=D(&UO9'5L92X*6VIA;ET@061D(&YE=R!H
M;V]K<R`H<F5P;&%C:6YG(%]H;W)D95]H;V]K7W5S97)N86UE*2!T;R!C;VYV
M97)T('5S97(@;F%M97,*("`@("`@9G)O;2!T:&4@8F%C:V5N9"!T;R!(;W)D
M92!A;F0@8F%C:RX*6V-J:%T@061D(&$@;F5W($%022!C86QL+"!!=71H.CII
M<T%U=&AE;G1I8V%T960H)')E86QM(#T@;G5L;"DL(&9O<@H@("`@("!D971E
M<FUI;FEN9R!W:&5T:&5R(&]R(&YO="!A('5S97(@:7,@;&]G9V5D(&EN('1O
M('1H92!C=7)R96YT"B`@("`@(')E86QM("AB>2!D969A=6QT(&YU;&PI+B!!
M=71H.CIG971!=71H*"D@:7,@<W1I;&P@=7-E9"!T;R!G970*("`@("`@=&AE
M(&-U<G)E;G0@=7-E<BP@8G5T(&YO=R!Y;W4@9&]N)W0@;F5E9"!T;R!K;F]W
M('1H92!A=71H(')E86QM"B`@("`@('1O(&=E="!T:&4@8W5R<F5N="!U<V5R
M("T@:G5S="!T;R!C:&5C:R!A=71H96YT:6-A=&EO;BX*6V-J:%T@1$A434P@
M9&%T92!P:6-K97(@;F]W(&]P96YS(')I9VAT(&]V97(@=&AE(&EM86=E('5S
M960@=&\@86YC:&]R(&ET+@I;8VIH72!4:&4@;&%S=%]L;V=I;B!P<F5F97)E
M;F-E(&ES(&YO=R!E;G1I<F5L>2!H86YD;&5D(&)Y($AO<F1E+@I;;6US72!!
M9&0@2&]R9&5?5&5S=#HZ(&-L87-S+W1E;7!L871E<R!T;R!A:60@:6X@8W)E
M871I;F<@=&5S="YP:'`@<V-R:7!T<RX*6VUM<UT@36]V92!C;VUP;&5X($E-
M05`@<V5A<F-H:6YG(&-O9&4@9G)O;2!)35!?4V5A<F-H.CH@=&\@24U!4%]3
M96%R8V@Z.BX*6V-J:%T@4F4M=V]R:R!T:&4@2&]R9&4@3$1!4"!S8VAE;6$@
M8FET<R!T;R!B92!M;W)E(&-O<G)E8W0@86YD"B`@("`@(&-O;G-I<W1E;G0@
M*$%D86T@5&%U;F\@5VEL;&EA;7,@/&%D86U`;6]R<FES;VXM:6YD+F-O;3XI
M+@I;;6US72!!9&0@1$]-('1O;VQT:7`@8V%P86)I;&ET>2!V:6$@2&]R9&4Z
M.FQI;FM4;V]L=&EP*"DN"EMM;7-=($%D9"!G87)B86=E(&-O;&QE8W1I;VX@
M8VQA<W,@*$AO<F1E7U9&4U]'0SHZ*2!F;W(@5D93+@I;;6US72!!9&0@=&EM
M96]U="!T;R!01U`@:V5Y<V5R=F5R(&QO;VMU<"X*6V-J:%T@061D(&YA=FEG
M871I;VX@9F]R('!R979I;W5S+VYE>'0@<')E9F5R96YC97,@8FQO8VL@:6X@
M4')E9G-520H@("`@("`H36%T:&EE=2!#3$%"0554(#QM871H:65U+F-L86)A
M=71`9G)E92YF<CXI+@I;8VIH72!!9&0@2&]R9&5?3&EN:W,@05!)("AJ+FAU
M:6YI;FM`=V%N861O;RYN;"DN"EMC:FA=($%D9"!M;W)E(&EN=')O<W!E8W1I
M;VXL(&EN('1H92!F;W)M(&]F(&=E=$-O;G1E;G14>7!E*"D@86YD"B`@("`@
M(&=E=$QI;FLH*2P@=&\@=&AE($AO<F1E7TEM86=E.CH@05!)+@I;8VIH72!!
M9&0@=71I;"]C86-H979I97<N<&AP(&9O<B!V:65W:6YG(&%N>2!D871A('=I
M=&@@82!#;VYT96YT+71Y<&4*("`@("`@<'5T(&EN=&\@=&AE(&-A8VAE+@I;
M8VIH72!!9&0@2&]R9&5?0V%C:&4Z.F-A8VAE3V)J96-T*"D@9F]R('5S92!I
M;B!C86-H:6YG('1H92!R97-U;'1S(&]F"B`@("`@(&YO;BUS=&%T:6,@;V)J
M96-T(&UE=&AO9',N"EMC:FA=(%)E;F%M92!#86-H93HZ('1O($AO<F1E7T-A
M8VAE.CHN"EMC:FA=($UO=F4@0V%C:&5?<V5S<VEO;CHZ('1O($AO<F1E7U-E
M<W-I;VY/8FIE8W1S.CHN"EMM;7-=($%D9&5D($AO<F1E.CIE>'1E;G-I;VY%
M>&ES=',H*2!T;R!C86-H92!E>'1E;G-I;VY?;&]A9&5D*"D@8V%L;',N"EMC
M:FA=($%D9"!.3%,Z.F1E8VEM86Q4;TQO8V%L92@I(&%N9"!.3%,Z.F1E8VEM
M86Q&<F]M3&]C86QE*"D@=&\@:&%N9&QE"B`@("`@(&-O;G9E<G1I;F<@8F5T
M=V5E;B!D:69F97)E;G0@9&5C:6UA;"!P;VEN="!S97!A<F%T;W)S+@I;8VIH
M72!!9&1E9"!-24U%7TAE861E<G,Z.BX*6VUM<UT@36]V960@9WII<"!A;F0@
M=&%R(&9I;&4@:&%N9&QI;F<@=&\@2&]R9&5?0V]M<')E<W-?*CHZ(&UO9'5L
M97,N"EMM;7-=($UO=F5D(%I)4"!H86YD;&EN9R!T;R!T:&4@2&]R9&5?0V]M
M<')E<W-?>FEP.CH@;6]D=6QE+@I;;6US72!-;W9E9"!43D5&(&AA;F1L:6YG
M('1O('1H92!(;W)D95]#;VUP<F5S<U]T;F5F.CH@;6]D=6QE+@I;;6US72!!
M9&1E9"!(;W)D95]#;VUP<F5S<SHZ($%022`M('5S960@=&\@8V]M<')E<W,O
M9&5C;VUP<F5S<R!D871A+@I;;61J72!!9&1E9"!T:&4@1$]-(&-A;&5N9&%R
M(&1A=&4@<&EC:V5R('1O($AO<F1E7T9O<FTL(&)A<V5D(&]N('=O<FL@8GD*
M("`@("`@36EK92!#;V-H<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX@
M86YD($)R:6%N($ME:69E<@H@("`@("`\8G)I86Y`=F%L:6YO<BYN970^+@I;
M;6US72!!9&1E9"!M=6QT:7!A<G0O<F5P;W)T($U)345?5FEE=V5R.CHN"EMM
M;7-=($%D9&5D($U)344Z.F=E;F5R871E365S<V%G94E$*"D@=&\@9V5N97)A
M=&4@34E-12UC;VUP;&EA;G0@;65S<V%G92!)1',N"EMC:FA=($%D9"!C;VUM
M86YD+6QI;F4@<V5T=7`N<&AP('-C<FEP="X@4FEG:'0@;F]W+"!T:&ES(&]N
M;'D@9V5N97)A=&5S+W5P9&%T97,*("`@("`@8V]N9FEG=7)A=&EO;G,[('EO
M=2!C86YN;W0@*F5D:70J(&$@8V]N9FEG=7)A=&EO;B!W:71H(&ET+@I;:F%N
M72!!9&0@4W1R:6YG.CH@8VQA<W,@=VET:"!L;V-A;&4O8VAA<G-E="!S869E
M('-T<FEN9R!F=6YC=&EO;G,N"EMM;7-=($%D9&5D($AO<F1E.CIA=71H96YT
M:6-A=&EO;D9A:6QU<F52961I<F5C="@I+@I;;6US72!!9&1E9"!"<F]W<V5R
M.CIE<V-A<&5*4T-O9&4H*2!T;R!E<V-A<&4@8V5R=&%I;B!C:&%R86-T97)S
M(&EN"B`@("`@(&IA=F%S8W)I<'0@8V]D92!D97!E;F1I;F<@;VX@=&AE(&)R
M;W=S97(@='EP92X*6VIA;ET@061D($Y,4SHZ<W1R=&]L;W=E<B@I(&%N9"!U
M<V4@:70@979E<GEW:&5R92!W:&5R92!L;V-A;&4@:6YD97!E;F1A;F-E"B`@
M("`@(&ES(&YE8V5S<V%R>2X*6VIA;ET@061D(%1U<FMI<V@@=')A;G-L871I
M;VX@*$=E;F-O(%EI;&UA>B`\9V5N8V]Y:6QM87I`>6%H;V\N8V]M/BDN"EMM
M;7-=($%D9"`G;&EN:R<@<&%R86UE=&5R('1O('1H92!P<F5F97)E;F-E<R!C
M;VYF:6<@=&\@86QL;W<@9F]R(&AE;'`@;&EN:W,*("`@("`@=&\@8F4@861D
M960@=&\@=&AE('!R969E<F5N8V5S('!A9V5S+@I;;6US72!!;F]T:&5R($UA
M:6YT96YA;F-E.CH@<F5W<FET92`M(&YO=R!S=&]R92!A;&P@9&%T82!I;B!T
M:&4@8V%C:&5D"B`@("`@($UA:6YT96YA;F-E7U1A<VML:7-T(&]B:F5C="X*
M6VUM<UT@061D960@8VAE8VL@=&\@4')E9G,Z.B!T;R!E;G-U<F4@=&AE(&1A
M=&$@<W1O<F5D(&1O97,@;F]T(&5X8V5E9"!T:&4*("`@("`@;6%X:6UU;2!S
M=&]R86=E('-I>F4@;V8@=&AE('!R969E<F5N8V5S('-T;W)A9V4@<WES=&5M
M+@I;:F%N72!!9&0@551&+3@@<W5P<&]R="X@06YY(&-O;G1E;G0@=VET:"!A
M;GD@8VAA<G-E="!C86X@;F]W(&)E(&1I<W!L87EE9"!W:71H"B`@("`@(&%N
M>2!T<F%N<VQA=&EO;BX*6VUM<UT@061D($Y,4SHZ8VAE8VM#:&%R<V5T*"D@
M=&\@9&5T97)M:6YE('=H971H97(@82!G:79E;B!C:&%R86-T97(@<V5T(&ES
M"B`@("`@('9A;&ED(&]N('1H92!C=7)R96YT('-Y<W1E;2X*6V-J:%T@1&5P
M<F5C871E9"!296=I<W1R>3HZ:6YC;'5D949I;&5S*"D@86YD(%)E9VES=')Y
M.CIS:'5T9&]W;B@I+@I;;6US72!!9&0@<W5P<&]R="!I;B!-24U%7TUA9VEC
M.CH@=&\@=7-E('1H92!53DE8(&9I;&4@9G5N8W1I;VX@=&\@9&5T97)M:6YE
M"B`@("`@('1H92!-24U%('1Y<&4@;V8@=6YK;F]W;B!F:6QE<RX*6VUM<UT@
M061D960@86X@97AA;7!L92!C<F]N('-C<FEP="!T;R!D96QE=&4@;VQD('1E
M;7!O<F%R>2!F:6QE<RX*6VUM<UT@0V]R<F5C=&QY(&=E="!C:&%R<V5T(&EN
M9F]R;6%T:6]N(&9O<B!-24U%7U!A<G1S(&EN($U)345?4W1R=6-T=7)E+@I;
M;6US72!297=R;W1E($U)345?365S<V%G92!T;R!E>'1E;F0@34E-15]087)T
M+@I;8VIH72!!9&0@;W)D97)I;F<@97AT96YS:6]N<R!T;R!T:&4@0V%T96=O
M<GDZ.B!F<F%M97=O<FL*("`@("`@*$UA<FMO(#QM87)K;T!O8FQO+F-O;3XI
M+@I;8VIH72!!9&0@82!S:6UP;&4@=&5M<&QA=&4@96YG:6YE+"!D97)I=F5D
M(&9R;VT@8E1E;7!L871E+`H@("`@("!F;W(@2&]R9&4@87!P;&EC871I;VYS
M('1O('5S92X*6V-J:%T@061D($%U=&A?>6%H;V\Z.B!W:&EC:"!L971S('EO
M=2!H879E(&YO(&QO8V%L(&%U=&@@86YD(')E;'D@;VX*("`@("`@66%H;V\A
M(&UA:6P@=7-E<FYA;65S+@I;;6US72!-;W9E9"!397)V97(@8V]N9FEG=7)A
M=&EO;B!C:&5C:VEN9R!F=6YC=&EO;G,@=&\@4V5R=F5R.CHN"EMC:FA=(%1H
M92!U<V5R(&%D;6EN('!A9V4@8V%N(&YO=R!S970@9G5L;&YA;64@86YD(&9R
M;VU?861D<B!P<F5F97)E;F-E<PH@("`@("!F;W(@86YY('5S97(@87,@;&]N
M9R!A<R!T:&4@075T:"!B86-K96YD(&ES(&-A<&%B;&4@;V8@870@;&5A<W0*
M("`@("`@;&ES=&EN9R!U<V5R<R`H9&]E<VXG="!H879E('1O(&)E(&%B;&4@
M=&\@=7!D871E('1H96TI+@I;8VIH72!3:&%R93HZ(&ES(&YO=R!(;W)D95]3
M:&%R93HZ+"!A;F0@:7,@<F5W;W)K960@=&\@:&]L9"!P97)M:7-S:6]N<PH@
M("`@("!I;G1E<FYA;&QY+B!792!C86X@;F]W(&%S<VEG;B!G<F]U<"]D969A
M=6QT+V=U97-T('!E<FUI<W-I;VYS"B`@("`@(&UO<F4@96%S:6QY+@I;:F%N
M72!!9&0@4E!#.CIP87)S955R;"@I+@I;:F%N72!!9&0@4E!#(&)A<V5D(')E
M;6]T92!S=6UM87)I97,N"EMC:FA=($%D9"!A(%-13"!3:&5L;"!T;R!T:&4@
M2&]R9&4@861M:6X@<V5C=&EO;BX*6V-J:%T@1&]N)W0@<')E9FEX($AO<F1E
M(&%D;6EN(&UE;G5I=&5M<R!W:71H(")(;W)D92(@=&\@<V%V92!S<&%C92X*
M6V-J:%T@2&]R9&5?1F]R;3HZ(&9O<FUS(&YO=R!U<V4@=&AE($AO<F1E7U1O
M:V5N.CH@05!)(&)Y(&1E9F%U;'0@=&\*("`@("`@;6%K92!S=7)E('1H870@
M=&AE>2!C86YN;W0@8F4@<F5L;V%D960N"EMC:FA=(%)E;F%M92!4;VME;CHZ
M('1O($AO<F1E7U1O:V5N.CH@9F]R(&9U='5R92!P86-K86=I;F<N"EMJ86Y=
M($%D9"!296=I<W1R>3HZ;&ES=$%027,H*2!A;F0@4F5G:7-T<GDZ.FQI<W1-
M971H;V1S*"DN"EMC:FA=(%1H92!097)M<SHZ('-Y<W1E;2!N;W<@<W5P<&]R
M=',@9&5F875L="!A;F0@9W5E<W0@<&5R;6ES<VEO;G,N"EMC:FA=($%P<&QI
M8V%T:6]N<R!C86X@;F]W('!R;W9I9&4@:6YD:79I9'5A;"!R96=I<W1R>2!M
M971H;V1S+"!N;W0@:G5S="!W:&]L90H@("`@("!I;G1E<F9A8V5S+B!!<'!L
M:6-A=&EO;G,@8V%N(&]V97)R:61E(&$@<VEN9VQE(&UE=&AO9"!O=70@;V8@
M86X@:6YT97)F86-E"B`@("`@(&%S('=E;&P@+2!A;B!A<'`@<')O=FED:6YG
M(&$@;6%I;"]F:6QT97(@=VAI;&4@24U0('!R;W9I9&5S(&UA:6PO*BP@92YG
M+@I;8VIH72!296YA;65D($9O<FU3<')O8VME=#HZ('1O($AO<F1E7T9O<FTZ
M.B!A;F0@1W)A<&A3<')O8VME=#HZ('1O"B`@("`@($AO<F1E7T=R87!H.CH@
M9F]R(&-O;G-I<W1E;F-Y(&%N9"!F=71U<F4@4$5!4B!P86-K86=I;F<N"EMM
M:7)=($%D9&5D(&5X86UP;&4@;V8@7VEM<%]H;V]K<U]F971C:&UA:6Q?9FEL
M=&5R('1O(&-O;F9I9R]H;V]K<RYP:'`N9&ES=`I;;6US72!!9&1E9"!T:&4@
M34E-15]#;VYT96YT<SHZ(&-L87-S.R!F=6YC=&EO;G,@=&\@:&5L<"!I;B!T
M:&4@;W5T<'5T"B`@("`@(&]F($U)344@8V]N=&5N="X*6V-J:%T@4F5W<FET
M92!T:&4@0V%T96=O<GDZ.B!S>7-T96T@=&\@86QL;W<@;75L=&EP;&4@;&5A
M=F5S('=I=&@@=&AE('-A;64*("`@("`@;F%M92`H87,@;&]N9R!A<R!T:&5Y
M(&AA=F4@9&EF9F5R96YT('!A<F5N=',I(&%N9"!R97=R:71E(&5V97)Y=&AI
M;F<*("`@("`@*%!E<FUS.CHL($=R;W5P.CHL(%-H87)E.CHL(&5T8RXI('1O
M('5S92!I="X*6V-J:%T@36]V92!?9FEL94-L96%N=7`H*2!I;G1O($AO<F1E
M.CH@87,@2&]R9&4Z.F1E;&5T94%T4VAU=&1O=VXH*2P*("`@("`@86YD(&%D
M9"!(;W)D93HZ7V1E;&5T94%T4VAU=&1O=VXH*2!T;R!D;R!T:&4@86-T=6%L
M(&1E;&5T:6YG+@I;8VIH72!);FET:6%L('-U<'!O<G0@9F]R(&-O;F9I9W5R
M:6YG('1H92!S=6UM87)Y('-C<F5E;@H@("`@("`H17)I8R!296-H;&EN(#QE
M<FEC0&AP8V%L8RYO<F<^*2X*6V-J:%T@061D(&$@<WES=&5M(&9O<B!D969I
M;FEN9R!G96YE<FEC(&AO;VMS(&9O<B!A;GD@<')E9F5R96YC92X*("`@("`@
M4V5E(&AO<F1E+V-O;F9I9R]H;V]K<RYP:'`N9&ES="!F;W(@;&]T<R!O9B!E
M>&%M<&QE<R!A;F0@9&]C<RX*6V-J:%T@061D(&$@8V]L;W)P:6-K97(@=71I
M;&ET>2!T;R!(;W)D90H@("`@("`H36EC:&%E;"!#;V-H<F%N92`\;6EK94!G
M<F%F=&]N:&%L;"YC;RYN>CXI+@I;8VIH72!!9&0@82!G=65S="!S97)V:6-E
M<R!E;G1R>2!P86=E(&%N9"!L:6YK<R!T;R!I="!F<F]M(&%L;`H@("`@("!L
M;V=I;B!P86=E<RX*6VIA;ET@061D('1R86YS;&%T:6]N(&AE;'!E<B!S8W)I
M<'0N"EMM;7-=(%-T>6QE<VAE970@;&EN:R!G96YE<F%T:6]N(&AA;F1L960@
M8GD@2&]R9&4Z.G-T>6QE<VAE971,:6YK*"DN"EMC:FA=($%D9"!T:&4@;F5W
M($-O;F9I9SHZ($%022!A;F0@<V5T=7`N<&AP+"!A('-Y<W1E;2!W:&EC:"!R
M96%D<PH@("`@("!C;VYF:6=U<F%T:6]N<R!F<F]M(%A-3"!F:6QE<R!A;F0@
M97AI<W1I;F<@8V]N9BYP:'`@9FEL97,L"B`@("`@('1A:VEN9R!C87)E(&]F
M(&UE<F=E<R!A;F0@861D:6YG(&YE=R!P87)A;65T97)S+B!#=7)R96YT;'D@
M=V4*("`@("`@:&%V92!A('=E8B!W:7IA<F0N"EMC:FA=(&-S<RYP:'`@;F]W
M('-U<'!O<G1S(&QO861I;F<@0U-3(&-L87-S97,@9F]R(&UU;'1I<&QE(&%P
M<&QI8V%T:6]N<RX*6VUM<UT@4F5M;W9E9"!T:&4@4V5S<VEO;D-A8VAE(&-L
M87-S+B!%<75I=F%L96YT(&-O9&4@:7,@;F]W(&%V86EL86)L92!I;@H@("`@
M("!T:&4@0V%C:&5?<V5S<VEO;CHZ(&-L87-S+@I;;6US72!!9&1E9"!)12!B
M<F]K96XM8G)O=W-E<B!D;W=N;&]A9&EN9R!C;V1E('1O($)R;W=S97(Z.BX*
M6VUM<UT@061D960@82!S97-S:6]N(&1R:79E<B!T;R!#86-H93HZ+@I;8VIH
M72!296YA;64@8V]N9FEG+VAO<F1E+G!H<"!T;R!C;VYF:6<O8V]N9BYP:'`N
M"EMC:FA=($UO=F4@8V]O:VEE7V1O;6%I;BP@8V]O:VEE7W!A=&@L('-E<G9E
M<E]N86UE+"!A;F0@<V5R=F5R7W!O<G0@:6YT;PH@("`@("!H;W)D92]C;VYF
M+G!H<"X*6V-J:%T@061D(&$@<&%R86UE=&5R(&9O<B!S971T:6YG('1H92!S
M97-S:6]N(&-A8VAE7VQI;6ET97(N"EMC:FA=($%D9"!-24U%7U9I97=E<E]T
M97AT('1O($AO<F1E+@I;8VIH72!297=R:71E(&%L;"!F86-T;W)Y+W-I;F=L
M971O;B!M971H;V1S('1O(&%L;&]W(&EN9&EV:61U86P@87!P;&EC871I;VYS
M"B`@("`@('1O('!R;W9I9&4@82!C=7-T;VT@8F%C:V5N9"P@86YD('1O(&%L
M;&]W('-I=&5S('1O('!R;W9I9&4@8W5S=&]M"B`@("`@(&)A8VME;F1S(&EN
M('1H96ER(&EN8VQU9&5?<&%T:"!S971T:6YG<RX*6VUM<UT@2&%N9&QI;F<@
M;V8@0V]N=&5N="U4>7!E('!A<F%M971E<G,@;6]V960@=&\@34E-15]087)T
M(&9R;VT@34E-15]-97-S86=E+@I;;6US72!#<GEP=%]P9W`Z.B!C86X@;F]W
M('5P;&]A9"!K97ES('1O(&$@<'5B;&EC(&ME>7-E<G9E<BX*6VUM<UT@4F5N
M86UE9"!T:&4@3&%N9SHZ(&-L87-S('1O($Y,4SHZ(&%N9"!M;W9E9"!T:&4@
M=&EM97IO;F4@<V5T=&EN9PH@("`@("!M971H;V0@:6YT;R!I="X*6VUM<UT@
M5&AE(&QO8V%L('1I;65Z;VYE(&-A;B!N;W<@8F4@<V5T('9I82!T:&4@2&]R
M9&4Z.G-E=%1I;65Z;VYE*"D@8V%L;"X*6VUM<UT@06QL(&)R;W=S97(@:&5A
M9&5R<R!F;W(@9&]W;FQO861I;F<@82!F:6QE(&AA=F4@8F5E;B!M;W9E9"!T
M;R!T:&4*("`@("`@0G)O=W-E<CHZ(&-L87-S+@I;8VIH72!!9&0@9FEL97,@
M=&\@=71I;"!T;R!S=7!P;W)T(&5M8F5D9&EN9R!A($=522!E9&ET;W(@:6YT
M;R!O=7(@<&%G97,N"EMM;7-=($U)344Z.B!N;R!L;VYG97(@97AP;W)T<R`D
M;6EM95]T>7!E<R!A;F0@)&UI;65?96YC;V1I;F=S(&%S(&=L;V)A;`H@("`@
M("!V87)I86)L97,@+2!R871H97(L($U)344Z.G1Y<&4H*2!A;F0@34E-13HZ
M96YC;V1I;F<H*2!S:&]U;&0@8F4@=7-E9"X*6VUM<UT@5&AE('1G>B!-24U%
M7U9I97=E<B!N;W<@;&ES=',@86QL(&9I;&5S('=I=&AO=70@=7-I;F<@86X@
M97AT97)N86P@:&5L<&5R"B`@("`@('!R;V=R86T@*$UI8VAA96P@0V]C:')A
M;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUM<UT@5&AE(')A<B!-
M24U%7U9I97=E<B!N;W<@;&ES=',@86QL(&9I;&5S('=I=&AO=70@=7-I;F<@
M86X@97AT97)N86P@:&5L<&5R"B`@("`@('!R;V=R86T@*$UI8VAA96P@0V]C
M:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUM<UT@5&AE('II
M<"!-24U%7U9I97=E<B!N;W<@;&ES=',@86QL(&9I;&5S('=I=&AO=70@=7-I
M;F<@86X@97AT97)N86P@:&5L<&5R"B`@("`@('!R;V=R86T@*$UI8VAA96P@
M0V]C:')A;F4@/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUM<UT@36%I
M;G1E;F%N8V4Z.B!N;W<@=7-E<R!S97-S:6]N('9A<FEA8FQE<R!T;R!P<F]V
M:61E(&UU8V@@8VQE86YE<B!A;F0@;6]R90H@("`@("!R;V)U<W0@<&5R9F]R
M;6%N8V4N"EMM;7-=($U3+51.148@871T86-H;65N=',@87)E(&YO=R!H86YD
M;&5D(&-O;7!L971E;'D@=FEA(%!(4"!R871H97(@=&AA;B!W:71H"B`@("`@
M(&%N(&5X=&5R;F%L('!R;V=R86TN"EMM;7-=($%D9&5D(&%P<&QI8V%T:6]N
M+VUS+71N968@34E-15]6:65W97(N"EMM;7-=($AO<F1E7T-R>7!T7W!G<"!C
M;&%S<R!C86X@<75E<GD@<'5B;&EC(&ME>7-E<G9E<G,N"EMM;7-=($U)345?
M4W1R=6-T=7)E.CIP87)S94U)345(96%D97)S*"D@8V%N(&YO=R!P87)S92!A
M;&P@:&5A9&5R<R!O9B!A($U)344*("`@("`@;65S<V%G92!A;F0@<F5T=7)N
M(&%N(&]B:F5C="X*6VIA;ET@061D($U)344Z.G)F8S@R,E=R:71E061D<F5S
M<R@I('1O(')E<&QA8V4@:6UA<%]R9F,X,C)?=W)I=&5?861D<F5S<R@I+@I;
M;6US72!!9&1E9"!3+TU)344@34E-15]6:65W97(N"EMJ;VY=(%-U<'!O<G0@
M<F5F97)R86QS(&)E='=E96X@3$1!4"!S97)V97)S(&EN('1H92!,1$%0('!R
M969E<F5N8V5S(&1R:79E<@H@("`@("`H2V5V:6X@2&EL9&5B<F%N9"`\:V5V
M:6Y`:'$N96YS;W!O<G0N8V]M/BDN"EMC:FA=($U)345?4W1R=6-T=7)E.CIP
M87)S92@I(&YO=R!R971U<FYS(&$@34E-15]-97-S86=E(&]B:F5C=`H@("`@
M("`H36EC:&%E;"!-(%-L=7-A<GH@/'-L=7-A<GI`8FEG=V]R;2YC;VQO<F%D
M;RYE9'4^*2X*6V-J:%T@0V]N9FEG=7)E(&%D;6EN:7-T<F%T:6]N('-E<G9I
M8V5S(&EN('1H92!296=I<W1R>0H@("`@("`H36%R8W5S($DN(%)Y86X@/&UA
M<F-U<T!R:6)O9FQA=FEN+FYE=#XI+@I;8VIH72!!9&0@05!)(&UE=&AO9',@
M9F]R(&=E='1I;F<@=&AE('!R969E<F5N8V5S(&%N9"!I9&5N=&ET:65S(&]F
M('5S97)S"B`@("`@(&]T:&5R('1H86X@=&AE(&QO9V=E9"UI;B!U<V5R+@I;
M8VIH72!!;&QO=R!S971T:6YG('1H92!#;VYT96YT+41I<W!O<VET:6]N(&]F
M($U)345?4&%R="!O8FIE8W1S+@I;8VIH72!!9&0@0W)Y<'0Z.B!F<F%M97=O
M<FL@*$UI8VAA96P@32!3;'5S87)Z(#QS;'5S87)Z0&)I9W=O<FTN8V]L;W)A
M9&\N961U/BDN"EMM87A=($%D9"!"<F]W;B!(;W)D92!T:&5M92`H36%R8V\@
M3V)A:60@/&UA<F-O0&UU=RYE9'4^*2X*6VIO;ET@06QL;W<@=&AE($Q$05`@
M=F5R<VEO;B!T;R!B92!S<&5C:69I960@9F]R('1H92!,1$%0('!R969E<F5N
M8V5S(&1R:79E<BX*6VIA;ET@061D('1H96UE('!R969E<F5N8V4N"EMJ86Y=
M($%D9"!C86QL8F%C:R!F=6YT:6]N(&9O<B!P<F5F97)E;F-E<RX*6VIO;ET@
M4F5M;W9E('1H92`D8V]N9ELG;65N=2==6R=F;&]A=&EN9U]B87(G72!F=6YC
M=&EO;F%L:71Y+@I;:F%N72!,;V%D(&]N;'D@;&]G:6X@<&%G92!O;B!S=&%R
M='5P(&%N9"!R961I<F5C="!T;R!F<F%M97-E="!A9G1E<B!L;V=I;BX*6V-J
M:%T@1&]N)W0@86QL;W<@86YO;GEM;W5S(&%C8V5S<R!T;R!P<F]B;&5M+G!H
M<"X*6V-J:%T@061D(&5N7T="(&QO8V%L92X*6V-J:%T@4F5M;W9E(&5X=&5N
M<VEO;G,@;VX@=&5M<&]R87)Y(&9I;&5S.R!T:&ES(&ES(&$@=&5M<"!R86-E
M(&AO;&4N"EMC:FA=($%L;&]W(&9O<B!A=71O+6-R96%T:6]N(&]F('!E<FUI
M<W-I;VYS("AM=6QT:7!L92!L979E;',@;V8@:&EE<F%R8VAY*2X*6V-J:%T@
M061D(&%D9&EN9R]R96UO=FEN9R!O9B!U<V5R<R!F<F]M(&=R;W5P<RX*6V-J
M:%T@0W)E871E('1E;7`@9FEL97,@=VET:"!T:&4@<FEG:'0@97AT96YS:6]N
M(&EN($U)345?5FEE=V5R7V5N<V-R:7!T.CH@<V\*("`@("`@96YS8W)I<'0@
M:&%S(&UO<F4@8VQU97,@=&\@9W5E<W,@9FEL92!T>7!E+@I;8VIH72!4:&4@
M861M:6YI;G-T<F%T:6]N(&EN=&5R9F%C92!F;W(@1W)O=7!S(&%N9"!097)M
M:7-S:6]N<R!I<R!N;W<*("`@("`@;6]S=&QY(&9U;F-T:6]N86PN"EMC:FA=
M($UA:V4@87!P;&EC871I;VX@875T:&5N=&EC871I;VX@86X@075T:#HZ(&1R
M:79E<BP@:6YS=&5A9"!O9B!A('-P96-I86P*("`@("`@4F5G:7-T<GD@8V%S
M92X*6V-J:%T@1FEX('!R;V)L96US('=I=&@@=&AE($YO=&EF:6-A=&EO;B!S
M=&%C:R!A;F0@<F5G:7-T97)?9VQO8F%L<R!B96EN9R!O9F8N"EMJ;VY=($%L
M=&5R($AO<F1E.CII;6<H*2!T;R!E>'!L:6-I=&QY(&%C8V5P="!A;B!A;'0]
M(B(@871T<FEB=71E+@H@("`@("!(;W)D93HZ:6UG*"D@;F]W(&=E;F5R871E
M<R!T:71L93TB(B!A='1R:6)U=&5S(&)A<V5D(&]N('1H92!A;'0](B(@=&5X
M="P*("`@("`@=&]O+@I;8VIH72!.;W1I9FEC871I;VXZ.FYO=&EF>2@I('!A
M<W-E<R!T:&4@;65S<V%G92!S=&%C:R!T;R!A;&P@;&ES=&5N97)S+"!S;R!T
M:&%T"B`@("`@(&QI<W1E;F5R<R!D;VXG="!H879E('1O(&MN;W<@86)O=70@
M=&AE(&UE<W-A9V4@<W1A8VLL(&%N9"!A<'`@=W)I=&5R<PH@("`@("!D;VXG
M="!H879E('1O(&MN;W<@86)O=70@86QL('!O<W-I8FQE(&QI<W1E;F5R<RX*
M6V-J:%T@4F5P;&%C92!T:&4@2$]21$5?*B!M97-S86=E(&-O;G-T86YT<R!W
M:71H("=H;W)D92YE<G)O<B<L(&5T8RX@9F]R"B`@("`@(&=R96%T97(@9FQE
M>&EB:6QI='DN"EMC:FA=(%)E;6]V92!(;W)D93HZ<F%I<V5-97-S86=E*"D@
M;F]W('1H870@=&AE($YO=&EF:6-A=&EO;B!S>7-T96T*("`@("`@<')O=FED
M97,@=&AA="!F=6YC=&EO;F%L:71Y+@I;8VIH72!5<V4@=&AE(&YE=R!.;W1I
M9FEC871I;VX@<WES=&5M+@I;8VIH72!296UO=F4@;W1H97(@4F5G:7-T<GD@
M9V5T*"D@;65T:&]D<RX*6VIO;ET@4F5M;W9E('-U<'!O<G0@9F]R('1H92!H
M;W)D95]L86YG=6%G92!C;V]K:64N"EMJ86Y=($UO=F4@=&AE(&UA:6YT96YA
M8V4@9G)A;65W;W)K(&9R;VT@24U0('1O($AO<F1E("A-:6-H865L($T@4VQU
M<V%R>@H@("`@("`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3XI+@H*
M"BTM+2TM+0IV,BXR+CD*+2TM+2TM"@I;:F%N72!314-54DE463H@1FEX('!O
M=&5N=&EA;"!84U,@=G5L;F5R86)I;&ET>2!D=64@=&\@;F]T('!R;W!E<FQY
M(&5S8V%P960*("`@("`@97)R;W(@;65S<V%G97,N"@H*+2TM+2TM"G8R+C(N
M.`HM+2TM+2T*"EMJ86Y=(%-%0U522519.B!#;&]S92!84U,@=VAE;B!S971T
M:6YG('1H92!P87)E;G0@9G)A;64G<R!P86=E('1I=&QE(&)Y"B`@("`@(&IA
M=F%S8W)I<'0@*&-J:"DN"@H*+2TM+2TM"G8R+C(N-PHM+2TM+2T*"EMC:FA=
M(%)E<W1O<F4@8V]M<&%T:6)I;&ET>2!W:71H(%!(4"`T+C$N"EMJ86Y=(%-%
M0U522519.B!&:7@@<&]T96YT:6%L(%A34R!V=6QN97)A8FEL:71Y(&EN('1H
M92!H96QP('=I;F1O=RX*6VIA;ET@1FEX(&-H87)S970@9F]R($QA='9I86X@
M=')A;G-L871I;VX@*$)U9R`C-C4V*2X*"@HM+2TM+2T*=C(N,BXV"BTM+2TM
M+0H*6VIA;ET@57-E($1".CIP<F5P87)E+T1".CIE>&5C=71E($].3%D@9F]R
M($]R86-L92!T;R!A=F]I9"!I;7!L:6-I=&QY(')E<75I<FEN9PH@("`@("!0
M2%`@-"XR(&9O<B!A;&P@;W1H97(@4D1"37,N"EMC:FA=($9I>"!/<F%C;&4@
M<V5S<VEO;B!H86YD;&5R+@I;8VIH72!!9&0@4U%,('-C<FEP=',@9F]R($]R
M86-L92!A;F0@4&]S=&=R95-13"!S97-S:6]N(&AA;F1L97)S+@I;:F%N72!$
M;VXG="!S=')I<"!T<F%I;&EN9R!S<&%C97,@9G)O;2!S:6=N871U<F4@9&%S
M:&5S(&EN($E-4"X*"@HM+2TM+2TM+2TM"G8R+C(N-BU20S$*+2TM+2TM+2TM
M+0H*6V-J:%T@1FEX('-U<'!O<G0@9F]R(&-U<W1O;2!S97-S:6]N(&AA;F1L
M97)S+@I;8VIH72!5<V4@1$(Z.G!R97!A<F4O1$(Z.F5X96-U=&4@:6X@=&AE
M(%!R969S7W-Q;"!D<FEV97(@9F]R(&)E='1E<B!S=7!P;W)T"B`@("`@(&]F
M(&QA<F=E(&9I96QD<R!O;B!D871A8F%S97,@<W5C:"!A<R!/<F%C;&4N"EMJ
M86Y=(%-H;W<@=&AE('5S97(G<R!F=6QL(&YA;64@;VX@=&AE('-U;6UA<GD@
M<V-R965N(&1I<F5C=&QY(&%F=&5R(&QO9V=I;F<*("`@("`@:6X@*$0N($%D
M86T@2V%R:6T@/&%D86U`86MA<G-O9G0N8V]M/BDN"EMJ86Y=($9I>"!J879A
M<V-R:7!T(&5R<F]R(&EN(")0<F]B;&5M(B!P86=E('=I=&@@<V]M92!T<F%N
M<VQA=&EO;G,@*$)U9R`C-C$I+@I;8VIH72!&:7@@:&%N9&QI;F<@;V8@4&]S
M=&=R95-13"!B;&]B<R`H0G5G(",T-"DN"@H*+2TM+2TM"G8R+C(N-0HM+2TM
M+2T*"EMJ86Y=($%D9"!);F1O;F5S:6%N(&QA;F=U86=E("A3;&%M:6X@/'-L
M86UI;D!U;F5J+F%C+FED/BDN"EMJ86Y=($%D9"!'86QI8VEA;B!T<F%N<VQA
M=&EO;B`H4F%F865L(%9A<F5L82!0970@/'-R<F%F84!U<V,N97,^+"!'=6EL
M;&5R;6\*("`@("`@365N9&5Z(#QG=6EL;&5`=7-C+F5S/BDN"EMM;7-=($9I
M>"!D;W=N;&]A9&EN9R!O9B!F:6QE<R!W:71H('-P86-E<R!I;B!-;WII;&QA
M+@H*"BTM+2TM+0IV,BXR+C0*+2TM+2TM"@I;;61J72!314-54DE463H@061D
M(&1E<F5F97)E<B!T;R!S=')I<"!O9F8@<V5S<VEO;B!I;F9O<FUA=&EO;B!F
M<F]M(&QI;FMS('1O"B`@("`@('1H92!O=71S:61E(&]F('1H92!(;W)D92!S
M>7-T96T@=&\@<')O=&5C="!A9V%I;G-T('-E<W-I;VX@:&EJ86-K:6YG+@I;
M;6US72!314-54DE463H@061D(&-O9&4@=&\@<')O=&5C="!A9V%I;G-T('-E
M<W-I;VX@9FEX871I;VX@:7-S=65S+@I;:F%N72!&:7@@82!B=6<@=VET:"!I
M;7!O<G1I;F<@=D-A<F0@,BXQ(&1A=&$N"EMJ86Y=($%D9"!!<F%B:6,@*%-Y
M<FEA*2!T<F%N<VQA=&EO;B`H4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;0H@
M("`@("`\9&5V=&5A;4!P;&%T:6YU;2US>2YN970^*2X*6VIA;ET@061D($UA
M8V5D;VYI86X@=')A;G-L871I;VX@*%-T;VIA;B!097-O=B`\<W-P0&5U<F5K
M82YC;VTN;6L^*2X*6VUI<ET@1FEX(&$@8G5G('1H870@:6YC;W)R96-T;'D@
M<75O=&5S('!R968@=F%L=65S("A"=6<@(S$R,C0I"EMC:FA=($9I>"!A(&)U
M9R!T:&%T('!R979E;G1E9"!L;V=G:6YG+@I;;6US72!$0B!S97-S:6]N(&AA
M;F1L97)S(&1O(&YO="!U<V4@<&5R<VES=&5N="!C;VYN96-T:6]N<R!B>2!D
M969A=6QT+@H*"BTM+2TM+0IV,BXR+C,*+2TM+2TM"@I;;6US72!&:7@@<&%R
M<V4@97)R;W(@:6X@2&]R9&5?0VEP:&5R7T)L;V-K36]D95]O9F(V-#HZ+@H*
M"BTM+2TM+0IV,BXR+C(*+2TM+2TM"@I;;6US72!/<'1I;6EZ871I;VX@;V8@
M4V5C<F5T.CH@86YD($AO<F1E7T-I<&AE<CHZ(&1R:79E<G,N"EMJ86Y=($%D
M9"!#871A;&%N('1R86YS;&%T:6]N("A!;F=E;',@1W5I;65RX"`\86YG96QS
M+D=U:6UE<F%`=6%B+F5S/BDN"EMM;7-=($%D9&5D(&$@4D%$2553($%U=&@Z
M.B!D<FEV97(N"EMM:7)=($%D9&5D(&$@4V%M8F$@075T:#HZ(&1R:79E<BX*
M6V-J:%T@061D960@=&AE($AO<F1E7TEM86=E.CH@8VQA<W,N"@H*+2TM+2TM
M"G8R+C(N,0HM+2TM+2T*"EMJ86Y=($9I>"!I;F-O;7!A=&EB:6QI='D@=VET
M:"!02%`@/"`T+C(N,"!I;B!T:&4@4U%,(%9&4R!D<FEV97(N"EMJ86Y=($9I
M>"!U;F1E9FEN960@=F%R:6%B;&4@:6X@0VEP:&5R+G!H<"`H8VIH*2X*6VUM
M<UT@0V]M<&QE=&4@;65R9VEN9R!O9B!344P@<V5S<VEO;B!H86YD;&5R+@H*
M"BTM+2T*=C(N,@HM+2TM"@I;8VIH72!!9&0@<W5P<&]R="!F;W(@=7-E<BUD
M969I;F5D('-E<W-I;VX@:&%N9&QE<G,*("`@("`@*$UI:V4@0V]C:')A;F4@
M/&UI:V5`9W)A9G1O;FAA;&PN8V\N;GH^*2X*6VUA8UT@0VAA;F=E(%-E8W)E
M=#HZ(&9R;VT@=7-I;F<@4$5!4B!#<GEP=%](0T5-1#4@=&\@=&AE($AO<F1E
M7T-I<&AE<B!C;&%S<RX*6VUA8UT@061D($AO<F1E7T-I<&AE<CHZ(&-L87-S
M('1O('!R;W9I9&4@82!C;VUM;VX@86)S=')A8W1E9"!I;G1E<F9A8V4@=&\*
M("`@("`@=F%R:6]U<R!#:7!H97)S(&9O<B!E;F-R>7!T:6]N(&]F(&%R8FET
M<F%R>2!L96YG=&@@<&EE8V5S(&]F(&1A=&$N"EMM;7-=($-O<G)E8W1L>2!G
M970@8VAA<G-E="!I;F9O<FUA=&EO;B!F;W(@34E-15]087)T<R!I;B!-24U%
M7U-T<G5C='5R92X*6VIA;ET@061D($QA='9I86X@=')A;G-L871I;VX@*$MA
M<W!A<G,@2V%P96YI96MS(#QK87-P87)S0')C8RYL=CXI+@I;:F%N72!!9&0@
M4F]M86YI86X@=')A;G-L871I;VX@*$-O<FYE;&EU($U54T%4(#QC;75S871`
M=&EA;6%T+FME>7-Y<RYR;SXI+@I;:F]N72!!9&1E9"!S=7!P;W)T(&9O<B!A
M;B`\97)E9CX@96YT:71Y('1O('1H92!H96QP('-Y<W1E;2X@(%1H:7,@86QL
M;W=S(&%N"B`@("`@(&5X=&5R;F%L(&QI;FL@=&\@8F4@96UB961D960@:6X@
M82!H96QP(&5N=')Y+B`H/&<N:&]R=$!U;G-W+F5D=2YA=3XI"EMC:FA=(%)E
M;F%M92!61E,Z.B!T;R!(;W)D95]61E,Z.B!F;W(@4$5!4B!P86-K86=I;F<N
M"EMC:FA=(%9&4SHZ(&ES(&YO=R!P86-K86=E9"!S;R!T:&%T(&ET(&-A;B!B
M92!E>'!O<G1E9"!A<R!A(%!%05(@8V]M<&]N96YT+@I;8VIH72!!9&0@82!M
M=6QT:2UU<V5R(%-13"!61E,@8F%C:V5N9"`H36EK92!#;V-H<F%N92`\;6EK
M94!G<F%F=&]N:&%L;"YC;RYN>CXI+@I;8VIH72!4:&4@5D93(&%P:2!N;W<@
M8V]N<VES=&5N=&QY('1A:V5S(&$@=&5M<"!F:6QE(&EN('1H92!W<FET92@I
M(&UE=&AO9`H@("`@("!A8W)O<W,@86QL(&)A8VME;F1S("A-:6-H865L(%9A
M<F=H97-E(#QM:6ME+G9A<F=H97-E0&%S8V5L;&%T96-H+F-O;3XI+@I;8VIH
M72!!9&0@82!61E,@05!)(&9O<B!S=&]R86=E(&]F(&9I;&5S(&EN(&%N(&%B
M<W1R86-T960@9FEL97-Y<W1E;2X*6V-J:%T@061D(&$@<')E9F5R96YC92!T
M;R!A;&QO=R!M86EN=&5N86YC92!O<',@=VET:"!N;R!C;VYF:7)M871I;VX@
M<V-R965N"EMC:FA=(%)E<&QA8V4@)W-H;W<G(&%T=')I8G5T92!I;B!T:&4@
M<F5G:7-T<GD@=VET:"!A(&UO<F4@9FQE>&EB;&4@)W-T871E)PH@("`@("!A
M='1R:6)U=&4N"EMJ86Y=($%L;&]W('-E='1I;F<@=&AE(&YU;6)E<B!O9B!C
M;VQU;6YS(&EN('1H92!S=6UM87)Y('-C<F5E;B!A<R!A('5S97(*("`@("`@
M<')E9F5R96YC92`H0G)I86X@2V5I9F5R(#QB<FEA;D!V86QI;F]R+FYE=#XI
M+@I;8VIH72!!9&0@2&]R9&4Z.F=E=$=E="@I(&%N9"!(;W)D93HZ9V5T4&]S
M="@I+@I;8VIH72!!9&0@86X@:6YI=&EA;%]A<'!L:6-A=&EO;B!P<F5F97)E
M;F-E('-O('5S97)S(&-A;B!S96QE8W0@86X@87!P"B`@("`@('1O(&)E('1A
M:V5N('1O(&EN<W1E860@;V8@=&AE($AO<F1E(%-U;6UA<GD@;VX@;&]G:6XN
M"EMC:FA=($UA:V4@=&5X="P@:6-O;BP@;W(@8F]T:"!M96YU<R!A('5S97(@
M<')E9F5R96YC90H@("`@("`H2V%A;$@A(#QK86%L:$!S;6]L+F]R9SXI+@I;
M8VIH72!!9&0@82!P87)A;65T97(@9F]R('-E='1I;F<@=&AE('-E<W-I;VX@
M=&EM96]U="X*6V-J:%T@061D(&$@<&%R86UE=&5R(&9O<B!S971T:6YG('1H
M92!S97-S:6]N(&1E;&EM:71E<BX*6VUM<UT@061D($U)345?36%G:6,Z.F9I
M;&5N86UE5&]-24U%*"DN"EMJ86Y=(%5S92!A<F=?<V5P87)A=&]R+F]U='!U
M="!I;G-T96%D(&]F(&AA<F1C;V1I;F<@)R8G("A$879I9"!5;&5V:71C:`H@
M("`@("`\9&%V:61U0&5V97)Y9&YS+FYE=#XI+@I;:F%N72!!9&0@3F]T:69I
M8V%T:6]N.CIC;W5N="@I("A$879I9"!5;&5V:71C:"`\9&%V:61U0&5V97)Y
M9&YS+FYE=#XI+@I;8VIH72!!9&0@075T:#HZ:7-!9&UI;B@I+@I;8VIH72!!
M;&QO=R!L;V%D:6YG(&]F('-U8BUC;&%S<V5S(&9R;VT@<V5V97)A;"!A9&1I
M=&EO;F%L('-O=7)C97,N"EMJ86Y=(%)E;6]V92!R969E<F5N8V5S('1O(&YO
M="!Y970@<F5L96%S960@87!P;&EC871I;VYS("A';VQL96TL(%1R;VQL*2X*
M6V-J:%T@4F5W<FET92!#871E9V]R>5]S<6P@:6UP;&5M96YT871I;VX@=&\@
M8F4@;75C:"!M;W)E(&5F9FEC:65N="X*6VIA;ET@061D($QI=&AU86YI86X@
M=')A;G-L871I;VX@*$1A<FEU<R!-871U;&EA=7-K87,@/&1A<FEU<T!L;FLN
M;'0^*2X*6VUM<UT@061D($AO<F1E.CIC;VUP<F5S<T]U='!U="@I+@I;;6US
M72!!9&0@82!K97)B97)O<R!!=71H.CH@9')I=F5R+@I;:F%N72!!9&0@0G5L
M9V%R:6%N('1R86YS;&%T:6]N("A-:7)O<VQA=B!096YD978@/'!E;F1E=D!H
M;W1M86EL+F-O;3XI+@I;:F%N72!296UO=F4@9&5P<F5C871E9"!$0CHZ:7-7
M87)N:6YG*"D@8V%L;',N"EMM;7-=($%D9"!(;W)D93HZ8W)E871E5&5M<$1I
M<B@I+@I;8VIH72!!9&0@2&]R9&4Z.G5S:6YG4U-,0V]N;F5C=&EO;B@I+@I;
M8VIH72!297!L86-E(#P_/2!W:71H(#P_<&AP(&5C:&\@=&\@<F5M;W9E('1H
M92!S:&]R=%]O<&5N7W1A9W,@<F5Q=6ER96UE;G0N"EMJ86Y=($%D9"!497AT
M.CIT;TA434PH*2P@5&5X=#HZ:&EG:&QI9VAT475O=&5S*"D@86YD(%1E>'0Z
M.F1I;5-I9VYA='5R92@I+@I;8VIH72!!9&0@4F5G:7-T<GDZ.FQI<W1!<'!S
M*"DN"EMC:FA=($%D9"!0<F5F<SHZ9V5T4')E9B@I(&9O<B!G971T:6YG('!R
M969E<F5N8V5S(&9O<B!S;VUE;VYE(&]T:&5R('1H86X@=&AE"B`@("`@(&QO
M9V=E9"UI;B!U<V5R+@I;8VIH72!!9&0@=&AE(&%B:6QI='D@=&\@;&]A9"!I
M9&5N=&ET:65S(&9O<B!S;VUE;VYE(&]T:&5R('1H86X@=&AE(&QO9V=E9"UI
M;@H@("`@("!U<V5R+@I;;6US72!!9&0@2&]R9&4Z.G)E;6]V95!A<F%M971E
M<B@I+@I;;6US72!!;&P@8G)O=W-E<B!H96%D97)S(&9O<B!D;W=N;&]A9&EN
M9R!A(&9I;&4@:&%V92!B965N(&UO=F5D('1O('1H90H@("`@("!"<F]W<V5R
M.CH@8VQA<W,N"EMJ86Y=($%D9"!D971E8W1I;VX@9F]R(%541B!C87!A8FEL
M:71Y('1O($)R;W=S97(@8VQA<W,N"EMM;7-=($%D9&5D(&EM86=E<R!-24U%
M7U9I97=E<BX*6V)J;ET@061D(%!O<W1G<F5344P@8V]M;6%N9"!F;&%G("A2
M:6-H87)D($<@2V]N;&]N(#Q21TMO;FQO;D`Q36%I;%!L86-E+F-O;3XI+@H*
M"BTM+2T*=C(N,0HM+2TM"@I;:F%N72!!9&0@2'5N9V%R:6%N('1R86YS;&%T
M:6]N("A,87-Z;&\@3"X@5&]R;F]C:2`\=&]R;&%S>D!X96YI82YS;W1E+FAU
M/BDN"EMJ86Y=($%D9"!.;W)W96=I86X@3GEN;W)S:R!T<F%N<VQA=&EO;B`H
M4&5R+5-T:6%N(%9A=&YE(#QP<W9`;W)S=&$N;W)G/BDN"EMJ;VY=($UA:F]R
M(&]V97)H875L('1O('1H92!,1$%0('!R969E<F5N8V5S(&1R:79E<BX@3F]T
M92!T:&4@8VAA;F=E<R!T;PH@("`@("!C;VYF:6<O:&]R9&4N<&AP(&%N9"!S
M8W)I<'1S+VQD87`O:&]R9&4N<V-H96UA('=H96X@=7!G<F%D:6YG+@I;:F%N
M72!!9&0@4VQO=F5N:6%N('1R86YS;&%T:6]N("A*=7)E($MR87-O=FEC(#QJ
M=7)E:T!R8V,M:7)C+G-I/BDN"EMC:FA=($%D9"!A($AO<F1E('!R969E<F5N
M8V5S('-C<F5E;BP@86YD(&$@<')E9F5R96YC92!T;R!R969R97-H('1H92!S
M=6UM87)Y"B`@("`@('-C<F5E;BX*6V-J:%T@061D('1E>'0O96YR:6-H960@
M34E-15]6:65W97(*("`@("`@*$5R:6,@4F]S=&5T=&5R(#QE<FEC+G)O<W1E
M='1E<D!P:'ES:6-S+G5T97AA<RYE9'4^*2X*6VIA;ET@26UP<F]V92!L86YG
M=6%G92!S96QE8W1I;VXN"EMJ86Y=($%D9"!*87!A;F5S92!T<F%N<VQA=&EO
M;B`H0BY*+B!";&%C:R`\=VEL;&EA;2YB;&%C:T!S=6XN8V]M/BDN"EMC:FA=
M($-L;W-E(&$@<&]T96YT:6%L('!R;V)L96T@=VET:"!R96=I<W1E<E]G;&]B
M86QS($]N(&%N9"`D:G-?;VY,;V%D+@I;:F%N72!!9&0@4')E9G,Z.FES1&5F
M875L="@I(&UE=&AO9"!T;R!D971E<FUI;F4@:68@82!P<F5F97)E;F-E)W,@
M=F%L=64@:7,*("`@("`@<V5T(&)Y('1H92!U<V5R(&]R('1H92!D969A=6QT
M('9A;'5E(&9R;VT@<')E9G,N<&AP+@I;:F]N72!/=F5R:&%U;&5D($Q$05`@
M<')E9F5R96YC97,@9')I=F5R+@I;8VIH72!-86ME($AO<F1E.CID:7-P96Q-
M86=I8U%U;W1E<R@I(')E8W5R<VEV92P@<V\@=&AA="!I="!H86YD;&5S(&%R
M<F%Y<RX*6V-J:%T@2&%V92!396-R970Z.G-E=$ME>2@I(&-H96-K(&9O<B!T
M:&4@<V5S<VEO;B!C;V]K:64@97AP;&EC:71L>2P@=&\@879O:60*("`@("`@
M<')O8FQE;7,@=VET:"!O;&0@8V]O:VEE<R!B96EN9R!S96YT('1O(&$@<VET
M92!W:&5N('1H97D@87)E(')E86QL>0H@("`@("!D:7-A8FQE9"X*6V-J:%T@
M061D(&$@4')E9G-522!C;&%S<R!F;W(@:&%N9&QI;F<@=&AE(&9O<FT@<')O
M8V5S<VEN9R!A;F0@54D@9V5N97)A=&EO;@H@("`@("!F;W(@=7-E<B!P<F5F
M97)E;F-E<SL@=&AI<R!C;V1E('=A<R!D=7!L:6-A=&5D(&%L;"!T:')O=6=H
M($AO<F1E+@I;8VIH72!!9&0@82!M87!P:6YG(&9U;F-T:6]N('1O('1H92!E
M;G-C<FEP="!D<FEV97(@=VAI8V@@;6%P<R!F:6QE"B`@("`@(&5X=&5N<VEO
M;G,@=&\@96YS8W)I<'0@;&%N9W5A9V4@8V]D97,L(&%N9"!P87-S('1H92!L
M86YG=6%G90H@("`@("!D:7)E8W1L>2!T;R!E;G-C<FEP="P@=&\@879O:60@
M:&%V:6YG('1O('5S92!A(&9I;&4@97AT96YS:6]N+@I;8VIH72!&:7@@34E-
M15]-86=I8SHZ34E-151O17AT*"D@=&\@=V]R:R!W:71H('@M97AT96YS:6]N
M+V5X="!T>7!E<RX*6V-J:%T@061D($U)345?36%G:6,Z.DU)3454;T5X="@I
M('1O(&UA<"!-24U%('1Y<&5S('1O(&9I;&4@97AT96YS:6]N<RX*6V-J:%T@
M4F5W<FET92!097)M<SHZ('1O('5S92!T:&4@0V%T96=O<FEE<R!B86-K96YD
M+@I;:F%N72!#:&%N9V4@=&AE($YO<G=E9VEA;B!";VMM86P@;&]C86QE(&9R
M;VT@;F]?0D]+('1O(&YB7TY/(&%N9"!M86ME(&ET('1H90H@("`@("!D969A
M=6QT(&QA;F=U86=E(&9O<B!.;W)W96=I86X@=7-E<G,N"EMC:FA=($UA:V4@
M2&]R9&4G<R!L;V=I;B!S8W)E96X@;FEC97([(&EN8VQU9&4@<F5A<V]N<R!I
M;B!I="X*6V-J:%T@57-E($A/4D1%7U1%35!,051%4R!F;W(@86QL('1E;7!L
M871E('!A=&AS+@I;8VIH72!5<V4@)')E9VES=')Y+3YG970H*2!F;W(@86QL
M(%)E9VES=')Y(&EN9F]R;6%T:6]N+@I;8VIH72!296UO=F5D(&%D;6EN:7-T
M<F%T:6]N(&-O9&4@=VAI8V@@:7,@:6YC;VUP;&5T92!A;F0@8V]N9G5S:6YG
M('1O('5S97)S+@I;:F%N72!!9&0@17-T;VYI86X@=')A;G-L871I;VX@*%1O
M;VUA<R!!87,@/'1O;VUA<RYA87-`<F%A9"YT87)T=2YE93XI+@I;:F%N72!!
M9&0@4VQO=F%K('1R86YS;&%T:6]N("A,96\@37)A9FMO(#QL96]`;V5L+G-K
M/BDN"EMJ;VY=($5N86)L92!T:&4@(G!O<G1A8FEL:71Y(B!O<'1I;VX@:6X@
M=&AE(%!%05(@1$(@*'-Q;"D@9')I=F5R<RX*6V-J:%T@57-E($AO<F1E)W,@
M)VEN:71I86Q?<&%G92<@8V]N9FEG=7)A=&EO;B!V86QU92!I;B!T:&4@2&]R
M9&4@9G)A;65S970N"EMJ86Y=($%D9"!0;W)T=6=U97,@=')A;G-L871I;VX@
M*$YU;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T/BDN"EMJ86Y=(%)E8G5I;&0@
M=&AE(&QA;F=U86=E('-E;&5C=&EO;B!L;V=I8RX@5&AE(&QA;F=U86=E('-E
M;&5C=&5D(&]N('1H92!L;V=I;@H@("`@("!S8W)E96X@:7,@;F]W(')E<W!E
M8W1E9"!A;F0@=&AE('-I=&4G<R!S=&%N9&%R9"!L86YG=6%G92!I<R!D969I
M;F5D(&EN"B`@("`@(&QA;F<N<&AP(&EN<W1E860@;V8@96%C:"!A<'!L:6-A
M=&EO;B=S('!R969E<F5N8V5S+@I;:F%N72!!9&0@:F%V87-C<FEP="!T;R!S
M970@=&AE(&9R86UE<V5T)W,@<&%G92!T:71L92`H36EC:&%E;"!#;V-H<F%N
M90H@("`@("`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CXI+@I;:F%N72!!9&0@
M56MR86EN:6%N('1R86YS;&%T:6]N("A!;F1R:7D@2V]P>7-T>6%N<VMY(#QA
M;G)I0'!O;'EN970N;'9I=BYU83XI+@I;:F%N72!5<&1A=&4@9V5T=&5X="!D
M;V-U;65N=&%T:6]N(&%N9"!-86ME9FEL97,@9F]R(%-O;&%R:7,@86YD($1E
M8FEA;BX*6VIO;ET@36%I;G1E;F%N8V4@9FEX97,@9G)O;2!-:6-H865L($T@
M4VQU<V%R>B`\<VQU<V%R>D!B:6=W;W)M+F-O;&]R861O+F5D=3XN"EMJ86Y=
M($%D9"!$86YI<V@@=')A;G-L871I;VX@*$UA<G1I;B!,:7-T+5!E=&5R<V5N
M(#QM87)T:6Y`;&ES="UP971E<G-E;BYD:SXI+@H*"BTM+2T*=C(N,`HM+2TM
M"@I;:F%N72!!9&0@3F]R=V5G:6%N($)O;VMM86P@=')A;G-L871I;VX@*$]Y
M<W1E:6X@4W1E:6UL97(@/&]Y<W1E:6Y`<F5X=&$N;F5T/BDN"EMA=G-M72!!
M9&0@+FAT86-C97-S(&9I;&5S('1O(&1E;GD@86-C97-S('1O(&1A=&$@9&ER
M96-T;W)I97,N"EMJ86Y=($%D9"!&:6YN:7-H('1R86YS;&%T:6]N("A,965N
M82!(96EN;R`\;&EI;G5`=71A+F9I/BDN"EMC:FA=($9I>"!O;F4@;&%S="!P
M<F]B;&5M('=I=&@@4$]0,R!A;F0@;75L=&EP87)T+V%L=&5R;F%T:79E(&%T
M=&%C:&UE;G1S+@H*"BTM+2TM+2TM"G8R+C`M4D,T"BTM+2TM+2TM"@I;<FEC
M:%T@26YC;'5D92!R97=R:71T96X@86YD(')E;W)G86YI>F5D(&1O8W5M96YT
M871I;VXN"EMC:FA=($%D9"!A;B!-4U!O=V5R<&]I;G0@34E-15]6:65W97(N
M"EMJ86Y=(%1H92!L86YG=6%G92!C;V]K:64@=V%S(')E;6]V960@:6X@9F%V
M;W(@;V8@;F5W(&UE=&AO9',@:6X@=&AE($QA;F<Z.@H@("`@("!C;&%S<R!T
M:&%T('-E;&5C="!T:&4@;&%N9W5A9V4@86YD('-E="!T:&4@9V5T=&5X="!D
M;VUA:6XN"EMA=G-M72!);F-L=61E($-H;W)A(&EN('1H:7,@<F5L96%S92!C
M>6-L92P@8G5T(&YO="!S:&]W:6YG(&EN('1H92!T;V]L8F%R+@I;8VIH72!!
M9&0@34E-15]6:65W97)?>FEP+@I;8VIH72!4<FEM(')E9VES=')Y+G!H<"YD
M:7-T('1O(&]N;'D@;&ES="!A<'!S(&EN('1H:7,@<F5L96%S92!C>6-L92X*
M6VIA;ET@061D(&1E;&5T94]B:F5C="@I(&UE=&AO9"!T;R!T:&4@4V5S<VEO
M;D-A8VAE(&-L87-S+@I;8FIN72!#:&%N9V4@)V5N)R!A;F0@)V5N7T5.)R!L
M;V-A;&5S('1O("=E;E]54R<@*&1E9F%U;'0I+@H*"BTM+2TM+2TM"G8R+C`M
M4D,S"BTM+2TM+2TM"@I;8VIH72!296-O9VYI>F4@82!F97<@4&%L;2YN970@
M8G)O=W-E<G,@86YD('-E="!Q=6ER:W,O9F5A='5R97,@86-C;W)D:6YG;'DN
M"EMC:FA=(%-U<'!O<G0@9F]R(&%D9&EN9R!A;F0@;&ES=&EN9R!,1$%0('5S
M97)S(&=I=F5N(&$@<V5T('-C:&5M82X*6V-J:%T@4V5T('1H92!S97-S:6]N
M(&-O;VMI92!P87)A;65T97)S('=I=&@@;W5R(&-O;VMI95]P871H+V-O;VMI
M95]D;VUA:6X*("`@("`@<V5T=&EN9W,N(%1H:7,@;65A;G,@=&AA="!Y;W4@
M8V%N(&)E(&QO9V=E9"!I;G1O(&UU;'1I<&QE($AO<F1E"B`@("`@(&EN<W1A
M;&QA=&EO;G,@;VX@=&AE('-A;64@<V5R=F5R("AD:69F97)E;G0@<&%T:',I
M(&%N9"!N;W0@:&%V92!T:&4*("`@("`@<V5S<VEO;G,@:6YT97)F97)E+@I;
M8VIH72!5<V4@)VAO<W1S<&5C)R!C;VYS:7-T96YT;'D@:6X@075T:"!D<FEV
M97)S+@H*"BTM+2TM+2TM"G8R+C`M4D,Q"BTM+2TM+2TM"@I;:F%N72!!9&0@
M0G)A>FEL:6%N(%!O<G1U9W5E<V4@=')A;G-L871I;VX@*$-A<FQO<R!$86YI
M96P@2VEB<FET(#QK:6)R:71`=&5R<F$N8V]M+F)R/BDN"EMJ86Y=($%D9"!'
M<F5E:R!T<F%N<VQA=&EO;B`H4W1E9F%N;W,@22X@1&EM:71R:6]U(#QS9&EM
M:71R:4!T96EA=&@N9W(^*2X*6VIA;ET@061D('9#87)D($U)344@9')I=F5R
M+B!#:&%N9V5D(&-O;F9I9R]M:6UE7V1R:79E<G,N<&AP+F1I<W0N"EMJ86Y=
M($%D9"!3=V5D:7-H('1R86YS;&%T:6]N("A!;F1R96%S($1A:&SI;B`\86YD
M<F5A<T!D86AL96XN=W,^*2X*6VIA;ET@061D($MO<F5A;B!T<F%N<VQA=&EO
M;B`H2BY)($MI;2`\87!O<FEE0&YE=&EA;BYC;VT^*2X*"@HM+2TM+2T*=C$N
M,RXU"BTM+2TM+0H*6VIO;ET@061D960@)&9I;&4@86YD("1L:6YE('!A<F%M
M971E<G,@=&\@2&]R9&4Z.F9A=&%L*"DN"EMJ;VY=(%)E;6]V960@=&AE(%!2
M14937RH@86YD($%55$A?*B!C;VYS=&%N=',@:6X@9F%V;W(@;V8@4$5!4E]%
M<G)O<B!O8FIE8W1S+@I;879S;5T@1&]N)W0@9&5P96YD(&]N('1H92!R96=I
M<W1R>2!B96EN9R!A=F%I;&%B;&4@=VAE;B!D:7-P;&%Y:6YG"B`@("`@('1H
M92`G2&]R9&4@:7,@;F]T(&-O;F9I9W5R960G(&UE<W-A9V4N"EMC:FA=($-L
M96%N('5P('1H92!)9&5N=&ET>2!C;&%S<R!T;R!B92!A(&=E;F5R86QI>F5D
M+"!C;&5A;B!P:65C92!O9B!T:&4*("`@("`@9G)A;65W;W)K('1H870@8V%N
M(&)E('5S960@:6X@;W1H97(@87!P<R!A;F0@<W5B8VQA<W-E9"!I9B!N96-E
M<W-A<GDN"EMC:FA=($UA:V4@9F%I;'5R92!T;R!C;VYN96-T('1O('1H92!P
M<F5F97)E;F-E<R!D871A<V]U<F-E(&$@9F%T86P@97)R;W(N"EMC:FA=($%D
M9&5D('1H92!397)I86QI>F4Z.B!C;&%S<R!F;W(@=F%R:6]U<R!M971H;V1S
M(&]F(&5N8V%P<W5L871I;F<@9&%T80H@("`@("`H<W1E<&@@/'-H=71H97)`
M>6%H;V\N9G(^*2X*6V-J:%T@061D960@=&AE(&-A<&%B:6QI='D@=&\@9V5T
M(&%U=&AE;G1I8V%T:6]N(&-R961E;G1I86QS(&]T:&5R('1H86X*("`@("`@
M=7-E<FYA;64@8F%C:R!F<F]M('1H92!!=71H(&9R86UE=V]R:RP@86YD(&-O
M;7!L971E9"!T:&4*("`@("`@875T:&5N=&EC871I;VX@<F5A;&T@9G5N8W1I
M;VYA;&ET>2X*6VIO;ET@06QL;W<@=&AE('1A8FQE(&-E;&P@86YD(&QI;FL@
M0U-3(&-L87-S97,@=&\@8F4@<W!E8VEF:65D('=H96X@8W)E871I;F<*("`@
M("`@;65N=2!I=&5M<RX*6VIA;ET@061D(')E9VES=')Y(&UE=&AO9"!F;W(@
M;&EN:VEN9R!T;R!A(&YA9R!T87-K+@I;:F%N72!!9&0@:61E;G1I='D@8VQA
M<W,N"EMM87A=($%D9"!296=I<W1R>3HZ9V5T3F%M92@I(&9O<B!Q=65R>6EN
M9R!A<'!L:6-A=&EO;B!N86UE<RX*6V-J:%T@2&]R9&4@;F]W('!R;W9I9&5S
M('1H92!(;W)D93HZ;&]G365S<V%G92@I(&UE=&AO9"!F;W(@;&]G9VEN9R!O
M9@H@("`@("!I;F9O<FUA=&EO;B!A8V-O<F1I;F<@=&\@8V]N9FEG=7)A8FQE
M('!R:6]R:71I97,L(&5T8RX*6VIA;ET@061D(&9U;F-T:6]N86QI='D@=&\@
M;6%P(&1A=&4@86YD('1I;64@9FEE;&1S('1O('1H92!$871A(&-L87-S+@I;
M8VIH72!!9&0@=&AE(&)E9VEN;FEN9W,@;V8@82!U<V5R(&%D;6EN:7-T<F%T
M:6]N('-Y<W1E;2X*6V-J:%T@061D($-H:6YE<V4@*%1R861I=&EO;F%L*2!T
M<F%N<VQA=&EO;B`H1&%V:60@0VAA;F<*("`@("`@/&1A=FED0'1H8G5O+F=O
M=BYT=SXI+@I;:F%N72!!9&0@271A;&EA;B!T<F%N<VQA=&EO;B`H1VEO=F%N
M;FD@365N96=H971T:2`\9VUE;F5G:&5T=&E`:6YF=FEC+FET/BDN"EMJ86Y=
M($%D9"!$871A(&-L87-S(&9O<B!I;7!O<G1I;F<@86YD(&5X<&]R=&EN9R!D
M871A+@I;:F]N72!#;&5A;F5D('5P('1H92!H96QP('-Y<W1E;2!A(&)I="X*
M6V-J:%T@061D($AO<F1E.CIF871A;"@I(&9O<B!D:7-P;&%Y:6YG(%!%05)?
M17)R;W(@;V)J96-T<R!A;F0@86)O<G1I;F<N"EMA=G-M72!%>'1E;F0@2&]R
M9&4Z.F=E=%1E;7!&:6QE*"D@=&\@86QL;W<@9&ER96-T;W)Y('1O(&)E(&]V
M97)R:61D96XN"EMA=G-M72!!;&QO=R!T96UP;W)A<GD@9FEL97,@=&\@8F4@
M=6YR96=I<W1E<F5D(&9R;VT@9&5L971I;VXN"EMA=G-M72!!9&0@82!#86-H
M92!F<F%M97=O<FL@9F]R('!E<G-I<W1E;G1L>2!S=&]R:6YG(&]B:F5C=',L
M(&%L;VYG"B`@("`@("!W:71H(&$@9FEL97-Y<W1E;2!D<FEV97(N"EMJ86Y=
M($%D9"!0;VQI<V@@=')A;G-L871I;VXN"EMC:FA=($9I>"!A('!R;V)L96T@
M=VET:"`D<F5G:7-T<GDM/F-A;&PH*2!A;F0@<W=I=&-H:6YG(&%P<&QI8V%T
M:6]N"B`@("`@(&-O;G1E>'1S+@I;8VIH72!'970@<FED(&]F('1H92!I;G9O
M:V4H*2!M971H;V1S(&EN('1H92!R96=I<W1R>2X*6V-J:%T@1&]N)W0@<F4M
M:6YC;'5D92!A<'!L:6-A=&EO;B!C;VYF:6<@9FEL97,[('-A=F4@8V]N9FEG
M<R!I;B!A(&-A8VAE('-O"B`@("`@('1H870@=V4@8V%N(&IU<W0@<&]I;G0@
M)$=,3T)!3%-;)V-O;F8G72!A="!T:&4@;VQD(&-O;F9I9R!O;@H@("`@("`D
M<F5G:7-T<GDM/G!O<$%P<"@I+"!E=&,N"EMJ86Y=($%D9"!&<F5N8V@@=')A
M;G-L871I;VX@*$9R961E<FEC(%1R=61E874@/&9T<G5D96%U0$-!32Y/4D<^
M*2X*6V-J:%T@061D($-Z96-H('1R86YS;&%T:6]N("AP8VAY=&EL0&%S<"YO
M9VDN961U*2X*6VIA;ET@061D(&YE=R!T:6UE>F]N92!H86YD;&EN9R!W:71H
M(&-L96%R=&5X="!T:6UE>F]N92!N86UE<R!I;B!L86YG+G!H<"X*6V-J:%T@
M061D(%)U<W-I86X@=')A;G-L871I;VX@*$EG;F%T($EK<GEA;F]V(#QI9VYA
M=$!I8F0N<G4^*2X*6VIO;ET@3F5W(&UE=&AO9',@:6X@0G)O=W-E<BYP:'`@
M9F]R(')E=')I979I;F<@=F5R<VEO;G,N(#QI>GIY0'%U;7)A;BYO<F<^"EMJ
M;VY=($)R;W=S97(N<&AP(&YO=R!D971E8W1S($]P97)A+B`\:7IZ>4!Q=6UR
M86XN;W)G/@I;8VIH72!-;W9E('1H92!L86YG=6%G92!A;F0@8VAA<G-E="!D
M969A=6QT<R!I;G1O(&-O;F9I9R]L86YG+G!H<"P@86YD(&%D9"!A"B`@("`@
M(%)E9VES=')Y(&UE=&AO9"!T;R!G970@=&AE(&-U<G)E;G0@8VAA<G-E="X*
M6V-J:%T@36%P(&)R;W=S97(@8V]D97,@<W5C:"!A<R`G;FPG('1O('1H92!F
M=6QL(&-O9&4@*"=N;%].3"<L(&5T8RXI+@I;879S;5T@4F5P;&%C92`D8V]N
M9ELG<&%T:',G72!W:71H('1H92`D<F5G:7-T<GD@97%U:79A;&5N=',N"EMA
M=G-M72!!9&0@9F]U<B!R96=I<W1R>2!F=6YC=&EO;G,@=&\@<75E<GD@=V5B
M<F]O=',@86YD('!A=&AS+@I;879S;5T@36%N>2!-24U%7U9I97=E<B!C:&%N
M9V5S.B!!4$D@='=E86MS+"!N97<@9')I=F5R<RP@=V]R:W,@=VET:"!)35`N
M"EMC:FA=("1C;VYF6R=U<V5R)UU;)V]N;&EN95]H96QP)UT@:7,@;F]W(&$@
M2&]R9&4M;&5V96P@<V5T=&EN9RX*6V%V<VU=($5N86)L92!A<'!L:6-A=&EO
M;G,@=&\@:&%V92!L;V-A;"!-24U%7U9I97=E<B!D<FEV97)S(&EN(&%D9&ET
M:6]N"B`@("`@("!T;R!T:&4@9VQO8F%L($AO<F1E(&]N97,N"EMA=G-M72!3
M:'5F9FQE(&%R;W5N9"!T:&4@34E-15]6:65W97(@05!).B!G971$<FEV97(H
M*2!I<R!N;W<@<')I=F%T90I;879S;5T@061D(&%N("=I;FET:6%L7W!A9V4G
M(&]P=&EO;B!T;R!T:&4@<F5G:7-T<GDL('1O(&QE="!U<R!L:6YK(&EN=&\*
M("`@("`@86YY('!A9V4@:6YS:61E(&%N(&%P<&QI8V%T:6]N+@I;8VIH72!!
M9&0@82!F<F%M97=O<FLM;&5V96P@8F%S92YP:'`@9FEL92!A;F0@;6%K92!F
M<F%M97=O<FL@<V-R:7!T<R!U<V4@:70N"EMC:FA=($%D9"!R92UO<F=A;FEZ
M960@8G5T('-T:6QL(&UO<W1L>2!O=70@;V8@9&%T92!(14Q0+TQ)4U13+U-/
M55)#12!F:6QE<PH@("`@("`H2F]S:"!-:6QL97(@/&IO<VAL:7-T<T!N96)O
M;F5T+F-O;3XI+@I;8VIH72!!9&0@82!P87)A;65T97(@=&AA="!D971E<FUI
M;F5S('=H971H97(@;W(@;F]T(&%P<',@87)E(&QI;FME9"!O;B!T:&4*("`@
M("`@2&]R9&4@;65N=6)A<BX*6V-J:%T@0VQE87(@=&AE('=H;VQE('-E<W-I
M;VX@=VAE;B!T:&4@=7-E<B!L;V=S(&]U="!O9B!(;W)D92X*6VIO;ET@061D
M960@4')E9G,Z.FES16UP='DH*2!F;W(@9&5T97)M:6YI;F<@=VAE=&AE<B!A
M('!R969E<F5N8V4@:7,@96UP='DN"EMJ;VY=($%D9&5D(&%N("1O;F-L:6-K
M('!A<F%M971E<B!T;R!(;W)D93HZ;&EN:R@I(&9O<B!S<&5C:69Y:6YG(&%N
M(&%N8VAO<B=S"B`@("`@("=O;F-L:6-K)R!*879A4V-R:7!T(&5V96YT+@I;
M8VIH72!5<V4@=&AE("IU<FPH*2!F=6YC=&EO;G,@;6]R92!C;VYS:7-T96YT
M;'D@=&\@;6%K92!S=7)E('1H870*("`@("`@8V]O:VEE+6QE<W,@<V5S<VEO
M;G,@=V]R:RX*6V-J:%T@36]D:69Y(&-S<RYP:'`@=&\@=7-E('1H92!296=I
M<W1R>2!T;R!G970@87!P;&EC871I;VX@9FEL92!P871H<RX*6V-J:%T@061D
M(&-O;VMI95]P871H(&%N9"!C;V]K:65?9&]M86EN('-E='1I;F=S(&9O<B!P
M96]P;&4@=VAO(&ME97`@87!P<PH@("`@("!O=71S:61E(&]F('1H92!(;W)D
M92!W96)R;V]T(&]R(&]N(&UU;'1I<&QE('-E<G9E<G,N"@H*+2TM+2TM"G8Q
M+C,N-`HM+2TM+2T*"EMC:FA=($%D9"!A($AO<F1E('-U;6UA<GD@9G)A;65W
M;W)K+"!W:&EC:"!U<V5S('1H92!296=I<W1R>2!T;R!G970*("`@("`@<W5M
M;6%R:65S(&]F(&%V86EL86)L92!D871A("T@=&%S:W,L(&5V96YT<RP@971C
M+B`M(&9O<B!T:&4@2&]R9&4*("`@("`@;&]G:6X@<V-R965N+@I;8VIH72!4
M:&4@<')E9F5R96YC97,@<V5T=&EN9W,@<VAO=6QD(&)E($AO<F1E+7=I9&4L
M(&%N9"!S;R!H879E(&)E96X@;6]V960@=&\*("`@("`@:&]R9&4O8V]N9FEG
M+VAO<F1E+G!H<"X*6V-J:%T@36]V92!P<F5F<RYG:68@86YD(&=E;F5R:6,@
M<')E9G,@=&5M<&QA=&5S(&EN=&\@2&]R9&4N"EMC:FA=($UO=F4@<V5T=&EN
M9R!O9B!T:&4@9V5T=&5X="!D;VUA:6X@:6YT;R!T:&4@4F5G:7-T<GDN"EMJ
M;VY=(%-I;7!L:69I960@=&AE('!R969E<F5N8V4@<WES=&5M)W,@8VQE86YU
M<"!F=6YC=&EO;G,N"EMJ;VY=($UE<F=E(&1O8W1Y<&4N:6YC(&EN=&\@8V]M
M;6]N+6AE861E<BYI;F,N"EMJ;VY=($%D9&5D(%1E>'0Z.FAT;6QS<&%C97,H
M*2!A;F0@5&5X=#HZ:'1M;&%L;'-P86-E<R@I+@I;8VIH72!!9&0@86X@;W!T
M:6]N('1O($AO<F1E.CIG971496UP1FEL92@I('1O(&YO="!D96QE=&4@=&AE
M(&9I;&4@870@=&AE"B`@("`@(&5N9"!O9B!T:&4@<F5Q=65S="X*6V-J:%T@
M061D(&$@)G-I;F=L971O;B@I(&UE=&AO9"!T;R!T:&4@4F5G:7-T<GD@8VQA
M<W,N"EMJ;VY=($%D9&5D($YA9R!I;G1E<F9A8V4@=&\@=&AE(')E9VES=')Y
M+@I;:F]N72!%>'!A;F1E9"!T:&4@<F5G:7-T<GD@=&\@:&%N9&QE(&EM<&]R
M=&EN9R!A<'!L:6-A=&EO;BUS<&5C:69I8PH@("`@("!C;VYF:6=U<F%T:6]N
M('9A;'5E<RX*6VUA>%T@061D(&%U=&@O;&]G:6X@86YD(&%U=&@O;&]G;W5T
M(&]P=&EO;G,@9F]R($=O;&QE;2!I;B!T:&4@<F5G:7-T<GDN"EMM87A=($%D
M9"!296=I<W1R>3HZ9V5T365T:&]D(&9U;F-T:6]N+@I;;6%X72!!9&0@8V]N
M=&%C=',O<V]U<F-E<R!S97)V:6-E('1O('1H92!R96=I<W1R>2X*6V-J:%T@
M4F5N86UE('1H92!#;VYN96-T:6]N(&-L87-S97,@=&\@5&]K96XN"EMC:FA=
M(%)E;F%M92!T:&4@3V)J96-T4W1O<F4@8VQA<W,@=&\@4V5S<VEO;D-A8VAE
M+@I;:F]N72!!9&1I;F<@1'5T8V@@;&%N9W5A9V4N"EMA=G-M72!!9&0@:6-O
M;B!S=7!P;W)T('1O('1H92!-24U%7U9I97=E<B!F<F%M97=O<FL*6V%V<VU=
M(%5P9&%T92!T:&4@34E-15]6:65W97(@05!)('1O(&EN8VQU9&4@9V5T1')I
M=F5R*"D@86YD(&=E=$EC;VXH*0I;:F]N72!/=F5R:&%U;&5D('1H92!P<F5F
M97)E;F-E<R!C86-H:6YG('-Y<W1E;2!A(&)I="X*6V-J:%T@57!D871E($)R
M;W=S97(Z.B!T;R!R96-O9VYI>F4@244V+@I;:F]N72!!9&1E9"!(;W)D92UW
M:61E(&%N9"!D<FEV97(M<W!E8VEF:6,@8VQE86YU<"!M971H;V1S('1O('1H
M92!P<F5F97)E;F-E<PH@("`@("!S>7-T96TN"EMC:FA=(%)E;6]V92!T:&4@
M<W1R=&]L;W=E<B@I(&9R;VT@3&%N9SHZ<V5L96-T*"D@=VAI8V@@=V%S('!R
M979E;G1I;F<*("`@("`@<')O<&5R(&QO8V%L92!N86UE<R`H;&EK92!P=%]"
M4BD@9G)O;2!W;W)K:6YG(&-O<G)E8W1L>2X*6VUA>%T@061D960@875T:&5N
M=&EC871I;VX@:&%N9&QE<B!T;R!T:&4@4F5G:7-T<GDN"EMJ;VY=(%1H92`G
M<V5S<VEO;B<@<')E9F5R96YC97,@9')I=F5R(&YO=R!H;VYO<G,@<')E9F5R
M96YC92!S8V]P92X*6VUA>%T@36%D92!S:71E;F%M92!T:71L92!C;VYF:6=U
M<F%B;&4N"EMJ;VY=(%)E=V]R:V5D('1H92!-96YU.CIC=7-T;VU)=&5M*"D@
M=&\@86-C97!T(%!(4"!D871A('-T<G5C='5R97,@:6YS=&5A9`H@("`@("!O
M9B!A('-T<FEN9R!O9B!E;F-O9&5D('!A<F%M971E<G,N"EMA=G-M72!!9&1E
M9"!-24U%7U9I97=E<B!F<F%M97=O<FL@=&\@:&%N9&QE(')E;F1E<FEN9R!F
M:6QE<R!I;G1O($A434P*("`@("`@("AA;F0@;W1H97(I(&9O<FUA=',@:6X@
M82!U<V5R+65X=&5N<VEB;&4@9F%S:&EO;B`H97AP97)I;65N=&%L*0I;879S
M;5T@3F5W($U)345?36%G:6,@86YD(&UI;65?;6%P<&EN9RYP:'`@8V]N9FEG
M(&9I;&4@*&5X<&5R:6UE;G1A;"D*6V%V<VU=(%1W;R!N97<@=&5M<&]R87)Y
M(&9I;&4@:&%N9&QI;F<@9G5N8W1I;VYS+"!(;W)D93HZ9V5T5&5M<$9I;&4H
M*2!A;F0*("`@("`@2&]R9&4Z.F=E=%1E;7!$:7(H*2!T;R!T86ME(&-A<F4@
M;V8@=&AE(&AO=7-E:V5E<&EN9R!O9B!T96UP(&9I;&5S+@I;;6%X72!!9&1E
M9"!C;VYT86-T<R]A9&0@<V5R=FEC92!T;R!R96=I<W1R>2X*6V-J:%T@4F5G
M:7-T<GDZ.F-A;&PH*2!I<R!N;W<@4F5G:7-T<GDZ.FQI;FLH*2X@5&AE<F4@
M:7,@82!N97<*("`@("`@4F5G:7-T<GDZ.F-A;&PH*2!W:&EC:"!A8W1U86QL
M>2!R971U<FYS('1H92!R97-U;'0@;V8@82!F=6YC=&EO;B!C86QL"B`@("`@
M(&UA9&4@=&\@86YO=&AE<B!A<'!L:6-A=&EO;BX*6V-J:%T@1FEX($1"('%U
M97)Y(')E<W5L="!C:&5C:VEN9R!I;B!S<6P@9')I=F5R<RX*6V-J:%T@1FEX
M(&AE;'`@<V\@=&AA="!G96YE<FEC(&AE;'`@;&EN:W,@*&]N(&UE;G4@8F%R
M<RD@<VAO=R!T:&4@=&]P:6,@;&ES=`H@("`@("!C;W)R96-T;'DN"EMC:FA=
M($UA:V4@=&AE(&QO9VEN(&9O<FT@;FEC97(L(&%N9"!A9&0@82!L;V=O=70@
M;&EN:RX*6V-J:%T@36%K92!S=7)E(&%L;"!O9B!T:&4@<W%L(&1R:79E<G,@
M=7-E($1".CIQ=6]T95-T<FEN9R@I(&]N(&%L;"!S=')I;F=S+@I;8VIH72!2
M97!L86-E(&$@0&UY<W%L7W%U97)Y*"D@=&AA="!W87,@:&ED:6YG(&EN($-O
M;FYE8W1I;VXO<W%L+G!H<"!W:71H"B`@("`@("1T:&ES+3YD8BT^<75E<GDH
M*2X*6V-J:%T@4F5T=7)N(&)A<V5N86UE*"1L86YG=6%G92D@9G)O;2!,86YG
M.CI396QE8W0H*2!T;R!A=F]I9"!P;W-S:6)L90H@("`@("!E>'!L;VET<RX*
M6V-J:%T@061D(%)E9VES=')Y.CIH87--971H;V0H*2!F;W(@8VAE8VMI;F<@
M:68@82!P:65C92!O9B!F=6YC=&EO;F%L:71Y(&AA<PH@("`@("!B965N(')E
M9VES=&5R960@=VET:"!(;W)D92X*6VIO;ET@06YO=&AE<B!L87)G92!O=F5R
M:&%U;"!T;R!T:&4@<')E9F5R96YC97,@<WES=&5M+B`@3F]T92!T:&%T('1H
M90H@("`@("!I<T-H86YG96%B;&4H*2!F=6YC=&EO;B!H87,@8F5E;B!R96YA
M;65D(&ES3&]C:V5D*"DN("!4:&5R92!I<R!A;'-O"B`@("`@('-U<'!O<G0@
M9F]R('!R969E<F5N8V4@<V-O<&4@*'9I82!I<U-H87)E9"@I(&%N9"!S9713
M:&%R960H*2DN"EMJ;VY=($%D9&5D(&-A<&%I8FQI='D@=&5S=',@=&\@=&AO
M<V4@9')I=F5R<R!T:&%T(')E<75I<F4@;F]N+7-T86YD87)D(%!(4`H@("`@
M("!E>'1E;G-I;VYS("AH86YD;&5D(&)Y($AO<F1E.CIF=6YC=&EO;D-H96-K
M*"DI+@I;:F]N72!!9&1E9"!A;B!!=71H7TQ$05`@2&]R9&4@875T:&5N=&EC
M871I;VX@9')I=F5R+@I;8VIH72!!9&0@;&ET=&QE('-N:7!P970M=&5M<&QA
M=&5S(&9O<B!D>6YA;6EC86QL>2!B=6EL9&EN9R!P<F5F97)E;F-E($=527,N
M"EMC:FA=(%)E;F%M92!T:&4@075T:"!I;G1E<F9A8V4G<R!A=71H*"D@;65T
M:&]D('1O(&%U=&AE;G1I8V%T92@I('1O(&%V;VED"B`@("`@(&]V97)L87!P
M:6YG('1H92!N86UE(&]F('1H92!C;VYS=')U8W1O<B!F;W(@=&AE($%U=&@@
M<&%R96YT(&-L87-S+@I;8VIH72!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2!I
M<R!N;W<@<VEM<&QY("1C;VYF+B!!;GD@<V5T=&EN9W,@=&AA="!M=7-T(&)E
M"B`@("`@(&%C8V5S<VEB;&4@=6YC:&%N9V5D("AN;W0@;W9E<G)I9&1E;BD@
M<VAO=6QD(&)E('!U="!I;G1O("1C;VYF6R=H;W)D92==+@H@("`@("!%=F5R
M>71H:6YG(&5L<V4@:7,@9F%I<B!G86UE(&9O<B!A<'!L:6-A=&EO;G,@=&\@
M;W9E<G)I9&4N"EMC:FA=($%D9"!A('=M;"]W87`@;&]G:6X@9F]R;2X*6VUA
M>%T@061D(&%N($%U=&A?1E10($AO<F1E(&%U=&AE;G1I8V%T:6]N(&1R:79E
M<BX*6V-J:%T@061D(&%N($%U=&A?34-!3"!(;W)D92!A=71H96YT:6-A=&EO
M;B!D<FEV97(N"EMC:FA=(%1H92!(;W)D92!L;V=I;B!F;W)M(&YO=R!A8W1U
M86QL>2!D;V5S('-O;65T:&EN9RX@3&]G9VEN9R!I;B!T;R!I=`H@("`@("!G
M971S('EO=2!A('1O:V5N(&EN('EO=7(@<V5S<VEO;B!S87EI;F<@=&AA="!Y
M;W4G=F4@875T:&5N=&EC871E9"!A;F0*("`@("`@=VAO('EO=2!A<F4N($%P
M<',@8V%N('1H96X@=7-E('1H:7,@:6YF;W)M871I;VX@=&\@86QL;W<@;W(@
M9&5N>0H@("`@("!A8V-E<W,L(&%N9"!T;R!I9&5N=&EF>2!U<V5R<RX*6V-J
M:%T@5&AE(&9O<FUA="!O9B!T:&4@8V]N9FEG+W)E9VES=')Y+G!H<"!F:6QE
M(&AA<R!C:&%N9V5D(&1R87-T:6-A;&QY('1O"B`@("`@(&)E(&UO<F4@<F5A
M9&%B;&4@86YD(&QE<W,@:6YD:7)E8W0N(%1H97)E(&ES(&%L<V\@82!N97<@
M87!P('!A<F%M971E<BP*("`@("`@)V%L;&]W7V=U97-T<R<L('=H:6-H(&1E
M9FEN97,@=VAE=&AE<B!O<B!N;W0@82!U<V5R(&ES(&%L;&]W960@=&\*("`@
M("`@86-C97-S('1H92!A<'!L:6-A=&EO;B!W:71H;W5T(&QO9V=I;F<@:6X@
M=&\@2&]R9&4N"EMC:FA=(%1H92!!=71H.CH@8VQA<W-E<R!N;W<@97AP96-T
M('1O(')E8V5I=F4@82!U<V5R:60@86YD(&%N(&%R<F%Y(&]F"B`@("`@(&-R
M961E;G1I86QS+B!2:6=H="!N;W<@86QL(&)A8VME;F1S(&%S<W5M92!T:&%T
M('1H;W-E(&-R961E;G1I86QS"B`@("`@(&-O;G1A:6X@82!P87-S=V]R9"P@
M8G5T('1H92!W87D@:7,@8VQE87(@=&\@:&%V92!O=&AE<B!K:6YD<R!O9B!A
M=71H"B`@("`@("A)4"P@=&EM92UB87-E9"P@=VAA=&5V97(I+@I;:F]N72!!
M9&1E9"!A(&YE=R!P87)A;65T97(@=&\@=&AE($Q$05`@<')E9F5R96YC97,@
M9')I=F5R.B`G86QW87ES7V)I;F0G+@I;8VIH72!!9&1E9"!A($UE;G4Z.B!C
M;&%S<R!T:&%T(&%L;"!M;V1U;&5S(&-A;B!U<V4@=&\@9V5N97)A=&4@;65N
M=2!I=&5M<RX*6VIO;ET@0VQE86YE9"!U<"!T:&4@3$1!4"!P<F5F97)E;F-E
M<R!D<FEV97(@82!B:70N"EMJ;VY=($%D9&5D('-E<W-I;VXM;&5V96P@<')E
M9F5R96YC97,@8V%C:&EN9R!T;R!T:&4@<')E9F5R96YC97,@<WES=&5M+@I;
M8VIH72!(879E($AO<F1E.CIL:6YK*"D@;6%K92!S=7)E('1H870@=&AE('-T
M871U<R!T97AT(&ES('-A9F4@9F]R"B`@("`@(&IA=F%S8W)I<'0@*&AT;6QE
M;G1I=&EE<RP@861D<VQA<VAE<RDN"EMC:FA=($9I>"!/8FIE8W13=&]R92!T
M;R!W;W)K('=H96X@<F5G:7-T97)?9VQO8F%L<R`]($]N+@I;:F]N72!!9&1E
M9"!A(%-E<W-I;VXM8F%S960@<')E9F5R96YC97,@9')I=F5R+@H*"BTM+2TM
M+0IV,2XS+C,*+2TM+2TM"@I;8VIH72!&=7)T:&5R(')E=F%M<"!T:&4@34E-
M12!I;G1E<F9A8V4N($)E(&-O;G-I<W1E;G0@:6X@8V%P:71A;&EZ871I;VX*
M("`@("`@*&%C<F]N>6US(&%R92!C87!I=&%L:7IE9"DL(&)R96%K(&]U="!-
M24U%7U-T<G5C='5R92!A;F0@34E-15]-97-S86=E"B`@("`@(&EN=&\@<V5P
M97)A=&4@9FEL97,L(&%N9"!P=70@86QL(&UE=&AO9',@:6YT;R!C;&%S<V5S
M+@I;8VIH72!!9&0@2&]R9&4Z.F=E=$9O<FU$871A*"D@=&\@9F5T8V@@82!V
M87)I86)L92!F<F]M(&5I=&AE<@H@("`@("`D2%144%]03U-47U9!4E,@;W(@
M)$A45%!?1T547U9!4E,@*&%N9"!T;R!C;&5A;B!M86=I8R!Q=6]T97,L(&EF
M"B`@("`@(&YE8V5S<V%R>2DN"EMC:FA=(%)E;6]V92!T:&4@3&]G.CH@8VQA
M<W,N(%1H:7,@:7,@<&%R="!O9B!014%2(&YO=RX*6V-J:%T@061D(&$@4V5S
M<VEO;D-A8VAE.CH@8VQA<W,N(%1H:7,@:7,@:6YT96YD960@9F]R('-T;W)I
M;F<@;V)J96-T<R!I;@H@("`@("!T:&4@<V5S<VEO;B!I;G1E;F1E9"!F;W(@
M;F5A<BUT97)M('5S92P@86YD('=I;&P@8W5R<F5N=&QY('-T87)T"B`@("`@
M('1H<F]W:6YG(&]U="!O8FIE8W1S('=H96X@;6]R92!T:&%N(#(P(&%R92!P
M=70@:6XN(%1H:7,@=VEL;"!H;W!E9G5L;'D*("`@("`@:V5E<"!A;GD@;VYE
M('-E<W-I;VX@9G)O;2!G<F]W:6YG('1O;R!L87)G92X*6V-J:%T@57-E('1H
M92!N97<@4$5!4B!C;&%S<R!-86EL7W)F8S@R,CHZ('1O('!A<G-E(&%D9')E
M<W,@;&ES=',L('-O('1H870*("`@("`@=V4@9V5T(')F8R`X,C(@9W)O=7`@
M<W5P<&]R="`H;7DM8G5D9&EE<SH@:F]N0&AO<F1E+&]R9RP*("`@("`@;6%X
M0&AO<F1E+F]R9SLI+"!W:&EC:"!I;6%P7W)F8S@R,E]P87)S95]A9')L:7-T
M*"D@9&]E<VXG="!H879E+@I;;6%X72!-86ME($AO<F1E(%A(5$U,(#$N,"!C
M;VUP;&EA;G0N"EMC:FA=($%D9"!A(&9E=R!F:65L9',@=&\@=&AE('!R;V)L
M96T@<F5P;W)T(&%N9"!T<GD@=&\@;6%K92!I="!M;W)E(&9R:65N9&QY+@I;
M8VIH72!&;&5S:"!O=70@=&AE($UI;64Z.B!C;&%S<RX*6V-J:%T@36]V92!T
M<FEM16UA:6Q!9&1R97-S*"D@:6YT;R!T:&4@;F5W($UI;64Z.B!C;&%S<RX*
M6V-J:%T@36]V92!S971?96YV7VEN7W-T<FEN9R@I('1O(%1E>'0Z.F5X<&%N
M9$5N=FER;VYM96YT*"DN"EMC:FA=(%)E;F%M92!H;W)D95]C;&5A;G5P*"D@
M=&\@7V9I;&5#;&5A;G5P*"DN"EMC:FA=(%1H92!Z;&EB(&UO9'5L92!N;W<@
M<W5P<&QI97,@82!G>F5N8V]D92@I(&9U;F-T:6]N('1H870@;V)S;VQE=&5S
M"B`@("`@($A45%!?0V%C:&4Z.F=Z16YC;V1E*"DN"EMC:FA=($UO9&EF>2!(
M;W)D93HZ=7)L*"D@<V\@=&AA="!I="!D969A=6QT<R`D8V]N9ELG=7-E7W-S
M;"==('1O(#(*("`@("`@*&%U=&\M9&5T96-T(&-U<G)E;G0@;6]D92DN"EMC
M:FA=($UO9&5R;FEZ92!S;VUE(&]F('1H92!(;W)D92!F<F]N=&5N9"`H<W1I
M;&P@;&]T<R!T;R!D;R!H97)E*3L@9V5T(')I9`H@("`@("!O9B!P86-K86=E
M+DA434Q$;V-U;65N="YP:'`@;VYC92!A;F0@9F]R(&%L;"X*6V%V<VU=($)R
M96%K9&]W;B!A;&P@<W!E8VEA;"!C:&%R86-T97)S(&EN(%523',@=&\@96YT
M:71I97,L('1O(&%V;VED"B`@("`@(&%M8FEG=6ET>2!I;B!H;W<@=F%R:6]U
M<R!B<F]W<V5R<R!P87)S92!T:&5M+@I;8VIH72!!9&0@2&]R9&4Z.G)A:7-E
M365S<V%G92@I(&9O<B!C<F5A=&EN9R!(;W)D92!M97-S86=E<R!T;R!B92!D
M:7-P;&%Y960*("`@("`@=&\@=&AE('5S97(N"EMC:FA=(%-O;64@9V5N97)A
M;"!522!T=V5A:W,@+2!F;VYT('-I>F4L(&5T8RX*6V-J:%T@4F5M;W9E(')F
M8V1A=&4H*2!I;B!F879O<B!O9B!T:&4@;F5W("=R)R!P87)A;65T97(@=&\@
M9&%T92X*6V-J:%T@061D960@87!P;&EC871I;VX@)W=E8G)O;W0G(&%N9"`G
M9FEL97)O;W0G('!R;W!E<G1I97,@=&\@=&AE(')E9VES=')Y"B`@("`@(&-O
M;F9I9R!F:6QE+B!4:&5S92!A;&QO=R!M;W)E(&9L97AI8FEL:71Y(&EN('!L
M86-I;F<@87!P<RP@86YD(&QE="!T:&4*("`@("`@<F5G:7-T<GD@=V]R:R!F
M<F]M(&UO<F4@<&QA8V5S+@I;8VIH72!-;W9E9"!P86-K86=E+E)E9VES=')Y
M+G!H<"!T;R!296=I<W1R>2YP:'`N"EMC:FA=($-O;6UE;G1E9"!C;VYF:6<O
M:&]R9&4N<&AP+F1I<W0@:&5A=FEL>2X*6V-J:%T@061D(&$@4V5C<F5T.CH@
M8VQA<W,@=&\@2&]R9&4N<&AP('1H870@<')O=FED97,@82!T<F%N<W!A<F5N
M=`H@("`@("!I;G1E<F9A8V4@=&\@96ET:&5R('1H92!M8W)Y<'0@97AT96YS
M:6]N("AP<F5F97)R960I(&]R('1H92!014%2"B`@("`@($-R>7!T7TA#14U$
M-3HZ(&-L87-S+@I;:F]N72!!8V-E<'0@82!U<V5R+61E9FEN960@9G5N8W1I
M;VX@9F]R('!E<F9O<FUI;F<@=7-E<FYA;64@;&]O:W5P<R!I;B!T:&4*("`@
M("`@<')E9F5R96YC97,@8V]D92X@(%1H92!P<F5F97)E;F-E<R!C;VYS=')U
M8W1O<B!L;V]K<R!F;W(@=&AE(&9U;F-T:6]N"B`@("`@(&EN("1P87)A;7-;
M)W5S97)?:&]O:R==+@I;8VIH72!#:&5C:R!(5%107T5.5E]605)3(&9O<B!T
M:&4@=7-E<BUA9V5N="!A<R!W96QL(&%S($A45%!?4T525D527U9!4E,N"EMC
M:FA=(%)E;6]V92!M86EL9G)O;2@I(&EN(&9A=F]R(&]F('1H92!014%2($UA
M:6PZ.B!I;G1E<F9A8V4N($%D:G5S="!T:&4*("`@("`@8V]N9B!F:6QE<R!A
M;F0@<')O8FQE;2YP:'`@86-C;W)D:6YG;'DN"EMC:FA=($%D9"!A('-E="!O
M9B!I;G9O:V4H*2!M971H;V1S('1O('1H92!296=I<W1R>3HZ(&-L87-S(&9O
M<B!D:7)E8W1L>0H@("`@("!I;G9O:VEN9R!S97)V:6-E<R`H:64L(&%C='5A
M;&QY('!O<'!I;F<@=7`@82!W:6YD;W<I(&EN<W1E860@;V8*("`@("`@<')I
M;G1I;F<@;&EN:W,@=&\@:6YV;VME('1H96TN"EMC:FA=($-L96%N('5P('!A
M8VMA9V4N36EM92YP:'`@82!B:70[(&1O;B=T('-E="!A(&-H87)S970@;VX@
M34E-12!P87)T<PH@("`@("!T:&%T(&%R96XG="!T97AT+@I;8VIH72!!9&1E
M9"!A(&9I;&4@9')I=F5R(&9O<B!T:&4@0V]N;F5C=&EO;CHZ(&-L87-S+@I;
M8VIH72!!9&1E9"!A(%=!4"!I;F1E>"!T;R!P<F]V:61E('%U:6-K(&QI;FMS
M('1O(&%L;"!(;W)D92!W:7)E;&5S<R!P86=E<RX*6V-J:%T@061D(&)A<VEC
M(%=!4"!B<F]W<V5R(&1E=&5C=&EO;B!T;R!"<F]W<V5R.CHN($-U<G)E;G1L
M>2!T:&ES(&ES(&]F('1H90H@("`@("`B:70@9&5T96-T<R!T:&4@<&AO;F4@
M22!H879E(&%N9"!T:&4@<VEM=6QA=&]R($D@=7-E(B!V87)I971Y.R!I="!I
M<PH@("`@("!?=F5R>5\@9F%R(&9R;VT@8V]M<&QE=&4N"EMC:FA=($%D9&5D
M($UA>"!+86QI:V$G<R!#;VYN96-T:6]N.CH@8VQA<W,@9F]R(&-O;FYE8W1I
M;VX@=')A8VMI;F<N"EMC:FA=($A45%!?0V%C:&4Z.B!N;W<@8V]M<')E<W-E
M<R!C;VYT96YT('=I=&AO=70@=&AE('5S92!O9B!A('1E;7`@9FEL92X*6V-J
M:%T@1FQE<VAE9"!O=70@=&AE($%U=&@Z.B!C;&%S<R!W:71H('1H92!A8FEL
M:71Y('1O(&-A8VAE(&%U=&AO<FEZ871I;VX*("`@("`@:6X@=&AE('-E<W-I
M;VXN"EMJ;VY=(%)E;6]V960@=&AE('-C<FEP=&5D('=O<F1W<F%P(&EN(&9A
M=F]R(&]F('1H92!N871I=F4@9G5N8W1I;VXN("!-;W9E9`H@("`@("!T:&4@
M=W)A<%]M97-S86=E*"D@9G5N8W1I;VX@=&\@5&5X=#HZ=W)A<"@I+@I;:F]N
M72!3=&%N9&%R9&EZ92!O;B!T:&4@<F9C9&%T92@I(&9U;F-T:6]N(&EN(&QI
M8B](;W)D92YP:'`N"EMC:FA=(%1H92!P<F5F<R!D<FEV97)S(&YO=R!E>'!E
M8W0@)'!A<F%M<ULG:&]S='-P96,G72P@9F]R(&-O;G-I<W1E;F-Y('=I=&@*
M("`@("`@4$5!4BX*6V-J:%T@5&AE(%!%05(@<W%L('!R969S(&1R:79E<B!N
M;W<@=V]R:W,N"EMC:FA=($UO=F4@:&]R9&4@8V]N9FEG=7)A=&EO;B!V86QU
M97,@=&AA="!S:&]U;&0@;F]T(&)E(&]V97)R:61D960@8GD*("`@("`@;6]D
M=6QE<R!I;G1O("1H;W)D95LG:&]R9&4G75M=('1O(&%L;&]W(&UO9'5L97,@
M=&\@9&\*("`@("`@;W9E<G)I9&EN9R]I;FAE<FET86YC92!O9B!O=&AE<B!O
M<'1I;VYS+@I;8VIH72!!9&0@=&AE($A45%!?0V%C:&4Z.B!C;&%S<R!T;R!(
M;W)D92YP:'`@9F]R($5486<@9V5N97)A=&EO;BP@9WII<`H@("`@("!C;VUP
M<F5S<VEO;B!O9B!H='1P(&-O;G1E;G0L(&5T8RX*6V-J:%T@4F5P;&%C92`D
M:&]R9&5;)VQO8V%L:&]S="==('=I=&@@)$A45%!?4T525D527U9!4E-;)U-%
M4E9%4E].04U%)UTN"EMC:FA=(%)E:F5C="!O=71R:6=H="!E;G9E;&]P92!&
M<F]M(&%D9')E<W-E<R!W:71H('-P86-E<R!I;B!T:&5M+@I;8VIH72!1=6]T
M92!T:&4@9G)O;2!A9&1R97-S('!A<W-E9"!T;R!S96YD;6%I;"!T;R!P<F5V
M96YT('-H96QL(&5X<&QO:71S+@I;8VIH72!5<&1A=&4@0G)O=W-E<BYP:'`@
M=&\@=7-E($A45%!?4T525D527U9!4E,L(&-O;G-O;&ED871E('1H92!J879A
M<V-R:7!T"B`@("`@('9E<G-I;VX@:6YF;W)M871I;VXL(&%N9"!A9&0@<W-L
M7V1O=VYL;V%D7VAA8VL@9F]R(&)R;W=S97)S('1H870@;F5E9`H@("`@("!D
M;W=N;&]A9',@=&\@8F4@8V%C:&5A8FQE+@I;:F]N72!!9&0@5&5X=#HZ9FEL
M=&5R('1O(&QI8B](;W)D92YP:'`N"EMC:FA=($-H96-K('1H92!R971U<FX@
M=F%L=64@;V8@<&-L;W-E*"D@8V]R<F5C=&QY(&EN(&UA:6QF<F]M*"DN"EMJ
M;VY=(%-E8W5R:71Y(&9I>"!F;W(@)&9R;VT@=F%L=64@:6X@;6%I;&9R;VTH
M*2X@/&-W0&-O8RUA9RYN970^"EMJ;VY=(%-I;&5N8V4@<V5S<VEO;E]S=&%R
M="!W87)N:6YG<RX*6VIO;ET@061D960@;F5W('QE>'1R87P@<W5B<W1I='5T
M:6]N('1O(&-O;F9I9R]R96=I<W1R>2YP:'`@9F]R(&5X=')A+`H@("`@("!N
M;VXM<W1A;F1A<F0@<&%R86UE=&5R('!A<W-I;F<N"EMJ;VY=(%)E;6]V92!B
M=6EL9%523"@I+B`@270G<R!B965N(')E<&QA8V5D(&)Y($AO<F1E.CIU<FPH
M*2X*6VIO;ET@4F5S=')U8W1U<F5D('1H92!344P@<')E9F5R96YC97,@<V-H
M96UA+@I;8VIH72!!9&1E9"`D:&]R9&5;)W-E<W-I;VY?;F%M92==('1O(&-O
M;G1R;VP@=&AE('-E<W-I;VX@;F%M92!G;&]B86QL>2X*6V-J:%T@4V5S<VEO
M;CHZ(&1O97-N)W0@<F5A;&QY(&)U>2!U<R!A;GET:&EN9RP@<V\@=V4G=F4@
M;6]V960@=&AE('5T:6QI='D*("`@("`@;65T:&]D<R!T:&%T(&1O(&EN=&\@
M2&]R9&4Z.BP@86YD(&%R92!J=7-T('5S:6YG('!H<#0@<V5S<VEO;B!C86QL
M<PH@("`@("!E;'-E=VAE<F4N"EMC:FA=($%D9&5D('1H92!B96=I;FYI;F=S
M(&]F(%5S97(@86YD($%U=&@@:6YT97)F86-E<RP@=VET:"!A(&)A<F4M8F]N
M97,*("`@("`@=V]R:VEN9R!!=71H7W-Q;"!I;7!L96UE;G1A=&EO;BX*6VIO
M;ET@4F5W<F]T92!T:&4@4V5S<VEO;B!C;&%S<R!F;W(@:6YS=&%N=&EA=&EO
M;B!W:71H(&AO;VMS(&9O<@H@("`@("!U<V5R+61E9FEN960@<V5S<VEO;B!H
M86YD;&5R<RX*6V-J:%T@5&AE(&)A<F4M8F]N97,@:6UP;&5M96YT871I;VX@
M;V8@=&AE(%!E<FUS('-C:&5M92P@=VET:"!A('-Q;"!D<FEV97(L"B`@("`@
M('=O<FMS+B!)9B!Y;W4@<&%S<R!I="!A(&9U;&P@<&%T:"!I="!W:6QL('1R
M879E<G-E('5P(&ET+"!R971U<FYI;F<*("`@("`@=&AE(&9I<G-T('!E<FUI
M<W-I;VX@:70@9FEN9',N"EMJ;VY=($UO=F5D('1H92!L86YG=6%G92!H86YD
M;&EN9R!F=6YC=&EO;G,@:6X@2&]R9&4N<&AP(&EN=&\@=&AE:7(@;W=N"B`@
M("`@(&-L87-S960@;F%M960@3&%N9RX*6V-J:%T@36]R92!C;VYS:7-T96YT
M+V-S<RUB87-E9"!L;V]K(&9O<B!T:&4@:&5L<"!S>7-T96TN"EMC:FA=(%-T
M87)T:6YG('1O(')E;6]V92!A;&P@=7-E<R!O9B!C86QL+71I;64@<&%S<RUB
M>2UR969E<F5N8V4N"EMC:FA=($%D9&5D(&-S<RYP:'`@9F]R(&%U=&]M86=I
M8V%L(&=E;F5R871I;VX@;V8@<W1Y;&5S:&5E=',@9F]R(&%P<',N"EMJ;VY=
M(%!R;VUO=&5D('1H92!796)#;&EE;G0@8VQA<W,@9G)O;2!L:6(O2&]R9&4N
M<&AP('1O(&ET<R!O=VX@8V]M<&]N96YT"B`@("`@(&YA;65D($)R;W=S97(N
M<&AP+@I;8VIH72!5<V4@=V]R9'=R87`@:6X@82!S;&EG:'1L>2!D:69F97)E
M;G0@=V%Y+"!W:&EC:"!S965M<R!T;R!P<F]D=6-E(&UU8V@*("`@("`@<')E
M='1I97(@<75O=&EN9R!O9B!M97-S86=E<RX*6VIO;ET@061D960@4')E9G,O
M;7ES<6PN<&AP(&1R:79E<B!F<F]M($UA>"!+86QI:V$@/&UA>$!T:&4M=')I
M=6UV:7)A=&4N;F5T/BX*6VIO;ET@3F5W(%A-3"UB87-E9"!H96QP('-U8G-Y
M<W1E;2X*6V-J:%T@4F5N86UE9"!P86-K86=E+FAO<F1E+G!H<"!T;R!(;W)D
M92YP:'`N"EMC:FA=($%D9"!I;6<H*2!A;F0@<&EM9R@I(&9U;F-T:6]N<R!T
M;R!T:&4@2&]R9&4Z.B!C;&%S<R!S;R!T:&%T(&UO9'5L97,*("`@("`@=7-I
M;F<@;VYL>2!S='EL97-H965T<R!D;VXG="!N965D('1H92!(5$U,1&]C=6UE
M;G0@<&%C:V%G92X*6V-J:%T@3VUI="!T:&4@<V5S<VEO;B!N86UE+VED(&9R
M;VT@=&AE(%523"!I9B!W92!C86X@=F5R:69Y('1H870@8V]O:VEE<PH@("`@
M("!A<F4@8F5I;F<@86-C97!T960N"EMJ;VY=($YE=R!W<F%P7VUE<W-A9V4@
M9G5N8W1I;VX@=&AA="!U<V5S('1H92!N871I=F4@=V]R9'=R87`@9G5N8W1I
M;VX@:68@:70*("`@("`@97AI<W1S+@I;:F]N72!5<&1A=&EN9R!H96%D97(@
M8V]M;65N="!C;W!Y<FEG:'0@:6YF;W)M871I;VXN"EMJ;VY=(%)E<&]R="!M
M;V1U;&4@=F5R<VEO;G,@:6X@=&5S="YP:'`@;W5T<'5T+@I;8VIH72!M:6UE
M7V5N8V%P<W5L871E*"D@;F]W('5S97,@86X@87)R87D@:6YS=&5A9"!O9B!A
M;B!O8FIE8W0N"EMJ;VY=(%)E;6]V960@=&AE("1?:'1M;%LG8V]M<&]S92HG
M72!S:7II;F<@<&%R86UE=&5R<R!F<F]M(&-O;F9I9R]H=&UL+G!H<"X*6V-J
M:%T@3&5A=F4@0F-C.B!O=70@;V8@=&AE(&AE861E<G,@=&AA="!A<F4@<&%S
M<V5D('1O('-E;F1M86EL+@I;:F]N72!297=R:71E(&$@9V]O9"!P;W)T:6]N
M(&]F('1H92!S8W)I<'1S+W-E=%]P97)M<RYS:"!S8W)I<'0@<V\*("`@("`@
M=&AA="!I="!E;F9O<F-E<R!A;B!E>'1R96UE;'D@:&EG:"!L979E;"!O9B!S
M96-U<FET>2X*6V-J:%T@5&AE('9A;&ED7VQA;F<H*2!F=6YC=&EO;B!N;W<@
M<F5Q=6ER97,@)&YL<ULG;&%N9W5A9V5S)UU;/&QA;F=U86=E/ET*("`@("`@
M=&\@8F4@<V5T(&9O<B!A(&QA;F=U86=E('1O(&)E(&-O;G-I9&5R960@=F%L
M:60@*&EN<W1E860@;V8@:G5S="!T:&4*("`@("`@;&]C86QE(&1I<F5C=&]R
M>2!E>&ES=&EN9RDN"EMC:FA=($%D9&5D(&$@)G-I;F=L971O;B@I(&UE=&AO
M9"!T;R!M86ME(&ET(&5A<VEE<B!T;R!O;FQY(&-R96%T92!O;F4@;&]G"B`@
M("`@(&EN<W1A;F-E+"!N;R!M871T97(@=VAE;B!Y;W4@;F5E9"!I="X*6V-J
M:%T@3F]W(&UA:6QF<F]M*"D@=V]R:W,@9F]R(')E8VEP:65N="!A9&1R97-S
M97,@=VET:"!S:6YG;&4@<75O=&5S(&]R"B`@("`@(&]T:&5R(&-H87)A8W1E
M<G,@=&AA="!N965D('1O(&)E(&5S8V%P960@:6X@=&AE;2X*6V-J:%T@3&]G
M(&-L87-S(&YO=R!H87,@86X@;6-A;"!I;G-T86YC92P@82!C;VUP;W-I=&4@
M*&9O<B!G<F]U<&EN9R!M=6QT:7!L90H@("`@("!L;V<@8F%C:V5N9',I+"!A
M;F0@;V)S97)V97)S(')E9VES=&5R('1H92!L979E;"!O9B!E=F5N=',@=&AE
M>2!W86YT('1O"B`@("`@(&AE87(@86)O=70L(&%N9"!O;FQY(&=E="!N;W1I
M9FEE9"!O9B!E=F5N=',@87,@:6UP;W)T86YT(&]R(&UO<F4*("`@("`@:6UP
M;W)T86YT('1H86X@=&AA="!L979E;"X*6V-J:%T@061D960@82!,;V<Z.B!F
M<F%M97=O<FL@86YD('-Y<VQO9R!I;7!L96UE;G1A=&EO;BP@:6YC;'5D:6YG
M(&$*("`@("`@3&]G7V]B<V5R=F5R(&-L87-S(&EN=&5N9&5D('1O('-I="!O
M;B!T;W`@;V8@3&]B(&]B:F5C=',@86YD('1A:V4*("`@("`@86-T:6]N(&EN
M(&5X8V5P=&EO;F%L(&-I<F-U;7-T86YC97,N"EMC:FA=($UA:V4@<W5R92!T
M;R!A;'=A>7,@<V5N9"!A(&-H87)S970@=VET:"!E;6%I;',N"EMC:FA=($EM
M<')O=F5D('1H92!M:6UE7V1E8V]D92@I(&%N9"!M:6UE7V5N8V]D92@I(&9U
M;F-T:6]N<RX*6V-J:%T@57!D871E9"!T97-T+G!H<"!T;R!R96-O9VYI>F4@
M<&AP-"!S=&%B;&4@<F5L96%S97,N"EMJ;VY=(%)E;6]V960@86QL(&]F('1H
M92!L;V-A;&4O*BYL86YG(&1E<&5N9&5N8VEE<RX*6VIO;ET@07-S=6UE('1H
M92!B<F]W<V5R(&ES(&9R86UE<RUC87!A8FQE(&)Y(&1E9F%U;'0N"EMC:FA=
M($%D9"!H;W)D95]C;&5A;G5P*"1F:6QE;F%M92DL('=H:6-H('1A:V5S(&-A
M<F4@;V8@9&5L971I;F<@9FEL97,@=&AA=`H@("`@("!S:&]U;&0@8F4@=6YL
M:6YK960@<F5G87)D;&5S<R!O9B!W:&5T:&5R(&]R(&YO="!T:&4@<F5Q=65S
M="!I<PH@("`@("!C86YC96QE9"!B>2!T:&4@=7-E<B!B969O<F4@=V4@9FEN
M:7-H(&5X96-U=&EN9RX*6V-J:%T@4F5M;W9E('!H<&QI8B!D97!E;F1A;F-Y
M(&EN(&9A=F]R(&]F('!H<#0@<V5S<VEO;G,O4$5!4BX*6V-J:%T@4F5P;&%C
M92!U<V4@=VET:"!R97%U:7)E7V]N8V4N"EMC:FA=($9I>&5D('5P('-E;&5C
M=%]L86YG*"D@=&\@=V]R:R`H:61E;G1I8V%L('1O(#$N,B!N;W<I"EMC:FA=
M($AO<F1E(&ES(&YO=R!U;F1E<B!T:&4@3$=03"X*6V-J:%T@1FEX(&UA:6QF
M<F]M*"D@<V\@:70@9&]E<VXG="!S96YD(&5X=')A(&AE861E<G,@=VAE;B!U
M<VEN9R!M86EL*"D*6V-J:%T@061D:6YG(&$@)VUA<F=I;G,G(&%T=')I8G5T
M92!T;R!(5$U,1&]C=6UE;G0@=&\@96YA8FQE('1U<FYI;F<@;V9F"B`@("`@
M(&1O8W5M96YT(&UA<F=I;G,N"@H*+2TM+2TM"G8Q+C,N,@HM+2TM+2T*"EMC
M:FA=(%)E<&QA8V5D(&UO9'5L92Y834Q?4D1&+G!H<"!W:71H(&$@=V]R:VEN
M9R!C;W!Y+@H*"BTM+2TM+0IV,2XS+C$*+2TM+2TM"@I;8VIH72!2979A;7!E
M9"!T:&4@36EM94UE<W-A9V4@8VQA<W,@=&\@8F4@;75C:"!S;6%L;&5R(&%N
M9"!S:6UP;&5R+@I;8VIH72!297!L86-E9"!T:&4@36EM95!A<G1$871A(&-L
M87-S('=I=&@@82!S970@;V8@9G5N8W1I;VYS('1H870@;6]R90H@("`@("!C
M;&5A;FQY(&%N9"!C;W)R96-T;'D@:6UP;&5M96YT('1H92!-24U%('-T86YD
M87)D+@I;8VIH72!S96QE8W1?;&%N9R@I(&YO=R!C:&5C:W,@9F]R(&5N('=H
M96X@=&AE(&)R;W=S97(@<F5Q=65S=',@96Y?1T(L(&5T8RX*6V-J:%T@4F5P
M;&%C960@86QL(&-A;&QS('1O(&5R96<J(&9U;F-T:6]N<R!W:71H('!R96<J
M(&9U;F-T:6]N<RP@9F]R('-P965D+@H@("`@("!"96-A=7-E(&]F('1H:7,@
M=V4@;F]W(')E<75I<F4@<&AP(#,N,"XQ,B!O<B!L871E<BX*"@HM+2TM+2T*
M=C$N,RXP"BTM+2TM+0H*6R`@(%T@1V5R;6%N('5P9&%T960*6R`@(%T@1FEX
M960@=&AE(&)R;VME;B`G8F%C:R<@;&EN:R!I;B!S971U<"YP:'`S(&9O<B!N
M;VXM16YG;&ES:"!U<V5R<PI;("`@72!M86YA9V5R+G!H<#,L(&1B+FQI8BP@
M86YD(&-O:&]R=',@87)E(&YO=R!G;VYE+B!4:&5Y('=E<F4@86QL('5N;6%I
M;G1A:6YE9"P@;W5T(&]F(&1A=&4L(&%N9"!N;W0@=F5R>2!U<V5F=6PN"B`@
M("`@(%9A<FEO=7,@8G5I;&0@<V-R:7!T<R!A<F4@=7!D871E9"!T;R!R969L
M96-T('1H:7,N"EMJ;VY=(%)E;6]V960@8V]N9FEG+V1E9F%U;'1S+G!H<#,@
M:6X@<')E9F5R96YC92!O9B!H;W)D92YP:'`S"EL@("!=($9I>&5D(&$@<V5T
M=7`N<&AP,R!B=6<@=VAE<F4@(B!W87,@=7-E9"!I;G-T96%D(&]F("<@9F]R
M("1D969A=6QT('9A;'5E<R`H;6EK92D*6R`@(%T@3F5W($9I;FYI<V@@=')A
M;G-L871I;VYS("A4:&%N:W,@=&\Z(&QE;RYJ86%S:V5L86EN96Y`:V]L=6UB
M=7,N9FDI"EL@("!=($9I>&5D(&QY;G@@<W5P<&]R="!I<W-U92!W:71H(&QO
M9VEN+G!H<#,*6R`@(%T@1FEX960@<VEG;G5P+G!H<#,@<')O8FQE;7,*6R`@
M(%T@1FEX960@<')O8FQE;2YP:'`S('!R;V)L96US("AL>6YX('-U<'!O<G0I
M"EL@("!=($%D9&5D(&1A=&%B87-E(&-R96%T:6]N('-C<FEP=',@9F]R(&)U
M:6QD:6YG('!H<&QI8B!C;VUP;&EA;B!T86)L97,*6R`@(%T@36]V960@86QL
M(&1O8W5M96YT871I;VX@*&5X8V5P="!214%$344@86YD($-/4%E)3D<I(&EN
M=&\@9&]C<R\@<W5B9&ER"EL@("!=($%D9&5D(&$@8V%C:&EN9R!C;&%S<R!S
M;R!T:&%T(&-A8VAI;F<@8V%N(&)E('1U<FYE9"!O;B!P97(@<&%G92!I9B!N
M965D960*"@HM+2TM+2T*=C$N,2XQ"BTM+2TM+0H*6R`@(%T@2&]R9&4@=6YD
M97)S=&%N9',@1G)E;F-H("AT:&%N:W,@=&\@36%T:&EE=2!#;&%B875T"B`@
M("`@(#QC;&%B875L=$!M=6QT:6UA;FEA+F-O;3XI"EL@("!=($UA:F]R(&9R
M86UE<V5T(')E9&5S:6=N"EL@("!=($%U=&\@<F5G:7-T<F%T:6]N+V-O;F=I
M<G5A=&EO;B!O9B!M;V1U;&5S"@H*+2TM+2TM"G8Q+C`N,PHM+2TM+2T*"EL@
M("!=($AO<F1E(&ES(&YO=R!W96(@<W5R9F%B;&4N"EL@("!=($AO<F1E(&AA
M;F1L97,@;'EN>"`H<'-E=61O;'DI"EL@("!=($5X=&5N9&%B;&4@;65N=7,N
M("AM96YU+G1X="!I;B!H;W)D92]C;VYF:6<I"EL@("!=(%-I9VYU<"P@<')O
M8FQE;2!R97!O<G1I;F<L(&AE;'`@9G5N8W1I;VYS(&%R92!N;W<@<&%R="!O
M9B!H;W)D90H``````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O0T]$
M24Y'7U-404Y$05)$4P``````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`V,34P-B`Q,#4Q-30S-#$S-2`P,C`W-C4`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B!(;W)D92!#;V1I;F<@4W1A;F1A<F1S"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`V+S`S
M+S$W(#`V.C$X.C`W("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XX
M-"XQ,"XQ-2`D"CI!=71H;W)S.B`@("`@("!*;VX@4&%R:7-E+"!#:'5C:R!(
M86=E;F)U8V@*.D-O;G1A8W0Z("`@("`@(&1E=D!L:7-T<RYH;W)D92YO<F<*
M"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C=&EO;BUN=6UB97)I;F<Z
M.@H*26YD96YT:6YG"CT]/3T]/3T]/0H*57-E(&%N(&EN9&5N="!O9B`T('-P
M86-E<RP@=VET:"!N;R!T86)S+@H*"D-O;G1R;VP@4W1R=6-T=7)E<PH]/3T]
M/3T]/3T]/3T]/3T]/3T*"E1H97-E(&EN8VQU9&4@8&!I9F!@+"!@8&9O<F!@
M+"!@8'=H:6QE8&`L(&!@<W=I=&-H8&`L(&5T8RX@($AE<F4@:7,@86X@97AA
M;7!L90I@8&EF8&`@<W1A=&5M96YT+"!S:6YC92!I="!I<R!T:&4@;6]S="!C
M;VUP;&EC871E9"!O9B!T:&5M.CH*"B`@:68@*"AC;VYD:71I;VXQ*2!\?"`H
M8V]N9&ET:6]N,BDI('L*("`@("`@86-T:6]N,3L*("!](&5L<V5I9B`H*&-O
M;F1I=&EO;C,I("8F("AC;VYD:71I;VXT*2D@>PH@("`@("!A8W1I;VXR.PH@
M('T@96QS92!["B`@("`@(&1E9F%U;'1A8W1I;VX["B`@?0H*375L=&DM;&EN
M92!I9B!C;VYD:71I;VYS(&%R92!B<F%C960@=&AI<R!W87DZ.@H*("!I9B`H
M*&-O;F1I=&EO;C$I('Q\("AC;VYD:71I;VXR*2!\?"`H8V]N9&ET:6]N,RD@
M?'P*("`@("`@*&-O;F1I=&EO;C0I*2!["B`@("`@(&%C=&EO;C$["B`@?0H*
M0V]N=')O;"!S=&%T96UE;G1S('-H;W5L9"!H879E(&]N92!S<&%C92!B971W
M965N('1H92!C;VYT<F]L(&ME>7=O<F0@86YD"F]P96YI;F<@<&%R96YT:&5S
M:7,L('1O(&1I<W1I;F=U:7-H('1H96T@9G)O;2!F=6YC=&EO;B!C86QL<RX*
M"D1O(&YO="!O;6ET('1H92!C=7)L>2!B<F%C97,@=6YD97(@86YY(&-I<F-U
M;7-T86YC92X@($EN('1H92!C87-E(&]F(&$@;&%R9V4*;G5M8F5R(&]F('-H
M;W)T('1E<W1S(&%N9"!A8W1I;VYS+"!T:&4@9F]L;&]W:6YG(&ES(&%C8V5P
M=&%B;&4Z.@H*("!I9B`H8V]N9&ET:6]N*2`@('L@86-T:6]N.R!]"B`@:68@
M*&-O;F1I=&EO;B`R*2![(&%C=&EO;B`R.R!]"B`@+BXN"@I&;W(@<W=I=&-H
M('-T871E;65N=',Z.@H*("!S=VET8V@@*&-O;F1I=&EO;BD@>PH@(&-A<V4@
M,3H*("`@("`@86-T:6]N,3L*("`@("`@8G)E86L["@H@(&-A<V4@,CH*("`@
M("`@86-T:6]N,CL*("`@("`@8G)E86L["@H@(&1E9F%U;'0Z"B`@("`@(&1E
M9F%U;'1A8W1I;VX["B`@("`@(&)R96%K.PH@('T*"@I&=6YC=&EO;B!#86QL
M<PH]/3T]/3T]/3T]/3T]/0H*1G5N8W1I;VYS('-H;W5L9"!B92!C86QL960@
M=VET:"!N;R!S<&%C97,@8F5T=V5E;B!T:&4@9G5N8W1I;VX@;F%M92P@=&AE
M"F]P96YI;F<@<&%R96YT:&5S:7,L(&%N9"!T:&4@9FER<W0@<&%R86UE=&5R
M.R!S<&%C97,@8F5T=V5E;B!C;VUM87,@86YD(&5A8V@*<&%R86UE=&5R+"!A
M;F0@;F\@<W!A8V4@8F5T=V5E;B!T:&4@;&%S="!P87)A;65T97(L('1H92!C
M;&]S:6YG('!A<F5N=&AE<VES+`IA;F0@=&AE('-E;6EC;VQO;BX@($AE<F4G
M<R!A;B!E>&%M<&QE.CH*"B`@)'9A<B`](&9O;R@D8F%R+"`D8F%Z+"`D<75U
M>"D["@I!<R!D:7-P;&%Y960@86)O=F4L('1H97)E('-H;W5L9"!B92!O;F4@
M<W!A8V4@;VX@96ET:&5R('-I9&4@;V8@86X@97%U86QS('-I9VX*=7-E9"!T
M;R!A<W-I9VX@=&AE(')E='5R;B!V86QU92!O9B!A(&9U;F-T:6]N('1O(&$@
M=F%R:6%B;&4N("!);B!T:&4@8V%S92!O9B!A"F)L;V-K(&]F(')E;&%T960@
M87-S:6=N;65N=',L(&UO<F4@<W!A8V4@;6%Y(&)E(&EN<V5R=&5D('1O('!R
M;VUO=&4*<F5A9&%B:6QI='DZ.@H*("`D<VAO<G0@("`@("`@("`](&9O;R@D
M8F%R*3L*("`D;&]N9U]V87)I86)L92`](&9O;R@D8F%Z*3L*"@I&=6YC=&EO
M;B!$969I;FET:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/0H*1G5N8W1I;VX@
M9&5C;&%R871I;VYS(&9O;&QO=R!T:&4@(D)31"]!;&QM86XB(&-O;G9E;G1I
M;VXZ.@H*("!F=6YC=&EO;B!F;V]&=6YC=&EO;B@D87)G,2P@)&%R9S(@/2`G
M)RD*("!["B`@("`@(&EF("AC;VYD:71I;VXI('L*("`@("`@("`@('-T871E
M;65N=#L*("`@("`@?0H@("`@("!R971U<FX@)'9A;#L*("!]"@I!<F=U;65N
M=',@=VET:"!D969A=6QT('9A;'5E<R!G;R!A="!T:&4@96YD(&]F('1H92!A
M<F=U;65N="!L:7-T+B`@06QW87ES"F%T=&5M<'0@=&\@<F5T=7)N(&$@;65A
M;FEN9V9U;"!V86QU92!F<F]M(&$@9G5N8W1I;VX@:68@;VYE(&ES(&%P<')O
M<')I871E+@H*1G5N8W1I;VYS('5S960@;VYL>2!I;B!T:&4@8W5R<F5N="!S
M8W)I<'0O8VQA<W,@*&4N9RX@<')I=F%T92!M96UB97(@;65T:&]D<RD*<VAO
M=6QD(&)E9VEN('=I=&@@82!@8%]@8"!C:&%R86-T97(@*&4N9RX@8&!?97AA
M;7!L94QI8G)A<GE@8"DN("!4:&ES(&AE;'!S"F1I<W1I;F=U:7-H('1H97-E
M('!R:79A=&4@9G5N8W1I;VX@8V%L;',@9G)O;2!O=&AE<BP@<'5B;&EC(&9U
M;F-T:6]N(&-A;&QS+@H*"D-L87-S($1E9FEN:71I;VYS"CT]/3T]/3T]/3T]
M/3T]/3T]"@I#;&%S<R!D969I;FET:6]N<R!F;VQL;W<@=&AE(")+)E(O2V5R
M;F5L(B!C;VYV96YT:6]N.CH*"B`@8VQA<W,@4V]M95]#;&%S<R!["@H@("`@
M("!V87(@)%]V87)I86)L93L*"B`@("`@(&9U;F-T:6]N(&9O;T9U;F-T:6]N
M*"D*("`@("`@>PH@("`@("`@("`@<W1A=&5M96YT.PH@("`@("!]"@H@('T*
M"DYO=&4@=&AE(&)L86YK(&QI;F5S(&%T('1H92!B96=I;FYI;F<@86YD(&5N
M9"!O9B!T:&4@8VQA<W,@9&5F:6YI=&EO;BX*"@I.86UI;F<@3&EB<F%R:65S
M"CT]/3T]/3T]/3T]/3T]/3T*"DQI8G)A<FEE<R`H86YY(&9I;&4@;&]C871E
M9"!I;B!T:&4@8&!L:6(O8&`@9&ER96-T;W)Y(&]F('1H92!A<'!L:6-A=&EO
M;BD*<VAO=6QD(&)E(&YA;65D('=I=&@@8V%P:71A;"!L971T97)S(&%T('1H
M92!B96=I;FYI;F<@;V8@96%C:"!W;W)D+B`@57-E"G-T=61L>6-A<',@9F]R
M(&YA;6EN9SL@82!S97-S:6]N(&-A8VAE(&-L87-S('=O=6QD(&)E('-T;W)E
M9"!I;@I@8&QI8B]397-S:6]N0V%C:&4N<&AP8&`N"@I)9B!T:&4@;&EB<F%R
M>2]C;&%S<R!I<R!E>'1E;F1E9"P@=&AE(&5X=&5N9&EN9R!F:6QE<R!S:&]U
M;&0@8F4@<W1O<F5D(&EN(&$*9&ER96-T;W)Y('5N9&5R(&!@;&EB+V!@('=I
M=&@@=&AE('-A;64@;F%M92!A<R!T:&4@;W)I9VEN86P@;&EB<F%R>2X*4W5B
M8VQA<W-E<R!F;VQL;W<@=&AE(&5X86-T('-A;64@;F%M:6YG(')E<75I<F5M
M96YT<RP@97AC97!T('1H870@:68@=&AE"G-U8F-L87-S(&ES(&EN<W1A;G1I
M871E9"!B>2!A(&9A8W1O<GD@;65T:&]D+"!I="!S:&]U;&0@8F4@86QL(&QO
M=V5R8V%S92X*"D5X86UP;&4*+2TM+2TM+0H*5&AE(")%>&%M<&QE($QI8G)A
M<GDB(&QI8G)A<GD@<VAO=6QD(&)E('-A=F5D(&%S(&!@;&EB+T5X86UP;&5,
M:6)R87)Y+G!H<&!@+@I!;GD@9FEL92!E>'1E;F1I;F<@=&AE(&QI8G)A<GDO
M8VQA<W,@<VAO=6QD(&)E('-T;W)E9"!I;B!T:&4@9&ER96-T;W)Y"F!@;&EB
M+T5X86UP;&5,:6)R87)Y+V!@+@H*"D-O;6UE;G1S"CT]/3T]/3T]"@I);FQI
M;F4@9&]C=6UE;G1A=&EO;B!F;W(@8VQA<W-E<R!S:&]U;&0@9F]L;&]W('1H
M92!@2F%V861O8R!C;VYV96YT:6]N8%\N"@HN+B!?2F%V861O8R!C;VYV96YT
M:6]N.B!H='1P.B\O:F%V82YS=6XN8V]M+W!R;V1U8W1S+VID:R]J879A9&]C
M+W=R:71I;F=D;V-C;VUM96YT<R]I;F1E>"YH=&UL"@I1=6EC:R!E>&%M<&QE
M(&9O<B!P<FEV871E('9A<FEA8FQE(&1E9FEN:71I;VX@9F]R($AO<F1E.CH*
M"B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&1E<V-R:7!T:6]N+@H@("`@("H*
M("`@("`J($!V87(@9&%T871Y<&4*("`@("`J+PH*475I8VL@97AA;7!L92!F
M=6YC=&EO;B!D969I;FET:6]N(&9O<B!(;W)D93HZ"@H@("`@+RHJ"B`@("`@
M*B!4:&4@9&5S8W)I<'1I;VX@;V8@=&AE(&9U;F-T:6]N(&=O97,@:&5R92X*
M("`@("`J"B`@("`@*B!`86-C97-S(%MP<FEV871E('P@<')O=&5C=&5D70H@
M("`@("H@6T1O;B=T(&)O=&AE<B!W:71H(")P=6)L:6,B('-I;F-E(&ET(&ES
M('1H92!D969A=6QT(&EF(&YO="!S<&5C:69I960N70H@("`@("H*("`@("`J
M($!P87)A;2!D871A='EP92`D=F%R:6%B;&5N86UE("`@1&5S8W)I<'1I;VX@
M;V8@=F%R:6%B;&4N"B`@("`@*B!`<&%R86T@9&%T871Y<&4@)'9A<FEA8FQE
M,FYA;64@($1E<V-R:7!T:6]N(&]F('9A<FEA8FQE,BX*("`@("`J("XN+@H@
M("`@("H@6TEN<V5R="`R('-P86-E<R!A9G1E<B!T:&4@;&]N9V5S="`D=F%R
M:6%B;&4@9&5F:6YI=&EO;BP@86YD('1H96X@;&EN90H@("`@("H@('5P(&%L
M;"!D97-C<FEP=&EO;G,@=VET:"!T:&ES(&1E<V-R:7!T:6]N70H@("`@("H*
M("`@("`J($!R971U<FX@9&%T871Y<&4@($1E<V-R:7!T:6]N(&]F(')E='5R
M;B!V86QU92X*("`@("`J(%M/;F-E(&%G86EN+"!I;G-E<G0@,B!S<&%C97,@
M869T97(@=&AE(&1A=&%T>7!E+"!A;F0@;&EN92!U<"!A;&P*("`@("`J("!S
M=6)S97%U96YT(&QI;F5S+"!I9B!A;GDL('=I=&@@=&AI<R!C:&%R86-T97(N
M70H@("`@("H*("`@("`J($!A8G-T<F%C="!;3VYL>2!I9B!N96-E<W-A<GE=
M"B`@("`@*@H@("`@("H@0'-I;F-E($AO<F1E('@N>"!;3VYL>2!I9B!N96-E
M<W-A<GD@+2!U<V4@:68@9G5N8W1I;VX@:7,@861D960@=&\@=&AE"B`@("`@
M*B!C=7)R96YT(')E;&5A<V4@=F5R<VEO;G,@=&\@:6YD:6-A=&4@=&AA="!T
M:&4@9G5N8W1I;VX@:&%S(&YO="!B965N"B`@("`@*B!A=F%I;&%B;&4@:6X@
M<')E=FEO=7,@=F5R<VEO;G,N70H@("`@("HO"@H*26YC;'5D:6YG($-O9&4*
M/3T]/3T]/3T]/3T]/3T*"DEF('EO=2!A<F4@:6YC;'5D:6YG(&$@8VQA<W,L
M(&9U;F-T:6]N(&QI8G)A<GDL(&]R(&%N>71H:6YG(&5L<V4@=VAI8V@@=V]U
M;&0*8V%U<V4@82!P87)S92!E<G)O<B!I9B!I;F-L=61E9"!T=VEC92P@86QW
M87ES('5S92!@:6YC;'5D95]O;F-E8%\N("!4:&ES('=I;&P*96YS=7)E('1H
M870@;F\@;6%T=&5R(&AO=R!M86YY(&9A8W1O<GD@;65T:&]D<R!W92!U<V4@
M;W(@:&]W(&UU8V@@9'EN86UI8PII;F-L=7-I;VX@=V4@9&\L('1H92!L:6)R
M87)Y('=I;&P@;VYL>2!B92!I;F-L=61E9"!O;F-E+@H*268@>6]U(&%R92!I
M;F-L=61I;F<@82!S=&%T:6,@9FEL96YA;64L('-U8V@@87,@82!C;VYF(&9I
M;&4@;W(@82!T96UP;&%T92!T:&%T"FES("IA;'=A>7,J('5S960L('5S92!@
M<F5Q=6ER96!?+@H*268@>6]U(&%R92!D>6YA;6EC86QL>2!I;F-L=61I;F<@
M82!F:6QE;F%M92P@;W(@=V%N="!T:&4@8V]D92!T;R!O;FQY(&)E('5S960*
M8V]N9&ET:6]N86QL>2`H86X@;W!T:6]N86P@=&5M<&QA=&4I+"!U<V4@8&EN
M8VQU9&5@7RX*"BXN(%]I;F-L=61E7V]N8V4Z(&AT='`Z+R]W=W<N<&AP+FYE
M="]M86YU86PO96XO9G5N8W1I;VXN:6YC;'5D92UO;F-E+G!H<`HN+B!?<F5Q
M=6ER93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYR
M97%U:7)E+G!H<`HN+B!?:6YC;'5D93H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA
M;G5A;"]E;B]F=6YC=&EO;BYI;F-L=61E+G!H<`H*"E!(4"!#;V1E(%1A9W,*
M/3T]/3T]/3T]/3T]/0H*06QW87ES('5S92!@8#P_<&AP(#\^8&`@=&\@9&5L
M:6UI="!02%`@8V]D92P@;F]T('1H92!@8#P_(#\^8&`@<VAO<G1H86YD+@I4
M:&ES(&ES(')E<75I<F5D(&9O<B!014%2(&-O;7!L:6%N8V4@86YD(&ES(&%L
M<V\@=&AE(&UO<W0@<&]R=&%B;&4@=V%Y('1O"FEN8VQU9&4@4$A0(&-O9&4@
M;VX@9&EF9F5R:6YG(&]P97)A=&EN9R!S>7-T96US(&%N9"!S971U<',N"@I)
M;B!T96UP;&%T97,L(&UA:V4@<W5R92!T;R!U<V4@=&AI<R!A<R!W96QL("A@
M8#P_<&AP(&5C:&\@)'9A<FYA;64@/SY@8"DL(&%S"G1H92!S:&]R=&-U="!V
M97)S:6]N("A@8#P_/2`D=F%R(#\^8&`I(&1O97,@;F]T('=O<FL@=VET:"!@
M<VAO<G1?;W!E;E]T86=@7PIT=7)N960@;V9F+@H*+BX@7W-H;W)T7V]P96Y?
M=&%G.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V-O;F9I9W5R871I
M;VXN9&ER96-T:79E<RYP:'`C:6YI+G-H;W)T+6]P96XM=&%G"@H*2&5A9&5R
M($-O;6UE;G0@0FQO8VMS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QL('-O
M=7)C92!C;V1E(&9I;&5S(&EN('1H92!(;W)D92!D:7-T<FEB=71I;VX@<VAO
M=6QD(&-O;G1A:6X@=&AE(&9O;&QO=VEN9PIC;VUM96YT(&)L;V-K(&%S('1H
M92!H96%D97(Z"@I%>&%M<&QE(&9O<B!@3$=03&!?)V5D($AO<F1E(&-O9&4Z
M.@H*("`@("\J*@H@("`@("H@5&AE($AO<F1E7T9O;SHZ(&-L87-S('!R;W9I
M9&5S(&%N($%022!F;W(@=F%R:6]U<R!F;V\*("`@("`J('1E8VAN:7%U97,@
M=&AA="!C86X@8F4@=7-E9"!B>2!(;W)D92!A<'!L:6-A=&EO;G,N"B`@("`@
M*@H@("`@("H@)$AO<F1E"B`@("`@*@H@("`@("H@0V]P>7)I9VAT(#$Y.3DM
M,C`P,2!/<FEG:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@
M("`J($-O<'ER:6=H="`R,#`Q(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M
M/@H@("`@("H*("`@("`J(%-E92!T:&4@96YC;&]S960@9FEL92!#3U!924Y'
M(&9O<B!L:6-E;G-E(&EN9F]R;6%T:6]N("A,1U!,*2X@268@>6]U"B`@("`@
M*B!D:60@;F]T(')E8V5I=F4@=&AI<R!F:6QE+"!S964@:'1T<#HO+W=W=RYF
M<V8N;W)G+V-O<'EL969T+VQG<&PN:'1M;"X*("`@("`J"B`@("`@*B!`875T
M:&]R("!/<FEG:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@
M("`J($!A=71H;W(@(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M/@H@("`@
M("H@0'-I;F-E("`@2&]R9&4@,RXP"B`@("`@*B!`<&%C:V%G92!(;W)D95]0
M86-K86=E"B`@("`@*B\*"BXN(%],1U!,.B!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+VQG<&PM;&EC96YS92YP:'`*"D5X86UP;&4@9F]R
M(&!'4$Q@7R=E9"!A<'!L:6-A=&EO;B!C;V1E.CH*"B`@("`O*BH*("`@("`J
M(%1H92!!<'!?0F%R.CH@8VQA<W,@8V]N=&%I;G,@86QL(&9U;F-T:6]N<R!R
M96QA=&5D('1O(&AA;F1L:6YG"B`@("`@*B!B87)S(&EN($%P<"X*("`@("`J
M"B`@("`@*B`D2&]R9&4*("`@("`J"B`@("`@*B!#;W!Y<FEG:'0@,3DY.2TR
M,#`Q($]R:6=I;F%L($%U=&AO<B`\875T:&]R0&5X86UP;&4N8V]M/@H@("`@
M("H@0V]P>7)I9VAT(#(P,#$@66]U<B!.86UE(#QY;W5`97AA;7!L92YC;VT^
M"B`@("`@*@H@("`@("H@4V5E('1H92!E;F-L;W-E9"!F:6QE($-/4%E)3D<@
M9F]R(&QI8V5N<V4@:6YF;W)M871I;VX@*$=03"DN($EF('EO=0H@("`@("H@
M9&ED(&YO="!R96-E:79E('1H:7,@9FEL92P@<V5E(&AT='`Z+R]W=W<N9G-F
M+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"X*("`@("`J"B`@("`@*B!`875T:&]R
M("!/<FEG:6YA;"!!=71H;W(@/&%U=&AO<D!E>&%M<&QE+F-O;3X*("`@("`J
M($!A=71H;W(@(%EO=7(@3F%M92`\>6]U0&5X86UP;&4N8V]M/@H@("`@("H@
M0'-I;F-E("`@07!P(#$N,`H@("`@("H@0'!A8VMA9V4@87!P"B`@("`@*B\*
M"@HN+B!?1U!,.B!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V=P;"UL:6-E;G-E+G!H<`H*5&AE<F4G<R!N;R!H87)D(')U;&4@=&\@9&5T
M97)M:6YE('=H96X@82!N97<@8V]D92!C;VYT<FEB=71E<B!S:&]U;&0@8F4@
M861D960*=&\@=&AE(&QI<W0@;V8@875T:&]R<R!F;W(@82!G:79E;B!S;W5R
M8V4@9FEL92X@($EN(&=E;F5R86PL('1H96ER(&-H86YG97,*<VAO=6QD(&9A
M;&P@:6YT;R!T:&4@(G-U8G-T86YT:6%L(B!C871E9V]R>2`H;65A;FEN9R!S
M;VUE=VAE<F4@87)O=6YD(#$P)2!T;PHR,"4@;V8@8V]D92!C:&%N9V5S*2X@
M($5X8V5P=&EO;G,@8V]U;&0@8F4@;6%D92!F;W(@<F5W<FET:6YG(&9U;F-T
M:6]N<R!O<@IC;VYT<FEB=71I;F<@;F5W(&QO9VEC+@H*4VEM<&QE(&-O9&4@
M<F5O<F=A;FEZ871I;VX@;W(@8G5G(&9I>&5S('=O=6QD(&YO="!J=7-T:69Y
M('1H92!A9&1I=&EO;B!O9B!A"FYE=R!I;F1I=FED=6%L('1O('1H92!L:7-T
M(&]F(&%U=&AO<G,N"@H*0U93(%1A9W,*/3T]/3T]/3T*"DEN8VQU9&4@=&AE
M(#QD;VQL87(^2&]R9&4Z(#QD;VQL87(^($-64R!V96YD;W(@=&%G(&EN(&5A
M8V@@9FEL92X@($%S(&5A8V@@9FEL90II<R!E9&ET960L(&%D9"!T:&ES('1A
M9R!I9B!I="=S(&YO="!Y970@<')E<V5N="`H;W(@<F5P;&%C92!E>&ES=&EN
M9R!F;W)M<PIS=6-H(&%S(#QD;VQL87(^260\9&]L;&%R/BP@(DQA<W0@36]D
M:69I960Z(BP@971C+BDN"@I%6$-%4%1)3TXZ($1O;B=T(&EN8VQU9&4@=&AE
M<V4@:6X@=&5M<&QA=&5S+@H*"D5X86UP;&4@55),<PH]/3T]/3T]/3T]/3T*
M"E5S92!@8&5X86UP;&4N8V]M8&`@9F]R(&%L;"!E>&%M<&QE(%523',L('!E
M<B!@4D9#(#(V,#9@7RX*"BXN(%]21D,@,C8P-CH@:'1T<#HO+W=W=RYF87%S
M+F]R9R]R9F-S+W)F8S(V,#8N:'1M;`H*"G!H<"YI;FD@<V5T=&EN9W,*/3T]
M/3T]/3T]/3T]/3T]/0H*06QL($AO<F1E(&-O9&4@<VAO=6QD('=O<FL@=VET
M:"!@<F5G:7-T97)?9VQO8F%L<V!?(&1I<V%B;&5D+B`@5&AI<R!M96%N<PIU
M<VEN9R!@8"1?0T]/2TE%8&`L(&!@)%]315-324].8&`L(&!@)%]315)615)@
M8"!A;F0@8&`D7T5.5F!@('1O(&%C8V5S<R!A;&P*8V]O:VEE+"!S97-S:6]N
M+"!S97)V97(@86YD(&5N=FER;VYM96YT(&1A=&$L(')E<W!E8W1I=F5L>2X*
M"E1O(')E=')I979E('!O<W1E9"!D871A("AI;B!T:&4@9VQO8F%L(&!@)%]'
M151@8"!A;F0@8&`D7U!/4U1@8"!V87)I86)L97,I+`IY;W4@<VAO=6QD(&YO
M<FUA;&QY('5S92!@571I;#HZ9V5T1F]R;41A=&$H*6!?('=H:6-H('=I;&P@
M875T;VUA=&EC86QL>2!R=6X*8%5T:6PZ.F1I<W!E;$UA9VEC475O=&5S*"E@
M7RX@5&AI<R!W:6QL(&5N<W5R92!T:&%T(&%L;"!(;W)D92!C;V1E('=I;&P@
M=V]R:PIR96=A<F1L97-S(&]F('1H92!S971T:6YG(&]F(&!M86=I8U]Q=6]T
M97-?9W!C8%\N(%1H92!O;FQY('1I;64@>6]U('-H;W5L9"!N;W0*=7-E(&!5
M=&EL.CIG971&;W)M1&%T82@I8%\@:7,@:68@>6]U('=A;G0@=&\@9&ER96-T
M;'D@86-C97-S(&$@1T54(&]R(%!/4U0*=F%R:6%B;&4@:6YS=&5A9#L@:6X@
M=&AI<R!C87-E+"!Y;W4@<VAO=6QD('5S92!@571I;#HZ9V5T1V5T*"E@7R!O
M<@I@571I;#HZ9V5T4&]S="@I8%\@<F5S<&5C=&EV96QY+@H*06QL($AO<F1E
M(&-O9&4@<VAO=6QD('=O<FL@=VET:"!@97)R;W)?<F5P;W)T:6YG8%\@/2!%
M7T%,3"X@1F%I;'5R92!T;R!D;R!S;PIW;W5L9"!R97-U;'0@:6X@=6=L>2!O
M=71P=70L(&5R<F]R(&QO9W,@9V5T=&EN9R!F:6QL960@=VET:"!L;W1S(&]F
M('=A<FYI;F<*;65S<V%G97,L(&]R(&5V96X@9&]W;G)I9VAT(&)R;VME;B!S
M8W)I<'1S+@H*3F\@2&]R9&4@8V]D92!S:&]U;&0@87-S=6UE('1H870@)RXG
M(&ES(&EN('1H92!I;F-L=61E('!A=&@N($%L=V%Y<R!S<&5C:69Y"B<N+R<@
M:6X@9G)O;G0@;V8@82!F:6QE;F%M92!W:&5N('EO=2!A<F4@:6YC;'5D:6YG
M(&$@9FEL92!I;B!T:&4@<V%M90ID:7)E8W1O<GDN"@HN+B!?<F5G:7-T97)?
M9VQO8F%L<SH@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]S96-U<FET
M>2YR96=I<W1E<F=L;V)A;',N<&AP"BXN(%]M86=I8U]Q=6]T97-?9W!C.B!H
M='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+W)E9BYI;F9O+G!H<"-I;FDN
M;6%G:6,M<75O=&5S+6=P8PHN+B!?97)R;W)?<F5P;W)T:6YG.B!H='1P.B\O
M=W=W+G!H<"YN970O;6%N=6%L+V5N+W)E9BYE<G)O<F9U;F,N<&AP(VEN:2YE
M<G)O<BUR97!O<G1I;F<*+BX@7U5T:6PZ.F=E=$9O<FU$871A*"DZ(&AT='`Z
M+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO2&]R9&5?571I;"]5=&EL
M+FAT;6PC;65T:&]D9V5T1F]R;41A=&$*+BX@7U5T:6PZ.F1I<W!E;$UA9VEC
M475O=&5S*"DZ(&AT='`Z+R]D978N:&]R9&4N;W)G+V%P:2]F<F%M97=O<FLO
M2&]R9&5?571I;"]5=&EL+FAT;6PC;65T:&]D9&ES<&5L36%G:6-1=6]T97,*
M+BX@7U5T:6PZ.F=E=$=E="@I.B!H='1P.B\O9&5V+FAO<F1E+F]R9R]A<&DO
M9G)A;65W;W)K+TAO<F1E7U5T:6PO571I;"YH=&UL(VUE=&AO9&=E=$=E=`HN
M+B!?571I;#HZ9V5T4&]S="@I.B!H='1P.B\O9&5V+FAO<F1E+F]R9R]A<&DO
M9G)A;65W;W)K+TAO<F1E7U5T:6PO571I;"YH=&UL(VUE=&AO9&=E=%!O<W0*
M"@I82%1-3"`Q+C`@0V]M<&QI86YC90H]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M06QL('1A9R!N86UE<R!A;F0@<&%R86UE=&5R<R!M=7-T(&)E(&QO=V5R(&-A
M<V4@:6YC;'5D:6YG(&IA=F%S8W)I<'0@979E;G0*:&%N9&QE<G,Z.@H*("`@
M(#QF;VYT(&-O;&]R/2(C1D9&1D9&(CXN+BX\+V9O;G0^"B`@("`\82!H<F5F
M/2)H='1P.B\O97AA;7!L92YC;VTB(&]N;6]U<V5O=F5R/2)S=&%T=7,])R<B
M(&]N;6]U<V5O=70](G-T871U<STG)R(^+BXN/"]A/@H*06QL('1A9R!P87)A
M;65T97)S(&UU<W0@8F4@;V8@82!V86QI9"!P87)A;65T97(](G9A;'5E(B!F
M;W)M("AN=6UE<FEC('9A;'5E<PIM=7-T(&%L<V\@8F4@<W5R<F]U;F1E9"!B
M>2!Q=6]T97,I+B`@1F]R('!A<F%M971E<G,@=&AA="!H860@;F\@=F%L=64@
M:6X@2%1-3"P*=&AE('!A<F%M971E<B!N86UE(&ES('1H92!V86QU92X@($9O
M<B!E>&%M<&QE.CH*"B`@("`\:6YP=70@='EP93TB8VAE8VMB;W@B(&-H96-K
M960](F-H96-K960B/@H@("`@/'-E;&5C="!N86UE/2)E>&%M<&QE(CX*("`@
M("`@("`\;W!T:6]N('-E;&5C=&5D/2)S96QE8W1E9"(@=F%L=64](C$B/D5X
M86UP;&4\+V]P=&EO;CX*("`@(#PO<V5L96-T/@H@("`@/'1D(&YO=W)A<#TB
M;F]W<F%P(CY%>&%M<&QE/"]T9#X*"D%L;"!T86=S(&UU<W0@8F4@<')O<&5R
M;'D@8VQO<V5D+B`@5&%G<R!W:&5R92!C;&]S:6YG(&ES(&9O<F)I9&1E;B!M
M=7-T(&5N9`IW:71H(&$@<W!A8V4@86YD(&$@<VQA<V@Z.@H*("`@(#QB<B`O
M/@H@("`@/&AR("\^"B`@("`\:6UG('-R8STB97AA;7!L92YG:68B(&%L=#TB
M17AA;7!L92(@+SX*("`@(#QI;G!U="!T>7!E/2)S=6)M:70B('9A;'5E/2)%
M>&%M<&QE(B`O/@H*06QL(&9O<FT@9&5F:6YI=&EO;G,@;75S="!B92!O;B!T
M:&5I<B!O=VX@;&EN92!A;F0@96ET:&5R(&9U;&QY(&1E9FEN960@=VET:&EN
M"F$@8&`\=&0^/"]T9#Y@8"!P86ER(&]R(&)E(&]U='-I9&4@=&%B;&4@=&%G
M<RX@($9O<FUS(&UU<W0@86QS;R!A;'=A>7,@:&%V92!A;@IA8W1I;VX@<&%R
M86UE=&5R.CH*"B`@("`\9F]R;2!M971H;V0](G!O<W0B(&%C=&EO;CTB:'1T
M<#HO+V5X86UP;&4N8V]M+V5X86UP;&4N8V=I(CX*("`@(#QT86)L93X*("`@
M("`@("`\='(^/'1D/F5X86UP;&4\+W1D/CPO='(^"B`@("`\+W1A8FQE/@H@
M("`@/"]F;W)M/@H*("`@(#QT86)L93X*("`@("`@("`\='(^/'1D/@H@("`@
M("`@("`@("`\9F]R;2!A8W1I;VX](FIA=F%S8W)I<'0Z=F]I9"@P*2(@;VYS
M=6)M:70](G)E='5R;B!F86QS93LB/@H@("`@("`@("`@("`\+V9O<FT^"B`@
M("`@("`@/"]T9#X\+W1R/@H@("`@/"]T86)L93X*"D%L;"!*879A4V-R:7!T
M('1A9W,@;75S="!H879E(&$@=F%L:60@='EP92!P87)A;65T97(Z.@H*("`@
M(#QS8W)I<'0@='EP93TB=&5X="]J879A<V-R:7!T(CX*("`@(#PA+2T*("`@
M("XN+@H@("`@+R\@+2T^"B`@("`\+W-C<FEP=#X*"DYO=&AI;F<@;6%Y(&%P
M<&5A<B!A9G1E<B!@8#PO:'1M;#Y@8"P@=&AE<F5F;W)E(&EN8VQU9&4@86YY
M(&-O;6UO;B!F;V]T97)S"F%F=&5R(&%L;"!O=&AE<B!O=71P=70N"@I!;&P@
M:6UA9V5S(&UU<W0@:&%V92!A;B!@8&%L=&!@(&%T=')I8G5T93HZ"@H@("`@
M/&EM9R!S<F,](F5X86UP;&4N9VEF(B!A;'0](CP_<&AP(&5C:&\@7R@B17AA
M;7!L92(I(#\^(B`O/@H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG*"=E>&%M
M<&QE+F=I9B<L(%\H(D5X86UP;&4B*2D@/SX@("`@("`@("`@("`@("`@("`H
M3VX@=&AE($A%040@8G)A;F-H*0H@("`@/#]P:'`@96-H;R!(;W)D93HZ:6UG
M*"=E>&%M<&QE+F=I9B<L("=A;'0](B<@+B!?*")%>&%M<&QE(BD@+B`G(B<I
M(#\^("`H3VX@=&AE(%)%3$5.1U\R(&)R86YC:"D*"DEN<'5T(&9I96QD<R!O
M9B!T>7!E(")I;6%G92(@9&\@;F]T(&%L;&]W('1H92!B;W)D97(@871T<FEB
M=71E(&%N9"!M87D@<F5N9&5R"G=I=&@@82!B;W)D97(@;VX@<V]M92!B<F]W
M<V5R<RX@(%5S92!T:&4@9F]L;&]W:6YG(&EN<W1E860Z.@H*("`@/&$@:')E
M9CTB(B!O;F-L:6-K/2)D;V-U;65N="YF;W)M;F%M92YS=6)M:70H*3L@<F5T
M=7)N(&9A;'-E.R(^/#]P:'`@96-H;R!(;W)D93HZ:6UG*")E>&%M<&QE+F=I
M9B(L(%\H(D5X86UP;&4B*2D@/SX\+V$^"@H*1&%T86)A<V4@3F%M:6YG($-O
M;G9E;G1I;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*06QL(&1A
M=&%B87-E('1A8FQE<R!U<V5D(&)Y($AO<F1E(')E<V]U<F-E<R!A;F0@2&]R
M9&4@87!P;&EC871I;VYS(&YE960@=&\*;6%K92!S=7)E('1H870@=&AE:7(@
M=&%B;&4@86YD(&9I96QD(&YA;65S('=O<FL@:6X@86QL(&1A=&%B87-E<RX@
M($UA;GD*9&%T86)A<V5S(')E<V5R=F4@=V]R9',@;&EK92`G=6ED)RP@)W5S
M97(G+"!E=&,N(&9O<B!I;G1E<FYA;"!U<V4L(&%N9"!F;W)B:60*=V]R9',@
M=&AA="!A<F4@4U%,(&ME>7=O<F1S("AS96QE8W0L('=H97)E+"!E=&,N*2X@
M($%L<V\L(&%L;"!N86UE<R!S:&]U;&0@8F4*;&]W97)C87-E+"!W:71H('5N
M9&5R<V-O<F5S("@G7R<I('1O('-E<&%R871E('=O<F1S+"!T;R!A=F]I9"!C
M87-E('-E;G-I=&EV:71Y"FES<W5E<RX*"D$@9V]O9"!W87D@=&\@9&\@=&AI
M<R!F;W(@9FEE;&0@;F%M97,@:7,@=&\@;6%K92!T:&4@9FEE;&0@;F%M90IT
M86)L96YA;65?9FEE;&1N86UE+@H*3W1H97(@9V5N97)A;"!G=6ED96QI;F5S
M.B!486)L92!N86UE<R!S:&]U;&0@8F4@<&QU<F%L("AU<V5R<RD[(&9I96QD
M(&YA;65S"G-H;W5L9"!B92!S:6YG=6QA<B`H=7-E<E]N86UE*2X*"@I296=U
M;&%R($5X<')E<W-I;VX@57-E"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"D%L
M=V%Y<R!U<V4@=&AE(&!P<F5G7V!?(&9U;F-T:6]N<R!I9B!P;W-S:6)L92!I
M;G-T96%D(&]F(&!E<F5G7V!?("AA;F0*8'!R96=?<W!L:70H*6!?(&EN<W1E
M860@;V8@8'-P;&ET*"E@7RD[('1H97D@87)E(&EN8VQU9&5D(&EN(%!(4"!B
M>2!D969A=6QT"F%N9"!M=6-H(&UO<F4@969F:6-I96YT(&%N9"!M=6-H(&9A
M<W1E<B!T:&%N(&!E<F5G7V!?+@H**BI.159%4BHJ('5S92!A(')E9W5L87(@
M97AP<F5S<VEO;B!T;R!M871C:"!O<B!R97!L86-E(&$@<W1A=&EC('-T<FEN
M9RX*8&5X<&QO9&4H*6!?("AI;B!P;&%C92!O9B!@<W!L:70H*6!?*2P@8'-T
M<E]R97!L86-E*"E@7RP@8'-T<G!O<R@I8%\L(&]R"F!S=')T<B@I8%\@9&\@
M=&AE(&IO8B!M=6-H(&UO<F4@969F:6-I96YT;'DN"@HN+B!?<')E9U\Z(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO<F5F+G!C<F4N<&AP"BXN(%]E
M<F5G7SH@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]R968N<F5G97@N
M<&AP"BXN(%]P<F5G7W-P;&ET*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU
M86PO96XO9G5N8W1I;VXN<')E9RUS<&QI="YP:'`*+BX@7W-P;&ET*"DZ(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN<W!L:70N<&AP
M"BXN(%]E>'!L;V1E*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO
M9G5N8W1I;VXN97AP;&]D92YP:'`*+BX@7W-T<E]R97!L86-E*"DZ(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN<W1R+7)E<&QA8V4N
M<&AP"BXN(%]S=')P;W,H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E
M;B]F=6YC=&EO;BYS=')P;W,N<&AP"BXN(%]S=')T<B@I.B!H='1P.B\O=W=W
M+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N+G-T<G1R+G!H<`H*"E!A<F%M
M971E<B!087-S:6YG"CT]/3T]/3T]/3T]/3T]/3T]"@I/8FIE8W1S('-H;W5L
M9"!B92!P87-S960@8GD@<F5F97)E;F-E+B`@179E<GET:&EN9R!E;'-E+"!I
M;F-L=61I;F<@87)R87ES+`IS:&]U;&0@8F4@<&%S<V5D(&)Y('9A;'5E('=H
M97)E=F5R('-E;6%N=&EC86QL>2!P;W-S:6)L92X*"EM:96YD($5N9VEN92`R
M.B!O8FIE8W1S('-H;W5L9"!A;'-O(&)E('!A<W-E9"!B>2!V86QU95T*"E1H
M:7,@<')A8W1I8V4@=&%K97,@9G5L;"!A9'9A;G1A9V4@;V8@<F5F97)E;F-E
M(&-O=6YT:6YG+@H*+BX@3F]T93HZ(%1H92!@=&5R;F%R>2!O<&5R871O<F!?
M(&%U=&]M871I8V%L;'D@<F5T=7)N<R!A(&-O<'D@;V8@:71S"B`@("`@("`@
M("!O<&5R86YD<RP@<V\@9&]N)W0@=7-E(&ET('=I=&@@;V)J96-T<RP@;W(@
M:68@>6]U(&%R92!S=7)E('EO=2!W86YT"B`@("`@("`@("!T;R!R971U<FX@
M86X@;V)J96-T(&-O<'DN"@HN+B!?8'1E<FYA<GD@;W!E<F%T;W)@.B!H='1P
M.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+VQA;F=U86=E+F]P97)A=&]R<RYC
M;VUP87)I<V]N+G!H<"-L86YG=6%G92YO<&5R871O<G,N8V]M<&%R:7-O;BYT
M97)N87)Y"@H*3&]N9R!,:6YE<PH]/3T]/3T]/3T]"@I7<F%P(&QI;F5S(&%T
M(#@P(&-H87)A8W1E<G,L(&EN8VQU9&EN9R!C;VUM96YT<RP@=6YL97-S('1H
M:7,@<V5V97)E;'D@:6UP86-T<PIT:&4@8VQA<FET>2!O9B!T:&4@8V]D92X@
M($%L=V%Y<R!W<F%P(&-O;6UE;G1S+@H*"DQI;F4@0G)E86MS"CT]/3T]/3T]
M/3T]"@I/;FQY('5S92!53DE8('-T>6QE(&]F(&QI;F5B<F5A:R`H8&!<;F!@
M*2P@;F]T(%=I;F1O=W,O1$]3+TUA8R!S='EL90HH8&!<<EQN8&`I+@H*57-I
M;F<@=FEM+"!T;R!C;VYV97)T(&9R;VT@1$]3('-T>6QE('1Y<&4Z.@H*("`@
M(#IS970@9F8]=6YI>`H*57-I;F<@=FDL('1O(&-O;G9E<G0@9G)O;2!$3U,@
M<W1Y;&4@='EP93HZ"@H@("`@.F<O7DTO<R\O+V<*"BA.;W1E('1H870@=&AE
M(&!@7DU@8"!I<R!A(&-O;G1R;VP@8VAA<F%C=&5R+"!A;F0@=&\@<F5P<F]D
M=6-E(&ET('=H96X@>6]U"G1Y<&4@:6X@=&AE('9I(&-O;6UA;F0@>6]U(&AA
M=F4@=&\@<&%D(&ET(&9I<G-T('5S:6YG('1H92!S<&5C:6%L(&!@7E9@8`IC
M:&%R86-T97(N*0H*"E!R:79A=&4@5F%R:6%B;&5S"CT]/3T]/3T]/3T]/3T]
M/3T]"@I687)I86)L97,@=7-E9"!E>&-L=7-I=F5L>2!W:71H:6X@82!C;&%S
M<R!S:&]U;&0@8F5G:6X@=VET:"!A('5N9&5R<V-O<F4@*"=?)RD*8VAA<F%C
M=&5R+B`@06X@97AA;7!L92!C;&%S<R!V87)I86)L92!D969I;FET:6]N.B`@
M8&!V87(@)%]V87)I86)L96YA;64[8&`*"@I!<G)A>2!$969I;FET:6]N<PH]
M/3T]/3T]/3T]/3T]/3T]/0H*5VAE;B!D969I;FEN9R!A<G)A>7,L(&]R(&YE
M<W1E9"!A<G)A>7,L('5S92!T:&4@9F]L;&]W:6YG(&9O<FUA="P@=VAE<F4*
M:6YD96YT871I;VX@:7,@;F]T960@=FEA('1H92!C;&]S:6YG('!A<F5N=&AE
M<VES(&-H87)A8W1E<G,Z.@H*("`@("1A<G)A>6YA;65;)VEN9&5X)UT@/2!A
M<G)A>2@*("`@("`@("`G;F%M93$G(#T^("=V86QU93$G+`H@("`@("`@("=N
M86UE,B<@/3X@87)R87DH"B`@("`@("`@("`@("=S=6)N86UE,2<@/3X@)W-U
M8G9A;'5E,2<L"B`@("`@("`@("`@("=S=6)N86UE,B<@/3X@)W-U8G9A;'5E
M,B<*("`@("`@("`I"B`@("`I.PH*5&AE(&]N;'D@97AC97!T:6]N('-H;W5L
M9"!B92!F;W(@96UP='D@;W(@<VAO<G0@87)R87ES('1H870@9FET(&]N(&]N
M92!L:6YE+`IW:&EC:"!M87D@8F4@=W)I='1E;B!A<SHZ"@H@("`@)&%R<F%Y
M;F%M95LG:6YD97@G72`](&%R<F%Y*"D["@H*26YT97)N871I;VYA;&EZ871I
M;VX@*$DQ.&XI"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*36%R:R!A
M;&P@<W1R:6YG<R!P<F5S96YT960@=&\@=&AE('5S97(@87,@9V5T=&5X="!S
M=')I;F=S(&)Y(&-A;&QI;F<@=&AE"F=E='1E>'0@<VAO<G1C=70@9G5N8W1I
M;VX@*&!@7R@I8&`I.CH*"B`@("!E8VAO(%\H(DAE;&QO('=O<FQD(BD["@I$
M;VXG="!U<V4@=&AE(&=E='1E>'0@9G5N8W1I;VYS(&9O<B!S=')I;F=S('1H
M870@=VEL;"!B92!W<FET=&5N('1O(&$@;&]G(&9I;&4*;W(@;W1H97)W:7-E
M('!R97-E;G1E9"!T;R!T:&4@861M:6YI<W1R871O<BX*"E1H92!3=')I;F<Z
M.B!C;&%S<R!C;VYT86EN<R!S979E<F%L('-T<FEN9R!M86YI<'5L871I;VX@
M;65T:&]D<R!T:&%T(&%R92P@87,*;W!P;W-E9"!T;R!T:&5I<B!02%`@97%U
M:79A;&5N=',L(&QO8V%L92!A;F0@8VAA<G-E="!S869E+@H*57-E(%-T<FEN
M9SHZ8V]N=F5R=$-H87)S970H*2!I9B!Y;W4@;F5E9"!T;R!C;VYV97)T(&)E
M='=E96X@9&EF9F5R96YT"F-H87)A8W1E<B!S970@96YC;V1I;F=S("AF;W(@
M97AA;7!L92P@8F5T=V5E;B!U<V5R(&EN<'5T(&%N9"!A('-T;W)A9V4@8F%C
M:V5N9`IO<B!D871A(&9R;VT@86X@97AT97)N86P@<V]U<F-E(&%N9"!T:&4@
M=7-E<B!I;G1E<F9A8V4I+B`@66]U(&1O;B=T(&YE960@=&\*8V%R92!I9B!T
M:&4@8VAA<F%C=&5R('-E=',@87)E(')E86QL>2!D:69F97)E;G0N"@I5<V4@
M=&AE(%-T<FEN9SHZ;&]W97(H*2!A;F0@4W1R:6YG.CIU<'!E<B@I(&UE=&AO
M9',@=VET:&]U="!A('-E8V]N9`IP87)A;65T97(@:68@>6]U(&YE960@=&\@
M<&5R9F]R;2!A(&QO8V%L92UI;F1E<&5N9&5N="!S=')I;F<@8V]N=F5R<VEO
M;BX*5&AA="=S('1H92!C87-E(&9O<B!A;&P@<W1R:6YG<R!T:&%T(&%R92!F
M=7)T:&5R('!R;V-E<W-E9"!O<B!I;G1E<G!R971E9"!B>0IC;V1E+B`@57-E
M('1H97-E(&UE=&AO9',@=VET:"!T:&4@<V5C;VYD('!A<F%M971E<B!S970@
M=&\@=')U92!F;W(@<W1R:6YG<PIT:&%T(&YE960@=&\@8F4@8V]N=F5R=&5D
M(&-O<G)E8W1L>2!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E;G0@*&]R('-P96-I
M9FEE9"D*8VAA<F%C=&5R('-E="X*"E5S92!T:&4@;W1H97(@4W1R:6YG.CH@
M97%U:79A;&5N=',@;V8@4$A0('-T<FEN9R!F=6YC=&EO;G,@=&\@;6%N:7!U
M;&%T90IS=')I;F=S(&-O<G)E8W1L>2!A8V-O<F1I;F<@=&\@=&AE(&-U<G)E
M;G0@*&]R('-P96-I9FEE9"D@8VAA<F%C=&5R('-E="!B=70*=7-E('1H92!0
M2%`@9G5N8W1I;VYS(&9O<B!C;V1E+VUA8VAI;F4@<')O8V5S<V5D('-T<FEN
M9W,N"@H*17)R;W(@8VAE8VMI;F<*/3T]/3T]/3T]/3T]/3T*"DAO<F1E(&-O
M9&4@<VAO=6QD('5S92!@4$5!4E]%<G)O<F!?(&]B:F5C=',@=&\@<F5T=7)N
M(&UO<W0@97)R;W(@8V]N9&ET:6]N<PIF<F]M(&QI8G)A<GD@8V%L;',L(&%N
M9"!M86YY('1I;65S('=E('=I;&P@<VEM<&QY('!A<W,@8F%C:R!A(&!014%2
M7T5R<F]R8%\*;V)J96-T(&=E;F5R871E9"!B>2!A;B!U;F1E<FQY:6YG(&QI
M8G)A<GD@*'-U8V@@87,@36%I;"!O<B!014%2($1"*2X*"D9O<B!T:&5S92!C
M87-E<RP@=7-E('1H92!F;VQL;W=I;F<@<W1Y;&4@;V8@8V]D92!B;&]C:R!T
M;R!C:&5C:R!F;W(@<W5C8V5S<PIA9G1E<B!A;GD@8V%L;"!W:&EC:"!C;W5L
M9"!G96YE<F%T92!A;B!E<G)O<B!C;VYD:71I;VXZ.@H*("`@("1R97-U;'0@
M/2`D<V]M971H:6YG+3YC86QL*"=M87D@97)R;W(G*3L*("`@(&EF("AI<U]A
M*"1R97-U;'0L("=014%27T5R<F]R)RDI('L*("`@("`@("`O+R!(86YD;&4@
M97)R;W(@8V]N9&ET:6]N+@H@("`@?2!E;'-E('L*("`@("`@("`O+R!3=6-C
M965D960N"B`@("!]"@I.;W1E('1H870@8&ES7V$H*6!?(&-H96-K<R!F;W(@
M<W5B8VQA<W-E<R!O9B!T:&4@;F%M960@8VQA<W,L(&%S('=E;&PL('-O(&EF
M"G1H92!O8FIE8W0@>6]U(&=E="!B86-K(&ES(')E86QL>2!A(&!$0E]%<G)O
M<F!?(&]B:F5C="P@=&AI<R!W:6QL('-T:6QL(&-A=&-H"FET("AS:6YC92!@
M1$)?17)R;W)@7R!E>'1E;F1S(&!014%27T5R<F]R8%\I+@H*0V%L;&EN9R!0
M14%2.CII<T5R<F]R*"D@<F5S=6QT<R!I;B!T:&4@<V%M92!B96AA=FEO<BP@
M8G5T(&ES7V$H*0IA8V-O;7!L:7-H97,@=&AE('-A;64@<F5S=6QT('=I=&@@
M82!S:6YG;&4@;F%T:79E(%!(4"!F=6YC=&EO;B!C86QL+@H*+BX@7U!%05)?
M17)R;W(Z(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<&5A
M<BYP96%R+65R<F]R+G!H<`HN+B!?1$)?17)R;W(Z(&AT='`Z+R]P96%R+G!H
M<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N9&(M97)R;W(N
M<&AP"BXN(%]I<U]A*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO
M9G5N8W1I;VXN:7,M82YP:'`*"@I%>&ES=&5N8V4@8VAE8VMI;F<*/3T]/3T]
M/3T]/3T]/3T]/3T]"@I/9G1E;B!Y;W4G;&P@;F5E9"!T;R!C:&5C:R!W:&5T
M:&5R(&]R(&YO="!A('9A<FEA8FQE(&]R('!R;W!E<G1Y(&5X:7-T<RX*5&AE
M<F4@87)E('-E=F5R86P@8V%S97,@:&5R93H*"F$N($EF('EO=2!N965D('1O
M(&MN;W<@:68@82!V87)I86)L92!E>&ES=',@870@86QL(&%N9"!I<R!N;W0@
M8&!N=6QL8&`L('5S90I@:7-S970H*6!?.CH*"B`@("`O+R!#:&5C:R!T;R!S
M964@:68@)'!A<F%M(&ES(&1E9FEN960N"B`@("!I9B`H:7-S970H)'!A<F%M
M*2D@>PH@("`@("`@("\O("1P87)A;2!M87D@8F4@9F%L<V4L(&)U="!I="=S
M('1H97)E+@H@("`@?0H*8BX@268@>6]U(&YE960@=&\@:VYO=R!I9B!A('9A
M<FEA8FQE(&5X:7-T<R!!3D0@:&%S(&$@;F]N+65M<'1Y('9A;'5E("AN;W0*
M8&!N=6QL8&`L(#`L(&!@9F%L<V5@8"P@96UP='D@<W1R:6YG(&]R('5N9&5F
M:6YE9"DL('5S92`A8&5M<'1Y*"E@7SHZ"@H@("`@+R\@36%K92!S=7)E('1H
M870@)&%N<W=E<B!E>&ES=',L(&ES(&YO="!A;B!E;7!T>2!S=')I;F<L(&%N
M9"!I<PH@("`@+R\@;F]T(#`Z"B`@("!I9B`H(65M<'1Y*"1A;G-W97(I*2![
M"B`@("`@("`@+R\@)&%N<W=E<B!H87,@<V]M92!N;VXM9F%L<V4@8V]N=&5N
M="X*("`@('T@96QS92!["B`@("`@("`@+R\@*&)O;VPI)&%N<W=E<B!W;W5L
M9"!B92!F86QS92X*("`@('T*"D%S('!O:6YT960@;W5T(&EN('1H92!C;VUM
M96YT(&]F('1H92!E;'-E(&-L875S92P@8&5M<'1Y*"E@7R!E<W-E;G1I86QL
M>2!D;V5S"G1H92!S86UE(&-H96-K(&%S(&!I<W-E="@I8%\@+2T@:7,@=&AI
M<R!V87)I86)L92!D969I;F5D(&EN('1H92!C=7)R96YT('-C;W!E/PHM+2!A
M;F0@=&AE;BP@:68@:70@:7,L(')E='5R;G,@=VAA="!T:&4@=F%R:6%B;&4@
M=V]U;&0@979A;'5A=&4@=&\@87,@80IB;V]L96%N+B!4:&ES(&UE86YS('1H
M870@,"P@=VAI;&4@<&]T96YT:6%L;'D@=F%L:60@:6YP=70L(&ES(")E;7!T
M>2(@+2!S;R!I9@HP(&ES('9A;&ED(&1A=&$@9F]R('EO=7(@8V%S92P@9&]N
M)W0@=7-E("%@96UP='DH*6!?+@H*8RX@268@>6]U(&MN;W<@>6]U(&%R92!W
M;W)K:6YG('=I=&@@82!M:7AE9"!V87)I86)L92!T:&5N('5S:6YG(&IU<W0*
M8&ES<V5T*"E@7R!A;F0@8&5M<'1Y*"E@7R!C;W5L9"!C875S92!U;F5X<&5C
M=&5D(')E<W5L=',L(&9O<B!E>&%M<&QE(&EF"G1E<W1I;F<@9F]R(&$@:V5Y
M(&%N9"!T:&4@=F%R:6%B;&4@:7,@86-T=6%L;'D@82!S=')I;F<Z.@H*("`@
M("1F;V\@/2`G8F%R)SL*("`@(&EF("AI<W-E="@D9F]O6R=S;VUE:V5Y)UTI
M*2!["B`@("`@("`@+R\@5&AI<R!W:6QL(&5V86QU871E('1O(%12544A"B`@
M("!]"@I)9B!Y;W4@:VYO=R!T:&%T('1H97)E(&ES(&$@<&]S<VEB:6QI='D@
M;V8@82!M:7AE9"!T>7!E('9A<FEA8FQE('1H92!S;VQU=&EO;@II;B!T:&ES
M(&-A<V4@=V]U;&0@8F4@=&\@861D(&%N(&!I<U]A<G)A>2@I8%\@8VAE8VL@
M:6X@=&AE(&!@:68H*6!@('-T871E;65N="X*"F0N(%5S92!@87)R87E?:V5Y
M7V5X:7-T<R@I8%\@=VAE;B!Y;W4@=V%N="!T;R!C:&5C:R!I9B!A;B!A<G)A
M>2!K97D@:7,@9&5F:6YE9`IE=F5N(&EF(&ET(&AA<R!A('9A;'5E(&]F(&!@
M;G5L;&!@.CH*"B`@("`O+R!-86ME('-U<F4@=V4@:&%V92!A(&-H87)S970@
M<&%R86UE=&5R+B!686QU92!C;W5L9"!A;'-O(&)E(&YU;&PN"B`@("!I9B`H
M(6%R<F%Y7VME>5]E>&ES=',H)V-H87)S970G+"`D<&%R86US*2D@>PH@("`@
M("`@($AO<F1E.CIF871A;"@G26YC;VUP;&5T92!C;VYF:6=U<F%T:6]N+B<I
M.PH@("`@?0H*4&QE87-E(&YO=&4@=&AA="!@87)R87E?:V5Y7V5X:7-T<R@I
M8%\@:7,@82!P97)F;W)M86YC92!H:70@*#(U)2TQ,#`E*2!A;F0*<VAO=6QD
M(&]N;'D@8F4@=7-E9"!W:&5N(&YE8V5S<V%R>2X@26YS=&5A9"!T<GD@=&\@
M=7-E("%@96UP='DH*6!?(&]R"F!I<W-E="@I8%\@:6YS=&5A9"X*"BXN(%]I
M<W-E="@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%N=6%L+V5N+V9U;F-T:6]N
M+FES<V5T+G!H<`HN+B!?96UP='DH*3H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA
M;G5A;"]E;B]F=6YC=&EO;BYE;7!T>2YP:'`*+BX@7VES7V%R<F%Y*"DZ(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN:7,M87)R87DN
M<&AP"BXN(%]A<G)A>5]K97E?97AI<W1S*"DZ(&AT='`Z+R]W=W<N<&AP+FYE
M="]M86YU86PO96XO9G5N8W1I;VXN87)R87DM:V5Y+65X:7-T<RYP:'`*"@I1
M=6]T97,*/3T]/3T]"@I9;W4@<VAO=6QD(&%L=V%Y<R!U<V4@<VEN9VQE('%U
M;W1E("@G*2!C:&%R86-T97)S(&%R;W5N9"!S=')I;F=S+"!E>&-E<'0@=VAE
M<F4*9&]U8FQE('%U;W1E("@B*2!C:&%R86-T97)S(&%R92!R97%U:7)E9"X@
M($%L;"!L:71E<F%L('-T<FEN9W,@<VAO=6QD(&)E(&EN"G-I;F=L92!Q=6]T
M97,N("!!(&-O;7!A<FES;VX@;V8@<VEN9VQE(&%N9"!D;W5B;&4@<75O=&4@
M=7-A9V4@9F]L;&]W<SH*"E-I;F=L92!1=6]T97,Z"B`@*B!687)I86)L97,@
M:6X@=&AE('-T<FEN9R!A<F4@;F]T('!A<G-E9"!O<B!E>'!A;F1E9"X*("`J
M($YE=R!L:6YE('-Y;6)O;',@8V%N(&)E(&EN8VQU9&5D(&%S(&QI=&5R86P@
M;&EN92!E;F1S("AN;W0@<F5C;VUM96YD960I+@H@("H@5&\@:6YC;'5D92!A
M('-I;F=L92!Q=6]T92!C:&%R86-T97(L(&5S8V%P92!I="!W:71H(&$@8&!<
M8&`@*&)A8VMS;&%S:"D*("`@(&-H87)A8W1E<BP@87,@:6XZ(&!@96-H;R`G
M2&5R95PG<R!A;B!E>&%M<&QE)SM@8`H@("H@5&\@<W!E8VEF>2!A(&!@7&!@
M("AB86-K<VQA<V@I(&-H87)A8W1E<BP@9&]U8FQE(&ET.B!@8&5C:&\@)V,Z
M7%QT96UP)SM@8`H*1&]U8FQE(%%U;W1E<SH*("`J(%!A<G-E<R!A;F0@97AP
M86YD<R!V87)I86)L97,@:6X@=&AE('-T<FEN9RX*("`J(%5S97,@861V86YC
M960@*&!S<')I;G1F8%\M<W1Y;&4I(&5S8V%P92!S97%U96YC97,@;&EK92!@
M8%QN8&`L(&!@7"1@8"P*("`@(&!@7'1@8"P@971C+@H@("H@4VAO=6QD(&)E
M('5S960@:6X@=&AE(&=E='1E>'0@<VAO<G1C=70@8&!?*"(B*6!@(&9O<FUA
M="X*("`J(%5S92!W:71H(&-A<F4L(&%S(&UA;GD@8V]R<F5C="!L;V]K:6YG
M('-T<FEN9W,@87)E(')E86QL>2!I;G9A;&ED+@H*5&AE(&9O;&QO=VEN9R!A
M<F4@86QL(&EN8V]R<F5C=#HZ"@H@("`@96-H;R`B5&]D87D@:7,@=&AE("1D
M871E6R=D87DG72!O9B`D9&%T95LG;6]N=&@G72(*("`@("1?4T534TE/3EMI
M;F1E>%T@/2`D7U-%4U-)3TY;(F]L9%]I;F1E>")=.PH*+BX@7W-P<FEN=&8Z
M(&AT='`Z+R]W=W<N<&AP+FYE="]S<')I;G1F"@H*9&5F:6YE*"D*/3T]/3T]
M/3T*"E-U<G!R:7-I;F=L>2!E;F]U9V@L(&!D969I;F4H*6!?(&ES(&$@<V]M
M97=H870@<VQO=R!F=6YC=&EO;B!I;B!02%`@*&%S(&]F(%!(4`HT+C,N>"D@
M<V\@97AC97-S:79E('5S92!I<R!D:7-C;W5R86=E9"X*"E5S:6YG(&!D969I
M;F4H*6!?(&EN(&-L87-S97,@<VAO=6QD(&)E($]+("T@=V4@=VEL;"!S86-R
M:69I8V4@82!T:6YY(&)I="!O9@IS<&5E9"!F;W(@<F5A9&%B:6QI='D@;V8@
M8V]D92X@(&!D969I;F4H*6!?('-H;W5L9"!.3U0@8F4@=7-E9"!F;W(@86-T
M:6]N241S("T*=7-E(&$@<&QA:6X@;VQD('-T<FEN9R!I;G-T96%D+B`@1F]R
M(&%N>71H:6YG(&5L<V4L('5S92!Y;W5R(&)E<W0@:G5D9VUE;G0N"@I!9&1I
M=&EO;F%L;'DL(&5V97)Y(&-O;G-T86YT('-H;W5L9"!B92!P<F5F:7AE9"!W
M:71H(&!@2$]21$5?8&`L(&ET<R!P86-K86=E"FYA;64L(&]R('1H92!A<'!L
M:6-A=&EO;B!N86UE+@H*+BX@7V1E9FEN92@I.B!H='1P.B\O=W=W+G!H<"YN
M970O;6%N=6%L+V5N+V9U;F-T:6]N+F1E9FEN92YP:'`*"@I396-U<FET>2!#
M;VYS:61E<F%T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE(&9O
M;&QO=VEN9R!A<F4@82!N;VXM97AH875S=&EV92!L:7-T(&]F(&9E871U<F5S
M+V9U;F-T:6]N<R!T;R!T86ME"G-P96-I86P@8V%R92!W:71H.@H*4$A0($-O
M9&4@17AE8W5T:6]N.@HM+2TM+2TM+2TM+2TM+2TM+2TM"@IR97%U:7)E+"!I
M;F-L=61E+"!R97%U:7)E7V]N8V4L(&EN8VQU9&5?;VYC92`M($-A<F5F=6QL
M>2!A=61I="!A;GD*=F%R:6%B;&5S('5S960@:6X@=&AE<V4@9G5N8W1I;VYS
M+"!A;F0@8VAE8VL@=&AE('-O=7)C92!O9B!A;GD*8V]N<W1A;G1S(&%S('=E
M;&PN"@IE=F%L("T@3V)V:6]U<R!D86YG97(@:68@=7-E<B!I;G!U="!I<R!S
M=7!P;&EE9"!T;R!I="!I;B!U;F-O;G1R;VQL960@8V]N9&ET:6]N<RX*"G!R
M96=?<F5P;&%C92`M(%1H92`O92!M;V1I9FEE<B!C875S97,@=&AE(')E<&QA
M8V5M96YT('-T<FEN9R!T;R!B90IE=F%L=6%T960@87,@4$A0(&-O9&4N"@I#
M;VUM86YD($5X96-U=&EO;CH*+2TM+2TM+2TM+2TM+2TM+2TM"@IE>&5C("T@
M17AE8W5T97,@82!S<&5C:69I960@8V]M;6%N9"!A;F0@<F5T=7)N<R!T:&4@
M;&%S="!L:6YE(&]F(&]U='!U="X*"G!A<W-T:')U("T@17AE8W5T97,@82!S
M<&5C:69I960@8V]M;6%N9"!A;F0@=W)I=&5S('1H92!O=71P=70@=&\@4U1$
M3U54+@H*8&`@*&)A8VMT:6-K<RD@+2!%>&5C=71E<R!T:&4@<W!E8VEF:65D
M(&-O;6UA;F0@86YD(')E='5R;G,@86QL('1H90IO=71P=70@:6X@86X@87)R
M87DN"@IS>7-T96T@+2!,:6ME('!A<W-T:')U*"D@8G5T(&1O97-N)W0@:&%N
M9&QE(&)I;F%R>2!D871A+@H*<&]P96X@+2!%>&5C=71E<R!A('-P96-I9FEE
M9"!C;VUM86YD(&%N9"!C;VYN96-T<R!I=',@;W5T<'5T(&]R(&EN<'5T"G-T
M<F5A;2!T;R!A(%!(4"!F:6QE(&1E<V-R:7!T;W(N"@I&:6QE($1I<V-L;W-U
M<F4Z"BTM+2TM+2TM+2TM+2TM+2T*"D9I;&4@9G5N8W1I;VYS('=H:6-H(&-A
M;B!B92!P;W1E;G1I86QL>2!U<V5D('1O(&]P96X@<F5M;W1E(&]R"G5N:6YT
M96YD960@9FEL97,Z(&9O<&5N+"!R96%D9FEL92P@9FEL92P@9FEL95]G971?
M8V]N=&5N=',N"@H*3W!T:6UI>F%T:6]N<PH]/3T]/3T]/3T]/3T]"@I4:&4@
M9F]L;&]W:6YG(&]P=&EM:7IA=&EO;G,@<VAO=6QD(&)E('5S960L(&EF('!O
M<W-I8FQE.@H*97AT96YS:6]N7VQO861E9"@I"BTM+2TM+2TM+2TM+2TM+2TM
M+0I4:&ES(&%P<&5A<G,@=&\@8F4@86X@97AP96YS:79E(%!(4"!C86QL+B`@
M57-E(%5T:6PZ.F5X=&5N<VEO;D5X:7-T<R@I"FEN<W1E860L('=H:6-H('=I
M;&P@8V%C:&4@=&AE(')E<W5L=',@;V8@=&AE(&-A;&PN"@I#;VYC871E;F%T
M92!S=')I;F=S"BTM+2TM+2TM+2TM+2TM+2TM+2T*0G5I;&1I;F<@82!S=')I
M;F<@=VET:"!C;VYC871E;F%T:6]N("AT:&4@(BXB(&]P97)A=&]R*2!U<VEN
M9PIS:6YG;&4M<75O=&5D('-T<FEN9W,@86YD('9A<FEA8FQE<R!I<R!F87-T
M97(@=&AA;B!U<VEN9R!A;@II;G1E<G!O;&%T960@<W1R:6YG("AA('-T<FEN
M9R!I;G-I9&4@9&]U8FQE('%U;W1E<R!W:71H('9A<FEA8FQE<PII;G-I9&4@
M=&AE('-T<FEN9R!I='-E;&8I+B`@26X@861D:71I;VXL(&-O;F-A=&5N871I
M;VX@:7,@96%S:65R('1O"G)E860@86YD(&%U9&ET(&9O<B!L;V=I8R!A;F0@
M<V5C=7)I='D@<')O8FQE;7,N"@I0<F4M:6YC<F5M96YT+V1E8W)E;65N=`HM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I"96-A=7-E(&]F('1H92!W87D@8V]M
M<&EL97)S+VEN=&5R<')E=&5R<R!W;W)K+"!P;W-T+6EN8W)E;65N=&EN9PHH
M)'9A<BLK*2!R97%U:7)E<R!S=&]R:6YG(&)O=&@@=&AE(&]R:6=I;F%L(&%N
M9"!N97<@=F%L=65S(&]F('1H90IV87)I86)L92!I;B!M96UO<GD@8F5C875S
M92!T:&4@;VQD('9A;'5E(&UA>2!B92!U<V5D(&%F=&5R('1H90IO<&5R871I
M;VX@:6X@<75E<W1I;VX@:7,@8V]M<&QE=&4N("!">2!C;VUP87)I<V]N+"!P
M<F4M:6YC<F5M96YT:6YG"B@K*R1V87(I(&%L;6]S="!N979E<B!N965D<R!T
M;R!S=&]R92!B;W1H('9A;'5E<RX@($ET)W,@82!M87)G:6YA;`IS<&5E9'5P
M(&)U="!I="=S(&%L<V\@<VEM<&QY(&-H86YG:6YG('1H92!O<F1E<B!O9B!A
M(&9E=R!C:&%R86-T97)S+@H*3&]O<',*+2TM+2T*36%K92!S=7)E('1H870@
M>6]U(&1O(&YO="!C;VYT:6YU92!T;R!D969I;F4@=&AE('-A;64@=F%R:6%B
M;&4@=VET:&EN(&$*;&]O<"X@($EN<W1E860L(&1E8VQA<F4@=&AE('9A<FEA
M8FQE(&$@<VEN9VQE('1I;64@8F5F;W)E('1H92!L;V]P(&ES(')U;BX*"D%R
M<F%Y"BTM+2TM"D%V;VED(&9R97%U96YT(&%R<F%Y(&%C8V5S<V5S+B`@268@
M>6]U('5S92!A;B!A<G)A>2!O<B!A;B!A<G)A>2!M96UB97(@:6X@80IL;V]P
M+"!A<W-I9VX@:70@=&\@82!V87)I86)L92!F:7)S=#HZ"@H@("`@)&$@/2!A
M<G)A>2@G>"<@/3X@)WDG*3L*("`@("1E;G1R:65S(#T@87)R87DH+BXN*3L*
M"B`@("`D;&5N9W1H(#T@8V]U;G0H)&5N=')I97,I.PH@("`@)'@@/2`D85LG
M>"==.PH@("`@9F]R("@D:2`](#`[("1I(#P@)&QE;F=T:#L@*RLD:2D@>PH@
M("`@("`@(&5C:&\@)'@["B`@("!]"@I5<V5R(&1E9FEN960@9G5N8W1I;VYS
M"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2T*57-E<B!D969I;F5D(&9U;F-T:6]N
M<R!A<F4@;6]R92!E>'!E;G-I=F4@=&AA;B`B<F5G=6QA<B(@9G5N8W1I;VYS
M+B`@57-E('1H96T*;VYL>2!I9B!T:&5Y(&EM<')O=F4@=&AE(&-O9&4@<F5A
M9&%B:6QI='D@;6]R92!T:&5N(')E9W5L87(@9G5N8W1I;VYS+@H*1&ES:R!)
M+T\*+2TM+2TM+2T*1&ES:R!R96%D(&%N9"!W<FET92!O<&5R871I;VYS(&%R
M92!S;&]W+B`@268@<&]S<VEB;&4@<F5A9"!A;F0@=W)I=&4@9FEL97,@:6X*
M;&%R9V4@8VAU;FMS+B`@06-C;W)D:6YG('1O(%!(4"!D;V-U;65N=&%T:6]N
M+"!F:6QE7V=E=%]C;VYT96YT<R@I(&ES"G!O=&5N=&EA;&QY(&UU8V@@9F%S
M=&5R('1H86X@=7-I;F<@9F]P96XH*2]F<F5A9"@I+V9C;&]S92@I+@H*"E-4
M1$E.+U-41$]55"]35$1%4E(*/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&\@86-C
M97-S(&5I=&AE<B!35$1)3BP@4U1$3U54+"!O<B!35$1%4E(L('1H92!F;VQL
M;W=I;F<@8V]D92!S:&]U;&0@8F4@=7-E9#HZ"@H@("`@=VAI;&4@*"%F96]F
M*%M35$1)3GQ35$1/551\4U1$15)272DI('L*("`@("`@("`D;&EN92`](&9G
M971S*%M35$1)3GQ35$1/551\4U1$15)272D["B`@("`@("`@+R\@<')O8V5S
M<R`D;&EN92!H97)E"B`@("!]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V1O8W,O0T].5%))0E5424Y'````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,S$T-"`Q,#4Q-30S-#$S-2`P,C`S,C``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/3T]
M/3T]/3T]/3T]/3T]/3T]/3T*($AO<F1E.B!(;W<@=&\@2&5L<`H]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`T+S`Y
M+S(T(#(Q.C`R.C`Q("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XT
M("0*.D-O;G1A8W0Z("`@("`@(&-O<F5`:&]R9&4N;W)G"@I4:&5R92!A<F4@
M;6%N>2!W87ES(&EN('=H:6-H('EO=2!C86X@:&5L<"!O=70@:6X@=&AE(&1E
M=F5L;W!M96YT(&]F(&%N>2!O9B!T:&4*2&]R9&4@<')O:F5C=',N(%1H92!F
M:7)S="!A;F0@8F5S="!W87D@>6]U(&%R92!A;')E861Y(&1O:6YG.B!Y;W4G
M<F4@=7-I;F<*=&AE;2X@3VYE(&]F('1H92!K97ES('1O(&$@9W)E870@<')O
M9'5C="!I<R!I=',@=7-E<G,N(%=I=&AO=70@=7-E<G,@=V4@8V%N)W0*9FEN
M9"!B=6=S(&]R(&=E="!F965D8F%C:R!O;B!W:&%T)W,@9V]O9"!A;F0@=VAA
M="=S(&)A9"X*"DET(&ES(&1A<FX@;F5A<B!I;7!O<W-I8FQE(&9O<B!T:&4@
M9&5V96QO<&5R<R!T;R!T97-T('1H92!C;V1E(&]N(&5V97)Y"D]P97)A=&EN
M9R!3>7-T96T@86YD(&5V97)Y(&1I9F9E<F5N="!V97)S:6]N(&]F(%=E8B!"
M<F]W<V5R(&%V86EL86)L92!T;R!M86ME"G-U<F4@=&AE(&-O9&4@<G5N<R!S
M;6]O=&AL>2!E=F5R>7=H97)E+B`@3&EN=7@@:7,@;F]T(%=I;F1O=W,L(&%N
M9"!)12!I<R!N;W0*36]Z:6QL82P@86YD(&ET(&ES("AF<F5Q=65N=&QY*2!D
M:69F:6-U;'0@=&\@=&\@<')E9&EC="!B96AA=FEO<B!B971W965N"G!L871F
M;W)M<R]B<F]W<V5R<RX*"E=I=&@@=&AI<R!S86ED+"!O;F4@;V8@=&AE(&)E
M<W0@=V%Y<R!Y;W4@8V%N(&AE;'`@:7,@=&\@=&5S="X@268@>6]U(&-A;B!H
M96QP"G5S('-M;V]T:"!O=70@=&AE(&-O9&4@86-R;W-S(&%L;"`H;W(@979E
M;B!A;GDI('!L871F;W)M<RP@>6]U)W)E(&1O:6YG(&$*9W)E870@<V5R=FEC
M92!T;R!T:&4@<')O:F5C="X*"DYO=RP@:68@=&AA="=S(&YO="!E;F]U9V@@
M86YD('EO=2!W86YT('1O(&1I9R!I;B!A;F0@:&5L<"!C;V1E+"!Y;W4@<VAO
M=6QD"F9I<G-T('-U8G-C<FEB92!T;R!T:&4@<')O:F5C="!L:7-T<RP@<&%R
M=&EC=6QA<FQY('1H92!G96YE<F%L($AO<F1E"F1E=F5L;W!E<G,@;&ES="!D
M979`;&ES=',N:&]R9&4N;W)G("AS964@:'1T<#HO+W=W=RYH;W)D92YO<F<O
M;6%I;"\@9F]R"FEN9F]R;6%T:6]N(&]N('-U8G-C<FEB:6YG('1O('1H92!M
M86EL:6YG(&QI<W1S*2X@($%D9&ET:6]N86QL>2P@>6]U("HJ35535"HJ"G)E
M860@=&AE(&!(;W)D92!#;V1I;F<@4W1A;F1A<F1S8%\@=&\@96YS=7)E('1H
M870@=&AE(&-O9&4@>6]U<B!S=6)M:71T:6YG"G=I;&P@=V%N="!T;R!B92!A
M;F%L>7IE9"!A;F0@<&]T96YT:6%L;'D@8V]M;6ET=&5D(&)Y('1H92!D979E
M;&]P97)S+B`@66]U"G-H;W5L9"!P<F]B86)L>2!R96%D('1H92!V87)I;W5S
M(%)%041-12!F:6QE<R`H9F]R('1H870@;6%T=&5R+"!A;&P@=&AE"F1O8W5M
M96YT871I;VX@:6X@=&AE(&!@9&]C<R]@8"!D:7)E8W1O<GDI(&9O<B!T:&4@
M<&%R=&EC=6QA<B!A<'!L:6-A=&EO;B!Y;W4*87)E('=O<FMI;F<@;VX@86QS
M;RX*"BXN(%]@2&]R9&4@0V]D:6YG(%-T86YD87)D<V`Z(#]F/4-/1$E.1U]3
M5$%.1$%21%,N:'1M;```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]D
M;V-S+T-2141)5%,`````````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,30S,S`@,3`U,34T,S0Q,S4@,#$W-3`U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V96QO<&UE;G0@5&5A;0H]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I#;W)E($1E=F5L;W!E<G,*/3T]/3T]
M/3T]/3T]/3T]"@I#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*
M2F%N(%-C:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX*36EC:&%E;"!3;'5S87)Z
M(#QS;'5S87)Z0&AO<F1E+F]R9SX*"@I,;V-A;&EZ871I;VX*/3T]/3T]/3T]
M/3T]"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*07)A8FEC
M("A3>7)I82D@("`@("`@("`@4&QA=&EN=6T@1&5V96QO<&UE;G0@5&5A;2`\
M9&5V=&5A;4!P;&%T:6YU;2US>2YN970^"D)O<VYI86X@("`@("`@("`@("`@
M("`@($%L96X@4V%R:VEN;W9I8R`\86QE;D!L:6YU>"YO<F<N8F$^"B`@("`@
M("`@("`@("`@("`@("`@("`@(%9E9')A;B!,:G5B;W9I8R`\=FQJ=6)O=FEC
M0'-M87)T;F5T+F)A/@I"<F%Z:6QI86X@4&]R='5G=65S92`@("!#87)L;W,@
M1&%N:65L($MI8G)I="`\:VEB<FET0'1E<G)A+F-O;2YB<CX*("`@("`@("`@
M("`@("`@("`@("`@("`@1F%B:6\@1V]M97,@/&9L9V]M<T!U;VPN8V]M+F)R
M/@I"=6QG87)I86X@("`@("`@("`@("`@("!-:7)O<VQA=B!096YD978@/'!E
M;F1E=D!H;W1M86EL+F-O;3X*0V%T86QA;B`@("`@("`@("`@("`@("`@06YG
M96QS($=U:6UE<N`@/&%N9V5L<RY'=6EM97)A0'5A8BYE<SX*("`@("`@("`@
M("`@("`@("`@("`@("`@2F]R9&D@1VER86QT(#QP<F]J96-T92YK,D!U<&-N
M970N97,^"D-H:6YE<V4@*%-I;7!L:69I960I("`@(%=A;F=(96YG5V5N(#QW
M:'=`;7DQ-CDN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!,:6%O8FEN
M(#QL:6%O8FEN0&II=&4N;F5T/@I#:&EN97-E("A4<F%D:71I;VYA;"D@("!$
M879I9"!#:&%N9R`\9&%V:61`=&UV+F=O=BYT=SX*0WIE8V@@("`@("`@("`@
M("`@("`@("`@4&%V96P@0VAY=&EL(#QP86IA0&%S<"YO9VDN961U/@I$86YI
M<V@@("`@("`@("`@("`@("`@("!-87)T:6X@3&ES="U0971E<G-E;B`\;6%R
M=&EN0&QI<W0M<&5T97)S96XN9&L^"B`@("`@("`@("`@("`@("`@("`@("`@
M($)R:6%N(%1R=65L<V5N(#QH;W)D92MI,3AN0&)R:6%N=')U96QS96XN9&L^
M"D1U=&-H("`@("`@("`@("`@("`@("`@($IA;B!+=6EP97)S(#QJ<FMU:7!E
M<G-`;&%U=V5R<V-O;&QE9V4N;FP^"B`@("`@("`@("`@("`@("`@("`@("`@
M(%!E=&5R($%R:65N(#QP971E<BYA<FEE;D!C8RYK=6QE=79E;BYA8RYB93X*
M("`@("`@("`@("`@("`@("`@("`@("`@2&%N(%-P<G5Y="`\:&%N+G-P<G5Y
M=$!I:G-S96QG<F]E<"YN;#X*17-T;VYI86X@("`@("`@("`@("`@("`@5&]O
M;6%S($%A<R`\=&]O;6%S+F%A<T!R86%D+G1A<G1U+F5E/@I&:6YN:7-H("`@
M("`@("`@("`@("`@("!,965N82!(96EN;R`\;&EI;G5`=71A+F9I/@I&<F5N
M8V@@("`@("`@("`@("`@("`@("!&<F5D97)I8R!4<G5D96%U(#QF=')U9&5A
M=4!C86TN;W)G/@H@("`@("`@("`@("`@("`@("`@("`@("!4:&EE<G)Y(%1H
M;VUA<R`\=&AI97)R>4!P;VUP;RYN970^"B`@("`@("`@("`@("`@("`@("`@
M("`@($)E;F]I="!3="U!;F1RZ2`\8F5N0&)E;F]I='-T+6%N9')E+FYE=#X*
M("`@("`@("`@("`@("`@("`@("`@("`@4&EE<G)E($QA8VAA;F-E(#QP;$!P
M:65R<F5L86-H86YC92YN970^"B`@("`@("`@("`@("`@("`@("`@("`@($=R
M96=O<GD@0V]L<&%R="`\9V-O;'!A<G1`979O;&EX+FYE=#X*1V%L:6-I86X@
M("`@("`@("`@("`@("`@4F%F865L(%9A<F5L82`\<F%F865L+G9A<F5L84!U
M<V,N97,^"B`@("`@("`@("`@("`@("`@("`@("`@($=U:6QL97)M;R!-96YD
M97H@/&=U:6QL94!U<V,N97,^"D=E<FUA;B`@("`@("`@("`@("`@("`@($IA
M;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"D=R965K("`@("`@("`@("`@
M("`@("`@(%-T969A;F]S($DN($1I;6ET<FEO=2`\<W5P<&]R=$!T96EA=&@N
M9W(^"B`@("`@("`@("`@("`@("`@("`@("`@(%-I;&QI9V%R9&]S(%AR:7-T
M;V9O<F]S"B`@("`@("`@("`@("`@("`@("`@("`@($%N86=N;W-T;W!O=6QO
M<R!!<&]S=&]L:7,*("`@("`@("`@("`@("`@("`@("`@("`@2V]N<W1A;G1I
M;F]S($,N($UI;&]S:7,@/&MM:6QO<VES0'EA:&]O+F-O;3X*2&5B<F5W("`@
M("`@("`@("`@("`@("`@36%T="!396QS:WD@/'-E;'-K>4!C;VQU;6)I82YE
M9'4^"DAU;F=A<FEA;B`@("`@("`@("`@("`@($QA<WIL;R!,+B!4;W)N;V-I
M(#QT;W)L87-Z0'AE;FEA+G-O=&4N:'4^"DEC96QA;F1I8R`@("`@("`@("`@
M("`@($)J;W)N($1A=FED<W-O;B`\8FIO<W-I0'-N97)P82YI<SX*26YD;VYE
M<VEA;B`@("`@("`@("`@("`@4VQA;6EN(#QS;&%M:6Y`=6YE:BYA8RYI9#X*
M("`@("`@("`@("`@("`@("`@("`@("`@2F%M97,@1&]E(#QJ86UE<T!A8W1I
M;VYM97-S86=E+F-O;3X*271A;&EA;B`@("`@("`@("`@("`@("`@4&%O;&$@
M0V%R<&5N=&5R(#QP8V%R<&5N=&5R0&EN9G9I8RYI=#X*("`@("`@("`@("`@
M("`@("`@("`@("`@1VEO=F%N;FD@365N96=H971T:2`\9VUE;F5G:&5T=&E`
M:6YF=FEC+FET/@H@("`@("`@("`@("`@("`@("`@("`@("!&961E<FEC;R!'
M:6%N;FEC:2`\9VEA;FYI8VE`;F5O;65D:6$N:70^"B`@("`@("`@("`@("`@
M("`@("`@("`@($UA<F-O(%!I<F]V86YO(#QM87)C;RYP:7)O=F%N;T!U;FEB
M;V-C;VYI+FET/@H@("`@("`@("`@("`@("`@("`@("`@("!#<FES=&EA;B!-
M86YO;FD@/&-R:7-T:6%N+FUA;F]N:4!N971H97-I<RYI=#X*2F%P86YE<V4@
M("`@("`@("`@("`@("`@0BY*+B!";&%C:R`\=VEL;&EA;2YB;&%C:T!S=6XN
M8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!486ME<VAI($UO<FES:&EM
M82`\=&U`;VYE<&]S="YN970^"B`@("`@("`@("`@("`@("`@("`@("`@($AI
M<F]M:2!+:6UU<F$@/&AI<F]M:4!T86,N='-U:W5B82YA8RYJ<#X*2VAM97(@
M("`@("`@("`@("`@("`@("`@3&5A;F<@0VAU;7-O8F5N(#QS;V)E;D!K:&UE
M<F]S+FEN9F\^"DMO<F5A;B`@("`@("`@("`@("`@("`@($HN22!+:6T@/&%P
M;W)I94!N971I86XN8V]M/@H@("`@("`@("`@("`@("`@("`@("`@("!*:6YH
M>6]K($AE;R`\;F]V96UB<F5`;W5R;F%T=7)E+F]R9SX*3&%T=FEA;B`@("`@
M("`@("`@("`@("`@2V%S<&%R<R!+87!E;FEE:W,@/&MA<W!A<G-`<F-C+FQV
M/@I,:71H=6%N:6%N("`@("`@("`@("`@("!$87)I=7,@36%T=6QI875S:V%S
M(#QD87)I=7-`;&YK+FQT/@H@("`@("`@("`@("`@("`@("`@("`@("!6:6QI
M=7,@4W5M<VMA<R`\=FEL:75S0&QN:RYL=#X*36%C961O;FEA;B`@("`@("`@
M("`@("`@4W1O:F%N(%!E<V]V(#QS<W!`975R96MA+F-O;2YM:SX*3F]R=V5G
M:6%N($)O:VUA86P@("`@("`@3WES=&5I;B!3=&5I;6QE<B`\;WES=&5I;D!R
M97AT82YN970^"B`@("`@("`@("`@("`@("`@("`@("`@(%1O<G-T96EN(%,N
M($AA;G-E;B`\:'5L96)O97)`=&5C:&)E92YN;SX*("`@("`@("`@("`@("`@
M("`@("`@("`@06YD<F5A<R!'=6YL96EK<VMA87,@/&%N9')E87-`9W5N;&5I
M:W-K86%S+FYO/@H@("`@("`@("`@("`@("`@("`@("`@("!4<F]N9"!":OAR
M<W1A9"`\=')B0&YD;BYN;SX*("`@("`@("`@("`@("`@("`@("`@("`@5&AO
M;6%S($-H<BX@1&%H;"`\=&-D0&YD;BYN;SX*("`@("`@("`@("`@("`@("`@
M("`@("`@1V5I<B!/+B!(;V=B97)G(#QH;W)D94!S:WED:79E<BYN;SX*3F]R
M=V5G:6%N($YY;F]R<VL@("`@("`@4&5R+5-T:6%N(%9A=&YE(#QP<W9`;W)S
M=&$N;W)G/@I097)S:6%N("`@("`@("`@("`@("`@("!-971A3D54($%M:7)K
M86)I<B`\<&5R<VEA;BUH;W)D94!M971A;F5T=V]R:VEN9RYC;VT^"E!O;&ES
M:"`@("`@("`@("`@("`@("`@($UA<FEU<WH@6GEN96P@/&UA<FEU<WI`;6%T
M:"YU=V(N961U+G!L/@H@("`@("`@("`@("`@("`@("`@("`@("!+<GIY<WIT
M;V8@2V]Z;&]W<VMI(#QK;WII:S%`;S(N<&P^"E!O<G1U9W5E<V4@("`@("`@
M("`@("`@($YU;F\@3&]U<F5I<F\@/&YU;F]`971H+G!T/@H@("`@("`@("`@
M("`@("`@("`@("`@("!-86YU96P@365N97IE<R!D92!397%U96ER82`\36%N
M=65L+E-E<75E:7)A/@I2;VUA;FEA;B`@("`@("`@("`@("`@("!#;W)N96QI
M=2!-=7-A="`\8VUU<V%T0'1I86UA="YK97ES>7,N<F\^"E)U<W-I86X@("`@
M("`@("`@("`@("`@($EG;F%T($EK<GEA;F]V(#QI9VYA=$!I8F0N<G4^"B`@
M("`@("`@("`@("`@("`@("`@("`@($9E9&]R($$N($9E=&ES;W8@/&9A9D!S
M<V,N<G4^"B`@("`@("`@("`@("`@("`@("`@("`@($%L97AE>2!:86MH87)O
M=B`\86QE>$!B:W,N8GD^"E-L;W9A:R`@("`@("`@("`@("`@("`@($QE;R!-
M<F%F:V\@/&QE;T!O96PN<VL^"B`@("`@("`@("`@("`@("`@("`@("`@($EV
M86X@3F]R:7,@/&YO<FES0&)G<RYS:SX*4VQO=F5N:6%N("`@("`@("`@("`@
M("`@2G5R92!+<F%S;W9I8R`\:G5R96M`<F-C+6ER8RYS:3X*("`@("`@("`@
M("`@("`@("`@("`@("`@36%T:6,@1&]L87(@/&UA=&EC0&UE9&EU;2YS:3X*
M4W!A;FES:"`@("`@("`@("`@("`@("`@4F'Z;"!!;'9A<F5Z(%9E;F5G87,@
M/')A=D!T96-O;6%N+G5C;VPN;7@^"B`@("`@("`@("`@("`@("`@("`@("`@
M($UA;G5E;"!097)E>B!!>6%L82`\;7!E<F%Y84!A;&-A>F%B82YU;F5X+F5S
M/@I3=V5D:7-H("`@("`@("`@("`@("`@("!!;F1R96%S($1A:&SI;B`\86YD
M<F5A<T!D86AL96XN=W,^"B`@("`@("`@("`@("`@("`@("`@("`@($IO87%U
M:6T@2&]M<FEG:&%U<V5N(#QJ;VAO0'=E8F)P;&%T<V5N+G-E/@I4=7)K:7-H
M("`@("`@("`@("`@("`@("!'96YC;R!9:6QM87H@/&=E;F-O>6EL;6%Z0'EA
M:&]O+F-O;3X*("`@("`@("`@("`@("`@("`@("`@("`@27-T86YB=6P@5&5C
M:&YI8V%L(%5N:79E<G-I='D@250@1&5P87)T;65N=`H@("`@("`@("`@("`@
M("`@("`@("`@("`\:71U8FEM0&ET=2YE9'4N='(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(%-E<G9E="!'_&YE>2`\<V=U;F5Y0&UE='4N961U+G1R/@H@
M("`@("`@("`@("`@("`@("`@("`@("!!:&UE="#6>G3\<FL@/&]A:&UE=$!M
M971U+F5D=2YT<CX*56MR86EN:6%N("`@("`@("`@("`@("`@06YD<FEY($MO
M<'ES='EA;G-K>2`\86YR:4!P;VQY;F5T+FQV:78N=6$^"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/2`@(#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*"E1H96UE<PH]/3T]/3T*"CT]/3T]
M/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/0I"87)B:64@("`@("`@("`@071I9B!':&%F9F%R(#QA9VAA9F9A
M<D!D979E;&]P97(N8V@^"D)R;W=N("`@("`@("`@("!-87)C;R!/8F%I9"`\
M;6%R8V]`;75W+F5D=3X*0V%M;W5F;&%G92`@("`@($%T:68@1VAA9F9A<B`\
M86=H869F87)`9&5V96QO<&5R+F-H/@I#:&5R<GD@("`@("`@("`@0VAR:7-T
M;W!H92!'=6EL;&]U>"`\<F]O=&EX0&)O;W1I>"YN970^"D=R965N("`@("`@
M("`@("!.86-E<B!,87)A9&II(#QL87)A9&II0'1U>&9A;6EL>2YO<F<^"D=R
M97D@("`@("`@("`@("!.86-E<B!,87)A9&II(#QL87)A9&II0'1U>&9A;6EL
M>2YO<F<^"DQA=F5N9&5R("`@("`@("!::6%U<B!286AM86X@/'II84!Q86QA
M8V]M+F-O;3X*3&EG:'0M0FQU92`@("`@($%T:68@1VAA9F9A<B`\86=H869F
M87)`9&5V96QO<&5R+F-H/@I-;WII;&QA("`@("`@("`@36EC:&%E;"!#;V-H
M<F%N92`\;6EK94!G<F%F=&]N:&%L;"YC;RYN>CX*3W)A;F=E("`@("`@("`@
M(%)O;FYI92!'87)C:6$@/')O;FYI94!M:S(N;F5T/@I3:6UP;&5X("`@("`@
M("`@0V%R:6%D($EL;>!R82`\8V%R:6%D0&%D;G@N;F5T/@I3=6X@("`@("`@
M("`@("`@0VAR:7-T;W!H92!'=6EL;&]U>"`\<F]O=&EX0&)O;W1I>"YN970^
M"CT]/3T]/3T]/3T]/3T@("`]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*"D-O;G1R:6)U=&EO;G,*/3T]/3T]/3T]/3T]/0H*
M2%1-3"!T;R!497AT($-O;G9E<G1E<CH@2F]N($%B97)N871H>2`\:F]N0&-H
M=6=G;G5T="YC;VT^"@H*26YA8W1I=F4@1&5V96QO<&5R<PH]/3T]/3T]/3T]
M/3T]/3T]/3T]"@HM($EV86X@12X@36]O<F4@24D@/')K<G5S='E`=&1Y8RYC
M;VT^"BT@36EK92!(87)D>2`\;6EK94!I='-P<F]J96-T<RYC;VT^"BT@2F]N
M(%!A<FES92`\:F]N0&-S:"YR:70N961U/@HM($%N:6P@36%D:&%V87!E9&1Y
M(#QA;FEL0')E8V]I;"YO<F<^"BT@4FEC:"!,869F97)T>2`\<FEC:$!H;W)D
M92YO<F<^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O9&]C<R](04-+24Y'````````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$V-S(R(#$P-3$U-#,T,3,U
M(#`Q-S0V,P`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V
M96QO<&UE;G0@4F5S;W5R8V5S"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@HZ3&%S="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#8O,#(O,#$@,#DZ,C`Z
M,CD@)`HZ4F5V:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C<N,3`N,2`D"CI!
M=71H;W(Z("`@("`@("!)=F%N($4N($UO;W)E($E)(#QR:W)U<W1Y0'1D>6,N
M8V]M/BP@36EK92!(87)D>0H@("`@("`@("`@("`@("`@/&UI:V5H0'-P87)K
M+F-O;3X*.D-O;G1A8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*
M+BX@8V]N=&5N=',Z.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ
M"@I/;FQI;F4@<F5S;W5R8V5S(&9O<B!D979E;&]P:6YG('=I=&@@2&]R9&4@
M*&EN8VQU9&EN9R!(;W)D92!&<F%M97=O<FL@05!)"F1O8W5M96YT871I;VXI
M(&%R92!A=F%I;&%B;&4@870Z"@H@("!H='1P.B\O9&5V+FAO<F1E+F]R9R\@
M("`*"@I(86-K:6YG(&]N($AO<F1E(&9R;VT@0U93"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"DAO<F1E(&%N9"!I=',@;6]D=6QE<R!U<V4@0U93(&9O
M<B!S;W5R8V4@8V]N=')O;"X@($-64R!I<R!W96QL+61O8W5M96YT960L(&)U
M=`IT:&4@;6%N=6%L('!A9V4@87-S=6UE<R!Y;W4@86QR96%D>2!K;F]W(&AO
M=R!I="!W;W)K<RX@($%N(&5X8V5L;&5N="!G=6ED92!T;PIG971T:6YG('-T
M87)T960@=VET:"!#5E,@:7,@(D]P96X@4V]U<F-E($1E=F5L;W!M96YT('=I
M=&@@0U93(B!B>2!+87)L($9O9V5L+@I)="=S('!U8FQI<VAE9"!B>2!#;W)I
M;VQI<RP@86YD('1H92!T96-H;FEC86P@<&%R="!O9B!T:&4@8F]O:R!I<R!A
M=F%I;&%B;&4*9F]R(&9R964@;VX@=&AE(%=E8B!A=`H*("`@:'1T<#HO+V-V
M<V)O;VLN<F5D+6)E86XN8V]M+PH*5&AE('!A<&5R('9E<G-I;VX@:6YC;'5D
M97,@8VAA<'1E<G,@;VX@;W)G86YI>FEN9R!A;F0@;6%N86=I;F<@3W!E;B!3
M;W5R8V4*9&5V96QO<&UE;G0N("!9;W4@8V%N(&]B=&%I;B!A($-64R!C;&EE
M;G0@9F]R('EO=7(@;W!E<F%T:6YG('-Y<W1E;2!A=`I#5E-(3TU%+"!A=`H*
M("`@:'1T<#HO+W=W=RYC=G-H;VUE+F]R9R]D;W=N;&]A9',N:'1M;`H*;V8@
M=&AE;2!M87D@8F4@9F]U;F0@870@:'1T<#HO+W=W=RYC>6-L:6,N8V]M("T@
M=&AE>2!S=7!P;W)T($-64R!C;VUM97)C:6%L;'DL"F5V96X@=&AO=6=H(&ET
M(&ES(&%N(&]P96X@<V]U<F-E('!R;V=R86TN"@I9;W4@=VEL;"!N965D(&$@
M0U93(&-L:65N="!T;R!D;R!A;GD@;V8@=&AE(&9O;&QO=VEN9R`H8VAE8VL@
M;W5T('1H92!#>6-L:6,*:&]M97!A9V4@:68@>6]U(&1O;B=T(&AA=F4@;VYE
M*2X*"D9O<B!T:&]S92!A;')E861Y(&9A;6EL:6%R('=I=&@@0U93+"!T:&4@
M86YO;GEM;W5S($-64U)/3U0@:7,Z.@H*("`@.G!S97)V97(Z8W9S<F5A9$!A
M;F]N8W9S+FAO<F1E+F]R9SHO<F5P;W-I=&]R>0H*"D1O=VYL;V%D:6YG($AO
M<F1E(&UO9'5L97,@9G)O;2!#5E,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+0H*66]U('=I;&P@=V%N="!T;R!D;R!T:&ES(&EF('EO=2!W
M86YT(&)L965D:6YG(&5D9V4@8V]D92X*"C$N($=O('1O('1H92!D:7)E8W1O
M<GD@>6]U('=A;G0@=&\@9&]W;FQO860@=&AE(&-O9&4@=&\Z.@H*("`@("`@
M8V0@?B]W;W)K"@HR+B!3970@8&!#5E-23T]48&`@=&\@=&AE(&QO8V%T:6]N
M(&]F('1H92!#5E,@<F5P;W-I=&]R>2X@(%EO=2!C;W5L9"!A;'-O('!A<W,*
M("`@8W9S('1H92!N86UE(&]F('1H92!#5E,@<F]O="!W:71H('1H92!@8"UD
M8&`@;W!T:6]N+B`@0F4@<W5R92!T;R!N;W1E('1H90H@("!C;VQO;B!@8#I@
M8"!I;B!F<F]N="!O9B!@8'!S97)V97)@8"X*"B`@("AI;B!S:"P@:W-H+"!B
M87-H+"!Z<V@I.CH*"B`@("`@($-64U)/3U0].G!S97)V97(Z8W9S<F5A9$!A
M;F]N8W9S+FAO<F1E+F]R9SHO<F5P;W-I=&]R>0H@("`@("!E>'!O<G0@0U93
M4D]/5`H*("`@*&EN(&-S:"P@=&-S:"DZ.@H*("`@("`@<V5T96YV($-64U)/
M3U0@.G!S97)V97(Z8W9S<F5A9$!A;F]N8W9S+FAO<F1E+F]R9SHO<F5P;W-I
M=&]R>0H*,RX@3&]G:6X@=&\@=&AE(&%N;VYY;6]U<R!#5E,@<F5P;W-I=&]R
M>2X@(%=H96X@<')O;7!T960@9F]R(&$@<&%S<W=O<F0L(&5N=&5R"B`@(&!@
M:&]R9&5@8#HZ"B`@("`@(`H@("`@("!C=G,@;&]G:6X*"C0N($-H96-K(&]U
M="!T:&4@;6]D=6QE('EO=2!W86YT('1O(&1O=VYL;V%D(&9R;VT@=&AE(')E
M<&]S:71O<GDN("!297!L86-E"B`@(&!@34]$54Q%8&`@=VET:"!H;W)D92P@
M:6UP+"!T=7)B82P@=')O;&PL(&%N9"!S;R!F;W)T:"X@("A4:&4@8&`M>C-@
M8"!T96QL<PH@("!C=G,@=&\@8V]M<')E<W,@=&AE(&1A=&$@:70@<V5N9',@
M;W9E<B!T:&4@;F5T=V]R:RP@=6YC;VUP<F5S<VEN9R!I="!W:&5N"B`@('EO
M=2`_/S\_.CH*"B`@("`@(&-V<R`M>C,@8V\@34]$54Q%"@H@("!)9B!Y;W4@
M=V%N="!T;R!C:&5C:R!O=70@82!P87)T:6-U;&%R(&)R86YC:"!O9B!A(&UO
M9'5L92`H9F]R(&5X86UP;&4L('1H90H@("!@8%)%3$5.1U\S8&`@8G)A;F-H
M(&]F($E-4"DL(&EN8VQU9&4@=&AE(&)R86YC:"!T86<@;&EK92!S;RP@<F5P
M;&%C:6YG"B`@(&!@5$%'8&`@=VET:"!T:&4@;F%M92!O9B!T:&4@8G)A;F-H
M.CH*"B`@("`@(&-V<R`M>C,@8V\@+7(@5$%'($U/1%5,10H*-2X@07,@>6]U
M('=O<FL@=VET:"!T:&4@<V]F='=A<F4L('EO=2!C86X@<&5R:6]D:6-A;&QY
M('5P9&%T92!Y;W5R('1R964@=&\*("`@;6%T8V@@=&AE(&UA<W1E<B!T<F5E
M(&%T(&%N>2!T:6UE+"!F<F]M('1H92!T;W`@9&ER96-T;W)Y(&]F('1H90H@
M("!M;V1U;&4N("!5<VEN9R!@8&AO<F1E8&`@87,@86X@97AA;7!L92!M;V1U
M;&4Z.@H*("`@("`@8V0@?B]W;W)K+VAO<F1E"B`@("`@(&-V<R`M>C,@=7!D
M871E"@H*3V)T86EN:6YG(&$@0U93(&%C8V]U;G0*+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*"DEF('EO=2=R92!G;VEN9R!T;R!B92!A(')E9W5L87(@8V]N
M=')I8G5T;W(@=&\@2&]R9&4L('1H96X@>6]U(&-A;B!R97%U97-T(&$*0U93
M(&%C8V]U;G0@:6X@;W)D97(@=&\@8V]M;6ET('EO=7(@8VAA;F=E<R!T;R!T
M:&4@<F5P;W-I=&]R>2!Y;W5R<V5L9BX@("A)9@IY;W4G<F4@;VYL>2!G;VEN
M9R!T;R!B92!C;VYT<FEB=71I;F<@;VYC92!I;B!A('=H:6QE+"!T:&5R92!T
M<G5L>2!I<R!N;R!N965D"F9O<B!Y;W4@=&\@:&%V92!O;F4L(&%S('!O<W1I
M;F<@>6]U<B!C:&%N9V5S('1O('1H92!A<'!L:6-A=&EO;B=S(&UA:6QI;F<@
M;&ES=`IW:6QL('-U9F9I8V4@=&\@9V5T('EO=7(@8VAA;F=E<R!R979I97=E
M9"!A;F0@:6YC;'5D960N*0H*268@>6]U(&1O(&=E="!C;VUM:70@86-C97-S
M('1O('1H92!#5E,@=')E92P@>6]U('=I;&P@:&%V92!T:&4@86)I;&ET>2!T
M;R!M97-S"G-O;64@=&AI;F=S('5P+B`@3F]T(&9O<B!G;V]D+"!M:6YD('EO
M=2P@87,@0U93(&%L;&]W<R!U<&1A=&5S('1O(&)E(&)A8VME9`IO9F8L(&)U
M="!Y;W4@<W1I;&P@;F5E9"!T;R!R96UE;6)E<B!W:&%T('EO=2=R92!D;VEN
M9R!A;F0@8F4@8V%R969U;"!W:&%T('EO=0IC;VUM:70@86YD('=H96X@>6]U
M(&-O;6UI="!I="X@($)E8V%U<V4@;V8@=&AI<RP@=V4@<')E9F5R('1H870@
M>6]U('-U8FUI=`IY;W5R('=O<FL@=&\@=&AE(&UA:6QI;F<@;&ES="!F;W(@
M82!W:&EL92!S;R!W92!C86X@=&5L;"!Y;W4@:VYO=R!W:&%T('EO=2=R90ID
M;VEN9RX*"DEF('EO=2=R92!N;W0@82!C;VUM:71T97(L('1H92!B97-T('=A
M>2!T;R!S=6)M:70@82!P871C:"!I<R!T;R!S96YD(&ET(&5I=&AE<@IT;R!T
M:&4@87!P;&EC871I;VXG<R!M86EL:6YG(&QI<W0@;W(@=&\@9&5V0&QI<W1S
M+FAO<F1E+F]R9RX@($9O<B!M;W)E"FEN9F]R;6%T:6]N(&]N($AO<F1E(&UA
M:6QI;F<@;&ES=',L('-E90H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6%I
M;"\*"@I#;VUM:71T:6YG(&-H86YG97,@=&\@0U93"BTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*"D]N8V4@>6]U(&AA=F4@82!#5E,@86-C;W5N="P@>6]U
M('=I;&P@;F5E9"!T;R!L;V<@:6YT;R!T:&4@0U93('-E<G9E<B!S;R!I=`IK
M;F]W<R!W:&\@>6]U(&%R92!A;F0@8V%N(&=R86YT('EO=2!T:&4@87!P<F]P
M<FEA=&4@<FEG:'1S('1O('=O<FL@;VX@=&AE"G-O=7)C97,N"@I4:&4@8&!#
M5E-23T]48&`@:7,@9&EF9F5R96YT(&9O<B!C;VUM:71T97)S.R!I;G-T96%D
M(&]F('1H92!R97!O<VET;W)Y(&QI<W1E9`IA8F]V92P@<V5T(&!@0U934D]/
M5&!@('1O.CH*"B`@(#IE>'0Z55-%4DY!345`8W9S+FAO<F1E+F]R9SHO<F5P
M;W-I=&]R>0H*<F5P;&%C:6YG(&!@55-%4DY!345@8"!W:71H('EO=7(@8W9S
M('5S97)N86UE+@H*5&AE(&-O;6UI='1E<G,G(')E<&]S:71O<GD@9&]E<R!N
M;W0@=7-E('!S97)V97(N("!9;W4@=VEL;"!N965D('1O(&AA=F4@<W-H"FEN
M<W1A;&QE9"!O;B!Y;W5R('-Y<W1E;2P@86YD(&AA=F4@87)R86YG960@=VET
M:"!O;F4@;V8@=&AE(&-O<F4@9&5V96QO<&5R<R!T;PIP=70@>6]U<B!34T@@
M:V5Y(&]N('1H92!S>7-T96TN("!)9B!Y;W4@:&%V92!N;W0@9&]N92!T:&ES
M+"!T86QK('1O(&]N92!O9B!T:&4*8V]R92!D979E;&]P97)S+@H*5&\@9V5T
M(&-V<R!T;R!U<V4@<W-H+"!Y;W4@=VEL;"!N965D('1O('-E="!T:&4@96YV
M:7)O;FUE;G0@=F%R:6%B;&4*8&!#5E-?4E-(8&`@=&\@8&!S<VA@8"!I;B!Y
M;W5R('-H96QL+@H*66]U(&1O(&YO="!N965D('1O(&1O(&!@8W9S(&QO9VEN
M8&`[('EO=2!W:6QL(&)E('!R;VUP=&5D(&9O<B!T:&4@<&%S<W!H<F%S90IF
M;W(@>6]U<B!34T@@:V5Y('=H96YE=F5R('EO=2!A8V-E<W,@=&AE(')E<&]S
M:71O<GDN"@I9;W4@;6%Y(&%L<V\@=VES:"!T;R!S970@=&AE(&5N=FER;VYM
M96YT('9A<FEA8FQE(&!@141)5$]28&`@=&\@<&]I;G0@=&\@>6]U<@IF879O
M<FET92!T97AT(&5D:71O<BX@5&AI<R!W87D@=VAE;B!Y;W4@8V]M;6ET('-O
M9G1W87)E(&-H86YG97,@86YD(&ET(&%S:W,*>6]U('1O(&5N=&5R(&$@8VAA
M;F=E(&1E<V-R:7!T:6]N+"!Y;W4@8V%N(&1O('-O(&EN('EO=7(@9F%V;W)I
M=&4@961I=&]R+@H*5&AE;BP@9F]R('=O<FL@;VX@9&5V96QO<&UE;G1A;"P@
M8FQE961I;F<M961G92!V97)S:6]N<SH*"C$I($-H96-K(&]U="!T:&4@8V]D
M92!B>2!T>7!I;F<@8&!C=G,@8V\@34]$54Q%8&`*,BD@5V]R:R!O;B!T:&4@
M8V]D92`\:&%C:RP@:&%C:RP@:&%C:SX*,RD@0V]M;6ET(&%N>2!C:&%N9V5S
M('=I=&@@8&!C=G,@8V]M;6ET($9)3$5.04U%4V!@(&EN('1H92!D:7)E8W1O
M<GD@=&AE(&9I;&5S"B`@(&%R92!I;BX*"E-O;65T:6UE<RP@;W1H97)S('=I
M;&P@;6%K92!C:&%N9V5S(&%N9"!Y;W4@=VEL;"!N965D('1O('5P9&%T92!Y
M;W5R('1R964@<V\*=&AE(&-H86YG97,@<VAO=R!U<"!I;B!Y;W5R(&QO8V%L
M('-O=7)C97,N("!9;W4@9&\@=&AI<R!W:71H('1H92!@8&-V<PIU<&1A=&5@
M8"!C;VUM86YD(&EN('1H92!H;W)D92!D:7)E8W1O<GDN("!0;&5A<V4@8F4@
M<W5R92!T;R!U<&1A=&4@>6]U<B!T<F5E"G)E9W5L87)L>3L@;65R9VEN9R!C
M:&%N9V5S(&ES(&-O;G-I9&5R86)L>2!M;W)E('=O<FL@=&AA;B!R=6YN:6YG
M(&!@8W9S"G5P9&%T96!@+@H*5&\@=V]R:R!W:71H(&%N>2!T86=G960@8G)A
M;F-H("AT;R!P871C:"!A('-T86)L92!R96QE87-E+"!F;W(@:6YS=&%N8V4I
M.@H*,2D@0VAE8VL@;W5T('1H92!C;V1E('=I=&@@8&!C=G,@8V\@+7(@5$%'
M($U/1%5,16!@"C(I(%=O<FL@;VX@=&AE(&-O9&4@/&AA8VLL(&AA8VLL(&AA
M8VL^"C,I($-O;6UI="!A;GD@8VAA;F=E<R!W:71H(&!@8W9S(&-O;6UI="!&
M24Q%3D%-15-@8"!I;B!T:&4@9&ER96-T;W)Y('1H92!F:6QE<PH@("!A<F4@
M:6XN"@I)9B!S;VUE8F]D>2!E;'-E(&%L<V\@;6%K97,@8VAA;F=E<R!T;R!T
M:&4@;&%B96QE9"!V97)S:6]N+"!Y;W4@8V%N(&=E="!T:&5M"FEN('EO=7(@
M;&]C86P@<V]U<F-E('1R964@=VET:"!T:&4@8&!C=G,@=7!D871E8&`@8V]M
M;6%N9"!I<W-U960@:6X@=&AE(&UO9'5L90ID:7)E8W1O<GDN"@I)9B!Y;W4@
M87)E(&1O;F4@=V]R:VEN9R!W:71H('1H92!L86)E;&5D('-O=7)C92!B<F%N
M8V@L(&%N9"!W;W5L9"!L:6ME('1O(&UO=F4*8F%C:R!I;G1O('1H92!B;&5E
M9&EN9RUE9&=E(&1E=F5L;W!M96YT('-O=7)C92!T<F5E+"!Y;W4@8V%N(&ES
M<W5E('1H92!C;VUM86YD"F!@8W9S('5P9&%T92`M06!@('1O('5P9&%T92!E
M=F5R>71H:6YG('1O('1H92!C=7)R96YT(&!@2$5!1&!@('9E<G-I;VXN"@HH
M5V4@=7-E9"!T;R!D;V-U;65N="!H;W<@=&\@;65R9V4@8V]D92!F<F]M($A%
M040@:6YT;R!A(&QA8F5L960@8G)A;F-H(&AE<F4L"F)U="!S:6YC92!I="!W
M87,@:&5A=FEL>2!P97!P97)E9"!W:71H(")T86QK('1O(&-O<F4@9&5V96QO
M<&5R<R!F:7)S="(L(&ET)W,*8F5E;B!E;&ED960@=&\@<')E=F5N="!E<G)O
M<G,@;V8@97AP97)I;65N=&%T:6]N+B`@268@>6]U('1H:6YK('EO=2!N965D
M('1O(&1O"G1H870L('EO=2!H879E('1O('1A;&L@=&\@8V]R92!D979E;&]P
M97)S(&%N>6AO=R`M+2!T:&5Y)VQL(&5X<&QA:6X@:&]W+BD*"@I/=&AE<B!#
M5E,@3F]T97,*+2TM+2TM+2TM+2TM+2TM"@I)9B!Y;W4@9&\@96YD('5P(&=E
M='1I;F<@82!#5E,@86-C;W5N="P@:&5R92!A<F4@<V]M92!T:7!S('1O(&AE
M;'`@:V5E<"!T:&EN9W,*9V]I;F<@<VUO;W1H;'DZ"@HQ+B!3=6)S8W)I8F4@
M=&\@=&AE(&-V<T!L:7-T<RYH;W)D92YO<F<@86YD(&1E=D!L:7-T<RYH;W)D
M92YO<F<@;6%I;&EN9R!L:7-T<RX*"C(N($)E('-U<F4@=&\@;6]D:69Y('1H
M92!F:6QE(&!@9&]C<R]#2$%.1T538&`@=&\@<F5F;&5C="!T:&4@8VAA;F=E
M<R!T;R!T:&4*("`@8V]D92!Y;W4@87)E(&-O;6UI='1I;F<N"@HS+B!)9B!Y
M;W4G<F4@<&QA;FYI;F<@;VX@9&]I;F<@86YY=&AI;F<@;6%J;W(L('!L96%S
M92!L970@<&5O<&QE(&MN;W<@:6X*("`@861V86YC92!O;B!T:&4@9&5V0"!O
M<B!A<'!L:6-A=&EO;B!M86EL:6YG(&QI<W1S(&%S(&%P<')O<')I871E+@H*
M("`@1&5V96QO<&5R<R!N965D('1O(&-O;6UU;FEC871E(&5X=&5N<VEV96QY
M(&EN(&]R9&5R('1O(&UA:V4@<W5R92!E=F5R>6]N90H@("!K;F]W<R!W:&%T
M)W,@9V]I;F<@;VXN("!4:&ES(&ES(&5X=')E;65L>2!I;7!O<G1A;G0@=VAE
M;B!Y;W4@=V]R:R!O;B!K97D*("`@8V]M<&]N96YT<RX*"C0N(%5S92!T:&4@
M0G5G(%1R86-K:6YG(%-Y<W1E;2!O;B!H='1P.B\O8G5G<RYH;W)D92YO<F<N
M("!!;&P@;F5W('-U8FUI<W-I;VYS"B`@(&%R92!B96EN9R!C8R=D('1O('1H
M92!B=6=S0&QI<W1S+FAO<F1E+F]R9R!M86EL:6YG(&QI<W0@<V\@=&AA="!I
M9B!W92!A<F5N)W0*("`@<&%Y:6YG(&%T=&5N=&EO;BP@=V4G;&P@870@;&5A
M<W0@9V5T(&UA:6P@86)O=70@:70N("!5<VEN9R!T:&4@0G5G<PH@("!D871A
M8F%S92!H96QP<R!U<R!K965P('1R86-K(&]F(&ES<W5E<R!W92!A<F4@:&%V
M:6YG(&%N9"!W:&5R92!W92!S=&%N9`H@("!W:71H('1H92!P<F]D=6-T+@H*
M-2X@4F5M96UB97(@=&\@861V86YC92!T:&4@;&EB<F%R>2!V97)S:6]N('=H
M96YE=F5R(&%N>71H:6YG(&UA:F]R(&ES(&-H86YG960N"@``````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]D;V-S+TE.4U1!3$P`````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C4R,S(@,3`U,34T,S0Q
M,S4@,#$W-3(U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@
M26YS=&%L;&EN9R!T:&4@2&]R9&4@,RXQ($9R86UE=V]R:PH]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"CI,87-T('5P9&%T93H@("`D
M1&%T93H@,C`P-B\P."\Q-2`P.3HS,#HT,R`D"CI2979I<VEO;CH@("`@("`D
M4F5V:7-I;VXZ(#$N.3`N-BXQ-B`D"CI#;VYT86-T.B`@("`@("!H;W)D94!L
M:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N=',*+BX@<V5C
M=&EO;BUN=6UB97)I;F<Z.@H*5&AI<R!D;V-U;65N="!C;VYT86EN<R!I;G-T
M<G5C=&EO;G,@9F]R(&EN<W1A;&QI;F<@=&AE($AO<F1E($9R86UE=V]R:R!O
M;B!Y;W5R"G-Y<W1E;2X*"E1H92!(;W)D92!&<F%M97=O<FLL(&)Y(&ET<V5L
M9BP@9&]E<R!N;W0@<')O=FED92!A;GD@<VEG;FEF:6-A;G0@96YD('5S97(*
M9G5N8W1I;VYA;&ET>3L@:70@<')O=FED97,@82!B87-E(&9O<B!O=&AE<B!A
M<'!L:6-A=&EO;G,@86YD('1O;VQS(&9O<@ID979E;&]P97)S+B!7:&5N('EO
M=2!H879E(&EN<W1A;&QE9"!(;W)D92!A<R!D97-C<FEB960@8F5L;W<L('EO
M=2!W:6QL"G!R;V)A8FQY('=A;G0@=&\@:6YS=&%L;"!S;VUE(&]F('1H92!A
M=F%I;&%B;&4@2&]R9&4@87!P;&EC871I;VYS+"!S=6-H(&%S"DE-4%\@*&$@
M=V5B;6%I;"!C;&EE;G0I+"!O<B!+<F]N;VQI=&A?("AA(&-A;&5N9&%R*2X@
M5&AE<F4@:7,@82!L:7-T(&]F($AO<F1E"F%P<&QI8V%T:6]N<R!A;F0@<')O
M:F5C=',@870@:'1T<#HO+W=W=RYH;W)D92YO<F<O<')O:F5C=',N<&AP+@H*
M268@>6]U(&%R92!I;G1E<F5S=&5D(&EN(&1E=F5L;W!I;F<@87!P;&EC871I
M;VYS(&9O<B!(;W)D92P@=&AE<F4@:7,@9&5V96QO<&5R"F1O8W5M96YT871I
M;VX@86YD(')E9F5R96YC97,@879A:6QA8FQE(&%T(&AT='`Z+R]D978N:&]R
M9&4N;W)G+RP@86YD('-O;64*='5T;W)I86QS(&%N9"!P87!E<G,@;VX@2&]R
M9&4@879A:6QA8FQE(&%T(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!A<&5R<R\N
M"@I&;W(@:6YF;W)M871I;VX@;VX@=&AE(&-A<&%B:6QI=&EE<R!A;F0@9F5A
M='5R97,@;V8@2&]R9&4L('-E92!T:&4@9FEL90I214%$345?(&EN('1H92!T
M;W`M;&5V96P@9&ER96-T;W)Y(&]F('1H92!(;W)D92!D:7-T<FEB=71I;VXN
M"@HN+B!?24U0.B!H='1P.B\O=W=W+FAO<F1E+F]R9R]I;7`O"BXN(%]+<F]N
M;VQI=&@Z(&AT='`Z+R]W=W<N:&]R9&4N;W)G+VMR;VYO;&ET:"\*"@I/8G1A
M:6YI;F<@2&]R9&4*/3T]/3T]/3T]/3T]/3T]"@I4:&4@2&]R9&4@1G)A;65W
M;W)K(&-A;B!B92!O8G1A:6YE9"!F<F]M('1H92!(;W)D92!W96)S:71E(&%N
M9"!&5%`@<V5R=F5R+"!A=`H*("`@:'1T<#HO+W=W=RYH;W)D92YO<F<O:&]R
M9&4O"@H@("!F='`Z+R]F='`N:&]R9&4N;W)G+W!U8B]H;W)D92\*"D]R+"!B
M971T97(@>65T+"!U<V4@82!M:7)R;W(@=&AA="!I<R!C;&]S97(@=&\@>6]U
M+B`@5&AE(&UI<G)O<B!L:7-T(&-A;B!B90IF;W5N9"!A=#H*"B`@(&AT='`Z
M+R]W=W<N:&]R9&4N;W)G+VUI<G)O<G,N<&AP"@I4:&4@1E10(&1I<F5C=&]R
M>2!C;VYT86EN<R!T:&4@2&]R9&4@4$A0(&9I;&5S('=H:6-H(&-A;B!B92!U
M;G!A8VME9"!U<VEN9PI@8'1A<F!@(&%N9"!@8&=U;GII<&!@("AS964@8$EN
M<W1A;&QI;F<@2&]R9&5@7RP@8F5L;W<I+@H*0FQE961I;F<M961G92!D979E
M;&]P;65N="!V97)S:6]N<R!O9B!(;W)D92!A;F0@:71S(&%P<&QI8V%T:6]N
M<R!A<F4@879A:6QA8FQE"G9I82!#5E,[('-E92!T:&4@9FEL92!@9&]C<R](
M04-+24Y'8%\L(&]R('9I<VET('1H92!W96)S:71E"FAT='`Z+R]W=W<N:&]R
M9&4N;W)G+W-O=7)C92\L(&9O<B!I;F9O<FUA=&EO;B!O;B!A8V-E<W-I;F<@
M=&AE($AO<F1E($-64PIR97!O<VET;W)Y+@H*66]U('=I;&P@<')O8F%B;'D@
M86QS;R!W86YT(&]N92!O<B!M;W)E($AO<F1E(&%P<&QI8V%T:6]N<RP@<VEN
M8V4@2&]R9&4*9&]E<VXG="!D;R!M=6-H(&)Y(&ET<V5L9CL@82!L:7-T(&]F
M(&%V86EL86)L92!A<'!L:6-A=&EO;G,L('=I=&@@;&EN:W,@=&\*9&5S8W)I
M<'1I;VYS(&%N9"!D;W=N;&]A9',L(&-A;B!B92!F;W5N9"!A=`H*("`@:'1T
M<#HO+W=W=RYH;W)D92YO<F<O<')O:F5C=',N<&AP"@I7:&EL92!P<F5V:6]U
M<R!V97)S:6]N<R!O9B!(;W)D92!W97)E(&YU;6)E<F5D('1O(&-O<G)E<W!O
M;F0@=VET:"!A('!A<G1I8W5L87(*=F5R<VEO;B!O9B!T:&4@24U0('=E8FUA
M:6P@87!P;&EC871I;VXL('1H870@:7,@;F\@;&]N9V5R('1R=64@87,@;V8@
M2&]R9&4*=F5R<VEO;B`R+C`N(%1H92!C=7)R96YT('9E<G-I;VX@;V8@2&]R
M9&4@=VEL;"!W;W)K('=I=&@@=&AE(&-U<G)E;G0@=F5R<VEO;@IO9B!(;W)D
M92!A<'!L:6-A=&EO;G,N($9O<B!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('=H
M:6-H('9E<G-I;VYS(&%R90IC;VUP871I8FQE('-E92!H='1P.B\O=W=W+FAO
M<F1E+F]R9R]S;W5R8V4O=F5R<VEO;G,N<&AP+@H*"E%U:6-K($EN<W1A;&P*
M/3T]/3T]/3T]/3T]/0H*5&AE<V4@87)E('9E<GD@=&5R<V4@:6YS=')U8W1I
M;VYS(&AO=R!T;R!I;G-T86QL($AO<F1E(&%N9"!I=',@<')E<F5Q=6ES:71E
M<PIO;B!A($Q!35`@<WET96TN("!4:&5Y(&%R92!A9&1R97-S960@=&\@97AP
M97)I96YC960@861M:6YI<W1R871O<G,@=VAO(&MN;W<*97AA8W1L>2!W:&%T
M('1H97D@87)E(&1O:6YG+B`@1F]R(&UO<F4@9&5T86EL960@:6YS=')U8W1I
M;VYS+"!S=&%R="!R96%D:6YG"F)E;&]W(&%T(%!R97)E<75I<VET97-?+@H*
M,2X@0V]M<&EL:6YG(%!(4"!F;W(@07!A8VAE.CH*"B`@("`@8V0@<&AP+7@N
M>"YX+PH@("`@("XO8V]N9FEG=7)E("TM=VET:"UA<'AS/2]U<W(O<V)I;B]A
M<'AS(%P*("`@("`@("`@("`@("`@("`M+7=I=&@M9V5T=&5X="`M+7=I=&@M
M9&]M("TM=VET:"UM8W)Y<'0@7`H@("`@("`@("`@("`@("`@("TM=VET:"UI
M8V]N=B`M+65N86)L92UM8G-T<FEN9SUA;&P@+2UE;F%B;&4M;6)R96=E>"!<
M"B`@("`@("`@("`@("`@("`@+2UW:71H+6=D("TM=VET:"UP;F<M9&ER/2]U
M<W(@+2UW:71H+6IP96<M9&ER/2]U<W(@7`H@("`@("`@("`@("`@("`@("TM
M=VET:"UM:6UE+6UA9VEC/2]U<V5R+W-H87)E+VUI<V,O;6%G:6,N;6EM92!<
M"B`@("`@("`@("`@("`@("`@6RTM=VET:"UM>7-Q;'PM+7=I=&@M<&=S<6Q\
M+2UW:71H+6]C:3A\+2UW:71H+6QD87!="B`@("`@;6%K90H@("`@(&UA:V4@
M:6YS=&%L;`H*,BX@4F5S=&%R="!!<&%C:&4N"@HS+B!);G-T86QL(%!%05(@
M<&%C:V%G97,Z.@H*("`@("!P96%R(&EN<W1A;&P@+6\@3&]G($UA:6P@36%I
M;%]-:6UE($1"($1A=&4@1FEL90H@("`@('!E87(@+60@<')E9F5R<F5D7W-T
M871E/6)E=&$@:6YS=&%L;"`M82!397)V:6-E<U]796%T:&5R"@HT+B!%>'1R
M86-T('1A<F)A;&PZ.@H*("`@("!C9"`O=7-R+VQO8V%L+V%P86-H92]H=&1O
M8W,*("`@("!T87(@>GAV9B`O<&%T:"]T;R]H;W)D92UX+GDN>BYT87(N9WH*
M("`@("!M=B!H;W)D92UX+GDN>B!H;W)D90H*-2X@0V]N9FEG=7)E($AO<F1E
M.CH*"B`@("`@8V0@8V]N9FEG+PH@("`@(&9O<B!F(&EN("HN9&ES=#L@9&\@
M8W`@)&8@8&)A<V5N86UE("1F("YD:7-T8#L@9&]N90H*-BX@0W)E871E(&1A
M=&%B87-E('1A8FQE<SHZ"@H@("`@(&-D("XN+W-C<FEP=',O<W%L"B`@("`@
M=FD@8W)E871E+FUY<W%L+G-Q;`H@("`@(&UY<W%L("UU(')O;W0@+7`@/"!C
M<F5A=&4N;7ES<6PN<W%L"@HW+B!497-T($AO<F1E.CH*"B`@("`@:'1T<#HO
M+WEO=7(M<V5R=F5R+VAO<F1E+W1E<W0N<&AP"@HX+B!&:6YI<V@@8V]N9FEG
M=7)A=&EO;CHZ"@H@("`@(&AT='`Z+R]Y;W5R+7-E<G9E<B]H;W)D92\*"B`@
M($=O('1O($%D;6EN<W1R871I;VX@/3X@4V5T=7`@/3X@2&]R9&4*"@I0<F5R
M97%U:7-I=&5S"CT]/3T]/3T]/3T]/3T*"E1H92!F;VQL;W=I;F<@<')E<F5Q
M=6ES:71E<R!A<F4@*BI215%525)%1"HJ(&9O<B!(;W)D92!T;R!F=6YC=&EO
M;B!P<F]P97)L>2X*"C$N($$@=V5B<V5R=F5R('1H870@<W5P<&]R=',@4$A0
M+@H*("`@2&]R9&4@86YD(&ET<R!A<'!L:6-A=&EO;G,@87)E(&1E=F5L;W!E
M9"!U;F1E<B!T:&4@07!A8VAE('=E8G-E<G9E<BP@=VAI8V@*("`@=V4@<F5C
M;VUM96YD+B!!<&%C:&4@:7,@879A:6QA8FQE(&9R;VT*"B`@("`@(&AT='`Z
M+R]H='1P9"YA<&%C:&4N;W)G+PH*("`@2&]R9&4@:&%S(&%L<V\@8F5E;B!R
M97!O<G1E9&QY('5S960@<W5C8V5S<V9U;&QY('5N9&5R($UI8W)O<V]F="!)
M25,L(&%M;VYG"B`@(&]T:&5R<RX*"C(N(%!(4"`T+C,N,"!O<B!A8F]V92X*
M"B`@(%!(4"!I<R!T:&4@:6YT97)P<F5T960@;&%N9W5A9V4@:6X@=VAI8V@@
M2&]R9&4@:7,@=W)I='1E;BX*("`@66]U(&-A;B!O8G1A:6X@4$A0(&%T"@H@
M("`@("!H='1P.B\O=W=W+G!H<"YN970O"@H@("!&;VQL;W<@=&AE(&EN<W1R
M=6-T:6]N<R!I;B!T:&4@4$A0('!A8VMA9V4@=&\@8G5I;&0@4$A0(&9O<B!Y
M;W5R('-Y<W1E;2X@268*("`@>6]U('5S92!!<&%C:&4L(&)E('-U<F4@=&\@
M8G5I;&0@4$A0(&%S(&$@;&EB<F%R>2!W:71H(&]N92!O9B!T:&4@9F]L;&]W
M:6YG"B`@(&]P=&EO;G,Z.@H*("`@("`@("TM=VET:"UA<&%C:&4*("`@("`@
M("TM=VET:"UA<'AS"B`@("`@("`M+7=I=&@M87!X<S(*"B`@(&]P=&EO;G,@
M=&\@8&`N+V-O;F9I9W5R96!@+"!A;F0@;F]T(&%S(&$@<W1A;F1A;&]N92!E
M>&5C=71A8FQE+@H*("`@5&AE(&9O;&QO=VEN9R!02%`@;W!T:6]N<R!A<F4@
M*BI215%525)%1"HJ(&)Y($AO<F1E("AL:7-T960@=VET:"!T:&5I<B!O=VX*
M("`@<')E<F5Q=6ES:71E<R!A;F0@8V]N9FEG=7)E(&]P=&EO;G,I+B!);B!M
M86YY(&-A<V5S+"!T:&4@<F5Q=6ER960@;&EB<F%R:65S"B`@(&%N9"!T;V]L
M<R!C86X@8F4@;V)T86EN960@87,@<&%C:V%G97,@9G)O;2!Y;W5R(&]P97)A
M=&EN9R!S>7-T96T@=F5N9&]R+@H*("`@82X@1V5T=&5X="!S=7!P;W)T+B!@
M8"TM=VET:"UG971T97AT8&`*"B`@("`@($=E='1E>'0@:7,@=&AE($=.52!4
M<F%N<VQA=&EO;B!0<F]J96-T)W,@;&]C86QI>F%T:6]N(&QI8G)A<GDN"B`@
M("`@($AO<F1E('5S97,@9V5T=&5X="!T;R!P<F]V:61E(&QO8V%L('1R86YS
M;&%T:6]N<R!O9B!T97AT(&1I<W!L87EE9"!B>0H@("`@("!A<'!L:6-A=&EO
M;G,N($EN9F]R;6%T:6]N(&]N(&]B=&%I;FEN9R!T:&4@9V5T=&5X="!P86-K
M86=E(&ES(&%V86EL86)L90H@("`@("!A=`H*("`@("`@("`@:'1T<#HO+W=W
M=RYG;G4N;W)G+W-O9G1W87)E+V=E='1E>'0O9V5T=&5X="YH=&UL"@H@("`@
M("!3964@86QS;R!N;W1E(&)E;&]W(&]N(&-O;F9I9W5R:6YG(%1R86YS;&%T
M:6]N<U\N"@H@("!B+B!834P@86YD($1/35A-3"!S=7!P;W)T+B!@8"TM=VET
M:"UD;VU@8`H*("`@("`@2&]R9&4G<R!H96QP(&5N9VEN92!A;F0@8V]M<&]N
M96YT('-E='5P(')E<75I<F4@6$U,('-U<'!O<G0N(%=H:6QE('-O;64*("`@
M("`@=V5B<V5R=F5R<R`H:6YC;'5D:6YG(')E8V5N="!!<&%C:&4@=F5R<VEO
M;G,I(&AA=F4@6$U,(&QI8G)A<FEE<PH@("`@("!B=6EL="UI;BP@;W1H97)S
M('=I;&P@<F5Q=6ER92!T:&4@97AP870@6$U,('!A<G-E<B!L:6)R87)I97,L
M(&%V86EL86)L90H@("`@("!F<F]M"@H@("`@("`@(&AT='`Z+R]E>'!A="YS
M;W5R8V5F;W)G92YN970O"@H@("`@("`N+B!);7!O<G1A;G0Z.B!9;W4@;75S
M="!H879E("HJ8F]T:"HJ(%A-3"!L:6)R87)I97,@:6YS=&%L;&5D(&9O<B!(
M;W)D90H@("`@("`@("`@("`@("`@("`@("!T;R!W;W)K('!R;W!E<FQY(0H*
M("`@("`@3VQD97(@=F5R<VEO;G,@;V8@4$A0(&%L<V\@<F5Q=6ER92!@8"TM
M=VET:"UX;6Q@8"!T;R!E;F%B;&4@=&AE"B`@("`@(%-!6"!834P@9G5N8W1I
M;VYS+B!7:71H(')E8V5N="!V97)S:6]N<R!O9B!02%`L('1H:7,@:7,@96YA
M8FQE9`H@("`@("!B>2!D969A=6QT+@H*("`@5&AE(&9O;&QO=VEN9R!02%`@
M;W!T:6]N<R!A<F4@*BI214-/34U%3D1%1"HJ('1O(&5N86)L92!A9'9A;F-E
M9"!F96%T=7)E<R!I;@H@("!(;W)D93H*"B`@(&$N($$@<')E9F5R96YC97,@
M8V]N=&%I;F5R+@H*("`@("`@2&]R9&4@87!P;&EC871I;VYS(&-A;B!S=&]R
M92!U<V5R('!R969E<F5N8V5S(&EN(&%N(%-13"!D871A8F%S92P@86X*("`@
M("`@3$1!4"!D:7)E8W1O<GDL(&%N($E-4U`@<V5R=F5R+"!A($MO;&%B('-E
M<G9E<BP@;W(@:6X@4$A0('-E<W-I;VYS+@H*("`@("`@1F]R(%-13"!D871A
M8F%S92!P<F5F97)E;F-E<R!S=&]R86=E+"!(;W)D92!I<R!T:&]R;W5G:&QY
M('1E<W1E9"!O;@H@("`@("!->5-13"`H8&`M+7=I=&@M;7ES<6Q@8"D@86YD
M(%!O<W1G<F5344P@*&!@+2UW:71H+7!G<W%L8&`I(&%N9"!H87,@8F5E;@H@
M("`@("!R97!O<G1E9"!T;R!W;W)K('=I=&@@3W)A8VQE("A@8"TM=VET:"UO
M8VDX8&`I(&%N9"!344P@4V5R=F5R"B`@("`@("A@8"TM=VET:"UM<W-Q;&!@
M*2X@($ET(&UA>2!A;'-O('=O<FL@=VET:"!A;GD@;W1H97(@9&%T86)A<V4@
M<W5P<&]R=&5D"B`@("`@(&)Y(%!%05(L(&)U="!T:&5Y(&%R92!U;G1E<W1E
M9"X*"B`@("`@(%!R969E<F5N8V5S(&-A;B!A;'-O(&)E('-T;W)E9"!V:6$@
M3$1!4"`H8&`M+7=I=&@M;&1A<&!@*2P@2V]L86(*("`@("`@*&!@+2UW:71H
M+6QD87!@8"DL(&%N9"!)35-0+@H*("`@("`@06QT97)N871I=F5L>2P@<')E
M9F5R96YC97,@8V%N(&)E('-T;W)E9"!I;B!02%`@<V5S<VEO;G,L('=H:6-H
M"B`@("`@(')E<75I<F5S(&YO(&5X=&5R;F%L('!R;V=R86US(&]R(&-O;F9I
M9W5R92!O<'1I;VYS+"!B=70@=VAI8V@@=VEL;"!N;W0*("`@("`@;6%I;G1A
M:6X@<')E9F5R96YC97,@8F5T=V5E;B!S97-S:6]N<RX*"B`@("`@(%=H:6QE
M('1H92!,1$%0+"!D871A8F%S92P@2V]L86(L(&]R($E-4U`@<V5R=F5R(&YE
M960@;F]T(&)E(')U;FYI;F<@;VX*("`@("`@=&AE(&UA8VAI;F4@;VYT;R!W
M:&EC:"!Y;W4@87)E(&EN<W1A;&QI;F<@2&]R9&4L('1H92!A<'!R;W!R:6%T
M90H@("`@("!C;&EE;G0@;&EB<F%R:65S('1O(&%C8V5S<R!T:&4@<V5R=F5R
M(&UU<W0@8F4@879A:6QA8FQE(&QO8V%L;'DN"@H@("`@("!)9B!A('!R969E
M<F5N8V4@8V]N=&%I;F5R(&ES(&YO="!C;VYF:6=U<F5D+"!N;R!P<F5F97)E
M;F-E(&]P=&EO;G,*("`@("`@=VEL;"!B92!C;VYF:6=U<F%B;&4@=FEA($AO
M<F1E)W,@=V5B(&EN=&5R9F%C92`M('1H92!D969A=6QT('9A;'5E<PH@("`@
M("!S=&]R960@:6X@96%C:"!A<'!L:6-A=&EO;G,@8&!C;VYF:6<O<')E9G,N
M<&AP8&`@9FEL92!W:6QL(&)E('5S960N"@H@("!B+B!-8W)Y<'0@<W5P<&]R
M="!@8"TM=VET:"UM8W)Y<'1@8`H*("`@("`@36-R>7!T(&ES(&$@9V5N97)A
M;"UP=7)P;W-E(&-R>7!T;V=R87!H>2!L:6)R87)Y('=H:6-H(&ES(&)R;V%D
M97(@86YD"B`@("`@('-I9VYI9FEC86YT;'D@;6]R92!E9F9I8VEE;G0@*$9!
M4U1%4B$I('1H86X@4$A0)W,@;W=N(&-R>7!T;V=R87!H:6,*("`@("`@8V]D
M92X@66]U(&-A;B!O8G1A:6X@;6-R>7!T(&9R;VT*"B`@("`@("`@(&AT='`Z
M+R]M8W)Y<'0N<V]U<F-E9F]R9V4N;F5T+PH*("`@("`@0G5I;&1I;F<@4$A0
M('=I=&AO=70@;6-R>7!T('-U<'!O<G0@=VEL;"!N;W0@<W1O<"!(;W)D92!F
M<F]M('=O<FMI;F<L"B`@("`@(&)U="!W:6QL(&9O<F-E(&ET('1O('5S92!W
M96%K97(@*&%N9"!M=6-H('-L;W=E<BD@96YC<GEP=&EO;BX*"B`@(&,N(%54
M1BTX('-U<'!O<G0@8&`M+7=I=&@M:6-O;G8@+2UE;F%B;&4M;6)S=')I;F<]
M86QL("TM96YA8FQE+6UB<F5G97A@8`H*("`@("`@268@=&AE<V4@97AT96YS
M:6]N<R!A<F4@96YA8FQE9"P@2&]R9&4@8V%N('-U<'!O<G0@;75L=&EB>71E
M(&-H87)A8W1E<@H@("`@("!S971S(&QI:V4@551&+3@@*&UE86YI;F<@=&AA
M="!C;VYT96YT('=I=&@@86YY(&-H87)S970@8V%N(&)E('9I97=E9`H@("`@
M("!W:71H(&%N>2!T<F%N<VQA=&EO;BDN"@H@("!D+B!'1"!S=7!P;W)T(&!@
M+2UW:71H+6=D8&`*"B`@("`@($AO<F1E('=I;&P@=7-E('1H92!'1"!E>'1E
M;G-I;VX@=&\@<&5R9F]R;2!M86YI<'5L871I;VYS(&]N(&EM86=E(&1A=&$*
M("`@("`@=&AR;W5G:"!T:&4@2&]R9&5?26UA9V4@;&EB<F%R>2X*"B`@("`@
M($EF('EO=2!W86YT($=$('1O(&)E(&%B;&4@=&\@=V]R:R!W:71H(%!.1R!I
M;6%G97,L('EO=2!S:&]U;&0@=7-E('1H90H@("`@("!@8"TM=VET:"UP;F<M
M9&ER8&`@;W!T:6]N('1O(&UA:V4@<W5R92!02%`@8V%N(&9I;F0@=&AE(%!.
M1R!L:6)R87)I97,*("`@("`@:70@;F5E9',@=&\@8V]M<&EL92X*"B`@("`@
M($EF('EO=2!W86YT($=$('1O(&)E(&%B;&4@=&\@=V]R:R!W:71H($I014<@
M:6UA9V5S+"!Y;W4@<VAO=6QD('5S92!T:&4*("`@("`@8&`M+7=I=&@M:G!E
M9RUD:7)@8"!O<'1I;VX@=&\@;6%K92!S=7)E(%!(4"!C86X@9FEN9"!T:&4@
M2E!%1R!L:6)R87)I97,*("`@("`@:70@;F5E9',@=&\@8V]M<&EL92X*"B`@
M("`@(%EO=2!C86X@86QS;R!U<V4@=&AE($EM86=E36%G:6-K7R!P86-K86=E
M('1O(&1O('1H97-E(&UA;FEP=6QA=&EO;G,*("`@("`@:6YS=&5A9"X@(%-E
M92!T:&4@8&!);6%G92!-86YI<'5L871I;VY@8"!T86(@;V8@=&AE($AO<F1E
M('-E='5P(&9O<B!M;W)E"B`@("`@(&1E=&%I;',N"@H@("`@("`N+B!?26UA
M9V5-86=I8VLZ(&AT='`Z+R]W=W<N:6UA9V5M86=I8VLN;W)G"@H@("!E+B!-
M24U%($UA9VEC('-U<'!O<G0@8&`M+7=I=&@M;6EM92UM86=I8V!@"@H@("`@
M("!(;W)D92!W:6QL('5S92!T:&4@34E-12!-86=I8R!E>'1E;G-I;VX@=&\@
M9W5E<W,@=&AE($U)344@='EP92!O9B!F:6QE<PH@("`@("!B>2!A;F%L>7II
M;F<@=&AE:7(@8V]N=&5N=',N"@H@("`@("`N+B!.;W1E.CH@5&AI<R!E>'1E
M;G-I;VX@:7,@<F5P;W)T960@=&\@8F4@9&5P<F5C871E9%\@:6X@9F%V;W(@
M;V8@=&AE"B`@("`@("`@("`@("`@("!F:6QE:6YF;R!014-,(&5X=&5N<VEO
M;B`H<V5E(&)E;&]W*2X@($AO=V5V97(L('-O;64@=7-E<G,@:&%V90H@("`@
M("`@("`@("`@("`@<F5P;W)T960@=&AA="!T:&4@9FEL96EN9F\@97AT96YS
M:6]N('=I;&P@;F]T(&)U:6QD(&-O<G)E8W1L>0H@("`@("`@("`@("`@("`@
M;VX@=&AE:7(@<WES=&5M+B!)9B!S;RP@=&AE;B!T:&4@34E-12!-86=I8R!E
M>'1E;G-I;VX@<VAO=6QD"B`@("`@("`@("`@("`@("!B92!U<V5D(&EN<W1E
M860N(%!I8VL@;VYE(&]R('1H92!O=&AE<B`M('1H97)E(&ES(&YO(&YE960@
M=&\*("`@("`@("`@("`@("`@(&-O;7!I;&4@8F]T:"X*"B`@("`@($EF('5S
M:6YG(%!(4"`T+C,N,"`M/B`T+C,N,2P@>6]U('-H;W5L9"!U<V4@8&`M+65N
M86)L92UM:6UE+6UA9VEC8&`*("`@("`@:6YS=&5A9"!O9B!@8"TM=VET:"UM
M:6UE+6UA9VEC8&`N"@H@("`@("`N+B!?9&5P<F5C871E9#H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VUI;65?;6%G:6,*"B`@("XN($EM<&]R=&%N=#HZ($%D9&ET
M:6]N86QL>2P@:6YD:79I9'5A;"!(;W)D92!A<'!L:6-A=&EO;G,@;6%Y("HJ
M4D5154E212HJ"B`@("`@("`@("`@("`@("`@(&]R("HJ4D5#3TU-14Y$*BH@
M;W1H97(@;W!T:6]N<R!T;R!B92!B=6EL="!I;G1O(%!(4`H@("`@("`@("`@
M("`@("`@("!A;'-O+B!0;&5A<V4@8VAE8VL@8&!D;V-S+TE.4U1!3$Q@8"!F
M;W(@86QL(&%P<&QI8V%T:6]N<R!Y;W4*("`@("`@("`@("`@("`@("`@=VES
M:"!T;R!U<V4@=&\@<V5E(&EF(&]T:&5R(%!(4"!O<'1I;VYS(&%R92!N965D
M960N"@HS+B!!9&1I=&EO;F%L(%!%05(@36]D=6QE<PH*("`@4$5!4B!I<R!S
M:&]R="!F;W(@(E!(4"!%>'1E;G-I;VX@86YD($%P<&QI8V%T:6]N(%)E<&]S
M:71O<GDB+B`@5&AE(&=O86P@;V8*("`@4$5!4B!I<R!T;R!P<F]V:61E(&$@
M;65A;G,@;V8@9&ES=')I8G5T:6YG(')E=7-A8FQE(&-O9&4N"@H@("!&;W(@
M;6]R92!I;F9O<FUA=&EO;BP@<V5E(&AT='`Z+R]P96%R+G!H<"YN970O"@H@
M("`N+B!);7!O<G1A;G0Z.B!-86ME('-U<F4@>6]U(&%R92!R=6YN:6YG(&$@
M<W5P<&]R=&5D("AI+F4N(&YE=R!E;F]U9V@I"B`@("`@("`@("`@("`@("`@
M('9E<G-I;VX@;V8@4$5!4CH@=7-E('1H92!T97-T('-C<FEP="!D97-C<FEB
M960@8F5L;W<@=6YD97(*("`@("`@("`@("`@("`@("`@(F!#;VYF:6=U<FEN
M9R!(;W)D96!?(BX@($1O("HJ;F]T*BH@=7-E('1H92!014%2('9E<G-I;VX*
M("`@("`@("`@("`@("`@("`@9G)O;2!F='`N:&]R9&4N;W)G+@H*("`@0VAE
M8VL@=&AA="!T:&4@<&%T:"!W:&5R92!T:&4@4$5!4B!P86-K86=E<R!A<F4@
M:6YS=&%L;&5D(&%R92!P87)T(&]F('1H90H@("!@8&EN8VQU9&5?<&%T:&!@
M('!A<F%M971E<B!T:&%T(%!(4"!U<V5S('1O(&9I;F0@4$5!4B!P86-K86=E
M<RX*"B`@(%)U;B!T:&4@8V]M;6%N9#HZ"@H@("`@('!E87(@8V]N9FEG+7-H
M;W<*"B`@(%EO=2!W:6QL('-E92!S;VUE=&AI;F<@;&EK93HZ"@H@("`@(%!%
M05(@9&ER96-T;W)Y("`@("`@("`@("`@("`@("!P:'!?9&ER("`@("`@("`@
M+W5S<B]S:&%R92]P:'`*"B`@($YO=R!O<&5N('1H92!P:'`N:6YI(&9I;&4@
M;V8@>6]U<B!S>7-T96TL(&9O<B!E>&%M<&QE(&!@+V5T8R]P:'`N:6YI8&`L
M"B`@(&9I;F0@=&AE(&!@:6YC;'5D95]P871H8&`@86YD(&UA:V4@<W5R92!T
M:&%T(&!@+W5S<B]S:&%R92]P:'!@8"!I<R!P87)T(&]F"B`@('1H92!L:7-T
M+B`@268@>6]U(&AA9"!T;R!C:&%N9V4@=&AA="!V86QU92P@<F5S=&%R="!T
M:&4@=V5B('-E<G9E<B!A9G1E<@H@("!S879I;F<@8&!P:'`N:6YI8&`N"@H@
M("!4:&5S92!014%2(&UO9'5L97,@87)E("HJ4D5154E2140J*B!T;R!B92!I
M;G-T86QL960@9F]R(&-O;7!L971E($AO<F1E"B`@(&9U;F-T:6]N86QI='DZ
M"@H@("!A+B!,;V<*("`@8BX@36%I;`H@("!C+B!-86EL7TUI;64*"B`@("`@
M(%1O(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA
M;F0@<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL($QO9R!-86EL($UA
M:6Q?36EM90H*("`@5&AE<V4@4$5!4B!M;V1U;&5S(&%R92`J*E)%0T]-345.
M1$5$*BH@=&\@8F4@:6YS=&%L;&5D.@H*("`@82X@1$(@*#X](#$N-BXP*0H*
M("`@("`@*BI215%525)%1"HJ(&%S('-O;VX@87,@>6]U('=A;G0@;W(@;F5E
M9"!T;R!S=&]R92!A;GET:&EN9R!I;B!A(&1A=&%B87-E+@H@("`@("!4;R!I
M;G-T86QL+"!E;G1E<B!T:&4@9F]L;&]W:6YG(&%T('1H92!C;VUM86YD('!R
M;VUP=#HZ"@H@("`@("`@('!E87(@:6YS=&%L;"!$0@H*("`@("`@5&\@=7!G
M<F%D92P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M
M<'0Z.@H*("`@("`@("!P96%R('5P9W)A9&4@1$(*"B`@(&(N($9I;&4*"B`@
M("`@("HJ4D5154E2140J*B!O;FQY(&EF('EO=2!W:7-H('1O(&EM<&]R="!#
M4U8@9FEL97,N"B`@("`@(%1O(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I
M;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T
M86QL($9I;&4*"B`@(&,N($1A=&4*"B`@("`@("HJ4D5154E2140J*B!O;FQY
M(&EF('EO=2!A<F4@9&5A;&EN9R!W:71H(&-A;&5N9&%R(&1A=&$N"B`@("`@
M(%1O(&EN<W1A;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA
M;F0@<')O;7!T.CH*"B`@("`@("`@<&5A<B!I;G-T86QL($1A=&4*"B`@(&0N
M(%-E<G9I8V5S7U=E871H97(@*#X](#$N,RXQ*0H*("`@("`@*BI215%525)%
M1"HJ(&]N;'D@:68@>6]U('=I<V@@=&\@=7-E('1H92!W96%T:&5R+F-O;2!B
M;&]C:R!O;@H@("`@("!T:&4@<&]R=&%L('!A9V4N"B`@("`@(%1O(&EN<W1A
M;&PL(&5N=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T
M.CH*"B`@("`@("`@<&5A<B`M9"!P<F5F97)R961?<W1A=&4]8F5T82!I;G-T
M86QL("UA(%-E<G9I8V5S7U=E871H97(*"B`@("`@($%D9&ET:6]N86P@<W1E
M<',@87)E(')E<75I<F5D(&EF('EO=2!W86YT('5S92!T:&4@345405(@=V5A
M=&AE<B!B;&]C:R!O;@H@("`@("!T:&4@<&]R=&%L('!A9V4N(%-E92!T:&4@
M9FEL92!@8&1A=&$O4V5R=FEC97-?5V5A=&AE<B]B=6EL9$UE=&%R1$(N<&AP
M8&`*("`@("`@:6X@>6]U<B!014%2(&1I<F5C=&]R>2!F;W(@9&5T86EL<RX*
M"B`@(%1H:7,@;65T:&]D(&]F(&EN<W1A;&QI;F<@4$5!4B!M;V1U;&5S(')E
M<75I<F5S('1H870@>6]U(&AA=F4@82!02%`@=F5R<VEO;@H@("!T:&%T(&AA
M<R!B965N(&-O;7!I;&5D(&%S(&$@<W1A=&EC(&)I;F%R>2X@($%L;"!V97)S
M:6]N<R!O9B!02%`@-"XS+C`K"B`@(&)U:6QD(&)O=&@@82!305!)(&UO9'5L
M92`H07!A8VAE+"!#1TDL(&5T8RXI(&%N9"!A(&-O;6UA;F0M;&EN92`H0TQ)
M*0H@("!B:6YA<GD@870@=&AE('-A;64@=&EM92X@($-H96-K(&EF('EO=2!H
M879E(&$@<&AP(&)I;F%R>2!I;@H@("!@8"]U<W(O;&]C86PO8FEN8&`@*&!@
M+W5S<B]B:6Y@8"!I9B!I9B!Y;W4@:6YS=&%L;&5D(&9R;VT@86X@;W!E<F%T
M:6YG"B`@('-Y<W1E;2!P86-K86=E*2!B969O<F4@<F5C;VUP:6QI;F<N"@H@
M("!)9B!Y;W4@<F5C96EV92!T:&4@97)R;W(@8&!#;W5L9"!N;W0@<F5A9"!C
M;60@87)G<V!@('EO=2!S:&]U;&0@<G5N('1H92!P96%R"B`@('-C<FEP="!T
M:&ES('=A>3HZ"@H@("`@('!H<"`M9"!R96=I<W1E<E]A<F=C7V%R9W8],2!?
M4$5!4E\@:6YS=&%L;"!?34]$54Q%7PH*("`@7U!%05)?(&ES('1H92!C;VUP
M;&5T92!P871H(&]F('1H92!P96%R('-C<FEP="!I;G-T86QL960@8GD@4$A0
M(&1U<FEN9PH@("!I;G-T86QL871I;VX@*&4N9RX@8&`O=7-R+VQO8V%L+V)I
M;B]P96%R8&`I+B`@36%K92!S=7)E('1H92!@8'!E87)@8"!S8W)I<'0*("`@
M87!P96%R<R!I;B!Y;W5R('!A=&@N(%1H92!D969A=6QT(&EN<W1A;&QA=&EO
M;B!P871H(&9O<B!P96%R(&ES"B`@(&!@+W5S<B]L;V-A;"]B:6XO<&5A<F!@
M+@H*("`@7TU/1%5,15\@:7,@=&AE(%!%05(@;6]D=6QE+"!L:7-T960@86)O
M=F4L('=H:6-H('EO=2!W:7-H('1O(&EN<W1A;&PN"@H@("!&;W(@;6]R92!D
M971A:6QE9"!D:7)E8W1I;VYS(&]N(&EN<W1A;&QI;F<@4$5!4B!M;V1U;&5S
M+"!S964@=&AE(%!%05(*("`@9&]C=6UE;G1A=&EO;B!A="!H='1P.B\O<&5A
M<BYP:'`N;F5T+VUA;G5A;"\*"C0N($%D9&ET:6]N86P@4$5#3"!-;V1U;&5S
M"@H@("!014-,(&ES('-H;W)T(&9O<B`B4$A0($5X=&5N<VEO;B!#;VUM=6YI
M='D@3&EB<F%R>2(N("!4:&4@9V]A;"!O9B!014-,(&ES"B`@('1O('!R;W9I
M9&4@82!M96%N<R!O9B!E87-I;'D@9&ES=')I8G5T:6YG(%!(4"!E>'1E;G-I
M;VYS+@H*("`@1F]R(&UO<F4@:6YF;W)M871I;VXL('-E92!H='1P.B\O<&5C
M;"YP:'`N;F5T+PH*("`@4$5#3"!I<R!T:&4@(G-I<W1E<B(@;V8@4$5!4B!A
M;F0@=7-E<R!T:&4@<V%M92!P86-K86=I;F<@86YD(&1I<W1R:6)U=&EO;@H@
M("!S>7-T96T@87,@4$5!4BP@<V\@=&AE(&-O;F9I9W5R871I;VXO<V5T=7`@
M:7,@97-S96YT:6%L;'D@:61E;G1I8V%L('1O('1H90H@("!014%2(&EN<W1R
M=6-T:6]N<R!A8F]V92X*"B`@(%=H96X@>6]U(&EN<W1A;&P@82!014-,(&5X
M=&5N<VEO;BP@>6]U(&AA=F4@=&\@861D(&ET('1O('EO=7(@8&!P:'`N:6YI
M8&`*("`@<V\@:70@9V5T<R!L;V%D960N("!!9&0@=&AE(&9O;&QO=VEN9R!L
M:6YE('1O('EO=7(@8&!P:'`N:6YI8&`@9FEL92!T;R!L;V%D"B`@('1H92!E
M>'1E;G-I;VX@*'1H92!E>'1E;G-I;VX@<VAO=6QD(&)E(&EN<W1A;&QE9"!I
M;B!T:&4@9&ER96-T;W)Y('-P96-I9FEE9`H@("!B>2!T:&4@8&!E>'1E;G-I
M;VY?9&ER8&`@;W!T:6]N(&EN(&!@<&AP+FEN:6!@*3HZ"@H@("`@(&5X=&5N
M<VEO;CUF:6QE:6YF;RYS;PH*("`@3W(@;VX@5VEN9&]W<SHZ"@H@("`@(&5X
M=&5N<VEO;CUF:6QE:6YF;RYD;&P*"B`@($%F=&5R('1H870L(')E<W1A<G0@
M>6]U<B!W96)S97)V97(N"@H@("!4:&5S92!014-,(&UO9'5L97,@87)E("HJ
M4D5#3TU-14Y$140J*B!T;R!B92!I;G-T86QL960Z"@H@("!A+B!F:6QE:6YF
M;PH*("`@("`@06QL;W=S($AO<F1E(&UO9'5L97,@=&\@9W5E<W,@=&AE($U)
M344@='EP92!O9B!F:6QE<R!B>2!A;F%L>7II;F<*("`@("`@=&AE:7(@8V]N
M=&5N=',N"@H@("`@("!)9B!N;W0@96YA8FQE9"P@2&]R9&4@=VEL;"!U<V4@
M:71S(&]W;B!02%`@8V]D92!T;R!P97)F;W)M($U)344@;6%G:6,*("`@("`@
M;&]O:W5P<RX@($AO=V5V97(L('1H:7,@;&]O:W5P(&ES('-L;W=E<BP@;&5S
M<R!A8V-U<F%T92P@86YD(&1E=&5C=',*("`@("`@9F5W97(@34E-12!T>7!E
M<R!T:&%N('1H92!014-,(&5X=&5N<VEO;B!W:6QL+@H*("`@("`@5&\@:6YS
M=&%L;"P@96YT97(@=&AE(&9O;&QO=VEN9R!A="!T:&4@8V]M;6%N9"!P<F]M
M<'0Z.@H*("`@("`@("!P96%R(&EN<W1A;&P@9FEL96EN9F\*"B`@(%1H97-E
M(%!%0TP@;6]D=6QE<R!A<F4@*BI214-/34U%3D1%1"HJ('1O(&)E(&EN<W1A
M;&QE9"!I9B!Y;W4@;F5E9`H@("!A9'9A;F-E9"!F=6YC=&EO;F%L:71Y.@H*
M("`@82X@;65M8V%C:&4*"B`@("`@($EF('5S:6YG('1H92!M96UC86-H960@
M4V5S<VEO;DAA;F1L97(L('1H92!M96UC86-H92!014-,(&5X=&5N<VEO;B!M
M=7-T"B`@("`@(&)E(&EN<W1A;&QE9"X*"B`@("`@(%1O(&EN<W1A;&PL(&5N
M=&5R('1H92!F;VQL;W=I;F<@870@=&AE(&-O;6UA;F0@<')O;7!T.CH*"B`@
M("`@("`@<&5A<B!I;G-T86QL(&UE;6-A8VAE"@H@("!&;W(@861D:71I;VYA
M;"!H96QP(&]N('5S:6YG('1H92!P96%R(&-O;6UA;F0M;&EN92!P<F]G<F%M
M('1O(&EN<W1A;&P@4$5#3`H@("!E>'1E;G-I;VYS+"!S964@=&AE(%!%05(@
M:6YS=&%L;&%T:6]N('-E8W1I;VX@86)O=F4N"@H*5&AE(&9O;&QO=VEN9R!N
M;VXM4$A0('!R97)E<75I<VET97,@87)E("HJ4D5#3TU-14Y$140J*BP@;W(@
M87)E("HJ4D5154E2140J*@II9B!Y;W4@=7-E(&$@<W!E8VEF:6,@2&]R9&4@
M87!P;&EC871I;VX@*&%S(&YO=&5D(&EN(%MB<F%C:V5T<UTI.@H*,2X@4V5N
M9&UA:6P@;W(@97%U:79A;&5N="X*"B`@($AO<F1E('5S97,@<V5N9&UA:6PL
M(&]R(&$@<')O9W)A;2!T:&%T(&EM<&QE;65N=',@=&AE(&!@<V5N9&UA:6PH
M."E@8"!!4$D*("`@*&%S(&EN8VQU9&5D('=I=&@@<&]S=&9I>"P@<6UA:6PL
M(&%N9"!E>&EM+"!A;6]N9R!O=&AE<G,I+B!)9B!Y;W5R('-Y<W1E;0H@("!D
M;V5S(&YO="!A;')E861Y(&AA=F4@82!F=6QL(&UA:6P@=')A;G-P;W)T('=I
M=&@@82!S96YD;6%I;"!I;G1E<F9A8V4L('EO=0H@("!C86X@8V]N9FEG=7)E
M($AO<F1E('1O('-P96%K(&1I<F5C=&QY('=I=&@@82!R96UO=&4@4TU44"!S
M97)V97(L(&)U="!T:&ES"B`@(&UA>2!I;F-U<B!A('!E<F9O<FUA;F-E('!E
M;F%L='DN"@H*26YS=&%L;&EN9R!(;W)D90H]/3T]/3T]/3T]/3T]/3T]"@I(
M;W)D92!I<R!W<FET=&5N(&EN(%!(4"P@86YD(&UU<W0@8F4@:6YS=&%L;&5D
M(&EN(&$@=V5B+6%C8V5S<VEB;&4@9&ER96-T;W)Y+@I4:&4@<')E8VES92!L
M;V-A=&EO;B!O9B!T:&ES(&1I<F5C=&]R>2!W:6QL(&1I9F9E<B!F<F]M('-Y
M<W1E;2!T;R!S>7-T96TN($EF"GEO=2!H879E(&YO(&ED96$@=VAE<F4@>6]U
M('-H;W5L9"!B92!I;G-T86QL:6YG($AO<F1E+"!I;G-T86QL(&ET(&1I<F5C
M=&QY"G5N9&5R('1H92!R;V]T(&]F('EO=7(@=V5B<V5R=F5R)W,@9&]C=6UE
M;G0@=')E92X*"@I);G-T86QL:6YG(&9R;VT@4F5L96%S92!487)B86QL<PI^
M?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?@H*4VEN8V4@2&]R9&4@
M:7,@=W)I='1E;B!I;B!02%`L('1H97)E(&ES(&YO(&-O;7!I;&%T:6]N(&YE
M8V5S<V%R>3L@<VEM<&QY"F5X<&%N9"!T:&4@9&ES=')I8G5T:6]N('=H97)E
M('EO=2!W86YT(&ET('1O(')E<VED92!A;F0@<F5N86UE('1H92!R;V]T"F1I
M<F5C=&]R>2!O9B!T:&4@9&ES=')I8G5T:6]N('1O('=H871E=F5R('EO=2!W
M:7-H('1O(&%P<&5A<B!I;B!T:&4*55),+B!0;&5A<V4@;F]T92!T:&%T('1H
M92!D969A=6QT(&-O;F9I9W5R871I;VX@97AP96-T<R!(;W)D92!T;R!B92!I
M;G-T86QL960*:6X@=&AE(&1I<F5C=&]R>2!@8"]H;W)D96!@('1H;W5G:"X@
M1F]R(&5X86UP;&4L('=I=&@@=&AE($%P86-H92!W96)S97)V97(G<PID969A
M=6QT(&1O8W5M96YT(')O;W0@;V8@8&`O=7-R+VQO8V%L+V%P86-H92]H=&1O
M8W-@8"P@>6]U('=O=6QD('1Y<&4Z.@H*("`@8V0@+W5S<B]L;V-A;"]A<&%C
M:&4O:'1D;V-S"B`@('1A<B!Z>'9F("]P871H+W1O+VAO<F1E+7@N>2YZ+G1A
M<BYG>@H@("!M=B!H;W)D92UX+GDN>B!H;W)D90H*66]U('=O=6QD('1H96X@
M9FEN9"!(;W)D92!A="!T:&4@55),.CH*"B`@(&AT='`Z+R]Y;W5R+7-E<G9E
M<B]H;W)D92\*"E-K:7`@=&AE(&YE>'0@<&%R86=R87!H(&EF('EO=2!I;G-T
M86QL960@2&]R9&4@9G)O;2!A(')E;&5A<V4@=&%R8F%L;"X*"@I);G-T86QL
M:6YG(&9R;VT@0U93(&]R(%-N87!H;W1S"GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^?GX*"D%T('1H:7,@<&]I;G0L('1H92!(;W)D92!F<F%M97=O
M<FL@;6]D=6QE<R!N965D('1O(&)E(&-H96-K960@;W5T(&9R;VT@0U93(&%N
M9`II;G-T86QL960N(%1H:7,@;75S="!B92!D;VYE(&%S(')O;W0@*&]R(&%N
M;W1H97(@=7-E<B!W:71H('-U9F9I8VEE;G0*861M:6YI<W1R871O<B!P<FEV
M:6QE9&=E<RDZ.@H*("`@8V0@:&]R9&4*("`@8W9S(&-O(&9R86UE=V]R:PH@
M("!C9"!F<F%M97=O<FL*("`@<&AP("UQ(&EN<W1A;&PM<&%C:V%G97,N<&AP
M"@I&;W(@5VEN9&]W<R!S>7-T96US("T@=7-E('1H92!@8&EN<W1A;&PM<&%C
M:V%G97,N8F%T8&`@9FEL92!I;G-T96%D+@I&;W(@1&5B:6%N('-Y<W1E;7,@
M+2!T:&4@8V]M;6%N9"UL:6YE(%!(4"!I;G1E<G!R971E<B!M:6=H="!B92!C
M86QL960@8&!P:'`T8&`*:6YS=&5A9"!O9B!@8'!H<&!@+@H*"D-O;F9I9W5R
M:6YG($AO<F1E"CT]/3T]/3T]/3T]/3T]/3T]"@HQ+B!#;VYF:6=U<FEN9R!T
M:&4@=V5B('-E<G9E<@H*("`@2&]R9&4@<F5Q=6ER97,@=&AE(&9O;&QO=VEN
M9R!W96)S97)V97(@<V5T=&EN9W,N($5X86UP;&5S('-H;W=N(&%R92!F;W(*
M("`@07!A8VAE.R!O=&AE<B!W96)S97)V97)S)R!C;VYF:6=U<F%T:6]N<R!W
M:6QL(&1I9F9E<BX*"B`@(&$N(%!(4"!I;G1E<G!R971A=&EO;B!F;W(@9FEL
M97,@;6%T8VAI;F<@8&`J+G!H<&!@.CH*"B`@("`@("`@($%D9%1Y<&4@87!P
M;&EC871I;VXO>"UH='1P9"UP:'`@+G!H<`H*("`@("`@+BX@3F]T93HZ(%1H
M92!A8F]V92!I;G-T<G5C=&EO;G,@;6%Y(&YO="!W;W)K(&EF('EO=2!H879E
M('-P96-I9FEE9"!02%`*("`@("`@("`@("`@("`@(&%S(&%N(&]U='!U="!F
M:6QT97(@=VET:"!@8%-E=$]U='!U=$9I;'1E<F!@(&1I<F5C=&EV92!I;@H@
M("`@("`@("`@("`@("`@07!A8VAE(#(N>"!V97)S:6]N<RX@($EN('!A<G1I
M8W5L87(L(%)E9"!(870@."XP(&%N9"!A8F]V90H@("`@("`@("`@("`@("`@
M07!A8VAE(#(N>"!24$U3(&AA=F4@=&AE(&]U='!U="!F:6QT97(@<V5T+"!A
M;F0@*BI-55-4($Y/5"HJ"B`@("`@("`@("`@("`@("!H879E('1H92!A8F]V
M92!@8$%D9%1Y<&5@8"!D:7)E8W1I=F4@861D960N"@H@("!B+B!@8&EN9&5X
M+G!H<&!@(&%S(&%N(&EN9&5X(&9I;&4@*&)R;W5G:'0@=7`@=VAE;B!A('5S
M97(@<F5Q=65S=',@82!54DP@9F]R"B`@("`@(&$@9&ER96-T;W)Y*3HZ"@H@
M("`@("`@("!$:7)E8W1O<GE);F1E>"!I;F1E>"YP:'`*"C(N($-R96%T:6YG
M(&1A=&%B87-E<PH*("`@5&AE('-P96-I9FEC('-T97!S('1O(&-R96%T92!A
M('!R969E<F5N8V5S('-T;W)A9V4@8V]N=&%I;F5R(&1E<&5N9"!O;@H@("!W
M:&EC:"!D871A8F%S92!Y;W4G=F4@8VAO<V5N('1O('5S92X*"B`@($9I<G-T
M+"!L;V]K(&EN(&!@<V-R:7!T<R]S<6PO8&`@=&\@<V5E(&EF(&$@8&!C<F5A
M=&4N8&`@<V-R:7!T(&%L<F5A9'D*("`@97AI<W1S(&9O<B!Y;W5R(&1A=&%B
M87-E+B`@268@<V\L('EO=2!S:&]U;&0@8F4@86)L92!T;R!S:6UP;'D@97AE
M8W5T92!T:&%T"B`@('-C<FEP="!A<R!S=7!E<G5S97(@:6X@>6]U<B!D871A
M8F%S92X@($-O;G-U;'0@=&AE(&!@<V-R:7!T<R]S<6PO4D5!1$U%8&`*("`@
M9FEL92!F;W(@;6]R92!I;F9O<FUA=&EO;BX*"B`@($)E('-U<F4@=&\@8VAA
M;F=E('1H92!D969A=6QT('!A<W-W;W)D+"!@8&AO<F1E8&`L('1O('-O;65T
M:&EN9R!E;'-E(&)E9F]R90H@("!C<F5A=&EN9R!T:&4@=&%B;&5S(2`H4F5M
M96UB97(@=&\@=7-E('1H:7,@<&%S<W=O<F0@=VAE;B!Y;W4@8V]N9FEG=7)E
M"B`@($AO<F1E(&EN('1H92!N97AT('-T97`N*0H*("`@268@<W5C:"!A('-C
M<FEP="!D;V5S(&YO="!E>&ES="P@>6]U)VQL(&YE960@=&\@8G5I;&0@>6]U
M<B!O=VXL('5S:6YG('1H90H@("!F:6QE<R!@8&AO<F1E7W5S97)S+G-Q;&!@
M+"!@8&AO<F1E7W!R969S+G-Q;&!@+"!A;F0@8&!H;W)D95]D871A=')E92YS
M<6Q@8`H@("!A<R!A('-T87)T:6YG('!O:6YT+B`@268@>6]U(&YE960@87-S
M:7-T86YC92!I;B!C<F5A=&EN9R!D871A8F%S97,@9F]R(&$*("`@9&%T86)A
M<V4@9F]R('=H:6-H(&YO(&!@8W)E871E+F!@('-C<FEP="!E>&ES=',L('EO
M=2!M87D@=VES:"!T;R!L970@=7,*("`@:VYO=R!O;B!T:&4@8$AO<F1E(&UA
M:6QI;F<@;&ES=&!?+@H*("`@268@>6]U(&%R92!G;VEN9R!T;R!U<V4@9&%T
M86)A<V4@8F%S960@<V5S<VEO;G,L(&-R96%T92!A('1A8FQE('5S:6YG('1H
M90H@("!F:6QE<R!@8'-C<FEP=',O<W%L+VAO<F1E7W-E<W-I;VYH86YD;&5R
M*BYS<6Q@8"!A<R!A('-T87)T:6YG('!O:6YT+@H*("`@+BX@7V!(;W)D92!M
M86EL:6YG(&QI<W1@.B!H;W)D94!L:7-T<RYH;W)D92YO<F<*"C,N($-O;F9I
M9W5R:6YG($AO<F1E"@H@("!4;R!C;VYF:6=U<F4@2&]R9&4L(&-H86YG92!T
M;R!T:&4@8&!C;VYF:6<O8&`@9&ER96-T;W)Y(&]F('1H92!I;G-T86QL960*
M("`@9&ES=')I8G5T:6]N+"!A;F0@;6%K92!C;W!I97,@;V8@86QL(&]F('1H
M92!C;VYF:6=U<F%T:6]N(&!@+F1I<W1@8"!F:6QE<PH@("!W:71H;W5T('1H
M92!@8"YD:7-T8&`@<W5F9FEX.CH*"B`@("`@(&-D(&-O;F9I9R\*("`@("`@
M9F]R(&8@:6X@*BYD:7-T.R!D;R!C<"`D9B!@8F%S96YA;64@)&8@+F1I<W1@
M.R!D;VYE"@H@("!/<B!I9B!Y;W4@87)E(&EN<W1A;&QI;F<@2&]R9&4@86X@
M82!7:6YD;W=S('-Y<W1E;3HZ"@H@("`@("!C9"!C;VYF:6<*("`@("`@8V]P
M>2`J+F1I<W0@*BX*"B`@("XN($YO=&4Z.B!9;W4@;VYL>2!N965D('1H92!@
M8&AO;VMS+G!H<&!@(&9I;&4@:68@>6]U('=A;G0@=&\@8W)E871E(&-U<W1O
M;0H@("`@("`@("`@("`@:&]O:W,@9F]R('-O;64@;V8@2&]R9&4G<R!F96%T
M=7)E<R!A;F0@9&5F875L="!V86QU97,N($)E<VED90H@("`@("`@("`@("`@
M=&AA="P@=&AI<R!F:6QE(&]N;'D@8V]N=&%I;G,@97AA;7!L97,@=&AA="!Y
M;W4@<VAO=6QD(&YO="!U<V4@87,*("`@("`@("`@("`@('1H97D@87)E+B!)
M9B!Y;W4@9&]N)W0@;F5E9"!H;V]K<R!I="=S(&$@9V]O9"!I9&5A('1O(')E
M;6]V92!T:&ES"B`@("`@("`@("`@("!F:6QE(&YO=SHZ"@H@("`@("`@("`@
M("`@("`@("`@<FT@:&]O:W,N<&AP"@H@("!$;V-U;65N=&%T:6]N(&]N('1H
M92!F;W)M870@;V8@=&AO<V4@9FEL97,@8V%N(&)E(&9O=6YD(&EN(&5A8V@@
M9FEL92X*"B`@("XN(%=A<FYI;F<Z.B!!;&P@8V]N9FEG=7)A=&EO;B!F:6QE
M<R!I;B!(;W)D92!A<F4@4$A0('-C<FEP=',@=&AA="!A<F4*("`@("`@("`@
M("`@("`@(&5X96-U=&5D(&)Y('1H92!W96(@<V5R=F5R+B!)9B!Y;W4@;6%K
M92!A;B!E<G)O<B!I;B!O;F4@;V8*("`@("`@("`@("`@("`@('1H97-E(&9I
M;&5S+"!(;W)D92!M:6=H="!S=&]P('=O<FMI;F<N(%1H=7,@:70@:7,@86QW
M87ES(&$*("`@("`@("`@("`@("`@(&=O;V0@:61E82!T;R!T97-T('1H92!C
M;VYF:6=U<F%T:6]N(&9I;&5S(&%F=&5R('EO=2!E9&ET960*("`@("`@("`@
M("`@("`@('1H96TN($EF('EO=2!W86YT('1O('1E<W0@;6EM95]D<FEV97)S
M+G!H<"!F;W(@97AA;7!L92!R=6XZ.@H*("`@("`@("`@("`@("`@("`@('!H
M<"`M;"!M:6UE7V1R:79E<G,N<&AP"@HT+B!497-T:6YG($AO<F1E"@H@("!/
M;F-E('EO=2!H879E(&-O;F9I9W5R960@>6]U<B!W96)S97)V97(L(%!(4"P@
M86YD($AO<F1E+"!B<FEN9R!U<"!T:&4*("`@:6YC;'5D960@=&5S="!P86=E
M(&EN('EO=7(@5V5B(&)R;W=S97(@=&\@96YS=7)E('1H870@86QL(&YE8V5S
M<V%R>0H@("!P<F5R97%U:7-I=&5S(&AA=F4@8F5E;B!M970N($EF('EO=2!I
M;G-T86QL960@2&]R9&4@87,@9&5S8W)I8F5D(&%B;W9E+"!T:&4*("`@55),
M('1O('1H92!T97-T('!A9V4@=V]U;&0@8F4Z.@H*("`@("`@:'1T<#HO+WEO
M=7(M<V5R=F5R+VAO<F1E+W1E<W0N<&AP"@H@("!#:&5C:R!T:&%T('EO=7(@
M4$A0(&%N9"!014%2('9E<G-I;VYS(&%R92!A8V-E<'1A8FQY(')E8V5N="P@
M=&AA="!A;&P*("`@<F5Q=6ER960@;6]D=6QE(&-A<&%B:6QI=&EE<R!A<F4@
M<')E<V5N="P@86YD('1H870@8&!M86=I8U]Q=6]T97-?<G5N=&EM96!@"B`@
M(&ES('-E="!T;R!@8$]F9F!@+B!4:&5N(&YO=&4@=&AE(&!@4V5S<VEO;B!C
M;W5N=&5R.B`Q8&`@;&EN92!U;F1E<B!@8%!(4`H@("!397-S:6]N<V!@+"!A
M;F0@<F5L;V%D('1H92!P86=E+B!4:&4@<V5S<VEO;B!C;W5N=&5R('-H;W5L
M9"!I;F-R96UE;G0N"@H@("!)9B!Y;W4@9V5T(&$@=V%R;FEN9R!L:6ME(&!@
M1F%I;&5D(&]P96YI;F<@)R]P871H+W1O+W1E<W0N<&AP)R!F;W(*("`@:6YC
M;'5S:6]N8&`L(&UA:V4@<W5R92!T:&%T('1H92!W96(@<V5R=F5R(&AA<R!T
M:&4@<&5R;6ES<VEO;B!T;R!R96%D('1H90H@("!@8'1E<W0N<&AP8&`@9FEL
M92X*"C4N($-O;7!L971I;F<@0V]N9FEG=7)A=&EO;@H*("`@66]U(&-A;B!N
M;W<@86-C97-S($AO<F1E('=I=&AO=70@82!P87-S=V]R9"P@86YD('EO=2!W
M:6QL(&)E(&QO9V=E9"!I;B!A<PH@("!A;B!A9&UI;FES=')A=&]R+B!9;W4@
M<VAO=6QD(&9I<G-T(&-O;F9I9W5R92!A(')E86P@875T:&5N=&EC871I;VX@
M8F%C:V5N9"X*("`@0VQI8VL@;VX@8&!3971U<&!@(&EN('1H92!@8$%D;6EN
M:7-T<F%T:6]N8&`@;65N=2!A;F0@8V]N9FEG=7)E"B`@($AO<F1E+B`@4W1A
M<G0@:6X@=&AE(&!@075T:&5N=&EC871I;VY@8"!T86(N"@H@("!(97)E(&ES
M(&%N(&5X86UP;&4@9F]R(&-O;F9I9W5R:6YG(&%U=&AE;G1I8V%T:6]N(&%G
M86EN<W0@82!R96UO=&4@24U!4`H@("!S97)V97(N("!3:6UI;&%R('-T97!S
M(&%P<&QY(&9O<B!A=71H96YT:6-A=&EN9R!A9V%I;G-T(&$@9&%T86)A<V4L
M(&%N($Q$05`*("`@<V5R=F5R+"!E=&,N"@H@("!A+B!);B!T:&4@8&!7:&EC
M:"!U<V5R<R!S:&]U;&0@8F4@=')E871E9"!A<R!A9&UI;FES=')A=&]R<V!@
M(&9I96QD(&5N=&5R(&$*("`@("`@8V]M;6$@<V5P87)A=&5D(&QI<W0@;V8@
M=7-E<B!N86UE<R!O9B!Y;W5R(&-H;V]S:6YG+B!4:&ES('=I;&P@8V]N=')O
M;`H@("`@("!W:&\@:7,@86QL;W=E9"!T;R!M86ME(&-O;F9I9W5R871I;VX@
M8VAA;F=E<RP@<V5E('!A<W-W;W)D<RP@<&]T96YT:6%L;'D*("`@("`@861D
M('5S97)S+"!E=&,N"@H@("!B+B!);B!T:&4@8&!7:&%T(&)A8VME;F0@<VAO
M=6QD('=E('5S92!F;W(@875T:&5N=&EC871I;F<@=7-E<G,@=&\@2&]R9&5@
M8`H@("`@("!P=6QL9&]W;B!M96YU('-E;&5C="!@8$E-05`@875T:&5N=&EC
M871I;VY@8"X@5&AE('!A9V4@=VEL;"!R96QO860@86YD"B`@("`@('EO=2!W
M:6QL(&AA=F4@<W!E8VEF:6,@;W!T:6]N<R!F;W(@24U!4"!A=71H96YT:6-A
M=&EO;BX*"B`@(&,N($EN('1H92!@8$-O;F9I9W5R871I;VX@='EP96!@('!U
M;&QD;W=N(&UE;G4@<V5L96-T(&!@4V5P87)A=&4@=F%L=65S8&`N"B`@("`@
M(%1H92!P86=E('=I;&P@<F5L;V%D('=I=&@@861D:71I;VYA;"!O<'1I;VYS
M+B!&:6QL(&EN('1H92!R96UA:6YI;F<*("`@("`@=&AR964@9FEE;&1S(&%P
M<')O<')I871E;'DZ"@H@("`@("`M($E0(&YA;64O;G5M8F5R(&]F('1H92!)
M34%0('-E<G9E<@H@("`@("`M($9O<B!A('-E8W5R92!C;VYN96-T:6]N+"!S
M96QE8W0@<&]R="`Y.3,N"B`@("`@("T@4V5L96-T('1H92!P<F]T;V-O;#L@
M9F]R(&$@<V5C=7)E(&-O;FYE8W1I;VX@96ET:&5R(&!@:6UA<"]S<VQ@8"!O
M<@H@("`@("`@(&!@:6UA<"]S<VPO;F]V86QI9&%T92UC97)T8&`@*&9O<B!S
M96QF+7-I9VYE9"!C97)T:69I8V%T97,I+@H*("`@0V]N=&EN=64@=&\@8V]N
M9FEG=7)E($AO<F1E('1H<F]U9V@@86QL('1H92!T86)S(&]F('1H92!S971U
M<"!I;G1E<F9A8V4@86YD"B`@(&-L:6-K(&]N(&!@1V5N97)A=&4@2&]R9&4@
M0V]N9FEG=7)A=&EO;F!@+B!);7!O<G1A;G0@:71E;7,@=&AA="!Y;W4*("`@
M<')O8F%B;'D@=V%N="!T;R!C;VYF:6=U<F4@87)E('1H92!@8%!R969E<F5N
M8V4@4WES=&5M8&`@=&AA="!L971S('5S97)S"B`@('-A=F4@=&AE:7(@<&5R
M<V]N86P@;W!T:6]N<RP@86YD('1H92!@8$1A=&%4<F5E(%-Y<W1E;6!@('1H
M870@:7,@<F5Q=6ER960*("`@9F]R('-O;64@87!P;&EC871I;VYS('1O('=O
M<FL@870@86QL+@H*("`@0V]N9FEG=7)A=&EO;B!O9B!A<'!L:6-A=&EO;G,@
M:6X@8&!R96=I<W1R>2YP:'!@8"!I<R!D;V-U;65N=&5D(&EN('1H90H@("!@
M8$E.4U1!3$Q@8"!F:6QE(&]F(&5A8V@@87!P;&EC871I;VXN("!-;W-T(&%P
M<&QI8V%T:6]N<R!R97%U:7)E('EO=2!T;PH@("!C;VYF:6=U<F4@=&AE;2!W
M:71H(&$@(DAO<F1E(&%D;6EN:7-T<F%T;W(B(&%C8V]U;G0N("!!($AO<F1E
M(&%D;6EN:7-T<F%T;W(*("`@86-C;W5N="!I<R!A;GD@;F]R;6%L($AO<F1E
M(&%C8V]U;G0@=&AA="!H87,@8F5E;B!A9&1E9"!T;R!T:&4*("`@861M:6YI
M<W1R871O<B!L:7-T(&EN('1H92!@8$%U=&AE;G1I8V%T:6]N8&`@=&%B(&]F
M('1H92!(;W)D92!S971U<"X*"B`@(%1H92!O=&AE<B!F:6QE<R!I;B!T:&%T
M(&1I<F5C=&]R>2!N965D(&]N;'D@8F4@;6]D:69I960@:68@>6]U('=I<V@@
M=&\*("`@8W5S=&]M:7IE($AO<F1E)W,@87!P96%R86YC92!O<B!B96AA=FEO
M=7(@+2T@=&AE(&1E9F%U;'1S('=I;&P@=V]R:R!A="!M;W-T"B`@('-I=&5S
M+@H*-BX@4V5C=7)I;F<@2&]R9&4*"B`@(&$N(%!A<W-W;W)D<PH*("`@("`@
M4V]M92!O9B!(;W)D92=S(&-O;F9I9W5R871I;VX@9FEL97,@8V]N=&%I;B!P
M87-S=V]R9',@=VAI8V@@;&]C86P@=7-E<G,*("`@("`@8V]U;&0@=7-E('1O
M(&%C8V5S<R!Y;W5R(&1A=&%B87-E+B`@270@:7,@<F5C;VUM96YD960@=&\@
M96YS=7)E('1H870@870*("`@("`@;&5A<W0@=&AE($AO<F1E(&-O;F9I9W5R
M871I;VX@9FEL97,@*&EN(&!@8V]N9FEG+V!@*2!A<F4@;F]T(')E861A8FQE
M('1O"B`@("`@('-Y<W1E;2!U<V5R<RX@(%1H97)E(&%R92!@8"YH=&%C8V5S
M<V!@(&9I;&5S(')E<W1R:6-T:6YG(&%C8V5S<R!T;PH@("`@("!D:7)E8W1O
M<FEE<R!T:&%T(&1O(&YO="!N965D('1O(&)E(&%C8V5S<V5D(&1I<F5C=&QY
M.R!B969O<F4@<F5L>6EN9R!O;@H@("`@("!T:&]S92P@96YS=7)E('1H870@
M>6]U<B!W96)S97)V97(@<W5P<&]R=',@8&`N:'1A8V-E<W-@8"!A;F0@:7,*
M("`@("`@8V]N9FEG=7)E9"!T;R!U<V4@=&AE;2P@86YD('1H870@=&AE(&9I
M;&5S(&EN('1H;W-E(&1I<F5C=&]R:65S(&%R92!I;@H@("`@("!F86-T(&EN
M86-C97-S:6)L92!V:6$@=&AE(&)R;W=S97(N"@H@("`@("!!;B!A9&1I=&EO
M;F%L(&%P<')O86-H(&ES('1O(&UA:V4@2&]R9&4G<R!C;VYF:6=U<F%T:6]N
M(&9I;&5S(&]W;F5D(&)Y"B`@("`@('1H92!U<V5R(&!@<F]O=&!@(&%N9"!B
M>2!A(&=R;W5P('=H:6-H(&]N;'D@=&AE('=E8G-E<G9E<B!U<V5R(&)E;&]N
M9W,*("`@("`@=&\L(&%N9"!T:&5N(&UA:VEN9R!T:&5M(')E861A8FQE(&]N
M;'D@=&\@;W=N97(@86YD(&=R;W5P+B`@1F]R(&5X86UP;&4L"B`@("`@(&EF
M('EO=7(@=V5B<V5R=F5R(')U;G,@87,@8&!W=W<N=W=W8&`L(&1O(&%S(&9O
M;&QO=W,Z.@H*("`@("`@("`@8VAO=VX@<F]O="YW=W<@8V]N9FEG+RH*("`@
M("`@("`@8VAM;V0@,#0T,"!C;VYF:6<O*@H*("`@8BX@4V5S<VEO;G,*"B`@
M("`@(%-E<W-I;VX@9&%T82`M+2!I;F-L=61I;F<@:&%S:&5D('9E<G-I;VYS
M(&]F('EO=7(@=7-E<G,G('!A<W-W;W)D<RP@:6X*("`@("`@<V]M92!A<'!L
M:6-A=&EO;G,@+2T@;6%Y(&YO="!B92!S=&]R960@87,@<V5C=7)E;'D@87,@
M;F5C97-S87)Y+@H*("`@("`@268@>6]U(&%R92!U<VEN9R!F:6QE+6)A<V5D
M(%!(4"!S97-S:6]N<R`H=VAI8V@@87)E('1H92!D969A=6QT*2P@8F4*("`@
M("`@<W5R92!T:&%T('-E<W-I;VX@9FEL97,@87)E(&YO="!B96EN9R!W<FET
M=&5N(&EN=&\@8&`O=&UP8&`@=VET:`H@("`@("!P97)M:7-S:6]N<R!T:&%T
M(&%L;&]W(&]T:&5R('5S97)S('1O(')E860@=&AE;2X@261E86QL>2P@8VAA
M;F=E('1H90H@("`@("!@8'-E<W-I;VXN<V%V95]P871H8&`@<V5T=&EN9R!I
M;B!@8'!H<"YI;FE@8"!T;R!A(&1I<F5C=&]R>2!O;FQY"B`@("`@(')E861A
M8FQE(&%N9"!W<FET96%B;&4@8GD@>6]U<B!W96)S97)V97(N"@H@("`@("!!
M9&1I=&EO;F%L;'DL('EO=2!C86X@8VAA;F=E('1H92!S97-S:6]N(&AA;F1L
M97(@;V8@4$A0('1O('5S92!A;GD*("`@("`@<W1O<F%G92!B86-K96YD(')E
M<75E<W1E9"`H92YG+B!344P@9&%T86)A<V4I('9I82!T:&4@8&!#=7-T;VT@
M4V5S<VEO;@H@("`@("!(86YD;&5R8&`@=&%B(&EN('1H92!(;W)D92!S971U
M<"X*"B`@($9O<B!M;W)E(&EN9F]R;6%T:6]N(&%B;W5T('-E8W5R:6YG('EO
M=7(@=V5B<V5R=F5R+"!02%`@86YD($AO<F1E+"!S964@=&AE"B`@(&!D;V-S
M+U-%0U5225198%\@9FEL92X*"C<N($5N=&5R:6YG('1H92!S=7)V97D*"B`@
M($EF('EO=2!L:6ME+"!G;R!T;R!H='1P.B\O=W=W+FAO<F1E+F]R9R]S=7)V
M97DO(&%N9"!E;G1E<B!T:&4@9&5T86EL<R!O9@H@("!Y;W5R('-Y<W1E;2X*
M"@I#;VYF:6=U<FEN9R!!<'!L:6-A=&EO;G,*/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]"@I!(&QI<W0@;V8@879A:6QA8FQE($AO<F1E(&%P<&QI8V%T:6]N
M<R!C86X@8F4@9F]U;F0@870*"B`@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+W!R
M;VIE8W1S+G!H<`H*26YS=')U8W1I;VYS(&]N(&-O;F9I9W5R:6YG($AO<F1E
M(&%P<&QI8V%T:6]N<R!C86X@8F4@9F]U;F0@:6X@=&AE(&!@24Y35$%,3&!@
M"F9I;&4@:6X@=&AE(&%P<&QI8V%T:6]N)W,@8&!D;V-S+V!@(&1I<F5C=&]R
M>2X*"@I496UP;W)A<GD@1FEL97,*/3T]/3T]/3T]/3T]/3T]"@I687)I;W5S
M($AO<F1E(&%P<&QI8V%T:6]N<R!W:6QL(&=E;F5R871E('1E;7!O<F%R>2!F
M:6QE<R!I;B!02%`G<R!T96UP;W)A<GD*9&ER96-T;W)Y("AS964@=&AE(&!@
M1V5N97)A;&!@('1A8B!I;B!T:&4@2&]R9&4@<V5T=7`I+B`@1F]R('9A<FEO
M=7,@<F5A<V]N<RP*<V]M92!O9B!T:&5S92!F:6QE<R!M87D@;F]T(&)E(')E
M;6]V960@=VAE;B!T:&4@=7-E<B=S('-E<W-I;VX@96YD<RX@5&\*<F5C;&%I
M;2!T:&ES(&1I<VL@<W!A8V4L(&ET(&UA>2!B92!N96-E<W-A<GD@=&\@<&5R
M:6]D:6-A;&QY(&1E;&5T92!T:&5S92!O;&0*=&5M<&]R87)Y(&9I;&5S+@H*
M06X@97AA;7!L92!C<F]N+6)A<V5D('-O;'5T:6]N(&-A;B!B92!F;W5N9"!A
M="!@8'-C<FEP=',O=&5M<"UC;&5A;G5P+F-R;VY@8"X*06YO=&AE<B!P;W-S
M:6)L92!S;VQU=&EO;B!I<R!T;R!U<V4@4F5D($AA="=S(&!@=&UP=V%T8VA@
M8"!U=&EL:71Y(&]R(&%N>71H:6YG"G-I;6EL87(@=&\@<F5M;W9E(&]L9"!F
M:6QE<R`H<V5E(&AT='`Z+R]W=W<N<F5D:&%T+F-O;2\I+@H*"E1R86YS;&%T
M:6]N<PH]/3T]/3T]/3T]/3T*"DYO=&4@9F]R(&EN=&5R;F%T:6]N86P@=7-E
M<G,Z($AO<F1E('5S97,@1TY5(&=E='1E>'0@=&\@<')O=FED92!L;V-A;`IT
M<F%N<VQA=&EO;G,@;V8@=&5X="!D:7-P;&%Y960@8GD@87!P;&EC871I;VYS
M.R!T:&4@=')A;G-L871I;VYS(&%R92!F;W5N9"!I;@IT:&4@<&\O(&1I<F5C
M=&]R>2X@($EF(&$@=')A;G-L871I;VX@:7,@;F]T('EE="!A=F%I;&%B;&4@
M9F]R('EO=7(@;&]C86QE("AA;F0*>6]U('=I<V@@=&\@8W)E871E(&]N92DL
M('-E92!T:&4@8&!H;W)D92]P;R]214%$345@8"!F:6QE+"!O<B!I9B!Y;W4G
M<F4@:&%V:6YG"G1R;W5B;&4@=7-I;F<@82!P<F]V:61E9"!T<F%N<VQA=&EO
M;BP@<&QE87-E('-E92!T:&4*8&AO<F1E+V1O8W,O5%)!3E-,051)3TY38%\@
M9FEL92!F;W(@:6YS=')U8W1I;VYS+@H*"D]B=&%I;FEN9R!3=7!P;W)T"CT]
M/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W4@96YC;W5N=&5R('!R;V)L96US('=I
M=&@@2&]R9&4L(&AE;'`@:7,@879A:6QA8FQE(0H*5&AE($AO<F1E($9R97%U
M96YT;'D@07-K960@475E<W1I;VYS($QI<W0@*$9!42DL(&%V86EL86)L92!O
M;B!T:&4@5V5B(&%T"@H@(&AT='`Z+R]W=W<N:&]R9&4N;W)G+V9A<2\*"E1H
M92!(;W)D92!0<F]J96-T(')U;G,@82!N=6UB97(@;V8@;6%I;&EN9R!L:7-T
M<RP@9F]R(&EN9&EV:61U86P@87!P;&EC871I;VYS"F%N9"!F;W(@:7-S=65S
M(')E;&%T:6YG('1O('1H92!P<F]J96-T(&%S(&$@=VAO;&4N($EN9F]R;6%T
M:6]N+"!A<F-H:79E<RP@86YD"G-U8G-C<FEP=&EO;B!I;F9O<FUA=&EO;B!C
M86X@8F4@9F]U;F0@870*"B`@:'1T<#HO+W=W=RYH;W)D92YO<F<O;6%I;"\*
M"D9I;F%L;'DL($AO<F1E(&1E=F5L;W!E<G,L(&-O;G1R:6)U=&]R<R!A;F0@
M=7-E<G,@86QS;R!M86ME(&]C8V%S:6]N86P*87!P96%R86YC97,@;VX@25)#
M+"!O;B!T:&4@8VAA;FYE;"`C:&]R9&4@;VX@=&AE(&9R965N;V1E($YE='=O
M<FL**&ER8RYF<F5E;F]D92YN970I+@H*4&QE87-E(&ME97`@:6X@;6EN9"!T
M:&%T($AO<F1E(&ES(&9R964@<V]F='=A<F4@=W)I='1E;B!B>2!V;VQU;G1E
M97)S+@I&;W(@:6YF;W)M871I;VX@;VX@<F5A<V]N86)L92!S=7!P;W)T(&5X
M<&5C=&%T:6]N<RP@<&QE87-E(')E860*"B`@:'1T<#HO+W=W=RYH;W)D92YO
M<F<O<W5P<&]R="YP:'`*"E1H86YK<R!F;W(@=7-I;F<@2&]R9&4A"@I4:&4@
M2&]R9&4@5&5A;0H*"BXN(%]214%$344Z(#]F/5)%041-12YH=&UL"BXN(%]D
M;V-S+TA!0TM)3D<Z(#]F/4A!0TM)3D<N:'1M;`HN+B!?9&]C<R]314-54DE4
M63H@/V8]4T5#55))5%DN:'1M;`HN+B!?8&AO<F1E+V1O8W,O5%)!3E-,051)
M3TY38#H@/V8]5%)!3E-,051)3TY3+FAT;6P*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+V1O8W,O4$521D]234%.0T4`````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3$S,B`Q,#4Q-30S-#$S-2`P,C`Q-3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@4&5R9F]R;6%N8V4@1W5I
M9&4*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@
M("1$871E.B`R,#`V+S`U+S,Q(#$Y.C$T.C$T("0*.E)E=FES:6]N.B`@("`@
M("12979I<VEO;CH@,2XY+C$P+C$S("0*.D-O;G1A8W0Z("`@("`@(&AO<F1E
M0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z.B!#;VYT96YT<PH*"E-O
M;64@=&EP<R!O;B!P97)F;W)M86YC92!T=6YI;F<@<WES=&5M<R!F;W(@2&]R
M9&4N("!4:&ES(&1O97,@;F]T(&-O=F5R"FAA<F1W87)E('1U;FEN9R!O<B!E
M=F5N(&QO=R!L979E;"!S>7-T96T@*&YE='=O<FLL(&9I;&5S>7-T96TL(&5T
M8RD@='5N:6YG+@H*1&]N)W0@87!P;'D@=&AE(&9O;&QO=VEN9R!T=6YI;F<@
M:&EN=',@8FQI;F1L>2X@(%1E<W0@>6]U<B!A<'!L:6-A=&EO;G,@8F5F;W)E
M"F%N9"!A9G1E<B!T:&4@8VAA;F=E<R!U;F1E<B!T:&4@8V]N9&ET:6]N<R!T
M:&%T(&%R92!I;7!O<G1A;G0@9F]R('EO=2X@($9O<@IS;VUE('!E;W!L92!I
M="=S(&UO<F4@:6UP;W)T86YT('1O(&UA:V4@=&AE;2!A<R!F87-T(&%S('!O
M<W-I8FQE(&9O<B!A('-M86QL"G5S97(@8F%S92P@;W1H97)S(')E<75I<F4@
M=&AE(&%P<&QI8V%T:6]N<R!T;R!S8V%L92!W96QL('5N9&5R(&$@:&EG:"!L
M;V%D+@I3;VUE(&]F('1H97-E(&AI;G1S(&UI9VAT(&5V96X@;6%K92!T:&4@
M87!P;&EC871I;VYS('-L;W=E<B!U;F1E<B!C97)T86EN"F-O;F1I=&EO;G,@
M;W(@=7-I;F<@82!C97)T86EN(&AA<F1W87)E+@H*"DQI;G5X(%1U;FEN9PH]
M/3T]/3T]/3T]/3T*"BH@4F5C;VUP:6QE(%)035,@9F]R('EO=7(@87)C:&ET
M96-T=7)E("AE+F<N(&DU.#8L(&DV.#8L(&%T:&QO;BP@971C*2X*("!4:&ES
M(&%P<&QI97,@;6]S="!T;R!Y;W5R($%P86-H92P@4$A0+"!)34%0+"!A;F0@
M4$]0,R!P86-K86=E<RX*"@I!<&%C:&4O4$A0('1U;FEN9PH]/3T]/3T]/3T]
M/3T]/3T]/0H**B!#;VYS:61E<B!A(%!(4"!A8V-E;&5R871O<B!P<F]G<F%M
M+B`@4V5E(&9O<B!E>&%M<&QE(&!4:&4@6F5N9"!097)F;W)M86YC90H@(%-U
M:71E8%\L(%1H92!@:6]N0W5B92!02%`@06-C96QE<F%T;W)@7RP@8%1U<F-K
M($U-0V%C:&4@9F]R(%!(4&!?+"!O<@H@(&5!8V-E;&5R871O<E\N("!4:&5S
M92!A8V-E;&5R871O<G,@<W!E960@=7`@86-C97-S(&)Y(&-A8VAI;F<@=&AE
M(&-O;7!I;&5D"B`@4$A0(&-O9&4L(&5L:6UI;F%T:6YG('1H92!N965D('1O
M(')E8V]M<&EL92!T:&4@8V]D92!F;W(@979E<GD@<VEN9VQE('!A9V4*("!L
M;V%D+B`@*BI4:&ES(&ES('!R;V)A8FQY('1H92!E87-I97-T('=A>2!T;R!I
M;7!R;W9E('1H92!P97)F;W)M86YC92!O9@H@($AO<F1E*BHN("!)9B!U<VEN
M9R!4=7)C:R!-34-A8VAE+"`J*E!,14%312HJ(')E860@8%1U<F-K($U-0V%C
M:&4*("!4<F]U8FQE<VAO;W1I;F=@7RX*"BH@0V]M<&EL92!02%`@=VET:"!T
M:&4@8&`M+65N86)L92UI;FQI;F4M;W!T:6UI>F%T:6]N8&`@;W!T:6]N('1O
M(&=E;F5R871E('1H90H@(&9A<W1E<W0@<&]S<VEB;&4@4$A0(&5X96-U=&%B
M;&4N"@HJ(%5S92!O9B!T:&4@;6-R>7!T(%!(4"!E>'1E;G-I;VX@<VAO=6QD
M('-I9VYI9FEC86YT;'D@:6YC<F5A<V4@<&5R9F]R;6%N8V4*("!W:&EL92!A
M;'-O(&EN8W)E87-I;F<@<V5C=7)I='DN"@HJ($5N86)L92!02%`@;W5T<'5T
M(&-O;7!R97-S:6]N("AE:71H97(@:6X@8&!P:'`N:6YI8&`@;W(*("!@8&AO
M<F1E+V-O;F9I9R]C;VYF+G!H<&!@*2X*"BH@1&ES86)L92!T:&4@;65M;W)Y
M(&QI;6ET(&EN(&!@<&AP+FEN:6!@+@H**B!+965P('1H92!I;F-L=61E('!A
M=&@@9&5F:6YE9"!I;B!@8'!H<"YI;FE@8"!A<R!S:&]R="!A<R!P;W-S:6)L
M92P@=VET:"!T:&4*("!M;W-T(&9R97%U96YT;'D@=7-E9"!L:6)R87)Y('!A
M=&AS(&9I<G-T+B`@66]U(&1O;B=T(&YE960@=&\@:6YC;'5D92!T:&4*("!L
M;V-A;"!D:7)E8W1O<GD@8&`N8&`@8F5C875S92!(;W)D92!A;'=A>7,@=7-E
M<R!F=6QL('!A=&AS(&EN<W1E860@;V8*("!R96QA=&EV92!P871H<RX*"BH@
M57-E(&%N(&]P=&EM:7IE9"!@8'!H<"YI;FE@8"P@<W1A<G0@9G)O;2!@8'!H
M<"YI;FDM<F5C;VUM96YD961@8"!O9B!Y;W5R(%!(4`H@(&1S:71R:6)U=&EO
M;BX*"BH@1&]N)W0@<G5N(%!(4"!S97-S:6]N(&=A<F)A9V4@8V]L;&5C=&EO
M;B!T;V\@;V9T96X@:68@=7-I;F<@82!S;&]W('-T;W)A9V4*("!M961I=6T@
M*&QI:V4@4U%,*2X@*%-E92!@8'-E<W-I;VXN9V-?<')O8F%B:6QI='E@8"!I
M;B!@8'!H<"YI;FE@8"D*"BH@268@>6]U(&AA=F4@82!L87)G92!N=6UB97(@
M;V8@<V5S<VEO;G,L(&-O;G-I9&5R('-T;W)I;F<@=&AE;2!I;B!H87-H960*
M("!D:7)E8W1O<GD@;&5V96QS+B`H4V5E(&!@<V5S<VEO;BYS879E7W!A=&A@
M8"!A="!H='1P.B\O=W=W+G!H<"YN970O<V5S<VEO;BD*"BH@0V]N<VED97(@
M=7-I;F<@82!F87-T97(@<W1O<F%G92!M961I=6T@9F]R('-E<W-I;VYS+"!S
M=6-H(&%S(&$@=&UP9G,@;W(*("!O=&AE<B!M96UO<GD@8F%S960@9FEL92!S
M>7-T96TN("!)9B!Y;W4@87)E('-U<F4@>6]U<B!A<&%C:&4@<V5T=7`@:7,@
M<F]C:PH@('-O;&ED(&%N9"!Y;W4@9&]N)W0@<F5S=&%R="!I="!T:&5R92!I
M<R!A(&UM('-E<W-I;VX@9')I=F5R+B`@2&]W979E<BP@8F4*("!A=V%R92!T
M:&%T(&-E<G1A:6X@2&]R9&4@87!P;&EC871I;VYS("AL:6ME($E-4"D@;6%K
M92!H96%V>2!U<V4@;V8@8V%C:&EN9PH@(&1A=&$@:6X@<V5S<VEO;G,@<V\@
M;65M;W)Y(&)A<V5D('-O;'5T:6]N<R!M87D@8F4@97AH875S=&5D('%U:6-K
M;'DL"B`@<&%R=&EC=6QA<FQY(&EF('1H97)E('=I;&P@8F4@;6]R92!T:&%N
M(&$@<VEN9VQE('5S97(N"@HJ($]N;'D@;&]A9"!A<R!M86YY($%P86-H92!A
M;F0@4$A0(&5X=&5N<VEO;G,@87,@;F5E9&5D("AT;R!R961U8V4@;65M;W)Y
M"B`@=7-A9V4I+@H**B!5<V4@<W1A=&EC86QL>2!C;VUP:6QE9"!!<&%C:&4@
M;6]D=6QE<RP@:6YC;'5D:6YG('1H92!02%`@;6]D=6QE+@H**B!5<V4@8V]M
M<&EL97(@;W!T:6UI>F%T:6]N<R`H+2UP<F5F97(M;F]N+7!I8RP@+4\S+"`M
M;6%R8V@@+6UC<'4L("UM<W-E+`H@("UM;6UX+"`M;69P;6%T:#US<V4L(&5T
M8RXI"@HJ($EF('5S:6YG(%-33"!W:71H(&$@;&%R9V4@<VET92P@8V]N<VED
M97(@82!H87)D=V%R92!34TP@86-C96QE<F%T;W(N"@HJ(%5S92!S:&%R960@
M;65M;W)Y(&9O<B!T:&4@07!A8VAE(%-33"!C86-H92!I9B!P;W-S:6)L92X*
M"BH@5&\@:6UP<F]V92!C86-H:6YG(&]F('-T871I8R!C;VYT96YT(&EF(&%C
M8V5S<VEN9R!!<&%C:&4@4U-,('=I=&@@26YT97)N970*("!%>'!L;W)E<BP@
M=')Y('-E='1I;F<@;&]N9V5R(&5X<&ER871I;VX@<&5R:6]D<SHZ"@H@("`@
M17AP:7)E<T%C=&EV92!/;@H@("`@17AP:7)E<T)Y5'EP92!I;6%G92]P;F<@
M(FYO=R!P;'5S(#$@;6]N=&@B"B`@("!%>'!I<F5S0GE4>7!E(&EM86=E+V=I
M9B`B;F]W('!L=7,@,2!M;VYT:"(*("`@($5X<&ER97-">51Y<&4@=&5X="]J
M879A<V-R:7!T(")N;W<@<&QU<R`Q(&UO;G1H(@H@("`@17AP:7)E<T)Y5'EP
M92!A<'!L:6-A=&EO;B]X+6IA=F%S8W)I<'0@(FYO=R!P;'5S(#$@;6]N=&@B
M"B`@("!%>'!I<F5S0GE4>7!E('1E>'0O8W-S(")N;W<@<&QU<R`Q(&UO;G1H
M(@H*("`N+B!.;W1E.CH@66]U(&UU<W0@8V]M<&EL92!T:&4@8&!M;V1?97AP
M:7)E<V!@(&5X=&5N<VEO;B!I;G1O($%P86-H92!I;@H@("`@("`@("`@("!O
M<F1E<B!T;R!U<V4@=&AE<V4@9&ER96-T:79E<RX*"B`@+BX@5V%R;FEN9SHZ
M(%1H:7,@;6EG:'0@8V%U<V4@<')O8FQE;7,@:68@>6]U('5P9W)A9&4@2&]R
M9&4@86YD('1H92!U<V5R<R<*("`@("`@("`@("`@("`@8G)O=W-E<G,@<W1I
M;&P@=7-E('1H92!O;&0@9FEL92!V97)S:6]N<RX*"BH@1&ES86)L92!$3E,@
M;&]O:W5P<R!I;B!Y;W5R($%P86-H92!L;V=G:6YG+"!O<B!U<V4@82!C86-H
M:6YG($1.4R!S97)V97(@;VX*("!T:&4@=V5B('-E<G9E<B!H;W-T+@H**B!%
M;F%B;&4@07!A8VAE(&ME97!A;&EV97,N"@HN+B!?8%1H92!:96YD(%!E<F9O
M<FUA;F-E(%-U:71E8#H@:'1T<#HO+W=W=RYZ96YD+F-O;2]H;W)D92YP:'`*
M+BX@7V!I;VY#=6)E(%!(4"!!8V-E;&5R871O<F`Z(&AT='`Z+R]W=W<N<&AP
M+6%C8V5L97)A=&]R+F-O+G5K"BXN(%]@5'5R8VL@34U#86-H92!F;W(@4$A0
M8#H@:'1T<#HO+W1U<F-K+6UM8V%C:&4N<V]U<F-E9F]R9V4N;F5T"BXN(%]E
M06-C96QE<F%T;W(Z(&AT='`Z+R]E86-C96QE<F%T;W(N;F5T"BXN(%]@5'5R
M8VL@34U#86-H92!4<F]U8FQE<VAO;W1I;F=@.B!H='1P.B\O=VEK:2YH;W)D
M92YO<F<O5'5R8VM-34-A8VAE5')O=6)L97-H;V]T:6YG"@H*4V5N9&EN9R!-
M86EL"CT]/3T]/3T]/3T]/0H**B!'96YE<F%L;'D@=7-I;F<@82!L;V-A;"!S
M96YD;6%I;"!C;VUM86YD('1O('-E;F0@;6%I;"!W:6QL(')E<W5L="!I;B!B
M971T97(*("!P969O<FUA;F-E('1H86X@=7-I;F<@82!33510(&-O;FYE8W1I
M;VXN"@HJ(%-O;64@351!('-E<G9E<G,@;6%Y(&)E(&9A<W1E<B!O<B!M;W)E
M(&5F9FEC:65N="!T:&%N(&]T:&5R<RX@($-O;G-I9&5R"B`@<W=I=&-H:6YG
M('1O(&$@9F%S=&5R(&9O<FUA="!I9B!N965D960N"@H*24U!4"!T=6YI;F<*
M/3T]/3T]/3T]/3T*"BH@0V]N<VED97(@86X@24U!4"!P<F]X>2!F;W(@;6]R
M92!P97)S:7-T96YT(&-O;FYE8W1I;VYS+B`@4V]M92!)34%0('!R;WAI97,*
M("!A<F4@=7`M:6UA<'!R;WAY7R!A;F0@4&5R9&ET:6]N7RX@(%1O(&UA:V4@
M<V5N<V4L('1H92!P<F]X>0H@('-H;W5L9"!B92!I;G-T86QL960@;VX@=&AE
M('-E<G9E<B!R=6YN:6YG($AO<F1E+"!A;F0@=&AI<R!S97)V97(@;F5E9',*
M("!E;F]U9V@@0U!5('!O=V5R('1O(&AA;F1L92!T:&4@861D:71I;VYA;"!L
M;V%D+@H**B!3;VUE($E-05`@<V5R=F5R<R`H;W(@24U!4"!M86EL8F]X('-T
M;W)E(&9O<FUA=',I('!E<F9O<FT@8F5T=&5R('1H86X*("!O=&AE<G,N("!#
M;VYS:61E<B!S=VET8VAI;F<@=&\@82!F87-T97(@9F]R;6%T(&EF(&YE961E
M9"X*"BH@1F]L;&]W('1H92!)34%0('-E<G9E<G,G('!E<F9O<FUA;F-E(&AI
M;G1S.@H*("`M($-Y<G5S.B!H='1P.B\O87-G+G=E8BYC;74N961U+V-Y<G5S
M+V1O=VYL;V%D+VEM87!D+VEN<W1A;&PM<&5R9BYH=&UL"@HN+B!?=7`M:6UA
M<'!R;WAY.B!H='1P.B\O=W=W+FEM87!P<F]X>2YO<F<O"BXN(%]097)D:71I
M;VXZ(&AT='`Z+R]W=W<N=F5R9V5N970N;F5T+VQI;G5X+W!E<F1I=&EO;B\*
M"@I0;W-T9W)E<W%L('1U;FEN9PH]/3T]/3T]/3T]/3T]/3T]/0H**B!$;R!A
M('9A8W5U;2!C;VUM86YD('!E<FEO9&EC86QL>2!T;R!T=6YE('EO=7(@9&%T
M86)A<V4*"BH@26YC<F5A<V4@8&!S:&%R961?8G5F9F5R<V!@(&%N9"!@8'-O
M<G1?;65M8&`@;65M;W)Y('-E='1I;F=S+@H**B!)9B!W96(@<V5R=F5R(&%N
M9"!D871A8F%S92!I<R!O;B!T:&4@<V%M92!U;FEX(&AO<W0L('5S92!U;FEX
M('-O8VME=',*("!I;G-T96%D(&]F(&YE='=O<FL@8V]N;F5C=&EO;G,@9F]R
M(&1A=&%B87-E(&%C8V5S<RX*"@I->5-13"!T=6YI;F<*/3T]/3T]/3T]/3T]
M"@HJ($EF('=E8B!S97)V97(@86YD(&1A=&%B87-E(&ES(&]N('1H92!S86UE
M('5N:7@@:&]S="P@=7-E('5N:7@@<V]C:V5T<PH@(&EN<W1E860@;V8@;F5T
M=V]R:R!C;VYN96-T:6]N<R!F;W(@9&%T86)A<V4@86-C97-S+@H**B!%;F%B
M;&4@;7ES<6P@<75E<GD@8V%C:&4@:68@>6]U(&AA=F4@<W5F9FEC:65N="!2
M04TN("!%9&ET('EO=7(@8&!M>2YC;F9@8`H@(&9I;&4@86YD(&%D9"!T:&4@
M9F]L;&]W:6YG('1O('1H92!@8%MM>7-Q;&1=8&`@<V5C=&EO;B`H8VAA;F=E
M('1H92!M96UO<GD*("!S:7IE('1O(&UE970@>6]U<B!N965D<RDZ.@H*("`@
M('-E="UV87)I86)L92`]('%U97)Y7V-A8VAE7W-I>F4],3(X30H*"DAO<F1E
M('1U;FEN9PH]/3T]/3T]/3T]/3T*"BH@66]U(&-A;B!C;VYF:6=U<F4@2&]R
M9&4@=&\@<V5R=F4@86QL(&EM86=E<R!A;F0@<W1Y;&4@<VAE971S(&9R;VT@
M80H@(&1I9F9E<F5N="!S97)V97(N(%1H:7,@8V]U;&0@8F4@82!V97)Y(&QI
M9VAT=V5I9VAT('-E<G9E<B!W:71H;W5T(&%L;"!T:&4*("!O=F5R:&5A9"!F
M;W(@<')O8V5S<VEN9R!02%`@9FEL97,L(&QI:V4@;&EG:'1T<&0N(%EO=2!N
M965D('1O('-E="!T:&4*("!@8'1H96UE<W5R:6!@('!A<F%M971E<B!I;B!@
M8&-O;F9I9R]R96=I<W1R>2YP:'!@8"!F;W(@86QL(&%P<&QI8V%T:6]N<R!A
M;F0*("!C;W!Y(&%L;"!@8'1H96UE<V!@(&1I<F5C=&]R:65S(&EN('1H92!S
M86UE(&1I<F5C=&]R>2!L87EO=70@=&\@=&AE(&]T:&5R"B`@<V5R=F5R+@H*
M+BX@7VQI9VAT='!D.B!H='1P.B\O=W=W+FQI9VAT='!D+FYE="\*"@I!<'!L
M:6-A=&EO;B!T=6YI;F<*/3T]/3T]/3T]/3T]/3T]/3T]"@HJ(%-O;64@87!P
M;&EC871I;VYS(&-O;G1A:6X@861V86YC960@9F5A='5R97,@=&AA="!M:6=H
M="!H879E(&$@8V5R=&%I;B!I;7!A8W0*("!O;B!T:&4@<&5R9F]R;6%N8V4N
M("!4:&5S92!F96%T=7)E<R!C86X@=7-U86QL>2!B92!T=7)N960@;V9F(&EN
M('1H90H@(&%P<&QI8V%T:6]N)W,@8V]N9FEG=7)A=&EO;B!A;F0@87)E(&5X
M<&QI8VET;'D@9&5S8W)I8F5D(&%S(&)E:6YG(&$*("!P97)F;W)M86YC92!H
M:70@:6X@=&AE(&-O;F9I9W5R871I;VX@=V5B(&9R;VYT96YD+@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O4T5#55))
M5%D`````````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R-#0T-B`Q,#4Q-30S-#$S-2`P,3<V-S``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H@2&]R9&4@4V5C=7)I='D@3F]T97,*/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E.B`R,#`T+S`Y+S(V(#(S.C,S
M.C`W("0*.E)E=FES:6]N.B`@("`@("12979I<VEO;CH@,2XY("0*.D-O;G1A
M8W0Z("`@("`@(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*+BX@8V]N=&5N=',Z
M.B!#;VYT96YT<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@H*5&5M<&]R87)Y
M(&9I;&5S"CT]/3T]/3T]/3T]/3T]/0H*2&]R9&4@87!P;&EC871I;VYS(&UA
M:V4@97AT96YS:79E('5S92!O9B!T96UP;W)A<GD@9FEL97,N("!);B!O<F1E
M<B!T;R!M86ME"G-U<F4@=&AE<V4@9FEL97,@87)E('-E8W5R92P@>6]U('-H
M;W5L9"!M86ME('-U<F4@>6]U<B!I;G-T86QL871I;VX@;65E=',@=&AE"F9O
M;&QO=VEN9R!C<FET97)I82X*"E-I=&5S(&UA>2!G86EN(&EN8W)E87-E9"!S
M96-U<FET>2!B>2!D969I;FEN9R!A('1E;7!O<F%R>2!D:7)E8W1O<GD@:6X@
M=&AE"DAO<F1E(&-O;F9I9W5R871I;VX@=VAI8V@@:7,@=W)I=&%B;&4@8GD@
M=&AE('=E8B!S97)V97(L(&)U="!N;W0@=W)I=&%B;&4@8GD*;W1H97(@=7-E
M<G,N("!3:6YC92!T:&4@=&5M<&]R87)Y(&9I;&5S(&UA>2!C;VYT86EN('-E
M;G-I=&EV92!I;F9O<FUA=&EO;B!I=`II<R!B97-T('1O(&%L<V\@;6%K92!T
M:&5S92!F:6QE('5N<F5A9&%B;&4@8GD@;W1H97(@=7-E<G,N("!4:&%T(&ES
M+"!T:&5Y(&-A;@IB92!M861E(')E861A8FQE(&%N9"!W<FET86)L92!O;FQY
M(&)Y('1H92!W96(@<V5R=F5R('5S97(N"@H*4$A0(%-E<W-I;VYS"CT]/3T]
M/3T]/3T]/0H*1F]R('1H92!M;W-T('-E8W5R:71Y+"!Y;W4@<VAO=6QD(&5N
M86)L92!02%`@<V5S<VEO;B!C;V]K:65S(&)Y(&5N86)L:6YG('1H90IP:'`@
M<V5T=&EN9R!@8'-E<W-I;VXN=7-E7V-O;VMI97-@8"X@(%=H96X@9&]I;F<@
M<V\L(&)E('-U<F4@=&\@<V5T(&%N"F%P<')O<')I871E(&!@<V5S<VEO;BYC
M;V]K:65?<&%T:&!@(&%N9"!@8'-E<W-I;VXN8V]O:VEE7V1O;6%I;F!@(&%L
M<V\@=&\*<V5C=7)E('EO=7(@8V]O:VEE<RX*"DEF(%!(4"!S97-S:6]N<R!A
M<F4@<V5T('1O('5S92!T:&4@8&!F:6QE<V!@('-A=F5?:&%N9&QE<BP@=&AE
M;B!T:&5S92!F:6QE<PIS:&]U;&0@8F4@<V5C=7)E9"!P<F]P97)L>2X@(%-I
M=&5S(&-A;B!I;F-R96%S92!S96-U<FET>2!B>2!S971T:6YG('1H92!P:'`*
M<V5T=&EN9R!@8'-E<W-I;VXN<V%V95]P871H8&`@=&\@82!D:7)E8W1O<GD@
M=&AA="!I<R!O;FQY(')E861A8FQE(&%N9`IW<FET86)L92!B>2!T:&4@=V5B
M('-E<G9E<B!P<F]C97-S+@H*4VET97,@=VET:"!A(&QA<F=E('5S97(@8F%S
M92!S:&]U;&0@8V]N<VED97(@<V5T=&EN9R!T:&4*8&!S97-S:6]N+F5N=')O
M<'E?9FEL96!@(&%N9"!@8'-E<W-I;VXN96YT<F]P>5]L96YG=&A@8"!T;R!A
M<'!R;W!R:6%T92!V86QU97,N"@I(;W)D92!W:6QL(&5N8W)Y<'0@=&AE('5S
M97(@8W)E9&5N=&EA;',@8F5F;W)E('-T;W)I;F<@=&AE;2!I;B!T:&4@<V5S
M<VEO;BX*2&]W979E<BP@=&AI<R!E;F-R>7!T:6]N(&-A;B!B92!I;7!R;W9E
M9"!I9B!Y;W4@:&%V92!A;F0@96YA8FQE('1H92!P:'`*97AT96YS:6]N(")M
M8W)Y<'0B('=H:6-H(&%L;&]W<R!F;W(@<W1R;VYG97(@96YC<GEP=&EO;B!T
M:&%N(&ES(&]T:&5R=VES90IP<F]V:61E9"!B>2!(;W)D92X*"@I$969A=6QT
M(&1A=&%B87-E('!A<W-W;W)D<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/0H*5&AE($AO<F1E(&1O8W5M96YT871I;VX@86YD('-A;7!L92!D871A8F%S
M92!C<F5A=&EO;B!S8W)I<'1S(&-R96%T92!A(&1E9F%U;'0*=7-E<B!A;F0@
M<&%S<W=O<F0@9F]R(&%C8V5S<VEN9R!T:&4@:&]R9&4@9&%T86)A<V4N("!5
M<VEN9R!T:&ES('!A<W-W;W)D(&EN(&$*<')O9'5C=&EO;B!E;G9I<F]N;65N
M="!I<R!A('-E8W5R:71Y(&AO;&4L('-I;F-E(&%N(&%T=&%C:V5R('=I;&P@
M96%S:6QY(&=U97-S"FET+@H*270@:7,@=F5R>2!I;7!O<G1A;G0@=&AA="!S
M:71E<R!C:&%N9V4@870@;&5A<W0@=&AE('!A<W-W;W)D('1O('-O;65T:&EN
M9PIS96-U<F4N"@H*4')E=F5N="!C;VYF:6=U<F%T:6]N(&9I;&4@<F5A9&EN
M9R!A;F0@=W)I=&EN9R`*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H*5&AE(&-O;F9I9W5R871I;VX@9FEL97,@;6%Y
M(&-O;G1A:6X@<V5N<VET:79E(&1A=&$@*'-U8V@@87,@9&%T86)A<V4*<&%S
M<W=O<F1S*2!T:&%T('-H;W5L9"!N;W0@8F4@<F5A9"!O<B!W<FET=&5N(&)Y
M(&QO8V%L('-Y<W1E;2!U<V5R<R!O<B!R96UO=&4*=V5B('5S97)S+@H*268@
M>6]U('5S92!A(%5N:7@@<WES=&5M+"!O;F4@=V%Y('1O(&UA:V4@=&AE(&-O
M;F9I9W5R871I;VX@9FEL97,@86YD"F1I<F5C=&]R:65S(&%C8V5S<VEB;&4@
M;VYL>2!T;R!T:&4@=V5B('-E<G9E<B!I<R!A<R!F;VQL;W=S+B`@2&5R92!W
M92!A<W-U;64*=&AA="!T:&4@=V5B('-E<G9E<B!R=6YS(&%S('1H92!U<V5R
M(&!@87!A8VAE8&`@86YD('1H92!F:6QE<R!A<F4@;&]C871E9"!I;@I@8"]H
M;VUE+VAT='!D+VAT;6Q@8"`M+2!S=6)S=&ET=71E('1H92!C;W)R96-T('5S
M97(@;W(@9FEL92!P871H(&EF(&YE961E9#HZ"@HD(&-H;W=N("U2(&%P86-H
M92`O:&]M92]H='1P9"]H=&UL+VAO<F1E+V-O;F9I9PHD(&-H;W=N("U2(&%P
M86-H92`O:&]M92]H='1P9"]H=&UL+VAO<F1E+RHO8V]N9FEG"B0@8VAM;V0@
M+5(@9V\M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O8V]N9FEG"B0@8VAM
M;V0@+5(@9V\M<G=X("]H;VUE+VAT='!D+VAT;6PO:&]R9&4O*B]C;VYF:6<*
M"D9O<B!C;VUP;&5T96QY(&9A<V-I<W0@<&5R;6ES<VEO;G,L('EO=2!C86X@
M;6%K92!T:&4@96YT:7)E($AO<F1E('1R964*:6YA8V-E<W-I8FQE(&)Y(&%N
M>6]N92!E>&-E<'0@=&AE('=E8B!S97)V97(@=7-E<B`H86YD(')O;W0I.CH*
M"B0@8VAO=VX@+5(@87!A8VAE("]H;VUE+VAT='!D+VAT;6PO:&]R9&4*)"!C
M:&UO9"`M4B!G;RUR=W@@("]H;VUE+VAT='!D+VAT;6PO:&]R9&4*)"!C:&UO
M9"`M4B!A+7<@("`O:&]M92]H='1P9"]H=&UL+VAO<F1E+PH*3F]T92!T:&%T
M('1H92!L87-T(&QI;F4@;6%K97,@86QL(&9I;&5S('5N=W)I=&%B;&4@8GD@
M86YY('5S97(@*&]N;'D@<F]O="!C86X*;W9E<G)I9&4@=&AI<RDN("!4:&ES
M(&UA:V5S('1H92!S:71E('-E8W5R92P@8G5T(&UA>2!M86ME(&ET(&UO<F4@
M9&EF9FEC=6QT('1O"F%D;6EN:7-T<F%T92X@($EN('!A<G1I8W5L87(L(&ET
M('=I;&P@9&5F96%T('1H92!(;W)D92!A9&UI;FES=')A=&EV90IC;VYF:6=U
M<F%T:6]N(&EN=&5R9F%C92P@9F]R8VEN9R!Y;W4@=&\@=7!D871E('1H92!(
M;W)D92!C;VYF:6=U<F%T:6]N(&9I;&5S"FUA;G5A;&QY("AA<R!P97(@=&AE
M($E.4U1!3$Q?(&EN<W1R=6-T:6]N<RDN"@I4:&4@86)O=F4@=VEL;"!N;W0@
M<V5C=7)E('1H92!F:6QE<R!I9B!O=&AE<B!U<V5R)W,@;VX@=&AE('-A;64@
M;6%C:&EN92!C86X*<G5N('-C<FEP=',@87,@=&AE(&%P86-H92!U<V5R+B`@
M268@>6]U(&YE960@=&\@<')O=&5C="!A9V%I;G-T('1H:7,@>6]U"G-H;W5L
M9"!M86ME(&]T:&5R('5S97(G<R!S8W)I<'1S(')U;B!U;F1E<B!T:&5I<B!O
M=VX@86-C;W5N="!W:71H('-O;64*9F%C:6QI='D@<W5C:"!A<R!A<&%C:&4G
M<R!S=65X96,@;6]D=6QE+B`@66]U(&YE960@=&\@=V%T8V@@;W5T(&YO="!O
M;FQY(&9O<@IC9VD@<V-R:7!T<RP@8G5T(&%L<V\@9F]R(&]T:&5R(&UO9'5L
M97,@;&EK92!M;V1?<&AP+"!M;V1?<&5R;"P@;6]D7W!Y=&AO;BP*971C+B!T
M:&%T(&UA>2!B92!I;B!U<V4@;VX@>6]U<B!S97)V97(N"@HN+B!?24Y35$%,
M3#H@/V8]24Y35$%,3"YH=&UL"@H*4F5S=')I8W1I;F<@=&5S="YP:'`@9FEL
M97,*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"E1H92!@8'1E<W0N<&AP
M8&`@9FEL97,@<')O=FED92!A('=E86QT:"!O9B!I;F9O<FUA=&EO;B!T:&%T
M(&-A;B!B92!U<V5D"F%G86EN<W0@=&AE('-I=&4@8GD@871T86-K97)S+B`@
M3VYE('EO=2!H879E(&-O;F9I<FUE9"!T:&%T(&5V97)Y=&AI;F<@:7,*=V]R
M:VEN9RP@>6]U('-H;W5L9"!D:7-A8FQE(&%C8V5S<R!T;R!T:&4@=&5S="YP
M:'`@9FEL97,N("!9;W4@8V%N(&1O('1H:7,@=FEA"G1H92!W96(@<V5R=F5R
M+"!O<B!V:6$@<WES=&5M(&9I;&4@<&5R;6ES<VEO;G,N("!/;B!A('5N:7@@
M<WES=&5M+"!Y;W4@;6EG:'0*:7-S=64@82!C;VUM86YD('-U8V@@87,Z.@H*
M)"!C:&UO9"!A+7)W>"`O:&]M92]H='1P9"]H=&UL+VAO<F1E+W1E<W0N<&AP
M"B0@8VAM;V0@82UR=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+W1E<W0N
M<&AP"@H*4')E=F5N=&EN9R!!<&%C:&4@9G)O;2!S97)V:6YG(&-O;F9I9W5R
M871I;VX@86YD('-O=7)C92!F:6QE<PH]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*5&AE
M($AO<F1E(&-O;F9I9W5R871I;VX@9FEL97,@;6%Y(&-O;G1A:6X@<V5N<VET
M:79E(&1A=&$@*'-U8V@@87,@9&%T86)A<V4*<&%S<W=O<F1S*2!T:&%T('-H
M;W5L9"!N;W0@8F4@<V5R=F5D(&)Y('1H92!W96(@<V5R=F5R+B!/=&AE<B!D
M:7)E8W1O<FEE<PIC;VYT86EN(%!(4"!S;W5R8V4@8V]D92!T:&%T(&ES;B=T
M(&EN=&5N9&5D(&9O<B!V:65W:6YG(&)Y(&5N9"UU<V5R<RX@5&AE"DAO<F1E
M(&=R;W5P(&AA<R!P<F]V:61E9"!@8"YH=&%C8V5S<V!@(&9I;&5S(&EN('9A
M<FEO=7,@9&ER96-T;W)I97,@=&\@:&5L<`IP<F]T96-T('1H97-E(&9I;&5S
M+B`@2&]W979E<BP@=&AA="!D97!E;F1S(&]N('EO=7(@=V5B('-E<G9E<B!H
M;VYO<FEN9PI@8"YH=&%C97-S8&`@9FEL97,@*'=H:6-H(&ES(&$@<&5R9F]R
M;6%N8V4@:&ET+"!A;F0@;6%Y(&YO="!B92!A=F%I;&%B;&4@:6X*86QL('=E
M8B!S97)V97)S*2X*"D%N($%P86-H92!S:71E(&-A;B!A;'-O('!R979E;G0@
M=&AE('=E8B!S97)V97(@9G)O;2!S97)V:6YG('1H97-E"F9I;&5S(&)Y(&%D
M9&EN9R!S96-T:6]N<R!T;R!@8&AT='!D+F-O;F9@8"!S=6-H(&%S('1H92!F
M;VQL;W=I;F<Z.@H*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H
M;W)D92]C;VYF:6<B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@
M9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B
M+VAO;64O:'1T<&0O:'1M;"]H;W)D92]L:6(B/@H@("`@("`@;W)D97(@9&5N
M>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*
M("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]L;V-A;&4B
M/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L
M;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O
M:'1M;"]H;W)D92]P;R(^"B`@("`@("!O<F1E<B!D96YY+&%L;&]W"B`@("`@
M("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\1&ER96-T;W)Y
M("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+W-C<FEP=',B/@H@("`@("`@;W)D
M97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C
M=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]T
M96UP;&%T97,B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N
M>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*"E)E<&5A="!T:&ES('!A='1E
M<FX@9F]R(&5A8V@@2&]R9&4@87!P;&EC871I;VXN("!&;W(@97AA;7!L92P@
M9F]R($E-4"!Y;W4*=V]U;&0@=&AE;B!A9&0Z.@H*("`@/$1I<F5C=&]R>2`B
M+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O8V]N9FEG(CX*("`@("`@(&]R
M9&5R(&1E;GDL86QL;W<*("`@("`@(&1E;GD@9G)O;2!A;&P*("`@/"]$:7)E
M8W1O<GD^"B`@(#Q$:7)E8W1O<GD@(B]H;VUE+VAT='!D+VAT;6PO:&]R9&4O
M:6UP+VQI8B(^"B`@("`@("!O<F1E<B!D96YY+&%L;&]W"B`@("`@("!D96YY
M(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@("`\1&ER96-T;W)Y("(O:&]M
M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]L;V-A;&4B/@H@("`@("`@;W)D97(@
M9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M(&%L;`H@("`\+T1I<F5C=&]R
M>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T<&0O:'1M;"]H;W)D92]I;7`O
M<&\B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F<F]M
M(&%L;`H@("`\+T1I<F5C=&]R>3X*("`@/$1I<F5C=&]R>2`B+VAO;64O:'1T
M<&0O:'1M;"]H;W)D92]I;7`O<V-R:7!T<R(^"B`@("`@("!O<F1E<B!D96YY
M+&%L;&]W"B`@("`@("!D96YY(&9R;VT@86QL"B`@(#PO1&ER96-T;W)Y/@H@
M("`\1&ER96-T;W)Y("(O:&]M92]H='1P9"]H=&UL+VAO<F1E+VEM<"]T96UP
M;&%T97,B/@H@("`@("`@;W)D97(@9&5N>2QA;&QO=PH@("`@("`@9&5N>2!F
M<F]M(&%L;`H@("`\+T1I<F5C=&]R>3X*"@I3971U<"!S8W)I<'1S"CT]/3T]
M/3T]/3T]/3T*"E1H97)E(&%R92!V87)I;W5S('-C<FEP=',@=7-E('1O('-E
M='5P(&]R(&-O;F9I9W5R92!(;W)D92X@($EF('EO=2!A;&QO=R!O=&AE<@IU
M<V5R<R!O;B!T:&4@=V5B('-E<G9E<B!M86-H:6YE+"!Y;W4@<VAO=6QD('!R
M;W1E8W0@=&AE<V4@9FEL97,@9G)O;2!B96EN9PIA8V-E<W-E9"!B>2!T:&5M
M+B`@3VX@82!U;FEX('-Y<W1E;2P@>6]U(&UI9VAT(')E<W1R:6-T('1H97-E
M(&9I;&5S('1O(')O;W0*86-C97-S(&)Y('5S:6YG('1H92!F;VQL;W=I;F<@
M='EP92!O9B!C;VUM86YD<SHZ"@HD(&-H;W=N("U2(')O;W0@+VAO;64O:'1T
M<&0O:'1M;"]H;W)D92]S8W)I<'1S"B0@8VAO=VX@+5(@<F]O="`O:&]M92]H
M='1P9"]H=&UL+VAO<F1E+RHO<V-R:7!T<PHD(&-H;6]D("U2(&=O+7)W>"`O
M:&]M92]H='1P9"]H=&UL+VAO<F1E+W-C<FEP=',*)"!C:&UO9"`M4B!G;RUR
M=W@@+VAO;64O:'1T<&0O:'1M;"]H;W)D92\J+W-C<FEP=',*"@I5<VEN9R!A
M(&-H<F]O="!W96(@<V5R=F5R('-E='5P"CT]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T*"E5N:7@@=7-E<G,@;6%Y('=A;G0@=&\@8V]N<VED97(@
M=7-I;F<@82!C:')O;W0@96YV:7)O;FUE;G0@9F]R('1H96ER('=E8@IS97)V
M97(N("!(;W<@=&\@9&\@=&AI<R!I<R!B97EO;F0@=&AE('-C;W!E(&]F('1H
M:7,@9&]C=6UE;G0L(&)U="!S=69F:6-I96YT"FEN9F]R;6%T:6]N(&5X:7-T
M<R!O;B!T:&4@=V]R;&0@=VED92!W96(@86YD+V]R(&EN('EO=7(@<V5R=F5R
M(&1O8W5M96YT871I;VX*=&\@8V]M<&QE=&4@=&AI<R!T87-K+@H*"DAI9&EN
M9R!02%`@:6YF;R!F<F]M('1H92!U<V5R"CT]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"@I9;W4@<VAO=6QD(&-O;G-I9&5R('-E='1I;F<@=&AE(&9O
M;&QO=VEN9R!02%`@=F%R:6%B;&5S(&EN('EO=7(@8&!P:'`N:6YI8&`*9FEL
M92!T;R!P<F5V96YT(&EN9F]R;6%T:6]N(&QE86L@=&\@=&AE('5S97(L(&]R
M(&=L;V)A;"!I;G-E<G1I;VX@8GD@=&AE"G5S97(Z.@H*("`@97AP;W-E7W!H
M<"`]($]F9@H@("!D:7-P;&%Y7V5R<F]R<R`]($]F9@H@("!L;V=?97)R;W)S
M(#T@3VX*("`@<F5G:7-T97)?9VQO8F%L<R`]($]F9@H*66]U('-H;W5L9"!A
M;'-O('-E="!U<"!E<G)O<B!L;V=G:6YG("AU<VEN9R!T:&4@4$A0(&!@97)R
M;W)?;&]G8&`@=F%R:6%B;&4I"G1O(&QO9R!T;R!A(&9I;&4L('-Y<VQO9RP@
M;W(@;W1H97(@;&]G(&1E<W1I;F%T:6]N+@H*"E5S:6YG(&$@<V5C=7)E('=E
M8B!S97)V97(*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*2&]R9&4@9&5P
M96YD<R!O;B!P87-S:6YG('-E;G-I=&EV92!I;F9O<FUA=&EO;B`H<W5C:"!A
M<R!P87-S=V]R9',@86YD('-E<W-I;VX*:6YF;W)M871I;VXI(&)E='=E96X@
M=&AE('=E8B!S97)V97(@86YD('1H92!W96(@8VQI96YT+B`@57-I;F<@82!S
M96-U<F4**%-33"UE;F%B;&5D*2!W96(@<V5R=F5R('=I;&P@:&5L<"!P<F]T
M96-T('1H:7,@:6YF;W)M871I;VX@87,@:70@=')A=F5R<VEN9PIT:&4@;F5T
M=V]R:RX*"@I5<VEN9R!A('-E8W5R92!03U`S+TE-05`@<V5R=F5R"CT]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DEF('EO=2!A<F4@=7-I;F<@
M82!03U`S+TE-05`@<V5R=F5R('=I=&@@2&]R9&4@*&4N9RX@9F]R(&%U=&AE
M;G1I8V%T:6]N(&]R(&9O<@I)35`I('1H96X@2&]R9&4@:7,@<&%S<VEN9R!T
M:&4@=7-E<B=S(&QO9VEN(&-R961E;G1I86QS(&)E='=E96X@=&AE('=E8B!S
M97)V97(*86YD('1H92!M86EL('-E<G9E<BX*"DEF('EO=7(@=V5B('-E<G9E
M<B!A;F0@24U!4"!S97)V97(@87)E(&]N('1H92!S86UE(&AO<W0L('EO=2!C
M86X@:6YC<F5A<V4*<V5C=7)I='D@8GD@9F]R8VEN9R!A;&P@=')A9F9I8R!O
M=F5R('1H92!L;V]P8F%C:R!O<B!L;V-A;&AO<W0@:6YT97)F86-E('-O"G1H
M870@:70@:7,@;F]T(&5X<&]S960@=&\@>6]U<B!N971W;W)K+@H*26X@8V%S
M97,@=VAE<F4@=&AA="!I<R!N;W0@<&]S<VEB;&4L('=E(')E8V]M;65N9"!U
M<VEN9R!A('-E8W5R92!M86EL"F-O;FYE8W1I;VX@<W5C:"!A<R!)34%0+5-3
M3"!O<B!03U`S+5-33"!T;R!E;G-U<F4@=&AA="!P87-S=V]R9',@<F5M86EN
M('-A9F4N"@H*3$1!4"!396-U<FET>0H]/3T]/3T]/3T]/3T]"@I,1$%0('-E
M8W5R:71Y(&ES('-I;6EL87(@=&\@=&AE(&%B;W9E(%!/4#,O24U!4"!S97)V
M97(@<V5C=7)I='D@:7-S=64N("!)9B!Y;W4*87)E('5S:6YG($Q$05`L('EO
M=2!S:&]U;&0@;6%K92!S=7)E('1H870@>6]U(&%R92!N;W0@97AP;W-I;F<@
M;&1A<"!P87-S=V]R9',*;W(@86YY('-E;G-I=&EV92!D871A(&EN('EO=7(@
M3$1!4"!D871A8F%S92X*"@I$871A8F%S92!S;V-K970@<V5C=7)I='D*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@I)9B!Y;W5R(&1A=&%B87-E("AE+F<N
M($UY4U%,(&]R(%!O<W1G<F5344PI(&ES(&]N('1H92!S86UE(&AO<W0@87,@
M>6]U<B!W96(*<V5R=F5R+"!Y;W4@;6%Y('5S92!U;FEX('-O8VME=',@<F%T
M:&5R('1H86X@=&-P(&-O;FYE8W1I;VYS('1O(&AE;'`@:6UP<F]V90IY;W5R
M('-E8W5R:71Y("AA;F0@<&5R9F]R;6%N8V4I+B`@268@:70@9&]E<VXG="!S
M=7!P;W)T('5N:7@@<V]C:V5T<RP@>6]U(&-A;@IA8VAI979E('-O;64@8F5T
M=&5R('-E8W5R:71Y(&)Y(')E<W1R:6-T:6YG('1H92!T8W`@<W5P<&]R="!T
M;R!T:&4@;&]O<&)A8VL@;W(*;&]C86QH;W-T(&EN=&5R9F%C92X*"DEF('1H
M92!D871A8F%S92!K965P<R!I=',@<V]C:V5T(&9I;&4@*&4N9RX@8&!M>7-Q
M;"YS;V-K8&`I(&EN(&$@9&ER96-T;W)Y"FQI:V4@8&`O=&UP8&`@;W(@8&`O
M=F%R+W1M<&!@+"!Y;W4@<VAO=6QD('-E="!P97)M:7-S:6]N<R!C87)E9G5L
M;'D@=&\@96YS=7)E"G1H870@;&]C86P@=7-E<G,@*&EF('EO=2!H879E(&%N
M>2D@8V%N)W0@9&5L971E('1H92!S;V-K970N("!4:&4@=6YI>"`B<W1I8VMY
M(@IB:70@<VAO=6QD(&%L<F5A9'D@8F4@<V5N="!O;B!T:&4@=&5M<&]R87)Y
M(&1I<F5C=&]R>2!I='-E;&8L(&)U="!Y;W4@86QS;PIN965D('1O(&UA:V4@
M<W5R92!T:&4@<V]C:V5T(&ET<V5L9B!I<VXG="!W<FET86)L92!B>2`B;W1H
M97(B(&]R('5S97)S(&-A;@ID96QE=&4@:70N"@I9;W4@;6EG:'0@8V]N<VED
M97(@;6]V:6YG('1H92!S;V-K970@9FEL92!T;R!A;F]T:&5R(&QO8V%T:6]N
M('-U8V@@87,*8&`O=F%R+W)U;F!@(&]R('1H92!T;W`M;&5V96P@9&ER96-T
M;W)Y(&]F('EO=7(@9&%T86)A<V4@<')O9W)A;2`H92YG+@I@8"]V87(O;&EB
M+VUY<W%L8&`@;W(@8&`O=F%R+VQI8B]P9W-Q;&!@*2X*"@I396YD;6%I;"!O
M<B!33510(&-O;G-I9&5R871I;VYS"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T*"DEN('-O;64@8V%S97,L('EO=2!C86X@:6YC<F5A<V4@<V5C
M=7)I='D@8GD@<V5N9&EN9R!M86EL('9I82!T:&4@;&]C86P*8V]M;6%N9"UL
M:6YE('-E;F1M86EL('!R;V=R86T@;VX@>6]U<B!W96(@<V5R=F5R+"!R871H
M97(@=&AA;B!U<VEN9R!33510+@I(;W=E=F5R+"!T:&5R92!M87D@8F4@<F5A
M<V]N<R!T;R!U<V4@4TU44"!I;G-T96%D+"!S=6-H(&%S(&EF('EO=7(@<VUT
M<"!S97)V97(*9&]E<R!S<&%M(&]R('9I<G5S(&-H96-K:6YG('=H:6-H('=O
M=6QD(&)E('-K:7!P960@=7-I;F<@=&AE(&QO8V%L('-E;F1M86EL"G!R;V=R
M86TN"@H*061D:71I;VYA;"!.;W1E<PH]/3T]/3T]/3T]/3T]/3T]"@I4:&ES
M(&ES(&)Y(&9A<B!N;W0@82!C;VUP;&5T92!S96-U<FET>2!(3U=43RX@5&AI
M<R!I<R!J=7-T(&$@8V]M<&EL960@;&ES="!O9@IW:&%T('!E;W!L92!H879E
M(&-O;G1R:6)U=&5D('-O(&9A<BX@268@>6]U(&AA=F4@=&EP<RP@:61E87,L
M('-U9V=E<W1I;VYS(&]R"F%N>71H:6YG(&5L<V4@=&AA="!Y;W4@=&AI;FL@
M8V]U;&0@:&5L<"!O=&AE<G,@:6X@<V5C=7)I;F<@=&AE:7(@2&]R9&4*:6YS
M=&%L;&%T:6]N+"!P;&5A<V4@;&5T('5S(&MN;W<N"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O9&]C<R]43T1/````````````````````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`S-S(Q(#$P-3$U-#,T,3,U(#`Q-S$U-P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@1&5V96QO<&UE;G0@
M5$]$3R!,:7-T"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@HZ3&%S
M="!U<&1A=&4Z("`@)$1A=&4Z(#(P,#0O,3(O,3@@,3DZ-3<Z,S(@)`HZ4F5V
M:7-I;VXZ("`@("`@)%)E=FES:6]N.B`Q+C(W("0*.D-O;G1A8W0Z("`@("`@
M(&AO<F1E0&QI<W1S+FAO<F1E+F]R9PH*26X@;F\@<&%R=&EC=6QA<B!O<F1E
M<CH*"BT@*$]P=&EO;F%L;'DI($)U;F1L92!014%2('!A8VMA9V5S('=I=&@@
M=&AE('1A<F)A;&QS+B!':79E;B!A('!A8VMA9V4@;&ES="P*("!M86ME+7)E
M;&5A<V4N<&AP('-H;W5L9"!G970@=&AE('!A8VMA9V5S(&%N9"!U;G!A8VL@
M=&AE;2!I;G1O(&QI8B\@=VAE<F4@=V4*("!I;G-T86QL(&]U<B!O=VX@<&%C
M:V%G97,@86YY=V%Y+B!4;V=E=&AE<B!W:71H('!E87(N:&]R9&4N;W)G('1H
M:7,@<VAO=6QD"B`@;&5A9"!T;R`B;&ET92(@=&%R8F%L;',@;VYL>2!C;VYT
M86EN:6YG(&%P<&QI8V%T:6]N(&-O9&4@86YD(")F=6QL(B!T87)B86QL<PH@
M('1H870@9&]N)W0@;F5E9"!A;GD@97AT97)N86P@9&5P96YC96YC:65S(&%N
M>6UO<F4N"@HM(")B<F]W<V4B(&1R:79E<B!F;W(@5D93('1H870@=7-E<R!(
M;W)D92=S(&)R;W=S92!!4$DN"@HM($-A8VAE('1H92!296=I<W1R>2!O8FIE
M8W0@<V\@=&AA="!F:6QE(&]V97)H96%D(&]F(')E861I;F<@:6X@96YT<FEE
M<R!F<F]M(&$*("!D:7)E8W1O<GD@*')E9VES=')Y+F0I(&ES(&UI=&EG871E
M9"X*"BT@26UP;&5M96YT(&%D;6EN+V1E;&5T955S97(@;65T:&]D<R!I;B!A
M<'!L:6-A=&EO;G,G($%027,@=&\@9&5L971E('5S97(*("!S<&5C:69I8R!D
M871A+@H*+2!!9&0@82`O<V5R=FEC97,O9W)O=7!S+R!S96-T:6]N+B!);F-L
M=61E('!U8FQI8R!G<F]U<"!H;VUE<&%G97,L(&EN8VQU9&EN9PH@(&%N>2!I
M;F9O<FUA=&EO;B!M87)K960@<'5B;&EC(&9O<B!T:&4@9W)O=7`@*&QE="!T
M:&4@;65M8F5R<R!L:7-T(&)E(&UA<FME9`H@('!U8FQI8R]G<F]U<"!O;FQY
M+V%D;6EN(&]N;'DI+"!A9&0@9W)O=7`@861M:6YI<W1R871O<G,@*&IU<W0@
M82!F;&%G(&9O<@H@('5S97)S*2P@861D('1H92!A8FEL:71Y('1O('-H;W<@
M86QL(&-A;&5N9&%R<R]O=&AE<B!S:&%R97,@=&AA="!A(&=R;W5P(&AA<PH@
M('!E<FUI<W-I;VYS('1O+"!A;&QO=R!C<F5A=&EN9R!A(&YE=R!C86QE;F1A
M<B]P;VQL+V5T8RX@9F]R(&$@9W)O=7`N"@HM($%D9"!T:&4@86)I;&ET>2!T
M;R!B<F5A:R!O=70@1&%T851R964@9W)O=7!?=6ED<R!I;G1O('1H96ER(&]W
M;B!T86)L97,@*&]N90H@('1A8FQE('!E<B!G<F]U<"DN"@HM(%5S92!T:&4@
M9G)E961E<VMT;W`@<VAA<F5D+6UI;64M:6YF;U\@6$U,(&9I;&4@=&\@8G5I
M;&0@;W5R($U)345?36%G:6,@;6%G:6,*("!D871A(&9I;&5S+@H*+2!!9&0@
M<W5P<&]R="!F;W(@=&AE(%-232!A<'!L:6-A=&EO;B!S97)V97(@*&AT='`Z
M+R]W=W<N=FPM<W)M+FYE="\I+@H*+2!!9&0@54D@<W5P<&]R="!F;W(@;6]R
M92!C;VYF:6=U<F%T:6]N(&9I;&5S+@H*+2!3:6YC92!#;VYT96YT+41I<W!O
M<VET:6]N("A21D,@,C$X,RD@:7,@;F]T(&$@35535"!I;7!L96UE;G0L(&%L
M;&]W"B`@:6YD:79I9'5A;"!-24U%(%9I97=E<G,@=&\@86QL;W<@97AP;&EC
M:70@;W9E<G)I9&4@*&DN92X@=&\@875T;R!I;FQI;F4@"B`@9&ES<&QA>2!A
M('!A<G0@:6YS=&5A9"!O9B!R96YD97)I;F<@87,@86X@871T86-H;65N="`M
M('5S969U;"!F;W(@4R]-24U%"B`@96YC<GEP=&5D('!A<G1S+"!F;W(@97AA
M;7!L92DN"@HM(%-H;W<@<VAA<F5D('!R969E<F5N8V5S(&]N(&%L;"!P<F5F
M<R!S=6UM87)Y('-C<F5E;G,@=&\@;6%K92!I=`H@(&5A<VEE<B!F;W(@=7-E
M<B!T;R!F:6YD(&=L;V)A;"!P<F5F97)E;F-E<RX*"@HN+B!?<VAA<F5D+6UI
M;64M:6YF;SH@:'1T<#HO+W=W=RYF<F5E9&5S:W1O<"YO<F<O4V]F='=A<F4O
M<VAA<F5D+6UI;64M:6YF;PH`````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O
M8W,O5%)!3E-,051)3TY3````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q,C4W,2`Q,#4Q-30S-#$S-2`P,C`S,S8`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/0H@2&]R9&4@5')A;G-L871I;VX@1W5I9&4*/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E
M.B`R,#`U+S$P+S$X(#$Q.C,S.C,X("0*.E)E=FES:6]N.B`@("`@("12979I
M<VEO;CH@,2XX+C$P+C(@)`HZ075T:&]R.B`@("`@("`@2F]R:7,@0G)A86MM
M86X@/&IB<F%A:VUA;D!Y86AO;RYC;VT^"CI!=71H;W(Z("`@("`@("!#:'5C
M:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX*.D%U=&AO<CH@("`@("`@
M($IA;B!38VAN96ED97(@/&IA;D!H;W)D92YO<F<^"CI#;VYT86-T.B`@("`@
M("!H;W)D94!L:7-T<RYH;W)D92YO<F<*"BXN(&-O;G1E;G1S.CH@0V]N=&5N
M=',*"@I'3E4@9V5T=&5X="P@4$A0(&%N9"!(;W)D90H]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/0H*2&]R9&4@=7-E<R!'3E4@9V5T=&5X="!F;W(@:6YT
M97)N871I;VYA;&EZ871I;VX@*&DQ.&XI(&%N9"!L;V-A;&EZ871I;VX**&PQ
M,&XI+B`@5&AE(&UA;G5A;"!A="!H='1P.B\O=W=W+F=N=2YO<F<O;6%N=6%L
M+V=E='1E>'0O:6YD97@N:'1M;"!I<R!B:6%S960*86=A:6YS="!#(&%N9"!U
M<VEN9R!%;6%C<RX@(%1H:7,@:7,@;6]R92!F;W(@2&]R9&4N"@I4:&5R92!I
M<R!A(&=O;V0@97AP;&%N871I;VX@9F]R(%!(4"!A;F0@9V5T=&5X="!A=#H*
M:'1T<#HO+W=W=RYF87%T<RYC;VTO:VYO=VQE9&=E+6)A<V4O=FEE=RYP:'1M
M;"]A:60O,CDU,R]F:60O-#(R"@I096]P;&4@<V5E;2!T;R!L:6ME(&QE87)N
M:6YG(&9R;VT@97AA;7!L97,@8F5T=&5R+"!S;R!)(&AA=F4@=7-E9"!D=71C
M:`HH;FQ?3DPI(&%S(&%N(&5X86UP;&4@979E<GEW:&5R92X*"E1H97)E(&ES
M(&$@8V]M;6%N9"!L:6YE('1O;VP@=W)I='1E;B!I;B!02%`@9F]R(&-R96%T
M:6YG(&%N9"!M86YA9VEN9PIT<F%N<VQA=&EO;G,@:6X@=&AE(&!@:&]R9&4O
M<&\O8&`@9&ER96-T;W)Y+B`@57-A9V4@:6YS=')U8W1I;VYS(&-A;B!B92!F
M;W5N9`II;B!@8&AO<F1E+W!O+U)%041-16!@(&%S('=E;&P@87,@:6YS=')U
M8W1I;VYS(&]N(&AO=R!T;R!S=&%R="!A;F0@;6%I;G1A:6X*=')A;G-L871I
M;VYS+@H*"E1R86YS;&%T:6]N<R!D;VXG="!W;W)K"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"@I)9B!A;&P@;W(@<V]M92!T<F%N<VQA=&EO;G,@9&]N)W0@
M=V]R:R!O;B!Y;W5R('-Y<W1E;2P@<&QE87-E(&9O;&QO=R!T:&4@<W1E<',*
M9&5S8W)I8F5D(&)E;&]W+B`@268@>6]U('=A;G0@=&\@87-K(&9O<B!H96QP
M(&5I=&AE<B!O;B!T:&4@8&DQ.&X@;6%I;&EN9PIL:7-T8%\@;W(@;VX@8$AO
M<F1E)W,@8G5G('-Y<W1E;6!?+"!P;&5A<V4@97AP;&%I;B!W:&EC:"!S=&5P
M<R!Y;W4@=')I960@86YD"G=H:6-H(&9A:6QE9"X*"EEO=2!M:6=H="!A;'-O
M(&9I;F0@<V]M92!M;W)E(&EN9F]R;6%T:6]N(&EN('1H92!&05%?+@H*4&QE
M87-E(&YO=&4@=&AA="!$=71C:"`H;FQ?3DPI(&ES(&]N;'D@=7-E9"!A<R!A
M;B!E>&%M<&QE(&AE<F4N("!)9B!Y;W4@:&%V90IP<F]B;&5M<R!W:71H(&$@
M8V5R=&%I;B!T<F%N<VQA=&EO;B!U<V4@=&AI<R!T<F%N<VQA=&EO;B=S(&QA
M;F=U86=E(&-O9&4*:6YS=&5A9"X*"C$N($ES('1H:7,@;&]C86QE("AN;%].
M3"D@:6YS=&%L;&5D(&%T(&%L;#\*"B`@(&!@;&]C86QE("UA8&`@<VAO=6QD
M(&QI<W0@86QL(&QO8V%L97,@:6YS=&%L;&5D(&]N('EO=7(@<WES=&5M+@H*
M("`@3VX@1&5B:6%N(&YO="!A;&P@;&]C86QE<R!M87D@8F4@96YA8FQE9"!B
M>2!D969A=6QT+B`@161I=`H@("!@8"]E=&,O;&]C86QE+F=E;F!@(&%N9"!R
M=6X@8&!L;V-A;&4M9V5N8&`@:68@>6]U(&-H86YG960@=&AE(&QI<W0@;V8*
M("`@96YA8FQE9"!L;V-A;&5S+@H*,BX@1&\@>6]U(&AA=F4@86YY("YM;R!F
M:6QE<S\*"B`@(%5S=6%L;'D@:6X@8&`O=7-R+W-H87)E+VQO8V%L92]@8`H@
M("!E+F<N(&!@+W5S<B]S:&%R92]L;V-A;&4O;FPO3$-?34534T%'15,O=&%R
M+FUO8&`*"C,N($1O97,@9V5T=&5X="!E=F5N('=O<FL_"@H@("!'970@82!S
M=')I;F<@=&\@=')A;G-L871E.CH*"B`@("`@("0@<W1R:6YG<R`O8FEN+W1A
M<B!\(&=R97`@365M;W)Y"B`@("`@($UE;6]R>2!E>&AA=7-T960*("`@("`@
M)"`H3$%.1SUN;%].3#L@3$%.1U5!1T4];FQ?3DP[($Q#7TU%4U-!1T53/6YL
M7TY,.R!G971T97AT('1A<B`B365M;W)Y(&5X:&%U<W1E9"(@*0H@("`@("!'
M96AE=6=E;B!U:71G97!U=`H*-"X@1&]E<R!T:&4@;&]C86P@2&]R9&4@9FEL
M92!W;W)K/PH*("`@07-S=6UI;F<@=&AA="!Y;W4@:&%V92!P=70@=&AE('1R
M86YS;&%T960@2&]R9&4@9FEL92!I;@H@("!@8"]D871A+W=W=R]H;W)D92]L
M;V-A;&4O;FQ?3DPO3$-?34534T%'15,O:&]R9&4N;6]@8#HZ"@H@("`@("`D
M(&5X<&]R="!415A41$]-04E.1$E2/2]D871A+W=W=R]H;W)D92]L;V-A;&4*
M("`@("`@)"`H3$%.1SUN;%].3#L@3$%.1U5!1T4];FQ?3DP[($Q#7TU%4U-!
M1T53/6YL7TY,.R!G971T97AT(&AO<F1E(")-97-S86=E(B`I"B`@("`@($)E
M<FEC:'0*"B`@($-R96%T92!A(&9I;&4@:6X@=&AE(&AO<F1E(&1I<F5C=&]R
M>2P@;&%N9W1E<W0N<&AP.CH*"B`@("`@(#P_<&AP"@H@("`@("!S971L;V-A
M;&4H3$-?34534T%'15,L("=N;%].3"<I.PH@("`@("!P=71E;G8H)TQ!3D<]
M;FQ?3DPG*3L*("`@("`@<'5T96YV*"=,04Y'54%'13UN;%].3"<I.PH@("`@
M("`O+R!U<V4@=&AE('1A<B!T97-T+@H@("`@("!E8VAO(&1G971T97AT*"=T
M87(G+"`G365M;W)Y(&5X:&%U<W1E9"<I.PH@("`@("!E8VAO("<\8G(@+SXG
M.PH*("`@("`@+R\@4W!E8VEF>2!L;V-A=&EO;B!O9B!T<F%N<VQA=&EO;B!T
M86)L97,*("`@("`@8FEN9'1E>'1D;VUA:6XH)VAO<F1E)RP@)RXO;&]C86QE
M)RD["@H@("`@("`O+R!#:&]O<V4@9&]M86EN"B`@("`@('1E>'1D;VUA:6XH
M)VAO<F1E)RD["@H@("`@("`O+R!0<FEN="!T:&4@86QR96%D>2!T97-T960@
M;65S<V%G90H@("`@("!E8VAO(%\H(DUE<W-A9V4B*3L*("`@("`@96-H;R`G
M/&)R("\^)SL*"B`@("`@("\O('1H:7,@<VAO=6QD('!R:6YT('1H92!S86UE
M+@H@("`@("!E8VAO(&1G971T97AT*"=H;W)D92<L("=-97-S86=E)RD["@H@
M("`@("`_/@H*("`@3W5T<'5T('=E8B!B<F]W<V5R.CH*"B`@("`@($=E:&5U
M9V5N('5I=&=E<'5T"B`@("`@($)E<FEC:'0*("`@("`@0F5R:6-H=`H*"BXN
M(%]@:3$X;B!M86EL:6YG(&QI<W1@.B!H='1P.B\O:&]R9&4N;W)G+VUA:6PO
M"BXN(%]@2&]R9&4G<R!B=6<@<WES=&5M8#H@:'1T<#HO+V)U9W,N:&]R9&4N
M;W)G"BXN(%]&05$Z(&AT='`Z+R]H;W)D92YO<F<O9F%Q+PH*"E-O;&%R:7,*
M/3T]/3T]/0H*4VEN8V4@=&AE("YM;R!F:6QE<R!A<F4@8FEN87)Y+"!T:&5Y
M(&%R92!P;&%T9F]R;2!S<&5C:69I8RX@(%EO=2!H879E('1O(')E<G5N"FUA
M:V4@:6X@86QL('!O(&1I<F5C=&]R:65S+@H*3VX@4V]L87)I<R`W+"!Y;W4@
M9&]N)W0@:&%V92!T:&4@8&!087)T:6%L($QO8V%L97,@*%-53E=P;&]C*6!@
M(&%N9`I@8%-U<'!L96UE;G1A<GD@4&%R=&EA;"!,;V-A;&5S("A354Y7<&QO
M8S$I8&`@<&%C:V%G97,@:6YS=&%L;&5D(&EF('EO=2!G970Z.@H*("`@)"!,
M04Y'/6YL7TY,"B`@(&-O=6QD;B=T('-E="!L;V-A;&4@8V]R<F5C=&QY"@I/
M;B!3;VQA<FES(#@L('EO=2!M=7-T(&EN<W1A;&P@=&AE(&QO8V%L('!A8VMA
M9V5S(')E<75I<F5D(&9O<B!T:&4@;&]C86QE<R!Y;W4*9&5S:7)E("AF;W(@
M97AA;7!L92P@>6]U(&UA>2!N965D('1O(&EN<W1A;&P@8&!354Y7=V5U;W-@
M8"!F;W(@5V5S=&5R;@I%=7)O<&5A;B!L;V-A;&5S(&]R(&!@4U5.5VUE86]S
M8&`@9F]R($UI9&1L92!%87-T97)N(&QO8V%L97,I+B`@5&AE('!A8VMA9V5S
M"F%R92!L;V-A=&5D(&]N(%-O9G1W87)E($1I<VL@,2!O9B`R(&EN('1H92!D
M:7)E8W1O<GDZ"F!@<V]L7SA?,3`P,5]S<&%R8R]S,"]3;VQA<FES7S@O4')O
M9'5C=&!@"@I4:&ES(&ES('=H870@:70@<VAO=6QD('-A>3H*"E-O;&%R:7,@
M-SHZ"@H@("`D('!K9VEN9F\@?"!G<F5P('!L;V,*("`@<WES=&5M("`@("`@
M4U5.5W!L;V,@("`@("`@4&%R=&EA;"!,;V-A;&5S"B`@('-Y<W1E;2`@("`@
M(%-53E=P;&]C,2`@("`@(%-U<'!L96UE;G1A<GD@4&%R=&EA;"!,;V-A;&5S
M"@I3;VQA<FES(#@Z.@H*("`@)"!P:V=I;F9O('P@9W)E<"!E=6\*("`@<WES
M=&5M("`@("`@4U5.5V-E=6]S("`@("`@0V5N=')A;"!%=7)O<&4@3U,@4W5P
M<&]R=`H@("!S>7-T96T@("`@("!354Y78V5U;W@@("`@("!#96YT<F%L($5U
M<F]P92`V-"UB:70@3U,@4W5P<&]R=`H@("!S>7-T96T@("`@("!354Y7965U
M;W,@("`@("!%87-T97)N($5U<F]P92!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@
M("`@(%-53E=E975O>"`@("`@($5A<W1E<FX@175R;W!E(#8T+6)I="!/4R!3
M=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=N975O<R`@("`@($YO<G1H97)N
M($5U<F]P92!/4R!3=7!P;W)T"B`@('-Y<W1E;2`@("`@(%-53E=N975O>"`@
M("`@($YO<G1H97)N($5U<F]P92`V-"UB:70@3U,@4W5P<&]R=`H@("!S>7-T
M96T@("`@("!354Y7<V5U;W,@("`@("!3;W5T:&5R;B!%=7)O<&4@3U,@4W5P
M<&]R=`H@("!S>7-T96T@("`@("!354Y7<V5U;W@@("`@("!3;W5T:&5R;B!%
M=7)O<&4@-C0M8FET($]3(%-U<'!O<G0*("`@<WES=&5M("`@("`@4U5.5W=E
M=6]S("`@("`@5V5S=&5R;B!%=7)O<&4@3U,@4W5P<&]R=`H@("!S>7-T96T@
M("`@("!354Y7=V5U;W@@("`@("!797-T97)N($5U<F]P92`V-"UB:70@3U,@
M4W5P<&]R=`H*5&AE('-T=69F(&ES(&EN<W1A;&QE9"!I;B!@8"]U<W(O;&EB
M+VQO8V%L96!@.CH*"B`@("0@;',@+W5S<B]L:6(O;&]C86QE+VYL"B`@($Q#
M7T-/3$Q!5$4@("!,0U]#5%E012`@("`@3$-?34534T%'15,@($Q#7TU/3D54
M05)9("!,0U].54U%4DE#("`@3$-?5$E-12`@("`@(&YL+G-O+C$*"DET('=A
M<R!R97!O<G1E9"!T:&%T('1H92!(5%10('-E<G9E<B!H87,@=&\@8F4@;&EN
M:V5D('1O('1H92!S86UE(&QI8FEN=&PN<V\*9FEL92!A<R!02%`@;VX@4V]L
M87)I<RX@($%L<V\L(&ET(&UA>2!B92!R97%U:7)E9"!T:&%T(&QI8FEN=&PN
M<V\@8F4@;&]A9&5D"F)E9F]R92!L:6)C(&ES(&QO861E9"X@($EF('EO=2!A
M<F4@:&%V:6YG(&-O;F9L:6-T<RP@>6]U(&UA>2!B92!A8FQE('1O(')E<VED
M90IT:&5M(&)Y('-T87)T:6YG(&%P86-H92!W:71H(&]N92!O9B!T:&4@9F]L
M;&]W:6YG(&-O;6UA;F1S.CH*"B`@("0@3$1?4%)%3$]!1#UL:6)I;G1L+G-O
M(&%P86-H96-T;"!S=&%R=`H*"D9R965"4T0*/3T]/3T]/0H*5&\@96YA8FQE
M(%541BTX('-U<'!O<G0@:6X@2&]R9&4L('EO=2!A;'-O(&YE960@551&+3@@
M<W5P<&]R="!I;@I&<F5E0E-$+B`@5&AI<R!I<R!N;W0@:6YS=&%L;&5D(&)Y
M(&1E9F%U;'0L('EO=2!N965D('1O(&EN<W1A;&P@=&AE"F!@=71F.&QO8V%L
M92UW:71H;W5T+7-W:61T:"TP-#`S,3E@8"!P86-K86=E(&]R('!O<G0N"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+V1O8W,O55!'4D%$24Y'````````````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,#,P-2`Q
M,#4Q-30S-#$S-2`P,3<W,C8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/3T]/3T]/3T]/3T]/3T]/3T*(%5P9W)A9&EN9R!(
M;W)D90H]/3T]/3T]/3T]/3T]/3T]/0H*.DQA<W0@=7!D871E.B`@("1$871E
M.B`R,#`V+S`V+S(Y(#$V.C(Y.C`R("0*.E)E=FES:6]N.B`@("`@("12979I
M<VEO;CH@,2XT+C0N,3$@)`HZ0V]N=&%C=#H@("`@("`@:&]R9&5`;&ES=',N
M:&]R9&4N;W)G"@H*5&AE<V4@87)E(&EN<W1R=6-T:6]N<R!T;R!U<&=R861E
M(&9R;VT@96%R;&EE<B!(;W)D92!V97)S:6]N<RX@4&QE87-E(&)A8VMU<`IY
M;W5R(&5X:7-T:6YG(&1A=&$@8F5F;W)E(')U;FYI;F<@86YY(&]F('1H92!S
M=&5P<R!D97-C<FEB960@8F5L;W<N(%EO=2!C86XG=`IU<V4@=&AE('5P9&%T
M960@9&%T82!W:71H('EO=7(@;VQD($AO<F1E('9E<G-I;VX@86YY;6]R92X*
M"D%F=&5R('5P9&%T:6YG('1O(&$@;F5W97(@2&]R9&4@=F5R<VEO;BP@;W(@
M82!N97=E<B!V97)S:6]N(&]F("HJ86YY*BH@2&]R9&4*87!P;&EC871I;VXL
M('EO=2`J*F%L=V%Y<RHJ(&YE960@=&\@=7!D871E("HJ86QL*BH@8V]N9FEG
M=7)A=&EO;B!F:6QE<RX*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`S+C$N,2!T
M;R`S+C$N,@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M"E-E<W-I;VX@0V]N9FEG=7)A=&EO;@HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M"D$@;F5W(&-O;F9I9W5R871I;VX@<V5T=&EN9R!H87,@8F5E;B!A9&1E9"!T
M;R!D:7-A8FQE($=%5"UB87-E9`IS97-S:6]N<RX@($EF('1H:7,@<V5T=&EN
M9R!I<R!E;F%B;&5D+"!S97-S:6]N($E$<R!W:6QL(&]N;'D@8F4@<W1O<F5D
M"FEN('-E<W-I;VX@8V]O:VEE<RP@<F5Q=6ER:6YG('1H92!U<V5R<R!T;R!E
M;F%B;&4@8V]O:VEE<R!I;B!T:&5I<@IB<F]W<V5R(&%N9"!T:&4@8V]O:VEE
M('-E='1I;F=S(&EN($AO<F1E)W,@8V]N9FEG=7)A=&EO;B!T;R!B92!C;W)R
M96-T+@H*57-I;F<@<V5S<VEO;B!C;V]K:65S(&ES(&UU8V@@<V%F97(@<VEN
M8V4@;F\@<V5S<VEO;B!I;F9O<FUA=&EO;B!C86X*8F4@<W1O<F5D(&EN(&%N
M>2!W96(@<V5R=F5R(&]R('!R;WAY(&QO9R!F:6QE<RP@<F5F97)R97(@:&5A
M9&5R<RP*8G)O=W-E<B!C86-H97,L(&]R(&)R;W=S97(@8F]O:VUA<FMS+@H*
M+BX@5V%R;FEN9SHZ(%1H:7,@<V5T=&EN9R!I;B!E;F%B;&5D(&)Y(&1E9F%U
M;'0N"@H*061D:71I;VYA;"!);F1E>&5S(&9O<B!T:&4@4')E9F5R96YC92!4
M86)L90HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"@I/<'1I;VYA;&QY(&5X96-U=&4@=&AE('!R;W9I9&5D(%-13"!S8W)I
M<'0@,C`P-BTP-BTR.5]H;W)D95]P<F5F<U]I;F1E>&5S+G-Q;`IT;R!C<F5A
M=&4@='=O(&%D9&ET:6]N86P@:6YD97AE<R!I;B!T:&4@<')E9F5R96YC92!T
M86)L92P@92YG+CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O="`M+7!A<W-W;W)D
M/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@/"!S8W)I<'1S+W5P
M9W)A9&5S+S(P,#8M,#8M,CE?:&]R9&5?<')E9G-?:6YD97AE<RYS<6P*"E1H
M:7,@:6YC<F5A<V5S(&1A=&%B87-E('!E<F9O<FUA;F-E(&9O<B!S;VUE(&1A
M=&%B87-E('-Y<W1E;7,L(&4N9RX@4&]S=&=R95-13`II9B!Y;W4@:&%V92!L
M87)G92!P<F5F97)E;F-E('1A8FQE<RX*"@I5<&=R861I;F<@2&]R9&4@9G)O
M;2`S+C$@=&\@,RXQ+C$*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]"@H*37E344P@4V5S<VEO;B!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+0H*5&AE(&UY<W%L('-E<W-I;VX@:&%N9&QE<B!H87,@8F5E;B!I;7!R
M;W9E9"!T;R!C;W)R96-T;'D@;&]C:R!C;VYC=7)R96YT"F%C8V5S<V5S('1O
M('1H92!S86UE('-E<W-I;VXN(%EO=2!N965D('1O('-E="!I;B!T:&4@2&]R
M9&4@8V]N9FEG=7)A=&EO;B!I9@IY;W4@=V%N="!T;R!U<V4@<F]W+6QE=F5L
M(&QO8VMI;F<@86YD('1R86YS86-T:6]N<R!O<B!T86)L92UL979E;`IL;V-K
M:6YG+B!2;W<M;&5V96P@;&]C:VEN9R!A;F0@=')A;G-A8W1I;VYS(&%R92!O
M;FQY('-U<'!O<G1E9"!B>2!S;VUE('1A8FQE"F5N9VEN97,@;&EK92!);FYO
M1$(L(&%N9"!I<R!R96-O;6UE;F1E9"!F;W(@<V5S<VEO;B!T86)L97,N(%1H
M92!D969A=6QT('1A8FQE"G1Y<&4@9F]R($UY4U%,(&ES($UY25-!32!T:&]U
M9V@L('1H870@;VYL>2!S=7!P;W)T<R!T86)L92UL979E;"!L;V-K:6YG+B!)
M9@IY;W4@=7-E9"!T:&4@4U%,('-C<FEP=',@9G)O;2!(;W)D92`S+C$@;W(@
M96%R;&EE<B!T;R!C<F5A=&4@=&AE('-E<W-I;VX*=&%B;&4L('1H:7,@:7,@
M<')O8F%B;'D@=&AE(&-U<G)E;G0@96YG:6YE(&]F('EO=2!S97-S:6]N('1A
M8FQE+B!)9B!Y;W4@=V%N=`IT;R!C:&%N9V4@=&AE('1A8FQE('1Y<&4@=&\@
M26YN;T1"+"!E>&5C=71E('1H92!F;VQL;W=I;F<@4U%,('-T871E;65N=#HZ
M"@H@("!!3%1%4B!404),12!H;W)D95]S97-S:6]N:&%N9&QE<B!%3D=)3D4@
M/2!);FYO1$(*"@H*57!G<F%D:6YG($AO<F1E(&9R;VT@,RXP+G@@=&\@,RXQ
M+G@*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"@I344P@
M0F%C:V5N9',*+2TM+2TM+2TM+2TM"@I!(&9E=R!N97<@=&%B;&5S(&AA=F4@
M8F5E;B!A9&1E9"!T;R!(;W)D92X*"D5X96-U=&4@;VYE(&]F('1H92!P<F]V
M:61E9"!344P@<V-R:7!T<R!T;R!U<&1A=&4@>6]U<B!D871A('1O('1H92!N
M97<@2&]R9&4*=F5R<VEO;BP@92YG+CHZ"@H@("!M>7-Q;"`M+75S97(]<F]O
M="`M+7!A<W-W;W)D/3Q->5-13"UR;V]T+7!A<W-W;W)D/B`\9&(@;F%M93X@
M/"!S8W)I<'1S+W5P9W)A9&5S+S,N,%]T;U\S+C$N;7ES<6PN<W%L"@H*1W)O
M=7!S"BTM+2TM+0H*5&AE($AO<F1E7T=R;W5P($%022!U<V5S(&=R;W5P($E$
M<R!I;G-T96%D(&]F(&=R;W5P(&YA;65S('1O(&%V;VED(&%M8FEG=6ET>2X*
M0F4@<W5R92!T;R!U<&1A=&4@86YY(&-U<W1O;2!C;V1E('1H870@=7-E<R!(
M;W)D95]'<F]U<"X*"@I(:7-T;W)Y"BTM+2TM+2T*"E1H92!(;W)D95](:7-T
M;W)Y('-T;W)A9V4@:&%S(&)E96X@;6]V960@;W5T('1O(&$@<V5P87)A=&4@
M9&%T86)A<V4@=&%B;&4@=&\*9')A<W1I8V%L;'D@:6UP<F]V92!P97)F;W)M
M86YC92X*"BXN(%=A<FYI;F<Z.B!-:6=R871I;VX@;V8@=&AE($AO<F1E7TAI
M<W1O<GD@9&%T82!M87D@=&%K92!A('9E<GD@;&]N9R!T:6UE+`H@("`@("`@
M("`@("`@<&]S<VEB;'D@9&%Y<RP@9&5P96YD:6YG(&]N('1H92!N=6UB97(@
M;V8@96YT<FEE<RX@($)E('-U<F4@=&\*("`@("`@("`@("`@(&5X96-U=&4@
M=&AI<R!S8W)I<'0@9G)O;2!A(&QO8V%T:6]N('=H97)E(&ET('=I;&P@;F]T
M(&)E('1I;65D"B`@("`@("`@("`@("!O=70@8GD@9FER97=A;&P@;W(@=&5R
M;6EN86P@=&EM96]U=',N"@I%>&5C=71E('1H92!P<F]V:61E9"!02%`@<V-R
M:7!T('1O(&UI9W)A=&4@>6]U<B!H:7-T;W)I97,@=&\@=&AE(&YE=R!T86)L
M93HZ"@H@("!P:'`@<V-R:7!T<R]U<&=R861E<R]M;W9E7VAI<W1O<GE?;W5T
M7V]F7V1A=&%T<F5E+G!H<`H*"@I5<&=R861I;F<@2&]R9&4@9G)O;2`R+G@@
M=&\@,RXP+G@*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"@H*
M0V]N9FEG=7)A=&EO;B!F:6QE<PHM+2TM+2TM+2TM+2TM+2TM+2TM"@I4:&4@
M8V]N9FEG=7)A=&EO;B!F:6QE<R!H879E(&)E96X@8VAA;F=E9"!T;R!834P@
M9F]R;6%T+B`@5&\@9V5N97)A=&4@82!V86QI9`IC;VYF:6=U<F%T:6]N(&9I
M;&4@9G)O;2!T:&4@6$U,(&9I;&4L(&9O;&QO=R!T:&4@8V]N9FEG=7)A=&EO
M;B!I;G-T<G5C=&EO;G,*:6X@=&AE(&%P<&QI8V%T:6]N<R<@8&!D;V-S+TE.
M4U1!3$Q@8"!F:6QE+@H*"E!R969E<F5N8V5S"BTM+2TM+2TM+2TM"@I4:&4@
M8&!L87-T7VQO9VEN8&`@86YD(&!@9&%T95]F;W)M871@8"!P<F5F97)E;F-E
M<R!H879E(&-H86YG960@=&AE:7(@9F]R;6%T"F%N9"]O<B!S8V]P92X@($IU
M<W0@<F5M;W9E(&%L;"!@8&QA<W1?;&]G:6Y@8"!A;F0@8&!D871E7V9O<FUA
M=&!@('!R969E<F5N8V5S"F9R;VT@=&AE('!R969E<F5N8V5S(&)A8VME;F0N
M"@H*4U%,($)A8VME;F1S"BTM+2TM+2TM+2TM+0H*02!F97<@;F5W('1A8FQE
M<R!H879E(&)E96X@861D960@=&\@2&]R9&4N"@I%>&5C=71E('1H92!P<F]V
M:61E9"!344P@<V-R:7!T('1O('5P9&%T92!Y;W5R(&1A=&$@=&\@=&AE(&YE
M=R!(;W)D92!V97)S:6]N.CH*"B`@(&UY<W%L("TM=7-E<CUR;V]T("TM<&%S
M<W=O<F0]/$UY4U%,+7)O;W0M<&%S<W=O<F0^(#QD8B!N86UE/B`\('-C<FEP
M=',O=7!G<F%D97,O,BXR7W1O7S,N,"YM>7-Q;"YS<6P*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]397)V:6-E<P``````````````````````````
M`````````````````````````````````````````````````````````#`P
M,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,R
M(#`R,#$V-``@-0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%R8VAI=F4`````
M````````````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q,S(@,#$W-S8R`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O075T:```````````````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,3<S,#(`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H90``````````````````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,3,R(#`Q-S0P-``@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-O;G-O
M;&4`````````````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S(@,#(P,#`S`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<P``````````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,R`P,3<S
M,S(`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A````````````````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,3,S(#`Q-S,Q,P`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+UA-3```````````````````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S,@,#$W,#0R`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O1$(`````````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M,R`P,38V-C<`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<`````````
M````````````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,S(#`Q-S$R,P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U-/05``````````````````````````````````````````````
M````````````````````````````````````````````,#`P-S4U(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S,@,#$W,30T`"`U
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1&%T90``````````````````````
M````````````````````````````````````````````````````````````
M```````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q
M-30S-#$S,R`P,3<R-3<`(#4`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5
M;FET````````````````````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,T(#`Q-S8W,@`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+T9I;&4`````````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S0@,#$W
M,C8R`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4@``````````````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$S-"`P,3<Q,S(`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]/4P``````````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,T(#`Q-C<R-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S````````````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M,S4@,#$W-30V`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O2%144```````
M````````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S-2`P,3<Q-C,`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]-86EL````````````````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,U(#`Q-S(V-@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE=```````````````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q,S4@,#$W,3,R`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O<&5C
M;&-M9"YP:'`N;W)I9P``````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S4R-2`Q,#4Q-30S-#$S-2`P,C$U-#<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\O#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@
M-2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@
M("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G
M92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-
M"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P
M;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O('P@075T:&]R<SH@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@
M("`@("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\-"B\O("1)9#H@<&5C;&-M9"YP:'`L=B`Q+C$@,C`P-2\P,B\R,2`P-3HS
M,#HU-B!C96QL;V<@17AP("0-"@T*+RHJ#0H@*B!`;F]D97`@1W1K#0H@*B\-
M"FEF("@G+VAO;64O;'5C97(O=V]R:R]P96%R+W-H87)E+W!H<"<@(3T@)T`G
M+B=I;F-L=61E7W!A=&@G+B=`)RD@>PT*("`@(&EN:5]S970H)VEN8VQU9&5?
M<&%T:"<L("<O:&]M92]L=6-E<B]W;W)K+W!E87(O<VAA<F4O<&AP)RD[#0H@
M("`@)')A=R`](&9A;'-E.PT*?2!E;'-E('L-"B`@("`O+R!T:&ES(&ES(&$@
M<F%W+"!U;FEN<W1A;&QE9"!P96%R+"!E:71H97(@82!C=G,@8VAE8VMO=70L
M(&]R('!H<"!D:7-T<F\-"B`@("`D<F%W(#T@=')U93L-"GT-"F1E9FEN92@G
M4$5!4E]254Y465!%)RP@)W!E8VPG*3L-"G)E<75I<F5?;VYC92`G<&5A<F-M
M9"YP:'`G.PT*+RH-"B`J($QO8V%L('9A<FEA8FQE<SH-"B`J('1A8BUW:61T
M:#H@-`T*("H@8RUB87-I8RUO9F9S970Z(#0-"B`J(&EN9&5N="UT86)S+6UO
M9&4Z(&YI;`T*("H@;6]D93H@<&AP#0H@*B!%;F0Z#0H@*B\-"B\O('9I;38P
M,#IS>6X]<&AP#0H-"C\^#0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PN<&AP
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,3<V,#$@,3`U,34T,S0Q,S4@,#(P,#8S`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@36%I;"YP:'`L=B`Q+C$R(#(P,#4O,#@O,C(@,#$Z
M,3DZ,C<@:F]N($5X<"`D"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J
M*@H@*B!014%2)W,@36%I;#HZ(&EN=&5R9F%C92X@1&5F:6YE<R!T:&4@:6YT
M97)F86-E(&9O<B!I;7!L96UE;G1I;F<*("H@;6%I;&5R<R!U;F1E<B!T:&4@
M4$5!4B!H:65R87)C:'DL(&%N9"!P<F]V:61E<R!S=7!P;W)T:6YG(&9U;F-T
M:6]N<PH@*B!U<V5F=6P@:6X@;75L=&EP;&4@;6%I;&5R(&)A8VME;F1S+@H@
M*@H@*B!`86-C97-S('!U8FQI8PH@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N
M,3(@)`H@*B!`<&%C:V%G92!-86EL"B`J+PIC;&%S<R!-86EL"GL*("`@("\J
M*@H@("`@("H@3&EN92!T97)M:6YA=&]R('5S960@9F]R('-E<&%R871I;F<@
M:&5A9&5R(&QI;F5S+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1S97`@/2`B7')<;B(["@H@("`@+RHJ"B`@("`@*B!0<F]V:61E<R!A
M;B!I;G1E<F9A8V4@9F]R(&=E;F5R871I;F<@36%I;#HZ(&]B:F5C=',@;V8@
M=F%R:6]U<PH@("`@("H@='EP97,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D<FEV97(@5&AE(&MI;F0@;V8@36%I;#HZ(&]B:F5C="!T;R!I;G-T
M86YT:6%T92X*("`@("`J($!P87)A;2!A<G)A>2`@)'!A<F%M<R!4:&4@<&%R
M86UE=&5R<R!T;R!P87-S('1O('1H92!-86EL.CH@;V)J96-T+@H@("`@("H@
M0')E='5R;B!O8FIE8W0@36%I;"!A(&EN<W1A;F-E(&]F('1H92!D<FEV97(@
M8VQA<W,@;W(@:68@9F%I;',@82!014%2($5R<F]R"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D9')I=F5R
M+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D9')I=F5R(#T@
M<W1R=&]L;W=E<B@D9')I=F5R*3L*("`@("`@("!`:6YC;'5D95]O;F-E("=-
M86EL+R<@+B`D9')I=F5R("X@)RYP:'`G.PH@("`@("`@("1C;&%S<R`]("=-
M86EL7R<@+B`D9')I=F5R.PH@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L
M87-S*2D@>PH@("`@("`@("`@("`D;6%I;&5R(#T@;F5W("1C;&%S<R@D<&%R
M86US*3L*("`@("`@("`@("`@<F5T=7)N("1M86EL97(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N
M86)L92!T;R!F:6YD(&-L87-S(&9O<B!D<FEV97(@)R`N("1D<FEV97(I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($EM<&QE;65N=',@36%I
M;#HZ<V5N9"@I(&9U;F-T:6]N('5S:6YG('!H<"=S(&)U:6QT+6EN(&UA:6PH
M*0H@("`@("H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@
M<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@("`@("A21D,X,C(@8V]M<&QI
M86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J("`@("`@
M("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R
M96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@("`@("`@('-P96-I9FEE9"!I
M;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@("H@("`@
M("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O('-E;F0@
M=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J("`@("`@("`@("`@("!A<W-O
M8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@
M("`J("`@("`@("`@("`@("!H96%D97(@;F%M92`H:64L("=3=6)J96-T)RDL
M(&%N9"!T:&4@87)R87D@=F%L=64*("`@("`J("`@("`@("`@("`@("!I<R!T
M:&4@:&5A9&5R('9A;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E<@H@("`@
M("H@("`@("`@("`@("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L=65S('=O
M=6QD(&)E("=3=6)J96-T.@H@("`@("H@("`@("`@("`@("`@('1E<W0G+@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U;&P@=&5X
M="!O9B!T:&4@;65S<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@("`@*B`@
M("`@("`@("`@("`@($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O<B!A(%!%
M05)?17)R;W(*("`@("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN9R!A(&1E
M<V-R:7!T:79E(&5R<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@("`@("`@
M("`@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`9&5P
M<F5C871E9"!U<V4@36%I;%]M86EL.CIS96YD(&EN<W1E860*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5N9"@D<F5C:7!I96YT<RP@)&AE861E<G,L("1B;V1Y
M*0H@("`@>PH@("`@("`@("\O(&EF('=E)W)E('!A<W-E9"!A;B!A<G)A>2!O
M9B!R96-I<&EE;G1S+"!I;7!L;V1E(&ET+@H@("`@("`@(&EF("AI<U]A<G)A
M>2@D<F5C:7!I96YT<RDI('L*("`@("`@("`@("`@)')E8VEP:65N=',@/2!I
M;7!L;V1E*"<L("<L("1R96-I<&EE;G1S*3L*("`@("`@("!]"@H@("`@("`@
M("\O(&=E="!T:&4@4W5B:F5C="!O=70@;V8@=&AE(&AE861E<G,@87)R87D@
M<V\@=&AA="!W92!C86X*("`@("`@("`O+R!P87-S(&ET(&%S(&$@<V5P97)A
M=&4@87)G=6UE;G0@=&\@;6%I;"@I+@H@("`@("`@("1S=6)J96-T(#T@)R<[
M"B`@("`@("`@:68@*&ES<V5T*"1H96%D97)S6R=3=6)J96-T)UTI*2!["B`@
M("`@("`@("`@("1S=6)J96-T(#T@)&AE861E<G-;)U-U8FIE8W0G73L*("`@
M("`@("`@("`@=6YS970H)&AE861E<G-;)U-U8FIE8W0G72D["B`@("`@("`@
M?0H*("`@("`@("`O+R!F;&%T=&5N('1H92!H96%D97)S(&]U="X*("`@("`@
M("!L:7-T*"PD=&5X=%]H96%D97)S*2`]($UA:6PZ.G!R97!A<F5(96%D97)S
M*"1H96%D97)S*3L*"B`@("`@("`@<F5T=7)N(&UA:6PH)')E8VEP:65N=',L
M("1S=6)J96-T+"`D8F]D>2P@)'1E>'1?:&5A9&5R<RD["@H@("`@?0H*("`@
M("\J*@H@("`@("H@5&%K92!A;B!A<G)A>2!O9B!M86EL(&AE861E<G,@86YD
M(')E='5R;B!A('-T<FEN9R!C;VYT86EN:6YG"B`@("`@*B!T97AT('5S86)L
M92!I;B!S96YD:6YG(&$@;65S<V%G92X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E<G,@=&\@<')E<&%R
M92P@:6X@86X@87-S;V-I871I=F4*("`@("`J("`@("`@("`@("`@("!A<G)A
M>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4@:&5A9&5R(&YA;64@*&EE
M+`H@("`@("H@("`@("`@("`@("`@("=3=6)J96-T)RDL(&%N9"!T:&4@87)R
M87D@=F%L=64@:7,@=&AE(&AE861E<@H@("`@("H@("`@("`@("`@("`@('9A
M;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E<B!P<F]D=6-E9"!F<F]M('1H
M;W-E"B`@("`@*B`@("`@("`@("`@("`@=F%L=65S('=O=6QD(&)E("=3=6)J
M96-T.B!T97-T)RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R
M;G,@9F%L<V4@:68@:70@96YC;W5N=&5R<R!A(&)A9"!A9&1R97-S+`H@("`@
M("H@("`@("`@("`@("`@("!O=&AE<G=I<V4@<F5T=7)N<R!A;B!A<G)A>2!C
M;VYT86EN:6YG('1W;PH@("`@("H@("`@("`@("`@("`@("!E;&5M96YT<SH@
M06YY($9R;VTZ(&%D9')E<W,@9F]U;F0@:6X@=&AE(&AE861E<G,L"B`@("`@
M*B`@("`@("`@("`@("`@(&%N9"!T:&4@<&QA:6X@=&5X="!V97)S:6]N(&]F
M('1H92!H96%D97)S+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N('!R97!A<F5(96%D97)S*"1H96%D97)S*0H@("`@>PH@
M("`@("`@("1L:6YE<R`](&%R<F%Y*"D["B`@("`@("`@)&9R;VT@/2!N=6QL
M.PH*("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("!I9B`H<W1R8V%S96-M<"@D:V5Y+"`G1G)O;2<I
M(#T]/2`P*2!["B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TUA:6PO
M4D9#.#(R+G!H<"<["B`@("`@("`@("`@("`@("`D<&%R<V5R(#T@)FYE=R!-
M86EL7U)&0S@R,B@I.PH@("`@("`@("`@("`@("`@)&%D9')E<W-E<R`]("1P
M87)S97(M/G!A<G-E061D<F5S<TQI<W0H)'9A;'5E+"`G;&]C86QH;W-T)RP@
M9F%L<V4I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&%D
M9')E<W-E<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&%D9')E
M<W-E<SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D9G)O
M;2`]("1A9&1R97-S97-;,%TM/FUA:6QB;W@@+B`G0"<@+B`D861D<F5S<V5S
M6S!=+3YH;W-T.PH*("`@("`@("`@("`@("`@("\O(%)E:F5C="!E;G9E;&]P
M92!&<F]M.B!A9&1R97-S97,@=VET:"!S<&%C97,N"B`@("`@("`@("`@("`@
M("!I9B`H<W1R<W1R*"1F<F]M+"`G("<I*2!["B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1L:6YE<UM=(#T@)&ME>2`N("<Z("<@+B`D=F%L=64["B`@("`@
M("`@("`@('T@96QS96EF("AS=')C87-E8VUP*"1K97DL("=296-E:79E9"<I
M(#T]/2`P*2!["B`@("`@("`@("`@("`@("`D<F5C96EV960@/2!A<G)A>2@I
M.PH@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1V86QU92DI('L*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&QI;F4I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E8V5I=F5D6UT@/2`D:V5Y("X@
M)SH@)R`N("1L:6YE.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("1R96-E:79E9%M=(#T@)&ME>2`N("<Z("<@+B`D=F%L=64["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`O+R!0=70@4F5C96EV
M960Z(&AE861E<G,@870@=&AE('1O<"X@(%-P86T@9&5T96-T;W)S(&]F=&5N
M"B`@("`@("`@("`@("`@("`O+R!F;&%G(&UE<W-A9V5S('=I=&@@4F5C96EV
M960Z(&AE861E<G,@869T97(@=&AE(%-U8FIE8W0Z"B`@("`@("`@("`@("`@
M("`O+R!A<R!S<&%M+@H@("`@("`@("`@("`@("`@)&QI;F5S(#T@87)R87E?
M;65R9V4H)')E8V5I=F5D+"`D;&EN97,I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@+R\@268@)'9A;'5E(&ES(&%N(&%R<F%Y("AI
M+F4N+"!A(&QI<W0@;V8@861D<F5S<V5S*2P@8V]N=F5R=`H@("`@("`@("`@
M("`@("`@+R\@:70@=&\@82!C;VUM82UD96QI;6ET960@<W1R:6YG(&]F(&ET
M<R!E;&5M96YT<R`H861D<F5S<V5S*2X*("`@("`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M(#T@:6UP;&]D92@G+"`G+"`D=F%L=64I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@)&QI;F5S6UT@/2`D:V5Y("X@)SH@)R`N("1V86QU
M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1F<F]M+"!J;VEN*"1T:&ES+3YS97`L("1L:6YE<RD@+B`D=&AI<RT^
M<V5P*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1A:V4@82!S970@;V8@<F5C
M:7!I96YT<R!A;F0@<&%R<V4@=&AE;2P@<F5T=7)N:6YG(&%N(&%R<F%Y(&]F
M"B`@("`@*B!B87)E(&%D9')E<W-E<R`H9F]R=V%R9"!P871H<RD@=&AA="!C
M86X@8F4@<&%S<V5D('1O('-E;F1M86EL"B`@("`@*B!O<B!A;B!S;71P('-E
M<G9E<B!W:71H('1H92!R8W!T('1O.B!C;VUM86YD+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"!%:71H97(@82!C;VUM82US97!E<F%T960@;&ES="!O
M9B!R96-I<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&0S@R,B!C;VUP
M;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@("H@("`@
M("`@("`@("`@(&5A8V@@4D9#.#(R('9A;&ED+@H@("`@("H*("`@("`J($!R
M971U<FX@87)R87D@06X@87)R87D@;V8@9F]R=V%R9"!P871H<R`H8F%R92!A
M9&1R97-S97,I+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N('!A<G-E4F5C:7!I96YT<R@D<F5C:7!I96YT<RD*("`@('L*
M("`@("`@("!I;F-L=61E7V]N8V4@)TUA:6PO4D9#.#(R+G!H<"<["@H@("`@
M("`@("\O(&EF('=E)W)E('!A<W-E9"!A;B!A<G)A>2P@87-S=6UE(&%D9')E
M<W-E<R!A<F4@=F%L:60@86YD"B`@("`@("`@+R\@:6UP;&]D92!T:&5M(&)E
M9F]R92!P87)S:6YG+@H@("`@("`@(&EF("AI<U]A<G)A>2@D<F5C:7!I96YT
M<RDI('L*("`@("`@("`@("`@)')E8VEP:65N=',@/2!I;7!L;V1E*"<L("<L
M("1R96-I<&EE;G1S*3L*("`@("`@("!]"@H@("`@("`@("\O(%!A<G-E(')E
M8VEP:65N=',L(&QE879I;F<@;W5T(&%L;"!P97)S;VYA;"!I;F9O+B!4:&ES
M(&ES"B`@("`@("`@+R\@9F]R('-M='`@<F5C:7!I96YT<RP@971C+B!!;&P@
M<F5L979A;G0@<&5R<V]N86P@:6YF;W)M871I;VX*("`@("`@("`O+R!S:&]U
M;&0@86QR96%D>2!B92!I;B!T:&4@:&5A9&5R<RX*("`@("`@("`D861D<F5S
M<V5S(#T@36%I;%]21D,X,C(Z.G!A<G-E061D<F5S<TQI<W0H)')E8VEP:65N
M=',L("=L;V-A;&AO<W0G+"!F86QS92D["B`@("`@("`@)')E8VEP:65N=',@
M/2!A<G)A>2@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D861D<F5S<V5S*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D861D<F5S<V5S(&%S("1O8BD@>PH@
M("`@("`@("`@("`@("`@)')E8VEP:65N='-;72`]("1O8BT^;6%I;&)O>"`N
M("=`)R`N("1O8BT^:&]S=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R96-I<&EE;G1S.PH@("`@?0H*?0H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]&:6QE+G!H<```````````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0P,3`R(#$P-3$U-#,T,3,U(#`R,#`U
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($9I;&4*("H@"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("`@1FEL
M90H@*B!`<&%C:V%G92`@("`@1FEL90H@*B!`875T:&]R("`@("`@4FEC:&%R
M9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@H@*B!`875T:&]R("`@("`@5&%L
M(%!E97(@/'1A;$!P:'`N;F5T/@H@*B!`875T:&]R("`@("`@36EC:&%E;"!7
M86QL;F5R(#QM:6ME0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`R+3(P
M,#4@5&AE($%U=&AO<G,*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("`@0U93.B`D260Z($9I;&4N<&AP+'8@,2XS,2`R,#`U+S`W+S(Q
M(#`W.C4S.C`Y(&UI:V4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]&:6QE"B`J+PH*+RHJ"B`J(%)E<75I<F5S
M(%!%05(*("HO"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J(%1H
M92!D969A=6QT(&YU;6)E<B!O9B!B>71E<R!F;W(@<F5A9&EN9PH@*B\*:68@
M*"%D969I;F5D*"=&24Q%7T1%1D%53%1?4D5!1%-)6D4G*2D@>PH@("`@9&5F
M:6YE*"=&24Q%7T1%1D%53%1?4D5!1%-)6D4G+"`Q,#(T+"!T<G5E*3L*?0H*
M+RHJ"B`J(%1H92!M87AI;75M(&YU;6)E<B!O9B!B>71E<R!F;W(@<F5A9&EN
M9R!L:6YE<PH@*B\*:68@*"%D969I;F5D*"=&24Q%7TU!6%],24Y%7U)%0413
M25I%)RDI('L*("`@(&1E9FEN92@G1DE,15]-05A?3$E.15]214%$4TE:12<L
M(#0P.38P+"!T<G5E*3L*?0H*+RHJ"B`J(%=H971H97(@9FEL92!L;V-K<R!S
M:&]U;&0@8FQO8VL*("HO"FEF("@A9&5F:6YE9"@G1DE,15],3T-+4U]"3$]#
M2R<I*2!["B`@("!D969I;F4H)T9)3$5?3$]#2U-?0DQ/0TLG+"!T<G5E+"!T
M<G5E*3L*?0H*+RHJ"B`J($UO9&4@=&\@=7-E(&9O<B!R96%D:6YG(&9R;VT@
M9FEL97,*("HO"F1E9FEN92@G1DE,15]-3T1%7U)%040G+"`G<F(G+"!T<G5E
M*3L*"B\J*@H@*B!-;V1E('1O('5S92!F;W(@=')U;F-A=&EN9R!F:6QE<RP@
M=&AE;B!W<FET:6YG"B`J+PID969I;F4H)T9)3$5?34]$15]74DE412<L("=W
M8B<L('1R=64I.PH*+RHJ"B`J($UO9&4@=&\@=7-E(&9O<B!A<'!E;F1I;F<@
M=&\@9FEL97,*("HO"F1E9FEN92@G1DE,15]-3T1%7T%04$5.1"<L("=A8B<L
M('1R=64I.PH*+RHJ"B`J(%5S92!T:&ES('=H96X@82!S:&%R960@*')E860I
M(&QO8VL@:7,@<F5Q=6ER960*("HO"F1E9FEN92@G1DE,15],3T-+7U-(05)%
M1"<L($Q/0TM?4T@@?"`H1DE,15],3T-+4U]"3$]#2R`_(#`@.B!,3T-+7TY"
M*2P@=')U92D["@HO*BH*("H@57-E('1H:7,@=VAE;B!A;B!E>&-L=7-I=F4@
M*'=R:71E*2!L;V-K(&ES(')E<75I<F5D"B`J+PID969I;F4H)T9)3$5?3$]#
M2U]%6$-,55-)5D4G+"!,3T-+7T58('P@*$9)3$5?3$]#2U-?0DQ/0TL@/R`P
M(#H@3$]#2U].0BDL('1R=64I.PH*+RHJ"B`J($-L87-S(&9O<B!H86YD;&EN
M9R!F:6QE<PH@*B`*("H@02!C;&%S<R!W:71H(&-O;6UO;B!F=6YC=&EO;G,@
M9F]R('=R:71I;F<L"B`J(')E861I;F<@86YD(&AA;F1L:6YG(&9I;&5S(&%N
M9"!D:7)E8W1O<FEE<PH@*B`*("H@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9$!P:'`N;F5T/@H@*B!`875T:&]R("!486P@4&5E<B`\=&%L0'!H
M<"YN970^"B`J($!A=71H;W(@($UI8VAA96P@5V%L;&YE<B`\;6EK94!P:'`N
M;F5T/@H@*B!`86-C97-S("!P=6)L:6,@"B`J($!P86-K86=E($9I;&4*("H@
M"B`J($!S=&%T:6,*("HO"F-L87-S($9I;&4@97AT96YD<R!014%2(`I["B`@
M("`O*BH*("`@("`J($1E<W1R=6-T;W(*("`@("`J(`H@("`@("H@56YL;V-K
M<R!A;GD@;&]C:V5D(&9I;&4@<&]I;G1E<G,@86YD(&-L;W-E<R!A;&P@9FEL
M97!O:6YT97)S"B`@("`@*B`*("`@("`J($!A8V-E<W,@<')I=F%T92`*("`@
M("`J+PH@("`@9G5N8W1I;VX@7T9I;&4H*0H@("`@>PH@("`@("`@($9I;&4Z
M.F-L;W-E06QL*"D["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@2&%N9&QE
M<R!F:6QE('!O:6YT97)S+B!)9B!A(&9I;&4@<&]I;G1E<B!N965D<R!T;R!B
M92!O<&5N960L"B`@("`@*B!I="!W:6QL(&)E+B!)9B!I="!A;')E861Y(&5X
M:7-T<R`H8F%S960@;VX@9FEL96YA;64@86YD(&UO9&4I"B`@("`@*B!T:&5N
M('1H92!E>&ES=&EN9R!O;F4@=VEL;"!B92!R971U<FYE9"X*("`@("`J(`H@
M("`@("H@0&%C8V5S<R`@<')I=F%T92`*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)&9I;&5N86UE($9I;&5N86UE('1O(&)E('5S960*("`@("`J($!P87)A
M;2`@('-T<FEN9R`@)&UO9&4@36]D92!T;R!O<&5N('1H92!F:6QE(&EN"B`@
M("`@*B!`<&%R86T@("!M:7AE9"`@("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U
M<V4*("`@("`J($!R971U<FX@(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O
M<B!O<B!F:6QE('!O:6YT97(@<F5S;W5R8V4@;VX@<W5C8V5S<PH@("`@("HO
M"B`@("!F=6YC=&EO;B`F7V=E=$9I;&50;VEN=&5R*"1F:6QE;F%M92P@)&UO
M9&4L("1L;V-K(#T@9F%L<V4I"B`@("!["B`@("`@("`@)&9I;&50;VEN=&5R
M<R`]("9014%2.CIG9713=&%T:6-0<F]P97)T>2@G1FEL92<L("=F:6QE4&]I
M;G1E<G,G*3L*("`@("`@("`*("`@("`@("`O+R!7:6XS,B!I<R!C87-E+6EN
M<V5N<VET:79E"B`@("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@("`@("`@
M("`@)&9I;&5N86UE(#T@<W1R5&],;W=E<B@D9FEL96YA;64I.PH@("`@("`@
M('T*("`@("`@("`*("`@("`@("`O+R!C:&5C:R!I9B!F:6QE('!O:6YT97(@
M86QR96%D>2!E>&ES=',*("`@("`@("!I9B`H("`@("%I<W-E="@D9FEL95!O
M:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=*2!\?"`*("`@("`@("`@("`@("`@
M("%I<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=
M*2D@>PH@("`@("`@("`@("`*("`@("`@("`@("`@+R\@8VAE8VL@:68@=V4@
M8V%N(&]P96X@=&AE(&9I;&4@:6X@=&AE(&1E<VER960@;6]D90H@("`@("`@
M("`@("!S=VET8V@@*"1M;V1E*0H@("`@("`@("`@("!["B`@("`@("`@("`@
M("`@("!C87-E($9)3$5?34]$15]214%$.@H@("`@("`@("`@("`@("`@("`@
M(&EF("@@("`@(7!R96=?;6%T8V@H)R]>+BLH/SPA9FEL92DZ7"]<+R]I)RP@
M)&9I;&5N86UE*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(69I
M;&5?97AI<W1S*"1F:6QE;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D9I;&4@9&]E<R!N;W0@97AI
M<W0Z("1F:6QE;F%M92(I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@
M("`@("!C87-E($9)3$5?34]$15]!4%!%3D0Z"B`@("`@("`@("`@("`@("!C
M87-E($9)3$5?34]$15]74DE413H*("`@("`@("`@("`@("`@("`@("!I9B`H
M9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES7W=R:71A8FQE*"1F:6QE;F%M92DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&
M:6QE(&ES(&YO="!W<FET86)L93H@)&9I;&5N86UE(BD["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M(6ES7W=R:71A8FQE*"1D:7(@/2!D:7)N86UE*"1F:6QE;F%M92DI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*")#86YN;W0@8W)E871E(&9I;&4@:6X@9&ER96-T;W)Y.B`D9&ER(BD["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`*("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(DEN=F%L
M:60@86-C97-S(&UO9&4Z("1M;V1E(BD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@"B`@("`@("`@("`@("\O(&]P96X@9FEL90H@("`@("`@("`@("`D
M9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=(#T@0&9O<&5N*"1F:6QE
M;F%M92P@)&UO9&4I.PH@("`@("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1F
M:6QE4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G1F%I;&5D('1O(&]P96X@
M9FEL93H@)R`N("1F:6QE;F%M92D["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@+R\@;&]C:R!F:6QE"B`@("`@("`@:68@*"1L
M;V-K*2!["B`@("`@("`@("`@("1L;V-K(#T@)&UO9&4@/3T@1DE,15]-3T1%
M7U)%040@/R!&24Q%7TQ/0TM?4TA!4D5$(#H@1DE,15],3T-+7T580TQ54TE6
M13L*("`@("`@("`@("`@)&QO8VMS(#T@)E!%05(Z.F=E=%-T871I8U!R;W!E
M<G1Y*"=&:6QE)RP@)VQO8VMS)RD["B`@("`@("`@("`@(&EF("A`9FQO8VLH
M)&9I;&50;VEN=&5R<ULD9FEL96YA;65=6R1M;V1E72P@)&QO8VLI*2!["B`@
M("`@("`@("`@("`@("`D;&]C:W-;72`]("8D9FEL95!O:6YT97)S6R1F:6QE
M;F%M95U;)&UO9&5=.PH@("`@("`@("`@("!](&5L<V5I9B`H1DE,15],3T-+
M4U]"3$]#2RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H(D9I;&4@86QR96%D>2!L;V-K960Z("1F:6QE;F%M92(I.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(D-O=6QD(&YO="!L;V-K(&9I;&4Z("1F:6QE;F%M92(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(')E
M='5R;B`D9FEL95!O:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=.PH@("`@?2`*
M"B`@("`O*BH*("`@("`J(%)E861S(&%N(&5N=&ER92!F:6QE(&%N9"!R971U
M<FYS(&ET+@H@("`@("H@57-E<R!F:6QE7V=E=%]C;VYT96YT<R!I9B!A=F%I
M;&%B;&4N"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@)&9I;&5N86UE($YA;64@;V8@9FEL92!T;R!R
M96%D(&9R;VT*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&QO8VL@5'EP92!O
M9B!L;V-K('1O('5S90H@("`@("H@0')E='5R;B`@;6EX960@("!014%27T5R
M<F]R(&EF(&%N(&5R<F]R(&AA<R!O8V-U<F5D(&]R(&$@<W1R:6YG('=I=&@@
M=&AE(&-O;G1E;G1S(&]F('1H92!T:&4@9FEL90H@("`@("HO"B`@("!F=6YC
M=&EO;B!R96%D06QL*"1F:6QE;F%M92P@)&QO8VL@/2!F86QS92D*("`@('L*
M("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT
M<R<I*2!["B`@("`@("`@("`@(&EF("AF86QS92`]/3T@)&9I;&4@/2!`9FEL
M95]G971?8V]N=&5N=',H)&9I;&5N86UE*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!R96%D(&9I;&4Z("1F
M:6QE;F%M92(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M9FEL93L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)&9I;&4@/2`G)SL*
M("`@("`@("!W:&EL92`H9F%L<V4@(3T]("1B=68@/2!&:6QE.CIR96%D*"1F
M:6QE;F%M92P@1DE,15]$149!54Q47U)%041325I%+"`D;&]C:RDI('L*("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&)U9BDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1F:6QE("X]("1B=68["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("\O
M(&-L;W-E('1H92!F:6QE('!O:6YT97(*("`@("`@("!&:6QE.CIC;&]S92@D
M9FEL96YA;64L($9)3$5?34]$15]214%$*3L*("`@("`@("`*("`@("`@("!R
M971U<FX@)&9I;&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@
M<W!E8VEF:65D(&YU;6)E<B!O9B!B>71E<R!O9B!A(&9I;&4N(`H@("`@("H@
M1&5F875L=',@=&\@1DE,15]$149!54Q47U)%041325I%+B`@268@)'-I>F4@
M:7,@,"P@86QL(&9I;&4@=VEL;"!B92!R96%D+@H@("`@("H@"B`@("`@*B!`
M86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1F:6QE
M;F%M92!.86UE(&]F(&9I;&4@=&\@<F5A9"!F<F]M"B`@("`@*B!`<&%R86T@
M("!I;G1E9V5R("1S:7IE($)Y=&5S('1O(')E860*("`@("`J($!P87)A;2`@
M(&UI>&5D("`@)&QO8VL@5'EP92!O9B!L;V-K('1O('5S90H@("`@("H@0')E
M='5R;B`@;6EX960@("!014%27T5R<F]R(&]N(&5R<F]R(&]R(&$@<W1R:6YG
M('=H:6-H(&-O;G1A:6YS('1H92!D871A(')E860*("`@("`J("`@("`@("`@
M("`@("`@("`@5VEL;"!A;'-O(')E='5R;B!F86QS92!U<&]N($5/1@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96%D*"1F:6QE;F%M92P@)'-I>F4@/2!&24Q%
M7T1%1D%53%1?4D5!1%-)6D4L("1L;V-K(#T@9F%L<V4I"B`@("!["B`@("`@
M("`@<W1A=&EC("1F:6QE4&]I;G1E<G,["B`@("`@("`@"B`@("`@("`@:68@
M*#`@/3T@)'-I>F4I('L*("`@("`@("`@("`@<F5T=7)N($9I;&4Z.G)E861!
M;&PH)&9I;&5N86UE+"`D;&]C:RD["B`@("`@("`@?2`*"B`@("`@("`@:68@
M*"`@("`A:7-S970H)&9I;&50;VEN=&5R<ULD9FEL96YA;65=*2!\?"`*("`@
M("`@("`@("`@("`@("%I<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F:6QE
M;F%M95TI*2!["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F<"`]
M("9&:6QE.CI?9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"!&24Q%7TU/1$5?
M4D5!1"P@)&QO8VLI*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F<#L*
M("`@("`@("`@("`@?2`*"B`@("`@("`@("`@("1F:6QE4&]I;G1E<G-;)&9I
M;&5N86UE72`]("8D9G`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&9P(#T@)B1F:6QE4&]I;G1E<G-;)&9I;&5N86UE73L*("`@("`@("!](`H*
M("`@("`@("!R971U<FX@(69E;V8H)&9P*2`_(&9R96%D*"1F<"P@)'-I>F4I
M(#H@9F%L<V4["B`@("!](`H*("`@("\J*@H@("`@("H@5W)I=&5S('1H92!G
M:79E;B!D871A('1O('1H92!G:79E;B!F:6QE;F%M92X@"B`@("`@*B!$969A
M=6QT<R!T;R!N;R!L;V-K+"!A<'!E;F0@;6]D92X*("`@("`J(`H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL
M96YA;64@3F%M92!O9B!F:6QE('1O('=R:71E('1O"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1D871A($1A=&$@=&\@=W)I=&4@=&\@9FEL90H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`D;6]D92!-;V1E('1O(&]P96X@9FEL92!I;@H@
M("`@("H@0'!A<F%M("`@;6EX960@("`D;&]C:R!4>7!E(&]F(&QO8VL@=&\@
M=7-E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R
M;W(@;W(@;G5M8F5R(&]F(&)Y=&5S('=R:71T96X@=&\@9FEL92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@=W)I=&4H)&9I;&5N86UE+"`D9&%T82P@)&UO9&4@
M/2!&24Q%7TU/1$5?05!014Y$+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1F<"`]("9&:6QE.CI?9V5T1FEL95!O
M:6YT97(H)&9I;&5N86UE+"`D;6]D92P@)&QO8VLI*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&9P.PH@("`@("`@('T*("`@("`@("!I9B`H+3$@/3T]("1B
M>71E<R`]($!F=W)I=&4H)&9P+"`D9&%T82P@<W1R;&5N*"1D871A*2DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!W
M<FET92!D871A.B`G)&1A=&$G('1O(&9I;&4Z("<D9FEL96YA;64G(BD["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D8GET97,["B`@("!](`H*("`@("\J
M*@H@("`@("H@4F5A9',@86YD(')E='5R;G,@82!S:6YG;&4@8VAA<F%C=&5R
M(&9R;VT@9VEV96X@9FEL96YA;64*("`@("`J(`H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@3F%M
M92!O9B!F:6QE('1O(')E860@9G)O;0H@("`@("H@0'!A<F%M("`@;6EX960@
M("`D;&]C:R!4>7!E(&]F(&QO8VL@=&\@=7-E"B`@("`@*B!`<F5T=7)N("!M
M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R;W(@;W(@;VYE(&-H87)A8W1E<B!O
M9B!T:&4@<W!E8VEF:65D(&9I;&4*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A
M9$-H87(H)&9I;&5N86UE+"`D;&]C:R`](&9A;'-E*0H@("`@>PH@("`@("`@
M(')E='5R;B!&:6QE.CIR96%D*"1F:6QE;F%M92P@,2P@)&QO8VLI.PH@("`@
M?2`*"B`@("`O*BH*("`@("`J(%=R:71E<R!A('-I;F=L92!C:&%R86-T97(@
M=&\@82!F:6QE"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8R`*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N86UE($YA;64@;V8@9FEL92!T
M;R!W<FET92!T;PH@("`@("H@0'!A<F%M("`@<W1R:6YG("`D8VAA<B!#:&%R
M86-T97(@=&\@=W)I=&4*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&UO9&4@
M36]D92!T;R!U<V4@=VAE;B!W<FET:6YG"B`@("`@*B!`<&%R86T@("!M:7AE
M9"`@("1L;V-K(%1Y<&4@;V8@;&]C:R!T;R!U<V4*("`@("`J($!R971U<FX@
M(&UI>&5D("`@4$5!4E]%<G)O<B!O;B!E<G)O<BP@;W(@,2!O;B!S=6-C97-S
M"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E0VAA<B@D9FEL96YA;64L("1C
M:&%R+"`D;6]D92`]($9)3$5?34]$15]!4%!%3D0L("1L;V-K(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9P(#T@)D9I;&4Z
M.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M;V1E+"`D;&]C:RDI*2![
M"B`@("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@("`@(&EF
M("@M,2`]/3T@0&9W<FET92@D9G`L("1C:&%R+"`Q*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T('=R:71E(&1A=&$Z
M("<D9&%T82<@=&\@9FEL93H@)R1F:6QE;F%M92<B*3L*("`@("`@("!]"B`@
M("`@("`@<F5T=7)N(#$["B`@("!](`H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!A(&QI;F4@;V8@=&AE(&9I;&4@*'=I=&AO=70@=')A:6QI;F<@0U),1BDN
M"B`@("`@*B!-87AI;75M(')E860@;&EN92!L96YG=&@@:7,@1DE,15]-05A?
M3$E.15]214%$4TE:12X*("`@("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9FEL96YA;64@3F%M92!O9B!F
M:6QE('1O(')E860@9G)O;0H@("`@("H@0'!A<F%M("`@8F]O;&5A;B`D;&]C
M:R!7:&5T:&5R(&9I;&4@<VAO=6QD(&)E(&QO8VME9`H@("`@("H@0')E='5R
M;B`@;6EX960@("!014%27T5R<F]R(&]N(&5R<F]R(&]R(&$@<W1R:6YG(&-O
M;G1A:6YI;F<@=&AE(&QI;F4@<F5A9"!F<F]M(&9I;&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5A9$QI;F4H)&9I;&5N86UE+"`D;&]C:R`](&9A;'-E*0H@
M("`@>PH@("`@("`@('-T871I8R`D9FEL95!O:6YT97)S.R`O+R!5<V5D('1O
M('!R979E;G0@=6YN96-E<W-A<GD@8V%L;',@=&\@7V=E=$9I;&50;VEN=&5R
M*"D*("`@("`@("`*("`@("`@("!I9B`H("`@("%I<W-E="@D9FEL95!O:6YT
M97)S6R1F:6QE;F%M95TI('Q\(`H@("`@("`@("`@("`@("`@(6ES7W)E<V]U
M<F-E*"1F:6QE4&]I;G1E<G-;)&9I;&5N86UE72DI('L*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&9P(#T@)D9I;&4Z.E]G971&:6QE4&]I;G1E
M<B@D9FEL96YA;64L($9)3$5?34]$15]214%$+"`D;&]C:RDI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)&9P.PH@("`@("`@("`@("!](`H*("`@("`@
M("`@("`@)&9I;&50;VEN=&5R<ULD9FEL96YA;65=(#T@)B1F<#L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D9G`@/2`F)&9I;&50;VEN=&5R<ULD
M9FEL96YA;65=.PH@("`@("`@('T@"@H@("`@("`@(&EF("AF96]F*"1F<"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@"B`@("`@
M("`@"B`@("`@("`@<F5T=7)N(')T<FEM*&9G971S*"1F<"P@1DE,15]-05A?
M3$E.15]214%$4TE:12DL(")<<EQN(BD["B`@("!](`H*("`@("\J*@H@("`@
M("H@5W)I=&5S(&$@<VEN9VQE(&QI;F4L(&%P<&5N9&EN9R!A($Q&("AB>2!D
M969A=6QT*0H@("`@("H@"B`@("`@*B!`86-C97-S("!P=6)L:6,@"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("1F:6QE;F%M92!.86UE(&]F(&9I;&4@=&\@
M=W)I=&4@=&\*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&QI;F4@3&EN92!O
M9B!D871A('1O(&)E('=R:71T96X@=&\@9FEL90H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D;6]D92!7<FET92!M;V1E+"!C86X@8F4@96ET:&5R($9)3$5?
M34]$15]74DE412!O<B!&24Q%7TU/1$5?05!014Y$"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1C<FQF(%1H92!#4DQ&('EO=7(@<WES=&5M(&ES('5S:6YG
M+B!53DE8(#T@7&X@5VEN9&]W<R`](%QR7&X@36%C(#T@7'(*("`@("`J($!P
M87)A;2`@(&UI>&5D("`@)&QO8VL@5VAE=&AE<B!T;R!L;V-K('1H92!F:6QE
M"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@(%!%05)?17)R;W(@;VX@97)R;W(@
M;W(@;G5M8F5R(&]F(&)Y=&5S('=R:71T96X@=&\@9FEL92`H:6YC;'5D:6YG
M(&%P<&5N9&5D(&-R;&8I"B`@("`@*B\*("`@(&9U;F-T:6]N('=R:71E3&EN
M92@D9FEL96YA;64L("1L:6YE+"`D;6]D92`]($9)3$5?34]$15]!4%!%3D0L
M("1C<FQF(#T@(EQN(BP@)&QO8VL@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R
M*"1F:6QE;F%M92P@)&UO9&4L("1L;V-K*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1F<#L*("`@("`@("!]"B`@("`@("`@:68@*"TQ(#T]/2`D8GET97,@
M/2!F=W)I=&4H)&9P+"`D;&EN92`N("1C<FQF*2D@>PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T('=R:71E(&1A=&$Z("<D
M9&%T82<@=&\@9FEL93H@)R1F:6QE)R(I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)&)Y=&5S.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%1H:7,@<F5W
M:6YD<R!A(&9I;&5P;VEN=&5R('1O('1H92!S=&%R="!O9B!A(&9I;&4*("`@
M("`J(`H@("`@("H@0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`D9FEL96YA;64@5&AE(&9I;&5N86UE"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("1M;V1E($UO9&4@=&AE(&9I;&4@=V%S(&]P96YE9"!I;@H@
M("`@("H@0')E='5R;B`@;6EX960@("!014%2($5R<F]R(&]N(&5R<F]R+"!T
M<G5E(&]N('-U8V-E<W,*("`@("`J+PH@("`@9G5N8W1I;VX@<F5W:6YD*"1F
M:6QE;F%M92P@)&UO9&4I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&9P(#T@)D9I;&4Z.E]G971&:6QE4&]I;G1E<B@D9FEL96YA;64L("1M
M;V1E*2DI('L*("`@("`@("`@("`@<F5T=7)N("1F<#L*("`@("`@("!]"B`@
M("`@("`@:68@*"%`<F5W:6YD*"1F<"DI('L*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!R97=I;F0@9FEL93H@)&9I;&5N
M86UE(BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2`*
M"B`@("`O*BH*("`@("`J($-L;W-E<R!A;&P@;W!E;B!F:6QE('!O:6YT97)S
M"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R
M;B`@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S94%L;"@I"B`@("![
M"B`@("`@("`@)&QO8VMS(#T@)E!%05(Z.F=E=%-T871I8U!R;W!E<G1Y*"=&
M:6QE)RP@)VQO8VMS)RD["B`@("`@("`@)&9I;&50;VEN=&5R<R`]("9014%2
M.CIG9713=&%T:6-0<F]P97)T>2@G1FEL92<L("=F:6QE4&]I;G1E<G,G*3L*
M("`@("`@("`*("`@("`@("`O+R!U;FQO8VL@9FEL97,*("`@("`@("!F;W(@
M*"1I(#T@,"P@)&,@/2!C;W5N="@D;&]C:W,I.R`D:2`\("1C.R`D:2LK*2![
M"B`@("`@("`@("`@(&ES7W)E<V]U<F-E*"1L;V-K<ULD:5TI(&%N9"!`9FQO
M8VLH)&QO8VMS6R1I72P@3$]#2U]53BD["B`@("`@("`@?0H@("`@("`@(`H@
M("`@("`@("\O(&-L;W-E(&9I;&5S"B`@("`@("`@:68@*"%E;7!T>2@D9FEL
M95!O:6YT97)S*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D9FEL95!O:6YT
M97)S(&%S("1F;F%M92`]/B`D;6]D97,I('L*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*&%R<F%Y7VME>7,H)&UO9&5S*2!A<R`D;6]D92D@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]R97-O=7)C92@D9FEL95!O:6YT97)S6R1F
M;F%M95U;)&UO9&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!`9F-L
M;W-E*"1F:6QE4&]I;G1E<G-;)&9N86UE75LD;6]D95TI.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9FEL95!O
M:6YT97)S6R1F;F%M95U;)&UO9&5=*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(`H@("`@+RHJ"B`@("`@
M*B!4:&ES(&-L;W-E<R!A;B!O<&5N(&9I;&4@<&]I;G1E<@H@("`@("H@"B`@
M("`@*B!`86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("1F:6QE;F%M92!4:&4@9FEL96YA;64@=&AA="!W87,@;W!E;F5D"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("1M;V1E($UO9&4@=&AE(&9I;&4@=V%S(&]P
M96YE9"!I;@H@("`@("H@0')E='5R;B`@;6EX960@("!014%2($5R<F]R(&]N
M(&5R<F]R+"!T<G5E(&]T:&5R=VES90H@("`@("HO"B`@("!F=6YC=&EO;B!C
M;&]S92@D9FEL96YA;64L("1M;V1E*0H@("`@>PH@("`@("`@("1F:6QE4&]I
M;G1E<G,@/2`F4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)T9I;&4G+"`G9FEL
M95!O:6YT97)S)RD["B`@("`@("`@"B`@("`@("`@:68@*$]37U=)3D1/5U,I
M('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@<W1R5&],;W=E<B@D9FEL96YA
M;64I.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1F:6QE4&]I;G1E
M<G-;)&9I;&5N86UE75LD;6]D95TI*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D9G`@/2`D9FEL95!O
M:6YT97)S6R1F:6QE;F%M95U;)&UO9&5=.PH@("`@("`@('5N<V5T*"1F:6QE
M4&]I;G1E<G-;)&9I;&5N86UE75LD;6]D95TI.PH@("`@("`@(`H@("`@("`@
M(&EF("AI<U]R97-O=7)C92@D9G`I*2!["B`@("`@("`@("`@("\O('5N;&]C
M:R!F:6QE"B`@("`@("`@("`@($!F;&]C:R@D9G`L($Q/0TM?54XI.PH@("`@
M("`@("`@("`O+R!C;&]S92!F:6QE"B`@("`@("`@("`@(&EF("@A0&9C;&]S
M92@D9G`I*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@B0V%N;F]T(&-L;W-E(&9I;&4Z("1F:6QE;F%M92(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?2`*"B`@("`O*BH*("`@("`J(%1H:7,@=6YL;V-K<R!A(&QO8VME
M9"!F:6QE('!O:6YT97(N"B`@("`@*B`*("`@("`J($!A8V-E<W,@('!U8FQI
M8R`*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&9I;&5N86UE(%1H92!F:6QE
M;F%M92!T:&%T('=A<R!O<&5N960*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M)&UO9&4@36]D92!T:&4@9FEL92!W87,@;W!E;F5D(&EN"B`@("`@*B!`<F5T
M=7)N("!M:7AE9"`@(%!%05(@17)R;W(@;VX@97)R;W(L('1R=64@;W1H97)W
M:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N('5N;&]C:R@D9FEL96YA;64L("1M
M;V1E*0H@("`@>PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1F<"`]("9&
M:6QE.CI?9V5T1FEL95!O:6YT97(H)&9I;&5N86UE+"`D;6]D92DI*2!["B`@
M("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@("`@(&EF("@A
M0&9L;V-K*"1F<"P@3$]#2U]53BDI('L*("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H(D-A8VYN;W0@=6YL;V-K(&9I;&4Z("1F:6QE;F%M
M92(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T@"@H@
M("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC=&EO
M;B!S=')I<%1R86EL:6YG4V5P87)A=&]R<R@D<&%T:"P@)'-E<&%R871O<B`]
M($1)4D5#5$]265]315!!4D%43U(I"B`@("!["B`@("`@("`@<F5T=7)N(')T
M<FEM*"1P871H+"`D<V5P87)A=&]R*3L*("`@('T@"@H@("`@+RHJ"B`@("`@
M*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC=&EO;B!S=')I<$QE861I
M;F=397!A<F%T;W)S*"1P871H+"`D<V5P87)A=&]R(#T@1$E214-43U)97U-%
M4$%2051/4BD*("`@('L*("`@("`@("!R971U<FX@;'1R:6TH)'!A=&@L("1S
M97!A<F%T;W(I.PH@("`@?2`*"B`@("`O*BH*("`@("`J($!D97!R96-A=&5D
M("`@("`@57-E($9I;&5?571I;#HZ8G5I;&10871H*"D@:6YS=&5A9"X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8G5I;&10871H*"1P87)T<RP@)'-E<&%R871O
M<B`]($1)4D5#5$]265]315!!4D%43U(I"B`@("!["B`@("`@("`@<F5Q=6ER
M95]O;F-E("=&:6QE+U5T:6PN<&AP)SL*("`@("`@("!R971U<FX@1FEL95]5
M=&EL.CIB=6EL9%!A=&@H)'!A<G1S+"`D<V5P87)A=&]R*3L*("`@('T@"@H@
M("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"`@("`@(%5S92!&:6QE7U5T:6PZ
M.G-K:7!2;V]T*"D@:6YS=&5A9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<VMI
M<%)O;W0H)'!A=&@I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE
M+U5T:6PN<&AP)SL*("`@("`@("!R971U<FX@1FEL95]5=&EL.CIS:VEP4F]O
M="@D<&%T:"D["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@
M("`@("!5<V4@1FEL95]5=&EL.CIT;7!$:7(H*2!I;G-T96%D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!G971496UP1&ER*"D*("`@('L*("`@("`@("!R97%U
M:7)E7V]N8V4@)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R;B!&:6QE
M7U5T:6PZ.G1M<$1I<B@I.PH@("`@?0H*("`@("\J*@H@("`@("H@0&1E<')E
M8V%T960@("`@("!5<V4@1FEL95]5=&EL.CIT;7!&:6QE*"D@:6YS=&5A9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5&5M<$9I;&4H)&1I<FYA;64@/2!N
M=6QL*0H@("`@>PH@("`@("`@(')E<75I<F5?;VYC92`G1FEL92]5=&EL+G!H
M<"<["B`@("`@("`@<F5T=7)N($9I;&5?571I;#HZ=&UP1FEL92@D9&ER;F%M
M92D["B`@("!](`H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@("`@("!5
M<V4@1FEL95]5=&EL.CII<T%B<V]L=71E*"D@:6YS=&5A9"X*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-!8G-O;'5T92@D<&%T:"D*("`@('L*("`@("`@("!R
M97%U:7)E7V]N8V4@)T9I;&4O571I;"YP:'`G.PH@("`@("`@(')E='5R;B!&
M:6QE7U5T:6PZ.FES06)S;VQU=&4H)'!A=&@I.PH@("`@?2`*"B`@("`O*BH*
M("`@("`J($!D97!R96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ<F5L871I
M=F50871H*"D@:6YS=&5A9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5L871I
M=F50871H*"1P871H+"`D<F]O="P@)'-E<&%R871O<B`]($1)4D5#5$]265]3
M15!!4D%43U(I"B`@("!["B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+U5T
M:6PN<&AP)SL*("`@("`@("!R971U<FX@1FEL95]5=&EL.CIR96QA=&EV95!A
M=&@H)'!A=&@L("1R;V]T+"`D<V5P87)A=&]R*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($!D97!R96-A=&5D("`@("`@57-E($9I;&5?571I;#HZ<F5A;'!A
M=&@H*2!I;G-T96%D+@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%L<&%T:"@D
M<&%T:"P@)'-E<&%R871O<B`]($1)4D5#5$]265]315!!4D%43U(I"B`@("![
M"B`@("`@("`@<F5Q=6ER95]O;F-E("=&:6QE+U5T:6PN<&AP)SL*("`@("`@
M("!R971U<FX@1FEL95]5=&EL.CIR96%L<&%T:"@D<&%T:"P@)'-E<&%R871O
M<BD["B`@("!]"GT*"E!%05(Z.G)E9VES=&5R4VAU=&1O=VY&=6YC*&%R<F%Y
M*"=&:6QE)RP@)U]&:6QE)RDI.PH*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(N<&AP````````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q,#4P-#4@,3`U,34T,S0Q,S4@,#$W-S,P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(%!%05(L('1H92!02%`@17AT96YS:6]N(&%N9"!!<'!L:6-A=&EO
M;B!297!O<VET;W)Y#0H@*@T*("H@4$5!4B!C;&%S<R!A;F0@4$5!4E]%<G)O
M<B!C;&%S<PT*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!0
M2%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%
M05(-"B`J($!A=71H;W(@("`@(%-T97)L:6YG($AU9VAE<R`\<W1E<FQI;F=`
M<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-6
M4SH@)$ED.B!014%2+G!H<"QV(#$N.3@@,C`P-B\P,2\R,R`P-3HS.#HP-2!C
M96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J*B-`*PT*("H@15)23U(@
M8V]N<W1A;G1S#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/4E]215154DXG+"`@
M("`@,2D[#0ID969I;F4H)U!%05)?15)23U)?4%))3E0G+"`@("`@(#(I.PT*
M9&5F:6YE*"=014%27T524D]27U1224='15(G+"`@("`T*3L-"F1E9FEN92@G
M4$5!4E]%4E)/4E]$244G+"`@("`@("`@."D[#0ID969I;F4H)U!%05)?15)2
M3U)?0T%,3$)!0TLG+"`@,38I.PT*+RHJ#0H@*B!705).24Y'.B!O8G-O;&5T
M90T*("H@0&1E<')E8V%T960-"B`J+PT*9&5F:6YE*"=014%27T524D]27T58
M0T505$E/3B<L(#,R*3L-"B\J*B-`+2HO#0ID969I;F4H)U!%05)?6D4R)RP@
M*&9U;F-T:6]N7V5X:7-T<R@G=F5R<VEO;E]C;VUP87)E)RD@)B8-"B`@("`@
M("`@("`@("`@("`@("`@=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I
M+"`B,BUD978B+"`B9V4B*2DI.PT*#0II9B`H<W5B<W1R*%!(4%]/4RP@,"P@
M,RD@/3T@)U=)3B<I('L-"B`@("!D969I;F4H)T]37U=)3D1/5U,G+"!T<G5E
M*3L-"B`@("!D969I;F4H)T]37U5.25@G+"`@("!F86QS92D[#0H@("`@9&5F
M:6YE*"=014%27T]3)RP@("`@)U=I;F1O=W,G*3L-"GT@96QS92![#0H@("`@
M9&5F:6YE*"=/4U]724Y$3U=3)RP@9F%L<V4I.PT*("`@(&1E9FEN92@G3U-?
M54Y)6"<L("`@('1R=64I.PT*("`@(&1E9FEN92@G4$5!4E]/4R<L("`@("=5
M;FEX)RD[("\O(&)L871A;G0@87-S=6UP=&EO;@T*?0T*#0HO+R!I;G-T86YT
M(&)A8VMW87)D<R!C;VUP871I8FEL:71Y#0II9B`H(61E9FEN960H)U!!5$A?
M4T5005)!5$]2)RDI('L-"B`@("!I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@
M("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SLG*3L-"B`@("!](&5L<V4@
M>PT*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SHG*3L-"B`@
M("!]#0I]#0H-"B1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G
M72`@("`@/2!014%27T524D]27U)%5%523CL-"B1'3$]"04Q36R=?4$5!4E]D
M969A=6QT7V5R<F]R7V]P=&EO;G,G72`@/2!%7U5315)?3D]424-%.PT*)$=,
M3T)!3%-;)U]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0G72`](&%R<F%Y
M*"D[#0HD1TQ/0D%,4ULG7U!%05)?<VAU=&1O=VY?9G5N8W,G72`@("`@("`@
M(#T@87)R87DH*3L-"B1'3$]"04Q36R=?4$5!4E]E<G)O<E]H86YD;&5R7W-T
M86-K)UT@("`@/2!A<G)A>2@I.PT*#0I`:6YI7W-E="@G=')A8VM?97)R;W)S
M)RP@=')U92D[#0H-"B\J*@T*("H@0F%S92!C;&%S<R!F;W(@;W1H97(@4$5!
M4B!C;&%S<V5S+B`@4')O=FED97,@<G5D:6UE;G1A<GD-"B`J(&5M=6QA=&EO
M;B!O9B!D97-T<G5C=&]R<RX-"B`J#0H@*B!)9B!Y;W4@=V%N="!A(&1E<W1R
M=6-T;W(@:6X@>6]U<B!C;&%S<RP@:6YH97)I="!014%2(&%N9"!M86ME(&$-
M"B`J(&1E<W1R=6-T;W(@;65T:&]D(&-A;&QE9"!?>6]U<F-L87-S;F%M92`H
M<V%M92!N86UE(&%S('1H90T*("H@8V]N<W1R=6-T;W(L(&)U="!W:71H(&$@
M(E\B('!R969I>"DN("!!;'-O+"!I;B!Y;W5R(&-O;G-T<G5C=&]R('EO=0T*
M("H@:&%V92!T;R!C86QL('1H92!014%2(&-O;G-T<G5C=&]R.B`D=&AI<RT^
M4$5!4B@I.RX-"B`J(%1H92!D97-T<G5C=&]R(&UE=&AO9"!W:6QL(&)E(&-A
M;&QE9"!W:71H;W5T('!A<F%M971E<G,N("!.;W1E('1H870-"B`J(&%T(&EN
M('-O;64@4T%022!I;7!L96UE;G1A=&EO;G,@*'-U8V@@87,@07!A8VAE*2P@
M86YY(&]U='!U="!D=7)I;F<-"B`J('1H92!R97%U97-T('-H=71D;W=N("AI
M;B!W:&EC:"!D97-T<G5C=&]R<R!A<F4@8V%L;&5D*2!S965M<R!T;R!B90T*
M("H@9&ES8V%R9&5D+B`@268@>6]U(&YE960@=&\@9V5T(&%N>2!D96)U9R!I
M;F9O<FUA=&EO;B!F<F]M('EO=7(-"B`J(&1E<W1R=6-T;W(L('5S92!E<G)O
M<E]L;V<H*2P@<WES;&]G*"D@;W(@<V]M971H:6YG('-I;6EL87(N#0H@*@T*
M("H@24U03U)404Y4(2!4;R!U<V4@=&AE(&5M=6QA=&5D(&1E<W1R=6-T;W)S
M('EO=2!N965D('1O(&-R96%T92!T:&4-"B`J(&]B:F5C=',@8GD@<F5F97)E
M;F-E.B`D;V)J(#TF(&YE=R!014%27V-H:6QD.PT*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O
M;6%S(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M964@("`@("`@(%!%05)?17)R;W(-"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!02%`@-"XP+C(-"B`J($!L:6YK("`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C;W)E+G!E87(N<&AP(V-O<F4N
M<&5A<BYP96%R#0H@*B\-"F-L87-S(%!%05(-"GL-"B`@("`O+R![>WL@<')O
M<&5R=&EE<PT*#0H@("`@+RHJ#0H@("`@("H@5VAE=&AE<B!T;R!E;F%B;&4@
M:6YT97)N86P@9&5B=6<@;65S<V%G97,N#0H@("`@("H-"B`@("`@*B!`=F%R
M("`@("!B;V]L#0H@("`@("H@0&%C8V5S<R`@<')I=F%T90T*("`@("`J+PT*
M("`@('9A<B`D7V1E8G5G(#T@9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@*B!$
M969A=6QT(&5R<F]R(&UO9&4@9F]R('1H:7,@;V)J96-T+@T*("`@("`J#0H@
M("`@("H@0'9A<B`@("`@:6YT#0H@("`@("H@0&%C8V5S<R`@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7V1E9F%U;'1?97)R;W)?;6]D92`](&YU;&P[
M#0H-"B`@("`O*BH-"B`@("`@*B!$969A=6QT(&5R<F]R(&]P=&EO;G,@=7-E
M9"!F;W(@=&AI<R!O8FIE8W0@=VAE;B!E<G)O<B!M;V1E#0H@("`@("H@:7,@
M4$5!4E]%4E)/4E]44DE'1T52+@T*("`@("`J#0H@("`@("H@0'9A<B`@("`@
M:6YT#0H@("`@("H@0&%C8V5S<R`@<')I=F%T90T*("`@("`J+PT*("`@('9A
M<B`D7V1E9F%U;'1?97)R;W)?;W!T:6]N<R`](&YU;&P[#0H-"B`@("`O*BH-
M"B`@("`@*B!$969A=6QT(&5R<F]R(&AA;F1L97(@*&-A;&QB86-K*2!F;W(@
M=&AI<R!O8FIE8W0L(&EF(&5R<F]R(&UO9&4@:7,-"B`@("`@*B!014%27T52
M4D]27T-!3$Q"04-++@T*("`@("`J#0H@("`@("H@0'9A<B`@("`@<W1R:6YG
M#0H@("`@("H@0&%C8V5S<R`@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D
M7V1E9F%U;'1?97)R;W)?:&%N9&QE<B`]("<G.PT*#0H@("`@+RHJ#0H@("`@
M("H@5VAI8V@@8VQA<W,@=&\@=7-E(&9O<B!E<G)O<B!O8FIE8W1S+@T*("`@
M("`J#0H@("`@("H@0'9A<B`@("`@<W1R:6YG#0H@("`@("H@0&%C8V5S<R`@
M<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V5R<F]R7V-L87-S(#T@)U!%
M05)?17)R;W(G.PT*#0H@("`@+RHJ#0H@("`@("H@06X@87)R87D@;V8@97AP
M96-T960@97)R;W)S+@T*("`@("`J#0H@("`@("H@0'9A<B`@("`@87)R87D-
M"B`@("`@*B!`86-C97-S("!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?
M97AP96-T961?97)R;W)S(#T@87)R87DH*3L-"@T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!#;VYS
M=')U8W1O<BX@(%)E9VES=&5R<R!T:&ES(&]B:F5C="!I;@T*("`@("`J("1?
M4$5!4E]D97-T<G5C=&]R7V]B:F5C=%]L:7-T(&9O<B!D97-T<G5C=&]R(&5M
M=6QA=&EO;B!I9B!A#0H@("`@("H@9&5S=')U8W1O<B!O8FIE8W0@97AI<W1S
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D97)R;W)?8VQA<W,@
M("AO<'1I;VYA;"D@=VAI8V@@8VQA<W,@=&\@=7-E(&9O<@T*("`@("`J("`@
M("`@("!E<G)O<B!O8FIE8W1S+"!D969A=6QT<R!T;R!014%27T5R<F]R+@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0')E='5R;B!V;VED#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4B@D97)R;W)?8VQA<W,@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@)&-L87-S;F%M92`]('-T<G1O;&]W97(H9V5T
M7V-L87-S*"1T:&ES*2D[#0H@("`@("`@(&EF("@D=&AI<RT^7V1E8G5G*2![
M#0H@("`@("`@("`@("!P<FEN="`B4$5!4B!C;VYS=')U8W1O<B!C86QL960L
M(&-L87-S/21C;&%S<VYA;65<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1E<G)O<E]C;&%S<R`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'1H:7,M
M/E]E<G)O<E]C;&%S<R`]("1E<G)O<E]C;&%S<SL-"B`@("`@("`@?0T*("`@
M("`@("!W:&EL92`H)&-L87-S;F%M92`F)B!S=')C87-E8VUP*"1C;&%S<VYA
M;64L(")P96%R(BDI('L-"B`@("`@("`@("`@("1D97-T<G5C=&]R(#T@(E\D
M8VQA<W-N86UE(CL-"B`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T
M:&ES+"`D9&5S=')U8W1O<BDI('L-"B`@("`@("`@("`@("`@("!G;&]B86P@
M)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0[#0H@("`@("`@("`@("`@
M("`@)%]014%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W1;72`]("8D=&AI<SL-
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?4$5!4E]3
M2%541$]73E]214=)4U1%4D5$)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E9VES=&5R7W-H=71D;W=N7V9U;F-T:6]N*")?4$5!4E]C86QL7V1E<W1R
M=6-T;W)S(BD[#0H@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=?4$5!
M4E]32%541$]73E]214=)4U1%4D5$)UT@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)&-L87-S;F%M92`](&=E=%]P87)E
M;G1?8VQA<W,H)&-L87-S;F%M92D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5S=')U8W1O
M<@T*#0H@("`@+RHJ#0H@("`@("H@1&5S=')U8W1O<B`H=&AE(&5M=6QA=&5D
M('1Y<&4@;V8N+BXI+B`@1&]E<R!N;W1H:6YG(')I9VAT(&YO=RP-"B`@("`@
M*B!B=70@:7,@:6YC;'5D960@9F]R(&9O<G=A<F0@8V]M<&%T:6)I;&ET>2P@
M<V\@<W5B8VQA<W,-"B`@("`@*B!D97-T<G5C=&]R<R!S:&]U;&0@86QW87ES
M(&-A;&P@:70N#0H@("`@("H-"B`@("`@*B!3964@=&AE(&YO=&4@:6X@=&AE
M(&-L87-S(&1E<V-I<'1I;VX@86)O=70@;W5T<'5T(&9R;VT-"B`@("`@*B!D
M97-T<G5C=&]R<RX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@
M("`@("H@0')E='5R;B!V;VED#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7U!%
M05(H*2![#0H@("`@("`@(&EF("@D=&AI<RT^7V1E8G5G*2![#0H@("`@("`@
M("`@("!P<FEN=&8H(E!%05(@9&5S=')U8W1O<B!C86QL960L(&-L87-S/25S
M7&XB+"!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI*3L-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G9713=&%T:6-0
M<F]P97)T>2@I#0H-"B`@("`O*BH-"B`@("`J($EF('EO=2!H879E(&$@8VQA
M<W,@=&AA="=S(&UO<W1L>2]E;G1I<F5L>2!S=&%T:6,L(&%N9"!Y;W4@;F5E
M9"!S=&%T:6,-"B`@("`J('!R;W!E<G1I97,L('EO=2!C86X@=7-E('1H:7,@
M;65T:&]D('1O('-I;75L871E('1H96TN($5G+B!I;B!Y;W5R(&UE=&AO9"AS
M*0T*("`@("H@9&\@=&AI<SH@)&UY5F%R(#T@)E!%05(Z.F=E=%-T871I8U!R
M;W!E<G1Y*"=M>6-L87-S)RP@)VUY5F%R)RD[#0H@("`@*B!9;W4@35535"!U
M<V4@82!R969E<F5N8V4L(&]R('1H97D@=VEL;"!N;W0@<&5R<VES="$-"B`@
M("`J#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@("H@0'!A<F%M("!S=')I
M;F<@)&-L87-S("!4:&4@8V%L;&EN9R!C;&%S<VYA;64L('1O('!R979E;G0@
M8VQA<VAE<PT*("`@("H@0'!A<F%M("!S=')I;F<@)'9A<B`@("!4:&4@=F%R
M:6%B;&4@=&\@<F5T<FEE=F4N#0H@("`@*B!`<F5T=7)N(&UI>&5D("`@02!R
M969E<F5N8V4@=&\@=&AE('9A<FEA8FQE+B!)9B!N;W0@<V5T(&ET('=I;&P@
M8F4-"B`@("`J("`@("`@("`@("`@("`@("!A=71O(&EN:71I86QI<V5D('1O
M($Y53$PN#0H@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4W1A=&EC4')O<&5R
M='DH)&-L87-S+"`D=F%R*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1P<F]P
M97)T:65S.PT*("`@("`@("!R971U<FX@)'!R;W!E<G1I97-;)&-L87-S75LD
M=F%R73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<F5G:7-T
M97)3:'5T9&]W;D9U;F,H*0T*#0H@("`@+RHJ#0H@("`@*B!5<V4@=&AI<R!F
M=6YC=&EO;B!T;R!R96=I<W1E<B!A('-H=71D;W=N(&UE=&AO9"!F;W(@<W1A
M=&EC#0H@("`@*B!C;&%S<V5S+@T*("`@("H-"B`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@*B!`<&%R86T@(&UI>&5D("1F=6YC("!4:&4@9G5N8W1I;VX@
M;F%M92`H;W(@87)R87D@;V8@8VQA<W,O;65T:&]D*2!T;R!C86QL#0H@("`@
M*B!`<&%R86T@(&UI>&5D("1A<F=S("!4:&4@87)G=6UE;G1S('1O('!A<W,@
M=&\@=&AE(&9U;F-T:6]N#0H@("`@*B!`<F5T=7)N('9O:60-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(')E9VES=&5R4VAU=&1O=VY&=6YC*"1F=6YC+"`D87)G
M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`O+R!I9B!W92!A<F4@8V%L
M;&5D('-T871I8V%L;'DL('1H97)E(&ES(&$@<&]T96YT:6%L#0H@("`@("`@
M("\O('1H870@;F\@<VAU=&1O=VX@9G5N8R!I<R!R96=I<W1E<F5D+B`@0G5G
M(",V-#0U#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27U-(
M551$3U=.7U)%1TE35$52140G72DI('L-"B`@("`@("`@("`@(')E9VES=&5R
M7W-H=71D;W=N7V9U;F-T:6]N*")?4$5!4E]C86QL7V1E<W1R=6-T;W)S(BD[
M#0H@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?4TA55$1/5TY?4D5'25-4
M15)%1"==(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D1TQ/0D%,4ULG
M7U!%05)?<VAU=&1O=VY?9G5N8W,G75M=(#T@87)R87DH)&9U;F,L("1A<F=S
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@:7-%<G)O<B@I
M#0H-"B`@("`O*BH-"B`@("`@*B!496QL('=H971H97(@82!V86QU92!I<R!A
M(%!%05(@97)R;W(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@("!M:7AE9"`D
M9&%T82`@('1H92!V86QU92!T;R!T97-T#0H@("`@("H@0'!A<F%M("`@:6YT
M("`@)&-O9&4@("!I9B`D9&%T82!I<R!A;B!E<G)O<B!O8FIE8W0L(')E='5R
M;B!T<G5E#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("!O;FQY(&EF
M("1C;V1E(&ES(&$@<W1R:6YG(&%N9`T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@)&]B:BT^9V5T365S<V%G92@I(#T]("1C;V1E(&]R#0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`D8V]D92!I<R!A;B!I;G1E9V5R
M(&%N9"`D;V)J+3YG971#;V1E*"D@/3T@)&-O9&4-"B`@("`@*B!`86-C97-S
M("!P=6)L:6,-"B`@("`@*B!`<F5T=7)N("!B;V]L("`@('1R=64@:68@<&%R
M86UE=&5R(&ES(&%N(&5R<F]R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-%
M<G)O<B@D9&%T82P@)&-O9&4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@
M*&ES7V$H)&1A=&$L("=014%27T5R<F]R)RDI('L-"B`@("`@("`@("`@(&EF
M("AI<U]N=6QL*"1C;V1E*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("`@("`@?2!E;'-E:68@*&ES7W-T<FEN9R@D8V]D92DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&1A=&$M/F=E=$UE<W-A9V4H
M*2`]/2`D8V]D93L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1D871A+3YG971#;V1E*"D@/3T@)&-O9&4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S971%<G)O<DAA;F1L
M:6YG*"D-"@T*("`@("\J*@T*("`@("`J(%-E=',@:&]W(&5R<F]R<R!G96YE
M<F%T960@8GD@=&AI<R!O8FIE8W0@<VAO=6QD(&)E(&AA;F1L960N#0H@("`@
M("H@0V%N(&)E(&EN=F]K960@8F]T:"!I;B!O8FIE8W1S(&%N9"!S=&%T:6-A
M;&QY+B`@268@8V%L;&5D#0H@("`@("H@<W1A=&EC86QL>2P@<V5T17)R;W)(
M86YD;&EN9R!S971S('1H92!D969A=6QT(&)E:&%V:6]U<B!F;W(@86QL#0H@
M("`@("H@4$5!4B!O8FIE8W1S+B`@268@8V%L;&5D(&EN(&%N(&]B:F5C="P@
M<V5T17)R;W)(86YD;&EN9R!S971S#0H@("`@("H@=&AE(&1E9F%U;'0@8F5H
M879I;W5R(&9O<B!T:&%T(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!I;G0@)&UO9&4-"B`@("`@*B`@("`@("`@3VYE(&]F(%!%05)?15)23U)?
M4D5455).+"!014%27T524D]27U!224Y4+`T*("`@("`J("`@("`@("!014%2
M7T524D]27U1224='15(L(%!%05)?15)23U)?1$E%+`T*("`@("`J("`@("`@
M("!014%27T524D]27T-!3$Q"04-+(&]R(%!%05)?15)23U)?15A#15!424].
M+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&UI>&5D("1O<'1I;VYS#0H@("`@
M("H@("`@("`@(%=H96X@)&UO9&4@:7,@4$5!4E]%4E)/4E]44DE'1T52+"!T
M:&ES(&ES('1H92!E<G)O<B!L979E;"`H;VYE#0H@("`@("H@("`@("`@(&]F
M($5?55-%4E].3U1)0T4L($5?55-%4E]705).24Y'(&]R($5?55-%4E]%4E)/
M4BDN#0H@("`@("H-"B`@("`@*B`@("`@("`@5VAE;B`D;6]D92!I<R!014%2
M7T524D]27T-!3$Q"04-++"!T:&ES('!A<F%M971E<B!I<R!E>'!E8W1E9`T*
M("`@("`J("`@("`@("!T;R!B92!T:&4@8V%L;&)A8VL@9G5N8W1I;VX@;W(@
M;65T:&]D+B`@02!C86QL8F%C:PT*("`@("`J("`@("`@("!F=6YC=&EO;B!I
M<R!A('-T<FEN9R!W:71H('1H92!N86UE(&]F('1H92!F=6YC=&EO;BP@80T*
M("`@("`J("`@("`@("!C86QL8F%C:R!M971H;V0@:7,@86X@87)R87D@;V8@
M='=O(&5L96UE;G1S.B!T:&4@96QE;65N=`T*("`@("`J("`@("`@("!A="!I
M;F1E>"`P(&ES('1H92!O8FIE8W0L(&%N9"!T:&4@96QE;65N="!A="!I;F1E
M>"`Q(&ES#0H@("`@("H@("`@("`@('1H92!N86UE(&]F('1H92!M971H;V0@
M=&\@8V%L;"!I;B!T:&4@;V)J96-T+@T*("`@("`J#0H@("`@("H@("`@("`@
M(%=H96X@)&UO9&4@:7,@4$5!4E]%4E)/4E]04DE.5"!O<B!014%27T524D]2
M7T1)12P@=&AI<R!I<PT*("`@("`J("`@("`@("!A('!R:6YT9B!F;W)M870@
M<W1R:6YG('5S960@=VAE;B!P<FEN=&EN9R!T:&4@97)R;W(-"B`@("`@*B`@
M("`@("`@;65S<V%G92X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0')E='5R;B!V;VED#0H@("`@("H@0'-E92!014%27T524D]2
M7U)%5%523@T*("`@("`J($!S964@4$5!4E]%4E)/4E]04DE.5`T*("`@("`J
M($!S964@4$5!4E]%4E)/4E]44DE'1T52#0H@("`@("H@0'-E92!014%27T52
M4D]27T1)10T*("`@("`J($!S964@4$5!4E]%4E)/4E]#04Q,0D%#2PT*("`@
M("`J($!S964@4$5!4E]%4E)/4E]%6$-%4%1)3TX-"B`@("`@*@T*("`@("`J
M($!S:6YC92!02%`@-"XP+C4-"B`@("`@*B\-"@T*("`@(&9U;F-T:6]N('-E
M=$5R<F]R2&%N9&QI;F<H)&UO9&4@/2!N=6QL+"`D;W!T:6]N<R`](&YU;&PI
M#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,I("8F(&ES7V$H)'1H
M:7,L("=014%2)RDI('L-"B`@("`@("`@("`@("1S971M;V1E("`@("`]("8D
M=&AI<RT^7V1E9F%U;'1?97)R;W)?;6]D93L-"B`@("`@("`@("`@("1S971O
M<'1I;VYS("`]("8D=&AI<RT^7V1E9F%U;'1?97)R;W)?;W!T:6]N<SL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S971M;V1E("`@("`]("8D
M1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]M;V1E)UT[#0H@("`@("`@
M("`@("`D<V5T;W!T:6]N<R`@/2`F)$=,3T)!3%-;)U]014%27V1E9F%U;'1?
M97)R;W)?;W!T:6]N<R==.PT*("`@("`@("!]#0H-"B`@("`@("`@<W=I=&-H
M("@D;6]D92D@>PT*("`@("`@("`@("`@8V%S92!014%27T524D]27T580T50
M5$E/3CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]215154DXZ#0H@
M("`@("`@("`@("!C87-E(%!%05)?15)23U)?4%))3E0Z#0H@("`@("`@("`@
M("!C87-E(%!%05)?15)23U)?5%))1T=%4CH-"B`@("`@("`@("`@(&-A<V4@
M4$5!4E]%4E)/4E]$244Z#0H@("`@("`@("`@("!C87-E(&YU;&PZ#0H@("`@
M("`@("`@("`@("`@)'-E=&UO9&4@/2`D;6]D93L-"B`@("`@("`@("`@("`@
M("`D<V5T;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@("`@("`@("`@("`@(&)R
M96%K.PT*#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?0T%,3$)!0TLZ
M#0H@("`@("`@("`@("`@("`@)'-E=&UO9&4@/2`D;6]D93L-"B`@("`@("`@
M("`@("`@("`O+R!C;&%S<R]O8FIE8W0@;65T:&]D(&-A;&QB86-K#0H@("`@
M("`@("`@("`@("`@:68@*&ES7V-A;&QA8FQE*"1O<'1I;VYS*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<V5T;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@('1R
M:6=G97)?97)R;W(H(FEN=F%L:60@97)R;W(@8V%L;&)A8VLB+"!%7U5315)?
M5T%23DE.1RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*#0H@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@("`@
M("`@('1R:6=G97)?97)R;W(H(FEN=F%L:60@97)R;W(@;6]D92(L($5?55-%
M4E]705).24Y'*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!E>'!E8W1%<G)O
M<B@I#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!U<V5D('1O
M('1E;&P@=VAI8V@@97)R;W)S('EO=2!E>'!E8W0@=&\@9V5T+@T*("`@("`J
M($5X<&5C=&5D(&5R<F]R<R!A<F4@86QW87ES(')E='5R;F5D('=I=&@@97)R
M;W(@;6]D90T*("`@("`J(%!%05)?15)23U)?4D5455).+B`@17AP96-T960@
M97)R;W(@8V]D97,@87)E('-T;W)E9"!I;B!A('-T86-K+`T*("`@("`J(&%N
M9"!T:&ES(&UE=&AO9"!P=7-H97,@82!N97<@96QE;65N="!O;G1O(&ET+B`@
M5&AE(&QI<W0@;V8-"B`@("`@*B!E>'!E8W1E9"!E<G)O<G,@87)E(&EN(&5F
M9F5C="!U;G1I;"!T:&5Y(&%R92!P;W!P960@;V9F('1H90T*("`@("`J('-T
M86-K('=I=&@@=&AE('!O<$5X<&5C="@I(&UE=&AO9"X-"B`@("`@*@T*("`@
M("`J($YO=&4@=&AA="!T:&ES(&UE=&AO9"!C86X@;F]T(&)E(&-A;&QE9"!S
M=&%T:6-A;&QY#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&-O9&4@
M82!S:6YG;&4@97)R;W(@8V]D92!O<B!A;B!A<G)A>2!O9B!E<G)O<B!C;V1E
M<R!T;R!E>'!E8W0-"B`@("`@*@T*("`@("`J($!R971U<FX@:6YT("`@("!T
M:&4@;F5W(&1E<'1H(&]F('1H92`B97AP96-T960@97)R;W)S(B!S=&%C:PT*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M97AP96-T17)R;W(H)&-O9&4@/2`G*B<I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-?87)R87DH)&-O9&4I*2![#0H@("`@("`@("`@("!A<G)A>5]P=7-H*"1T
M:&ES+3Y?97AP96-T961?97)R;W)S+"`D8V]D92D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?97AP96-T961?
M97)R;W)S+"!A<G)A>2@D8V]D92DI.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!S:7IE;V8H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!P;W!%>'!E8W0H*0T*#0H@("`@
M+RHJ#0H@("`@("H@5&AI<R!M971H;V0@<&]P<R!O;F4@96QE;65N="!O9F8@
M=&AE(&5X<&5C=&5D(&5R<F]R(&-O9&5S#0H@("`@("H@<W1A8VLN#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@=&AE(&QI<W0@;V8@97)R;W(@
M8V]D97,@=&AA="!W97)E('!O<'!E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('!O<$5X<&5C="@I#0H@("`@>PT*("`@("`@("!R971U<FX@87)R87E?<&]P
M*"1T:&ES+3Y?97AP96-T961?97)R;W)S*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7V-H96-K1&5L17AP96-T*"D-"@T*("`@("\J*@T*
M("`@("`J(%1H:7,@;65T:&]D(&-H96-K<R!U;G-E=',@86X@97)R;W(@8V]D
M92!I9B!A=F%I;&%B;&4-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"!E
M<G)O<B!C;V1E#0H@("`@("H@0')E='5R;B!B;V]L('1R=64@:68@=&AE(&5R
M<F]R(&-O9&4@=V%S('5N<V5T+"!F86QS92!O=&AE<G=I<V4-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B!`<VEN8V4@4$A0(#0N,RXP#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7V-H96-K1&5L17AP96-T*"1E<G)O<E]C;V1E
M*0T*("`@('L-"B`@("`@("`@)&1E;&5T960@/2!F86QS93L-"@T*("`@("`@
M("!F;W)E86-H("@D=&AI<RT^7V5X<&5C=&5D7V5R<F]R<R!!4R`D:V5Y(#T^
M("1E<G)O<E]A<G)A>2D@>PT*("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1E
M<G)O<E]C;V1E+"`D97)R;W)?87)R87DI*2![#0H@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G-;)&ME>5U;87)R87E?<V5A
M<F-H*"1E<G)O<E]C;V1E+"`D97)R;W)?87)R87DI72D[#0H@("`@("`@("`@
M("`@("`@)&1E;&5T960@/2!T<G5E.PT*("`@("`@("`@("`@?0T*#0H@("`@
M("`@("`@("`O+R!C;&5A;B!U<"!E;7!T>2!A<G)A>7,-"B`@("`@("`@("`@
M(&EF("@P(#T](&-O=6YT*"1T:&ES+3Y?97AP96-T961?97)R;W)S6R1K97E=
M*2D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?97AP96-T961?
M97)R;W)S6R1K97E=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@)&1E;&5T960[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&1E;$5X<&5C="@I#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES
M(&UE=&AO9"!D96QE=&5S(&%L;"!O8V-U<F5N8V5S(&]F('1H92!S<&5C:69I
M960@96QE;65N="!F<F]M#0H@("`@("H@=&AE(&5X<&5C=&5D(&5R<F]R(&-O
M9&5S('-T86-K+@T*("`@("`J#0H@("`@("H@0'!A<F%M("!M:7AE9"`D97)R
M;W)?8V]D92!E<G)O<B!C;V1E('1H870@<VAO=6QD(&)E(&1E;&5T960-"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(&QI<W0@;V8@97)R;W(@8V]D97,@=&AA="!W
M97)E(&1E;&5T960@;W(@97)R;W(-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J($!S:6YC92!02%`@-"XS+C`-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!D96Q%>'!E8W0H)&5R<F]R7V-O9&4I#0H@("`@>PT*("`@("`@("`D9&5L
M971E9"`](&9A;'-E.PT*#0H@("`@("`@(&EF("@H:7-?87)R87DH)&5R<F]R
M7V-O9&4I("8F("@P("$](&-O=6YT*"1E<G)O<E]C;V1E*2DI*2![#0H@("`@
M("`@("`@("`O+R`D97)R;W)?8V]D92!I<R!A(&YO;BUE;7!T>2!A<G)A>2!H
M97)E.PT*("`@("`@("`@("`@+R\@=V4@=V%L:R!T:')O=6=H(&ET('1R>6EN
M9R!T;R!U;G-E="!A;&P-"B`@("`@("`@("`@("\O('9A;'5E<PT*("`@("`@
M("`@("`@9F]R96%C:"@D97)R;W)?8V]D92!A<R`D:V5Y(#T^("1E<G)O<BD@
M>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-H96-K1&5L17AP96-T
M*"1E<G)O<BDI('L-"B`@("`@("`@("`@("`@("`@("`@)&1E;&5T960@/2`@
M=')U93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D9&5L971E9"`](&9A;'-E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D9&5L971E9"`_
M('1R=64@.B!014%2.CIR86ES945R<F]R*")4:&4@97AP96-T960@97)R;W(@
M>6]U('-U8FUI='1E9"!D;V5S(&YO="!E>&ES="(I.R`O+R!)35!23U9%($U%
M#0H@("`@("`@('T@96QS96EF("@A96UP='DH)&5R<F]R7V-O9&4I*2![#0H@
M("`@("`@("`@("`O+R`D97)R;W)?8V]D92!C;VUE<R!A;&]N92P@=')Y:6YG
M('1O('5N<V5T(&ET#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:T1E
M;$5X<&5C="@D97)R;W)?8V]D92DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(E1H92!E>'!E8W1E9"!E<G)O
M<B!Y;W4@<W5B;6ET=&5D(&1O97,@;F]T(&5X:7-T(BD[("\O($E-4%)/5D4@
M344-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("\O("1E<G)O<E]C;V1E(&ES(&5M<'1Y#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@B5&AE(&5X<&5C=&5D(&5R<F]R('EO=2!S
M=6)M:71T960@:7,@96UP='DB*3L@+R\@24U04D]612!-10T*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(')A:7-E17)R;W(H
M*0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!M971H;V0@:7,@82!W<F%P<&5R
M('1H870@<F5T=7)N<R!A;B!I;G-T86YC92!O9B!T:&4-"B`@("`@*B!C;VYF
M:6=U<F5D(&5R<F]R(&-L87-S('=I=&@@=&AI<R!O8FIE8W0G<R!D969A=6QT
M(&5R<F]R#0H@("`@("H@:&%N9&QI;F<@87!P;&EE9"X@($EF('1H92`D;6]D
M92!A;F0@)&]P=&EO;G,@<&%R86UE=&5R<R!A<F4@;F]T#0H@("`@("H@<W!E
M8VEF:65D+"!T:&4@;V)J96-T)W,@9&5F875L=',@87)E('5S960N#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@;6EX960@)&UE<W-A9V4@82!T97AT(&5R<F]R
M(&UE<W-A9V4@;W(@82!014%2(&5R<F]R(&]B:F5C=`T*("`@("`J#0H@("`@
M("H@0'!A<F%M(&EN="`D8V]D92`@("`@(&$@;G5M97)I8R!E<G)O<B!C;V1E
M("AI="!I<R!U<"!T;R!Y;W5R(&-L87-S#0H@("`@("H@("`@("`@("`@("`@
M("`@("!T;R!D969I;F4@=&AE<V4@:68@>6]U('=A;G0@=&\@=7-E(&-O9&5S
M*0T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN="`D;6]D92`@("`@($]N92!O
M9B!014%27T524D]27U)%5%523BP@4$5!4E]%4E)/4E]04DE.5"P-"B`@("`@
M*B`@("`@("`@("`@("`@("`@(%!%05)?15)23U)?5%))1T=%4BP@4$5!4E]%
M4E)/4E]$244L#0H@("`@("H@("`@("`@("`@("`@("`@("!014%27T524D]2
M7T-!3$Q"04-++"!014%27T524D]27T580T505$E/3BX-"B`@("`@*@T*("`@
M("`J($!P87)A;2!M:7AE9"`D;W!T:6]N<R!)9B`D;6]D92!I<R!014%27T52
M4D]27U1224='15(L('1H:7,@<&%R86UE=&5R#0H@("`@("H@("`@("`@("`@
M("`@("`@("!S<&5C:69I97,@=&AE(%!(4"UI;G1E<FYA;"!E<G)O<B!L979E
M;"`H;VYE(&]F#0H@("`@("H@("`@("`@("`@("`@("`@("!%7U5315)?3D]4
M24-%+"!%7U5315)?5T%23DE.1R!O<B!%7U5315)?15)23U(I+@T*("`@("`J
M("`@("`@("`@("`@("`@("`@268@)&UO9&4@:7,@4$5!4E]%4E)/4E]#04Q,
M0D%#2RP@=&AI<PT*("`@("`J("`@("`@("`@("`@("`@("`@<&%R86UE=&5R
M('-P96-I9FEE<R!T:&4@8V%L;&)A8VL@9G5N8W1I;VX@;W(-"B`@("`@*B`@
M("`@("`@("`@("`@("`@(&UE=&AO9"X@($EN(&]T:&5R(&5R<F]R(&UO9&5S
M('1H:7,@<&%R86UE=&5R#0H@("`@("H@("`@("`@("`@("`@("`@("!I<R!I
M9VYO<F5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D=7-E<FEN
M9F\@268@>6]U(&YE960@=&\@<&%S<R!A;&]N9R!F;W(@97AA;7!L92!D96)U
M9PT*("`@("`J("`@("`@("`@("`@("`@("`@:6YF;W)M871I;VXL('1H:7,@
M<&%R86UE=&5R(&ES(&UE86YT(&9O<B!T:&%T+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D97)R;W)?8VQA<W,@5&AE(')E='5R;F5D(&5R<F]R
M(&]B:F5C="!W:6QL(&)E#0H@("`@("H@("`@("`@("`@("`@("`@("!I;G-T
M86YT:6%T960@9G)O;2!T:&ES(&-L87-S+"!I9B!S<&5C:69I960N#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@8F]O;"`D<VMI<&US9R!)9B!T<G5E+"!R86ES
M945R<F]R('=I;&P@;VYL>2!P87-S(&5R<F]R(&-O9&5S+`T*("`@("`J("`@
M("`@("`@("`@("`@("`@=&AE(&5R<F]R(&UE<W-A9V4@<&%R86UE=&5R('=I
M;&P@8F4@9')O<'!E9"X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0')E='5R;B!O8FIE8W0@("!A(%!%05(@97)R;W(@;V)J96-T
M#0H@("`@("H@0'-E92!014%2.CIS971%<G)O<DAA;F1L:6YG#0H@("`@("H@
M0'-I;F-E(%!(4"`T+C`N-0T*("`@("`J+PT*("`@(&9U;F-T:6]N("9R86ES
M945R<F]R*"1M97-S86=E(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]D92`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M)&UO9&4@/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I
M;VYS(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<FEN
M9F\@/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)O<E]C
M;&%S<R`](&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@)'-K:7!M
M<V<@/2!F86QS92D-"B`@("![#0H@("`@("`@("\O(%1H92!E<G)O<B!I<R!Y
M970@82!014%2(&5R<F]R(&]B:F5C=`T*("`@("`@("!I9B`H:7-?;V)J96-T
M*"1M97-S86=E*2D@>PT*("`@("`@("`@("`@)&-O9&4@("`@("`@(#T@)&UE
M<W-A9V4M/F=E=$-O9&4H*3L-"B`@("`@("`@("`@("1U<V5R:6YF;R`@("`]
M("1M97-S86=E+3YG9715<V5R26YF;R@I.PT*("`@("`@("`@("`@)&5R<F]R
M7V-L87-S(#T@)&UE<W-A9V4M/F=E=%1Y<&4H*3L-"B`@("`@("`@("`@("1M
M97-S86=E+3YE<G)O<E]M97-S86=E7W!R969I>"`]("<G.PT*("`@("`@("`@
M("`@)&UE<W-A9V4@("`@(#T@)&UE<W-A9V4M/F=E=$UE<W-A9V4H*3L-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RD@)B8@:7-S970H
M)'1H:7,M/E]E>'!E8W1E9%]E<G)O<G,I("8F('-I>F5O9B@D=&AI<RT^7V5X
M<&5C=&5D7V5R<F]R<RD@/B`P("8F('-I>F5O9B@D97AP(#T@96YD*"1T:&ES
M+3Y?97AP96-T961?97)R;W)S*2DI('L-"B`@("`@("`@("`@(&EF("@D97AP
M6S!=(#T]("(J(B!\?`T*("`@("`@("`@("`@("`@("AI<U]I;G0H<F5S970H
M)&5X<"DI("8F(&EN7V%R<F%Y*"1C;V1E+"`D97AP*2D@?'P-"B`@("`@("`@
M("`@("`@("`H:7-?<W1R:6YG*')E<V5T*"1E>'`I*2`F)B!I;E]A<G)A>2@D
M;65S<V%G92P@)&5X<"DI*2![#0H@("`@("`@("`@("`@("`@)&UO9&4@/2!0
M14%27T524D]27U)%5%523CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`O+R!.;R!M;V1E(&=I=F5N+"!T<GD@9VQO8F%L(&]N97,-"B`@
M("`@("`@:68@*"1M;V1E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`O+R!#
M;&%S<R!E<G)O<B!H86YD;&5R#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,I("8F(&ES<V5T*"1T:&ES+3Y?9&5F875L=%]E<G)O<E]M;V1E*2D@>PT*
M("`@("`@("`@("`@("`@("1M;V1E("`@(#T@)'1H:7,M/E]D969A=6QT7V5R
M<F]R7VUO9&4[#0H@("`@("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^
M7V1E9F%U;'1?97)R;W)?;W!T:6]N<SL-"B`@("`@("`@("`@("\O($=L;V)A
M;"!E<G)O<B!H86YD;&5R#0H@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H
M)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;6]D92==*2D@>PT*("`@
M("`@("`@("`@("`@("1M;V1E("`@(#T@)$=,3T)!3%-;)U]014%27V1E9F%U
M;'1?97)R;W)?;6]D92==.PT*("`@("`@("`@("`@("`@("1O<'1I;VYS(#T@
M)$=,3T)!3%-;)U]014%27V1E9F%U;'1?97)R;W)?;W!T:6]N<R==.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1E<G)O<E]C
M;&%S<R`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&5C(#T@)&5R<F]R7V-L
M87-S.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,I("8F(&ES<V5T
M*"1T:&ES+3Y?97)R;W)?8VQA<W,I*2![#0H@("`@("`@("`@("`D96,@/2`D
M=&AI<RT^7V5R<F]R7V-L87-S.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&5C(#T@)U!%05)?17)R;W(G.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D<VMI<&US9RD@>PT*("`@("`@("`@("`@)&$@/2`F;F5W("1E8R@D
M8V]D92P@)&UO9&4L("1O<'1I;VYS+"`D=7-E<FEN9F\I.PT*("`@("`@("`@
M("`@<F5T=7)N("1A.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M)&$@/2`F;F5W("1E8R@D;65S<V%G92P@)&-O9&4L("1M;V1E+"`D;W!T:6]N
M<RP@)'5S97)I;F9O*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!T:')O=T5R
M<F]R*"D-"@T*("`@("\J*@T*("`@("`J(%-I;7!L97(@9F]R;2!O9B!R86ES
M945R<F]R('=I=&@@9F5W97(@;W!T:6]N<RX@($EN(&UO<W0@8V%S97,-"B`@
M("`@*B!M97-S86=E+"!C;V1E(&%N9"!U<V5R:6YF;R!A<F4@96YO=6=H+@T*
M("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;65S<V%G90T*("`@("`J
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)G1H<F]W17)R;W(H)&UE<W-A9V4@
M/2!N=6QL+`T*("`@("`@("`@("`@("`@("`@("`@("`@("1C;V1E(#T@;G5L
M;"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<FEN9F\@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T
M:&ES+"`G4$5!4B<I*2![#0H@("`@("`@("`@("`D82`]("8D=&AI<RT^<F%I
M<V5%<G)O<B@D;65S<V%G92P@)&-O9&4L(&YU;&PL(&YU;&PL("1U<V5R:6YF
M;RD[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D82`]("9014%2.CIR86ES945R<F]R*"1M97-S86=E
M+"`D8V]D92P@;G5L;"P@;G5L;"P@)'5S97)I;F9O*3L-"B`@("`@("`@("`@
M(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*
M("`@(&9U;F-T:6]N('-T871I8U!U<VA%<G)O<DAA;F1L:6YG*"1M;V1E+"`D
M;W!T:6]N<R`](&YU;&PI#0H@("`@>PT*("`@("`@("`D<W1A8VL@/2`F)$=,
M3T)!3%-;)U]014%27V5R<F]R7VAA;F1L97)?<W1A8VLG73L-"B`@("`@("`@
M)&1E9E]M;V1E("`@(#T@)B1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R
M7VUO9&4G73L-"B`@("`@("`@)&1E9E]O<'1I;VYS(#T@)B1'3$]"04Q36R=?
M4$5!4E]D969A=6QT7V5R<F]R7V]P=&EO;G,G73L-"B`@("`@("`@)'-T86-K
M6UT@/2!A<G)A>2@D9&5F7VUO9&4L("1D969?;W!T:6]N<RD[#0H@("`@("`@
M('-W:71C:"`H)&UO9&4I('L-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/
M4E]%6$-%4%1)3TXZ#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?4D54
M55)..@T*("`@("`@("`@("`@8V%S92!014%27T524D]27U!224Y4.@T*("`@
M("`@("`@("`@8V%S92!014%27T524D]27U1224='15(Z#0H@("`@("`@("`@
M("!C87-E(%!%05)?15)23U)?1$E%.@T*("`@("`@("`@("`@8V%S92!N=6QL
M.@T*("`@("`@("`@("`@("`@("1D969?;6]D92`]("1M;V1E.PT*("`@("`@
M("`@("`@("`@("1D969?;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?
M0T%,3$)!0TLZ#0H@("`@("`@("`@("`@("`@)&1E9E]M;V1E(#T@)&UO9&4[
M#0H@("`@("`@("`@("`@("`@+R\@8VQA<W,O;V)J96-T(&UE=&AO9"!C86QL
M8F%C:PT*("`@("`@("`@("`@("`@(&EF("AI<U]C86QL86)L92@D;W!T:6]N
M<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&1E9E]O<'1I;VYS(#T@)&]P
M=&EO;G,[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI9"!E<G)O<B!C86QL8F%C
M:R(L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@
M("`@("`@("`@("`@("`@=')I9V=E<E]E<G)O<B@B:6YV86QI9"!E<G)O<B!M
M;V1E(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("!]#0H@("`@("`@("1S=&%C:UM=(#T@87)R87DH)&UO9&4L
M("1O<'1I;VYS*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I#0H@("`@>PT*
M("`@("`@("`D<W1A8VL@/2`F)$=,3T)!3%-;)U]014%27V5R<F]R7VAA;F1L
M97)?<W1A8VLG73L-"B`@("`@("`@)'-E=&UO9&4@("`@(#T@)B1'3$]"04Q3
M6R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G73L-"B`@("`@("`@)'-E=&]P
M=&EO;G,@(#T@)B1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7V]P=&EO
M;G,G73L-"B`@("`@("`@87)R87E?<&]P*"1S=&%C:RD[#0H@("`@("`@(&QI
M<W0H)&UO9&4L("1O<'1I;VYS*2`]("1S=&%C:UMS:7IE;V8H)'-T86-K*2`M
M(#%=.PT*("`@("`@("!A<G)A>5]P;W`H)'-T86-K*3L-"B`@("`@("`@<W=I
M=&-H("@D;6]D92D@>PT*("`@("`@("`@("`@8V%S92!014%27T524D]27T58
M0T505$E/3CH-"B`@("`@("`@("`@(&-A<V4@4$5!4E]%4E)/4E]215154DXZ
M#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?4%))3E0Z#0H@("`@("`@
M("`@("!C87-E(%!%05)?15)23U)?5%))1T=%4CH-"B`@("`@("`@("`@(&-A
M<V4@4$5!4E]%4E)/4E]$244Z#0H@("`@("`@("`@("!C87-E(&YU;&PZ#0H@
M("`@("`@("`@("`@("`@)'-E=&UO9&4@/2`D;6]D93L-"B`@("`@("`@("`@
M("`@("`D<V5T;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@("`@("`@("`@("`@
M(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E(%!%05)?15)23U)?0T%,3$)!
M0TLZ#0H@("`@("`@("`@("`@("`@)'-E=&UO9&4@/2`D;6]D93L-"B`@("`@
M("`@("`@("`@("`O+R!C;&%S<R]O8FIE8W0@;65T:&]D(&-A;&QB86-K#0H@
M("`@("`@("`@("`@("`@:68@*&ES7V-A;&QA8FQE*"1O<'1I;VYS*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<V5T;W!T:6]N<R`]("1O<'1I;VYS.PT*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M('1R:6=G97)?97)R;W(H(FEN=F%L:60@97)R;W(@8V%L;&)A8VLB+"!%7U53
M15)?5T%23DE.1RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&)R96%K.PT*#0H@("`@("`@("`@("!D969A=6QT.@T*("`@("`@("`@
M("`@("`@('1R:6=G97)?97)R;W(H(FEN=F%L:60@97)R;W(@;6]D92(L($5?
M55-%4E]705).24Y'*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R![
M>WL@<'5S:$5R<F]R2&%N9&QI;F<H*0T*#0H@("`@+RHJ#0H@("`@("H@4'5S
M:"!A(&YE=R!E<G)O<B!H86YD;&5R(&]N('1O<"!O9B!T:&4@97)R;W(@:&%N
M9&QE<B!O<'1I;VYS('-T86-K+B!7:71H('1H:7,-"B`@("`@*B!Y;W4@8V%N
M(&5A<VEL>2!O=F5R<FED92!T:&4@86-T=6%L(&5R<F]R(&AA;F1L97(@9F]R
M('-O;64@8V]D92!A;F0@<F5S=&]R90T*("`@("`J(&ET(&QA=&5R('=I=&@@
M<&]P17)R;W)(86YD;&EN9RX-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE
M9"`D;6]D92`H<V%M92!A<R!S971%<G)O<DAA;F1L:6YG*0T*("`@("`J($!P
M87)A;2!M:7AE9"`D;W!T:6]N<R`H<V%M92!A<R!S971%<G)O<DAA;F1L:6YG
M*0T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L($%L=V%Y<R!T<G5E#0H@
M("`@("H-"B`@("`@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!P=7-H17)R;W)(86YD;&EN9R@D;6]D92P@
M)&]P=&EO;G,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)'-T86-K(#T@)B1'
M3$]"04Q36R=?4$5!4E]E<G)O<E]H86YD;&5R7W-T86-K)UT[#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RD@)B8@:7-?82@D=&AI<RP@)U!%05(G*2D@>PT*
M("`@("`@("`@("`@)&1E9E]M;V1E("`@(#T@)B1T:&ES+3Y?9&5F875L=%]E
M<G)O<E]M;V1E.PT*("`@("`@("`@("`@)&1E9E]O<'1I;VYS(#T@)B1T:&ES
M+3Y?9&5F875L=%]E<G)O<E]O<'1I;VYS.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)&1E9E]M;V1E("`@(#T@)B1'3$]"04Q36R=?4$5!4E]D
M969A=6QT7V5R<F]R7VUO9&4G73L-"B`@("`@("`@("`@("1D969?;W!T:6]N
M<R`]("8D1TQ/0D%,4ULG7U!%05)?9&5F875L=%]E<G)O<E]O<'1I;VYS)UT[
M#0H@("`@("`@('T-"B`@("`@("`@)'-T86-K6UT@/2!A<G)A>2@D9&5F7VUO
M9&4L("1D969?;W!T:6]N<RD[#0H-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M*2`F)B!I<U]A*"1T:&ES+"`G4$5!4B<I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^<V5T17)R;W)(86YD;&EN9R@D;6]D92P@)&]P=&EO;G,I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@4$5!4CHZ<V5T17)R;W)(86YD;&EN
M9R@D;6]D92P@)&]P=&EO;G,I.PT*("`@("`@("!]#0H@("`@("`@("1S=&%C
M:UM=(#T@87)R87DH)&UO9&4L("1O<'1I;VYS*3L-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('!O<$5R
M<F]R2&%N9&QI;F<H*0T*#0H@("`@+RHJ#0H@("`@*B!0;W`@=&AE(&QA<W0@
M97)R;W(@:&%N9&QE<B!U<V5D#0H@("`@*@T*("`@("H@0')E='5R;B!B;V]L
M($%L=V%Y<R!T<G5E#0H@("`@*@T*("`@("H@0'-E92!014%2.CIP=7-H17)R
M;W)(86YD;&EN9PT*("`@("HO#0H@("`@9G5N8W1I;VX@<&]P17)R;W)(86YD
M;&EN9R@I#0H@("`@>PT*("`@("`@("`D<W1A8VL@/2`F)$=,3T)!3%-;)U]0
M14%27V5R<F]R7VAA;F1L97)?<W1A8VLG73L-"B`@("`@("`@87)R87E?<&]P
M*"1S=&%C:RD[#0H@("`@("`@(&QI<W0H)&UO9&4L("1O<'1I;VYS*2`]("1S
M=&%C:UMS:7IE;V8H)'-T86-K*2`M(#%=.PT*("`@("`@("!A<G)A>5]P;W`H
M)'-T86-K*3L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES*2`F)B!I<U]A*"1T
M:&ES+"`G4$5!4B<I*2![#0H@("`@("`@("`@("`D=&AI<RT^<V5T17)R;W)(
M86YD;&EN9R@D;6]D92P@)&]P=&EO;G,I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@D;6]D92P@)&]P
M=&EO;G,I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!L;V%D17AT96YS:6]N*"D-
M"@T*("`@("\J*@T*("`@("H@3U,@:6YD97!E;F1A;G0@4$A0(&5X=&5N<VEO
M;B!L;V%D+B!296UE;6)E<B!T;R!T86ME(&-A<F4-"B`@("`J(&]N('1H92!C
M;W)R96-T(&5X=&5N<VEO;B!N86UE(&9O<B!C87-E('-E;G-I=&EV92!/4V5S
M+@T*("`@("H-"B`@("`J($!P87)A;2!S=')I;F<@)&5X="!4:&4@97AT96YS
M:6]N(&YA;64-"B`@("`J($!R971U<FX@8F]O;"!3=6-C97-S(&]R(&YO="!O
M;B!T:&4@9&PH*2!C86QL#0H@("`@*B\-"B`@("!F=6YC=&EO;B!L;V%D17AT
M96YS:6]N*"1E>'0I#0H@("`@>PT*("`@("`@("!I9B`H(65X=&5N<VEO;E]L
M;V%D960H)&5X="DI('L-"B`@("`@("`@("`@("\O(&EF(&5I=&AE<B!R971U
M<FYS('1R=64@9&PH*2!W:6QL('!R;V1U8V4@82!&051!3"!E<G)O<BP@<W1O
M<"!T:&%T#0H@("`@("`@("`@("!I9B`H*&EN:5]G970H)V5N86)L95]D;"<I
M("$](#$I('Q\("AI;FE?9V5T*"=S869E7VUO9&4G*2`]/2`Q*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("A/4U]724Y$3U=3*2![#0H@("`@("`@("`@("`@("`@
M)'-U9F9I>"`]("<N9&QL)SL-"B`@("`@("`@("`@('T@96QS96EF("A02%!?
M3U,@/3T@)TA0+558)RD@>PT*("`@("`@("`@("`@("`@("1S=69F:7@@/2`G
M+G-L)SL-"B`@("`@("`@("`@('T@96QS96EF("A02%!?3U,@/3T@)T%)6"<I
M('L-"B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@)RYA)SL-"B`@("`@("`@
M("`@('T@96QS96EF("A02%!?3U,@/3T@)T]36"<I('L-"B`@("`@("`@("`@
M("`@("`D<W5F9FEX(#T@)RYB=6YD;&4G.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D<W5F9FEX(#T@)RYS;R<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@0&1L*"=P:'!?)RXD97AT+B1S
M=69F:7@I('Q\($!D;"@D97AT+B1S=69F:7@I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*?0T*#0HO
M+R![>WL@7U!%05)?8V%L;%]D97-T<G5C=&]R<R@I#0H-"F9U;F-T:6]N(%]0
M14%27V-A;&Q?9&5S=')U8W1O<G,H*0T*>PT*("`@(&=L;V)A;"`D7U!%05)?
M9&5S=')U8W1O<E]O8FIE8W1?;&ES=#L-"B`@("!I9B`H:7-?87)R87DH)%]0
M14%27V1E<W1R=6-T;W)?;V)J96-T7VQI<W0I("8F#0H@("`@("`@('-I>F5O
M9B@D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="DI#0H@("`@>PT*("`@
M("`@("!R97-E="@D7U!%05)?9&5S=')U8W1O<E]O8FIE8W1?;&ES="D[#0H@
M("`@("`@(&EF("A`4$5!4CHZ9V5T4W1A=&EC4')O<&5R='DH)U!%05(G+"`G
M9&5S=')U8W1L:69O)RDI('L-"B`@("`@("`@("`@("1?4$5!4E]D97-T<G5C
M=&]R7V]B:F5C=%]L:7-T(#T@87)R87E?<F5V97)S92@D7U!%05)?9&5S=')U
M8W1O<E]O8FIE8W1?;&ES="D[#0H@("`@("`@('T-"B`@("`@("`@=VAI;&4@
M*&QI<W0H)&LL("1O8FIR968I(#T@96%C:"@D7U!%05)?9&5S=')U8W1O<E]O
M8FIE8W1?;&ES="DI('L-"B`@("`@("`@("`@("1C;&%S<VYA;64@/2!G971?
M8VQA<W,H)&]B:G)E9BD[#0H@("`@("`@("`@("!W:&EL92`H)&-L87-S;F%M
M92D@>PT*("`@("`@("`@("`@("`@("1D97-T<G5C=&]R(#T@(E\D8VQA<W-N
M86UE(CL-"B`@("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V)J
M<F5F+"`D9&5S=')U8W1O<BDI('L-"B`@("`@("`@("`@("`@("`@("`@)&]B
M:G)E9BT^)&1E<W1R=6-T;W(H*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&-L87-S;F%M92`](&=E=%]P87)E;G1?8VQA<W,H)&-L87-S;F%M
M92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@("\O($5M<'1Y('1H92!O8FIE8W0@;&ES="!T;R!E;G-U
M<F4@=&AA="!D97-T<G5C=&]R<R!A<F4-"B`@("`@("`@+R\@;F]T(&-A;&QE
M9"!M;W)E('1H86X@;VYC92X-"B`@("`@("`@)%]014%27V1E<W1R=6-T;W)?
M;V)J96-T7VQI<W0@/2!A<G)A>2@I.PT*("`@('T-"@T*("`@("\O($YO=R!C
M86QL('1H92!S:'5T9&]W;B!F=6YC=&EO;G,-"B`@("!I9B`H:7-?87)R87DH
M)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UTI($%.1"`A96UP='DH
M)$=,3T)!3%-;)U]014%27W-H=71D;W=N7V9U;F-S)UTI*2![#0H@("`@("`@
M(&9O<F5A8V@@*"1'3$]"04Q36R=?4$5!4E]S:'5T9&]W;E]F=6YC<R==(&%S
M("1V86QU92D@>PT*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R87DH
M)'9A;'5E6S!=+"`D=F%L=65;,5TI.PT*("`@("`@("!]#0H@("`@?0T*?0T*
M#0HO+R!]?7T-"B\J*@T*("H@4W1A;F1A<F0@4$5!4B!E<G)O<B!C;&%S<R!F
M;W(@4$A0(#0-"B`J#0H@*B!4:&ES(&-L87-S(&ES('-U<'-E<G-E9&5D(&)Y
M('M`;&EN:R!014%27T5X8V5P=&EO;GT@:6X@4$A0(#4-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@
M("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO
M<B`@("`@1W)E9V]R>2!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O
M<F4N<&5A<BYP96%R+65R<F]R+G!H<`T*("H@0'-E92`@("`@("`@4$5!4CHZ
M<F%I<V5%<G)O<B@I+"!014%2.CIT:')O=T5R<F]R*"D-"B`J($!S:6YC92`@
M("`@($-L87-S(&%V86EL86)L92!S:6YC92!02%`@-"XP+C(-"B`J+PT*8VQA
M<W,@4$5!4E]%<G)O<@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@
M("!V87(@)&5R<F]R7VUE<W-A9V5?<')E9FEX(#T@)R<[#0H@("`@=F%R("1M
M;V1E("`@("`@("`@("`@("`@("`](%!%05)?15)23U)?4D5455)..PT*("`@
M('9A<B`D;&5V96P@("`@("`@("`@("`@("`@/2!%7U5315)?3D]424-%.PT*
M("`@('9A<B`D8V]D92`@("`@("`@("`@("`@("`@/2`M,3L-"B`@("!V87(@
M)&UE<W-A9V4@("`@("`@("`@("`@(#T@)R<[#0H@("`@=F%R("1U<V5R:6YF
M;R`@("`@("`@("`@("`]("<G.PT*("`@('9A<B`D8F%C:W1R86-E("`@("`@
M("`@("`@/2!N=6QL.PT*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T
M<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27T5R<F]R(&-O;G-T<G5C
M=&]R#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1M97-S86=E("!M
M97-S86=E#0H@("`@("H-"B`@("`@*B!`<&%R86T@:6YT("1C;V1E("`@("`H
M;W!T:6]N86PI(&5R<F]R(&-O9&4-"B`@("`@*@T*("`@("`J($!P87)A;2!I
M;G0@)&UO9&4@("`@("AO<'1I;VYA;"D@97)R;W(@;6]D92P@;VYE(&]F.B!0
M14%27T524D]27U)%5%523BP-"B`@("`@*B!014%27T524D]27U!224Y4+"!0
M14%27T524D]27T1)12P@4$5!4E]%4E)/4E]44DE'1T52+`T*("`@("`J(%!%
M05)?15)23U)?0T%,3$)!0TL@;W(@4$5!4E]%4E)/4E]%6$-%4%1)3TX-"B`@
M("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D;W!T:6]N<R`@("AO<'1I;VYA
M;"D@97)R;W(@;&5V96PL(%]/4E\@:6X@=&AE(&-A<V4@;V8-"B`@("`@*B!0
M14%27T524D]27T-!3$Q"04-++"!T:&4@8V%L;&)A8VL@9G5N8W1I;VX@;W(@
M;V)J96-T+VUE=&AO9`T*("`@("`J('1U<&QE+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=7-E<FEN9F\@*&]P=&EO;F%L*2!A9&1I=&EO;F%L
M('5S97(O9&5B=6<@:6YF;PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?17)R;W(H
M)&UE<W-A9V4@/2`G=6YK;F]W;B!E<G)O<B<L("1C;V1E(#T@;G5L;"P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@;G5L;"P@)&]P=&EO;G,@
M/2!N=6QL+"`D=7-E<FEN9F\@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@
M*"1M;V1E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D;6]D92`](%!%05)?
M15)23U)?4D5455)..PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YM97-S
M86=E("`@/2`D;65S<V%G93L-"B`@("`@("`@)'1H:7,M/F-O9&4@("`@("`]
M("1C;V1E.PT*("`@("`@("`D=&AI<RT^;6]D92`@("`@(#T@)&UO9&4[#0H@
M("`@("`@("1T:&ES+3YU<V5R:6YF;R`@/2`D=7-E<FEN9F\[#0H@("`@("`@
M(&EF("AF=6YC=&EO;E]E>&ES=',H(F1E8G5G7V)A8VMT<F%C92(I*2![#0H@
M("`@("`@("`@("!I9B`H0"%014%2.CIG9713=&%T:6-0<F]P97)T>2@G4$5!
M4E]%<G)O<B<L("=S:VEP=')A8V4G*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3YB86-K=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UO9&4@)B!014%27T52
M4D]27T-!3$Q"04-+*2![#0H@("`@("`@("`@("`D=&AI<RT^;&5V96P@/2!%
M7U5315)?3D]424-%.PT*("`@("`@("`@("`@)'1H:7,M/F-A;&QB86-K(#T@
M)&]P=&EO;G,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H
M)&]P=&EO;G,@/3T](&YU;&PI('L-"B`@("`@("`@("`@("`@("`D;W!T:6]N
M<R`]($5?55-%4E].3U1)0T4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D=&AI<RT^;&5V96P@/2`D;W!T:6]N<SL-"B`@("`@("`@("`@("1T:&ES
M+3YC86QL8F%C:R`](&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T
M:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]04DE.5"D@>PT*("`@("`@("`@("`@
M:68@*&ES7VYU;&PH)&]P=&EO;G,I('Q\(&ES7VEN="@D;W!T:6]N<RDI('L-
M"B`@("`@("`@("`@("`@("`D9F]R;6%T(#T@(B5S(CL-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&9O<FUA="`]("1O<'1I;VYS
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<')I;G1F*"1F;W)M870L
M("1T:&ES+3YG971-97-S86=E*"DI.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@D=&AI<RT^;6]D92`F(%!%05)?15)23U)?5%))1T=%4BD@>PT*("`@("`@
M("`@("`@=')I9V=E<E]E<G)O<B@D=&AI<RT^9V5T365S<V%G92@I+"`D=&AI
M<RT^;&5V96PI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^;6]D
M92`F(%!%05)?15)23U)?1$E%*2![#0H@("`@("`@("`@("`D;7-G(#T@)'1H
M:7,M/F=E=$UE<W-A9V4H*3L-"B`@("`@("`@("`@(&EF("AI<U]N=6QL*"1O
M<'1I;VYS*2!\?"!I<U]I;G0H)&]P=&EO;G,I*2![#0H@("`@("`@("`@("`@
M("`@)&9O<FUA="`]("(E<R([#0H@("`@("`@("`@("`@("`@:68@*'-U8G-T
M<B@D;7-G+"`M,2D@(3T@(EQN(BD@>PT*("`@("`@("`@("`@("`@("`@("`D
M;7-G("X](")<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9F]R;6%T(#T@)&]P=&EO;G,[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!D:64H<W!R:6YT9B@D9F]R
M;6%T+"`D;7-G*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YM
M;V1E("8@4$5!4E]%4E)/4E]#04Q,0D%#2RD@>PT*("`@("`@("`@("`@:68@
M*&ES7V-A;&QA8FQE*"1T:&ES+3YC86QL8F%C:RDI('L-"B`@("`@("`@("`@
M("`@("!C86QL7W5S97)?9G5N8R@D=&AI<RT^8V%L;&)A8VLL("1T:&ES*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M
M/FUO9&4@)B!014%27T524D]27T580T505$E/3BD@>PT*("`@("`@("`@("`@
M=')I9V=E<E]E<G)O<B@B4$5!4E]%4E)/4E]%6$-%4%1)3TX@:7,@;V)S;VQE
M=&4L('5S92!C;&%S<R!014%27T5X8V5P=&EO;B!F;W(@97AC97!T:6]N<R(L
M($5?55-%4E]705).24Y'*3L-"B`@("`@("`@("`@(&5V86PH)R1E(#T@;F5W
M($5X8V5P=&EO;B@D=&AI<RT^;65S<V%G92P@)'1H:7,M/F-O9&4I.W1H<F]W
M*"1E*3LG*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!G971-;V1E*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M97)R;W(@;6]D92!F<F]M(&%N(&5R<F]R(&]B:F5C="X-"B`@("`@*@T*("`@
M("`J($!R971U<FX@:6YT(&5R<F]R(&UO9&4-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$UO9&4H*2![#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^;6]D93L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9V5T0V%L;&)A8VLH*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!C86QL8F%C:R!F=6YC=&EO;B]M971H;V0@9G)O;2!A;B!E<G)O
M<B!O8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&-A;&QB
M86-K(&9U;F-T:6]N(&]R(&]B:F5C="]M971H;V0@87)R87D-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$-A;&QB
M86-K*"D@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-A;&QB86-K.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971-97-S86=E*"D-"@T*
M#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!E<G)O<B!M97-S86=E(&9R;VT@
M86X@97)R;W(@;V)J96-T+@T*("`@("`J#0H@("`@("H@0')E='5R;B`@<W1R
M:6YG("!F=6QL(&5R<F]R(&UE<W-A9V4-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$UE<W-A9V4H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("@D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@@
M+B`D=&AI<RT^;65S<V%G92D[#0H@("`@?0T*#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@9V5T0V]D92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@97)R
M;W(@8V]D92!F<F]M(&%N(&5R<F]R(&]B:F5C=`T*("`@("`J#0H@("`@("H@
M0')E='5R;B!I;G0@97)R;W(@8V]D90T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@(&9U;F-T:6]N(&=E=$-O9&4H*0T*("`@("![#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^8V]D93L-"B`@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=%1Y<&4H*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!N86UE(&]F('1H:7,@97)R;W(O97AC97!T:6]N+@T*("`@("`J
M#0H@("`@("H@0')E='5R;B!S=')I;F<@97)R;W(O97AC97!T:6]N(&YA;64@
M*'1Y<&4I#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G9714>7!E*"D-"B`@("![#0H@("`@("`@(')E='5R;B!G971?
M8VQA<W,H)'1H:7,I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!G9715<V5R26YF;R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@861D:71I
M;VYA;"!U<V5R+7-U<'!L:65D(&EN9F]R;6%T:6]N+@T*("`@("`J#0H@("`@
M("H@0')E='5R;B!S=')I;F<@=7-E<BUS=7!P;&EE9"!I;F9O<FUA=&EO;@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T57-E<DEN9F\H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YU
M<V5R:6YF;SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T
M1&5B=6=);F9O*"D-"@T*("`@("\J*@T*("`@("`J($=E="!A9&1I=&EO;F%L
M(&1E8G5G(&EN9F]R;6%T:6]N('-U<'!L:65D(&)Y('1H92!A<'!L:6-A=&EO
M;BX-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(&1E8G5G(&EN9F]R
M;6%T:6]N#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971$96)U9TEN9F\H*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YG9715<V5R26YF;R@I.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!G971"86-K=')A8V4H*0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T('1H92!C86QL(&)A8VMT<F%C92!F<F]M('=H97)E('1H92!E<G)O<B!W
M87,@9V5N97)A=&5D+@T*("`@("`J(%-U<'!O<G1E9"!W:71H(%!(4"`T+C,N
M,"!O<B!N97=E<BX-"B`@("`@*@T*("`@("`J($!P87)A;2!I;G0@)&9R86UE
M("AO<'1I;VYA;"D@=VAA="!F<F%M92!T;R!F971C:`T*("`@("`J($!R971U
M<FX@87)R87D@0F%C:W1R86-E+"!O<B!.54Q,(&EF(&YO="!A=F%I;&%B;&4N
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!G971"86-K=')A8V4H)&9R86UE(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M(&EF("AD969I;F5D*"=014%27TE'3D]215]"04-+5%)!0T4G*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1F<F%M92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YB86-K=')A8V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3YB86-K=')A8V5;)&9R86UE73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@861D57-E<DEN9F\H*0T*#0H@("`@9G5N8W1I;VX@861D57-E
M<DEN9F\H)&EN9F\I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M
M/G5S97)I;F9O*2D@>PT*("`@("`@("`@("`@)'1H:7,M/G5S97)I;F9O(#T@
M)&EN9F\[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^
M=7-E<FEN9F\@+CT@(B`J*B`D:6YF;R([#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=&]3=')I;F<H*0T*#0H@("`@+RHJ
M#0H@("`@("H@36%K92!A('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&ES
M(&]B:F5C="X-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(&$@<W1R
M:6YG('=I=&@@86X@;V)J96-T('-U;6UA<GD-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('1O4W1R:6YG*"D@>PT*("`@
M("`@("`D;6]D97,@/2!A<G)A>2@I.PT*("`@("`@("`D;&5V96QS(#T@87)R
M87DH15]54T527TY/5$E#12`@/3X@)VYO=&EC92<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("!%7U5315)?5T%23DE.1R`]/B`G=V%R;FEN9R<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("!%7U5315)?15)23U(@("`]/B`G97)R;W(G
M*3L-"B`@("`@("`@:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]#04Q,
M0D%#2RD@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YC86QL
M8F%C:RDI('L-"B`@("`@("`@("`@("`@("`D8V%L;&)A8VL@/2`H:7-?;V)J
M96-T*"1T:&ES+3YC86QL8F%C:ULP72D@/PT*("`@("`@("`@("`@("`@("`@
M("!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RT^8V%L;&)A8VM;,%TI*2`Z
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86QL8F%C:ULP72D@+B`G
M.CHG("X-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A;&QB86-K6S%=
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D8V%L
M;&)A8VL@/2`D=&AI<RT^8V%L;&)A8VL[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@<W!R:6YT9B@G6R5S.B!M97-S86=E/2(E<R(@8V]D
M93TE9"!M;V1E/6-A;&QB86-K("<N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8V%L;&)A8VL])7,@<')E9FEX/2(E<R(@:6YF;STB)7,B72<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*&=E=%]C;&%S
M<R@D=&AI<RDI+"`D=&AI<RT^;65S<V%G92P@)'1H:7,M/F-O9&4L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V%L;&)A8VLL("1T:&ES+3YE<G)O
M<E]M97-S86=E7W!R969I>"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YU<V5R:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T
M:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]04DE.5"D@>PT*("`@("`@("`@("`@
M)&UO9&5S6UT@/2`G<')I;G0G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^;6]D92`F(%!%05)?15)23U)?5%))1T=%4BD@>PT*("`@("`@("`@
M("`@)&UO9&5S6UT@/2`G=')I9V=E<B<[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]$244I('L-"B`@("`@("`@
M("`@("1M;V1E<UM=(#T@)V1I92<[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1T:&ES+3YM;V1E("8@4$5!4E]%4E)/4E]215154DXI('L-"B`@("`@("`@
M("`@("1M;V1E<UM=(#T@)W)E='5R;B<[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('-P<FEN=&8H)ULE<SH@;65S<V%G93TB)7,B(&-O9&4])60@;6]D
M93TE<R!L979E;#TE<R`G+@T*("`@("`@("`@("`@("`@("`@("`@("`G<')E
M9FEX/2(E<R(@:6YF;STB)7,B72<L#0H@("`@("`@("`@("`@("`@("`@("`@
M('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DL("1T:&ES+3YM97-S86=E
M+"`D=&AI<RT^8V]D92P-"B`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D
M92@B?"(L("1M;V1E<RDL("1L979E;'-;)'1H:7,M/FQE=F5L72P-"B`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX
M+`T*("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=7-E<FEN9F\I.PT*
M("`@('T-"@T*("`@("\O('U]?0T*?0T*#0HO*@T*("H@3&]C86P@5F%R:6%B
M;&5S.@T*("H@;6]D93H@<&AP#0H@*B!T86(M=VED=&@Z(#0-"B`J(&,M8F%S
M:6,M;V9F<V5T.B`T#0H@*B!%;F0Z#0H@*B\-"C\^#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$871E
M+G!H<```````````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,3$S,#`P(#$P-3$U-#,T,3,U(#`R,#`T-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*B!V:6TZ('-E
M="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O
M<#TT.B`J+PHO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-2!"86)A($)U96AL97(L(%!I97)R
M92U!;&%I;B!*;WEE("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!T:&4@3F5W($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*
M+R\@?"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@879A:6QA8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO
M<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M;F5W($)31&QI8V5N<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R.B!"86)A($)U96AL97(@/&)A8F%`8F%B87HN8V]M/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@4&EE<G)E+4%L
M86EN($IO>64@/'!A:F]Y94!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*
M("H@1V5N97)I8R!D871E(&AA;F1L:6YG(&-L87-S(&9O<B!014%2"B`J"B`J
M($=E;F5R:6,@9&%T92!H86YD;&EN9R!C;&%S<R!F;W(@4$5!4BX@($%T=&5M
M<'1S('1O(&)E('1I;64@>F]N92!A=V%R90H@*B!T:')O=6=H('1H92!$871E
M.CI4:6UE6F]N92!C;&%S<RX@(%-U<'!O<G1S('-E=F5R86P@;W!E<F%T:6]N
M<R!F<F]M"B`J($1A=&4Z.D-A;&,@;VX@1&%T92!O8FIE8W1S+@H@*@H@*B!`
M8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J($!P86-K86=E("`@($1A=&4*
M("H@0&%U=&AO<B`@("`@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O;3X*
M("H@0&%U=&AO<B`@("`@4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N
M<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!$871E+G!H<"QV(#$N,S4@,C`P-2\Q,2\Q-2`P
M,#HQ-CHS."!P86IO>64@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T1A=&4*("HO"@HO*BI`(RL*("H@26YC;'5D
M92!S=7!P;W)T:6YG(&-L87-S97,*("HO"G)E<75I<F5?;VYC92`G1&%T92]4
M:6UE6F]N92YP:'`G.PIR97%U:7)E7V]N8V4@)T1A=&4O0V%L8RYP:'`G.PIR
M97%U:7)E7V]N8V4@)T1A=&4O4W!A;BYP:'`G.PHO*BI`(RTJ+PH*+RHJ0",K
M"B`J($]U='!U="!F;W)M871S+B`@4&%S<R!T:&ES('1O(&=E=$1A=&4H*2X*
M("HO"B\J*@H@*B`B65E962U-32U$1"!(2#I-33I34R(*("HO"F1E9FEN92@G
M1$%415]&3U)-051?25-/)RP@,2D["B\J*@H@*B`B65E964U-4U-42$A-35-3
M*%I\*"LO+2E(2$U-*3\B"B`J+PID969I;F4H)T1!5$5?1D]234%47TE33U]"
M05-)0R<L(#(I.PHO*BH*("H@(EE965DM34TM4U-42$@Z34TZ4U,H6GPH*R\M
M*4A(.DU-*3\B"B`J+PID969I;F4H)T1!5$5?1D]234%47TE33U]%6%1%3D1%
M1"<L(#,I.PHO*BH*("H@(EE965DM34TM4U-42$@Z34TZ4U,H+E,J*3\H6GPH
M*R\M*4A(.DU-*3\B"B`J+PID969I;F4H)T1!5$5?1D]234%47TE33U]%6%1%
M3D1%1%]-24-23U1)344G+"`V*3L*+RHJ"B`J(")965E934U$1$A(34U34R(*
M("HO"F1E9FEN92@G1$%415]&3U)-051?5$E-15-404U0)RP@-"D["B\J*@H@
M*B!L;VYG(&EN="P@<V5C;VYD<R!S:6YC92!T:&4@=6YI>"!E<&]C:`H@*B\*
M9&5F:6YE*"=$051%7T9/4DU!5%]53DE85$E-12<L(#4I.PHO*BI`(RTJ+PH*
M+RHJ"B`J($=E;F5R:6,@9&%T92!H86YD;&EN9R!C;&%S<R!F;W(@4$5!4@H@
M*@H@*B!'96YE<FEC(&1A=&4@:&%N9&QI;F<@8VQA<W,@9F]R(%!%05(N("!!
M='1E;7!T<R!T;R!B92!T:6UE('IO;F4@87=A<F4*("H@=&AR;W5G:"!T:&4@
M1&%T93HZ5&EM95IO;F4@8VQA<W,N("!3=7!P;W)T<R!S979E<F%L(&]P97)A
M=&EO;G,@9G)O;0H@*B!$871E.CI#86QC(&]N($1A=&4@;V)J96-T<RX*("H*
M("H@0&%U=&AO<B`@("`@0F%B82!"=65H;&5R(#QB86)A0&)A8F%Z+F-O;3X*
M("H@0&%U=&AO<B`@("`@4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N
M<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V97)S
M:6]N("`@(%)E;&5A<V4Z(#$N-"XV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J+PIC;&%S<R!$871E"GL*("`@
M("\J*@H@("`@("H@=&AE('EE87(*("`@("`J($!V87(@:6YT"B`@("`@*B\*
M("`@('9A<B`D>65A<CL*("`@("\J*@H@("`@("H@=&AE(&UO;G1H"B`@("`@
M*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&UO;G1H.PH@("`@+RHJ"B`@
M("`@*B!T:&4@9&%Y"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@
M)&1A>3L*("`@("\J*@H@("`@("H@=&AE(&AO=7(*("`@("`J($!V87(@:6YT
M"B`@("`@*B\*("`@('9A<B`D:&]U<CL*("`@("\J*@H@("`@("H@=&AE(&UI
M;G5T90H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1M:6YU=&4[
M"B`@("`O*BH*("`@("`J('1H92!S96-O;F0*("`@("`J($!V87(@:6YT"B`@
M("`@*B\*("`@('9A<B`D<V5C;VYD.PH@("`@+RHJ"B`@("`@*B!T:&4@<&%R
M=',@;V8@82!S96-O;F0*("`@("`J($!V87(@9FQO870*("`@("`J+PH@("`@
M=F%R("1P87)T<V5C;VYD.PH*("`@("\J*@H@("`@("H@=&EM97IO;F4@9F]R
M('1H:7,@9&%T90H@("`@("H@0'9A<B!O8FIE8W0@1&%T95]4:6UE6F]N90H@
M("`@("HO"B`@("!V87(@)'1Z.PH*("`@("\J*@H@("`@("H@9&5F:6YE('1H
M92!D969A=6QT('=E96MD87D@86)B<F5V:6%T:6]N(&QE;F=T:`H@("`@("H@
M=7-E9"!B>2`Z.F9O<FUA="@I"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@
M("!V87(@)&=E=%=E96MD87E!8F)R;F%M94QE;F=T:"`](#,["@H*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!#<F5A=&5S(&$@
M;F5W($1A=&4@3V)J96-T(&EN:71I86QI>F5D('1O('1H92!C=7)R96YT(&1A
M=&4O=&EM92!I;B!T:&4*("`@("`J('-Y<W1E;2UD969A=6QT('1I;65Z;VYE
M(&)Y(&1E9F%U;'0N("!!(&1A=&4@;W!T:6]N86QL>0H@("`@("H@<&%S<V5D
M(&EN(&UA>2!B92!I;B!T:&4@25-/(#@V,#$L(%1)34535$%-4"!O<B!53DE8
M5$E-12!F;W)M870L"B`@("`@*B!O<B!A;F]T:&5R($1A=&4@;V)J96-T+B`@
M268@;F\@9&%T92!I<R!P87-S960L('1H92!C=7)R96YT(&1A=&4O=&EM90H@
M("`@("H@:7,@=7-E9"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-E92!S971$871E*"D*("`@("`J($!P87)A;2!M:7AE9"`D9&%T
M92!O<'1I;VYA;"`M(&1A=&4O=&EM92!T;R!I;FET:6%L:7IE"B`@("`@*B!`
M<F5T=7)N(&]B:F5C="!$871E('1H92!N97<@1&%T92!O8FIE8W0*("`@("`J
M+PH@("`@9G5N8W1I;VX@1&%T92@D9&%T92`](&YU;&PI"B`@("!["B`@("`@
M("`@)'1H:7,M/G1Z(#T@1&%T95]4:6UE6F]N93HZ9V5T1&5F875L="@I.PH@
M("`@("`@(&EF("AI<U]N=6QL*"1D871E*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<V5T1&%T92AD871E*")9+6TM9"!(.FDZ<R(I*3L*("`@("`@("!](&5L
M<V5I9B`H:7-?82@D9&%T92P@)T1A=&4G*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^8V]P>2@D9&%T92D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/G-E=$1A=&4H)&1A=&4I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@9FEE;&1S(&]F(&$@1&%T92!O8FIE8W0@8F%S
M960@;VX@=&AE(&EN<'5T(&1A=&4@86YD(&9O<FUA=`H@("`@("H*("`@("`J
M(%-E="!T:&4@9FEE;&1S(&]F(&$@1&%T92!O8FIE8W0@8F%S960@;VX@=&AE
M(&EN<'5T(&1A=&4@86YD(&9O<FUA="P*("`@("`J('=H:6-H(&ES('-P96-I
M9FEE9"!B>2!T:&4@1$%415]&3U)-051?*B!C;VYS=&%N=',N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&4@:6YP=70@9&%T90H@("`@("H@0'!A<F%M(&EN="`D9F]R;6%T($]P=&EO
M;F%L(&9O<FUA="!C;VYS=&%N="`H1$%415]&3U)-051?*BD@;V8@=&AE(&EN
M<'5T(&1A=&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@5&AI<R!P87)A
M;65T97(@:7-N)W0@<F5A;&QY(&YE961E9"!A;GEM;W)E+"!B=70@>6]U(&-O
M=6QD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@=7-E(&ET('1O(&9O<F-E
M($1!5$5?1D]234%47U5.25A424U%+@H@("`@("HO"B`@("!F=6YC=&EO;B!S
M971$871E*"1D871E+"`D9F]R;6%T(#T@1$%415]&3U)-051?25-/*0H@("`@
M>PH*("`@("`@("!I9B`H"B`@("`@("`@("`@('!R96=?;6%T8V@H)R]>*%QD
M>S1]*2T_*%QD>S)]*2T_*%QD>S)]*2A;5%QS73\H7&1[,GTI.C\H7&1[,GTI
M.C\H7&1[,GTI*%PN7&0K*3\H6GQ;7"M<+5U<9'LR?3H_7&1[,GTI/RD_)"]I
M)RP@)&1A=&4L("1R96=S*0H@("`@("`@("`@("`F)B`D9F]R;6%T("$]($1!
M5$5?1D]234%47U5.25A424U%*2!["B`@("`@("`@("`@("\O($1!5$5?1D]2
M34%47TE33RP@25-/7T)!4TE#+"!)4T]?15A414Y$140L(&%N9"!424U%4U1!
M35`*("`@("`@("`@("`@+R\@5&AE<V4@9F]R;6%T<R!A<F4@97AT<F5M96QY
M(&-L;W-E('1O(&5A8V@@;W1H97(N("!4:&ES(')E9V5X"B`@("`@("`@("`@
M("\O(&ES('9E<GD@;&]O<V4@86YD(&%C8V5P=',@86QM;W-T(&%N>2!B=71C
M:&5R960@9F]R;6%T('EO=2!C;W5L9`H@("`@("`@("`@("`O+R!T:')O=R!A
M="!I="X@(&4N9RX@,C`P,RTQ,"TP-R`Q.3HT-3HQ-2!A;F0@,C`P,RTQ,#`W
M,3DT-3HQ-0H@("`@("`@("`@("`O+R!A<F4@=&AE('-A;64@=&AI;F<@:6X@
M=&AE(&5Y97,@;V8@=&AI<R!R96=E>"P@979E;B!T:&]U9V@@=&AE"B`@("`@
M("`@("`@("\O(&QA='1E<B!I<R!N;W0@82!V86QI9"!)4T\@.#8P,2!D871E
M+@H@("`@("`@("`@("`D=&AI<RT^>65A<B`@("`@("`]("1R96=S6S%=.PH@
M("`@("`@("`@("`D=&AI<RT^;6]N=&@@("`@("`]("1R96=S6S)=.PH@("`@
M("`@("`@("`D=&AI<RT^9&%Y("`@("`@("`]("1R96=S6S-=.PH@("`@("`@
M("`@("`D=&AI<RT^:&]U<B`@("`@("`](&ES<V5T*"1R96=S6S5=*3\D<F5G
M<ULU73HP.PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E("`@("`](&ES<V5T
M*"1R96=S6S9=*3\D<F5G<ULV73HP.PH@("`@("`@("`@("`D=&AI<RT^<V5C
M;VYD("`@("`](&ES<V5T*"1R96=S6S==*3\D<F5G<ULW73HP.PH@("`@("`@
M("`@("`D=&AI<RT^<&%R='-E8V]N9"`](&ES<V5T*"1R96=S6SA=*3\H9FQO
M870I)')E9W-;.%TZ*&9L;V%T*3`["@H@("`@("`@("`@("`O+R!I9B!A;B!O
M9F9S970@:7,@9&5F:6YE9"P@8V]N=F5R="!T:6UE('1O(%540PH@("`@("`@
M("`@("`O+R!$871E(&-U<G)E;G1L>2!C86XG="!S970@82!T:6UE>F]N92!O
M;FQY(&)Y(&]F9G-E="P*("`@("`@("`@("`@+R\@<V\@:70@:&%S('1O('-T
M;W)E(&ET(&%S(%540PH@("`@("`@("`@("!I9B`H:7-S970H)')E9W-;.5TI
M*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^=&]55$-B>4]F9G-E="@D<F5G
M<ULY72D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?;G5M
M97)I8R@D9&%T92DI('L*("`@("`@("`@("`@+R\@54Y)6%1)344*("`@("`@
M("`@("`@)'1H:7,M/G-E=$1A=&4H9&%T92@B62UM+60@2#II.G,B+"`D9&%T
M92DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O('5N:VYO=VX@
M9F]R;6%T"B`@("`@("`@("`@("1T:&ES+3YY96%R("`@("`@(#T@,#L*("`@
M("`@("`@("`@)'1H:7,M/FUO;G1H("`@("`@/2`Q.PH@("`@("`@("`@("`D
M=&AI<RT^9&%Y("`@("`@("`](#$["B`@("`@("`@("`@("1T:&ES+3YH;W5R
M("`@("`@(#T@,#L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92`@("`@/2`P
M.PH@("`@("`@("`@("`D=&AI<RT^<V5C;VYD("`@("`](#`["B`@("`@("`@
M("`@("1T:&ES+3YP87)T<V5C;VYD(#T@*&9L;V%T*3`["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T(&$@<W1R:6YG("AO<B!O=&AE<BD@
M<F5P<F5S96YT871I;VX@;V8@=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T
M(&$@<W1R:6YG("AO<B!O=&AE<BD@<F5P<F5S96YT871I;VX@;V8@=&AI<R!D
M871E(&EN('1H90H@("`@("H@9F]R;6%T('-P96-I9FEE9"!B>2!T:&4@1$%4
M15]&3U)-051?*B!C;VYS=&%N=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!P87)A;2!I;G0@)&9O<FUA="!F;W)M870@8V]N<W1A
M;G0@*$1!5$5?1D]234%47RHI(&]F('1H92!O=71P=70@9&%T90H@("`@("H@
M0')E='5R;B!S=')I;F<@=&AE(&1A=&4@:6X@=&AE(')E<75E<W1E9"!F;W)M
M870*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%T92@D9F]R;6%T(#T@1$%4
M15]&3U)-051?25-/*0H@("`@>PH@("`@("`@('-W:71C:"`H)&9O<FUA="D@
M>PH@("`@("`@(&-A<V4@1$%415]&3U)-051?25-/.@H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F9O<FUA="@B)5DM)6TM)60@)50B*3L*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92!$051%7T9/4DU!5%])4T]?0D%324,Z
M"B`@("`@("`@("`@("1F;W)M870@/2`B)5DE;25D5"5()4TE4R(["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^='HM/F=E=$E$*"D@/3T@)U540R<I('L*("`@
M("`@("`@("`@("`@("1F;W)M870@+CT@(EHB.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^9F]R;6%T*"1F;W)M870I.PH@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?1D]234%47TE33U]%
M6%1%3D1%1#H*("`@("`@("`@("`@)&9O<FUA="`]("(E62TE;2TE9%0E2#HE
M33HE4R(["B`@("`@("`@("`@(&EF("@D=&AI<RT^='HM/F=E=$E$*"D@/3T@
M)U540R<I('L*("`@("`@("`@("`@("`@("1F;W)M870@+CT@(EHB.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F]R;6%T*"1F
M;W)M870I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E($1!5$5?
M1D]234%47TE33U]%6%1%3D1%1%]-24-23U1)344Z"B`@("`@("`@("`@("1F
M;W)M870@/2`B)5DM)6TM)614)4@Z)4TZ)7,B.PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/G1Z+3YG971)1"@I(#T]("=55$,G*2!["B`@("`@("`@("`@("`@
M("`D9F]R;6%T("X]("):(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F9O<FUA="@D9F]R;6%T*3L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@8V%S92!$051%7T9/4DU!5%]424U%4U1!35`Z"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9F]R;6%T*"(E625M)60E2"5-)5,B*3L*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!$051%7T9/4DU!5%]5
M3DE85$E-13H*("`@("`@("`@("`@<F5T=7)N(&UK=&EM92@D=&AI<RT^:&]U
M<BP@)'1H:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N9"P@)'1H:7,M/FUO;G1H
M+"`D=&AI<RT^9&%Y+"`D=&AI<RT^>65A<BD["B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-O<'D@=F%L=65S
M(&9R;VT@86YO=&AE<B!$871E(&]B:F5C=`H@("`@("H*("`@("`J($UA:V5S
M('1H:7,@1&%T92!A(&-O<'D@;V8@86YO=&AE<B!$871E(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&]B:F5C
M="!$871E("1D871E($1A=&4@=&\@8V]P>2!F<F]M"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O<'DH)&1A=&4I"B`@("!["B`@("`@("`@)'1H:7,M/GEE87(@
M/2`D9&%T92T^>65A<CL*("`@("`@("`D=&AI<RT^;6]N=&@@/2`D9&%T92T^
M;6]N=&@["B`@("`@("`@)'1H:7,M/F1A>2`]("1D871E+3YD87D["B`@("`@
M("`@)'1H:7,M/FAO=7(@/2`D9&%T92T^:&]U<CL*("`@("`@("`D=&AI<RT^
M;6EN=71E(#T@)&1A=&4M/FUI;G5T93L*("`@("`@("`D=&AI<RT^<V5C;VYD
M(#T@)&1A=&4M/G-E8V]N9#L*("`@("`@("`D=&AI<RT^='H@/2`D9&%T92T^
M='H["B`@("!]"@H@("`@+RHJ"B`@("`@*B`@1&%T92!P<F5T='D@<')I;G1I
M;F<L('-I;6EL87(@=&\@<W1R9G1I;64H*0H@("`@("H*("`@("`J("!&;W)M
M871S('1H92!D871E(&EN('1H92!G:79E;B!F;W)M870L(&UU8V@@;&EK90H@
M("`@("H@('-T<F9T:6UE*"DN("!-;W-T('-T<F9T:6UE*"D@;W!T:6]N<R!A
M<F4@<W5P<&]R=&5D+CQB<CX\8G(^"B`@("`@*@H@("`@("H@(&9O<FUA='1I
M;F<@;W!T:6]N<SH\8G(^/&)R/@H@("`@("H*("`@("`J("`\8V]D93XE82`@
M/"]C;V1E/B`@86)B<F5V:6%T960@=V5E:V1A>2!N86UE("A3=6XL($UO;BP@
M5'5E*2`\8G(^"B`@("`@*B`@/&-O9&4^)4$@(#PO8V]D93X@(&9U;&P@=V5E
M:V1A>2!N86UE("A3=6YD87DL($UO;F1A>2P@5'5E<V1A>2D@/&)R/@H@("`@
M("H@(#QC;V1E/B5B("`\+V-O9&4^("!A8F)R979I871E9"!M;VYT:"!N86UE
M("A*86XL($9E8BP@36%R*2`\8G(^"B`@("`@*B`@/&-O9&4^)4(@(#PO8V]D
M93X@(&9U;&P@;6]N=&@@;F%M92`H2F%N=6%R>2P@1F5B<G5A<GDL($UA<F-H
M*2`\8G(^"B`@("`@*B`@/&-O9&4^)4,@(#PO8V]D93X@(&-E;G1U<GD@;G5M
M8F5R("AT:&4@>65A<B!D:79I9&5D(&)Y(#$P,"!A;F0@=')U;F-A=&5D('1O
M(&%N(&EN=&5G97(L(')A;F=E(#`P('1O(#DY*2`\8G(^"B`@("`@*B`@/&-O
M9&4^)60@(#PO8V]D93X@(&1A>2!O9B!M;VYT:"`H<F%N9V4@,#`@=&\@,S$I
M(#QB<CX*("`@("`J("`\8V]D93XE1"`@/"]C;V1E/B`@<V%M92!A<R`B)6TO
M)60O)7DB(#QB<CX*("`@("`J("`\8V]D93XE92`@/"]C;V1E/B`@9&%Y(&]F
M(&UO;G1H+"!S:6YG;&4@9&EG:70@*')A;F=E(#`@=&\@,S$I(#QB<CX*("`@
M("`J("`\8V]D93XE12`@/"]C;V1E/B`@;G5M8F5R(&]F(&1A>7,@<VEN8V4@
M=6YS<&5C:69I960@97!O8V@@*&EN=&5G97(L($1A=&5?0V%L8SHZ9&%T951O
M1&%Y<R@I*2`\8G(^"B`@("`@*B`@/&-O9&4^)4@@(#PO8V]D93X@(&AO=7(@
M87,@9&5C:6UA;"!N=6UB97(@*#`P('1O(#(S*2`\8G(^"B`@("`@*B`@/&-O
M9&4^)4D@(#PO8V]D93X@(&AO=7(@87,@9&5C:6UA;"!N=6UB97(@;VX@,3(M
M:&]U<B!C;&]C:R`H,#$@=&\@,3(I(#QB<CX*("`@("`J("`\8V]D93XE:B`@
M/"]C;V1E/B`@9&%Y(&]F('EE87(@*')A;F=E(#`P,2!T;R`S-C8I(#QB<CX*
M("`@("`J("`\8V]D93XE;2`@/"]C;V1E/B`@;6]N=&@@87,@9&5C:6UA;"!N
M=6UB97(@*')A;F=E(#`Q('1O(#$R*2`\8G(^"B`@("`@*B`@/&-O9&4^)4T@
M(#PO8V]D93X@(&UI;G5T92!A<R!A(&1E8VEM86P@;G5M8F5R("@P,"!T;R`U
M.2D@/&)R/@H@("`@("H@(#QC;V1E/B5N("`\+V-O9&4^("!N97=L:6YE(&-H
M87)A8W1E<B`H7&XI(#QB<CX*("`@("`J("`\8V]D93XE3R`@/"]C;V1E/B`@
M9'-T+6-O<G)E8W1E9"!T:6UE>F]N92!O9F9S970@97AP<F5S<V5D(&%S("(K
M+RU(2#I-32(@/&)R/@H@("`@("H@(#QC;V1E/B5O("`\+V-O9&4^("!R87<@
M=&EM97IO;F4@;V9F<V5T(&5X<')E<W-E9"!A<R`B*R\M2$@Z34TB(#QB<CX*
M("`@("`J("`\8V]D93XE<"`@/"]C;V1E/B`@96ET:&5R("=A;2<@;W(@)W!M
M)R!D97!E;F1I;F<@;VX@=&AE('1I;64@/&)R/@H@("`@("H@(#QC;V1E/B50
M("`\+V-O9&4^("!E:71H97(@)T%-)R!O<B`G4$TG(&1E<&5N9&EN9R!O;B!T
M:&4@=&EM92`\8G(^"B`@("`@*B`@/&-O9&4^)7(@(#PO8V]D93X@('1I;64@
M:6X@86TO<&T@;F]T871I;VXL('-A;64@87,@(B5).B5-.B53("5P(B`\8G(^
M"B`@("`@*B`@/&-O9&4^)5(@(#PO8V]D93X@('1I;64@:6X@,C0M:&]U<B!N
M;W1A=&EO;BP@<V%M92!A<R`B)4@Z)4TB(#QB<CX*("`@("`J("`\8V]D93XE
M<R`@/"]C;V1E/B`@<V5C;VYD<R!I;F-L=61I;F<@=&AE(&1E8VEM86P@<F5P
M<F5S96YT871I;VX@<VUA;&QE<B!T:&%N(&]N92!S96-O;F0@/&)R/@H@("`@
M("H@(#QC;V1E/B53("`\+V-O9&4^("!S96-O;F1S(&%S(&$@9&5C:6UA;"!N
M=6UB97(@*#`P('1O(#4Y*2`\8G(^"B`@("`@*B`@/&-O9&4^)70@(#PO8V]D
M93X@('1A8B!C:&%R86-T97(@*%QT*2`\8G(^"B`@("`@*B`@/&-O9&4^)50@
M(#PO8V]D93X@(&-U<G)E;G0@=&EM92P@<V%M92!A<R`B)4@Z)4TZ)5,B(#QB
M<CX*("`@("`J("`\8V]D93XE=R`@/"]C;V1E/B`@=V5E:V1A>2!A<R!D96-I
M;6%L("@P(#T@4W5N9&%Y*2`\8G(^"B`@("`@*B`@/&-O9&4^)54@(#PO8V]D
M93X@('=E96L@;G5M8F5R(&]F(&-U<G)E;G0@>65A<BP@9FER<W0@<W5N9&%Y
M(&%S(&9I<G-T('=E96L@/&)R/@H@("`@("H@(#QC;V1E/B5Y("`\+V-O9&4^
M("!Y96%R(&%S(&1E8VEM86P@*')A;F=E(#`P('1O(#DY*2`\8G(^"B`@("`@
M*B`@/&-O9&4^)5D@(#PO8V]D93X@('EE87(@87,@9&5C:6UA;"!I;F-L=61I
M;F<@8V5N='5R>2`H<F%N9V4@,#`P,"!T;R`Y.3DY*2`\8G(^"B`@("`@*B`@
M/&-O9&4^)24@(#PO8V]D93X@(&QI=&5R86P@)R4G(#QB<CX*("`@("`J(#QB
M<CX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M('-T<FEN9R!F;W)M870@=&AE(&9O<FUA="!S=')I;F<@9F]R(')E='5R;F5D
M(&1A=&4O=&EM90H@("`@("H@0')E='5R;B!S=')I;F<@9&%T92]T:6UE(&EN
M(&=I=F5N(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO;B!F;W)M870H)&9O
M<FUA="D*("`@('L*("`@("`@("`D;W5T<'5T(#T@(B(["@H@("`@("`@(&9O
M<B@D<W1R<&]S(#T@,#L@)'-T<G!O<R`\('-T<FQE;B@D9F]R;6%T*3L@)'-T
M<G!O<RLK*2!["B`@("`@("`@("`@("1C:&%R(#T@<W5B<W1R*"1F;W)M870L
M)'-T<G!O<RPQ*3L*("`@("`@("`@("`@:68@*"1C:&%R(#T]("(E(BD@>PH@
M("`@("`@("`@("`@("`@)&YE>'1C:&%R(#T@<W5B<W1R*"1F;W)M870L)'-T
M<G!O<R`K(#$L,2D["B`@("`@("`@("`@("`@("!S=VET8V@@*"1N97AT8VAA
M<BD@>PH@("`@("`@("`@("`@("`@8V%S92`B82(Z"B`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E=%=E96MD87E!8F)R;F%M
M92@D=&AI<RT^9&%Y+"1T:&ES+3YM;VYT:"PD=&AI<RT^>65A<BP@)'1H:7,M
M/F=E=%=E96MD87E!8F)R;F%M94QE;F=T:"D["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")!(CH*("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T5V5E:V1A>49U
M;&QN86UE*"1T:&ES+3YD87DL)'1H:7,M/FUO;G1H+"1T:&ES+3YY96%R*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(F(B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#
M86QC.CIG971-;VYT:$%B8G)N86UE*"1T:&ES+3YM;VYT:"D["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")"(CH*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T
M36]N=&A&=6QL;F%M92@D=&AI<RT^;6]N=&@I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B0R(Z"B`@("`@("`@
M("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E,#)D(BQI;G1V86PH
M)'1H:7,M/GEE87(O,3`P*2D["B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("!C87-E(")D(CH*("`@("`@("`@("`@("`@("`@
M("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0B+"1T:&ES+3YD87DI.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B
M1"(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E
M,#)D+R4P,F0O)3`R9"(L)'1H:7,M/FUO;G1H+"1T:&ES+3YD87DL)'1H:7,M
M/GEE87(I.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@8V%S92`B92(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N
M/2`D=&AI<RT^9&%Y("H@,3L@+R\@9V5T(')I9"!O9B!L96%D:6YG('IE<F\*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(D4B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#
M86QC.CID871E5&]$87ES*"1T:&ES+3YD87DL)'1H:7,M/FUO;G1H+"1T:&ES
M+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(D@B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@<W!R:6YT9B@B)3`R9"(L("1T:&ES+3YH;W5R*3L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)60B+"`D=&AI
M<RT^:&]U<BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("!C87-E("))(CH*("`@("`@("`@("`@("`@("`@("`D:&]U<B`]
M("@D=&AI<RT^:&]U<B`K(#$I(#X@,3(@/R`D=&AI<RT^:&]U<B`M(#$R(#H@
M)'1H:7,M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S
M<')I;G1F*"(E,#)D(BP@)&AO=7(]/3`@/R`Q,B`Z("1H;W5R*3L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(FDB
M.@H@("`@("`@("`@("`@("`@("`@("1H;W5R(#T@*"1T:&ES+3YH;W5R("L@
M,2D@/B`Q,B`_("1T:&ES+3YH;W5R("T@,3(@.B`D=&AI<RT^:&]U<CL*("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B5D(BP@)&AO
M=7(]/3`@/R`Q,B`Z("1H;W5R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@(&-A<V4@(FHB.@H@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@1&%T95]#86QC.CIJ=6QI86Y$871E*"1T:&ES+3YD
M87DL)'1H:7,M/FUO;G1H+"1T:&ES+3YY96%R*3L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(FTB.@H@("`@("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9"(L)'1H:7,M
M/FUO;G1H*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(DTB.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@<W!R:6YT9B@B)3`R9"(L)'1H:7,M/FUI;G5T92D["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")N(CH*("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X](")<;B(["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")/(CH*("`@
M("`@("`@("`@("`@("`@("`D;V9F;7,@/2`D=&AI<RT^='HM/F=E=$]F9G-E
M="@D=&AI<RD["B`@("`@("`@("`@("`@("`@("`@)&1I<F5C=&EO;B`]("1O
M9F9M<R`^/2`P(#\@(BLB(#H@(BTB.PH@("`@("`@("`@("`@("`@("`@("1O
M9F9M:6YS(#T@86)S*"1O9F9M<RD@+R`Q,#`P("\@-C`["B`@("`@("`@("`@
M("`@("`@("`@)&AO=7)S(#T@)&]F9FUI;G,@+R`V,#L*("`@("`@("`@("`@
M("`@("`@("`D;6EN=71E<R`]("1O9F9M:6YS("4@-C`["B`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"(E<R4P,F0Z)3`R9"(L("1D
M:7)E8W1I;VXL("1H;W5R<RP@)&UI;G5T97,I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B;R(Z"B`@("`@("`@
M("`@("`@("`@("`@)&]F9FUS(#T@)'1H:7,M/G1Z+3YG971287=/9F9S970H
M)'1H:7,I.PH@("`@("`@("`@("`@("`@("`@("1D:7)E8W1I;VX@/2`D;V9F
M;7,@/CT@,"`_("(K(B`Z("(M(CL*("`@("`@("`@("`@("`@("`@("`D;V9F
M;6EN<R`](&%B<R@D;V9F;7,I("\@,3`P,"`O(#8P.PH@("`@("`@("`@("`@
M("`@("`@("1H;W5R<R`]("1O9F9M:6YS("\@-C`["B`@("`@("`@("`@("`@
M("`@("`@)&UI;G5T97,@/2`D;V9F;6EN<R`E(#8P.PH@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)7,E,#)D.B4P,F0B+"`D9&ER
M96-T:6]N+"`D:&]U<G,L("1M:6YU=&5S*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(G`B.@H@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/FAO=7(@/CT@,3(@/R`B<&TB
M(#H@(F%M(CL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(E`B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@)'1H:7,M/FAO=7(@/CT@,3(@/R`B4$TB(#H@(D%-(CL*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(G(B.@H@
M("`@("`@("`@("`@("`@("`@("1H;W5R(#T@*"1T:&ES+3YH;W5R("L@,2D@
M/B`Q,B`_("1T:&ES+3YH;W5R("T@,3(@.B`D=&AI<RT^:&]U<CL*("`@("`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H(B4P,F0Z)3`R9#HE
M,#)D("5S(BP@)&AO=7(]/3`@/R`@,3(@.B`D:&]U<BP@)'1H:7,M/FUI;G5T
M92P@)'1H:7,M/G-E8V]N9"P@)'1H:7,M/FAO=7(@/CT@,3(@/R`B4$TB(#H@
M(D%-(BD["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E(")2(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M('-P<FEN=&8H(B4P,F0Z)3`R9"(L("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN
M=71E*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&-A<V4@(G,B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@
M<W1R7W)E<&QA8V4H)RPG+"`G+B<L('-P<FEN=&8H(B4P.68B+"`H9FQO870I
M*"AF;&]A="DD=&AI<RT^<V5C;VYD("L@)'1H:7,M/G!A<G1S96-O;F0I*2D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(")3(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN
M=&8H(B4P,F0B+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(G0B.@H@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@(EQT(CL*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(E0B.@H@("`@("`@("`@
M("`@("`@("`@("1O=71P=70@+CT@<W!R:6YT9B@B)3`R9#HE,#)D.B4P,F0B
M+"`D=&AI<RT^:&]U<BP@)'1H:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N9"D[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C
M87-E(")W(CH*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?
M0V%L8SHZ9&%Y3V97965K*"1T:&ES+3YD87DL)'1H:7,M/FUO;G1H+"1T:&ES
M+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@(&-A<V4@(E4B.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@
M+CT@1&%T95]#86QC.CIW965K3V9996%R*"1T:&ES+3YD87DL)'1H:7,M/FUO
M;G1H+"1T:&ES+3YY96%R*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&-A<V4@(GDB.@H@("`@("`@("`@("`@("`@("`@
M("1O=71P=70@+CT@<W5B<W1R*"1T:&ES+3YY96%R+#(L,BD["B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")9(CH*
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YY96%R.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S
M92`B6B(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^
M='HM/FEN1&%Y;&EG:'14:6UE*"1T:&ES*2`_("1T:&ES+3YT>BT^9V5T1%-4
M4VAO<G1.86UE*"D@.B`D=&AI<RT^='HM/F=E=%-H;W)T3F%M92@I.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B
M)2(Z"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B)2(["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&-H87(N)&YE>'1C
M:&%R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-T<G!O
M<RLK.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2`D8VAA<CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@)&]U='!U=#L*"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M=&AI<R!D871E+W1I;64@:6X@56YI>"!T:6UE*"D@9F]R;6%T"B`@("`@*@H@
M("`@("H@1V5T(&$@<F5P<F5S96YT871I;VX@;V8@=&AI<R!D871E(&EN(%5N
M:7@@=&EM92@I(&9O<FUA="X@(%1H:7,@;6%Y(&]N;'D@8F4*("`@("`J('9A
M;&ED(&9O<B!D871E<R!F<F]M(#$Y-S`@=&\@?C(P,S@N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT(&YU;6)E<B!O
M9B!S96-O;F1S('-I;F-E('1H92!U;FEX(&5P;V-H"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%1I;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M9V5T1&%T92A$051%7T9/4DU!5%]53DE85$E-12D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!T:6UE('IO;F4@;V8@=&AI<R!$871E"B`@("`@
M*@H@("`@("H@4V5T<R!T:&4@=&EM92!Z;VYE(&]F('1H:7,@9&%T92!W:71H
M('1H92!G:79E;@H@("`@("H@1&%T95]4:6UE6F]N92!O8FIE8W0N("!$;V5S
M(&YO="!A;'1E<B!T:&4@9&%T92]T:6UE+`H@("`@("H@;VYL>2!A<W-I9VYS
M(&$@;F5W('1I;64@>F]N92X@($9O<B!C;VYV97)S:6]N+"!U<V4*("`@("`J
M(&-O;G9E<G146B@I+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<&%R86T@;V)J96-T($1A=&5?5&EM95IO;F4@)'1Z('1H92!$871E
M7U1I;65:;VYE(&]B:F5C="!T;R!U<V4L(&EF(&-A;&QE9`H@("`@("H@=VET
M:"!A('!A<F%M871E<B!T:&%T(&ES(&YO="!A($1A=&5?5&EM95IO;F4@;V)J
M96-T+"!W:6QL(&9A;&P@=&AR;W5G:"!T;PH@("`@("H@<V5T5%IB>4E$*"DN
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1:*"1T>BD*("`@('L*("`@(`EI
M9BAI<U]A*"1T>BP@)T1A=&5?5&EM97IO;F4G*2D@>PH@("`@("`@(`DD=&AI
M<RT^='H@/2`D='H["B`@("`)?2!E;'-E('L*("`@(`D))'1H:7,M/G-E=%1:
M8GE)1"@D='HI.PH@("`@"7T*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE('1I;64@>F]N92!O9B!T:&ES(&1A=&4@=VET:"!T:&4@9VEV96X@=&EM
M92!Z;VYE(&ED"B`@("`@*@H@("`@("H@4V5T<R!T:&4@=&EM92!Z;VYE(&]F
M('1H:7,@9&%T92!W:71H('1H92!G:79E;@H@("`@("H@=&EM92!Z;VYE(&ED
M+"!O<B!T;R!T:&4@<WES=&5M(&1E9F%U;'0@:68@=&AE"B`@("`@*B!G:79E
M;B!I9"!I<R!I;G9A;&ED+B!$;V5S(&YO="!A;'1E<B!T:&4@9&%T92]T:6UE
M+`H@("`@("H@;VYL>2!A<W-I9VYS(&$@;F5W('1I;64@>F]N92X@($9O<B!C
M;VYV97)S:6]N+"!U<V4*("`@("`J(&-O;G9E<G146B@I+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG(&ED(&$@
M=&EM92!Z;VYE(&ED"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%1:8GE)1"@D
M:60I"B`@("!["B`@("`@("`@:68@*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)
M1"@D:60I*2!["B`@("`@("`@("`@("1T:&ES+3YT>B`](&YE=R!$871E7U1I
M;65:;VYE*"1I9"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/G1Z(#T@1&%T95]4:6UE6F]N93HZ9V5T1&5F875L="@I.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J(%1E<W1S(&EF('1H:7,@9&%T92]T
M:6UE(&ES(&EN($135`H@("`@("H*("`@("`J(%)E='5R;G,@=')U92!I9B!D
M87EL:6=H="!S879I;F=S('1I;64@:7,@:6X@969F96-T(&9O<@H@("`@("H@
M=&AI<R!D871E(&EN('1H:7,@9&%T92=S('1I;64@>F]N92X@(%-E92!$871E
M7U1I;65:;VYE.CII;D1A>6QI9VAT5&EM92@I"B`@("`@*B!F;W(@8V]M<&%T
M86)I;&ET>2!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@1%-4(&ES(&EN
M(&5F9F5C="!F;W(@=&AI<R!D871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN
M1&%Y;&EG:'14:6UE*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1Z
M+3YI;D1A>6QI9VAT5&EM92@D=&AI<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@551#(&%N9"!S971S('1H:7,@9&%T
M92=S('1I;65Z;VYE('1O(%540PH@("`@("H*("`@("`J($-O;G9E<G1S('1H
M:7,@9&%T92!T;R!55$,@86YD('-E=',@=&AI<R!D871E)W,@=&EM97IO;F4@
M=&\@551#"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@=&]55$,H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^
M='HM/F=E=$]F9G-E="@D=&AI<RD@/B`P*2!["B`@("`@("`@("`@("1T:&ES
M+3YS=6)T<F%C=%-E8V]N9',H:6YT=F%L*"1T:&ES+3YT>BT^9V5T3V9F<V5T
M*"1T:&ES*2`O(#$P,#`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^861D4V5C;VYD<RAI;G1V86PH86)S*"1T:&ES+3YT>BT^9V5T
M3V9F<V5T*"1T:&ES*2D@+R`Q,#`P*2D["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3YT>B`](&YE=R!$871E7U1I;65:;VYE*"=55$,G*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G9E<G1S('1H:7,@9&%T92!T;R!A(&YE=R!T:6UE
M('IO;F4*("`@("`J"B`@("`@*B!#;VYV97)T<R!T:&ES(&1A=&4@=&\@82!N
M97<@=&EM92!Z;VYE+@H@("`@("H@5T%23DE.1SH@5&AI<R!M87D@;F]T('=O
M<FL@8V]R<F5C=&QY(&EF('EO=7(@<WES=&5M(&1O97,@;F]T(&%L;&]W"B`@
M("`@*B!P=71E;G8H*2!O<B!I9B!L;V-A;'1I;64H*2!D;V5S(&YO="!W;W)K
M(&EN('EO=7(@96YV:7)O;FUE;G0N("!3964*("`@("`J($1A=&4Z.E1I;65:
M;VYE.CII;D1A>6QI9VAT5&EM92@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J
M96-T($1A=&5?5&EM95IO;F4@)'1Z('1H92!$871E.CI4:6UE6F]N92!O8FIE
M8W0@9F]R('1H92!C;VYV97)S:6]N('1I;64@>F]N90H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;VYV97)T5%HH)'1Z*0H@("`@>PH@("`@("`@("\O(&-O;G9E
M<G0@=&\@551#"B`@("`@("`@:68@*"1T:&ES+3YT>BT^9V5T3V9F<V5T*"1T
M:&ES*2`^(#`I('L*("`@("`@("`@("`@)'1H:7,M/G-U8G1R86-T4V5C;VYD
M<RAI;G1V86PH86)S*"1T:&ES+3YT>BT^9V5T3V9F<V5T*"1T:&ES*2D@+R`Q
M,#`P*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F%D
M9%-E8V]N9',H:6YT=F%L*&%B<R@D=&AI<RT^='HM/F=E=$]F9G-E="@D=&AI
M<RDI("\@,3`P,"DI.PH@("`@("`@('T*("`@("`@("`O+R!C;VYV97)T(%54
M0R!T;R!N97<@=&EM97IO;F4*("`@("`@("!I9B`H)'1Z+3YG971/9F9S970H
M)'1H:7,I(#X@,"D@>PH@("`@("`@("`@("`D=&AI<RT^861D4V5C;VYD<RAI
M;G1V86PH86)S*"1T>BT^9V5T3V9F<V5T*"1T:&ES*2D@+R`Q,#`P*2D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/G-U8G1R86-T4V5C
M;VYD<RAI;G1V86PH86)S*"1T>BT^9V5T3V9F<V5T*"1T:&ES*2D@+R`Q,#`P
M*2D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YT>B`]("1T>CL*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S('1H:7,@9&%T92!T;R!A(&YE=R!T
M:6UE('IO;F4L(&=I=F5N(&$@=F%L:60@=&EM92!Z;VYE($E$"B`@("`@*@H@
M("`@("H@0V]N=F5R=',@=&AI<R!D871E('1O(&$@;F5W('1I;64@>F]N92P@
M9VEV96X@82!V86QI9"!T:6UE('IO;F4@240*("`@("`J(%=!4DY)3D<Z(%1H
M:7,@;6%Y(&YO="!W;W)K(&-O<G)E8W1L>2!I9B!Y;W5R('-Y<W1E;2!D;V5S
M(&YO="!A;&QO=PH@("`@("H@<'5T96YV*"D@;W(@:68@;&]C86QT:6UE*"D@
M9&]E<R!N;W0@=V]R:R!I;B!Y;W5R(&5N=FER;VYM96YT+B`@4V5E"B`@("`@
M*B!$871E.CI4:6UE6F]N93HZ:6Y$87EL:6=H=%1I;64H*2!F;W(@;6]R92!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'!A<F%M('-T<FEN9R!I9"!A('1I;64@>F]N92!I9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!C;VYV97)T5%IB>4E$*"1I9"D*("`@('L*("`@("`@(&EF
M("A$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED*2D@>PH@("`@("`@("`@
M)'1Z(#T@;F5W($1A=&5?5&EM95IO;F4H)&ED*3L*("`@("`@('T@96QS92![
M"B`@("`@("`@("`D='H@/2!$871E7U1I;65:;VYE.CIG971$969A=6QT*"D[
M"B`@("`@("!]"B`@("`@("`D=&AI<RT^8V]N=F5R=%1:*"1T>BD["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&]55$-B>4]F9G-E="@D;V9F<V5T*0H@("`@>PH@
M("`@("`@(&EF("@D;V9F<V5T(#T]("):(B!\?"`D;V9F<V5T(#T]("(K,#`Z
M,#`B('Q\("1O9F9S970@/3T@(BLP,#`P(BD@>PH@("`@("`@("`@("`D=&AI
M<RT^=&]55$,H*3L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?0H*("`@("`@("!I9B`H<')E9U]M871C:"@G+RA;7"M<+5TI*%QD>S)]*3H_
M*%QD>S)]*2\G+"`D;V9F<V5T+"`D<F5G<RDI('L*("`@("`@("`@("`@+R\@
M8V]N=F5R="!O9F9S970@=&\@<V5C;VYD<PH@("`@("`@("`@("`D:&]U<G,@
M(#T@*&EN="D@:7-S970H)')E9W-;,ETI/R1R96=S6S)=.C`["B`@("`@("`@
M("`@("1M:6YS("`@/2`H:6YT*2!I<W-E="@D<F5G<ULS72D_)')E9W-;,UTZ
M,#L*("`@("`@("`@("`@)&]F9G-E="`]("@D:&]U<G,@*B`S-C`P*2`K("@D
M;6EN<R`J(#8P*3L*"B`@("`@("`@("`@(&EF("AI<W-E="@D<F5G<ULQ72D@
M)B8@)')E9W-;,5T@/3T@(BTB*2!["B`@("`@("`@("`@("`@("`D;V9F<V5T
M("H]("TQ.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H)&]F9G-E
M="`^(#`I('L*("`@("`@("`@("`@("`@("1T:&ES+3YS=6)T<F%C=%-E8V]N
M9',H:6YT=F%L*"1O9F9S970I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YA9&1396-O;F1S*&EN='9A;"AA8G,H)&]F
M9G-E="DI*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/G1Z
M(#T@;F5W($1A=&5?5&EM95IO;F4H)U540R<I.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@82!G:79E;B!N=6UB97(@;V8@<V5C
M;VYD<R!T;R!T:&4@9&%T90H@("`@("H*("`@("`J($%D9',@82!G:79E;B!N
M=6UB97(@;V8@<V5C;VYD<R!T;R!T:&4@9&%T90H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@:6YT("1S96,@=&AE(&YU;6)E
M<B!O9B!S96-O;F1S('1O(&%D9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&13
M96-O;F1S*"1S96,I"B`@("!["B`@("`@("`@)'1H:7,M/F%D9%-P86XH;F5W
M($1A=&5?4W!A;B@H:6YT96=E<BDD<V5C*2D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&$@=&EM92!S<&%N('1O('1H92!D871E"B`@("`@*@H@("`@
M("H@061D<R!A('1I;64@<W!A;B!T;R!T:&4@9&%T90H@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&5?4W!A
M;B`D<W!A;B!T:&4@=&EM92!S<&%N('1O(&%D9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&13<&%N*"1S<&%N*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M<W!A;BP@)T1A=&5?4W!A;B<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YS96-O;F0@*ST@)'-P86XM/G-E8V]N
M9#L*("`@("`@("!I9B`H)'1H:7,M/G-E8V]N9"`^/2`V,"D@>PH@("`@("`@
M("`@("`D=&AI<RT^;6EN=71E*RL["B`@("`@("`@("`@("1T:&ES+3YS96-O
M;F0@+3T@-C`["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^;6EN=71E("L]
M("1S<&%N+3YM:6YU=&4["B`@("`@("`@:68@*"1T:&ES+3YM:6YU=&4@/CT@
M-C`I('L*("`@("`@("`@("`@)'1H:7,M/FAO=7(K*SL*("`@("`@("`@("`@
M:68@*"1T:&ES+3YH;W5R(#X](#(T*2!["B`@("`@("`@("`@("`@("!L:7-T
M*"1T:&ES+3YY96%R+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YD87DI(#T*("`@
M("`@("`@("`@("`@("`@("!S<V-A;F8H1&%T95]#86QC.CIN97AT1&%Y*"1T
M:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I+"`B)3`T<R4P
M,G,E,#)S(BD["B`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`M/2`R-#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^;6EN=71E("T](#8P
M.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/FAO=7(@*ST@)'-P86XM/FAO
M=7(["B`@("`@("`@:68@*"1T:&ES+3YH;W5R(#X](#(T*2!["B`@("`@("`@
M("`@(&QI<W0H)'1H:7,M/GEE87(L("1T:&ES+3YM;VYT:"P@)'1H:7,M/F1A
M>2D@/0H@("`@("`@("`@("`@("`@<W-C86YF*$1A=&5?0V%L8SHZ;F5X=$1A
M>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R*2P@(B4P
M-',E,#)S)3`R<R(I.PH@("`@("`@("`@("`D=&AI<RT^:&]U<B`M/2`R-#L*
M("`@("`@("!]"@H@("`@("`@("1D(#T@1&%T95]#86QC.CID871E5&]$87ES
M*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@
M("`@("1D("L]("1S<&%N+3YD87D["@H@("`@("`@(&QI<W0H)'1H:7,M/GEE
M87(L("1T:&ES+3YM;VYT:"P@)'1H:7,M/F1A>2D@/0H@("`@("`@("`@("!S
M<V-A;F8H1&%T95]#86QC.CID87ES5&]$871E*"1D*2P@(B4P-',E,#)S)3`R
M<R(I.PH@("`@("`@("1T:&ES+3YY96%R("`](&EN='9A;"@D=&AI<RT^>65A
M<BD["B`@("`@("`@)'1H:7,M/FUO;G1H(#T@:6YT=F%L*"1T:&ES+3YM;VYT
M:"D["B`@("`@("`@)'1H:7,M/F1A>2`@(#T@:6YT=F%L*"1T:&ES+3YD87DI
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4W5B=')A8W1S(&$@9VEV96X@;G5M
M8F5R(&]F('-E8V]N9',@9G)O;2!T:&4@9&%T90H@("`@("H*("`@("`J(%-U
M8G1R86-T<R!A(&=I=F5N(&YU;6)E<B!O9B!S96-O;F1S(&9R;VT@=&AE(&1A
M=&4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M(&EN="`D<V5C('1H92!N=6UB97(@;V8@<V5C;VYD<R!T;R!S=6)T<F%C=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S=6)T<F%C=%-E8V]N9',H)'-E8RD*("`@
M('L*("`@("`@("`D=&AI<RT^<W5B=')A8W13<&%N*&YE=R!$871E7U-P86XH
M)'-E8RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@4W5B=')A8W1S(&$@=&EM
M92!S<&%N('1O('1H92!D871E"B`@("`@*@H@("`@("H@4W5B=')A8W1S(&$@
M=&EM92!S<&%N('1O('1H92!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@1&%T95]3<&%N("1S<&%N('1H
M92!T:6UE('-P86X@=&\@<W5B=')A8W0*("`@("`J+PH@("`@9G5N8W1I;VX@
M<W5B=')A8W13<&%N*"1S<&%N*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D
M<W!A;BP@)T1A=&5?4W!A;B<I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@
M("`@("!]"B`@("`@("`@:68@*"1S<&%N+3YI<T5M<'1Y*"DI('L*("`@("`@
M("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G-E8V]N
M9"`M/2`D<W!A;BT^<V5C;VYD.PH@("`@("`@(&EF("@D=&AI<RT^<V5C;VYD
M(#P@,"D@>PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E+2T["B`@("`@("`@
M("`@("1T:&ES+3YS96-O;F0@*ST@-C`["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^;6EN=71E("T]("1S<&%N+3YM:6YU=&4["B`@("`@("`@:68@*"1T
M:&ES+3YM:6YU=&4@/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YH;W5R+2T[
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^:&]U<B`\(#`I('L*("`@("`@("`@
M("`@("`@(&QI<W0H)'1H:7,M/GEE87(L("1T:&ES+3YM;VYT:"P@)'1H:7,M
M/F1A>2D@/0H@("`@("`@("`@("`@("`@("`@('-S8V%N9BA$871E7T-A;&,Z
M.G!R979$87DH)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A
M<BDL("(E,#1S)3`R<R4P,G,B*3L*("`@("`@("`@("`@("`@("1T:&ES+3YH
M;W5R("L](#(T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YM
M:6YU=&4@*ST@-C`["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^:&]U<B`M
M/2`D<W!A;BT^:&]U<CL*("`@("`@("!I9B`H)'1H:7,M/FAO=7(@/"`P*2![
M"B`@("`@("`@("`@(&QI<W0H)'1H:7,M/GEE87(L("1T:&ES+3YM;VYT:"P@
M)'1H:7,M/F1A>2D@/0H@("`@("`@("`@("`@("`@<W-C86YF*$1A=&5?0V%L
M8SHZ<')E=D1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY
M96%R*2P@(B4P-',E,#)S)3`R<R(I.PH@("`@("`@("`@("`D=&AI<RT^:&]U
M<B`K/2`R-#L*("`@("`@("!]"@H@("`@("`@("1D(#T@1&%T95]#86QC.CID
M871E5&]$87ES*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE
M87(I.PH@("`@("`@("1D("T]("1S<&%N+3YD87D["@H@("`@("`@(&QI<W0H
M)'1H:7,M/GEE87(L("1T:&ES+3YM;VYT:"P@)'1H:7,M/F1A>2D@/0H@("`@
M("`@("`@("!S<V-A;F8H1&%T95]#86QC.CID87ES5&]$871E*"1D*2P@(B4P
M-',E,#)S)3`R<R(I.PH@("`@("`@("1T:&ES+3YY96%R("`](&EN='9A;"@D
M=&AI<RT^>65A<BD["B`@("`@("`@)'1H:7,M/FUO;G1H(#T@:6YT=F%L*"1T
M:&ES+3YM;VYT:"D["B`@("`@("`@)'1H:7,M/F1A>2`@(#T@:6YT=F%L*"1T
M:&ES+3YD87DI.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]M<&%R97,@='=O
M(&1A=&5S"B`@("`@*@H@("`@("H@0V]M<&%R97,@='=O(&1A=&5S+B`@4W5I
M=&%B;&4@9F]R('5S90H@("`@("H@:6X@<V]R=&EN9R!F=6YC=&EO;G,N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE
M8W0@1&%T92`D9#$@=&AE(&9I<G-T(&1A=&4*("`@("`J($!P87)A;2!O8FIE
M8W0@1&%T92`D9#(@=&AE('-E8V]N9"!D871E"B`@("`@*B!`<F5T=7)N(&EN
M="`P(&EF('1H92!D871E<R!A<F4@97%U86PL("TQ(&EF(&0Q(&ES(&)E9F]R
M92!D,BP@,2!I9B!D,2!I<R!A9G1E<B!D,@H@("`@("HO"B`@("!F=6YC=&EO
M;B!C;VUP87)E*"1D,2P@)&0R*0H@("`@>PH@("`@("`@("1D,2T^8V]N=F5R
M=%1:*&YE=R!$871E7U1I;65:;VYE*"=55$,G*2D["B`@("`@("`@)&0R+3YC
M;VYV97)T5%HH;F5W($1A=&5?5&EM95IO;F4H)U540R<I*3L*("`@("`@("`D
M9&%Y<S$@/2!$871E7T-A;&,Z.F1A=&54;T1A>7,H)&0Q+3YD87DL("1D,2T^
M;6]N=&@L("1D,2T^>65A<BD["B`@("`@("`@)&1A>7,R(#T@1&%T95]#86QC
M.CID871E5&]$87ES*"1D,BT^9&%Y+"`D9#(M/FUO;G1H+"`D9#(M/GEE87(I
M.PH@("`@("`@(&EF("@D9&%Y<S$@/"`D9&%Y<S(I(')E='5R;B`M,3L*("`@
M("`@("!I9B`H)&1A>7,Q(#X@)&1A>7,R*2!R971U<FX@,3L*("`@("`@("!I
M9B`H)&0Q+3YH;W5R(#P@)&0R+3YH;W5R*2!R971U<FX@+3$["B`@("`@("`@
M:68@*"1D,2T^:&]U<B`^("1D,BT^:&]U<BD@<F5T=7)N(#$["B`@("`@("`@
M:68@*"1D,2T^;6EN=71E(#P@)&0R+3YM:6YU=&4I(')E='5R;B`M,3L*("`@
M("`@("!I9B`H)&0Q+3YM:6YU=&4@/B`D9#(M/FUI;G5T92D@<F5T=7)N(#$[
M"B`@("`@("`@:68@*"1D,2T^<V5C;VYD(#P@)&0R+3YS96-O;F0I(')E='5R
M;B`M,3L*("`@("`@("!I9B`H)&0Q+3YS96-O;F0@/B`D9#(M/G-E8V]N9"D@
M<F5T=7)N(#$["B`@("`@("`@<F5T=7)N(#`["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!497-T(&EF('1H:7,@9&%T92]T:6UE(&ES(&)E9F]R92!A(&-E<G1A
M:6X@9&%T92]T:6UE"B`@("`@*@H@("`@("H@5&5S="!I9B!T:&ES(&1A=&4O
M=&EM92!I<R!B969O<F4@82!C97)T86EN(&1A=&4O=&EM90H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&4@
M)'=H96X@=&AE(&1A=&4@=&\@=&5S="!A9V%I;G-T"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@=')U92!I9B!T:&ES(&1A=&4@:7,@8F5F;W)E("1W:&5N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&)E9F]R92@D=VAE;BD*("`@('L*("`@("`@
M("!I9B`H1&%T93HZ8V]M<&%R92@D=&AI<RPD=VAE;BD@/3T@+3$I('L*("`@
M("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@:7,@869T97(@82!C97)T
M:6%N(&1A=&4O=&EM90H@("`@("H*("`@("`J(%1E<W0@:68@=&AI<R!D871E
M+W1I;64@:7,@869T97(@82!C97)T:6%N(&1A=&4O=&EM90H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@;V)J96-T($1A=&4@
M)'=H96X@=&AE(&1A=&4@=&\@=&5S="!A9V%I;G-T"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@=')U92!I9B!T:&ES(&1A=&4@:7,@869T97(@)'=H96X*("`@
M("`J+PH@("`@9G5N8W1I;VX@869T97(H)'=H96XI"B`@("!["B`@("`@("`@
M:68@*$1A=&4Z.F-O;7!A<F4H)'1H:7,L)'=H96XI(#T](#$I('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1E<W0@:68@=&AI<R!D871E+W1I;64@:7,@97AA8W1L>2!E<75A;"!T
M;R!A(&-E<G1I86X@9&%T92]T:6UE"B`@("`@*@H@("`@("H@5&5S="!I9B!T
M:&ES(&1A=&4O=&EM92!I<R!E>&%C=&QY(&5Q=6%L('1O(&$@8V5R=&EA;B!D
M871E+W1I;64*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'!A<F%M(&]B:F5C="!$871E("1W:&5N('1H92!D871E('1O('1E<W0@86=A
M:6YS=`H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI<R!D871E
M(&ES(&5X86-T;'D@97%U86P@=&\@)'=H96X*("`@("`J+PH@("`@9G5N8W1I
M;VX@97%U86QS*"1W:&5N*0H@("`@>PH@("`@("`@(&EF("A$871E.CIC;VUP
M87)E*"1T:&ES+"1W:&5N*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@
M:68@=&AI<R!D871E(&ES(&EN('1H92!F=71U<F4*("`@("`J"B`@("`@*B!$
M971E<FUI;F4@:68@=&AI<R!D871E(&ES(&EN('1H92!F=71U<F4*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!B;V]L96%N
M('1R=64@:68@=&AI<R!D871E(&ES(&EN('1H92!F=71U<F4*("`@("`J+PH@
M("`@9G5N8W1I;VX@:7-&=71U<F4H*0H@("`@>PH@("`@("`@("1N;W<@/2!N
M97<@1&%T92@I.PH@("`@("`@(&EF("@D=&AI<RT^869T97(H)&YO=RDI('L*
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN92!I9B!T:&ES(&1A=&4@:7,@:6X@=&AE('!A
M<W0*("`@("`J"B`@("`@*B!$971E<FUI;F4@:68@=&AI<R!D871E(&ES(&EN
M('1H92!P87-T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H:7,@9&%T92!I<R!I;B!T:&4@
M<&%S=`H@("`@("HO"B`@("!F=6YC=&EO;B!I<U!A<W0H*0H@("`@>PH@("`@
M("`@("1N;W<@/2!N97<@1&%T92@I.PH@("`@("`@(&EF("@D=&AI<RT^8F5F
M;W)E*"1N;W<I*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F4@:68@=&AE('EE87(@
M:6X@=&AI<R!D871E(&ES(&$@;&5A<"!Y96%R"B`@("`@*@H@("`@("H@1&5T
M97)M:6YE(&EF('1H92!Y96%R(&EN('1H:7,@9&%T92!I<R!A(&QE87`@>65A
M<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@=')U92!I9B!T:&ES('EE87(@:7,@82!L96%P('EE87(*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-,96%P665A<B@I"B`@("!["B`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ:7-,96%P665A<B@D=&AI<RT^>65A<BD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE($IU;&EA;B!D871E(&9O<B!T
M:&ES(&1A=&4*("`@("`J"B`@("`@*B!'970@=&AE($IU;&EA;B!D871E(&9O
M<B!T:&ES(&1A=&4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0')E='5R;B!I;G0@=&AE($IU;&EA;B!D871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$IU;&EA;D1A=&4H*0H@("`@>PH@("`@("`@(')E='5R;B!$
M871E7T-A;&,Z.FIU;&EA;D1A=&4H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H
M+"`D=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H
M92!D87D@;V8@=&AE('=E96L@9F]R('1H:7,@9&%T90H@("`@("H*("`@("`J
M($=E=',@=&AE(&1A>2!O9B!T:&4@=V5E:R!F;W(@=&AI<R!D871E("@P/5-U
M;F1A>2D*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E
M='5R;B!I;G0@=&AE(&1A>2!O9B!T:&4@=V5E:R`H,#U3=6YD87DI"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$1A>4]F5V5E:R@I"B`@("!["B`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ9&%Y3V97965K*"1T:&ES+3YD87DL("1T:&ES
M+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1V5T<R!T:&4@=V5E:R!O9B!T:&4@>65A<B!F;W(@=&AI<R!D871E"B`@("`@
M*@H@("`@("H@1V5T<R!T:&4@=V5E:R!O9B!T:&4@>65A<B!F;W(@=&AI<R!D
M871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U
M<FX@:6YT('1H92!W965K(&]F('1H92!Y96%R"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%=E96M/9EEE87(H*0H@("`@>PH@("`@("`@(')E='5R;B!$871E
M7T-A;&,Z.G=E96M/9EEE87(H)'1H:7,M/F1A>2P@)'1H:7,M/FUO;G1H+"`D
M=&AI<RT^>65A<BD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!Q
M=6%R=&5R(&]F('1H92!Y96%R(&9O<B!T:&ES(&1A=&4*("`@("`J"B`@("`@
M*B!'971S('1H92!Q=6%R=&5R(&]F('1H92!Y96%R(&9O<B!T:&ES(&1A=&4*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I
M;G0@=&AE('%U87)T97(@;V8@=&AE('EE87(@*#$M-"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T475A<G1E<D]F665A<B@I"B`@("!["B`@("`@("`@<F5T
M=7)N($1A=&5?0V%L8SHZ<75A<G1E<D]F665A<B@D=&AI<RT^9&%Y+"`D=&AI
M<RT^;6]N=&@L("1T:&ES+3YY96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E=',@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&UO;G1H(&9O<B!T:&ES(&1A
M=&4*("`@("`J"B`@("`@*B!'971S(&YU;6)E<B!O9B!D87ES(&EN('1H92!M
M;VYT:"!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!R971U<FX@:6YT(&YU;6)E<B!O9B!D87ES(&EN('1H:7,@
M;6]N=&@*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1&%Y<TEN36]N=&@H*0H@
M("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"1T
M:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1V5T<R!T:&4@;G5M8F5R(&]F('=E96MS(&EN('1H92!M;VYT:"!F;W(@
M=&AI<R!D871E"B`@("`@*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F('=E
M96MS(&EN('1H92!M;VYT:"!F;W(@=&AI<R!D871E"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT(&YU;6)E<B!O9B!W
M965K<R!I;B!T:&ES(&UO;G1H"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%=E
M96MS26Y-;VYT:"@I"B`@("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ
M=V5E:W-);DUO;G1H*"1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@9G5L;"!N86UE(&]R(&%B8G)I
M=FEA=&5D(&YA;64@;V8@=&AI<R!W965K9&%Y"B`@("`@*@H@("`@("H@1V5T
M<R!T:&4@9G5L;"!N86UE(&]R(&%B8G)I=FEA=&5D(&YA;64@;V8@=&AI<R!W
M965K9&%Y"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2!B;V]L96%N("1A8F)R(&%B8G)I=F%T92!T:&4@;F%M90H@("`@("H@
M0')E='5R;B!S=')I;F<@;F%M92!O9B!T:&ES(&1A>0H@("`@("HO"B`@("!F
M=6YC=&EO;B!G971$87E.86UE*"1A8F)R(#T@9F%L<V4L("1L96YG=&@@/2`S
M*0H@("`@>PH@("`@("`@(&EF("@D86)B<BD@>PH@("`@("`@("`@("!R971U
M<FX@1&%T95]#86QC.CIG9717965K9&%Y06)B<FYA;64H)'1H:7,M/F1A>2P@
M)'1H:7,M/FUO;G1H+"`D=&AI<RT^>65A<BP@)&QE;F=T:"D["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9V5T5V5E
M:V1A>49U;&QN86UE*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M
M/GEE87(I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@
M=&AE(&9U;&P@;F%M92!O<B!A8F)R:79I871E9"!N86UE(&]F('1H:7,@;6]N
M=&@*("`@("`J"B`@("`@*B!'971S('1H92!F=6QL(&YA;64@;W(@86)B<FEV
M:6%T960@;F%M92!O9B!T:&ES(&UO;G1H"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!P87)A;2!B;V]L96%N("1A8F)R(&%B8G)I=F%T
M92!T:&4@;F%M90H@("`@("H@0')E='5R;B!S=')I;F<@;F%M92!O9B!T:&ES
M(&UO;G1H"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$UO;G1H3F%M92@D86)B
M<B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@D86)B<BD@>PH@("`@("`@
M("`@("!R971U<FX@1&%T95]#86QC.CIG971-;VYT:$%B8G)N86UE*"1T:&ES
M+3YM;VYT:"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M($1A=&5?0V%L8SHZ9V5T36]N=&A&=6QL;F%M92@D=&AI<RT^;6]N=&@I.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($=E="!A($1A=&4@;V)J
M96-T(&9O<B!T:&4@9&%Y(&%F=&5R('1H:7,@;VYE"B`@("`@*@H@("`@("H@
M1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H92!D87D@869T97(@=&AI<R!O;F4N
M"B`@("`@*B!4:&4@=&EM92!O9B!T:&4@<F5T=7)N960@1&%T92!O8FIE8W0@
M:7,@=&AE('-A;64@87,@=&AI<R!T:6UE+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$871E($1A=&4@<F5P
M<F5S96YT:6YG('1H92!N97AT(&1A>0H@("`@("HO"B`@("!F=6YC=&EO;B!G
M971.97AT1&%Y*"D*("`@('L*("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CIN
M97AT1&%Y*"1T:&ES+3YD87DL("1T:&ES+3YM;VYT:"P@)'1H:7,M/GEE87(L
M("(E62TE;2TE9"(I.PH@("`@("`@("1D871E(#T@<W!R:6YT9B@B)7,@)3`R
M9#HE,#)D.B4P,F0B+"`D9&%Y+"`D=&AI<RT^:&]U<BP@)'1H:7,M/FUI;G5T
M92P@)'1H:7,M/G-E8V]N9"D["B`@("`@("`@)&YE=T1A=&4@/2!N97<@1&%T
M92@I.PH@("`@("`@("1N97=$871E+3YS971$871E*"1D871E*3L*("`@("`@
M("!R971U<FX@)&YE=T1A=&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@
M82!$871E(&]B:F5C="!F;W(@=&AE(&1A>2!B969O<F4@=&AI<R!O;F4*("`@
M("`J"B`@("`@*B!'970@82!$871E(&]B:F5C="!F;W(@=&AE(&1A>2!B969O
M<F4@=&AI<R!O;F4N"B`@("`@*B!4:&4@=&EM92!O9B!T:&4@<F5T=7)N960@
M1&%T92!O8FIE8W0@:7,@=&AE('-A;64@87,@=&AI<R!T:6UE+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&]B:F5C="!$
M871E($1A=&4@<F5P<F5S96YT:6YG('1H92!P<F5V:6]U<R!D87D*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4')E=D1A>2@I"B`@("!["B`@("`@("`@)&1A
M>2`]($1A=&5?0V%L8SHZ<')E=D1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N
M=&@L("1T:&ES+3YY96%R+"`B)5DM)6TM)60B*3L*("`@("`@("`D9&%T92`]
M('-P<FEN=&8H(B5S("4P,F0Z)3`R9#HE,#)D(BP@)&1A>2P@)'1H:7,M/FAO
M=7(L("1T:&ES+3YM:6YU=&4L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("1N
M97=$871E(#T@;F5W($1A=&4H*3L*("`@("`@("`D;F5W1&%T92T^<V5T1&%T
M92@D9&%T92D["B`@("`@("`@<F5T=7)N("1N97=$871E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1V5T(&$@1&%T92!O8FIE8W0@9F]R('1H92!W965K9&%Y
M(&%F=&5R('1H:7,@;VYE"B`@("`@*@H@("`@("H@1V5T(&$@1&%T92!O8FIE
M8W0@9F]R('1H92!W965K9&%Y(&%F=&5R('1H:7,@;VYE+@H@("`@("H@5&AE
M('1I;64@;V8@=&AE(')E='5R;F5D($1A=&4@;V)J96-T(&ES('1H92!S86UE
M(&%S('1H:7,@=&EM92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!O8FIE8W0@1&%T92!$871E(')E<')E<V5N=&EN9R!T
M:&4@;F5X="!W965K9&%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$YE>'17
M965K9&%Y*"D*("`@('L*("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CIN97AT
M5V5E:V1A>2@D=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R
M+"`B)5DM)6TM)60B*3L*("`@("`@("`D9&%T92`]('-P<FEN=&8H(B5S("4P
M,F0Z)3`R9#HE,#)D(BP@)&1A>2P@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU
M=&4L("1T:&ES+3YS96-O;F0I.PH@("`@("`@("1N97=$871E(#T@;F5W($1A
M=&4H*3L*("`@("`@("`D;F5W1&%T92T^<V5T1&%T92@D9&%T92D["B`@("`@
M("`@<F5T=7)N("1N97=$871E.PH@("`@?0H*("`@("\J*@H@("`@("H@1V5T
M(&$@1&%T92!O8FIE8W0@9F]R('1H92!W965K9&%Y(&)E9F]R92!T:&ES(&]N
M90H@("`@("H*("`@("`J($=E="!A($1A=&4@;V)J96-T(&9O<B!T:&4@=V5E
M:V1A>2!B969O<F4@=&AI<R!O;F4N"B`@("`@*B!4:&4@=&EM92!O9B!T:&4@
M<F5T=7)N960@1&%T92!O8FIE8W0@:7,@=&AE('-A;64@87,@=&AI<R!T:6UE
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="!$871E($1A=&4@<F5P<F5S96YT:6YG('1H92!P<F5V:6]U<R!W
M965K9&%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%!R9797965K9&%Y*"D*
M("`@('L*("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CIP<F5V5V5E:V1A>2@D
M=&AI<RT^9&%Y+"`D=&AI<RT^;6]N=&@L("1T:&ES+3YY96%R+"`B)5DM)6TM
M)60B*3L*("`@("`@("`D9&%T92`]('-P<FEN=&8H(B5S("4P,F0Z)3`R9#HE
M,#)D(BP@)&1A>2P@)'1H:7,M/FAO=7(L("1T:&ES+3YM:6YU=&4L("1T:&ES
M+3YS96-O;F0I.PH@("`@("`@("1N97=$871E(#T@;F5W($1A=&4H*3L*("`@
M("`@("`D;F5W1&%T92T^<V5T1&%T92@D9&%T92D["B`@("`@("`@<F5T=7)N
M("1N97=$871E.PH@("`@?0H*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('EE87(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@
M4F5T=7)N<R!T:&4@>65A<B!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@
M=&AE('EE87(*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T665A<B@I"B`@("![
M"B`@("`@("`@<F5T=7)N("AI;G0I)'1H:7,M/GEE87(["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!M;VYT:"!F:65L9"!O9B!T:&4@9&%T
M92!O8FIE8W0*("`@("`J"B`@("`@*B!2971U<FYS('1H92!M;VYT:"!F:65L
M9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0')E='5R;B!I;G0@=&AE(&UO;G1H"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$UO;G1H*"D*("`@('L*("`@("`@("!R971U<FX@*&EN
M="DD=&AI<RT^;6]N=&@["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!D87D@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@
M("H@4F5T=7)N<R!T:&4@9&%Y(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN
M="!T:&4@9&%Y"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1A>2@I"B`@("![
M"B`@("`@("`@<F5T=7)N("AI;G0I)'1H:7,M/F1A>3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&AO=7(@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@:&]U<B!F:65L9"!O
M9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0')E='5R;B!I;G0@=&AE(&AO=7(*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T2&]U<B@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YH
M;W5R.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;6EN=71E
M(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@("`@("H*("`@("`J(%)E='5R
M;G,@=&AE(&UI;G5T92!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@=&AE
M(&UI;G5T90H@("`@("HO"B`@("!F=6YC=&EO;B!G971-:6YU=&4H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^;6EN=71E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!T:&4@<V5C;VYD(&9I96QD(&]F('1H92!D871E
M(&]B:F5C=`H@("`@("H*("`@("`J(%)E='5R;G,@=&AE('-E8V]N9"!F:65L
M9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0')E='5R;B!I;G0@=&AE('-E8V]N9`H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971396-O;F0H*0H@("`@>PH@("`@("`@("!R971U<FX@
M)'1H:7,M/G-E8V]N9#L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@
M>65A<B!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3
M970@=&AE('EE87(@9FEE;&0@;V8@=&AE(&1A=&4@;V)J96-T+"!I;G9A;&ED
M('EE87)S("AN;W0@,"TY.3DY*2!A<F4@<V5T('1O(#`N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@)'D@=&AE('EE
M87(*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T665A<B@D>2D*("`@('L*("`@
M("`@("!I9B`H)'D@/"`P('Q\("1Y(#X@.3DY.2D@>PH@("`@("`@("`@("`D
M=&AI<RT^>65A<B`](#`["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/GEE87(@/2`D>3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3970@=&AE(&UO;G1H(&9I96QD(&]F('1H92!D871E(&]B:F5C=`H@
M("`@("H*("`@("`J(%-E="!T:&4@;6]N=&@@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T+"!I;G9A;&ED(&UO;G1H<R`H;F]T(#$M,3(I(&%R92!S970@=&\@
M,2X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M
M(&EN="`D;2!T:&4@;6]N=&@*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T36]N
M=&@H)&TI"B`@("!["B`@("`@("`@:68@*"1M(#P@,2!\?"`D;2`^(#$R*2![
M"B`@("`@("`@("`@("1T:&ES+3YM;VYT:"`](#$["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/FUO;G1H(#T@)&T["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!D87D@9FEE;&0@;V8@=&AE
M(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H92!D87D@9FEE;&0@
M;V8@=&AE(&1A=&4@;V)J96-T+"!I;G9A;&ED(&1A>7,@*&YO="`Q+3,Q*2!A
M<F4@<V5T('1O(#$N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!P87)A;2!I;G0@)&0@=&AE(&1A>0H@("`@("HO"B`@("!F=6YC=&EO
M;B!S971$87DH)&0I"B`@("!["B`@("`@("`@:68@*"1D(#X@,S$@?'P@)&0@
M/"`Q*2!["B`@("`@("`@("`@("1T:&ES+3YD87D@/2`Q.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T:&ES+3YD87D@/2`D9#L*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE(&AO=7(@9FEE;&0@;V8@
M=&AE(&1A=&4@;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H92!H;W5R(&9I
M96QD(&]F('1H92!D871E(&]B:F5C="!I;B`R-"UH;W5R(&9O<FUA="X*("`@
M("`J($EN=F%L:60@:&]U<G,@*&YO="`P+3(S*2!A<F4@<V5T('1O(#`N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!I;G0@
M)&@@=&AE(&AO=7(*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2&]U<B@D:"D*
M("`@('L*("`@("`@("!I9B`H)&@@/B`R,R!\?"`D:"`\(#`I('L*("`@("`@
M("`@("`@)'1H:7,M/FAO=7(@/2`P.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3YH;W5R(#T@)&@["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@4V5T('1H92!M:6YU=&4@9FEE;&0@;V8@=&AE(&1A=&4@
M;V)J96-T"B`@("`@*@H@("`@("H@4V5T('1H92!M:6YU=&4@9FEE;&0@;V8@
M=&AE(&1A=&4@;V)J96-T+"!I;G9A;&ED(&UI;G5T97,@*&YO="`P+34Y*2!A
M<F4@<V5T('1O(#`N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!P87)A;2!I;G0@)&T@=&AE(&UI;G5T90H@("`@("HO"B`@("!F=6YC
M=&EO;B!S971-:6YU=&4H)&TI"B`@("!["B`@("`@("`@:68@*"1M(#X@-3D@
M?'P@)&T@/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4@/2`P.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YM:6YU=&4@/2`D
M;3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('-E
M8V]N9"!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0*("`@("`J"B`@("`@*B!3
M970@=&AE('-E8V]N9"!F:65L9"!O9B!T:&4@9&%T92!O8FIE8W0L(&EN=F%L
M:60@<V5C;VYD<R`H;F]T(#`M-3DI(&%R92!S970@=&\@,"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M(&EN="`D<R!T:&4@
M<V5C;VYD"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=%-E8V]N9"@D<RD@>PH@
M("`@("`@(&EF("@D<R`^(#4Y('Q\("1S(#P@,"D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5C;VYD(#T@,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5C;VYD(#T@)',["B`@("`@("`@?0H@("`@?0I]"@H_/@IU
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70N<&AP````````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P,3`@
M,3`U,34T,S0Q,S4@,#(P-#4S`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T
M86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*
M("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P
M-2P@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN
M9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U
M=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H
M(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R
M;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M
M970Z"B`J"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@
M;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E
M+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D
M:7-C;&%I;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA
M<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J
M("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T
M:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4*
M("H@("`@(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA
M;64@;V8@4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES
M"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O
M<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S
M;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES
M<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@
M0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@*B`B05,@25,B
M($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ5
M1$E.1RP@0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)2
M04Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534PH@*B!&3U(@
M02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($56
M14Y4(%-(04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E54
M3U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.
M0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!
M3"!$04U!1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@
M4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*
M("H@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3
M($E.5$524E505$E/3BD@2$]7159%4@H@*B!#0553140@04Y$($].($%.62!4
M2$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))
M0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%
M($]2($]42$525TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!4
M2$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!4
M2$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E
M9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T
M:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G
M;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"
M97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL
M:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z(%!(4%5N:70N<&AP+'8@,2XQ-R`R,#`U+S$Q+S$P(#`Y.C0W.C$Q('-E
M8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=0
M2%!5;FET+U1E<W1#87-E+G!H<"<["G)E<75I<F5?;VYC92`G4$A056YI="]4
M97-T4F5S=6QT+G!H<"<["G)E<75I<F5?;VYC92`G4$A056YI="]497-T4W5I
M=&4N<&AP)SL*"B\J*@H@*B!02%!5;FET(')U;G,@82!497-T4W5I=&4@86YD
M(')E='5R;G,@82!497-T4F5S=6QT(&]B:F5C="X*("H*("H@2&5R92!I<R!A
M;B!E>&%M<&QE.@H@*@H@*B`\8V]D93X*("H@/#]P:'`*("H@<F5Q=6ER95]O
M;F-E("=02%!5;FET+G!H<"<["B`J"B`J(&-L87-S($UA=&A497-T(&5X=&5N
M9',@4$A056YI=%]497-T0V%S92!["B`J("`@("!V87(@)&9686QU93$["B`J
M("`@("!V87(@)&9686QU93(["B`J"B`J("`@("!F=6YC=&EO;B!-871H5&5S
M="@D;F%M92D@>PH@*B`@("`@("`D=&AI<RT^4$A056YI=%]497-T0V%S92@D
M;F%M92D["B`J("`@("!]"B`J"B`J("`@("!F=6YC=&EO;B!S9715<"@I('L*
M("H@("`@("`@)'1H:7,M/F9686QU93$@/2`R.PH@*B`@("`@("`D=&AI<RT^
M9E9A;'5E,B`](#,["B`J("`@("!]"B`J"B`J("`@("!F=6YC=&EO;B!T97-T
M061D*"D@>PH@*B`@("`@("`D=&AI<RT^87-S97)T5')U92@D=&AI<RT^9E9A
M;'5E,2`K("1T:&ES+3YF5F%L=64R(#T](#4I.PH@*B`@("`@?0H@*B!]"B`J
M"B`J("1S=6ET92`](&YE=R!02%!5;FET7U1E<W13=6ET92@I.PH@*B`D<W5I
M=&4M/F%D9%1E<W0H;F5W($UA=&A497-T*"=T97-T061D)RDI.PH@*@H@*B`D
M<F5S=6QT(#T@4$A056YI=#HZ<G5N*"1S=6ET92D["B`J('!R:6YT("1R97-U
M;'0M/G1O2%1-3"@I.PH@*B`_/@H@*B`\+V-O9&4^"B`J"B`J($%L=&5R;F%T
M:79E;'DL('EO=2!C86X@<&%S<R!A(&-L87-S(&YA;64@=&\@=&AE(%!(4%5N
M:71?5&5S=%-U:71E*"D*("H@8V]N<W1R=6-T;W(@86YD(&QE="!I="!A=71O
M;6%T:6-A;&QY(&%D9"!A;&P@;65T:&]D<R!O9B!T:&%T(&-L87-S"B`J('1H
M870@<W1A<G0@=VET:"`G=&5S="<@=&\@=&AE('-U:71E.@H@*@H@*B`\8V]D
M93X*("H@/#]P:'`*("H@)'-U:71E("`](&YE=R!02%!5;FET7U1E<W13=6ET
M92@G36%T:%1E<W0G*3L*("H@)')E<W5L="`](%!(4%5N:70Z.G)U;B@D<W5I
M=&4I.PH@*B!P<FEN="`D<F5S=6QT+3YT;TA434PH*3L*("H@/SX*("H@/"]C
M;V1E/@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@
M(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS
M8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M
M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N
M;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@
M($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S
M<R!02%!5;FET('L*("`@("\J*@H@("`@("H@4G5N<R!A('1E<W0H<W5I=&4I
M+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960*("`@("`J($!R971U<FX@
M4$A056YI=%]497-T4F5S=6QT"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B`F<G5N*"8D<W5I=&4I('L*("`@("`@("`D<F5S
M=6QT(#T@;F5W(%!(4%5N:71?5&5S=%)E<W5L="@I.PH@("`@("`@("1S=6ET
M92T^<G5N*"1R97-U;'0I.PH*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@
M('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*
M("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD
M97(M<#H@;FEL"B`J($5N9#H*("HO"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O1$(N<&AP````````````````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$Q-#`S,2`Q,#4Q-30S-#$S
M-2`P,3<T-C$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@1&%T86)A
M<V4@:6YD97!E;F1E;G0@<75E<GD@:6YT97)F86-E"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\
M<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O
M>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z($1"+G!H<"QV(#$N.#`@,C`P-2\P,B\Q-B`P,CHQ
M-CHP,"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE(%!%
M05(@8VQA<W,@<V\@:70@8V%N(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I
M<F5?;VYC92`G4$5!4BYP:'`G.PH*"B\O('M[>R!C;VYS=&%N=',*+R\@>WM[
M(&5R<F]R(&-O9&5S"@HO*BHC0"L*("H@3VYE(&]F(%!%05(@1$(G<R!P;W)T
M86)L92!E<G)O<B!C;V1E<RX*("H@0'-E92!$0E]C;VUM;VXZ.F5R<F]R0V]D
M92@I+"!$0CHZ97)R;W)-97-S86=E*"D*("H*("H@>T!I;G1E<FYA;"!)9B!Y
M;W4@861D(&%N(&5R<F]R(&-O9&4@:&5R92P@;6%K92!S=7)E('EO=2!A;'-O
M(&%D9"!A('1E>'1U86P*("H@=F5R<VEO;B!O9B!I="!I;B!$0CHZ97)R;W)-
M97-S86=E*"DN?7T*("HO"@HO*BH*("H@5&AE(&-O9&4@<F5T=7)N960@8GD@
M;6%N>2!M971H;V1S('5P;VX@<W5C8V5S<PH@*B\*9&5F:6YE*"=$0E]/2R<L
M(#$I.PH*+RHJ"B`J(%5N:V]W;B!E<G)O<@H@*B\*9&5F:6YE*"=$0E]%4E)/
M4B<L("TQ*3L*"B\J*@H@*B!3>6YT87@@97)R;W(*("HO"F1E9FEN92@G1$)?
M15)23U)?4UE.5$%8)RP@+3(I.PH*+RHJ"B`J(%1R:65D('1O(&EN<V5R="!A
M(&1U<&QI8V%T92!V86QU92!I;G1O(&$@<')I;6%R>2!O<B!U;FEQ=64@:6YD
M97@*("HO"F1E9FEN92@G1$)?15)23U)?0T].4U1204E.5"<L("TS*3L*"B\J
M*@H@*B!!;B!I9&5N=&EF:65R(&EN('1H92!Q=65R>2!R969E<G,@=&\@82!N
M;VXM97AI<W1A;G0@;V)J96-T"B`J+PID969I;F4H)T1"7T524D]27TY/5%]&
M3U5.1"<L("TT*3L*"B\J*@H@*B!4<FEE9"!T;R!C<F5A=&4@82!D=7!L:6-A
M=&4@;V)J96-T"B`J+PID969I;F4H)T1"7T524D]27T%,4D5!1%E?15A)4U13
M)RP@+34I.PH*+RHJ"B`J(%1H92!C=7)R96YT(&1R:79E<B!D;V5S(&YO="!S
M=7!P;W)T('1H92!A8W1I;VX@>6]U(&%T=&5M<'1E9`H@*B\*9&5F:6YE*"=$
M0E]%4E)/4E]53E-54%!/4E1%1"<L("TV*3L*"B\J*@H@*B!4:&4@;G5M8F5R
M(&]F('!A<F%M971E<G,@9&]E<R!N;W0@;6%T8V@@=&AE(&YU;6)E<B!O9B!P
M;&%C96AO;&1E<G,*("HO"F1E9FEN92@G1$)?15)23U)?34E334%40T@G+"`M
M-RD["@HO*BH*("H@02!L:71E<F%L('-U8FUI='1E9"!D:60@;F]T(&UA=&-H
M('1H92!D871A('1Y<&4@97AP96-T960*("HO"F1E9FEN92@G1$)?15)23U)?
M24Y604Q)1"<L("TX*3L*"B\J*@H@*B!4:&4@8W5R<F5N="!$0DU3(&1O97,@
M;F]T('-U<'!O<G0@=&AE(&%C=&EO;B!Y;W4@871T96UP=&5D"B`J+PID969I
M;F4H)T1"7T524D]27TY/5%]#05!!0DQ%)RP@+3DI.PH*+RHJ"B`J($$@;&ET
M97)A;"!S=6)M:71T960@=V%S('1O;R!L;VYG('-O('1H92!E;F0@;V8@:70@
M=V%S(')E;6]V960*("HO"F1E9FEN92@G1$)?15)23U)?5%)53D-!5$5$)RP@
M+3$P*3L*"B\J*@H@*B!!(&QI=&5R86P@;G5M8F5R('-U8FUI='1E9"!D:60@
M;F]T(&UA=&-H('1H92!D871A('1Y<&4@97AP96-T960*("HO"F1E9FEN92@G
M1$)?15)23U)?24Y604Q)1%].54U"15(G+"`M,3$I.PH*+RHJ"B`J($$@;&ET
M97)A;"!D871E('-U8FUI='1E9"!D:60@;F]T(&UA=&-H('1H92!D871A('1Y
M<&4@97AP96-T960*("HO"F1E9FEN92@G1$)?15)23U)?24Y604Q)1%]$051%
M)RP@+3$R*3L*"B\J*@H@*B!!='1E;7!T('1O(&1I=FED92!S;VUE=&AI;F<@
M8GD@>F5R;PH@*B\*9&5F:6YE*"=$0E]%4E)/4E]$259:15)/)RP@+3$S*3L*
M"B\J*@H@*B!!(&1A=&%B87-E(&YE961S('1O(&)E('-E;&5C=&5D"B`J+PID
M969I;F4H)T1"7T524D]27TY/1$)314Q%0U1%1"<L("TQ-"D["@HO*BH*("H@
M0V]U;&0@;F]T(&-R96%T92!T:&4@;V)J96-T(')E<75E<W1E9`H@*B\*9&5F
M:6YE*"=$0E]%4E)/4E]#04Y.3U1?0U)%051%)RP@+3$U*3L*"B\J*@H@*B!#
M;W5L9"!N;W0@9')O<"!T:&4@9&%T86)A<V4@<F5Q=65S=&5D(&)E8V%U<V4@
M:70@9&]E<R!N;W0@97AI<W0*("HO"F1E9FEN92@G1$)?15)23U)?0T%.3D]4
M7T123U`G+"`M,3<I.PH*+RHJ"B`J($%N(&ED96YT:69I97(@:6X@=&AE('%U
M97)Y(')E9F5R<R!T;R!A(&YO;BUE>&ES=&%N="!T86)L90H@*B\*9&5F:6YE
M*"=$0E]%4E)/4E].3U-50TA404),12<L("TQ."D["@HO*BH*("H@06X@:61E
M;G1I9FEE<B!I;B!T:&4@<75E<GD@<F5F97)S('1O(&$@;F]N+65X:7-T86YT
M(&-O;'5M;@H@*B\*9&5F:6YE*"=$0E]%4E)/4E].3U-50TA&245,1"<L("TQ
M.2D["@HO*BH*("H@5&AE(&1A=&$@<W5B;6ET=&5D('1O('1H92!M971H;V0@
M=V%S(&EN87!P<F]P<FEA=&4*("HO"F1E9FEN92@G1$)?15)23U)?3D5%1%]-
M3U)%7T1!5$$G+"`M,C`I.PH*+RHJ"B`J(%1H92!A='1E;7!T('1O(&QO8VL@
M=&AE('1A8FQE(&9A:6QE9`H@*B\*9&5F:6YE*"=$0E]%4E)/4E].3U1?3$]#
M2T5$)RP@+3(Q*3L*"B\J*@H@*B!4:&4@;G5M8F5R(&]F(&-O;'5M;G,@9&]E
M<VXG="!M871C:"!T:&4@;G5M8F5R(&]F('9A;'5E<PH@*B\*9&5F:6YE*"=$
M0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<G+"`M,C(I.PH*+RHJ"B`J(%1H
M92!$4TX@<W5B;6ET=&5D(&AA<R!P<F]B;&5M<PH@*B\*9&5F:6YE*"=$0E]%
M4E)/4E])3E9!3$E$7T133B<L("TR,RD["@HO*BH*("H@0V]U;&0@;F]T(&-O
M;FYE8W0@=&\@=&AE(&1A=&%B87-E"B`J+PID969I;F4H)T1"7T524D]27T-/
M3DY%0U1?1D%)3$5$)RP@+3(T*3L*"B\J*@H@*B!4:&4@4$A0(&5X=&5N<VEO
M;B!N965D960@9F]R('1H:7,@1$)-4R!C;W5L9"!N;W0@8F4@9F]U;F0*("HO
M"F1E9FEN92@G1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"<L+3(U*3L*
M"B\J*@H@*B!4:&4@<')E<V5N="!U<V5R(&AA<R!I;F%D97%U871E('!E<FUI
M<W-I;VYS('1O('!E<F9O<FT@=&AE('1A<VL@<F5Q=65S=&0*("HO"F1E9FEN
M92@G1$)?15)23U)?04-#15-37U9)3TQ!5$E/3B<L("TR-BD["@HO*BH*("H@
M5&AE(&1A=&%B87-E(')E<75E<W1E9"!D;V5S(&YO="!E>&ES=`H@*B\*9&5F
M:6YE*"=$0E]%4E)/4E].3U-50TA$0B<L("TR-RD["@HO*BH*("H@5')I960@
M=&\@:6YS97)T(&$@;G5L;"!V86QU92!I;G1O(&$@8V]L=6UN('1H870@9&]E
M<VXG="!A;&QO=R!N=6QL<PH@*B\*9&5F:6YE*"=$0E]%4E)/4E]#3TY35%)!
M24Y47TY/5%].54Q,)RPM,CDI.PHO*BHC0"TJ+PH*"B\O('U]?0HO+R![>WL@
M<')E<&%R960@<W1A=&5M96YT+7)E;&%T960*"@HO*BHC0"L*("H@261E;G1I
M9FEE<G,@9F]R('1H92!P;&%C96AO;&1E<G,@=7-E9"!I;B!P<F5P87)E9"!S
M=&%T96UE;G1S+@H@*B!`<V5E($1"7V-O;6UO;CHZ<')E<&%R92@I"B`J+PH*
M+RHJ"B`J($EN9&EC871E<R!A('-C86QA<B`H/&MB9#X_/"]K8F0^*2!P;&%C
M96AO;&1E<B!W87,@=7-E9`H@*@H@*B!1=6]T92!A;F0@97-C87!E('1H92!V
M86QU92!A<R!N96-E<W-A<GDN"B`J+PID969I;F4H)T1"7U!!4D%-7U-#04Q!
M4B<L(#$I.PH*+RHJ"B`J($EN9&EC871E<R!A;B!O<&%Q=64@*#QK8F0^)CPO
M:V)D/BD@<&QA8V5H;VQD97(@=V%S('5S960*("H*("H@5&AE('9A;'5E('!R
M97-E;G1E9"!I<R!A(&9I;&4@;F%M92X@($5X=')A8W0@=&AE(&-O;G1E;G1S
M(&]F('1H870@9FEL90H@*B!A;F0@<&QA8V4@=&AE;2!I;B!T:&ES(&-O;'5M
M;BX*("HO"F1E9FEN92@G1$)?4$%204U?3U!!455%)RP@,BD["@HO*BH*("H@
M26YD:6-A=&5S(&$@;6ES8R`H/&MB9#XA/"]K8F0^*2!P;&%C96AO;&1E<B!W
M87,@=7-E9`H@*@H@*B!4:&4@=F%L=64@<VAO=6QD(&YO="!B92!Q=6]T960@
M;W(@97-C87!E9"X*("HO"F1E9FEN92@G1$)?4$%204U?34E30R<L("`@,RD[
M"B\J*B-`+2HO"@H*+R\@?7U]"B\O('M[>R!B:6YA<GD@9&%T82UR96QA=&5D
M"@H*+RHJ(T`K"B`J(%1H92!D:69F97)E;G0@=V%Y<R!O9B!R971U<FYI;F<@
M8FEN87)Y(&1A=&$@9G)O;2!Q=65R:65S+@H@*B\*"B\J*@H@*B!396YD<R!T
M:&4@9F5T8VAE9"!D871A('-T<F%I9VAT('1H<F]U9V@@=&\@;W5T<'5T"B`J
M+PID969I;F4H)T1"7T))3DU/1$5?4$%34U1(4E4G+"`Q*3L*"B\J*@H@*B!,
M971S('EO=2!R971U<FX@9&%T82!A<R!U<W5A;`H@*B\*9&5F:6YE*"=$0E]"
M24Y-3T1%7U)%5%523B<L(#(I.PH*+RHJ"B`J($-O;G9E<G1S('1H92!D871A
M('1O(&AE>"!F;W)M870@8F5F;W)E(')E='5R;FEN9R!I=`H@*@H@*B!&;W(@
M97AA;7!L92!T:&4@<W1R:6YG("(Q,C,B('=O=6QD(&)E8V]M92`B,S$S,C,S
M(BX*("HO"F1E9FEN92@G1$)?0DE.34]$15]#3TY615)4)RP@,RD["B\J*B-`
M+2HO"@H*+R\@?7U]"B\O('M[>R!F971C:"!M;V1E<PH*"B\J*B-`*PH@*B!&
M971C:"!-;V1E<RX*("H@0'-E92!$0E]C;VUM;VXZ.G-E=$9E=&-H36]D92@I
M"B`J+PH*+RHJ"B`J($EN9&EC871E<R!T:&4@8W5R<F5N="!D969A=6QT(&9E
M=&-H(&UO9&4@<VAO=6QD(&)E('5S960*("H@0'-E92!$0E]C;VUM;VXZ.B1F
M971C:&UO9&4*("HO"F1E9FEN92@G1$)?1D540TA-3T1%7T1%1D%53%0G+"`P
M*3L*"B\J*@H@*B!#;VQU;6X@9&%T82!I;F1E>&5D(&)Y(&YU;6)E<G,L(&]R
M9&5R960@9G)O;2`P(&%N9"!U<`H@*B\*9&5F:6YE*"=$0E]&151#2$U/1$5?
M3U)$15)%1"<L(#$I.PH*+RHJ"B`J($-O;'5M;B!D871A(&EN9&5X960@8GD@
M8V]L=6UN(&YA;65S"B`J+PID969I;F4H)T1"7T9%5$-(34]$15]!4U-/0R<L
M(#(I.PH*+RHJ"B`J($-O;'5M;B!D871A(&%S(&]B:F5C="!P<F]P97)T:65S
M"B`J+PID969I;F4H)T1"7T9%5$-(34]$15]/0DI%0U0G+"`S*3L*"B\J*@H@
M*B!&;W(@;75L=&DM9&EM96YS:6]N86P@<F5S=6QT<RP@;6%K92!T:&4@8V]L
M=6UN(&YA;64@=&AE(&9I<G-T(&QE=F5L"B`J(&]F('1H92!A<G)A>2!A;F0@
M<'5T('1H92!R;W<@;G5M8F5R(&EN('1H92!S96-O;F0@;&5V96P@;V8@=&AE
M(&%R<F%Y"B`J"B`J(%1H:7,@:7,@9FQI<'!E9"!F<F]M('1H92!N;W)M86P@
M8F5H879I;W(L('=H:6-H('!U=',@=&AE(')O=R!N=6UB97)S"B`J(&EN('1H
M92!F:7)S="!L979E;"!O9B!T:&4@87)R87D@86YD('1H92!C;VQU;6X@;F%M
M97,@:6X@=&AE('-E8V]N9"!L979E;"X*("HO"F1E9FEN92@G1$)?1D540TA-
M3T1%7T9,25!0140G+"`T*3L*+RHJ(T`M*B\*"B\J*B-`*PH@*B!/;&0@9F5T
M8V@@;6]D97,N("!,969T(&AE<F4@9F]R(&-O;7!A=&EB:6QI='DN"B`J+PID
M969I;F4H)T1"7T=%5$U/1$5?3U)$15)%1"<L($1"7T9%5$-(34]$15]/4D1%
M4D5$*3L*9&5F:6YE*"=$0E]'151-3T1%7T%34T]#)RP@("!$0E]&151#2$U/
M1$5?05-33T,I.PID969I;F4H)T1"7T=%5$U/1$5?1DQ)4%!%1"<L($1"7T9%
M5$-(34]$15]&3$E04$5$*3L*+RHJ(T`M*B\*"@HO+R!]?7T*+R\@>WM[('1A
M8FQE26YF;R@I("8F(&%U=&]0<F5P87)E*"DM<F5L871E9`H*"B\J*B-`*PH@
M*B!4:&4@='EP92!O9B!I;F9O<FUA=&EO;B!T;R!R971U<FX@9G)O;2!T:&4@
M=&%B;&5);F9O*"D@;65T:&]D+@H@*@H@*B!":71W:7-E9"!C;VYS=&%N=',L
M('-O('1H97D@8V%N(&)E(&-O;6)I;F5D('5S:6YG(#QK8F0^?#PO:V)D/@H@
M*B!A;F0@<F5M;W9E9"!U<VEN9R`\:V)D/EX\+VMB9#XN"B`J"B`J($!S964@
M1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@*@H@*B![0&EN=&5R;F%L(%-I;F-E
M('1H92!404),14E.1D\@8V]N<W1A;G1S(&%R92!B:71W:7-E9"P@:68@;6]R
M92!O9B!T:&5M(&%R90H@*B!A9&1E9"!I;B!T:&4@9G5T=7)E+"!M86ME('-U
M<F4@=&\@861J=7-T($1"7U1!0DQ%24Y&3U]&54Q,(&%C8V]R9&EN9VQY+GU]
M"B`J+PID969I;F4H)T1"7U1!0DQ%24Y&3U]/4D1%4B<L(#$I.PID969I;F4H
M)T1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%)RP@,BD["F1E9FEN92@G1$)?5$%"
M3$5)3D9/7T953$PG+"`S*3L*+RHJ(T`M*B\*"@HO*BHC0"L*("H@5&AE('1Y
M<&4@;V8@<75E<GD@=&\@8W)E871E('=I=&@@=&AE(&%U=&]M871I8R!Q=65R
M>2!B=6EL9&EN9R!M971H;V1S+@H@*B!`<V5E($1"7V-O;6UO;CHZ875T;U!R
M97!A<F4H*2P@1$)?8V]M;6]N.CIA=71O17AE8W5T92@I"B`J+PID969I;F4H
M)T1"7T%55$]1545265])3E-%4E0G+"`Q*3L*9&5F:6YE*"=$0E]!551/455%
M4EE?55!$051%)RP@,BD["B\J*B-`+2HO"@H*+R\@?7U]"B\O('M[>R!P;W)T
M86)I;&ET>2!M;V1E<PH*"B\J*B-`*PH@*B!0;W)T86)I;&ET>2!-;V1E<RX*
M("H*("H@0FET=VES960@8V]N<W1A;G1S+"!S;R!T:&5Y(&-A;B!B92!C;VUB
M:6YE9"!U<VEN9R`\:V)D/GP\+VMB9#X*("H@86YD(')E;6]V960@=7-I;F<@
M/&MB9#Y>/"]K8F0^+@H@*@H@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N
M*"D*("H*("H@>T!I;G1E<FYA;"!3:6YC92!T:&4@4$]25$%"24Q)5%D@8V]N
M<W1A;G1S(&%R92!B:71W:7-E9"P@:68@;6]R92!O9B!T:&5M(&%R90H@*B!A
M9&1E9"!I;B!T:&4@9G5T=7)E+"!M86ME('-U<F4@=&\@861J=7-T($1"7U!/
M4E1!0DE,25197T%,3"!A8V-O<F1I;F=L>2Y]?0H@*B\*"B\J*@H@*B!4=7)N
M(&]F9B!A;&P@<&]R=&%B:6QI='D@9F5A='5R97,*("HO"F1E9FEN92@G1$)?
M4$]25$%"24Q)5%E?3D].12<L(#`I.PH*+RHJ"B`J($-O;G9E<G0@;F%M97,@
M;V8@=&%B;&5S(&%N9"!F:65L9',@=&\@;&]W97(@8V%S90H@*B!W:&5N('5S
M:6YG('1H92!G970J*"DL(&9E=&-H*B@I(&%N9"!T86)L94EN9F\H*2!M971H
M;V1S"B`J+PID969I;F4H)T1"7U!/4E1!0DE,25197TQ/5T520T%312<L(#$I
M.PH*+RHJ"B`J(%)I9VAT('1R:6T@=&AE(&1A=&$@;W5T<'5T(&)Y(&=E="HH
M*2!A;F0@9F5T8V@J*"D*("HO"F1E9FEN92@G1$)?4$]25$%"24Q)5%E?4E12
M24TG+"`R*3L*"B\J*@H@*B!&;W)C92!R97!O<G1I;F<@=&AE(&YU;6)E<B!O
M9B!R;W=S(&1E;&5T960*("HO"F1E9FEN92@G1$)?4$]25$%"24Q)5%E?1$5,
M151%7T-/54Y4)RP@-"D["@HO*BH*("H@16YA8FQE(&AA8VL@=&AA="!M86ME
M<R!N=6U2;W=S*"D@=V]R:R!I;B!/<F%C;&4*("HO"F1E9FEN92@G1$)?4$]2
M5$%"24Q)5%E?3E5-4D]74R<L(#@I.PH*+RHJ"B`J($UA:V5S(&-E<G1A:6X@
M97)R;W(@;65S<V%G97,@:6X@8V5R=&%I;B!D<FEV97)S(&-O;7!A=&EB;&4*
M("H@=VET:"!T:&]S92!F<F]M(&]T:&5R($1"35,G<PH@*@H@*B`K(&UY<W%L
M+"!M>7-Q;&DZ("!C:&%N9V4@=6YI<75E+W!R:6UA<GD@:V5Y(&-O;G-T<F%I
M;G1S"B`J("`@1$)?15)23U)?04Q214%$65]%6$E35%,@+3X@1$)?15)23U)?
M0T].4U1204E.5`H@*@H@*B`K(&]D8F,H86-C97-S*3H@($U3)W,@3T1"0R!D
M<FEV97(@<F5P;W)T<R`G;F\@<W5C:"!F:65L9"<@87,@8V]D90H@*B`@(#`W
M,#`Q+"!W:&EC:"!M96%N<R`G=&]O(&9E=R!P87)A;65T97)S+B<@(%=H96X@
M=&AI<R!O<'1I;VX@:7,@;VX*("H@("!T:&%T(&-O9&4@9V5T<R!M87!P960@
M=&\@1$)?15)23U)?3D]354-(1DE%3$0N"B`J+PID969I;F4H)T1"7U!/4E1!
M0DE,25197T524D]24R<L(#$V*3L*"B\J*@H@*B!#;VYV97)T(&YU;&P@=F%L
M=65S('1O(&5M<'1Y('-T<FEN9W,@:6X@9&%T82!O=71P=70@8GD*("H@9V5T
M*B@I(&%N9"!F971C:"HH*0H@*B\*9&5F:6YE*"=$0E]03U)404))3$E465].
M54Q,7U1/7T5-4%19)RP@,S(I.PH*+RHJ"B`J(%1U<FX@;VX@86QL('!O<G1A
M8FEL:71Y(&9E871U<F5S"B`J+PID969I;F4H)T1"7U!/4E1!0DE,25197T%,
M3"<L(#8S*3L*+RHJ(T`M*B\*"B\O('U]?0H*"B\O('U]?0HO+R![>WL@8VQA
M<W,@1$(*"B\J*@H@*B!$871A8F%S92!I;F1E<&5N9&5N="!Q=65R>2!I;G1E
M<F9A8V4*("H*("H@5&AE(&UA:6X@(D1"(B!C;&%S<R!I<R!S:6UP;'D@82!C
M;VYT86EN97(@8VQA<W,@=VET:"!S;VUE('-T871I8PH@*B!M971H;V1S(&9O
M<B!C<F5A=&EN9R!$0B!O8FIE8W1S(&%S('=E;&P@87,@<V]M92!U=&EL:71Y
M(&9U;F-T:6]N<PH@*B!C;VUM;VX@=&\@86QL('!A<G1S(&]F($1"+@H@*@H@
M*B!4:&4@;V)J96-T(&UO9&5L(&]F($1"(&ES(&%S(&9O;&QO=W,@*&EN9&5N
M=&%T:6]N(&UE86YS(&EN:&5R:71A;F-E*3H*("H@/'!R93X*("H@1$(@("`@
M("`@("`@(%1H92!M86EN($1"(&-L87-S+B`@5&AI<R!I<R!S:6UP;'D@82!U
M=&EL:71Y(&-L87-S"B`J("`@("`@("`@("`@("!W:71H('-O;64@(G-T871I
M8R(@;65T:&]D<R!F;W(@8W)E871I;F<@1$(@;V)J96-T<R!A<PH@*B`@("`@
M("`@("`@("`@=V5L;"!A<R!C;VUM;VX@=71I;&ET>2!F=6YC=&EO;G,@9F]R
M(&]T:&5R($1"(&-L87-S97,N"B`J"B`J($1"7V-O;6UO;B`@("!4:&4@8F%S
M92!F;W(@96%C:"!$0B!I;7!L96UE;G1A=&EO;BX@(%!R;W9I9&5S(&1E9F%U
M;'0*("H@?"`@("`@("`@("`@(&EM<&QE;65N=&%T:6]N<R`H:6X@3T\@;&EN
M9V\@=FER='5A;"!M971H;V1S*2!F;W(*("H@?"`@("`@("`@("`@('1H92!A
M8W1U86P@1$(@:6UP;&5M96YT871I;VYS(&%S('=E;&P@87,@82!B=6YC:"!O
M9@H@*B!\("`@("`@("`@("`@<75E<GD@=71I;&ET>2!F=6YC=&EO;G,N"B`J
M('P*("H@*RU$0E]M>7-Q;"`@(%1H92!$0B!I;7!L96UE;G1A=&EO;B!F;W(@
M37E344PN("!);FAE<FET<R!$0E]C;VUM;VXN"B`J("`@("`@("`@("`@("!7
M:&5N(&-A;&QI;F<@1$(Z.F9A8W1O<GD@;W(@1$(Z.F-O;FYE8W0@9F]R($UY
M4U%,"B`J("`@("`@("`@("`@("!C;VYN96-T:6]N<RP@=&AE(&]B:F5C="!R
M971U<FYE9"!I<R!A;B!I;G-T86YC92!O9B!T:&ES"B`J("`@("`@("`@("`@
M("!C;&%S<RX*("H@/"]P<F4^"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N
M(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\
M8V]X0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1""GL*("`@("\O
M('M[>R`F9F%C=&]R>2@I"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!N97<@
M1$(@;V)J96-T(&9O<B!T:&4@<W!E8VEF:65D(&1A=&%B87-E('1Y<&4@8G5T
M(&1O;B=T"B`@("`@*B!C;VYN96-T('1O('1H92!D871A8F%S90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@("`@('1H92!D871A8F%S92!T
M>7!E("AE9R`B;7ES<6PB*0H@("`@("H@0'!A<F%M(&%R<F%Y("`D;W!T:6]N
M<R`@86X@87-S;V-I871I=F4@87)R87D@;V8@;W!T:6]N(&YA;65S(&%N9"!V
M86QU97,*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@1$(@
M;V)J96-T+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F9A8W1O<GDH)'1Y<&4L("1O<'1I;VYS(#T@9F%L<V4I
M"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@
M("`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G<&5R<VES=&5N="<@/3X@)&]P
M=&EO;G,I.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R=D96)U9R==*2`F)B`D;W!T:6]N<ULG9&5B=6<G72`^/2`R*2!["B`@("`@
M("`@("`@("\O(&5X<&]S92!P:'`@97)R;W)S('=I=&@@<W5F9FEC:65N="!D
M96)U9R!L979E;`H@("`@("`@("`@("!I;F-L=61E7V]N8V4@(D1"+WLD='EP
M97TN<&AP(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!`:6YC;'5D
M95]O;F-E(")$0B][)'1Y<&5]+G!H<"(["B`@("`@("`@?0H*("`@("`@("`D
M8VQA<W-N86UE(#T@(D1"7R1[='EP97TB.PH*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@D8VQA<W-N86UE*2D@>PH@("`@("`@("`@("`D=&UP(#T@4$5!
M4CHZ<F%I<V5%<G)O<BAN=6QL+"!$0E]%4E)/4E].3U1?1D]53D0L(&YU;&PL
M(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")5
M;F%B;&4@=&\@:6YC;'5D92!T:&4@1$(O>R1T>7!E?2YP:'`B"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B!F:6QE(&9O<B`G)&1S
M;B<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1$)?
M17)R;W(G+"!T<G5E*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@
M("`@?0H*("`@("`@("!`)&]B:B`])B!N97<@)&-L87-S;F%M93L*"B`@("`@
M("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&]P=&EO;B`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@)'1E<W0@/2`D;V)J+3YS971/<'1I;VXH)&]P=&EO;BP@
M)'9A;'5E*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1T97-T*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T97-T.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&]B:CL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R`F8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#
M<F5A=&4@82!N97<@1$(@;V)J96-T(&EN8VQU9&EN9R!A(&-O;FYE8W1I;VX@
M=&\@=&AE('-P96-I9FEE9"!D871A8F%S90H@("`@("H*("`@("`J($5X86UP
M;&4@,2X*("`@("`J(#QC;V1E/@H@("`@("H@<F5Q=6ER95]O;F-E("=$0BYP
M:'`G.PH@("`@("H*("`@("`J("1D<VX@/2`G<&=S<6PZ+R]U<V5R.G!A<W-W
M;W)D0&AO<W0O9&%T86)A<V4G.PH@("`@("H@)&]P=&EO;G,@/2!A<G)A>2@*
M("`@("`J("`@("`G9&5B=6<G("`@("`@(#T^(#(L"B`@("`@*B`@("`@)W!O
M<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL"B`@("`@*B`I.PH@
M("`@("H*("`@("`J("1D8B`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N
M<RD["B`@("`@*B!I9B`H4$5!4CHZ:7-%<G)O<B@D9&(I*2!["B`@("`@*B`@
M("`@9&EE*"1D8BT^9V5T365S<V%G92@I*3L*("`@("`J('T*("`@("`J(#PO
M8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&1S;B`@("`@('1H
M92!S=')I;F<@(F1A=&$@<V]U<F-E(&YA;64B(&]R(&%R<F%Y(&EN('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@9F]R;6%T(')E='5R;F5D
M(&)Y($1".CIP87)S94133B@I"B`@("`@*B!`<&%R86T@87)R87D@)&]P=&EO
M;G,@(&%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F(&]P=&EO;B!N86UE<R!A;F0@
M=F%L=65S"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@(&$@;F5W($1"
M(&]B:F5C="X@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'5S97,@1$)?9&)A<V4Z.F-O;FYE8W0H*2P@1$)?9F)S<6PZ
M.F-O;FYE8W0H*2P@1$)?:6)A<V4Z.F-O;FYE8W0H*2P*("`@("`J("`@("`@
M($1"7VEF>#HZ8V]N;F5C="@I+"!$0E]M<W%L.CIC;VYN96-T*"DL($1"7VUS
M<W%L.CIC;VYN96-T*"DL"B`@("`@*B`@("`@("!$0E]M>7-Q;#HZ8V]N;F5C
M="@I+"!$0E]M>7-Q;&DZ.F-O;FYE8W0H*2P@1$)?;V-I.#HZ8V]N;F5C="@I
M+`H@("`@("H@("`@("`@1$)?;V1B8SHZ8V]N;F5C="@I+"!$0E]P9W-Q;#HZ
M8V]N;F5C="@I+"!$0E]S<6QI=&4Z.F-O;FYE8W0H*2P*("`@("`J("`@("`@
M($1"7W-Y8F%S93HZ8V]N;F5C="@I"B`@("`@*@H@("`@("H@0'5S97,@1$(Z
M.G!A<G-E1%-.*"DL($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"DL(%!%05(Z.FES
M17)R;W(H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F8V]N;F5C="@D9'-N+"`D
M;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)&1S;FEN9F\@/2!$
M0CHZ<&%R<V5$4TXH)&1S;BD["B`@("`@("`@)'1Y<&4@/2`D9'-N:6YF;ULG
M<&AP='EP92==.PH*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O<'1I;VYS*2D@
M>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!&;W(@8F%C:W=A<F1S
M(&-O;7!A=&EB:6QI='DN("`D;W!T:6]N<R!U<V5D('1O(&)E(&)O;VQE86XL
M"B`@("`@("`@("`@("`J(&EN9&EC871I;F<@=VAE=&AE<B!T:&4@8V]N;F5C
M=&EO;B!S:&]U;&0@8F4@<&5R<VES=&5N="X*("`@("`@("`@("`@("HO"B`@
M("`@("`@("`@("1O<'1I;VYS(#T@87)R87DH)W!E<G-I<W1E;G0G(#T^("1O
M<'1I;VYS*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG9&5B=6<G72D@)B8@)&]P=&EO;G-;)V1E8G5G)UT@/CT@,BD@>PH@("`@
M("`@("`@("`O+R!E>'!O<V4@<&AP(&5R<F]R<R!W:71H('-U9F9I8VEE;G0@
M9&5B=6<@;&5V96P*("`@("`@("`@("`@:6YC;'5D95]O;F-E(")$0B\D>W1Y
M<&5]+G!H<"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&EN8VQU
M9&5?;VYC92`B1$(O)'MT>7!E?2YP:'`B.PH@("`@("`@('T*"B`@("`@("`@
M)&-L87-S;F%M92`](")$0E\D>W1Y<&5](CL*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@D8VQA<W-N86UE*2D@>PH@("`@("`@("`@("`D=&UP(#T@4$5!
M4CHZ<F%I<V5%<G)O<BAN=6QL+"!$0E]%4E)/4E].3U1?1D]53D0L(&YU;&PL
M(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")5
M;F%B;&4@=&\@:6YC;'5D92!T:&4@1$(O>R1T>7!E?2YP:'`B"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B!F:6QE(&9O<B`G)&1S
M;B<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1$)?
M17)R;W(G+"!T<G5E*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@
M("`@?0H*("`@("`@("!`)&]B:B`])B!N97<@)&-L87-S;F%M93L*"B`@("`@
M("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&]P=&EO;B`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@)'1E<W0@/2`D;V)J+3YS971/<'1I;VXH)&]P=&EO;BP@
M)'9A;'5E*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1T97-T*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T97-T.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D97)R(#T@)&]B:BT^8V]N;F5C="@D9'-N
M:6YF;RP@)&]B:BT^9V5T3W!T:6]N*"=P97)S:7-T96YT)RDI.PH@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@("`@("`D97)R+3YA
M9&15<V5R26YF;R@D9'-N*3L*("`@("`@("`@("`@<F5T=7)N("1E<G(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&]B:CL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!A<&E697)S:6]N*"D*"B`@("`O*BH*("`@("`J(%)E
M='5R;B!T:&4@1$(@05!)('9E<G-I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE($1"($%022!V97)S:6]N(&YU;6)E<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A<&E697)S:6]N*"D*("`@('L*("`@("`@("!R971U<FX@
M)S$N-RXV)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!I<T5R<F]R
M*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@82!V87)I86)L92!I
M<R!A($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!P87)A;2!M:7AE
M9"`D=F%L=64@('1H92!V87)I86)L92!T;R!C:&5C:PH@("`@("H*("`@("`J
M($!R971U<FX@8F]O;"`@=VAE=&AE<B`D=F%L=64@:7,@1$)?17)R;W(@;V)J
M96-T"B`@("`@*B\*("`@(&9U;F-T:6]N(&ES17)R;W(H)'9A;'5E*0H@("`@
M>PH@("`@("`@(')E='5R;B!I<U]A*"1V86QU92P@)T1"7T5R<F]R)RD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@:7-#;VYN96-T:6]N*"D*"B`@
M("`O*BH*("`@("`J($1E=&5R;6EN97,@:68@82!V86QU92!I<R!A($1"7SQD
M<FEV97(^(&]B:F5C=`H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D=F%L
M=64@('1H92!V86QU92!T;R!T97-T"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!W:&5T:&5R("1V86QU92!I<R!A($1"7SQD<FEV97(^(&]B:F5C=`H@
M("`@("HO"B`@("!F=6YC=&EO;B!I<T-O;FYE8W1I;VXH)'9A;'5E*0H@("`@
M>PH@("`@("`@(')E='5R;B`H:7-?;V)J96-T*"1V86QU92D@)B8*("`@("`@
M("`@("`@("`@(&ES7W-U8F-L87-S7V]F*"1V86QU92P@)V1B7V-O;6UO;B<I
M("8F"B`@("`@("`@("`@("`@("!M971H;V1?97AI<W1S*"1V86QU92P@)W-I
M;7!L95%U97)Y)RDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&ES
M36%N:7`H*0H*("`@("\J*@H@("`@("H@5&5L;"!W:&5T:&5R(&$@<75E<GD@
M:7,@82!D871A(&UA;FEP=6QA=&EO;B!O<B!D871A(&1E9FEN:71I;VX@<75E
M<GD*("`@("`J"B`@("`@*B!%>&%M<&QE<R!O9B!D871A(&UA;FEP=6QA=&EO
M;B!Q=65R:65S(&%R92!)3E-%4E0L(%501$%412!A;F0@1$5,151%+@H@("`@
M("H@17AA;7!L97,@;V8@9&%T82!D969I;FET:6]N('%U97)I97,@87)E($-2
M14%412P@1%)/4"P@04Q415(L($=204Y4+`H@("`@("H@4D563TM%+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("!T:&4@<75E<GD*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@('=H971H97(@)'%U97)Y(&ES
M(&$@9&%T82!M86YI<'5L871I;VX@<75E<GD*("`@("`J+PH@("`@9G5N8W1I
M;VX@:7--86YI<"@D<75E<GDI"B`@("!["B`@("`@("`@)&UA;FEP<R`]("=)
M3E-%4E1\55!$051%?$1%3$5417Q215!,04-%?"<*("`@("`@("`@("`@("`@
M("X@)T-214%417Q$4D]0?"<*("`@("`@("`@("`@("`@("X@)TQ/040@1$%4
M07Q314Q%0U0@+BH@24Y43WQ#3U!9?"<*("`@("`@("`@("`@("`@("X@)T%,
M5$52?$=204Y4?%)%5D]+17PG"B`@("`@("`@("`@("`@("`N("=,3T-+?%5.
M3$]#2R<["B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J(C\H)R`N("1M
M86YI<',@+B`G*5QS*R]I)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R365S<V%G92@I"@H@("`@
M+RHJ"B`@("`@*B!2971U<FX@82!T97AT=6%L(&5R<F]R(&UE<W-A9V4@9F]R
M(&$@1$(@97)R;W(@8V]D90H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R
M("1V86QU92`@=&AE($1"(&5R<F]R(&-O9&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE(&5R<F]R(&UE<W-A9V4@;W(@9F%L<V4@:68@=&AE
M(&5R<F]R(&-O9&4@=V%S"B`@("`@*B`@("`@("`@("`@("`@("`@(&YO="!R
M96-O9VYI>F5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R365S<V%G92@D
M=F%L=64I"B`@("!["B`@("`@("`@<W1A=&EC("1E<G)O<DUE<W-A9V5S.PH@
M("`@("`@(&EF("@A:7-S970H)&5R<F]R365S<V%G97,I*2!["B`@("`@("`@
M("`@("1E<G)O<DUE<W-A9V5S(#T@87)R87DH"B`@("`@("`@("`@("`@("!$
M0E]%4E)/4B`@("`@("`@("`@("`@("`@("`@/3X@)W5N:VYO=VX@97)R;W(G
M+`H@("`@("`@("`@("`@("`@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3B`@
M(#T^("=I;G-U9F9I8VEE;G0@<&5R;6ES<VEO;G,G+`H@("`@("`@("`@("`@
M("`@1$)?15)23U)?04Q214%$65]%6$E35%,@("`@(#T^("=A;')E861Y(&5X
M:7-T<R<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]#04Y.3U1?0U)%051%
M("`@("`@/3X@)V-A;B!N;W0@8W)E871E)RP*("`@("`@("`@("`@("`@($1"
M7T524D]27T-!3DY/5%]$4D]0("`@("`@("`]/B`G8V%N(&YO="!D<F]P)RP*
M("`@("`@("`@("`@("`@($1"7T524D]27T-/3DY%0U1?1D%)3$5$("`@("`]
M/B`G8V]N;F5C="!F86EL960G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?
M0T].4U1204E.5"`@("`@("`@(#T^("=C;VYS=')A:6YT('9I;VQA=&EO;B<L
M"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,
M/3X@)VYU;&P@=F%L=64@=FEO;&%T97,@;F]T+6YU;&P@8V]N<W1R86EN="<L
M"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]$259:15)/("`@("`@("`@("`@
M/3X@)V1I=FES:6]N(&)Y('IE<F\G+`H@("`@("`@("`@("`@("`@1$)?15)2
M3U)?15A414Y324].7TY/5%]&3U5.1#T^("=E>'1E;G-I;VX@;F]T(&9O=6YD
M)RP*("`@("`@("`@("`@("`@($1"7T524D]27TE.5D%,240@("`@("`@("`@
M("`]/B`G:6YV86QI9"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E])3E9!
M3$E$7T1!5$4@("`@("`@/3X@)VEN=F%L:60@9&%T92!O<B!T:6UE)RP*("`@
M("`@("`@("`@("`@($1"7T524D]27TE.5D%,241?1%-.("`@("`@("`]/B`G
M:6YV86QI9"!$4TXG+`H@("`@("`@("`@("`@("`@1$)?15)23U)?24Y604Q)
M1%].54U"15(@("`@(#T^("=I;G9A;&ED(&YU;6)E<B<L"B`@("`@("`@("`@
M("`@("!$0E]%4E)/4E]-25--051#2"`@("`@("`@("`@/3X@)VUI<VUA=&-H
M)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY%141?34]215]$051!("`@
M("`]/B`G:6YS=69F:6-I96YT(&1A=&$@<W5P<&QI960G+`H@("`@("`@("`@
M("`@("`@1$)?15)23U)?3D]$0E-%3$5#5$5$("`@("`@(#T^("=N;R!D871A
M8F%S92!S96QE8W1E9"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E].3U-5
M0TA$0B`@("`@("`@("`@/3X@)VYO('-U8V@@9&%T86)A<V4G+`H@("`@("`@
M("`@("`@("`@1$)?15)23U)?3D]354-(1DE%3$0@("`@("`@(#T^("=N;R!S
M=6-H(&9I96QD)RP*("`@("`@("`@("`@("`@($1"7T524D]27TY/4U5#2%1!
M0DQ%("`@("`@("`]/B`G;F\@<W5C:"!T86)L92<L"B`@("`@("`@("`@("`@
M("!$0E]%4E)/4E].3U1?0T%004),12`@("`@("`@/3X@)T1"(&)A8VME;F0@
M;F]T(&-A<&%B;&4G+`H@("`@("`@("`@("`@("`@1$)?15)23U)?3D]47T9/
M54Y$("`@("`@("`@(#T^("=N;W0@9F]U;F0G+`H@("`@("`@("`@("`@("`@
M1$)?15)23U)?3D]47TQ/0TM%1"`@("`@("`@(#T^("=N;W0@;&]C:V5D)RP*
M("`@("`@("`@("`@("`@($1"7T524D]27U-93E1!6"`@("`@("`@("`@("`]
M/B`G<WEN=&%X(&5R<F]R)RP*("`@("`@("`@("`@("`@($1"7T524D]27U5.
M4U504$]25$5$("`@("`@("`]/B`G;F]T('-U<'!O<G1E9"<L"B`@("`@("`@
M("`@("`@("!$0E]%4E)/4E]44E5.0T%4140@("`@("`@("`@/3X@)W1R=6YC
M871E9"<L"B`@("`@("`@("`@("`@("!$0E]%4E)/4E]604Q515]#3U5.5%]/
M3E]23U<@/3X@)W9A;'5E(&-O=6YT(&]N(')O=R<L"B`@("`@("`@("`@("`@
M("!$0E]/2R`@("`@("`@("`@("`@("`@("`@("`@/3X@)VYO(&5R<F]R)RP*
M("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D=F%L=64I*2!["B`@("`@("`@("`@("1V86QU92`]("1V86QU92T^
M9V5T0V]D92@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1E
M<G)O<DUE<W-A9V5S6R1V86QU95TI(#\@)&5R<F]R365S<V%G97-;)'9A;'5E
M70H@("`@("`@("`@("`@("`@("`@("`Z("1E<G)O<DUE<W-A9V5S6T1"7T52
M4D]273L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P87)S94133B@I
M"@H@("`@+RHJ"B`@("`@*B!087)S92!A(&1A=&$@<V]U<F-E(&YA;64*("`@
M("`J"B`@("`@*B!!9&1I=&EO;F%L(&ME>7,@8V%N(&)E(&%D9&5D(&)Y(&%P
M<&5N9&EN9R!A(%5222!Q=65R>2!S=')I;F<@=&\@=&AE"B`@("`@*B!E;F0@
M;V8@=&AE($133BX*("`@("`J"B`@("`@*B!4:&4@9F]R;6%T(&]F('1H92!S
M=7!P;&EE9"!$4TX@:7,@:6X@:71S(&9U;&QE<W0@9F]R;3H*("`@("`J(#QC
M;V1E/@H@("`@("H@('!H<'1Y<&4H9&)S>6YT87@I.B\O=7-E<FYA;64Z<&%S
M<W=O<F1`<')O=&]C;VPK:&]S='-P96,O9&%T86)A<V4_;W!T:6]N/3@F86YO
M=&AE<CUT<G5E"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@36]S="!V
M87)I871I;VYS(&%R92!A;&QO=V5D.@H@("`@("H@/&-O9&4^"B`@("`@*B`@
M<&AP='EP93HO+W5S97)N86UE.G!A<W-W;W)D0'!R;W1O8V]L*VAO<W1S<&5C
M.C$Q,"\O=7-R+V1B7V9I;&4N9&(_;6]D93TP-C0T"B`@("`@*B`@<&AP='EP
M93HO+W5S97)N86UE.G!A<W-W;W)D0&AO<W1S<&5C+V1A=&%B87-E7VYA;64*
M("`@("`J("!P:'!T>7!E.B\O=7-E<FYA;64Z<&%S<W=O<F1`:&]S='-P96,*
M("`@("`J("!P:'!T>7!E.B\O=7-E<FYA;65`:&]S='-P96,*("`@("`J("!P
M:'!T>7!E.B\O:&]S='-P96,O9&%T86)A<V4*("`@("`J("!P:'!T>7!E.B\O
M:&]S='-P96,*("`@("`J("!P:'!T>7!E*&1B<WEN=&%X*0H@("`@("H@('!H
M<'1Y<&4*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1D<VX@1&%T82!3;W5R8V4@3F%M92!T;R!B92!P87)S960*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I
M=&@@=&AE(&9O;&QO=VEN9R!K97ES.@H@("`@("H@("L@<&AP='EP93H@($1A
M=&%B87-E(&)A8VME;F0@=7-E9"!I;B!02%`@*&UY<W%L+"!O9&)C(&5T8RXI
M"B`@("`@*B`@*R!D8G-Y;G1A>#H@1&%T86)A<V4@=7-E9"!W:71H(')E9V%R
M9',@=&\@4U%,('-Y;G1A>"!E=&,N"B`@("`@*B`@*R!P<F]T;V-O;#H@0V]M
M;75N:6-A=&EO;B!P<F]T;V-O;"!T;R!U<V4@*'1C<"P@=6YI>"!E=&,N*0H@
M("`@("H@("L@:&]S='-P96,Z($AO<W0@<W!E8VEF:6-A=&EO;B`H:&]S=&YA
M;65;.G!O<G1=*0H@("`@("H@("L@9&%T86)A<V4Z($1A=&%B87-E('1O('5S
M92!O;B!T:&4@1$)-4R!S97)V97(*("`@("`J("`K('5S97)N86UE.B!5<V5R
M(&YA;64@9F]R(&QO9VEN"B`@("`@*B`@*R!P87-S=V]R9#H@4&%S<W=O<F0@
M9F]R(&QO9VEN"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E1%-.*"1D<VXI
M"B`@("!["B`@("`@("`@)'!A<G-E9"`](&%R<F%Y*`H@("`@("`@("`@("`G
M<&AP='EP92<@(#T^(&9A;'-E+`H@("`@("`@("`@("`G9&)S>6YT87@G(#T^
M(&9A;'-E+`H@("`@("`@("`@("`G=7-E<FYA;64G(#T^(&9A;'-E+`H@("`@
M("`@("`@("`G<&%S<W=O<F0G(#T^(&9A;'-E+`H@("`@("`@("`@("`G<')O
M=&]C;VPG(#T^(&9A;'-E+`H@("`@("`@("`@("`G:&]S='-P96,G(#T^(&9A
M;'-E+`H@("`@("`@("`@("`G<&]R="<@("`@(#T^(&9A;'-E+`H@("`@("`@
M("`@("`G<V]C:V5T)R`@(#T^(&9A;'-E+`H@("`@("`@("`@("`G9&%T86)A
M<V4G(#T^(&9A;'-E+`H@("`@("`@("D["@H@("`@("`@(&EF("AI<U]A<G)A
M>2@D9'-N*2D@>PH@("`@("`@("`@("`D9'-N(#T@87)R87E?;65R9V4H)'!A
M<G-E9"P@)&1S;BD["B`@("`@("`@("`@(&EF("@A)&1S;ELG9&)S>6YT87@G
M72D@>PH@("`@("`@("`@("`@("`@)&1S;ELG9&)S>6YT87@G72`]("1D<VY;
M)W!H<'1Y<&4G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@
M)&1S;CL*("`@("`@("!]"@H@("`@("`@("\O($9I;F0@<&AP='EP92!A;F0@
M9&)S>6YT87@*("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)&1S;BP@)SHO
M+R<I*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'-T<B`]('-U8G-T<B@D
M9'-N+"`P+"`D<&]S*3L*("`@("`@("`@("`@)&1S;B`]('-U8G-T<B@D9'-N
M+"`D<&]S("L@,RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-T
M<B`]("1D<VX["B`@("`@("`@("`@("1D<VX@/2!N=6QL.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1V5T('!H<'1Y<&4@86YD(&1B<WEN=&%X"B`@("`@("`@
M+R\@)'-T<B`]/B!P:'!T>7!E*&1B<WEN=&%X*0H@("`@("`@(&EF("AP<F5G
M7VUA=&-H*"=\7B@N*S\I7"@H+BH_*5PI)'PG+"`D<W1R+"`D87)R*2D@>PH@
M("`@("`@("`@("`D<&%R<V5D6R=P:'!T>7!E)UT@(#T@)&%R<ELQ73L*("`@
M("`@("`@("`@)'!A<G-E9%LG9&)S>6YT87@G72`]("$D87)R6S)=(#\@)&%R
M<ELQ72`Z("1A<G);,ET["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'!A<G-E9%LG<&AP='EP92==("`]("1S='(["B`@("`@("`@("`@("1P87)S
M961;)V1B<WEN=&%X)UT@/2`D<W1R.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%C;W5N="@D9'-N*2D@>PH@("`@("`@("`@("!R971U<FX@)'!A<G-E9#L*
M("`@("`@("!]"@H@("`@("`@("\O($=E="`H:68@9F]U;F0I.B!U<V5R;F%M
M92!A;F0@<&%S<W=O<F0*("`@("`@("`O+R`D9'-N(#T^('5S97)N86UE.G!A
M<W-W;W)D0'!R;W1O8V]L*VAO<W1S<&5C+V1A=&%B87-E"B`@("`@("`@:68@
M*"@D870@/2!S=')R<&]S*"1D<VXL)T`G*2D@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1S='(@/2!S=6)S='(H)&1S;BP@,"P@)&%T*3L*("`@("`@("`@
M("`@)&1S;B`]('-U8G-T<B@D9'-N+"`D870@*R`Q*3L*("`@("`@("`@("`@
M:68@*"@D<&]S(#T@<W1R<&]S*"1S='(L("<Z)RDI("$]/2!F86QS92D@>PH@
M("`@("`@("`@("`@("`@)'!A<G-E9%LG=7-E<FYA;64G72`](')A=W5R;&1E
M8V]D92AS=6)S='(H)'-T<BP@,"P@)'!O<RDI.PH@("`@("`@("`@("`@("`@
M)'!A<G-E9%LG<&%S<W=O<F0G72`](')A=W5R;&1E8V]D92AS=6)S='(H)'-T
M<BP@)'!O<R`K(#$I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1P87)S961;)W5S97)N86UE)UT@/2!R87=U<FQD96-O9&4H)'-T
M<BD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($9I;F0@
M<')O=&]C;VP@86YD(&AO<W1S<&5C"@H@("`@("`@(&EF("AP<F5G7VUA=&-H
M*"=\7BA;7BA=*RE<*"@N*C\I7"DO/R@N*C\I)'PG+"`D9'-N+"`D;6%T8V@I
M*2!["B`@("`@("`@("`@("\O("1D<VX@/3X@<')O=&\H<')O=&]?;W!T<RDO
M9&%T86)A<V4*("`@("`@("`@("`@)'!R;W1O("`@("`@(#T@)&UA=&-H6S%=
M.PH@("`@("`@("`@("`D<')O=&]?;W!T<R`@/2`D;6%T8VA;,ET@/R`D;6%T
M8VA;,ET@.B!F86QS93L*("`@("`@("`@("`@)&1S;B`@("`@("`@(#T@)&UA
M=&-H6S-=.PH*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R`D9'-N
M(#T^('!R;W1O8V]L*VAO<W1S<&5C+V1A=&%B87-E("AO;&0@9F]R;6%T*0H@
M("`@("`@("`@("!I9B`H<W1R<&]S*"1D<VXL("<K)RD@(3T](&9A;'-E*2![
M"B`@("`@("`@("`@("`@("!L:7-T*"1P<F]T;RP@)&1S;BD@/2!E>'!L;V1E
M*"<K)RP@)&1S;BP@,BD["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*'-T<G!O<R@D9'-N+"`G+R<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@
M("`@;&ES="@D<')O=&]?;W!T<RP@)&1S;BD@/2!E>'!L;V1E*"<O)RP@)&1S
M;BP@,BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<')O=&]?;W!T<R`]("1D<VX["B`@("`@("`@("`@("`@("`D9'-N(#T@;G5L
M;#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@<')O8V5S
M<R!T:&4@9&EF9F5R96YT('!R;W1O8V]L(&]P=&EO;G,*("`@("`@("`D<&%R
M<V5D6R=P<F]T;V-O;"==(#T@*"%E;7!T>2@D<')O=&\I*2`_("1P<F]T;R`Z
M("=T8W`G.PH@("`@("`@("1P<F]T;U]O<'1S(#T@<F%W=7)L9&5C;V1E*"1P
M<F]T;U]O<'1S*3L*("`@("`@("!I9B`H)'!A<G-E9%LG<')O=&]C;VPG72`]
M/2`G=&-P)RD@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1P<F]T;U]O<'1S
M+"`G.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@;&ES="@D<&%R
M<V5D6R=H;W-T<W!E8R==+`H@("`@("`@("`@("`@("`@("`@("`D<&%R<V5D
M6R=P;W)T)UTI(#T@97AP;&]D92@G.B<L("1P<F]T;U]O<'1S*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P87)S961;)VAO<W1S
M<&5C)UT@/2`D<')O=&]?;W!T<SL*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS96EF("@D<&%R<V5D6R=P<F]T;V-O;"==(#T]("=U;FEX)RD@>PH@("`@
M("`@("`@("`D<&%R<V5D6R=S;V-K970G72`]("1P<F]T;U]O<'1S.PH@("`@
M("`@('T*"B`@("`@("`@+R\@1V5T(&1A8F%S92!I9B!A;GD*("`@("`@("`O
M+R`D9'-N(#T^(&1A=&%B87-E"B`@("`@("`@:68@*"1D<VXI('L*("`@("`@
M("`@("`@:68@*"@D<&]S(#T@<W1R<&]S*"1D<VXL("<_)RDI(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@+R\@+V1A=&%B87-E"B`@("`@("`@("`@
M("`@("`D<&%R<V5D6R=D871A8F%S92==(#T@<F%W=7)L9&5C;V1E*"1D<VXI
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@+V1A
M=&%B87-E/W!A<F%M,3UV86QU93$F<&%R86TR/79A;'5E,@H@("`@("`@("`@
M("`@("`@)'!A<G-E9%LG9&%T86)A<V4G72`](')A=W5R;&1E8V]D92AS=6)S
M='(H)&1S;BP@,"P@)'!O<RDI.PH@("`@("`@("`@("`@("`@)&1S;B`]('-U
M8G-T<B@D9'-N+"`D<&]S("L@,2D["B`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1D<VXL("<F)RD@(3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@
M("`@)&]P=',@/2!E>'!L;V1E*"<F)RP@)&1S;BD["B`@("`@("`@("`@("`@
M("!](&5L<V4@>R`O+R!D871A8F%S93]P87)A;3$]=F%L=64Q"B`@("`@("`@
M("`@("`@("`@("`@)&]P=',@/2!A<G)A>2@D9'-N*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O<'1S(&%S("1O<'0I
M('L*("`@("`@("`@("`@("`@("`@("!L:7-T*"1K97DL("1V86QU92D@/2!E
M>'!L;V1E*"<])RP@)&]P="D["B`@("`@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D<&%R<V5D6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!D;VXG="!A;&QO=R!P87)A;7,@;W9E<G=R:71E"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P87)S961;)&ME>5T@/2!R87=U<FQD96-O9&4H)'9A
M;'5E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<&%R
M<V5D.PH@("`@?0H*("`@("\O('U]?0I]"@HO+R!]?7T*+R\@>WM[(&-L87-S
M($1"7T5R<F]R"@HO*BH*("H@1$)?17)R;W(@:6UP;&5M96YT<R!A(&-L87-S
M(&9O<B!R97!O<G1I;F<@<&]R=&%B;&4@9&%T86)A<V4@97)R;W(*("H@;65S
M<V%G97,*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@
M("`@1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW
M+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1""B`J+PIC;&%S<R!$0E]%<G)O<B!E>'1E;F1S(%!%05)?17)R;W(*>PH@
M("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!$0E]%<G)O
M<B!C;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D8V]D
M92`@("`@("!$0B!E<G)O<B!C;V1E+"!O<B!S=')I;F<@=VET:"!E<G)O<B!M
M97-S86=E"B`@("`@*B!`<&%R86T@:6YT("`@)&UO9&4@("`@("`@=VAA="`B
M97)R;W(@;6]D92(@=&\@;W!E<F%T92!I;@H@("`@("H@0'!A<F%M(&EN="`@
M("1L979E;"`@("`@('=H870@97)R;W(@;&5V96P@=&\@=7-E(&9O<B`D;6]D
M92`F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?15)2
M3U)?5%))1T=%4@H@("`@("H@0'!A<F%M(&UI>&5D("1D96)U9VEN9F\@(&%D
M9&ET:6]N86P@9&5B=6<@:6YF;RP@<W5C:"!A<R!T:&4@;&%S="!Q=65R>0H@
M("`@("H*("`@("`J($!S964@4$5!4E]%<G)O<@H@("`@("HO"B`@("!F=6YC
M=&EO;B!$0E]%<G)O<B@D8V]D92`]($1"7T524D]2+"`D;6]D92`](%!%05)?
M15)23U)?4D5455).+`H@("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@
M15]54T527TY/5$E#12P@)&1E8G5G:6YF;R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7VEN="@D8V]D92DI('L*("`@("`@("`@("`@)'1H:7,M/E!%
M05)?17)R;W(H)T1"($5R<F]R.B`G("X@1$(Z.F5R<F]R365S<V%G92@D8V]D
M92DL("1C;V1E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6]D
M92P@)&QE=F5L+"`D9&5B=6=I;F9O*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^4$5!4E]%<G)O<B@B1$(@17)R;W(Z("1C;V1E(BP@
M1$)?15)23U(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M;V1E
M+"`D;&5V96PL("1D96)U9VEN9F\I.PH@("`@("`@('T*("`@('T*"B`@("`O
M+R!]?7T*?0H*+R\@?7U]"B\O('M[>R!C;&%S<R!$0E]R97-U;'0*"B\J*@H@
M*B!4:&ES(&-L87-S(&EM<&QE;65N=',@82!W<F%P<&5R(&9O<B!A($1"(')E
M<W5L="!S970*("H*("H@02!N97<@:6YS=&%N8V4@;V8@=&AI<R!C;&%S<R!W
M:6QL(&)E(')E='5R;F5D(&)Y('1H92!$0B!I;7!L96UE;G1A=&EO;@H@*B!A
M9G1E<B!P<F]C97-S:6YG(&$@<75E<GD@=&AA="!R971U<FYS(&1A=&$N"B`J
M"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*
M8VQA<W,@1$)?<F5S=6QT"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@
M+RHJ"B`@("`@*B!3:&]U;&0@<F5S=6QT<R!B92!F<F5E9"!A=71O;6%T:6-A
M;&QY('=H96X@=&AE<F4@87)E(&YO(&UO<F4@<F]W<S\*("`@("`J($!V87(@
M8F]O;&5A;@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.B1O<'1I;VYS"B`@("`@
M*B\*("`@('9A<B`D875T;V9R964["@H@("`@+RHJ"B`@("`@*B!!(')E9F5R
M96YC92!T;R!T:&4@1$)?/&1R:79E<CX@;V)J96-T"B`@("`@*B!`=F%R(&]B
M:F5C=`H@("`@("HO"B`@("!V87(@)&1B:#L*"B`@("`O*BH*("`@("`J(%1H
M92!C=7)R96YT(&1E9F%U;'0@9F5T8V@@;6]D90H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ)&9E=&-H;6]D90H@("`@("HO
M"B`@("!V87(@)&9E=&-H;6]D93L*"B`@("`O*BH*("`@("`J(%1H92!N86UE
M(&]F('1H92!C;&%S<R!I;G1O('=H:6-H(')E<W5L=',@<VAO=6QD(&)E(&9E
M=&-H960@=VAE;@H@("`@("H@1$)?1D540TA-3T1%7T]"2D5#5"!I<R!I;B!E
M9F9E8W0*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.B1F971C:&UO9&5?;V)J96-T7V-L87-S"B`@("`@*B\*("`@
M('9A<B`D9F5T8VAM;V1E7V]B:F5C=%]C;&%S<SL*"B`@("`O*BH*("`@("`J
M(%1H92!N=6UB97(@;V8@<F]W<R!T;R!F971C:"!F<F]M(&$@;&EM:70@<75E
M<GD*("`@("`J($!V87(@:6YT96=E<@H@("`@("HO"B`@("!V87(@)&QI;6ET
M7V-O=6YT(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!R;W<@=&\@<W1A
M<G0@9F5T8VAI;F<@9G)O;2!I;B!L:6UI="!Q=65R:65S"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1L:6UI=%]F<F]M(#T@;G5L;#L*
M"B`@("`O*BH*("`@("`J(%1H92!E>&5C=71E('!A<F%M971E<G,@=&AA="!C
M<F5A=&5D('1H:7,@<F5S=6QT"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`
M<VEN8V4@4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*
M("`@("`J+PH@("`@=F%R("1P87)A;65T97)S.PH*("`@("\J*@H@("`@("H@
M5&AE('%U97)Y('-T<FEN9R!T:&%T(&-R96%T960@=&AI<R!R97-U;'0*("`@
M("`J"B`@("`@*B!#;W!I960@:&5R92!I;F-A<V4@:70@8VAA;F=E<R!I;B`D
M9&)H+"!W:&EC:"!I<R!R969E<F5N8V5D"B`@("`@*@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J($!S:6YC92!0<F]P97)T>2!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!V87(@)'%U97)Y.PH*("`@("\J
M*@H@("`@("H@5&AE('%U97)Y(')E<W5L="!R97-O=7)C92!I9"!C<F5A=&5D
M(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@
M)')E<W5L=#L*"B`@("`O*BH*("`@("`J(%1H92!P<F5S96YT(')O=R!B96EN
M9R!D96%L="!W:71H"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@
M=F%R("1R;W=?8V]U;G1E<B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<')E<&%R960@<W1A=&5M96YT(')E<V]U<F-E(&ED(&-R96%T960@8GD@4$A0
M(&EN("1D8F@*("`@("`J"B`@("`@*B!4:&ES(')E<V]U<F-E(&ES(&]N;'D@
M879A:6QA8FQE('=H96X@=&AE(')E<W5L="!S970@=V%S(&-R96%T960@=7-I
M;F<*("`@("`J(&$@9')I=F5R)W,@;F%T:79E(&5X96-U=&4H*2!M971H;V0L
M(&YO="!014%2($1")W,@96UU;&%T960@;VYE+@H@("`@("H*("`@("`J($-O
M<&EE9"!H97)E(&EN8V%S92!I="!C:&%N9V5S(&EN("1D8F@L('=H:6-H(&ES
M(')E9F5R96YC960*("`@("`J"B`@("`@*B![0&EN=&5R;F%L("!-86EN;'D@
M:&5R92!B96-A=7-E('1H92!);G1E<D)A<V4O1FER96)I<F0@05!)(&ES(&]N
M;'D*("`@("`J(&%B;&4@=&\@<F5T<FEE=F4@9&%T82!F<F]M(')E<W5L="!S
M971S(&EF('1H92!S=&%T96UN="!H86YD;&4@:7,*("`@("`J('-T:6QL(&EN
M('-C;W!E+GU]"B`@("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("H@
M0'-I;F-E(%!R;W!E<G1Y(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP
M"B`@("`@*B\*("`@('9A<B`D<W1A=&5M96YT.PH*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS
M=')U8W1O<B!S971S('1H92!O8FIE8W0G<R!P<F]P97)T:65S"B`@("`@*@H@
M("`@("H@0'!A<F%M(&]B:F5C="`@("8D9&)H("`@("!T:&4@1$(@;V)J96-T
M(')E9F5R96YC90H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("!T
M:&4@<F5S=6QT(')E<V]U<F-E(&ED"B`@("`@*B!`<&%R86T@87)R87D@("`@
M)&]P=&EO;G,@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@<F5S=6QT(&]P
M=&EO;G,*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@1$)?<F5S=6QT*"8D9&)H+"`D<F5S=6QT+"`D;W!T:6]N<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H:7,M/F%U=&]F<F5E("`@(#T@
M)&1B:"T^;W!T:6]N<ULG875T;V9R964G73L*("`@("`@("`D=&AI<RT^9&)H
M("`@("`@("`@/2`F)&1B:#L*("`@("`@("`D=&AI<RT^9F5T8VAM;V1E("`@
M/2`D9&)H+3YF971C:&UO9&4["B`@("`@("`@)'1H:7,M/F9E=&-H;6]D95]O
M8FIE8W1?8VQA<W,@/2`D9&)H+3YF971C:&UO9&5?;V)J96-T7V-L87-S.PH@
M("`@("`@("1T:&ES+3YP87)A;65T97)S("`]("1D8F@M/FQA<W1?<&%R86UE
M=&5R<SL*("`@("`@("`D=&AI<RT^<75E<GD@("`@("`@/2`D9&)H+3YL87-T
M7W%U97)Y.PH@("`@("`@("1T:&ES+3YR97-U;'0@("`@("`]("1R97-U;'0[
M"B`@("`@("`@)'1H:7,M/G-T871E;65N="`@(#T@96UP='DH)&1B:"T^;&%S
M=%]S=&UT*2`_(&YU;&P@.B`D9&)H+3YL87-T7W-T;70["B`@("`@("`@9F]R
M96%C:"`H)&]P=&EO;G,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@
M("`@)'1H:7,M/G-E=$]P=&EO;B@D:V5Y+"`D=F%L=64I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!O<'1I;VYS(&9O<B!T:&4@1$)?
M<F5S=6QT(&]B:F5C=`H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&ME
M>2`@("!T:&4@;W!T:6]N('1O('-E=`H@("`@("H@0'!A<F%M(&UI>&5D("`D
M=F%L=64@('1H92!V86QU92!T;R!S970@=&AE(&]P=&EO;B!T;PH@("`@("H*
M("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!S971/
M<'1I;VXH)&ME>2P@)'9A;'5E(#T@;G5L;"D*("`@('L*("`@("`@("!S=VET
M8V@@*"1K97DI('L*("`@("`@("`@("`@8V%S92`G;&EM:71?9G)O;2<Z"B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&EM:71?9G)O;2`]("1V86QU93L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=L:6UI=%]C
M;W5N="<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^;&EM:71?8V]U;G0@/2`D
M=F%L=64["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&9E=&-H4F]W*"D*"B`@("`O*BH*("`@("`J($9E=&-H(&$@<F]W(&]F(&1A
M=&$@86YD(')E='5R;B!I="!B>2!R969E<F5N8V4@:6YT;R!A;B!A<G)A>0H@
M("`@("H*("`@("`J(%1H92!T>7!E(&]F(&%R<F%Y(')E='5R;F5D(&-A;B!B
M92!C;VYT<F]L;&5D(&5I=&AE<B!B>2!S971T:6YG('1H:7,*("`@("`J(&UE
M=&AO9"=S(#QV87(^)&9E=&-H;6]D93PO=F%R/B!P87)A;65T97(@;W(@8GD@
M8VAA;F=I;F<@=&AE(&1E9F%U;'0*("`@("`J(&9E=&-H(&UO9&4@<V5T1F5T
M8VA-;V1E*"D@8F5F;W)E(&-A;&QI;F<@=&AI<R!M971H;V0N"B`@("`@*@H@
M("`@("H@5&AE<F4@87)E('1W;R!O<'1I;VYS(&9O<B!S=&%N9&%R9&EZ:6YG
M('1H92!I;F9O<FUA=&EO;B!R971U<FYE9`H@("`@("H@9G)O;2!D871A8F%S
M97,L(&5N<W5R:6YG('1H96ER('9A;'5E<R!A<F4@8V]N<VES=&5N="!W:&5N
M(&-H86YG:6YG"B`@("`@*B!$0DU3)W,N("!4:&5S92!P;W)T86)I;&ET>2!O
M<'1I;VYS(&-A;B!B92!T=7)N960@;VX@=VAE;B!C<F5A=&EN9R!A"B`@("`@
M*B!N97<@1$(@;V)J96-T(&]R(&)Y('5S:6YG('-E=$]P=&EO;B@I+@H@("`@
M("H*("`@("`J("`@*R`\=F%R/D1"7U!/4E1!0DE,25197TQ/5T520T%313PO
M=F%R/@H@("`@("H@("`@(&-O;G9E<G0@;F%M97,@;V8@9FEE;&1S('1O(&QO
M=V5R(&-A<V4*("`@("`J"B`@("`@*B`@("L@/'9A<CY$0E]03U)404))3$E4
M65]25%))33PO=F%R/@H@("`@("H@("`@(')I9VAT('1R:6T@=&AE(&1A=&$*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1F971C:&UO9&4@('1H92!C;VYS
M=&%N="!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&1A=&$*("`@("`J
M($!P87)A;2!I;G0@)')O=VYU;2`@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T
M8V@@*&EN9&5X('-T87)T<R!A="`P*0H@("`@("H*("`@("`J($!R971U<FX@
M;6EX960@(&%N(&%R<F%Y(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!R;W<G
M<R!D871A+`H@("`@("H@("`@("`@("`@("`@("`@($Y53$P@=VAE;B!T:&4@
M96YD(&]F('1H92!R97-U;'0@<V5T(&ES(')E86-H960*("`@("`J("`@("`@
M("`@("`@("`@("!O<B!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*2P@1$)?
M8V]M;6]N.CIS971&971C:$UO9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F
M9F5T8VA2;W<H)&9E=&-H;6]D92`]($1"7T9%5$-(34]$15]$149!54Q4+"`D
M<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&9E=&-H;6]D92`]
M/3T@1$)?1D540TA-3T1%7T1%1D%53%0I('L*("`@("`@("`@("`@)&9E=&-H
M;6]D92`]("1T:&ES+3YF971C:&UO9&4["B`@("`@("`@?0H@("`@("`@(&EF
M("@D9F5T8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?3T)*14-4*2!["B`@("`@
M("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?05-33T,["B`@("`@
M("`@("`@("1O8FIE8W1?8VQA<W,@/2`D=&AI<RT^9F5T8VAM;V1E7V]B:F5C
M=%]C;&%S<SL*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YL:6UI=%]F
M<F]M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^<F]W7V-O
M=6YT97(@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@("1T:&ES+3YR;W=?
M8V]U;G1E<B`]("1T:&ES+3YL:6UI=%]F<F]M.PH@("`@("`@("`@("`@("`@
M+R\@4VMI<"!R;W=S"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F1B:"T^
M9F5A='5R97-;)VQI;6ET)UT@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`@("`@)&D@/2`P.PH@("`@("`@("`@("`@("`@("`@('=H:6QE("@D:2LK
M(#P@)'1H:7,M/FQI;6ET7V9R;VTI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F1B:"T^9F5T8VA);G1O*"1T:&ES+3YR97-U;'0L("1A<G(L
M("1F971C:&UO9&4I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/G)O=U]C;W5N=&5R(#X]("@D=&AI<RT^;&EM:71?9G)O;2`K("1T:&ES+3YL
M:6UI=%]C;W5N="DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^875T;V9R964I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9G)E92@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'1M<"`](&YU;&P["B`@("`@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/F1B:"T^9F5A='5R
M97-;)VQI;6ET)UT@/3T]("=E;75L871E)RD@>PH@("`@("`@("`@("`@("`@
M)')O=VYU;2`]("1T:&ES+3YR;W=?8V]U;G1E<CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^<F]W7V-O=6YT97(K*SL*("`@("`@("!]"B`@
M("`@("`@)')E<R`]("1T:&ES+3YD8F@M/F9E=&-H26YT;R@D=&AI<RT^<F5S
M=6QT+"`D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M*3L*("`@("`@("!I9B`H
M)')E<R`]/3T@1$)?3TLI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O8FIE
M8W1?8VQA<W,I*2!["B`@("`@("`@("`@("`@("`O+R!4:&4@9&5F875L="!M
M;V1E(&ES('-P96-I9FEE9"!I;B!T:&4*("`@("`@("`@("`@("`@("\O($1"
M7V-O;6UO;CHZ9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R!P<F]P97)T>0H@("`@
M("`@("`@("`@("`@:68@*"1O8FIE8W1?8VQA<W,@/3T@)W-T9$-L87-S)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1A<G(@/2`H;V)J96-T*2`D87)R.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M87)R(#T@)FYE=R`D;V)J96-T7V-L87-S*"1A<G(I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D87)R.PH@
M("`@("`@('T*("`@("`@("!I9B`H)')E<R`]/2!N=6QL("8F("1T:&ES+3YA
M=71O9G)E92D@>PH@("`@("`@("`@("`D=&AI<RT^9G)E92@I.PH@("`@("`@
M('T*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@1F5T8V@@82!R
M;W<@;V8@9&%T82!I;G1O(&%N(&%R<F%Y('=H:6-H(&ES('!A<W-E9"!B>2!R
M969E<F5N8V4*("`@("`J"B`@("`@*B!4:&4@='EP92!O9B!A<G)A>2!R971U
M<FYE9"!C86X@8F4@8V]N=')O;&QE9"!E:71H97(@8GD@<V5T=&EN9R!T:&ES
M"B`@("`@*B!M971H;V0G<R`\=F%R/B1F971C:&UO9&4\+W9A<CX@<&%R86UE
M=&5R(&]R(&)Y(&-H86YG:6YG('1H92!D969A=6QT"B`@("`@*B!F971C:"!M
M;V1E('-E=$9E=&-H36]D92@I(&)E9F]R92!C86QL:6YG('1H:7,@;65T:&]D
M+@H@("`@("H*("`@("`J(%1H97)E(&%R92!T=V\@;W!T:6]N<R!F;W(@<W1A
M;F1A<F1I>FEN9R!T:&4@:6YF;W)M871I;VX@<F5T=7)N960*("`@("`J(&9R
M;VT@9&%T86)A<V5S+"!E;G-U<FEN9R!T:&5I<B!V86QU97,@87)E(&-O;G-I
M<W1E;G0@=VAE;B!C:&%N9VEN9PH@("`@("H@1$)-4R=S+B`@5&AE<V4@<&]R
M=&%B:6QI='D@;W!T:6]N<R!C86X@8F4@='5R;F5D(&]N('=H96X@8W)E871I
M;F<@80H@("`@("H@;F5W($1"(&]B:F5C="!O<B!B>2!U<VEN9R!S971/<'1I
M;VXH*2X*("`@("`J"B`@("`@*B`@("L@/'9A<CY$0E]03U)404))3$E465],
M3U=%4D-!4T4\+W9A<CX*("`@("`J("`@("!C;VYV97)T(&YA;65S(&]F(&9I
M96QD<R!T;R!L;W=E<B!C87-E"B`@("`@*@H@("`@("H@("`K(#QV87(^1$)?
M4$]25$%"24Q)5%E?4E1224T\+W9A<CX*("`@("`J("`@("!R:6=H="!T<FEM
M('1H92!D871A"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("8D87)R("`@
M("`@('1H92!V87)I86)L92!W:&5R92!T:&4@9&%T82!S:&]U;&0@8F4@<&QA
M8V5D"B`@("`@*B!`<&%R86T@:6YT("`@)&9E=&-H;6]D92`@=&AE(&-O;G-T
M86YT(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@9&%T80H@("`@("H@
M0'!A<F%M(&EN="`@("1R;W=N=6T@("`@('1H92!R;W<@;G5M8F5R('1O(&9E
M=&-H("AI;F1E>"!S=&%R=',@870@,"D*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!$0E]/2R!I9B!A(')O=R!I<R!P<F]C97-S960L($Y53$P@=VAE
M;B!T:&4@96YD(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@(')E<W5L
M="!S970@:7,@<F5A8VAE9"!O<B!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I
M+"!$0E]C;VUM;VXZ.G-E=$9E=&-H36]D92@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9E=&-H26YT;R@F)&%R<BP@)&9E=&-H;6]D92`]($1"7T9%5$-(34]$
M15]$149!54Q4+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M)&9E=&-H;6]D92`]/3T@1$)?1D540TA-3T1%7T1%1D%53%0I('L*("`@("`@
M("`@("`@)&9E=&-H;6]D92`]("1T:&ES+3YF971C:&UO9&4["B`@("`@("`@
M?0H@("`@("`@(&EF("@D9F5T8VAM;V1E(#T]/2!$0E]&151#2$U/1$5?3T)*
M14-4*2!["B`@("`@("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?
M05-33T,["B`@("`@("`@("`@("1O8FIE8W1?8VQA<W,@/2`D=&AI<RT^9F5T
M8VAM;V1E7V]B:F5C=%]C;&%S<SL*("`@("`@("!]"B`@("`@("`@:68@*"1T
M:&ES+3YL:6UI=%]F<F]M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@D
M=&AI<RT^<F]W7V-O=6YT97(@/3T](&YU;&PI('L*("`@("`@("`@("`@("`@
M("1T:&ES+3YR;W=?8V]U;G1E<B`]("1T:&ES+3YL:6UI=%]F<F]M.PH@("`@
M("`@("`@("`@("`@+R\@4VMI<"!R;W=S"B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/F1B:"T^9F5A='5R97-;)VQI;6ET)UT@/3T](&9A;'-E*2!["B`@
M("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("`@("`@("`@
M('=H:6QE("@D:2LK(#P@)'1H:7,M/FQI;6ET7V9R;VTI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F1B:"T^9F5T8VA);G1O*"1T:&ES+3YR
M97-U;'0L("1A<G(L("1F971C:&UO9&4I.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)'1H:7,M/G)O=U]C;W5N=&5R(#X]("@*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;&EM:71?9G)O;2`K("1T:&ES+3YL:6UI=%]C;W5N="DI
M"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^875T
M;V9R964I('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9G)E92@I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1T:&ES+3YD8F@M/F9E
M871U<F5S6R=L:6UI="==(#T]/2`G96UU;&%T92<I('L*("`@("`@("`@("`@
M("`@("1R;W=N=6T@/2`D=&AI<RT^<F]W7V-O=6YT97(["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1T:&ES+3YR;W=?8V]U;G1E<BLK.PH@("`@("`@
M('T*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B:"T^9F5T8VA);G1O*"1T:&ES
M+3YR97-U;'0L("1A<G(L("1F971C:&UO9&4L("1R;W=N=6TI.PH@("`@("`@
M(&EF("@D<F5S(#T]/2!$0E]/2RD@>PH@("`@("`@("`@("!I9B`H:7-S970H
M)&]B:F5C=%]C;&%S<RDI('L*("`@("`@("`@("`@("`@("\O(&1E9F%U;'0@
M;6]D92!S<&5C:69I960@:6X@=&AE"B`@("`@("`@("`@("`@("`O+R!$0E]C
M;VUM;VXZ.F9E=&-H;6]D95]O8FIE8W1?8VQA<W,@<')O<&5R='D*("`@("`@
M("`@("`@("`@(&EF("@D;V)J96-T7V-L87-S(#T]("=S=&1#;&%S<R<I('L*
M("`@("`@("`@("`@("`@("`@("`D87)R(#T@*&]B:F5C="D@)&%R<CL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&%R
M<B`](&YE=R`D;V)J96-T7V-L87-S*"1A<G(I.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B!$0E]/2SL*("`@
M("`@("!]"B`@("`@("`@:68@*"1R97,@/3T@;G5L;"`F)B`D=&AI<RT^875T
M;V9R964I('L*("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE('1H92!N
M=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M;G5M0V]L<R@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD8F@M/FYU
M;4-O;',H)'1H:7,M/G)E<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&YU;6)E
M<B!O9B!R;W=S(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/F1B:"T^9F5A='5R97-;)VYU;7)O
M=W,G72`]/3T@)V5M=6QA=&4G"B`@("`@("`@("`@("8F("1T:&ES+3YD8F@M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54U2
M3U=3*0H@("`@("`@('L*("`@("`@("`@("`@:68@*"1T:&ES+3YD8F@M/F9E
M871U<F5S6R=P<F5P87)E)UTI('L*("`@("`@("`@("`@("`@("1R97,@/2`D
M=&AI<RT^9&)H+3YQ=65R>2@D=&AI<RT^<75E<GDL("1T:&ES+3YP87)A;65T
M97)S*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R
M97,@/2`D=&AI<RT^9&)H+3YQ=65R>2@D=&AI<RT^<75E<GDI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@
M("`@("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("!W:&EL92`H)')E<RT^9F5T
M8VA);G1O*"1T;7`L($1"7T9%5$-(34]$15]/4D1%4D5$*2D@>PH@("`@("`@
M("`@("`@("`@)&DK*SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U
M<FX@)&D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YD8F@M/FYU;5)O=W,H)'1H:7,M/G)E<W5L="D["B`@("`@("`@?0H@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H*0H*("`@
M("\J*@H@("`@("H@1V5T('1H92!N97AT(')E<W5L="!I9B!A(&)A=&-H(&]F
M('%U97)I97,@=V%S(&5X96-U=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!T<G5E(&EF(&$@;F5W(')E<W5L="!I<R!A=F%I;&%B;&4@;W(@9F%L
M<V4@:68@;F]T"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&)H+3YN97AT4F5S=6QT*"1T
M:&ES+3YR97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R
M964H*0H*("`@("\J*@H@("`@("H@1G)E97,@=&AE(')E<V]U<F-E<R!A;&QO
M8V%T960@9F]R('1H:7,@<F5S=6QT('-E=`H@("`@("H*("`@("`J($!R971U
M<FX@8F]O;"`@=')U92!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E92@I"B`@("![
M"B`@("`@("`@)&5R<B`]("1T:&ES+3YD8F@M/F9R965297-U;'0H)'1H:7,M
M/G)E<W5L="D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1E<G(I*2!["B`@
M("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^<F5S=6QT(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/G-T871E;65N="`]
M(&9A;'-E.PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@+RHJ"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J($!D97!R96-A=&5D($UE
M=&AO9"!D97!R96-A=&5D('-O;64@=&EM92!B969O<F4@4F5L96%S92`Q+C(*
M("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1M;V1E(#T@;G5L;"D*
M("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1M;V1E*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F1B:"T^<F%I<V5%<G)O<BA$0E]%4E)/4E].
M145$7TU/4D5?1$%402D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI
M<RT^9&)H+3YT86)L94EN9F\H)'1H:7,L("1M;V1E*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!G9711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!$
M971E<FUI;F4@=&AE('%U97)Y('-T<FEN9R!T:&%T(&-R96%T960@=&AI<R!R
M97-U;'0*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y
M('-T<FEN9PH@("`@("H*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M475E<GDH*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4F]W0V]U;G1E<B@I"@H@
M("`@+RHJ"B`@("`@*B!496QL<R!W:&EC:"!R;W<@;G5M8F5R(&ES(&-U<G)E
M;G1L>2!B96EN9R!P<F]C97-S960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@('1H92!C=7)R96YT(')O=R!B96EN9R!L;V]K960@870N("!3=&%R
M=',@870@,2X*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4F]W0V]U;G1E<B@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YR;W=?8V]U;G1E<CL*("`@
M('T*"B`@("`O+R!]?7T*?0H*+R\@?7U]"B\O('M[>R!C;&%S<R!$0E]R;W<*
M"B\J*@H@*B!014%2($1"(%)O=R!/8FIE8W0*("H*("H@5&AE(&]B:F5C="!C
M;VYT86EN<R!A(')O=R!O9B!D871A(&9R;VT@82!R97-U;'0@<V5T+B`@16%C
M:"!C;VQU;6XG<R!D871A"B`J(&ES('!L86-E9"!I;B!A('!R;W!E<G1Y(&YA
M;65D(&9O<B!T:&4@8V]L=6UN+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@
M4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O1$(*("H@0'-E92`@("`@("`@1$)?8V]M;6]N.CIS
M971&971C:$UO9&4H*0H@*B\*8VQA<W,@1$)?<F]W"GL*("`@("\O('M[>R!C
M;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AE(&-O;G-T<G5C=&]R('!L
M86-E<R!A(')O=R=S(&1A=&$@:6YT;R!P<F]P97)T:65S(&]F('1H:7,@;V)J
M96-T"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("!T:&4@87)R87D@8V]N
M=&%I;FEN9R!T:&4@<F]W)W,@9&%T80H@("`@("H*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]R;W<H)B1A<G(I"B`@("![
M"B`@("`@("`@9F]R96%C:"`H)&%R<B!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("`D=&AI<RT^)&ME>2`]("8D87)R6R1K97E=.PH@("`@("`@
M('T*("`@('T*"B`@("`O+R!]?7T*?0H*+R\@?7U]"@HO*@H@*B!,;V-A;"!V
M87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@
M-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4WES=&5M
M+G!H<```````````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`T-C<V-"`Q,#4Q-30S-#$S-2`P,C`U,#$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J*@T*("H@1FEL
M92]$:7)E8W1O<GD@;6%N:7!U;&%T:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4WES=&5M#0H@*B!`875T:&]R("`@("!4;VUA<R!6
M+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4WES=&5M+G!H<"QV(#$N-3,@,C`P
M-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-
M"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL-"G)E<75I<F5?;VYC92`G0V]N<V]L92]'971O<'0N<&AP)SL-"@T*
M)$=,3T)!3%-;)U]3>7-T96U?=&5M<%]F:6QE<R==(#T@87)R87DH*3L-"@T*
M+RHJ#0HJ(%-Y<W1E;2!O9F9E<G,@8W)O<W,@<&QA='1F;W)M(&-O;7!A=&EB
M;&4@<WES=&5M(&9U;F-T:6]N<PT**@T**B!3=&%T:6,@9G5N8W1I;VYS(&9O
M<B!D:69F97)E;G0@;W!E<F%T:6]N<RX@4VAO=6QD('=O<FL@=6YD97(-"BH@
M56YI>"!A;F0@5VEN9&]W<RX@5&AE(&YA;65S(&%N9"!U<V%G92!H87,@8F5E
M;B!T86ME;B!F<F]M(&ET<R!R97-P96-T:79E;'D-"BH@1TY5(&-O;6UA;F1S
M+B!4:&4@9G5N8W1I;VYS('=I;&P@<F5T=7)N("AB;V]L*2!F86QS92!O;B!E
M<G)O<B!A;F0@=VEL;`T**B!T<FEG9V5R('1H92!E<G)O<B!W:71H('1H92!0
M2%`@=')I9V=E<E]E<G)O<B@I(&9U;F-T:6]N("AY;W4@8V%N('-I;&5N8V4-
M"BH@=&AE(&5R<F]R(&)Y('!R969I>&EN9R!A("=`)R!S:6=N(&%F=&5R('1H
M92!F=6YC=&EO;B!C86QL*2X-"BH-"BH@1&]C=6UE;G1A=&EO;B!O;B!T:&ES
M(&-L87-S('EO=2!C86X@9FEN9"!I;CH-"BH@:'1T<#HO+W!E87(N<&AP+FYE
M="]M86YU86PO#0HJ#0HJ($5X86UP;&4@=7-A9V4Z#0HJ(&EF("@A0%-Y<W1E
M;3HZ<FTH)RUR(&9I;&4Q(&1I<C$G*2D@>PT**B`@("!P<FEN="`B8V]U;&0@
M;F]T(&1E;&5T92!F:6QE,2!O<B!D:7(Q(CL-"BH@?0T**@T**B!);B!C87-E
M('EO=2!N965D('1O('1O('!A<W,@9FEL92!N86UE<R!W:71H('-P86-E<RP-
M"BH@<&%S<R!T:&4@<&%R86US(&%S(&%N(&%R<F%Y.@T**@T**B!3>7-T96TZ
M.G)M*&%R<F%Y*"<M<B<L("1F:6QE,2P@)&1I<C$I*3L-"BH-"BH@0&-A=&5G
M;W)Y("`@<&5A<@T**B!`<&%C:V%G92`@("!3>7-T96T-"BH@0&%U=&AO<B`@
M("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C;F5T+F-O;3X-"BH@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"BH@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0HJ($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0HJ($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0HJ($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*
M*B\-"F-L87-S(%-Y<W1E;0T*>PT*("`@("\J*@T*("`@("H@<F5T=7)N<R!T
M:&4@8V]M;6%N9&QI;F4@87)G=6UE;G1S(&]F(&$@9G5N8W1I;VX-"B`@("`J
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D87)G=B`@("`@("`@("`@=&AE
M(&-O;6UA;F1L:6YE#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D<VAO<G1?
M;W!T:6]N<R`@=&AE(&%L;&]W960@;W!T:6]N('-H;W)T+71A9W,-"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("1L;VYG7V]P=&EO;G,@("!T:&4@86QL;W=E
M9"!O<'1I;VX@;&]N9RUT86=S#0H@("`@*B!`<F5T=7)N("`@87)R87D@("!T
M:&4@9VEV96X@;W!T:6]N<R!A;F0@=&AE<F4@=F%L=65S#0H@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(%]P87)S94%R9W,H
M)&%R9W8L("1S:&]R=%]O<'1I;VYS+"`D;&]N9U]O<'1I;VYS(#T@;G5L;"D-
M"B`@("![#0H@("`@("`@(&EF("@A:7-?87)R87DH)&%R9W8I("8F("1A<F=V
M("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D87)G=B`]('!R96=?<W!L:70H
M)R]<<RLO)RP@)&%R9W8L("TQ+"!04D5'7U-03$E47TY/7T5-4%19*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@0V]N<V]L95]'971O<'0Z.F=E=&]P
M=#(H)&%R9W8L("1S:&]R=%]O<'1I;VYS*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`J($]U='!U="!E<G)O<G,@=VET:"!02%`@=')I9V=E<E]E<G)O<B@I
M+B!9;W4@8V%N('-I;&5N8V4@=&AE(&5R<F]R<PT*("`@("H@=VET:"!P<F5F
M:7AI;F<@82`B0"(@<VEG;B!T;R!T:&4@9G5N8W1I;VX@8V%L;#H@0%-Y<W1E
M;3HZ;6MD:7(H+BXI.PT*("`@("H-"B`@("`J($!P87)A;2!M:7AE9"`D97)R
M;W(@82!014%2(&5R<F]R(&]R(&$@<W1R:6YG('=I=&@@=&AE(&5R<F]R(&UE
M<W-A9V4-"B`@("`J($!R971U<FX@8F]O;"!F86QS90T*("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@*B\-"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1E
M<G)O<BD-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O
M<BDI('L-"B`@("`@("`@("`@("1E<G)O<B`]("1E<G)O<BT^9V5T365S<V%G
M92@I.PT*("`@("`@("!]#0H@("`@("`@('1R:6=G97)?97)R;W(H)&5R<F]R
M+"!%7U5315)?5T%23DE.1RD[#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`J($-R96%T97,@82!N97-T960@87)R87D@
M<F5P<F5S96YT:6YG('1H92!S=')U8W1U<F4@;V8@82!D:7)E8W1O<GD-"B`@
M("`J#0H@("`@*B!3>7-T96TZ.E]D:7)4;U-T<G5C="@G9&ER,2<L(#`I(#T^
M#0H@("`@*B`@($%R<F%Y#0H@("`@*B`@("`H#0H@("`@*B`@("!;9&ER<UT@
M/3X@07)R87D-"B`@("`J("`@("`@("`H#0H@("`@*B`@("`@("`@("`@(%LP
M72`]/B!D:7(Q#0H@("`@*B`@("`@("`@*0T*("`@("H-"B`@("`J("`@(%MF
M:6QE<UT@/3X@07)R87D-"B`@("`J("`@("`@("`H#0H@("`@*B`@("`@("`@
M("`@(%LP72`]/B!D:7(Q+V9I;&4R#0H@("`@*B`@("`@("`@("`@(%LQ72`]
M/B!D:7(Q+V9I;&4S#0H@("`@*B`@("`@("`@*0T*("`@("H@("`@*0T*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@)'-0871H("`@("`@3F%M92!O9B!T:&4@
M9&ER96-T;W)Y#0H@("`@*B!`<&%R86T@("`@:6YT96=E<B`D;6%X:6YS="`@
M("!M87@N(&1E97`@;V8@=&AE(&QO;VMU<`T*("`@("H@0'!A<F%M("`@(&EN
M=&5G97(@)&%K=&EN<W0@("`@<W1A<G1I;F<@9&5E<"!O9B!T:&4@;&]O:W5P
M#0H@("`@*B!`<F5T=7)N("`@87)R87D@("!T:&4@<W1R=6-T=7)E(&]F('1H
M92!D:7(-"B`@("`J($!A8V-E<W,@("!P<FEV871E#0H@("`@*B\-"@T*("`@
M(&9U;F-T:6]N(%]D:7)4;U-T<G5C="@D<U!A=&@L("1M87AI;G-T+"`D86MT
M:6YS="`](#`I#0H@("`@>PT*("`@("`@("`D<W1R=6-T(#T@87)R87DH)V1I
M<G,G(#T^(&%R<F%Y*"DL("=F:6QE<R<@/3X@87)R87DH*2D[#0H@("`@("`@
M(&EF("@H)&1I<B`]($!O<&5N9&ER*"1S4&%T:"DI(#T]/2!F86QS92D@>PT*
M("`@("`@("`@("`@4WES=&5M.CIR86ES945R<F]R*")#;W5L9"!N;W0@;W!E
M;B!D:7(@)'-0871H(BD[#0H@("`@("`@("`@("!R971U<FX@)'-T<G5C=#L@
M+R\@6%A8(&-O=6QD(&YO="!O<&5N(&5R<F]R#0H@("`@("`@('T-"B`@("`@
M("`@)'-T<G5C=%LG9&ER<R==6UT@/2`D<U!A=&@@/2!R96%L<&%T:"@D<U!A
M=&@I.R`O+R!86%@@9&]N)W0@861D(&EF("<N)R!O<B`G+BXG(#\-"B`@("`@
M("`@)&QI<W0@/2!A<G)A>2@I.PT*("`@("`@("!W:&EL92`H9F%L<V4@(3T]
M("@D9FEL92`](')E861D:7(H)&1I<BDI*2![#0H@("`@("`@("`@("!I9B`H
M)&9I;&4@(3T@)RXG("8F("1F:6QE("$]("<N+B<I('L-"B`@("`@("`@("`@
M("`@("`D;&ES=%M=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@8VQO<V5D:7(H)&1I<BD[#0H@("`@("`@('-O<G0H)&QI
M<W0I.PT*("`@("`@("!I9B`H)&%K=&EN<W0@/"`D;6%X:6YS="!\?"`D;6%X
M:6YS="`]/2`P*2![#0H@("`@("`@("`@("!F;W)E86-H*"1L:7-T(&%S("1V
M86PI('L-"B`@("`@("`@("`@("`@("`D<&%T:"`]("1S4&%T:"`N($1)4D5#
M5$]265]315!!4D%43U(@+B`D=F%L.PT*("`@("`@("`@("`@("`@(&EF("AI
M<U]D:7(H)'!A=&@I("8F("%I<U]L:6YK*"1P871H*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&UP(#T@4WES=&5M.CI?9&ER5&]3=')U8W0H)'!A=&@L
M("1M87AI;G-T+"`D86MT:6YS="LQ*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'-T<G5C="`](&%R<F%Y7VUE<F=E7W)E8W5R<VEV92@D=&UP+"`D<W1R=6-T
M*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D<W1R=6-T6R=F:6QE<R==6UT@/2`D<&%T:#L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1S=')U8W0[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!#<F5A=&5S
M(&$@;F5S=&5D(&%R<F%Y(')E<')E<V5N=&EN9R!T:&4@<W1R=6-T=7)E(&]F
M(&$@9&ER96-T;W)Y(&%N9"!F:6QE<PT*("`@("H-"B`@("`J($!P87)A;2`@
M("!A<G)A>2`D9FEL97,@07)R87D@;&ES=&EN9R!F:6QE<R!A;F0@9&ER<PT*
M("`@("H@0')E='5R;B`@(&%R<F%Y#0H@("`@*B!`<V5E(%-Y<W1E;3HZ7V1I
M<E1O4W1R=6-T*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(%]M=6QT:7!L951O
M4W1R=6-T*"1F:6QE<RD-"B`@("![#0H@("`@("`@("1S=')U8W0@/2!A<G)A
M>2@G9&ER<R<@/3X@87)R87DH*2P@)V9I;&5S)R`]/B!A<G)A>2@I*3L-"B`@
M("`@("`@<V5T='EP92@D9FEL97,L("=A<G)A>2<I.PT*("`@("`@("!F;W)E
M86-H("@D9FEL97,@87,@)&9I;&4I('L-"B`@("`@("`@("`@(&EF("AI<U]D
M:7(H)&9I;&4I("8F("%I<U]L:6YK*"1F:6QE*2D@>PT*("`@("`@("`@("`@
M("`@("1T;7`@/2!3>7-T96TZ.E]D:7)4;U-T<G5C="@D9FEL92P@,"D[#0H@
M("`@("`@("`@("`@("`@)'-T<G5C="`](&%R<F%Y7VUE<F=E7W)E8W5R<VEV
M92@D=&UP+"`D<W1R=6-T*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)'-T<G5C=%LG9FEL97,G75M=(#T@)&9I;&4[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1S=')U8W0[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!4:&4@<FT@8V]M;6%N9"!F;W(@
M<F5M;W9I;F<@9FEL97,N#0H@("`@*B!3=7!P;W)T<R!M=6QT:7!L92!F:6QE
M<R!A;F0@9&ER<R!A;F0@86QS;R!R96-U<G-I=F4@9&5L971E<PT*("`@("H-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1A<F=S("`@=&AE(&%R9W5M96YT
M<R!F;W(@<FT-"B`@("`J($!R971U<FX@("!M:7AE9"`@(%!%05)?17)R;W(@
M;W(@=')U92!F;W(@<W5C8V5S<PT*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*
M("`@("HO#0H@("`@9G5N8W1I;VX@<FTH)&%R9W,I#0H@("`@>PT*("`@("`@
M("`D;W!T<R`](%-Y<W1E;3HZ7W!A<G-E07)G<R@D87)G<RP@)W)F)RD[("\O
M(")F(B!D;R!N;W1H:6YG(&)U="!L:6ME(&ET(#HM*0T*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D;W!T<RDI('L-"B`@("`@("`@("`@(')E='5R;B!3
M>7-T96TZ.G)A:7-E17)R;W(H)&]P=',I.PT*("`@("`@("!]#0H@("`@("`@
M(&9O<F5A8V@H)&]P='-;,%T@87,@)&]P="D@>PT*("`@("`@("`@("`@:68@
M*"1O<'1;,%T@/3T@)W(G*2![#0H@("`@("`@("`@("`@("`@)&1O7W)E8W5R
M<VEV92`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@)')E="`]('1R=64[#0H@("`@("`@(&EF("AI<W-E="@D9&]?<F5C=7)S
M:79E*2D@>PT*("`@("`@("`@("`@)'-T<G5C="`](%-Y<W1E;3HZ7VUU;'1I
M<&QE5&]3=')U8W0H)&]P='-;,5TI.PT*("`@("`@("`@("`@9F]R96%C:"@D
M<W1R=6-T6R=F:6QE<R==(&%S("1F:6QE*2![#0H@("`@("`@("`@("`@("`@
M:68@*"%`=6YL:6YK*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5T(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@9F]R96%C:"@D<W1R=6-T6R=D:7)S)UT@87,@)&1I
M<BD@>PT*("`@("`@("`@("`@("`@(&EF("@A0')M9&ER*"1D:7(I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("!F;W)E86-H("@D;W!T<ULQ72!A<R`D9FEL92D@>PT*("`@("`@
M("`@("`@("`@("1D96QE=&4@/2`H:7-?9&ER*"1F:6QE*2D@/R`G<FUD:7(G
M(#H@)W5N;&EN:R<[#0H@("`@("`@("`@("`@("`@:68@*"%`)&1E;&5T92@D
M9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A;'-E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J
M($UA:V4@9&ER96-T;W)I97,N#0H@("`@*@T*("`@("H@5&AE("UP(&]P=&EO
M;B!W:6QL(&-R96%T92!P87)E;G0@9&ER96-T;W)I97,-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("1A<F=S("`@('1H92!N86UE(&]F('1H92!D:7)E8W1O
M<BAY?&EE<RD@=&\@8W)E871E#0H@("`@*B!`<F5T=7)N("`@8F]O;"`@("!4
M<G5E(&9O<B!S=6-C97-S#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!M:T1I<B@D87)G<RD-"B`@("![#0H@("`@("`@
M("1O<'1S(#T@4WES=&5M.CI?<&%R<V5!<F=S*"1A<F=S+"`G<&TZ)RD[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1O<'1S*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N(%-Y<W1E;3HZ<F%I<V5%<G)O<B@D;W!T<RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&UO9&4@/2`P-S<W.R`O+R!D969A=6QT(&UO9&4-"B`@
M("`@("`@9F]R96%C:"@D;W!T<ULP72!A<R`D;W!T*2![#0H@("`@("`@("`@
M("!I9B`H)&]P=%LP72`]/2`G<"<I('L-"B`@("`@("`@("`@("`@("`D8W)E
M871E7W!A<F5N=',@/2!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E:68H)&]P
M=%LP72`]/2`G;2<I('L-"B`@("`@("`@("`@("`@("`O+R!I9B!T:&4@;6]D
M92!I<R!C;&5A<FQY(&%N(&]C=&%L(&YU;6)E<B`H<W1A<G1S('=I=&@@,"D-
M"B`@("`@("`@("`@("`@("`O+R!C;VYV97)T(&ET('1O(&1E8VEM86P-"B`@
M("`@("`@("`@("`@("!I9B`H<W1R;&5N*"1O<'1;,5TI("8F("1O<'1;,5U[
M,'T@/3T@)S`G*2![#0H@("`@("`@("`@("`@("`@("`@("1O<'1;,5T@/2!O
M8W1D96,H)&]P=%LQ72D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@+R\@8V]N=F5R="!T;R!I;G0-"B`@("`@("`@
M("`@("`@("`@("`@)&]P=%LQ72`K/2`P.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D;6]D92`]("1O<'1;,5T[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)')E="`]('1R=64[#0H@("`@("`@
M(&EF("AI<W-E="@D8W)E871E7W!A<F5N=',I*2![#0H@("`@("`@("`@("!F
M;W)E86-H*"1O<'1S6S%=(&%S("1D:7(I('L-"B`@("`@("`@("`@("`@("`D
M9&ER<W1A8VL@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('=H:6QE("@A
M0&ES7V1I<B@D9&ER*2`F)B`D9&ER("$]($1)4D5#5$]265]315!!4D%43U(I
M('L-"B`@("`@("`@("`@("`@("`@("`@87)R87E?=6YS:&EF="@D9&ER<W1A
M8VLL("1D:7(I.PT*("`@("`@("`@("`@("`@("`@("`D9&ER(#T@9&ER;F%M
M92@D9&ER*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M=VAI;&4@*"1N97=D:7(@/2!A<G)A>5]S:&EF="@D9&ER<W1A8VLI*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-?=W)I=&5A8FQE*&1I<FYA;64H
M)&YE=V1I<BDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6UK
M9&ER*"1N97=D:7(L("1M;V1E*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E="`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@9F]R96%C:"@D;W!T<ULQ72!A<R`D9&ER*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%`:7-?9&ER*"1D:7(I("8F("%M:V1I<B@D
M9&ER+"`D;6]D92DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E="`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`J($-O;F-A=&5N871E(&9I;&5S#0H@("`@*@T*("`@("H@57-A9V4Z
M#0H@("`@*B`Q*2`D=F%R(#T@4WES=&5M.CIC870H)W-A;7!L92YT>'0@=&5S
M="YT>'0G*3L-"B`@("`J(#(I(%-Y<W1E;3HZ8V%T*"=S86UP;&4N='AT('1E
M<W0N='AT(#X@9FEN86PN='AT)RD[#0H@("`@*B`S*2!3>7-T96TZ.F-A="@G
M<V%M<&QE+G1X="!T97-T+G1X="`^/B!F:6YA;"YT>'0G*3L-"B`@("`J#0H@
M("`@*B!.;W1E.B!A<R!T:&4@8VQA<W,@=7-E(&9O<&5N+"!U<FQS('-H;W5L
M9"!W;W)K(&%L<V\@*'1E<W0@=&AA="D-"B`@("`J#0H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`D87)G<R`@('1H92!A<F=U;65N=',-"B`@("`J($!R971U
M<FX@("!B;V]L96%N('1R=64@;VX@<W5C8V5S<PT*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@)F-A="@D87)G<RD-"B`@
M("![#0H@("`@("`@("1R970@/2!N=6QL.PT*("`@("`@("`D9FEL97,@/2!A
M<G)A>2@I.PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<F=S*2D@>PT*("`@
M("`@("`@("`@)&%R9W,@/2!P<F5G7W-P;&ET*"<O7',K+R<L("1A<F=S+"`M
M,2P@4%)%1U]34$Q)5%].3U]%35!462D[#0H@("`@("`@('T-"B`@("`@("`@
M9F]R*"1I/3`[("1I(#P@8V]U;G0H)&%R9W,I.R`D:2LK*2![#0H@("`@("`@
M("`@("!I9B`H)&%R9W-;)&E=(#T]("<^)RD@>PT*("`@("`@("`@("`@("`@
M("1M;V1E(#T@)W=B)SL-"B`@("`@("`@("`@("`@("`D;W5T<'5T9FEL92`]
M("1A<F=S6R1I*S%=.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@?2!E;'-E:68@*"1A<F=S6R1I72`]/2`G/CXG*2![#0H@("`@("`@
M("`@("`@("`@)&UO9&4@/2`G86(K)SL-"B`@("`@("`@("`@("`@("`D;W5T
M<'5T9FEL92`]("1A<F=S6R1I*S%=.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9FEL
M97-;72`]("1A<F=S6R1I73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&UO9&4I*2![#0H@("`@("`@("`@("!I9B`H
M(21O=71P=71F9"`](&9O<&5N*"1O=71P=71F:6QE+"`D;6]D92DI('L-"B`@
M("`@("`@("`@("`@("`D97)R(#T@4WES=&5M.CIR86ES945R<F]R*")#;W5L
M9"!N;W0@;W!E;B`D;W5T<'5T9FEL92(I.PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D97)R.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`]
M('1R=64[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S
M("1F:6QE*2![#0H@("`@("`@("`@("!I9B`H(21F9"`](&9O<&5N*"1F:6QE
M+"`G<B<I*2![#0H@("`@("`@("`@("`@("`@4WES=&5M.CIR86ES945R<F]R
M*")#;W5L9"!N;W0@;W!E;B`D9FEL92(I.PT*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@=VAI;&4@*"1C
M;VYT(#T@9G)E860H)&9D+"`R,#0X*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D;W5T<'5T9F0I*2![#0H@("`@("`@("`@("`@("`@("`@(&9W
M<FET92@D;W5T<'5T9F0L("1C;VYT*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T("X]("1C;VYT.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9C
M;&]S92@D9F0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A`:7-?<F5S;W5R
M8V4H)&]U='!U=&9D*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1O=71P=71F
M9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@*B!#<F5A=&5S('1E;7!O<F%R>2!F:6QE<R!O<B!D
M:7)E8W1O<FEE<RX@5&AI<R!F=6YC=&EO;B!W:6QL(')E;6]V90T*("`@("H@
M=&AE(&-R96%T960@9FEL97,@=VAE;B!T:&4@<V-R:7!T<R!F:6YI<V@@:71S
M(&5X96-U=&EO;BX-"B`@("`J#0H@("`@*B!5<V%G93H-"B`@("`J("`@,2D@
M)'1E;7!F:6QE(#T@4WES=&5M.CIM:W1E;7`H(G!R969I>"(I.PT*("`@("H@
M("`R*2`D=&5M<&1I<B`@/2!3>7-T96TZ.FUK=&5M<"@B+60@<')E9FEX(BD[
M#0H@("`@*B`@(#,I("1T96UP9FEL92`](%-Y<W1E;3HZ;6MT96UP*"D[#0H@
M("`@*B`@(#0I("1T96UP9FEL92`](%-Y<W1E;3HZ;6MT96UP*"(M="`O=F%R
M+W1M<"!P<F5F:7@B*3L-"B`@("`J#0H@("`@*B!P<F5F:7@@+3X@5&AE('-T
M<FEN9R!T:&%T('=I;&P@8F4@<')E<&5N9&5D('1O('1H92!T96UP(&YA;64-
M"B`@("`J("`@("`@("`@("`H9&5F875L=',@=&\@(G1M<"(I+@T*("`@("H@
M+60@("`@("T^($$@=&5M<&]R87)Y(&1I<B!W:6QL(&)E(&-R96%T960@:6YS
M=&5A9"!O9B!A(&9I;&4N#0H@("`@*B`M="`@("`@+3X@5&AE('1A<F=E="!D
M:7(@=VAE<F4@=&AE('1E;7!O<F%R>2`H9FEL97QD:7(I('=I;&P@8F4@8W)E
M871E9"X@268-"B`@("`J("`@("`@("`@("!T:&ES('!A<F%M(&ES(&UI<W-I
M;F<@8GD@9&5F875L="!T:&4@96YV('9A<G,@5$U0(&]N(%=I;F1O=W,@;W(-
M"B`@("`J("`@("`@("`@("!435!$25(@:6X@56YI>"!W:6QL(&)E('5S960N
M($EF('1H97-E('9A<G,@87)E(&%L<V\@;6ES<VEN9PT*("`@("H@("`@("`@
M("`@(&,Z7'=I;F1O=W-<=&5M<"!O<B`O=&UP('=I;&P@8F4@=7-E9"X-"B`@
M("`J#0H@("`@*B!`<&%R86T@("!S=')I;F<@("1A<F=S("!4:&4@87)G=6UE
M;G1S#0H@("`@*B!`<F5T=7)N("!M:7AE9"`@('1H92!F=6QL('!A=&@@;V8@
M=&AE(&-R96%T960@*&9I;&5\9&ER*2!O<B!F86QS90T*("`@("H@0'-E92!3
M>7-T96TZ.G1M<&1I<B@I#0H@("`@*B!`86-C97-S("!P=6)L:6,-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&UK=&5M<"@D87)G<R`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!S=&%T:6,@)&9I<G-T7W1I;64@/2!T<G5E.PT*("`@("`@("`D
M;W!T<R`](%-Y<W1E;3HZ7W!A<G-E07)G<R@D87)G<RP@)W0Z9"<I.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;W!T<RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!3>7-T96TZ.G)A:7-E17)R;W(H)&]P=',I.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<F5A8V@H)&]P='-;,%T@87,@)&]P="D@>PT*("`@("`@
M("`@("`@:68H)&]P=%LP72`]/2`G9"<I('L-"B`@("`@("`@("`@("`@("`D
M=&UP7VES7V1I<B`]('1R=64[#0H@("`@("`@("`@("!](&5L<V5I9B@D;W!T
M6S!=(#T]("=T)RD@>PT*("`@("`@("`@("`@("`@("1T;7!D:7(@/2`D;W!T
M6S%=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1P<F5F
M:7@@/2`H:7-S970H)&]P='-;,5U;,%TI*2`_("1O<'1S6S%=6S!=(#H@)W1M
M<"<[#0H@("`@("`@(&EF("@A:7-S970H)'1M<&1I<BDI('L-"B`@("`@("`@
M("`@("1T;7!D:7(@/2!3>7-T96TZ.G1M<&1I<B@I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A4WES=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D=&UP9&ER
M*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D=&UP(#T@=&5M<&YA;2@D=&UP9&ER+"`D<')E9FEX*3L-"B`@
M("`@("`@:68@*&ES<V5T*"1T;7!?:7-?9&ER*2D@>PT*("`@("`@("`@("`@
M=6YL:6YK*"1T;7`I.R`O+R!B92!C87)E9G5L('!O<W-I8FQE(')A8V4@8V]N
M9&ET:6]N(&AE<F4-"B`@("`@("`@("`@(&EF("@A;6MD:7(H)'1M<"P@,#<P
M,"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4WES=&5M.CIR86ES945R
M<F]R*")5;F%B;&4@=&\@8W)E871E('1E;7!O<F%R>2!D:7)E8W1O<GD@)'1M
M<&1I<B(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1'
M3$]"04Q36R=?4WES=&5M7W1E;7!?9FEL97,G75M=(#T@)'1M<#L-"B`@("`@
M("`@:68@*"1F:7)S=%]T:6UE*2![#0H@("`@("`@("`@("!014%2.CIR96=I
M<W1E<E-H=71D;W=N1G5N8RAA<G)A>2@G4WES=&5M)RP@)U]R96UO=F54;7!&
M:6QE<R<I*3L-"B`@("`@("`@("`@("1F:7)S=%]T:6UE(#T@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T;7`[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@*B!296UO=F4@=&5M<&]R87)Y(&9I;&5S(&-R96%T960@;7D@
M;6M496UP+B!4:&ES(&9U;F-T:6]N(&ES(&5X96-U=&5D#0H@("`@*B!A="!S
M8W)I<'0@<VAU=&1O=VX@=&EM90T*("`@("H-"B`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("HO#0H@("`@9G5N8W1I;VX@7W)E;6]V951M<$9I;&5S*"D-
M"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D1TQ/0D%,4ULG7U-Y<W1E;5]T
M96UP7V9I;&5S)UTI*2![#0H@("`@("`@("`@("`D9&5L971E(#T@)$=,3T)!
M3%-;)U]3>7-T96U?=&5M<%]F:6QE<R==.PT*("`@("`@("`@("`@87)R87E?
M=6YS:&EF="@D9&5L971E+"`G+7(G*3L-"B`@("`@("`@("`@(%-Y<W1E;3HZ
M<FTH)&1E;&5T92D[#0H@("`@("`@("`@("`D1TQ/0D%,4ULG7U-Y<W1E;5]T
M96UP7V9I;&5S)UT@/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@*B!'970@=&AE('!A=&@@;V8@=&AE('1E;7!O<F%L(&1I
M<F5C=&]R>2!S970@:6X@=&AE('-Y<W1E;0T*("`@("H@8GD@;&]O:VEN9R!I
M;B!I=',@96YV:7)O;FUE;G1S('9A<FEA8FQE<RX-"B`@("`J($YO=&4Z('!H
M<"YI;FDM<F5C;VUM96YD960@<F5M;W9E<R!T:&4@(D4B(&9R;VT@=&AE('9A
M<FEA8FQE<U]O<F1E<B!S971T:6YG+`T*("`@("H@;6%K:6YG('5N879A:6)L
M92!T:&4@)%]%3E8@87)R87DL('1H870@<R!W:'D@=V4@9&\@=&5S=',@=VET
M:"!?14Y6#0H@("`@*@T*("`@("H@0')E='5R;B!S=')I;F<@5&AE('1E;7!O
M<F%L(&1I<F5C=&]R>2!O;B!T:&4@<WES=&5M#0H@("`@*B\-"B`@("!F=6YC
M=&EO;B!T;7!D:7(H*0T*("`@('L-"B`@("`@("`@:68@*$]37U=)3D1/5U,I
M('L-"B`@("`@("`@("`@(&EF("@D=F%R(#T@:7-S970H)%]%3E9;)U1%35`G
M72D@/R`D7T5.5ELG5$5-4"==(#H@9V5T96YV*"=414U0)RDI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'9A<CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D=F%R(#T@:7-S970H)%]%3E9;)U1-4"==*2`_("1?14Y6
M6R=435`G72`Z(&=E=&5N=B@G5$U0)RDI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)'9A<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M=F%R(#T@:7-S970H)%]%3E9;)W=I;F1I<B==*2`_("1?14Y66R=W:6YD:7(G
M72`Z(&=E=&5N=B@G=VEN9&ER)RDI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'9A<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!G
M971E;G8H)U-Y<W1E;5)O;W0G*2`N("=<=&5M<"<[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1V87(@/2!I<W-E="@D7T5.5ELG5$U01$E2)UTI(#\@)%]%
M3E9;)U1-4$1)4B==(#H@9V5T96YV*"=435!$25(G*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1V87([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("<O
M=&UP)SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J(%1H92`B=VAI8V@B(&-O
M;6UA;F0@*'-H;W<@=&AE(&9U;&P@<&%T:"!O9B!A(&-O;6UA;F0I#0H@("`@
M*@T*("`@("H@0'!A<F%M('-T<FEN9R`D<')O9W)A;2!4:&4@8V]M;6%N9"!T
M;R!S96%R8V@@9F]R#0H@("`@*B!`<&%R86T@;6EX960@("1F86QL8F%C:R!6
M86QU92!T;R!R971U<FX@:68@)'!R;V=R86T@:7,@;F]T(&9O=6YD#0H@("`@
M*@T*("`@("H@0')E='5R;B!M:7AE9"!!('-T<FEN9R!W:71H('1H92!F=6QL
M('!A=&@@;W(@9F%L<V4@:68@;F]T(&9O=6YD#0H@("`@*B!`875T:&]R(%-T
M:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`@("`J+PT*("`@(&9U;F-T:6]N
M('=H:6-H*"1P<F]G<F%M+"`D9F%L;&)A8VL@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("\O(&5N9F]R8V4@05!)#0H@("`@("`@(&EF("@A:7-?<W1R:6YG
M*"1P<F]G<F%M*2!\?"`G)R`]/2`D<')O9W)A;2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1F86QL8F%C:SL-"B`@("`@("`@?0T*#0H@("`@("`@("\O(&%V
M86EL86)L92!S:6YC92`T+C,N,%)#,@T*("`@("`@("!I9B`H9&5F:6YE9"@G
M4$%42%]315!!4D%43U(G*2D@>PT*("`@("`@("`@("`@)'!A=&A?9&5L:6T@
M/2!0051(7U-%4$%2051/4CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1P871H7V1E;&EM(#T@3U-?5TE.1$]74R`_("<[)R`Z("<Z)SL-"B`@
M("`@("`@?0T*("`@("`@("`O+R!F=6QL('!A=&@@9VEV96X-"B`@("`@("`@
M:68@*&)A<V5N86UE*"1P<F]G<F%M*2`A/2`D<')O9W)A;2D@>PT*("`@("`@
M("`@("`@)'!A=&A?96QE;65N='-;72`](&1I<FYA;64H)'!R;V=R86TI.PT*
M("`@("`@("`@("`@)'!R;V=R86T@/2!B87-E;F%M92@D<')O9W)A;2D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O+R!(;VYO<B!S869E(&UO
M9&4-"B`@("`@("`@("`@(&EF("@A:6YI7V=E="@G<V%F95]M;V1E)RD@?'P@
M(21P871H(#T@:6YI7V=E="@G<V%F95]M;V1E7V5X96-?9&ER)RDI('L-"B`@
M("`@("`@("`@("`@("`D<&%T:"`](&=E=&5N=B@G4$%42"<I.PT*("`@("`@
M("`@("`@("`@(&EF("@A)'!A=&@I('L-"B`@("`@("`@("`@("`@("`@("`@
M)'!A=&@@/2!G971E;G8H)U!A=&@G*3L@+R\@<V]M92!/4V5S(&%R92!J=7-T
M('-T=7!I9"!E;F]U9V@@=&\@9&\@=&AI<PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P871H7V5L96UE;G1S(#T@
M97AP;&]D92@D<&%T:%]D96QI;2P@)'!A=&@I.PT*("`@("`@("!]#0H-"B`@
M("`@("`@:68@*$]37U=)3D1/5U,I('L-"B`@("`@("`@("`@("1E>&5?<W5F
M9FEX97,@/2!G971E;G8H)U!!5$A%6%0G*0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`_(&5X<&QO9&4H)'!A=&A?9&5L:6TL(&=E=&5N=B@G
M4$%42$585"<I*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M(&%R<F%Y*"<N97AE)RPG+F)A="<L)RYC;60G+"<N8V]M)RD[#0H@("`@("`@
M("`@("`O+R!A;&QO=R!P87-S:6YG(&$@8V]M;6%N9"YE>&4@<&%R86T-"B`@
M("`@("`@("`@(&EF("AS=')P;W,H)'!R;V=R86TL("<N)RD@(3T](&9A;'-E
M*2![#0H@("`@("`@("`@("`@("`@87)R87E?=6YS:&EF="@D97AE7W-U9F9I
M>&5S+"`G)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!I<U]E
M>&5C=71A8FQE*"D@:7,@;F]T(&%V86EL86)L92!O;B!W:6YD;W=S(&9O<B!0
M2%`T#0H@("`@("`@("`@("`D<&5A<E]I<U]E>&5C=71A8FQE(#T@*&9U;F-T
M:6]N7V5X:7-T<R@G:7-?97AE8W5T86)L92<I*2`_("=I<U]E>&5C=71A8FQE
M)R`Z("=I<U]F:6QE)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1E>&5?<W5F9FEX97,@/2!A<G)A>2@G)RD[#0H@("`@("`@("`@("`D<&5A
M<E]I<U]E>&5C=71A8FQE(#T@)VES7V5X96-U=&%B;&4G.PT*("`@("`@("!]
M#0H-"B`@("`@("`@9F]R96%C:"`H)&5X95]S=69F:7AE<R!A<R`D<W5F9BD@
M>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A=&A?96QE;65N=',@87,@)&1I
M<BD@>PT*("`@("`@("`@("`@("`@("1F:6QE(#T@)&1I<B`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`D<')O9W)A;2`N("1S=69F.PT*("`@("`@("`@("`@
M("`@(&EF("@D<&5A<E]I<U]E>&5C=71A8FQE*"1F:6QE*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&9I;&4[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M9F%L;&)A8VL[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!4:&4@(F9I;F0B
M(&-O;6UA;F0-"B`@("`J#0H@("`@*B!5<V%G93H-"B`@("`J#0H@("`@*B!3
M>7-T96TZ.F9I;F0H)&1I<BD[#0H@("`@*B!3>7-T96TZ.F9I;F0H(B1D:7(@
M+71Y<&4@9"(I.PT*("`@("H@4WES=&5M.CIF:6YD*"(D9&ER("UT>7!E(&8B
M*3L-"B`@("`J(%-Y<W1E;3HZ9FEN9"@B)&1I<B`M;F%M92`J+G!H<"(I.PT*
M("`@("H@4WES=&5M.CIF:6YD*"(D9&ER("UN86UE("HN<&AP("UN86UE("HN
M:'1M*B(I.PT*("`@("H@4WES=&5M.CIF:6YD*"(D9&ER("UM87AD97!T:"`Q
M(BD[#0H@("`@*@T*("`@("H@4&%R86US(&EM<&QM96YT960Z#0H@("`@*B`D
M9&ER("`@("`@("`@("`@+3X@4W1A<G0@=&AE('-E87)C:"!A="!T:&ES(&1I
M<F5C=&]R>0T*("`@("H@+71Y<&4@9"`@("`@("`@("T^(')E='5R;B!O;FQY
M(&1I<F5C=&]R:65S#0H@("`@*B`M='EP92!F("`@("`@("`@+3X@<F5T=7)N
M(&]N;'D@9FEL97,-"B`@("`J("UM87AD97!T:"`\;CX@("`M/B!M87@@9&5P
M=&@@;V8@<F5C=7)S:6]N#0H@("`@*B`M;F%M92`\<&%T=&5R;CX@+3X@<V5A
M<F-H('!A='1E<FX@*&)A<V@@<W1Y;&4I+B!-=6QT:7!L92`M;F%M92!P87)A
M;2!A;&QO=V5D#0H@("`@*@T*("`@("H@0'!A<F%M("!M:7AE9"!%:71H97(@
M87)R87D@;W(@<W1R:6YG('=I=&@@=&AE(&-O;6UA;F0@;&EN90T*("`@("H@
M0')E='5R;B!A<G)A>2!!<G)A>2!O9B!F;W5N9"!F:6QE<PT*("`@("H-"B`@
M("`J+PT*("`@(&9U;F-T:6]N(&9I;F0H)&%R9W,I#0H@("`@>PT*("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1A<F=S*2D@>PT*("`@("`@("`@("`@)&%R9W,@
M/2!P<F5G7W-P;&ET*"<O7',K+R<L("1A<F=S+"`M,2P@4%)%1U]34$Q)5%].
M3U]%35!462D[#0H@("`@("`@('T-"B`@("`@("`@)&1I<B`](&%R<F%Y7W-H
M:69T*"1A<F=S*3L-"B`@("`@("`@)'!A='1E<FYS(#T@87)R87DH*3L-"B`@
M("`@("`@)&1E<'1H(#T@,#L-"B`@("`@("`@)&1O7V9I;&5S(#T@)&1O7V1I
M<G,@/2!T<G5E.PT*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D
M87)G<RD[("1I*RLI('L-"B`@("`@("`@("`@('-W:71C:"`H)&%R9W-;)&E=
M*2![#0H@("`@("`@("`@("`@("`@8V%S92`G+71Y<&4G.@T*("`@("`@("`@
M("`@("`@("`@("!I9B`H:6Y?87)R87DH)&%R9W-;)&DK,5TL(&%R<F%Y*"=D
M)RP@)V8G*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D87)G
M<ULD:2LQ72`]/2`G9"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&]?9FEL97,@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1O7V1I
M<G,@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D:2LK.PT*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C
M87-E("<M;F%M92<Z#0H@("`@("`@("`@("`@("`@("`@(&EF("A/4U]724Y$
M3U=3*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%R9W-;)&DK
M,5U[,'T@/3T@)UQ<)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O('!R97!E;F0@9')I=F4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D87)G<ULD:2LQ72`](&%D9'-L87-H97,H<W5B<W1R*&=E=&-W9"@I+"`P
M+"`R*2`N("1A<F=S6R1I("L@,5TI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@97-C87!E('!A=&@@
M<V5P87)A=&]R<R!T;R!A=F]I9"!00U)%('!R;V)L96US#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D87)G<ULD:2LQ72`]('-T<E]R97!L86-E*"=<7"<L
M("=<7%Q<)RP@)&%R9W-;)&DK,5TI.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("1P871T97)N<UM=(#T@(B@B("X@<')E
M9U]R97!L86-E*&%R<F%Y*"<O7"XO)RP@)R]<*B\G*2P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)UPN)RP@)RXJ)RP@*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%R9W-;)&DK,5TI#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(BDB.PT*("`@
M("`@("`@("`@("`@("`@("`D:2LK.PT*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("<M;6%X9&5P=&@G.@T*("`@
M("`@("`@("`@("`@("`@("`D9&5P=&@@/2`D87)G<ULD:2LQ73L-"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@)'!A=&@@/2!3>7-T96TZ.E]D:7)4;U-T<G5C="@D9&ER
M+"`D9&5P=&@I.PT*("`@("`@("!I9B`H)&1O7V9I;&5S("8F("1D;U]D:7)S
M*2![#0H@("`@("`@("`@("`D9FEL97,@/2!A<G)A>5]M97)G92@D<&%T:%LG
M9FEL97,G72P@)'!A=&A;)V1I<G,G72D[#0H@("`@("`@('T@96QS96EF("@D
M9&]?9&ER<RD@>PT*("`@("`@("`@("`@)&9I;&5S(#T@)'!A=&A;)V1I<G,G
M73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1F:6QE<R`]("1P
M871H6R=F:6QE<R==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D
M<&%T=&5R;G,I*2![#0H@("`@("`@("`@("`D<&%T=&5R;G,@/2!I;7!L;V1E
M*"=\)RP@)'!A='1E<FYS*3L-"B`@("`@("`@("`@("1R970@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)&9I;&5S
M*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"(C
M7B1P871T97)N<UPD(R(L("1F:6QE<ULD:5TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1R971;72`]("1F:6QE<ULD:5T[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1F:6QE<SL-"B`@("!]#0I]#0H_
M/@T*````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]P
M96%R8VUD+G!H<```````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#,U-C$S(#$P-3$U-#,T,3,U(#`R,#8Q-P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+R\-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R<VEO
M;B`U("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L
M("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K
M86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*+R\@
M?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@
M?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN
M970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\
M("`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M#0HO+PT*+R\@)$ED.B!P96%R8VUD+G!H<"QV(#$N,S,@,C`P-B\P,2\P,B`Q
M.#HP-3HU,R!C96QL;V<@17AP("0-"@T*;V)?96YD7V-L96%N*"D[#0II9B`H
M(61E9FEN960H)U!%05)?4E5.5%E012<I*2![#0H@("`@+R\@=&AI<R!I<R!D
M969I;F5D(&EN('!E8VQC;60N<&AP(&%S("=P96-L)PT*("`@(&1E9FEN92@G
M4$5!4E]254Y465!%)RP@)W!E87(G*3L-"GT-"F1E9FEN92@G4$5!4E])1TY/
M4D5?0D%#2U1204-%)RP@,2D[#0II9B`H(69U;F-T:6]N7V5X:7-T<R@G9FEL
M95]G971?8V]N=&5N=',G*2D@>PT*("`@(&9U;F-T:6]N(&9I;&5?9V5T7V-O
M;G1E;G1S*"1F:6QE;F%M92D-"B`@("![#0H@("`@("`@("1F<"`](&9O<&5N
M*"1F:6QE;F%M92P@)W)B)RD[#0H@("`@("`@("1R970@/2`G)SL-"B`@("`@
M("`@=VAI;&4@*"%F96]F*"1F<"DI('L-"B`@("`@("`@("`@("1R970@+CT@
M9G)E860H)&9P+"`X,#DR*3L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@?0T*?0T*+RHJ#0H@*B!`;F]D97`@1W1K#0H@*B\-"FEF
M("@G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(G("$]("=`)RXG:6YC
M;'5D95]P871H)RXG0"<I('L-"B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G
M+"`G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(G*3L-"B`@("`D<F%W
M(#T@9F%L<V4[#0I](&5L<V4@>PT*("`@("\O('1H:7,@:7,@82!R87<L('5N
M:6YS=&%L;&5D('!E87(L(&5I=&AE<B!A(&-V<R!C:&5C:V]U="P@;W(@<&AP
M(&1I<W1R;PT*("`@("1R87<@/2!T<G5E.PT*?0T*0&EN:5]S970H)V%L;&]W
M7W5R;%]F;W!E;B<L('1R=64I.PT*:68@*"%I;FE?9V5T*"=S869E7VUO9&4G
M*2D@>PT*("`@($!S971?=&EM95]L:6UI="@P*3L-"GT-"F]B7VEM<&QI8VET
M7V9L=7-H*'1R=64I.PT*0&EN:5]S970H)W1R86-K7V5R<F]R<R<L('1R=64I
M.PT*0&EN:5]S970H)VAT;6Q?97)R;W)S)RP@9F%L<V4I.PT*0&EN:5]S970H
M)VUA9VEC7W%U;W1E<U]R=6YT:6UE)RP@9F%L<V4I.PT*)%]014%27U!(4$1)
M4B`]("<C)"5>)BHG.PT*<V5T7V5R<F]R7VAA;F1L97(H)V5R<F]R7VAA;F1L
M97(G*3L-"@T*)'!E87)?<&%C:V%G95]V97)S:6]N(#T@(C$N-"XY(CL-"@T*
M<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O
M1G)O;G1E;F0N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF:6<N<&AP
M)SL-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM86YD+G!H<"<[#0IR97%U:7)E
M7V]N8V4@)T-O;G-O;&4O1V5T;W!T+G!H<"<[#0H-"@T*4$5!4E]#;VUM86YD
M.CIS971&<F]N=&5N9%1Y<&4H)T-,22<I.PT*)&%L;%]C;VUM86YD<R`](%!%
M05)?0V]M;6%N9#HZ9V5T0V]M;6%N9',H*3L-"@T*+R\@<F5M;W9E('1H:7,@
M;F5X="!P87)T('=H96X@=V4@<W1O<"!S=7!P;W)T:6YG('1H870@8W)A<"UA
M<W,@4$A0(#0N,@T*:68@*"%I<W-E="@D7U-%4E9%4ELG87)G=B==*2`F)B`A
M:7-S970H)&%R9W8I("8F("%I<W-E="@D2%144%]315)615)?5D%24ULG87)G
M=B==*2D@>PT*("`@(&1I92@G15)23U(Z(&5I=&AE<B!U<V4@=&AE($-,22!P
M:'`@97AE8W5T86)L92P@;W(@<V5T(')E9VES=&5R7V%R9V-?87)G=CU/;B!I
M;B!P:'`N:6YI)RD[#0I]#0HD87)G=B`]($-O;G-O;&5?1V5T;W!T.CIR96%D
M4$A007)G=B@I.PT*+R\@9FEX($-'22!S87!I(&]D9&ET>2`M('1H92`M+2!I
M;B!P96%R+F)A="]P96%R(&ES(&YO="!R96UO=F5D#0II9B`H<&AP7W-A<&E?
M;F%M92@I("$]("=C;&DG("8F(&ES<V5T*"1A<F=V6S%=*2`F)B`D87)G=ELQ
M72`]/2`G+2TG*2![#0H@("`@=6YS970H)&%R9W9;,5TI.PT*("`@("1A<F=V
M(#T@87)R87E?=F%L=65S*"1A<F=V*3L-"GT-"B1P<F]G;F%M92`](%!%05)?
M4E5.5%E013L-"FEF("AI;E]A<G)A>2@G9V5T;W!T,B<L(&=E=%]C;&%S<U]M
M971H;V1S*"=#;VYS;VQE7T=E=&]P="<I*2D@>PT*("`@(&%R<F%Y7W-H:69T
M*"1A<F=V*3L-"B`@("`D;W!T:6]N<R`]($-O;G-O;&5?1V5T;W!T.CIG971O
M<'0R*"1A<F=V+"`B8SI#.F0Z1#I':#]S4W%U.G96(BD[#0I](&5L<V4@>PT*
M("`@("1O<'1I;VYS(#T@0V]N<V]L95]'971O<'0Z.F=E=&]P="@D87)G=BP@
M(F,Z0SID.D0Z1V@_<U-Q=3IV5B(I.PT*?0T*:68@*%!%05(Z.FES17)R;W(H
M)&]P=&EO;G,I*2![#0H@("`@=7-A9V4H)&]P=&EO;G,I.PT*?0T*#0HD;W!T
M<R`]("1O<'1I;VYS6S!=.PT*#0HD9F5T>7!E(#T@)T-,22<[#0II9B`H)'!R
M;V=N86UE(#T]("=G<&5A<B<@?'P@)'!R;V=N86UE(#T]("=P96%R+6=T:R<I
M('L-"B`@("`D9F5T>7!E(#T@)T=T:R<[#0I](&5L<V4@>PT*("`@(&9O<F5A
M8V@@*"1O<'1S(&%S("1O<'0I('L-"B`@("`@("`@:68@*"1O<'1;,%T@/3T@
M)T<G*2![#0H@("`@("`@("`@("`D9F5T>7!E(#T@)T=T:R<[#0H@("`@("`@
M('T-"B`@("!]#0I]#0HO+T-H96-K(&EF($=T:R!A;F0@4$A0(#X](#4N,2XP
M#0II9B`H)&9E='EP92`]/2`G1W1K)R`F)B!V97)S:6]N7V-O;7!A<F4H<&AP
M=F5R<VEO;B@I+"`G-2XQ+C`G+"`G/CTG*2D@>PT*("`@("1F971Y<&4@/2`G
M1W1K,B<[#0I]#0H-"B1P96%R7W5S97)?8V]N9FEG(#T@)R<[#0HD<&5A<E]S
M>7-T96U?8V]N9FEG(#T@)R<[#0HD<W1O<F5?=7-E<E]C;VYF:6<@/2!F86QS
M93L-"B1S=&]R95]S>7-T96U?8V]N9FEG(#T@9F%L<V4[#0HD=F5R8F]S92`]
M(#$[#0H-"F9O<F5A8V@@*"1O<'1S(&%S("1O<'0I('L-"B`@("!S=VET8V@@
M*"1O<'1;,%TI('L-"B`@("`@("`@8V%S92`G8R<Z#0H@("`@("`@("`@("`D
M<&5A<E]U<V5R7V-O;F9I9R`]("1O<'1;,5T[#0H@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@8V%S92`G0R<Z#0H@("`@("`@("`@("`D<&5A<E]S>7-T
M96U?8V]N9FEG(#T@)&]P=%LQ73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@
M('T-"GT-"@T*4$5!4E]#;VUM86YD.CIS971&<F]N=&5N9%1Y<&4H)&9E='EP
M92D[#0HD=6D@/2`F4$5!4E]#;VUM86YD.CIG971&<F]N=&5N9$]B:F5C="@I
M.PT*)&-O;F9I9R`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"1P96%R7W5S
M97)?8V]N9FEG+"`D<&5A<E]S>7-T96U?8V]N9FEG*3L-"@T*:68@*%!%05(Z
M.FES17)R;W(H)&-O;F9I9RDI('L-"B`@("`D7V9I;&4@/2`G)SL-"B`@("!I
M9B`H)'!E87)?=7-E<E]C;VYF:6<@(3T](&9A;'-E*2![#0H@("`@("`@)%]F
M:6QE("X]("1P96%R7W5S97)?8V]N9FEG.PT*("`@('T-"B`@("!I9B`H)'!E
M87)?<WES=&5M7V-O;F9I9R`A/3T@9F%L<V4I('L-"B`@("`@("`D7V9I;&4@
M+CT@)R\G("X@)'!E87)?<WES=&5M7V-O;F9I9SL-"B`@("!]#0H@("`@:68@
M*"1?9FEL92`]/2`G+R<I('L-"B`@("`@("`@)%]F:6QE(#T@)U1H92!D969A
M=6QT(&-O;F9I9R!F:6QE)SL-"B`@("!]#0H@("`@)&-O;F9I9RT^9V5T365S
M<V%G92@I.PT*("`@("1U:2T^;W5T<'5T1&%T82@B15)23U(Z("1?9FEL92!I
M<R!N;W0@82!V86QI9"!C;VYF:6<@9FEL92!O<B!I<R!C;W)R=7!T960N(BD[
M#0H@("`@+R\@5V4@<W1O<"P@=V4@:&%V92!N;R!I9&5A('=H97)E('=E(&%R
M92`Z*0T*("`@(&5X:70H*3L@("`@#0I]#0H-"B\O('1H:7,@:7,@=7-E9"!I
M;B!T:&4@97)R;W(@:&%N9&QE<B!T;R!R971R:65V92!A(')E;&%T:79E('!A
M=&@-"B1?4$5!4E]02%!$25(@/2`D8V]N9FEG+3YG970H)W!H<%]D:7(G*3L-
M"B1U:2T^<V5T0V]N9FEG*"1C;VYF:6<I.PT*4$5!4CHZ<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27T-!3$Q"04-++"!A<G)A>2@D=6DL(")D:7-P;&%Y
M1F%T86Q%<G)O<B(I*3L-"FEF("AI;FE?9V5T*"=S869E7VUO9&4G*2D@>PT*
M("`@("1U:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@<G5N;FEN9R!I;B!S869E
M(&UO9&4@<F5Q=6ER97,@=&AA="!A;&P@9FEL97,@8W)E871E9"`G("X-"B`@
M("`@("`@)V)E('1H92!S86UE('5I9"!A<R!T:&4@8W5R<F5N="!S8W)I<'0N
M("!02%`@<F5P;W)T<R!T:&ES('-C<FEP="!I<R!U:60Z("<@+@T*("`@("`@
M("!`9V5T;7EU:60H*2`N("<L(&%N9"!C=7)R96YT('5S97(@:7,Z("<@+B!`
M9V5T7V-U<G)E;G1?=7-E<B@I*3L-"GT-"@T*)'9E<F)O<V4@/2`D8V]N9FEG
M+3YG970H(G9E<F)O<V4B*3L-"B1C;61O<'1S(#T@87)R87DH*3L-"@T*:68@
M*"1R87<I('L-"B`@("!I9B`H(21C;VYF:6<M/FES1&5F:6YE9$QA>65R*"=U
M<V5R)RD@)B8@(21C;VYF:6<M/FES1&5F:6YE9$QA>65R*"=S>7-T96TG*2D@
M>PT*("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@9F]R96%C:"`H
M)&]P=',@87,@)&]P="D@>PT*("`@("`@("`@("`@:68@*"1O<'1;,%T@/3T@
M)V0G('Q\("1O<'1;,%T@/3T@)T0G*2![#0H@("`@("`@("`@("`@("`@)&9O
M=6YD(#T@=')U93L@+R\@=&AE('5S97(@:VYO=W,@=VAA="!T:&5Y(&%R92!D
M;VEN9RP@86YD(&%R92!S971T:6YG(&-O;F9I9R!V86QU97,-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21F;W5N9"D@>PT*("`@
M("`@("`@("`@+R\@;F\@<')I;W(@<G5N<RP@=')Y('1O(&EN<W1A;&P@4$5!
M4@T*("`@("`@("`@("`@:68@*'-T<G!O<RAD:7)N86UE*%]?1DE,15]?*2P@
M)W-C<FEP=',G*2D@>PT*("`@("`@("`@("`@("`@("1P86-K86=E>&UL(#T@
M9&ER;F%M92AD:7)N86UE*%]?1DE,15]?*2D@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@("`@("`@("`@)'!E87)B
M87-E(#T@9&ER;F%M92AD:7)N86UE*%]?1DE,15]?*2D[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1P86-K86=E>&UL(#T@9&ER
M;F%M92A?7T9)3$5?7RD@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA
M9V4R+GAM;"<[#0H@("`@("`@("`@("`@("`@)'!E87)B87-E(#T@9&ER;F%M
M92A?7T9)3$5?7RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M9FEL95]E>&ES=',H)'!A8VMA9V5X;6PI*2![#0H@("`@("`@("`@("`@("`@
M)&]P=&EO;G-;,5T@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN
M<W1A;&PG+`T*("`@("`@("`@("`@("`@("`@("`D<&%C:V%G97AM;`T*("`@
M("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T
M*"=P:'!?9&ER)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N
M("=P:'`G*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG+3YS970H)V1A=&%?
M9&ER)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N("=D871A
M)RD[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=D;V-?9&ER)RP@
M)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N("=D;V-S)RD[#0H@
M("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=T97-T7V1I<B<L("1P96%R
M8F%S92`N($1)4D5#5$]265]315!!4D%43U(@+B`G=&5S=',G*3L-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YS970H)V5X=%]D:7(G+"`D<&5A<F)A<V4@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)V5X=&5N<VEO;G,G*3L-"B`@("`@
M("`@("`@("`@("`D8V]N9FEG+3YS970H)V)I;E]D:7(G+"`D<&5A<F)A<V4I
M.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/FUE<F=E0V]N9FEG1FEL92@D
M<&5A<F)A<V4@+B`G<&5A<BYI;FDG+"!F86QS92D[#0H@("`@("`@("`@("`@
M("`@)&-O;F9I9RT^<W1O<F4H*3L-"B`@("`@("`@("`@("`@("`D8V]N9FEG
M+3YS970H)V%U=&]?9&ES8V]V97(G+"`Q*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@('T-"GT-"F9O<F5A8V@@*"1O<'1S(&%S("1O<'0I('L-
M"B`@("`D<&%R86T@/2`A96UP='DH)&]P=%LQ72D@/R`D;W!T6S%=(#H@=')U
M93L-"B`@("!S=VET8V@@*"1O<'1;,%TI('L-"B`@("`@("`@8V%S92`G9"<Z
M#0H@("`@("`@("`@("!L:7-T*"1K97DL("1V86QU92D@/2!E>'!L;V1E*"<]
M)RP@)'!A<F%M*3L-"B`@("`@("`@("`@("1C;VYF:6<M/G-E="@D:V5Y+"`D
M=F%L=64L("=U<V5R)RD[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M8V%S92`G1"<Z#0H@("`@("`@("`@("!L:7-T*"1K97DL("1V86QU92D@/2!E
M>'!L;V1E*"<])RP@)'!A<F%M*3L-"B`@("`@("`@("`@("1C;VYF:6<M/G-E
M="@D:V5Y+"`D=F%L=64L("=S>7-T96TG*3L-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("!C87-E("=S)SH-"B`@("`@("`@("`@("1S=&]R95]U<V5R
M7V-O;F9I9R`]('1R=64[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M8V%S92`G4R<Z#0H@("`@("`@("`@("`D<W1O<F5?<WES=&5M7V-O;F9I9R`]
M('1R=64[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G=2<Z
M#0H@("`@("`@("`@("`D8V]N9FEG+3YR96UO=F4H)'!A<F%M+"`G=7-E<B<I
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)W8G.@T*("`@
M("`@("`@("`@)&-O;F9I9RT^<V5T*"=V97)B;W-E)RP@)&-O;F9I9RT^9V5T
M*"=V97)B;W-E)RD@*R`Q*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("!C87-E("=Q)SH-"B`@("`@("`@("`@("1C;VYF:6<M/G-E="@G=F5R8F]S
M92<L("1C;VYF:6<M/F=E="@G=F5R8F]S92<I("T@,2D[#0H@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@8V%S92`G5B<Z#0H@("`@("`@("`@("!U<V%G
M92AN=6QL+"`G=F5R<VEO;B<I.PT*("`@("`@("!C87-E("=C)SH-"B`@("`@
M("`@8V%S92`G0R<Z#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@9&5F
M875L=#H-"B`@("`@("`@("`@("\O(&%L;"!N;VX@<&5A<B!P87)A;7,@9V]E
M<R!T;R!T:&4@8V]M;6%N9`T*("`@("`@("`@("`@)&-M9&]P='-;)&]P=%LP
M75T@/2`D<&%R86T[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("!]#0I]#0H-
M"FEF("@D<W1O<F5?<WES=&5M7V-O;F9I9RD@>PT*("`@("1C;VYF:6<M/G-T
M;W)E*"=S>7-T96TG*3L-"GT-"@T*:68@*"1S=&]R95]U<V5R7V-O;F9I9RD@
M>PT*("`@("1C;VYF:6<M/G-T;W)E*"=U<V5R)RD[#0I]#0H-"B1C;VUM86YD
M(#T@*&ES<V5T*"1O<'1I;VYS6S%=6S!=*2D@/R`D;W!T:6]N<ULQ75LP72`Z
M(&YU;&P[#0H-"FEF("AE;7!T>2@D8V]M;6%N9"D@)B8@*"1S=&]R95]U<V5R
M7V-O;F9I9R!\?"`D<W1O<F5?<WES=&5M7V-O;F9I9RDI('L-"B`@("!E>&ET
M.PT*?0T*#0II9B`H)&9E='EP92`]/2`G1W1K)R!\?"`D9F5T>7!E(#T]("='
M=&LR)RD@>PT*("`@(&EF("@A)&-O;F9I9RT^=F%L:61#;VYF:6=U<F%T:6]N
M*"DI('L-"B`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@G0U))5$E#04P@15)2
M3U(Z(&YO(&5X:7-T:6YG('9A;&ED(&-O;F9I9W5R871I;VX@9FEL97,@9F]U
M;F0@:6X@9FEL97,@)R`N#0H@("`@("`@("`@("`B)R1P96%R7W5S97)?8V]N
M9FEG)R!O<B`G)'!E87)?<WES=&5M7V-O;F9I9R<L('!L96%S92!C;W!Y(&%N
M(&5X:7-T:6YG(&-O;F9I9W5R871I;VXB("X-"B`@("`@("`@("`@("=F:6QE
M('1O(&]N92!O9B!T:&5S92!L;V-A=&EO;G,L(&]R('5S92!T:&4@+6,@86YD
M("US(&]P=&EO;G,@=&\@8W)E871E(&]N92<I.PT*("`@('T-"B`@("!'=&LZ
M.FUA:6XH*3L-"GT@96QS92!D;R![#0H@("`@:68@*"1C;VUM86YD(#T]("=H
M96QP)RD@>PT*("`@("`@("!U<V%G92AN=6QL+"!`)&]P=&EO;G-;,5U;,5TI
M.PT*("`@('T-"B`@("!I9B`H(21C;VYF:6<M/G9A;&ED0V]N9FEG=7)A=&EO
M;B@I*2![#0H@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)T-2251)0T%,($52
M4D]2.B!N;R!E>&ES=&EN9R!V86QI9"!C;VYF:6=U<F%T:6]N(&9I;&5S(&9O
M=6YD(&EN(&9I;&5S("<@+@T*("`@("`@("`@("`@(B<D<&5A<E]U<V5R7V-O
M;F9I9R<@;W(@)R1P96%R7W-Y<W1E;5]C;VYF:6<G+"!P;&5A<V4@8V]P>2!A
M;B!E>&ES=&EN9R!C;VYF:6=U<F%T:6]N(B`N#0H@("`@("`@("`@("`G9FEL
M92!T;R!O;F4@;V8@=&AE<V4@;&]C871I;VYS+"!O<B!U<V4@=&AE("UC(&%N
M9"`M<R!O<'1I;VYS('1O(&-R96%T92!O;F4G*3L-"B`@("!]#0H-"B`@("!0
M14%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@)&-M9"`](%!%05)?0V]M;6%N9#HZ9F%C=&]R>2@D8V]M;6%N9"P@)&-O
M;F9I9RD[#0H@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@(&EF
M("A014%2.CII<T5R<F]R*"1C;60I*2![#0H@("`@("`@('5S86=E*&YU;&PL
M($`D;W!T:6]N<ULQ75LP72D[#0H@("`@?0T*#0H@("`@)'-H;W)T7V%R9W,@
M/2`D;&]N9U]A<F=S(#T@;G5L;#L-"B`@("!014%27T-O;6UA;F0Z.F=E=$=E
M=&]P=$%R9W,H)&-O;6UA;F0L("1S:&]R=%]A<F=S+"`D;&]N9U]A<F=S*3L-
M"B`@("!I9B`H:6Y?87)R87DH)V=E=&]P=#(G+"!G971?8VQA<W-?;65T:&]D
M<R@G0V]N<V]L95]'971O<'0G*2DI('L-"B`@("`@("`@87)R87E?<VAI9G0H
M)&]P=&EO;G-;,5TI.PT*("`@("`@("`D=&UP(#T@0V]N<V]L95]'971O<'0Z
M.F=E=&]P=#(H)&]P=&EO;G-;,5TL("1S:&]R=%]A<F=S+"`D;&]N9U]A<F=S
M*3L-"B`@("!](&5L<V4@>PT*("`@("`@("`D=&UP(#T@0V]N<V]L95]'971O
M<'0Z.F=E=&]P="@D;W!T:6]N<ULQ72P@)'-H;W)T7V%R9W,L("1L;VYG7V%R
M9W,I.PT*("`@('T-"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&UP*2D@>PT*
M("`@("`@("!B<F5A:SL-"B`@("!]#0H@("`@;&ES="@D=&UP;W!T+"`D<&%R
M86US*2`]("1T;7`[#0H@("`@)&]P=',@/2!A<G)A>2@I.PT*("`@(&9O<F5A
M8V@@*"1T;7!O<'0@87,@)&9O;R`]/B`D=&UP,BD@>PT*("`@("`@("!L:7-T
M*"1O<'0L("1V86QU92D@/2`D=&UP,CL-"B`@("`@("`@:68@*"1V86QU92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@)'9A;'5E(#T@=')U93L@+R\@;W!T
M:6]N<R!W:71H;W5T(&%R9W,-"B`@("`@("`@?0T*("`@("`@("!I9B`H<W1R
M;&5N*"1O<'0I(#T](#$I('L-"B`@("`@("`@("`@("1C;61O<'1I;VYS(#T@
M)&-M9"T^9V5T3W!T:6]N<R@D8V]M;6%N9"D[#0H@("`@("`@("`@("!F;W)E
M86-H("@D8VUD;W!T:6]N<R!A<R`D;R`]/B`D9"D@>PT*("`@("`@("`@("`@
M("`@(&EF("A`)&1;)W-H;W)T;W!T)UT@/3T@)&]P="D@>PT*("`@("`@("`@
M("`@("`@("`@("`D;W!T<ULD;UT@/2`D=F%L=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@:68@*'-U8G-T<B@D;W!T+"`P+"`R*2`]/2`G+2TG*2![#0H@("`@
M("`@("`@("`@("`@)&]P='-;<W5B<W1R*"1O<'0L(#(I72`]("1V86QU93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`D;VL@/2`D
M8VUD+3YR=6XH)&-O;6UA;F0L("1O<'1S+"`D<&%R86US*3L-"B`@("!I9B`H
M)&]K(#T]/2!F86QS92D@>PT*("`@("`@("!014%2.CIR86ES945R<F]R*")U
M;FMN;W=N(&-O;6UA;F0@8"1C;VUM86YD)R(I.PT*("`@('T-"B`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D;VLI*2![#0H@("`@("`@(%!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@87)R87DH)'5I+"`B9&ES
M<&QA>49A=&%L17)R;W(B*2D[#0H@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H
M)&]K*3L-"B`@("!]#0I]('=H:6QE("AF86QS92D[#0H-"B\O('M[>R!U<V%G
M92@I#0H-"F9U;F-T:6]N('5S86=E*"1E<G)O<B`](&YU;&PL("1H96QP<W5B
M:F5C="`](&YU;&PI#0I[#0H@("`@9VQO8F%L("1P<F]G;F%M92P@)&%L;%]C
M;VUM86YD<SL-"B`@("`D<W1D97)R(#T@9F]P96XH)W!H<#HO+W-T9&5R<B<L
M("=W)RD[#0H@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R*2D@>PT*("`@
M("`@("!F<'5T<R@D<W1D97)R+"`D97)R;W(M/F=E=$UE<W-A9V4H*2`N(")<
M;B(I.PT*("`@('T@96QS96EF("@D97)R;W(@(3T](&YU;&PI('L-"B`@("`@
M("`@9G!U=',H)'-T9&5R<BP@(B1E<G)O<EQN(BD[#0H@("`@?0T*("`@(&EF
M("@D:&5L<'-U8FIE8W0@(3T@;G5L;"D@>PT*("`@("`@("`D<'5T(#T@8VUD
M2&5L<"@D:&5L<'-U8FIE8W0I.PT*("`@('T@96QS92![#0H@("`@("`@("1P
M=70@/0T*("`@("`@("`@("`@(D-O;6UA;F1S.EQN(CL-"B`@("`@("`@)&UA
M>&QE;B`](&UA>"AA<G)A>5]M87`H(G-T<FQE;B(L("1A;&Q?8V]M;6%N9',I
M*3L-"B`@("`@("`@)&9O<FUA='-T<B`]("(E+7LD;6%X;&5N?7,@("5S7&XB
M.PT*("`@("`@("!K<V]R="@D86QL7V-O;6UA;F1S*3L-"B`@("`@("`@9F]R
M96%C:"`H)&%L;%]C;VUM86YD<R!A<R`D8VUD(#T^("1C;&%S<RD@>PT*("`@
M("`@("`@("`@)'!U="`N/2!S<')I;G1F*"1F;W)M871S='(L("1C;60L(%!%
M05)?0V]M;6%N9#HZ9V5T1&5S8W)I<'1I;VXH)&-M9"DI.PT*("`@("`@("!]
M#0H@("`@("`@("1P=70@+CT-"B`@("`@("`@("`@(")5<V%G93H@)'!R;V=N
M86UE(%MO<'1I;VYS72!C;VUM86YD(%MC;VUM86YD+6]P=&EO;G-=(#QP87)A
M;65T97)S/EQN(BX-"B`@("`@("`@("`@(")4>7!E(%PB)'!R;V=N86UE(&AE
M;'`@;W!T:6]N<UPB('1O(&QI<W0@86QL(&]P=&EO;G,N7&XB+@T*("`@("`@
M("`@("`@(E1Y<&4@7"(D<')O9VYA;64@:&5L<"!S:&]R=&-U='-<(B!T;R!L
M:7-T(&%L;"!C;VUM86YD('-H;W)T8W5T<RY<;B(N#0H@("`@("`@("`@("`B
M5'EP92!<(B1P<F]G;F%M92!H96QP(#QC;VUM86YD/EPB('1O(&=E="!T:&4@
M:&5L<"!F;W(@=&AE('-P96-I9FEE9"!C;VUM86YD+B([#0H@("`@?0T*("`@
M(&9P=71S*"1S=&1E<G(L("(D<'5T7&XB*3L-"B`@("!F8VQO<V4H)'-T9&5R
M<BD[#0H@("`@97AI=#L-"GT-"@T*9G5N8W1I;VX@8VUD2&5L<"@D8V]M;6%N
M9"D-"GL-"B`@("!G;&]B86P@)'!R;V=N86UE+"`D86QL7V-O;6UA;F1S+"`D
M8V]N9FEG.PT*("`@(&EF("@D8V]M;6%N9"`]/2`B;W!T:6]N<R(I('L-"B`@
M("`@("`@<F5T=7)N#0H@("`@("`@(")/<'1I;VYS.EQN(BX-"B`@("`@("`@
M(B`@("`@+78@("`@("`@("!I;F-R96%S92!V97)B;W-I='D@;&5V96P@*&1E
M9F%U;'0@,2E<;B(N#0H@("`@("`@("(@("`@("UQ("`@("`@("`@8F4@<75I
M970L(&1E8W)E87-E('9E<F)O<VET>2!L979E;%QN(BX-"B`@("`@("`@(B`@
M("`@+6,@9FEL92`@("!F:6YD('5S97(@8V]N9FEG=7)A=&EO;B!I;B!@9FEL
M92=<;B(N#0H@("`@("`@("(@("`@("U#(&9I;&4@("`@9FEN9"!S>7-T96T@
M8V]N9FEG=7)A=&EO;B!I;B!@9FEL92=<;B(N#0H@("`@("`@("(@("`@("UD
M(&9O;SUB87(@<V5T('5S97(@8V]N9FEG('9A<FEA8FQE(&!F;V\G('1O(&!B
M87(G7&XB+@T*("`@("`@("`B("`@("`M1"!F;V\]8F%R('-E="!S>7-T96T@
M8V]N9FEG('9A<FEA8FQE(&!F;V\G('1O(&!B87(G7&XB+@T*("`@("`@("`B
M("`@("`M1R`@("`@("`@('-T87)T(&EN(&=R87!H:6-A;"`H1W1K*2!M;V1E
M7&XB+@T*("`@("`@("`B("`@("`M<R`@("`@("`@('-T;W)E('5S97(@8V]N
M9FEG=7)A=&EO;EQN(BX-"B`@("`@("`@(B`@("`@+5,@("`@("`@("!S=&]R
M92!S>7-T96T@8V]N9FEG=7)A=&EO;EQN(BX-"B`@("`@("`@(B`@("`@+74@
M9F]O("`@("!U;G-E="!@9F]O)R!I;B!T:&4@=7-E<B!C;VYF:6=U<F%T:6]N
M7&XB+@T*("`@("`@("`B("`@("`M:"P@+3\@("`@(&1I<W!L87D@:&5L<"]U
M<V%G92`H=&AI<R!M97-S86=E*5QN(BX-"B`@("`@("`@(B`@("`@+58@("`@
M("`@("!V97)S:6]N(&EN9F]R;6%T:6]N7&XB.PT*("`@('T@96QS96EF("@D
M8V]M;6%N9"`]/2`B<VAO<G1C=71S(BD@>PT*("`@("`@("`D<V,@/2!014%2
M7T-O;6UA;F0Z.F=E=%-H;W)T8W5T<R@I.PT*("`@("`@("`D<F5T(#T@(E-H
M;W)T8W5T<SI<;B([#0H@("`@("`@(&9O<F5A8V@@*"1S8R!A<R`D<R`]/B`D
M8RD@>PT*("`@("`@("`@("`@)')E="`N/2!S<')I;G1F*"(@("`@("4M.',@
M)7-<;B(L("1S+"`D8RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R
M970[#0H-"B`@("!](&5L<V5I9B`H)&-O;6UA;F0@/3T@(G9E<G-I;VXB*2![
M#0H@("`@("`@(')E='5R;B`B4$5!4B!697)S:6]N.B`B+B1'3$]"04Q36R=P
M96%R7W!A8VMA9V5?=F5R<VEO;B==+@T*("`@("`@("`@("`@("`@(EQN4$A0
M(%9E<G-I;VXZ("(N<&AP=F5R<VEO;B@I+@T*("`@("`@("`@("`@("`@(EQN
M6F5N9"!%;F=I;F4@5F5R<VEO;CH@(BYZ96YD7W9E<G-I;VXH*2X-"B`@("`@
M("`@("`@("`@(")<;E)U;FYI;F<@;VXZ("(N<&AP7W5N86UE*"D[#0H-"B`@
M("!](&5L<V5I9B`H)&AE;'`@/2!014%27T-O;6UA;F0Z.F=E=$AE;'`H)&-O
M;6UA;F0I*2![#0H@("`@("`@(&EF("AI<U]S=')I;F<H)&AE;'`I*2![#0H@
M("`@("`@("`@("!R971U<FX@(B1P<F]G;F%M92`D8V]M;6%N9"!;;W!T:6]N
M<UT@)&AE;'!<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@*"1H96QP6S%=
M(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@(B1P<F]G;F%M92`D
M8V]M;6%N9"`D:&5L<%LP72([#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!R971U<FX@(B1P<F]G;F%M92`D8V]M;6%N9"!;;W!T:6]N<UT@)&AE
M;'!;,%U<;B1H96QP6S%=(CL-"B`@("`@("`@?0T*("`@('T-"B`@("!R971U
M<FX@(D-O;6UA;F0@)R1C;VUM86YD)R!I<R!N;W0@=F%L:60L('1R>2`G<&5A
M<B!H96QP)R([#0I]#0H-"B\O('U]?0T*#0IF=6YC=&EO;B!E<G)O<E]H86YD
M;&5R*"1E<G)N;RP@)&5R<FUS9RP@)&9I;&4L("1L:6YE+"`D=F%R<RD@>PT*
M("`@(&EF("@H9&5F:6YE9"@G15]35%))0U0G*2`F)B`D97)R;F\@)B!%7U-4
M4DE#5"D@?'P@(65R<F]R7W)E<&]R=&EN9R@I*2![#0H@("`@("`@(&EF("AD
M969I;F5D*"=%7U-44DE#5"<I("8F("1E<G)N;R`F($5?4U1224-4*2![#0H@
M("`@("`@("`@("!R971U<FX[("\O($5?4U1224-4#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1'3$]"04Q36R=C;VYF:6<G72T^9V5T*"=V97)B;W-E)RD@
M/"`T*2![#0H@("`@("`@("`@("!R971U<FX[("\O($!S:6QE;F-E9"!E<G)O
M<BP@<VAO=R!A;&P@:68@9&5B=6<@:7,@:&EG:"!E;F]U9V@-"B`@("`@("`@
M?0T*("`@('T-"B`@("`D97)R;W)T>7!E(#T@87)R87D@*`T*("`@("`@("!%
M7T524D]2("`@/3X@(")%<G)O<B(L#0H@("`@("`@($5?5T%23DE.1R`@(#T^
M("`B5V%R;FEN9R(L#0H@("`@("`@($5?4$%24T4@("`]/B`@(E!A<G-I;F<@
M17)R;W(B+`T*("`@("`@("!%7TY/5$E#12`@(#T^("`B3F]T:6-E(BP-"B`@
M("`@("`@15]#3U)%7T524D]2("`]/B`@(D-O<F4@17)R;W(B+`T*("`@("`@
M("!%7T-/4D5?5T%23DE.1R`@/3X@(")#;W)E(%=A<FYI;F<B+`T*("`@("`@
M("!%7T-/35!)3$5?15)23U(@(#T^("`B0V]M<&EL92!%<G)O<B(L#0H@("`@
M("`@($5?0T]-4$E,15]705).24Y'(#T^("`B0V]M<&EL92!787)N:6YG(BP-
M"B`@("`@("`@15]54T527T524D]2(#T^("`B57-E<B!%<G)O<B(L#0H@("`@
M("`@($5?55-%4E]705).24Y'(#T^("`B57-E<B!787)N:6YG(BP-"B`@("`@
M("`@15]54T527TY/5$E#12`]/B`@(E5S97(@3F]T:6-E(@T*("`@("D[#0H@
M("`@)'!R969I>"`]("1E<G)O<G1Y<&5;)&5R<FYO73L-"B`@("!G;&]B86P@
M)%]014%27U!(4$1)4CL-"B`@("!I9B`H<W1R:7-T<B@D9FEL92P@)%]014%2
M7U!(4$1)4BDI('L-"B`@("`@("`@)&9I;&4@/2!S=6)S='(H)&9I;&4L('-T
M<FQE;B@D7U!%05)?4$A01$E2*2`K(#$I.PT*("`@('T@96QS92![#0H@("`@
M("`@("1F:6QE(#T@8F%S96YA;64H)&9I;&4I.PT*("`@('T-"B`@("!P<FEN
M="`B7&XD<')E9FEX.B`D97)R;7-G(&EN("1F:6QE(&]N(&QI;F4@)&QI;F5<
M;B([#0I]#0H-"@T*+RH-"B`J($QO8V%L('9A<FEA8FQE<SH-"B`J('1A8BUW
M:61T:#H@-`T*("H@8RUB87-I8RUO9F9S970Z(#0-"B`J(&EN9&5N="UT86)S
M+6UO9&4Z(&YI;`T*("H@;6]D93H@<&AP#0H@*B!%;F0Z#0H@*B\-"B\O('9I
M;38P,#IS>6X]<&AP#0H-"C\^#0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+G!H<```````
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C4R
M-38@,3`U,34T,S0Q,S4@,#(P,C$Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD
M96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"`@("`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B
M0'-E8F%S=&EA;BUB97)G;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($-A8VAE+G!H
M<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E
M7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O;F-E("=#86-H92]%<G)O<BYP
M:'`G.PH*+RHJ"BH@0V%C:&4@:7,@82!B87-E(&-L87-S(&9O<B!C86-H92!I
M;7!L96UE;G1A=&EO;G,N"BH**B!4:&4@<&5A<B!C86-H92!M;V1U;&4@:7,@
M82!G96YE<FEC(&1A=&$@8V%C:&4@=VAI8V@@8V%N(&)E('5S960@=&\@"BH@
M8V%C:&4@<V-R:7!T(')U;G,N(%1H92!I9&5A(&)E:&EN9"!T:&4@8V%C:&4@
M:7,@<75I=&4@<VEM<&QE+B!)9B!Y;W4@:&%V90HJ('1H92!S86UE(&EN<'5T
M('!A<F%M971E<G,@9F]R('=H871E=F5R('1A<VMS+V%L9V]R:71H;2!Y;W4@
M=7-E('EO=2=L;`HJ('5S=6%L;'D@9V5T('1H92!S86UE(&]U='!U="X@4V\@
M=VAY(&YO="!C86-H:6YG('1E;7!L871E<RP@9G5N8W1I;VYS(&-A;&QS+`HJ
M(&=R87!H:6,@9V5N97)A=&EO;B!E=&,N($-A8VAI;F<@8V5R=&%I;B!A8W1I
M;VYS(&4N9RX@6%-,5"!T<F%N9F]R;6%T:6]N<PHJ('-A=F5S('EO=2!L;W1S
M(&]F('1I;64N(`HJ"BH@5&AE(&1E<VEG;B!O9B!T:&4@8V%C:&4@<F5M:6YD
M<R!O9B!02%!,:6)S('-E<W-I;VX@:6UP;&5M96YT871I;VXN($$@"BH@*%!(
M4$QI8CH@<V5S<VEO;BD@8V]N=')O;&QE<B!U<V5S('-T;W)A9V4@8V]N=&%I
M;F5R("A02%!,:6(Z(&-T7RHN:6YC*2!T;R!S879E(`HJ(&-E<G1A:6X@9&%T
M82`H4$A03&EB.B!S97-S:6]N(&1A=&$I+B!);B!C;VYT<F%S="!T;R!T:&4@
M<V5S<VEO;B!S='5F9B!I="=S('5P('1O(`HJ('EO=2!T;R!G96YE<F%T92!A
M;B!)1"!F;W(@=&AE(&1A=&$@=&\@8V%C:&4N($EF('EO=2=R92!U<VEN9R!T
M:&4@;W5T<'5T(&-A8VAE"BH@>6]U(&UI9VAT('5S92!T:&4@<V-R:7!T(&YA
M;64@87,@82!S965D(&9O<B!C86-H93HZ9V5N97)A=&5)1"@I+"!I9B!Y;W5R
M('5S:6YG('1H90HJ(&9U;F-T:6]N(&-A8VAE('EO=2=D('5S92!A;B!A<G)A
M>2!W:71H(&%L;"!F=6YC=&EO;B!P87)A;65T97)S+@HJ"BH@57-A9V4@97AA
M;7!L92!O9B!T:&4@9V5N97)I8R!D871A(&-A8VAE.@HJ"BH@<F5Q=6ER95]O
M;F-E*"=#86-H92YP:'`G*3L**@HJ("1C86-H92`](&YE=R!#86-H92@G9FEL
M92<L(&%R<F%Y*"=C86-H95]D:7(G(#T^("=C86-H92\G*2`I.PHJ("1I9"`]
M("1C86-H92T^9V5N97)A=&5)1"@G=&5S=&5N=')Y)RD["BH**B!I9B`H)&1A
M=&$@/2`D8V%C:&4M/F=E="@D:60I*2!["BH@("`@<')I;G0@(D-A8VAE(&AI
M="X\8G(^1&%T83H@)&1A=&$B.PHJ"BH@?2!E;'-E('L**B`@("1D871A(#T@
M)V1A=&$@;V8@86YY(&MI;F0G.PHJ("`@)&-A8VAE+3YS879E*"1I9"P@)&1A
M=&$I.PHJ("`@<')I;G0@)T-A8VAE(&UI<W,N/&)R/B<["BH@?0HJ"BH@5T%2
M3DE.1SH@3F\@1FEL92]$0BU486)L92U2;W<@;&]C:VEN9R!I<R!I;7!L96UE
M;G1E9"!Y970L"BH@("`@("`@("`@:70G<R!P;W-S:6)L92P@=&AA="!Y;W4@
M9V5T(&-O<G)U<'1E9"!D871A+65N=')I97,@=6YD97(**B`@("`@("`@("!B
M860@8VER8W5M<W1A;F-E<R`@*&5S<&5C:6%L;'D@=VET:"!T:&4@9FEL92!C
M;VYT86EN97(I"BH**B!`875T:&]R("`@56QF(%=E;F1E;"`\=6QF+G=E;F1E
M;$!P:'!D;V,N9&4^"BH@0'9E<G-I;VX@("1)9#H@0V%C:&4N<&AP+'8@,2XU
M(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0**B!`<&%C:V%G92`@0V%C
M:&4**B!`86-C97-S("`@<'5B;&EC"BHO"F-L87-S($-A8VAE(&5X=&5N9',@
M4$5!4B!["@H@("`@+RHJ"B`@("`J($5N86)L97,@+R!D:7-A8FQE<R!C86-H
M:6YG+@H@("`@*@H@("`@*B!43T1/.B!!9&0@97AP;&%N871I;VX@=VAA="!T
M:&ES(&ES(&=O;V0@9F]R+@H@("`@*@H@("`@*B!`=F%R("`@("`@8F]O;&5A
M;@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B\*("`@('9A<B`D8V%C
M:&EN9R`]('1R=64["@H@("`@+RHJ"B`@("`J($=A<F)A9V4@8V]L;&5C=&EO
M;CH@<')O8F%B:6QI='D@:6X@<V5C;VYD<PH@("`@*@H@("`@*B!)9B!S970@
M=&\@82!V86QU92!A8F]V92`P(&$@9V%R8F%G92!C;VQL96-T:6]N('=I;&P*
M("`@("H@9FQU<V@@86QL(&-A8VAE(&5N=')I97,@;VQD97(@=&AA;B!T:&4@
M<W!E8VEF:65D(&YU;6)E<@H@("`@*B!O9B!S96-O;F1S+@H@("`@*@H@("`@
M*B!`=F%R("`@("`@:6YT96=E<@H@("`@*B!`<V5E("`@("`@)&=C7W!R;V)A
M8FEL:71Y+"`D9V-?;6%X;&EF971I;64*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PH@("`@*B\*("`@('9A<B`D9V-?=&EM92`@/2`Q.PH*("`@("\J*@H@("`@
M*B!'87)B86=E(&-O;&QE8W1I;VXZ('!R;V)A8FEL:71Y(&EN('!E<F-E;G0*
M("`@("H*("`@("H@5$]$3SH@061D(&%N(&5X<&QA;F%T:6]N+@H@("`@*@H@
M("`@*B!`=F%R("`@("`@:6YT96=E<B`@("`@,"`]/B!N979E<@H@("`@*B!`
M<V5E("`@("`@)&=C7W1I;64L("1G8U]M87AL:69E=&EM90H@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J+PH@("`@=F%R("1G8U]P<F]B86)I;&ET>2`]
M(#$["B`@("`*("`@("\J*@H@("`@*B!'87)B86=E(&-O;&QE8W1I;VXZ(&1E
M;&5T92!A;&P@96YT<FEE<R!N;W0@=7-E(&9O<B!N('-E8V]N9',N"B`@("`J
M"B`@("`J($1E9F%U;'0@:7,@;VYE(&1A>2P@-C`@*B`V,"`J(#(T(#T@.#8T
M,#`@<V5C;VYD<RX*("`@("H*("`@("H@0'9A<B`@:6YT96=E<@H@("`@*B!`
M<V5E("`D9V-?<')O8F%B:6QI='DL("1G8U]T:6UE"B`@("`J+PH@("`@=F%R
M("1G8U]M87AL:69E=&EM92`](#@V-#`P.PH*("`@("\J*@H@("`@*B!3=&]R
M86=E(&-O;G1A:6YE<B!O8FIE8W0N"B`@("`J"B`@("`J($!V87(@(&]B:F5C
M="!#86-H95]#;VYT86EN97(*("`@("HO"B`@("!V87(@)&-O;G1A:6YE<CL*
M"B`@("`O+PH@("`@+R\@<'5B;&EC(&UE=&AO9',*("`@("\O"@H@("`@+RHJ
M"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@($YA;64@;V8@8V]N=&%I
M;F5R(&-L87-S"B`@("`J($!P87)A;2`@("!A<G)A>2`@($%R<F%Y('=I=&@@
M8V]N=&%I;F5R(&-L87-S(&]P=&EO;G,*("`@("HO"B`@("!F=6YC=&EO;B!#
M86-H92@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO;G,@/2`G)RD*("`@
M('L*("`@("`@("`D=&AI<RT^4$5!4B@I.PH@("`@("`@("1C;VYT86EN97(@
M/2!S=')T;VQO=V5R*"1C;VYT86EN97(I.PH@("`@("`@("1C;VYT86EN97)?
M8VQA<W,@/2`G0V%C:&5?0V]N=&%I;F5R7R<@+B`D8V]N=&%I;F5R.PH@("`@
M("`@("1C;VYT86EN97)?8VQA<W-F:6QE(#T@)T-A8VAE+T-O;G1A:6YE<B\G
M("X@)&-O;G1A:6YE<B`N("<N<&AP)SL*"B`@("`@("`@:6YC;'5D95]O;F-E
M("1C;VYT86EN97)?8VQA<W-F:6QE.PH@("`@("`@("1T:&ES+3YC;VYT86EN
M97(@/2!N97<@)&-O;G1A:6YE<E]C;&%S<R@D8V]N=&%I;F5R7V]P=&EO;G,I
M.PH@("`@?0H*("`@("\O9&5C;VYS=')U8W1O<@H@("`@9G5N8W1I;VX@7T-A
M8VAE*"D*("`@('L*("`@("`@("`D=&AI<RT^9V%R8F%G94-O;&QE8W1I;VXH
M*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@
M8V%C:&EN9R!S=&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N("!B;V]L96%N
M("`@("!4:&4@8W5R<F5N="!C86-H:6YG('-T871E+@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$-A8VAI;F<H*0H@
M("`@>PH@("`@("`@(')E='5R;B`H)'1H:7,M/F-A8VAI;F<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!C86-H:6YG+@H@
M("`@("H*("`@("`J($!P87)A;2`@(&)O;VQE86X@("`@(%1H92!N97<@8V%C
M:&EN9R!S=&%T92X*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!S971#86-H:6YG*"1S=&%T92D*("`@('L*("`@("`@("`D
M=&AI<RT^8V%C:&EN9R`]("1S=&%T93L*("`@('T*"B`@("`O*BH*("`@("H@
M4F5T=7)N<R!T:&4@<F5Q=65S=&5D(&1A=&%S970@:70@:68@97AI<W1S(&%N
M9"!I<R!N;W0@97AP:7)E9`H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!D871A<V5T($E$"B`@("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R
M;W5P"B`@("`J($!R971U<FX@("!M:7AE9"`@(&-A8VAE9"!D871A(&]R($Y5
M3$P@;VX@9F%I;'5R90H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@
M("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N
M("<G.PH*("`@("`@("!I9B`H)'1H:7,M/FES0V%C:&5D*"1I9"P@)&=R;W5P
M*2`F)B`A)'1H:7,M/FES17AP:7)E9"@D:60L("1G<F]U<"DI"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@
M(')E='5R;B!.54Q,.PH@("`@?2`O+R!E;F0@9G5N8R!G970*"B`@("`O*BH*
M("`@("H@4W1O<F5S('1H92!G:79E;B!D871A(&EN('1H92!C86-H92X*("`@
M("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1"!U<V5D(&%S
M(&-A8VAE(&ED96YT:69I97(*("`@("H@0'!A<F%M("`@(&UI>&5D("`@9&%T
M82!T;R!C86-H90H@("`@*B!`<&%R86T@("`@:6YT96=E<B!L:69E=&EM92!O
M9B!T:&4@8V%C:&5D(&1A=&$@:6X@<V5C;VYD<R`M(#`@9F]R(&5N9&QE<W,*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E
M='5R;B`@(&)O;VQE86X*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D9&%T82P@)&5X<&ER97,@/2`P+"`D
M9W)O=7`@/2`G9&5F875L="<I('L*("`@("`@("!I9B`H(21T:&ES+3YC86-H
M:6YG*0H@("`@("`@("`@("!R971U<FX@=')U93L*"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YE>'13879E*"1I9"P@)&1A=&$L("<G+"1E>'!I<F5S+"`D9W)O
M=7`I.PH@("`@?2`O+R!E;F0@9G5N8R!S879E"@H@("`@+RHJ"B`@("`J(%-T
M;W)E<R!A(&1A=&%S970@=VET:"!A9&1I=&EO;F%L('5S97)D969I;F5D(&1A
M=&$N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*
M("`@("H@0'!A<F%M("`@(&UI>&5D("`@9&%T82!T;R!S=&]R90H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!A9&1I=&EO;F%L('5S97)D969I;F5D(&1A=&$*
M("`@("H@0'!A<F%M("`@(&UI>&5D("`@=7-E<F1E9FEN960@97AP:7)E(&1A
M=&4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@
M0')E='5R;B`@(&)O;VQE86X*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@(&=E=%5S
M97)D871A*"D*("`@("HO"B`@("!F=6YC=&EO;B!E>'13879E*"1I9"P@)&-A
M8VAE9&%T82P@)'5S97)D871A+"`D97AP:7)E<R`](#`L("1G<F]U<"`]("=D
M969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH*("`@("`@("!R971U<FX@)'1H:7,M/F-O
M;G1A:6YE<BT^<V%V92@D:60L("1C86-H961A=&$L("1E>'!I<F5S+"`D9W)O
M=7`L("1U<V5R9&%T82D["B`@("!]("\O(&5N9"!F=6YC(&5X=%-A=F4*"B`@
M("`O*BH*("`@("H@3&]A9',@=&AE(&=I=F5N($E$(&9R;VT@=&AE(&-A8VAE
M+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U
M<FX@("!M:7AE9"`@(&-A8VAE9"!D871A(&]R($Y53$P@;VX@9F%I;'5R90H@
M("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@;&]A
M9"@D:60L("1G<F]U<"`]("=D969A=6QT)RD@>PH@("`@("`@(&EF("@A)'1H
M:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B`G)SL*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YC;VYT86EN97(M/FQO860H)&ED+"`D9W)O=7`I.PH@
M("`@?2`O+R!E;F0@9G5N8R!L;V%D"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@
M=&AE('5S97)D871A(&9I96QD(&]F(&$@8V%C:&5D(&1A=&$@<V5T+@H@("`@
M*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P
M87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!S
M=')I;F<@('5S97)D871A"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@
M0'-E92`@("`@(&5X=%-A=F4H*0H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5S
M97)D871A*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@
M*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N("<G.PH*("`@
M("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^9V5T57-E<F1A=&$H)&ED
M+"`D9W)O=7`I.PH@("`@?2`O+R!E;F0@9G5N8R!G9715<V5R9&%T80H*("`@
M("\J*@H@("`@*B!296UO=F5S('1H92!S<&5C:69I960@9&%T87-E="!F<F]M
M('1H92!C86-H92X*("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T
M87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@
M("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`J+PH@("`@9G5N8W1I;VX@<F5M;W9E*"1I9"P@)&=R;W5P(#T@)V1E
M9F%U;'0G*2!["B`@("`@("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@
M("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(')E='5R;B`D=&AI<RT^8V]N
M=&%I;F5R+3YR96UO=F4H)&ED+"`D9W)O=7`I.PH@("`@?2`O+R!E;F0@9G5N
M8R!R96UO=F4*"B`@("`O*BH*("`@("H@1FQU<VAE<R!T:&4@8V%C:&4@+2!R
M96UO=F5S(&%L;"!D871A(&9R;VT@:70*("`@("H*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@8V%C:&4@9W)O=7`L(&EF(&5M<'1Y(&%L;"!G<F]U<',@=VEL
M;"!B92!F;&%S:&5D"B`@("`J($!R971U<FX@("!I;G1E9V5R(&YU;6)E<B!O
M9B!R96UO=F5D(&1A=&%S971S"B`@("`J+PH@("`@9G5N8W1I;VX@9FQU<V@H
M)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@*"$D=&AI<RT^8V%C
M:&EN9RD*("`@("`@("`@("`@<F5T=7)N('1R=64["@H@("`@("`@(')E='5R
M;B`D=&AI<RT^8V]N=&%I;F5R+3YF;'5S:"@D9W)O=7`I.PH@("`@?2`O+R!E
M;F0@9G5N8R!F;'5S:`H*("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D871A
M<V5T(&5X:7-T<RX*("`@("H*("`@("H@3F]T93H@=&AI<R!D;V5S(&YO="!S
M87D@=&AA="!T:&4@8V%C:&5D(&1A=&$@:7,@;F]T(&5X<&ER960A"B`@("`J
M"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&)O
M;VQE86X*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T
M:6]N(&ES0V%C:&5D*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@
M("`@:68@*"$D=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH*("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^:7-#86-H
M960H)&ED+"`D9W)O=7`I.PH@("`@?2`O+R!E;F0@9G5N8R!I<T-A8VAE9`H*
M("`@("\J*@H@("`@*B!#:&5C:W,@:68@82!D871A<V5T(&ES(&5X<&ER960*
M("`@("H*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<&%R86T@
M("`@:6YT96=E<B!M87AI;75M(&%G92!F;W(@=&AE(&-A8VAE9"!D871A(&EN
M('-E8V]N9',@+2`P(&9O<B!E;F1L97-S"B`@("`J("`@("`@("`@("`@("`@
M("`@($EF('1H92!C86-H960@9&%T82!I<R!O;&1E<B!B=70@=&AE(&=I=F5N
M(&QI9F5T:6UE(&ET('=I;&P*("`@("H@("`@("`@("`@("`@("`@("`@8F4@
M<F5M;W9E9"!F<F]M('1H92!C86-H92X@66]U(&1O;B=T(&AA=F4@=&\@<')O
M=FED92!T:&ES"B`@("`J("`@("`@("`@("`@("`@("`@(&%R9W5M96YT(&EF
M('EO=2!C86QL(&ES17AP:7)E9"@I+B!%=F5R>2!D871A<V5T(&MN;W=S"B`@
M("`J("`@("`@("`@("`@("`@("`@(&ET)W,@97AP:7)E(&1A=&4@86YD('=I
M;&P@8F4@<F5M;W9E9"!A=71O;6%T:6-A;&QY+B!5<V4*("`@("H@("`@("`@
M("`@("`@("`@("`@=&AI<R!O;FQY(&EF('EO=2!K;F]W('=H870@>6]U)W)E
M(&1O:6YG+BXN"B`@("`J($!R971U<FX@("!B;V]L96%N"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!I<T5X<&ER960H)&ED
M+"`D9W)O=7`@/2`G9&5F875L="<L("1M87A?86=E(#T@,"D@>PH@("`@("`@
M(&EF("@A)'1H:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH*("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1A:6YE<BT^:7-%>'!I<F5D
M*"1I9"P@)&=R;W5P+"`D;6%X7V%G92D["B`@("!]("\O(&5N9"!F=6YC(&ES
M17AP:7)E9`H*("`@("\J*@H@("`@*B!'96YE<F%T97,@82`B=6YI<75E(B!)
M1"!F;W(@=&AE(&=I=F5N('9A;'5E"B`@("`J"B`@("`J(%1H:7,@:7,@82!Q
M=6EC:R!B=70@9&ER='D@:&%C:R!T;R!G970@82`B=6YI<75E(B!)1"!F;W(@
M82!A;GD@:VEN9"!O9B!V87)I86)L92X*("`@("H@240@8VQA<VAE<R!M:6=H
M="!O8V-U<B!F<F]M('1I;64@=&\@=&EM92!A;'1H;W5G:"!T:&5Y(&%R92!E
M>'1R96UE('5N;&EK96QY(0H@("`@*@H@("`@*B!`<&%R86T@("`@;6EX960@
M("!V87)I86)L92!T;R!G96YE<F%T92!A($E$(&9O<@H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("`B=6YI<75E(B!)1`H@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`J+PH@("`@9G5N8W1I;VX@9V5N97)A=&5)1"@D=F%R:6%B;&4I('L*
M("`@("`@("`O+R!705).24Y'.B!)1"!C;&%S:&5S(&%R92!P;W-S:6)L92!A
M;'1H;W5G:"!U;FQI:V5L>0H@("`@("`@(')E='5R;B!M9#4H<V5R:6%L:7IE
M*"1V87)I86)L92DI.PH@("`@?0H*("`@("\J*@H@("`@*B!#86QL<R!T:&4@
M9V%R8F%G92!C;VQL96-T;W(@;V8@=&AE('-T;W)A9V4@;V)J96-T('=I=&@@
M82!C97)T86EN('!R;V)A8FEL:71Y"B`@("`J"B`@("`J($!P87)A;2`@("!B
M;V]L96%N($9O<F-E(&$@9V%R8F%G92!C;VQL96-T:6]N(')U;C\*("`@("H@
M0'-E92`@)&=C7W!R;V)A8FEL:71Y+"`D9V-?=&EM90H@("`@*B\*("`@(&9U
M;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1F;W)C92`](&9A;'-E*2!["B`@
M("`@("`@<W1A=&EC("1L87-T7W)U;B`](#`["@H@("`@("`@(&EF("@A)'1H
M:7,M/F-A8VAI;F<I"B`@("`@("`@("`@(')E='5R;CL*"B`@("`@("`@<W)A
M;F0H*&1O=6)L92D@;6EC<F]T:6UE*"D@*B`Q,#`P,#`P*3L*"B`@("`@("`@
M+R\@=&EM92!A;F0@<')O8F%B:6QI='D@8F%S960*("`@("`@("!I9B`H*"1F
M;W)C92D@?'P@*"1L87-T7W)U;B`F)B`D;&%S=%]R=6X@/"!T:6UE*"D@*R`D
M=&AI<RT^9V-?=&EM92D@?'P@*')A;F0H,2P@,3`P*2`\("1T:&ES+3YG8U]P
M<F]B86)I;&ET>2DI('L*("`@("`@("`@("`@)'1H:7,M/F-O;G1A:6YE<BT^
M9V%R8F%G94-O;&QE8W1I;VXH)'1H:7,M/F=C7VUA>&QI9F5T:6UE*3L*("`@
M("`@("`@("`@)&QA<W1?<G5N(#T@=&EM92@I.PH@("`@("`@('T*("`@('T@
M+R\@96YD(&9U;F,@9V%R8F%G94-O;&QE8W1I;VX*"GT@+R\@96YD(&-L87-S
M(&-A8VAE"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]P96%R8VUD+G!H<"YO<FEG````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,U-C$W(#$P-3$U-#,T,3,U
M(#`R,34V,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+R\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PT*+R\@?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW
M+3(P,#0@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD
M;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N
M9"!I<R`@("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\
M#0HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3=&EG
M($)A:VME;B`\<W-B0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\#0HO+R!\("`@("`@("`@(%1O;6%S(%8N5BY#;W@@/&-O
M>$!I9&5C;F5T+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!P96%R8VUD+G!H<"QV
M(#$N,S,@,C`P-B\P,2\P,B`Q.#HP-3HU,R!C96QL;V<@17AP("0-"@T*;V)?
M96YD7V-L96%N*"D[#0II9B`H(61E9FEN960H)U!%05)?4E5.5%E012<I*2![
M#0H@("`@+R\@=&AI<R!I<R!D969I;F5D(&EN('!E8VQC;60N<&AP(&%S("=P
M96-L)PT*("`@(&1E9FEN92@G4$5!4E]254Y465!%)RP@)W!E87(G*3L-"GT-
M"F1E9FEN92@G4$5!4E])1TY/4D5?0D%#2U1204-%)RP@,2D[#0II9B`H(69U
M;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@(&9U
M;F-T:6]N(&9I;&5?9V5T7V-O;G1E;G1S*"1F:6QE;F%M92D-"B`@("![#0H@
M("`@("`@("1F<"`](&9O<&5N*"1F:6QE;F%M92P@)W)B)RD[#0H@("`@("`@
M("1R970@/2`G)SL-"B`@("`@("`@=VAI;&4@*"%F96]F*"1F<"DI('L-"B`@
M("`@("`@("`@("1R970@+CT@9G)E860H)&9P+"`X,#DR*3L[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*?0T*+RHJ#0H@*B!`
M;F]D97`@1W1K#0H@*B\-"FEF("@G+VAO;64O;'5C97(O=V]R:R]P96%R+W-H
M87)E+W!H<"<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PT*("`@(&EN
M:5]S970H)VEN8VQU9&5?<&%T:"<L("<O:&]M92]L=6-E<B]W;W)K+W!E87(O
M<VAA<F4O<&AP)RD[#0H@("`@)')A=R`](&9A;'-E.PT*?2!E;'-E('L-"B`@
M("`O+R!T:&ES(&ES(&$@<F%W+"!U;FEN<W1A;&QE9"!P96%R+"!E:71H97(@
M82!C=G,@8VAE8VMO=70L(&]R('!H<"!D:7-T<F\-"B`@("`D<F%W(#T@=')U
M93L-"GT-"D!I;FE?<V5T*"=A;&QO=U]U<FQ?9F]P96XG+"!T<G5E*3L-"FEF
M("@A:6YI7V=E="@G<V%F95]M;V1E)RDI('L-"B`@("!`<V5T7W1I;65?;&EM
M:70H,"D[#0I]#0IO8E]I;7!L:6-I=%]F;'5S:"AT<G5E*3L-"D!I;FE?<V5T
M*"=T<F%C:U]E<G)O<G,G+"!T<G5E*3L-"D!I;FE?<V5T*"=H=&UL7V5R<F]R
M<R<L(&9A;'-E*3L-"D!I;FE?<V5T*"=M86=I8U]Q=6]T97-?<G5N=&EM92<L
M(&9A;'-E*3L-"B1?4$5!4E]02%!$25(@/2`G(R0E7B8J)SL-"G-E=%]E<G)O
M<E]H86YD;&5R*"=E<G)O<E]H86YD;&5R)RD[#0H-"B1P96%R7W!A8VMA9V5?
M=F5R<VEO;B`]("(Q+C0N.2([#0H-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G
M.PT*<F5Q=6ER95]O;F-E("=014%2+T9R;VYT96YD+G!H<"<[#0IR97%U:7)E
M7V]N8V4@)U!%05(O0V]N9FEG+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O
M0V]M;6%N9"YP:'`G.PT*<F5Q=6ER95]O;F-E("=#;VYS;VQE+T=E=&]P="YP
M:'`G.PT*#0H-"E!%05)?0V]M;6%N9#HZ<V5T1G)O;G1E;F14>7!E*"=#3$DG
M*3L-"B1A;&Q?8V]M;6%N9',@/2!014%27T-O;6UA;F0Z.F=E=$-O;6UA;F1S
M*"D[#0H-"B\O(')E;6]V92!T:&ES(&YE>'0@<&%R="!W:&5N('=E('-T;W`@
M<W5P<&]R=&EN9R!T:&%T(&-R87`M87-S(%!(4"`T+C(-"FEF("@A:7-S970H
M)%]315)615);)V%R9W8G72D@)B8@(6ES<V5T*"1A<F=V*2`F)B`A:7-S970H
M)$A45%!?4T525D527U9!4E-;)V%R9W8G72DI('L-"B`@("!D:64H)T524D]2
M.B!E:71H97(@=7-E('1H92!#3$D@<&AP(&5X96-U=&%B;&4L(&]R('-E="!R
M96=I<W1E<E]A<F=C7V%R9W8]3VX@:6X@<&AP+FEN:2<I.PT*?0T*)&%R9W8@
M/2!#;VYS;VQE7T=E=&]P=#HZ<F5A9%!(4$%R9W8H*3L-"B\O(&9I>"!#1TD@
M<V%P:2!O9&1I='D@+2!T:&4@+2T@:6X@<&5A<BYB870O<&5A<B!I<R!N;W0@
M<F5M;W9E9`T*:68@*'!H<%]S87!I7VYA;64H*2`A/2`G8VQI)R`F)B!I<W-E
M="@D87)G=ELQ72D@)B8@)&%R9W9;,5T@/3T@)RTM)RD@>PT*("`@('5N<V5T
M*"1A<F=V6S%=*3L-"B`@("`D87)G=B`](&%R<F%Y7W9A;'5E<R@D87)G=BD[
M#0I]#0HD<')O9VYA;64@/2!014%27U)53E194$4[#0II9B`H:6Y?87)R87DH
M)V=E=&]P=#(G+"!G971?8VQA<W-?;65T:&]D<R@G0V]N<V]L95]'971O<'0G
M*2DI('L-"B`@("!A<G)A>5]S:&EF="@D87)G=BD[#0H@("`@)&]P=&EO;G,@
M/2!#;VYS;VQE7T=E=&]P=#HZ9V5T;W!T,B@D87)G=BP@(F,Z0SID.D0Z1V@_
M<U-Q=3IV5B(I.PT*?2!E;'-E('L-"B`@("`D;W!T:6]N<R`]($-O;G-O;&5?
M1V5T;W!T.CIG971O<'0H)&%R9W8L(")C.D,Z9#I$.D=H/W-3<74Z=E8B*3L-
M"GT-"FEF("A014%2.CII<T5R<F]R*"1O<'1I;VYS*2D@>PT*("`@('5S86=E
M*"1O<'1I;VYS*3L-"GT-"@T*)&]P=',@/2`D;W!T:6]N<ULP73L-"@T*)&9E
M='EP92`]("=#3$DG.PT*:68@*"1P<F]G;F%M92`]/2`G9W!E87(G('Q\("1P
M<F]G;F%M92`]/2`G<&5A<BUG=&LG*2![#0H@("`@)&9E='EP92`]("='=&LG
M.PT*?2!E;'-E('L-"B`@("!F;W)E86-H("@D;W!T<R!A<R`D;W!T*2![#0H@
M("`@("`@(&EF("@D;W!T6S!=(#T]("=')RD@>PT*("`@("`@("`@("`@)&9E
M='EP92`]("='=&LG.PT*("`@("`@("!]#0H@("`@?0T*?0T*+R]#:&5C:R!I
M9B!'=&L@86YD(%!(4"`^/2`U+C$N,`T*:68@*"1F971Y<&4@/3T@)T=T:R<@
M)B8@=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,2XP)RP@)SX]
M)RDI('L-"B`@("`D9F5T>7!E(#T@)T=T:S(G.PT*?0T*#0HD<&5A<E]U<V5R
M7V-O;F9I9R`]("<G.PT*)'!E87)?<WES=&5M7V-O;F9I9R`]("<G.PT*)'-T
M;W)E7W5S97)?8V]N9FEG(#T@9F%L<V4[#0HD<W1O<F5?<WES=&5M7V-O;F9I
M9R`](&9A;'-E.PT*)'9E<F)O<V4@/2`Q.PT*#0IF;W)E86-H("@D;W!T<R!A
M<R`D;W!T*2![#0H@("`@<W=I=&-H("@D;W!T6S!=*2![#0H@("`@("`@(&-A
M<V4@)V,G.@T*("`@("`@("`@("`@)'!E87)?=7-E<E]C;VYF:6<@/2`D;W!T
M6S%=.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)T,G.@T*
M("`@("`@("`@("`@)'!E87)?<WES=&5M7V-O;F9I9R`]("1O<'1;,5T[#0H@
M("`@("`@("`@("!B<F5A:SL-"B`@("!]#0I]#0H-"E!%05)?0V]M;6%N9#HZ
M<V5T1G)O;G1E;F14>7!E*"1F971Y<&4I.PT*)'5I(#T@)E!%05)?0V]M;6%N
M9#HZ9V5T1G)O;G1E;F1/8FIE8W0H*3L-"B1C;VYF:6<@/2`F4$5!4E]#;VYF
M:6<Z.G-I;F=L971O;B@D<&5A<E]U<V5R7V-O;F9I9RP@)'!E87)?<WES=&5M
M7V-O;F9I9RD[#0H-"FEF("A014%2.CII<T5R<F]R*"1C;VYF:6<I*2![#0H@
M("`@)%]F:6QE(#T@)R<[#0H@("`@:68@*"1P96%R7W5S97)?8V]N9FEG("$]
M/2!F86QS92D@>PT*("`@("`@("1?9FEL92`N/2`D<&5A<E]U<V5R7V-O;F9I
M9SL-"B`@("!]#0H@("`@:68@*"1P96%R7W-Y<W1E;5]C;VYF:6<@(3T](&9A
M;'-E*2![#0H@("`@("`@)%]F:6QE("X]("<O)R`N("1P96%R7W-Y<W1E;5]C
M;VYF:6<[#0H@("`@?0T*("`@(&EF("@D7V9I;&4@/3T@)R\G*2![#0H@("`@
M("`@("1?9FEL92`]("=4:&4@9&5F875L="!C;VYF:6<@9FEL92<[#0H@("`@
M?0T*("`@("1C;VYF:6<M/F=E=$UE<W-A9V4H*3L-"B`@("`D=6DM/F]U='!U
M=$1A=&$H(D524D]2.B`D7V9I;&4@:7,@;F]T(&$@=F%L:60@8V]N9FEG(&9I
M;&4@;W(@:7,@8V]R<G5P=&5D+B(I.PT*("`@("\O(%=E('-T;W`L('=E(&AA
M=F4@;F\@:61E82!W:&5R92!W92!A<F4@.BD-"B`@("!E>&ET*"D[("`@(`T*
M?0T*#0HO+R!T:&ES(&ES('5S960@:6X@=&AE(&5R<F]R(&AA;F1L97(@=&\@
M<F5T<FEE=F4@82!R96QA=&EV92!P871H#0HD7U!%05)?4$A01$E2(#T@)&-O
M;F9I9RT^9V5T*"=P:'!?9&ER)RD[#0HD=6DM/G-E=$-O;F9I9R@D8V]N9FEG
M*3L-"E!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#
M2RP@87)R87DH)'5I+"`B9&ES<&QA>49A=&%L17)R;W(B*2D[#0II9B`H:6YI
M7V=E="@G<V%F95]M;V1E)RDI('L-"B`@("`D=6DM/F]U='!U=$1A=&$H)U=!
M4DY)3D<Z(')U;FYI;F<@:6X@<V%F92!M;V1E(')E<75I<F5S('1H870@86QL
M(&9I;&5S(&-R96%T960@)R`N#0H@("`@("`@("=B92!T:&4@<V%M92!U:60@
M87,@=&AE(&-U<G)E;G0@<V-R:7!T+B`@4$A0(')E<&]R=',@=&AI<R!S8W)I
M<'0@:7,@=6ED.B`G("X-"B`@("`@("`@0&=E=&UY=6ED*"D@+B`G+"!A;F0@
M8W5R<F5N="!U<V5R(&ES.B`G("X@0&=E=%]C=7)R96YT7W5S97(H*2D[#0I]
M#0H-"B1V97)B;W-E(#T@)&-O;F9I9RT^9V5T*")V97)B;W-E(BD[#0HD8VUD
M;W!T<R`](&%R<F%Y*"D[#0H-"FEF("@D<F%W*2![#0H@("`@:68@*"$D8V]N
M9FEG+3YI<T1E9FEN961,87EE<B@G=7-E<B<I("8F("$D8V]N9FEG+3YI<T1E
M9FEN961,87EE<B@G<WES=&5M)RDI('L-"B`@("`@("`@)&9O=6YD(#T@9F%L
M<V4[#0H@("`@("`@(&9O<F5A8V@@*"1O<'1S(&%S("1O<'0I('L-"B`@("`@
M("`@("`@(&EF("@D;W!T6S!=(#T]("=D)R!\?"`D;W!T6S!=(#T]("=$)RD@
M>PT*("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[("\O('1H92!U<V5R
M(&MN;W=S('=H870@=&AE>2!A<F4@9&]I;F<L(&%N9"!A<F4@<V5T=&EN9R!C
M;VYF:6<@=F%L=65S#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D9F]U;F0I('L-"B`@("`@("`@("`@("\O(&YO('!R:6]R(')U
M;G,L('1R>2!T;R!I;G-T86QL(%!%05(-"B`@("`@("`@("`@(&EF("AS=')P
M;W,H9&ER;F%M92A?7T9)3$5?7RDL("=S8W)I<'1S)RDI('L-"B`@("`@("`@
M("`@("`@("`D<&%C:V%G97AM;"`](&1I<FYA;64H9&ER;F%M92A?7T9)3$5?
M7RDI("X@1$E214-43U)97U-%4$%2051/4B`N("=P86-K86=E,BYX;6PG.PT*
M("`@("`@("`@("`@("`@("1P96%R8F%S92`](&1I<FYA;64H9&ER;F%M92A?
M7T9)3$5?7RDI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D<&%C:V%G97AM;"`](&1I<FYA;64H7U]&24Q%7U\I("X@1$E214-4
M3U)97U-%4$%2051/4B`N("=P86-K86=E,BYX;6PG.PT*("`@("`@("`@("`@
M("`@("1P96%R8F%S92`](&1I<FYA;64H7U]&24Q%7U\I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P86-K86=E>&UL
M*2D@>PT*("`@("`@("`@("`@("`@("1O<'1I;VYS6S%=(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=I;G-T86QL)RP-"B`@("`@("`@("`@("`@
M("`@("`@)'!A8VMA9V5X;6P-"B`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@("`@("1C;VYF:6<M/G-E="@G<&AP7V1I<B<L("1P96%R8F%S92`N
M($1)4D5#5$]265]315!!4D%43U(@+B`G<&AP)RD[#0H@("`@("`@("`@("`@
M("`@)&-O;F9I9RT^<V5T*"=D871A7V1I<B<L("1P96%R8F%S92`N($1)4D5#
M5$]265]315!!4D%43U(@+B`G9&%T82<I.PT*("`@("`@("`@("`@("`@("1C
M;VYF:6<M/G-E="@G9&]C7V1I<B<L("1P96%R8F%S92`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G9&]C<R<I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M
M/G-E="@G=&5S=%]D:7(G+"`D<&5A<F)A<V4@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)W1E<W1S)RD[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T
M*"=E>'1?9&ER)RP@)'!E87)B87-E("X@1$E214-43U)97U-%4$%2051/4B`N
M("=E>'1E;G-I;VYS)RD[#0H@("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T
M*"=B:6Y?9&ER)RP@)'!E87)B87-E*3L-"B`@("`@("`@("`@("`@("`D8V]N
M9FEG+3YM97)G94-O;F9I9T9I;&4H)'!E87)B87-E("X@)W!E87(N:6YI)RP@
M9F%L<V4I.PT*("`@("`@("`@("`@("`@("1C;VYF:6<M/G-T;W)E*"D[#0H@
M("`@("`@("`@("`@("`@)&-O;F9I9RT^<V5T*"=A=71O7V1I<V-O=F5R)RP@
M,2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0I]#0IF;W)E
M86-H("@D;W!T<R!A<R`D;W!T*2![#0H@("`@)'!A<F%M(#T@(65M<'1Y*"1O
M<'1;,5TI(#\@)&]P=%LQ72`Z('1R=64[#0H@("`@<W=I=&-H("@D;W!T6S!=
M*2![#0H@("`@("`@(&-A<V4@)V0G.@T*("`@("`@("`@("`@;&ES="@D:V5Y
M+"`D=F%L=64I(#T@97AP;&]D92@G/2<L("1P87)A;2D[#0H@("`@("`@("`@
M("`D8V]N9FEG+3YS970H)&ME>2P@)'9A;'5E+"`G=7-E<B<I.PT*("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)T0G.@T*("`@("`@("`@("`@
M;&ES="@D:V5Y+"`D=F%L=64I(#T@97AP;&]D92@G/2<L("1P87)A;2D[#0H@
M("`@("`@("`@("`D8V]N9FEG+3YS970H)&ME>2P@)'9A;'5E+"`G<WES=&5M
M)RD[#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G<R<Z#0H@
M("`@("`@("`@("`D<W1O<F5?=7-E<E]C;VYF:6<@/2!T<G5E.PT*("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@)U,G.@T*("`@("`@("`@("`@
M)'-T;W)E7W-Y<W1E;5]C;VYF:6<@/2!T<G5E.PT*("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@(&-A<V4@)W4G.@T*("`@("`@("`@("`@)&-O;F9I9RT^
M<F5M;W9E*"1P87)A;2P@)W5S97(G*3L-"B`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("!C87-E("=V)SH-"B`@("`@("`@("`@("1C;VYF:6<M/G-E="@G
M=F5R8F]S92<L("1C;VYF:6<M/F=E="@G=F5R8F]S92<I("L@,2D[#0H@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@8V%S92`G<2<Z#0H@("`@("`@("`@
M("`D8V]N9FEG+3YS970H)W9E<F)O<V4G+"`D8V]N9FEG+3YG970H)W9E<F)O
M<V4G*2`M(#$I.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@(&-A<V4@
M)U8G.@T*("`@("`@("`@("`@=7-A9V4H;G5L;"P@)W9E<G-I;VXG*3L-"B`@
M("`@("`@8V%S92`G8R<Z#0H@("`@("`@(&-A<V4@)T,G.@T*("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`O+R!A
M;&P@;F]N('!E87(@<&%R86US(&=O97,@=&\@=&AE(&-O;6UA;F0-"B`@("`@
M("`@("`@("1C;61O<'1S6R1O<'1;,%U=(#T@)'!A<F%M.PT*("`@("`@("`@
M("`@8G)E86L[#0H@("`@?0T*?0T*#0II9B`H)'-T;W)E7W-Y<W1E;5]C;VYF
M:6<I('L-"B`@("`D8V]N9FEG+3YS=&]R92@G<WES=&5M)RD[#0I]#0H-"FEF
M("@D<W1O<F5?=7-E<E]C;VYF:6<I('L-"B`@("`D8V]N9FEG+3YS=&]R92@G
M=7-E<B<I.PT*?0T*#0HD8V]M;6%N9"`]("AI<W-E="@D;W!T:6]N<ULQ75LP
M72DI(#\@)&]P=&EO;G-;,5U;,%T@.B!N=6QL.PT*#0II9B`H96UP='DH)&-O
M;6UA;F0I("8F("@D<W1O<F5?=7-E<E]C;VYF:6<@?'P@)'-T;W)E7W-Y<W1E
M;5]C;VYF:6<I*2![#0H@("`@97AI=#L-"GT-"@T*:68@*"1F971Y<&4@/3T@
M)T=T:R<@?'P@)&9E='EP92`]/2`G1W1K,B<I('L-"B`@("!I9B`H(21C;VYF
M:6<M/G9A;&ED0V]N9FEG=7)A=&EO;B@I*2![#0H@("`@("`@(%!%05(Z.G)A
M:7-E17)R;W(H)T-2251)0T%,($524D]2.B!N;R!E>&ES=&EN9R!V86QI9"!C
M;VYF:6=U<F%T:6]N(&9I;&5S(&9O=6YD(&EN(&9I;&5S("<@+@T*("`@("`@
M("`@("`@(B<D<&5A<E]U<V5R7V-O;F9I9R<@;W(@)R1P96%R7W-Y<W1E;5]C
M;VYF:6<G+"!P;&5A<V4@8V]P>2!A;B!E>&ES=&EN9R!C;VYF:6=U<F%T:6]N
M(B`N#0H@("`@("`@("`@("`G9FEL92!T;R!O;F4@;V8@=&AE<V4@;&]C871I
M;VYS+"!O<B!U<V4@=&AE("UC(&%N9"`M<R!O<'1I;VYS('1O(&-R96%T92!O
M;F4G*3L-"B`@("!]#0H@("`@1W1K.CIM86EN*"D[#0I](&5L<V4@9&\@>PT*
M("`@(&EF("@D8V]M;6%N9"`]/2`G:&5L<"<I('L-"B`@("`@("`@=7-A9V4H
M;G5L;"P@0"1O<'1I;VYS6S%=6S%=*3L-"B`@("!]#0H@("`@:68@*"$D8V]N
M9FEG+3YV86QI9$-O;F9I9W5R871I;VXH*2D@>PT*("`@("`@("!014%2.CIR
M86ES945R<F]R*"=#4DE424-!3"!%4E)/4CH@;F\@97AI<W1I;F<@=F%L:60@
M8V]N9FEG=7)A=&EO;B!F:6QE<R!F;W5N9"!I;B!F:6QE<R`G("X-"B`@("`@
M("`@("`@("(G)'!E87)?=7-E<E]C;VYF:6<G(&]R("<D<&5A<E]S>7-T96U?
M8V]N9FEG)RP@<&QE87-E(&-O<'D@86X@97AI<W1I;F<@8V]N9FEG=7)A=&EO
M;B(@+@T*("`@("`@("`@("`@)V9I;&4@=&\@;VYE(&]F('1H97-E(&QO8V%T
M:6]N<RP@;W(@=7-E('1H92`M8R!A;F0@+7,@;W!T:6]N<R!T;R!C<F5A=&4@
M;VYE)RD[#0H@("`@?0T*#0H@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("1C;60@/2!014%27T-O;6UA;F0Z
M.F9A8W1O<GDH)&-O;6UA;F0L("1C;VYF:6<I.PT*("`@(%!%05(Z.G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VUD*2D@
M>PT*("`@("`@("!U<V%G92AN=6QL+"!`)&]P=&EO;G-;,5U;,%TI.PT*("`@
M('T-"@T*("`@("1S:&]R=%]A<F=S(#T@)&QO;F=?87)G<R`](&YU;&P[#0H@
M("`@4$5!4E]#;VUM86YD.CIG971'971O<'1!<F=S*"1C;VUM86YD+"`D<VAO
M<G1?87)G<RP@)&QO;F=?87)G<RD[#0H@("`@:68@*&EN7V%R<F%Y*"=G971O
M<'0R)RP@9V5T7V-L87-S7VUE=&AO9',H)T-O;G-O;&5?1V5T;W!T)RDI*2![
M#0H@("`@("`@(&%R<F%Y7W-H:69T*"1O<'1I;VYS6S%=*3L-"B`@("`@("`@
M)'1M<"`]($-O;G-O;&5?1V5T;W!T.CIG971O<'0R*"1O<'1I;VYS6S%=+"`D
M<VAO<G1?87)G<RP@)&QO;F=?87)G<RD[#0H@("`@?2!E;'-E('L-"B`@("`@
M("`@)'1M<"`]($-O;G-O;&5?1V5T;W!T.CIG971O<'0H)&]P=&EO;G-;,5TL
M("1S:&]R=%]A<F=S+"`D;&]N9U]A<F=S*3L-"B`@("!]#0H@("`@:68@*%!%
M05(Z.FES17)R;W(H)'1M<"DI('L-"B`@("`@("`@8G)E86L[#0H@("`@?0T*
M("`@(&QI<W0H)'1M<&]P="P@)'!A<F%M<RD@/2`D=&UP.PT*("`@("1O<'1S
M(#T@87)R87DH*3L-"B`@("!F;W)E86-H("@D=&UP;W!T(&%S("1F;V\@/3X@
M)'1M<#(I('L-"B`@("`@("`@;&ES="@D;W!T+"`D=F%L=64I(#T@)'1M<#([
M#0H@("`@("`@(&EF("@D=F%L=64@/3T](&YU;&PI('L-"B`@("`@("`@("`@
M("1V86QU92`]('1R=64[("\O(&]P=&EO;G,@=VET:&]U="!A<F=S#0H@("`@
M("`@('T-"B`@("`@("`@:68@*'-T<FQE;B@D;W!T*2`]/2`Q*2![#0H@("`@
M("`@("`@("`D8VUD;W!T:6]N<R`]("1C;60M/F=E=$]P=&EO;G,H)&-O;6UA
M;F0I.PT*("`@("`@("`@("`@9F]R96%C:"`H)&-M9&]P=&EO;G,@87,@)&\@
M/3X@)&0I('L-"B`@("`@("`@("`@("`@("!I9B`H0"1D6R=S:&]R=&]P="==
M(#T]("1O<'0I('L-"B`@("`@("`@("`@("`@("`@("`@)&]P='-;)&]=(#T@
M)'9A;'5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AS=6)S='(H)&]P="P@
M,"P@,BD@/3T@)RTM)RD@>PT*("`@("`@("`@("`@("`@("1O<'1S6W-U8G-T
M<B@D;W!T+"`R*5T@/2`D=F%L=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H@("`@)&]K(#T@)&-M9"T^<G5N*"1C;VUM86YD+"`D;W!T
M<RP@)'!A<F%M<RD[#0H@("`@:68@*"1O:R`]/3T@9F%L<V4I('L-"B`@("`@
M("`@4$5!4CHZ<F%I<V5%<G)O<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N
M9"<B*3L-"B`@("!]#0H@("`@:68@*%!%05(Z.FES17)R;W(H)&]K*2D@>PT*
M("`@("`@("!014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,
M3$)!0TLL(&%R<F%Y*"1U:2P@(F1I<W!L87E&871A;$5R<F]R(BDI.PT*("`@
M("`@("!014%2.CIR86ES945R<F]R*"1O:RD[#0H@("`@?0T*?2!W:&EL92`H
M9F%L<V4I.PT*#0HO+R![>WL@=7-A9V4H*0T*#0IF=6YC=&EO;B!U<V%G92@D
M97)R;W(@/2!N=6QL+"`D:&5L<'-U8FIE8W0@/2!N=6QL*0T*>PT*("`@(&=L
M;V)A;"`D<')O9VYA;64L("1A;&Q?8V]M;6%N9',[#0H@("`@)'-T9&5R<B`]
M(&9O<&5N*"=P:'`Z+R]S=&1E<G(G+"`G=R<I.PT*("`@(&EF("A014%2.CII
M<T5R<F]R*"1E<G)O<BDI('L-"B`@("`@("`@9G!U=',H)'-T9&5R<BP@)&5R
M<F]R+3YG971-97-S86=E*"D@+B`B7&XB*3L-"B`@("!](&5L<V5I9B`H)&5R
M<F]R("$]/2!N=6QL*2![#0H@("`@("`@(&9P=71S*"1S=&1E<G(L("(D97)R
M;W)<;B(I.PT*("`@('T-"B`@("!I9B`H)&AE;'!S=6)J96-T("$](&YU;&PI
M('L-"B`@("`@("`@)'!U="`](&-M9$AE;'`H)&AE;'!S=6)J96-T*3L-"B`@
M("!](&5L<V4@>PT*("`@("`@("`D<'5T(#T-"B`@("`@("`@("`@(")#;VUM
M86YD<SI<;B([#0H@("`@("`@("1M87AL96X@/2!M87@H87)R87E?;6%P*")S
M=')L96XB+"`D86QL7V-O;6UA;F1S*2D[#0H@("`@("`@("1F;W)M871S='(@
M/2`B)2U[)&UA>&QE;GUS("`E<UQN(CL-"B`@("`@("`@:W-O<G0H)&%L;%]C
M;VUM86YD<RD[#0H@("`@("`@(&9O<F5A8V@@*"1A;&Q?8V]M;6%N9',@87,@
M)&-M9"`]/B`D8VQA<W,I('L-"B`@("`@("`@("`@("1P=70@+CT@<W!R:6YT
M9B@D9F]R;6%T<W1R+"`D8VUD+"!014%27T-O;6UA;F0Z.F=E=$1E<V-R:7!T
M:6]N*"1C;60I*3L-"B`@("`@("`@?0T*("`@("`@("`D<'5T("X]#0H@("`@
M("`@("`@("`B57-A9V4Z("1P<F]G;F%M92!;;W!T:6]N<UT@8V]M;6%N9"!;
M8V]M;6%N9"UO<'1I;VYS72`\<&%R86UE=&5R<SY<;B(N#0H@("`@("`@("`@
M("`B5'EP92!<(B1P<F]G;F%M92!H96QP(&]P=&EO;G-<(B!T;R!L:7-T(&%L
M;"!O<'1I;VYS+EQN(BX-"B`@("`@("`@("`@(")4>7!E(%PB)'!R;V=N86UE
M(&AE;'`@<VAO<G1C=71S7"(@=&\@;&ES="!A;&P@8V]M;6%N9"!S:&]R=&-U
M=',N7&XB+@T*("`@("`@("`@("`@(E1Y<&4@7"(D<')O9VYA;64@:&5L<"`\
M8V]M;6%N9#Y<(B!T;R!G970@=&AE(&AE;'`@9F]R('1H92!S<&5C:69I960@
M8V]M;6%N9"XB.PT*("`@('T-"B`@("!F<'5T<R@D<W1D97)R+"`B)'!U=%QN
M(BD[#0H@("`@9F-L;W-E*"1S=&1E<G(I.PT*("`@(&5X:70[#0I]#0H-"F9U
M;F-T:6]N(&-M9$AE;'`H)&-O;6UA;F0I#0I[#0H@("`@9VQO8F%L("1P<F]G
M;F%M92P@)&%L;%]C;VUM86YD<RP@)&-O;F9I9SL-"B`@("!I9B`H)&-O;6UA
M;F0@/3T@(F]P=&EO;G,B*2![#0H@("`@("`@(')E='5R;@T*("`@("`@("`B
M3W!T:6]N<SI<;B(N#0H@("`@("`@("(@("`@("UV("`@("`@("`@:6YC<F5A
M<V4@=F5R8F]S:71Y(&QE=F5L("AD969A=6QT(#$I7&XB+@T*("`@("`@("`B
M("`@("`M<2`@("`@("`@(&)E('%U:65T+"!D96-R96%S92!V97)B;W-I='D@
M;&5V96Q<;B(N#0H@("`@("`@("(@("`@("UC(&9I;&4@("`@9FEN9"!U<V5R
M(&-O;F9I9W5R871I;VX@:6X@8&9I;&4G7&XB+@T*("`@("`@("`B("`@("`M
M0R!F:6QE("`@(&9I;F0@<WES=&5M(&-O;F9I9W5R871I;VX@:6X@8&9I;&4G
M7&XB+@T*("`@("`@("`B("`@("`M9"!F;V\]8F%R('-E="!U<V5R(&-O;F9I
M9R!V87)I86)L92!@9F]O)R!T;R!@8F%R)UQN(BX-"B`@("`@("`@(B`@("`@
M+40@9F]O/6)A<B!S970@<WES=&5M(&-O;F9I9R!V87)I86)L92!@9F]O)R!T
M;R!@8F%R)UQN(BX-"B`@("`@("`@(B`@("`@+4<@("`@("`@("!S=&%R="!I
M;B!G<F%P:&EC86P@*$=T:RD@;6]D95QN(BX-"B`@("`@("`@(B`@("`@+7,@
M("`@("`@("!S=&]R92!U<V5R(&-O;F9I9W5R871I;VY<;B(N#0H@("`@("`@
M("(@("`@("U3("`@("`@("`@<W1O<F4@<WES=&5M(&-O;F9I9W5R871I;VY<
M;B(N#0H@("`@("`@("(@("`@("UU(&9O;R`@("`@=6YS970@8&9O;R<@:6X@
M=&AE('5S97(@8V]N9FEG=7)A=&EO;EQN(BX-"B`@("`@("`@(B`@("`@+6@L
M("T_("`@("!D:7-P;&%Y(&AE;'`O=7-A9V4@*'1H:7,@;65S<V%G92E<;B(N
M#0H@("`@("`@("(@("`@("U6("`@("`@("`@=F5R<VEO;B!I;F9O<FUA=&EO
M;EQN(CL-"B`@("!](&5L<V5I9B`H)&-O;6UA;F0@/3T@(G-H;W)T8W5T<R(I
M('L-"B`@("`@("`@)'-C(#T@4$5!4E]#;VUM86YD.CIG9713:&]R=&-U=',H
M*3L-"B`@("`@("`@)')E="`](")3:&]R=&-U=',Z7&XB.PT*("`@("`@("!F
M;W)E86-H("@D<V,@87,@)',@/3X@)&,I('L-"B`@("`@("`@("`@("1R970@
M+CT@<W!R:6YT9B@B("`@("`E+3AS("5S7&XB+"`D<RP@)&,I.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*#0H@("`@?2!E;'-E:68@*"1C
M;VUM86YD(#T](")V97)S:6]N(BD@>PT*("`@("`@("!R971U<FX@(E!%05(@
M5F5R<VEO;CH@(BXD1TQ/0D%,4ULG<&5A<E]P86-K86=E7W9E<G-I;VXG72X-
M"B`@("`@("`@("`@("`@(")<;E!(4"!697)S:6]N.B`B+G!H<'9E<G-I;VXH
M*2X-"B`@("`@("`@("`@("`@(")<;EIE;F0@16YG:6YE(%9E<G-I;VXZ("(N
M>F5N9%]V97)S:6]N*"DN#0H@("`@("`@("`@("`@("`B7&Y2=6YN:6YG(&]N
M.B`B+G!H<%]U;F%M92@I.PT*#0H@("`@?2!E;'-E:68@*"1H96QP(#T@4$5!
M4E]#;VUM86YD.CIG971(96QP*"1C;VUM86YD*2D@>PT*("`@("`@("!I9B`H
M:7-?<W1R:6YG*"1H96QP*2D@>PT*("`@("`@("`@("`@<F5T=7)N("(D<')O
M9VYA;64@)&-O;6UA;F0@6V]P=&EO;G-=("1H96QP7&XB.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D:&5L<%LQ72`]/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@<F5T=7)N("(D<')O9VYA;64@)&-O;6UA;F0@)&AE;'!;,%TB.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("(D<')O9VYA;64@
M)&-O;6UA;F0@6V]P=&EO;G-=("1H96QP6S!=7&XD:&5L<%LQ72([#0H@("`@
M("`@('T-"B`@("!]#0H@("`@<F5T=7)N(")#;VUM86YD("<D8V]M;6%N9"<@
M:7,@;F]T('9A;&ED+"!T<GD@)W!E87(@:&5L<"<B.PT*?0T*#0HO+R!]?7T-
M"@T*9G5N8W1I;VX@97)R;W)?:&%N9&QE<B@D97)R;F\L("1E<G)M<V<L("1F
M:6QE+"`D;&EN92P@)'9A<G,I('L-"B`@("!I9B`H*&1E9FEN960H)T5?4U12
M24-4)RD@)B8@)&5R<FYO("8@15]35%))0U0I('Q\("%E<G)O<E]R97!O<G1I
M;F<H*2D@>PT*("`@("`@("!I9B`H9&5F:6YE9"@G15]35%))0U0G*2`F)B`D
M97)R;F\@)B!%7U-44DE#5"D@>PT*("`@("`@("`@("`@<F5T=7)N.R`O+R!%
M7U-44DE#5`T*("`@("`@("!]#0H@("`@("`@(&EF("@D1TQ/0D%,4ULG8V]N
M9FEG)UTM/F=E="@G=F5R8F]S92<I(#P@-"D@>PT*("`@("`@("`@("`@<F5T
M=7)N.R`O+R!`<VEL96YC960@97)R;W(L('-H;W<@86QL(&EF(&1E8G5G(&ES
M(&AI9V@@96YO=6=H#0H@("`@("`@('T-"B`@("!]#0H@("`@)&5R<F]R='EP
M92`](&%R<F%Y("@-"B`@("`@("`@15]%4E)/4B`@(#T^("`B17)R;W(B+`T*
M("`@("`@("!%7U=!4DY)3D<@("`]/B`@(E=A<FYI;F<B+`T*("`@("`@("!%
M7U!!4E-%("`@/3X@(")087)S:6YG($5R<F]R(BP-"B`@("`@("`@15].3U1)
M0T4@("`]/B`@(DYO=&EC92(L#0H@("`@("`@($5?0T]215]%4E)/4B`@/3X@
M(")#;W)E($5R<F]R(BP-"B`@("`@("`@15]#3U)%7U=!4DY)3D<@(#T^("`B
M0V]R92!787)N:6YG(BP-"B`@("`@("`@15]#3TU024Q%7T524D]2("`]/B`@
M(D-O;7!I;&4@17)R;W(B+`T*("`@("`@("!%7T-/35!)3$5?5T%23DE.1R`]
M/B`@(D-O;7!I;&4@5V%R;FEN9R(L#0H@("`@("`@($5?55-%4E]%4E)/4B`]
M/B`@(E5S97(@17)R;W(B+`T*("`@("`@("!%7U5315)?5T%23DE.1R`]/B`@
M(E5S97(@5V%R;FEN9R(L#0H@("`@("`@($5?55-%4E].3U1)0T4@/3X@(")5
M<V5R($YO=&EC92(-"B`@("`I.PT*("`@("1P<F5F:7@@/2`D97)R;W)T>7!E
M6R1E<G)N;UT[#0H@("`@9VQO8F%L("1?4$5!4E]02%!$25([#0H@("`@:68@
M*'-T<FES='(H)&9I;&4L("1?4$5!4E]02%!$25(I*2![#0H@("`@("`@("1F
M:6QE(#T@<W5B<W1R*"1F:6QE+"!S=')L96XH)%]014%27U!(4$1)4BD@*R`Q
M*3L-"B`@("!](&5L<V4@>PT*("`@("`@("`D9FEL92`](&)A<V5N86UE*"1F
M:6QE*3L-"B`@("!]#0H@("`@<')I;G0@(EQN)'!R969I>#H@)&5R<FUS9R!I
M;B`D9FEL92!O;B!L:6YE("1L:6YE7&XB.PT*?0T*#0H-"B\J#0H@*B!,;V-A
M;"!V87)I86)L97,Z#0H@*B!T86(M=VED=&@Z(#0-"B`J(&,M8F%S:6,M;V9F
M<V5T.B`T#0H@*B!I;F1E;G0M=&%B<RUM;V1E.B!N:6P-"B`J(&UO9&4Z('!H
M<`T*("H@16YD.@T*("HO#0HO+R!V:6TV,#`Z<WEN/7!H<`T*#0H_/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W!E8VQC;60N<&AP````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,U,C$@,3`U,34T,S0Q,S4@,#(P-C`T`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%!(4"!6
M97)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M#0HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P-"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P-"B\O('P@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<G,Z(%-T:6<@0F%K:V5N(#QS<V)`
M<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O#0HO+R`D260Z('!E8VQC;60N<&AP+'8@,2XQ(#(P,#4O,#(O
M,C$@,#4Z,S`Z-38@8V5L;&]G($5X<"`D#0H-"B\J*@T*("H@0&YO9&5P($=T
M:PT*("HO#0II9B`H)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R)R`A
M/2`G0"<N)VEN8VQU9&5?<&%T:"<N)T`G*2![#0H@("`@:6YI7W-E="@G:6YC
M;'5D95]P871H)RP@)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R)RD[
M#0H@("`@)')A=R`](&9A;'-E.PT*?2!E;'-E('L-"B`@("`O+R!T:&ES(&ES
M(&$@<F%W+"!U;FEN<W1A;&QE9"!P96%R+"!E:71H97(@82!C=G,@8VAE8VMO
M=70L(&]R('!H<"!D:7-T<F\-"B`@("`D<F%W(#T@=')U93L-"GT-"F1E9FEN
M92@G4$5!4E]254Y465!%)RP@)W!E8VPG*3L-"G)E<75I<F5?;VYC92`G<&5A
M<F-M9"YP:'`G.PT*+RH-"B`J($QO8V%L('9A<FEA8FQE<SH-"B`J('1A8BUW
M:61T:#H@-`T*("H@8RUB87-I8RUO9F9S970Z(#0-"B`J(&EN9&5N="UT86)S
M+6UO9&4Z(&YI;`T*("H@;6]D93H@<&AP#0H@*B!%;F0Z#0H@*B\-"B\O('9I
M;38P,#IS>6X]<&AP#0H-"C\^#0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],
M;V<N<&AP````````````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#8P-#8S(#$P-3$U-#,T,3,U(#`Q-S<R-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO*BH*("H@
M)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+G!H<"QV(#$N-3D@
M,C`P-B\P-"\R-2`P-CHP,CHR,R!J;VX@17AP("0*("H@)$AO<F1E.B!H;W)D
M92]L:6(O3&]G+G!H<"QV(#$N,34@,C`P,"\P-B\R.2`R,SHS.3HT-2!J;VX@
M17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C4Y("0*("H@0'!A
M8VMA9V4@3&]G"B`J+PH*9&5F:6YE*"=014%27TQ/1U]%34521R<L("`@(#`I
M.R`@("`@+RHJ(%-Y<W1E;2!I<R!U;G5S86)L92`J+PID969I;F4H)U!%05)?
M3$]'7T%,15)4)RP@("`@,2D[("`@("`O*BH@26UM961I871E(&%C=&EO;B!R
M97%U:7)E9"`J+PID969I;F4H)U!%05)?3$]'7T-2250G+"`@("`@,BD[("`@
M("`O*BH@0W)I=&EC86P@8V]N9&ET:6]N<R`J+PID969I;F4H)U!%05)?3$]'
M7T524B<L("`@("`@,RD[("`@("`O*BH@17)R;W(@8V]N9&ET:6]N<R`J+PID
M969I;F4H)U!%05)?3$]'7U=!4DY)3D<G+"`@-"D[("`@("`O*BH@5V%R;FEN
M9R!C;VYD:71I;VYS("HO"F1E9FEN92@G4$5!4E],3T=?3D]424-%)RP@("`U
M*3L@("`@("\J*B!.;W)M86P@8G5T('-I9VYI9FEC86YT("HO"F1E9FEN92@G
M4$5!4E],3T=?24Y&3R<L("`@("`V*3L@("`@("\J*B!);F9O<FUA=&EO;F%L
M("HO"F1E9FEN92@G4$5!4E],3T=?1$5"54<G+"`@("`W*3L@("`@("\J*B!$
M96)U9RUL979E;"!M97-S86=E<R`J+PH*9&5F:6YE*"=014%27TQ/1U]!3$PG
M+"`@("`@(&)I;F1E8R@G,3$Q,3$Q,3$G*2D[("`O*BH@06QL(&UE<W-A9V5S
M("HO"F1E9FEN92@G4$5!4E],3T=?3D].12<L("`@("!B:6YD96,H)S`P,#`P
M,#`P)RDI.R`@+RHJ($YO(&UE<W-A9V4@*B\*"B\J($QO9R!T>7!E<R!F;W(@
M4$A0)W,@;F%T:79E(&5R<F]R7VQO9R@I(&9U;F-T:6]N+B`J+PID969I;F4H
M)U!%05)?3$]'7U194$5?4UE35$5-)RP@(#`I.R`O*BH@57-E(%!(4"=S('-Y
M<W1E;2!L;V=G97(@*B\*9&5F:6YE*"=014%27TQ/1U]465!%7TU!24PG+"`@
M("`Q*3L@+RHJ(%5S92!02%`G<R!M86EL*"D@9G5N8W1I;VX@*B\*9&5F:6YE
M*"=014%27TQ/1U]465!%7T1%0E5')RP@("`R*3L@+RHJ(%5S92!02%`G<R!D
M96)U9V=I;F<@8V]N;F5C=&EO;B`J+PID969I;F4H)U!%05)?3$]'7U194$5?
M1DE,12<L("`@(#,I.R`O*BH@07!P96YD('1O(&$@9FEL92`J+PH*+RHJ"B`J
M(%1H92!,;V<Z.B!C;&%S<R!I;7!L96UE;G1S(&)O=&@@86X@86)S=')A8W1I
M;VX@9F]R('9A<FEO=7,@;&]G9VEN9PH@*B!M96-H86YI<VUS(&%N9"!T:&4@
M4W5B:F5C="!E;F0@;V8@82!3=6)J96-T+4]B<V5R=F5R('!A='1E<FXN"B`J
M"B`J($!A=71H;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G
M/@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X*("H@0'-I
M;F-E("`@2&]R9&4@,2XS"B`J($!P86-K86=E($QO9PH@*B\*8VQA<W,@3&]G
M"GL*("`@("\J*@H@("`@("H@26YD:6-A=&5S('=H971H97(@;W(@;F]T('1H
M92!L;V<@8V%N(&)E96X@;W!E;F5D("\@8V]N;F5C=&5D+@H@("`@("H*("`@
M("`J($!V87(@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7V]P96YE9"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@
M26YS=&%N8V4M<W!E8VEF:6,@=6YI<75E(&ED96YT:69I8V%T:6]N(&YU;6)E
M<BX*("`@("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]I9"`](#`["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;&%B96P@=&AA="!U;FEQ=65L>2!I9&5N=&EF:65S('1H:7,@
M<V5T(&]F(&QO9R!M97-S86=E<RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VED
M96YT(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&5F875L="!P<FEO<FET
M>2!T;R!U<V4@=VAE;B!L;V=G:6YG(&%N(&5V96YT+@H@("`@("H*("`@("`J
M($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7W!R:6]R:71Y(#T@4$5!4E],3T=?24Y&3SL*"B`@("`O*BH*
M("`@("`J(%1H92!B:71M87-K(&]F(&%L;&]W960@;&]G(&QE=F5L<RX*("`@
M("`J"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]M87-K(#T@4$5!4E],3T=?04Q,.PH*("`@
M("\J*@H@("`@("H@2&]L9',@86QL($QO9U]O8G-E<G9E<B!O8FIE8W1S('1H
M870@=VES:"!T;R!B92!N;W1I9FEE9"!O9B!N97<@;65S<V%G97,N"B`@("`@
M*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7VQI<W1E;F5R<R`](&%R<F%Y*"D["@H@("`@+RHJ
M"B`@("`@*B!-87!S(&-A;F]N:6-A;"!F;W)M870@:V5Y<R!T;R!P;W-I=&EO
M;B!A<F=U;65N=',@9F]R('5S92!I;B!B=6EL9&EN9PH@("`@("H@(FQI;F4@
M9F]R;6%T(B!S=')I;F=S+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F;W)M871-
M87`@/2!A<G)A>2@G)7MT:6UE<W1A;7!])R`@/3X@)R4Q)',G+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)R5[:61E;G1])R`@("`@(#T^("<E,B1S
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E>W!R:6]R:71Y?2<@
M("`]/B`G)3,D<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)7MM
M97-S86=E?2<@("`@/3X@)R4T)',G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R5[9FEL97TG("`@("`@(#T^("<E-21S)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<E>VQI;F5])R`@("`@("`]/B`G)38D<R<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G)7MF=6YC=&EO;GTG("`@/3X@
M)R4W)',G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R5<>R<@("`@
M("`@("`@(#T^("<E)7LG*3L*"@H@("`@+RHJ"B`@("`@*B!!='1E;7!T<R!T
M;R!R971U<FX@82!C;VYC<F5T92!,;V<@:6YS=&%N8V4@;V8@='EP92`D:&%N
M9&QE<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1H86YD;&5R("`@
M5&AE('1Y<&4@;V8@8V]N8W)E=&4@3&]G('-U8F-L87-S('1O(')E='5R;BX*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!!='1E;7!T('1O(&1Y
M;F%M:6-A;&QY(&EN8VQU9&4@=&AE(&-O9&4@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@=&AI<R!S=6)C;&%S<RX@0W5R<F5N=&QY+"!V
M86QI9"!V86QU97,@87)E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-O;G-O;&4G+"`G<WES;&]G)RP@)W-Q;"<L("=F:6QE)RP@86YD("=M
M8V%L)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@
M5&AE(&YA;64@;V8@=&AE(&%C='5A;&QY(&QO9R!F:6QE+"!T86)L92P@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!O=&AE<B!S<&5C:69I
M8R!S=&]R92!T;R!U<V4N($1E9F%U;'1S('1O(&%N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@96UP='D@<W1R:6YG+"!W:71H('=H:6-H('1H
M92!S=6)C;&%S<R!W:6QL"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@871T96UP="!T;R!D;R!S;VUE=&AI;F<@:6YT96QL:6=E;G0N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@(%1H92!I9&5N=&ET
M>2!R97!O<G1E9"!T;R!T:&4@;&]G('-Y<W1E;2X*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@("1C;VYF("`@("`@02!H87-H(&-O;G1A:6YI;F<@86YY
M(&%D9&ET:6]N86P@8V]N9FEG=7)A=&EO;@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EN9F]R;6%T:6]N('1H870@82!S=6)C;&%S<R!M:6=H
M="!N965D+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&QE=F5L("`@("`@
M("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN8VQU9&EN9R!T:&ES(&QE=F5L
M+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T($QO9R`@("`@("!4:&4@
M;F5W;'D@8W)E871E9"!C;VYC<F5T92!,;V<@:6YS=&%N8V4L(&]R"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"!O;B!A;B!E<G)O<BX*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@3&]G(#$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B`F9F%C=&]R>2@D:&%N9&QE<BP@)&YA;64@
M/2`G)RP@)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@
M("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@
M("`@("`@("1H86YD;&5R(#T@<W1R=&]L;W=E<B@D:&%N9&QE<BD["B`@("`@
M("`@)&-L87-S(#T@)TQO9U\G("X@)&AA;F1L97(["B`@("`@("`@)&-L87-S
M9FEL92`]("=,;V<O)R`N("1H86YD;&5R("X@)RYP:'`G.PH*("`@("`@("`O
M*@H@("`@("`@("`J($%T=&5M<'0@=&\@:6YC;'5D92!O=7(@=F5R<VEO;B!O
M9B!T:&4@;F%M960@8VQA<W,L(&)U="!D;VXG="!T<F5A=`H@("`@("`@("`J
M(&$@9F%I;'5R92!A<R!F871A;"X@(%1H92!C86QL97(@;6%Y(&AA=F4@86QR
M96%D>2!I;F-L=61E9"!T:&5I<B!O=VX*("`@("`@("`@*B!V97)S:6]N(&]F
M('1H92!N86UE9"!C;&%S<RX*("`@("`@("`@*B\*("`@("`@("!I9B`H(6-L
M87-S7V5X:7-T<R@D8VQA<W,I*2!["B`@("`@("`@("`@(&EN8VQU9&5?;VYC
M92`D8VQA<W-F:6QE.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&-L
M87-S(&5X:7-T<RP@<F5T=7)N(&$@;F5W(&EN<W1A;F-E(&]F(&ET+B`J+PH@
M("`@("`@(&EF("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@
M("`D;V)J(#T@)FYE=R`D8VQA<W,H)&YA;64L("1I9&5N="P@)&-O;F8L("1L
M979E;"D["B`@("`@("`@("`@(')E='5R;B`D;V)J.PH@("`@("`@('T*"B`@
M("`@("`@)&YU;&P@/2!N=6QL.PH@("`@("`@(')E='5R;B`D;G5L;#L*("`@
M('T*"B`@("`O*BH*("`@("`J($%T=&5M<'1S('1O(')E='5R;B!A(')E9F5R
M96YC92!T;R!A(&-O;F-R971E($QO9R!I;G-T86YC92!O9B!T>7!E"B`@("`@
M*B`D:&%N9&QE<BP@;VYL>2!C<F5A=&EN9R!A(&YE=R!I;G-T86YC92!I9B!N
M;R!L;V<@:6YS=&%N8V4@=VET:"!T:&4@<V%M90H@("`@("H@<&%R86UE=&5R
M<R!C=7)R96YT;'D@97AI<W1S+@H@("`@("H*("`@("`J(%EO=2!S:&]U;&0@
M=7-E('1H:7,@:68@=&AE<F4@87)E(&UU;'1I<&QE('!L86-E<R!Y;W4@;6EG
M:'0@8W)E871E(&$*("`@("`J(&QO9V=E<BP@>6]U(&1O;B=T('=A;G0@=&\@
M8W)E871E(&UU;'1I<&QE(&QO9V=E<G,L(&%N9"!Y;W4@9&]N)W0@=V%N="!T
M;PH@("`@("H@8VAE8VL@9F]R('1H92!E>&ES=&%N8V4@;V8@;VYE(&5A8V@@
M=&EM92X@5&AE('-I;F=L971O;B!P871T97)N(&1O97,@86QL"B`@("`@*B!T
M:&4@8VAE8VMI;F<@=V]R:R!F;W(@>6]U+@H@("`@("H*("`@("`J(#QB/EEO
M=2!-55-4(&-A;&P@=&AI<R!M971H;V0@=VET:"!T:&4@)'9A<B`]("9,;V<Z
M.G-I;F=L971O;B@I('-Y;G1A>"X*("`@("`J(%=I=&AO=70@=&AE(&%M<&5R
M<V%N9"`H)BD@:6X@9G)O;G0@;V8@=&AE(&UE=&AO9"!N86UE+"!Y;W4@=VEL
M;"!N;W0@9V5T"B`@("`@*B!A(')E9F5R96YC92P@>6]U('=I;&P@9V5T(&$@
M8V]P>2X\+V(^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:&%N9&QE
M<B`@(%1H92!T>7!E(&]F(&-O;F-R971E($QO9R!S=6)C;&%S<R!T;R!R971U
M<FXN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@071T96UP="!T
M;R!D>6YA;6EC86QL>2!I;F-L=61E('1H92!C;V1E(&9O<@H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H:7,@<W5B8VQA<W,N($-U<G)E;G1L
M>2P@=F%L:60@=F%L=65S(&%R90H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("=C;VYS;VQE)RP@)W-Y<VQO9R<L("=S<6PG+"`G9FEL92<L(&%N
M9"`G;6-A;"<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M("`@(%1H92!N86UE(&]F('1H92!A8W1U86QL>2!L;V<@9FEL92P@=&%B;&4L
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@;W1H97(@<W!E
M8VEF:6,@<W1O<F4@=&\@=7-E+B`@1&5F875L=',@=&\@86X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("!E;7!T>2!S=')I;F<L('=I=&@@=VAI
M8V@@=&AE('-U8F-L87-S('=I;&P*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("!A='1E;7!T('1O(&1O('-O;65T:&EN9R!I;G1E;&QI9V5N="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("`@5&AE(&ED
M96YT:71Y(')E<&]R=&5D('1O('1H92!L;V<@<WES=&5M+@H@("`@("H*("`@
M("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@("!!(&AA<V@@8V]N=&%I;FEN
M9R!A;GD@861D:71I;VYA;"!C;VYF:6=U<F%T:6]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@:6YF;W)M871I;VX@=&AA="!A('-U8F-L87-S
M(&UI9VAT(&YE960N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;&5V96P@
M("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@
M;&5V96PN"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@3&]G("`@("`@
M(%1H92!N97=L>2!C<F5A=&5D(&-O;F-R971E($QO9R!I;G-T86YC92P@;W(*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL(&]N(&%N(&5R
M<F]R+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92!,;V<@
M,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N("9S:6YG;&5T;VXH)&AA;F1L97(L
M("1N86UE(#T@)R<L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'
M*0H@("`@>PH@("`@("`@('-T871I8R`D:6YS=&%N8V5S.PH@("`@("`@(&EF
M("@A:7-S970H)&EN<W1A;F-E<RDI("1I;G-T86YC97,@/2!A<G)A>2@I.PH*
M("`@("`@("`D<VEG;F%T=7)E(#T@<V5R:6%L:7IE*&%R<F%Y*"1H86YD;&5R
M+"`D;F%M92P@)&ED96YT+"`D8V]N9BP@)&QE=F5L*2D["B`@("`@("`@:68@
M*"%I<W-E="@D:6YS=&%N8V5S6R1S:6=N871U<F5=*2D@>PH@("`@("`@("`@
M("`D:6YS=&%N8V5S6R1S:6=N871U<F5=(#T@)DQO9SHZ9F%C=&]R>2@D:&%N
M9&QE<BP@)&YA;64L("1I9&5N="P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F8L("1L979E;"D["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&EN<W1A;F-E<ULD<VEG;F%T=7)E
M73L*("`@('T*"B`@("`O*BH*("`@("`J($%B<W1R86-T(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!O<&5N*"D@;65T:&]D+@H@("`@("H@0'-I;F-E($QO9R`Q
M+C`*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@06)S=')A8W0@
M:6UP;&5M96YT871I;VX@;V8@=&AE(&-L;W-E*"D@;65T:&]D+@H@("`@("H@
M0'-I;F-E($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J($%B<W1R86-T(&EM<&QE;65N=&%T:6]N(&]F('1H92!F;'5S:"@I(&UE
M=&AO9"X*("`@("`J($!S:6YC92!,;V<@,2XX+C(*("`@("`J+PH@("`@9G5N
M8W1I;VX@9FQU<V@H*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O*BH*("`@("`J($%B<W1R86-T(&EM<&QE;65N=&%T:6]N(&]F
M('1H92!L;V<H*2!M971H;V0N"B`@("`@*B!`<VEN8V4@3&]G(#$N,`H@("`@
M("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L("1P<FEO<FET>2`](&YU
M;&PI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@02!C;VYV96YI96YC92!F=6YC=&EO;B!F;W(@;&]G9VEN9R!A
M(&5M97)G96YC>2!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A
M9V4@870@=&AE(%!%05)?3$]'7T5-15)'(&QO9R!L979E;"X*("`@("`J"B`@
M("`@*B!`<&%R86T@("!M:7AE9"`@("1M97-S86=E("`@(%-T<FEN9R!O<B!O
M8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T;R!L;V<N"B`@("`@*@H@("`@("H@0')E
M='5R;B`@8F]O;&5A;B!4<G5E(&EF('1H92!M97-S86=E('=A<R!S=6-C97-S
M9G5L;'D@;&]G9V5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'-I;F-E("`@3&]G(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&5M97)G*"1M97-S86=E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M;&]G*"1M97-S86=E+"!014%27TQ/1U]%34521RD["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&%N
M(&%L97)T(&5V96YT+B`@270@=VEL;"!L;V<@80H@("`@("H@;65S<V%G92!A
M="!T:&4@4$5!4E],3T=?04Q%4E0@;&]G(&QE=F5L+@H@("`@("H*("`@("`J
M($!P87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M("!B;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL
M>2!L;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@86QE
M<G0H)&UE<W-A9V4I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YL;V<H
M)&UE<W-A9V4L(%!%05)?3$]'7T%,15)4*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($$@8V]N=F5N:65N8V4@9G5N8W1I;VX@9F]R(&QO9V=I;F<@82!C<FET
M:6-A;"!E=F5N="X@($ET('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@870@
M=&AE(%!%05)?3$]'7T-2250@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P
M87)A;2`@(&UI>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C
M;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B
M;V]L96%N(%1R=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L
M;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@8W)I="@D
M;65S<V%G92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FQO9R@D;65S
M<V%G92P@4$5!4E],3T=?0U))5"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M(&-O;G9E;FEE;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&$@97)R;W(@979E
M;G0N("!)="!W:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%2
M7TQ/1U]%4E(@;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2`@(&UI
M>&5D("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG
M('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('1O(&QO9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B;V]L96%N(%1R
M=64@:68@=&AE(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L;V=G960N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,
M;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@97)R*"1M97-S86=E*0H@
M("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;&]G*"1M97-S86=E+"!014%2
M7TQ/1U]%4E(I.PH@("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI96YC
M92!F=6YC=&EO;B!F;W(@;&]G9VEN9R!A('=A<FYI;F<@979E;G0N("!)="!W
M:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/1U]705).
M24Y'(&QO9R!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@("!M:7AE9"`@
M("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@
M;65S<V%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M;R!L;V<N"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B!4<G5E(&EF
M('1H92!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N
M-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N('=A<FYI;F<H)&UE<W-A9V4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?
M3$]'7U=!4DY)3D<I.PH@("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI
M96YC92!F=6YC=&EO;B!F;W(@;&]G9VEN9R!A(&YO=&EC92!E=F5N="X@($ET
M('=I;&P@;&]G(&$*("`@("`J(&UE<W-A9V4@870@=&AE(%!%05)?3$]'7TY/
M5$E#12!L;V<@;&5V96PN"B`@("`@*@H@("`@("H@0'!A<F%M("`@;6EX960@
M("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE
M(&UE<W-A9V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&\@;&]G+@H@("`@("H*("`@("`J($!R971U<FX@(&)O;VQE86X@5')U92!I
M9B!T:&4@;65S<V%G92!W87,@<W5C8V5S<V9U;&QY(&QO9V=E9"X*("`@("`J
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q
M+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!N;W1I8V4H)&UE<W-A9V4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?
M3$]'7TY/5$E#12D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!(&-O;G9E;FEE
M;F-E(&9U;F-T:6]N(&9O<B!L;V=G:6YG(&$@:6YF;W)M871I;VX@979E;G0N
M("!)="!W:6QL(&QO9R!A"B`@("`@*B!M97-S86=E(&%T('1H92!014%27TQ/
M1U])3D9/(&QO9R!L979E;"X*("`@("`J"B`@("`@*B!`<&%R86T@("!M:7AE
M9"`@("1M97-S86=E("`@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T
M:&4@;65S<V%G90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!T;R!L;V<N"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O;&5A;B!4<G5E
M(&EF('1H92!M97-S86=E('=A<R!S=6-C97-S9G5L;'D@;&]G9V5D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G
M(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&EN9F\H)&UE<W-A9V4I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?
M3$]'7TE.1D\I.PH@("`@?0H*("`@("\J*@H@("`@("H@02!C;VYV96YI96YC
M92!F=6YC=&EO;B!F;W(@;&]G9VEN9R!A(&1E8G5G(&5V96YT+B`@270@=VEL
M;"!L;V<@80H@("`@("H@;65S<V%G92!A="!T:&4@4$5!4E],3T=?1$5"54<@
M;&]G(&QE=F5L+@H@("`@("H*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&UE
M<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S
M86=E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&QO
M9RX*("`@("`J"B`@("`@*B!`<F5T=7)N("!B;V]L96%N(%1R=64@:68@=&AE
M(&UE<W-A9V4@=V%S('-U8V-E<W-F=6QL>2!L;V=G960N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&5B=6<H)&UE<W-A9V4I"B`@("!["B`@
M("`@("`@<F5T=7)N("1T:&ES+3YL;V<H)&UE<W-A9V4L(%!%05)?3$]'7T1%
M0E5'*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-T<FEN
M9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92!D871A+@H@("`@("H*
M("`@("`J($EF("1M97-S86=E(&ES(&%N(&]B:F5C="P@7V5X=')A8W1-97-S
M86=E*"D@=VEL;"!A='1E;7!T('1O(&5X=')A8W0*("`@("`J('1H92!M97-S
M86=E('1E>'0@=7-I;F<@82!K;F]W;B!M971H;V0@*'-U8V@@87,@82!014%2
M7T5R<F]R(&]B:F5C="=S"B`@("`@*B!G971-97-S86=E*"D@;65T:&]D*2X@
M($EF(&$@:VYO=VX@;65T:&]D+"!C86YN;W0@8F4@9F]U;F0L('1H90H@("`@
M("H@<V5R:6%L:7IE9"!R97!R97-E;G1A=&EO;B!O9B!T:&4@;V)J96-T('=I
M;&P@8F4@<F5T=7)N960N"B`@("`@*@H@("`@("H@268@=&AE(&UE<W-A9V4@
M9&%T82!I<R!A;')E861Y(&$@<W1R:6YG+"!I="!W:6QL(&)E(')E='5R;F5D
M('5N8VAA;F=E9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D("1M97-S
M86=E("`@5&AE(&]R:6=I;F%L(&UE<W-A9V4@9&%T82X@(%1H:7,@;6%Y(&)E
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@;W(@
M86YY(&]B:F5C="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@
M("`@("`@5&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V5X=')A8W1-97-S86=E*"1M97-S86=E*0H@("`@>PH@("`@
M("`@("\J"B`@("`@("`@("H@268@=V4G=F4@8F5E;B!G:79E;B!A;B!O8FIE
M8W0L(&%T=&5M<'0@=&\@97AT<F%C="!T:&4@;65S<V%G92!U<VEN9PH@("`@
M("`@("`J(&$@:VYO=VX@;65T:&]D+B`@268@=V4@8V%N)W0@9FEN9"!S=6-H
M(&$@;65T:&]D+"!D969A=6QT('1O('1H90H@("`@("`@("`J(")H=6UA;BUR
M96%D86)L92(@=F5R<VEO;B!O9B!T:&4@;V)J96-T+@H@("`@("`@("`J"B`@
M("`@("`@("H@5V4@86QS;R!U<V4@=&AE(&AU;6%N+7)E861A8FQE(&9O<FUA
M="!F;W(@87)R87ES+@H@("`@("`@("`J+PH@("`@("`@(&EF("AI<U]O8FIE
M8W0H)&UE<W-A9V4I*2!["B`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S
M*"1M97-S86=E+"`G9V5T;65S<V%G92<I*2!["B`@("`@("`@("`@("`@("`D
M;65S<V%G92`]("1M97-S86=E+3YG971-97-S86=E*"D["B`@("`@("`@("`@
M('T@96QS92!I9B`H;65T:&]D7V5X:7-T<R@D;65S<V%G92P@)W1O<W1R:6YG
M)RDI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@)&UE<W-A9V4M/G1O
M4W1R:6YG*"D["B`@("`@("`@("`@('T@96QS92!I9B`H;65T:&]D7V5X:7-T
M<R@D;65S<V%G92P@)U]?=&]S=')I;F<G*2D@>PH@("`@("`@("`@("`@("`@
M:68@*'9E<G-I;VY?8V]M<&%R92A02%!?5D524TE/3BP@)S4N,"XP)RP@)V=E
M)RDI('L*("`@("`@("`@("`@("`@("`@("`D;65S<V%G92`]("AS=')I;F<I
M)&UE<W-A9V4["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1M97-S86=E(#T@)&UE<W-A9V4M/E]?=&]3=')I;F<H*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1M97-S86=E(#T@<')I;G1?<B@D;65S<V%G92P@=')U92D[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@:68@*&ES7V%R<F%Y*"1M
M97-S86=E*2D@>PH@("`@("`@("`@("!I9B`H:7-S970H)&UE<W-A9V5;)VUE
M<W-A9V4G72DI('L*("`@("`@("`@("`@("`@("1M97-S86=E(#T@)&UE<W-A
M9V5;)VUE<W-A9V4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1M97-S86=E(#T@<')I;G1?<B@D;65S<V%G92P@=')U92D["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J($]T:&5R=VES92P@
M=V4@87-S=6UE('1H92!M97-S86=E(&ES(&$@<W1R:6YG+B`J+PH@("`@("`@
M(')E='5R;B`D;65S<V%G93L*("`@('T*"B`@("`O*BH*("`@("`J(%5S:6YG
M(&1E8G5G7V)A8VMT<F%C92@I+"!R971U<FYS('1H92!F:6QE+"!L:6YE+"!A
M;F0@96YC;&]S:6YG(&9U;F-T:6]N"B`@("`@*B!N86UE(&]F('1H92!S;W5R
M8V4@8V]D92!C;VYT97AT(&9R;VT@=VAI8V@@;&]G*"D@=V%S(&EN=F]K=F5D
M+@H@("`@("H*("`@("`J($!P87)A;2`@(&EN="`@("`@)&1E<'1H("!4:&4@
M:6YI=&EA;"!N=6UB97(@;V8@9G)A;65S('=E('-H;W5L9"!S=&5P"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@8F%C:R!I;G1O('1H92!T<F%C
M92X*("`@("`J"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@($%R<F%Y(&-O;G1A
M:6YI;F<@=&AR964@<W1R:6YG<SH@=&AE(&9I;&5N86UE+"!T:&4@;&EN92P*
M("`@("`J("`@("`@("`@("`@("`@("`@86YD('1H92!F=6YC=&EO;B!N86UE
M(&9R;VT@=VAI8V@@;&]G*"D@=V%S(&-A;&QE9"X*("`@("`J"B`@("`@*B!`
M86-C97-S("!P<FEV871E"B`@("`@*B!`<VEN8V4@("!,;V<@,2XY+C0*("`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=$)A8VMT<F%C959A<G,H)&1E<'1H*0H@
M("`@>PH@("`@("`@("\J(%-T87)T(&)Y(&=E;F5R871I;F<@82!B86-K=')A
M8V4@9G)O;2!T:&4@8W5R<F5N="!C86QL("AH97)E*2X@*B\*("`@("`@("`D
M8F%C:W1R86-E(#T@9&5B=6=?8F%C:W1R86-E*"D["@H@("`@("`@("\J"B`@
M("`@("`@("H@5V4G<F4@:6YT97)E<W1E9"!I;B!T:&4@9G)A;64@=VAI8V@@
M:6YV;VME9"!T:&4@;&]G*"D@9G5N8W1I;VXL('-O"B`@("`@("`@("H@=V4@
M;F5E9"!T;R!W86QK(&)A8VL@<V]M92!N=6UB97(@;V8@9G)A;65S(&EN=&\@
M=&AE(&)A8VMT<F%C92X@(%1H90H@("`@("`@("`J("1D97!T:"!P87)A;65T
M97(@=&5L;',@=7,@=VAE<F4@=&\@<W1A<G0@;&]O:VEN9RX@("!792!G;R!O
M;F4@<W1E<`H@("`@("`@("`J(&9U<G1H97(@8F%C:R!T;R!F:6YD('1H92!N
M86UE(&]F('1H92!E;F-A<'-U;&%T:6YG(&9U;F-T:6]N(&9R;VT*("`@("`@
M("`@*B!W:&EC:"!L;V<H*2!W87,@8V%L;&5D+@H@("`@("`@("`J+PH@("`@
M("`@("1F:6QE(#T@0"1B86-K=')A8V5;)&1E<'1H75LG9FEL92==.PH@("`@
M("`@("1L:6YE(#T@0"1B86-K=')A8V5;)&1E<'1H75LG;&EN92==.PH@("`@
M("`@("1F=6YC(#T@0"1B86-K=')A8V5;)&1E<'1H("L@,5U;)V9U;F-T:6]N
M)UT["@H@("`@("`@("\J"B`@("`@("`@("H@2&]W979E<BP@:68@;&]G*"D@
M=V%S(&-A;&QE9"!F<F]M(&]N92!O9B!O=7(@(G-H;W)T8W5T(B!F=6YC=&EO
M;G,L"B`@("`@("`@("H@=V4G<F4@9V]I;F<@=&\@;F5E9"!T;R!G;R!B86-K
M(&%N(&%D9&ET:6]N86P@<W1E<"X*("`@("`@("`@*B\*("`@("`@("!I9B`H
M:6Y?87)R87DH)&9U;F,L(&%R<F%Y*"=E;65R9R<L("=A;&5R="<L("=C<FET
M)RP@)V5R<B<L("=W87)N:6YG)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=N;W1I8V4G+"`G:6YF;R<L("=D96)U9R<I*2D@>PH@("`@
M("`@("`@("`D9FEL92`]($`D8F%C:W1R86-E6R1D97!T:"`K(#%=6R=F:6QE
M)UT["B`@("`@("`@("`@("1L:6YE(#T@0"1B86-K=')A8V5;)&1E<'1H("L@
M,5U;)VQI;F4G73L*("`@("`@("`@("`@)&9U;F,@/2!`)&)A8VMT<F%C95LD
M9&5P=&@@*R`R75LG9G5N8W1I;VXG73L*("`@("`@("!]"@H@("`@("`@("\J
M"B`@("`@("`@("H@268@=V4@8V]U;&1N)W0@97AT<F%C="!A(&9U;F-T:6]N
M(&YA;64@*'!E<FAA<',@8F5C875S92!W92!W97)E"B`@("`@("`@("H@97AE
M8W5T960@9G)O;2!T:&4@(FUA:6XB(&-O;G1E>'0I+"!P<F]V:61E(&$@9&5F
M875L="!V86QU92X*("`@("`@("`@*B\*("`@("`@("!I9B`H:7-?;G5L;"@D
M9G5N8RDI('L*("`@("`@("`@("`@)&9U;F,@/2`G*&YO;F4I)SL*("`@("`@
M("!]"@H@("`@("`@("\J(%)E='5R;B!A(#,M='5P;&4@8V]N=&%I;FEN9R`H
M9FEL92P@;&EN92P@9G5N8W1I;VXI+B`J+PH@("`@("`@(')E='5R;B!A<G)A
M>2@D9FEL92P@)&QI;F4L("1F=6YC*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%!R;V1U8V5S(&$@9F]R;6%T=&5D(&QO9R!L:6YE(&)A<V5D(&]N(&$@9F]R
M;6%T('-T<FEN9R!A;F0@82!S970@;V8*("`@("`J('9A<FEA8FQE<R!R97!R
M97-E;G1I;F<@=&AE(&-U<G)E;G0@;&]G(')E8V]R9"!A;F0@<W1A=&4N"B`@
M("`@*@H@("`@("H@0')E='5R;B`@<W1R:6YG("!&;W)M871T960@;&]G('-T
M<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`
M<VEN8V4@("!,;V<@,2XY+C0*("`@("`J+PH@("`@9G5N8W1I;VX@7V9O<FUA
M="@D9F]R;6%T+"`D=&EM97-T86UP+"`D<')I;W)I='DL("1M97-S86=E*0H@
M("`@>PH@("`@("`@("\J"B`@("`@("`@("H@268@=&AE(&9O<FUA="!S=')I
M;F<@<F5F97)E;F-E<R!A;GD@;V8@=&AE(&)A8VMT<F%C92UD<FEV96X*("`@
M("`@("`@*B!V87)I86)L97,@*"4U+"`E-BP@)3<I+"!G96YE<F%T92!T:&4@
M8F%C:W1R86-E(&%N9"!F971C:"!T:&5M+@H@("`@("`@("`J+PH@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O)5LU-C==+R<L("1F;W)M870I*2!["B`@("`@
M("`@("`@(&QI<W0H)&9I;&4L("1L:6YE+"`D9G5N8RD@/2`D=&AI<RT^7V=E
M=$)A8VMT<F%C959A<G,H,BD["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@
M("`@("`J($)U:6QD('1H92!F;W)M871T960@<W1R:6YG+B`@5V4@=7-E('1H
M92!S<')I;G1F*"D@9G5N8W1I;VXG<PH@("`@("`@("`J(")A<F=U;65N="!S
M=V%P<&EN9R(@8V%P86)I;&ET>2!T;R!D>6YA;6EC86QL>2!S96QE8W0@86YD
M('!O<VET:6]N"B`@("`@("`@("H@=&AE('9A<FEA8FQE<R!W:&EC:"!W:6QL
M('5L=&EM871E;'D@87!P96%R(&EN('1H92!L;V<@<W1R:6YG+@H@("`@("`@
M("`J+PH@("`@("`@(')E='5R;B!S<')I;G1F*"1F;W)M870L"B`@("`@("`@
M("`@("`@("`@("`@("`@)'1I;65S=&%M<"P*("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7VED96YT+`H@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YP<FEO<FET>51O4W1R:6YG*"1P<FEO<FET>2DL"B`@("`@("`@("`@
M("`@("`@("`@("`@)&UE<W-A9V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M:7-S970H)&9I;&4I(#\@)&9I;&4@.B`G)RP*("`@("`@("`@("`@("`@("`@
M("`@("!I<W-E="@D;&EN92D@/R`D;&EN92`Z("<G+`H@("`@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1F=6YC*2`_("1F=6YC(#H@)R<I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@<W1R:6YG(')E<')E<V5N=&%T
M:6]N(&]F(&$@4$5!4E],3T=?*B!I;G1E9V5R(&-O;G-T86YT+@H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@)'!R:6]R:71Y("`@("!!(%!%05)?3$]'7RH@
M:6YT96=E<B!C;VYS=&%N="X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@("`@("`@("`@5&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B`D;&5V
M96PN"B`@("`@*@H@("`@("H@0'-I;F-E("`@3&]G(#$N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!P<FEO<FET>51O4W1R:6YG*"1P<FEO<FET>2D*("`@('L*
M("`@("`@("`D;&5V96QS(#T@87)R87DH"B`@("`@("`@("`@(%!%05)?3$]'
M7T5-15)'("`@/3X@)V5M97)G96YC>2<L"B`@("`@("`@("`@(%!%05)?3$]'
M7T%,15)4("`@/3X@)V%L97)T)RP*("`@("`@("`@("`@4$5!4E],3T=?0U))
M5"`@("`]/B`G8W)I=&EC86PG+`H@("`@("`@("`@("!014%27TQ/1U]%4E(@
M("`@(#T^("=E<G)O<B<L"B`@("`@("`@("`@(%!%05)?3$]'7U=!4DY)3D<@
M/3X@)W=A<FYI;F<G+`H@("`@("`@("`@("!014%27TQ/1U].3U1)0T4@(#T^
M("=N;W1I8V4G+`H@("`@("`@("`@("!014%27TQ/1U])3D9/("`@(#T^("=I
M;F9O)RP*("`@("`@("`@("`@4$5!4E],3T=?1$5"54<@("`]/B`G9&5B=6<G
M"B`@("`@("`@*3L*"B`@("`@("`@<F5T=7)N("1L979E;'-;)'!R:6]R:71Y
M73L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('1H92!014%2
M7TQ/1U\J(&EN=&5G97(@8V]N<W1A;G0@9F]R('1H92!G:79E;B!S=')I;F<*
M("`@("`J(')E<')E<V5N=&%T:6]N(&]F(&$@<')I;W)I='D@;F%M92X@(%1H
M:7,@9G5N8W1I;VX@<&5R9F]R;7,@80H@("`@("H@8V%S92UI;G-E;G-I=&EV
M92!S96%R8V@N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M("`@(%-T<FEN9R!C;VYT86EN:6YG(&$@<')I;W)I='D@;F%M92X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@("`@("`@("`@5&AE(%!%05)?3$]'
M7RH@:6YT96=E<B!C;VYT<W1A;G0@8V]R<F5S<&]N9&EN9PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H92!T:&4@<W!E8VEF:65D('!R:6]R
M:71Y(&YA;64N"B`@("`@*@H@("`@("H@0'-I;F-E("`@3&]G(#$N.2XP"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-T<FEN9U1O4')I;W)I='DH)&YA;64I"B`@
M("!["B`@("`@("`@)&QE=F5L<R`](&%R<F%Y*`H@("`@("`@("`@("`G96UE
M<F=E;F-Y)R`]/B!014%27TQ/1U]%34521RP*("`@("`@("`@("`@)V%L97)T
M)R`@("`@/3X@4$5!4E],3T=?04Q%4E0L"B`@("`@("`@("`@("=C<FET:6-A
M;"<@(#T^(%!%05)?3$]'7T-2250L"B`@("`@("`@("`@("=E<G)O<B<@("`@
M(#T^(%!%05)?3$]'7T524BP*("`@("`@("`@("`@)W=A<FYI;F<G("`@/3X@
M4$5!4E],3T=?5T%23DE.1RP*("`@("`@("`@("`@)VYO=&EC92<@("`@/3X@
M4$5!4E],3T=?3D]424-%+`H@("`@("`@("`@("`G:6YF;R<@("`@("`]/B!0
M14%27TQ/1U])3D9/+`H@("`@("`@("`@("`G9&5B=6<G("`@("`]/B!014%2
M7TQ/1U]$14)51PH@("`@("`@("D["@H@("`@("`@(')E='5R;B`D;&5V96QS
M6W-T<G1O;&]W97(H)&YA;64I73L*("`@('T*"B`@("`O*BH*("`@("`J($-A
M;&-U;&%T92!T:&4@;&]G(&UA<VL@9F]R('1H92!G:79E;B!P<FEO<FET>2X*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M87D@8F4@8V%L;&5D('-T871I
M8V%L;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@("`D<')I;W)I
M='D@("!4:&4@<')I;W)I='D@=VAO<V4@;6%S:R!W:6QL(&)E(&-A;&-U;&%T
M960N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!4:&4@8V%L8W5L
M871E9"!L;V<@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO
M;B!-05-+*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@*#$@/#P@
M)'!R:6]R:71Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!T
M:&4@;&]G(&UA<VL@9F]R(&%L;"!P<FEO<FET:65S('5P('1O('1H92!G:79E
M;B!P<FEO<FET>2X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M87D@8F4@
M8V%L;&5D('-T871I8V%L;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G
M97(@("`D<')I;W)I='D@("!4:&4@;6%X:6UU;2!P<FEO<FET>2!C;W9E<F5D
M(&)Y('1H:7,@;6%S:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@
M(%1H92!R97-U;'1I;F<@;&]G(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J"B`@
M("`@*B!`9&5P<F5C871E9"!D97!R96-A=&5D('-I;F-E($QO9R`Q+CDN-#L@
M=7-E($QO9SHZ34%8*"D@:6YS=&5A9`H@("`@("HO"B`@("!F=6YC=&EO;B!5
M4%1/*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@3&]G.CI-05@H
M)'!R:6]R:71Y*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!T
M:&4@;&]G(&UA<VL@9F]R(&%L;"!P<FEO<FET:65S(&=R96%T97(@=&AA;B!O
M<B!E<75A;"!T;R!T:&4*("`@("`J(&=I=F5N('!R:6]R:71Y+B`@26X@;W1H
M97(@=V]R9',L("1P<FEO<FET>2!W:6QL(&)E('1H92!L;W=E<W0@<')I;W)I
M='D*("`@("`J(&UA=&-H960@8GD@=&AE(')E<W5L=&EN9R!M87-K+@H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&UA>2!B92!C86QL960@<W1A=&EC86QL
M>2X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@
M(%1H92!M:6YI;75M('!R:6]R:71Y(&-O=F5R960@8GD@=&AI<R!M87-K+@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@5&AE(')E<W5L=&EN9R!L
M;V<@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@($QO9R`Q+CDN-`H@("`@("HO"B`@("!F=6YC=&EO;B!-24XH
M)'!R:6]R:71Y*0H@("`@>PH@("`@("`@(')E='5R;B!014%27TQ/1U]!3$P@
M7B`H*#$@/#P@)'!R:6]R:71Y*2`M(#$I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V%L8W5L871E('1H92!L;V<@;6%S:R!F;W(@86QL('!R:6]R:71I97,@
M;&5S<R!T:&%N(&]R(&5Q=6%L('1O('1H90H@("`@("H@9VEV96X@<')I;W)I
M='DN("!);B!O=&AE<B!W;W)D<RP@)'!R:6]R:71Y('=I;&P@8F4@=&AE(&AI
M9VAE<W1S('!R:6]R:71Y"B`@("`@*B!M871C:&5D(&)Y('1H92!R97-U;'1I
M;F<@;6%S:RX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!M87D@8F4@8V%L
M;&5D('-T871I8V%L;'DN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@
M("`D<')I;W)I='D@("!4:&4@;6%X:6UU;2!P<FEO<FET>2!C;W9E<F5D(&)Y
M('1H:7,@;6%S:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H
M92!R97-U;'1I;F<@;&]G(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XY+C0*("`@("`J+PH@("`@
M9G5N8W1I;VX@34%8*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@
M*"@Q(#P\("@D<')I;W)I='D@*R`Q*2D@+2`Q*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E="!A;F0@<F5T=7)N('1H92!L979E;"!M87-K(&9O<B!T:&4@
M8W5R<F5N="!,;V<@:6YS=&%N8V4N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M=&5G97(@)&UA<VL@("`@($$@8FET=VES92!M87-K(&]F(&QO9R!L979E;',N
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("`@("`@("`@(%1H92!C
M=7)R96YT(&QE=F5L(&UA<VLN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@<V5T36%S:R@D;6%S:RD*("`@('L*("`@("`@("`D=&AI<RT^7VUA
M<VL@/2`D;6%S:SL*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;6%S:SL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@;&5V96P@
M;6%S:RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5R9V5R("`@("`@("`@
M5&AE(&-U<G)E;G0@;&5V96P@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S
M("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C<N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971-87-K*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]M87-K.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VL@:68@=&AE
M(&=I=F5N('!R:6]R:71Y(&ES(&EN8VQU9&5D(&EN('1H92!C=7)R96YT(&QE
M=F5L(&UA<VLN"B`@("`@*@H@("`@("H@0'!A<F%M(&EN=&5G97(@("`D<')I
M;W)I='D@("!4:&4@<')I;W)I='D@=&\@8VAE8VLN"B`@("`@*@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!G:79E;B!P<FEO<FET>2!I
M<R!I;F-L=61E9"!I;B!T:&4@8W5R<F5N=`H@("`@("H@("`@("`@("`@("`@
M("`@("!L;V<@;6%S:RX*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B!`<VEN8V4@("!,;V<@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@7VES36%S:V5D*"1P<FEO<FET>2D*("`@('L*("`@("`@("!R971U<FX@
M*$QO9SHZ34%32R@D<')I;W)I='DI("8@)'1H:7,M/E]M87-K*3L*("`@('T*
M"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@9&5F875L="!P
M<FEO<FET>2X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(@(%1H92!C
M=7)R96YT(&1E9F%U;'0@<')I;W)I='DN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XX+C0*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4')I;W)I='DH*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!R:6]R:71Y.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T
M<R!T:&4@9&5F875L="!P<FEO<FET>2!T;R!T:&4@<W!E8VEF:65D('9A;'5E
M+@H@("`@("H*("`@("`J($!P87)A;2`@(&EN=&5G97(@)'!R:6]R:71Y("`@
M5&AE(&YE=R!D969A=6QT('!R:6]R:71Y+@H@("`@("H*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@3&]G(#$N."XT"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-E=%!R:6]R:71Y*"1P<FEO<FET>2D*("`@('L*("`@
M("`@("`D=&AI<RT^7W!R:6]R:71Y(#T@)'!R:6]R:71Y.PH@("`@?0H*("`@
M("\J*@H@("`@("H@061D<R!A($QO9U]O8G-E<G9E<B!I;G-T86YC92!T;R!T
M:&4@;&ES="!O9B!O8G-E<G9E<G,@=&AA="!A<F4@;&ES=&5N:6YG"B`@("`@
M*B!F;W(@;65S<V%G97,@96UI='1E9"!B>2!T:&ES($QO9R!I;G-T86YC92X*
M("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T("`@("1O8G-E<G9E<B`@(%1H
M92!,;V=?;V)S97)V97(@:6YS=&%N8V4@=&\@871T86-H(&%S(&$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&ES=&5N97(N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&)O;VQE86X@("!4<G5E(&EF('1H92!O8G-E<G9E
M<B!I<R!S=6-C97-S9G5L;'D@871T86-H960N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%T=&%C:"@F)&]B<V5R=F5R*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?82@D;V)S97)V97(L("=,;V=?;V)S97)V97(G*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VQI<W1E;F5R<ULD;V)S97)V97(M/E]I9%T@/2`F)&]B<V5R=F5R.PH*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M;6]V97,@82!,;V=?;V)S97)V97(@:6YS=&%N8V4@9G)O;2!T:&4@;&ES="!O
M9B!O8G-E<G9E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D
M;V)S97)V97(@("!4:&4@3&]G7V]B<V5R=F5R(&EN<W1A;F-E('1O(&1E=&%C
M:"!F<F]M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!L:7-T(&]F(&QI<W1E;F5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`@(%1R=64@:68@=&AE(&]B<V5R=F5R(&ES('-U8V-E<W-F=6QL>2!D
M971A8VAE9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M($!S:6YC92`@($QO9R`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@9&5T86-H
M*"1O8G-E<G9E<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&]B<V5R=F5R
M+"`G3&]G7V]B<V5R=F5R)RD@?'P*("`@("`@("`@("`@(6ES<V5T*"1T:&ES
M+3Y?;&ES=&5N97)S6R1O8G-E<G9E<BT^7VED72DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@=6YS970H)'1H:7,M
M/E]L:7-T96YE<G-;)&]B<V5R=F5R+3Y?:61=*3L*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F9O<FUS(&5A8V@@<F5G
M:7-T97)E9"!O8G-E<G9E<B!I;G-T86YC92!T:&%T(&$@;F5W(&UE<W-A9V4@
M:&%S(&)E96X*("`@("`J(&QO9V=E9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@("`@("1E=F5N="`@("`@($$@:&%S:"!D97-C<FEB:6YG('1H92!L
M;V<@979E;G0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%]A;FYO=6YC92@D979E;G0I"B`@("!["B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]L:7-T96YE<G,@87,@)&ED(#T^("1L:7-T
M96YE<BD@>PH@("`@("`@("`@("!I9B`H)&5V96YT6R=P<FEO<FET>2==(#P]
M("1T:&ES+3Y?;&ES=&5N97)S6R1I9%TM/E]P<FEO<FET>2D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&ED72T^;F]T:69Y*"1E=F5N
M="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);F1I8V%T97,@=VAE=&AE<B!T:&ES(&ES(&$@8V]M<&]S:71E(&-L
M87-S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@("`@("`@("!4
M<G5E(&EF('1H:7,@:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XP"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&ES0V]M<&]S:71E*"D*("`@('L*("`@("`@
M("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M:7,@3&]G(&EN<W1A;F-E)W,@:61E;G1I9FEC871I;VX@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)&ED96YT("`@("`@5&AE(&YE
M=R!I9&5N=&EF:6-A=&EO;B!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XV+C,*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?:61E;G0@/2`D:61E;G0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!C=7)R96YT(&ED96YT:69I8V%T:6]N('-T<FEN9RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@(%1H92!C=7)R96YT($QO9R!I
M;G-T86YC92=S(&ED96YT:69I8V%T:6]N('-T<FEN9RX*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!S:6YC92`@($QO9R`Q+C8N,PH@
M("`@("HO"B`@("!F=6YC=&EO;B!G971)9&5N="@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?:61E;G0["B`@("!]"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3F5T+T94
M4```````````````````````````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-2`P,3<U-C,`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B].970O4V]C:V5T+G!H<```````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,U-S<U(#$P-3$U-#,T,3,U(#`R,3$W
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M2%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC
M96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W)S.B!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@
M("`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!3;V-K970N<&AP+'8@,2XR-"`R,#`U+S`R
M+S`S(#(P.C0P.C$V(&-H86=E;F)U($5X<"`D"@IR97%U:7)E7V]N8V4@)U!%
M05(N<&AP)SL*"F1E9FEN92@G3D547U-/0TM%5%]214%$)RP@(#$I.PID969I
M;F4H)TY%5%]33T-+151?5U))5$4G+"`R*3L*9&5F:6YE*"=.151?4T]#2T54
M7T524D]2)RP@,RD["@HO*BH*("H@1V5N97)A;&EZ960@4V]C:V5T(&-L87-S
M+@H@*@H@*B!`=F5R<VEO;B`Q+C$*("H@0&%U=&AO<B!3=&EG($)A:VME;B`\
M<W-B0'!H<"YN970^"B`J($!A=71H;W(@0VAU8VL@2&%G96YB=6-H(#QC:'5C
M:T!H;W)D92YO<F<^"B`J+PIC;&%S<R!.971?4V]C:V5T(&5X=&5N9',@4$5!
M4B!["@H@("`@+RHJ"B`@("`@*B!3;V-K970@9FEL92!P;VEN=&5R+@H@("`@
M("H@0'9A<B!R97-O=7)C92`D9G`*("`@("`J+PH@("`@=F%R("1F<"`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1H92!S;V-K970@:7,@8FQO
M8VMI;F<N($1E9F%U;'1S('1O('1R=64N"B`@("`@*B!`=F%R(&)O;VQE86X@
M)&)L;V-K:6YG"B`@("`@*B\*("`@('9A<B`D8FQO8VMI;F<@/2!T<G5E.PH*
M("`@("\J*@H@("`@("H@5VAE=&AE<B!T:&4@<V]C:V5T(&ES('!E<G-I<W1E
M;G0N($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@0'9A<B!B;V]L96%N("1P
M97)S:7-T96YT"B`@("`@*B\*("`@('9A<B`D<&5R<VES=&5N="`](&9A;'-E
M.PH*("`@("\J*@H@("`@("H@5&AE($E0(&%D9')E<W,@=&\@8V]N;F5C="!T
M;RX*("`@("`J($!V87(@<W1R:6YG("1A9&1R"B`@("`@*B\*("`@('9A<B`D
M861D<B`]("<G.PH*("`@("\J*@H@("`@("H@5&AE('!O<G0@;G5M8F5R('1O
M(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R(&EN=&5G97(@)'!O<G0*("`@("`J
M+PH@("`@=F%R("1P;W)T(#T@,#L*"B`@("`O*BH*("`@("`J($YU;6)E<B!O
M9B!S96-O;F1S('1O('=A:70@;VX@<V]C:V5T(&-O;FYE8W1I;VYS(&)E9F]R
M92!A<W-U;6EN9PH@("`@("H@=&AE<F4G<R!N;R!M;W)E(&1A=&$N($1E9F%U
M;'1S('1O(&YO('1I;65O=70N"B`@("`@*B!`=F%R(&EN=&5G97(@)'1I;65O
M=70*("`@("`J+PH@("`@=F%R("1T:6UE;W5T(#T@9F%L<V4["@H@("`@+RHJ
M"B`@("`@*B!.=6UB97(@;V8@8GET97,@=&\@<F5A9"!A="!A('1I;64@:6X@
M<F5A9$QI;F4H*2!A;F0*("`@("`J(')E861!;&PH*2X@1&5F875L=',@=&\@
M,C`T."X*("`@("`J($!V87(@:6YT96=E<B`D;&EN94QE;F=T:`H@("`@("HO
M"B`@("!V87(@)&QI;F5,96YG=&@@/2`R,#0X.PH*("`@("\J*@H@("`@("H@
M0V]N;F5C="!T;R!T:&4@<W!E8VEF:65D('!O<G0N($EF(&-A;&QE9"!W:&5N
M('1H92!S;V-K970@:7,*("`@("`J(&%L<F5A9'D@8V]N;F5C=&5D+"!I="!D
M:7-C;VYN96-T<R!A;F0@8V]N;F5C=',@86=A:6XN"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`@)&%D9'(@("`@("`@($E0(&%D9')E<W,@;W(@:&]S
M="!N86UE+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<G0@("`@("`@(%1#
M4"!P;W)T(&YU;6)E<BX*("`@("`J($!P87)A;2!B;V]L96%N("1P97)S:7-T
M96YT("`H;W!T:6]N86PI(%=H971H97(@=&AE(&-O;FYE8W1I;VX@:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P97)S:7-T96YT("AK
M97!T(&]P96X@8F5T=V5E;B!R97%U97-T<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)Y('1H92!W96(@<V5R=F5R*2X*("`@("`J($!P
M87)A;2!I;G1E9V5R("1T:6UE;W5T("`@("`H;W!T:6]N86PI($AO=R!L;VYG
M('1O('=A:70@9F]R(&1A=&$N"B`@("`@*B!`<&%R86T@87)R87D@("`D;W!T
M:6]N<R`@("`@4V5E(&]P=&EO;G,@9F]R('-T<F5A;5]C;VYT97AT7V-R96%T
M92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H*("`@("`J
M($!R971U<FX@8F]O;&5A;B!\(%!%05)?17)R;W(@(%1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05)?17)R;W(@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N;F5C="@D861D<BP@)'!O<G0@/2`P+"`D<&5R<VES=&5N="`]
M(&YU;&PL("1T:6UE;W5T(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@
M("`@("`@($!F8VQO<V4H)'1H:7,M/F9P*3L*("`@("`@("`@("`@)'1H:7,M
M/F9P(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@(&EF("@A)&%D9'(I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<D861D<B!C
M86YN;W0@8F4@96UP='DG*3L*("`@("`@("!](&5L<V5I9B`H<W1R<W!N*"1A
M9&1R+"`G+C`Q,C,T-38W.#DG*2`]/2!S=')L96XH)&%D9'(I('Q\"B`@("`@
M("`@("`@("`@("`@('-T<G-T<B@D861D<BP@)R\G*2`A/3T@9F%L<V4I('L*
M("`@("`@("`@("`@)'1H:7,M/F%D9'(@/2`D861D<CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^861D<B`]($!G971H;W-T8GEN86UE
M*"1A9&1R*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YP;W)T(#T@)'!O
M<G0@)2`V-34S-CL*"B`@("`@("`@:68@*"1P97)S:7-T96YT("$]/2!N=6QL
M*2!["B`@("`@("`@("`@("1T:&ES+3YP97)S:7-T96YT(#T@)'!E<G-I<W1E
M;G0["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1I;65O=70@(3T](&YU;&PI
M('L*("`@("`@("`@("`@)'1H:7,M/G1I;65O=70@/2`D=&EM96]U=#L*("`@
M("`@("!]"@H@("`@("`@("1O<&5N9G5N8R`]("1T:&ES+3YP97)S:7-T96YT
M(#\@)W!F<V]C:V]P96XG(#H@)V9S;V-K;W!E;B<["B`@("`@("`@)&5R<FYO
M(#T@,#L*("`@("`@("`D97)R<W1R(#T@)R<["B`@("`@("`@:68@*"1O<'1I
M;VYS("8F(&9U;F-T:6]N7V5X:7-T<R@G<W1R96%M7V-O;G1E>'1?8W)E871E
M)RDI('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT:6UE;W5T*2!["B`@("`@
M("`@("`@("`@("`D=&EM96]U="`]("1T:&ES+3YT:6UE;W5T.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1I;65O=70@/2`P.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1C;VYT97AT(#T@<W1R96%M7V-O
M;G1E>'1?8W)E871E*"1O<'1I;VYS*3L*("`@("`@("`@("`@)&9P(#T@0"1O
M<&5N9G5N8R@D=&AI<RT^861D<BP@)'1H:7,M/G!O<G0L("1E<G)N;RP@)&5R
M<G-T<BP@)'1I;65O=70L("1C;VYT97AT*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/G1I;65O=70I('L*("`@("`@("`@("`@
M("`@("1F<"`]($`D;W!E;F9U;F,H)'1H:7,M/F%D9'(L("1T:&ES+3YP;W)T
M+"`D97)R;F\L("1E<G)S='(L("1T:&ES+3YT:6UE;W5T*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1F<"`]($`D;W!E;F9U;F,H
M)'1H:7,M/F%D9'(L("1T:&ES+3YP;W)T+"`D97)R;F\L("1E<G)S='(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(21F<"D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<G-T<BP@
M)&5R<FYO*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YF<"`]("1F<#L*
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YS971";&]C:VEN9R@D=&AI<RT^8FQO
M8VMI;F<I.PH@("`@?0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O
M;2!T:&4@<&5E<BP@8VQO<V5S('1H92!S;V-K970N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@;6EX960@=')U92!O;B!S
M=6-C97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O=&AE<G=I<V4*("`@("`J+PH@
M("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@:68@*"%I
M<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*
M"B`@("`@("`@0&9C;&]S92@D=&AI<RT^9G`I.PH@("`@("`@("1T:&ES+3YF
M<"`](&YU;&P["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!&:6YD(&]U="!I9B!T:&4@<V]C:V5T(&ES(&EN(&)L;V-K:6YG
M(&UO9&4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R
M971U<FX@8F]O;&5A;B`@5&AE(&-U<G)E;G0@8FQO8VMI;F<@;6]D92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@:7-";&]C:VEN9R@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YB;&]C:VEN9SL*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E=',@=VAE=&AE<B!T:&4@<V]C:V5T(&-O;FYE8W1I;VX@<VAO=6QD(&)E
M(&)L;V-K:6YG(&]R"B`@("`@*B!N;W0N($$@<F5A9"!C86QL('1O(&$@;F]N
M+6)L;V-K:6YG('-O8VME="!W:6QL(')E='5R;B!I;6UE9&EA=&5L>0H@("`@
M("H@:68@=&AE<F4@:7,@;F\@9&%T82!A=F%I;&%B;&4L('=H97)E87,@:70@
M=VEL;"!B;&]C:R!U;G1I;"!T:&5R90H@("`@("H@:7,@9&%T82!F;W(@8FQO
M8VMI;F<@<V]C:V5T<RX*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M;6]D92`@5')U92!F;W(@8FQO8VMI;F<@<V]C:V5T<RP@9F%L<V4@9F]R(&YO
M;F)L;V-K:6YG+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U
M<FX@;6EX960@=')U92!O;B!S=6-C97-S(&]R(&%N(&5R<F]R(&]B:F5C="!O
M=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T0FQO8VMI;F<H)&UO
M9&4I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T
M(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F)L;V-K
M:6YG(#T@)&UO9&4["B`@("`@("`@<V]C:V5T7W-E=%]B;&]C:VEN9R@D=&AI
M<RT^9G`L("1T:&ES+3YB;&]C:VEN9RD["B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!T:6UE;W5T('9A;'5E
M(&]N('-O8VME="!D97-C<FEP=&]R+`H@("`@("H@97AP<F5S<V5D(&EN('1H
M92!S=6T@;V8@<V5C;VYD<R!A;F0@;6EC<F]S96-O;F1S"B`@("`@*@H@("`@
M("H@0'!A<F%M(&EN=&5G97(@)'-E8V]N9',@(%-E8V]N9',N"B`@("`@*B!`
M<&%R86T@:6YT96=E<B`D;6EC<F]S96-O;F1S("!-:6-R;W-E8V]N9',N"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!M:7AE9"!T<G5E
M(&]N('-U8V-E<W,@;W(@86X@97)R;W(@;V)J96-T(&]T:&5R=VES90H@("`@
M("HO"B`@("!F=6YC=&EO;B!S9714:6UE;W5T*"1S96-O;F1S+"`D;6EC<F]S
M96-O;F1S*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M
M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!S
M;V-K971?<V5T7W1I;65O=70H)'1H:7,M/F9P+"`D<V5C;VYD<RP@)&UI8W)O
M<V5C;VYD<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R
M;6%T:6]N(&%B;W5T(&%N(&5X:7-T:6YG('-O8VME="!R97-O=7)C92X*("`@
M("`J($-U<G)E;G1L>2!R971U<FYS(&9O=7(@96YT<FEE<R!I;B!T:&4@<F5S
M=6QT(&%R<F%Y.@H@("`@("H*("`@("`J(#QP/@H@("`@("H@=&EM961?;W5T
M("AB;V]L*2`M(%1H92!S;V-K970@=&EM960@;W5T('=A:71I;F<@9F]R(&1A
M=&$\8G(^"B`@("`@*B!B;&]C:V5D("AB;V]L*2`M(%1H92!S;V-K970@=V%S
M(&)L;V-K960\8G(^"B`@("`@*B!E;V8@*&)O;VPI("T@26YD:6-A=&5S($5/
M1B!E=F5N=#QB<CX*("`@("`J('5N<F5A9%]B>71E<R`H:6YT*2`M($YU;6)E
M<B!O9B!B>71E<R!L969T(&EN('1H92!S;V-K970@8G5F9F5R/&)R/@H@("`@
M("H@/"]P/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N(&UI>&5D($%R<F%Y(&-O;G1A:6YI;F<@:6YF;W)M871I;VX@86)O
M=70@97AI<W1I;F<@<V]C:V5T(')E<V]U<F-E(&]R(&%N(&5R<F]R(&]B:F5C
M="!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W1A='5S*"D*
M("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N
M;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@<V]C:V5T7V=E
M=%]S=&%T=7,H)'1H:7,M/F9P*3L*("`@('T*"B`@("`O*BH*("`@("`J($=E
M="!A('-P96-I9FEE9"!L:6YE(&]F(&1A=&$*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0')E='5R;B`D<VEZ92!B>71E<R!O9B!D871A
M(&9R;VT@=&AE('-O8VME="P@;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@
M("`@("`@(&YO="!C;VYN96-T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=',H)'-I>F4I"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI
M<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M($!F9V5T<R@D=&AI<RT^9G`L("1S:7IE*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E860@82!S<&5C:69I960@86UO=6YT(&]F(&1A=&$N(%1H:7,@:7,@
M9W5A<F%N=&5E9"!T;R!R971U<FXL"B`@("`@*B!A;F0@:&%S('1H92!A9&1E
M9"!B96YE9FET(&]F(&=E='1I;F<@979E<GET:&EN9R!I;B!O;F4@9G)E860H
M*0H@("`@("H@8VAU;FL[(&EF('EO=2!K;F]W('1H92!S:7IE(&]F('1H92!D
M871A('EO=2=R92!G971T:6YG"B`@("`@*B!B969O<F5H86YD+"!T:&ES(&ES
M(&1E9FEN:71E;'D@=&AE('=A>2!T;R!G;RX*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT96=E<B`D<VEZ92`@5&AE(&YU;6)E<B!O9B!B>71E<R!T;R!R96%D
M(&9R;VT@=&AE('-O8VME="X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N("1S:7IE(&)Y=&5S(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T
M+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE
M8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9"@D<VEZ92D*("`@('L*
M("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@0&9R96%D*"1T:&ES+3YF
M<"P@)'-I>F4I.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@82!S<&5C
M:69I960@86UO=6YT(&]F(&1A=&$N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&1A=&$@("`@("`@1&%T82!T;R!W<FET92X*("`@("`J($!P87)A
M;2!I;G1E9V5R("1B;&]C:W-I>F4@($%M;W5N="!O9B!D871A('1O('=R:71E
M(&%T(&]N8V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!.
M54Q,(&UE86YS(&%L;"!A="!O;F-E+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<R!O
M<B!A;B!E<G)O<B!O8FIE8W0@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T
M:6]N('=R:71E*"1D871A+"`D8FQO8VMS:7IE(#T@;G5L;"D*("`@('L*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=N;W0@8V]N;F5C=&5D)RD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?;G5L;"@D8FQO8VMS:7IE*2`F
M)B`A3U-?5TE.1$]74RD@>PH@("`@("`@("`@("!R971U<FX@9G=R:71E*"1T
M:&ES+3YF<"P@)&1A=&$I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&EF("AI<U]N=6QL*"1B;&]C:W-I>F4I*2!["B`@("`@("`@("`@("`@("`D
M8FQO8VMS:7IE(#T@,3`R-#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)'!O<R`](#`["B`@("`@("`@("`@("1S:7IE(#T@<W1R;&5N*"1D871A*3L*
M("`@("`@("`@("`@=VAI;&4@*"1P;W,@/"`D<VEZ92D@>PH@("`@("`@("`@
M("`@("`@)'=R:71T96X@/2!`9G=R:71E*"1T:&ES+3YF<"P@<W5B<W1R*"1D
M871A+"`D<&]S+"`D8FQO8VMS:7IE*2D["B`@("`@("`@("`@("`@("!I9B`H
M)'=R:71T96X@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M)'!O<R`K/2`D=W)I='1E;CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M<F5T=7)N("1P;W,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5W)I=&4@82!L:6YE(&]F(&1A=&$@=&\@=&AE('-O8VME="P@9F]L;&]W960@
M8GD@82!T<F%I;&EN9R`B7')<;B(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!R971U<FX@;6EX960@9G!U=',@<F5S=6QT+"!O<B!A
M;B!E<G)O<@H@("`@("HO"B`@("!F=6YC=&EO;B!W<FET94QI;F4H)&1A=&$I
M"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O
M;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(&9W<FET92@D
M=&AI<RT^9G`L("1D871A("X@(EQR7&XB*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%1E<W1S(&9O<B!E;F0M;V8M9FEL92!O;B!A('-O8VME="!D97-C<FEP
M=&]R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N(&)O;VP*("`@("`J+PH@("`@9G5N8W1I;VX@96]F*"D*("`@('L*("`@
M("`@("!R971U<FX@*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"D@)B8@9F5O9B@D
M=&AI<RT^9G`I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E861S(&$@8GET
M92!O9B!D871A"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!R971U<FX@,2!B>71E(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A
M(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$)Y=&4H*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!O<F0H0&9R96%D*"1T:&ES+3YF<"P@
M,2DI.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9',@82!W;W)D(&]F(&1A
M=&$*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R
M;B`Q('=O<F0@;V8@9&%T82!F<F]M('1H92!S;V-K970L(&]R(&$@4$5!4E]%
M<G)O<B!I9@H@("`@("H@("`@("`@("!N;W0@8V]N;F5C=&5D+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!R96%D5V]R9"@I"B`@("!["B`@("`@("`@:68@*"%I
M<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I.PH@("`@("`@('T*
M"B`@("`@("`@)&)U9B`]($!F<F5A9"@D=&AI<RT^9G`L(#(I.PH@("`@("`@
M(')E='5R;B`H;W)D*"1B=69;,%TI("L@*&]R9"@D8G5F6S%=*2`\/"`X*2D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296%D<R!A;B!I;G0@;V8@9&%T80H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(#$@:6YT(&]F(&1A=&$@9G)O;2!T:&4@<V]C:V5T+"!O<B!A(%!%
M05)?17)R;W(@:68*("`@("`J("`@("`@("`@("`@("`@("`@;F]T(&-O;FYE
M8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9$EN="@I"B`@("!["B`@
M("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O;FYE8W1E9"<I
M.PH@("`@("`@('T*"B`@("`@("`@)&)U9B`]($!F<F5A9"@D=&AI<RT^9G`L
M(#0I.PH@("`@("`@(')E='5R;B`H;W)D*"1B=69;,%TI("L@*&]R9"@D8G5F
M6S%=*2`\/"`X*2`K"B`@("`@("`@("`@("`@("`H;W)D*"1B=69;,ETI(#P\
M(#$V*2`K("AO<F0H)&)U9ELS72D@/#P@,C0I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E861S(&$@>F5R;RUT97)M:6YA=&5D('-T<FEN9R!O9B!D871A
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M<W1R:6YG+"!O<B!A(%!%05)?17)R;W(@:68*("`@("`J("`@("`@("`@;F]T
M(&-O;FYE8W1E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@<F5A9%-T<FEN9R@I
M"B`@("!["B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D=&AI<RT^9G`I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F]T(&-O
M;FYE8W1E9"<I.PH@("`@("`@('T*"B`@("`@("`@)'-T<FEN9R`]("<G.PH@
M("`@("`@('=H:6QE("@H)&-H87(@/2!`9G)E860H)'1H:7,M/F9P+"`Q*2D@
M(3T@(EQX,#`B*2`@>PH@("`@("`@("`@("`D<W1R:6YG("X]("1C:&%R.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E861S(&%N($E0($%D9')E<W,@86YD(')E='5R;G,@:70@
M:6X@82!D;W0@9F]R;6%T960@<W1R:6YG"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!R971U<FX@1&]T(&9O<FUA=&5D('-T<FEN9RP@
M;W(@82!014%27T5R<F]R(&EF"B`@("`@*B`@("`@("`@(&YO="!C;VYN96-T
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861)4$%D9')E<W,H*0H@("`@
M>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T
M960G*3L*("`@("`@("!]"@H@("`@("`@("1B=68@/2!`9G)E860H)'1H:7,M
M/F9P+"`T*3L*("`@("`@("!R971U<FX@<W!R:6YT9B@B)7,N)7,N)7,N)7,B
M+"!O<F0H)&)U9ELP72DL(&]R9"@D8G5F6S%=*2P*("`@("`@("`@("`@("`@
M("`@("`@("!O<F0H)&)U9ELR72DL(&]R9"@D8G5F6S-=*2D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!296%D('5N=&EL(&5I=&AE<B!T:&4@96YD(&]F('1H
M92!S;V-K970@;W(@82!N97=L:6YE+"!W:&EC:&5V97(*("`@("`J(&-O;65S
M(&9I<G-T+B!3=')I<',@=&AE('1R86EL:6YG(&YE=VQI;F4@9G)O;2!T:&4@
M<F5T=7)N960@9&%T82X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0')E='5R;B!!;&P@879A:6QA8FQE(&1A=&$@=7`@=&\@82!N97=L
M:6YE+"!W:71H;W5T('1H870*("`@("`J("`@("`@("`@;F5W;&EN92P@;W(@
M=6YT:6P@=&AE(&5N9"!O9B!T:&4@<V]C:V5T+"!O<B!A(%!%05)?17)R;W(@
M:68*("`@("`J("`@("`@("`@;F]T(&-O;FYE8W1E9"X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<F5A9$QI;F4H*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S
M;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@("`@("!]"@H@("`@
M("`@("1L:6YE(#T@)R<["B`@("`@("`@)'1I;65O=70@/2!T:6UE*"D@*R`D
M=&AI<RT^=&EM96]U=#L*("`@("`@("!W:&EL92`H(69E;V8H)'1H:7,M/F9P
M*2`F)B`H(21T:&ES+3YT:6UE;W5T('Q\('1I;64H*2`\("1T:6UE;W5T*2D@
M>PH@("`@("`@("`@("`D;&EN92`N/2!`9F=E=',H)'1H:7,M/F9P+"`D=&AI
M<RT^;&EN94QE;F=T:"D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&QI;F4L
M("TQ*2`]/2`B7&XB*2!["B`@("`@("`@("`@("`@("!R971U<FX@<G1R:6TH
M)&QI;F4L(")<<EQN(BD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1L:6YE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5A9"!U
M;G1I;"!T:&4@<V]C:V5T(&-L;W-E<RP@;W(@=6YT:6P@=&AE<F4@:7,@;F\@
M;6]R92!D871A(&EN"B`@("`@*B!T:&4@:6YN97(@4$A0(&)U9F9E<BX@268@
M=&AE(&EN;F5R(&)U9F9E<B!I<R!E;7!T>2P@:6X@8FQO8VMI;F<*("`@("`J
M(&UO9&4@=V4@=V%I="!F;W(@870@;&5A<W0@,2!B>71E(&]F(&1A=&$N(%1H
M97)E9F]R92P@:6X*("`@("`J(&)L;V-K:6YG(&UO9&4L(&EF('1H97)E(&ES
M(&YO(&1A=&$@870@86QL('1O(&)E(')E860L('1H:7,*("`@("`J(&9U;F-T
M:6]N('=I;&P@;F5V97(@97AI="`H=6YL97-S('1H92!S;V-K970@:7,@8VQO
M<V5D(&]N('1H90H@("`@("H@<F5M;W1E(&5N9"DN"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M06QL(&1A=&$@=6YT:6P@=&AE('-O8VME="!C;&]S97,L(&]R(&$@4$5!4E]%
M<G)O<B!I9@H@("`@("H@("`@("`@("`@("`@("`@(&YO="!C;VYN96-T960N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')E861!;&PH*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F9P*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO="!C;VYN96-T960G*3L*("`@
M("`@("!]"@H@("`@("`@("1D871A(#T@)R<["B`@("`@("`@=VAI;&4@*"%F
M96]F*"1T:&ES+3YF<"DI('L*("`@("`@("`@("`@)&1A=&$@+CT@0&9R96%D
M*"1T:&ES+3YF<"P@)'1H:7,M/FQI;F5,96YG=&@I.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&1A=&$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2=6YS
M('1H92!E<75I=F%L96YT(&]F('1H92!S96QE8W0H*2!S>7-T96T@8V%L;"!O
M;B!T:&4@<V]C:V5T"B`@("`@*B!W:71H(&$@=&EM96]U="!S<&5C:69I960@
M8GD@='9?<V5C(&%N9"!T=E]U<V5C+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G1E9V5R("1S=&%T92`@("!7:&EC:"!O9B!R96%D+W=R:71E+V5R<F]R('1O
M(&-H96-K(&9O<BX*("`@("`J($!P87)A;2!I;G1E9V5R("1T=E]S96,@("!.
M=6UB97(@;V8@<V5C;VYD<R!F;W(@=&EM96]U="X*("`@("`J($!P87)A;2!I
M;G1E9V5R("1T=E]U<V5C("!.=6UB97(@;V8@;6EC<F]S96-O;F1S(&9O<B!T
M:6UE;W5T+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<F5T=7)N($9A;'-E(&EF('-E;&5C="!F86EL<RP@:6YT96=E<B!D97-C<FEB
M:6YG('=H:6-H(&]F(')E860O=W)I=&4O97)R;W(*("`@("`J("`@("`@("`@
M87)E(')E861Y+"!O<B!014%27T5R<F]R(&EF(&YO="!C;VYN96-T960N"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E;&5C="@D<W1A=&4L("1T=E]S96,L("1T
M=E]U<V5C(#T@,"D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T
M:&ES+3YF<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=N;W0@8V]N;F5C=&5D)RD["B`@("`@("`@?0H*("`@("`@("`D<F5A
M9"`](&YU;&P["B`@("`@("`@)'=R:71E(#T@;G5L;#L*("`@("`@("`D97AC
M97!T(#T@;G5L;#L*("`@("`@("!I9B`H)'-T871E("8@3D547U-/0TM%5%]2
M14%$*2!["B`@("`@("`@("`@("1R96%D6UT@/2`D=&AI<RT^9G`["B`@("`@
M("`@?0H@("`@("`@(&EF("@D<W1A=&4@)B!.151?4T]#2T547U=2251%*2![
M"B`@("`@("`@("`@("1W<FET95M=(#T@)'1H:7,M/F9P.PH@("`@("`@('T*
M("`@("`@("!I9B`H)'-T871E("8@3D547U-/0TM%5%]%4E)/4BD@>PH@("`@
M("`@("`@("`D97AC97!T6UT@/2`D=&AI<RT^9G`["B`@("`@("`@?0H@("`@
M("`@(&EF("AF86QS92`]/3T@*"1S<B`]('-T<F5A;5]S96QE8W0H)')E860L
M("1W<FET92P@)&5X8V5P="P@)'1V7W-E8RP@)'1V7W5S96,I*2D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D<F5S
M=6QT(#T@,#L*("`@("`@("!I9B`H8V]U;G0H)')E860I*2!["B`@("`@("`@
M("`@("1R97-U;'0@?#T@3D547U-/0TM%5%]214%$.PH@("`@("`@('T*("`@
M("`@("!I9B`H8V]U;G0H)'=R:71E*2D@>PH@("`@("`@("`@("`D<F5S=6QT
M('P]($Y%5%]33T-+151?5U))5$4["B`@("`@("`@?0H@("`@("`@(&EF("AC
M;W5N="@D97AC97!T*2D@>PH@("`@("`@("`@("`D<F5S=6QT('P]($Y%5%]3
M3T-+151?15)23U(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S=6QT
M.PH@("`@?0H*?0H```!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE
M="]33510+G!H<```````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P-S0R,C4@,3`U,34T,S0Q,S4@,#(P-3$W`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!S;V9T=&%B<W1O<#TT('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@
M;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`
M:&]R9&4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE=#X@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@1&%M:6%N
M($%L96IA;F1R;R!&97)N86YD97H@4V]S82`\9&%M;&ES='-`8VYB82YU8F$N
M87(^("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!33510+G!H<"QV(#$N-34@,C`P-B\P,B\P-B`P-CHP,#HR,B!J
M;VX@17AP("0*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PIR97%U:7)E7V]N
M8V4@)TYE="]3;V-K970N<&AP)SL*"B\J*@H@*B!0<F]V:61E<R!A;B!I;7!L
M96UE;G1A=&EO;B!O9B!T:&4@4TU44"!P<F]T;V-O;"!U<VEN9R!014%2)W,*
M("H@3F5T7U-O8VME=#HZ(&-L87-S+@H@*@H@*B!`<&%C:V%G92!.971?4TU4
M4`H@*B!`875T:&]R("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R
M9SX*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!A
M=71H;W(@($1A;6EA;B!!;&5J86YD<F\@1F5R;F%N9&5Z(%-O<V$@/&1A;6QI
M<W1S0&-N8F$N=6)A+F%R/@H@*@H@*B!`97AA;7!L92!B87-I8RYP:'`@("!!
M(&)A<VEC(&EM<&QE;65N=&%T:6]N(&]F('1H92!.971?4TU44"!P86-K86=E
M+@H@*B\*8VQA<W,@3F5T7U--5%`*>PH@("`@+RHJ"B`@("`@*B!4:&4@<V5R
M=F5R('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1H;W-T(#T@)VQO8V%L
M:&]S="<["@H@("`@+RHJ"B`@("`@*B!4:&4@<&]R="!T;R!C;VYN96-T('1O
M+@H@("`@("H@0'9A<B!I;G0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@('9A<B`D<&]R="`](#(U.PH*("`@("\J*@H@("`@("H@5&AE('9A
M;'5E('1O(&=I=F4@=VAE;B!S96YD:6YG($5(3$\@;W(@2$5,3RX*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!V87(@)&QO8V%L:&]S="`]("=L;V-A;&AO<W0G.PH*("`@("\J*@H@("`@
M("H@3&ES="!O9B!S=7!P;W)T960@875T:&5N=&EC871I;VX@;65T:&]D<RP@
M:6X@<')E9F5R96YT:6%L(&]R9&5R+@H@("`@("H@0'9A<B!A<G)A>0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@=F%R("1A=71H7VUE=&AO
M9',@/2!A<G)A>2@G1$E'15-4+4U$-2<L("=#4D%-+4U$-2<L("=,3T=)3B<L
M("=03$%)3B<I.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&1E8G5G9VEN9R!O
M=71P=70@8F4@96YA8FQE9#\*("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1E8G5G(#T@9F%L
M<V4["@H@("`@+RHJ"B`@("`@*B!4:&4@<V]C:V5T(')E<V]U<F-E(&)E:6YG
M('5S960@=&\@8V]N;F5C="!T;R!T:&4@4TU44"!S97)V97(N"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?<V]C:V5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!M
M;W-T(')E8V5N="!S97)V97(@<F5S<&]N<V4@8V]D92X*("`@("`J($!V87(@
M:6YT"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M8V]D92`]("TQ.PH*("`@("\J*@H@("`@("H@5&AE(&UO<W0@<F5C96YT('-E
M<G9E<B!R97-P;VYS92!A<F=U;65N=',N"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?87)G=6UE
M;G1S(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J(%-T;W)E<R!D971E8W1E
M9"!F96%T=7)E<R!O9B!T:&4@4TU44"!S97)V97(N"B`@("`@*B!`=F%R(&%R
M<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M97-M='`@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@26YS=&%N=&EA=&5S
M(&$@;F5W($YE=%]33510(&]B:F5C="P@;W9E<G)I9&EN9R!A;GD@9&5F875L
M=',*("`@("`J('=I=&@@<&%R86UE=&5R<R!T:&%T(&%R92!P87-S960@:6XN
M"B`@("`@*@H@("`@("H@268@>6]U(&AA=F4@4U-,('-U<'!O<G0@:6X@4$A0
M+"!Y;W4@8V%N(&-O;FYE8W0@=&\@82!S97)V97(*("`@("`J(&]V97(@4U-,
M('5S:6YG(&%N("=S<VPZ+R\G('!R969I>#H*("`@("`J"B`@("`@*B`@("\O
M(#0V-2!I<R!A(&-O;6UO;B!S;71P<R!P;W)T+@H@("`@("H@("`D<VUT<"`]
M(&YE=R!.971?4TU44"@G<W-L.B\O;6%I;"YH;W-T+F-O;2<L(#0V-2D["B`@
M("`@*B`@("1S;71P+3YC;VYN96-T*"D["B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&AO<W0@("`@("`@5&AE('-E<G9E<B!T;R!C;VYN96-T('1O
M+@H@("`@("H@0'!A<F%M(&EN=&5G97(@)'!O<G0@("`@("`@5&AE('!O<G0@
M=&\@8V]N;F5C="!T;RX*("`@("`J($!P87)A;2!S=')I;F<@("1L;V-A;&AO
M<W0@(%1H92!V86QU92!T;R!G:79E('=H96X@<V5N9&EN9R!%2$Q/(&]R($A%
M3$\N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN
M8V4@("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@3F5T7U--5%`H)&AO<W0@
M/2!N=6QL+"`D<&]R="`](&YU;&PL("1L;V-A;&AO<W0@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D:&]S="DI("1T:&ES+3YH;W-T(#T@)&AO
M<W0["B`@("`@("`@:68@*&ES<V5T*"1P;W)T*2D@)'1H:7,M/G!O<G0@/2`D
M<&]R=#L*("`@("`@("!I9B`H:7-S970H)&QO8V%L:&]S="DI("1T:&ES+3YL
M;V-A;&AO<W0@/2`D;&]C86QH;W-T.PH*("`@("`@("`D=&AI<RT^7W-O8VME
M="`]("9N97<@3F5T7U-O8VME="@I.PH*("`@("`@("`O*@H@("`@("`@("`J
M($EN8VQU9&4@=&AE($%U=&A?4T%33"!P86-K86=E+B`@268@=&AE('!A8VMA
M9V4@:7,@;F]T(&%V86EL86)L92P*("`@("`@("`@*B!W92!D:7-A8FQE('1H
M92!A=71H96YT:6-A=&EO;B!M971H;V1S('1H870@9&5P96YD('5P;VX@:70N
M"B`@("`@("`@("HO"B`@("`@("`@:68@*"A`:6YC;'5D95]O;F-E("=!=71H
M+U-!4TPN<&AP)RD@/3T](&9A;'-E*2!["B`@("`@("`@("`@("1P;W,@/2!A
M<G)A>5]S96%R8V@H)T1)1T535"U-1#4G+"`D=&AI<RT^875T:%]M971H;V1S
M*3L*("`@("`@("`@("`@=6YS970H)'1H:7,M/F%U=&A?;65T:&]D<ULD<&]S
M72D["B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R8V@H)T-204TM340U
M)RP@)'1H:7,M/F%U=&A?;65T:&]D<RD["B`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3YA=71H7VUE=&AO9'-;)'!O<UTI.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!T:&4@=F%L=64@;V8@=&AE(&1E8G5G9VEN9R!F
M;&%G+@H@("`@("H*("`@("`J($!P87)A;2`@(&)O;VQE86X@)&1E8G5G("`@
M("`@3F5W('9A;'5E(&9O<B!T:&4@9&5B=6=G:6YG(&9L86<N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!S971$96)U9R@D9&5B=6<I"B`@("!["B`@
M("`@("`@)'1H:7,M/E]D96)U9R`]("1D96)U9SL*("`@('T*"B`@("`O*BH*
M("`@("`J(%-E;F0@=&AE(&=I=F5N('-T<FEN9R!O9B!D871A('1O('1H92!S
M97)V97(N"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&%T82`@
M("`@("!4:&4@<W1R:6YG(&]F(&1A=&$@=&\@<V5N9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N("!M:7AE9"`@(%1R=64@;VX@<W5C8V5S<R!O<B!A(%!%05)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<')I=F%T90H@("`@("H@0'-I;F-E("`@,2XQ+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E;F0H)&1A=&$I"B`@("!["B`@("`@("`@:68@*"1T:&ES
M+3Y?9&5B=6<I('L*("`@("`@("`@("`@96-H;R`B1$5"54<Z(%-E;F0Z("1D
M871A7&XB.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<F]R(#T@)'1H:7,M/E]S;V-K970M/G=R:71E*"1D871A*2DI('L*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!W
M<FET92!T;R!S;V-K970Z("<@+@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D97)R;W(M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M;F0@82!C;VUM86YD('1O('1H92!S97)V97(@=VET:"!A;B!O<'1I;VYA;"!S
M=')I;F<@;V8*("`@("`J(&%R9W5M96YT<RX@($$@8V%R<FEA9V4@<F5T=7)N
M("\@;&EN969E960@*$-23$8I('-E<75E;F-E('=I;&P*("`@("`J(&)E(&%P
M<&5N9&5D('1O(&5A8V@@8V]M;6%N9"!S=')I;F<@8F5F;W)E(&ET(&ES('-E
M;G0@=&\@=&AE"B`@("`@*B!33510('-E<G9E<B`M(&%N(&5R<F]R('=I;&P@
M8F4@=&AR;W=N(&EF('1H92!C;VUM86YD('-T<FEN9PH@("`@("H@86QR96%D
M>2!C;VYT86EN<R!A;GD@;F5W;&EN92!C:&%R86-T97)S+B!5<V4@7W-E;F0H
M*2!F;W(*("`@("`J(&-O;6UA;F1S('1H870@;75S="!C;VYT86EN(&YE=VQI
M;F5S+@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@)&-O;6UA;F0@
M("`@5&AE(%--5%`@8V]M;6%N9"!T;R!S96YD('1O('1H92!S97)V97(N"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("1A<F=S("`@("`@($$@<W1R:6YG(&]F
M(&]P=&EO;F%L(&%R9W5M96YT<R!T;R!A<'!E;F0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@=&AE(&-O;6UA;F0N"B`@("`@*@H@
M("`@("H@0')E='5R;B`@;6EX960@("!4:&4@<F5S=6QT(&]F('1H92!?<V5N
M9"@I(&-A;&PN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@
M("H@0'-I;F-E("`@,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7W!U="@D
M8V]M;6%N9"P@)&%R9W,@/2`G)RD*("`@('L*("`@("`@("!I9B`H(65M<'1Y
M*"1A<F=S*2D@>PH@("`@("`@("`@("`D8V]M;6%N9"`N/2`G("<@+B`D87)G
M<SL*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C<W!N*"1C;VUM86YD+"`B
M7')<;B(I("$]/2!S=')L96XH)&-O;6UA;F0I*2!["B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=#;VUM86YD<R!C86YN;W0@8V]N=&%I
M;B!N97=L:6YE<R<I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<V5N9"@D8V]M;6%N9"`N(")<<EQN(BD["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!296%D(&$@<F5P;'D@9G)O;2!T:&4@4TU44"!S97)V97(N("!4:&4@
M<F5P;'D@8V]N<VES=',@;V8@82!R97-P;VYS90H@("`@("H@8V]D92!A;F0@
M82!R97-P;VYS92!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2`@(&UI
M>&5D("`@)'9A;&ED("`@("`@5&AE('-E="!O9B!V86QI9"!R97-P;VYS92!C
M;V1E<RX@(%1H97-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&UA>2!B92!S<&5C:69I960@87,@86X@87)R87D@;V8@:6YT96=E<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!V86QU97,@;W(@
M87,@82!S:6YG;&4@:6YT96=E<B!V86QU92X*("`@("`J"B`@("`@*B!`<F5T
M=7)N("!M:7AE9"`@(%1R=64@:68@=&AE('-E<G9E<B!R971U<FYE9"!A('9A
M;&ED(')E<W!O;G-E(&-O9&4@;W(*("`@("`J("`@("`@("`@("`@("`@("`@
M82!014%27T5R<F]R(&]B:F5C="!I<R!A;B!E<G)O<B!C;VYD:71I;VX@:7,@
M<F5A8VAE9"X*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@
M*B!`<VEN8V4@("`Q+C$N,`H@("`@("H*("`@("`J($!S964@("`@(&=E=%)E
M<W!O;G-E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95)E<W!O;G-E*"1V
M86QI9"D*("`@('L*("`@("`@("`D=&AI<RT^7V-O9&4@/2`M,3L*("`@("`@
M("`D=&AI<RT^7V%R9W5M96YT<R`](&%R<F%Y*"D["@H@("`@("`@('=H:6QE
M("@D;&EN92`]("1T:&ES+3Y?<V]C:V5T+3YR96%D3&EN92@I*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V1E8G5G*2!["B`@("`@("`@("`@("`@("!E
M8VAO(")$14)51SH@4F5C=CH@)&QI;F5<;B(["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("\J($EF('=E(')E8V5I=F4@86X@96UP='D@;&EN92P@=&AE
M(&-O;FYE8W1I;VX@:&%S(&)E96X@8VQO<V5D+B`J+PH@("`@("`@("`@("!I
M9B`H96UP='DH)&QI;F4I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^9&ES
M8V]N;F5C="@I.PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)T-O;FYE8W1I;VX@=V%S('5N97AP96-T961L>2!C;&]S960G*3L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4F5A9"!T:&4@8V]D92!A
M;F0@<W1O<F4@=&AE(')E<W0@:6X@=&AE(&%R9W5M96YT<R!A<G)A>2X@*B\*
M("`@("`@("`@("`@)&-O9&4@/2!S=6)S='(H)&QI;F4L(#`L(#,I.PH@("`@
M("`@("`@("`D=&AI<RT^7V%R9W5M96YT<UM=(#T@=')I;2AS=6)S='(H)&QI
M;F4L(#0I*3L*"B`@("`@("`@("`@("\J($-H96-K('1H92!S>6YT87@@;V8@
M=&AE(')E<W!O;G-E(&-O9&4N("HO"B`@("`@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1C;V1E*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;V1E(#T@
M*&EN="DD8V]D93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8V]D92`]("TQ.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($EF('1H:7,@:7,@;F]T
M(&$@;75L=&EL:6YE(')E<W!O;G-E+"!W92=R92!D;VYE+B`J+PH@("`@("`@
M("`@("!I9B`H<W5B<W1R*"1L:6YE+"`S+"`Q*2`A/2`G+2<I('L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("`O*B!#;VUP87)E('1H92!S97)V97(G<R!R97-P;VYS92!C;V1E('=I
M=&@@=&AE('9A;&ED(&-O9&4N("HO"B`@("`@("`@:68@*&ES7VEN="@D=F%L
M:60I("8F("@D=&AI<RT^7V-O9&4@/3T]("1V86QI9"DI('L*("`@("`@("`@
M("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!W
M97)E(&=I=F5N(&%N(&%R<F%Y(&]F('9A;&ED(')E<W!O;G-E(&-O9&5S+"!C
M:&5C:R!E86-H(&]N92X@*B\*("`@("`@("!I9B`H:7-?87)R87DH)'9A;&ED
M*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D=F%L:60@87,@)'9A;&ED7V-O
M9&4I('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O9&4@/3T]("1V
M86QI9%]C;V1E*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(')E<W!O
M;G-E(&-O9&4@<F5C96EV960@9G)O;2!S97)V97(G*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;B!A(#(M='5P;&4@8V]N=&%I;FEN9R!T:&4@;&%S
M="!R97-P;VYS92!F<F]M('1H92!33510('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N("!A<G)A>2`@($$@='=O+65L96UE;G0@87)R87DZ('1H92!F
M:7)S="!E;&5M96YT(&-O;G1A:6YS('1H90H@("`@("H@("`@("`@("`@("`@
M("`@("!R97-P;VYS92!C;V1E(&%S(&%N(&EN=&5G97(@86YD('1H92!S96-O
M;F0@96QE;65N=`H@("`@("H@("`@("`@("`@("`@("`@("!C;VYT86EN<R!T
M:&4@<F5S<&]N<V4G<R!A<F=U;65N=',@87,@82!S=')I;F<N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("`Q+C$N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS92@I"B`@("!["B`@("`@
M("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3Y?8V]D92P@:F]I;B@B7&XB+"`D=&AI
M<RT^7V%R9W5M96YT<RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@071T96UP
M="!T;R!C;VYN96-T('1O('1H92!33510('-E<G9E<BX*("`@("`J"B`@("`@
M*B!`<&%R86T@("!I;G0@("`@("1T:6UE;W5T("`@(%1H92!T:6UE;W5T('9A
M;'5E("AI;B!S96-O;F1S*2!F;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-O8VME="!C;VYN96-T:6]N+@H@("`@("H@0'!A
M<F%M("`@8F]O;"`@("`D<&5R<VES=&5N="!3:&]U;&0@82!P97)S:7-T96YT
M('-O8VME="!C;VYN96-T:6]N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)E('5S960_"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@
M;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@
M;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H
M)'1I;65O=70@/2!N=6QL+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W-O8VME="T^8V]N;F5C="@D=&AI
M<RT^:&]S="P@)'1H:7,M/G!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P97)S:7-T96YT+"`D=&EM96]U="D["B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!C;VYN96-T
M('-O8VME=#H@)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97-U;'0M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S
M<&]N<V4H,C(P*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]N96=O=&EA=&4H*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@071T96UP="!T;R!D:7-C;VYN96-T(&9R;VT@=&AE(%--
M5%`@<V5R=F5R+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N
M<R!A(%!%05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@
M("`@("H@("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@
M;VX@<W5C8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN
M8V4@(#$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@
M('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@G455)5"<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@
M("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C(Q*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&5R<F]R(#T@)'1H:7,M/E]S;V-K970M/F1I<V-O;FYE8W0H*2DI('L*
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T
M;R!D:7-C;VYN96-T('-O8VME=#H@)R`N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1E<G)O<BT^9V5T365S<V%G92@I*3L*("`@("`@
M("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@071T96UP="!T;R!S96YD('1H92!%2$Q/(&-O;6UA;F0@86YD(&]B=&%I
M;B!A(&QI<W0@;V8@15--5%`*("`@("`J(&5X=&5N<VEO;G,@879A:6QA8FQE
M+"!A;F0@9F%I;&EN9R!T:&%T(&IU<W0@<V5N9"!(14Q/+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A
M;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K
M:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@
M("`J+PH@("`@9G5N8W1I;VX@7VYE9V]T:6%T92@I"B`@("!["B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)T5(3$\G
M+"`D=&AI<RT^;&]C86QH;W-T*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E
M<G)O<CL*("`@("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T
M:&ES+3Y?<&%R<V5297-P;VYS92@R-3`I*2D@>PH@("`@("`@("`@("`O*B!)
M9B!W92!R96-E:79E(&$@-3`S(')E<W!O;G-E+"!W92=R92!A;')E861Y(&%U
M=&AE;G1I8V%T960N("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O9&4@
M/3T](#4P,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("\J($EF('1H92!%2$Q/(&9A:6QE9"P@
M=')Y('1H92!S:6UP;&5R($A%3$\@8V]M;6%N9"X@*B\*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)TA%3$\G
M+"`D=&AI<RT^;&]C86QH;W-T*2DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G2$5,3R!W87,@
M;F]T(&%C8V5P=&5D.B`G+"`D=&AI<RT^7V-O9&4I.PH@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?87)G=6UE;G1S(&%S("1A<F=U;65N="D@>PH@
M("`@("`@("`@("`D=F5R8B`]('-T<G1O:R@D87)G=6UE;G0L("<@)RD["B`@
M("`@("`@("`@("1A<F=U;65N=',@/2!S=6)S='(H)&%R9W5M96YT+"!S=')L
M96XH)'9E<F(I("L@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!S=')L96XH)&%R9W5M96YT*2`M('-T<FQE;B@D=F5R8BD@+2`Q*3L*("`@
M("`@("`@("`@)'1H:7,M/E]E<VUT<%LD=F5R8ET@/2`D87)G=6UE;G1S.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!N86UE(&]F('1H92!B97-T(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"!T:&%T('1H92!S97)V97(*("`@("`J(&AA<R!A9'9E
M<G1I<V5D+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@("`@4F5T=7)N
M<R!A('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F('1H92!B97-T"B`@
M("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G1E9"!A=71H96YT:6-A=&EO
M;B!M971H;V0@;W(@82!014%27T5R<F]R(&]B:F5C=`H@("`@("H@("`@("`@
M("`@("`@("`@("!I9B!A(&9A:6QU<F4@8V]N9&ET:6]N(&ES(&5N8V]U;G1E
M<F5D+@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<VEN8V4@(#$N
M,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971"97-T075T:$UE=&AO9"@I
M"B`@("!["B`@("`@("`@)&%V86EL86)L95]M971H;V1S(#T@97AP;&]D92@G
M("<L("1T:&ES+3Y?97-M='!;)T%55$@G72D["@H@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YA=71H7VUE=&AO9',@87,@)&UE=&AO9"D@>PH@("`@("`@("`@
M("!I9B`H:6Y?87)R87DH)&UE=&AO9"P@)&%V86EL86)L95]M971H;V1S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1M971H;V0["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*"=.;R!S=7!P;W)T960@875T:&5N=&EC871I;VX@;65T:&]D<R<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@071T96UP="!T;R!D;R!33510(&%U=&AE;G1I
M8V%T:6]N+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I
M9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H
M92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J($!P87)A
M;2!S=')I;F<@5&AE(')E<75E<W1E9"!A=71H96YT:6-A=&EO;B!M971H;V0N
M("!)9B!N;VYE(&ES"B`@("`@*B`@("`@("`@("`@("`@('-P96-I9FEE9"P@
M=&AE(&)E<W0@<W5P<&]R=&5D(&UE=&AO9"!W:6QL(&)E('5S960N"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W
M:71H(&%N(&5R<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@
M("`@(&MI;F0@;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%U=&@H)'5I9"P@)'!W9"`L("1M971H;V0@/2`G)RD*
M("`@('L*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]E<VUT<%LG05542"==
M*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4TU4
M4"!S97)V97(@9&]E<R!N;R!S=7!P;W)T(&%U=&AE;G1I8V%T:6]N)RD["B`@
M("`@("`@?0H*("`@("`@("`O*B!)9B!N;R!M971H;V0@:&%S(&)E96X@<W!E
M8VEF:65D+"!G970@=&AE(&YA;64@;V8@=&AE(&)E<W0*("`@("`@("`@*B!S
M=7!P;W)T960@;65T:&]D(&%D=F5R=&ES960@8GD@=&AE(%--5%`@<V5R=F5R
M+B`J+PH@("`@("`@(&EF("AE;7!T>2@D;65T:&]D*2D@>PH@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D;65T:&]D(#T@)'1H:7,M/E]G971"97-T
M075T:$UE=&AO9"@I*2D@>PH@("`@("`@("`@("`@("`@+RH@4F5T=7)N('1H
M92!014%27T5R<F]R(&]B:F5C="!F<F]M(%]G971"97-T075T:$UE=&AO9"@I
M+B`J+PH@("`@("`@("`@("`@("`@<F5T=7)N("1M971H;V0["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;65T:&]D(#T@
M<W1R=&]U<'!E<B@D;65T:&]D*3L*("`@("`@("`@("`@:68@*"%I;E]A<G)A
M>2@D;65T:&]D+"`D=&AI<RT^875T:%]M971H;V1S*2D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(B1M971H;V0@:7,@;F]T
M(&$@<W5P<&]R=&5D(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"(I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("!S=VET8V@@*"1M971H;V0I('L*
M("`@("`@("`@("`@8V%S92`G1$E'15-4+4U$-2<Z"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/E]A=71H1&EG97-T7TU$-2@D=6ED+"`D<'=D
M*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=#
M4D%-+4U$-2<Z"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]A
M=71H0U)!35]-1#4H)'5I9"P@)'!W9"D["B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@8V%S92`G3$]'24XG.@H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?875T:$QO9VEN*"1U:60L("1P=V0I.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@)U!,04E.)SH*
M("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V%U=&A0;&%I;B@D
M=6ED+"`D<'=D*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!D969A=6QT.@H@("`@("`@("`@("`@("`@)')E<W5L="`](%!%05(Z.G)A
M:7-E17)R;W(H(B1M971H;V0@:7,@;F]T(&$@<W5P<&]R=&5D(&%U=&AE;G1I
M8V%T:6]N(&UE=&AO9"(I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@?0H*("`@("`@("`O*B!)9B!A;B!E<G)O<B!W87,@96YC;W5N=&5R960L
M(')E='5R;B!T:&4@4$5!4E]%<G)O<B!O8FIE8W0N("HO"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M("1R97-U;'0["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($%U=&AE;G1I8V%T97,@=&AE('5S97(@=7-I
M;F<@=&AE($1)1T535"U-1#4@;65T:&]D+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@5&AE('5S97)I9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@
M*B!`<&%R86T@<W1R:6YG(%1H92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@
M=VET:"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!0
M14%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J
M("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U
M8V-E<W,N"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!S:6YC92`@
M,2XQ+C`*("`@("`J+PH@("`@9G5N8W1I;VX@7V%U=&A$:6=E<W1?340U*"1U
M:60L("1P=V0I"B`@("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<F]R(#T@)'1H:7,M/E]P=70H)T%55$@G+"`G1$E'15-4+4U$-2<I*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("`O
M*B`S,S0Z($-O;G1I;G5E(&%U=&AE;G1I8V%T:6]N(')E<75E<W0@*B\*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E
M4F5S<&]N<V4H,S,T*2DI('L*("`@("`@("`@("`@+RH@-3`S.B!%<G)O<CH@
M86QR96%D>2!A=71H96YT:6-A=&5D("HO"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^7V-O9&4@/3T](#4P,RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("!]"@H@("`@("`@("1C:&%L;&5N9V4@/2!B87-E-C1?9&5C;V1E
M*"1T:&ES+3Y?87)G=6UE;G1S6S!=*3L*("`@("`@("`D9&EG97-T(#T@)D%U
M=&A?4T%33#HZ9F%C=&]R>2@G9&EG97-T;60U)RD["B`@("`@("`@)&%U=&A?
M<W1R(#T@8F%S938T7V5N8V]D92@D9&EG97-T+3YG971297-P;VYS92@D=6ED
M+"`D<'=D+"`D8VAA;&QE;F=E+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO<W0L(")S
M;71P(BDI.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D
M=&AI<RT^7W!U="@D875T:%]S='(I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*("`@("`@("`O*B`S,S0Z($-O;G1I;G5E(&%U
M=&AE;G1I8V%T:6]N(')E<75E<W0@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,S,T*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@
M("\J(%=E(&1O;B=T('5S92!T:&4@<')O=&]C;VPG<R!T:&ER9"!S=&5P(&)E
M8V%U<V4@4TU44"!D;V5S;B=T"B`@("`@("`@("H@86QL;W<@<W5B<V5Q=65N
M="!A=71H96YT:6-A=&EO;BP@<V\@=V4@:G5S="!S:6QE;G1L>2!I9VYO<F4*
M("`@("`@("`@*B!I="X@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R;W(@/2`D=&AI<RT^7W!U="@G("<I*2D@>PH@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("`O*B`R,S4Z($%U=&AE;G1I
M8V%T:6]N('-U8V-E<W-F=6P@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C,U*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!=71H96YT:6-A=&5S('1H92!U<V5R('5S:6YG('1H92!#
M4D%-+4U$-2!M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4
M:&4@=7-E<FED('1O(&%U=&AE;G1I8V%T92!A<RX*("`@("`J($!P87)A;2!S
M=')I;F<@5&AE('!A<W-W;W)D('1O(&%U=&AE;G1I8V%T92!W:71H+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@
M=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@
M("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'-I;F-E("`Q+C$N,`H@("`@
M("HO"B`@("!F=6YC=&EO;B!?875T:$-204U?340U*"1U:60L("1P=V0I"B`@
M("!["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M
M/E]P=70H)T%55$@G+"`G0U)!32U-1#4G*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@+RH@,S,T.B!#;VYT:6YU
M92!A=71H96YT:6-A=&EO;B!R97%U97-T("HO"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#,S-"DI
M*2!["B`@("`@("`@("`@("\J(#4P,SH@17)R;W(Z(&%L<F5A9'D@875T:&5N
M=&EC871E9"`J+PH@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;V1E(#T]/2`U
M,#,I('L*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@
M("`@("`D8VAA;&QE;F=E(#T@8F%S938T7V1E8V]D92@D=&AI<RT^7V%R9W5M
M96YT<ULP72D["B`@("`@("`@)&-R86T@/2`F075T:%]305-,.CIF86-T;W)Y
M*"=C<F%M;60U)RD["B`@("`@("`@)&%U=&A?<W1R(#T@8F%S938T7V5N8V]D
M92@D8W)A;2T^9V5T4F5S<&]N<V4H)'5I9"P@)'!W9"P@)&-H86QL96YG92DI
M.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!U="@D875T:%]S='(I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R
M.PH@("`@("`@('T*"B`@("`@("`@+RH@,C,U.B!!=71H96YT:6-A=&EO;B!S
M=6-C97-S9G5L("HO"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R
M(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(S-2DI*2!["B`@("`@("`@("`@
M(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@075T:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@3$]'24X@;65T
M:&]D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I9"!T
M;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!P
M87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R
M;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O
M9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V%U=&A,;V=I;B@D=6ED+"`D<'=D*0H@("`@>PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=!551()RP@
M)TQ/1TE.)RDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I;VX@
M<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]
M("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@("`O
M*B`U,#,Z($5R<F]R.B!A;')E861Y(&%U=&AE;G1I8V%T960@*B\*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R
M971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H8F%S938T7V5N8V]D92@D=6ED
M*2DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H@
M("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I;VX@<F5Q=65S
M="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES
M+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<F]R(#T@)'1H:7,M/E]P=70H8F%S938T7V5N8V]D92@D<'=D*2DI*2![
M"B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@
M("`O*B`R,S4Z($%U=&AE;G1I8V%T:6]N('-U8V-E<W-F=6P@*B\*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S
M<&]N<V4H,C,U*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@075T:&5N=&EC871E<R!T:&4@=7-E<B!U<VEN9R!T:&4@4$Q!24X@
M;65T:&]D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE('5S97)I
M9"!T;R!A=71H96YT:6-A=&4@87,N"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H
M92!P87-S=V]R9"!T;R!A=71H96YT:6-A=&4@=VET:"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@
M97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN
M9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!S:6YC92`@,2XQ+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V%U=&A0;&%I;B@D=6ED+"`D<'=D*0H@("`@>PH@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES+3Y?<'5T*"=!551(
M)RP@)U!,04E.)RDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H@("`@("`@("\J(#,S-#H@0V]N=&EN=64@875T:&5N=&EC871I
M;VX@<F5Q=65S="`J+PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O
M<B`]("1T:&ES+3Y?<&%R<V5297-P;VYS92@S,S0I*2D@>PH@("`@("`@("`@
M("`O*B`U,#,Z($5R<F]R.B!A;')E861Y(&%U=&AE;G1I8V%T960@*B\*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?8V]D92`]/3T@-3`S*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@)&%U=&A?<W1R
M(#T@8F%S938T7V5N8V]D92AC:'(H,"D@+B`D=6ED("X@8VAR*#`I("X@)'!W
M9"D["@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES
M+3Y?<'5T*"1A=71H7W-T<BDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H*("`@("`@("`O*B`R,S4Z($%U=&AE;G1I8V%T:6]N
M('-U8V-E<W-F=6P@*B\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C,U*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@2$5,3R!C;VUM
M86YD+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@5&AE(&1O;6%I;B!N
M86UE('1O('-A>2!W92!A<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@
M;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@
M;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&AE;&\H)&1O
M;6%I;BD*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@
M/2`D=&AI<RT^7W!U="@G2$5,3R<L("1D;VUA:6XI*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E4F5S<&]N<V4H,C4P*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T
M:&4@34%)3"!&4D]-.B!C;VUM86YD+@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'-E;F1E<B`@("!4:&4@<V5N9&5R("AR979E<G-E('!A=&@I('1O
M('-E="X*("`@("`J($!P87)A;2!S=')I;F<@)'!A<F%M<R`@("!3=')I;F<@
M8V]N=&%I;FEN9R!A9&1I=&EO;F%L($U!24P@<&%R86UE=&5R<RP*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("!S=6-H(&%S('1H92!.3U1)1ED@
M9FQA9W,@9&5F:6YE9"!B>2!21D,@,3@Y,0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&]R('1H92!615)0('!R;W1O8V]L+@H@("`@("H*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!)9B`D<&%R86US(&ES(&%N
M(&%R<F%Y+"!O;FQY('1H92`G=F5R<"<@;W!T:6]N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@:7,@<W5P<&]R=&5D+B`@268@)W9E<G`G(&ES
M('1R=64L('1H92!85D524`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<F%M971E<B!I<R!A<'!E;F1E9"!T;R!T:&4@34%)3"!C;VUM86YD
M+B`@268*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@)W9E
M<G`G('9A;'5E(&ES(&$@<W1R:6YG+"!T:&4@9G5L;`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A615)0/79A;'5E('!A<F%M971E<B!I<R!A
M<'!E;F1E9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@
M82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@
M("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N
M('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E
M("`Q+C`*("`@("`J+PH@("`@9G5N8W1I;VX@;6%I;$9R;VTH)'-E;F1E<BP@
M)'!A<F%M<R`](&YU;&PI"B`@("!["B`@("`@("`@)&%R9W,@/2`B1E)/33H\
M)'-E;F1E<CXB.PH*("`@("`@("`O*B!3=7!P;W)T('1H92!D97!R96-A=&5D
M(&%R<F%Y(&9O<FT@;V8@)'!A<F%M<RX@*B\*("`@("`@("!I9B`H:7-?87)R
M87DH)'!A<F%M<RD@)B8@:7-S970H)'!A<F%M<ULG=F5R<"==*2D@>PH@("`@
M("`@("`@("`O*B!85D524"`J+PH@("`@("`@("`@("!I9B`H)'!A<F%M<ULG
M=F5R<"==(#T]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D87)G<R`N/2`G
M(%A615)0)SL*"B`@("`@("`@("`@("\J(%A615)0/7-O;65T:&EN9R`J+PH@
M("`@("`@("`@("!](&5L<V5I9B`H=')I;2@D<&%R86US6R=V97)P)UTI*2![
M"B`@("`@("`@("`@("`@("`D87)G<R`N/2`G(%A615)0/2<@+B`D<&%R86US
M6R=V97)P)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?
M<W1R:6YG*"1P87)A;7,I*2!["B`@("`@("`@("`@("1A<F=S("X]("<@)R`N
M("1P87)A;7,["B`@("`@("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G34%)3"<L("1A<F=S*2DI('L*("`@
M("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E
M*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E;F0@=&AE(%)#4%0@5$\Z(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D<F5C:7!I96YT(%1H92!R96-I<&EE;G0@*&9O<G=A<F0@
M<&%T:"D@=&\@861D+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%R86US("`@
M(%-T<FEN9R!C;VYT86EN:6YG(&%D9&ET:6]N86P@4D-05"!P87)A;65T97)S
M+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@('-U8V@@87,@=&AE
M($Y/5$E&62!F;&%G<R!D969I;F5D(&)Y(%)&0R`Q.#DQ+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@=VET:"!A
M;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@("`@("!K
M:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F-P=%1O*"1R96-I<&EE;G0L("1P87)A;7,@/2!N
M=6QL*0H@("`@>PH@("`@("`@("1A<F=S(#T@(E1/.CPD<F5C:7!I96YT/B([
M"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<&%R86US*2D@>PH@("`@("`@("`@
M("`D87)G<R`N/2`G("<@+B`D<&%R86US.PH@("`@("`@('T*"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)U)#4%0G
M+"`D87)G<RDI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G)O<B`]("1T:&ES
M+3Y?<&%R<V5297-P;VYS92AA<G)A>2@R-3`L(#(U,2DI*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!1=6]T92!T:&4@9&%T82!S
M;R!T:&%T(&ET(&UE971S(%--5%`@<W1A;F1A<F1S+@H@("`@("H*("`@("`J
M(%1H:7,@:7,@<')O=FED960@87,@82!S97!A<F%T92!P=6)L:6,@9G5N8W1I
M;VX@=&\@9F%C:6QI=&%T90H@("`@("H@96%S:65R(&]V97)L;V%D:6YG(&9O
M<B!T:&4@8V%S97,@=VAE<F4@:70@:7,@9&5S:7)A8FQE('1O"B`@("`@*B!C
M=7-T;VUI>F4@=&AE('%U;W1I;F<@8F5H879I;W(N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9&%T82`@5&AE(&UE<W-A9V4@=&5X="!T;R!Q=6]T
M92X@5&AE('-T<FEN9R!M=7-T(&)E('!A<W-E9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@8GD@<F5F97)E;F-E+"!A;F0@=&AE('1E>'0@=VEL;"!B
M92!M;V1I9FEE9"!I;B!P;&%C92X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E("`Q+C(*("`@("`J+PH@("`@9G5N8W1I;VX@
M<75O=&5D871A*"8D9&%T82D*("`@('L*("`@("`@("`O*B!#:&%N9V4@56YI
M>"`H7&XI(&%N9"!-86,@*%QR*2!L:6YE9F5E9',@:6YT;PH@("`@("`@("`J
M($EN=&5R;F5T+7-T86YD87)D($-23$8@*%QR7&XI(&QI;F5F965D<RX@*B\*
M("`@("`@("`D9&%T82`]('!R96=?<F5P;&%C92AA<G)A>2@G+R@_/"%<<BE<
M;B\G+"<O7'(H/R%<;BDO)RDL(")<<EQN(BP@)&1A=&$I.PH*("`@("`@("`O
M*B!"96-A=7-E(&$@<VEN9VQE(&QE861I;F<@<&5R:6]D("@N*2!S:6=N:69I
M97,@86X@96YD('1O('1H90H@("`@("`@("`J(&1A=&$L(&QE9VET:6UA=&4@
M;&5A9&EN9R!P97)I;V1S(&YE960@=&\@8F4@(F1O=6)L960B"B`@("`@("`@
M("H@*&4N9RX@)RXN)RDN("HO"B`@("`@("`@)&1A=&$@/2!S=')?<F5P;&%C
M92@B7&XN(BP@(EQN+BXB+"`D9&%T82D["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!396YD('1H92!$051!(&-O;6UA;F0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D9&%T82`@5&AE(&UE<W-A9V4@8F]D>2!T;R!S96YD+@H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%05)?17)R;W(@
M=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@("`@("`@("`@
M("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C8V5S<RX*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!D871A*"1D871A*0H@("`@>PH@("`@("`@("\J(%)&
M0R`Q.#<P+"!S96-T:6]N(#,L('-U8G-E8W1I;VX@,R!S=&%T97,@(F$@=F%L
M=64@;V8@>F5R;PH@("`@("`@("`J(&EN9&EC871E<R!T:&%T(&YO(&9I>&5D
M(&UA>&EM=6T@;65S<V%G92!S:7IE(&ES(&EN(&9O<F-E(BX*("`@("`@("`@
M*B!&=7)T:&5R;6]R92P@:70@<V%Y<R!T:&%T(&EF(")T:&4@<&%R86UE=&5R
M(&ES(&]M:71T960@;F\*("`@("`@("`@*B!I;F9O<FUA=&EO;B!I<R!C;VYV
M97EE9"!A8F]U="!T:&4@<V5R=F5R)W,@9FEX960@;6%X:6UU;0H@("`@("`@
M("`J(&UE<W-A9V4@<VEZ92(N("HO"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?97-M='!;)U-)6D4G72D@)B8@*"1T:&ES+3Y?97-M='!;)U-)6D4G72`^
M(#`I*2!["B`@("`@("`@("`@(&EF("AS=')L96XH)&1A=&$I(#X]("1T:&ES
M+3Y?97-M='!;)U-)6D4G72D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1I
M<V-O;FYE8W0H*3L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=-97-S86=E('-I>F4@97AC961E<R!T:&4@<V5R=F5R(&QI;6ET
M)RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\J(%%U;W1E
M('1H92!D871A(&)A<V5D(&]N('1H92!33510('-T86YD87)D<RX@*B\*("`@
M("`@("`D=&AI<RT^<75O=&5D871A*"1D871A*3L*"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)T1!5$$G*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O
M;G-E*#,U-"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT(#T@)'1H
M:7,M/E]S96YD*"1D871A("X@(EQR7&XN7')<;B(I*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI
M*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@
M=&AE(%-%3D0@1E)/33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@
M97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN
M9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C(N-@H@("`@("HO"B`@("!F
M=6YC=&EO;B!S96YD1G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G4T5.1"<L(")&4D]-
M.CPD<&%T:#XB*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@
M("`@("!]"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H
M:7,M/E]P87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($)A8VMW87)D<RUC;VUP871I8FEL:71Y('=R
M87!P97(@9F]R('-E;F1&<F]M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R!4:&4@<F5V97)S92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R
M<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@
M;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J
M($!A8V-E<W,@("`@("!P=6)L:6,*("`@("`J($!S:6YC92`@("`@("`Q+C`*
M("`@("`J($!D97!R96-A=&5D("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S96YD7V9R;VTH)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N('-E;F1&
M<F]M*"1P871H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%-/
M34P@1E)/33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M(%1H92!R979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@
M;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F
M86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'-I;F-E("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO
M;B!S;VUL1G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G4T]-3"<L(")&4D]-.CPD<&%T
M:#XB*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P
M87)S95)E<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R
M;W(["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($)A8VMW87)D<RUC;VUP871I8FEL:71Y('=R87!P97(@
M9F]R('-O;6Q&<F]M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4
M:&4@<F5V97)S92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE
M<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I
M;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E
M<W,@("`@("!P=6)L:6,*("`@("`J($!S:6YC92`@("`@("`Q+C`*("`@("`J
M($!D97!R96-A=&5D("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S;VUL
M7V9R;VTH)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N('-O;6Q&<F]M*"1P
M871H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%-!34P@1E)/
M33H@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(%1H92!R
M979E<G-E('!A=&@@=&\@<V5N9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI
M>&5D(%)E='5R;G,@82!014%27T5R<F]R('=I=&@@86X@97)R;W(@;65S<V%G
M92!O;B!A;GD*("`@("`J("`@("`@("`@("`@("`@:VEN9"!O9B!F86EL=7)E
M+"!O<B!T<G5E(&]N('-U8V-E<W,N"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-I;F-E("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S86UL
M1G)O;2@D<&%T:"D*("`@('L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R;W(@/2`D=&AI<RT^7W!U="@G4T%-3"<L(")&4D]-.CPD<&%T:#XB*2DI
M('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E
M<W!O;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*
M("`@("`J($)A8VMW87)D<RUC;VUP871I8FEL:71Y('=R87!P97(@9F]R('-A
M;6Q&<F]M*"DN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@<F5V
M97)S92!P871H('1O('-E;F0N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R<F]R(&UE<W-A9V4@
M;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@;V8@9F%I;'5R92P@
M;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@("`@
M("!P=6)L:6,*("`@("`J($!S:6YC92`@("`@("`Q+C`*("`@("`J($!D97!R
M96-A=&5D("`Q+C(N-@H@("`@("HO"B`@("!F=6YC=&EO;B!S86UL7V9R;VTH
M)'!A=&@I"B`@("!["B`@("`@("`@<F5T=7)N('-A;6Q&<F]M*"1P871H*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@=&AE(%)3150@8V]M;6%N9"X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R;G,@82!014%27T5R
M<F]R('=I=&@@86X@97)R;W(@;65S<V%G92!O;B!A;GD*("`@("`J("`@("`@
M("`@("`@("`@:VEN9"!O9B!F86EL=7)E+"!O<B!T<G5E(&]N('-U8V-E<W,N
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E("`Q+C`*("`@
M("`J+PH@("`@9G5N8W1I;VX@<G-E="@I"B`@("!["B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P=70H)U)3150G*2DI('L*
M("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<F]R(#T@)'1H:7,M/E]P87)S95)E<W!O
M;G-E*#(U,"DI*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E;F0@=&AE(%921ED@8V]M;6%N9"X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG(%1H92!S=')I;F<@=&\@=F5R:69Y"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"!2971U<FYS(&$@4$5!4E]%<G)O<B!W:71H(&%N(&5R
M<F]R(&UE<W-A9V4@;VX@86YY"B`@("`@*B`@("`@("`@("`@("`@(&MI;F0@
M;V8@9F%I;'5R92P@;W(@=')U92!O;B!S=6-C97-S+@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J($!S:6YC92`@,2XP"B`@("`@*B\*("`@(&9U;F-T
M:6]N('9R9GDH)'-T<FEN9RD*("`@('L*("`@("`@("`O*B!.;W1E.B`R-3$@
M:7,@86QS;R!A('9A;&ED(')E<W!O;G-E(&-O9&4@*B\*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G5E)&62<L("1S
M=')I;F<I*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@
M('T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^
M7W!A<G-E4F5S<&]N<V4H87)R87DH,C4P+"`R-3(I*2DI('L*("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<CL*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5N9"!T:&4@3D]/4"!C;VUM
M86YD+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@4F5T=7)N<R!A(%!%
M05)?17)R;W(@=VET:"!A;B!E<G)O<B!M97-S86=E(&]N(&%N>0H@("`@("H@
M("`@("`@("`@("`@("!K:6YD(&]F(&9A:6QU<F4L(&]R('1R=64@;VX@<W5C
M8V5S<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(#$N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!N;V]P*"D*("`@('L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!U="@G3D]/4"<I
M*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@('T*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D=&AI<RT^7W!A<G-E
M4F5S<&]N<V4H,C4P*2DI('L*("`@("`@("`@("`@<F5T=7)N("1E<G)O<CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0F%C:W=A<F1S+6-O;7!A=&EB:6QI='D@;65T:&]D+B`@:61E
M;G1I9GE396YD97(H*2=S(&9U;F-T:6]N86QI='D@:7,*("`@("`J(&YO=R!H
M86YD;&5D(&EN=&5R;F%L;'DN"B`@("`@*@H@("`@("H@0')E='5R;B`@8F]O
M;&5A;B`@("`@5&AI<R!M971H;V0@86QW87ES(')E='5R;B!T<G5E+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I;F-E("`@,2XP
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&ED96YT:69Y4V5N9&5R*"D*("`@('L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B].970O55),+G!H<```````````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,R-C,T(#$P-3$U-#,T,3,U
M(#`R,#,W-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-"P@4FEC:&%R9"!(97EE<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!!;&P@<FEG
M:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C
M92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`T*+R\@
M?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`T*+R\@?"!A<F4@;65T.B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`T*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M
M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?`T*+R\@?"`@
M(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`T*+R\@?"!O(%)E9&ES=')I8G5T
M:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@
M8V]P>7)I9VAT("`@?`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@
M?`T*+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L
M<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?`T*+R\@?"!O(%1H
M92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD
M;W)S92!O<B!P<F]M;W1E("`@("`@?`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV
M960@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@
M=W)I='1E;B`@?`T*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!42$E3(%-/
M1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!
M3D0@0T].5%))0E543U)3("`@?`T*+R\@?"`B05,@25,B($%.1"!!3ED@15A0
M4D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/
M5"`@("`@?`T*+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y4
M2453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?`T*+R\@
M?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@
M159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?`T*+R\@?"!/5TY%4B!/4B!#
M3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#
M5"P@24Y#241%3E1!3"P@?`T*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2
M($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@
M("`@?`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4
M551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`T*+R\@?"!$
M051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/
M5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`T*+R\@?"!42$5/4ED@3T8@3$E!
M0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519
M+"!/4B!43U)4("`@?`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@
M3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@
M?`T*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@
M5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?`T*+R\@?"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA
M<F0@870@<&AP(&YE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O("1)9#H@
M55),+G!H<"QV(#$N,S8@,C`P-"\P-B\Q.2`Q.#HU.#HU,"!R:6-H87)D($5X
M<"`D#0HO+PT*+R\@3F5T7U523"!#;&%S<PT*#0IC;&%S<R!.971?55),#0I[
M#0H@("`@+RHJ#0H@("`@*B!&=6QL('5R;`T*("`@("H@0'9A<B!S=')I;F<-
M"B`@("`J+PT*("`@('9A<B`D=7)L.PT*#0H@("`@+RHJ#0H@("`@*B!0<F]T
M;V-O;`T*("`@("H@0'9A<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D<')O
M=&]C;VP[#0H-"B`@("`O*BH-"B`@("`J(%5S97)N86UE#0H@("`@*B!`=F%R
M('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1U<V5R;F%M93L-"@T*("`@("\J
M*@T*("`@("H@4&%S<W=O<F0-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-
M"B`@("!V87(@)'!A<W-W;W)D.PT*#0H@("`@+RHJ#0H@("`@*B!(;W-T#0H@
M("`@*B!`=F%R('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1H;W-T.PT*#0H@
M("`@+RHJ#0H@("`@*B!0;W)T#0H@("`@*B!`=F%R(&EN=&5G97(-"B`@("`J
M+PT*("`@('9A<B`D<&]R=#L-"@T*("`@("\J*@T*("`@("H@4&%T:`T*("`@
M("H@0'9A<B!S=')I;F<-"B`@("`J+PT*("`@('9A<B`D<&%T:#L-"@T*("`@
M("\J*@T*("`@("H@475E<GD@<W1R:6YG#0H@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@*B\-"B`@("!V87(@)'%U97)Y<W1R:6YG.PT*#0H@("`@+RHJ#0H@("`@
M*B!!;F-H;W(-"B`@("`J($!V87(@<W1R:6YG#0H@("`@*B\-"B`@("!V87(@
M)&%N8VAO<CL-"@T*("`@("\J*@T*("`@("H@5VAE=&AE<B!T;R!U<V4@6UT-
M"B`@("`J($!V87(@8F]O;`T*("`@("HO#0H@("`@=F%R("1U<V5"<F%C:V5T
M<SL-"@T*("`@("\J*@T*("`@("H@4$A0-"!#;VYS=')U8W1O<@T*("`@("H-
M"B`@("`J($!S964@7U]C;VYS=')U8W0H*0T*("`@("HO#0H@("`@9G5N8W1I
M;VX@3F5T7U523"@D=7)L(#T@;G5L;"P@)'5S94)R86-K971S(#T@=')U92D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?7V-O;G-T<G5C="@D=7)L+"`D=7-E
M0G)A8VME=',I.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@4$A0-2!#;VYS
M=')U8W1O<@T*("`@("H-"B`@("`J(%!A<G-E<R!T:&4@9VEV96X@=7)L(&%N
M9"!S=&]R97,@=&AE('9A<FEO=7,@<&%R=',-"B`@("`J($1E9F%U;'1S(&%R
M92!U<V5D(&EN(&-E<G1A:6X@8V%S97,-"B`@("`J#0H@("`@*B!`<&%R86T@
M<W1R:6YG("1U<FP@("`@("`@("!/<'1I;VYA;"!54DP-"B`@("`J($!P87)A
M;2!B;V]L("`@)'5S94)R86-K971S(%=H971H97(@=&\@=7-E('-Q=6%R92!B
M<F%C:V5T<R!W:&5N#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!M=6QT:7!L92!Q=65R>7-T<FEN9W,@=VET:"!T:&4@<V%M92!N86UE#0H@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!E>&ES=`T*("`@("HO
M#0H@("`@9G5N8W1I;VX@7U]C;VYS=')U8W0H)'5R;"`](&YU;&PL("1U<V5"
M<F%C:V5T<R`]('1R=64I#0H@("`@>PT*("`@("`@("`D2%144%]315)615)?
M5D%24R`@/2`A96UP='DH)%]315)615(I(#\@)%]315)615(@.B`D1TQ/0D%,
M4ULG2%144%]315)615)?5D%24R==.PT*#0H@("`@("`@("1T:&ES+3YU<V5"
M<F%C:V5T<R`]("1U<V5"<F%C:V5T<SL-"B`@("`@("`@)'1H:7,M/G5R;"`@
M("`@("`@(#T@)'5R;#L-"B`@("`@("`@)'1H:7,M/G5S97(@("`@("`@(#T@
M)R<[#0H@("`@("`@("1T:&ES+3YP87-S("`@("`@("`]("<G.PT*("`@("`@
M("`D=&AI<RT^:&]S="`@("`@("`@/2`G)SL-"B`@("`@("`@)'1H:7,M/G!O
M<G0@("`@("`@(#T@.#`[#0H@("`@("`@("1T:&ES+3YP871H("`@("`@("`]
M("<G.PT*("`@("`@("`D=&AI<RT^<75E<GES=')I;F<@/2!A<G)A>2@I.PT*
M("`@("`@("`D=&AI<RT^86YC:&]R("`@("`@/2`G)SL-"@T*("`@("`@("`O
M+R!/;FQY('5S92!D969A=6QT<R!I9B!N;W0@86X@86)S;VQU=&4@55),(&=I
M=F5N#0H@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY;82UZ,"TY72LZ7"]<
M+R]I)RP@)'5R;"DI('L-"@T*("`@("`@("`@("`@)'1H:7,M/G!R;W1O8V]L
M("`@(#T@*$`D2%144%]315)615)?5D%24ULG2%144%,G72`]/2`G;VXG(#\@
M)VAT='!S)R`Z("=H='1P)RD[#0H-"B`@("`@("`@("`@("\J*@T*("`@("`@
M("`@("`@*B!&:6=U<F4@;W5T(&AO<W0O<&]R=`T*("`@("`@("`@("`@*B\-
M"B`@("`@("`@("`@(&EF("@A96UP='DH)$A45%!?4T525D527U9!4E-;)TA4
M5%!?2$]35"==*2!!3D0@<')E9U]M871C:"@G+UXH+BHI*#HH6S`M.5TK*2D_
M)"]5)RP@)$A45%!?4T525D527U9!4E-;)TA45%!?2$]35"==+"`D;6%T8VAE
M<RDI('L-"B`@("`@("`@("`@("`@("`D:&]S="`]("1M871C:&5S6S%=.PT*
M("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&UA=&-H97-;,UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1P;W)T(#T@)&UA=&-H97-;,UT[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'!O
M<G0@/2`D=&AI<RT^9V5T4W1A;F1A<F10;W)T*"1T:&ES+3YP<F]T;V-O;"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@
M("`@("`D=&AI<RT^=7-E<B`@("`@("`@/2`G)SL-"B`@("`@("`@("`@("1T
M:&ES+3YP87-S("`@("`@("`]("<G.PT*("`@("`@("`@("`@)'1H:7,M/FAO
M<W0@("`@("`@(#T@(65M<'1Y*"1H;W-T*2`_("1H;W-T(#H@*&ES<V5T*"1(
M5%107U-%4E9%4E]605)36R=315)615)?3D%-12==*2`_("1(5%107U-%4E9%
M4E]605)36R=315)615)?3D%-12==(#H@)VQO8V%L:&]S="<I.PT*("`@("`@
M("`@("`@)'1H:7,M/G!O<G0@("`@("`@(#T@(65M<'1Y*"1P;W)T*2`_("1P
M;W)T(#H@*&ES<V5T*"1(5%107U-%4E9%4E]605)36R=315)615)?4$]25"==
M*2`_("1(5%107U-%4E9%4E]605)36R=315)615)?4$]25"==(#H@)'1H:7,M
M/F=E=%-T86YD87)D4&]R="@D=&AI<RT^<')O=&]C;VPI*3L-"B`@("`@("`@
M("`@("1T:&ES+3YP871H("`@("`@("`]("%E;7!T>2@D2%144%]315)615)?
M5D%24ULG4$A07U-%3$8G72D@/R`D2%144%]315)615)?5D%24ULG4$A07U-%
M3$8G72`Z("<O)SL-"B`@("`@("`@("`@("1T:&ES+3YQ=65R>7-T<FEN9R`]
M(&ES<V5T*"1(5%107U-%4E9%4E]605)36R=1545265]35%))3D<G72D@/R`D
M=&AI<RT^7W!A<G-E4F%W475E<GES=')I;F<H)$A45%!?4T525D527U9!4E-;
M)U%515)97U-44DE.1R==*2`Z(&YU;&P[#0H@("`@("`@("`@("`D=&AI<RT^
M86YC:&]R("`@("`@/2`G)SL-"B`@("`@("`@?0T*#0H@("`@("`@("\O(%!A
M<G-E('1H92!U<FP@86YD('-T;W)E('1H92!V87)I;W5S('!A<G1S#0H@("`@
M("`@(&EF("@A96UP='DH)'5R;"DI('L-"B`@("`@("`@("`@("1U<FQI;F9O
M(#T@<&%R<V5?=7)L*"1U<FPI.PT*#0H@("`@("`@("`@("`O+R!$969A=6QT
M('%U97)Y<W1R:6YG#0H@("`@("`@("`@("`D=&AI<RT^<75E<GES=')I;F<@
M/2!A<G)A>2@I.PT*#0H@("`@("`@("`@("!F;W)E86-H("@D=7)L:6YF;R!A
M<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@("`@('-W:71C:"`H
M)&ME>2D@>PT*("`@("`@("`@("`@("`@("`@("!C87-E("=S8VAE;64G.@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R;W1O8V]L(#T@)'9A
M;'5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!O<G0@("`@
M(#T@)'1H:7,M/F=E=%-T86YD87)D4&]R="@D=F%L=64I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("`@("`@
M8V%S92`G=7-E<B<Z#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W!A<W,G
M.@T*("`@("`@("`@("`@("`@("`@("!C87-E("=H;W-T)SH-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G<&]R="<Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^)&ME>2`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)W!A
M=&@G.@T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1V86QU97LP?2`]
M/2`G+R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M<&%T:"`]("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A=&@@/2!D:7)N
M86UE*"1T:&ES+3YP871H*2`]/2!$25)%0U1/4EE?4T5005)!5$]2(#\@)R<@
M.B!D:7)N86UE*"1T:&ES+3YP871H*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<&%T:"`]('-P<FEN=&8H)R5S+R5S)RP@)'!A=&@L
M("1V86QU92D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@("`@("`@
M("!C87-E("=Q=65R>2<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^<75E<GES=')I;F<@/2`D=&AI<RT^7W!A<G-E4F%W475E<GE3=')I;F<H
M)'9A;'5E*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)V9R86=M96YT)SH-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YA;F-H;W(@/2`D=F%L=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`J(%)E='5R;G,@9G5L;"!U<FP-"B`@("`J#0H@("`@*B!`<F5T=7)N
M('-T<FEN9R!&=6QL('5R;`T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=%523"@I#0H@("`@>PT*("`@("`@("`D<75E
M<GES=')I;F<@/2`D=&AI<RT^9V5T475E<GE3=')I;F<H*3L-"@T*("`@("`@
M("`D=&AI<RT^=7)L(#T@)'1H:7,M/G!R;W1O8V]L("X@)SHO+R<-"B`@("`@
M("`@("`@("`@("`@("`N("1T:&ES+3YU<V5R("X@*"%E;7!T>2@D=&AI<RT^
M<&%S<RD@/R`G.B<@.B`G)RD-"B`@("`@("`@("`@("`@("`@("`N("1T:&ES
M+3YP87-S("X@*"%E;7!T>2@D=&AI<RT^=7-E<BD@/R`G0"<@.B`G)RD-"B`@
M("`@("`@("`@("`@("`@("`N("1T:&ES+3YH;W-T("X@*"1T:&ES+3YP;W)T
M(#T]("1T:&ES+3YG9713=&%N9&%R9%!O<G0H)'1H:7,M/G!R;W1O8V]L*2`_
M("<G(#H@)SHG("X@)'1H:7,M/G!O<G0I#0H@("`@("`@("`@("`@("`@("`@
M+B`D=&AI<RT^<&%T:`T*("`@("`@("`@("`@("`@("`@("X@*"%E;7!T>2@D
M<75E<GES=')I;F<I(#\@)S\G("X@)'%U97)Y<W1R:6YG(#H@)R<I#0H@("`@
M("`@("`@("`@("`@("`@+B`H(65M<'1Y*"1T:&ES+3YA;F-H;W(I(#\@)R,G
M("X@)'1H:7,M/F%N8VAO<B`Z("<G*3L-"@T*("`@("`@("!R971U<FX@)'1H
M:7,M/G5R;#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`J($%D9',@82!Q=65R
M>7-T<FEN9R!I=&5M#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@)&YA
M;64@("`@("`@3F%M92!O9B!I=&5M#0H@("`@*B!`<&%R86T@('-T<FEN9R`D
M=F%L=64@("`@("!686QU92!O9B!I=&5M#0H@("`@*B!`<&%R86T@(&)O;VP@
M("`D<')E96YC;V1E9"!7:&5T:&5R('9A;'5E(&ES('5R;&5N8V]D960@;W(@
M;F]T+"!D969A=6QT(#T@;F]T#0H@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("HO#0H@("`@9G5N8W1I;VX@861D475E<GE3=')I;F<H)&YA;64L("1V86QU
M92P@)'!R965N8V]D960@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D
M<')E96YC;V1E9"D@>PT*("`@("`@("`@("`@)'1H:7,M/G%U97)Y<W1R:6YG
M6R1N86UE72`]("1V86QU93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3YQ=65R>7-T<FEN9ULD;F%M95T@/2!I<U]A<G)A>2@D=F%L
M=64I(#\@87)R87E?;6%P*"=R87=U<FQE;F-O9&4G+"`D=F%L=64I.B!R87=U
M<FQE;F-O9&4H)'9A;'5E*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J
M*@T*("`@("H@4F5M;W9E<R!A('%U97)Y<W1R:6YG(&ET96T-"B`@("`J#0H@
M("`@*B!`<&%R86T@('-T<FEN9R`D;F%M92!.86UE(&]F(&ET96T-"B`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!R96UO=F51
M=65R>5-T<FEN9R@D;F%M92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^<75E<GES=')I;F=;)&YA;65=*2D@>PT*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/G%U97)Y<W1R:6YG6R1N86UE72D[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`J(%-E=',@=&AE('%U97)Y<W1R:6YG('1O
M(&QI=&5R86QL>2!W:&%T('EO=2!S=7!P;'D-"B`@("`J#0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D<75E<GES=')I;F<@5&AE('%U97)Y<W1R:6YG(&1A=&$N
M(%-H;W5L9"!B92!O9B!T:&4@9F]R;6%T(&9O;SUB87(F>#UY(&5T8PT*("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9%)A
M=U%U97)Y4W1R:6YG*"1Q=65R>7-T<FEN9RD-"B`@("![#0H@("`@("`@("1T
M:&ES+3YQ=65R>7-T<FEN9R`]("1T:&ES+3Y?<&%R<V5287=1=65R>5-T<FEN
M9R@D<75E<GES=')I;F<I.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@4F5T
M=7)N<R!F;&%T('%U97)Y<W1R:6YG#0H@("`@*@T*("`@("H@0')E='5R;B!S
M=')I;F<@475E<GES=')I;F<-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!G9711=65R>5-T<FEN9R@I#0H@("`@>PT*("`@
M("`@("!I9B`H(65M<'1Y*"1T:&ES+3YQ=65R>7-T<FEN9RDI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YQ=65R>7-T<FEN9R!A<R`D;F%M92`]
M/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A
M;'5E*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@
M87,@)&L@/3X@)'8I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1Q=65R
M>7-T<FEN9UM=(#T@)'1H:7,M/G5S94)R86-K971S(#\@<W!R:6YT9B@G)7-;
M)7-=/25S)RP@)&YA;64L("1K+"`D=BD@.B`H)&YA;64@+B`G/2<@+B`D=BD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H(6ES7VYU;&PH)'9A;'5E*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<75E<GES=')I;F=;72`]("1N86UE("X@)STG("X@)'9A;'5E.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1Q
M=65R>7-T<FEN9UM=(#T@)&YA;64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'%U97)Y<W1R:6YG(#T@:6UP;&]D
M92AI;FE?9V5T*"=A<F=?<V5P87)A=&]R+F]U='!U="<I+"`D<75E<GES=')I
M;F<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'%U97)Y<W1R
M:6YG(#T@)R<[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'%U97)Y
M<W1R:6YG.PT*("`@('T-"@T*("`@("\J*@T*("`@("H@4&%R<V5S(')A=R!Q
M=65R>7-T<FEN9R!A;F0@<F5T=7)N<R!A;B!A<G)A>2!O9B!I=`T*("`@("H-
M"B`@("`J($!P87)A;2`@<W1R:6YG("`D<75E<GES=')I;F<@5&AE('%U97)Y
M<W1R:6YG('1O('!A<G-E#0H@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@
M("`@("`@($%N(&%R<F%Y(&]F('1H92!Q=65R>7-T<FEN9R!D871A#0H@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*("`@(&9U;F-T:6]N(%]P87)S
M95)A=U%U97)Y<W1R:6YG*"1Q=65R>7-T<FEN9RD-"B`@("![#0H@("`@("`@
M("1P87)T<R`@/2!P<F5G7W-P;&ET*"<O6R<@+B!P<F5G7W%U;W1E*&EN:5]G
M970H)V%R9U]S97!A<F%T;W(N:6YP=70G*2P@)R\G*2`N("==+R<L("1Q=65R
M>7-T<FEN9RP@+3$L(%!214=?4U!,251?3D]?14U05%DI.PT*("`@("`@("`D
M<F5T=7)N(#T@87)R87DH*3L-"@T*("`@("`@("!F;W)E86-H("@D<&%R=',@
M87,@)'!A<G0I('L-"B`@("`@("`@("`@(&EF("AS=')P;W,H)'!A<G0L("<]
M)RD@(3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@<W5B
M<W1R*"1P87)T+"!S=')P;W,H)'!A<G0L("<])RD@*R`Q*3L-"B`@("`@("`@
M("`@("`@("`D:V5Y("`@/2!S=6)S='(H)'!A<G0L(#`L('-T<G!O<R@D<&%R
M="P@)STG*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1V86QU92`](&YU;&P[#0H@("`@("`@("`@("`@("`@)&ME>2`@(#T@
M)'!A<G0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1K97DL("TR*2`]/2`G6UTG*2![#0H@("`@("`@("`@("`@("`@)&ME>2`]
M('-U8G-T<B@D:V5Y+"`P+"`M,BD[#0H@("`@("`@("`@("`@("`@:68@*$`A
M:7-?87)R87DH)')E='5R;ELD:V5Y72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)')E='5R;ELD:V5Y72`@(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`@("`@)')E='5R;ELD:V5Y75M=(#T@)'9A;'5E.PT*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1R971U<FY;)&ME
M>5U;72`]("1V86QU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!](&5L<V5I9B`H(21T:&ES+3YU<V5"<F%C:V5T<R!!3D0@(65M<'1Y*"1R
M971U<FY;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@)')E='5R;ELD:V5Y
M72`@(#T@*&%R<F%Y*21R971U<FY;)&ME>5T[#0H@("`@("`@("`@("`@("`@
M)')E='5R;ELD:V5Y75M=(#T@)'9A;'5E.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D<F5T=7)N6R1K97E=(#T@)'9A;'5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N("1R
M971U<FX[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!297-O;'9E<R`O+RP@
M+BXO(&%N9"`N+R!F<F]M(&$@<&%T:"!A;F0@<F5T=7)N<PT*("`@("H@=&AE
M(')E<W5L="X@16<Z#0H@("`@*@T*("`@("H@+V9O;R]B87(O+BXO8F]O+G!H
M<"`@("`]/B`O9F]O+V)O;RYP:'`-"B`@("`J("]F;V\O8F%R+RXN+RXN+V)O
M;RYP:'`@/3X@+V)O;RYP:'`-"B`@("`J("]F;V\O8F%R+RXN+RXO+V)O;RYP
M:'`@/3X@+V9O;R]B;V\N<&AP#0H@("`@*@T*("`@("H@5&AI<R!M971H;V0@
M8V%N(&%L<V\@8F4@8V%L;&5D('-T871I8V%L;'DN#0H@("`@*@T*("`@("H@
M0'!A<F%M("!S=')I;F<@)'5R;"!54DP@<&%T:"!T;R!R97-O;'9E#0H@("`@
M*B!`<F5T=7)N('-T<FEN9R`@("`@(%1H92!R97-U;'0-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(')E<V]L=F50871H*"1P871H*0T*("`@('L-"B`@("`@("`@
M)'!A=&@@/2!E>'!L;V1E*"<O)RP@<W1R7W)E<&QA8V4H)R\O)RP@)R\G+"`D
M<&%T:"DI.PT*#0H@("`@("`@(&9O<B`H)&D],#L@)&D\8V]U;G0H)'!A=&@I
M.R`D:2LK*2![#0H@("`@("`@("`@("!I9B`H)'!A=&A;)&E=(#T]("<N)RD@
M>PT*("`@("`@("`@("`@("`@('5N<V5T*"1P871H6R1I72D[#0H@("`@("`@
M("`@("`@("`@)'!A=&@@/2!A<G)A>5]V86QU97,H)'!A=&@I.PT*("`@("`@
M("`@("`@("`@("1I+2T[#0H-"B`@("`@("`@("`@('T@96QS96EF("@D<&%T
M:%LD:5T@/3T@)RXN)R!!3D0@*"1I(#X@,2!/4B`H)&D@/3T@,2!!3D0@)'!A
M=&A;,%T@(3T@)R<I("D@*2![#0H@("`@("`@("`@("`@("`@=6YS970H)'!A
M=&A;)&E=*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D<&%T:%LD:2TQ72D[
M#0H@("`@("`@("`@("`@("`@)'!A=&@@/2!A<G)A>5]V86QU97,H)'!A=&@I
M.PT*("`@("`@("`@("`@("`@("1I("T](#([#0H-"B`@("`@("`@("`@('T@
M96QS96EF("@D<&%T:%LD:5T@/3T@)RXN)R!!3D0@)&D@/3T@,2!!3D0@)'!A
M=&A;,%T@/3T@)R<I('L-"B`@("`@("`@("`@("`@("!U;G-E="@D<&%T:%LD
M:5TI.PT*("`@("`@("`@("`@("`@("1P871H(#T@87)R87E?=F%L=65S*"1P
M871H*3L-"B`@("`@("`@("`@("`@("`D:2TM.PT*#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)R\G
M+"`D<&%T:"D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!2971U<FYS('1H
M92!S=&%N9&%R9"!P;W)T(&YU;6)E<B!F;W(@82!P<F]T;V-O;`T*("`@("H-
M"B`@("`J($!P87)A;2`@<W1R:6YG("`D<V-H96UE(%1H92!P<F]T;V-O;"!T
M;R!L;V]K=7`-"B`@("`J($!R971U<FX@:6YT96=E<B`@("`@("`@(%!O<G0@
M;G5M8F5R(&]R($Y53$P@:68@;F\@<V-H96UE(&UA=&-H97,-"B`@("`J#0H@
M("`@*B!`875T:&]R(%!H:6QI<'!E($IA=7-I;VYS(#Q0:&EL:7!P92Y*875S
M:6]N<T`Q,6%B86-U<RYC;VT^#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G9713
M=&%N9&%R9%!O<G0H)'-C:&5M92D-"B`@("![#0H@("`@("`@('-W:71C:"`H
M<W1R=&]L;W=E<B@D<V-H96UE*2D@>PT*("`@("`@("`@("`@8V%S92`G:'1T
M<"<Z("`@(')E='5R;B`X,#L-"B`@("`@("`@("`@(&-A<V4@)VAT='!S)SH@
M("!R971U<FX@-#0S.PT*("`@("`@("`@("`@8V%S92`G9G1P)SH@("`@(')E
M='5R;B`R,3L-"B`@("`@("`@("`@(&-A<V4@)VEM87`G.B`@("!R971U<FX@
M,30S.PT*("`@("`@("`@("`@8V%S92`G:6UA<',G.B`@(')E='5R;B`Y.3,[
M#0H@("`@("`@("`@("!C87-E("=P;W`S)SH@("`@<F5T=7)N(#$Q,#L-"B`@
M("`@("`@("`@(&-A<V4@)W!O<#-S)SH@("!R971U<FX@.3DU.PT*("`@("`@
M("`@("`@9&5F875L=#H@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@('T-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`J($9O<F-E<R!T:&4@55),('1O(&$@
M<&%R=&EC=6QA<B!P<F]T;V-O;`T*("`@("H-"B`@("`J($!P87)A;2!S=')I
M;F<@("1P<F]T;V-O;"!0<F]T;V-O;"!T;R!F;W)C92!T:&4@55),('1O#0H@
M("`@*B!`<&%R86T@:6YT96=E<B`D<&]R="`@("`@3W!T:6]N86P@<&]R="`H
M<W1A;F1A<F0@<&]R="!I<R!U<V5D(&)Y(&1E9F%U;'0I#0H@("`@*B\-"B`@
M("!F=6YC=&EO;B!S9710<F]T;V-O;"@D<')O=&]C;VPL("1P;W)T(#T@;G5L
M;"D-"B`@("![#0H@("`@("`@("1T:&ES+3YP<F]T;V-O;"`]("1P<F]T;V-O
M;#L-"B`@("`@("`@)'1H:7,M/G!O<G0@/2!I<U]N=6QL*"1P;W)T*2`_("1T
M:&ES+3YG9713=&%N9&%R9%!O<G0H*2`Z("1P;W)T.PT*("`@('T-"@T*?0T*
M/SX-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TYE
M="]&5%`N<&AP````````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`R,3(Q,C0@,3`U,34T,S0Q,S4@,#(P,S4U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S
M=&]P/30Z("HO"@HO*BH*("H@3F5T7T944"!M86EN(&9I;&4N"B`J"B`J(%1H
M:7,@9FEL92!M=7-T(&)E(&EN8VQU9&5D('1O('5S92!T:&4@3F5T7T944"!P
M86-K86=E+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@3F5T=V]R:VEN9PH@*B!`<&%C:V%G92`@("!&5%`*("H@
M0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@/'1O8GE`<&AP+FYE=#X*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!&5%`N<&AP
M+'8@,2XT,B`R,#`U+S`S+S,Q(#(P.C`W.C4X('1O8GD@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TYE=%]&5%`*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P
M+C`N,0H@*B\*"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH*+RHJ"B`J($]P
M=&EO;B!T;R!L970@=&AE(&QS*"D@;65T:&]D(')E='5R;B!O;FQY(&9I;&5S
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?1DE,15-?3TY,
M60H@*B!`<V5E($YE=%]&5%`Z.FQS*"D*("HO"F1E9FEN92@G3D547T944%]&
M24Q%4U]/3DQ9)RP@,"P@=')U92D["@HO*BH*("H@3W!T:6]N('1O(&QE="!T
M:&4@;',H*2!M971H;V0@<F5T=7)N(&]N;'D@9&ER96-T;W)I97,N"B`J"B`J
M($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]$25)37T].3%D*("H@0'-E
M92!.971?1E10.CIL<R@I"B`J+PID969I;F4H)TY%5%]&5%!?1$E24U]/3DQ9
M)RP@,2P@=')U92D["@HO*BH*("H@3W!T:6]N('1O(&QE="!T:&4@;',H*2!M
M971H;V0@<F5T=7)N(&1I<F5C=&]R:65S(&%N9"!F:6QE<R`H9&5F875L="DN
M"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]$25)37T9)3$53
M"B`J($!S964@3F5T7T944#HZ;',H*0H@*B\*9&5F:6YE*"=.151?1E107T1)
M4E-?1DE,15,G+"`R+"!T<G5E*3L*"B\J*@H@*B!/<'1I;VX@=&\@;&5T('1H
M92!L<R@I(&UE=&AO9"!R971U<FX@=&AE(')A=R!D:7)E8W1O<GD@;&ES=&EN
M9R!F<F]M(&9T<%]R87=L:7-T*"DN"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA
M;64@3D547T944%]205=,25-4"B`J($!S964@3F5T7T944#HZ;',H*0H@*B\*
M9&5F:6YE*"=.151?1E107U)!5TQ)4U0G+"`S+"!T<G5E*3L*"@HO*BH*("H@
M17)R;W(@8V]D92!T;R!I;F1I8V%T92!A(&9A:6QE9"!C;VYN96-T:6]N"B`J
M(%1H:7,@97)R;W(@8V]D92!I;F1I8V%T97,L('1H870@=&AE(&-O;FYE8W1I
M;VX@>6]U('1R>65D('1O('-E="!U<`H@*B!C;W5L9"!N;W0@8F4@97-T86)L
M:7-H960N($-H96-K('EO=7(@8V]N;F5C=&EO;B!S971T:6YG<R`H:&]S="`F
M('!O<G0I(0H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)2
M7T-/3DY%0U1?1D%)3$5$"B`J($!S964@3F5T7T944#HZ8V]N;F5C="@I"B`J
M+PID969I;F4H)TY%5%]&5%!?15)27T-/3DY%0U1?1D%)3$5$)RP@+3$I.PH*
M+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@82!F86EL960@;&]G:6X*
M("H@5&AI<R!E<G)O<B!C;V1E(&EN9&EC871E<RP@=&AA="!T:&4@;&]G:6X@
M=&\@=&AE($944"!S97)V97(@9F%I;&5D+B!#:&5C:PH@*B!Y;W5R('5S97(@
M9&%T82`H=7-E<FYA;64@)B!P87-S=V]R9"DN"B`J"B`J($!S:6YC92`Q+C,*
M("H@0&YA;64@3D547T944%]%4E)?3$]'24Y?1D%)3$5$"B`J($!S964@3F5T
M7T944#HZ;&]G:6XH*0H@*B\*9&5F:6YE*"=.151?1E107T524E],3T=)3E]&
M04E,140G+"`M,BD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!A
M(&9A:6QE9"!D:7)E8W1O<GD@8VAA;F=E"B`J(%1H92!C9"@I(&UE=&AO9"!F
M86EL960N($5N<W5R92!T:&%T('1H92!D:7)E8W1O<GD@>6]U('=A;G1E9"!T
M;R!A8V-E<W,@97AI<W1S+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%
M5%]&5%!?15)27T1)4D-(04Y'15]&04E,140*("H@0'-E92!.971?1E10.CIC
M9"@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T1)4D-(04Y'15]&04E,140G
M+"`R*3L@+R\@0V]M<&%T:6)I;&QI='D@<F5A<V]N<R$*"B\J*@H@*B!%<G)O
M<B!C;V1E('1O(&EN9&EC871E('1H870@3F5T7T944"!C;W5L9"!N;W0@9&5T
M97)M:6YE('1H92!C=7)R96YT('!A=&@*("H@5&AE(&-W9"@I(&UE=&AO9"!F
M86EL960@86YD(&-O=6QD(&YO="!D971E<FUI;F4@=&AE('!A=&@@>6]U(&-U
M<G)E;G1L>2!R97-I9&4*("H@:6X@;VX@=&AE($944"!S97)V97(N"B`J"B`J
M($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?1$5415)-24Y%4$%4
M2%]&04E,140*("H@0'-E92!.971?1E10.CIP=V0H*0H@*B\*9&5F:6YE*"=.
M151?1E107T524E]$151%4DU)3D50051(7T9!24Q%1"<L(#0I.R`O+R!#;VUP
M871I8FEL;&ET>2!R96%S;VYS(0H*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD
M:6-A=&4@=&AA="!T:&4@8W)E871I;VX@;V8@82!D:7)E8W1O<GD@9F%I;&5D
M"B`J(%1H92!D:7)E8W1O<GD@>6]U('1R>65D('1O(&-R96%T92!C;W5L9"!N
M;W0@8F4@8W)E871E9"X@0VAE8VL@=&AE"B`J(&%C8V5S<R!R:6=H=',@;VX@
M=&AE('!A<F5N="!D:7)E8W1O<GDA"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA
M;64@3D547T944%]%4E)?0U)%051%1$E27T9!24Q%1`H@*B!`<V5E($YE=%]&
M5%`Z.FUK9&ER*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?0U)%051%1$E2
M7T9!24Q%1"<L("TT*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E
M('1H870@=&AE($5814,@97AE8W5T:6]N(&9A:6QE9"X*("H@5&AE(&5X96-U
M=&EO;B!O9B!A(&-O;6UA;F0@=7-I;F<@15A%0R!F86EL960N($5N<W5R92P@
M=&AA="!Y;W5R"B`J($944"!S97)V97(@<W5P<&]R=',@=&AE($5814,@8V]M
M;6%N9"X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]%
M6$5#7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F5X96-U=&4H*0H@*B\*9&5F
M:6YE*"=.151?1E107T524E]%6$5#7T9!24Q%1"<L("TU*3L*"B\J*@H@*B!%
M<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE(%-)5$4@8V]M;6%N9"!F
M86EL960N"B`J(%1H92!E>&5C=71I;VX@;V8@82!C;VUM86YD('5S:6YG(%-)
M5$4@9F%I;&5D+B!%;G-U<F4L('1H870@>6]U<@H@*B!&5%`@<V5R=F5R('-U
M<'!O<G1S('1H92!3251%(&-O;6UA;F0N"B`J"B`J($!S:6YC92`Q+C,*("H@
M0&YA;64@3D547T944%]%4E)?4TE415]&04E,140*("H@0'-E92!.971?1E10
M.CIS:71E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4TE415]&04E,140G
M+"`M-BD["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H
M92!#2$U/1"!C;VUM86YD(&9A:6QE9"X*("H@5&AE(&5X96-U=&EO;B!O9B!#
M2$U/1"!F86EL960N($5N<W5R92P@=&AA="!Y;W5R"B`J($944"!S97)V97(@
M<W5P<&]R=',@=&AE($-(34]$(&-O;6UA;F0@86YD('1H870@>6]U(&AA=F4@
M=&AE(&%P<')O<')I871E"B`J(&%C8V5S<R!R:6=H=',@=&\@=7-E($-(34]$
M+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T-(34]$
M7T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F-H;6]D*"D*("HO"F1E9FEN92@G
M3D547T944%]%4E)?0TA-3T1?1D%)3$5$)RP@+3<I.PH*+RHJ"B`J($5R<F]R
M(&-O9&4@=&\@:6YD:6-A=&4@=&AA="!A(&9I;&4@<F5N86UE(&9A:6QE9`H@
M*B!4:&4@<F5N86UI;F<@;V8@82!F:6QE(&]N('1H92!S97)V97(@9F%I;&5D
M+B!%;G-U<F4@=&AA="!Y;W4@:&%V92!T:&4*("H@87!P<F]P<FEA=&4@86-C
M97-S(')I9VAT<R!T;R!R96YA;64@=&AE(&9I;&4N"B`J"B`J($!S:6YC92`Q
M+C,*("H@0&YA;64@3D547T944%]%4E)?4D5.04U%7T9!24Q%1`H@*B!`<V5E
M($YE=%]&5%`Z.G)E;F%M92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27U)%
M3D%-15]&04E,140G+"`M."D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I
M8V%T92!T:&%T('1H92!-1%1-(&-O;6UA;F0@9F%I;&5D"B`J(%1H92!-1%1-
M(&-O;6UA;F0@:7,@;F]T('-U<'!O<G1E9"!F;W(@9&ER96-T;W)I97,N($5N
M<W5R92!T:&%T('EO=2!G879E"B`J(&$@9FEL92!P871H('1O('1H92!M9'1M
M*"D@;65T:&]D+"!N;W0@82!D:7)E8W1O<GD@<&%T:"X*("H*("H@0'-I;F-E
M(#$N,PH@*B!`;F%M92!.151?1E107T524E]-1%1-1$E27U5.4U504$]25$5$
M"B`J($!S964@3F5T7T944#HZ;61T;2@I"B`J+PID969I;F4H)TY%5%]&5%!?
M15)27TU$5$U$25)?54Y355!03U)4140G+"`M.2D["@HO*BH*("H@17)R;W(@
M8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!-1%1-(&-O;6UA;F0@9F%I;&5D
M"B`J(%1H92!-1%1-(&-O;6UA;F0@9F%I;&5D+B!%;G-U<F4@=&AA="!Y;W5R
M('-E<G9E<B!S=7!P;W)T<R!T:&4@341432!C;VUM86YD+@H@*@H@*B!`<VEN
M8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27TU$5$U?1D%)3$5$"B`J($!S
M964@3F5T7T944#HZ;61T;2@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27TU$
M5$U?1D%)3$5$)RP@+3$P*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC
M871E('1H870@82!D871E(')E='5R;F5D(&)Y('1H92!S97)V97(@=V%S(&UI
M<V9O<FUA=&5D"B`J($$@9&%T92!S=')I;F<@<F5T=7)N960@8GD@>6]U<B!S
M97)V97(@<V5E;7,@=&\@8F4@;6ES<V9O<FUA=&5D(&%N9"!C;W5L9"!N;W0@
M8F4*("H@<&%R<V5D+B!#:&5C:R!T:&%T('1H92!S97)V97(@:7,@8V]N9FEG
M=7)E9"!C;W)R96-T;'DN($EF('EO=2=R92!S=7)E+"!P;&5A<V4*("H@<V5N
M9"!A;B!E;6%I;"!T;R!T:&4@875H=&]R('=I=&@@82!D=6UP960@;W5T<'5T
M(&]F("1F='`M/FQS*"<N+R<L($Y%5%]&5%!?4D%73$E35"D["B`J('1O(&=E
M="!T:&4@9&%T92!F;W)M870@<W5P<&]R=&5D+@H@*@H@*B!`<VEN8V4@,2XS
M"B`J($!N86UE($Y%5%]&5%!?15)27T1!5$5&3U)-051?1D%)3$5$"B`J($!S
M964@3F5T7T944#HZ;61T;2@I+"!.971?1E10.CIL<R@I"B`J+PID969I;F4H
M)TY%5%]&5%!?15)27T1!5$5&3U)-051?1D%)3$5$)RP@+3$Q*3L*"B\J*@H@
M*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE(%-)6D4@8V]M;6%N
M9"!F86EL960*("H@5&AE(&1E=&5R;6EN871I;VX@;V8@=&AE(&9I;&5S:7IE
M(&]F(&$@9FEL92!F86EL960N($5N<W5R92!T:&%T('EO=7(@<V5R=F5R('-U
M<'!O<G1S('1H90H@*B!325I%(&-O;6UA;F0N"B`J"B`J($!S:6YC92`Q+C,*
M("H@0&YA;64@3D547T944%]%4E)?4TE:15]&04E,140*("H@0'-E92!.971?
M1E10.CIS:7IE*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4TE:15]&04E,
M140G+"`M,3(I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA
M="!A(&QO8V%L(&9I;&4@8V]U;&0@;F]T(&)E(&]V97)W<FET=&5N"B`J(%EO
M=2!S<&5C:69I960@;F]T('1O(&]V97)W<FET92!F:6QE<RX@5&AE<F5F;W)E
M('1H92!L;V-A;"!F:6QE(&AA<R!N;W0@8F5E;@H@*B!O=F5R=W)I=&5N+B!)
M9B!Y;W4@=V%N="!T;R!G970@=&AE(&9I;&4@;W9E<G=R:71E;BP@<&QE87-E
M('-E="!T:&4@;W!T:6]N('1O"B`J(&1O('-O+@H@*@H@*B!`<VEN8V4@,2XS
M"B`J($!N86UE($Y%5%]&5%!?15)27T]615)74DE414Q/0T%,1DE,15]&3U)"
M241$14X*("H@0'-E92!.971?1E10.CIG970H*2P@3F5T7T944#HZ9V5T4F5C
M=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3U9%4E=2251%3$]#
M04Q&24Q%7T9/4D))1$1%3B<L("TQ,RD["@HO*BH*("H@17)R;W(@8V]D92!T
M;R!I;F1I8V%T92!T:&%T(&$@;&]C86P@9FEL92!C;W5L9"!N;W0@8F4@;W9E
M<G=R:71T96X*("H@06QS;R!Y;W4@<W!E8VEF:65D('1O(&]V97)W<FET92!T
M:&4@;&]C86P@9FEL92!Y;W4@=V%N="!T;R!D;W=N;&]A9"!T;RP*("H@:70@
M:&%S(&YO="!B965N('!O<W-I8FQE('1O(&1O('-O+B!#:&5C:R!T:&%T('EO
M=2!H879E('1H92!A<'!R;W!R:6%T92!A8V-E<W,*("H@<FEG:'1S(&]N('1H
M92!L;V-A;"!F:6QE('1O(&]V97)W<FET92!I="X*("H*("H@0'-I;F-E(#$N
M,PH@*B!`;F%M92!.151?1E107T524E]/5D525U))5$5,3T-!3$9)3$5?1D%)
M3$5$"B`J($!S964@3F5T7T944#HZ9V5T*"DL($YE=%]&5%`Z.F=E=%)E8W5R
M<VEV92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27T]615)74DE414Q/0T%,
M1DE,15]&04E,140G+"`M,30I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD
M:6-A=&4@=&AA="!T:&4@9FEL92!Y;W4@=V%N=&5D('1O('5P;&]A9"!D;V5S
M(&YO="!E>&ES=`H@*B!4:&4@9FEL92!Y;W4@=')I960@=&\@=7!L;V%D(&1O
M97,@;F]T(&5X:7-T+B!%;G-U<F4@=&AA="!I="!E>&ES=',N"B`J"B`J($!S
M:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?3$]#04Q&24Q%3D]415A)
M4U0*("H@0'-E92!.971?1E10.CIP=70H*2P@3F5T7T944#HZ<'5T4F5C=7)S
M:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3$]#04Q&24Q%3D]415A)
M4U0G+"`M,34I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA
M="!A(')E;6]T92!F:6QE(&-O=6QD(&YO="!B92!O=F5R=W)I='1E;@H@*B!9
M;W4@<W!E8VEF:65D(&YO="!T;R!O=F5R=W)I=&4@9FEL97,N(%1H97)E9F]R
M92!T:&4@<F5M;W1E(&9I;&4@:&%S(&YO="!B965N"B`J(&]V97)W<FET96XN
M($EF('EO=2!W86YT('1O(&=E="!T:&4@9FEL92!O=F5R=W)I=&5N+"!P;&5A
M<V4@<V5T('1H92!O<'1I;VX@=&\*("H@9&\@<V\N"B`J"B`J($!S:6YC92`Q
M+C,*("H@0&YA;64@3D547T944%]%4E)?3U9%4E=2251%4D5-3U1%1DE,15]&
M3U)"241$14X*("H@0'-E92!.971?1E10.CIP=70H*2P@3F5T7T944#HZ<'5T
M4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?3U9%4E=2251%
M4D5-3U1%1DE,15]&3U)"241$14XG+"`M,38I.PH*+RHJ"B`J($5R<F]R(&-O
M9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@=7!L;V%D(&]F(&$@9FEL92!F86EL
M960*("H@5&AE('5P;&]A9"!Y;W4@=')I960@9F%I;&5D+B!%;G-U<F4@=&AA
M="!Y;W4@:&%V92!A<'!R;W!R:6%T92!A8V-E<W,@<FEG:'1S"B`J('1O('5P
M;&]A9"!T:&4@9&5S:7)E9"!F:6QE+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N
M86UE($Y%5%]&5%!?15)27U503$]!1$9)3$5?1D%)3$5$"B`J($!S964@3F5T
M7T944#HZ<'5T*"DL($YE=%]&5%`Z.G!U=%)E8W5R<VEV92@I"B`J+PID969I
M;F4H)TY%5%]&5%!?15)27U503$]!1$9)3$5?1D%)3$5$)RP@+3$W*3L*"B\J
M*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@>6]U('-P96-I9FEE
M9"!A;B!I;F-O<G)E8W0@9&ER96-T;W)Y('!A=&@*("H@5&AE(')E;6]T92!P
M871H('EO=2!S<&5C:69I960@<V5E;7,@;F]T('1O(&)E(&$@9&ER96-T;W)Y
M+B!%;G-U<F4@=&AA=`H@*B!T:&4@<&%T:"!Y;W4@<W!E8VEF>2!I<R!A(&1I
M<F5C=&]R>2!A;F0@=&AA="!T:&4@<&%T:"!S=')I;F<@96YD<R!W:71H"B`J
M(&$@+RX*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]2
M14U/5$50051(3D]$25(*("H@0'-E92!.971?1E10.CIP=71296-U<G-I=F4H
M*2P@3F5T7T944#HZ9V5T4F5C=7)S:79E*"D*("HO"F1E9FEN92@G3D547T94
M4%]%4E)?4D5-3U1%4$%42$Y/1$E2)RP@+3$X*3L*"B\J*@H@*B!%<G)O<B!C
M;V1E('1O(&EN9&EC871E('1H870@>6]U('-P96-I9FEE9"!A;B!I;F-O<G)E
M8W0@9&ER96-T;W)Y('!A=&@*("H@5&AE(&QO8V%L('!A=&@@>6]U('-P96-I
M9FEE9"!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN($5N<W5R92!T:&%T
M"B`J('1H92!P871H('EO=2!S<&5C:69Y(&ES(&$@9&ER96-T;W)Y(&%N9"!T
M:&%T('1H92!P871H('-T<FEN9R!E;F1S('=I=&@*("H@82`O+@H@*@H@*B!`
M<VEN8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27TQ/0T%,4$%42$Y/1$E2
M"B`J($!S964@3F5T7T944#HZ<'5T4F5C=7)S:79E*"DL($YE=%]&5%`Z.F=E
M=%)E8W5R<VEV92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27TQ/0T%,4$%4
M2$Y/1$E2)RP@+3$Y*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E
M('1H870@82!L;V-A;"!D:7)E8W1O<GD@9F%I;&5D('1O(&)E(&-R96%T960*
M("H@66]U('1R:65D('1O(&-R96%T92!A(&QO8V%L(&1I<F5C=&]R>2!T:')O
M=6=H(&=E=%)E8W5R<VEV92@I(&UE=&AO9"P*("H@=VAI8V@@:&%S(&9A:6QE
M9"X@16YS=7)E('1H870@>6]U(&AA=F4@=&AE(&%P<')O<')I871E(&%C8V5S
M<R!R:6=H=',*("H@=&\@8W)E871E(&ET+@H@*@H@*B!`<VEN8V4@,2XS"B`J
M($!N86UE($Y%5%]&5%!?15)27T-214%414Q/0T%,1$E27T9!24Q%1`H@*B!`
M<V5E($YE=%]&5%`Z.F=E=%)E8W5R<VEV92@I"B`J+PID969I;F4H)TY%5%]&
M5%!?15)27T-214%414Q/0T%,1$E27T9!24Q%1"<L("TR,"D["@HO*BH*("H@
M17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!P<F]V:61E9"!H;W-T
M;F%M92!W87,@:6YC;W)R96-T"B`J(%1H92!H;W-T;F%M92!Y;W4@<')O=FED
M960@=V%S(&EN=F%L:60N($5N<W5R92!T;R!P<F]V:61E(&5I=&AE<B!A"B`J
M(&9U;&P@<75A;&EF:65D(&1O;6%I;B!N86UE(&]R(&%N($E0(&%D9')E<W,N
M"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?2$]35$Y!
M345.3U-44DE.1PH@*B!`<V5E($YE=%]&5%`Z.G-E=$AO<W1N86UE*"D*("HO
M"F1E9FEN92@G3D547T944%]%4E)?2$]35$Y!345.3U-44DE.1R<L("TR,2D[
M"@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!P<F]V
M:61E9"!P;W)T('=A<R!I;F-O<G)E8W0*("H@5&AE('!O<G0@;G5M8F5R('EO
M=2!P<F]V:61E9"!W87,@:6YV86QI9"X@16YS=7)E('1O('!R;W9I9&4@96ET
M:&5R(&$*("H@82!N=6UE<FEC('!O<G0@;G5M8F5R(&=R96%T97(@>F5R;RX*
M("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]03U)43$53
M4UI%4D\*("H@0'-E92!.971?1E10.CIS9710;W)T*"D*("HO"F1E9FEN92@G
M3D547T944%]%4E)?4$]25$Q%4U-:15)/)RP@+3(R*3L*"B\J*@H@*B!%<G)O
M<B!C;V1E('1O(&EN9&EC871E('1H870@>6]U('!R;W9I9&5D(&%N(&EN=F%L
M:60@;6]D92!C;VYS=&%N=`H@*B!4:&4@;6]D92!C;VYS=&%N="!Y;W4@<')O
M=FED960@=V%S(&EN=F%L:60N(%EO=2!M87D@;VYL>2!P<F]V:61E"B`J($94
M4%]!4T-)22!O<B!&5%!?0DE.05)9+@H@*@H@*B!`<VEN8V4@,2XS"B`J($!N
M86UE($Y%5%]&5%!?15)27TY/34]$14-/3E-4"B`J($!S964@3F5T7T944#HZ
M<V5T36]D92@I"B`J+PID969I;F4H)TY%5%]&5%!?15)27TY/34]$14-/3E-4
M)RP@+3(S*3L*"B\J*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@
M>6]U('!R;W9I9&5D(&%N(&EN=F%L:60@=&EM96]U=`H@*B!4:&4@=&EM96]U
M="!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N(%EO=2!H879E('1O('!R;W9I
M9&4@82!T:6UE;W5T(&=R96%T97(*("H@;W(@97%U86P@=&\@>F5R;RX*("H*
M("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]424U%3U543$53
M4UI%4D\*("H@0'-E92!.971?1E10.CI.971?1E10*"DL($YE=%]&5%`Z.G-E
M=%1I;65O=70H*0H@*B\*9&5F:6YE*"=.151?1E107T524E]424U%3U543$53
M4UI%4D\G+"`M,C0I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@
M=&AA="!Y;W4@<')O=FED960@86X@:6YV86QI9"!T:6UE;W5T"B`J($%N(&5R
M<F]R(&]C8W5R960@=VAI;&4@<V5T=&EN9R!T:&4@=&EM96]U="X@16YS=7)E
M('1H870@>6]U('!R;W9I9&4@80H@*B!V86QI9"!I;G1E9V5R(&9O<B!T:&4@
M=&EM96]U;G0@86YD('1H870@>6]U<B!02%`@:6YS=&%L;&%T:6]N('=O<FMS
M"B`J(&-O<G)E8W1L>2X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.151?
M1E107T524E]3151424U%3U547T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z.DYE
M=%]&5%`H*2P@3F5T7T944#HZ<V5T5&EM96]U="@I"B`J+PID969I;F4H)TY%
M5%]&5%!?15)27U-%5%1)345/551?1D%)3$5$)RP@+3(U*3L*"B\J*@H@*B!%
M<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE('!R;W9I9&5D(&5X=&5N
M<VEO;B!F:6QE(&1O97-N)W0@97AI<W0*("H@5&AE('!R;W9I9&5D(&5X=&5N
M<VEO;B!F:6QE(&1O97,@;F]T(&5X:7-T+B!%;G-U<F4@=&\@<')O=FED960@
M86X*("H@97AI<W1A;G0@97AT96YS:6]N(&9I;&4N"B`J"B`J($!S:6YC92`Q
M+C,*("H@0&YA;64@3D547T944%]%4E)?15A41DE,14Y/5$5825-4"B`J($!S
M964@3F5T7T944#HZ9V5T17AT96YS:6]N1FEL92@I"B`J+PID969I;F4H)TY%
M5%]&5%!?15)27T585$9)3$5.3U1%6$E35"<L("TR-BD["@HO*BH*("H@17)R
M;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!P<F]V:61E9"!E>'1E;G-I
M;VX@9FEL92!I<R!N;W0@<F5A9&%B;&4*("H@5&AE('!R;W9I9&5D(&5X=&5N
M<VEO;B!F:6QE(&ES(&YO="!R96%D86)L92X@16YS=7)E('1O(&AA=F4@<W5F
M9FEC:65N=`H@*B!A8V-E<W,@<FEG:'1S(&9O<B!I="X*("H*("H@0'-I;F-E
M(#$N,PH@*B!`;F%M92!.151?1E107T524E]%6%1&24Q%4D5!1%]&04E,140*
M("H@0'-E92!.971?1E10.CIG971%>'1E;G-I;VY&:6QE*"D*("HO"F1E9FEN
M92@G3D547T944%]%4E)?15A41DE,15)%041?1D%)3$5$)RP@+3(W*3L*"B\J
M*@H@*B!%<G)O<B!C;V1E('1O(&EN9&EC871E('1H870@=&AE(&1E;&5T:6]N
M(&]F(&$@9FEL92!F86EL960*("H@5&AE('-P96-I9FEE9"!F:6QE(&-O=6QD
M(&YO="!B92!D96QE=&5D+B!%;G-U<F4@=&\@:&%V92!S=69F:6-I96YT"B`J
M(&%C8V5S<R!R:6=H=',@=&\@9&5L971E('1H92!F:6QE+@H@*@H@*B!`<VEN
M8V4@,2XS"B`J($!N86UE($Y%5%]&5%!?15)27T585$9)3$5214%$7T9!24Q%
M1`H@*B!`<V5E($YE=%]&5%`Z.G)M*"D*("HO"F1E9FEN92@G3D547T944%]%
M4E)?1$5,151%1DE,15]&04E,140G+"`M,C@I.PH*+RHJ"B`J($5R<F]R(&-O
M9&4@=&\@:6YD:6-A=&4@=&AA="!T:&4@9&5L971I;VX@;V8@82!D:7)E8W1O
M<GD@9F%I;&0*("H@5&AE('-P96-I9FEE9"!F:6QE(&-O=6QD(&YO="!B92!D
M96QE=&5D+B!%;G-U<F4@=&\@:&%V92!S=69F:6-I96YT"B`J(&%C8V5S<R!R
M:6=H=',@=&\@9&5L971E('1H92!F:6QE+@H@*@H@*B!`<VEN8V4@,2XS"B`J
M($!N86UE($Y%5%]&5%!?15)27T585$9)3$5214%$7T9!24Q%1`H@*B!`<V5E
M($YE=%]&5%`Z.G)M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?1$5,151%
M1$E27T9!24Q%1"<L("TR.2D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I
M8V%T92!T:&%T('1H92!D:7)E8W1O<GD@;&ES=&EN9R!F86EL960*("H@4$A0
M(&-O=6QD(&YO="!L:7-T('1H92!D:7)E8W1O<GD@8V]N=&5N=',@;VX@=&AE
M('-E<G9E<BX@16YS=7)E"B`J('1H870@>6]U<B!S97)V97(@:7,@8V]N9FEG
M=7)E9"!A<'!R;W!R:6%T92X*("H*("H@0'-I;F-E(#$N,PH@*B!`;F%M92!.
M151?1E107T524E]205=$25),25-47T9!24Q%1`H@*B!`<V5E($YE=%]&5%`Z
M.FQS*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?4D%71$E23$E35%]&04E,
M140G+"`M,S`I.PH*+RHJ"B`J($5R<F]R(&-O9&4@=&\@:6YD:6-A=&4@=&AA
M="!T:&4@9&ER96-T;W)Y(&QI<W1I;F<@9F%I;&5D"B`J(%1H92!D:7)E8W1O
M<GD@;&ES=&EN9R!F;W)M870@>6]U<B!S97)V97(@=7-E<R!S965M<R!N;W0@
M=&\*("H@8F4@<W5P<&]R=&5D(&)Y($YE=%]&5%`N(%!L96%S92!S96YD('1H
M92!O=71P=70@;V8@=&AE"B`J(&-A;&P@;',H)RXO)RP@3D547T944%]205=,
M25-4*3L@=&\@=&AE(&%U=&AO<B!O9B!T:&ES"B`J(&-L87-S('1O(&=E="!I
M="!S=7!P;W)T960N"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T94
M4%]%4E)?1$E23$E35%]53E-54%!/4E1%1`H@*B!`<V5E($YE=%]&5%`Z.FQS
M*"D*("HO"F1E9FEN92@G3D547T944%]%4E)?1$E23$E35%]53E-54%!/4E1%
M1"<L("TS,2D["@HO*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!F86EL
M960@9&ES8V]N;F5C=&EN9PH@*B!4:&ES(&5R<F]R(&-O9&4@:6YD:6-A=&5S
M+"!T:&%T(&1I<V-O;FYE8W1I;VX@=V%S(&YO="!P;W-S:6)L92X*("H*("H@
M0'-I;F-E(#$N,PH@*B!`;F%M92!.151?1E107T524E]$25-#3TY.14-47T9!
M24Q%1`H@*B!`<V5E($YE=%]&5%`Z.F1I<V-O;FYE8W0H*0H@*B\*9&5F:6YE
M*"=.151?1E107T524E]$25-#3TY.14-47T9!24Q%1"<L("TS,BD["@HO*BH*
M("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!U<V5R;F%M92!Y
M;W4@<')O=FED960@=V%S(&EN=F%L:60N"B`J($-H96-K('1H870@>6]U('!R
M;W9I9&5D(&$@;F]N+65M<'1Y('-T<FEN9R!A<R!T:&4@=7-E<FYA;64N"B`J
M"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?55-%4DY!345.
M3U-44DE.1PH@*B!`<V5E($YE=%]&5%`Z.G-E=%5S97)N86UE*"D*("HO"F1E
M9FEN92@G3D547T944%]%4E)?55-%4DY!345.3U-44DE.1R<L("TS,RD["@HO
M*BH*("H@17)R;W(@8V]D92!T;R!I;F1I8V%T92!T:&%T('1H92!U<V5R;F%M
M92!Y;W4@<')O=FED960@=V%S(&EN=F%L:60N"B`J($-H96-K('1H870@>6]U
M('!R;W9I9&5D(&$@;F]N+65M<'1Y('-T<FEN9R!A<R!T:&4@=7-E<FYA;64N
M"B`J"B`J($!S:6YC92`Q+C,*("H@0&YA;64@3D547T944%]%4E)?4$%34U=/
M4D1.3U-44DE.1PH@*B!`<V5E($YE=%]&5%`Z.G-E=%!A<W-W;W)D*"D*("HO
M"F1E9FEN92@G3D547T944%]%4E)?4$%34U=/4D1.3U-44DE.1R<L("TS,RD[
M"@HO*BH*("H@0VQA<W,@9F]R(&-O;69O<G1A8FQE($944"UC;VUM=6YI8V%T
M:6]N"B`J"B`J(%1H:7,@8VQA<W,@<')O=FED97,@8V]M9F]R=&%B;&4@8V]M
M;75N:6-A=&EO;B!W:71H($944"US97)V97)S+B!9;W4@;6%Y(&1O(&5V97)Y
M=&AI;F<*("H@96YA8FQE9"!B>2!T:&4@4$A0+4944"UE>'1E;G-I;VX@86YD
M(&9U<G1H97(@9G5N8W1I;VYA;&ET:65S+"!L:6ME(')E8W5R<VEV92UD96QE
M=&EO;BP*("H@+75P+2!A;F0@+61O=VYL;V%D+B!!;F]T:&5R(&9E871U<F4@
M:7,@=&\@8W)E871E(&1I<F5C=&]R:65S(')E8W5R<VEV96QY+@H@*@H@*B!`
M;&EC96YS92`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`H@*B!`8V%T96=O<GD@($YE='=O<FMI;F<*("H@
M0'!A8VMA9V4@("!&5%`*("H@0&%U=&AO<B`@("!4;V)I87,@4V-H;&ET="`\
M=&]B>4!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT(#$Y.3<M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!V97)S:6]N("`@4F5L96%S93H@,2XS+C$*("H@0&QI;FL@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O3F5T7T944`H@*B!`
M<VEN8V4@("`@(#`N,"XQ"B`J($!A8V-E<W,@("`@<'5B;&EC"B`J+PIC;&%S
M<R!.971?1E10(&5X=&5N9',@4$5!4B`*>PH@("`@+RHJ"B`@("`@*B!4:&4@
M:&]S="!T;R!C;VYN96-T('1O"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("H@0'9A<B`@("`@<W1R:6YG"B`@("`@*B\*("`@(`H@("`@
M=F%R("1?:&]S=&YA;64["@H@("`@+RHJ"B`@("`@*B!4:&4@<&]R="!F;W(@
M9G1P+6-O;FYE8W1I;VX@*'-T86YD87)D(&ES(#(Q*0H@("`@("H*("`@("`J
M($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@(&EN=`H@("`@("HO
M"B`@("`*("`@('9A<B`D7W!O<G0@/2`R,3L*"B`@("`O*BH*("`@("`J(%1H
M92!U<V5R;F%M92!F;W(@;&]G:6X*("`@("`J"B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B!`=F%R("`@("!S=')I;F<*("`@("`J+PH@("`@"B`@
M("!V87(@)%]U<V5R;F%M93L*"B`@("`O*BH*("`@("`J(%1H92!P87-S=V]R
M9"!F;W(@;&]G:6X*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B!`=F%R("`@("!S=')I;F<*("`@("`J+PH@("`@"B`@("!V87(@)%]P
M87-S=V]R9#L*"B`@("`O*BH*("`@("`J($1E=&5R;6EN92!W:&5T:&5R('1O
M('5S92!P87-S:79E+6UO9&4@*'1R=64I(&]R(&%C=&EV92UM;V1E("AF86QS
M92D*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`=F%R
M("`@("!B;V]L"B`@("`@*B\*("`@(`H@("`@=F%R("1?<&%S<W8["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<W1A;F1A<F0@;6]D92!F;W(@9G1P+71R86YS9F5R
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@
M("`@:6YT"B`@("`@*B\*("`@(`H@("`@=F%R("1?;6]D92`]($944%]"24Y!
M4ED["@H@("`@+RHJ"B`@("`@*B!4:&ES(&AO;&1S('1H92!H86YD;&4@9F]R
M('1H92!F='`M8V]N;F5C=&EO;@H@("`@("H*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J($!V87(@("`@(')E<V]U<F-E"B`@("`@*B\*("`@(`H@
M("`@=F%R("1?:&%N9&QE.PH*("`@("\J*@H@("`@("H@0V]N=&%I;G,@=&AE
M('1I;65O=70@9F]R($944"!O<&5R871I;VYS"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@:6YT"B`@("`@*B!`<VEN
M8V4@("`Q+C,*("`@("`J+PH@("`@"B`@("!V87(@)%]T:6UE;W5T(#T@.3`[
M"B`@("`@("`@"B`@("`O*BH*("`@("`J(%-A=F5S(&9I;&4M97AT96YS:6]N
M<R!F;W(@87-C:6DM(&%N9"!B:6YA<GDM;6]D90H@("`@("H*("`@("`J(%1H
M92!A<G)A>2!C;VYT86EN<R`R('-U8BUA<G)A>7,@*")A<V-I:2(@86YD(")B
M:6YA<GDB*2P@=VAI8V@@8F]T:"!C;VYT86EN"B`@("`@*B!F:6QE+65X=&5N
M<VEO;G,@=VET:&]U="!T:&4@(BXB("@B+G!H<"(@/2`B<&AP(BDN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'9A<B`@("`@87)R
M87D*("`@("`J+PH@("`@"B`@("!V87(@)%]F:6QE7V5X=&5N<VEO;G,["@H@
M("`@+RHJ"B`@("`@*B!L<R!M871C:`H@("`@("H@36%T8VAE<R!T:&4@;',@
M96YT<FEE<R!A9V%I;G-T(&$@<F5G97@@86YD(&UA<',@=&AE(')E<W5L=&EN
M9R!A<G)A>2!T;R!S<&5A:VEN9R!N86UE<PH@("`@("H*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J($!V87(@("`@(&%R<F%Y"B`@("`@*B!`<VEN
M8V4@("`Q+C,*("`@("`J+PH@("`@"B`@("!V87(@)%]L<U]M871C:"`](&%R
M<F%Y*`H@("`@("`@("=U;FEX)R`@("`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W!A='1E<FXG(#T^("<O*#\Z*&0I?"XI*%MR=WAT+5TK*5QS*RA<=RLI7',K
M*%M<=UQD72LI7',K*%M<=UQD72LI7',K*%QW*RE<<RLH7%,K7',K7%,K7',K
M7%,K*5QS*R@N*RDO)RP*("`@("`@("`@("`@)VUA<"<@("`@(#T^(&%R<F%Y
M*"=N86UE)ST^."PG<VEZ92<]/C8L)W)I9VAT<R<]/C(L)W5S97(G/3XT+"=G
M<F]U<"<]/C4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=F:6QE
M<U]I;G-I9&4G/3XS+"=D871E)ST^-RPG:7-?9&ER)ST^,2D*("`@("`@("`I
M+`H@("`@("`@("=W:6YD;W=S)R`]/B!A<G)A>2@*("`@("`@("`@("`@)W!A
M='1E<FXG(#T^("<O*"XK*5QS*R@N*RE<<RLH*#Q$25(^*7Q;,"TY72LI7',K
M*"XK*2\G+`H@("`@("`@("`@("`G;6%P)R`@("`@/3X@87)R87DH)VYA;64G
M/3XU+"=D871E)ST^,2PG:7-?9&ER)ST^,RD*("`@("`@("`I"B`@("`I.PH@
M("`@"B`@("`O*BH*("`@("`J(&UA=&-H97(*("`@("`J(%-T;W)E<R!T:&4@
M;6%T8VAE<B!F;W(@=&AE(&-U<G)E;G0@8V]N;F5C=&EO;@H@("`@("H*("`@
M("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!V87(@("`@(&%R<F%Y"B`@
M("`@*B!`<VEN8V4@("`Q+C,*("`@("`J+PH@("`@=F%R("1?;6%T8VAE<B`]
M(&YU;&P["B`@("`*("`@("\J*@H@("`@("H@2&]L9',@86QL($YE=%]&5%!?
M3V)S97)V97(@;V)J96-T<R`*("`@("`J('1H870@=VES:"!T;R!B92!N;W1I
M9FEE9"!O9B!N97<@;65S<V%G97,N"B`@("`@*@H@("`@("H@0'9A<B`@("`@
M87)R87D*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!S:6YC92`@
M(#$N,PH@("`@("HO"B`@("`*("`@('9A<B`D7VQI<W1E;F5R<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!4:&ES(&=E;F5R871E<R!A(&YE=R!&5%`M
M3V)J96-T+B!4:&4@1E10+6-O;FYE8W1I;VX@=VEL;"!N;W0@8F4@97-T86)L
M:7-H960L('EE="X*("`@("`J(%EO=2!C86X@;&5A=F4@)&AO<W0@86YD("1P
M;W)T(&)L86YK+"!I9B!Y;W4@=V%N="X@5&AE("1H;W-T('=I;&P@;F]T(&)E
M('-E=`H@("`@("H@86YD('1H92`D<&]R="!W:6QL(&)E(&QE9G0@870@,C$N
M(%EO=2!H879E('1O('-E="!T:&4@)&AO<W0@;6%N=6%L>2!B969O<F4*("`@
M("`J('1R>6EN9R!T;R!C;VYN96-T(&]R('=I=&@@=&AE(&-O;FYE8W0H*2!M
M971H;V0N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@)&AO<W0@("`@*&]P=&EO;F%L*2!4:&4@:&]S=&YA
M;64@"B`@("`@*B!`<&%R86T@("!I;G0@("`@)'!O<G0@("`@*&]P=&EO;F%L
M*2!4:&4@<&]R=`H@("`@("H@0'!A<F%M("`@:6YT("`@("1T:6UE;W5T("AO
M<'1I;VYA;"D@4V5T<R!T:&4@<W1A;F1A<F0@=&EM96]U=`H@("`@("H@0')E
M='5R;B`@=F]I9`H@("`@("H@0'-E92`@("`@3F5T7T944#HZ<V5T2&]S=&YA
M;64H*2P@3F5T7T944#HZ<V5T4&]R="@I+"!.971?1E10.CIC;VYN96-T*"D*
M("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!.971?1E10*"1H;W-T(#T@;G5L
M;"P@)'!O<G0@/2!N=6QL+"`D=&EM96]U="`](#DP*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y014%2*"D["B`@("`@("`@:68@*&ES<V5T*"1H;W-T*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^<V5T2&]S=&YA;64H)&AO<W0I.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)'!O<G0I*2!["B`@("`@("`@("`@("1T
M:&ES+3YS9710;W)T*"1P;W)T*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/E]T:6UE;W5T(#T@)'1I;65O=70["B`@("`@("`@)'1H:7,M/E]F:6QE7V5X
M=&5N<VEO;G-;1E107T%30TE)72`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M
M/E]F:6QE7V5X=&5N<VEO;G-;1E107T))3D%265T@/2!A<G)A>2@I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!G96YE<F%T97,@=&AE
M($944"UC;VYN96-T:6]N+B!9;W4@8V%N(&]P=&EO;F%L;'D@9&5F:6YE(&$*
M("`@("`J(&AO<W1N86UE(&%N9"]O<B!A('!O<G0N($EF('EO=2!D;R!S;RP@
M=&AI<R!D871A(&ES('-T;W)E9"!I;G-I9&4@=&AE(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN
M9R`D:&]S="`@("`H;W!T:6]N86PI(%1H92!(;W-T;F%M90H@("`@("H@0'!A
M<F%M("`@:6YT("`@("1P;W)T("`@("AO<'1I;VYA;"D@5&AE(%!O<G0@"B`@
M("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@5')U92!O;B!S=6-C97-S
M+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&
M5%!?15)27T-/3DY%0U1?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I
M;VX@8V]N;F5C="@D:&]S="`](&YU;&PL("1P;W)T(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7VUA=&-H97(@/2!N=6QL.PH@("`@("`@(&EF("AI
M<W-E="@D:&]S="DI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$AO<W1N86UE
M*"1H;W-T*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P;W)T*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5T4&]R="@D<&]R="D["B`@("`@("`@
M?0H@("`@("`@("1H86YD;&4@/2!`9G1P7V-O;FYE8W0H)'1H:7,M/F=E=$AO
M<W1N86UE*"DL("1T:&ES+3YG9710;W)T*"DL("1T:&ES+3Y?=&EM96]U="D[
M"B`@("`@("`@:68@*"$D:&%N9&QE*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B0V]N;F5C=&EO;B!T;R!H;W-T(&9A:6QE9"(L
M($Y%5%]&5%!?15)27T-/3DY%0U1?1D%)3$5$*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7VAA;F1L92`])B`D:&%N9&QE.PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&9U;F-T:6]N(&-L;W-E('1H92!&5%`M8V]N;F5C=&EO
M;@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R
M;B`@8F]O;'Q014%27T5R<F]R(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!0
M14%27T5R<F]R(&]N(&9A:6QU<F4*("`@("`J+PH@("`@"B`@("!F=6YC=&EO
M;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D<F5S(#T@0&9T<%]C;&]S
M92@D=&AI<RT^7VAA;F1L92D["B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=$:7-C;VYN96-T(&9A
M:6QE9"XG+"!.151?1E107T524E]$25-#3TY.14-47T9!24Q%1"D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AI<R!L;V=G97,@>6]U(&EN=&\@=&AE(&9T<"US97)V97(N(%EO=2!A
M<F4@9G)E92!T;R!S<&5C:69Y('5S97)N86UE(&%N9"!P87-S=V]R9`H@("`@
M("H@:6X@=&AI<R!M971H;V0N($EF('EO=2!S<&5C:69Y(&ET+"!T:&4@=F%L
M=65S('=I;&P@8F4@=&%K96X@:6YT;R!T:&4@8V]R<F5S<&]N9&EN9PH@("`@
M("H@871T<FEB=71E<RP@:68@9&\@;F]T('-P96-I9GDL('1H92!A='1R:6)U
M=&5S(&%R92!T86ME;BX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!P87)A;2`@('-T<FEN9R`D=7-E<FYA;64@("AO<'1I;VYA;"D@
M5&AE('5S97)N86UE('1O('5S92`*("`@("`J($!P87)A;2`@('-T<FEN9R`D
M<&%S<W=O<F0@("AO<'1I;VYA;"D@5&AE('!A<W-W;W)D('1O('5S90H@("`@
M("H@0')E='5R;B`@;6EX960@("`@("`@("`@("`@5')U92!O;B!S=6-C97-S
M+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&
M5%!?15)27TQ/1TE.7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N
M(&QO9VEN*"1U<V5R;F%M92`](&YU;&PL("1P87-S=V]R9"`](&YU;&PI"B`@
M("!["B`@("`@("`@:68@*"%I<W-E="@D=7-E<FYA;64I*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("1T:&ES+3YG9715<V5R;F%M92@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS9715<V5R;F%M92@D=7-E
M<FYA;64I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%I<W-E="@D<&%S<W=O
M<F0I*2!["B`@("`@("`@("`@("1P87-S=V]R9"`]("1T:&ES+3YG971087-S
M=V]R9"@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YS
M971087-S=V]R9"@D<&%S<W=O<F0I.PH@("`@("`@('T*"B`@("`@("`@)')E
M<R`]($!F='!?;&]G:6XH)'1H:7,M/E]H86YD;&4L("1U<V5R;F%M92P@)'!A
M<W-W;W)D*3L*"B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B56YA8FQE('1O(&QO9VEN(BP@3D54
M7T944%]%4E)?3$]'24Y?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:&ES(&-H86YG97,@=&AE(&-U<G)E;G1L>2!U<V5D(&1I<F5C
M=&]R>2X@66]U(&-A;B!U<V4@96ET:&5R(&%N(&%B<V]L=71E"B`@("`@*B!D
M:7)E8W1O<GDM<&%T:"`H92YG+B`B+VAO;64O8FQA:"(I(&]R(&$@<F5L871I
M=F4@;VYE("AE+F<N("(N+B]T97-T(BDN"B`@("`@*@H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&1I<B`@5&AE(&1I
M<F5C=&]R>2!T;R!G;R!T;RX*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@
M("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@
M("H@0'-E92`@("`@3D547T944%]%4E)?1$E20TA!3D=%7T9!24Q%1`H@("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N(&-D*"1D:7(I"B`@("!["B`@("`@("`@
M)&5R9R`]($!F='!?8VAD:7(H)'1H:7,M/E]H86YD;&4L("1D:7(I.PH@("`@
M("`@(&EF("@A)&5R9RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(D1I<F5C=&]R>2!C:&%N9V4@9F%I;&5D(BP@3D547T944%]%
M4E)?1$E20TA!3D=%7T9!24Q%1"D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4VAO=R=S('EO=2!T:&4@86-T=6%L('!A=&@@;VX@=&AE('-E<G9E
M<@H@("`@("H@5&AI<R!F=6YC=&EO;B!Q=65S=&EO;G,@=&AE(&9T<"UH86YD
M;&4@9F]R('1H92!A8W1U86P@<V5L96-T960@<&%T:"!A;F0@<F5T=7)N<R!I
M="X*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U
M<FX@(&UI>&5D("`@("`@("!4:&4@86-T=6%L('!A=&@@;W(@4$5!4CHZ17)R
M;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27T1%5$5234E.15!!5$A?
M1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<'=D*"D*("`@('L*
M("`@("`@("`D<F5S(#T@0&9T<%]P=V0H)'1H:7,M/E]H86YD;&4I.PH@("`@
M("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H(D-O=6QD(&YO="!D971E<FUI;F4@=&AE(&%C='5A;"!P871H
M+B(L($Y%5%]&5%!?15)27T1%5$5234E.15!!5$A?1D%)3$5$*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES('=O<FMS('-I;6EL87(@=&\@
M=&AE(&UK9&ER+6-O;6UA;F0@;VX@>6]U<B!L;V-A;"!M86-H:6YE+B!9;W4@
M8V%N(&5I=&AE<B!G:79E"B`@("`@*B!I="!A;B!A8G-O;'5T92!O<B!R96QA
M=&EV92!P871H+B!4:&4@<F5L871I=F4@<&%T:"!W:6QL(&)E(&-O;7!L971E
M9"!W:71H('1H92!A8W1U86P*("`@("`J('-E;&5C=&5D('-E<G9E<BUP871H
M+B`H<V5E.B!P=V0H*2D*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("`@("`@($%B<V]L=71E(&]R
M(')E;&%T:79E(&1I<BUP871H"B`@("`@*B!`<&%R86T@("!B;V]L("`@)')E
M8W5R<VEV92`H;W!T:6]N86PI($-R96%T92!A;&P@;F5E9&5D(&1I<F5C=&]R
M:65S"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("!4<G5E(&]N
M('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@
M("`@3D547T944%]%4E)?0U)%051%1$E27T9!24Q%1`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N(&UK9&ER*"1D:7(L("1R96-U<G-I=F4@/2!F86QS92D*
M("`@('L*("`@("`@("`D9&ER(#T@)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D
M9&ER*3L*("`@("`@("`D<V%V961I<B`]("1T:&ES+3YP=V0H*3L*("`@("`@
M("`D=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PH@("`@("`@("1E(#T@)'1H:7,M/F-D*"1D:7(I.PH@("`@("`@("1T:&ES
M+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@:68@*"1E(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@("1T:&ES+3YC9"@D<V%V961I<BD["B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^8V0H
M)'-A=F5D:7(I.PH@("`@("`@(&EF("@D<F5C=7)S:79E(#T]/2!F86QS92E[
M"B`@("`@("`@("`@("1R97,@/2!`9G1P7VUK9&ER*"1T:&ES+3Y?:&%N9&QE
M+"`D9&ER*3L*("`@("`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-R96%T:6]N(&]F("<D
M9&ER)R!F86EL960B+"!.151?1E107T524E]#4D5!5$5$25)?1D%)3$5$*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@:68H<W1R<&]S*"1D:7(L("<O)RD@/3T](&9A;'-E*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/FUK9&ER*"1D:7(L9F%L<V4I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1P;W,@/2`P.PH@("`@("`@("`@("`D
M<F5S(#T@)'1H:7,M/FUK9&ER*&1I<FYA;64H)&1I<BDL('1R=64I.PH@("`@
M("`@("`@("`D<F5S(#T@)'1H:7,M/FUK9&ER*"1D:7(L(&9A;'-E*3L*("`@
M("`@("`@("`@:68@*"1R97,@(3T]('1R=64I('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@
M;65T:&]D('1R:65S(&5X96-U=&EN9R!A(&-O;6UA;F0@;VX@=&AE(&9T<"P@
M=7-I;F<@4TE412!%6$5#+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1C;VUM86YD(%1H92!C;VUM86YD
M('1O(&5X96-U=&4*("`@("`J($!R971U<FX@(&UI>&5D("`@("`@("`@("!4
M:&4@<F5S=6QT(&]F('1H92!C;VUM86YD("AI9B!S=6-C97-S9G5L;"DL(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?15A%0U]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!E>&5C
M=71E*"1C;VUM86YD*0H@("`@>PH@("`@("`@("1R97,@/2!`9G1P7V5X96,H
M)'1H:7,M/E]H86YD;&4L("1C;VUM86YD*3L*("`@("`@("!I9B`H(21R97,I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")%>&5C
M=71I;VX@;V8@8V]M;6%N9"`G)&-O;6UA;F0G(&9A:6QE9"XB+"!.151?1E10
M7T524E]%6$5#7T9!24Q%1"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@17AE8W5T92!A(%-)5$4@8V]M;6%N9"!O;B!T:&4@<V5R=F5R"B`@("`@
M*B!4:&ES(&UE=&AO9"!T<FEE<R!T;R!E>&5C=71E(&$@4TE412!C;VUM86YD
M(&]N('1H92!F='`@<V5R=F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1C;VUM86YD("`@5&AE(&-O
M;6UA;F0@=VET:"!P87)A;65T97)S('1O(&5X96-U=&4*("`@("`J($!R971U
M<FX@(&UI>&5D("`@("`@("`@("`@(%1R=64@:68@<W5C8V5S<V9U;"P@;W1H
M97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T52
M4E]3251%7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N('-I=&4H
M)&-O;6UA;F0I"B`@("!["B`@("`@("`@)')E<R`]($!F='!?<VET92@D=&AI
M<RT^7VAA;F1L92P@)&-O;6UA;F0I.PH@("`@("`@(&EF("@A)')E<RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D5X96-U=&EO
M;B!O9B!3251%(&-O;6UA;F0@)R1C;VUM86YD)R!F86EL960N(BP@3D547T94
M4%]%4E)?4TE415]&04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@;65T:&]D('=I;&P@=')Y('1O(&-H;6]D('1H92!F:6QE('-P
M96-I9FEE9"!O;B!T:&4@<V5R=F5R"B`@("`@*B!#=7)R96YT;'DL('EO=2!M
M=7-T(&=I=F4@82!N=6UB97(@87,@=&AE('1H92!P97)M:7-S:6]N(&%R9W5M
M96YT("@W-S<@;W(*("`@("`J('-I;6EL87(I+B!4:&4@9FEL92!C86X@8F4@
M96ET:&5R(&$@<F5L871I=F4@;W(@86)S;VQU=&4@<&%T:"X*("`@("`J($Y/
M5$4Z(%-O;64@<V5R=F5R<R!D;R!N;W0@<W5P<&]R="!T:&ES(&9E871U<F4N
M($EN('1H870@8V%S92P@>6]U('=I;&P*("`@("`J(&=E="!A(%!%05(@97)R
M;W(@;V)J96-T(')E='5R;F5D+B!)9B!S=6-C97-S9G5L+"!T:&4@;65T:&]D
M(')E='5R;G,@=')U90H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'!A<F%M("`@;6EX960@("`D=&%R9V5T("`@("`@("!4:&4@9FEL
M92!O<B!A<G)A>2!O9B!F:6QE<R!T;R!S970@<&5R;6ES<VEO;G,@9F]R"B`@
M("`@*B!`<&%R86T@("!I;G1E9V5R("1P97)M:7-S:6]N<R`@(%1H92!M;V1E
M('1O('-E="!T:&4@9FEL92!P97)M:7-S:6]N<R!T;PH@("`@("H@0')E='5R
M;B`@;6EX960@("`@("`@("`@("`@("`@("!4<G5E(&EF('-U8V-E<W-F=6PL
M(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T94
M4%]%4E)?0TA-3T1?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M8VAM;V0H)'1A<F=E="P@)'!E<FUI<W-I;VYS*0H@("`@>PH@("`@("`@("\O
M($EF("1T87)G970@:7,@86X@87)R87DZ($QO;W`@=&AR;W5G:"!I="X*("`@
M("`@("!I9B`H:7-?87)R87DH)'1A<F=E="DI('L*"B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T87)G970I.R`D:2LK*2!["B`@("`@
M("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F-H;6]D*"1T87)G971;)&E=+"`D
M<&5R;6ES<VEO;G,I.PH@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)')E<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<SL*
M("`@("`@("`@("`@("`@('T@+R\@96YD(&EF(&ES17)R;W(*("`@("`@("`@
M("`@?2`O+R!E;F0@9F]R(&D@/"!C;W5N="@D=&%R9V5T*0H*("`@("`@("!]
M(&5L<V4@>PH*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YS:71E*")#2$U/
M1"`B("X@)'!E<FUI<W-I;VYS("X@(B`B("X@)'1A<F=E="D["B`@("`@("`@
M("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H(D-(34]$("(@+B`D<&5R;6ES<VEO;G,@+B`B("(@+B`D
M=&%R9V5T("X@(B!F86EL960B+"!.151?1E107T524E]#2$U/1%]&04E,140I
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M("1R97,["B`@("`@("`@("`@('T*"B`@("`@("`@?2`O+R!E;F0@:68@:7-?
M87)R87D*"B`@("!]("\O(&5N9"!M971H;V0@8VAM;V0*"B`@("`O*BH*("`@
M("`J(%1H:7,@;65T:&]D('=I;&P@=')Y('1O(&-H;6]D(&$@9F]L9&5R(&%N
M9"!A;&P@;V8@:71S(&-O;G1E;G1S"B`@("`@*B!O;B!T:&4@<V5R=F5R+B!4
M:&4@=&%R9V5T(&%R9W5M96YT(&UU<W0@8F4@82!F;VQD97(@;W(@86X@87)R
M87D@;V8@9F]L9&5R<PH@("`@("H@86YD('1H92!P97)M:7-S:6]N<R!A<F=U
M;65N="!H879E('1O(&)E(&%N(&EN=&5G97(@*&DN92X@-S<W*2X*("`@("`J
M(%1H92!F:6QE(&-A;B!B92!E:71H97(@82!R96QA=&EV92!O<B!A8G-O;'5T
M92!P871H+@H@("`@("H@3D]413H@4V]M92!S97)V97)S(&1O(&YO="!S=7!P
M;W)T('1H:7,@9F5A='5R92X@26X@=&AA="!C87-E+"!Y;W4*("`@("`J('=I
M;&P@9V5T(&$@4$5!4B!E<G)O<B!O8FIE8W0@<F5T=7)N960N($EF('-U8V-E
M<W-F=6PL('1H92!M971H;V0*("`@("`J(')E='5R;G,@=')U90H@("`@("H*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@;6EX960@
M("`D=&%R9V5T("`@("`@("!4:&4@9F]L9&5R(&]R(&%R<F%Y(&]F(&9O;&1E
M<G,@=&\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<V5T('!E<FUI<W-I;VYS(&9O<@H@("`@("H@0'!A<F%M("`@:6YT96=E<B`D
M<&5R;6ES<VEO;G,@("!4:&4@;6]D92!T;R!S970@=&AE(&9O;&1E<@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A;F0@9FEL92!P
M97)M:7-S:6]N<R!T;PH@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@
M("`@("`@("!4<G5E(&EF('-U8V-E<W-F=6PL(&]T:&5R=VES92!014%2.CI%
M<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%4E)?0TA-3T1?1D%)3$5$
M+"!.151?1E107T524E]$151%4DU)3D50051(7T9!24Q%1"P@3D547T944%]%
M4E)?4D%71$E23$E35%]&04E,140L($Y%5%]&5%!?15)27T1)4DQ)4U1?54Y3
M55!03U)4140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!C:&UO9%)E8W5R
M<VEV92@D=&%R9V5T+"`D<&5R;6ES<VEO;G,I"B`@("!["B`@("`@("`@<W1A
M=&EC("1D:7)?<&5R;6ES<VEO;G,["@H@("`@("`@(&EF*"%I<W-E="@D9&ER
M7W!E<FUI<W-I;VYS*2E[("\O($UA:VEN9R!D:7)E8W1O<GD@<W!E8VEF:6,@
M<&5R;6ES<VEO;G,*("`@("`@("`@("`@)&1I<E]P97)M:7-S:6]N<R`]("1T
M:&ES+3Y?;6%K941I<E!E<FUI<W-I;VYS*"1P97)M:7-S:6]N<RD["B`@("`@
M("`@?0H*("`@("`@("`O+R!)9B`D=&%R9V5T(&ES(&%N(&%R<F%Y.B!,;V]P
M('1H<F]U9V@@:70*("`@("`@("!I9B`H:7-?87)R87DH)'1A<F=E="DI('L*
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T87)G970I
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F-H;6]D
M4F5C=7)S:79E*"1T87)G971;)&E=+"`D<&5R;6ES<VEO;G,I.PH@("`@("`@
M("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@("`@('T@+R\@
M96YD(&EF(&ES17)R;W(*("`@("`@("`@("`@?2`O+R!E;F0@9F]R(&D@/"!C
M;W5N="@D=&%R9V5T*0H*("`@("`@("!](&5L<V4@>PH*("`@("`@("`@("`@
M)')E;6]T95]P871H(#T@)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D=&%R9V5T
M*3L*"B`@("`@("`@("`@("\O($-H;6]D('1H92!D:7)E8W1O<GD@:71S96QF
M"B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^8VAM;V0H)')E;6]T95]P
M871H+"`D9&ER7W!E<FUI<W-I;VYS*3L*"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@268@)')E
M;6]T95]P871H(&QA<W0@8VAA<F%C=&5R(&ES(&YO="!A('-L87-H+"!A9&0@
M;VYE"B`@("`@("`@("`@(&EF("AS=6)S='(H)')E;6]T95]P871H+"!S=')L
M96XH)')E;6]T95]P871H*2TQ*2`A/2`B+R(I('L*"B`@("`@("`@("`@("`@
M("`D<F5M;W1E7W!A=&@@+CT@(B\B.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D9&ER7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("`@("`D;6]D92`]
M($Y%5%]&5%!?1$E24U]/3DQ9.PH@("`@("`@("`@("`D9&ER7VQI<W0@/2`D
M=&AI<RT^;',H)')E;6]T95]P871H+"`D;6]D92D["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1D:7)?;&ES="!A<R`D9&ER7V5N=')Y*2!["@H@("`@("`@("`@
M("`@("`@)')E;6]T95]P871H7VYE=R`]("1R96UO=&5?<&%T:"XD9&ER7V5N
M=')Y6R)N86UE(ETN(B\B.PH*("`@("`@("`@("`@("`@("\O($-H;6]D('1H
M92!D:7)E8W1O<GD@=V4G<F4@86)O=70@=&\@96YT97(*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^8VAM;V0H)')E;6]T95]P871H7VYE=RP@
M)&1I<E]P97)M:7-S:6]N<RD["@H@("`@("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F-H;6]D4F5C=7)S:79E*"1R96UO=&5?<&%T
M:%]N97<L("1P97)M:7-S:6]N<RD["@H@("`@("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@
M('T@+R\@96YD(&9O<F5A8V@@9&ER7VQI<W0@87,@9&ER7V5N=')Y"@H@("`@
M("`@("`@("`D9FEL95]L:7-T(#T@87)R87DH*3L*("`@("`@("`@("`@)&UO
M9&4@/2!.151?1E107T9)3$537T].3%D["B`@("`@("`@("`@("1F:6QE7VQI
M<W0@/2`D=&AI<RT^;',H)')E;6]T95]P871H+"`D;6]D92D["@H@("`@("`@
M("`@("!F;W)E86-H("@D9FEL95]L:7-T(&%S("1F:6QE7V5N=')Y*2!["@H@
M("`@("`@("`@("`@("`@)')E;6]T95]F:6QE(#T@)')E;6]T95]P871H+B1F
M:6QE7V5N=')Y6R)N86UE(ET["@H@("`@("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YC:&UO9"@D<F5M;W1E7V9I;&4L("1P97)M:7-S:6]N<RD["@H@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('T@+R\@96YD(&9O<F5A8V@@)&9I;&5?
M;&ES=`H*("`@("`@("!]("\O(&5N9"!I9B!I<U]A<G)A>0H*("`@("`@("!R
M971U<FX@=')U93L@+R\@3F\@97)R;W)S"@H@("`@?2`O+R!E;F0@;65T:&]D
M(&-H;6]D4F5C=7)S:79E"@H@("`@+RHJ"B`@("`@*B!296YA;64@;W(@;6]V
M92!A(&9I;&4@;W(@82!D:7)E8W1O<GD@9G)O;2!T:&4@9G1P+7-E<G9E<@H@
M("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@
M<W1R:6YG("1R96UO=&5?9G)O;2!4:&4@<F5M;W1E(&9I;&4@;W(@9&ER96-T
M;W)Y(&]R:6=I;F%L('1O(')E;F%M92!O<B!M;W9E"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@)')E;6]T95]T;R!4:&4@<F5M;W1E(&9I;&4@;W(@9&ER96-T
M;W)Y(&9I;F%L('1O(')E;F%M92!O<B!M;W9E"B`@("`@*B!`<F5T=7)N("!B
M;V]L("1R97,@5')U92!O;B!S=6-C97-S+"!O=&AE<G=I<V4@4$5!4CHZ17)R
M;W(*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U)%3D%-15]&04E,140*
M("`@("`J+PH*("`@(&9U;F-T:6]N(')E;F%M92`H)')E;6]T95]F<F]M+"`D
M<F5M;W1E7W1O*2`*("`@('L*("`@("`@("`D<F5S(#T@0&9T<%]R96YA;64H
M)'1H:7,M/E]H86YD;&4L("1R96UO=&5?9G)O;2P@)')E;6]T95]T;RD["B`@
M("`@("`@:68H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")#;W5L9"!N;W0@<F5N86UE("(N)')E;6]T95]F<F]M+B(@
M=&\@(BXD<F5M;W1E7W1O+B(@(2(L($Y%5%]&5%!?15)27U)%3D%-15]&04E,
M140I.PH@("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%1H:7,@=VEL;"!R971U<FX@;&]G:6-A;"!P97)M:7-S
M:6]N<R!M87-K(&9O<B!D:7)E8W1O<GDN"B`@("`@*B!I9B!D:7)E8W1O<GD@
M:&%V92!T;R!B92!W<FET96%B;&4@:70@:&%V92!A;'-O(&)E(&5X96-U=&%B
M;&4*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@)'!E<FUI<W-I;VYS("`@($9I;&4@<&5R;6ES<VEO;G,@
M:6X@9&EG:71S(&9O<B!F:6QE("AI+F4N(#8V-BD*("`@("`J($!R971U<FX@
M('-T<FEN9R`@("`@("`@("`@("`@("`@1FEL92!P97)M:7-S:6]N<R!I;B!D
M:6=I=',@9F]R(&1I<F5C=&]R>2`H:2YE+B`W-S<I"B`@("`@*B\*"B`@("!F
M=6YC=&EO;B!?;6%K941I<E!E<FUI<W-I;VYS*"1P97)M:7-S:6]N<RE["B`@
M("`@("`@)'!E<FUI<W-I;VYS(#T@*'-T<FEN9RDD<&5R;6ES<VEO;G,["@H@
M("`@("`@(&9O<B@D:2`](#`[("1I(#P@<W1R;&5N*"1P97)M:7-S:6]N<RD[
M("1I*RLI>R`O+R!G;VEN9R!T:')O=6=H("AU<V5R+"!G<F]U<"P@=V]R;&0I
M"B`@("`@("`@("`@(&EF*"AI;G0I)'!E<FUI<W-I;VYS>R1I?2`F(#0@86YD
M("$H*&EN="DD<&5R;6ES<VEO;G-[)&E]("8@,2DI>R`O+R!296%D('!E<FUI
M<W-I;VX@:7,@<V5T"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!B=70@97AE8W5T92!N;W0@>65T"B`@("`@("`@("`@("`@("`H:6YT*21P
M97)M:7-S:6]N<WLD:7T@/2`H:6YT*21P97)M:7-S:6]N<WLD:7T@*R`Q.R`O
M+R!!9&1I;F<@97AE8W5T92!F;&%G"B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`H<W1R:6YG*21P97)M:7-S:6]N<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(%1H:7,@=VEL;"!R971U<FX@=&AE(&QA<W0@;6]D
M:69I8V%T:6]N+71I;64@;V8@82!F:6QE+B!9;W4@8V%N(&5I=&AE<B!G:79E
M('1H:7,*("`@("`J(&9U;F-T:6]N(&$@<F5L871I=F4@;W(@86X@86)S;VQU
M=&4@<&%T:"!T;R!T:&4@9FEL92!T;R!C:&5C:RX*("`@("`J($Y/5$4Z(%-O
M;64@<V5R=F5R<R!W:6QL(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92!A;F0@
M=&AE(&9U;F-T:6]N('=O<FMS"B`@("`@*B!O;FQY(&]N(&9I;&5S+"!N;W0@
M9&ER96-T;W)I97,A(%=H96X@<W5C8V5S<V9U;"P*("`@("`J(&ET('=I;&P@
M<F5T=7)N('1H92!L87-T(&UO9&EF:6-A=&EO;BUT:6UE(&%S(&$@=6YI>"UT
M:6UE<W1A;7`@;W(L('=H96X@)&9O<FUA="!I<PH@("`@("H@<W!E8VEF:65D
M+"!A('!R969O<FUA=&5D('1I;65S=')I;F<N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&9I;&4@("`@
M5&AE(&9I;&4@=&\@8VAE8VL*("`@("`J($!P87)A;2`@('-T<FEN9R`D9F]R
M;6%T("`H;W!T:6]N86PI(%1H92!F;W)M870@=&\@9VEV92!T:&4@9&%T92!B
M86-K(`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&EF(&YO="!S
M970L(&ET('=I;&P@<F5T=7)N(&$@56YI>"!T:6UE<W1A;7`*("`@("`J($!R
M971U<FX@(&UI>&5D("`@("`@("`@("!5;FEX('1I;65S=&%M<"P@82!P<F5F
M;W)M871E9"!D871E+7-T<FEN9R!O<B!014%2.CI%<G)O<@H@("`@("H@0'-E
M92`@("`@3D547T944%]%4E)?3414341)4E]53E-54%!/4E1%1"P@3D547T94
M4%]%4E)?341435]&04E,140L($Y%5%]&5%!?15)27T1!5$5&3U)-051?1D%)
M3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@;61T;2@D9FEL92P@)&9O
M<FUA="`](&YU;&PI"B`@("!["B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7V-O
M;G-T<G5C=%]P871H*"1F:6QE*3L*("`@("`@("!I9B`H)'1H:7,M/E]C:&5C
M:U]D:7(H)&9I;&4I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B1FEL96YA;64@)R1F:6QE)R!S965M<R!T;R!B92!A(&1I<F5C
M=&]R>2XB+"!.151?1E107T524E]-1%1-1$E27U5.4U504$]25$5$*3L*("`@
M("`@("!]"B`@("`@("`@)')E<R`]($!F='!?;61T;2@D=&AI<RT^7VAA;F1L
M92P@)&9I;&4I.PH@("`@("`@(&EF("@D<F5S(#T]("TQ*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&=E="!L
M87-T+6UO9&EF:6-A=&EO;BUD871E(&]F("<D9FEL92<N(BP@3D547T944%]%
M4E)?341435]&04E,140I.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)&9O<FUA="DI('L*("`@("`@("`@("`@)')E<R`](&1A=&4H)&9O<FUA="P@
M)')E<RD["B`@("`@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$871E+69O<FUA="!F86EL
M960@;VX@=&EM97-T86UP("<D<F5S)RXB+"!.151?1E107T524E]$051%1D]2
M34%47T9!24Q%1"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES('=I;&P@
M<F5T=7)N('1H92!S:7IE(&]F(&$@9VEV96X@9FEL92!I;B!B>71E<RX@66]U
M(&-A;B!E:71H97(@9VEV92!T:&ES(&9U;F-T:6]N"B`@("`@*B!A(')E;&%T
M:79E(&]R(&%N(&%B<V]L=71E(&9I;&4M<&%T:"X@3D]413H@4V]M92!S97)V
M97)S(&1O(&YO="!S=7!P;W)T('1H:7,@9F5A='5R92$*("`@("`J"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D9FEL
M92`@(%1H92!F:6QE('1O(&-H96-K"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@
M("`@("`@("!3:7IE(&EN(&)Y=&5S(&]R(%!%05(Z.D5R<F]R"B`@("`@*B!`
M<V5E("`@("!.151?1E107T524E]325I%7T9!24Q%1`H@("`@("HO"B`@("`*
M("`@(&9U;F-T:6]N('-I>F4H)&9I;&4I"B`@("!["B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1F:6QE*3L*("`@("`@("`D<F5S
M(#T@0&9T<%]S:7IE*"1T:&ES+3Y?:&%N9&QE+"`D9FEL92D["B`@("`@("`@
M:68@*"1R97,@/3T@+3$I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")#;W5L9"!N;W0@9&5T97)M:6YE(&9I;&5S:7IE(&]F("<D
M9FEL92<N(BP@3D547T944%]%4E)?4TE:15]&04E,140I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@
M('T*"B`@("`O*BH*("`@("`J(%1H:7,@;65T:&]D(')E='5R;G,@82!D:7)E
M8W1O<GDM;&ES="!O9B!T:&4@8W5R<F5N="!D:7)E8W1O<GD@;W(@9VEV96X@
M;VYE+@H@("`@("H@5&\@9&ES<&QA>2!T:&4@8W5R<F5N="!S96QE8W1E9"!D
M:7)E8W1O<GDL('-I;7!L>2!S970@=&AE(&9I<G-T('!A<F%M971E<B!T;R!N
M=6QL"B`@("`@*B!O<B!L96%V92!I="!B;&%N:RP@:68@>6]U(&1O(&YO="!W
M86YT('1O('5S92!A;GD@;W1H97(@<&%R86UE=&5R<RX*("`@("`J(#Q"4CX\
M0E(^"B`@("`@*B!4:&5R92!A<F4@-"!D:69F97)E;G0@;6]D97,@;V8@;&ES
M=&EN9R!D:7)E8W1O<FEE<RX@16ET:&5R('1O(&QI<W0@;VYL>0H@("`@("H@
M=&AE(&9I;&5S("AU<VEN9R!.151?1E107T9)3$537T].3%DI+"!T;R!L:7-T
M(&]N;'D@9&ER96-T;W)I97,@*'5S:6YG"B`@("`@*B!.151?1E107T1)4E-?
M3TY,62D@;W(@=&\@<VAO=R!B;W1H("AU<VEN9R!.151?1E107T1)4E-?1DE,
M15,L('=H:6-H(&ES(&1E9F%U;'0I+@H@("`@("H@/$)2/CQ"4CX*("`@("`J
M(%1H92`T=&@@;VYE(&ES('1H92!.151?1E107U)!5TQ)4U0L('=H:6-H(')E
M='5R;G,@:G5S="!T:&4@87)R87D@8W)E871E9"!B>2!T:&4*("`@("`J(&9T
M<%]R87=L:7-T*"DM9G5N8W1I;VX@8G5I;&0@:6YT;R!02%`N"B`@("`@*B`\
M0E(^/$)2/@H@("`@("H@5&AE(&]T:&5R(&9U;F-T:6]N+6UO9&5S('=I;&P@
M<F5T=7)N(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(')E<75E<W1E9"!D871A
M+@H@("`@("H@5&AE(&9I;&5S(&%N9"!D:7)S(&%R92!L:7-T960@:6X@:'5M
M86XM<V]R=&5D(&]R9&5R+"!B=70@:68@>6]U('-E;&5C=`H@("`@("H@3D54
M7T944%]$25)37T9)3$53('1H92!D:7)E8W1O<FEE<R!W:6QL(&)E(&%D9&5D
M(&%B;W9E('1H92!F:6QE<RP*("`@("`J(&)U="!A;'1H;W5G:"!B;W1H('-O
M<G1E9"X*("`@("`J(#Q"4CX\0E(^"B`@("`@*B!!;&P@96QE;65N=',@:6X@
M=&AE(&%R<F%Y<R!A<F4@87-S;V-I871I=F4@87)R87ES('1H96US96QV97,N
M(%1H92!H879E('1H92!F;VQL;W=I;F<*("`@("`J('-T<G5C='5R93H*("`@
M("`J(#Q"4CX\0E(^"B`@("`@*B!$:7)S.CQ"4CX*("`@("`J("`@("`@("`@
M("!;(FYA;64B72`@("`@("`@/3X@('-T<FEN9R!4:&4@;F%M92!O9B!T:&4@
M9&ER96-T;W)Y/$)2/@H@("`@("H@("`@("`@("`@(%LB<FEG:'1S(ET@("`@
M("`]/B`@<W1R:6YG(%1H92!R:6=H=',@;V8@=&AE(&1I<F5C=&]R>2`H:6X@
M<W1Y;&4@(G)W>'(M>'(M>"(I/$)2/@H@("`@("H@("`@("`@("`@(%LB=7-E
M<B)=("`@("`@("`]/B`@<W1R:6YG(%1H92!O=VYE<B!O9B!T:&4@9&ER96-T
M;W)Y/$)2/@H@("`@("H@("`@("`@("`@(%LB9W)O=7`B72`@("`@("`]/B`@
M<W1R:6YG(%1H92!G<F]U<"UO=VYE<B!O9B!T:&4@9&ER96-T;W)Y/$)2/@H@
M("`@("H@("`@("`@("`@(%LB9FEL97-?:6YS:61E(ET]/B`@<W1R:6YG(%1H
M92!N=6UB97(@;V8@9FEL97,O9&ER<R!I;G-I9&4@=&AE(&1I<F5C=&]R>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5X
M8VQU9&EN9R`B+B(@86YD("(N+B(\0E(^"B`@("`@*B`@("`@("`@("`@6R)D
M871E(ET@("`@("`@(#T^("!I;G0@5&AE(&-R96%T:6]N+61A=&4@87,@56YI
M>"!T:6UE<W1A;7`\0E(^"B`@("`@*B`@("`@("`@("`@6R)I<U]D:7(B72`@
M("`@(#T^("!B;V]L('1R=64L(&-A=7-E('1H:7,@:7,@82!D:7(\0E(^"B`@
M("`@*B`\0E(^/$)2/@H@("`@("H@1FEL97,Z/$)2/@H@("`@("H@("`@("`@
M("`@(%LB;F%M92)=("`@("`@("`]/B`@<W1R:6YG(%1H92!N86UE(&]F('1H
M92!F:6QE/$)2/@H@("`@("H@("`@("`@("`@(%LB<VEZ92)=("`@("`@("`]
M/B`@:6YT(%-I>F4@:6X@8GET97,\0E(^"B`@("`@*B`@("`@("`@("`@6R)R
M:6=H=',B72`@("`@(#T^("!S=')I;F<@5&AE(')I9VAT<R!O9B!T:&4@9FEL
M92`H:6X@<W1Y;&4@(G)W>'(M>'(M>"(I/$)2/@H@("`@("H@("`@("`@("`@
M(%LB=7-E<B)=("`@("`@("`]/B`@<W1R:6YG(%1H92!O=VYE<B!O9B!T:&4@
M9FEL93Q"4CX*("`@("`J("`@("`@("`@("!;(F=R;W5P(ET@("`@("`@/3X@
M('-T<FEN9R!4:&4@9W)O=7`M;W=N97(@;V8@=&AE(&9I;&4\0E(^"B`@("`@
M*B`@("`@("`@("`@6R)D871E(ET@("`@("`@(#T^("!I;G0@5&AE(&-R96%T
M:6]N+61A=&4@87,@56YI>"!T:6UE<W1A;7`\0E(^"B`@("`@*B`@("`@("`@
M("`@6R)I<U]D:7(B72`@("`@(#T^("!B;V]L(&9A;'-E+"!C875S92!T:&ES
M(&ES(&$@9FEL93Q"4CX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!P87)A;2`@('-T<FEN9R`D9&ER("`@*&]P=&EO;F%L*2!4:&4@
M9&ER96-T;W)Y('1O(&QI<W0@;W(@;G5L;"P@=VAE;B!L:7-T:6YG('1H92!C
M=7)R96YT(&1I<F5C=&]R>2X*("`@("`J($!P87)A;2`@(&EN="`@("`D;6]D
M92`@*&]P=&EO;F%L*2!4:&4@;6]D92!W:&EC:"!T>7!E<R!T;R!L:7-T("AF
M:6QE<RP@9&ER96-T;W)I97,@;W(@8F]T:"DN"B`@("`@*B!`<F5T=7)N("!M
M:7AE9"`@("`@("`@(%1H92!D:7)E8W1O<GD@;&ES="!A<R!D97-C<FEB960@
M86)O=F4@;W(@4$5!4CHZ17)R;W(@;VX@9F%I;'5R92X*("`@("`J($!S964@
M("`@($Y%5%]&5%!?1$E24U]&24Q%4RP@3D547T944%]$25)37T].3%DL($Y%
M5%]&5%!?1DE,15-?3TY,62P@3D547T944%]205=,25-4+"!.151?1E107T52
M4E]$151%4DU)3D50051(7T9!24Q%1"P@3D547T944%]%4E)?4D%71$E23$E3
M5%]&04E,140L($Y%5%]&5%!?15)27T1)4DQ)4U1?54Y355!03U)4140*("`@
M("`J+PH@("`@(`H@("`@9G5N8W1I;VX@;',H)&1I<B`](&YU;&PL("1M;V1E
M(#T@3D547T944%]$25)37T9)3$53*0H@("`@>PH@("`@("`@(&EF("@A:7-S
M970H)&1I<BDI('L*("`@("`@("`@("`@)&1I<B`]($!F='!?<'=D*"1T:&ES
M+3Y?:&%N9&QE*3L*("`@("`@("`@("`@:68@*"$D9&ER*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!R
M971R:65V92!C=7)R96YT(&1I<F5C=&]R>2(L($Y%5%]&5%!?15)27T1%5$52
M34E.15!!5$A?1D%)3$5$*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!I9B`H*"1M;V1E("$]($Y%5%]&5%!?1DE,15-?3TY,62D@)B8@*"1M
M;V1E("$]($Y%5%]&5%!?1$E24U]/3DQ9*2`F)B`H)&UO9&4@(3T@3D547T94
M4%]205=,25-4*2D@>PH@("`@("`@("`@("`D;6]D92`]($Y%5%]&5%!?1$E2
M4U]&24Q%4SL*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)&UO9&4I('L*
M("`@("`@("`@("`@8V%S92!.151?1E107T1)4E-?1DE,15,Z("`@("1R97,@
M/2`D=&AI<RT^7VQS7V)O=&@@*"`D9&ER("D["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S
M92!.151?1E107T1)4E-?3TY,63H@("`@("1R97,@/2`D=&AI<RT^7VQS7V1I
M<G,@*"`D9&ER("D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@8V%S92!.151?1E107T9)3$53
M7T].3%DZ("`@("1R97,@/2`D=&AI<RT^7VQS7V9I;&5S("@@)&1I<B`I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@3D547T944%]205=,25-4.B`@("`@("`D<F5S
M(#T@0&9T<%]R87=L:7-T*"1T:&ES+3Y?:&%N9&QE+"`D9&ER*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!4:&ES(&UE=&AO9"!W:6QL(&1E;&5T92!T:&4@9VEV96X@9FEL92!O
M<B!D:7)E8W1O<GD@*"1P871H*2!F<F]M('1H92!S97)V97(*("`@("`J("AM
M87EB92!R96-U<G-I=F4I+@H@("`@("H*("`@("`J(%=H971H97(@=&AE(&=I
M=F5N('-T<FEN9R!I<R!A(&9I;&4@;W(@9&ER96-T;W)Y(&ES(&]N;'D@9&5T
M97)M:6YE9"!B>2!T:&4@;&%S=`H@("`@("H@<VEG;B!I;G-I9&4@=&AE('-T
M<FEN9R`H(B\B(&]R(&YO="DN"B`@("`@*@H@("`@("H@268@>6]U('-P96-I
M9GD@82!D:7)E8W1O<GDL('EO=2!C86X@;W!T:6]N86QL>2!S<&5C:69Y("1R
M96-U<G-I=F4@87,@=')U92P*("`@("`J('1O(&QE="!T:&4@9&ER96-T;W)Y
M(&)E(&1E;&5T960@<F5C=7)S:79E("AW:71H(&%L;"!S=6(M9&ER96-T;W)I
M97,@86YD(&9I;&5S"B`@("`@*B!I;FAE<FET960I+@H@("`@("H*("`@("`J
M(%EO=2!C86X@96ET:&5R(&=I=F4@82!A8G-O;'5T92!O<B!R96QA=&EV92!P
M871H(&9O<B!T:&4@9FEL92`O(&1I<BX@268@>6]U(&-H;V]S92!T;PH@("`@
M("H@=7-E('1H92!R96QA=&EV92!P871H+"!I="!W:6QL(&)E(&%U=&]M871I
M8V%L;'D@8V]M<&QE=&5D('=I=&@@=&AE(&%C='5A;`H@("`@("H@<V5L96-T
M960@9&ER96-T;W)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0'!A<F%M("`@<W1R:6YG("1P871H("`@("`@5&AE(&%B<V]L=71E
M(&]R(')E;&%T:79E('!A=&@@=&\@=&AE(&9I;&4@+R!D:7)E8W1O<GDN"B`@
M("`@*B!`<&%R86T@("!B;V]L("`@)')E8W5R<VEV92`H;W!T:6]N86PI"B`@
M("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("!4<G5E(&]N('-U8V-E
M<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D54
M7T944%]%4E)?1$5,151%1DE,15]&04E,140L($Y%5%]&5%!?15)27T1%3$54
M141)4E]&04E,140L($Y%5%]&5%!?15)27U)%34]415!!5$A.3T1)4@H@("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N(')M*"1P871H+"`D<F5C=7)S:79E(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@)'!A=&@@/2`D=&AI<RT^7V-O;G-T<G5C
M=%]P871H*"1P871H*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8VAE8VM?9&ER
M*"1P871H*2D@>PH@("`@("`@("`@("!I9B`H)')E8W5R<VEV92D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<FU?9&ER7W)E8W5R<VEV92@D
M<&%T:"D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R;5]D:7(H)'!A=&@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<FU?
M9FEL92@D<&%T:"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M5&AI<R!F=6YC=&EO;B!W:6QL(&1O=VYL;V%D(&$@9FEL92!F<F]M('1H92!F
M='`M<V5R=F5R+B!9;W4@8V%N(&5I=&AE<B!S<&-I9GD@82!A8G-O;'5T90H@
M("`@("H@<&%T:"!T;R!T:&4@9FEL92`H8F5G:6YN:6YG('=I=&@@(B\B*2!O
M<B!A(')E;&%T:79E(&]N92P@=VAI8V@@=VEL;"!B92!C;VUP;&5T960*("`@
M("`J('=I=&@@=&AE(&%C='5A;"!D:7)E8W1O<GD@>6]U('-E;&5C=&5D(&]N
M('1H92!S97)V97(N(%EO=2!C86X@<W!E8VEF>0H@("`@("H@=&AE('!A=&@@
M=&\@=VAI8V@@=&AE(&9I;&4@=VEL;"!B92!D;W=N;&]A9&5D(&]N('1H92!L
M;V-A;`H@("`@("H@;6%S8VAI;F4L(&EF('1H92!F:6QE('-H;W5L9"!B92!O
M=F5R=W)I='1E;B!I9B!I="!E>&ES=',@*&]P=&EO;F%L;'DL(&1E9F%U;'0@
M:7,*("`@("`J(&YO(&]V97)W<FET:6YG*2!A;F0@:6X@=VAI8V@@;6]D92`H
M1E107T%30TE)(&]R($944%]"24Y!4EDI('1H92!F:6QE('-H;W5L9"!B90H@
M("`@("H@9&]W;FQO861E9"`H:68@>6]U(&1O(&YO="!S<&5C:69Y('1H:7,L
M('1H92!M971H;V0@=')I97,@=&\@9&5T97)M:6YE(&ET(&%U=&]M871I8V%L
M;'D*("`@("`J(&9R;VT@=&AE(&UO9&4M9&ER96-T;W)Y(&]R('5S97,@=&AE
M(&1E9F%U;'0M;6]D92P@<V5T(&)Y('EO=2DN($EF('EO=2!G:79E(&$@<F5L
M871I=F4*("`@("`J('!A=&@@=&\@=&AE(&QO8V%L+69I;&4L('1H92!S8W)I
M<'0M<&%T:"!I<R!U<V5D(&%S(&)A<V5P871H+@H@("`@("H*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1R96UO=&5?
M9FEL92!4:&4@86)S;VQU=&4@;W(@<F5L871I=F4@<&%T:"!T;R!T:&4@9FEL
M92!T;R!D;W=N;&]A9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("1L;V-A;%]F
M:6QE("!4:&4@;&]C86P@9FEL92!T;R!P=70@=&AE(&1O=VYL;V%D960@:6X*
M("`@("`J($!P87)A;2`@(&)O;VP@("`D;W9E<G=R:71E("`@*&]P=&EO;F%L
M*2!7:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN9R!F:6QE"B`@("`@*B!`
M<&%R86T@("!I;G0@("`@)&UO9&4@("`@("`@("AO<'1I;VYA;"D@16ET:&5R
M($944%]!4T-)22!O<B!&5%!?0DE.05)9"B`@("`@*B!`<F5T=7)N("!M:7AE
M9"`@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%
M05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]/5D525U))
M5$5,3T-!3$9)3$5?1D]20DE$1$5.+"!.151?1E107T524E]/5D525U))5$5,
M3T-!3$9)3$5?1D%)3$5$+"!.151?1E107T524E]/5D525U))5$5,3T-!3$9)
M3$5?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@9V5T*"1R96UO
M=&5?9FEL92P@)&QO8V%L7V9I;&4L("1O=F5R=W)I=&4@/2!F86QS92P@)&UO
M9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&UO9&4I*2![
M"B`@("`@("`@("`@("1M;V1E(#T@)'1H:7,M/F-H96-K1FEL945X=&5N<VEO
M;B@D<F5M;W1E7V9I;&4I.PH@("`@("`@('T*"B`@("`@("`@)')E;6]T95]F
M:6QE(#T@)'1H:7,M/E]C;VYS=')U8W1?<&%T:"@D<F5M;W1E7V9I;&4I.PH*
M("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1L;V-A;%]F:6QE*2`F)B`A)&]V
M97)W<FET92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(DQO8V%L(&9I;&4@)R1L;V-A;%]F:6QE)R!E>&ES=',@86YD(&UA>2!N
M;W0@8F4@;W9E<G=R:71E;BXB+"!.151?1E107T524E]/5D525U))5$5,3T-!
M3$9)3$5?1D]20DE$1$5.*3L*("`@("`@("!]"B`@("`@("`@:68@*$!F:6QE
M7V5X:7-T<R@D;&]C86Q?9FEL92D@)B8@(4!I<U]W<FET96%B;&4H)&QO8V%L
M7V9I;&4I("8F("1O=F5R=W)I=&4I('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"),;V-A;"!F:6QE("<D;&]C86Q?9FEL92<@:7,@
M;F]T('=R:71E86)L92X@0V%N(&YO="!O=F5R=W)I=&4N(BP@3D547T944%]%
M4E)?3U9%4E=2251%3$]#04Q&24Q%7T9!24Q%1"D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H0&9U;F-T:6]N7V5X:7-T<R@G9G1P7VYB7V=E="<I*7L*("`@
M("`@("`@("`@)')E<R`]($!F='!?;F)?9V5T*"1T:&ES+3Y?:&%N9&QE+"`D
M;&]C86Q?9FEL92P@)')E;6]T95]F:6QE+"`D;6]D92D["B`@("`@("`@("`@
M('=H:6QE("@D<F5S(#T]($944%]-3U)%1$%402D@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]A;FYO=6YC92@G;F)?9V5T)RD["B`@("`@("`@("`@("`@
M("`D<F5S(#T@0&9T<%]N8E]C;VYT:6YU92`H)'1H:7,M/E]H86YD;&4I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E
M<R`]($!F='!?9V5T*"1T:&ES+3Y?:&%N9&QE+"`D;&]C86Q?9FEL92P@)')E
M;6]T95]F:6QE+"`D;6]D92D["B`@("`@("`@?0H@("`@("`@(&EF("@A)')E
M<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D9I
M;&4@)R1R96UO=&5?9FEL92<@8V]U;&0@;F]T(&)E(&1O=VYL;V%D960@=&\@
M)R1L;V-A;%]F:6QE)RXB+"!.151?1E107T524E]/5D525U))5$5,3T-!3$9)
M3$5?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&9U;F-T:6]N('=I;&P@=7!L;V%D(&$@9FEL92!T;R!T:&4@9G1P+7-E<G9E
M<BX@66]U(&-A;B!E:71H97(@<W!E8VEF>2!A(&%B<V]L=71E"B`@("`@*B!P
M871H('1O('1H92!R96UO=&4M9FEL92`H8F5G:6YN:6YG('=I=&@@(B\B*2!O
M<B!A(')E;&%T:79E(&]N92P@=VAI8V@@=VEL;"!B92!C;VUP;&5T960*("`@
M("`J('=I=&@@=&AE(&%C='5A;"!D:7)E8W1O<GD@>6]U('-E;&5C=&5D(&]N
M('1H92!S97)V97(N(%EO=2!C86X@<W!E8VEF>0H@("`@("H@=&AE('!A=&@@
M9G)O;2!W:&EC:"!T:&4@9FEL92!W:6QL(&)E('5P;&]A9&5D(&]N('1H92!L
M;V-A;`H@("`@("H@;6%S8VAI;F4L(&EF('1H92!F:6QE('-H;W5L9"!B92!O
M=F5R=W)I='1E;B!I9B!I="!E>&ES=',@*&]P=&EO;F%L;'DL(&1E9F%U;'0@
M:7,*("`@("`J(&YO(&]V97)W<FET:6YG*2!A;F0@:6X@=VAI8V@@;6]D92`H
M1E107T%30TE)(&]R($944%]"24Y!4EDI('1H92!F:6QE('-H;W5L9"!B90H@
M("`@("H@9&]W;FQO861E9"`H:68@>6]U(&1O(&YO="!S<&5C:69Y('1H:7,L
M('1H92!M971H;V0@=')I97,@=&\@9&5T97)M:6YE(&ET(&%U=&]M871I8V%L
M;'D*("`@("`J(&9R;VT@=&AE(&UO9&4M9&ER96-T;W)Y(&]R('5S97,@=&AE
M(&1E9F%U;'0M;6]D92P@<V5T(&)Y('EO=2DN($EF('EO=2!G:79E(&$@<F5L
M871I=F4*("`@("`J('!A=&@@=&\@=&AE(&QO8V%L+69I;&4L('1H92!S8W)I
M<'0M<&%T:"!I<R!U<V5D(&%S(&)A<V5P871H+@H@("`@("H*("`@("`J($!A
M8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R:6YG("1L;V-A;%]F
M:6QE("!4:&4@;&]C86P@9FEL92!T;R!U<&QO860*("`@("`J($!P87)A;2`@
M('-T<FEN9R`D<F5M;W1E7V9I;&4@5&AE(&%B<V]L=71E(&]R(')E;&%T:79E
M('!A=&@@=&\@=&AE(&9I;&4@=&\@=7!L;V%D('1O"B`@("`@*B!`<&%R86T@
M("!B;V]L("`@)&]V97)W<FET92`@("AO<'1I;VYA;"D@5VAE=&AE<B!T;R!O
M=F5R=W)I=&4@97AI<W1I;F<@9FEL90H@("`@("H@0'!A<F%M("`@:6YT("`@
M("1M;V1E("`@("`@("`H;W!T:6]N86PI($5I=&AE<B!&5%!?05-#24D@;W(@
M1E107T))3D%260H@("`@("H@0')E='5R;B`@;6EX960@("`@("`@("`@("`@
M("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@
M("H@0'-E92`@("`@3D547T944%]%4E)?3$]#04Q&24Q%3D]415A)4U0L($Y%
M5%]&5%!?15)27T]615)74DE415)%34]4149)3$5?1D]20DE$1$5.+"!.151?
M1E107T524E]54$Q/041&24Q%7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N('!U="@D;&]C86Q?9FEL92P@)')E;6]T95]F:6QE+"`D;W9E<G=R
M:71E(#T@9F%L<V4L("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H
M(6ES<V5T*"1M;V1E*2D@>PH@("`@("`@("`@("`D;6]D92`]("1T:&ES+3YC
M:&5C:T9I;&5%>'1E;G-I;VXH)&QO8V%L7V9I;&4I.PH@("`@("`@('T*("`@
M("`@("`D<F5M;W1E7V9I;&4@/2`D=&AI<RT^7V-O;G-T<G5C=%]P871H*"1R
M96UO=&5?9FEL92D["@H@("`@("`@(&EF("@A0&9I;&5?97AI<W1S*"1L;V-A
M;%]F:6QE*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(DQO8V%L(&9I;&4@)R1L;V-A;%]F:6QE)R!D;V5S(&YO="!E>&ES="XB
M+"!.151?1E107T524E],3T-!3$9)3$5.3U1%6$E35"D["B`@("`@("`@?0H@
M("`@("`@(&EF("@H0&9T<%]S:7IE*"1T:&ES+3Y?:&%N9&QE+"`D<F5M;W1E
M7V9I;&4I("$]("TQ*2`F)B`A)&]V97)W<FET92D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E)E;6]T92!F:6QE("<D<F5M;W1E
M7V9I;&4G(&5X:7-T<R!A;F0@;6%Y(&YO="!B92!O=F5R=W)I=&5N+B(L($Y%
M5%]&5%!?15)27T]615)74DE415)%34]4149)3$5?1D]20DE$1$5.*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9T<%]N8E]P
M=70G*2E["B`@("`@("`@("`@("1R97,@/2!`9G1P7VYB7W!U="@D=&AI<RT^
M7VAA;F1L92P@)')E;6]T95]F:6QE+"`D;&]C86Q?9FEL92P@)&UO9&4I.PH@
M("`@("`@("`@("!W:&EL92`H)')E<R`]/2!&5%!?34]2141!5$$I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H)VYB7W!U="<I.PH@("`@
M("`@("`@("`@("`@)')E<R`]($!F='!?;F)?8V]N=&EN=64H)'1H:7,M/E]H
M86YD;&4I.PH@("`@("`@("`@("!]"@H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R97,@/2!`9G1P7W!U="@D=&AI<RT^7VAA;F1L92P@)')E;6]T
M95]F:6QE+"`D;&]C86Q?9FEL92P@)&UO9&4I.PH@("`@("`@('T*("`@("`@
M("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")&:6QE("<D;&]C86Q?9FEL92<@8V]U;&0@;F]T(&)E('5P;&]A
M9&5D('1O("<D<F5M;W1E7V9I;&4G+B(L($Y%5%]&5%!?15)27U503$]!1$9)
M3$5?1D%)3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&9U;F-T:6]N86QI='D@86QL;W=S('EO=2!T;R!T<F%N<V9E<B!A('=H;VQE
M(&1I<F5C=&]R>2US=')U8W1U<F4@9G)O;2!T:&4*("`@("`J(')E;6]T92UF
M='`@=&\@>6]U<B!L;V-A;"!H;W-T+B!9;W4@:&%V92!T;R!G:79E(&$@<F5M
M;W1E+61I<F5C=&]R>2`H96YD:6YG('=I=&@*("`@("`J("<O)RD@86YD('1H
M92!L;V-A;"!D:7)E8W1O<GD@*&5N9&EN9R!W:71H("<O)RD@=VAE<F4@=&\@
M<'5T('1H92!F:6QE<R!Y;W4@9&]W;FQO860N"B`@("`@*B!4:&4@<F5M;W1E
M('!A=&@@:7,@875T;VUA=&EC86QL>2!C;VUP;&5T960@=VET:"!T:&4@8W5R
M<F5N="UR96UO=&4M9&ER+"!I9B!Y;W4@9VEV90H@("`@("H@82!R96QA=&EV
M92!P871H('1O('1H:7,@9G5N8W1I;VXN(%EO=2!C86X@9VEV92!A(')E;&%T
M:79E('!A=&@@9F]R('1H92`D;&]C86Q?<&%T:"P*("`@("`J('1O;RX@5&AE
M;B!T:&4@<V-R:7!T+6)A<V5D:7(@=VEL;"!B92!U<V5D(&9O<B!C;VUL971I
M;VX@;V8@=&AE('!A=&@N"B`@("`@*B!4:&4@<&%R86UE=&5R("1O=F5R=W)I
M=&4@=VEL;"!D971E<FUI;F4L('=H971H97(@=&\@;W9E<G=R:71E(&5X:7-T
M:6YG(&9I;&5S(&]R(&YO="X*("`@("`J(%-T86YD87)D(&9O<B!T:&ES(&ES
M(&9A;'-E+B!&;W5R=&@@>6]U(&-A;B!E>'!L:6-I=&QY('-E="!A(&UO9&4@
M9F]R(&%L;"!T<F%N<V9E<BT*("`@("`J(&%C=&EO;G,@9&]N92X@268@>6]U
M(&1O(&YO="!S970@=&AI<RP@=&AE(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI
M;F4@=&AE('1R86YS9F5R+0H@("`@("H@;6]D92!B>2!C:&5C:VEN9R!Y;W5R
M(&UO9&4M9&ER96-T;W)Y(&9O<B!T:&4@9FEL92UE>'1E;G-I;VXN($EF('1H
M92!E>'1E;G-I;VX@:7,@;F]T"B`@("`@*B!I;G-I9&4@=&AE(&UO9&4M9&ER
M96-T;W)Y+"!I="!W:6QL(&=E="!Y;W5R(&1E9F%U;'0M;6]D92X*("`@("`J
M"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN
M9R`D<F5M;W1E7W!A=&@@5&AE('!A=&@@=&\@9&]W;FQO860*("`@("`J($!P
M87)A;2`@('-T<FEN9R`D;&]C86Q?<&%T:"`@5&AE('!A=&@@=&\@9&]W;FQO
M860@=&\*("`@("`J($!P87)A;2`@(&)O;VP@("`D;W9E<G=R:71E("`@*&]P
M=&EO;F%L*2!7:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN9R!F:6QE<R`H
M=')U92D@;W(@;F]T("AF86QS92P@<W1A;F1A<F0I+@H@("`@("H@0'!A<F%M
M("`@:6YT("`@("1M;V1E("`@("`@("`H;W!T:6]N86PI(%1H92!T<F%N<V9E
M<FUO9&4@*&5I=&AE<B!&5%!?05-#24D@;W(@1E107T))3D%262DN"B`@("`@
M*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("`@(%1R=64@;VX@<W5C8V5S
M+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&
M5%!?15)27T]615)74DE414Q/0T%,1DE,15]&3U)"241$14XL($Y%5%]&5%!?
M15)27T]615)74DE414Q/0T%,1DE,15]&04E,140L($Y%5%]&5%!?15)27T]6
M15)74DE414Q/0T%,1DE,15]&04E,140L($Y%5%]&5%!?15)27U)%34]415!!
M5$A.3T1)4BP@3D547T944%]%4E)?3$]#04Q0051(3D]$25(L3D547T944%]%
M4E)?0U)%051%3$]#04Q$25)?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N
M8W1I;VX@9V5T4F5C=7)S:79E*"1R96UO=&5?<&%T:"P@)&QO8V%L7W!A=&@L
M("1O=F5R=W)I=&4@/2!F86QS92P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@
M("`@("1R96UO=&5?<&%T:"`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)')E
M;6]T95]P871H*3L*("`@("`@("!I9B`H(21T:&ES+3Y?8VAE8VM?9&ER*"1R
M96UO=&5?<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")':79E;B!R96UO=&4M<&%T:"`G)')E;6]T95]P871H)R!S965M
M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN(BP@3D547T944%]%4E)?4D5-3U1%
M4$%42$Y/1$E2*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D=&AI<RT^7V-H
M96-K7V1I<B@D;&]C86Q?<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")':79E;B!L;V-A;"UP871H("<D;&]C86Q?<&%T
M:"<@<V5E;7,@;F]T('1O(&)E(&$@9&ER96-T;W)Y+B(L($Y%5%]&5%!?15)2
M7TQ/0T%,4$%42$Y/1$E2*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A0&ES
M7V1I<B@D;&]C86Q?<&%T:"DI('L*("`@("`@("`@("`@)')E<R`]($!M:V1I
M<B@D;&]C86Q?<&%T:"D["B`@("`@("`@("`@(&EF("@A)')E<RD@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#;W5L9"!N
M;W0@8W)E871E(&1I<B`G)&QO8V%L7W!A=&@G(BP@3D547T944%]%4E)?0U)%
M051%3$]#04Q$25)?1D%)3$5$*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("`D9&ER7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("1D:7)?;&ES
M="`]("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L($Y%5%]&5%!?1$E24U]/3DQ9
M*3L*("`@("`@("!F;W)E86-H("@D9&ER7VQI<W0@87,@)&1I<E]E;G1R>2D@
M>PH@("`@("`@("`@("!I9B`H)&1I<E]E;G1R>5LG;F%M92==("$]("<N)R`F
M)B`D9&ER7V5N=')Y6R=N86UE)UT@(3T@)RXN)RD@>PH@("`@("`@("`@("`@
M("`@)')E;6]T95]P871H7VYE=R`]("1R96UO=&5?<&%T:"XD9&ER7V5N=')Y
M6R)N86UE(ETN(B\B.PH@("`@("`@("`@("`@("`@)&QO8V%L7W!A=&A?;F5W
M(#T@)&QO8V%L7W!A=&@N)&1I<E]E;G1R>5LB;F%M92)=+B(O(CL*("`@("`@
M("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^9V5T4F5C=7)S:79E*"1R96UO
M=&5?<&%T:%]N97<L("1L;V-A;%]P871H7VYE=RP@)&]V97)W<FET92P@)&UO
M9&4I.PH@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<T5R<F]R*"1R97-U
M;'0I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@)&9I;&5?;&ES="`](&%R<F%Y*"D["B`@("`@("`@)&9I;&5?;&ES="`]
M("1T:&ES+3YL<R@D<F5M;W1E7W!A=&@L($Y%5%]&5%!?1DE,15-?3TY,62D[
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5?;&ES="!A<R`D9FEL95]E;G1R>2D@
M>PH@("`@("`@("`@("`D<F5M;W1E7V9I;&4@/2`D<F5M;W1E7W!A=&@N)&9I
M;&5?96YT<GE;(FYA;64B73L*("`@("`@("`@("`@)&QO8V%L7V9I;&4@/2`D
M;&]C86Q?<&%T:"XD9FEL95]E;G1R>5LB;F%M92)=.PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/F=E="@D<F5M;W1E7V9I;&4L("1L;V-A;%]F:6QE
M+"`D;W9E<G=R:71E+"`D;6]D92D["B`@("`@("`@("`@(&EF("@D=&AI<RT^
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U;F-T:6]N86QI
M='D@86QL;W=S('EO=2!T;R!T<F%N<V9E<B!A('=H;VQE(&1I<F5C=&]R>2US
M=')U8W1U<F4@9G)O;2!Y;W5R"B`@("`@*B!L;V-A;"!H;W-T('1O('1H92!R
M96UO=&4M9G1P+B!9;W4@:&%V92!T;R!G:79E(&$@<F5M;W1E+61I<F5C=&]R
M>2`H96YD:6YG('=I=&@*("`@("`J("<O)RD@86YD('1H92!L;V-A;"!D:7)E
M8W1O<GD@*&5N9&EN9R!W:71H("<O)RD@=VAE<F4@=&\@<'5T('1H92!F:6QE
M<R!Y;W4@9&]W;FQO860N"B`@("`@*B!4:&4@<F5M;W1E('!A=&@@:7,@875T
M;VUA=&EC86QL>2!C;VUP;&5T960@=VET:"!T:&4@8W5R<F5N="UR96UO=&4M
M9&ER+"!I9B!Y;W4@9VEV90H@("`@("H@82!R96QA=&EV92!P871H('1O('1H
M:7,@9G5N8W1I;VXN(%EO=2!C86X@9VEV92!A(')E;&%T:79E('!A=&@@9F]R
M('1H92`D;&]C86Q?<&%T:"P*("`@("`J('1O;RX@5&AE;B!T:&4@<V-R:7!T
M+6)A<V5D:7(@=VEL;"!B92!U<V5D(&9O<B!C;VUL971I;VX@;V8@=&AE('!A
M=&@N"B`@("`@*B!4:&4@<&%R86UE=&5R("1O=F5R=W)I=&4@=VEL;"!D971E
M<FUI;F4L('=H971H97(@=&\@;W9E<G=R:71E(&5X:7-T:6YG(&9I;&5S(&]R
M(&YO="X*("`@("`J(%-T86YD87)D(&9O<B!T:&ES(&ES(&9A;'-E+B!&;W5R
M=&@@>6]U(&-A;B!E>'!L:6-I=&QY('-E="!A(&UO9&4@9F]R(&%L;"!T<F%N
M<V9E<BT*("`@("`J(&%C=&EO;G,@9&]N92X@268@>6]U(&1O(&YO="!S970@
M=&AI<RP@=&AE(&UE=&AO9"!T<FEE<R!T;R!D971E<FUI;F4@=&AE('1R86YS
M9F5R+0H@("`@("H@;6]D92!B>2!C:&5C:VEN9R!Y;W5R(&UO9&4M9&ER96-T
M;W)Y(&9O<B!T:&4@9FEL92UE>'1E;G-I;VXN($EF('1H92!E>'1E;G-I;VX@
M:7,@;F]T"B`@("`@*B!I;G-I9&4@=&AE(&UO9&4M9&ER96-T;W)Y+"!I="!W
M:6QL(&=E="!Y;W5R(&1E9F%U;'0M;6]D92X*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!P87)A;2`@('-T<FEN9R`D<F5M;W1E7W!A
M=&@@5&AE('!A=&@@=&\@9&]W;FQO860@"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@)&QO8V%L7W!A=&@@(%1H92!P871H('1O(&1O=VYL;V%D('1O"B`@("`@
M*B!`<&%R86T@("!B;V]L("`@)&]V97)W<FET92`@("AO<'1I;VYA;"D@5VAE
M=&AE<B!T;R!O=F5R=W)I=&4@97AI<W1I;F<@9FEL97,@*'1R=64I(&]R(&YO
M="`H9F%L<V4L('-T86YD87)D*2X*("`@("`J($!P87)A;2`@(&EN="`@("`D
M;6]D92`@("`@("`@*&]P=&EO;F%L*2!4:&4@=')A;G-F97)M;V1E("AE:71H
M97(@1E107T%30TE)(&]R($944%]"24Y!4EDI+@H@("`@("H@0')E='5R;B`@
M;6EX960@("`@("`@("`@("`@("!4<G5E(&]N('-U8V-E<RP@;W1H97)W:7-E
M(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@("!.151?1E107T524E],3T-!
M3$9)3$5.3U1%6$E35"P@3D547T944%]%4E)?3U9%4E=2251%4D5-3U1%1DE,
M15]&3U)"241$14XL($Y%5%]&5%!?15)27U503$]!1$9)3$5?1D%)3$5$+"!.
M151?1E107T524E],3T-!3%!!5$A.3T1)4BP@3D547T944%]%4E)?4D5-3U1%
M4$%42$Y/1$E2"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<'5T4F5C=7)S
M:79E*"1L;V-A;%]P871H+"`D<F5M;W1E7W!A=&@L("1O=F5R=W)I=&4@/2!F
M86QS92P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@("1R96UO=&5?<&%T
M:"`]("1T:&ES+3Y?8V]N<W1R=6-T7W!A=&@H)')E;6]T95]P871H*3L*("`@
M("`@("!I9B`H(21T:&ES+3Y?8VAE8VM?9&ER*"1L;V-A;%]P871H*2!\?"`A
M:7-?9&ER*"1L;V-A;%]P871H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(D=I=F5N(&QO8V%L+7!A=&@@)R1L;V-A;%]P871H
M)R!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN(BP@3D547T944%]%4E)?
M3$]#04Q0051(3D]$25(I.PH@("`@("`@('T*("`@("`@("!I9B`H(21T:&ES
M+3Y?8VAE8VM?9&ER*"1R96UO=&5?<&%T:"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")':79E;B!R96UO=&4M<&%T:"`G)')E
M;6]T95]P871H)R!S965M<R!N;W0@=&\@8F4@82!D:7)E8W1O<GDN(BP@3D54
M7T944%]%4E)?4D5-3U1%4$%42$Y/1$E2*3L*("`@("`@("!]"B`@("`@("`@
M)&]L9%]P871H(#T@)'1H:7,M/G!W9"@I.PH@("`@("`@(&EF("@D=&AI<RT^
M:7-%<G)O<B@D=&AI<RT^8V0H)')E;6]T95]P871H*2DI('L*("`@("`@("`@
M("`@)')E<R`]("1T:&ES+3YM:V1I<B@D<F5M;W1E7W!A=&@I.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D<F5S.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3YC9"@D;VQD7W!A=&@I.PH@("`@("`@("1D:7)?;&ES="`]
M("1T:&ES+3Y?;'-?;&]C86PH)&QO8V%L7W!A=&@I.PH@("`@("`@(&9O<F5A
M8V@@*"1D:7)?;&ES=%LB9&ER<R)=(&%S("1D:7)?96YT<GDI('L*("`@("`@
M("`@("`@)')E;6]T95]P871H7VYE=R`]("1R96UO=&5?<&%T:"XD9&ER7V5N
M=')Y+B(O(CL*("`@("`@("`@("`@)&QO8V%L7W!A=&A?;F5W(#T@)&QO8V%L
M7W!A=&@N)&1I<E]E;G1R>2XB+R(["B`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^<'5T4F5C=7)S:79E*"1L;V-A;%]P871H7VYE=RP@)')E;6]T95]P
M871H7VYE=RP@)&]V97)W<FET92P@)&UO9&4I.PH@("`@("`@("`@("!I9B`H
M)'1H:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!F;W)E86-H("@D9&ER7VQI<W1;(F9I;&5S(ET@87,@)&9I;&5?96YT<GDI
M('L*("`@("`@("`@("`@)')E;6]T95]F:6QE(#T@)')E;6]T95]P871H+B1F
M:6QE7V5N=')Y.PH@("`@("`@("`@("`D;&]C86Q?9FEL92`]("1L;V-A;%]P
M871H+B1F:6QE7V5N=')Y.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/G!U="@D;&]C86Q?9FEL92P@)')E;6]T95]F:6QE+"`D;W9E<G=R:71E+"`D
M;6]D92D["B`@("`@("`@("`@(&EF("@D=&AI<RT^:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4:&ES(&-H96-K<RP@=VAE=&AE<B!A(&9I;&4@<VAO
M=6QD(&)E('1R86YS9F5R960@:6X@87-C:6DM(&]R(&)I;F%R>2UM;V1E"B`@
M("`@*B!B>2!I="=S(&9I;&4M97AT96YS:6]N+B!)9B!T:&4@9FEL92UE>'1E
M;G-I;VX@:7,@;F]T('-E="!O<@H@("`@("H@=&AE(&5X=&5N<VEO;B!I<R!N
M;W0@:6YS:61E(&]N92!O9B!T:&4@97AT96YS:6]N+61I<G,L('1H92!A8W1U
M86P@<V5T"B`@("`@*B!T<F%N<V9E<BUM;V1E(&ES(')E='5R;F5D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A<F%M("`@<W1R
M:6YG("1F:6QE;F%M92`@5&AE(&9I;&5N86UE('1O(&)E(&-H96-K960*("`@
M("`J($!R971U<FX@(&EN="`@("`@("`@("`@("`@($5I=&AE<B!&5%!?05-#
M24D@;W(@1E107T))3D%260H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(&-H
M96-K1FEL945X=&5N<VEO;B@D9FEL96YA;64I"B`@("!["B`@("`@("`@)'!A
M='1E<FX@/2`B+UPN*"XJ*20O(CL*("`@("`@("`D:&%S7V5X=&5N<VEO;B`]
M('!R96=?;6%T8V@H)'!A='1E<FXL("1F:6QE;F%M92P@)&5R96=S*3L*("`@
M("`@("!I9B`H(21H87-?97AT96YS:6]N*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUO9&4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&5X="`]("1E<F5G<ULQ73L*("`@("`@("!]"@H@("`@("`@(&EF("@A96UP
M='DH)'1H:7,M/E]F:6QE7V5X=&5N<VEO;G-;)&5X=%TI*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT73L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7VUO9&4["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3970@=&AE($AO<W1N86UE"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&AO<W0@
M5&AE($AO<W1N86UE('1O('-E=`H@("`@("H@0')E='5R;B`@8F]O;"!4<G5E
M(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E
M92`@("`@3D547T944%]%4E)?2$]35$Y!345.3U-44DE.1PH@("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N('-E=$AO<W1N86UE*"1H;W-T*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?<W1R:6YG*"1H;W-T*2D@>PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@B2&]S=&YA;64@;75S="!B92!A('-T<FEN
M9RXB+"!.151?1E107T524E](3U-43D%-14Y/4U1224Y'*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]H;W-T;F%M92`]("1H;W-T.PH@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!0;W)T
M"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<&%R86T@
M("!I;G0@)'!O<G0@("`@5&AE(%!O<G0@=&\@<V5T"B`@("`@*B!`<F5T=7)N
M("!B;V]L(%1R=64@;VX@<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R
M"B`@("`@*B!`<V5E("`@("!.151?1E107T524E]03U)43$534UI%4D\*("`@
M("`J+PH@("`@"B`@("!F=6YC=&EO;B!S9710;W)T*"1P;W)T*0H@("`@>PH@
M("`@("`@(&EF("@A:7-?:6YT*"1P;W)T*2!\?"`H)'!O<G0@/"`P*2D@>PH@
M("`@("`@("`@("!014%2.CIR86ES945R<F]R*"));G9A;&ED('!O<G0N($AA
M<R!T;R!B92!I;G1E9V5R(#X](#`B+"!.151?1E107T524E]03U)43$534UI%
M4D\I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W!O<G0@/2`D<&]R=#L*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M="!T:&4@57-E<FYA;64*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*
M("`@("`J($!P87)A;2`@('-T<FEN9R`D=7-E<B!4:&4@57-E<FYA;64@=&\@
M<V5T"B`@("`@*B!`<F5T=7)N("!M:7AE9"!4<G5E(&]N('-U8V-E<W,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?55-%4DY!345.3U-44DE.1PH@("`@("HO"B`@("`*("`@(&9U;F-T:6]N
M('-E=%5S97)N86UE*"1U<V5R*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D
M=7-E<BD@?'P@(6ES7W-T<FEN9R@D=7-E<BDI('L*("`@("`@("`@("`@<F5T
M=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5S97)N86UE("1U<V5R(&EN=F%L:60N
M)RP@3D547T944%]%4E)?55-%4DY!345.3U-44DE.1RD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?=7-E<FYA;64@/2`D=7-E<CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%-E="!T:&4@4&%S<W=O<F0*("`@("`J"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)'!A<W-W;W)D
M("!4:&4@4&%S<W=O<F0@=&\@<V5T"B`@("`@*B!`<F5T=7)N("!V;VED"B`@
M("`@*B!`<V5E("`@("!.151?1E107T524E]005-35T]21$Y/4U1224Y'"B`@
M("`@*B\*("`@(`H@("`@9G5N8W1I;VX@<V5T4&%S<W=O<F0H)'!A<W-W;W)D
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D<&%S<W=O<F0I('Q\("%I<U]S
M=')I;F<H)'!A<W-W;W)D*2D@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G4&%S<W=O<F0@>'AX(&EN=F%L:60N)RP@3D547T944%]%
M4E)?4$%34U=/4D1.3U-44DE.1RD["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?<&%S<W=O<F0@/2`D<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@=&AE('1R86YS9F5R+6UO9&4N(%EO=2!C86X@=7-E('1H92!P<F5D
M969I;F5D(&-O;G-T86YT<PH@("`@("H@1E107T%30TE)(&]R($944%]"24Y!
M4EDN(%1H92!M;V1E('=I;&P@8F4@<W1O<F5D(&9O<B!A;GD@9G5R=&AE<B!T
M<F%N<V9E<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<&%R86T@("!I;G0@("`@)&UO9&4@(%1H92!M;V1E('1O('-E=`H@("`@
M("H@0')E='5R;B`@;6EX960@("`@("`@("!4<G5E(&]N('-U8V-E<W,L(&]T
M:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T944%]%
M4E)?3D]-3T1%0T].4U0*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!S971-
M;V1E*"1M;V1E*0H@("`@>PH@("`@("`@(&EF("@H)&UO9&4@/3T@1E107T%3
M0TE)*2!\?"`H)&UO9&4@/3T@1E107T))3D%262DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]M;V1E(#T@)&UO9&4["B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G1E10+4UO9&4@:&%S(&5I=&AE<B!T;R!B92!&5%!?05-#
M24D@;W(@1E107T))3D%262<L($Y%5%]&5%!?15)27TY/34]$14-/3E-4*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1R86YS
M9F5R+6UE=&AO9"!T;R!P87-S:79E(&UO9&4*("`@("`J"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('9O:60*("`@("`J+PH@("`@
M"B`@("!F=6YC=&EO;B!S971087-S:79E*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!A<W-V(#T@=')U93L*("`@("`@("!`9G1P7W!A<W8H)'1H:7,M/E]H
M86YD;&4L('1R=64I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T
M<F%N<V9E<BUM971H;V0@=&\@86-T:79E(&UO9&4*("`@("`J"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('9O:60*("`@("`J+PH@
M("`@"B`@("!F=6YC=&EO;B!S971!8W1I=F4H*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<&%S<W8@/2!F86QS93L*("`@("`@("!`9G1P7W!A<W8H)'1H:7,M
M/E]H86YD;&4L(&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T
M:&4@=&EM96]U="!F;W(@1E10(&]P97)A=&EO;G,*("`@("`J(%5S92!T:&ES
M(&UE=&AO9"!T;R!S970@82!T:6UE;W5T(&9O<B!&5%`@;W!E<F%T:6]N+B!4
M:6UE;W5T(&AA<R!T;R!B92!A;B!I;G1E9V5R+@H@("`@("H*("`@("`J($!A
M8V5S<R`@('!U8FQI8PH@("`@("H@0'!A<F%M("`@:6YT("1T:6UE;W5T('1H
M92!T:6UE;W5T('1O('5S90H@("`@("H@0')E='5R;B`@8F]O;"!4<G5E(&]N
M('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@
M("`@3D547T944%]%4E)?5$E-14]55$Q%4U-:15)/+"!.151?1E107T524E]3
M151424U%3U547T9!24Q%1`H@("`@("HO"B`@("`@"B`@("!F=6YC=&EO;B!S
M9714:6UE;W5T("@@)'1I;65O=70@/2`P("D@"B`@("!["B`@("`@("`@:68@
M*"%I<U]I;G0H)'1I;65O=70I('Q\("@D=&EM96]U="`\(#`I*2!["B`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")4:6UE;W5T("1T:6UE
M;W5T(&ES(&EN=F%L:60L(&AA<R!T;R!B92!A;B!I;G1E9V5R(#X](#`B+"!.
M151?1E107T524E]424U%3U543$534UI%4D\I.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^7W1I;65O=70@/2`D=&EM96]U=#L*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]H86YD;&4I("8F(&ES7W)E<V]U<F-E*"1T:&ES+3Y?:&%N
M9&QE*2D@>PH@("`@("`@("`@("`D<F5S(#T@0&9T<%]S971?;W!T:6]N*"1T
M:&ES+3Y?:&%N9&QE+"!&5%!?5$E-14]55%]314,L("1T:6UE;W5T*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#T@=')U93L*("`@("`@
M("!]"B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")3970@=&EM96]U="!F86EL960N(BP@3D547T94
M4%]%4E)?4T545$E-14]55%]&04E,140I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@=')U93L*("`@('T@("`@("`@(`H@("`@"B`@("`O*BH*("`@("`J
M($%D9',@86X@97AT96YS:6]N('1O(&$@;6]D92UD:7)E8W1O<GD*("`@("`J
M(%1H92!M;V1E+61I<F5C=&]R>2!S879E<R!F:6QE+65X=&5N<VEO;G,@8V]R
M97-P;VYD:6YG('1O(&9I;&5T>7!E<PH@("`@("H@*&%S8VEI(&4N9RXZ("=P
M:'`G+"`G='AT)RP@)VAT;2<L+BXN.R!B:6YA<GD@92YG+CH@)VIP9R<L("=G
M:68G+"`G97AE)RPN+BXI+@H@("`@("H@5&AE(&5X=&5N<VEO;G,@:&%V92!T
M;R!B92!S879E9"!W:71H;W5T('1H92`G+B<N($%N9`H@("`@("H@8V%N(&)E
M('!R961E9FEN960@:6X@86X@97AT97)N86P@9FEL92`H<V5E.B!G971%>'1E
M;G-I;VYS1FEL92@I*2X*("`@("`J"B`@("`@*B!4:&4@87)R87D@:7,@8G5I
M;&0@;&EK92!T:&ES.B`G<&AP)R`]/B!&5%!?05-#24DL("=P;F<G(#T^($94
M4%]"24Y!4ED*("`@("`J"B`@("`@*B!4;R!C:&%N9V4@=&AE(&UO9&4@;V8@
M86X@97AT96YS:6]N+"!J=7-T(&%D9"!I="!A9V%I;B!W:71H('1H92!N97<@
M;6]D92$*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!P
M87)A;2`@(&EN="`@("`D;6]D92`@16ET:&5R($944%]!4T-)22!O<B!&5%!?
M0DE.05)9"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&5X="`@($5X=&5N<VEO
M;@H@("`@("H@0')E='5R;B`@=F]I9`H@("`@("HO"B`@("`*("`@(&9U;F-T
M:6]N(&%D9$5X=&5N<VEO;B@D;6]D92P@)&5X="D*("`@('L*("`@("`@("`D
M=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT72`]("1M;V1E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!R96UO=F5S(&%N(&5X=&5N
M<VEO;B!F<F]M('1H92!M;V1E+61I<F5C=&]R:65S(`H@("`@("H@*&1E<V-R
M:6)E9"!A8F]V92DN"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@)&5X="`@5&AE(&5X=&5N<VEO;B!T;R!R
M96UO=F4*("`@("`J($!R971U<FX@('9O:60*("`@("`J+PH@("`@"B`@("!F
M=6YC=&EO;B!R96UO=F5%>'1E;G-I;VXH)&5X="D*("`@('L*("`@("`@("!U
M;G-E="@D=&AI<RT^7V9I;&5?97AT96YS:6]N<ULD97AT72D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!4:&ES(&=E="=S(&)O=&@@*&%S8VEI+2!A;F0@8FEN
M87)Y+6UO9&4M9&ER96-T;W)I97,I(&9R;VT@=&AE(&=I=F5N(&9I;&4N"B`@
M("`@*B!"97=A<F4L(&EF('EO=2!R96%D(&$@9FEL92!I;G1O('1H92!M;V1E
M+61I<F5C=&]R>2P@86QL(&9O<FUE<B!S970@=F%L=65S(`H@("`@("H@=VEL
M;"!B92!U;G-E="$*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J($!P87)A;2`@('-T<FEN9R`D9FEL96YA;64@(%1H92!F:6QE('1O(&=E
M="!F<F]M"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@("`@("!4<G5E
M(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E
M92`@("`@3D547T944%]%4E)?15A41DE,14Y/5$5825-4+"!.151?1E107T52
M4E]%6%1&24Q%4D5!1%]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO
M;B!G971%>'1E;G-I;VYS1FEL92@D9FEL96YA;64I"B`@("!["B`@("`@("`@
M:68@*"%F:6QE7V5X:7-T<R@D9FEL96YA;64I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B17AT96YS:6]N<RUF:6QE("<D9FEL
M96YA;64G(&1O97,@;F]T(&5X:7-T(BP@3D547T944%]%4E)?15A41DE,14Y/
M5$5825-4*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5A9&%B;&4H
M)&9I;&5N86UE*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D5X=&5N<VEO;G,M9FEL92`G)&9I;&5N86UE)R!I<R!N;W0@<F5A
M9&%B;&4B+"!.151?1E107T524E]%6%1&24Q%4D5!1%]&04E,140I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/E]F:6QE7V5X=&5N<VEO;B`]($!P87)S
M95]I;FE?9FEL92@D9FEL96YA;64I.PH@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@2&]S=&YA;64*("`@
M("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!R971U<FX@('-T
M<FEN9R`@5&AE($AO<W1N86UE"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M9V5T2&]S=&YA;64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VAO
M<W1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@4&]R
M=`H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R
M;B`@:6YT("`@("!4:&4@4&]R=`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N
M(&=E=%!O<G0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W!O<G0[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!5<V5R;F%M90H@
M("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@
M<W1R:6YG("!4:&4@57-E<FYA;64*("`@("`J+PH@("`@"B`@("!F=6YC=&EO
M;B!G9715<V5R;F%M92@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M=7-E<FYA;64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!0
M87-S=V]R9`H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@
M0')E='5R;B`@<W1R:6YG("!4:&4@4&%S<W=O<F0*("`@("`J+PH@("`@"B`@
M("!F=6YC=&EO;B!G971087-S=V]R9"@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%S<W=O<F0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS('1H92!4<F%N<V9E<FUO9&4*("`@("`J"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!R971U<FX@(&EN="`@("`@5&AE('1R86YS9F5R;6]D
M92P@96ET:&5R($944%]!4T-)22!O<B!&5%!?0DE.05)9+@H@("`@("HO"B`@
M("`*("`@(&9U;F-T:6]N(&=E=$UO9&4H*0H@("`@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7VUO9&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M+"!W:&5T:&5R('1H92!C;VYN96-T:6]N(&ES('-E="!T;R!P87-S:79E(&UO
M9&4@;W(@;F]T"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N("!B;V]L("`@(%1R=64@:68@<&%S<VEV92TL(&9A;'-E(&EF
M(&%C=&EV92UM;V1E"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@:7-087-S
M:79E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]P87-S=CL*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&UO9&4@<V5T(&9O<B!A
M(&9I;&4M97AT96YS:6]N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`D97AT("`@(%1H92!E>'1E;G-I
M;VX@>6]U('=A;FYA(&%S:R!F;W(*("`@("`J($!R971U<FX@(&EN="`@("`@
M("`@("`@("`@16ET:&5R($944%]!4T-)22P@1E107T))3D%262!O<B!.54Q,
M("AI9B!N;W0@<V5T(&$@;6]D92!F;W(@:70I"B`@("`@*B\*("`@(`H@("`@
M9G5N8W1I;VX@9V5T17AT96YS:6]N36]D92@D97AT*0H@("`@>PH@("`@("`@
M(')E='5R;B!`)'1H:7,M/E]F:6QE7V5X=&5N<VEO;G-;)&5X=%T["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!'970@=&AE(&-U<G)E;G1L>2!S970@=&EM96]U
M="X*("`@("`J(%)E='5R;G,@=&AE(&%C='5A;"!T:6UE;W5T('-E="X*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!I;G0@
M5&AE(&%C='5A;"!T:6UE;W5T"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M9V5T5&EM96]U="`H("D*("`@('L*("`@("`@("!R971U<FX@9G1P7V=E=%]O
M<'1I;VXH)'1H:7,M/E]H86YD;&4L($944%]424U%3U547U-%0RD["B`@("!]
M("`@(`H*("`@("\J*@H@("`@("H@061D<R!A($YE=%]&5%!?3V)S97)V97(@
M:6YS=&%N8V4@=&\@=&AE(&QI<W0@;V8@;V)S97)V97)S(`H@("`@("H@=&AA
M="!A<F4@;&ES=&5N:6YG(&9O<B!M97-S86=E<R!E;6ET=&5D(&)Y('1H:7,@
M3F5T7T944"!I;G-T86YC92X*("`@("`J"B`@("`@*B!`<&%R86T@("!O8FIE
M8W0@("`D;V)S97)V97(@("`@(%1H92!.971?1E107T]B<V5R=F5R(&EN<W1A
M;F-E('1O(&%T=&%C:"`*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87,@82!L:7-T96YE<BX*("`@("`J($!R971U<FX@(&)O;VQE
M86X@("`@("`@("`@("`@("`@5')U92!I9B!T:&4@;V)S97)V97(@:7,@<W5C
M8V5S<V9U;&QY(&%T=&%C:&5D+@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B!`<VEN8V4@("`Q+C,*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!A
M='1A8V@H)B1O8G-E<G9E<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&]B
M<V5R=F5R+"`G3F5T7T944%]/8G-E<G9E<B<I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?;&ES=&5N
M97)S6R1O8G-E<G9E<BT^9V5T260H*5T@/2`F)&]B<V5R=F5R.PH@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M($YE=%]&5%!?3V)S97)V97(@:6YS=&%N8V4@9G)O;2!T:&4@;&ES="!O9B!O
M8G-E<G9E<G,N"B`@("`@*@H@("`@("H@0'!A<F%M("`@;V)J96-T("`@)&]B
M<V5R=F5R("`@("!4:&4@3F5T7T944%]/8G-E<G9E<B!I;G-T86YC92!T;R!D
M971A8V@@"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9R;VT@=&AE(&QI<W0@;V8@;&ES=&5N97)S+@H@("`@("H@0')E='5R;B`@
M8F]O;&5A;B`@("`@("`@("`@("`@("!4<G5E(&EF('1H92!O8G-E<G9E<B!I
M<R!S=6-C97-S9G5L;'D@9&5T86-H960N"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J($!S:6YC92`@(#$N,PH@("`@("HO"B`@("`*("`@(&9U;F-T
M:6]N(&1E=&%C:"@D;V)S97)V97(I"B`@("!["B`@("`@("`@:68@*"%I<U]A
M*"1O8G-E<G9E<BP@)TYE=%]&5%!?3V)S97)V97(G*2!\?`H@("`@("`@("`@
M("`A:7-S970H)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R=F5R+3YG971)9"@I
M72DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@=6YS970H)'1H:7,M/E]L:7-T96YE<G-;)&]B<V5R=F5R+3YG971)
M9"@I72D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!);F9O<FUS(&5A8V@@<F5G:7-T97)E9"!O8G-E<G9E<B!I;G-T86YC
M92!T:&%T(&$@;F5W(&UE<W-A9V4@:&%S(&)E96X*("`@("`J('-E;G0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@)&5V96YT("`@("`@($$@
M:&%S:"!D97-C<FEB:6YG('1H92!N970@979E;G0N("`@"B`@("`@*B!`86-C
M97-S("!P<FEV871E("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`*("`@("`J($!S:6YC92`@(#$N,R`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(`H@("`@("HO("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@"B`@("`*
M("`@(&9U;F-T:6]N(%]A;FYO=6YC92@D979E;G0I"B`@("!["B`@("`@("`@
M9F]R96%C:"`H)'1H:7,M/E]L:7-T96YE<G,@87,@)&ED(#T^("1L:7-T96YE
M<BD@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:61=+3YN;W1I
M9GDH)&5V96YT*3L*("`@("`@("!]"B`@("!]"B`@("`*("`@("`@("`O*BH*
M("`@("`J(%)E8G5I;&0@=&AE('!A=&@L(&EF(&=I=F5N(')E;&%T:79E"B`@
M("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("1P871H("`@5&AE('!A=&@@=&\@8VAE8VL@86YD(&-O;G-T<G5C
M=`H@("`@("H@0')E='5R;B`@<W1R:6YG("`@("`@("`@5&AE(&)U:6QD('!A
M=&@*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?8V]N<W1R=6-T7W!A=&@H
M)'!A=&@I"B`@("!["B`@("`@("`@:68@*"AS=6)S='(H)'!A=&@L(#`L(#$I
M("$]("(O(BD@)B8@*'-U8G-T<B@D<&%T:"P@,"P@,BD@(3T@(BXO(BDI('L*
M("`@("`@("`@("`@)&%C='5A;%]D:7(@/2!`9G1P7W!W9"@D=&AI<RT^7VAA
M;F1L92D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&%C='5A;%]D:7(L("AS
M=')L96XH)&%C='5A;%]D:7(I("T@,BDL(#$I("$]("(O(BD@>PH@("`@("`@
M("`@("`@("`@)&%C='5A;%]D:7(@+CT@(B\B.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1P871H(#T@)&%C='5A;%]D:7(N)'!A=&@["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<&%T:#L*("`@('T*"B`@("`O*BH*("`@("`J
M($-H96-K<RP@=VAE=&AE<B!A(&=I=F5N('-T<FEN9R!I<R!A(&1I<F5C=&]R
M>2UP871H("AE;F1S('=I=&@@(B\B*2!O<B!N;W0N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R:6YG("1P871H
M("!0871H('1O(&-H96-K"B`@("`@*B!`<F5T=7)N("!B;V]L("`@("`@("`@
M(%1R=64@:68@)'!A=&@@:7,@82!D:7)E8W1O<GDL(&]T:&5R=VES92!F86QS
M90H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]C:&5C:U]D:7(H)'!A=&@I
M"B`@("!["B`@("`@("`@:68@*"%E;7!T>2@D<&%T:"D@)B8@<W5B<W1R*"1P
M871H+"`H<W1R;&5N*"1P871H*2`M(#$I+"`Q*2`]/2`B+R(I('L*("`@("`@
M("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%1H:7,@=VEL;"!R96UO=F4@82!F:6QE"B`@("`@*@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("H@0'!A<F%M("`@<W1R:6YG("1F:6QE("`@
M5&AE(&9I;&4@=&\@9&5L971E"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@
M("`@("!4<G5E(&]N('-U8V-E<W,L(&]T:&5R=VES92!014%2.CI%<G)O<@H@
M("`@("H@0'-E92`@("`@3D547T944%]%4E)?1$5,151%1DE,15]&04E,140*
M("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?<FU?9FEL92@D9FEL92D*("`@
M('L*("`@("`@("!I9B`H<W5B<W1R*"1F:6QE+"`P+"`Q*2`A/2`B+R(I('L*
M("`@("`@("`@("`@)&%C='5A;%]D:7(@/2!`9G1P7W!W9"@D=&AI<RT^7VAA
M;F1L92D["B`@("`@("`@("`@(&EF("AS=6)S='(H)&%C='5A;%]D:7(L("AS
M=')L96XH)&%C='5A;%]D:7(I("T@,BDL(#$I("$]("(O(BD@>PH@("`@("`@
M("`@("`@("`@)&%C='5A;%]D:7(@+CT@(B\B.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1F:6QE(#T@)&%C='5A;%]D:7(N)&9I;&4["B`@("`@("`@
M?0H@("`@("`@("1R97,@/2!`9G1P7V1E;&5T92@D=&AI<RT^7VAA;F1L92P@
M)&9I;&4I.PH@("`@("`@(`H@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-O=6QD(&YO="!D96QE
M=&4@9FEL92`G)&9I;&4G+B(L($Y%5%]&5%!?15)27T1%3$54149)3$5?1D%)
M3$5$*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES('=I;&P@
M<F5M;W9E(&$@9&ER"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@(%1H92!D:7(@=&\@9&5L971E
M"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@5')U92!O;B!S=6-C97-S
M+"!O=&AE<G=I<V4@4$5!4CHZ17)R;W(*("`@("`J($!S964@("`@($Y%5%]&
M5%!?15)27U)%34]415!!5$A.3T1)4BP@3D547T944%]%4E)?1$5,151%1$E2
M7T9!24Q%1`H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]R;5]D:7(H)&1I
M<BD*("`@('L*("`@("`@("!I9B`H<W5B<W1R*"1D:7(L("AS=')L96XH)&1I
M<BD@+2`Q*2P@,2D@(3T@(B\B*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B1&ER96-T;W)Y(&YA;64@)R1D:7(G(&ES(&EN=F%L
M:60L(&AA<R!T;R!E;F0@=VET:"`G+R<B+"!.151?1E107T524E]214U/5$50
M051(3D]$25(I.PH@("`@("`@('T*("`@("`@("`D<F5S(#T@0&9T<%]R;61I
M<B@D=&AI<RT^7VAA;F1L92P@)&1I<BD["B`@("`@("`@:68@*"$D<F5S*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0V]U;&0@
M;F]T(&1E;&5T92!D:7)E8W1O<GD@)R1D:7(G+B(L($Y%5%]&5%!?15)27T1%
M3$54141)4E]&04E,140I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%1H:7,@=VEL;"!R96UO=F4@82!D:7(@86YD(&%L;"!S=6)D:7)S(&%N9"`M
M9FEL97,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`
M<&%R86T@("!S=')I;F<@)&9I;&4@(%1H92!D:7(@=&\@9&5L971E(')E8W5R
M<VEV96QY"B`@("`@*B!`<F5T=7)N("!M:7AE9"`@("`@("`@(%1R=64@;VX@
M<W5C8V5S<RP@;W1H97)W:7-E(%!%05(Z.D5R<F]R"B`@("`@*B!`<V5E("`@
M("!.151?1E107T524E]214U/5$50051(3D]$25(L($Y%5%]&5%!?15)27T1%
M3$54141)4E]&04E,140*("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?<FU?
M9&ER7W)E8W5R<VEV92@D9&ER*0H@("`@>PH@("`@("`@(&EF("AS=6)S='(H
M)&1I<BP@*'-T<FQE;B@D9&ER*2`M(#$I+"`Q*2`A/2`B+R(I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$:7)E8W1O<GD@;F%M
M92`G)&1I<B<@:7,@:6YV86QI9"P@:&%S('1O(&5N9"!W:71H("<O)R(L($Y%
M5%]&5%!?15)27U)%34]415!!5$A.3T1)4BD["B`@("`@("`@?0H@("`@("`@
M("1F:6QE7VQI<W0@/2`D=&AI<RT^7VQS7V9I;&5S*"1D:7(I.PH@("`@("`@
M(&9O<F5A8V@@*"1F:6QE7VQI<W0@87,@)&9I;&4I('L*("`@("`@("`@("`@
M)&9I;&4@/2`D9&ER+B1F:6QE6R)N86UE(ET["B`@("`@("`@("`@("1R97,@
M/2`D=&AI<RT^<FTH)&9I;&4I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/FES
M17)R;W(H)')E<RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D:7)?;&ES="`]("1T
M:&ES+3Y?;'-?9&ER<R@D9&ER*3L*("`@("`@("!F;W)E86-H("@D9&ER7VQI
M<W0@87,@)&YE=U]D:7(I('L*("`@("`@("`@("`@)&YE=U]D:7(@/2`D9&ER
M+B1N97=?9&ER6R)N86UE(ETN(B\B.PH@("`@("`@("`@("`D<F5S(#T@)'1H
M:7,M/E]R;5]D:7)?<F5C=7)S:79E*"1N97=?9&ER*3L*("`@("`@("`@("`@
M:68@*"1T:&ES+3YI<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D
M<F5S(#T@)'1H:7,M/E]R;5]D:7(H)&1I<BD["B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@3&ES=',@=7`@9FEL97,@86YD
M(&1I<F5C=&]R:65S"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("H@0'!A<F%M("`@<W1R:6YG("1D:7(@(%1H92!D:7)E8W1O<GD@=&\@
M;&ES="!U<`H@("`@("H@0')E='5R;B`@87)R87D@("`@("`@($%N(&%R<F%Y
M(&]F(&1I<G,@86YD(&9I;&5S"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@
M7VQS7V)O=&@H)&1I<BD*("`@('L*("`@("`@("`D;&ES=%]S<&QI='1E9"`]
M("1T:&ES+3Y?;&ES=%]A;F1?<&%R<V4H)&1I<BD["B`@("`@("`@:68@*"%I
M<U]A<G)A>2@D;&ES=%]S<&QI='1E9%LB9FEL97,B72DI('L*("`@("`@("`@
M("`@)&QI<W1?<W!L:71T961;(F9I;&5S(ET@/2!A<G)A>2@I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1L:7-T7W-P;&ET=&5D6R)D:7)S
M(ETI*2!["B`@("`@("`@("`@("1L:7-T7W-P;&ET=&5D6R)D:7)S(ET@/2!A
M<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D<F5S(#T@87)R87DH*3L*("`@
M("`@("!`87)R87E?<W!L:6-E*"1R97,L(#`L(#`L("1L:7-T7W-P;&ET=&5D
M6R)F:6QE<R)=*3L*("`@("`@("!`87)R87E?<W!L:6-E*"1R97,L(#`L(#`L
M("1L:7-T7W-P;&ET=&5D6R)D:7)S(ETI.PH@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES=',@=7`@9&ER96-T;W)I97,*
M("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@)&1I<B`@5&AE(&1I<F5C=&]R>2!T;R!L:7-T('5P"B`@("`@
M*B!`<F5T=7)N("!A<G)A>2`@("`@("`@06X@87)R87D@;V8@9&ER<PH@("`@
M("HO"B`@("`*("`@(&9U;F-T:6]N(%]L<U]D:7)S*"1D:7(I"B`@("!["B`@
M("`@("`@)&QI<W0@/2`D=&AI<RT^7VQI<W1?86YD7W!A<G-E*"1D:7(I.PH@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1L:7-T*2D@>PH@("`@("`@("`@
M("!R971U<FX@)&QI<W0["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;&ES
M=%LB9&ER<R)=.PH@("`@?0H*("`@("\J*@H@("`@("H@3&ES=',@=7`@9FEL
M97,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@)&1I<B`@5&AE(&1I<F5C=&]R>2!T;R!L:7-T('5P"B`@
M("`@*B!`<F5T=7)N("!A<G)A>2`@("`@("`@06X@87)R87D@;V8@9FEL97,*
M("`@("`J+PH@("`@"B`@("!F=6YC=&EO;B!?;'-?9FEL97,H)&1I<BD*("`@
M('L*("`@("`@("`D;&ES="`]("1T:&ES+3Y?;&ES=%]A;F1?<&%R<V4H)&1I
M<BD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QI<W0I*2!["B`@("`@
M("`@("`@(')E='5R;B`D;&ES=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1L:7-T6R)F:6QE<R)=.PH@("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!L
M:7-T<R!U<"!T:&4@9&ER96-T;W)Y+6-O;G1E;G0@86YD('!A<G-E<R!T:&4@
M:71E;7,@:6YT;R!W96QL+69O<FUA=&5D(&%R<F%Y<PH@("`@("H@5&AE(')E
M<W5L=',@;V8@=&AI<R!A<G)A>2!A<F4@<V]R=&5D("AD:7)S(&]N('1O<"P@
M<V]R=&5D(&)Y(&YA;64["B`@("`@*B!F:6QE<R!B96QO=RP@<V]R=&5D(&)Y
M(&YA;64I+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J
M($!P87)A;2`@('-T<FEN9R`D9&ER("!4:&4@9&ER96-T;W)Y('1O('!A<G-E
M"B`@("`@*B!`<F5T=7)N("!A<G)A>2`@("`@("`@3&ES=',@;V8@9&ER<R!A
M;F0@9FEL97,*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27U)!5T1)4DQ)
M4U1?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7VQI<W1?86YD
M7W!A<G-E*"1D:7(I"B`@("!["B`@("`@("`@)&1I<G-?;&ES="`](&%R<F%Y
M*"D["B`@("`@("`@)&9I;&5S7VQI<W0@/2!A<G)A>2@I.PH@("`@("`@("1D
M:7)?;&ES="`]($!F='!?<F%W;&ES="@D=&AI<RT^7VAA;F1L92P@)&1I<BD[
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D9&ER7VQI<W0I*2!["B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#;W5L9"!N;W0@9V5T(')A
M=R!D:7)E8W1O<GD@;&ES=&EN9RXG+"!.151?1E107T524E]205=$25),25-4
M7T9!24Q%1"D["B`@("`@("`@?0H@("`@("`@("\O($AA;F1L92!E;7!T>2!D
M:7)E8W1O<FEE<PH@("`@("`@(&EF("AC;W5N="@D9&ER7VQI<W0I(#T](#`I
M('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=D:7)S)R`]/B`D9&ER<U]L
M:7-T+"`G9FEL97,G(#T^("1F:6QE<U]L:7-T*3L*("`@("`@("!]"B`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7VUA=&-H97(I('Q\(%!%05(Z.FES17)R
M;W(H)'1H:7,M/E]M871C:&5R*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VUA
M=&-H97(@/2`D=&AI<RT^7V1E=&5R;6EN95]O<U]M871C:"@D9&ER7VQI<W0I
M.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7VUA=&-H
M97(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]M871C:&5R
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&9O<F5A8V@@*"1D
M:7)?;&ES="!A<R`D96YT<GDI('L*("`@("`@("`@("`@:68@*"%P<F5G7VUA
M=&-H*"1T:&ES+3Y?;6%T8VAE<ELG<&%T=&5R;B==+"`D96YT<GDL("1M*2D@
M>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&5N=')Y(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]M871C:&5R6R=M87`G72!A<R`D:V5Y/3XD=F%L*2!["B`@
M("`@("`@("`@("`@("`D96YT<GE;)&ME>5T@/2`D;5LD=F%L73L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D96YT<GE;)W-T86UP)UT@/2`D=&AI<RT^
M7W!A<G-E7T1A=&4H)&5N=')Y6R=D871E)UTI.PH*("`@("`@("`@("`@:68@
M*"1E;G1R>5LG:7-?9&ER)UTI('L*("`@("`@("`@("`@("`@("1D:7)S7VQI
M<W1;72`]("1E;G1R>3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1F:6QE<U]L:7-T6UT@/2`D96YT<GD["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@0'5S;W)T*"1D:7)S7VQI<W0L(&%R<F%Y*").
M971?1E10(BP@(E]N871?<V]R="(I*3L*("`@("`@("!`=7-O<G0H)&9I;&5S
M7VQI<W0L(&%R<F%Y*").971?1E10(BP@(E]N871?<V]R="(I*3L*("`@("`@
M("`D<F5S6R)D:7)S(ET@/2`H:7-?87)R87DH)&1I<G-?;&ES="DI(#\@)&1I
M<G-?;&ES="`Z(&%R<F%Y*"D["B`@("`@("`@)')E<ULB9FEL97,B72`]("AI
M<U]A<G)A>2@D9FEL97-?;&ES="DI(#\@)&9I;&5S7VQI<W0@.B!A<G)A>2@I
M.PH@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H@("`@"B`@("`O*BH*("`@
M("`J($1E=&5R;6EN92!S97)V97(@3U,*("`@("`J(%1H:7,@9&5T97)M:6YE
M<R!T:&4@<V5R=F5R($]3(&%N9"!R971U<FYS(&$@=F%L:60@<F5G97@@=&\@
M<&%R<V4*("`@("`J(&QS*"D@;W5T<'5T+@H@("`@("H*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@(&%R<F%Y("1D:7)?;&ES="!4
M:&4@<F%W(&1I<B!L:7-T('1O('!A<G-E"B`@("`@*B!`<F5T=7)N("!M:7AE
M9"!!;B!A<G)A>2!O9B`G<&%T=&5R;B<@86YD("=M87`G(&]N('-U8V-E<W,L
M(&]T:&5R=VES92!014%2.CI%<G)O<@H@("`@("H@0'-E92`@("`@3D547T94
M4%]%4E)?1$E23$E35%]53E-54%!/4E1%1`H@("`@("HO"B`@("`*("`@(&9U
M;F-T:6]N(%]D971E<FUI;F5?;W-?;6%T8V@H)B1D:7)?;&ES="D@>PH@("`@
M9F]R96%C:"`H)&1I<E]L:7-T(&%S("1E;G1R>2D@>PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?;'-?;6%T8V@@87,@)&]S(#T^("1M871C:"D@>PH@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@D;6%T8VA;)W!A='1E<FXG72P@)&5N
M=')Y*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D;6%T8V@["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@('T*("`@("`@("`D
M97)R;W(@/2`G5&AE(&QI<W0@<W1Y;&4@;V8@>6]U<B!S97)V97(@<V5E;7,@
M;F]T('1O(&)E('-U<'!O<G1E9"X@4&QE87-E(&5M86EL(&$@(B1F='`M/FQS
M*$Y%5%]&5%!?4D%73$E35"D[(B!O=71P=70@<&QU<R!I;F9O(&]N('1H92!S
M97)V97(@=&\@=&AE(&UA:6YT86EN97(@;V8@=&AI<R!P86-K86=E('1O(&=E
M="!I="!S=7!P;W)T960A(%1H86YK<R!F;W(@>6]U<B!H96QP(2<["B`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R+"!.151?1E107T52
M4E]$25),25-47U5.4U504$]25$5$*3L*("`@('T*("`@("\J*@H@("`@("H@
M3&ES=',@82!L;V-A;"!D:7)E8W1O<GD*("`@("`J"B`@("`@*B!`86-C97-S
M("!P<FEV871E"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&1I<E]P871H("!4
M:&4@9&ER('1O(&QI<W0*("`@("`J($!R971U<FX@(&%R<F%Y("`@("`@("`@
M("`@(%1H92!L:7-T(&]F(&1I<G,@86YD(&9I;&5S"B`@("`@*B\*("`@(`H@
M("`@9G5N8W1I;VX@7VQS7VQO8V%L*"1D:7)?<&%T:"D*("`@('L*("`@("`@
M("`D9&ER(#T@9&ER*"1D:7)?<&%T:"D["B`@("`@("`@)&1I<E]L:7-T(#T@
M87)R87DH*3L*("`@("`@("`D9FEL95]L:7-T(#T@87)R87DH*3L*("`@("`@
M("!W:&EL92`H9F%L<V4@(3T]("@D96YT<GD@/2`D9&ER+3YR96%D*"DI*2![
M"B`@("`@("`@("`@(&EF("@H)&5N=')Y("$]("<N)RD@)B8@*"1E;G1R>2`A
M/2`G+BXG*2D@>PH@("`@("`@("`@("`@("`@:68@*&ES7V1I<B@D9&ER7W!A
M=&@N)&5N=')Y*2D@>PH@("`@("`@("`@("`@("`@("`@("1D:7)?;&ES=%M=
M(#T@)&5N=')Y.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D9FEL95]L:7-T6UT@/2`D96YT<GD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@)&1I<BT^
M8VQO<V4H*3L*("`@("`@("`D<F5S6R=D:7)S)UT@/2`D9&ER7VQI<W0["B`@
M("`@("`@)')E<ULG9FEL97,G72`]("1F:6QE7VQI<W0["B`@("`@("`@<F5T
M=7)N("1R97,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!F;W(@
M=7-E('=I=&@@=7-O<G0H*2X*("`@("`J($-O;7!A<F5S('1H92!L:7-T+6%R
M<F%Y+65L96UE;G1S(&)Y(&YA;64N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@
M<')I=F%T90H@("`@("HO"B`@("`*("`@(&9U;F-T:6]N(%]N871?<V]R="@D
M:71E;5\Q+"`D:71E;5\R*0H@("`@>PH@("`@("`@(')E='5R;B!S=')N871C
M;7`H)&ET96U?,5LG;F%M92==+"`D:71E;5\R6R=N86UE)UTI.PH@("`@?0H*
M("`@("\J*@H@("`@("H@4&%R<V4@9&%T97,@=&\@=&EM97-T86UP<PH@("`@
M("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!P87)A;2`@('-T
M<FEN9R`D9&%T92`@1&%T90H@("`@("H@0')E='5R;B`@:6YT("`@("`@("`@
M("!4:6UE<W1A;7`*("`@("`J($!S964@("`@($Y%5%]&5%!?15)27T1!5$5&
M3U)-051?1D%)3$5$"B`@("`@*B\*("`@(`H@("`@9G5N8W1I;VX@7W!A<G-E
M7T1A=&4H)&1A=&4I"B`@("!["B`@("`@("`@+R\@4V5P(#$P(#(R.C`V(#T^
M(%-E<"`Q,"P@/'EE87(^(#(R.C`V"B`@("`@("`@:68@*'!R96=?;6%T8V@H
M)R\H6T$M6F$M>ETK*5L@72LH6S`M.5TK*5L@72LH6S`M.5TK*3HH6S`M.5TK
M*2\G+"`D9&%T92P@)')E<RDI('L*("`@("`@("`@("`@)'EE87(@/2!D871E
M*"=9)RD["B`@("`@("`@("`@("1M;VYT:"`]("1R97-;,5T["B`@("`@("`@
M("`@("1D87D@/2`D<F5S6S)=.PH@("`@("`@("`@("`D:&]U<B`]("1R97-;
M,UT["B`@("`@("`@("`@("1M:6YU=&4@/2`D<F5S6S1=.PH@("`@("`@("`@
M("`D9&%T92`]("(D;6]N=&@@)&1A>2P@)'EE87(@)&AO=7(Z)&UI;G5T92([
M"B`@("`@("`@("`@("1T;7!$871E(#T@<W1R=&]T:6UE*"1D871E*3L*("`@
M("`@("`@("`@:68@*"1T;7!$871E(#X@=&EM92@I*2!["B`@("`@("`@("`@
M("`@("`D>65A<BTM.PH@("`@("`@("`@("`@("`@)&1A=&4@/2`B)&UO;G1H
M("1D87DL("1Y96%R("1H;W5R.B1M:6YU=&4B.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@("\O(#`Y+3$P+3`T(#T^(#`Y+S$P+S`T"B`@("`@
M("`@96QS96EF("AP<F5G7VUA=&-H*"<O7EQD7&0M7&1<9"U<9%QD+R<L)&1A
M=&4I*2!["B`@("`@("`@("`@("1D871E(#T@<W1R7W)E<&QA8V4H)RTG+"<O
M)RPD9&%T92D["B`@("`@("`@?0H@("`@("`@("1R97,@/2!S=')T;W1I;64H
M)&1A=&4I.PH@("`@("`@(&EF("@A)')E<RD@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)T1A=&5C;VYV97)S:6]N(&9A:6QE9"XG
M+"!.151?1E107T524E]$051%1D]234%47T9!24Q%1"D["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<F5S.PH@("`@?0I]"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B].970O1E10
M+T]B<V5R=F5R+G!H<```````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`U-C(R(#$P-3$U-#,T,3,U(#`R,C$T-P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RH@=FEM.B!S970@
M97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]
M-#H@*B\*"B\J*@H@*B!.971?1E10(&]B<V5R=F5R+@H@*@H@*B!4:&ES(&-L
M87-S(&EM<&QE;65N=',@=&AE($]B<V5R=F5R('!A<G0@;V8@82!3=6)J96-T
M+4]B<V5R=F5R"B`J(&1E<VEG;B!P871T97)N+B!)="!L:7-T96YS('1O('1H
M92!E=F5N=',@<V5N="!B>2!A($YE=%]&5%`@:6YS=&%N8V4N"B`J(%1H:7,@
M;6]D=6QE(&AA9"!M86YY(&EN9FQU96YC97,@9G)O;2!T:&4@3&]G7V]B<V5R
M=F5R(&-O9&4N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@
M*B!`8V%T96=O<GD@("!.971W;W)K:6YG"B`J($!P86-K86=E("`@($944`H@
M*B!`875T:&]R("`@("!4;V)I87,@4V-H;&ET="`\=&]B>4!P:'`N;F5T/@H@
M*B!`875T:&]R("`@("!,875R96YT($QA=FEL;&4@/'!E87)`;&%U<F5N="UL
M879I;&QE+F]R9SX*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC
M:'5C:T!H;W)D92YO<F<^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@
M4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@3V)S97)V97(N<&AP+'8@,2XR(#(P,#4O,#(O,C,@,3(Z
M,3(Z,C,@=&]B>2!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O3F5T7T944`H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#`N,"XQ"B`J+PH*+RHJ"B`J(%1H:7,@
M8VQA<W,@:6UP;&5M96YT<R!T:&4@3V)S97)V97(@<&%R="!O9B!A(%-U8FIE
M8W0M3V)S97)V97(*("H@9&5S:6=N('!A='1E<FXN($ET(&QI<W1E;G,@=&\@
M=&AE(&5V96YT<R!S96YT(&)Y(&$@3F5T7T944"!I;G-T86YC92X*("H@5&AI
M<R!M;V1U;&4@:&%D(&UA;GD@:6YF;'5E;F-E<R!F<F]M('1H92!,;V=?;V)S
M97)V97(@8V]D92X*("H*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!C871E
M9V]R>2`@($YE='=O<FMI;F<*("H@0'!A8VMA9V4@("`@1E10"B`J($!A=71H
M;W(@("`@($QA=7)E;G0@3&%V:6QL92`\<&5A<D!L875R96YT+6QA=FEL;&4N
M;W)G/@H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX*("H@0&%U=&AO<B`@("`@5&]B:6%S(%-C:&QI='0@/'1O8GE`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C$*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TYE=%]&5%`*("H@0'-I
M;F-E("`@("`@,2XS+C`N,`H@*B!`86-C97-S("`@("!P=6)L:6,*("H*("H@
M0&5X86UP;&4@("`@;V)S97)V97)?=7!L;V%D+G!H<"`@("`@("`@("!!;B!E
M>&%M<&QE(&]F($YE=%]&5%!?3V)S97)V97(@:6UP;&5M96YT871I;VXN"B`J
M+PIC;&%S<R!.971?1E107T]B<V5R=F5R"GL*("`@("\J*@H@("`@("H@26YS
M=&%N8V4M<W!E8VEF:6,@=6YI<75E(&ED96YT:69I8V%T:6]N(&YU;6)E<BX*
M("`@("`J"B`@("`@*B!`=F%R("`@("`@("!I;G1E9V5R"B`@("`@*B!`<VEN
M8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@("`@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]I9#L*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N
M97<@8F%S:6,@3F5T7T944%]/8G-E<G9E<B!I;G-T86YC92X*("`@("`J"B`@
M("`@*B!`<VEN8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@("`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($YE=%]&5%!?3V)S97)V97(H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES=&5N97(G<R!I
M9&5N=&EF:65R"B`@("`@*@H@("`@("H@0')E='5R;B`@("`@<W1R:6YG"B`@
M("`@*B!`<VEN8V4@("`@("`Q+C,N,`H@("`@("H@0&%C8V5S<R`@("`@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$ED*"D*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/E]I9#L*("`@('T*"B`@("`O*BH*("`@("`J(%1H
M:7,@:7,@82!S='5B(&UE=&AO9"!T;R!M86ME('-U<F4@=&AA="!.971?1E10
M7T]B<V5R=F5R(&-L87-S97,@9&\*("`@("`J('-O;65T:&EN9R!W:&5N('1H
M97D@87)E(&YO=&EF:65D(&]F(&$@;65S<V%G92X@(%1H92!D969A=6QT(&)E
M:&%V:6]R"B`@("`@*B!I<R!T;R!J=7-T(&1O(&YO=&AI;F<N"B`@("`@*B!9
M;W4@<VAO=6QD(&]V97)R:61E('1H:7,@;65T:&]D+@H@("`@("H*("`@("`J
M($!P87)A;2`@("`@(&UI>&5D("`@("`D979E;G0@("`@("`@("!!(&AA<V@@
M9&5S8W)I8FEN9R!T:&4@;F5T(&5V96YT+@H@("`@("H*("`@("`J($!S:6YC
M92`@("`@(#$N,RXP"B`@("`@*B!`86-C97-S("`@("!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@;F]T:69Y*"1E=F5N="D*("`@('L*("`@("`@("!R
M971U<FX["B`@("!]"GT*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO;6EM941E8V]D92YP:'``````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-S0V-38@,3`U,34T
M,S0Q,S4@,#(R,3,S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P
M/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M
M,C`P,R`@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($-O<'ER:6=H="`H8RD@,C`P,RTR,#`U("!4:&4@4$A0
M($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\
M"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H
M870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P*+R\@?"!A<F4@;65T
M.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@
M;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="`@("`@('P*+R\@?"`@
M(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P*
M+R\@?"`@(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P
M<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA
M;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@("`@("!\"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R
M;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T
M96X@('P*+R\@?"`@('!E<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@5$A)4R!33T945T%212!)
M4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E12
M24)55$]24R`@('P*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)
M35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO
M+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@3452
M0TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\"B\O('P@02!005)424-5
M3$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,
M(%1(12!#3U!94DE'2%0@('P*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@
M0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!
M3"P@?`HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!
M3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\"B\O('P@3$E-
M251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!3
M15)624-%4SL@3$]34R!/1B!54T4L('P*+R\@?"!$051!+"!/4B!04D]&2513
M.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.
M1"!/3B!!3ED@?`HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@
M24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\"B\O
M('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.
M1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P*+R\@?"!/1B!42$E3(%-/
M1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)0DE,2519($]&
M(%-50T@@1$%-04=%+B`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@HJ("`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T@24U03U)404Y4("TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L**B`@?"!5<V%G92!O9B!T:&ES
M(&-L87-S(&-O;7!A<F5D('1O(&YA=&EV92!P:'`@97AT96YS:6]N<R!S=6-H
M(&%S("`@("`@("!\"BH@('P@;6%I;'!A<G-E(&]R(&EM87`L(&ES('-L;W<@
M86YD(&UA>2!B92!F96%T=7)E(&1E9FEC:65N="X@268@879A:6QA8FQE?`HJ
M("!\('EO=2!A<F4@4U123TY'3%D@<F5C;VUM96YD960@=&\@=7-E('1H92!P
M:'`@97AT96YS:6]N<RX@("`@("`@("`@("`@('P**B`@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"BH**B!-:6UE($1E8V]D:6YG(&-L87-S"BH**B!4
M:&ES(&-L87-S('=I;&P@<&%R<V4@82!R87<@;6EM92!E;6%I;"!A;F0@<F5T
M=7)N"BH@=&AE('-T<G5C='5R92X@4F5T=7)N960@<W1R=6-T=7)E(&ES('-I
M;6EL87(@=&\**B!T:&%T(')E='5R;F5D(&)Y(&EM87!?9F5T8VAS=')U8W1U
M<F4H*2X**@HJ(%5304=%.B`H87-S=6UE("1I;G!U="!I<R!Y;W5R(')A=R!E
M;6%I;"D**@HJ("1D96-O9&4@/2!N97<@36%I;%]M:6UE1&5C;V1E*"1I;G!U
M="P@(EQR7&XB*3L**B`D<W1R=6-T=7)E(#T@)&1E8V]D92T^9&5C;V1E*"D[
M"BH@<')I;G1?<B@D<W1R=6-T=7)E*3L**@HJ($]R('-T871I8V%L;'DZ"BH*
M*B`D<&%R86US6R=I;G!U="==(#T@)&EN<'5T.PHJ("1S=')U8W1U<F4@/2!-
M86EL7VUI;65$96-O9&4Z.F1E8V]D92@D<&%R86US*3L**B!P<FEN=%]R*"1S
M=')U8W1U<F4I.PHJ"BH@5$]$3SH**B`@;R!);7!L96UE;G0@;75L=&EP87)T
M+V%P<&QE9&]U8FQE"BH@(&\@551&.#H@/S\_"@H)"3X@-"X@5V4@:&%V92!A
M;'-O(&9O=6YD(&$@<V]L=71I;VX@9F]R(&1E8V]D:6YG('1H92!55$8M."`*
M"0D^(&AE861E<G,N(%1H97)E9F]R92!)(&UA9&4@=&AE(&9O;&QO=VEN9R!F
M=6YC=&EO;CH*"0D^(`H)"3X@9G5N8W1I;VX@9&5C;V1E7W5T9C@H)'1X="D@
M>PH)"3X@)'1R86YS/6%R<F%Y*"+%)B,X,C$V.R(]/B+#M2(L(L6Q(CT^(L.[
M(BPBQ9`B/3XBPR8C.#(R-CLB+"+%L"(*"0D]/B+#)B,X,C4P.R(I.PH)"3X@
M)'1X=#US=')T<B@D='AT+"1T<F%N<RD["@D)/B!R971U<FXH=71F.%]D96-O
M9&4H)'1X="DI.PH)"3X@?0H)"3X@"@D)/B!!;F0@22!H879E(&EN<V5R=&5D
M('1H92!F;VQL;W=I;F<@;&EN92!T;R!T:&4@8VQA<W,Z"@D)/B`*"0D^(&EF
M("AS=')T;VQO=V5R*"1C:&%R<V5T*3T](G5T9BTX(BD@)'1E>'0]9&5C;V1E
M7W5T9C@H)'1E>'0I.PH)"3X@"@D)/B`N+BX@8F5F;W)E('1H92!F;VQL;W=I
M;F<@;VYE(&EN('1H92`B7V1E8V]D94AE861E<B(@9G5N8W1I;VXZ"@D)/B`*
M"0D^("1I;G!U="`]('-T<E]R97!L86-E*"1E;F-O9&5D+"`D=&5X="P@)&EN
M<'5T*3L*"0D^(`H)"3X@5&AI<R!W87D@9G)O;2!N;W<@;VX@:70@8V%N(&5A
M<VEL>2!D96-O9&4@=&AE(%541BTX(&AE861E<G,@=&]O+@H**@HJ($!A=71H
M;W(@(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^"BH@0'9E
M<G-I;VX@)%)E=FES:6]N.B`Q+C0V("0**B!`<&%C:V%G92!-86EL"BHO"F-L
M87-S($UA:6Q?;6EM941E8V]D92!E>'1E;F1S(%!%05(*>PH@("`@+RHJ"B`@
M("`@*B!4:&4@<F%W(&5M86EL('1O(&1E8V]D90H@("`@("H@0'9A<B`@("!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?:6YP=70["@H@("`@+RHJ"B`@("`@
M*B!4:&4@:&5A9&5R('!A<G0@;V8@=&AE(&EN<'5T"B`@("`@*B!`=F%R("`@
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]H96%D97(["@H@("`@+RHJ"B`@
M("`@*B!4:&4@8F]D>2!P87)T(&]F('1H92!I;G!U=`H@("`@("H@0'9A<B`@
M("!S=')I;F<*("`@("`J+PH@("`@=F%R("1?8F]D>3L*"B`@("`O*BH*("`@
M("`J($EF(&%N(&5R<F]R(&]C8W5R<RP@=&AI<R!I<R!U<V5D('1O('-T;W)E
M('1H92!M97-S86=E"B`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)%]E<G)O<CL*"B`@("`O*BH*("`@("`J($9L86<@=&\@9&5T97)M
M:6YE('=H971H97(@=&\@:6YC;'5D92!B;V1I97,@:6X@=&AE"B`@("`@*B!R
M971U<FYE9"!O8FIE8W0N"B`@("`@*B!`=F%R("`@(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1?:6YC;'5D95]B;V1I97,["@H@("`@+RHJ"B`@("`@*B!&
M;&%G('1O(&1E=&5R;6EN92!W:&5T:&5R('1O(&1E8V]D92!B;V1I97,*("`@
M("`J($!V87(@("`@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)%]D96-O9&5?
M8F]D:65S.PH*("`@("\J*@H@("`@("H@1FQA9R!T;R!D971E<FUI;F4@=VAE
M=&AE<B!T;R!D96-O9&4@:&5A9&5R<PH@("`@("H@0'9A<B`@("!B;V]L96%N
M"B`@("`@*B\*("`@('9A<B`D7V1E8V]D95]H96%D97)S.PH*("`@("\J*@H@
M("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@4V5T<R!U<"!T:&4@
M;V)J96-T+"!I;FET:6%L:7-E('1H92!V87)I86)L97,L(&%N9"!S<&QI=',@
M86YD"B`@("`@*B!S=&]R97,@=&AE(&AE861E<B!A;F0@8F]D>2!O9B!T:&4@
M:6YP=70N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!4:&4@:6YP=70@
M=&\@9&5C;V1E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!-86EL7VUI;65$96-O9&4H)&EN<'5T*0H@("`@>PH@("`@("`@
M(&QI<W0H)&AE861E<BP@)&)O9'DI("`@/2`D=&AI<RT^7W-P;&ET0F]D>4AE
M861E<B@D:6YP=70I.PH*("`@("`@("`D=&AI<RT^7VEN<'5T("`@("`@("`@
M(#T@)&EN<'5T.PH@("`@("`@("1T:&ES+3Y?:&5A9&5R("`@("`@("`@/2`D
M:&5A9&5R.PH@("`@("`@("1T:&ES+3Y?8F]D>2`@("`@("`@("`@/2`D8F]D
M>3L*("`@("`@("`D=&AI<RT^7V1E8V]D95]B;V1I97,@(#T@9F%L<V4["B`@
M("`@("`@)'1H:7,M/E]I;F-L=61E7V)O9&EE<R`]('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!"96=I;G,@=&AE(&1E8V]D:6YG('!R;V-E<W,N($EF
M(&-A;&QE9"!S=&%T:6-A;&QY"B`@("`@*B!I="!W:6QL(&-R96%T92!A;B!O
M8FIE8W0@86YD(&-A;&P@=&AE(&1E8V]D92@I(&UE=&AO9`H@("`@("H@;V8@
M:70N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y($%N(&%R<F%Y(&]F('9A
M<FEO=7,@<&%R86UE=&5R<R!T:&%T(&1E=&5R;6EN90H@("`@("H@("`@("`@
M("`@("`@('9A<FEO=7,@=&AI;F=S.@H@("`@("H@("`@("`@("`@("`@(&EN
M8VQU9&5?8F]D:65S("T@5VAE=&AE<B!T;R!I;F-L=61E('1H92!B;V1Y(&EN
M('1H92!R971U<FYE9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;V)J96-T+@H@("`@("H@("`@("`@("`@("`@(&1E8V]D95]B;V1I
M97,@("T@5VAE=&AE<B!T;R!D96-O9&4@=&AE(&)O9&EE<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@;V8@=&AE('!A<G1S+B`H5')A
M;G-F97(@96YC;V1I;F<I"B`@("`@*B`@("`@("`@("`@("`@9&5C;V1E7VAE
M861E<G,@+2!7:&5T:&5R('1O(&1E8V]D92!H96%D97)S"B`@("`@*B`@("`@
M("`@("`@("`@:6YP=70@("`@("`@("`@+2!)9B!C86QL960@<W1A=&EC86QL
M>2P@=&AI<R!W:6QL(&)E('1R96%T960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%S('1H92!I;G!U=`H@("`@("H@0')E='5R;B!O
M8FIE8W0@1&5C;V1E9"!R97-U;'1S"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!D96-O9&4H)'!A<F%M<R`](&YU;&PI"B`@
M("!["B`@("`@("`@+R\@9&5T97)M:6YE(&EF('1H:7,@;65T:&]D(&AA<R!B
M965N(&-A;&QE9"!S=&%T:6-A;&QY"B`@("`@("`@)&ES4W1A=&EC(#T@(2AI
M<W-E="@D=&AI<RD@)B8@9V5T7V-L87-S*"1T:&ES*2`]/2!?7T-,05-37U\I
M.PH*("`@("`@("`O+R!(879E('=E(&)E96X@8V%L;&5D('-T871I8V%L;'D_
M"@DO+R!)9B!S;RP@8W)E871E(&%N(&]B:F5C="!A;F0@<&%S<R!D971A:6QS
M('1O('1H870N"B`@("`@("`@:68@*"1I<U-T871I8R!!3D0@:7-S970H)'!A
M<F%M<ULG:6YP=70G72DI('L*"B`@("`@("`@("`@("1O8FH@/2!N97<@36%I
M;%]M:6UE1&5C;V1E*"1P87)A;7-;)VEN<'5T)UTI.PH@("`@("`@("`@("`D
M<W1R=6-T=7)E(#T@)&]B:BT^9&5C;V1E*"1P87)A;7,I.PH*("`@("`@("`O
M+R!#86QL960@<W1A=&EC86QL>2!B=70@;F\@:6YP=70*("`@("`@("!](&5L
M<V5I9B`H)&ES4W1A=&EC*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=#86QL960@<W1A=&EC86QL>2!A;F0@;F\@:6YP=70@9VEV
M96XG*3L*"B`@("`@("`@+R\@0V%L;&5D('9I82!A;B!O8FIE8W0*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7VEN8VQU9&5?8F]D:65S
M(#T@:7-S970H)'!A<F%M<ULG:6YC;'5D95]B;V1I97,G72D@/PH)("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R=I;F-L=61E7V)O9&EE
M<R==(#H@9F%L<V4["B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E7V)O9&EE
M<R`@/2!I<W-E="@D<&%R86US6R=D96-O9&5?8F]D:65S)UTI(#\*"2`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULG9&5C;V1E7V)O9&EE
M<R==("`Z(&9A;'-E.PH@("`@("`@("`@("`D=&AI<RT^7V1E8V]D95]H96%D
M97)S(#T@:7-S970H)'!A<F%M<ULG9&5C;V1E7VAE861E<G,G72D@/PH)("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R=D96-O9&5?:&5A
M9&5R<R==(#H@9F%L<V4["@H@("`@("`@("`@("`D<W1R=6-T=7)E(#T@)'1H
M:7,M/E]D96-O9&4H)'1H:7,M/E]H96%D97(L("1T:&ES+3Y?8F]D>2D["B`@
M("`@("`@("`@(&EF("@D<W1R=6-T=7)E(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)'-T<G5C='5R92`]("1T:&ES+3YR86ES945R<F]R*"1T:&ES
M+3Y?97)R;W(I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)'-T<G5C='5R93L*("`@('T*"B`@("`O*BH*("`@("`J(%!E<F9O
M<FUS('1H92!D96-O9&EN9RX@1&5C;V1E<R!T:&4@8F]D>2!S=')I;F<@<&%S
M<V5D('1O(&ET"B`@("`@*B!)9B!I="!F:6YD<R!C97)T86EN(&-O;G1E;G0M
M='EP97,@:70@=VEL;"!C86QL(&ET<V5L9B!I;B!A"B`@("`@*B!R96-U<G-I
M=F4@9F%S:&EO;@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@2&5A9&5R
M('-E8W1I;VX*("`@("`J($!P87)A;2!S=')I;F<@0F]D>2!S96-T:6]N"B`@
M("`@*B!`<F5T=7)N(&]B:F5C="!297-U;'1S(&]F(&1E8V]D:6YG('!R;V-E
M<W,*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!?9&5C;V1E*"1H96%D97)S+"`D8F]D>2P@)&1E9F%U;'1?8W1Y<&4@/2`G
M=&5X="]P;&%I;B<I"B`@("!["B`@("`@("`@)')E='5R;B`](&YE=R!S=&1#
M;&%S<SL*("`@("`@("`D<F5T=7)N+3YH96%D97)S(#T@87)R87DH*3L*("`@
M("`@("`D:&5A9&5R<R`]("1T:&ES+3Y?<&%R<V5(96%D97)S*"1H96%D97)S
M*3L*"B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)'9A;'5E*2!["B`@
M("`@("`@("`@(&EF("AI<W-E="@D<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W
M97(H)'9A;'5E6R=N86UE)UTI72D@04Y$("%I<U]A<G)A>2@D<F5T=7)N+3YH
M96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI72DI('L*("`@("`@
M("`@("`@("`@("1R971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;
M)VYA;64G72E=("`@/2!A<G)A>2@D<F5T=7)N+3YH96%D97)S6W-T<G1O;&]W
M97(H)'9A;'5E6R=N86UE)UTI72D["B`@("`@("`@("`@("`@("`D<F5T=7)N
M+3YH96%D97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI75M=(#T@)'9A
M;'5E6R=V86QU92==.PH*("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R
M971U<FXM/FAE861E<G-;<W1R=&]L;W=E<B@D=F%L=65;)VYA;64G72E=*2D@
M>PH@("`@("`@("`@("`@("`@)')E='5R;BT^:&5A9&5R<UMS=')T;VQO=V5R
M*"1V86QU95LG;F%M92==*5U;72`]("1V86QU95LG=F%L=64G73L*"B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5T=7)N+3YH96%D
M97)S6W-T<G1O;&]W97(H)'9A;'5E6R=N86UE)UTI72`]("1V86QU95LG=F%L
M=64G73L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5S970H
M)&AE861E<G,I.PH@("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V86QU92D@
M/2!E86-H*"1H96%D97)S*2D@>PH@("`@("`@("`@("`D:&5A9&5R<ULD:V5Y
M75LG;F%M92==(#T@<W1R=&]L;W=E<B@D:&5A9&5R<ULD:V5Y75LG;F%M92==
M*3L*("`@("`@("`@("`@<W=I=&-H("@D:&5A9&5R<ULD:V5Y75LG;F%M92==
M*2!["@H@("`@("`@("`@("`@("`@8V%S92`G8V]N=&5N="UT>7!E)SH*("`@
M("`@("`@("`@("`@("`@("`D8V]N=&5N=%]T>7!E(#T@)'1H:7,M/E]P87)S
M94AE861E<E9A;'5E*"1H96%D97)S6R1K97E=6R=V86QU92==*3L*"B`@("`@
M("`@("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H6S`M.6$M>BLN+5TK
M*5PO*%LP+3EA+7HK+BU=*RDO:2<L("1C;VYT96YT7W1Y<&5;)W9A;'5E)UTL
M("1R96=S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3YC
M='EP95]P<FEM87)Y("`@/2`D<F5G<ULQ73L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E='5R;BT^8W1Y<&5?<V5C;VYD87)Y(#T@)')E9W-;,ET["B`@
M("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&-O;G1E;G1?='EP95LG;W1H97(G72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@=VAI;&4@*&QI<W0H)'!?;F%M92P@)'!?=F%L=64I(#T@
M96%C:"@D8V]N=&5N=%]T>7!E6R=O=&AE<B==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E='5R;BT^8W1Y<&5?<&%R86UE=&5R<ULD<%]N
M86UE72`]("1P7W9A;'5E.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("`@("`@("`@(&-A<V4@)V-O;G1E;G0M9&ES<&]S:71I;VXG
M.@H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT7V1I<W!O<VET:6]N(#T@
M)'1H:7,M/E]P87)S94AE861E<E9A;'5E*"1H96%D97)S6R1K97E=6R=V86QU
M92==*3L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3YD:7-P;W-I=&EO
M;B`@(#T@)&-O;G1E;G1?9&ES<&]S:71I;VY;)W9A;'5E)UT["B`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1C;VYT96YT7V1I<W!O<VET:6]N6R=O
M=&AE<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!W:&EL92`H;&ES
M="@D<%]N86UE+"`D<%]V86QU92D@/2!E86-H*"1C;VYT96YT7V1I<W!O<VET
M:6]N6R=O=&AE<B==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')E='5R;BT^9%]P87)A;65T97)S6R1P7VYA;65=(#T@)'!?=F%L=64["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G8V]N=&5N="UT<F%N<V9E<BUE;F-O9&EN9R<Z"B`@("`@("`@("`@
M("`@("`@("`@)&-O;G1E;G1?=')A;G-F97)?96YC;V1I;F<@/2`D=&AI<RT^
M7W!A<G-E2&5A9&5R5F%L=64H)&AE861E<G-;)&ME>5U;)W9A;'5E)UTI.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O;G1E;G1?='EP92DI('L*("`@
M("`@("`@("`@<W=I=&-H("AS=')T;VQO=V5R*"1C;VYT96YT7W1Y<&5;)W9A
M;'5E)UTI*2!["B`@("`@("`@("`@("`@("!C87-E("=T97AT+W!L86EN)SH*
M("`@("`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!I<W-E="@D8V]N=&5N
M=%]T<F%N<V9E<E]E;F-O9&EN9RD@/R`D8V]N=&5N=%]T<F%N<V9E<E]E;F-O
M9&EN9ULG=F%L=64G72`Z("<W8FET)SL*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7VEN8VQU9&5?8F]D:65S(#\@)')E='5R;BT^8F]D>2`]("@D=&AI
M<RT^7V1E8V]D95]B;V1I97,@/R`D=&AI<RT^7V1E8V]D94)O9'DH)&)O9'DL
M("1E;F-O9&EN9RD@.B`D8F]D>2D@.B!N=6QL.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)W1E>'0O:'1M;"<Z
M"B`@("`@("`@("`@("`@("`@("`@)&5N8V]D:6YG(#T@:7-S970H)&-O;G1E
M;G1?=')A;G-F97)?96YC;V1I;F<I(#\@)&-O;G1E;G1?=')A;G-F97)?96YC
M;V1I;F=;)W9A;'5E)UT@.B`G-V)I="<["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;F-L=61E7V)O9&EE<R`_("1R971U<FXM/F)O9'D@/2`H)'1H
M:7,M/E]D96-O9&5?8F]D:65S(#\@)'1H:7,M/E]D96-O9&5";V1Y*"1B;V1Y
M+"`D96YC;V1I;F<I(#H@)&)O9'DI(#H@;G5L;#L*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G0O
M<&%R86QL96PG.@H@("`@("`@("`@("`@("`@8V%S92`G;75L=&EP87)T+W)E
M<&]R="<Z("\O(%)&0S$X.3(*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I
M<&%R="]S:6=N960G.B`O+R!01U`*("`@("`@("`@("`@("`@(&-A<V4@)VUU
M;'1I<&%R="]D:6=E<W0G.@H@("`@("`@("`@("`@("`@8V%S92`G;75L=&EP
M87)T+V%L=&5R;F%T:79E)SH*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I
M<&%R="]R96QA=&5D)SH*("`@("`@("`@("`@("`@(&-A<V4@)VUU;'1I<&%R
M="]M:7AE9"<Z"B`@("`@("`@("`@("`@("`@("`@:68H(6ES<V5T*"1C;VYT
M96YT7W1Y<&5;)V]T:&5R)UU;)V)O=6YD87)Y)UTI*7L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B`]("=.;R!B;W5N9&%R>2!F;W5N
M9"!F;W(@)R`N("1C;VYT96YT7W1Y<&5;)W9A;'5E)UT@+B`G('!A<G0G.PH@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("`@("`D9&5F875L=%]C
M='EP92`]("AS=')T;VQO=V5R*"1C;VYT96YT7W1Y<&5;)W9A;'5E)UTI(#T]
M/2`G;75L=&EP87)T+V1I9V5S="<I(#\@)VUE<W-A9V4O<F9C.#(R)R`Z("=T
M97AT+W!L86EN)SL*"B`@("`@("`@("`@("`@("`@("`@)'!A<G1S(#T@)'1H
M:7,M/E]B;W5N9&%R>5-P;&ET*"1B;V1Y+"`D8V]N=&5N=%]T>7!E6R=O=&AE
M<B==6R=B;W5N9&%R>2==*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D<&%R=',I.R`D:2LK*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&QI<W0H)'!A<G1?:&5A9&5R+"`D<&%R=%]B;V1Y*2`]
M("1T:&ES+3Y?<W!L:71";V1Y2&5A9&5R*"1P87)T<ULD:5TI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R="`]("1T:&ES+3Y?9&5C;V1E*"1P87)T
M7VAE861E<BP@)'!A<G1?8F]D>2P@)&1E9F%U;'1?8W1Y<&4I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B@D<&%R="`]/3T@9F%L<V4I"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R="`]("1T:&ES+3YR86ES945R<F]R
M*"1T:&ES+3Y?97)R;W(I.PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T
M=7)N+3YP87)T<UM=(#T@)'!A<G0["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A
M<V4@)VUE<W-A9V4O<F9C.#(R)SH*("`@("`@("`@("`@("`@("`@("`D;V)J
M(#T@)FYE=R!-86EL7VUI;65$96-O9&4H)&)O9'DI.PH@("`@("`@("`@("`@
M("`@("`@("1R971U<FXM/G!A<G1S6UT@/2`D;V)J+3YD96-O9&4H87)R87DH
M)VEN8VQU9&5?8F]D:65S)R`]/B`D=&AI<RT^7VEN8VQU9&5?8F]D:65S+`H)
M"0D)"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V1E
M8V]D95]B;V1I97,G("`]/B`D=&AI<RT^7V1E8V]D95]B;V1I97,L"@D)"0D)
M"0D)"0D)"0D)("`G9&5C;V1E7VAE861E<G,G(#T^("1T:&ES+3Y?9&5C;V1E
M7VAE861E<G,I*3L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D;V)J*3L*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@(&EF*"%I<W-E="@D8V]N=&5N
M=%]T<F%N<V9E<E]E;F-O9&EN9ULG=F%L=64G72DI"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT7W1R86YS9F5R7V5N8V]D:6YG6R=V86QU92==
M(#T@)S=B:70G.PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YC;'5D
M95]B;V1I97,@/R`D<F5T=7)N+3YB;V1Y(#T@*"1T:&ES+3Y?9&5C;V1E7V)O
M9&EE<R`_("1T:&ES+3Y?9&5C;V1E0F]D>2@D8F]D>2P@)&-O;G1E;G1?=')A
M;G-F97)?96YC;V1I;F=;)W9A;'5E)UTI(#H@)&)O9'DI(#H@;G5L;#L*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D8W1Y<&4@/2!E>'!L;V1E*"<O)RP@
M)&1E9F%U;'1?8W1Y<&4I.PH@("`@("`@("`@("`D<F5T=7)N+3YC='EP95]P
M<FEM87)Y("`@/2`D8W1Y<&5;,%T["B`@("`@("`@("`@("1R971U<FXM/F-T
M>7!E7W-E8V]N9&%R>2`]("1C='EP95LQ73L*("`@("`@("`@("`@)'1H:7,M
M/E]I;F-L=61E7V)O9&EE<R`_("1R971U<FXM/F)O9'D@/2`H)'1H:7,M/E]D
M96-O9&5?8F]D:65S(#\@)'1H:7,M/E]D96-O9&5";V1Y*"1B;V1Y*2`Z("1B
M;V1Y*2`Z(&YU;&P["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E='5R
M;CL*("`@('T*"B`@("`O*BH*("`@("`J($=I=F5N('1H92!O=71P=70@;V8@
M=&AE(&%B;W9E(&9U;F-T:6]N+"!T:&ES('=I;&P@<F5T=7)N(&%N"B`@("`@
M*B!A<G)A>2!O9B!R969E<F5N8V5S('1O('1H92!P87)T<RP@:6YD97AE9"!B
M>2!M:6UE(&YU;6)E<BX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="`D
M<W1R=6-T=7)E("`@5&AE('-T<G5C='5R92!T;R!G;R!T:')O=6=H"B`@("`@
M*B!`<&%R86T@('-T<FEN9R`D;6EM95]N=6UB97(@26YT97)N86P@=7-E(&]N
M;'DN"B`@("`@*B!`<F5T=7)N(&%R<F%Y("`@("`@("`@("`@("`@36EM92!N
M=6UB97)S"B`@("`@*B\*("`@(&9U;F-T:6]N("9G971-:6UE3G5M8F5R<R@F
M)'-T<G5C='5R92P@)&YO7W)E9G,@/2!F86QS92P@)&UI;65?;G5M8F5R(#T@
M)R<L("1P<F5P96YD(#T@)R<I"B`@("!["B`@("`@("`@)')E='5R;B`](&%R
M<F%Y*"D["B`@("`@("`@:68@*"%E;7!T>2@D<W1R=6-T=7)E+3YP87)T<RDI
M('L*("`@("`@("`@("`@:68@*"1M:6UE7VYU;6)E<B`A/2`G)RD@>PH@("`@
M("`@("`@("`@("`@)'-T<G5C='5R92T^;6EM95]I9"`]("1P<F5P96YD("X@
M)&UI;65?;G5M8F5R.PH@("`@("`@("`@("`@("`@)')E='5R;ELD<')E<&5N
M9"`N("1M:6UE7VYU;6)E<ET@/2`F)'-T<G5C='5R93L*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<W1R=6-T
M=7)E+3YP87)T<RD[("1I*RLI('L*"B`@("`@("`@("`@(`H@("`@("`@("`@
M("`@("`@:68@*"%E;7!T>2@D<W1R=6-T=7)E+3YH96%D97)S6R=C;VYT96YT
M+71Y<&4G72D@04Y$('-U8G-T<BAS=')T;VQO=V5R*"1S=')U8W1U<F4M/FAE
M861E<G-;)V-O;G1E;G0M='EP92==*2P@,"P@."D@/3T@)VUE<W-A9V4O)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1P<F5P96YD("`@("`@/2`D<')E<&5N
M9"`N("1M:6UE7VYU;6)E<B`N("<N)SL*("`@("`@("`@("`@("`@("`@("`D
M7VUI;65?;G5M8F5R(#T@)R<["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1?;6EM95]N=6UB97(@/2`H)&UI;65?;G5M
M8F5R(#T]("<G(#\@)&D@*R`Q(#H@<W!R:6YT9B@G)7,N)7,G+"`D;6EM95]N
M=6UB97(L("1I("L@,2DI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1A<G(@/2`F36%I;%]M:6UE1&5C;V1E.CIG971-:6UE3G5M8F5R
M<R@D<W1R=6-T=7)E+3YP87)T<ULD:5TL("1N;U]R969S+"`D7VUI;65?;G5M
M8F5R+"`D<')E<&5N9"D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D87)R
M(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1N;U]R
M969S(#\@)')E='5R;ELD:V5Y72`]("<G(#H@)')E='5R;ELD:V5Y72`]("8D
M87)R6R1K97E=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1M:6UE7VYU;6)E<B`]
M/2`G)RD@>PH@("`@("`@("`@("`@("`@)&UI;65?;G5M8F5R(#T@)S$G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1S=')U8W1U<F4M/FUI;65?:60@
M/2`D<')E<&5N9"`N("1M:6UE7VYU;6)E<CL*("`@("`@("`@("`@)&YO7W)E
M9G,@/R`D<F5T=7)N6R1P<F5P96YD("X@)&UI;65?;G5M8F5R72`]("<G(#H@
M)')E='5R;ELD<')E<&5N9"`N("1M:6UE7VYU;6)E<ET@/2`F)'-T<G5C='5R
M93L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1R971U<FX[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!':79E;B!A('-T<FEN9R!C;VYT86EN
M:6YG(&$@:&5A9&5R(&%N9"!B;V1Y"B`@("`@*B!S96-T:6]N+"!T:&ES(&9U
M;F-T:6]N('=I;&P@<W!L:70@=&AE;2`H870@=&AE(&9I<G-T"B`@("`@*B!B
M;&%N:R!L:6YE*2!A;F0@<F5T=7)N('1H96TN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!);G!U="!T;R!S<&QI="!A<&%R=`H@("`@("H@0')E='5R
M;B!A<G)A>2!#;VYT86EN<R!H96%D97(@86YD(&)O9'D@<V5C=&EO;@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S<&QI
M=$)O9'E(96%D97(H)&EN<'5T*0H@("`@>PH@("`@("`@(&EF("AP<F5G7VUA
M=&-H*"(O7B@N*C\I7'(_7&Y<<C]<;B@N*BDO<R(L("1I;G!U="P@)&UA=&-H
M*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH)&UA=&-H6S%=+"`D;6%T
M8VA;,ETI.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7V5R<F]R(#T@)T-O
M=6QD(&YO="!S<&QI="!H96%D97(@86YD(&)O9'DG.PH@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E(&AE861E<G,@
M9VEV96X@:6X@)&EN<'5T(&%N9"!R971U<FX*("`@("`J(&%S(&%S<V]C(&%R
M<F%Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@2&5A9&5R<R!T;R!P
M87)S90H@("`@("H@0')E='5R;B!A<G)A>2!#;VYT86EN<R!P87)S960@:&5A
M9&5R<PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(%]P87)S94AE861E<G,H)&EN<'5T*0H@("`@>PH*("`@("`@("!I9B`H
M)&EN<'5T("$]/2`G)RD@>PH@("`@("`@("`@("`O+R!5;F9O;&0@=&AE(&EN
M<'5T"B`@("`@("`@("`@("1I;G!U="`@(#T@<')E9U]R97!L86-E*"(O7'(_
M7&XO(BP@(EQR7&XB+"`D:6YP=70I.PH@("`@("`@("`@("`D:6YP=70@("`]
M('!R96=?<F5P;&%C92@B+UQR7&XH7'1\("DK+R(L("<@)RP@)&EN<'5T*3L*
M("`@("`@("`@("`@)&AE861E<G,@/2!E>'!L;V1E*")<<EQN(BP@=')I;2@D
M:6YP=70I*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*"1H96%D97)S(&%S("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@)&AD<E]N86UE(#T@<W5B<W1R*"1V
M86QU92P@,"P@)'!O<R`]('-T<G!O<R@D=F%L=64L("<Z)RDI.PH@("`@("`@
M("`@("`@("`@)&AD<E]V86QU92`]('-U8G-T<B@D=F%L=64L("1P;W,K,2D[
M"B`@("`@("`@("`@("`@("!I9B@D:&1R7W9A;'5E6S!=(#T]("<@)RD*("`@
M("`@("`@("`@("`@("`@("`D:&1R7W9A;'5E(#T@<W5B<W1R*"1H9')?=F%L
M=64L(#$I.PH*("`@("`@("`@("`@("`@("1R971U<FY;72`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D
M:&1R7VYA;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%L=64G(#T^("1T:&ES+3Y?9&5C;V1E7VAE861E<G,@/R`D=&AI<RT^7V1E
M8V]D94AE861E<B@D:&1R7W9A;'5E*2`Z("1H9')?=F%L=64*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R971U<FX@/2!A<G)A>2@I.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!P87)S92!A(&AE861E<B!V86QU92P*
M("`@("`J(&5X=')A8W0@9FER<W0@<&%R="P@86YD(&%N>2!S96-O;F1A<GD*
M("`@("`J('!A<G1S("AA9G1E<B`[*2!4:&ES(&9U;F-T:6]N(&ES(&YO="!A
M<PH@("`@("H@<F]B=7-T(&%S(&ET(&-O=6QD(&)E+B!%9RX@:&5A9&5R(&-O
M;6UE;G1S"B`@("`@*B!I;B!T:&4@=W)O;F<@<&QA8V4@=VEL;"!P<F]B86)L
M>2!B<F5A:R!I="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG($AE861E
M<B!V86QU92!T;R!P87)S90H@("`@("H@0')E='5R;B!A<G)A>2!#;VYT86EN
M<R!P87)S960@<F5S=6QT"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@7W!A<G-E2&5A9&5R5F%L=64H)&EN<'5T*0H@("`@
M>PH*("`@("`@("!I9B`H*"1P;W,@/2!S=')P;W,H)&EN<'5T+"`G.R<I*2`A
M/3T@9F%L<V4I('L*"B`@("`@("`@("`@("1R971U<FY;)W9A;'5E)UT@/2!T
M<FEM*'-U8G-T<B@D:6YP=70L(#`L("1P;W,I*3L*("`@("`@("`@("`@)&EN
M<'5T(#T@=')I;2AS=6)S='(H)&EN<'5T+"`D<&]S*S$I*3L*"B`@("`@("`@
M("`@(&EF("AS=')L96XH)&EN<'5T*2`^(#`I('L*"B`@("`@("`@("`@("`@
M("`O+R!4:&ES('-P;&ET<R!O;B!A('-E;6DM8V]L;VXL(&EF('1H97)E)W,@
M;F\@<')E8V5E9&EN9R!B86-K<VQA<V@*("`@("`@("`@("`@("`@("\O($YO
M=R!W;W)K<R!W:71H('%U;W1E9"!V86QU97,[(&AA9"!T;R!G;'5E('1H92!<
M.R!B<F5A:W,@:6X@4$A0"B`@("`@("`@("`@("`@("`O+R!T:&4@<F5G97@@
M:7,@86QR96%D>2!B;W)D97)I;F<@;VX@:6YC;VUP<F5H96YS:6)L90H@("`@
M("`@("`@("`@("`@)'-P;&ET4F5G97@@/2`G+RA;7CM<)R)=*EM<)R)=*%M>
M7"<B72HH6UY<)R)=*BDJ*5M<)R)=6UX[7"<B72I\*%M>.UTK*2DH.WPD*2\G
M.PH@("`@("`@("`@("`@("`@<')E9U]M871C:%]A;&PH)'-P;&ET4F5G97@L
M("1I;G!U="P@)&UA=&-H97,I.PH@("`@("`@("`@("`@("`@)'!A<F%M971E
M<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@9F]R("@D:3TP.R`D:3QC
M;W5N="@D;6%T8VAE<ULP72D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@
M("`D<&%R86T@/2`D;6%T8VAE<ULP75LD:5T["B`@("`@("`@("`@("`@("`@
M("`@=VAI;&4@*'-U8G-T<B@D<&%R86TL("TR*2`]/2`G7#LG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)A;2`N/2`D;6%T8VAE<ULP75LK*R1I
M73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M971E<G-;72`]("1P87)A;3L*("`@("`@("`@("`@("`@('T*"B`@
M("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<&%R86UE
M=&5R<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D<&%R86U?;F%M
M92`@/2!T<FEM*'-U8G-T<B@D<&%R86UE=&5R<ULD:5TL(#`L("1P;W,@/2!S
M=')P;W,H)'!A<F%M971E<G-;)&E=+"`G/2<I*2P@(B=<(CM<=%Q<("(I.PH@
M("`@("`@("`@("`@("`@("`@("1P87)A;5]V86QU92`]('1R:6TH<W1R7W)E
M<&QA8V4H)UP[)RP@)SLG+"!S=6)S='(H)'!A<F%M971E<G-;)&E=+"`D<&]S
M("L@,2DI+"`B)UPB.UQT7%P@(BD["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1P87)A;5]V86QU95LP72`]/2`G(B<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M7W9A;'5E(#T@<W5B<W1R*"1P87)A;5]V86QU92P@,2P@
M+3$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N6R=O=&AE<B==6R1P87)A;5]N86UE72`]("1P87)A;5]V86QU
M93L*("`@("`@("`@("`@("`@("`@("`D<F5T=7)N6R=O=&AE<B==6W-T<G1O
M;&]W97(H)'!A<F%M7VYA;64I72`]("1P87)A;5]V86QU93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R971U<FY;)W9A;'5E)UT@/2!T<FEM*"1I;G!U="D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)')E='5R;CL*("`@('T*"B`@("`O*BH*
M("`@("`J(%1H:7,@9G5N8W1I;VX@<W!L:71S('1H92!I;G!U="!B87-E9`H@
M("`@("H@;VX@=&AE(&=I=F5N(&)O=6YD87)Y"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R!);G!U="!T;R!P87)S90H@("`@("H@0')E='5R;B!A<G)A
M>2!#;VYT86EN<R!A<G)A>2!O9B!R97-U;'1I;F<@;6EM92!P87)T<PH@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]B;W5N
M9&%R>5-P;&ET*"1I;G!U="P@)&)O=6YD87)Y*0H@("`@>PH@("`@("`@("1P
M87)T<R`](&%R<F%Y*"D["@H@("`@("`@("1B<U]P;W-S:6)L92`]('-U8G-T
M<B@D8F]U;F1A<GDL(#(L("TR*3L*("`@("`@("`D8G-?8VAE8VL@/2`G7"(G
M("X@)&)S7W!O<W-I8FQE("X@)UPB)SL*"B`@("`@("`@:68@*"1B;W5N9&%R
M>2`]/2`D8G-?8VAE8VLI('L*("`@("`@("`@("`@)&)O=6YD87)Y(#T@)&)S
M7W!O<W-I8FQE.PH@("`@("`@('T*"B`@("`@("`@)'1M<"`](&5X<&QO9&4H
M)RTM)R`N("1B;W5N9&%R>2P@)&EN<'5T*3L*"B`@("`@("`@9F]R("@D:2`]
M(#$[("1I(#P@8V]U;G0H)'1M<"D@+2`Q.R`D:2LK*2!["B`@("`@("`@("`@
M("1P87)T<UM=(#T@)'1M<%LD:5T["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@)'!A<G1S.PH@("`@?0H*("`@("\J*@H@("`@("H@1VEV96X@82!H96%D
M97(L('1H:7,@9G5N8W1I;VX@=VEL;"!D96-O9&4@:70*("`@("`J(&%C8V]R
M9&EN9R!T;R!21D,R,#0W+B!0<F]B86)L>2!N;W0@*F5X86-T;'DJ"B`@("`@
M*B!C;VYF;W)M86YT+"!B=70@:70@9&]E<R!P87-S(&%L;"!T:&4@9VEV96X*
M("`@("`J(&5X86UP;&5S("AI;B!21D,R,#0W*2X*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG($EN<'5T(&AE861E<B!V86QU92!T;R!D96-O9&4*("`@
M("`J($!R971U<FX@<W1R:6YG($1E8V]D960@:&5A9&5R('9A;'5E"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8V]D
M94AE861E<B@D:6YP=70I"B`@("!["B`@("`@("`@+R\@4F5M;W9E('=H:71E
M('-P86-E(&)E='=E96X@96YC;V1E9"UW;W)D<PH@("`@("`@("1I;G!U="`]
M('!R96=?<F5P;&%C92@G+R@]7#];7C]=*UP_*'%\8BE</UM>/UTJ7#\]*2A<
M<RDK/5P_+VDG+"`G7#$]/R<L("1I;G!U="D["@H@("`@("`@("\O($9O<B!E
M86-H(&5N8V]D960M=V]R9"XN+@H@("`@("`@('=H:6QE("AP<F5G7VUA=&-H
M*"<O*#U</RA;7C]=*RE</RAQ?&(I7#\H6UX_72HI7#\]*2]I)RP@)&EN<'5T
M+"`D;6%T8VAE<RDI('L*"B`@("`@("`@("`@("1E;F-O9&5D("`]("1M871C
M:&5S6S%=.PH@("`@("`@("`@("`D8VAA<G-E="`@/2`D;6%T8VAE<ULR73L*
M("`@("`@("`@("`@)&5N8V]D:6YG(#T@)&UA=&-H97-;,UT["B`@("`@("`@
M("`@("1T97AT("`@("`]("1M871C:&5S6S1=.PH*("`@("`@("`@("`@<W=I
M=&-H("AS=')T;VQO=V5R*"1E;F-O9&EN9RDI('L*("`@("`@("`@("`@("`@
M(&-A<V4@)V(G.@H@("`@("`@("`@("`@("`@("`@("1T97AT(#T@8F%S938T
M7V1E8V]D92@D=&5X="D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G<2<Z"B`@("`@("`@("`@("`@("`@("`@
M)'1E>'0@/2!S=')?<F5P;&%C92@G7R<L("<@)RP@)'1E>'0I.PH@("`@("`@
M("`@("`@("`@("`@('!R96=?;6%T8VA?86QL*"<O/2A;82UF,"TY77LR?2DO
M:2<L("1T97AT+"`D;6%T8VAE<RD["B`@("`@("`@("`@("`@("`@("`@9F]R
M96%C:"@D;6%T8VAE<ULQ72!A<R`D=F%L=64I"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T97AT(#T@<W1R7W)E<&QA8V4H)STG+B1V86QU92P@8VAR*&AE
M>&1E8R@D=F%L=64I*2P@)'1E>'0I.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D:6YP=70@/2!S=')?
M<F5P;&%C92@D96YC;V1E9"P@)'1E>'0L("1I;G!U="D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)&EN<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1VEV96X@82!B;V1Y('-T<FEN9R!A;F0@86X@96YC;V1I;F<@='EP92P*("`@
M("`J('1H:7,@9G5N8W1I;VX@=VEL;"!D96-O9&4@86YD(')E='5R;B!I="X*
M("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R!);G!U="!B;V1Y('1O(&1E
M8V]D90H@("`@("H@0'!A<F%M("!S=')I;F<@16YC;V1I;F<@='EP92!T;R!U
M<V4N"B`@("`@*B!`<F5T=7)N('-T<FEN9R!$96-O9&5D(&)O9'D*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?9&5C;V1E
M0F]D>2@D:6YP=70L("1E;F-O9&EN9R`]("<W8FET)RD*("`@('L*("`@("`@
M("!S=VET8V@@*'-T<G1O;&]W97(H)&5N8V]D:6YG*2D@>PH@("`@("`@("`@
M("!C87-E("<W8FET)SH*("`@("`@("`@("`@("`@(')E='5R;B`D:6YP=70[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)W%U
M;W1E9"UP<FEN=&%B;&4G.@H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<75O=&5D4')I;G1A8FQE1&5C;V1E*"1I;G!U="D["B`@("`@("`@("`@
M("`@("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V)A<V4V-"<Z"B`@("`@
M("`@("`@("`@("!R971U<FX@8F%S938T7V1E8V]D92@D:6YP=70I.PH@("`@
M("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("1I;G!U=#L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!':79E;B!A('%U;W1E9"UP<FEN=&%B;&4@<W1R:6YG
M+"!T:&ES"B`@("`@*B!F=6YC=&EO;B!W:6QL(&1E8V]D92!A;F0@<F5T=7)N
M(&ET+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG($EN<'5T(&)O9'D@
M=&\@9&5C;V1E"B`@("`@*B!`<F5T=7)N('-T<FEN9R!$96-O9&5D(&)O9'D*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<75O=&5D4')I;G1A8FQE1&5C;V1E*"1I;G!U="D*("`@('L*("`@("`@("`O
M+R!296UO=F4@<V]F="!L:6YE(&)R96%K<PH@("`@("`@("1I;G!U="`]('!R
M96=?<F5P;&%C92@B+SU<<C]<;B\B+"`G)RP@)&EN<'5T*3L*"B`@("`@("`@
M+R\@4F5P;&%C92!E;F-O9&5D(&-H87)A8W1E<G,*"0DD:6YP=70@/2!P<F5G
M7W)E<&QA8V4H)R\]*%MA+68P+3E=>S)]*2]I92<L(")C:'(H:&5X9&5C*"=<
M7#$G*2DB+"`D:6YP=70I.PH*("`@("`@("!R971U<FX@)&EN<'5T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!I;G!U="!F;W(@=75E;F-O
M9&5D(&9I;&5S(&%N9"!R971U<FYS"B`@("`@*B!A;B!A<G)A>2!O9B!T:&5M
M+B!#86X@8F4@8V%L;&5D('-T871I8V%L;'DL(&5G.@H@("`@("H*("`@("`J
M("1F:6QE<R`])B!-86EL7VUI;65$96-O9&4Z.G5U9&5C;V1E*"1S;VUE7W1E
M>'0I.PH@("`@("H*("`@("`J($ET('=I;&P@8VAE8VL@9F]R('1H92!B96=I
M;B`V-C8@+BXN(&5N9"!S>6YT87@*("`@("`J(&AO=V5V97(@86YD('=O;B=T
M(&IU<W0@8FQI;F1L>2!D96-O9&4@=VAA=&5V97(@>6]U"B`@("`@*B!P87-S
M(&ET+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG($EN<'5T(&)O9'D@
M=&\@;&]O:R!F;W(@871T86AC;65N=',@:6X*("`@("`J($!R971U<FX@87)R
M87D@($1E8V]D960@8F]D:65S+"!F:6QE;F%M97,@86YD('!E<FUI<W-I;VYS
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%U=&AO<B!5;FMN;W=N
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9U=61E8V]D92@D:6YP=70I"B`@("![
M"B`@("`@("`@+R\@1FEN9"!A;&P@=75E;F-O9&5D('-E8W1I;VYS"B`@("`@
M("`@<')E9U]M871C:%]A;&PH(B]B96=I;B`H6S`M-UU[,WTI("@N*RE<<C]<
M;B@N*RE<<C]<;F5N9"]5<R(L("1I;G!U="P@)&UA=&-H97,I.PH*("`@("`@
M("!F;W(@*"1J(#T@,#L@)&H@/"!C;W5N="@D;6%T8VAE<ULS72D[("1J*RLI
M('L*"B`@("`@("`@("`@("1S='(@("`@("`]("1M871C:&5S6S-=6R1J73L*
M("`@("`@("`@("`@)&9I;&5N86UE(#T@)&UA=&-H97-;,EU;)&I=.PH@("`@
M("`@("`@("`D9FEL97!E<FT@/2`D;6%T8VAE<ULQ75LD:ET["@H@("`@("`@
M("`@("`D9FEL92`]("<G.PH@("`@("`@("`@("`D<W1R(#T@<')E9U]S<&QI
M="@B+UQR/UQN+R(L('1R:6TH)'-T<BDI.PH@("`@("`@("`@("`D<W1R;&5N
M(#T@8V]U;G0H)'-T<BD["@H@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D<W1R;&5N.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D<&]S(#T@,3L*
M("`@("`@("`@("`@("`@("1D(#T@,#L*("`@("`@("`@("`@("`@("1L96X]
M*&EN="DH*"AO<F0H<W5B<W1R*"1S=');)&E=+#`L,2DI("TS,BD@+2`G("<I
M("8@,#<W*3L*"B`@("`@("`@("`@("`@("!W:&EL92`H*"1D("L@,R`\/2`D
M;&5N*2!!3D0@*"1P;W,@*R`T(#P]('-T<FQE;B@D<W1R6R1I72DI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&,P(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL
M)'!O<RPQ*2D@7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@("`D8S$@/2`H
M;W)D*'-U8G-T<B@D<W1R6R1I72PD<&]S*S$L,2DI(%X@,'@R,"D["B`@("`@
M("`@("`@("`@("`@("`@)&,R(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O
M<RLR+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@("`@("`@("1C,R`]("AO
M<F0H<W5B<W1R*"1S=');)&E=+"1P;W,K,RPQ*2D@7B`P>#(P*3L*("`@("`@
M("`@("`@("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,P("T@)R`G*2`F(#`W
M-RD@/#P@,BD@?"`H*"@D8S$@+2`G("<I("8@,#<W*2`^/B`T*2D["@H@("`@
M("`@("`@("`@("`@("`@("1F:6QE("X](&-H<B@H*"@D8S$@+2`G("<I("8@
M,#<W*2`\/"`T*2!\("@H*"1C,B`M("<@)RD@)B`P-S<I(#X^(#(I*3L*"B`@
M("`@("`@("`@("`@("`@("`@)&9I;&4@+CT@8VAR*"@H*"1C,B`M("<@)RD@
M)B`P-S<I(#P\(#8I('P@("@H)&,S("T@)R`G*2`F(#`W-RDI.PH*("`@("`@
M("`@("`@("`@("`@("`D<&]S("L](#0["B`@("`@("`@("`@("`@("`@("`@
M)&0@*ST@,SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I
M9B`H*"1D("L@,B`\/2`D;&5N*2`F)B`H)'!O<R`K(#,@/#T@<W1R;&5N*"1S
M=');)&E=*2DI('L*("`@("`@("`@("`@("`@("`@("`D8S`@/2`H;W)D*'-U
M8G-T<B@D<W1R6R1I72PD<&]S+#$I*2!>(#!X,C`I.PH@("`@("`@("`@("`@
M("`@("`@("1C,2`]("AO<F0H<W5B<W1R*"1S=');)&E=+"1P;W,K,2PQ*2D@
M7B`P>#(P*3L*("`@("`@("`@("`@("`@("`@("`D8S(@/2`H;W)D*'-U8G-T
M<B@D<W1R6R1I72PD<&]S*S(L,2DI(%X@,'@R,"D["B`@("`@("`@("`@("`@
M("`@("`@)&9I;&4@+CT@8VAR*"@H*"1C,"`M("<@)RD@)B`P-S<I(#P\(#(I
M('P@*"@H)&,Q("T@)R`G*2`F(#`W-RD@/CX@-"DI.PH*("`@("`@("`@("`@
M("`@("`@("`D9FEL92`N/2!C:'(H*"@H)&,Q("T@)R`G*2`F(#`W-RD@/#P@
M-"D@?"`H*"@D8S(@+2`G("<I("8@,#<W*2`^/B`R*2D["@H@("`@("`@("`@
M("`@("`@("`@("1P;W,@*ST@,SL*("`@("`@("`@("`@("`@("`@("`D9"`K
M/2`R.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("@H
M)&0@*R`Q(#P]("1L96XI("8F("@D<&]S("L@,B`\/2!S=')L96XH)'-T<ELD
M:5TI*2D@>PH@("`@("`@("`@("`@("`@("`@("1C,"`]("AO<F0H<W5B<W1R
M*"1S=');)&E=+"1P;W,L,2DI(%X@,'@R,"D["B`@("`@("`@("`@("`@("`@
M("`@)&,Q(#T@*&]R9"AS=6)S='(H)'-T<ELD:5TL)'!O<RLQ+#$I*2!>(#!X
M,C`I.PH@("`@("`@("`@("`@("`@("`@("1F:6QE("X](&-H<B@H*"@D8S`@
M+2`G("<I("8@,#<W*2`\/"`R*2!\("@H*"1C,2`M("<@)RD@)B`P-S<I(#X^
M(#0I*3L*"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&9I;&5S6UT@/2!A<G)A>2@G9FEL96YA;64G(#T^("1F:6QE;F%M
M92P@)V9I;&5P97)M)R`]/B`D9FEL97!E<FTL("=F:6QE9&%T82<@/3X@)&9I
M;&4I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@('T*
M"B`@("`O*BH*("`@("`J(&=E=%-E;F1!<G)A>2@I(')E='5R;G,@=&AE(&%R
M9W5M96YT<R!R97%U:7)E9"!F;W(@36%I;#HZ<V5N9"@I"B`@("`@*B!U<V5D
M('1O(&)U:6QD('1H92!A<F=U;65N=',@9F]R(&$@;6%I;#HZ<V5N9"@I(&-A
M;&P@"B`@("`@*@H@("`@("H@57-A9V4Z"B`@("`@*B`D;6%I;'1E>'0@/2!&
M=6QL(&5M86EL("AF;W(@97AA;7!L92!G96YE<F%T960@8GD@82!T96UP;&%T
M92D*("`@("`J("1D96-O9&5R(#T@;F5W($UA:6Q?;6EM941E8V]D92@D;6%I
M;'1E>'0I.PH@("`@("H@)'!A<G1S(#T@("1D96-O9&5R+3YG971396YD07)R
M87DH*3L*("`@("`J(&EF("@A4$5!4CHZ:7-%<G)O<B@D<&%R=',I('L*("`@
M("`J("`@("!L:7-T*"1R96-I<&5N=',L)&AE861E<G,L)&)O9'DI(#T@)'!A
M<G1S.PH@("`@("H@("`@("1M86EL(#T@36%I;#HZ9F%C=&]R>2@G<VUT<"<I
M.PH@("`@("H@("`@("1M86EL+3YS96YD*"1R96-I<&5N=',L)&AE861E<G,L
M)&)O9'DI.PH@("`@("H@?2!E;'-E('L*("`@("`J("`@("!E8VAO("1P87)T
M<RT^;65S<V%G93L*("`@("`J('T*("`@("`J($!R971U<FX@;6EX960@("!A
M<G)A>2!O9B!R96-I<&5I;G0L(&AE861E<G,L8F]D>2!O<B!096%R7T5R<F]R
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%U=&AO<B!!;&%N($MN
M;W=L97,@/&%L86Y`86MB:VAO;64N8V]M/@H@("`@("HO"B`@("!F=6YC=&EO
M;B!G971396YD07)R87DH*0H@("`@>PH@("`@("`@("\O('!R979E;G0@=V%R
M;FEN9R!I9B!T:&ES(&ES(&YO="!S970*("`@("`@("`D=&AI<RT^7V1E8V]D
M95]H96%D97)S(#T@1D%,4T4["B`@("`@("`@)&AE861E<FQI<W0@/21T:&ES
M+3Y?<&%R<V5(96%D97)S*"1T:&ES+3Y?:&5A9&5R*3L*("`@("`@("`D=&\@
M/2`B(CL*("`@("`@("!I9B`H(21H96%D97)L:7-T*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B365S<V%G92!D:60@;F]T(&-O
M;G1A:6X@:&5A9&5R<R(I.PH@("`@("`@('T*("`@("`@("!F;W)E86-H*"1H
M96%D97)L:7-T(&%S("1I=&5M*2!["B`@("`@("`@("`@("1H96%D97);)&ET
M96U;)VYA;64G75T@/2`D:71E;5LG=F%L=64G73L*("`@("`@("`@("`@<W=I
M=&-H("AS=')T;VQO=V5R*"1I=&5M6R=N86UE)UTI*2!["B`@("`@("`@("`@
M("`@("!C87-E(")T;R(Z"B`@("`@("`@("`@("`@("!C87-E(")C8R(Z"B`@
M("`@("`@("`@("`@("!C87-E(")B8V,B.@H@("`@("`@("`@("`@("`@("`@
M("1T;R`]("(L(BXD:71E;5LG=F%L=64G73L*("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H)'1O(#T]("(B*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B365S<V%G92!D:60@;F]T
M(&-O;G1A:6X@86YY(')E8VEP96YT<R(I.PH@("`@("`@('T*("`@("`@("`D
M=&\@/2!S=6)S='(H)'1O+#$I.PH@("`@("`@(')E='5R;B!A<G)A>2@D=&\L
M)&AE861E<BPD=&AI<RT^7V)O9'DI.PH@("`@?2`*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@82!X;6P@8V]P>2!O9B!T:&4@;W5T<'5T(&]F"B`@("`@*B!-
M86EL7VUI;65$96-O9&4Z.F1E8V]D92X@4&%S<R!T:&4@;W5T<'5T(&EN(&%S
M('1H90H@("`@("H@87)G=6UE;G0N(%1H:7,@9G5N8W1I;VX@8V%N(&)E(&-A
M;&QE9"!S=&%T:6-A;&QY+B!%9SH*("`@("`J"B`@("`@*B`D;W5T<'5T(#T@
M)&]B:BT^9&5C;V1E*"D["B`@("`@*B`D>&UL("`@(#T@36%I;%]M:6UE1&5C
M;V1E.CIG971834PH)&]U='!U="D["B`@("`@*@H@("`@("H@5&AE($141"!U
M<V5D(&9O<B!T:&ES('-H;W5L9"!H879E(&)E96X@:6X@=&AE('!A8VMA9V4N
M($]R"B`@("`@*B!A;'1E<FYA=&EV96QY('EO=2!C86X@9V5T(&ET(&9R;VT@
M8W9S+"!O<B!H97)E.@H@("`@("H@:'1T<#HO+W=W=RYP:'!G=7)U+F]R9R]X
M;6%I;"]X;6%I;"YD=&0N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@
M26YP=70@=&\@8V]N=F5R="!T;R!X;6PN(%1H:7,@<VAO=6QD(&)E('1H90H@
M("`@("H@("`@("`@("`@("`@("`@;W5T<'5T(&]F('1H92!-86EL7VUI;65$
M96-O9&4Z.F1E8V]D92!F=6YC=&EO;@H@("`@("H@0')E='5R;B!S=')I;F<@
M6$U,('9E<G-I;VX@;V8@:6YP=70*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=%A-3"@D:6YP=70I"B`@("!["B`@("`@
M("`@)&-R;&8@("`@/2`@(EQR7&XB.PH@("`@("`@("1O=71P=70@(#T@)SP_
M>&UL('9E<G-I;VX]7"<Q+C!<)S\^)R`N("1C<FQF("X*("`@("`@("`@("`@
M("`@("`@("<\(41/0U194$4@96UA:6P@4UE35$5-(")H='1P.B\O=W=W+G!H
M<&=U<G4N;W)G+WAM86EL+WAM86EL+F1T9"(^)R`N("1C<FQF("X*("`@("`@
M("`@("`@("`@("`@("<\96UA:6P^)R`N("1C<FQF("X*("`@("`@("`@("`@
M("`@("`@($UA:6Q?;6EM941E8V]D93HZ7V=E=%A-3"@D:6YP=70I("X*("`@
M("`@("`@("`@("`@("`@("<\+V5M86EL/B<["@H@("`@("`@(')E='5R;B`D
M;W5T<'5T.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&AA="!D
M;V5S('1H92!A8W1U86P@8V]N=F5R<VEO;B!T;R!X;6PN($1O97,@82!S:6YG
M;&4*("`@("`J(&UI;65P87)T(&%T(&$@=&EM92X*("`@("`J"B`@("`@*B!`
M<&%R86T@(&]B:F5C="`@26YP=70@=&\@8V]N=F5R="!T;R!X;6PN(%1H:7,@
M:7,@82!M:6UE<&%R="!O8FIE8W0N"B`@("`@*B`@("`@("`@("`@("`@("`@
M270@;6%Y(&]R(&UA>2!N;W0@8V]N=&%I;B!S=6)P87)T<RX*("`@("`J($!P
M87)A;2`@:6YT96=E<B!.=6UB97(@;V8@=&%B<R!T;R!I;F1E;G0*("`@("`J
M($!R971U<FX@<W1R:6YG("!834P@=F5R<VEO;B!O9B!I;G!U=`H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G971834PH
M)&EN<'5T+"`D:6YD96YT(#T@,2D*("`@('L*("`@("`@("`D:'1A8B`@("`]
M("`B7'0B.PH@("`@("`@("1C<FQF("`@(#T@(")<<EQN(CL*("`@("`@("`D
M;W5T<'5T("`]("`G)SL*("`@("`@("`D:&5A9&5R<R`]($`H87)R87DI)&EN
M<'5T+3YH96%D97)S.PH*("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D
M:&1R7VYA;64@/3X@)&AD<E]V86QU92D@>PH*("`@("`@("`@("`@+R\@375L
M=&EP;&4@:&5A9&5R<R!W:71H('1H:7,@;F%M90H@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&AE861E<G-;)&AD<E]N86UE72DI('L*("`@("`@("`@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1H9')?=F%L=64I.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!-86EL7VUI;65$
M96-O9&4Z.E]G971834Q?:&5L<&5R*"1H9')?;F%M92P@)&AD<E]V86QU95LD
M:5TL("1I;F1E;G0I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M+R\@3VYL>2!O;F4@:&5A9&5R(&]F('1H:7,@<V]R=`H@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)&]U='!U="`N/2!-86EL7VUI;65$
M96-O9&4Z.E]G971834Q?:&5L<&5R*"1H9')?;F%M92P@)&AD<E]V86QU92P@
M)&EN9&5N="D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF
M("@A96UP='DH)&EN<'5T+3YP87)T<RDI('L*("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@8V]U;G0H)&EN<'5T+3YP87)T<RD[("1I*RLI('L*("`@
M("`@("`@("`@("`@("1O=71P=70@+CT@)&-R;&8@+B!S=')?<F5P96%T*"1H
M=&%B+"`D:6YD96YT*2`N("<\;6EM97!A<G0^)R`N("1C<FQF("X*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@36%I;%]M:6UE1&5C;V1E.CI?9V5T6$U,
M*"1I;G!U="T^<&%R='-;)&E=+"`D:6YD96YT*S$I("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@+B`G
M/"]M:6UE<&%R=#XG("X@)&-R;&8["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)&EN<'5T+3YB;V1Y*2D@>PH@("`@("`@("`@("`D
M;W5T<'5T("X]("1C<FQF("X@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@
M+B`G/&)O9'D^/"%;0T1!5$%;)R`N"B`@("`@("`@("`@("`@("`@("`@("`@
M)&EN<'5T+3YB;V1Y("X@)UU=/CPO8F]D>3XG("X@)&-R;&8["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&]U='!U=#L*("`@('T*"B`@("`O*BH*("`@
M("`J($AE;'!E<B!F=6YC=&EO;B!T;R!?9V5T6$U,*"DN(%)E='5R;G,@>&UL
M(&]F(&$@:&5A9&5R+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("!.
M86UE(&]F(&AE861E<@H@("`@("H@0'!A<F%M("!S=')I;F<@(%9A;'5E(&]F
M(&AE861E<@H@("`@("H@0'!A<F%M("!I;G1E9V5R($YU;6)E<B!O9B!T86)S
M('1O(&EN9&5N=`H@("`@("H@0')E='5R;B!S=')I;F<@(%A-3"!V97)S:6]N
M(&]F(&EN<'5T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V=E=%A-3%]H96QP97(H)&AD<E]N86UE+"`D:&1R7W9A;'5E
M+"`D:6YD96YT*0H@("`@>PH@("`@("`@("1H=&%B("`@/2`B7'0B.PH@("`@
M("`@("1C<FQF("`@/2`B7')<;B(["B`@("`@("`@)')E='5R;B`]("<G.PH*
M("`@("`@("`D;F5W7VAD<E]V86QU92`]("@D:&1R7VYA;64@(3T@)W)E8V5I
M=F5D)RD@/R!-86EL7VUI;65$96-O9&4Z.E]P87)S94AE861E<E9A;'5E*"1H
M9')?=F%L=64I(#H@87)R87DH)W9A;'5E)R`]/B`D:&1R7W9A;'5E*3L*("`@
M("`@("`D;F5W7VAD<E]N86UE("`]('-T<E]R97!L86-E*"<@)RP@)RTG+"!U
M8W=O<F1S*'-T<E]R97!L86-E*"<M)RP@)R`G+"`D:&1R7VYA;64I*2D["@H@
M("`@("`@("\O(%-O<G0@;W5T(&%N>2!P87)A;65T97)S"B`@("`@("`@:68@
M*"%E;7!T>2@D;F5W7VAD<E]V86QU95LG;W1H97(G72DI('L*("`@("`@("`@
M("`@9F]R96%C:"`H)&YE=U]H9')?=F%L=65;)V]T:&5R)UT@87,@)'!A<F%M
M;F%M92`]/B`D<&%R86UV86QU92D@>PH@("`@("`@("`@("`@("`@)'!A<F%M
M<UM=(#T@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@+B`D:'1A8B`N("<\
M<&%R86UE=&5R/B<@+B`D8W)L9B`N"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!S=')?<F5P96%T*"1H=&%B+"`D:6YD96YT*2`N("1H=&%B("X@)&AT
M86(@+B`G/'!A<F%M;F%M93XG("X@:'1M;'-P96-I86QC:&%R<R@D<&%R86UN
M86UE*2`N("<\+W!A<F%M;F%M93XG("X@)&-R;&8@+@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@+B`D
M:'1A8B`N("1H=&%B("X@)SQP87)A;79A;'5E/B<@+B!H=&UL<W!E8VEA;&-H
M87)S*"1P87)A;79A;'5E*2`N("<\+W!A<F%M=F%L=64^)R`N("1C<FQF("X*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<E]R97!E870H)&AT86(L
M("1I;F1E;G0I("X@)&AT86(@+B`G/"]P87)A;65T97(^)R`N("1C<FQF.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`D<&%R86US(#T@:6UP;&]D92@G
M)RP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!A
M<F%M<R`]("<G.PH@("`@("`@('T*"B`@("`@("`@)')E='5R;B`]('-T<E]R
M97!E870H)&AT86(L("1I;F1E;G0I("X@)SQH96%D97(^)R`N("1C<FQF("X*
M("`@("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@
M+B`D:'1A8B`N("<\:&5A9&5R;F%M93XG("X@:'1M;'-P96-I86QC:&%R<R@D
M;F5W7VAD<E]N86UE*2`N("<\+VAE861E<FYA;64^)R`N("1C<FQF("X*("`@
M("`@("`@("`@("`@("`@<W1R7W)E<&5A="@D:'1A8BP@)&EN9&5N="D@+B`D
M:'1A8B`N("<\:&5A9&5R=F%L=64^)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&YE
M=U]H9')?=F%L=65;)W9A;'5E)UTI("X@)SPO:&5A9&5R=F%L=64^)R`N("1C
M<FQF("X*("`@("`@("`@("`@("`@("`@)'!A<F%M<R`N"B`@("`@("`@("`@
M("`@("`@('-T<E]R97!E870H)&AT86(L("1I;F1E;G0I("X@)SPO:&5A9&5R
M/B<@+B`D8W)L9CL*"B`@("`@("`@<F5T=7)N("1R971U<FX["B`@("!]"@I]
M("\O($5N9"!O9B!C;&%S<PH_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL
M+W-E;F1M86EL+G!H<```````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$S,S8V(#$P-3$U-#,T,3,U(#`R,38V,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO+PHO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO
M+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@
M9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@
M870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!0
M2%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W(Z($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PH*+RHJ"B`J(%-E;F1M86EL(&EM<&QE;65N=&%T:6]N(&]F('1H
M92!014%2($UA:6PZ.B!I;G1E<F9A8V4N"B`J($!A8V-E<W,@<'5B;&EC"B`J
M($!P86-K86=E($UA:6P*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C$S("0*
M("HO"F-L87-S($UA:6Q?<V5N9&UA:6P@97AT96YD<R!-86EL('L*"@DO*BH*
M("`@("`J(%1H92!L;V-A=&EO;B!O9B!T:&4@<V5N9&UA:6P@;W(@<V5N9&UA
M:6P@=W)A<'!E<B!B:6YA<GD@;VX@=&AE"B`@("`@*B!F:6QE<WES=&5M+@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S96YD;6%I;%]P
M871H(#T@)R]U<W(O<V)I;B]S96YD;6%I;"<["@H)+RHJ"B`@("`@*B!!;GD@
M97AT<F$@8V]M;6%N9"UL:6YE('!A<F%M971E<G,@=&\@<&%S<R!T;R!T:&4@
M<V5N9&UA:6P@;W(*("`@("`J('-E;F1M86EL('=R87!P97(@8FEN87)Y+@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S96YD;6%I;%]A
M<F=S(#T@)R<["@H)+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@
M("`@*B!);G-T86YT:6%T97,@82!N97<@36%I;%]S96YD;6%I;#HZ(&]B:F5C
M="!B87-E9"!O;B!T:&4@<&%R86UE=&5R<PH@("`@("H@<&%S<V5D(&EN+B!)
M="!L;V]K<R!F;W(@=&AE(&9O;&QO=VEN9R!P87)A;65T97)S.@H@("`@("H@
M("`@('-E;F1M86EL7W!A=&@@("`@5&AE(&QO8V%T:6]N(&]F('1H92!S96YD
M;6%I;"!B:6YA<GD@;VX@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("!F:6QE<WES=&5M+B!$969A=6QT<R!T;R`G+W5S<B]S8FEN+W-E;F1M86EL
M)RX*("`@("`J"B`@("`@*B`@("`@<V5N9&UA:6Q?87)G<R`@("!!;GD@97AT
M<F$@<&%R86UE=&5R<R!T;R!P87-S('1O('1H92!S96YD;6%I;`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@;W(@<V5N9&UA:6P@=W)A<'!E<B!B:6YA
M<GDN"B`@("`@*@H@("`@("H@268@82!P87)A;65T97(@:7,@<')E<V5N="!I
M;B!T:&4@)'!A<F%M<R!A<G)A>2P@:70@<F5P;&%C97,@=&AE"B`@("`@*B!D
M969A=6QT+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D<&%R86US($AA
M<V@@8V]N=&%I;FEN9R!A;GD@<&%R86UE=&5R<R!D:69F97)E;G0@9G)O;2!T
M:&4*("`@("`J("`@("`@("`@("`@("!D969A=6QT<RX*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6Q?<V5N9&UA:6PH
M)'!A<F%M<RD*("`@('L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<V5N
M9&UA:6Q?<&%T:"==*2D@)'1H:7,M/G-E;F1M86EL7W!A=&@@/2`D<&%R86US
M6R=S96YD;6%I;%]P871H)UT["B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;
M)W-E;F1M86EL7V%R9W,G72DI("1T:&ES+3YS96YD;6%I;%]A<F=S(#T@)'!A
M<F%M<ULG<V5N9&UA:6Q?87)G<R==.PH*("`@("`@("`O*@H@("`@("`@("`J
M($)E8V%U<V4@=V4@;F5E9"!T;R!P87-S(&UE<W-A9V4@:&5A9&5R<R!T;R!T
M:&4@<V5N9&UA:6P@<')O9W)A;2!O;@H@("`@("`@("`J('1H92!C;VUM86YD
M;&EN92P@=V4@8V%N)W0@9W5A<F%N=&5E('1H92!U<V4@;V8@=&AE('-T86YD
M87)D(")<<EQN(@H@("`@("`@("`J('-E<&%R871O<BX@($EN<W1E860L('=E
M('5S92!T:&4@<WES=&5M)W,@;F%T:79E(&QI;F4@<V5P87)A=&]R+@H@("`@
M("`@("`J+PH@("`@("`@(&EF("AD969I;F5D*%!(4%]%3TPI*2!["B`@("`@
M("`@("`@("1T:&ES+3YS97`@/2!02%!?14],.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YS97`@/2`H<W1R<&]S*%!(4%]/4RP@)U=)
M3B<I(#T]/2!F86QS92D@/R`B7&XB(#H@(EQR7&XB.PH@("`@("`@('T*("`@
M('T*"@DO*BH*("`@("`J($EM<&QE;65N=',@36%I;#HZ<V5N9"@I(&9U;F-T
M:6]N('5S:6YG('1H92!S96YD;6%I;`H@("`@("H@8V]M;6%N9"UL:6YE(&)I
M;F%R>2X*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E8VEP:65N=',@
M16ET:&5R(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT<PH@
M("`@("H@("`@("`@("`@("`@("A21D,X,C(@8V]M<&QI86YT*2P@;W(@86X@
M87)R87D@;V8@<F5C:7!I96YT<RP*("`@("`J("`@("`@("`@("`@("!E86-H
M(%)&0S@R,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R96-I<&EE;G1S(&YO
M=`H@("`@("H@("`@("`@("`@("`@('-P96-I9FEE9"!I;B!T:&4@:&5A9&5R
M<RP@9F]R($)C8SHL(')E<V5N9&EN9PH@("`@("H@("`@("`@("`@("`@(&UE
M<W-A9V5S+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D
M97)S(%1H92!A<G)A>2!O9B!H96%D97)S('1O('-E;F0@=VET:"!T:&4@;6%I
M;"P@:6X@86X*("`@("`J("`@("`@("`@("`@("!A<W-O8VEA=&EV92!A<G)A
M>2P@=VAE<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@("`J("`@("`@("`@
M("`@("!H96%D97(@;F%M92`H:64L("=3=6)J96-T)RDL(&%N9"!T:&4@87)R
M87D@=F%L=64*("`@("`J("`@("`@("`@("`@("!I<R!T:&4@:&5A9&5R('9A
M;'5E("AI92P@)W1E<W0G*2X@5&AE(&AE861E<@H@("`@("H@("`@("`@("`@
M("`@('!R;V1U8V5D(&9R;VT@=&AO<V4@=F%L=65S('=O=6QD(&)E("=3=6)J
M96-T.@H@("`@("H@("`@("`@("`@("`@('1E<W0G+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&)O9'D@5&AE(&9U;&P@=&5X="!O9B!T:&4@;65S
M<V%G92!B;V1Y+"!I;F-L=61I;F<@86YY"B`@("`@*B`@("`@("`@("`@("`@
M($UI;64@<&%R=',L(&5T8RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(%)E='5R;G,@=')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R;W(*("`@
M("`J("`@("`@("`@("`@("`@8V]N=&%I;FEN9R!A(&1E<V-R:7!T:79E(&5R
M<F]R(&UE<W-A9V4@;VX*("`@("`J("`@("`@("`@("`@("`@9F%I;'5R92X*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M;F0H)')E8VEP:65N=',L("1H96%D97)S+"`D8F]D>2D*("`@('L*("`@("`@
M("`D<F5C:7!I96YT<R`]("1T:&ES+3YP87)S95)E8VEP:65N=',H)')E8VEP
M:65N=',I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R96-I<&EE;G1S
M*2D@>PH@("`@("`@("`@("!R971U<FX@)')E8VEP:65N=',["B`@("`@("`@
M?0H@("`@("`@("1R96-I<&EE;G1S(#T@97-C87!E4VAE;&Q#;60H:6UP;&]D
M92@G("<L("1R96-I<&EE;G1S*2D["@H@("`@("`@("1H96%D97)%;&5M96YT
M<R`]("1T:&ES+3YP<F5P87)E2&5A9&5R<R@D:&5A9&5R<RD["B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&AE861E<D5L96UE;G1S*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&AE861E<D5L96UE;G1S.PH@("`@("`@('T*("`@("`@
M("!L:7-T*"1F<F]M+"`D=&5X=%]H96%D97)S*2`]("1H96%D97)%;&5M96YT
M<SL*"B`@("`@("`@:68@*"%I<W-E="@D9G)O;2DI('L*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(&9R;VT@861D<F5S<R!G:79E
M;BXG*3L*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*"1F<F]M+"`G("<I("$]
M/2!F86QS92!\?`H@("`@("`@("`@("`@("`@("!S=')P;W,H)&9R;VTL("<[
M)RD@(3T](&9A;'-E('Q\"B`@("`@("`@("`@("`@("`@('-T<G!O<R@D9G)O
M;2P@)R8G*2`A/3T@9F%L<V4@?'P*("`@("`@("`@("`@("`@("`@<W1R<&]S
M*"1F<F]M+"`G8"<I("$]/2!F86QS92D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G1G)O;2!A9&1R97-S('-P96-I9FEE9"!W:71H
M(&1A;F=E<F]U<R!C:&%R86-T97)S+B<I.PH@("`@("`@('T*"B`@("`@("`@
M)&9R;VT@/2!E<V-A<&53:&5L;$-M9"@D9G)O;2D["B`@("`@("`@)&UA:6P@
M/2!`<&]P96XH)'1H:7,M/G-E;F1M86EL7W!A=&@@+B`H(65M<'1Y*"1T:&ES
M+3YS96YD;6%I;%]A<F=S*2`_("<@)R`N("1T:&ES+3YS96YD;6%I;%]A<F=S
M(#H@)R<I("X@(B`M9B1F<F]M("TM("1R96-I<&EE;G1S(BP@)W<G*3L*("`@
M("`@("!I9B`H(21M86EL*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=&86EL960@=&\@;W!E;B!S96YD;6%I;"!;)R`N("1T:&ES
M+3YS96YD;6%I;%]P871H("X@)UT@9F]R(&5X96-U=&EO;BXG*3L*("`@("`@
M("!]"@H@("`@("`@(&9P=71S*"1M86EL+"`D=&5X=%]H96%D97)S*3L*("`@
M("`@("!F<'5T<R@D;6%I;"P@)'1H:7,M/G-E<"D[("`O+R!N97=L:6YE('1O
M(&5N9"!T:&4@:&5A9&5R<R!S96-T:6]N"B`@("`@("`@9G!U=',H)&UA:6PL
M("1B;V1Y*3L*("`@("`@("`D<F5S=6QT(#T@<&-L;W-E*"1M86EL*3L*("`@
M("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,BXS
M)RD@/3T@+3$I('L*("`@("`@("`@("`@+R\@5VET:"!O;&1E<B!P:'`@=F5R
M<VEO;G,L('=E(&YE960@=&\@<VAI9G0@=&AE('!C;&]S90H@("`@("`@("`@
M("`O+R!R97-U;'0@=&\@9V5T('1H92!E>&ET(&-O9&4N"B`@("`@("`@("`@
M("1R97-U;'0@/2`D<F5S=6QT(#X^(#@@)B`P>$9&.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1R97-U;'0@(3T@,"D@>PH@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@G<V5N9&UA:6P@<F5T=7)N960@97)R;W(@8V]D
M92`G("X@)')E<W5L="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<W5L="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO<VUT
M<"YP:'``````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,S`P-#8@,3`U,34T,S0Q,S4@,#(Q,#0T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z
M($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("!*;VX@4&%R:7-E(#QJ
M;VY`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+RHJ($5R<F]R
M.B!&86EL960@=&\@8W)E871E(&$@3F5T7U--5%`@;V)J96-T("HO"F1E9FEN
M92@G4$5!4E]-04E,7U--5%!?15)23U)?0U)%051%)RP@,3`P,#`I.PH*+RHJ
M($5R<F]R.B!&86EL960@=&\@8V]N;F5C="!T;R!33510('-E<G9E<B`J+PID
M969I;F4H)U!%05)?34%)3%]335107T524D]27T-/3DY%0U0G+"`Q,#`P,2D[
M"@HO*BH@17)R;W(Z(%--5%`@875T:&5N=&EC871I;VX@9F%I;'5R92`J+PID
M969I;F4H)U!%05)?34%)3%]335107T524D]27T%55$@G+"`Q,#`P,BD["@HO
M*BH@17)R;W(Z($YO($9R;VTZ(&%D9')E<W,@:&%S(&)E96X@<')O=FED960@
M*B\*9&5F:6YE*"=014%27TU!24Q?4TU44%]%4E)/4E]&4D]-)RP@,3`P,#,I
M.PH*+RHJ($5R<F]R.B!&86EL960@=&\@<V5T('-E;F1E<B`J+PID969I;F4H
M)U!%05)?34%)3%]335107T524D]27U-%3D1%4B<L(#$P,#`T*3L*"B\J*B!%
M<G)O<CH@1F%I;&5D('1O(&%D9"!R96-I<&EE;G0@*B\*9&5F:6YE*"=014%2
M7TU!24Q?4TU44%]%4E)/4E]214-)4$E%3E0G+"`Q,#`P-2D["@HO*BH@17)R
M;W(Z($9A:6QE9"!T;R!S96YD(&1A=&$@*B\*9&5F:6YE*"=014%27TU!24Q?
M4TU44%]%4E)/4E]$051!)RP@,3`P,#8I.PH*+RHJ"B`J(%--5%`@:6UP;&5M
M96YT871I;VX@;V8@=&AE(%!%05(@36%I;"!I;G1E<F9A8V4N(%)E<75I<F5S
M('1H92!.971?4TU44"!C;&%S<RX*("H@0&%C8V5S<R!P=6)L:6,*("H@0'!A
M8VMA9V4@36%I;`H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,C8@)`H@*B\*
M8VQA<W,@36%I;%]S;71P(&5X=&5N9',@36%I;"!["@H@("`@+RHJ"B`@("`@
M*B!33510(&-O;FYE8W1I;VX@;V)J96-T+@H@("`@("H*("`@("`J($!V87(@
M;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R
M("1?<VUT<"`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!4:&4@4TU44"!H;W-T
M('1O(&-O;FYE8W0@=&\N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&AO<W0@/2`G;&]C86QH;W-T)SL*"B`@("`O*BH*("`@("`J(%1H
M92!P;W)T('1H92!33510('-E<G9E<B!I<R!O;BX*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)'!O<G0@/2`R-3L*"B`@("`O*BH*("`@
M("`J(%-H;W5L9"!33510(&%U=&AE;G1I8V%T:6]N(&)E('5S960_"B`@("`@
M*@H@("`@("H@5&AI<R!V86QU92!M87D@8F4@<V5T('1O('1R=64L(&9A;'-E
M(&]R('1H92!N86UE(&]F(&$@<W!E8VEF:6,*("`@("`J(&%U=&AE;G1I8V%T
M:6]N(&UE=&AO9"X*("`@("`J"B`@("`@*B!)9B!T:&4@=F%L=64@:7,@<V5T
M('1O('1R=64L('1H92!.971?4TU44"!P86-K86=E('=I;&P@871T96UP="!T
M;R!U<V4*("`@("`J('1H92!B97-T(&%U=&AE;G1I8V%T:6]N(&UE=&AO9"!A
M9'9E<G1I<V5D(&)Y('1H92!R96UO=&4@4TU44"!S97)V97(N"B`@("`@*@H@
M("`@("H@0'9A<B!M:7AE9`H@("`@("HO"B`@("!V87(@)&%U=&@@/2!F86QS
M93L*"B`@("`O*BH*("`@("`J(%1H92!U<V5R;F%M92!T;R!U<V4@:68@=&AE
M(%--5%`@<V5R=F5R(')E<75I<F5S(&%U=&AE;G1I8V%T:6]N+@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1U<V5R;F%M92`]("<G.PH*
M("`@("\J*@H@("`@("H@5&AE('!A<W-W;W)D('1O('5S92!I9B!T:&4@4TU4
M4"!S97)V97(@<F5Q=6ER97,@875T:&5N=&EC871I;VXN"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!A<W-W;W)D(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!(;W-T;F%M92!O<B!D;VUA:6X@=&AA="!W:6QL(&)E('-E
M;G0@=&\@=&AE(')E;6]T92!33510('-E<G9E<B!I;B!T:&4*("`@("`J($A%
M3$\@+R!%2$Q/(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1L;V-A;&AO<W0@/2`G;&]C86QH;W-T)SL*"B`@
M("`O*BH*("`@("`J(%--5%`@8V]N;F5C=&EO;B!T:6UE;W5T('9A;'5E+B`@
M3E5,3"!I;F1I8V%T97,@;F\@=&EM96]U="X*("`@("`J"B`@("`@*B!`=F%R
M(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1T:6UE;W5T(#T@;G5L;#L*"B`@
M("`O*BH*("`@("`J(%=H971H97(@=&\@=7-E(%9%4E`@;W(@;F]T+B!)9B!N
M;W0@82!B;V]L96%N+"!T:&4@<W1R:6YG('9A;'5E"B`@("`@*B!W:6QL(&)E
M('5S960@87,@=&AE(%9%4E`@<V5P87)A=&]R<RX*("`@("`J"B`@("`@*B!`
M=F%R(&UI>&5D(&)O;VQE86X@;W(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M=F5R<"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@5'5R;B!O;B!.971?4TU4
M4"!D96)U9V=I;F<_"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N("1D96)U
M9PH@("`@("HO"B`@("!V87(@)&1E8G5G(#T@9F%L<V4["@H@("`@+RHJ"B`@
M("`@*B!);F1I8V%T97,@=VAE=&AE<B!O<B!N;W0@=&AE(%--5%`@8V]N;F5C
M=&EO;B!S:&]U;&0@<&5R<VES="!O=F5R"B`@("`@*B!M=6QT:7!L92!C86QL
M<R!T;R!T:&4@<V5N9"@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1P97)S:7-T(#T@9F%L<V4["@H@("`@
M+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!);G-T86YT
M:6%T97,@82!N97<@36%I;%]S;71P.CH@;V)J96-T(&)A<V5D(&]N('1H92!P
M87)A;65T97)S"B`@("`@*B!P87-S960@:6XN($ET(&QO;VMS(&9O<B!T:&4@
M9F]L;&]W:6YG('!A<F%M971E<G,Z"B`@("`@*B`@("`@:&]S="`@("`@("`@
M5&AE('-E<G9E<B!T;R!C;VYN96-T('1O+B!$969A=6QT<R!T;R!L;V-A;&AO
M<W0N"B`@("`@*B`@("`@<&]R="`@("`@("`@5&AE('!O<G0@=&\@8V]N;F5C
M="!T;RX@1&5F875L=',@=&\@,C4N"B`@("`@*B`@("`@875T:"`@("`@("`@
M4TU44"!A=71H96YT:6-A=&EO;BX@($1E9F%U;'1S('1O(&YO;F4N"B`@("`@
M*B`@("`@=7-E<FYA;64@("`@5&AE('5S97)N86UE('1O('5S92!F;W(@4TU4
M4"!A=71H+B!.;R!D969A=6QT+@H@("`@("H@("`@('!A<W-W;W)D("`@(%1H
M92!P87-S=V]R9"!T;R!U<V4@9F]R(%--5%`@875T:"X@3F\@9&5F875L="X*
M("`@("`J("`@("!L;V-A;&AO<W0@("!4:&4@;&]C86P@:&]S=&YA;64@+R!D
M;VUA:6XN($1E9F%U;'1S('1O(&QO8V%L:&]S="X*("`@("`J("`@("!T:6UE
M;W5T("`@("!4:&4@4TU44"!C;VYN96-T:6]N('1I;65O=70N($1E9F%U;'1S
M('1O(&YO;F4N"B`@("`@*B`@("`@=F5R<"`@("`@("`@5VAE=&AE<B!T;R!U
M<V4@5D524"!O<B!N;W0N($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H@("`@
M(&1E8G5G("`@("`@($%C=&EV871E(%--5%`@9&5B=6<@;6]D93\@1&5F875L
M=',@=&\@9F%L<V4N"B`@("`@*B`@("`@<&5R<VES="`@("`@4VAO=6QD('1H
M92!33510(&-O;FYE8W1I;VX@<&5R<VES=#\*("`@("`J"B`@("`@*B!)9B!A
M('!A<F%M971E<B!I<R!P<F5S96YT(&EN('1H92`D<&%R86US(&%R<F%Y+"!I
M="!R97!L86-E<R!T:&4*("`@("`J(&1E9F%U;'0N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y($AA<V@@8V]N=&%I;FEN9R!A;GD@<&%R86UE=&5R<R!D
M:69F97)E;G0@9G)O;2!T:&4*("`@("`J("`@("`@("`@("`@("!D969A=6QT
M<RX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M($UA:6Q?<VUT<"@D<&%R86US*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M<&%R86US6R=H;W-T)UTI*2`D=&AI<RT^:&]S="`]("1P87)A;7-;)VAO<W0G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG<&]R="==*2D@)'1H:7,M
M/G!O<G0@/2`D<&%R86US6R=P;W)T)UT["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)V%U=&@G72DI("1T:&ES+3YA=71H(#T@)'!A<F%M<ULG875T:"==
M.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=U<V5R;F%M92==*2D@)'1H
M:7,M/G5S97)N86UE(#T@)'!A<F%M<ULG=7-E<FYA;64G73L*("`@("`@("!I
M9B`H:7-S970H)'!A<F%M<ULG<&%S<W=O<F0G72DI("1T:&ES+3YP87-S=V]R
M9"`]("1P87)A;7-;)W!A<W-W;W)D)UT["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)VQO8V%L:&]S="==*2D@)'1H:7,M/FQO8V%L:&]S="`]("1P87)A
M;7-;)VQO8V%L:&]S="==.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=T
M:6UE;W5T)UTI*2`D=&AI<RT^=&EM96]U="`]("1P87)A;7-;)W1I;65O=70G
M73L*("`@("`@("!I9B`H:7-S970H)'!A<F%M<ULG=F5R<"==*2D@)'1H:7,M
M/G9E<G`@/2`D<&%R86US6R=V97)P)UT["B`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)V1E8G5G)UTI*2`D=&AI<RT^9&5B=6<@/2`H8F]O;&5A;BDD<&%R
M86US6R=D96)U9R==.PH@("`@("`@(&EF("AI<W-E="@D<&%R86US6R=P97)S
M:7-T)UTI*2`D=&AI<RT^<&5R<VES="`]("AB;V]L96%N*21P87)A;7-;)W!E
M<G-I<W0G73L*"B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH
M87)R87DH)B1T:&ES+"`G7TUA:6Q?<VUT<"<I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($1E<W1R=6-T;W(@:6UP;&5M96YT871I;VX@=&\@96YS=7)E('1H
M870@=V4@9&ES8V]N;F5C="!F<F]M(&%N>0H@("`@("H@<&]T96YT:6%L;'DM
M86QI=F4@<&5R<VES=&5N="!33510(&-O;FYE8W1I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?36%I;%]S;71P*"D*("`@('L*("`@("`@("`D=&AI<RT^
M9&ES8V]N;F5C="@I.PH@("`@?0H*("`@("\J*@H@("`@("H@26UP;&5M96YT
M<R!-86EL.CIS96YD*"D@9G5N8W1I;VX@=7-I;F<@4TU44"X*("`@("`J"B`@
M("`@*B!`<&%R86T@;6EX960@)')E8VEP:65N=',@16ET:&5R(&$@8V]M;6$M
M<V5P97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT<PH@("`@("H@("`@("`@("`@
M("`@("A21D,X,C(@8V]M<&QI86YT*2P@;W(@86X@87)R87D@;V8@<F5C:7!I
M96YT<RP*("`@("`J("`@("`@("`@("`@("!E86-H(%)&0S@R,B!V86QI9"X@
M5&AI<R!M87D@8V]N=&%I;B!R96-I<&EE;G1S(&YO=`H@("`@("H@("`@("`@
M("`@("`@('-P96-I9FEE9"!I;B!T:&4@:&5A9&5R<RP@9F]R($)C8SHL(')E
M<V5N9&EN9PH@("`@("H@("`@("`@("`@("`@(&UE<W-A9V5S+"!E=&,N"B`@
M("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H92!A<G)A>2!O
M9B!H96%D97)S('1O('-E;F0@=VET:"!T:&4@;6%I;"P@:6X@86X*("`@("`J
M("`@("`@("`@("`@("!A<W-O8VEA=&EV92!A<G)A>2P@=VAE<F4@=&AE(&%R
M<F%Y(&ME>2!I<R!T:&4*("`@("`J("`@("`@("`@("`@("!H96%D97(@;F%M
M92`H92YG+BP@)U-U8FIE8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@("`@
M("H@("`@("`@("`@("`@(&ES('1H92!H96%D97(@=F%L=64@*&4N9RXL("=T
M97-T)RDN(%1H92!H96%D97(*("`@("`J("`@("`@("`@("`@("!P<F]D=6-E
M9"!F<F]M('1H;W-E('9A;'5E<R!W;W5L9"!B92`G4W5B:F5C=#H*("`@("`J
M("`@("`@("`@("`@("!T97-T)RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1B;V1Y(%1H92!F=6QL('1E>'0@;V8@=&AE(&UE<W-A9V4@8F]D>2P@
M:6YC;'5D:6YG(&%N>0H@("`@("H@("`@("`@("`@("`@("!-:6UE('!A<G1S
M+"!E=&,N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!2971U<FYS('1R
M=64@;VX@<W5C8V5S<RP@;W(@82!014%27T5R<F]R"B`@("`@*B`@("`@("`@
M("`@("`@(&-O;G1A:6YI;F<@82!D97-C<FEP=&EV92!E<G)O<B!M97-S86=E
M(&]N"B`@("`@*B`@("`@("`@("`@("`@(&9A:6QU<F4N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"1R96-I<&EE
M;G1S+"`D:&5A9&5R<RP@)&)O9'DI"B`@("!["B`@("`@("`@:6YC;'5D95]O
M;F-E("=.970O4TU44"YP:'`G.PH*("`@("`@("`O*B!)9B!W92!D;VXG="!A
M;')E861Y(&AA=F4@86X@4TU44"!O8FIE8W0L(&-R96%T92!O;F4N("HO"B`@
M("`@("`@:68@*&ES7V]B:F5C="@D=&AI<RT^7W-M='`I(#T]/2!F86QS92D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-M='`@/28@;F5W($YE=%]33510*"1T
M:&ES+3YH;W-T+"`D=&AI<RT^<&]R="P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]C86QH;W-T*3L*"B`@("`@
M("`@("`@("\J($EF('=E('-T:6QL(&1O;B=T(&AA=F4@86X@4TU44"!O8FIE
M8W0@870@=&AI<R!P;VEN="P@9F%I;"X@*B\*("`@("`@("`@("`@:68@*&ES
M7V]B:F5C="@D=&AI<RT^7W-M='`I(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T9A:6QE9"!T;R!C<F5A
M=&4@82!.971?4TU44"!O8FIE8W0G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@4$5!4E]-04E,7U--5%!?15)23U)?0U)%051%
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@0V]N9FEG=7)E('1H
M92!33510(&-O;FYE8W1I;VXN("HO"B`@("`@("`@("`@(&EF("@D=&AI<RT^
M9&5B=6<I('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<V5T1&5B
M=6<H=')U92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\J($%T=&5M
M<'0@=&\@8V]N;F5C="!T;R!T:&4@8V]N9FEG=7)E9"!33510('-E<G9E<BX@
M*B\*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES
M+3Y?<VUT<"T^8V]N;F5C="@D=&AI<RT^=&EM96]U="DI*2!["B`@("`@("`@
M("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R<F]R*"=&86EL960@=&\@8V]N
M;F5C="!T;R`G("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FAO<W0@+B`G.B<@+B`D=&AI<RT^<&]R="P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<RD["B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W(L(%!%
M05)?34%)3%]335107T524D]27T-/3DY%0U0I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`O*B!!='1E;7!T('1O(&%U=&AE;G1I8V%T92!I9B!A=71H
M96YT:6-A=&EO;B!H87,@8F5E;B!E;F%B;&5D+B`J+PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/F%U=&@I('L*("`@("`@("`@("`@("`@("1M971H;V0@/2!I
M<U]S=')I;F<H)'1H:7,M/F%U=&@I(#\@)'1H:7,M/F%U=&@@.B`G)SL*"B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'1H:7,M
M/E]S;71P+3YA=71H*"1T:&ES+3YU<V5R;F%M92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G!A<W-W;W)D+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65T:&]D*2DI('L*
M("`@("`@("`@("`@("`@("`@("`D97)R;W(@/2`D=&AI<RT^7V5R<F]R*"(D
M;65T:&]D(&%U=&AE;G1I8V%T:6]N(&9A:6QU<F4B+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<RD["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]S;71P+3YR<V5T*"D["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R+"!014%2
M7TU!24Q?4TU44%]%4E)/4E]!551(*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&AE861E<D5L96UE;G1S
M(#T@)'1H:7,M/G!R97!A<F5(96%D97)S*"1H96%D97)S*3L*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D:&5A9&5R16QE;65N=',I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I.PH@("`@("`@("`@("!R971U<FX@
M)&AE861E<D5L96UE;G1S.PH@("`@("`@('T*("`@("`@("!L:7-T*"1F<F]M
M+"`D=&5X=$AE861E<G,I(#T@)&AE861E<D5L96UE;G1S.PH*("`@("`@("`O
M*B!3:6YC92!F97<@351!<R!A<F4@9V]I;F<@=&\@86QL;W<@=&AI<R!H96%D
M97(@=&\@8F4@9F]R9V5D"B`@("`@("`@("H@=6YL97-S(&ET)W,@:6X@=&AE
M($U!24P@1E)/33H@97AC:&%N9V4L('=E)VQL('5S90H@("`@("`@("`J(%)E
M='5R;BU0871H(&EN<W1E860@;V8@1G)O;3H@:68@:70G<R!S970N("HO"B`@
M("`@("`@:68@*"%E;7!T>2@D:&5A9&5R<ULG4F5T=7)N+5!A=&@G72DI('L*
M("`@("`@("`@("`@)&9R;VT@/2`D:&5A9&5R<ULG4F5T=7)N+5!A=&@G73L*
M("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&9R;VTI*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I.PH@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3F\@1G)O;3H@861D<F5S<R!H87,@8F5E
M;B!P<F]V:61E9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(%!%05)?34%)3%]335107T524D]27T923TTI.PH@("`@("`@('T*"B`@
M("`@("`@)&%R9W-;)W9E<G`G72`]("1T:&ES+3YV97)P.PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7W-M='`M/FUA:6Q&<F]M
M*"1F<F]M+"`D87)G<RDI*2!["B`@("`@("`@("`@("1E<G)O<B`]("1T:&ES
M+3Y?97)R;W(H(D9A:6QE9"!T;R!S970@<V5N9&5R.B`D9G)O;2(L("1R97,I
M.PH@("`@("`@("`@("`D=&AI<RT^7W-M='`M/G)S970H*3L*("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R+"!014%27TU!24Q?
M4TU44%]%4E)/4E]314Y$15(I.PH@("`@("`@('T*"B`@("`@("`@)')E8VEP
M:65N=',@/2`D=&AI<RT^<&%R<V5296-I<&EE;G1S*"1R96-I<&EE;G1S*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5C:7!I96YT<RDI('L*("`@
M("`@("`@("`@)'1H:7,M/E]S;71P+3YR<V5T*"D["B`@("`@("`@("`@(')E
M='5R;B`D<F5C:7!I96YT<SL*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@
M*"1R96-I<&EE;G1S(&%S("1R96-I<&EE;G0I('L*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')E<R`]("1T:&ES+3Y?<VUT<"T^<F-P=%1O*"1R
M96-I<&EE;G0I*2D@>PH@("`@("`@("`@("`@("`@)&5R<F]R(#T@)'1H:7,M
M/E]E<G)O<B@B1F%I;&5D('1O(&%D9"!R96-I<&EE;G0Z("1R96-I<&EE;G0B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I.PH@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)&5R<F]R+"!0
M14%27TU!24Q?4TU44%]%4E)/4E]214-)4$E%3E0I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`O*B!396YD('1H92!M97-S86=E)W,@:&5A
M9&5R<R!A;F0@=&AE(&)O9'D@87,@4TU44"!D871A+B`J+PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7W-M='`M/F1A=&$H(B1T
M97AT2&5A9&5R<UQR7&XD8F]D>2(I*2D@>PH@("`@("`@("`@("`D97)R;W(@
M/2`D=&AI<RT^7V5R<F]R*"=&86EL960@=&\@<V5N9"!D871A)RP@)')E<RD[
M"B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"T^<G-E="@I.PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D97)R;W(L(%!%05)?34%)3%]3
M35107T524D]27T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@+RH@268@<&5R
M<VES=&5N="!C;VYN96-T:6]N<R!A<F4@9&ES86)L960L(&1E<W1R;WD@;W5R
M(%--5%`@;V)J96-T+B`J+PH@("`@("`@(&EF("@D=&AI<RT^<&5R<VES="`]
M/3T@9F%L<V4I('L*("`@("`@("`@("`@)'1H:7,M/F1I<V-O;FYE8W0H*3L*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1&ES8V]N;F5C="!A;F0@9&5S=')O>2!T:&4@8W5R<F5N="!3
M3510(&-O;FYE8W1I;VXN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M(%1R=64@:68@=&AE(%--5%`@8V]N;F5C=&EO;B!N;R!L;VYG97(@97AI<W1S
M+@H@("`@("H*("`@("`J($!S:6YC92`@,2XQ+CD*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@("\J($EF('=E(&AA=F4@86X@4TU44"!O8FIE8W0L(&1I<V-O
M;FYE8W0@86YD(&1E<W1R;WD@:70N("HO"B`@("`@("`@:68@*&ES7V]B:F5C
M="@D=&AI<RT^7W-M='`I("8F("1T:&ES+3Y?<VUT<"T^9&ES8V]N;F5C="@I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?<VUT<"`](&YU;&P["B`@("`@("`@
M?0H*("`@("`@("`O*B!792!A<F4@9&ES8V]N;F5C=&5D(&EF('=E(&YO(&QO
M;F=E<B!H879E(&%N(%--5%`@;V)J96-T+B`J+PH@("`@("`@(')E='5R;B`H
M)'1H:7,M/E]S;71P(#T]/2!N=6QL*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($)U:6QD(&$@<W1A;F1A<F1I>F5D('-T<FEN9R!D97-C<FEB:6YG('1H92!C
M=7)R96YT(%--5%`@97)R;W(N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&5X="`@0W5S=&]M('-T<FEN9R!D97-C<FEB:6YG('1H92!E<G)O<B!C
M;VYT97AT+@H@("`@("H@0'!A<F%M(&]B:F5C="`D97)R;W(@4F5F97)E;F-E
M('1O('1H92!C=7)R96YT(%!%05)?17)R;W(@;V)J96-T+@H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("`@("`@($$@<W1R:6YG(&1E<V-R:6)I;F<@
M=&AE(&-U<G)E;G0@4TU44"!E<G)O<BX*("`@("`J"B`@("`@*B!`<VEN8V4@
M(#$N,2XW"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7V5R<F]R*"1T97AT+"`F)&5R<F]R*0H@("`@>PH@("`@("`@("\J
M(%-P;&ET('1H92!33510(')E<W!O;G-E(&EN=&\@82!C;V1E(&%N9"!A(')E
M<W!O;G-E('-T<FEN9RX@*B\*("`@("`@("!L:7-T*"1C;V1E+"`D<F5S<&]N
M<V4I(#T@)'1H:7,M/E]S;71P+3YG971297-P;VYS92@I.PH*("`@("`@("`O
M*B!"=6EL9"!O=7(@<W1A;F1A<F1I>F5D(&5R<F]R('-T<FEN9RX@*B\*("`@
M("`@("`D;7-G(#T@)'1E>'0["B`@("`@("`@)&US9R`N/2`G(%M33510.B`G
M("X@)&5R<F]R+3YG971-97-S86=E*"D["B`@("`@("`@)&US9R`N/2`B("AC
M;V1E.B`D8V]D92P@<F5S<&]N<V4Z("1R97-P;VYS92E=(CL*"B`@("`@("`@
M<F5T=7)N("1M<V<["B`@("!]"GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL+U)&0S@R,BYP:'``
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#<V-C(S
M(#$P-3$U-#,T,3,U(#`R,#<T,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`R,#`Q+3(P,#(L(%)I8VAA
M<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@4F5D:7-T<FEB=71I;VX@86YD('5S92!I
M;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T("`@
M('P*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@
M=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?`HO+R!\(&%R92!M
M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D
M92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?`HO+R!\
M("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\"B\O('P@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@
M?`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO;BY\"B\O('P@;R!4:&4@
M;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92`@("`@('P*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@
M9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I
M='1E;B`@?`HO+R!\("`@<&5R;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3("`@?`HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2
M($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\
M"B\O('P@3$E-251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-
M15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P*+R\@?"!!(%!!4E1)
M0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!
M3$P@5$A%($-/4%E224=(5"`@?`HO+R!\($]73D52($]2($-/3E1224)55$]2
M4R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.
M5$%,+"!\"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y4
M24%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P*+R\@?"!,
M24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2
M(%-%4E9)0T53.R!,3U-3($]&(%5312P@?`HO+R!\($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@
M04Y$($].($%.62!\"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%
M4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P*
M+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE3
M24Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?`HO+R!\($]&(%1(25,@
M4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U
M=&AO<G,Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*
M+RHJ"B`J(%)&0R`X,C(@16UA:6P@861D<F5S<R!L:7-T('9A;&ED871I;VX@
M571I;&ET>0H@*@H@*B!7:&%T(&ES(&ET/PH@*@H@*B!4:&ES(&-L87-S('=I
M;&P@=&%K92!A;B!A9&1R97-S('-T<FEN9RP@86YD('!A<G-E(&ET(&EN=&\@
M:70G<R!C;VYS:71U96YT"B`J('!A<G1S+"!B92!T:&%T(&5I=&AE<B!A9&1R
M97-S97,L(&=R;W5P<RP@;W(@8V]M8FEN871I;VYS+B!.97-T960@9W)O=7!S
M"B`J(&%R92!N;W0@<W5P<&]R=&5D+B!4:&4@<W1R=6-T=7)E(&ET(')E='5R
M;G,@:7,@<')E='1Y('-T<F%I9VAT(&9O<G=A<F0L"B`J(&%N9"!I<R!S:6UI
M;&%R('1O('1H870@<')O=FED960@8GD@=&AE(&EM87!?<F9C.#(R7W!A<G-E
M7V%D<FQI<W0H*2X@57-E"B`J('!R:6YT7W(H*2!T;R!V:65W('1H92!S=')U
M8W1U<F4N"B`J"B`J($AO=R!D;R!)('5S92!I=#\*("H*("H@)&%D9')E<W-?
M<W1R:6YG(#T@)TUY($=R;W5P.B`B4FEC:&%R9"(@/')I8VAA<F1`;&]C86QH
M;W-T/B`H02!C;VUM96YT*2P@=&5D0&5X86UP;&4N8V]M("A4960@0FQO9V=S
M*2P@0F%R;F5Y.R<["B`J("1S=')U8W1U<F4@/2!-86EL7U)&0S@R,CHZ<&%R
M<V5!9&1R97-S3&ES="@D861D<F5S<U]S=')I;F<L("=E>&%M<&QE+F-O;2<L
M('1R=64I"B`J('!R:6YT7W(H)'-T<G5C='5R92D["B`J"B`J($!A=71H;W(@
M(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^"B`J($!A=71H
M;W(@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R9&4N;W)G/@H@*B!`=F5R
M<VEO;B`D4F5V:7-I;VXZ(#$N,C(@)`H@*B!`;&EC96YS92!"4T0*("H@0'!A
M8VMA9V4@36%I;`H@*B\*8VQA<W,@36%I;%]21D,X,C(@>PH*("`@("\J*@H@
M("`@("H@5&AE(&%D9')E<W,@8F5I;F<@<&%R<V5D(&)Y('1H92!21D,X,C(@
M;V)J96-T+@H@("`@("H@0'9A<B!S=')I;F<@)&%D9')E<W,*("`@("`J+PH@
M("`@=F%R("1A9&1R97-S(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&5F
M875L="!D;VUA:6X@=&\@=7-E(&9O<B!U;G%U86QI9FEE9"!A9&1R97-S97,N
M"B`@("`@*B!`=F%R('-T<FEN9R`D9&5F875L=%]D;VUA:6X*("`@("`J+PH@
M("`@=F%R("1D969A=6QT7V1O;6%I;B`]("=L;V-A;&AO<W0G.PH*("`@("\J
M*@H@("`@("H@4VAO=6QD('=E(')E='5R;B!A(&YE<W1E9"!A<G)A>2!S:&]W
M:6YG(&=R;W5P<RP@;W(@9FQA='1E;B!E=F5R>71H:6YG/PH@("`@("H@0'9A
M<B!B;V]L96%N("1N97-T1W)O=7!S"B`@("`@*B\*("`@('9A<B`D;F5S=$=R
M;W5P<R`]('1R=64["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R(&]R(&YO="!T
M;R!V86QI9&%T92!A=&]M<R!F;W(@;F]N+6%S8VEI(&-H87)A8W1E<G,N"B`@
M("`@*B!`=F%R(&)O;VQE86X@)'9A;&ED871E"B`@("`@*B\*("`@('9A<B`D
M=F%L:61A=&4@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE(&%R<F%Y(&]F
M(')A=R!A9&1R97-S97,@8G5I;'0@=7`@87,@=V4@<&%R<V4N"B`@("`@*B!`
M=F%R(&%R<F%Y("1A9&1R97-S97,*("`@("`J+PH@("`@=F%R("1A9&1R97-S
M97,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(&9I;F%L(&%R<F%Y
M(&]F('!A<G-E9"!A9&1R97-S(&EN9F]R;6%T:6]N('1H870@=V4@8G5I;&0@
M=7`N"B`@("`@*B!`=F%R(&%R<F%Y("1S=')U8W1U<F4*("`@("`J+PH@("`@
M=F%R("1S=')U8W1U<F4@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE
M(&-U<G)E;G0@97)R;W(@;65S<V%G92P@:68@86YY+@H@("`@("H@0'9A<B!S
M=')I;F<@)&5R<F]R"B`@("`@*B\*("`@('9A<B`D97)R;W(@/2!N=6QL.PH*
M("`@("\J*@H@("`@("H@06X@:6YT97)N86P@8V]U;G1E<B]P;VEN=&5R+@H@
M("`@("H@0'9A<B!I;G1E9V5R("1I;F1E>`H@("`@("HO"B`@("!V87(@)&EN
M9&5X(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@9W)O
M=7!S('1H870@:&%V92!B965N(&9O=6YD(&EN('1H92!A9&1R97-S(&QI<W0N
M"B`@("`@*B!`=F%R(&EN=&5G97(@)&YU;5]G<F]U<',*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@('9A<B`D;G5M7V=R;W5P<R`](#`["@H@
M("`@+RHJ"B`@("`@*B!!('9A<FEA8FQE('-O('1H870@=V4@8V%N('1E;&P@
M=VAE=&AE<B!O<B!N;W0@=V4G<F4@:6YS:61E(&$*("`@("`J($UA:6Q?4D9#
M.#(R(&]B:F5C="X*("`@("`J($!V87(@8F]O;&5A;B`D;6%I;%)&0S@R,@H@
M("`@("HO"B`@("!V87(@)&UA:6Q21D,X,C(@/2!T<G5E.PH*("`@("\J*@H@
M("`@*B!!(&QI;6ET(&%F=&5R('=H:6-H('!R;V-E<W-I;F<@<W1O<',*("`@
M("H@0'9A<B!I;G0@)&QI;6ET"B`@("`J+PH@("`@=F%R("1L:6UI="`](&YU
M;&P["@H@("`@+RHJ"B`@("`@*B!3971S('5P('1H92!O8FIE8W0N(%1H92!A
M9&1R97-S(&UU<W0@96ET:&5R(&)E('-E="!H97)E(&]R('=H96X*("`@("`J
M(&-A;&QI;F<@<&%R<V5!9&1R97-S3&ES="@I+B!/;F4@;W(@=&AE(&]T:&5R
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D861D<F5S<R`@("`@("`@(%1H92!A9&1R97-S*&5S*2!T;R!V
M86QI9&%T92X*("`@("`J($!P87)A;2!S=')I;F<@("1D969A=6QT7V1O;6%I
M;B`@1&5F875L="!D;VUA:6XO:&]S="!E=&,N($EF(&YO="!S=7!P;&EE9"P@
M=VEL;"!B92!S970@=&\@;&]C86QH;W-T+@H@("`@("H@0'!A<F%M(&)O;VQE
M86X@)&YE<W1?9W)O=7!S("`@("!7:&5T:&5R('1O(')E='5R;B!T:&4@<W1R
M=6-T=7)E('=I=&@@9W)O=7!S(&YE<W1E9"!F;W(@96%S:65R('9I97=I;F<N
M"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=F%L:61A=&4@("`@("`@(%=H971H
M97(@=&\@=F%L:61A=&4@871O;7,N(%1U<FX@=&AI<R!O9F8@:68@>6]U(&YE
M960@=&\@<G5N(&%D9')E<W-E<R!T:')O=6=H(&)E9F]R92!E;F-O9&EN9R!T
M:&4@<&5R<V]N86P@;F%M97,L(&9O<B!I;G-T86YC92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&]B:F5C="!-86EL7U)&0S@R,B!!(&YE=R!-86EL7U)&0S@R
M,B!O8FIE8W0N"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6Q?4D9#.#(R*"1A
M9&1R97-S(#T@;G5L;"P@)&1E9F%U;'1?9&]M86EN(#T@;G5L;"P@)&YE<W1?
M9W)O=7!S(#T@;G5L;"P@)'9A;&ED871E(#T@;G5L;"P@)&QI;6ET(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)&%D9')E<W,I*2`@("`@("`@
M)'1H:7,M/F%D9')E<W,@("`@("`@(#T@)&%D9')E<W,["B`@("`@("`@:68@
M*&ES<V5T*"1D969A=6QT7V1O;6%I;BDI("1T:&ES+3YD969A=6QT7V1O;6%I
M;B`]("1D969A=6QT7V1O;6%I;CL*("`@("`@("!I9B`H:7-S970H)&YE<W1?
M9W)O=7!S*2D@("`@)'1H:7,M/FYE<W1'<F]U<',@("`@(#T@)&YE<W1?9W)O
M=7!S.PH@("`@("`@(&EF("AI<W-E="@D=F%L:61A=&4I*2`@("`@("`D=&AI
M<RT^=F%L:61A=&4@("`@("`@/2`D=F%L:61A=&4["B`@("`@("`@:68@*&ES
M<V5T*"1L:6UI="DI("`@("`@("`@("1T:&ES+3YL:6UI="`@("`@("`@("`]
M("1L:6UI=#L*("`@('T*"B`@("`O*BH*("`@("`J(%-T87)T<R!T:&4@=VAO
M;&4@<')O8V5S<RX@5&AE(&%D9')E<W,@;75S="!E:71H97(@8F4@<V5T(&AE
M<F4*("`@("`J(&]R('=H96X@8W)E871I;F<@=&AE(&]B:F5C="X@3VYE(&]R
M('1H92!O=&AE<BX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'!A<F%M('-T<FEN9R`@)&%D9')E<W,@("`@("`@("!4:&4@861D<F5S
M<RAE<RD@=&\@=F%L:61A=&4N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&5F
M875L=%]D;VUA:6X@($1E9F%U;'0@9&]M86EN+VAO<W0@971C+@H@("`@("H@
M0'!A<F%M(&)O;VQE86X@)&YE<W1?9W)O=7!S("`@("!7:&5T:&5R('1O(')E
M='5R;B!T:&4@<W1R=6-T=7)E('=I=&@@9W)O=7!S(&YE<W1E9"!F;W(@96%S
M:65R('9I97=I;F<N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D=F%L:61A=&4@
M("`@("`@(%=H971H97(@=&\@=F%L:61A=&4@871O;7,N(%1U<FX@=&AI<R!O
M9F8@:68@>6]U(&YE960@=&\@<G5N(&%D9')E<W-E<R!T:')O=6=H(&)E9F]R
M92!E;F-O9&EN9R!T:&4@<&5R<V]N86P@;F%M97,L(&9O<B!I;G-T86YC92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y($$@<W1R=6-T=7)E9"!A<G)A
M>2!O9B!A9&1R97-S97,N"B`@("`@*B\*("`@(&9U;F-T:6]N('!A<G-E061D
M<F5S<TQI<W0H)&%D9')E<W,@/2!N=6QL+"`D9&5F875L=%]D;VUA:6X@/2!N
M=6QL+"`D;F5S=%]G<F]U<',@/2!N=6QL+"`D=F%L:61A=&4@/2!N=6QL+"`D
M;&EM:70@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,I
M('Q\("%I<W-E="@D=&AI<RT^;6%I;%)&0S@R,BDI('L*("`@("`@("`@("`@
M)&]B:B`](&YE=R!-86EL7U)&0S@R,B@D861D<F5S<RP@)&1E9F%U;'1?9&]M
M86EN+"`D;F5S=%]G<F]U<',L("1V86QI9&%T92P@)&QI;6ET*3L*("`@("`@
M("`@("`@<F5T=7)N("1O8FHM/G!A<G-E061D<F5S<TQI<W0H*3L*("`@("`@
M("!]"@H@("`@("`@(&EF("AI<W-E="@D861D<F5S<RDI("`@("`@("`D=&AI
M<RT^861D<F5S<R`@("`@("`@/2`D861D<F5S<SL*("`@("`@("!I9B`H:7-S
M970H)&1E9F%U;'1?9&]M86EN*2D@)'1H:7,M/F1E9F%U;'1?9&]M86EN(#T@
M)&1E9F%U;'1?9&]M86EN.PH@("`@("`@(&EF("AI<W-E="@D;F5S=%]G<F]U
M<',I*2`@("`D=&AI<RT^;F5S=$=R;W5P<R`@("`@/2`D;F5S=%]G<F]U<',[
M"B`@("`@("`@:68@*&ES<V5T*"1V86QI9&%T92DI("`@("`@("1T:&ES+3YV
M86QI9&%T92`@("`@("`]("1V86QI9&%T93L*("`@("`@("!I9B`H:7-S970H
M)&QI;6ET*2D@("`@("`@("`@)'1H:7,M/FQI;6ET("`@("`@("`@(#T@)&QI
M;6ET.PH*("`@("`@("`D=&AI<RT^<W1R=6-T=7)E("`](&%R<F%Y*"D["B`@
M("`@("`@)'1H:7,M/F%D9')E<W-E<R`@/2!A<G)A>2@I.PH@("`@("`@("1T
M:&ES+3YE<G)O<B`@("`@(#T@;G5L;#L*("`@("`@("`D=&AI<RT^:6YD97@@
M("`@("`](&YU;&P["@H@("`@("`@("\O(%5N9F]L9"!A;GD@;&]N9R!L:6YE
M<R!I;B`D=&AI<RT^861D<F5S<RX*("`@("`@("`D=&AI<RT^861D<F5S<R`]
M('!R96=?<F5P;&%C92@G+UQR/UQN+R<L(")<<EQN(BP@)'1H:7,M/F%D9')E
M<W,I.PH@("`@("`@("1T:&ES+3YA9&1R97-S(#T@<')E9U]R97!L86-E*"<O
M7')<;BA<='P@*2LO)RP@)R`G+"`D=&AI<RT^861D<F5S<RD["@H@("`@("`@
M('=H:6QE("@D=&AI<RT^861D<F5S<R`]("1T:&ES+3Y?<W!L:71!9&1R97-S
M97,H)'1H:7,M/F%D9')E<W,I*3L*"B`@("`@("`@:68@*"1T:&ES+3YA9&1R
M97-S(#T]/2!F86QS92!\?"!I<W-E="@D=&AI<RT^97)R;W(I*2!["B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D=&AI<RT^97)R;W(I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@5F%L:61A=&4@96%C:"!A9&1R97-S(&EN9&EV:61U
M86QL>2X@($EF('=E(&5N8V]U;G1E<B!A;B!I;G9A;&ED"B`@("`@("`@+R\@
M861D<F5S<RP@<W1O<"!I=&5R871I;F<@86YD(')E='5R;B!A;B!E<G)O<B!I
M;6UE9&EA=&5L>2X*("`@("`@("!F;W)E86-H("@D=&AI<RT^861D<F5S<V5S
M(&%S("1A9&1R97-S*2!["B`@("`@("`@("`@("1V86QI9"`]("1T:&ES+3Y?
M=F%L:61A=&5!9&1R97-S*"1A9&1R97-S*3L*"B`@("`@("`@("`@(&EF("@D
M=F%L:60@/3T](&9A;'-E('Q\(&ES<V5T*"1T:&ES+3YE<G)O<BDI('L*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PH@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'1H:7,M/F5R<F]R
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"$D=&AI<RT^;F5S
M=$=R;W5P<RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-T<G5C='5R92`]
M(&%R<F%Y7VUE<F=E*"1T:&ES+3YS=')U8W1U<F4L("1V86QI9"D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1R=6-T
M=7)E6UT@/2`D=F%L:60["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=&AI<RT^<W1R=6-T=7)E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4W!L:71S(&%N(&%D9')E<W,@:6YT;R!S97!A<F%T92!A9&1R97-S
M97,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A9&1R97-S(%1H92!A9&1R97-S97,@=&\@<W!L:70N"B`@
M("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<W!L:71!9&1R97-S97,H)&%D9')E<W,I"B`@
M("!["B`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^;&EM:70I("8F(&-O=6YT
M*"1T:&ES+3YA9&1R97-S97,I(#T]("1T:&ES+3YL:6UI="D@>PH@("`@("`@
M("`@("!R971U<FX@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/E]I<T=R;W5P*"1A9&1R97-S*2`F)B`A:7-S970H)'1H:7,M/F5R<F]R*2D@
M>PH@("`@("`@("`@("`D<W!L:71?8VAA<B`]("<[)SL*("`@("`@("`@("`@
M)&ES7V=R;W5P("`@/2!T<G5E.PH@("`@("`@('T@96QS96EF("@A:7-S970H
M)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("`D<W!L:71?8VAA<B`]("<L
M)SL*("`@("`@("`@("`@)&ES7V=R;W5P("`@/2!F86QS93L*("`@("`@("!]
M(&5L<V5I9B`H:7-S970H)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!3<&QI="!T:&4@
M<W1R:6YG(&)A<V5D(&]N('1H92!A8F]V92!T96X@;W(@<V\@;&EN97,N"B`@
M("`@("`@)'!A<G1S("`](&5X<&QO9&4H)'-P;&ET7V-H87(L("1A9&1R97-S
M*3L*("`@("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T
M<RP@)'-P;&ET7V-H87(I.PH*("`@("`@("`O+R!)9B!A(&=R;W5P+BXN"B`@
M("`@("`@:68@*"1I<U]G<F]U<"D@>PH@("`@("`@("`@("`O+R!)9B`D<W1R
M:6YG(&1O97,@;F]T(&-O;G1A:6X@82!C;VQO;B!O=71S:61E(&]F"B`@("`@
M("`@("`@("\O(&)R86-K971S+W%U;W1E<R!E=&,@=&AE;B!S;VUE=&AI;F<G
M<R!F=6)A<BX*"B`@("`@("`@("`@("\O($9I<G-T(&-H96-K('1H97)E)W,@
M82!C;VQO;B!A="!A;&PZ"B`@("`@("`@("`@(&EF("AS=')P;W,H)'-T<FEN
M9RP@)SHG*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1T:&ES+3YE
M<G)O<B`]("=);G9A;&ED(&%D9')E<W,Z("<@+B`D<W1R:6YG.PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R!.;W<@8VAE8VL@:70G<R!O=71S:61E(&]F(&)R86-K971S+W%U
M;W1E<SH*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W-P;&ET0VAE8VLH97AP
M;&]D92@G.B<L("1S=')I;F<I+"`G.B<I*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%=E
M(&UU<W0@:&%V92!A(&=R;W5P(&%T('1H:7,@<&]I;G0L('-O(&EN8W)E87-E
M('1H92!C;W5N=&5R.@H@("`@("`@("`@("`D=&AI<RT^;G5M7V=R;W5P<RLK
M.PH@("`@("`@('T*"B`@("`@("`@+R\@)'-T<FEN9R!N;W<@8V]N=&%I;G,@
M=&AE(&9I<G-T(&9U;&P@861D<F5S<R]G<F]U<"X*("`@("`@("`O+R!!9&0@
M=&\@=&AE(&%D9')E<W-E<R!A<G)A>2X*("`@("`@("`D=&AI<RT^861D<F5S
M<V5S6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G861D<F5S<R<@/3X@=')I;2@D<W1R:6YG*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G9W)O=7`G("`@/3X@)&ES7V=R;W5P
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@
M("`@+R\@4F5M;W9E('1H92!N;W<@<W1O<F5D(&%D9')E<W,@9G)O;2!T:&4@
M:6YI=&EA;"!L:6YE+"!T:&4@*S$*("`@("`@("`O+R!I<R!T;R!A8V-O=6YT
M(&9O<B!T:&4@97AP;&]D92!C:&%R86-T97(N"B`@("`@("`@)&%D9')E<W,@
M/2!T<FEM*'-U8G-T<B@D861D<F5S<RP@<W1R;&5N*"1S=')I;F<I("L@,2DI
M.PH*("`@("`@("`O+R!)9B!T:&4@;F5X="!C:&%R(&ES(&$@8V]M;6$@86YD
M('1H:7,@=V%S(&$@9W)O=7`L('1H96X*("`@("`@("`O+R!T:&5R92!A<F4@
M;6]R92!A9&1R97-S97,L(&]T:&5R=VES92P@:68@=&AE<F4@87)E(&%N>2!M
M;W)E"B`@("`@("`@+R\@8VAA<G,L('1H96X@=&AE<F4@:7,@86YO=&AE<B!A
M9&1R97-S+@H@("`@("`@(&EF("@D:7-?9W)O=7`@)B8@<W5B<W1R*"1A9&1R
M97-S+"`P+"`Q*2`]/2`G+"<I>PH@("`@("`@("`@("`D861D<F5S<R`]('1R
M:6TH<W5B<W1R*"1A9&1R97-S+"`Q*2D["B`@("`@("`@("`@(')E='5R;B`D
M861D<F5S<SL*"B`@("`@("`@?2!E;'-E:68@*'-T<FQE;B@D861D<F5S<RD@
M/B`P*2!["B`@("`@("`@("`@(')E='5R;B`D861D<F5S<SL*"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@('T*"B`@
M("`@("`@+R\@268@>6]U(&=O="!H97)E('1H96X@<V]M971H:6YG)W,@;V9F
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0VAE8VMS(&9O<B!A(&=R;W5P(&%T('1H92!S=&%R="!O9B!T:&4@<W1R:6YG
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("H@0'!A<F%M
M('-T<FEN9R`D861D<F5S<R!4:&4@861D<F5S<R!T;R!C:&5C:RX*("`@("`J
M($!R971U<FX@8F]O;&5A;B!7:&5T:&5R(&]R(&YO="!T:&5R92!I<R!A(&=R
M;W5P(&%T('1H92!S=&%R="!O9B!T:&4@<W1R:6YG+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?:7-'<F]U<"@D861D<F5S<RD*("`@('L*("`@("`@("`O+R!&
M:7)S="!C;VUM82!N;W0@:6X@<75O=&5S+"!A;F=L97,@;W(@97-C87!E9#H*
M("`@("`@("`D<&%R=',@(#T@97AP;&]D92@G+"<L("1A9&1R97-S*3L*("`@
M("`@("`D<W1R:6YG(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)RPG
M*3L*"B`@("`@("`@+R\@3F]W('=E(&AA=F4@=&AE(&9I<G-T(&%D9')E<W,L
M('=E(&-A;B!R96QI86)L>2!C:&5C:R!F;W(@80H@("`@("`@("\O(&=R;W5P
M(&)Y('-E87)C:&EN9R!F;W(@82!C;VQO;B!T:&%T)W,@;F]T(&5S8V%P960@
M;W(@:6X*("`@("`@("`O+R!Q=6]T97,@;W(@86YG;&4@8G)A8VME=',N"B`@
M("`@("`@:68@*&-O=6YT*"1P87)T<R`](&5X<&QO9&4H)SHG+"`D<W1R:6YG
M*2D@/B`Q*2!["B`@("`@("`@("`@("1S=')I;F<R(#T@)'1H:7,M/E]S<&QI
M=$-H96-K*"1P87)T<RP@)SHG*3L*("`@("`@("`@("`@<F5T=7)N("@D<W1R
M:6YG,B`A/3T@)'-T<FEN9RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($$@8V]M;6]N(&9U;F-T:6]N('1H870@=VEL;"!C:&5C:R!A;B!E>'!L
M;V1E9"!S=')I;F<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B!`<&%R86T@87)R87D@)'!A<G1S(%1H92!E>&QO9&5D('-T<FEN9RX*
M("`@("`J($!P87)A;2!S=')I;F<@)&-H87(@(%1H92!C:&%R('1H870@=V%S
M(&5X<&QO9&5D(&]N+@H@("`@("H@0')E='5R;B!M:7AE9"!&86QS92!I9B!T
M:&4@<W1R:6YG(&-O;G1A:6YS('5N8VQO<V5D('%U;W1E<R]B<F%C:V5T<RP@
M;W(@=&AE('-T<FEN9R!O;B!S=6-C97-S+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!?<W!L:71#:&5C:R@D<&%R=',L("1C:&%R*0H@("`@>PH@("`@("`@("1S
M=')I;F<@/2`D<&%R='-;,%T["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M(&-O=6YT*"1P87)T<RD[("1I*RLI('L*("`@("`@("`@("`@:68@*"1T:&ES
M+3Y?:&%S56YC;&]S9611=6]T97,H)'-T<FEN9RD*("`@("`@("`@("`@("`@
M('Q\("1T:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<R@D<W1R:6YG+"`G/#XG
M*0H@("`@("`@("`@("`@("`@?'P@)'1H:7,M/E]H87-5;F-L;W-E9$)R86-K
M971S*"1S=')I;F<L("=;72<I"B`@("`@("`@("`@("`@("!\?"`D=&AI<RT^
M7VAA<U5N8VQO<V5D0G)A8VME=',H)'-T<FEN9RP@)R@I)RD*("`@("`@("`@
M("`@("`@('Q\('-U8G-T<B@D<W1R:6YG+"`M,2D@/3T@)UQ<)RD@>PH@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1P87)T<ULD:2`K(#%=*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1S=')I;F<@/2`D<W1R:6YG("X@)&-H87(@+B`D
M<&%R='-;)&D@*R`Q73L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R(#T@)TEN=F%L:60@861D<F5S
M<R!S<&5C+B!5;F-L;W-E9"!B<F%C:V5T(&]R('%U;W1E<R<["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/FEN
M9&5X(#T@)&D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1S=')I;F<["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#:&5C:W,@:68@82!S=')I;F<@:&%S(&%N('5N8VQO
M<V5D('%U;W1E<R!O<B!N;W0N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@5&AE('-T<FEN9R!T
M;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A;B!4<G5E(&EF('1H97)E
M(&%R92!U;F-L;W-E9"!Q=6]T97,@:6YS:61E('1H92!S=')I;F<L(&9A;'-E
M(&]T:&5R=VES92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VAA<U5N8VQO<V5D
M475O=&5S*"1S=')I;F<I"B`@("!["B`@("`@("`@)'-T<FEN9R`@("`@/2!E
M>'!L;V1E*"<B)RP@)'-T<FEN9RD["B`@("`@("`@)'-T<FEN9U]C;G0@/2!C
M;W5N="@D<W1R:6YG*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@*&-O
M=6YT*"1S=')I;F<I("T@,2D[("1I*RLI"B`@("`@("`@("`@(&EF("AS=6)S
M='(H)'-T<FEN9ULD:5TL("TQ*2`]/2`G7%PG*0H@("`@("`@("`@("`@("`@
M)'-T<FEN9U]C;G0M+3L*"B`@("`@("`@<F5T=7)N("@D<W1R:6YG7V-N="`E
M(#(@/3T](#`I.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS(&EF(&$@
M<W1R:6YG(&AA<R!A;B!U;F-L;W-E9"!B<F%C:V5T<R!O<B!N;W0N($E-4$]2
M5$%.5#H*("`@("`J(%1H:7,@9G5N8W1I;VX@:&%N9&QE<R!B;W1H(&%N9VQE
M(&)R86-K971S(&%N9"!S<75A<F4@8G)A8VME=',["B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@
M5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!P87)A;2!S=')I;F<@)&-H
M87)S("!4:&4@8VAA<F%C=&5R<R!T;R!C:&5C:R!F;W(N"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@5')U92!I9B!T:&5R92!A<F4@=6YC;&]S960@8G)A8VME
M=',@:6YS:61E('1H92!S=')I;F<L(&9A;'-E(&]T:&5R=VES92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7VAA<U5N8VQO<V5D0G)A8VME=',H)'-T<FEN9RP@
M)&-H87)S*0H@("`@>PH@("`@("`@("1N=6U?86YG;&5?<W1A<G0@/2!S=6)S
M=')?8V]U;G0H)'-T<FEN9RP@)&-H87)S6S!=*3L*("`@("`@("`D;G5M7V%N
M9VQE7V5N9"`@(#T@<W5B<W1R7V-O=6YT*"1S=')I;F<L("1C:&%R<ULQ72D[
M"@H@("`@("`@("1T:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<U-U8B@D<W1R
M:6YG+"`D;G5M7V%N9VQE7W-T87)T+"`D8VAA<G-;,%TI.PH@("`@("`@("1T
M:&ES+3Y?:&%S56YC;&]S961"<F%C:V5T<U-U8B@D<W1R:6YG+"`D;G5M7V%N
M9VQE7V5N9"P@)&-H87)S6S%=*3L*"B`@("`@("`@:68@*"1N=6U?86YG;&5?
M<W1A<G0@/"`D;G5M7V%N9VQE7V5N9"D@>PH@("`@("`@("`@("`D=&AI<RT^
M97)R;W(@/2`G26YV86QI9"!A9&1R97-S('-P96,N(%5N;6%T8VAE9"!Q=6]T
M92!O<B!B<F%C:V5T("@G("X@)&-H87)S("X@)RDG.PH@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N("@D;G5M7V%N9VQE7W-T87)T(#X@)&YU;5]A;F=L95]E;F0I.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%-U8B!F=6YC=&EO;B!T:&%T
M(&ES('5S960@;VYL>2!B>2!H87-5;F-L;W-E9$)R86-K971S*"DN"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=')I;F<@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!P87)A;2!I
M;G1E9V5R("8D;G5M("`@(%1H92!N=6UB97(@;V8@;V-C=7)E;F-E<RX*("`@
M("`J($!P87)A;2!S=')I;F<@)&-H87(@("!4:&4@8VAA<F%C=&5R('1O(&-O
M=6YT+@H@("`@("H@0')E='5R;B!I;G1E9V5R(%1H92!N=6UB97(@;V8@;V-C
M=7)E;F-E<R!O9B`D8VAA<B!I;B`D<W1R:6YG+"!A9&IU<W1E9"!F;W(@8F%C
M:W-L87-H97,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]H87-5;F-L;W-E9$)R
M86-K971S4W5B*"1S=')I;F<L("8D;G5M+"`D8VAA<BD*("`@('L*("`@("`@
M("`D<&%R=',@/2!E>'!L;V1E*"1C:&%R+"`D<W1R:6YG*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<&%R=',I.R`D:2LK*7L*("`@("`@
M("`@("`@:68@*'-U8G-T<B@D<&%R='-;)&E=+"`M,2D@/3T@)UQ<)R!\?"`D
M=&AI<RT^7VAA<U5N8VQO<V5D475O=&5S*"1P87)T<ULD:5TI*0H@("`@("`@
M("`@("`@("`@)&YU;2TM.PH@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1S
M6R1I("L@,5TI*0H@("`@("`@("`@("`@("`@)'!A<G1S6R1I("L@,5T@/2`D
M<&%R='-;)&E=("X@)&-H87(@+B`D<&%R='-;)&D@*R`Q73L*("`@("`@("!]
M"@H@("`@("`@(')E='5R;B`D;G5M.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1G5N8W1I;VX@=&\@8F5G:6X@8VAE8VMI;F<@=&AE(&%D9')E<W,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1A9&1R97-S(%1H92!A9&1R97-S('1O('9A;&ED871E+@H@("`@("H@0')E
M='5R;B!M:7AE9"!&86QS92!O;B!F86EL=7)E+"!O<B!A('-T<G5C='5R960@
M87)R87D@;V8@861D<F5S<R!I;F9O<FUA=&EO;B!O;B!S=6-C97-S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&5!9&1R97-S*"1A9&1R97-S*0H@
M("`@>PH@("`@("`@("1I<U]G<F]U<"`](&9A;'-E.PH@("`@("`@("1A9&1R
M97-S97,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&%D9')E<W-;)V=R;W5P
M)UTI('L*("`@("`@("`@("`@)&ES7V=R;W5P(#T@=')U93L*"B`@("`@("`@
M("`@("\O($=E="!T:&4@9W)O=7`@<&%R="!O9B!T:&4@;F%M90H@("`@("`@
M("`@("`D<&%R=',@("`@(#T@97AP;&]D92@G.B<L("1A9&1R97-S6R=A9&1R
M97-S)UTI.PH@("`@("`@("`@("`D9W)O=7!N86UE(#T@)'1H:7,M/E]S<&QI
M=$-H96-K*"1P87)T<RP@)SHG*3L*("`@("`@("`@("`@)'-T<G5C='5R92`]
M(&%R<F%Y*"D["@H@("`@("`@("`@("`O+R!!;F0@=F%L:61A=&4@=&AE(&=R
M;W5P('!A<G0@;V8@=&AE(&YA;64N"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]V86QI9&%T95!H<F%S92@D9W)O=7!N86UE*2E["B`@("`@("`@("`@("`@
M("`D=&AI<RT^97)R;W(@/2`G1W)O=7`@;F%M92!D:60@;F]T('9A;&ED871E
M+B<["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!$;VXG="!I;F-L=61E(&=R
M;W5P<R!I9B!W92!A<F4@;F]T(&YE<W1I;F<*("`@("`@("`@("`@("`@("\O
M('1H96TN(%1H:7,@879O:61S(')E='5R;FEN9R!I;G9A;&ED(&%D9')E<W-E
M<RX*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;F5S=$=R;W5P<RD@>PH@
M("`@("`@("`@("`@("`@("`@("1S=')U8W1U<F4@/2!N97<@<W1D0VQA<W,[
M"B`@("`@("`@("`@("`@("`@("`@)'-T<G5C='5R92T^9W)O=7!N86UE(#T@
M)&=R;W5P;F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@)&%D9')E<W-;)V%D9')E<W,G72`](&QT<FEM*'-U8G-T
M<B@D861D<F5S<ULG861D<F5S<R==+"!S=')L96XH)&=R;W5P;F%M92`N("<Z
M)RDI*3L*("`@("`@("!]"@H@("`@("`@("\O($EF(&$@9W)O=7`@=&AE;B!S
M<&QI="!O;B!C;VUM82!A;F0@<'5T(&EN=&\@86X@87)R87DN"B`@("`@("`@
M+R\@3W1H97)W:7-E+"!*=7-T('!U="!T:&4@=VAO;&4@861D<F5S<R!I;B!A
M;B!A<G)A>2X*("`@("`@("!I9B`H)&ES7V=R;W5P*2!["B`@("`@("`@("`@
M('=H:6QE("AS=')L96XH)&%D9')E<W-;)V%D9')E<W,G72D@/B`P*2!["B`@
M("`@("`@("`@("`@("`D<&%R=',@("`@("`@/2!E>'!L;V1E*"<L)RP@)&%D
M9')E<W-;)V%D9')E<W,G72D["B`@("`@("`@("`@("`@("`D861D<F5S<V5S
M6UT@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G+"<I.PH@("`@("`@
M("`@("`@("`@)&%D9')E<W-;)V%D9')E<W,G72`]('1R:6TH<W5B<W1R*"1A
M9&1R97-S6R=A9&1R97-S)UTL('-T<FQE;BAE;F0H)&%D9')E<W-E<RD@+B`G
M+"<I*2D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D861D<F5S<V5S6UT@/2`D861D<F5S<ULG861D<F5S<R==.PH@("`@
M("`@('T*"B`@("`@("`@+R\@0VAE8VL@=&AA="`D861D<F5S<V5S(&ES('-E
M="P@:68@861D<F5S<R!L:6ME('1H:7,Z"B`@("`@("`@+R\@1W)O=7!N86UE
M.CL*("`@("`@("`O+R!4:&5N(&5R<F]R<R!W97)E(&%P<&5A<FEN9RX*("`@
M("`@("!I9B`H(6-O=6YT*"1A9&1R97-S97,I*7L*("`@("`@("`@("`@)'1H
M:7,M/F5R<F]R(#T@)T5M<'1Y(&=R;W5P+B<["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\O(%1R:6T@=&AE('=H:71E
M<W!A8V4@9G)O;2!A;&P@;V8@=&AE(&%D9')E<W,@<W1R:6YG<RX*("`@("`@
M("!A<G)A>5]M87`H)W1R:6TG+"`D861D<F5S<V5S*3L*"B`@("`@("`@+R\@
M5F%L:61A=&4@96%C:"!M86EL8F]X+@H@("`@("`@("\O($9O<FUA="!C;W5L
M9"!B92!O;F4@;V8Z(&YA;64@/&=E97IE<D!D;VUA:6XN8V]M/@H@("`@("`@
M("\O("`@("`@("`@("`@("`@("`@("`@("`@(&=E97IE<D!D;VUA:6XN8V]M
M"B`@("`@("`@+R\@("`@("`@("`@("`@("`@("`@("`@("`@9V5E>F5R"B`@
M("`@("`@+R\@+BXN(&]R(&%N>2!O=&AE<B!F;W)M870@=F%L:60@8GD@4D9#
M(#@R,BX*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D861D<F5S
M<V5S*3L@)&DK*RD@>PH@("`@("`@("`@("!I9B`H(21T:&ES+3YV86QI9&%T
M94UA:6QB;W@H)&%D9')E<W-E<ULD:5TI*2!["B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/F5R<F]R*2D@>PH@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YE<G)O<B`]("=686QI9&%T:6]N(&9A:6QE9"!F;W(Z("<@+B`D
M861D<F5S<V5S6R1I73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@+R\@3F5S=&5D(&9O<FUA=`H@("`@("`@(&EF("@D=&AI<RT^;F5S
M=$=R;W5P<RD@>PH@("`@("`@("`@("!I9B`H)&ES7V=R;W5P*2!["B`@("`@
M("`@("`@("`@("`D<W1R=6-T=7)E+3YA9&1R97-S97,@/2`D861D<F5S<V5S
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-T<G5C
M='5R92`]("1A9&1R97-S97-;,%T["B`@("`@("`@("`@('T*"B`@("`@("`@
M+R\@1FQA="!F;W)M870*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!I
M9B`H)&ES7V=R;W5P*2!["B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E(#T@
M87)R87E?;65R9V4H)'-T<G5C='5R92P@)&%D9')E<W-E<RD["B`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<W1R=6-T=7)E(#T@)&%D
M9')E<W-E<SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T
M=7)N("1S=')U8W1U<F4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO
M;B!T;R!V86QI9&%T92!A('!H<F%S92X*("`@("`J"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)'!H<F%S92!4:&4@<&AR
M87-E('1O(&-H96-K+@H@("`@("H@0')E='5R;B!B;V]L96%N(%-U8V-E<W,@
M;W(@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E4&AR
M87-E*"1P:')A<V4I"B`@("!["B`@("`@("`@+R\@4W!L:71S(&]N(&]N92!O
M<B!M;W)E(%1A8B!O<B!S<&%C92X*("`@("`@("`D<&%R=',@/2!P<F5G7W-P
M;&ET*"<O6R!<7'@P.5TK+R<L("1P:')A<V4L("TQ+"!04D5'7U-03$E47TY/
M7T5-4%19*3L*"B`@("`@("`@)'!H<F%S95]P87)T<R`](&%R<F%Y*"D["B`@
M("`@("`@=VAI;&4@*&-O=6YT*"1P87)T<RD@/B`P*7L*("`@("`@("`@("`@
M)'!H<F%S95]P87)T<UM=(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@
M)R`G*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)'1H:7,M/FEN
M9&5X("L@,3L@)&DK*RD*("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1P
M87)T<RD["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D<&AR87-E7W!A
M<G1S(&%S("1P87)T*2!["B`@("`@("`@("`@("\O($EF('%U;W1E9"!S=')I
M;F<Z"B`@("`@("`@("`@(&EF("AS=6)S='(H)'!A<G0L(#`L(#$I(#T]("<B
M)RD@>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E475O
M=&5D4W1R:6YG*"1P87)T*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!/=&AE<G=I
M<V4@:70G<R!A;B!A=&]M.@H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?=F%L
M:61A=&5!=&]M*"1P87)T*2D@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC
M=&EO;B!T;R!V86QI9&%T92!A;B!A=&]M('=H:6-H(&9R;VT@<F9C.#(R(&ES
M.@H@("`@("H@871O;2`](#$J/&%N>2!#2$%2(&5X8V5P="!S<&5C:6%L<RP@
M4U!!0T4@86YD($-43',^"B`@("`@*@H@("`@("H@268@=F%L:61A=&EO;B`H
M)'1H:7,M/G9A;&ED871E*2!H87,@8F5E;B!T=7)N960@;V9F+"!T:&5N"B`@
M("`@*B!V86QI9&%T94%T;VTH*2!D;V5S;B=T(&%C='5A;&QY(&-H96-K(&%N
M>71H:6YG+B!4:&ES(&ES('-O('1H870@>6]U"B`@("`@*B!C86X@<W!L:70@
M82!L:7-T(&]F(&%D9')E<W-E<R!U<"!B969O<F4@96YC;V1I;F<@<&5R<V]N
M86P@;F%M97,*("`@("`J("AU;6QA=71S+"!E=&,N*2P@9F]R(&5X86UP;&4N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1A=&]M(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X@4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!?=F%L:61A=&5!=&]M*"1A=&]M*0H@("`@>PH@("`@("`@(&EF
M("@A)'1H:7,M/G9A;&ED871E*2!["B`@("`@("`@("`@("\O(%9A;&ED871I
M;VX@:&%S(&)E96X@='5R;F5D(&]F9CL@87-S=6UE('1H92!A=&]M(&ES(&]K
M87DN"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@+R\@0VAE8VL@9F]R(&%N>2!C:&%R(&9R;VT@05-#24D@,"`M($%30TE)
M(#$R-PH@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY;7%QX,#`M7%QX-T5=
M*R0O:2<L("1A=&]M+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R('-P96-I
M86QS.@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O6UU;*"D\/D`L.UQ<.B(N
M(%TO)RP@)&%T;VTI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@("\O($-H96-K(&9O<B!C;VYT<F]L(&-H87)A8W1E
M<G,@*$%30TE)(#`M,S$I.@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O6UQ<
M>#`P+5Q<>#%&72LO)RP@)&%T;VTI*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L:61A=&4@<75O=&5D('-T
M<FEN9RP@=VAI8V@@:7,Z"B`@("`@*B!Q=6]T960M<W1R:6YG(#T@/"(^("HH
M<71E>'0O<75O=&5D+7!A:7(I(#PB/@H@("`@("H*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("H@0'!A<F%M('-T<FEN9R`D<7-T<FEN9R!4:&4@<W1R
M:6YG('1O(&-H96-K"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@4W5C8V5S<R!O
M<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&51=6]T
M9613=')I;F<H)'%S=')I;F<I"B`@("!["B`@("`@("`@+R\@3&5A9&EN9R!A
M;F0@=')A:6QI;F<@(@H@("`@("`@("1Q<W1R:6YG(#T@<W5B<W1R*"1Q<W1R
M:6YG+"`Q+"`M,2D["@H@("`@("`@("\O(%!E<F9O<FT@8VAE8VLL(')E;6]V
M:6YG('%U;W1E9"!C:&%R86-T97)S(&9I<G-T+@H@("`@("`@(')E='5R;B`A
M<')E9U]M871C:"@G+UM<>#!$7%Q<7")=+R<L('!R96=?<F5P;&%C92@G+UQ<
M7%PN+R<L("<G+"`D<7-T<FEN9RDI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M1G5N8W1I;VX@=&\@=F%L:61A=&4@82!M86EL8F]X+"!W:&EC:"!I<SH*("`@
M("`J(&UA:6QB;W@@/2`@(&%D9'(M<W!E8R`@("`@("`@(#L@<VEM<&QE(&%D
M9')E<W,*("`@("`J("`@("`@("`@("`O('!H<F%S92!R;W5T92UA9&1R(#L@
M;F%M92!A;F0@<F]U=&4M861D<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@<W1R:6YG("8D;6%I;&)O>"!4:&4@<W1R:6YG
M('1O(&-H96-K+@H@("`@("H@0')E='5R;B!B;V]L96%N(%-U8V-E<W,@;W(@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@=F%L:61A=&5-86EL8F]X
M*"8D;6%I;&)O>"D*("`@('L*("`@("`@("`O+R!!(&-O=7!L92!O9B!D969A
M=6QT<RX*("`@("`@("`D<&AR87-E("`]("<G.PH@("`@("`@("1C;VUM96YT
M(#T@)R<["B`@("`@("`@)&-O;6UE;G1S(#T@87)R87DH*3L*"B`@("`@("`@
M+R\@0V%T8V@@86YY(%)&0S@R,B!C;VUM96YT<R!A;F0@<W1O<F4@=&AE;2!S
M97!A<F%T96QY+@H@("`@("`@("1?;6%I;&)O>"`]("1M86EL8F]X.PH@("`@
M("`@('=H:6QE("AS=')L96XH=')I;2@D7VUA:6QB;W@I*2`^(#`I('L*("`@
M("`@("`@("`@)'!A<G1S(#T@97AP;&]D92@G*"<L("1?;6%I;&)O>"D["B`@
M("`@("`@("`@("1B969O<F5?8V]M;65N="`]("1T:&ES+3Y?<W!L:71#:&5C
M:R@D<&%R=',L("<H)RD["B`@("`@("`@("`@(&EF("@D8F5F;W)E7V-O;6UE
M;G0@(3T@)%]M86EL8F]X*2!["B`@("`@("`@("`@("`@("`O+R!&:7)S="!C
M:&%R('-H;W5L9"!B92!A("@N"B`@("`@("`@("`@("`@("`D8V]M;65N="`@
M("`]('-U8G-T<BAS=')?<F5P;&%C92@D8F5F;W)E7V-O;6UE;G0L("<G+"`D
M7VUA:6QB;W@I+"`Q*3L*("`@("`@("`@("`@("`@("1P87)T<R`@("`@(#T@
M97AP;&]D92@G*2<L("1C;VUM96YT*3L*("`@("`@("`@("`@("`@("1C;VUM
M96YT("`@(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1P87)T<RP@)RDG*3L*("`@
M("`@("`@("`@("`@("1C;VUM96YT<UM=(#T@)&-O;6UE;G0["@H@("`@("`@
M("`@("`@("`@+R\@*S$@:7,@9F]R('1H92!T<F%I;&EN9R`I"B`@("`@("`@
M("`@("`@("`D7VUA:6QB;W@@("`]('-U8G-T<B@D7VUA:6QB;W@L('-T<G!O
M<R@D7VUA:6QB;W@L("1C;VUM96YT*2MS=')L96XH)&-O;6UE;G0I*S$I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&9O<F5A8V@@*"1C;VUM
M96YT<R!A<R`D8V]M;65N="D@>PH@("`@("`@("`@("`D;6%I;&)O>"`]('-T
M<E]R97!L86-E*"(H)&-O;6UE;G0I(BP@)R<L("1M86EL8F]X*3L*("`@("`@
M("!]"@H@("`@("`@("1M86EL8F]X(#T@=')I;2@D;6%I;&)O>"D["@H@("`@
M("`@("\O($-H96-K(&9O<B!N86UE("L@<F]U=&4M861D<@H@("`@("`@(&EF
M("AS=6)S='(H)&UA:6QB;W@L("TQ*2`]/2`G/B<@)B8@<W5B<W1R*"1M86EL
M8F]X+"`P+"`Q*2`A/2`G/"<I('L*("`@("`@("`@("`@)'!A<G1S("`](&5X
M<&QO9&4H)SPG+"`D;6%I;&)O>"D["B`@("`@("`@("`@("1N86UE("`@/2`D
M=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G/"<I.PH*("`@("`@("`@("`@
M)'!H<F%S92`@("`@/2!T<FEM*"1N86UE*3L*("`@("`@("`@("`@)')O=71E
M7V%D9'(@/2!T<FEM*'-U8G-T<B@D;6%I;&)O>"P@<W1R;&5N*"1N86UE+B<\
M)RDL("TQ*2D["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]V86QI9&%T95!H
M<F%S92@D<&AR87-E*2`]/3T@9F%L<V4@?'P@*"1R;W5T95]A9&1R(#T@)'1H
M:7,M/E]V86QI9&%T95)O=71E061D<B@D<F]U=&5?861D<BDI(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("\O($]N;'D@9V]T(&%D9'(M<W!E8PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("\O($9I<G-T('-N:7`@86YG;&4@8G)A8VME
M=',@:68@<')E<V5N="X*("`@("`@("`@("`@:68@*'-U8G-T<B@D;6%I;&)O
M>"P@,"P@,2D@/3T@)SPG("8F('-U8G-T<B@D;6%I;&)O>"P@+3$I(#T]("<^
M)RD@>PH@("`@("`@("`@("`@("`@)&%D9')?<W!E8R`]('-U8G-T<B@D;6%I
M;&)O>"P@,2P@+3$I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&%D9')?<W!E8R`]("1M86EL8F]X.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!I9B`H*"1A9&1R7W-P96,@/2`D=&AI<RT^7W9A;&ED871E
M061D<E-P96,H)&%D9')?<W!E8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("`O+R!#;VYS=')U8W0@=&AE(&]B:F5C="!T:&%T('=I;&P@8F4@
M<F5T=7)N960N"B`@("`@("`@)&UB;W@@/2!N97<@<W1D0VQA<W,H*3L*"B`@
M("`@("`@+R\@061D('1H92!P:')A<V4@*&5V96X@:68@96UP='DI(&%N9"!C
M;VUM96YT<PH@("`@("`@("1M8F]X+3YP97)S;VYA;"`]("1P:')A<V4["B`@
M("`@("`@)&UB;W@M/F-O;6UE;G0@(#T@:7-S970H)&-O;6UE;G1S*2`_("1C
M;VUM96YT<R`Z(&%R<F%Y*"D["@H@("`@("`@(&EF("AI<W-E="@D<F]U=&5?
M861D<BDI('L*("`@("`@("`@("`@)&UB;W@M/FUA:6QB;W@@/2`D<F]U=&5?
M861D<ELG;&]C86Q?<&%R="==.PH@("`@("`@("`@("`D;6)O>"T^:&]S="`@
M("`]("1R;W5T95]A9&1R6R=D;VUA:6XG73L*("`@("`@("`@("`@)')O=71E
M7V%D9');)V%D;"==("$]/2`G)R`_("1M8F]X+3YA9&P@/2`D<F]U=&5?861D
M<ELG861L)UT@.B`G)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M;6)O>"T^;6%I;&)O>"`]("1A9&1R7W-P96-;)VQO8V%L7W!A<G0G73L*("`@
M("`@("`@("`@)&UB;W@M/FAO<W0@("`@/2`D861D<E]S<&5C6R=D;VUA:6XG
M73L*("`@("`@("!]"@H@("`@("`@("1M86EL8F]X(#T@)&UB;W@["B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&ES(&9U
M;F-T:6]N('9A;&ED871E<R!A(')O=71E+6%D9'(@=VAI8V@@:7,Z"B`@("`@
M*B!R;W5T92UA9&1R(#T@(CPB(%MR;W5T95T@861D<BUS<&5C("(^(@H@("`@
M("H*("`@("`J($%N9VQE(&)R86-K971S(&AA=F4@86QR96%D>2!B965N(')E
M;6]V960@870@=&AE('!O:6YT(&]F"B`@("`@*B!G971T:6YG('1O('1H:7,@
M9G5N8W1I;VXN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1R;W5T95]A9&1R(%1H92!S=')I;F<@=&\@8VAE
M8VLN"B`@("`@*B!`<F5T=7)N(&UI>&5D($9A;'-E(&]N(&9A:6QU<F4L(&]R
M(&%N(&%R<F%Y(&-O;G1A:6YI;F<@=F%L:61A=&5D(&%D9')E<W,O<F]U=&4@
M:6YF;W)M871I;VX@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N8W1I;VX@
M7W9A;&ED871E4F]U=&5!9&1R*"1R;W5T95]A9&1R*0H@("`@>PH@("`@("`@
M("\O($-H96-K(&9O<B!C;VQO;BX*("`@("`@("!I9B`H<W1R<&]S*"1R;W5T
M95]A9&1R+"`G.B<I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<&%R=',@
M/2!E>'!L;V1E*"<Z)RP@)')O=71E7V%D9'(I.PH@("`@("`@("`@("`D<F]U
M=&4@/2`D=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G.B<I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R;W5T92`]("1R;W5T95]A9&1R.PH@
M("`@("`@('T*"B`@("`@("`@+R\@268@)')O=71E(&ES('-A;64@87,@)')O
M=71E7V%D9'(@=&AE;B!T:&4@8V]L;VX@=V%S(&EN"B`@("`@("`@+R\@<75O
M=&5S(&]R(&)R86-K971S(&]R+"!O9B!C;W5R<V4L(&YO;B!E>&ES=&5N="X*
M("`@("`@("!I9B`H)')O=71E(#T]/2`D<F]U=&5?861D<BE["B`@("`@("`@
M("`@('5N<V5T*"1R;W5T92D["B`@("`@("`@("`@("1A9&1R7W-P96,@/2`D
M<F]U=&5?861D<CL*("`@("`@("`@("`@:68@*"@D861D<E]S<&5C(#T@)'1H
M:7,M/E]V86QI9&%T94%D9')3<&5C*"1A9&1R7W-P96,I*2`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O(%9A;&ED871E(')O
M=71E('!A<G0N"B`@("`@("`@("`@(&EF("@H)')O=71E(#T@)'1H:7,M/E]V
M86QI9&%T95)O=71E*"1R;W5T92DI(#T]/2!F86QS92D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D861D<E]S<&5C(#T@<W5B<W1R*"1R;W5T95]A9&1R+"!S=')L96XH)')O
M=71E("X@)SHG*2D["@H@("`@("`@("`@("`O+R!686QI9&%T92!A9&1R+7-P
M96,@<&%R="X*("`@("`@("`@("`@:68@*"@D861D<E]S<&5C(#T@)'1H:7,M
M/E]V86QI9&%T94%D9')3<&5C*"1A9&1R7W-P96,I*2`]/3T@9F%L<V4I('L*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1R;W5T92DI('L*("`@("`@
M("`@("`@)')E='5R;ELG861L)UT@/2`D<F]U=&4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)')E='5R;ELG861L)UT@/2`G)SL*("`@("`@("!]
M"@H@("`@("`@("1R971U<FX@/2!A<G)A>5]M97)G92@D<F5T=7)N+"`D861D
M<E]S<&5C*3L*("`@("`@("!R971U<FX@)')E='5R;CL*("`@('T*"B`@("`O
M*BH*("`@("`J($9U;F-T:6]N('1O('9A;&ED871E(&$@<F]U=&4L('=H:6-H
M(&ES.@H@("`@("H@<F]U=&4@/2`Q(R@B0"(@9&]M86EN*2`B.B(*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@
M)')O=71E(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&UI
M>&5D($9A;'-E(&]N(&9A:6QU<F4L(&]R('1H92!V86QI9&%T960@)')O=71E
M(&]N('-U8V-E<W,N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V86QI9&%T95)O
M=71E*"1R;W5T92D*("`@('L*("`@("`@("`O+R!3<&QI="!O;B!C;VUM82X*
M("`@("`@("`D9&]M86EN<R`](&5X<&QO9&4H)RPG+"!T<FEM*"1R;W5T92DI
M.PH*("`@("`@("!F;W)E86-H("@D9&]M86EN<R!A<R`D9&]M86EN*2!["B`@
M("`@("`@("`@("1D;VUA:6X@/2!S=')?<F5P;&%C92@G0"<L("<G+"!T<FEM
M*"1D;VUA:6XI*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E
M1&]M86EN*"1D;VUA:6XI*2!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@)')O=71E.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N
M8W1I;VX@=&\@=F%L:61A=&4@82!D;VUA:6XL('1H;W5G:"!T:&ES(&ES(&YO
M="!Q=6ET92!W:&%T"B`@("`@*B!Y;W4@97AP96-T(&]F(&$@<W1R:6-T(&EN
M=&5R;F5T(&1O;6%I;BX*("`@("`J"B`@("`@*B!D;VUA:6X@/2!S=6(M9&]M
M86EN("HH(BXB('-U8BUD;VUA:6XI"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1D;VUA:6X@5&AE('-T<FEN
M9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I
M;'5R92P@;W(@=&AE('9A;&ED871E9"!D;VUA:6X@;VX@<W5C8V5S<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@7W9A;&ED871E1&]M86EN*"1D;VUA:6XI"B`@
M("!["B`@("`@("`@+R\@3F]T92!T:&4@9&EF9F5R96YT('5S92!O9B`D<W5B
M9&]M86EN<R!A;F0@)'-U8E]D;VUA:6YS"B`@("`@("`@)'-U8F1O;6%I;G,@
M/2!E>'!L;V1E*"<N)RP@)&1O;6%I;BD["@H@("`@("`@('=H:6QE("AC;W5N
M="@D<W5B9&]M86EN<RD@/B`P*2!["B`@("`@("`@("`@("1S=6)?9&]M86EN
M<UM=(#T@)'1H:7,M/E]S<&QI=$-H96-K*"1S=6)D;VUA:6YS+"`G+B<I.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^:6YD97@@*R`Q
M.R`D:2LK*0H@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)'-U8F1O;6%I
M;G,I.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C:"`H)'-U8E]D;VUA:6YS
M(&%S("1S=6)?9&]M86EN*2!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]V
M86QI9&%T95-U8F1O;6%I;BAT<FEM*"1S=6)?9&]M86EN*2DI"B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!-
M86YA9V5D('1O(&=E="!H97)E+"!S;R!R971U<FX@:6YP=70N"B`@("`@("`@
M<F5T=7)N("1D;VUA:6X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO
M;B!T;R!V86QI9&%T92!A('-U8F1O;6%I;CH*("`@("`J("`@<W5B9&]M86EN
M(#T@9&]M86EN+7)E9B`O(&1O;6%I;BUL:71E<F%L"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=6)D;VUA
M:6X@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@("`J($!R971U<FX@8F]O;&5A
M;B!3=6-C97-S(&]R(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]V
M86QI9&%T95-U8F1O;6%I;B@D<W5B9&]M86EN*0H@("`@>PH@("`@("`@(&EF
M("AP<F5G7VUA=&-H*"=\7EQ;*"XJ*5TD?"<L("1S=6)D;VUA:6XL("1A<G(I
M*7L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E1&QI=&5R86PH
M)&%R<ELQ72DI(')E='5R;B!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&5!=&]M*"1S=6)D;VUA:6XI
M*2!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O+R!';W0@:&5R
M92P@<V\@<F5T=7)N('-U8V-E<W-F=6PN"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A
M(&1O;6%I;B!L:71E<F%L.@H@("`@("H@("!D;VUA:6XM;&ET97)A;"`]("`B
M6R(@*BAD=&5X="`O('%U;W1E9"UP86ER*2`B72(*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&1L:71E<F%L
M(%1H92!S=')I;F<@=&\@8VAE8VLN"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M4W5C8V5S<R!O<B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L
M:61A=&5$;&ET97)A;"@D9&QI=&5R86PI"B`@("!["B`@("`@("`@<F5T=7)N
M("%P<F5G7VUA=&-H*"<O*"XI6UU;7'@P1%Q<7%Q=+R<L("1D;&ET97)A;"P@
M)&UA=&-H97,I("8F("1M871C:&5S6S%=("$]("=<7"<["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&=6YC=&EO;B!T;R!V86QI9&%T92!A;B!A9&1R+7-P96,N
M"B`@("`@*@H@("`@("H@861D<BUS<&5C(#T@;&]C86PM<&%R="`B0"(@9&]M
M86EN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1A9&1R7W-P96,@5&AE('-T<FEN9R!T;R!C:&5C:RX*("`@
M("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I;'5R92P@;W(@=&AE('9A
M;&ED871E9"!A9&1R+7-P96,@;VX@<W5C8V5S<RX*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W9A;&ED871E061D<E-P96,H)&%D9')?<W!E8RD*("`@('L*("`@
M("`@("`D861D<E]S<&5C(#T@=')I;2@D861D<E]S<&5C*3L*"B`@("`@("`@
M+R\@4W!L:70@;VX@0"!S:6=N(&EF('1H97)E(&ES(&]N92X*("`@("`@("!I
M9B`H<W1R<&]S*"1A9&1R7W-P96,L("=`)RD@(3T](&9A;'-E*2!["B`@("`@
M("`@("`@("1P87)T<R`@("`@(#T@97AP;&]D92@G0"<L("1A9&1R7W-P96,I
M.PH@("`@("`@("`@("`D;&]C86Q?<&%R="`]("1T:&ES+3Y?<W!L:71#:&5C
M:R@D<&%R=',L("=`)RD["B`@("`@("`@("`@("1D;VUA:6X@("`@(#T@<W5B
M<W1R*"1A9&1R7W-P96,L('-T<FQE;B@D;&]C86Q?<&%R="`N("=`)RDI.PH*
M("`@("`@("`O+R!.;R!`('-I9VX@<V\@87-S=6UE('1H92!D969A=6QT(&1O
M;6%I;BX*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&]C86Q?<&%R
M="`]("1A9&1R7W-P96,["B`@("`@("`@("`@("1D;VUA:6X@("`@(#T@)'1H
M:7,M/F1E9F%U;'1?9&]M86EN.PH@("`@("`@('T*"B`@("`@("`@:68@*"@D
M;&]C86Q?<&%R="`]("1T:&ES+3Y?=F%L:61A=&5,;V-A;%!A<G0H)&QO8V%L
M7W!A<G0I*2`]/3T@9F%L<V4I(')E='5R;B!F86QS93L*("`@("`@("!I9B`H
M*"1D;VUA:6X@("`@(#T@)'1H:7,M/E]V86QI9&%T941O;6%I;B@D9&]M86EN
M*2D@/3T](&9A;'-E*2!R971U<FX@9F%L<V4["@H@("`@("`@("\O($=O="!H
M97)E('-O(')E='5R;B!S=6-C97-S9G5L+@H@("`@("`@(')E='5R;B!A<G)A
M>2@G;&]C86Q?<&%R="<@/3X@)&QO8V%L7W!A<G0L("=D;VUA:6XG(#T^("1D
M;VUA:6XI.PH@("`@?0H*("`@("\J*@H@("`@("H@1G5N8W1I;VX@=&\@=F%L
M:61A=&4@=&AE(&QO8V%L('!A<G0@;V8@86X@861D<F5S<SH*("`@("`J("`@
M;&]C86PM<&%R="`]('=O<F0@*B@B+B(@=V]R9"D*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2!S=')I;F<@)&QO8V%L7W!A
M<G0*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@9F%I;'5R92P@;W(@
M=&AE('9A;&ED871E9"!L;V-A;"!P87)T(&]N('-U8V-E<W,N"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]V86QI9&%T94QO8V%L4&%R="@D;&]C86Q?<&%R="D*
M("`@('L*("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<N)RP@)&QO8V%L7W!A
M<G0I.PH@("`@("`@("1W;W)D<R`](&%R<F%Y*"D["@H@("`@("`@("\O(%-P
M;&ET('1H92!L;V-A;%]P87)T(&EN=&\@=V]R9',N"B`@("`@("`@=VAI;&4@
M*&-O=6YT*"1P87)T<RD@/B`P*7L*("`@("`@("`@("`@)'=O<F1S6UT@/2`D
M=&AI<RT^7W-P;&ET0VAE8VLH)'!A<G1S+"`G+B<I.PH@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D=&AI<RT^:6YD97@@*R`Q.R`D:2LK*2!["B`@
M("`@("`@("`@("`@("!A<G)A>5]S:&EF="@D<&%R=',I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`O+R!686QI9&%T92!E86-H('=O<F0N
M"B`@("`@("`@9F]R96%C:"`H)'=O<F1S(&%S("1W;W)D*2!["B`@("`@("`@
M("`@("\O($EF('1H:7,@=V]R9"!C;VYT86EN<R!A;B!U;G%U;W1E9"!S<&%C
M92P@:70@:7,@:6YV86QI9"X@*#8N,BXT*0H@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1W;W)D+"`G("<I("8F("1W;W)D6S!=("$]/2`G(B<I"B`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3Y?=F%L:61A=&50:')A<V4H
M=')I;2@D=V]R9"DI(#T]/2!F86QS92D@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T*"B`@("`@("`@+R\@36%N86=E9"!T;R!G970@:&5R92P@<V\@<F5T=7)N
M('1H92!I;G!U="X*("`@("`@("!R971U<FX@)&QO8V%L7W!A<G0["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&%N(&%P<')O>&EM871E(&-O=6YT
M(&]F(&AO=R!M86YY(&%D9')E<W-E<R!A<F4@:6X@=&AE"B`@("`@*B!G:79E
M;B!S=')I;F<N(%1H:7,@:7,@05!04D]824U!5$4@87,@:70@;VYL>2!S<&QI
M=',@8F%S960@;VX@80H@("`@("H@8V]M;6$@=VAI8V@@:&%S(&YO('!R96-E
M9&EN9R!B86-K<VQA<V@N($-O=6QD(&)E('5S969U;"!A<PH@("`@("H@;&%R
M9V4@86UO=6YT<R!O9B!A9&1R97-S97,@=VEL;"!E;F0@=7`@<')O9'5C:6YG
M("IL87)G92H*("`@("`J('-T<G5C='5R97,@=VAE;B!U<V5D('=I=&@@<&%R
M<V5!9&1R97-S3&ES="@I+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG
M("1D871A($%D9')E<W-E<R!T;R!C;W5N=`H@("`@("H@0')E='5R;B!I;G0@
M("`@("`@("`@07!P<F]X:6UA=&4@8V]U;G0*("`@("`J+PH@("`@9G5N8W1I
M;VX@87!P<F]X:6UA=&5#;W5N="@D9&%T82D*("`@('L*("`@("`@("!R971U
M<FX@8V]U;G0H<')E9U]S<&QI="@G+R@_/"%<7%Q<*2PO)RP@)&1A=&$I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J(%1H:7,@:7,@82!E;6%I;"!V86QI9&%T
M:6YG(&9U;F-T:6]N('-E<&%R871E('1O('1H92!R97-T(&]F('1H90H@("`@
M("H@8VQA<W,N($ET('-I;7!L>2!V86QI9&%T97,@=VAE=&AE<B!A;B!E;6%I
M;"!I<R!O9B!T:&4@8V]M;6]N"B`@("`@*B!I;G1E<FYE="!F;W)M.B`\=7-E
M<CY`/&1O;6%I;CXN(%1H:7,@8V%N(&)E('-U9F9I8VEE;G0@9F]R(&UO<W0*
M("`@("`J('!E;W!L92X@3W!T:6]N86P@<W1R:6-T97(@;6]D92!C86X@8F4@
M=71I;&ES960@=VAI8V@@<F5S=')I8W1S"B`@("`@*B!M86EL8F]X(&-H87)A
M8W1E<G,@86QL;W=E9"!T;R!A;'!H86YU;65R:6,L(&9U;&P@<W1O<"P@:'EP
M:&5N"B`@("`@*B!A;F0@=6YD97)S8V]R92X*("`@("`J"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`@)&1A=&$@("!!9&1R97-S('1O(&-H96-K"B`@("`@*B!`
M<&%R86T@(&)O;VQE86X@)'-T<FEC="!/<'1I;VYA;"!S=')I8W1E<B!M;V1E
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@("`@("`@("!&86QS92!I9B!I="!F
M86EL<RP@86X@:6YD97AE9"!A<G)A>0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@=7-E<FYA;64O9&]M86EN(&EF(&ET(&UA=&-H97,*("`@("`J
M+PH@("`@9G5N8W1I;VX@:7-686QI9$EN971!9&1R97-S*"1D871A+"`D<W1R
M:6-T(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E9V5X(#T@)'-T<FEC="`_
M("<O7BA;+C`M.6$M>E\K+5TK*4`H*%LP+3EA+7HM72M<+BDK6S`M.6$M>EU[
M,BPT?2DD+VDG(#H@)R]>*%LJ*R$N)B,D?%PG7%PE7"\P+3EA+7I>7V![?3T_
M?CHM72LI0"@H6S`M.6$M>BU=*UPN*2M;,"TY82UZ77LR+#1]*20O:2<["B`@
M("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X+"!T<FEM*"1D871A*2P@)&UA
M=&-H97,I*2!["B`@("`@("`@("`@(')E='5R;B!A<G)A>2@D;6%T8VAE<ULQ
M72P@)&UA=&-H97-;,ETI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TUA:6PO;6EM
M95!A<G0N<&AP````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,S$Q,3`@,3`U,34T,S0Q,S4@,#(Q-C,P`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP#0HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR
M,#`S("!2:6-H87)D($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-
M"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@4F5D:7-T
M<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@
M=VET:"!O<B!W:71H;W5T("`@('P-"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS("`@('P-"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@;R!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@("`@('P-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@
M("`@('P-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@
M;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P-"B\O('P@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P-"B\O('P@("!D;V-U;65N=&%T
M:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@
M9&ES=')I8G5T:6]N+GP-"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO
M<G,@;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@
M('P-"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R
M92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P-"B\O('P@("!P
M97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P-"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"
M62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P-
M"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)2
M04Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P-"B\O('P@3$E-251%
M1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)
M5%D@04Y$($9)5$Y%4U,@1D]2('P-"B\O('P@02!005)424-53$%2(%!54E!/
M4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!9
M4DE'2%0@('P-"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),
M12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P-"B\O
M('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'
M15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P-"B\O('P@3$E-251%1"!4
M3RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%
M4SL@3$]34R!/1B!54T4L('P-"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@
M0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@
M04Y9('P-"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#
M3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P-"B\O('P@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P-"B\O('P@3T8@5$A)4R!33T94
M5T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!3
M54-(($1!34%'12X@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@075T
M:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L-"@T*+RHJ#0HJ#0HJ("!287<@;6EM92!E;F-O9&EN9R!C
M;&%S<PT**@T**B!7:&%T(&ES(&ET/PT**B`@(%1H:7,@8VQA<W,@96YA8FQE
M<R!Y;W4@=&\@;6%N:7!U;&%T92!A;F0@8G5I;&0-"BH@("!A(&UI;64@96UA
M:6P@9G)O;2!T:&4@9W)O=6YD('5P+@T**@T**B!7:'D@=7-E('1H:7,@:6YS
M=&5A9"!O9B!M:6UE+G!H<#\-"BH@("!M:6UE+G!H<"!I<R!A('5S97)F<FEE
M;F1L>2!A<&D@=&\@=&AI<R!C;&%S<R!F;W(-"BH@("!P96]P;&4@=VAO(&%R
M96XG="!I;G1E<F5S=&5D(&EN('1H92!I;G1E<FYA;',@;V8-"BH@("!M:6UE
M(&UA:6PN(%1H:7,@8VQA<W,@:&]W979E<B!A;&QO=W,@9G5L;"!C;VYT<F]L
M#0HJ("`@;W9E<B!T:&4@96UA:6PN#0HJ#0HJ($5G+@T**@T**B`O+R!3:6YC
M92!M=6QT:7!A<G0O;6EX960@:&%S(&YO(')E86P@8F]D>2P@*'1H92!B;V1Y
M(&ES#0HJ("\O('1H92!S=6)P87)T*2P@=V4@<V5T('1H92!B;V1Y(&%R9W5M
M96YT('1O(&)L86YK+@T**@T**B`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]
M("=M=6QT:7!A<G0O;6EX960G.PT**B`D96UA:6P@/2!N97<@36%I;%]M:6UE
M4&%R="@G)RP@)'!A<F%M<RD[#0HJ#0HJ("\O($AE<F4@=V4@861D(&$@=&5X
M="!P87)T('1O('1H92!M=6QT:7!A<G0@=V4@:&%V90T**B`O+R!A;')E861Y
M+B!!<W-U;64@)&)O9'D@8V]N=&%I;G,@<&QA:6X@=&5X="X-"BH-"BH@)'!A
M<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G=&5X="]P;&%I;B<[#0HJ("1P87)A
M;7-;)V5N8V]D:6YG)UT@("`@(#T@)S=B:70G.PT**B`D=&5X="`]("1E;6%I
M;"T^861D4W5B4&%R="@D8F]D>2P@)'!A<F%M<RD[#0HJ#0HJ("\O($YO=R!A
M9&0@86X@871T86-H;65N="X@07-S=6UE("1A='1A8V@@:7,-"BH@=&AE(&-O
M;G1E;G1S(&]F('1H92!A='1A8VAM96YT#0HJ#0HJ("1P87)A;7-;)V-O;G1E
M;G1?='EP92==(#T@)V%P<&QI8V%T:6]N+WII<"<[#0HJ("1P87)A;7-;)V5N
M8V]D:6YG)UT@("`@(#T@)V)A<V4V-"<[#0HJ("1P87)A;7-;)V1I<W!O<VET
M:6]N)UT@(#T@)V%T=&%C:&UE;G0G.PT**B`D<&%R86US6R=D9FEL96YA;64G
M72`@("`]("=E>&%M<&QE+GII<"<[#0HJ("1A='1A8V@@/28@)&5M86EL+3YA
M9&13=6)087)T*"1B;V1Y+"`D<&%R86US*3L-"BH-"BH@+R\@3F]W(&)U:6QD
M('1H92!E;6%I;"X@3F]T92!T:&%T('1H92!E;F-O9&4-"BH@+R\@9G5N8W1I
M;VX@<F5T=7)N<R!A;B!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG('1W
M;PT**B`O+R!E;&5M96YT<RP@8F]D>2!A;F0@:&5A9&5R<RX@66]U('=I;&P@
M;F5E9"!T;R!A9&0@97AT<F$-"BH@+R\@:&5A9&5R<RP@*&5G+B!-:6UE+59E
M<G-I;VXI(&)E9F]R92!S96YD:6YG+@T**@T**B`D96UA:6P@/2`D;65S<V%G
M92T^96YC;V1E*"D[#0HJ("1E;6%I;%LG:&5A9&5R<R==6UT@/2`G36EM92U6
M97)S:6]N.B`Q+C`G.PT**@T**@T**B!&=7)T:&5R(&5X86UP;&5S(&%R92!A
M=F%I;&%B;&4@870@:'1T<#HO+W=W=RYP:'!G=7)U+F]R9PT**@T**B!43T1/
M.@T**B`@+2!3970@96YC;V1E*"D@=&\@<F5T=7)N('1H92`D;V)J+3YE;F-O
M9&5D(&EF(&5N8V]D92@I#0HJ("`@(&AA<R!A;')E861Y(&)E96X@<G5N+B!5
M;FQE<W,@82!F;&%G(&ES('!A<W-E9"!T;R!S<&5C:69I8V%L;'D-"BH@("`@
M<F4M8G5I;&0@=&AE(&UE<W-A9V4N#0HJ#0HJ($!A=71H;W(@(%)I8VAA<F0@
M2&5Y97,@/')I8VAA<F1`<&AP9W5R=2YO<F<^#0HJ($!V97)S:6]N("12979I
M<VEO;CH@,2XQ,R`D#0HJ($!P86-K86=E($UA:6P-"BHO#0H-"F-L87-S($UA
M:6Q?;6EM95!A<G0@>PT*#0H@("`O*BH-"B`@("`J(%1H92!E;F-O9&EN9R!T
M>7!E(&]F('1H:7,@<&%R=`T*("`@("H@0'9A<B!S=')I;F<-"B`@("`J+PT*
M("`@('9A<B`D7V5N8V]D:6YG.PT*#0H@("`O*BH-"B`@("`J($%N(&%R<F%Y
M(&]F('-U8G!A<G1S#0H@("`@*B!`=F%R(&%R<F%Y#0H@("`@*B\-"B`@("!V
M87(@)%]S=6)P87)T<SL-"@T*("`@+RHJ#0H@("`@*B!4:&4@;W5T<'5T(&]F
M('1H:7,@<&%R="!A9G1E<B!B96EN9R!B=6EL=`T*("`@("H@0'9A<B!S=')I
M;F<-"B`@("`J+PT*("`@('9A<B`D7V5N8V]D960[#0H-"B`@("\J*@T*("`@
M("H@2&5A9&5R<R!F;W(@=&AI<R!P87)T#0H@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@*B\-"B`@("!V87(@)%]H96%D97)S.PT*#0H@("`O*BH-"B`@("`J(%1H
M92!B;V1Y(&]F('1H:7,@<&%R="`H;F]T(&5N8V]D960I#0H@("`@*B!`=F%R
M('-T<FEN9PT*("`@("HO#0H@("`@=F%R("1?8F]D>3L-"@T*("`@("\J*@T*
M("`@("`J($-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@4V5T<R!U<"!T
M:&4@;V)J96-T+@T*("`@("`J#0H@("`@("H@0'!A<F%M("1B;V1Y("`@+2!4
M:&4@8F]D>2!O9B!T:&4@;6EM92!P87)T(&EF(&%N>2X-"B`@("`@*B!`<&%R
M86T@)'!A<F%M<R`M($%N(&%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E
M<G,Z#0H@("`@("H@("`@("`@("`@("`@("`@("!C;VYT96YT7W1Y<&4@+2!4
M:&4@8V]N=&5N="!T>7!E(&9O<B!T:&ES('!A<G0@96<@;75L=&EP87)T+VUI
M>&5D#0H@("`@("H@("`@("`@("`@("`@("`@("!E;F-O9&EN9R`@("`@+2!4
M:&4@96YC;V1I;F<@=&\@=7-E+"`W8FET+"`X8FET+"!B87-E-C0L(&]R('%U
M;W1E9"UP<FEN=&%B;&4-"B`@("`@*B`@("`@("`@("`@("`@("`@(&-I9"`@
M("`@("`@("`M($-O;G1E;G0@240@=&\@87!P;'D-"B`@("`@*B`@("`@("`@
M("`@("`@("`@(&1I<W!O<VET:6]N("`M($-O;G1E;G0@9&ES<&]S:71I;VXL
M(&EN;&EN92!O<B!A='1A8VAM96YT#0H@("`@("H@("`@("`@("`@("`@("`@
M("!D9FEL96YA;64@("`@+2!/<'1I;VYA;"!F:6QE;F%M92!P87)A;65T97(@
M9F]R(&-O;G1E;G0@9&ES<&]S:71I;VX-"B`@("`@*B`@("`@("`@("`@("`@
M("`@(&1E<V-R:7!T:6]N("`M($-O;G1E;G0@9&5S8W)I<'1I;VX-"B`@("`@
M*B`@("`@("`@("`@("`@("`@(&-H87)S970@("`@("`M($-H87)A8W1E<B!S
M970@=&\@=7-E#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!-86EL7VUI;65087)T*"1B;V1Y(#T@)R<L("1P87)A;7,@
M/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@:68@*"%D969I;F5D*"=-04E,
M7TU)345005)47T-23$8G*2D@>PT*("`@("`@("`@("`@9&5F:6YE*"=-04E,
M7TU)345005)47T-23$8G+"!D969I;F5D*"=-04E,7TU)345?0U),1B<I(#\@
M34%)3%]-24U%7T-23$8@.B`B7')<;B(L(%12544I.PT*("`@("`@("!]#0H-
M"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:V5Y(#T^("1V86QU92D@
M>PT*("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2![#0H@("`@("`@("`@("`@
M("`@8V%S92`G8V]N=&5N=%]T>7!E)SH-"B`@("`@("`@("`@("`@("`@("`@
M)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@)'9A;'5E("X@*&ES<V5T*"1C
M:&%R<V5T*2`_("<[(&-H87)S970](B<@+B`D8VAA<G-E="`N("<B)R`Z("<G
M*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@
M("`@("!C87-E("=E;F-O9&EN9R<Z#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?96YC;V1I;F<@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@("`@
M("1H96%D97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D:6YG)UT@/2`D=F%L
M=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@
M("`@("`@8V%S92`G8VED)SH-"B`@("`@("`@("`@("`@("`@("`@)&AE861E
M<G-;)T-O;G1E;G0M240G72`]("<\)R`N("1V86QU92`N("<^)SL-"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@("`@("!C87-E
M("=D:7-P;W-I=&EO;B<Z#0H@("`@("`@("`@("`@("`@("`@("1H96%D97)S
M6R=#;VYT96YT+41I<W!O<VET:6]N)UT@/2`D=F%L=64@+B`H:7-S970H)&1F
M:6QE;F%M92D@/R`G.R!F:6QE;F%M93TB)R`N("1D9FEL96YA;64@+B`G(B<@
M.B`G)RD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@
M("`@("`@("`@8V%S92`G9&9I;&5N86UE)SH-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1H96%D97)S6R=#;VYT96YT+41I<W!O<VET:6]N)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG0V]N=&5N
M="U$:7-P;W-I=&EO;B==("X]("<[(&9I;&5N86UE/2(G("X@)'9A;'5E("X@
M)R(G.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1F:6QE;F%M92`]("1V86QU93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"@T*
M("`@("`@("`@("`@("`@(&-A<V4@)V1E<V-R:7!T:6]N)SH-"B`@("`@("`@
M("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M1&5S8W)I<'1I;VXG72`]
M("1V86QU93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@
M("`@("`@("`@("!C87-E("=C:&%R<V5T)SH-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1H96%D97)S6R=#;VYT96YT+51Y<&4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51Y<&4G
M72`N/2`G.R!C:&%R<V5T/2(G("X@)'9A;'5E("X@)R(G.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-H87)S970@/2`D=F%L=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R!$969A=6QT(&-O;G1E;G0M='EP90T*("`@
M("`@("!I9B`H(6ES<V5T*"1H96%D97)S6R=#;VYT96YT+51Y<&4G72DI('L-
M"B`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51Y<&4G72`]("=T97AT
M+W!L86EN)SL-"B`@("`@("`@?0T*#0H@("`@("`@("\O1&5F875L="!E;F-O
M9&EN9PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?96YC;V1I;F<I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V5N8V]D:6YG(#T@)S=B:70G.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@07-S:6=N('-T=69F('1O(&UE;6)E<B!V
M87)I86)L97,-"B`@("`@("`@)'1H:7,M/E]E;F-O9&5D("`](&%R<F%Y*"D[
M#0H@("`@("`@("1T:&ES+3Y?:&5A9&5R<R`@/2`D:&5A9&5R<SL-"B`@("`@
M("`@)'1H:7,M/E]B;V1Y("`@("`]("1B;V1Y.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(&5N8V]D92@I#0H@("`@("H-"B`@("`@*B!%;F-O9&5S(&%N
M9"!R971U<FYS('1H92!E;6%I;"X@06QS;R!S=&]R97,-"B`@("`@*B!I="!I
M;B!T:&4@96YC;V1E9"!M96UB97(@=F%R:6%B;&4-"B`@("`@*@T*("`@("`J
M($!R971U<FX@06X@87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!T=V\@
M96QE;65N=',L#0H@("`@("H@("`@("`@("!B;V1Y(&%N9"!H96%D97)S+B!4
M:&4@:&5A9&5R<R!E;&5M96YT(&ES(&ET<V5L9@T*("`@("`J("`@("`@("`@
M86X@:6YD97AE9"!A<G)A>2X-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&5N8V]D92@I#0H@("`@>PT*("`@("`@("`D
M96YC;V1E9"`])B`D=&AI<RT^7V5N8V]D960[#0H-"B`@("`@("`@:68@*"%E
M;7!T>2@D=&AI<RT^7W-U8G!A<G1S*2D@>PT*("`@("`@("`@("`@<W)A;F0H
M*&1O=6)L92EM:6-R;W1I;64H*2HQ,#`P,#`P*3L-"B`@("`@("`@("`@("1B
M;W5N9&%R>2`]("<]7R<@+B!M9#4H<F%N9"@I("X@;6EC<F]T:6UE*"DI.PT*
M("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R=#;VYT96YT+51Y<&4G72`N
M/2`G.R<@+B!-04E,7TU)345005)47T-23$8@+B`B7'0B("X@)V)O=6YD87)Y
M/2(G("X@)&)O=6YD87)Y("X@)R(G.PT*#0H@("`@("`@("`@("`O+R!!9&0@
M8F]D>2!P87)T<R!T;R`D<W5B<&%R=',-"B`@("`@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?<W5B<&%R=',I.R`D:2LK*2![#0H@
M("`@("`@("`@("`@("`@)&AE861E<G,@/2!A<G)A>2@I.PT*("`@("`@("`@
M("`@("`@("1T;7`@/2`D=&AI<RT^7W-U8G!A<G1S6R1I72T^96YC;V1E*"D[
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1M<%LG:&5A9&5R<R==(&%S
M("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@("`@("1H96%D
M97)S6UT@/2`D:V5Y("X@)SH@)R`N("1V86QU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)'-U8G!A<G1S6UT@/2!I;7!L;V1E*$U!
M24Q?34E-15!!4E1?0U),1BP@)&AE861E<G,I("X@34%)3%]-24U%4$%25%]#
M4DQ&("X@34%)3%]-24U%4$%25%]#4DQ&("X@)'1M<%LG8F]D>2==.PT*("`@
M("`@("`@("`@?0T*#0H@("`@("`@("`@("`D96YC;V1E9%LG8F]D>2==(#T@
M)RTM)R`N("1B;W5N9&%R>2`N($U!24Q?34E-15!!4E1?0U),1B`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+2TG("X@)&)O
M=6YD87)Y("X@34%)3%]-24U%4$%25%]#4DQ&+"`D<W5B<&%R=',I("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+2TG("X@)&)O=6YD87)Y
M+B<M+2<@+B!-04E,7TU)345005)47T-23$8[#0H-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1E;F-O9&5D6R=B;V1Y)UT@/2`D=&AI<RT^7V=E
M=$5N8V]D961$871A*"1T:&ES+3Y?8F]D>2P@)'1H:7,M/E]E;F-O9&EN9RD@
M+B!-04E,7TU)345005)47T-23$8[#0H@("`@("`@('T-"@T*("`@("`@("`O
M+R!!9&0@:&5A9&5R<R!T;R`D96YC;V1E9`T*("`@("`@("`D96YC;V1E9%LG
M:&5A9&5R<R==(#TF("1T:&ES+3Y?:&5A9&5R<SL-"@T*("`@("`@("!R971U
M<FX@)&5N8V]D960[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@)F%D9%-U
M8E!A<G0H*0T*("`@("`J#0H@("`@("H@061D<R!A('-U8G!A<G0@=&\@8W5R
M<F5N="!M:6UE('!A<G0@86YD(')E='5R;G,-"B`@("`@*B!A(')E9F5R96YC
M92!T;R!I=`T*("`@("`J#0H@("`@("H@0'!A<F%M("1B;V1Y("`@5&AE(&)O
M9'D@;V8@=&AE('-U8G!A<G0L(&EF(&%N>2X-"B`@("`@*B!`<&%R86T@)'!A
M<F%M<R!4:&4@<&%R86UE=&5R<R!F;W(@=&AE('-U8G!A<G0L('-A;64-"B`@
M("`@*B`@("`@("`@("`@("`@("!A<R!T:&4@)'!A<F%M<R!A<F=U;65N="!F
M;W(@8V]N<W1R=6-T;W(N#0H@("`@("H@0')E='5R;B!!(')E9F5R96YC92!T
M;R!T:&4@<&%R="!Y;W4@:G5S="!A9&1E9"X@270@:7,-"B`@("`@*B`@("`@
M("`@(&-R=6-I86P@:68@=7-I;F<@;75L=&EP87)T+RH@:6X@>6]U<B!S=6)P
M87)T<R!T:&%T#0H@("`@("H@("`@("`@("!Y;W4@=7-E(#TF(&EN('EO=7(@
M<V-R:7!T('=H96X@8V%L;&EN9R!T:&ES(&9U;F-T:6]N+`T*("`@("`J("`@
M("`@("`@;W1H97)W:7-E('EO=2!W:6QL(&YO="!B92!A8FQE('1O(&%D9"!F
M=7)T:&5R('-U8G!A<G1S+@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@)F%D9%-U8E!A<G0H)&)O9'DL("1P87)A;7,I
M#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-U8G!A<G1S6UT@/2!N97<@36%I
M;%]M:6UE4&%R="@D8F]D>2P@)'!A<F%M<RD[#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^7W-U8G!A<G1S6V-O=6YT*"1T:&ES+3Y?<W5B<&%R=',I("T@,5T[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@7V=E=$5N8V]D961$871A*"D-
M"B`@("`@*@T*("`@("`J(%)E='5R;G,@96YC;V1E9"!D871A(&)A<V5D('5P
M;VX@96YC;V1I;F<@<&%S<V5D('1O(&ET#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@)&1A=&$@("`@(%1H92!D871A('1O(&5N8V]D92X-"B`@("`@*B!`<&%R
M86T@)&5N8V]D:6YG(%1H92!E;F-O9&EN9R!T>7!E('1O('5S92P@-V)I="P@
M8F%S938T+`T*("`@("`J("`@("`@("`@("`@("`@("`@;W(@<75O=&5D+7!R
M:6YT86)L92X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?9V5T16YC;V1E9$1A=&$H)&1A=&$L("1E;F-O9&EN9RD-
M"B`@("![#0H@("`@("`@('-W:71C:"`H)&5N8V]D:6YG*2![#0H@("`@("`@
M("`@("!C87-E("<X8FET)SH-"B`@("`@("`@("`@(&-A<V4@)S=B:70G.@T*
M("`@("`@("`@("`@("`@(')E='5R;B`D9&%T83L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"@T*("`@("`@("`@("`@8V%S92`G<75O=&5D+7!R:6YT86)L
M92<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<75O=&5D4')I
M;G1A8FQE16YC;V1E*"1D871A*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"@T*("`@("`@("`@("`@8V%S92`G8F%S938T)SH-"B`@("`@("`@("`@("`@
M("!R971U<FX@<G1R:6TH8VAU;FM?<W!L:70H8F%S938T7V5N8V]D92@D9&%T
M82DL(#<V+"!-04E,7TU)345005)47T-23$8I*3L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"@T*("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@
M("`@("!R971U<FX@)&1A=&$[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!Q=6]T96%D4')I;G1A8FQE16YC;V1E*"D-"B`@("`@*@T*
M("`@("`J($5N8V]D97,@9&%T82!T;R!Q=6]T960M<')I;G1A8FQE('-T86YD
M87)D+@T*("`@("`J#0H@("`@("H@0'!A<F%M("1I;G!U="`@("!4:&4@9&%T
M82!T;R!E;F-O9&4-"B`@("`@*B!`<&%R86T@)&QI;F5?;6%X($]P=&EO;F%L
M(&UA>"!L:6YE(&QE;F=T:"X@4VAO=6QD#0H@("`@("H@("`@("`@("`@("`@
M("`@("!N;W0@8F4@;6]R92!T:&%N(#<V(&-H87)S#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<75O
M=&5D4')I;G1A8FQE16YC;V1E*"1I;G!U="`L("1L:6YE7VUA>"`](#<V*0T*
M("`@('L-"B`@("`@("`@)&QI;F5S("`]('!R96=?<W!L:70H(B]<<C]<;B\B
M+"`D:6YP=70I.PT*("`@("`@("`D96]L("`@(#T@34%)3%]-24U%4$%25%]#
M4DQ&.PT*("`@("`@("`D97-C87!E(#T@)STG.PT*("`@("`@("`D;W5T<'5T
M(#T@)R<[#0H-"B`@("`@("`@=VAI;&4H;&ES="@L("1L:6YE*2`](&5A8V@H
M)&QI;F5S*2E[#0H-"B`@("`@("`@("`@("1L:6YL96X@("`@(#T@<W1R;&5N
M*"1L:6YE*3L-"B`@("`@("`@("`@("1N97=L:6YE(#T@)R<[#0H-"B`@("`@
M("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1L:6YL96X[("1I*RLI('L-"B`@
M("`@("`@("`@("`@("`D8VAA<B`]('-U8G-T<B@D;&EN92P@)&DL(#$I.PT*
M("`@("`@("`@("`@("`@("1D96,@(#T@;W)D*"1C:&%R*3L-"@T*("`@("`@
M("`@("`@("`@(&EF("@H)&1E8R`]/2`S,BD@04Y$("@D:2`]/2`H)&QI;FQE
M;B`M(#$I*2E[("`@("\O(&-O;G9E<G0@<W!A8V4@870@96]L(&]N;'D-"B`@
M("`@("`@("`@("`@("`@("`@)&-H87(@/2`G/3(P)SL-"@T*("`@("`@("`@
M("`@("`@('T@96QS96EF*"@D9&5C(#T](#DI($%.1"`H)&D@/3T@*"1L:6YL
M96X@+2`Q*2DI('L@("\O(&-O;G9E<G0@=&%B(&%T(&5O;"!O;FQY#0H@("`@
M("`@("`@("`@("`@("`@("1C:&%R(#T@)STP.2<[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E:68H)&1E8R`]/2`Y*2![#0H@("`@("`@("`@("`@("`@("`@
M(#L@+R\@1&\@;F]T:&EN9R!I9B!A('1A8BX-"B`@("`@("`@("`@("`@("!]
M(&5L<V5I9B@H)&1E8R`]/2`V,2D@3U(@*"1D96,@/"`S,B`I($]2("@D9&5C
M(#X@,3(V*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8VAA<B`]("1E<V-A
M<&4@+B!S=')T;W5P<&5R*'-P<FEN=&8H)R4P,G,G+"!D96-H97@H)&1E8RDI
M*3L-"B`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("!I9B`H
M*'-T<FQE;B@D;F5W;&EN92D@*R!S=')L96XH)&-H87(I*2`^/2`D;&EN95]M
M87@I('L@("`@("`@("\O($U!24Q?34E-15!!4E1?0U),1B!I<R!N;W0@8V]U
M;G1E9`T*("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("`N/2`D;F5W;&EN
M92`N("1E<V-A<&4@+B`D96]L.R`@("`@("`@("`@("`@("`@("`@+R\@<V]F
M="!L:6YE(&)R96%K.R`B(#U<<EQN(B!I<R!O:V%Y#0H@("`@("`@("`@("`@
M("`@("`@("1N97=L:6YE("`]("<G.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D;F5W;&EN92`N/2`D8VAA<CL-"B`@("`@("`@("`@
M('T@+R\@96YD(&]F(&9O<@T*("`@("`@("`@("`@)&]U='!U="`N/2`D;F5W
M;&EN92`N("1E;VP[#0H@("`@("`@('T-"B`@("`@("`@)&]U='!U="`]('-U
M8G-T<B@D;W5T<'5T+"`P+"`M,2`J('-T<FQE;B@D96]L*2D[("\O($1O;B=T
M('=A;G0@;&%S="!C<FQF#0H@("`@("`@(')E='5R;B`D;W5T<'5T.PT*("`@
M('T-"GT@+R\@16YD(&]F(&-L87-S#0H_/@T*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+TUA:6PO;6EM92YP:'``````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-C$P-C,@,3`U,34T,S0Q,S4@,#(Q,#$S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30Z("HO"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R`@4FEC:&%R9"!(97EE<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($-O<'ER:6=H
M="`H8RD@,C`P,RTR,#`U("!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%)E
M9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R
M;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O('P@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@;R!2961I<W1R
M:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E
M(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@
M("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU
M<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\"B\O('P@("!N
M;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W
M:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@?"`@(&1O8W5M96YT871I;VX@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T
M<FEB=71I;VXN?`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA
M>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\"B\O
M('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H
M;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P*+R\@?"`@('!E<FUI<W-I
M;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]0
M65))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P*+R\@?"`B05,@
M25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.
M0TQ51$E.1RP@0E54($Y/5"`@("`@?`HO+R!\($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!\"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,
M04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P*+R\@
M?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@?`HO+R!\(%-014-)04PL($58
M14U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L
M($)55"!.3U0@("`@("!\"B\O('P@3$E-251%1"!43RP@4%)/0U5214U%3E0@
M3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L
M('P*+R\@?"!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)5
M4%1)3TXI($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED@?`HO+R!\(%1(14]2
M62!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,
M24%"24Q)5%DL($]2(%1/4E0@("!\"B\O('P@*$E.0TQ51$E.1R!.14=,24=%
M3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!4
M2$4@55-%('P*+R\@?"!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3
M140@3T8@5$A%(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+B`@?`HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I
M8VAA<F1`<&AP9W5R=2YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\("`@("`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96-N970N8V]M
M/B`H<&]R="!T;R!014%2*2`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!M:6UE+G!H<"QV(#$N
M,SD@,C`P-2\P-B\Q,R`R,3HR-#HQ-B!C:7!R:2!%>'`@)`H*<F5Q=6ER95]O
M;F-E*"=014%2+G!H<"<I.PIR97%U:7)E7V]N8V4H)TUA:6PO;6EM95!A<G0N
M<&AP)RD["@HO*BH*("H@36EM92!M86EL(&-O;7!O<V5R(&-L87-S+B!#86X@
M:&%N9&QE.B!T97AT(&%N9"!H=&UL(&)O9&EE<RP@96UB961D960@:'1M;`H@
M*B!I;6%G97,@86YD(&%T=&%C:&UE;G1S+@H@*B!$;V-U;65N=&%T:6]N(&%N
M9"!E>&%M<&QE<R!O9B!T:&ES(&-L87-S(&%R92!A=F%I8FQE(&AE<F4Z"B`J
M(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+PH@*@H@*B!`;F]T97,@5&AI
M<R!C;&%S<R!I<R!B87-E9"!O;B!(5$U,($UI;64@36%I;"!C;&%S<R!F<F]M
M"B`J("`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'!G=7)U+F]R9SX@=VAI
M8V@@=V%S(&)A<V5D(&%L<V\*("H@("!I;B!T:&4@;6EM95]M86EL+F-L87-S
M(&)Y(%1O8FEA<R!2871S8VAI;&QE<B`\=&]B:6%S0&1N970N:70^(&%N9`H@
M*B`@(%-A<V-H82!38VAU;6%N;B`\<V%S8VAA0'-C:'5M86YN+F-X/@H@*@H@
M*B!`875T:&]R("`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9"YH97EE<T!H97EE
M<RUC;VUP=71I;F<N;F5T/@H@*B!`875T:&]R("`@5&]M87,@5BY6+D-O>"`\
M8V]X0&ED96-N970N8V]M/@H@*B!`<&%C:V%G92`@36%I;`H@*B!`86-C97-S
M("`@<'5B;&EC"B`J+PIC;&%S<R!-86EL7VUI;64*>PH@("`@+RHJ"B`@("`@
M*B!#;VYT86EN<R!T:&4@<&QA:6X@=&5X="!P87)T(&]F('1H92!E;6%I;`H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?='AT8F]D>3L*
M("`@("\J*@H@("`@("H@0V]N=&%I;G,@=&AE(&AT;6P@<&%R="!O9B!T:&4@
M96UA:6P*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7VAT
M;6QB;V1Y.PH@("`@+RHJ"B`@("`@*B!C;VYT86EN<R!T:&4@;6EM92!E;F-O
M9&5D('1E>'0*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D
M7VUI;64["B`@("`O*BH*("`@("`J(&-O;G1A:6YS('1H92!M=6QT:7!A<G0@
M8V]N=&5N=`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1?
M;75L=&EP87)T.PH@("`@+RHJ"B`@("`@*B!L:7-T(&]F('1H92!A='1A8VAE
M9"!I;6%G97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1?
M:'1M;%]I;6%G97,@/2!A<G)A>2@I.PH@("`@+RHJ"B`@("`@*B!L:7-T(&]F
M('1H92!A='1A8VAE;65N=',*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1?<&%R=',@/2!A<G)A>2@I.PH@("`@+RHJ"B`@("`@*B!"=6EL
M9"!P87)A;65T97)S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D7V)U:6QD7W!A<F%M<R`](&%R<F%Y*"D["B`@("`O*BH*("`@("`J($AE
M861E<G,@9F]R('1H92!M86EL"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D7VAE861E<G,@/2!A<G)A>2@I.PH@("`@+RHJ"B`@("`@*B!%
M;F0@3V8@3&EN92!S97%U96YC92`H9F]R('-E<FEA;&EZ92D*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5O;#L*"@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<B!F=6YC=&EO;@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($UA:6Q?;6EM92@D8W)L
M9B`](")<<EQN(BD*("`@('L*("`@("`@("`D=&AI<RT^7W-E=$5/3"@D8W)L
M9BD["B`@("`@("`@)'1H:7,M/E]B=6EL9%]P87)A;7,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T97AT7V5N8V]D
M:6YG)R`]/B`G-V)I="<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:'1M;%]E;F-O9&EN9R<@/3X@)W%U;W1E9"UP<FEN=&%B;&4G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)S=B:71?
M=W)A<"<@("`@(#T^(#DY."P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=H=&UL7V-H87)S970G("`]/B`G25-/+3@X-3DM,2<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&5X=%]C:&%R
M<V5T)R`@/3X@)TE33RTX.#4Y+3$G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VAE861?8VAA<G-E="<@(#T^("=)4T\M.#@U.2TQ
M)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5V%K975P("AU;G-E<FEA;&EZ92D@+2!R92US
M971S($5/3"!C;VYS=&%N=`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?7W=A:V5U<"@I"B`@("!["B`@("`@
M("`@)'1H:7,M/E]S971%3TPH)'1H:7,M/E]E;VPI.PH@("`@?0H*("`@("\J
M*@H@("`@("H@06-C97-S;W(@9G5N8W1I;VX@=&\@<V5T('1H92!B;V1Y('1E
M>'0N($)O9'D@=&5X="!I<R!U<V5D(&EF"B`@("`@*B!I="=S(&YO="!A;B!H
M=&UL(&UA:6P@8F5I;F<@<V5N="!O<B!E;'-E(&ES('5S960@=&\@9FEL;"!T
M:&4*("`@("`J('1E>'0O<&QA:6X@<&%R="!T:&%T(&5M86EL<R!C;&EE;G1S
M('=H;R!D;VXG="!S=7!P;W)T"B`@("`@*B!H=&UL('-H;W5L9"!S:&]W+@H@
M("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG("`D9&%T82`@($5I=&AE<B!A
M('-T<FEN9R!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@=&AE
M(&9I;&4@;F%M92!W:71H('1H92!C;VYT96YT<PH@("`@("H@0'!A<F%M("!B
M;V]L("`@("1I<V9I;&4@268@=')U92!T:&4@9FER<W0@<&%R86T@<VAO=6QD
M(&)E('1R96%T960*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%S
M(&$@9FEL92!N86UE+"!E;'-E(&%S(&$@<W1R:6YG("AD969A=6QT*0H@("`@
M("H@0'!A<F%M("!B;V]L("`@("1A<'!E;F0@268@=')U92!T:&4@=&5X="!O
M<B!F:6QE(&ES(&%P<&5N9&5D('1O"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!T:&4@97AI<W1I;F<@8F]D>2P@96QS92!T:&4@;VQD(&)O9'D@
M:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&]V97)W<FET=&5N
M"B`@("`@*B!`<F5T=7)N(&UI>&5D("`@=')U92!O;B!S=6-C97-S(&]R(%!%
M05)?17)R;W(@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S97146%1";V1Y*"1D871A+"`D:7-F:6QE(#T@9F%L
M<V4L("1A<'!E;F0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(21I<V9I
M;&4I('L*("`@("`@("`@("`@:68@*"$D87!P96YD*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W1X=&)O9'D@/2`D9&%T83L*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?='AT8F]D>2`N/2`D9&%T
M83L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1C;VYT(#T@)'1H:7,M/E]F:6QE,G-T<B@D9&%T82D["B`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1C;VYT*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1C;VYT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)&%P<&5N9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]T>'1B;V1Y(#T@
M)&-O;G0["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W1X=&)O9'D@+CT@)&-O;G0["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!!9&1S(&$@:'1M;"!P87)T('1O('1H92!M86EL"B`@("`@*@H@("`@("H@
M0'!A<F%M("!S=')I;F<@("1D871A("`@16ET:&5R(&$@<W1R:6YG(&]R('1H
M92!F:6QE(&YA;64@=VET:"!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1E;G1S"B`@("`@*B!`<&%R86T@(&)O;VP@("`@)&ES9FEL
M92!)9B!T<G5E('1H92!F:7)S="!P87)A;2!S:&]U;&0@8F4@=')E871E9`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@87,@82!F:6QE(&YA;64L
M(&5L<V4@87,@82!S=')I;F<@*&1E9F%U;'0I"B`@("`@*B!`<F5T=7)N(&UI
M>&5D("`@=')U92!O;B!S=6-C97-S(&]R(%!%05)?17)R;W(@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971(
M5$U,0F]D>2@D9&%T82P@)&ES9FEL92`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A)&ES9FEL92D@>PH@("`@("`@("`@("`D=&AI<RT^7VAT;6QB;V1Y
M(#T@)&1A=&$["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-O;G0@
M/2`D=&AI<RT^7V9I;&4R<W1R*"1D871A*3L*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&-O;G0I*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)&-O;G0["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]H=&UL
M8F]D>2`]("1C;VYT.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&%N(&EM86=E('1O('1H92!L
M:7-T(&]F(&5M8F5D9&5D(&EM86=E<RX*("`@("`J"B`@("`@*B!`<&%R86T@
M('-T<FEN9R`@)&9I;&4@("`@("`@5&AE(&EM86=E(&9I;&4@;F%M92!/4B!I
M;6%G92!D871A(&ET<V5L9@H@("`@("H@0'!A<F%M("!S=')I;F<@("1C7W1Y
M<&4@("`@(%1H92!C;VYT96YT('1Y<&4*("`@("`J($!P87)A;2`@<W1R:6YG
M("`D;F%M92`@("`@("!4:&4@9FEL96YA;64@;V8@=&AE(&EM86=E+@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($]N;'D@=7-E(&EF("1F
M:6QE(&ES('1H92!I;6%G92!D871A"B`@("`@*B!`<&%R86T@(&)O;VP@("`@
M)&ES9FEL96YA;64@5VAE=&AE<B`D9FEL92!I<R!A(&9I;&5N86UE(&]R(&YO
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S
M('1O('1R=64*("`@("`J($!R971U<FX@;6EX960@("!T<G5E(&]N('-U8V-E
M<W,@;W(@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$A434Q);6%G92@D9FEL92P@)&-?
M='EP93TG87!P;&EC871I;VXO;V-T970M<W1R96%M)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;F%M92`]("<G+"`D:7-F:6QE;F%M92`]('1R=64I
M"B`@("!["B`@("`@("`@)&9I;&5D871A(#T@*"1I<V9I;&5N86UE(#T]/2!T
M<G5E*2`_("1T:&ES+3Y?9FEL93)S='(H)&9I;&4I"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Z("1F:6QE.PH@("`@("`@
M(&EF("@D:7-F:6QE;F%M92`]/3T@=')U92D@>PH@("`@("`@("`@("`D9FEL
M96YA;64@/2`H)&YA;64@/3T@)R<@/R!B87-E;F%M92@D9FEL92D@.B!B87-E
M;F%M92@D;F%M92DI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1F
M:6QE;F%M92`](&)A<V5N86UE*"1N86UE*3L*("`@("`@("!]"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&9I;&5D871A*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&9I;&5D871A.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VAT
M;6Q?:6UA9V5S6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G8F]D>2<@("`]/B`D9FEL961A=&$L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@/3X@)&9I
M;&5N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=C7W1Y<&4G(#T^("1C7W1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-I9"<@("`@/3X@;60U*'5N:7%I9"AT:6UE*"DI
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M82!F:6QE('1O('1H92!L:7-T(&]F(&%T=&%C:&UE;G1S+@H@("`@("H*("`@
M("`J($!P87)A;2`@<W1R:6YG("`D9FEL92`@("`@("!4:&4@9FEL92!N86UE
M(&]F('1H92!F:6QE('1O(&%T=&%C:`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($]2('1H92!F:6QE(&1A=&$@:71S96QF"B`@("`@*B!`
M<&%R86T@('-T<FEN9R`@)&-?='EP92`@("`@5&AE(&-O;G1E;G0@='EP90H@
M("`@("H@0'!A<F%M("!S=')I;F<@("1N86UE("`@("`@(%1H92!F:6QE;F%M
M92!O9B!T:&4@871T86-H;65N=`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($]N;'D@=7-E(&EF("1F:6QE(&ES('1H92!F:6QE(&1A=&$*
M("`@("`J($!P87)A;2`@8F]O;"`@("`D:7-&:6QE;F%M92!7:&5T:&5R("1F
M:6QE(&ES(&$@9FEL96YA;64@;W(@;F]T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L=',@=&\@=')U90H@("`@("H@0')E='5R
M;B!M:7AE9"!T<G5E(&]N('-U8V-E<W,@;W(@4$5!4E]%<G)O<B!O8FIE8W0*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9$%T=&%C:&UE;G0H)&9I;&4L("1C7W1Y<&4@/2`G87!P;&EC871I;VXO;V-T
M970M<W1R96%M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@
M/2`G)RP@)&ES9FEL96YA;64@/2!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D96YC;V1I;F<@/2`G8F%S938T)RD*("`@('L*("`@("`@("`D
M9FEL961A=&$@/2`H)&ES9FEL96YA;64@/3T]('1R=64I(#\@)'1H:7,M/E]F
M:6QE,G-T<B@D9FEL92D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(#H@)&9I;&4["B`@("`@("`@:68@*"1I<V9I;&5N86UE
M(#T]/2!T<G5E*2!["B`@("`@("`@("`@("\O($9O<F-E('1H92!N86UE('1H
M92!U<V5R('-U<'!L:65D+"!O=&AE<G=I<V4@=7-E("1F:6QE"B`@("`@("`@
M("`@("1F:6QE;F%M92`]("@A96UP='DH)&YA;64I*2`_("1N86UE(#H@)&9I
M;&4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9I;&5N86UE(#T@
M)&YA;64["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9FEL96YA;64I
M*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*`H@("`@
M("`@("`@("`@("=4:&4@<W5P<&QI960@9FEL96YA;64@9F]R('1H92!A='1A
M8VAM96YT(&-A;EPG="!B92!E;7!T>2<*("`@("`@("`@("`@*3L*("`@("`@
M("!]"B`@("`@("`@)&9I;&5N86UE(#T@8F%S96YA;64H)&9I;&5N86UE*3L*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL961A=&$I*2!["B`@("`@
M("`@("`@(')E='5R;B`D9FEL961A=&$["B`@("`@("`@?0H*("`@("`@("`D
M=&AI<RT^7W!A<G1S6UT@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8F]D>2<@("`@(#T^("1F:6QE9&%T82P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@("`@(#T^("1F:6QE;F%M
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8U]T>7!E)R`@
M(#T^("1C7W1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V5N8V]D:6YG)R`]/B`D96YC;V1I;F<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!'970@=&AE(&-O;G1E;G1S(&]F('1H92!G:79E;B!F:6QE
M(&YA;64@87,@<W1R:6YG"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@
M("1F:6QE7VYA;64@('!A=&@@;V8@9FEL92!T;R!P<F]C97-S"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@8V]N=&5N=',@;V8@)&9I;&5?;F%M90H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9?9FEL93)S
M='(H)&9I;&5?;F%M92D*("`@('L*("`@("`@("!I9B`H(6ES7W)E861A8FQE
M*"1F:6QE7VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=&:6QE(&ES(&YO="!R96%D86)L92`G("X@)&9I;&5?;F%M92D[
M"B`@("`@("`@?0H@("`@("`@(&EF("@A)&9D(#T@9F]P96XH)&9I;&5?;F%M
M92P@)W)B)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T-O=6QD(&YO="!O<&5N("<@+B`D9FEL95]N86UE*3L*("`@("`@("!]
M"B`@("`@("`@)&9I;&5S:7IE(#T@9FEL97-I>F4H)&9I;&5?;F%M92D["B`@
M("`@("`@:68@*"1F:6QE<VEZ92`]/2`P*7L*("`@("`@("`@("`@)&-O;G0@
M/2`@(B(["B`@("`@("`@?65L<V5["B`@("`@("`@("`@("1C;VYT(#T@9G)E
M860H)&9D+"`D9FEL97-I>F4I.PH@("`@("`@('T*("`@("`@("!F8VQO<V4H
M)&9D*3L*("`@("`@("!R971U<FX@)&-O;G0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S(&$@=&5X="!S=6)P87)T('1O('1H92!M:6UE4&%R="!O8FIE
M8W0@86YD"B`@("`@*B!R971U<FYS(&ET(&1U<FEN9R!T:&4@8G5I;&0@<')O
M8V5S<RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("`@5&AE(&]B:F5C
M="!T;R!A9&0@=&AE('!A<G0@=&\L(&]R"B`@("`@*B`@("`@("`@("`@("`@
M("`@;G5L;"!I9B!A(&YE=R!O8FIE8W0@:7,@=&\@8F4@8W)E871E9"X*("`@
M("`J($!P87)A;2!S=')I;F<@("!4:&4@=&5X="!T;R!A9&0N"B`@("`@*B!`
M<F5T=7)N(&]B:F5C="`@5&AE('1E>'0@;6EM95!A<G0@;V)J96-T"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A9&14
M97AT4&%R="@F)&]B:BP@)'1E>'0I"B`@("!["B`@("`@("`@)'!A<F%M<ULG
M8V]N=&5N=%]T>7!E)UT@/2`G=&5X="]P;&%I;B<["B`@("`@("`@)'!A<F%M
M<ULG96YC;V1I;F<G72`@("`@/2`D=&AI<RT^7V)U:6QD7W!A<F%M<ULG=&5X
M=%]E;F-O9&EN9R==.PH@("`@("`@("1P87)A;7-;)V-H87)S970G72`@("`@
M(#T@)'1H:7,M/E]B=6EL9%]P87)A;7-;)W1E>'1?8VAA<G-E="==.PH@("`@
M("`@(&EF("AI<U]O8FIE8W0H)&]B:BDI('L*("`@("`@("`@("`@<F5T=7)N
M("1O8FHM/F%D9%-U8G!A<G0H)'1E>'0L("1P87)A;7,I.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@(')E='5R;B!N97<@36%I;%]M:6UE4&%R="@D
M=&5X="P@)'!A<F%M<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@061D<R!A(&AT;6P@<W5B<&%R="!T;R!T:&4@;6EM95!A<G0@;V)J96-T
M(&%N9`H@("`@("H@<F5T=7)N<R!I="!D=7)I;F<@=&AE(&)U:6QD('!R;V-E
M<W,N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`@(%1H92!O8FIE8W0@
M=&\@861D('1H92!P87)T('1O+"!O<@H@("`@("H@("`@("`@("`@("`@("`@
M(&YU;&P@:68@82!N97<@;V)J96-T(&ES('1O(&)E(&-R96%T960N"B`@("`@
M*B!`<F5T=7)N(&]B:F5C="`@5&AE(&AT;6P@;6EM95!A<G0@;V)J96-T"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@)E]A
M9&1(=&UL4&%R="@F)&]B:BD*("`@('L*("`@("`@("`D<&%R86US6R=C;VYT
M96YT7W1Y<&4G72`]("=T97AT+VAT;6PG.PH@("`@("`@("1P87)A;7-;)V5N
M8V]D:6YG)UT@("`@(#T@)'1H:7,M/E]B=6EL9%]P87)A;7-;)VAT;6Q?96YC
M;V1I;F<G73L*("`@("`@("`D<&%R86US6R=C:&%R<V5T)UT@("`@("`]("1T
M:&ES+3Y?8G5I;&1?<&%R86US6R=H=&UL7V-H87)S970G73L*("`@("`@("!I
M9B`H:7-?;V)J96-T*"1O8FHI*2!["B`@("`@("`@("`@(')E='5R;B`D;V)J
M+3YA9&13=6)P87)T*"1T:&ES+3Y?:'1M;&)O9'DL("1P87)A;7,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!N97<@36%I;%]M:6UE
M4&%R="@D=&AI<RT^7VAT;6QB;V1Y+"`D<&%R86US*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W(&UI;65087)T(&]B
M:F5C="P@=7-I;F<@;75L=&EP87)T+VUI>&5D(&%S"B`@("`@*B!T:&4@:6YI
M=&EA;"!C;VYT96YT+71Y<&4@86YD(')E='5R;G,@:70@9'5R:6YG('1H90H@
M("`@("H@8G5I;&0@<')O8V5S<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="`@5&AE(&UU;'1I<&%R="]M:7AE9"!M:6UE4&%R="!O8FIE8W0*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7V%D
M9$UI>&5D4&%R="@I"B`@("!["B`@("`@("`@)'!A<F%M<ULG8V]N=&5N=%]T
M>7!E)UT@/2`G;75L=&EP87)T+VUI>&5D)SL*("`@("`@("!R971U<FX@;F5W
M($UA:6Q?;6EM95!A<G0H)R<L("1P87)A;7,I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@061D<R!A(&UU;'1I<&%R="]A;'1E<FYA=&EV92!P87)T('1O(&$@
M;6EM95!A<G0*("`@("`J(&]B:F5C="`H;W(@8W)E871E<R!O;F4I+"!A;F0@
M<F5T=7)N<R!I="!D=7)I;F<*("`@("`J('1H92!B=6EL9"!P<F]C97-S+@H@
M("`@("H*("`@("`J($!P87)A;2`@;6EX960@("!4:&4@;V)J96-T('1O(&%D
M9"!T:&4@<&%R="!T;RP@;W(*("`@("`J("`@("`@("`@("`@("`@("!N=6QL
M(&EF(&$@;F5W(&]B:F5C="!I<R!T;R!B92!C<F5A=&5D+@H@("`@("H@0')E
M='5R;B!O8FIE8W0@(%1H92!M=6QT:7!A<G0O;6EX960@;6EM95!A<G0@;V)J
M96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@)E]A9&1!;'1E<FYA=&EV95!A<G0H)B1O8FHI"B`@("!["B`@("`@("`@
M)'!A<F%M<ULG8V]N=&5N=%]T>7!E)UT@/2`G;75L=&EP87)T+V%L=&5R;F%T
M:79E)SL*("`@("`@("!I9B`H:7-?;V)J96-T*"1O8FHI*2!["B`@("`@("`@
M("`@(')E='5R;B`D;V)J+3YA9&13=6)P87)T*"<G+"`D<&%R86US*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM
M95!A<G0H)R<L("1P87)A;7,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*
M("`@("`J($%D9',@82!M=6QT:7!A<G0O<F5L871E9"!P87)T('1O(&$@;6EM
M95!A<G0*("`@("`J(&]B:F5C="`H;W(@8W)E871E<R!O;F4I+"!A;F0@<F5T
M=7)N<R!I="!D=7)I;F<*("`@("`J('1H92!B=6EL9"!P<F]C97-S+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`@("!4:&4@;V)J96-T('1O(&%D9"!T
M:&4@<&%R="!T;RP@;W(*("`@("`J("`@("`@("`@("`@("`@("!N=6QL(&EF
M(&$@;F5W(&]B:F5C="!I<R!T;R!B92!C<F5A=&5D"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="`@5&AE(&UU;'1I<&%R="]M:7AE9"!M:6UE4&%R="!O8FIE8W0*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F
M7V%D9%)E;&%T961087)T*"8D;V)J*0H@("`@>PH@("`@("`@("1P87)A;7-;
M)V-O;G1E;G1?='EP92==(#T@)VUU;'1I<&%R="]R96QA=&5D)SL*("`@("`@
M("!I9B`H:7-?;V)J96-T*"1O8FHI*2!["B`@("`@("`@("`@(')E='5R;B`D
M;V)J+3YA9&13=6)P87)T*"<G+"`D<&%R86US*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("!R971U<FX@;F5W($UA:6Q?;6EM95!A<G0H)R<L("1P
M87)A;7,I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D9',@
M86X@:'1M;"!I;6%G92!S=6)P87)T('1O(&$@;6EM95!A<G0@;V)J96-T"B`@
M("`@*B!A;F0@<F5T=7)N<R!I="!D=7)I;F<@=&AE(&)U:6QD('!R;V-E<W,N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@(%1H92!M:6UE4&%R="!T
M;R!A9&0@=&AE(&EM86=E('1O"B`@("`@*B!`<&%R86T@(&%R<F%Y("`@5&AE
M(&EM86=E(&EN9F]R;6%T:6]N"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE
M(&EM86=E(&UI;65087)T(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N("9?861D2'1M;$EM86=E4&%R="@F)&]B
M:BP@)'9A;'5E*0H@("`@>PH@("`@("`@("1P87)A;7-;)V-O;G1E;G1?='EP
M92==(#T@)'9A;'5E6R=C7W1Y<&4G73L*("`@("`@("`D<&%R86US6R=E;F-O
M9&EN9R==("`@("`]("=B87-E-C0G.PH@("`@("`@("1P87)A;7-;)V1I<W!O
M<VET:6]N)UT@(#T@)VEN;&EN92<["B`@("`@("`@)'!A<F%M<ULG9&9I;&5N
M86UE)UT@("`@/2`D=F%L=65;)VYA;64G73L*("`@("`@("`D<&%R86US6R=C
M:60G72`@("`@("`@("`]("1V86QU95LG8VED)UT["B`@("`@("`@)&]B:BT^
M861D4W5B<&%R="@D=F%L=65;)V)O9'DG72P@)'!A<F%M<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!!9&1S(&%N(&%T=&%C:&UE;G0@<W5B<&%R="!T;R!A
M(&UI;65087)T(&]B:F5C=`H@("`@("H@86YD(')E='5R;G,@:70@9'5R:6YG
M('1H92!B=6EL9"!P<F]C97-S+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J
M96-T("!4:&4@;6EM95!A<G0@=&\@861D('1H92!I;6%G92!T;PH@("`@("H@
M0'!A<F%M("!A<G)A>2`@(%1H92!A='1A8VAM96YT(&EN9F]R;6%T:6]N"B`@
M("`@*B!`<F5T=7)N(&]B:F5C="`@5&AE(&EM86=E(&UI;65087)T(&]B:F5C
M=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9?861D071T86-H;65N=%!A<G0H)B1O8FHL("1V86QU92D*("`@('L*("`@
M("`@("`D<&%R86US6R=C;VYT96YT7W1Y<&4G72`]("1V86QU95LG8U]T>7!E
M)UT["B`@("`@("`@)'!A<F%M<ULG96YC;V1I;F<G72`@("`@/2`D=F%L=65;
M)V5N8V]D:6YG)UT["B`@("`@("`@)'!A<F%M<ULG9&ES<&]S:71I;VXG72`@
M/2`G871T86-H;65N="<["B`@("`@("`@)'!A<F%M<ULG9&9I;&5N86UE)UT@
M("`@/2`D=F%L=65;)VYA;64G73L*("`@("`@("`D;V)J+3YA9&13=6)P87)T
M*"1V86QU95LG8F]D>2==+"`D<&%R86US*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($)U:6QD<R!T:&4@;75L=&EP87)T(&UE<W-A9V4@9G)O;2!T:&4@;&ES
M="`H)'1H:7,M/E]P87)T<RD@86YD"B`@("`@*B!R971U<FYS('1H92!M:6UE
M(&-O;G1E;G0N"B`@("`@*@H@("`@("H@0'!A<F%M("!A<G)A>2`@0G5I;&0@
M<&%R86UE=&5R<R!T:&%T(&-H86YG92!T:&4@=V%Y('1H92!E;6%I;`H@("`@
M("H@("`@("`@("`@("`@("`@:7,@8G5I;'0N(%-H;W5L9"!B92!A<W-O8VEA
M=&EV92X@0V%N(&-O;G1A:6XZ"B`@("`@*B`@("`@("`@("`@("`@("!T97AT
M7V5N8V]D:6YG("`M("!7:&%T(&5N8V]D:6YG('1O('5S92!F;W(@<&QA:6X@
M=&5X=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1&5F875L="!I<R`W8FET"B`@("`@*B`@("`@("`@("`@("`@("!H=&UL7V5N
M8V]D:6YG("`M("!7:&%T(&5N8V]D:6YG('1O('5S92!F;W(@:'1M;`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1&5F875L="!I
M<R!Q=6]T960M<')I;G1A8FQE"B`@("`@*B`@("`@("`@("`@("`@("`W8FET
M7W=R87`@("`@("`M("!.=6UB97(@;V8@8VAA<F%C=&5R<R!B969O<F4@=&5X
M="!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=W)A<'!E9"!I;B`W8FET(&5N8V]D:6YG"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$969A=6QT(&ES(#DY.`H@("`@("H@("`@
M("`@("`@("`@("`@:'1M;%]C:&%R<V5T("`@+2`@5&AE(&-H87)A8W1E<B!S
M970@=&\@=7-E(&9O<B!H=&UL+@H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@1&5F875L="!I<R!I<V\M.#@U.2TQ"B`@("`@*B`@
M("`@("`@("`@("`@("!T97AT7V-H87)S970@("`M("!4:&4@8VAA<F%C=&5R
M('-E="!T;R!U<V4@9F]R('1E>'0N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!$969A=6QT(&ES(&ES;RTX.#4Y+3$*("`@("`J
M("`@("`@("`@("`@("`@(&AE861?8VAA<G-E="`@("T@(%1H92!C:&%R86-T
M97(@<V5T('1O('5S92!F;W(@:&5A9&5R<RX*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'0@:7,@:7-O+3@X-3DM,0H@
M("`@("H@0')E='5R;B!S=')I;F<@5&AE(&UI;64@8V]N=&5N=`H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E="@D8G5I
M;&1?<&%R86US(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-S970H)&)U
M:6QD7W!A<F%M<RDI('L*("`@("`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@
M)'9A;'5E*2`](&5A8V@H)&)U:6QD7W!A<F%M<RDI('L*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8G5I;&1?<&%R86US6R1K97E=(#T@)'9A;'5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES
M+3Y?:'1M;%]I;6%G97,I($%.1"!I<W-E="@D=&AI<RT^7VAT;6QB;V1Y*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7VAT;6Q?:6UA9V5S(&%S
M("1V86QU92D@>PH@("`@("`@("`@("`@("`@)')E9V5X(#T@)R,H7',I*"@_
M:2ES<F-\8F%C:V=R;W5N9'QH<F5F*#\M:2DI7',J/5QS*BA;(EPG73\I)R`N
M('!R96=?<75O=&4H)'9A;'5E6R=N86UE)UTL("<C)RD@+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@)UPS(R<["B`@("`@("`@("`@("`@("`D<F5P(#T@
M)UPQ7#(]7#-C:60Z)R`N("1V86QU95LG8VED)UT@+B=<,R<["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7VAT;6QB;V1Y(#T@<')E9U]R97!L86-E*"1R96=E
M>"P@)')E<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]H=&UL8F]D>0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1N=6QL("`@("`@("`](&YU;&P["B`@("`@("`@)&%T=&%C:&UE;G1S(#T@
M(65M<'1Y*"1T:&ES+3Y?<&%R=',I("`@("`@("`@("`@("`@(#\@=')U92`Z
M(&9A;'-E.PH@("`@("`@("1H=&UL7VEM86=E<R`]("%E;7!T>2@D=&AI<RT^
M7VAT;6Q?:6UA9V5S*2`@("`@("`@("`_('1R=64@.B!F86QS93L*("`@("`@
M("`D:'1M;"`@("`@("`@/2`A96UP='DH)'1H:7,M/E]H=&UL8F]D>2D@("`@
M("`@("`@("`@/R!T<G5E(#H@9F%L<V4["B`@("`@("`@)'1E>'0@("`@("`@
M(#T@*"$D:'1M;"!!3D0@(65M<'1Y*"1T:&ES+3Y?='AT8F]D>2DI(#\@=')U
M92`Z(&9A;'-E.PH*("`@("`@("!S=VET8V@@*'1R=64I('L*("`@("`@("!C
M87-E("1T97AT($%.1"`A)&%T=&%C:&UE;G1S.@H@("`@("`@("`@("`D;65S
M<V%G92`])B`D=&AI<RT^7V%D9%1E>'1087)T*"1N=6QL+"`D=&AI<RT^7W1X
M=&)O9'DI.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`A)'1E
M>'0@04Y$("$D:'1M;"!!3D0@)&%T=&%C:&UE;G1S.@H@("`@("`@("`@("`D
M;65S<V%G92`])B`D=&AI<RT^7V%D9$UI>&5D4&%R="@I.PH@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7W!A<G1S*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1!='1A8VAM96YT4&%R
M="@D;65S<V%G92P@)'1H:7,M/E]P87)T<ULD:5TI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("1T97AT($%.1"`D
M871T86-H;65N=',Z"B`@("`@("`@("`@("1M97-S86=E(#TF("1T:&ES+3Y?
M861D36EX961087)T*"D["B`@("`@("`@("`@("1T:&ES+3Y?861D5&5X=%!A
M<G0H)&UE<W-A9V4L("1T:&ES+3Y?='AT8F]D>2D["B`@("`@("`@("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1T:&ES+3Y?<&%R=',I.R`D:2LK*2![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$%T=&%C:&UE;G1087)T*"1M
M97-S86=E+"`D=&AI<RT^7W!A<G1S6R1I72D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)&AT;6P@04Y$("$D871T
M86-H;65N=',@04Y$("$D:'1M;%]I;6%G97,Z"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W1X=&)O9'DI*2!["B`@("`@("`@("`@("`@("`D;65S
M<V%G92`])B`D=&AI<RT^7V%D9$%L=&5R;F%T:79E4&%R="@D;G5L;"D["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9%1E>'1087)T*"1M97-S86=E+"`D
M=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1(
M=&UL4&%R="@D;65S<V%G92D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D;65S<V%G92`])B`D=&AI<RT^7V%D9$AT;6Q087)T*"1N
M=6QL*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@
M("`@8V%S92`D:'1M;"!!3D0@(21A='1A8VAM96YT<R!!3D0@)&AT;6Q?:6UA
M9V5S.@H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T>'1B;V1Y*2D@
M>PH@("`@("`@("`@("`@("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1!;'1E
M<FYA=&EV95!A<G0H)&YU;&PI.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A
M9&1497AT4&%R="@D;65S<V%G92P@)'1H:7,M/E]T>'1B;V1Y*3L*("`@("`@
M("`@("`@("`@("1R96QA=&5D(#TF("1T:&ES+3Y?861D4F5L871E9%!A<G0H
M)&UE<W-A9V4I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)&UE<W-A9V4@/28@)'1H:7,M/E]A9&1296QA=&5D4&%R="@D;G5L;"D[
M"B`@("`@("`@("`@("`@("`D<F5L871E9"`])B`D;65S<V%G93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V%D9$AT;6Q087)T*"1R96QA
M=&5D*3L*("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H)'1H
M:7,M/E]H=&UL7VEM86=E<RD[("1I*RLI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?861D2'1M;$EM86=E4&%R="@D<F5L871E9"P@)'1H:7,M/E]H=&UL
M7VEM86=E<ULD:5TI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("1H=&UL($%.1"`D871T86-H;65N=',@04Y$("$D
M:'1M;%]I;6%G97,Z"B`@("`@("`@("`@("1M97-S86=E(#TF("1T:&ES+3Y?
M861D36EX961087)T*"D["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W1X=&)O9'DI*2!["B`@("`@("`@("`@("`@("`D86QT(#TF("1T:&ES+3Y?
M861D06QT97)N871I=F5087)T*"1M97-S86=E*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?861D5&5X=%!A<G0H)&%L="P@)'1H:7,M/E]T>'1B;V1Y*3L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D2'1M;%!A<G0H)&%L="D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9$AT;6Q087)T*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7W!A<G1S*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1!='1A8VAM96YT4&%R
M="@D;65S<V%G92P@)'1H:7,M/E]P87)T<ULD:5TI.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("1H=&UL($%.1"`D
M871T86-H;65N=',@04Y$("1H=&UL7VEM86=E<SH*("`@("`@("`@("`@)&UE
M<W-A9V4@/28@)'1H:7,M/E]A9&1-:7AE9%!A<G0H*3L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?='AT8F]D>2DI('L*("`@("`@("`@("`@("`@
M("1A;'0@/28@)'1H:7,M/E]A9&1!;'1E<FYA=&EV95!A<G0H)&UE<W-A9V4I
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1497AT4&%R="@D86QT+"`D
M=&AI<RT^7W1X=&)O9'DI.PH@("`@("`@("`@("`@("`@)')E;"`])B`D=&AI
M<RT^7V%D9%)E;&%T961087)T*"1A;'0I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E;"`])B`D=&AI<RT^7V%D9%)E;&%T9610
M87)T*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^7V%D9$AT;6Q087)T*"1R96PI.PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"!C;W5N="@D=&AI<RT^7VAT;6Q?:6UA9V5S*3L@)&DK*RD@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1(=&UL26UA9V5087)T*"1R96PL
M("1T:&ES+3Y?:'1M;%]I;6%G97-;)&E=*3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D=&AI<RT^7W!A<G1S
M*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1!='1A8VAM
M96YT4&%R="@D;65S<V%G92P@)'1H:7,M/E]P87)T<ULD:5TI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D;65S<V%G92DI('L*("`@("`@("`@("`@)&]U='!U="`]
M("1M97-S86=E+3YE;F-O9&4H*3L*("`@("`@("`@("`@)'1H:7,M/E]H96%D
M97)S(#T@87)R87E?;65R9V4H)'1H:7,M/E]H96%D97)S+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T6R=H96%D
M97)S)UTI.PH@("`@("`@("`@("!R971U<FX@)&]U='!U=%LG8F]D>2==.PH*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A;B!A<G)A
M>2!W:71H('1H92!H96%D97)S(&YE961E9"!T;R!P<F5P96YD('1O('1H92!E
M;6%I;`H@("`@("H@*$U)344M5F5R<VEO;B!A;F0@0V]N=&5N="U4>7!E*2X@
M1F]R;6%T(&]F(&%R9W5M96YT(&ES.@H@("`@("H@)&%R<F%Y6R=H96%D97(M
M;F%M92==(#T@)VAE861E<BUV86QU92<["B`@("`@*@H@("`@("H@0'!A<F%M
M("!A<G)A>2`D>'1R85]H96%D97)S($%S<V]C(&%R<F%Y('=I=&@@86YY(&5X
M=')A(&AE861E<G,N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@3W!T:6]N86PN"B`@("`@*B!`<F5T=7)N(&%R<F%Y($%S<V]C(&%R<F%Y
M('=I=&@@=&AE(&UI;64@:&5A9&5R<PH@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@)FAE861E<G,H)'AT<F%?:&5A9&5R<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@+R\@0V]N=&5N="U4>7!E(&AE861E<B!S
M:&]U;&0@86QR96%D>2!B92!P<F5S96YT+`H@("`@("`@("\O(%-O(&IU<W0@
M861D(&UI;64@=F5R<VEO;B!H96%D97(*("`@("`@("`D:&5A9&5R<ULG34E-
M12U697)S:6]N)UT@/2`G,2XP)SL*("`@("`@("!I9B`H:7-S970H)'AT<F%?
M:&5A9&5R<RDI('L*("`@("`@("`@("`@)&AE861E<G,@/2!A<G)A>5]M97)G
M92@D:&5A9&5R<RP@)'AT<F%?:&5A9&5R<RD["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?:&5A9&5R<R`](&%R<F%Y7VUE<F=E*"1H96%D97)S+"`D=&AI
M<RT^7VAE861E<G,I.PH*("`@("`@("!R971U<FX@)'1H:7,M/E]E;F-O9&5(
M96%D97)S*"1T:&ES+3Y?:&5A9&5R<RD["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!'970@=&AE('1E>'0@=F5R<VEO;B!O9B!T:&4@:&5A9&5R<PH@("`@("H@
M*'5S969U;&P@:68@>6]U('=A;G0@=&\@=7-E('1H92!02%`@;6%I;"@I(&9U
M;F-T:6]N*0H@("`@("H*("`@("`J($!P87)A;2`@87)R87D@("`D>'1R85]H
M96%D97)S($%S<V]C(&%R<F%Y('=I=&@@86YY(&5X=')A(&AE861E<G,N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!/<'1I;VYA;"X*
M("`@("`J($!R971U<FX@<W1R:6YG("!0;&%I;B!T97AT(&AE861E<G,*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1X=$AE
M861E<G,H)'AT<F%?:&5A9&5R<R`](&YU;&PI"B`@("!["B`@("`@("`@)&AE
M861E<G,@/2`D=&AI<RT^:&5A9&5R<R@D>'1R85]H96%D97)S*3L*("`@("`@
M("`D<F5T(#T@)R<["B`@("`@("`@9F]R96%C:"`H)&AE861E<G,@87,@)&ME
M>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1R970@+CT@(B1K97DZ("1V86PB
M("X@34%)3%]-24U%7T-23$8["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<F5T.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@4W5B:F5C="!H
M96%D97(*("`@("`J"B`@("`@*B!`<&%R86T@('-T<FEN9R`D<W5B:F5C="!3
M=')I;F<@=&\@<V5T('1H92!S=6)J96-T('1O"B`@("`@*B!A8V-E<W,@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S9713=6)J96-T*"1S=6)J96-T
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:&5A9&5R<ULG4W5B:F5C="==(#T@
M)'-U8FIE8W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@86X@96UA:6P@
M=&\@=&AE($9R;VT@*'1H92!S96YD97(I(&AE861E<@H@("`@("H*("`@("`J
M($!P87)A;2`@<W1R:6YG("1E;6%I;"!4:&4@96UA:6P@9&ER96-T:6]N('1O
M(&%D9`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T1G)O;2@D96UA:6PI"B`@("!["B`@("`@("`@)'1H:7,M/E]H96%D
M97)S6R=&<F]M)UT@/2`D96UA:6P["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&0@86X@96UA:6P@=&\@=&AE($-C("AC87)B;VX@8V]P>2D@:&5A9&5R"B`@
M("`@*B`H;75L=&EP;&4@8V%L;',@=&\@=&AI<R!M971H;V0@87)E(&%L;&]W
M960I"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&5M86EL(%1H92!E
M;6%I;"!D:7)E8W1I;VX@=&\@861D"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!A9&1#8R@D96UA:6PI"B`@("!["B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULG0V,G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]H96%D97)S6R=#8R==("X]("(L("1E;6%I;"(["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R=#
M8R==(#T@)&5M86EL.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9"!A;B!E;6%I;"!T;R!T:&4@0F-C("AB;&%N:R!C87)B;VX@8V]P>2D@
M:&5A9&5R"B`@("`@*B`H;75L=&EP;&4@8V%L;',@=&\@=&AI<R!M971H;V0@
M87)E(&%L;&]W960I"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)&5M
M86EL(%1H92!E;6%I;"!D:7)E8W1I;VX@=&\@861D"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1"8V,H)&5M86EL*0H@
M("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)T)C8R==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)T)C8R==("X]("(L
M("1E;6%I;"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M
M/E]H96%D97)S6R="8V,G72`]("1E;6%I;#L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!%;F-O9&5S(&$@:&5A9&5R(&%S('!E<B!21D,R,#0W
M"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@("1I;G!U="!4:&4@:&5A
M9&5R(&1A=&$@=&\@96YC;V1E"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@16YC
M;V1E9"!D871A"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V5N8V]D94AE861E<G,H)&EN<'5T*0H@("`@>PH@("`@("`@
M(&9O<F5A8V@@*"1I;G!U="!A<R`D:&1R7VYA;64@/3X@)&AD<E]V86QU92D@
M>PH@("`@("`@("`@("!P<F5G7VUA=&-H7V%L;"@G+RA<=RI;7'@X,"U<>$9&
M72M<=RHI+R<L("1H9')?=F%L=64L("1M871C:&5S*3L*("`@("`@("`@("`@
M9F]R96%C:"`H)&UA=&-H97-;,5T@87,@)'9A;'5E*2!["B`@("`@("`@("`@
M("`@("`D<F5P;&%C96UE;G0@/2!P<F5G7W)E<&QA8V4H)R\H6UQX.#`M7'A&
M1ETI+V4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<B/2(@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<G1O=7!P97(H9&5C:&5X*&]R9"@B7#$B*2DI)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%L=64I.PH@("`@("`@("`@("`@("`@)&AD<E]V86QU92`]('-T<E]R97!L
M86-E*"1V86QU92P@)ST_)R`N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]B=6EL9%]P87)A;7-;)VAE861?8VAA
M<G-E="==("X*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G/U$_)R`N("1R97!L86-E;65N="`N("<_/2<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&AD<E]V86QU92D["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&EN<'5T6R1H9')?;F%M95T@/2`D
M:&1R7W9A;'5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I;G!U=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@;V)J96-T)W,@96YD+6]F
M+6QI;F4@86YD(&1E9FEN92!T:&4@8V]N<W1A;G0@:68@87!P;&EC86)L90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&5O;"!%;F0@3V8@3&EN92!S
M97%U96YC90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%]S971%3TPH)&5O;"D*("`@('L*("`@("`@("`D=&AI<RT^7V5O
M;"`]("1E;VP["B`@("`@("`@:68@*"%D969I;F5D*"=-04E,7TU)345?0U),
M1B<I*2!["B`@("`@("`@("`@(&1E9FEN92@G34%)3%]-24U%7T-23$8G+"`D
M=&AI<RT^7V5O;"P@=')U92D["B`@("`@("`@?0H@("`@?0H*("`@(`H*?2`O
M+R!%;F0@;V8@8VQA<W,*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+TUA:6PO;6%I;"YP:'``````````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3$W,S<@,3`U,34T,S0Q,S4@,#(Q
M,#$Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@
M;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<CH@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@;6%I;"YP:'`L
M=B`Q+C$U(#(P,#4O,3`O,3`@,#0Z,38Z,C8@:F]N($5X<"`D"@HO*BH*("H@
M:6YT97)N86P@4$A0+6UA:6PH*2!I;7!L96UE;G1A=&EO;B!O9B!T:&4@4$5!
M4B!-86EL.CH@:6YT97)F86-E+@H@*B!`<&%C:V%G92!-86EL"B`J($!V97)S
M:6]N("12979I<VEO;CH@,2XQ-2`D"B`J+PIC;&%S<R!-86EL7VUA:6P@97AT
M96YD<R!-86EL('L*"B`@("`O*BH*("`@("`J($%N>2!A<F=U;65N=',@=&\@
M<&%S<R!T;R!T:&4@;6%I;"@I(&9U;F-T:6]N+@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1?<&%R86US(#T@)R<["@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!);G-T86YT:6%T97,@
M82!N97<@36%I;%]M86EL.CH@;V)J96-T(&)A<V5D(&]N('1H92!P87)A;65T
M97)S"B`@("`@*B!P87-S960@:6XN"B`@("`@*@H@("`@("H@0'!A<F%M(&%R
M<F%Y("1P87)A;7,@17AT<F$@87)G=6UE;G1S(&9O<B!T:&4@;6%I;"@I(&9U
M;F-T:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!-86EL7VUA:6PH)'!A<F%M
M<R`](&YU;&PI"B`@("!["B`@("`@("`@+RH@5&AE(&]T:&5R(&UA:6P@:6UP
M;&5M96YT871I;VYS(&%C8V5P="!P87)A;65T97)S(&%S(&%R<F%Y<RX*("`@
M("`@("`@*B!);B!T:&4@:6YT97)E<W0@;V8@8F5I;F<@8V]N<VES=&5N="P@
M97AP;&]D92!A;B!A<G)A>2!I;G1O"B`@("`@("`@("H@82!S=')I;F<@;V8@
M<&%R86UE=&5R(&%R9W5M96YT<RX@*B\*("`@("`@("!I9B`H:7-?87)R87DH
M)'!A<F%M<RDI('L*("`@("`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!J;VEN
M*"<@)RP@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/E]P87)A;7,@/2`D<&%R86US.PH@("`@("`@('T*"B`@("`@("`@
M+RH@0F5C875S92!T:&4@;6%I;"@I(&9U;F-T:6]N(&UA>2!P87-S(&AE861E
M<G,@87,@8V]M;6%N9`H@("`@("`@("`J(&QI;F4@87)G=6UE;G1S+"!W92!C
M86XG="!G=6%R86YT964@=&AE('5S92!O9B!T:&4@<W1A;F1A<F0*("`@("`@
M("`@*B`B7')<;B(@<V5P87)A=&]R+B`@26YS=&5A9"P@=V4@=7-E('1H92!S
M>7-T96TG<R!N871I=F4@;&EN90H@("`@("`@("`J('-E<&%R871O<BX@*B\*
M("`@("`@("!I9B`H9&5F:6YE9"A02%!?14],*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^<V5P(#T@4$A07T5/3#L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^<V5P(#T@*'-T<G!O<RA02%!?3U,L("=724XG*2`]/3T@
M9F%L<V4I(#\@(EQN(B`Z(")<<EQN(CL*("`@("`@("!]"B`@("!]"@H)+RHJ
M"B`@("`@*B!);7!L96UE;G1S($UA:6Q?;6%I;#HZ<V5N9"@I(&9U;F-T:6]N
M('5S:6YG('!H<"=S(&)U:6QT+6EN(&UA:6PH*0H@("`@("H@8V]M;6%N9"X*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)')E8VEP:65N=',@16ET:&5R
M(&$@8V]M;6$M<V5P97)A=&5D(&QI<W0@;V8@<F5C:7!I96YT<PH@("`@("H@
M("`@("`@("`@("`@("A21D,X,C(@8V]M<&QI86YT*2P@;W(@86X@87)R87D@
M;V8@<F5C:7!I96YT<RP*("`@("`J("`@("`@("`@("`@("!E86-H(%)&0S@R
M,B!V86QI9"X@5&AI<R!M87D@8V]N=&%I;B!R96-I<&EE;G1S(&YO=`H@("`@
M("H@("`@("`@("`@("`@('-P96-I9FEE9"!I;B!T:&4@:&5A9&5R<RP@9F]R
M($)C8SHL(')E<V5N9&EN9PH@("`@("H@("`@("`@("`@("`@(&UE<W-A9V5S
M+"!E=&,N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1H96%D97)S(%1H
M92!A<G)A>2!O9B!H96%D97)S('1O('-E;F0@=VET:"!T:&4@;6%I;"P@:6X@
M86X*("`@("`J("`@("`@("`@("`@("!A<W-O8VEA=&EV92!A<G)A>2P@=VAE
M<F4@=&AE(&%R<F%Y(&ME>2!I<R!T:&4*("`@("`J("`@("`@("`@("`@("!H
M96%D97(@;F%M92`H:64L("=3=6)J96-T)RDL(&%N9"!T:&4@87)R87D@=F%L
M=64*("`@("`J("`@("`@("`@("`@("!I<R!T:&4@:&5A9&5R('9A;'5E("AI
M92P@)W1E<W0G*2X@5&AE(&AE861E<@H@("`@("H@("`@("`@("`@("`@('!R
M;V1U8V5D(&9R;VT@=&AO<V4@=F%L=65S('=O=6QD(&)E("=3=6)J96-T.@H@
M("`@("H@("`@("`@("`@("`@('1E<W0G+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&)O9'D@5&AE(&9U;&P@=&5X="!O9B!T:&4@;65S<V%G92!B
M;V1Y+"!I;F-L=61I;F<@86YY"B`@("`@*B`@("`@("`@("`@("`@($UI;64@
M<&%R=',L(&5T8RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D(%)E='5R
M;G,@=')U92!O;B!S=6-C97-S+"!O<B!A(%!%05)?17)R;W(*("`@("`J("`@
M("`@("`@("`@("`@8V]N=&%I;FEN9R!A(&1E<V-R:7!T:79E(&5R<F]R(&UE
M<W-A9V4@;VX*("`@("`J("`@("`@("`@("`@("`@9F%I;'5R92X*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S
M96YD*"1R96-I<&EE;G1S+"`D:&5A9&5R<RP@)&)O9'DI"B`@("!["B`@("`@
M("`@+R\@268@=V4G<F4@<&%S<V5D(&%N(&%R<F%Y(&]F(')E8VEP:65N=',L
M(&EM<&QO9&4@:70N"B`@("`@("`@:68@*&ES7V%R<F%Y*"1R96-I<&EE;G1S
M*2D@>PH@("`@("`@("`@("`D<F5C:7!I96YT<R`](&EM<&QO9&4H)RP@)RP@
M)')E8VEP:65N=',I.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T('1H92!3
M=6)J96-T(&]U="!O9B!T:&4@:&5A9&5R<R!A<G)A>2!S;R!T:&%T('=E(&-A
M;@H@("`@("`@("\O('!A<W,@:70@87,@82!S97!E<F%T92!A<F=U;65N="!T
M;R!M86EL*"DN"B`@("`@("`@)'-U8FIE8W0@/2`G)SL*("`@("`@("!I9B`H
M:7-S970H)&AE861E<G-;)U-U8FIE8W0G72DI('L*("`@("`@("`@("`@)'-U
M8FIE8W0@/2`D:&5A9&5R<ULG4W5B:F5C="==.PH@("`@("`@("`@("!U;G-E
M="@D:&5A9&5R<ULG4W5B:F5C="==*3L*("`@("`@("!]"@H@("`@("`@("\O
M($9L871T96X@=&AE(&AE861E<G,@;W5T+@H@("`@("`@("1H96%D97)%;&5M
M96YT<R`]("1T:&ES+3YP<F5P87)E2&5A9&5R<R@D:&5A9&5R<RD["B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&AE861E<D5L96UE;G1S*2D@>PH@("`@
M("`@("`@("!R971U<FX@)&AE861E<D5L96UE;G1S.PH@("`@("`@('T*("`@
M("`@("!L:7-T*"P@)'1E>'1?:&5A9&5R<RD@/2`D:&5A9&5R16QE;65N=',[
M"@H@("`@("`@("\J"B`@("`@("`@("H@5V4@;VYL>2!U<V4@;6%I;"@I)W,@
M;W!T:6]N86P@9FEF=&@@<&%R86UE=&5R(&EF('1H92!A9&1I=&EO;F%L"B`@
M("`@("`@("H@<&%R86UE=&5R<R!H879E(&)E96X@<')O=FED960@86YD('=E
M)W)E(&YO="!R=6YN:6YG(&EN('-A9F4@;6]D92X*("`@("`@("`@*B\*("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]P87)A;7,I('Q\(&EN:5]G970H)W-A
M9F5?;6]D92<I*2!["B`@("`@("`@("`@("1R97-U;'0@/2!M86EL*"1R96-I
M<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T97AT7VAE861E<G,I.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2!M86EL*"1R96-I
M<&EE;G1S+"`D<W5B:F5C="P@)&)O9'DL("1T97AT7VAE861E<G,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%R86US*3L*("`@("`@
M("!]"@H@("`@("`@("\J"B`@("`@("`@("H@268@=&AE(&UA:6PH*2!F=6YC
M=&EO;B!R971U<FYE9"!F86EL=7)E+"!W92!N965D('1O(&-R96%T92!A"B`@
M("`@("`@("H@4$5!4E]%<G)O<B!O8FIE8W0@86YD(')E='5R;B!I="!I;G-T
M96%D(&]F('1H92!B;V]L96%N(')E<W5L="X*("`@("`@("`@*B\*("`@("`@
M("!I9B`H)')E<W5L="`]/3T@9F%L<V4I('L*("`@("`@("`@("`@)')E<W5L
M="`](%!%05(Z.G)A:7-E17)R;W(H)VUA:6PH*2!R971U<FYE9"!F86EL=7)E
M)RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*
M"GT*````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]-86EL+VYU;&PN<&AP````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T-S<Q(#$P-3$U-#,T
M,3,U(#`R,3`T,0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z(%!H:6P@2V5R;FEC:R`\<&AI
M;&M`<F]T9FPN8V]M+F%U/B`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&YU
M;&PN<&AP+'8@,2XR(#(P,#0O,#0O,#8@,#4Z,3DZ,#,@:F]N($5X<"`D"B\O
M"@HO*BH*("H@3G5L;"!I;7!L96UE;G1A=&EO;B!O9B!T:&4@4$5!4B!-86EL
M.CH@:6YT97)F86-E+@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!-
M86EL"B`J($!V97)S:6]N("12979I<VEO;CH@,2XR("0*("HO"F-L87-S($UA
M:6Q?;G5L;"!E>'1E;F1S($UA:6P@>PH*("`@("\J*@H@("`@("H@26UP;&5M
M96YT<R!-86EL7VYU;&PZ.G-E;F0H*2!F=6YC=&EO;BX@4VEL96YT;'D@9&ES
M8V%R9',@86QL"B`@("`@*B!M86EL+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`D<F5C:7!I96YT<R!%:71H97(@82!C;VUM82US97!E<F%T960@;&ES
M="!O9B!R96-I<&EE;G1S"B`@("`@*B`@("`@("`@("`@("`@*%)&0S@R,B!C
M;VUP;&EA;G0I+"!O<B!A;B!A<G)A>2!O9B!R96-I<&EE;G1S+`H@("`@("H@
M("`@("`@("`@("`@(&5A8V@@4D9#.#(R('9A;&ED+B!4:&ES(&UA>2!C;VYT
M86EN(')E8VEP:65N=',@;F]T"B`@("`@*B`@("`@("`@("`@("`@<W!E8VEF
M:65D(&EN('1H92!H96%D97)S+"!F;W(@0F-C.BP@<F5S96YD:6YG"B`@("`@
M*B`@("`@("`@("`@("`@;65S<V%G97,L(&5T8RX*("`@("`J"B`@("`@*B!`
M<&%R86T@87)R87D@)&AE861E<G,@5&AE(&%R<F%Y(&]F(&AE861E<G,@=&\@
M<V5N9"!W:71H('1H92!M86EL+"!I;B!A;@H@("`@("H@("`@("`@("`@("`@
M(&%S<V]C:6%T:79E(&%R<F%Y+"!W:&5R92!T:&4@87)R87D@:V5Y(&ES('1H
M90H@("`@("H@("`@("`@("`@("`@(&AE861E<B!N86UE("AI92P@)U-U8FIE
M8W0G*2P@86YD('1H92!A<G)A>2!V86QU90H@("`@("H@("`@("`@("`@("`@
M(&ES('1H92!H96%D97(@=F%L=64@*&EE+"`G=&5S="<I+B!4:&4@:&5A9&5R
M"B`@("`@*B`@("`@("`@("`@("`@<')O9'5C960@9G)O;2!T:&]S92!V86QU
M97,@=V]U;&0@8F4@)U-U8FIE8W0Z"B`@("`@*B`@("`@("`@("`@("`@=&5S
M="<N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8F]D>2!4:&4@9G5L
M;"!T97AT(&]F('1H92!M97-S86=E(&)O9'DL(&EN8VQU9&EN9R!A;GD*("`@
M("`J("`@("`@("`@("`@("`@36EM92!P87)T<RP@971C+@H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@4F5T=7)N<R!T<G5E(&]N('-U8V-E<W,L(&]R
M(&$@4$5!4E]%<G)O<@H@("`@("H@("`@("`@("`@("`@("!C;VYT86EN:6YG
M(&$@9&5S8W)I<'1I=F4@97)R;W(@;65S<V%G92!O;@H@("`@("H@("`@("`@
M("`@("`@("!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5N9"@D<F5C:7!I96YT<RP@)&AE861E<G,L("1B
M;V1Y*0H@("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B](5%10+U)E<75E<W0`
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,3,U(#`R,#8Q,P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+TA45%`O4F5Q=65S="YP:'``````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q,3$R-S$@,3`U,34T,S0Q,S4@,#(Q-#`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#(P,#(M,C`P,RP@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!2961I
M<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS
M+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E
M('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET
M:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB
M=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C
M;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@
M('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T
M(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D;V-U;65N=&%T:6]N(&%N
M9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I
M8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M87D@
M;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?`HO+R!\
M("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U
M="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P97)M:7-S:6]N
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E2
M24=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O('P@(D%3($E3
M(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,
M541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/+"!42$4@24U0
M3$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D53
M4R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)
M345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\"B\O('P@
M3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#
M5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#24%,+"!%6$5-
M4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"
M550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!\
M"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!4
M24].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@?"!42$5/4ED@
M3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0U0@3$E!
M0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#
M12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%
M(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$
M($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H
M87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(%)E
M<75E<W0N<&AP+'8@,2XT,R`R,#`U+S$Q+S`V(#$X.C(Y.C$T(&%V8B!%>'`@
M)`HO+PHO+R!(5%107U)E<75E<W0@0VQA<W,*+R\*+R\@4VEM<&QE(&5X86UP
M;&4L("A&971C:&5S('EA:&]O+F-O;2!A;F0@9&ES<&QA>7,@:70I.@HO+PHO
M+R`D82`]("9N97<@2%144%]297%U97-T*"=H='1P.B\O=W=W+GEA:&]O+F-O
M;2\G*3L*+R\@)&$M/G-E;F1297%U97-T*"D["B\O(&5C:&\@)&$M/F=E=%)E
M<W!O;G-E0F]D>2@I.PHO+PH*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["G)E
M<75I<F5?;VYC92`G3F5T+U-O8VME="YP:'`G.PIR97%U:7)E7V]N8V4@)TYE
M="]54DPN<&AP)SL*"F1E9FEN92@G2%144%]215%515-47TU%5$A/1%]'150G
M+"`@("`@)T=%5"<L("`@("!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?
M34542$]$7TA%040G+"`@("`G2$5!1"<L("`@('1R=64I.PID969I;F4H)TA4
M5%!?4D5154535%]-151(3T1?4$]35"<L("`@("=03U-4)RP@("`@=')U92D[
M"F1E9FEN92@G2%144%]215%515-47TU%5$A/1%]0550G+"`@("`@)U!55"<L
M("`@("!T<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?34542$]$7T1%3$54
M12<L("`G1$5,151%)RP@('1R=64I.PID969I;F4H)TA45%!?4D5154535%]-
M151(3T1?3U!424].4R<L("=/4%1)3TY3)RP@=')U92D["F1E9FEN92@G2%14
M4%]215%515-47TU%5$A/1%]44D%#12<L("`@)U1204-%)RP@("!T<G5E*3L*
M"F1E9FEN92@G2%144%]215%515-47TA45%!?5D527S%?,"<L("<Q+C`G+"!T
M<G5E*3L*9&5F:6YE*"=(5%107U)%455%4U1?2%144%]615)?,5\Q)RP@)S$N
M,2<L('1R=64I.PH*8VQA<W,@2%144%]297%U97-T('L*"B`@("`O*BH*("`@
M("H@26YS=&%N8V4@;V8@3F5T7U523`H@("`@*B!`=F%R(&]B:F5C="!.971?
M55),"B`@("`J+PH@("`@=F%R("1?=7)L.PH*("`@("\J*@H@("`@*B!4>7!E
M(&]F(')E<75E<W0*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@
M)%]M971H;V0["@H@("`@+RHJ"B`@("`J($A45%`@5F5R<VEO;@H@("`@*B!`
M=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7VAT='`["@H@("`@+RHJ"B`@
M("`J(%)E<75E<W0@:&5A9&5R<PH@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@
M("`@=F%R("1?<F5Q=65S=$AE861E<G,["@H@("`@+RHJ"B`@("`J($)A<VEC
M($%U=&@@57-E<FYA;64*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V
M87(@)%]U<V5R.PH@("`@"B`@("`O*BH*("`@("H@0F%S:6,@075T:"!087-S
M=V]R9`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7W!A<W,[
M"@H@("`@+RHJ"B`@("`J(%-O8VME="!O8FIE8W0*("`@("H@0'9A<B!O8FIE
M8W0@3F5T7U-O8VME=`H@("`@*B\*("`@('9A<B`D7W-O8VL["B`@("`*("`@
M("\J*@H@("`@*B!0<F]X>2!S97)V97(*("`@("H@0'9A<B!S=')I;F<*("`@
M("HO"B`@("!V87(@)%]P<F]X>5]H;W-T.PH@("`@"B`@("`O*BH*("`@("H@
M4')O>'D@<&]R=`H@("`@*B!`=F%R(&EN=&5G97(*("`@("HO"B`@("!V87(@
M)%]P<F]X>5]P;W)T.PH@("`@"B`@("`O*BH*("`@("H@4')O>'D@=7-E<FYA
M;64*("`@("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]P<F]X>5]U
M<V5R.PH@("`@"B`@("`O*BH*("`@("H@4')O>'D@<&%S<W=O<F0*("`@("H@
M0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]P<F]X>5]P87-S.PH*("`@
M("\J*@H@("`@*B!0;W-T(&1A=&$*("`@("H@0'9A<B!A<G)A>0H@("`@*B\*
M("`@('9A<B`D7W!O<W1$871A.PH*("`@+RHJ"B`@("`J(%)E<75E<W0@8F]D
M>2`@"B`@("`J($!V87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?8F]D>3L*
M"B`@("\J*@H@("`@*B!!(&QI<W0@;V8@;65T:&]D<R!T:&%T($U54U0@3D]4
M(&AA=F4@82!R97%U97-T(&)O9'DL('!E<B!21D,@,C8Q-@H@("`@*B!`=F%R
M(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?8F]D>41I<V%L;&]W960@/2!A<G)A
M>2@G5%)!0T4G*3L*"B`@("\J*@H@("`@*B!&:6QE<R!T;R!P;W-T(`H@("`@
M*B!`=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?<&]S=$9I;&5S(#T@87)R
M87DH*3L*"B`@("`O*BH*("`@("H@0V]N;F5C=&EO;B!T:6UE;W5T+@H@("`@
M*B!`=F%R(&9L;V%T"B`@("`J+PH@("`@=F%R("1?=&EM96]U=#L*("`@(`H@
M("`@+RHJ"B`@("`J($A45%!?4F5S<&]N<V4@;V)J96-T"B`@("`J($!V87(@
M;V)J96-T($A45%!?4F5S<&]N<V4*("`@("HO"B`@("!V87(@)%]R97-P;VYS
M93L*("`@(`H@("`@+RHJ"B`@("`J(%=H971H97(@=&\@86QL;W<@<F5D:7)E
M8W1S"B`@("`J($!V87(@8F]O;&5A;@H@("`@*B\*("`@('9A<B`D7V%L;&]W
M4F5D:7)E8W1S.PH@("`@"B`@("`O*BH*("`@("H@36%X:6UU;2!R961I<F5C
M=',@86QL;W=E9`H@("`@*B!`=F%R(&EN=&5G97(*("`@("HO"B`@("!V87(@
M)%]M87A2961I<F5C=',["B`@("`*("`@("\J*@H@("`@*B!#=7)R96YT(&YU
M;6)E<B!O9B!R961I<F5C=',*("`@("H@0'9A<B!I;G1E9V5R"B`@("`J+PH@
M("`@=F%R("1?<F5D:7)E8W1S.PH*("`@+RHJ"B`@("`J(%=H971H97(@=&\@
M87!P96YD(&)R86-K971S(%M=('1O(&%R<F%Y('9A<FEA8FQE<PH@("`@*B!`
M=F%R(&)O;VP*("`@("HO"B`@("!V87(@)%]U<V5"<F%C:V5T<R`]('1R=64[
M"@H@("`O*BH*("`@("H@071T86-H960@;&ES=&5N97)S"B`@("`J($!V87(@
M87)R87D*("`@("HO"B`@("!V87(@)%]L:7-T96YE<G,@/2!A<G)A>2@I.PH*
M("`@+RHJ"B`@("`J(%=H971H97(@=&\@<V%V92!R97-P;VYS92!B;V1Y(&EN
M(')E<W!O;G-E(&]B:F5C="!P<F]P97)T>2`@"B`@("`J($!V87(@8F]O;`H@
M("`@*B\*("`@('9A<B`D7W-A=F5";V1Y(#T@=')U93L*"B`@("\J*@H@("`@
M*B!4:6UE;W5T(&9O<B!R96%D:6YG(&9R;VT@<V]C:V5T("AA<G)A>2AS96-O
M;F1S+"!M:6-R;W-E8V]N9',I*0H@("`@*B!`=F%R(&%R<F%Y"B`@("`J+PH@
M("`@=F%R("1?<F5A9%1I;65O=70@/2!N=6QL.PH*("`@+RHJ"B`@("`J($]P
M=&EO;G,@=&\@<&%S<R!T;R!.971?4V]C:V5T.CIC;VYN96-T+B!3964@<W1R
M96%M7V-O;G1E>'1?8W)E871E"B`@("`J($!V87(@87)R87D*("`@("HO"B`@
M("!V87(@)%]S;V-K971/<'1I;VYS(#T@;G5L;#L*"B`@("`O*BH*("`@("H@
M0V]N<W1R=6-T;W(*("`@("H*("`@("H@4V5T<R!U<"!T:&4@;V)J96-T"B`@
M("`J($!P87)A;2`@("!S=')I;F<@(%1H92!U<FP@=&\@9F5T8V@O86-C97-S
M"B`@("`J($!P87)A;2`@("!A<G)A>2`@($%S<V]C:6%T:79E(&%R<F%Y(&]F
M('!A<F%M971E<G,@=VAI8V@@8V%N(&AA=F4@=&AE(&9O;&QO=VEN9R!K97ES
M.@H@("`@*B`\=6P^"B`@("`J("`@/&QI/FUE=&AO9"`@("`@("`@("T@365T
M:&]D('1O('5S92P@1T54+"!03U-4(&5T8R`H<W1R:6YG*3PO;&D^"B`@("`J
M("`@/&QI/FAT='`@("`@("`@("`@("T@2%144"!697)S:6]N('1O('5S92P@
M,2XP(&]R(#$N,2`H<W1R:6YG*3PO;&D^"B`@("`J("`@/&QI/G5S97(@("`@
M("`@("`@("T@0F%S:6,@075T:"!U<V5R;F%M92`H<W1R:6YG*3PO;&D^"B`@
M("`J("`@/&QI/G!A<W,@("`@("`@("`@("T@0F%S:6,@075T:"!P87-S=V]R
M9"`H<W1R:6YG*3PO;&D^"B`@("`J("`@/&QI/G!R;WAY7VAO<W0@("`@("T@
M4')O>'D@<V5R=F5R(&AO<W0@*'-T<FEN9RD\+VQI/@H@("`@*B`@(#QL:3YP
M<F]X>5]P;W)T("`@("`M(%!R;WAY('-E<G9E<B!P;W)T("AI;G1E9V5R*3PO
M;&D^"B`@("`J("`@/&QI/G!R;WAY7W5S97(@("`@("T@4')O>'D@875T:"!U
M<V5R;F%M92`H<W1R:6YG*3PO;&D^"B`@("`J("`@/&QI/G!R;WAY7W!A<W,@
M("`@("T@4')O>'D@875T:"!P87-S=V]R9"`H<W1R:6YG*3PO;&D^"B`@("`J
M("`@/&QI/G1I;65O=70@("`@("`@("T@0V]N;F5C=&EO;B!T:6UE;W5T(&EN
M('-E8V]N9',@*&9L;V%T*3PO;&D^"B`@("`J("`@/&QI/F%L;&]W4F5D:7)E
M8W1S("T@5VAE=&AE<B!T;R!F;VQL;W<@<F5D:7)E8W1S(&]R(&YO="`H8F]O
M;"D\+VQI/@H@("`@*B`@(#QL:3YM87A2961I<F5C=',@("`M($UA>"!N=6UB
M97(@;V8@<F5D:7)E8W1S('1O(&9O;&QO=R`H:6YT96=E<BD\+VQI/@H@("`@
M*B`@(#QL:3YU<V5"<F%C:V5T<R`@("`M(%=H971H97(@=&\@87!P96YD(%M=
M('1O(&%R<F%Y('9A<FEA8FQE(&YA;65S("AB;V]L*3PO;&D^"B`@("`J("`@
M/&QI/G-A=F5";V1Y("`@("`@("T@5VAE=&AE<B!T;R!S879E(')E<W!O;G-E
M(&)O9'D@:6X@<F5S<&]N<V4@;V)J96-T('!R;W!E<G1Y("AB;V]L*3PO;&D^
M"B`@("`J("`@/&QI/G)E8614:6UE;W5T("`@("T@5&EM96]U="!F;W(@<F5A
M9&EN9R`O('=R:71I;F<@9&%T82!O=F5R('1H92!S;V-K970@*&%R<F%Y("AS
M96-O;F1S+"!M:6-R;W-E8V]N9',I*3PO;&D^"B`@("`J("`@/&QI/G-O8VME
M=$]P=&EO;G,@("T@3W!T:6]N<R!T;R!P87-S('1O($YE=%]3;V-K970@;V)J
M96-T("AA<G)A>2D\+VQI/@H@("`@*B`\+W5L/@H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N($A45%!?4F5Q=65S="@D=7)L(#T@
M)R<L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M<V]C:R`@("`@("`@("`@/2`F;F5W($YE=%]3;V-K970H*3L*("`@("`@("`D
M=&AI<RT^7VUE=&AO9"`@("`@("`@(#T@($A45%!?4D5154535%]-151(3T1?
M1T54.PH@("`@("`@("1T:&ES+3Y?:'1T<"`@("`@("`@("`@/2`@2%144%]2
M15%515-47TA45%!?5D527S%?,3L*("`@("`@("`D=&AI<RT^7W)E<75E<W1(
M96%D97)S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7W!O<W1$871A("`@
M("`@(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V)O9'D@("`@("`@("`@
M(#T@;G5L;#L*"B`@("`@("`@)'1H:7,M/E]U<V5R(#T@;G5L;#L*("`@("`@
M("`D=&AI<RT^7W!A<W,@/2!N=6QL.PH*("`@("`@("`D=&AI<RT^7W!R;WAY
M7VAO<W0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?<')O>'E?<&]R="`](&YU
M;&P["B`@("`@("`@)'1H:7,M/E]P<F]X>5]U<V5R(#T@;G5L;#L*("`@("`@
M("`D=&AI<RT^7W!R;WAY7W!A<W,@/2!N=6QL.PH*("`@("`@("`D=&AI<RT^
M7V%L;&]W4F5D:7)E8W1S(#T@9F%L<V4["B`@("`@("`@)'1H:7,M/E]M87A2
M961I<F5C=',@("`](#,["B`@("`@("`@)'1H:7,M/E]R961I<F5C=',@("`@
M("`](#`["@H@("`@("`@("1T:&ES+3Y?=&EM96]U="`@/2!N=6QL.PH@("`@
M("`@("1T:&ES+3Y?<F5S<&]N<V4@/2!N=6QL.PH*("`@("`@("!F;W)E86-H
M("@D<&%R86US(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1T
M:&ES+3Y[)U\G("X@)&ME>7T@/2`D=F%L=64["B`@("`@("`@?0H*("`@("`@
M("!I9B`H(65M<'1Y*"1U<FPI*2!["B`@("`@("`@("`@("1T:&ES+3YS9715
M4DPH)'5R;"D["B`@("`@("`@?0H*("`@("`@("`O+R!$969A=6QT('5S97)A
M9V5N=`H@("`@("`@("1T:&ES+3YA9&1(96%D97(H)U5S97(M06=E;G0G+"`G
M4$5!4B!(5%107U)E<75E<W0@8VQA<W,@*"!H='1P.B\O<&5A<BYP:'`N;F5T
M+R`I)RD["@H@("`@("`@("\O($UA:V4@<W5R92!K965P86QI=F5S(&1O;G0@
M:VYO8F)L92!U<PH@("`@("`@("1T:&ES+3YA9&1(96%D97(H)T-O;FYE8W1I
M;VXG+"`G8VQO<V4G*3L*"B`@("`@("`@+R\@0F%S:6,@875T:&5N=&EC871I
M;VX*("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?=7-E<BDI('L*("`@("`@
M("`@("`@)'1H:7,M/F%D9$AE861E<B@G075T:&]R:7IA=&EO;B<L("="87-I
M8R`G("X@8F%S938T7V5N8V]D92@D=&AI<RT^7W5S97(@+B`G.B<@+B`D=&AI
M<RT^7W!A<W,I*3L*("`@("`@("!]"@H@("`@("`@("\O(%5S92!G>FEP(&5N
M8V]D:6YG(&EF('!O<W-I8FQE"B`@("`@("`@+R\@079O:60@9WII<"!E;F-O
M9&EN9R!I9B!U<VEN9R!M=6QT:6)Y=&4@9G5N8W1I;VYS("AS964@(S$W.#$I
M"B`@("`@("`@:68@*$A45%!?4D5154535%](5%107U9%4E\Q7S$@/3T@)'1H
M:7,M/E]H='1P("8F(&5X=&5N<VEO;E]L;V%D960H)WIL:6(G*2`F)@H@("`@
M("`@("`@("`P(#T]("@R("8@:6YI7V=E="@G;6)S=')I;F<N9G5N8U]O=F5R
M;&]A9"<I*2D@>PH*("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G06-C
M97!T+45N8V]D:6YG)RP@)V=Z:7`G*3L*("`@("`@("!]"B`@("!]"B`@("`*
M("`@("\J*@H@("`@*B!'96YE<F%T97,@82!(;W-T(&AE861E<B!F;W(@2%14
M4"\Q+C$@<F5Q=65S=',*("`@("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`J($!R971U<FX@<W1R:6YG"B`@("`J+PH@("`@9G5N8W1I;VX@7V=E;F5R
M871E2&]S=$AE861E<B@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?=7)L
M+3YP;W)T("$](#@P($%.1"!S=')C87-E8VUP*"1T:&ES+3Y?=7)L+3YP<F]T
M;V-O;"P@)VAT='`G*2`]/2`P*2!["B`@("`@("`@("`@("1H;W-T(#T@)'1H
M:7,M/E]U<FPM/FAO<W0@+B`G.B<@+B`D=&AI<RT^7W5R;"T^<&]R=#L*"B`@
M("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?=7)L+3YP;W)T("$](#0T,R!!3D0@
M<W1R8V%S96-M<"@D=&AI<RT^7W5R;"T^<')O=&]C;VPL("=H='1P<R<I(#T]
M(#`I('L*("`@("`@("`@("`@)&AO<W0@/2`D=&AI<RT^7W5R;"T^:&]S="`N
M("<Z)R`N("1T:&ES+3Y?=7)L+3YP;W)T.PH*("`@("`@("!](&5L<V5I9B`H
M)'1H:7,M/E]U<FPM/G!O<G0@/3T@-#0S($%.1"!S=')C87-E8VUP*"1T:&ES
M+3Y?=7)L+3YP<F]T;V-O;"P@)VAT='!S)RD@/3T@,"!!3D0@<W1R<&]S*"1T
M:&ES+3Y?=7)L+3YU<FPL("<Z-#0S)RD@(3T](&9A;'-E*2!["B`@("`@("`@
M("`@("1H;W-T(#T@)'1H:7,M/E]U<FPM/FAO<W0@+B`G.B<@+B`D=&AI<RT^
M7W5R;"T^<&]R=#L*("`@("`@("`*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D:&]S="`]("1T:&ES+3Y?=7)L+3YH;W-T.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1H;W-T.PH@("`@?0H@("`@"B`@("`O*BH*("`@("H@
M4F5S971S('1H92!O8FIE8W0@=&\@:71S(&EN:71I86P@<W1A=&4@*$1%4%)%
M0T%4140I+@H@("`@*B!486ME<R!T:&4@<V%M92!P87)A;65T97)S(&%S('1H
M92!C;VYS=')U8W1O<BX*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)'5R
M;"`@("!4:&4@=7)L('1O(&)E(')E<75E<W1E9`H@("`@*B!`<&%R86T@(&%R
M<F%Y("`D<&%R86US($%S<V]C:6%T:79E(&%R<F%Y(&]F('!A<F%M971E<G,*
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`H<V5E(&-O;G-T<G5C=&]R
M(&9O<B!D971A:6QS*0H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`9&5P
M<F5C871E9"!D97!R96-A=&5D('-I;F-E(#$N,BP@8V%L;"!T:&4@8V]N<W1R
M=6-T;W(@:68@=&AI<R!I<R!N96-E<W-A<GD*("`@("HO"B`@("!F=6YC=&EO
M;B!R97-E="@D=7)L+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@
M("`D=&AI<RT^2%144%]297%U97-T*"1U<FPL("1P87)A;7,I.PH@("`@?0H*
M("`@("\J*@H@("`@*B!3971S('1H92!54DP@=&\@8F4@<F5Q=65S=&5D"B`@
M("`J"B`@("`J($!P87)A;2`@<W1R:6YG(%1H92!U<FP@=&\@8F4@<F5Q=65S
M=&5D"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T55),*"1U<FPI"B`@("!["B`@("`@("`@)'1H:7,M/E]U<FP@/2`F;F5W
M($YE=%]54DPH)'5R;"P@)'1H:7,M/E]U<V5"<F%C:V5T<RD["@H@("`@("`@
M(&EF("@A96UP='DH)'1H:7,M/E]U<FPM/G5S97(I('Q\("%E;7!T>2@D=&AI
M<RT^7W5R;"T^<&%S<RDI('L*("`@("`@("`@("`@)'1H:7,M/G-E=$)A<VEC
M075T:"@D=&AI<RT^7W5R;"T^=7-E<BP@)'1H:7,M/E]U<FPM/G!A<W,I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*$A45%!?4D5154535%](5%107U9%4E\Q
M7S$@/3T@)'1H:7,M/E]H='1P*2!["B`@("`@("`@("`@("1T:&ES+3YA9&1(
M96%D97(H)TAO<W0G+"`D=&AI<RT^7V=E;F5R871E2&]S=$AE861E<B@I*3L*
M("`@("`@("!]"B`@("!]"B`@("`*("`@("\J*@H@("`@*B!3971S(&$@<')O
M>'D@=&\@8F4@=7-E9`H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!0
M<F]X>2!H;W-T"B`@("`J($!P87)A;2!I;G0@("`@("`@(%!R;WAY('!O<G0*
M("`@("H@0'!A<F%M('-T<FEN9R`@("`@4')O>'D@=7-E<FYA;64*("`@("H@
M0'!A<F%M('-T<FEN9R`@("`@4')O>'D@<&%S<W=O<F0*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S9710<F]X>2@D:&]S="P@
M)'!O<G0@/2`X,#@P+"`D=7-E<B`](&YU;&PL("1P87-S(#T@;G5L;"D*("`@
M('L*("`@("`@("`D=&AI<RT^7W!R;WAY7VAO<W0@/2`D:&]S=#L*("`@("`@
M("`D=&AI<RT^7W!R;WAY7W!O<G0@/2`D<&]R=#L*("`@("`@("`D=&AI<RT^
M7W!R;WAY7W5S97(@/2`D=7-E<CL*("`@("`@("`D=&AI<RT^7W!R;WAY7W!A
M<W,@/2`D<&%S<SL*"B`@("`@("`@:68@*"%E;7!T>2@D=7-E<BDI('L*("`@
M("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G4')O>'DM075T:&]R:7IA=&EO
M;B<L("="87-I8R`G("X@8F%S938T7V5N8V]D92@D=7-E<B`N("<Z)R`N("1P
M87-S*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!3971S(&)A
M<VEC(&%U=&AE;G1I8V%T:6]N('!A<F%M971E<G,*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`@("`@57-E<FYA;64*("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@4&%S<W=O<F0*("`@("HO"B`@("!F=6YC=&EO;B!S971"87-I8T%U=&@H
M)'5S97(L("1P87-S*0H@("`@>PH@("`@("`@("1T:&ES+3Y?=7-E<B`]("1U
M<V5R.PH@("`@("`@("1T:&ES+3Y?<&%S<R`]("1P87-S.PH*("`@("`@("`D
M=&AI<RT^861D2&5A9&5R*"=!=71H;W)I>F%T:6]N)RP@)T)A<VEC("<@+B!B
M87-E-C1?96YC;V1E*"1U<V5R("X@)SHG("X@)'!A<W,I*3L*("`@('T*"B`@
M("`O*BH*("`@("H@4V5T<R!T:&4@;65T:&]D('1O(&)E('5S960L($=%5"P@
M4$]35"!E=&,N"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@("`@($UE=&AO
M9"!T;R!U<V4N(%5S92!T:&4@9&5F:6YE9"!C;VYS=&%N=',@9F]R('1H:7,*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S971-
M971H;V0H)&UE=&AO9"D*("`@('L*("`@("`@("`D=&AI<RT^7VUE=&AO9"`]
M("1M971H;V0["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E=',@=&AE($A45%`@
M=F5R<VEO;B!T;R!U<V4L(#$N,"!O<B`Q+C$*("`@("H*("`@("H@0'!A<F%M
M('-T<FEN9R`@("`@5F5R<VEO;B!T;R!U<V4N(%5S92!T:&4@9&5F:6YE9"!C
M;VYS=&%N=',@9F]R('1H:7,*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO
M"B`@("!F=6YC=&EO;B!S971(='1P5F5R*"1H='1P*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?:'1T<"`]("1H='1P.PH@("`@?0H*("`@("\J*@H@("`@*B!!
M9&1S(&$@<F5Q=65S="!H96%D97(*("`@("H*("`@("H@0'!A<F%M('-T<FEN
M9R`@("`@2&5A9&5R(&YA;64*("`@("H@0'!A<F%M('-T<FEN9R`@("`@2&5A
M9&5R('9A;'5E"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N
M8W1I;VX@861D2&5A9&5R*"1N86UE+"`D=F%L=64I"B`@("!["B`@("`@("`@
M)'1H:7,M/E]R97%U97-T2&5A9&5R<UMS=')T;VQO=V5R*"1N86UE*5T@/2`D
M=F%L=64["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E;6]V97,@82!R97%U97-T
M(&AE861E<@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@("!(96%D97(@
M;F%M92!T;R!R96UO=F4*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@
M("!F=6YC=&EO;B!R96UO=F5(96%D97(H)&YA;64I"B`@("!["B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<F5Q=65S=$AE861E<G-;<W1R=&]L;W=E<B@D
M;F%M92E=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W)E<75E<W1(
M96%D97)S6W-T<G1O;&]W97(H)&YA;64I72D["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@*B!!9&1S(&$@<75E<GES=')I;F<@<&%R86UE=&5R"B`@
M("`J"B`@("`J($!P87)A;2!S=')I;F<@("`@(%%U97)Y<W1R:6YG('!A<F%M
M971E<B!N86UE"B`@("`J($!P87)A;2!S=')I;F<@("`@(%%U97)Y<W1R:6YG
M('!A<F%M971E<B!V86QU90H@("`@*B!`<&%R86T@8F]O;"`@("`@("!7:&5T
M:&5R('1H92!V86QU92!I<R!A;')E861Y('5R;&5N8V]D960@;W(@;F]T+"!D
M969A=6QT(#T@;F]T"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@
M9G5N8W1I;VX@861D475E<GE3=')I;F<H)&YA;64L("1V86QU92P@)'!R965N
M8V]D960@/2!F86QS92D*("`@('L*("`@("`@("`D=&AI<RT^7W5R;"T^861D
M475E<GE3=')I;F<H)&YA;64L("1V86QU92P@)'!R965N8V]D960I.PH@("`@
M?2`@("`*("`@(`H@("`@+RHJ"B`@("`J(%-E=',@=&AE('%U97)Y<W1R:6YG
M('1O(&QI=&5R86QL>2!W:&%T('EO=2!S=7!P;'D*("`@("H*("`@("H@0'!A
M<F%M('-T<FEN9R`@("`@5&AE('%U97)Y<W1R:6YG(&1A=&$N(%-H;W5L9"!B
M92!O9B!T:&4@9F]R;6%T(&9O;SUB87(F>#UY(&5T8PH@("`@*B!`<&%R86T@
M8F]O;"`@("`@("!7:&5T:&5R(&1A=&$@:7,@86QR96%D>2!U<FQE;F-O9&5D
M(&]R(&YO="P@9&5F875L="`](&%L<F5A9'D@96YC;V1E9`H@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&%D9%)A=U%U97)Y4W1R
M:6YG*"1Q=65R>7-T<FEN9RP@)'!R965N8V]D960@/2!T<G5E*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?=7)L+3YA9&1287=1=65R>5-T<FEN9R@D<75E<GES
M=')I;F<L("1P<F5E;F-O9&5D*3L*("`@('T*"B`@("`O*BH*("`@("H@061D
M<R!P;W-T9&%T82!I=&5M<PH@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG("`@
M("!0;W-T(&1A=&$@;F%M90H@("`@*B!`<&%R86T@<W1R:6YG("`@("!0;W-T
M(&1A=&$@=F%L=64*("`@("H@0'!A<F%M(&)O;VP@("`@("`@5VAE=&AE<B!D
M871A(&ES(&%L<F5A9'D@=7)L96YC;V1E9"!O<B!N;W0L(&1E9F%U;'0@/2!N
M;W0*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A
M9&10;W-T1&%T82@D;F%M92P@)'9A;'5E+"`D<')E96YC;V1E9"`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@D<')E96YC;V1E9"D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W!O<W1$871A6R1N86UE72`]("1V86QU93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W!O<W1$871A6R1N86UE72`]
M("1T:&ES+3Y?87)R87E-87!296-U<G-I=F4H)W5R;&5N8V]D92<L("1V86QU
M92D["B`@("`@("`@?0H@("`@?0H*("`@+RHJ"B`@("`J(%)E8W5R<VEV96QY
M(&%P<&QI97,@=&AE(&-A;&QB86-K(&9U;F-T:6]N('1O('1H92!V86QU90H@
M("`@*B`*("`@("H@0'!A<F%M("`@(&UI>&5D("`@0V%L;&)A8VL@9G5N8W1I
M;VX*("`@("H@0'!A<F%M("`@(&UI>&5D("`@5F%L=64@=&\@<')O8V5S<PH@
M("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<F5T=7)N("`@;6EX960@
M("!0<F]C97-S960@=F%L=64*("`@("HO"B`@("!F=6YC=&EO;B!?87)R87E-
M87!296-U<G-I=F4H)&-A;&QB86-K+"`D=F%L=64I"B`@("!["B`@("`@("`@
M:68@*"%I<U]A<G)A>2@D=F%L=64I*2!["B`@("`@("`@("`@(')E='5R;B!C
M86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("1V86QU92D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UA<"`](&%R<F%Y*"D["B`@("`@("`@("`@
M(&9O<F5A8V@@*"1V86QU92!A<R`D:R`]/B`D=BD@>PH@("`@("`@("`@("`@
M("`@)&UA<%LD:UT@/2`D=&AI<RT^7V%R<F%Y36%P4F5C=7)S:79E*"1C86QL
M8F%C:RP@)'8I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D
M;6%P.PH@("`@("`@('T*("`@('T*"B`@("\J*@H@("`@*B!!9&1S(&$@9FEL
M92!T;R!U<&QO860*("`@("H@"B`@("`J(%1H:7,@86QS;R!C:&%N9V5S(&-O
M;G1E;G0M='EP92!T;R`G;75L=&EP87)T+V9O<FTM9&%T82<@9F]R('!R;W!E
M<B!U<&QO860*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!P
M87)A;2`@<W1R:6YG("`@(&YA;64@;V8@9FEL92UU<&QO860@9FEE;&0*("`@
M("H@0'!A<F%M("!M:7AE9"`@("`@9FEL92!N86UE*',I"B`@("`J($!P87)A
M;2`@;6EX960@("`@(&-O;G1E;G0M='EP92AS*2!O9B!F:6QE*',I(&)E:6YG
M('5P;&]A9&5D"B`@("`J($!R971U<FX@8F]O;"`@("`@('1R=64@;VX@<W5C
M8V5S<PH@("`@*B!`=&AR;W=S(%!%05)?17)R;W(*("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1&:6QE*"1I;G!U=$YA;64L("1F:6QE3F%M92P@)&-O;G1E;G14
M>7!E(#T@)V%P<&QI8V%T:6]N+V]C=&5T+7-T<F5A;2<I"B`@("!["B`@("`@
M("`@:68@*"%I<U]A<G)A>2@D9FEL94YA;64I("8F("%I<U]R96%D86)L92@D
M9FEL94YA;64I*2!["B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*")&:6QE("=[)&9I;&5.86UE?2<@:7,@;F]T(')E861A8FQE(BD["B`@
M("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1F:6QE3F%M92DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&9I;&5.86UE(&%S("1N86UE*2!["B`@("`@("`@
M("`@("`@("!I9B`H(6ES7W)E861A8FQE*"1N86UE*2D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")&:6QE("=[)&YA
M;65])R!I<R!N;W0@<F5A9&%B;&4B*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^861D2&5A9&5R
M*"=#;VYT96YT+51Y<&4G+"`G;75L=&EP87)T+V9O<FTM9&%T82<I.PH@("`@
M("`@("1T:&ES+3Y?<&]S=$9I;&5S6R1I;G!U=$YA;65=(#T@87)R87DH"B`@
M("`@("`@("`@("=N86UE)R`]/B`D9FEL94YA;64L"B`@("`@("`@("`@("=T
M>7!E)R`]/B`D8V]N=&5N=%1Y<&4*("`@("`@("`I.PH@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@*B!!9&1S(')A=R!P;W-T9&%T
M82`H1$504D5#051%1"D*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`@("`@
M5&AE(&1A=&$*("`@("H@0'!A<F%M(&)O;VP@("`@("`@5VAE=&AE<B!D871A
M(&ES('!R965N8V]D960@;W(@;F]T+"!D969A=6QT(#T@86QR96%D>2!E;F-O
M9&5D"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!D97!R96-A=&5D("`@
M("`@(&1E<')E8V%T960@<VEN8V4@,2XS+C`L(&UE=&AO9"!A9&1";V1Y*"D@
M<VAO=6QD(&)E('5S960@:6YS=&5A9`H@("`@*B\*("`@(&9U;F-T:6]N(&%D
M9%)A=U!O<W1$871A*"1P;W-T9&%T82P@)'!R965N8V]D960@/2!T<G5E*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?8F]D>2`]("1P<F5E;F-O9&5D(#\@)'!O
M<W1D871A(#H@=7)L96YC;V1E*"1P;W-T9&%T82D["B`@("!]"@H@("`O*BH*
M("`@("H@4V5T<R!T:&4@<F5Q=65S="!B;V1Y("AF;W(@4$]35"P@4%54(&%N
M9"!S:6UI;&%R(')E<75E<W1S*0H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!297%U97-T(&)O9'D*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M*B\*("`@(&9U;F-T:6]N('-E=$)O9'DH)&)O9'DI"B`@("!["B`@("`@("`@
M)'1H:7,M/E]B;V1Y(#T@)&)O9'D["B`@("!]"@H@("`@+RHJ"B`@("`J($-L
M96%R<R!A;GD@<&]S=&1A=&$@=&AA="!H87,@8F5E;B!A9&1E9"`H1$504D5#
M051%1"DN(`H@("`@*B`*("`@("H@57-E9G5L(&9O<B!M=6QT:7!L92!R97%U
M97-T('-C96YA<FEO<RX*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("H@0&1E<')E8V%T960@9&5P<F5C871E9"!S:6YC92`Q+C(*("`@("HO"B`@
M("!F=6YC=&EO;B!C;&5A<E!O<W1$871A*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7W!O<W1$871A(#T@;G5L;#L*("`@('T*"B`@("`O*BH*("`@("H@07!P
M96YD<R!A(&-O;VMI92!T;R`B0V]O:VEE.B(@:&5A9&5R"B`@("`J(`H@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE(&-O;VMI92!N86UE"B`@("`J($!P87)A
M;2!S=')I;F<@)'9A;'5E(&-O;VMI92!V86QU90H@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&%D9$-O;VMI92@D;F%M92P@)'9A
M;'5E*0H@("`@>PH@("`@("`@("1C;V]K:65S(#T@:7-S970H)'1H:7,M/E]R
M97%U97-T2&5A9&5R<ULG8V]O:VEE)UTI(#\@)'1H:7,M/E]R97%U97-T2&5A
M9&5R<ULG8V]O:VEE)UTN("<[("<@.B`G)SL*("`@("`@("`D=&AI<RT^861D
M2&5A9&5R*"=#;V]K:64G+"`D8V]O:VEE<R`N("1N86UE("X@)STG("X@)'9A
M;'5E*3L*("`@('T*("`@(`H@("`@+RHJ"B`@("`J($-L96%R<R!A;GD@8V]O
M:VEE<R!T:&%T(&AA=F4@8F5E;B!A9&1E9"`H1$504D5#051%1"DN(`H@("`@
M*B`*("`@("H@57-E9G5L(&9O<B!M=6QT:7!L92!R97%U97-T('-C96YA<FEO
M<PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`9&5P<F5C871E
M9"!D97!R96-A=&5D('-I;F-E(#$N,@H@("`@*B\*("`@(&9U;F-T:6]N(&-L
M96%R0V]O:VEE<R@I"B`@("!["B`@("`@("`@)'1H:7,M/G)E;6]V94AE861E
M<B@G0V]O:VEE)RD["B`@("!]"@H@("`@+RHJ"B`@("`J(%-E;F1S('1H92!R
M97%U97-T"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!P87)A
M;2`@8F]O;"`@(%=H971H97(@=&\@<W1O<F4@<F5S<&]N<V4@8F]D>2!I;B!2
M97-P;VYS92!O8FIE8W0@<')O<&5R='DL"B`@("`J("`@("`@("`@("`@("`@
M('-E="!T:&ES('1O(&9A;'-E(&EF(&1O=VYL;V%D:6YG(&$@3$%21T4@9FEL
M92!A;F0@=7-I;F<@82!,:7-T96YE<@H@("`@*B!`<F5T=7)N(&UI>&5D("!0
M14%2(&5R<F]R(&]N(&5R<F]R+"!T<G5E(&]T:&5R=VES90H@("`@*B\*("`@
M(&9U;F-T:6]N('-E;F1297%U97-T*"1S879E0F]D>2`]('1R=64I"B`@("![
M"B`@("`@("`@:68@*"%I<U]A*"1T:&ES+3Y?=7)L+"`G3F5T7U523"<I*2![
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=.;R!54DP@
M9VEV96XN)RD["B`@("`@("`@?0H*("`@("`@("`D:&]S="`](&ES<V5T*"1T
M:&ES+3Y?<')O>'E?:&]S="D@/R`D=&AI<RT^7W!R;WAY7VAO<W0@.B`D=&AI
M<RT^7W5R;"T^:&]S=#L*("`@("`@("`D<&]R="`](&ES<V5T*"1T:&ES+3Y?
M<')O>'E?<&]R="D@/R`D=&AI<RT^7W!R;WAY7W!O<G0@.B`D=&AI<RT^7W5R
M;"T^<&]R=#L*"B`@("`@("`@+R\@-"XS+C`@<W5P<&]R=',@4U-,(&-O;FYE
M8W1I;VYS('5S:6YG($]P96Y34TPN(%1H92!F=6YC=&EO;B!T97-T(&1E=&5R
M;6EN97,*("`@("`@("`O+R!W92!R=6YN:6YG(&]N(&%T(&QE87-T(#0N,RXP
M"B`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H:7,M/E]U<FPM/G!R;W1O8V]L
M+"`G:'1T<',G*2`]/2`P($%.1"!F=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T
M7V-O;G1E;G1S)RD@04Y$(&5X=&5N<VEO;E]L;V%D960H)V]P96YS<VPG*2D@
M>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P<F]X>5]H;W-T*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TA4
M5%!3('!R;WAI97,@87)E(&YO="!S=7!P;W)T960N)RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)&AO<W0@/2`G<W-L.B\O)R`N("1H;W-T.PH@("`@
M("`@('T*"B`@("`@("`@+R\@;6%G:6,@<75O=&5S(&UA>2!F=6-K('5P(&9I
M;&4@=7!L;V%D<R!A;F0@8VAU;FME9"!R97-P;VYS92!P<F]C97-S:6YG"B`@
M("`@("`@)&UA9VEC475O=&5S(#T@:6YI7V=E="@G;6%G:6-?<75O=&5S7W)U
M;G1I;64G*3L*("`@("`@("!I;FE?<V5T*"=M86=I8U]Q=6]T97-?<G5N=&EM
M92<L(&9A;'-E*3L*"B`@("`@("`@+R\@268@=&AI<R!I<R!A('-E8V]N9"!R
M97%U97-T+"!W92!M87D@9V5T(&%W87D@=VET:&]U=`H@("`@("`@("\O(')E
M+6-O;FYE8W1I;F<@:68@=&AE>2=R92!O;B!T:&4@<V%M92!S97)V97(*("`@
M("`@("`D97)R(#T@)'1H:7,M/E]S;V-K+3YC;VYN96-T*"1H;W-T+"`D<&]R
M="P@;G5L;"P@)'1H:7,M/E]T:6UE;W5T+"`D=&AI<RT^7W-O8VME=$]P=&EO
M;G,I.PH@("`@("`@(%!%05(Z.FES17)R;W(H)&5R<BD@;W(@)&5R<B`]("1T
M:&ES+3Y?<V]C:RT^=W)I=&4H)'1H:7,M/E]B=6EL9%)E<75E<W0H*2D["@H@
M("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<F5A9%1I;65O=70I*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-O8VLM/G-E=%1I;65O=70H)'1H:7,M/E]R96%D
M5&EM96]U=%LP72P@)'1H:7,M/E]R96%D5&EM96]U=%LQ72D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;F]T:69Y*"=S96YT4F5Q=65S
M="<I.PH*("`@("`@("`@("`@+R\@4F5A9"!T:&4@<F5S<&]N<V4*("`@("`@
M("`@("`@)'1H:7,M/E]R97-P;VYS92`]("9N97<@2%144%]297-P;VYS92@D
M=&AI<RT^7W-O8VLL("1T:&ES+3Y?;&ES=&5N97)S*3L*("`@("`@("`@("`@
M)&5R<B`]("1T:&ES+3Y?<F5S<&]N<V4M/G!R;V-E<W,H)'1H:7,M/E]S879E
M0F]D>2`F)B`D<V%V94)O9'DI.PH@("`@("`@('T*"B`@("`@("`@:6YI7W-E
M="@G;6%G:6-?<75O=&5S7W)U;G1I;64G+"`D;6%G:6-1=6]T97,I.PH*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PH@("`@("`@("`@("!R
M971U<FX@)&5R<CL*("`@("`@("!]"@H*("`@("`@("`O+R!#:&5C:R!F;W(@
M<F5D:7)E8W1I;VX*("`@("`@("!I9B`H("`@("1T:&ES+3Y?86QL;W=2961I
M<F5C=',*("`@("`@("`@("`@04Y$("1T:&ES+3Y?<F5D:7)E8W1S(#P]("1T
M:&ES+3Y?;6%X4F5D:7)E8W1S"B`@("`@("`@("`@($%.1"`D=&AI<RT^9V5T
M4F5S<&]N<V5#;V1E*"D@/B`S,#`*("`@("`@("`@("`@04Y$("1T:&ES+3YG
M971297-P;VYS94-O9&4H*2`\(#,Y.0H@("`@("`@("`@("!!3D0@(65M<'1Y
M*"1T:&ES+3Y?<F5S<&]N<V4M/E]H96%D97)S6R=L;V-A=&EO;B==*2D@>PH*
M("`@("`@("`@("`@"B`@("`@("`@("`@("1R961I<F5C="`]("1T:&ES+3Y?
M<F5S<&]N<V4M/E]H96%D97)S6R=L;V-A=&EO;B==.PH*("`@("`@("`@("`@
M+R\@06)S;VQU=&4@55),"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O
M7FAT='!S/SI<+UPO+VDG+"`D<F5D:7)E8W0I*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W5R;"`]("9N97<@3F5T7U523"@D<F5D:7)E8W0I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9$AE861E<B@G2&]S="<L("1T:&ES+3Y?
M9V5N97)A=&5(;W-T2&5A9&5R*"DI.PH@("`@("`@("`@("`O+R!!8G-O;'5T
M92!P871H"B`@("`@("`@("`@('T@96QS96EF("@D<F5D:7)E8W1[,'T@/3T@
M)R\G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W5R;"T^<&%T:"`]("1R
M961I<F5C=#L*("`@("`@("`@("`@"B`@("`@("`@("`@("\O(%)E;&%T:79E
M('!A=&@*("`@("`@("`@("`@?2!E;'-E:68@*'-U8G-T<B@D<F5D:7)E8W0L
M(#`L(#,I(#T]("<N+B\G($]2('-U8G-T<B@D<F5D:7)E8W0L(#`L(#(I(#T]
M("<N+R<I('L*("`@("`@("`@("`@("`@(&EF("AS=6)S='(H)'1H:7,M/E]U
M<FPM/G!A=&@L("TQ*2`]/2`G+R<I('L*("`@("`@("`@("`@("`@("`@("`D
M<F5D:7)E8W0@/2`D=&AI<RT^7W5R;"T^<&%T:"`N("1R961I<F5C=#L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E
M9&ER96-T(#T@9&ER;F%M92@D=&AI<RT^7W5R;"T^<&%T:"D@+B`G+R<@+B`D
M<F5D:7)E8W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M<F5D:7)E8W0@/2!.971?55),.CIR97-O;'9E4&%T:"@D<F5D:7)E8W0I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]U<FPM/G!A=&@@/2`D<F5D:7)E8W0[
M"B`@("`@("`@("`@("`@("`*("`@("`@("`@("`@+R\@1FEL96YA;64L(&YO
M('!A=&@*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF
M("AS=6)S='(H)'1H:7,M/E]U<FPM/G!A=&@L("TQ*2`]/2`G+R<I('L*("`@
M("`@("`@("`@("`@("`@("`D<F5D:7)E8W0@/2`D=&AI<RT^7W5R;"T^<&%T
M:"`N("1R961I<F5C=#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)')E9&ER96-T(#T@9&ER;F%M92@D=&AI<RT^7W5R
M;"T^<&%T:"D@+B`G+R<@+B`D<F5D:7)E8W0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W5R;"T^<&%T:"`]("1R961I<F5C
M=#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'1H:7,M/E]R961I<F5C
M=',K*SL*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS96YD4F5Q=65S="@D
M<V%V94)O9'DI.PH*("`@("`@("`O+R!4;V\@;6%N>2!R961I<F5C=',*("`@
M("`@("!](&5L<V5I9B`H)'1H:7,M/E]A;&QO=U)E9&ER96-T<R!!3D0@)'1H
M:7,M/E]R961I<F5C=',@/B`D=&AI<RT^7VUA>%)E9&ER96-T<RD@>PH@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G5&]O(&UA;GD@<F5D
M:7)E8W1S)RD["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7W-O8VLM/F1I
M<V-O;FYE8W0H*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@
M+RHJ"B`@("`J(%)E='5R;G,@=&AE(')E<W!O;G-E(&-O9&4*("`@("H*("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0')E='5R;B!M:7AE9"`@("`@4F5S
M<&]N<V4@8V]D92P@9F%L<V4@:68@;F]T('-E=`H@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%)E<W!O;G-E0V]D92@I"B`@("!["B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3Y?<F5S<&]N<V4M/E]C;V1E*2`_("1T:&ES+3Y?<F5S<&]N
M<V4M/E]C;V1E(#H@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R
M;G,@96ET:&5R('1H92!N86UE9"!H96%D97(@;W(@86QL(&EF(&YO(&YA;64@
M9VEV96X*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'!A<F%M
M('-T<FEN9R`@("`@5&AE(&AE861E<B!N86UE('1O(')E='5R;BP@9&\@;F]T
M('-E="!T;R!G970@86QL(&AE861E<G,*("`@("H@0')E='5R;B!M:7AE9"`@
M("`@96ET:&5R('1H92!V86QU92!O9B`D:&5A9&5R;F%M92`H9F%L<V4@:68@
M:&5A9&5R(&ES(&YO="!P<F5S96YT*0H@("`@*B`@("`@("`@("`@("`@("`@
M("!O<B!A;B!A<G)A>2!O9B!A;&P@:&5A9&5R<PH@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=%)E<W!O;G-E2&5A9&5R*"1H96%D97)N86UE(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H(6ES<V5T*"1H96%D97)N86UE*2D@>PH@("`@("`@
M("`@("!R971U<FX@:7-S970H)'1H:7,M/E]R97-P;VYS92T^7VAE861E<G,I
M/R`D=&AI<RT^7W)E<W!O;G-E+3Y?:&5A9&5R<SH@87)R87DH*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D:&5A9&5R;F%M92`]('-T<G1O;&]W
M97(H)&AE861E<FYA;64I.PH@("`@("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/E]R97-P;VYS92T^7VAE861E<G-;)&AE861E<FYA;65=*2`_("1T:&ES
M+3Y?<F5S<&]N<V4M/E]H96%D97)S6R1H96%D97)N86UE72`Z(&9A;'-E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@8F]D
M>2!O9B!T:&4@<F5S<&]N<V4*("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("H@0')E='5R;B!M:7AE9"`@("`@<F5S<&]N<V4@8F]D>2P@9F%L<V4@
M:68@;F]T('-E=`H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%)E<W!O;G-E0F]D
M>2@I"B`@("!["B`@("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<F5S<&]N
M<V4M/E]B;V1Y*2`_("1T:&ES+3Y?<F5S<&]N<V4M/E]B;V1Y(#H@9F%L<V4[
M"B`@("!]"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@8V]O:VEE<R!S970@:6X@
M<F5S<&]N<V4*("`@("H@"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R
M971U<FX@;6EX960@("`@(&%R<F%Y(&]F(')E<W!O;G-E(&-O;VMI97,L(&9A
M;'-E(&EF(&YO;F4@87)E('!R97-E;G0*("`@("HO"B`@("!F=6YC=&EO;B!G
M971297-P;VYS94-O;VMI97,H*0H@("`@>PH@("`@("`@(')E='5R;B!I<W-E
M="@D=&AI<RT^7W)E<W!O;G-E+3Y?8V]O:VEE<RD@/R`D=&AI<RT^7W)E<W!O
M;G-E+3Y?8V]O:VEE<R`Z(&9A;'-E.PH@("`@?0H*("`@("\J*@H@("`@*B!"
M=6EL9',@=&AE(')E<75E<W0@<W1R:6YG"B`@("`J"B`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@*B!`<F5T=7)N('-T<FEN9R!4:&4@<F5Q=65S="!S=')I
M;F<*("`@("HO"B`@("!F=6YC=&EO;B!?8G5I;&1297%U97-T*"D*("`@('L*
M("`@("`@("`D<V5P87)A=&]R(#T@:6YI7V=E="@G87)G7W-E<&%R871O<BYO
M=71P=70G*3L*("`@("`@("!I;FE?<V5T*"=A<F=?<V5P87)A=&]R+F]U='!U
M="<L("<F)RD["B`@("`@("`@)'%U97)Y<W1R:6YG(#T@*"1Q=65R>7-T<FEN
M9R`]("1T:&ES+3Y?=7)L+3YG9711=65R>5-T<FEN9R@I*2`_("<_)R`N("1Q
M=65R>7-T<FEN9R`Z("<G.PH@("`@("`@(&EN:5]S970H)V%R9U]S97!A<F%T
M;W(N;W5T<'5T)RP@)'-E<&%R871O<BD["@H@("`@("`@("1H;W-T(#T@:7-S
M970H)'1H:7,M/E]P<F]X>5]H;W-T*2`_("1T:&ES+3Y?=7)L+3YP<F]T;V-O
M;"`N("<Z+R\G("X@)'1H:7,M/E]U<FPM/FAO<W0@.B`G)SL*("`@("`@("`D
M<&]R="`]("AI<W-E="@D=&AI<RT^7W!R;WAY7VAO<W0I($%.1"`D=&AI<RT^
M7W5R;"T^<&]R="`A/2`X,"D@/R`G.B<@+B`D=&AI<RT^7W5R;"T^<&]R="`Z
M("<G.PH@("`@("`@("1P871H(#T@*&5M<'1Y*"1T:&ES+3Y?=7)L+3YP871H
M*3\@)R\G.B`D=&AI<RT^7W5R;"T^<&%T:"D@+B`D<75E<GES=')I;F<["B`@
M("`@("`@)'5R;"`@/2`D:&]S="`N("1P;W)T("X@)'!A=&@["@H@("`@("`@
M("1R97%U97-T(#T@)'1H:7,M/E]M971H;V0@+B`G("<@+B`D=7)L("X@)R!(
M5%10+R<@+B`D=&AI<RT^7VAT='`@+B`B7')<;B(["@H@("`@("`@(&EF("AI
M;E]A<G)A>2@D=&AI<RT^7VUE=&AO9"P@)'1H:7,M/E]B;V1Y1&ES86QL;W=E
M9"D@?'P*("`@("`@("`@("`@*$A45%!?4D5154535%]-151(3T1?4$]35"`A
M/2`D=&AI<RT^7VUE=&AO9"`F)B!E;7!T>2@D=&AI<RT^7V)O9'DI*2!\?`H@
M("`@("`@("`@("`H2%144%]215%515-47TU%5$A/1%]03U-4("$]("1T:&ES
M+3Y?;65T:&]D("8F(&5M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I("8F(&5M<'1Y
M*"1T:&ES+3Y?<&]S=$9I;&5S*2DI('L*"B`@("`@("`@("`@("1T:&ES+3YR
M96UO=F5(96%D97(H)T-O;G1E;G0M5'EP92<I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W)E<75E<W1(96%D97)S
M6R=C;VYT96YT+71Y<&4G72DI('L*("`@("`@("`@("`@("`@("\O($%D9"!D
M969A=6QT(&-O;G1E;G0M='EP90H@("`@("`@("`@("`@("`@)'1H:7,M/F%D
M9$AE861E<B@G0V]N=&5N="U4>7!E)RP@)V%P<&QI8V%T:6]N+W@M=W=W+69O
M<FTM=7)L96YC;V1E9"<I.PH@("`@("`@("`@("!](&5L<V5I9B`H)VUU;'1I
M<&%R="]F;W)M+61A=&$G(#T]("1T:&ES+3Y?<F5Q=65S=$AE861E<G-;)V-O
M;G1E;G0M='EP92==*2!["B`@("`@("`@("`@("`@("`D8F]U;F1A<GD@/2`G
M2%144%]297%U97-T7R<@+B!M9#4H=6YI<6ED*"=R97%U97-T)RD@+B!M:6-R
M;W1I;64H*2D["B`@("`@("`@("`@("`@("`D=&AI<RT^861D2&5A9&5R*"=#
M;VYT96YT+51Y<&4G+"`G;75L=&EP87)T+V9O<FTM9&%T83L@8F]U;F1A<GD]
M)R`N("1B;W5N9&%R>2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O(%)E<75E<W0@2&5A9&5R<PH@("`@("`@(&EF("@A96UP='DH)'1H
M:7,M/E]R97%U97-T2&5A9&5R<RDI('L*("`@("`@("`@("`@9F]R96%C:"`H
M)'1H:7,M/E]R97%U97-T2&5A9&5R<R!A<R`D;F%M92`]/B`D=F%L=64I('L*
M("`@("`@("`@("`@("`@("1C86YO;FEC86Q.86UE(#T@:6UP;&]D92@G+2<L
M(&%R<F%Y7VUA<"@G=6-F:7)S="<L(&5X<&QO9&4H)RTG+"`D;F%M92DI*3L*
M("`@("`@("`@("`@("`@("1R97%U97-T("`@("`@+CT@)&-A;F]N:6-A;$YA
M;64@+B`G.B`G("X@)'9A;'5E("X@(EQR7&XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!.;R!P;W-T(&1A=&$@;W(@=W)O;F<@;65T
M:&]D+"!S;R!S:6UP;'D@861D(&$@9FEN86P@0U),1@H@("`@("`@(&EF("AI
M;E]A<G)A>2@D=&AI<RT^7VUE=&AO9"P@)'1H:7,M/E]B;V1Y1&ES86QL;W=E
M9"D@?'P@"B`@("`@("`@("`@("A(5%107U)%455%4U1?34542$]$7U!/4U0@
M(3T@)'1H:7,M/E]M971H;V0@)B8@96UP='DH)'1H:7,M/E]B;V1Y*2DI('L*
M"B`@("`@("`@("`@("1R97%U97-T("X](")<<EQN(CL*"B`@("`@("`@+R\@
M4&]S="!D871A(&EF(&ET)W,@86X@87)R87D*("`@("`@("!](&5L<V5I9B`H
M2%144%]215%515-47TU%5$A/1%]03U-4(#T]("1T:&ES+3Y?;65T:&]D("8F
M(`H@("`@("`@("`@("`@("`@("`H(65M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I
M('Q\("%E;7!T>2@D=&AI<RT^7W!O<W1&:6QE<RDI*2!["@H@("`@("`@("`@
M("`O+R`B;F]R;6%L(B!03U-4(')E<75E<W0*("`@("`@("`@("`@:68@*"%I
M<W-E="@D8F]U;F1A<GDI*2!["B`@("`@("`@("`@("`@("`D<&]S=&1A=&$@
M/2!I;7!L;V1E*"<F)RP@87)R87E?;6%P*`H@("`@("`@("`@("`@("`@("`@
M(&-R96%T95]F=6YC=&EO;B@G)&$G+"`G<F5T=7)N("1A6S!=("X@7"<]7"<@
M+B`D85LQ73LG*2P@"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]F;&%T
M=&5N07)R87DH)R<L("1T:&ES+3Y?<&]S=$1A=&$I"B`@("`@("`@("`@("`@
M("`I*3L*"B`@("`@("`@("`@("\O(&UU;'1I<&%R="!R97%U97-T+"!P<F]B
M86)L>2!W:71H(&9I;&4@=7!L;V%D<PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)'!O<W1D871A(#T@)R<["B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1T:&ES+3Y?<&]S=$1A=&$I*2!["B`@("`@("`@("`@
M("`@("`@("`@)&9L871$871A(#T@)'1H:7,M/E]F;&%T=&5N07)R87DH)R<L
M("1T:&ES+3Y?<&]S=$1A=&$I.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1F;&%T1&%T82!A<R`D:71E;2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]S=&1A=&$@+CT@)RTM)R`N("1B;W5N9&%R>2`N(")<<EQN(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O<W1D871A("X]("=#;VYT96YT
M+41I<W!O<VET:6]N.B!F;W)M+61A=&$[(&YA;64](B<@+B`D:71E;5LP72`N
M("<B)SL*("`@("`@("`@("`@("`@("`@("`@("`@)'!O<W1D871A("X](")<
M<EQN7')<;B(@+B!U<FQD96-O9&4H)&ET96U;,5TI("X@(EQR7&XB.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&]S=$9I;&5S(&%S("1N86UE(#T^
M("1V86QU92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M=F%L=65;)VYA;64G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A
M<FYA;64@("`@("`@/2`D;F%M92`N("@D=&AI<RT^7W5S94)R86-K971S/R`G
M6UTG.B`G)RD["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'9A<FYA;64@("`@("`@/2`D;F%M93L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=N86UE)UT@/2!A<G)A>2@D
M=F%L=65;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1V86QU95LG;F%M92==(&%S("1K97D@
M/3X@)&9I;&5N86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F<"`@
M(#T@9F]P96XH)&9I;&5N86UE+"`G<B<I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D9&%T82`](&9R96%D*"1F<"P@9FEL97-I>F4H)&9I;&5N86UE*2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8F%S96YA;64@/2!B87-E;F%M92@D9FEL96YA
M;64I.PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`@("`@/2!I<U]A
M<G)A>2@D=F%L=65;)W1Y<&4G72D_($`D=F%L=65;)W1Y<&4G75LD:V5Y73H@
M)'9A;'5E6R=T>7!E)UT["@H@("`@("`@("`@("`@("`@("`@("`@("`D<&]S
M=&1A=&$@+CT@)RTM)R`N("1B;W5N9&%R>2`N(")<<EQN(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O<W1D871A("X]("=#;VYT96YT+41I<W!O<VET
M:6]N.B!F;W)M+61A=&$[(&YA;64](B<@+B`D=F%R;F%M92`N("<B.R!F:6QE
M;F%M93TB)R`N("1B87-E;F%M92`N("<B)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!O<W1D871A("X](")<<EQN0V]N=&5N="U4>7!E.B`B("X@)'1Y
M<&4["B`@("`@("`@("`@("`@("`@("`@("`@("1P;W-T9&%T82`N/2`B7')<
M;EQR7&XB("X@)&1A=&$@+B`B7')<;B(["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!O<W1D871A
M("X]("<M+2<@+B`D8F]U;F1A<GD@+B`B+2U<<EQN(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D<F5Q=65S="`N/2`G0V]N=&5N="U,96YG=&@Z("<@
M+B!S=')L96XH)'!O<W1D871A*2`N(")<<EQN7')<;B(["B`@("`@("`@("`@
M("1R97%U97-T("X]("1P;W-T9&%T83L*"B`@("`@("`@+R\@17AP;&EC:71L
M>2!S970@<F5Q=65S="!B;V1Y"B`@("`@("`@?2!E;'-E:68@*"%E;7!T>2@D
M=&AI<RT^7V)O9'DI*2!["@H@("`@("`@("`@("`D<F5Q=65S="`N/2`G0V]N
M=&5N="U,96YG=&@Z("<@+B!S=')L96XH)'1H:7,M/E]B;V1Y*2`N(")<<EQN
M7')<;B(["B`@("`@("`@("`@("1R97%U97-T("X]("1T:&ES+3Y?8F]D>3L*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1R97%U97-T.PH@
M("`@?0H*("`@+RHJ"B`@("`J($AE;'!E<B!F=6YC=&EO;B!T;R!C:&%N9V4@
M=&AE("AP<F]B86)L>2!M=6QT:61I;65N<VEO;F%L*2!A<W-O8VEA=&EV92!A
M<G)A>0H@("`@*B!I;G1O('1H92!S:6UP;&4@;VYE+@H@("`@*@H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!N86UE(&9O<B!I=&5M"B`@("`J($!P87)A;2`@
M("!M:7AE9"`@(&ET96TG<R!V86QU97,*("`@("H@0')E='5R;B`@(&%R<F%Y
M("`@87)R87D@=VET:"!T:&4@9F]L;&]W:6YG(&ET96US.B!A<G)A>2@G:71E
M;2!N86UE)RP@)VET96T@=F%L=64G*3L*("`@("HO"B`@("!F=6YC=&EO;B!?
M9FQA='1E;D%R<F%Y*"1N86UE+"`D=F%L=65S*0H@("`@>PH@("`@("`@(&EF
M("@A:7-?87)R87DH)'9A;'5E<RDI('L*("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*&%R<F%Y*"1N86UE+"`D=F%L=65S*2D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@("`@(&9O<F5A
M8V@@*"1V86QU97,@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D;F%M92DI('L*("`@("`@("`@("`@("`@("`@("`D;F5W3F%M
M92`]("1K.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?=7-E
M0G)A8VME=',I('L*("`@("`@("`@("`@("`@("`@("`D;F5W3F%M92`]("1N
M86UE("X@)ULG("X@)&L@+B`G72<["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("1N97=.86UE(#T@)&YA;64["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5T(#T@87)R87E?;65R
M9V4H)')E="P@)'1H:7,M/E]F;&%T=&5N07)R87DH)&YE=TYA;64L("1V*2D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R970["B`@("`@
M("`@?0H@("`@?0H*"B`@("\J*@H@("`@*B!!9&1S(&$@3&ES=&5N97(@=&\@
M=&AE(&QI<W0@;V8@;&ES=&5N97)S('1H870@87)E(&YO=&EF:65D(&]F"B`@
M("`J('1H92!O8FIE8W0G<R!E=F5N=',*("`@("H@"B`@("`J($!P87)A;2`@
M("!O8FIE8W0@("!(5%107U)E<75E<W1?3&ES=&5N97(@:6YS=&%N8V4@=&\@
M871T86-H"B`@("`J($!R971U<FX@("!B;V]L96%N("!W:&5T:&5R('1H92!L
M:7-T96YE<B!W87,@<W5C8V5S<V9U;&QY(&%T=&%C:&5D"B`@("`J($!A8V-E
M<W,@("!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!A='1A8V@H)B1L:7-T
M96YE<BD*("`@('L*("`@("`@("!I9B`H(6ES7V$H)&QI<W1E;F5R+"`G2%14
M4%]297%U97-T7TQI<W1E;F5R)RDI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD;&ES
M=&5N97(M/F=E=$ED*"E=(#TF("1L:7-T96YE<CL*("`@("`@("!R971U<FX@
M=')U93L*("`@('T*"@H@("`O*BH*("`@("H@4F5M;W9E<R!A($QI<W1E;F5R
M(&9R;VT@=&AE(&QI<W0@;V8@;&ES=&5N97)S(`H@("`@*B`*("`@("H@0'!A
M<F%M("`@(&]B:F5C="`@($A45%!?4F5Q=65S=%],:7-T96YE<B!I;G-T86YC
M92!T;R!D971A8V@*("`@("H@0')E='5R;B`@(&)O;VQE86X@('=H971H97(@
M=&AE(&QI<W1E;F5R('=A<R!S=6-C97-S9G5L;'D@9&5T86-H960*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&1E=&%C:"@F
M)&QI<W1E;F5R*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;&ES=&5N97(L
M("=(5%107U)E<75E<W1?3&ES=&5N97(G*2!\?"`*("`@("`@("`@("`@(6ES
M<V5T*"1T:&ES+3Y?;&ES=&5N97)S6R1L:7-T96YE<BT^9V5T260H*5TI*2![
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@
M=6YS970H)'1H:7,M/E]L:7-T96YE<G-;)&QI<W1E;F5R+3YG971)9"@I72D[
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H*("`@+RHJ"B`@("`J($YO
M=&EF:65S(&%L;"!R96=I<W1E<F5D(&QI<W1E;F5R<R!O9B!A;B!E=F5N="X*
M("`@("H@"B`@("`J($5V96YT<R!S96YT(&)Y($A45%!?4F5Q=65S="!O8FIE
M8W0*("`@("H@)W-E;G1297%U97-T)SH@869T97(@=&AE(')E<75E<W0@=V%S
M('-E;G0*("`@("H@179E;G1S('-E;G0@8GD@2%144%]297-P;VYS92!O8FIE
M8W0*("`@("H@)V=O=$AE861E<G,G.B!A9G1E<B!R96-E:79I;F<@<F5S<&]N
M<V4@:&5A9&5R<R`H:&5A9&5R<R!A<F4@<&%S<V5D(&EN("1D871A*0H@("`@
M*B`G=&EC:R<Z(&]N(')E8V5I=FEN9R!A('!A<G0@;V8@<F5S<&]N<V4@8F]D
M>2`H=&AE('!A<G0@:7,@<&%S<V5D(&EN("1D871A*0H@("`@*B`G9WI4:6-K
M)SH@;VX@<F5C96EV:6YG(&$@9WII<"UE;F-O9&5D('!A<G0@;V8@<F5S<&]N
M<V4@8F]D>2`H9&ET=&\I"B`@("`J("=G;W1";V1Y)SH@869T97(@<F5C96EV
M:6YG('1H92!R97-P;VYS92!B;V1Y("AP87-S97,@=&AE(&1E8V]D960@8F]D
M>2!I;B`D9&%T82!I9B!I="!W87,@9WII<'!E9"D*("`@("H@"B`@("`J($!P
M87)A;2`@("!S=')I;F<@($5V96YT(&YA;64*("`@("H@0'!A<F%M("`@(&UI
M>&5D("`@061D:71I;VYA;"!D871A"B`@("`J($!A8V-E<W,@("!P<FEV871E
M"B`@("`J+PH@("`@9G5N8W1I;VX@7VYO=&EF>2@D979E;G0L("1D871A(#T@
M;G5L;"D*("`@('L*("`@("`@("!F;W)E86-H("AA<G)A>5]K97ES*"1T:&ES
M+3Y?;&ES=&5N97)S*2!A<R`D:60I('L*("`@("`@("`@("`@)'1H:7,M/E]L
M:7-T96YE<G-;)&ED72T^=7!D871E*"1T:&ES+"`D979E;G0L("1D871A*3L*
M("`@("`@("!]"B`@("!]"GT*"@HO*BH**B!297-P;VYS92!C;&%S<R!T;R!C
M;VUP;&5M96YT('1H92!297%U97-T(&-L87-S"BHO"F-L87-S($A45%!?4F5S
M<&]N<V4*>PH@("`@+RHJ"B`@("`J(%-O8VME="!O8FIE8W0*("`@("H@0'9A
M<B!O8FIE8W0*("`@("HO"B`@("!V87(@)%]S;V-K.PH*("`@("\J*@H@("`@
M*B!0<F]T;V-O;`H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D
M7W!R;W1O8V]L.PH@("`@"B`@("`O*BH*("`@("H@4F5T=7)N(&-O9&4*("`@
M("H@0'9A<B!S=')I;F<*("`@("HO"B`@("!V87(@)%]C;V1E.PH@("`@"B`@
M("`O*BH*("`@("H@4F5S<&]N<V4@:&5A9&5R<PH@("`@*B!`=F%R(&%R<F%Y
M"B`@("`J+PH@("`@=F%R("1?:&5A9&5R<SL*"B`@("`O*BH*("`@("H@0V]O
M:VEE<R!S970@:6X@<F5S<&]N<V4@(`H@("`@*B!`=F%R(&%R<F%Y"B`@("`J
M+PH@("`@=F%R("1?8V]O:VEE<SL*"B`@("`O*BH*("`@("H@4F5S<&]N<V4@
M8F]D>0H@("`@*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7V)O9'D@
M/2`G)SL*"B`@("\J*@H@("`@*B!5<V5D(&)Y(%]R96%D0VAU;FME9"@I.B!R
M96UA:6YI;F<@;&5N9W1H(&]F('1H92!C=7)R96YT(&-H=6YK"B`@("`J($!V
M87(@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?8VAU;FM,96YG=&@@/2`P.PH*
M("`@+RHJ"B`@("`J($%T=&%C:&5D(&QI<W1E;F5R<PH@("`@*B!`=F%R(&%R
M<F%Y"B`@("`J+PH@("`@=F%R("1?;&ES=&5N97)S(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("H@0V]N<W1R=6-T;W(*("`@("H*("`@("H@0'!A<F%M("!O
M8FIE8W0@3F5T7U-O8VME="`@("`@<V]C:V5T('1O(')E860@=&AE(')E<W!O
M;G-E(&9R;VT*("`@("H@0'!A<F%M("!A<G)A>2`@("`@("`@("`@("`@("`@
M;&ES=&5N97)S(&%T=&%C:&5D('1O(')E<75E<W0*("`@("H@0')E='5R;B!M
M:7AE9"!014%2($5R<F]R(&]N(&5R<F]R+"!T<G5E(&]T:&5R=VES90H@("`@
M*B\*("`@(&9U;F-T:6]N($A45%!?4F5S<&]N<V4H)B1S;V-K+"`F)&QI<W1E
M;F5R<RD*("`@('L*("`@("`@("`D=&AI<RT^7W-O8VL@("`@("`])B`D<V]C
M:SL*("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<R`])B`D;&ES=&5N97)S.PH@
M("`@?0H*"B`@("\J*@H@("`@*B!0<F]C97-S97,@82!(5%10(')E<W!O;G-E
M"B`@("`J(`H@("`@*B!4:&ES(&5X=')A8W1S(')E<W!O;G-E(&-O9&4L(&AE
M861E<G,L(&-O;VMI97,@86YD(&1E8V]D97,@8F]D>2!I9B!I="`*("`@("H@
M=V%S(&5N8V]D960@:6X@<V]M92!W87D*("`@("H*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("H@0'!A<F%M("!B;V]L("`@("`@5VAE=&AE<B!T;R!S=&]R
M92!R97-P;VYS92!B;V1Y(&EN(&]B:F5C="!P<F]P97)T>2P@<V5T"B`@("`J
M("`@("`@("`@("`@("`@("`@('1H:7,@=&\@9F%L<V4@:68@9&]W;FQO861I
M;F<@82!,05)'12!F:6QE(&%N9"!U<VEN9R!A($QI<W1E;F5R+@H@("`@*B`@
M("`@("`@("`@("`@("`@("!4:&ES(&ES(&%S<W5M960@=&\@8F4@=')U92!I
M9B!B;V1Y(&ES(&=Z:7`M96YC;V1E9"X*("`@("H@0'1H<F]W<R!014%27T5R
M<F]R"B`@("`J($!R971U<FX@;6EX960@("`@('1R=64@;VX@<W5C8V5S<RP@
M4$5!4E]%<G)O<B!I;B!C87-E(&]F(&UA;&9O<FUE9"!R97-P;VYS90H@("`@
M*B\*("`@(&9U;F-T:6]N('!R;V-E<W,H)'-A=F5";V1Y(#T@=')U92D*("`@
M('L*("`@("`@("!D;R!["B`@("`@("`@("`@("1L:6YE(#T@)'1H:7,M/E]S
M;V-K+3YR96%D3&EN92@I.PH@("`@("`@("`@("!I9B`H<W-C86YF*"1L:6YE
M+"`G2%144"\E<R`E<R<L("1H='1P7W9E<G-I;VXL("1R971U<FYC;V1E*2`A
M/2`R*2!["B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G36%L9F]R;65D(')E<W!O;G-E+B<I.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]P<F]T;V-O;"`]("=(5%10+R<@
M+B`D:'1T<%]V97)S:6]N.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C;V1E
M("`@("`](&EN='9A;"@D<F5T=7)N8V]D92D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@=VAI;&4@*"<G("$]/2`H)&AE861E<B`]("1T:&ES+3Y?<V]C
M:RT^<F5A9$QI;F4H*2DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<')O
M8V5S<TAE861E<B@D:&5A9&5R*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*#$P,"`]/2`D=&AI<RT^7V-O9&4I.PH*("`@("`@("`D=&AI<RT^
M7VYO=&EF>2@G9V]T2&5A9&5R<R<L("1T:&ES+3Y?:&5A9&5R<RD["@H@("`@
M("`@("\O($EF(')E<W!O;G-E(&)O9'D@:7,@<')E<V5N="P@<F5A9"!I="!A
M;F0@9&5C;V1E"B`@("`@("`@)&-H=6YK960@/2!I<W-E="@D=&AI<RT^7VAE
M861E<G-;)W1R86YS9F5R+65N8V]D:6YG)UTI("8F("@G8VAU;FME9"<@/3T@
M)'1H:7,M/E]H96%D97)S6R=T<F%N<V9E<BUE;F-O9&EN9R==*3L*("`@("`@
M("`D9WII<'!E9"`](&ES<V5T*"1T:&ES+3Y?:&5A9&5R<ULG8V]N=&5N="UE
M;F-O9&EN9R==*2`F)B`H)V=Z:7`G(#T]("1T:&ES+3Y?:&5A9&5R<ULG8V]N
M=&5N="UE;F-O9&EN9R==*3L*("`@("`@("`D:&%S0F]D>2`](&9A;'-E.PH@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]H96%D97)S6R=C;VYT96YT+6QE
M;F=T:"==*2!\?"`P("$]("1T:&ES+3Y?:&5A9&5R<ULG8V]N=&5N="UL96YG
M=&@G72D@>PH@("`@("`@("`@("!W:&EL92`H(21T:&ES+3Y?<V]C:RT^96]F
M*"DI('L*("`@("`@("`@("`@("`@(&EF("@D8VAU;FME9"D@>PH@("`@("`@
M("`@("`@("`@("`@("1D871A(#T@)'1H:7,M/E]R96%D0VAU;FME9"@I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M9&%T82`]("1T:&ES+3Y?<V]C:RT^<F5A9"@T,#DV*3L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&EF("@G)R`]/2`D9&%T82D@>PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D:&%S0F]D>2`]('1R=64["B`@("`@
M("`@("`@("`@("`@("`@:68@*"1S879E0F]D>2!\?"`D9WII<'!E9"D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V)O9'D@+CT@)&1A=&$[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?;F]T:69Y*"1G>FEP<&5D/R`G9WI4:6-K)SH@)W1I8VLG+"`D9&%T
M82D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"1H87-";V1Y*2!["B`@("`@("`@("`@("\O(%5N8V]M
M<')E<W,@=&AE(&)O9'D@:68@;F5E9&5D"B`@("`@("`@("`@(&EF("@D9WII
M<'!E9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]B;V1Y(#T@9WII;F9L
M871E*'-U8G-T<B@D=&AI<RT^7V)O9'DL(#$P*2D["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7VYO=&EF>2@G9V]T0F]D>2<L("1T:&ES+3Y?8F]D>2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VYO
M=&EF>2@G9V]T0F]D>2<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("\J*@H@("`@*B!0<F]C97-S
M97,@=&AE(')E<W!O;G-E(&AE861E<@H@("`@*@H@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("H@0'!A<F%M("!S=')I;F<@("`@2%144"!H96%D97(*("`@
M("HO"B`@("!F=6YC=&EO;B!?<')O8V5S<TAE861E<B@D:&5A9&5R*0H@("`@
M>PH@("`@("`@(&QI<W0H)&AE861E<FYA;64L("1H96%D97)V86QU92D@/2!E
M>'!L;V1E*"<Z)RP@)&AE861E<BP@,BD["B`@("`@("`@)&AE861E<FYA;64@
M(#T@<W1R=&]L;W=E<B@D:&5A9&5R;F%M92D["B`@("`@("`@)&AE861E<G9A
M;'5E(#T@;'1R:6TH)&AE861E<G9A;'5E*3L*("`@("`@("`*("`@("`@("!I
M9B`H)W-E="UC;V]K:64G("$]("1H96%D97)N86UE*2!["B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VAE861E<G-;)&AE861E<FYA;65=*2D@>PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]H96%D97)S6R1H96%D97)N86UE72`N
M/2`G+"<@+B`D:&5A9&5R=F%L=64["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VAE861E<G-;)&AE861E<FYA;65=("`]
M("1H96%D97)V86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5#;V]K:64H)&AE861E<G9A;'5E
M*3L*("`@("`@("!]"B`@("!]"@H*("`@+RHJ"B`@("`J(%!A<G-E(&$@4V5T
M+4-O;VMI92!H96%D97(@=&\@9FEL;"`D7V-O;VMI97,@87)R87D*("`@("H*
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!P87)A;2`@<W1R:6YG("`@
M('9A;'5E(&]F(%-E="U#;V]K:64@:&5A9&5R"B`@("`J+PH@("`@9G5N8W1I
M;VX@7W!A<G-E0V]O:VEE*"1H96%D97)V86QU92D*("`@('L*("`@("`@("`D
M8V]O:VEE(#T@87)R87DH"B`@("`@("`@("`@("=E>'!I<F5S)R`]/B!N=6QL
M+`H@("`@("`@("`@("`G9&]M86EN)R`@/3X@;G5L;"P*("`@("`@("`@("`@
M)W!A=&@G("`@(#T^(&YU;&PL"B`@("`@("`@("`@("=S96-U<F4G("`]/B!F
M86QS90H@("`@("`@("D["@H@("`@("`@("\O($]N;'D@82!N86UE/79A;'5E
M('!A:7(*("`@("`@("!I9B`H(7-T<G!O<R@D:&5A9&5R=F%L=64L("<[)RDI
M('L*("`@("`@("`@("`@)'!O<R`]('-T<G!O<R@D:&5A9&5R=F%L=64L("<]
M)RD["B`@("`@("`@("`@("1C;V]K:65;)VYA;64G72`@/2!T<FEM*'-U8G-T
M<B@D:&5A9&5R=F%L=64L(#`L("1P;W,I*3L*("`@("`@("`@("`@)&-O;VMI
M95LG=F%L=64G72`]('1R:6TH<W5B<W1R*"1H96%D97)V86QU92P@)'!O<R`K
M(#$I*3L*"B`@("`@("`@+R\@4V]M92!O<'1I;VYA;"!P87)A;65T97)S(&%R
M92!S=7!P;&EE9`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1E;&5M
M96YT<R`](&5X<&QO9&4H)SLG+"`D:&5A9&5R=F%L=64I.PH@("`@("`@("`@
M("`D<&]S(#T@<W1R<&]S*"1E;&5M96YT<ULP72P@)STG*3L*("`@("`@("`@
M("`@)&-O;VMI95LG;F%M92==("`]('1R:6TH<W5B<W1R*"1E;&5M96YT<ULP
M72P@,"P@)'!O<RDI.PH@("`@("`@("`@("`D8V]O:VEE6R=V86QU92==(#T@
M=')I;2AS=6)S='(H)&5L96UE;G1S6S!=+"`D<&]S("L@,2DI.PH*("`@("`@
M("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)&5L96UE;G1S*3L@)&DK
M*RD@>PH@("`@("`@("`@("`@("`@:68@*&9A;'-E(#T]/2!S=')P;W,H)&5L
M96UE;G1S6R1I72P@)STG*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;$YA
M;64@(#T@=')I;2@D96QE;65N='-;)&E=*3L*("`@("`@("`@("`@("`@("`@
M("`D96Q686QU92`](&YU;&P["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&QI<W0@*"1E;$YA;64L("1E;%9A;'5E*2`]
M(&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D96QE;65N='-;)&E=
M*2D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D96Q.86UE
M(#T@<W1R=&]L;W=E<B@D96Q.86UE*3L*("`@("`@("`@("`@("`@(&EF("@G
M<V5C=7)E)R`]/2`D96Q.86UE*2!["B`@("`@("`@("`@("`@("`@("`@)&-O
M;VMI95LG<V5C=7)E)UT@/2!T<G5E.PH@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*"=E>'!I<F5S)R`]/2`D96Q.86UE*2!["B`@("`@("`@("`@("`@("`@
M("`@)&-O;VMI95LG97AP:7)E<R==(#T@<W1R7W)E<&QA8V4H)R(G+"`G)RP@
M)&5L5F%L=64I.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*"=P871H)R`]
M/2`D96Q.86UE('Q\("=D;VUA:6XG(#T]("1E;$YA;64I('L*("`@("`@("`@
M("`@("`@("`@("`D8V]O:VEE6R1E;$YA;65=(#T@=7)L9&5C;V1E*"1E;%9A
M;'5E*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)&-O;VMI95LD96Q.86UE72`]("1E;%9A;'5E.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3Y?8V]O:VEE<UM=(#T@)&-O;VMI93L*("`@('T*"@H@("`O*BH*("`@("H@
M4F5A9"!A('!A<G0@;V8@<F5S<&]N<V4@8F]D>2!E;F-O9&5D('=I=&@@8VAU
M;FME9"!4<F%N<V9E<BU%;F-O9&EN9PH@("`@*B`*("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`J($!R971U<FX@<W1R:6YG"B`@("`J+PH@("`@9G5N8W1I
M;VX@7W)E861#:'5N:V5D*"D*("`@('L*("`@("`@("`O+R!A="!S=&%R="!O
M9B!T:&4@;F5X="!C:'5N:S\*("`@("`@("!I9B`H,"`]/2`D=&AI<RT^7V-H
M=6YK3&5N9W1H*2!["B`@("`@("`@("`@("1L:6YE(#T@)'1H:7,M/E]S;V-K
M+3YR96%D3&EN92@I.PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UXH
M6S`M.6$M9ETK*2]I)RP@)&QI;F4L("1M871C:&5S*2D@>PH@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C:'5N:TQE;F=T:"`](&AE>&1E8R@D;6%T8VAE<ULQ
M72D[(`H@("`@("`@("`@("`@("`@+R\@0VAU;FL@=VET:"!Z97)O(&QE;F=T
M:"!I;F1I8V%T97,@=&AE(&5N9`H@("`@("`@("`@("`@("`@:68@*#`@/3T@
M)'1H:7,M/E]C:'5N:TQE;F=T:"D@>PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<V]C:RT^<F5A9$QI;F4H*3L@+R\@;6%K92!T:&ES(&%N(&5O9B@I
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("<G.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("<G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1D871A
M(#T@)'1H:7,M/E]S;V-K+3YR96%D*"1T:&ES+3Y?8VAU;FM,96YG=&@I.PH@
M("`@("`@("1T:&ES+3Y?8VAU;FM,96YG=&@@+3T@<W1R;&5N*"1D871A*3L*
M("`@("`@("!I9B`H,"`]/2`D=&AI<RT^7V-H=6YK3&5N9W1H*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<V]C:RT^<F5A9$QI;F4H*3L@+R\@5')A:6QI;F<@
M0U),1@H@("`@("`@('T*("`@("`@("!R971U<FX@)&1A=&$["B`@("!]"@H*
M("`@+RHJ"B`@("`J($YO=&EF:65S(&%L;"!R96=I<W1E<F5D(&QI<W1E;F5R
M<R!O9B!A;B!E=F5N="X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@
M($5V96YT(&YA;64*("`@("H@0'!A<F%M("`@(&UI>&5D("`@061D:71I;VYA
M;"!D871A"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!S964@2%14
M4%]297%U97-T.CI?;F]T:69Y*"D*("`@("HO"B`@("!F=6YC=&EO;B!?;F]T
M:69Y*"1E=F5N="P@)&1A=&$@/2!N=6QL*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]L:7-T96YE<G,I(&%S("1I9"D@>PH@
M("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:61=+3YU<&1A=&4H)'1H
M:7,L("1E=F5N="P@)&1A=&$I.PH@("`@("`@('T*("`@('T*?2`O+R!%;F0@
M8VQA<W,@2%144%]297-P;VYS90H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+TA45%`O4F5Q=65S="],:7-T96YE<BYP:'``
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<R-3`@,3`U,34T,S0Q
M,S4@,#(S,3<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,RP@4FEC:&%R9"!(97EE<R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($%L;"!R:6=H
M=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@?`HO+R!\(&UO
M9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F
M;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE=#H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T
M86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@("!N;W1I8V4L
M('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I
M<V-L86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B
M:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT
M("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A
M;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\"B\O('P@("!D
M;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4@9&ES=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N86UE<R!O9B!T
M:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M
M;W1E("`@("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@
M<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O
M('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$
M140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@
M("!\"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!7
M05)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)
M5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)0
M3U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]0
M65))1TA4("!\"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),
M12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@
M?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%
M4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L
M(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[
M($Q/4U,@3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E53
M24Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9
M('P*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E12
M04-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,
M541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9
M(%=!62!/550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@
M159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!
M34%'12X@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!!;&5X
M97D@0F]R>F]V(#QA=F)`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O"B\O("1)9#H@3&ES=&5N97(N<&AP+'8@,2XR(#(P,#,O,3`O,C8@,3`Z
M,C@Z,CD@879B($5X<"`D"B\O"@HO*BH*("H@5&AI<R!C;&%S<R!I;7!L96UE
M;G1S('1H92!/8G-E<G9E<B!P87)T(&]F(&$@4W5B:F5C="U/8G-E<G9E<@H@
M*B!D97-I9VX@<&%T=&5R;BX@270@;&ES=&5N<R!T;R!T:&4@979E;G1S('-E
M;G0@8GD@82`*("H@2%144%]297%U97-T(&]R($A45%!?4F5S<&]N<V4@:6YS
M=&%N8V4N"B`J"B`J($!P86-K86=E($A45%!?4F5Q=65S=`H@*B!`875T:&]R
M("!!;&5X97D@0F]R>F]V(#QA=F)`<&AP+FYE=#X*("H@0'9E<G-I;VX@)%)E
M=FES:6]N.B`Q+C(@)`H@*B\*8VQA<W,@2%144%]297%U97-T7TQI<W1E;F5R
M(`I["B`@("\J*@H@("`@*B!!(&QI<W1E;F5R)W,@:61E;G1I9FEE<@H@("`@
M*B!`=F%R('-T<FEN9PH@("`@*B\*("`@('9A<B`D7VED.PH*("`@+RHJ"B`@
M("`J($-O;G-T<G5C=&]R+"!S971S('1H92!O8FIE8W0G<R!I9&5N=&EF:65R
M"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I
M;VX@2%144%]297%U97-T7TQI<W1E;F5R*"D*("`@('L*("`@("`@("`D=&AI
M<RT^7VED(#T@;60U*'5N:7%I9"@G:'1T<%]R97%U97-T7R<L(#$I*3L*("`@
M('T*"@H@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@;&ES=&5N97(G<R!I9&5N
M=&EF:65R"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U
M<FX@<W1R:6YG"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T260H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^7VED.PH@("`@?0H*"B`@("\J*@H@("`@
M*B!4:&ES(&UE=&AO9"!I<R!C86QL960@=VAE;B!,:7-T96YE<B!I<R!N;W1I
M9FEE9"!O9B!A;B!E=F5N=`H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC
M"B`@("`J($!P87)A;2`@("!O8FIE8W0@(&%N(&]B:F5C="!T:&4@;&ES=&5N
M97(@:7,@871T86-H960@=&\*("`@("H@0'!A<F%M("`@('-T<FEN9R`@179E
M;G0@;F%M90H@("`@*B!`<&%R86T@("`@;6EX960@("!!9&1I=&EO;F%L(&1A
M=&$*("`@("H@0&%B<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@=7!D871E
M*"8D<W5B:F5C="P@)&5V96YT+"`D9&%T82`](&YU;&PI"B`@("!["B`@("`@
M("`@96-H;R`B3F]T:69I960@;V8@979E;G0Z("<D979E;G0G7&XB.PH@("`@
M("`@(&EF("AN=6QL("$]/2`D9&%T82D@>PH@("`@("`@("`@("!E8VAO(")!
M9&1I=&EO;F%L(&1A=&$Z("(["B`@("`@("`@("`@('9A<E]D=6UP*"1D871A
M*3L*("`@("`@("!]"B`@("!]"GT*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-
M3%]087)S97(`````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S0@,#(Q-3(Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(`````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-"`P,C`P,S(`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R].971?4TU44```````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,U(#`R,3$S-P`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+TUA:6P`````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S4@,#(P-#,P`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00P``````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-2`P
M,C`W,3(`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<`````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,3,U(#`R,#(V-P`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+T1A=&4`````````````````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S4@,#(P-#(S`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL90``````````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$S-2`P,C`T,C4`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&
M:6QE+W1E<W1S````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,3,U(#`R,34V-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S4@,#(R,C(R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]T
M97-T+F-S=@``````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3`S,2`Q
M,#4Q-30S-#$S-2`P,C,S,S4`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````9C$)9C()9C,)9C0*9V]O9#$)9V]O9#()9V]O9#,)
M9V]O9#0*.SL[.SL).SL[.SL).SL[.SL).SL[.SL*.B`Z(#H).R`[("()(BX)
M(@DZ.CHZ.SL[.R(*;F\B<75O=&4);F\B<74B;W1E"6XB<75O=&4B"6XB<2)U
M(F\B="(*(G%U;W1E,2()(G%U;W1E,B();F]Q=6]T93,B"6YO<75O=&4T"G1E
M<W0Q"2)L;VYG"G1E<W0R(@DB;&]N9R!T97-T,PEW:71H"7-E<',B"2)))VT*
M"0D)"0ES:6QL>0H)"0D)"6QO;F<B"FQE<W,Q"2)L97-S,@DN(@EL97-S,PII
M<W9A;&ED,0EI<W9A;&ED,@EI<W9A;&ED,PEI<W9A;&ED-`IM;W)E,C$)(FUO
M<F4R,@D)+B();6]R93(S"6UO<F4R-`EM;W)E,C4);6]R93(V"FES=F%L:60R
M,0EI<W9A;&ED,C():7-V86QI9#(S"6ES=F%L:60R-`IL97-S;F]Q,S$);&5S
M<VYO<3,R"6QE<W-N;W$S,PII<W9A;&ED,S$):7-V86QI9#,R"6ES=F%L:60S
M,PEI<W9A;&ED,S0*;6]R96YO<30Q"6UO<F5N;W$T,@EM;W)E;F]Q-#,);6]R
M96YO<30T"6UO<F5N;W$T-0II<W9A;&ED-#$):7-V86QI9#0R"6ES=F%L:60T
M,PEI<W9A;&ED-#0*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T
M97-T<R]&:6QE5&5S="YP:'``````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R
M,3$Q,2`Q,#4Q-30S-#$S-2`P,C0P-S(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\O(&YE961E9"!F;W(@;&]C
M:VEN9R!T97-T"F1E9FEN92@G1DE,15],3T-+4U]"3$]#2R<L(&9A;'-E+"!T
M<G5E*3L*"G)E<75I<F5?;VYC92`G4$A056YI="YP:'`G.PIR97%U:7)E7V]N
M8V4@)T9I;&4N<&AP)SL*"F-L87-S($9I;&5497-T(&5X=&5N9',@4$A056YI
M=%]497-T0V%S92`*>PH@("`@9G5N8W1I;VX@1FEL951E<W0H)&YA;64@/2`G
M1FEL951E<W0G*0H@("`@>PH@("`@("`@("1T:&ES+3Y02%!5;FET7U1E<W1#
M87-E*"1N86UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!G971497-T4W1R:6YG
M*"D*("`@('L*("`@("`@("!S=&%T:6,@)'-T<CL*("`@("`@("!I<W-E="@D
M<W1R*2!O<B`D<W1R(#T@<W1R7W)E<&5A="AS=')?<F5P96%T*"(P,3(S-#4V
M-S@Y(BP@,3`P,"DN(EQN(BP@,3`P*3L*("`@("`@("!R971U<FX@)'-T<CL*
M("`@('T*("`@(`H@("`@9G5N8W1I;VX@9V5T5&5S=$QI;F4H*0H@("`@>PH@
M("`@("`@('-T871I8R`D<W1R.PH@("`@("`@(&ES<V5T*"1S='(I(&]R("1S
M='(@/2!S=')?<F5P96%T*"(P,3(S-#4V-S@Y(BP@,3`P,"D["B`@("`@("`@
M<F5T=7)N("1S='(["B`@("!]"B`@("`*("`@(&9U;F-T:6]N('-E=%5P*"D*
M("`@('L*("`@("`@("`D=&AI<RT^=&5A<D1O=VXH*3L*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D92`]($9I;&4Z.G=R:71E*"=T97-T+G1X="<L("1T
M:&ES+3YG971497-T4W1R:6YG*"DL($9)3$5?34]$15]74DE412DI*2!["B`@
M("`@("`@("`@(&1I92@B0V%N;F]T('-T87)T('1E<W0Z("(N('-T<E]R97!L
M86-E*"1T:&ES+3YG971497-T4W1R:6YG*"DL)RXN+B<L("1E+3YG971-97-S
M86=E*"DI*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&5A<D1O
M=VXH*0H@("`@>PH@("`@("`@($9I;&4Z.F-L;W-E06QL*"D["B`@("`@("`@
M9FEL95]E>&ES=',H)W1E<W0N='AT)RD@86YD('5N;&EN:R@G=&5S="YT>'0G
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T;&]C:VEN9R@I"B`@("!["B`@
M("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ
M=W)I=&4H)W1E<W0N='AT)RP@)V%B8R<L($9)3$5?34]$15]!4%!%3D0L('1R
M=64I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H4$5!4CHZ:7-%<G)O
M<BA&:6QE.CIW<FET92@G=&5S="YT>'0G+"`G9&5F)RP@1DE,15]-3T1%7U=2
M251%+"!T<G5E*2DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2
M.CII<T5R<F]R*$9I;&4Z.G5N;&]C:R@G=&5S="YT>'0G+"!&24Q%7TU/1$5?
M05!014Y$*2DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII
M<T5R<F]R*$9I;&4Z.G5N;&]C:R@G=&5S="YT>'0G+"!&24Q%7TU/1$5?5U))
M5$4I*2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=&-L;W-E*"D*("`@('L*
M("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE
M.CIC;&]S92@G=&5S="YT>'0G+"!&24Q%7TU/1$5?5U))5$4I*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H1FEL93HZ8VQO
M<V4H)W1E<W0N='AT)RP@1DE,15]-3T1%7T%04$5.1"DI*3L*("`@("`@("`D
M=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIC;&]S92@G
M=&5S="YT>'0G+"!&24Q%7TU/1$5?4D5!1"DI*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!T97-T<F5A9$%L;"@I"B`@("!["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=%-T<FEN9R@I+"!&:6QE.CIR96%D06QL
M*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T
M:&ES+3YG971497-T4W1R:6YG*"DL($9I;&4Z.G)E861!;&PH)W1E<W0N='AT
M)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E
M<W13=')I;F<H*2P@1FEL93HZ<F5A9$%L;"@G=&5S="YT>'0G*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&5S=')E860H*0H@("`@>PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E
M860H)W1E<W0N='AT)RP@,3`P,#`I*3L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*")<;B(L($9I;&4Z.G)E860H)W1E<W0N='AT)RP@,2DI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S`Q,C,T-38W.#DG+"!&:6QE.CIR
M96%D*"=T97-T+G1X="<L(#$P*2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S
M='=R:71E*"D*("`@('L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!
M4CHZ:7-%<G)O<B@D8GET97,@/2!&:6QE.CIW<FET92@G=&5S="YT>'0G+"`G
M,#$R,S0U-C<X.2<I*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q
M,"P@)&)Y=&5S*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T<F5A9$-H87(H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92A014%2.CII<T5R
M<F]R*$9I;&4Z.G)E=VEN9"@G=&5S="YT>'0G+"!&24Q%7TU/1$5?4D5!1"DI
M*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<P)RP@1FEL93HZ<F5A
M9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H)S$G+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$5Q=6%L<R@G,B<L($9I;&4Z.G)E861#:&%R*"=T97-T
M+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<S)RP@1FEL
M93HZ<F5A9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H)S0G+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G*2D["B`@
M("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G-2<L($9I;&4Z.G)E861#:&%R
M*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<V
M)RP@1FEL93HZ<F5A9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)S<G+"!&:6QE.CIR96%D0VAA<B@G=&5S="YT>'0G
M*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G."<L($9I;&4Z.G)E
M861#:&%R*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U
M86QS*"<Y)RP@1FEL93HZ<F5A9$-H87(H)W1E<W0N='AT)RDI.PH@("`@("`@
M("1T:&ES+3YA<W-E<G1%<75A;',H)S`G+"!&:6QE.CIR96%D0VAA<B@G=&5S
M="YT>'0G*2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S='=R:71E0VAA<B@I
M"B`@("!["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW
M<FET94-H87(H)W1E<W0N='AT)RP@)V$G*2D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V(G
M*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET
M94-H87(H)W1E<W0N='AT)RP@)V,G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V0G*2D[
M"B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H
M87(H)W1E<W0N='AT)RP@)V4G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q
M=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V8G*2D["B`@
M("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H
M)W1E<W0N='AT)RP@)V<G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)V@G*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q+"!&:6QE.CIW<FET94-H87(H)W1E
M<W0N='AT)RP@)VDG*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@Q
M+"!&:6QE.CIW<FET94-H87(H)W1E<W0N='AT)RP@)VHG*2D["B`@("!]"@H@
M("`@9G5N8W1I;VX@=&5S=')E861,:6YE*"D*("`@('L*("`@("`@("`D=&AI
M<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE.CIR97=I;F0H)W1E
M<W0N='AT)RP@1DE,15]-3T1%7U)%040I*2D["B`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI
M;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,:6YE*"=T97-T+G1X
M="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1T:&ES+3YG9714
M97-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S="YT>'0G*2D["B`@("`@
M("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@
M1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL($9I;&4Z.G)E861,
M:6YE*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS
M*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR96%D3&EN92@G=&5S="YT
M>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&AI<RT^9V5T
M5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N='AT)RDI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)'1H:7,M/F=E=%1E<W1,:6YE*"DL
M($9I;&4Z.G)E861,:6YE*"=T97-T+G1X="<I*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*"1T:&ES+3YG971497-T3&EN92@I+"!&:6QE.CIR96%D
M3&EN92@G=&5S="YT>'0G*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@D=&AI<RT^9V5T5&5S=$QI;F4H*2P@1FEL93HZ<F5A9$QI;F4H)W1E<W0N
M='AT)RDI.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1W<FET94QI;F4H*0H@
M("`@>PH@("`@("`@("1L:6YE(#T@)'1H:7,M/F=E=%1E<W1,:6YE*"D["B`@
M("`@("`@)&QE;F=T:"`]('-T<FQE;B@D;&EN92D@*R`Q.PH@("`@("`@("1T
M:&ES+3YA<W-E<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T
M97-T+G1X="<L("1L:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@D;&5N9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I
M*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z
M.G=R:71E3&EN92@G=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T
M+G1X="<L("1L:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D
M;&5N9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R
M:71E3&EN92@G=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X
M="<L("1L:6YE*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D;&5N
M9W1H+"!&:6QE.CIW<FET94QI;F4H)W1E<W0N='AT)RP@)&QI;F4I*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*"1L96YG=&@L($9I;&4Z.G=R:71E
M3&EN92@G=&5S="YT>'0G+"`D;&EN92DI.PH@("`@("`@("1T:&ES+3YA<W-E
M<G1%<75A;',H)&QE;F=T:"P@1FEL93HZ=W)I=&5,:6YE*"=T97-T+G1X="<L
M("1L:6YE*2D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=')E=VEN9"@I"B`@
M("!["B`@("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*%!%05(Z.FES17)R;W(H
M1FEL93HZ<F5W:6YD*"=T97-T+G1X="<L($9)3$5?34]$15]74DE412DI*3L*
M("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H4$5!4CHZ:7-%<G)O<BA&:6QE
M.CIR97=I;F0H)W1E<W0N='AT)RP@1DE,15]-3T1%7U)%040I*2D["B`@("!]
M"@H@("`@9G5N8W1I;VX@=&5S=&)U:6QD4&%T:"@I"B`@("!["B`@("`@("`@
M)'!A=&@@/2!A<G)A>2@*("`@("`@("`@("`@)W-O;64G+`H@("`@("`@("`@
M("!$25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("`@("!$25)%0U1/4EE?
M4T5005)!5$]2+`H@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+`H@
M("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+`H@("`@("`@("`@("`G
M=V5I<F0G+D1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@("`@($1)4D5#
M5$]265]315!!4D%43U(L"B`@("`@("`@("`@($1)4D5#5$]265]315!!4D%4
M3U(L"B`@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(L"B`@("`@("`@
M("`@($1)4D5#5$]265]315!!4D%43U(N)W!A=&@G+D1)4D5#5$]265]315!!
M4D%43U(N1$E214-43U)97U-%4$%2051/4BP*("`@("`@("`I.PH@("`@("`@
M("1B=6EL="`](&EM<&QO9&4H1$E214-43U)97U-%4$%2051/4BP@87)R87DH
M)W-O;64G+"=W96ER9"<L)W!A=&@G+"<G+"<G*2D["B`@("`@("`@)'1H:7,M
M/F%S<V5R=$5Q=6%L<R@D8G5I;'0L($9I;&4Z.F)U:6QD4&%T:"@D<&%T:"DI
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1S:VEP4F]O="@I"B`@("!["B`@
M("`@("`@:68@*$]37U=)3D1/5U,I('L*("`@("`@("`@("`@)'1H:7,M/F%S
M<V5R=$5Q=6%L<R@G5TE.1$]74R<L($9I;&4Z.G-K:7!2;V]T*"=#.EQ<5TE.
M1$]74R<I*3L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G5TE.
M1$]74R<L($9I;&4Z.G-K:7!2;V]T*"=#.EQ<7%Q724Y$3U=3)RDI.PH@("`@
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"=724Y$3U=3)RP@1FEL93HZ
M<VMI<%)O;W0H)T,Z+U=)3D1/5U,G*2D["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@G=7-R+W-H87)E+W!E87(G
M+"!&:6QE.CIS:VEP4F]O="@G+W5S<B]S:&%R92]P96%R)RDI.PH@("`@("`@
M('T*("`@('T*"B`@("!F=6YC=&EO;B!T97-T9V5T5&5M<$1I<B@I"B`@("![
M"B`@("`@("`@)&1I<B`]($9I;&4Z.F=E=%1E;7!$:7(H*3L*("`@("`@("`D
M=&AI<RT^87-S97)T5')U92AI<U]D:7(H)&1I<BDL(")I<U]D:7(H)&1I<BDB
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T9V5T5&5M<$9I;&4H*0H@("`@
M>PH@("`@("`@("1T;7`@/2!&:6QE.CIG971496UP1FEL92@I.PH@("`@("`@
M("1T:&ES+3YA<W-E<G14<G5E*&9I;&5?97AI<W1S*"1T;7`I*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T:7-!8G-O;'5T92@I"B`@("!["B`@("`@("`@
M)'1H:7,M/F%S<V5R=$9A;'-E*$9I;&4Z.FES06)S;VQU=&4H)V%B<F$O+BXO
M8V%D86)R82<I*3L*("`@("`@("`D=&AI<RT^87-S97)T1F%L<V4H1FEL93HZ
M:7-!8G-O;'5T92@G9&%T82]D:7(G*2D["B`@("`@("`@:68@*$]37U=)3D1/
M5U,I('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H1FEL93HZ:7-!
M8G-O;'5T92@G0SI<7%Q<9&%T82<I*3L*("`@("`@("`@("`@)'1H:7,M/F%S
M<V5R=%1R=64H1FEL93HZ:7-!8G-O;'5T92@G9#HO9&%T82<I*3L*("`@("`@
M("`@("`@)'1H:7,M/F%S<V5R=$9A;'-E*$9I;&4Z.FES06)S;VQU=&4H)UQ<
M)RDI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YA<W-E
M<G14<G5E*$9I;&4Z.FES06)S;VQU=&4H)R\G*2D["B`@("`@("`@("`@("1T
M:&ES+3YA<W-E<G1&86QS92A&:6QE.CII<T%B<V]L=71E*"=<7"<I*3L*("`@
M("`@("`@("`@)'1H:7,M/F%S<V5R=%1R=64H1FEL93HZ:7-!8G-O;'5T92@G
M?FUI:V4O8FEN)RDI.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!T
M97-T<F5L871I=F50871H*"D*("`@('L*("`@("`@("`D=&AI<RT^87-S97)T
M17%U86QS*"=T97-T<R]&:6QE)RP@1FEL93HZ<F5L871I=F50871H*"<O=7-R
M+W-H87)E+W!E87(O=&5S=',O1FEL92<L("<O=7-R+W-H87)E+W!E87(G+"`G
M+R<I*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<N+B]E=&,G+"!&
M:6QE.CIR96QA=&EV95!A=&@H)R]E=&,G+"`G+W5S<B<L("<O)RDI.PH@("`@
M("`@("1T:&ES+3YA<W-E<G1%<75A;',H)T0Z7%Q$871A)RP@1FEL93HZ<F5L
M871I=F50871H*"=$.EQ<1&%T82<L("=#.EQ<1&%T82<L("=<7"<I*3L*("`@
M("`@("!I9B`H3U-?5TE.1$]74RD@>PH@("`@("`@("`@("`D=&AI<RT^87-S
M97)T17%U86QS*"=D871A7%QD:7(G+"!&:6QE.CIR96QA=&EV95!A=&@H)R]V
M87(O9&%T82]D:7(G+"`G+W9A<B<I*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"=D871A+V1I<B<L($9I;&4Z
M.G)E;&%T:79E4&%T:"@G+W9A<B]D871A+V1I<B<L("<O=F%R)RDI.PH@("`@
M("`@('T*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"<N+B\G+"!&:6QE
M.CIR96QA=&EV95!A=&@H)V1A=&$G+"`G9&%T82]D:7(G+"`G+R<I*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!T97-T<F5A;'!A=&@H*0H@("`@>PH@("`@("`@
M("1D<FEV92`]($]37U=)3D1/5U,@/R!S=6)S='(H9V5T8W=D*"DL,"P@,BD@
M.B<G.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)&1R:79E("X@)R]A
M+W=E:7)D+W!A=&@O:7,G+"!&:6QE.CIR96%L<&%T:"@G+V%<7'=E:7)D+R]P
M871H7&ES+W1H870O+B\N+B\G+"`G+R<I*3L*("`@("`@("`D=&AI<RT^87-S
M97)T17%U86QS*"1D<FEV92`N("<O82]W96ER9"]P871H+VES+W1H870G+"!&
M:6QE.CIR96%L<&%T:"@G+V%<7'=E:7)D+R]P871H7&ES+W1H870O+B\N+B]T
M:&%T+RXG+"`G+R<I*3L*("`@('T*?0H*)')E<W5L="`]("902%!5;FET.CIR
M=6XH;F5W(%!(4%5N:71?5&5S=%-U:71E*"=&:6QE5&5S="<I*3L*96-H;R`D
M<F5S=6QT+3YT;U-T<FEN9R@I.PH*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]&:6QE+W1E<W1S+W!A<G-E<BYP:'``````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`Q,C`P(#$P-3$U-#,T,3,U(#`R,S8T-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HD<&%T:"`](&EN
M:5]G970H)VEN8VQU9&5?<&%T:"<I.PII;FE?<V5T*"=I;F-L=61E7W!A=&@G
M+"!R96%L<&%T:"@G+BXO)RD@+B`B.B1P871H(BD["G)E<75I<F5?;VYC92`G
M1FEL92]#4U8N<&AP)SL*"B\J+T5X86UP;&4@8V]N9CH*)&-O;F8@/2!A<G)A
M>2@*("`@("=F:65L9',G(#T^(#0L"B`@("`G<V5P)R`@("`]/B`B7'0B+`H@
M("`@)W%U;W1E)R`@/3X@)R(G+`H@("`@)VAE861E<B<@/3X@9F%L<V4**3L*
M+R\J+PIO8E]I;7!L:6-I=%]F;'5S:"AT<G5E*3L*)&%R9W8@/2`D7U-%4E9%
M4ELG87)G=B==.PHD9FEL92`]("1A<F=V6S%=.PHD=W)I=&4@/2`H:7-S970H
M)&%R9W9;,ETI*2`_("1A<F=V6S)=(#H@9F%L<V4["E!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"P@(G=A<FYI;F<Z("5S7&XB*3L*
M"B1C;VYF(#T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE*3L*=VAI
M;&4@*"1F:65L9',@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2![
M"B`@("!I9B`H)'=R:71E*2!["B`@("`@("`@1FEL95]#4U8Z.G=R:71E*"1W
M<FET92P@)&9I96QD<RP@)&-O;F8I.PH@("`@?0H@("`@<')I;G1?<B@D9FEE
M;&1S*3L*?0H*=F%R7V1U;7`H)&-O;F8I.PIE8VAO(")<;B(*"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#$N<&AP=```````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`R,34Q(#$P-3$U-#,T,3,U(#`R,S0W-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````M+51%4U0M+0I&
M:6QE7T-35B!497-T($-A<V4@,#`Q.B!&:65L9',@8V]U;G0@;&5S<R!T:&%N
M(&5X<&5C=&5D"BTM1DE,12TM"CP_<&AP"B\O("1)9#H@,#`Q+G!H<'0L=B`Q
M+C(@,C`P-2\P,B\Q."`Q,3HQ.3HS,R!D=69U>B!%>'`@)`HO*BH*("H@5&5S
M="!F;W(Z"B`J("T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"D*("H@+2!&
M:6QE7T-35CHZ<F5A9"@I"B`J+PH*<F5Q=6ER95]O;F-E("=&:6QE+T-35BYP
M:'`G.PH*)&9I;&4@/2`G,#`Q+F-S=B<["B1C;VYF(#T@1FEL95]#4U8Z.F1I
M<V-O=F5R1F]R;6%T*"1F:6QE*3L*"G!R:6YT(")&;W)M870Z7&XB.PIP<FEN
M=%]R*"1C;VYF*3L*<')I;G0@(EQN(CL*"B1D871A(#T@87)R87DH*3L*=VAI
M;&4@*"1R97,@/2!&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I*2!["B`@
M("`D9&%T85M=(#T@)')E<SL*?0H*<')I;G0@(D1A=&$Z7&XB.PIP<FEN=%]R
M*"1D871A*3L*/SX*+2U%6%!%0U0M+0I&;W)M870Z"D%R<F%Y"B@*("`@(%MF
M:65L9'-=(#T^(#0*("`@(%MS97!=(#T^("P*("`@(%MQ=6]T95T@/3X@(@HI
M"@I$871A.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@
M("`@("`@("`@(%LP72`]/B!&:65L9"`Q+3$*("`@("`@("`@("`@6S%=(#T^
M($9I96QD(#$M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,2TS"B`@("`@
M("`@("`@(%LS72`]/B!&:65L9"`Q+30*("`@("`@("`I"@H@("`@6S%=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,BTQ
M"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`R+3(*("`@("`@("`@("`@6S)=
M(#T^($9I96QD(#(M,PH@("`@("`@("`@("!;,UT@/3X@"B`@("`@("`@*0H*
M("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^
M($9I96QD(#,M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,RTR"B`@("`@
M("`@("`@(%LR72`]/B`*("`@("`@("`@("`@6S-=(#T^(`H@("`@("`@("D*
M"B`@("!;,UT@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]
M/B!&:65L9"`T+3$*("`@("`@("`@("`@6S%=(#T^(`H@("`@("`@("`@("!;
M,ET@/3X@"B`@("`@("`@("`@(%LS72`]/B`*("`@("`@("`I"@HI````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O0U-6
M+S`P,BYP:'!T````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-C(@,3`U
M,34T,S0Q,S4@,#(S-3`P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"TM5$535"TM"D9I;&5?0U-6(%1E<W0@0V%S92`P,#(Z
M($9I96QD<R!C;W5N="!M;W)E('1H86X@97AP96-T960*+2U&24Q%+2T*/#]P
M:'`*+R\@)$ED.B`P,#(N<&AP="QV(#$N,B`R,#`U+S`R+S$X(#$Q.C$Y.C,S
M(&1U9G5Z($5X<"`D"B\J*@H@*B!497-T(&9O<CH*("H@+2!&:6QE7T-35CHZ
M9&ES8V]V97)&;W)M870H*0H@*B`M($9I;&5?0U-6.CIR96%D*"D*("HO"@IR
M97%U:7)E7V]N8V4@)T9I;&4O0U-6+G!H<"<["@HD9FEL92`]("<P,#(N8W-V
M)SL*)&-O;F8@/2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H)&9I;&4I.PH*
M<')I;G0@(D9O<FUA=#I<;B(["G!R:6YT7W(H)&-O;F8I.PIP<FEN="`B7&XB
M.PH*)&1A=&$@/2!A<G)A>2@I.PIW:&EL92`H)')E<R`]($9I;&5?0U-6.CIR
M96%D*"1F:6QE+"`D8V]N9BDI('L*("`@("1D871A6UT@/2`D<F5S.PI]"@IP
M<FEN="`B1&%T83I<;B(["G!R:6YT7W(H)&1A=&$I.PH_/@HM+4584$5#5"TM
M"D9O<FUA=#H*07)R87D**`H@("`@6V9I96QD<UT@/3X@-`H@("`@6W-E<%T@
M/3X@+`H@("`@6W%U;W1E72`]/B`B"BD*"D1A=&$Z"D%R<F%Y"B@*("`@(%LP
M72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD
M(#$M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,2TR"B`@("`@("`@("`@
M(%LR72`]/B!&:65L9"`Q+3,*("`@("`@("`@("`@6S-=(#T^($9I96QD(#$M
M-`H@("`@("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@
M("`@("`@(%LP72`]/B!&:65L9"`R+3$*("`@("`@("`@("`@6S%=(#T^($9I
M96QD(#(M,@H@("`@("`@("`@("!;,ET@/3X@1FEE;&0@,BTS"B`@("`@("`@
M("`@(%LS72`]/B!&:65L9"`R+30*("`@("`@("`I"@H@("`@6S)=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,RTQ"B`@
M("`@("`@("`@(%LQ72`]/B!&:65L9"`S+3(*("`@("`@("`@("`@6S)=(#T^
M(`H@("`@("`@("`@("!;,UT@/3X@"B`@("`@("`@*0H*("`@(%LS72`]/B!!
M<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I96QD(#0M,0H@
M("`@("`@("`@("!;,5T@/3X@"B`@("`@("`@("`@(%LR72`]/B`*("`@("`@
M("`@("`@6S-=(#T^(`H@("`@("`@("D*"BD`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O=&5S=',O1FEL92]T97-T<R]#4U8O,#`R+F-S=@``````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#(S,B`Q,#4Q-30S-#$S-2`P,C,S,30`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````(D9I96QD(#$M
M,2(L(")&:65L9"`Q+3(B+"`B1FEE;&0@,2TS(BP@(D9I96QD(#$M-"(*(D9I
M96QD(#(M,2(L(")&:65L9"`R+3(B+"`B1FEE;&0@,BTS(BP@(D9I96QD(#(M
M-"(L(")%>'1R82!&:65L9"(*(D9I96QD(#,M,2(L(")&:65L9"`S+3(B"B)&
M:65L9"`T+3$B"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I
M;&4O=&5S=',O0U-6+S`P,RYP:'!T````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$W-C(@,3`U,34T,S0Q,S4@,#(S-3`V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"D9I;&5?0U-6(%1E
M<W0@0V%S92`P,#,Z(%=I;F1O=W,@14],"BTM1DE,12TM"CP_<&AP"B\O("1)
M9#H@,#`S+G!H<'0L=B`Q+C(@,C`P-2\P,B\Q."`Q,3HQ.3HS,R!D=69U>B!%
M>'`@)`HO*BH*("H@5&5S="!F;W(Z"B`J("T@1FEL95]#4U8Z.F1I<V-O=F5R
M1F]R;6%T*"D*("H@+2!&:6QE7T-35CHZ<F5A9"@I"B`J+PH*<F5Q=6ER95]O
M;F-E("=&:6QE+T-35BYP:'`G.PH*)&9I;&4@/2`G,#`S+F-S=B<["B1C;VYF
M(#T@1FEL95]#4U8Z.F1I<V-O=F5R1F]R;6%T*"1F:6QE*3L*"G!R:6YT(")&
M;W)M870Z7&XB.PIP<FEN=%]R*"1C;VYF*3L*<')I;G0@(EQN(CL*"B1D871A
M(#T@87)R87DH*3L*=VAI;&4@*"1R97,@/2!&:6QE7T-35CHZ<F5A9"@D9FEL
M92P@)&-O;F8I*2!["B`@("`D9&%T85M=(#T@)')E<SL*?0H*<')I;G0@(D1A
M=&$Z7&XB.PIP<FEN=%]R*"1D871A*3L*/SX*+2U%6%!%0U0M+0I&;W)M870Z
M"D%R<F%Y"B@*("`@(%MF:65L9'-=(#T^(#0*("`@(%MS97!=(#T^("P*("`@
M(%MQ=6]T95T@/3X@(@HI"@I$871A.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R
M87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`Q+3$*("`@
M("`@("`@("`@6S%=(#T^($9I96QD(#$M,@H@("`@("`@("`@("!;,ET@/3X@
M1FEE;&0@,2TS"B`@("`@("`@("`@(%LS72`]/B!&:65L9"`Q+30*("`@("`@
M("`I"@H@("`@6S%=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;
M,%T@/3X@1FEE;&0@,BTQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`R+3(*
M("`@("`@("`@("`@6S)=(#T^($9I96QD(#(M,PH@("`@("`@("`@("!;,UT@
M/3X@22=M(&UU;'1I;&EN90I&:65L9`H@("`@("`@("D*"B`@("!;,ET@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]/B!&:65L9"`S+3$*
M("`@("`@("`@("`@6S%=(#T^($9I96QD(#,M,@H@("`@("`@("`@("!;,ET@
M/3X@1FEE;&0@,RTS"B`@("`@("`@("`@(%LS72`]/B`*("`@("`@("`I"@HI
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T9I;&4O=&5S=',O0U-6+S`P,RYC<W8`````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`R,C(@,3`U,34T,S0Q,S4@,#(S,S$T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````")&:65L9"`Q+3$B+")&
M:65L9"`Q+3(B+")&:65L9"`Q+3,B+")&:65L9"`Q+30B#0HB1FEE;&0@,BTQ
M(BPB1FEE;&0@,BTR(BPB1FEE;&0@,BTS(BPB22=M(&UU;'1I;&EN90T*1FEE
M;&0B#0HB1FEE;&0@,RTQ(BPB1FEE;&0@,RTR(BPB1FEE;&0@,RTS(@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E
M<W1S+T-35B\P,#0N<&AP=```````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q
M-S4W(#$P-3$U-#,T,3,U(#`R,S4Q,P`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+51%4U0M+0I&:6QE7T-35B!497-T($-A
M<V4@,#`T.B!5;FEX($5/3`HM+49)3$4M+0H\/W!H<`HO+R`D260Z(#`P-"YP
M:'!T+'8@,2XR(#(P,#4O,#(O,3@@,3$Z,3DZ,S,@9'5F=7H@17AP("0*+RHJ
M"B`J(%1E<W0@9F]R.@H@*B`M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@I
M"B`J("T@1FEL95]#4U8Z.G)E860H*0H@*B\*"G)E<75I<F5?;VYC92`G1FEL
M92]#4U8N<&AP)SL*"B1F:6QE(#T@)S`P-"YC<W8G.PHD8V]N9B`]($9I;&5?
M0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL92D["@IP<FEN="`B1F]R;6%T.EQN
M(CL*<')I;G1?<B@D8V]N9BD["G!R:6YT(")<;B(["@HD9&%T82`](&%R<F%Y
M*"D["G=H:6QE("@D<F5S(#T@1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF
M*2D@>PH@("`@)&1A=&%;72`]("1R97,["GT*"G!R:6YT(")$871A.EQN(CL*
M<')I;G1?<B@D9&%T82D["C\^"BTM15A014-4+2T*1F]R;6%T.@I!<G)A>0HH
M"B`@("!;9FEE;&1S72`]/B`T"B`@("!;<V5P72`]/B`L"B`@("!;<75O=&5=
M(#T^("(**0H*1&%T83H*07)R87D**`H@("`@6S!=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,2TQ"B`@("`@("`@("`@
M(%LQ72`]/B!&:65L9"`Q+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD(#$M
M,PH@("`@("`@("`@("!;,UT@/3X@1FEE;&0@,2TT"B`@("`@("`@*0H*("`@
M(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^($9I
M96QD(#(M,0H@("`@("`@("`@("!;,5T@/3X@1FEE;&0@,BTR"B`@("`@("`@
M("`@(%LR72`]/B!&:65L9"`R+3,*("`@("`@("`@("`@6S-=(#T^($DG;2!M
M=6QT:6QI;F4*1FEE;&0*("`@("`@("`I"@H@("`@6S)=(#T^($%R<F%Y"B`@
M("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE;&0@,RTQ"B`@("`@("`@
M("`@(%LQ72`]/B!&:65L9"`S+3(*("`@("`@("`@("`@6S)=(#T^($9I96QD
M(#,M,PH@("`@("`@("`@("!;,UT@/3X@"B`@("`@("`@*0H**0``````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&
M:6QE+W1E<W1S+T-35B\P,#0N8W-V````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,C$V(#$P-3$U-#,T,3,U(#`R,S,R,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````B1FEE;&0@,2TQ(BPB1FEE;&0@
M,2TR(BPB1FEE;&0@,2TS(BPB1FEE;&0@,2TT(@HB1FEE;&0@,BTQ(BPB1FEE
M;&0@,BTR(BPB1FEE;&0@,BTS(BPB22=M(&UU;'1I;&EN90I&:65L9"(*(D9I
M96QD(#,M,2(L(D9I96QD(#,M,B(L(D9I96QD(#,M,R(*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1FEL92]T97-T<R]#
M4U8O,#`U+G!H<'0`````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C<Q,B`Q
M,#4Q-30S-#$S-2`P,C,U,#0`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*1FEL95]#4U8@5&5S="!#87-E(#`P
M-3H@36%C($5/3`HM+49)3$4M+0H\/W!H<`HO+R`D260Z(#`P-2YP:'!T+'8@
M,2XS(#(P,#4O,#(O,3D@,3(Z,C,Z,C@@9'5F=7H@17AP("0*+RHJ"B`J(%1E
M<W0@9F]R.@H@*B`M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@I"B`J("T@
M1FEL95]#4U8Z.G)E860H*0H@*B\*"G)E<75I<F5?;VYC92`G1FEL92]#4U8N
M<&AP)SL*"B1F:6QE(#T@)S`P-2YC<W8G.PHD8V]N9B`]($9I;&5?0U-6.CID
M:7-C;W9E<D9O<FUA="@D9FEL92D["@IP<FEN="`B1F]R;6%T.EQN(CL*<')I
M;G1?<B@D8V]N9BD["G!R:6YT(")<;B(["@HD9&%T82`](&%R<F%Y*"D["G=H
M:6QE("@D<F5S(#T@1FEL95]#4U8Z.G)E860H)&9I;&4L("1C;VYF*2D@>PH@
M("`@)&1A=&%;72`]("1R97,["GT*"F9U;F-T:6]N(%]D8F="=69F*"1D871A
M*0I["B`@("!F;W)E86-H("@D9&%T82!A<R`D:V5Y(#T^("1R;W<I('L*("`@
M("`@("!I9B`H<W1R<&]S*"1R;W<L(")<<B(I("$]/2!F86QS92D@>PH@("`@
M("`@("`@("`D<F]W(#T@<W1R7W)E<&QA8V4H(EQR(BP@(E]R7R(L("1R;W<I
M.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R<&]S*"1R;W<L(")<;B(I("$]
M/2!F86QS92D@>PH@("`@("`@("`@("`D<W1R(#T@<W1R7W)E<&QA8V4H(EQN
M(BP@(E]N7R(L("1R;W<I.PH@("`@("`@('T*("`@("`@("!I9B`H<W1R<&]S
M*"1R;W<L(")<="(I("$]/2!F86QS92D@>PH@("`@("`@("`@("`D<F]W(#T@
M<W1R7W)E<&QA8V4H(EQT(BP@(E]T7R(L("1R;W<I.PH@("`@("`@('T*("`@
M("`@("`D9&%T85LD:V5Y72`]("1R;W<["B`@("!]"B`@("!R971U<FX@)&1A
M=&$["GT*"B1D871A(#T@87)R87E?;6%P*"=?9&)G0G5F9B<L("1D871A*3L*
M"G!R:6YT(")$871A.EQN(CL*<')I;G1?<B@D9&%T82D["C\^"BTM15A014-4
M+2T*1F]R;6%T.@I!<G)A>0HH"B`@("!;9FEE;&1S72`]/B`T"B`@("!;<V5P
M72`]/B`L"B`@("!;<75O=&5=(#T^("(**0H*1&%T83H*07)R87D**`H@("`@
M6S!=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@1FEE
M;&0@,2TQ"B`@("`@("`@("`@(%LQ72`]/B!&:65L9"`Q+3(*("`@("`@("`@
M("`@6S)=(#T^($9I96QD(#$M,PH@("`@("`@("`@("!;,UT@/3X@1FEE;&0@
M,2TT"B`@("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@
M("`@("`@("`@6S!=(#T^($9I96QD(#(M,0H@("`@("`@("`@("!;,5T@/3X@
M1FEE;&0@,BTR"B`@("`@("`@("`@(%LR72`]/B!&:65L9"`R+3,*("`@("`@
M("`@("`@6S-=(#T^($DG;2!M=6QT:6QI;F5?<E]&:65L9`H@("`@("`@("D*
M"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP72`]
M/B!&:65L9"`S+3$*("`@("`@("`@("`@6S%=(#T^($9I96QD(#,M,@H@("`@
M("`@("`@("!;,ET@/3X@1FEE;&0@,RTS"B`@("`@("`@("`@(%LS72`]/B`*
M("`@("`@("`I"@HI````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P,#4N8W-V````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,C$V(#$P-3$U-#,T,3,U(#`R,S,R,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````B1FEE;&0@
M,2TQ(BPB1FEE;&0@,2TR(BPB1FEE;&0@,2TS(BPB1FEE;&0@,2TT(@TB1FEE
M;&0@,BTQ(BPB1FEE;&0@,BTR(BPB1FEE;&0@,BTS(BPB22=M(&UU;'1I;&EN
M90U&:65L9"(-(D9I96QD(#,M,2(L(D9I96QD(#,M,B(L(D9I96QD(#,M,R(-
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M1FEL92]T97-T<R]#4U8O,#`V+G!H<'0`````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#8R-R`Q,#4Q-30S-#$S-2`P,C,U,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*1FEL95]#4U8@
M5&5S="!#87-E(#`P-CH@3VYE(&9I96QD('%U;W1E(&%U=&]D:7-C;W9E<GD*
M+2U&24Q%+2T*/#]P:'`*+R\@)$ED.B`P,#8N<&AP="QV(#$N,2`R,#`U+S`U
M+S(Q(#`V.C(V.C0X(&1U9G5Z($5X<"`D"B\J*@H@*B!497-T(&9O<CH*("H@
M+2!&:6QE7T-35CHZ9&ES8V]V97)&;W)M870H*0H@*B\*"G)E<75I<F5?;VYC
M92`G1FEL92]#4U8N<&AP)SL*"B1F:6QE(#T@)S`P-BYC<W8G.PHD8V]N9B`]
M($9I;&5?0U-6.CID:7-C;W9E<D9O<FUA="@D9FEL92D["@IP<FEN="`B1F]R
M;6%T.EQN(CL*<')I;G1?<B@D8V]N9BD["G!R:6YT(")<;B(["C\^"BTM15A0
M14-4+2T*1F]R;6%T.@I!<G)A>0HH"B`@("!;9FEE;&1S72`]/B`Q"B`@("!;
M<V5P72`]/B`L"B`@("!;<75O=&5=(#T^("(**0H`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T9I;&4O=&5S=',O
M0U-6+S`P-BYC<W8`````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`Q-3`@
M,3`U,34T,S0Q,S4@,#(S,S$W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````")386UP;&4@1&%T82!,:6YE(#$B"B)386UP;&4@
M1&%T82!,:6YE(#(B"B)386UP;&4@1&%T82!,:6YE(#,B"B)386UP;&4@1&%T
M82!,:6YE(#0B"B)386UP;&4@1&%T82!,:6YE(#4B````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B]T97-T<RYT
M>'0``````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,3`V(#$P-3$U-#,T,3,U
M(#`R-#(P,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!&:6QE7T-35B!497-T($-A<V4*/3T]/3T]/3T]/3T]/3T]/3T]"@H@
M("`@($-A<V4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($-O
M=F5R960@($YO=&5S"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"C`P,2`@1FEE;&1S(&-O=6YT(&QE<W,@=&AA;B!E>'!E8W1E9"`@("`@
M("`@6WA="C`P,B`@1FEE;&1S(&-O=6YT(&UO<F4@=&AA;B!E>'!E8W1E9"`@
M("`@("`@6WA=("`@("`@2&EG:"!R:7-K('!O<W-I8FEL:71Y"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9&ES8V]V97)E9"!F:65L9',@8V]U;G0*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!W<F]N9PHP,#,@(%=I
M;F1O=W,@14],("`@("`@("`@("`@("`@("`@("`@("`@("`@(%MX70HP,#0@
M(%5N:7@@14],("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%MX70HP
M,#4@($UA8R!%3TP@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%MX
M70H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]&:6QE+W1E<W1S+T-35B\P
M,#$N8W-V````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,3<V(#$P-3$U
M-#,T,3,U(#`R,S,R,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````B1FEE;&0@,2TQ(BP@(D9I96QD(#$M,B(L(")&:65L9"`Q
M+3,B+"`B1FEE;&0@,2TT(@HB1FEE;&0@,BTQ(BP@(D9I96QD(#(M,B(L(")&
M:65L9"`R+3,B"B)&:65L9"`S+3$B+"`B1FEE;&0@,RTR(@HB1FEE;&0@-"TQ
M(@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<P``````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-2`P,C$U
M-C4`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S
M+V-A;&,N<&AP+F]R:6<`````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0T-#<P
M(#$P-3$U-#,T,3,U(#`R-#(R-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PHO+PHO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P-2!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN
M970^("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W
M($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA
M8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+RHJ
M"B`J(%1E<W1S(&9O<B!T:&4@1&%T95]#86QC(&-L87-S"B`J"B`J($%N>2!I
M;F1I=FED=6%L('1E<W1S('1H870@9F%I;"!W:6QL(&AA=F4@=&AE:7(@;F%M
M92P@97AP96-T960@<F5S=6QT"B`J(&%N9"!A8W1U86P@<F5S=6QT('!R:6YT
M960@;W5T+B`@4V\@<V5E:6YG(&YO(&]U='!U="!W:&5N(&5X96-U=&EN9PH@
M*B!T:&ES(&9I;&4@:7,@82!G;V]D('1H:6YG+@H@*@H@*B!#86X@8F4@<G5N
M('9I82!#3$D@;W(@82!W96(@<V5R=F5R+@H@*@H@*B!4:&ES('1E<W0@<V5N
M<V5S('=H971H97(@:70@:7,@9G)O;2!A;B!I;G-T86QL871I;VX@;V8@4$5!
M4CHZ1&%T92!O<B!I9@H@*B!I="=S(&9R;VT@0U93(&]R(&$@+G1A<B!F:6QE
M+B`@268@:70G<R!A;B!I;G-T86QL960@=F5R<VEO;BP@=7-E('1H90H@*B!I
M;G-T86QL960@=F5R<VEO;B!O9B!$871E7T-A;&,N("!/=&AE<G=I<V4L('5S
M92!T:&4@;&]C86P@9&5V96QO<&UE;G0*("H@8V]P>2!O9B!$871E7T-A;&,N
M"B`J"B`J($!C871E9V]R>2`@($1A=&4@86YD(%1I;64*("H@0'!A8VMA9V4@
M("`@1&%T90H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI
M96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M8V%L8RYP:'`L=B`Q+C@@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP
M("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1A=&4*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C4*("HO"@II9B`H)R]H;VUE+VQU8V5R+W=O<FLO<&5A<B]S:&%R
M92]P:'`G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L*("`@(&EN:5]S
M970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@
M("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<*("`@("D["GT@96QS
M92!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T:"AD:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXO)RD*("`@("`@("`@("`@+B!0051(7U-%
M4$%2051/4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@
M:6YI7V=E="@G:6YC;'5D95]P871H)RD*("`@("D["GT*"B\J*@H@*B!'970@
M=&AE(&YE961E9"!C;&%S<PH@*B\*<F5Q=6ER95]O;F-E("=$871E+T-A;&,N
M<&AP)SL*"B\J*@H@*B!#;VUP87)E('1H92!T97-T(')E<W5L="!T;R!T:&4@
M97AP96-T960@<F5S=6QT"B`J"B`J($EF('1H92!T97-T(&9A:6QS+"!E8VAO
M(&]U="!T:&4@<F5S=6QT<RX*("H*("H@0'!A<F%M(&UI>&5D("`D97AP96-T
M("`@("!T:&4@<V-A;&%R(&]R(&%R<F%Y('EO=2!E>'!E8W0@9G)O;2!T:&4@
M=&5S=`H@*B!`<&%R86T@;6EX960@("1A8W1U86P@("`@('1H92!S8V%L87(@
M;W(@87)R87D@<F5S=6QT<R!F<F]M('1H92!T97-T"B`J($!P87)A;2!S=')I
M;F<@)'1E<W1?;F%M92`@=&AE(&YA;64@;V8@=&AE('1E<W0*("H*("H@0')E
M='5R;B!V;VED"B`J+PIF=6YC=&EO;B!C;VUP87)E*"1E>'!E8W0L("1A8W1U
M86PL("1T97-T7VYA;64I('L*("`@(&EF("AI<U]A<G)A>2@D97AP96-T*2D@
M>PH@("`@("`@(&EF("AC;W5N="AA<G)A>5]D:69F*"1A8W1U86PL("1E>'!E
M8W0I*2D@>PH@("`@("`@("`@("!E8VAO("(D=&5S=%]N86UE(&9A:6QE9"X@
M($5X<&5C=#I<;B(["B`@("`@("`@("`@('!R:6YT7W(H)&5X<&5C="D["B`@
M("`@("`@("`@(&5C:&\@(D%C='5A;#I<;B(["B`@("`@("`@("`@('!R:6YT
M7W(H)&%C='5A;"D["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I
M9B`H)&5X<&5C="`A/2`D86-T=6%L*2!["B`@("`@("`@("`@(&5C:&\@(B1T
M97-T7VYA;64@9F%I;&5D+B`@17AP96-T.B`D97AP96-T+B`@06-T=6%L.B`D
M86-T=6%L7&XB.PH@("`@("`@('T*("`@('T*?0H*:68@*'!H<%]S87!I7VYA
M;64H*2`A/2`G8VQI)RD@>PH@("`@96-H;R`B/'!R93Y<;B(["GT*"@IC;VUP
M87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ9&%T949O<FUA="@R,BP@,3$L
M(#(P,#`L("<E625M)60G*2P@)V1A=&5&;W)M870G*3L*8V]M<&%R92@G,C`P
M,#$Q,C(G+"!$871E7T-A;&,Z.F1A=&5&;W)M870H)S(R)RP@)S$Q)RP@)S(P
M,#`G+"`G)5DE;25D)RDL("=D871E1F]R;6%T('-T<B<I.PH*8V]M<&%R92@G
M,C`P,2<L($1A=&5?0V%L8SHZ9&5F875L=$-E;G1U<GDH)S$G*2P@)V1E9F%U
M;'1#96YT=7)Y(#$@<W1R)RD["F-O;7!A<F4H)S(P,#$G+"!$871E7T-A;&,Z
M.F1E9F%U;'1#96YT=7)Y*#$I+"`G9&5F875L=$-E;G1U<GD@,2<I.PIC;VUP
M87)E*"<Q.38P)RP@1&%T95]#86QC.CID969A=6QT0V5N='5R>2@V,"DL("=D
M969A=6QT0V5N='5R>2`R)RD["F-O;7!A<F4H)S(P,3`G+"!$871E7T-A;&,Z
M.F1E9F%U;'1#96YT=7)Y*#$P*2P@)V1E9F%U;'1#96YT=7)Y(#,G*3L*"F-O
M;7!A<F4H,C0U,3@W,2P@1&%T95]#86QC.CID871E5&]$87ES*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=D871E5&]$87ES('-T<B<I.PIC;VUP87)E*#(T-3$X
M-S$L($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@R,BP@,3$L(#(P,#`I+"`G9&%T
M951O1&%Y<R<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ9&%Y
M<U1O1&%T92@R-#4Q.#<Q*2P@)V1A>7-4;T1A=&4G*3L*"F-O;7!A<F4H)S(P
M,#`M-#<M,R<L($1A=&5?0V%L8SHZ9W)E9V]R:6%N5&])4T\H)S(R)RP@)S$Q
M)RP@)S(P,#`G*2P@)V=R96=O<FEA;E1O25-/('-T<B<I.PIC;VUP87)E*"<R
M,#`P+30W+3,G+"!$871E7T-A;&,Z.F=R96=O<FEA;E1O25-/*#(R+"`Q,2P@
M,C`P,"DL("=G<F5G;W)I86Y4;TE33R<I.PIC;VUP87)E*#(T-3$W,38N-38W
M-C<L($1A=&5?0V%L8SHZ9&%T95-E87-O;B@G4U5-34524T],4U1)0T4G+"`R
M,#`P*2P@)V1A=&5396%S;VXG*3L*"F-O;7!A<F4H9&%T92@G66UD)RDL($1A
M=&5?0V%L8SHZ9&%T94YO=R@I+"`G9&%T94YO=R<I.PIC;VUP87)E*&1A=&4H
M)UDG*2P@1&%T95]#86QC.CIG971996%R*"DL("=G971996%R)RD["F-O;7!A
M<F4H9&%T92@G;2<I+"!$871E7T-A;&,Z.F=E=$UO;G1H*"DL("=G971-;VYT
M:"<I.PIC;VUP87)E*&1A=&4H)V0G*2P@1&%T95]#86QC.CIG971$87DH*2P@
M)V=E=$1A>2<I.PH*8V]M<&%R92@S,C<L($1A=&5?0V%L8SHZ:G5L:6%N1&%T
M92@R,BP@,3$L(#(P,#`I+"`G:G5L:6%N1&%T92<I.PIC;VUP87)E*"=.;W9E
M;6)E<B<L($1A=&5?0V%L8SHZ9V5T36]N=&A&=6QL;F%M92@Q,2DL("=G971-
M;VYT:$9U;&QN86UE)RD["F-O;7!A<F4H)TYO=B<L($1A=&5?0V%L8SHZ9V5T
M36]N=&A!8F)R;F%M92@Q,2DL("=G971-;VYT:$%B8G)N86UE)RD["F-O;7!A
M<F4H)U-A='5R9&%Y)RP@1&%T95]#86QC.CIG9717965K9&%Y1G5L;&YA;64H
M,2P@,2P@,C`P-2DL("=G9717965K9&%Y1G5L;&YA;64G*3L*8V]M<&%R92@G
M4V%T)RP@1&%T95]#86QC.CIG9717965K9&%Y06)B<FYA;64H,2P@,2P@,C`P
M-2DL("=G9717965K9&%Y06)B<FYA;64G*3L*8V]M<&%R92@Q,2P@1&%T95]#
M86QC.CIG971-;VYT:$9R;VU&=6QL3F%M92@G3F]V96UB97(G*2P@)V=E=$UO
M;G1H1G)O;49U;&Q.86UE)RD["@IC;VUP87)E*#,R-RP@1&%T95]#86QC.CIJ
M=6QI86Y$871E*"<R,B<L("<Q,2<L("<R,#`P)RDL("=J=6QI86Y$871E('-T
M<B<I.PIC;VUP87)E*"=.;W9E;6)E<B<L($1A=&5?0V%L8SHZ9V5T36]N=&A&
M=6QL;F%M92@G,3$G*2P@)V=E=$UO;G1H1G5L;&YA;64@<W1R)RD["F-O;7!A
M<F4H)TYO=B<L($1A=&5?0V%L8SHZ9V5T36]N=&A!8F)R;F%M92@G,3$G*2P@
M)V=E=$UO;G1H06)B<FYA;64@<W1R)RD["F-O;7!A<F4H)U-A='5R9&%Y)RP@
M1&%T95]#86QC.CIG9717965K9&%Y1G5L;&YA;64H)S`Q)RP@)S`Q)RP@)S(P
M,#4G*2P@)V=E=%=E96MD87E&=6QL;F%M92!S='(G*3L*8V]M<&%R92@G4V%T
M)RP@1&%T95]#86QC.CIG9717965K9&%Y06)B<FYA;64H)S`Q)RP@)S`Q)RP@
M)S(P,#4G*2P@)V=E=%=E96MD87E!8F)R;F%M92!S='(G*3L*"B1E>'`@/2!A
M<G)A>2@*("`@("=*86YU87)Y)RP*("`@("=&96)R=6%R>2<L"B`@("`G36%R
M8V@G+`H@("`@)T%P<FEL)RP*("`@("=-87DG+`H@("`@)TIU;F4G+`H@("`@
M)TIU;'DG+`H@("`@)T%U9W5S="<L"B`@("`G4V5P=&5M8F5R)RP*("`@("=/
M8W1O8F5R)RP*("`@("=.;W9E;6)E<B<L"B`@("`G1&5C96UB97(G"BD["F-O
M;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG971-;VYT:$YA;65S*"DL("=G971-
M;VYT:$YA;65S)RD["@HD97AP(#T@87)R87DH"B`@("`G36]N9&%Y)RP*("`@
M("=4=65S9&%Y)RP*("`@("=7961N97-D87DG+`H@("`@)U1H=7)S9&%Y)RP*
M("`@("=&<FED87DG+`H@("`@)U-A='5R9&%Y)RP*("`@("=3=6YD87DG"BD[
M"F-O;7!A<F4H)&5X<"P@1&%T95]#86QC.CIG9717965K1&%Y<R@I+"`G9V5T
M5V5E:T1A>7,G*3L*"F-O;7!A<F4H,RP@1&%T95]#86QC.CID87E/9E=E96LH
M,C(L(#$Q+"`R,#`P*2P@)V1A>4]F5V5E:R<I.PIC;VUP87)E*#0W+"!$871E
M7T-A;&,Z.G=E96M/9EEE87(H,C(L(#$Q+"`R,#`P*2P@)W=E96M/9EEE87(G
M*3L*8V]M<&%R92@T+"!$871E7T-A;&,Z.G%U87)T97)/9EEE87(H,C(L(#$Q
M+"`R,#`P*2P@)W%U87)T97)/9EEE87(G*3L*"F-O;7!A<F4H,RP@1&%T95]#
M86QC.CID87E/9E=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V1A>4]F5V5E
M:R!S='(G*3L*8V]M<&%R92@T-RP@1&%T95]#86QC.CIW965K3V9996%R*"<R
M,B<L("<Q,2<L("<R,#`P)RDL("=W965K3V9996%R('-T<B<I.PIC;VUP87)E
M*#0L($1A=&5?0V%L8SHZ<75A<G1E<D]F665A<B@G,C(G+"`G,3$G+"`G,C`P
M,"<I+"`G<75A<G1E<D]F665A<B!S='(G*3L*"F-O;7!A<F4H,C@L($1A=&5?
M0V%L8SHZ9&%Y<TEN36]N=&@H,BP@,3DP,"DL("=D87ES26Y-;VYT:"`Q)RD[
M"F-O;7!A<F4H,CDL($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H,BP@,3DY-BDL
M("=D87ES26Y-;VYT:"`R)RD["F-O;7!A<F4H,CDL($1A=&5?0V%L8SHZ9&%Y
M<TEN36]N=&@H,BP@,C`P,"DL("=D87ES26Y-;VYT:"`S)RD["F-O;7!A<F4H
M,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H,BP@,C`P,2DL("=D87ES26Y-
M;VYT:"`T)RD["F-O;7!A<F4H,S`L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H
M,3$L(#(P,#`I+"`G9&%Y<TEN36]N=&@@-2<I.PH*8V]M<&%R92@R."P@1&%T
M95]#86QC.CID87ES26Y-;VYT:"@G,#(G+"`Q.3`P*2P@)V1A>7-);DUO;G1H
M(#$@<W1R)RD["F-O;7!A<F4H,CDL($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H
M)S`R)RP@,3DY-BDL("=D87ES26Y-;VYT:"`R('-T<B<I.PIC;VUP87)E*#(Y
M+"!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"<P,B<L(#(P,#`I+"`G9&%Y<TEN
M36]N=&@@,R!S='(G*3L*8V]M<&%R92@R."P@1&%T95]#86QC.CID87ES26Y-
M;VYT:"@G,#(G+"`R,#`Q*2P@)V1A>7-);DUO;G1H(#0@<W1R)RD["F-O;7!A
M<F4H,S`L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)S$Q)RP@)S(P,#`G*2P@
M)V1A>7-);DUO;G1H(#4@<W1R)RD["@IC;VUP87)E*#4L($1A=&5?0V%L8SHZ
M=V5E:W-);DUO;G1H*#$Q+"`R,#`P*2P@)W=E96MS26Y-;VYT:"<I.PIC;VUP
M87)E*#4L($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H*"<Q,2<L("<R,#`P)RDL
M("=W965K<TEN36]N=&@@<W1R)RD["@H*)&5X<"`](&%R<F%Y*`H@("`@)S$Y
M,#`P,C(V)RP*("`@("<Q.3`P,#(R-R<L"B`@("`G,3DP,#`R,C@G+`H@("`@
M)S$Y,#`P,S`Q)RP*("`@("<Q.3`P,#,P,B<L"B`@("`G,3DP,#`S,#,G+`H@
M("`@)S$Y,#`P,S`T)RP**3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E
M=$-A;&5N9&%R5V5E:R@R-RP@,BP@,3DP,"DL("=G971#86QE;F1A<E=E96L@
M,2<I.PH*)&5X<"`](&%R<F%Y*`H@("`@)S(P,#`P,C(X)RP*("`@("<R,#`P
M,#(R.2<L"B`@("`G,C`P,#`S,#$G+`H@("`@)S(P,#`P,S`R)RP*("`@("<R
M,#`P,#,P,R<L"B`@("`G,C`P,#`S,#0G+`H@("`@)S(P,#`P,S`U)RP**3L*
M8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E:R@R."P@
M,BP@,C`P,"DL("=G971#86QE;F1A<E=E96L@,B<I.PH*)&5X<"`](&%R<F%Y
M*`H@("`@)S(P,#`Q,3(W)RP*("`@("<R,#`P,3$R."<L"B`@("`G,C`P,#$Q
M,CDG+`H@("`@)S(P,#`Q,3,P)RP*("`@("<R,#`P,3(P,2<L"B`@("`G,C`P
M,#$R,#(G+`H@("`@)S(P,#`Q,C`S)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?
M0V%L8SHZ9V5T0V%L96YD87)7965K*#(W+"`Q,2P@,C`P,"DL("=G971#86QE
M;F1A<E=E96L@,R<I.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L
M96YD87)7965K*"<R-R<L("<Q,2<L("<R,#`P)RDL("=G971#86QE;F1A<E=E
M96L@,R!S='(G*3L*"B1E>'`@/2!A<G)A>2@*("`@(&%R<F%Y*`H@("`@("`@
M("<R,#`P,3`S,"<L"B`@("`@("`@)S(P,#`Q,#,Q)RP*("`@("`@("`G,C`P
M,#$Q,#$G+`H@("`@("`@("<R,#`P,3$P,B<L"B`@("`@("`@)S(P,#`Q,3`S
M)RP*("`@("`@("`G,C`P,#$Q,#0G+`H@("`@*2P*("`@(&%R<F%Y*`H@("`@
M("`@("<R,#`P,3$P-2<L"B`@("`@("`@)S(P,#`Q,3`V)RP*("`@("`@("`G
M,C`P,#$Q,#<G+`H@("`@("`@("<R,#`P,3$P."<L"B`@("`@("`@)S(P,#`Q
M,3`Y)RP*("`@("`@("`G,C`P,#$Q,3`G+`H@("`@("`@("<R,#`P,3$Q,2<L
M"B`@("`I+`H@("`@87)R87DH"B`@("`@("`@)S(P,#`Q,3$R)RP*("`@("`@
M("`G,C`P,#$Q,3,G+`H@("`@("`@("<R,#`P,3$Q-"<L"B`@("`@("`@)S(P
M,#`Q,3$U)RP*("`@("`@("`G,C`P,#$Q,38G+`H@("`@("`@("<R,#`P,3$Q
M-R<L"B`@("`@("`@)S(P,#`Q,3$X)RP*("`@("DL"B`@("!A<G)A>2@*("`@
M("`@("`G,C`P,#$Q,3DG+`H@("`@("`@("<R,#`P,3$R,2<L"B`@("`@("`@
M)S(P,#`Q,3(R)RP*("`@("`@("`G,C`P,#$Q,C,G+`H@("`@("`@("<R,#`P
M,3$R-"<L"B`@("`@("`@)S(P,#`Q,3(U)RP*("`@("`@("`G,C`P,#$Q,C8G
M+`H@("`@*2P*("`@(&%R<F%Y*`H@("`@("`@("<R,#`P,3$R-R<L"B`@("`@
M("`@)S(P,#`Q,3(X)RP*("`@("`@("`G,C`P,#$Q,CDG+`H@("`@("`@("<R
M,#`P,3$S,"<L"B`@("`@("`@)S(P,#`Q,C`Q)RP*("`@("`@("`G,C`P,#$R
M,#(G+`H@("`@("`@("<R,#`P,3(P,R<*("`@("D**3L*8V]M<&%R92@D97AP
M+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R36]N=&@H,3$L(#(P,#`I+"`G9V5T
M0V%L96YD87)-;VYT:"<I.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T
M0V%L96YD87)-;VYT:"@G,3$G+"`G,C`P,"<I+"`G9V5T0V%L96YD87)-;VYT
M:"!S='(G*3L*"B\O($D@9&]N)W0@9F5E;"!L:6ME(&1E86QI;F<@=VET:"!T
M:&ES(')I9VAT(&YO=RXN+@HO+V-O;7!A<F4H)R<L($1A=&5?0V%L8SHZ9V5T
M0V%L96YD87)996%R*#(P,#`I+"`G9V5T0V%L96YD87)996%R)RD["@IC;VUP
M87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>2@R,BP@,3$L(#(P
M,#`I+"`G<')E=D1A>2<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L
M8SHZ;F5X=$1A>2@R,BP@,3$L(#(P,#`I+"`G;F5X=$1A>2<I.PIC;VUP87)E
M*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>2@R,BP@,3$L(#(P,#`I
M+"`G<')E=D1A>2!S='(G*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A
M;&,Z.FYE>'1$87DH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VYE>'1$87D@<W1R
M)RD["@IC;VUP87)E*"<R,#`P,3$Q-R<L($1A=&5?0V%L8SHZ<')E=E=E96MD
M87DH)S$Y)RP@)S$Q)RP@)S(P,#`G*2P@)W!R9797965K9&%Y(#$@<W1R)RD[
M"F-O;7!A<F4H)S(P,#`Q,3$W)RP@1&%T95]#86QC.CIP<F5V5V5E:V1A>2@Q
M.2P@,3$L(#(P,#`I+"`G<')E=E=E96MD87D@,2<I.PIC;VUP87)E*"<R,#`P
M,3$R,2<L($1A=&5?0V%L8SHZ<')E=E=E96MD87DH,C(L(#$Q+"`R,#`P*2P@
M)W!R9797965K9&%Y(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A
M;&,Z.FYE>'17965K9&%Y*#(R+"`Q,2P@,C`P,"DL("=N97AT5V5E:V1A>2`Q
M)RD["F-O;7!A<F4H)S(P,#`Q,3(W)RP@1&%T95]#86QC.CIN97AT5V5E:V1A
M>2@R-"P@,3$L(#(P,#`I+"`G;F5X=%=E96MD87D@,B<I.PIC;VUP87)E*"<R
M,#`P,3$R-R<L($1A=&5?0V%L8SHZ;F5X=%=E96MD87DH)S(T)RP@)S$Q)RP@
M)S(P,#`G*2P@)VYE>'17965K9&%Y(#(@<W1R)RD["@IC;VUP87)E*"<R,#`P
M,3$R,2<L($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:R@G,B<L("<R,B<L("<Q
M,2<L("<R,#`P)RDL("=P<F5V1&%Y3V97965K(#$@<W1R)RD["F-O;7!A<F4H
M)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K*#(L(#(R+"`Q
M,2P@,C`P,"DL("=P<F5V1&%Y3V97965K(#$G*3L*8V]M<&%R92@G,C`P,#$Q
M,34G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P
M*2P@)W!R979$87E/9E=E96L@,B<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A
M=&5?0V%L8SHZ<')E=D1A>4]F5V5E:R@S+"`R,BP@,3$L(#(P,#`L("<E625M
M)60G+"!T<G5E*2P@)W!R979$87E/9E=E96L@,R<I.PIC;VUP87)E*"<R,#`P
M,3$R,B<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:R@S+"`R,BP@,3$L(#(P
M,#`L("<E625M)60G+"!T<G5E*2P@)VYE>'1$87E/9E=E96L@,2<I.PIC;VUP
M87)E*"<R,#`P,3$R.2<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:R@S+"`R
M,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E:R`R)RD["F-O;7!A<F4H)S(P
M,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K*#0L(#(R+"`Q,2P@
M,C`P,"DL("=N97AT1&%Y3V97965K(#,G*3L*8V]M<&%R92@G,C`P,#$Q,C,G
M+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96LH)S0G+"`G,C(G+"`G,3$G+"`G
M,C`P,"<I+"`G;F5X=$1A>4]F5V5E:R`S('-T<B<I.PH*8V]M<&%R92@G,C`P
M,#$Q,C$G+"!$871E7T-A;&,Z.G!R979$87E/9E=E96M/;D]R0F5F;W)E*"<R
M)RP@)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)W!R979$87E/9E=E96M/;D]R0F5F
M;W)E(#$@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP
M<F5V1&%Y3V97965K3VY/<D)E9F]R92@R+"`R,BP@,3$L(#(P,#`I+"`G<')E
M=D1A>4]F5V5E:T]N3W)"969O<F4@,2<I.PIC;VUP87)E*"<R,#`P,3$R,B<L
M($1A=&5?0V%L8SHZ<')E=D1A>4]F5V5E:T]N3W)"969O<F4H,RP@,C(L(#$Q
M+"`R,#`P*2P@)W!R979$87E/9E=E96M/;D]R0F5F;W)E(#(G*3L*8V]M<&%R
M92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z.FYE>'1$87E/9E=E96M/;D]R069T
M97(H,RP@,C(L(#$Q+"`R,#`P*2P@)VYE>'1$87E/9E=E96M/;D]R069T97(@
M,2<I.PIC;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F
M5V5E:T]N3W)!9G1E<B@T+"`R,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E
M:T]N3W)!9G1E<B`R)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC
M.CIN97AT1&%Y3V97965K3VY/<D%F=&5R*"<T)RP@)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)VYE>'1$87E/9E=E96M/;D]R069T97(@,B!S='(G*3L*"F-O;7!A
M<F4H)S(P,#`Q,3(P)RP@1&%T95]#86QC.CIB96=I;D]F5V5E:R@G,C(G+"`G
M,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9E=E96L@<W1R)RD["F-O;7!A<F4H)S(P
M,#`Q,3(P)RP@1&%T95]#86QC.CIB96=I;D]F5V5E:R@R,BP@,3$L(#(P,#`I
M+"`G8F5G:6Y/9E=E96LG*3L*8V]M<&%R92@G,C`P,#$Q,C8G+"!$871E7T-A
M;&,Z.F5N9$]F5V5E:R@R,BP@,3$L(#(P,#`I+"`G96YD3V97965K)RD["F-O
M;7!A<F4H)S(P,#`Q,3(V)RP@1&%T95]#86QC.CIE;F1/9E=E96LH)S(R)RP@
M)S$Q)RP@)S(P,#`G*2P@)V5N9$]F5V5E:R!S='(G*3L*"F-O;7!A<F4H)S(P
M,#`Q,3$S)RP@1&%T95]#86QC.CIB96=I;D]F4')E=E=E96LH,C(L(#$Q+"`R
M,#`P*2P@)V)E9VEN3V90<F5V5V5E:R<I.PIC;VUP87)E*"<R,#`P,3$R-R<L
M($1A=&5?0V%L8SHZ8F5G:6Y/9DYE>'17965K*#(R+"`Q,2P@,C`P,"DL("=B
M96=I;D]F3F5X=%=E96LG*3L*8V]M<&%R92@G,C`P,#$Q,3,G+"!$871E7T-A
M;&,Z.F)E9VEN3V90<F5V5V5E:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G
M:6Y/9E!R9797965K('-T<B<I.PIC;VUP87)E*"<R,#`P,3$R-R<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9DYE>'17965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=B
M96=I;D]F3F5X=%=E96L@<W1R)RD["@IC;VUP87)E*"<R,#`P,3$P,2<L($1A
M=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H*#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT
M:"<I.PIC;VUP87)E*"<R,#`P,3$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H*"<Q,2<L("<R,#`P)RDL("=B96=I;D]F36]N=&@@<W1R)RD["@IC;VUP
M87)E*"<R,#`P,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9E!R979-;VYT:"@R
M,BP@,3$L(#(P,#`I+"`G8F5G:6Y/9E!R979-;VYT:"<I.PIC;VUP87)E*"<R
M,#`P,3`S,2<L($1A=&5?0V%L8SHZ96YD3V90<F5V36]N=&@H,C(L(#$Q+"`R
M,#`P*2P@)V5N9$]F4')E=DUO;G1H)RD["F-O;7!A<F4H)S(P,#`Q,#`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F4')E=DUO;G1H*"<R,B<L("<Q,2<L("<R,#`P
M)RDL("=B96=I;D]F4')E=DUO;G1H('-T<B<I.PIC;VUP87)E*"<R,#`P,3`S
M,2<L($1A=&5?0V%L8SHZ96YD3V90<F5V36]N=&@H)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)V5N9$]F4')E=DUO;G1H('-T<B<I.PH*8V]M<&%R92@G,C`P,#$R
M,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9.97AT36]N=&@H,C(L(#$Q+"`R,#`P
M*2P@)V)E9VEN3V9.97AT36]N=&@G*3L*8V]M<&%R92@G,C`P,#$R,S$G+"!$
M871E7T-A;&,Z.F5N9$]F3F5X=$UO;G1H*#(R+"`Q,2P@,C`P,"DL("=E;F1/
M9DYE>'1-;VYT:"<I.PIC;VUP87)E*"<R,#`P,3(P,2<L($1A=&5?0V%L8SHZ
M8F5G:6Y/9DYE>'1-;VYT:"@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/
M9DYE>'1-;VYT:"!S='(G*3L*8V]M<&%R92@G,C`P,#$R,S$G+"!$871E7T-A
M;&,Z.F5N9$]F3F5X=$UO;G1H*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/
M9DYE>'1-;VYT:"!S='(G*3L*"F-O;7!A<F4H)S$Y.3DQ,#`Q)RP@1&%T95]#
M86QC.CIB96=I;D]F36]N=&A">5-P86XH+3$S+"`Q,2P@,C`P,"DL("=B96=I
M;D]F36]N=&A">5-P86X@,2<I.PIC;VUP87)E*"<R,#`P,3`P,2<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"TQ+"`Q,2P@,C`P,"DL("=B96=I
M;D]F36]N=&A">5-P86X@,B<I.PIC;VUP87)E*"<R,#`P,3$P,2<L($1A=&5?
M0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#`L(#$Q+"`R,#`P*2P@)V)E9VEN
M3V9-;VYT:$)Y4W!A;B`S)RD["F-O;7!A<F4H)S(P,#`Q,C`Q)RP@1&%T95]#
M86QC.CIB96=I;D]F36]N=&A">5-P86XH,2P@,3$L(#(P,#`I+"`G8F5G:6Y/
M9DUO;G1H0GE3<&%N(#0G*3L*8V]M<&%R92@G,C`P,3$R,#$G+"!$871E7T-A
M;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@Q,RP@,3$L(#(P,#`I+"`G8F5G:6Y/
M9DUO;G1H0GE3<&%N(#4G*3L*"F-O;7!A<F4H)S$Y.3DP,3`Q)RP@1&%T95]#
M86QC.CIB96=I;D]F36]N=&A">5-P86XH)RTQ,R<L("<P,B<L("<R,#`P)RDL
M("=B96=I;D]F36]N=&A">5-P86X@-B!S='(G*3L*8V]M<&%R92@G,3DY.3`Q
M,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@M,3,L(#(L(#(P
M,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#8G*3L*8V]M<&%R92@G,C`P,#`Q
M,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@M,2P@,BP@,C`P
M,"DL("=B96=I;D]F36]N=&A">5-P86X@-R<I.PIC;VUP87)E*"<R,#`P,#(P
M,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*#`L(#(L(#(P,#`I
M+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#@G*3L*8V]M<&%R92@G,C`P,#`S,#$G
M+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y4W!A;B@Q+"`R+"`R,#`P*2P@
M)V)E9VEN3V9-;VYT:$)Y4W!A;B`Y)RD["F-O;7!A<F4H)S(P,#$P,S`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH,3,L(#(L(#(P,#`I+"`G
M8F5G:6Y/9DUO;G1H0GE3<&%N(#$P)RD["F-O;7!A<F4H)S(P,#$P,S`Q)RP@
M1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH)S$S)RP@)S`R)RP@)S(P
M,#`G*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`Q,"!S='(G*3L*"F-O;7!A<F4H
M)S$Y.3DQ,#,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ,RP@
M,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`Q)RD["F-O;7!A<F4H)S(P
M,#`Q,#,Q)RP@1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ+"`Q,2P@
M,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#(G*3L*8V]M<&%R92@G,C`P,#$Q
M,S`G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH,"P@,3$L(#(P,#`I
M+"`G96YD3V9-;VYT:$)Y4W!A;B`S)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@
M1&%T95]#86QC.CIE;F1/9DUO;G1H0GE3<&%N*#$L(#$Q+"`R,#`P*2P@)V5N
M9$]F36]N=&A">5-P86X@-"<I.PIC;VUP87)E*"<R,#`Q,3(S,2<L($1A=&5?
M0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@Q,RP@,3$L(#(P,#`I+"`G96YD3V9-
M;VYT:$)Y4W!A;B`U)RD["@IC;VUP87)E*"<Q.3DY,#$S,2<L($1A=&5?0V%L
M8SHZ96YD3V9-;VYT:$)Y4W!A;B@G+3$S)RP@)S`R)RP@)S(P,#`G*2P@)V5N
M9$]F36]N=&A">5-P86X@-B!S='(G*3L*8V]M<&%R92@G,3DY.3`Q,S$G+"!$
M871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH+3$S+"`R+"`R,#`P*2P@)V5N
M9$]F36]N=&A">5-P86X@-B<I.PIC;VUP87)E*"<R,#`P,#$S,2<L($1A=&5?
M0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@M,2P@,BP@,C`P,"DL("=E;F1/9DUO
M;G1H0GE3<&%N(#<G*3L*8V]M<&%R92@G,C`P,#`R,CDG+"!$871E7T-A;&,Z
M.F5N9$]F36]N=&A">5-P86XH,"P@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3
M<&%N(#@G*3L*8V]M<&%R92@G,C`P,#`S,S$G+"!$871E7T-A;&,Z.F5N9$]F
M36]N=&A">5-P86XH,2P@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#DG
M*3L*8V]M<&%R92@G,C`P,3`S,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A"
M>5-P86XH,3,L(#(L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`Q,"<I.PIC
M;VUP87)E*"<R,#`Q,#,S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A
M;B@G,3,G+"`G,#(G+"`G,C`P,"<I+"`G96YD3V9-;VYT:$)Y4W!A;B`Q,"!S
M='(G*3L*"F-O;7!A<F4H,RP@1&%T95]#86QC.CIF:7)S=$]F36]N=&A7965K
M9&%Y*#$Q+"`R,#`P*2P@)V9I<G-T3V9-;VYT:%=E96MD87DG*3L*8V]M<&%R
M92@S+"!$871E7T-A;&,Z.F9I<G-T3V9-;VYT:%=E96MD87DH)S$Q)RP@)S(P
M,#`G*2P@)V9I<G-T3V9-;VYT:%=E96MD87D@<W1R)RD["@IC;VUP87)E*"<R
M,#`U,#$P,2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*#$L(#8L(#$L
M(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(#$V,2<I.PIC;VUP87)E*"<R,#`U
M,#$P,B<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*#$L(#`L(#$L(#(P
M,#4I+"`G3E=E96MD87E/9DUO;G1H(#$P,2<I.PIC;VUP87)E*"<R,#`U,#$P
M,R<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*#$L(#$L(#$L(#(P,#4I
M+"`G3E=E96MD87E/9DUO;G1H(#$Q,2<I.PIC;VUP87)E*"<R,#`U,#$P-"<L
M($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*#$L(#(L(#$L(#(P,#4I+"`G
M3E=E96MD87E/9DUO;G1H(#$R,2<I.PIC;VUP87)E*"<R,#`U,#$P-2<L($1A
M=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*#$L(#,L(#$L(#(P,#4I+"`G3E=E
M96MD87E/9DUO;G1H(#$S,2<I.PIC;VUP87)E*"<R,#`U,#$P-B<L($1A=&5?
M0V%L8SHZ3E=E96MD87E/9DUO;G1H*#$L(#0L(#$L(#(P,#4I+"`G3E=E96MD
M87E/9DUO;G1H(#$T,2<I.PIC;VUP87)E*"<R,#`U,#$P-R<L($1A=&5?0V%L
M8SHZ3E=E96MD87E/9DUO;G1H*#$L(#4L(#$L(#(P,#4I+"`G3E=E96MD87E/
M9DUO;G1H(#$U,2<I.PH*8V]M<&%R92@G,C`P-3`Q,#@G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@G,B<L("<V)RP@)S`Q)RP@)S(P,#4G*2P@)TY7
M965K9&%Y3V9-;VYT:"`R-C$G*3L*8V]M<&%R92@G,C`P-3`Q,#DG+"!$871E
M7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L("<P)RP@)S`Q)RP@)S(P,#4G
M*2P@)TY7965K9&%Y3V9-;VYT:"`R,#$G*3L*8V]M<&%R92@G,C`P-3`Q,3`G
M+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L("<Q)RP@)S`Q)RP@
M)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R,3$G*3L*8V]M<&%R92@G,C`P
M-3`Q,3$G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L("<R)RP@
M)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R,C$G*3L*8V]M<&%R
M92@G,C`P-3`Q,3(G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L
M("<S)RP@)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R,S$G*3L*
M8V]M<&%R92@G,C`P-3`Q,3,G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT
M:"@G,B<L("<T)RP@)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R
M-#$G*3L*8V]M<&%R92@G,C`P-3`Q,30G+"!$871E7T-A;&,Z.DY7965K9&%Y
M3V9-;VYT:"@G,B<L("<U)RP@)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-
M;VYT:"`R-3$G*3L*"F-O;7!A<F4H)S(P,#4P,3,Q)RP@1&%T95]#86QC.CI.
M5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`Q+"`Q+"`R,#`U*2P@)TY7965K9&%Y
M3V9-;VYT:"!L,3$G*3L*8V]M<&%R92@G,C`P-3`Q,S`G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#`L(#$L(#(P,#4I+"`G3E=E96MD
M87E/9DUO;G1H(&PP,2<I.PIC;VUP87)E*"<R,#`U,#$R.2<L($1A=&5?0V%L
M8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-BP@,2P@,C`P-2DL("=.5V5E
M:V1A>4]F36]N=&@@;#8Q)RD["F-O;7!A<F4H)S(P,#4P,3(X)RP@1&%T95]#
M86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`U+"`Q+"`R,#`U*2P@)TY7
M965K9&%Y3V9-;VYT:"!L-3$G*3L*8V]M<&%R92@G,C`P-3`Q,C<G+"!$871E
M7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#0L(#$L(#(P,#4I+"`G
M3E=E96MD87E/9DUO;G1H(&PT,2<I.PIC;VUP87)E*"<R,#`U,#$R-B<L($1A
M=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,RP@,2P@,C`P-2DL
M("=.5V5E:V1A>4]F36]N=&@@;#,Q)RD["F-O;7!A<F4H)S(P,#4P,3(U)RP@
M1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`R+"`Q+"`R,#`U
M*2P@)TY7965K9&%Y3V9-;VYT:"!L,C$G*3L*"F-O;7!A<F4H)S(P,#4P,S,Q
M)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`T+"`S+"`R
M,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-#,G*3L*8V]M<&%R92@G,C`P-3`S
M,S`G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#,L(#,L
M(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PS,R<I.PIC;VUP87)E*"<R,#`U
M,#,R.2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,BP@
M,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#(S)RD["F-O;7!A<F4H)S(P
M,#4P,S(X)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`Q
M+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,3,G*3L*8V]M<&%R92@G
M,C`P-3`S,C<G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L
M(#`L(#,L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PP,R<I.PIC;VUP87)E
M*"<R,#`U,#,R-B<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T
M)RP@-BP@,RP@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#8S)RD["F-O;7!A
M<F4H)S(P,#4P,S(U)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA
M<W0G+"`U+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-3,G*3L*"@IC
M;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES5F%L:61$871E*#(Y+"`R+"`Q
M.3`P*2P@)VES5F%L:61$871E(#$G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A
M;&,Z.FES5F%L:61$871E*#(Y+"`R+"`R,#`P*2P@)VES5F%L:61$871E(#(G
M*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES5F%L:61$871E*"<R.2<L
M("<P,B<L("<R,#`P)RDL("=I<U9A;&ED1&%T92`R('-T<B<I.PH*8V]M<&%R
M92AF86QS92P@1&%T95]#86QC.CII<TQE87!996%R*#$Y,#`I+"`G:7-,96%P
M665A<B`Q)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<TQE87!996%R
M*#$Y.38I+"`G:7-,96%P665A<B`R)RD["F-O;7!A<F4H=')U92P@1&%T95]#
M86QC.CII<TQE87!996%R*#(P,#`I+"`G:7-,96%P665A<B`S)RD["F-O;7!A
M<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-,96%P665A<B@R,#`Q*2P@)VES3&5A
M<%EE87(@-"<I.PIC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES3&5A<%EE
M87(H)S(P,#$G*2P@)VES3&5A<%EE87(@-"!S='(G*3L*"F-O;7!A<F4H9F%L
M<V4L($1A=&5?0V%L8SHZ:7-&=71U<F5$871E*"<R,B<L("<Q,2<L("<R,#`P
M)RDL("=I<T9U='5R941A=&4@,2!S='(G*3L*8V]M<&%R92AF86QS92P@1&%T
M95]#86QC.CII<T9U='5R941A=&4H,C(L(#$Q+"`R,#`P*2P@)VES1G5T=7)E
M1&%T92`Q)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<T9U='5R941A
M=&4H,C(L(#$Q+"!D871E*"=9)RD@*R`Q*2P@)VES1G5T=7)E1&%T92`R)RD[
M"@IC;VUP87)E*&9A;'-E+"!$871E7T-A;&,Z.FES4&%S=$1A=&4H,C(L(#$Q
M+"!D871E*"=9)RD@*R`Q*2P@)VES4&%S=$1A=&4@,2<I.PIC;VUP87)E*'1R
M=64L($1A=&5?0V%L8SHZ:7-087-T1&%T92@R,BP@,3$L(#(P,#`I+"`G:7-0
M87-T1&%T92`R)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<U!A<W1$
M871E*"<R,B<L("<Q,2<L("<R,#`P)RDL("=I<U!A<W1$871E(#(@<W1R)RD[
M"@IC;VUP87)E*#$P+"!$871E7T-A;&,Z.F1A=&5$:69F*#(R+"`Q,2P@,C`P
M,"P@,3(L(#$Q+"`R,#`P*2P@)V1A=&5$:69F(#$G*3L*8V]M<&%R92@Q,"P@
M1&%T95]#86QC.CID871E1&EF9B@Q,BP@,3$L(#(P,#`L(#(R+"`Q,2P@,C`P
M,"DL("=D871E1&EF9B`R)RD["F-O;7!A<F4H-C$L($1A=&5?0V%L8SHZ9&%T
M941I9F8H,C(L(#$Q+"`R,#`P+"`R,BP@,2P@,C`P,2DL("=D871E1&EF9B`S
M)RD["F-O;7!A<F4H-C$L($1A=&5?0V%L8SHZ9&%T941I9F8H)S(R)RP@)S$Q
M)RP@)S(P,#`G+"`G,C(G+"`G,#$G+"`G,C`P,2<I+"`G9&%T941I9F8@,R!S
M='(G*3L*"F-O;7!A<F4H+3$L($1A=&5?0V%L8SHZ8V]M<&%R941A=&5S*#$R
M+"`Q,2P@,C`P,"P@,C(L(#$Q+"`R,#`P*2P@)V-O;7!A<F5$871E<R`Q)RD[
M"F-O;7!A<F4H,"P@1&%T95]#86QC.CIC;VUP87)E1&%T97,H,C(L(#$Q+"`R
M,#`P+"`R,BP@,3$L(#(P,#`I+"`G8V]M<&%R941A=&5S(#(G*3L*8V]M<&%R
M92@Q+"!$871E7T-A;&,Z.F-O;7!A<F5$871E<R@R,BP@,3$L(#(P,#`L(#$R
M+"`Q,2P@,C`P,"DL("=C;VUP87)E1&%T97,@,R<I.PIC;VUP87)E*#$L($1A
M=&5?0V%L8SHZ8V]M<&%R941A=&5S*"<R,B<L("<Q,2<L("<R,#`P)RP@)S$R
M)RP@)S$Q)RP@)S(P,#`G*2P@)V-O;7!A<F5$871E<R`S('-T<B<I.PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]B=6<W,C=?,BYP:'``````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C`V,"`Q,#4Q-30S-#$S-2`P,C,V,3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH*("H@
M5&5S=',@9F]R('=E96MS26Y-;VYT:"P@9F5B<G5A<GD@=VET:"`T('=E96MS
M"B`J(%-U;F1A>2!A<R`Q<W0@9&%Y(&]F('=E96L*("HO"F1E9FEN92@G1$%4
M15]#04Q#7T)%1TE.7U=%14M$05DG+"`P*3L*<F5Q=6ER95]O;F-E(")$871E
M+T-A;&,N<&AP(CL*"B\J*@H@*B!497-T(&1A=&5S(&9R;VT@,3DW,"!T;R`R
M,#(Y"B`J($1A=&$@9G)O;3H@:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N
M=6LO=VMN;W1E<W0N='AT"B`J($]T:&5R<R!U<V5F=6QL(&1A=&%S(&%V86EL
M86)L92!F<F]M.@H@*B!H='1P.B\O=W=W+FUE<FQY;BYD96UO;BYC;RYU:R\C
M9&%T"B`J+PHD9&%T87!A=&@@/2!D:7)N86UE*"!?7T9)3$5?7RD["@HD9F%I
M;&5D7W1E<W1?9&%T82`@(#T@9F%L<V4["B1D871E<R`@(#T@9FEL92@D9&%T
M87!A=&@@+B`G+W=E96MS:6YM;VYT:%\T7W-U;F1A>2YT>'0G*3L*)&-N="`@
M("`@/2!S:7IE;V8H)&1A=&5S*3L*)'9A;&ED<R`](&%R<F%Y*"D["F9O<B@@
M)&D],#LD:3PD8VYT.R1I*RL@*7L*("`@("1P87)T<R`@("`@(#T@97AP;&]D
M92@G+R<L)&1A=&5S6R1I72D["B`@("`D=F%L:61S6R1P87)T<ULP75T@/2!A
M<G)A>2@D<&%R='-;,5T]/BAI;G0I<W1R7W)E<&QA8V4H(EQN(BPG)RPD<&%R
M='-;,ETI*3L*?0IU;G-E="@D9&%T97,I.PIF;W)E86-H*"1V86QI9',@87,@
M)'EE87(@/3X@)&UO;G1H<RE["B`@("!F;W)E86-H("@D;6]N=&AS(&%S("1M
M;VYT:#T^)'9A;&ED7W=E96MS*2!["B`@("`@("`@)&-A;&-?=V5E:W,@/2!$
M871E7T-A;&,Z.G=E96MS26Y-;VYT:"@D;6]N=&@L)'EE87(I.PH@("`@("`@
M(&EF*"1C86QC7W=E96MS(3TD=F%L:61?=V5E:W,I>PH@("`@("`@("`@("`D
M9F%I;&5D7W1E<W1?9&%T82`@(#T@=')U93L*("`@("`@("`@("`@96-H;R`B
M0G5G(",W,C<L('!A<W,@,SH@)'EE87(O)&UO;G1H(&9A:6QE9"X@17AP96-T
M.B1V86QI9%]W965K<R!';W0Z)&-A;&-?=V5E:W-<;B(["B`@("`@("`@?0H@
M("`@?0I]"FEF("@A)&9A:6QE9%]T97-T7V1A=&$I('L*"65C:&\@(D)U9R`C
M-S(W+"!P87-S(#(Z($]+7&XB.PI]"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S+V)U9S<R
M-U\S+G!H<```````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R,#4P(#$P-3$U
M-#,T,3,U(#`R,S8Q,0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*@H@*B!497-T<R!F;W(@=V5E:W-);DUO;G1H
M+"`B<F%N9&]M(@H@*B!3=6YD87D@87,@,7-T(&1A>2!O9B!W965K"B`J+PID
M969I;F4H)T1!5$5?0T%,0U]"14=)3E]7145+1$%9)RP@,"D["G)E<75I<F5?
M;VYC92`B1&%T92]#86QC+G!H<"(["@HO*BH*("H@5&5S="!D871E<R!F<F]M
M(#$Y-S`@=&\@,C`R.0H@*B!$871A(&9R;VTZ(&AT='`Z+R]W=W<N;65R;'EN
M+F1E;6]N+F-O+G5K+W=K;F]T97-T+G1X=`H@*B!/=&AE<G,@=7-E9G5L;"!D
M871A<R!A=F%I;&%B;&4@9G)O;3H*("H@:'1T<#HO+W=W=RYM97)L>6XN9&5M
M;VXN8V\N=6LO(V1A=`H@*B\*)&1A=&%P871H(#T@9&ER;F%M92@@7U]&24Q%
M7U\I.PH*)&9A:6QE9%]T97-T7V1A=&$@("`](&9A;'-E.PHD9&%T97,@("`]
M(&9I;&4H)&1A=&%P871H("X@)R]W965K<VEN;6]N=&A?<F1M7W-U;F1A>2YT
M>'0G*3L*)&-N="`@("`@/2!S:7IE;V8H)&1A=&5S*3L*)'9A;&ED<R`](&%R
M<F%Y*"D["F9O<B@@)&D],#LD:3PD8VYT.R1I*RL@*7L*("`@("1P87)T<R`@
M("`@(#T@97AP;&]D92@G+R<L)&1A=&5S6R1I72D["B`@("`D=F%L:61S6R1P
M87)T<ULP75T@/2!A<G)A>2@D<&%R='-;,5T]/BAI;G0I<W1R7W)E<&QA8V4H
M(EQN(BPG)RPD<&%R='-;,ETI*3L*?0IU;G-E="@D9&%T97,I.PIF;W)E86-H
M*"1V86QI9',@87,@)'EE87(@/3X@)&UO;G1H<RE["B`@("!F;W)E86-H("@D
M;6]N=&AS(&%S("1M;VYT:#T^)'9A;&ED7W=E96MS*2!["B`@("`@("`@)&-A
M;&-?=V5E:W,@/2!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@D;6]N=&@L)'EE
M87(I.PH@("`@("`@(&EF*"1C86QC7W=E96MS(3TD=F%L:61?=V5E:W,I>PH@
M("`@("`@("`@("`D9F%I;&5D7W1E<W1?9&%T82`@(#T@=')U93L*("`@("`@
M("`@("`@96-H;R`B0G5G(",W,C<L('!A<W,@,SH@)'EE87(O)&UO;G1H(&9A
M:6QE9"X@17AP96-T.B1V86QI9%]W965K<R!';W0Z)&-A;&-?=V5E:W-<;B([
M"B`@("`@("`@?0H@("`@?0I]"FEF("@A)&9A:6QE9%]T97-T7V1A=&$I('L*
M("`@(&5C:&\@(D)U9R`C-S(W+"!P87-S(#,Z($]+7&XB.PI]"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1A=&4O=&5S=',O8G5G-S(W7S0N<&AP````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#(P-#<@,3`U,34T,S0Q,S4@,#(S-C(P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J"B`J
M(%1E<W1S(&9O<B!W965K<TEN36]N=&@L(")R86YD;VTB"B`J($UO;F1A>2!A
M<R`Q<W0@9&%Y(&]F('=E96L*("HO"F1E9FEN92@G1$%415]#04Q#7T)%1TE.
M7U=%14M$05DG+"`Q*3L*<F5Q=6ER95]O;F-E(")$871E+T-A;&,N<&AP(CL*
M"B\J*@H@*B!497-T(&1A=&5S(&9R;VT@,3DW,"!T;R`R,#(Y"B`J($1A=&$@
M9G)O;3H@:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO=VMN;W1E<W0N
M='AT"B`J($]T:&5R<R!U<V5F=6QL(&1A=&%S(&%V86EL86)L92!F<F]M.@H@
M*B!H='1P.B\O=W=W+FUE<FQY;BYD96UO;BYC;RYU:R\C9&%T"B`J+PHD9&%T
M87!A=&@@/2!D:7)N86UE*"!?7T9)3$5?7RD["@HD9F%I;&5D7W1E<W1?9&%T
M82`@(#T@9F%L<V4["B1D871E<R`@(#T@9FEL92@D9&%T87!A=&@@+B`G+W=E
M96MS:6YM;VYT:%]R9&U?;6]N9&%Y+G1X="<I.PHD8VYT("`@("`]('-I>F5O
M9B@D9&%T97,I.PHD=F%L:61S(#T@87)R87DH*3L*9F]R*"`D:3TP.R1I/"1C
M;G0[)&DK*R`I>PH@("`@)'!A<G1S("`@("`@/2!E>'!L;V1E*"<O)RPD9&%T
M97-;)&E=*3L*("`@("1V86QI9'-;)'!A<G1S6S!=72`](&%R<F%Y*"1P87)T
M<ULQ73T^*&EN="ES=')?<F5P;&%C92@B7&XB+"<G+"1P87)T<ULR72DI.PI]
M"G5N<V5T*"1D871E<RD["F9O<F5A8V@H)'9A;&ED<R!A<R`D>65A<B`]/B`D
M;6]N=&AS*7L*("`@(&9O<F5A8V@@*"1M;VYT:',@87,@)&UO;G1H/3XD=F%L
M:61?=V5E:W,I('L*("`@("`@("`D8V%L8U]W965K<R`]($1A=&5?0V%L8SHZ
M=V5E:W-);DUO;G1H*"1M;VYT:"PD>65A<BD["B`@("`@("`@:68H)&-A;&-?
M=V5E:W,A/21V86QI9%]W965K<RE["B`@("`@("`@("`@("1F86EL961?=&5S
M=%]D871A("`@/2!T<G5E.PH@("`@("`@("`@("!E8VAO(")"=6<@-S(W+"!P
M87-S(#0Z("1Y96%R+R1M;VYT:"!F86EL960N($5X<&5C=#HD=F%L:61?=V5E
M:W,@1V]T.B1C86QC7W=E96MS7&XB.PH@("`@("`@('T*("`@('T*?0II9B`H
M(21F86EL961?=&5S=%]D871A*2!["B`@("!E8VAO(")"=6<@(S<R-RP@<&%S
M<R`T.B!/2UQN(CL*?0H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<Y
M-C<N<&AP````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#8Q-2`Q,#4Q
M-30S-#$S-2`P,C,T,#(`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*<F5Q=6ER95]O;F-E("=$871E+G!H<"<["B1?
M1$%415]424U%6D].15]$149!54Q4(#T@)U!A8VEF:6,O0VAA=&AA;2<["B1T
M>B`]($1A=&5?5&EM95IO;F4Z.F=E=$1E9F%U;'0H*3L*:68@*"1T>BT^:60A
M/21?1$%415]424U%6D].15]$149!54Q4("8F("1T>BT^:60A/2=086-I9FEC
M+T-H871H86TG*2!["B`@("!E8VAO(")S971$969A=6QT($9A:6QE9%QN(CL*
M?0I$871E7U1I;65:;VYE.CIS971$969A=6QT*"=#4U0G*3L*)&1E9F%U;'0@
M/2`G15-4)SL*)'1Z(#T@1&%T95]4:6UE6F]N93HZ9V5T1&5F875L="@I.PII
M9B`H)'1Z+3YI9"$])%]$051%7U1)345:3TY%7T1%1D%53%0@)B8@)'1Z+3YI
M9"$])T535"<I('L*("`@(&5C:&\@(G-E=$1E9F%U;'0@1F%I;&5D7&XB.PI]
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O8V%L8RYP:'``````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#0T-C8@,3`U,34T,S0Q,S4@,#(S
M,C<U`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W
M:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H
M870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H
M92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@
M('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L
M92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A
M<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W(Z($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO*BH*("H@5&5S=',@9F]R('1H
M92!$871E7T-A;&,@8VQA<W,*("H*("H@06YY(&EN9&EV:61U86P@=&5S=',@
M=&AA="!F86EL('=I;&P@:&%V92!T:&5I<B!N86UE+"!E>'!E8W1E9"!R97-U
M;'0*("H@86YD(&%C='5A;"!R97-U;'0@<')I;G1E9"!O=70N("!3;R!S965I
M;F<@;F\@;W5T<'5T('=H96X@97AE8W5T:6YG"B`J('1H:7,@9FEL92!I<R!A
M(&=O;V0@=&AI;F<N"B`J"B`J($-A;B!B92!R=6X@=FEA($-,22!O<B!A('=E
M8B!S97)V97(N"B`J"B`J(%1H:7,@=&5S="!S96YS97,@=VAE=&AE<B!I="!I
M<R!F<F]M(&%N(&EN<W1A;&QA=&EO;B!O9B!014%2.CI$871E(&]R(&EF"B`J
M(&ET)W,@9G)O;2!#5E,@;W(@82`N=&%R(&9I;&4N("!)9B!I="=S(&%N(&EN
M<W1A;&QE9"!V97)S:6]N+"!U<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N
M(&]F($1A=&5?0V%L8RX@($]T:&5R=VES92P@=7-E('1H92!L;V-A;"!D979E
M;&]P;65N=`H@*B!C;W!Y(&]F($1A=&5?0V%L8RX*("H*("H@0&-A=&5G;W)Y
M("`@1&%T92!A;F0@5&EM90H@*B!`<&%C:V%G92`@("!$871E"B`J($!A=71H
M;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@
M0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!C86QC+G!H<"QV(#$N."`R
M,#`U+S$Q+S$U(#`P.C$V.C0P('!A:F]Y92!%>'`@)`H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-0H@*B\*"FEF
M("@G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(G("$]("=`)RXG:6YC
M;'5D95]P871H)RXG0"<I('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L
M(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`@("`@("`@("X@4$%42%]3
M15!!4D%43U(@+B`G+B<*("`@("D["GT@96QS92!["B`@("!I;FE?<V5T*"=I
M;F-L=61E7W!A=&@G+"!R96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2`N("<O
M+BXO)RD*("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)R`N(%!!
M5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI7V=E="@G:6YC;'5D95]P
M871H)RD*("`@("D["GT*"B\J*@H@*B!'970@=&AE(&YE961E9"!C;&%S<PH@
M*B\*<F5Q=6ER95]O;F-E("=$871E+T-A;&,N<&AP)SL*"B\J*@H@*B!#;VUP
M87)E('1H92!T97-T(')E<W5L="!T;R!T:&4@97AP96-T960@<F5S=6QT"B`J
M"B`J($EF('1H92!T97-T(&9A:6QS+"!E8VAO(&]U="!T:&4@<F5S=6QT<RX*
M("H*("H@0'!A<F%M(&UI>&5D("`D97AP96-T("`@("!T:&4@<V-A;&%R(&]R
M(&%R<F%Y('EO=2!E>'!E8W0@9G)O;2!T:&4@=&5S=`H@*B!`<&%R86T@;6EX
M960@("1A8W1U86P@("`@('1H92!S8V%L87(@;W(@87)R87D@<F5S=6QT<R!F
M<F]M('1H92!T97-T"B`J($!P87)A;2!S=')I;F<@)'1E<W1?;F%M92`@=&AE
M(&YA;64@;V8@=&AE('1E<W0*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC
M=&EO;B!C;VUP87)E*"1E>'!E8W0L("1A8W1U86PL("1T97-T7VYA;64I('L*
M("`@(&EF("AI<U]A<G)A>2@D97AP96-T*2D@>PH@("`@("`@(&EF("AC;W5N
M="AA<G)A>5]D:69F*"1A8W1U86PL("1E>'!E8W0I*2D@>PH@("`@("`@("`@
M("!E8VAO("(D=&5S=%]N86UE(&9A:6QE9"X@($5X<&5C=#I<;B(["B`@("`@
M("`@("`@('!R:6YT7W(H)&5X<&5C="D["B`@("`@("`@("`@(&5C:&\@(D%C
M='5A;#I<;B(["B`@("`@("`@("`@('!R:6YT7W(H)&%C='5A;"D["B`@("`@
M("`@?0H@("`@?2!E;'-E('L*("`@("`@("!I9B`H)&5X<&5C="`A/2`D86-T
M=6%L*2!["B`@("`@("`@("`@(&5C:&\@(B1T97-T7VYA;64@9F%I;&5D+B`@
M17AP96-T.B`D97AP96-T+B`@06-T=6%L.B`D86-T=6%L7&XB.PH@("`@("`@
M('T*("`@('T*?0H*:68@*'!H<%]S87!I7VYA;64H*2`A/2`G8VQI)RD@>PH@
M("`@96-H;R`B/'!R93Y<;B(["GT*"@IC;VUP87)E*"<R,#`P,3$R,B<L($1A
M=&5?0V%L8SHZ9&%T949O<FUA="@R,BP@,3$L(#(P,#`L("<E625M)60G*2P@
M)V1A=&5&;W)M870G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E7T-A;&,Z
M.F1A=&5&;W)M870H)S(R)RP@)S$Q)RP@)S(P,#`G+"`G)5DE;25D)RDL("=D
M871E1F]R;6%T('-T<B<I.PH*8V]M<&%R92@G,C`P,2<L($1A=&5?0V%L8SHZ
M9&5F875L=$-E;G1U<GDH)S$G*2P@)V1E9F%U;'1#96YT=7)Y(#$@<W1R)RD[
M"F-O;7!A<F4H)S(P,#$G+"!$871E7T-A;&,Z.F1E9F%U;'1#96YT=7)Y*#$I
M+"`G9&5F875L=$-E;G1U<GD@,2<I.PIC;VUP87)E*"<Q.38P)RP@1&%T95]#
M86QC.CID969A=6QT0V5N='5R>2@V,"DL("=D969A=6QT0V5N='5R>2`R)RD[
M"F-O;7!A<F4H)S(P,3`G+"!$871E7T-A;&,Z.F1E9F%U;'1#96YT=7)Y*#$P
M*2P@)V1E9F%U;'1#96YT=7)Y(#,G*3L*"F-O;7!A<F4H,C0U,3@W,2P@1&%T
M95]#86QC.CID871E5&]$87ES*"<R,B<L("<Q,2<L("<R,#`P)RDL("=D871E
M5&]$87ES('-T<B<I.PIC;VUP87)E*#(T-3$X-S$L($1A=&5?0V%L8SHZ9&%T
M951O1&%Y<R@R,BP@,3$L(#(P,#`I+"`G9&%T951O1&%Y<R<I.PIC;VUP87)E
M*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@R-#4Q.#<Q*2P@
M)V1A>7-4;T1A=&4G*3L*"F-O;7!A<F4H)S(P,#`M-#<M,R<L($1A=&5?0V%L
M8SHZ9W)E9V]R:6%N5&])4T\H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V=R96=O
M<FEA;E1O25-/('-T<B<I.PIC;VUP87)E*"<R,#`P+30W+3,G+"!$871E7T-A
M;&,Z.F=R96=O<FEA;E1O25-/*#(R+"`Q,2P@,C`P,"DL("=G<F5G;W)I86Y4
M;TE33R<I.PIC;VUP87)E*#(T-3$W,38N-38W-C<L($1A=&5?0V%L8SHZ9&%T
M95-E87-O;B@G4U5-34524T],4U1)0T4G+"`R,#`P*2P@)V1A=&5396%S;VXG
M*3L*"F-O;7!A<F4H9&%T92@G66UD)RDL($1A=&5?0V%L8SHZ9&%T94YO=R@I
M+"`G9&%T94YO=R<I.PIC;VUP87)E*&1A=&4H)UDG*2P@1&%T95]#86QC.CIG
M971996%R*"DL("=G971996%R)RD["F-O;7!A<F4H9&%T92@G;2<I+"!$871E
M7T-A;&,Z.F=E=$UO;G1H*"DL("=G971-;VYT:"<I.PIC;VUP87)E*&1A=&4H
M)V0G*2P@1&%T95]#86QC.CIG971$87DH*2P@)V=E=$1A>2<I.PH*8V]M<&%R
M92@S,C<L($1A=&5?0V%L8SHZ:G5L:6%N1&%T92@R,BP@,3$L(#(P,#`I+"`G
M:G5L:6%N1&%T92<I.PIC;VUP87)E*"=.;W9E;6)E<B<L($1A=&5?0V%L8SHZ
M9V5T36]N=&A&=6QL;F%M92@Q,2DL("=G971-;VYT:$9U;&QN86UE)RD["F-O
M;7!A<F4H)TYO=B<L($1A=&5?0V%L8SHZ9V5T36]N=&A!8F)R;F%M92@Q,2DL
M("=G971-;VYT:$%B8G)N86UE)RD["F-O;7!A<F4H)U-A='5R9&%Y)RP@1&%T
M95]#86QC.CIG9717965K9&%Y1G5L;&YA;64H,2P@,2P@,C`P-2DL("=G9717
M965K9&%Y1G5L;&YA;64G*3L*8V]M<&%R92@G4V%T)RP@1&%T95]#86QC.CIG
M9717965K9&%Y06)B<FYA;64H,2P@,2P@,C`P-2DL("=G9717965K9&%Y06)B
M<FYA;64G*3L*8V]M<&%R92@Q,2P@1&%T95]#86QC.CIG971-;VYT:$9R;VU&
M=6QL3F%M92@G3F]V96UB97(G*2P@)V=E=$UO;G1H1G)O;49U;&Q.86UE)RD[
M"@IC;VUP87)E*#,R-RP@1&%T95]#86QC.CIJ=6QI86Y$871E*"<R,B<L("<Q
M,2<L("<R,#`P)RDL("=J=6QI86Y$871E('-T<B<I.PIC;VUP87)E*"=.;W9E
M;6)E<B<L($1A=&5?0V%L8SHZ9V5T36]N=&A&=6QL;F%M92@G,3$G*2P@)V=E
M=$UO;G1H1G5L;&YA;64@<W1R)RD["F-O;7!A<F4H)TYO=B<L($1A=&5?0V%L
M8SHZ9V5T36]N=&A!8F)R;F%M92@G,3$G*2P@)V=E=$UO;G1H06)B<FYA;64@
M<W1R)RD["F-O;7!A<F4H)U-A='5R9&%Y)RP@1&%T95]#86QC.CIG9717965K
M9&%Y1G5L;&YA;64H)S`Q)RP@)S`Q)RP@)S(P,#4G*2P@)V=E=%=E96MD87E&
M=6QL;F%M92!S='(G*3L*8V]M<&%R92@G4V%T)RP@1&%T95]#86QC.CIG9717
M965K9&%Y06)B<FYA;64H)S`Q)RP@)S`Q)RP@)S(P,#4G*2P@)V=E=%=E96MD
M87E!8F)R;F%M92!S='(G*3L*"B1E>'`@/2!A<G)A>2@*("`@("=*86YU87)Y
M)RP*("`@("=&96)R=6%R>2<L"B`@("`G36%R8V@G+`H@("`@)T%P<FEL)RP*
M("`@("=-87DG+`H@("`@)TIU;F4G+`H@("`@)TIU;'DG+`H@("`@)T%U9W5S
M="<L"B`@("`G4V5P=&5M8F5R)RP*("`@("=/8W1O8F5R)RP*("`@("=.;W9E
M;6)E<B<L"B`@("`G1&5C96UB97(G"BD["F-O;7!A<F4H)&5X<"P@1&%T95]#
M86QC.CIG971-;VYT:$YA;65S*"DL("=G971-;VYT:$YA;65S)RD["@HD97AP
M(#T@87)R87DH"B`@("`G36]N9&%Y)RP*("`@("=4=65S9&%Y)RP*("`@("=7
M961N97-D87DG+`H@("`@)U1H=7)S9&%Y)RP*("`@("=&<FED87DG+`H@("`@
M)U-A='5R9&%Y)RP*("`@("=3=6YD87DG"BD["F-O;7!A<F4H)&5X<"P@1&%T
M95]#86QC.CIG9717965K1&%Y<R@I+"`G9V5T5V5E:T1A>7,G*3L*"F-O;7!A
M<F4H,RP@1&%T95]#86QC.CID87E/9E=E96LH,C(L(#$Q+"`R,#`P*2P@)V1A
M>4]F5V5E:R<I.PIC;VUP87)E*#0W+"!$871E7T-A;&,Z.G=E96M/9EEE87(H
M,C(L(#$Q+"`R,#`P*2P@)W=E96M/9EEE87(G*3L*8V]M<&%R92@T+"!$871E
M7T-A;&,Z.G%U87)T97)/9EEE87(H,C(L(#$Q+"`R,#`P*2P@)W%U87)T97)/
M9EEE87(G*3L*"F-O;7!A<F4H,RP@1&%T95]#86QC.CID87E/9E=E96LH)S(R
M)RP@)S$Q)RP@)S(P,#`G*2P@)V1A>4]F5V5E:R!S='(G*3L*8V]M<&%R92@T
M-RP@1&%T95]#86QC.CIW965K3V9996%R*"<R,B<L("<Q,2<L("<R,#`P)RDL
M("=W965K3V9996%R('-T<B<I.PIC;VUP87)E*#0L($1A=&5?0V%L8SHZ<75A
M<G1E<D]F665A<B@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G<75A<G1E<D]F665A
M<B!S='(G*3L*"F-O;7!A<F4H,C@L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H
M,BP@,3DP,"DL("=D87ES26Y-;VYT:"`Q)RD["F-O;7!A<F4H,CDL($1A=&5?
M0V%L8SHZ9&%Y<TEN36]N=&@H,BP@,3DY-BDL("=D87ES26Y-;VYT:"`R)RD[
M"F-O;7!A<F4H,CDL($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H,BP@,C`P,"DL
M("=D87ES26Y-;VYT:"`S)RD["F-O;7!A<F4H,C@L($1A=&5?0V%L8SHZ9&%Y
M<TEN36]N=&@H,BP@,C`P,2DL("=D87ES26Y-;VYT:"`T)RD["F-O;7!A<F4H
M,S`L($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H,3$L(#(P,#`I+"`G9&%Y<TEN
M36]N=&@@-2<I.PH*8V]M<&%R92@R."P@1&%T95]#86QC.CID87ES26Y-;VYT
M:"@G,#(G+"`Q.3`P*2P@)V1A>7-);DUO;G1H(#$@<W1R)RD["F-O;7!A<F4H
M,CDL($1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)S`R)RP@,3DY-BDL("=D87ES
M26Y-;VYT:"`R('-T<B<I.PIC;VUP87)E*#(Y+"!$871E7T-A;&,Z.F1A>7-)
M;DUO;G1H*"<P,B<L(#(P,#`I+"`G9&%Y<TEN36]N=&@@,R!S='(G*3L*8V]M
M<&%R92@R."P@1&%T95]#86QC.CID87ES26Y-;VYT:"@G,#(G+"`R,#`Q*2P@
M)V1A>7-);DUO;G1H(#0@<W1R)RD["F-O;7!A<F4H,S`L($1A=&5?0V%L8SHZ
M9&%Y<TEN36]N=&@H)S$Q)RP@)S(P,#`G*2P@)V1A>7-);DUO;G1H(#4@<W1R
M)RD["@IC;VUP87)E*#4L($1A=&5?0V%L8SHZ=V5E:W-);DUO;G1H*#$Q+"`R
M,#`P*2P@)W=E96MS26Y-;VYT:"<I.PIC;VUP87)E*#4L($1A=&5?0V%L8SHZ
M=V5E:W-);DUO;G1H*"<Q,2<L("<R,#`P)RDL("=W965K<TEN36]N=&@@<W1R
M)RD["@H*)&5X<"`](&%R<F%Y*`H@("`@)S$Y,#`P,C(V)RP*("`@("<Q.3`P
M,#(R-R<L"B`@("`G,3DP,#`R,C@G+`H@("`@)S$Y,#`P,S`Q)RP*("`@("<Q
M.3`P,#,P,B<L"B`@("`G,3DP,#`S,#,G+`H@("`@)S$Y,#`P,S`T)RP**3L*
M8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A;&5N9&%R5V5E:R@R-RP@
M,BP@,3DP,"DL("=G971#86QE;F1A<E=E96L@,2<I.PH*)&5X<"`](&%R<F%Y
M*`H@("`@)S(P,#`P,C(X)RP*("`@("<R,#`P,#(R.2<L"B`@("`G,C`P,#`S
M,#$G+`H@("`@)S(P,#`P,S`R)RP*("`@("<R,#`P,#,P,R<L"B`@("`G,C`P
M,#`S,#0G+`H@("`@)S(P,#`P,S`U)RP**3L*8V]M<&%R92@D97AP+"!$871E
M7T-A;&,Z.F=E=$-A;&5N9&%R5V5E:R@R."P@,BP@,C`P,"DL("=G971#86QE
M;F1A<E=E96L@,B<I.PH*)&5X<"`](&%R<F%Y*`H@("`@)S(P,#`Q,3(W)RP*
M("`@("<R,#`P,3$R."<L"B`@("`G,C`P,#$Q,CDG+`H@("`@)S(P,#`Q,3,P
M)RP*("`@("<R,#`P,3(P,2<L"B`@("`G,C`P,#$R,#(G+`H@("`@)S(P,#`Q
M,C`S)PHI.PIC;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)7
M965K*#(W+"`Q,2P@,C`P,"DL("=G971#86QE;F1A<E=E96L@,R<I.PIC;VUP
M87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)7965K*"<R-R<L("<Q
M,2<L("<R,#`P)RDL("=G971#86QE;F1A<E=E96L@,R!S='(G*3L*"B1E>'`@
M/2!A<G)A>2@*("`@(&%R<F%Y*`H@("`@("`@("<R,#`P,3`S,"<L"B`@("`@
M("`@)S(P,#`Q,#,Q)RP*("`@("`@("`G,C`P,#$Q,#$G+`H@("`@("`@("<R
M,#`P,3$P,B<L"B`@("`@("`@)S(P,#`Q,3`S)RP*("`@("`@("`G,C`P,#$Q
M,#0G+`H@("`@*2P*("`@(&%R<F%Y*`H@("`@("`@("<R,#`P,3$P-2<L"B`@
M("`@("`@)S(P,#`Q,3`V)RP*("`@("`@("`G,C`P,#$Q,#<G+`H@("`@("`@
M("<R,#`P,3$P."<L"B`@("`@("`@)S(P,#`Q,3`Y)RP*("`@("`@("`G,C`P
M,#$Q,3`G+`H@("`@("`@("<R,#`P,3$Q,2<L"B`@("`I+`H@("`@87)R87DH
M"B`@("`@("`@)S(P,#`Q,3$R)RP*("`@("`@("`G,C`P,#$Q,3,G+`H@("`@
M("`@("<R,#`P,3$Q-"<L"B`@("`@("`@)S(P,#`Q,3$U)RP*("`@("`@("`G
M,C`P,#$Q,38G+`H@("`@("`@("<R,#`P,3$Q-R<L"B`@("`@("`@)S(P,#`Q
M,3$X)RP*("`@("DL"B`@("!A<G)A>2@*("`@("`@("`G,C`P,#$Q,3DG+`H@
M("`@("`@("<R,#`P,3$R,2<L"B`@("`@("`@)S(P,#`Q,3(R)RP*("`@("`@
M("`G,C`P,#$Q,C,G+`H@("`@("`@("<R,#`P,3$R-"<L"B`@("`@("`@)S(P
M,#`Q,3(U)RP*("`@("`@("`G,C`P,#$Q,C8G+`H@("`@*2P*("`@(&%R<F%Y
M*`H@("`@("`@("<R,#`P,3$R-R<L"B`@("`@("`@)S(P,#`Q,3(X)RP*("`@
M("`@("`G,C`P,#$Q,CDG+`H@("`@("`@("<R,#`P,3$S,"<L"B`@("`@("`@
M)S(P,#`Q,C`Q)RP*("`@("`@("`G,C`P,#$R,#(G+`H@("`@("`@("<R,#`P
M,3(P,R<*("`@("D**3L*8V]M<&%R92@D97AP+"!$871E7T-A;&,Z.F=E=$-A
M;&5N9&%R36]N=&@H,3$L(#(P,#`I+"`G9V5T0V%L96YD87)-;VYT:"<I.PIC
M;VUP87)E*"1E>'`L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)-;VYT:"@G,3$G
M+"`G,C`P,"<I+"`G9V5T0V%L96YD87)-;VYT:"!S='(G*3L*"B\O($D@9&]N
M)W0@9F5E;"!L:6ME(&1E86QI;F<@=VET:"!T:&ES(')I9VAT(&YO=RXN+@HO
M+V-O;7!A<F4H)R<L($1A=&5?0V%L8SHZ9V5T0V%L96YD87)996%R*#(P,#`I
M+"`G9V5T0V%L96YD87)996%R)RD["@IC;VUP87)E*"<R,#`P,3$R,2<L($1A
M=&5?0V%L8SHZ<')E=D1A>2@R,BP@,3$L(#(P,#`I+"`G<')E=D1A>2<I.PIC
M;VUP87)E*"<R,#`P,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>2@R,BP@,3$L
M(#(P,#`I+"`G;F5X=$1A>2<I.PIC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?
M0V%L8SHZ<')E=D1A>2@R,BP@,3$L(#(P,#`I+"`G<')E=D1A>2!S='(G*3L*
M8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$87DH)S(R)RP@
M)S$Q)RP@)S(P,#`G*2P@)VYE>'1$87D@<W1R)RD["@IC;VUP87)E*"<R,#`P
M,3$Q-R<L($1A=&5?0V%L8SHZ<')E=E=E96MD87DH)S$Y)RP@)S$Q)RP@)S(P
M,#`G*2P@)W!R9797965K9&%Y(#$@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3$W
M)RP@1&%T95]#86QC.CIP<F5V5V5E:V1A>2@Q.2P@,3$L(#(P,#`I+"`G<')E
M=E=E96MD87D@,2<I.PIC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ
M<')E=E=E96MD87DH,C(L(#$Q+"`R,#`P*2P@)W!R9797965K9&%Y(#(G*3L*
M8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'17965K9&%Y*#(R
M+"`Q,2P@,C`P,"DL("=N97AT5V5E:V1A>2`Q)RD["F-O;7!A<F4H)S(P,#`Q
M,3(W)RP@1&%T95]#86QC.CIN97AT5V5E:V1A>2@R-"P@,3$L(#(P,#`I+"`G
M;F5X=%=E96MD87D@,B<I.PIC;VUP87)E*"<R,#`P,3$R-R<L($1A=&5?0V%L
M8SHZ;F5X=%=E96MD87DH)S(T)RP@)S$Q)RP@)S(P,#`G*2P@)VYE>'17965K
M9&%Y(#(@<W1R)RD["@IC;VUP87)E*"<R,#`P,3$R,2<L($1A=&5?0V%L8SHZ
M<')E=D1A>4]F5V5E:R@G,B<L("<R,B<L("<Q,2<L("<R,#`P)RDL("=P<F5V
M1&%Y3V97965K(#$@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3(Q)RP@1&%T95]#
M86QC.CIP<F5V1&%Y3V97965K*#(L(#(R+"`Q,2P@,C`P,"DL("=P<F5V1&%Y
M3V97965K(#$G*3L*8V]M<&%R92@G,C`P,#$Q,34G+"!$871E7T-A;&,Z.G!R
M979$87E/9E=E96LH,RP@,C(L(#$Q+"`R,#`P*2P@)W!R979$87E/9E=E96L@
M,B<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ<')E=D1A>4]F
M5V5E:R@S+"`R,BP@,3$L(#(P,#`L("<E625M)60G+"!T<G5E*2P@)W!R979$
M87E/9E=E96L@,R<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ
M;F5X=$1A>4]F5V5E:R@S+"`R,BP@,3$L(#(P,#`L("<E625M)60G+"!T<G5E
M*2P@)VYE>'1$87E/9E=E96L@,2<I.PIC;VUP87)E*"<R,#`P,3$R.2<L($1A
M=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:R@S+"`R,BP@,3$L(#(P,#`I+"`G;F5X
M=$1A>4]F5V5E:R`R)RD["F-O;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC
M.CIN97AT1&%Y3V97965K*#0L(#(R+"`Q,2P@,C`P,"DL("=N97AT1&%Y3V97
M965K(#,G*3L*8V]M<&%R92@G,C`P,#$Q,C,G+"!$871E7T-A;&,Z.FYE>'1$
M87E/9E=E96LH)S0G+"`G,C(G+"`G,3$G+"`G,C`P,"<I+"`G;F5X=$1A>4]F
M5V5E:R`S('-T<B<I.PH*8V]M<&%R92@G,C`P,#$Q,C$G+"!$871E7T-A;&,Z
M.G!R979$87E/9E=E96M/;D]R0F5F;W)E*"<R)RP@)S(R)RP@)S$Q)RP@)S(P
M,#`G*2P@)W!R979$87E/9E=E96M/;D]R0F5F;W)E(#$@<W1R)RD["F-O;7!A
M<F4H)S(P,#`Q,3(Q)RP@1&%T95]#86QC.CIP<F5V1&%Y3V97965K3VY/<D)E
M9F]R92@R+"`R,BP@,3$L(#(P,#`I+"`G<')E=D1A>4]F5V5E:T]N3W)"969O
M<F4@,2<I.PIC;VUP87)E*"<R,#`P,3$R,B<L($1A=&5?0V%L8SHZ<')E=D1A
M>4]F5V5E:T]N3W)"969O<F4H,RP@,C(L(#$Q+"`R,#`P*2P@)W!R979$87E/
M9E=E96M/;D]R0F5F;W)E(#(G*3L*8V]M<&%R92@G,C`P,#$Q,C(G+"!$871E
M7T-A;&,Z.FYE>'1$87E/9E=E96M/;D]R069T97(H,RP@,C(L(#$Q+"`R,#`P
M*2P@)VYE>'1$87E/9E=E96M/;D]R069T97(@,2<I.PIC;VUP87)E*"<R,#`P
M,3$R,R<L($1A=&5?0V%L8SHZ;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B@T+"`R
M,BP@,3$L(#(P,#`I+"`G;F5X=$1A>4]F5V5E:T]N3W)!9G1E<B`R)RD["F-O
M;7!A<F4H)S(P,#`Q,3(S)RP@1&%T95]#86QC.CIN97AT1&%Y3V97965K3VY/
M<D%F=&5R*"<T)RP@)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)VYE>'1$87E/9E=E
M96M/;D]R069T97(@,B!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3(P)RP@1&%T
M95]#86QC.CIB96=I;D]F5V5E:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G
M:6Y/9E=E96L@<W1R)RD["F-O;7!A<F4H)S(P,#`Q,3(P)RP@1&%T95]#86QC
M.CIB96=I;D]F5V5E:R@R,BP@,3$L(#(P,#`I+"`G8F5G:6Y/9E=E96LG*3L*
M8V]M<&%R92@G,C`P,#$Q,C8G+"!$871E7T-A;&,Z.F5N9$]F5V5E:R@R,BP@
M,3$L(#(P,#`I+"`G96YD3V97965K)RD["F-O;7!A<F4H)S(P,#`Q,3(V)RP@
M1&%T95]#86QC.CIE;F1/9E=E96LH)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V5N
M9$]F5V5E:R!S='(G*3L*"F-O;7!A<F4H)S(P,#`Q,3$S)RP@1&%T95]#86QC
M.CIB96=I;D]F4')E=E=E96LH,C(L(#$Q+"`R,#`P*2P@)V)E9VEN3V90<F5V
M5V5E:R<I.PIC;VUP87)E*"<R,#`P,3$R-R<L($1A=&5?0V%L8SHZ8F5G:6Y/
M9DYE>'17965K*#(R+"`Q,2P@,C`P,"DL("=B96=I;D]F3F5X=%=E96LG*3L*
M8V]M<&%R92@G,C`P,#$Q,3,G+"!$871E7T-A;&,Z.F)E9VEN3V90<F5V5V5E
M:R@G,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9E!R9797965K('-T<B<I
M.PIC;VUP87)E*"<R,#`P,3$R-R<L($1A=&5?0V%L8SHZ8F5G:6Y/9DYE>'17
M965K*"<R,B<L("<Q,2<L("<R,#`P)RDL("=B96=I;D]F3F5X=%=E96L@<W1R
M)RD["@IC;VUP87)E*"<R,#`P,3$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO
M;G1H*#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:"<I.PIC;VUP87)E*"<R,#`P
M,3$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H*"<Q,2<L("<R,#`P)RDL
M("=B96=I;D]F36]N=&@@<W1R)RD["@IC;VUP87)E*"<R,#`P,3`P,2<L($1A
M=&5?0V%L8SHZ8F5G:6Y/9E!R979-;VYT:"@R,BP@,3$L(#(P,#`I+"`G8F5G
M:6Y/9E!R979-;VYT:"<I.PIC;VUP87)E*"<R,#`P,3`S,2<L($1A=&5?0V%L
M8SHZ96YD3V90<F5V36]N=&@H,C(L(#$Q+"`R,#`P*2P@)V5N9$]F4')E=DUO
M;G1H)RD["F-O;7!A<F4H)S(P,#`Q,#`Q)RP@1&%T95]#86QC.CIB96=I;D]F
M4')E=DUO;G1H*"<R,B<L("<Q,2<L("<R,#`P)RDL("=B96=I;D]F4')E=DUO
M;G1H('-T<B<I.PIC;VUP87)E*"<R,#`P,3`S,2<L($1A=&5?0V%L8SHZ96YD
M3V90<F5V36]N=&@H)S(R)RP@)S$Q)RP@)S(P,#`G*2P@)V5N9$]F4')E=DUO
M;G1H('-T<B<I.PH*8V]M<&%R92@G,C`P,#$R,#$G+"!$871E7T-A;&,Z.F)E
M9VEN3V9.97AT36]N=&@H,C(L(#$Q+"`R,#`P*2P@)V)E9VEN3V9.97AT36]N
M=&@G*3L*8V]M<&%R92@G,C`P,#$R,S$G+"!$871E7T-A;&,Z.F5N9$]F3F5X
M=$UO;G1H*#(R+"`Q,2P@,C`P,"DL("=E;F1/9DYE>'1-;VYT:"<I.PIC;VUP
M87)E*"<R,#`P,3(P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DYE>'1-;VYT:"@G
M,C(G+"`G,3$G+"`G,C`P,"<I+"`G8F5G:6Y/9DYE>'1-;VYT:"!S='(G*3L*
M8V]M<&%R92@G,C`P,#$R,S$G+"!$871E7T-A;&,Z.F5N9$]F3F5X=$UO;G1H
M*"<R,B<L("<Q,2<L("<R,#`P)RDL("=E;F1/9DYE>'1-;VYT:"!S='(G*3L*
M"F-O;7!A<F4H)S$Y.3DQ,#`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A"
M>5-P86XH+3$S+"`Q,2P@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@,2<I
M.PIC;VUP87)E*"<R,#`P,3`P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H
M0GE3<&%N*"TQ+"`Q,2P@,C`P,"DL("=B96=I;D]F36]N=&A">5-P86X@,B<I
M.PIC;VUP87)E*"<R,#`P,3$P,2<L($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H
M0GE3<&%N*#`L(#$Q+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A;B`S)RD[
M"F-O;7!A<F4H)S(P,#`Q,C`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A"
M>5-P86XH,2P@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#0G*3L*
M8V]M<&%R92@G,C`P,3$R,#$G+"!$871E7T-A;&,Z.F)E9VEN3V9-;VYT:$)Y
M4W!A;B@Q,RP@,3$L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N(#4G*3L*
M"F-O;7!A<F4H)S$Y.3DP,3`Q)RP@1&%T95]#86QC.CIB96=I;D]F36]N=&A"
M>5-P86XH)RTQ,R<L("<P,B<L("<R,#`P)RDL("=B96=I;D]F36]N=&A">5-P
M86X@-B!S='(G*3L*8V]M<&%R92@G,3DY.3`Q,#$G+"!$871E7T-A;&,Z.F)E
M9VEN3V9-;VYT:$)Y4W!A;B@M,3,L(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H
M0GE3<&%N(#8G*3L*8V]M<&%R92@G,C`P,#`Q,#$G+"!$871E7T-A;&,Z.F)E
M9VEN3V9-;VYT:$)Y4W!A;B@M,2P@,BP@,C`P,"DL("=B96=I;D]F36]N=&A"
M>5-P86X@-R<I.PIC;VUP87)E*"<R,#`P,#(P,2<L($1A=&5?0V%L8SHZ8F5G
M:6Y/9DUO;G1H0GE3<&%N*#`L(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3
M<&%N(#@G*3L*8V]M<&%R92@G,C`P,#`S,#$G+"!$871E7T-A;&,Z.F)E9VEN
M3V9-;VYT:$)Y4W!A;B@Q+"`R+"`R,#`P*2P@)V)E9VEN3V9-;VYT:$)Y4W!A
M;B`Y)RD["F-O;7!A<F4H)S(P,#$P,S`Q)RP@1&%T95]#86QC.CIB96=I;D]F
M36]N=&A">5-P86XH,3,L(#(L(#(P,#`I+"`G8F5G:6Y/9DUO;G1H0GE3<&%N
M(#$P)RD["F-O;7!A<F4H)S(P,#$P,S`Q)RP@1&%T95]#86QC.CIB96=I;D]F
M36]N=&A">5-P86XH)S$S)RP@)S`R)RP@)S(P,#`G*2P@)V)E9VEN3V9-;VYT
M:$)Y4W!A;B`Q,"!S='(G*3L*"F-O;7!A<F4H)S$Y.3DQ,#,Q)RP@1&%T95]#
M86QC.CIE;F1/9DUO;G1H0GE3<&%N*"TQ,RP@,3$L(#(P,#`I+"`G96YD3V9-
M;VYT:$)Y4W!A;B`Q)RD["F-O;7!A<F4H)S(P,#`Q,#,Q)RP@1&%T95]#86QC
M.CIE;F1/9DUO;G1H0GE3<&%N*"TQ+"`Q,2P@,C`P,"DL("=E;F1/9DUO;G1H
M0GE3<&%N(#(G*3L*8V]M<&%R92@G,C`P,#$Q,S`G+"!$871E7T-A;&,Z.F5N
M9$]F36]N=&A">5-P86XH,"P@,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A
M;B`S)RD["F-O;7!A<F4H)S(P,#`Q,C,Q)RP@1&%T95]#86QC.CIE;F1/9DUO
M;G1H0GE3<&%N*#$L(#$Q+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@-"<I
M.PIC;VUP87)E*"<R,#`Q,3(S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y
M4W!A;B@Q,RP@,3$L(#(P,#`I+"`G96YD3V9-;VYT:$)Y4W!A;B`U)RD["@IC
M;VUP87)E*"<Q.3DY,#$S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A
M;B@G+3$S)RP@)S`R)RP@)S(P,#`G*2P@)V5N9$]F36]N=&A">5-P86X@-B!S
M='(G*3L*8V]M<&%R92@G,3DY.3`Q,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N
M=&A">5-P86XH+3$S+"`R+"`R,#`P*2P@)V5N9$]F36]N=&A">5-P86X@-B<I
M.PIC;VUP87)E*"<R,#`P,#$S,2<L($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y
M4W!A;B@M,2P@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#<G*3L*8V]M
M<&%R92@G,C`P,#`R,CDG+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH
M,"P@,BP@,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#@G*3L*8V]M<&%R92@G
M,C`P,#`S,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH,2P@,BP@
M,C`P,"DL("=E;F1/9DUO;G1H0GE3<&%N(#DG*3L*8V]M<&%R92@G,C`P,3`S
M,S$G+"!$871E7T-A;&,Z.F5N9$]F36]N=&A">5-P86XH,3,L(#(L(#(P,#`I
M+"`G96YD3V9-;VYT:$)Y4W!A;B`Q,"<I.PIC;VUP87)E*"<R,#`Q,#,S,2<L
M($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@G,3,G+"`G,#(G+"`G,C`P
M,"<I+"`G96YD3V9-;VYT:$)Y4W!A;B`Q,"!S='(G*3L*"F-O;7!A<F4H,RP@
M1&%T95]#86QC.CIF:7)S=$]F36]N=&A7965K9&%Y*#$Q+"`R,#`P*2P@)V9I
M<G-T3V9-;VYT:%=E96MD87DG*3L*8V]M<&%R92@S+"!$871E7T-A;&,Z.F9I
M<G-T3V9-;VYT:%=E96MD87DH)S$Q)RP@)S(P,#`G*2P@)V9I<G-T3V9-;VYT
M:%=E96MD87D@<W1R)RD["@IC;VUP87)E*"<R,#`U,#$P,2<L($1A=&5?0V%L
M8SHZ3E=E96MD87E/9DUO;G1H*#$L(#8L(#$L(#(P,#4I+"`G3E=E96MD87E/
M9DUO;G1H(#$V,2<I.PIC;VUP87)E*"<R,#`U,#$P,B<L($1A=&5?0V%L8SHZ
M3E=E96MD87E/9DUO;G1H*#$L(#`L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO
M;G1H(#$P,2<I.PIC;VUP87)E*"<R,#`U,#$P,R<L($1A=&5?0V%L8SHZ3E=E
M96MD87E/9DUO;G1H*#$L(#$L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H
M(#$Q,2<I.PIC;VUP87)E*"<R,#`U,#$P-"<L($1A=&5?0V%L8SHZ3E=E96MD
M87E/9DUO;G1H*#$L(#(L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(#$R
M,2<I.PIC;VUP87)E*"<R,#`U,#$P-2<L($1A=&5?0V%L8SHZ3E=E96MD87E/
M9DUO;G1H*#$L(#,L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(#$S,2<I
M.PIC;VUP87)E*"<R,#`U,#$P-B<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO
M;G1H*#$L(#0L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(#$T,2<I.PIC
M;VUP87)E*"<R,#`U,#$P-R<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H
M*#$L(#4L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(#$U,2<I.PH*8V]M
M<&%R92@G,C`P-3`Q,#@G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G
M,B<L("<V)RP@)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R-C$G
M*3L*8V]M<&%R92@G,C`P-3`Q,#DG+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@G,B<L("<P)RP@)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT
M:"`R,#$G*3L*8V]M<&%R92@G,C`P-3`Q,3`G+"!$871E7T-A;&,Z.DY7965K
M9&%Y3V9-;VYT:"@G,B<L("<Q)RP@)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y
M3V9-;VYT:"`R,3$G*3L*8V]M<&%R92@G,C`P-3`Q,3$G+"!$871E7T-A;&,Z
M.DY7965K9&%Y3V9-;VYT:"@G,B<L("<R)RP@)S`Q)RP@)S(P,#4G*2P@)TY7
M965K9&%Y3V9-;VYT:"`R,C$G*3L*8V]M<&%R92@G,C`P-3`Q,3(G+"!$871E
M7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L("<S)RP@)S`Q)RP@)S(P,#4G
M*2P@)TY7965K9&%Y3V9-;VYT:"`R,S$G*3L*8V]M<&%R92@G,C`P-3`Q,3,G
M+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L("<T)RP@)S`Q)RP@
M)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R-#$G*3L*8V]M<&%R92@G,C`P
M-3`Q,30G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G,B<L("<U)RP@
M)S`Q)RP@)S(P,#4G*2P@)TY7965K9&%Y3V9-;VYT:"`R-3$G*3L*"F-O;7!A
M<F4H)S(P,#4P,3,Q)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA
M<W0G+"`Q+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L,3$G*3L*8V]M
M<&%R92@G,C`P-3`Q,S`G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-;VYT:"@G
M;&%S="<L(#`L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PP,2<I.PIC
M;VUP87)E*"<R,#`U,#$R.2<L($1A=&5?0V%L8SHZ3E=E96MD87E/9DUO;G1H
M*"=L87-T)RP@-BP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@;#8Q)RD[
M"F-O;7!A<F4H)S(P,#4P,3(X)RP@1&%T95]#86QC.CI.5V5E:V1A>4]F36]N
M=&@H)VQA<W0G+"`U+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT:"!L-3$G
M*3L*8V]M<&%R92@G,C`P-3`Q,C<G+"!$871E7T-A;&,Z.DY7965K9&%Y3V9-
M;VYT:"@G;&%S="<L(#0L(#$L(#(P,#4I+"`G3E=E96MD87E/9DUO;G1H(&PT
M,2<I.PIC;VUP87)E*"<R,#`U,#$R-B<L($1A=&5?0V%L8SHZ3E=E96MD87E/
M9DUO;G1H*"=L87-T)RP@,RP@,2P@,C`P-2DL("=.5V5E:V1A>4]F36]N=&@@
M;#,Q)RD["F-O;7!A<F4H)S(P,#4P,3(U)RP@1&%T95]#86QC.CI.5V5E:V1A
M>4]F36]N=&@H)VQA<W0G+"`R+"`Q+"`R,#`U*2P@)TY7965K9&%Y3V9-;VYT
M:"!L,C$G*3L*"F-O;7!A<F4H)S(P,#4P,S,Q)RP@1&%T95]#86QC.CI.5V5E
M:V1A>4]F36]N=&@H)VQA<W0G+"`T+"`S+"`R,#`U*2P@)TY7965K9&%Y3V9-
M;VYT:"!L-#,G*3L*8V]M<&%R92@G,C`P-3`S,S`G+"!$871E7T-A;&,Z.DY7
M965K9&%Y3V9-;VYT:"@G;&%S="<L(#,L(#,L(#(P,#4I+"`G3E=E96MD87E/
M9DUO;G1H(&PS,R<I.PIC;VUP87)E*"<R,#`U,#,R.2<L($1A=&5?0V%L8SHZ
M3E=E96MD87E/9DUO;G1H*"=L87-T)RP@,BP@,RP@,C`P-2DL("=.5V5E:V1A
M>4]F36]N=&@@;#(S)RD["F-O;7!A<F4H)S(P,#4P,S(X)RP@1&%T95]#86QC
M.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`Q+"`S+"`R,#`U*2P@)TY7965K
M9&%Y3V9-;VYT:"!L,3,G*3L*8V]M<&%R92@G,C`P-3`S,C<G+"!$871E7T-A
M;&,Z.DY7965K9&%Y3V9-;VYT:"@G;&%S="<L(#`L(#,L(#(P,#4I+"`G3E=E
M96MD87E/9DUO;G1H(&PP,R<I.PIC;VUP87)E*"<R,#`U,#,R-B<L($1A=&5?
M0V%L8SHZ3E=E96MD87E/9DUO;G1H*"=L87-T)RP@-BP@,RP@,C`P-2DL("=.
M5V5E:V1A>4]F36]N=&@@;#8S)RD["F-O;7!A<F4H)S(P,#4P,S(U)RP@1&%T
M95]#86QC.CI.5V5E:V1A>4]F36]N=&@H)VQA<W0G+"`U+"`S+"`R,#`U*2P@
M)TY7965K9&%Y3V9-;VYT:"!L-3,G*3L*"@IC;VUP87)E*&9A;'-E+"!$871E
M7T-A;&,Z.FES5F%L:61$871E*#(Y+"`R+"`Q.3`P*2P@)VES5F%L:61$871E
M(#$G*3L*8V]M<&%R92AT<G5E+"!$871E7T-A;&,Z.FES5F%L:61$871E*#(Y
M+"`R+"`R,#`P*2P@)VES5F%L:61$871E(#(G*3L*8V]M<&%R92AT<G5E+"!$
M871E7T-A;&,Z.FES5F%L:61$871E*"<R.2<L("<P,B<L("<R,#`P)RDL("=I
M<U9A;&ED1&%T92`R('-T<B<I.PH*8V]M<&%R92AF86QS92P@1&%T95]#86QC
M.CII<TQE87!996%R*#$Y,#`I+"`G:7-,96%P665A<B`Q)RD["F-O;7!A<F4H
M=')U92P@1&%T95]#86QC.CII<TQE87!996%R*#$Y.38I+"`G:7-,96%P665A
M<B`R)RD["F-O;7!A<F4H=')U92P@1&%T95]#86QC.CII<TQE87!996%R*#(P
M,#`I+"`G:7-,96%P665A<B`S)RD["F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L
M8SHZ:7-,96%P665A<B@R,#`Q*2P@)VES3&5A<%EE87(@-"<I.PIC;VUP87)E
M*&9A;'-E+"!$871E7T-A;&,Z.FES3&5A<%EE87(H)S(P,#$G*2P@)VES3&5A
M<%EE87(@-"!S='(G*3L*"F-O;7!A<F4H9F%L<V4L($1A=&5?0V%L8SHZ:7-&
M=71U<F5$871E*"<R,B<L("<Q,2<L("<R,#`P)RDL("=I<T9U='5R941A=&4@
M,2!S='(G*3L*8V]M<&%R92AF86QS92P@1&%T95]#86QC.CII<T9U='5R941A
M=&4H,C(L(#$Q+"`R,#`P*2P@)VES1G5T=7)E1&%T92`Q)RD["F-O;7!A<F4H
M=')U92P@1&%T95]#86QC.CII<T9U='5R941A=&4H,C(L(#$Q+"!D871E*"=9
M)RD@*R`Q*2P@)VES1G5T=7)E1&%T92`R)RD["@IC;VUP87)E*&9A;'-E+"!$
M871E7T-A;&,Z.FES4&%S=$1A=&4H,C(L(#$Q+"!D871E*"=9)RD@*R`Q*2P@
M)VES4&%S=$1A=&4@,2<I.PIC;VUP87)E*'1R=64L($1A=&5?0V%L8SHZ:7-0
M87-T1&%T92@R,BP@,3$L(#(P,#`I+"`G:7-087-T1&%T92`R)RD["F-O;7!A
M<F4H=')U92P@1&%T95]#86QC.CII<U!A<W1$871E*"<R,B<L("<Q,2<L("<R
M,#`P)RDL("=I<U!A<W1$871E(#(@<W1R)RD["@IC;VUP87)E*#$P+"!$871E
M7T-A;&,Z.F1A=&5$:69F*#(R+"`Q,2P@,C`P,"P@,3(L(#$Q+"`R,#`P*2P@
M)V1A=&5$:69F(#$G*3L*8V]M<&%R92@Q,"P@1&%T95]#86QC.CID871E1&EF
M9B@Q,BP@,3$L(#(P,#`L(#(R+"`Q,2P@,C`P,"DL("=D871E1&EF9B`R)RD[
M"F-O;7!A<F4H-C$L($1A=&5?0V%L8SHZ9&%T941I9F8H,C(L(#$Q+"`R,#`P
M+"`R,BP@,2P@,C`P,2DL("=D871E1&EF9B`S)RD["F-O;7!A<F4H-C$L($1A
M=&5?0V%L8SHZ9&%T941I9F8H)S(R)RP@)S$Q)RP@)S(P,#`G+"`G,C(G+"`G
M,#$G+"`G,C`P,2<I+"`G9&%T941I9F8@,R!S='(G*3L*"F-O;7!A<F4H+3$L
M($1A=&5?0V%L8SHZ8V]M<&%R941A=&5S*#$R+"`Q,2P@,C`P,"P@,C(L(#$Q
M+"`R,#`P*2P@)V-O;7!A<F5$871E<R`Q)RD["F-O;7!A<F4H,"P@1&%T95]#
M86QC.CIC;VUP87)E1&%T97,H,C(L(#$Q+"`R,#`P+"`R,BP@,3$L(#(P,#`I
M+"`G8V]M<&%R941A=&5S(#(G*3L*8V]M<&%R92@Q+"!$871E7T-A;&,Z.F-O
M;7!A<F5$871E<R@R,BP@,3$L(#(P,#`L(#$R+"`Q,2P@,C`P,"DL("=C;VUP
M87)E1&%T97,@,R<I.PIC;VUP87)E*#$L($1A=&5?0V%L8SHZ8V]M<&%R941A
M=&5S*"<R,B<L("<Q,2<L("<R,#`P)RP@)S$R)RP@)S$Q)RP@)S(P,#`G*2P@
M)V-O;7!A<F5$871E<R`S('-T<B<I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S
M+W1E<W1U;FET+G!H<```````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-S0S
M(#$P-3$U-#,T,3,U(#`R-#(T,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@
M=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0('9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P-2`@36%R<VAA;&P@4F]C:"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!T:&4@3F5W
M($)31"!L:6-E;G-E+"!4:&%T(&ES(&)U;F1L960@('P*+R\@?"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA
M8FQE('1H<F]U9V@@("`@("!\"B\O('P@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@;F5W($)31&QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@("!\"B\O('P@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@
M("`@("`@?`HO+R!\('!E87(M9&5V0&QI<W1S+G!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@36%R<VAA
M;&P@4F]C:"`\;7)O8VA`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!T97-T=6YI="YP:'`L=B`Q+C(@,C`P-2\Q,2\Q-2`P,#HQ-CHT
M,"!P86IO>64@17AP("0*"B\J*@H@*B!$:7-P;&%Y<R!A;&P@=&5S="!C87-E
M<R!O;B!T:&4@<V%M92!P86=E"B`J"B`J($!P86-K86=E($1A=&4*("H@0&%U
M=&AO<B!-87)S:&%L;"!2;V-H(#QM<F]C:$!P:'`N;F5T/@H@*B\*"@IE8VAO
M("(\<')E/B(["G)E<75I<F5?;VYC92`G4$A056YI="YP:'`G.PIR97%U:7)E
M7V]N8V4@)W1E<W1U;FET7V1A=&4N<&AP)SL*<F5Q=6ER95]O;F-E("=T97-T
M=6YI=%]D871E7W-P86XN<&AP)SL*96-H;R`B/"]P<F4^(CL*/SX*````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S='5N:71?9&%T92YP:'``````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,C`P-30@,3`U,34T,S0Q,S4@,#(U,C,R`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<V]F='1A8G-T;W`]
M-"!S:&EF='=I9'1H/30Z"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@36%R<VAA;&P@4F]C:"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS
M92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!T:')O=6=H
M("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@
M?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@36%R<VAA;&P@4F]C:"`\;7)O
M8VA`<&AP+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=&5S
M='5N:71?9&%T92YP:'`L=B`Q+C,@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO
M>64@17AP("0*+R\*"G)E<75I<F5?;VYC92`G1&%T92YP:'`G.PIR97%U:7)E
M7V]N8V4@)U!(4%5N:70N<&AP)SL*"F-L87-S(&UY1&%T92!E>'1E;F1S($1A
M=&4@>PH@("`@9G5N8W1I;VX@;7E$871E*"1D871E*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y$871E*"1D871E*3L*("`@('T*?0H*+RHJ"B`J(%1E<W0@8V%S
M92!F;W(@1&%T90H@*@H@*B!`<&%C:V%G92!$871E"B`J($!A=71H;W(@36%R
M<VAA;&P@4F]C:"`\;7)O8VA`<&AP+FYE=#X*("HO"F-L87-S($1A=&5?5&5S
M="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@>PH*("`@('9A<B`D=&EM93L*
M"B`@("!F=6YC=&EO;B!$871E7U1E<W0H)&YA;64I"B`@("!["B`@("`@("`@
M)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H)&YA;64I.PH@("`@?0H*("`@(&9U
M;F-T:6]N('-E=%5P*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM92`](&YE
M=R!$871E*"(R,#`S+3$P+3`T(#$T.C`S.C(T(BD["B`@("!]"@H@("`@9G5N
M8W1I;VX@=&5A<D1O=VXH*0H@("`@>PH@("`@("`@('5N<V5T*"1T:&ES+3YT
M:6UE*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T1&%T94YU;&PH*0H@("`@
M>PH@("`@("`@("1T:6UE(#T@;F5W($1A=&4H*3L*("`@("`@("`D=&AI<RT^
M87-S97)T17%U86QS*`H@("`@("`@("`@("!D871E*"=9+6TM9"!(.FDZ<R<I
M+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P
M,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&EM92T^>65A<BP@)'1I;64M
M/FUO;G1H+"`D=&EM92T^9&%Y+`H@("`@("`@("`@("`@("`@)'1I;64M/FAO
M=7(L("1T:6UE+3YM:6YU=&4L("1T:6UE+3YS96-O;F0I"B`@("`@("`@*3L*
M("`@('T*"B`@("!F=6YC=&EO;B!T97-T06)S=')A8W1I;VXH*0H@("`@>PH@
M("`@("`@("1D(#T@;F5W($1A=&4H*3L*("`@("`@("`D;7D@/2!N97<@;7E$
M871E*"1D*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*"1D+3YG971$
M871E*"DL)&UY+3YG971$871E*"DI.PH@("`@?0H*("`@(&9U;F-T:6]N('1E
M<W1$871E0V]P>2@I"B`@("!["B`@("`@("`@)'1E;7`@/2!N97<@1&%T92@D
M=&AI<RT^=&EM92D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D=&5M
M<"P@)'1H:7,M/G1I;64I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1$871E
M25-/*"D*("`@('L*("`@("`@("`D=&5M<"`](&YE=R!$871E*"(R,#`S+3$P
M+3`T(#$T.C`S.C(T(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*
M("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@
M("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@
M("`@("`@("`@("`@("`D=&5M<"T^>65A<BP@)'1E;7`M/FUO;G1H+"`D=&5M
M<"T^9&%Y+`H@("`@("`@("`@("`@("`@)'1E;7`M/FAO=7(L("1T96UP+3YM
M:6YU=&4L("1T96UP+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F
M=6YC=&EO;B!T97-T1&%T94E33T)A<VEC*"D*("`@('L*("`@("`@("`D=&5M
M<"`](&YE=R!$871E*"(R,#`S,3`P-%0Q-#`S,C0B*3L*("`@("`@("`D=&AI
M<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP
M,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P
M,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("1T96UP+3YY96%R+"`D
M=&5M<"T^;6]N=&@L("1T96UP+3YD87DL"B`@("`@("`@("`@("`@("`D=&5M
M<"T^:&]U<BP@)'1E;7`M/FUI;G5T92P@)'1E;7`M/G-E8V]N9"D*("`@("`@
M("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W1$871E25-/17AT96YD960H
M*0H@("`@>PH@("`@("`@("1T96UP(#T@;F5W($1A=&4H(C(P,#,M,3`M,#14
M,30Z,#,Z,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@
M("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P
M<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@
M("`@("`@("`@("1T96UP+3YY96%R+"`D=&5M<"T^;6]N=&@L("1T96UP+3YD
M87DL"B`@("`@("`@("`@("`@("`D=&5M<"T^:&]U<BP@)'1E;7`M/FUI;G5T
M92P@)'1E;7`M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T
M:6]N('1E<W1$871E25-/5&EM97-T86UP*"D*("`@('L*("`@("`@("`D=&5M
M<"`](&YE=R!$871E*"(R,#`S,3`P-#$T,#,R-"(I.PH@("`@("`@("1T:&ES
M+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R,#`S+3$P+3`T(#$T.C`S
M.C(T)RP*("`@("`@("`@("`@<W!R:6YT9B@G)3`T9"TE,#)D+24P,F0@)3`R
M9#HE,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@)'1E;7`M/GEE87(L("1T
M96UP+3YM;VYT:"P@)'1E;7`M/F1A>2P*("`@("`@("`@("`@("`@("1T96UP
M+3YH;W5R+"`D=&5M<"T^;6EN=71E+"`D=&5M<"T^<V5C;VYD*0H@("`@("`@
M("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$1A=&55;FEX=&EM92@I"B`@
M("!["B`@("`@("`@)'1E;7`@/2!N97<@1&%T92AS=')T;W1I;64H(C(P,#,M
M,3`M,#0@,30Z,#,Z,C0B*2D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@
M("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L
M"B`@("`@("`@("`@("`@("`D=&5M<"T^>65A<BP@)'1E;7`M/FUO;G1H+"`D
M=&5M<"T^9&%Y+`H@("`@("`@("`@("`@("`@)'1E;7`M/FAO=7(L("1T96UP
M+3YM:6YU=&4L("1T96UP+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@
M("!F=6YC=&EO;B!T97-T4V5T1&%T94E33R@I"B`@("!["B`@("`@("`@)'1H
M:7,M/G1I;64M/G-E=$1A=&4H(C(P,#,M,3`M,#0@,30Z,#,Z,C0B*3L*("`@
M("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,C`P,RTQ
M,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P<FEN=&8H)R4P-&0M)3`R
M9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@("`@("`@("`@("1T:&ES
M+3YT:6UE+3YY96%R+"`D=&AI<RT^=&EM92T^;6]N=&@L("1T:&ES+3YT:6UE
M+3YD87DL"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^:&]U<BP@)'1H
M:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M/G-E8V]N9"D*("`@("`@
M("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971$871E25-/0F%S:6,H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971$871E*"(R,#`S,3`P
M-%0Q-#`S,C0B*3L*("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@
M("`@("`@("`G,C`P,RTQ,"TP-"`Q-#HP,SHR-"<L"B`@("`@("`@("`@('-P
M<FEN=&8H)R4P-&0M)3`R9"TE,#)D("4P,F0Z)3`R9#HE,#)D)RP*("`@("`@
M("`@("`@("`@("1T:&ES+3YT:6UE+3YY96%R+"`D=&AI<RT^=&EM92T^;6]N
M=&@L("1T:&ES+3YT:6UE+3YD87DL"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=&EM92T^:&]U<BP@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M/G1I;64M
M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13
M971$871E25-/17AT96YD960H*0H@("`@>PH@("`@("`@("1T:&ES+3YT:6UE
M+3YS971$871E*"(R,#`S+3$P+3`T5#$T.C`S.C(T(BD["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z
M,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E
M,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^
M>65A<BP@)'1H:7,M/G1I;64M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y+`H@
M("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT:6UE
M+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1&%T951I;65S=&%M<"@I"B`@("![
M"B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$1A=&4H(C(P,#,Q,#`T,30P,S(T
M(BD["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@
M)S(P,#,M,3`M,#0@,30Z,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E
M,#1D+24P,F0M)3`R9"`E,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=&EM92T^>65A<BP@)'1H:7,M/G1I;64M/FUO;G1H+"`D=&AI
M<RT^=&EM92T^9&%Y+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FAO
M=7(L("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I
M"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1&%T955N
M:7AT:6UE*"D*("`@('L*("`@("`@("`D=&AI<RT^=&EM92T^<V5T1&%T92AS
M=')T;W1I;64H(C(P,#,M,3`M,#0@,30Z,#,Z,C0B*2D["B`@("`@("`@)'1H
M:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@)S(P,#,M,3`M,#0@,30Z
M,#,Z,C0G+`H@("`@("`@("`@("!S<')I;G1F*"<E,#1D+24P,F0M)3`R9"`E
M,#)D.B4P,F0Z)3`R9"<L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^
M>65A<BP@)'1H:7,M/G1I;64M/FUO;G1H+"`D=&AI<RT^=&EM92T^9&%Y+`H@
M("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FAO=7(L("1T:&ES+3YT:6UE
M+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!T97-T1V5T1&%T94E33R@I"B`@("!["B`@("`@
M("`@)&1A=&4@/2`D=&AI<RT^=&EM92T^9V5T1&%T92A$051%7T9/4DU!5%])
M4T\I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H)S(P,#,M,3`M,#0@
M,30Z,#,Z,C0G+"`D9&%T92D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$=E
M=$1A=&5)4T]"87-I8R@I"B`@("!["B`@("`@("`@)&1A=&4@/2`D=&AI<RT^
M=&EM92T^9V5T1&%T92A$051%7T9/4DU!5%])4T]?0D%324,I.PH@("`@("`@
M("1T:&ES+3YA<W-E<G1%<75A;',H)S(P,#,Q,#`T5#$T,#,R-%HG+"`D9&%T
M92D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$=E=$1A=&5)4T]%>'1E;F1E
M9"@I"B`@("!["B`@("`@("`@)&1A=&4@/2`D=&AI<RT^=&EM92T^9V5T1&%T
M92A$051%7T9/4DU!5%])4T]?15A414Y$140I.PH@("`@("`@("1T:&ES+3YA
M<W-E<G1%<75A;',H)S(P,#,M,3`M,#14,30Z,#,Z,C1:)RP@)&1A=&4I.PH@
M("`@?0H*("`@(&9U;F-T:6]N('1E<W1'971$871E5&EM97-T86UP*"D*("`@
M('L*("`@("`@("`D9&%T92`]("1T:&ES+3YT:6UE+3YG971$871E*$1!5$5?
M1D]234%47U1)34535$%-4"D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L
M<R@G,C`P,S$P,#0Q-#`S,C0G+"`D9&%T92D["B`@("!]"@H@("`@9G5N8W1I
M;VX@=&5S=$=E=$1A=&55;FEX=&EM92@I"B`@("!["B`@("`@("`@)&1A=&4@
M/2`D=&AI<RT^=&EM92T^9V5T1&%T92A$051%7T9/4DU!5%]53DE85$E-12D[
M"B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<RAS=')T;W1I;64H)S(P,#,M
M,3`M,#0@,30Z,#,Z,C0G*2P@)&1A=&4I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W1&;W)M870H*0H@("`@>PH@("`@("`@("1C;V1E<R`](&%R<F%Y*`H@
M("`@("`@("`@("`G82<@/3X@)U-A="<L"B`@("`@("`@("`@("=!)R`]/B`G
M4V%T=7)D87DG+`H@("`@("`@("`@("`G8B<@/3X@)T]C="<L"B`@("`@("`@
M("`@("=")R`]/B`G3V-T;V)E<B<L"B`@("`@("`@("`@("=#)R`]/B`G,C`G
M+`H@("`@("`@("`@("`G9"<@/3X@)S`T)RP*("`@("`@("`@("`@)T0G(#T^
M("<Q,"\P-"\R,#`S)RP*("`@("`@("`@("`@)V4G(#T^("<T)RP*("`@("`@
M("`@("`@)T@G(#T^("<Q-"<L"B`@("`@("`@("`@("=))R`]/B`G,#(G+`H@
M("`@("`@("`@("`G:B<@/3X@)S(W-R<L"B`@("`@("`@("`@("=M)R`]/B`G
M,3`G+`H@("`@("`@("`@("`G32<@/3X@)S`S)RP*("`@("`@("`@("`@)VXG
M(#T^(")<;B(L"B`@("`@("`@("`@("=/)R`]/B`G*S`P.C`P)RP*("`@("`@
M("`@("`@)V\G(#T^("<K,#`Z,#`G+`H@("`@("`@("`@("`G<"<@/3X@)W!M
M)RP*("`@("`@("`@("`@)U`G(#T^("=032<L"B`@("`@("`@("`@("=R)R`]
M/B`G,#(Z,#,Z,C0@4$TG+`H@("`@("`@("`@("`G4B<@/3X@)S$T.C`S)RP*
M("`@("`@("`@("`@)U,G(#T^("<R-"<L"B`@("`@("`@("`@("=T)R`]/B`B
M7'0B+`H@("`@("`@("`@("`G5"<@/3X@)S$T.C`S.C(T)RP*("`@("`@("`@
M("`@)W<G(#T^("<V)RP*("`@("`@("`@("`@)U4G(#T^("<T,"<L"B`@("`@
M("`@("`@("=Y)R`]/B`G,#,G+`H@("`@("`@("`@("`G62<@/3X@)S(P,#,G
M+`H@("`@("`@("`@("`G)2<@/3X@)R4G"B`@("`@("`@*3L*"B`@("`@("`@
M9F]R96%C:"`H)&-O9&5S(&%S("1C;V1E(#T^("1E>'!E8W1E9"D@>PH@("`@
M("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`@("`@
M(B1C;V1E.B`D97AP96-T960B+"`D=&AI<RT^=&EM92T^9F]R;6%T*"(D8V]D
M93H@)21C;V1E(BD*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@("!]"@H@
M("`@9G5N8W1I;VX@=&5S=%1O551#8GE/9F9S970H*0H@("`@>PH@("`@("`@
M("1T:&ES+3YT:6UE+3YS97146F)Y240H)T535"<I.PH@("`@("`@("1T:&ES
M+3YT:6UE+3YT;U540R@I.PH@("`@("`@("1T96UP(#T@;F5W($1A=&4H(C(P
M,#,M,3`M,#0@,30Z,#,Z,C0B*3L*("`@("`@("`D=&5M<"T^=&]55$-B>4]F
M9G-E="@B+3`U.C`P(BD["@H@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H
M)'1E;7`L("1T:&ES+3YT:6UE*3L*("`@('T*"GT*"B\O(')U;G,@=&AE('1E
M<W1S"B1S=6ET92`](&YE=R!02%!5;FET7U1E<W13=6ET92@B1&%T95]497-T
M(BD["B1R97-U;'0@/2!02%!5;FET.CIR=6XH)'-U:71E*3L*+R\@<')I;G1S
M('1H92!T97-T<PIE8VAO("1R97-U;'0M/G1O4W1R:6YG*"D["@H_/@H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O=&5S='5N:71?9&%T95]S<&%N+G!H<```````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,3(W-S4@,3`U,34T,S0Q,S4@,#(V,C8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J('9I;3H@
M<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT.B`J+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S($QE86YD<F\@3'5C87)E;&QA
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@
M?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E
M+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W(Z($QE86YD<F\@3'5C87)E;&QA(#QL;'5C87A`<&AP+FYE=#X@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z('1E<W1U;FET7V1A=&5?<W!A;BYP:'`L
M=B`Q+C0@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*+R\*"G)E
M<75I<F5?;VYC92`G1&%T92YP:'`G.PIR97%U:7)E7V]N8V4@)T1A=&4O4W!A
M;BYP:'`G.PIR97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP)SL*"B\J*@H@*B!4
M97-T(&-A<V4@9F]R($1A=&5?4W!A;@H@*@H@*B!`<&%C:V%G92!$871E"B`J
M($!A=71H;W(@3&5A;F1R;R!,=6-A<F5L;&$@/&QL=6-A>$!P:'`N;F5T/@H@
M*B\*8VQA<W,@1&%T95]3<&%N5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A
M<V4@>PH*("`@('9A<B`D=&EM93L*"B`@("!F=6YC=&EO;B!$871E7U-P86Y4
M97-T*"1N86UE*2!["B`@("`@("`@)'1H:7,M/E!(4%5N:71?5&5S=$-A<V4H
M)&YA;64I.PH@("`@?0H*("`@(&9U;F-T:6]N('-E=%5P*"D@>PH@("`@("`@
M("1T:&ES+3YT:6UE(#T@;F5W($1A=&5?4W!A;B@Y-S4S,2D["B`@("!]"@H@
M("`@9G5N8W1I;VX@=&5A<D1O=VXH*2!["B`@("`@("`@=6YS970H)'1H:7,M
M/G1I;64I.PH@("`@?0H*("`@(&9U;F-T:6]N('1E<W13971&<F]M07)R87DH
M*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$9R;VU!<G)A>2AA<G)A>2@U
M+"`T."XU+"`R."XU+"`S,2DI.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A
M;',H"B`@("`@("`@("`@("<W.C`Z-3DZ,2<L"B`@("`@("`@("`@('-P<FEN
M=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M/F1A>2P@)'1H:7,M/G1I
M;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI<RT^=&EM92T^;6EN=71E
M+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@("!]"@H@("`@
M9G5N8W1I;VX@=&5S=%-E=$9R;VU3=')I;F<H*2!["B`@("`@("`@)'1H:7,M
M/G1I;64M/G-E=$9R;VU3=')I;F<H)S4Z,#`Z-3DZ,S$G*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G-3HP.C4Y.C,Q)RP*
M("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM
M92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T
M:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@
M("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1G)O;5-E8V]N9',H
M*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$9R;VU396-O;F1S*#0S-#,T
M-"D["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@*("`@("`@("`@("`@
M)S4Z,#HS.3HT)RP*("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G
M+"`D=&AI<RT^=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@
M("`@("`@("`@("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS
M96-O;F0I"B`@("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T
M1G)O;4UI;G5T97,H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-E=$9R;VU-
M:6YU=&5S*#<X-C`N,#$V-C8V-C8V-BD["B`@("`@("`@)'1H:7,M/F%S<V5R
M=$5Q=6%L<R@*("`@("`@("`@("`@)S4Z,3$Z,#HQ)RP*("`@("`@("`@("`@
M<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^=&EM92T^9&%Y+"`D=&AI
M<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@("1T:&ES+3YT:6UE+3YM
M:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@("`@("`@*3L*("`@('T*
M"B`@("!F=6YC=&EO;B!T97-T4V5T1G)O;4AO=7)S*"D@>PH@("`@("`@("1T
M:&ES+3YT:6UE+3YS971&<F]M2&]U<G,H-3`N,3(S-#4I.PH@("`@("`@("1T
M:&ES+3YA<W-E<G1%<75A;',H"B`@("`@("`@("`@("<R.C(Z-SHR-"<L"B`@
M("`@("`@("`@('-P<FEN=&8H)R5D.B5D.B5D.B5D)RP@)'1H:7,M/G1I;64M
M/F1A>2P@)'1H:7,M/G1I;64M/FAO=7(L"B`@("`@("`@("`@("`@("`D=&AI
M<RT^=&EM92T^;6EN=71E+"`D=&AI<RT^=&EM92T^<V5C;VYD*0H@("`@("`@
M("D["B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=%-E=$9R;VU$87ES*"D@>PH@
M("`@("`@("1T:&ES+3YT:6UE+3YS971&<F]M1&%Y<RAP:2@I*3L*("`@("`@
M("`D=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("`G,SHS.C(S.C4T
M)RP*("`@("`@("`@("`@<W!R:6YT9B@G)60Z)60Z)60Z)60G+"`D=&AI<RT^
M=&EM92T^9&%Y+"`D=&AI<RT^=&EM92T^:&]U<BP*("`@("`@("`@("`@("`@
M("1T:&ES+3YT:6UE+3YM:6YU=&4L("1T:&ES+3YT:6UE+3YS96-O;F0I"B`@
M("`@("`@*3L*("`@('T*"B`@("!F=6YC=&EO;B!T97-T4V5T1G)O;41A=&5$
M:69F*"D@>PH@("`@("`@("1T:&ES+3YT:6UE+3YS971&<F]M1&%T941I9F8H
M"B`@("`@("`@("`@(&YE=R!$871E*"<R,#`T+3`S+3$P(#`Q.C$U.C4Y)RDL
M"B`@("`@("`@("`@(&YE=R!$871E*"<R,#`S+3`S+3$P(#`P.C$P.C4P)RD*
M("`@("`@("`I.PH@("`@("`@("1T:&ES+3YA<W-E<G1%<75A;',H"B`@("`@
M("`@("`@("<S-C8Z,3HU.CDG+`H@("`@("`@("`@("!S<')I;G1F*"<E9#HE
M9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH;W5R
M+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M
M/G1I;64M/G-E8V]N9"D*("`@("`@("`I.PH@("`@?0H*("`@(&9U;F-T:6]N
M('1E<W1#;W!Y*"D@>PH@("`@("`@("1T:6UE(#T@;F5W($1A=&5?4W!A;B@I
M.PH@("`@("`@("1T:6UE+3YC;W!Y*"1T:&ES+3YT:6UE*3L*("`@("`@("`D
M=&AI<RT^87-S97)T17%U86QS*`H@("`@("`@("`@("!S<')I;G1F*"<E9#HE
M9#HE9#HE9"<L("1T:&ES+3YT:6UE+3YD87DL("1T:&ES+3YT:6UE+3YH;W5R
M+`H@("`@("`@("`@("`@("`@)'1H:7,M/G1I;64M/FUI;G5T92P@)'1H:7,M
M/G1I;64M/G-E8V]N9"DL"B`@("`@("`@("`@('-P<FEN=&8H)R5D.B5D.B5D
M.B5D)RP@)'1I;64M/F1A>2P@)'1I;64M/FAO=7(L"B`@("`@("`@("`@("`@
M("`D=&EM92T^;6EN=71E+"`D=&EM92T^<V5C;VYD*0H@("`@("`@("D["B`@
M("!]"@H@("`@9G5N8W1I;VX@=&5S=$9O<FUA="@I('L*("`@("`@("`D8V]D
M97,@/2!A<G)A>2@*("`@("`@("`@("`@)T,G(#T^("<Q+"`P,SHP-3HS,2<L
M"B`@("`@("`@("`@("=D)R`]/B`G,2XQ,C@X,S$P,3@U,3@U)RP*("`@("`@
M("`@("`@)T0G(#T^("<Q)RP*("`@("`@("`@("`@)V4G(#T^("<R-RXP.3$Y
M-#0T-#0T-#0G+`H@("`@("`@("`@("`G9B<@/3X@)S$V,C4N-3$V-C8V-C8V
M-R<L"B`@("`@("`@("`@("=G)R`]/B`G.3<U,S$G+`H@("`@("`@("`@("`G
M:"<@/3X@)S,G+`H@("`@("`@("`@("`G2"<@/3X@)S`S)RP*("`@("`@("`@
M("`@)VDG(#T^("<S)RP*("`@("`@("`@("`@)TDG(#T^("<P,R<L"B`@("`@
M("`@("`@("=M)R`]/B`G-2<L"B`@("`@("`@("`@("=-)R`]/B`G,#4G+`H@
M("`@("`@("`@("`G;B<@/3X@(EQN(BP*("`@("`@("`@("`@)W`G(#T^("=A
M;2<L"B`@("`@("`@("`@("=0)R`]/B`G04TG+`H@("`@("`@("`@("`G<B<@
M/3X@)S`S.C`U.C,Q(&%M)RP*("`@("`@("`@("`@)U(G(#T^("<P,SHP-2<L
M"B`@("`@("`@("`@("=S)R`]/B`G,S$G+`H@("`@("`@("`@("`G4R<@/3X@
M)S,Q)RP*("`@("`@("`@("`@)W0G(#T^(")<="(L"B`@("`@("`@("`@("=4
M)R`]/B`G,#,Z,#4Z,S$G+`H@("`@("`@("`@("`G)2<@/3X@)R4G+`H@("`@
M("`@("D["B`@("`@("`@9F]R96%C:"`H)&-O9&5S(&%S("1C;V1E(#T^("1E
M>'!E8W1E9"D@>PH@("`@("`@("`@("`D=&AI<RT^87-S97)T17%U86QS*`H@
M("`@("`@("`@("`@("`@(B1C;V1E.B`D97AP96-T960B+"`D=&AI<RT^=&EM
M92T^9F]R;6%T*"(D8V]D93H@)21C;V1E(BD*("`@("`@("`@("`@*3L*("`@
M("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@=&5S=$%D9"@I('L*("`@("`@
M("`D=&AI<RT^=&EM92T^861D*&YE=R!$871E7U-P86XH-C`P,"DI.PH@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^=&EM92T^=&]396-O;F1S*"D["B`@("`@
M("`@)&5X<&5C=&5D(#T@,3`S-3,Q.PH@("`@("`@("1T:&ES+3YA<W-E<G1%
M<75A;',H)&5X<&5C=&5D+"`D<F5S=6QT*3L*("`@('T*"B`@("!F=6YC=&EO
M;B!T97-T4W5B=')A8W0H*2!["B`@("`@("`@)'1H:7,M/G1I;64M/G-U8G1R
M86-T*&YE=R!$871E7U-P86XH-C`P,"DI.PH@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^=&EM92T^=&]396-O;F1S*"D["B`@("`@("`@)&5X<&5C=&5D(#T@
M.3$U,S$["B`@("`@("`@)'1H:7,M/F%S<V5R=$5Q=6%L<R@D97AP96-T960L
M("1R97-U;'0I.PH@("`@?0H*?0H*+R\@<G5N<R!T:&4@=&5S=',*)'-U:71E
M(#T@;F5W(%!(4%5N:71?5&5S=%-U:71E*")$871E7U-P86Y497-T(BD["B1R
M97-U;'0@/2!02%!5;FET.CIR=6XH)'-U:71E*3L*+R\@<')I;G1S('1H92!T
M97-T<PIE8VAO("1R97-U;'0M/G1O4W1R:6YG*"D["@H_/@H```!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=&5S=%]C
M86QC+G!H<```````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(T,C0@,3`U,34T
M,S0Q,S4@,#(T,S(P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"G)E<75I<F5?;VYC92`B1&%T92]#86QC+G!H<"([
M"@HO*BH*("H@5&5S="!D871E<R!F<F]M(#$Y-S`@=&\@,C`R.0H@*B!$871A
M(&9R;VTZ(&AT='`Z+R]W=W<N;65R;'EN+F1E;6]N+F-O+G5K+W=K;F]T97-T
M+G1X=`H@*B!/=&AE<G,@=7-E9G5L;"!D871A<R!A=F%I;&%B;&4@9G)O;3H*
M("H@:'1T<#HO+W=W=RYM97)L>6XN9&5M;VXN8V\N=6LO(V1A=`H@*B\*)&9A
M:6QE9%]T97-T7V1A=&$@("`](&9A;'-E.PHD=VMN;R`@(#T@9FEL92@G=VMN
M;W1E<W0N='AT)RD["B1C;G0@("`@/2!S:7IE;V8H)'=K;F\I.PIF;W(H("1I
M/3`[)&D\)&-N=#LD:2LK("E["B`@("`D<&%R=',@("`@("`](&5X<&QO9&4H
M)SHG+"1W:VYO6R1I72D["B`@("`D=V5E:W-N;ULD<&%R='-;,%U=(#T@<W1R
M7W)E<&QA8V4H(EQN(BPG)RPD<&%R='-;,5TI.PI]"G5N<V5T*"1W:VYO*3L*
M9F]R96%C:"@D=V5E:W-N;R!A<R`D9&%T93T^)&ES;RE["B`@("`D>65A<B`@
M("`@("`]('-U8G-T<B@D9&%T92PP+#0I.PH@("`@)&UO;G1H("`@("`@/2!S
M=6)S='(H)&1A=&4L-"PR*3L*("`@("1D87D@("`@("`@(#T@<W5B<W1R*"1D
M871E+#8I.PH@("`@)&ES;SDV,#$@/2!$871E7T-A;&,Z.F=R96=O<FEA;E1O
M25-/*"1D87DL)&UO;G1H+"1Y96%R*3L*("`@(&EF*"1I<V\Y-C`Q(3TD:7-O
M*7L*("`@("`@("`D9F%I;&5D7W1E<W1?9&%T82`@(#T@=')U93L*("`@("`@
M("!E8VAO("1D871E("X@)R@G("X@)&ES;R`N("<I(#T^)R`N("1Y96%R+B<M
M)RXD;6]N=&@N)RTG+B1D87D@+B<]/B<@+B`D:7-O.38P,2`N("(@.B!F86EL
M961<;B(["B`@("!]"GT*"B\J*@H@*B!"=6=S(",Q.3<X.`H@*B\*)&9A:6QE
M9%]T97-T7S$Y-S@X("`](&9A;'-E.PHD<&%S<S$@(#T@,CT]1&%T95]#86QC
M.CIW965K3V9996%R*#4L,2PQ.3DX*3]T<G5E.F9A;'-E.PHD<&%S<S(@(#T@
M,CT]1&%T95]#86QC.CIW965K3V9996%R*#8L,2PQ.3DX*3]T<G5E.F9A;'-E
M.PHD<&%S<S,@(#T@,CT]1&%T95]#86QC.CIW965K3V9996%R*#4L,2PR,#`T
M*3]T<G5E.F9A;'-E.PHD<&%S<S0@(#T@,CT]1&%T95]#86QC.CIW965K3V99
M96%R*#8L,2PR,#`T*3]T<G5E.F9A;'-E.PII9B@@(2@D<&%S<S$@)B8@)'!A
M<W,R("8F("1P87-S,R`F)B`D<&%S<S0I("E["B`@("`D9F%I;&5D7W1E<W1?
M,3DW.#@@("`]('1R=64["GT*"FEF*"1F86EL961?=&5S=%\Q.3<X."!\?"`D
M9F%I;&5D7W1E<W1?9&%T82E["B`@("!E8VAO(")"=6<@(S$Y-S@X.B!F86EL
M961<;B(["GT@96QS92!["B`@("!E8VAO(")"=6<@(S$Y-S@X.B!/2UQN(CL*
M?0H_/@H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1&%T92]T97-T<R]T97-T7V1A=&5?;65T:&]D<U]S<&%N+G!H<```
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-3(S-R`Q,#4Q-30S-#$S-2`P,C<Q,#0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-#H@*B\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#4@($QE86YD<F\@3'5C87)E
M;&QA("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=&AE($YE=R!"4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D
M("!\"B\O('P@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES(&%V86EL86)L92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W
M;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(&YE=R!"4T1L:6-E;G-E(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<CH@3&5A;F1R;R!,=6-A<F5L;&$@/&QL=6-A>$!P:'`N;F5T/B`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=&5S=%]D871E7VUE=&AO9'-?<W!A
M;BYP:'`L=B`Q+C(@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*
M+R\*"@IR97%U:7)E7V]N8V4@)T1A=&4N<&AP)SL*<F5Q=6ER95]O;F-E("=$
M871E+U-P86XN<&AP)SL*"B1D871E(#T@;F5W($1A=&4H*3L*)'1M<"`](&YE
M=R!$871E*"1D871E*3L*"G!R:6YT9B@B06-T=6%L(&1A=&4Z("5S7&XB+"`D
M9&%T92T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I*3L*"B1T;7`M/F-O<'DH
M)&1A=&4I.PHD=&UP+3YS=6)T<F%C=%-P86XH;F5W($1A=&5?4W!A;B@G,#HP
M,#HP,#HP-2<I*3L*<')I;G1F*")3=6)T<F%C=&EN9R`U('-E8V]N9',Z("5S
M7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^
M8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R86-T4W!A;BAN97<@1&%T95]3<&%N
M*"<P.C`P.C(P.C`P)RDI.PIP<FEN=&8H(E-U8G1R86-T:6YG(#(P(&UI;G5T
M97,Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE33RDI.PH*
M)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R86-T4W!A;BAN97<@1&%T
M95]3<&%N*"<P.C$P.C`P.C`P)RDI.PIP<FEN=&8H(E-U8G1R86-T:6YG(#$P
M(&AO=7)S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I
M*3L*"B1T;7`M/F-O<'DH)&1A=&4I.PHD=&UP+3YS=6)T<F%C=%-P86XH;F5W
M($1A=&5?4W!A;B@G,SHP,#HP,#HP,"<I*3L*<')I;G1F*")3=6)T<F%C=&EN
M9R`S(&1A>7,Z("5S7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE3
M3RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M/G-U8G1R86-T4W!A;BAN
M97<@1&%T95]3<&%N*"<S.C$P.C(P.C`U)RDI.PIP<FEN=&8H(E-U8G1R86-T
M:6YG(#,@9&%Y<RP@,3`@:&]U<G,L(#(P(&UI;G5T97,@86YD(#4@<V5C;VYD
M<SH@)7-<;B(L("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD
M=&UP+3YC;W!Y*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@1&%T95]3<&%N
M*"<P.C`P.C`P.C`U)RDI.PIP<FEN=&8H(D%D9&EN9R`U('-E8V]N9',Z("5S
M7&XB+"`D=&UP+3YG971$871E*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^
M8V]P>2@D9&%T92D["B1T;7`M/F%D9%-P86XH;F5W($1A=&5?4W!A;B@G,#HP
M,#HR,#HP,"<I*3L*<')I;G1F*")!9&1I;F<@,C`@;6EN=71E<SH@)7-<;B(L
M("1T;7`M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC;W!Y
M*"1D871E*3L*)'1M<"T^861D4W!A;BAN97<@1&%T95]3<&%N*"<P.C$P.C`P
M.C`P)RDI.PIP<FEN=&8H(D%D9&EN9R`Q,"!H;W5R<SH@)7-<;B(L("1T;7`M
M/F=E=$1A=&4H1$%415]&3U)-051?25-/*2D["@HD=&UP+3YC;W!Y*"1D871E
M*3L*)'1M<"T^861D4W!A;BAN97<@1&%T95]3<&%N*"<S.C`P.C`P.C`P)RDI
M.PIP<FEN=&8H(D%D9&EN9R`S(&1A>7,Z("5S7&XB+"`D=&UP+3YG971$871E
M*$1!5$5?1D]234%47TE33RDI.PH*)'1M<"T^8V]P>2@D9&%T92D["B1T;7`M
M/F%D9%-P86XH;F5W($1A=&5?4W!A;B@G,SHQ,#HR,#HP-2<I*3L*<')I;G1F
M*")!9&1I;F<@,R!D87ES+"`Q,"!H;W5R<RP@,C`@;6EN=71E<R!A;F0@-2!S
M96-O;F1S.B`E<UQN(BP@)'1M<"T^9V5T1&%T92A$051%7T9/4DU!5%])4T\I
M*3L*"C\^"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$871E+W1E<W1S
M+W=E96MS:6YM;VYT:%\T7VUO;F1A>2YT>'0`````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C8T
M(#$P-3$U-#,T,3,U(#`R-C<Q-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````Q.3DY+S(O-`HR,#$P+S(O-`HR,#(Q+S(O-`HR
M,#(W+S(O-`HQ.3,W+S(O-`HQ.30S+S(O-`HQ.#`R+S(O-`HQ.#$S+S(O-`HQ
M.#$Y+S(O-`HQ.#,P+S(O-`HQ.#0Q+S(O-`HQ.#0W+S(O-`HQ.#4X+S(O-`HQ
M.#8Y+S(O-`HQ.#<U+S(O-`HQ.#@V+S(O-`HQ.#DW+S(O-`HQ.3`Y+S(O-`HQ
M.3$U+S(O-`HQ.3(V+S(O-`H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]W965K<VEN;6]N
M=&A?-%]S=6YD87DN='AT```````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(V-"`Q,#4Q-30S-#$S
M-2`P,C8W,S``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````,C`P.2\R+S0*,C`Q-2\R+S0*,C`R-B\R+S0*,C`S-R\R+S0*,3DS
M,2\R+S0*,3DT,B\R+S0*,3@P,2\R+S0*,3@P-R\R+S0*,3@Q."\R+S0*,3@R
M.2\R+S0*,3@S-2\R+S0*,3@T-B\R+S0*,3@U-R\R+S0*,3@V,R\R+S0*,3@W
M-"\R+S0*,3@X-2\R+S0*,3@Y,2\R+S0*,3DP,R\R+S0*,3DQ-"\R+S0*,3DR
M-2\R+S0*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E:W-I;FUO;G1H7W)D;5]M;VYD
M87DN='AT````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#<R,38@,3`U,34T,S0Q,S4@,#(W,S,W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#$Y.3DO
M."\V"C(P,#`O,3`O-@HR,#`Q+S$R+S8*,C`P,B\Q,B\V"C(P,#,O-B\V"C(P
M,#0O."\V"C(P,#4O,3`O-@HR,#`V+S$P+S8*,C`P-R\Q,B\V"C(P,#@O-B\V
M"C(P,#DO,3$O-@HR,#$P+S@O-@HR,#$Q+S$P+S8*,C`Q,B\Q,B\V"C(P,3,O
M,3(O-@HR,#$T+S8O-@HR,#$U+S$Q+S8*,C`Q-B\Q,"\V"C(P,3<O,3`O-@HR
M,#$X+S$R+S8*,C`Q.2\Q,B\V"C(P,C`O,3$O-@HR,#(Q+S@O-@HR,#(R+S$P
M+S8*,C`R,R\Q,"\V"C(P,C0O,3(O-@HR,#(U+S8O-@HR,#(V+S$Q+S8*,C`R
M-R\X+S8*,C`R."\Q,"\V"C(P,CDO,3(O-@HR,#,P+S$R+S8*,C`S,2\V+S8*
M,C`S,B\X+S8*,C`S,R\Q,"\V"C(P,S0O,3`O-@HR,#,U+S$R+S8*,C`S-B\V
M+S8*,C`S-R\Q,2\V"C$Y,S`O-B\V"C$Y,S$O,3$O-@HQ.3,R+S$P+S8*,3DS
M,R\Q,"\V"C$Y,S0O,3(O-@HQ.3,U+S$R+S8*,3DS-B\Q,2\V"C$Y,S<O."\V
M"C$Y,S@O,3`O-@HQ.3,Y+S$P+S8*,3DT,"\Q,B\V"C$Y-#$O-B\V"C$Y-#(O
M,3$O-@HQ.30S+S@O-@HQ.30T+S$P+S8*,3DT-2\Q,B\V"C$Y-#8O,3(O-@HQ
M.30W+S8O-@HQ.30X+S@O-@HQ.30Y+S$P+S8*,3@P,"\V+S8*,3@P,2\Q,2\V
M"C$X,#(O."\V"C$X,#,O,3`O-@HQ.#`T+S$R+S8*,3@P-2\Q,B\V"C$X,#8O
M-B\V"C$X,#<O,3$O-@HQ.#`X+S$P+S8*,3@P.2\Q,"\V"C$X,3`O,3(O-@HQ
M.#$Q+S$R+S8*,3@Q,B\Q,2\V"C$X,3,O."\V"C$X,30O,3`O-@HQ.#$U+S$P
M+S8*,3@Q-B\Q,B\V"C$X,3<O-B\V"C$X,3@O,3$O-@HQ.#$Y+S@O-@HQ.#(P
M+S$P+S8*,3@R,2\Q,B\V"C$X,C(O,3(O-@HQ.#(S+S8O-@HQ.#(T+S@O-@HQ
M.#(U+S$P+S8*,3@R-B\Q,"\V"C$X,C<O,3(O-@HQ.#(X+S8O-@HQ.#(Y+S$Q
M+S8*,3@S,"\X+S8*,3@S,2\Q,"\V"C$X,S(O,3(O-@HQ.#,S+S$R+S8*,3@S
M-"\V+S8*,3@S-2\Q,2\V"C$X,S8O,3`O-@HQ.#,W+S$P+S8*,3@S."\Q,B\V
M"C$X,SDO,3(O-@HQ.#0P+S$Q+S8*,3@T,2\X+S8*,3@T,B\Q,"\V"C$X-#,O
M,3`O-@HQ.#0T+S$R+S8*,3@T-2\V+S8*,3@T-B\Q,2\V"C$X-#<O."\V"C$X
M-#@O,3`O-@HQ.#0Y+S$R+S8*,3@U,"\Q,B\V"C$X-3$O-B\V"C$X-3(O."\V
M"C$X-3,O,3`O-@HQ.#4T+S$P+S8*,3@U-2\Q,B\V"C$X-38O-B\V"C$X-3<O
M,3$O-@HQ.#4X+S@O-@HQ.#4Y+S$P+S8*,3@V,"\Q,B\V"C$X-C$O,3(O-@HQ
M.#8R+S8O-@HQ.#8S+S$Q+S8*,3@V-"\Q,"\V"C$X-C4O,3`O-@HQ.#8V+S$R
M+S8*,3@V-R\Q,B\V"C$X-C@O,3$O-@HQ.#8Y+S@O-@HQ.#<P+S$P+S8*,3@W
M,2\Q,"\V"C$X-S(O,3(O-@HQ.#<S+S8O-@HQ.#<T+S$Q+S8*,3@W-2\X+S8*
M,3@W-B\Q,"\V"C$X-S<O,3(O-@HQ.#<X+S$R+S8*,3@W.2\V+S8*,3@X,"\X
M+S8*,3@X,2\Q,"\V"C$X.#(O,3`O-@HQ.#@S+S$R+S8*,3@X-"\V+S8*,3@X
M-2\Q,2\V"C$X.#8O."\V"C$X.#<O,3`O-@HQ.#@X+S$R+S8*,3@X.2\Q,B\V
M"C$X.3`O-B\V"C$X.3$O,3$O-@HQ.#DR+S$P+S8*,3@Y,R\Q,"\V"C$X.30O
M,3(O-@HQ.#DU+S$R+S8*,3@Y-B\Q,2\V"C$X.3<O."\V"C$X.3@O,3`O-@HQ
M.#DY+S$P+S8*,3DP,"\Q,B\V"C$Y,#$O,3(O-@HQ.3`R+S8O-@HQ.3`S+S$Q
M+S8*,3DP-"\Q,"\V"C$Y,#4O,3`O-@HQ.3`V+S$R+S8*,3DP-R\Q,B\V"C$Y
M,#@O,3$O-@HQ.3`Y+S@O-@HQ.3$P+S$P+S8*,3DQ,2\Q,"\V"C$Y,3(O,3(O
M-@HQ.3$S+S8O-@HQ.3$T+S$Q+S8*,3DQ-2\X+S8*,3DQ-B\Q,"\V"C$Y,3<O
M,3(O-@HQ.3$X+S$R+S8*,3DQ.2\V+S8*,3DR,"\X+S8*,3DR,2\Q,"\V"C$Y
M,C(O,3`O-@HQ.3(S+S$R+S8*,3DR-"\V+S8*,3DR-2\Q,2\V"C$Y,C8O."\V
M"C$Y,C<O,3`O-@HQ.3(X+S$R+S8*,3DR.2\Q,B\V"C$Y.3DO,3(O-0HR,#`P
M+S$R+S4*,C`P,2\Q,2\U"C(P,#(O,3$O-0HR,#`S+S$R+S4*,C`P-"\Q,B\U
M"C(P,#4O,3(O-0HR,#`V+S$R+S4*,C`P-R\Q,2\U"C(P,#@O,3(O-0HR,#`Y
M+S$R+S4*,C`Q,"\Q,B\U"C(P,3$O,3(O-0HR,#$R+S$Q+S4*,C`Q,R\Q,2\U
M"C(P,30O,3(O-0HR,#$U+S$R+S4*,C`Q-B\Q,B\U"C(P,3<O,3(O-0HR,#$X
M+S$Q+S4*,C`Q.2\Q,2\U"C(P,C`O,3(O-0HR,#(Q+S$R+S4*,C`R,B\Q,B\U
M"C(P,C,O,3(O-0HR,#(T+S$Q+S4*,C`R-2\Q,B\U"C(P,C8O,3(O-0HR,#(W
M+S$R+S4*,C`R."\Q,B\U"C(P,CDO,3$O-0HR,#,P+S$Q+S4*,C`S,2\Q,B\U
M"C(P,S(O,3(O-0HR,#,S+S$R+S4*,C`S-"\Q,B\U"C(P,S4O,3$O-0HR,#,V
M+S$R+S4*,C`S-R\Q,B\U"C$Y,S`O,3(O-0HQ.3,Q+S$R+S4*,3DS,B\Q,B\U
M"C$Y,S,O,3(O-0HQ.3,T+S$Q+S4*,3DS-2\Q,2\U"C$Y,S8O,3(O-0HQ.3,W
M+S$R+S4*,3DS."\Q,B\U"C$Y,SDO,3(O-0HQ.30P+S$Q+S4*,3DT,2\Q,B\U
M"C$Y-#(O,3(O-0HQ.30S+S$R+S4*,3DT-"\Q,B\U"C$Y-#4O,3$O-0HQ.30V
M+S$Q+S4*,3DT-R\Q,B\U"C$Y-#@O,3(O-0HQ.30Y+S$R+S4*,3@P,"\Q,B\U
M"C$X,#$O,3(O-0HQ.#`R+S$R+S4*,3@P,R\Q,B\U"C$X,#0O,3$O-0HQ.#`U
M+S$Q+S4*,3@P-B\Q,B\U"C$X,#<O,3(O-0HQ.#`X+S$R+S4*,3@P.2\Q,B\U
M"C$X,3`O,3$O-0HQ.#$Q+S$Q+S4*,3@Q,B\Q,B\U"C$X,3,O,3(O-0HQ.#$T
M+S$R+S4*,3@Q-2\Q,B\U"C$X,38O,3$O-0HQ.#$W+S$R+S4*,3@Q."\Q,B\U
M"C$X,3DO,3(O-0HQ.#(P+S$R+S4*,3@R,2\Q,2\U"C$X,C(O,3$O-0HQ.#(S
M+S$R+S4*,3@R-"\Q,B\U"C$X,C4O,3(O-0HQ.#(V+S$R+S4*,3@R-R\Q,2\U
M"C$X,C@O,3(O-0HQ.#(Y+S$R+S4*,3@S,"\Q,B\U"C$X,S$O,3(O-0HQ.#,R
M+S$Q+S4*,3@S,R\Q,2\U"C$X,S0O,3(O-0HQ.#,U+S$R+S4*,3@S-B\Q,B\U
M"C$X,S<O,3(O-0HQ.#,X+S$Q+S4*,3@S.2\Q,2\U"C$X-#`O,3(O-0HQ.#0Q
M+S$R+S4*,3@T,B\Q,B\U"C$X-#,O,3(O-0HQ.#0T+S$Q+S4*,3@T-2\Q,B\U
M"C$X-#8O,3(O-0HQ.#0W+S$R+S4*,3@T."\Q,B\U"C$X-#DO,3$O-0HQ.#4P
M+S$Q+S4*,3@U,2\Q,B\U"C$X-3(O,3(O-0HQ.#4S+S$R+S4*,3@U-"\Q,B\U
M"C$X-34O,3$O-0HQ.#4V+S$R+S4*,3@U-R\Q,B\U"C$X-3@O,3(O-0HQ.#4Y
M+S$R+S4*,3@V,"\Q,2\U"C$X-C$O,3$O-0HQ.#8R+S$R+S4*,3@V,R\Q,B\U
M"C$X-C0O,3(O-0HQ.#8U+S$R+S4*,3@V-B\Q,2\U"C$X-C<O,3$O-0HQ.#8X
M+S$R+S4*,3@V.2\Q,B\U"C$X-S`O,3(O-0HQ.#<Q+S$R+S4*,3@W,B\Q,2\U
M"C$X-S,O,3(O-0HQ.#<T+S$R+S4*,3@W-2\Q,B\U"C$X-S8O,3(O-0HQ.#<W
M+S$Q+S4*,3@W."\Q,2\U"C$X-SDO,3(O-0HQ.#@P+S$R+S4*,3@X,2\Q,B\U
M"C$X.#(O,3(O-0HQ.#@S+S$Q+S4*,3@X-"\Q,B\U"C$X.#4O,3(O-0HQ.#@V
M+S$R+S4*,3@X-R\Q,B\U"C$X.#@O,3$O-0HQ.#@Y+S$Q+S4*,3@Y,"\Q,B\U
M"C$X.3$O,3(O-0HQ.#DR+S$R+S4*,3@Y,R\Q,B\U"C$X.30O,3$O-0HQ.#DU
M+S$Q+S4*,3@Y-B\Q,B\U"C$X.3<O,3(O-0HQ.#DX+S$R+S4*,3@Y.2\Q,B\U
M"C$Y,#`O,3$O-0HQ.3`Q+S$Q+S4*,3DP,B\Q,B\U"C$Y,#,O,3(O-0HQ.3`T
M+S$R+S4*,3DP-2\Q,B\U"C$Y,#8O,3$O-0HQ.3`W+S$Q+S4*,3DP."\Q,B\U
M"C$Y,#DO,3(O-0HQ.3$P+S$R+S4*,3DQ,2\Q,B\U"C$Y,3(O,3$O-0HQ.3$S
M+S$R+S4*,3DQ-"\Q,B\U"C$Y,34O,3(O-0HQ.3$V+S$R+S4*,3DQ-R\Q,2\U
M"C$Y,3@O,3$O-0HQ.3$Y+S$R+S4*,3DR,"\Q,B\U"C$Y,C$O,3(O-0HQ.3(R
M+S$R+S4*,3DR,R\Q,2\U"C$Y,C0O,3(O-0HQ.3(U+S$R+S4*,3DR-B\Q,B\U
M"C$Y,C<O,3(O-0HQ.3(X+S$Q+S4*,3DR.2\Q,2\U"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O=&5S=',O=V5E
M:W-I;FUO;G1H7W)D;5]S=6YD87DN='AT````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#<R,38@,3`U
M,34T,S0Q,S4@,#(W,S4S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#$Y.3DO,3(O-0HR,#`P+S$Q+S4*,C`P,2\Q,2\U"C(P
M,#(O,3(O-0HR,#`S+S$R+S4*,C`P-"\Q,B\U"C(P,#4O,3(O-0HR,#`V+S$Q
M+S4*,C`P-R\Q,2\U"C(P,#@O,3(O-0HR,#`Y+S$R+S4*,C`Q,"\Q,B\U"C(P
M,3$O,3(O-0HR,#$R+S$Q+S4*,C`Q,R\Q,B\U"C(P,30O,3(O-0HR,#$U+S$R
M+S4*,C`Q-B\Q,B\U"C(P,3<O,3$O-0HR,#$X+S$Q+S4*,C`Q.2\Q,B\U"C(P
M,C`O,3(O-0HR,#(Q+S$R+S4*,C`R,B\Q,B\U"C(P,C,O,3$O-0HR,#(T+S$R
M+S4*,C`R-2\Q,B\U"C(P,C8O,3(O-0HR,#(W+S$R+S4*,C`R."\Q,2\U"C(P
M,CDO,3$O-0HR,#,P+S$R+S4*,C`S,2\Q,B\U"C(P,S(O,3(O-0HR,#,S+S$R
M+S4*,C`S-"\Q,2\U"C(P,S4O,3$O-0HR,#,V+S$R+S4*,C`S-R\Q,B\U"C$Y
M,S`O,3(O-0HQ.3,Q+S$R+S4*,3DS,B\Q,B\U"C$Y,S,O,3$O-0HQ.3,T+S$Q
M+S4*,3DS-2\Q,B\U"C$Y,S8O,3(O-0HQ.3,W+S$R+S4*,3DS."\Q,B\U"C$Y
M,SDO,3$O-0HQ.30P+S$R+S4*,3DT,2\Q,B\U"C$Y-#(O,3(O-0HQ.30S+S$R
M+S4*,3DT-"\Q,2\U"C$Y-#4O,3$O-0HQ.30V+S$R+S4*,3DT-R\Q,B\U"C$Y
M-#@O,3(O-0HQ.30Y+S$R+S4*,3@P,"\Q,B\U"C$X,#$O,3(O-0HQ.#`R+S$R
M+S4*,3@P,R\Q,B\U"C$X,#0O,3$O-0HQ.#`U+S$R+S4*,3@P-B\Q,B\U"C$X
M,#<O,3(O-0HQ.#`X+S$R+S4*,3@P.2\Q,2\U"C$X,3`O,3$O-0HQ.#$Q+S$R
M+S4*,3@Q,B\Q,B\U"C$X,3,O,3(O-0HQ.#$T+S$R+S4*,3@Q-2\Q,2\U"C$X
M,38O,3(O-0HQ.#$W+S$R+S4*,3@Q."\Q,B\U"C$X,3DO,3(O-0HQ.#(P+S$Q
M+S4*,3@R,2\Q,2\U"C$X,C(O,3(O-0HQ.#(S+S$R+S4*,3@R-"\Q,B\U"C$X
M,C4O,3(O-0HQ.#(V+S$Q+S4*,3@R-R\Q,2\U"C$X,C@O,3(O-0HQ.#(Y+S$R
M+S4*,3@S,"\Q,B\U"C$X,S$O,3(O-0HQ.#,R+S$Q+S4*,3@S,R\Q,B\U"C$X
M,S0O,3(O-0HQ.#,U+S$R+S4*,3@S-B\Q,B\U"C$X,S<O,3$O-0HQ.#,X+S$Q
M+S4*,3@S.2\Q,B\U"C$X-#`O,3(O-0HQ.#0Q+S$R+S4*,3@T,B\Q,B\U"C$X
M-#,O,3$O-0HQ.#0T+S$R+S4*,3@T-2\Q,B\U"C$X-#8O,3(O-0HQ.#0W+S$R
M+S4*,3@T."\Q,2\U"C$X-#DO,3$O-0HQ.#4P+S$R+S4*,3@U,2\Q,B\U"C$X
M-3(O,3(O-0HQ.#4S+S$R+S4*,3@U-"\Q,2\U"C$X-34O,3$O-0HQ.#4V+S$R
M+S4*,3@U-R\Q,B\U"C$X-3@O,3(O-0HQ.#4Y+S$R+S4*,3@V,"\Q,2\U"C$X
M-C$O,3(O-0HQ.#8R+S$R+S4*,3@V,R\Q,B\U"C$X-C0O,3(O-0HQ.#8U+S$Q
M+S4*,3@V-B\Q,2\U"C$X-C<O,3(O-0HQ.#8X+S$R+S4*,3@V.2\Q,B\U"C$X
M-S`O,3(O-0HQ.#<Q+S$Q+S4*,3@W,B\Q,B\U"C$X-S,O,3(O-0HQ.#<T+S$R
M+S4*,3@W-2\Q,B\U"C$X-S8O,3$O-0HQ.#<W+S$Q+S4*,3@W."\Q,B\U"C$X
M-SDO,3(O-0HQ.#@P+S$R+S4*,3@X,2\Q,B\U"C$X.#(O,3$O-0HQ.#@S+S$Q
M+S4*,3@X-"\Q,B\U"C$X.#4O,3(O-0HQ.#@V+S$R+S4*,3@X-R\Q,B\U"C$X
M.#@O,3$O-0HQ.#@Y+S$R+S4*,3@Y,"\Q,B\U"C$X.3$O,3(O-0HQ.#DR+S$R
M+S4*,3@Y,R\Q,2\U"C$X.30O,3$O-0HQ.#DU+S$R+S4*,3@Y-B\Q,B\U"C$X
M.3<O,3(O-0HQ.#DX+S$R+S4*,3@Y.2\Q,2\U"C$Y,#`O,3$O-0HQ.3`Q+S$R
M+S4*,3DP,B\Q,B\U"C$Y,#,O,3(O-0HQ.3`T+S$R+S4*,3DP-2\Q,2\U"C$Y
M,#8O,3$O-0HQ.3`W+S$R+S4*,3DP."\Q,B\U"C$Y,#DO,3(O-0HQ.3$P+S$R
M+S4*,3DQ,2\Q,2\U"C$Y,3(O,3(O-0HQ.3$S+S$R+S4*,3DQ-"\Q,B\U"C$Y
M,34O,3(O-0HQ.3$V+S$Q+S4*,3DQ-R\Q,2\U"C$Y,3@O,3(O-0HQ.3$Y+S$R
M+S4*,3DR,"\Q,B\U"C$Y,C$O,3(O-0HQ.3(R+S$Q+S4*,3DR,R\Q,2\U"C$Y
M,C0O,3(O-0HQ.3(U+S$R+S4*,3DR-B\Q,B\U"C$Y,C<O,3(O-0HQ.3(X+S$Q
M+S4*,3DR.2\Q,B\U"C$Y.3DO,3`O-@HR,#`P+S$R+S8*,C`P,2\Q,B\V"C(P
M,#(O-B\V"C(P,#,O,3$O-@HR,#`T+S$P+S8*,C`P-2\Q,"\V"C(P,#8O,3(O
M-@HR,#`W+S$R+S8*,C`P."\Q,2\V"C(P,#DO."\V"C(P,3`O,3`O-@HR,#$Q
M+S$P+S8*,C`Q,B\Q,B\V"C(P,3,O-B\V"C(P,30O,3$O-@HR,#$U+S@O-@HR
M,#$V+S$P+S8*,C`Q-R\Q,B\V"C(P,3@O,3(O-@HR,#$Y+S8O-@HR,#(P+S@O
M-@HR,#(Q+S$P+S8*,C`R,B\Q,"\V"C(P,C,O,3(O-@HR,#(T+S8O-@HR,#(U
M+S$Q+S8*,C`R-B\X+S8*,C`R-R\Q,"\V"C(P,C@O,3(O-@HR,#(Y+S$R+S8*
M,C`S,"\V+S8*,C`S,2\Q,2\V"C(P,S(O,3`O-@HR,#,S+S$P+S8*,C`S-"\Q
M,B\V"C(P,S4O,3(O-@HR,#,V+S$Q+S8*,C`S-R\X+S8*,3DS,"\Q,2\V"C$Y
M,S$O."\V"C$Y,S(O,3`O-@HQ.3,S+S$R+S8*,3DS-"\Q,B\V"C$Y,S4O-B\V
M"C$Y,S8O."\V"C$Y,S<O,3`O-@HQ.3,X+S$P+S8*,3DS.2\Q,B\V"C$Y-#`O
M-B\V"C$Y-#$O,3$O-@HQ.30R+S@O-@HQ.30S+S$P+S8*,3DT-"\Q,B\V"C$Y
M-#4O,3(O-@HQ.30V+S8O-@HQ.30W+S$Q+S8*,3DT."\Q,"\V"C$Y-#DO,3`O
M-@HQ.#`P+S$Q+S8*,3@P,2\X+S8*,3@P,B\Q,"\V"C$X,#,O,3`O-@HQ.#`T
M+S$R+S8*,3@P-2\V+S8*,3@P-B\Q,2\V"C$X,#<O."\V"C$X,#@O,3`O-@HQ
M.#`Y+S$R+S8*,3@Q,"\Q,B\V"C$X,3$O-B\V"C$X,3(O."\V"C$X,3,O,3`O
M-@HQ.#$T+S$P+S8*,3@Q-2\Q,B\V"C$X,38O-B\V"C$X,3<O,3$O-@HQ.#$X
M+S@O-@HQ.#$Y+S$P+S8*,3@R,"\Q,B\V"C$X,C$O,3(O-@HQ.#(R+S8O-@HQ
M.#(S+S$Q+S8*,3@R-"\Q,"\V"C$X,C4O,3`O-@HQ.#(V+S$R+S8*,3@R-R\Q
M,B\V"C$X,C@O,3$O-@HQ.#(Y+S@O-@HQ.#,P+S$P+S8*,3@S,2\Q,"\V"C$X
M,S(O,3(O-@HQ.#,S+S8O-@HQ.#,T+S$Q+S8*,3@S-2\X+S8*,3@S-B\Q,"\V
M"C$X,S<O,3(O-@HQ.#,X+S$R+S8*,3@S.2\V+S8*,3@T,"\X+S8*,3@T,2\Q
M,"\V"C$X-#(O,3`O-@HQ.#0S+S$R+S8*,3@T-"\V+S8*,3@T-2\Q,2\V"C$X
M-#8O."\V"C$X-#<O,3`O-@HQ.#0X+S$R+S8*,3@T.2\Q,B\V"C$X-3`O-B\V
M"C$X-3$O,3$O-@HQ.#4R+S$P+S8*,3@U,R\Q,"\V"C$X-30O,3(O-@HQ.#4U
M+S$R+S8*,3@U-B\Q,2\V"C$X-3<O."\V"C$X-3@O,3`O-@HQ.#4Y+S$P+S8*
M,3@V,"\Q,B\V"C$X-C$O-B\V"C$X-C(O,3$O-@HQ.#8S+S@O-@HQ.#8T+S$P
M+S8*,3@V-2\Q,B\V"C$X-C8O,3(O-@HQ.#8W+S8O-@HQ.#8X+S@O-@HQ.#8Y
M+S$P+S8*,3@W,"\Q,"\V"C$X-S$O,3(O-@HQ.#<R+S8O-@HQ.#<S+S$Q+S8*
M,3@W-"\X+S8*,3@W-2\Q,"\V"C$X-S8O,3(O-@HQ.#<W+S$R+S8*,3@W."\V
M+S8*,3@W.2\Q,2\V"C$X.#`O,3`O-@HQ.#@Q+S$P+S8*,3@X,B\Q,B\V"C$X
M.#,O,3(O-@HQ.#@T+S$Q+S8*,3@X-2\X+S8*,3@X-B\Q,"\V"C$X.#<O,3`O
M-@HQ.#@X+S$R+S8*,3@X.2\V+S8*,3@Y,"\Q,2\V"C$X.3$O."\V"C$X.3(O
M,3`O-@HQ.#DS+S$R+S8*,3@Y-"\Q,B\V"C$X.34O-B\V"C$X.38O."\V"C$X
M.3<O,3`O-@HQ.#DX+S$P+S8*,3@Y.2\Q,B\V"C$Y,#`O,3(O-@HQ.3`Q+S8O
M-@HQ.3`R+S$Q+S8*,3DP,R\X+S8*,3DP-"\Q,"\V"C$Y,#4O,3(O-@HQ.3`V
M+S$R+S8*,3DP-R\V+S8*,3DP."\X+S8*,3DP.2\Q,"\V"C$Y,3`O,3`O-@HQ
M.3$Q+S$R+S8*,3DQ,B\V+S8*,3DQ,R\Q,2\V"C$Y,30O."\V"C$Y,34O,3`O
M-@HQ.3$V+S$R+S8*,3DQ-R\Q,B\V"C$Y,3@O-B\V"C$Y,3DO,3$O-@HQ.3(P
M+S$P+S8*,3DR,2\Q,"\V"C$Y,C(O,3(O-@HQ.3(S+S$R+S8*,3DR-"\Q,2\V
M"C$Y,C4O."\V"C$Y,C8O,3`O-@HQ.3(W+S$P+S8*,3DR."\Q,B\V"C$Y,CDO
M-B\V"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1A=&4O=&5S=',O=VMN;W1E<W0N='AT````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,C`W,#0@,3`U,34T,S0Q,S4@,#(T,C8V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#$Y.3DQ,C(W.C$Y.3DM
M-3(M,0HQ.3DY,3(R.#HQ.3DY+34R+3(*,3DY.3$R,CDZ,3DY.2TU,BTS"C$Y
M.3DQ,C,P.C$Y.3DM-3(M-`HQ.3DY,3(S,3HQ.3DY+34R+34*,C`P,#`Q,#$Z
M,3DY.2TU,BTV"C(P,#`P,3`R.C$Y.3DM-3(M-PHR,#`P,#$P,SHR,#`P+3`Q
M+3$*,C`P,#`Q,#0Z,C`P,"TP,2TR"C(P,#`P,3`U.C(P,#`M,#$M,PHR,#`P
M,#$P-CHR,#`P+3`Q+30*,C`P,#`Q,#<Z,C`P,"TP,2TU"C(P,#`P,3`X.C(P
M,#`M,#$M-@HR,#`P,#$P.3HR,#`P+3`Q+3<*,C`P,#$R,C4Z,C`P,"TU,BTQ
M"C(P,#`Q,C(V.C(P,#`M-3(M,@HR,#`P,3(R-SHR,#`P+34R+3,*,C`P,#$R
M,C@Z,C`P,"TU,BTT"C(P,#`Q,C(Y.C(P,#`M-3(M-0HR,#`P,3(S,#HR,#`P
M+34R+38*,C`P,#$R,S$Z,C`P,"TU,BTW"C(P,#$P,3`Q.C(P,#$M,#$M,0HR
M,#`Q,#$P,CHR,#`Q+3`Q+3(*,C`P,3`Q,#,Z,C`P,2TP,2TS"C(P,#$P,3`T
M.C(P,#$M,#$M-`HR,#`Q,#$P-3HR,#`Q+3`Q+34*,C`P,3`Q,#8Z,C`P,2TP
M,2TV"C(P,#$P,3`W.C(P,#$M,#$M-PHR,#`Q,3(R-#HR,#`Q+34R+3$*,C`P
M,3$R,C4Z,C`P,2TU,BTR"C(P,#$Q,C(V.C(P,#$M-3(M,PHR,#`Q,3(R-SHR
M,#`Q+34R+30*,C`P,3$R,C@Z,C`P,2TU,BTU"C(P,#$Q,C(Y.C(P,#$M-3(M
M-@HR,#`Q,3(S,#HR,#`Q+34R+3<*,C`P,3$R,S$Z,C`P,BTP,2TQ"C(P,#(P
M,3`Q.C(P,#(M,#$M,@HR,#`R,#$P,CHR,#`R+3`Q+3,*,C`P,C`Q,#,Z,C`P
M,BTP,2TT"C(P,#(P,3`T.C(P,#(M,#$M-0HR,#`R,#$P-3HR,#`R+3`Q+38*
M,C`P,C`Q,#8Z,C`P,BTP,2TW"C(P,#(Q,C(S.C(P,#(M-3(M,0HR,#`R,3(R
M-#HR,#`R+34R+3(*,C`P,C$R,C4Z,C`P,BTU,BTS"C(P,#(Q,C(V.C(P,#(M
M-3(M-`HR,#`R,3(R-SHR,#`R+34R+34*,C`P,C$R,C@Z,C`P,BTU,BTV"C(P
M,#(Q,C(Y.C(P,#(M-3(M-PHR,#`R,3(S,#HR,#`S+3`Q+3$*,C`P,C$R,S$Z
M,C`P,RTP,2TR"C(P,#,P,3`Q.C(P,#,M,#$M,PHR,#`S,#$P,CHR,#`S+3`Q
M+30*,C`P,S`Q,#,Z,C`P,RTP,2TU"C(P,#,P,3`T.C(P,#,M,#$M-@HR,#`S
M,#$P-3HR,#`S+3`Q+3<*,C`P,S$R,C(Z,C`P,RTU,BTQ"C(P,#,Q,C(S.C(P
M,#,M-3(M,@HR,#`S,3(R-#HR,#`S+34R+3,*,C`P,S$R,C4Z,C`P,RTU,BTT
M"C(P,#,Q,C(V.C(P,#,M-3(M-0HR,#`S,3(R-SHR,#`S+34R+38*,C`P,S$R
M,C@Z,C`P,RTU,BTW"C(P,#,Q,C(Y.C(P,#0M,#$M,0HR,#`S,3(S,#HR,#`T
M+3`Q+3(*,C`P,S$R,S$Z,C`P-"TP,2TS"C(P,#0P,3`Q.C(P,#0M,#$M-`HR
M,#`T,#$P,CHR,#`T+3`Q+34*,C`P-#`Q,#,Z,C`P-"TP,2TV"C(P,#0P,3`T
M.C(P,#0M,#$M-PHR,#`T,3(R,#HR,#`T+34R+3$*,C`P-#$R,C$Z,C`P-"TU
M,BTR"C(P,#0Q,C(R.C(P,#0M-3(M,PHR,#`T,3(R,SHR,#`T+34R+30*,C`P
M-#$R,C0Z,C`P-"TU,BTU"C(P,#0Q,C(U.C(P,#0M-3(M-@HR,#`T,3(R-CHR
M,#`T+34R+3<*,C`P-#$R,C<Z,C`P-"TU,RTQ"C(P,#0Q,C(X.C(P,#0M-3,M
M,@HR,#`T,3(R.3HR,#`T+34S+3,*,C`P-#$R,S`Z,C`P-"TU,RTT"C(P,#0Q
M,C,Q.C(P,#0M-3,M-0HR,#`U,#$P,3HR,#`T+34S+38*,C`P-3`Q,#(Z,C`P
M-"TU,RTW"C(P,#4P,3`S.C(P,#4M,#$M,0HR,#`U,#$P-#HR,#`U+3`Q+3(*
M,C`P-3`Q,#4Z,C`P-2TP,2TS"C(P,#4P,3`V.C(P,#4M,#$M-`HR,#`U,#$P
M-SHR,#`U+3`Q+34*,C`P-3`Q,#@Z,C`P-2TP,2TV"C(P,#4P,3`Y.C(P,#4M
M,#$M-PHR,#`U,3(R-CHR,#`U+34R+3$*,C`P-3$R,C<Z,C`P-2TU,BTR"C(P
M,#4Q,C(X.C(P,#4M-3(M,PHR,#`U,3(R.3HR,#`U+34R+30*,C`P-3$R,S`Z
M,C`P-2TU,BTU"C(P,#4Q,C,Q.C(P,#4M-3(M-@HR,#`V,#$P,3HR,#`U+34R
M+3<*,C`P-C`Q,#(Z,C`P-BTP,2TQ"C(P,#8P,3`S.C(P,#8M,#$M,@HR,#`V
M,#$P-#HR,#`V+3`Q+3,*,C`P-C`Q,#4Z,C`P-BTP,2TT"C(P,#8P,3`V.C(P
M,#8M,#$M-0HR,#`V,#$P-SHR,#`V+3`Q+38*,C`P-C`Q,#@Z,C`P-BTP,2TW
M"C(P,#8Q,C(U.C(P,#8M-3(M,0HR,#`V,3(R-CHR,#`V+34R+3(*,C`P-C$R
M,C<Z,C`P-BTU,BTS"C(P,#8Q,C(X.C(P,#8M-3(M-`HR,#`V,3(R.3HR,#`V
M+34R+34*,C`P-C$R,S`Z,C`P-BTU,BTV"C(P,#8Q,C,Q.C(P,#8M-3(M-PHR
M,#`W,#$P,3HR,#`W+3`Q+3$*,C`P-S`Q,#(Z,C`P-RTP,2TR"C(P,#<P,3`S
M.C(P,#<M,#$M,PHR,#`W,#$P-#HR,#`W+3`Q+30*,C`P-S`Q,#4Z,C`P-RTP
M,2TU"C(P,#<P,3`V.C(P,#<M,#$M-@HR,#`W,#$P-SHR,#`W+3`Q+3<*,C`P
M-S$R,C0Z,C`P-RTU,BTQ"C(P,#<Q,C(U.C(P,#<M-3(M,@HR,#`W,3(R-CHR
M,#`W+34R+3,*,C`P-S$R,C<Z,C`P-RTU,BTT"C(P,#<Q,C(X.C(P,#<M-3(M
M-0HR,#`W,3(R.3HR,#`W+34R+38*,C`P-S$R,S`Z,C`P-RTU,BTW"C(P,#<Q
M,C,Q.C(P,#@M,#$M,0HR,#`X,#$P,3HR,#`X+3`Q+3(*,C`P.#`Q,#(Z,C`P
M."TP,2TS"C(P,#@P,3`S.C(P,#@M,#$M-`HR,#`X,#$P-#HR,#`X+3`Q+34*
M,C`P.#`Q,#4Z,C`P."TP,2TV"C(P,#@P,3`V.C(P,#@M,#$M-PHR,#`X,3(R
M,CHR,#`X+34R+3$*,C`P.#$R,C,Z,C`P."TU,BTR"C(P,#@Q,C(T.C(P,#@M
M-3(M,PHR,#`X,3(R-3HR,#`X+34R+30*,C`P.#$R,C8Z,C`P."TU,BTU"C(P
M,#@Q,C(W.C(P,#@M-3(M-@HR,#`X,3(R.#HR,#`X+34R+3<*,C`P.#$R,CDZ
M,C`P.2TP,2TQ"C(P,#@Q,C,P.C(P,#DM,#$M,@HR,#`X,3(S,3HR,#`Y+3`Q
M+3,*,C`P.3`Q,#$Z,C`P.2TP,2TT"C(P,#DP,3`R.C(P,#DM,#$M-0HR,#`Y
M,#$P,SHR,#`Y+3`Q+38*,C`P.3`Q,#0Z,C`P.2TP,2TW"C(P,#DQ,C(Q.C(P
M,#DM-3(M,0HR,#`Y,3(R,CHR,#`Y+34R+3(*,C`P.3$R,C,Z,C`P.2TU,BTS
M"C(P,#DQ,C(T.C(P,#DM-3(M-`HR,#`Y,3(R-3HR,#`Y+34R+34*,C`P.3$R
M,C8Z,C`P.2TU,BTV"C(P,#DQ,C(W.C(P,#DM-3(M-PHR,#`Y,3(R.#HR,#`Y
M+34S+3$*,C`P.3$R,CDZ,C`P.2TU,RTR"C(P,#DQ,C,P.C(P,#DM-3,M,PHR
M,#`Y,3(S,3HR,#`Y+34S+30*,C`Q,#`Q,#$Z,C`P.2TU,RTU"C(P,3`P,3`R
M.C(P,#DM-3,M-@HR,#$P,#$P,SHR,#`Y+34S+3<*,C`Q,#`Q,#0Z,C`Q,"TP
M,2TQ"C(P,3`P,3`U.C(P,3`M,#$M,@HR,#$P,#$P-CHR,#$P+3`Q+3,*,C`Q
M,#`Q,#<Z,C`Q,"TP,2TT"C(P,3`P,3`X.C(P,3`M,#$M-0HR,#$P,#$P.3HR
M,#$P+3`Q+38*,C`Q,#`Q,3`Z,C`Q,"TP,2TW"C(P,3`Q,C(W.C(P,3`M-3(M
M,0HR,#$P,3(R.#HR,#$P+34R+3(*,C`Q,#$R,CDZ,C`Q,"TU,BTS"C(P,3`Q
M,C,P.C(P,3`M-3(M-`HR,#$P,3(S,3HR,#$P+34R+34*,C`Q,3`Q,#$Z,C`Q
M,"TU,BTV"C(P,3$P,3`R.C(P,3`M-3(M-PHR,#$Q,#$P,SHR,#$Q+3`Q+3$*
M,C`Q,3`Q,#0Z,C`Q,2TP,2TR"C(P,3$P,3`U.C(P,3$M,#$M,PHR,#$Q,#$P
M-CHR,#$Q+3`Q+30*,C`Q,3`Q,#<Z,C`Q,2TP,2TU"C(P,3$P,3`X.C(P,3$M
M,#$M-@HR,#$Q,#$P.3HR,#$Q+3`Q+3<*,C`Q,3$R,C8Z,C`Q,2TU,BTQ"C(P
M,3$Q,C(W.C(P,3$M-3(M,@HR,#$Q,3(R.#HR,#$Q+34R+3,*,C`Q,3$R,CDZ
M,C`Q,2TU,BTT"C(P,3$Q,C,P.C(P,3$M-3(M-0HR,#$Q,3(S,3HR,#$Q+34R
M+38*,C`Q,C`Q,#$Z,C`Q,2TU,BTW"C(P,3(P,3`R.C(P,3(M,#$M,0HR,#$R
M,#$P,SHR,#$R+3`Q+3(*,C`Q,C`Q,#0Z,C`Q,BTP,2TS"C(P,3(P,3`U.C(P
M,3(M,#$M-`HR,#$R,#$P-CHR,#$R+3`Q+34*,C`Q,C`Q,#<Z,C`Q,BTP,2TV
M"C(P,3(P,3`X.C(P,3(M,#$M-PHR,#$R,3(R-#HR,#$R+34R+3$*,C`Q,C$R
M,C4Z,C`Q,BTU,BTR"C(P,3(Q,C(V.C(P,3(M-3(M,PHR,#$R,3(R-SHR,#$R
M+34R+30*,C`Q,C$R,C@Z,C`Q,BTU,BTU"C(P,3(Q,C(Y.C(P,3(M-3(M-@HR
M,#$R,3(S,#HR,#$R+34R+3<*,C`Q,C$R,S$Z,C`Q,RTP,2TQ"C(P,3,P,3`Q
M.C(P,3,M,#$M,@HR,#$S,#$P,CHR,#$S+3`Q+3,*,C`Q,S`Q,#,Z,C`Q,RTP
M,2TT"C(P,3,P,3`T.C(P,3,M,#$M-0HR,#$S,#$P-3HR,#$S+3`Q+38*,C`Q
M,S`Q,#8Z,C`Q,RTP,2TW"C(P,3,Q,C(S.C(P,3,M-3(M,0HR,#$S,3(R-#HR
M,#$S+34R+3(*,C`Q,S$R,C4Z,C`Q,RTU,BTS"C(P,3,Q,C(V.C(P,3,M-3(M
M-`HR,#$S,3(R-SHR,#$S+34R+34*,C`Q,S$R,C@Z,C`Q,RTU,BTV"C(P,3,Q
M,C(Y.C(P,3,M-3(M-PHR,#$S,3(S,#HR,#$T+3`Q+3$*,C`Q,S$R,S$Z,C`Q
M-"TP,2TR"C(P,30P,3`Q.C(P,30M,#$M,PHR,#$T,#$P,CHR,#$T+3`Q+30*
M,C`Q-#`Q,#,Z,C`Q-"TP,2TU"C(P,30P,3`T.C(P,30M,#$M-@HR,#$T,#$P
M-3HR,#$T+3`Q+3<*,C`Q-#$R,C(Z,C`Q-"TU,BTQ"C(P,30Q,C(S.C(P,30M
M-3(M,@HR,#$T,3(R-#HR,#$T+34R+3,*,C`Q-#$R,C4Z,C`Q-"TU,BTT"C(P
M,30Q,C(V.C(P,30M-3(M-0HR,#$T,3(R-SHR,#$T+34R+38*,C`Q-#$R,C@Z
M,C`Q-"TU,BTW"C(P,30Q,C(Y.C(P,34M,#$M,0HR,#$T,3(S,#HR,#$U+3`Q
M+3(*,C`Q-#$R,S$Z,C`Q-2TP,2TS"C(P,34P,3`Q.C(P,34M,#$M-`HR,#$U
M,#$P,CHR,#$U+3`Q+34*,C`Q-3`Q,#,Z,C`Q-2TP,2TV"C(P,34P,3`T.C(P
M,34M,#$M-PHR,#$U,3(R,3HR,#$U+34R+3$*,C`Q-3$R,C(Z,C`Q-2TU,BTR
M"C(P,34Q,C(S.C(P,34M-3(M,PHR,#$U,3(R-#HR,#$U+34R+30*,C`Q-3$R
M,C4Z,C`Q-2TU,BTU"C(P,34Q,C(V.C(P,34M-3(M-@HR,#$U,3(R-SHR,#$U
M+34R+3<*,C`Q-3$R,C@Z,C`Q-2TU,RTQ"C(P,34Q,C(Y.C(P,34M-3,M,@HR
M,#$U,3(S,#HR,#$U+34S+3,*,C`Q-3$R,S$Z,C`Q-2TU,RTT"C(P,38P,3`Q
M.C(P,34M-3,M-0HR,#$V,#$P,CHR,#$U+34S+38*,C`Q-C`Q,#,Z,C`Q-2TU
M,RTW"C(P,38P,3`T.C(P,38M,#$M,0HR,#$V,#$P-3HR,#$V+3`Q+3(*,C`Q
M-C`Q,#8Z,C`Q-BTP,2TS"C(P,38P,3`W.C(P,38M,#$M-`HR,#$V,#$P.#HR
M,#$V+3`Q+34*,C`Q-C`Q,#DZ,C`Q-BTP,2TV"C(P,38P,3$P.C(P,38M,#$M
M-PHR,#$V,3(R-CHR,#$V+34R+3$*,C`Q-C$R,C<Z,C`Q-BTU,BTR"C(P,38Q
M,C(X.C(P,38M-3(M,PHR,#$V,3(R.3HR,#$V+34R+30*,C`Q-C$R,S`Z,C`Q
M-BTU,BTU"C(P,38Q,C,Q.C(P,38M-3(M-@HR,#$W,#$P,3HR,#$V+34R+3<*
M,C`Q-S`Q,#(Z,C`Q-RTP,2TQ"C(P,3<P,3`S.C(P,3<M,#$M,@HR,#$W,#$P
M-#HR,#$W+3`Q+3,*,C`Q-S`Q,#4Z,C`Q-RTP,2TT"C(P,3<P,3`V.C(P,3<M
M,#$M-0HR,#$W,#$P-SHR,#$W+3`Q+38*,C`Q-S`Q,#@Z,C`Q-RTP,2TW"C(P
M,3<Q,C(U.C(P,3<M-3(M,0HR,#$W,3(R-CHR,#$W+34R+3(*,C`Q-S$R,C<Z
M,C`Q-RTU,BTS"C(P,3<Q,C(X.C(P,3<M-3(M-`HR,#$W,3(R.3HR,#$W+34R
M+34*,C`Q-S$R,S`Z,C`Q-RTU,BTV"C(P,3<Q,C,Q.C(P,3<M-3(M-PHR,#$X
M,#$P,3HR,#$X+3`Q+3$*,C`Q.#`Q,#(Z,C`Q."TP,2TR"C(P,3@P,3`S.C(P
M,3@M,#$M,PHR,#$X,#$P-#HR,#$X+3`Q+30*,C`Q.#`Q,#4Z,C`Q."TP,2TU
M"C(P,3@P,3`V.C(P,3@M,#$M-@HR,#$X,#$P-SHR,#$X+3`Q+3<*,C`Q.#$R
M,C0Z,C`Q."TU,BTQ"C(P,3@Q,C(U.C(P,3@M-3(M,@HR,#$X,3(R-CHR,#$X
M+34R+3,*,C`Q.#$R,C<Z,C`Q."TU,BTT"C(P,3@Q,C(X.C(P,3@M-3(M-0HR
M,#$X,3(R.3HR,#$X+34R+38*,C`Q.#$R,S`Z,C`Q."TU,BTW"C(P,3@Q,C,Q
M.C(P,3DM,#$M,0HR,#$Y,#$P,3HR,#$Y+3`Q+3(*,C`Q.3`Q,#(Z,C`Q.2TP
M,2TS"C(P,3DP,3`S.C(P,3DM,#$M-`HR,#$Y,#$P-#HR,#$Y+3`Q+34*,C`Q
M.3`Q,#4Z,C`Q.2TP,2TV"C(P,3DP,3`V.C(P,3DM,#$M-PHR,#$Y,3(R,SHR
M,#$Y+34R+3$*,C`Q.3$R,C0Z,C`Q.2TU,BTR"C(P,3DQ,C(U.C(P,3DM-3(M
M,PHR,#$Y,3(R-CHR,#$Y+34R+30*,C`Q.3$R,C<Z,C`Q.2TU,BTU"C(P,3DQ
M,C(X.C(P,3DM-3(M-@HR,#$Y,3(R.3HR,#$Y+34R+3<*,C`Q.3$R,S`Z,C`R
M,"TP,2TQ"C(P,3DQ,C,Q.C(P,C`M,#$M,@HR,#(P,#$P,3HR,#(P+3`Q+3,*
M,C`R,#`Q,#(Z,C`R,"TP,2TT"C(P,C`P,3`S.C(P,C`M,#$M-0HR,#(P,#$P
M-#HR,#(P+3`Q+38*,C`R,#`Q,#4Z,C`R,"TP,2TW"C(P,C`Q,C(Q.C(P,C`M
M-3(M,0HR,#(P,3(R,CHR,#(P+34R+3(*,C`R,#$R,C,Z,C`R,"TU,BTS"C(P
M,C`Q,C(T.C(P,C`M-3(M-`HR,#(P,3(R-3HR,#(P+34R+34*,C`R,#$R,C8Z
M,C`R,"TU,BTV"C(P,C`Q,C(W.C(P,C`M-3(M-PHR,#(P,3(R.#HR,#(P+34S
M+3$*,C`R,#$R,CDZ,C`R,"TU,RTR"C(P,C`Q,C,P.C(P,C`M-3,M,PHR,#(P
M,3(S,3HR,#(P+34S+30*,C`R,3`Q,#$Z,C`R,"TU,RTU"C(P,C$P,3`R.C(P
M,C`M-3,M-@HR,#(Q,#$P,SHR,#(P+34S+3<*,C`R,3`Q,#0Z,C`R,2TP,2TQ
M"C(P,C$P,3`U.C(P,C$M,#$M,@HR,#(Q,#$P-CHR,#(Q+3`Q+3,*,C`R,3`Q
M,#<Z,C`R,2TP,2TT"C(P,C$P,3`X.C(P,C$M,#$M-0HR,#(Q,#$P.3HR,#(Q
M+3`Q+38*,C`R,3`Q,3`Z,C`R,2TP,2TW"C(P,C$Q,C(W.C(P,C$M-3(M,0HR
M,#(Q,3(R.#HR,#(Q+34R+3(*,C`R,3$R,CDZ,C`R,2TU,BTS"C(P,C$Q,C,P
M.C(P,C$M-3(M-`HR,#(Q,3(S,3HR,#(Q+34R+34*,C`R,C`Q,#$Z,C`R,2TU
M,BTV"C(P,C(P,3`R.C(P,C$M-3(M-PHR,#(R,#$P,SHR,#(R+3`Q+3$*,C`R
M,C`Q,#0Z,C`R,BTP,2TR"C(P,C(P,3`U.C(P,C(M,#$M,PHR,#(R,#$P-CHR
M,#(R+3`Q+30*,C`R,C`Q,#<Z,C`R,BTP,2TU"C(P,C(P,3`X.C(P,C(M,#$M
M-@HR,#(R,#$P.3HR,#(R+3`Q+3<*,C`R,C$R,C8Z,C`R,BTU,BTQ"C(P,C(Q
M,C(W.C(P,C(M-3(M,@HR,#(R,3(R.#HR,#(R+34R+3,*,C`R,C$R,CDZ,C`R
M,BTU,BTT"C(P,C(Q,C,P.C(P,C(M-3(M-0HR,#(R,3(S,3HR,#(R+34R+38*
M,C`R,S`Q,#$Z,C`R,BTU,BTW"C(P,C,P,3`R.C(P,C,M,#$M,0HR,#(S,#$P
M,SHR,#(S+3`Q+3(*,C`R,S`Q,#0Z,C`R,RTP,2TS"C(P,C,P,3`U.C(P,C,M
M,#$M-`HR,#(S,#$P-CHR,#(S+3`Q+34*,C`R,S`Q,#<Z,C`R,RTP,2TV"C(P
M,C,P,3`X.C(P,C,M,#$M-PHR,#(S,3(R-3HR,#(S+34R+3$*,C`R,S$R,C8Z
M,C`R,RTU,BTR"C(P,C,Q,C(W.C(P,C,M-3(M,PHR,#(S,3(R.#HR,#(S+34R
M+30*,C`R,S$R,CDZ,C`R,RTU,BTU"C(P,C,Q,C,P.C(P,C,M-3(M-@HR,#(S
M,3(S,3HR,#(S+34R+3<*,C`R-#`Q,#$Z,C`R-"TP,2TQ"C(P,C0P,3`R.C(P
M,C0M,#$M,@HR,#(T,#$P,SHR,#(T+3`Q+3,*,C`R-#`Q,#0Z,C`R-"TP,2TT
M"C(P,C0P,3`U.C(P,C0M,#$M-0HR,#(T,#$P-CHR,#(T+3`Q+38*,C`R-#`Q
M,#<Z,C`R-"TP,2TW"C(P,C0Q,C(S.C(P,C0M-3(M,0HR,#(T,3(R-#HR,#(T
M+34R+3(*,C`R-#$R,C4Z,C`R-"TU,BTS"C(P,C0Q,C(V.C(P,C0M-3(M-`HR
M,#(T,3(R-SHR,#(T+34R+34*,C`R-#$R,C@Z,C`R-"TU,BTV"C(P,C0Q,C(Y
M.C(P,C0M-3(M-PHR,#(T,3(S,#HR,#(U+3`Q+3$*,C`R-#$R,S$Z,C`R-2TP
M,2TR"C(P,C4P,3`Q.C(P,C4M,#$M,PHR,#(U,#$P,CHR,#(U+3`Q+30*,C`R
M-3`Q,#,Z,C`R-2TP,2TU"C(P,C4P,3`T.C(P,C4M,#$M-@HR,#(U,#$P-3HR
M,#(U+3`Q+3<*,C`R-3$R,C(Z,C`R-2TU,BTQ"C(P,C4Q,C(S.C(P,C4M-3(M
M,@HR,#(U,3(R-#HR,#(U+34R+3,*,C`R-3$R,C4Z,C`R-2TU,BTT"C(P,C4Q
M,C(V.C(P,C4M-3(M-0HR,#(U,3(R-SHR,#(U+34R+38*,C`R-3$R,C@Z,C`R
M-2TU,BTW"C(P,C4Q,C(Y.C(P,C8M,#$M,0HR,#(U,3(S,#HR,#(V+3`Q+3(*
M,C`R-3$R,S$Z,C`R-BTP,2TS"C(P,C8P,3`Q.C(P,C8M,#$M-`HR,#(V,#$P
M,CHR,#(V+3`Q+34*,C`R-C`Q,#,Z,C`R-BTP,2TV"C(P,C8P,3`T.C(P,C8M
M,#$M-PHR,#(V,3(R,3HR,#(V+34R+3$*,C`R-C$R,C(Z,C`R-BTU,BTR"C(P
M,C8Q,C(S.C(P,C8M-3(M,PHR,#(V,3(R-#HR,#(V+34R+30*,C`R-C$R,C4Z
M,C`R-BTU,BTU"C(P,C8Q,C(V.C(P,C8M-3(M-@HR,#(V,3(R-SHR,#(V+34R
M+3<*,C`R-C$R,C@Z,C`R-BTU,RTQ"C(P,C8Q,C(Y.C(P,C8M-3,M,@HR,#(V
M,3(S,#HR,#(V+34S+3,*,C`R-C$R,S$Z,C`R-BTU,RTT"C(P,C<P,3`Q.C(P
M,C8M-3,M-0HR,#(W,#$P,CHR,#(V+34S+38*,C`R-S`Q,#,Z,C`R-BTU,RTW
M"C(P,C<P,3`T.C(P,C<M,#$M,0HR,#(W,#$P-3HR,#(W+3`Q+3(*,C`R-S`Q
M,#8Z,C`R-RTP,2TS"C(P,C<P,3`W.C(P,C<M,#$M-`HR,#(W,#$P.#HR,#(W
M+3`Q+34*,C`R-S`Q,#DZ,C`R-RTP,2TV"C(P,C<P,3$P.C(P,C<M,#$M-PHR
M,#(W,3(R-SHR,#(W+34R+3$*,C`R-S$R,C@Z,C`R-RTU,BTR"C(P,C<Q,C(Y
M.C(P,C<M-3(M,PHR,#(W,3(S,#HR,#(W+34R+30*,C`R-S$R,S$Z,C`R-RTU
M,BTU"C(P,C@P,3`Q.C(P,C<M-3(M-@HR,#(X,#$P,CHR,#(W+34R+3<*,C`R
M.#`Q,#,Z,C`R."TP,2TQ"C(P,C@P,3`T.C(P,C@M,#$M,@HR,#(X,#$P-3HR
M,#(X+3`Q+3,*,C`R.#`Q,#8Z,C`R."TP,2TT"C(P,C@P,3`W.C(P,C@M,#$M
M-0HR,#(X,#$P.#HR,#(X+3`Q+38*,C`R.#`Q,#DZ,C`R."TP,2TW"C(P,C@Q
M,C(U.C(P,C@M-3(M,0HR,#(X,3(R-CHR,#(X+34R+3(*,C`R.#$R,C<Z,C`R
M."TU,BTS"C(P,C@Q,C(X.C(P,C@M-3(M-`HR,#(X,3(R.3HR,#(X+34R+34*
M,C`R.#$R,S`Z,C`R."TU,BTV"C(P,C@Q,C,Q.C(P,C@M-3(M-PHR,#(Y,#$P
M,3HR,#(Y+3`Q+3$*,C`R.3`Q,#(Z,C`R.2TP,2TR"C(P,CDP,3`S.C(P,CDM
M,#$M,PHR,#(Y,#$P-#HR,#(Y+3`Q+30*,C`R.3`Q,#4Z,C`R.2TP,2TU"C(P
M,CDP,3`V.C(P,CDM,#$M-@HR,#(Y,#$P-SHR,#(Y+3`Q+3<`````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1A=&4O
M=&5S=',O8G5G-C<T+G!H<```````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(S-S0@,3`U,34T,S0Q,S4@,#(S-#`Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"G)E<75I<F5?;VYC92`G1&%T
M92YP:'`G.PHD97)R;W(@/2!F86QS93L*)&1A=&5S(#T@87)R87D@*`H@("`@
M87)R87DH(&%R<F%Y*#(P,#,L,RPQ-RDL)S(P,#,P,S(S)RPG,C`P,S`S,3<G
M+"<R,#`S,#,R-"<L)S(P,#,P,S$P)RDL"B`@("!A<G)A>2@@87)R87DH,C`P
M,RPS+#(P*2PG,C`P,S`S,C,G+"<R,#`S,#,Q-R<L)S(P,#,P,S(T)RPG,C`P
M,S`S,3`G*2P*("`@(&%R<F%Y*"!A<G)A>2@R,#`S+#,L,C,I+"<R,#`S,#,R
M,R<L)S(P,#,P,S$W)RPG,C`P,S`S,C0G+"<R,#`S,#,Q,"<I"BD["F9O<F5A
M8V@@*"1D871E<R!A<R`D9"D@>PH@("`@)&1A=&4@/2`D9%LP73L*("`@("1R
M97,@/2!$871E7T-A;&,Z.F5N9$]F5V5E:R@D9&%T95LR72PD9&%T95LQ72PD
M9&%T95LP72D["B`@("!I9B`H)')E<R$])&1;,5TI('L*("`@("`@("!E8VAO
M(")"=6<@-C<T(&5O=SH@(B`N("1D871E6S!=+B1D871E6S%=+B1D871E6S)=
M+B(@9F%I;&5D7&XB.PH@("`@("`@("1E<G)O<B`]('1R=64["B`@("!]"GT*
M"F9O<F5A8V@@*"1D871E<R!A<R`D9"D@>PH@("`@)&1A=&4@/2`D9%LP73L*
M("`@("1R97,@/2!$871E7T-A;&,Z.F)E9VEN3V97965K*"1D871E6S)=+"1D
M871E6S%=+"1D871E6S!=*3L*("`@(&EF("@D<F5S(3TD9%LR72D@>PH@("`@
M("`@(&5C:&\@(D)U9R`V-S0@8F]W.B`B("X@)&1A=&5;,%TN)&1A=&5;,5TN
M)&1A=&5;,ETN(B!F86EL961<;B(["B`@("`@("`@)&5R<F]R(#T@=')U93L*
M("`@('T*?0H*"F9O<F5A8V@@*"1D871E<R!A<R`D9"D@>PH@("`@)&1A=&4@
M/2`D9%LP73L*("`@("1R97,@/2!$871E7T-A;&,Z.F)E9VEN3V9.97AT5V5E
M:R@D9&%T95LR72PD9&%T95LQ72PD9&%T95LP72D["B`@("!I9B`H)')E<R$]
M)&1;,UTI('L*("`@("`@("!E8VAO(")"=6<@-C<T(&)O;G<Z("(@+B`D9&%T
M95LP72XD9&%T95LQ72XD9&%T95LR72XB(&9A:6QE9%QN(CL*("`@("`@("`D
M97)R;W(@/2!T<G5E.PH@("`@?0I]"@H*9F]R96%C:"`H)&1A=&5S(&%S("1D
M*2!["B`@("`D9&%T92`]("1D6S!=.PH@("`@)')E<R`]($1A=&5?0V%L8SHZ
M8F5G:6Y/9E!R9797965K*"1D871E6S)=+"1D871E6S%=+"1D871E6S!=*3L*
M("`@(&EF("@D<F5S(3TD9%LT72D@>PH@("`@("`@(&5C:&\@(D)U9R`V-S0@
M8F]P=SH@(B`N("1D871E6S!=+B1D871E6S%=+B1D871E6S)=+B(@9F%I;&5D
M7&XB.PH@("`@("`@("1E<G)O<B`]('1R=64["B`@("!]"GT*"FEF("@A)&5R
M<F]R*2!["B`@("!E8VAO(")"=6<@-C<T.B!/2UQN(CL*?0H*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1&%T92]T97-T<R]B=6<W,C=?,2YP:'``````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C`V,"`Q,#4Q-30S-#$S-2`P,C,V
M,3``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH*("H@5&5S=',@9F]R('=E96MS26Y-;VYT:"P@9F5B<G5A<GD@
M=VET:"`T('=E96MS"B`J($UO;F1A>2!A<R`Q<W0@9&%Y(&]F('=E96L*("HO
M"F1E9FEN92@G1$%415]#04Q#7T)%1TE.7U=%14M$05DG+"`Q*3L*<F5Q=6ER
M95]O;F-E(")$871E+T-A;&,N<&AP(CL*"B\J*@H@*B!497-T(&1A=&5S(&9R
M;VT@,3DW,"!T;R`R,#(Y"B`J($1A=&$@9G)O;3H@:'1T<#HO+W=W=RYM97)L
M>6XN9&5M;VXN8V\N=6LO=VMN;W1E<W0N='AT"B`J($]T:&5R<R!U<V5F=6QL
M(&1A=&%S(&%V86EL86)L92!F<F]M.@H@*B!H='1P.B\O=W=W+FUE<FQY;BYD
M96UO;BYC;RYU:R\C9&%T"B`J+PHD9&%T87!A=&@@/2!D:7)N86UE*"!?7T9)
M3$5?7RD["@HD9F%I;&5D7W1E<W1?9&%T82`@(#T@9F%L<V4["B1D871E<R`@
M(#T@9FEL92@D9&%T87!A=&@@+B`G+W=E96MS:6YM;VYT:%\T7VUO;F1A>2YT
M>'0G*3L*)&-N="`@("`@/2!S:7IE;V8H)&1A=&5S*3L*)'9A;&ED<R`](&%R
M<F%Y*"D["F9O<B@@)&D],#LD:3PD8VYT.R1I*RL@*7L*("`@("1P87)T<R`@
M("`@(#T@97AP;&]D92@G+R<L)&1A=&5S6R1I72D["B`@("`D=F%L:61S6R1P
M87)T<ULP75T@/2!A<G)A>2@D<&%R='-;,5T]/BAI;G0I<W1R7W)E<&QA8V4H
M(EQN(BPG)RPD<&%R='-;,ETI*3L*?0IU;G-E="@D9&%T97,I.PIF;W)E86-H
M*"1V86QI9',@87,@)'EE87(@/3X@)&UO;G1H<RE["B`@("!F;W)E86-H("@D
M;6]N=&AS(&%S("1M;VYT:#T^)'9A;&ED7W=E96MS*2!["B`@("`@("`@)&-A
M;&-?=V5E:W,@/2!$871E7T-A;&,Z.G=E96MS26Y-;VYT:"@D;6]N=&@L)'EE
M87(I.PH@("`@("`@(&EF*"1C86QC7W=E96MS(3TD=F%L:61?=V5E:W,I>PH@
M("`@("`@("`@("`D9F%I;&5D7W1E<W1?9&%T82`@(#T@=')U93L*("`@("`@
M("`@("`@96-H;R`B0G5G(",W,C<L('!A<W,@,3H@)'EE87(O)&UO;G1H(&9A
M:6QE9"X@17AP96-T.B1V86QI9%]W965K<R!';W0Z)&-A;&-?=V5E:W-<;B([
M"B`@("`@("`@?0H@("`@?0I]"FEF("@A)&9A:6QE9%]T97-T7V1A=&$I('L*
M"65C:&\@(D)U9R`C-S(W+"!P87-S(#$Z($]+7&XB.PI]"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R],;V<O
M=&5S=',`````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,U(#`R,30S,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+TQO9R]T97-T<R]C;VUP;W-I=&4N<&AP=```````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#$T-3(@,3`U,34T,S0Q,S4@,#(T-#$Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM5$53
M5"TM"DQO9SH@0V]M<&]S:71E($AA;F1L97(*+2U&24Q%+2T*/#]P:'`*"G)E
M<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE1F]R
M;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<I.PHD8V]N<V]L93$@/2`F3&]G
M.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)T-/3E-/3$4Q)RP@)&-O;F8I
M.PHD8V]N<V]L93(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@
M)T-/3E-/3$4R)RP@)&-O;F8I.PH*)&-O;7!O<VET92`]("9,;V<Z.G-I;F=L
M971O;B@G8V]M<&]S:71E)RD["B1C;VUP;W-I=&4M/F%D9$-H:6QD*"1C;VYS
M;VQE,2D["B1C;VUP;W-I=&4M/F%D9$-H:6QD*"1C;VYS;VQE,BD["@HD8V]M
M<&]S:71E+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!L;V=G960@=&\@8F]T
M:"!H86YD;&5R<RXG*3L*"B1C;VUP;W-I=&4M/G-E=$ED96YT*"=)1$5.5"<I
M.PIE8VAO("1C;VUP;W-I=&4M/F=E=$ED96YT*"D@+B`B7&XB.PH*)&-O;7!O
M<VET92T^;&]G*"=4:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@
M:&%N9&QE<G,N)RD["@HM+4584$5#5"TM"D-/3E-/3$4Q(%MI;F9O72!4:&ES
M(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N"D-/3E-/
M3$4R(%MI;F9O72!4:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@
M:&%N9&QE<G,N"DE$14Y4"DE$14Y4(%MI;F9O72!4:&ES(&5V96YT('=I;&P@
M8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N"DE$14Y4(%MI;F9O72!4:&ES
M(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N9&QE<G,N"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]D:7-P;&%Y+G!H<'0`````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P-S(@,3`U,34T,S0Q,S4@,#(T
M,#4R`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"DQO9SH@1&ES<&QA>2!(86YD;&5R"BTM1DE,12TM"CP_<&AP
M"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G97)R
M;W)?<')E<&5N9"<@/3X@)SQT=#XG+`H@("`@("`@("`@("`@("=E<G)O<E]A
M<'!E;F0G("`]/B`G/"]T=#XG+`H@("`@("`@("`@("`@("=L:6YE8G)E86LG
M("`@("`]/B`B/&)R("\^/&)R("\^7&XB*3L*)&QO9V=E<B`]("9,;V<Z.G-I
M;F=L971O;B@G9&ES<&QA>2<L("<G+"`G)RP@)&-O;F8I.PIF;W(@*"1I(#T@
M,#L@)&D@/"`S.R`D:2LK*2!["@DD;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D
M:2(I.PI]"B1L;V=G97(M/FQO9R@B375L=&E<;DQI;F5<;D5N=')Y(BD["@HM
M+4584$5#5"TM"CQT=#X\8CY);F9O/"]B/CH@3&]G(&5N=')Y(#`\+W1T/CQB
M<B`O/CQB<B`O/@H\='0^/&(^26YF;SPO8CXZ($QO9R!E;G1R>2`Q/"]T=#X\
M8G(@+SX\8G(@+SX*/'1T/CQB/DEN9F\\+V(^.B!,;V<@96YT<GD@,CPO='0^
M/&)R("\^/&)R("\^"CQT=#X\8CY);F9O/"]B/CH@375L=&D\8G(@+SX*3&EN
M93QB<B`O/@I%;G1R>3PO='0^/&)R("\^/&)R("\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]E<G)O<E]L;V<N
M<&AP=```````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,C,@,3`U,34T,S0Q
M,S4@,#(T,S<V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"TM5$535"TM"DQO9SH@17)R;W)?3&]G($AA;F1L97(*+2U&24Q%
M+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G9V5R(#T@
M)DQO9SHZ<VEN9VQE=&]N*"=E<G)O<E]L;V<G+"!014%27TQ/1U]465!%7U-9
M4U1%32P@)VED96YT)RD["F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI('L*
M"21L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*"BTM15A014-4+2T*
M:61E;G0Z($QO9R!E;G1R>2`P"FED96YT.B!,;V<@96YT<GD@,0II9&5N=#H@
M3&]G(&5N=')Y(#(*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R],;V<O=&5S=',O97AT<F%C="YP:'!T````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R,S4Q(#$P-3$U-#,T,3,U(#`R-#`V,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````M+51%
M4U0M+0I,;V<Z(%]E>'1R86-T365S<V%G92@I(%M:96YD($5N9VEN92`Q70HM
M+5-+25!)1BTM"CP_<&AP(&EF("AV97)S:6]N7V-O;7!A<F4H>F5N9%]V97)S
M:6]N*"DL("(R+C`N,"(L("(^/2(I*2!D:64H)W-K:7`G*3L@/SX*+2U&24Q%
M+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD8V]N9B`](&%R
M<F%Y*"=L:6YE1F]R;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<I.PHD;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=I9&5N="<L
M("1C;VYF*3L*"B\J($QO9V=I;F<@82!R96=U;&%R('-T<FEN9RX@*B\*)&QO
M9V=E<BT^;&]G*"=3=')I;F<G*3L*"B\J($QO9V=I;F<@82!B87)E(&]B:F5C
M="X@*B\*8VQA<W,@0F%R94]B:F5C="![?0HD;&]G9V5R+3YL;V<H;F5W($)A
M<F5/8FIE8W0H*2D["@HO*B!,;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@9V5T
M365S<V%G92@I(&UE=&AO9"X@*B\*8VQA<W,@1V5T365S<V%G94]B:F5C="![
M(&9U;F-T:6]N(&=E=$UE<W-A9V4H*2![(')E='5R;B`B9V5T365S<V%G92([
M('T@?0HD;&]G9V5R+3YL;V<H;F5W($=E=$UE<W-A9V5/8FIE8W0H*2D["@HO
M*B!,;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@=&]3=')I;F<H*2!M971H;V0N
M("HO"F-L87-S(%1O4W1R:6YG3V)J96-T('L@9G5N8W1I;VX@=&]3=')I;F<H
M*2![(')E='5R;B`B=&]3=')I;F<B.R!]('T*)&QO9V=E<BT^;&]G*&YE=R!4
M;U-T<FEN9T]B:F5C="@I*3L*"B\J($QO9V=I;F<@82!014%27T5R<F]R(&]B
M:F5C="X@*B\*<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B1L;V=G97(M/FQO
M9RAN97<@4$5!4E]%<G)O<B@G4$5!4E]%<G)O<B!O8FIE8W0G+"`Q,#`I*3L*
M"B\J($QO9V=I;F<@86X@87)R87DN("HO"B1L;V=G97(M/FQO9RAA<G)A>2@Q
M+"`R+"`G=&AR964G(#T^(#,I*3L*"B\J($QO9V=I;F<@86X@87)R87D@=VET
M:"!A("=M97-S86=E)R!K97DN("HO"B1L;V=G97(M/FQO9RAA<G)A>2@G;65S
M<V%G92<@/3X@)TUE<W-A9V4@2V5Y)RDI.PH*+2U%6%!%0U0M+0II9&5N="!;
M:6YF;UT@4W1R:6YG"FED96YT(%MI;F9O72!B87)E;V)J96-T($]B:F5C=`HH
M"BD*"FED96YT(%MI;F9O72!G971-97-S86=E"FED96YT(%MI;F9O72!T;U-T
M<FEN9PII9&5N="!;:6YF;UT@4$5!4E]%<G)O<B!O8FIE8W0*:61E;G0@6VEN
M9F]=($%R<F%Y"B@*("`@(%LP72`]/B`Q"B`@("!;,5T@/3X@,@H@("`@6W1H
M<F5E72`]/B`S"BD*"FED96YT(%MI;F9O72!-97-S86=E($ME>0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T97-T
M<R]E>'1R86-T,BYP:'!T````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(V
M-C$@,3`U,34T,S0Q,S4@,#(T,30V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"TM5$535"TM"DQO9SH@7V5X=')A8W1-97-S
M86=E*"D@6UIE;F0@16YG:6YE(#)="BTM4TM)4$E&+2T*/#]P:'`@:68@*'9E
M<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@(C(N,"XP(BP@(CPB*2D@
M9&EE*"=S:VEP)RD[(#\^"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@
M)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G;&EN949O<FUA="<@/3X@)R4R
M)',@6R4S)'-=("4T)',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G
M8V]N<V]L92<L("<G+"`G:61E;G0G+"`D8V]N9BD["@HO*B!,;V=G:6YG(&$@
M<F5G=6QA<B!S=')I;F<N("HO"B1L;V=G97(M/FQO9R@G4W1R:6YG)RD["@HO
M*B!,;V=G:6YG(&$@8F%R92!O8FIE8W0N("HO"F-L87-S($)A<F5/8FIE8W0@
M>WT*)&QO9V=E<BT^;&]G*&YE=R!"87)E3V)J96-T*"DI.PH*+RH@3&]G9VEN
M9R!A;B!O8FIE8W0@=VET:"!A(&=E=$UE<W-A9V4H*2!M971H;V0N("HO"F-L
M87-S($=E=$UE<W-A9V5/8FIE8W0@>R!F=6YC=&EO;B!G971-97-S86=E*"D@
M>R!R971U<FX@(F=E=$UE<W-A9V4B.R!]('T*)&QO9V=E<BT^;&]G*&YE=R!'
M971-97-S86=E3V)J96-T*"DI.PH*+RH@3&]G9VEN9R!A;B!O8FIE8W0@=VET
M:"!A('1O4W1R:6YG*"D@;65T:&]D+B`J+PIC;&%S<R!4;U-T<FEN9T]B:F5C
M="![(&9U;F-T:6]N('1O4W1R:6YG*"D@>R!R971U<FX@(G1O4W1R:6YG(CL@
M?2!]"B1L;V=G97(M/FQO9RAN97<@5&]3=')I;F=/8FIE8W0H*2D["@HO*B!,
M;V=G:6YG(&%N(&]B:F5C="!W:71H(&$@7U]T;U-T<FEN9R@I(&UE=&AO9"!U
M<VEN9R!C87-T:6YG+B`J+PIC;&%S<R!#87-T86)L94]B:F5C="![(&9U;F-T
M:6]N(%]?=&]3=')I;F<H*2![(')E='5R;B`B7U]T;U-T<FEN9R([('T@?0HD
M;&]G9V5R+3YL;V<H;F5W($-A<W1A8FQE3V)J96-T*"DI.PH*+RH@3&]G9VEN
M9R!A(%!%05)?17)R;W(@;V)J96-T+B`J+PIR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*)&QO9V=E<BT^;&]G*&YE=R!014%27T5R<F]R*"=014%27T5R<F]R
M(&]B:F5C="<L(#$P,"DI.PH*+RH@3&]G9VEN9R!A;B!A<G)A>2X@*B\*)&QO
M9V=E<BT^;&]G*&%R<F%Y*#$L(#(L("=T:')E92<@/3X@,RDI.PH*+RH@3&]G
M9VEN9R!A;B!A<G)A>2!W:71H(&$@)VUE<W-A9V4G(&ME>2X@*B\*)&QO9V=E
M<BT^;&]G*&%R<F%Y*"=M97-S86=E)R`]/B`G365S<V%G92!+97DG*2D["@HM
M+4584$5#5"TM"FED96YT(%MI;F9O72!3=')I;F<*:61E;G0@6VEN9F]=($)A
M<F5/8FIE8W0@3V)J96-T"B@**0H*:61E;G0@6VEN9F]=(&=E=$UE<W-A9V4*
M:61E;G0@6VEN9F]=('1O4W1R:6YG"FED96YT(%MI;F9O72!/8FIE8W0@:60@
M(S(*:61E;G0@6VEN9F]=(%!%05)?17)R;W(@;V)J96-T"FED96YT(%MI;F9O
M72!!<G)A>0HH"B`@("!;,%T@/3X@,0H@("`@6S%=(#T^(#(*("`@(%MT:')E
M95T@/3X@,PHI"@II9&5N="!;:6YF;UT@365S<V%G92!+97D*````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O3&]G+W1E<W1S+V9A8W1O<GDN<&AP=```````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#8R-2`Q,#4Q-30S-#$S-2`P,C0P-3<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2U4
M15-4+2T*3&]G.B!&86-T;W)Y"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N
M8V4@)TQO9RYP:'`G.PH*)&-O;G-O;&4Q(#T@)DQO9SHZ9F%C=&]R>2@G8V]N
M<V]L92<I.PHD8V]N<V]L93(@/2`F3&]G.CIF86-T;W)Y*"=C;VYS;VQE)RD[
M"@II9B`H:7-?82@D8V]N<V]L93$L("=,;V=?8V]N<V]L92<I("8F(&ES7V$H
M)&-O;G-O;&4R+"`G3&]G7V-O;G-O;&4G*2D*>PH)96-H;R`B5'=O($QO9U]C
M;VYS;VQE(&]B:F5C=',N7&XB.PI]"@II9B`H)&-O;G-O;&4Q+3Y?:60@(3T@
M)&-O;G-O;&4R+3Y?:60I('L*"65C:&\@(E1H92!O8FIE8W1S(&AA=F4@9&EF
M9F5R96YT($E$<RY<;B(["GT*"BTM15A014-4+2T*5'=O($QO9U]C;VYS;VQE
M(&]B:F5C=',N"E1H92!O8FIE8W1S(&AA=F4@9&EF9F5R96YT($E$<RX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+TQO9R]T97-T<R]F:6QE+G!H<'0`````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#$Q-C(@,3`U,34T,S0Q,S4@,#(S,S(T`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM5$535"TM"DQO9SH@
M1FEL92!(86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO
M9RYP:'`G.PH*)&9I;&5N86UE(#T@9&ER;F%M92A?7T9)3$5?7RD@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@)W1E<W0N;&]G)SL*:68@*&9I;&5?97AI<W1S
M*"1F:6QE;F%M92DI('5N;&EN:R@D9FEL96YA;64I.PH*+RH@5W)I=&4@<V]M
M92!E;G1R:65S('1O('1H92!L;V<@9FEL92X@*B\*)&-O;F8@/2!A<G)A>2@G
M;&EN949O<FUA="<@/3X@)R4R)',@6R4S)'-=("4T)',G*3L*)&QO9V=E<B`]
M("9,;V<Z.G-I;F=L971O;B@G9FEL92<L("1F:6QE;F%M92P@)R<L("1C;VYF
M*3L*"F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I*RLI('L*"21L;V=G97(M/FQO
M9R@B3&]G(&5N=')Y("1I(BD["GT*)&QO9V=E<BT^8VQO<V4H*3L*"B\J($1U
M;7`@=&AE(&-O;G1E;G1S(&]F('1H92!L;V<@9FEL92X@*B\*96-H;R!F:6QE
M7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PH*+RH@0VQE86X@=7`N("HO"FEF
M("AF:6QE7V5X:7-T<R@D9FEL96YA;64I*2!U;FQI;FLH)&9I;&5N86UE*3L*
M"BTM15A014-4+2T*(%MI;F9O72!,;V<@96YT<GD@,`H@6VEN9F]=($QO9R!E
M;G1R>2`Q"B!;:6YF;UT@3&]G(&5N=')Y(#(*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+W1E<W1S+TQO9R]T97-T<R]L979E;',N<&AP=```````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#$U-S0@,3`U,34T,S0Q,S4@,#(S-S`V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"TM5$535"TM
M"DQO9SH@3&5V96QS"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO
M9RYP:'`G.PH*9G5N8W1I;VX@=F5R:69Y*"1E>'`L("1M<V<I"GL*("`@(&5C
M:&\@)&US9R`N("<Z("<["B`@("!E8VAO("@D97AP*2`_("=P87-S)R`Z("=F
M86EL)SL*("`@(&5C:&\@(EQN(CL*?0H*9G5N8W1I;VX@=&5S=$QE=F5L<R@D
M;6%S:RD*>PH@("`@96-H;R`B36%S:SH@)&UA<VM<;B(["@H@("`@9F]R("@D
M<')I;W)I='D@/2!014%27TQ/1U]%34521SL@)'!R:6]R:71Y(#P](%!%05)?
M3$]'7T1%0E5'.R`D<')I;W)I='DK*RD@>PH@("`@("`@("1M87-K960@/2`H
M3&]G.CI-05-+*"1P<FEO<FET>2D@)B`D;6%S:RD["B`@("`@("`@96-H;R`B
M4')I;W)I='D@)'!R:6]R:71Y.B`B.PH@("`@("`@(&5C:&\H)&UA<VME9"D@
M/R`B;6%S:V5D7&XB(#H@(G5N;6%S:V5D7&XB.PH@("`@?0I]"@IT97-T3&5V
M96QS*$QO9SHZ34E.*%!%05)?3$]'7U=!4DY)3D<I*3L*96-H;R`B7&XB.PIT
M97-T3&5V96QS*$QO9SHZ34%8*%!%05)?3$]'7U=!4DY)3D<I*3L*"BTM15A0
M14-4+2T*36%S:SH@,C0P"E!R:6]R:71Y(#`Z('5N;6%S:V5D"E!R:6]R:71Y
M(#$Z('5N;6%S:V5D"E!R:6]R:71Y(#(Z('5N;6%S:V5D"E!R:6]R:71Y(#,Z
M('5N;6%S:V5D"E!R:6]R:71Y(#0Z(&UA<VME9`I0<FEO<FET>2`U.B!M87-K
M960*4')I;W)I='D@-CH@;6%S:V5D"E!R:6]R:71Y(#<Z(&UA<VME9`H*36%S
M:SH@,S$*4')I;W)I='D@,#H@;6%S:V5D"E!R:6]R:71Y(#$Z(&UA<VME9`I0
M<FEO<FET>2`R.B!M87-K960*4')I;W)I='D@,SH@;6%S:V5D"E!R:6]R:71Y
M(#0Z(&UA<VME9`I0<FEO<FET>2`U.B!U;FUA<VME9`I0<FEO<FET>2`V.B!U
M;FUA<VME9`I0<FEO<FET>2`W.B!U;FUA<VME9`H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+TQO9R]T97-T<R]N=6QL+G!H<'0`````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`R-C$@,3`U,34T,S0Q,S4@,#(S,S4V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M5$535"TM"DQO9SH@3G5L;"!(86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR97%U
M:7)E7V]N8V4@)TQO9RYP:'`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G;G5L;"<I.PIF;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK*2!["@DD;&]G
M9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@HM+4584$5#5"TM"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R],;V<O=&5S=',O<')I;W)I='DN<&AP=```````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q,S(W(#$P-3$U-#,T,3,U(#`R-#(W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+51%4U0M+0I,;V<Z
M(%!R:6]R:71I97,*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G
M+G!H<"<["@HD8V]N9B`](&%R<F%Y*"=L:6YE1F]R;6%T)R`]/B`G6R4S)'-=
M("4T)',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L
M("<G+"`G:61E;G0G+"`D8V]N9BD["@HO*B!,;V<@870@=&AE(&1E9F%U;'0@
M4$5!4E],3T=?24Y&3R!L979E;"X@*B\*)&QO9V=E<BT^;&]G*"=,;V<@;65S
M<V%G92<I.PH*+RH@4V5T('1H92!D969A=6QT('!R:6]R:71Y('1O(%!%05)?
M3$]'7T1%0E5'+B`J+PHD;&]G9V5R+3YS9710<FEO<FET>2A014%27TQ/1U]$
M14)51RD["B1L;V=G97(M/FQO9R@G3&]G(&UE<W-A9V4G*3L*"B\J(%9E<FEF
M>2!T:&%T('1H92!G9710<FEO<FET>2@I(&UE=&AO9"!A;'-O('1H:6YG<R!W
M92=R92!A="!014%27TQ/1U]$14)51RX@*B\*)'!R:6]R:71Y(#T@)&QO9V=E
M<BT^<')I;W)I='E4;U-T<FEN9R@D;&]G9V5R+3YG9710<FEO<FET>2@I*3L*
M96-H;R`B)'!R:6]R:71Y7&XB.PH*+RH@5F5R:69Y('1H870@<W1R:6YG5&]0
M<FEO<FET>2@I(&-A;B!C;VYV97)T(&)A8VL@=&\@82!C;VYS=&%N="X@*B\*
M)'!R:6]R:71Y(#T@)&QO9V=E<BT^<W1R:6YG5&]0<FEO<FET>2@D<')I;W)I
M='DI.PIE8VAO("(D<')I;W)I='E<;B(["@HM+4584$5#5"TM"EMI;F9O72!,
M;V<@;65S<V%G90I;9&5B=6==($QO9R!M97-S86=E"F1E8G5G"C<*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R],;V<O=&5S=',O<VEN9VQE=&]N+G!H<'0`````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P-C(W(#$P-3$U-#,T,3,U(#`R-#0Q-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I,;V<Z(%-I;F=L971O;@HM+49)3$4M+0H\/W!H<`H*<F5Q=6ER95]O;F-E
M("=,;V<N<&AP)SL*"B1C;VYS;VQE,2`]("9,;V<Z.G-I;F=L971O;B@G8V]N
M<V]L92<I.PHD8V]N<V]L93(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G
M*3L*"FEF("AI<U]A*"1C;VYS;VQE,2P@)TQO9U]C;VYS;VQE)RD@)B8@:7-?
M82@D8V]N<V]L93(L("=,;V=?8V]N<V]L92<I*0I["@EE8VAO(")4=V\@3&]G
M7V-O;G-O;&4@;V)J96-T<RY<;B(["GT*"FEF("@D8V]N<V]L93$M/E]I9"`]
M/2`D8V]N<V]L93(M/E]I9"D@>PH)96-H;R`B5&AE(&]B:F5C=',@:&%V92!T
M:&4@<V%M92!)1"Y<;B(["GT*"BTM15A014-4+2T*5'=O($QO9U]C;VYS;VQE
M(&]B:F5C=',N"E1H92!O8FIE8W1S(&AA=F4@=&AE('-A;64@240N"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M3&]G+W1E<W1S+W-Q;&ET92YP:'!T````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,3(U-R`Q,#4Q-30S-#$S-2`P,C,W,3,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*3&]G.B!3<6QI
M=&4@2&%N9&QE<@HM+5-+25!)1BTM"CP_<&AP(&EF("@A9G5N8W1I;VY?97AI
M<W1S*"=S<6QI=&5?;W!E;B<I*2!D:64H(G-K:7!<;B(I.R`_/@HM+49)3$4M
M+0H\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1F:6QE;F%M92`]
M(&1I<FYA;64H7U]&24Q%7U\I("X@1$E214-43U)97U-%4$%2051/4B`N("=S
M<6QI=&4M;&]G+F1B)SL*:68@*&9I;&5?97AI<W1S*"1F:6QE;F%M92DI('5N
M;&EN:R@D9FEL96YA;64I.PH*)&1B(#T@<W%L:71E7V]P96XH)&9I;&5N86UE
M+"`P-C8V+"`D97)R;W(I.PHD:61E;G0@/2!T:6UE*"D["B1M97-S86=E(#T@
M)VQO9V=I;F<@86X@979E;G0G.PHD;&]G9V5R(#TF($QO9SHZ9F%C=&]R>2@G
M<W%L:71E)RP@)VQO9U]T86)L92<L("1I9&5N="P@)&1B*3L*)&QO9V=E<BT^
M;&]G*"1M97-S86=E+"!014%27TQ/1U]705).24Y'*3L*"B1Q(#T@(E-%3$5#
M5"!M97-S86=E($923TT@;&]G7W1A8FQE(%=(15)%(&ED96YT/2<D:61E;G0G
M(CL*)')E<R`]('-Q;&ET95]Q=65R>2@D9&(L("1Q*3L*:68@*'-Q;&ET95]F
M971C:%]S=')I;F<H)')E<RD@/3T@)&UE<W-A9V4I('L*"65C:&\@)V]K)SL*
M?0H*<W%L:71E7V-L;W-E*"1D8BD["FEF("AF:6QE7V5X:7-T<R@D9FEL96YA
M;64I*2!U;FQI;FLH)&9I;&5N86UE*3L*"BTM15A014-4+2T*;VL*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O3&]G+W1E<W1S+W-Q;%]I9&5N="YP:'!T````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#<Q,B`Q,#4Q-30S-#$S-2`P,C0S-C<`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2U415-4+2T*3&]G
M.B!344P@<V5T261E;G0H*0HM+5-+25!)1BTM"CP_<&AP"@IR97%U:7)E7V]N
M8V4@)U!%05(O4F5G:7-T<GDN<&AP)SL*)')E9VES=')Y(#T@)FYE=R!014%2
M7U)E9VES=')Y*"D["@II9B`H(21R96=I<W1R>2T^<&%C:V%G945X:7-T<R@G
M1$(G*2D@9&EE*")S:VEP7&XB*3L*+2U&24Q%+2T*/#]P:'`*"G)E<75I<F5?
M;VYC92`G3&]G+G!H<"<["@HD:61E;G0@/2`G,3(S-#4V-S@Y,#$R,S0U-C<X
M.3`G.PH*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G<W%L)RP@)VQO9U]T
M86)L92<L("1I9&5N="P@87)R87DH)V1S;B<@/3X@)R<I*3L*96-H;R`D;&]G
M9V5R+3YG971)9&5N="@I("X@(EQN(CL*"B1L;V=G97(M/G-E=$ED96YT*"1I
M9&5N="D["F5C:&\@)&QO9V=E<BT^9V5T261E;G0H*2`N(")<;B(["@HM+458
M4$5#5"TM"C$R,S0U-C<X.3`Q,C,T-38*,3(S-#4V-S@Y,#$R,S0U-@H`````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TQO9R]T
M97-T<R]C;VYS;VQE+G!H<'0`````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#(Q-S<@,3`U,34T,S0Q,S4@,#(T,#4V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"DQO9SH@0V]N<V]L92!(
M86YD;&5R"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G
M.PH*)&-O;F8@/2!A<G)A>2@G;&EN949O<FUA="<@/3X@)R4R)',@6R4S)'-=
M("4T)',G*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G8V]N<V]L92<L
M("<G+"`G:61E;G0G+"`D8V]N9BD["F9O<B`H)&D@/2`P.R`D:2`\(#,[("1I
M*RLI('L*"21L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD["GT*"F5C:&\@
M(EQN6T)U9F9E<FEN9R`O($9L=7-H(%1E<W1=7&XB.PHD8V]N9B`](&%R<F%Y
M*"=L:6YE1F]R;6%T)R`]/B`G)3(D<R!;)3,D<UT@)30D<R<L("=B=69F97)I
M;F<G(#T^('1R=64I.PHD8G5F9F5R961?;&]G9V5R(#T@)DQO9SHZ<VEN9VQE
M=&]N*"=C;VYS;VQE)RP@)R<L("=B=69F97)E9"<L("1C;VYF*3L*9F]R("@D
M:2`](#`[("1I(#P@,SL@)&DK*RD@>PH@("`@)&)U9F9E<F5D7VQO9V=E<BT^
M;&]G*")0<F4M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y("1I(BD["GT*96-H
M;R`B4')E+69L=7-H7&XB.PHD8G5F9F5R961?;&]G9V5R+3YF;'5S:"@I.PIE
M8VAO(")0;W-T+69L=7-H7&XB.PIF;W(@*"1I(#T@,#L@)&D@/"`S.R`D:2LK
M*2!["B`@("`D8G5F9F5R961?;&]G9V5R+3YL;V<H(E!O<W0M9FQU<V@@8G5F
M9F5R960@;&]G(&5N=')Y("1I(BD["GT*96-H;R`B4VAU=&1O=VY<;B(["B1B
M=69F97)E9%]L;V=G97(M/F-L;W-E*"D["@HM+4584$5#5"TM"FED96YT(%MI
M;F9O72!,;V<@96YT<GD@,`II9&5N="!;:6YF;UT@3&]G(&5N=')Y(#$*:61E
M;G0@6VEN9F]=($QO9R!E;G1R>2`R"@I;0G5F9F5R:6YG("\@1FQU<V@@5&5S
M=%T*4')E+69L=7-H"F)U9F9E<F5D(%MI;F9O72!0<F4M9FQU<V@@8G5F9F5R
M960@;&]G(&5N=')Y(#`*8G5F9F5R960@6VEN9F]=(%!R92UF;'5S:"!B=69F
M97)E9"!L;V<@96YT<GD@,0IB=69F97)E9"!;:6YF;UT@4')E+69L=7-H(&)U
M9F9E<F5D(&QO9R!E;G1R>2`R"E!O<W0M9FQU<V@*4VAU=&1O=VX*8G5F9F5R
M960@6VEN9F]=(%!O<W0M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y(#`*8G5F
M9F5R960@6VEN9F]=(%!O<W0M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y(#$*
M8G5F9F5R960@6VEN9F]=(%!O<W0M9FQU<V@@8G5F9F5R960@;&]G(&5N=')Y
M(#(*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<P``````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-2`P,C(P
M-30`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E
M<W1S+W1E<W1?1'5M<"YP:'``````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,#0R
M(#$P-3$U-#,T,3,U(#`R-#8P-P`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RH*("H@268@=&AE('!A8VMA9V4@
M=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P
M;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A
M;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L
M;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@*B!I;G-T86QL960@
M=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B92!I;B!T:&4@:6YC
M;'5D92!P871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@:&%S(&YO="!B965N
M('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J('1H:7,@
M9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U="!O<B!A
M("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@=&AE('1E
M<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@6$U,7U)00R!T:&%T
M(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G,2XT+C@G
M("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*("`@("\J*@H@("`@
M("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@4$5!4B!I;G-T86QL
M871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=834PO4E!#+T1U;7`N
M<&AP)SL*?2!E;'-E('L*("`@("\J*@H@("`@("H@1V5T('1H92!N965D960@
M8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R>0H@("`@("HO"B`@("!R
M97%U:7)E7V]N8V4@)RXN+T1U;7`N<&AP)SL*?0H*)'9A;"`](&YE=R!834Q?
M4E!#7U9A;'5E*&%R<F%Y*`H@("`@)W1I=&QE)R`@("`]/FYE=R!834Q?4E!#
M7U9A;'5E*"=D87,@:7-T(&1E<B!4:71E;"<L("=S=')I;F<G*2P*("`@("=S
M=&%R=$1A=&4G/3YN97<@6$U,7U)00U]686QU92AM:W1I;64H,"PP+#`L,3,L
M,3$L,C`P-"DL("=D871E5&EM92YI<V\X-C`Q)RDL"B`@("`G96YD1&%T92<@
M(#T^;F5W(%A-3%]24$-?5F%L=64H;6MT:6UE*#`L,"PP+#$U+#$Q+#(P,#0I
M+"`G9&%T951I;64N:7-O.#8P,2<I+`H@("`@)V5R<F]R)R`@("`]/B=S=')I
M;F<G+`H@("`@)V%R:V5Y)R`@("`]/B!N97<@6$U,7U)00U]686QU92@@87)R
M87DH"B`@("`@("`@;F5W(%A-3%]24$-?5F%L=64H)W-I;7!L92!S=')I;F<G
M*2P*("`@("`@("!N97<@6$U,7U)00U]686QU92@Q,C,T-2P@)VEN="<I"B`@
M("`@("`@*2P@)V%R<F%Y)RD*("`@("D*("`@("PG<W1R=6-T)RD["@I834Q?
M4E!#7T1U;7`H)'9A;"D["@IE8VAO("<]/3T]/3T]/3T]/3T]/2<@+B`B7')<
M;B(["B1V86PR(#T@;F5W(%A-3%]24$-?5F%L=64H-#0S-3,L("=I;G0G*3L*
M6$U,7U)00U]$=6UP*"1V86PR*3L*"F5C:&\@)ST]/3T]/3T]/3T]/3T])R`N
M(")<<EQN(CL*)'9A;#,@/2!N97<@6$U,7U)00U]686QU92@G=&AI<R!S:&]U
M;&0@8F4@82!S=')I;F<G+"`G<W1R:6YG)RD["EA-3%]24$-?1'5M<"@D=F%L
M,RD["@IE8VAO("<]/3T]/3T]/3T]/3T]/2<@+B`B7')<;B(["B1V86PT(#T@
M;F5W(%A-3%]24$-?5F%L=64H=')U92P@)V)O;VQE86XG*3L*6$U,7U)00U]$
M=6UP*"1V86PT*3L*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U)00R]T97-T<R]E
M>'1R82UL:6YE<RYP:'``````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C`Q-"`Q,#4Q
M-30S-#$S-2`P,C4Q,#``(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"@T*+RHJ#0H@*B!497-T<R!H;W<@=&AE(%A-
M3%]24$,@<V5R=F5R(&AA;F1L97,@<&%R86UE=&5R<R!W:71H(&5M<'1Y('9A
M;'5E<RX-"B`J#0H@*B!)9B!Y;W4@87)E(')U;FYI;F<@=&AI<R!T97-T(&9R
M;VT@82!#5E,@8VAE8VMO=70L('EO=2!M=7-T(')E;F%M92!T:&4@=V]R:VEN
M9PT*("H@9&ER96-T;W)Y(&9R;VT@(EA-3%]24$,B('1O(")834PB+@T*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@(%=E8B!397)V:6-E<PT*("H@0'!A8VMA9V4@("`@6$U,7U)0
M0PT*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,C`P-2!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS90T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&5X
M=')A+6QI;F5S+G!H<"QV(#$N,2`R,#`V+S`T+S`W(#$T.C0X.C$T(&1A;FEE
M;&,@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]834Q?4E!##0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XT#0H@*B\-"@T*+RH-"B`J($EF('1H92!P
M86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN('1H92!L969T(&AA
M;F0-"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B96QO=RP@
M=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S#0H@*B!C;VUE(&9R;VT@=&AE(%!%
M05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90T*("H@
M:6YS=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S:&]U;&0@8F4@
M:6X@=&AE(&EN8VQU9&4@<&%T:"X-"B`J(`T*("H@268@=&AE('9E<G-I;VX@
M:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I
M;VXL#0H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@
M8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N#0H@*B!4:&5R969O<F4L('=E)VQL
M(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO;B!O9@T*
M("H@6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X-
M"B`J+PT*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E7W9E<G-I;VXG+B=`
M)RD@>PT*("`@("\J*@T*("`@("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R
M;VT@=&AE(%!%05(@:6YS=&%L;&%T:6]N#0H@("`@("HO#0H@("`@<F5Q=6ER
M95]O;F-E("=834PO4E!#+G!H<"<[#0I](&5L<V4@>PT*("`@(&EF("AS=6)S
M='(H9&ER;F%M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@)UA-3"<I('L-"B`@
M("`@("`@96-H;R`B5&AE('!A<F5N="!D:7)E8W1O<GD@;75S="!B92!N86UE
M9"`G6$U,)RY<;B([#0H@("`@("`@(&5X:70[#0H@("`@?0T*#0H@("`@:6YI
M7W-E="@G:6YC;'5D95]P871H)RP@)RXN+RXN+R<-"B`@("`@("`@("`@("X@
M4$%42%]315!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@T*("`@("`@
M("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0T*("`@("D[#0H-"B`@
M("`O*BH-"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F<F]M('1H92!P
M87)E;G0@9&ER96-T;W)Y#0H@("`@("HO#0H@("`@<F5Q=6ER95]O;F-E("<N
M+B]24$,N<&AP)SL-"GT-"@T*)&EN<'5T(#T@(D9I<G-T(&QF<UQN7&Y396-O
M;F0@8W)L9G-<<EQN7')<;E1H:7)D(&-R<UQR7')&;W5R=&@@;&EN92([#0H-
M"B1E>'!E8W1?<F5M;W9E9"`]("(\/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC
M;V1I;F<]7")55$8M.%PB/SX-"CQM971H;V1#86QL/@T*/&UE=&AO9$YA;64^
M;F%D83PO;65T:&]D3F%M93X-"CQP87)A;7,^#0H\<&%R86T^#0H\=F%L=64^
M/'-T<FEN9SY&:7)S="!L9G,-"E-E8V]N9"!C<FQF<PT*5&AI<F0@8W)S#0I&
M;W5R=&@@;&EN93PO<W1R:6YG/CPO=F%L=64^#0H\+W!A<F%M/@T*/"]P87)A
M;7,^#0H\+VUE=&AO9$-A;&P^#0HB.PT*#0HD97AP96-T7VYO=%]R96UO=F5D
M(#T@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(B!E;F-O9&EN9SU<(E541BTX7"(_
M/@T*/&UE=&AO9$-A;&P^#0H\;65T:&]D3F%M93YN861A/"]M971H;V1.86UE
M/@T*/'!A<F%M<SX-"CQP87)A;3X-"CQV86QU93X\<W1R:6YG/D9I<G-T(&QF
M<PT*#0I396-O;F0@8W)L9G,-"@T*5&AI<F0@8W)S#0H-"D9O=7)T:"!L:6YE
M/"]S=')I;F<^/"]V86QU93X-"CPO<&%R86T^#0H\+W!A<F%M<SX-"CPO;65T
M:&]D0V%L;#X-"B([#0H-"@T*)&US9R`](&YE=R!834Q?4E!#7TUE<W-A9V4H
M)VYA9&$G+"!A<G)A>2A834Q?4E!#7V5N8V]D92@D:6YP=70I*2D[#0HD;7-G
M+3YC<F5A=&5087EL;V%D*"D[#0II9B`H)&US9RT^<&%Y;&]A9"`]/2`D97AP
M96-T7W)E;6]V960I('L-"B`@("!E8VAO(")P87-S961<;B([#0I](&5L<V4@
M>PT*("`@(&5C:&\@(E!23T),14U<;B([#0I]#0H-"B1M<V<@/2!N97<@6$U,
M7U)00U]-97-S86=E*"=N861A)RP@87)R87DH6$U,7U)00U]E;F-O9&4H)&EN
M<'5T*2DI.PT*)&US9RT^<F5M;W9E7V5X=')A7VQI;F5S(#T@9F%L<V4[#0HD
M;7-G+3YC<F5A=&5087EL;V%D*"D[#0II9B`H)&US9RT^<&%Y;&]A9"`]/2`D
M97AP96-T7VYO=%]R96UO=F5D*2![#0H@("`@96-H;R`B<&%S<V5D7&XB.PT*
M?2!E;'-E('L-"B`@("!E8VAO(")04D]"3$5-7&XB.PT*?0T*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]24$,O=&5S=',O
M<')O=&]P;W)T+G!H<```````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C4U-#,@,3`U
M,34T,S0Q,S4@,#(T-S(U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AA="!P<F]P97)T
M:65S(&]F(%A-3%]24$-?0VQI96YT(&=E="!P<F]P97)L>2!S970*("H*("H@
M06YY(&EN9&EV:61U86P@=&5S=',@=&AA="!F86EL('=I;&P@:&%V92!T:&5I
M<B!N86UE+"!E>'!E8W1E9"!R97-U;'0*("H@86YD(&%C='5A;"!R97-U;'0@
M<')I;G1E9"!O=70N("!3;R!S965I;F<@;F\@;W5T<'5T('=H96X@97AE8W5T
M:6YG"B`J('1H:7,@9FEL92!I<R!A(&=O;V0@=&AI;F<N"B`J"B`J($-A;B!B
M92!R=6X@=FEA($-,22!O<B!A('=E8B!S97)V97(N"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC
M97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@<')O=&]P;W)T+G!H<"QV(#$N-"`R,#`U+S`Q
M+S(T(#$W.C0X.C0W(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(*("HO"@HO*@H@
M*B!)9B!T:&4@<&%C:V%G92!V97)S:6]N(&YU;6)E<B!I<R!F;W5N9"!I;B!T
M:&4@;&5F="!H86YD"B`J('!O<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO
M;B!B96QO=RP@=&AA="!M96%N<R!T:&ES(&9I;&4@:&%S"B`J(&-O;64@9G)O
M;2!T:&4@4$5!4B!I;G-T86QL97(N("!4:&5R969O<F4L(&QE="=S('1E<W0@
M=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N(&]F(%A-3%]24$,@=VAI8V@@<VAO
M=6QD(&)E(&EN('1H92!I;F-L=61E('!A=&@N"B`J(`H@*B!)9B!T:&4@=F5R
M<VEO;B!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@=&AE(&EF*"D@97AP
M<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@8V]M92!F<F]M(&$@
M0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4:&5R969O<F4L('=E
M)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T:&4@=F5R<VEO;B!O
M9@H@*B!834Q?4E!#('1H870@:&%S(&-O;64@9G)O;2!T:&5R92!A<R!W96QL
M+@H@*B\*:68@*"<Q+C0N."<@(3T@)T`G+B=P86-K86=E7W9E<G-I;VXG+B=`
M)RD@>PH@("`@+RHJ"B`@("`@*B!'970@=&AE(&YE961E9"!C;&%S<R!F<F]M
M('1H92!014%2(&EN<W1A;&QA=&EO;@H@("`@("HO"B`@("!R97%U:7)E7V]N
M8V4@)UA-3"]24$,N<&AP)SL*?2!E;'-E('L*("`@("\J*@H@("`@("H@1V5T
M('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R>0H@
M("`@("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U)00RYP:'`G.PI]"@HO*BH*
M("H@0V]M<&%R92!T:&4@=&5S="!R97-U;'0@=&\@=&AE(&5X<&5C=&5D(')E
M<W5L=`H@*@H@*B!)9B!T:&4@=&5S="!F86EL<RP@96-H;R!O=70@=&AE(')E
M<W5L=',N"B`J"B`J($!P87)A;2!A<G)A>2`@)&5X<&5C="`@("`@=&AE(&%R
M<F%Y(&]F(&]B:F5C="!P<F]P97)T:65S('EO=2!E>'!E8W0*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9G)O;2!T:&4@=&5S=`H@*B!`<&%R86T@
M;V)J96-T("1A8W1U86P@("`@('1H92!O8FIE8W0@<F5S=6QT<R!F<F]M('1H
M92!T97-T"B`J($!P87)A;2!S=')I;F<@)'1E<W1?;F%M92`@=&AE(&YA;64@
M;V8@=&AE('1E<W0*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!C
M;VUP87)E*"1E>'!E8W0L("1A8W1U86PL("1T97-T7VYA;64I('L*("`@("1A
M8W1U86P@/2!G971?;V)J96-T7W9A<G,H)&%C='5A;"D["B`@("!I9B`H8V]U
M;G0H87)R87E?9&EF9B@D86-T=6%L+"`D97AP96-T*2DI('L*("`@("`@("!E
M8VAO("(D=&5S=%]N86UE(&9A:6QE9"Y<;D5X<&5C=#H@(CL*("`@("`@("!P
M<FEN=%]R*"1E>'!E8W0I.PH@("`@("`@(&5C:&\@(D%C='5A;#H@(CL*("`@
M("`@("!P<FEN=%]R*"1A8W1U86PI.PH@("`@("`@(&5C:&\@(EQN(CL*("`@
M('T*?0H*:68@*'!H<%]S87!I7VYA;64H*2`A/2`G8VQI)RD@>PH@("`@96-H
M;R`B/'!R93Y<;B(["GT*"@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G(#T^("=T
M:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@("`@)W!R
M;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@/3X@.#`L"B`@("`G
M<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R;W1O8V]L)R`]/B`G:'1T<#HO
M+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X,"P*("`@("=P<F]X>5]U<V5R
M)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*("`@("=E<G)N;R<@
M/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P
M+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S=V]R9"<@/3X@)R<L
M"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P871H)RP@)W1H97-E
M<G9E<B<I.PIC;VUP87)E*"1X+"`D8RP@)V1E9F%U;'1S)RD["@HD>"`](&%R
M<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^
M("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@
M("`G<&]R="<@/3X@.#`L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY
M7W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@
M.#`X,"P*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S
M)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^
M("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*
M("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI
M96YT*"=T:&5P871H)RP@)VAT='`Z+R]T:&5S97)V97(G*3L*8V]M<&%R92@D
M>"P@)&,L("=D969A=6QT<R!W:71H(&AT='`G*3L*"B1X(#T@87)R87DH"B`@
M("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E
M<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@)W!O<G0G
M(#T^(#0T,RP*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G<')O>'E?<')O=&]C
M;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X,#@P+`H@
M("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G(#T^("<G
M+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@)R<L"B`@
M("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@("`@)W!A
M<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE;G0H)W1H
M97!A=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G*3L*8V]M<&%R92@D>"P@)&,L
M("=D969A=6QT<R!W:71H(&AT='!S)RD["@HD>"`](&%R<F%Y*`H@("`@)W!A
M=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V97(G
M+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P;W)T)R`]/B`T
M-#,L"B`@("`G<')O>'DG(#T^("<G+`H@("`@)W!R;WAY7W!R;W1O8V]L)R`]
M/B`G:'1T<#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@.#`X,"P*("`@("=P
M<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*("`@
M("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@)V1E
M8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S=V]R
M9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P871H
M)RP@)W-S;#HO+W1H97-E<G9E<B<I.PIC;VUP87)E*"1X+"`D8RP@)V1E9F%U
M;'1S('=I=&@@<W-L)RD["@H*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G
M=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P
M<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!O<G0G(#T^(#8U+`H@("`@
M)W!R;WAY)R`]/B`G)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z
M+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G<')O>'E?=7-E
M<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G
M(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@
M,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G
M+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=T:&5S
M97)V97(G+"`V-2D["F-O;7!A<F4H)'@L("1C+"`G<&]R="`V-2<I.PH*)'@@
M/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R
M)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)VAT='`Z+R\G
M+`H@("`@)W!O<G0G(#T^(#8U+`H@("`@)W!R;WAY)R`]/B`G)RP*("`@("=P
M<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G
M(#T^(#@P.#`L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?
M<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG
M)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@
M)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#
M7T-L:65N="@G=&AE<&%T:"<L("=H='1P.B\O=&AE<V5R=F5R)RP@-C4I.PIC
M;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET:"!H='1P)RD["@HD>"`](&%R
M<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^
M("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@
M("=P;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G<')O>'E?
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X
M,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G
M(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@
M)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@
M("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE
M;G0H)W1H97!A=&@G+"`G:'1T<',Z+R]T:&5S97)V97(G+"`V-2D["F-O;7!A
M<F4H)'@L("1C+"`G<&]R="`V-2!W:71H(&AT='!S)RD["@HD>"`](&%R<F%Y
M*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T
M:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P
M;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)R<L"B`@("`G<')O>'E?<')O
M=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X,#@P
M+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G(#T^
M("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@)R<L
M"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@("`@
M)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE;G0H
M)W1H97!A=&@G+"`G<W-L.B\O=&AE<V5R=F5R)RP@-C4I.PIC;VUP87)E*"1X
M+"`D8RP@)W!O<G0@-C4@=VET:"!S<VPG*3L*"@HD>"`](&%R<F%Y*`H@("`@
M)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V
M97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@
M/3X@.#`L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G<')O>'E?
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`X
M,#@P+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G
M(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@
M)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@
M("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE
M;G0H)W1H97!A=&@G+"`G=&AE<V5R=F5R)RP@,"P*("`@("`@("`@("`@("`@
M("`@("`@("`@)W1H97!R;WAY)RD["F-O;7!A<F4H)'@L("1C+"`G9&5F875L
M=',@<')O>'DG*3L*"B1X(#T@87)R87DH"B`@("`G<&%T:"<@/3X@)W1H97!A
M=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G<')O=&]C
M;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T)R`]/B`X,"P*("`@("=P<F]X
M>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@/3X@)VAT
M='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G(#T^(#@P.#`L"B`@("`G<')O>'E?
M=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R
M;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@
M/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^
M("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=H
M='1P.B\O=&AE<V5R=F5R)RP@,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M)VAT='`Z+R]T:&5P<F]X>2<I.PIC;VUP87)E*"1X+"`D8RP@)V1E9F%U;'1S
M('=I=&@@:'1T<"!P<F]X>2<I.PH*)'@@/2!A<G)A>2@*("`@("=P871H)R`]
M/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@
M("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@/3X@-#0S+`H@
M("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@)W!R;WAY7W!R;W1O8V]L
M)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`T-#,L"B`@("`G
M<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@
M("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D
M96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O
M<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T
M:"<L("=H='1P<SHO+W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@("`@("`@
M("`@("`@("=H='1P<SHO+W1H97!R;WAY)RD["F-O;7!A<F4H)'@L("1C+"`G
M9&5F875L=',@=VET:"!H='1P<R!P<F]X>2<I.PH*)'@@/2!A<G)A>2@*("`@
M("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G<V5R=F5R)R`]/B`G=&AE<V5R
M=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S;#HO+R<L"B`@("`G<&]R="<@
M/3X@-#0S+`H@("`@)W!R;WAY)R`]/B`G=&AE<')O>'DG+`H@("`@)W!R;WAY
M7W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`T
M-#,L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?<&%S<R<@
M/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG)R`]/B`G
M)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@)R<L"B`@
M("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#7T-L:65N
M="@G=&AE<&%T:"<L("=S<VPZ+R]T:&5S97)V97(G+"`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G<W-L.B\O=&AE<')O>'DG*3L*8V]M<&%R92@D>"P@
M)&,L("=D969A=6QT<R!W:71H('-S;"!P<F]X>2<I.PH*"B1X(#T@87)R87DH
M"B`@("`G<&%T:"<@/3X@)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H
M97-E<G9E<B<L"B`@("`G<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P
M;W)T)R`]/B`V-2P*("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P
M<F]X>5]P<F]T;V-O;"<@/3X@)VAT='`Z+R\G+`H@("`@)W!R;WAY7W!O<G0G
M(#T^(#8U-C4L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L"B`@("`G<')O>'E?
M<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@("`G97)R<W1R:6YG
M)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U<V5R;F%M92<@/3X@
M)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`](&YE=R!834Q?4E!#
M7T-L:65N="@G=&AE<&%T:"<L("=T:&5S97)V97(G+"`V-2P*("`@("`@("`@
M("`@("`@("`@("`@("`@)W1H97!R;WAY)RP@-C4V-2D["F-O;7!A<F4H)'@L
M("1C+"`G<&]R="`V-2!P<F]X>2`V-38U)RD["@HD>"`](&%R<F%Y*`H@("`@
M)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V
M97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G:'1T<#HO+R<L"B`@("`G<&]R="<@
M/3X@-C4L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@("`G<')O>'E?
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P<F]X>5]P;W)T)R`]/B`V
M-38U+`H@("`@)W!R;WAY7W5S97(G(#T^("<G+`H@("`@)W!R;WAY7W!A<W,G
M(#T^("<G+`H@("`@)V5R<FYO)R`]/B`P+`H@("`@)V5R<G-T<FEN9R<@/3X@
M)R<L"B`@("`G9&5B=6<G(#T^(#`L"B`@("`G=7-E<FYA;64G(#T^("<G+`H@
M("`@)W!A<W-W;W)D)R`]/B`G)RP**3L*)&,@/2!N97<@6$U,7U)00U]#;&EE
M;G0H)W1H97!A=&@G+"`G:'1T<#HO+W1H97-E<G9E<B<L(#8U+`H@("`@("`@
M("`@("`@("`@("`@("`@("`G:'1T<#HO+W1H97!R;WAY)RP@-C4V-2D["F-O
M;7!A<F4H)'@L("1C+"`G<&]R="`V-2!W:71H(&AT='`@<')O>'D@-C4V-2<I
M.PH*)'@@/2!A<G)A>2@*("`@("=P871H)R`]/B`G=&AE<&%T:"<L"B`@("`G
M<V5R=F5R)R`]/B`G=&AE<V5R=F5R)RP*("`@("=P<F]T;V-O;"<@/3X@)W-S
M;#HO+R<L"B`@("`G<&]R="<@/3X@-C4L"B`@("`G<')O>'DG(#T^("=T:&5P
M<F]X>2<L"B`@("`G<')O>'E?<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@
M)W!R;WAY7W!O<G0G(#T^(#8U-C4L"B`@("`G<')O>'E?=7-E<B<@/3X@)R<L
M"B`@("`G<')O>'E?<&%S<R<@/3X@)R<L"B`@("`G97)R;F\G(#T^(#`L"B`@
M("`G97)R<W1R:6YG)R`]/B`G)RP*("`@("=D96)U9R<@/3X@,"P*("`@("=U
M<V5R;F%M92<@/3X@)R<L"B`@("`G<&%S<W=O<F0G(#T^("<G+`HI.PHD8R`]
M(&YE=R!834Q?4E!#7T-L:65N="@G=&AE<&%T:"<L("=H='1P<SHO+W1H97-E
M<G9E<B<L(#8U+`H@("`@("`@("`@("`@("`@("`@("`@("`G:'1T<',Z+R]T
M:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@-C4@=VET
M:"!H='1P<R!P<F]X>2`V-38U)RD["@HD>"`](&%R<F%Y*`H@("`@)W!A=&@G
M(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^("=T:&5S97)V97(G+`H@
M("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@("=P;W)T)R`]/B`V-2P*
M("`@("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T;V-O
M;"<@/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@-C4V-2P*("`@
M("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*
M("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@
M)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S
M=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P
M871H)RP@)W-S;#HO+W1H97-E<G9E<B<L(#8U+`H@("`@("`@("`@("`@("`@
M("`@("`@("`G<W-L.B\O=&AE<')O>'DG+"`V-38U*3L*8V]M<&%R92@D>"P@
M)&,L("=P;W)T(#8U('=I=&@@<W-L('!R;WAY(#8U-C4G*3L*"@HD>"`](&%R
M<F%Y*`H@("`@)W!A=&@G(#T^("=T:&5P871H)RP*("`@("=S97)V97(G(#T^
M("=T:&5S97)V97(G+`H@("`@)W!R;W1O8V]L)R`]/B`G<W-L.B\O)RP*("`@
M("=P;W)T)R`]/B`T-#,L"B`@("`G<')O>'DG(#T^("=T:&5P<F]X>2<L"B`@
M("`G<')O>'E?<')O=&]C;VPG(#T^("=S<VPZ+R\G+`H@("`@)W!R;WAY7W!O
M<G0G(#T^(#0T,RP*("`@("=P<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X
M>5]P87-S)R`]/B`G)RP*("`@("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I
M;F<G(#T^("<G+`H@("`@)V1E8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]
M/B`G)RP*("`@("=P87-S=V]R9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]2
M4$-?0VQI96YT*"=T:&5P871H)RP@)W1H97-E<G9E<B<L(#0T,RP*("`@("`@
M("`@("`@("`@("`@("`@("`@)W1H97!R;WAY)RP@-#0S*3L*8V]M<&%R92@D
M>"P@)&,L("=P;W)T(#0T,R!N;R!P<F]T;V-O;"!A;F0@<')O>'D@<&]R="`T
M-#,@;F\@<')O=&]C;VPG*3L*"B1X(#T@87)R87DH"B`@("`G<&%T:"<@/3X@
M)W1H97!A=&@G+`H@("`@)W-E<G9E<B<@/3X@)W1H97-E<G9E<B<L"B`@("`G
M<')O=&]C;VPG(#T^("=H='1P.B\O)RP*("`@("=P;W)T)R`]/B`X,"P*("`@
M("=P<F]X>2<@/3X@)W1H97!R;WAY)RP*("`@("=P<F]X>5]P<F]T;V-O;"<@
M/3X@)W-S;#HO+R<L"B`@("`G<')O>'E?<&]R="<@/3X@-C4V-2P*("`@("=P
M<F]X>5]U<V5R)R`]/B`G)RP*("`@("=P<F]X>5]P87-S)R`]/B`G)RP*("`@
M("=E<G)N;R<@/3X@,"P*("`@("=E<G)S=')I;F<G(#T^("<G+`H@("`@)V1E
M8G5G)R`]/B`P+`H@("`@)W5S97)N86UE)R`]/B`G)RP*("`@("=P87-S=V]R
M9"<@/3X@)R<L"BD["B1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"=T:&5P871H
M)RP@)W1H97-E<G9E<B<L(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("=S
M<VPZ+R]T:&5P<F]X>2<L(#8U-C4I.PIC;VUP87)E*"1X+"`D8RP@)W!O<G0@
M-#0S(&YO('!R;W1O8V]L(&%N9"!P<F]X>2!P;W)T(#0T,R!N;R!P<F]T;V-O
M;"<I.PH`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]834Q?4E!#+W1E<W1S+V5M<'1Y+79A;'5E+G!H
M<````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,#0R(#$P-3$U-#,T,3,U(#`R-3$Q
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J(%1E<W1S(&AO=R!T:&4@6$U,7U)00R!S97)V97(@:&%N
M9&QE<R!P87)A;65T97)S('=I=&@@96UP='D@=F%L=65S+@H@*@H@*B!)9B!Y
M;W4@87)E(')U;FYI;F<@=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE8VMO=70L
M('EO=2!M=7-T(')E;F%M92!T:&4@=V]R:VEN9PH@*B!D:7)E8W1O<GD@9G)O
M;2`B6$U,7U)00R(@=&\@(EA-3"(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A
M8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@96UP='DM=F%L=64N<&AP+'8@,2XQ(#(P,#4O,3`O,34@,C`Z
M,CDZ-#8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XT"B`J+PH*+RH*("H@268@
M=&AE('!A8VMA9V4@=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE
M9G0@:&%N9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L
M;W<L('1H870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE
M(%!%05(@:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@
M*B!I;G-T86QL960@=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B
M92!I;B!T:&4@:6YC;'5D92!P871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@
M:&%S(&YO="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I
M;VXL"B`J('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C
M:&5C:V]U="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A
M<W-U;64@=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@
M6$U,7U)00R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO
M"FEF("@G,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*
M("`@("\J*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@
M4$5!4B!I;G-T86QL871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=8
M34PO4E!#+U-E<G9E<BYP:'`G.PI](&5L<V4@>PH@("`@:68@*'-U8G-T<BAD
M:7)N86UE*%]?1DE,15]?*2P@+3DL("TV*2`A/2`G6$U,)RD@>PH@("`@("`@
M(&5C:&\@(E1H92!P87)E;G0@9&ER96-T;W)Y(&UU<W0@8F4@;F%M960@)UA-
M3"<N7&XB.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@:6YI7W-E="@G:6YC
M;'5D95]P871H)RP@)RXN+RXN+R<*("`@("`@("`@("`@+B!0051(7U-%4$%2
M051/4B`N("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI
M7V=E="@G:6YC;'5D95]P871H)RD*("`@("D["@H@("`@+RHJ"B`@("`@*B!'
M970@=&AE(&YE961E9"!C;&%S<R!F<F]M('1H92!P87)E;G0@9&ER96-T;W)Y
M"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G+BXO4V5R=F5R+G!H<"<["GT*
M"B1'3$]"04Q36R=(5%107U)!5U]03U-47T1!5$$G72`](#P\/$5/4$]35`H\
M/WAM;"!V97)S:6]N/2(Q+C`B/SX*/&UE=&AO9$-A;&P^"B`\;65T:&]D3F%M
M93YA;&QG;W0\+VUE=&AO9$YA;64^"B`@/'!A<F%M<SX*("`@/'!A<F%M/CQV
M86QU93X\<W1R:6YG/CPO<W1R:6YG/CPO=F%L=64^/"]P87)A;3X*("`@/'!A
M<F%M/CQV86QU93YF:7)S=#PO=F%L=64^/"]P87)A;3X*("`@/'!A<F%M/CQV
M86QU93X@(#PO=F%L=64^/"]P87)A;3X*("`@/'!A<F%M/CQV86QU93X\+W9A
M;'5E/CPO<&%R86T^"B`@/"]P87)A;7,^"B`\+VUE=&AO9$-A;&P^"D5/4$]3
M5#L*"B1E>'!E8W0@/2`\/#Q%3T584`H\/WAM;"!V97)S:6]N/2(Q+C`B(&5N
M8V]D:6YG/2)55$8M."(_/@H\;65T:&]D4F5S<&]N<V4^"CQP87)A;7,^"CQP
M87)A;3X*/'9A;'5E/CQS=')I;F<^<&%R86T@,#H@)R<*<&%R86T@,3H@)V9I
M<G-T)PIP87)A;2`R.B`G("`G"G!A<F%M(#,Z("<G"CPO<W1R:6YG/CPO=F%L
M=64^"CPO<&%R86T^"CPO<&%R86US/@H\+VUE=&AO9%)E<W!O;G-E/@I%3T58
M4#L*"FEN8VQU9&4@)RXO86QL9V]T+FEN8R<["@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+UA-3%]24$,O=&5S=',O='EP97,N<&AP````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#8T-#`@,3`U,34T,S0Q,S4@,#(T,#$T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@HO*BH*("H@5&5S
M=',@:&]W('1H92!834Q?4E!#('-E<G9E<B!H86YD;&5S(&$@8G5N8V@@;V8@
M9&EF9F5R96YT('!A<F%M971E<@H@*B!D871A('1Y<&5S+@H@*@H@*B!)9B!Y
M;W4@87)E(')U;FYI;F<@=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE8VMO=70L
M('EO=2!M=7-T(')E;F%M92!T:&4@=V]R:VEN9PH@*B!D:7)E8W1O<GD@9G)O
M;2`B6$U,7U)00R(@=&\@(EA-3"(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A
M8VMA9V4@("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@='EP97,N<&AP+'8@,2XQ(#(P,#4O,3`O,34@,C`Z,CDZ-#8@
M9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O6$U,7U)00PH@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XT"B`J+PH*+RH*("H@268@=&AE('!A
M8VMA9V4@=F5R<VEO;B!N=6UB97(@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N
M9`H@*B!P;W)T:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H
M870@;65A;G,@=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@
M:6YS=&%L;&5R+B`@5&AE<F5F;W)E+"!L970G<R!T97-T('1H90H@*B!I;G-T
M86QL960@=F5R<VEO;B!O9B!834Q?4E!#('=H:6-H('-H;W5L9"!B92!I;B!T
M:&4@:6YC;'5D92!P871H+@H@*B`*("H@268@=&AE('9E<G-I;VX@:&%S(&YO
M="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J
M('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U
M="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@
M=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@6$U,7U)0
M0R!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@87,@=V5L;"X*("HO"FEF("@G
M,2XT+C@G("$]("=`)RXG<&%C:V%G95]V97)S:6]N)RXG0"<I('L*("`@("\J
M*@H@("`@("H@1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@4$5!4B!I
M;G-T86QL871I;VX*("`@("`J+PH@("`@<F5Q=6ER95]O;F-E("=834PO4E!#
M+U-E<G9E<BYP:'`G.PI](&5L<V4@>PH@("`@:68@*'-U8G-T<BAD:7)N86UE
M*%]?1DE,15]?*2P@+3DL("TV*2`A/2`G6$U,)RD@>PH@("`@("`@(&5C:&\@
M(E1H92!P87)E;G0@9&ER96-T;W)Y(&UU<W0@8F4@;F%M960@)UA-3"<N7&XB
M.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@:6YI7W-E="@G:6YC;'5D95]P
M871H)RP@)RXN+RXN+R<*("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N
M("<N)R`N(%!!5$A?4T5005)!5$]2"B`@("`@("`@("`@("X@:6YI7V=E="@G
M:6YC;'5D95]P871H)RD*("`@("D["@H@("`@+RHJ"B`@("`@*B!'970@=&AE
M(&YE961E9"!C;&%S<R!F<F]M('1H92!P87)E;G0@9&ER96-T;W)Y"B`@("`@
M*B\*("`@(')E<75I<F5?;VYC92`G+BXO4V5R=F5R+G!H<"<["GT*"B1'3$]"
M04Q36R=(5%107U)!5U]03U-47T1!5$$G72`](#P\/$5/4$]35`H\/WAM;"!V
M97)S:6]N/2(Q+C`B/SX*/&UE=&AO9$-A;&P^"B`\;65T:&]D3F%M93YA;&QG
M;W0\+VUE=&AO9$YA;64^"B`@/'!A<F%M<SX*("`@/'!A<F%M/CQV86QU93YD
M969A=6QT('1O('-T<FEN9SPO=F%L=64^/"]P87)A;3X*("`@/'!A<F%M/CQV
M86QU93X\<W1R:6YG/FEN<VED92!S=')I;F<\+W-T<FEN9SX\+W9A;'5E/CPO
M<&%R86T^"B`@(#QP87)A;3X\=F%L=64^/&EN=#XX/"]I;G0^/"]V86QU93X\
M+W!A<F%M/@H@("`\<&%R86T^/'9A;'5E/CQD871E=&EM92YI<V\X-C`Q/C(P
M,#4P.#`Y5#`Q.C,S.C0T/"]D871E=&EM92YI<V\X-C`Q/CPO=F%L=64^/"]P
M87)A;3X*"B`@(#QP87)A;3X*("`@(#QV86QU93X*("`@("`\87)R87D^"B`@
M("`@(#QD871A/@H@("`@("`@/'9A;'5E/@H@("`@("`@(#QS=')I;F<^83PO
M<W1R:6YG/@H@("`@("`@/"]V86QU93X*("`@("`@(#QV86QU93X*("`@("`@
M("`\<W1R:6YG/F(\+W-T<FEN9SX*("`@("`@(#PO=F%L=64^"B`@("`@(#PO
M9&%T83X*("`@("`\+V%R<F%Y/@H@("`@/"]V86QU93X*("`@/"]P87)A;3X*
M"B`@(#QP87)A;3X*("`@(#QV86QU93X*("`@("`\<W1R=6-T/@H@("`@("`\
M;65M8F5R/@H@("`@("`@/&YA;64^83PO;F%M93X*("`@("`@(#QV86QU93X*
M("`@("`@("`\<W1R:6YG/F%Y/"]S=')I;F<^"B`@("`@("`\+W9A;'5E/@H@
M("`@("`\+VUE;6)E<CX*("`@("`@/&UE;6)E<CX*("`@("`@(#QN86UE/F(\
M+VYA;64^"B`@("`@("`\=F%L=64^"B`@("`@("`@/'-T<FEN9SYB93PO<W1R
M:6YG/@H@("`@("`@/"]V86QU93X*("`@("`@/"]M96UB97(^"B`@("`@/"]S
M=')U8W0^"B`@("`\+W9A;'5E/@H@("`\+W!A<F%M/@H*("`\+W!A<F%M<SX*
M(#PO;65T:&]D0V%L;#X*14]03U-4.PH*)&5X<&5C="`](#P\/$5/15A0"CP_
M>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<](E541BTX(C\^"CQM971H;V12
M97-P;VYS93X*/'!A<F%M<SX*/'!A<F%M/@H\=F%L=64^/'-T<FEN9SYP87)A
M;2`P.B`G9&5F875L="!T;R!S=')I;F<G"G!A<F%M(#$Z("=I;G-I9&4@<W1R
M:6YG)PIP87)A;2`R.B`G."<*<&%R86T@,SH@)S(P,#4P.#`Y5#`Q.C,S.C0T
M)PIP87)A;2`T.B!A<G)A>2`H"B`@,"`])F=T.R`G82<L"B`@,2`])F=T.R`G
M8B<L"BD*<&%R86T@-3H@87)R87D@*`H@("=A)R`])F=T.R`G87DG+`H@("=B
M)R`])F=T.R`G8F4G+`HI"CPO<W1R:6YG/CPO=F%L=64^"CPO<&%R86T^"CPO
M<&%R86US/@H\+VUE=&AO9%)E<W!O;G-E/@I%3T584#L*"FEN8VQU9&4@)RXO
M86QL9V]T+FEN8R<["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T
M<R]834Q?4E!#+W1E<W1S+V%L;&=O="YI;F,`````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`S,#8P(#$P-3$U-#,T,3,U(#`R-#$P-P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RHJ"B`J(`H@
M*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S
M90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y
M("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U
M=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`R,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&%L;&=O="YI;F,L=B`Q
M+C$@,C`P-2\Q,"\Q-2`R,#HR.3HT-B!D86YI96QC($5X<"`D"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C0*("HO"@IO8E]S=&%R="@I.PH*9G5N8W1I;VX@<F5T=7)N06QL1V]T*"1P
M87)A;7,I('L*("`@("1O=70@/2`G)SL*("`@("1C;W5N="`](&-O=6YT*"1P
M87)A;7,M/G!A<F%M<RD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[
M("1I*RLI('L*("`@("`@("`D<&%R86T@/2`D<&%R86US+3YG971087)A;2@D
M:2D["B`@("`@("`@:68@*"%834Q?4E!#7U9A;'5E.CII<U9A;'5E*"1P87)A
M;2DI('L*("`@("`@("`@("`@)&]U="`N/2`B<&%R86UE=&5R("1I('=A<R!E
M<G)O<CH@)'!A<F%M7&XB.PH@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@
M("!]"B`@("`@("`@)&=O="`](%A-3%]24$-?1&5C;V1E*"1P87)A;2D["B`@
M("`@("`@)&]U="`N/2`B<&%R86T@)&DZ("(@+B!V87)?97AP;W)T*"1G;W0L
M('1R=64I("X@(EQN(CL*("`@('T*("`@("1V86P@/2!N97<@6$U,7U)00U]6
M86QU92@D;W5T+"`G<W1R:6YG)RD["B`@("!R971U<FX@;F5W(%A-3%]24$-?
M4F5S<&]N<V4H)'9A;"D["GT*"B1S97)V97(@/2!N97<@6$U,7U)00U]397)V
M97(H"B`@("!A<G)A>2@*("`@("`@("`G86QL9V]T)R`]/B!A<G)A>2@*("`@
M("`@("`@("`@)V9U;F-T:6]N)R`]/B`G<F5T=7)N06QL1V]T)RP*("`@("`@
M("`I+`H@("`@*0HI.PH*)&=O="`](&]B7V=E=%]C;&5A;B@I.PH*:68@*"1G
M;W0@/3T@)&5X<&5C="D@>PH@("`@96-H;R`B<&%S<V5D7&XB.PI](&5L<V4@
M>PH@("`@96-H;R`B1D%)3$5$7&XB.PH@("`@96-H;R`B17AP96-T960Z7&XD
M97AP96-T7&XB.PH@("`@96-H;R`B1V]T.EQN)&=O=%QN(CL*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,
M7U)00R]T97-T<R]E;7!T>2UV86QU92US=')U8W0N<&AP````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-3`V-"`Q,#4Q-30S-#$S-2`P,C8T-#,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B\J*@H@*B!497-T<R!H
M;W<@=&AE(%A-3%]24$,@<V5R=F5R(&AA;F1L97,@82!P87)A;65T97(@=VET
M:"!A;B!E;7!T>2!S=')U8W0@=VET:&]U=`H@*B!A;GD@<W!A8V5S(&EN('1H
M92!834P@869T97(@=&AE(&5M<'1Y('9A;'5E+@H@*@H@*B!)9B!Y;W4@87)E
M(')U;FYI;F<@=&AI<R!T97-T(&9R;VT@82!#5E,@8VAE8VMO=70L('EO=2!M
M=7-T(')E;F%M92!T:&4@=V]R:VEN9PH@*B!D:7)E8W1O<GD@9G)O;2`B6$U,
M7U)00R(@=&\@(EA-3"(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@
M("`@6$U,7U)00PH@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD
M86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@96UP='DM=F%L=64M<W1R=6-T+G!H<"QV(#$N,2`R,#`U+S$P+S$U(#(P
M.C(Y.C0V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N-`H@*B\*"B\J"B`J($EF
M('1H92!P86-K86=E('9E<G-I;VX@;G5M8F5R(&ES(&9O=6YD(&EN('1H92!L
M969T(&AA;F0*("H@<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N(&)E
M;&]W+"!T:&%T(&UE86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M('1H
M92!014%2(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=&5S="!T:&4*
M("H@:6YS=&%L;&5D('9E<G-I;VX@;V8@6$U,7U)00R!W:&EC:"!S:&]U;&0@
M8F4@:6X@=&AE(&EN8VQU9&4@<&%T:"X*("H@"B`J($EF('1H92!V97)S:6]N
M(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E9"!I;B!T:&4@:68H*2!E>'!R97-S
M:6]N+`H@*B!T:&ES(&9I;&4@:&%S(&QI:V5L>2!C;VUE(&9R;VT@82!#5E,@
M8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N"B`J(%1H97)E9F]R92P@=V4G;&P@
M87-S=6UE('1H92!T97-T<R!S:&]U;&0@=7-E('1H92!V97)S:6]N(&]F"B`J
M(%A-3%]24$,@=&AA="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN"B`J
M+PII9B`H)S$N-"XX)R`A/2`G0"<N)W!A8VMA9V5?=F5R<VEO;B<N)T`G*2![
M"B`@("`O*BH*("`@("`J($=E="!T:&4@;F5E9&5D(&-L87-S(&9R;VT@=&AE
M(%!%05(@:6YS=&%L;&%T:6]N"B`@("`@*B\*("`@(')E<75I<F5?;VYC92`G
M6$U,+U)00R]397)V97(N<&AP)SL*?2!E;'-E('L*("`@(&EF("AS=6)S='(H
M9&ER;F%M92A?7T9)3$5?7RDL("TY+"`M-BD@(3T@)UA-3"<I('L*("`@("`@
M("!E8VAO(")4:&4@<&%R96YT(&1I<F5C=&]R>2!M=7-T(&)E(&YA;65D("=8
M34PG+EQN(CL*("`@("`@("!E>&ET.PH@("`@?0H*("`@(&EN:5]S970H)VEN
M8VQU9&5?<&%T:"<L("<N+B\N+B\G"B`@("`@("`@("`@("X@4$%42%]315!!
M4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN
M:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PH*("`@("\J*@H@("`@("H@
M1V5T('1H92!N965D960@8VQA<W,@9G)O;2!T:&4@<&%R96YT(&1I<F5C=&]R
M>0H@("`@("HO"B`@("!R97%U:7)E7V]N8V4@)RXN+U-E<G9E<BYP:'`G.PI]
M"@HD1TQ/0D%,4ULG2%144%]205=?4$]35%]$051!)UT@/2`\/#Q%3U!/4U0*
M/#]X;6P@=F5R<VEO;CTB,2XP(C\^"CQM971H;V1#86QL/@H@/&UE=&AO9$YA
M;64^86QL9V]T/"]M971H;V1.86UE/@H@(#QP87)A;7,^"B`@(#QP87)A;3X*
M("`@(#QV86QU93X*("`@("`\<W1R=6-T/@H@("`@("`\;65M8F5R/@H@("`@
M("`\;F%M93YF;&0Q/"]N86UE/CQV86QU93X\+W9A;'5E/CPO;65M8F5R/CPO
M<W1R=6-T/CPO=F%L=64^"B`@(#PO<&%R86T^"B`@/"]P87)A;7,^"B`\+VUE
M=&AO9$-A;&P^"D5/4$]35#L*"B1E>'!E8W0@/2`\/#Q%3T584`H\/WAM;"!V
M97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2)55$8M."(_/@H\;65T:&]D4F5S<&]N
M<V4^"CQP87)A;7,^"CQP87)A;3X*/'9A;'5E/CQS=')I;F<^<&%R86T@,#H@
M87)R87D@*`H@("=F;&0Q)R`])F=T.R`G)RP**0H\+W-T<FEN9SX\+W9A;'5E
M/@H\+W!A<F%M/@H\+W!A<F%M<SX*/"]M971H;V1297-P;VYS93X*14]%6%`[
M"@II;F-L=61E("<N+V%L;&=O="YI;F,G.PH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]-86EL+W1E<W1S````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,U(#`R,34W,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TUA
M:6PO=&5S=',O<VUT<%]E<G)O<BYP:'!T````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$S,C<@,3`U,34T,S0Q,S4@,#(T-S0U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"DUA:6PZ(%--5%`@
M17)R;W(@4F5P;W)T:6YG"BTM4TM)4$E&+2T*/#]P:'`*"G)E<75I<F5?;VYC
M92`G4$5!4B]296=I<W1R>2YP:'`G.PHD<F5G:7-T<GD@/2`F;F5W(%!%05)?
M4F5G:7-T<GDH*3L*"FEF("@A)')E9VES=')Y+3YP86-K86=E17AI<W1S*"=.
M971?4TU44"<I*2!D:64H(G-K:7!<;B(I.PHM+49)3$4M+0H\/W!H<`IR97%U
M:7)E7V]N8V4@)TUA:6PN<&AP)SL*"B\J(%)E9F5R96YC92!A(&)O9W5S(%--
M5%`@<V5R=F5R(&%D9')E<W,@=&\@9W5A<F%N=&5E(&$@8V]N;F5C=&EO;B!F
M86EL=7)E+B`J+PHD<&%R86US(#T@87)R87DH)VAO<W0G(#T^("=B;V=U<RYH
M;W-T+G1L9"<I.PH*+RH@0W)E871E(&]U<B!33510+6)A<V5D(&UA:6QE<B!O
M8FIE8W0N("HO"B1M86EL97(@/2`F36%I;#HZ9F%C=&]R>2@G<VUT<"<L("1P
M87)A;7,I.PH*+RH@071T96UP="!T;R!S96YD(&%N(&5M<'1Y(&UE<W-A9V4@
M:6X@;W)D97(@=&\@=')I9V=E<B!A;B!E<G)O<BX@*B\*:68@*%!%05(Z.FES
M17)R;W(H)&4@/2`D;6%I;&5R+3YS96YD*&%R<F%Y*"DL(&%R<F%Y*"DL("<G
M*2DI('L*("`@(&1I92@D92T^9V5T365S<V%G92@I("X@(EQN(BD["GT*"BTM
M15A014-4+2T*1F%I;&5D('1O(&-O;FYE8W0@=&\@8F]G=7,N:&]S="YT;&0Z
M,C4@6U--5%`Z($9A:6QE9"!T;R!C;VYN96-T('-O8VME=#H@56YK;F]W;B!E
M<G)O<CH@,"`H8V]D93H@+3$L(')E<W!O;G-E.B`I70H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+TUA:6PO=&5S=',O<F9C.#(R+G!H<'0`````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#4Q,34@,3`U,34T,S0Q,S4@,#(S-34V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM5$535"TM"DUA:6Q?
M4D9#.#(R.B!!9&1R97-S(%!A<G-I;F<*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER
M95]O;F-E("=-86EL+U)&0S@R,BYP:'`G.PH*)'!A<G-E<B`]("9N97<@36%I
M;%]21D,X,C(H*3L*(`HO*B!!('-I;7!L92P@8F%R92!A9&1R97-S+B`J+PHD
M861D<F5S<R`]("=U<V5R0&5X86UP;&4N8V]M)SL*<')I;G1?<B@D<&%R<V5R
M+3YP87)S94%D9')E<W-,:7-T*"1A9&1R97-S+"!N=6QL+"!T<G5E+"!T<G5E
M*2D["@HO*B!!9&1R97-S(&=R;W5P<RX@*B\*)&%D9')E<W,@/2`G37D@1W)O
M=7`Z(")2:6-H87)D(B`\<FEC:&%R9$!L;V-A;&AO<W0^("A!(&-O;6UE;G0I
M+"!T961`97AA;7!L92YC;VT@*%1E9"!";&]G9W,I+"!"87)N97D[)SL*<')I
M;G1?<B@D<&%R<V5R+3YP87)S94%D9')E<W-,:7-T*"1A9&1R97-S+"!N=6QL
M+"!T<G5E+"!T<G5E*2D["@HO*B!!('9A;&ED(&%D9')E<W,@=VET:"!S<&%C
M97,@:6X@=&AE(&QO8V%L('!A<G0N("HO"B1A9&1R97-S(#T@)SPB2F]N(%!A
M<FES92)`<&AP+FYE=#XG.PIP<FEN=%]R*"1P87)S97(M/G!A<G-E061D<F5S
M<TQI<W0H)&%D9')E<W,L(&YU;&PL('1R=64L('1R=64I*3L*"B\J($%N(&EN
M=F%L:60@861D<F5S<R!W:71H('-P86-E<R!I;B!T:&4@;&]C86P@<&%R="X@
M*B\*)&%D9')E<W,@/2`G/$IO;B!087)I<V5`<&AP+FYE=#XG.PHD<F5S=6QT
M(#T@)'!A<G-E<BT^<&%R<V5!9&1R97-S3&ES="@D861D<F5S<RP@;G5L;"P@
M=')U92P@=')U92D["FEF("A014%2.CII<T5R<F]R*"1R97-U;'0I*2!E8VAO
M("1R97-U;'0M/F=E=$UE<W-A9V4H*2`N(")<;B(["@HM+4584$5#5"TM"D%R
M<F%Y"B@*("`@(%LP72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@("`H"B`@
M("`@("`@("`@(%MP97)S;VYA;%T@/3X@"B`@("`@("`@("`@(%MC;VUM96YT
M72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@
M*0H*("`@("`@("`@("`@6VUA:6QB;WA=(#T^('5S97(*("`@("`@("`@("`@
M6VAO<W1=(#T^(&5X86UP;&4N8V]M"B`@("`@("`@*0H**0I!<G)A>0HH"B`@
M("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@
M("!;9W)O=7!N86UE72`]/B!->2!'<F]U<`H@("`@("`@("`@("!;861D<F5S
M<V5S72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@
M("`@("`@(%LP72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@("`@("`@("`@
M("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@6W!E<G-O
M;F%L72`]/B`B4FEC:&%R9"(*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%MC;VUM96YT72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6S!=(#T^($$@8V]M;65N=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("D*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!;;6%I;&)O>%T@
M/3X@<FEC:&%R9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@6VAO<W1=
M(#T^(&QO8V%L:&]S=`H@("`@("`@("`@("`@("`@("`@("`@("`I"@H@("`@
M("`@("`@("`@("`@("`@(%LQ72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@
M("`@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6W!E<G-O;F%L72`]/B`*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%MC;VUM96YT72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6S!=(#T^(%1E9"!";&]G9W,*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@6VUA:6QB;WA=
M(#T^('1E9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@6VAO<W1=(#T^
M(&5X86UP;&4N8V]M"B`@("`@("`@("`@("`@("`@("`@("`@("D*"B`@("`@
M("`@("`@("`@("`@("`@6S)=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@
M("`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!;<&5R<V]N86Q=(#T^(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6V-O;6UE;G1=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!;;6%I;&)O>%T@/3X@0F%R;F5Y
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!;:&]S=%T@/3X@;&]C86QH
M;W-T"B`@("`@("`@("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@("`@
M("`I"@H@("`@("`@("D*"BD*07)R87D**`H@("`@6S!=(#T^('-T9$-L87-S
M($]B:F5C=`H@("`@("`@("@*("`@("`@("`@("`@6W!E<G-O;F%L72`]/B`*
M("`@("`@("`@("`@6V-O;6UE;G1=(#T^($%R<F%Y"B`@("`@("`@("`@("`@
M("`H"B`@("`@("`@("`@("`@("`I"@H@("`@("`@("`@("!;;6%I;&)O>%T@
M/3X@(DIO;B!087)I<V4B"B`@("`@("`@("`@(%MH;W-T72`]/B!P:'`N;F5T
M"B`@("`@("`@*0H**0I686QI9&%T:6]N(&9A:6QE9"!F;W(Z(#Q*;VX@4&%R
M:7-E0'!H<"YN970^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O3F5T7U--5%`O=&5S
M=',`````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$S-2`P,C(S,#$`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T
M97-T<R].971?4TU44"]T97-T<R]B87-I8RYP:'!T````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`Q,S(T(#$P-3$U-#,T,3,U(#`R-#,S-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````M+51%4U0M+0I.971?
M4TU44#H@0F%S:6,@1G5N8W1I;VYA;&ET>0HM+49)3$4M+0H\/W!H<`H*<F5Q
M=6ER95]O;F-E("=.970O4TU44"YP:'`G.PIR97%U:7)E7V]N8V4@)V-O;F9I
M9RYP:'`G.PH*:68@*"$@*"1S;71P(#T@;F5W($YE=%]33510*%1%4U1?2$]3
M5$Y!344L(%1%4U1?4$]25"P@5$535%],3T-!3$A/4U0I*2D@>PH)9&EE*")5
M;F%B;&4@=&\@:6YS=&%N=&EA=&4@3F5T7U--5%`@;V)J96-T7&XB*3L*?0H*
M:68@*%!%05(Z.FES17)R;W(H)&4@/2`D<VUT<"T^8V]N;F5C="@I*2D@>PH)
M9&EE*"1E+3YG971-97-S86=E*"D@+B`B7&XB*3L*?0H*:68@*%!%05(Z.FES
M17)R;W(H)'-M='`M/FUA:6Q&<F]M*%1%4U1?1E)/32DI*2!["@ED:64H)U5N
M86)L92!T;R!S970@<V5N9&5R('1O(#PG("X@5$535%]&4D]-("X@(CY<;B(I
M.PI]"@II9B`H4$5!4CHZ:7-%<G)O<B@D<F5S(#T@)'-M='`M/G)C<'14;RA4
M15-47U1/*2DI('L*"61I92@G56YA8FQE('1O(&%D9"!R96-I<&EE;G0@/"<@
M+B!415-47U1/("X@)SXZ("<@+@H)"21R97,M/F=E=$UE<W-A9V4H*2`N(")<
M;B(I.PI]"@II9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^9&%T82A415-47U-5
M0DI%0U0@+B`B7')<;B(@+B!415-47T)/1%DI*2D@>PH)9&EE*")5;F%B;&4@
M=&\@<V5N9"!D871A7&XB*3L*?0H*)'-M='`M/F1I<V-O;FYE8W0H*3L*"F5C
M:&\@)U-U8V-E<W,A)SL*"BTM15A014-4+2T*4W5C8V5S<R$*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R].971?4TU44"]T97-T<R]C;VYF:6<N<&AP+F1I<W0`````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P-S4P(#$P-3$U-#,T,3,U(#`R-3,P,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*BH*("H@0V]P>2!T:&ES(&9I;&4@=&\@8V]N9FEG+G!H<"!A;F0@8W5S=&]M
M:7IE('1H92!F;VQL;W=I;F<@=F%L=65S('1O"B`J('-U:70@>6]U<B!C;VYF
M:6=U<F%T:6]N+@H@*B\*"F1E9FEN92@G5$535%](3U-43D%-12<L("`@("`G
M;&]C86QH;W-T)RD["F1E9FEN92@G5$535%]03U)4)RP@("`@("`@("`R-2D[
M"F1E9FEN92@G5$535%],3T-!3$A/4U0G+"`@("`G;&]C86QH;W-T)RD["F1E
M9FEN92@G5$535%]!551(7U5315(G+"`@("`G:F]N)RD["F1E9FEN92@G5$53
M5%]!551(7U!!4U,G+"`@("`G<V5C<F5T)RD["F1E9FEN92@G5$535%]&4D]-
M)RP@("`@("`@("`G9G)O;4!E>&%M<&QE+F-O;2<I.PID969I;F4H)U1%4U1?
M5$\G+"`@("`@("`@("`@)W1O0&5X86UP;&4N8V]M)RD["F1E9FEN92@G5$53
M5%]354)*14-4)RP@("`@("`G5&5S="!3=6)J96-T)RD["F1E9FEN92@G5$53
M5%]"3T19)RP@("`@("`@("`G5&5S="!";V1Y)RD["@``````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O
M3F5T7U--5%`O=&5S=',O<75O=&5D871A+G!H<'0`````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,S0P,R`Q,#4Q-30S-#$S-2`P,C4R-#0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+2U415-4+2T*3F5T7U--5%`Z
M('%U;W1E9&%T82@I(%QN('P@7'(@(#T^(%QR7&X@<F5P;&%C96UE;G0*+2U&
M24Q%+2T*/#]P:'`*"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?
M;VYC92`G3F5T+U--5%`N<&AP)SL*"B1T97-T<R`](&%R<F%Y*`H@("`@(EQN
M(B`@("`@("`@("`@("`@(#T^(")<<EQN(BP*("`@(")<<EQN(B`@("`@("`@
M("`@("`]/B`B7')<;B(L"B`@("`B7&YX>"(@("`@("`@("`@("`@/3X@(EQR
M7&YX>"(L"B`@("`B>'A<;B(@("`@("`@("`@("`@/3X@(GAX7')<;B(L"B`@
M("`B>'A<;GAX(B`@("`@("`@("`@/3X@(GAX7')<;GAX(BP*("`@(")<;EQN
M>'@B("`@("`@("`@("`]/B`B7')<;EQR7&YX>"(L"B`@("`B>'A<;EQN>'@B
M("`@("`@("`@/3X@(GAX7')<;EQR7&YX>"(L"B`@("`B>'A<;EQN(B`@("`@
M("`@("`@/3X@(GAX7')<;EQR7&XB+`H@("`@(EQR7&YX>"(@("`@("`@("`@
M(#T^(")<<EQN>'@B+`H@("`@(GAX7')<;B(@("`@("`@("`@(#T^(")X>%QR
M7&XB+`H@("`@(GAX7')<;GAX(B`@("`@("`@(#T^(")X>%QR7&YX>"(L"B`@
M("`B7')<;EQR7&YX>"(@("`@("`@/3X@(EQR7&Y<<EQN>'@B+`H@("`@(GAX
M7')<;EQR7&YX>"(@("`@(#T^(")X>%QR7&Y<<EQN>'@B+`H@("`@(GAX7')<
M;EQR7&XB("`@("`@(#T^(")X>%QR7&Y<<EQN(BP*("`@(")<<EQN7&YX>"(@
M("`@("`@("`]/B`B7')<;EQR7&YX>"(L"B`@("`B7&Y<<EQN>'@B("`@("`@
M("`@/3X@(EQR7&Y<<EQN>'@B+`H@("`@(GAX7')<;EQN>'@B("`@("`@(#T^
M(")X>%QR7&Y<<EQN>'@B+`H@("`@(GAX7&Y<<EQN>'@B("`@("`@(#T^(")X
M>%QR7&Y<<EQN>'@B+`H@("`@(GAX7')<;EQN(B`@("`@("`@(#T^(")X>%QR
M7&Y<<EQN(BP*("`@(")X>%QN7')<;B(@("`@("`@("`]/B`B>'A<<EQN7')<
M;B(L"B`@("`B7'(B("`@("`@("`@("`@("`@/3X@(EQR7&XB+`H@("`@(EQR
M>'@B("`@("`@("`@("`@(#T^(")<<EQN>'@B+`H@("`@(GAX7')X>"(@("`@
M("`@("`@(#T^(")X>%QR7&YX>"(L"B`@("`B>'A<<B(@("`@("`@("`@("`@
M/3X@(GAX7')<;B(L"B`@("`B7')<<B(@("`@("`@("`@("`@/3X@(EQR7&Y<
M<EQN(BP*("`@(")<<EQR>'@B("`@("`@("`@("`]/B`B7')<;EQR7&YX>"(L
M"B`@("`B>'A<<EQR>'@B("`@("`@("`@/3X@(GAX7')<;EQR7&YX>"(L"B`@
M("`B>'A<<EQR(B`@("`@("`@("`@/3X@(GAX7')<;EQR7&XB+`H@("`@(GAX
M7')X>%QN>'A<<EQN>'@B(#T^(")X>%QR7&YX>%QR7&YX>%QR7&YX>"(L"B`@
M("`B7')<<EQN7&XB("`@("`@("`@/3X@(EQR7&Y<<EQN7')<;B(L"BD["@HD
M:&%D17)R;W(@/2!F86QS93L*9F]R96%C:"`H)'1E<W1S(&%S("1I;G!U="`]
M/B`D97AP96-T*2!["B`@("`D;W5T<'5T(#T@)&EN<'5T.PH@("`@3F5T7U--
M5%`Z.G%U;W1E9&%T82@D;W5T<'5T*3L*("`@(&EF("@D;W5T<'5T("$]("1E
M>'!E8W0I('L*("`@("`@("!E8VAO(")%<G)O<CH@:6YP=70@(B`N('!R971T
M>7!R:6YT*"1I;G!U="D@+B`B+"!O=71P=70@(B`N('!R971T>7!R:6YT*"1O
M=71P=70I("X@(BP@97AP96-T960@(B`N('!R971T>7!R:6YT*"1E>'!E8W0I
M("X@(EQN(CL*("`@("`@("`D:&%D17)R;W(@/2!T<G5E.PH@("`@?0I]"@II
M9B`H(21H861%<G)O<BD@>PH@("`@96-H;R`B<W5C8V5S<UQN(CL*?0H*9G5N
M8W1I;VX@<')E='1Y<')I;G0H)'@I"GL*("`@(')E='5R;B!S=')?<F5P;&%C
M92AA<G)A>2@B7'(B+"`B7&XB*2P@87)R87DH)UQR)RP@)UQN)RDL("1X*3L*
M?0H*+2U%6%!%0U0M+0IS=6-C97-S"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+TYE=%]3
M3510+W1E<W1S+V%U=&@N<&AP=```````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#$T,S8@,3`U,34T,S0Q,S4@,#(T,C(R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````"TM5$535"TM"DYE=%]33510.B!33510
M($%U=&AE;G1I8V%T:6]N"BTM1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@
M)TYE="]33510+G!H<"<["G)E<75I<F5?;VYC92`G8V]N9FEG+G!H<"<["@II
M9B`H(2`H)'-M='`@/2!N97<@3F5T7U--5%`H5$535%](3U-43D%-12P@5$53
M5%]03U)4+"!415-47TQ/0T%,2$]35"DI*2!["@ED:64H(E5N86)L92!T;R!I
M;G-T86YT:6%T92!.971?4TU44"!O8FIE8W1<;B(I.PI]"@II9B`H4$5!4CHZ
M:7-%<G)O<B@D92`]("1S;71P+3YC;VYN96-T*"DI*2!["@ED:64H)&4M/F=E
M=$UE<W-A9V4H*2`N(")<;B(I.PI]"@II9B`H4$5!4CHZ:7-%<G)O<B@D92`]
M("1S;71P+3YA=71H*%1%4U1?05542%]54T52+"!415-47T%55$A?4$%34RDI
M*2!["GT*"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YM86EL1G)O;2A415-4
M7T923TTI*2D@>PH)9&EE*"=5;F%B;&4@=&\@<V5T('-E;F1E<B!T;R`\)R`N
M(%1%4U1?1E)/32`N("(^7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H)')E
M<R`]("1S;71P+3YR8W!T5&\H5$535%]43RDI*2!["@ED:64H)U5N86)L92!T
M;R!A9&0@<F5C:7!I96YT(#PG("X@5$535%]43R`N("<^.B`G("X*"0DD<F5S
M+3YG971-97-S86=E*"D@+B`B7&XB*3L*?0H*:68@*%!%05(Z.FES17)R;W(H
M)'-M='`M/F1A=&$H5$535%]354)*14-4("X@(EQR7&XB("X@5$535%]"3T19
M*2DI('L*"61I92@B56YA8FQE('1O('-E;F0@9&%T85QN(BD["GT*"B1S;71P
M+3YD:7-C;VYN96-T*"D["@IE8VAO("=3=6-C97-S(2<["@HM+4584$5#5"TM
M"E-U8V-E<W,A"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S4@,#(Q,3<U`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-2`P,C(T
M-S``(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M8E]F86-T;W)Y+G!H<'0`````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-S$Q
M(#$P-3$U-#,T,3,U(#`R-#(V-@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+51%4U0M+0I$0CHZ9F%C=&]R>0HM+5-+25!)
M1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O
M;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@
M0RLK("TJ+0IR97%U:7)E7V]N8V4@)RXO:6YC;'5D92YI;F,G.PIR97%U:7)E
M7V]N8V4@)T1"+G!H<"<["@HD8F%C:V5N9',@/2!A<G)A>2@*("`@("=D8F%S
M92<L"B`@("`G9F)S<6PG+`H@("`@)VEB87-E)RP*("`@("=I9G@G+`H@("`@
M)VUS<6PG+`H@("`@)VUS<W%L)RP*("`@("=M>7-Q;"<L"B`@("`G;7ES<6QI
M)RP*("`@("=O8VDX)RP*("`@("=O9&)C)RP*("`@("=P9W-Q;"<L"B`@("`G
M<W%L:71E)RP*("`@("=S>6)A<V4G+`HI.PH*9F]R96%C:"`H)&)A8VME;F1S
M(&%S("1N86UE*2!["B`@("`D;V)J(#T@1$(Z.F9A8W1O<GDH)&YA;64I.PH*
M("`@('!R:6YT(")T97-T:6YG("1N86UE.B`B.PH@("`@:68@*$1".CII<T5R
M<F]R*"1O8FHI*2!["@D@("`@<')I;G0@)V5R<F]R.B`G("X@)&]B:BT^9V5T
M365S<V%G92@I("X@(EQN(CL*("`@('T@96QS92!["@D@("`@<')I;G0@)V]B
M:F5C=#H@)R`N("1O8FHM/G1O4W1R:6YG*"D@+B`B7&XB.PH@("`@?0I]"@H_
M/@HM+4=%5"TM"BTM4$]35"TM"BTM15A014-4+2T*=&5S=&EN9R!D8F%S93H@
M;V)J96-T.B!D8E]D8F%S93H@*'!H<'1Y<&4]9&)A<V4L(&1B<WEN=&%X/61B
M87-E*0IT97-T:6YG(&9B<W%L.B!O8FIE8W0Z(&1B7V9B<W%L.B`H<&AP='EP
M93UF8G-Q;"P@9&)S>6YT87@]9F)S<6PI"G1E<W1I;F<@:6)A<V4Z(&]B:F5C
M=#H@9&)?:6)A<V4Z("AP:'!T>7!E/6EB87-E+"!D8G-Y;G1A>#UI8F%S92D*
M=&5S=&EN9R!I9G@Z(&]B:F5C=#H@9&)?:69X.B`H<&AP='EP93UI9G@L(&1B
M<WEN=&%X/6EF>"D*=&5S=&EN9R!M<W%L.B!O8FIE8W0Z(&1B7VUS<6PZ("AP
M:'!T>7!E/6US<6PL(&1B<WEN=&%X/6US<6PI"G1E<W1I;F<@;7-S<6PZ(&]B
M:F5C=#H@9&)?;7-S<6PZ("AP:'!T>7!E/6US<W%L+"!D8G-Y;G1A>#UM<W-Q
M;"D*=&5S=&EN9R!M>7-Q;#H@;V)J96-T.B!D8E]M>7-Q;#H@*'!H<'1Y<&4]
M;7ES<6PL(&1B<WEN=&%X/6UY<W%L*0IT97-T:6YG(&UY<W%L:3H@;V)J96-T
M.B!D8E]M>7-Q;&DZ("AP:'!T>7!E/6UY<W%L:2P@9&)S>6YT87@];7ES<6QI
M*0IT97-T:6YG(&]C:3@Z(&]B:F5C=#H@9&)?;V-I.#H@*'!H<'1Y<&4];V-I
M."P@9&)S>6YT87@];V-I."D*=&5S=&EN9R!O9&)C.B!O8FIE8W0Z(&1B7V]D
M8F,Z("AP:'!T>7!E/6]D8F,L(&1B<WEN=&%X/7-Q;#DR*0IT97-T:6YG('!G
M<W%L.B!O8FIE8W0Z(&1B7W!G<W%L.B`H<&AP='EP93UP9W-Q;"P@9&)S>6YT
M87@]<&=S<6PI"G1E<W1I;F<@<W%L:71E.B!O8FIE8W0Z(&1B7W-Q;&ET93H@
M*'!H<'1Y<&4]<W%L:71E+"!D8G-Y;G1A>#US<6QI=&4I"G1E<W1I;F<@<WEB
M87-E.B!O8FIE8W0Z(&1B7W-Y8F%S93H@*'!H<'1Y<&4]<WEB87-E+"!D8G-Y
M;G1A>#US>6)A<V4I"@``````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+W1E<W1S+T1"+W1E<W1S+V1B7VES;6%N:7`N<&AP=```````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(R-#<@,3`U,34T,S0Q,S4@,#(T,C8S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"TM5$53
M5"TM"D1".CII<TUA;FEP"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M
M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^
M"BTM1DE,12TM"CP_<&AP("\O("TJ+2!#*RL@+2HM"G)E<75I<F5?;VYC92`G
M+B]I;F-L=61E+FEN8R<["G)E<75I<F5?;VYC92`G1$(N<&AP)SL*"F9U;F-T
M:6]N('1E<W0H)'%U97)Y*2!["B`@("!P<FEN=&8H(B5S(#H@)61<;B(L('!R
M96=?<F5P;&%C92@G+UQS*RXJ+R<L("<G+"`D<75E<GDI+`H@("`@("`@("`@
M($1".CII<TUA;FEP*"1Q=65R>2DI.PI]"@IP<FEN="`B=&5S=&EN9R!$0CHZ
M:7--86YI<"XN+EQN(CL*"G1E<W0H(E-%3$5#5"`J($923TT@=&%B;&4B*3L*
M=&5S="@B4V5L96-T("H@9G)O;2!T86)L92(I.PIT97-T*")S96QE8W0@*B!&
M<F]M('1A8FQE(BD["G1E<W0H(G-%;$5#="`J(&9R3VT@=&%B;&4B*3L*=&5S
M="@B4T5,14-4($1)4U1)3D-4(&YA;64@1E)/32!T86)L92(I.PIT97-T*")5
M4$1!5$4@=&%B;&4@4T54(&9O;R`]("=B87(G(BD["G1E<W0H(D1%3$5412!&
M4D]-('1A8FQE(BD["G1E<W0H(F1E;&5T92!F<F]M('1A8FQE('=H97)E(&ED
M(&ES(&YU;&PB*3L*=&5S="@B8W)E871E('1A8FQE("AI9"!I;G1E9V5R+"!N
M86UE('9A<F-H87(H,3`P*2DB*3L*=&5S="@B0U)%051%(%-%455%3D-%(&9O
M;R(I.PIT97-T*")<(D-214%412!04D]#14154D4@9F]O7"(B*3L*=&5S="@B
M1U)!3E0@4T5,14-4($].('1A8FQE(%1/('5S97(B*3L*=&5S="@B4D563TM%
M(%-%3$5#5"!/3B!T86)L92!&4D]-('5S97(B*3L*=&5S="@B4TA/5R!/4%1)
M3TY3(BD["G1E<W0H(D123U`@5$%"3$4@9F]O(BD["G1E<W0H(D%,5$52(%1!
M0DQ%(&9O;R!!1$0@0T],54U.("AB87(@24Y414=%4BDB*3L*=&5S="@B("!3
M14Q%0U0@*B!&4D]-('1A8FQE(BD["G1E<W0H(B`@1$5,151%($923TT@=&%B
M;&4B*3L*/SX*+2U'150M+0HM+5!/4U0M+0HM+4584$5#5"TM"G1E<W1I;F<@
M1$(Z.FES36%N:7`N+BX*4T5,14-4(#H@,`I396QE8W0@.B`P"G-E;&5C="`Z
M(#`*<T5L14-T(#H@,`I314Q%0U0@.B`P"E501$%412`Z(#$*1$5,151%(#H@
M,0ID96QE=&4@.B`Q"F-R96%T92`Z(#$*0U)%051%(#H@,0HB0U)%051%(#H@
M,0I'4D%.5"`Z(#$*4D563TM%(#H@,0I32$]7(#H@,`I$4D]0(#H@,0I!3%1%
M4B`Z(#$*(#H@,`H@.B`Q"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9&)?97)R;W(R+G!H<'0`````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C(S
M-B`Q,#4Q-30S-#$S-2`P,C0P-#``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````+2U415-4+2T*1$(Z.D5R<F]R(#(*+2U32TE0
M248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?
M;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER
M95]O;F-E("<N+VEN8VQU9&4N:6YC)SL*<F5Q=6ER95]O;F-E("=$0BYP:'`G
M.PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"F9U;F-T:6]N(&UY9G5N8R@F
M)&]B:BD@>PH@("`@<')I;G0@)VUY9G5N8R!H97)E+"!O8FH])PH@("`@("`@
M("`@+B!S=')T;VQO=V5R*"1O8FHM/G1O4W1R:6YG*"DI("X@(EQN(CL*?0IF
M=6YC=&EO;B!M>69U;F,R*"8D;V)J*2!["B`@("!P<FEN="`G;7EF=6YC,B!H
M97)E+"!O8FH])PH@("`@("`@("`@+B!S=')T;VQO=V5R*"1O8FHM/G1O4W1R
M:6YG*"DI("X@(EQN(CL*?0IC;&%S<R!M>6-L87-S('L*("`@(&9U;F-T:6]N
M(&UY9G5N8R@F)&]B:BD@>PH@("`@("`@('!R:6YT("=M>6-L87-S.CIM>69U
M;F,@:&5R92P@;V)J/2<*("`@("`@("`@("X@<W1R=&]L;W=E<B@D;V)J+3YT
M;U-T<FEN9R@I*2`N(")<;B(["B`@("!]"GT*9G5N8W1I;VX@=&5S=%]E<G)O
M<E]H86YD;&5R*"1E<G)N;RP@)&5R<FUS9RP@)&9I;&4L("1L:6YE+"`D=F%R
M<RD@>PH@("`@:68@*&1E9FEN960H)T5?4U1224-4)RDI('L*("`@("`@("!I
M9B`H)&5R<FYO("8@15]35%))0U0*("`@("`@("`@("`@)B8@*&5R<F]R7W)E
M<&]R=&EN9R@I("8@15]35%))0U0I("$]($5?4U1224-4*2!["B`@("`@("`@
M("`@("\O($EG;F]R92!%7U-44DE#5"!N;W1I8V5S('5N;&5S<R!T:&5Y(&AA
M=F4@8F5E;B!T=7)N960@;VX*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@('T@96QS92!["B`@("`@("`@9&5F:6YE*"=%7U-44DE#5"<L(#(P
M-#@I.PH@("`@?0H@("`@)&5R<F]R='EP92`](&%R<F%Y("@*("`@("`@("!%
M7T524D]2(#T^("=%<G)O<B<L"B`@("`@("`@15]705).24Y'(#T^("=787)N
M:6YG)RP*("`@("`@("!%7U!!4E-%(#T^("=087)S:6YG($5R<F]R)RP*("`@
M("`@("!%7TY/5$E#12`]/B`G3F]T:6-E)RP*("`@("`@("!%7T-/4D5?15)2
M3U(@/3X@)T-O<F4@17)R;W(G+`H@("`@("`@($5?0T]215]705).24Y'(#T^
M("=#;W)E(%=A<FYI;F<G+`H@("`@("`@($5?0T]-4$E,15]%4E)/4B`]/B`G
M0V]M<&EL92!%<G)O<B<L"B`@("`@("`@15]#3TU024Q%7U=!4DY)3D<@/3X@
M)T-O;7!I;&4@5V%R;FEN9R<L"B`@("`@("`@15]54T527T524D]2(#T^("=5
M<V5R($5R<F]R)RP*("`@("`@("!%7U5315)?5T%23DE.1R`]/B`G57-E<B!7
M87)N:6YG)RP*("`@("`@("!%7U5315)?3D]424-%(#T^("=5<V5R($YO=&EC
M92<L"B`@("`@("`@15]35%))0U0@/3X@)U-T<FEC="!.;W1I8V4G+`H@("`@
M*3L*("`@("1P<F5F:7@@/2`D97)R;W)T>7!E6R1E<G)N;UT["B`@("!P<FEN
M="!S=')T;VQO=V5R*"(D<')E9FEX.B`D97)R;7-G(&EN("(@+B!B87-E;F%M
M92@D9FEL92D*("`@("`@("`@("`@("`@("`@("`@+B`B(&]N(&QI;F4@6%A8
M7&XB*3L*?0H*)&]B:B`](&YE=R!M>6-L87-S.PH*)&1B:"`]($1".CIF86-T
M;W)Y*")M>7-Q;"(I.PH*<')I;G0@(F1E9F%U;'0Z("(["B1E(#T@)&1B:"T^
M<F%I<V5%<G)O<B@B<F5T=7)N('1E<W1I;F<@97)R;W(B*3L*<')I;G0@<W1R
M=&]L;W=E<B@D92T^=&]3=')I;F<H*2D@+B`B7&XB.PH*<')I;G0@(F=L;V)A
M;"!D969A=6QT.B`B.PI014%2.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?0T%,3$)!0TLL(")M>69U;F,R(BD["B1E(#T@)&1B:"T^<F%I<V5%<G)O
M<B@B9VQO8F%L(&1E9F%U;'0@=&5S="(I.PH*)&1B:"T^<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27U!224Y4*3L*<')I;G0@(FUO9&4]<')I;G0Z("([
M"B1E(#T@)&1B:"T^<F%I<V5%<G)O<B@B<')I;G0@=&5S=&EN9R!E<G)O<B(I
M.PIP<FEN="`B7&XB.PH*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27T-!3$Q"04-++"`B;7EF=6YC(BD["G!R:6YT(")M;V1E/69U;F-T:6]N
M(&-A;&QB86-K.B`B.PHD92`]("1D8F@M/G)A:7-E17)R;W(H(F9U;F-T:6]N
M(&-A;&QB86-K('1E<W1I;F<@97)R;W(B*3L*"B1D8F@M/G-E=$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@87)R87DH)&]B:BP@(FUY9G5N
M8R(I*3L*<')I;G0@(FUO9&4];V)J96-T(&-A;&QB86-K.B`B.PHD92`]("1D
M8F@M/G)A:7-E17)R;W(H(F]B:F5C="!C86QL8F%C:R!T97-T:6YG(&5R<F]R
M(BD["@IS971?97)R;W)?:&%N9&QE<B@B=&5S=%]E<G)O<E]H86YD;&5R(BD[
M"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]44DE'1T52*3L*
M<')I;G0@(FUO9&4]=')I9V=E<CH@(CL*)&4@/2`D9&)H+3YR86ES945R<F]R
M*")T<FEG9V5R('1E<W1I;F<@97)R;W(B*3L*"C\^"BTM15A014-4+2T*9&5F
M875L=#H@6V1B7V5R<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@<F5T=7)N('1E
M<W1I;F<@97)R;W(B(&-O9&4]+3$@;6]D93UR971U<FX@;&5V96P];F]T:6-E
M('!R969I>#TB(B!I;F9O/2(@6V1B(&5R<F]R.B!U;FMN;W=N(&5R<F]R72)=
M"F=L;V)A;"!D969A=6QT.B!M>69U;F,R(&AE<F4L(&]B:CU;9&)?97)R;W(Z
M(&UE<W-A9V4](F1B(&5R<F]R.B!G;&]B86P@9&5F875L="!T97-T(B!C;V1E
M/2TQ(&UO9&4]8V%L;&)A8VL@8V%L;&)A8VL];7EF=6YC,B!P<F5F:7@](B(@
M:6YF;STB(%MD8B!E<G)O<CH@=6YK;F]W;B!E<G)O<ETB70IM;V1E/7!R:6YT
M.B!$0B!%<G)O<CH@<')I;G0@=&5S=&EN9R!E<G)O<@IM;V1E/69U;F-T:6]N
M(&-A;&QB86-K.B!M>69U;F,@:&5R92P@;V)J/5MD8E]E<G)O<CH@;65S<V%G
M93TB9&(@97)R;W(Z(&9U;F-T:6]N(&-A;&QB86-K('1E<W1I;F<@97)R;W(B
M(&-O9&4]+3$@;6]D93UC86QL8F%C:R!C86QL8F%C:SUM>69U;F,@<')E9FEX
M/2(B(&EN9F\](B!;9&(@97)R;W(Z('5N:VYO=VX@97)R;W)=(ET*;6]D93UO
M8FIE8W0@8V%L;&)A8VLZ(&UY8VQA<W,Z.FUY9G5N8R!H97)E+"!O8FH]6V1B
M7V5R<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@;V)J96-T(&-A;&QB86-K('1E
M<W1I;F<@97)R;W(B(&-O9&4]+3$@;6]D93UC86QL8F%C:R!C86QL8F%C:SUM
M>6-L87-S.CIM>69U;F,@<')E9FEX/2(B(&EN9F\](B!;9&(@97)R;W(Z('5N
M:VYO=VX@97)R;W)=(ET*;6]D93UT<FEG9V5R.B!U<V5R(&YO=&EC93H@9&(@
M97)R;W(Z('1R:6=G97(@=&5S=&EN9R!E<G)O<B!I;B!P96%R+G!H<"!O;B!L
M:6YE('AX>`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S
M+V5R<F]R<RYI;F,`````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S,V
M,30@,3`U,34T,S0Q,S4@,#(S,C<R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@HO*BH*("H@5&5S=',@=&AE(&1R
M:79E<G,G(&5R<F]R(&UA<'!I;F<*("H*("H@17AE8W5T960@8GD@9')I=F5R
M+S$P97)R;W)M87`N<&AP=`H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@
M*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@
M1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P
M:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U
M<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!E
M<G)O<G,N:6YC+'8@,2XS-2`R,#`U+S`R+S(X(#`R.C`R.C0Q(&1A;FEE;&,@
M17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+T1""B`J+PH*+RHJ"B`J($1E=&5R;6EN92!I9B!T:&4@97)R;W(@9G)O
M;2!T:&4@9')I=F5R(&UA=&-H97,@=&AE(&5R<F]R('=E(&5X<&5C=`H@*@H@
M*B!)9B!T:&EN9W,@87)E(&%S('=E(&5X<&5C="P@<')I;G0@;W5T(")M871C
M:&5S(&5X<&5C=&5D(&]U=&-O;64B"B`J"B`J($EF('1H:6YG<R!G;R!W<F]N
M9RP@<')I;G0@(E5.15A014-4140@3U540T]-12(@86YD(&1I<W!L87D@=&AE
M"B`J(&5R<F]R)W,@:6YF;W)M871I;VXN"B`J"B`J($!P87)A;2!O8FIE8W0@
M("1E("`@("`@("`@("`@("`@("!T:&4@1$)?17)R;W(@;V)J96-T(&9R;VT@
M=&AE('%U97)Y"B`J($!P87)A;2!I;G0@("`@("1E>'!E8W1E9%]D8E]C;V1E
M("!T:&4@1$)?15)23U(J(&-O;G-T86YT('1O(&5X<&5C=`H@*B!`<&%R86T@
M8F]O;&5A;B`D<VAO=6QD7V)E7V5R<F]R("`@9&]E<R!T:&4@1$)-4R!C;VYS
M:61E<B!T:&ES(&%N(&5R<F]R/PH@*@H@*B!`<F5T=7)N('9O:60*("HO"F9U
M;F-T:6]N(&-H96-K7V5R<F]R*"1E+"`D97AP96-T961?9&)?8V]D92P@)'-H
M;W5L9%]B95]E<G)O<B`]('1R=64I('L*("`@(&EF("@D<VAO=6QD7V)E7V5R
M<F]R*2!["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1E*2D@>PH@("`@("`@
M("`@("!I9B`H)&4M/F=E=$-O9&4H*2`]/2`D97AP96-T961?9&)?8V]D92D@
M>PH@("`@("`@("`@("`@("`@<')I;G0@(FUA=&-H97,@97AP96-T960@;W5T
M8V]M95QN(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M('!R:6YT(")53D584$5#5$5$($]55$-/344N+BY<;B(["B`@("`@("`@("`@
M("`@("!P<FEN="`G("`@(%!%05(Z.D1"(&5R<F]R8V]D93H@)R`N("1E+3YG
M971#;V1E*"D@+B`B7&XB.PH@("`@("`@("`@("`@("`@<')I;G0@)R`@("`G
M("X@)&4M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@(EQN("`@(%5.15A0
M14-4140@3U540T]-12XN+B!E>'!E8W1E9"!E<G)O<B!B=70@:70@=V%S;B=T
M7&XB.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1E*2D@>PH@("`@("`@("`@("!P<FEN="`B54Y%6%!%0U1%1"!/
M551#3TU%+BXN(&1I9&XG="!E>'!E8W0@97)R;W(@8G5T(&ET('=A<UQN(CL*
M("`@("`@("`@("`@<')I;G0@)R`@("!014%2.CI$0B!E<G)O<F-O9&4Z("<@
M+B`D92T^9V5T0V]D92@I("X@(EQN(CL*("`@("`@("`@("`@<')I;G0@)R`@
M("`G("X@)&4M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@('!R:6YT(")M871C:&5S(&5X<&5C=&5D(&]U=&-O
M;65<;B(["B`@("`@("`@?0H@("`@?0I]"@HO*BH*("H@3&]C86P@97)R;W(@
M8V%L;&)A8VL@:&%N9&QE<@H@*B`*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%
M05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@
M;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R
M2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@('!R:6YT(")<
M;BTM+2TM+2TM+2TM+2TM+5QN(CL*("`@('!R:6YT(")(879I;F<@<')O8FQE
M;7,@8W)E871I;F<@82!T86)L92!F;W(@=&5S=&EN9RXN+EQN(CL*("`@('!R
M:6YT("1O+3YG971$96)U9TEN9F\H*2`N(")<;B(["B`@("!P<FEN="`B+2TM
M+2TM+2TM+2TM+2TM7&XB.PI]"@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD["@H*<')I;G0@)T1"7T524D]27TY/4U5#2%1!
M0DQ%(&9O<B!S96QE8W0Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH)U-%3$5#
M5"`J($923TT@=&%B;&54:&%T<T)O9W5S)RD["F-H96-K7V5R<F]R*"1R97,L
M($1"7T524D]27TY/4U5#2%1!0DQ%*3L*"G!R:6YT("=$0E]%4E)/4E].3U-5
M0TA404),12!F;W(@9')O<#H@("<["B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L
M("=T86)L951H871S0F]G=7,G*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?15)2
M3U)?3D]354-(5$%"3$4I.PH*<')I;G0@)T1"7T524D]27TY/5%]&3U5.1"!F
M;W(@9')O<"!I;F1E>#H@("<["G-W:71C:"`H)&1B:"T^<&AP='EP92`N("<Z
M)R`N("1D8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=F8G-Q;#IF8G-Q;"<Z
M"B`@("!C87-E("=I8F%S93IF:7)E8FER9"<Z"B`@("!C87-E("=I8F%S93II
M8F%S92<Z"B`@("!C87-E("=I9G@Z:69X)SH*("`@(&-A<V4@)V]D8F,Z9&(R
M)SH*("`@(&-A<V4@)V]C:3@Z;V-I."<Z"B`@("!C87-E("=P9W-Q;#IP9W-Q
M;"<Z"B`@("!C87-E("=S<6QI=&4Z<W%L:71E)SH*("`@("`@("`D<F5S(#T@
M)&1B:"T^<75E<GDH)T123U`@24Y$15@@9F%K96EN9&5X)RD["B`@("`@("`@
M8G)E86L["B`@("!C87-E("=M<W-Q;#IM<W-Q;"<Z"B`@("!C87-E("=S>6)A
M<V4Z<WEB87-E)SH*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T123U`@
M24Y$15@@<&AP=&5S="YF86ME:6YD97@G*3L*("`@("`@("!B<F5A:SL*("`@
M(&-A<V4@)VUS<6PZ;7-Q;"<Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y
M*"=$4D]0($E.1$58(&9A:V5I;F1E>"!&4D]-('!H<'1E<W0G*3L*("`@("`@
M("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U
M97)Y*"=$4D]0($E.1$58(&9A:V5I;F1E>"!/3B!P:'!T97-T)RD["GT*8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?3D]47T9/54Y$*3L*"@IP<FEN="`G
M1$)?15)23U)?04Q214%$65]%6$E35%,@9F]R(&-R96%T92!T86)L93H@("<[
M"B1R97,@/2`D9&)H+3YQ=65R>2@D=&5S=%]M:W1A8FQE7W%U97)Y*3L*8VAE
M8VM?97)R;W(H)')E<RP@1$)?15)23U)?04Q214%$65]%6$E35%,I.PH*<')I
M;G0@)T1"7T524D]27T%,4D5!1%E?15A)4U13(&9O<B!C<F5A=&4@:6YD97@Z
M("`G.PHD<F5S(#T@9')O<%]T86)L92@D9&)H+"`G82<I.PHD9&)H+3YP=7-H
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*)')E
M<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)3E1%1T52*2<I
M.PHD9&)H+3YP;W!%<G)O<DAA;F1L:6YG*"D["B1R97,@/2`D9&)H+3YQ=65R
M>2@G0U)%051%($E.1$58(&%A7VED>"!/3B!A("AA*2<I.PHD<F5S(#T@)&1B
M:"T^<75E<GDH)T-214%412!)3D1%6"!A85]I9'@@3TX@82`H82DG*3L*<W=I
M=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=F8G-Q;"<Z"B`@("`@
M("`@+R\@1G)O;G1"87-E(&1O97-N)W0@87-S:6=N(&$@<W!E8VEF:6,@8V]D
M92!F;W(@=&AI<R!Y970N"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?
M15)23U)?04Q214%$65]%6$E35%,L(&9A;'-E*3L*("`@("`@("!B<F5A:SL*
M("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)2
M3U)?04Q214%$65]%6$E35%,I.PI]"B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L
M("=A)RD["@H*<')I;G0@)T1"7T524D]27T-/3E-44D%)3E0@9F]R('!R:6UA
M<GD@:V5Y(&EN<V5R="!D=7!L:6-A=&4Z("`G.PHD<F5S(#T@9')O<%]T86)L
M92@D9&)H+"`G82<I.PHD9&)H+3YP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27T-!3$Q"04-++"`G<&4G*3L*<W=I=&-H("@D9&)H+3YP:'!T>7!E*2![
M"B`@("!C87-E("=M<W%L)SH*("`@("`@("`D<F5S(#T@)&1B:"T^<75E<GDH
M)T-214%412!404),12!A("AA($E.5$5'15(@3D]4($Y53$PI)RD["B`@("`@
M("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@54Y)455%($E.1$58(&%P
M:R!/3B!A("AA*2<I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@
M("`@("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!A("AA($E.
M5$5'15(@3D]4($Y53$PL(%!224U!4ED@2T59("AA*2DG*3L*?0HD9&)H+3YP
M;W!%<G)O<DAA;F1L:6YG*"D["B1R97,@/2`D9&)H+3YQ=65R>2@G24Y315)4
M($E.5$\@82!604Q515,@*#$I)RD["B1R97,@/2`D9&)H+3YQ=65R>2@G24Y3
M15)4($E.5$\@82!604Q515,@*#$I)RD["F-H96-K7V5R<F]R*"1R97,L($1"
M7T524D]27T-/3E-44D%)3E0I.PH*"G!R:6YT("=$0E]%4E)/4E]#3TY35%)!
M24Y4(&9O<B!P<FEM87)Y(&ME>2!U<&1A=&4@9'5P;&EC871E.B`@)SL*)')E
M<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!A(%9!3%5%4R`H,BDG*3L*
M)')E<R`]("1D8F@M/G%U97)Y*"=54$1!5$4@82!3150@83TQ(%=(15)%(&$]
M,B<I.PIC:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y4*3L*
M"@IP<FEN="`G1$)?15)23U)?0T].4U1204E.5"!F;W(@=6YI<75E(&ME>2!I
M;G-E<G0@9'5P;&EC871E.B`@)SL*)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@
M)V$G*3L*)&1B:"T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,
M0D%#2RP@)W!E)RD["G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S
M92`G;7-Q;"<Z"B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@
M5$%"3$4@82`H82!)3E1%1T52($Y/5"!.54Q,*2<I.PH@("`@("`@("1R97,@
M/2`D9&)H+3YQ=65R>2@G0U)%051%(%5.25%512!)3D1%6"!A=6L@3TX@82`H
M82DG*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@)')E
M<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)3E1%1T52($Y/
M5"!.54Q,+"!53DE1544@*&$I*2<I.PI]"B1D8F@M/G!O<$5R<F]R2&%N9&QI
M;F<H*3L*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!A(%9!3%5%
M4R`H,2DG*3L*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!A(%9!
M3%5%4R`H,2DG*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?0T].4U12
M04E.5"D["@H*<')I;G0@)T1"7T524D]27T-/3E-44D%)3E0@9F]R('5N:7%U
M92!K97D@=7!D871E(&1U<&QI8V%T93H@("<["B1R97,@/2`D9&)H+3YQ=65R
M>2@G24Y315)4($E.5$\@82!604Q515,@*#(I)RD["B1R97,@/2`D9&)H+3YQ
M=65R>2@G55!$051%(&$@4T54(&$],2!72$5212!A/3(G*3L*8VAE8VM?97)R
M;W(H)')E<RP@1$)?15)23U)?0T].4U1204E.5"D["@H*<')I;G0@)T1"7T52
M4D]27T-/3E-44D%)3E0@9F]R(&9O<F5I9VX@:V5Y(&]N(&EN<V5R=#H@("<[
M"B1R97,@/2!D<F]P7W1A8FQE*"1D8F@L("=B)RD["B1R97,@/2!D<F]P7W1A
M8FQE*"1D8F@L("=A)RD["B1D8F@M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?0T%,3$)!0TLL("=P92<I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I
M('L*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@
M("`@)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@82`H82!)3E0@
M3D]4($Y53$PL("<*("`@("`@("`@("`@("`@("`@("`N("=04DE-05)9($M%
M62`H82DI("<*("`@("`@("`@("`@("`@("`@("`N("=465!%/4E.3D]$0B<I
M.PH@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!0DQ%(&(@
M*&(@24Y4+"`G"B`@("`@("`@("`@("`@("`@("`@+B`G24Y$15@@<&%R7VEN
M9"`H8BDL("<*("`@("`@("`@("`@("`@("`@("`N("=&3U)%24=.($M%62`H
M8BD@4D5&15)%3D-%4R!A("AA*2D@)PH@("`@("`@("`@("`@("`@("`@("X@
M)U194$4]24Y.3T1")RD["B`@("`@("`@)&1B:"T^<&]P17)R;W)(86YD;&EN
M9R@I.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)VUS<6PG.@H@("`@("`@
M("\O(&US<6P@9&]E<R!N;W0@<W5P<&]R="!F;W)E:6=N(&ME>7,*("`@("`@
M("`D<F5S(#T@)&1B:"T^<75E<GDH)T-214%412!404),12!A("AA($E.5$5'
M15(@3D]4($Y53$PI)RD["B`@("`@("`@)')E<R`]("1D8F@M/G%U97)Y*"=#
M4D5!5$4@54Y)455%($E.1$58(&%U:R!/3B!A("AA*2<I.PH@("`@("`@("1D
M8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`D<F5S(#T@)&1B:"T^
M<75E<GDH)T-214%412!404),12!B("AB($E.5$5'15(@4D5&15)%3D-%4R!A
M("AA*2DG*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@
M("`@("`@("`@<')I;G0@(FUA=&-H97,@97AP96-T960@;W5T8V]M95QN(CL*
M("`@("`@("`@("`@<')I;G0@(D1"7T524D]27T-/3E-44D%)3E0@9F]R(&9O
M<F5I9VX@:V5Y(&]N(&1E;&5T93H@(&UA=&-H97,@97AP96-T960@;W5T8V]M
M95QN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B5T]7
M+"!I="!S965M<R!M4U%,(&YO=R!S=7!P;W)T<R!R969E<F5N8V5S7&XB.PH@
M("`@("`@("`@("!P<FEN="`B5T]7+"!I="!S965M<R!M4U%,(&YO=R!S=7!P
M;W)T<R!R969E<F5N8V5S7&XB.PH@("`@("`@('T*("`@("`@("!B<F5A:SL*
M"B`@("!D969A=6QT.@H@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%
M051%(%1!0DQ%(&$@*&$@24Y414=%4B!.3U0@3E5,3"P@4%))34%262!+15D@
M*&$I*2<I.PH@("`@("`@("1R97,@/2`D9&)H+3YQ=65R>2@G0U)%051%(%1!
M0DQ%(&(@*&(@24Y414=%4B!2149%4D5.0T53(&$@*&$I*2<I.PH@("`@("`@
M("1D8F@M/G!O<$5R<F]R2&%N9&QI;F<H*3L*?0H*:68@*"1D8F@M/G!H<'1Y
M<&4@(3T@)VUS<6PG*2!["B`@("`D<F5S(#T@)&1B:"T^<75E<GDH)TE.4T52
M5"!)3E1/(&$@*&$I('9A;'5E<R`H,2DG*3L*("`@("1R97,@/2`D9&)H+3YQ
M=65R>2@G24Y315)4($E.5$\@8B`H8BD@=F%L=65S("@R*2<I.PH@("`@<W=I
M=&-H("@D9&)H+3YP:'!T>7!E*2!["B`@("`@("`@8V%S92`G<W%L:71E)SH*
M("`@("`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?0T].4U12
M04E.5"P@9F%L<V4I.PH@("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]#
M3TY35%)!24Y4*3L*("`@('T@("`*"B`@("!P<FEN="`G1$)?15)23U)?0T].
M4U1204E.5"!F;W(@9F]R96EG;B!K97D@;VX@9&5L971E.B`@)SL*("`@("1R
M97,@/2`D9&)H+3YQ=65R>2@G24Y315)4($E.5$\@8B`H8BD@=F%L=65S("@Q
M*2<I.PH@("`@)')E<R`]("1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!A(%=(
M15)%(&$@/2`Q)RD["B`@("!S=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@
M("`@("!C87-E("=S<6QI=&4G.@H@("`@("`@("`@("!C:&5C:U]E<G)O<B@D
M<F5S+"!$0E]%4E)/4E]#3TY35%)!24Y4+"!F86QS92D["B`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@(&-H96-K7V5R
M<F]R*"1R97,L($1"7T524D]27T-/3E-44D%)3E0I.PH@("`@?0I]"@H*<')I
M;G0@)T1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$P@;VX@:6YS97)T.B`@
M)SL*)')E<R`](&1R;W!?=&%B;&4H)&1B:"P@)W!E87)T97-T;G5L;"<I.PHD
M9&)H+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M<&4G*3L*)')E<R`]("1D8F@M/G%U97)Y*"=#4D5!5$4@5$%"3$4@<&5A<G1E
M<W1N=6QL("AA($-(05(H,RD@3D]4($Y53$PI)RD["B1D8F@M/G!O<$5R<F]R
M2&%N9&QI;F<H*3L*)')E<R`]("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!P
M96%R=&5S=&YU;&P@5D%,5453("A.54Q,*2<I.PIC:&5C:U]E<G)O<B@D<F5S
M+"!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,*3L*"@IP<FEN="`G1$)?
M15)23U)?0T].4U1204E.5%].3U1?3E5,3"!O;B!U<&1A=&4Z("`G.PHD<F5S
M(#T@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!E87)T97-T;G5L;"!604Q5
M15,@*"=O;F4G*2(I.PHD<F5S(#T@)&1B:"T^<75E<GDH(E501$%412!P96%R
M=&5S=&YU;&P@4T54(&$@/2!.54Q,(%=(15)%(&$@/2`G;VYE)R(I.PIS=VET
M8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A
M<V4@)VUY<W%L:2<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)2
M3U)?0T].4U1204E.5%].3U1?3E5,3"P@9F%L<V4I.PH@("`@("`@(&)R96%K
M.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%
M4E)/4E]#3TY35%)!24Y47TY/5%].54Q,*3L*?0H*"G!R:6YT("=$0E]%4E)/
M4E].3U-50TA&245,1"!J;VEN:6YG($].(&)O9W5S(&-O;'5M;CH@("<["B1R
M97,@/2`D9&)H+3YQ=65R>2@G4T5,14-4("H@1E)/32!P:'!T97-T($I/24X@
M82!/3B`H<&AP=&5S="YA(#T@82YB*2<I.PIS=VET8V@@*"1D8F@M/G!H<'1Y
M<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G;7-Q;#IM
M<W%L)SH*("`@(&-A<V4@)V]D8F,Z86-C97-S)SH*("`@("`@("!C:&5C:U]E
M<G)O<B@D<F5S+"!$0E]%4E)/4E]364Y405@I.PH@("`@("`@(&)R96%K.PH@
M("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/
M4E].3U-50TA&245,1"D["GT*"@IP<FEN="`G1$)?15)23U)?3D]354-(1DE%
M3$0@:F]I;FEN9R!54TE.1R!B;V=U<R!C;VQU;6XZ("`G.PHD<F5S(#T@)&1B
M:"T^<75E<GDH)U-%3$5#5"`J($923TT@<&AP=&5S="!*3TE.(&$@55-)3D<@
M*&(I)RD["G-W:71C:"`H)&1B:"T^<&AP='EP92`N("<Z)R`N("1D8F@M/F1B
M<WEN=&%X*2!["B`@("!C87-E("=I8F%S93II8F%S92<Z"B`@("!C87-E("=I
M8F%S93IF:7)E8FER9"<Z"B`@("!C87-E("=M<W%L.FUS<6PG.@H@("`@8V%S
M92`G;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G;V1B8SID8C(G.@H@("`@8V%S
M92`G<WEB87-E.G-Y8F%S92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?4UE.5$%8*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z
M"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?3D]354-(1DE%
M3$0I.PI]"@H*<')I;G0@)T1"7T524D]27T1)5EI%4D\Z("`G.PHO+R!);G1E
M<F)A<V4@9&5T96-T<R!T:&4@97)R;W(@;VX@9F5T8VAI;F<*)')E<R`]("1D
M8F@M/F=E=$%L;"@G4T5,14-4(#`O,"!&4D]-('!H<'1E<W0G*3L*<W=I=&-H
M("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=O9&)C)SH*("`@("`@("!S
M=VET8V@@*"1D8F@M/F1B<WEN=&%X*2!["B`@("`@("`@("`@(&-A<V4@)V%C
M8V5S<R<Z"B`@("`@("`@("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%
M4E)/4E]$259:15)/+"!F86QS92D["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`G9&(R)SH*("`@("`@("`@("`@("`@(&-H96-K
M7V5R<F]R*"1R97,L($1"7T524D]27T1)5EI%4D\I.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@?0H@("`@("`@(&)R96%K.PH@("`@8V%S92`G
M:6)A<V4G.@H@("`@8V%S92`G:69X)SH*("`@(&-A<V4@)V9B<W%L)SH*("`@
M(&-A<V4@)VUS<W%L)SH*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A<V4@)VUY
M<W%L:2<Z"B`@("!C87-E("=S<6QI=&4G.@H@("`@8V%S92`G<WEB87-E)SH*
M("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]$259:15)/+"!F
M86QS92D["B`@("`@("`@8G)E86L["B`@("!C87-E("=M<W%L)SH*("`@("`@
M("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E]364Y405@I.PH@("`@("`@
M(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S
M+"!$0E]%4E)/4E]$259:15)/*3L*?0H*"G!R:6YT("=$0E]%4E)/4E])3E9!
M3$E$7TY534)%4B!P=71T:6YG(&-H87)S(&EN($E.5"!C;VQU;6XZ("`G.PHD
M<F5S(#T@)&1B:"T^<75E<GDH(E501$%412!P:'!T97-T(%-%5"!A(#T@)V%B
M8R<@5TA%4D4@82`](#0R(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@
M("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G;7ES<6QI)SH*("`@(&-A<V4@
M)W-Q;&ET92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?
M24Y604Q)1%].54U"15(L(&9A;'-E*3L*("`@("`@("!B<F5A:SL*("`@(&1E
M9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y6
M04Q)1%].54U"15(I.PI]"@H*<')I;G0@)T1"7T524D]27TE.5D%,241?3E5-
M0D52('!U='1I;F<@9FQO870@:6X@24Y4(&-O;'5M;CH@("<["B1R97,@/2`D
M9&)H+3YQ=65R>2@B55!$051%('!H<'1E<W0@4T54(&$@/2`X+CD@5TA%4D4@
M82`](#0R(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G
M9F)S<6PG.@H@("`@8V%S92`G:6)A<V4G.@H@("`@8V%S92`G:69X)SH*("`@
M(&-A<V4@)VUS<W%L)SH*("`@(&-A<V4@)VUY<W%L)SH*("`@(&-A<V4@)VUY
M<W%L:2<Z"B`@("!C87-E("=O8VDX)SH*("`@(&-A<V4@)V]D8F,G.@H@("`@
M8V%S92`G<&=S<6PG.@H@("`@8V%S92`G<W%L:71E)SH*("`@("`@("!C:&5C
M:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP@9F%L<V4I
M.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E
M<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$7TY534)%4BD["GT*"@IP<FEN
M="`G1$)?15)23U)?24Y604Q)1%].54U"15(@<'5T=&EN9R!E>&-E<W-I=F4@
M:6YT(&EN($E.5"!C;VQU;6XZ("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH(E50
M1$%412!P:'!T97-T(%-%5"!A(#T@,3@T-#8W-#0P-S,W,#DU-3$V,38@5TA%
M4D4@82`](#0R(BD["G-W:71C:"`H)&1B:"T^<&AP='EP92`N("<Z)R`N("1D
M8F@M/F1B<WEN=&%X*2!["B`@("!C87-E("=I8F%S93II8F%S92<Z"B`@("!C
M87-E("=I8F%S93IF:7)E8FER9"<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E
M<RP@1$)?15)23U)?4UE.5$%8*3L*("`@("`@("!B<F5A:SL*("`@(&-A<V4@
M)V9B<W%L.F9B<W%L)SH*("`@(&-A<V4@)VUS<6PZ;7-Q;"<Z"B`@("!C87-E
M("=M<W-Q;#IM<W-Q;"<Z"B`@("!C87-E("=M>7-Q;#IM>7-Q;"<Z"B`@("!C
M87-E("=M>7-Q;&DZ;7ES<6QI)SH*("`@(&-A<V4@)V]C:3@Z;V-I."<Z"B`@
M("!C87-E("=O9&)C.F%C8V5S<R<Z"B`@("!C87-E("=S<6QI=&4Z<W%L:71E
M)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$
M7TY534)%4BP@9F%L<V4I.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*
M("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])3E9!3$E$7TY5
M34)%4BD["GT*"@IP<FEN="`G1$)?15)23U)?24Y604Q)1%].54U"15(@<'5T
M=&EN9R!I;G0@:6X@0TA!4B!C;VQU;6XZ("`G.PHD<F5S(#T@)&1B:"T^<75E
M<GDH(E501$%412!P:'!T97-T(%-%5"!B(#T@."!72$5212!A(#T@-#(B*3L*
M<W=I=&-H("@D9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@I
M('L*("`@(&-A<V4@)VEB87-E.FEB87-E)SH*("`@(&-A<V4@)VEB87-E.F9I
M<F5B:7)D)SH*("`@(&-A<V4@)VEF>#II9G@G.@H@("`@8V%S92`G;7-S<6PZ
M;7-S<6PG.@H@("`@8V%S92`G;7ES<6PZ;7ES<6PG.@H@("`@8V%S92`G;7ES
M<6QI.FUY<W%L:2<Z"B`@("!C87-E("=O8VDX.F]C:3@G.@H@("`@8V%S92`G
M;V1B8SIA8V-E<W,G.@H@("`@8V%S92`G<&=S<6PZ<&=S<6PG.@H@("`@8V%S
M92`G<W%L:71E.G-Q;&ET92<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?24Y604Q)1%].54U"15(L(&9A;'-E*3L*("`@("`@("!B<F5A
M:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?
M15)23U)?24Y604Q)1%].54U"15(I.PI]"@H*<')I;G0@)T1"7T524D]27TY/
M4U5#2$9)14Q$.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y*"=314Q%0U0@92!&
M4D]-('!H<'1E<W0G*3L*8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?3D]3
M54-(1DE%3$0I.PH*"G!R:6YT("=$0E]%4E)/4E]364Y405@Z("`G.PHD<F5S
M(#T@)&1B:"T^<75E<GDH)T-214%412<I.PIC:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E]364Y405@I.PH*"G!R:6YT("=$0E]%4E)/4E]604Q515]#3U5.
M5%]/3E]23U<Z("`G.PHD<F5S(#T@)&1B:"T^<75E<GDH)TE.4T525"!)3E1/
M('!H<'1E<W0@*&$I(%9!3%5%4R`H-C<X+"`R*2<I.PIS=VET8V@@*"1D8F@M
M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VUS<6PG.@H@("`@("`@(&-H96-K7V5R
M<F]R*"1R97,L($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP@9F%L<V4I
M.PH@("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("!C:&5C:U]E
M<G)O<B@D<F5S+"!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<I.PI]"@H*
M<')I;G0@)T1"7T524D]27TE.5D%,240@;VX@0TA!4B!C;VQU;6X@9&%T82!T
M;V\@;&]N9SH@("<["B1R97,@/2`D9&)H+3YQ=65R>2@B24Y315)4($E.5$\@
M<&AP=&5S="`H8BD@5D%,5453("@G,3(S-#4V-S@Y+C$R,S0U-C<X.2XQ,C,T
M-38W.#DN,3(S-#4V-S@Y+C$G*2(I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4@
M+B`G.B<@+B`D9&)H+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G;7-Q;#IM<W%L
M)SH*("`@(&-A<V4@)VUS<W%L.FUS<W%L)SH*("`@(&-A<V4@)VUY<W%L.FUY
M<W%L)SH*("`@(&-A<V4@)VUY<W%L:3IM>7-Q;&DG.@H@("`@8V%S92`G;V1B
M8SIA8V-E<W,G.@H@("`@8V%S92`G<W%L:71E.G-Q;&ET92<Z"B`@("!C87-E
M("=S>6)A<V4Z<WEB87-E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$
M0E]%4E)/4E])3E9!3$E$+"!F86QS92D["B`@("`@("`@8G)E86L["B`@("!C
M87-E("=F8G-Q;#IF8G-Q;"<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@
M1$)?15)23U)?5%)53D-!5$5$*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U
M;'0Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)
M1"D["GT*"@IP<FEN="`G1$)?15)23U)?24Y604Q)1"!O;B!605)#2$%2(&-O
M;'5M;B!D871A('1O;R!L;VYG.B`@)SL*)')E<R`]("1D8F@M/G%U97)Y*"))
M3E-%4E0@24Y43R!P:'!T97-T("AD*2!604Q515,@*"<Q,C,T-38W.#DN,3(S
M-#4V-S@Y+C$G*2(I.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D
M9&)H+3YD8G-Y;G1A>"D@>PH@("`@8V%S92`G;7-Q;#IM<W%L)SH*("`@(&-A
M<V4@)VUS<W%L.FUS<W%L)SH*("`@(&-A<V4@)VUY<W%L.FUY<W%L)SH*("`@
M(&-A<V4@)VUY<W%L:3IM>7-Q;&DG.@H@("`@8V%S92`G;V1B8SIA8V-E<W,G
M.@H@("`@8V%S92`G<W%L:71E.G-Q;&ET92<Z"B`@("!C87-E("=S>6)A<V4Z
M<WEB87-E)SH*("`@("`@("!C:&5C:U]E<G)O<B@D<F5S+"!$0E]%4E)/4E])
M3E9!3$E$+"!F86QS92D["B`@("`@("`@8G)E86L["B`@("!C87-E("=F8G-Q
M;#IF8G-Q;"<Z"B`@("`@("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?
M5%)53D-!5$5$*3L*("`@("`@("!B<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@
M("`@8VAE8VM?97)R;W(H)')E<RP@1$)?15)23U)?24Y604Q)1"D["GT*"@H*
M9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PID<F]P7W1A8FQE*"1D8F@L
M("=B)RD["F1R;W!?=&%B;&4H)&1B:"P@)V$G*3L*9')O<%]T86)L92@D9&)H
M+"`G<&5A<G1E<W1N=6QL)RD["@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]F
M971C:&UO9&5?;V)J96-T+FEN8P``````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,C(W
M(#$P-3$U-#,T,3,U(#`R-3(T,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!D<FEV
M97)S)R!O8FIE8W0@9F5T8V@@;6]D92!P<F]C961U<F5S"B`J"B`J($5X96-U
M=&5D(&)Y(&1R:79E<B\Q-&9E=&-H;6]D95]O8FIE8W0N<&AP=`H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@)$ED.B!F971C:&UO9&5?;V)J96-T+FEN8RQV(#$N
M,3$@,C`P-2\P,B\P,R`P-3HT.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"F5R
M<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO*BH*("H@3&]C86P@97)R;W(@8V%L
M;&)A8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S="!T86)L92P@
M<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@
M<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@
M;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J
M($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D9&)H.PH*("`@
M("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@
M("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@(&1I92@D;RT^
M=&]3=')I;F<H*2D["GT*"B\J*@H@*B!0<FEN="!O=70@=&AE(&]B:F5C=`H@
M*B\*9G5N8W1I;VX@<')I;G1?;V)J*"8D;V)J*2!["B`@("!I9B`H(6ES7V]B
M:F5C="@D;V)J*2D@>PH@("`@("`@(&5C:&\@(D524D]2.B!N;R!O8FIE8W0A
M7&XB.PH@("`@?2!E;'-E('L*("`@("`@("!E8VAO('-T<G1O;&]W97(H9V5T
M7V-L87-S*"1O8FHI*2`N("<@+3X@)R`N(&EM<&QO9&4H)R`G+"!A<G)A>5]K
M97ES*"AA<G)A>2DD;V)J*2D@+B`B7&XB.PH@("`@?0I]"@H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"F5C
M:&\@(BTM+2!F971C:"!W:71H('!A<F%M($1"7T9%5$-(34]$15]/0DI%0U0@
M+2TM7&XB.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP
M=&5S="(I.PHD<F]W(#T@)'-T:"T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]"
M2D5#5"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"T^9G)E92@I.R`@+R\@:V5E
M<"!F8G-Q;"!H87!P>2X*"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@
M1E)/32!P:'!T97-T(BD["B1S=&@M/F9E=&-H26YT;R@D<F]W+"!$0E]&151#
M2$U/1$5?3T)*14-4*3L*<')I;G1?;V)J*"1R;W<I.PHD<W1H+3YF<F5E*"D[
M("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*96-H;R`B+2TM(&9E=&-H('=I=&@@
M9&5F875L="!F971C:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"`M+2U<;B([
M"B1D8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?3T)*14-4*3L*)'-T
M:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O
M=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R:6YT7V]B:B@D<F]W*3L*)'-T:"T^
M9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"B1S=&@@/2`D9&)H+3YQ
M=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1S=&@M/F9E=&-H26YT
M;R@D<F]W*3L*<')I;G1?;V)J*"1R;W<I.PHD<W1H+3YF<F5E*"D[("`O+R!K
M965P(&9B<W%L(&AA<'!Y+@H*96-H;R`B+2TM(&9E=&-H('=I=&@@9&5F875L
M="!F971C:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"!A;F0@8VQA<W,@1$)?
M<F]W("TM+5QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/
M0DI%0U0L("=$0E]R;W<G*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@
M*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*"D["G!R
M:6YT7V]B:B@D<F]W*3L*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H
M87!P>2X*"B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T
M97-T(BD["B1S=&@M/F9E=&-H26YT;R@D<F]W*3L*<')I;G1?;V)J*"1R;W<I
M.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*96-H;R`B
M+2TM(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-3T1%
M7T]"2D5#5"!W:71H(&YO(&-L87-S('1H96X@1$)?<F]W("TM+5QN(CL*)&1B
M:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/0DI%0U0I.PHD<W1H(#T@
M)&1B:"T^<75E<GDH)U-%3$5#5"`J($923TT@<&AP=&5S="<I.PHD<F]W(#T@
M)'-T:"T^9F5T8VA2;W<H*3L*<')I;G1?;V)J*"1R;W<I.PHD<W1H+3YF<F5E
M*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*)&1B:"T^<V5T1F5T8VA-;V1E
M*$1"7T9%5$-(34]$15]/0DI%0U0L("=$0E]R;W<G*3L*)'-T:"`]("1D8F@M
M/G%U97)Y*"=314Q%0U0@*B!&4D]-('!H<'1E<W0G*3L*)')O=R`]("1S=&@M
M/F9E=&-H4F]W*"D["G!R:6YT7V]B:B@D<F]W*3L*"B1S=&@M/F9R964H*3L@
M("\O(&ME97`@9F)S<6P@:&%P<'DN"B`@("`@("`@("`@("`@("\O(&ME97`@
M:6)A<V4@:&%P<'DZ(&-A;B=T(&1R;W`@=&)L('1H870@:&%S(')E<W5L=',@
M;W!E;B!A9V%I;G-T(&ET+@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O
M9F5T8VAM;V1E<RYI;F,`````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S,V
M,B`Q,#4Q-30S-#$S-2`P,C0P-S4`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@9')I
M=F5R<R<@=F%R:6]U<R!F971C:"!M971H;V1S"B`J"B`J($5X96-U=&5D(&)Y
M(&1R:79E<B\P,F9E=&-H+G!H<'0*("H*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J
M('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E
M("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE
M;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)
M9#H@9F5T8VAM;V1E<RYI;F,L=B`Q+C$Q(#(P,#4O,#(O,30@,3<Z,#0Z,30@
M9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A
M8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I
M;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O
M8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J
M96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R
M971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@
M*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D
M8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@
M9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@(&1I92@D;RT^=&]3
M=')I;F<H*2D["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]#04Q,0D%#2RP@)W!E)RD["B1D8F@M/G-E=$]P=&EO;B@G875T;V9R964G
M+"!T<G5E*3L*"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!
M3%5%4R`H,2P@)V]N92<L("=/;F4G+"`G,C`P,2TP,BTQ-B<I(BD["B1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,BP@)W1W;R<L
M("=4=V\G+"`G,C`P,2TP,BTQ-2<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@
M24Y43R!P:'!T97-T(%9!3%5%4R`H,RP@)W1H<F5E)RP@)U1H<F5E)RP@)S(P
M,#$M,#(M,30G*2(I.PH*<')I;G0@(G1E<W1I;F<@9F5T8VAR;W<Z7&XB.PHD
M<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PIF
M;W(@*"1I(#T@,3L@)&D@/#T@-3L@)&DK*RD@>PH@("`@<')I;G0@(G)O=R`D
M:3H@(CL*("`@("1R;W<@/2`D<W1H+3YF971C:%)O=R@I.PH@("`@:68@*$1"
M.CII<T5R<F]R*"1R;W<I*2!["B`@("`@("`@<')I;G0@)')O=RT^=&]3=')I
M;F<H*2`N(")<;B(["B`@("`@("`@8V]N=&EN=64["B`@("!]"B`@("!I9B`H
M:7-?87)R87DH)')O=RDI('L*("`@("`@("!P<FEN="!I;7!L;V1E*"<L("<L
M("1R;W<I("X@(EQN(CL*("`@('T@96QS92!["B`@("`@("`@=F%R7V1U;7`H
M)')O=RD["B`@("!]"GT*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H
M87!P>2X*"B1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!P:'!T97-T(%=(15)%
M(&$@/#X@-#(G*3L*"@IP<FEN="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C
M:')O=R!D969A=6QT(&1E9F%U;'0L('!O<G1A8FEL:71Y(&UO9&4@1$)?4$]2
M5$%"24Q)5%E?04Q,(%X@1$)?4$]25$%"24Q)5%E?4E1224U<;B(["B1D8F@M
M/G-E=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465]!3$P@
M7B!$0E]03U)404))3$E465]25%))32D["B1S=&@@/2`D9&)H+3YQ=65R>2@B
M4T5,14-4("H@1E)/32!P:'!T97-T(BD["B1R;W<@/2`D<W1H+3YF971C:%)O
M=R@I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN
M(CL*)&%C='5A;"`](&EM<&QO9&4H)R`G+"!A<G)A>5]V86QU97,H)')O=RDI
M.PIS=VET8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)V9B<W%L)SH*
M("`@(&-A<V4@)VUS<6PG.@H@("`@8V%S92`G;7ES<6PG.@H@("`@8V%S92`G
M;7ES<6QI)SH*("`@(&-A<V4@)W-Q;&ET92<Z"B`@("`@("`@)&5X<&5C=&5D
M(#T@)S0R(&)I;F<@5&AI<R!I<R!A('1E<W0@,3DY.2TQ,2TR,2<["B`@("`@
M("`@8G)E86L["B`@("!C87-E("=I9G@G.@H@("`@("`@("1E>'!E8W1E9"`]
M("<T,B!B:6YG("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%1H:7,@:7,@82!T97-T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`Q.3DY+3$Q+3(Q("`@
M("`@("`@("<["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@
M("1E>'!E8W1E9"`]("<T,B!B:6YG("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%1H:7,@:7,@82!T97-T(#$Y.3DM,3$M,C$G.PI]"FEF
M("@D86-T=6%L(#T]("1E>'!E8W1E9"D@>PH@("`@96-H;R`B;W5T<'5T(&UA
M=&-H960@97AP96-T960@9F]R;6%T7&XB.PI](&5L<V4@>PH@("`@96-H;R`B
M1$E$3B=4($U!5$-((2`@17AP96-T960@;W5T<'5T.B`G)&5X<&5C=&5D)RX@
M($%C='5A;"!O=71P=70Z("<D86-T=6%L)RY<;B(["GT*)'-T:"T^9G)E92@I
M.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R:6YT(")T97-T:6YG(&9E=&-H
M;6]D97,Z(&9E=&-H:6YT;R!D969A=6QT(&1E9F%U;'1<;B(["B1D8F@M/G-E
M=$]P=&EO;B@G<&]R=&%B:6QI='DG+"!$0E]03U)404))3$E465]!3$PI.PHD
M<W1H(#T@)&1B:"T^<75E<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD
M<F]W(#T@87)R87DH*3L*)'-T:"T^9F5T8VA);G1O*"1R;W<I.PIP<FEN="!I
M;7!L;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*<')I;G0@:6UP
M;&]D92@G("<L(&%R<F%Y7W9A;'5E<R@D<F]W*2DN(EQN(CL*)'-T:"T^9G)E
M92@I.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R:6YT(")T97-T:6YG(&9E
M=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F875L=%QN(CL*)&1B:"T^
M<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*)'-T:"`]("1D
M8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]("1S
M=&@M/F9E=&-H4F]W*"D["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES
M*"1R;W<I*2XB7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA
M<'!Y+@H*<')I;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@87-S
M;V,@9&5F875L=%QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$
M15]!4U-/0RD["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P
M:'!T97-T(BD["B1R;W<@/2`D<W1H+3YF971C:%)O=R@I.PIP<FEN="!I;7!L
M;V1E*"(@(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*)'-T:"T^9G)E92@I
M.R`@+R\@:V5E<"!F8G-Q;"!H87!P>2X*"G!R:6YT(")T97-T:6YG(&9E=&-H
M;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F875L="!W:71H(&%S<V]C('-P
M96-I9FEE9%QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-('!H
M<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]!
M4U-/0RD["G!R:6YT(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB
M7&XB.PHD<W1H+3YF<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*<')I
M;G0@(G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAR;W<@87-S;V,@9&5F875L
M="!W:71H(&]R9&5R960@<W!E8VEF:65D7&XB.PHD9&)H+3YS971&971C:$UO
M9&4H1$)?1D540TA-3T1%7T%34T]#*3L*)'-T:"`]("1D8F@M/G%U97)Y*")3
M14Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)')O=R`]("1S=&@M/F9E=&-H4F]W
M*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G0@:6UP;&]D92@B("(L(&%R
M<F%Y7VME>7,H)')O=RDI+B)<;B(["B1S=&@M/F9R964H*3L@("\O(&ME97`@
M9F)S<6P@:&%P<'DN"@IP<FEN="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C
M:&EN=&\@;W)D97)E9"!D969A=6QT7&XB.PHD9&)H+3YS971&971C:$UO9&4H
M1$)?1D540TA-3T1%7T]21$52140I.PHD<W1H(#T@)&1B:"T^<75E<GDH(E-%
M3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@87)R87DH*3L*)'-T:"T^
M9F5T8VA);G1O*"1R;W<I.PIP<FEN="!I;7!L;V1E*"(@(BP@87)R87E?:V5Y
M<R@D<F]W*2DN(EQN(CL*)'-T:"T^9G)E92@I.R`@+R\@:V5E<"!F8G-Q;"!H
M87!P>2X*"G!R:6YT(")T97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!A
M<W-O8R!D969A=6QT7&XB.PHD9&)H+3YS971&971C:$UO9&4H1$)?1D540TA-
M3T1%7T%34T]#*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@*B!&4D]-
M('!H<'1E<W0B*3L*)')O=R`](&%R<F%Y*"D["B1S=&@M/F9E=&-H26YT;R@D
M<F]W*3L*<')I;G0@:6UP;&]D92@B("(L(&%R<F%Y7VME>7,H)')O=RDI+B)<
M;B(["B1S=&@M/F9R964H*3L@("\O(&ME97`@9F)S<6P@:&%P<'DN"@IP<FEN
M="`B=&5S=&EN9R!F971C:&UO9&5S.B!F971C:&EN=&\@;W)D97)E9"!D969A
M=6QT('=I=&@@87-S;V,@<W!E8VEF:65D7&XB.PHD9&)H+3YS971&971C:$UO
M9&4H1$)?1D540TA-3T1%7T]21$52140I.PHD<W1H(#T@)&1B:"T^<75E<GDH
M(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PHD<F]W(#T@87)R87DH*3L*)'-T
M:"T^9F5T8VA);G1O*"1R;W<L($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT
M(&EM<&QO9&4H(B`B+"!A<G)A>5]K97ES*"1R;W<I*2XB7&XB.PHD<W1H+3YF
M<F5E*"D[("`O+R!K965P(&9B<W%L(&AA<'!Y+@H*<')I;G0@(G1E<W1I;F<@
M9F5T8VAM;V1E<SH@9F5T8VAI;G1O(&%S<V]C(&1E9F%U;'0@=VET:"!O<F1E
M<F5D('-P96-I9FEE9%QN(CL*)&1B:"T^<V5T1F5T8VA-;V1E*$1"7T9%5$-(
M34]$15]!4U-/0RD["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/
M32!P:'!T97-T(BD["B1R;W<@/2!A<G)A>2@I.PHD<W1H+3YF971C:$EN=&\H
M)')O=RP@1$)?1D540TA-3T1%7T]21$52140I.PIP<FEN="!I;7!L;V1E*"(@
M(BP@87)R87E?:V5Y<R@D<F]W*2DN(EQN(CL*"B1S=&@M/F9R964H*3L@("\O
M(&ME97`@9F)S<6P@:&%P<'DN"B`@("`@("`@("`@("`@("\O(&ME97`@:6)A
M<V4@:&%P<'DZ(&-A;B=T(&1R;W`@=&)L('1H870@:&%S(')E<W5L=',@;W!E
M;B!A9V%I;G-T(&ET+@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]I;F-L
M=61E+FEN8P``````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,#4R(#$P
M-3$U-#,T,3,U(#`R,S,W,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H*+RHJ"B`J(%-E=',@=&AE(&EN8VQU9&5?
M<&%T:"P@97)R;W)?<F5P;W)T:6YG(&%N9"!0051(7U-%4$%2051/4B!F;W(@
M=&5S=',*("H@:6X@=&AE($1"+W1E<W1S(&1I<F5C=&]R>0H@*@H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A
M<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@)$ED.B!I;F-L=61E+FEN8RQV(#$N-2`R,#`U+S`R+S`S
M(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*97)R;W)?<F5P;W)T:6YG
M*$5?04Q,*3L*"FEF("@A9&5F:6YE9"@G4$%42%]315!!4D%43U(G*2D@>PH@
M("`@:68@*'-T<FES='(H4$A07T]3+"`G5TE.)RDI('L*("`@("`@("`O*BH*
M("`@("`@("`@*B!$969I;F4@=&AE('!A=&@@<V5P87)A=&]R(&9O<B!W:6YD
M;W=S"B`@("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/
M4B<L("<[)RD["B`@("!](&5L<V4@>PH@("`@("`@("\J*@H@("`@("`@("`J
M($1E9FEN92!T:&4@<&%T:"!S97!A<F%T;W(@9F]R(&]T:&5R('-Y<W1E;7,*
M("`@("`@("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@
M)SHG*3L*("`@('T*?0H*+RH*("H@268@=&AE('!A=&@@=&\@>6]U<B!014%2
M(&EN<W1A;&QA=&EO;B!I<R!F;W5N9"!I;B!T:&4@;&5F="!H86YD"B`J('!O
M<G1I;VX@;V8@=&AE(&EF*"D@97AP<F5S<VEO;B!B96QO=RP@=&AA="!M96%N
M<R!T:&ES(&9I;&4@:&%S"B`J(&-O;64@9G)O;2!T:&4@4$5!4B!I;G-T86QL
M97(N("!4:&5R969O<F4L(&QE="=S('5S92!T:&4*("H@:6YS=&%L;&5D('9E
M<G-I;VX@;V8@1$(L('=H:6-H('-H;W5L9"!B92!F;W5N9"!V:6$@=&AE"B`J
M(&-O;7!U=&5R)W,@9&5F875L="!I;F-L=61E7W!A=&@N("!!9&0@)RXG('1O
M('1H92!I;F-L=61E7W!A=&@*("H@=&\@96YS=7)E("<N)R!I<R!I;B!T:&5R
M92X*("H@"B`J($EF('1H92!P871H(&AA<R!N;W0@8F5E;B!S=6)S=&ET=71E
M9"!I;B!T:&4@:68H*2!E>'!R97-S:6]N+`H@*B!T:&ES(&9I;&4@:&%S(&QI
M:V5L>2!C;VUE(&9R;VT@82!#5E,@8VAE8VMO=70@;W(@82`N=&%R(&9I;&4N
M"B`J(%1H97)E9F]R92P@=V4G;&P@87-S=6UE('1H92!T97-T<R!S:&]U;&0@
M=7-E('1H92!V97)S:6]N(&]F"B`J($1"('1H870@:&%S(&-O;64@9G)O;2!T
M:&5R92!A<R!W96QL+@H@*B\*:68@*"<O=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PH@("`@:6YI
M7W-E="@G:6YC;'5D95]P871H)RP@:6YI7V=E="@G:6YC;'5D95]P871H)RD*
M("`@("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)PH@("`@*3L*?2!E
M;'-E('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(')E86QP871H*&1I
M<FYA;64H7U]&24Q%7U\I("X@)R\N+B<I"B`@("`@("`@("`@("X@4$%42%]3
M15!!4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N
M(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PI]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]L:6UI="YI;F,`````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`T-C(R(#$P-3$U-#,T,3,U(#`R,S`W,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S
M('1H92!D<FEV97)S)R!L:6UI=%%U97)Y*"D@;65T:&]D"B`J"B`J($5X96-U
M=&5D(&)Y(&1R:79E<B\Q,VQI;6ET+G!H<'0*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T
M:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P
M86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@
M/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N
M("`@("1)9#H@;&EM:70N:6YC+'8@,2XQ,2`R,#`U+S`R+S`S(#`U.C0Y.C0T
M(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+T1""B`J+PH*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*
M"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R"B`J"B`J($1R
M;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE
M<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@
M;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P
M87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@
M4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RD@
M>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D8F@L("=P
M:'!T97-T)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*"B1D8F@M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A
M8FQE*"1D8F@L("=P:'!?;&EM:70G*3L*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@HD9&)H+3YQ=65R>2@G
M0U)%051%(%1!0DQ%('!H<%]L:6UI="`H82!#2$%2*#(P*2DG*3L*"@HD9G)O
M;2`@("`](#`["B1C;W5N="`@(#T@,3`["B1N=6UR;W=S(#T@,S`["@IF;W(@
M*"1I/3`[("1I/#TD;G5M<F]W<RLR.R`D:2LK*2!["B`@("`D9&)H+3YQ=65R
M>2@B24Y315)4($E.5$\@<&AP7VQI;6ET(%9!3%5%4R@G<F5S=6QT("1I)RDB
M*3L*?0IF;W(@*"1I(#T@,#L@)&D@/#T@,SL@)&DK*RD@>PH@("`@)&9R;VT@
M/2`Q,"`J("1I.PH@("`@)')E<R`]("1D8F@M/FQI;6ET475E<GDH(G-E;&5C
M="`J(&9R;VT@<&AP7VQI;6ET(BP@)&9R;VTL("1C;W5N="D["B`@("!E8VAO
M("(]/3T]/3T]($9R;VTZ("1F<F]M('Q\($YU;6)E<B!O9B!R;W=S('1O(&9E
M=&-H.B`D8V]U;G0@/3T]/3T]/5QN(CL*("`@('=H:6QE("@D<F]W(#T@)')E
M<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*2D@>PH@("`@("`@(&5C
M:&\@)')E<RT^9V5T4F]W0V]U;G1E<B@I("X@)RXM("<@+B`D<F]W6R=A)UT@
M+B`B7&XB.PH@("`@?0H@("`@)')E<RT^9G)E92@I.R`@+R\@:V5E<"!F8G-Q
M;"!H87!P>2X*?0H*"B1F<F]M("`](#$Q.PHD8V]U;G0@/2`S.PH*96-H;R`B
M/3T]/3T]/2!087-S:6YG(%PD<&%R86US('Q\($9R;VTZ("1F<F]M('Q\($YU
M;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`D8V]U;G0@/3T]/3T]/5QN(CL*)')E
M<R`]("1D8F@M/FQI;6ET475E<GDH)U-%3$5#5"`J($923TT@<&AP7VQI;6ET
M(%=(15)%(&$@/"`_)RP@)&9R;VTL("1C;W5N="P@87)R87DH)W)E<W5L="`Y
M.2<I*3L*=VAI;&4@*"1R;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&151#2$U/
M1$5?05-33T,I*2!["B`@("!E8VAO("1R97,M/F=E=%)O=T-O=6YT97(H*2`N
M("<N+2`G("X@)')O=ULG82==("X@(EQN(CL*?0H*)')E<RT^9G)E92@I.R`@
M+R\@:V5E<"!F8G-Q;"!H87!P>2X*("`@("`@("`@("`@("`@+R\@:V5E<"!I
M8F%S92!H87!P>3H@8V%N)W0@9')O<"!T8FP@=&AA="!H87,@<F5S=6QT<R!O
M<&5N(&%G86EN<W0@:70N"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&AP7VQI;6ET)RD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]N=6UC;VQS+FEN8P``````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`S-3$S(#$P-3$U-#,T,3,U(#`R,S0S,0`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RHJ"B`J(%1E<W1S('1H92!D<FEV97)S)R!N=6U#;VQS*"D@;65T:&]D"B`J
M"B`J($5X96-U=&5D(&)Y(&1R:79E<B\P-&YU;6-O;',N<&AP=`H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@)$ED.B!N=6UC;VQS+FEN8RQV(#$N-R`R,#`U+S`R
M+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L
M(&5R<F]R(&-A;&QB86-K(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E
M<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL
M;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!0
M14%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES
M(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O
M<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@
M)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@
M("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1S=&@@/2`D9&)H
M+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)61<
M;B(L("1S=&@M/FYU;4-O;',H*2D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,
M14-4(&$L8B!&4D]-('!H<'1E<W0B*3L*<')I;G1F*"(E9%QN(BP@)'-T:"T^
M;G5M0V]L<R@I*3L*)'-T:"`]("1D8F@M/G%U97)Y*")314Q%0U0@82QB+&,@
M1E)/32!P:'!T97-T(BD["G!R:6YT9B@B)61<;B(L("1S=&@M/FYU;4-O;',H
M*2D["B1S=&@@/2`D9&)H+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T
M(BD["G!R:6YT9B@B)61<;B(L("1S=&@M/FYU;4-O;',H*2D["@H*<W=I=&-H
M("@D9&)H+3YP:'!T>7!E*2!["B`@("!C87-E("=I8F%S92<Z"B`@("`@("`@
M+RH*("`@("`@("`@*B!);G1E<F)A<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN
M9R!T86)L97,@=&AA="!H879E(')E<W5L=`H@("`@("`@("`J('-E=',@<W1I
M;&P@;W!E;BX*("`@("`@("`@*B\*("`@("`@("`D9&)H+3YF<F5E4F5S=6QT
M*"1S=&@M/G)E<W5L="D["B`@("`@("`@8G)E86L["GT*)&1B:"T^<V5T17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B
M:"P@)W!H<'1E<W0G*3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O1$(O=&5S=',O;G5M<F]W<RYI;F,`````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-C(S-B`Q,#4Q-30S-#$S-2`P,C,T-S``(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J*@H@
M*B!497-T<R!T:&4@9')I=F5R<R<@;G5M4F]W<R@I(&UE=&AO9`H@*@H@*B!%
M>&5C=71E9"!B>2!D<FEV97(O,#EN=6UR;W=S+G!H<'0*("H*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E
M+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E
M"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV
M:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V
M97)S:6]N("`@("1)9#H@;G5M<F]W<RYI;F,L=B`Q+C$R(#(P,#4O,#(O,#D@
M,#<Z,#<Z,C0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@97)R
M;W(@8V%L;&)A8VL@:&%N9&QE<@H@*@H@*B!$<F]P<R!T:&4@<&AP=&5S="!T
M86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T
M:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@
M97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T
M:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N
M9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@(&=L;V)A;"`D9&)H
M.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH*("`@('!R
M:6YT(")<;BTM+2TM+2TM+2TM+5QN(CL*("`@(&EF("@D;RT^9V5T0V]D92@I
M(#T]($1"7T524D]27TY/5%]#05!!0DQ%*2!["B`@("`@("`@<')I;G0@(E1H
M:7,@1$)-4R!D;V5S(&YO="!S=7!P;W)T(&YU;5)O=W,H*2XB.PH@("`@?2!E
M;'-E:68@*"1O+3YG971#;V1E*"D@/3T@1$)?15)23U)?34E334%40T@I('L*
M("`@("`@("!P<FEN="`B36ES;6%T8V@@8F5T=V5E;B!T:&4@;G5M8F5R(&]F
M('!L86-E:&]L9&5R<R!A;F0@<&%R86UE=&5R<RY<;B(["B`@("`@("`@9F]R
M96%C:"`H)&\M/F)A8VMT<F%C92!A<R`D:71E;2`]/B`D9&5T86EL*2!["B`@
M("`@("`@("`@(&EF("@D9&5T86EL6R=F=6YC=&EO;B==(#T]("=Q=65R>2<I
M('L*("`@("`@("`@("`@("`@(&5C:&\@)U%515)9.B`G("X@)&1E=&%I;%LG
M87)G<R==6S!=("X@(EQN(CL*("`@("`@("`@("`@("`@(&5C:&\@(E!!4D%-
M151%4E,Z7&XB.PH@("`@("`@("`@("`@("`@<')I;G1?<B@D9&5T86EL6R=A
M<F=S)UU;,5TI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?2!E;'-E
M('L*("`@("`@("!P<FEN="`D;RT^9V5T1&5B=6=);F9O*"D@+B`B7&XB.PH@
M("`@?0H@("`@97AI=#L*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%2
M7T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD<F5S(#T@)&1B:"T^<75E<GDH
M(E-%3$5#5"!A($923TT@<&AP=&5S="(I.PII9B`H(41".CII<T5R<F]R*"1R
M;W=S(#T@)')E<RT^;G5M4F]W<R@I*2D@>PH@("`@<')I;G0@(BAW86YT(#$I
M(&=O="`D<F]W<R!F<F]M(&9I<G-T7&XB.PI](&5L<V4@>PH@("`@<')I;G0@
M(EQN(CL*?0IF;W(@*"1I(#T@,#L@)&D@/"`U.R`D:2LK*2!["B`@("`D9&)H
M+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="`H82D@5D%,5453("@D:2DB
M*3L*("`@("1R97,@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@1E)/32!P:'!T
M97-T(BD["B`@("!I9B`H(41".CII<T5R<F]R*"1R;W=S(#T@)')E<RT^;G5M
M4F]W<R@I*2D@>PH@("`@("`@('!R:6YT("<H=V%N="`G("X@*"1I("L@,BD@
M+B`B*2!G;W0@)')O=W,@9G)O;2`D:5QN(CL*("`@('T@96QS92!["B`@("`@
M("`@<')I;G0@(EQN(CL*("`@('T*?0H*)')E<R`]("1D8F@M/G%U97)Y*"=3
M14Q%0U0@82!&4D]-('!H<'1E<W0@5TA%4D4@82`^(#\G+"`P*3L*:68@*"%$
M0CHZ:7-%<G)O<B@D<F]W<R`]("1R97,M/FYU;5)O=W,H*2DI('L*("`@('!R
M:6YT("(H=V%N="`U*2!G;W0@)')O=W,@9G)O;2`^(#`@*'!A<W-I;F<@<&%R
M86US('1O('%U97)Y*5QN(CL*?2!E;'-E('L*("`@('!R:6YT(")<;B(["GT*
M"B1S=&@@/2`D9&)H+3YP<F5P87)E*"=314Q%0U0@82!&4D]-('!H<'1E<W0@
M5TA%4D4@82`\(#\G*3L*)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:"P@87)R
M87DH-"DI.PII9B`H(41".CII<T5R<F]R*"1R;W=S(#T@)')E<RT^;G5M4F]W
M<R@I*2D@>PH@("`@<')I;G0@(BAW86YT(#0I(&=O="`D<F]W<R!F<F]M(#P@
M-"`H9&]I;F<@<')E<&%R92]E>&5C=71E*5QN(CL*?2!E;'-E('L*("`@('!R
M:6YT(")<;B(["GT*"B1D8F@M/G%U97)Y*")$14Q%5$4@1E)/32!P:'!T97-T
M(%=(15)%(&$@/"`T(BD["B1R97,@/2`D9&)H+3YQ=65R>2@B4T5,14-4(&$@
M1E)/32!P:'!T97-T(BD["FEF("@A1$(Z.FES17)R;W(H)')O=W,@/2`D<F5S
M+3YN=6U2;W=S*"DI*2!["B`@("!P<FEN="`B*'=A;G0@,BD@9V]T("1R;W=S
M(&9R;VT@-2!A;F0@-B!N;W0@9&5L971E9%QN(CL*?2!E;'-E('L*("`@('!R
M:6YT(")<;B(["GT*)')E<R`]("1D8F@M/G%U97)Y*")314Q%0U0@82!&4D]-
M('!H<'1E<W0@=VAE<F4@82`\(#`B*3L*:68@*"%$0CHZ:7-%<G)O<B@D<F]W
M<R`]("1R97,M/FYU;5)O=W,H*2DI('L*("`@('!R:6YT("(H=V%N="`P*2!G
M;W0@)')O=W,@9G)O;2`\(#!<;B(["GT@96QS92!["B`@("!P<FEN="`B7&XB
M.PI]"@H*)')E<RT^9G)E92@I.R`@+R\@:V5E<"!I8F%S92!H87!P>0HD9&)H
M+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T
M86)L92@D9&)H+"`G<&AP=&5S="<I.PH`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+W1E<W1S+T1"+W1E<W1S+W!R97!E>&4N:6YC````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,30W,C0@,3`U,34T,S0Q,S4@,#(S-#(W`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"@HO*BH*
M("H@5&5S=',@=&AE(&1R:79E<G,G('!R97!A<F4@86YD(&5X96-U=&4@;65T
M:&]D<PH@*@H@*B!%>&5C=71E9"!B>2!D<FEV97(O,#9P<F5P97AE8RYP:'!T
M"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE
M87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O
M<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@
M("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`D260Z('!R97!E>&4N:6YC+'8@,2XR
M-2`R,#`U+S`R+S$V(#$S.C4T.C4Q(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*)'1M
M<&9I;&4@/2!T96UP;F%M*"(O=&UP(BP@(G!H<'1M<"(I.PIR96=I<W1E<E]S
M:'5T9&]W;E]F=6YC=&EO;B@B;7E?<VAU=&1O=VXB*3L*)&9P(#T@9F]P96XH
M)'1M<&9I;&4L(")W(BD["B1F:6QE9&%T82`](")O<&%Q=64@<&QA8V5H;VQD
M97(G<R!T97-T(CL*9G=R:71E*"1F<"P@)&9I;&5D871A*3L*9F-L;W-E*"1F
M<"D["@H*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(*("H*
M("H@4')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E(&%N9"!K:6QL<R!T:&4@
M<')O8V5S<RX*("H*("H@0'!A<F%M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@
M;V)J96-T(&%U=&]M871I8V%L;'D@<&%S<V5D('1O('1H:7,@;65T:&]D"B`J
M($!R971U<FX@=F]I9`H@*B!`<V5E(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H
M*0H@*B\*9G5N8W1I;VX@<&4H)&\I('L*("`@('!R:6YT(")<;B(@+B`D;RT^
M=&]3=')I;F<H*3L*("`@(&5X:70["GT*"B1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@)W!E)RD["@H*+R\@,2D@375L=&EP
M;&4@<')E<&%R92]E>&5C($E.4T525"!Q=65R:65S"F5C:&\@(BTM+2TM+2TM
M+2TM+3$M+2TM+2TM+2TM+2U<;B(["@HD<W1H,2`]("1D8F@M/G!R97!A<F4H
M(DE.4T525"!)3E1/('!H<'1E<W0@*&$L(&(I(%9!3%5%4R`H/RP@)V$G*2(I
M.PHD<W1H,B`]("1D8F@M/G!R97!A<F4H(DE.4T525"!)3E1/('!H<'1E<W0@
M*&$L8BD@5D%,5453("@A+#\I(BD["B1S=&@S(#T@)&1B:"T^<')E<&%R92@B
M24Y315)4($E.5$\@<&AP=&5S="`H82QB+&,I(%9!3%5%4R`H/RPA+"8I(BD[
M"B1S=&@T(#T@)&1B:"T^<')E<&%R92@B24Y315)4($E.5$\@<&AP=&5S="`H
M82P@8BD@5D%,5453("@W,BP@)V1I<F5C="<I(BD["G!R:6YT(")S=&@Q+'-T
M:#(L<W1H,RQS=&@T(&-R96%T961<;B(["G!R:6YT("=S=&@Q.B`_(&%S('!A
M<F%M+"!P87-S:6YG(&%S(&%R<F%Y+BXN("<["FEF("@H)')E<R`]("1D8F@M
M/F5X96-U=&4H)'-T:#$L(&%R<F%Y*#<R*2DI(#T]/2!$0E]/2RD@>PH@("`@
M<')I;G0@(G-T:#$@97AE8W5T961<;B(["GT@96QS92!["B`@("!P<FEN="`B
M<W1H,2!F86EL961<;B(["GT*"G!R:6YT("=S=&@R.B`A(&%N9"`_(&%S('!A
M<F%M<RP@<&%S<VEN9R!A<R!A<G)A>2XN+B`G.PII9B`H*"1R97,@/2`D9&)H
M+3YE>&5C=71E*"1S=&@R+"!A<G)A>2@W,BP@(G1H870G<R!R:6=H="(I*2D@
M/3T]($1"7T]+*2!["B`@("!P<FEN="`B<W1H,B!E>&5C=71E9%QN(CL*?2!E
M;'-E('L*("`@('!R:6YT(")S=&@R(&9A:6QE9%QN(CL*?0H*<')I;G0@)W-T
M:#,Z(#\L("$@86YD("8@87,@<&%R86US+"!P87-S:6YG(&%S(&%R<F%Y+BXN
M("<["G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@("`@8V%S92`G;7-Q;"<Z
M"B`@("`@("`@)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:#,L(&%R<F%Y*#<R
M+"`B)VET7%PG<R!G;V]D)R(L("1T;7!F:6QE*2D["B`@("`@("`@8G)E86L[
M"B`@("!D969A=6QT.@H@("`@("`@("1R97,@/2`D9&)H+3YE>&5C=71E*"1S
M=&@S+"!A<G)A>2@W,BP@(B=I="<G<R!G;V]D)R(L("1T;7!F:6QE*2D["GT*
M:68@*"1R97,@/3T]($1"7T]+*2!["B`@("!P<FEN="`B<W1H,R!E>&5C=71E
M9%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")S=&@S(&9A:6QE9%QN(CL*?0H*
M<')I;G0@)W-T:#0Z(&YO('!A<F%M<RXN+B`G.PII9B`H*"1R97,@/2`D9&)H
M+3YE>&5C=71E*"1S=&@T*2D@/3T]($1"7T]+*2!["B`@("!P<FEN="`B<W1H
M-"!E>&5C=71E9%QN(CL*?2!E;'-E('L*("`@('!R:6YT(")S=&@T(&9A:6QE
M9%QN(CL*?0IP<FEN=%]R97-U;'1S*"D["@H*+R\@,BD@3VYE('!R97!A<F5D
M+"!M=6QT:7!L92!T:6UE(&5X96-U=&5D"F5C:&\@(EQN+2TM+2TM+2TM+2TM
M,BTM+2TM+2TM+2TM+5QN(CL*"B1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!P
M:'!T97-T)RD["B1S=&@@/2`D9&)H+3YP<F5P87)E*"=)3E-%4E0@24Y43R!P
M:'!T97-T("AA+"!B+"!C+"!D*2!604Q515,@*#\L(#\L("8L(#\I)RD["B1D
M871A(#T@87)R87DH"B`@("`P(#T^(&%R<F%Y*#<R+"`G<V5T,2<L("1T;7!F
M:6QE+"`G,3(S-"TU-BTW."<I+`H@("`@,2`]/B!A<G)A>2@W,BP@)W-E=#(G
M+"`D=&UP9FEL92P@;G5L;"DL"B`@("`R(#T^(&%R<F%Y*#<R+"`G<V5T,R<L
M("1T;7!F:6QE+"!N=6QL*0HI.PHD<F5S(#T@)&1B:"T^97AE8W5T94UU;'1I
M<&QE*"1S=&@L("1D871A*3L*<')I;G1?<F5S=6QT<R@I.PH*"B\O(#,I(&9R
M9650<F5P87)E9"@I('1E<W0*96-H;R`B7&XM+2TM+2TM+2TM+2TS+2TM+2TM
M+2TM+2TM7&XB.PH*:68@*"1D8F@M/F9R9650<F5P87)E9"@D<W1H*2D@>PH@
M("`@96-H;R`G5%)512<["GT@96QS92!["B`@("!E8VAO("=&04Q312<["GT*
M96-H;R`B7&XB.PII9B`H)&1B:"T^9G)E95!R97!A<F5D*#8V-BDI('L*("`@
M(&5C:&\@)U12544G.PI](&5L<V4@>PH@("`@96-H;R`G1D%,4T4G.PI]"F5C
M:&\@(EQN(CL*"@HO+R`T*2!314Q%0U1S('1E<W1S"F5C:&\@(EQN+2TM+2TM
M+2TM+2TM-"TM+2TM+2TM+2TM+5QN(CL*)'-T:#$@/2`D9&)H+3YP<F5P87)E
M*")314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`](#\@3U)$15(@0ED@
M8B(I.PIP<FEN=%\T*"1S=&@Q+"`W,BD["G!R:6YT7S0H)'-T:#$L(#<Q*3L*
M)'-T:#(@/2`D9&)H+3YP<F5P87)E*")314Q%0U0@*B!&4D]-('!H<'1E<W0@
M5TA%4D4@9"`](#\@3U)$15(@0ED@8B(I.PIP<FEN=%\T*"1S=&@R+"`G,3(S
M-"TU-BTW."<I.PHD<W1H,R`]("1D8F@M/G!R97!A<F4H(E-%3$5#5"`J($92
M3TT@<&AP=&5S="!72$5212!C(#T@)B!/4D1%4B!"62!B(BD["G!R:6YT7S0H
M)'-T:#,L("1T;7!F:6QE*3L*"@HO+R`U*2!!4U-/0TE!5$E612!!4E)!62!Q
M=65R:65S"F5C:&\@(EQN+2TM+2TM+2TM+2TM-2TM+2TM+2TM+2TM+5QN(CL*
M"B1S=&@U(#T@)&1B:"T^<')E<&%R92@G24Y315)4($E.5$\@<&AP=&5S="`H
M82P@8BP@9"D@5D%,5453("@_+"`_+"`_*2<I.PHD87)R87D@/2!A<G)A>2@*
M("`@("=F;V\G(#T^(#$Q+`H@("`@)V)A<B<@/3X@)W1H<F5E)RP*("`@("=B
M87HG(#T^(&YU;&PL"BD["B1R97,@/2`D9&)H+3YE>&5C=71E*"1S=&@U+"`D
M87)R87DI.PIP<FEN="`G:6YS97)T.B`G("X@*"1R97,@/3T]($1"7T]+(#\@
M)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*)'-T:#8@/2`D9&)H+3YP<F5P
M87)E*"=314Q%0U0@82P@8BP@9"!&4D]-('!H<'1E<W0@5TA%4D4@82`](#\G
M*3L*)')E<R`]("1D8F@M/F5X96-U=&4H)'-T:#8L(&%R<F%Y*#$Q*2D["B1R
M;W<@/2`D<F5S+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I.PIP<FEN
M="`B82`]('LD<F]W6R=A)UU]+"!B(#T@>R1R;W=;)V(G77TL(&0@/2`B.PII
M9B`H)&1B:"T^<&AP='EP92`]/2`G;7-Q;"<I('L*("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"=D)RP@)')O=RDI('L*("`@("`@("`D='EP92`](&=E='1Y
M<&4H)')O=ULG9"==*3L*("`@("`@("!I9B`H)'1Y<&4@/3T@)TY53$PG('Q\
M("1R;W=;)V0G72`]/2`G)RD@>PH@("`@("`@("`@("!P<FEN="`B9V]T(&5X
M<&5C=&5D(&]U=&-O;65<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1Y<&4@/2!G971T>7!E*"1R;W=;)V0G72D["B`@("`@("`@("`@('!R
M:6YT(")53BUE>'!E8W1E9"!O=71C;VUE.B`D='EP95QN(CL*("`@("`@("!]
M"B`@("!](&5L<V4@>PH@("`@("`@("\O(&AT='`Z+R]B=6=S+G!H<"YN970O
M/VED/3,Q.38P"B`@("`@("`@<')I;G0@(E!R:6]R('1O(%!(4"`T+C,N,3$@
M;W(@-2XP+C0L(%!(4"=S(&US<6P@97AT96YS:6]N('-I;&5N=&QY(@H@("`@
M("`@("`@("`@("X@(B!D<F]P<&5D(&-O;'5M;G,@=VET:"!N=6QL('9A;'5E
M<RX@66]U(&YE960@=&\@=7!G<F%D92Y<;B(["B`@("!]"GT@96QS92!["B`@
M("`D='EP92`](&=E='1Y<&4H)')O=ULG9"==*3L*("`@(&EF("@D='EP92`]
M/2`G<W1R:6YG)RD@>PH@("`@("`@('!R:6YT(")G;W0@97AP96-T960@;W5T
M8V]M95QN(CL*("`@('T@96QS92!["B`@("`@("`@<')I;G0@(E5.+65X<&5C
M=&5D(&]U=&-O;64Z("1T>7!E7&XB.PH@("`@?0I]"@HO*BH*("H@075T;VUA
M=&EC86QL>2!F<F5E('1H92!P<F5P87)E9"!S=&%T96UE;G1S(&%N9"!R97-U
M;'1S('=H96X@=&AE('-C<FEP=`H@*B!T97)M:6YA=&5S"B`J"B`J($!R971U
M<FX@=F]I9`H@*B\*9G5N8W1I;VX@;7E?<VAU=&1O=VXH*2!["B`@("!G;&]B
M86P@)'1M<&9I;&4L("1D8F@L("1S=&@Q+"`D<W1H,BP@)'-T:#,L("1S=&@T
M+"`D<W1H-2P@)'-T:#8L("1R97,["@H@("`@<W=I=&-H("@D9&)H+3YP:'!T
M>7!E*2!["B`@("`@("`@8V%S92`G:6)A<V4G.@H@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!);G1E<F)A<V4@9&]E<VXG="!A;&QO=R!D<F]P<&EN
M9R!T86)L97,@=&AA="!H879E(')E<W5L=`H@("`@("`@("`@("`@*B!S971S
M('-T:6QL(&]P96XN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D9&)H
M+3YF<F5E4')E<&%R960H)'-T:#$I.PH@("`@("`@("`@("`D9&)H+3YF<F5E
M4')E<&%R960H)'-T:#(I.PH@("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R
M960H)'-T:#,I.PH@("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H)'-T
M:#0I.PH@("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H)'-T:#4I.PH@
M("`@("`@("`@("`D9&)H+3YF<F5E4')E<&%R960H)'-T:#8I.PH@("`@("`@
M("`@("`D9&)H+3YF<F5E4F5S=6QT*"1R97,M/G)E<W5L="D["B`@("`@("`@
M("`@(&)R96%K.PH@("`@?0H*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G<&AP
M=&5S="<I.PH*("`@('5N;&EN:R@D=&UP9FEL92D["GT*"B\J*@H@*B!0<FEN
M="!O=70@=&AE(&1A=&$@:6X@=&5S="!T86)L90H@*@H@*B!`<F5T=7)N('9O
M:60*("HO"F9U;F-T:6]N('!R:6YT7W)E<W5L=',H*2!["B`@("!G;&]B86P@
M)&1B:#L*("`@('!R:6YT(")R97-U;'1S.EQN(CL*("`@("1R97,@/2`D9&)H
M+3YQ=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&$@/2`W,B!/
M4D1%4B!"62!B(BD["B`@("`D:2`](#`["B`@("!W:&EL92`H)')O=R`]("1R
M97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*2D@>PH@("`@("`@
M('!R:6YT("=\)R`N(&EM<&QO9&4H(B`M("(L("1R;W<I("X@(GQ<;B(["B`@
M("`@("`@)&DK*SL*("`@('T*("`@(&EF("@A)&DI('L*("`@("`@("!P<FEN
M="`B5&AE(')E8V]R9',@=V5R92!N;W0@9F]U;F0N("!$:60@=&AE>2!G970@
M:6YS97)T960_7&XB.PH@("`@?0I]"@HO*BH*("H@17AE8W5T92!T:&4@<')E
M<&%R960@<W1A=&5M96YT(&%N9"!P<FEN="!O=70@=&AE(&1A=&$@:6X@=&AE
M(')E<W5L=`H@*@H@*B!`<&%R86T@<F5S;W5R8V4@("`@("1S=&@@("!T:&4@
M<W1A=&5M96YT(&AA;F1L92!T;R!P<F]C97-S"B`J($!P87)A;2!S=')I;F=\
M87)R87D@)&)I;F0@('1H92!D871A('1H870@=VEL;"!R97!L86-E('1H92!P
M;&%C96AO;&1E<G,*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC=&EO;B!P
M<FEN=%\T*"1S=&@L("1B:6YD*2!["B`@("!G;&]B86P@)&1B:#L*("`@("1R
M97,@/2`D9&)H+3YE>&5C=71E*"1S=&@L("1B:6YD*3L*("`@('=H:6QE("@D
M<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I*2![
M"B`@("`@("`@<')I;G0@)WPG("X@:6UP;&]D92@B("T@(BP@)')O=RD@+B`B
M?%QN(CL*("`@('T*("`@(&5C:&\@(GY^7&XB.PI]"@``````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]R=6XN8W9S````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C4Q(#$P-3$U-#,T,3,U(#`R
M,C8P,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```C(2`O8FEN+W-H"@HC("1)9#H@<G5N+F-V<RQV(#$N,R`R,#`T+S`R+S(P
M(#$X.C4W.C4Q(&1A;FEE;&,@17AP("0*"B,@=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G8*(R!014%2($1"(%1%
M4U0@4U1!4E1%4@HC"B,@("!4;R!R=6X@86QL('1E<W1S.B`@+B]R=6X*(R`@
M(%1O(')U;B!O;F4@=&5S=#H@("`N+W)U;B`\=&5S="!F:6QE(&YA;64^"B,@
M("!%>&%M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN<&AP=`HC
M"B,@0F5F;W)E(')U;FYI;F<@=&AE('1E<W1S('EO=2!M=7-T(&%D:G5S="!T
M:&4*(R!F;VQL;W=I;F<@=&AR964@=F%R:6%B;&5S.@H*(R`@(%1H92!F=6QL
M('!A=&@@=&\@>6]U<B!02%`@9&ER96-T;W)Y.@H@("`@1$)?5$535%]02%!?
M4$%42#UC.B]P<F]G<F%^,2]P:'`*"B,@("!4:&4@;F%M92!O9B!Y;W5R(%!(
M4"!#3$D@97AE8W5T86)L90HC("`@*&5X86UP;&5S('!H<"YE>&4L('!H<"UC
M;&DN97AE+"!C;&DO<&AP+F5X92DZ"B`@("!$0E]415-47U!(4%]#3$D]<&AP
M+F5X90H*(R`@(%1H92!F=6QL('!A=&@@=&\@=&AE('!R97-E;G0@9&ER96-T
M;W)Y"B,@("`H;F]T('5S:6YG("105T0@9'5E('1O($-Y9W=I;BDZ"B`@("!$
M0E]415-47T1)4CUD.B]P96%R=&5S="]P96%R+T1"+W1E<W1S"@HC(%Y>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M"@H*"E1%4U1?4$A07T5814-55$%"3$4])$1"7U1%4U1?4$A07U!!5$@O)$1"
M7U1%4U1?4$A07T-,20IE>'!O<G0@5$535%]02%!?15A%0U5404),10H*:68@
M6R`D(R`M9W0@,"!="G1H96X*("`@('1E<W0])#$*96QS90H@("`@=&5S=#TJ
M+G!H<'0*9FD*"B1415-47U!(4%]%6$5#551!0DQ%("1$0E]415-47U!(4%]0
M051(+W)U;BUT97-T<RYP:'`@)$1"7U1%4U1?1$E2+R1[=&5S='T*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S97%U96YC97,N
M:6YC````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-38Q(#$P-3$U-#,T
M,3,U(#`R,S<U,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RHJ"B`J(%1E<W1S('1H92!D<FEV97)S)R!S97%U
M96YC92`H86MA(&%U=&]?:6YC<F5M96YT*2!M971H;V1S"B`J"B`J($5X96-U
M=&5D(&)Y(&1R:79E<B\P-7-E<75E;F-E<RYP:'!T"B`J"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@
M*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R
M<VEO;B`@("`D260Z('-E<75E;F-E<RYI;F,L=B`Q+C$Q(#(P,#4O,#(O,3@@
M,C(Z,S@Z-#,@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3&]C86P@97)R
M;W(@:&%N9&QE<@H@*B\*9G5N8W1I;VX@97)R;W)?:&%N9&QE<B@F)&]B:BD@
M>PH@("`@<')I;G0@(G-E<75E;F-E<RYI;F,@97)R;W)?:&%N9&QE<CI<;B`@
M("`B.PH@("`@<')I;G0@)&]B:BT^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B([
M"GT*;V)?:6UP;&EC:71?9FQU<V@H=')U92D["@HD9')O<"`]("1D8F@M/F1R
M;W!397%U96YC92@G=&5S="<I.PII9B`H1$(Z.FES17)R;W(H)&1R;W`I("8F
M"B`@("`D9')O<"T^9V5T0V]D92@I("$]($1"7T524D]27TY/4U5#2%1!0DQ%
M*0I["B`@("!P<FEN="`B0V]U;&0@;F]T(&1R;W`@<V5Q=65N8V4N+BY<;B([
M"B`@("!P<FEN="`D9')O<"T^9V5T1&5B=6=);F9O*"D@+B`B7&Y<;B(["B`@
M("!I9B`H)&1B:"T^<&AP='EP92`]/2`G:6)A<V4G("8F"B`@("`@("`@)&1R
M;W`M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].*0H@
M("`@>PH@("`@("`@('!R:6YT(")5<V4@=&AI<R!Q=65R>2!T;R!P<F]V:61E
M('1H92!P97)M:7-S:6]N<R!N965D960Z7&XB.PH@("`@("`@('!R:6YT("<@
M("!G<F%N="!A;&P@;VX@4D1")$=%3D52051/4E,@=&\@/%5315).04U%/B<[
M"B`@("!]"B`@("!E>&ET.PI]"@HO+R`Q*2!T97-T('1H870@<V5Q=65N8V5S
M(&%R92!N;W0@8W)E871E9"!I9B`B;VYD96UA;F0B(&ES(&9A;'-E"@HD92`]
M("1D8F@M/FYE>'1)9"@B=&5S="(L(&9A;'-E*3L*:68@*$1".CII<T5R<F]R
M*"1E*2`F)B`D92T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%
M*2!["B`@("!P<FEN="`B86X@97)R;W(@:7,@=&AE('!R;W!E<B!R97-P;VYS
M92!H97)E7&XB.PI](&5L<V4@>PH@("`@:68@*$1".CII<T5R<F]R*"1E*2D@
M>PH@("`@("`@(&EF("@D9&)H+3YP:'!T>7!E(#T]("=I8F%S92<@)B8@)&4M
M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E]364Y405@I('L*("`@("`@("`@("`@
M<')I;G0@(F%N(&5R<F]R(&ES('1H92!P<F]P97(@<F5S<&]N<V4@:&5R95QN
M(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B=&5S="`Q
M*2!W92!E>'!E8W1E9"!T;R!G970@8F%C:R`G1$(@17)R;W(Z(&YO('-U8V@@
M=&%B;&4G+EQN(CL*("`@("`@("`@("`@<')I;G0@(DAE<F4@:7,@=&AE(&5R
M<F]R('=E(&=O=#I<;B(["B`@("`@("`@("`@('!R:6YT("=#;V1E.B`G("X@
M)&4M/F=E=$-O9&4H*2`N(")<;B(["B`@("`@("`@("`@('!R:6YT("=-97-S
M86=E.B`G("X@)&4M/F=E=$UE<W-A9V4H*2`N(")<;B(["B`@("`@("`@("`@
M('!R:6YT("=$96)U9SH@)R`N("1E+3YG971$96)U9TEN9F\H*2`N(")<;EQN
M(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")T97-T
M(#$I('=E(&5X<&5C=&5D('1O(&=E="!B86-K("=$0B!%<G)O<CH@;F\@<W5C
M:"!T86)L92<N7&XB.PH@("`@("`@('!R:6YT(")"=70@86X@97)R;W(@=V%S
M;B=T(&=E;F5R871E9%QN7&XB.PH@("`@?0I]"@HO+R`R*2!T97-T('1H870@
M=&AE('-E<75E;F-E(&ES(&YO="!C<F5A=&5D(&)U="!T:&4@97)R;W(@:7,*
M+R\@:&%N9&QE9"!B>2!T:&4@8VQA<W,@97)R;W(@:&%N9&QE<@HD9&)H+3YS
M971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0L"B`@("`@("`@("`@
M("`@("`@("`@("`@(F%N(&5R<F]R(&-O=6=H="!B>2!T:&4@97)R;W(@:&%N
M9&QE<B!I<R!G;V]D7&XB*3L*)&4@/2`D9&)H+3YN97AT260H(G1E<W0B+"!F
M86QS92D["FEF("@A1$(Z.FES17)R;W(H)&4I*2!["B`@("!P<FEN="`B=&5S
M="`R*2!F86EL960A7&XB.PI]"B1D8F@M/E]D969A=6QT7V5R<F]R7VUO9&4@
M/2!N=6QL.PH*+R\@,RD@=&5S="!T:&%T('-E<75E;F-E<R!A<F4@8W)E871E
M9"!I9B`B;VYD96UA;F0B(&ES('1R=64L(&%N9"!T:&%T"B\O('1W;R!S=6-C
M97-S:79E(&YE>'1)9',@<F5T=7)N(&%D:F%C96YT('9A;'5E<PHD82`]("1D
M8F@M/FYE>'1)9"@B=&5S="(I.PHD8B`]("1D8F@M/FYE>'1)9"@B=&5S="(I
M.PII9B`H1$(Z.FES17)R;W(H)&$I*2!["B`@("!P<FEN="`G83H@)R`N("1A
M+3YG971$96)U9TEN9F\H*2`N(")<;EQN(CL*?2!E;'-E('L*("`@('!R:6YT
M(")A/21A7&XB.PI]"FEF("A$0CHZ:7-%<G)O<B@D8BDI('L*("`@('!R:6YT
M("=B.B`G("X@)&(M/F=E=$1E8G5G26YF;R@I("X@(EQN7&XB.PI](&5L<V4@
M>PH@("`@<')I;G0@(F(])&)<;B(["GT*:68@*"%$0CHZ:7-%<G)O<B@D82D@
M)B8@(41".CII<T5R<F]R*"1B*2D@>PH@("`@<')I;G0@)V(M83TG("X@*"1B
M+21A*2`N(")<;B(["GT*"B\O(#0I('1E<W0@=&AA="!T:&4@=7-E<BUS<&5C
M:69I960@97)R;W(@:&%N9&QE<B!I<R!R96%L;'D@9&ES86)L960*+R\@9'5R
M:6YG(&YE>'1)9"P@=VET:"!P97(M;V)J96-T(&AA;F1L97(@87,@=V5L;"!A
M<R!G;&]B86P@:&%N9&QE<@HD9&)H+3YD<F]P4V5Q=65N8V4H(G1E<W0B*3L*
M"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]#04Q,0D%#2RP@
M)V5R<F]R7VAA;F1L97(G*3L*)&,@/2`D9&)H+3YN97AT260H(G1E<W0B*3L*
M:68@*"%$0CHZ:7-%<G)O<B@D8RDI('L*("`@('!R:6YT(")C/21C7&XB.PI]
M"B1D8F@M/F1R;W!397%U96YC92@B=&5S="(I.PHD9&)H+3Y?9&5F875L=%]E
M<G)O<E]M;V1E(#T@;G5L;#L*)&0@/2`D9&)H+3YN97AT260H(G1E<W0B*3L*
M:68@*"%$0CHZ:7-%<G)O<B@D9"DI('L*("`@('!R:6YT(")D/21D7&XB.PI]
M"@HO+R`U*2!T97-T('1H870@=&AE('-E<75E;F-E(&ES(&AA;F1L960@<FEG
M:'0@=VAE;B!T:&4@=&%B;&4@:7,@96UP='D*"B\O($)A8VME;F0@=VET:"!R
M96%L('-E<75E;F-E<R!M87D@9&]N)W0@;&EK92!T:&%T"E!%05(Z.G!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*)&1B:"T^<75E<GDH
M)T1%3$5412!&4D]-('1E<W1?<V5Q)RD["E!%05(Z.G!O<$5R<F]R2&%N9&QI
M;F<H*3L*)&4@/2`D9&)H+3YN97AT240H)W1E<W0G*3L*:68@*$1".CII<T5R
M<F]R*"1D*2D@>PH@("`@<')I;G0@)V4Z("<@+B`D9"T^9V5T1&5B=6=);F9O
M*"D@+B`B7&Y<;B(["GT@96QS92!["B`@("!P<FEN="`B93TD9%QN(CL*?0H*
M+R\@9FEN86P@8VQE86XM=7`*)&1B:"T^9')O<%-E<75E;F-E*")T97-T(BD[
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$
M0B]T97-T<R]S:6UP;&5Q=65R>2YI;F,`````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S-C(U(#$P-3$U-#,T,3,U(#`R-#,S-``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RHJ"B`J(%1E<W1S
M('1H92!D<FEV97)S)R!S:6UP;&51=65R>2@I(&UE=&AO9`H@*@H@*B!%>&5C
M=71E9"!B>2!D<FEV97(O,#-S:6UP;&5Q=65R>2YP:'!T"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S
M90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`
M=F5R<VEO;B`@("`D260Z('-I;7!L97%U97)Y+FEN8RQV(#$N."`R,#`U+S`R
M+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($QO8V%L
M(&5R<F]R(&-A;&QB86-K(&AA;F1L97(*("H*("H@1')O<',@=&AE('!H<'1E
M<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G92!A;F0@:VEL
M;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE8W0@("1O("!0
M14%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E9"!T;R!T:&ES
M(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2.CIS971%<G)O
M<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@("!G;&]B86P@
M)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"B`@
M("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1S=&@@/2`D9&)H
M+3YS:6UP;&51=65R>2@B4T5,14-4("H@1E)/32!P:'!T97-T(BD["@IS=VET
M8V@@*"1D8F@M/G!H<'1Y<&4I('L*("`@(&-A<V4@)VUY<W%L:2<Z"B`@("`@
M("`@:68@*&ES7V$H)'-T:"P@)VUY<W%L:5]R97-U;'0G*2D@>PH@("`@("`@
M("`@("!P<FEN="`B<&%S<V5D7&XB.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@('!R:6YT(")04D]"3$5-7&XB.PH@("`@("`@('T*("`@("`@("!B
M<F5A:SL*("`@(&1E9F%U;'0Z"B`@("`@("`@:68@*&=E='1Y<&4H)'-T:"D@
M/3T@)W)E<V]U<F-E)RD@>PH@("`@("`@("`@("!P<FEN="`B<&%S<V5D7&XB
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@('!R:6YT(")04D]"3$5-
M7&XB.PH@("`@("`@('T*?0H*"G-W:71C:"`H)&1B:"T^<&AP='EP92D@>PH@
M("`@8V%S92`G:6)A<V4G.@H@("`@("`@("\J"B`@("`@("`@("H@26YT97)B
M87-E(&1O97-N)W0@86QL;W<@9')O<'!I;F<@=&%B;&5S('1H870@:&%V92!R
M97-U;'0*("`@("`@("`@*B!S971S('-T:6QL(&]P96XN"B`@("`@("`@("HO
M"B`@("`@("`@)&1B:"T^9G)E95)E<W5L="@D<W1H*3L*("`@("`@("!B<F5A
M:SL*?0HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*9')O<%]T86)L92@D9&)H+"`G<&AP=&5S="<I.PH`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S
M=',O=')A;G-A8W1I;VYS+FEN8P``````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-38T-"`Q,#4Q-30S-#$S-2`P,C0T-S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@
M9')I=F5R<R<@=')A;G-A8W1I;VX@:&%N9&QI;F<@;65T:&]D<PH@*@H@*B!%
M>&5C=71E9"!B>2!D<FEV97(O,3%T<F%N<V%C=&EO;G,N<&AP=`H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@)$ED.B!T<F%N<V%C=&EO;G,N:6YC+'8@,2XY(#(P
M,#4O,#(O,#,@,#4Z-#DZ-#0@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO+R!497-T
M:6YG(&AE<F4@9'5E('1O('-K:7`@;F]T('=O<FMI;F<@8W5R<F5N=&QY(&EN
M(&AE860*:68@*"$D9&)H+3YF96%T=7)E<ULG=')A;G-A8W1I;VYS)UTI('L*
M("`@(&1I92@G=&AI<R!D<FEV97(@9&]E<R!N;W0@<W5P<&]R="!T<F%N<V%C
M=&EO;G,G*3L*?0H*+R\@5FEE=R!T:&4@=&%B;&4@9G)O;2!A('-E<&%R871E
M(&-O;FYE8W1I;VX@<V\@=V4@9&]N)W0@9&ES='5R8@HO+R!T:&4@=')A;G-A
M8W1I;VXN"B1D8F@R(#T@1$(Z.F-O;FYE8W0H)&1B:"T^9'-N*3L*"F9U;F-T
M:6]N(&5R<F]R7VAA;F1L97(H)B1O8FHI('L*("`@('!R:6YT(")<;B(@+B`D
M;V)J+3YG971$96)U9TEN9F\H*2`N(")<;B(["GT*"F9U;F-T:6]N(&1U;7!T
M86)L92@D97AP96-T960I('L*("`@(&=L;V)A;"`D9&)H+"`D9&)H,CL*("`@
M('!R:6YT(&EM<&QO9&4H)R`G+"`D9&)H+3YG971#;VPH)U-%3$5#5"!B($92
M3TT@<&AP=&5S="<I*3L*"B`@("!I9B`H:7-S970H)&1B:"T^=')A;G-A8W1I
M;VY?;W!C;W5N="DI('L*("`@("`@("!I9B`H)&5X<&5C=&5D(#T]("1D8F@M
M/G1R86YS86-T:6]N7V]P8V]U;G0I('L*("`@("`@("`@("`@<')I;G0@(BX@
M(&]P<SUO:UQN(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN
M="`B+B`@;W!S/21D8F@M/G1R86YS86-T:6]N7V]P8V]U;G1<;B(["B`@("`@
M("`@?0H@("`@?2!E;'-E('L*("`@("`@("!P<FEN="`B+B`@;W!S/6]K7&XB
M.PH@("`@?0I]"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M0T%,3$)!0TLL("=E<G)O<E]H86YD;&5R)RD["@H*)&1B:"T^875T;T-O;6UI
M="AT<G5E*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,
M5453*#$L("=O;F4G+"`G3VYE)RP@)S(P,#$M,#(M,3DG*2(I.PH*<')I;G0@
M)S$I(&%F=&5R(&%U=&]C;VUM:70Z("<["F1U;7!T86)L92@P*3L*"B1D8F@M
M/F%U=&]#;VUM:70H9F%L<V4I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@
M<&AP=&5S="!604Q515,H,BP@)W1W;R<L("=4=V\G+"`G,C`P,2TP,BTR,"<I
M(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R@S
M+"`G=&AR964G+"`G5&AR964G+"`G,C`P,2TP,BTR,2<I(BD["G!R:6YT("<R
M*2!B969O<F4@8V]M;6ET.B`G.PID=6UP=&%B;&4H,BD["@HD9&)H+3YC;VUM
M:70H*3L*<')I;G0@)S,I(&%F=&5R(&-O;6UI=#H@)SL*9'5M<'1A8FQE*#`I
M.PH*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453*#0L
M("=F;W5R)RP@)T9O=7(G+"`G,C`P,2TP,BTR,B<I(BD["B1D8F@M/G%U97)Y
M*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R@U+"`G9FEV92<L("=&:79E
M)RP@)S(P,#$M,#(M,C,G*2(I.PIP<FEN="`G-"D@8F5F;W)E(')O;&QB86-K
M.B`G.PID=6UP=&%B;&4H,BD["@HD9&)H+3YR;VQL8F%C:R@I.PIP<FEN="`G
M-2D@869T97(@<F]L;&)A8VLZ("<["F1U;7!T86)L92@P*3L*)&1B:"T^<F]L
M;&)A8VLH*3L*"B1D8F@M/F%U=&]#;VUM:70H=')U92D["B1D8F@M/G%U97)Y
M*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R@V+"`G<VEX)RP@)U-I>"<L
M("<R,#`Q+3`R+3(T)RDB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H
M<'1E<W0@5D%,5453*#<L("=S979E;B<L("=3979E;B<L("<R,#`Q+3`R+3(U
M)RDB*3L*<')I;G0@)S8I(&)E9F]R92!A=71O8V]M;6ET*W)O;&QB86-K.B`G
M.PID=6UP=&%B;&4H,"D["@HD9&)H+3YR;VQL8F%C:R@I.PIP<FEN="`G-RD@
M869T97(@875T;V-O;6UI="MR;VQL8F%C:SH@)SL*9'5M<'1A8FQE*#`I.PH*
M<')I;G0@)S@I('1E<W1I;F<@=&AA="!S96QE8W0@9&]E<VY<)W0@9&ES='5R
M8F4@;W!C;W5N=#H@)SL*)&1B:"T^875T;T-O;6UI="AF86QS92D["B1D8F@M
M/G-I;7!L95%U97)Y*")314Q%0U0@*B!&4D]-('!H<'1E<W0B*3L*)&1B:"T^
M<VEM<&QE475E<GDH(E-%3$5#5"!A+&,@1E)/32!P:'!T97-T(BD["B1D8F@M
M/G-I;7!L95%U97)Y*")314Q%0U0@8BQD($923TT@<&AP=&5S="(I.PII9B`H
M96UP='DH)&1B:"T^=')A;G-A8W1I;VY?;W!C;W5N="DI('L*("`@('!R:6YT
M(")O:UQN(CL*?2!E;'-E('L*("`@('!R:6YT(")F86EL960@*&-O=6YT/21D
M8F@M/G1R86YS86-T:6]N7V]P8V]U;G0I7&XB.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]S:VEP:68N:6YC````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C4W(#$P-3$U-#,T,3,U
M(#`R,S(T-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*+RHJ"B`J($$@=&5S="!T;R!M86ME('-U<F4@4$5!4B!$
M0B!C86X@8F4@9F]U;F0*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!0
M2%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1"
M"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP
M+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@<VMI
M<&EF+FEN8RQV(#$N,B`R,#`U+S`R+S`S(#`U.C0Y.C0T(&1A;FEE;&,@17AP
M("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1""B`J+PH*+RHJ"B`J(%-E="!U<"!T:&4@:6YC;'5D95]P871H+"!E<G)O
M<E]R97!O<G1I;F<@86YD(%!!5$A?4T5005)!5$]2"B`J+PIR97%U:7)E7V]N
M8V4@)RXO:6YC;'5D92YI;F,G.PH*:68@*"%I;F-L=61E7V]N8V4@)T1"+G!H
M<"<I('L*("`@('!R:6YT("=S:VEP(&-O=6QD(&YO="!F:6YD($1"+G!H<"<[
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D8E]E<G)O
M<BYP:'!T````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,30W(#$P-3$U
M-#,T,3,U(#`R,S<U-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+51%4U0M+0I$0CHZ1$)?17)R;W(*+2U32TE0248M+0H\
M/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G
M+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M
M*BT*<F5Q=6ER95]O;F-E("<N+VEN8VQU9&4N:6YC)SL*<F5Q=6ER95]O;F-E
M("=$0BYP:'`G.PH*9G5N8W1I;VX@=&5S=%]E<G)O<E]H86YD;&5R*"1E<G)N
M;RP@)&5R<FUS9RP@)&9I;&4L("1L:6YE+"`D=F%R<RD@>PH@("`@:68@*&1E
M9FEN960H)T5?4U1224-4)RDI('L*("`@("`@("!I9B`H)&5R<FYO("8@15]3
M5%))0U0*("`@("`@("`@("`@)B8@*&5R<F]R7W)E<&]R=&EN9R@I("8@15]3
M5%))0U0I("$]($5?4U1224-4*2!["B`@("`@("`@("`@("\O($EG;F]R92!%
M7U-44DE#5"!N;W1I8V5S('5N;&5S<R!T:&5Y(&AA=F4@8F5E;B!T=7)N960@
M;VX*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T@96QS92![
M"B`@("`@("`@9&5F:6YE*"=%7U-44DE#5"<L(#(P-#@I.PH@("`@?0H@("`@
M)&5R<F]R='EP92`](&%R<F%Y("@*("`@("`@("!%7T524D]2(#T^("=%<G)O
M<B<L"B`@("`@("`@15]705).24Y'(#T^("=787)N:6YG)RP*("`@("`@("!%
M7U!!4E-%(#T^("=087)S:6YG($5R<F]R)RP*("`@("`@("!%7TY/5$E#12`]
M/B`G3F]T:6-E)RP*("`@("`@("!%7T-/4D5?15)23U(@/3X@)T-O<F4@17)R
M;W(G+`H@("`@("`@($5?0T]215]705).24Y'(#T^("=#;W)E(%=A<FYI;F<G
M+`H@("`@("`@($5?0T]-4$E,15]%4E)/4B`]/B`G0V]M<&EL92!%<G)O<B<L
M"B`@("`@("`@15]#3TU024Q%7U=!4DY)3D<@/3X@)T-O;7!I;&4@5V%R;FEN
M9R<L"B`@("`@("`@15]54T527T524D]2(#T^("=5<V5R($5R<F]R)RP*("`@
M("`@("!%7U5315)?5T%23DE.1R`]/B`G57-E<B!787)N:6YG)RP*("`@("`@
M("!%7U5315)?3D]424-%(#T^("=5<V5R($YO=&EC92<L"B`@("`@("`@15]3
M5%))0U0@/3X@)U-T<FEC="!.;W1I8V4G+`H@("`@*3L*("`@("1P<F5F:7@@
M/2`D97)R;W)T>7!E6R1E<G)N;UT["B`@("!P<FEN="`B7&XD<')E9FEX.B`D
M97)R;7-G(&EN("(@+B!B87-E;F%M92@D9FEL92D@+B`B(&]N(&QI;F4@6%A8
M7&XB.PI]"@IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PIS971?97)R;W)?:&%N
M9&QE<B@G=&5S=%]E<G)O<E]H86YD;&5R)RD["@IP<FEN="`B=&5S=&EN9R!D
M:69F97)E;G0@97)R;W(@8V]D97,N+BY<;B(["B1E(#T@;F5W($1"7T5R<F]R
M*"D[('!R:6YT('-T<G1O;&]W97(H)&4M/G1O4W1R:6YG*"DI+B)<;B(["B1E
M(#T@;F5W($1"7T5R<F]R*")T97-T(&5R<F]R(BD[('!R:6YT('-T<G1O;&]W
M97(H)&4M/G1O4W1R:6YG*"DI+B)<;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"
M7T]+*3L@<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*
M)&4@/2!N97<@1$)?17)R;W(H1$)?15)23U(I.R!P<FEN="!S=')T;VQO=V5R
M*"1E+3YT;U-T<FEN9R@I*2XB7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%
M4E)/4E]364Y405@I.R!P<FEN="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I
M*2XB7&XB.PHD92`](&YE=R!$0E]%<G)O<BA$0E]%4E)/4E]$259:15)/*3L@
M<')I;G0@<W1R=&]L;W=E<B@D92T^=&]3=')I;F<H*2DN(EQN(CL*"G!R:6YT
M(")T97-T:6YG(&1I9F9E<F5N="!E<G)O<B!M;V1E<RXN+EQN(CL*)&4@/2!N
M97<@1$)?17)R;W(H1$)?15)23U(L(%!%05)?15)23U)?4%))3E0I.R!P<FEN
M="!S=')T;VQO=V5R*"1E+3YT;U-T<FEN9R@I*2XB7&XB.PHD92`](&YE=R!$
M0E]%<G)O<BA$0E]%4E)/4E]364Y405@L(%!%05)?15)23U)?5%))1T=%4BD[
M"@IP<FEN="`B=&5S=&EN9R!D:69F97)E;G0@97)R;W(@<V5R=F5R:71I97,N
M+BY<;B(["B1E(#T@;F5W($1"7T5R<F]R*$1"7T524D]27U-93E1!6"P@4$5!
M4E]%4E)/4E]44DE'1T52+"!%7U5315)?3D]424-%*3L*)&4@/2!N97<@1$)?
M17)R;W(H1$)?15)23U)?4UE.5$%8+"!014%27T524D]27U1224='15(L($5?
M55-%4E]705).24Y'*3L*)&4@/2!N97<@1$)?17)R;W(H1$)?15)23U)?4UE.
M5$%8+"!014%27T524D]27U1224='15(L($5?55-%4E]%4E)/4BD["@H_/@HM
M+4=%5"TM"BTM4$]35"TM"BTM15A014-4+2T*=&5S=&EN9R!D:69F97)E;G0@
M97)R;W(@8V]D97,N+BX*6V1B7V5R<F]R.B!M97-S86=E/2)D8B!E<G)O<CH@
M=6YK;F]W;B!E<G)O<B(@8V]D93TM,2!M;V1E/7)E='5R;B!L979E;#UN;W1I
M8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E<G)O<CH@;65S<V%G93TB9&(@
M97)R;W(Z('1E<W0@97)R;W(B(&-O9&4]+3$@;6]D93UR971U<FX@;&5V96P]
M;F]T:6-E('!R969I>#TB(B!I;F9O/2(B70I;9&)?97)R;W(Z(&UE<W-A9V4]
M(F1B(&5R<F]R.B!N;R!E<G)O<B(@8V]D93TQ(&UO9&4]<F5T=7)N(&QE=F5L
M/6YO=&EC92!P<F5F:7@](B(@:6YF;STB(ET*6V1B7V5R<F]R.B!M97-S86=E
M/2)D8B!E<G)O<CH@=6YK;F]W;B!E<G)O<B(@8V]D93TM,2!M;V1E/7)E='5R
M;B!L979E;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E<G)O<CH@
M;65S<V%G93TB9&(@97)R;W(Z('-Y;G1A>"!E<G)O<B(@8V]D93TM,B!M;V1E
M/7)E='5R;B!L979E;#UN;W1I8V4@<')E9FEX/2(B(&EN9F\](B)="EMD8E]E
M<G)O<CH@;65S<V%G93TB9&(@97)R;W(Z(&1I=FES:6]N(&)Y('IE<F\B(&-O
M9&4]+3$S(&UO9&4]<F5T=7)N(&QE=F5L/6YO=&EC92!P<F5F:7@](B(@:6YF
M;STB(ET*=&5S=&EN9R!D:69F97)E;G0@97)R;W(@;6]D97,N+BX*1$(@17)R
M;W(Z('5N:VYO=VX@97)R;W);9&)?97)R;W(Z(&UE<W-A9V4](F1B(&5R<F]R
M.B!U;FMN;W=N(&5R<F]R(B!C;V1E/2TQ(&UO9&4]<')I;G0@;&5V96P];F]T
M:6-E('!R969I>#TB(B!I;F9O/2(B70H*57-E<B!.;W1I8V4Z($1"($5R<F]R
M.B!S>6YT87@@97)R;W(@:6X@4$5!4BYP:'`@;VX@;&EN92!86%@*=&5S=&EN
M9R!D:69F97)E;G0@97)R;W(@<V5R=F5R:71I97,N+BX*"E5S97(@3F]T:6-E
M.B!$0B!%<G)O<CH@<WEN=&%X(&5R<F]R(&EN(%!%05(N<&AP(&]N(&QI;F4@
M6%A8"@I5<V5R(%=A<FYI;F<Z($1"($5R<F]R.B!S>6YT87@@97)R;W(@:6X@
M4$5!4BYP:'`@;VX@;&EN92!86%@*"E5S97(@17)R;W(Z($1"($5R<F]R.B!S
M>6YT87@@97)R;W(@:6X@4$5!4BYP:'`@;VX@;&EN92!86%@*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9&)?<&%R
M<V5D<VXN<&AP=```````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,S$V-2`Q,#4Q
M-30S-#$S-2`P,C0T-#0`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2U415-4+2T*1$(Z.G!A<G-E1%-."BTM4TM)4$E&+2T*
M/#]P:'`@8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@
M)RXO<VMI<&EF+FEN8R<[(#\^"BTM1DE,12TM"CP_<&AP("\O("TJ+2!#*RL@
M+2HM"G)E<75I<F5?;VYC92`G+B]I;F-L=61E+FEN8R<["G)E<75I<F5?;VYC
M92`G1$(N<&AP)SL*"F9U;F-T:6]N('1E<W0H)&1S;BD@>PH@("`@96-H;R`B
M1%-..B`D9'-N7&XB.PH@("`@<')I;G1?<BA$0CHZ<&%R<V5$4TXH)&1S;BDI
M.PI]"@IF=6YC=&EO;B!T97-T07)R87DH)&1S;BD@>PH@("`@96-H;R`B1%-.
M.B!A<G)A>5QN(CL*("`@('!R:6YT7W(H1$(Z.G!A<G-E1%-.*"1D<VXI*3L*
M?0H*<')I;G0@(G1E<W1I;F<@1$(Z.G!A<G-E1%-.+BXN7&Y<;B(["@IT97-T
M*")M>7-Q;"(I.PIT97-T*")O9&)C*&US<W%L*2(I.PIT97-T*"=O9&)C*&1B
M,BDZ+R]U<V5R.G!A<W-W;W)D0"]D871A8F%S92<I.PIT97-T*"=O9&)C*&%C
M8V5S<RDZ+R\O9&%T86)A<V4G*3L*=&5S="@G;V1B8SHO+V%D;6EN0"]D871A
M<V]U<F-E3F%M92<I.PIT97-T*")M>7-Q;#HO+VQO8V%L:&]S="(I.PIT97-T
M*")M>7-Q;#HO+W)E;6]T92YH;W-T+F-O;2]D8B(I.PIT97-T*")O8VDX.B\O
M<WES=&5M.FUA;F%G97)`(BD["G1E<W0H(F]C:3@Z+R]U<V5R.G!A<W-`=&YS
M+6YA;64B*3L*=&5S="@B;V1B8RAS;VQI9"DZ+R]F;V\Z8F%R0'1C<"ML;V-A
M;&AO<W0K,3,Q,R(I.R`@+R\@9&5P<F5C871E9`IT97-T*")P9W-Q;#HO+W5S
M97)`=6YI>"ML;V-A;&AO<W0O<&5A<B(I.R`@("`@("`@("`O+R!D97!R96-A
M=&5D"G1E<W0H(FEB87-E.B\O=7-E<B4T,&1O;6%I;CIP87-S=V]R9$!H;W-T
M(BD["G1E<W0H(FEB87-E.B\O=7-E<D!D;VUA:6XZ<&%S<T!W;W)D0"]D871A
M8F%S92(I.R`@("\O(&%L<V\@<W5P<&]R=&5D"G1E<W0H(FEF>#HO+W5S97)`
M9&]M86EN.G!A<W-`=V]R9$!H;W-T+F-O;2\O=7-R+V1B+V=E;F5R86PN9&(B
M*3L*=&5S="@G:69X.B\O<F5M;W1E+FAO<W0N8V]M+V,Z7'=I;F1O=W-<;7DN
M9&(G*3L*=&5S="@G;V-I.#HO+U-(3T]43U54.BHJ*BHJ*D`H1$530U))4%1)
M3TX]*$%$1%)%4U-?3$E35#TH041$4D534STH4%)/5$]#3TP]5$-0*2A(3U-4
M/3$Y,BXQ-C@N,3`Q+C$V,2DH4$]25#TQ-3(Q*2DI*$-/3DY%0U1?1$%403TH
M4T525DE#15].04U%/51)4RDI*2<I.PH*+R\@;F5W(&9O<FUA=',*=&5S="@B
M;V1B8RAS;VQI9"DZ+R]F;V\Z8F%R0&QO8V%L:&]S=#HQ,S$S(BD["G1E<W0H
M(G!G<W%L.B\O=7-E<D!U;FEX*"DO<&5A<B(I.PIT97-T*")M>7-Q;#HO+W5S
M97)`=6YI>"@O<&%T:"]T;R]S;V-K970I+W!E87(B*3L*=&5S="@B<&=S<6PZ
M+R]U<V5R0'1C<"@I+W!E87(B*3L*=&5S="@B<&=S<6PZ+R]U<V5R0'1C<"AS
M;VUE:&]S="DO<&5A<B(I.PIT97-T*")P9W-Q;#HO+W5S97(Z<&%S<T!W;W)D
M0'1C<"AS;VUE:&]S=#HW-S<W*2]P96%R(BD["@HO+R!S<&5C:6%L(&)A8VME
M;F0@;W!T:6]N<PIT97-T*"=I8F%S93HO+W5S97(Z<&%S<T!L;V-A;&AO<W0O
M+W9A<B]L:6(O9&)A<V4N9&)F/W)O;&4]9F]O)RD["G1E<W0H)V1B87-E.B\O
M0"\_<F]L93UF;V\F9&EA;&5C=#UB87(G*3L*=&5S="@G<W%L:71E.B\O+R]U
M;FEX+W!A=&@O=&\O9&%T86)A<V4_;W!T:6]N/79A;'5E)F%N;W1H97)O<'1I
M;VX]86YO=&AE<G9A;'5E)RD["G1E<W0H)W-Q;&ET93HO+R]C.B]W:6XO<&%T
M:"]T;R]D871A8F%S93]O<'1I;VX]=F%L=64G*3L*"B\O('-O;64@97AA;7!L
M97,@9G)O;2!M86YU86P*=&5S="@G;7ES<6PZ+R]U<V5R;F%M94!H;W-T<W!E
M8R<I.PIT97-T*"=M>7-Q;#HO+VAO<W1S<&5C+V1A=&%B87-E)RD["G1E<W0H
M)VUY<W%L.B\O:&]S='-P96,G*3L*=&5S="@G;7ES<6PZ+R\O9&%T86)A<V4G
M*3L*"B\O(&%R<F%Y('1E<W1S"B1A<G)A>2`](&%R<F%Y*`H@("`@)W!H<'1Y
M<&4G("`]/B`G;7ES<6PG+`H@("`@)VAO<W1S<&5C)R`]/B`G9F]O8F%R)RP*
M*3L*=&5S=$%R<F%Y*"1A<G)A>2D["@H_/@HM+4=%5"TM"BTM4$]35"TM"BTM
M15A014-4+2T*=&5S=&EN9R!$0CHZ<&%R<V5$4TXN+BX*"D133CH@;7ES<6P*
M07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;9&)S>6YT87A=
M(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^(`H@("`@6W!A<W-W;W)D72`]
M/B`*("`@(%MP<F]T;V-O;%T@/3X@"B`@("!;:&]S='-P96-=(#T^(`H@("`@
M6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^
M(`HI"D133CH@;V1B8RAM<W-Q;"D*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^
M(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@;7-S<6P*("`@(%MU<V5R;F%M95T@
M/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B`*("`@
M(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]
M/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-..B!O9&)C*&1B,BDZ+R]U<V5R
M.G!A<W-W;W)D0"]D871A8F%S90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@
M;V1B8PH@("`@6V1B<WEN=&%X72`]/B!D8C(*("`@(%MU<V5R;F%M95T@/3X@
M=7-E<@H@("`@6W!A<W-W;W)D72`]/B!P87-S=V]R9`H@("`@6W!R;W1O8V]L
M72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@
M("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@9&%T86)A<V4**0I$
M4TXZ(&]D8F,H86-C97-S*3HO+R]D871A8F%S90I!<G)A>0HH"B`@("!;<&AP
M='EP95T@/3X@;V1B8PH@("`@6V1B<WEN=&%X72`]/B!A8V-E<W,*("`@(%MU
M<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L
M72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@
M("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@9&%T86)A<V4**0I$
M4TXZ(&]D8F,Z+R]A9&UI;D`O9&%T87-O=7)C94YA;64*07)R87D**`H@("`@
M6W!H<'1Y<&5=(#T^(&]D8F,*("`@(%MD8G-Y;G1A>%T@/3X@;V1B8PH@("`@
M6W5S97)N86UE72`]/B!A9&UI;@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP
M<F]T;V-O;%T@/3X@=&-P"B`@("!;:&]S='-P96-=(#T^(`H@("`@6W!O<G1=
M(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^(&1A=&%S
M;W5R8V5.86UE"BD*1%-..B!M>7-Q;#HO+VQO8V%L:&]S=`I!<G)A>0HH"B`@
M("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD8G-Y;G1A>%T@/3X@;7ES<6P*
M("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R
M;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@;&]C86QH;W-T"B`@
M("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@
M/3X@"BD*1%-..B!M>7-Q;#HO+W)E;6]T92YH;W-T+F-O;2]D8@I!<G)A>0HH
M"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@(%MD8G-Y;G1A>%T@/3X@;7ES
M<6P*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@
M6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@<F5M;W1E+FAO
M<W0N8V]M"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD
M871A8F%S95T@/3X@9&(**0I$4TXZ(&]C:3@Z+R]S>7-T96TZ;6%N86=E<D`*
M07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&]C:3@*("`@(%MD8G-Y;G1A>%T@
M/3X@;V-I.`H@("`@6W5S97)N86UE72`]/B!S>7-T96T*("`@(%MP87-S=V]R
M9%T@/3X@;6%N86=E<@H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T
M<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@
M(%MD871A8F%S95T@/3X@"BD*1%-..B!O8VDX.B\O=7-E<CIP87-S0'1N<RUN
M86UE"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!O8VDX"B`@("!;9&)S>6YT
M87A=(#T^(&]C:3@*("`@(%MU<V5R;F%M95T@/3X@=7-E<@H@("`@6W!A<W-W
M;W)D72`]/B!P87-S"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S
M<&5C72`]/B!T;G,M;F%M90H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@
M/3X@"B`@("!;9&%T86)A<V5=(#T^(`HI"D133CH@;V1B8RAS;VQI9"DZ+R]F
M;V\Z8F%R0'1C<"ML;V-A;&AO<W0K,3,Q,PI!<G)A>0HH"B`@("!;<&AP='EP
M95T@/3X@;V1B8PH@("`@6V1B<WEN=&%X72`]/B!S;VQI9`H@("`@6W5S97)N
M86UE72`]/B!F;V\*("`@(%MP87-S=V]R9%T@/3X@8F%R"B`@("!;<')O=&]C
M;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!L;V-A;&AO<W0K,3,Q,PH@
M("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=
M(#T^(`HI"D133CH@<&=S<6PZ+R]U<V5R0'5N:7@K;&]C86QH;W-T+W!E87(*
M07)R87D**`H@("`@6W!H<'1Y<&5=(#T^('!G<W%L"B`@("!;9&)S>6YT87A=
M(#T^('!G<W%L"B`@("!;=7-E<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R
M9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('5N:7@*("`@(%MH;W-T<W!E8UT@
M/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B!L;V-A;&AO<W0*
M("`@(%MD871A8F%S95T@/3X@<&5A<@HI"D133CH@:6)A<V4Z+R]U<V5R)30P
M9&]M86EN.G!A<W-W;W)D0&AO<W0*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^
M(&EB87-E"B`@("!;9&)S>6YT87A=(#T^(&EB87-E"B`@("!;=7-E<FYA;65=
M(#T^('5S97)`9&]M86EN"B`@("!;<&%S<W=O<F1=(#T^('!A<W-W;W)D"B`@
M("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T"B`@
M("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@
M/3X@"BD*1%-..B!I8F%S93HO+W5S97)`9&]M86EN.G!A<W-`=V]R9$`O9&%T
M86)A<V4*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&EB87-E"B`@("!;9&)S
M>6YT87A=(#T^(&EB87-E"B`@("!;=7-E<FYA;65=(#T^('5S97)`9&]M86EN
M"B`@("!;<&%S<W=O<F1=(#T^('!A<W-`=V]R9`H@("`@6W!R;W1O8V]L72`]
M/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;
M<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@9&%T86)A<V4**0I$4TXZ
M(&EF>#HO+W5S97)`9&]M86EN.G!A<W-`=V]R9$!H;W-T+F-O;2\O=7-R+V1B
M+V=E;F5R86PN9&(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&EF>`H@("`@
M6V1B<WEN=&%X72`]/B!I9G@*("`@(%MU<V5R;F%M95T@/3X@=7-E<D!D;VUA
M:6X*("`@(%MP87-S=V]R9%T@/3X@<&%S<T!W;W)D"B`@("!;<')O=&]C;VQ=
M(#T^('1C<`H@("`@6VAO<W1S<&5C72`]/B!H;W-T+F-O;0H@("`@6W!O<G1=
M(#T^(`H@("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^("]U<W(O
M9&(O9V5N97)A;"YD8@HI"D133CH@:69X.B\O<F5M;W1E+FAO<W0N8V]M+V,Z
M7'=I;F1O=W-<;7DN9&(*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&EF>`H@
M("`@6V1B<WEN=&%X72`]/B!I9G@*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;
M<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T
M<W!E8UT@/3X@<F5M;W1E+FAO<W0N8V]M"B`@("!;<&]R=%T@/3X@"B`@("!;
M<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@8SI<=VEN9&]W<UQM>2YD
M8@HI"D133CH@;V-I.#HO+U-(3T]43U54.BHJ*BHJ*D`H1$530U))4%1)3TX]
M*$%$1%)%4U-?3$E35#TH041$4D534STH4%)/5$]#3TP]5$-0*2A(3U-4/3$Y
M,BXQ-C@N,3`Q+C$V,2DH4$]25#TQ-3(Q*2DI*$-/3DY%0U1?1$%403TH4T52
M5DE#15].04U%/51)4RDI*0I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;V-I
M.`H@("`@6V1B<WEN=&%X72`]/B!O8VDX"B`@("!;=7-E<FYA;65=(#T^(%-(
M3T]43U54"B`@("!;<&%S<W=O<F1=(#T^("HJ*BHJ*@H@("`@6W!R;W1O8V]L
M72`]/B!T8W`*("`@(%MH;W-T<W!E8UT@/3X@*$1%4T-225!424]./2A!1$12
M15-37TQ)4U0]*$%$1%)%4U,]*%!23U1/0T],/51#4"DH2$]35#TQ.3(N,38X
M+C$P,2XQ-C$I*%!/4E0],34R,2DI*2A#3TY.14-47T1!5$$]*%-%4E9)0T5?
M3D%-13U425,I*2D*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@
M("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&]D8F,H<V]L:60I.B\O9F]O.F)A
M<D!L;V-A;&AO<W0Z,3,Q,PI!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;V1B
M8PH@("`@6V1B<WEN=&%X72`]/B!S;VQI9`H@("`@6W5S97)N86UE72`]/B!F
M;V\*("`@(%MP87-S=V]R9%T@/3X@8F%R"B`@("!;<')O=&]C;VQ=(#T^('1C
M<`H@("`@6VAO<W1S<&5C72`]/B!L;V-A;&AO<W0*("`@(%MP;W)T72`]/B`Q
M,S$S"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-.
M.B!P9W-Q;#HO+W5S97)`=6YI>"@I+W!E87(*07)R87D**`H@("`@6W!H<'1Y
M<&5=(#T^('!G<W%L"B`@("!;9&)S>6YT87A=(#T^('!G<W%L"B`@("!;=7-E
M<FYA;65=(#T^('5S97(*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C
M;VQ=(#T^('5N:7@*("`@(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@
M"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@<&5A<@HI"D13
M3CH@;7ES<6PZ+R]U<V5R0'5N:7@H+W!A=&@O=&\O<V]C:V5T*2]P96%R"D%R
M<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]
M/B!M>7-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R"B`@("!;<&%S<W=O<F1=
M(#T^(`H@("`@6W!R;W1O8V]L72`]/B!U;FEX"B`@("!;:&]S='-P96-=(#T^
M(`H@("`@6W!O<G1=(#T^(`H@("`@6W-O8VME=%T@/3X@+W!A=&@O=&\O<V]C
M:V5T"B`@("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ('!G<W%L.B\O=7-E
M<D!T8W`H*2]P96%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!P9W-Q;`H@
M("`@6V1B<WEN=&%X72`]/B!P9W-Q;`H@("`@6W5S97)N86UE72`]/B!U<V5R
M"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@
M(%MH;W-T<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]
M/B`*("`@(%MD871A8F%S95T@/3X@<&5A<@HI"D133CH@<&=S<6PZ+R]U<V5R
M0'1C<"AS;VUE:&]S="DO<&5A<@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@
M<&=S<6P*("`@(%MD8G-Y;G1A>%T@/3X@<&=S<6P*("`@(%MU<V5R;F%M95T@
M/3X@=7-E<@H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@
M=&-P"B`@("!;:&]S='-P96-=(#T^('-O;65H;W-T"B`@("!;<&]R=%T@/3X@
M"B`@("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@<&5A<@HI"D13
M3CH@<&=S<6PZ+R]U<V5R.G!A<W-`=V]R9$!T8W`H<V]M96AO<W0Z-S<W-RDO
M<&5A<@I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@<&=S<6P*("`@(%MD8G-Y
M;G1A>%T@/3X@<&=S<6P*("`@(%MU<V5R;F%M95T@/3X@=7-E<@H@("`@6W!A
M<W-W;W)D72`]/B!P87-S0'=O<F0*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@
M("!;:&]S='-P96-=(#T^('-O;65H;W-T"B`@("!;<&]R=%T@/3X@-S<W-PH@
M("`@6W-O8VME=%T@/3X@"B`@("!;9&%T86)A<V5=(#T^('!E87(**0I$4TXZ
M(&EB87-E.B\O=7-E<CIP87-S0&QO8V%L:&]S="\O=F%R+VQI8B]D8F%S92YD
M8F8_<F]L93UF;V\*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&EB87-E"B`@
M("!;9&)S>6YT87A=(#T^(&EB87-E"B`@("!;=7-E<FYA;65=(#T^('5S97(*
M("`@(%MP87-S=V]R9%T@/3X@<&%S<PH@("`@6W!R;W1O8V]L72`]/B!T8W`*
M("`@(%MH;W-T<W!E8UT@/3X@;&]C86QH;W-T"B`@("!;<&]R=%T@/3X@"B`@
M("!;<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@+W9A<B]L:6(O9&)A
M<V4N9&)F"B`@("!;<F]L95T@/3X@9F]O"BD*1%-..B!D8F%S93HO+T`O/W)O
M;&4]9F]O)F1I86QE8W0]8F%R"D%R<F%Y"B@*("`@(%MP:'!T>7!E72`]/B!D
M8F%S90H@("`@6V1B<WEN=&%X72`]/B!D8F%S90H@("`@6W5S97)N86UE72`]
M/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@
M("`@6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=
M(#T^(`H@("`@6V1A=&%B87-E72`]/B`*("`@(%MR;VQE72`]/B!F;V\*("`@
M(%MD:6%L96-T72`]/B!B87(**0I$4TXZ('-Q;&ET93HO+R\O=6YI>"]P871H
M+W1O+V1A=&%B87-E/V]P=&EO;CUV86QU929A;F]T:&5R;W!T:6]N/6%N;W1H
M97)V86QU90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@<W%L:71E"B`@("!;
M9&)S>6YT87A=(#T^('-Q;&ET90H@("`@6W5S97)N86UE72`]/B`*("`@(%MP
M87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@6VAO<W1S
M<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@
M6V1A=&%B87-E72`]/B`O=6YI>"]P871H+W1O+V1A=&%B87-E"B`@("!;;W!T
M:6]N72`]/B!V86QU90H@("`@6V%N;W1H97)O<'1I;VY=(#T^(&%N;W1H97)V
M86QU90HI"D133CH@<W%L:71E.B\O+V,Z+W=I;B]P871H+W1O+V1A=&%B87-E
M/V]P=&EO;CUV86QU90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@<W%L:71E
M"B`@("!;9&)S>6YT87A=(#T^('-Q;&ET90H@("`@6W5S97)N86UE72`]/B`*
M("`@(%MP87-S=V]R9%T@/3X@"B`@("!;<')O=&]C;VQ=(#T^('1C<`H@("`@
M6VAO<W1S<&5C72`]/B`*("`@(%MP;W)T72`]/B`*("`@(%MS;V-K971=(#T^
M(`H@("`@6V1A=&%B87-E72`]/B!C.B]W:6XO<&%T:"]T;R]D871A8F%S90H@
M("`@6V]P=&EO;ET@/3X@=F%L=64**0I$4TXZ(&UY<W%L.B\O=7-E<FYA;65`
M:&]S='-P96,*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY<W%L"B`@("!;
M9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^('5S97)N86UE
M"B`@("!;<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@
M(%MH;W-T<W!E8UT@/3X@:&]S='-P96,*("`@(%MP;W)T72`]/B`*("`@(%MS
M;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`**0I$4TXZ(&UY<W%L.B\O
M:&]S='-P96,O9&%T86)A<V4*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY
M<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^
M(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@
M("!;:&]S='-P96-=(#T^(&AO<W1S<&5C"B`@("!;<&]R=%T@/3X@"B`@("!;
M<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@9&%T86)A<V4**0I$4TXZ
M(&UY<W%L.B\O:&]S='-P96,*07)R87D**`H@("`@6W!H<'1Y<&5=(#T^(&UY
M<W%L"B`@("!;9&)S>6YT87A=(#T^(&UY<W%L"B`@("!;=7-E<FYA;65=(#T^
M(`H@("`@6W!A<W-W;W)D72`]/B`*("`@(%MP<F]T;V-O;%T@/3X@=&-P"B`@
M("!;:&]S='-P96-=(#T^(&AO<W1S<&5C"B`@("!;<&]R=%T@/3X@"B`@("!;
M<V]C:V5T72`]/B`*("`@(%MD871A8F%S95T@/3X@"BD*1%-..B!M>7-Q;#HO
M+R]D871A8F%S90I!<G)A>0HH"B`@("!;<&AP='EP95T@/3X@;7ES<6P*("`@
M(%MD8G-Y;G1A>%T@/3X@;7ES<6P*("`@(%MU<V5R;F%M95T@/3X@"B`@("!;
M<&%S<W=O<F1=(#T^(`H@("`@6W!R;W1O8V]L72`]/B!T8W`*("`@(%MH;W-T
M<W!E8UT@/3X@"B`@("!;<&]R=%T@/3X@"B`@("!;<V]C:V5T72`]/B`*("`@
M(%MD871A8F%S95T@/3X@9&%T86)A<V4**0I$4TXZ(&%R<F%Y"D%R<F%Y"B@*
M("`@(%MP:'!T>7!E72`]/B!M>7-Q;`H@("`@6V1B<WEN=&%X72`]/B!M>7-Q
M;`H@("`@6W5S97)N86UE72`]/B`*("`@(%MP87-S=V]R9%T@/3X@"B`@("!;
M<')O=&]C;VQ=(#T^(`H@("`@6VAO<W1S<&5C72`]/B!F;V]B87(*("`@(%MP
M;W)T72`]/B`*("`@(%MS;V-K971=(#T^(`H@("`@6V1A=&%B87-E72`]/B`*
M*0H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O:6YC;'5D92YI
M;F,N;W)I9P``````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#`U-"`Q,#4Q-30S
M-#$S-2`P,C0S,S0`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"B\J*@H@*B!3971S('1H92!I;F-L=61E7W!A=&@L
M(&5R<F]R7W)E<&]R=&EN9R!A;F0@4$%42%]315!!4D%43U(@9F]R('1E<W1S
M"B`J(&EN('1H92!$0B]T97-T<R!D:7)E8W1O<GD*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO
M=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J
M($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S
M;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U
M(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S
M:6]N("`@("1)9#H@:6YC;'5D92YI;F,L=B`Q+C4@,C`P-2\P,B\P,R`P-3HT
M.3HT-"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"F5R<F]R7W)E<&]R=&EN9RA%7T%,
M3"D["@II9B`H(61E9FEN960H)U!!5$A?4T5005)!5$]2)RDI('L*("`@(&EF
M("AS=')I<W1R*%!(4%]/4RP@)U=)3B<I*2!["B`@("`@("`@+RHJ"B`@("`@
M("`@("H@1&5F:6YE('1H92!P871H('-E<&%R871O<B!F;W(@=VEN9&]W<PH@
M("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G4$%42%]315!!4D%43U(G+"`G
M.R<I.PH@("`@?2!E;'-E('L*("`@("`@("`O*BH*("`@("`@("`@*B!$969I
M;F4@=&AE('!A=&@@<V5P87)A=&]R(&9O<B!O=&AE<B!S>7-T96US"B`@("`@
M("`@("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<Z)RD[
M"B`@("!]"GT*"B\J"B`J($EF('1H92!P871H('1O('EO=7(@4$5!4B!I;G-T
M86QL871I;VX@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P;W)T:6]N
M(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A;G,@=&AI
M<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R+B`@
M5&AE<F5F;W)E+"!L970G<R!U<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S:6]N
M(&]F($1"+"!W:&EC:"!S:&]U;&0@8F4@9F]U;F0@=FEA('1H90H@*B!C;VUP
M=71E<B=S(&1E9F%U;'0@:6YC;'5D95]P871H+B`@061D("<N)R!T;R!T:&4@
M:6YC;'5D95]P871H"B`J('1O(&5N<W5R92`G+B<@:7,@:6X@=&AE<F4N"B`J
M(`H@*B!)9B!T:&4@<&%T:"!H87,@;F]T(&)E96X@<W5B<W1I='5T960@:6X@
M=&AE(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME;'D@
M8V]M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@*B!4
M:&5R969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S92!T
M:&4@=F5R<VEO;B!O9@H@*B!$0B!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE<F4@
M87,@=V5L;"X*("HO"FEF("@G+VAO;64O;'5C97(O=V]R:R]P96%R+W-H87)E
M+W!H<"<@(3T@)T`G+B=I;F-L=61E7W!A=&@G+B=`)RD@>PH@("`@:6YI7W-E
M="@G:6YC;'5D95]P871H)RP@:6YI7V=E="@G:6YC;'5D95]P871H)RD*("`@
M("`@("`@("`@+B!0051(7U-%4$%2051/4B`N("<N)PH@("`@*3L*?2!E;'-E
M('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(')E86QP871H*&1I<FYA
M;64H7U]&24Q%7U\I("X@)R\N+B<I"B`@("`@("`@("`@("X@4$%42%]315!!
M4D%43U(@+B`G+B<@+B!0051(7U-%4$%2051/4@H@("`@("`@("`@("`N(&EN
M:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@("`I.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S
M=',O9')I=F5R+W-E='5P+FEN8RYC=G,N;W)I9P``````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-S4V,B`Q,#4Q-30S-#$S-"`P,C8Q-#0`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*"B\J*@H@*B!%<W1A8FQI<VAE
M<R!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N;F5C=&EO;B`D;W!T
M:6]N<PH@*@H@*B!)9B!T:&ES(&9I;&4@:7,@;F%M960@(G-E='5P+FEN8RYC
M=G,L(B!I="!I<R!T:&4@;W)I9VEN86P@;VYE(&9R;VT@0U93+@H@*B!0;&5A
M<V4@9&\@=&AE(&9O;&QO=VEN9SH*("H@("`Q*2!-86ME(&$@8V]P>2!O9B!T
M:&ES(&9I;&4@;F%M960@(G-E='5P+FEN8R(N"B`J("`@,BD@5&AE;BP@:6X@
M=&AE(&-O<'DL(&5D:70@=&AE("1D<VYS(&%R<F%Y(&%S(&%P<')O<')I871E
M(&9O<B!Y;W5R"B`J("`@("`@96YV:7)O;FUE;G0N"B`J("`@,RD@070@;&5A
M<W0@;VYE(&5L96UE;G0@;V8@=&AE("1D<VYS(&%R<F%Y(&YE961S('1O(&)E
M('5N8V]M;65N=&5D+@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@)$ED.B!S971U
M<"YI;F,N8W9S+'8@,2XV(#(P,#4O,#(O,30@,C,Z,S,Z,C`@9&%N:65L8R!%
M>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O1$(*("HO"@II9B`H(61E9FEN960H)U!!5$A?4T5005)!5$]2)RDI('L*
M("`@(&EF("AS=')I<W1R*%!(4%]/4RP@)U=)3B<I*2!["B`@("`@("`@+RHJ
M"B`@("`@("`@("H@5&AE('-T<FEN9R!U<V5D('1O(&1E;&EM:70@96QE;65N
M=',@;V8@=&AE('!A=&@N"B`@("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0
M051(7U-%4$%2051/4B<L("<[)RD["B`@("!](&5L<V4@>PH@("`@("`@("\J
M*@H@("`@("`@("`J(%1H92!S=')I;F<@=7-E9"!T;R!D96QI;6ET(&5L96UE
M;G1S(&]F('1H92!P871H+@H@("`@("`@("`J+PH@("`@("`@(&1E9FEN92@G
M4$%42%]315!!4D%43U(G+"`G.B<I.PH@("`@?0I]"@HO*@H@*B!)9B!T:&4@
M<&%T:"!T;R!Y;W5R(%!%05(@:6YS=&%L;&%T:6]N(&ES(&9O=6YD(&EN('1H
M92!L969T(&AA;F0*("H@<&]R=&EO;B!O9B!T:&4@:68H*2!E>'!R97-S:6]N
M(&)E;&]W+"!T:&%T(&UE86YS('1H:7,@9FEL92!H87,*("H@8V]M92!F<F]M
M('1H92!014%2(&EN<W1A;&QE<BX@(%1H97)E9F]R92P@;&5T)W,@=7-E('1H
M90H@*B!I;G-T86QL960@=F5R<VEO;B!O9B!$0BP@=VAI8V@@<VAO=6QD(&)E
M(&9O=6YD('9I82!T:&4*("H@8V]M<'5T97(G<R!D969A=6QT(&EN8VQU9&5?
M<&%T:"X@($%D9"`G+B<@=&\@=&AE(&EN8VQU9&5?<&%T:`H@*B!T;R!E;G-U
M<F4@)RXG(&ES(&EN('1H97)E+@H@*B`*("H@268@=&AE('!A=&@@:&%S(&YO
M="!B965N('-U8G-T:71U=&5D(&EN('1H92!I9B@I(&5X<')E<W-I;VXL"B`J
M('1H:7,@9FEL92!H87,@;&EK96QY(&-O;64@9G)O;2!A($-64R!C:&5C:V]U
M="!O<B!A("YT87(@9FEL92X*("H@5&AE<F5F;W)E+"!W92=L;"!A<W-U;64@
M=&AE('1E<W1S('-H;W5L9"!U<V4@=&AE('9E<G-I;VX@;V8*("H@1$(@=&AA
M="!H87,@8V]M92!F<F]M('1H97)E(&%S('=E;&PN"B`J+PII9B`H)R]H;VUE
M+VQU8V5R+W=O<FLO<&5A<B]S:&%R92]P:'`G("$]("=`)RXG:6YC;'5D95]P
M871H)RXG0"<I('L*("`@(&EN:5]S970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G
M970H)VEN8VQU9&5?<&%T:"<I"B`@("`@("`@("`@("X@4$%42%]315!!4D%4
M3U(@+B`G+B<*("`@("D["GT@96QS92!["B`@("!I;FE?<V5T*"=I;F-L=61E
M7W!A=&@G+"!R96%L<&%T:"AD:7)N86UE*%]?1DE,15]?*2`N("<O+BXO+BXG
M*0H@("`@("`@("`@("`N(%!!5$A?4T5005)!5$]2("X@)RXG("X@4$%42%]3
M15!!4D%43U(*("`@("`@("`@("`@+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G
M*0H@("`@*3L*?0H*+RHJ"B`J($=R86(@=&AE(%!%05(@1$(@8VQA<W-E<RX*
M("HO"G)E<75I<F5?;VYC92`G1$(N<&AP)SL*"B\O($]P=&EO;G,@=7-E9"!W
M:&5N(&-O;FYE8W1I;F<*)&]P=&EO;G,@/2!A<G)A>2@*("`@("\O)V]P=&EM
M:7IE)R`]/B`G<&]R=&%B:6QI='DG+`H@("`@)W!O<G1A8FEL:71Y)R`]/B!$
M0E]03U)404))3$E465]!3$PL"B`@("`G9&5B=6<G(#T^(#(L"BD["@HD9&)A
M<V5D<VX@/2!A<G)A>2@*("`@("=P:'!T>7!E)R`@/3X@)V1B87-E)RP*("`@
M("=D871A8F%S92<@/3X@)R]P871H+V%N9"]N86UE+V]F+V1B87-E+V9I;&4G
M+`H@("`@)VUO9&4G("`@("`]/B`R+`H@("`@)V9I96QD<R<@("`]/B!A<G)A
M>2@*("`@("`@("!A<G)A>2@G82<L("=.)RP@-2P@,"DL"B`@("`@("`@87)R
M87DH)V(G+"`G0R<L(#0P*2P*("`@("`@("!A<G)A>2@G8R<L("=#)RP@,C4U
M*2P*("`@("`@("!A<G)A>2@G9"<L("=#)RP@,C`I+`H@("`@*2P**3L*"B\J
M"B`J(%5N8V]M;65N="!A="!L96%S="!O;F4@;V8@=&AE(&9O;&QO=VEN9R!E
M;&5M96YT<RX*("H@5VAE;B!R=6YN:6YG('1H92`N<&AP="!T97-T<RP@=&AE
M(&9I<G-T('5N8V]M;65N=&5D(&5L96UE;G0@:7,@=7-E9"X*("H@5VAE;B!R
M=6YN:6YG('1H92!M=6QT:6-O;FYE8W0N<&AP('1E<W0L(&%L;"!U;F-O;6UE
M;G1E9"!E;&5M96YT<R!A<F4@=7-E9"X*("HO"B1D<VYS(#T@87)R87DH"B`@
M("`O+R`G9&)A<V4G("`@(#T^("1D8F%S961S;BP*("`@("\O("=F8G-Q;"<@
M("`@/3X@)V9B<W%L.B\O7W-Y<W1E;3I`+V1B)RP*("`@("\O("=F:7)E8FER
M9"<@/3X@)VEB87-E*&9I<F5B:7)D*3HO+U-94T1"03IM87-T97)K97E`+R]O
M<'0O:6YT97)B87-E+V5X86UP;&5S+V5M<&QO>65E+F=D8C]D:6%L96-T/3,G
M+`H@("`@+R\@)VEF>"<@("`@("`]/B`G:69X.B\O=7-E<CIP=T!L;V-A;&AO
M<W0O9&(G+`H@("`@+R\@)VUS<6PG("`@("`]/B`G;7-Q;#HO+R]D8B<L"@H@
M("`@+R\@270G<R!A9'9I<V%B;&4@=&\@=7-E(&]N;'D@;VYE(&]F('1H92!F
M;VQL;W=I;F<@870@82!T:6UE.@H@("`@+R\@)VUS<W%L)R`@("`]/B`G;7-S
M<6PZ+R]S84!S;VUE:&]S="]P=6)S)RP*("`@("\O("=S>6)A<V4G("`@/3X@
M)W-Y8F%S93HO+W-A0'-O;65H;W-T+W!U8G,G+`H*("`@("\O("=M>7-Q;"<@
M("`@/3X@)VUY<W%L.B\O<F]O=$!L;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G
M;7ES<6QI)R`@(#T^("=M>7-Q;&DZ+R]R;V]T0&QO8V%L:&]S="]T97-T)RP*
M("`@("\O("=O8VDX)R`@("`@/3X@)V]C:3@Z+R]S>7-T96TZ;6%N86=E<D`G
M+`H@("`@+R\@)V%C8V5S<R<@("`]/B`G;V1B8RAA8V-E<W,I.B\O861M:6Y`
M+U-Y<W1E;41S;DYA;64G+`H@("`@+R\@)V1B,B<@("`@("`]/B`G;V1B8RAD
M8C(I.B\O9&(R:6YS=#$Z6%A86$`O4T%-4$Q%)RP*("`@("\O("=P9W-Q;"<@
M("`@/3X@)W!G<W%L.B\O<&]S=&=R97-`;&]C86QH;W-T+W1E<W0G+`H@("`@
M+R\@)W-Q;&ET92<@("`]/B`G<W%L:71E.B\O9'5M;7DZ0&QO8V%L:&]S="\G
M("X@9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W1E<W0N9&(_
M;6]D93TP-C0T)RP**3L*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S`S<VEM<&QE<75E<GDN<&AP
M=``````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#,U-R`Q,#4Q-30S-#$S-"`P,C8Q-S(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````+2U415-4
M+2T*1$)?9')I=F5R.CIS:6UP;&51=65R>0HM+4E.22TM"F5R<F]R7W)E<&]R
M=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?
M1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&
M24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q
M=6ER95]O;F-E("<N+B]S:6UP;&5Q=65R>2YI;F,G.PH_/@HM+4584$5#5"TM
M"G!A<W-E9`H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+T1"+W1E<W1S+V1R:79E<B\P-&YU;6-O;',N<&AP=```````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S-3`@,3`U,34T,S0Q,S0@,#(U,C8U`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM5$535"TM"D1"7V1R:79E
M<CHZ;G5M0V]L<PHM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U3
M2TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I
M<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q
M=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N+B]N
M=6UC;VQS+FEN8R<["C\^"BTM15A014-4+2T*,0HR"C,*-`H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D
M<FEV97(O,#5S97%U96YC97,N<&AP=```````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#$W
M(#$P-3$U-#,T,3,T(#`R-38P,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G-E<75E;F-E
M<PHM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\
M/W!H<`IE<G)O<E]R97!O<G1I;F<H15]!3$PI.PIC:&1I<BAD:7)N86UE*%]?
M1DE,15]?*2D["G)E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*)'1A8FQE
M26YF;R`]("1D8BT^9')O<%-E<75E;F-E*"=A:FMD<VQF86IO:6IK861I92<I
M.PII9B`H1$(Z.FES17)R;W(H)'1A8FQE26YF;RD@)B8@)'1A8FQE26YF;RT^
M8V]D92`]/2!$0E]%4E)/4E].3U1?0T%004),12D@>PH@("`@9&EE*")S:VEP
M("1T86)L94EN9F\M/FUE<W-A9V4B*3L*?0H_/@HM+49)3$4M+0H\/W!H<`IR
M97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PIR97%U:7)E7V]N8V4@)RXN
M+W-E<75E;F-E<RYI;F,G.PH_/@HM+4584$5#5"TM"F%N(&5R<F]R(&ES('1H
M92!P<F]P97(@<F5S<&]N<V4@:&5R90IA;B!E<G)O<B!C;W5G:'0@8GD@=&AE
M(&5R<F]R(&AA;F1L97(@:7,@9V]O9`IA/3$*8CTR"F(M83TQ"F,],0ID/3$*
M93TQ"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T
M97-T<R]D<FEV97(O,#9P<F5P97AE8RYP:'!T````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,S<U(#$P-3$U-#,T,3,T(#`R-30S,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G!R
M97!A<F4O97AE8W5T90HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*
M+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E
M<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*
M<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*<F5Q=6ER95]O;F-E("<N
M+B]P<F5P97AE+FEN8R<["C\^"BTM15A014-4+2T*+2TM+2TM+2TM+2TM,2TM
M+2TM+2TM+2TM+0IS=&@Q+'-T:#(L<W1H,RQS=&@T(&-R96%T960*<W1H,3H@
M/R!A<R!P87)A;2P@<&%S<VEN9R!A<R!A<G)A>2XN+B!S=&@Q(&5X96-U=&5D
M"G-T:#(Z("$@86YD(#\@87,@<&%R86US+"!P87-S:6YG(&%S(&%R<F%Y+BXN
M('-T:#(@97AE8W5T960*<W1H,SH@/RP@(2!A;F0@)B!A<R!P87)A;7,L('!A
M<W-I;F<@87,@87)R87DN+BX@<W1H,R!E>&5C=71E9`IS=&@T.B!N;R!P87)A
M;7,N+BX@<W1H-"!E>&5C=71E9`IR97-U;'1S.@I\-S(@+2!A("T@("T@?`I\
M-S(@+2!D:7)E8W0@+2`@+2!\"GPW,B`M(&ET)W,@9V]O9"`M(&]P87%U92!P
M;&%C96AO;&1E<B=S('1E<W0@+2!\"GPW,B`M('1H870G<R!R:6=H="`M("`M
M('P*"BTM+2TM+2TM+2TM+3(M+2TM+2TM+2TM+2T*<F5S=6QT<SH*?#<R("T@
M<V5T,2`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X
M?`I\-S(@+2!S970R("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*
M?#<R("T@<V5T,R`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\"@HM
M+2TM+2TM+2TM+2TS+2TM+2TM+2TM+2TM"E12544*1D%,4T4*"BTM+2TM+2TM
M+2TM+30M+2TM+2TM+2TM+2T*?#<R("T@<V5T,2`M(&]P87%U92!P;&%C96AO
M;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X?`I\-S(@+2!S970R("T@;W!A<75E
M('!L86-E:&]L9&5R)W,@=&5S="`M('P*?#<R("T@<V5T,R`M(&]P87%U92!P
M;&%C96AO;&1E<B=S('1E<W0@+2!\"GY^"GY^"GPW,B`M('-E=#$@+2!O<&%Q
M=64@<&QA8V5H;VQD97(G<R!T97-T("T@,3(S-"TU-BTW.'P*?GX*?#<R("T@
M<V5T,2`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2`Q,C,T+34V+3<X
M?`I\-S(@+2!S970R("T@;W!A<75E('!L86-E:&]L9&5R)W,@=&5S="`M('P*
M?#<R("T@<V5T,R`M(&]P87%U92!P;&%C96AO;&1E<B=S('1E<W0@+2!\"GY^
M"@HM+2TM+2TM+2TM+2TU+2TM+2TM+2TM+2TM"FEN<V5R=#H@;VMA>0IA(#T@
M,3$L(&(@/2!T:')E92P@9"`](&=O="!E>'!E8W1E9"!O=71C;VUE"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P.&%F9F5C=&5D
M<F]W<RYP:'!T````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W-S(@,3`U,34T,S0Q,S0@,#(V
M,C<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"TM5$535"TM"D1"7V1R:79E<CHZ869F96-T9612;W=S"BTM24Y)+2T*97)R
M;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I
M<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G
M.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI
M;F,G.PH*+RHJ"B`J($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J
M"B`J($1R;W!S('1H92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R
M<F]R(&UE<W-A9V4@86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`
M<&%R86T@;V)J96-T("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC
M86QL>2!P87-S960@=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J
M($!S964@4$5!4CHZ<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P
M92@D;RD@>PH@("`@9VQO8F%L("1D8F@["@H@("`@)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("!D<F]P7W1A8FQE*"1D
M8F@L("=P:'!T97-T)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*
M)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G
M<&4G*3L*"@HO+R!#;&5A;B!T86)L90HD9&)H+3YQ=65R>2@B1$5,151%($92
M3TT@<&AP=&5S="(I.PH*+R\@069F96-T960@<F]W<R!B>2!)3E-%4E0@<W1A
M=&5M96YT"B1D8F@M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AA+&(I
M(%9!3%5%4R@Q+"`G=&5S="<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@24Y4
M3R!P:'!T97-T("AA+&(I(%9!3%5%4R@R+"`G=&5S="<I(BD["G!R:6YT9B@B
M)60@869T97(@:6YS97)T7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H*2D["@HO
M+R!!9F9E8W1E9"!R;W=S(&)Y(%-%3$5#5"!S=&%T96UE;G0*)&1B:"T^<75E
M<GDH(E-%3$5#5"`J($923TT@<&AP=&5S="(I.PIP<FEN=&8H(B5D(&%F=&5R
M('-E;&5C=%QN(BP@)&1B:"T^869F96-T9612;W=S*"DI.PHD9&)H+3YQ=65R
M>2@B1$5,151%($923TT@<&AP=&5S="!72$5212!B(#T@)W1E<W0G(BD["G!R
M:6YT9B@B)60@869T97(@9&5L971E7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H
M*2D["@HO+R!!9F9E8W1E9"!R;W=S(&)Y($1%3$5412!S=&%T96UE;G0*)&1B
M:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@*&$L8BD@5D%,5453*#$L
M("=T97-T)RDB*3L*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@
M*&$L8BD@5D%,5453*#(L("=T97-T)RDB*3L*)&1B:"T^<75E<GDH(D1%3$54
M12!&4D]-('!H<'1E<W0B*3L*<')I;G1F*"(E9"!A9G1E<B!D96QE=&4@86QL
M7&XB+"`D9&)H+3YA9F9E8W1E9%)O=W,H*2D["@H*)&1B:"T^<V5T17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@
M)W!H<'1E<W0G*3L*"C\^"BTM15A014-4+2T*,2!A9G1E<B!I;G-E<G0*,"!A
M9G1E<B!S96QE8W0*,B!A9G1E<B!D96QE=&4*,B!A9G1E<B!D96QE=&4@86QL
M"@```````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O
M=&5S=',O9')I=F5R+S`Y;G5M<F]W<RYP:'!T````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,3`Q,B`Q,#4Q-30S-#$S-2`P,C4S,C$`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````+2U415-4+2T*1$)?9')I=F5R.CIN
M=6U2;W=S"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)
M1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O
M;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E
M7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+VYU;7)O
M=W,N:6YC)SL*/SX*+2U%6%!%0U0M+0HH=V%N="`Q*2!G;W0@,2!F<F]M(&9I
M<G-T"BAW86YT(#(I(&=O="`R(&9R;VT@,`HH=V%N="`S*2!G;W0@,R!F<F]M
M(#$**'=A;G0@-"D@9V]T(#0@9G)O;2`R"BAW86YT(#4I(&=O="`U(&9R;VT@
M,PHH=V%N="`V*2!G;W0@-B!F<F]M(#0**'=A;G0@-2D@9V]T(#4@9G)O;2`^
M(#`@*'!A<W-I;F<@<&%R86US('1O('%U97)Y*0HH=V%N="`T*2!G;W0@-"!F
M<F]M(#P@-"`H9&]I;F<@<')E<&%R92]E>&5C=71E*0HH=V%N="`R*2!G;W0@
M,B!F<F]M(#4@86YD(#8@;F]T(&1E;&5T960**'=A;G0@,"D@9V]T(#`@9G)O
M;2`\(#`*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S
M=',O1$(O=&5S=',O9')I=F5R+S$P97)R;W)M87`N<&AP=```````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S8S,R`Q,#4Q-30S-#$S-2`P,C4T-#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````+2U415-4+2T*1$)?9')I
M=F5R.CIE<G)O<B!M87!P:6YG"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@
M,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N
M8V4@)RXN+V5R<F]R<RYI;F,G.PH_/@HM+4584$5#5"TM"D1"7T524D]27TY/
M4U5#2%1!0DQ%(&9O<B!S96QE8W0Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O
M;64*1$)?15)23U)?3D]354-(5$%"3$4@9F]R(&1R;W`Z("!M871C:&5S(&5X
M<&5C=&5D(&]U=&-O;64*1$)?15)23U)?3D]47T9/54Y$(&9O<B!D<F]P(&EN
M9&5X.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T%,4D5!
M1%E?15A)4U13(&9O<B!C<F5A=&4@=&%B;&4Z("!M871C:&5S(&5X<&5C=&5D
M(&]U=&-O;64*1$)?15)23U)?04Q214%$65]%6$E35%,@9F]R(&-R96%T92!I
M;F1E>#H@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]#3TY3
M5%)!24Y4(&9O<B!P<FEM87)Y(&ME>2!I;G-E<G0@9'5P;&EC871E.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T-/3E-44D%)3E0@9F]R
M('!R:6UA<GD@:V5Y('5P9&%T92!D=7!L:6-A=&4Z("!M871C:&5S(&5X<&5C
M=&5D(&]U=&-O;64*1$)?15)23U)?0T].4U1204E.5"!F;W(@=6YI<75E(&ME
M>2!I;G-E<G0@9'5P;&EC871E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE
M"D1"7T524D]27T-/3E-44D%)3E0@9F]R('5N:7%U92!K97D@=7!D871E(&1U
M<&QI8V%T93H@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]#
M3TY35%)!24Y4(&9O<B!F;W)E:6=N(&ME>2!O;B!I;G-E<G0Z("!M871C:&5S
M(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?0T].4U1204E.5"!F;W(@9F]R
M96EG;B!K97D@;VX@9&5L971E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE
M"D1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$P@;VX@:6YS97)T.B`@;6%T
M8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27T-/3E-44D%)3E1?3D]4
M7TY53$P@;VX@=7!D871E.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"
M7T524D]27TY/4U5#2$9)14Q$(&IO:6YI;F<@3TX@8F]G=7,@8V]L=6UN.B`@
M;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TY/4U5#2$9)14Q$
M(&IO:6YI;F<@55-)3D<@8F]G=7,@8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E
M9"!O=71C;VUE"D1"7T524D]27T1)5EI%4D\Z("!M871C:&5S(&5X<&5C=&5D
M(&]U=&-O;64*1$)?15)23U)?24Y604Q)1%].54U"15(@<'5T=&EN9R!C:&%R
M<R!I;B!)3E0@8V]L=6UN.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"
M7T524D]27TE.5D%,241?3E5-0D52('!U='1I;F<@9FQO870@:6X@24Y4(&-O
M;'5M;CH@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E])3E9!
M3$E$7TY534)%4B!P=71T:6YG(&5X8V5S<VEV92!I;G0@:6X@24Y4(&-O;'5M
M;CH@(&UA=&-H97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E])3E9!3$E$
M7TY534)%4B!P=71T:6YG(&EN="!I;B!#2$%2(&-O;'5M;CH@(&UA=&-H97,@
M97AP96-T960@;W5T8V]M90I$0E]%4E)/4E].3U-50TA&245,1#H@(&UA=&-H
M97,@97AP96-T960@;W5T8V]M90I$0E]%4E)/4E]364Y405@Z("!M871C:&5S
M(&5X<&5C=&5D(&]U=&-O;64*1$)?15)23U)?5D%,545?0T]53E1?3TY?4D]7
M.B`@;6%T8VAE<R!E>'!E8W1E9"!O=71C;VUE"D1"7T524D]27TE.5D%,240@
M;VX@0TA!4B!C;VQU;6X@9&%T82!T;V\@;&]N9SH@(&UA=&-H97,@97AP96-T
M960@;W5T8V]M90I$0E]%4E)/4E])3E9!3$E$(&]N(%9!4D-(05(@8V]L=6UN
M(&1A=&$@=&]O(&QO;F<Z("!M871C:&5S(&5X<&5C=&5D(&]U=&-O;64*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"
M+W1E<W1S+V1R:79E<B\Q,71R86YS86-T:6]N<RYP:'!T````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#$T,34@,3`U,34T,S0Q,S4@,#(V,S$W`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"TM5$535"TM"D1"7V1R:79E<CHZ
M=')A;G-A8W1I;VX@=&5S=`HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P
M-#<*+2U32TE0248M+0H\/W!H<`IC:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[
M(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*:68@*"$D9&(M/F9E871U
M<F5S6R=T<F%N<V%C=&EO;G,G72D@>PH@("`@9&EE*"=S:VEP('1H:7,@9')I
M=F5R(&1O97,@;F]T('-U<'!O<G0@=')A;G-A8W1I;VYS)RD["GT*/SX*+2U&
M24Q%+2T*/#]P:'`*)&YE961I;FYO9&(@/2!T<G5E.PIR97%U:7)E7V]N8V4@
M)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+W1R86YS86-T:6]N
M<RYI;F,G.PH_/@HM+4584$5#5"TM"C$I(&%F=&5R(&%U=&]C;VUM:70Z(&)I
M;F<@;VYE+B`@;W!S/6]K"C(I(&)E9F]R92!C;VUM:70Z(&)I;F<@;VYE('1W
M;R!T:')E92X@(&]P<SUO:PHS*2!A9G1E<B!C;VUM:70Z(&)I;F<@;VYE('1W
M;R!T:')E92X@(&]P<SUO:PHT*2!B969O<F4@<F]L;&)A8VLZ(&)I;F<@;VYE
M('1W;R!T:')E92!F;W5R(&9I=F4N("!O<',];VL*-2D@869T97(@<F]L;&)A
M8VLZ(&)I;F<@;VYE('1W;R!T:')E92X@(&]P<SUO:PHV*2!B969O<F4@875T
M;V-O;6UI="MR;VQL8F%C:SH@8FEN9R!O;F4@='=O('1H<F5E('-I>"!S979E
M;BX@(&]P<SUO:PHW*2!A9G1E<B!A=71O8V]M;6ET*W)O;&QB86-K.B!B:6YG
M(&]N92!T=V\@=&AR964@<VEX('-E=F5N+B`@;W!S/6]K"C@I('1E<W1I;F<@
M=&AA="!S96QE8W0@9&]E<VXG="!D:7-T=7)B92!O<&-O=6YT.B!O:PH`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E
M<W1S+T1"+W1E<W1S+V1R:79E<B\Q,VQI;6ET+G!H<'0`````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(P-C(@,3`U,34T,S0Q,S4@,#(T-S(V`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"TM5$535"TM"D1"7V1R
M:79E<CHZ<F]W(&QI;6ET"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T
M-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@
M<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H
M<`IR97%U:7)E7V]N8V4@)RXO8V]N;F5C="YI;F,G.PIR97%U:7)E7V]N8V4@
M)RXO9')O<'1A8FQE+FEN8R<["G)E<75I<F5?;VYC92`G+BXO;&EM:70N:6YC
M)SL*/SX*+2U%6%!%0U0M+0H]/3T]/3T]($9R;VTZ(#`@?'P@3G5M8F5R(&]F
M(')O=W,@=&\@9F5T8V@Z(#$P(#T]/3T]/3T*,2XM(')E<W5L="`P"C(N+2!R
M97-U;'0@,0HS+BT@<F5S=6QT(#(*-"XM(')E<W5L="`S"C4N+2!R97-U;'0@
M-`HV+BT@<F5S=6QT(#4*-RXM(')E<W5L="`V"C@N+2!R97-U;'0@-PHY+BT@
M<F5S=6QT(#@*,3`N+2!R97-U;'0@.0H]/3T]/3T]($9R;VTZ(#$P('Q\($YU
M;6)E<B!O9B!R;W=S('1O(&9E=&-H.B`Q,"`]/3T]/3T]"C$Q+BT@<F5S=6QT
M(#$P"C$R+BT@<F5S=6QT(#$Q"C$S+BT@<F5S=6QT(#$R"C$T+BT@<F5S=6QT
M(#$S"C$U+BT@<F5S=6QT(#$T"C$V+BT@<F5S=6QT(#$U"C$W+BT@<F5S=6QT
M(#$V"C$X+BT@<F5S=6QT(#$W"C$Y+BT@<F5S=6QT(#$X"C(P+BT@<F5S=6QT
M(#$Y"CT]/3T]/3T@1G)O;3H@,C`@?'P@3G5M8F5R(&]F(')O=W,@=&\@9F5T
M8V@Z(#$P(#T]/3T]/3T*,C$N+2!R97-U;'0@,C`*,C(N+2!R97-U;'0@,C$*
M,C,N+2!R97-U;'0@,C(*,C0N+2!R97-U;'0@,C,*,C4N+2!R97-U;'0@,C0*
M,C8N+2!R97-U;'0@,C4*,C<N+2!R97-U;'0@,C8*,C@N+2!R97-U;'0@,C<*
M,CDN+2!R97-U;'0@,C@*,S`N+2!R97-U;'0@,CD*/3T]/3T]/2!&<F]M.B`S
M,"!\?"!.=6UB97(@;V8@<F]W<R!T;R!F971C:#H@,3`@/3T]/3T]/0HS,2XM
M(')E<W5L="`S,`HS,BXM(')E<W5L="`S,0HS,RXM(')E<W5L="`S,@H]/3T]
M/3T](%!A<W-I;F<@)'!A<F%M<R!\?"!&<F]M.B`Q,2!\?"!.=6UB97(@;V8@
M<F]W<R!T;R!F971C:#H@,R`]/3T]/3T]"C$R+BT@<F5S=6QT(#$Q"C$S+BT@
M<F5S=6QT(#$R"C$T+BT@<F5S=6QT(#$S"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$T
M9F5T8VAM;V1E7V]B:F5C="YP:'!T````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3(Q-R`Q,#4Q-30S
M-#$S-2`P,C<P-S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````+2U415-4+2T*1$)?9')I=F5R.CIF971C:&UO9&4@;V)J96-T
M"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_
M<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I*3L@<F5Q=6ER95]O;F-E("<N
M+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\/W!H<`IR97%U:7)E7V]N8V4@
M)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N8V4@)RXN+V9E=&-H;6]D95]O
M8FIE8W0N:6YC)SL*/SX*+2U%6%!%0U0M+0HM+2T@9F5T8V@@=VET:"!P87)A
M;2!$0E]&151#2$U/1$5?3T)*14-4("TM+0IS=&1C;&%S<R`M/B!A(&(@8R!D
M"G-T9&-L87-S("T^(&$@8B!C(&0*+2TM(&9E=&-H('=I=&@@9&5F875L="!F
M971C:&UO9&4@1$)?1D540TA-3T1%7T]"2D5#5"`M+2T*<W1D8VQA<W,@+3X@
M82!B(&,@9`IS=&1C;&%S<R`M/B!A(&(@8R!D"BTM+2!F971C:"!W:71H(&1E
M9F%U;'0@9F5T8VAM;V1E($1"7T9%5$-(34]$15]/0DI%0U0@86YD(&-L87-S
M($1"7W)O=R`M+2T*9&)?<F]W("T^(&$@8B!C(&0*9&)?<F]W("T^(&$@8B!C
M(&0*+2TM(&9E=&-H('=I=&@@9&5F875L="!F971C:&UO9&4@1$)?1D540TA-
M3T1%7T]"2D5#5"!W:71H(&YO(&-L87-S('1H96X@1$)?<F]W("TM+0IS=&1C
M;&%S<R`M/B!A(&(@8R!D"F1B7W)O=R`M/B!A(&(@8R!D"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I
M=F5R+S$U<75O=&4N<&AP=```````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S8P,2`Q
M,#4Q-30S-#$S-2`P,C0W-3``(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````+2U415-4+2T*1$)?9')I=F5R.CIQ=6]T90HM+4E.
M22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C
M:&1I<BAD:7)N86UE*%]?1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP
M:68N:6YC)SL@/SX*+2U&24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+V-O
M;FYE8W0N:6YC)SL*<F5Q=6ER95]O;F-E("<N+V1R;W!T86)L92YI;F,G.PH*
M"B\J*@H@*B!,;V-A;"!E<G)O<B!C86QL8F%C:R!H86YD;&5R+@H@*@H@*B!$
M<F]P<R!T:&4@<&AP=&5S="!T86)L92P@<')I;G1S(&]U="!A;B!E<G)O<B!M
M97-S86=E(&%N9"!K:6QL<R!T:&4*("H@<')O8V5S<RX*("H*("H@0'!A<F%M
M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@
M<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E
M(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I
M('L*("`@(&=L;V)A;"`D9&)H.PH*("`@("1D8F@M/G-E=$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@9')O<%]T86)L92@D9&)H+"`G
M<&5A<G%U;W1E)RD["@H@("`@9&EE*"1O+3YT;U-T<FEN9R@I*3L*?0H*+R\@
M1$)-4R!B;V]L96%N(&-O;'5M;B!T>7!E('-I;75L871I;VXN+BX*)&)O;VQE
M86Y?8V]L7W1Y<&4@/2!A<G)A>2@*("`@("=D8F%S92<@(#T^("=,;V=I8V%L
M)RP*("`@("=F8G-Q;"<@(#T^("="3T],14%.)RP*("`@("=I8F%S92<@(#T^
M("=334%,3$E.5"<L"B`@("`G:69X)R`@("`]/B`G4TU!3$Q)3E0G+`H@("`@
M)VUS<6PG("`@/3X@)TE.5$5'15(G+`H@("`@)VUS<W%L)R`@/3X@)T))5"<L
M"B`@("`G;7ES<6PG("`]/B`G5$E.64E.5"@Q*2<L"B`@("`G;7ES<6QI)R`]
M/B`G5$E.64E.5"@Q*2<L"B`@("`G;V-I."<@("`]/B`G3E5-0D52*#$I)RP*
M("`@("=O9&)C)R`@(#T^("=334%,3$E.5"<L"B`@("`G<&=S<6PG("`]/B`G
M0D]/3$5!3B<L"B`@("`G<W%L:71E)R`]/B`G24Y414=%4B<L"B`@("`G<WEB
M87-E)R`]/B`G5$E.64E.5"<L"BD["@HO+R!A9&IU<W0@=&AI;F=S(&9O<B!S
M<&5C:69I8R!$0DU3)W,*"FEF("@D9&)H+3YP:'!T>7!E(#T]("=O9&)C)RD@
M>PH@("`@:68@*"1D8F@M/F1B<WEN=&%X(#T]("=O9&)C)RD@>PH@("`@("`@
M("1T>7!E(#T@)&1B:"T^<&AP='EP93L*("`@('T@96QS92!["B`@("`@("`@
M)'1Y<&4@/2`D9&)H+3YD8G-Y;G1A>#L*("`@('T*?2!E;'-E('L*("`@("1T
M>7!E(#T@)&1B:"T^<&AP='EP93L*?0H*<W=I=&-H("@D='EP92D@>PH@("`@
M8V%S92`G86-C97-S)SH*("`@("`@("`D9&5C:6UA;"`]("=324Y'3$4G.PH@
M("`@("`@("1N=6QL(#T@)R<["B`@("`@("`@)&-H<B`@/2`G5D%20TA!4B@X
M*2<["B`@("`@("`@)&ED96YT:69I97(@/2`G<5QU="`B9&YT)SL*("`@("`@
M("!B<F5A:SL*("`@(&-A<V4@)V1B,B<Z"B`@("!C87-E("=I8F%S92<Z"B`@
M("`@("`@)&1E8VEM86P@/2`G1$5#24U!3"@S+#$I)SL*("`@("`@("`D;G5L
M;"`]("<G.PH@("`@("`@("1C:'(@(#T@)U9!4D-(05(H."DG.PH@("`@("`@
M("1I9&5N=&EF:65R(#T@)W%<=71=(")D;EMT)SL*("`@("`@("!B<F5A:SL*
M("`@(&-A<V4@)VEF>"<Z"B`@("`@("`@+R\@9&]I;F<@=&AI<R!F;W(@:69X
M('1O(&ME97`@8V5R=&%I;B!V97)S:6]N<R!H87!P>0H@("`@("`@("1D96-I
M;6%L(#T@)T1%0TE-04PH,RPQ*2<["B`@("`@("`@)&YU;&P@/2`G)SL*("`@
M("`@("`D8VAR("`]("=#2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]
M("<G.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@
M)&1E8VEM86P@/2`G4D5!3"<["B`@("`@("`@)&YU;&P@/2`G)SL*("`@("`@
M("`D8VAR("`]("=#2$%2*#@I)SL*("`@("`@("`D:61E;G1I9FEE<B`]("<G
M.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G9F)S<6PG.@H@("`@8V%S92`G
M;V-I."<Z"B`@("`@("`@)&1E8VEM86P@/2`G1$5#24U!3"@S+#$I)SL*("`@
M("`@("`D;G5L;"`]("<G.PH@("`@("`@("1C:'(@(#T@)U9!4D-(05(H."DG
M.PH@("`@("`@("1I9&5N=&EF:65R(#T@)W%<=71=(&1N6W0G.PH@("`@("`@
M(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D9&5C:6UA;"`]("=$14-)
M34%,*#,L,2DG.PH@("`@("`@("1N=6QL(#T@)TY53$PG.PH@("`@("`@("1C
M:'(@(#T@)U9!4D-(05(H."DG.PH@("`@("`@("1I9&5N=&EF:65R(#T@)W%<
M=71=(")D;EMT)SL*?0H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD["F1R;W!?=&%B;&4H)&1B:"P@)W!E87)Q=6]T92<I.PH*
M"FEF("@D:61E;G1I9FEE<BD@>PH@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E
M*2!["B`@("`@("`@8V%S92`G<WEB87-E)SH*("`@("`@("`@("`@)')E<R`]
M("1D8F@M/G%U97)Y*"=S970@<75O=&5D7VED96YT:69I97(@;VXG*3L*("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I("D@>PH@("`@("`@("`@
M("`@("`@<&4H)')E<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@9&5F875L=#H*("`@('T*("`@("1C<F5A=&4@/2`D9&)H
M+3YQ=65R>2@B"B`@("`@("`@0U)%051%(%1!0DQ%('!E87)Q=6]T92`H"B`@
M("`@("`@("!N("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@<R`D8VAR("1N
M=6QL+`H@("`@("`@("`@(B`N("1D8F@M/G%U;W1E261E;G1I9FEE<B@D:61E
M;G1I9FEE<BD@+B`B("1D96-I;6%L("1N=6QL+`H@("`@("`@("`@8B![)&)O
M;VQE86Y?8V]L7W1Y<&5;)&1B:"T^<&AP='EP95U]("1N=6QL"B`@("`@("`@
M*0H@("`@(BD["@H@("`@:68@*$1".CII<T5R<F]R*"1C<F5A=&4I("D@>PH@
M("`@("`@('!E*"1C<F5A=&4I.PH@("`@?0H*("`@("1I;F9O(#T@)&1B:"T^
M=&%B;&5);F9O*"=P96%R<75O=&4G*3L*("`@(&EF("A$0CHZ:7-%<G)O<B@D
M:6YF;RD@*2!["B`@("`@("`@:68@*"1I;F9O+3YC;V1E(#T]($1"7T524D]2
M7TY/5%]#05!!0DQ%*2!["B`@("`@("`@("`@('!R:6YT(")';W0@;W5T8V]M
M92!E>'!E8W1E9"!F<F]M(&1E;&EM:71E9"!I9&5N=&EF:65R+EQN(CL*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`B=&%B;&5);F9O*"D@
M9F%I;&5D+EQN(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@(&EF
M("@D:61E;G1I9FEE<B`]/2`D:6YF;ULR75LG;F%M92==*2!["B`@("`@("`@
M("`@('!R:6YT(")';W0@;W5T8V]M92!E>'!E8W1E9"!F<F]M(&1E;&EM:71E
M9"!I9&5N=&EF:65R+EQN(CL*("`@("`@("`@("`@+R\@<')I;G0@(D-/3%5-
M3B!.04U%($E3.B![)&EN9F];,EU;)VYA;64G77U<;B(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<')I;G0@(D5X<&5C=&5D(&-O;'5M;B!N86UE
M.B`G)&ED96YT:69I97(G("XN+B`B.PH@("`@("`@("`@("!P<FEN="`B06-T
M=6%L(&-O;'5M;B!N86UE.B`G>R1I;F9O6S)=6R=N86UE)UU])UQN(CL*("`@
M("`@("!]"B`@("!]"@I](&5L<V4@>PH@("`@)&1B:"T^<75E<GDH(@H@("`@
M("`@($-214%412!404),12!P96%R<75O=&4@*`H@("`@("`@("`@;B`D9&5C
M:6UA;"`D;G5L;"P*("`@("`@("`@(',@)&-H<B`D;G5L;"P*("`@("`@("`@
M('!L86EN:61E;G1I9FEE<B`D9&5C:6UA;"`D;G5L;"P*("`@("`@("`@(&(@
M>R1B;V]L96%N7V-O;%]T>7!E6R1D8F@M/G!H<'1Y<&5=?2`D;G5L;`H@("`@
M("`@("D*("`@("(I.PH@("`@<')I;G0@(D=O="!O=71C;VUE(&5X<&5C=&5D
M(&9R;VT@9&5L:6UI=&5D(&ED96YT:69I97(N7&XB.PI]"@H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD
M<W1R:6YG<R`](&%R<F%Y*`H@("`@(B<B+`H@("`@(EPB(BP*("`@(")<7"(L
M"B`@("`B)2(L"B`@("`B7R(L"B`@("`B)R<B+`H@("`@(EPB7"(B+`H@("`@
M(EQ<7%PB+`H@("`@(EQ<)UQ<)R(L"B`@("`B7%Q<(EQ<7"(B"BD["@HD;G5M
M<R`](&%R<F%Y*`H@("`@,3(N,RP*("`@(#$U+`HI.PH*)&)O;VQS(#T@87)R
M87DH"B`@("!44E5%+`H@("`@1D%,4T4L"BD["@H*96-H;R`B4W1R:6YG(&5S
M8V%P92!T97-T.B`B.PIF;W)E86-H("@D<W1R:6YG<R!A<R`D<RD@>PH@("`@
M)'%U;W1E9"`]("1D8F@M/G%U;W1E4VUA<G0H)',I.PH@("`@)&1B:"T^<75E
M<GDH(DE.4T525"!)3E1/('!E87)Q=6]T92`H<RD@5D%,5453("@D<75O=&5D
M*2(I.PI]"B1D:69F(#T@87)R87E?9&EF9B@D<W1R:6YG<RP@)')E<R`]("1D
M8F@M/F=E=$-O;"@B4T5,14-4(',@1E)/32!P96%R<75O=&4B*2D["FEF("AC
M;W5N="@D9&EF9BD@/B`P*2!["B`@("!E8VAO(")&04E,(CL*("`@('!R:6YT
M7W(H)'-T<FEN9W,I.PH@("`@<')I;G1?<B@D<F5S*3L*?2!E;'-E('L*("`@
M(&5C:&\@(D]+(CL*?0H*)&1B:"T^<75E<GDH(D1%3$5412!&4D]-('!E87)Q
M=6]T92(I.PH*"F5C:&\@(EQN3G5M8F5R(&5S8V%P92!T97-T.B`B.PIF;W)E
M86-H("@D;G5M<R!A<R`D;BD@>PH@("`@)'%U;W1E9"`]("1D8F@M/G%U;W1E
M4VUA<G0H)&XI.PH@("`@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!E87)Q
M=6]T92`H;BD@5D%,5453("@D<75O=&5D*2(I.PI]"@HD9&EF9B`](&%R<F%Y
M*"D["B1R97,@/28@)&1B:"T^9V5T0V]L*"=314Q%0U0@;B!&4D]-('!E87)Q
M=6]T92!/4D1%4B!"62!N)RD["F9O<F5A8V@@*"1N=6US(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@:68@*"1V86P@(3T@)')E<ULD:V5Y72D@>PH@("`@("`@
M("1D:69F6UT@/2`B)'9A;"`A/2![)')E<ULD:V5Y77TB.PH@("`@?0I]"@II
M9B`H8V]U;G0H)&1I9F8I(#X@,"D@>PH@("`@96-H;R`B1D%)3%QN(CL*("`@
M('!R:6YT7W(H)&1I9F8I.PI](&5L<V4@>PH@("`@96-H;R`G3TLG.PI]"@HD
M9&)H+3YQ=65R>2@G1$5,151%($923TT@<&5A<G%U;W1E)RD["@H*96-H;R`B
M7&Y";V]L96%N(&5S8V%P92!T97-T.B`B.PHD:2`](#$["F9O<F5A8V@@*"1B
M;V]L<R!A<R`D8BD@>PH@("`@)'%U;W1E9"`]("1D8F@M/G%U;W1E4VUA<G0H
M)&(I.PH@("`@)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!E87)Q=6]T92`H
M;BP@8BD@5D%,5453("@D:2P@)'%U;W1E9"DB*3L*("`@("1I*RL["GT*"B1D
M:69F(#T@87)R87DH*3L*)')E<R`])B`D9&)H+3YG971#;VPH)U-%3$5#5"!B
M+"!N($923TT@<&5A<G%U;W1E($]21$52($)9(&XG*3L*9F]R96%C:"`H)&)O
M;VQS(&%S("1K97D@/3X@)'9A;"D@>PH@("`@:68@*"1V86P@/3T]('1R=64I
M('L*("`@("`@("!I9B`H)')E<ULD:V5Y72`]/2`Q('Q\("1R97-;)&ME>5T@
M/3T@=')U92!\?`H@("`@("`@("`@("!S=6)S='(H<W1R=&]L;W=E<B@D<F5S
M6R1K97E=*2P@,"P@,2D@/3T@)W0G*0H@("`@("`@('L*("`@("`@("`@("`@
M+R\@9V]O9`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1D:69F6UT@
M/2`B:6XZ=')U92`A/2!O=70Z>R1R97-;)&ME>5U](CL*("`@("`@("!]"B`@
M("!](&5L<V4@>PH@("`@("`@(&EF("@D<F5S6R1K97E=(#T](#`@?'P@)')E
M<ULD:V5Y72`]/2!F86QS92!\?`H@("`@("`@("`@("!S=6)S='(H<W1R=&]L
M;W=E<B@D<F5S6R1K97E=*2P@,"P@,2D@/3T@)V8G*0H@("`@("`@('L*("`@
M("`@("`@("`@+R\@9V]O9`H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1D:69F6UT@/2`B:6XZ9F%L<V4@(3T@;W5T.GLD<F5S6R1K97E=?2(["B`@
M("`@("`@?0H@("`@?0I]"@II9B`H8V]U;G0H)&1I9F8I(#X@,"D@>PH@("`@
M96-H;R`B1D%)3%QN(CL*("`@('!R:6YT7W(H)&1I9F8I.PI](&5L<V4@>PH@
M("`@96-H;R`B3TM<;B(["GT*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G<&5A<G%U;W1E
M)RD["@H_/@HM+4584$5#5"TM"D=O="!O=71C;VUE(&5X<&5C=&5D(&9R;VT@
M9&5L:6UI=&5D(&ED96YT:69I97(N"E-T<FEN9R!E<V-A<&4@=&5S=#H@3TL*
M3G5M8F5R(&5S8V%P92!T97-T.B!/2PI";V]L96%N(&5S8V%P92!T97-T.B!/
M2PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O
M,39T86)L96EN9F\N<&AP=```````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,3`V-C(S(#$P-3$U
M-#,T,3,U(#`R-34V-@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````M+51%4U0M+0I$0E]D<FEV97(Z.G1A8FQE26YF;PHM+4E.
M22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<`H*
M+RHJ"B`J($-A;&QS('1A8FQE26YF;R@I(&EN('9A<FEO=7,@=V%Y<R!A;F0@
M8VAE8VMS('1O('-E92!T:&%T('1H92!O=71P=70*("H@;6%T8VAE<R!W:&%T
M)W,@97AP96-T960N"B`J"B`J(%1H97-E('1E<W1S(&%C8V]U;G0@9F]R(&5A
M8V@@1$)-4R!U<VEN9R!D:69F97)E;G0@8V]L=6UN('1Y<&5S(&%N9`H@*B!R
M97!O<G1I;F<@8F%C:R!D:69F97)E;G0@:6YF;W)M871I;VXN("!4:&5S92!D
M:69F97)E;F-E<R!A<F4@86-C;W5N=&5D"B`J(&9O<B!I;B!T:&4@/'9A<CXD
M<75I<FMS/"]V87(^(&%R<F%Y+"!W:&EC:"!H87,@=&AE(&9O;&QO=VEN9R!F
M;W)M870Z"B`J"B`J(#QP<F4^"B`J("=D<FEV97(G(#T^(&%R<F%Y*`H@*B`@
M("`@)V-L;V(G(#T^($1"35,G<R!C;VQU;6X@='EP92!F;W(@8W)E871I;F<@
M0TQ/0B!F:65L9',*("H@("`@("=D871E)R`]/B!$0DU3)W,@8V]L=6UN('1Y
M<&4@9F]R(&-R96%T:6YG($1!5$4@9FEE;&1S"B`J("`@("`G9&%T96QI=&5R
M86PG(#T^(%1H92!344P@:V5Y=V]R9"!N96-E<W-A<GD@9F]R(&1E9FEN:6YG
M(&1A=&5S"B`J("`@("`G9FEN9'-?=&%B;&4G(#T^($-A;B!T:&ES($1"35,@
M9&5T97)M:6YE('1A8FQE(&YA;65S(&9R;VT@<75E<FEE<S\*("H@("`@("=S
M:7IE7V9R;VU?=&%B;&4G(#T^($1O97,@=&AI<R!$0DU3(&MN;W<@=&AE(&-O
M;'5M;B!S:7IE('9I82!T86)L92!N86UE/PH@*B`@("`@)VAA;F1L97-?<F5S
M=6QT<R<@/3X@0V%N('1H92!$0DU3(&=E="!I;F9O(&9R;VT@<75E<GD@<F5S
M=6QT<S\*("H@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`J("`@("`@("`@
M17AT<F$@8V]M;6%N9',@=&\@8F4@<&%S<V5D('1O(%!(4"=S(&5V86PH*2!F
M=6YC=&EO;@H@*B`@("`@*0H@*B`@("`@,"`]/B!A<G)A>2@*("H@("`@("`@
M("`O+R`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S
M=%]F:RYA"B`J("`@("`@("`@+R\@("A)3E1%1T52($Y/5"!.54Q,*2`H54Y)
M455%($M%62!W:71H(&0I"B`J("`@("`@("`@)W1Y<&4G(#T^($-O;'5M;B!T
M>7!E(')E<&]R=&5D(&)Y('1H92!$0DU3"B`J("`@("`@("`@)VQE;B<@/3X@
M0V]L=6UN('-I>F4@<F5P;W)T960@8GD@=&AE($1"35,*("H@("`@("`@("`G
M9FQA9W,G(#T^($9L86=S(')E<&]R=&5D(&)Y('1H92!$0DU3"B`J("`@("`I
M"B`J("`@("`Q(#T^(&%R<F%Y*"D@($EN9F\@97AP96-T960@=&\@8F4@<F5P
M;W)T960@9F]R('!H<'1E<W1?9FLN9FL*("H@("`@("`@("`@("`@("`@("`@
M*$E.5$5'15(@3D]4($Y53$PI("A04DE-05)9($M%62D*("H@("`@(#(@/3X@
M87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP
M=&5S=%]F:RYC"B`J("`@("`@("`@("`@("`@("`@("A#3$]"+T-(05(O5D%2
M0TA!4B!.54Q,*0H@*B`@("`@,R`]/B!A<G)A>2@I("!);F9O(&5X<&5C=&5D
M('1O(&)E(')E<&]R=&5D(&9O<B!P:'!T97-T7V9K+F0*("H@("`@("`@("`@
M("`@("`@("`@*$1!5$4@3D]4($Y53$PI("A53DE1544@2T59('=I=&@@82D*
M("H@("`@(#0@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O
M<G1E9"!F;W(@<&AP=&5S=%]F:RYE"B`J("`@("`@("`@("`@("`@("`@("A#
M2$%2*#(I($1%1D%53%0@)R!E)R!.3U0@3E5,3"D*("H@("`@(#4@/3X@87)R
M87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R97!O<G1E9"!F;W(@<&AP=&5S
M=%]F:RYF"B`J("`@("`@("`@("`@("`@("`@("A$14-)34%,*#(L,2D@3E5,
M3"D*("H@("`@(#D@/3X@87)R87DH*2`@26YF;R!E>'!E8W1E9"!T;R!B92!R
M97!O<G1E9"!F;W(@<&AP=&5S="YD"B`J("`@("`@("`@("`@("`@("`@("A6
M05)#2$%2*#(P*2!.54Q,*0H@*B`I"B`J(#PO<')E/@H@*@H@*B!`8V%T96=O
M<GD@1&%T86)A<V4*("H@0'!A8VMA9V4@($1""B`J($!V97)S:6]N("`D260Z
M(#$V=&%B;&5I;F9O+G!H<'0L=B`Q+C,R(#(P,#4O,#(O,30@,3<Z,#0Z,3<@
M9&%N:65L8R!%>'`@)`H@*B!`875T:&]R("`@1&%N:65L($-O;G9I<W-O<B`\
M9&%N:65L8T!A;F%L>7-I<V%N9'-O;'5T:6]N<RYC;VT^"B`J($!S964@("`@
M("!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`J+PH*97)R;W)?<F5P;W)T:6YG
M*$5?04Q,*3L*8VAD:7(H9&ER;F%M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N
M8V4@)RXO<VMI<&EF+FEN8R<["B1T86)L94EN9F\@/2`D9&(M/G1A8FQE26YF
M;R@G86IK9'-L9F%J;VEJ:V%D:64G*3L*:68@*$1".CII<T5R<F]R*"1T86)L
M94EN9F\I("8F("1T86)L94EN9F\M/F-O9&4@/3T@1$)?15)23U)?3D]47T-!
M4$%"3$4I('L*("`@(&1I92@B<VMI<"`D=&%B;&5);F9O+3YM97-S86=E(BD[
M"GT*"C\^"BTM1DE,12TM"CP_<&AP"@HO+R`@)$ED.B`Q-G1A8FQE:6YF;RYP
M:'!T+'8@,2XS,B`R,#`U+S`R+S$T(#$W.C`T.C$W(&1A;FEE;&,@17AP("0*
M"B\J*@H@*B!#;VYN96-T('1O('1H92!D871A8F%S92!A;F0@;6%K92!T:&4@
M<&AP=&5S="!T86)L92X*("HO"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN
M8R<["@HO*BH*("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*
M("H@26X@9V5N97)A;"P@:70@<')I;G1S(&]U="!A;B!E<G)O<B!M97-S86=E
M(&%N9"!K:6QL<R!T:&4@<')O8V5S<RX*("H@0G5T('-O;64@97)R;W)S(&%R
M92!E>'!E8W1E9"!A;F0@86QL;W=E9"!T;R!E>&ES="X*("H*("H@0'!A<F%M
M(&]B:F5C="`@)&\@(%!%05(@97)R;W(@;V)J96-T(&%U=&]M871I8V%L;'D@
M<&%S<V5D('1O('1H:7,@;65T:&]D"B`J($!R971U<FX@=F]I9`H@*B!`<V5E
M(%!%05(Z.G-E=$5R<F]R2&%N9&QI;F<H*0H@*B\*9G5N8W1I;VX@<&4H)&\I
M>PH@("`@9VQO8F%L("1D8F@L("1Q=6ER:W,["@H@("`@:68@*"1O+3YG971-
M97-S86=E*"D@/3T@(D1"($5R<F]R.B!C86XG="!D:7-T:6YG=6ES:"!D=7!L
M:6-A=&4@9FEE;&0@;F%M97,B*2!["B`@("`@("`@<')I;G0@(DY/5$E#13H@
M)&1B:"T^<&AP='EP92!C86XG="!D:7-T:6YG=6ES:"!D=7!L:6-A=&4@9FEE
M;&0@;F%M97,B.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!I9B`H)&\M
M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].3U1?0T%004),12`F)@H@("`@("`@
M("$D<75I<FMS6R1D8F@M/G!H<'1Y<&4@+B`G.B<@+B`D9&)H+3YD8G-Y;G1A
M>%U;)VAA;F1L97-?<F5S=6QT<R==*0H@("`@>PH@("`@("`@(')E='5R;CL*
M("`@('T*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*("`@
M(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W1?9FLG*3L*"B`@("!D:64H)&\M
M/G1O4W1R:6YG*"DI.PI]"@HO*BH*("H@3&]O<"!T:')O=6=H(&%N(&%R<F%Y
M(')E='5R;F5D(&9R;VT@=&%B;&5);F9O*"DL(&-O;7!A<F4@=&AE(&%C='5A
M;`H@*B!C;VYT96YT<R!T;R!T:&4@97AP96-T960@8V]N=&5N=',N("!)9B!T
M:&4@86-T=6%L(')E<W5L=',@;6%T8V@@=&AE"B`J(&5X<&5C=&%T:6]N<RP@
M<V%Y('-O+B`@268@;F]T+"!S87D@<V\@86YD('-H;W<@=&AE(&EN9F]R;6%T
M:6]N+@H@*@H@*B!`<&%R86T@87)R87D@("`D87)R87D@("`@('1H92!A<G)A
M>2!T;R!B92!E>&%M:6YE9`H@*B!`<&%R86T@<W1R:6YG("`D97AP96-T960@
M('1H92!E>'!E8W1E9"!C;VYT96YT<R!O9B!T:&4@87)R87D*("H@0'!A<F%M
M('-T<FEN9R`@)&9I96QD("`@("!F:65L9"!I;F1E>"!N=6UB97(@;V8@)'%U
M<FEK<R!A;F0@=&%B;&4*("H@0'!A<F%M(&)O;VQE86X@)'%U97)Y("`@("!T
M<G5E(&EF(&%R<F%Y(&ES(&9R;VT@82!Q=65R>2!O<B!F86QS92!I9B!A<G)A
M>0H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES('1A8FQE26YF;R@I
M"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@97AA;6EN94%R<F%Y1&%T
M82@D87)R87DL("1E>'!E8W1E9"P@)&9I96QD(#T@9F%L<V4L("1Q=65R>2`]
M('1R=64I('L*("`@(&=L;V)A;"`D9&)H+"`D<75I<FMS.PH*("`@("1Q=6ER
M:U]K97D@/2`D9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@[
M"@H@("`@:68@*$1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG971#
M;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@("`@("!P<FEN
M="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["B`@("`@("`@<F5T=7)N
M.PH@("`@?0H*("`@(&EF("@A:7-?87)R87DH)&%R<F%Y*2D@>PH@("`@("`@
M('!R:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O<&5R(')E<W5L
M='-<;B(["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&EF("AI<U]I;G0H
M)&9I96QD*2D@>PH@("`@("`@("1A<G)A>2`]("1A<G)A>5LD9FEE;&1=.PH@
M("`@?0H*("`@("1A8W1U86P@/2`G)SL*("`@(&9O<F5A8V@@*"1A<G)A>2!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@(&EF("@D9FEE;&0@(3T](&9A
M;'-E("8F"B`@("`@("`@("`@(&ES<V5T*"1Q=6ER:W-;)'%U:7)K7VME>5U;
M)&9I96QD75LD:V5Y72DI"B`@("`@("`@>PH@("`@("`@("`@("!I9B`H)&ME
M>2`]/2`G9FQA9W,G("8F("1V86QU92`]/2`G)R`F)B`D<75E<GD@)B8*("`@
M("`@("`@("`@("`@("$D<75I<FMS6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L
M92==*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D86-T=6%L("X]
M("(D:V5Y("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E7&XB.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@:68@*"1Q=6ER:W-;)'%U
M:7)K7VME>5U;)&9I96QD75LD:V5Y72`]/2`D=F%L=64I('L*("`@("`@("`@
M("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!M871C:&5D(&5X<&5C
M=&5D('9A;'5E7&XB.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T](#`*("`@("`@("`@("`@("`@
M("`@("`@("`@)B8@(21Q=6ER:W-;)'%U:7)K7VME>5U;)W-I>F5?9G)O;5]T
M86)L92==*0H@("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&%C='5A;"`N/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E
M9"!V86QU95QN(CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!W87,@
M)R1V86QU92<@8G5T('=E(&5X<&5C=&5D("(["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A8W1U86P@+CT@(B=[)'%U:7)K<ULD<75I<FM?:V5Y75LD9FEE
M;&1=6R1K97E=?2=<;B(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@:68@*"1K97D@/3T@)W1A8FQE)RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1F:65L9"`\/2`U*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"1V86QU92`]/2`G<&AP=&5S=%]F:R<I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%C='5A;"`N/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V
M86QU95QN(CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E(#T]("<G("8F("1Q=65R>2`F
M)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@(21Q=6ER:W-;)'%U:7)K
M7VME>5U;)V9I;F1S7W1A8FQE)UTI"B`@("`@("`@("`@("`@("`@("`@("`@
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K
M97D@+BXN(&UA=&-H960@97AP96-T960@=F%L=65<;B(["B`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D86-T=6%L("X]("(D:V5Y("XN+B!W87,@)R1V86QU92<@8G5T('=E
M(&5X<&5C=&5D("=P:'!T97-T7V9K)UQN(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1V86QU92`]/2`G
M<&AP=&5S="<I('L*("`@("`@("`@("`@("`@("`@("`@("`@)&%C='5A;"`N
M/2`B)&ME>2`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU95QN(CL*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'9A;'5E(#T]("<G("8F("1Q=65R>2`F)@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(21Q=6ER:W-;)'%U:7)K7VME>5U;)V9I;F1S7W1A
M8FQE)UTI"B`@("`@("`@("`@("`@("`@("`@("`@('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=65<;B(["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D86-T=6%L("X]
M("(D:V5Y("XN+B!W87,@)R1V86QU92<@8G5T('=E(&5X<&5C=&5D("=P:'!T
M97-T7V9K)UQN(CL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1A8W1U86P@+CT@(B1K97D@/3X@
M)'9A;'5E7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M:68@*"1A8W1U86P@/3T@)&5X<&5C=&5D*2!["B`@("`@("`@<')I;G0@(FUA
M=&-H960@97AP96-T960@<F5S=6QT7&XB.PH@("`@?2!E;'-E('L*("`@("`@
M("!P<FEN="`B1$E$3B=4(&UA=&-H(&5X<&5C=&5D('9A;'5E<RXN+EQN(CL*
M("`@("`@("!P<FEN="`B?GY^?GY^?GY<;D5X<&5C=&5D.EQN)&5X<&5C=&5D
M7&XB.PH@("`@("`@('!R:6YT(")^?GY^7&Y!8W1U86PZ7&XD86-T=6%L7&Y^
M?GY^?GY^?EQN7&XB.PH@("`@?0I]"@HO*BH*("H@3&]O<"!T:')O=6=H(&%N
M(&%R<F%Y(&]F('1A8FQE(&EN9F\@9&%T82!A;F0@<F5T=7)N('1H92!R97-U
M;'1S+@H@*@H@*B!`<&%R86T@87)R87D@("1A<G)A>2`@=&AE(&%R<F%Y('1O
M(&)E(&5X86UI;F5D"B`J($!R971U<FX@<W1R:6YG"B`J+PIF=6YC=&EO;B!R
M971U<FY!<G)A>41A=&$H)&%R<F%Y*2!["B`@("!G;&]B86P@)&1B:"P@)'%U
M:7)K<SL*"B`@("`D<75I<FM?:V5Y(#T@)&1B:"T^<&AP='EP92`N("<Z)R`N
M("1D8F@M/F1B<WEN=&%X.PH*("`@(&EF("@A)'%U:7)K<ULD<75I<FM?:V5Y
M75LG:&%N9&QE<U]R97-U;'1S)UTI('L*("`@("`@("!R971U<FX@(EQN(CL*
M("`@('T*"B`@("`D;W5T(#T@)R<["B`@("!F;W)E86-H("@D87)R87D@87,@
M)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`D;W5T("X]("(D:V5Y(#T^("1V
M86QU95QN(CL*("`@('T*("`@(')E='5R;B`D;W5T.PI]"@H*)&1B:"T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"@HD
M<75I<FMS(#T@87)R87DH"B`@("`G9F)S<6PZ9F)S<6PG(#T^(&%R<F%Y*`H@
M("`@("`@("=C;&]B)R`]/B`G0TA!4B@R.2DG+`H@("`@("`@("=D871E)R`]
M/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G($1!5$4@)RP*
M("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE
M7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L
M=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@
M("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'15(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N
M;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@
M("`@("`@("`G='EP92<@/3X@)T-(05)!0U1%4B<L"B`@("`@("`@("`@("=L
M96XG(#T^(#(Y+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@
M("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=$051%)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!4D%#5$52)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G1$5#24U!3"<L"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T-(05)!0U1%4B<L"B`@
M("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=I8F%S93II8F%S92<@/3X@
M87)R87DH"B`@("`@("`@)V-L;V(G(#T^("=605)#2$%2*#4P*2<L"B`@("`@
M("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^
M("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?
M<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y
M*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G=6YI<75E7VME>2!N;W1?;G5L;"<L
M"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)TE.5$5'15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=P<FEM87)Y7VME>2!N;W1?;G5L;"<L
M"B`@("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`U,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#,@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%412<L"B`@
M("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)W5N:7%U95]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-"`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#2$%2)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T
M7VYU;&P@9&5F875L="<L"B`@("`@("`@*2P*("`@("`@("`U(#T^(&%R<F%Y
M*`H@("`@("`@("`@("`G='EP92<@/3X@)TY5345224,H.2PQ*2<L"B`@("`@
M("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*
M"B`@("`G:6)A<V4Z9FER96)I<F0G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B
M)R`]/B`G5D%20TA!4B@U,"DG+`H@("`@("`@("=D871E)R`]/B`G1$%412<L
M"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?
M=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE7V9R;VU?=&%B;&4G(#T^
M(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L=',G(#T^('1R=64L"B`@
M("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@("`@("`I+`H@("`@("`@
M(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L
M"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)W5N:7%U95]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G<')I;6%R>5]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-3`L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)T1!5$4G+`H@("`@("`@("`@("`G;&5N)R`]/B`T
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y(&YO=%]N=6QL
M)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL(&1E9F%U;'0G+`H@("`@
M("`@("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=.54U%4DE#*#DL,2DG+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@
M.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)VEF>#II9G@G(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G0TA!4B@R.2DG+`H@("`@("`@("=D
M871E)R`]/B`G0TA!4B@Q,"DG+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@
M)R<L"B`@("`@("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G
M<VEZ95]F<F]M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R
M97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH
M"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U-13$E.5"<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#$@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G4U%,
M24Y4)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=344Q#2$%2)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,CDL"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G
M='EP92<@/3X@)U-13$-(05(G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL
M"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=3
M44Q#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@
M)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@-2`]
M/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=344Q$14-)34%,)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@-3$S+`H@("`@("`@("`@("`G9FQA9W,G
M(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=344Q#2$%2)RP*("`@("`@("`@("`@)VQE;B<@
M/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*
M("`@("DL"@H@("`@)VUS<6PZ;7-Q;"<@/3X@87)R87DH"B`@("`@("`@)V-L
M;V(G(#T^("=415A4*#(U-2DG+`H@("`@("`@("=D871E)R`]/B`G0TA!4B@Q
M,"DG+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@)V9I
M;F1S7W1A8FQE)R`]/B!T<G5E+`H@("`@("`@("=S:7IE7V9R;VU?=&%B;&4G
M(#T^('1R=64L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*
M("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@
M("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG
M(#T^(#0L"B`@("`@("`@("`@("\O(&9O<B!S;VUE(')E87-O;BP@=&AE('5N
M:7%U92!P<F]P97)T>2!A;'=A>7,@8V]N=&%I;G,@,`H@("`@("`@("`@("`O
M+R`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y(&YO=%]N=6QL)RP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=T97AT)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,C4U+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I
M+`H@("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M8VAA<B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@
M87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@
M("`@("=L96XG(#T^(#@L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@
M("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)V-H87(G+`H@("`@("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G
M;7-S<6PZ;7-S<6PG(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$58
M5"<L"B`@("`@("`@)V1A=&4G(#T^("=334%,3$1!5$5424U%)RP*("`@("`@
M("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@
M/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L
M"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G
M8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("`@("`G:6YI7W-E="@B;7-S
M<6PN9&%T971I;65C;VYV97)T(BP@(D]F9B(I.R<L"B`@("`@("`@("`@("<D
M9&)H+3YQ=65R>2@B4T54($1!5$5&3U)-050@>6UD(BD[)RP*("`@("`@("`I
M+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G
M:6YT)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;75L=&EP;&5?:V5Y('5N:7%U95]K97D@;F]T7VYU;&PG+`H@
M("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=P<FEM87)Y7VME>2!N;W1?;G5L;"<L"B`@("`@
M("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W1E>'0G+`H@("`@("`@("`@("`G;&5N)R`]/B`T,#DV+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@,R`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=D871E=&EM92<L"B`@("`@
M("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VUU
M;'1I<&QE7VME>2!U;FEQ=65?:V5Y(&YO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G8VAA
M<B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@("`@
M("=L96XG(#T^(#$Y+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@
M("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G
M(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C`L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("DL"@H@("`@)VUY
M<W%L.FUY<W%L)R`]/B!A<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)U1%6%0G
M+`H@("`@("`@("=D871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L:71E
M<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^('1R=64L"B`@
M("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@=')U92P*("`@("`@("`G:&%N
M9&QE<U]R97-U;'1S)R`]/B!T<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@
M87)R87DH"B`@("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q
M+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!M=6QT:7!L95]K
M97DG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,2P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@<')I;6%R>5]K97DG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=B;&]B)RP*("`@("`@("`@("`@)VQE;B<@/3X@-C4U,S4L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)V)L;V(G+`H@("`@("`@("DL"B`@
M("`@("`@,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=D871E
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL(&UU;'1I<&QE7VME>2<L"B`@("`@("`@*2P*("`@
M("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#4@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<F5A;"<L"B`@("`@("`@("`@
M("=L96XG(#T^(#0L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@
M("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@
M/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L96XG(#T^(#(P+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`I+`H*("`@("=M
M>7-Q;&DZ;7ES<6QI)R`]/B!A<G)A>2@*("`@("`@("`G8VQO8B<@/3X@)U1%
M6%0G+`H@("`@("`@("=D871E)R`]/B`G1$%412<L"B`@("`@("`@)V1A=&5L
M:71E<F%L)R`]/B`G)RP*("`@("`@("`G9FEN9'-?=&%B;&4G(#T^('1R=64L
M"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@
M)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G
M(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`R+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!M=6QT:7!L
M95]K97D@9W)O=7!?8GDG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A
M>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=I;G0G+`H@("`@("`@("`@("`G
M;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!P
M<FEM87)Y7VME>2!G<F]U<%]B>2<L"B`@("`@("`@*2P*("`@("`@("`R(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V)L;V(G+`H@("`@("`@
M("`@("`G;&5N)R`]/B`P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=B;&]B
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G9&%T92<L"B`@("`@("`@("`@("=L96XG(#T^(#$P+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"!M=6QT:7!L95]K97DG
M+`H@("`@("`@("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=C:&%R)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@
M("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@
M("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=D96-I
M;6%L)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G9W)O=7!?8GDG+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=V87)C:&%R)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@*2P*("`@("DL"@H@("`@)V]C:3@Z;V-I."<@/3X@87)R87DH
M"B`@("`@("`@)V-L;V(G(#T^("=#3$]")RP*("`@("`@("`G9&%T92<@/3X@
M)T1!5$4G+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@("`@
M)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M7W1A
M8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]/B!T
M<G5E+`H@("`@("`@("=C;VUM86YD<R<@/3X@87)R87DH"B`@("`@("`@("`@
M("<D9&)H+3YQ=65R>2@B04Q415(@4T534TE/3B!3150@3DQ37T1!5$5?1D]2
M34%4(#T@7"=965E9+4U-+41$7"<B*3LG+`H@("`@("`@("DL"B`@("`@("`@
M,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U"15(G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`R,BP*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=.54U"15(G+`H@("`@("`@("`@("`G
M;&5N)R`]/B`R,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG
M+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@("`@
M)W1Y<&4G(#T^("=#3$]")RP*("`@("`@("`@("`@)VQE;B<@/3X@-#`P,"P*
M("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@("`@("`@
M(#,@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G1$%412<L"B`@
M("`@("`@("`@("=L96XG(#T^(#<L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G3E5-0D52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,C(L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G;V1B8SIA8V-E<W,G(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G
M(#T^("=$051%5$E-12<L"B`@("`@("`@)V1A=&5L:71E<F%L)R`]/B`G)RP*
M("`@("`@("`G9FEN9'-?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=S:7IE
M7V9R;VU?=&%B;&4G(#T^(&9A;'-E+`H@("`@("`@("=H86YD;&5S7W)E<W5L
M=',G(#T^('1R=64L"B`@("`@("`@)V-O;6UA;F1S)R`]/B!A<G)A>2@*("`@
M("`@("`I+`H@("`@("`@(#`@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG(#T^(#$P+`H@("`@
M("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@("`@("`@*2P*("`@
M("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)TE.5$5'
M15(G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,"P*("`@("`@("`@("`@)V9L
M86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=,3TY'0TA!4B<L"B`@("`@
M("`@("`@("=L96XG(#T^(#(U-2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G1$%4151)344G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q
M.2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@
M("DL"B`@("`@("`@-"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=605)#2$%2)RP*("`@("`@("`@("`@)VQE;B<@/3X@,BP*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=$14-)34%,)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,34L"B`@("`@("`@("`@("=F;&%G<R<@
M/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@("`@("`@("`G;&5N)R`]
M/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@("`@("`I+`H@
M("`@*2P*"B`@("`G;V1B8SID8C(G(#T^(&%R<F%Y*`H@("`@("`@("=C;&]B
M)R`]/B`G0TQ/0B<L"B`@("`@("`@)V1A=&4G(#T^("=$051%)RP*("`@("`@
M("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@("`@("=F:6YD<U]T86)L92<@
M/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O;5]T86)L92<@/3X@9F%L<V4L
M"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@/3X@=')U92P*("`@("`@("`G
M8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@("DL"B`@("`@("`@,"`]/B!A
M<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*("`@("`@
M("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO
M=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#$@/3X@87)R87DH"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G24Y414=%4B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#$P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("=N;W1?;G5L;"<L"B`@
M("`@("`@*2P*("`@("`@("`R(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)T-,3T(G+`H@("`@("`@("`@("`G;&5N)R`]/B`Q,#0X-3<V+`H@
M("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@
M,R`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=$051%)RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,3`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@
M)VYO=%]N=6QL)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R87DH"B`@
M("`@("`@("`@("=T>7!E)R`]/B`G0TA!4B<L"B`@("`@("`@("`@("=L96XG
M(#T^(#(L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G1$5#24U!3"<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@
M("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^
M(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)U9!4D-(05(G+`H@("`@
M("`@("`@("`G;&5N)R`]/B`R,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@*2P*"B`@("`G<&=S<6PZ<&=S<6PG(#T^(&%R
M<F%Y*`H@("`@("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G
M(#T^("=$051%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@
M("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O
M;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@
M/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G)&1B:"T^<75E<GDH(E-%5"!$051%4U193$4@/2!)4T\B*3LG+`H@
M("`@("`@("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y
M<&4G(#T^("=I;G0T)RP*("`@("`@("`@("`@)VQE;B<@/3X@-"P*("`@("`@
M("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@=6YI<75E7VME>2!M=6QT:7!L
M95]K97DG+`H@("`@("`@("DL"B`@("`@("`@,2`]/B!A<G)A>2@*("`@("`@
M("`@("`@)W1Y<&4G(#T^("=I;G0T)RP*("`@("`@("`@("`@)VQE;B<@/3X@
M-"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G;F]T7VYU;&P@<')I;6%R>5]K
M97DG+`H@("`@("`@("DL"B`@("`@("`@,B`]/B!A<G)A>2@*("`@("`@("`@
M("`@)W1Y<&4G(#T^("=T97AT)RP*("`@("`@("`@("`@)VQE;B<@/3X@+3$L
M"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@
M("`S(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)V1A=&4G+`H@
M("`@("`@("`@("`G;&5N)R`]/B`T+`H@("`@("`@("`@("`G9FQA9W,G(#T^
M("=N;W1?;G5L;"!U;FEQ=65?:V5Y(&UU;'1I<&QE7VME>2<L"B`@("`@("`@
M*2P*("`@("`@("`T(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@
M)V)P8VAA<B<L"B`@("`@("`@("`@("=L96XG(#T^("TQ+`H@("`@("`@("`@
M("`G9FQA9W,G(#T^("=N;W1?;G5L;"!D969A=6QT7R4R,&4G+`H@("`@("`@
M("DL"B`@("`@("`@-2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=N=6UE<FEC)RP*("`@("`@("`@("`@)VQE;B<@/3X@+3$L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W9A<F-H87(G+`H@("`@("`@
M("`@("`G;&5N)R`]/B`M,2P*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*
M("`@("`@("`I+`H@("`@*2P*"B`@("`G<W%L:71E.G-Q;&ET92<@/3X@87)R
M87DH"B`@("`@("`@)V-L;V(G(#T^("=#3$]")RP*("`@("`@("`G9&%T92<@
M/3X@)T1!5$4G+`H@("`@("`@("=D871E;&ET97)A;"<@/3X@)R<L"B`@("`@
M("`@)V9I;F1S7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G<VEZ95]F<F]M
M7W1A8FQE)R`]/B!F86QS92P*("`@("`@("`G:&%N9&QE<U]R97-U;'1S)R`]
M/B!F86QS92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@
M("DL"B`@("`@("`@,"`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^
M("=)3E1%1T52)RP*("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@
M("`@)V9L86=S)R`]/B`G;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,2`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=)3E1%1T52)RP*
M("`@("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]
M/B`G<')I;6%R>5]K97D@;F]T7VYU;&PG+`H@("`@("`@("DL"B`@("`@("`@
M,B`]/B!A<G)A>2@*("`@("`@("`@("`@)W1Y<&4G(#T^("=#3$]")RP*("`@
M("`@("`@("`@)VQE;B<@/3X@,"P*("`@("`@("`@("`@)V9L86=S)R`]/B`G
M)RP*("`@("`@("`I+`H@("`@("`@(#,@/3X@87)R87DH"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G1$%412<L"B`@("`@("`@("`@("=L96XG(#T^(#`L"B`@
M("`@("`@("`@("=F;&%G<R<@/3X@)VYO=%]N=6QL)RP*("`@("`@("`I+`H@
M("`@("`@(#0@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G0TA!
M4B<L"B`@("`@("`@("`@("=L96XG(#T^(#(L"B`@("`@("`@("`@("=F;&%G
M<R<@/3X@)VYO=%]N=6QL(&1E9F%U;'1?)3(P92<L"B`@("`@("`@*2P*("`@
M("`@("`U(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)T1%0TE-
M04PG+`H@("`@("`@("`@("`G;&5N)R`]/B`R+`H@("`@("`@("`@("`G9FQA
M9W,G(#T^("<G+`H@("`@("`@("DL"B`@("`@("`@.2`]/B!A<G)A>2@*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=605)#2$%2)RP*("`@("`@("`@("`@)VQE
M;B<@/3X@,C`L"B`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@
M*2P*("`@("DL"@H@("`@)W-Y8F%S93IS>6)A<V4G(#T^(&%R<F%Y*`H@("`@
M("`@("=C;&]B)R`]/B`G5$585"<L"B`@("`@("`@)V1A=&4G(#T^("=334%,
M3$1!5$5424U%)RP*("`@("`@("`G9&%T96QI=&5R86PG(#T^("<G+`H@("`@
M("`@("=F:6YD<U]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)W-I>F5?9G)O
M;5]T86)L92<@/3X@9F%L<V4L"B`@("`@("`@)VAA;F1L97-?<F5S=6QT<R<@
M/3X@=')U92P*("`@("`@("`G8V]M;6%N9',G(#T^(&%R<F%Y*`H@("`@("`@
M("`@("`G)&1B:"T^<75E<GDH(E-%5"!$051%1D]234%4('EM9"(I.R<L"B`@
M("`@("`@*2P*("`@("`@("`P(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=M=6QT:7!L95]K97D@=6YI<75E7VME>2<L"B`@
M("`@("`@*2P*("`@("`@("`Q(#T^(&%R<F%Y*`H@("`@("`@("`@("`G='EP
M92<@/3X@)VEN="<L"B`@("`@("`@("`@("=L96XG(#T^(#$Q+`H@("`@("`@
M("`@("`G9FQA9W,G(#T^("=U;FEQ=65?:V5Y)RP*("`@("`@("`I+`H@("`@
M("`@(#(@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG
M)RP*("`@("`@("`@("`@)VQE;B<@/3X@,S(W-C@L"B`@("`@("`@("`@("=F
M;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`S(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`G='EP92<@/3X@)V1A=&5T:6UE)RP*("`@("`@("`@("`@
M)VQE;B<@/3X@,CDL"B`@("`@("`@("`@("=F;&%G<R<@/3X@)VUU;'1I<&QE
M7VME>2!U;FEQ=65?:V5Y)RP*("`@("`@("`I+`H@("`@("`@(#0@/3X@87)R
M87DH"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG)RP*("`@("`@("`@
M("`@)VQE;B<@/3X@,BP*("`@("`@("`@("`@)V9L86=S)R`]/B`G)RP*("`@
M("`@("`I+`H@("`@("`@(#4@/3X@87)R87DH"B`@("`@("`@("`@("=T>7!E
M)R`]/B`G<F5A;"<L"B`@("`@("`@("`@("=L96XG(#T^(#0L"B`@("`@("`@
M("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@*2P*("`@("`@("`Y(#T^(&%R
M<F%Y*`H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L"B`@("`@("`@
M("`@("=L96XG(#T^(#(P+`H@("`@("`@("`@("`G9FQA9W,G(#T^("<G+`H@
M("`@("`@("DL"B`@("`I+`HI.PH*"B1Q=6ER:U]K97D@/2`D9&)H+3YP:'!T
M>7!E("X@)SHG("X@)&1B:"T^9&)S>6YT87@["@II9B`H(6ES<V5T*"1Q=6ER
M:W-;)'%U:7)K7VME>5TI*2!["B`@("!D:64H(E1H:7,@=&5S="!D;V5S(&YO
M="!Y970@<W5P<&]R="`D<75I<FM?:V5Y(BD["GT*"FEF("AC;W5N="@D<75I
M<FMS6R1Q=6ER:U]K97E=6R=C;VUM86YD<R==*2D@>PH@("`@9F]R96%C:"`H
M)'%U:7)K<ULD<75I<FM?:V5Y75LG8V]M;6%N9',G72!A<R`D=F%L=64I('L*
M("`@("`@("!E=F%L*"1V86QU92D["B`@("!]"GT*"@HD9&)H+3YQ=65R>2@G
M1$5,151%($923TT@<&AP=&5S="<I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.
M5$\@<&AP=&5S="!604Q515,@*#$L("=O;F4G+"`G3VYE)RP@)S(P,#$M,#(M
M,38G*2(I.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,@*#(L("=T=V\G+"`G5'=O)RP@)S(P,#$M,#(M,34G*2(I.PHD9&)H+3YQ
M=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q515,@*#,L("=T:')E92<L
M("=4:')E92<L("<R,#`Q+3`R+3$T)RDB*3L*"@HD9&)H+3YS971%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*9')O<%]T86)L92@D9&)H+"`G
M<&AP=&5S=%]F:R<I.PHD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?0T%,3$)!0TLL("=P92<I.PH*"FEF("@D<75I<FM?:V5Y(#T]("=O9&)C
M.F%C8V5S<R<I('L*("`@("1D969A=6QT7V4@/2`G)SL*("`@("1D96-I;6%L
M("`@/2`G3E5-15))0R<["GT@96QS96EF("@D<75I<FM?:V5Y(#T]("=M<W%L
M.FUS<6PG*2!["B`@("`D9&5F875L=%]E(#T@)R<["B`@("`D9&5C:6UA;"`@
M(#T@)U)%04PG.PI](&5L<V4@>PH@("`@)&1E9F%U;'1?92`](")$149!54Q4
M("<@92<B.PH@("`@)&1E8VEM86P@("`]("=$14-)34%,*#(L,2DG.PI]"@HO
M+R`D;G5L;"!I<R!S970@:6X@;6MT86)L92YI;F,*"G-W:71C:"`H)&1B:"T^
M<&AP='EP92D@>PH@("`@8V%S92`G;7-Q;"<Z"B`@("`@("`@)&1B:"T^<75E
M<GDH(@H@("`@("`@("`@("!#4D5!5$4@5$%"3$4@<&AP=&5S=%]F:R`H"B`@
M("`@("`@("`@("`@("!A($E.5$5'15(@3D]4($Y53$PL"B`@("`@("`@("`@
M("`@("!F:R!)3E1%1T52($Y/5"!.54Q,+`H@("`@("`@("`@("`@("`@8R![
M)'%U:7)K<ULD<75I<FM?:V5Y75LG8VQO8B==?2`D;G5L;"P*("`@("`@("`@
M("`@("`@(&0@>R1Q=6ER:W-;)'%U:7)K7VME>5U;)V1A=&4G77T@3D]4($Y5
M3$PL"B`@("`@("`@("`@("`@("!E($-(05(H,BD@)&1E9F%U;'1?92!.3U0@
M3E5,3"P*("`@("`@("`@("`@("`@(&8@)&1E8VEM86P@)&YU;&P*("`@("`@
M("`@("`@*0H@("`@("`@("(I.PH@("`@("`@("1D8F@M/G%U97)Y*"=#4D5!
M5$4@54Y)455%($E.1$58(&9K<&L@3TX@<&AP=&5S=%]F:R`H9FLI)RD["B`@
M("`@("`@)&1B:"T^<75E<GDH)T-214%412!53DE1544@24Y$15@@9FMU:R!/
M3B!P:'!T97-T7V9K("AA+"!D*2<I.PH@("`@("`@(&)R96%K.PH@("`@9&5F
M875L=#H*("`@("`@("`D9&)H+3YQ=65R>2@B"B`@("`@("`@("`@($-214%4
M12!404),12!P:'!T97-T7V9K("@*("`@("`@("`@("`@("`@(&$@24Y414=%
M4B!.3U0@3E5,3"P*("`@("`@("`@("`@("`@(&9K($E.5$5'15(@3D]4($Y5
M3$PL"B`@("`@("`@("`@("`@("!C('LD<75I<FMS6R1Q=6ER:U]K97E=6R=C
M;&]B)UU]("1N=6QL+`H@("`@("`@("`@("`@("`@9"![)'%U:7)K<ULD<75I
M<FM?:V5Y75LG9&%T92==?2!.3U0@3E5,3"P*("`@("`@("`@("`@("`@(&4@
M0TA!4B@R*2`D9&5F875L=%]E($Y/5"!.54Q,+`H@("`@("`@("`@("`@("`@
M9B`D9&5C:6UA;"`D;G5L;"P*("`@("`@("`@("`@("`@(%!224U!4ED@2T59
M("AF:RDL"B`@("`@("`@("`@("`@("!53DE1544@*&$L(&0I"B`@("`@("`@
M("`@("D*("`@("`@("`B*3L*?0H*)&1B:"T^<75E<GDH(D-214%412!)3D1%
M6"!T:&5D:61X($].('!H<'1E<W1?9FL@*&0I(BD["B1D8F@M/G%U97)Y*"))
M3E-%4E0@24Y43R!P:'!T97-T7V9K(%9!3%5%4R`H,3`L(#$L("=/;F4G+"(*
M("`@("`@("`@("`@+B`D<75I<FMS6R1Q=6ER:U]K97E=6R=D871E;&ET97)A
M;"==("X@(B<R,#`Q+3`R+3$V)RP@("=C,2<L(#$N,2DB*3L*)&1B:"T^<75E
M<GDH(DE.4T525"!)3E1/('!H<'1E<W1?9FL@5D%,5453("@R,"P@,BP@)U1W
M;R<L(@H@("`@("`@("`@("`N("1Q=6ER:W-;)'%U:7)K7VME>5U;)V1A=&5L
M:71E<F%L)UT@+B`B)S(P,#$M,#(M,34G+"`G8S(G+"`R+C(I(BD["B1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T7V9K(%9!3%5%4R`H,S`L(#,L
M("=4:')E92<L(@H@("`@("`@("`@("`N("1Q=6ER:W-;)'%U:7)K7VME>5U;
M)V1A=&5L:71E<F%L)UT@+B`B)S(P,#$M,#(M,30G+"`G8S,G+"`S+C,I(BD[
M"@IF=6YC=&EO;B`F<G5N475E<GDH*2!["B`@("!G;&]B86P@)&1B:"P@)')E
M<W5L=&]B:CL*"B`@("`D<75I<FM?:V5Y(#T@)&1B:"T^<&AP='EP92`N("<Z
M)R`N("1D8F@M/F1B<WEN=&%X.PH*("`@('-W:71C:"`H)'%U:7)K7VME>2D@
M>PH@("`@("`@(&-A<V4@)V]D8F,Z9&(R)SH*("`@("`@("`@("`@+R\@8V%N
M)W0@97AT<F%C="!B;&]B)W,@=&AI<R!W87D@<V\@;6%K92!A(&9A:V4@8V]L
M=6UN"B`@("`@("`@("`@("1Q=65R>2`](")314Q%0U0@<&AP=&5S=%]F:RYA
M+"!P:'!T97-T7V9K+F9K+"`G=&5M<'AY>B<@05,@8RPB"B`@("`@("`@("`@
M("`@("`@("`N("<@<&AP=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L('!H<'1E
M<W1?9FLN9BPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S="YA+"!P
M:'!T97-T+F(L('!H<'1E<W0N8RP@<&AP=&5S="YD)PH@("`@("`@("`@("`@
M("`@("`@+B`G($923TT@<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@("`@("`@
M("`@("`@("`@("X@)R!72$5212!P:'!T97-T+F$@/2!P:'!T97-T7V9K+F9K
M)SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`G;7-Q;#IM<W%L
M)SH*("`@("`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!P:'!T97-T7V9K+F$L
M('!H<'1E<W1?9FLN9FLL('!H<'1E<W1?9FLN8RPG"B`@("`@("`@("`@("`@
M("`@("`N("<@<&AP=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L('!H<'1E<W1?
M9FLN9BPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP=&5S="YA+"!P:'!T
M97-T+F(L('!H<'1E<W0N8RP@<&AP=&5S="YD)PH@("`@("`@("`@("`@("`@
M("`@+B`G($923TT@<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@("`@("`@("`@
M("`@("`@("X@)R!72$5212!P:'!T97-T+F$@/2!P:'!T97-T7V9K+F9K)SL*
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L=#H*("`@("`@("`@
M("`@)'%U97)Y(#T@)U-%3$5#5"!P:'!T97-T7V9K+F$L('!H<'1E<W1?9FLN
M9FLL('!H<'1E<W1?9FLN8RPG"B`@("`@("`@("`@("`@("`@("`N("<@<&AP
M=&5S=%]F:RYD+"!P:'!T97-T7V9K+F4L('!H<'1E<W1?9FLN9BPG"B`@("`@
M("`@("`@("`@("`@("`N("<@<&AP=&5S="YA+"!P:'!T97-T+F(L('!H<'1E
M<W0N8RP@<&AP=&5S="YD)PH@("`@("`@("`@("`@("`@("`@+B`G($923TT@
M<&AP=&5S=%]F:RP@<&AP=&5S="<*("`@("`@("`@("`@("`@("`@("X@)R!7
M2$5212!P:'!T97-T+F$@/2!P:'!T97-T7V9K+F9K)SL*("`@('T*("`@("1R
M97-U;'1O8FH@/28@)&1B:"T^<75E<GDH)'%U97)Y*3L*("`@(')E='5R;B`D
M<F5S=6QT;V)J.PI]"@H*)&5X<&5C=&5D,#$@/2`G=&%B;&4@+BXN(&UA=&-H
M960@97AP96-T960@=F%L=64*;F%M92`]/B!A"G1Y<&4@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E
M"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"B<["@HD97AP96-T
M960P,B`]("=T86)L92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN86UE
M(#T^(&9K"G1Y<&4@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*;&5N("XN
M+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"F9L86=S("XN+B!M871C:&5D(&5X
M<&5C=&5D('9A;'5E"B<["@HD97AP96-T960P,R`]("=T86)L92`N+BX@;6%T
M8VAE9"!E>'!E8W1E9"!V86QU90IN86UE(#T^(&,*='EP92`N+BX@;6%T8VAE
M9"!E>'!E8W1E9"!V86QU90IL96X@+BXN(&UA=&-H960@97AP96-T960@=F%L
M=64*9FQA9W,@+BXN(&UA=&-H960@97AP96-T960@=F%L=64*)SL*"B1E>'!E
M8W1E9#`T(#T@)W1A8FQE("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA
M;64@/3X@9`IT>7!E("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N
M+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E
M>'!E8W1E9"!V86QU90HG.PH*)&5X<&5C=&5D,#4@/2`G=&%B;&4@+BXN(&UA
M=&-H960@97AP96-T960@=F%L=64*;F%M92`]/B!E"G1Y<&4@+BXN(&UA=&-H
M960@97AP96-T960@=F%L=64*;&5N("XN+B!M871C:&5D(&5X<&5C=&5D('9A
M;'5E"F9L86=S("XN+B!M871C:&5D(&5X<&5C=&5D('9A;'5E"B<["@HD97AP
M96-T960P-B`]("=T86)L92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IN
M86UE(#T^(&8*='EP92`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90IL96X@
M+BXN(&UA=&-H960@97AP96-T960@=F%L=64*9FQA9W,@+BXN(&UA=&-H960@
M97AP96-T960@=F%L=64*)SL*"B1E>'!E8W1E9#$P(#T@)W1A8FQE("XN+B!M
M871C:&5D(&5X<&5C=&5D('9A;'5E"FYA;64@/3X@9`IT>7!E("XN+B!M871C
M:&5D(&5X<&5C=&5D('9A;'5E"FQE;B`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V
M86QU90IF;&%G<R`N+BX@;6%T8VAE9"!E>'!E8W1E9"!V86QU90HG.PH*"@IP
M<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3U<;B(["G!R:6YT(")087-S:6YG(')E<W5L="!/0DI%0U0@=&\@;65T
M:&]D(&EN($1"7SQT>7!E/BY<;B(["G!R:6YT(")/=71P=70@/2!D969A=6QT
M+EQN(CL*<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+5QN(CL*)')E<W5L=&]B:B`])B!R=6Y1=65R>2@I.PHD87)R
M87D@/2`D9&)H+3YT86)L94EN9F\H)')E<W5L=&]B:BD["@IP<FEN="`B7&YC
M;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T
M960P,2P@,"D["@IP<FEN="`B7&YC;VQU;6X@.3I<;B(["F5X86UI;F5!<G)A
M>41A=&$H)&%R<F%Y+"`D97AP96-T960Q,"P@.2D["@H*<')I;G0@(EQN/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP
M<FEN="`B4&%S<VEN9R!R97-U;'0@240@=&\@;65T:&]D(&EN($1"7SQT>7!E
M/BY<;B(["G!R:6YT(")/=71P=70@/2!$0E]404),14E.1D]?3U)$15(N7&XB
M.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM7&XB.PHD<F5S=6QT;V)J(#TF(')U;E%U97)Y*"D["B1A<G)A>2`]
M("1D8F@M/G1A8FQE26YF;R@D<F5S=6QT;V)J+3YR97-U;'0L($1"7U1!0DQ%
M24Y&3U]/4D1%4BD["@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!
M<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P,2P@,"D["@IP<FEN="`B7&YC
M;VQU;6X@,SI<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T
M960P-"P@,RD["@IP<FEN="`B7&YN=6U?9FEE;&1S.B`B.PII9B`H)'%U:7)K
M<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT@)B8@)&%R<F%Y6R=N
M=6U?9FEE;&1S)UT@/3T@,3`I('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C
M=&5D(')E<W5L=%QN(CL*?2!E;'-E:68@*$1".CII<T5R<F]R*"1A<G)A>2D@
M)B8@)&%R<F%Y+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I
M('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E
M;'-E('L*("`@('!R:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O
M<&5R(')E<W5L='-<;B(["GT*"G!R:6YT(")<;F]R9&5R.EQN(CL*:68@*"1Q
M=6ER:W-;)'%U:7)K7VME>5U;)VAA;F1L97-?<F5S=6QT<R==("8F(&ES7V%R
M<F%Y*"1A<G)A>5LG;W)D97(G72DI('L*("`@("1E>'!E8W1E9"`]("=A(#T^
M(#8*8B`]/B`W"F,@/3X@.`ID(#T^(#D*92`]/B`T"F8@/3X@-0IF:R`]/B`Q
M"B<["B`@("!K<V]R="@D87)R87E;)V]R9&5R)UTI.PH@("`@97AA;6EN94%R
M<F%Y1&%T82@D87)R87E;)V]R9&5R)UTL("1E>'!E8W1E9"D["GT@96QS96EF
M("A$0CHZ:7-%<G)O<B@D87)R87DI("8F("1A<G)A>2T^9V5T0V]D92@I(#T]
M($1"7T524D]27TY/5%]#05!!0DQ%*2!["B`@("!P<FEN="`B;6%T8VAE9"!E
M>'!E8W1E9"!R97-U;'1<;B(["GT@96QS92!["B`@("!P<FEN="`B5&AI<R!$
M34)3(&1I9&XG="!P<F]D=6-E('!R;W!E<B!R97-U;'1S7&XB.PI]"@H*"G!R
M:6YT(")<;CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/5QN(CL*<')I;G0@(E!A<W-I;F<@1$)?5$%"3$5)3D9/7T]21$525$%"
M3$4@=&\@;65T:&]D(&EN($1"7W)E<W5L="Y<;B(["G!R:6YT(")/=71P=70@
M/2!$0E]404),14E.1D]?3U)$15)404),12Y<;B(["G!R:6YT("(M+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2U<;B(["B1R97-U
M;'1O8FH@/28@<G5N475E<GDH*3L*)&%R<F%Y(#T@)')E<W5L=&]B:BT^=&%B
M;&5);F9O*$1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*3L*+R\@1G)E92!T:&ES
M('1O(&ME97`@:6YT97)B87-E(&AA<'!Y+@HD<F5S=6QT;V)J+3YF<F5E*"D[
M"@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R
M<F%Y+"`D97AP96-T960P,2P@,"D["@IP<FEN="`B7&YC;VQU;6X@,SI<;B([
M"F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`D97AP96-T960P-"P@,RD["@IP
M<FEN="`B7&YN=6U?9FEE;&1S.B`B.PII9B`H)'%U:7)K<ULD<75I<FM?:V5Y
M75LG:&%N9&QE<U]R97-U;'1S)UT@)B8@)&%R<F%Y6R=N=6U?9FEE;&1S)UT@
M/3T@,3`I('L*("`@('!R:6YT(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN
M(CL*?2!E;'-E:68@*$1".CII<T5R<F]R*"1A<G)A>2D@)B8@)&%R<F%Y+3YG
M971#;V1E*"D@/3T@1$)?15)23U)?3D]47T-!4$%"3$4I('L*("`@('!R:6YT
M(")M871C:&5D(&5X<&5C=&5D(')E<W5L=%QN(CL*?2!E;'-E('L*("`@('!R
M:6YT(")4:&ES($1-0E,@9&ED;B=T('!R;V1U8V4@<')O<&5R(')E<W5L='-<
M;B(["GT*"@IP<FEN="`G;W)D97)T86)L95MP:'!T97-T73H@)SL*)&5X<&5C
M=&5D(#T@)V$@/3X@-@IB(#T^(#<*8R`]/B`X"F0@/3X@.0HG.PII9B`H)'%U
M:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U;'1S)UT*("`@("8F(&ES
M<V5T*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T)UTI*2!["B`@("`D
M86-T=6%L(#T@<F5T=7)N07)R87E$871A*"1A<G)A>5LG;W)D97)T86)L92==
M6R=P:'!T97-T)UTI.PI](&5L<V4@>PH@("`@)&%C='5A;"`]("<G.PI]"FEF
M("@D86-T=6%L(#T]("1E>'!E8W1E9"D@>PH@("`@<')I;G0@(FUA=&-H960@
M97AP96-T960@<F5S=6QT7&XB.PI](&5L<V4@>PH@("`@:68@*"@D<75I<FMS
M6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L92==(#T]/2!F86QS92`*("`@("`@
M("!\?"!$0CHZ:7-%<G)O<B@D87)R87DI("8F("1A<G)A>2T^9V5T0V]D92@I
M(#T]($1"7T524D]27TY/5%]#05!!0DQ%*0H@("`@("`@("8F("1A8W1U86P@
M/3T@)R<I('L*("`@("`@("!P<FEN="`B;6%T8VAE9"!E>'!E8W1E9"!R97-U
M;'1<;B(["B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")$241.)U0@;6%T
M8V@@97AP96-T960@=F%L=65S+BXN7&XB.PH@("`@("`@('!R:6YT(")^?GY^
M?GY^?EQN17AP96-T960Z7&XD97AP96-T961<;B(["B`@("`@("`@<')I;G0@
M(GY^?GY<;D%C='5A;#I<;B1A8W1U86Q<;GY^?GY^?GY^7&Y<;B(["B`@("!]
M"GT*"@IP<FEN="`G;W)D97)T86)L95MP:'!T97-T7V9K73H@)SL*)&5X<&5C
M=&5D(#T@)V$@/3X@,`IF:R`]/B`Q"F,@/3X@,@ID(#T^(#,*92`]/B`T"F8@
M/3X@-0HG.PII9B`H)'%U:7)K<ULD<75I<FM?:V5Y75LG:&%N9&QE<U]R97-U
M;'1S)UT*("`@("8F(&ES<V5T*"1A<G)A>5LG;W)D97)T86)L92==6R=P:'!T
M97-T7V9K)UTI*2!["B`@("`D86-T=6%L(#T@<F5T=7)N07)R87E$871A*"1A
M<G)A>5LG;W)D97)T86)L92==6R=P:'!T97-T7V9K)UTI.PI](&5L<V4@>PH@
M("`@)&%C='5A;"`]("<G.PI]"FEF("@D86-T=6%L(#T]("1E>'!E8W1E9"D@
M>PH@("`@<')I;G0@(FUA=&-H960@97AP96-T960@<F5S=6QT7&XB.PI](&5L
M<V4@>PH@("`@:68@*"@D<75I<FMS6R1Q=6ER:U]K97E=6R=F:6YD<U]T86)L
M92==(#T]/2!F86QS92`*("`@("`@("!\?"!$0CHZ:7-%<G)O<B@D87)R87DI
M("8F("1A<G)A>2T^9V5T0V]D92@I(#T]($1"7T524D]27TY/5%]#05!!0DQ%
M*0H@("`@("`@("8F("1A8W1U86P@/3T@)R<I('L*("`@("`@("!P<FEN="`B
M;6%T8VAE9"!E>'!E8W1E9"!R97-U;'1<;B(["B`@("!](&5L<V4@>PH@("`@
M("`@('!R:6YT(")$241.)U0@;6%T8V@@97AP96-T960@=F%L=65S+BXN7&XB
M.PH@("`@("`@('!R:6YT(")^?GY^?GY^?EQN17AP96-T960Z7&XD97AP96-T
M961<;B(["B`@("`@("`@<')I;G0@(GY^?GY<;D%C='5A;#I<;B1A8W1U86Q<
M;GY^?GY^?GY^7&Y<;B(["B`@("!]"GT*"@IP<FEN="`B7&X]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")0
M87-S:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$
M0E\\9')I=F5R/BY<;B(["G!R:6YT(")/=71P=70@/2!D969A=6QT+EQN(CL*
M<')I;G0@(BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+5QN(CL*)&%R<F%Y(#T@)&1B:"T^=&%B;&5);F9O*"=P:'!T97-T7V9K
M)RD["@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H
M)&%R<F%Y+"`D97AP96-T960P,2P@,"P@9F%L<V4I.PH*<')I;G0@(EQN8V]L
M=6UN(#$Z7&XB.PIE>&%M:6YE07)R87E$871A*"1A<G)A>2P@)&5X<&5C=&5D
M,#(L(#$L(&9A;'-E*3L*"G!R:6YT(")<;F-O;'5M;B`R.EQN(CL*97AA;6EN
M94%R<F%Y1&%T82@D87)R87DL("1E>'!E8W1E9#`S+"`R+"!F86QS92D["@IP
M<FEN="`B7&YC;VQU;6X@,SI<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y
M+"`D97AP96-T960P-"P@,RP@9F%L<V4I.PH*<')I;G0@(EQN8V]L=6UN(#0Z
M7&XB.PIE>&%M:6YE07)R87E$871A*"1A<G)A>2P@)&5X<&5C=&5D,#4L(#0L
M(&9A;'-E*3L*"G!R:6YT(")<;F-O;'5M;B`U.EQN(CL*97AA;6EN94%R<F%Y
M1&%T82@D87)R87DL("1E>'!E8W1E9#`V+"`U+"!F86QS92D["@H*<')I;G0@
M(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M7&XB.PIP<FEN="`B4&%S<VEN9R!404),12!.04U%("=P:'!T97-T7V9K)R!T
M;R!M971H;V0@:6X@1$)?/&1R:79E<CXN7&XB.PIP<FEN="`B3W5T<'5T(#T@
M1$)?5$%"3$5)3D9/7T953$PN7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM7&XB.PHD87)R87D@/2`D9&)H
M+3YT86)L94EN9F\H)W!H<'1E<W1?9FLG+"!$0E]404),14E.1D]?1E5,3"D[
M"@IP<FEN="`B7&YC;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R
M<F%Y+"`D97AP96-T960P,2P@,"P@9F%L<V4I.PH*<')I;G0@(EQN;W)D97(Z
M7&XB.PHD97AP96-T(#TG82`]/B`P"F9K(#T^(#$*8R`]/B`R"F0@/3X@,PIE
M(#T^(#0*9B`]/B`U"B<["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y6R=O<F1E
M<B==+"`D97AP96-T+"!F86QS92P@9F%L<V4I.PH*<')I;G0@(EQN;W)D97)T
M86)L95MP:'!T97-T7V9K73I<;B(["B1E>'!E8W0@/2=A(#T^(#`*9FL@/3X@
M,0IC(#T^(#(*9"`]/B`S"F4@/3X@-`IF(#T^(#4*)SL*97AA;6EN94%R<F%Y
M1&%T82@D87)R87E;)V]R9&5R=&%B;&4G75LG<&AP=&5S=%]F:R==+"`D97AP
M96-T*3L*"@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`B4&%S<VEN9R!404),12!.04U%
M("=P:'!T97-T7V9K)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CX@04=!24XN
M7&XB.PIP<FEN="`B3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T953$PL(&QO=V5R
M8V%S:6YG('1U<FYE9"!O9F8N7&XB.PIP<FEN="`B+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM7&XB.PHD9&)H+3YS971/<'1I
M;VXH)W!O<G1A8FEL:71Y)RP@1$)?4$]25$%"24Q)5%E?04Q,(%X@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%*3L*)&%R<F%Y(#T@)&1B:"T^=&%B;&5);F9O
M*"=P:'!T97-T7V9K)RP@1$)?5$%"3$5)3D9/7T953$PI.PH*+R\@=&5S=&EN
M9R!N;VXM;&]W97)C87-I;F<@86)O=F4@=&\@96YS=7)E('!R;V=R86T@9&]E
M<VXG="!D:64N"B\O(&QO=V5R8V%S92!T:&4@;F%M97,@:&5R92!T;R!E;G-U
M<F4@=&5S="!U;FEF;W)M:71Y+@HD87)R87E;,%U;)W1A8FQE)UT@/2!S=')T
M;VQO=V5R*"1A<G)A>5LP75LG=&%B;&4G72D["B1A<G)A>5LP75LG;F%M92==
M(#T@<W1R=&]L;W=E<B@D87)R87E;,%U;)VYA;64G72D["@IP<FEN="`B7&YC
M;VQU;6X@,#I<;B(["F5X86UI;F5!<G)A>41A=&$H)&%R<F%Y+"`P+"!F86QS
M92D["@H*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["F1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*9')O<%]T86)L92@D
M9&)H+"`G<&AP=&5S=%]F:R<I.PH*/SX*+2U%6%!%0U0M+0H]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!R97-U
M;'0@3T)*14-4('1O(&UE=&AO9"!I;B!$0E\\='EP93XN"D]U='!U="`](&1E
M9F%U;'0N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC;VQU
M;6X@.3H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S:6YG(')E<W5L="!)
M1"!T;R!M971H;V0@:6X@1$)?/'1Y<&4^+@I/=71P=70@/2!$0E]404),14E.
M1D]?3U)$15(N"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+0H*8V]L=6UN(#`Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC
M;VQU;6X@,SH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"FYU;5]F:65L9',Z
M(&UA=&-H960@97AP96-T960@<F5S=6QT"@IO<F1E<CH*;6%T8VAE9"!E>'!E
M8W1E9"!R97-U;'0*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/0I087-S:6YG($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%('1O
M(&UE=&AO9"!I;B!$0E]R97-U;'0N"D]U='!U="`]($1"7U1!0DQ%24Y&3U]/
M4D1%4E1!0DQ%+@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T*"F-O;'5M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H*
M8V]L=6UN(#,Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IN=6U?9FEE;&1S
M.B!M871C:&5D(&5X<&5C=&5D(')E<W5L=`IO<F1E<G1A8FQE6W!H<'1E<W1=
M.B!M871C:&5D(&5X<&5C=&5D(')E<W5L=`IO<F1E<G1A8FQE6W!H<'1E<W1?
M9FM=.B!M871C:&5D(&5X<&5C=&5D(')E<W5L=`H*/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"E!A<W-I;F<@5$%"3$4@3D%-
M12`G<&AP=&5S=%]F:R<@=&\@;65T:&]D(&EN($1"7SQD<FEV97(^+@I/=71P
M=70@/2!D969A=6QT+@HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*"F-O;'5M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E<W5L
M=`H*8V]L=6UN(#$Z"FUA=&-H960@97AP96-T960@<F5S=6QT"@IC;VQU;6X@
M,CH*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"F-O;'5M;B`S.@IM871C:&5D
M(&5X<&5C=&5D(')E<W5L=`H*8V]L=6UN(#0Z"FUA=&-H960@97AP96-T960@
M<F5S=6QT"@IC;VQU;6X@-3H*;6%T8VAE9"!E>'!E8W1E9"!R97-U;'0*"CT]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0I087-S
M:6YG(%1!0DQ%($Y!344@)W!H<'1E<W1?9FLG('1O(&UE=&AO9"!I;B!$0E\\
M9')I=F5R/BX*3W5T<'5T(#T@1$)?5$%"3$5)3D9/7T953$PN"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*8V]L=6UN(#`Z
M"FUA=&-H960@97AP96-T960@<F5S=6QT"@IO<F1E<CH*;6%T8VAE9"!E>'!E
M8W1E9"!R97-U;'0*"F]R9&5R=&%B;&5;<&AP=&5S=%]F:UTZ"FUA=&-H960@
M97AP96-T960@<F5S=6QT"@H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T*4&%S<VEN9R!404),12!.04U%("=P:'!T97-T7V9K
M)R!T;R!M971H;V0@:6X@1$)?/&1R:79E<CX@04=!24XN"D]U='!U="`]($1"
M7U1!0DQ%24Y&3U]&54Q,+"!L;W=E<F-A<VEN9R!T=7)N960@;V9F+@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"F-O;'5M
M;B`P.@IM871C:&5D(&5X<&5C=&5D(')E<W5L=`H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O,3=Q=65R>2YP:'!T````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W
M,S,T(#$P-3$U-#,T,3,U(#`R-#<W,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````M+51%4U0M+0I$0E]D<FEV97(Z.G%U97)Y
M"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@,C`T-PHM+5-+25!)1BTM"CP_
M<&AP"@HO*BH*("H@0V%L;',@=&AE('%U97)Y*"D@;65T:&]D(&EN('9A<FEO
M=7,@=V%Y<R!A9V%I;G-T(&%N>2!$0DU3+@H@*@H@*B!`<V5E("`@("`@1$)?
M8V]M;6]N.CIQ=65R>2@I"B`J(`H@*B!`<&%C:V%G92`@1$(*("H@0'9E<G-I
M;VX@("1)9#H@,3=Q=65R>2YP:'!T+'8@,2XQ,R`R,#`U+S`R+S$V(#$S.C4T
M.C4R(&1A;FEE;&,@17AP("0*("H@0&-A=&5G;W)Y($1A=&%B87-E"B`J($!A
M=71H;W(@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0&%N86QY<VES86YD
M<V]L=71I;VYS+F-O;3X*("H@0&EN=&5R;F%L"B`J+PH*8VAD:7(H9&ER;F%M
M92A?7T9)3$5?7RDI.PIR97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<["@H_
M/@HM+49)3$4M+0H\/W!H<`H*+R\@)$ED.B`Q-W%U97)Y+G!H<'0L=B`Q+C$S
M(#(P,#4O,#(O,38@,3,Z-30Z-3(@9&%N:65L8R!%>'`@)`H*+RHJ"B`J($-O
M;FYE8W0@=&\@=&AE(&1A=&%B87-E(&%N9"!M86ME('1H92!P:'!T97-T('1A
M8FQE+@H@*B\*<F5Q=6ER95]O;F-E("<N+VUK=&%B;&4N:6YC)SL*"@HO*BH*
M("H@3&]C86P@97)R;W(@8V%L;&)A8VL@:&%N9&QE<BX*("H*("H@1')O<',@
M=&AE('!H<'1E<W0@=&%B;&4L('!R:6YT<R!O=70@86X@97)R;W(@;65S<V%G
M92!A;F0@:VEL;',@=&AE"B`J('!R;V-E<W,N"B`J"B`J($!P87)A;2!O8FIE
M8W0@("1O("!014%2(&5R<F]R(&]B:F5C="!A=71O;6%T:6-A;&QY('!A<W-E
M9"!T;R!T:&ES(&UE=&AO9`H@*B!`<F5T=7)N('9O:60*("H@0'-E92!014%2
M.CIS971%<G)O<DAA;F1L:6YG*"D*("HO"F9U;F-T:6]N('!E*"1O*2!["B`@
M("!G;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E
M<W0G*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1D
M8F@M/G-E=$9E=&-H36]D92A$0E]&151#2$U/1$5?05-33T,I.PH*"B1R97,@
M/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@82`]
M(#$W)RD["G!R:6YT("<Q*2!D96QE=&4Z("<@+B`H)')E<R`]/3T@1$)?3TL@
M/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@HD<F5S(#TF("1D8F@M/G%U
M97)Y*"))3E-%4E0@24Y43R!P:'!T97-T("AA+"!B+"!C*2!604Q515,@*#$W
M+"`G;VYE)RP@)T]N92<I(BD["G!R:6YT("<R*2!I;G-E<G0Z("<@+B`H)')E
M<R`]/3T@1$)?3TL@/R`G;VMA>2<@.B`G97)R;W(G*2`N(")<;B(["@HD<F5S
M(#TF("1D8F@M/G%U97)Y*"=)3E-%4E0@24Y43R!P:'!T97-T("AA+"!B+"!C
M*2!604Q515,@*#\L(#\L(#\I)RP@87)R87DH,3<L("=T=V\G+"`G5'=O)RDI
M.PIP<FEN="`G,RD@:6YS97)T.B`G("X@*"1R97,@/3T]($1"7T]+(#\@)V]K
M87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*"B1R97,@/28@)&1B:"T^<75E<GDH
M)U-%3$5#5"!A+"!B($923TT@<&AP=&5S="!72$5212!A(#T@,3<G*3L*)')O
M=R`]("1R97,M/F9E=&-H4F]W*"D["G!R:6YT("(T*2!A(#T@>R1R;W=;)V$G
M77TL(&(@/2![)')O=ULG8B==?5QN(CL*)')E<RT^9G)E92@I.R`@+R\@:V5E
M<"!F8G-Q;"!H87!P>2X*"B1R97,@/28@)&1B:"T^<75E<GDH)U-%3$5#5"!A
M+"!B($923TT@<&AP=&5S="!72$5212!C(#T@/R<L(&%R<F%Y*"=4=V\G*2D[
M"B1R;W<@/2`D<F5S+3YF971C:%)O=R@I.PIP<FEN="`B-2D@82`]('LD<F]W
M6R=A)UU]+"!B(#T@>R1R;W=;)V(G77U<;B(["@H*)&%R<F%Y(#T@87)R87DH
M"B`@("`G9F]O)R`]/B`Q,2P*("`@("=B87(G(#T^("=T:')E92<L"B`@("`G
M8F%Z)R`]/B!N=6QL+`HI.PHD<F5S(#TF("1D8F@M/G%U97)Y*"=)3E-%4E0@
M24Y43R!P:'!T97-T("AA+"!B+"!D*2!604Q515,@*#\L(#\L(#\I)RP@)&%R
M<F%Y*3L*<')I;G0@)S8I(&EN<V5R=#H@)R`N("@D<F5S(#T]/2!$0E]/2R`_
M("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B:"T^<75E
M<GDH)U-%3$5#5"!A+"!B+"!D($923TT@<&AP=&5S="!72$5212!A(#T@/R<L
M(#$Q*3L*)')O=R`]("1R97,M/F9E=&-H4F]W*"D["G!R:6YT("(W*2!A(#T@
M>R1R;W=;)V$G77TL(&(@/2![)')O=ULG8B==?2P@9"`]("(["FEF("@D9&)H
M+3YP:'!T>7!E(#T]("=M<W%L)RD@>PH@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)V0G+"`D<F]W*2D@>PH@("`@("`@("1T>7!E(#T@9V5T='EP92@D<F]W
M6R=D)UTI.PH@("`@("`@(&EF("@D='EP92`]/2`G3E5,3"<@?'P@)')O=ULG
M9"==(#T]("<G*2!["B`@("`@("`@("`@('!R:6YT(")G;W0@97AP96-T960@
M=F%L=65<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<')I;G0@
M(D524CH@97AP96-T960@9"=S('1Y<&4@=&\@8F4@3E5,3"!B=70@:70G<R`D
M='EP92!A;F0@=&AE('9A;'5E(&ES("(["B`@("`@("`@("`@('!R:6YT("1R
M;W=;)V0G72`N(")<;B(["B`@("`@("`@?0H@("`@?2!E;'-E('L*("`@("`@
M("`O+R!H='1P.B\O8G5G<RYP:'`N;F5T+S]I9#TS,3DV,`H@("`@("`@('!R
M:6YT(")0<FEO<B!T;R!02%`@-"XS+C$Q(&]R(#4N,"XT+"!02%`G<R!M<W%L
M(&5X=&5N<VEO;B!S:6QE;G1L>2(*("`@("`@("`@("`@("`N("(@9')O<'!E
M9"!C;VQU;6YS('=I=&@@;G5L;"!V86QU97,N(%EO=2!N965D('1O('5P9W)A
M9&4N7&XB.PH@("`@?0I](&5L<V4@>PH@("`@)'1Y<&4@/2!G971T>7!E*"1R
M;W=;)V0G72D["B`@("!I9B`H)'1Y<&4@/3T@)TY53$PG('Q\("1R;W=;)V0G
M72`]/2`G)RD@>PH@("`@("`@('!R:6YT(")G;W0@97AP96-T960@=F%L=65<
M;B(["B`@("!](&5L<V4@>PH@("`@("`@('!R:6YT(")%4E(Z(&5X<&5C=&5D
M(&0G<R!T>7!E('1O(&)E($Y53$P@8G5T(&ET)W,@)'1Y<&4@86YD('1H92!V
M86QU92!I<R`B.PH@("`@("`@('!R:6YT("1R;W=;)V0G72`N(")<;B(["B`@
M("!]"GT*"@HD<F5S(#TF("1D8F@M/G%U97)Y*"=$14Q%5$4@1E)/32!P:'!T
M97-T(%=(15)%(&$@/2`_)RP@87)R87DH,3<I*3L*<')I;G0@)S@I(&1E;&5T
M93H@)R`N("@D<F5S(#T]/2!$0E]/2R`_("=O:V%Y)R`Z("=E<G)O<B<I("X@
M(EQN(CL*"B1R97,@/28@)&1B:"T^<75E<GDH)T1%3$5412!&4D]-('!H<'1E
M<W0@5TA%4D4@82`](#\G+"!A<G)A>2@P*2D["G!R:6YT("<Y*2!D96QE=&4@
M=VET:"!A<G)A>2@P*2!A<R!P87)A;3H@)R`N("@D<F5S(#T]/2!$0E]/2R`_
M("=O:V%Y)R`Z("=E<G)O<B<I("X@(EQN(CL*"B1R97,@/28@)&1B:"T^<75E
M<GDH)T1%3$5412!&4D]-('!H<'1E<W0@5TA%4D4@82`](#\G+"`P*3L*<')I
M;G0@)S$P*2!D96QE=&4@=VET:"`P(&%S('!A<F%M.B`G("X@*"1R97,@/3T]
M($1"7T]+(#\@)V]K87DG(#H@)V5R<F]R)RD@+B`B7&XB.PH*"B1D8F@M/G-E
M=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE
M*"1D8F@L("=P:'!T97-T)RD["@H_/@HM+4584$5#5"TM"C$I(&1E;&5T93H@
M;VMA>0HR*2!I;G-E<G0Z(&]K87D*,RD@:6YS97)T.B!O:V%Y"C0I(&$@/2`Q
M-RP@8B`](&]N90HU*2!A(#T@,3<L(&(@/2!T=V\*-BD@:6YS97)T.B!O:V%Y
M"C<I(&$@/2`Q,2P@8B`]('1H<F5E+"!D(#T@9V]T(&5X<&5C=&5D('9A;'5E
M"C@I(&1E;&5T93H@;VMA>0HY*2!D96QE=&4@=VET:"!A<G)A>2@P*2!A<R!P
M87)A;3H@;VMA>0HQ,"D@9&5L971E('=I=&@@,"!A<R!P87)A;3H@;VMA>0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,3AG970N<&AP=```````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#,V-#`U(#$P-3$U-#,T,3,U(#`R-#0P-``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I$0E]D<FEV97(Z.F=E=`HM+4E.22TM"F5R<F]R7W)E<&]R=&EN9R`](#(P
M-#<*+2U32TE0248M+0H\/W!H<`H*+RHJ"B`J($-A;&QS('1H92!G970J*"D@
M;65T:&]D<R!I;B!V87)I;W5S('=A>7,@86=A:6YS="!A;GD@1$)-4RX*("H*
M("H@0'-E92!$0E]#;VUM;VXZ.F=E=$%L;"@I+"!$0E]#;VUM;VXZ.F=E=$%S
M<V]C*"DL($1"7T-O;6UO;CHZ9V5T0V]L*"D*("H@("`@("!$0E]#;VUM;VXZ
M.F=E=$QI<W1/9B@I+"!$0E]#;VUM;VXZ.F=E=$]N92@I+"!$0E]#;VUM;VXZ
M.F=E=%)O=R@I"B`J"B`J($!P86-K86=E("!$0@H@*B!`=F5R<VEO;B`@)$ED
M.B`Q.&=E="YP:'!T+'8@,2XY(#(P,#4O,#(O,30@,C,Z-#<Z-30@9&%N:65L
M8R!%>'`@)`H@*B!`8V%T96=O<GD@1&%T86)A<V4*("H@0&%U=&AO<B`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`86YA;'ES:7-A;F1S;VQU=&EO;G,N
M8V]M/@H@*B!`:6YT97)N86P*("HO"@IC:&1I<BAD:7)N86UE*%]?1DE,15]?
M*2D["G)E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL*"C\^"BTM1DE,12TM
M"CP_<&AP"@HO+R`D260Z(#$X9V5T+G!H<'0L=B`Q+CD@,C`P-2\P,B\Q-"`R
M,SHT-SHU-"!D86YI96QC($5X<"`D"@HO*BH*("H@0V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4@86YD(&UA:V4@=&AE(#QK8F0^<&AP=&5S=#PO:V)D/B!T86)L
M92X*("HO"G)E<75I<F5?;VYC92`G+B]M:W1A8FQE+FEN8R<["@H*+RHJ"B`J
M($QO8V%L(&5R<F]R(&-A;&QB86-K(&AA;F1L97(N"B`J"B`J($1R;W!S('1H
M92!P:'!T97-T('1A8FQE+"!P<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@
M86YD(&MI;&QS('1H90H@*B!P<F]C97-S+@H@*@H@*B!`<&%R86T@;V)J96-T
M("`D;R`@4$5!4B!E<G)O<B!O8FIE8W0@875T;VUA=&EC86QL>2!P87-S960@
M=&\@=&AI<R!M971H;V0*("H@0')E='5R;B!V;VED"B`J($!S964@4$5!4CHZ
M<V5T17)R;W)(86YD;&EN9R@I"B`J+PIF=6YC=&EO;B!P92@D;RE["B`@("!G
M;&]B86P@)&1B:#L*"B`@("`D9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*("`@(&1R;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G
M*3L*"B`@("!D:64H)&\M/G1O4W1R:6YG*"DI.PI]"@HD9&)H+3YS971%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=P92<I.PH*"B1D8F@M
M/G%U97)Y*"))3E-%4E0@24Y43R!P:'!T97-T(%9!3%5%4R`H,BP@)W1W;R<L
M("=4=V\G+"`G,C`P,BTP,BTR,B<I(BD["B1D8F@M/G%U97)Y*"))3E-%4E0@
M24Y43R!P:'!T97-T(%9!3%5%4R`H-#(L("=T:')E92<L("=4:')E92<L("<R
M,#`S+3`S+3(S)RDB*3L*"@IP<FEN="`B/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN="`G=&5S
M=&EN9R!G971/;F4Z("<["B1R970@/28@)&1B:"T^9V5T3VYE*")314Q%0U0@
M*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`]("=4=V\G(BD["G!R:6YT7W(H)')E
M="D["G!R:6YT(")<;B(["@IP<FEN="`G=&5S=&EN9R!G971/;F4@=VET:"!S
M=')I;F<@<&%R86US.B`G.PHD<F5T(#TF("1D8F@M/F=E=$]N92@G4T5,14-4
M("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`_)RP@)U1H<F5E)RD["G!R:6YT
M7W(H)')E="D["G!R:6YT(")<;B(["@IP<FEN="`G=&5S=&EN9R!G971/;F4@
M=VET:"!A<G)A>2!P87)A;7,Z("<["B1R970@/28@)&1B:"T^9V5T3VYE*"=3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@8R`](#\G+"!A<G)A>2@G5'=O
M)RDI.PIP<FEN=%]R*"1R970I.PIP<FEN="`B7&XB.PH*<')I;G0@(EQN/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]7&XB.PIP<FEN="`B=&5S=&EN9R!G9712;W<Z7&XB.PHD<F5T(#TF("1D
M8F@M/F=E=%)O=R@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G
M5'=O)R(I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T4F]W
M('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*
M)')E="`])B`D9&)H+3YG9712;W<H(E-%3$5#5"`J($923TT@<&AP=&5S="!7
M2$5212!C(#T@)U1W;R<B+`H@("`@("`@(&YU;&PL($1"7T9%5$-(34]$15]/
M4D1%4D5$*3L*<')I;G1?<B@D<F5T*3L*"B\O(%1(25,@1$]%4TXG5"!73U)+
M($1512!43R!"04-+5T%21%,@0T]-4$%424))3$E462!#4D%0"B\O('!R:6YT
M(")T97-T:6YG(&=E=%)O=R!W:71H('-T<FEN9R!P87)A;7,L($1"7T9%5$-(
M34]$15]/4D1%4D5$.EQN(CL*+R\@)')E="`])B`D9&)H+3YG9712;W<H)U-%
M3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L"B\O("`@("`@("`@
M)U1W;R<L($1"7T9%5$-(34]$15]/4D1%4D5$*3L*+R\@<')I;G1?<B@D<F5T
M*3L*+R\*+R\@=&5S=&EN9R!G9712;W<@=VET:"!S=')I;F<@<&%R86US+"!$
M0E]&151#2$U/1$5?3U)$15)%1#H*+R\@07)R87D*+R\@*`HO+R`@("`@6S!=
M(#T^(#(*+R\@("`@(%LQ72`]/B!T=V\*+R\@("`@(%LR72`]/B!4=V\*+R\@
M("`@(%LS72`]/B`R,#`R+3`R+3(R"B\O("D*"B`@('!R:6YT(")T97-T:6YG
M(&=E=%)O=R!W:71H(%)%5D524T5$(&%R9W,Z($1"7T9%5$-(34]$15]!4U-/
M0RP@87)R87D@<&%R86US.EQN(CL*("`@)')E="`])B`D9&)H+3YG9712;W<H
M)U-%3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R<L"B`@("`@("`@
M("`@1$)?1D540TA-3T1%7T%34T]#+"!A<G)A>2@G5'=O)RDI.PH@("!P<FEN
M=%]R*"1R970I.PH@("`*("`@<')I;G0@(G1E<W1I;F<@9V5T4F]W('=I=&@@
M4D5615)3140@87)G<SH@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*("`@)')E
M="`])B`D9&)H+3YG9712;W<H(E-%3$5#5"`J($923TT@<&AP=&5S="!72$52
M12!C(#T@)U1W;R<B+`H@("`@("`@("`@($1"7T9%5$-(34]$15]!4U-/0RD[
M"B`@('!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G9712;W<@=VET
M:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0SI<;B(["B1R970@
M/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@
M8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4=V\G*2P@1$)?1D540TA-3T1%7T%3
M4T]#*3L*<')I;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=%)O=R!W
M:71H(&%R<F%Y('!A<F%M<RP@1$)?1D540TA-3T1%7T]"2D5#5#I<;B(["B1R
M970@/28@)&1B:"T^9V5T4F]W*"=314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%
M4D4@8R`](#\G+`H@("`@("`@(&%R<F%Y*"=4=V\G*2P@1$)?1D540TA-3T1%
M7T]"2D5#5"D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB
M.PIP<FEN="`B=&5S=&EN9R!G971#;VPZ7&XB.PHD<F5T(#TF("1D8F@M/F=E
M=$-O;"@B4T5,14-4("H@1E)/32!P:'!T97-T($]21$52($)9(&(B*3L*<')I
M;G1?<B@D<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O;"!O;B!Q=65R>2!W
M:71H(&YO(')E8V]R9',Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$-O;"@G4T5,
M14-4("H@1E)/32!P:'!T97-T(%=(15)%(&$@/B`R,#`G*3L*<')I;G1?<B@D
M<F5T*3L*"G!R:6YT(")T97-T:6YG(&=E=$-O;"!W:71H(&EN=F%L:60@8V]L
M=6UN(&ED.EQN(CL*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD["B1R970@/28@)&1B:"T^9V5T0V]L*"=314Q%0U0@8B!&4D]-
M('!H<'1E<W0@3U)$15(@0ED@8B<L(#$I.PII9B`H1$(Z.FES17)R;W(H)')E
M="DI('L*("`@(&5C:&\@)')E="T^9V5T365S<V%G92@I("X@(EQN(CL*?2!E
M;'-E('L*("`@('!R:6YT("(^/B!3:&]U;&0@:&%V92!P<F]D=6-E9"`G;F\@
M<W5C:"!F:65L9"<@97)R;W)<;B(["GT*)&1B:"T^<V5T17)R;W)(86YD;&EN
M9RA014%27T524D]27T-!3$Q"04-++"`G<&4G*3L*"G!R:6YT(")T97-T:6YG
M(&=E=$-O;"!W:71H(#$@8V]L.EQN(CL*)')E="`])B`D9&)H+3YG971#;VPH
M(E-%3$5#5"`J($923TT@<&AP=&5S="!/4D1%4B!"62!B(BP@,2D["G!R:6YT
M7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971#;VP@=VET:"!B(&-O;#I<
M;B(["B1R970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E
M<W0@3U)$15(@0ED@8B(L("=B)RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B
M=&5S=&EN9R!G971#;VP@=VET:"!B(&-O;"P@<V-A;&%R('!A<F%M<SI<;B([
M"B1R970@/28@)&1B:"T^9V5T0V]L*")314Q%0U0@*B!&4D]-('!H<'1E<W0@
M5TA%4D4@82`\(#\@3U)$15(@0ED@8B(L"B`@("`@("`@)V(G+"`Q,#`I.PIP
M<FEN=%]R*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T0V]L('=I=&@@8B!C
M;VPL(&%R<F%Y('!A<F%M<SI<;B(["B1R970@/28@)&1B:"T^9V5T0V]L*")3
M14Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B(L
M"B`@("`@("`@)V(G+"!A<G)A>2@Q,#`I*3L*<')I;G1?<B@D<F5T*3L*"@IP
M<FEN="`B7&X]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3U<;B(["G!R:6YT(")T97-T:6YG(&=E=$%S<V]C.EQN
M(CL*)')E="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(L(&,@1E)/
M32!P:'!T97-T(%=(15)%(&$@/"`Q,#`@3U)$15(@0ED@8B<I.PIP<FEN=%]R
M*"1R970I.PH*<')I;G0@(G1E<W1I;F<@9V5T07-S;V,@=VET:"!F86QS92!F
M;W)C92P@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*
M)')E="`])B`D9&)H+3YG971!<W-O8R@B4T5,14-4(&$L(&(L(&,@1E)/32!P
M:'!T97-T(%=(15)%(&$@/"`Q,#`@3U)$15(@0ED@8B(L"B`@("`@("`@("`@
M("`@("`@("`@("`@(&9A;'-E+"!N=6QL+"!$0E]&151#2$U/1$5?3U)$15)%
M1"D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W
M:71H(&9A;'-E(&9O<F-E+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?
M05-33T,Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@
M8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@
M("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"`Q,#`L($1"7T9%5$-(34]$
M15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G971!
M<W-O8R!W:71H('1W;R!C;VQS+"!F86QS92!F;W)C92P@<V-A;&%R('!A<F%M
M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!
M<W-O8R@G4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(15)%(&$@/"`_($]2
M1$52($)9(&(G+`H@("`@("`@("`@("`@("`@("`@("`@("!F86QS92P@,3`P
M+"!$0E]&151#2$U/1$5?05-33T,I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@
M(G1E<W1I;F<@9V5T07-S;V,@=VET:"!T=V\@8V]L<RP@=')U92!F;W)C92P@
M<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`]
M)B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(@1E)/32!P:'!T97-T(%=(
M15)%(&$@/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@("`@("`@("`@
M("!T<G5E+"`Q,#`L($1"7T9%5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E
M="D["@IP<FEN="`B=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E
M+"!S8V%L87(@<&%R86US+"!$0E]&151#2$U/1$5?05-33T,L('1R=64@9W)O
M=7`Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=314Q%0U0@82P@8BP@
M8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@0ED@8B<L"B`@("`@
M("`@("`@("`@("`@("`@("`@(&9A;'-E+"`Q,#`L($1"7T9%5$-(34]$15]!
M4U-/0RP@=')U92D["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN9R!G
M971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!A<G)A>2!P87)A;7,L($1"7T9%
M5$-(34]$15]/0DI%0U0Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%S<V]C*"=3
M14Q%0U0@82P@8BP@8R!&4D]-('!H<'1E<W0@5TA%4D4@82`\(#\@3U)$15(@
M0ED@8B<L"B`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+"!A<G)A>2@Q
M,#`I+"!$0E]&151#2$U/1$5?3T)*14-4*3L*<')I;G1?<B@D<F5T*3L*"G!R
M:6YT(")T97-T:6YG(&=E=$%S<V]C('=I=&@@=')U92!F;W)C92P@87)R87D@
M<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4+"!T<G5E(&=R;W5P.EQN(CL*
M)')E="`])B`D9&)H+3YG971!<W-O8R@G4T5,14-4(&$L(&(L(&,@1E)/32!P
M:'!T97-T(%=(15)%(&$@/"`_($]21$52($)9(&(G+`H@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92P@87)R87DH,3`P*2P@1$)?1D540TA-3T1%7T]"
M2D5#5"P@=')U92D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M7&XB.PIP<FEN="`B=&5S=&EN9R!G971!;&PZ7&XB.PHD<F5T(#TF("1D8F@M
M/F=E=$%L;"@B4T5,14-4("H@1E)/32!P:'!T97-T(%=(15)%(&,@/2`G5'=O
M)R!/4B!C(#T@)U1H<F5E)R(I.PIP<FEN=%]R*"1R970I.PH*<')I;G0@(G1E
M<W1I;F<@9V5T06QL('=I=&@@;G5L;"!P87)A;7,L($1"7T9%5$-(34]$15]/
M4D1%4D5$.EQN(CL*)')E="`])B`D9&)H+3YG971!;&PH(E-%3$5#5"`J($92
M3TT@<&AP=&5S="!72$5212!C(#T@)U1W;R<@3U(@8R`]("=4:')E92<B+`H@
M("`@("`@(&YU;&PL($1"7T9%5$-(34]$15]/4D1%4D5$*3L*<')I;G1?<B@D
M<F5T*3L*"B\O(%1(25,@1$]%4TXG5"!73U)+($1512!43R!"04-+5T%21%,@
M0T]-4$%424))3$E462!#4D%0"B\O('!R:6YT(")T97-T:6YG(&=E=$%L;"!W
M:71H('-T<FEN9R!P87)A;7,L($1"7T9%5$-(34]$15]/4D1%4D5$.EQN(CL*
M+R\@)')E="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP=&5S
M="!72$5212!C(#T@/R<L"B\O("`@("`@("`@)U1W;R<L($1"7T9%5$-(34]$
M15]/4D1%4D5$*3L*+R\@<')I;G1?<B@D<F5T*3L*+R\*+R\@=&5S=&EN9R!G
M971!;&P@=VET:"!S=')I;F<@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%
M1#H*+R\@07)R87D*+R\@*`HO+R`@("`@6S!=(#T^(#(*+R\@("`@(%LQ72`]
M/B!T=V\*+R\@("`@(%LR72`]/B!4=V\*+R\@("`@(%LS72`]/B`R,#`R+3`R
M+3(R"B\O("D*"B`@('!R:6YT(")T97-T:6YG(&=E=$%L;"!W:71H(%)%5D52
M4T5$(&%R9W,Z($1"7T9%5$-(34]$15]!4U-/0RP@87)R87D@<&%R86US.EQN
M(CL*("`@)')E="`])B`D9&)H+3YG971!;&PH)U-%3$5#5"`J($923TT@<&AP
M=&5S="!72$5212!C(#T@/R!/4B!C(#T@/R!/4D1%4B!"62!C)RP*("`@("`@
M("`@("!$0E]&151#2$U/1$5?05-33T,L(&%R<F%Y*"=4=V\G+"`G5&AR964G
M*2D["B`@('!R:6YT7W(H)')E="D["B`@(`H@("!P<FEN="`B=&5S=&EN9R!G
M971!;&P@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z
M7&XB.PH@("`D<F5T(#TF("1D8F@M/F=E=$%L;"@B4T5,14-4("H@1E)/32!P
M:'!T97-T(%=(15)%(&,@/2`G5'=O)R!/4B!C(#T@)U1H<F5E)R(L"B`@("`@
M("`@("`@1$)?1D540TA-3T1%7T%34T]#*3L*("`@<')I;G1?<B@D<F5T*3L*
M"G!R:6YT(")T97-T:6YG(&=E=$%L;"!W:71H(&%R<F%Y('!A<F%M<RP@1$)?
M1D540TA-3T1%7T%34T]#.EQN(CL*)')E="`])B`D9&)H+3YG971!;&PH)U-%
M3$5#5"`J($923TT@<&AP=&5S="!72$5212!C(#T@/R!/4B!C(#T@/R!/4D1%
M4B!"62!C)RP*("`@("`@("!A<G)A>2@G5'=O)RP@)U1H<F5E)RDL($1"7T9%
M5$-(34]$15]!4U-/0RD["G!R:6YT7W(H)')E="D["@IP<FEN="`B=&5S=&EN
M9R!G971!;&P@=VET:"!A<G)A>2!P87)A;7,L($1"7T9%5$-(34]$15]/0DI%
M0U0Z7&XB.PHD<F5T(#TF("1D8F@M/F=E=$%L;"@G4T5,14-4("H@1E)/32!P
M:'!T97-T(%=(15)%(&,@/2`_($]2(&,@/2`_($]21$52($)9(&,G+`H@("`@
M("`@(&%R<F%Y*"=4=V\G+"`G5&AR964G*2P@1$)?1D540TA-3T1%7T]"2D5#
M5"D["G!R:6YT7W(H)')E="D["@H*<')I;G0@(EQN/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]7&XB.PIP<FEN
M="`G=&5S=&EN9R!G971/;F4@=VET:"!N=6QL('9A;'5E(&EN(&-O;'5M;CH@
M)SL*)&1B:"T^<75E<GDH(DE.4T525"!)3E1/('!H<'1E<W0@5D%,5453("@Y
M+"`G;FEN92<L("<G+"!.54Q,*2(I.PHD<F5T(#TF("1D8F@M/F=E=$]N92@G
M4T5,14-4(&0@1E)/32!P:'!T97-T(%=(15)%(&$@/2`Y)RD["FEF("@D<F5T
M(#T]/2`G)RD@>PH@("`@<')I;G0@(FUA=&-H97,@97AP96-T960@<F5S=6QT
M7&XB.PI](&5L<V4@>PH@("`@:68@*"1D8F@M/G!H<'1Y<&4@/3T@)VUS<6PG
M*2!["B`@("`@("`@:68@*&=E='1Y<&4H)')E="D@/3T@)TY53$PG*2!["B`@
M("`@("`@("`@("\O(&US<6P@9&]E<VXG="!E=F5N(')E='5R;B!T:&4@8V]L
M=6UN+B`@2F]Y(2`Z*0H@("`@("`@("`@("`O+R!H='1P.B\O8G5G<RYP:'`N
M;F5T+S]I9#TS,3DV,`H@("`@("`@("`@("!P<FEN="`B;6%T8VAE<R!E>'!E
M8W1E9"!R97-U;'1<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M<')I;G0@(E=/5RP@;5-13"!N;W<@<F5T=7)N<R!C;VQU;6YS('1H870@:&%V
M92!.54Q,4R!I;B!T:&5M7&XB.PH@("`@("`@('T*("`@('T@96QS92!["B`@
M("`@("`@<')I;G0@)W1Y<&4])R`N(&=E='1Y<&4H)')E="D@+B`B+"!V86QU
M93TD<F5T7&XB.PH@("`@?0I]"@IP<FEN="`G=&5S=&EN9R!G971/;F4@=VET
M:"!E;7!T>2!S=')I;F<@:6X@8V]L=6UN.B`G.PHD<F5T(#TF("1D8F@M/F=E
M=$]N92@G4T5,14-4(&,@1E)/32!P:'!T97-T(%=(15)%(&$@/2`Y)RD["FEF
M("@D<F5T(#T]/2`G)RD@>PH@("`@<')I;G0@(F5M<'1Y('-T<FEN9UQN(CL*
M?2!E;'-E('L*("`@('!R:6YT("=T>7!E/2<@+B!G971T>7!E*"1R970I("X@
M(BP@=F%L=64])')E=%QN(CL*?0H*"G!R:6YT(")<;CT]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/5QN(CL*"@ID
M<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T)RD["@H*/SX*+2U%6%!%0U0M+0H]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T*=&5S=&EN9R!G971/;F4Z(#(*=&5S=&EN9R!G971/;F4@=VET:"!S
M=')I;F<@<&%R86US.B`T,@IT97-T:6YG(&=E=$]N92!W:71H(&%R<F%Y('!A
M<F%M<SH@,@H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@9V5T4F]W.@I!<G)A>0HH"B`@("!;
M,%T@/3X@,@H@("`@6S%=(#T^('1W;PH@("`@6S)=(#T^(%1W;PH@("`@6S-=
M(#T^(#(P,#(M,#(M,C(**0IT97-T:6YG(&=E=%)O=R!W:71H(&YU;&P@<&%R
M86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*07)R87D**`H@("`@6S!=(#T^
M(#(*("`@(%LQ72`]/B!T=V\*("`@(%LR72`]/B!4=V\*("`@(%LS72`]/B`R
M,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!2159%4E-%1"!A<F=S
M.B!$0E]&151#2$U/1$5?05-33T,L(&%R<F%Y('!A<F%M<SH*07)R87D**`H@
M("`@6V%=(#T^(#(*("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@
M(%MD72`]/B`R,#`R+3`R+3(R"BD*=&5S=&EN9R!G9712;W<@=VET:"!2159%
M4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%MA
M72`]/B`R"B`@("!;8ET@/3X@='=O"B`@("!;8UT@/3X@5'=O"B`@("!;9%T@
M/3X@,C`P,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W('=I=&@@87)R87D@<&%R
M86US+"!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%MA72`]/B`R
M"B`@("!;8ET@/3X@='=O"B`@("!;8UT@/3X@5'=O"B`@("!;9%T@/3X@,C`P
M,BTP,BTR,@HI"G1E<W1I;F<@9V5T4F]W('=I=&@@87)R87D@<&%R86US+"!$
M0E]&151#2$U/1$5?3T)*14-4.@IS=&1#;&%S<R!/8FIE8W0**`H@("`@6V%=
M(#T^(#(*("`@(%MB72`]/B!T=V\*("`@(%MC72`]/B!4=V\*("`@(%MD72`]
M/B`R,#`R+3`R+3(R"BD*"CT]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0IT97-T:6YG(&=E=$-O;#H*07)R87D*
M*`H@("`@6S!=(#T^(#0R"B`@("!;,5T@/3X@-#(*("`@(%LR72`]/B`R"BD*
M=&5S=&EN9R!G971#;VP@;VX@<75E<GD@=VET:"!N;R!R96-O<F1S.@I!<G)A
M>0HH"BD*=&5S=&EN9R!G971#;VP@=VET:"!I;G9A;&ED(&-O;'5M;B!I9#H*
M1$(@17)R;W(Z(&YO('-U8V@@9FEE;&0*=&5S=&EN9R!G971#;VP@=VET:"`Q
M(&-O;#H*07)R87D**`H@("`@6S!=(#T^(&)I;F<*("`@(%LQ72`]/B!T:')E
M90H@("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@9V5T0V]L('=I=&@@8B!C;VPZ
M"D%R<F%Y"B@*("`@(%LP72`]/B!B:6YG"B`@("!;,5T@/3X@=&AR964*("`@
M(%LR72`]/B!T=V\**0IT97-T:6YG(&=E=$-O;"!W:71H(&(@8V]L+"!S8V%L
M87(@<&%R86US.@I!<G)A>0HH"B`@("!;,%T@/3X@8FEN9PH@("`@6S%=(#T^
M('1H<F5E"B`@("!;,ET@/3X@='=O"BD*=&5S=&EN9R!G971#;VP@=VET:"!B
M(&-O;"P@87)R87D@<&%R86US.@I!<G)A>0HH"B`@("!;,%T@/3X@8FEN9PH@
M("`@6S%=(#T^('1H<F5E"B`@("!;,ET@/3X@='=O"BD*"CT]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0IT97-T
M:6YG(&=E=$%S<V]C.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;,%T@/3X@=&AR964*("`@("`@("`@("`@6S%=
M(#T^(%1H<F5E"B`@("`@("`@*0H*("`@(%LR72`]/B!!<G)A>0H@("`@("`@
M("@*("`@("`@("`@("`@6S!=(#T^('1W;PH@("`@("`@("`@("!;,5T@/3X@
M5'=O"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@
M9F]R8V4L(&YU;&P@<&%R86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*07)R
M87D**`H@("`@6S0R72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@
M6S!=(#T^('1H<F5E"B`@("`@("`@("`@(%LQ72`]/B!4:')E90H@("`@("`@
M("D*"B`@("!;,ET@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%LP
M72`]/B!T=V\*("`@("`@("`@("`@6S%=(#T^(%1W;PH@("`@("`@("D*"BD*
M=&5S=&EN9R!G971!<W-O8R!W:71H(&9A;'-E(&9O<F-E+"!S8V%L87(@<&%R
M86US+"!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LT,ET@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@
M("`@("`@("!;8UT@/3X@5&AR964*("`@("`@("`I"@H@("`@6S)=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@
M("`@(%MC72`]/B!4=V\*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@
M=VET:"!T=V\@8V]L<RP@9F%L<V4@9F]R8V4L('-C86QA<B!P87)A;7,L($1"
M7T9%5$-(34]$15]!4U-/0SH*07)R87D**`H@("`@6S0R72`]/B!T:')E90H@
M("`@6S)=(#T^('1W;PHI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!T=V\@8V]L
M<RP@=')U92!F;W)C92P@<V-A;&%R('!A<F%M<RP@1$)?1D540TA-3T1%7T%3
M4T]#.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@("`@*`H@("`@
M("`@("`@("!;8ET@/3X@=&AR964*("`@("`@("`I"@H@("`@6S)=(#T^($%R
M<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@
M*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@9F%L<V4@9F]R8V4L('-C86QA
M<B!P87)A;7,L($1"7T9%5$-(34]$15]!4U-/0RP@=')U92!G<F]U<#H*07)R
M87D**`H@("`@6S0R72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@
M6S!=(#T^($%R<F%Y"B`@("`@("`@("`@("`@("`H"B`@("`@("`@("`@("`@
M("`@("`@6V)=(#T^(&)I;F<*("`@("`@("`@("`@("`@("`@("!;8UT@/3X@
M5&AI<R!I<R!A('1E<W0*("`@("`@("`@("`@("`@("D*"B`@("`@("`@("`@
M(%LQ72`]/B!!<G)A>0H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@("`@
M("`@("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("`@("`@("`@(%MC72`]
M/B!4:')E90H@("`@("`@("`@("`@("`@*0H*("`@("`@("`I"@H@("`@6S)=
M(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@07)R87D*
M("`@("`@("`@("`@("`@("@*("`@("`@("`@("`@("`@("`@("!;8ET@/3X@
M='=O"B`@("`@("`@("`@("`@("`@("`@6V-=(#T^(%1W;PH@("`@("`@("`@
M("`@("`@*0H*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T07-S;V,@=VET:"!F
M86QS92!F;W)C92P@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4
M.@I!<G)A>0HH"B`@("!;-#)=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@
M("@*("`@("`@("`@("`@6V%=(#T^(#0R"B`@("`@("`@("`@(%MB72`]/B!T
M:')E90H@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@("`@("`I"@H@("`@
M6S)=(#T^('-T9$-L87-S($]B:F5C=`H@("`@("`@("@*("`@("`@("`@("`@
M6V%=(#T^(#(*("`@("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@("!;
M8UT@/3X@5'=O"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%S<V]C('=I=&@@
M=')U92!F;W)C92P@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*14-4
M+"!T<G5E(&=R;W5P.@I!<G)A>0HH"B`@("!;-#)=(#T^($%R<F%Y"B`@("`@
M("`@*`H@("`@("`@("`@("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@
M("`@("`@("`@("`H"B`@("`@("`@("`@("`@("`@("`@6V%=(#T^(#0R"B`@
M("`@("`@("`@("`@("`@("`@6V)=(#T^(&)I;F<*("`@("`@("`@("`@("`@
M("`@("!;8UT@/3X@5&AI<R!I<R!A('1E<W0*("`@("`@("`@("`@("`@("D*
M"B`@("`@("`@("`@(%LQ72`]/B!S=&1#;&%S<R!/8FIE8W0*("`@("`@("`@
M("`@("`@("@*("`@("`@("`@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@
M("`@("`@("`@("`@("!;8ET@/3X@=&AR964*("`@("`@("`@("`@("`@("`@
M("!;8UT@/3X@5&AR964*("`@("`@("`@("`@("`@("D*"B`@("`@("`@*0H*
M("`@(%LR72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6S!=(#T^
M('-T9$-L87-S($]B:F5C=`H@("`@("`@("`@("`@("`@*`H@("`@("`@("`@
M("`@("`@("`@(%MA72`]/B`R"B`@("`@("`@("`@("`@("`@("`@6V)=(#T^
M('1W;PH@("`@("`@("`@("`@("`@("`@(%MC72`]/B!4=V\*("`@("`@("`@
M("`@("`@("D*"B`@("`@("`@*0H**0H*/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]"G1E<W1I;F<@9V5T06QL
M.@I!<G)A>0HH"B`@("!;,%T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%LP72`]/B`R"B`@("`@("`@("`@(%LQ72`]/B!T=V\*("`@("`@("`@
M("`@6S)=(#T^(%1W;PH@("`@("`@("`@("!;,UT@/3X@,C`P,BTP,BTR,@H@
M("`@("`@("D*"B`@("!;,5T@/3X@07)R87D*("`@("`@("`H"B`@("`@("`@
M("`@(%LP72`]/B`T,@H@("`@("`@("`@("!;,5T@/3X@=&AR964*("`@("`@
M("`@("`@6S)=(#T^(%1H<F5E"B`@("`@("`@("`@(%LS72`]/B`R,#`S+3`S
M+3(S"B`@("`@("`@*0H**0IT97-T:6YG(&=E=$%L;"!W:71H(&YU;&P@<&%R
M86US+"!$0E]&151#2$U/1$5?3U)$15)%1#H*07)R87D**`H@("`@6S!=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@,@H@("`@("`@
M("`@("!;,5T@/3X@='=O"B`@("`@("`@("`@(%LR72`]/B!4=V\*("`@("`@
M("`@("`@6S-=(#T^(#(P,#(M,#(M,C(*("`@("`@("`I"@H@("`@6S%=(#T^
M($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;,%T@/3X@-#(*("`@("`@
M("`@("`@6S%=(#T^('1H<F5E"B`@("`@("`@("`@(%LR72`]/B!4:')E90H@
M("`@("`@("`@("!;,UT@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"BD*=&5S
M=&EN9R!G971!;&P@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?
M05-33T,L(&%R<F%Y('!A<F%M<SH*07)R87D**`H@("`@6S!=(#T^($%R<F%Y
M"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@
M6V)=(#T^('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@
M("`@("!;9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"B`@("!;,5T@/3X@
M07)R87D*("`@("`@("`H"B`@("`@("`@("`@(%MA72`]/B`R"B`@("`@("`@
M("`@(%MB72`]/B!T=V\*("`@("`@("`@("`@6V-=(#T^(%1W;PH@("`@("`@
M("`@("!;9%T@/3X@,C`P,BTP,BTR,@H@("`@("`@("D*"BD*=&5S=&EN9R!G
M971!;&P@=VET:"!2159%4E-%1"!A<F=S.B!$0E]&151#2$U/1$5?05-33T,Z
M"D%R<F%Y"B@*("`@(%LP72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6V%=(#T^(#(*("`@("`@("`@("`@6V)=(#T^('1W;PH@("`@("`@("`@
M("!;8UT@/3X@5'=O"B`@("`@("`@("`@(%MD72`]/B`R,#`R+3`R+3(R"B`@
M("`@("`@*0H*("`@(%LQ72`]/B!!<G)A>0H@("`@("`@("@*("`@("`@("`@
M("`@6V%=(#T^(#0R"B`@("`@("`@("`@(%MB72`]/B!T:')E90H@("`@("`@
M("`@("!;8UT@/3X@5&AR964*("`@("`@("`@("`@6V1=(#T^(#(P,#,M,#,M
M,C,*("`@("`@("`I"@HI"G1E<W1I;F<@9V5T06QL('=I=&@@87)R87D@<&%R
M86US+"!$0E]&151#2$U/1$5?05-33T,Z"D%R<F%Y"B@*("`@(%LP72`]/B!!
M<G)A>0H@("`@("`@("@*("`@("`@("`@("`@6V%=(#T^(#0R"B`@("`@("`@
M("`@(%MB72`]/B!T:')E90H@("`@("`@("`@("!;8UT@/3X@5&AR964*("`@
M("`@("`@("`@6V1=(#T^(#(P,#,M,#,M,C,*("`@("`@("`I"@H@("`@6S%=
M(#T^($%R<F%Y"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@,@H@("`@
M("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@
M("`@("`@("`@6V1=(#T^(#(P,#(M,#(M,C(*("`@("`@("`I"@HI"G1E<W1I
M;F<@9V5T06QL('=I=&@@87)R87D@<&%R86US+"!$0E]&151#2$U/1$5?3T)*
M14-4.@I!<G)A>0HH"B`@("!;,%T@/3X@<W1D0VQA<W,@3V)J96-T"B`@("`@
M("`@*`H@("`@("`@("`@("!;85T@/3X@-#(*("`@("`@("`@("`@6V)=(#T^
M('1H<F5E"B`@("`@("`@("`@(%MC72`]/B!4:')E90H@("`@("`@("`@("!;
M9%T@/3X@,C`P,RTP,RTR,PH@("`@("`@("D*"B`@("!;,5T@/3X@<W1D0VQA
M<W,@3V)J96-T"B`@("`@("`@*`H@("`@("`@("`@("!;85T@/3X@,@H@("`@
M("`@("`@("!;8ET@/3X@='=O"B`@("`@("`@("`@(%MC72`]/B!4=V\*("`@
M("`@("`@("`@6V1=(#T^(#(P,#(M,#(M,C(*("`@("`@("`I"@HI"@H]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T*=&5S=&EN9R!G971/;F4@=VET:"!N=6QL('9A;'5E(&EN(&-O;'5M;CH@
M;6%T8VAE<R!E>'!E8W1E9"!R97-U;'0*=&5S=&EN9R!G971/;F4@=VET:"!E
M;7!T>2!S=')I;F<@:6X@8V]L=6UN.B!E;7!T>2!S=')I;F<*"CT]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R+S$Y9V5T;&ES=&]F+G!H
M<'0````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C$W,B`Q,#4Q-30S-#$S-2`P,C4V,C4`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````+2U4
M15-4+2T*1$)?9')I=F5R.CIG971,:7-T3V8*+2U)3DDM+0IE<G)O<E]R97!O
M<G1I;F<@/2`R,#0W"BTM4TM)4$E&+2T*/#]P:'`@8VAD:7(H9&ER;F%M92A?
M7T9)3$5?7RDI.R!R97%U:7)E7V]N8V4@)RXO<VMI<&EF+FEN8R<[(#\^"BTM
M1DE,12TM"CP_<&AP"@IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PH*
M+RH*("H@06X@87)R87D@=VET:"!K97ES(&-O;G1A:6YI;F<@=&AE("1T>7!E
M('1O(&)E('!A<W-E9"!T;R!T:&4@9V5T3&ES=$]F*"D*("H@;65T:&]D+B`@
M5&AE('9A;'5E<R!O9B!T:&4@;6%I;B!A<G)A>2!A<F4@82!S=6(M87)R87D@
M=&AA="!H87,@:V5Y<PH@*B!L:7-T:6YG('1H92!P:'!T>7!E(&%N9"!D8G-Y
M;G1A>"!O9B!E86-H(&1R:79E<B!A;F0@=F%L=65S(&]F('1H90H@*B!R97-U
M;'0@97AP96-T960@9G)O;2!T:&4@8V]M8FEN871I;VX@;V8@86QL('1H97-E
M(&9A8W1O<G,N"B`J+PHD=&5S=',@/2!A<G)A>2@*("`@("=T86)L97,G(#T^
M(&%R<F%Y*`H@("`@("`@("=D8F%S93ID8F%S92<@/3X@1$)?15)23U)?54Y3
M55!03U)4140L"B`@("`@("`@)V9B<W%L.F9B<W%L)R`]/B`G87)R87DG+`H@
M("`@("`@("=I8F%S93II8F%S92<@/3X@)V%R<F%Y)RP*("`@("`@("`G:6)A
M<V4Z9FER96)I<F0G(#T^("=A<G)A>2<L"B`@("`@("`@)VEF>#II9G@G(#T^
M("=A<G)A>2<L"B`@("`@("`@)VUS<6PZ;7-Q;"<@/3X@)V%R<F%Y)RP*("`@
M("`@("`G;7-S<6PZ;7-S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L
M.FUY<W%L)R`]/B`G87)R87DG+`H@("`@("`@("=M>7-Q;&DZ;7ES<6QI)R`]
M/B`G87)R87DG+`H@("`@("`@("=O8VDX.F]C:3@G(#T^("=A<G)A>2<L"B`@
M("`@("`@)V]D8F,Z86-C97-S)R`]/B`G87)R87DG+`H@("`@("`@("=O9&)C
M.F1B,B<@/3X@)V%R<F%Y)RP*("`@("`@("`G<&=S<6PZ<&=S<6PG(#T^("=A
M<G)A>2<L"B`@("`@("`@)W-Q;&ET93IS<6QI=&4G(#T^("=A<G)A>2<L"B`@
M("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^("=A<G)A>2<L"B`@("`I+`H@("`@
M)W9I97=S)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^("=A<G)A>2<L"B`@
M("`@("`@)VEB87-E.F9I<F5B:7)D)R`]/B`G87)R87DG+`H@("`@("`@("=I
M9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-Q
M;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-S
M<6PZ;7-S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]
M/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L
M:2<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I
M."<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C
M97-S)R`]/B`G87)R87DG+`H@("`@("`@("=O9&)C.F1B,B<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G<&=S<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@
M)W-Q;&ET93IS<6QI=&4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=S>6)A<V4Z<WEB87-E)R`]/B`G87)R87DG+`H@("`@*2P*("`@("=U
M<V5R<R<@/3X@87)R87DH"B`@("`@("`@)V1B87-E.F1B87-E)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G9F)S<6PZ9F)S<6PG(#T^("=A
M<G)A>2<L"B`@("`@("`@)VEB87-E.FEB87-E)R`]/B`G87)R87DG+`H@("`@
M("`@("=I8F%S93IF:7)E8FER9"<@/3X@)V%R<F%Y)RP*("`@("`@("`G:69X
M.FEF>"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUS<6PZ
M;7-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VUS<W%L
M.FUS<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES
M<6PZ;7ES<6PG(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@
M("`@)VUY<W%L:3IM>7-Q;&DG(#T^($1"7T524D]27T%#0T534U]624],051)
M3TXL"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?54Y355!03U)4
M140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B!$0E]%4E)/4E]53E-54%!/
M4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y)RP*("`@("`@
M("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@
M("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@*2P*("`@("=D871A8F%S97,G(#T^(&%R<F%Y*`H@("`@("`@("=D
M8F%S93ID8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)V9B<W%L.F9B<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@
M("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?15)23U)?54Y355!03U)4140L
M"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@
M("`@("`@("=M<W%L.FUS<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUS<W%L
M.FUS<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES
M<6PZ;7ES<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)VUY<W%L:3IM>7-Q;&DG
M(#T^("=A<G)A>2<L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B`G87)R87DG
M+`H@("`@("`@("=O9&)C.F1B,B<@/3X@)V%R<F%Y)RP*("`@("`@("`G<&=S
M<6PZ<&=S<6PG(#T^("=A<G)A>2<L"B`@("`@("`@)W-Q;&ET93IS<6QI=&4G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=S>6)A<V4Z<WEB
M87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("DL"B`@("`G9G5N
M8W1I;VYS)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M<W%L.FUS<6PG(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M<W-Q;#IM<W-Q;"<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]/B!$0E]%
M4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@
M1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@
M1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]
M/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^
M($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@
M/3X@)V%R<F%Y)RP*("`@("`@("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@*2P*("`@("=P<F]C961U<F5S)R`]
M/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@)V%R<F%Y)RP*
M("`@("`@("`G:6)A<V4Z:6)A<V4G(#T^($1"7T524D]27U5.4U504$]25$5$
M+`H@("`@("`@("=I8F%S93IF:7)E8FER9"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VEF>#II9G@G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=M<W%L.FUS<6PG(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=M<W-Q;#IM<W-Q;"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VUY<W%L.FUY<W%L)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G;7ES<6QI.FUY<W%L:2<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V]C:3@Z;V-I."<@/3X@1$)?15)23U)?
M54Y355!03U)4140L"B`@("`@("`@)V]D8F,Z86-C97-S)R`]/B!$0E]%4E)/
M4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID8C(G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP9W-Q;"<@/3X@)V%R<F%Y
M)RP*("`@("`@("`G<W%L:71E.G-Q;&ET92<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)W-Y8F%S93IS>6)A<V4G(#T^($1"7T524D]27U5.
M4U504$]25$5$+`H@("`@*2P*("`@("=S8VAE;6$N=&%B;&5S)R`]/B!A<G)A
M>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G(#T^($1"7T524D]27U5.4U504$]2
M5$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q;"<@/3X@1$)?15)23U)?54Y355!0
M3U)4140L"B`@("`@("`@)VEB87-E.FEB87-E)R`]/B!$0E]%4E)/4E]53E-5
M4%!/4E1%1"P*("`@("`@("`G:6)A<V4Z9FER96)I<F0G(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=I9G@Z:69X)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G;7-Q;#IM<W%L)R`]/B!$0E]%4E)/4E]5
M3E-54%!/4E1%1"P*("`@("`@("`G;7-S<6PZ;7-S<6PG(#T^($1"7T524D]2
M7U5.4U504$]25$5$+`H@("`@("`@("=M>7-Q;#IM>7-Q;"<@/3X@1$)?15)2
M3U)?54Y355!03U)4140L"B`@("`@("`@)VUY<W%L:3IM>7-Q;&DG(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O8VDX.F]C:3@G(#T^($1"
M7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=O9&)C.F%C8V5S<R<@/3X@
M)V%R<F%Y)RP*("`@("`@("`G;V1B8SID8C(G(#T^("=A<G)A>2<L"B`@("`@
M("`@)W!G<W%L.G!G<W%L)R`]/B`G87)R87DG+`H@("`@("`@("=S<6QI=&4Z
M<W%L:71E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G<WEB
M87-E.G-Y8F%S92<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`I+`H@
M("`@)W-Y;F]N>6US)R`]/B!A<G)A>2@*("`@("`@("`G9&)A<V4Z9&)A<V4G
M(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=F8G-Q;#IF8G-Q
M;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)VEB87-E.FEB
M87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G:6)A<V4Z
M9FER96)I<F0G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=I
M9G@Z:69X)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-Q
M;#IM<W%L)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;7-S
M<6PZ;7-S<6PG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=M
M>7-Q;#IM>7-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@
M)VUY<W%L:3IM>7-Q;&DG(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@
M("`@("=O8VDX.F]C:3@G(#T^("=A<G)A>2<L"B`@("`@("`@)V]D8F,Z86-C
M97-S)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("`@("`G;V1B8SID
M8C(G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=P9W-Q;#IP
M9W-Q;"<@/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)W-Q;&ET
M93IS<6QI=&4G(#T^($1"7T524D]27U5.4U504$]25$5$+`H@("`@("`@("=S
M>6)A<V4Z<WEB87-E)R`]/B!$0E]%4E)/4E]53E-54%!/4E1%1"P*("`@("DL
M"BD["@HO*BH*("H@1&5T97)M:6YE(&EF('1H92!O=71P=70@9G)O;2!T:&4@
M9')I=F5R(&UA=&-H97,@=VAA="!W92!E>'!E8W0*("H*("H@268@=&AI;F=S
M(&%R92!A<R!W92!E>'!E8W0L(&YO=&AI;F<@:7,@<')I;G1E9"!O=70N"B`J
M"B`J($EF('1H:6YG<R!G;R!W<F]N9RP@<')I;G0@(E5.15A014-4140@3U54
M0T]-12(@86YD(&1I<W!L87D*("H@=VAA="!H87!P96YE9"X*("H*("H@0'!A
M<F%M(&UI>&5D("`D<F5S=6QT("`@('1H92!R97-U;'0@9G)O;2!G971,:7-T
M3V8*("H@0'!A<F%M(&UI>&5D("`D97AP96-T960@('1H92!E>'!E8W1E9"!R
M97-U;'0*("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@('1H92!N86UE(&]F
M('1H92!C=7)R96YT('1E<W0*("H*("H@0')E='5R;B!V;VED"B`J+PIF=6YC
M=&EO;B!C:&5C:U]O=71P=70H)')E<W5L="P@)&5X<&5C=&5D+"`D;F%M92D@
M>PH@("`@:68@*&ES7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@(&EF("@D
M<F5S=6QT+3YG971#;V1E*"D@(3T]("1E>'!E8W1E9"D@>PH@("`@("`@("`@
M("!E8VAO(")53D584$5#5$5$($]55$-/344@1D]2("1N86UE+BXN7&XB.PH@
M("`@("`@("`@("!E8VAO("1R97-U;'0M/F=E=$1E8G5G26YF;R@I("X@(EQN
M(CL*("`@("`@("!]"B`@("!](&5L<V4@>PH@("`@("`@("1T>7!E(#T@9V5T
M='EP92@D<F5S=6QT*3L*("`@("`@("!I9B`H)'1Y<&4@(3T@)&5X<&5C=&5D
M*2!["B`@("`@("`@("`@(&EF("@D97AP96-T960@/3T]($1"7T524D]27T%#
M0T534U]624],051)3TX*("`@("`@("`@("`@("`@("8F("1T>7!E(#T]("=A
M<G)A>2<I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O(%1H:7,@
M=7-E<B!H87,@86-C97-S('1O('1H92!M>7-Q;"!T86)L92X*("`@("`@("`@
M("`@("`@("\O($YO="!A('!R;V)L96T*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&5C:&\@(E5.15A014-4140@3U540T]-12!&3U(@
M)&YA;64N+BY<;B(["B`@("`@("`@("`@("`@("!E8VAO("(@($5X<&5C=&5D
M.B`D97AP96-T961<;B(["B`@("`@("`@("`@("`@("!E8VAO("<@(%)E<W5L
M=#H@)SL*("`@("`@("`@("`@("`@('!R:6YT7W(H)')E<W5L="D["B`@("`@
M("`@("`@("`@("!E8VAO(")<;B(["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"GT*"@HD9&)H+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L*9F]R96%C:"`H)'1E<W1S(&%S("1T97-T(#T^("1D8FUS*2![
M"B`@("!C:&5C:U]O=71P=70H)&1B:"T^9V5T3&ES=$]F*"1T97-T*2P*("`@
M("`@("`@("`@("`@("`D9&)M<ULD9&)H+3YP:'!T>7!E("X@)SHG("X@)&1B
M:"T^9&)S>6YT87A=+`H@("`@("`@("`@("`@("`@("1T97-T*3L*?0H*"F1R
M;W!?=&%B;&4H)&1B:"P@)W!H<'1E<W0G*3L*"C\^"BTM15A014-4+2T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O8V]N;F5C="YI;F,`
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R-#`P(#$P-3$U-#,T,3,U(#`R-#8V
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RHJ"B`J($-O;FYE8W1S('1O('1H92!D871A8F%S90H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S
M96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N:65L
M($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*
M("H@0'9E<G-I;VX@("`@)$ED.B!C;VYN96-T+FEN8RQV(#$N,3(@,C`P-2\P
M,B\P,B`P,#HT,#HR,R!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"F5R<F]R7W)E<&]R
M=&EN9RA%7T%,3"D["@HO+R!3971T:6YG(&]F("1O<'1I;VYS(&%N9"!R97%U
M:7)I;F<@1$(@87)E(&1O;F4@:6X@<V5T=7`N:6YC"@HO*BH*("H@17-T86)L
M:7-H('1H92!I;F-L=61E7W!A=&@L($133B=S(&%N9"!C;VYN96-T:6]N("1O
M<'1I;VYS"B`J+PIR97%U:7)E7V]N8V4@)RXO<V5T=7`N:6YC)SL*"FEF("AE
M;7!T>2@D9'-N<RDI('L*("`@(&1I92@G070@;&5A<W0@;VYE(&5L96UE;G0@
M;V8@)&1S;G,@;75S="!B92!D969I;F5D(&EN('-E='5P+FEN8R<I.PI]"@IL
M:7-T*"1D8FUS+"`D9'-N*2`](&5A8V@H)&1S;G,I.PH*:68@*"1D8FUS(#T]
M("=M<W-Q;"<I('L*("`@(&EN:5]S970H)VUS<W%L+G1E>'1L:6UI="<L(#0P
M.38I.PH@("`@:6YI7W-E="@G;7-S<6PN=&5X='-I>F4G+"`T,#DV*3L*?0H*
M)&1B:"`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["FEF("A$0CHZ
M:7-%<G)O<B@D9&)H*2D@>PH@("`@9&EE*"=C;VYN96-T+FEN8SH@)R`N("1D
M8F@M/G1O4W1R:6YG*"DI.PI]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+T1"+W1E
M<W1S+V1R:79E<B]M:W1A8FQE+FEN8P``````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,3`Q-C0@,3`U,34T,S0Q,S4@,#(T-C8S`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"@HO*BH*("H@0W)E871E<R!T
M:&4@/&MB9#YP:'!T97-T/"]K8F0^('1A8FQE"B`J"B`J(%1R:65S('1O(&1R
M;W`@=&AE('1A8FQE(&9I<G-T+"!I;B!C87-E(&ET(&%L<F5A9'D@97AI<W1S
M+@H@*@H@*B`\<')E/@H@*B!#4D5!5$4@5$%"3$4@<&AP=&5S="`H"B`J("`@
M82!)3E1%1T52($Y53$PL"B`J("`@8B!#2$%2*#0P*2!$149!54Q4("=D968G
M($Y/5"!.54Q,+`H@*B`@(&,@5D%20TA!4B@R-34I($Y53$PL"B`J("`@9"!6
M05)#2$%2*#(P*2!.54Q,*0H@*B`\+W!R93X*("H*("H@3F5E9"`\:V)D/DY/
M5"!.54Q,/"]K8F0^(&]N(#QK8F0^8CPO:V)D/B!T;R!T97-T"B`J(#QK8F0^
M1$)?4$]25$%"24Q)5%E?4E1224T\+VMB9#XN("!-4R!344P@86YD(%-Y8F%S
M92!T<FEM(&]U='!U="!F<F]M"B`J(#QK8F0^5D%20TA!4CPO:V)D/BP@8G5T
M(&YO="!O;B`\:V)D/D-(05(\+VMB9#XN"B`J"B`J($YE960@/&MB9#Y$149!
M54Q4/"]K8F0^('9A;'5E(&]N(#QK8F0^8CPO:V)D/B!B96-A=7-E($]R86-L
M92!C;VYS:61E<G,*("H@86X@96UP='D@<W1R:6YG('1O(&)E(#QK8F0^3E5,
M3#PO:V)D/BX*("H*("H@26X@3W)A8VQE+"!W:&5N('5S:6YG('!L86-E:&]L
M9&5R<R!I;B`\:V)D/E=(15)%/"]K8F0^(&-L875S97,@;VX@"B`J(#QK8F0^
M0TA!4CPO:V)D/B!C;VQU;6YS+"!T:&4@8V]L=6UN(&UU<W0@:&%V92`\:V)D
M/E)44DE-*"D\+VMB9#X@<G5N(&]N"B`J('1H92!C;VQU;6XZ"B`J(#QS86UP
M/@H@*B`@("!314Q%0U0@*B!&4D]-('!H<'1E<W0@5TA%4D4@4E1224TH8BD@
M/2`_"B`J(#PO<V%M<#X*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!0
M2%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P
M:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN
M"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1"
M"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP
M+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("1)9#H@;6MT
M86)L92YI;F,L=B`Q+C$Y(#(P,#4O,#(O,30@,C,Z,S,Z,C`@9&%N:65L8R!%
M>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O1$(*("HO"@HO*BH*("H@17-T86)L:7-H97,@=&AE($1"(&]B:F5C="!A
M;F0@8V]N;F5C=',@=&\@=&AE(&1A=&%B87-E"B`J+PIR97%U:7)E7V]N8V4@
M)RXO8V]N;F5C="YI;F,G.PH*+RHJ"B`J($=E="!T:&4@9')O<%]T86)L92@I
M(&9U;F-T:6]N"B`J+PIR97%U:7)E7V]N8V4@)RXO9')O<'1A8FQE+FEN8R<[
M"@HO*BH*("H@5&AE(&5R<F]R(&AA;F1L97(@9F]R('1H92!D<F]P('1A8FQE
M('!R;V-E9'5R90H@*@H@*B!0<FEN=',@;W5T(&%N(&5R<F]R(&UE<W-A9V4@
M86YD(&1I97,N"B`J+PIF=6YC=&EO;B!D96)U9U]D:64H)&\I>PH@("`@9&EE
M*"1O+3YT;U-T<FEN9R@I*3L*?0H*"B1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PID<F]P7W1A8FQE*"1D8F@L("=P:'!T97-T
M)RD["@HO+R1D8F@M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]44DE'
M1T52*3L*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27T-!3$Q"
M04-++"`G9&5B=6=?9&EE)RD["@II9B`H)&1B:"T^<&AP='EP92`]/2`G;V1B
M8R<I('L*("`@(&EF("@D9&)H+3YD8G-Y;G1A>"`]/2`G;V1B8R<I('L*("`@
M("`@("`D='EP92`]("1D8F@M/G!H<'1Y<&4["B`@("!](&5L<V4@>PH@("`@
M("`@("1T>7!E(#T@)&1B:"T^9&)S>6YT87@["B`@("!]"GT@96QS92!["B`@
M("`D='EP92`]("1D8F@M/G!H<'1Y<&4["GT*"@IS=VET8V@@*"1T>7!E*2![
M"B`@("!C87-E("=A8V-E<W,G.@H@("`@("`@("1N=6QL(#T@)TY53$PG.PH@
M("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@
M/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@)R<["B`@("`@
M("`@)'1A8FQE='EP92`]("<G.PH@("`@("`@(&)R96%K.PH@("`@8V%S92`G
M9&(R)SH*("`@(&-A<V4@)VEB87-E)SH*("`@("`@("`D;G5L;"`]("<G.PH@
M("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@
M/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@
M)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*("`@
M("`@("!B<F5A:SL*("`@(&-A<V4@)V9B<W%L)SH*("`@("`@("`D;G5L;"`]
M("<G.PH@("`@("`@("1C:')C(#T@)T-(05(H,C4U*2<["B`@("`@("`@)&-H
M<F0@/2`G0TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@
M)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1D871E7VQI=&5R86P@/2`G($1!
M5$4@)SL*("`@("`@("`D=&%B;&5T>7!E(#T@)R<["B`@("`@("`@8G)E86L[
M"B`@("!C87-E("=I9G@G.@H@("`@("`@("\O(&1O:6YG('1H:7,@9F]R(&EF
M>"!T;R!K965P(&-E<G1A:6X@=F5R<VEO;G,@:&%P<'D*("`@("`@("`D;G5L
M;"`]("<G.PH@("`@("`@("1C:')C(#T@)T-(05(H,C4U*2<["B`@("`@("`@
M)&-H<F0@/2`G0TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%5
M3%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*
M("`@("`@("!B<F5A:SL*("`@(&-A<V4@)VUS<6PG.@H@("`@("`@("1N=6QL
M(#T@)R<["B`@("`@("`@)&-H<F,@/2`G0TA!4B@R-34I)SL*("`@("`@("`D
M8VAR9"`]("=#2$%2*#(P*2<["B`@("`@("`@)&1E9F%U;'0@/2`G)SL*("`@
M("`@("`D=&%B;&5T>7!E(#T@)R<["B`@("`@("`@8G)E86L["B`@("!C87-E
M("=M>7-Q;"<Z"B`@("!C87-E("=M>7-Q;&DG.@H@("`@("`@("1N=6QL(#T@
M)TY53$PG.PH@("`@("`@("1C:')C(#T@)U9!4D-(05(H,C4U*2<["B`@("`@
M("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG.PH@("`@("`@("1D969A=6QT(#T@
M(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB.PH@("`@("`@(&EF("@A96UP='DH
M)&YE961I;FYO9&(I*2!["B`@("`@("`@("`@("1T86)L971Y<&4@/2`G5%E0
M13U)3DY/1$(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T86)L
M971Y<&4@/2`G)SL*("`@("`@("!]"B`@("`@("`@8G)E86L["B`@("!D969A
M=6QT.@H@("`@("`@("1N=6QL(#T@)TY53$PG.PH@("`@("`@("1C:')C(#T@
M)U9!4D-(05(H,C4U*2<["B`@("`@("`@)&-H<F0@/2`G5D%20TA!4B@R,"DG
M.PH@("`@("`@("1D969A=6QT(#T@(D1%1D%53%0@)V1E9B<@3D]4($Y53$PB
M.PH@("`@("`@("1T86)L971Y<&4@/2`G)SL*?0H*<W=I=&-H("@D9&)H+3YP
M:'!T>7!E*2!["B`@("!C87-E("=D8F%S92<Z"B`@("`@("`@+R\@9FEL92!E
M>&ES=',@;W(@=V%S(&-R96%T960@:6X@1$)?9&)A<V4Z.F-O;FYE8W0H*0H@
M("`@("`@(&)R96%K.PH@("`@9&5F875L=#H*("`@("`@("`D=&5S=%]M:W1A
M8FQE7W%U97)Y(#T@(@H@("`@("`@("`@("!#4D5!5$4@5$%"3$4@<&AP=&5S
M="`H"B`@("`@("`@("`@("`@82!)3E1%1T52("1N=6QL+`H@("`@("`@("`@
M("`@(&(@0TA!4B@T,"D@)&1E9F%U;'0L"B`@("`@("`@("`@("`@8R`D8VAR
M8R`D;G5L;"P*("`@("`@("`@("`@("!D("1C:')D("1N=6QL*2`D=&%B;&5T
M>7!E"B`@("`@("`@(CL*?0H*"B1D8F@M/G%U97)Y*"1T97-T7VUK=&%B;&5?
M<75E<GDI.PHD9&)H+3YQ=65R>2@B24Y315)4($E.5$\@<&AP=&5S="!604Q5
M15,H-#(L("=B:6YG)RP@)U1H:7,@:7,@82!T97-T)RP@)S$Y.3DM,3$M,C$G
M*2(I.PH*)&1B:"T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD["@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O1$(O=&5S=',O9')I=F5R
M+VUU;'1I8V]N;F5C="YP:'``````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3$P-R`Q,#4Q
M-30S-#$S-2`P,C4W-C<`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J*@H@*B!497-T<R!T:&4@=F%R:6]U<R!W
M87ES($1")W,@8V]N;F5C="@I(&9U;F-T:6]N(&]P97)A=&5S"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A
M8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@
M*B!`=F5R<VEO;B`@("`D260Z(&UU;'1I8V]N;F5C="YP:'`L=B`Q+C(@,C`P
M-2\P,B\P,R`P-3HT.3HT-2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`J+PH*+RHJ
M"B`J($5S=&%B;&ES:"!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N
M;F5C=&EO;B`D;W!T:6]N<PH@*B\*<F5Q=6ER95]O;F-E("<N+W-E='5P+FEN
M8R<["@IF;W)E86-H("@D9'-N<R!A<R`D9&)M<R`]/B`D9'-N*2!["B`@("!E
M8VAO("(]/3T]/3T]/2`D9&)M<R`]/3T]/3T]/5QN(CL*("`@("1O<'1I;VYS
M6R=P97)S:7-T96YT)UT@/2!F86QS93L*("`@("1D8F@@/28@1$(Z.F-O;FYE
M8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@:68@*$1".CII<T5R<F]R*"1D8F@I
M*2!["B`@("`@("`@96-H;R`G4%)/0DQ%33H@)R`N("1D8F@M/F=E=%5S97))
M;F9O*"D@+B`B7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0H*("`@(&EF
M("@D9&)H+3YP<F]V:61E<R@G;F5W7VQI;FLG*0H@("`@("`@("8F('9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("1D8F@M/G!R;W9I9&5S*"=N97=?
M;&EN:R<I+"`G/CTG*2D*("`@('L*("`@("`@("`D<')O8G,@/2!F86QS93L*
M("`@("`@("`D9'-N(#T@1$(Z.G!A<G-E1%-.*"1D<VXI.PH@("`@("`@("1D
M<VY;)VYE=U]L:6YK)UT@/2!T<G5E.PH@("`@("`@("1D8F@@/28@1$(Z.F-O
M;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O
M<B@D9&)H*2D@>PH@("`@("`@("`@("!E8VAO("=.15<@3$E.2R!04D]"3$5-
M.B`G("X@)&1B:"T^9V5T57-E<DEN9F\H*2`N(")<;B(["B`@("`@("`@("`@
M("1P<F]B<R`]('1R=64["B`@("`@("`@?0H*("`@("`@("!I9B`H)&1B:"T^
M<')O=FED97,H)W!C;VYN96-T)RDI('L*("`@("`@("`@("`@)&]P=&EO;G-;
M)W!E<G-I<W1E;G0G72`]('1R=64["B`@("`@("`@("`@("1D8F@M/F1I<V-O
M;FYE8W0H*3L*("`@("`@("`@("`@)&1B:"`])B!$0CHZ8V]N;F5C="@D9'-N
M+"`D;W!T:6]N<RD["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D9&)H
M*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G4$524TE35"!.15=#3TX@4%)/
M0DQ%33H@)R`N("1D8F@M/F=E=%5S97));F9O*"D@+B`B7&XB.PH@("`@("`@
M("`@("`@("`@)'!R;V)S(#T@=')U93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@=6YS970H)&1S;ELG;F5W7VQI;FLG72D["B`@("`@("`@("`@("1D
M8F@M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@("`@)&1B:"`])B!$0CHZ8V]N
M;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D9&)H*2D@>PH@("`@("`@("`@("`@("`@96-H;R`G4$524TE35"!/
M3$1#3TX@4%)/0DQ%33H@)R`N("1D8F@M/F=E=%5S97));F9O*"D@+B`B7&XB
M.PH@("`@("`@("`@("`@("`@)'!R;V)S(#T@=')U93L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H)'!R;V)S*2!["B`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("`D9&)H+3YD:7-C;VYN96-T
M*"D["@H@("`@?2!E;'-E:68@*"1D8F@M/G!R;W9I9&5S*"=P8V]N;F5C="<I
M*2!["B`@("`@("`@)&]P=&EO;G-;)W!E<G-I<W1E;G0G72`]('1R=64["B`@
M("`@("`@)&1B:"T^9&ES8V]N;F5C="@I.PH@("`@("`@("1D8F@@/28@1$(Z
M.F-O;FYE8W0H)&1S;BP@)&]P=&EO;G,I.PH@("`@("`@(&EF("A$0CHZ:7-%
M<G)O<B@D9&)H*2D@>PH@("`@("`@("`@("!E8VAO("=015)325-4(%!23T),
M14TZ("<@+B`D9&)H+3YG9715<V5R26YF;R@I("X@(EQN(CL*("`@("`@("`@
M("`@8V]N=&EN=64["B`@("`@("`@?0H@("`@("`@("1D8F@M/F1I<V-O;FYE
M8W0H*3L*("`@('T*("`@(&5C:&\@(D=/3T1<;B(["GT*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<G5N+F-V<P``````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C8P(#$P-3$U-#,T,3,U(#`R-#`W,P`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````C(2`O
M8FEN+W-H"@HC("1)9#H@<G5N+F-V<RQV(#$N,B`R,#`T+S`R+S(P(#$X.C4W
M.C4R(&1A;FEE;&,@17AP("0*"B,@=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V
M=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G9V=G8*(R!014%2($1"(%1%4U0@4U1!
M4E1%4@HC"B,@("!4;R!R=6X@86QL('1E<W1S.B`@+B]R=6X*(R`@(%1O(')U
M;B!O;F4@=&5S=#H@("`N+W)U;B`\=&5S="!F:6QE(&YA;64^"B,@("!%>&%M
M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN<&AP=`HC"B,@0F5F
M;W)E(')U;FYI;F<@=&AE('1E<W1S('EO=2!M=7-T(&%D:G5S="!T:&4*(R!F
M;VQL;W=I;F<@=&AR964@=F%R:6%B;&5S.@H*(R`@(%1H92!F=6QL('!A=&@@
M=&\@>6]U<B!02%`@9&ER96-T;W)Y.@H@("`@1$)?5$535%]02%!?4$%42#UC
M.B]P<F]G<F%^,2]P:'`*"B,@("!4:&4@;F%M92!O9B!Y;W5R(%!(4"!#3$D@
M97AE8W5T86)L90HC("`@*&5X86UP;&5S('!H<"YE>&4L('!H<"UC;&DN97AE
M+"!C;&DO<&AP+F5X92DZ"B`@("!$0E]415-47U!(4%]#3$D]<&AP+F5X90H*
M(R`@(%1H92!F=6QL('!A=&@@=&\@=&AE('!R97-E;G0@9&ER96-T;W)Y"B,@
M("`H;F]T('5S:6YG("105T0@9'5E('1O($-Y9W=I;BDZ"B`@("!$0E]415-4
M7T1)4CUD.B]P96%R=&5S="]P96%R+T1"+W1E<W1S+V1R:79E<@H*(R!>7EY>
M7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>7EY>
M7@H*"@I415-47U!(4%]%6$5#551!0DQ%/21$0E]415-47U!(4%]0051(+R1$
M0E]415-47U!(4%]#3$D*97AP;W)T(%1%4U1?4$A07T5814-55$%"3$4*"FEF
M(%L@)",@+6=T(#`@70IT:&5N"B`@("!T97-T/20Q"F5L<V4*("`@('1E<W0]
M*BYP:'!T"F9I"@HD5$535%]02%!?15A%0U5404),12`D1$)?5$535%]02%!?
M4$%42"]R=6XM=&5S=',N<&AP("1$0E]415-47T1)4B\D>W1E<W1]"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O<V5T=7`N:6YC
M+F-V<P```````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W-38P(#$P-3$U-#,T,3,U(#`R
M-3(P-``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`H*+RHJ"B`J($5S=&%B;&ES:&5S('1H92!I;F-L=61E7W!A=&@L
M($133B=S(&%N9"!C;VYN96-T:6]N("1O<'1I;VYS"B`J"B`J($EF('1H:7,@
M9FEL92!I<R!N86UE9"`B<V5T=7`N:6YC+F-V<RPB(&ET(&ES('1H92!O<FEG
M:6YA;"!O;F4@9G)O;2!#5E,N"B`J(%!L96%S92!D;R!T:&4@9F]L;&]W:6YG
M.@H@*B`@(#$I($UA:V4@82!C;W!Y(&]F('1H:7,@9FEL92!N86UE9"`B<V5T
M=7`N:6YC(BX*("H@("`R*2!4:&5N+"!I;B!T:&4@8V]P>2P@961I="!T:&4@
M)&1S;G,@87)R87D@87,@87!P<F]P<FEA=&4@9F]R('EO=7(*("H@("`@("!E
M;G9I<F]N;65N="X*("H@("`S*2!!="!L96%S="!O;F4@96QE;65N="!O9B!T
M:&4@)&1S;G,@87)R87D@;F5E9',@=&\@8F4@=6YC;VUM96YT960N"B`J"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U
M<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0
M(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$
M871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("`D260Z('-E='5P+FEN8RYC=G,L=B`Q+C8@,C`P
M-2\P,B\Q-"`R,SHS,SHR,"!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"FEF("@A9&5F
M:6YE9"@G4$%42%]315!!4D%43U(G*2D@>PH@("`@:68@*'-T<FES='(H4$A0
M7T]3+"`G5TE.)RDI('L*("`@("`@("`O*BH*("`@("`@("`@*B!4:&4@<W1R
M:6YG('5S960@=&\@9&5L:6UI="!E;&5M96YT<R!O9B!T:&4@<&%T:"X*("`@
M("`@("`@*B\*("`@("`@("!D969I;F4H)U!!5$A?4T5005)!5$]2)RP@)SLG
M*3L*("`@('T@96QS92!["B`@("`@("`@+RHJ"B`@("`@("`@("H@5&AE('-T
M<FEN9R!U<V5D('1O(&1E;&EM:70@96QE;65N=',@;V8@=&AE('!A=&@N"B`@
M("`@("`@("HO"B`@("`@("`@9&5F:6YE*"=0051(7U-%4$%2051/4B<L("<Z
M)RD["B`@("!]"GT*"B\J"B`J($EF('1H92!P871H('1O('EO=7(@4$5!4B!I
M;G-T86QL871I;VX@:7,@9F]U;F0@:6X@=&AE(&QE9G0@:&%N9`H@*B!P;W)T
M:6]N(&]F('1H92!I9B@I(&5X<')E<W-I;VX@8F5L;W<L('1H870@;65A;G,@
M=&AI<R!F:6QE(&AA<PH@*B!C;VUE(&9R;VT@=&AE(%!%05(@:6YS=&%L;&5R
M+B`@5&AE<F5F;W)E+"!L970G<R!U<V4@=&AE"B`J(&EN<W1A;&QE9"!V97)S
M:6]N(&]F($1"+"!W:&EC:"!S:&]U;&0@8F4@9F]U;F0@=FEA('1H90H@*B!C
M;VUP=71E<B=S(&1E9F%U;'0@:6YC;'5D95]P871H+B`@061D("<N)R!T;R!T
M:&4@:6YC;'5D95]P871H"B`J('1O(&5N<W5R92`G+B<@:7,@:6X@=&AE<F4N
M"B`J(`H@*B!)9B!T:&4@<&%T:"!H87,@;F]T(&)E96X@<W5B<W1I='5T960@
M:6X@=&AE(&EF*"D@97AP<F5S<VEO;BP*("H@=&AI<R!F:6QE(&AA<R!L:6ME
M;'D@8V]M92!F<F]M(&$@0U93(&-H96-K;W5T(&]R(&$@+G1A<B!F:6QE+@H@
M*B!4:&5R969O<F4L('=E)VQL(&%S<W5M92!T:&4@=&5S=',@<VAO=6QD('5S
M92!T:&4@=F5R<VEO;B!O9@H@*B!$0B!T:&%T(&AA<R!C;VUE(&9R;VT@=&AE
M<F4@87,@=V5L;"X*("HO"FEF("@G+W5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(G("$]("=`)RXG:6YC;'5D95]P871H)RXG0"<I('L*("`@(&EN:5]S
M970H)VEN8VQU9&5?<&%T:"<L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I"B`@
M("`@("`@("`@("X@4$%42%]315!!4D%43U(@+B`G+B<*("`@("D["GT@96QS
M92!["B`@("!I;FE?<V5T*"=I;F-L=61E7W!A=&@G+"!R96%L<&%T:"AD:7)N
M86UE*%]?1DE,15]?*2`N("<O+BXO+BXG*0H@("`@("`@("`@("`N(%!!5$A?
M4T5005)!5$]2("X@)RXG("X@4$%42%]315!!4D%43U(*("`@("`@("`@("`@
M+B!I;FE?9V5T*"=I;F-L=61E7W!A=&@G*0H@("`@*3L*?0H*+RHJ"B`J($=R
M86(@=&AE(%!%05(@1$(@8VQA<W-E<RX*("HO"G)E<75I<F5?;VYC92`G1$(N
M<&AP)SL*"B\O($]P=&EO;G,@=7-E9"!W:&5N(&-O;FYE8W1I;F<*)&]P=&EO
M;G,@/2!A<G)A>2@*("`@("\O)V]P=&EM:7IE)R`]/B`G<&]R=&%B:6QI='DG
M+`H@("`@)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL"B`@
M("`G9&5B=6<G(#T^(#(L"BD["@HD9&)A<V5D<VX@/2!A<G)A>2@*("`@("=P
M:'!T>7!E)R`@/3X@)V1B87-E)RP*("`@("=D871A8F%S92<@/3X@)R]P871H
M+V%N9"]N86UE+V]F+V1B87-E+V9I;&4G+`H@("`@)VUO9&4G("`@("`]/B`R
M+`H@("`@)V9I96QD<R<@("`]/B!A<G)A>2@*("`@("`@("!A<G)A>2@G82<L
M("=.)RP@-2P@,"DL"B`@("`@("`@87)R87DH)V(G+"`G0R<L(#0P*2P*("`@
M("`@("!A<G)A>2@G8R<L("=#)RP@,C4U*2P*("`@("`@("!A<G)A>2@G9"<L
M("=#)RP@,C`I+`H@("`@*2P**3L*"B\J"B`J(%5N8V]M;65N="!A="!L96%S
M="!O;F4@;V8@=&AE(&9O;&QO=VEN9R!E;&5M96YT<RX*("H@5VAE;B!R=6YN
M:6YG('1H92`N<&AP="!T97-T<RP@=&AE(&9I<G-T('5N8V]M;65N=&5D(&5L
M96UE;G0@:7,@=7-E9"X*("H@5VAE;B!R=6YN:6YG('1H92!M=6QT:6-O;FYE
M8W0N<&AP('1E<W0L(&%L;"!U;F-O;6UE;G1E9"!E;&5M96YT<R!A<F4@=7-E
M9"X*("HO"B1D<VYS(#T@87)R87DH"B`@("`O+R`G9&)A<V4G("`@(#T^("1D
M8F%S961S;BP*("`@("\O("=F8G-Q;"<@("`@/3X@)V9B<W%L.B\O7W-Y<W1E
M;3I`+V1B)RP*("`@("\O("=F:7)E8FER9"<@/3X@)VEB87-E*&9I<F5B:7)D
M*3HO+U-94T1"03IM87-T97)K97E`+R]O<'0O:6YT97)B87-E+V5X86UP;&5S
M+V5M<&QO>65E+F=D8C]D:6%L96-T/3,G+`H@("`@+R\@)VEF>"<@("`@("`]
M/B`G:69X.B\O=7-E<CIP=T!L;V-A;&AO<W0O9&(G+`H@("`@+R\@)VUS<6PG
M("`@("`]/B`G;7-Q;#HO+R]D8B<L"@H@("`@+R\@270G<R!A9'9I<V%B;&4@
M=&\@=7-E(&]N;'D@;VYE(&]F('1H92!F;VQL;W=I;F<@870@82!T:6UE.@H@
M("`@+R\@)VUS<W%L)R`@("`]/B`G;7-S<6PZ+R]S84!S;VUE:&]S="]P=6)S
M)RP*("`@("\O("=S>6)A<V4G("`@/3X@)W-Y8F%S93HO+W-A0'-O;65H;W-T
M+W!U8G,G+`H*("`@("\O("=M>7-Q;"<@("`@/3X@)VUY<W%L.B\O<F]O=$!L
M;V-A;&AO<W0O=&5S="<L"B`@("`O+R`G;7ES<6QI)R`@(#T^("=M>7-Q;&DZ
M+R]R;V]T0&QO8V%L:&]S="]T97-T)RP*("`@("\O("=O8VDX)R`@("`@/3X@
M)V]C:3@Z+R]S>7-T96TZ;6%N86=E<D`G+`H@("`@+R\@)V%C8V5S<R<@("`]
M/B`G;V1B8RAA8V-E<W,I.B\O861M:6Y`+U-Y<W1E;41S;DYA;64G+`H@("`@
M+R\@)V1B,B<@("`@("`]/B`G;V1B8RAD8C(I.B\O9&(R:6YS=#$Z6%A86$`O
M4T%-4$Q%)RP*("`@("\O("=P9W-Q;"<@("`@/3X@)W!G<W%L.B\O<&]S=&=R
M97-`;&]C86QH;W-T+W1E<W0G+`H@("`@+R\@)W-Q;&ET92<@("`]/B`G<W%L
M:71E.B\O9'5M;7DZ0&QO8V%L:&]S="\G("X@9V5T8W=D*"D@+B!$25)%0U1/
M4EE?4T5005)!5$]2("X@)W1E<W0N9&(_;6]D93TP-C0T)RP**3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]T97-T<R]$0B]T97-T
M<R]D<FEV97(O<VMI<&EF+FEN8P``````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,3(V(#$P-3$U-#,T,3,U(#`R-#4S,``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*+RHJ"B`J($$@=&5S="!T;R!M
M86ME('-U<F4@=&AE(&1A=&%B87-E(&-A;B!B92!C;VYN96-T960@=&\*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@("1)9#H@<VMI<&EF+FEN8RQV(#$N-R`R,#`U
M+S`R+S`R(#`P.C0P.C(S(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($5S
M=&%B;&ES:"!T:&4@:6YC;'5D95]P871H+"!$4TXG<R!A;F0@8V]N;F5C=&EO
M;B`D;W!T:6]N<PH@*B\*<F5Q=6ER95]O;F-E("<N+W-E='5P+FEN8R<["@II
M9B`H96UP='DH)&1S;G,I*2!["B`@("!D:64H)W-K:7`@070@;&5A<W0@;VYE
M(&5L96UE;G0@;V8@)&1S;G,@;75S="!B92!D969I;F5D(&EN('-E='5P+FEN
M8R<I.PI]"@IL:7-T*"1D8FUS+"`D9'-N*2`](&5A8V@H)&1S;G,I.PH*)&1B
M:"`])B!$0CHZ8V]N;F5C="@D9'-N+"`D;W!T:6]N<RD["FEF("A$0CHZ:7-%
M<G)O<B@D9&)H*2D@>PH@("`@9&EE*"=S:VEP("<@+B`D9&)H+3YM97-S86=E
M*3L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+W1E<W1S+T1"+W1E<W1S+V1R:79E<B\P,6-O;FYE8W0N<&AP
M=```````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,R-30@,3`U,34T,S0Q,S4@,#(U,C0R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M5$535"TM"D1"7V1R:79E<CHZ8V]N;F5C=`HM+4E.22TM"F5R<F]R7W)E<&]R
M=&EN9R`](#(P-#<*+2U32TE0248M+0H\/W!H<"!C:&1I<BAD:7)N86UE*%]?
M1DE,15]?*2D[(')E<75I<F5?;VYC92`G+B]S:VEP:68N:6YC)SL@/SX*+2U&
M24Q%+2T*/#]P:'`*<F5Q=6ER95]O;F-E("<N+V-O;FYE8W0N:6YC)SL*"B\J
M*@H@*B!$971E<FUI;F4@:68@=&AE(&1A=&%B87-E(&-O;FYE8W1I;VX@;6%T
M8VAE<R!W:&%T)W,@97AP96-T960*("H*("H@0'!A<F%M(&]B:F5C="`D9&)H
M("`@=&AE(%!%05(@1$(@;V)J96-T"B`J($!P87)A;2!S=')I;F<@)&YA;64@
M('1H92!N86UE(&]F('1H92!C=7)R96YT('1E<W0*("H*("H@0')E='5R;B!V
M;VED"B`J+PIF=6YC=&EO;B!C:&5C:U]D8F@H)&1B:"P@)&YA;64I('L*("`@
M(&EF("A$0CHZ:7-%<G)O<B@D9&)H*2D@>PH@("`@("`@(&1I92@G8V]N;F5C
M="YI;F,Z("<@+B`D9&)H+3YT;U-T<FEN9R@I*3L*("`@('T*("`@(&EF("AI
M<U]O8FIE8W0H)&1B:"DI('L*("`@("`@("!P<FEN="`B)&YA;64@:7,@86X@
M;V)J96-T7&XB.PH@("`@?0H@("`@<W=I=&-H("@D9&)H+3YP:'!T>7!E*2![
M"B`@("`@("`@8V%S92`G9&)A<V4G.@H@("`@("`@("`@("!I9B`H:7-?:6YT
M*"1D8F@M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!P<FEN="`B
M)&YA;64@:7,@8V]N;F5C=&5D7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@<')I;G0@(B1N86UE($Y/5"!C;VYN96-T961<;B([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S
M92`G;7ES<6QI)SH*("`@("`@("`@("`@:68@*&ES7V$H)&1B:"T^8V]N;F5C
M=&EO;BP@)VUY<W%L:2<I*2!["B`@("`@("`@("`@("`@("!P<FEN="`B)&YA
M;64@:7,@8V]N;F5C=&5D7&XB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<')I;G0@(B1N86UE($Y/5"!C;VYN96-T961<;B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@:68@*&=E='1Y<&4H)&1B:"T^8V]N;F5C=&EO;BD@
M/3T@)W)E<V]U<F-E)RD@>PH@("`@("`@("`@("`@("`@<')I;G0@(B1N86UE
M(&ES(&-O;FYE8W1E9%QN(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@('!R:6YT("(D;F%M92!.3U0@8V]N;F5C=&5D7&XB.PH@("`@
M("`@("`@("!]"B`@("!]"GT*"@IC:&5C:U]D8F@H)&1B:"P@)R1D8F@G*3L*
M"@HD=&5S=%]A<G)A>5]D<VX@/2!$0CHZ<&%R<V5$4TXH)&1S;BD["F9O<F5A
M8V@@*"1T97-T7V%R<F%Y7V1S;B!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M:68@*"1V86QU92`]/3T@9F%L<V4I('L*("`@("`@("!U;G-E="@D=&5S=%]A
M<G)A>5]D<VY;)&ME>5TI.PH@("`@?0I]"@HD9&)H82`])B!$0CHZ8V]N;F5C
M="@D=&5S=%]A<G)A>5]D<VXL("1O<'1I;VYS*3L*8VAE8VM?9&)H*"1D8FAA
M+"`G)&1B:&$G*3L*"@HD=&UP("`]('-E<FEA;&EZ92@D9&)H82D["B1D8FAU
M(#T@=6YS97)I86QI>F4H)'1M<"D["F-H96-K7V1B:"@D9&)H=2P@)R1D8FAU
M)RD["@H_/@HM+4584$5#5"TM"B1D8F@@:7,@86X@;V)J96-T"B1D8F@@:7,@
M8V]N;F5C=&5D"B1D8FAA(&ES(&%N(&]B:F5C=`HD9&)H82!I<R!C;VYN96-T
M960*)&1B:'4@:7,@86X@;V)J96-T"B1D8FAU(&ES(&-O;FYE8W1E9`H`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]T97-T<R]$0B]T97-T<R]D<FEV97(O,#)F971C:"YP:'!T````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R,38P(#$P-3$U-#,T,3,U(#`R-#8W-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M+51%4U0M
M+0I$0E]D<FEV97(Z.F9E=&-H"BTM24Y)+2T*97)R;W)?<F5P;W)T:6YG(#T@
M,C`T-PHM+5-+25!)1BTM"CP_<&AP(&-H9&ER*&1I<FYA;64H7U]&24Q%7U\I
M*3L@<F5Q=6ER95]O;F-E("<N+W-K:7!I9BYI;F,G.R`_/@HM+49)3$4M+0H\
M/W!H<`IR97%U:7)E7V]N8V4@)RXO;6MT86)L92YI;F,G.PIR97%U:7)E7V]N
M8V4@)RXN+V9E=&-H;6]D97,N:6YC)SL*/SX*+2U%6%!%0U0M+0IT97-T:6YG
M(&9E=&-H<F]W.@IR;W<@,3H@-#(L(&)I;F<L(%1H:7,@:7,@82!T97-T+"`Q
M.3DY+3$Q+3(Q"G)O=R`R.B`Q+"!O;F4L($]N92P@,C`P,2TP,BTQ-@IR;W<@
M,SH@,BP@='=O+"!4=V\L(#(P,#$M,#(M,34*<F]W(#0Z(#,L('1H<F5E+"!4
M:')E92P@,C`P,2TP,BTQ-`IR;W<@-3H@3E5,3`IT97-T:6YG(&9E=&-H;6]D
M97,Z(&9E=&-H<F]W(&1E9F%U;'0@9&5F875L="P@<&]R=&%B:6QI='D@;6]D
M92!$0E]03U)404))3$E465]!3$P@7B!$0E]03U)404))3$E465]25%))30HP
M(#$@,B`S"F]U='!U="!M871C:&5D(&5X<&5C=&5D(&9O<FUA=`IT97-T:6YG
M(&9E=&-H;6]D97,Z(&9E=&-H:6YT;R!D969A=6QT(&1E9F%U;'0*,"`Q(#(@
M,PHT,B!B:6YG(%1H:7,@:7,@82!T97-T(#$Y.3DM,3$M,C$*=&5S=&EN9R!F
M971C:&UO9&5S.B!F971C:')O=R!O<F1E<F5D(&1E9F%U;'0*,"`Q(#(@,PIT
M97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&%S<V]C(&1E9F%U;'0*82!B
M(&,@9`IT97-T:6YG(&9E=&-H;6]D97,Z(&9E=&-H<F]W(&]R9&5R960@9&5F
M875L="!W:71H(&%S<V]C('-P96-I9FEE9`IA(&(@8R!D"G1E<W1I;F<@9F5T
M8VAM;V1E<SH@9F5T8VAR;W<@87-S;V,@9&5F875L="!W:71H(&]R9&5R960@
M<W!E8VEF:65D"C`@,2`R(#,*=&5S=&EN9R!F971C:&UO9&5S.B!F971C:&EN
M=&\@;W)D97)E9"!D969A=6QT"C`@,2`R(#,*=&5S=&EN9R!F971C:&UO9&5S
M.B!F971C:&EN=&\@87-S;V,@9&5F875L=`IA(&(@8R!D"G1E<W1I;F<@9F5T
M8VAM;V1E<SH@9F5T8VAI;G1O(&]R9&5R960@9&5F875L="!W:71H(&%S<V]C
M('-P96-I9FEE9`IA(&(@8R!D"G1E<W1I;F<@9F5T8VAM;V1E<SH@9F5T8VAI
M;G1O(&%S<V]C(&1E9F%U;'0@=VET:"!O<F1E<F5D('-P96-I9FEE9`HP(#$@
M,B`S"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O
M=&5S=',`````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q,S0@,#(R-C8S`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M=&5S=',O6$U,7U!A<G-E<B]T97-T<R\P,#4N<&AP=```````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,S8W-2`Q,#4Q-30S-#$S-"`P,C0Q-38`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+2U415-4+2T*6$U,
M(%!A<G-E<CH@;6EX:6YG(&-H87)A8W1E<B!E;F-O9&EN9W,*+2U32TE0248M
M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO("=S
M:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*+R\@
M5&5S="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@+2!M
M:7AI;F<@8VAA<F%C=&5R(&5N8V]D:6YG<PHO+PHO+R!4:&ES(&ES('=H870@
M=V4@=&5S=#H*+R\@,2!55$8M."`@("`@("T^($E33RTX.#4Y+3$*+R\@,B!5
M5$8M."`@("`@("T^(%53+4%30TE)"B\O(#,@25-/+3@X-3DM,2`M/B!55$8M
M.`HO+R`T($E33RTX.#4Y+3$@+3X@55,M05-#24D*+R\@-2!54RU!4T-)22`@
M("T^(%541BTX"B\O(#8@55,M05-#24D@("`M/B!)4T\M.#@U.2TQ"B\O"@IR
M97%U:7)E7V]N8V4@(BXN+U!A<G-E<BYP:'`B.PH*8VQA<W,@5&5S=$5N8V]D
M:6YG<S$@97AT96YD<R!834Q?4&%R<V5R('L*("`@('9A<B`D;W5T<'5T(#T@
M)R<["@H@("`@9G5N8W1I;VX@5&5S=$5N8V]D:6YG<S$H)'1O+"`D9G)O;2D@
M>PH@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R*"1F<F]M+"`G979E;G0G+"`D
M=&\I.PH@("`@?0H@("`@9G5N8W1I;VX@<W1A<G1(86YD;&5R*"1X<"P@)&5L
M96TL("1A='1R:6)S*2!["B`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B/"1E
M;&5M/B(["B`@("!]"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L
M96TI('L*("`@("`@("`D=&AI<RT^;W5T<'5T("X]("(\+R1E;&5M/B(["B`@
M("!]"B`@("!F=6YC=&EO;B!C9&%T84AA;F1L97(H)'AP+"`D9&%T82D@>PH@
M("`@("`@("1T:&ES+3YO=71P=70@+CT@)&1A=&$["B`@("!]"B`@("!F=6YC
M=&EO;B!T97-T*"1D871A*2!["B`@("`@("`@+R\@)'1H:7,M/F]U='!U="`]
M("<G.PH@("`@("`@("1T:&ES+3YP87)S95-T<FEN9R@D9&%T82P@=')U92D[
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YO=71P=70["B`@("!]"GT*"B1X;6P@
M/2`B/#]X;6P@=F5R<VEO;CTG,2XP)R`_/B(["B1I;G!U="`](&%R<F%Y*`H@
M("`@(E541BTX(B`@("`@(#T^("(\83YA8F/#IL.XPZ4\+V$^(BP*("`@("))
M4T\M.#@U.2TQ(B`]/B`B/&$^86)CYOCE/"]A/B(L"B`@("`B55,M05-#24DB
M("`@/3X@(CQA/F%B8V%O83PO83XB"BD["@HD96YC;V1I;F=S(#T@87)R87E?
M:V5Y<R@D:6YP=70I.PIF;W)E86-H("@D:6YP=70@87,@)'-R8V5N8R`]/B`D
M<W1R:6YG*2!["B`@("!F;W)E86-H("@D96YC;V1I;F=S(&%S("1T9W1E;F,I
M('L*("`@("`@("!I9B`H)'-R8V5N8R`]/2`D=&=T96YC*2!["B`@("`@("`@
M("`@(&-O;G1I;G5E.PH@("`@("`@('T*("`@("`@("!P<FEN="`B5&5S=&EN
M9R`D<W)C96YC("T^("1T9W1E;F,Z("(["B`@("`@("`@)'`@/28@;F5W(%1E
M<W1%;F-O9&EN9W,Q*"1T9W1E;F,L("1S<F-E;F,I.PH@("`@("`@("1E(#T@
M)'`M/G1E<W0H)&EN<'5T6R1S<F-E;F-=*3L*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92DI('L*("`@("`@("`@("`@<')I;G1F*")/3U!3.B`E<UQN
M(BP@)&4M/F=E=$UE<W-A9V4H*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@=F%R7V1U;7`H)&4I.PH@("`@("`@('T*("`@('T*?0H*/SX*+2U%
M6%!%0U0M+0I497-T:6YG(%541BTX("T^($E33RTX.#4Y+3$Z('-T<FEN9R@Q
M,RD@(CQ!/F%B8^;XY3PO03XB"E1E<W1I;F<@551&+3@@+3X@55,M05-#24DZ
M('-T<FEN9R@Q,RD@(CQ!/F%B8S\_/SPO03XB"E1E<W1I;F<@25-/+3@X-3DM
M,2`M/B!55$8M.#H@<W1R:6YG*#$V*2`B/$$^86)CPZ;#N,.E/"]!/B(*5&5S
M=&EN9R!)4T\M.#@U.2TQ("T^(%53+4%30TE).B!S=')I;F<H,3,I("(\03YA
M8F,_/S\\+T$^(@I497-T:6YG(%53+4%30TE)("T^(%541BTX.B!S=')I;F<H
M,3,I("(\03YA8F-A;V$\+T$^(@I497-T:6YG(%53+4%30TE)("T^($E33RTX
M.#4Y+3$Z('-T<FEN9R@Q,RD@(CQ!/F%B8V%O83PO03XB"@``````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S
M+UA-3%]087)S97(O=&5S=',O,#`S+G!H<'0`````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#(T,C(@,3`U,34T,S0Q,S0@,#(T,30Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"TM5$535"TM"EA-3"!087)S
M97(Z('!A<G-E(&9R;VT@9FEL92!R97-O=7)C90HM+5-+25!)1BTM"CP_<&AP
M(&EF("@A97AT96YS:6]N7VQO861E9"@B>&UL(BDI(&5C:&\@)W-K:7`G.R`_
M/@HM+49)3$4M+0H\/W!H<"`O+R`M*BT@0RLK("TJ+0HO+PHO+R!497-T(&9O
M<CH@6$U,+U!A<G-E<BYP:'`*+R\@4&%R=',@=&5S=&5D.B`M('!A<G-E<B!C
M<F5A=&EO;@HO+R`@("`@("`@("`@("`@("T@<V]M92!H86YD;&5R<PHO+R`@
M("`@("`@("`@("`@("T@<&%R<V4@9G)O;2!F:6QE(')E<V]U<F-E"B\O"F-H
M9&ER("AD:7)N86UE*%]?1DE,15]?*2D["@IR97%U:7)E7V]N8V4@(BXN+U!A
M<G-E<BYP:'`B.PH*8VQA<W,@7U]497-T4&%R<V5R,R!E>'1E;F1S(%A-3%]0
M87)S97(@>PH@("`@9G5N8W1I;VX@7U]497-T4&%R<V5R,R@I('L*("`@("`@
M("`D=&AI<RT^6$U,7U!A<G-E<B@I.PH@("`@?0H@("`@9G5N8W1I;VX@<W1A
M<G1(86YD;&5R*"1X<"P@)&5L96UE;G0L("1A='1R:6)S*2!["B`@("`@("`@
M<')I;G0@(CPD96QE;65N="(["B`@("`@("`@<F5S970H)&%T=')I8G,I.PH@
M("`@("`@('=H:6QE("AL:7-T*"1K97DL("1V86PI(#T@96%C:"@D871T<FEB
M<RDI('L*("`@("`@("`@("`@)&5N8R`](&AT;6QE;G1I=&EE<R@D=F%L*3L*
M("`@("`@("`@("`@<')I;G0@(B`D:V5Y/5PB)&5N8UPB(CL*("`@("`@("!]
M"B`@("`@("`@<')I;G0@(CXB.PH@("`@?0H@("`@9G5N8W1I;VX@96YD2&%N
M9&QE<B@D>'`L("1E;&5M96YT*2!["B`@("`@("`@<')I;G0@(CPO)&5L96UE
M;G0^7&XB.PH@("`@?0H@("`@9G5N8W1I;VX@8V1A=&%(86YD;&5R*"1X<"P@
M)&-D871A*2!["B`@("`@("`@<')I;G0@(CPA6T-$051!6R1C9&%T85U=/B([
M"B`@("!]"B`@("!F=6YC=&EO;B!D969A=6QT2&%N9&QE<B@D>'`L("1C9&%T
M82D@>PH*("`@('T*?0IP<FEN="`B;F5W(%]?5&5S=%!A<G-E<C,@(CL*=F%R
M7V1U;7`H9V5T7V-L87-S*"1O(#T@;F5W(%]?5&5S=%!A<G-E<C,H*2DI.PIP
M<FEN="`B9F]P96X@(CL*<')I;G0@:7-?<F5S;W5R8V4H)&9P(#T@9F]P96XH
M(G1E<W0S+GAM;"(L(")R(BDI+B)<;B(["G!R:6YT(")S971);G!U="`B.PIV
M87)?9'5M<"@D;RT^<V5T26YP=70H)&9P*2D["G!R:6YT(")P87)S92`B.PIV
M87)?9'5M<"@D;RT^<&%R<V4H*2D["@H_/@HM+4584$5#5"TM"FYE=R!?7U1E
M<W1087)S97(S('-T<FEN9R@Q,RD@(E]?=&5S='!A<G-E<C,B"F9O<&5N(#$*
M<V5T26YP=70@8F]O;"AT<G5E*0IP87)S92`\4D]/5#X\(5M#1$%405MF;V]=
M73X\+U)/3U0^"F)O;VPH=')U92D*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T<R\P,#0N
M<&AP=``````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3$R,2`Q,#4Q-30S-#$S
M-"`P,C0Q,S4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+2U415-4+2T*6$U,(%!A<G-E<CH@97)R;W(@8VQA<W,*+2U32TE0
M248M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D960H(GAM;"(I*2!E8VAO
M("=S:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`@+R\@+2HM($,K*R`M*BT*+R\*
M+R\@5&5S="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@
M+2!P87)S97(@97)R;W(@8VQA<W,*+R\*"G)E<75I<F5?;VYC92`B+BXO4&%R
M<V5R+G!H<"(["@IP<FEN="`B;F5W(%A-3%]087)S97(@(CL*=F%R7V1U;7`H
M9V5T7V-L87-S*"1P(#T@;F5W(%A-3%]087)S97(H*2DI.PHD92`]("1P+3YP
M87)S95-T<FEN9R@B/#]X;6P@=F5R<VEO;CTG,2XP)R`_/CQF;V\^/"]B87(^
M(BP@=')U92D["FEF("A014%2.CII<T5R<F]R*"1E*2D@>PH@("`@<')I;G1F
M*")E<G)O<B!M97-S86=E.B`E<UQN(BP@)&4M/F=E=$UE<W-A9V4H*2D["GT@
M96QS92!["B`@("!P<FEN="`B;F\@97)R;W)<;B(["GT*"C\^"BTM15A014-4
M+2T*;F5W(%A-3%]087)S97(@<W1R:6YG*#$P*2`B>&UL7W!A<G-E<B(*97)R
M;W(@;65S<V%G93H@6$U,7U!A<G-E<CH@;6ES;6%T8VAE9"!T86<@870@6$U,
M(&EN<'5T(&QI;F4@,0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,7U!A<G-E<B]T97-T
M<R\P,#(N<&AP=```````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q,B`Q,#4Q
M-30S-#$S-"`P,C0Q,S8`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````+2U415-4+2T*6$U,(%!A<G-E<CH@<&%R<V4@9G)O;2!F
M:6QE"BTM4TM)4$E&+2T*/#]P:'`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*")X
M;6PB*2D@96-H;R`G<VMI<"<[(#\^"BTM1DE,12TM"CP_<&AP("\O("TJ+2!#
M*RL@+2HM"B\O"B\O(%1E<W0@9F]R.B!834PO4&%R<V5R+G!H<`HO+R!087)T
M<R!T97-T960Z("T@<&%R<V5R(&-R96%T:6]N"B\O("`@("`@("`@("`@("`@
M+2!S;VUE(&AA;F1L97)S"B\O("`@("`@("`@("`@("`@+2!P87)S92!F<F]M
M(&9I;&4*+R\*8VAD:7(@*&1I<FYA;64H7U]&24Q%7U\I*3L*"G)E<75I<F5?
M;VYC92`B+BXO4&%R<V5R+G!H<"(["@IC;&%S<R!?7U1E<W1087)S97(R(&5X
M=&5N9',@6$U,7U!A<G-E<B!["B`@("!F=6YC=&EO;B!?7U1E<W1087)S97(R
M*"D@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R*"D["B`@("!]"B`@("!F
M=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP+"`D96QE;65N="P@)&%T=')I8G,I
M('L*("`@("`@("!P<FEN="`B/"1E;&5M96YT(CL*("`@("`@("!R97-E="@D
M871T<FEB<RD["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@)'9A;"D@/2!E
M86-H*"1A='1R:6)S*2D@>PH@("`@("`@("`@("`D96YC(#T@:'1M;&5N=&ET
M:65S*"1V86PI.PH@("`@("`@("`@("!P<FEN="`B("1K97D]7"(D96YC7"(B
M.PH@("`@("`@('T*("`@("`@("!P<FEN="`B/B(["B`@("!]"B`@("!F=6YC
M=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96UE;G0I('L*("`@("`@("!P<FEN
M="`B/"\D96QE;65N=#Y<;B(["B`@("!]"B`@("!F=6YC=&EO;B!C9&%T84AA
M;F1L97(H)'AP+"`D8V1A=&$I('L*("`@("`@("!P<FEN="`B/"%;0T1!5$%;
M)&-D871A75T^(CL*("`@('T*("`@(&9U;F-T:6]N(&1E9F%U;'1(86YD;&5R
M*"1X<"P@)&-D871A*2!["@H@("`@?0I]"G!R:6YT(")N97<@7U]497-T4&%R
M<V5R,B`B.PIV87)?9'5M<"AG971?8VQA<W,H)&\@/2!N97<@7U]497-T4&%R
M<V5R,B@I*2D["G!R:6YT(")S971);G!U=$9I;&4@(CL*<')I;G0@:7-?<F5S
M;W5R8V4H)&\M/G-E=$EN<'5T1FEL92@B=&5S=#(N>&UL(BDI+B)<;B(["G!R
M:6YT(")P87)S92`B.PIV87)?9'5M<"@D;RT^<&%R<V4H*2D["@H_/@HM+458
M4$5#5"TM"FYE=R!?7U1E<W1087)S97(R('-T<FEN9R@Q,RD@(E]?=&5S='!A
M<G-E<C(B"G-E=$EN<'5T1FEL92`Q"G!A<G-E(#Q23T]4/CPA6T-$051!6V9O
M;UU=/CPO4D]/5#X*8F]O;"AT<G5E*0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]T97-T<R]834Q?4&%R<V5R+W1E<W1S+W1E<W0R+GAM;```````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#0W(#$P-3$U-#,T,3,T(#`R-#4R-@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/WAM;"!V97)S
M:6]N/2<Q+C`G(#\^"CQR;V]T/F9O;SPO<F]O=#X`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O=&5S=',O6$U,
M7U!A<G-E<B]T97-T<R]T97-T,RYX;6P`````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`T-R`Q,#4Q-30S-#$S-"`P,C0U,C<`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]X;6P@=F5R<VEO;CTG,2XP)R`_
M/@H\<F]O=#YF;V\\+W)O;W0^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+W1E<W1S+UA-3%]087)S97(O=&5S
M=',O,#`Q+G!H<'0`````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(R,S<@,3`U
M,34T,S0Q,S0@,#(T,30S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"TM5$535"TM"EA-3"!087)S97(Z('!A<G-E('-I;7!L
M92!S=')I;F<*+2U32TE0248M+0H\/W!H<"!I9B`H(65X=&5N<VEO;E]L;V%D
M960H(GAM;"(I*2!E8VAO("=S:VEP)SL@/SX*+2U&24Q%+2T*/#]P:'`*+R\*
M+R\@5&5S="!F;W(Z(%A-3"]087)S97(N<&AP"B\O(%!A<G1S('1E<W1E9#H@
M+2!P87)S97(@8W)E871I;VX*+R\@("`@("`@("`@("`@("`M('-O;64@:&%N
M9&QE<G,*+R\@("`@("`@("`@("`@("`M('!A<G-E('-I;7!L92!S=')I;F<*
M+R\*"G)E<75I<F5?;VYC92`B+BXO4&%R<V5R+G!H<"(["@IC;&%S<R!?7U1E
M<W1087)S97(Q(&5X=&5N9',@6$U,7U!A<G-E<B!["B`@("!F=6YC=&EO;B!?
M7U1E<W1087)S97(Q*"D@>PH@("`@("`@("1T:&ES+3Y834Q?4&%R<V5R*"D[
M"B`@("!]"B`@("!F=6YC=&EO;B!S=&%R=$AA;F1L97(H)'AP+"`D96QE;65N
M="P@)&%T=')I8G,I('L*("`@("`@("!P<FEN="`B/"1E;&5M96YT(CL*("`@
M("`@("!R97-E="@D871T<FEB<RD["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME
M>2P@)'9A;"D@/2!E86-H*"1A='1R:6)S*2D@>PH@("`@("`@("`@("`D96YC
M(#T@:'1M;&5N=&ET:65S*"1V86PI.PH@("`@("`@("`@("!P<FEN="`B("1K
M97D]7"(D96YC7"(B.PH@("`@("`@('T*("`@("`@("!P<FEN="`B/B(["B`@
M("!]"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1X<"P@)&5L96UE;G0I('L*
M("`@("`@("!P<FEN="`B/"\D96QE;65N=#Y<;B(["B`@("!]"B`@("!F=6YC
M=&EO;B!C9&%T84AA;F1L97(H)'AP+"`D8V1A=&$I('L*("`@("`@("!P<FEN
M="`B/"%;0T1!5$%;)&-D871A75T^(CL*("`@('T*("`@(&9U;F-T:6]N(&1E
M9F%U;'1(86YD;&5R*"1X<"P@)&-D871A*2!["@H@("`@?0I]"F5R<F]R7W)E
M<&]R=&EN9R@Q,#(S*3L*<')I;G0@(FYE=R!?7U1E<W1087)S97(Q("(["G9A
M<E]D=6UP*&=E=%]C;&%S<R@D;R`](&YE=R!?7U1E<W1087)S97(Q*"DI*3L*
M<')I;G0@(G!A<G-E4W1R:6YG("(["G9A<E]D=6UP*"1O+3YP87)S95-T<FEN
M9R@B/#]X;6P@=F5R<VEO;CTG,2XP)R`_/CQR;V]T/F9O;SPO<F]O=#XB+"`Q
M*2D["@H_/@HM+4584$5#5"TM"FYE=R!?7U1E<W1087)S97(Q('-T<FEN9R@Q
M,RD@(E]?=&5S='!A<G-E<C$B"G!A<G-E4W1R:6YG(#Q23T]4/CPA6T-$051!
M6V9O;UU=/CPO4D]/5#X*8F]O;"AT<G5E*0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O3U,O1W5E<W,N<&AP````````````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`R-3<U-R`Q,#4Q-30S-#$S-"`P,C`V,C(`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`-"B\J
M*@T*("H@5&AE($]37T=U97-S(&-L87-S#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9V]R>2!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z($=U97-S+G!H<"QV(#$N,C`@,C`P-2\Q,"\R
M-B`Q.3HS,SHP,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!014%2(#`N,0T*("HO#0H-"B\O('M[>R!U
M;F%M92!E>&%M<&QE<PT*#0HO+R!P:'!?=6YA;64H*2!W:71H;W5T(&%R9W,@
M<F5T=7)N<R!T:&4@<V%M92!A<R`G=6YA;64@+6$G+"!O<B!A(%!(4"UC=7-T
M;VT-"B\O('-T<FEN9R!F;W(@5VEN9&]W<RX-"B\O(%!(4"!V97)S:6]N<R!P
M<FEO<B!T;R`T+C,@<F5T=7)N('1H92!U;F%M92!O9B!T:&4@:&]S="!W:&5R
M92!02%`@=V%S(&)U:6QT+`T*+R\@87,@;V8@-"XS(&ET(')E='5R;G,@=&AE
M('5N86UE(&]F('1H92!H;W-T(')U;FYI;F<@=&AE(%!(4"!C;V1E+@T*+R\-
M"B\O(%!#(%)E9$AA="!,:6YU>"`W+C$Z#0HO+R!,:6YU>"!H;W-T+F5X86UP
M;&4N8V]M(#(N-"XR+3(@(S$@4W5N($%P<B`X(#(P.C0Q.C,P($5$5"`R,#`Q
M(&DV.#8@=6YK;F]W;@T*+R\-"B\O(%!#($1E8FEA;B!0;W1A=&\Z#0HO+R!,
M:6YU>"!H;W-T(#(N-"XQ-R`C,B!335`@5'5E($9E8B`Q,B`Q-3HQ,#HP-"!#
M150@,C`P,B!I-C@V('5N:VYO=VX-"B\O#0HO+R!00R!&<F5E0E-$(#,N,SH-
M"B\O($9R965"4T0@:&]S="YE>&%M<&QE+F-O;2`S+C,M4U1!0DQ%($9R965"
M4T0@,RXS+5-404),12`C,#H@36]N($9E8B`R,2`P,#HT,CHS,2!#150@,C`P
M,"`@("`@<F]O=$!E>&%M<&QE+F-O;3HO=7-R+W-R8R]S>7,O8V]M<&EL92]#
M3TY&24<@(&DS.#8-"B\O#0HO+R!00R!&<F5E0E-$(#0N,SH-"B\O($9R965"
M4T0@:&]S="YE>&%M<&QE+F-O;2`T+C,M4D5,14%312!&<F5E0E-$(#0N,RU2
M14Q%05-%(",Q.B!-;VX@2G5N(#(U(#$Q.C$Y.C0S($5$5"`R,#`Q("`@("!R
M;V]T0&5X86UP;&4N8V]M.B]U<W(O<W)C+W-Y<R]C;VUP:6QE+T-/3D9)1R`@
M:3,X-@T*+R\-"B\O(%!#($9R965"4T0@-"XU.@T*+R\@1G)E94)31"!H;W-T
M+F5X86UP;&4N8V]M(#0N-2U35$%"3$4@1G)E94)31"`T+C4M4U1!0DQ%(",P
M.B!7960@1F5B("`V(#(S.C4Y.C(S($-%5"`R,#`R("`@("!R;V]T0&5X86UP
M;&4N8V]M.B]U<W(O<W)C+W-Y<R]C;VUP:6QE+T-/3D9)1R`@:3,X-@T*+R\-
M"B\O(%!#($9R965"4T0@-"XU('<O=6YA;64@9G)O;2!'3E4@<VAE;&QU=&EL
M<SH-"B\O($9R965"4T0@:&]S="YE>&%M<&QE+F-O;2`T+C4M4U1!0DQ%($9R
M965"4T0@-"XU+5-404),12`C,#H@5V5D($9E8B`@:3,X-B!U;FMN;W=N#0HO
M+PT*+R\@2%`@.3`P,"\W,3(@2%`M55@@,3`Z#0HO+R!(4"U56"!I<2!"+C$P
M+C$P($$@.3`P,"\W,3(@,C`P.#0R.3$Q,R!T=V\M=7-E<B!L:6-E;G-E#0HO
M+PT*+R\@2%`@.3`P,"\W,3(@2%`M55@@,3`@=R]U;F%M92!F<F]M($=.52!S
M:&5L;'5T:6QS.@T*+R\@2%`M55@@:&]S="!"+C$P+C$P($$@.3`P,"\W,3(@
M=6YK;F]W;@T*+R\-"B\O($E"32!24S8P,#`O-34P($%)6"`T+C,Z#0HO+R!!
M25@@:&]S="`S(#0@,#`P,#`S-3,Q0S`P#0HO+PT*+R\@04E8(#0N,R!W+W5N
M86UE(&9R;VT@1TY5('-H96QL=71I;',Z#0HO+R!!25@@:&]S="`S(#0@,#`P
M,#`S-3,Q0S`P('5N:VYO=VX-"B\O#0HO+R!31TD@3VYY>"!)4DE8(#8N-2!W
M+W5N86UE(&9R;VT@1TY5('-H96QL=71I;',Z#0HO+R!)4DE8-C0@:&]S="`V
M+C4@,#$P.3$X,C`@25`Q.2!M:7!S#0HO+PT*+R\@4T=)($]N>7@@25))6"`V
M+C4Z#0HO+R!)4DE8-C0@:&]S="`V+C4@,#$P.3$X,C`@25`Q.0T*+R\-"B\O
M(%-P87)C4W1A=&EO;B`R,"!3;VQA<FES(#@@=R]U;F%M92!F<F]M($=.52!S
M:&5L;'5T:6QS.@T*+R\@4W5N3U,@:&]S="YE>&%M<&QE+F-O;2`U+C@@1V5N
M97)I8U\Q,#@U,C@M,3(@<W5N-&T@<W!A<F,-"B\O#0HO+R!3<&%R8U-T871I
M;VX@,C`@4V]L87)I<R`X.@T*+R\@4W5N3U,@:&]S="YE>&%M<&QE+F-O;2`U
M+C@@1V5N97)I8U\Q,#@U,C@M,3(@<W5N-&T@<W!A<F,@4U5.5RQ34$%20W-T
M871I;VXM,C`-"B\O#0HO+R!-86,@3U,@6"`H1&%R=VEN*0T*+R\@1&%R=VEN
M(&AO;64M961E;BYL;V-A;"`W+C4N,"!$87)W:6X@2V5R;F5L(%9E<G-I;VX@
M-RXU+C`Z(%1H=2!!=6<@(#4@,3DZ,C8Z,38@4$14(#(P,#0[(')O;W0Z>&YU
M+WAN=2TU,3<N-RXR,2YO8FI^,R]214Q%05-%7U!00R`@4&]W97(@36%C:6YT
M;W-H#0HO+PT*+R\@36%C($]3(%@@96%R;'D@=F5R<VEO;G,-"B\O(`T*#0HO
M+R!]?7T-"@T*+RH@5$]$3SH-"B`J("T@9&5F:6YE(&5N9&EA;FYE<W,L('1O
M(&%L;&]W(&UA=&-H4VEG;F%T=7)E*")B:6=E;F0B*2!E=&,N#0H@*B\-"@T*
M+RHJ#0H@*B!2971R:65V97,@:6YF;W)M871I;VX@86)O=70@=&AE(&-U<G)E
M;G0@;W!E<F%T:6YG('-Y<W1E;0T*("H-"B`J(%1H:7,@8VQA<W,@=7-E<R!P
M:'!?=6YA;64H*2!T;R!G<F]K(&EN9F]R;6%T:6]N(&%B;W5T('1H92!C=7)R
M96YT($]3#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N
M;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9V]R>2!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA<W,@3U-?1W5E<W,-"GL-
M"B`@("!V87(@)'-Y<VYA;64[#0H@("`@=F%R("1N;V1E;F%M93L-"B`@("!V
M87(@)&-P=3L-"B`@("!V87(@)')E;&5A<V4[#0H@("`@=F%R("1E>'1R83L-
M"@T*("`@(&9U;F-T:6]N($]37T=U97-S*"1U;F%M92`](&YU;&PI#0H@("`@
M>PT*("`@("`@("!L:7-T*"1T:&ES+3YS>7-N86UE+`T*("`@("`@("`@("`@
M("1T:&ES+3YR96QE87-E+`T*("`@("`@("`@("`@("1T:&ES+3YC<'4L#0H@
M("`@("`@("`@("`@)'1H:7,M/F5X=')A+`T*("`@("`@("`@("`@("1T:&ES
M+3YN;V1E;F%M92D@/2`D=&AI<RT^<&%R<V53:6=N871U<F4H)'5N86UE*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!P87)S95-I9VYA='5R92@D=6YA;64@
M/2!N=6QL*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1S>7-M87`@/2!A<G)A
M>2@-"B`@("`@("`@("`@("=(4"U56"<@/3X@)VAP=7@G+`T*("`@("`@("`@
M("`@)TE225@V-"<@/3X@)VER:7@G+`T*("`@("`@("`I.PT*("`@("`@("!S
M=&%T:6,@)&-P=6UA<"`](&%R<F%Y*`T*("`@("`@("`@("`@)VDU.#8G(#T^
M("=I,S@V)RP-"B`@("`@("`@("`@("=I-C@V)R`]/B`G:3,X-B<L#0H@("`@
M("`@("`@("`G<'!C)R`]/B`G<&]W97)P8R<L#0H@("`@("`@("D[#0H@("`@
M("`@(&EF("@D=6YA;64@/3T](&YU;&PI('L-"B`@("`@("`@("`@("1U;F%M
M92`]('!H<%]U;F%M92@I.PT*("`@("`@("!]#0H@("`@("`@("1P87)T<R`]
M('-P;&ET*"=;6SIS<&%C93I=72LG+"!T<FEM*"1U;F%M92DI.PT*("`@("`@
M("`D;B`](&-O=6YT*"1P87)T<RD[#0H-"B`@("`@("`@)')E;&5A<V4@/2`D
M;6%C:&EN92`]("1C<'4@/2`G)SL-"B`@("`@("`@)'-Y<VYA;64@/2`D<&%R
M='-;,%T[#0H@("`@("`@("1N;V1E;F%M92`]("1P87)T<ULQ73L-"B`@("`@
M("`@)&-P=2`]("1P87)T<ULD;BTQ73L-"B`@("`@("`@)&5X=')A(#T@)R<[
M#0H@("`@("`@(&EF("@D8W!U(#T]("=U;FMN;W=N)RD@>PT*("`@("`@("`@
M("`@)&-P=2`]("1P87)T<ULD;BTR73L-"B`@("`@("`@?0T*#0H@("`@("`@
M('-W:71C:"`H)'-Y<VYA;64I('L-"B`@("`@("`@("`@(&-A<V4@)T%)6"<@
M.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@(B1P87)T<ULS72XD<&%R
M='-;,ETB.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92`G5VEN9&]W<R<@.@T*("`@("`@("`@("`@("`@('-W:71C:"`H)'!A
M<G1S6S%=*2![#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)SDU+SDX)SH-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E(#T@)SEX)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M("`@("!D969A=6QT.@T*("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A
M<V4@/2`D<&%R='-;,5T[#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-P=2`]
M("=I,S@V)SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@)TQI;G5X)R`Z#0H@("`@("`@("`@("`@("`@)&5X=')A(#T@)'1H
M:7,M/E]D971E8W1';&EB8U9E<G-I;VXH*3L-"B`@("`@("`@("`@("`@("`O
M+R!U<V4@;VYL>2!T:&4@9FER<W0@='=O(&1I9VET<R!F<F]M('1H92!K97)N
M96P@=F5R<VEO;@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@97)E9U]R
M97!L86-E*"=>*%M;.F1I9VET.EU=*UPN6ULZ9&EG:70Z75TK*2XJ)RP@)UPQ
M)RP@)'!A<G1S6S)=*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@(&-A<V4@)TUA8R<@.@T*("`@("`@("`@("`@("`@("1S>7-N86UE
M(#T@)V1A<G=I;B<[#0H@("`@("`@("`@("`@("`@)&YO9&5N86UE(#T@)'!A
M<G1S6S)=.PT*("`@("`@("`@("`@("`@("1R96QE87-E(#T@)'!A<G1S6S-=
M.PT*("`@("`@("`@("`@("`@(&EF("@D8W!U(#T]("=-86-I;G1O<V@G*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<&%R='-;)&X@+2`R72`]/2`G
M4&]W97(G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W!U(#T@)W!O
M=V5R<&,G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G1&%R=VEN)R`Z#0H@("`@("`@("`@("`@("`@:68@*"1C<'4@/3T@)TUA
M8VEN=&]S:"<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P87)T<ULD
M;B`M(#)=(#T]("=0;W=E<B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C<'4@/2`G<&]W97)P8R<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E;&5A<V4@/2!E
M<F5G7W)E<&QA8V4H)UXH6ULZ9&EG:70Z75TK7"Y;6SID:6=I=#I=72LI+BHG
M+"`G7#$G+"`D<&%R='-;,ETI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("`D<F5L96%S
M92`](&5R96=?<F5P;&%C92@G+2XJ)RP@)R<L("1P87)T<ULR72D[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"@T*#0H@("`@("`@(&EF
M("AI<W-E="@D<WES;6%P6R1S>7-N86UE72DI('L-"B`@("`@("`@("`@("1S
M>7-N86UE(#T@)'-Y<VUA<%LD<WES;F%M95T[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`D<WES;F%M92`]('-T<G1O;&]W97(H)'-Y<VYA;64I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D8W!U;6%P6R1C<'5=
M*2D@>PT*("`@("`@("`@("`@)&-P=2`]("1C<'5M87!;)&-P=5T[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1S>7-N86UE+"`D<F5L96%S
M92P@)&-P=2P@)&5X=')A+"`D;F]D96YA;64I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]D971E8W1';&EB8U9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@
M<W1A=&EC("1G;&EB8R`](&9A;'-E.PT*("`@("`@("!I9B`H)&=L:6)C("$]
M/2!F86QS92D@>PT*("`@("`@("`@("`@<F5T=7)N("1G;&EB8SL@+R\@;F\@
M;F5E9"!T;R!R=6X@=&AI<R!M=6QT:7!L92!T:6UE<PT*("`@("`@("!]#0H@
M("`@("`@(&EN8VQU9&5?;VYC92`B4WES=&5M+G!H<"([#0H@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)R]U<W(O8FEN+V-P<"<I('Q\("%I<U]E>&5C=71A
M8FQE*"<O=7-R+V)I;B]C<'`G*2D@>PT*("`@("`@("`@("`@+R\@57-E(&=L
M:6)C)W,@/&9E871U<F5S+F@^(&AE861E<B!F:6QE('1O#0H@("`@("`@("`@
M("`O+R!G970@;6%J;W(@86YD(&UI;F]R('9E<G-I;VX@;G5M8F5R.@T*("`@
M("`@("`@("`@:68@*"1F96%T=7)E<U]F:6QE(#T@0&9O<&5N*"<O=7-R+VEN
M8VQU9&4O9F5A='5R97,N:"<L("=R8B<I("D@>PT*("`@("`@("`@("`@("`@
M('=H:6QE("@A9F5O9B@D9F5A='5R97-?9FEL92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&QI;F4@/2!F9V5T<R@D9F5A='5R97-?9FEL92P@.#$Y,BD[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A)&QI;F4@?'P@*'-T<G!O<R@D
M;&EN92P@)R-D969I;F4G*2`]/3T@9F%L<V4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1L:6YE+"`G7U]'3$E"
M0U]?)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&UA:F]R('9E
M<G-I;VX@;G5M8F5R("-D969I;F4@7U]'3$E"0U]?('9E<G-I;VX-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1L:6YE(#T@<')E9U]S<&QI="@G+UQS*R\G
M+"`D;&EN92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D9VQI8F-?;6%J
M;W(@/2!T<FEM*"1L:6YE6S)=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9VQI8F-?;6EN;W(I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S
M*"1L:6YE+"`G7U]'3$E"0U]-24Y/4E]?)RDI("![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!G;W0@=&AE(&UI;F]R('9E<G-I;VX@;G5M8F5R#0H@
M("`@("`@("`@("`@("`@("`@("`@("`O+R`C9&5F:6YE(%]?1TQ)0D-?34E.
M3U)?7R!V97)S:6]N#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&EN92`]
M('!R96=?<W!L:70H)R]<<RLO)RP@)&QI;F4I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&=L:6)C7VUI;F]R(#T@=')I;2@D;&EN95LR72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=L:6)C7VUA:F]R*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F96%T=7)E<U]F:6QE
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1G;&EB8U]M86IO<BD@
M?'P@(6ES<V5T*"1G;&EB8U]M:6YO<BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1G;&EB8R`]("<G.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@)&=L:6)C(#T@)V=L:6)C)R`N('1R:6TH
M)&=L:6)C7VUA:F]R*2`N("(N(B`N('1R:6TH)&=L:6)C7VUI;F]R*2`[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&=L:6)C(#T@)R<[
M#0H@("`@("`@('T-"B`@("`@("`@)'1M<&9I;&4@/2!3>7-T96TZ.FUK=&5M
M<"@B9VQI8F-T97-T(BD[#0H@("`@("`@("1F<"`](&9O<&5N*"1T;7!F:6QE
M+"`B=R(I.PT*("`@("`@("!F=W)I=&4H)&9P+"`B(VEN8VQU9&4@/&9E871U
M<F5S+F@^7&Y?7T=,24)#7U\@7U]'3$E"0U]-24Y/4E]?7&XB*3L-"B`@("`@
M("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("1C<'`@/2!P;W!E;B@B+W5S<B]B
M:6XO8W!P("1T;7!F:6QE(BP@(G(B*3L-"B`@("`@("`@)&UA:F]R(#T@)&UI
M;F]R(#T@,#L-"B`@("`@("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)&-P<"P@
M,3`R-"DI('L-"B`@("`@("`@("`@(&EF("@D;&EN97LP?2`]/2`G(R<@?'P@
M=')I;2@D;&EN92D@/3T@)R<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AL:7-T*"1M86IO
M<BP@)&UI;F]R*2`](&5X<&QO9&4H)R`G+"!T<FEM*"1L:6YE*2DI('L-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!P8VQO<V4H)&-P<"D[#0H@("`@("`@('5N;&EN:R@D=&UP
M9FEL92D[#0H@("`@("`@(&EF("@A*"1M86IO<B`F)B`D;6EN;W(I("8F(&ES
M7VQI;FLH)R]L:6(O;&EB8RYS;RXV)RDI('L-"B`@("`@("`@("`@("\O($QE
M="=S('1R>2!R96%D:6YG('1H92!L:6)C+G-O+C8@<WEM;&EN:PT*("`@("`@
M("`@("`@:68@*&5R96<H)UYL:6)C+2A;+BI=*5PN<V\D)RP@8F%S96YA;64H
M<F5A9&QI;FLH)R]L:6(O;&EB8RYS;RXV)RDI+"`D;6%T8VAE<RDI('L-"B`@
M("`@("`@("`@("`@("!L:7-T*"1M86IO<BP@)&UI;F]R*2`](&5X<&QO9&4H
M)RXG+"`D;6%T8VAE<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$H)&UA:F]R("8F("1M:6YO<BDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D9VQI8F,@/2`G)SL-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)&=L:6)C(#T@(F=L:6)C>R1M86IO<GTN>R1M:6YO<GTB.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=%-I9VYA='5R92@I#0H@("`@>PT*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/F5X=')A*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(")[)'1H:7,M/G-Y<VYA;65]+7LD=&AI<RT^<F5L96%S97TM>R1T:&ES
M+3YC<'5](CL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@(GLD=&AI<RT^
M<WES;F%M97TM>R1T:&ES+3YR96QE87-E?2U[)'1H:7,M/F-P=7TM>R1T:&ES
M+3YE>'1R87TB.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%-Y<VYA;64H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YS>7-N86UE.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$YO9&5N86UE*"D-"B`@("![#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^;F]D96YA;64[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T0W!U*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^
M8W!U.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%)E;&5A<V4H*0T*("`@
M('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YR96QE87-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=$5X=')A*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^97AT<F$[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@;6%T8VA3
M:6=N871U<F4H)&UA=&-H*0T*("`@('L-"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1M871C:"DI('L-"B`@("`@("`@("`@("1F<F%G;65N=',@/2`D;6%T8V@[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D9G)A9VUE;G1S(#T@
M97AP;&]D92@G+2<L("1M871C:"D[#0H@("`@("`@('T-"B`@("`@("`@)&X@
M/2!C;W5N="@D9G)A9VUE;G1S*3L-"B`@("`@("`@)&UA=&-H97,@/2`P.PT*
M("`@("`@("!I9B`H)&X@/B`P*2![#0H@("`@("`@("`@("`D;6%T8VAE<R`K
M/2`D=&AI<RT^7VUA=&-H1G)A9VUE;G0H)&9R86=M96YT<ULP72P@)'1H:7,M
M/G-Y<VYA;64I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;B`^(#$I('L-
M"B`@("`@("`@("`@("1M871C:&5S("L]("1T:&ES+3Y?;6%T8VA&<F%G;65N
M="@D9G)A9VUE;G1S6S%=+"`D=&AI<RT^<F5L96%S92D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1N(#X@,BD@>PT*("`@("`@("`@("`@)&UA=&-H97,@
M*ST@)'1H:7,M/E]M871C:$9R86=M96YT*"1F<F%G;65N='-;,ETL("1T:&ES
M+3YC<'4I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;B`^(#,I('L-"B`@
M("`@("`@("`@("1M871C:&5S("L]("1T:&ES+3Y?;6%T8VA&<F%G;65N="@D
M9G)A9VUE;G1S6S-=+"`D=&AI<RT^97AT<F$I.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`H)&UA=&-H97,@/3T@)&XI.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]M871C:$9R86=M96YT*"1F<F%G;65N="P@)'9A;'5E*0T*("`@
M('L-"B`@("`@("`@:68@*'-T<F-S<&XH)&9R86=M96YT+"`G*C\G*2`\('-T
M<FQE;B@D9G)A9VUE;G0I*2![#0H@("`@("`@("`@("`D<F5G(#T@)UXG("X@
M<W1R7W)E<&QA8V4H87)R87DH)RHG+"`G/R<L("<O)RDL(&%R<F%Y*"<N*B<L
M("<N)RP@)UQ<+R<I+"`D9G)A9VUE;G0I("X@)R0G.PT*("`@("`@("`@("`@
M<F5T=7)N(&5R96=I*"1R96<L("1V86QU92D[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("@D9G)A9VUE;G0@/3T@)RHG('Q\("%S=')C87-E8VUP*"1F
M<F%G;65N="P@)'9A;'5E*2D[#0H@("`@?0T*#0I]#0HO*@T*("H@3&]C86P@
M5F%R:6%B;&5S.@T*("H@:6YD96YT+71A8G,M;6]D93H@;FEL#0H@*B!C+6)A
M<VEC+6]F9G-E=#H@-`T*("H@16YD.@T*("HO#0H_/@T*````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O1&]W;FQO
M861E<@``````````````````````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q,S0@,#(Q,C,P`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]487-K````````````````````````````````````````
M```````````````````````````````````````````P,#`W-34@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-"`P,C`P,S0`(#4`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U9A;&ED871O<@``````````
M````````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,3,T(#`R,3`U-P`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M0V]M;6%N9```````````````````````````````````````````````````
M````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S0@,#(P-3$P`"`U````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]215-4````````````````````````````````
M```````````````````````````````````````````````````P,#`W-34@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-"`P,3<W
M,#<`(#4`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T9R;VYT96YD````
M````````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,3,T(#`R,#<Q,0`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O26YS=&%L;&5R````````````````````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S0@,#(Q,#8W`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL90``````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M-"`P,C$R-C4`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-H86YN
M96Q&:6QE````````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,T(#`R,3,P,@`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O1&]W;FQO861E<BYP:'``````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`Q-C8T,3,@,3`U,34T,S0Q,S0@,#(R,#,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?1&]W;FQO861E<BP@=&AE(%!%05(@26YS=&%L;&5R
M)W,@9&]W;FQO860@=71I;&ET>2!C;&%S<PT*("H-"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N(%8N
M($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@36%R=&EN
M($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!$;W=N;&]A9&5R+G!H<"QV(#$N.3D@,C`P
M-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,RXP#0H@*B\-
M"@T*+RHJ#0H@*B!.965D960@9F]R(&-O;G-T86YT<RP@97AT96YD:6YG#0H@
M*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM;VXN<&AP)SL-"@T*9&5F:6YE
M*"=014%27TE.4U1!3$Q%4E]/2R<L("`@("`@(#$I.PT*9&5F:6YE*"=014%2
M7TE.4U1!3$Q%4E]&04E,140G+"`@(#`I.PT*9&5F:6YE*"=014%27TE.4U1!
M3$Q%4E]32TE04$5$)RP@+3$I.PT*9&5F:6YE*"=014%27TE.4U1!3$Q%4E]%
M4E)/4E].3U]04D5&7U-4051%)RP@,BD[#0H-"B\J*@T*("H@061M:6YI<W1R
M871I;VX@8VQA<W,@=7-E9"!T;R!D;W=N;&]A9"!A;GET:&EN9R!F<F]M('1H
M92!I;G1E<FYE="`H4$5!4B!086-K86=E<RP-"B`J('-T871I8R!54DQS+"!X
M;6P@9FEL97,I#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P
M:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`
M:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM
M:D!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C,N,`T*("HO#0IC;&%S<R!014%27T1O
M=VYL;V%D97(@97AT96YD<R!014%27T-O;6UO;@T*>PT*("`@("\J*@T*("`@
M("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7W)E9VES=')Y.PT*#0H@("`@+RHJ#0H@
M("`@("H@0'9A<B!014%27U)E;6]T90T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7W)E;6]T93L-"@T*("`@("\J*@T*("`@
M("`J(%!R969E<G)E9"!);G-T86QL871I;VX@4W1A=&4@*'-N87!S:&]T+"!D
M979E;"P@86QP:&$L(&)E=&$L('-T86)L92D-"B`@("`@*B!`=F%R('-T<FEN
M9WQN=6QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M=F%R("1?<')E9F5R<F5D4W1A=&4[#0H-"B`@("`O*BH-"B`@("`@*B!/<'1I
M;VYS(&9R;VT@8V]M;6%N9"UL:6YE('!A<W-E9"!T;R!);G-T86QL+@T*("`@
M("`J#0H@("`@("H@4F5C;V=N:7IE9"!O<'1I;VYS.CQB<B`O/@T*("`@("`J
M("`M(&]N;'ER97%D97!S("`@.B!I;G-T86QL(&%L;"!R97%U:7)E9"!D97!E
M;F1E;F-I97,@87,@=V5L;`T*("`@("`J("`M(&%L;&1E<',@("`@("`@.B!I
M;G-T86QL(&%L;"!D97!E;F1E;F-I97,L(&EN8VQU9&EN9R!O<'1I;VYA;`T*
M("`@("`J("`M(&EN<W1A;&QR;V]T("`@.B!B87-E(')E;&%T:79E('!A=&@@
M=&\@:6YS=&%L;"!F:6QE<R!I;@T*("`@("`J("`M(&9O<F-E("`@("`@("`@
M.B!F;W)C92!A(&1O=VYL;V%D(&5V96X@:68@=V%R;FEN9W,@=V]U;&0@<')E
M=F5N="!I=`T*("`@("`J("`M(&YO8V]M<')E<W,@("`@.B!D;W=N;&]A9"!U
M;F-O;7!R97-S960@=&%R8F%L;',-"B`@("`@*B!`<V5E(%!%05)?0V]M;6%N
M9%]);G-T86QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'9A
M<B!A<G)A>0T*("`@("`J+PT*("`@('9A<B`D7V]P=&EO;G,[#0H-"B`@("`O
M*BH-"B`@("`@*B!$;W=N;&]A9&5D(%!A8VMA9V5S(&%F=&5R(&$@8V%L;"!T
M;R!D;W=N;&]A9"@I+@T*("`@("`J#0H@("`@("H@1F]R;6%T(&]F(&5A8V@@
M96YT<GDZ#0H@("`@("H-"B`@("`@*B`\8V]D93X-"B`@("`@*B!A<G)A>2@G
M<&MG)R`]/B`G<&%C:V%G95]N86UE)RP@)V9I;&4G(#T^("<O<&%T:"]T;R]L
M;V-A;"]F:6QE)RP-"B`@("`@*B`@("`G:6YF;R<@/3X@87)R87DH*2`O+R!P
M87)S960@<&%C:V%G92YX;6P-"B`@("`@*B`I.PT*("`@("`J(#PO8V]D93X-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B!`=F%R(&%R<F%Y#0H@
M("`@("HO#0H@("`@=F%R("1?9&]W;FQO861E9%!A8VMA9V5S(#T@87)R87DH
M*3L-"@T*("`@("\J*@T*("`@("`J(%!A8VMA9V5S('-L871E9"!F;W(@9&]W
M;FQO860N#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('5S960@=&\@<')E=F5N
M="!D;W=N;&]A9&EN9R!A('!A8VMA9V4@;6]R92!T:&%N(&]N8V4@<VAO=6QD
M(&ET(&)E(&$@9&5P96YD96YC>0T*("`@("`J(&9O<B!T=V\@<&%C:V%G97,@
M=&\@8F4@:6YS=&%L;&5D+@T*("`@("`J($9O<FUA="!O9B!E86-H(&5N=')Y
M.@T*("`@("`J#0H@("`@("H@/'!R93X-"B`@("`@*B!A<G)A>2@G<&%C:V%G
M95]N86UE,2<@/3X@<&%R<V5D('!A8VMA9V4N>&UL+"`G<&%C:V%G95]N86UE
M,B<@/3X@<&%R<V5D('!A8VMA9V4N>&UL+`T*("`@("`J("D[#0H@("`@("H@
M/"]P<F4^#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J+PT*("`@('9A<B`D7W1O1&]W;FQO860@/2!A<G)A>2@I
M.PT*#0H@("`@+RHJ#0H@("`@("H@07)R87D@;V8@979E<GD@<&%C:V%G92!I
M;G-T86QL960L('=I=&@@;F%M97,@;&]W97(M8V%S960N#0H@("`@("H-"B`@
M("`@*B!&;W)M870Z#0H@("`@("H@/&-O9&4^#0H@("`@("H@87)R87DH)W!A
M8VMA9V4Q)R`]/B`P+"`G<&%C:V%G93(G(#T^(#$L("D[#0H@("`@("H@/"]C
M;V1E/@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]I
M;G-T86QL960@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!A
M<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A
M<B`D7V5R<F]R4W1A8VL@/2!A<G)A>2@I.PT*("`@(`T*("`@("\J*@T*("`@
M("`J($!V87(@8F]O;&5A;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@('9A<B`D7VEN=&5R;F%L1&]W;FQO860@/2!F86QS93L-"@T*
M("`@("\J*@T*("`@("`J(%1E;7!O<F%R>2!V87)I86)L92!U<V5D(&EN('-O
M<G1I;F<@<&%C:V%G97,@8GD@9&5P96YD96YC>2!I;B![0&QI;FL@<V]R=%!K
M9T1E<',H*7T-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<&%C:V%G95-O<G14<F5E.PT*
M#0H@("`@+RHJ#0H@("`@("H@5&5M<&]R87)Y(&1I<F5C=&]R>2P@;W(@8V]N
M9FEG=7)A=&EO;B!V86QU92!W:&5R92!D;W=N;&]A9',@=VEL;"!O8V-U<@T*
M("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1?9&]W;FQO
M861$:7([#0H@("`@+R\@>WM[(%!%05)?1&]W;FQO861E<B@I#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9%\J#0H@("`@("H@0'!A
M<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@4$5!4E]$;W=N;&]A9&5R*"8D=6DL("1O<'1I;VYS
M+"`F)&-O;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM
M;VXH*3L-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@
M("`@("`@("1T:&ES+3YC;VYF:6<@/2`F)&-O;F9I9SL-"B`@("`@("`@)'1H
M:7,M/E]P<F5F97)R9613=&%T92`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E
M9F5R<F5D7W-T871E)RD[#0H@("`@("`@("1T:&ES+3YU:2`]("8D=6D[#0H@
M("`@("`@(&EF("@A)'1H:7,M/E]P<F5F97)R9613=&%T92D@>PT*("`@("`@
M("`@("`@+R\@9&]N)W0@:6YA9'9E<G1A;G1L>2!U<V4@82!N;VXM<V5T('!R
M969E<G)E9%]S=&%T90T*("`@("`@("`@("`@)'1H:7,M/E]P<F5F97)R9613
M=&%T92`](&YU;&P[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=I;G-T86QL<F]O="==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9RT^<V5T26YS=&%L;%)O;W0H)'1H:7,M/E]O<'1I
M;VYS6R=I;G-T86QL<F]O="==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y(#T@)B1C;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@
M("`@("1T:&ES+3Y?<F5M;W1E(#T@)B1C;VYF:6<M/F=E=%)E;6]T92@I.PT*
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)V%L;&1E<',G
M72D@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=O;FQY<F5Q9&5P<R==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]I;G-T86QL960@/2`D=&AI<RT^7W)E
M9VES=')Y+3YL:7-T06QL4&%C:V%G97,H*3L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?:6YS=&%L;&5D(&%S("1K97D@/3X@)'5N=7-E9"D@>PT*
M("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)'5N=7-E9"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@($!A<G)A>5]W86QK*"1T:&ES+3Y?:6YS=&%L;&5D
M6R1K97E=+"`G<W1R=&]L;W=E<B<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@071T96UP="!T;R!D:7-C
M;W9E<B!A(&-H86YN96PG<R!R96UO=&4@8V%P86)I;&ET:65S(&9R;VT-"B`@
M("`@*B!I=',@<V5R=F5R(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@
M("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9&ES8V]V97(H)&-H86YN96PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^;&]G
M*#$L("=!='1E;7!T:6YG('1O(&1I<V-O=F5R(&-H86YN96P@(B<@+B`D8VAA
M;FYE;"`N("<B+BXN)RD[#0H@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&-A;&QB86-K(#T@
M)'1H:7,M/G5I(#\@87)R87DH)B1T:&ES+"`G7V1O=VYL;V%D0V%L;&)A8VLG
M*2`Z(&YU;&P[#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG
M*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-
M"B`@("`@("`@?0T*("`@("`@("`D82`]("1T:&ES+3YD;W=N;&]A9$AT='`H
M)VAT='`Z+R\G("X@)&-H86YN96P@+B`G+V-H86YN96PN>&UL)RP@)'1H:7,M
M/G5I+`T*("`@("`@("`@("`@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI
M+"`D8V%L;&)A8VLL(&9A;'-E*3L-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D82DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("!L:7-T*"1A+"`D;&%S=&UO9&EF:65D*2`]("1A.PT*("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@G4$5!4B]#:&%N;F5L1FEL92YP:'`G*2D@>PT*("`@
M("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[
M#0H@("`@("`@('T-"B`@("`@("`@)&(@/2!N97<@4$5!4E]#:&%N;F5L1FEL
M93L-"B`@("`@("`@:68@*"1B+3YF<F]M6&UL1FEL92@D82DI('L-"B`@("`@
M("`@("`@($!U;FQI;FLH)&$I.PT*("`@("`@("`@("`@:68@*"1T:&ES+3YC
M;VYF:6<M/F=E="@G875T;U]D:7-C;W9E<B<I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>2T^861D0VAA;FYE;"@D8BP@)&QA<W1M;V1I
M9FEE9"D[#0H@("`@("`@("`@("`@("`@)&%L:6%S(#T@)&(M/F=E=$YA;64H
M*3L-"B`@("`@("`@("`@("`@("!I9B`H)&(M/F=E=$YA;64H*2`]/2`D=&AI
M<RT^7W)E9VES=')Y+3YC:&%N;F5L3F%M92@D8BT^9V5T06QI87,H*2DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)&(M/F=E=$%L:6%S*"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,2P@)T%U=&\M9&ES8V]V97)E9"!C:&%N;F5L("(G("X@)&-H86YN96P@
M+@T*("`@("`@("`@("`@("`@("`@("`G(BP@86QI87,@(B<@+B`D86QI87,@
M+B`G(BP@861D:6YG('1O(')E9VES=')Y)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!`
M=6YL:6YK*"1A*3L-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($9O<B!S:6UP;&5R('5N:70M=&5S=&EN9PT*("`@
M("`J($!P87)A;2!014%27T1O=VYL;V%D97(-"B`@("`@*B!`<F5T=7)N(%!%
M05)?1&]W;FQO861E<E]086-K86=E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M)FYE=T1O=VYL;V%D97)086-K86=E*"8D="D-"B`@("![#0H@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"=014%27T1O=VYL;V%D97)?4&%C:V%G92<I*2![
M#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&]W;FQO861E<B]0
M86-K86=E+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2`F;F5W(%!%
M05)?1&]W;FQO861E<E]086-K86=E*"1T*3L-"B`@("`@("`@<F5T=7)N("1A
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($9O<B!S:6UP;&5R('5N:70M
M=&5S=&EN9PT*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!P
M87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A
M;2!I;G0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T1&5P96YD96YC>3)/
M8FIE8W0H)B1C+"`D:2P@)'`L("1S*0T*("`@('L-"B`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05(O1&5P96YD96YC>3(N<&AP)RDI('L-"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y,BYP:'`G.PT*
M("`@("`@("!]#0H@("`@("`@("1Z(#T@)FYE=R!014%27T1E<&5N9&5N8WDR
M*"1C+"`D:2P@)'`L("1S*3L-"B`@("`@("`@<F5T=7)N("1Z.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N("9D;W=N;&]A9"@D<&%R86US*0T*("`@('L-"B`@
M("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&$@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R96=I<W1R>2DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^
M9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<F5M;W1E*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96UO
M=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@('T-
M"B`@("`@("`@)&-H86YN96QS8VAE8VME9"`](&%R<F%Y*"D[#0H@("`@("`@
M("\O(&-O;G9E<G0@86QL('!A<F%M971E<G,@:6YT;R!014%27T1O=VYL;V%D
M97)?4&%C:V%G92!O8FIE8W1S#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@
M87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("`D<&%R86US6R1I72`]
M("8D=&AI<RT^;F5W1&]W;FQO861E<E!A8VMA9V4H)'1H:7,I.PT*("`@("`@
M("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PT*("`@("`@("`@("`@)&5R<B`]("1P87)A;7-;)&E=+3YI
M;FET:6%L:7IE*"1P87)A;2D[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H(21E<G(I('L-
M"B`@("`@("`@("`@("`@("`O+R!S:VEP('!A<F%M971E<G,@=&AA="!W97)E
M(&UI<W-E9"!B>2!P<F5F97)R961?<W1A=&4-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`D97)R+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<&%R86US6R1I72`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!A<F%M
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D<&%R86TM/F=E
M=$-H86YN96PH*2`N("<O)R`N("1P87)A;2T^9V5T4&%C:V%G92@I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$5R
M<F]R*"=086-K86=E("(G("X@)'!A<F%M("X@)R(@:7,@;F]T('9A;&ED)RP-
M"B`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?4TM)4%!%1"D[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<&%R86US6R1I72`F)B`A:7-S970H)&-H86YN96QS8VAE8VME9%LD<&%R86US
M6R1I72T^9V5T0VAA;FYE;"@I72D@)B8-"B`@("`@("`@("`@("`@("`@("`@
M("`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=O9F9L:6YE)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1C:&%N;F5L<V-H96-K961;)'!A<F%M<ULD:5TM
M/F=E=$-H86YN96PH*5T@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!0
M14%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3
M>7-T96TG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D8W5R8VAA;FYE;"`]("8D=&AI<RT^7W)E9VES
M=')Y+3YG971#:&%N;F5L*"1P87)A;7-;)&E=+3YG971#:&%N;F5L*"DI.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8W5R8VAA
M;FYE;"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G-T871I
M8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D8W5R8VAA;FYE;"D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&$@/2`D
M=&AI<RT^9&]W;FQO861(='1P*"=H='1P.B\O)R`N("1P87)A;7-;)&E=+3YG
M971#:&%N;F5L*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R]C:&%N
M;F5L+GAM;"<L("1T:&ES+3YU:2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M(%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*2P@;G5L;"P@)&-U<F-H86YN
M96PM/FQA<W1-;V1I9FEE9"@I*3L-"B`@("`@("`@("`@("`@("`@("`@4$5!
M4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D82D@?'P@(21A*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).
M24Y'.B!C:&%N;F5L("(G("X@)'!A<F%M<ULD:5TM/F=E=$-H86YN96PH*2`N
M("<B(&AA<R`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=U<&1A=&5D
M(&ET<R!P<F]T;V-O;',L('5S92`B8VAA;FYE;"UU<&1A=&4@)R`N("1P87)A
M;7-;)&E=+3YG971#:&%N;F5L*"D@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@)R(@=&\@=7!D871E)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@D<&%R86US6R1I72`F)B`A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=D;W=N;&]A9&]N;'DG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-H96-K9&ER(#T@)'1H
M:7,M/E]P<F5P96YD4&%T:"@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G+"!N=6QL+"`D<&%R86US
M6R1I72T^9V5T0VAA;FYE;"@I*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D8VAE8VMD:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL("1P87)A;7-;
M)&E=+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('=H:6QE("@D8VAE8VMD:7(@)B8@)&-H96-K
M9&ER("$]("<O)R`F)B`A9FEL95]E>&ES=',H)&-H96-K9&ER*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&-H96-K9&ER(#T@9&ER;F%M92@D8VAE
M8VMD:7(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D8VAE8VMD:7(@/3T@)RXG*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D8VAE8VMD:7(@/2`G+R<[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%`:7-?=W)I=&5A8FQE
M*"1C:&5C:V1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@:6YS=&%L;"P@<&AP7V1I<B!F
M;W(@8VAA;FYE;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<ULD:5TM/F=E=$-H86YN96PH*2`N("<B(&ES(&YO="!W<FET96%B
M;&4@8GD@=&AE(&-U<G)E;G0@=7-E<B<I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@('5N<V5T*"1C:&%N;F5L<V-H96-K960I.PT*("`@("`@
M("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M;W9E1'5P;&EC871E<R@D
M<&%R86US*3L-"B`@("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@>PT*("`@
M("`@("`@("`@)&$@/2!A<G)A>2@I.PT*("`@("`@("`@("`@<F5T=7)N("1A
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;V9F
M;&EN92==*2D@>PT*("`@("`@("`@("`@)')E=F5R:69Y(#T@=')U93L-"B`@
M("`@("`@("`@('=H:6QE("@D<F5V97)I9GDI('L-"B`@("`@("`@("`@("`@
M("`D<F5V97)I9GD@/2!F86QS93L-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5T(#T@)'!A<F%M<ULD:5TM/F1E=&5C=$1E<&5N9&5N8VEE<R@D
M<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R979E<FEF
M>2`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I
M72`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T97,H)'!A<F%M<RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@)')E="T^9V5T365S<V%G92@I*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;V9F;&EN92==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/FQO9R@S+"`G4VMI<'!I;F<@9&5P96YD96YC>2!D;W=N
M;&]A9"!C:&5C:RP@+2UO9F9L:6YE('-P96-I9FEE9"<I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@
M("1A(#T@87)R87DH*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@
M("`@?0T*("`@("`@("!W:&EL92`H4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z
M.FUE<F=E1&5P96YD96YC:65S*"1P87)A;7,I*3L-"B`@("`@("`@4$5!4E]$
M;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V94EN<W1A;&QE9"@D<&%R86US*3L-
M"B`@("`@("`@:68@*"%C;W5N="@D<&%R86US*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/G!U<VA%<G)O<B@G3F\@=F%L:60@<&%C:V%G97,@9F]U;F0G+"!0
M14%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@)&$@/2!A<G)A
M>2@I.PT*("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("!]#0H@("`@
M("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@)&5R<B`]("1T:&ES+3YA;F%L>7IE1&5P96YD96YC:65S
M*"1P87)A;7,I.PT*("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@(&EF("@A8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@
M("1T:&ES+3YP=7-H17)R;W(H)TYO('9A;&ED('!A8VMA9V5S(&9O=6YD)RP@
M4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("1A(#T@87)R
M87DH*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@
M("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@)&YE=W!A<F%M<R`](&%R
M<F%Y*"D[#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V]P=&EO;G-;)W!R
M971E;F0G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D<&%R86US.PT*("`@
M("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A
M8VMA9V4I('L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1P9B`]
M("8D<&%R86US6R1I72T^9&]W;FQO860H*3L-"B`@("`@("`@("`@(%!%05(Z
M.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#$L("1P9BT^9V5T365S<V%G92@I*3L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`G17)R;W(Z(&-A;FYO
M="!D;W=N;&]A9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P86-K
M86=E+3YG971087)S961086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(G
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;F5W<&%R86US6UT@
M/2`F)'!A<F%M<ULD:5T[#0H@("`@("`@("`@("`D<F5T6UT@/2!A<G)A>2@G
M9FEL92<@/3X@)'!F+3YG971!<F-H:79E1FEL92@I+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G:6YF;R<@/3X@)B1P9BP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!K9R<@/3X@)'!F+3YG
M971086-K86=E*"DI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&]W
M;FQO861E9%!A8VMA9V5S(#T@)')E=#L-"B`@("`@("`@<F5T=7)N("1N97=P
M87)A;7,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(&%L;"!P86-K86=E<R!T;R!B92!I;G-T86QL960-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!A;F%L>7IE1&5P96YD96YC:65S*"8D<&%R86US*0T*("`@('L-
M"B`@("`@("`@)&AA<V9A:6QE9"`]("1F86EL960@/2!F86QS93L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI
M*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@
M4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]21515
M4DXI.PT*("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@("`@("1R97-E="`]
M(&9A;'-E.PT*("`@("`@("!W:&EL92`H)')E9&\I('L-"B`@("`@("`@("`@
M("1R961O(#T@9F%L<V4[#0H@("`@("`@("`@("!F;W)E86-H("@D<&%R86US
M(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@("`@("1D97!S(#T@
M)'!A<F%M+3YG971$97!S*"D[#0H@("`@("`@("`@("`@("`@:68@*"$D9&5P
M<RD@>PT*("`@("`@("`@("`@("`@("`@("`D9&5P8VAE8VME<B`]("8D=&AI
M<RT^9V5T1&5P96YD96YC>3)/8FIE8W0H)'1H:7,M/F-O;F9I9RP@)'1H:7,M
M/F=E=$]P=&EO;G,H*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A
M;2T^9V5T4&%R<V5D4&%C:V%G92@I+"!014%27U9!3$E$051%7T1/5TY,3T%$
M24Y'*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1P87)A;2T^9V5T5'EP
M92@I(#T]("=X;6QR<&,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<V5N9"`]("1P87)A;2T^9V5T1&]W;FQO86154DPH*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S
M96YD(#T@)'!A<F%M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL8VAE8VL@
M/2`D9&5P8VAE8VME<BT^=F%L:61A=&5086-K86=E*"1S96YD+"`D=&AI<RP@
M)'!A<F%M<RD[#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1I;G-T86QL8VAE8VLI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)&EN<W1A
M;&QC:&5C:RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1H87-F86EL960@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<ULD:5T@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-E="`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D9F%I;&5D(#T@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M
M;W9E1'5P;&EC871E<R@D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("@A)')E<V5T("8F("1P87)A;2T^86QR96%D
M>59A;&ED871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)&1E<',I*2![#0H@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R
M(#T@)B1T:&ES+3YG971$97!E;F1E;F-Y,D]B:F5C="@D=&AI<RT^8V]N9FEG
M+"`D=&AI<RT^9V5T3W!T:6]N<R@I+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A<F%M+3YG971087)S961086-K86=E*"DL(%!%05)?5D%,241!5$5?
M1$]73DQ/041)3D<I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F%M
M+3YG9714>7!E*"D@/3T@)WAM;')P8R<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S96YD(#T@)'!A<F%M+3YG971$;W=N;&]A9%523"@I.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-E;F0@/2`D<&%R86TM/F=E=%!A8VMA9V5&:6QE*"D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A
M;&QC:&5C:R`]("1D97!C:&5C:V5R+3YV86QI9&%T95!A8VMA9V4H)'-E;F0L
M("1T:&ES+"`D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&EN<W1A;&QC:&5C:RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P
M+"`D:6YS=&%L;&-H96-K+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&AA<V9A
M:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US
M6R1I72`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<V5T
M(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R961O(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F86EL960@/2!F86QS93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?1&]W;FQO861E<E]086-K
M86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`D9F%I;&5D(#T@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=R
M97%U:7)E9"==(&%S("1T>7!E(#T^("1D97`I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!N;W1E.B!$97!E;F1E;F-Y,B!W:6QL(&YE=F5R
M(')E='5R;B!A(%!%05)?17)R;W(@:68@:6=N;W)E+65R<F]R<PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&ES('-P96-I9FEE9"P@<V\@<V]F
M="!I<R!N965D960@=&\@='5R;B!O9F8@;&]G9VEN9PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&4@/2`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y
M(GTH)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@=')U92P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y
M*"1E*2`F)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D95LP72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D9&5P(&%S("1D*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y(GTH)&0L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M<G5E+"`D<&%R86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F%I;&5D(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E+3YG971-97-S
M86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("AI<U]A<G)A>2@D92D@)B8@(21P87)A;2T^86QR96%D>59A;&ED
M871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@P+"`D95LP72D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=O<'1I;VYA;"==(&%S("1T
M>7!E(#T^("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D9&5P6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&-H
M96-K97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D97`L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F86QS
M92P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G
M92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H:7-?87)R87DH)&4I("8F("$D<&%R86TM/F%L<F5A9'E686QI9&%T
M960H*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,"P@)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97`@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<&-H96-K97(M/GLB=F%L:61A=&5[)'1Y<&5]1&5P96YD96YC>2)]*"1D
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&9A;'-E+"`D<&%R86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#`L("1E+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1E
M*2`F)B`A)'!A<F%M+3YA;')E861Y5F%L:61A=&5D*"DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,"P@)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P;F%M92`]
M("1P87)A;2T^9V5T1W)O=7`H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P<ULG9W)O=7`G72D@)B8@)&=R;W5P;F%M92D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;
M)V=R;W5P)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!S6R=G<F]U<"==(#T@87)R87DH)&1E<'-;)V=R;W5P)UTI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG9W)O=7`G72!A<R`D9W)O
M=7`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1G
M<F]U<%LG871T<FEB<R==6R=N86UE)UT@/3T@)&=R;W5P;F%M92D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D9F]U;F0I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&=R;W5P6R=A='1R:6)S)UTI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9W)O=7`@87,@)'1Y
M<&4@/3X@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D9&5P6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y
M(GTH)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F86QS92P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL960@/2!T<G5E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A
M<G)A>2@D92D@)B8@(21P87)A;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*#`L("1E6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E<"!A<R`D9"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D92`]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1D97!C:&5C:V5R+3Y[(G9A;&ED871E
M>R1T>7!E?41E<&5N9&5N8WDB?2@D9"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F%L<V4L("1P87)A;7,I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9A:6QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@
M)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D
M92D@)B8@(21P87)A;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YL;V<H,"P@)&5;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1E
M<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E(#T@)&1E<&-H96-K97(M/G9A;&ED871E1&5P
M96YD96YC>3$H)&1E<"P@)'!A<F%M<RDI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F86EL960@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@P+"`D92T^9V5T365S<V%G92@I*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<U]A<G)A>2@D92D@)B8@(21P87)A
M;2T^86QR96%D>59A;&ED871E9"@I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*#`L("1E6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72T^<V5T5F%L:61A
M=&5D*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D9F%I;&5D*2![#0H@("`@("`@("`@("`@("`@("`@("1H87-F86EL960@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("`@("`D<F5S970@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("`D<F5D;R`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("1F86EL960@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4Z.G)E;6]V941U<&QI8V%T97,H)'!A
M<F%M<RD[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M:68@*"1H87-F86EL960@)B8@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG:6=N
M;W)E+65R<F]R<R==*2!\?`T*("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)VYO9&5P<R==*2DI('L-"B`@("`@("`@("`@("\O('1H:7,@
M:7,@<')O8F%B;'D@;F]T(&YE961E9"P@8G5T(&IU<W0@:6X@8V%S90T*("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).24Y'.B!D
M97!E;F1E;F-I97,@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971R:65V92!T:&4@9&ER
M96-T;W)Y('1H870@9&]W;FQO861S('=I;&P@:&%P<&5N(&EN#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971$;W=N;&]A9$1I<B@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]D;W=N;&]A9$1I<BDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D1&ER.PT*("`@("`@("!]
M#0H@("`@("`@("1D;W=N;&]A9&1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M9&]W;FQO861?9&ER)RD[#0H@("`@("`@(&EF("AE;7!T>2@D9&]W;FQO861D
M:7(I*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4WES=&5M
M)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP
M:'`G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&1O=VYL;V%D9&ER(#T@4WES=&5M.CIM:W1E;7`H)RUD)RDI*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1D;W=N;&]A9&1I<CL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@)RL@=&UP(&1I
M<B!C<F5A=&5D(&%T("<@+B`D9&]W;FQO861D:7(I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D1&ER(#T@)&1O=VYL;V%D
M9&ER.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$1O=VYL;V%D1&ER*"1D
M:7(I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&ER(#T@)&1I
M<CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N9FEG4V5T
M*"D-"B`@("!F=6YC=&EO;B!C;VYF:6=3970H)&ME>2P@)'9A;'5E+"`D;&%Y
M97(@/2`G=7-E<B<L("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS970H)&ME>2P@)'9A;'5E+"`D;&%Y97(L("1C
M:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M/E]P<F5F97)R9613=&%T92`]("1T
M:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RP@;G5L;"P@)&-H
M86YN96PI.PT*("`@("`@("!I9B`H(21T:&ES+3Y?<')E9F5R<F5D4W1A=&4I
M('L-"B`@("`@("`@("`@("\O(&1O;B=T(&EN861V97)T86YT;'D@=7-E(&$@
M;F]N+7-E="!P<F5F97)R961?<W1A=&4-"B`@("`@("`@("`@("1T:&ES+3Y?
M<')E9F5R<F5D4W1A=&4@/2!N=6QL.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[('-E=$]P=&EO;G,H*0T*("`@(&9U;F-T
M:6]N('-E=$]P=&EO;G,H)&]P=&EO;G,I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7V]P=&EO;G,@/2`D;W!T:6]N<SL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@<V5T3W!T:6]N<R@I#0H@("`@9G5N8W1I;VX@9V5T3W!T
M:6]N<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]O<'1I;VYS
M.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R
M('-I;7!L97(@=6YI="UT97-T:6YG#0H@("`@("H@0'!A<F%M(%!%05)?0V]N
M9FEG#0H@("`@("H@0'!A<F%M(&EN=`T*("`@("`J($!P87)A;2!S=')I;F<-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4&%C:V%G969I;&5/8FIE8W0H
M)B1C+"`D9"P@)'0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE)RDI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@
M("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C+"`D
M9"P@)'0I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@
M>WM[(%]G971086-K86=E1&]W;FQO8615<FPH*0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&]U='!U="!O9B![0&QI;FL@<&%R<V5086-K86=E
M3F%M92@I?0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]G971086-K86=E1&]W;FQO8615<FPH)'!A<G(I#0H@("`@
M>PT*("`@("`@("`D8W5R8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G
M9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1P87)R6R=C:&%N;F5L)UTI.PT*("`@("`@
M("`O+R!G971$;W=N;&]A9%523"!R971U<FYS(&%N(&%R<F%Y+B`@3VX@97)R
M;W(L(&ET(&]N;'D@8V]N=&%I;G,@:6YF;W)M871I;VX-"B`@("`@("`@+R\@
M;VX@=&AE(&QA=&5S="!R96QE87-E(&%S(&%R<F%Y*'9E<G-I;VXL(&EN9F\I
M+B`@3VX@<W5C8V5S<R!I="!C;VYT86EN<PT*("`@("`@("`O+R!A<G)A>2AV
M97)S:6]N+"!I;F9O+"!D;W=N;&]A9"!U<FP@<W1R:6YG*0T*("`@("`@("`D
M<W1A=&4@/2!I<W-E="@D<&%R<ELG<W1A=&4G72D@/R`D<&%R<ELG<W1A=&4G
M72`Z("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7W-T871E)RD[#0H@
M("`@("`@(&EF("@A)'1H:7,M/E]R96=I<W1R>2T^8VAA;FYE;$5X:7-T<R@D
M<&%R<ELG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@9&\@>PT*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)V%U=&]?9&ES8V]V
M97(G*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F1I<V-O
M=F5R*"1P87)R6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D
M969A=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@<F5M;W1E(&-H
M86YN96PZ("<@+B`D<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@("`@("!]('=H
M:6QE("AF86QS92D[#0H@("`@("`@('T-"B`@("`@("`@)&-H86X@/2`F)'1H
M:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D<&%R<ELG8VAA;FYE;"==*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@
M("`@("!R971U<FX@)&-H86X[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I
M;VX@/2`D=&AI<RT^7W)E9VES=')Y+3YP86-K86=E26YF;R@D<&%R<ELG<&%C
M:V%G92==+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`D<&%R<ELG8VAA;FYE
M;"==*3L-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M
M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@
M("`@("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D
M=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@
M("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N
M,"<L("1T:&ES+3Y?;W!T:6]N<RD[#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1P87)R6R=V97)S:6]N)UTI("8F("%I<W-E="@D<&%R<ELG<W1A=&4G72D@
M)B8@)'9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("8F("%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@("`@
M("`@("1U<FP@/2`D<F5S="T^9V5T1&]W;FQO86154DPH)&)A<V4L("1P87)R
M+"`D<W1A=&4L("1V97)S:6]N*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)'5R;"`]("1R97-T+3YG971$;W=N;&]A9%523"@D
M8F%S92P@)'!A<G(L("1S=&%T92P@9F%L<V4I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'5R;"DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG
M+"`D8W5R8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1U<FP[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'!A<G);)V-H86YN
M96PG72`A/2`D8W5R8VAA;FYE;"D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3YC;VYF:6=3970H)V1E9F%U;'1?8VAA;FYE;"<L("1C=7)C:&%N;F5L*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)'5R
M;"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1U<FQ;)W)A=R==(#T@9F%L<V4[("\O(&YO
M(&-H96-K:6YG(&ES(&YE8V5S<V%R>2!F;W(@4D535`T*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D=7)L6R=I;F9O)UTI*2![#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TEN=F%L:60@<F5M;W1E(&1E
M<&5N9&5N8VEE<R!R971R:65V960@9G)O;2!215-4("T@)R`N#0H@("`@("`@
M("`@("`@("`@("`@("=T:&ES('-H;W5L9"!N979E<B!H87!P96XG*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=7)L6R=I;F9O
M)UU;)W)E<75I<F5D)UTI('Q\("1U<FQ;)V-O;7!A=&EB;&4G72D@>PT*("`@
M("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V
M,BYP:'`G.PT*("`@("`@("`@("`@("`@("1P9B`](&YE=R!014%27U!A8VMA
M9V5&:6QE7W8R.PT*("`@("`@("`@("`@("`@("1P9BT^<V5T4F%W0VAA;FYE
M;"@D<&%R<ELG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("`@("!I9B`H)'5R
M;%LG8V]M<&%T:6)L92==*2![#0H@("`@("`@("`@("`@("`@("`@("1P9BT^
M<V5T4F%W0V]M<&%T:6)L92@D=7)L6R=C;VUP871I8FQE)UTI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H<"<[
M#0H@("`@("`@("`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?
M=C$[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&8M/G-E=%)A=U!A
M8VMA9V4H)'5R;%LG<&%C:V%G92==*3L-"B`@("`@("`@("`@("1P9BT^<V5T
M1&5P<R@D=7)L6R=I;F9O)UTI.PT*("`@("`@("`@("`@)'!F+3YS971287=3
M=&%T92@D=7)L6R=S=&%B:6QI='DG72D[#0H@("`@("`@("`@("`D=7)L6R=I
M;F9O)UT@/2`F)'!F.PT*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A
M9&5D*")Z;&EB(BD@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V-O;7!R
M97-S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&%R)SL-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N
M=&=Z)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=7)L*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=7)L6R=U
M<FPG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'5R;%LG=7)L)UT@+CT@
M)&5X=#L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@?2!E;'-E:68@*"1C:&%N
M+3YS=7!P;W)T<R@G>&UL<G!C)RP@)W!A8VMA9V4N9V5T1&]W;FQO86154DPG
M+"!F86QS92P@)S$N,2<I*2![#0H@("`@("`@("`@("`O+R!D;VXG="!I;G-T
M86QL('=I=&@@=&AE(&]L9"!V97)S:6]N(&EN9F]R;6%T:6]N('5N;&5S<R!W
M92=R92!D;VEN9R!A('!L86EN#0H@("`@("`@("`@("`O+R!V86YI;&QA('-I
M;7!L92!I;G-T86QL871I;VXN("!)9B!T:&4@=7-E<B!S87ES('1O(&EN<W1A
M;&P@82!P87)T:6-U;&%R#0H@("`@("`@("`@("`O+R!V97)S:6]N(&]R('-T
M871E+"!I9VYO<F4@=&AE(&-U<G)E;G0@:6YS=&%L;&5D('9E<G-I;VX-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'!A<G);)W9E<G-I;VXG72D@)B8@(6ES
M<V5T*"1P87)R6R=S=&%T92==*2`F)B`D=F5R<VEO;@T*("`@("`@("`@("`@
M("`@("`@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO861O;FQY
M)UTI*2![#0H@("`@("`@("`@("`@("`@)'5R;"`]("1T:&ES+3Y?<F5M;W1E
M+3YC86QL*"=P86-K86=E+F=E=$1O=VYL;V%D55),)RP@)'!A<G(L("1S=&%T
M92P@)'9E<G-I;VXI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D=7)L(#T@)'1H:7,M/E]R96UO=&4M/F-A;&PH)W!A8VMA9V4N
M9V5T1&]W;FQO86154DPG+"`D<&%R<BP@)'-T871E*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1U<FP@/2`D=&AI
M<RT^7W)E;6]T92T^8V%L;"@G<&%C:V%G92YG971$;W=N;&]A9%523"<L("1P
M87)R+"`D<W1A=&4I.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1U<FPI*2![#0H@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)'!A<G);)V-H86YN96PG72`A/2`D8W5R
M8VAA;FYE;"D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F
M875L=%]C:&%N;F5L)RP@)&-U<F-H86YN96PI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D=7)L6R=?7U!%05)?15)23U)?0TQ!4U-?7R==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)'5R;%LG
M;65S<V%G92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1U<FPI*2![#0H@("`@("`@("`@("!R971U<FX@)'5R;#L-"B`@("`@("`@
M?0T*("`@("`@("`D=7)L6R=R87<G72`]("1U<FQ;)VEN9F\G73L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI
M*2![#0H@("`@("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL
M94]B:F5C="@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^9&5B=6<I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C
M:V%G969I;&5/8FIE8W0H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F1E8G5G+`T*
M("`@("`@("`@("`@("`@("1T:&ES+3YG971$;W=N;&]A9$1I<B@I*3L-"B`@
M("`@("`@?0T*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN
M9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1P:6YF;R`]("8D<&MG
M+3YF<F]M6&UL4W1R:6YG*"1U<FQ;)VEN9F\G72P@4$5!4E]604Q)1$%415]$
M3U=.3$]!1$E.1RP@)W)E;6]T92<I.PT*("`@("`@("!014%2.CIS=&%T:6-0
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1P:6YF;RDI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@P+"`D<&EN9F\M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4F5M;W1E('!A
M8VMA9V4N>&UL(&ES(&YO="!V86QI9"`M('1H:7,@<VAO=6QD(&YE=F5R(&AA
M<'!E;B<I.PT*("`@("`@("!]#0H@("`@("`@("1U<FQ;)VEN9F\G72`]("8D
M<&EN9F\[#0H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@B>FQI8B(I
M('Q\(&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*
M("`@("`@("`@("`@)&5X="`]("<N=&%R)SL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES7V%R<F%Y*"1U<FPI*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'5R;%LG=7)L)UTI*2![#0H@("`@("`@("`@("`@("`@)'5R;%LG=7)L
M)UT@+CT@)&5X=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'5R;#L-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&=E=$1E<%!A8VMA9V5$;W=N;&]A9%5R;"@I#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@87)R87D@9&5P96YD96YC>2!A<G)A>0T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971$97!086-K
M86=E1&]W;FQO8615<FPH)&1E<"P@)'!A<G(I#0H@("`@>PT*("`@("`@("`D
M>'-D=F5R<VEO;B`](&ES<V5T*"1D97!;)W)E;"==*2`_("<Q+C`G(#H@)S(N
M,"<[#0H@("`@("`@("1C=7)C:&%N;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("1R96UO=&5C:&%N;F5L(#T@
M)&1E<%LG8VAA;FYE;"==.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)')E;6]T96-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(21T:&ES+3Y?<F5G:7-T<GDM/F-H86YN96Q%>&ES
M=',H)')E;6]T96-H86YN96PI*2![#0H@("`@("`@("`@("!D;R![#0H@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G875T;U]D:7-C
M;W9E<B<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^9&ES
M8V]V97(H)')E;6]T96-H86YN96PI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G56YK;F]W;B!R96UO=&4@8VAA;FYE;#H@)R`N("1R96UO=&5C:&%N
M;F5L*3L-"B`@("`@("`@("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG
M+"`D<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@("1S=&%T92`](&ES<V5T*"1P
M87)R6R=S=&%T92==*2`_("1P87)R6R=S=&%T92==(#H@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*3L-"B`@("`@("`@:68@*&ES<V5T
M*"1P87)R6R=S=&%T92==*2`F)B!I<W-E="@D<&%R<ELG=F5R<VEO;B==*2D@
M>PT*("`@("`@("`@("`@=6YS970H)'!A<G);)W-T871E)UTI.PT*("`@("`@
M("!]#0H@("`@("`@("1C:&%N(#T@)B1T:&ES+3Y?<F5G:7-T<GDM/F=E=$-H
M86YN96PH)')E;6]T96-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D8VAA;CL-"B`@
M("`@("`@?0T*("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<F5G:7-T<GDM
M/G!A8VMA9V5);F9O*"1D97!;)VYA;64G72P@)W9E<G-I;VXG+`T*("`@("`@
M("`@("`@)')E;6]T96-H86YN96PI.PT*("`@("`@("!I9B`H)&-H86XM/G-U
M<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R
M;W(G*2D@)B8-"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S
M95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D
M7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4D535"@G,2XP)RP@)'1H:7,M/E]O<'1I;VYS*3L-"B`@("`@
M("`@("`@("1U<FP@/2`D<F5S="T^9V5T1&5P1&]W;FQO86154DPH)&)A<V4L
M("1X<V1V97)S:6]N+"`D9&5P+"`D<&%R<BP-"B`@("`@("`@("`@("`@("`@
M("`@)'-T871E+"`D=F5R<VEO;BD[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D=7)L*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=7)L
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1P87)R6R=C:&%N
M;F5L)UT@(3T@)&-U<F-H86YN96PI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1U
M<FPI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D=7)L6R=R87<G72`](&9A;'-E.R`O+R!N
M;R!C:&5C:VEN9R!I<R!N96-E<W-A<GD@9F]R(%)%4U0-"B`@("`@("`@("`@
M(&EF("@A:7-?87)R87DH)'5R;%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=);G9A;&ED(')E;6]T92!D
M97!E;F1E;F-I97,@<F5T<FEE=F5D(&9R;VT@4D535"`M("<@+@T*("`@("`@
M("`@("`@("`@("`@("`G=&AI<R!S:&]U;&0@;F5V97(@:&%P<&5N)RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'5R;%LG:6YF
M;R==6R=R97%U:7)E9"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R
M+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P
M9B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8R.PT*("`@("`@("`@("`@("`@
M("1P9BT^<V5T4F%W0VAA;FYE;"@D<F5M;W1E8VAA;FYE;"D[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%27U!A8VMA9V5&:6QE7W8Q)RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H<"<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P9B`](&YE
M=R!014%27U!A8VMA9V5&:6QE7W8Q.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'!F+3YS971287=086-K86=E*"1U<FQ;)W!A8VMA9V4G72D[#0H@
M("`@("`@("`@("`D<&8M/G-E=$1E<',H)'5R;%LG:6YF;R==*3L-"B`@("`@
M("`@("`@("1P9BT^<V5T4F%W4W1A=&4H)'5R;%LG<W1A8FEL:71Y)UTI.PT*
M("`@("`@("`@("`@)'5R;%LG:6YF;R==(#T@)B1P9CL-"B`@("`@("`@("`@
M(&EF("@A97AT96YS:6]N7VQO861E9"@B>FQI8B(I('Q\(&ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*("`@("`@("`@("`@("`@
M("1E>'0@/2`G+G1A<B<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)'5R;"DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'5R;%LG=7)L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1U<FQ;)W5R;"==("X]("1E>'0[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@
M("`@('T@96QS96EF("@D8VAA;BT^<W5P<&]R=',H)WAM;')P8R<L("=P86-K
M86=E+F=E=$1E<$1O=VYL;V%D55),)RP@9F%L<V4L("<Q+C$G*2D@>PT*("`@
M("`@("`@("`@:68@*"1V97)S:6]N*2![#0H@("`@("`@("`@("`@("`@)'5R
M;"`]("1T:&ES+3Y?<F5M;W1E+3YC86QL*"=P86-K86=E+F=E=$1E<$1O=VYL
M;V%D55),)RP@)'AS9'9E<G-I;VXL("1D97`L("1P87)R+`T*("`@("`@("`@
M("`@("`@("`@("`D<W1A=&4L("1V97)S:6]N*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'5R;"`]("1T:&ES+3Y?<F5M;W1E
M+3YC86QL*"=P86-K86=E+F=E=$1E<$1O=VYL;V%D55),)RP@)'AS9'9E<G-I
M;VXL("1D97`L("1P87)R+`T*("`@("`@("`@("`@("`@("`@("`D<W1A=&4I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'5R;"`]("1T:&ES+3Y?<F5M;W1E+3YC86QL*"=P86-K86=E+F=E=$1E
M<$1O=VYL;V%D55),)RP@)'AS9'9E<G-I;VXL("1D97`L("1P87)R+"`D<W1A
M=&4I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<&%R<ELG8VAA;FYE;"==
M("$]("1C=7)C:&%N;F5L*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG
M4V5T*"=D969A=6QT7V-H86YN96PG+"`D8W5R8VAA;FYE;"D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D=7)L*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1U<FP[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1U<FQ;)U]?4$5!4E]%4E)/4E]#3$%34U]?)UTI*2![#0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@D=7)L6R=M97-S86=E)UTI.PT*
M("`@("`@("!]#0H@("`@("`@("1U<FQ;)W)A=R==(#T@)'5R;%LG:6YF;R==
M.PT*("`@("`@("`D<&MG(#T@)B1T:&ES+3YG971086-K86=E9FEL94]B:F5C
M="@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^9&5B=6<I.PT*("`@("`@("!014%2
M.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("1P:6YF;R`]("8D<&MG+3YF<F]M6&UL4W1R:6YG*"1U<FQ;
M)VEN9F\G72P@4$5!4E]604Q)1$%415]$3U=.3$]!1$E.1RP@)W)E;6]T92<I
M.PT*("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P:6YF;RDI('L-"B`@("`@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D<&EN9F\M/F=E=$UE<W-A
M9V4H*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G4F5M;W1E('!A8VMA9V4N>&UL(&ES(&YO="!V86QI
M9"`M('1H:7,@<VAO=6QD(&YE=F5R(&AA<'!E;B<I.PT*("`@("`@("!]#0H@
M("`@("`@("1U<FQ;)VEN9F\G72`]("8D<&EN9F\[#0H@("`@("`@(&EF("AI
M<U]A<G)A>2@D=7)L*2D@>PT*("`@("`@("`@("`@:68@*"%E>'1E;G-I;VY?
M;&]A9&5D*")Z;&EB(BD@?'P@:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V-O
M;7!R97-S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5X="`]("<N=&%R)SL-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5X="`]
M("<N=&=Z)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=7)L6R=U<FPG72DI('L-"B`@("`@("`@("`@("`@("`D=7)L6R=U<FPG
M72`N/2`D97AT.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=7)L.PT*("`@('T-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9V5T4&%C:V%G941O=VYL;V%D57)L*"D-"@T*("`@("\J*@T*("`@("`J($!D
M97!R96-A=&5D(&EN(&9A=F]R(&]F(%]G971086-K86=E1&]W;FQO8615<FP-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971086-K86=E1&]W;FQO8615<FPH
M)'!A8VMA9V4L("1V97)S:6]N(#T@;G5L;"P@)&-H86YN96P@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@D=F5R<VEO;BD@>PT*("`@("`@("`@("`@
M)'!A8VMA9V4@+CT@(BTD=F5R<VEO;B([#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1T:&ES(#T]/2!N=6QL('Q\("1T:&ES+3Y?<F5G:7-T<GD@/3T](&YU
M;&PI('L-"B`@("`@("`@("`@("1P86-K86=E(#T@(FAT='`Z+R]P96%R+G!H
M<"YN970O9V5T+R1P86-K86=E(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1C:&%N(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T0VAA;FYE;"@D
M8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA
M;BDI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)R<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<&%C:V%G92`](")H='1P.B\O(B`N("1C:&%N
M+3YG971397)V97(H*2`N("(O9V5T+R1P86-K86=E(CL-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H(GIL:6(B*2D@>PT*("`@
M("`@("`@("`@)'!A8VMA9V4@+CT@)S]U;F-O;7!R97-S/7EE<R<[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1P86-K86=E.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!G971$;W=N;&]A9&5D4&%C:V%G97,H*0T*
M#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@82!L:7-T(&]F(&1O=VYL;V%D
M960@<&%C:V%G97,@869T97(@82!C86QL('1O('M`;&EN:R!D;W=N;&]A9"@I
M?2X-"B`@("`@*@T*("`@("`J($%L<V\@<F5S971S('1H92!L:7-T(&]F(&1O
M=VYL;V%D960@<&%C:V%G97,N#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=$1O=VYL;V%D961086-K86=E<R@I#0H@
M("`@>PT*("`@("`@("`D<F5T(#T@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G
M97,[#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO861E9%!A8VMA9V5S(#T@87)R
M87DH*3L-"B`@("`@("`@)'1H:7,M/E]T;T1O=VYL;V%D(#T@87)R87DH*3L-
M"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(%]D;W=N;&]A9$-A;&QB86-K*"D-"@T*("`@(&9U;F-T:6]N
M(%]D;W=N;&]A9$-A;&QB86-K*"1M<V<L("1P87)A;7,@/2!N=6QL*0T*("`@
M('L-"B`@("`@("`@<W=I=&-H("@D;7-G*2![#0H@("`@("`@("`@("!C87-E
M("=S879E87,G.@T*("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@(F1O
M=VYL;V%D:6YG("1P87)A;7,@+BXN(BD[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=D;VYE)SH-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^;&]G*#$L("<N+BYD;VYE.B`G("X@;G5M8F5R7V9O<FUA="@D
M<&%R86US+"`P+"`G)RP@)RPG*2`N("<@8GET97,G*3L-"B`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V)Y=&5S<F5A9"<Z#0H@
M("`@("`@("`@("`@("`@<W1A=&EC("1B>71E<SL-"B`@("`@("`@("`@("`@
M("!I9B`H96UP='DH)&)Y=&5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M8GET97,@/2`P.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H(2@D8GET97,@)2`Q,#(T,"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@Q+"`G+B<L(&9A;'-E*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)&)Y=&5S("L]("1P87)A;7,[#0H@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=S=&%R="<Z
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`B4W1A<G1I;F<@=&\@
M9&]W;FQO860@>R1P87)A;7-;,%U]("@B+FYU;6)E<E]F;W)M870H)'!A<F%M
M<ULQ72P@,"P@)R<L("<L)RDN(B!B>71E<RDB*3L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H;65T:&]D7V5X:7-T
M<R@D=&AI<RT^=6DL("=?9&]W;FQO861#86QL8F%C:R<I*0T*("`@("`@("`@
M("`@)'1H:7,M/G5I+3Y?9&]W;FQO861#86QL8F%C:R@D;7-G+"`D<&%R86US
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!R97!E;F10
M871H*"1P871H+"`D<')E<&5N9"D-"@T*("`@(&9U;F-T:6]N(%]P<F5P96YD
M4&%T:"@D<&%T:"P@)'!R97!E;F0I#0H@("`@>PT*("`@("`@("!I9B`H<W1R
M;&5N*"1P<F5P96YD*2`^(#`I('L-"B`@("`@("`@("`@(&EF("A/4U]724Y$
M3U=3("8F('!R96=?;6%T8V@H)R]>6V$M>ETZ+VDG+"`D<&%T:"DI('L-"B`@
M("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;82UZ73HO:2<L("1P
M<F5P96YD*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<')E<&5N9"`]('-U
M8G-T<B@D<')E<&5N9"P@,BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1P<F5P96YD>S!]("$]("=<7"<I('L-"B`@("`@("`@("`@("`@("`@("`@
M)'!R97!E;F0@/2`B7%PD<')E<&5N9"([#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1P871H(#T@<W5B<W1R*"1P871H+"`P+"`R*2`N
M("1P<F5P96YD("X@<W5B<W1R*"1P871H+"`R*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'!A=&@@/2`D<')E<&5N9"`N("1P
M871H.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D<&%T:#L-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('!U<VA%
M<G)O<B@D97)R;7-G+"`D8V]D92D-"@T*("`@("\J*@T*("`@("`J($!P87)A
M;2!S=')I;F<-"B`@("`@*B!`<&%R86T@:6YT96=E<@T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('!U<VA%<G)O<B@D97)R;7-G+"`D8V]D92`]("TQ*0T*("`@
M('L-"B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^7V5R<F]R4W1A8VLL(&%R
M<F%Y*"1E<G)M<V<L("1C;V1E*2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=$5R<F]R37-G<R@I#0H-"B`@("!F=6YC=&EO;B!G971%
M<G)O<DUS9W,H*0T*("`@('L-"B`@("`@("`@)&US9W,@/2!A<G)A>2@I.PT*
M("`@("`@("`D97)R<R`]("1T:&ES+3Y?97)R;W)3=&%C:SL-"B`@("`@("`@
M9F]R96%C:"`H)&5R<G,@87,@)&5R<BD@>PT*("`@("`@("`@("`@)&US9W-;
M72`]("1E<G);,%T[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]E<G)O
M<E-T86-K(#T@87)R87DH*3L-"B`@("`@("`@<F5T=7)N("1M<V=S.PT*("`@
M('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@9F]R($)##0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<V]R=%!K9T1E<',H)B1P86-K86=E<RP@
M)'5N:6YS=&%L;"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'5N:6YS=&%L
M;"`_(`T*("`@("`@("`@("`@)'1H:7,M/G-O<G1086-K86=E<T9O<E5N:6YS
M=&%L;"@D<&%C:V%G97,I(#H-"B`@("`@("`@("`@("1T:&ES+3YS;W)T4&%C
M:V%G97-&;W));G-T86QL*"1P86-K86=E<RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7V=E=$1E<%1R965$4"@D<&%C:V%G92P@)'!A8VMA9V5S+"`F)&1E
M<',L("8D8VAE8VME9"D-"B`@("![#0H@("`@("`@("1P9B`]("1P86-K86=E
M+3YG971086-K86=E1FEL92@I.PT*("`@("`@("`D8VAE8VME9%MS=')T;VQO
M=V5R*"1P86-K86=E+3YG971#:&%N;F5L*"DI75MS=')T;VQO=V5R*"1P86-K
M86=E+3YG971086-K86=E*"DI70T*("`@("`@("`@("`@/2!T<G5E.PT*("`@
M("`@("`D<&1E<',@/2`D<&8M/F=E=$1E<',H=')U92D[#0H@("`@("`@(&EF
M("@A)'!D97!S*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1P9BT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G
M,2XP)RD@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!D97!S(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==("$]("=P:V<G
M*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`D9&5P<ULG<&5A<BYP:'`N;F5T
M)UU;<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI72`]('1R=64[#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1P*2![#0H@("`@("`@
M("`@("`@("`@("`@("1D97!;)V-H86YN96PG72`]("=P96%R+G!H<"YN970G
M.PT*("`@("`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P
M6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<"T^:7-%<75A
M;"@D9&5P*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D8VAE8VME9%MS=')T;VQO=V5R*"1P+3YG971#:&%N;F5L*"DI70T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@6W-T<G1O;&]W97(H)'`M/F=E
M=%!A8VMA9V4H*2E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&%D9"!T:&4@9&5P96YD96YC>2=S(&1E<&5N9&5N8VEE<R!T;R!T:&4@
M=')E90T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9V5T
M1&5P5')E9410*"1P+"`D<&%C:V%G97,L("1D97!S+"`D8VAE8VME9"D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=&1E<',@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G
M92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=R97%U:7)E
M9"==6R=P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A>2@D="D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T9&5P<R`]
M(&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG<F5Q=6ER960G75LG<W5B<&%C
M:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=R97%U
M:7)E9"==6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A
M>2@D="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M9&5P<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG;W!T:6]N86PG75LG
M<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S6R=O
M<'1I;VYA;"==6R=P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@/2!A<G)A
M>2@D="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M9&5P<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG;W!T:6]N86PG75LG
M<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("1T(#T@)'!D97!S
M6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'0@
M/2!A<G)A>2@D="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1T9&5P<R`](&%R<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1P9&5P<ULG9W)O=7`G
M72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P9&5P<ULG9W)O
M=7`G75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!D97!S6R=G<F]U
M<"==(#T@87)R87DH)'!D97!S6R=G<F]U<"==*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!D97!S6R=G<F]U<"==
M(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&=R;W5P6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D="`]("1G<F]U<%LG<&%C:V%G92==.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=%LP72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D="`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T9&5P<R`](&%R
M<F%Y7VUE<F=E*"1T9&5P<RP@)'0I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W-U8G!A
M8VMA9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T(#T@)&=R
M;W5P6R=S=6)P86-K86=E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1T6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T(#T@87)R87DH)'0I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'1D97!S(#T@87)R87E?;65R
M9V4H)'1D97!S+"`D="D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D=&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&1E<%LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D9&5P8VAA;FYE;"`]("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/2`D9&5P
M6R=C:&%N;F5L)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1D97!S6R1D97!C:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)VYA;64G
M72E=(#T@=')U93L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G
M97,@87,@)'`I('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE
M;"==(#T@)&1E<&-H86YN96P[#0H@("`@("`@("`@("`@("`@("`@("1D97!;
M)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1P+3YI<T5Q=6%L*"1D97`I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1C:&5C:V5D6W-T<G1O;&]W97(H)'`M/F=E
M=$-H86YN96PH*2E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!;
M<W1R=&]L;W=E<B@D<"T^9V5T4&%C:V%G92@I*5TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@861D('1H92!D97!E;F1E;F-Y)W,@9&5P
M96YD96YC:65S('1O('1H92!T<F5E#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]G971$97!4<F5E1%`H)'`L("1P86-K86=E<RP@)&1E
M<',L("1C:&5C:V5D*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%-O<G0@82!L:7-T(&]F(&%R<F%Y<R!O9B!A<G)A>2AD;W=N;&]A9&5D('!A
M8VMA9V5F:6QE;F%M92D@8GD@9&5P96YD96YC>2X-"B`@("`@*@T*("`@("`J
M($ET(&%L<V\@<F5M;W9E<R!D=7!L:6-A=&4@9&5P96YD96YC:65S#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&%N(&%R<F%Y(&]F(&1O=VYL;V%D960@4$5!4E]$
M;W=N;&]A9&5R7U!A8VMA9V5S#0H@("`@("H@0')E='5R;B!A<G)A>2!A<G)A
M>2!O9B!A<G)A>2AP86-K86=E9FEL96YA;64L('!A8VMA9V4N>&UL(&-O;G1E
M;G1S*0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-O<G1086-K86=E<T9O<DEN
M<W1A;&PH)B1P86-K86=E<RD-"B`@("![#0H@("`@("`@(&9O<F5A8V@@*"1P
M86-K86=E<R!A<R`D:2`]/B`D<&%C:V%G92D@>PT*("`@("`@("`@("`@)&-H
M96-K960@/2`D9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`D=&AI<RT^
M7V=E=$1E<%1R965$4"@D<&%C:V%G97-;)&E=+"`D<&%C:V%G97,L("1D97!S
M+"`D8VAE8VME9"D[#0H@("`@("`@("`@("`D=&AI<RT^7V1E<%1R965;)'!A
M8VMA9V4M/F=E=$-H86YN96PH*5U;)'!A8VMA9V4M/F=E=%!A8VMA9V4H*5T@
M/2`D9&5P<SL-"B`@("`@("`@?0T*("`@("`@("!U<V]R="@D<&%C:V%G97,L
M(&%R<F%Y*"8D=&AI<RP@)U]S;W)T26YS=&%L;"<I*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?9&5P96YD<T]N*"1A+"`D8BD-"B`@("![#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-H96-K1&5P5')E92AS=')T;VQO=V5R*"1A+3YG
M971#:&%N;F5L*"DI+"!S=')T;VQO=V5R*"1A+3YG971086-K86=E*"DI+`T*
M("`@("`@("`@("`@)&(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C:&5C
M:T1E<%1R964H)&-H86YN96PL("1P86-K86=E+"`D8BP@)&-H96-K960@/2!A
M<G)A>2@I*0T*("`@('L-"B`@("`@("`@)&-H96-K961;)&-H86YN96Q=6R1P
M86-K86=E72`]('1R=64[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]D
M97!4<F5E6R1C:&%N;F5L75LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?9&5P5')E95LD8VAA;FYE;%U;)'!A8VMA9V5=6W-T<G1O;&]W97(H
M)&(M/F=E=$-H86YN96PH*2E=#0H@("`@("`@("`@("`@(%MS=')T;VQO=V5R
M*"1B+3YG971086-K86=E*"DI72DI('L-"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?9&5P
M5')E95LD8VAA;FYE;%U;)'!A8VMA9V5=(&%S("1C:"`]/B`D<&%C:V%G97,I
M('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D<&$@/3X@
M)'1R=64I('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C:&5C:T1E
M<%1R964H)&-H+"`D<&$L("1B+"`D8VAE8VME9"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?<V]R=$EN<W1A;&PH)&$L("1B*0T*
M("`@('L-"B`@("`@("`@:68@*"$D82T^9V5T1&5P<R@I("8F("$D8BT^9V5T
M1&5P<R@I*2![#0H@("`@("`@("`@("!R971U<FX@,#L@+R\@;F5I=&AE<B!P
M86-K86=E(&AA<R!D97!E;F1E;F-I97,L(&]R9&5R(&ES(&EN<VEG;FEF:6-A
M;G0-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&$M/F=E=$1E<',H*2`F)B`A
M)&(M/F=E=$1E<',H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(#$[("\O("1A
M(&UU<W0@8F4@:6YS=&%L;&5D(&%F=&5R("1B(&)E8V%U<V4@)&$@:&%S(&1E
M<&5N9&5N8VEE<PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&$M/F=E=$1E
M<',H*2`F)B`D8BT^9V5T1&5P<R@I*2![#0H@("`@("`@("`@("!R971U<FX@
M+3$[("\O("1B(&UU<W0@8F4@:6YS=&%L;&5D(&%F=&5R("1A(&)E8V%U<V4@
M)&(@:&%S(&1E<&5N9&5N8VEE<PT*("`@("`@("!]#0H@("`@("`@("\O(&)O
M=&@@<&%C:V%G97,@:&%V92!D97!E;F1E;F-I97,-"B`@("`@("`@:68@*"1T
M:&ES+3Y?9&5P96YD<T]N*"1A+"`D8BDI('L-"B`@("`@("`@("`@(')E='5R
M;B`Q.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7V1E<&5N9'-/
M;B@D8BP@)&$I*2![#0H@("`@("`@("`@("!R971U<FX@+3$[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(#`[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@1&]W;FQO860@82!F:6QE('1H<F]U9V@@2%144"X@($-O;G-I9&5R<R!S
M=6=G97-T960@9FEL92!N86UE(&EN#0H@("`@("H@0V]N=&5N="UD:7-P;W-I
M=&EO;CH@:&5A9&5R(&%N9"!C86X@<G5N(&$@8V%L;&)A8VL@9G5N8W1I;VX@
M9F]R#0H@("`@("H@9&EF9F5R96YT(&5V96YT<RX@(%1H92!C86QL8F%C:R!W
M:6QL(&)E(&-A;&QE9"!W:71H('1W;PT*("`@("`J('!A<F%M971E<G,Z('1H
M92!C86QL8F%C:R!T>7!E+"!A;F0@<&%R86UE=&5R<RX@(%1H92!I;7!L96UE
M;G1E9`T*("`@("`J(&-A;&QB86-K('1Y<&5S(&%R93H-"B`@("`@*@T*("`@
M("`J("`G<V5T=7`G("`@("`@(&-A;&QE9"!A="!T:&4@=F5R>2!B96=I;FYI
M;F<L('!A<F%M971E<B!I<R!A(%5)(&]B:F5C=`T*("`@("`J("`@("`@("`@
M("`@("`@('1H870@<VAO=6QD(&)E('5S960@9F]R(&%L;"!O=71P=70-"B`@
M("`@*B`@)VUE<W-A9V4G("`@("!T:&4@<&%R86UE=&5R(&ES(&$@<W1R:6YG
M('=I=&@@86X@:6YF;W)M871I;VYA;"!M97-S86=E#0H@("`@("H@("=S879E
M87,G("`@("`@;6%Y(&)E('5S960@=&\@<V%V92!W:71H(&$@9&EF9F5R96YT
M(&9I;&4@;F%M92P@=&AE#0H@("`@("H@("`@("`@("`@("`@("`@<&%R86UE
M=&5R(&ES('1H92!F:6QE;F%M92!T:&%T(&ES(&%B;W5T('1O(&)E('5S960N
M#0H@("`@("H@("`@("`@("`@("`@("`@268@82`G<V%V96%S)R!C86QL8F%C
M:R!R971U<FYS(&$@;F]N+65M<'1Y('-T<FEN9RP-"B`@("`@*B`@("`@("`@
M("`@("`@("!T:&%T(&9I;&4@;F%M92!W:6QL(&)E('5S960@87,@=&AE(&9I
M;&5N86UE(&EN<W1E860N#0H@("`@("H@("`@("`@("`@("`@("`@3F]T92!T
M:&%T("1S879E7V1I<B!W:6QL(&YO="!B92!A9F9E8W1E9"!B>2!T:&ES+"!O
M;FQY#0H@("`@("H@("`@("`@("`@("`@("`@=&AE(&)A<V5N86UE(&]F('1H
M92!F:6QE+@T*("`@("`J("`G<W1A<G0G("`@("`@(&1O=VYL;V%D(&ES('-T
M87)T:6YG+"!P87)A;65T97(@:7,@;G5M8F5R(&]F(&)Y=&5S#0H@("`@("H@
M("`@("`@("`@("`@("`@=&AA="!A<F4@97AP96-T960L(&]R("TQ(&EF('5N
M:VYO=VX-"B`@("`@*B`@)V)Y=&5S<F5A9"<@("!P87)A;65T97(@:7,@=&AE
M(&YU;6)E<B!O9B!B>71E<R!R96%D('-O(&9A<@T*("`@("`J("`G9&]N92<@
M("`@("`@(&1O=VYL;V%D(&ES(&-O;7!L971E+"!P87)A;65T97(@:7,@=&AE
M('1O=&%L(&YU;6)E<@T*("`@("`J("`@("`@("`@("`@("`@(&]F(&)Y=&5S
M(')E860-"B`@("`@*B`@)V-O;FYF86EL960G("!I9B!T:&4@5$-0+U-33"!C
M;VYN96-T:6]N(&9A:6QS+"!T:&ES(&-A;&QB86-K(&ES(&-A;&QE9`T*("`@
M("`J("`@("`@("`@("`@("`@('=I=&@@87)R87DH:&]S="QP;W)T+&5R<FYO
M+&5R<FUS9RD-"B`@("`@*B`@)W=R:71E9F%I;&5D)R!I9B!W<FET:6YG('1O
M(&1I<VL@9F%I;',L('1H:7,@8V%L;&)A8VL@:7,@8V%L;&5D#0H@("`@("H@
M("`@("`@("`@("`@("`@=VET:"!A<G)A>2AD97-T9FEL92QE<G)M<V<I#0H@
M("`@("H-"B`@("`@*B!)9B!A;B!(5%10('!R;WAY(&AA<R!B965N(&-O;F9I
M9W5R960@*&AT='!?<')O>'D@4$5!4E]#;VYF:6<-"B`@("`@*B!S971T:6YG
M*2P@=&AE('!R;WAY('=I;&P@8F4@=7-E9"X-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@("1U<FP@("`@("`@=&AE(%523"!T;R!D;W=N;&]A9`T*
M("`@("`J($!P87)A;2!O8FIE8W0@("1U:2`@("`@("`@4$5!4E]&<F]N=&5N
M9%\J(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M(&]B:F5C="`@)&-O;F9I9R`@
M("!014%27T-O;F9I9R!I;G-T86YC90T*("`@("`J($!P87)A;2!S=')I;F<@
M("1S879E7V1I<B`@9&ER96-T;W)Y('1O('-A=F4@9FEL92!I;@T*("`@("`J
M($!P87)A;2!M:7AE9"`@("1C86QL8F%C:R`@9G5N8W1I;VXO;65T:&]D('1O
M(&-A;&P@9F]R('-T871U<PT*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7!D871E<PT*("`@("`J($!P87)A;2!F86QS97QS=')I;F=\87)R
M87D@)&QA<W1M;V1I9FEE9"!H96%D97(@=F%L=65S('1O(&-H96-K(&%G86EN
M<W0@9F]R(&-A8VAI;F<-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@('5S92!F86QS92!T;R!R971U<FX@=&AE(&AE861E<B!V86QU97,@9G)O
M;2!T:&ES(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M(&9A;'-E?&%R<F%Y("1A
M8V-E<'0@06-C97!T(&AE861E<G,@=&\@<V5N9`T*("`@("`J($!R971U<FX@
M<W1R:6YG?&%R<F%Y("!2971U<FYS('1H92!F=6QL('!A=&@@;V8@=&AE(&1O
M=VYL;V%D960@9FEL92!O<B!A(%!%05(-"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@97)R;W(@;VX@9F%I;'5R92X@($EF('1H92!E<G)O<B!I<R!C
M875S960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V]C:V5T
M+7)E;&%T960@97)R;W)S+"!T:&4@97)R;W(@;V)J96-T('=I;&P-"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@:&%V92!T:&4@9G-O8VMO<&5N(&5R
M<F]R(&-O9&4@879A:6QA8FQE('1H<F]U9V@-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@9V5T0V]D92@I+B`@268@8V%C:&EN9R!I<R!R97%U97-T
M960L('1H96X@<F5T=7)N('1H92!H96%D97(-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@=F%L=65S+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P
M=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D;W=N;&]A9$AT='`H)'5R
M;"P@)B1U:2P@)'-A=F5?9&ER(#T@)RXG+"`D8V%L;&)A8VL@/2!N=6QL+"`D
M;&%S=&UO9&EF:65D(#T@;G5L;"P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&%C8V5P="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1R
M961I<F5C="`](#`[#0H@("`@("`@("\O(&%L;'=A>7,@<F5S970@+"!S;R!W
M92!A<F4@8VQE86X@8V%S92!O9B!E<G)O<@T*("`@("`@("`D=V%S<F5D:7)E
M8W0@/2`D<F5D:7)E8W0[#0H@("`@("`@("1R961I<F5C="`](#`[#0H@("`@
M("`@(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC*"1C86QL8F%C:RP@)W-E='5P)RP@87)R87DH)B1U:2DI.PT*("`@("`@
M("!]#0H@("`@("`@("1I;F9O(#T@<&%R<V5?=7)L*"1U<FPI.PT*("`@("`@
M("!I9B`H(6ES<V5T*"1I;F9O6R=S8VAE;64G72D@?'P@(6EN7V%R<F%Y*"1I
M;F9O6R=S8VAE;64G72P@87)R87DH)VAT='`G+"`G:'1T<',G*2DI('L-"B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@9&]W
M;FQO860@;F]N+6AT='`@55),("(G("X@)'5R;"`N("<B)RD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG:&]S="==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;FYO="!D;W=N
M;&]A9"!F<F]M(&YO;BU54DP@(B<@+B`D=7)L("X@)R(G*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1H;W-T(#T@0"1I;F9O6R=H;W-T)UT[
M#0H@("`@("`@("`@("`D<&]R="`]($`D:6YF;ULG<&]R="==.PT*("`@("`@
M("`@("`@)'!A=&@@/2!`)&EN9F];)W!A=&@G73L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,I*2![#0H@("`@("`@("`@("`D8V]N9FEG
M(#T@)B1T:&ES+3YC;VYF:6<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<')O>'E?:&]S="`]("1P<F]X>5]P;W)T(#T@
M)'!R;WAY7W5S97(@/2`D<')O>'E?<&%S<R`]("<G.PT*("`@("`@("!I9B`H
M)&-O;F9I9RT^9V5T*"=H='1P7W!R;WAY)RDF)B`-"B`@("`@("`@("`@("`@
M)'!R;WAY(#T@<&%R<V5?=7)L*"1C;VYF:6<M/F=E="@G:'1T<%]P<F]X>2<I
M*2D@>PT*("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2!`)'!R;WAY6R=H;W-T
M)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!R;WAY6R=S8VAE;64G72D@
M)B8@)'!R;WAY6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@
M("`@("`@)'!R;WAY7VAO<W0@/2`G<W-L.B\O)R`N("1P<F]X>5]H;W-T.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!R;WAY7W!O<G0@/2!`)'!R
M;WAY6R=P;W)T)UT[#0H@("`@("`@("`@("`D<')O>'E?=7-E<B`]($`D<')O
M>'E;)W5S97(G73L-"B`@("`@("`@("`@("1P<F]X>5]P87-S(#T@0"1P<F]X
M>5LG<&%S<R==.PT*#0H@("`@("`@("`@("!I9B`H)'!R;WAY7W!O<G0@/3T@
M)R<I('L-"B`@("`@("`@("`@("`@("`D<')O>'E?<&]R="`](#@P.#`[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@
M("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G;65S
M<V%G92<L(")5<VEN9R!(5%10('!R;WAY("1H;W-T.B1P;W)T(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1P;W)T
M*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S8VAE;64G72D@
M)B8@)&EN9F];)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@("`@("`@("`@
M("`@("`D<&]R="`](#0T,SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)'!O<G0@/2`X,#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'!R;WAY7VAO<W0@(3T@)R<I('L-"B`@("`@
M("`@("`@("1F<"`]($!F<V]C:V]P96XH)'!R;WAY7VAO<W0L("1P<F]X>5]P
M;W)T+"`D97)R;F\L("1E<G)S='(I.PT*("`@("`@("`@("`@:68@*"$D9G`I
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@
M("`@("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)V-O;FYF
M86EL960G+"!A<G)A>2@D<')O>'E?:&]S="P@)'!R;WAY7W!O<G0L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D97)R;F\L("1E<G)S='(I*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H(D-O;FYE8W1I;VX@=&\@8"1P<F]X>5]H;W-T.B1P<F]X>5]P;W)T
M)R!F86EL960Z("1E<G)S='(B+"`D97)R;F\I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"1L87-T;6]D:69I960@/3T](&9A;'-E('Q\("1L
M87-T;6]D:69I960I('L-"B`@("`@("`@("`@("`@("`D<F5Q=65S="`](")'
M150@)'5R;"!(5%10+S$N,5QR7&XB.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`D<F5Q=65S="`](")'150@)'5R;"!(5%10+S$N
M,%QR7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S8VAE;64G72D@)B8@)&EN9F];
M)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@("`@("`@("`@("`@("`D:&]S
M="`]("=S<VPZ+R\G("X@)&AO<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D9G`@/2!`9G-O8VMO<&5N*"1H;W-T+"`D<&]R="P@)&5R<FYO+"`D
M97)R<W1R*3L-"B`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@("`@("!C
M86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=C;VYN9F%I;&5D)RP@87)R87DH
M)&AO<W0L("1P;W)T+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<FYO+"`D
M97)R<W1R*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(')E='5R;B!014%2.CIR86ES945R<F]R*")#;VYN96-T:6]N('1O(&`D:&]S
M=#HD<&]R="<@9F%I;&5D.B`D97)R<W1R(BP@)&5R<FYO*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@D;&%S=&UO9&EF:65D(#T]/2!F86QS
M92!\?"`D;&%S=&UO9&EF:65D*2![#0H@("`@("`@("`@("`@("`@)')E<75E
M<W0@/2`B1T54("1P871H($A45%`O,2XQ7')<;B([#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1R97%U97-T(#T@(D=%5"`D<&%T
M:"!(5%10+S$N,%QR7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`G)SL-"B`@("`@("`@:68@*&ES
M7V%R<F%Y*"1L87-T;6]D:69I960I*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&QA<W1M;V1I9FEE9%LG3&%S="U-;V1I9FEE9"==*2D@>PT*("`@("`@
M("`@("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`G268M36]D:69I960M4VEN
M8V4Z("<@+B`D;&%S=&UO9&EF:65D6R=,87-T+4UO9&EF:65D)UT@+B`B7')<
M;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&QA
M<W1M;V1I9FEE9%LG151A9R==*2D@>PT*("`@("`@("`@("`@("`@("1I9FUO
M9&EF:65D<VEN8V4@+CT@(DEF+4YO;F4M36%T8V@Z("1L87-T;6]D:69I961;
M151A9UU<<EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`H)&QA<W1M;V1I9FEE
M9"`_("))9BU-;V1I9FEE9"U3:6YC93H@)&QA<W1M;V1I9FEE9%QR7&XB(#H@
M)R<I.PT*("`@("`@("!]#0H@("`@("`@("1R97%U97-T("X](")(;W-T.B`D
M:&]S=#HD<&]R=%QR7&XB("X@)&EF;6]D:69I961S:6YC92`N#0H@("`@("`@
M("`@("`B57-E<BU!9V5N=#H@4$5!4B\Q+C0N.2]02%`O(B`N(%!(4%]615)3
M24].("X@(EQR7&XB.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,I*2![("\O
M(&]N;'D@<&%S<R!I;B!A=71H96YT:6-A=&EO;B!F;W(@;F]N+7-T871I8R!C
M86QL<PT*("`@("`@("`@("`@)'5S97)N86UE(#T@)&-O;F9I9RT^9V5T*"=U
M<V5R;F%M92<I.PT*("`@("`@("`@("`@)'!A<W-W;W)D(#T@)&-O;F9I9RT^
M9V5T*"=P87-S=V]R9"<I.PT*("`@("`@("`@("`@:68@*"1U<V5R;F%M92`F
M)B`D<&%S<W=O<F0I('L-"B`@("`@("`@("`@("`@("`D=&UP(#T@8F%S938T
M7V5N8V]D92@B)'5S97)N86UE.B1P87-S=V]R9"(I.PT*("`@("`@("`@("`@
M("`@("1R97%U97-T("X](")!=71H;W)I>F%T:6]N.B!"87-I8R`D=&UP7')<
M;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P
M<F]X>5]H;W-T("$]("<G("8F("1P<F]X>5]U<V5R("$]("<G*2![#0H@("`@
M("`@("`@("`D<F5Q=65S="`N/2`G4')O>'DM075T:&]R:7IA=&EO;CH@0F%S
M:6,@)R`N#0H@("`@("`@("`@("`@("`@8F%S938T7V5N8V]D92@D<')O>'E?
M=7-E<B`N("<Z)R`N("1P<F]X>5]P87-S*2`N(")<<EQN(CL-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&%C8V5P="D@>PT*("`@("`@("`@("`@)')E<75E
M<W0@+CT@)T%C8V5P=#H@)R`N(&EM<&QO9&4H)RP@)RP@)&%C8V5P="D@+B`B
M7')<;B([#0H@("`@("`@('T-"B`@("`@("`@)')E<75E<W0@+CT@(D-O;FYE
M8W1I;VXZ(&-L;W-E7')<;B([#0H@("`@("`@("1R97%U97-T("X](")<<EQN
M(CL-"B`@("`@("`@9G=R:71E*"1F<"P@)')E<75E<W0I.PT*("`@("`@("`D
M:&5A9&5R<R`](&%R<F%Y*"D[#0H@("`@("`@("1R97!L>2`](#`[#0H@("`@
M("`@('=H:6QE("AT<FEM*"1L:6YE(#T@9F=E=',H)&9P+"`Q,#(T*2DI('L-
M"B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7BA;7CI=*RDZ7',K*"XJ
M*5QS*B0O)RP@)&QI;F4L("1M871C:&5S*2D@>PT*("`@("`@("`@("`@("`@
M("1H96%D97)S6W-T<G1O;&]W97(H)&UA=&-H97-;,5TI72`]('1R:6TH)&UA
M=&-H97-;,ETI.PT*("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H
M)WQ>2%144"\Q+ELP,5T@*%LP+3E=>S-]*2!\)RP@)&QI;F4L("1M871C:&5S
M*2D@>PT*("`@("`@("`@("`@("`@("1R97!L>2`]("AI;G0I("1M871C:&5S
M6S%=.PT*("`@("`@("`@("`@("`@(&EF("@D<F5P;'D@/3T@,S`T("8F("@D
M;&%S=&UO9&EF:65D('Q\("@D;&%S=&UO9&EF:65D(#T]/2!F86QS92DI*2![
M#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"$@:6Y?87)R87DH)')E
M<&QY+"!A<G)A>2@R,#`L(#,P,2P@,S`R+"`S,#,L(#,P-2P@,S`W*2DI('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M(D9I;&4@:'1T<#HO+R1H;W-T.B1P;W)T)'!A=&@@;F]T('9A;&ED("AR96-E
M:79E9#H@)&QI;F4I(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5P;'D@(3T@,C`P*2![
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&AE861E<G-;)VQO8V%T:6]N)UTI
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1W87-R961I<F5C="`\(#4I('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E9&ER96-T(#T@)'=A<W)E9&ER96-T
M("L@,3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YD;W=N
M;&]A9$AT='`H)&AE861E<G-;)VQO8V%T:6]N)UTL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'5I+"`D<V%V95]D:7(L("1C86QL8F%C:RP@)&QA
M<W1M;V1I9FEE9"P@)&%C8V5P="D[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D9I;&4@:'1T<#HO+R1H;W-T.B1P;W)T)'!A=&@@;F]T('9A;&ED("AR
M961I<F5C=&EO;B!L;V]P960@;6]R92!T:&%N(#4@=&EM97,I(BD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B1FEL92!H='1P.B\O
M)&AO<W0Z)'!O<G0D<&%T:"!N;W0@=F%L:60@*')E9&ER96-T960@8G5T(&YO
M(&QO8V%T:6]N*2(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D:&5A9&5R<ULG8V]N=&5N="UD:7-P;W-I=&EO;B==
M*2`F)@T*("`@("`@("`@("`@<')E9U]M871C:"@G+UQS9FEL96YA;64]7"(H
M6UX[72I<4RE<(EQS*B@[?"0I+R<L("1H96%D97)S6R=C;VYT96YT+61I<W!O
M<VET:6]N)UTL("1M871C:&5S*2D@>PT*("`@("`@("`@("`@)'-A=F5?87,@
M/2!B87-E;F%M92@D;6%T8VAE<ULQ72D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D<V%V95]A<R`](&)A<V5N86UE*"1U<FPI.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D8V%L;&)A8VLI('L-"B`@("`@("`@("`@("1T
M;7`@/2!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=S879E87,G+"`D<V%V
M95]A<RD[#0H@("`@("`@("`@("!I9B`H)'1M<"D@>PT*("`@("`@("`@("`@
M("`@("1S879E7V%S(#T@)'1M<#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("`D9&5S=%]F:6QE(#T@)'-A=F5?9&ER("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1S879E7V%S.PT*("`@("`@("!I9B`H(21W<"`]($!F
M;W!E;B@D9&5S=%]F:6QE+"`G=V(G*2D@>PT*("`@("`@("`@("`@9F-L;W-E
M*"1F<"D[#0H@("`@("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@
M("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K+"`G=W)I=&5F86EL
M960G+"!A<G)A>2@D9&5S=%]F:6QE+"`D<&AP7V5R<F]R;7-G*2D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B8V]U;&0@;F]T(&]P96X@)&1E<W1?9FEL92!F;W(@=W)I=&EN9R(I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG8V]N=&5N
M="UL96YG=&@G72DI('L-"B`@("`@("`@("`@("1L96YG=&@@/2`D:&5A9&5R
M<ULG8V]N=&5N="UL96YG=&@G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1L96YG=&@@/2`M,3L-"B`@("`@("`@?0T*("`@("`@("`D8GET
M97,@/2`P.PT*("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@
M("!C86QL7W5S97)?9G5N8R@D8V%L;&)A8VLL("=S=&%R="<L(&%R<F%Y*&)A
M<V5N86UE*"1D97-T7V9I;&4I+"`D;&5N9W1H*2D[#0H@("`@("`@('T-"B`@
M("`@("`@=VAI;&4@*"1D871A(#T@0&9R96%D*"1F<"P@,3`R-"DI('L-"B`@
M("`@("`@("`@("1B>71E<R`K/2!S=')L96XH)&1A=&$I.PT*("`@("`@("`@
M("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E
M<E]F=6YC*"1C86QL8F%C:RP@)V)Y=&5S<F5A9"<L("1B>71E<RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(4!F=W)I=&4H)'=P+"`D9&%T
M82DI('L-"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M("`@("`@("!I9B`H)&-A;&QB86-K*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-A;&Q?=7-E<E]F=6YC*"1C86QL8F%C:RP@)W=R:71E9F%I;&5D)RP@87)R
M87DH)&1E<W1?9FEL92P@)'!H<%]E<G)O<FUS9RDI.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B)&1E<W1?9FEL93H@=W)I=&4@9F%I;&5D("@D<&AP7V5R<F]R;7-G*2(I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&9C;&]S92@D
M9G`I.PT*("`@("`@("!F8VQO<V4H)'=P*3L-"B`@("`@("`@:68@*"1C86QL
M8F%C:RD@>PT*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H)&-A;&QB86-K
M+"`G9&]N92<L("1B>71E<RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1L
M87-T;6]D:69I960@/3T](&9A;'-E('Q\("1L87-T;6]D:69I960I('L-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D:&5A9&5R<ULG971A9R==*2D@>PT*("`@
M("`@("`@("`@("`@("1L87-T;6]D:69I960@/2!A<G)A>2@G151A9R<@/3X@
M)&AE861E<G-;)V5T86<G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&AE861E<G-;)VQA<W0M;6]D:69I960G72DI('L-"B`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&QA<W1M;V1I9FEE9"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9%LG3&%S="U-;V1I
M9FEE9"==(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D;&%S=&UO
M9&EF:65D(#T@)&AE861E<G-;)VQA<W0M;6]D:69I960G73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@
M87)R87DH)&1E<W1?9FEL92P@)&QA<W1M;V1I9FEE9"P@)&AE861E<G,I.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B`D9&5S=%]F:6QE.PT*("`@('T-
M"GT-"B\O('U]?0T*#0H_/@T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O17)R;W)3=&%C:RYP:'``````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#,V,3,@,3`U,34T
M,S0Q,S0@,#(R,#`U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO*BH-"B`J($5R<F]R(%-T86-K($EM<&QE;65N
M=&%T:6]N#0H@*B`-"B`J(%1H:7,@:7,@86X@:6YC<F5D:6)L>2!S:6UP;&4@
M:6UP;&5M96YT871I;VX@;V8@82!V97)Y(&-O;7!L97@@97)R;W(@:&%N9&QI
M;F<-"B`J(&9A8VEL:71Y+B`@270@8V]N=&%I;G,@=&AE(&%B:6QI='D-"B`J
M('1O('1R86-K(&UU;'1I<&QE(&5R<F]R<R!F<F]M(&UU;'1I<&QE('!A8VMA
M9V5S('-I;75L=&%N96]U<VQY+B`@26X@861D:71I;VXL#0H@*B!I="!C86X@
M=')A8VL@97)R;W)S(&]F(&UA;GD@;&5V96QS+"!S879E(&1A=&$@86QO;F<@
M=VET:"!T:&4@97)R;W(L(&-O;G1E>'0-"B`J(&EN9F]R;6%T:6]N('-U8V@@
M87,@=&AE(&5X86-T(&9I;&4L(&QI;F4@;G5M8F5R+"!C;&%S<R!A;F0@9G5N
M8W1I;VX@=&AA=`T*("H@9V5N97)A=&5D('1H92!E<G)O<BP@86YD(&EF(&YE
M8V5S<V%R>2P@:70@8V%N(')A:7-E(&$@=')A9&ET:6]N86P@4$5!4E]%<G)O
M<BX-"B`J($ET(&AA<R!B=6EL="UI;B!S=7!P;W)T(&9O<B!014%2.CI,;V<L
M('1O(&QO9R!E<G)O<G,@87,@=&AE>2!O8V-U<@T*("H@#0H@*B!3:6YC92!V
M97)S:6]N(#`N,F%L<&AA+"!I="!I<R!A;'-O('!O<W-I8FQE('1O('-E;&5C
M=&EV96QY(&EG;F]R92!E<G)O<G,L#0H@*B!T:')O=6=H('1H92!U<V4@;V8@
M86X@97)R;W(@8V%L;&)A8VLL('-E92![0&QI;FL@<'5S:$-A;&QB86-K*"E]
M#0H@*B`-"B`J(%-I;F-E('9E<G-I;VX@,"XS86QP:&$L(&ET(&ES('!O<W-I
M8FQE('1O('-P96-I9GD@=&AE(&5X8V5P=&EO;B!C;&%S<PT*("H@<F5T=7)N
M960@9G)O;2![0&QI;FL@<'5S:"@I?0T*("H-"B`J(%-I;F-E('9E<G-I;VX@
M4$5!4C$N,RXR+"!%<G)O<E-T86-K(&YO(&QO;F=E<B!I;G-T86YT:6%T97,@
M86X@97AC97!T:6]N(&-L87-S+B`@5&AI<R!C86X-"B`J('-T:6QL(&)E(&1O
M;F4@<75I=&4@:&%N9&EL>2!I;B!A;B!E<G)O<B!C86QL8F%C:R!O<B!B>2!M
M86YI<'5L871I;F<@=&AE(')E='5R;F5D(&%R<F%Y#0H@*B!`8V%T96=O<GD@
M("!$96)U9V=I;F<-"B`J($!P86-K86=E("`@(%!%05)?17)R;W)3=&%C:PT*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,C`P-"TR,#`V($=R96<@0F5A=F5R#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!%<G)O
M<E-T86-K+G!H<"QV(#$N,C(@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%27T5R<F]R4W1A8VL-"B`J+PT*#0HO*BH-"B`J(%-I;F=L971O
M;B!S=&]R86=E#0H@*B`-"B`J($9O<FUA=#H-"B`J(#QP<F4^#0H@*B!A<G)A
M>2@-"B`J("`G<&%C:V%G93$G(#T^(%!%05)?17)R;W)3=&%C:R!O8FIE8W0L
M#0H@*B`@)W!A8VMA9V4R)R`]/B!014%27T5R<F]R4W1A8VL@;V)J96-T+`T*
M("H@("XN+@T*("H@*0T*("H@/"]P<F4^#0H@*B!`86-C97-S('!R:79A=&4-
M"B`J($!G;&]B86P@87)R87D@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?
M4TE.1TQ%5$].)UT-"B`J+PT*)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?
M4TE.1TQ%5$].)UT@/2!A<G)A>2@I.PT*#0HO*BH-"B`J($=L;V)A;"!E<G)O
M<B!C86QL8F%C:R`H9&5F875L="D-"B`J(`T*("H@5&AI<R!I<R!O;FQY('5S
M960@:68@<V5T('1O(&YO;BUF86QS92X@("H@:7,@=&AE(&1E9F%U;'0@8V%L
M;&)A8VL@9F]R#0H@*B!A;&P@<&%C:V%G97,L('=H97)E87,@<W!E8VEF:6,@
M<&%C:V%G97,@;6%Y('-E="!A(&1E9F%U;'0@8V%L;&)A8VL-"B`J(&9O<B!A
M;&P@:6YS=&%N8V5S+"!R96=A<F1L97-S(&]F('=H971H97(@=&AE>2!A<F4@
M82!S:6YG;&5T;VX@;W(@;F]T+@T*("H-"B`J(%1O(&5X8VQU9&4@;F]N+7-I
M;F=L971O;G,L(&]N;'D@<V5T('1H92!L;V-A;"!C86QL8F%C:R!F;W(@=&AE
M('-I;F=L971O;@T*("H@0'-E92!014%27T5R<F]R4W1A8VLZ.G-E=$1E9F%U
M;'1#86QL8F%C:R@I#0H@*B!`86-C97-S('!R:79A=&4-"B`J($!G;&]B86P@
M87)R87D@)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,
M0D%#2R==#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T1%1D%5
M3%1?0T%,3$)!0TLG72`](&%R<F%Y*`T*("`@("<J)R`]/B!F86QS92P-"BD[
M#0H-"B\J*@T*("H@1VQO8F%L($QO9R!O8FIE8W0@*&1E9F%U;'0I#0H@*B`-
M"B`J(%1H:7,@:7,@;VYL>2!U<V5D(&EF('-E="!T;R!N;VXM9F%L<V4N("!5
M<V4@=&\@<V5T(&$@9&5F875L="!L;V<@;V)J96-T(&9O<@T*("H@86QL('-T
M86-K<RP@<F5G87)D;&5S<R!O9B!I;G-T86YT:6%T:6]N(&]R9&5R(&]R(&QO
M8V%T:6]N#0H@*B!`<V5E(%!%05)?17)R;W)3=&%C:SHZ<V5T1&5F875L=$QO
M9V=E<B@I#0H@*B!`86-C97-S('!R:79A=&4-"B`J($!G;&]B86P@87)R87D@
M)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%],3T='15(G70T*
M("HO#0HD1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%
M4B==(#T@9F%L<V4[#0H-"B\J*@T*("H@1VQO8F%L($]V97)R:61I;F<@0V%L
M;&)A8VL-"B`J(`T*("H@5&AI<R!C86QL8F%C:R!W:6QL(&]V97)R:61E(&%N
M>2!E<G)O<B!C86QL8F%C:W,@=&AA="!S<&5C:69I8R!L;V=G97)S(&AA=F4@
M<V5T+@T*("H@57-E('=I=&@@15A44D5-12!C875T:6]N#0H@*B!`<V5E(%!%
M05)?17)R;W)3=&%C:SHZ<W1A=&EC4'5S:$-A;&QB86-K*"D-"B`J($!A8V-E
M<W,@<')I=F%T90T*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG7U!%05)?
M15)23U)35$%#2U]$149!54Q47TQ/1T=%4B==#0H@*B\-"B1'3$]"04Q36R=?
M4$5!4E]%4E)/4E-404-+7T]615)2241%7T-!3$Q"04-+)UT@/2!A<G)A>2@I
M.PT*#0HO*BHC0"L-"B`J($]N92!O9B!F;W5R('!O<W-I8FQE(')E='5R;B!V
M86QU97,@9G)O;2!T:&4@97)R;W(@0V%L;&)A8VL-"B`J($!S964@4$5!4E]%
M<G)O<E-T86-K.CI?97)R;W)#86QL8F%C:R@I#0H@*B\-"B\J*@T*("H@268@
M=&AI<R!I<R!R971U<FYE9"P@=&AE;B!T:&4@97)R;W(@=VEL;"!B92!B;W1H
M('!U<VAE9"!O;G1O('1H92!S=&%C:PT*("H@86YD(&QO9V=E9"X-"B`J+PT*
M9&5F:6YE*"=014%27T524D]24U1!0TM?4%532$%.1$Q/1R<L(#$I.PT*+RHJ
M#0H@*B!)9B!T:&ES(&ES(')E='5R;F5D+"!T:&5N('1H92!E<G)O<B!W:6QL
M(&]N;'D@8F4@<'5S:&5D(&]N=&\@=&AE('-T86-K+`T*("H@86YD(&YO="!L
M;V=G960N#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/4E-404-+7U!54T@G+"`R
M*3L-"B\J*@T*("H@268@=&AI<R!I<R!R971U<FYE9"P@=&AE;B!T:&4@97)R
M;W(@=VEL;"!O;FQY(&)E(&QO9V=E9"P@8G5T(&YO="!P=7-H960-"B`J(&]N
M=&\@=&AE(&5R<F]R('-T86-K+@T*("HO#0ID969I;F4H)U!%05)?15)23U)3
M5$%#2U],3T<G+"`S*3L-"B\J*@T*("H@268@=&AI<R!I<R!R971U<FYE9"P@
M=&AE;B!T:&4@97)R;W(@:7,@8V]M<&QE=&5L>2!I9VYO<F5D+@T*("HO#0ID
M969I;F4H)U!%05)?15)23U)35$%#2U])1TY/4D4G+"`T*3L-"B\J*@T*("H@
M268@=&AI<R!I<R!R971U<FYE9"P@=&AE;B!T:&4@97)R;W(@:7,@;&]G9V5D
M(&%N9"!D:64H*2!I<R!C86QL960N#0H@*B\-"F1E9FEN92@G4$5!4E]%4E)/
M4E-404-+7T1)12<L(#4I.PT*+RHJ(T`M*B\-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E(&9O<B!A;B!A='1E;7!T('1O(&EN<W1A;G1I871E(&$@;F]N+6-L87-S
M(&%S(&$@4$5!4E]%<G)O<E-T86-K(&EN#0H@*B!T:&4@<VEN9VQE=&]N(&UE
M=&AO9"X-"B`J+PT*9&5F:6YE*"=014%27T524D]24U1!0TM?15)27TY/3D-,
M05-3)RP@,2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!F;W(@86X@871T96UP
M="!T;R!P87-S(&%N(&]B:F5C="!I;G1O('M`;&EN:R!014%27T5R<F]R4W1A
M8VLZ.F=E=$UE<W-A9V4H*7T-"B`J('1H870@:&%S(&YO(%]?=&]3=')I;F<H
M*2!M971H;V0-"B`J+PT*9&5F:6YE*"=014%27T524D]24U1!0TM?15)27T]"
M2E1/4U1224Y')RP@,BD[#0HO*BH-"B`J($5R<F]R(%-T86-K($EM<&QE;65N
M=&%T:6]N#0H@*@T*("H@57-A9V4Z#0H@*B`\8V]D93X-"B`J("\O(&=L;V)A
M;"!E<G)O<B!S=&%C:PT*("H@)&=L;V)A;%]S=&%C:R`]("9014%27T5R<F]R
M4W1A8VLZ.G-I;F=L971O;B@G37E086-K86=E)RD[#0H@*B`O+R!L;V-A;"!E
M<G)O<B!S=&%C:PT*("H@)&QO8V%L7W-T86-K(#T@;F5W(%!%05)?17)R;W)3
M=&%C:R@G37E086-K86=E)RD[#0H@*B`\+V-O9&4^#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`=F5R<VEO;B`@
M("`Q+C0N.0T*("H@0'!A8VMA9V4@("`@4$5!4E]%<G)O<E-T86-K#0H@*B!`
M8V%T96=O<GD@("!$96)U9V=I;F<-"B`J($!C;W!Y<FEG:'0@(#(P,#0M,C`P
M-B!'<F5G($)E879E<@T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@17)R;W)3=&%C:RYP:'`L=B`Q+C(R(#(P,#8O
M,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4E]%<G)O<E-T86-K#0H@
M*B\-"F-L87-S(%!%05)?17)R;W)3=&%C:R![#0H@("`@+RHJ#0H@("`@("H@
M17)R;W)S(&%R92!S=&]R960@:6X@=&AE(&]R9&5R('1H870@=&AE>2!A<F4@
M<'5S:&5D(&]N('1H92!S=&%C:RX-"B`@("`@*B!`<VEN8V4@,"XT86QP:&$@
M17)R;W)S(&%R92!N;R!L;VYG97(@;W)G86YI>F5D(&)Y(&5R<F]R(&QE=F5L
M+@T*("`@("`J(%1H:7,@<F5N9&5R<R!P;W`H*2!N96%R;'D@=6YU<V%B;&4L
M(&%N9"!L979E;',@8V]U;&0@8F4@;6]R92!E87-I;'D-"B`@("`@*B!H86YD
M;&5D(&EN(&$@8V%L;&)A8VL@86YY=V%Y#0H@("`@("H@0'9A<B!A<G)A>0T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V5R
M<F]R<R`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@("`@*B!3=&]R86=E(&]F
M(&5R<F]R<R!B>2!L979E;"X-"B`@("`@*@T*("`@("`J($%L;&]W<R!E87-Y
M(')E=')I979A;"!A;F0@9&5L971I;VX@;V8@;VYL>2!E<G)O<G,@9G)O;2!A
M('!A<G1I8W5L87(@;&5V96P-"B`@("`@*B!`<VEN8V4@4$5!4B`Q+C0N,&1E
M=@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!V87(@)%]E<G)O<G-">4QE=F5L(#T@87)R87DH*3L-
M"@T*("`@("\J*@T*("`@("`J(%!A8VMA9V4@;F%M92!T:&ES(&5R<F]R('-T
M86-K(')E<')E<V5N=',-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?<&%C:V%G93L-
M"B`@("`-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@82!0
M14%27T5R<F]R(&ES('1H<F]W;B!U<&]N(&5V97)Y(&5R<F]R(&%D9&ET:6]N
M#0H@("`@("H@0'9A<B!B;V]L96%N#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@=F%R("1?8V]M<&%T(#T@9F%L<V4[#0H@("`@#0H@
M("`@+RHJ#0H@("`@("H@268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H
M:7,@=VEL;"!B92!U<V5D('1O(&=E;F5R871E('1H92!E<G)O<@T*("`@("`J
M(&UE<W-A9V4@9G)O;2!T:&4@97)R;W(@8V]D92P@;W1H97)W:7-E('1H92!M
M97-S86=E('!A<W-E9"!I;B!W:6QL(&)E#0H@("`@("H@=7-E9`T*("`@("`J
M($!V87(@9F%L<V5\<W1R:6YG?&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@=F%R("1?;7-G0V%L;&)A8VL@/2!F86QS93L-
M"B`@("`-"B`@("`O*BH-"B`@("`@*B!)9B!S970@=&\@82!V86QI9"!C86QL
M8F%C:RP@=&AI<R!W:6QL(&)E('5S960@=&\@9V5N97)A=&4@=&AE(&5R<F]R
M#0H@("`@("H@8V]N=&5X="!F;W(@86X@97)R;W(N("!&;W(@4$A0+7)E;&%T
M960@97)R;W)S+"!T:&ES('=I;&P@8F4@82!F:6QE#0H@("`@("H@86YD(&QI
M;F4@;G5M8F5R(&%S(')E=')I979E9"!F<F]M(&1E8G5G7V)A8VMT<F%C92@I
M+"!B=70@8V%N(&)E#0H@("`@("H@8W5S=&]M:7IE9"!F;W(@;W1H97(@<'5R
M<&]S97,N("!4:&4@97)R;W(@;6EG:'0@86-T=6%L;'D@8F4@:6X@82!S97!A
M<F%T90T*("`@("`J(&-O;F9I9W5R871I;VX@9FEL92P@;W(@:6X@82!D871A
M8F%S92!Q=65R>2X-"B`@("`@*B!`=F%R(&9A;'-E?'-T<FEN9WQA<G)A>0T*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?
M8V]N=&5X=$-A;&QB86-K(#T@9F%L<V4[#0H@("`@#0H@("`@+RHJ#0H@("`@
M("H@268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H:7,@=VEL;"!B92!C
M86QL960@979E<GD@=&EM92!A;B!E<G)O<@T*("`@("`J(&ES('!U<VAE9"!O
M;G1O('1H92!S=&%C:RX@(%1H92!R971U<FX@=F%L=64@=VEL;"!B92!U<V5D
M('1O(&1E=&5R;6EN90T*("`@("`J('=H971H97(@=&\@86QL;W<@86X@97)R
M;W(@=&\@8F4@<'5S:&5D(&]R(&QO9V=E9"X-"B`@("`@*B`-"B`@("`@*B!4
M:&4@<F5T=7)N('9A;'5E(&UU<W0@8F4@;VYE(&%N(%!%05)?15)23U)35$%#
M2U\J(&-O;G-T86YT#0H@("`@("H@0'-E92!014%27T524D]24U1!0TM?4%53
M2$%.1$Q/1RP@4$5!4E]%4E)/4E-404-+7U!54T@L(%!%05)?15)23U)35$%#
M2U],3T<-"B`@("`@*B!`=F%R(&9A;'-E?'-T<FEN9WQA<G)A>0T*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?97)R;W)#
M86QL8F%C:R`](&%R<F%Y*"D[#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4$5!
M4CHZ3&]G(&]B:F5C="!F;W(@;&]G9VEN9R!E<G)O<G,-"B`@("`@*B!`=F%R
M(&9A;'-E?$QO9PT*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@=F%R("1?;&]G9V5R(#T@9F%L<V4[#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@17)R;W(@;65S<V%G97,@+2!D97-I9VYE9"!T;R!B92!O=F5R<FED
M9&5N#0H@("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8G-T<F%C=`T*("`@
M("`J+PT*("`@('9A<B`D7V5R<F]R37-G<R`](&%R<F%Y*"D[#0H@("`@#0H@
M("`@+RHJ#0H@("`@("H@4V5T('5P(&$@;F5W(&5R<F]R('-T86-K#0H@("`@
M("H@#0H@("`@("H@0'!A<F%M('-T<FEN9R`@("1P86-K86=E(&YA;64@;V8@
M=&AE('!A8VMA9V4@=&AI<R!E<G)O<B!S=&%C:R!R97!R97-E;G1S#0H@("`@
M("H@0'!A<F%M(&-A;&QB86-K("1M<V=#86QL8F%C:R!C86QL8F%C:R!U<V5D
M(&9O<B!E<G)O<B!M97-S86=E(&=E;F5R871I;VX-"B`@("`@*B!`<&%R86T@
M8V%L;&)A8VL@)&-O;G1E>'1#86QL8F%C:R!C86QL8F%C:R!U<V5D(&9O<B!C
M;VYT97AT(&=E;F5R871I;VXL#0H@("`@("H@("`@("`@("`@("`@("`@(&1E
M9F%U;'1S('1O('M`;&EN:R!G971&:6QE3&EN92@I?0T*("`@("`J($!P87)A
M;2!B;V]L96%N("`D=&AR;W=014%27T5R<F]R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@4$5!4E]%<G)O<E-T86-K*"1P86-K86=E+"`D;7-G0V%L;&)A8VL@
M/2!F86QS92P@)&-O;G1E>'1#86QL8F%C:R`](&9A;'-E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:')O=U!%05)?17)R;W(@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G92`]("1P86-K86=E.PT*("`@
M("`@("`D=&AI<RT^<V5T365S<V%G94-A;&QB86-K*"1M<V=#86QL8F%C:RD[
M#0H@("`@("`@("1T:&ES+3YS971#;VYT97AT0V%L;&)A8VLH)&-O;G1E>'1#
M86QL8F%C:RD[#0H@("`@("`@("1T:&ES+3Y?8V]M<&%T(#T@)'1H<F]W4$5!
M4E]%<G)O<CL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N
M(&$@<VEN9VQE(&5R<F]R('-T86-K(&9O<B!T:&ES('!A8VMA9V4N#0H@("`@
M("H@#0H@("`@("H@3F]T92!T:&%T(&%L;"!P87)A;65T97)S(&%R92!I9VYO
M<F5D(&EF('1H92!S=&%C:R!F;W(@<&%C:V%G92`D<&%C:V%G90T*("`@("`J
M(&AA<R!A;')E861Y(&)E96X@:6YS=&%N=&EA=&5D#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`@("1P86-K86=E(&YA;64@;V8@=&AE('!A8VMA9V4@=&AI<R!E
M<G)O<B!S=&%C:R!R97!R97-E;G1S#0H@("`@("H@0'!A<F%M(&-A;&QB86-K
M("1M<V=#86QL8F%C:R!C86QL8F%C:R!U<V5D(&9O<B!E<G)O<B!M97-S86=E
M(&=E;F5R871I;VX-"B`@("`@*B!`<&%R86T@8V%L;&)A8VL@)&-O;G1E>'1#
M86QL8F%C:R!C86QL8F%C:R!U<V5D(&9O<B!C;VYT97AT(&=E;F5R871I;VXL
M#0H@("`@("H@("`@("`@("`@("`@("`@(&1E9F%U;'1S('1O('M`;&EN:R!G
M971&:6QE3&EN92@I?0T*("`@("`J($!P87)A;2!B;V]L96%N("`D=&AR;W=0
M14%27T5R<F]R#0H@("`@("H@0'!A<F%M('-T<FEN9R`@("1S=&%C:T-L87-S
M(&-L87-S('1O(&EN<W1A;G1I871E#0H@("`@("H@0'-T871I8PT*("`@("`J
M($!R971U<FX@4$5!4E]%<G)O<E-T86-K#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)G-I;F=L971O;B@D<&%C:V%G92P@)&US9T-A;&QB86-K(#T@9F%L<V4L
M("1C;VYT97AT0V%L;&)A8VL@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AR;W=014%27T5R<F]R(#T@9F%L<V4L("1S=&%C:T-L87-S
M(#T@)U!%05)?17)R;W)3=&%C:R<I#0H@("`@>PT*("`@("`@("!I9B`H:7-S
M970H)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%5$].)UU;)'!A
M8VMA9V5=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!
M4E]%4E)/4E-404-+7U-)3D=,151/3B==6R1P86-K86=E73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D<W1A8VM#;&%S<RDI('L-
M"B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V1E8G5G7V)A8VMT
M<F%C92<I*2![#0H@("`@("`@("`@("`@("`@)'1R86-E(#T@9&5B=6=?8F%C
M:W1R86-E*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!014%27T5R
M<F]R4W1A8VLZ.G-T871I8U!U<V@H)U!%05)?17)R;W)3=&%C:R<L(%!%05)?
M15)23U)35$%#2U]%4E)?3D].0TQ!4U,L#0H@("`@("`@("`@("`@("`@)V5X
M8V5P=&EO;B<L(&%R<F%Y*"=S=&%C:V-L87-S)R`]/B`D<W1A8VM#;&%S<RDL
M#0H@("`@("`@("`@("`@("`@)W-T86-K(&-L87-S("(E<W1A8VMC;&%S<R4B
M(&ES(&YO="!A('9A;&ED(&-L87-S(&YA;64@*'-H;W5L9"!B92!L:6ME(%!%
M05)?17)R;W)3=&%C:RDG+`T*("`@("`@("`@("`@("`@(&9A;'-E+"`D=')A
M8V4I.PT*("`@("`@("!]#0H@("`@("`@("1'3$]"04Q36R=?4$5!4E]%4E)/
M4E-404-+7U-)3D=,151/3B==6R1P86-K86=E72`]#0H@("`@("`@("`@("!N
M97<@)'-T86-K0VQA<W,H)'!A8VMA9V4L("1M<V=#86QL8F%C:RP@)&-O;G1E
M>'1#86QL8F%C:RP@)'1H<F]W4$5!4E]%<G)O<BD[#0H-"B`@("`@("`@<F5T
M=7)N("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)3D=,151/3B==6R1P
M86-K86=E73L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!);G1E<FYA;"!E
M<G)O<B!H86YD;&5R(&9O<B!014%27T5R<F]R4W1A8VL@8VQA<W,-"B`@("`@
M*B`-"B`@("`@*B!$:65S(&EF('1H92!E<G)O<B!I<R!A;B!E>&-E<'1I;VX@
M*&%N9"!W;W5L9"!H879E(&1I960@86YY=V%Y*0T*("`@("`J($!A8V-E<W,@
M<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]H86YD;&5%<G)O<B@D
M97)R*0T*("`@('L-"B`@("`@("`@:68@*"1E<G);)VQE=F5L)UT@/3T@)V5X
M8V5P=&EO;B<I('L-"B`@("`@("`@("`@("1M97-S86=E(#T@)&5R<ELG;65S
M<V%G92==.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1?4T525D526R=215%5
M15-47U5222==*2D@>PT*("`@("`@("`@("`@("`@(&5C:&\@)SQB<B`O/B<[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&5C:&\@
M(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('9A<E]D=6UP*"1E
M<G);)V-O;G1E>'0G72D[#0H@("`@("`@("`@("!D:64H)&UE<W-A9V4I.PT*
M("`@("`@("!]#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!U
M<"!A(%!%05(Z.DQO9R!O8FIE8W0@9F]R(&%L;"!E<G)O<B!S=&%C:W,@=&AA
M="!D;VXG="!H879E(&]N90T*("`@("`J($!P87)A;2!,;V<@)&QO9R`-"B`@
M("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1&5F875L
M=$QO9V=E<B@F)&QO9RD-"B`@("![#0H@("`@("`@(&EF("AI<U]O8FIE8W0H
M)&QO9RD@)B8@;65T:&]D7V5X:7-T<R@D;&]G+"`G;&]G)RD@*2![#0H@("`@
M("`@("`@("`D1TQ/0D%,4ULG7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/
M1T=%4B==(#T@)B1L;V<[#0H@("`@("`@('T@96QS96EF("AI<U]C86QL86)L
M92@D;&]G*2D@>PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T524D]2
M4U1!0TM?1$5&055,5%],3T='15(G72`]("8D;&]G.PT*"7T-"B`@("!]#0H@
M("`@#0H@("`@+RHJ#0H@("`@("H@4V5T('5P(&$@4$5!4CHZ3&]G(&]B:F5C
M="!F;W(@=&AI<R!E<G)O<B!S=&%C:PT*("`@("`J($!P87)A;2!,;V<@)&QO
M9R`-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971,;V=G97(H)B1L;V<I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1L;V<I("8F(&UE=&AO9%]E
M>&ES=',H)&QO9RP@)VQO9R<I("D@>PT*("`@("`@("`@("`@)'1H:7,M/E]L
M;V=G97(@/2`F)&QO9SL-"B`@("`@("`@?2!E;'-E:68@*&ES7V-A;&QA8FQE
M*"1L;V<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G
M.PT*("`@("`@("!]#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E
M="!A;B!E<G)O<B!C;V1E(#T^(&5R<F]R(&UE<W-A9V4@;6%P<&EN9R!C86QL
M8F%C:PT*("`@("`J(`T*("`@("`J(%1H:7,@;65T:&]D('-E=',@=&AE(&-A
M;&QB86-K('1H870@8V%N(&)E('5S960@=&\@9V5N97)A=&4@97)R;W(-"B`@
M("`@*B!M97-S86=E<R!F;W(@86YY(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M
M(&%R<F%Y?'-T<FEN9R!#86QL8F%C:R!F=6YC=&EO;B]M971H;V0-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971-97-S86=E0V%L;&)A8VLH)&US9T-A;&QB
M86-K*0T*("`@('L-"B`@("`@("`@:68@*"$D;7-G0V%L;&)A8VLI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?;7-G0V%L;&)A8VL@/2!A<G)A>2@F)'1H:7,L
M("=G971%<G)O<DUE<W-A9V4G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@(&EF("AI<U]C86QL86)L92@D;7-G0V%L;&)A8VLI*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]M<V=#86QL8F%C:R`]("1M<V=#86QL8F%C
M:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!'970@86X@97)R;W(@8V]D92`]/B!E<G)O<B!M97-S
M86=E(&UA<'!I;F<@8V%L;&)A8VL-"B`@("`@*B`-"B`@("`@*B!4:&ES(&UE
M=&AO9"!R971U<FYS('1H92!C=7)R96YT(&-A;&QB86-K('1H870@8V%N(&)E
M('5S960@=&\@9V5N97)A=&4@97)R;W(-"B`@("`@*B!M97-S86=E<PT*("`@
M("`J($!R971U<FX@87)R87E\<W1R:6YG?&9A;'-E($-A;&QB86-K(&9U;F-T
M:6]N+VUE=&AO9"!O<B!F86QS92!I9B!N;VYE#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T365S<V%G94-A;&QB86-K*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7VUS9T-A;&QB86-K.PT*("`@('T-"B`@("`-"B`@("`O
M*BH-"B`@("`@*B!3971S(&$@9&5F875L="!C86QL8F%C:R!T;R!B92!U<V5D
M(&)Y(&%L;"!E<G)O<B!S=&%C:W,-"B`@("`@*B`-"B`@("`@*B!4:&ES(&UE
M=&AO9"!S971S('1H92!C86QL8F%C:R!T:&%T(&-A;B!B92!U<V5D('1O(&=E
M;F5R871E(&5R<F]R#0H@("`@("H@;65S<V%G97,@9F]R(&$@<VEN9VQE=&]N
M#0H@("`@("H@0'!A<F%M(&%R<F%Y?'-T<FEN9R!#86QL8F%C:R!F=6YC=&EO
M;B]M971H;V0-"B`@("`@*B!`<&%R86T@<W1R:6YG(%!A8VMA9V4@;F%M92P@
M;W(@9F%L<V4@9F]R(&%L;"!P86-K86=E<PT*("`@("`J($!S=&%T:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!S971$969A=6QT0V%L;&)A8VLH)&-A;&QB
M86-K(#T@9F%L<V4L("1P86-K86=E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H(6ES7V-A;&QA8FQE*"1C86QL8F%C:RDI('L-"B`@("`@("`@("`@
M("1C86QL8F%C:R`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1P86-K
M86=E(#T@)'!A8VMA9V4@/R`D<&%C:V%G92`Z("<J)SL-"B`@("`@("`@)$=,
M3T)!3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==6R1P
M86-K86=E72`]("1C86QL8F%C:SL-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@4V5T(&$@8V%L;&)A8VL@=&AA="!G96YE<F%T97,@8V]N=&5X="!I
M;F9O<FUA=&EO;B`H;&]C871I;VX@;V8@97)R;W(I(&9O<B!A;B!E<G)O<B!S
M=&%C:PT*("`@("`J(`T*("`@("`J(%1H:7,@;65T:&]D('-E=',@=&AE(&-A
M;&QB86-K('1H870@8V%N(&)E('5S960@=&\@9V5N97)A=&4@8V]N=&5X=`T*
M("`@("`J(&EN9F]R;6%T:6]N(&9O<B!A;B!E<G)O<BX@(%!A<W-I;F<@:6X@
M3E5,3"!W:6QL(&1I<V%B;&4@8V]N=&5X="!G96YE<F%T:6]N#0H@("`@("H@
M86YD(')E;6]V92!T:&4@97AP96YS:79E(&-A;&P@=&\@9&5B=6=?8F%C:W1R
M86-E*"D-"B`@("`@*B!`<&%R86T@87)R87E\<W1R:6YG?&YU;&P@0V%L;&)A
M8VL@9G5N8W1I;VXO;65T:&]D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T
M0V]N=&5X=$-A;&QB86-K*"1C;VYT97AT0V%L;&)A8VLI#0H@("`@>PT*("`@
M("`@("!I9B`H)&-O;G1E>'1#86QL8F%C:R`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8V]N=&5X=$-A;&QB86-K(#T@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D8V]N=&5X=$-A;&QB86-K*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V-O;G1E>'1#86QL8F%C:R`](&%R<F%Y
M*"8D=&AI<RP@)V=E=$9I;&5,:6YE)RD[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)&-O;G1E>'1#86QL8F%C:RDI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-O;G1E>'1#86QL8F%C:R`]
M("1C;VYT97AT0V%L;&)A8VL[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4V5T(&%N(&5R<F]R($-A
M;&QB86-K#0H@("`@("H@268@<V5T('1O(&$@=F%L:60@8V%L;&)A8VLL('1H
M:7,@=VEL;"!B92!C86QL960@979E<GD@=&EM92!A;B!E<G)O<@T*("`@("`J
M(&ES('!U<VAE9"!O;G1O('1H92!S=&%C:RX@(%1H92!R971U<FX@=F%L=64@
M=VEL;"!B92!U<V5D('1O(&1E=&5R;6EN90T*("`@("`J('=H971H97(@=&\@
M86QL;W<@86X@97)R;W(@=&\@8F4@<'5S:&5D(&]R(&QO9V=E9"X-"B`@("`@
M*B`-"B`@("`@*B!4:&4@<F5T=7)N('9A;'5E(&UU<W0@8F4@;VYE(&]F('1H
M92!%4E)/4E-404-+7RH@8V]N<W1A;G1S+@T*("`@("`J(`T*("`@("`J(%1H
M:7,@9G5N8W1I;VYA;&ET>2!C86X@8F4@=7-E9"!T;R!E;75L871E(%!%05(G
M<R!P=7-H17)R;W)(86YD;&EN9RP@86YD#0H@("`@("H@=&AE(%!%05)?15)2
M3U)?0T%,3$)!0TL@;6]D92P@=VET:&]U="!A9F9E8W1I;F<@=&AE(&EN=&5G
M<FET>2!O9@T*("`@("`J('1H92!E<G)O<B!S=&%C:R!O<B!L;V=G:6YG#0H@
M("`@("H@0'-E92!014%27T524D]24U1!0TM?4%532$%.1$Q/1RP@4$5!4E]%
M4E)/4E-404-+7U!54T@L(%!%05)?15)23U)35$%#2U],3T<-"B`@("`@*B!`
M<V5E('!O<$-A;&QB86-K*"D-"B`@("`@*B!`<&%R86T@<W1R:6YG?&%R<F%Y
M("1C8@T*("`@("`J+PT*("`@(&9U;F-T:6]N('!U<VA#86QL8F%C:R@D8V(I
M#0H@("`@>PT*("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?97)R;W)#86QL
M8F%C:RP@)&-B*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4F5M
M;W9E(&$@8V%L;&)A8VL@9G)O;2!T:&4@97)R;W(@8V%L;&)A8VL@<W1A8VL-
M"B`@("`@*B!`<V5E('!U<VA#86QL8F%C:R@I#0H@("`@("H@0')E='5R;B!A
M<G)A>7QS=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P;W!#
M86QL8F%C:R@I#0H@("`@>PT*("`@("`@("!I9B`H(6-O=6YT*"1T:&ES+3Y?
M97)R;W)#86QL8F%C:RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R87E?<&]P*"1T:&ES+3Y?
M97)R;W)#86QL8F%C:RD[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J
M(%-E="!A('1E;7!O<F%R>2!O=F5R<FED:6YG(&5R<F]R(&-A;&QB86-K(&9O
M<B!E=F5R>2!P86-K86=E(&5R<F]R('-T86-K#0H@("`@("H-"B`@("`@*B!5
M<V4@=&AI<R!T;R!T96UP;W)A<FEL>2!D:7-A8FQE(&%L;"!E>&ES=&EN9R!C
M86QL8F%C:W,@*&-A;B!B92!U<V5D#0H@("`@("H@=&\@96UU;&%T92!T:&4@
M0"!O<&5R871O<BP@9F]R(&EN<W1A;F-E*0T*("`@("`J($!S964@4$5!4E]%
M4E)/4E-404-+7U!54TA!3D1,3T<L(%!%05)?15)23U)35$%#2U]055-(+"!0
M14%27T524D]24U1!0TM?3$]'#0H@("`@("H@0'-E92!S=&%T:6-0;W!#86QL
M8F%C:R@I+"!P=7-H0V%L;&)A8VLH*0T*("`@("`J($!P87)A;2!S=')I;F=\
M87)R87D@)&-B#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-T871I8U!U<VA#86QL8F%C:R@D8V(I#0H@("`@>PT*("`@("`@("!A
M<G)A>5]P=7-H*"1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7T]615)2241%
M7T-!3$Q"04-+)UTL("1C8BD[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@
M("`J(%)E;6]V92!A('1E;7!O<F%R>2!O=F5R<FED:6YG(&5R<F]R(&-A;&QB
M86-K#0H@("`@("H@0'-E92!S=&%T:6-0=7-H0V%L;&)A8VLH*0T*("`@("`J
M($!R971U<FX@87)R87E\<W1R:6YG?&9A;'-E#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-T871I8U!O<$-A;&QB86-K*"D-"B`@
M("![#0H@("`@("`@("1R970@/2!A<G)A>5]P;W`H)$=,3T)!3%-;)U]014%2
M7T524D]24U1!0TM?3U9%4E))1$5?0T%,3$)!0TLG72D[#0H@("`@("`@(&EF
M("@A:7-?87)R87DH)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?3U9%4E))
M1$5?0T%,3$)!0TLG72DI('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!
M4E]%4E)/4E-404-+7T]615)2241%7T-!3$Q"04-+)UT@/2!A<G)A>2@I.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"B`@("`-
M"B`@("`O*BH-"B`@("`@*B!!9&0@86X@97)R;W(@=&\@=&AE('-T86-K#0H@
M("`@("H@#0H@("`@("H@268@=&AE(&UE<W-A9V4@9V5N97)A=&]R(&5X:7-T
M<RP@:70@:7,@8V%L;&5D('=I=&@@,B!P87)A;65T97)S+@T*("`@("`J("`M
M('1H92!C=7)R96YT($5R<F]R(%-T86-K(&]B:F5C=`T*("`@("`J("`M(&%N
M(&%R<F%Y('1H870@:7,@:6X@=&AE('-A;64@9F]R;6%T(&%S(&%N(&5R<F]R
M+B`@079A:6QA8FQE(&EN9&EC97,-"B`@("`@*B`@("!A<F4@)V-O9&4G+"`G
M<&%C:V%G92<L("=T:6UE)RP@)W!A<F%M<R<L("=L979E;"<L(&%N9"`G8V]N
M=&5X="<-"B`@("`@*B`-"B`@("`@*B!.97AT+"!I9B!T:&4@97)R;W(@<VAO
M=6QD(&-O;G1A:6X@8V]N=&5X="!I;F9O<FUA=&EO;BP@=&AI<R!I<PT*("`@
M("`J(&AA;F1L960@8GD@=&AE(&-O;G1E>'0@9W)A8F)I;F<@;65T:&]D+@T*
M("`@("`J($9I;F%L;'DL('1H92!E<G)O<B!I<R!P=7-H960@;VYT;R!T:&4@
M<')O<&5R(&5R<F]R('-T86-K#0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]D
M92`@("`@(%!A8VMA9V4M<W!E8VEF:6,@97)R;W(@8V]D90T*("`@("`J($!P
M87)A;2!S=')I;F<@)&QE=F5L("`@("!%<G)O<B!L979E;"X@(%1H:7,@:7,@
M3D]4('-P96QL+6-H96-K960-"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A
M;7,@("`@87-S;V-I871I=F4@87)R87D@;V8@97)R;W(@<&%R86UE=&5R<PT*
M("`@("`J($!P87)A;2!S=')I;F<@)&US9R`@("`@("!%<G)O<B!M97-S86=E
M+"!O<B!A('!O<G1I;VX@;V8@:70@:68@=&AE(&UE<W-A9V4-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@:7,@=&\@8F4@9V5N97)A=&5D#0H@
M("`@("H@0'!A<F%M(&%R<F%Y("`D<F5P86-K86=E($EF('1H:7,@97)R;W(@
M<F4M<&%C:V%G97,@86X@97)R;W(@<'5S:&5D(&)Y#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%N;W1H97(@<&%C:V%G92P@<&QA8V4@=&AE
M(&%R<F%Y(')E='5R;F5D(&9R;VT-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@>T!L:6YK('!O<"@I?2!I;B!T:&ES('!A<F%M971E<@T*("`@
M("`J($!P87)A;2!A<G)A>2`@)&)A8VMT<F%C92!0<F]T96-T960@<&%R86UE
M=&5R.B!U<V4@=&AI<R!T;R!P87-S(&EN('1H90T*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("![0&QI;FL@9&5B=6=?8F%C:W1R86-E*"E]('1H
M870@<VAO=6QD(&)E('5S960-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@=&\@9FEN9"!E<G)O<B!C;VYT97AT#0H@("`@("H@0')E='5R;B!0
M14%27T5R<F]R?&%R<F%Y?$5X8V5P=&EO;@T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B!C;VUP871I8FEL:71Y(&UO9&4@:7,@;VXL(&$@
M4$5!4E]%<G)O<B!I<R!A;'-O#0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@('1H<F]W;BX@($EF('1H92!C;&%S<R!%>&-E<'1I;VX@97AI<W1S
M+"!T:&5N(&]N90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!I
M<R!R971U<FYE9"!T;R!A;&QO=R!C;V1E(&QI:V4Z#0H@("`@("H@/&-O9&4^
M#0H@("`@("H@=&AR;W<@*"1S=&%C:RT^<'5S:"A-65]%4E)/4E]#3T1%+"`G
M97)R;W(G+"!A<G)A>2@G=7-E<FYA;64G(#T^("=G<F]B)RDI*3L-"B`@("`@
M*B`\+V-O9&4^#0H@("`@("H@#0H@("`@("H@5&AE(&5R<F]R1&%T82!P<F]P
M97)T>2!O9B!T:&4@97AC97!T:6]N(&-L87-S('=I;&P@8F4@<V5T('1O('1H
M92!A<G)A>0T*("`@("`J('1H870@=V]U;&0@;F]R;6%L;'D@8F4@<F5T=7)N
M960N("!)9B!A(%!%05)?17)R;W(@:7,@<F5T=7)N960L('1H92!U<V5R:6YF
M;PT*("`@("`J('!R;W!E<G1Y(&ES('-E="!T;R!T:&4@87)R87D-"B`@("`@
M*B`-"B`@("`@*B!/=&AE<G=I<V4L(&%N(&%R<F%Y(&ES(')E='5R;F5D(&EN
M('1H:7,@9F]R;6%T.@T*("`@("`J(#QC;V1E/@T*("`@("`J(&%R<F%Y*`T*
M("`@("`J("`@("=C;V1E)R`]/B`D8V]D92P-"B`@("`@*B`@("`G<&%R86US
M)R`]/B`D<&%R86US+`T*("`@("`J("`@("=P86-K86=E)R`]/B`D=&AI<RT^
M7W!A8VMA9V4L#0H@("`@("H@("`@)VQE=F5L)R`]/B`D;&5V96PL#0H@("`@
M("H@("`@)W1I;64G(#T^('1I;64H*2P-"B`@("`@*B`@("`G8V]N=&5X="<@
M/3X@)&-O;G1E>'0L#0H@("`@("H@("`@)VUE<W-A9V4G(#T^("1M<V<L#0H@
M("`@("H@+R];)W)E<&%C:V%G92<@/3X@)&5R<ET@<F5P86-K86=E9"!E<G)O
M<B!A<G)A>2]%>&-E<'1I;VX@8VQA<W,-"B`@("`@*B`I.PT*("`@("`J(#PO
M8V]D93X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P=7-H*"1C;V1E+"`D;&5V
M96P@/2`G97)R;W(G+"`D<&%R86US(#T@87)R87DH*2P@)&US9R`](&9A;'-E
M+`T*("`@("`@("`@("`@("`@("`@)')E<&%C:V%G92`](&9A;'-E+"`D8F%C
M:W1R86-E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V]N=&5X="`](&9A
M;'-E.PT*("`@("`@("`O+R!G<F%B(&5R<F]R(&-O;G1E>'0-"B`@("`@("`@
M:68@*"1T:&ES+3Y?8V]N=&5X=$-A;&QB86-K*2![#0H@("`@("`@("`@("!I
M9B`H(21B86-K=')A8V4I('L-"B`@("`@("`@("`@("`@("`D8F%C:W1R86-E
M(#T@9&5B=6=?8F%C:W1R86-E*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D8V]N=&5X="`](&-A;&Q?=7-E<E]F=6YC*"1T:&ES+3Y?8V]N=&5X
M=$-A;&QB86-K+"`D8V]D92P@)'!A<F%M<RP@)&)A8VMT<F%C92D[#0H@("`@
M("`@('T-"B`@("`@("`@#0H@("`@("`@("\O('-A=F4@97)R;W(-"B`@("`@
M("`@)'1I;64@/2!E>'!L;V1E*"<@)RP@;6EC<F]T:6UE*"DI.PT*("`@("`@
M("`D=&EM92`]("1T:6UE6S%=("L@)'1I;65;,%T[#0H@("`@("`@("1E<G(@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G8V]D92<@/3X@)&-O9&4L#0H@
M("`@("`@("`@("`@("`@)W!A<F%M<R<@/3X@)'!A<F%M<RP-"B`@("`@("`@
M("`@("`@("`G<&%C:V%G92<@/3X@)'1H:7,M/E]P86-K86=E+`T*("`@("`@
M("`@("`@("`@("=L979E;"<@/3X@)&QE=F5L+`T*("`@("`@("`@("`@("`@
M("=T:6UE)R`]/B`D=&EM92P-"B`@("`@("`@("`@("`@("`G8V]N=&5X="<@
M/3X@)&-O;G1E>'0L#0H@("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1M
M<V<L#0H@("`@("`@("`@("`@("`I.PT*#0H@("`@("`@(&EF("@D<F5P86-K
M86=E*2![#0H@("`@("`@("`@("`D97)R6R=R97!A8VMA9V4G72`]("1R97!A
M8VMA9V4[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!S970@=7`@=&AE(&5R
M<F]R(&UE<W-A9V4L(&EF(&YE8V5S<V%R>0T*("`@("`@("!I9B`H)'1H:7,M
M/E]M<V=#86QL8F%C:RD@>PT*("`@("`@("`@("`@)&US9R`](&-A;&Q?=7-E
M<E]F=6YC7V%R<F%Y*"1T:&ES+3Y?;7-G0V%L;&)A8VLL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)B1T:&ES+"`D
M97)R*2D[#0H@("`@("`@("`@("`D97)R6R=M97-S86=E)UT@/2`D;7-G.PT*
M("`@("`@("!]("`@("`@("`-"B`@("`@("`@)'!U<V@@/2`D;&]G(#T@=')U
M93L-"B`@("`@("`@)&1I92`](&9A;'-E.PT*("`@("`@("`O+R!T<GD@=&AE
M(&]V97)R:61I;F<@8V%L;&)A8VL@9FER<W0-"B`@("`@("`@)&-A;&QB86-K
M(#T@)'1H:7,M/G-T871I8U!O<$-A;&QB86-K*"D[#0H@("`@("`@(&EF("@D
M8V%L;&)A8VLI('L-"B`@("`@("`@("`@("1T:&ES+3YS=&%T:6-0=7-H0V%L
M;&)A8VLH)&-A;&QB86-K*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES
M7V-A;&QA8FQE*"1C86QL8F%C:RDI('L-"B`@("`@("`@("`@("\O('1R>2!T
M:&4@;&]C86P@8V%L;&)A8VL@;F5X=`T*("`@("`@("`@("`@)&-A;&QB86-K
M(#T@)'1H:7,M/G!O<$-A;&QB86-K*"D[#0H@("`@("`@("`@("!I9B`H:7-?
M8V%L;&%B;&4H)&-A;&QB86-K*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3YP=7-H0V%L;&)A8VLH)&-A;&QB86-K*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@+R\@=')Y('1H92!D969A=6QT(&-A;&QB
M86-K#0H@("`@("`@("`@("`@("`@)&-A;&QB86-K(#T@:7-S970H)$=,3T)!
M3%-;)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==6R1T:&ES
M+3Y?<&%C:V%G95TI(#\-"B`@("`@("`@("`@("`@("`@("`@)$=,3T)!3%-;
M)U]014%27T524D]24U1!0TM?1$5&055,5%]#04Q,0D%#2R==6R1T:&ES+3Y?
M<&%C:V%G95T@.@T*("`@("`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%
M05)?15)23U)35$%#2U]$149!54Q47T-!3$Q"04-+)UU;)RHG73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?8V%L;&%B;&4H
M)&-A;&QB86-K*2D@>PT*("`@("`@("`@("`@<W=I=&-H*&-A;&Q?=7-E<E]F
M=6YC*"1C86QL8F%C:RP@)&5R<BDI>PT*("`@("`@("`@("`@"6-A<V4@4$5!
M4E]%4E)/4E-404-+7TE'3D]213H@#0H@("`@("`@("`@("`)"7)E='5R;B`D
M97)R.PT*("`@("`@("`)"6)R96%K.PT*("`@("`@("`@("`@"6-A<V4@4$5!
M4E]%4E)/4E-404-+7U!54T@Z(`T*("`@("`@("`@("`@"0DD;&]G(#T@9F%L
M<V4[#0H@("`@("`@(`D)8G)E86L[#0H@("`@("`@("`@("`)8V%S92!014%2
M7T524D]24U1!0TM?3$]'.B`-"B`@("`@("`@("`@(`D))'!U<V@@/2!F86QS
M93L-"B`@("`@("`@"0EB<F5A:SL-"B`@("`@("`@("`@(`EC87-E(%!%05)?
M15)23U)35$%#2U]$244Z(`T*("`@("`@("`@("`@"0DD9&EE(#T@=')U93L-
M"B`@("`@("`@"0EB<F5A:SL-"B`@("`@("`@("`@("`@("`O+R!A;GET:&EN
M9R!E;'-E(')E='5R;F5D(&AA<R!T:&4@<V%M92!E9F9E8W0@87,@<'5S:&%N
M9&QO9PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<'5S:"D@>PT*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D=&AI<RT^7V5R
M<F]R<RP@)&5R<BD[#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<T)Y3&5V
M96Q;)&5R<ELG;&5V96PG75U;72`]("8D=&AI<RT^7V5R<F]R<ULP73L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&QO9RD@>PT*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?;&]G9V5R('Q\("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+
M7T1%1D%53%1?3$]'1T52)UTI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VQO9R@D97)R*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&1I92D@>PT*("`@("`@("`@("`@9&EE*"D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<&%T("8F("1P=7-H*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&US9RP@)&-O9&4L
M(&YU;&PL(&YU;&PL("1E<G(I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D97)R.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@*B!3=&%T:6,@
M=F5R<VEO;B!O9B![0&QI;FL@<'5S:"@I?0T*("`@("`J(`T*("`@("`J($!P
M87)A;2!S=')I;F<@)'!A8VMA9V4@("!086-K86=E(&YA;64@=&AI<R!E<G)O
M<B!B96QO;F=S('1O#0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]D92`@("`@
M(%!A8VMA9V4M<W!E8VEF:6,@97)R;W(@8V]D90T*("`@("`J($!P87)A;2!S
M=')I;F<@)&QE=F5L("`@("!%<G)O<B!L979E;"X@(%1H:7,@:7,@3D]4('-P
M96QL+6-H96-K960-"B`@("`@*B!`<&%R86T@87)R87D@("1P87)A;7,@("`@
M87-S;V-I871I=F4@87)R87D@;V8@97)R;W(@<&%R86UE=&5R<PT*("`@("`J
M($!P87)A;2!S=')I;F<@)&US9R`@("`@("!%<G)O<B!M97-S86=E+"!O<B!A
M('!O<G1I;VX@;V8@:70@:68@=&AE(&UE<W-A9V4-"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@:7,@=&\@8F4@9V5N97)A=&5D#0H@("`@("H@
M0'!A<F%M(&%R<F%Y("`D<F5P86-K86=E($EF('1H:7,@97)R;W(@<F4M<&%C
M:V%G97,@86X@97)R;W(@<'5S:&5D(&)Y#0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%N;W1H97(@<&%C:V%G92P@<&QA8V4@=&AE(&%R<F%Y
M(')E='5R;F5D(&9R;VT-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@>T!L:6YK('!O<"@I?2!I;B!T:&ES('!A<F%M971E<@T*("`@("`J($!P
M87)A;2!A<G)A>2`@)&)A8VMT<F%C92!0<F]T96-T960@<&%R86UE=&5R.B!U
M<V4@=&AI<R!T;R!P87-S(&EN('1H90T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("![0&QI;FL@9&5B=6=?8F%C:W1R86-E*"E]('1H870@<VAO
M=6QD(&)E('5S960-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&\@9FEN9"!E<G)O<B!C;VYT97AT#0H@("`@("H@0')E='5R;B!014%27T5R
M<F]R?&YU;&Q\17AC97!T:6]N#0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF(&-O;7!A=&EB:6QI='D@;6]D92!I<R!O;BP@82!014%27T5R
M<F]R(&ES(&%L<V\-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M=&AR;W=N+B`@268@=&AE(&-L87-S($5X8V5P=&EO;B!E>&ES=',L('1H96X@
M;VYE#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@(&ES(')E='5R
M;F5D('1O(&%L;&]W(&-O9&4@;&EK93H-"B`@("`@*B`\8V]D93X-"B`@("`@
M*B!T:')O=R`H)'-T86-K+3YP=7-H*$U97T524D]27T-/1$4L("=E<G)O<B<L
M(&%R<F%Y*"=U<V5R;F%M92<@/3X@)V=R;V(G*2DI.PT*("`@("`J(#PO8V]D
M93X-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A
M=&EC4'5S:"@D<&%C:V%G92P@)&-O9&4L("1L979E;"`]("=E<G)O<B<L("1P
M87)A;7,@/2!A<G)A>2@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&US
M9R`](&9A;'-E+"`D<F5P86-K86=E(#T@9F%L<V4L("1B86-K=')A8V4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1S(#T@)E!%05)?17)R;W)3=&%C:SHZ
M<VEN9VQE=&]N*"1P86-K86=E*3L-"B`@("`@("`@:68@*"1S+3Y?8V]N=&5X
M=$-A;&QB86-K*2![#0H@("`@("`@("`@("!I9B`H(21B86-K=')A8V4I('L-
M"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B
M86-K=')A8V4G*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8F%C:W1R86-E
M(#T@9&5B=6=?8F%C:W1R86-E*"D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<RT^<'5S
M:"@D8V]D92P@)&QE=F5L+"`D<&%R86US+"`D;7-G+"`D<F5P86-K86=E+"`D
M8F%C:W1R86-E*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ#0H@("`@("H@3&]G
M(&%N(&5R<F]R('5S:6YG(%!%05(Z.DQO9PT*("`@("`J($!P87)A;2!A<G)A
M>2`D97)R($5R<F]R(&%R<F%Y#0H@("`@("H@0'!A<F%M(&%R<F%Y("1L979E
M;',@17)R;W(@;&5V96P@/3X@3&]G(&-O;G-T86YT(&UA<`T*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VQO9R@D
M97)R*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@
M("`@("`@("`@("`D;&]G9V5R(#T@)B1T:&ES+3Y?;&]G9V5R.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)&QO9V=E<B`]("8D1TQ/0D%,4ULG
M7U!%05)?15)23U)35$%#2U]$149!54Q47TQ/1T=%4B==.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<U]A*"1L;V=G97(L("=,;V<G*2D@>PT*("`@("`@
M("`@("`@)&QE=F5L<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=E>&-E
M<'1I;VXG(#T^(%!%05)?3$]'7T-2250L#0H@("`@("`@("`@("`@("`@)V%L
M97)T)R`]/B!014%27TQ/1U]!3$525"P-"B`@("`@("`@("`@("`@("`G8W)I
M=&EC86PG(#T^(%!%05)?3$]'7T-2250L#0H@("`@("`@("`@("`@("`@)V5R
M<F]R)R`]/B!014%27TQ/1U]%4E(L#0H@("`@("`@("`@("`@("`@)W=A<FYI
M;F<G(#T^(%!%05)?3$]'7U=!4DY)3D<L#0H@("`@("`@("`@("`@("`@)VYO
M=&EC92<@/3X@4$5!4E],3T=?3D]424-%+`T*("`@("`@("`@("`@("`@("=I
M;F9O)R`]/B!014%27TQ/1U])3D9/+`T*("`@("`@("`@("`@("`@("=D96)U
M9R<@/3X@4$5!4E],3T=?1$5"54<I.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1L979E;'-;)&5R<ELG;&5V96PG75TI*2![#0H@("`@("`@("`@("`@("`@
M)&QE=F5L(#T@)&QE=F5L<ULD97)R6R=L979E;"==73L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?
M24Y&3SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1L;V=G97(M/FQO
M9R@D97)R6R=M97-S86=E)UTL("1L979E;"P@)&5R<BD[#0H@("`@("`@('T@
M96QS92![("\O('-U<'!O<G0@;F]N+7-T86YD87)D(&QO9W,-"B`@("`@("`@
M("`@(&-A;&Q?=7-E<E]F=6YC*"1L;V=G97(L("1E<G(I.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4&]P(&%N(&5R<F]R
M(&]F9B!O9B!T:&4@97)R;W(@<W1A8VL-"B`@("`@*B`-"B`@("`@*B!`<F5T
M=7)N(&9A;'-E?&%R<F%Y#0H@("`@("H@0'-I;F-E(#`N-&%L<&AA(&ET(&ES
M(&YO(&QO;F=E<B!P;W-S:6)L92!T;R!S<&5C:69Y(&$@<W!E8VEF:6,@97)R
M;W(-"B`@("`@*B!L979E;"!T;R!R971U<FX@+2!T:&4@;&%S="!E<G)O<B!P
M=7-H960@=VEL;"!B92!R971U<FYE9"P@:6YS=&5A9`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('!O<"@I#0H@("`@>PT*("`@("`@("!R971U<FX@0&%R<F%Y
M7W-H:69T*"1T:&ES+3Y?97)R;W)S*3L-"B`@("!]#0H@("`@#0H@("`@+RHJ
M#0H@("`@("H@1&5T97)M:6YE('=H971H97(@=&AE<F4@87)E(&%N>2!E<G)O
M<G,@;VX@=&AE('-T86-K#0H@("`@("H@0'!A<F%M('-T<FEN9WQA<G)A>2!,
M979E;"!N86UE+B`@57-E('1O(&1E=&5R;6EN92!I9B!A;GD@97)R;W)S#0H@
M("`@("H@;V8@;&5V96P@*'-T<FEN9RDL(&]R(&QE=F5L<R`H87)R87DI(&AA
M=F4@8F5E;B!P=7-H960-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!H87-%<G)O<G,H)&QE=F5L(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("!I9B`H)&QE=F5L*2![#0H@("`@("`@("`@("!R971U
M<FX@:7-S970H)'1H:7,M/E]E<G)O<G-">4QE=F5L6R1L979E;%TI.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!C;W5N="@D=&AI<RT^7V5R<F]R<RD[
M#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%)E=')I979E(&%L;"!E
M<G)O<G,@<VEN8V4@;&%S="!P=7)G90T*("`@("`J(`T*("`@("`J($!P87)A
M;2!B;V]L96%N('-E="!I;B!O<F1E<B!T;R!E;7!T>2!T:&4@97)R;W(@<W1A
M8VL-"B`@("`@*B!`<&%R86T@<W1R:6YG(&QE=F5L(&YA;64L('1O(')E='5R
M;B!O;FQY(&5R<F]R<R!O9B!A('!A<G1I8W5L87(@<V5V97)I='D-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T17)R
M;W)S*"1P=7)G92`](&9A;'-E+"`D;&5V96P@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("@A)'!U<F=E*2![#0H@("`@("`@("`@("!I9B`H)&QE=F5L
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V5R<F]R
M<T)Y3&5V96Q;)&QE=F5L72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?97)R;W)S0GE,979E;%LD
M;&5V96Q=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?97)R;W)S.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D;&5V96PI
M('L-"B`@("`@("`@("`@("1R970@/2`D=&AI<RT^7V5R<F]R<T)Y3&5V96Q;
M)&QE=F5L73L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?97)R;W)S
M0GE,979E;%LD;&5V96Q=(&%S("1I(#T^("1U;G5S960I('L-"B`@("`@("`@
M("`@("`@("`O+R!E;G1R:65S(&%R92!R969E<F5N8V5S('1O('1H92`D7V5R
M<F]R<R!A<G)A>0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W)S0GE,
M979E;%LD;&5V96Q=6R1I72`](&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@+R\@87)R87E?9FEL=&5R(')E;6]V97,@86QL(&5N=')I97,@
M/3T](&9A;'-E#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R<R`](&%R<F%Y
M7V9I;'1E<B@D=&AI<RT^7V5R<F]R<RD[#0H@("`@("`@("`@("!U;G-E="@D
M=&AI<RT^7V5R<F]R<T)Y3&5V96Q;)&QE=F5L72D[#0H@("`@("`@("`@("!R
M971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M
M/E]E<G)O<G,[#0H@("`@("`@("1T:&ES+3Y?97)R;W)S(#T@87)R87DH*3L-
M"B`@("`@("`@)'1H:7,M/E]E<G)O<G-">4QE=F5L(#T@87)R87DH*3L-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@
M("`J($1E=&5R;6EN92!W:&5T:&5R('1H97)E(&%R92!A;GD@97)R;W)S(&]N
M(&$@<VEN9VQE(&5R<F]R('-T86-K+"!O<B!O;B!A;GD@97)R;W(@<W1A8VL-
M"B`@("`@*@T*("`@("`J(%1H92!O<'1I;VYA;"!P87)A;65T97(@8V%N(&)E
M('5S960@=&\@=&5S="!T:&4@97AI<W1E;F-E(&]F(&%N>2!E<G)O<G,@=VET
M:&]U="!T:&4@;F5E9"!O9@T*("`@("`J('-I;F=L971O;B!I;G-T86YT:6%T
M:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!086-K86=E(&YA;64@
M=&\@8VAE8VL@9F]R(&5R<F]R<PT*("`@("`J($!P87)A;2!S=')I;F<@3&5V
M96P@;F%M92!T;R!C:&5C:R!F;W(@82!P87)T:6-U;&%R('-E=F5R:71Y#0H@
M("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("H@0'-T871I8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N('-T871I8TAA<T5R<F]R<R@D<&%C:V%G92`](&9A
M;'-E+"`D;&5V96P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D<&%C
M:V%G92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D1TQ/0D%,4ULG7U!%
M05)?15)23U)35$%#2U]324Y'3$543TXG75LD<&%C:V%G95TI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]%4E)/4E-404-+7U-)
M3D=,151/3B==6R1P86-K86=E72T^:&%S17)R;W)S*"1L979E;"D[#0H@("`@
M("`@('T-"B`@("`@("`@9F]R96%C:"`H)$=,3T)!3%-;)U]014%27T524D]2
M4U1!0TM?4TE.1TQ%5$].)UT@87,@)'!A8VMA9V4@/3X@)&]B:BD@>PT*("`@
M("`@("`@("`@:68@*"1O8FHM/FAA<T5R<F]R<R@D;&5V96PI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F(&%L;"!E<G)O<G,@<VEN8V4@
M;&%S="!P=7)G92P@;W)G86YI>F5D(&)Y('!A8VMA9V4-"B`@("`@*B!`<VEN
M8V4@4$5!4B`Q+C0N,&1E=B!"0R!B<F5A:R$@)&QE=F5L(&ES(&YO=R!I;B!T
M:&4@<&QA8V4@)&UE<F=E('5S960@=&\@8F4-"B`@("`@*B!`<&%R86T@8F]O
M;&5A;B`D<'5R9V4@4V5T('1O('!U<F=E('1H92!E<G)O<B!S=&%C:R!O9B!E
M>&ES=&EN9R!E<G)O<G,-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D;&5V96P@
M4V5T('1O(&$@;&5V96P@;F%M92!I;B!O<F1E<B!T;R!R971R:65V92!O;FQY
M(&5R<F]R<R!O9B!A('!A<G1I8W5L87(@;&5V96P-"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D;65R9V4@4V5T('1O(')E='5R;B!A(&9L870@87)R87DL(&YO
M="!O<F=A;FEZ960@8GD@<&%C:V%G90T*("`@("`J($!P87)A;2!A<G)A>2`@
M("1S;W)T9G5N8R!&=6YC=&EO;B!U<V5D('1O('-O<G0@82!M97)G960@87)R
M87D@+2!D969A=6QT#0H@("`@("H@("`@("`@('-O<G1S(&)Y('1I;64L(&%N
M9"!S:&]U;&0@8F4@9V]O9"!F;W(@;6]S="!C87-E<PT*("`@("`J($!S=&%T
M:6,-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-T871I8T=E=$5R<F]R<R@D<'5R9V4@/2!F86QS92P@)&QE=F5L(#T@
M9F%L<V4L("1M97)G92`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<V]R=&9U;F,@/2!A<G)A>2@G4$5!4E]%<G)O<E-T86-K)RP@
M)U]S;W)T17)R;W)S)RDI#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH
M*3L-"B`@("`@("`@:68@*"%I<U]C86QL86)L92@D<V]R=&9U;F,I*2![#0H@
M("`@("`@("`@("`D<V]R=&9U;F,@/2!A<G)A>2@G4$5!4E]%<G)O<E-T86-K
M)RP@)U]S;W)T17)R;W)S)RD[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H)$=,3T)!3%-;)U]014%27T524D]24U1!0TM?4TE.1TQ%5$].)UT@87,@
M)'!A8VMA9V4@/3X@)&]B:BD@>PT*("`@("`@("`@("`@)'1E<W0@/2`D1TQ/
M0D%,4ULG7U!%05)?15)23U)35$%#2U]324Y'3$543TXG75LD<&%C:V%G95TM
M/F=E=$5R<F]R<R@D<'5R9V4L("1L979E;"D[#0H@("`@("`@("`@("!I9B`H
M)'1E<W0I('L-"B`@("`@("`@("`@("`@("!I9B`H)&UE<F=E*2![#0H@("`@
M("`@("`@("`@("`@("`@("1R970@/2!A<G)A>5]M97)G92@D<F5T+"`D=&5S
M="D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)')E=%LD<&%C:V%G95T@/2`D=&5S=#L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M
M97)G92D@>PT*("`@("`@("`@("`@=7-O<G0H)')E="P@)'-O<G1F=6YC*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H@("`@
M#0H@("`@+RHJ#0H@("`@("H@17)R;W(@<V]R=&EN9R!F=6YC=&EO;BP@<V]R
M=',@8GD@=&EM90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]S;W)T17)R;W)S*"1A+"`D8BD-"B`@("![#0H@("`@
M("`@(&EF("@D85LG=&EM92==(#T]("1B6R=T:6UE)UTI('L-"B`@("`@("`@
M("`@(')E='5R;B`P.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D85LG=&EM
M92==(#P@)&);)W1I;64G72D@>PT*("`@("`@("`@("`@<F5T=7)N(#$[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("TQ.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%-T86YD87)D(&9I;&4O;&EN92!N=6UB97(O9G5N8W1I;VXO
M8VQA<W,@8V]N=&5X="!C86QL8F%C:PT*("`@("`J#0H@("`@("H@5&AI<R!F
M=6YC=&EO;B!U<V5S(&$@8F%C:W1R86-E(&=E;F5R871E9"!F<F]M('M`;&EN
M:R!D96)U9U]B86-K=')A8V4H*7T-"B`@("`@*B!A;F0@<V\@=VEL;"!N;W0@
M=V]R:R!A="!A;&P@:6X@4$A0(#P@-"XS+C`N("!4:&4@9G)A;64@<VAO=6QD
M#0H@("`@("H@<F5F97)E;F-E('1H92!F<F%M92!T:&%T(&-O;G1A:6YS('1H
M92!S;W5R8V4@;V8@=&AE(&5R<F]R+@T*("`@("`J($!R971U<FX@87)R87E\
M9F%L<V4@96ET:&5R(&%R<F%Y*"=F:6QE)R`]/B!F:6QE+"`G;&EN92<@/3X@
M;&EN92P-"B`@("`@*B`@("`@("`@("=F=6YC=&EO;B<@/3X@9G5N8W1I;VX@
M;F%M92P@)V-L87-S)R`]/B!C;&%S<R!N86UE*2!O<@T*("`@("`J("`@("`@
M("`@:68@=&AI<R!D;V5S;B=T('=O<FLL('1H96X@9F%L<V4-"B`@("`@*B!`
M<&%R86T@=6YU<V5D#0H@("`@("H@0'!A<F%M(&EN=&5G97(@8F%C:W1R86-E
M(&9R86UE+@T*("`@("`J($!P87)A;2!A<G)A>2!297-U;'1S(&]F(&1E8G5G
M7V)A8VMT<F%C92@I#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=$9I;&5,:6YE*"1C;V1E+"`D<&%R86US+"`D8F%C:W1R86-E
M(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D8F%C:W1R86-E(#T]/2!N
M=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@)&9R86UE(#T@,#L-"B`@("`@("`@)&9U;F-T:6]N9G)A;64@
M/2`Q.PT*("`@("`@("!I9B`H(6ES<V5T*"1B86-K=')A8V5;,5TI*2![#0H@
M("`@("`@("`@("`D9G5N8W1I;VYF<F%M92`](#`[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!W:&EL92`H:7-S970H)&)A8VMT<F%C95LD9G5N
M8W1I;VYF<F%M95U;)V9U;F-T:6]N)UTI("8F#0H@("`@("`@("`@("`@("`@
M("`D8F%C:W1R86-E6R1F=6YC=&EO;F9R86UE75LG9G5N8W1I;VXG72`]/2`G
M979A;"<@)B8-"B`@("`@("`@("`@("`@("`@(&ES<V5T*"1B86-K=')A8V5;
M)&9U;F-T:6]N9G)A;64@*R`Q72DI('L-"B`@("`@("`@("`@("`@("`D9G5N
M8W1I;VYF<F%M92LK.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D8F%C:W1R86-E6R1F<F%M95TI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1B86-K=')A8V5;)&9R86UE75LG9FEL92==*2D@
M>PT*("`@("`@("`@("`@("`@("1F<F%M92LK.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)&9U;F-B86-K=')A8V4@/2`D8F%C:W1R86-E6R1F=6YC
M=&EO;F9R86UE73L-"B`@("`@("`@("`@("1F:6QE8F%C:W1R86-E(#T@)&)A
M8VMT<F%C95LD9G)A;65=.PT*("`@("`@("`@("`@)')E="`](&%R<F%Y*"=F
M:6QE)R`]/B`D9FEL96)A8VMT<F%C95LG9FEL92==+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("=L:6YE)R`]/B`D9FEL96)A8VMT<F%C95LG;&EN92==
M*3L-"B`@("`@("`@("`@("\O(')E87)R86YG92!F;W(@979A;"=D(&-O9&4@
M;W(@8W)E871E(&9U;F-T:6]N(&5R<F]R<PT*("`@("`@("`@("`@:68@*'-T
M<G!O<R@D9FEL96)A8VMT<F%C95LG9FEL92==+"`G*"<I("8F(`T*("`@("`@
M("`@("`@"2`@<')E9U]M871C:"@G.UXH+BH_*5PH*%QD*RE<*2`Z("@N*C\I
M)#LG+"`D9FEL96)A8VMT<F%C95LG9FEL92==+`T*("`@("`@("`@("`@("`@
M("`@)&UA=&-H97,I*2![#0H@("`@("`@("`@("`@("`@)')E=%LG9FEL92==
M(#T@)&UA=&-H97-;,5T[#0H@("`@("`@("`@("`@("`@)')E=%LG;&EN92==
M(#T@)&UA=&-H97-;,ET@*R`P.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&ES<V5T*"1F=6YC8F%C:W1R86-E6R=F=6YC=&EO;B==*2`F)B!I
M<W-E="@D8F%C:W1R86-E6S%=*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M9G5N8V)A8VMT<F%C95LG9G5N8W1I;VXG72`A/2`G979A;"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1F=6YC8F%C:W1R86-E6R=F=6YC=&EO;B==
M(#T]("=?7VQA;6)D85]F=6YC)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E=%LG9G5N8W1I;VXG72`]("=C<F5A=&5?9G5N8W1I;VXH*2!C;V1E
M)SL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1R971;)V9U;F-T:6]N)UT@/2`D9G5N8V)A8VMT<F%C
M95LG9G5N8W1I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D9G5N8V)A8VMT<F%C95LG8VQA<W,G72D@)B8@:7-S970H)&)A8VMT
M<F%C95LQ72DI('L-"B`@("`@("`@("`@("`@("`D<F5T6R=C;&%S<R==(#T@
M)&9U;F-B86-K=')A8V5;)V-L87-S)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-T86YD
M87)D(&5R<F]R(&UE<W-A9V4@9V5N97)A=&EO;B!C86QL8F%C:PT*("`@("`J
M(`T*("`@("`J(%1H:7,@;65T:&]D(&UA>2!A;'-O(&)E(&-A;&QE9"!B>2!A
M(&-U<W1O;2!E<G)O<B!M97-S86=E(&=E;F5R871O<@T*("`@("`J('1O(&9I
M;&P@:6X@=&5M<&QA=&4@=F%L=65S(&9R;VT@=&AE('!A<F%M<R!A<G)A>2P@
M<VEM<&QY#0H@("`@("H@<V5T('1H92!T:&ER9"!P87)A;65T97(@=&\@=&AE
M(&5R<F]R(&UE<W-A9V4@=&5M<&QA=&4@<W1R:6YG('1O('5S90T*("`@("`J
M(`T*("`@("`J(%1H92!S<&5C:6%L('9A<FEA8FQE("5?7VUS9R4@:7,@<F5S
M97)V960Z('5S92!I="!O;FQY('1O('-P96-I9GD-"B`@("`@*B!W:&5R92!A
M(&UE<W-A9V4@<&%S<V5D(&EN(&)Y('1H92!U<V5R('-H;W5L9"!B92!P;&%C
M960@:6X@=&AE('1E;7!L871E+`T*("`@("`J(&QI:V4@<V\Z#0H@("`@("H@
M#0H@("`@("H@17)R;W(@;65S<V%G93H@)6US9R4@+2!I;G1E<FYA;"!E<G)O
M<@T*("`@("`J(`T*("`@("`J($EF('1H92!M97-S86=E('!A<W-E9"!L:6ME
M('-O.@T*("`@("`J(`T*("`@("`J(#QC;V1E/@T*("`@("`J("1S=&%C:RT^
M<'5S:"A%4E)/4E]#3T1%+"`G97)R;W(G+"!A<G)A>2@I+"`G<V5R=F5R(&5R
M<F]R(#4P,"<I.PT*("`@("`J(#PO8V]D93X-"B`@("`@*B`-"B`@("`@*B!4
M:&4@<F5T=7)N960@97)R;W(@;65S<V%G92!W:6QL(&)E(")%<G)O<B!M97-S
M86=E.B!S97)V97(@97)R;W(@-3`P("T-"B`@("`@*B!I;G1E<FYA;"!E<G)O
M<B(-"B`@("`@*B!`<&%R86T@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@0'!A
M<F%M(&%R<F%Y#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!0<F4M9V5N
M97)A=&5D(&5R<F]R(&UE<W-A9V4@=&5M<&QA=&4-"B`@("`@*B!`<W1A=&EC
M#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!G971%<G)O<DUE<W-A9V4H)B1S=&%C:RP@)&5R<BP@)'1E;7!L871E(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)'1E;7!L871E*2![#0H@("`@
M("`@("`@("`D;6%I;FUS9R`]("1T96UP;&%T93L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1M86EN;7-G(#T@)'-T86-K+3YG971%<G)O<DUE
M<W-A9V5496UP;&%T92@D97)R6R=C;V1E)UTI.PT*("`@("`@("!]#0H@("`@
M("`@("1M86EN;7-G(#T@<W1R7W)E<&QA8V4H)R5?7VUS9R4G+"`D97)R6R=M
M97-S86=E)UTL("1M86EN;7-G*3L-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1E
M<G);)W!A<F%M<R==*2`F)B!C;W5N="@D97)R6R=P87)A;7,G72DI('L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1E<G);)W!A<F%M<R==(&%S("1N86UE(#T^
M("1V86PI('L-"B`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)'9A;"DI
M('L-"B`@("`@("`@("`@("`@("`@("`@+R\@0"!I<R!N965D960@:6X@8V%S
M92`D=F%L(&ES(&$@;75L=&DM9&EM96YS:6]N86P@87)R87D-"B`@("`@("`@
M("`@("`@("`@("`@)'9A;"`]($!I;7!L;V1E*"<L("<L("1V86PI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T
M*"1V86PI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI
M<W1S*"1V86PL("=?7W1O4W1R:6YG)RDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1V86P@/2`D=F%L+3Y?7W1O4W1R:6YG*"D[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!0
M14%27T5R<F]R4W1A8VLZ.G-T871I8U!U<V@H)U!%05)?17)R;W)3=&%C:R<L
M(%!%05)?15)23U)35$%#2U]%4E)?3T)*5$]35%))3D<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)W=A<FYI;F<G+"!A<G)A>2@G;V)J)R`]/B!G
M971?8VQA<W,H)'9A;"DI+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=O8FIE8W0@)6]B:B4@<&%S<V5D(&EN=&\@9V5T17)R;W)-97-S86=E+"!B
M=70@:&%S(&YO(%]?=&]3=')I;F<H*2!M971H;V0G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1V86P@/2`G3V)J96-T)SL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M;6%I;FUS9R`]('-T<E]R97!L86-E*"<E)R`N("1N86UE("X@)R4G+"`D=F%L
M+"`D;6%I;FUS9RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1M86EN;7-G.PT*("`@('T-"B`@("`-"B`@("`O*BH-"B`@
M("`@*B!3=&%N9&%R9"!%<G)O<B!-97-S86=E(%1E;7!L871E(&=E;F5R871O
M<B!F<F]M(&-O9&4-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&=E=$5R<F]R365S<V%G951E;7!L871E*"1C;V1E*0T*
M("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V5R<F]R37-G<ULD
M8V]D95TI*2![#0H@("`@("`@("`@("!R971U<FX@)R5?7VUS9R4G.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V5R<F]R37-G<ULD8V]D
M95T[#0H@("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%-E="!T:&4@17)R
M;W(@365S<V%G92!496UP;&%T92!A<G)A>0T*("`@("`J(`T*("`@("`J(%1H
M92!A<G)A>2!F;W)M870@;75S="!B93H-"B`@("`@*B`\<')E/@T*("`@("`J
M(&%R<F%Y*&5R<F]R(&-O9&4@/3X@)VUE<W-A9V4@=&5M<&QA=&4G+"XN+BD-
M"B`@("`@*B`\+W!R93X-"B`@("`@*B`-"B`@("`@*B!%<G)O<B!M97-S86=E
M('!A<F%M971E<G,@<&%S<V5D(&EN=&\@>T!L:6YK('!U<V@H*7T@=VEL;"!B
M92!U<V5D(&%S(&EN<'5T#0H@("`@("H@9F]R('1H92!E<G)O<B!M97-S86=E
M+B`@268@=&AE('1E;7!L871E(&ES("=M97-S86=E("5F;V\E('=A<R`E8F%R
M)2<L(&%N9"!T:&4-"B`@("`@*B!P87)A;65T97)S(&%R92!A<G)A>2@G9F]O
M)R`]/B`G;VYE)RP@)V)A<B<@/3X@)W-I>"<I+"!T:&4@97)R;W(@;65S<V%G
M92!R971U<FYE9"!W:6QL#0H@("`@("H@8F4@)VUE<W-A9V4@;VYE('=A<R!S
M:7@G#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S971%<G)O<DUE<W-A9V5496UP;&%T92@D=&5M<&QA=&4I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7V5R<F]R37-G<R`]("1T96UP;&%T93L-"B`@
M("!]#0H@("`@#0H@("`@#0H@("`@+RHJ#0H@("`@("H@96UU;&%T92!014%2
M.CIR86ES945R<F]R*"D-"B`@("`@*B`-"B`@("`@*B!`<F5T=7)N(%!%05)?
M17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"D-"B`@
M("![#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*("`@("`@
M("`D87)G<R`](&9U;F-?9V5T7V%R9W,H*3L-"B`@("`@("`@<F5T=7)N(&-A
M;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"=014%2)RP@)W)A:7-E17)R;W(G
M*2P@)&%R9W,I.PT*("`@('T-"GT-"B1S=&%C:R`]("9014%27T5R<F]R4W1A
M8VLZ.G-I;F=L971O;B@G4$5!4E]%<G)O<E-T86-K)RD[#0HD<W1A8VLM/G!U
M<VA#86QL8F%C:RAA<G)A>2@G4$5!4E]%<G)O<E-T86-K)RP@)U]H86YD;&5%
M<G)O<B<I*3L-"C\^#0H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O17AC97!T:6]N+G!H<```
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S$V,3`@,3`U
M,34T,S0Q,S0@,#(Q-C8Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-H:69T=VED=&@]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\-"B\J
M*@T*("H@4$5!4E]%>&-E<'1I;VX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!4;VUA<R!6+B!6+B!#
M;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($AA;G,@3&5L
M;&5L:60@/&AA;G-`=F5L=6TN;F5T/@T*("H@0&%U=&AO<B`@("`@0F5R=')A
M;F0@36%N<VEO;B`\8FUA;G-I;VY`;6%M87-A;2YC;VT^#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@17AC97!T:6]N+G!H
M<"QV(#$N,C,@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N,RXS#0H@*B\-"@T*#0HO*BH-"B`J($)A<V4@4$5!4E]%>&-E<'1I;VX@
M0VQA<W,-"B`J#0H@*B`Q*2!&96%T=7)E<SH-"B`J#0H@*B`M($YE<W1A8FQE
M(&5X8V5P=&EO;G,@*'1H<F]W(&YE=R!014%27T5X8V5P=&EO;B@D;7-G+"`D
M<')E=E]E>&-E<'1I;VXI*0T*("H@+2!$969I;F%B;&4@=')I9V=E<G,L('-H
M;W0@=VAE;B!E>&-E<'1I;VYS(&]C8W5R#0H@*B`M(%!R971T>2!A;F0@:6YF
M;W)M871I=F4@97)R;W(@;65S<V%G97,-"B`J("T@061D960@;6]R92!C;VYT
M97AT(&EN9F\@879A:6QA8FQE("AL:6ME(&-L87-S+"!M971H;V0@;W(@8V%U
M<V4I#0H@*B`M(&-A=7-E(&-A;B!B92!A(%!%05)?17AC97!T:6]N(&]R(&%N
M(&%R<F%Y(&]F(&UI>&5D#0H@*B`@(%!%05)?17AC97!T:6]N<R]014%27T5R
M<F]R4W1A8VL@=V%R;FEN9W,-"B`J("T@8V%L;&)A8VMS(&9O<B!S<&5C:69I
M8R!E>&-E<'1I;VX@8VQA<W-E<R!A;F0@=&AE:7(@8VAI;&1R96X-"B`J#0H@
M*B`R*2!)9&5A<SH-"B`J#0H@*B`M($UA>6)E(&$@=V%Y('1O(&1E9FEN92!A
M("=T96UP;&%T92<@9F]R('1H92!O=71P=70-"B`J#0H@*B`S*2!);FAE<FET
M960@<')O<&5R=&EE<R!F<F]M(%!(4"!%>&-E<'1I;VX@0VQA<W,Z#0H@*@T*
M("H@<')O=&5C=&5D("1M97-S86=E#0H@*B!P<F]T96-T960@)&-O9&4-"B`J
M('!R;W1E8W1E9"`D;&EN90T*("H@<')O=&5C=&5D("1F:6QE#0H@*B!P<FEV
M871E("`@)'1R86-E#0H@*@T*("H@-"D@26YH97)I=&5D(&UE=&AO9',@9G)O
M;2!02%`@17AC97!T:6]N($-L87-S.@T*("H-"B`J(%]?8VQO;F4-"B`J(%]?
M8V]N<W1R=6-T#0H@*B!G971-97-S86=E#0H@*B!G971#;V1E#0H@*B!G971&
M:6QE#0H@*B!G971,:6YE#0H@*B!G9714<F%C95-A9F4-"B`J(&=E=%1R86-E
M4V%F94%S4W1R:6YG#0H@*B!?7W1O4W1R:6YG#0H@*@T*("H@-2D@57-A9V4@
M97AA;7!L90T*("H-"B`J(#QC;V1E/@T*("H@(')E<75I<F5?;VYC92`G4$5!
M4B]%>&-E<'1I;VXN<&AP)SL-"B`J#0H@*B`@8VQA<W,@5&5S="![#0H@*B`@
M("`@9G5N8W1I;VX@9F]O*"D@>PT*("H@("`@("`@("!T:')O=R!N97<@4$5!
M4E]%>&-E<'1I;VXH)T5R<F]R($UE<W-A9V4G+"!%4E)/4E]#3T1%*3L-"B`J
M("`@("!]#0H@*B`@?0T*("H-"B`J("!F=6YC=&EO;B!M>4QO9V=E<B@D<&5A
M<E]E>&-E<'1I;VXI('L-"B`J("`@("!E8VAO("1P96%R7V5X8V5P=&EO;BT^
M9V5T365S<V%G92@I.PT*("H@('T-"B`J("`O+R!E86-H('1I;64@82!E>&-E
M<'1I;VX@:7,@=&AR;W=N('1H92`G;7E,;V=G97(G('=I;&P@8F4@8V%L;&5D
M#0H@*B`@+R\@*&ET<R!U<V4@:7,@8V]M<&QE=&5L>2!O<'1I;VYA;"D-"B`J
M("!014%27T5X8V5P=&EO;CHZ861D3V)S97)V97(H)VUY3&]G9V5R)RD[#0H@
M*B`@)'1E<W0@/2!N97<@5&5S=#L-"B`J("!T<GD@>PT*("H@("`@("1T97-T
M+3YF;V\H*3L-"B`J("!](&-A=&-H("A014%27T5X8V5P=&EO;B`D92D@>PT*
M("H@("`@('!R:6YT("1E.PT*("H@('T-"B`J(#PO8V]D93X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`
M875T:&]R("`@("!(86YS($QE;&QE;&ED(#QH86YS0'9E;'5M+FYE=#X-"B`J
M($!A=71H;W(@("`@($)E<G1R86YD($UA;G-I;VX@/&)M86YS:6]N0&UA;6%S
M86TN8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C,N,PT*("H-"B`J+PT*8VQA<W,@4$5!4E]%
M>&-E<'1I;VX@97AT96YD<R!%>&-E<'1I;VX-"GL-"B`@("!C;VYS="!/0E-%
M4E9%4E]04DE.5"`]("TR.PT*("`@(&-O;G-T($]"4T525D527U1224='15(@
M/2`M-#L-"B`@("!C;VYS="!/0E-%4E9%4E]$244@/2`M.#L-"B`@("!P<F]T
M96-T960@)&-A=7-E.PT*("`@('!R:79A=&4@<W1A=&EC("1?;V)S97)V97)S
M(#T@87)R87DH*3L-"B`@("!P<FEV871E('-T871I8R`D7W5N:7%U96ED(#T@
M,#L-"B`@("!P<FEV871E("1?=')A8V4[#0H-"B`@("`O*BH-"B`@("`@*B!3
M=7!P;W)T960@<VEG;F%T=7)E<SH-"B`@("`@*B!014%27T5X8V5P=&EO;BAS
M=')I;F<@)&UE<W-A9V4I.PT*("`@("`J(%!%05)?17AC97!T:6]N*'-T<FEN
M9R`D;65S<V%G92P@:6YT("1C;V1E*3L-"B`@("`@*B!014%27T5X8V5P=&EO
M;BAS=')I;F<@)&UE<W-A9V4L($5X8V5P=&EO;B`D8V%U<V4I.PT*("`@("`J
M(%!%05)?17AC97!T:6]N*'-T<FEN9R`D;65S<V%G92P@17AC97!T:6]N("1C
M875S92P@:6YT("1C;V1E*3L-"B`@("`@*B!014%27T5X8V5P=&EO;BAS=')I
M;F<@)&UE<W-A9V4L(&%R<F%Y("1C875S97,I.PT*("`@("`J(%!%05)?17AC
M97!T:6]N*'-T<FEN9R`D;65S<V%G92P@87)R87D@)&-A=7-E<RP@:6YT("1C
M;V1E*3L-"B`@("`@*B\-"B`@("!P=6)L:6,@9G5N8W1I;VX@7U]C;VYS=')U
M8W0H)&UE<W-A9V4L("1P,B`](&YU;&PL("1P,R`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!I9B`H:7-?:6YT*"1P,BDI('L-"B`@("`@("`@("`@("1C;V1E
M(#T@)'`R.PT*("`@("`@("`@("`@)'1H:7,M/F-A=7-E(#T@;G5L;#L-"B`@
M("`@("`@?2!E;'-E:68@*"1P,B!I;G-T86YC96]F($5X8V5P=&EO;B!\?"!I
M<U]A<G)A>2@D<#(I*2![#0H@("`@("`@("`@("`D8V]D92`]("1P,SL-"B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D<#(I("8F(&ES<V5T*"1P,ELG;65S
M<V%G92==*2D@>PT*("`@("`@("`@("`@("`@("\O(&9I>"!P;W1E;G1I86P@
M<')O8FQE;2!O9B!P87-S:6YG(&EN(&$@<VEN9VQE('=A<FYI;F<-"B`@("`@
M("`@("`@("`@("`D<#(@/2!A<G)A>2@D<#(I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'1H:7,M/F-A=7-E(#T@)'`R.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&-O9&4@/2!N=6QL.PT*("`@("`@("`@("`@
M)'1H:7,M/F-A=7-E(#T@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("!P87)E
M;G0Z.E]?8V]N<W1R=6-T*"1M97-S86=E+"`D8V]D92D[#0H@("`@("`@("1T
M:&ES+3YS:6=N86PH*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R
M86T@;6EX960@)&-A;&QB86-K("`M($$@=F%L:60@<&AP(&-A;&QB86-K+"!S
M964@<&AP(&9U;F,@:7-?8V%L;&%B;&4H*0T*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("T@02!014%27T5X8V5P=&EO;CHZ3T)315)615)?*B!C
M;VYS=&%N=`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("T@06X@
M87)R87DH8V]N<W0@4$5!4E]%>&-E<'1I;VXZ.D]"4T525D527RHL#0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!M:7AE9"`D;W!T:6]N<RD-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1L86)E;"`@("!4:&4@;F%M92!O9B!T
M:&4@;V)S97)V97(N(%5S92!T:&ES(&EF('EO=2!W86YT#0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@<F5M;W9E(&ET(&QA=&5R('=I=&@@
M<F5M;W9E3V)S97)V97(H*0T*("`@("`J+PT*("`@('!U8FQI8R!S=&%T:6,@
M9G5N8W1I;VX@861D3V)S97)V97(H)&-A;&QB86-K+"`D;&%B96P@/2`G9&5F
M875L="<I#0H@("`@>PT*("`@("`@("!S96QF.CHD7V]B<V5R=F5R<ULD;&%B
M96Q=(#T@)&-A;&QB86-K.PT*("`@('T-"@T*("`@('!U8FQI8R!S=&%T:6,@
M9G5N8W1I;VX@<F5M;W9E3V)S97)V97(H)&QA8F5L(#T@)V1E9F%U;'0G*0T*
M("`@('L-"B`@("`@("`@=6YS970H<V5L9CHZ)%]O8G-E<G9E<G-;)&QA8F5L
M72D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!I;G0@=6YI
M<75E(&ED96YT:69I97(@9F]R(&%N(&]B<V5R=F5R#0H@("`@("HO#0H@("`@
M<'5B;&EC('-T871I8R!F=6YC=&EO;B!G9715;FEQ=65)9"@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@<V5L9CHZ)%]U;FEQ=65I9"LK.PT*("`@('T-"@T*
M("`@('!R:79A=&4@9G5N8W1I;VX@<VEG;F%L*"D-"B`@("![#0H@("`@("`@
M(&9O<F5A8V@@*'-E;&8Z.B1?;V)S97)V97)S(&%S("1F=6YC*2![#0H@("`@
M("`@("`@("!I9B`H:7-?8V%L;&%B;&4H)&9U;F,I*2![#0H@("`@("`@("`@
M("`@("`@8V%L;%]U<V5R7V9U;F,H)&9U;F,L("1T:&ES*3L-"B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('-E='1Y<&4H)&9U;F,L("=A<G)A>2<I.PT*("`@("`@("`@("`@<W=I=&-H
M("@D9G5N8ULP72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@<V5L9CHZ3T)3
M15)615)?4%))3E0@.@T*("`@("`@("`@("`@("`@("`@("`D9B`]("AI<W-E
M="@D9G5N8ULQ72DI(#\@)&9U;F-;,5T@.B`G)7,G.PT*("`@("`@("`@("`@
M("`@("`@("!P<FEN=&8H)&8L("1T:&ES+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E
M('-E;&8Z.D]"4T525D527U1224='15(@.@T*("`@("`@("`@("`@("`@("`@
M("`D9B`]("AI<W-E="@D9G5N8ULQ72DI(#\@)&9U;F-;,5T@.B!%7U5315)?
M3D]424-%.PT*("`@("`@("`@("`@("`@("`@("!T<FEG9V5R7V5R<F]R*"1T
M:&ES+3YG971-97-S86=E*"DL("1F*3L-"B`@("`@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92!S96QF.CI/0E-%4E9%4E]$
M244@.@T*("`@("`@("`@("`@("`@("`@("`D9B`]("AI<W-E="@D9G5N8ULQ
M72DI(#\@)&9U;F-;,5T@.B`G)7,G.PT*("`@("`@("`@("`@("`@("`@("!D
M:64H<')I;G1F*"1F+"`D=&AI<RT^9V5T365S<V%G92@I*2D[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&1E9F%U;'0Z
M#0H@("`@("`@("`@("`@("`@("`@('1R:6=G97)?97)R;W(H)VEN=F%L:60@
M;V)S97)V97(@='EP92<L($5?55-%4E]705).24Y'*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R
M;B!S<&5C:69I8R!E<G)O<B!I;F9O<FUA=&EO;B!T:&%T(&-A;B!B92!U<V5D
M(&9O<B!M;W)E(&1E=&%I;&5D#0H@("`@("H@97)R;W(@;65S<V%G97,@;W(@
M=')A;G-L871I;VXN#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO9"!M87D@
M8F4@;W9E<G)I9&1E;B!I;B!C:&EL9"!E>&-E<'1I;VX@8VQA<W-E<R!I;B!O
M<F1E<@T*("`@("`J('1O(&%D9"!F=6YC=&EO;F%L:71Y(&YO="!P<F5S96YT
M(&EN(%!%05)?17AC97!T:6]N(&%N9"!I<R!A('!L86-E:&]L9&5R#0H@("`@
M("H@=&\@9&5F:6YE($%020T*("`@("`J#0H@("`@("H@5&AE(')E='5R;F5D
M(&%R<F%Y(&UU<W0@8F4@86X@87-S;V-I871I=F4@87)R87D@;V8@<&%R86UE
M=&5R(#T^('9A;'5E(&QI:V4@<V\Z#0H@("`@("H@/'!R93X-"B`@("`@*B!A
M<G)A>2@G;F%M92<@/3X@)&YA;64L("=C;VYT97AT)R`]/B!A<G)A>2@N+BXI
M*0T*("`@("`J(#PO<')E/@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@
M*B\-"B`@("!P=6)L:6,@9G5N8W1I;VX@9V5T17)R;W)$871A*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B!A<G)A>2@I.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%)E='5R;G,@=&AE(&5X8V5P=&EO;B!T:&%T(&-A=7-E9"!T:&ES
M(&5X8V5P=&EO;B!T;R!B92!T:')O=VX-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J($!R971U<FX@17AC97!T:6]N?&%R<F%Y(%1H92!C;VYT97AT
M(&]F('1H92!E>&-E<'1I;VX-"B`@("`@*B\-"B`@("!P=6)L:6,@9G5N8W1I
M;VX@9V5T0V%U<V4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YC
M875S93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&=6YC=&EO;B!M=7-T
M(&)E('!U8FQI8R!T;R!C86QL(&]N(&-A=7-E9"!E>&-E<'1I;VYS#0H@("`@
M("H@0'!A<F%M(&%R<F%Y#0H@("`@("HO#0H@("`@<'5B;&EC(&9U;F-T:6]N
M(&=E=$-A=7-E365S<V%G92@F)&-A=7-E<RD-"B`@("![#0H@("`@("`@("1T
M<F%C92`]("1T:&ES+3YG9714<F%C95-A9F4H*3L-"B`@("`@("`@)&-A=7-E
M(#T@87)R87DH)V-L87-S)R`@(#T^(&=E=%]C;&%S<R@D=&AI<RDL#0H@("`@
M("`@("`@("`@("`@("`@("`@("=M97-S86=E)R`]/B`D=&AI<RT^;65S<V%G
M92P-"B`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("=U;FMN;W=N
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@)VQI;F4G(#T^("=U;FMN;W=N
M)RD[#0H@("`@("`@(&EF("AI<W-E="@D=')A8V5;,%TI*2![#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'1R86-E6S!=6R=F:6QE)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&-A=7-E6R=F:6QE)UT@/2`D=')A8V5;,%U;)V9I;&4G73L-
M"B`@("`@("`@("`@("`@("`D8V%U<V5;)VQI;F4G72`]("1T<F%C95LP75LG
M;&EN92==.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1C
M875S97-;72`]("1C875S93L-"B`@("`@("`@:68@*"1T:&ES+3YC875S92!I
M;G-T86YC96]F(%!%05)?17AC97!T:6]N*2![#0H@("`@("`@("`@("`D=&AI
M<RT^8V%U<V4M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-"B`@("`@("`@
M?2!E;'-E:68@*"1T:&ES+3YC875S92!I;G-T86YC96]F($5X8V5P=&EO;BD@
M>PT*("`@("`@("`@("`@)&-A=7-E<UM=(#T@87)R87DH)V-L87-S)R`@(#T^
M(&=E=%]C;&%S<R@D8V%U<V4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)VUE<W-A9V4G(#T^("1C875S92T^9V5T365S<V%G92@I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("1C875S92T^9V5T1FEL
M92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;F4G(#T^("1C
M875S92T^9V5T3&EN92@I*3L-"@T*("`@("`@("!](&5L<V5I9B`H:7-?87)R
M87DH)'1H:7,M/F-A=7-E*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/F-A=7-E(&%S("1C875S92D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M8V%U<V4@:6YS=&%N8V5O9B!014%27T5X8V5P=&EO;BD@>PT*("`@("`@("`@
M("`@("`@("`@("`D8V%U<V4M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-A=7-E(&EN<W1A;F-E;V8@
M17AC97!T:6]N*2![#0H@("`@("`@("`@("`@("`@("`@("1C875S97-;72`]
M(&%R<F%Y*"=C;&%S<R<@("`]/B!G971?8VQA<W,H)&-A=7-E*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1C
M875S92T^9V5T365S<V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G9FEL92<@/3X@)&-A=7-E+3YG971&:6QE*"DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=L:6YE)R`]/B`D8V%U
M<V4M/F=E=$QI;F4H*2D[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES
M7V%R<F%Y*"1C875S92D@)B8@:7-S970H)&-A=7-E6R=M97-S86=E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("\O(%!%05)?17)R;W)3=&%C:R!W87)N
M:6YG#0H@("`@("`@("`@("`@("`@("`@("1C875S97-;72`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)V-L87-S)R`]/B`D8V%U<V5;)W!A
M8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=M97-S86=E)R`]
M/B`D8V%U<V5;)VUE<W-A9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=F:6QE)R`]/B!I<W-E="@D8V%U<V5;)V-O;G1E>'0G75LG9FEL92==*2`_
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C875S95LG8V]N=&5X="==6R=F:6QE)UT@.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=6YK;F]W;B<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G;&EN92<@/3X@:7-S970H)&-A=7-E6R=C
M;VYT97AT)UU;)VQI;F4G72D@/PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D8V%U<V5;)V-O;G1E>'0G75LG;&EN92==
M(#H-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W5N:VYO=VXG+`T*("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@('!U8FQI8R!F=6YC=&EO;B!G9714<F%C95-A9F4H*0T*("`@('L@
M("`-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W1R86-E*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]T<F%C92`]("1T:&ES+3YG9714<F%C92@I.PT*
M("`@("`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?=')A8V4I*2![#0H@("`@
M("`@("`@("`@("`@)&)A8VMT<F%C92`](&1E8G5G7V)A8VMT<F%C92@I.PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=')A8V4@/2!A<G)A>2@D8F%C:W1R
M86-E6V-O=6YT*"1B86-K=')A8V4I+3%=*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]T<F%C93L-"B`@("!]
M#0H-"B`@("!P=6)L:6,@9G5N8W1I;VX@9V5T17)R;W)#;&%S<R@I#0H@("`@
M>PT*("`@("`@("`D=')A8V4@/2`D=&AI<RT^9V5T5')A8V53869E*"D[#0H@
M("`@("`@(')E='5R;B`D=')A8V5;,%U;)V-L87-S)UT[#0H@("`@?0T*#0H@
M("`@<'5B;&EC(&9U;F-T:6]N(&=E=$5R<F]R365T:&]D*"D-"B`@("![#0H@
M("`@("`@("1T<F%C92`]("1T:&ES+3YG9714<F%C95-A9F4H*3L-"B`@("`@
M("`@<F5T=7)N("1T<F%C95LP75LG9G5N8W1I;VXG73L-"B`@("!]#0H-"B`@
M("!P=6)L:6,@9G5N8W1I;VX@7U]T;U-T<FEN9R@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)%]315)615);)U)%455%4U1?55)))UTI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G1O2'1M;"@I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D=&AI<RT^=&]497AT*"D[#0H@("`@?0T*#0H@("`@
M<'5B;&EC(&9U;F-T:6]N('1O2'1M;"@I#0H@("`@>PT*("`@("`@("`D=')A
M8V4@/2`D=&AI<RT^9V5T5')A8V53869E*"D[#0H@("`@("`@("1C875S97,@
M/2!A<G)A>2@I.PT*("`@("`@("`D=&AI<RT^9V5T0V%U<V5-97-S86=E*"1C
M875S97,I.PT*("`@("`@("`D:'1M;"`]("`G/'1A8FQE(&)O<F1E<CTB,2(@
M8V5L;'-P86-I;F<](C`B/B<@+B`B7&XB.PT*("`@("`@("!F;W)E86-H("@D
M8V%U<V5S(&%S("1I(#T^("1C875S92D@>PT*("`@("`@("`@("`@)&AT;6P@
M+CT@)SQT<CX\=&0@8V]L<W!A;CTB,R(@8F=C;VQO<CTB(V9F.3DY.2(^)PT*
M("`@("`@("`@("`@("`@+B!S=')?<F5P96%T*"<M)RP@)&DI("X@)R`\8CXG
M("X@)&-A=7-E6R=C;&%S<R==("X@)SPO8CXZ("<-"B`@("`@("`@("`@("`@
M("X@:'1M;'-P96-I86QC:&%R<R@D8V%U<V5;)VUE<W-A9V4G72D@+B`G(&EN
M(#QB/B<@+B`D8V%U<V5;)V9I;&4G72`N("<\+V(^("<-"B`@("`@("`@("`@
M("`@("X@)V]N(&QI;F4@/&(^)R`N("1C875S95LG;&EN92==("X@)SPO8CXG
M#0H@("`@("`@("`@("`@("`N("(\+W1D/CPO='(^7&XB.PT*("`@("`@("!]
M#0H@("`@("`@("1H=&UL("X]("<\='(^/'1D(&-O;'-P86X](C,B(&)G8V]L
M;W(](B-A86%A86$B(&%L:6=N/2)C96YT97(B/CQB/D5X8V5P=&EO;B!T<F%C
M93PO8CX\+W1D/CPO='(^)R`N(")<;B(-"B`@("`@("`@("`@("`@("X@)SQT
M<CX\=&0@86QI9VX](F-E;G1E<B(@8F=C;VQO<CTB(V-C8V-C8R(@=VED=&@]
M(C(P(CX\8CXC/"]B/CPO=&0^)PT*("`@("`@("`@("`@("`@+B`G/'1D(&%L
M:6=N/2)C96YT97(B(&)G8V]L;W(](B-C8V-C8V,B/CQB/D9U;F-T:6]N/"]B
M/CPO=&0^)PT*("`@("`@("`@("`@("`@+B`G/'1D(&%L:6=N/2)C96YT97(B
M(&)G8V]L;W(](B-C8V-C8V,B/CQB/DQO8V%T:6]N/"]B/CPO=&0^/"]T<CXG
M("X@(EQN(CL-"@T*("`@("`@("!F;W)E86-H("@D=')A8V4@87,@)&L@/3X@
M)'8I('L-"B`@("`@("`@("`@("1H=&UL("X]("<\='(^/'1D(&%L:6=N/2)C
M96YT97(B/B<@+B`D:R`N("<\+W1D/B<-"B`@("`@("`@("`@("`@("`@("`N
M("<\=&0^)SL-"B`@("`@("`@("`@(&EF("@A96UP='DH)'9;)V-L87-S)UTI
M*2![#0H@("`@("`@("`@("`@("`@)&AT;6P@+CT@)'9;)V-L87-S)UT@+B`D
M=ELG='EP92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&AT;6P@
M+CT@)'9;)V9U;F-T:6]N)UT[#0H@("`@("`@("`@("`D87)G<R`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("!I9B`H(65M<'1Y*"1V6R=A<F=S)UTI*2![#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'9;)V%R9W,G72!A<R`D87)G*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6QL*"1A<F<I*2`D87)G
M<UM=(#T@)VYU;&PG.PT*("`@("`@("`@("`@("`@("`@("!E;'-E:68@*&ES
M7V%R<F%Y*"1A<F<I*2`D87)G<UM=(#T@)T%R<F%Y)SL-"B`@("`@("`@("`@
M("`@("`@("`@96QS96EF("AI<U]O8FIE8W0H)&%R9RDI("1A<F=S6UT@/2`G
M3V)J96-T*"<N9V5T7V-L87-S*"1A<F<I+B<I)SL-"B`@("`@("`@("`@("`@
M("`@("`@96QS96EF("AI<U]B;V]L*"1A<F<I*2`D87)G<UM=(#T@)&%R9R`_
M("=T<G5E)R`Z("=F86QS92<[#0H@("`@("`@("`@("`@("`@("`@(&5L<V5I
M9B`H:7-?:6YT*"1A<F<I('Q\(&ES7V1O=6)L92@D87)G*2D@)&%R9W-;72`]
M("1A<F<[#0H@("`@("`@("`@("`@("`@("`@(&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%R9R`]("AS=')I;F<I)&%R9SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1S='(@/2!H=&UL<W!E8VEA;&-H87)S*'-U8G-T
M<B@D87)G+"`P+"`Q-BDI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'-T<FQE;B@D87)G*2`^(#$V*2`D<W1R("X]("<F:&5L;&EP.R<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D87)G<UM=(#T@(B<B("X@)'-T<B`N("(G
M(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1H=&UL("X]("<H)R`N(&EM
M<&QO9&4H)RP@)RPD87)G<RD@+B`G*2<-"B`@("`@("`@("`@("`@("`@("`N
M("<\+W1D/B<-"B`@("`@("`@("`@("`@("`@("`N("<\=&0^)R`N("AI<W-E
M="@D=ELG9FEL92==*2`_("1V6R=F:6QE)UT@.B`G=6YK;F]W;B<I#0H@("`@
M("`@("`@("`@("`@("`@+B`G.B<@+B`H:7-S970H)'9;)VQI;F4G72D@/R`D
M=ELG;&EN92==(#H@)W5N:VYO=VXG*0T*("`@("`@("`@("`@("`@("`@("X@
M)SPO=&0^/"]T<CXG("X@(EQN(CL-"B`@("`@("`@?0T*("`@("`@("`D:'1M
M;"`N/2`G/'1R/CQT9"!A;&EG;CTB8V5N=&5R(CXG("X@*"1K*S$I("X@)SPO
M=&0^)PT*("`@("`@("`@("`@("`@+B`G/'1D/GMM86EN?3PO=&0^)PT*("`@
M("`@("`@("`@("`@+B`G/'1D/B9N8G-P.SPO=&0^/"]T<CXG("X@(EQN(@T*
M("`@("`@("`@("`@("`@+B`G/"]T86)L93XG.PT*("`@("`@("!R971U<FX@
M)&AT;6P[#0H@("`@?0T*#0H@("`@<'5B;&EC(&9U;F-T:6]N('1O5&5X="@I
M#0H@("`@>PT*("`@("`@("`D8V%U<V5S(#T@87)R87DH*3L-"B`@("`@("`@
M)'1H:7,M/F=E=$-A=7-E365S<V%G92@D8V%U<V5S*3L-"B`@("`@("`@)&-A
M=7-E37-G(#T@)R<[#0H@("`@("`@(&9O<F5A8V@@*"1C875S97,@87,@)&D@
M/3X@)&-A=7-E*2![#0H@("`@("`@("`@("`D8V%U<V5-<V<@+CT@<W1R7W)E
M<&5A="@G("<L("1I*2`N("1C875S95LG8VQA<W,G72`N("<Z("<-"B`@("`@
M("`@("`@("`@("`@("`N("1C875S95LG;65S<V%G92==("X@)R!I;B`G("X@
M)&-A=7-E6R=F:6QE)UT-"B`@("`@("`@("`@("`@("`@("`N("<@;VX@;&EN
M92`G("X@)&-A=7-E6R=L:6YE)UT@+B`B7&XB.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D8V%U<V5-<V<@+B`D=&AI<RT^9V5T5')A8V5!<U-T<FEN
M9R@I.PT*("`@('T-"GT-"@T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O1G)O;G1E
M;F0N<&AP````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,30Q-S0@,3`U,34T,S0Q,S0@,#(Q-3$P`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?1G)O
M;G1E;F0L('1H92!S:6YG;&5T;VXM8F%S960@9G)O;G1E;F0@9F]R('5S97(@
M:6YP=70O;W5T<'5T#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J
M#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V
M86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L
M;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@
M=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@
M("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P
M:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O
M=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93
M.B`D260Z($9R;VYT96YD+G!H<"QV(#$N.2`R,#`V+S`S+S`S(#$S.C$S.C`W
M('!A:F]Y92!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@5VAI
M8V@@=7-E<B!I;G1E<F9A8V4@8VQA<W,@:7,@8F5I;F<@=7-E9"X-"B`J($!V
M87(@<W1R:6YG(&-L87-S(&YA;64-"B`J+PT*)$=,3T)!3%-;)U]014%27T92
M3TY414Y$7T-,05-3)UT@/2`G4$5!4E]&<F]N=&5N9%]#3$DG.PT*#0HO*BH-
M"B`J($EN<W1A;F-E(&]F("1?4$5!4E]#;VUM86YD7W5I8VQA<W,N#0H@*B!`
M=F%R(&]B:F5C=`T*("HO#0HD1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?4TE.
M1TQ%5$].)UT@/2!N=6QL.PT*#0HO*BH-"B`J(%-I;F=L971O;BUB87-E9"!F
M<F]N=&5N9"!F;W(@4$5!4B!U<V5R(&EN<'5T+V]U='!U=`T*("H-"B`J($YO
M=&4@=&AA="!F<F]N=&5N9"!C;&%S<V5S(&UU<W0@:6UP;&5M96YT('5S97)#
M;VYF:7)M*"DL(&%N9"!S:&]U;"!I;7!L96UE;G0-"B`J(&1I<W!L87E&871A
M;$5R<F]R*"D@86YD(&]U='!U=$1A=&$H*0T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-
M"F-L87-S(%!%05)?1G)O;G1E;F0@97AT96YD<R!014%2#0I[#0H@("`@+RHJ
M#0H@("`@("H@4F5T<FEE=F4@=&AE(&9R;VYT96YD(&]B:F5C=`T*("`@("`J
M($!R971U<FX@4$5!4E]&<F]N=&5N9%]#3$E\4$5!4E]&<F]N=&5N9%]796)\
M4$5!4E]&<F]N=&5N9%]'=&L-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@)G-I;F=L971O;B@D='EP92`](&YU;&PI#0H@("`@>PT*
M("`@("`@("!I9B`H)'1Y<&4@/3T](&YU;&PI('L-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==
M*2D@>PT*("`@("`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M<F5T=7)N("1'3$]"04Q36R=?4$5!4E]&4D].5$5.1%]324Y'3$543TXG73L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@4$5!4E]&<F]N
M=&5N9#HZ<V5T1G)O;G1E;F1#;&%S<R@D='EP92D[#0H@("`@("`@("`@("!R
M971U<FX@)&$[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!3970@=&AE(&9R;VYT96YD(&-L87-S('1H870@=VEL;"!B92!U<V5D(&)Y
M(&-A;&QS('1O('M`;&EN:R!S:6YG;&5T;VXH*7T-"B`@("`@*@T*("`@("`J
M($9R;VYT96YD<R!A<F4@97AP96-T960@=&\@8V]N9F]R;2!T;R!T:&4@4$5!
M4B!N86UI;F<@<W1A;F1A<F0@;V8-"B`@("`@*B!?(#T^($1)4D5#5$]265]3
M15!!4D%43U(@*%!%05)?1G)O;G1E;F1?0TQ)(&ES(&EN(%!%05(O1G)O;G1E
M;F0O0TQ)+G!H<"D-"B`@("`@*B!`<&%R86T@<W1R:6YG("1U:6-L87-S(&9U
M;&P@8VQA<W,@;F%M90T*("`@("`J($!R971U<FX@4$5!4E]&<F]N=&5N9`T*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F<V5T1G)O
M;G1E;F1#;&%S<R@D=6EC;&%S<RD-"B`@("![#0H@("`@("`@(&EF("AI<U]O
M8FIE8W0H)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==*2`F
M)@T*("`@("`@("`@("`@("!I<U]A*"1'3$]"04Q36R=?4$5!4E]&4D].5$5.
M1%]324Y'3$543TXG72P@)'5I8VQA<W,I*2![#0H@("`@("`@("`@("!R971U
M<FX@)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1U:6-L87-S*2D@
M>PT*("`@("`@("`@("`@)&9I;&4@/2!S=')?<F5P;&%C92@G7R<L("<O)RP@
M)'5I8VQA<W,I("X@)RYP:'`G.PT*("`@("`@("`@("`@:68@*%!%05)?1G)O
M;G1E;F0Z.FES26YC;'5D96%B;&4H)&9I;&4I*2![#0H@("`@("`@("`@("`@
M("`@:6YC;'5D95]O;F-E("1F:6QE.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)'5I8VQA<W,I*2![#0H@
M("`@("`@("`@("`D;V)J(#T@)FYE=R`D=6EC;&%S<SL-"B`@("`@("`@("`@
M("\O('%U:6-K('1E<W0@=&\@<V5E(&EF('1H:7,@8VQA<W,@:6UP;&5M96YT
M<R!A(&9E=R!O9B!T:&4@;6]S=`T*("`@("`@("`@("`@+R\@:6UP;W)T86YT
M(&9R;VYT96YD(&UE=&AO9',-"B`@("`@("`@("`@(&EF("AM971H;V1?97AI
M<W1S*"1O8FHL("=U<V5R0V]N9FER;2<I*2![#0H@("`@("`@("`@("`@("`@
M)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==(#T@)B1O8FH[
M#0H@("`@("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T923TY414Y$7T-,
M05-3)UT@/2`D=6EC;&%S<SL-"B`@("`@("`@("`@("`@("!R971U<FX@)&]B
M:CL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5R
M<B`](%!%05(Z.G)A:7-E17)R;W(H(FYO="!A(&9R;VYT96YD(&-L87-S.B`D
M=6EC;&%S<R(I.PT*("`@("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1E<G(@/2!014%2.CIR
M86ES945R<F]R*")N;R!S=6-H(&-L87-S.B`D=6EC;&%S<R(I.PT*("`@("`@
M("!R971U<FX@)&5R<CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!3970@
M=&AE(&9R;VYT96YD(&-L87-S('1H870@=VEL;"!B92!U<V5D(&)Y(&-A;&QS
M('1O('M`;&EN:R!S:6YG;&5T;VXH*7T-"B`@("`@*@T*("`@("`J($9R;VYT
M96YD<R!A<F4@97AP96-T960@=&\@8F4@82!D97-C96YD86YT(&]F(%!%05)?
M1G)O;G1E;F0-"B`@("`@*B!`<&%R86T@4$5!4E]&<F]N=&5N9`T*("`@("`J
M($!R971U<FX@4$5!4E]&<F]N=&5N9`T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F<V5T1G)O;G1E;F1/8FIE8W0H)'5I;V)J96-T
M*0T*("`@('L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D1TQ/0D%,4ULG7U!%
M05)?1E)/3E1%3D1?4TE.1TQ%5$].)UTI("8F#0H@("`@("`@("`@("`@(&ES
M7V$H)$=,3T)!3%-;)U]014%27T923TY414Y$7U-)3D=,151/3B==+"!G971?
M8VQA<W,H)'5I;V)J96-T*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D1TQ/
M0D%,4ULG7U!%05)?1E)/3E1%3D1?4TE.1TQ%5$].)UT[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<U]A*"1U:6]B:F5C="P@)U!%05)?1G)O;G1E;F0G
M*2D@>PT*("`@("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H)VYO
M="!A('9A;&ED(&9R;VYT96YD(&-L87-S.B`H)R`N#0H@("`@("`@("`@("`@
M("`@9V5T7V-L87-S*"1U:6]B:F5C="D@+B`G*2<I.PT*("`@("`@("`@("`@
M<F5T=7)N("1E<G([#0H@("`@("`@('T-"B`@("`@("`@+R\@<75I8VL@=&5S
M="!T;R!S964@:68@=&AI<R!C;&%S<R!I;7!L96UE;G1S(&$@9F5W(&]F('1H
M92!M;W-T#0H@("`@("`@("\O(&EM<&]R=&%N="!F<F]N=&5N9"!M971H;V1S
M#0H@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1U:6]B:F5C="P@)W5S97)#
M;VYF:7)M)RDI('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?4$5!4E]&4D].
M5$5.1%]324Y'3$543TXG72`]("8D=6EO8FIE8W0[#0H@("`@("`@("`@("`D
M1TQ/0D%,4ULG7U!%05)?1E)/3E1%3D1?0TQ!4U,G72`](&=E=%]C;&%S<R@D
M=6EO8FIE8W0I.PT*("`@("`@("`@("`@<F5T=7)N("1U:6]B:F5C=#L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1E<G(@/2!014%2.CIR86ES
M945R<F]R*")N;W0@82!V86QU92!F<F]N=&5N9"!C;&%S<SH@*"(@+B!G971?
M8VQA<W,H)'5I;V)J96-T*0T*("`@("`@("`@("`@("`@("X@)RDG*3L-"B`@
M("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<&%T:"!R96QA=&EV92!O
M<B!A8G-O;'5T92!I;F-L=61E('!A=&@-"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-)
M;F-L=61E86)L92@D<&%T:"D-"B`@("![#0H@("`@("`@(&EF("AF:6QE7V5X
M:7-T<R@D<&%T:"D@)B8@:7-?<F5A9&%B;&4H)'!A=&@I*2![#0H@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D:7!A=&@@
M/2!E>'!L;V1E*%!!5$A?4T5005)!5$]2+"!I;FE?9V5T*"=I;F-L=61E7W!A
M=&@G*2D[#0H@("`@("`@(&9O<F5A8V@@*"1I<&%T:"!A<R`D:6YC;'5D92D@
M>PT*("`@("`@("`@("`@)'1E<W0@/2!R96%L<&%T:"@D:6YC;'5D92`N($1)
M4D5#5$]265]315!!4D%43U(@+B`D<&%T:"D[#0H@("`@("`@("`@("!I9B`H
M(21T97-T*2![("\O('-U<'!O<G0@=W)A<'!E<G,@;&EK92!P:&%R("AR96%L
M<&%T:"!J=7-T(&1O;B=T('=O<FL@=VET:"!T:&5M*0T*("`@("`@("`@("`@
M("`@("1T97-T(#T@)&EN8VQU9&4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)'!A=&@[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H9FEL95]E
M>&ES=',H)'1E<W0I("8F(&ES7W)E861A8FQE*"1T97-T*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S971#;VYF:6<H)B1C;VYF:6<I#0H@("`@>PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J(%1H:7,@8V%N(&)E(&]V97)R:61D96X@=&\@86QL;W<@
M<V5S<VEO;BUB87-E9"!T96UP;W)A<GD@9FEL92!M86YA9V5M96YT#0H@("`@
M("H-"B`@("`@*B!">2!D969A=6QT+"!A;&P@9FEL97,@87)E(&1E;&5T960@
M870@=&AE(&5N9"!O9B!A('-E<W-I;VXN("!4:&4@=V5B(&EN<W1A;&QE<@T*
M("`@("`J(&YE961S('1O(&)E(&%B;&4@=&\@<W5S=&%I;B!A(&QI<W0@;W9E
M<B!M86YY('-E<W-I;VYS(&EN(&]R9&5R('1O('-U<'!O<G0-"B`@("`@*B!U
M<V5R(&EN=&5R86-T:6]N('=I=&@@:6YS=&%L;"!S8W)I<'1S#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@861D5&5M<$9I;&4H)&9I;&4I#0H@("`@>PT*("`@
M("`@("`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W1E;7!F:6QE<R==6UT@/2`D
M9FEL93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!L;V<H)&US9RP@)&%P<&5N
M9%]C<FQF(#T@=')U92D-"B`@("![#0H@("`@?0T*?0T*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+TEN<W1A;&QE<BYP:'``````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,3<V,34Q(#$P-3$U-#,T,3,T(#`R,38W,@`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27TEN<W1A;&QE<@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BX@0V]X(#QC
M;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N
M(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z($EN<W1A;&QE<BYP:'`L=B`Q+C(R."XR+C$@,C`P-B\P
M,R\P-2`R,#HP-SHU,B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J
M*@T*("H@57-E9"!F;W(@:6YS=&%L;&%T:6]N(&=R;W5P<R!I;B!P86-K86=E
M+GAM;"`R+C`@86YD('!L871F;W)M(&5X8V5P=&EO;G,-"B`J+PT*<F5Q=6ER
M95]O;F-E("=/4R]'=65S<RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T1O
M=VYL;V%D97(N<&AP)SL-"@T*9&5F:6YE*"=014%27TE.4U1!3$Q%4E].3T))
M3D%262<L("TR-#`I.PT*+RHJ#0H@*B!!9&UI;FES=')A=&EO;B!C;&%S<R!U
M<V5D('1O(&EN<W1A;&P@4$5!4B!P86-K86=E<R!A;F0@;6%I;G1A:6X@=&AE
M#0H@*B!I;G-T86QL960@<&%C:V%G92!D871A8F%S92X-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@
M("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO
M<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ
M#0H@*B\-"F-L87-S(%!%05)?26YS=&%L;&5R(&5X=&5N9',@4$5!4E]$;W=N
M;&]A9&5R#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@("\J*B!N
M86UE(&]F('1H92!P86-K86=E(&1I<F5C=&]R>2P@9F]R(&5X86UP;&4@1F]O
M+3$N,`T*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1P
M:V=D:7([#0H-"B`@("`O*BH@9&ER96-T;W)Y('=H97)E(%!(4"!C;V1E(&9I
M;&5S(&=O#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B\-"B`@("!V87(@
M)'!H<&1I<CL-"@T*("`@("\J*B!D:7)E8W1O<GD@=VAE<F4@4$A0(&5X=&5N
M<VEO;B!F:6QE<R!G;PT*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@
M("`@=F%R("1E>'1D:7([#0H-"B`@("`O*BH@9&ER96-T;W)Y('=H97)E(&1O
M8W5M96YT871I;VX@9V]E<PT*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO
M#0H@("`@=F%R("1D;V-D:7([#0H-"B`@("`O*BH@:6YS=&%L;&%T:6]N(')O
M;W0@9&ER96-T;W)Y("AA;&$@4$A0)W,@24Y35$%,3%]23T]4(&]R#0H@("`@
M("H@875T;VUA:V4G<R!$15-41$E2#0H@("`@("H@0'9A<B!S=')I;F<-"B`@
M("`@*B\-"B`@("!V87(@)&EN<W1A;&QR;V]T(#T@)R<[#0H-"B`@("`O*BH@
M9&5B=6<@;&5V96P-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J+PT*("`@('9A
M<B`D9&5B=6<@/2`Q.PT*#0H@("`@+RHJ('1E;7!O<F%R>2!D:7)E8W1O<GD-
M"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J+PT*("`@('9A<B`D=&UP9&ER
M.PT*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]296=I<W1R>2!O8FIE8W0@=7-E
M9"!B>2!T:&4@:6YS=&%L;&5R#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y
M#0H@("`@("HO#0H@("`@=F%R("1R96=I<W1R>3L-"@T*("`@("\J*@T*("`@
M("`J(&%R<F%Y(&]F(%!%05)?1&]W;FQO861E<E]086-K86=E<PT*("`@("`J
M($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9&5D4&%C
M:V%G97,[#0H-"B`@("`O*BH@3&ES="!O9B!F:6QE('1R86YS86-T:6]N<R!Q
M=65U960@9F]R(&%N(&EN<W1A;&PO=7!G<F%D92]U;FEN<W1A;&PN#0H@("`@
M("H-"B`@("`@*B`@1F]R;6%T.@T*("`@("`J("`@(&%R<F%Y*`T*("`@("`J
M("`@("`@,"`]/B!A<G)A>2@B<F5N86UE(#T^(&%R<F%Y*")F<F]M+69I;&4B
M+"`B=&\M9FEL92(I*2P-"B`@("`@*B`@("`@(#$@/3X@87)R87DH(F1E;&5T
M92(@/3X@87)R87DH(F9I;&4M=&\M9&5L971E(BDI+`T*("`@("`J("`@("`@
M+BXN#0H@("`@("H@("`@*0T*("`@("`J#0H@("`@("H@0'9A<B!A<G)A>0T*
M("`@("`J+PT*("`@('9A<B`D9FEL95]O<&5R871I;VYS(#T@87)R87DH*3L-
M"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@
M("`O*BH-"B`@("`@*B!014%27TEN<W1A;&QE<B!C;VYS=')U8W1O<BX-"B`@
M("`@*@T*("`@("`J($!P87)A;2!O8FIE8W0@)'5I('5S97(@:6YT97)F86-E
M(&]B:F5C="`H:6YS=&%N8V4@;V8@4$5!4E]&<F]N=&5N9%\J*0T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!014%27TEN<W1A;&QE<B@F)'5I*0T*("`@('L-"B`@("`@("`@<&%R96YT
M.CI014%27T-O;6UO;B@I.PT*("`@("`@("`D=&AI<RT^<V5T1G)O;G1E;F1/
M8FIE8W0H)'5I*3L-"B`@("`@("`@)'1H:7,M/F1E8G5G(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M<V5T3W!T:6]N<R@D;W!T:6]N<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E
M=$-O;F9I9R@F)&-O;F9I9RD-"B`@("![#0H@("`@("`@("1T:&ES+3YC;VYF
M:6<@/2`F)&-O;F9I9SL-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D
M8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@('T-"@T*("`@("\O('U]?0T*
M#0H@("`@9G5N8W1I;VX@7W)E;6]V94)A8VMU<',H)&9I;&5S*0T*("`@('L-
M"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1P871H*2![#0H@("`@("`@
M("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@G<F5M;W9E8F%C:W5P)RP@
M87)R87DH)'!A=&@I*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('M[
M>R!?9&5L971E4&%C:V%G949I;&5S*"D-"@T*("`@("\J*@T*("`@("`J($1E
M;&5T92!A('!A8VMA9V4G<R!I;G-T86QL960@9FEL97,L(&1O97,@;F]T(')E
M;6]V92!E;7!T>2!D:7)E8W1O<FEE<RX-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!C
M:&%N;F5L(&YA;64-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T:&5N
M(&9I;&5S(&%R92!B86-K960@=7`@9FER<W0-"B`@("`@*B!`<F5T=7)N(&)O
M;VP@5%)512!O;B!S=6-C97-S+"!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R
M90T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V1E;&5T95!A8VMA9V5&:6QE<R@D<&%C:V%G92P@)&-H86YN96P@
M/2!F86QS92P@)&)A8VMU<"`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"$D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`G<&5A<BYP
M:'`N;F5T)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(7-T<FQE;B@D<&%C
M:V%G92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B3F\@<&%C:V%G92!T;R!U;FEN<W1A;&P@9VEV96XB*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H<W1R=&]L;W=E<B@D<&%C:V%G92D@/3T@)W!E87(G
M("8F("1C:&%N;F5L(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@
M("`O+R!T;R!A=F]I9"!R86-E(&-O;F1I=&EO;G,L(&EN8VQU9&4@86QL('!O
M<W-I8FQE(&YE961E9"!F:6QE<PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+U1A<VLO0V]M;6]N+G!H<"<[#0H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)U!%05(O5&%S:R]297!L86-E+G!H<"<[#0H@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O5&%S:R]5;FEX96]L+G!H<"<[#0H@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O5&%S:R]7:6YD;W=S96]L+G!H<"<[
M#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O
M=C$N<&AP)SL-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K
M86=E1FEL92]V,BYP:'`G.PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=0
M14%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,2YP:'`G.PT*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V
M,BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE;&ES="`]("1T:&ES
M+3Y?<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P86-K86=E+"`G9FEL96QI<W0G
M+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF("@D9FEL96QI<W0@/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8VAA
M;FYE;"\D<&%C:V%G92!N;W0@:6YS=&%L;&5D(BD[#0H@("`@("`@('T-"B`@
M("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE
M;&ES="!A<R`D9FEL92`]/B`D<')O<',I('L-"B`@("`@("`@("`@(&EF("AE
M;7!T>2@D<')O<'-;)VEN<W1A;&QE9%]A<R==*2D@>PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!A
M=&@@/2`D<')O<'-;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("`@("`@:68@
M*"1B86-K=7`I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1FEL94]P
M97)A=&EO;B@G8F%C:W5P)RP@87)R87DH)'!A=&@I*3L-"B`@("`@("`@("`@
M("`@("`D<F5T6UT@/2`D<&%T:#L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T:6]N*"=D96QE=&4G+"!A<G)A>2@D
M<&%T:"DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D8F%C:W5P*2![#0H@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M7VEN<W1A;&Q&:6QE*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<@9FEL96YA;64-"B`@("`@*B!`<&%R86T@87)R87D@871T<FEB=71E<R!F
M<F]M(#QF:6QE/B!T86<@:6X@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('!A=&@@=&\@:6YS=&%L;"!T:&4@9FEL92!I;@T*("`@("`J($!P
M87)A;2!A<G)A>2!O<'1I;VYS(&9R;VT@8V]M;6%N9"UL:6YE#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VEN<W1A
M;&Q&:6QE*"1F:6QE+"`D871T<RP@)'1M<%]P871H+"`D;W!T:6]N<RD-"B`@
M("![#0H@("`@("`@("\O('M[>R!R971U<FX@:68@=&AI<R!F:6QE(&ES(&UE
M86YT(&9O<B!A;F]T:&5R('!L871F;W)M#0H@("`@("`@('-T871I8R`D;W,[
M#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]R96=I<W1R>2DI('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^
M9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&%T='-;)W!L871F;W)M)UTI*2![#0H@("`@("`@("`@("!I9B`H96UP='DH
M)&]S*2D@>PT*("`@("`@("`@("`@("`@("1O<R`](&YE=R!/4U]'=65S<R@I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-T<FQE;B@D871T
M<ULG<&QA=&9O<FTG72D@)B8@)&%T='-;)W!L871F;W)M)UU[,'T@/3T@)R$G
M*2![#0H@("`@("`@("`@("`@("`@)&YE9V%T92`]('1R=64[#0H@("`@("`@
M("`@("`@("`@)'!L871F;W)M(#T@<W5B<W1R*"1A='1S6R=P;&%T9F]R;2==
M+"`Q*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)&YE9V%T92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("1P;&%T9F]R;2`]
M("1A='1S6R=P;&%T9F]R;2==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"AB;V]L*2`D;W,M/FUA=&-H4VEG;F%T=7)E*"1P;&%T9F]R;2D@
M/3T]("1N96=A=&4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L
M(")S:VEP<&5D("1F:6QE("AM96%N="!F;W(@)&%T='-;<&QA=&9O<FU=+"!W
M92!A<F4@(BXD;W,M/F=E=%-I9VYA='5R92@I+B(I(BD[#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05)?24Y35$%,3$527U-+25!0140[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@("`@
M)&-H86YN96P@/2`D=&AI<RT^<&MG:6YF;RT^9V5T0VAA;FYE;"@I.PT*("`@
M("`@("`O+R![>WL@87-S96UB;&4@=&AE(&1E<W1I;F%T:6]N('!A=&AS#0H@
M("`@("`@('-W:71C:"`H)&%T='-;)W)O;&4G72D@>PT*("`@("`@("`@("`@
M8V%S92`G9&]C)SH-"B`@("`@("`@("`@(&-A<V4@)V1A=&$G.@T*("`@("`@
M("`@("`@8V%S92`G=&5S="<Z#0H@("`@("`@("`@("`@("`@)&1E<W1?9&ER
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1A='1S6R=R;VQE)UT@+B`G7V1I<B<L
M(&YU;&PL("1C:&%N;F5L*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@1$E214-43U)97U-%4$%2051/4B`N("1T:&ES+3YP:V=I;F9O+3YG9710
M86-K86=E*"D[#0H@("`@("`@("`@("`@("`@=6YS970H)&%T='-;)V)A<V5I
M;G-T86QL9&ER)UTI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G97AT)SH-"B`@("`@("`@("`@(&-A<V4@)W!H<"<Z#0H@
M("`@("`@("`@("`@("`@)&1E<W1?9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"1A='1S6R=R;VQE)UT@+B`G7V1I<B<L(&YU;&PL("1C:&%N;F5L*3L-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W-C<FEP
M="<Z#0H@("`@("`@("`@("`@("`@)&1E<W1?9&ER(#T@)'1H:7,M/F-O;F9I
M9RT^9V5T*"=B:6Y?9&ER)RP@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G<W)C)SH-"B`@("`@
M("`@("`@(&-A<V4@)V5X='-R8R<Z#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/G-O=7)C95]F:6QE<RLK.PT*("`@("`@("`@("`@("`@(')E='5R;CL-"B`@
M("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"));G9A;&ED(')O;&4@8"1A='1S6W)O;&5=)R!F
M;W(@9FEL92`D9FEL92(I.PT*("`@("`@("!]#0H@("`@("`@("1S879E7V1E
M<W1D:7(@/2`D9&5S=%]D:7([#0H@("`@("`@(&EF("@A96UP='DH)&%T='-;
M)V)A<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]D:7(@
M+CT@1$E214-43U)97U-%4$%2051/4B`N("1A='1S6R=B87-E:6YS=&%L;&1I
M<B==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AD:7)N86UE*"1F:6QE*2`A
M/2`G+B<@)B8@96UP='DH)&%T='-;)VEN<W1A;&PM87,G72DI('L-"B`@("`@
M("`@("`@("1D97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@9&ER
M;F%M92@D9FEL92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1A
M='1S6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]F:6QE
M(#T@)&1E<W1?9&ER("X@1$E214-43U)97U-%4$%2051/4B`N(&)A<V5N86UE
M*"1F:6QE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D97-T
M7V9I;&4@/2`D9&5S=%]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&%T
M='-;)VEN<W1A;&PM87,G73L-"B`@("`@("`@?0T*("`@("`@("`D;W)I9U]F
M:6QE(#T@)'1M<%]P871H("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE
M.PT*#0H@("`@("`@("\O($-L96%N('5P('1H92!$25)%0U1/4EE?4T5005)!
M5$]2(&UE<W,-"B`@("`@("`@)&1S,B`]($1)4D5#5$]265]315!!4D%43U(@
M+B!$25)%0U1/4EE?4T5005)!5$]2.PT*("`@("`@("!L:7-T*"1D97-T7V9I
M;&4L("1O<FEG7V9I;&4I(#T@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA
M)RP@)R$O(2<L("(A)&1S,BLA(BDL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH1$E214-43U)9
M7U-%4$%2051/4BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(I+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"1D97-T7V9I;&4L("1O<FEG7V9I;&4I*3L-"B`@("`@("`@)&9I
M;F%L7V1E<W1?9FEL92`]("1I;G-T86QL961?87,@/2`D9&5S=%]F:6QE.PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R
M;V]T)UTI*2![#0H@("`@("`@("`@("`D:6YS=&%L;&5D87-?9&5S=%]D:7(@
M/2!D:7)N86UE*"1F:6YA;%]D97-T7V9I;&4I.PT*("`@("`@("`@("`@)&EN
M<W1A;&QE9&%S7V1E<W1?9FEL92`]("1D97-T7V1I<B`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`G+G1M<"<@+B!B87-E;F%M92@D9FEN86Q?9&5S=%]F:6QE
M*3L-"B`@("`@("`@("`@("1F:6YA;%]D97-T7V9I;&4@/2`D=&AI<RT^7W!R
M97!E;F10871H*"1F:6YA;%]D97-T7V9I;&4L#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R;V]T)UTI.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&EN<W1A;&QE9&%S7V1E<W1?9&ER(#T@
M9&ER;F%M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("1I;G-T
M86QL961A<U]D97-T7V9I;&4@/2`D:6YS=&%L;&5D87-?9&5S=%]D:7(@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)RYT;7`G("X@8F%S96YA;64H)&9I;F%L
M7V1E<W1?9FEL92D[#0H@("`@("`@('T-"B`@("`@("`@)&1E<W1?9&ER(#T@
M9&ER;F%M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@)&1E<W1?9FEL
M92`]("1D97-T7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`G+G1M<"<@
M+B!B87-E;F%M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@+R\@?7U]
M#0H-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T
M97(M;VYL>2==*2`F)B`A0&ES7V1I<B@D9&5S=%]D:7(I*2![#0H@("`@("`@
M("`@("!I9B`H(21T:&ES+3YM:T1I<DAI97(H)&1E<W1?9&ER*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D
M('1O(&UK9&ER("1D97-T7V1I<B(L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&UK
M9&ER("1D97-T7V1I<B(I.PT*("`@("`@("!]#0H@("`@("`@("\O('!R971T
M>2!M=6-H(&YO=&AI;F<@:&%P<&5N<R!I9B!W92!A<F4@;VYL>2!R96=I<W1E
M<FEN9R!T:&4@:6YS=&%L;`T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]O
M<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI*2![#0H@("`@("`@("`@("!I9B`H
M96UP='DH)&%T='-;)W)E<&QA8V5M96YT<R==*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)&]R:6=?9FEL92DI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F:6QE("1O
M<FEG7V9I;&4@9&]E<R!N;W0@97AI<W0B+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)
M3$5$*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"%`8V]P>2@D;W)I9U]F:6QE+"`D9&5S=%]F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T
M;R!W<FET92`D9&5S=%]F:6QE(BP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,RP@(BL@8W`@)&]R:6=?9FEL92`D9&5S=%]F:6QE(BD[#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1A='1S6R=M9#5S=6TG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&UD-7-U;2`](&UD-5]F:6QE*"1D97-T7V9I;&4I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@+R\@>WM[(&9I;&4@=VET:"!R97!L86-E;65N=',-
M"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1O<FEG7V9I;&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B9FEL92!D;V5S(&YO="!E>&ES="(L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&
M04E,140I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?9V5T7V-O;G1E
M;G1S*"1O<FEG7V9I;&4I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1F<"`](&9O<&5N*"1O<FEG7V9I;&4L(")R
M(BD[#0H@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D
M9G`L(&9I;&5S:7IE*"1O<FEG7V9I;&4I*3L-"B`@("`@("`@("`@("`@("`@
M("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@D8V]N=&5N=',@/3T](&9A;'-E*2![#0H@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT<R`]("<G.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T='-;)VUD-7-U;2==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D;60U<W5M(#T@;60U*"1C;VYT96YT
M<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1S=6)S
M=%]F<F]M(#T@)'-U8G-T7W1O(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D871T<ULG<F5P;&%C96UE;G1S)UT@87,@)&$I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1O(#T@)R<[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D85LG='EP92==(#T]("=P:'`M8V]N<W0G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;82UZ,"TY7UTK
M)"]I)RP@)&%;)W1O)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@979A;"@B7"1T;R`]("1A6W1O73LB*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")I;G9A;&ED('!H
M<"UC;VYS="!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!](&5L<V5I9B`H)&%;)W1Y<&4G72`]/2`G<&5A<BUC
M;VYF:6<G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&%;)W1O
M)UT@/3T@)VUA<W1E<E]S97)V97(G*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-H86X@/2`D=&AI<RT^7W)E9VES=')Y+3YG971#:&%N;F5L
M*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(5!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T;R`]("1C:&%N+3YG971397)V97(H*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&\@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)&%;)W1O)UTL(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T:&ES+3YC
M;VYF:6<M/F=E="@D85LG=&\G72P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES7VYU;&PH)'1O*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B:6YV86QI
M9"!P96%R+6-O;F9I9R!R97!L86-E;65N=#H@)&%;=&]=(BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&%;)W1Y<&4G72`]/2`G
M<&%C:V%G92UI;F9O)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1T(#T@)'1H:7,M/G!K9VEN9F\M/G!A8VMA9V5);F9O*"1A6R=T;R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H
M,"P@(FEN=F%L:60@<&%C:V%G92UI;F9O(')E<&QA8V5M96YT.B`D85MT;UTB
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<U]N=6QL*"1T;RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1S=6)S=%]F<F]M6UT@/2`D85LG9G)O;2==.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-U8G-T7W1O6UT@/2`D=&\[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/FQO9R@S+"`B9&]I;F<@(BYS:7IE;V8H)'-U8G-T7V9R
M;VTI+B(@<W5B<W1I='5T:6]N*',I(&9O<B`D9FEN86Q?9&5S=%]F:6QE(BD[
M#0H@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D<W5B<W1?9G)O;2DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H
M)'-U8G-T7V9R;VTL("1S=6)S=%]T;RP@)&-O;G1E;G1S*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'=P(#T@0&9O<&5N*"1D97-T
M7V9I;&4L(")W8B(I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R
M8V4H)'=P*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!C<F5A=&4@)&1E<W1?9FEL93H@)'!H
M<%]E<G)O<FUS9R(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H9G=R:71E*"1W<"P@
M)&-O;G1E;G1S*2`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")F86EL960@=W)I=&EN9R!T;R`D
M9&5S=%]F:6QE.B`D<&AP7V5R<F]R;7-G(BP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?24Y35$%,3$527T9!
M24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9C
M;&]S92@D=W`I.PT*("`@("`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@+R\@>WM[(&-H96-K('1H92!M9#4-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D;60U<W5M*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("AS=')T;VQO=V5R*"1M9#5S=6TI(#T]('-T<G1O;&]W97(H)&%T='-;
M)VUD-7-U;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*#(L(")M9#5S=6T@;VLZ("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)&]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!D96QE=&4@=&AE(&9I;&4-"B`@("`@("`@("`@("`@("`@("`@
M("`@($!U;FQI;FLH)&1E<W1?9FEL92D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")B860@;60U<W5M(&9O<B!F:6QE("1F:6YA;%]D97-T7V9I
M;&4B+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B=V%R
M;FEN9R`Z(&)A9"!M9#5S=6T@9F]R(&9I;&4@)&9I;F%L7V1E<W1?9FEL92(I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;
M)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*#`L(")W87)N:6YG(#H@8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN
M86Q?9&5S=%]F:6QE(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`O+R!]?7T-"B`@("`@("`@("`@("\O
M('M[>R!S970@9FEL92!P97)M:7-S:6]N<PT*("`@("`@("`@("`@:68@*"%/
M4U]724Y$3U=3*2![#0H@("`@("`@("`@("`@("`@:68@*"1A='1S6R=R;VQE
M)UT@/3T@)W-C<FEP="<I('L-"B`@("`@("`@("`@("`@("`@("`@)&UO9&4@
M/2`P-S<W("8@?BAI;G0I;V-T9&5C*"1T:&ES+3YC;VYF:6<M/F=E="@G=6UA
M<VLG*2D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@
M8VAM;V0@*W@@)&1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@,#8V-B`F('XH:6YT
M*6]C=&1E8R@D=&AI<RT^8V]N9FEG+3YG970H)W5M87-K)RDI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1FEL94]P
M97)A=&EO;B@B8VAM;V0B+"!A<G)A>2@D;6]D92P@)&1E<W1?9FEL92DI.PT*
M("`@("`@("`@("`@("`@(&EF("@A0&-H;6]D*"1D97-T7V9I;&4L("1M;V1E
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#`L(")F86EL960@=&\@8VAA;F=E(&UO9&4@;V8@)&1E<W1?9FEL92(I
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@+R\@?7U]#0H@("`@("`@("`@
M("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@B<F5N86UE(BP@87)R87DH)&1E
M<W1?9FEL92P@)&9I;F%L7V1E<W1?9FEL92P-"B`@("`@("`@("`@("`@("`D
M871T<ULG<F]L92==(#T]("=E>'0G*2D[#0H@("`@("`@('T-"B`@("`@("`@
M+R\@4W1O<F4@=&AE(&9U;&P@<&%T:"!W:&5R92!T:&4@9FEL92!W87,@:6YS
M=&%L;&5D(&9O<B!E87-Y('5N:7-T86QL#0H@("`@("`@("1T:&ES+3YA9&1&
M:6QE3W!E<F%T:6]N*")I;G-T86QL961?87,B+"!A<G)A>2@D9FEL92P@)&EN
M<W1A;&QE9%]A<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'-A=F5?9&5S=&1I<BP@9&ER;F%M92AS=6)S='(H)&EN<W1A;&QE9&%S7V1E
M<W1?9FEL92P@<W1R;&5N*"1S879E7V1E<W1D:7(I*2DI*3L-"@T*("`@("`@
M("`O+R1T:&ES+3YL;V<H,BP@(FEN<W1A;&QE9#H@)&1E<W1?9FEL92(I.PT*
M("`@("`@("!R971U<FX@4$5!4E])3E-404Q,15)?3TL[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(%]I;G-T86QL1FEL93(H*0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL96YA;64-
M"B`@("`@*B!`<&%R86T@87)R87D@871T<FEB=71E<R!F<F]M(#QF:6QE/B!T
M86<@:6X@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A=&@@
M=&\@:6YS=&%L;"!T:&4@9FEL92!I;@T*("`@("`J($!P87)A;2!A<G)A>2!O
M<'1I;VYS(&9R;VT@8V]M;6%N9"UL:6YE#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7VEN<W1A;&Q&:6QE,B@F)'!K
M9RP@)&9I;&4L("1A='1S+"`D=&UP7W!A=&@L("1O<'1I;VYS*0T*("`@('L-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W)E9VES=')Y*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^8V]N9FEG+3YG
M971296=I<W1R>2@I.PT*("`@("`@("!]#0H-"B`@("`@("`@)&-H86YN96P@
M/2`D<&MG+3YG971#:&%N;F5L*"D[#0H@("`@("`@("\O('M[>R!A<W-E;6)L
M92!T:&4@9&5S=&EN871I;VX@<&%T:',-"B`@("`@("`@:68@*"%I;E]A<G)A
M>2@D871T<ULG871T<FEB<R==6R=R;VQE)UTL#0H@("`@("`@("`@("`@(%!%
M05)?26YS=&%L;&5R7U)O;&4Z.F=E=%9A;&ED4F]L97,H)'!K9RT^9V5T4&%C
M:V%G951Y<&4H*2DI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)TEN=F%L:60@<F]L92!@)R`N("1A='1S6R=A='1R:6)S)UU;
M)W)O;&4G72`N#0H@("`@("`@("`@("`@("`@("`@("(G(&9O<B!F:6QE("1F
M:6QE(BD[#0H@("`@("`@('T-"B`@("`@("`@)')O;&4@/2`F4$5!4E]);G-T
M86QL97)?4F]L93HZ9F%C=&]R>2@D<&MG+"`D871T<ULG871T<FEB<R==6R=R
M;VQE)UTL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D97)R(#T@)')O;&4M
M/G-E='5P*"1T:&ES+"`D<&MG+"`D871T<ULG871T<FEB<R==+"`D9FEL92D[
M#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@
M("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R
M;VQE+3YI<TEN<W1A;&QA8FQE*"DI('L-"B`@("`@("`@("`@(')E='5R;CL-
M"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`]("1R;VQE+3YP<F]C97-S26YS
M=&%L;&%T:6]N*"1P:V<L("1A='1S6R=A='1R:6)S)UTL("1F:6QE+"`D=&UP
M7W!A=&@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D:6YF;SL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(&QI<W0H)'-A=F5?9&5S=&1I<BP@)&1E<W1?9&ER+"`D
M9&5S=%]F:6QE+"`D;W)I9U]F:6QE*2`]("1I;F9O.PT*("`@("`@("!]#0H@
M("`@("`@("1F:6YA;%]D97-T7V9I;&4@/2`D:6YS=&%L;&5D7V%S(#T@)&1E
M<W1?9FEL93L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@("`@("`@)&9I;F%L7V1E<W1?
M9FEL92`]("1T:&ES+3Y?<')E<&5N9%!A=&@H)&9I;F%L7V1E<W1?9FEL92P-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O
M;W0G72D[#0H@("`@("`@('T-"B`@("`@("`@)&1E<W1?9&ER(#T@9&ER;F%M
M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@)&1E<W1?9FEL92`]("1D
M97-T7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`G+G1M<"<@+B!B87-E
M;F%M92@D9FEN86Q?9&5S=%]F:6QE*3L-"B`@("`@("`@+R\@?7U]#0H-"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T97(M;VYL
M>2==*2D@>PT*("`@("`@("`@("`@:68@*"%`:7-?9&ER*"1D97-T7V1I<BDI
M('L-"B`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YM:T1I<DAI97(H)&1E
M<W1?9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!M:V1I<B`D9&5S=%]D:7(B+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!M:V1I<B`D9&5S=%]D:7(B
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D871T<FEB
M<R`]("1A='1S6R=A='1R:6)S)UT[#0H@("`@("`@('5N<V5T*"1A='1S6R=A
M='1R:6)S)UTI.PT*("`@("`@("`O+R!P<F5T='D@;75C:"!N;W1H:6YG(&AA
M<'!E;G,@:68@=V4@87)E(&]N;'D@<F5G:7-T97)I;F<@=&AE(&EN<W1A;&P-
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;W!T:6]N<ULG<F5G:7-T97(M
M;VYL>2==*2D@>PT*("`@("`@("`@("`@:68@*"%C;W5N="@D871T<RDI('L@
M+R\@;F\@=&%S:W,-"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S
M*"1O<FEG7V9I;&4I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B9FEL92`D;W)I9U]F:6QE(&1O97,@;F]T(&5X
M:7-T(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@A0&-O<'DH)&]R:6=?9FEL92P@
M)&1E<W1?9FEL92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=&\@=W)I=&4@)&1E<W1?9FEL92(L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27TE.4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&-P("1O<FEG7V9I
M;&4@)&1E<W1?9FEL92(I.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<FEB<ULG;60U<W5M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1M
M9#5S=6T@/2!M9#5?9FEL92@D9&5S=%]F:6QE*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!](&5L<V4@>R`O+R!F:6QE('=I=&@@=&%S:W,-
M"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1O<FEG7V9I;&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B9FEL92`D;W)I9U]F:6QE(&1O97,@;F]T(&5X:7-T(BP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?
M24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E
M;G1S)RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@9FEL
M95]G971?8V]N=&5N=',H)&]R:6=?9FEL92D[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH)&]R
M:6=?9FEL92P@(G(B*3L-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S
M(#T@0&9R96%D*"1F<"P@9FEL97-I>F4H)&]R:6=?9FEL92DI.R`O+R!F:6QE
M<VEZ92!C86X@8F4@,`T*("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1C
M;VYT96YT<R`]/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`@("`@)&-O
M;G1E;G1S(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D871T<FEB<ULG;60U<W5M)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1M9#5S=6T@/2!M9#4H)&-O;G1E;G1S*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=',@
M87,@)'1A9R`]/B`D<F%W*2![#0H@("`@("`@("`@("`@("`@("`@("1T86<@
M/2!S=')?<F5P;&%C92@D<&MG+3YG971487-K<TYS*"D@+B`G.B<L("<G+"`D
M=&%G*3L-"B`@("`@("`@("`@("`@("`@("`@)'1A<VL@/2`B4$5!4E]487-K
M7R1T86<B.PT*("`@("`@("`@("`@("`@("`@("`D=&%S:R`]("9N97<@)'1A
M<VLH)'1H:7,M/F-O;F9I9RP@)'1H:7,L(%!%05)?5$%32U])3E-404Q,*3L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&%S:RT^:7-38W)I<'0H*2D@
M>R`O+R!S8W)I<'1S(&%R92!O;FQY(&AA;F1L960@869T97(@:6YS=&%L;&%T
M:6]N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&%S:RT^:6YI="@D<F%W
M+"`D871T<FEB<RP@)'!K9RT^9V5T3&%S=$EN<W1A;&QE9%9E<G-I;VXH*2D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5S(#T@)'1A<VLM/G-T87)T
M4V5S<VEO;B@D<&MG+"`D8V]N=&5N=',L("1F:6YA;%]D97-T7V9I;&4I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97,@/3T](&9A;'-E*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O('-K
M:7`@=&AI<R!F:6QE#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5S.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;G1E;G1S(#T@)')E<SL@+R\@<V%V92!C:&%N9V5S#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'=P(#T@
M0&9O<&5N*"1D97-T7V9I;&4L(")W8B(I.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES7W)E<V]U<F-E*"1W<"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9F%I;&5D('1O(&-R
M96%T92`D9&5S=%]F:6QE.B`D<&AP7V5R<F]R;7-G(BP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TE.
M4U1!3$Q%4E]&04E,140I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AF=W)I=&4H)'=P+"`D8V]N=&5N=',I(#T]
M/2!F86QS92D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")F86EL960@=W)I=&EN9R!T;R`D9&5S=%]F:6QE
M.B`D<&AP7V5R<F]R;7-G(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%27TE.4U1!3$Q%4E]&04E,140I
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&9C;&]S92@D=W`I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("\O('M[>R!C:&5C:R!T:&4@;60U#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&UD-7-U;2DI('L-"B`@("`@("`@("`@("`@("!I
M9B`H<W1R=&]L;W=E<B@D;60U<W5M*2`]/2!S=')T;VQO=V5R*"1A='1R:6)S
M6R=M9#5S=6TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@R+"`B;60U<W5M(&]K.B`D9FEN86Q?9&5S=%]F:6QE(BD[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@9&5L971E('1H92!F:6QE#0H@("`@("`@("`@("`@("`@("`@
M("`@("!`=6YL:6YK*"1D97-T7V9I;&4I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F
M:6QE(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L
M(")W87)N:6YG(#H@8F%D(&UD-7-U;2!F;W(@9FEL92`D9FEN86Q?9&5S=%]F
M:6QE(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@(G=A<FYI;F<@.B!B860@;60U<W5M(&9O<B!F:6QE
M("1F:6YA;%]D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@
M("`@+R\@>WM[('-E="!F:6QE('!E<FUI<W-I;VYS#0H@("`@("`@("`@("!I
M9B`H(4]37U=)3D1/5U,I('L-"B`@("`@("`@("`@("`@("!I9B`H)')O;&4M
M/FES17AE8W5T86)L92@I*2![#0H@("`@("`@("`@("`@("`@("`@("1M;V1E
M(#T@,#<W-R`F('XH:6YT*6]C=&1E8R@D=&AI<RT^8V]N9FEG+3YG970H)W5M
M87-K)RDI.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K
M(&-H;6]D("MX("1D97-T7V9I;&4B*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D;6]D92`](#`V-C8@)B!^*&EN
M="EO8W1D96,H)'1H:7,M/F-O;F9I9RT^9V5T*"=U;6%S:R<I*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I;&5/
M<&5R871I;VXH(F-H;6]D(BP@87)R87DH)&UO9&4L("1D97-T7V9I;&4I*3L-
M"B`@("`@("`@("`@("`@("!I9B`H(4!C:&UO9"@D9&5S=%]F:6QE+"`D;6]D
M92DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO9R@P+"`B9F%I;&5D('1O(&-H86YG92!M;V1E(&]F("1D97-T7V9I;&4B
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O('U]?0T*("`@("`@("`@
M("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH(G)E;F%M92(L(&%R<F%Y*"1D
M97-T7V9I;&4L("1F:6YA;%]D97-T7V9I;&4L("1R;VQE+3YI<T5X=&5N<VEO
M;B@I*2D[#0H@("`@("`@('T-"B`@("`@("`@+R\@4W1O<F4@=&AE(&9U;&P@
M<&%T:"!W:&5R92!T:&4@9FEL92!W87,@:6YS=&%L;&5D(&9O<B!E87-Y('5N
M:6YS=&%L;`T*("`@("`@("`D=&AI<RT^861D1FEL94]P97)A=&EO;B@B:6YS
M=&%L;&5D7V%S(BP@87)R87DH)&9I;&4L("1I;G-T86QL961?87,L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-A=F5?9&5S=&1I<BP@9&ER;F%M
M92AS=6)S='(H)&1E<W1?9FEL92P@<W1R;&5N*"1S879E7V1E<W1D:7(I*2DI
M*3L-"@T*("`@("`@("`O+R1T:&ES+3YL;V<H,BP@(FEN<W1A;&QE9#H@)&1E
M<W1?9FEL92(I.PT*("`@("`@("!R971U<FX@4$5!4E])3E-404Q,15)?3TL[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9$9I;&5/<&5R
M871I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@061D(&$@9FEL92!O<&5R871I
M;VX@=&\@=&AE(&-U<G)E;G0@9FEL92!T<F%N<V%C=&EO;BX-"B`@("`@*@T*
M("`@("`J($!S964@<W1A<G1&:6QE5')A;G-A8W1I;VXH*0T*("`@("`J($!P
M87)A;2!S=')I;F<@)'1Y<&4@5&AI<R!C86X@8F4@;VYE(&]F.@T*("`@("`J
M("`@("T@<F5N86UE.B`@<F5N86UE(&$@9FEL92`H)&1A=&$@:&%S(#,@=F%L
M=65S*0T*("`@("`J("`@("T@8F%C:W5P.B`@8F%C:W5P(&%N(&5X:7-T:6YG
M(&9I;&4@*"1D871A(&AA<R`Q('9A;'5E*0T*("`@("`J("`@("T@<F5M;W9E
M8F%C:W5P.B`@8VQE86X@=7`@8F%C:W5P<R!C<F5A=&5D(&1U<FEN9R!I;G-T
M86QL("@D9&%T82!H87,@,2!V86QU92D-"B`@("`@*B`@("`M(&-H;6]D.B`@
M(&-H86YG92!P97)M:7-S:6]N<R!O;B!A(&9I;&4@*"1D871A(&AA<R`R('9A
M;'5E<RD-"B`@("`@*B`@("`M(&1E;&5T93H@(&1E;&5T92!A(&9I;&4@*"1D
M871A(&AA<R`Q('9A;'5E*0T*("`@("`J("`@("T@<FUD:7(Z("`@9&5L971E
M(&$@9&ER96-T;W)Y(&EF(&5M<'1Y("@D9&%T82!H87,@,2!V86QU92D-"B`@
M("`@*B`@("`M(&EN<W1A;&QE9%]A<SH@;6%R:R!A(&9I;&4@87,@:6YS=&%L
M;&5D("@D9&%T82!H87,@-"!V86QU97,I+@T*("`@("`J($!P87)A;2!A<G)A
M>2`D9&%T82!&;W(@86QL(&9I;&4@;W!E<F%T:6]N<RP@=&AI<R!A<G)A>2!M
M=7-T(&-O;G1A:6X@=&AE#0H@("`@("H@("`@9G5L;"!P871H('1O('1H92!F
M:6QE(&]R(&1I<F5C=&]R>2!T:&%T(&ES(&)E:6YG(&]P97)A=&5D(&]N+B`@
M1F]R#0H@("`@("H@("`@=&AE(')E;F%M92!C;VUM86YD+"!T:&4@9FER<W0@
M<&%R86UE=&5R(&UU<W0@8F4@=&AE(&9I;&4@=&\@<F5N86UE+`T*("`@("`J
M("`@('1H92!S96-O;F0@:71S(&YE=R!N86UE+"!T:&4@=&AI<F0@=VAE=&AE
M<B!T:&ES(&ES(&$@4$A0(&5X=&5N<VEO;BX-"B`@("`@*@T*("`@("`J("`@
M(%1H92!I;G-T86QL961?87,@;W!E<F%T:6]N(&-O;G1A:6YS(#0@96QE;65N
M=',@:6X@=&AI<R!O<F1E<CH-"B`@("`@*B`@("`Q+B!&:6QE;F%M92!A<R!L
M:7-T960@:6X@=&AE(&9I;&5L:7-T(&5L96UE;G0@9G)O;2!P86-K86=E+GAM
M;`T*("`@("`J("`@(#(N($9U;&P@<&%T:"!T;R!T:&4@:6YS=&%L;&5D(&9I
M;&4-"B`@("`@*B`@("`S+B!&=6QL('!A=&@@9G)O;2!T:&4@<&AP7V1I<B!C
M;VYF:6=U<F%T:6]N('9A<FEA8FQE('5S960@:6X@=&AI<PT*("`@("`J("`@
M("`@(&EN<W1A;&QA=&EO;@T*("`@("`J("`@(#0N(%)E;&%T:79E('!A=&@@
M9G)O;2!T:&4@<&AP7V1I<B!T:&%T('1H:7,@9FEL92!I<R!I;G-T86QL960@
M:6X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1&:6QE3W!E<F%T:6]N*"1T
M>7!E+"`D9&%T82D-"B`@("![#0H@("`@("`@(&EF("@A:7-?87)R87DH)&1A
M=&$I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)TEN=&5R;F%L($5R<F]R.B`D9&%T82!I;B!A9&1&:6QE3W!E<F%T:6]N)PT*
M("`@("`@("`@("`@("`@("X@)R!M=7-T(&)E(&%N(&%R<F%Y+"!W87,@)R`N
M(&=E='1Y<&4H)&1A=&$I*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1Y
M<&4@/3T@)V-H;6]D)RD@>PT*("`@("`@("`@("`@)&]C=&UO9&4@/2!D96-O
M8W0H)&1A=&%;,%TI.PT*("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B861D
M:6YG('1O('1R86YS86-T:6]N.B`D='EP92`D;V-T;6]D92`D9&%T85LQ72(I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/FQO9R@S
M+"`B861D:6YG('1O('1R86YS86-T:6]N.B`D='EP92`B("X@:6UP;&]D92@B
M("(L("1D871A*2D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F9I;&5?
M;W!E<F%T:6]N<UM=(#T@87)R87DH)'1Y<&4L("1D871A*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<W1A<G1&:6QE5')A;G-A8W1I;VXH
M*0T*#0H@("`@9G5N8W1I;VX@<W1A<G1&:6QE5')A;G-A8W1I;VXH)')O;&QB
M86-K7VEN7V-A<V4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("AC;W5N
M="@D=&AI<RT^9FEL95]O<&5R871I;VYS*2`F)B`D<F]L;&)A8VM?:6Y?8V%S
M92D@>PT*("`@("`@("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T
M:6]N*"D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F9I;&5?;W!E<F%T
M:6]N<R`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&-O;6UI=$9I;&54<F%N<V%C=&EO;B@I#0H-"B`@("!F=6YC=&EO;B!C
M;VUM:71&:6QE5')A;G-A8W1I;VXH*0T*("`@('L-"B`@("`@("`@)&X@/2!C
M;W5N="@D=&AI<RT^9FEL95]O<&5R871I;VYS*3L-"B`@("`@("`@)'1H:7,M
M/FQO9R@R+"`B86)O=70@=&\@8V]M;6ET("1N(&9I;&4@;W!E<F%T:6]N<R(I
M.PT*("`@("`@("`O+R![>WL@9FER<W0L(&-H96-K('!E<FUI<W-I;VYS(&%N
M9"!S=6-H(&UA;G5A;&QY#0H@("`@("`@("1E<G)O<G,@/2!A<G)A>2@I.PT*
M("`@("`@("!F;W)E86-H("@D=&AI<RT^9FEL95]O<&5R871I;VYS(&%S("1T
M<BD@>PT*("`@("`@("`@("`@;&ES="@D='EP92P@)&1A=&$I(#T@)'1R.PT*
M("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PT*("`@("`@("`@("`@("`@
M(&-A<V4@)W)E;F%M92<Z#0H@("`@("`@("`@("`@("`@("`@(&EF("@A9FEL
M95]E>&ES=',H)&1A=&%;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;W)S6UT@/2`B8V%N;F]T(')E;F%M92!F:6QE("1D871A6S!=+"!D
M;V5S;B=T(&5X:7-T(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`O+R!C:&5C:R!T:&%T(&1E<W0@9&ER+B!I<R!W<FET
M86)L90T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R:71A8FQE*&1I
M<FYA;64H)&1A=&%;,5TI*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&5R<F]R<UM=(#T@(G!E<FUI<W-I;VX@9&5N:65D("@D='EP92DZ("1D871A
M6S%=(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=C:&UO9"<Z#0H@
M("`@("`@("`@("`@("`@("`@("\O(&-H96-K('1H870@9FEL92!I<R!W<FET
M86)L90T*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7W=R:71A8FQE*"1D
M871A6S%=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=
M(#T@(G!E<FUI<W-I;VX@9&5N:65D("@D='EP92DZ("1D871A6S%=("(@+B!D
M96-O8W0H)&1A=&%;,%TI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@
M)V1E;&5T92<Z#0H@("`@("`@("`@("`@("`@("`@(&EF("@A9FEL95]E>&ES
M=',H)&1A=&%;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;&]G*#(L(")W87)N:6YG.B!F:6QE("1D871A6S!=(&1O97-N)W0@97AI
M<W0L(&-A;B=T(&)E(&1E;&5T960B*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`O+R!C:&5C:R!T:&%T(&1I<F5C=&]R
M>2!I<R!W<FET86)L90T*("`@("`@("`@("`@("`@("`@("!I9B`H9FEL95]E
M>&ES=',H)&1A=&%;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7W=R:71A8FQE*&1I<FYA;64H)&1A=&%;,%TI*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E<G)O<G-;72`](")P97)M:7-S:6]N
M(&1E;FEE9"`H)'1Y<&4I.B`D9&%T85LP72([#0H@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&UA:V4@<W5R92!T:&4@9FEL92!T;R!B92!D96QE=&5D(&-A;B!B92!O
M<&5N960@9F]R('=R:71I;F<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9G`@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES7V1I<B@D9&%T85LP72D@)B8@(2@D9G`@/2!`9F]P96XH)&1A=&%;
M,%TL("=A)RDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E<G)O<G-;72`](")P97)M:7-S:6]N(&1E;FEE9"`H)'1Y<&4I.B`D9&%T
M85LP72([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*"1F<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!]#0H-
M"B`@("`@("`@?0T*("`@("`@("`O+R!]?7T-"B`@("`@("`@)&T@/2!S:7IE
M;V8H)&5R<F]R<RD[#0H@("`@("`@(&EF("@D;2`^(#`I('L-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1E<G)O<G,@87,@)&5R<F]R*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-O9G0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`D97)R;W(I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=I9VYO<F4M97)R;W)S)UTI
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&ER=')E92`](&%R
M<F%Y*"D[#0H@("`@("`@("\O('M[>R!R96%L;'D@8V]M;6ET('1H92!T<F%N
M<V%C=&EO;@T*("`@("`@("!F;W)E86-H("@D=&AI<RT^9FEL95]O<&5R871I
M;VYS(&%S("1T<BD@>PT*("`@("`@("`@("`@;&ES="@D='EP92P@)&1A=&$I
M(#T@)'1R.PT*("`@("`@("`@("`@<W=I=&-H("@D='EP92D@>PT*("`@("`@
M("`@("`@("`@(&-A<V4@)V)A8VMU<"<Z#0H@("`@("`@("`@("`@("`@("`@
M($!C;W!Y*"1D871A6S!=+"`D9&%T85LP72`N("<N8F%K)RD[#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,RP@(BL@8F%C:W5P("1D871A6S!=
M('1O("1D871A6S!=+F)A:R(I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!C87-E("=R96UO=F5B86-K=7`G.@T*("`@
M("`@("`@("`@("`@("`@("!`=6YL:6YK*"1D871A6S!=("X@)RYB86LG*3L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!R;2!B86-K
M=7`@;V8@)&1A=&%;,%T@*"1D871A6S!=+F)A:RDB*3L-"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G<F5N86UE
M)SH-"B`@("`@("`@("`@("`@("`@("`@)'1E<W0@/2!`=6YL:6YK*"1D871A
M6S%=*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D=&5S="`F)B!F:6QE
M7V5X:7-T<R@D9&%T85LQ72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D9&%T85LR72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E>'1R82`]("<L('1H:7,@97AT96YS:6]N(&UU<W0@8F4@:6YS=&%L;&5D
M(&UA;G5A;&QY+B`@4F5N86UE('1O("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8F%S96YA;64H)&1A=&%;,5TI("X@)R(G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D97AT<F$@/2`G)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FQO9R@Q+"`G0V]U;&0@;F]T(&1E;&5T92`G
M("X@)&1A=&%;,5T@+B`G+"!C86YN;W0@<F5N86UE("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T85LP72`N("1E>'1R82D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG:6=N;W)E+65R<F]R
M<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!`<F5N86UE*"1D871A
M6S!=+"`D9&%T85LQ72D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL
M;V<H,RP@(BL@;78@)&1A=&%;,%T@)&1A=&%;,5TB*3L-"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G8VAM;V0G
M.@T*("`@("`@("`@("`@("`@("`@("!`8VAM;V0H)&1A=&%;,5TL("1D871A
M6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@)&]C=&UO9&4@/2!D96-O8W0H
M)&1A=&%;,%TI.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L
M("(K(&-H;6]D("1O8W1M;V1E("1D871A6S%=(BD[#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)V1E;&5T92<Z
M#0H@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;,%TI.PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(')M("1D871A6S!=
M(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@(&-A<V4@)W)M9&ER)SH-"B`@("`@("`@("`@("`@("`@("`@0')M9&ER
M*"1D871A6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S
M+"`B*R!R;61I<B`D9&%T85LP72(I.PT*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=I;G-T86QL961?87,G.@T*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;RT^<V5T26YS=&%L
M;&5D07,H)&1A=&%;,%TL("1D871A6S%=*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7V1I<G1R965;9&ER;F%M92@D9&%T85LQ
M72E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D:7)T
M<F5E6V1I<FYA;64H)&1A=&%;,5TI72`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<&MG:6YF;RT^<V5T1&ER=')E92AD:7)N86UE
M*"1D871A6S%=*2D[#0H-"B`@("`@("`@("`@("`@("`@("`@("`@('=H:6QE
M*"%E;7!T>2@D9&%T85LS72D@)B8@)&1A=&%;,UT@(3T@)R\G("8F("1D871A
M6S-=("$]("=<7"<-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("8F
M("1D871A6S-=("$]("<N)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YP:V=I;F9O+3YS971$:7)T<F5E*"1P<"`]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<')E<&5N9%!A=&@H
M)&1A=&%;,UTL("1D871A6S)=*2D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D:7)T<F5E6R1P<%T@/2!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D871A6S-=(#T@9&ER;F%M92@D9&%T85LS
M72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U]#0H@("`@("`@("1T
M:&ES+3YL;V<H,BP@(G-U8V-E<W-F=6QL>2!C;VUM:71T960@)&X@9FEL92!O
M<&5R871I;VYS(BD[#0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO;G,@
M/2!A<G)A>2@I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH
M*0T*#0H@("`@9G5N8W1I;VX@<F]L;&)A8VM&:6QE5')A;G-A8W1I;VXH*0T*
M("`@('L-"B`@("`@("`@)&X@/2!C;W5N="@D=&AI<RT^9FEL95]O<&5R871I
M;VYS*3L-"B`@("`@("`@)'1H:7,M/FQO9R@R+"`B<F]L;&EN9R!B86-K("1N
M(&9I;&4@;W!E<F%T:6]N<R(I.PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M9FEL95]O<&5R871I;VYS(&%S("1T<BD@>PT*("`@("`@("`@("`@;&ES="@D
M='EP92P@)&1A=&$I(#T@)'1R.PT*("`@("`@("`@("`@<W=I=&-H("@D='EP
M92D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)V)A8VMU<"<Z#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D9&%T85LP72`N("<N8F%K
M)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;
M,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@0&-O<'DH)&1A=&%;,%T@
M+B`G+F)A:R<L("1D871A6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YL;V<H,RP@(BL@<F5S=&]R92`D9&%T85LP72!F<F]M("1D871A
M6S!=+F)A:R(I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)W)E;F%M
M92<Z#0H@("`@("`@("`@("`@("`@("`@($!U;FQI;FLH)&1A=&%;,%TI.PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(')M("1D871A
M6S!=(BD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@(&-A<V4@)VUK9&ER)SH-"B`@("`@("`@("`@("`@("`@("`@0')M
M9&ER*"1D871A6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@S+"`B*R!R;61I<B`D9&%T85LP72(I.PT*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("=C:&UO9"<Z#0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@
M)V1E;&5T92<Z#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@("`@(&-A<V4@)VEN<W1A;&QE9%]A<R<Z#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YP:V=I;F9O+3YS971);G-T86QL961!<R@D9&%T85LP
M72P@9F%L<V4I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^<&MG:6YF;RT^
M<F5S971$:7)T<F5E*"D[#0H@("`@("`@("1T:&ES+3YF:6QE7V]P97)A=&EO
M;G,@/2!A<G)A>2@I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!M:T1I<DAI97(H)&1I<BD-"@T*("`@(&9U;F-T:6]N(&UK1&ER2&EE<B@D
M9&ER*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F%D9$9I;&5/<&5R871I;VXH
M)VUK9&ER)RP@87)R87DH)&1I<BDI.PT*("`@("`@("!R971U<FX@<&%R96YT
M.CIM:T1I<DAI97(H)&1I<BD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&1O=VYL;V%D*"D-"@T*("`@("\J*@T*("`@("`J($1O=VYL;V%D
M(&%N>2!F:6QE<R!A;F0@=&AE:7(@9&5P96YD96YC:65S+"!I9B!N96-E<W-A
M<GD-"B`@("`@*@T*("`@("`J($!P87)A;2!A<G)A>2!A(&UI>&5D(&QI<W0@
M;V8@<&%C:V%G92!N86UE<RP@;&]C86P@9FEL97,L(&]R('!A8VMA9V4N>&UL
M#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&]P=&EO;G,@9G)O;2!T:&4@8V]M;6%N9"!L:6YE#0H@("`@("H@0'!A
M<F%M(&%R<F%Y('1H:7,@:7,@=&AE(&%R<F%Y('1H870@=VEL;"!B92!P;W!U
M;&%T960@=VET:"!P86-K86=E<R!T;PT*("`@("`J("`@("`@("`@("`@("!I
M;G-T86QL+B`@1F]R;6%T(&]F(&5A8V@@96YT<GDZ#0H@("`@("H-"B`@("`@
M*B`\8V]D93X-"B`@("`@*B!A<G)A>2@G<&MG)R`]/B`G<&%C:V%G95]N86UE
M)RP@)V9I;&4G(#T^("<O<&%T:"]T;R]L;V-A;"]F:6QE)RP-"B`@("`@*B`@
M("`G:6YF;R<@/3X@87)R87DH*2`O+R!P87)S960@<&%C:V%G92YX;6P-"B`@
M("`@*B`I.PT*("`@("`J(#PO8V]D93X-"B`@("`@*B!`<&%R86T@87)R87D@
M=&AI<R!W:6QL(&)E('!O<'5L871E9"!W:71H(&%N>2!E<G)O<B!M97-S86=E
M<PT*("`@("`J($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO;B!V87)I
M86)L90T*("`@("`J($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO;B!V
M87)I86)L90T*("`@("`J($!P87)A;2!F86QS92!P<FEV871E(')E8W5R<VEO
M;B!V87)I86)L90T*("`@("`J($!D97!R96-A=&5D(&EN(&9A=F]R(&]F(%!%
M05)?1&]W;FQO861E<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&1O=VYL;V%D
M*"1P86-K86=E<RP@)&]P=&EO;G,L("8D8V]N9FEG+"`F)&EN<W1A;&QP86-K
M86=E<RP-"B`@("`@("`@("`@("`@("`@("`@("`F)&5R<F]R<RP@)&EN<W1A
M;&QE9"`](&9A;'-E+"`D=VEL;&EN<W1A;&P@/2!F86QS92P@)'-T871E(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("`O+R!T<FEC:VEN97-S.B!I;FET:6%L
M:7IE(&AE<F4-"B`@("`@("`@<&%R96YT.CI014%27T1O=VYL;V%D97(H)'1H
M:7,M/G5I+"`D;W!T:6]N<RP@)&-O;F9I9RD[#0H@("`@("`@("1R970@/2!P
M87)E;G0Z.F1O=VYL;V%D*"1P86-K86=E<RD[#0H@("`@("`@("1E<G)O<G,@
M/2`D=&AI<RT^9V5T17)R;W)-<V=S*"D[#0H@("`@("`@("1I;G-T86QL<&%C
M:V%G97,@/2`D=&AI<RT^9V5T1&]W;FQO861E9%!A8VMA9V5S*"D[#0H@("`@
M("`@('1R:6=G97)?97)R;W(H(E!%05(@5V%R;FEN9SH@4$5!4E]);G-T86QL
M97(Z.F1O=VYL;V%D*"D@:7,@9&5P<F5C871E9"`B("X-"B`@("`@("`@("`@
M("`@("`@("`@("`B:6X@9F%V;W(@;V8@4$5!4E]$;W=N;&]A9&5R(&-L87-S
M(BP@15]54T527U=!4DY)3D<I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!A<G-E4&%C:V%G95AM
M;"@I#0H-"B`@("!F=6YC=&EO;B!?<&%R<V5086-K86=E6&UL*"8D9&5S8V9I
M;&4L("8D=&UP9&ER*0T*("`@('L-"B`@("`@("`@:68@*'-U8G-T<B@D9&5S
M8V9I;&4L("TT*2`]/2`G+GAM;"<I('L-"B`@("`@("`@("`@("1T;7!D:7(@
M/2!F86QS93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O('M[
M>R!$96-O;7!R97-S('!A8VL@:6X@=&UP(&1I<B`M+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM#0H-"B`@("`@("`@("`@("\O(%1O(&%L
M;&]W(')E;&%T:79E('!A8VMA9V4@9FEL92!N86UE<PT*("`@("`@("`@("`@
M)&1E<V-F:6QE(#T@<F5A;'!A=&@H)&1E<V-F:6QE*3L-"@T*("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP
M*"<M9"<I*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&UP9&ER.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`G*R!T
M;7`@9&ER(&-R96%T960@870@)R`N("1T;7!D:7(I.PT*("`@("`@("`@("`@
M+R\@?7U]#0H@("`@("`@('T-"B`@("`@("`@+R\@4&%R<V4@>&UL(&9I;&4@
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2T-"B`@("`@("`@)'!K9R`](&YE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES
M+3YC;VYF:6<L("1T:&ES+3YD96)U9RP@)'1M<&1I<BD[#0H@("`@("`@(%!%
M05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@)'`@/2`F)'!K9RT^9G)O;4%N>49I;&4H)&1E<V-F:6QE
M+"!014%27U9!3$E$051%7TE.4U1!3$Q)3D<I.PT*("`@("`@("!014%2.CIS
M=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1P*2D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P+3YG
M9715<V5R26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P
M+3YG9715<V5R26YF;R@I(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&QO9VQE=F5L(#T@)&5R<ELG;&5V96PG72`]/2`G97)R;W(G(#\@,"`Z
M(#$[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^;&]G*"1L;V=L979E;"P@=6-F:7)S="@D97)R6R=L979E;"==*2`N
M("<Z("<@+B`D97)R6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);G-T86QL871I;VX@
M9F%I;&5D.B!I;G9A;&ED('!A8VMA9V4@9FEL92<I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&1E<V-F:6QE(#T@)'`M/F=E=%!A8VMA9V5&
M:6QE*"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\J*@T*("`@("`J(%-E="!T:&4@;&ES="!O
M9B!014%27T1O=VYL;V%D97)?4&%C:V%G92!O8FIE8W1S('1O(&%L;&]W(&UO
M<F4@<V%N90T*("`@("`J(&1E<&5N9&5N8WD@=F%L:61A=&EO;@T*("`@("`J
M($!P87)A;2!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$1O=VYL
M;V%D961086-K86=E<R@F)'!K9W,I#0H@("`@>PT*("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("1E<G(@/2`D=&AI<RT^86YA;'EZ941E<&5N9&5N8VEE<R@D<&MG<RD[#0H@
M("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M97)R.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&]W;FQO861E9%!A
M8VMA9V5S(#T@)B1P:V=S.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-E
M="!T:&4@;&ES="!O9B!014%27T1O=VYL;V%D97)?4&%C:V%G92!O8FIE8W1S
M('1O(&%L;&]W(&UO<F4@<V%N90T*("`@("`J(&1E<&5N9&5N8WD@=F%L:61A
M=&EO;@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T
M:6]N('-E=%5N:6YS=&%L;%!A8VMA9V5S*"8D<&MG<RD-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E9%!A8VMA9V5S(#T@)B1P:V=S.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=$EN<W1A;&Q086-K86=E<R@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,[
M#0H@("`@?0T*#0H@("`@+R\@>WM[(&EN<W1A;&PH*0T*#0H@("`@+RHJ#0H@
M("`@("H@26YS=&%L;',@=&AE(&9I;&5S('=I=&AI;B!T:&4@<&%C:V%G92!F
M:6QE('-P96-I9FEE9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F=\
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V4@)'!K9V9I;&4@<&%T:"!T;R!T:&4@
M<&%C:V%G92!F:6QE+`T*("`@("`J("`@("`@("!O<B!A('!R92UI;FET:6%L
M:7IE9"!P86-K86=E9FEL92!O8FIE8W0-"B`@("`@*B!`<&%R86T@87)R87D@
M)&]P=&EO;G,-"B`@("`@*B!R96-O9VYI>F5D(&]P=&EO;G,Z#0H@("`@("H@
M+2!I;G-T86QL<F]O="`@(#H@;W!T:6]N86P@<')E9FEX(&1I<F5C=&]R>2!F
M;W(@:6YS=&%L;&%T:6]N#0H@("`@("H@+2!F;W)C92`@("`@("`@(#H@9F]R
M8V4@:6YS=&%L;&%T:6]N#0H@("`@("H@+2!R96=I<W1E<BUO;FQY(#H@=7!D
M871E(')E9VES=')Y(&)U="!D;VXG="!I;G-T86QL(&9I;&5S#0H@("`@("H@
M+2!U<&=R861E("`@("`@(#H@=7!G<F%D92!E>&ES=&EN9R!I;G-T86QL#0H@
M("`@("H@+2!S;V9T("`@("`@("`@(#H@9F%I;"!S:6QE;G1L>0T*("`@("`J
M("T@;F]D97!S("`@("`@("`Z(&EG;F]R92!D97!E;F1E;F-Y(&-O;F9L:6-T
M<R]M:7-S:6YG(&1E<&5N9&5N8VEE<PT*("`@("`J("T@86QL9&5P<R`@("`@
M("`Z(&EN<W1A;&P@86QL(&1E<&5N9&5N8VEE<PT*("`@("`J("T@;VYL>7)E
M<61E<',@("`Z(&EN<W1A;&P@;VYL>2!R97%U:7)E9"!D97!E;F1E;F-I97,-
M"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O<B!P86-K
M86=E(&EN9F\@:68@<W5C8V5S<V9U;`T*("`@("`J+PT*#0H@("`@9G5N8W1I
M;VX@:6YS=&%L;"@D<&MG9FEL92P@)&]P=&EO;G,@/2!A<G)A>2@I*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@("`@
M("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG9FEL92DI('L-
M"B`@("`@("`@("`@("1D;'!K9R`]("8D<&MG9FEL93L-"B`@("`@("`@("`@
M("1P:V<@/2`D<&MG9FEL92T^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@
M("`@("1P:V=F:6QE(#T@)'!K9RT^9V5T07)C:&EV949I;&4H*3L-"B`@("`@
M("`@("`@("1D97-C9FEL92`]("1P:V<M/F=E=%!A8VMA9V5&:6QE*"D[#0H@
M("`@("`@("`@("`D=&UP9&ER(#T@9&ER;F%M92@D9&5S8V9I;&4I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E<V-F:6QE(#T@)'!K9V9I
M;&4[#0H@("`@("`@("`@("`D=&UP9&ER(#T@)R<[#0H@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<&MG(#T@)B1T:&ES+3Y?<&%R<V5086-K86=E
M6&UL*"1D97-C9FEL92P@)'1M<&1I<BDI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1P:V<[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@
M("`@("!I9B`H<F5A;'!A=&@H)&1E<V-F:6QE*2`A/2!R96%L<&%T:"@D<&MG
M9FEL92DI('L-"B`@("`@("`@("`@("1T87(@/2!N97<@07)C:&EV95]487(H
M)'!K9V9I;&4I.PT*("`@("`@("`@("`@:68@*"%`)'1A<BT^97AT<F%C="@D
M=&UP9&ER*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B=6YA8FQE('1O('5N<&%C:R`D<&MG9FEL92(I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@)'!K9VYA;64@/2`D<&MG
M+3YG971.86UE*"D[#0H@("`@("`@("1C:&%N;F5L(#T@)'!K9RT^9V5T0VAA
M;FYE;"@I.PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS6R=P
M86-K86=I;F=R;V]T)UTI*2![#0H@("`@("`@("`@("`D<&%C:W)O;W1P:'!?
M9&ER(#T@)'1H:7,M/E]P<F5P96YD4&%T:"@-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D:7(G+"!N=6QL+"`D8VAA;FYE;"DL
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I;F=R
M;V]T)UTI.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=I;G-T86QL<F]O="==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O
M;F9I9RT^<V5T26YS=&%L;%)O;W0H)&]P=&EO;G-;)VEN<W1A;&QR;V]T)UTI
M.PT*("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^8V]N
M9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@)&EN<W1A;&QR96=I
M<W1R>2`]("8D=&AI<RT^7W)E9VES=')Y.PT*("`@("`@("`@("`@)'1H:7,M
M/FEN<W1A;&QR;V]T(#T@)R<[("\O(&%L;"!D;VYE(&%U=&]M86=I8V%L;'D@
M;F]W#0H@("`@("`@("`@("`D<&AP7V1I<B`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G<&AP7V1I<B<L(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E=$EN<W1A;&Q2;V]T
M*&9A;'-E*3L-"B`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H
M:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)W!A8VMA9VEN9W)O;W0G72DI('L-"B`@
M("`@("`@("`@("`@("`D:6YS=&%L;')E9VES=')Y(#T@)FYE=R!014%27U)E
M9VES=')Y*"1P86-K<F]O='!H<%]D:7(I.PT*("`@("`@("`@("`@("`@("1P
M:'!?9&ER(#T@)'!A8VMR;V]T<&AP7V1I<CL-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)&EN<W1A;&QR96=I<W1R>2`]("8D=&AI
M<RT^7W)E9VES=')Y.PT*("`@("`@("`@("`@("`@("1P:'!?9&ER(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@)&-H86YN96PI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QR;V]T
M(#T@)R<[#0H@("`@("`@('T-"@T*("`@("`@("`O+R![>WL@8VAE8VMS('1O
M(&1O('=H96X@;F]T(&EN(")F;W)C92(@;6]D90T*("`@("`@("!I9B`H96UP
M='DH)&]P=&EO;G-;)V9O<F-E)UTI("8F($!I<U]D:7(H)'1H:7,M/F-O;F9I
M9RT^9V5T*"=P:'!?9&ER)RDI*2![#0H@("`@("`@("`@("`D=&5S='`@/2`D
M8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)R`_("1P:V=N86UE(#H@87)R87DH
M)&-H86YN96PL("1P:V=N86UE*3L-"B`@("`@("`@("`@("1I;G-T9FEL96QI
M<W0@/2`D<&MG+3YG971);G-T86QL871I;VY&:6QE3&ES="AT<G5E*3L-"B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;G-T9FEL96QI<W0I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1I;G-T9FEL96QI<W0[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T
M<GDM/F-H96-K1FEL94UA<"@D:6YS=&9I;&5L:7-T+"`D=&5S='`L("<Q+C$G
M*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T97-T*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&5S=#L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AS:7IE;V8H)'1E<W0I*2![#0H@("`@("`@("`@
M("`@("`@)'!K9W,@/2`D=&AI<RT^9V5T26YS=&%L;%!A8VMA9V5S*"D[#0H@
M("`@("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!K9W,@87,@)'!A<F%M*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D<&MG+3YI<U-U8G!A8VMA9V5/9B@D<&%R86TI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1F
M;W5N9"D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!S=6)P86-K86=E<R!C
M86X@8V]N9FQI8W0@=VET:"!E87)L:65R('9E<G-I;VYS(&]F('!A<F5N="!P
M86-K86=E<PT*("`@("`@("`@("`@("`@("`@("`D<&%R96YT<F5G(#T@)&EN
M<W1A;&QR96=I<W1R>2T^<&%C:V%G94EN9F\H)'!A<F%M+3YG971086-K86=E
M*"DL(&YU;&PL("1P87)A;2T^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@
M("`@("`@("`@)'1M<"`]("1T97-T.PT*("`@("`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=&UP(&%S("1F:6QE(#T^("1I;F9O*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)&EN9F\I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN9F];,5TI
M(#T]('-T<G1O;&]W97(H)'!A<F%M+3YG971086-K86=E*"DI("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D:6YF
M;ULP72D@/3T@<W1R=&]L;W=E<B@D<&%R86TM/F=E=$-H86YN96PH*2DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1E<W1;
M)&9I;&5=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'!A<F5N=')E9ULG9FEL96QI<W0G75LD9FEL95TI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T
M<G1O;&]W97(H)'!A<F%M+3YG971#:&%N;F5L*"DI("$]("=P96%R+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;RD@/3T@
M<W1R=&]L;W=E<B@D<&%R86TM/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1E<W1;)&9I;&5=*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!A<F5N
M=')E9ULG9FEL96QI<W0G75LD9FEL95TI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<&9K(#T@
M)FYE=R!014%27U!A8VMA9V5&:6QE*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@
M("`@("`@("`@("`@("`D<&%R96YT<&MG(#T@)B1P9FLM/F9R;VU!<G)A>2@D
M<&%R96YT<F5G*3L-"B`@("`@("`@("`@("`@("`@("`@)&EN<W1A;&QR96=I
M<W1R>2T^=7!D871E4&%C:V%G93(H)'!A<F5N='!K9RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<&%R86TM/F=E=$-H86YN
M96PH*2`]/2`G<&5C;"YP:'`N;F5T)R`F)B!I<W-E="@D;W!T:6]N<ULG=7!G
M<F%D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&UP(#T@)'1E<W0[
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T;7`@87,@)&9I;&4@
M/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]S
M=')I;F<H)&EN9F\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@<&5A<BYP:'`N;F5T('!A8VMA9V5S(&%R92!A;'=A>7,@<W1O<F5D(&%S
M('-T<FEN9W,-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M=&]L;W=E<B@D:6YF;RD@/3T@<W1R=&]L;W=E<B@D<&%R86TM/F=E=%!A8VMA
M9V4H*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=7!G<F%D:6YG(&5X:7-T:6YG('!A8VMA9V4-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=6YS970H)'1E<W1;)&9I;&5=*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D=&5S="DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&US9R`]("(D8VAA;FYE;"\D<&MG;F%M93H@8V]N
M9FQI8W1I;F<@9FEL97,@9F]U;F0Z7&XB.PT*("`@("`@("`@("`@("`@("`@
M("`D;&]N9V5S="`](&UA>"AA<G)A>5]M87`H(G-T<FQE;B(L(&%R<F%Y7VME
M>7,H)'1E<W0I*2D[#0H@("`@("`@("`@("`@("`@("`@("1F;70@/2`B)21[
M;&]N9V5S='US("@E<RE<;B([#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1T97-T(&%S("1F:6QE(#T^("1I;F9O*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I;F9O*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O(#T@87)R87DH)W!E87(N<&AP+FYE
M="<L("1I;F9O*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O(#T@)&EN9F];,%T@+B`G+R<@+B`D
M:6YF;ULQ73L-"B`@("`@("`@("`@("`@("`@("`@("`@("1M<V<@+CT@<W!R
M:6YT9B@D9FUT+"`D9FEL92P@)&EN9F\I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;
M)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D;7-G*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")705).24Y'.B`D;7-G(BD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@+R\@?7U]#0H-"B`@("`@("`@)'1H:7,M/G-T87)T
M1FEL951R86YS86-T:6]N*"D[#0H-"B`@("`@("`@:68@*&5M<'1Y*"1O<'1I
M;VYS6R=U<&=R861E)UTI("8F(&5M<'1Y*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`O+R!C:&5C:W,@=&\@9&\@;VYL>2!W:&5N(&EN<W1A
M;&QI;F<@;F5W('!A8VMA9V5S#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@
M/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`D=&5S="`]
M("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L("1C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!I9B`H(21T97-T*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C
M:V%G945X:7-T<R@D<&MG;F%M92P@)W!E87(N<&AP+FYE="<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S
M*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H96UP='DH)&]P=&EO;G-;)V9O<F-E)UTI("8F("1T97-T*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D
M8VAA;FYE;"\D<&MG;F%M92!I<R!A;')E861Y(&EN<W1A;&QE9"(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'5S
M96-H86YN96P@/2`D8VAA;FYE;#L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE
M;"`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("1T97-T
M(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@
M)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("@A)'1E<W0I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP
M86-K86=E17AI<W1S*"1P:V=N86UE+"`G<&5A<BYP:'`N;F5T)RD[#0H@("`@
M("`@("`@("`@("`@("`@("1U<V5C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA
M9V5%>&ES=',H)'!K9VYA;64L("1C:&%N;F5L*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D=&5S="D@>PT*("`@("`@("`@("`@("`@("1V
M,2`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P:V=N86UE+"`G
M=F5R<VEO;B<L("1U<V5C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`D=C(@
M/2`D<&MG+3YG971697)S:6]N*"D[#0H@("`@("`@("`@("`@("`@)&-M<"`]
M('9E<G-I;VY?8V]M<&%R92@B)'8Q(BP@(B1V,B(L("=G="<I.PT*("`@("`@
M("`@("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9F]R8V4G72D@)B8@(79E
M<G-I;VY?8V]M<&%R92@B)'8R(BP@(B1V,2(L("=G="<I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=7!G<F%D
M92!T;R!A(&YE=V5R('9E<G-I;VX@*"1V,B!I<R!N;W0@;F5W97(@=&AA;B`D
M=C$I(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("AE;7!T>2@D;W!T:6]N<ULG<F5G:7-T97(M;VYL>2==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`O+R!W:&5N('5P9W)A9&EN9RP@<F5M;W9E(&]L9"!R
M96QE87-E)W,@9FEL97,@9FER<W0Z#0H@("`@("`@("`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1E<G(@/2`D=&AI<RT^7V1E;&5T95!A8VMA9V5&
M:6QE<R@D<&MG;F%M92P@)'5S96-H86YN96PL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@('1R=64I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG:6=N;W)E+65R<F]R<R==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D97)R*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T
M:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^;&]G*#`L("=705).24Y'.B`G("X@)&5R<BT^9V5T365S
M<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8F%C:V5D=7`@/2`D
M97)R.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@>WM[
M($-O<'D@9FEL97,@=&\@9&5S="!D:7(@+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM#0H-"B`@("`@("`@+R\@:6YF;R!F<F]M('1H
M92!P86-K86=E(&ET('-E;&8@=V4@=V%N="!T;R!A8V-E<W,@9G)O;2!?:6YS
M=&%L;$9I;&4-"B`@("`@("`@)'1H:7,M/G!K9VEN9F\@/2`F)'!K9SL-"B`@
M("`@("`@+R\@=7-E9"!T;R!D971E<FUI;F4@=VAE=&AE<B!W92!S:&]U;&0@
M8G5I;&0@86YY($,@8V]D90T*("`@("`@("`D=&AI<RT^<V]U<F-E7V9I;&5S
M(#T@,#L-"@T*("`@("`@("`D<V%V96-H86YN96P@/2`D=&AI<RT^8V]N9FEG
M+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("!I9B`H96UP='DH
M)&]P=&EO;G-;)W)E9VES=&5R+6]N;'DG72D@)B8@(6ES7V1I<B@D<&AP7V1I
M<BDI('L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*%-Y<W1E;3HZ
M;6MD:7(H87)R87DH)RUP)RDL("1P:'!?9&ER*2DI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(FYO(&EN<W1A;&QA=&EO
M;B!D97-T:6YA=&EO;B!D:7)E8W1O<GD@)R1P:'!?9&ER)UQN(BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`D=&UP7W!A=&@@/2!D
M:7)N86UE*"1D97-C9FEL92D[#0H@("`@("`@(&EF("AS=6)S='(H)'!K9V9I
M;&4L("TT*2`A/2`G+GAM;"<I('L-"B`@("`@("`@("`@("1T;7!?<&%T:"`N
M/2!$25)%0U1/4EE?4T5005)!5$]2("X@)'!K9VYA;64@+B`G+2<@+B`D<&MG
M+3YG971697)S:6]N*"D[#0H@("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^
M8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@
M("`@("\O('M[>R!I;G-T86QL(&9I;&5S#0H@("`@("`@(`T*("`@("`@("!I
M9B`H)'!K9RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@>PT*
M("`@("`@("`@("`@)&9I;&5L:7-T(#T@)'!K9RT^9V5T26YS=&%L;&%T:6]N
M1FEL96QI<W0H*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1F
M:6QE;&ES="`]("1P:V<M/F=E=$9I;&5,:7-T*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I;&5L:7-T*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1F:6QE;&ES=#L-"B`@("`@("`@?0T*("`@("`@("`D
M<&MG+3YR97-E=$9I;&5L:7-T*"D[#0H@("`@("`@("1P:V<M/G-E=$QA<W1)
M;G-T86QL961697)S:6]N*"1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5);F9O
M*"1P:V<M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("=V97)S:6]N)RP@
M)'!K9RT^9V5T0VAA;FYE;"@I*2D[#0H@("`@("`@(&9O<F5A8V@@*"1F:6QE
M;&ES="!A<R`D9FEL92`]/B`D871T<RD@>PT*("`@("`@("`@("`@:68@*"1P
M:V<M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^97AP96-T17)R;W(H4$5!4E])3E-404Q,15)?
M1D%)3$5$*3L-"B`@("`@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/E]I;G-T
M86QL1FEL92@D9FEL92P@)&%T=',L("1T;7!?<&%T:"P@)&]P=&EO;G,I.PT*
M("`@("`@("`@("`@("`@("1T:&ES+3YP;W!%>'!E8W0H*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F5X<&5C=$5R
M<F]R*%!%05)?24Y35$%,3$527T9!24Q%1"D[#0H@("`@("`@("`@("`@("`@
M)')E<R`]("1T:&ES+3Y?:6YS=&%L;$9I;&4R*"1P:V<L("1F:6QE+"`D871T
M<RP@)'1M<%]P871H+"`D;W!T:6]N<RD[#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/G!O<$5X<&5C="@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)')E<RDI('L-"B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G)O;&QB86-K1FEL951R86YS86-T:6]N
M*"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S+3YG971-97-S86=E
M*"D@/3T@(F9I;&4@9&]E<R!N;W0@97AI<W0B*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92`D9FEL92!I;B!P
M86-K86=E+GAM;"!D;V5S(&YO="!E>&ES="(I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D<F5S*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L(")7
M87)N:6YG.B`B("X@)')E<RT^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@D<F5S(#T](%!%05)?24Y35$%,3$527T]+*2![
M#0H@("`@("`@("`@("`@("`@+R\@4F5G:7-T97(@9FEL97,@=&AA="!W97)E
M(&EN<W1A;&QE9`T*("`@("`@("`@("`@("`@("1P:V<M/FEN<W1A;&QE9$9I
M;&4H)&9I;&4L("1A='1S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`O+R!]?7T-"@T*("`@("`@("`O+R![>WL@8V]M<&EL92!A;F0@
M:6YS=&%L;"!S;W5R8V4@9FEL97,-"B`@("`@("`@:68@*"1T:&ES+3YS;W5R
M8V5?9FEL97,@/B`P("8F(&5M<'1Y*"1O<'1I;VYS6R=N;V)U:6QD)UTI*2![
M#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T-"B`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?8V]M<&EL95-O=7)C949I;&5S*"1S879E
M8VAA;FYE;"P@)'!K9RDI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E
M<G([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U]
M#0H-"B`@("`@("`@:68@*&ES<V5T*"1B86-K961U<"DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<F5M;W9E0F%C:W5P<R@D8F%C:V5D=7`I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A)'1H:7,M/F-O;6UI=$9I;&54<F%N<V%C=&EO
M;B@I*2![#0H@("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A
M8W1I;VXH*3L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U
M;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O;6UI="!F86EL960B+"!014%27TE.
M4U1!3$Q%4E]&04E,140I.PT*("`@("`@("!]#0H@("`@("`@("\O('U]?0T*
M#0H@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@)&EN<W1A;&QP:&%S
M92`]("=I;G-T86QL)SL-"B`@("`@("`@)&]L9'9E<G-I;VX@/2!F86QS93L-
M"B`@("`@("`@+R\@>WM[(%)E9VES=&5R('1H870@=&AE('!A8VMA9V4@:7,@
M:6YS=&%L;&5D("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM#0H@("`@("`@(&EF
M("AE;7!T>2@D;W!T:6]N<ULG=7!G<F%D92==*2D@>PT*("`@("`@("`@("`@
M+R\@:68@)V9O<F-E)R!I<R!U<V5D+"!R97!L86-E('1H92!I;F9O(&EN(')E
M9VES=')Y#0H@("`@("`@("`@("`D=7-E8VAA;FYE;"`]("1C:&%N;F5L.PT*
M("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L+G!H<"YN970G*2![
M#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS=&%L;')E9VES=')Y+3YP
M86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE;"D[#0H@("`@("`@("`@
M("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@("`D=&5S
M="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!K9VYA;64L
M("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("`@("`@)'5S96-H
M86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T97-T(#T@
M)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D<&MG;F%M92P@)&-H
M86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D;W!T:6]N<ULG9F]R8V4G72D@)B8@)'1E<W0I('L-"B`@("`@("`@("`@
M("`@("`D;VQD=F5R<VEO;B`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5)
M;F9O*"1P:V=N86UE+"`G=F5R<VEO;B<L("1U<V5C:&%N;F5L*3L-"B`@("`@
M("`@("`@("`@("`D:6YS=&%L;')E9VES=')Y+3YD96QE=&5086-K86=E*"1P
M:V=N86UE+"`D=7-E8VAA;FYE;"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D<F5T(#T@)&EN<W1A;&QR96=I<W1R>2T^861D4&%C:V%G93(H)'!K
M9RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=7-E8VAA;FYE
M;"`]("1C:&%N;F5L.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P
M96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@)'1E<W0@/2`D:6YS
M=&%L;')E9VES=')Y+3YP86-K86=E17AI<W1S*"1P:V=N86UE+"`D8VAA;FYE
M;"D[#0H@("`@("`@("`@("`@("`@:68@*"$D=&5S="D@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&5S="`]("1I;G-T86QL<F5G:7-T<GDM/G!A8VMA9V5%
M>&ES=',H)'!K9VYA;64L("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@
M("`@("`@("`@)'5S96-H86YN96P@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1T97-T(#T@)&EN<W1A;&QR96=I<W1R>2T^<&%C:V%G945X:7-T
M<R@D<&MG;F%M92P@)&-H86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@+R\@;F5W.B!U<&=R861E(&EN<W1A;&QS(&$@<&%C:V%G92!I9B!I
M="!I<VXG="!I;G-T86QL960-"B`@("`@("`@("`@(&EF("@A)'1E<W0I('L-
M"B`@("`@("`@("`@("`@("`D<F5T(#T@)&EN<W1A;&QR96=I<W1R>2T^861D
M4&%C:V%G93(H)'!K9RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(&EF("@D=7-E8VAA;FYE;"`A/2`D8VAA;FYE;"D@>PT*("`@
M("`@("`@("`@("`@("`@("`D:6YS=&%L;')E9VES=')Y+3YD96QE=&5086-K
M86=E*"1P:V=N86UE+"`D=7-E8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@
M("`@("1R970@/2`D:6YS=&%L;')E9VES=')Y+3YA9&1086-K86=E,B@D<&MG
M*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5T(#T@)&EN<W1A;&QR96=I<W1R>2T^=7!D871E4&%C:V%G93(H
M)'!K9RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I
M;G-T86QL<&AA<V4@/2`G=7!G<F%D92<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"$D<F5T*2![#0H@("`@("`@("`@("`D=&AI
M<RT^8V]N9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI
M.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")!9&1I
M;F<@<&%C:V%G92`D8VAA;FYE;"\D<&MG;F%M92!T;R!R96=I<W1R>2!F86EL
M960B*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!]?7T-"B`@("`@("`@)'1H
M:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L
M*3L-"B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@G4$5!4E]487-K7T-O;6UO
M;B<I*2![("\O('1H:7,@:7,@875T;RUI;F-L=61E9"!I9B!A;GD@=&%S:W,@
M97AI<W0-"B`@("`@("`@("`@(&EF("A014%27U1A<VM?0V]M;6]N.CIH87-0
M;W-T:6YS=&%L;%1A<VMS*"DI('L-"B`@("`@("`@("`@("`@("!014%27U1A
M<VM?0V]M;6]N.CIR=6Y0;W-T:6YS=&%L;%1A<VMS*"1I;G-T86QL<&AA<V4I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M<&MG+3YT;T%R<F%Y*'1R=64I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(%]C;VUP:6QE4V]U<F-E1FEL97,H*0T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E
M1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V-O;7!I;&53;W5R8V5&:6QE<R@D<V%V96-H86YN96PL("8D9FEL
M96QI<W0I#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0G5I
M;&1E<BYP:'`G.PT*("`@("`@("`D=&AI<RT^;&]G*#$L("(D=&AI<RT^<V]U
M<F-E7V9I;&5S('-O=7)C92!F:6QE<RP@8G5I;&1I;F<B*3L-"B`@("`@("`@
M)&)O8B`]("9N97<@4$5!4E]"=6EL9&5R*"1T:&ES+3YU:2D[#0H@("`@("`@
M("1B;V(M/F1E8G5G(#T@)'1H:7,M/F1E8G5G.PT*("`@("`@("`D8G5I;'0@
M/2`D8F]B+3YB=6EL9"@D9FEL96QI<W0L(&%R<F%Y*"8D=&AI<RP@)U]B=6EL
M9$-A;&QB86-K)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8G5I
M;'0I*2![#0H@("`@("`@("`@("`D=&AI<RT^<F]L;&)A8VM&:6QE5')A;G-A
M8W1I;VXH*3L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U
M;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U
M<FX@)&)U:6QT.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YL;V<H,2P@
M(EQN0G5I;&0@<')O8V5S<R!C;VUP;&5T960@<W5C8V5S<V9U;&QY(BD[#0H@
M("`@("`@(&9O<F5A8V@@*"1B=6EL="!A<R`D97AT*2![#0H@("`@("`@("`@
M("`D8FX@/2!B87-E;F%M92@D97AT6R=F:6QE)UTI.PT*("`@("`@("`@("`@
M;&ES="@D7V5X=%]N86UE+"`D7V5X=%]S=69F*2`](&5X<&QO9&4H)RXG+"`D
M8FXI.PT*("`@("`@("`@("`@:68@*"1?97AT7W-U9F8@/3T@)RYS;R<@?'P@
M)%]E>'1?<W5F9B`]/2`G+F1L;"<I('L-"B`@("`@("`@("`@("`@("!I9B`H
M97AT96YS:6]N7VQO861E9"@D7V5X=%]N86UE*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B17AT96YS:6]N("<D7V5X=%]N
M86UE)R!A;')E861Y(&QO861E9"X@(B`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=0;&5A<V4@=6YL;V%D(&ET(&EN('EO=7(@
M<&AP+FEN:2!F:6QE("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<')I;W(@=&\@:6YS=&%L;"!O<B!U<&=R861E)RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R;VQE(#T@)V5X
M="<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1R
M;VQE(#T@)W-R8R<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9&5S
M="`]("1E>'1;)V1E<W0G73L-"B`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@
M(DEN<W1A;&QI;F<@)R1E>'1;9FEL95TG(BD[#0H@("`@("`@("`@("`D<&%C
M:V%G:6YG<F]O="`]("<G.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@("`@("`@
M("`@("1P86-K86=I;F=R;V]T(#T@)'1H:7,M/E]O<'1I;VYS6R=P86-K86=I
M;F=R;V]T)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D8V]P>71O
M(#T@)'1H:7,M/E]P<F5P96YD4&%T:"@D9&5S="P@)'!A8VMA9VEN9W)O;W0I
M.PT*("`@("`@("`@("`@)&-O<'ED:7(@/2!D:7)N86UE*"1C;W!Y=&\I.PT*
M("`@("`@("`@("`@+R\@<')E='1Y(&UU8V@@;F]T:&EN9R!H87!P96YS(&EF
M('=E(&%R92!O;FQY(')E9VES=&5R:6YG('1H92!I;G-T86QL#0H@("`@("`@
M("`@("!I9B`H96UP='DH)'1H:7,M/E]O<'1I;VYS6R=R96=I<W1E<BUO;FQY
M)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%`:7-?9&ER*"1C;W!Y9&ER
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(21T:&ES+3YM:T1I<DAI
M97(H)&-O<'ED:7(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!M:V1I<B`D8V]P>61I
M<B(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E])3E-404Q,
M15)?1D%)3$5$*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^;&]G*#,L("(K(&UK9&ER("1C;W!Y9&ER(BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A0&-O
M<'DH)&5X=%LG9FEL92==+"`D8V]P>71O*2D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!W<FET
M92`D8V]P>71O(BP@4$5!4E])3E-404Q,15)?1D%)3$5$*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@S+"`B*R!C
M<"`D97AT6V9I;&5=("1C;W!Y=&\B*3L-"B`@("`@("`@("`@("`@("!I9B`H
M(4]37U=)3D1/5U,I('L-"B`@("`@("`@("`@("`@("`@("`@)&UO9&4@/2`P
M-C8V("8@?BAI;G0I;V-T9&5C*"1T:&ES+3YC;VYF:6<M/F=E="@G=6UA<VLG
M*2D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&:6QE3W!E<F%T
M:6]N*"=C:&UO9"<L(&%R<F%Y*"1M;V1E+"`D8V]P>71O*2D[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A0&-H;6]D*"1C;W!Y=&\L("1M;V1E*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`B9F%I;&5D
M('1O(&-H86YG92!M;V1E(&]F("1C;W!Y=&\B*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^861D1FEL94]P97)A=&EO;B@G<F5N86UE)RP@87)R87DH)&5X=%LG
M9FEL92==+"`D8V]P>71O*2D[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@
M("`@(&EF("@D9FEL96QI<W0M/F=E=%!A8VMA9V58;6Q697)S:6]N*"D@/3T@
M)S$N,"<I('L-"B`@("`@("`@("`@("`@("`D9FEL96QI<W0M/FEN<W1A;&QE
M9$9I;&4H)&)N+"!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W)O;&4G
M(#T^("1R;VQE+`T*("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&)N
M+`T*("`@("`@("`@("`@("`@("`@("`G:6YS=&%L;&5D7V%S)R`]/B`D9&5S
M="P-"B`@("`@("`@("`@("`@("`@("`@)W!H<%]A<&DG(#T^("1E>'1;)W!H
M<%]A<&DG72P-"B`@("`@("`@("`@("`@("`@("`@)WIE;F1?;6]D7V%P:2<@
M/3X@)&5X=%LG>F5N9%]M;V1?87!I)UTL#0H@("`@("`@("`@("`@("`@("`@
M("=Z96YD7V5X=%]A<&DG(#T^("1E>'1;)WIE;F1?97AT7V%P:2==+`T*("`@
M("`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&9I;&5L:7-T+3YI;G-T86QL961&:6QE*"1B;BP@
M87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<F]L92<@/3X@)')O;&4L#0H@("`@("`@("`@("`@("`@("`@("=N86UE
M)R`]/B`D8FXL#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL961?87,G
M(#T^("1D97-T+`T*("`@("`@("`@("`@("`@("`@("`G<&AP7V%P:2<@/3X@
M)&5X=%LG<&AP7V%P:2==+`T*("`@("`@("`@("`@("`@("`@("`G>F5N9%]M
M;V1?87!I)R`]/B`D97AT6R=Z96YD7VUO9%]A<&DG72P-"B`@("`@("`@("`@
M("`@("`@("`@)WIE;F1?97AT7V%P:2<@/3X@)&5X=%LG>F5N9%]E>'1?87!I
M)UTL#0H@("`@("`@("`@("`@("`@("`@("DI*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@(&9U;F-T:6]N
M("9G9715;FEN<W1A;&Q086-K86=E<R@I#0H@("`@>PT*("`@("`@("!R971U
M<FX@)'1H:7,M/E]D;W=N;&]A9&5D4&%C:V%G97,[#0H@("`@?0T*("`@("\O
M('M[>R!U;FEN<W1A;&PH*0T*#0H@("`@+RHJ#0H@("`@("H@56YI;G-T86QL
M(&$@<&%C:V%G90T*("`@("`J#0H@("`@("H@5&AI<R!M971H;V0@<F5M;W9E
M<R!A;&P@9FEL97,@:6YS=&%L;&5D(&)Y('1H92!A<'!L:6-A=&EO;BP@86YD
M('1H96X-"B`@("`@*B!R96UO=F5S(&%N>2!E;7!T>2!D:7)E8W1O<FEE<RX-
M"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P
M87)A;2!A<G)A>2!#;VUM86YD+6QI;F4@;W!T:6]N<RX@(%!O<W-I8FEL:71I
M97,@:6YC;'5D93H-"B`@("`@*@T*("`@("`J("`@("`@("`@("`@("`M(&EN
M<W1A;&QR;V]T.B!B87-E(&EN<W1A;&QA=&EO;B!D:7(L(&EF(&YO="!T:&4@
M9&5F875L=`T*("`@("`J("`@("`@("`@("`@("`M(&YO9&5P<SH@9&\@;F]T
M('!R;V-E<W,@9&5P96YD96YC:65S(&]F(&]T:&5R('!A8VMA9V5S('1O(&5N
M<W5R90T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@=6YI;G-T86QL
M871I;VX@9&]E<R!N;W0@8G)E86L@=&AI;F=S#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=6YI;G-T86QL*"1P86-K86=E+"`D;W!T:6]N<R`](&%R<F%Y*"DI
M#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEN<W1A;&QR
M;V]T)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS971);G-T
M86QL4F]O="@D;W!T:6]N<ULG:6YS=&%L;')O;W0G72D[#0H@("`@("`@("`@
M("`D=&AI<RT^:6YS=&%L;')O;W0@/2`G)SL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E=$EN<W1A;&Q2;V]T*"<G
M*3L-"B`@("`@("`@("`@("1T:&ES+3YI;G-T86QL<F]O="`]("<G.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@/2`F)'1H:7,M/F-O
M;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D
M<&%C:V%G92DI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A8VMA9V4M
M/F=E=$-H86YN96PH*3L-"B`@("`@("`@("`@("1P:V<@/2`D<&%C:V%G93L-
M"B`@("`@("`@("`@("1P86-K86=E(#T@)'!K9RT^9V5T4&%C:V%G92@I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'!K9R`](&9A;'-E.PT*
M("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S95!A
M8VMA9V5.86UE*"1P86-K86=E+`T*("`@("`@("`@("`@("`@("1T:&ES+3YC
M;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@("`@("`@
M)&-H86YN96P@/2`D:6YF;ULG8VAA;FYE;"==.PT*("`@("`@("`@("`@)'!A
M8VMA9V4@/2`D:6YF;ULG<&%C:V%G92==.PT*("`@("`@("!]#0H@("`@("`@
M("1S879E8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C
M:&%N;F5L)RD[#0H@("`@("`@("1T:&ES+3YC;VYF:6=3970H)V1E9F%U;'1?
M8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@:68@*"%I<U]O8FIE8W0H
M)'!K9RDI('L-"B`@("`@("`@("`@("1P:V<@/2`D=&AI<RT^7W)E9VES=')Y
M+3YG971086-K86=E*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D<&MG*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N
M9FEG4V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1T:&ES+3Y?<F5G
M:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]
M/B`D8VAA;FYE;"P-"B`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^
M("1P86-K86=E#0H@("`@("`@("`@("`@("`@*2P@=')U92D@+B`G(&YO="!I
M;G-T86QL960G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!K9RT^9V5T
M26YS=&%L;&5D0FEN87)Y*"DI('L-"B`@("`@("`@("`@("\O('1H:7,@:7,@
M:G5S="!A;B!A;&EA<R!F;W(@82!B:6YA<GD@<&%C:V%G90T*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GDM/F1E;&5T95!A8VMA9V4H)'!A
M8VMA9V4L("1C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@("`D9FEL96QI
M<W0@/2`D<&MG+3YG971&:6QE;&ES="@I.PT*("`@("`@("!014%2.CIS=&%T
M:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E<&5N9&5N8WDR)RDI('L-
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$97!E;F1E;F-Y,BYP
M:'`G.PT*("`@("`@("!]#0H@("`@("`@("1D97!C:&5C:V5R(#T@)FYE=R!0
M14%27T1E<&5N9&5N8WDR*"1T:&ES+3YC;VYF:6<L("1O<'1I;VYS+"`-"B`@
M("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P@)W!A8VMA
M9V4G(#T^("1P86-K86=E*2P-"B`@("`@("`@("`@(%!%05)?5D%,241!5$5?
M54Y)3E-404Q,24Y'*3L-"B`@("`@("`@)&4@/2`D9&5P8VAE8VME<BT^=F%L
M:61A=&5086-K86=E56YI;G-T86QL*"1T:&ES*3L-"B`@("`@("`@4$5!4CHZ
M<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO
M;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&4I.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)U=!
M4DY)3D<Z("<@+B`D92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS96EF("AI<U]A<G)A
M>2@D92DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O
M9G0G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("1E6S!=
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`O+R![>WL@
M1&5L971E('1H92!F:6QE<PT*("`@("`@("`D=&AI<RT^<W1A<G1&:6QE5')A
M;G-A8W1I;VXH*3L-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D97)R(#T@)'1H:7,M/E]D96QE=&5086-K86=E1FEL97,H)'!A8VMA9V4L
M("1C:&%N;F5L*2DI('L-"B`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N
M9&QI;F<H*3L-"B`@("`@("`@("`@("1T:&ES+3YR;VQL8F%C:T9I;&54<F%N
M<V%C=&EO;B@I.PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F
M875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@("`@(&EF
M("@A:7-S970H)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<BD[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@P+"`G5T%23DE.1SH@)R`N("1E<G(M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/F-O;6UI=$9I
M;&54<F%N<V%C=&EO;B@I*2![#0H@("`@("`@("`@("`D=&AI<RT^<F]L;&)A
M8VM&:6QE5')A;G-A8W1I;VXH*3L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)VEG;F]R92UE<G)O<G,G72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N:6YS=&%L;"!F86EL960B
M*3L-"B`@("`@("`@("`@('T@96QS96EF("@A:7-S970H)&]P=&EO;G-;)W-O
M9G0G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=705).
M24Y'.B!U;FEN<W1A;&P@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^<W1A<G1&:6QE5')A
M;G-A8W1I;VXH*3L-"B`@("`@("`@("`@(&EF("@D9&ER=')E92`]("1P:V<M
M/F=E=$1I<E1R964H*2D@>PT*("`@("`@("`@("`@("`@("\O(&%T=&5M<'0@
M=&\@9&5L971E(&5M<'1Y(&1I<F5C=&]R:65S#0H@("`@("`@("`@("`@("`@
M=6MS;W)T*"1D:7)T<F5E+"!A<G)A>2@D=&AI<RP@)U]S;W)T1&ER<R<I*3L-
M"B`@("`@("`@("`@("`@("!F;W)E86-H*"1D:7)T<F5E(&%S("1D:7(@/3X@
M)&YO='5S960I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9I
M;&5/<&5R871I;VXH)W)M9&ER)RP@87)R87DH)&1I<BDI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F-O;F9I9U-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C
M:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R96=I
M<W1R>2T^9&5L971E4&%C:V%G92@D<&%C:V%G92P@)&-H86YN96PI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]M;6ET1FEL
M951R86YS86-T:6]N*"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F]L
M;&)A8VM&:6QE5')A;G-A8W1I;VXH*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`O+R!]?7T-"@T*("`@("`@("`D=&AI<RT^8V]N9FEG
M4V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@
M("`O+R!296=I<W1E<B!T:&%T('1H92!P86-K86=E(&ES(&YO(&QO;F=E<B!I
M;G-T86QL960-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GDM/F1E
M;&5T95!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!3;W)T(&$@;&ES="!O9B!A<G)A>7,@;V8@87)R87DH
M9&]W;FQO861E9"!P86-K86=E9FEL96YA;64I(&)Y(&1E<&5N9&5N8WDN#0H@
M("`@("H-"B`@("`@*B!)="!A;'-O(')E;6]V97,@9'5P;&EC871E(&1E<&5N
M9&5N8VEE<PT*("`@("`J($!P87)A;2!A<G)A>2!A;B!A<G)A>2!O9B!014%2
M7U!A8VMA9V5&:6QE7W9;,2\R72!O8FIE8W1S#0H@("`@("H@0')E='5R;B!A
M<G)A>7Q014%27T5R<F]R(&%R<F%Y(&]F(&%R<F%Y*'!A8VMA9V5F:6QE;F%M
M92P@<&%C:V%G92YX;6P@8V]N=&5N=',I#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V]R=%!A8VMA9V5S1F]R56YI;G-T86QL*"8D<&%C:V%G97,I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0B`]("9014%27T1E<&5N
M9&5N8WE$0CHZ<VEN9VQE=&]N*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7V1E<&5N9&5N8WE$0BDI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1E<&5N9&5N8WE$0CL-"B`@("`@
M("`@?0T*("`@("`@("!U<V]R="@D<&%C:V%G97,L(&%R<F%Y*"8D=&AI<RP@
M)U]S;W)T56YI;G-T86QL)RDI.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]S
M;W)T56YI;G-T86QL*"1A+"`D8BD-"B`@("![#0H@("`@("`@(&EF("@A)&$M
M/F=E=$1E<',H*2`F)B`A)&(M/F=E=$1E<',H*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(#`[("\O(&YE:71H97(@<&%C:V%G92!H87,@9&5P96YD96YC:65S
M+"!O<F1E<B!I<R!I;G-I9VYI9FEC86YT#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1A+3YG971$97!S*"D@)B8@(21B+3YG971$97!S*"DI('L-"B`@("`@
M("`@("`@(')E='5R;B`M,3L@+R\@)&$@;75S="!B92!I;G-T86QL960@869T
M97(@)&(@8F5C875S92`D82!H87,@9&5P96YD96YC:65S#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D82T^9V5T1&5P<R@I("8F("1B+3YG971$97!S*"DI
M('L-"B`@("`@("`@("`@(')E='5R;B`Q.R`O+R`D8B!M=7-T(&)E(&EN<W1A
M;&QE9"!A9G1E<B`D82!B96-A=7-E("1B(&AA<R!D97!E;F1E;F-I97,-"B`@
M("`@("`@?0T*("`@("`@("`O+R!B;W1H('!A8VMA9V5S(&AA=F4@9&5P96YD
M96YC:65S#0H@("`@("`@(&EF("@D=&AI<RT^7V1E<&5N9&5N8WE$0BT^9&5P
M96YD<T]N*"1A+"`D8BDI('L-"B`@("`@("`@("`@(')E='5R;B`M,3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]D97!E;F1E;F-Y1$(M/F1E
M<&5N9'-/;B@D8BP@)&$I*2![#0H@("`@("`@("`@("!R971U<FX@,3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@,#L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@7W-O<G1$:7)S*"D-"B`@("!F=6YC=&EO;B!?<V]R
M=$1I<G,H)&$L("1B*0T*("`@('L-"B`@("`@("`@:68@*'-T<FYA=&-M<"@D
M82P@)&(I(#T]("TQ*2!R971U<FX@,3L-"B`@("`@("`@:68@*'-T<FYA=&-M
M<"@D82P@)&(I(#T](#$I(')E='5R;B`M,3L-"B`@("`@("`@<F5T=7)N(#`[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V)U:6QD0V%L
M;&)A8VLH*0T*#0H@("`@9G5N8W1I;VX@7V)U:6QD0V%L;&)A8VLH)'=H870L
M("1D871A*0T*("`@('L-"B`@("`@("`@:68@*"@D=VAA="`]/2`G8VUD;W5T
M<'5T)R`F)B`D=&AI<RT^9&5B=6<@/B`Q*2!\?`T*("`@("`@("`@("`@*"1W
M:&%T(#T]("=O=71P=70G("8F("1T:&ES+3YD96)U9R`^(#`I*2![#0H@("`@
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H<G1R:6TH)&1A=&$I+"`G
M8G5I;&0G*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*?0T*
M#0HO+R![>WL@;60U7V9I;&4H*2!U=&EL:71Y(&9U;F-T:6]N#0II9B`H(69U
M;F-T:6]N7V5X:7-T<R@B;60U7V9I;&4B*2D@>PT*("`@(&9U;F-T:6]N(&UD
M-5]F:6QE*"1F:6QE;F%M92D@>PT*("`@("`@("`D9G`@/2!F;W!E;B@D9FEL
M96YA;64L(")R(BD[#0H@("`@("`@(&EF("@A)&9P*2!R971U<FX@;G5L;#L-
M"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N
M=',G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@
M("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@9G)E
M860H)&9P+"!F:6QE<VEZ92@D9FEL96YA;64I*3L-"B`@("`@("`@("`@(&9C
M;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!M9#4H)&-O
M;G1E;G1S*3L-"B`@("!]#0I]#0HO+R!]?7T-"@T*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]296UO=&4N<&AP````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T-3,V,R`Q,#4Q-30S-#$S
M-"`P,C$Q-S``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`-"B\J*@T*("H@4$5!4E]296UO=&4-"B`J#0H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G
M($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@
M*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4F5M;W1E+G!H<"QV(#$N-S8@,C`P
M-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-
M"B\J*@T*("H@;F5E9&5D(&9O<B!014%27T5R<F]R#0H@*B\-"G)E<75I<F5?
M;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;F9I9RYP
M:'`G.PT*#0HO*BH-"B`J(%1H:7,@:7,@82!C;&%S<R!F;W(@9&]I;F<@<F5M
M;W1E(&]P97)A=&EO;G,@86=A:6YS="!T:&4@8V5N=')A;`T*("H@4$5!4B!D
M871A8F%S92X-"B`J#0H@*B!`;F]D97`@6$U,7U)00U]686QU90T*("H@0&YO
M9&5P(%A-3%]24$-?365S<V%G90T*("H@0&YO9&5P(%A-3%]24$-?0VQI96YT
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,0T*("HO#0IC;&%S<R!014%27U)E;6]T92!E>'1E;F1S(%!%05(-
M"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@=F%R("1C;VYF:6<@
M/2!N=6QL.PT*("`@('9A<B`D8V%C:&4@(#T@;G5L;#L-"B`@("`O*BH-"B`@
M("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!V87(@)%]R96=I<W1R>3L-"@T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(%!%05)?4F5M;W1E*&-O;F9I9U]O8FIE8W0I#0H-
M"B`@("!F=6YC=&EO;B!014%27U)E;6]T92@F)&-O;F9I9RD-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y014%2*"D[#0H@("`@("`@("1T:&ES+3YC;VYF:6<@
M/2`F)&-O;F9I9SL-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI
M<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!S971296=I<W1R>2@I#0H@("`@#0H@("`@9G5N8W1I
M;VX@<V5T4F5G:7-T<GDH)B1R96<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W)E9VES=')Y(#T@)B1R96<[#0H@("`@?0T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971#86-H92@I#0H-"@T*("`@(&9U;F-T:6]N(&=E=$-A8VAE*"1A
M<F=S*0T*("`@('L-"B`@("`@("`@)&ED("`@("`@(#T@;60U*'-E<FEA;&EZ
M92@D87)G<RDI.PT*("`@("`@("`D8V%C:&5D:7(@/2`D=&AI<RT^8V]N9FEG
M+3YG970H)V-A8VAE7V1I<B<I.PT*("`@("`@("`D9FEL96YA;64@/2`D8V%C
M:&5D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)WAM;')P8U]C86-H95\G
M("X@)&ED.PT*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1F:6QE;F%M92DI
M('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H-"B`@
M("`@("`@)&9P(#T@9F]P96XH)&9I;&5N86UE+"`G<F(G*3L-"B`@("`@("`@
M:68@*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O
M;G1E;G1S)RDI('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@
M("`@("`@)&-O;G1E;G0@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL96YA;64I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G0@(#T@
M9G)E860H)&9P+"!F:6QE<VEZ92@D9FEL96YA;64I*3L-"B`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@("1R97-U;'0@("`]
M(&%R<F%Y*`T*("`@("`@("`@("`@)V%G92<@("`@("`@(#T^('1I;64H*2`M
M(&9I;&5M=&EM92@D9FEL96YA;64I+`T*("`@("`@("`@("`@)VQA<W1#:&%N
M9V4G(#T^(&9I;&5M=&EM92@D9FEL96YA;64I+`T*("`@("`@("`@("`@)V-O
M;G1E;G0G("`@(#T^('5N<V5R:6%L:7IE*"1C;VYT96YT*2P-"B`@("`@("`@
M("`@("D[#0H@("`@("`@(')E='5R;B`D<F5S=6QT.PT*("`@('T-"@T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[('-A=F5#86-H92@I#0H-"B`@("!F=6YC
M=&EO;B!S879E0V%C:&4H)&%R9W,L("1D871A*0T*("`@('L-"B`@("`@("`@
M)&ED("`@("`@(#T@;60U*'-E<FEA;&EZ92@D87)G<RDI.PT*("`@("`@("`D
M8V%C:&5D:7(@/2`D=&AI<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I.PT*
M("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1C86-H961I<BDI('L-"B`@("`@
M("`@("`@(%-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@)&-A8VAE9&ER*2D[
M#0H@("`@("`@('T-"B`@("`@("`@)&9I;&5N86UE(#T@)&-A8VAE9&ER+B<O
M>&UL<G!C7V-A8VAE7R<N)&ED.PT*#0H@("`@("`@("1F<"`]($!F;W!E;B@D
M9FEL96YA;64L(")W8B(I.PT*("`@("`@("!I9B`H)&9P*2![#0H@("`@("`@
M("`@("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&1A=&$I*3L-"B`@("`@("`@
M("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@8VQE87)#86-H92@I#0H-"B`@("!F=6YC=&EO
M;B!C;&5A<D-A8VAE*"1M971H;V0L("1A<F=S*0T*("`@('L-"B`@("`@("`@
M87)R87E?=6YS:&EF="@D87)G<RP@)&UE=&AO9"D[#0H@("`@("`@(&%R<F%Y
M7W5N<VAI9G0H)&%R9W,L("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C
M:&%N;F5L)RDI.R`O+R!C86-H92!B>2!C:&%N;F5L#0H@("`@("`@("1I9"`@
M("`@("`](&UD-2AS97)I86QI>F4H)&%R9W,I*3L-"B`@("`@("`@)&-A8VAE
M9&ER(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D:7(G*3L-"B`@("`@
M("`@)&9I;&5N86UE(#T@)&-A8VAE9&ER+B<O>&UL<G!C7V-A8VAE7R<N)&ED
M.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H)&9I;&5N86UE*2D@>PT*("`@
M("`@("`@("`@0'5N;&EN:R@D9FEL96YA;64I.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-A;&PH;65T:&]D+"!;87)G
M<RXN+ETI#0H-"B`@("!F=6YC=&EO;B!C86QL*"1M971H;V0I#0H@("`@>PT*
M("`@("`@("`D7V%R9W,@/2`D87)G<R`](&9U;F-?9V5T7V%R9W,H*3L-"@T*
M("`@("`@("`D<V5R=F5R7V-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D8VAA;FYE;"`]("1T:&ES
M+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)'-E<G9E<E]C:&%N;F5L*3L-"B`@
M("`@("`@:68@*"%014%2.CII<T5R<F]R*"1C:&%N;F5L*2D@>PT*("`@("`@
M("`@("`@)&UI<G)O<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D
M7VUI<G)O<B<I.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YG971-:7)R
M;W(H)&UI<G)O<BDI('L-"B`@("`@("`@("`@("`@("!I9B`H)&-H86YN96PM
M/G-U<'!O<G1S*"=X;6QR<&,G+"`D;65T:&]D+"`D;6ER<F]R*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<V5R=F5R7V-H86YN96P@/2`D<V5R=F5R7VAO
M<W0@/2`D;6ER<F]R.R`O+R!U<V4@=&AE('!R969E<G)E9"!M:7)R;W(-"B`@
M("`@("`@("`@("`@("`@("`@)'-E<G9E<E]P;W)T(#T@)&-H86YN96PM/F=E
M=%!O<G0H)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"$D
M8VAA;FYE;"T^<W5P<&]R=',H)WAM;')P8R<L("1M971H;V0I*2![#0H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0VAA
M;FYE;"`D<V5R=F5R7V-H86YN96P@9&]E<R!N;W0@(B`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`B<W5P<&]R="!X;6PM<G!C(&UE=&AO9"`D;65T:&]D
M(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"%I<W-E="@D<V5R=F5R7VAO<W0I*2![#0H@("`@("`@("`@
M("`@("`@:68@*"$D8VAA;FYE;"T^<W5P<&]R=',H)WAM;')P8R<L("1M971H
M;V0I*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B0VAA;FYE;"`D<V5R=F5R7V-H86YN96P@9&]E<R!N;W0@<W5P
M<&]R="`B("X-"B`@("`@("`@("`@("`@("`@("`@("`@(")X;6PM<G!C(&UE
M=&AO9"`D;65T:&]D(BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)'-E<G9E<E]H;W-T(#T@)'-E<G9E<E]C:&%N
M;F5L.PT*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R7W!O<G0@/2`D8VAA
M;FYE;"T^9V5T4&]R="@I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@B56YK;F]W;B!C:&%N;F5L("<D<V5R=F5R7V-H
M86YN96PG(BD[#0H@("`@("`@('T-"@T*("`@("`@("!A<G)A>5]U;G-H:69T
M*"1?87)G<RP@)'-E<G9E<E]C:&%N;F5L*3L@+R\@8V%C:&4@8GD@8VAA;FYE
M;`T*("`@("`@("`D=&AI<RT^8V%C:&4@/2`D=&AI<RT^9V5T0V%C:&4H)%]A
M<F=S*3L-"B`@("`@("`@)&-A8VAE='1L(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=C86-H95]T=&PG*3L-"B`@("`@("`@+R\@268@8V%C:&4@:7,@;F5W97(@
M=&AA;B`D8V%C:&5T=&P@<V5C;VYD<RP@=V4@=7-E('1H92!C86-H92$-"B`@
M("`@("`@:68@*"1T:&ES+3YC86-H92`A/3T@;G5L;"`F)B`D=&AI<RT^8V%C
M:&5;)V%G92==(#P@)&-A8VAE='1L*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F-A8VAE6R=C;VYT96YT)UT[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&5X=&5N<VEO;E]L;V%D960H(GAM;')P8R(I*2![#0H@("`@("`@("`@
M("`D<F5S=6QT(#T@8V%L;%]U<V5R7V9U;F-?87)R87DH87)R87DH)B1T:&ES
M+"`G8V%L;%]E<&DG*2P@)&%R9W,I.PT*("`@("`@("`@("`@:68@*"%014%2
M.CII<T5R<F]R*"1R97-U;'0I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/G-A=F5#86-H92@D7V%R9W,L("1R97-U;'0I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[#0H@("`@("`@('T@96QS96EF
M("@A0&EN8VQU9&5?;VYC92`G6$U,+U)00RYP:'`G*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D9O<B!T:&ES(')E;6]T92!0
M14%2(&]P97)A=&EO;B!Y;W4@;F5E9"!T;R!L;V%D('1H92!X;6QR<&,@97AT
M96YS:6]N(&]R(&EN<W1A;&P@6$U,7U)00R(I.PT*("`@("`@("!]#0H-"B`@
M("`@("`@87)R87E?<VAI9G0H)&%R9W,I.PT*("`@("`@("`D=7-E<FYA;64@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)W5S97)N86UE)RD[#0H@("`@("`@("1P
M87-S=V]R9"`]("1T:&ES+3YC;VYF:6<M/F=E="@G<&%S<W=O<F0G*3L-"B`@
M("`@("`@)&5A<F=S(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"@D87)G
M<R!A<R`D87)G*2![#0H@("`@("`@("`@("`D96%R9W-;72`]("1T:&ES+3Y?
M96YC;V1E*"1A<F<I.PT*("`@("`@("!]#0H@("`@("`@("1F(#T@;F5W(%A-
M3%]24$-?365S<V%G92@D;65T:&]D+"`D96%R9W,I.PT*("`@("`@("!I9B`H
M)'1H:7,M/F-A8VAE("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D;6%X06=E
M(#T@)S]M87A!9V4])RXD=&AI<RT^8V%C:&5;)VQA<W1#:&%N9V4G73L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1M87A!9V4@/2`G)SL-"B`@
M("`@("`@?0T*("`@("`@("`D<')O>'E?:&]S="`]("1P<F]X>5]P;W)T(#T@
M)'!R;WAY7W5S97(@/2`D<')O>'E?<&%S<R`]("<G.PT*("`@("`@("!I9B`H
M)'!R;WAY(#T@<&%R<V5?=7)L*"1T:&ES+3YC;VYF:6<M/F=E="@G:'1T<%]P
M<F]X>2<I*2D@>PT*("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2!`)'!R;WAY
M6R=H;W-T)UT[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!R;WAY6R=S8VAE
M;64G72D@)B8@)'!R;WAY6R=S8VAE;64G72`]/2`G:'1T<',G*2![#0H@("`@
M("`@("`@("`@("`@)'!R;WAY7VAO<W0@/2`G:'1T<',Z+R\G("X@)'!R;WAY
M7VAO<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<')O>'E?<&]R
M="`]($`D<')O>'E;)W!O<G0G73L-"B`@("`@("`@("`@("1P<F]X>5]U<V5R
M(#T@0'5R;&1E8V]D92A`)'!R;WAY6R=U<V5R)UTI.PT*("`@("`@("`@("`@
M)'!R;WAY7W!A<W,@/2!`=7)L9&5C;V1E*$`D<')O>'E;)W!A<W,G72D[#0H@
M("`@("`@('T-"B`@("`@("`@)'-H;W-T(#T@)'-E<G9E<E]H;W-T.PT*("`@
M("`@("!I9B`H)&-H86YN96PM/F=E=%-33"@I*2![#0H@("`@("`@("`@("`D
M<VAO<W0@/2`B:'1T<',Z+R\D<VAO<W0B.PT*("`@("`@("!]#0H@("`@("`@
M("1C(#T@;F5W(%A-3%]24$-?0VQI96YT*"<O)R`N("1C:&%N;F5L+3YG9710
M871H*"=X;6QR<&,G*0T*("`@("`@("`@("`@+B`D;6%X06=E+"`D<VAO<W0L
M("1S97)V97)?<&]R="P@)'!R;WAY7VAO<W0L("1P<F]X>5]P;W)T+`T*("`@
M("`@("`@("`@)'!R;WAY7W5S97(L("1P<F]X>5]P87-S*3L-"B`@("`@("`@
M:68@*"1U<V5R;F%M92`F)B`D<&%S<W=O<F0I('L-"B`@("`@("`@("`@("1C
M+3YS971#<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S=V]R9"D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S
M92<I(#X](#,I('L-"B`@("`@("`@("`@("1C+3YS971$96)U9R@Q*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<B`]("1C+3YS96YD*"1F*3L-"B`@("`@("`@
M:68@*"$D<BD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")834Q?4E!#('-E;F0@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@
M("`@)'8@/2`D<BT^=F%L=64H*3L-"B`@("`@("`@:68@*"1E(#T@)'(M/F9A
M=6QT0V]D92@I*2![#0H@("`@("`@("`@("!I9B`H)&4@/3T@)$=,3T)!3%-;
M)UA-3%]24$-?97)R)UU;)VAT='!?97)R;W(G72`F)B!S=')S='(H)'(M/F9A
M=6QT4W1R:6YG*"DL("<S,#0@3F]T($UO9&EF:65D)RD@(3T](&9A;'-E*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC86-H95LG8V]N=&5N
M="==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1R+3YF875L=%-T<FEN9R@I+"`D92D[#0H@("`@("`@
M('T-"@T*("`@("`@("`D<F5S=6QT(#T@6$U,7U)00U]D96-O9&4H)'8I.PT*
M("`@("`@("`D=&AI<RT^<V%V94-A8VAE*"1?87)G<RP@)')E<W5L="D[#0H@
M("`@("`@(')E='5R;B`D<F5S=6QT.PT*("`@('T-"@T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&-A;&Q?97!I*&UE=&AO9"P@6V%R9W,N+BY=*0T*#0H@
M("`@9G5N8W1I;VX@8V%L;%]E<&DH)&UE=&AO9"D-"B`@("![#0H@("`@("`@
M(&1O('L-"B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*")X;6QR
M<&,B*2D@>PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*$]37U=)3D1/5U,I('L-"B`@("`@("`@("`@
M("`@("`D97AT(#T@)V1L;"<[#0H@("`@("`@("`@("!](&5L<V5I9B`H4$A0
M7T]3(#T]("=(4"U56"<I('L-"B`@("`@("`@("`@("`@("`D97AT(#T@)W-L
M)SL-"B`@("`@("`@("`@('T@96QS96EF("A02%!?3U,@/3T@)T%)6"<I('L-
M"B`@("`@("`@("`@("`@("`D97AT(#T@)V$G.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D97AT(#T@)W-O)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1E>'0@/2!/4U]724Y$3U=3(#\@)V1L;"<@
M.B`G<V\G.PT*("`@("`@("`@("`@0&1L*")X;6QR<&,M97!I+B1E>'0B*3L-
M"B`@("`@("`@("`@(&EF("AE>'1E;G-I;VY?;&]A9&5D*")X;6QR<&,B*2D@
M>PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@0&1L*")X;6QR<&,N)&5X="(I.PT*("`@("`@("`@("`@:68@
M*&5X=&5N<VEO;E]L;V%D960H(GAM;')P8R(I*2![#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H(G5N86)L92!T;R!L;V%D('AM;')P8R!E>'1E
M;G-I;VXB*3L-"B`@("`@("`@?2!W:&EL92`H9F%L<V4I.PT*("`@("`@("`D
M<V5R=F5R7V-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?
M8VAA;FYE;"<I.PT*("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3Y?<F5G:7-T
M<GDM/F=E=$-H86YN96PH)'-E<G9E<E]C:&%N;F5L*3L-"B`@("`@("`@:68@
M*"%014%2.CII<T5R<F]R*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@)&UI
M<G)O<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I
M.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YG971-:7)R;W(H)&UI<G)O
M<BDI('L-"B`@("`@("`@("`@("`@("!I9B`H)&-H86YN96PM/G-U<'!O<G1S
M*"=X;6QR<&,G+"`D;65T:&]D+"`D;6ER<F]R*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<V5R=F5R7V-H86YN96P@/2`D<V5R=F5R7VAO<W0@/2`D;6ER
M<F]R.R`O+R!U<V4@=&AE('!R969E<G)E9"!M:7)R;W(-"B`@("`@("`@("`@
M("`@("`@("`@)'-E<G9E<E]P;W)T(#T@)&-H86YN96PM/F=E=%!O<G0H)&UI
M<G)O<BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"$D8VAA;FYE;"T^
M<W5P<&]R=',H)WAM;')P8R<L("1M971H;V0I*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0VAA;FYE;"`D<V5R
M=F5R7V-H86YN96P@9&]E<R!N;W0@(B`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`B<W5P<&]R="!X;6PM<G!C(&UE=&AO9"`D;65T:&]D(BD[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"%I<W-E="@D<V5R=F5R7VAO<W0I*2![#0H@("`@("`@("`@("`@("`@:68@
M*"$D8VAA;FYE;"T^<W5P<&]R=',H)WAM;')P8R<L("1M971H;V0I*2![#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M0VAA;FYE;"`D<V5R=F5R7V-H86YN96P@9&]E<R!N;W0@<W5P<&]R="`B("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@(")X;6PM<G!C(&UE=&AO9"`D;65T
M:&]D(BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)'-E<G9E<E]H;W-T(#T@)'-E<G9E<E]C:&%N;F5L.PT*("`@
M("`@("`@("`@("`@("`@("`D<V5R=F5R7W!O<G0@/2`D8VAA;FYE;"T^9V5T
M4&]R="@I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B56YK;F]W;B!C:&%N;F5L("<D<V5R=F5R7V-H86YN96PG(BD[
M#0H@("`@("`@('T-"B`@("`@("`@)'!A<F%M<R`](&9U;F-?9V5T7V%R9W,H
M*3L-"B`@("`@("`@87)R87E?<VAI9G0H)'!A<F%M<RD[#0H@("`@("`@("1M
M971H;V0@/2!S=')?<F5P;&%C92@B7R(L("(N(BP@)&UE=&AO9"D[#0H@("`@
M("`@("1R97%U97-T(#T@>&UL<G!C7V5N8V]D95]R97%U97-T*"1M971H;V0L
M("1P87)A;7,I.PT*("`@("`@("!I9B`H)&AT='!?<')O>'D@/2`D=&AI<RT^
M8V]N9FEG+3YG970H)VAT='!?<')O>'DG*2D@>PT*("`@("`@("`@("`@)'!R
M;WAY(#T@<&%R<V5?=7)L*"1H='1P7W!R;WAY*3L-"B`@("`@("`@("`@("1P
M<F]X>5]H;W-T(#T@)'!R;WAY7W!O<G0@/2`D<')O>'E?=7-E<B`]("1P<F]X
M>5]P87-S(#T@)R<[#0H@("`@("`@("`@("`D<')O>'E?:&]S="`]($`D<')O
M>'E;)VAO<W0G73L-"B`@("`@("`@("`@(&EF("AI<W-E="@D<')O>'E;)W-C
M:&5M92==*2`F)B`D<')O>'E;)W-C:&5M92==(#T]("=H='1P<R<I('L-"B`@
M("`@("`@("`@("`@("`D<')O>'E?:&]S="`]("=S<VPZ+R\G("X@)'!R;WAY
M7VAO<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<')O>'E?<&]R
M="`]($`D<')O>'E;)W!O<G0G73L-"B`@("`@("`@("`@("1P<F]X>5]U<V5R
M(#T@0'5R;&1E8V]D92A`)'!R;WAY6R=U<V5R)UTI.PT*("`@("`@("`@("`@
M)'!R;WAY7W!A<W,@/2!`=7)L9&5C;V1E*$`D<')O>'E;)W!A<W,G72D[#0H@
M("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1P<F]X>5]H;W-T+"`D<')O
M>'E?<&]R="D[#0H@("`@("`@("`@("`D=7-E7W!R;WAY(#T@=')U93L-"B`@
M("`@("`@("`@(&EF("@D8VAA;FYE;"T^9V5T4U-,*"DI('L-"B`@("`@("`@
M("`@("`@("`D<V5R=F5R7VAO<W0@/2`B:'1T<',Z+R\D<V5R=F5R7VAO<W0B
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'5S95]P<F]X>2`](&9A;'-E.PT*("`@("`@("`@("`@)'-S;"`]("1C
M:&%N;F5L+3YG97134TPH*3L-"B`@("`@("`@("`@("1F<"`]($!F<V]C:V]P
M96XH*"1S<VP@/R`G<W-L.B\O)R`Z("<G*2`N("1S97)V97)?:&]S="P@)'-E
M<G9E<E]P;W)T*3L-"B`@("`@("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@
M("`@("`@("`@)'-E<G9E<E]H;W-T(#T@(B1S<VPD<V5R=F5R7VAO<W0B.R`O
M+R!F;W(@97)R;W(M<F5P;W)T:6YG#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D9G`@)B8@)&AT='!?<')O>'DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]296UO=&4Z
M.F-A;&PZ(&9S;V-K;W!E;BA@)'!R;WAY7VAO<W0G+"`D<')O>'E?<&]R="D@
M9F%I;&5D(BD[#0H@("`@("`@('T@96QS96EF("@A)&9P*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?4F5M;W1E.CIC
M86QL.B!F<V]C:V]P96XH8"1S97)V97)?:&]S="<L("1S97)V97)?<&]R="D@
M9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)&QE;B`]('-T<FQE;B@D
M<F5Q=65S="D[#0H@("`@("`@("1R97%?:&5A9&5R<R`](")(;W-T.B`D<V5R
M=F5R7VAO<W0Z)'-E<G9E<E]P;W)T7')<;B(@+@T*("`@("`@("`@("`@(")#
M;VYT96YT+71Y<&4Z('1E>'0O>&UL7')<;B(@+@T*("`@("`@("`@("`@(")#
M;VYT96YT+6QE;F=T:#H@)&QE;EQR7&XB.PT*("`@("`@("`D=7-E<FYA;64@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)W5S97)N86UE)RD[#0H@("`@("`@("1P
M87-S=V]R9"`]("1T:&ES+3YC;VYF:6<M/F=E="@G<&%S<W=O<F0G*3L-"B`@
M("`@("`@:68@*"1U<V5R;F%M92`F)B`D<&%S<W=O<F0I('L-"B`@("`@("`@
M("`@("1R97%?:&5A9&5R<R`N/2`B0V]O:VEE.B!014%27U5315(])'5S97)N
M86UE.R!014%27U!7/21P87-S=V]R9%QR7&XB.PT*("`@("`@("`@("`@)'1M
M<"`](&)A<V4V-%]E;F-O9&4H(B1U<V5R;F%M93HD<&%S<W=O<F0B*3L-"B`@
M("`@("`@("`@("1R97%?:&5A9&5R<R`N/2`B075T:&]R:7IA=&EO;CH@0F%S
M:6,@)'1M<%QR7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^
M8V%C:&4@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1M87A!9V4@/2`G/VUA
M>$%G93TG+B1T:&ES+3YC86-H95LG;&%S=$-H86YG92==.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&UA>$%G92`]("<G.PT*("`@("`@("!]
M#0H-"B`@("`@("`@:68@*"1U<V5?<')O>'D@)B8@)'!R;WAY7VAO<W0@(3T@
M)R<@)B8@)'!R;WAY7W5S97(@(3T@)R<I('L-"B`@("`@("`@("`@("1R97%?
M:&5A9&5R<R`N/2`G4')O>'DM075T:&]R:7IA=&EO;CH@0F%S:6,@)PT*("`@
M("`@("`@("`@("`@("YB87-E-C1?96YC;V1E*"1P<F]X>5]U<V5R+B<Z)RXD
M<')O>'E?<&%S<RD-"B`@("`@("`@("`@("`@("`N(EQR7&XB.PT*("`@("`@
M("!]#0H-"B`@("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/F=E="@G=F5R8F]S
M92<I(#X@,RD@>PT*("`@("`@("`@("`@<')I;G0@(EA-3%)00R!215%515-4
M($A%041%4E,Z7&XB.PT*("`@("`@("`@("`@=F%R7V1U;7`H)')E<5]H96%D
M97)S*3L-"B`@("`@("`@("`@('!R:6YT(")834Q24$,@4D5154535"!"3T19
M.EQN(CL-"B`@("`@("`@("`@('9A<E]D=6UP*"1R97%U97-T*3L-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("@D=7-E7W!R;WAY("8F("1P<F]X>5]H;W-T
M("$]("<G*2![#0H@("`@("`@("`@("`D<&]S=%]S=')I;F<@/2`B4$]35"!H
M='1P.B\O(BXD<V5R=F5R7VAO<W0[#0H@("`@("`@("`@("!I9B`H)'!R;WAY
M7W!O<G0@/B`G)RD@>PT*("`@("`@("`@("`@("`@("1P;W-T7W-T<FEN9R`N
M/2`G.B<N)'-E<G9E<E]P;W)T.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)'!O<W1?<W1R:6YG(#T@(E!/4U0@(CL-
M"B`@("`@("`@?0T*#0H@("`@("`@("1P871H(#T@)R\G("X@)&-H86YN96PM
M/F=E=%!A=&@H)WAM;')P8R<I.PT*("`@("`@("!F=W)I=&4H)&9P+"`H)'!O
M<W1?<W1R:6YG("X@)'!A=&@@+B`B)&UA>$%G92!(5%10+S$N,%QR7&XD<F5Q
M7VAE861E<G-<<EQN)')E<75E<W0B*2D[#0H@("`@("`@("1R97-P;VYS92`]
M("<G.PT*("`@("`@("`D;&EN93$@/2!F9V5T<R@D9G`L(#(P-#@I.PT*("`@
M("`@("!I9B`H(7!R96=?;6%T8V@H)R%>2%144"];,"TY7"Y=*R`H7&0K*2`H
M+BHI(2<L("1L:6YE,2P@)&UA=&-H97,I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?4F5M;W1E.B!I;G9A;&ED($A4
M5%`@<F5S<&]N<V4@9G)O;2!834PM4E!#('-E<G9E<B(I.PT*("`@("`@("!]
M#0H@("`@("`@('-W:71C:"`H)&UA=&-H97-;,5TI('L-"B`@("`@("`@("`@
M(&-A<V4@(C(P,"(Z("\O($]+#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("(S,#0B.B`O+R!.;W0@36]D:69I960-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/F-A8VAE6R=C;VYT96YT)UT[#0H@
M("`@("`@("`@("!C87-E("(T,#$B.B`O+R!5;F%U=&AO<FEZ960-"B`@("`@
M("`@("`@("`@("!I9B`H)'5S97)N86UE("8F("1P87-S=V]R9"D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%
M05)?4F5M;W1E("@D<V5R=F5R7VAO<W0Z)'-E<G9E<E]P;W)T*2`B("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("(Z(&%U=&AO<FEZ871I;VX@9F%I;&5D
M(BP@-#`Q*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!%05)?4F5M
M;W1E("@D<V5R=F5R7VAO<W0Z)'-E<G9E<E]P;W)T*2`B("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("(Z(&%U=&AO<FEZ871I;VX@<F5Q=6ER960L('!L
M96%S92!L;V<@:6X@9FER<W0B+"`T,#$I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")014%27U)E;6]T92`H)'-E<G9E<E]H;W-T
M.B1S97)V97)?<&]R="D@.B`B("X-"B`@("`@("`@("`@("`@("`@("`@(G5N
M97AP96-T960@2%144"!R97-P;VYS92(L("AI;G0I)&UA=&-H97-;,5TL(&YU
M;&PL(&YU;&PL#0H@("`@("`@("`@("`@("`@("`@("(D;6%T8VAE<ULQ72`D
M;6%T8VAE<ULR72(I.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE("AT<FEM
M*&9G971S*"1F<"P@,C`T."DI("$]("<G*3L@+R\@<VMI<"!R97-T(&]F(&AE
M861E<G,-"B`@("`@("`@=VAI;&4@*"1C:'5N:R`](&9R96%D*"1F<"P@,3`R
M-#`I*2![#0H@("`@("`@("`@("`D<F5S<&]N<V4@+CT@)&-H=6YK.PT*("`@
M("`@("!]#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!I9B`H)'1H
M:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`S*2![#0H@("`@("`@("`@
M("!P<FEN="`B6$U,4E!#(%)%4U!/3E-%.EQN(CL-"B`@("`@("`@("`@('9A
M<E]D=6UP*"1R97-P;VYS92D[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]
M('AM;')P8U]D96-O9&4H)')E<W!O;G-E*3L-"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1R970I("8F(&ES<V5T*"1R971;)U]?4$5!4E]465!%7U\G72DI('L-
M"B`@("`@("`@("`@(&EF("@D<F5T6R=?7U!%05)?5%E015]?)UT@/3T@)V5R
M<F]R)RD@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5T6R=?7U!%
M05)?0TQ!4U-?7R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@
M/2`D<F5T6R=?7U!%05)?0TQ!4U-?7R==.PT*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("1C;&%S<R`](")014%27T5R
M<F]R(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"1R971;)V-O9&4G72`@("`@/3T]("<G*2`D<F5T6R=C;V1E)UT@("`@(#T@
M;G5L;#L-"B`@("`@("`@("`@("`@("!I9B`H)')E=%LG;65S<V%G92==("`]
M/3T@)R<I("1R971;)VUE<W-A9V4G72`@/2!N=6QL.PT*("`@("`@("`@("`@
M("`@(&EF("@D<F5T6R=U<V5R:6YF;R==(#T]/2`G)RD@)')E=%LG=7-E<FEN
M9F\G72`](&YU;&P[#0H@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)&-L87-S*2`]/2`G9&)?97)R;W(G*2![#0H@("`@("`@("`@("`@("`@("`@
M("1R970@/2`D=&AI<RT^<F%I<V5%<G)O<BA014%2.CIE<G)O<DUE<W-A9V4H
M)')E=%LG8V]D92==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R971;)V-O9&4G72P@;G5L;"P@;G5L;"P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M971;)W5S97)I;F9O)UTI.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("1R970@/2`D=&AI<RT^<F%I<V5%<G)O<B@D
M<F5T6R=M97-S86=E)UTL("1R971;)V-O9&4G72P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL("1R
M971;)W5S97)I;F9O)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1R970I("8F('-I
M>F5O9B@D<F5T*2`]/2`Q("8F(&ES<V5T*"1R971;,%TI#0H@("`@("`@("`@
M("`@("`@("`F)B!I<U]A<G)A>2@D<F5T6S!=*2`F)@T*("`@("`@("`@("`@
M("`@("`@(65M<'1Y*"1R971;,%U;)V9A=6QT4W1R:6YG)UTI("8F#0H@("`@
M("`@("`@("`@("`@("`A96UP='DH)')E=%LP75LG9F%U;'1#;V1E)UTI*2![
M#0H@("`@("`@("`@("!E>'1R86-T*"1R971;,%TI.PT*("`@("`@("`@("`@
M)&9A=6QT4W1R:6YG(#T@(EA-3"U24$,@4V5R=F5R($9A=6QT.B`B("X-"B`@
M("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H(EQN(BP@(B`B+"`D9F%U;'13
M=')I;F<I.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1F875L=%-T<FEN9RP@)&9A=6QT0V]D92D[#0H@("`@("`@('T@96QS96EF
M("AI<U]A<G)A>2@D<F5T*2`F)B!S:7IE;V8H)')E="D@/3T@,B`F)B`A96UP
M='DH)')E=%LG9F%U;'13=')I;F<G72D@)B8-"B`@("`@("`@("`@("`@(65M
M<'1Y*"1R971;)V9A=6QT0V]D92==*2D@>PT*("`@("`@("`@("`@97AT<F%C
M="@D<F5T*3L-"B`@("`@("`@("`@("1F875L=%-T<FEN9R`](")834PM4E!#
M(%-E<G9E<B!&875L=#H@(B`N#0H@("`@("`@("`@("`@("`@('-T<E]R97!L
M86-E*")<;B(L("(@(BP@)&9A=6QT4W1R:6YG*3L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D9F%U;'13=')I;F<L("1F875L=$-O
M9&4I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]E;F-O9&4-"@T*("`@("\O
M(&$@<VQI9VAT;'D@97AT96YD960@=F5R<VEO;B!O9B!834Q?4E!#7V5N8V]D
M90T*("`@(&9U;F-T:6]N(%]E;F-O9&4H)'!H<%]V86PI#0H@("`@>PT*("`@
M("`@("!G;&]B86P@)%A-3%]24$-?0F]O;&5A;BP@)%A-3%]24$-?26YT+"`D
M6$U,7U)00U]$;W5B;&4[#0H@("`@("`@(&=L;V)A;"`D6$U,7U)00U]3=')I
M;F<L("1834Q?4E!#7T%R<F%Y+"`D6$U,7U)00U]3=')U8W0[#0H-"B`@("`@
M("`@)'1Y<&4@/2!G971T>7!E*"1P:'!?=F%L*3L-"B`@("`@("`@)'AM;')P
M8W9A;"`](&YE=R!834Q?4E!#7U9A;'5E.PT*#0H@("`@("`@('-W:71C:"@D
M='EP92D@>PT*("`@("`@("`@("`@8V%S92`B87)R87DB.@T*("`@("`@("`@
M("`@("`@(')E<V5T*"1P:'!?=F%L*3L-"B`@("`@("`@("`@("`@("`D9FER
M<W1K97D@/2!K97DH)'!H<%]V86PI.PT*("`@("`@("`@("`@("`@(&5N9"@D
M<&AP7W9A;"D[#0H@("`@("`@("`@("`@("`@)&QA<W1K97D@/2!K97DH)'!H
M<%]V86PI.PT*("`@("`@("`@("`@("`@(')E<V5T*"1P:'!?=F%L*3L-"B`@
M("`@("`@("`@("`@("!I9B`H)&9I<G-T:V5Y(#T]/2`P("8F(&ES7VEN="@D
M;&%S=&ME>2D@)B8-"B`@("`@("`@("`@("`@("`@("`@*"1L87-T:V5Y("L@
M,2D@/3T@8V]U;G0H)'!H<%]V86PI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1I<U]C;VYT:6YU;W5S(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@
M<F5S970H)'!H<%]V86PI.PT*("`@("`@("`@("`@("`@("`@("`D<VEZ92`]
M(&-O=6YT*"1P:'!?=F%L*3L-"B`@("`@("`@("`@("`@("`@("`@9F]R("@D
M97AP96-T(#T@,#L@)&5X<&5C="`\("1S:7IE.R`D97AP96-T*RLL(&YE>'0H
M)'!H<%]V86PI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:V5Y
M*"1P:'!?=F%L*2`A/3T@)&5X<&5C="D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I<U]C;VYT:6YU;W5S(#T@9F%L<V4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1I<U]C;VYT:6YU;W5S*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!R97-E="@D<&AP7W9A;"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D87)R(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('=H:6QE("AL:7-T*"1K+"`D=BD@/2!E86-H*"1P:'!?=F%L*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A<G);)&M=(#T@)'1H:7,M/E]E
M;F-O9&4H)'8I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'AM;')P8W9A;"T^861D07)R87DH)&%R<BD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`O+R!F86QL('1H;W5G:"!I9B!N;W0@;G5M97)I8V%L(&%N9"!C;VYT:6YU
M;W5S#0H@("`@("`@("`@("!C87-E(")O8FIE8W0B.@T*("`@("`@("`@("`@
M("`@("1A<G(@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('=H:6QE("AL
M:7-T*"1K+"`D=BD@/2!E86-H*"1P:'!?=F%L*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D87)R6R1K72`]("1T:&ES+3Y?96YC;V1E*"1V*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'AM;')P8W9A;"T^861D
M4W1R=6-T*"1A<G(I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`B:6YT96=E<B(Z#0H@("`@("`@("`@("`@("`@)'AM;')P
M8W9A;"T^861D4V-A;&%R*"1P:'!?=F%L+"`D6$U,7U)00U]);G0I.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`B9&]U8FQE
M(CH-"B`@("`@("`@("`@("`@("`D>&UL<G!C=F%L+3YA9&138V%L87(H)'!H
M<%]V86PL("1834Q?4E!#7T1O=6)L92D[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E(")S=')I;F<B.@T*("`@("`@("`@("`@
M8V%S92`B3E5,3"(Z#0H@("`@("`@("`@("`@("`@)'AM;')P8W9A;"T^861D
M4V-A;&%R*"1P:'!?=F%L+"`D6$U,7U)00U]3=')I;F<I.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`B8F]O;&5A;B(Z#0H@
M("`@("`@("`@("`@("`@)'AM;')P8W9A;"T^861D4V-A;&%R*"1P:'!?=F%L
M+"`D6$U,7U)00U]";V]L96%N*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@(G5N:VYO=VX@='EP92(Z#0H@("`@("`@("`@
M("!D969A=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D>&UL<G!C=F%L.PT*("`@('T-"@T*
M("`@("\O('U]?0T*#0I]#0H-"C\^#0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4$5!4B]086-K86=E<BYP:'``````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`Q-S4U,R`Q,#4Q-30S-#$S-"`P,C$T-3(`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`-
M"B\J*@T*("H@4$5!4E]086-K86=E<B!F;W(@9V5N97)A=&EN9R!R96QE87-E
M<PT*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("`@(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A
M8VMA9V5R+G!H<"QV(#$N-C@@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0IR97%U:7)E7V]N
M8V4@)U!%05(O4&%C:V%G949I;&4N<&AP)SL-"G)E<75I<F5?;VYC92`G4WES
M=&5M+G!H<"<[#0H-"B\J*@T*("H@061M:6YI<W1R871I;VX@8VQA<W,@=7-E
M9"!T;R!M86ME(&$@4$5!4B!R96QE87-E('1A<F)A;&PN#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P
M+C$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E<B!E>'1E;F1S(%!%05)?0V]M
M;6]N#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@
M("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[#0H@("`@+R\@>WM[('!A8VMA
M9V4H*0T*#0H@("`@9G5N8W1I;VX@<&%C:V%G92@D<&MG9FEL92`](&YU;&PL
M("1C;VUP<F5S<R`]('1R=64L("1P:V<R(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@("\O('M[>R!V86QI9&%T92!S=7!P;&EE9"!P86-K86=E+GAM;"!F:6QE
M#0H@("`@("`@(&EF("AE;7!T>2@D<&MG9FEL92DI('L-"B`@("`@("`@("`@
M("1P:V=F:6QE(#T@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@?0T*("`@("`@
M("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H
M)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F1E8G5G*3L-"B`@("`@("`@)'!F(#T@
M)B1P:V<M/F9R;VU086-K86=E1FEL92@D<&MG9FEL92P@4$5!4E]604Q)1$%4
M15].3U)-04PI.PT*("`@("`@("`D;6%I;B`]("8D<&8[#0H@("`@("`@(%!%
M05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1P9BT^9V5T57-E<DEN9F\H*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D<&8M/F=E=%5S97));F9O*"D@87,@)&5R<F]R*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R.B`G("X@)&5R<F]R
M6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)'!F+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#
M86YN;W0@<&%C:V%G92P@97)R;W)S(&EN('!A8VMA9V4@9FEL92(I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG9716
M86QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,2P@)U=A<FYI;F<Z("<@+B`D=V%R;FEN9ULG
M;65S<V%G92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O('U]?0T*("`@("`@("!I9B`H)'!K9S(I('L-"B`@("`@("`@("`@
M("1T:&ES+3YL;V<H,"P@)T%T=&5M<'1I;F<@=&\@<')O8V5S<R!T:&4@<V5C
M;VYD('!A8VMA9V4@9FEL92<I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC
M4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`@("`@)'!F,B`]("8D<&MG+3YF<F]M4&%C:V%G949I;&4H)'!K9S(L(%!%
M05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I
M8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2.CII
M<T5R<F]R*"1P9C(I*2![#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1P9C(M/F=E=%5S97));F9O*"DI*2![#0H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1P9C(M/F=E=%5S97));F9O*"D@87,@)&5R<F]R*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#`L("=%<G)O<CH@
M)R`N("1E<G)O<ELG;65S<V%G92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M;&]G*#`L("1P9C(M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")#86YN;W0@<&%C:V%G92P@97)R
M;W)S(&EN('-E8V]N9"!P86-K86=E(&9I;&4B*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F,BT^9V5T5F%L
M:61A=&EO;E=A<FYI;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9R@Q+"`G5V%R;FEN9SH@)R`N("1W87)N:6YG
M6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D<&8R+3YG971086-K86=E>&UL5F5R<VEO
M;B@I(#T]("<R+C`G*2![#0H@("`@("`@("`@("`@("`@)&UA:6X@/2`F)'!F
M,CL-"B`@("`@("`@("`@("`@("`D;W1H97(@/2`F)'!F.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D;6%I;B`]("8D<&8[#0H@
M("`@("`@("`@("`@("`@)&]T:&5R(#T@)B1P9C([#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H)&UA:6XM/F=E=%!A8VMA9V5X;6Q697)S:6]N
M*"D@(3T@)S(N,"<I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G17)R;W(Z(&-A;FYO="!P86-K86=E('1W;R!P86-K86=E
M+GAM;"!V97)S:6]N(#$N,"P@8V%N("<@+@T*("`@("`@("`@("`@("`@("`@
M("`G;VYL>2!P86-K86=E('1O9V5T:&5R(&$@<&%C:V%G92YX;6P@,2XP(&%N
M9"!P86-K86=E+GAM;"`R+C`G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@D;W1H97(M/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@(3T@)S$N
M,"<I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G17)R;W(Z(&-A;FYO="!P86-K86=E('1W;R!P86-K86=E+GAM;"!V97)S
M:6]N(#(N,"P@8V%N("<@+@T*("`@("`@("`@("`@("`@("`@("`G;VYL>2!P
M86-K86=E('1O9V5T:&5R(&$@<&%C:V%G92YX;6P@,2XP(&%N9"!P86-K86=E
M+GAM;"`R+C`G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D;6%I;BT^<V5T3&]G9V5R*"1T:&ES*3L-"B`@("`@("`@:68@*"$D;6%I
M;BT^=F%L:61A=&4H4$5!4E]604Q)1$%415]004-+04=)3D<I*2![#0H@("`@
M("`@("`@("!F;W)E86-H("@D;6%I;BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S
M*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G
M*#`L("=%<G)O<CH@)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")#86YN;W0@<&%C:V%G92P@97)R;W)S(&EN('!A8VMA9V4B*3L-"B`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1M86EN+3YG9716
M86QI9&%T:6]N5V%R;FEN9W,H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YL;V<H,2P@)U=A<FYI;F<Z("<@+B`D=V%R;FEN9ULG
M;65S<V%G92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)'!K9S(I('L-"B`@("`@("`@("`@("1O=&AE<BT^<V5T3&]G9V5R
M*"1T:&ES*3L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@
M("!I9B`H(21O=&AE<BT^=F%L:61A=&4H4$5!4E]604Q)1$%415].3U)-04PI
M('Q\("1A(#T@(21M86EN+3YI<T5Q=6EV86QE;G0H)&]T:&5R*2D@>PT*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1O=&AE<BT^9V5T5F%L:61A=&EO;E=A
M<FYI;F=S*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/FQO9R@P+"`G17)R;W(Z("<@+B`D=V%R;FEN9ULG;65S<V%G92==
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&UA:6XM/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1W87)N:6YG
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,"P@)T5R<F]R
M.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("@D82D@>PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U1H92!T=V\@<&%C:V%G
M92YX;6P@9FEL97,@87)E(&YO="!E<75I=F%L96YT(2<I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D-A;FYO="!P86-K86=E+"!E<G)O<G,@:6X@<&%C:V%G92(I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!F;W)E86-H
M("@D;W1H97(M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1W87)N:6YG
M*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YL;V<H,2P@)U=A<FYI
M;F<Z("<@+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9V5N(#T@)B1M86EN
M+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@("`@("`@("`@("`D=&=Z9FEL
M92`]("1G96XM/G1O5&=Z,B@D=&AI<RP@)&]T:&5R+"`D8V]M<')E<W,I.PT*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1G>F9I;&4I*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T9WIF:6QE.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@)&1E<W1?<&%C:V%G92`](&)A<V5N86UE*"1T9WIF
M:6QE*3L-"B`@("`@("`@("`@("1P:V=D:7(@/2!D:7)N86UE*"1P:V=F:6QE
M*3L-"B`@("`-"B`@("`@("`@("`@("\O(%1!4B!T:&4@4&%C:V%G92`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM#0H@("`@
M("`@("`@("`D=&AI<RT^;&]G*#$L(")086-K86=E("1D97-T7W!A8VMA9V4@
M9&]N92(I.PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"(D<&MG9&ER
M+T-64R]2;V]T(BDI('L-"B`@("`@("`@("`@("`@("`D8W9S=F5R<VEO;B`]
M('!R96=?<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D<&8M/F=E=%9E
M<G-I;VXH*2D[#0H@("`@("`@("`@("`@("`@)&-V<W1A9R`](")214Q%05-%
M7R1C=G-V97)S:6]N(CL-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L
M("=486<@=&AE(')E;&5A<V5D(&-O9&4@=VET:"`B<&5A<B!C=G-T86<@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("1M86EN+3YG971086-K86=E1FEL92@I
M("X@)R(G*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;&]G*#$L("(H;W(@
M<V5T('1H92!#5E,@=&%G("1C=G-T86<@8GD@:&%N9"DB*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E('L@+R\@=&AI<R!B<F%N8V@@:7,@97AE
M8W5T960@9F]R('-I;F=L92!P86-K86=E9FEL92!P86-K86=I;F<-"B`@("`@
M("`@("`@("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N97)A=&]R*"D[#0H@
M("`@("`@("`@("`D=&=Z9FEL92`]("1G96XM/G1O5&=Z*"1T:&ES+"`D8V]M
M<')E<W,I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1G>F9I
M;&4I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO9R@P+"`D=&=Z9FEL
M92T^9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(D-A;FYO="!P86-K86=E+"!E<G)O<G,@:6X@<&%C
M:V%G92(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<W1?<&%C
M:V%G92`](&)A<V5N86UE*"1T9WIF:6QE*3L-"B`@("`@("`@("`@("1P:V=D
M:7(@/2!D:7)N86UE*"1P:V=F:6QE*3L-"B`@("`-"B`@("`@("`@("`@("\O
M(%1!4B!T:&4@4&%C:V%G92`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM#0H@("`@("`@("`@("`D=&AI<RT^;&]G*#$L(")0
M86-K86=E("1D97-T7W!A8VMA9V4@9&]N92(I.PT*("`@("`@("`@("`@:68@
M*&9I;&5?97AI<W1S*"(D<&MG9&ER+T-64R]2;V]T(BDI('L-"B`@("`@("`@
M("`@("`@("`D8W9S=F5R<VEO;B`]('!R96=?<F5P;&%C92@G+UM>82UZ,"TY
M72]I)RP@)U\G+"`D<&8M/F=E=%9E<G-I;VXH*2D[#0H@("`@("`@("`@("`@
M("`@)&-V<W1A9R`](")214Q%05-%7R1C=G-V97)S:6]N(CL-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^;&]G*#$L(")486<@=&AE(')E;&5A<V5D(&-O9&4@
M=VET:"!@<&5A<B!C=G-T86<@)'!K9V9I;&4G(BD[#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/FQO9R@Q+"`B*&]R('-E="!T:&4@0U93('1A9R`D8W9S=&%G
M(&)Y(&AA;F0I(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1D97-T7W!A8VMA9V4[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0I]#0H-"B\O('M[>R!M9#5?9FEL92@I('5T:6QI='D@9G5N8W1I;VX-"FEF
M("@A9G5N8W1I;VY?97AI<W1S*"=M9#5?9FEL92<I*2![#0H@("`@9G5N8W1I
M;VX@;60U7V9I;&4H)&9I;&4I('L-"B`@("`@("`@:68@*"$D9F0@/2!`9F]P
M96XH)&9I;&4L("=R)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE
M7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F8VQO<V4H)&9D*3L-
M"B`@("`@("`@("`@("1M9#4@/2!M9#4H9FEL95]G971?8V]N=&5N=',H)&9I
M;&4I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1M9#4@/2!M
M9#4H9G)E860H)&9D+"!F:6QE<VEZ92@D9FEL92DI*3L-"B`@("`@("`@("`@
M(&9C;&]S92@D9F0I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D;60U
M.PT*("`@('T-"GT-"B\O('U]?0T*#0H_/@T*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4N<&AP
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S8U-S$@,3`U
M,34T,S0Q,S0@,#(R,#<Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?4&%C:V%G949I;&4L
M('!A8VMA9V4N>&UL('!A<G-I;F<@=71I;&ET>2!C;&%S<PT*("H-"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!086-K86=E1FEL92YP:'`L
M=B`Q+C,S(#(P,#8O,#(O,#D@,C(Z,SDZ,S(@8V5L;&]G($5X<"`D#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!N965D960@9F]R(%!%05)?5D%,241!
M5$5?*B!C;VYS=&%N=',-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U9A;&ED
M871E+G!H<"<[#0HO*BH-"B`J($5R<F]R(&-O9&4@:68@=&AE('!A8VMA9V4N
M>&UL(#QP86-K86=E/B!T86<@9&]E<R!N;W0@8V]N=&%I;B!A('9A;&ED('9E
M<G-I;VX-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/
M7U!!0TM!1T5615)324].)RP@,2D[#0HO*BH-"B`J($5R<F]R(&-O9&4@:68@
M=&AE('!A8VMA9V4N>&UL(#QP86-K86=E/B!T86<@=F5R<VEO;B!I<R!N;W0@
M<W5P<&]R=&5D("AV97)S:6]N(#$N,"!A;F0@,2XQ(&%R92!T:&4@;VYL>2!S
M=7!P;W)T960@=F5R<VEO;G,L#0H@*B!C=7)R96YT;'D-"B`J+PT*9&5F:6YE
M*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?4$%#2T%'159%4E-)
M3TXG+"`R*3L-"B\J*@T*("H@06)S=')A8W1I;VX@9F]R('1H92!P86-K86=E
M+GAM;"!P86-K86=E(&1E<V-R:7!T:6]N(&9I;&4-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP
M83$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL90T*>PT*("`@("\J*@T*
M("`@("`J($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@)%]C
M;VYF:6<[#0H@("`@=F%R("1?9&5B=6<[#0H@("`@+RHJ#0H@("`@("H@5&5M
M<"!D:7)E8W1O<GD@9F]R('5N8V]M<')E<W-I;F<@=&=Z(&9I;&5S+@T*("`@
M("`J($!V87(@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@=F%R("1?=&UP
M9&ER.PT*("`@('9A<B`D7VQO9V=E<B`](&9A;'-E.PT*("`@("\J*@T*("`@
M("`J($!V87(@8F]O;&5A;@T*("`@("`J+PT*("`@('9A<B`D7W)A=U)E='5R
M;B`](&9A;'-E.PT*#0H@("`@+RHJ#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M("!014%27T-O;F9I9R`D8V]N9FEG#0H@("`@("H@0'!A<F%M("`@/R`@("1D
M96)U9PT*("`@("`J($!P87)A;2`@('-T<FEN9R!`=&UP9&ER($]P=&EO;F%L
M('1E;7!O<F%R>2!D:7)E8W1O<GD@9F]R('5N8V]M<')E<W-I;F<-"B`@("`@
M*B`@("`@("`@("!F:6QE<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?
M4&%C:V%G949I;&4H)B1C;VYF:6<L("1D96)U9R`](&9A;'-E+"`D=&UP9&ER
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V-O;F9I9R`]("1C
M;VYF:6<[#0H@("`@("`@("1T:&ES+3Y?9&5B=6<@/2`D9&5B=6<[#0H@("`@
M("`@("1T:&ES+3Y?=&UP9&ER(#T@)'1M<&1I<CL-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!4=7)N(&]F9B!V86QI9&%T:6]N("T@<F5T=7)N(&$@<&%R
M<V5D('!A8VMA9V4N>&UL('=I=&AO=70@8VAE8VMI;F<@:70-"B`@("`@*@T*
M("`@("`J(%1H:7,@:7,@=7-E9"!B>2!T:&4@<&%C:V%G92UV86QI9&%T92!C
M;VUM86YD#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F%W4F5T=7)N*"D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<F%W4F5T=7)N(#T@=')U93L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!S971,;V=G97(H)B1L*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]L;V=G97(@/2`F)&P[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0W)E871E(&$@4$5!4E]086-K86=E1FEL95]087)S97)?=BH@;V8@
M82!G:79E;B!V97)S:6]N+@T*("`@("`J($!P87)A;2`@(&EN="`D=F5R<VEO
M;@T*("`@("`J($!R971U<FX@(%!%05)?4&%C:V%G949I;&5?4&%R<V5R7W8Q
M?%!%05)?4&%C:V%G949I;&5?4&%R<V5R7W8Q#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)G!A<G-E<D9A8W1O<GDH)'9E<G-I;VXI#0H@("`@>PT*("`@("`@
M("!I9B`H(6EN7V%R<F%Y*"1V97)S:6]N>S!]+"!A<G)A>2@G,2<L("<R)RDI
M*2![#0H@("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@<F5T
M=7)N("1A.PT*("`@("`@("!]#0H@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!
M4B]086-K86=E1FEL92]087)S97(O=B<@+B`D=F5R<VEO;GLP?2`N("<N<&AP
M)SL-"B`@("`@("`@)'9E<G-I;VX@/2`D=F5R<VEO;GLP?3L-"B`@("`@("`@
M)&-L87-S(#T@(E!%05)?4&%C:V%G949I;&5?4&%R<V5R7W8D=F5R<VEO;B([
M#0H@("`@("`@("1A(#T@;F5W("1C;&%S<SL-"B`@("`@("`@<F5T=7)N("1A
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($9O<B!S:6UP;&5R('5N:70M
M=&5S=&EN9PT*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T0VQA<W-0<F5F:7@H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("=014%27U!A8VMA9V5&:6QE7W8G.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G949I;&5?=BH@;V8@82!G:79E
M;B!V97)S:6]N+@T*("`@("`J($!P87)A;2`@(&EN="`D=F5R<VEO;@T*("`@
M("`J($!R971U<FX@(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E
M1FEL95]V,0T*("`@("`J+PT*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1V97)S
M:6]N*0T*("`@('L-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D=F5R<VEO;GLP
M?2P@87)R87DH)S$G+"`G,B<I*2D@>PT*("`@("`@("`@("`@)&$@/2!F86QS
M93L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@("`@
M("!I;F-L=61E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=B<@+B`D=F5R<VEO
M;GLP?2`N("<N<&AP)SL-"B`@("`@("`@)'9E<G-I;VX@/2`D=F5R<VEO;GLP
M?3L-"B`@("`@("`@)&-L87-S(#T@)'1H:7,M/F=E=$-L87-S4')E9FEX*"D@
M+B`D=F5R<VEO;CL-"B`@("`@("`@)&$@/2!N97<@)&-L87-S.PT*("`@("`@
M("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0W)E871E
M(&$@4$5!4E]086-K86=E1FEL95]V*B!F<F]M(&ET<R!T;T%R<F%Y*"D@;65T
M:&]D#0H@("`@("H-"B`@("`@*B!705).24Y'.B!N;R!V86QI9&%T:6]N(&ES
M('!E<F9O<FUE9"P@=&AE(&%R<F%Y(&ES(&%S<W5M960@=&\@8F4@=F%L:60L
M#0H@("`@("H@86QW87ES('!A<G-E(&9R;VT@>&UL(&EF('EO=2!W86YT('9A
M;&ED871I;VXN#0H@("`@("H@0'!A<F%M("`@87)R87D@)&%R<@T*("`@("`J
M($!R971U<FX@4$5!4E]086-K86=E1FEL94UA;F%G97)?=C%\4$5!4E]086-K
M86=E1FEL94UA;F%G97)?=C(-"B`@("`@*B!`=7-E<R`@("!F86-T;W)Y*"D@
M=&\@8V]N<W1R=6-T('1H92!R971U<FYE9"!O8FIE8W0N#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@)F9R;VU!<G)A>2@D87)R*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1A<G);)WAS9'9E<G-I;VXG72DI('L-"B`@("`@("`@("`@
M("1O8FH@/2`F)'1H:7,M/F9A8W1O<GDH)&%R<ELG>'-D=F5R<VEO;B==*3L-
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VQO9V=E<BD@>PT*("`@("`@("`@
M("`@("`@("1O8FHM/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D;V)J+3YS971#;VYF:6<H)'1H:7,M
M/E]C;VYF:6<I.PT*("`@("`@("`@("`@)&]B:BT^9G)O;4%R<F%Y*"1A<G(I
M.PT*("`@("`@("`@("`@<F5T=7)N("1O8FH[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&%R<ELG<&%C:V%G92==6R=A='1R
M:6)S)UU;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`D;V)J(#T@
M)B1T:&ES+3YF86-T;W)Y*"1A<G);)W!A8VMA9V4G75LG871T<FEB<R==6R=V
M97)S:6]N)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D;V)J(#T@)B1T:&ES+3YF86-T;W)Y*"<Q+C`G*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VQO9V=E<BD@>PT*("`@
M("`@("`@("`@("`@("1O8FHM/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;V)J+3YS971#;VYF:6<H
M)'1H:7,M/E]C;VYF:6<I.PT*("`@("`@("`@("`@)&]B:BT^9G)O;4%R<F%Y
M*"1A<G(I.PT*("`@("`@("`@("`@<F5T=7)N("1O8FH[#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@82!014%27U!A8VMA
M9V5&:6QE7W8J(&9R;VT@86X@6$U,('-T<FEN9RX-"B`@("`@*B!`86-C97-S
M("!P=6)L:6,-"B`@("`@*B!`<&%R86T@("!S=')I;F<@)&1A=&$@8V]N=&5N
M=',@;V8@<&%C:V%G92YX;6P@9FEL90T*("`@("`J($!P87)A;2`@(&EN="`D
M<W1A=&4@<&%C:V%G92!S=&%T92`H;VYE(&]F(%!%05)?5D%,241!5$5?*B!C
M;VYS=&%N=',I#0H@("`@("H@0'!A<F%M("`@<W1R:6YG("1F:6QE(&9U;&P@
M<&%T:"!T;R!T:&4@<&%C:V%G92YX;6P@9FEL92`H86YD('1H92!F:6QE<PT*
M("`@("`J("`@("`@("`@(&ET(')E9F5R96YC97,I#0H@("`@("H@0'!A<F%M
M("`@<W1R:6YG("1A<F-H:79E(&]P=&EO;F%L(&YA;64@;V8@=&AE(&%R8VAI
M=F4@=&AA="!T:&4@6$U,('=A<PT*("`@("`J("`@("`@("`@(&5X=')A8W1E
M9"!F<F]M+"!I9B!A;GD-"B`@("`@*B!`<F5T=7)N("!014%27U!A8VMA9V5&
M:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`=7-E<R`@("!P
M87)S97)&86-T;W)Y*"D@=&\@8V]N<W1R=6-T(&$@<&%R<V5R('1O(&QO860@
M=&AE('!A8VMA9V4N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F9R;VU8;6Q3
M=')I;F<H)&1A=&$L("1S=&%T92P@)&9I;&4L("1A<F-H:79E(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H<')E9U]M871C:"@G+SQP86-K86=E6UX^
M72MV97)S:6]N/2(H6S`M.5TK7"Y;,"TY72LI(B\G+"`D9&%T82P@)'!A8VMA
M9V5V97)S:6]N*2D@>PT*("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D<&%C
M:V%G979E<G-I;VY;,5TL(&%R<F%Y*"<Q+C`G+"`G,BXP)RDI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A8VMA9V4N
M>&UL('9E<G-I;VX@(B<@+B`D<&%C:V%G979E<G-I;VY;,5T@+@T*("`@("`@
M("`@("`@("`@("`@("`G(B!I<R!N;W0@<W5P<&]R=&5D+"!O;FQY(#$N,"!A
M;F0@,BXP(&%R92!S=7!P;W)T960N)RD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D;V)J96-T(#T@)B1T:&ES+3YP87)S97)&86-T;W)Y*"1P86-K
M86=E=F5R<VEO;ELQ72D[#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]L;V=G
M97(I('L-"B`@("`@("`@("`@("`@("`D;V)J96-T+3YS971,;V=G97(H)'1H
M:7,M/E]L;V=G97(I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&]B
M:F5C="T^<V5T0V]N9FEG*"1T:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@
M("1P9B`]("1O8FIE8W0M/G!A<G-E*"1D871A+"`D9FEL92P@)&%R8VAI=F4I
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D<&8[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]R87=2971U<FXI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@)'!F.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1P9BT^=F%L:61A=&4H)'-T871E*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^7VQO9V=E<BD@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H9F%L<V4I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E=%9A;&ED871I
M;VY787)N:6YG<R@I(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@P+"`G5T%23DE.1SH@
M)R`N("1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1P9BP@
M)V9L871T96Y&:6QE;&ES="<I*2![#0H@("`@("`@("`@("`@("`@("`@("1P
M9BT^9FQA='1E;D9I;&5L:7-T*"D[("\O(&9O<B!V,@T*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@)'!F.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C;VYF
M:6<M/F=E="@G=F5R8F]S92<I(#X@,"D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]L;V=G97(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D<&8M/F=E=%9A;&ED871I;VY787)N:6YG<RAF86QS92DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E
M=%9A;&ED871I;VY787)N:6YG<RAF86QS92D@87,@)'=A<FYI;F<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M
M/FQO9R@P+"`G15)23U(Z("<@+B`D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@)&$@/2!014%2.CIR86ES945R<F]R
M*"=087)S:6YG(&]F('!A8VMA9V4N>&UL(&9R;VT@9FEL92`B)R`N("1F:6QE
M("X@)R(@9F%I;&5D)RP-"B`@("`@("`@("`@("`@("`@("`@,BP@;G5L;"P@
M;G5L;"P@)'!F+3YG971686QI9&%T:6]N5V%R;FEN9W,H*2D[#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V5I9B`H<')E9U]M871C:"@G+SQP86-K86=E6UX^72MV97)S:6]N/2(H
M6UXB72LI(B\G+"`D9&%T82P@)'!A8VMA9V5V97)S:6]N*2D@>PT*("`@("`@
M("`@("`@)&$@/2!014%2.CIR86ES945R<F]R*"=P86-K86=E+GAM;"!F:6QE
M("(G("X@)&9I;&4@+@T*("`@("`@("`@("`@("`@("<B(&AA<R!U;G-U<'!O
M<G1E9"!P86-K86=E+GAM;"`\<&%C:V%G93X@=F5R<VEO;B`B)R`N("1P86-K
M86=E=F5R<VEO;ELQ72`N("<B)RD[#0H@("`@("`@("`@("!R971U<FX@)&$[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X
M:7-T<R@G4$5!4E]%<G)O<E-T86-K)RDI('L-"B`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O17)R;W)3=&%C:RYP:'`G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@4$5!4E]%<G)O<E-T86-K.CIS=&%T:6-0=7-H
M*"=014%27U!A8VMA9V5&:6QE)RP-"B`@("`@("`@("`@("`@("!014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7U!!0TM!1T5615)324].+`T*("`@("`@("`@
M("`@("`@("=W87)N:6YG)RP@87)R87DH)WAM;"<@/3X@)&1A=&$I+"`G<&%C
M:V%G92YX;6P@(B<@+B`D9FEL92`N#0H@("`@("`@("`@("`@("`@("`@("<B
M(&AA<R!N;R!P86-K86=E+GAM;"`\<&%C:V%G93X@=F5R<VEO;B<I.PT*("`@
M("`@("`@("`@)&]B:F5C="`]("8D=&AI<RT^<&%R<V5R1F%C=&]R>2@G,2XP
M)RD[#0H@("`@("`@("`@("`D;V)J96-T+3YS971#;VYF:6<H)'1H:7,M/E]C
M;VYF:6<I.PT*("`@("`@("`@("`@)'!F(#T@)&]B:F5C="T^<&%R<V4H)&1A
M=&$L("1F:6QE+"`D87)C:&EV92D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P9CL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W)A=U)E
M='5R;BD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D<&8[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H)'!F+3YV86QI9&%T92@D<W1A=&4I
M*2![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?;&]G9V5R*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("@D<&8M/F=E=%9A;&ED871I;VY787)N
M:6YG<RAF86QS92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P9BT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"D@87,@)'=A<FYI;F<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VQO9V=E
M<BT^;&]G*#`L("=705).24Y'.B`G("X@)'=A<FYI;F=;)VUE<W-A9V4G72D[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*&UE=&AO9%]E>&ES=',H)'!F+"`G9FQA='1E;D9I;&5L:7-T)RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'!F+3YF;&%T=&5N1FEL96QI<W0H*3L@+R\@
M9F]R('8R#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B`D<&8[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1A(#T@4$5!4CHZ<F%I<V5%<G)O<B@G4&%R<VEN9R!O9B!P86-K86=E
M+GAM;"!F<F]M(&9I;&4@(B<@+B`D9FEL92`N("<B(&9A:6QE9"<L#0H@("`@
M("`@("`@("`@("`@("`@(#(L(&YU;&PL(&YU;&PL("1P9BT^9V5T5F%L:61A
M=&EO;E=A<FYI;F=S*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D83L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%)E9VES=&5R(&$@=&5M<&]R87)Y(&9I;&4@;W(@9&ER96-T;W)Y
M+B`@5VAE;B!T:&4@9&5S=')U8W1O<B!I<PT*("`@("`J(&5X96-U=&5D+"!A
M;&P@<F5G:7-T97)E9"!T96UP;W)A<GD@9FEL97,@86YD(&1I<F5C=&]R:65S
M(&%R90T*("`@("`J(')E;6]V960N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("`D9FEL92`@;F%M92!O9B!F:6QE(&]R(&1I<F5C=&]R>0T*("`@
M("`J($!R971U<FX@('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&14
M96UP1FEL92@D9FEL92D-"B`@("![#0H@("`@("`@("1'3$]"04Q36R=?4$5!
M4E]#;VUM;VY?=&5M<&9I;&5S)UU;72`]("1F:6QE.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($-R96%T92!A(%!%05)?4&%C:V%G949I;&5?=BH@9G)O
M;2!A(&-O;7!R97-E9"!487(@;W(@5&=Z(&9I;&4N#0H@("`@("H@0&%C8V5S
M<R`@<'5B;&EC#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYT96YT<R!O9B!P
M86-K86=E+GAM;"!F:6QE#0H@("`@("H@0'!A<F%M(&EN="!P86-K86=E('-T
M871E("AO;F4@;V8@4$5!4E]604Q)1$%415\J(&-O;G-T86YT<RD-"B`@("`@
M*B!`<F5T=7)N("!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I
M;&5?=C(-"B`@("`@*B!`=7-I;F<@("!!<F-H:79E7U1A<B!T;R!E>'1R86-T
M('1H92!F:6QE<PT*("`@("`J($!U<VEN9R`@(&9R;VU086-K86=E1FEL92@I
M('1O(&QO860@=&AE('!A8VMA9V4@869T97(@=&AE('!A8VMA9V4N>&UL#0H@
M("`@("H@("`@("`@("`@9FEL92!I<R!E>'1R86-T960N#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@)F9R;VU49WI&:6QE*"1F:6QE+"`D<W1A=&4I#0H@("`@
M>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G07)C:&EV95]487(G*2D@
M>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=!<F-H:79E+U1A<BYP:'`G
M.PT*("`@("`@("!]#0H@("`@("`@("1T87(@/2!N97<@07)C:&EV95]487(H
M)&9I;&4I.PT*("`@("`@("!I9B`H)'1H:7,M/E]D96)U9R`\/2`Q*2![#0H@
M("`@("`@("`@("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]2
M7U)%5%523BD[#0H@("`@("`@('T-"B`@("`@("`@)&-O;G1E;G0@/2`D=&%R
M+3YL:7-T0V]N=&5N="@I.PT*("`@("`@("!I9B`H)'1H:7,M/E]D96)U9R`\
M/2`Q*2![#0H@("`@("`@("`@("`D=&%R+3YP;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D8V]N=&5N="DI
M('L-"B`@("`@("`@("`@(&EF("AI<U]S=')I;F<H)&9I;&4I("8F('-T<FQE
M;B@D9FEL92`\(#(U-2D@)B8@(4!I<U]F:6QE*"1F:6QE*2D@>PT*("`@("`@
M("`@("`@("`@("1R970@/2!014%2.CIR86ES945R<F]R*")C;W5L9"!N;W0@
M;W!E;B!F:6QE(%PB)&9I;&5<(B(I.PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&9I;&4@/2!R
M96%L<&%T:"@D9FEL92D[#0H@("`@("`@("`@("`D<F5T(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@B0V]U;&0@;F]T(&=E="!C;VYT96YT<R!O9B!P86-K86=E(%PB
M)&9I;&5<(B(N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)RX@26YV86QI9"!T9WH@9FEL92XG*3L-"B`@("`@("`@("`@(')E='5R
M;B`D<F5T.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@*"%C
M;W5N="@D8V]N=&5N="D@)B8@(4!I<U]F:6QE*"1F:6QE*2D@>PT*("`@("`@
M("`@("`@("`@("1R970@/2!014%2.CIR86ES945R<F]R*")C;W5L9"!N;W0@
M;W!E;B!F:6QE(%PB)&9I;&5<(B(I.PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5T.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1X
M;6P@/2!N=6QL.PT*("`@("`@("`D;W)I9V9I;&4@/2`D9FEL93L-"B`@("`@
M("`@9F]R96%C:"`H)&-O;G1E;G0@87,@)&9I;&4I('L-"B`@("`@("`@("`@
M("1N86UE(#T@)&9I;&5;)V9I;&5N86UE)UT[#0H@("`@("`@("`@("!I9B`H
M)&YA;64@/3T@)W!A8VMA9V4R+GAM;"<I('L@+R\@86QL;W<@82`N=&=Z('1O
M(&1I<W1R:6)U=&4@8F]T:"!V97)S:6]N<PT*("`@("`@("`@("`@("`@("1X
M;6P@/2`D;F%M93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@D;F%M92`]/2`G<&%C:V%G92YX;6PG
M*2![#0H@("`@("`@("`@("`@("`@)'AM;"`]("1N86UE.PT*("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@?2!E;'-E:68@*&5R96<H)W!A
M8VMA9V4N>&UL)"<L("1N86UE+"`D;6%T8V@I*2![#0H@("`@("`@("`@("`@
M("`@)'AM;"`]("1N86UE.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7W1M
M<&1I<BD@>PT*("`@("`@("`@("`@)'1M<&1I<B`]("1T:&ES+3Y?=&UP9&ER
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1M<&1I<B`](%-Y
M<W1E;3HZ;6M496UP*&%R<F%Y*"<M9"<L("=P96%R)RDI.PT*("`@("`@("`@
M("`@4$5!4E]086-K86=E1FEL93HZ861D5&5M<$9I;&4H)'1M<&1I<BD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"$D>&UL('Q\("$D=&%R+3YE>'1R86-T
M3&ES="AA<G)A>2@D>&UL*2P@)'1M<&1I<BDI('L-"B`@("`@("`@("`@("1R
M970@/2!014%2.CIR86ES945R<F]R*"=C;W5L9"!N;W0@97AT<F%C="!T:&4@
M<&%C:V%G92YX;6P@9FEL92!F<F]M("(G("X-"B`@("`@("`@("`@("`@("`D
M;W)I9V9I;&4@+B`G(B<I.PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`]("9014%27U!A8VMA9V5&:6QE.CIF
M<F]M4&%C:V%G949I;&4H(B1T;7!D:7(O)'AM;"(L("1S=&%T92P@)&]R:6=F
M:6QE*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0W)E871E(&$@4$5!4E]086-K86=E1FEL95]V*B!F<F]M(&$@
M<&%C:V%G92YX;6P@9FEL92X-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D9&5S8V9I;&4@(&YA;64@
M;V8@<&%C:V%G92!X;6P@9FEL90T*("`@("`J($!P87)A;2`@(&EN="`@("`@
M)'-T871E('!A8VMA9V4@<W1A=&4@*&]N92!O9B!014%27U9!3$E$051%7RH@
M8V]N<W1A;G1S*0T*("`@("`J($!P87)A;2`@('-T<FEN9WQF86QS92`D87)C
M:&EV92!N86UE(&]F('1H92!A<F-H:79E('1H:7,@<&%C:V%G92YX;6P@8V%M
M90T*("`@("`J("`@("`@("`@(&9R;VTL(&EF(&%N>0T*("`@("`J($!R971U
M<FX@(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL95]V,@T*
M("`@("`J($!U<V5S("`@(%!%05)?4&%C:V%G949I;&4Z.F9R;VU8;6Q3=')I
M;F<@=&\@8W)E871E('1H92!O:F5C="!A9G1E<B!T:&4-"B`@("`@*B`@("`@
M("`@("!834P@:7,@;&]A9&5D(&9R;VT@=&AE('!A8VMA9V4N>&UL(&9I;&4N
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F9R;VU086-K86=E1FEL92@D9&5S
M8V9I;&4L("1S=&%T92P@)&%R8VAI=F4@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(&EF("AI<U]S=')I;F<H)&1E<V-F:6QE*2`F)B!S=')L96XH)&1E<V-F
M:6QE*2`\(#(U-2`F)@T*("`@("`@("`@("`@("%`:7-?9FEL92@D9&5S8V9I
M;&4I('Q\("%I<U]R96%D86)L92@D9&5S8V9I;&4I('Q\#0H@("`@("`@("`@
M("`@*"$D9G`@/2!`9F]P96XH)&1E<V-F:6QE+"`G<B<I*2D@>PT*("`@("`@
M("`@("`@)&$@/2!014%2.CIR86ES945R<F]R*")5;F%B;&4@=&\@;W!E;B`D
M9&5S8V9I;&4B*3L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O(')E860@=&AE('=H;VQE('1H:6YG('-O('=E(&]N
M;'D@9V5T(&]N92!C9&%T82!C86QL8F%C:PT*("`@("`@("`O+R!F;W(@96%C
M:"!B;&]C:R!O9B!C9&%T80T*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S
M*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!`9F-L;W-E
M*"1F<"D[#0H@("`@("`@("`@("`D9&%T82`](&9I;&5?9V5T7V-O;G1E;G1S
M*"1D97-C9FEL92D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M9&%T82`]("<G.PT*("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1F<"DI('L-
M"B`@("`@("`@("`@("`@("`D9&%T82`N/2!`9G)E860H)&9P+"`X,3DR*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("!]#0H@("`@("`@("1R970@/2`F4$5!4E]086-K86=E1FEL93HZ9G)O
M;5AM;%-T<FEN9R@D9&%T82P@)'-T871E+"`D9&5S8V9I;&4L("1A<F-H:79E
M*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H-"B`@("`O*BH-
M"B`@("`@*B!#<F5A=&4@82!014%27U!A8VMA9V5&:6QE7W8J(&9R;VT@82`N
M=&=Z(&%R8VAI=F4@;W(@<&%C:V%G92YX;6P@9FEL92X-"B`@("`@*@T*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&%B;&4@=&\@97AT<F%C="!I;F9O<FUA=&EO
M;B!A8F]U="!A('!A8VMA9V4@9G)O;2!A("YT9WH-"B`@("`@*B!A<F-H:79E
M(&]R(&9R;VT@82!834P@<&%C:V%G92!D969I;FET:6]N(&9I;&4N#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@)&EN9F\@9FEL92!N86UE#0H@("`@("H@0'!A<F%M("`@:6YT("`@
M("`D<W1A=&4@<&%C:V%G92!S=&%T92`H;VYE(&]F(%!%05)?5D%,241!5$5?
M*B!C;VYS=&%N=',I#0H@("`@("H@0')E='5R;B`@4$5!4E]086-K86=E1FEL
M95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'5S97,@("`@9G)O
M;5!A8VMA9V5&:6QE*"D@:68@=&AE(&9I;&4@87!P96%R<R!T;R!B92!834P-
M"B`@("`@*B!`=7-E<R`@("!F<F]M5&=Z1FEL92@I('1O(&QO860@86QL(&YO
M;BU834P@9FEL97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9G)O;4%N>49I
M;&4H)&EN9F\L("1S=&%T92D-"B`@("![#0H@("`@("`@("1F<"`](&9A;'-E
M.PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1I;F9O*2`F)B!S=')L96XH)&EN
M9F\I(#P@,C4U("8F#0H@("`@("`@("`@("`@*&9I;&5?97AI<W1S*"1I;F9O
M*2!\?"`H)&9P(#T@0&9O<&5N*"1I;F9O+"`G<B<I*2DI('L-"B`@("`@("`@
M("`@(&EF("@D9G`I('L-"B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T;7`@/2!S=6)S='(H)&EN
M9F\L("TT*3L-"B`@("`@("`@("`@(&EF("@D=&UP(#T]("<N>&UL)RD@>PT*
M("`@("`@("`@("`@("`@("1I;F9O(#T@)E!%05)?4&%C:V%G949I;&4Z.F9R
M;VU086-K86=E1FEL92@D:6YF;RP@)'-T871E*3L-"B`@("`@("`@("`@('T@
M96QS96EF("@D=&UP(#T]("<N=&%R)R!\?"`D=&UP(#T]("<N=&=Z)RD@>PT*
M("`@("`@("`@("`@("`@("1I;F9O(#T@)E!%05)?4&%C:V%G949I;&4Z.F9R
M;VU49WI&:6QE*"1I;F9O+"`D<W1A=&4I.PT*("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D:6YF;RP@(G(B*3L-
M"B`@("`@("`@("`@("`@("`D=&5S="`](&9R96%D*"1F<"P@-2D[#0H@("`@
M("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@:68@
M*"1T97-T(#T]("(\/WAM;"(I('L-"B`@("`@("`@("`@("`@("`@("`@)&EN
M9F\@/2`F4$5!4E]086-K86=E1FEL93HZ9G)O;5!A8VMA9V5&:6QE*"1I;F9O
M+"`D<W1A=&4I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O(#T@)E!%05)?4&%C:V%G949I;&4Z.F9R;VU4
M9WI&:6QE*"1I;F9O+"`D<W1A=&4I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1I
M;F9O(#T@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(&]P96X@)R1I;F9O)R!F
M;W(@<&%R<VEN9R(I.PT*("`@("`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D:6YF;SL-"B`@("!]#0I]#0H-"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U)E9VES=')Y+G!H
M<```````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,C$V,C(P
M(#$P-3$U-#,T,3,T(#`R,34S-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`T*+RHJ#0H@*B!014%27U)E9VES=')Y
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4F5G
M:7-T<GDN<&AP+'8@,2XQ-3`N,BXR(#(P,#8O,#,O,3$@,#0Z,38Z-#@@8V5L
M;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&9O<B!014%27T5R
M<F]R#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q=6ER95]O
M;F-E("=014%2+T1E<&5N9&5N8WE$0BYP:'`G.PT*#0ID969I;F4H)U!%05)?
M4D5'25-44EE?15)23U)?3$]#2R<L("`@+3(I.PT*9&5F:6YE*"=014%27U)%
M1TE35%)97T524D]27T9/4DU!5"<L("TS*3L-"F1E9FEN92@G4$5!4E]214=)
M4U1265]%4E)/4E]&24Q%)RP@("`M-"D[#0ID969I;F4H)U!%05)?4D5'25-4
M4EE?15)23U)?0T].1DQ)0U0G+"`M-2D[#0ID969I;F4H)U!%05)?4D5'25-4
M4EE?15)23U)?0TA!3DY%3%]&24Q%)RP@+38I.PT*#0HO*BH-"B`J($%D;6EN
M:7-T<F%T:6]N(&-L87-S('5S960@=&\@;6%I;G1A:6X@=&AE(&EN<W1A;&QE
M9"!P86-K86=E(&1A=&%B87-E+@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@
M/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BX@5BX@0V]X
M(#QC;WA`:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA
M<W,@4$5!4E]296=I<W1R>2!E>'1E;F1S(%!%05(-"GL-"B`@("`O+R![>WL@
M<')O<&5R=&EE<PT*#0H@("`@+RHJ#0H@("`@("H@1FEL92!C;VYT86EN:6YG
M(&%L;"!C:&%N;F5L(&EN9F]R;6%T:6]N+@T*("`@("`J($!V87(@<W1R:6YG
M#0H@("`@("HO#0H@("`@=F%R("1C:&%N;F5L<R`]("<G.PT*#0H@("`@+RHJ
M($1I<F5C=&]R>2!W:&5R92!R96=I<W1R>2!F:6QE<R!A<F4@<W1O<F5D+@T*
M("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1S=&%T961I
M<B`]("<G.PT*#0H@("`@+RHJ($9I;&4@=VAE<F4@=&AE(&9I;&4@;6%P(&ES
M('-T;W)E9`T*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R
M("1F:6QE;6%P(#T@)R<[#0H-"B`@("`O*BH@1&ER96-T;W)Y('=H97)E(')E
M9VES=')Y(&9I;&5S(&9O<B!C:&%N;F5L<R!A<F4@<W1O<F5D+@T*("`@("`J
M($!V87(@<W1R:6YG#0H@("`@("HO#0H@("`@=F%R("1C:&%N;F5L<V1I<B`]
M("<G.PT*#0H@("`@+RHJ($YA;64@;V8@9FEL92!U<V5D(&9O<B!L;V-K:6YG
M('1H92!R96=I<W1R>0T*("`@("`J($!V87(@<W1R:6YG#0H@("`@("HO#0H@
M("`@=F%R("1L;V-K9FEL92`]("<G.PT*#0H@("`@+RHJ($9I;&4@9&5S8W)I
M<'1O<B!U<V5D(&1U<FEN9R!L;V-K:6YG#0H@("`@("H@0'9A<B!R97-O=7)C
M90T*("`@("`J+PT*("`@('9A<B`D;&]C:U]F<"`](&YU;&P[#0H-"B`@("`O
M*BH@36]D92!U<V5D(&1U<FEN9R!L;V-K:6YG#0H@("`@("H@0'9A<B!I;G0-
M"B`@("`@*B\-"B`@("!V87(@)&QO8VM?;6]D92`](#`[("\O(%A86"!53E53
M140-"@T*("`@("\J*B!#86-H92!O9B!P86-K86=E(&EN9F]R;6%T:6]N+B`@
M4W1R=6-T=7)E.@T*("`@("`J(&%R<F%Y*`T*("`@("`J("`@)W!A8VMA9V4G
M(#T^(&%R<F%Y*"=I9"<@/3X@+BXN("DL#0H@("`@("H@("`N+BX@*0T*("`@
M("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@("!V87(@)'!K9VEN9F]?8V%C
M:&4@/2!A<G)A>2@I.PT*#0H@("`@+RHJ($-A8VAE(&]F(&9I;&4@;6%P+B`@
M4W1R=6-T=7)E.@T*("`@("`J(&%R<F%Y*"`G+W!A=&@O=&\O9FEL92<@/3X@
M)W!A8VMA9V4G+"`N+BX@*0T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-
M"B`@("!V87(@)&9I;&5M87!?8V%C:&4@/2!A<G)A>2@I.PT*#0H@("`@+RHJ
M#0H@("`@("H@0'9A<B!F86QS97Q014%27T-H86YN96Q&:6QE#0H@("`@("HO
M#0H@("`@=F%R("1?<&5A<D-H86YN96P[#0H-"B`@("`O*BH-"B`@("`@*B!`
M=F%R(&9A;'-E?%!%05)?0VAA;FYE;$9I;&4-"B`@("`@*B\-"B`@("!V87(@
M)%]P96-L0VAA;FYE;#L-"@T*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]$
M97!E;F1E;F-Y1$(-"B`@("`@*B\-"B`@("!V87(@)%]D97!E;F1E;F-Y1$([
M#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?0V]N9FEG#0H@("`@("HO
M#0H@("`@=F%R("1?8V]N9FEG.PT*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27U)E9VES=')Y
M(&-O;G-T<G5C=&]R+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`H
M;W!T:6]N86PI(%!%05(@:6YS=&%L;"!D:7)E8W1O<GD@*&9O<B`N<&AP(&9I
M;&5S*0T*("`@("`J($!P87)A;2!014%27T-H86YN96Q&:6QE(%!%05)?0VAA
M;FYE;$9I;&4@;V)J96-T(')E<')E<V5N=&EN9R!T:&4@4$5!4B!C:&%N;F5L
M+"!I9@T*("`@("`J("`@("`@("!D969A=6QT('9A;'5E<R!A<F4@;F]T(&1E
M<VER960N("!/;FQY('5S960@=&AE('9E<GD@9FER<W0@=&EM92!A(%!%05(-
M"B`@("`@*B`@("`@("`@<F5P;W-I=&]R>2!I<R!I;FET:6%L:7IE9`T*("`@
M("`J($!P87)A;2!014%27T-H86YN96Q&:6QE(%!%05)?0VAA;FYE;$9I;&4@
M;V)J96-T(')E<')E<V5N=&EN9R!T:&4@4$5#3"!C:&%N;F5L+"!I9@T*("`@
M("`J("`@("`@("!D969A=6QT('9A;'5E<R!A<F4@;F]T(&1E<VER960N("!/
M;FQY('5S960@=&AE('9E<GD@9FER<W0@=&EM92!A(%!%05(-"B`@("`@*B`@
M("`@("`@<F5P;W-I=&]R>2!I<R!I;FET:6%L:7IE9`T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%2
M7U)E9VES=')Y*"1P96%R7VEN<W1A;&Q?9&ER(#T@4$5!4E])3E-404Q,7T1)
M4BP@)'!E87)?8VAA;FYE;"`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!E8VQ?8VAA;FYE;"`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@<&%R96YT.CI014%2*"D[#0H@("`@("`@("1D<R`]($1)4D5#5$]265]3
M15!!4D%43U([#0H@("`@("`@("1T:&ES+3YI;G-T86QL7V1I<B`]("1P96%R
M7VEN<W1A;&Q?9&ER.PT*("`@("`@("`D=&AI<RT^8VAA;FYE;'-D:7(@/2`D
M<&5A<E]I;G-T86QL7V1I<BXD9',N)RYC:&%N;F5L<R<[#0H@("`@("`@("1T
M:&ES+3YS=&%T961I<B`]("1P96%R7VEN<W1A;&Q?9&ER+B1D<RXG+G)E9VES
M=')Y)SL-"B`@("`@("`@)'1H:7,M/F9I;&5M87`@(#T@)'!E87)?:6YS=&%L
M;%]D:7(N)&1S+B<N9FEL96UA<"<[#0H@("`@("`@("1T:&ES+3YL;V-K9FEL
M92`]("1P96%R7VEN<W1A;&Q?9&ER+B1D<RXG+FQO8VLG.PT*("`@("`@("`D
M=&AI<RT^7W!E87)#:&%N;F5L(#T@)'!E87)?8VAA;FYE;#L-"B`@("`@("`@
M)'1H:7,M/E]P96-L0VAA;FYE;"`]("1P96-L7V-H86YN96P[#0H@("`@("`@
M("1T:&ES+3Y?8V]N9FEG(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@:&%S5W)I=&5!8V-E<W,H*0T*("`@('L-"B`@("`@("`@:68@*"%`9FEL
M95]E>&ES=',H)'1H:7,M/FEN<W1A;&Q?9&ER*2D@>PT*("`@("`@("`@("`@
M)&1I<B`]("1T:&ES+3YI;G-T86QL7V1I<CL-"B`@("`@("`@("`@('=H:6QE
M("@D9&ER("8F("1D:7(@(3T@)RXG*2![#0H@("`@("`@("`@("`@("`@)&1I
M<B`](&1I<FYA;64H)&1I<BD[("\O(&-D("XN#0H@("`@("`@("`@("`@("`@
M:68@*"1D:7(@(3T@)RXG("8F($!F:6QE7V5X:7-T<R@D9&ER*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H0&ES7W=R:71E86)L92@D9&ER*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N($!I<U]W<FET
M96%B;&4H)'1H:7,M/FEN<W1A;&Q?9&ER*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!S971#;VYF:6<H)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7V-O;F9I9R`]("8D8V]N9FEG.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(%]I;FET:6%L:7IE0VAA;FYE;$1I<G,H*0T*("`@('L-"B`@("`@("`@<W1A
M=&EC("1R=6YN:6YG(#T@9F%L<V4[#0H@("`@("`@(&EF("@A)')U;FYI;F<I
M('L-"B`@("`@("`@("`@("1R=6YN:6YG(#T@=')U93L-"B`@("`@("`@("`@
M("1D<R`]($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@("`@("!I9B`H
M(6ES7V1I<B@D=&AI<RT^8VAA;FYE;'-D:7(I('Q\#0H@("`@("`@("`@("`@
M("`@("`A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@
M)W!E87(N<&AP+FYE="YR96<G*2!\?`T*("`@("`@("`@("`@("`@("`@(69I
M;&5?97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I<B`N("1D<R`N("=P96-L+G!H
M<"YN970N<F5G)RD@?'P-"B`@("`@("`@("`@("`@("`@("%F:6QE7V5X:7-T
M<R@D=&AI<RT^8VAA;FYE;'-D:7(@+B`D9',@+B`G7U]U<FDN<F5G)RDI('L-
M"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1T:&ES+3YC:&%N
M;F5L<V1I<B`N("1D<R`N("=P96%R+G!H<"YN970N<F5G)RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE;"`]("1T:&ES+3Y?<&5A<D-H
M86YN96P[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?82@D<&5A<E]C
M:&%N;F5L+"`G4$5!4E]#:&%N;F5L1FEL92<I('Q\("$D<&5A<E]C:&%N;F5L
M+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N;F5L1FEL92<I*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN
M96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L(#T@;F5W(%!%05)?
M0VAA;FYE;$9I;&4[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C
M:&%N;F5L+3YS971.86UE*"=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$%L:6%S*"=P96%R)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS9713
M97)V97(H)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!E87)?8VAA;FYE;"T^<V5T4W5M;6%R>2@G4$A0($5X=&5N<VEO;B!A
M;F0@07!P;&EC871I;VX@4F5P;W-I=&]R>2<I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T1&5F875L=%!%05)0<F]T;V-O
M;',H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96%R7V-H86YN96PM
M/G-E=$)A<V554DPH)U)%4U0Q+C`G+"`G:'1T<#HO+W!E87(N<&AP+FYE="]R
M97-T+R<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE
M;"T^<V5T0F%S95523"@G4D535#$N,2<L("=H='1P.B\O<&5A<BYP:'`N;F5T
M+W)E<W0O)RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971.86UE*"=P
M96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P96%R
M7V-H86YN96PM/G-E=$%L:6%S*"=P96%R)RD[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^=F%L
M:61A=&4H*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1#:&%N
M;F5L*"1P96%R7V-H86YN96PI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1T:&ES+3YC:&%N;F5L<V1I
M<B`N("1D<R`N("=P96-L+G!H<"YN970N<F5G)RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'!E8VQ?8VAA;FYE;"`]("1T:&ES+3Y?<&5C;$-H86YN96P[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?82@D<&5C;%]C:&%N;F5L
M+"`G4$5!4E]#:&%N;F5L1FEL92<I('Q\("$D<&5C;%]C:&%N;F5L+3YV86QI
M9&%T92@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]#:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN96Q&:6QE
M+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L(#T@;F5W(%!%05)?0VAA;FYE
M;$9I;&4[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L
M+3YS971.86UE*"=P96-L+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P96-L7V-H86YN96PM/G-E=$%L:6%S*"=P96-L)RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YS971397)V97(H
M)W!E8VPN<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E
M8VQ?8VAA;FYE;"T^<V5T4W5M;6%R>2@G4$A0($5X=&5N<VEO;B!#;VUM=6YI
M='D@3&EB<F%R>2<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E8VQ?
M8VAA;FYE;"T^<V5T1&5F875L=%!%05)0<F]T;V-O;',H*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P96-L7V-H86YN96PM/G-E=$)A<V554DPH)U)%
M4U0Q+C`G+"`G:'1T<#HO+W!E8VPN<&AP+FYE="]R97-T+R<I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!E8VQ?8VAA;FYE;"T^<V5T0F%S95523"@G
M4D535#$N,2<L("=H='1P.B\O<&5C;"YP:'`N;F5T+W)E<W0O)RD[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YS971686QI9&%T
M:6]N4&%C:V%G92@G4$5!4E]686QI9&%T;W)?4$5#3"<L("<Q+C`G*3L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P96-L7V-H86YN96PM/G-E=$YA;64H)W!E8VPN<&AP+FYE="<I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!E8VQ?8VAA;FYE;"T^<V5T
M06QI87,H)W!E8VPG*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D<&5C;%]C:&%N;F5L+3YV86QI9&%T92@I.PT*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$-H86YN96PH)'!E8VQ?8VAA
M;FYE;"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@)U]?
M=7)I+G)E9R<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1P<FEV871E(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[#0H@("`@("`@("`@
M("`@("`@("`@("1P<FEV871E+3YS971.86UE*"=?7W5R:2<I.PT*("`@("`@
M("`@("`@("`@("`@("`D<')I=F%T92T^861D1G5N8W1I;VXH)WAM;')P8R<L
M("<Q+C`G+"`G*BHJ*B<I.PT*("`@("`@("`@("`@("`@("`@("`D<')I=F%T
M92T^<V5T4W5M;6%R>2@G4'-E=61O+6-H86YN96P@9F]R('-T871I8R!P86-K
M86=E<R<I.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$-H86YN
M96PH)'!R:79A=&4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<G5N;FEN9R`](&9A;'-E.PT*("`@("`@("!]#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN:71I86QI>F5$:7)S*"D-"B`@("![
M#0H@("`@("`@("1D<R`]($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@
M("\O(%A86"!#;VUP871I8FEL:71Y(&-O9&4@<VAO=6QD(&)E(')E;6]V960@
M:6X@=&AE(&9U='5R90T*("`@("`@("`O+R!R96YA;64@86QL(')E9VES=')Y
M(&9I;&5S(&EF(&%N>2!T;R!L;W=E<F-A<V4-"B`@("`@("`@:68@*"%/4U]7
M24Y$3U=3("8F("1H86YD;&4@/2!`;W!E;F1I<B@D=&AI<RT^<W1A=&5D:7(I
M*2![#0H@("`@("`@("`@("`D9&5S="`]("1T:&ES+3YS=&%T961I<B`N("1D
M<SL-"B`@("`@("`@("`@('=H:6QE("AF86QS92`A/3T@*"1F:6QE(#T@<F5A
M9&1I<B@D:&%N9&QE*2DI('L-"B`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G+UXN*EM!+5I=+BI<+G)E9R0O)RP@)&9I;&4I*2![#0H@("`@("`@
M("`@("`@("`@("`@(')E;F%M92@D9&5S="`N("1F:6QE+"`D9&5S="`N('-T
M<G1O;&]W97(H)&9I;&4I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!C;&]S961I<B@D:&%N9&QE*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7VEN:71I86QI>F5#:&%N;F5L1&ER<R@I
M.PT*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1T:&ES+3YF:6QE;6%P*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]R96)U:6QD1FEL94UA<"@I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?:6YI=&EA;&EZ941E<$1"*"D[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7VEN:71I86QI>F5$97!$0B@I#0H@("`@
M>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?9&5P96YD96YC>41"*2D@
M>PT*("`@("`@("`@("`@<W1A=&EC("1I;FET:6%L:7II;F<@/2!F86QS93L-
M"B`@("`@("`@("`@(&EF("@A)&EN:71I86QI>FEN9RD@>PT*("`@("`@("`@
M("`@("`@("1I;FET:6%L:7II;F<@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]C;VYF:6<I('L@+R\@;F5V97(@=7-E9#\-"B`@("`@
M("`@("`@("`@("`@("`@:68@*$]37U=)3D1/5U,I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6QE(#T@)W!E87(N:6YI)SL-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@)RYP96%R<F,G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)FYE=R!014%27T-O
M;F9I9R@D=&AI<RT^<W1A=&5D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE*3L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C;VYF:6<M/G-E=%)E9VES=')Y*"1T:&ES*3L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VYF:6<M/G-E="@G<&AP
M7V1I<B<L("1T:&ES+3YI;G-T86QL7V1I<BD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"(#T@)E!%
M05)?1&5P96YD96YC>41".CIS:6YG;&5T;VXH)'1H:7,M/E]C;VYF:6<I.PT*
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?9&5P
M96YD96YC>41"*2D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!A='1E;7!T
M('1O(')E8V]V97(@8GD@<F5M;W9I;F<@=&AE(&1E<"!D8@T*("`@("`@("`@
M("`@("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?8V]N9FEG+3YG970H)W!H<%]D
M:7(G+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RD@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@1$E214-43U)97U-%4$%2051/4B`N("<N9&5P9&(G*3L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(@/2`F4$5!
M4E]$97!E;F1E;F-Y1$(Z.G-I;F=L971O;B@D=&AI<RT^7V-O;F9I9RD[#0H@
M("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?
M9&5P96YD96YC>41"*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@96-H
M;R`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^9V5T365S<V%G92@I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@9&EE*"=5;G)E8V]V97)A8FQE(&5R<F]R)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&EN:71I86QI>FEN9R`](&9A;'-E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D97-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27U)E9VES
M=')Y(&1E<W1R=6-T;W(N("!-86ME<R!S=7)E(&YO(&QO8VMS(&%R92!F;W)G
M;W1T96XN#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?4$5!4E]296=I<W1R>2@I#0H@("`@>PT*("`@
M("`@("!P87)E;G0Z.E]014%2*"D[#0H@("`@("`@(&EF("AI<U]R97-O=7)C
M92@D=&AI<RT^;&]C:U]F<"DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=6YL
M;V-K*"D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!?87-S97)T4W1A=&5$:7(H*0T*#0H@("`@+RHJ#0H@("`@("H@
M36%K92!S=7)E('1H92!D:7)E8W1O<GD@=VAE<F4@=V4@:V5E<"!R96=I<W1R
M>2!F:6QE<R!E>&ES=',N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M5%)512!I9B!D:7)E8W1O<GD@97AI<W1S+"!&04Q312!I9B!I="!C;W5L9"!N
M;W0@8F4-"B`@("`@*B!C<F5A=&5D#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?87-S97)T4W1A=&5$
M:7(H)&-H86YN96P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D8VAA
M;FYE;"`F)B`D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI
M("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]A<W-E<G1#:&%N;F5L4W1A=&5$:7(H)&-H86YN96PI.PT*("`@("`@
M("!]#0H@("`@("`@('-T871I8R`D:6YI="`](&9A;'-E.PT*("`@("`@("!I
M9B`H(4!I<U]D:7(H)'1H:7,M/G-T871E9&ER*2D@>PT*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("!I9B`H
M(5-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@)'1H:7,M/G-T871E9&ER*2DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F-O=6QD(&YO="!C<F5A=&4@9&ER96-T;W)Y("=[)'1H:7,M/G-T871E9&ER
M?2<B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1I;FET(#T@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("`D9',@/2!$25)%0U1/4EE?4T5005)!
M5$]2.PT*("`@("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M/F-H86YN96QS9&ER
M*2!\?`T*("`@("`@("`@("`@("`A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN
M96QS9&ER("X@)&1S("X@)W!E87(N<&AP+FYE="YR96<G*2!\?`T*("`@("`@
M("`@("`@("`A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S
M("X@)W!E8VPN<&AP+FYE="YR96<G*2!\?`T*("`@("`@("`@("`@("`A9FEL
M95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER("X@)&1S("X@)U]?=7)I+G)E
M9R<I*2![#0H@("`@("`@("`@("`D:6YI="`]('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1I;FET*2![#0H@("`@("`@("`@("!S=&%T:6,@)')U
M;FYI;F<@/2!F86QS93L-"B`@("`@("`@("`@(&EF("@A)')U;FYI;F<I('L-
M"B`@("`@("`@("`@("`@("`D<G5N;FEN9R`]('1R=64[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;FET:6%L:7IE1&ER<R@I.PT*("`@("`@("`@("`@
M("`@("1R=6YN:6YG(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@)&EN:70@
M/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("1T:&ES+3Y?:6YI=&EA;&EZ941E<$1"*"D[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(%]A<W-E<G1#:&%N;F5L4W1A=&5$:7(H*0T*#0H@("`@
M+RHJ#0H@("`@("H@36%K92!S=7)E('1H92!D:7)E8W1O<GD@=VAE<F4@=V4@
M:V5E<"!R96=I<W1R>2!F:6QE<R!E>&ES=',@9F]R(&$@;F]N+7-T86YD87)D
M(&-H86YN96PN#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN
M96P@;F%M90T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&EF(&1I<F5C=&]R
M>2!E>&ES=',L($9!3%-%(&EF(&ET(&-O=6QD(&YO="!B90T*("`@("`J(&-R
M96%T960-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]A<W-E<G1#:&%N;F5L4W1A=&5$:7(H)&-H86YN
M96PI#0H@("`@>PT*("`@("`@("`D9',@/2!$25)%0U1/4EE?4T5005)!5$]2
M.PT*("`@("`@("!I9B`H(21C:&%N;F5L('Q\("1T:&ES+3Y?9V5T0VAA;FYE
M;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@
M("`@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER
M("X@)&1S("X@)W!E87(N<&AP+FYE="YR96<G*2D@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6YI=&EA;&EZ94-H86YN96Q$:7)S*"D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]A<W-E<G13=&%T
M941I<B@D8VAA;FYE;"D[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96Q$
M:7(@/2`D=&AI<RT^7V-H86YN96Q$:7)E8W1O<GE.86UE*"1C:&%N;F5L*3L-
M"B`@("`@("`@:68@*"%I<U]D:7(H)'1H:7,M/F-H86YN96QS9&ER*2!\?`T*
M("`@("`@("`@("`@("`A9FEL95]E>&ES=',H)'1H:7,M/F-H86YN96QS9&ER
M("X@)&1S("X@)W!E87(N<&AP+FYE="YR96<G*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]I;FET:6%L:7IE0VAA;FYE;$1I<G,H*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(4!I<U]D:7(H)&-H86YN96Q$:7(I*2![#0H@("`@("`@
M("`@("!I9B`H(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@("`@
M(&EF("@A4WES=&5M.CIM:V1I<BAA<G)A>2@G+7`G+"`D8VAA;FYE;$1I<BDI
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*")C;W5L9"!N;W0@8W)E871E(&1I<F5C=&]R>2`G(B`N("1C:&%N;F5L1&ER
M("X-"B`@("`@("`@("`@("`@("`@("`@(B<B*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7V%S<V5R=$-H86YN96Q$:7(H*0T*#0H@
M("`@+RHJ#0H@("`@("H@36%K92!S=7)E('1H92!D:7)E8W1O<GD@=VAE<F4@
M=V4@:V5E<"!R96=I<W1R>2!F:6QE<R!F;W(@8VAA;FYE;',@97AI<W1S#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!I9B!D:7)E8W1O<GD@
M97AI<W1S+"!&04Q312!I9B!I="!C;W5L9"!N;W0@8F4-"B`@("`@*B!C<F5A
M=&5D#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?87-S97)T0VAA;FYE;$1I<B@I#0H@("`@>PT*("`@
M("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M/F-H86YN96QS9&ER*2D@>PT*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@
M("`@("!I9B`H(5-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@)'1H:7,M/F-H
M86YN96QS9&ER*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@9&ER96-T;W)Y("=[)'1H
M:7,M/F-H86YN96QS9&ER?2<B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H(4!I<U]D:7(H)'1H:7,M/F-H86YN96QS9&ER("X@
M1$E214-43U)97U-%4$%2051/4B`N("<N86QI87,G*2D@>PT*("`@("`@("`@
M("`@:68@*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("!I
M9B`H(5-Y<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@)'1H:7,M/F-H86YN96QS
M9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("<N86QI87,G*2DI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD
M(&YO="!C<F5A=&4@9&ER96-T;W)Y("=[)'1H:7,M/F-H86YN96QS9&ER?2\N
M86QI87,G(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(%]P86-K86=E1FEL94YA;64H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H
M92!N86UE(&]F('1H92!F:6QE('=H97)E(&1A=&$@9F]R(&$@9VEV96X@<&%C
M:V%G92!I<R!S=&]R960N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&-H86YN96P@;F%M92P@;W(@9F%L<V4@:68@=&AI<R!I<R!A(%!%05(@<&%C
M:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!R96=I<W1R>2!F:6QE(&YA;64-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@7W!A8VMA9V5&:6QE3F%M92@D<&%C:V%G92P@)&-H86YN96P@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D8VAA;FYE;"`F)B`D=&AI
M<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI("$]("=P96%R+G!H
M<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]C:&%N;F5L
M1&ER96-T;W)Y3F%M92@D8VAA;FYE;"D@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X-"B`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1P86-K86=E*2`N("<N
M<F5G)SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/G-T871E
M9&ER("X@1$E214-43U)97U-%4$%2051/4B`N('-T<G1O;&]W97(H)'!A8VMA
M9V4I("X@)RYR96<G.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!?8VAA;FYE;$9I;&5.86UE*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T
M:&4@;F%M92!O9B!T:&4@9FEL92!W:&5R92!D871A(&9O<B!A(&=I=F5N(&-H
M86YN96P@:7,@<W1O<F5D+@T*("`@("`J($!P87)A;2!S=')I;F<@8VAA;FYE
M;"!N86UE#0H@("`@("H@0')E='5R;B!S=')I;F<@<F5G:7-T<GD@9FEL92!N
M86UE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V-H86YN96Q&:6QE3F%M92@D
M8VAA;FYE;"P@)&YO86QI87-E<R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@
M:68@*"$D;F]A;&EA<V5S*2![#0H@("`@("`@("`@("!I9B`H0&9I;&5?97AI
M<W1S*"1T:&ES+3Y?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PI
M*2D@>PT*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@:6UP;&]D92@G)RP@
M9FEL92@D=&AI<RT^7V=E=$-H86YN96Q!;&EA<T9I;&5.86UE*"1C:&%N;F5L
M*2DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^8VAA;FYE;'-D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M<W1R7W)E<&QA8V4H)R\G+"`G7R<L#0H@("`@("`@("`@("!S=')T;VQO=V5R
M*"1C:&%N;F5L*2D@+B`G+G)E9R<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&=E=$-H86YN96Q!;&EA<T9I;&5.86UE*"D-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971#:&%N;F5L06QI87-&:6QE
M3F%M92@D86QI87,I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F-H
M86YN96QS9&ER("X@1$E214-43U)97U-%4$%2051/4B`N("<N86QI87,G("X-
M"B`@("`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4B`N('-T<E]R97!L
M86-E*"<O)RP@)U\G+"!S=')T;VQO=V5R*"1A;&EA<RDI("X@)RYT>'0G.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?9V5T0VAA;FYE;$9R
M;VU!;&EA<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&YA;64@;V8@
M82!C:&%N;F5L(&9R;VT@:71S(&%L:6%S#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI#0H@("`@>PT*("`@
M("`@("!I9B`H(21T:&ES+3Y?8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-
M"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`G<&5A<BYP:'`N;F5T)SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G<&5C
M;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`G<&5C;"YP
M:'`N;F5T)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D8VAA
M;FYE;"`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("=?
M7W5R:2<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R
M*"1C:&%N;F5L*3L-"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1T:&ES+3Y?
M9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PI*2D@>PT*("`@("`@
M("`@("`@+R\@=')A;G-L871E(&%N(&%L:6%S('1O(&%N(&%C='5A;"!C:&%N
M;F5L#0H@("`@("`@("`@("!R971U<FX@:6UP;&]D92@G)RP@9FEL92@D=&AI
M<RT^7V=E=$-H86YN96Q!;&EA<T9I;&5.86UE*"1C:&%N;F5L*2DI.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1C:&%N;F5L.PT*
M("`@("`@("!]#0H@("`@?2`@("`-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M7V=E=$-H86YN96Q&<F]M06QI87,H*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T
M('1H92!A;&EA<R!O9B!A(&-H86YN96P@9G)O;2!I=',@86QI87,@;W(@:71S
M(&YA;64-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9V5T06QI87,H)&-H86YN
M96PI#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?8VAA;FYE;$5X:7-T
M<R@D8VAA;FYE;"DI('L-"B`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G
M<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`G<&5A
M<B<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@
M/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)W!E8VPG.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/E]G
M971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&-H86YN96PI*2![#0H@("`@("`@("`@("!R971U<FX@)&-H86YN96P[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1C:&%N;F5L+3YG971!;&EA
M<R@I.PT*("`@('T@("`@#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C:&%N
M;F5L1&ER96-T;W)Y3F%M92@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE
M(&YA;64@;V8@=&AE(&9I;&4@=VAE<F4@9&%T82!F;W(@82!G:79E;B!P86-K
M86=E(&ES('-T;W)E9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M8VAA;FYE;"!N86UE+"!O<B!F86QS92!I9B!T:&ES(&ES(&$@4$5!4B!P86-K
M86=E#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@
M*@T*("`@("`J($!R971U<FX@<W1R:6YG(')E9VES=')Y(&9I;&4@;F%M90T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?8VAA;FYE;$1I<F5C=&]R>4YA;64H)&-H86YN96PI#0H@("`@
M>PT*("`@("`@("!I9B`H(21C:&%N;F5L('Q\("1T:&ES+3Y?9V5T0VAA;FYE
M;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)W!E87(N<&AP+FYE="<I('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<W1A=&5D:7([#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D8V@@/2`D=&AI<RT^7V=E=$-H86YN96Q&
M<F]M06QI87,H)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*"$D8V@I('L-
M"B`@("`@("`@("`@("`@("`D8V@@/2`D8VAA;FYE;#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W1A=&5D:7(@+B!$25)%
M0U1/4EE?4T5005)!5$]2("X@<W1R=&]L;W=E<B@G+F-H86YN96PN)R`N#0H@
M("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H)R\G+"`G7R<L("1C:"DI.PT*
M("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]O
M<&5N4&%C:V%G949I;&4H*0T*#0H@("`@9G5N8W1I;VX@7V]P96Y086-K86=E
M1FEL92@D<&%C:V%G92P@)&UO9&4L("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H(21T:&ES+3Y?87-S97)T4W1A=&5$:7(H)&-H86YN
M96PI*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H(6EN7V%R<F%Y*"1M;V1E+"!A<G)A>2@G<B<L("=R8B<I
M*2`F)B`A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@("`@("`@("`@
M(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@("1F:6QE(#T@)'1H
M:7,M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@
M("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`D;6]D92D[#0H@("`@("`@(&EF
M("@A)&9P*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)&9P.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!?8VQO<V5086-K86=E1FEL92@I#0H-"B`@("!F=6YC=&EO
M;B!?8VQO<V5086-K86=E1FEL92@D9G`I#0H@("`@>PT*("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V]P
M96Y086-K86=E1FEL92@I#0H-"B`@("!F=6YC=&EO;B!?;W!E;D-H86YN96Q&
M:6QE*"1C:&%N;F5L+"`D;6]D92D-"B`@("![#0H@("`@("`@(&EF("@A)'1H
M:7,M/E]A<W-E<G1#:&%N;F5L1&ER*"DI('L-"B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R87DH)&UO
M9&4L(&%R<F%Y*"=R)RP@)W)B)RDI("8F("$D=&AI<RT^:&%S5W)I=&5!8V-E
M<W,H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-
M"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7V-H86YN96Q&:6QE3F%M92@D8VAA
M;FYE;"D[#0H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL92P@)&UO9&4I.PT*
M("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1F<#L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@7V-L;W-E4&%C:V%G949I;&4H*0T*#0H@
M("`@9G5N8W1I;VX@7V-L;W-E0VAA;FYE;$9I;&4H)&9P*0T*("`@('L-"B`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(%]R96)U:6QD1FEL94UA<"@I#0H-"B`@("!F=6YC=&EO;B!?<F5B
M=6EL9$9I;&5-87`H*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05)?26YS=&%L;&5R7U)O;&4G*2D@>PT*("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+TEN<W1A;&QE<B]2;VQE+G!H<"<[#0H@("`@("`@
M('T-"B`@("`@("`@)&-H86YN96QS(#T@)'1H:7,M/E]L:7-T06QL4&%C:V%G
M97,H*3L-"B`@("`@("`@)&9I;&5S(#T@87)R87DH*3L-"B`@("`@("`@9F]R
M96%C:"`H)&-H86YN96QS(&%S("1C:&%N;F5L(#T^("1P86-K86=E<RD@>PT*
M("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5S(&%S("1P86-K86=E*2![
M#0H@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7W!A8VMA9V5)
M;F9O*"1P86-K86=E+"`G=F5R<VEO;B<L("1C:&%N;F5L*3L-"B`@("`@("`@
M("`@("`@("`D9FEL96QI<W0@/2`D=&AI<RT^7W!A8VMA9V5);F9O*"1P86-K
M86=E+"`G9FEL96QI<W0G+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D9FEL96QI<W0I*2![#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&YA;64@/3X@)&%T=')S*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D871T<G-;)V%T=')I
M8G,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1A='1R<R`]("1A
M='1R<ULG871T<FEB<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("\O(&ET(&ES('!O<W-I8FQE(&9O<B!C;VYF;&EC
M=&EN9R!P86-K86=E<R!I;B!D:69F97)E;G0@8VAA;FYE;',@=&\-"B`@("`@
M("`@("`@("`@("`@("`@+R\@8V]N9FQI8W0@=VET:"!D871A(&9I;&5S+V1O
M8R!F:6QE<PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&YA;64@/3T@)V1I
M<G1R964G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&%T=')S6R=R;VQE)UTI("8F("%I;E]A<G)A>2@D871T<G-;
M)W)O;&4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]);G-T
M86QL97)?4F]L93HZ9V5T26YS=&%L;&%B;&52;VQE<R@I*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@=&AE<V4@87)E(&YO="!I;G-T86QL960-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M871T<G-;)W)O;&4G72D@)B8@(6EN7V%R<F%Y*"1A='1R<ULG<F]L92==+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE
M.CIG971"87-E:6YS=&%L;%)O;&5S*"DI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D871T<G-;)V)A<V5I;G-T86QL9&ER)UT@/2`D<&%C:V%G93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)&%T=')S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D871T<G-;)V)A<V5I;G-T86QL
M9&ER)UTN1$E214-43U)97U-%4$%2051/4BXD;F%M93L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M:6QE(#T@)&YA;64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@)&9I;&4@/2!P<F5G7W)E<&QA8V4H)RQ>+RLL)RP@)R<L
M("1F:6QE*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L("$]
M("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9FEL97-;)&%T=')S6R=R;VQE)UU=6R1F:6QE72`](&%R<F%Y*'-T<G1O;&]W
M97(H)&-H86YN96PI+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T
M<G1O;&]W97(H)'!A8VMA9V4I*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F:6QE<ULD871T<G-;
M)W)O;&4G75U;)&9I;&5=(#T@<W1R=&]L;W=E<B@D<&%C:V%G92D[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]A<W-E<G13=&%T
M941I<B@I.PT*("`@("`@("!I9B`H(21T:&ES+3YH87-7<FET94%C8V5S<R@I
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3YF:6QE;6%P+"`G=V(G*3L-"B`@
M("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^9FEL96UA<%]C86-H92`]("1F
M:6QE<SL-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1F:6QE<RDI
M.PT*("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]R96%D1FEL94UA
M<"@I#0H-"B`@("!F=6YC=&EO;B!?<F5A9$9I;&5-87`H*0T*("`@('L-"B`@
M("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3YF:6QE;6%P+"`G<B<I.PT*("`@
M("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=014%27U)E9VES=')Y.B!C;W5L9"!N;W0@;W!E;B!F:6QE
M;6%P("(G("X@)'1H:7,M/F9I;&5M87`@+B`G(B<L(%!%05)?4D5'25-44EE?
M15)23U)?1DE,12P@;G5L;"P@;G5L;"P@)'!H<%]E<G)O<FUS9RD[#0H@("`@
M("`@('T-"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@("`@)')T
M(#T@9V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"D[#0H@("`@("`@('-E=%]M
M86=I8U]Q=6]T97-?<G5N=&EM92@P*3L-"B`@("`@("`@)&9S:7IE(#T@9FEL
M97-I>F4H)'1H:7,M/F9I;&5M87`I.PT*("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@("`@("!F
M8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?8V]N
M=&5N=',H)'1H:7,M/F9I;&5M87`I.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&1A=&$@/2!F<F5A9"@D9G`L("1F<VEZ92D[#0H@("`@("`@
M("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("!S971?;6%G
M:6-?<75O=&5S7W)U;G1I;64H)')T*3L-"B`@("`@("`@)'1M<"`]('5N<V5R
M:6%L:7IE*"1D871A*3L-"B`@("`@("`@:68@*"$D=&UP("8F("1F<VEZ92`^
M(#<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M4$5!4E]296=I<W1R>3H@:6YV86QI9"!F:6QE;6%P(&1A=&$G+"!014%27U)%
M1TE35%)97T524D]27T9/4DU!5"P@;G5L;"P@;G5L;"P@)&1A=&$I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YF:6QE;6%P7V-A8VAE(#T@)'1M<#L-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(%]L;V-K*"D-"@T*("`@("\J*@T*("`@("`J($QO8VL@=&AE
M(')E9VES=')Y+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN=&5G97(@;&]C
M:R!M;V1E+"!O;F4@;V8@3$]#2U]%6"P@3$]#2U]32"!O<B!,3T-+7U5.+@T*
M("`@("`J("`@("`@("`@("`@("`@(%-E92!F;&]C:R!M86YU86P@9F]R(&UO
M<F4@:6YF;W)M871I;VXN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M5%)512!O;B!S=6-C97-S+"!&04Q312!I9B!L;V-K:6YG(&9A:6QE9"P@;W(@
M80T*("`@("`J("`@("`@("`@("`@("!014%2(&5R<F]R(&EF('-O;64@;W1H
M97(@97)R;W(@;V-C=7)S("AS=6-H(&%S('1H90T*("`@("`J("`@("`@("`@
M("`@("!L;V-K(&9I;&4@;F]T(&)E:6YG('=R:71A8FQE*2X-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]L;V-K*"1M;V1E(#T@3$]#2U]%6"D-"B`@("![#0H@("`@("`@(&EF("@A
M97)E9VDH)U=I;F1O=W,@.2<L('!H<%]U;F%M92@I*2D@>PT*("`@("`@("`@
M("`@:68@*"1M;V1E("$]($Q/0TM?54X@)B8@:7-?<F5S;W5R8V4H)'1H:7,M
M/FQO8VM?9G`I*2![#0H@("`@("`@("`@("`@("`@+R\@6%A8(&1O97,@;F]T
M(&-H96-K('1Y<&4@;V8@;&]C:R`H3$]#2U]32"],3T-+7T58*0T*("`@("`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"$D=&AI<RT^7V%S<V5R=%-T871E1&ER*"DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H)&UO9&4@/3T@3$]#2U]%6"D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U)E9VES=')Y
M(&1I<F5C=&]R>2!I<R!N;W0@=W)I=&5A8FQE(&)Y('1H92!C=7)R96YT('5S
M97(G*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D;W!E;E]M;V1E(#T@)W<G.PT*("`@
M("`@("`@("`@+R\@6%A8(%!E;W!L92!R97!O<G1E9"!P<F]B;&5M<R!W:71H
M($Q/0TM?4T@@86YD("=W)PT*("`@("`@("`@("`@:68@*"1M;V1E(#T]/2!,
M3T-+7U-(('Q\("1M;V1E(#T]/2!,3T-+7U5.*2![#0H@("`@("`@("`@("`@
M("`@:68@*$`A:7-?9FEL92@D=&AI<RT^;&]C:V9I;&4I*2![#0H@("`@("`@
M("`@("`@("`@("`@('1O=6-H*"1T:&ES+3YL;V-K9FEL92D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1O<&5N7VUO9&4@/2`G<B<[
M#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@A:7-?<F5S;W5R
M8V4H)'1H:7,M/FQO8VM?9G`I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/FQO8VM?9G`@/2!`9F]P96XH)'1H:7,M/FQO8VMF:6QE+"`D;W!E;E]M;V1E
M*3L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@:68@*"%I<U]R97-O
M=7)C92@D=&AI<RT^;&]C:U]F<"DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!C<F5A=&4@;&]C:R!F
M:6QE(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("AI<W-E="@D<&AP7V5R<F]R;7-G*2`_("(Z("(@+B`D<&AP7V5R<F]R
M;7-G(#H@(B(I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M*&EN="EF;&]C:R@D=&AI<RT^;&]C:U]F<"P@)&UO9&4I*2![#0H@("`@("`@
M("`@("`@("`@<W=I=&-H("@D;6]D92D@>PT*("`@("`@("`@("`@("`@("`@
M("!C87-E($Q/0TM?4T@Z("1S='(@/2`G<VAA<F5D)SL@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@("`@(&-A<V4@3$]#2U]%6#H@)'-T<B`]("=E>&-L
M=7-I=F4G.R!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@8V%S92!,3T-+
M7U5..B`D<W1R(#T@)W5N;&]C:R<[("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@("`@("!D969A=6QT.B`@("`@("1S='(@/2`G=6YK;F]W;B<[("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&%C<75I<F4@)'-T<B!L
M;V-K("@D=&AI<RT^;&]C:V9I;&4I(BP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@4$5!4E]214=)4U1265]%4E)/4E],3T-+
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W5N;&]C
M:R@I#0H-"B`@("!F=6YC=&EO;B!?=6YL;V-K*"D-"B`@("![#0H@("`@("`@
M("1R970@/2`D=&AI<RT^7VQO8VLH3$]#2U]53BD[#0H@("`@("`@(&EF("AI
M<U]R97-O=7)C92@D=&AI<RT^;&]C:U]F<"DI('L-"B`@("`@("`@("`@(&9C
M;&]S92@D=&AI<RT^;&]C:U]F<"D[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/FQO8VM?9G`@/2!N=6QL.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7W!A8VMA9V5%>&ES=',H
M*0T*#0H@("`@9G5N8W1I;VX@7W!A8VMA9V5%>&ES=',H)'!A8VMA9V4L("1C
M:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!R971U<FX@9FEL95]E
M>&ES=',H)'1H:7,M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4L("1C:&%N
M;F5L*2D[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]C:&%N
M;F5L17AI<W1S*"D-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W:&5T
M:&5R(&$@8VAA;FYE;"!E>&ES=',@:6X@=&AE(')E9VES=')Y#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!#:&%N;F5L(&YA;64-"B`@("`@*B!`<&%R86T@8F]O
M;"!I9B!T<G5E+"!T:&5N(&%L:6%S97,@=VEL;"!B92!I9VYO<F5D#0H@("`@
M("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V-H
M86YN96Q%>&ES=',H)&-H86YN96PL("1N;V%L:6%S97,@/2!F86QS92D-"B`@
M("![#0H@("`@("`@("1A(#T@9FEL95]E>&ES=',H)'1H:7,M/E]C:&%N;F5L
M1FEL94YA;64H)&-H86YN96PL("1N;V%L:6%S97,I*3L-"B`@("`@("`@:68@
M*"$D82`F)B`D8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M82`F)B`D8VAA;FYE;"`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1A
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?861D0VAA;FYE
M;"@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]#:&%N;F5L1FEL
M92!#:&%N;F5L(&]B:F5C=`T*("`@("`J($!P87)A;2!D;VYO='5S90T*("`@
M("`J($!P87)A;2!S=')I;F<@3&%S="U-;V1I9FEE9"!(5%10('1A9R!F<F]M
M(')E;6]T92!R97%U97-T#0H@("`@("H@0')E='5R;B!B;V]L96%N?%!%05)?
M17)R;W(@5')U92!O;B!C<F5A=&EO;BP@9F%L<V4@:68@:70@86QR96%D>2!E
M>&ES=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?861D0VAA;FYE;"@D8VAA
M;FYE;"P@)'5P9&%T92`](&9A;'-E+"`D;&%S=&UO9&EF:65D(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V$H)&-H86YN96PL("=014%27T-H
M86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H(21C:&%N;F5L+3YV86QI9&%T92@I*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&9I;&5?97AI<W1S*"1T:&ES+3Y?8VAA;FYE;$9I;&5.86UE*"1C
M:&%N;F5L+3YG971.86UE*"DI*2D@>PT*("`@("`@("`@("`@:68@*"$D=7!D
M871E*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)&-H96-K97(@/2`D=&AI<RT^7V=E=$-H
M86YN96PH)&-H86YN96PM/F=E=$YA;64H*2D[#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D8VAE8VME<BDI('L-"B`@("`@("`@("`@("`@("!R
M971U<FX@)&-H96-K97([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H)&-H86YN96PM/F=E=$%L:6%S*"D@(3T@)&-H96-K97(M/F=E=$%L:6%S
M*"DI('L-"B`@("`@("`@("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?9V5T0VAA
M;FYE;$%L:6%S1FEL94YA;64H)&-H96-K97(M/F=E=$%L:6%S*"DI*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF
M("@D=7!D871E("8F("%I;E]A<G)A>2@D8VAA;FYE;"T^9V5T3F%M92@I+"!A
M<G)A>2@G<&5A<BYP:'`N;F5T)RP@)W!E8VPN<&AP+FYE="<I*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]A<W-E<G1#:&%N;F5L
M1&ER*"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@
M("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]A<W-E<G1#:&%N;F5L4W1A=&5$:7(H)&-H86YN96PM
M/F=E=$YA;64H*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R970I
M*2![#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&-H86YN96PM/F=E=$%L:6%S*"D@(3T@)&-H86YN96PM/F=E
M=$YA;64H*2D@>PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1T:&ES
M+3Y?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&-H86YN96PM/F=E=$%L:6%S
M*"DI*2`F)@T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971#:&%N;F5L
M1G)O;4%L:6%S*"1C:&%N;F5L+3YG971!;&EA<R@I*2`A/2`D8VAA;FYE;"T^
M9V5T3F%M92@I*2![#0H@("`@("`@("`@("`@("`@)&-H86YN96PM/G-E=$%L
M:6%S*"1C:&%N;F5L+3YG971.86UE*"DI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^:&%S5W)I=&5!8V-E<W,H*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1F<"`]($!F;W!E;B@D=&AI<RT^7V=E=$-H86YN96Q!;&EA
M<T9I;&5.86UE*"1C:&%N;F5L+3YG971!;&EA<R@I*2P@)W<G*3L-"B`@("`@
M("`@("`@(&EF("@A)&9P*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9G=R:71E*"1F<"P@
M)&-H86YN96PM/F=E=$YA;64H*2D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3YH87-7<FET94%C
M8V5S<R@I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@)&9P(#T@0&9O<&5N*"1T:&ES+3Y?8VAA;FYE;$9I;&5.
M86UE*"1C:&%N;F5L+3YG971.86UE*"DI+"`G=V(G*3L-"B`@("`@("`@:68@
M*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D:6YF;R`]("1C:&%N;F5L+3YT;T%R<F%Y*"D[#0H@("`@
M("`@(&EF("@D;&%S=&UO9&EF:65D*2![#0H@("`@("`@("`@("`D:6YF;ULG
M7VQA<W1M;V1I9FEE9"==(#T@)&QA<W1M;V1I9FEE9#L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1I;F9O6R=?;&%S=&UO9&EF:65D)UT@/2!D
M871E*"=R)RD[#0H@("`@("`@('T-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R
M:6%L:7IE*"1I;F9O*2D[#0H@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@7V1E;&5T94-H86YN96PH*0T*#0H@("`@+RHJ#0H@("`@("H@1&5L971I
M;VX@9F%I;',@:68@=&AE<F4@87)E(&%N>2!P86-K86=E<R!I;G-T86QL960@
M9G)O;2!T:&4@8VAA;FYE;`T*("`@("`J($!P87)A;2!S=')I;F=\4$5!4E]#
M:&%N;F5L1FEL92!C:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86Y\4$5!4E]%<G)O<B!4<G5E(&]N(&1E;&5T:6]N+"!F86QS92!I9B!I="!D
M;V5S;B=T(&5X:7-T#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V1E;&5T94-H
M86YN96PH)&-H86YN96PI#0H@("`@>PT*("`@("`@("!I9B`H(6ES7W-T<FEN
M9R@D8VAA;FYE;"DI('L-"B`@("`@("`@("`@(&EF("AI<U]A*"1C:&%N;F5L
M+"`G4$5!4E]#:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@:68@
M*"$D8VAA;FYE;"T^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1C:&%N;F5L(#T@)&-H86YN96PM/F=E=$YA;64H*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI
M<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H86YN96PI(#T]("=?7W5R:2<I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L
M*2`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/E]C:&%N;F5L
M17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)&-H86YN96P@?'P@)'1H:7,M
M/E]G971#:&%N;F5L1G)O;4%L:6%S*"1C:&%N;F5L*2`]/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/E]G971#:&%N;F5L1G)O;4%L
M:6%S*"1C:&%N;F5L*3L-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R
M+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)'1E<W0@/2`D=&AI<RT^7VQI<W1#:&%N;F5L4&%C
M:V%G97,H)&-H86YN96PI.PT*("`@("`@("!I9B`H8V]U;G0H)'1E<W0I*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@)'1E<W0@/2!`<FUD:7(H)'1H:7,M/E]C:&%N;F5L1&ER96-T;W)Y3F%M
M92@D8VAA;FYE;"DI.PT*("`@("`@("!I9B`H(21T97-T*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&9I;&4@
M/2`D=&AI<RT^7V=E=$-H86YN96Q!;&EA<T9I;&5.86UE*"1T:&ES+3Y?9V5T
M06QI87,H)&-H86YN96PI*3L-"B`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D
M9FEL92DI('L-"B`@("`@("`@("`@("1T97-T(#T@0'5N;&EN:R@D9FEL92D[
M#0H@("`@("`@("`@("!I9B`H(21T97-T*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1F:6QE(#T@)'1H:7,M/E]C:&%N;F5L1FEL94YA;64H)&-H86YN96PI
M.PT*("`@("`@("`D<F5T(#T@0'5N;&EN:R@D9FEL92D[#0H@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?
M:7-#:&%N;F5L06QI87,H*0T*#0H@("`@+RHJ#0H@("`@("H@1&5T97)M:6YE
M('=H971H97(@82!C:&%N;F5L(&5X:7-T<R!I;B!T:&4@<F5G:7-T<GD-"B`@
M("`@*B!`<&%R86T@<W1R:6YG($-H86YN96P@06QI87,-"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?:7-#:&%N;F5L
M06QI87,H)&%L:6%S*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9I;&5?97AI
M<W1S*"1T:&ES+3Y?9V5T0VAA;FYE;$%L:6%S1FEL94YA;64H)&%L:6%S*2D[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]P86-K86=E26YF
M;R@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG?&YU;&P-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&YU;&P-"B`@("`@*B!`<&%R86T@<W1R:6YG
M?&YU;&P-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&YU;&P-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<&%C:V%G94EN
M9F\H)'!A8VMA9V4@/2!N=6QL+"`D:V5Y(#T@;G5L;"P@)&-H86YN96P@/2`G
M<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@("`@(&EF("@D<&%C:V%G92`]
M/3T@;G5L;"D@>PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]/2!N=6QL
M*2![#0H@("`@("`@("`@("`@("`@)&-H86YN96QS(#T@)'1H:7,M/E]L:7-T
M0VAA;FYE;',H*3L-"B`@("`@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L-
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D8VAA;FYE;',@87,@)&-H86YN
M96PI('L-"B`@("`@("`@("`@("`@("`@("`@)&-H86YN96P@/2!S=')T;VQO
M=V5R*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`@("`@)')E=%LD8VAA
M;FYE;%T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`D<&%C:V%G
M97,@/2`D=&AI<RT^7VQI<W1086-K86=E<R@D8VAA;FYE;"D[#0H@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D<&%C:V%G92D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E=%LD8VAA;FYE;%U;72`]
M("1T:&ES+3Y?<&%C:V%G94EN9F\H)'!A8VMA9V4L(&YU;&PL("1C:&%N;F5L
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1P<R`]("1T:&ES+3Y?;&ES=%!A8VMA9V5S*"1C:&%N
M;F5L*3L-"B`@("`@("`@("`@(&EF("@A8V]U;G0H)'!S*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y7VUA<"AA<G)A>2@F)'1H:7,L("=?<&%C
M:V%G94EN9F\G*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!S
M+"!A<G)A>5]F:6QL*#`L(&-O=6YT*"1P<RDL(&YU;&PI+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>5]F:6QL*#`L(&-O=6YT*"1P<RDL
M("1C:&%N;F5L*2D[#0H@("`@("`@('T-"B`@("`@("`@)&9P(#T@)'1H:7,M
M/E]O<&5N4&%C:V%G949I;&4H)'!A8VMA9V4L("=R)RP@)&-H86YN96PI.PT*
M("`@("`@("!I9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@;G5L;#L-"B`@("`@("`@?0T*("`@("`@("`D<G0@/2!G971?;6%G:6-?
M<75O=&5S7W)U;G1I;64H*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R
M=6YT:6UE*#`I.PT*("`@("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@
M("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E4&%C:V%G949I;&4H)&9P*3L-
M"B`@("`@("`@("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)'1H:7,M
M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4L("1C:&%N;F5L*2D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D9&%T82`](&9R96%D*"1F<"P@
M9FEL97-I>F4H)'1H:7,M/E]P86-K86=E1FEL94YA;64H)'!A8VMA9V4L("1C
M:&%N;F5L*2DI.PT*("`@("`@("`@("`@)'1H:7,M/E]C;&]S95!A8VMA9V5&
M:6QE*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E
M<U]R=6YT:6UE*"1R="D[#0H@("`@("`@("1D871A(#T@=6YS97)I86QI>F4H
M)&1A=&$I.PT*("`@("`@("!I9B`H)&ME>2`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1D871A.PT*("`@("`@("!]#0H@("`@("`@("\O(&-O
M;7!A=&EB:6QI='D@9F]R('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP#0H@("`@
M("`@(&EF("AI<W-E="@D9&%T85LG;VQD)UU;)&ME>5TI*2![#0H@("`@("`@
M("`@("!R971U<FX@)&1A=&%;)V]L9"==6R1K97E=.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&%T85LD:V5Y72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D9&%T85LD:V5Y73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@;G5L;#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V-H
M86YN96Q);F9O*"D-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@
M0VAA;FYE;"!N86UE#0H@("`@("H@0'!A<F%M(&)O;VP@=VAE=&AE<B!T;R!S
M=')I8W1L>2!R971R:65V92!I;F9O(&]F(&-H86YN96QS+"!N;W0@:G5S="!A
M;&EA<V5S#0H@("`@("H@0')E='5R;B!A<G)A>7QN=6QL#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7V-H86YN96Q);F9O*"1C:&%N;F5L+"`D;F]A;&EA<V5S
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?8VAA;FYE
M;$5X:7-T<R@D8VAA;FYE;"P@)&YO86QI87-E<RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!N=6QL.PT*("`@("`@("!]#0H@("`@("`@("1F<"`]("1T:&ES
M+3Y?;W!E;D-H86YN96Q&:6QE*"1C:&%N;F5L+"`G<B<I.PT*("`@("`@("!I
M9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-
M"B`@("`@("`@?0T*("`@("`@("`D<G0@/2!G971?;6%G:6-?<75O=&5S7W)U
M;G1I;64H*3L-"B`@("`@("`@<V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*#`I
M.PT*("`@("`@("!C;&5A<G-T871C86-H92@I.PT*("`@("`@("!I9B`H9G5N
M8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT96YT<R<I*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7V-L;W-E0VAA;FYE;$9I;&4H)&9P*3L-"B`@("`@("`@
M("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)'1H:7,M/E]C:&%N;F5L
M1FEL94YA;64H)&-H86YN96PI*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1D871A(#T@9G)E860H)&9P+"!F:6QE<VEZ92@D=&AI<RT^7V-H
M86YN96Q&:6QE3F%M92@D8VAA;FYE;"DI*3L-"B`@("`@("`@("`@("1T:&ES
M+3Y?8VQO<V5#:&%N;F5L1FEL92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@
M('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@D<G0I.PT*("`@("`@("`D9&%T
M82`]('5N<V5R:6%L:7IE*"1D871A*3L-"B`@("`@("`@<F5T=7)N("1D871A
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?;&ES=$-H86YN
M96QS*"D-"@T*("`@(&9U;F-T:6]N(%]L:7-T0VAA;FYE;',H*0T*("`@('L-
M"B`@("`@("`@)&-H86YN96QL:7-T(#T@87)R87DH*3L-"B`@("`@("`@)&1P
M(#T@0&]P96YD:7(H)'1H:7,M/F-H86YN96QS9&ER*3L-"B`@("`@("`@:68@
M*"$D9'`@('Q\("%`:7-?9&ER*"1T:&ES+3YC:&%N;F5L<V1I<BDI('L-"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@G<&5A<BYP:'`N;F5T)RP@)W!E8VPN
M<&AP+FYE="<L("=?7W5R:2<I.PT*("`@("`@("!]#0H@("`@("`@('=H:6QE
M("@D96YT(#T@<F5A9&1I<B@D9'`I*2![#0H@("`@("`@("`@("!I9B`H)&5N
M='LP?2`]/2`G+B<@?'P@<W5B<W1R*"1E;G0L("TT*2`A/2`G+G)E9R<I('L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D96YT(#T]("=?7W5R:2YR96<G*2![#0H@("`@("`@
M("`@("`@("`@)&-H86YN96QL:7-T6UT@/2`G7U]U<FDG.PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&-H86YN96QL:7-T6UT@/2!S=')?<F5P;&%C92@G7R<L("<O)RP@<W5B<W1R
M*"1E;G0L(#`L("TT*2D[#0H@("`@("`@('T-"B`@("`@("`@8VQO<V5D:7(H
M)&1P*3L-"B`@("`@("`@:68@*"%I;E]A<G)A>2@G<&5A<BYP:'`N;F5T)RP@
M)&-H86YN96QL:7-T*2D@>PT*("`@("`@("`@("`@)&-H86YN96QL:7-T6UT@
M/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6EN
M7V%R<F%Y*"=P96-L+G!H<"YN970G+"`D8VAA;FYE;&QI<W0I*2![#0H@("`@
M("`@("`@("`D8VAA;FYE;&QI<W1;72`]("=P96-L+G!H<"YN970G.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R87DH)U]?=7)I)RP@)&-H86YN
M96QL:7-T*2D@>PT*("`@("`@("`@("`@)&-H86YN96QL:7-T6UT@/2`G7U]U
M<FDG.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D8VAA;FYE;&QI<W0[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(%]L:7-T4&%C:V%G
M97,H*0T*#0H@("`@9G5N8W1I;VX@7VQI<W1086-K86=E<R@D8VAA;FYE;"`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1C:&%N;F5L("8F("1T:&ES
M+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@(3T@)W!E87(N<&AP
M+FYE="<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VQI<W1#:&%N
M;F5L4&%C:V%G97,H)&-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@("1P
M:V=L:7-T(#T@87)R87DH*3L-"B`@("`@("`@)&1P(#T@0&]P96YD:7(H)'1H
M:7,M/G-T871E9&ER*3L-"B`@("`@("`@:68@*"$D9'`I('L-"B`@("`@("`@
M("`@(')E='5R;B`D<&MG;&ES=#L-"B`@("`@("`@?0T*("`@("`@("!W:&EL
M92`H)&5N="`](')E861D:7(H)&1P*2D@>PT*("`@("`@("`@("`@:68@*"1E
M;G1[,'T@/3T@)RXG('Q\('-U8G-T<B@D96YT+"`M-"D@(3T@)RYR96<G*2![
M#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D<&MG;&ES=%M=(#T@<W5B<W1R*"1E;G0L(#`L("TT*3L-
M"B`@("`@("`@?0T*("`@("`@("!C;&]S961I<B@D9'`I.PT*("`@("`@("!R
M971U<FX@)'!K9VQI<W0[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(%]L:7-T0VAA;FYE;%!A8VMA9V5S*"D-"@T*("`@(&9U;F-T:6]N(%]L
M:7-T0VAA;FYE;%!A8VMA9V5S*"1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@
M)'!K9VQI<W0@/2!A<G)A>2@I.PT*("`@("`@("`D9'`@/2!`;W!E;F1I<B@D
M=&AI<RT^7V-H86YN96Q$:7)E8W1O<GE.86UE*"1C:&%N;F5L*2D[#0H@("`@
M("`@(&EF("@A)&1P*2![#0H@("`@("`@("`@("!R971U<FX@)'!K9VQI<W0[
M#0H@("`@("`@('T-"B`@("`@("`@=VAI;&4@*"1E;G0@/2!R96%D9&ER*"1D
M<"DI('L-"B`@("`@("`@("`@(&EF("@D96YT>S!](#T]("<N)R!\?"!S=6)S
M='(H)&5N="P@+30I("$]("<N<F5G)RD@>PT*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!K9VQI<W1;
M72`]('-U8G-T<B@D96YT+"`P+"`M-"D[#0H@("`@("`@('T-"B`@("`@("`@
M8VQO<V5D:7(H)&1P*3L-"B`@("`@("`@<F5T=7)N("1P:V=L:7-T.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@(`T*("`@(&9U;F-T:6]N(%]L:7-T06QL
M4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?;&ES=$-H86YN96QS*"D@87,@)&-H
M86YN96PI('L-"B`@("`@("`@("`@("1R971;)&-H86YN96Q=(#T@)'1H:7,M
M/E]L:7-T4&%C:V%G97,H)&-H86YN96PI.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($%D9"!A
M;B!I;G-T86QL960@<&%C:V%G92!T;R!T:&4@<F5G:7-T<GD-"B`@("`@*B!`
M<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!A<G)A
M>2!P86-K86=E(&EN9F\@*'!A<G-E9"!B>2!014%27T-O;6UO;CHZ:6YF;T9R
M;VTJ*"D@;65T:&]D<RD-"B`@("`@*B!`<F5T=7)N(&)O;VP@<W5C8V5S<R!O
M9B!S879I;F<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?861D4&%C:V%G92@D<&%C:V%G92P@)&EN9F\I#0H@("`@
M>PT*("`@("`@("!I9B`H)'1H:7,M/E]P86-K86=E17AI<W1S*"1P86-K86=E
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@("1F<"`]("1T:&ES+3Y?;W!E;E!A8VMA9V5&:6QE*"1P86-K86=E
M+"`G=V(G*3L-"B`@("`@("`@:68@*"1F<"`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O
M6R=?;&%S=&UO9&EF:65D)UT@/2!T:6UE*"D[#0H@("`@("`@(&9W<FET92@D
M9G`L('-E<FEA;&EZ92@D:6YF;RDI.PT*("`@("`@("`D=&AI<RT^7V-L;W-E
M4&%C:V%G949I;&4H)&9P*3L-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=F
M:6QE;&ES="==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96)U:6QD1FEL
M94UA<"@I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<F5T=7)N(&)O;VP-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?861D4&%C:V%G93(H)&EN9F\I#0H@("`@>PT*("`@("`@("!I9B`H(21I
M;F9O+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("!I9B`H8VQA<W-?97AI
M<W1S*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("`@("`@)'5I(#T@
M4$5!4E]&<F]N=&5N9#HZ<VEN9VQE=&]N*"D[#0H@("`@("`@("`@("`@("`@
M:68@*"1U:2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF
M;RT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"D@87,@)&5R<BD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'5I+3YL;V<H,BP@)&5R<ELG;65S<V%G92==
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("`D8VAA;FYE;"`]("1I;F9O+3YG971#:&%N;F5L
M*"D[#0H@("`@("`@("1P86-K86=E(#T@)&EN9F\M/F=E=%!A8VMA9V4H*3L-
M"B`@("`@("`@)'-A=F4@/2`D:6YF;SL-"B`@("`@("`@:68@*"1T:&ES+3Y?
M<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96PI*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D
M=&AI<RT^7V-H86YN96Q%>&ES=',H)&-H86YN96PL('1R=64I*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&EN
M9F\@/2`D:6YF;RT^=&]!<G)A>2AT<G5E*3L-"B`@("`@("`@:68@*"$D:6YF
M;RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@
M("`@("`@("1F<"`]("1T:&ES+3Y?;W!E;E!A8VMA9V5&:6QE*"1P86-K86=E
M+"`G=V(G+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF("@D9G`@/3T](&YU;&PI
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("`D:6YF;ULG7VQA<W1M;V1I9FEE9"==(#T@=&EM92@I.PT*("`@("`@
M("!F=W)I=&4H)&9P+"!S97)I86QI>F4H)&EN9F\I*3L-"B`@("`@("`@)'1H
M:7,M/E]C;&]S95!A8VMA9V5&:6QE*"1F<"D[#0H@("`@("`@("1T:&ES+3Y?
M<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!086-K86=E(&YA
M;64-"B`@("`@*B!`<&%R86T@87)R87D@<&%R<V5D('!A8VMA9V4N>&UL(#$N
M,`T*("`@("`J($!P87)A;2!B;V]L('1H:7,@<&%R86UE=&5R(&ES(&]N;'D@
M:&5R92!F;W(@0D,N("!$;VXG="!U<V4@:70N#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5P9&%T95!A8VMA9V4H
M)'!A8VMA9V4L("1I;F9O+"`D;65R9V4@/2!T<G5E*0T*("`@('L-"B`@("`@
M("`@)&]L9&EN9F\@/2`D=&AI<RT^7W!A8VMA9V5);F9O*"1P86-K86=E*3L-
M"B`@("`@("`@:68@*&5M<'1Y*"1O;&1I;F9O*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1F<"`]("1T:&ES
M+3Y?;W!E;E!A8VMA9V5&:6QE*"1P86-K86=E+"`G=R<I.PT*("`@("`@("!I
M9B`H)&9P(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V]B:F5C="@D:6YF;RDI('L-
M"B`@("`@("`@("`@("1I;F9O(#T@)&EN9F\M/G1O07)R87DH*3L-"B`@("`@
M("`@?0T*("`@("`@("`D:6YF;ULG7VQA<W1M;V1I9FEE9"==(#T@=&EM92@I
M.PT*("`@("`@("`D;F5W:6YF;R`]("1I;F9O.PT*("`@("`@("!I9B`H)&UE
M<F=E*2![#0H@("`@("`@("`@("`D:6YF;R`](&%R<F%Y7VUE<F=E*"1O;&1I
M;F9O+"`D:6YF;RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M9&EF9B`]("1I;F9O.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D9G`L
M('-E<FEA;&EZ92@D:6YF;RDI.PT*("`@("`@("`D=&AI<RT^7V-L;W-E4&%C
M:V%G949I;&4H)&9P*3L-"B`@("`@("`@:68@*&ES<V5T*"1N97=I;F9O6R=F
M:6QE;&ES="==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96)U:6QD1FEL
M94UA<"@I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE
M7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<F5T=7)N(&)O;VP-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?=7!D871E4&%C:V%G93(H)&EN9F\I#0H@("`@>PT*("`@("`@("!I9B`H
M(21T:&ES+3Y?<&%C:V%G945X:7-T<R@D:6YF;RT^9V5T4&%C:V%G92@I+"`D
M:6YF;RT^9V5T0VAA;FYE;"@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1F<"`]("1T:&ES+3Y?;W!E;E!A
M8VMA9V5&:6QE*"1I;F9O+3YG971086-K86=E*"DL("=W)RP@)&EN9F\M/F=E
M=$-H86YN96PH*2D[#0H@("`@("`@(&EF("@D9G`@/3T](&YU;&PI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D
M<V%V92`]("1I;F9O.PT*("`@("`@("`D:6YF;R`]("1S879E+3YG971!<G)A
M>2AT<G5E*3L-"B`@("`@("`@)&EN9F];)U]L87-T;6]D:69I960G72`]('1I
M;64H*3L-"B`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE*"1I;F9O*2D[
M#0H@("`@("`@("1T:&ES+3Y?8VQO<V5086-K86=E1FEL92@D9G`I.PT*("`@
M("`@("`D=&AI<RT^7W)E8G5I;&1&:6QE36%P*"D[#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<@4&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!#:&%N;F5L
M(&YA;64-"B`@("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?=C%\4$5!
M4E]086-K86=E1FEL95]V,GQN=6QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)E]G971086-K86=E*"1P86-K86=E
M+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G*0T*("`@('L-"B`@("`@("`@
M)&EN9F\@/2`D=&AI<RT^7W!A8VMA9V5);F9O*"1P86-K86=E+"!N=6QL+"`D
M8VAA;FYE;"D[#0H@("`@("`@(&EF("@D:6YF;R`]/3T@;G5L;"D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@("`@("!]#0H@("`@("`@("1A
M(#T@)'1H:7,M/E]C;VYF:6<[#0H@("`@("`@(&EF("@A)&$I('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)FYE=R!014%27T-O;F9I9SL-"B`@
M("`@("`@("`@("1T:&ES+3Y?8V]N9FEG+3YS970H)W!H<%]D:7(G+"`D=&AI
M<RT^<W1A=&5D:7(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27U!A8VMA9V5&:6QE)RDI('L-"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("!]
M#0H@("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M
M/E]C;VYF:6<I.PT*("`@("`@("`D<&8@/2`F)'!K9RT^9G)O;4%R<F%Y*"1I
M;F9O*3L-"B`@("`@("`@<F5T=7)N("1P9CL-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M90T*("`@("`J($!P
M87)A;2!B;V]L('=H971H97(@=&\@<W1R:6-T;'D@<F5T<FEE=F4@8VAA;FYE
M;"!N86UE<PT*("`@("`J($!R971U<FX@4$5!4E]#:&%N;F5L1FEL97Q014%2
M7T5R<F]R#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@)E]G971#:&%N;F5L*"1C:&%N;F5L+"`D;F]A;&EA<V5S(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V@@/2!F86QS93L-"B`@("`@("`@
M:68@*"1T:&ES+3Y?8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"P@)&YO86QI87-E
M<RDI('L-"B`@("`@("`@("`@("1C:&EN9F\@/2`D=&AI<RT^7V-H86YN96Q)
M;F9O*"1C:&%N;F5L+"`D;F]A;&EA<V5S*3L-"B`@("`@("`@("`@(&EF("@D
M8VAI;F9O*2![#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-H(#T@)E!%05)?0VAA;FYE
M;$9I;&4Z.F9R;VU!<G)A>5=I=&A%<G)O<G,H)&-H:6YF;RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:"D@>PT*("`@("`@
M("`@("`@:68@*"1C:"T^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D8V@[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D8V@M/F=E=$5R<F]R<RAT<G5E*2!A<R`D97)R*2![#0H@("`@("`@
M("`@("`@("`@)&UE<W-A9V4@/2`D97)R6R=M97-S86=E)UT@+B`B7&XB.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-H(#T@4$5!4CHZ<F%I<V5%
M<G)O<B@D;65S<V%G92D[#0H@("`@("`@("`@("!R971U<FX@)&-H.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI
M87,H)&-H86YN96PI(#T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@
M("`O+R!T:&4@<F5G:7-T<GD@:7,@;F]T('!R;W!E<FQY('-E="!U<"P@<V\@
M=7-E(&1E9F%U;'1S#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]#:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L(#T@;F5W(%!%05)?0VAA;FYE
M;$9I;&4[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971.86UE*"=P
M96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E
M=$%L:6%S*"=P96%R)RD[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS
M9713=6UM87)Y*"=02%`@17AT96YS:6]N(&%N9"!!<'!L:6-A=&EO;B!297!O
M<VET;W)Y)RD[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971$969A
M=6QT4$5!4E!R;W1O8V]L<R@I.PT*("`@("`@("`@("`@)'!E87)?8VAA;FYE
M;"T^<V5T0F%S95523"@G4D535#$N,"<L("=H='1P.B\O<&5A<BYP:'`N;F5T
M+W)E<W0O)RD[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E
M55),*"=215-4,2XQ)RP@)VAT='`Z+R]P96%R+G!H<"YN970O<F5S="\G*3L-
M"B`@("`@("`@("`@(')E='5R;B`D<&5A<E]C:&%N;F5L.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D=&AI<RT^7V=E=$-H86YN96Q&<F]M06QI87,H)&-H
M86YN96PI(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`O+R!T
M:&4@<F5G:7-T<GD@:7,@;F]T('!R;W!E<FQY('-E="!U<"P@<V\@=7-E(&1E
M9F%U;'1S#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#
M:&%N;F5L1FEL92<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=014%2+T-H86YN96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<&5A<E]C:&%N;F5L(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4[
M#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971.86UE*"=P96-L+G!H
M<"YN970G*3L-"B`@("`@("`@("`@("1P96%R7V-H86YN96PM/G-E=$%L:6%S
M*"=P96-L)RD[#0H@("`@("`@("`@("`D<&5A<E]C:&%N;F5L+3YS9713=6UM
M87)Y*"=02%`@17AT96YS:6]N($-O;6UU;FET>2!,:6)R87)Y)RD[#0H@("`@
M("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971$969A=6QT4$5!4E!R;W1O8V]L
M<R@I.PT*("`@("`@("`@("`@)'!E87)?8VAA;FYE;"T^<V5T0F%S95523"@G
M4D535#$N,"<L("=H='1P.B\O<&5C;"YP:'`N;F5T+W)E<W0O)RD[#0H@("`@
M("`@("`@("`D<&5A<E]C:&%N;F5L+3YS971"87-E55),*"=215-4,2XQ)RP@
M)VAT='`Z+R]P96-L+G!H<"YN970O<F5S="\G*3L-"B`@("`@("`@("`@("1P
M96%R7V-H86YN96PM/G-E=%9A;&ED871I;VY086-K86=E*"=014%27U9A;&ED
M871O<E]014-,)RP@)S$N,"<I.PT*("`@("`@("`@("`@<F5T=7)N("1P96%R
M7V-H86YN96P[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3Y?9V5T
M0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D@/3T@)U]?=7)I)RD@>PT*("`@
M("`@("`@("`@+R\@=&AE(')E9VES=')Y(&ES(&YO="!P<F]P97)L>2!S970@
M=7`L('-O('5S92!D969A=6QT<PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'!R:79A=&4@/2!N97<@4$5!4E]#:&%N
M;F5L1FEL93L-"B`@("`@("`@("`@("1P<FEV871E+3YS971.86UE*"=?7W5R
M:2<I.PT*("`@("`@("`@("`@)'!R:79A=&4M/F%D9$9U;F-T:6]N*"=X;6QR
M<&,G+"`G,2XP)RP@)RHJ*BHG*3L-"B`@("`@("`@("`@("1P<FEV871E+3YS
M9713=6UM87)Y*"=0<V5U9&\M8VAA;FYE;"!F;W(@<W1A=&EC('!A8VMA9V5S
M)RD[#0H@("`@("`@("`@("!R971U<FX@)'!R:79A=&4[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1C:#L-"B`@("!]#0H-"B`@("`O+R![>WL@<&%C
M:V%G945X:7-T<R@I#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(%!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@0VAA;FYE;"!N
M86UE#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96P@/2`G<&5A<BYP
M:'`N;F5T)RD-"B`@("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R970@/2`D=&AI<RT^7W!A
M8VMA9V5%>&ES=',H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("`@("`@)'1H
M:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8VAA;FYE;$5X:7-T<R@I#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M90T*
M("`@("`J($!P87)A;2!B;V]L(&EF('1R=64L('1H96X@86QI87-E<R!W:6QL
M(&)E(&EG;F]R960-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!C:&%N;F5L17AI<W1S*"1C:&%N;F5L+"`D;F]A;&EA<V5S
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]C
M:&%N;F5L17AI<W1S*"1C:&%N;F5L+"`D;F]A;&EA<V5S*3L-"B`@("`@("`@
M)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@:7-!;&EA<R@I#0H-"B`@
M("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AE('!A<F%M971E
M<B!I<R!A;B!A;&EA<R!O9B!A(&-H86YN96P-"B`@("`@*B!`<&%R86T@<W1R
M:6YG#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@:7-!;&EA<R@D86QI87,I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@
M)'1H:7,M/E]I<T-H86YN96Q!;&EA<R@D86QI87,I.PT*("`@("`@("`D=&AI
M<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@<&%C:V%G94EN9F\H*0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9WQN=6QL#0H@("`@("H@0'!A<F%M
M('-T<FEN9WQN=6QL#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R
M971U<FX@87)R87E\;G5L;`T*("`@("`J+PT*("`@(&9U;F-T:6]N('!A8VMA
M9V5);F9O*"1P86-K86=E(#T@;G5L;"P@)&ME>2`](&YU;&PL("1C:&%N;F5L
M(#T@)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@
M)'1H:7,M/E]P86-K86=E26YF;R@D<&%C:V%G92P@)&ME>2P@)&-H86YN96PI
M.PT*("`@("`@("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@
M)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAA;FYE
M;$EN9F\H*0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@82!R87<@87)R
M87D@;V8@8VAA;FYE;"!D871A+@T*("`@("`J#0H@("`@("H@1&\@;F]T('5S
M92!T:&ES+"!I;G-T96%D('5S92![0&QI;FL@9V5T0VAA;FYE;"@I?2!F;W(@
M;F]R;6%L#0H@("`@("H@;W!E<F%T:6]N<RX@($%R<F%Y('-T<G5C='5R92!I
M<R!U;F1E9FEN960@:6X@=&AI<R!M971H;V0-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-H86YN96P@;F%M90T*("`@("`J($!P87)A;2!B;V]L('=H971H97(@
M=&\@<W1R:6-T;'D@<F5T<FEE=F4@:6YF;W)M871I;VX@;VYL>2!O;B!N;VXM
M86QI87-E<PT*("`@("`J($!R971U<FX@87)R87E\;G5L;'Q014%27T5R<F]R
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAA;FYE;$EN9F\H)&-H86YN96P@
M/2!N=6QL+"`D;F]A;&EA<V5S(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@
M("`D<F5T(#T@)'1H:7,M/E]C:&%N;F5L26YF;R@D8VAA;FYE;"P@)&YO86QI
M87-E<RD[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H
M86YN96Q.86UE*"1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@
M("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]
M("1T:&ES+3Y?9V5T0VAA;FYE;$9R;VU!;&EA<R@D8VAA;FYE;"D[#0H@("`@
M("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!C:&%N;F5L06QI87,H)&-H86YN96PI#0H@("`@
M>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?;&]C
M:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@("`@
M("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]G971!;&EA<R@D8VAA;FYE
M;"D[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(')E='5R
M;B`D<F5T.PT*("`@('T-"B`@("`O+R![>WL@;&ES=%!A8VMA9V5S*"D-"@T*
M("`@(&9U;F-T:6]N(&QI<W1086-K86=E<R@D8VAA;FYE;"`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^
M7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?;&ES=%!A8VMA9V5S
M*"1C:&%N;F5L*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&QI<W1!;&Q086-K86=E<R@I#0H-"B`@("!F=6YC=&EO;B!L:7-T06QL
M4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?
M;&ES=$%L;%!A8VMA9V5S*"D[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[
M#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!L:7-T0VAA;FYE;"@I#0H-"B`@("!F=6YC=&EO;B!L:7-T
M0VAA;FYE;',H*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?
M;&ES=$-H86YN96QS*"D[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!A9&1086-K86=E*"D-"@T*("`@("\J*@T*("`@("`J($%D9"!A
M;B!I;G-T86QL960@<&%C:V%G92!T;R!T:&4@<F5G:7-T<GD-"B`@("`@*B!`
M<&%R86T@<W1R:6YG?%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E
M1FEL95]V,B!P86-K86=E(&YA;64@;W(@;V)J96-T#0H@("`@("H@("`@("`@
M("`@("`@("!T:&%T('=I;&P@8F4@<&%S<V5D('1O('M`;&EN:R!A9&1086-K
M86=E,B@I?0T*("`@("`J($!P87)A;2!A<G)A>2!P86-K86=E(&EN9F\@*'!A
M<G-E9"!B>2!014%27T-O;6UO;CHZ:6YF;T9R;VTJ*"D@;65T:&]D<RD-"B`@
M("`@*B!`<F5T=7)N(&)O;VP@<W5C8V5S<R!O9B!S879I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!A9&1086-K86=E*"1P86-K86=E+"`D:6YF;RD-"B`@
M("![#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&EN9F\I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F%D9%!A8VMA9V4R*"1I;F9O*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?
M;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M/E]A9&1086-K86=E*"1P
M86-K86=E+"`D:6YF;RD[#0H@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@
M("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X
M:7-T<R@G4$5!4E]086-K86=E1FEL95]V,2<I*2![#0H@("`@("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8Q+G!H<"<[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]086-K
M86=E1FEL95]V,3L-"B`@("`@("`@("`@("1P9BT^<V5T0V]N9FEG*"1T:&ES
M+3Y?8V]N9FEG*3L-"B`@("`@("`@("`@("1P9BT^9G)O;4%R<F%Y*"1I;F9O
M*3L-"B`@("`@("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YU;FEN<W1A
M;&Q086-K86=E*"1P9BD[#0H@("`@("`@("`@("`D=&AI<RT^7V1E<&5N9&5N
M8WE$0BT^:6YS=&%L;%!A8VMA9V4H)'!F*3L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@861D4&%C:V%G93(H*0T*#0H@("`@9G5N8W1I;VX@861D4&%C:V%G93(H
M)&EN9F\I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V]B:F5C="@D:6YF;RDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^861D4&%C:V%G92@D:6YF
M;ULG<&%C:V%G92==+"`D:6YF;RD[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]%6"DI*2![
M#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@
M)')E="`]("1T:&ES+3Y?861D4&%C:V%G93(H)&EN9F\I.PT*("`@("`@("`D
M=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!I9B`H)')E="D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(M/G5N:6YS=&%L;%!A8VMA9V4H
M)&EN9F\I.PT*("`@("`@("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y1$(M/FEN
M<W1A;&Q086-K86=E*"1I;F9O*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@=7!D
M871E0VAA;FYE;"@I#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@9G5T=7)E(&5X
M<&%N9&EB:6QI='D@<'5R<&]S97,L('-E<&%R871E('1H:7,-"B`@("`@*B!`
M<&%R86T@4$5!4E]#:&%N;F5L1FEL90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M('5P9&%T94-H86YN96PH)&-H86YN96PL("1L87-T;6]D:69I960@/2!N=6QL
M*0T*("`@('L-"B`@("`@("`@:68@*"1C:&%N;F5L+3YG971.86UE*"D@/3T@
M)U]?=7)I)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^861D0VAA;FYE;"@D8VAA;FYE
M;"P@)&QA<W1M;V1I9FEE9"P@=')U92D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1E;&5T94-H86YN96PH*0T*#0H@("`@+RHJ#0H@("`@
M("H@1&5L971I;VX@9F%I;',@:68@=&AE<F4@87)E(&%N>2!P86-K86=E<R!I
M;G-T86QL960@9G)O;2!T:&4@8VAA;FYE;`T*("`@("`J($!P87)A;2!S=')I
M;F=\4$5!4E]#:&%N;F5L1FEL92!C:&%N;F5L(&YA;64-"B`@("`@*B!`<F5T
M=7)N(&)O;VQE86Y\4$5!4E]%<G)O<B!4<G5E(&]N(&1E;&5T:6]N+"!F86QS
M92!I9B!I="!D;V5S;B=T(&5X:7-T#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9&5L971E0VAA;FYE;"@D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?15@I*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@("`@("1R
M970@/2`D=&AI<RT^7V1E;&5T94-H86YN96PH)&-H86YN96PI.PT*("`@("`@
M("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!I9B`H)')E="`F)B!I<U]A
M*"1T:&ES+3Y?8V]N9FEG+"`G4$5!4E]#;VYF:6<G*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]C;VYF:6<M/G-E=$-H86YN96QS*"1T:&ES+3YL:7-T0VAA
M;FYE;',H*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9$-H86YN96PH*0T*
M#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?0VAA;FYE;$9I;&4@0VAA
M;FYE;"!O8FIE8W0-"B`@("`@*B!`<&%R86T@<W1R:6YG($QA<W0M36]D:69I
M960@:&5A9&5R(&9R;VT@2%144"!F;W(@8V%C:&EN9PT*("`@("`J($!R971U
M<FX@8F]O;&5A;GQ014%27T5R<F]R(%1R=64@;VX@8W)E871I;VXL(&9A;'-E
M(&EF(&ET(&%L<F5A9'D@97AI<W1S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"`](&9A;'-E+"`D
M=7!D871E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V$H)&-H
M86YN96PL("=014%27T-H86YN96Q&:6QE)RDI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21C:&%N;F5L
M+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI
M<RT^7VQO8VLH3$]#2U]%6"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`]("1T:&ES+3Y?861D0VAA;FYE
M;"@D8VAA;FYE;"P@)'5P9&%T92P@)&QA<W1M;V1I9FEE9"D[#0H@("`@("`@
M("1T:&ES+3Y?=6YL;V-K*"D[#0H@("`@("`@(&EF("@A)'5P9&%T92`F)B`D
M<F5T("8F(&ES7V$H)'1H:7,M/E]C;VYF:6<L("=014%27T-O;F9I9R<I*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V-O;F9I9RT^<V5T0VAA;FYE;',H)'1H
M:7,M/FQI<W1#:&%N;F5L<R@I*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5L
M971E4&%C:V%G92@I#0H-"B`@("!F=6YC=&EO;B!D96QE=&5086-K86=E*"1P
M86-K86=E+"`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G*0T*("`@('L-"B`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#
M2U]%6"DI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-
M"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^7W!A8VMA9V5&:6QE3F%M92@D<&%C
M:V%G92P@)&-H86YN96PI.PT*("`@("`@("`D<F5T(#T@0'5N;&EN:R@D9FEL
M92D[#0H@("`@("`@("1T:&ES+3Y?<F5B=6EL9$9I;&5-87`H*3L-"B`@("`@
M("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@)'`@/2!A<G)A>2@G8VAA
M;FYE;"<@/3X@)&-H86YN96PL("=P86-K86=E)R`]/B`D<&%C:V%G92D[#0H@
M("`@("`@("1T:&ES+3Y?9&5P96YD96YC>41"+3YU;FEN<W1A;&Q086-K86=E
M*"1P*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[('5P9&%T95!A8VMA9V4H*0T*#0H@("`@9G5N8W1I
M;VX@=7!D871E4&%C:V%G92@D<&%C:V%G92P@)&EN9F\L("1M97)G92`]('1R
M=64I#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1I;F9O*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YU<&1A=&5086-K86=E,B@D:6YF
M;RP@)&UE<F=E*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H
M:7,M/E]U<&1A=&5086-K86=E*"1P86-K86=E+"`D:6YF;RP@)&UE<F=E*3L-
M"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@:68@*"1R970I
M('L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA
M9V5&:6QE7W8Q)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1P9B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8Q.PT*("`@
M("`@("`@("`@)'!F+3YS971#;VYF:6<H)'1H:7,M/E]C;VYF:6<I.PT*("`@
M("`@("`@("`@)'!F+3YF<F]M07)R87DH)'1H:7,M/G!A8VMA9V5);F9O*"1P
M86-K86=E*2D[#0H@("`@("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^
M=6YI;G-T86QL4&%C:V%G92@D<&8I.PT*("`@("`@("`@("`@)'1H:7,M/E]D
M97!E;F1E;F-Y1$(M/FEN<W1A;&Q086-K86=E*"1P9BD[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[('5P9&%T95!A8VMA9V4R*"D-"@T*("`@(&9U;F-T:6]N('5P
M9&%T95!A8VMA9V4R*"1I;F9O*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]O
M8FIE8W0H)&EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G5P
M9&%T95!A8VMA9V4H)&EN9F];)W!A8VMA9V4G72P@)&EN9F\L("1M97)G92D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D:6YF;RT^=F%L:61A=&4H4$5!
M4E]604Q)1$%415]$3U=.3$]!1$E.1RDI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D92`]("1T:&ES+3Y?;&]C:RA,3T-+7T58*2DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)'1H:7,M
M/E]U<&1A=&5086-K86=E,B@D:6YF;RD[#0H@("`@("`@("1T:&ES+3Y?=6YL
M;V-K*"D[#0H@("`@("`@(&EF("@D<F5T*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7V1E<&5N9&5N8WE$0BT^=6YI;G-T86QL4&%C:V%G92@D:6YF;RD[#0H@
M("`@("`@("`@("`D=&AI<RT^7V1E<&5N9&5N8WE$0BT^:6YS=&%L;%!A8VMA
M9V4H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971#:&%N;F5L*"D-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M90T*
M("`@("`J($!P87)A;2!B;V]L('=H971H97(@=&\@<W1R:6-T;'D@<F5T=7)N
M(')A=R!C:&%N;F5L<R`H;F\@86QI87-E<RD-"B`@("`@*B!`<F5T=7)N(%!%
M05)?0VAA;FYE;$9I;&5\4$5!4E]%<G)O<@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N("9G971#:&%N;F5L*"1C:&%N;F5L+"`D;F]A;&EA<V5S(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES
M+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D93L-
M"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)B1T:&ES+3Y?9V5T0VAA;FYE
M;"@D8VAA;FYE;"P@)&YO86QI87-E<RD[#0H@("`@("`@(&EF("@A)')E="D@
M>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO
M=VX@8VAA;FYE;#H@)R`N("1C:&%N;F5L*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7W5N;&]C:R@I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4&%C:V%G92@I#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M90T*("`@("`J($!R971U
M<FX@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R?&YU
M;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T4&%C:V%G92@D<&%C:V%G
M92P@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]L;V-K*$Q/0TM?4T@I
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("!]#0H@("`@
M("`@("1P9B`]("8D=&AI<RT^7V=E=%!A8VMA9V4H)'!A8VMA9V4L("1C:&%N
M;F5L*3L-"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@<F5T
M=7)N("1P9CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*("`@
M("`J($=E="!014%27U!A8VMA9V5&:6QE7W9;,2\R72!O8FIE8W1S(')E<')E
M<V5N=&EN9R!T:&4@8V]N=&5N=',@;V8-"B`@("`@*B!A(&1E<&5N9&5N8WD@
M9W)O=7`@=&AA="!A<F4@:6YS=&%L;&5D+@T*("`@("`J#0H@("`@("H@5&AI
M<R!I<R!U<V5D(&%T('5N:6YS=&%L;"UT:6UE#0H@("`@("H@0'!A<F%M(&%R
M<F%Y#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$EN<W1A;&QE9$=R;W5P*"1G<F]U<"D-"B`@("![#0H@
M("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S970H)&=R
M;W5P6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1G
M<F]U<%LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1G<F]U
M<%LG<&%C:V%G92==(#T@87)R87DH)&=R;W5P6R=P86-K86=E)UTI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R=P86-K
M86=E)UT@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D9&5P8VAA
M;FYE;"`](&ES<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI(#\@)'!A8VMA9V5;
M)V-H86YN96PG72`Z("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@)'`@/2`F
M)'1H:7,M/F=E=%!A8VMA9V4H)'!A8VMA9V5;)VYA;64G72P@)&1E<&-H86YN
M96PI.PT*("`@("`@("`@("`@("`@(&EF("@D<"D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<V%V92`]("8D<#L-"B`@("`@("`@("`@("`@("`@("`@)')E
M=%M=(#T@)B1S879E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&=R;W5P6R=S=6)P
M86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<%LG
M<W5B<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1G<F]U<%LG
M<W5B<&%C:V%G92==(#T@87)R87DH)&=R;W5P6R=S=6)P86-K86=E)UTI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R=S
M=6)P86-K86=E)UT@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D
M9&5P8VAA;FYE;"`](&ES<V5T*"1P86-K86=E6R=C:&%N;F5L)UTI(#\@)'!A
M8VMA9V5;)V-H86YN96PG72`Z("=?7W5R:2<[#0H@("`@("`@("`@("`@("`@
M)'`@/2`F)'1H:7,M/F=E=%!A8VMA9V4H)'!A8VMA9V5;)VYA;64G72P@)&1E
M<&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("@D<"D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<V%V92`]("8D<#L-"B`@("`@("`@("`@("`@("`@
M("`@)')E=%M=(#T@)B1S879E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-O=6YT*"1R970I
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@>WM[(&=E=$-H
M86YN96Q686QI9&%T;W(H*0T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0')E='5R;B!014%27U9A;&ED871E
M?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-H86YN96Q686QI
M9&%T;W(H)&-H86YN96PI#0H@("`@>PT*("`@("`@("`D8VAA;B`]("1T:&ES
M+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&-H86XI*2![#0H@("`@("`@("`@("!R971U<FX@)&-H86X[#0H@
M("`@("`@('T-"B`@("`@("`@)'9A;"`]("1C:&%N+3YG971686QI9&%T:6]N
M3V)J96-T*"D[#0H@("`@("`@(')E='5R;B`D=F%L.PT*("`@('T-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@9V5T0VAA;FYE;',H*0T*("`@("\J*@T*("`@
M("`J($!P87)A;2!S=')I;F<@8VAA;FYE;"!N86UE#0H@("`@("H@0')E='5R
M;B!A<G)A>2!A;B!A<G)A>2!O9B!014%27T-H86YN96Q&:6QE(&]B:F5C=',@
M<F5P<F5S96YT:6YG(&5V97)Y(&EN<W1A;&QE9"!C:&%N;F5L#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)F=E=$-H86YN96QS*"D-"B`@("![#0H@("`@("`@
M("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M92`]("1T:&ES+3Y?;&]C:RA,3T-+7U-(*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7VQI<W1#:&%N;F5L<R@I(&%S("1C:&%N;F5L*2![#0H@("`@("`@("`@("`D
M92`]("8D=&AI<RT^7V=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("`@
M("`@:68@*"$D92!\?"!014%2.CII<T5R<F]R*"1E*2D@>PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)')E=%M=(#T@)&4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]U;FQO
M8VLH*3L-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&-H96-K1FEL94UA<"@I#0H-"B`@("`O*BH-"B`@
M("`@*B!497-T('=H971H97(@82!F:6QE(&]R('-E="!O9B!F:6QE<R!B96QO
M;F=S('1O(&$@<&%C:V%G92X-"B`@("`@*@T*("`@("`J($EF(&%N(&%R<F%Y
M(&ES('!A<W-E9"!I;@T*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@9FEL
M92!P871H+"!A8G-O;'5T92!O<B!R96QA=&EV92!T;R!T:&4@<&5A<@T*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@:6YS=&%L;"!D:7(-"B`@("`@*B!`
M<&%R86T@<W1R:6YG?&%R<F%Y(&YA;64@;V8@4$5!4B!P86-K86=E(&]R(&%R
M<F%Y*"=P86-K86=E)R`]/B!N86UE+"`G8VAA;FYE;"<@/3X-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@(&-H86YN96PI(&]F(&$@<&%C:V%G92!T:&%T
M('=I;&P@8F4@:6=N;W)E9`T*("`@("`J($!P87)A;2!S=')I;F<@05!)('9E
M<G-I;VX@+2`Q+C$@=VEL;"!E>&-L=61E(&%N>2!F:6QE<R!B96QO;F=I;F<@
M=&\@82!P86-K86=E#0H@("`@("H@0'!A<F%M(&%R<F%Y('!R:79A=&4@<F5C
M=7)S:6]N('9A<FEA8FQE#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS92!W
M:&EC:"!P86-K86=E(&%N9"!C:&%N;F5L('1H92!F:6QE(&)E;&]N9W,@=&\L
M(&]R(&%N(&5M<'1Y#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!S=')I
M;F<@:68@=&AE(&9I;&4@9&]E<R!N;W0@8F5L;VYG('1O(&%N(&EN<W1A;&QE
M9"!P86-K86=E+`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@;W(@8F5L
M;VYG<R!T;R!T:&4@<V5C;VYD('!A<F%M971E<B=S('!A8VMA9V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!C:&5C:T9I;&5-87`H)'!A=&@L("1P86-K86=E
M(#T@9F%L<V4L("1A<&D@/2`G,2XP)RP@)&%T=')S(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-?87)R87DH)'!A=&@I*2![#0H@("`@("`@("`@
M("!S=&%T:6,@)&YO=&5M<'1Y.PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1N
M;W1E;7!T>2DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@G4$5!4E]);G-T86QL97)?4F]L92<I*2![#0H@("`@("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(O4F]L92YP:'`G.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D;F]T96UP='D@
M/2!C<F5A=&5?9G5N8W1I;VXH)R1A)RPG<F5T=7)N("%E;7!T>2@D82D[)RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%C:V%G92`](&ES7V%R
M<F%Y*"1P86-K86=E*2`_(&%R<F%Y*'-T<G1O;&]W97(H)'!A8VMA9V5;,%TI
M+"!S=')T;VQO=V5R*"1P86-K86=E6S%=*2D-"B`@("`@("`@("`@("`@("`Z
M('-T<G1O;&]W97(H)'!A8VMA9V4I.PT*("`@("`@("`@("`@)'!K9W,@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A=&@@87,@)&YA;64@
M/3X@)&%T=')S*2![#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1A
M='1R<RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R
M<ULG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2`D871T<G-;)VEN<W1A;&PM87,G73L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1A
M='1R<ULG<F]L92==+"!014%27TEN<W1A;&QE<E]2;VQE.CIG971);G-T86QL
M86)L95)O;&5S*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!T
M:&5S92!A<F4@;F]T(&EN<W1A;&QE9`T*("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D871T<G-;)W)O;&4G72P@4$5!
M4E]);G-T86QL97)?4F]L93HZ9V5T0F%S96EN<W1A;&Q2;VQE<R@I*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')S6R=B87-E:6YS=&%L;&1I
M<B==(#T@:7-?87)R87DH)'!A8VMA9V4I(#\@)'!A8VMA9V5;,5T@.B`D<&%C
M:V%G93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&%T=')S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`D871T<G-;)V)A<V5I
M;G-T86QL9&ER)UT@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&YA;64[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)'!K9W-;)&YA;65=(#T@)'1H:7,M/F-H96-K1FEL94UA
M<"@D;F%M92P@)'!A8VMA9V4L("1A<&DL("1A='1R<RD[#0H@("`@("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!K9W-;)&YA;65=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'!K9W-;)&YA;65=.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R
M;B!A<G)A>5]F:6QT97(H)'!K9W,L("1N;W1E;7!T>2D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YF:6QE;6%P7V-A8VAE*2D@>PT*
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7VQO
M8VLH3$]#2U]32"DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3Y?<F5A
M9$9I;&5-87`H*3L-"B`@("`@("`@("`@("1T:&ES+3Y?=6YL;V-K*"D[#0H@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("@A)&%T=')S*2![#0H@("`@("`@("`@("`D871T
M<G,@/2!A<G)A>2@G<F]L92<@/3X@)W!H<"<I.R`O+R!A;GD@;VQD(&-A;&P@
M=V]U;&0@8F4@9F]R(%!(4"!R;VQE(&]N;'D-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F9I;&5M87!?8V%C:&5;)&%T=')S6R=R;VQE
M)UU=6R1P871H72DI('L-"B`@("`@("`@("`@(&EF("@D87!I(#X]("<Q+C$G
M("8F("1T:&ES+3YF:6QE;6%P7V-A8VAE6R1A='1R<ULG<F]L92==75LD<&%T
M:%T@/3T@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F9I;&5M87!?8V%C:&5;)&%T=')S6R=R;VQE)UU=6R1P871H73L-"B`@("`@
M("`@?0T*("`@("`@("`D;"`]('-T<FQE;B@D=&AI<RT^:6YS=&%L;%]D:7(I
M.PT*("`@("`@("!I9B`H<W5B<W1R*"1P871H+"`P+"`D;"D@/3T@)'1H:7,M
M/FEN<W1A;&Q?9&ER*2![#0H@("`@("`@("`@("`D<&%T:"`]('!R96=?<F5P
M;&%C92@G(5XG+D1)4D5#5$]265]315!!4D%43U(N)RLA)RP@)R<L('-U8G-T
M<B@D<&%T:"P@)&PI*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F9I;&5M87!?8V%C:&5;)&%T=')S6R=R;VQE)UU=6R1P871H72DI
M('L-"B`@("`@("`@("`@(&EF("@D87!I(#X]("<Q+C$G("8F("1T:&ES+3YF
M:6QE;6%P7V-A8VAE6R1A='1R<ULG<F]L92==75LD<&%T:%T@/3T@)'!A8VMA
M9V4I('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9I;&5M87!?8V%C
M:&5;)&%T=')S6R=R;VQE)UU=6R1P871H73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&%P:59E<G-I;VXH*0T*("`@("\J*@T*("`@("`J($=E="!T:&4@97AP
M96-T960@05!)('9E<G-I;VXN("!#:&%N;F5L<R!!4$D@:7,@=F5R<VEO;B`Q
M+C$L(&%S(&ET(&ES(&)A8VMW87)D<PT*("`@("`J(&-O;7!A=&EB;&4@=VET
M:"`Q+C`-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&%P:59E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<Q
M+C$G.PT*("`@('T-"B`@("`O+R!]?7T-"@T*#0H@("`@+RHJ#0H@("`@("H@
M4&%R<V4@82!P86-K86=E(&YA;64L(&]R('9A;&ED871E(&$@<&%R<V5D('!A
M8VMA9V4@;F%M92!A<G)A>0T*("`@("`J($!P87)A;2!S=')I;F=\87)R87D@
M<&%S<R!I;B!A;B!A<G)A>2!O9B!F;W)M870-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("=P86-K86=E)R`]/B`G<&YA;64G+`T*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@6R=C:&%N;F5L)R`]/B`G8VAA;FYA;64G+%T-"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@(%LG=F5R<VEO;B<@/3X@)W9E<G-I;VXG+%T-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(%LG<W1A=&4G(#T^("=S=&%T92<L
M70T*("`@("`J("`@("`@("`@("`@("`@("`@("`@6R=G<F]U<"<@/3X@)V=R
M;W5P;F%M92==*0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@;W(@82!S
M=')I;F<@;V8@9F]R;6%T#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;
M8VAA;FYE;#HO+UU;8VAA;FYA;64O77!N86UE6RUV97)S:6]N?"US=&%T95U;
M+V=R;W5P/6=R;W5P;F%M95T-"B`@("`@*B!`<F5T=7)N(&%R<F%Y?%!%05)?
M17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P87)S95!A8VMA9V5.86UE
M*"1P87)A;2P@)&1E9F%U;'1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<I#0H@
M("`@>PT*("`@("`@("`D<V%V97!A<F%M(#T@)'!A<F%M.PT*("`@("`@("!I
M9B`H:7-?87)R87DH)'!A<F%M*2D@>PT*("`@("`@("`@("`@+R\@8V]N=F5R
M="!T;R!S=')I;F<@9F]R(&5R<F]R(&UE<W-A9V5S#0H@("`@("`@("`@("`D
M<V%V97!A<F%M(#T@)'1H:7,M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M)'!A<F%M*3L-"B`@("`@("`@("`@("\O('!R;V-E<W,@=&AE(&%R<F%Y#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)A;5LG<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S
M95!A8VMA9V5.86UE*"DZ(&%R<F%Y("1P87)A;2`G("X-"B`@("`@("`@("`@
M("`@("`@("`@)VUU<W0@8V]N=&%I;B!A('9A;&ED('!A8VMA9V4@;F%M92!I
M;B!I;F1E>"`B<&%R86TB)RP-"B`@("`@("`@("`@("`@("`@("`@)W!A8VMA
M9V4G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*"%I<W-E="@D<&%R86U;)W5R:2==*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M6R=C:&%N;F5L)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1P87)A;5LG8VAA;FYE;"==(#T@)&1E9F%U
M;'1C:&%N;F5L.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=C:&%N;F5L)UT@/2`G
M7U]U<FDG.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&-O;7!O;F5N=',@/2!`<&%R<V5?=7)L*"1P87)A;2D[#0H@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;7!O;F5N='-;)W-C:&5M92==*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("@D8V]M<&]N96YT<ULG<V-H96UE)UT@
M/3T@)VAT='`G*2![#0H@("`@("`@("`@("`@("`@("`@("\O('5R:2!P86-K
M86=E#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`](&%R<F%Y*"=U<FDG
M(#T^("1P87)A;2P@)V-H86YN96PG(#T^("=?7W5R:2<I.PT*("`@("`@("`@
M("`@("`@('T@96QS96EF*"1C;VUP;VYE;G1S6R=S8VAE;64G72`A/2`G8VAA
M;FYE;"<I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@;VYL>2!C:&%N;F5L.B\O
M('5R:7,@;6%Y("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)V)E(&1O
M=VYL;V%D960L(&YO="`B)R`N("1P87)A;2`N("<B)RP@)VEN=F%L:60G+"!N
M=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)&-O;7!O;F5N='-;
M)W!A=&@G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G<&%R<V5086-K86=E3F%M92@I.B!A<G)A>2`D<&%R86T@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("=M=7-T(&-O;G1A:6X@82!V86QI9"!P
M86-K86=E(&YA;64@:6X@(B<@+B`D<&%R86T@+B`G(B<L#0H@("`@("`@("`@
M("`@("`@("`@("=P86-K86=E)RP@;G5L;"P@;G5L;"P@)'!A<F%M*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D8V]M<&]N96YT
M<ULG:&]S="==*2D@>PT*("`@("`@("`@("`@("`@("\O(')E;6]V92!T:&4@
M;&5A9&EN9R`B+R(-"B`@("`@("`@("`@("`@("`D8V]M<&]N96YT<ULG<&%T
M:"==(#T@<W5B<W1R*"1C;VUP;VYE;G1S6R=P871H)UTL(#$I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D8V]M<&]N96YT<ULG
M<V-H96UE)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D8V]M
M<&]N96YT<ULG<&%T:"==+"`G+R<I("$]/2!F86QS92D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)&-O;7!O;F5N='-;)W!A=&@G77LP?2`]/2`G+R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=P87)S95!A8VMA9V5.86UE*"DZ('1H:7,@:7,@;F]T("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=A('!A8VMA9V4@;F%M92P@
M:70@8F5G:6YS('=I=&@@(B\B(&EN("(G("X@)'!A<F%M("X@)R(G+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=I;G9A;&ED)RP@;G5L;"P@;G5L
M;"P@)'!A<F%M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`D<&%R=',@/2!E>'!L;V1E*"<O)RP@)&-O;7!O;F5N='-;
M)W!A=&@G72D[#0H@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=H
M;W-T)UT@/2!A<G)A>5]S:&EF="@D<&%R=',I.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)'!A<G1S*2`^(#$I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1C;VUP;VYE;G1S6R=P871H)UT@/2!A<G)A>5]P;W`H)'!A
M<G1S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VUP;VYE;G1S6R=H
M;W-T)UT@+CT@)R\G("X@:6UP;&]D92@G+R<L("1P87)T<RD[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]M<&]N96YT<ULG<&%T:"==(#T@:6UP;&]D92@G+R<L("1P87)T<RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D8V]M<&]N96YT<ULG:&]S="==
M(#T@)&1E9F%U;'1C:&%N;F5L.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D
M8V]M<&]N96YT<ULG<&%T:"==+"`G+R<I*2![#0H@("`@("`@("`@("`@("`@
M("`@("1P87)T<R`](&5X<&QO9&4H)R\G+"`D8V]M<&]N96YT<ULG<&%T:"==
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&-O;7!O;F5N='-;)W!A=&@G72`]
M(&%R<F%Y7W!O<"@D<&%R=',I.PT*("`@("`@("`@("`@("`@("`@("`D8V]M
M<&]N96YT<ULG:&]S="==("X]("<O)R`N(&EM<&QO9&4H)R\G+"`D<&%R=',I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@
M("`D<&%R86U;)W!A8VMA9V4G72`]("1C;VUP;VYE;G1S6R=P871H)UT[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1P87)A;2`]
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)&-O
M;7!O;F5N='-;)W!A=&@G70T*("`@("`@("`@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D8V]M<&]N96YT<ULG:&]S="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&%R86U;)V-H86YN96PG72`]("1C
M;VUP;VYE;G1S6R=H;W-T)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R=F
M<F%G;65N="==*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG9W)O=7`G
M72`]("1C;VUP;VYE;G1S6R=F<F%G;65N="==.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R=U<V5R)UTI*2![
M#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=U<V5R)UT@/2`D8V]M<&]N96YT
M<ULG=7-E<B==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1C;VUP;VYE;G1S6R=P87-S)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'!A<F%M6R=P87-S)UT@/2`D8V]M<&]N96YT<ULG<&%S<R==.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1C;VUP;VYE;G1S6R=Q
M=65R>2==*2D@>PT*("`@("`@("`@("`@("`@('!A<G-E7W-T<B@D8V]M<&]N
M96YT<ULG<75E<GDG72P@)'!A<F%M6R=O<'1S)UTI.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@+R\@8VAE8VL@9F]R(&5X=&5N<VEO;@T*("`@("`@
M("`@("`@)'!A=&AI;F9O(#T@<&%T:&EN9F\H)'!A<F%M6R=P86-K86=E)UTI
M.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P871H:6YF;ULG97AT96YS:6]N
M)UTI("8F#0H@("`@("`@("`@("`@("`@("!I;E]A<G)A>2AS=')T;VQO=V5R
M*"1P871H:6YF;ULG97AT96YS:6]N)UTI+"!A<G)A>2@G=&=Z)RP@)W1A<B<I
M*2D@>PT*("`@("`@("`@("`@("`@("1P87)A;5LG97AT96YS:6]N)UT@/2`D
M<&%T:&EN9F];)V5X=&5N<VEO;B==.PT*("`@("`@("`@("`@("`@("1P87)A
M;5LG<&%C:V%G92==(#T@<W5B<W1R*"1P871H:6YF;ULG8F%S96YA;64G72P@
M,"P-"B`@("`@("`@("`@("`@("`@("`@<W1R;&5N*"1P871H:6YF;ULG8F%S
M96YA;64G72D@+2`T*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O
M(&-H96-K(&9O<B!V97)S:6]N#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1P
M87)A;5LG<&%C:V%G92==+"`G+2<I*2![#0H@("`@("`@("`@("`@("`@)'1E
M<W0@/2!E>'!L;V1E*"<M)RP@)'!A<F%M6R=P86-K86=E)UTI.PT*("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D=&5S="D@(3T@,BD@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G<&%R<V5086-K
M86=E3F%M92@I.B!O;FQY(&]N92!V97)S:6]N+W-T871E("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E;&EM:71E<B`B+2(@:7,@86QL;W=E9"!I
M;B`B)R`N("1S879E<&%R86T@+B`G(B<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G=F5R<VEO;B<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&QI<W0H)'!A<F%M6R=P86-K
M86=E)UTL("1P87)A;5LG=F5R<VEO;B==*2`]("1T97-T.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("\O('9A;&ED871I;VX-"B`@("`@
M("`@)&EN9F\@/2`D=&AI<RT^8VAA;FYE;$5X:7-T<R@D<&%R86U;)V-H86YN
M96PG72D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A)&EN9F\I('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=U;FMN;W=N(&-H86YN96P@(B<@+B`D<&%R86U;)V-H86YN96PG
M72`N#0H@("`@("`@("`@("`@("`@)R(@:6X@(B<@+B`D<V%V97!A<F%M("X@
M)R(G+"`G8VAA;FYE;"<L(&YU;&PL(&YU;&PL("1P87)A;2D[#0H@("`@("`@
M('T-"B`@("`@("`@)&-H86X@/2`D=&AI<RT^9V5T0VAA;FYE;"@D<&%R86U;
M)V-H86YN96PG72D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1C:&%N.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A)&-H86XI('L-"B`@("`@("`@("`@(')E='5R;B!014%2
M.CIR86ES945R<F]R*")%>&-E<'1I;VXZ(&-O<G)U<'0@<F5G:7-T<GDL(&-O
M=6QD(&YO="`B("X-"B`@("`@("`@("`@("`@("`B<F5T<FEE=F4@8VAA;FYE
M;"`B("X@)'!A<F%M6R=C:&%N;F5L)UT@+B`B(&EN9F]R;6%T:6]N(BP-"B`@
M("`@("`@("`@("`@("`G<F5G:7-T<GDG+"!N=6QL+"!N=6QL+"`D<&%R86TI
M.PT*("`@("`@("!]#0H@("`@("`@("1P87)A;5LG8VAA;FYE;"==(#T@)&-H
M86XM/F=E=$YA;64H*3L-"B`@("`@("`@)'9A;&ED871E(#T@)&-H86XM/F=E
M=%9A;&ED871I;VY/8FIE8W0H*3L-"B`@("`@("`@)'9P86-K86=E(#T@)&-H
M86XM/F=E=%9A;&ED871I;VY086-K86=E*"D[#0H@("`@("`@("\O('9A;&ED
M871E('!A8VMA9V4@;F%M90T*("`@("`@("!I9B`H(21V86QI9&%T92T^=F%L
M:61086-K86=E3F%M92@D<&%R86U;)W!A8VMA9V4G72P@)'9P86-K86=E6R=?
M8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@:6YV86QI9"!P86-K86=E(&YA
M;64@(B<@+@T*("`@("`@("`@("`@("`@("1P87)A;5LG<&%C:V%G92==("X@
M)R(@:6X@(B<@+B`D<V%V97!A<F%M("X@)R(G+`T*("`@("`@("`@("`@("`@
M("=P86-K86=E)RP@;G5L;"P@;G5L;"P@)'!A<F%M*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)'!A<F%M6R=G<F]U<"==*2D@>PT*("`@("`@
M("`@("`@:68@*"%014%27U9A;&ED871E.CIV86QI9$=R;W5P3F%M92@D<&%R
M86U;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)W!A<G-E4&%C:V%G94YA;64H*3H@9&5P96YD96YC>2!G
M<F]U<"`B)R`N("1P87)A;5LG9W)O=7`G72`N#0H@("`@("`@("`@("`@("`@
M("`@("<B(&ES(&YO="!A('9A;&ED(&=R;W5P(&YA;64@:6X@(B<@+B`D<V%V
M97!A<F%M("X@)R(G+"`G9W)O=7`G+"!N=6QL+"!N=6QL+`T*("`@("`@("`@
M("`@("`@("`@("`D<&%R86TI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D<&%R86U;)W-T871E)UTI*2![#0H@("`@
M("`@("`@("!I9B`H(6EN7V%R<F%Y*'-T<G1O;&]W97(H)'!A<F%M6R=S=&%T
M92==*2P@)'9A;&ED871E+3YG971686QI9%-T871E<R@I*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=P87)S95!A8VMA
M9V5.86UE*"DZ('-T871E("(G("X@)'!A<F%M6R=S=&%T92==#0H@("`@("`@
M("`@("`@("`@("`@("X@)R(@:7,@;F]T(&$@=F%L:60@<W1A=&4@:6X@(B<@
M+B`D<V%V97!A<F%M("X@)R(G+`T*("`@("`@("`@("`@("`@("`@("`G<W1A
M=&4G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%R86U;)W9E<G-I;VXG72DI
M('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D<&%R86U;)W-T871E)UTI*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)W!A
M<G-E4&%C:V%G94YA;64H*3H@8V%N;F]T(&-O;G1A:6X@8F]T:"`G("X-"B`@
M("`@("`@("`@("`@("`@("`@)V$@=F5R<VEO;B!A;F0@82!S=&%B:6QI='D@
M*'-T871E*2!I;B`B)R`N("1S879E<&%R86T@+B`G(B<L#0H@("`@("`@("`@
M("`@("`@("`@("=V97)S:6]N+W-T871E)RP@;G5L;"P@;G5L;"P@)'!A<F%M
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(&-H96-K('=H971H
M97(@=F5R<VEO;B!I<R!A8W1U86QL>2!A('-T871E#0H@("`@("`@("`@("!I
M9B`H:6Y?87)R87DH<W1R=&]L;W=E<B@D<&%R86U;)W9E<G-I;VXG72DL("1V
M86QI9&%T92T^9V5T5F%L:613=&%T97,H*2DI('L-"B`@("`@("`@("`@("`@
M("`D<&%R86U;)W-T871E)UT@/2!S=')T;VQO=V5R*"1P87)A;5LG=F5R<VEO
M;B==*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D<&%R86U;)W9E<G-I;VXG
M72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF
M("@A)'9A;&ED871E+3YV86QI9%9E<G-I;VXH)'!A<F%M6R=V97)S:6]N)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=P87)S95!A8VMA9V5.86UE*"DZ("(G("X@)'!A<F%M6R=V97)S:6]N
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(@:7,@;F5I=&AE<B!A
M('9A;&ED('9E<G-I;VX@;F]R(&$@=F%L:60@<W1A=&4@:6X@(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)'-A=F5P87)A;2`N("<B)RP@)W9E<G-I
M;VXO<W1A=&4G+"!N=6QL+"!N=6QL+"`D<&%R86TI.PT*("`@("`@("`@("`@
M("`@('T@("`@("`@("`@("`@("`@("`@(`T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D<&%R86T[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0')E='5R;B!S=')I
M;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P87)S961086-K86=E3F%M951O
M4W1R:6YG*"1P87)S960L("1B<FEE9B`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@:68@*&ES7W-T<FEN9R@D<&%R<V5D*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1P87)S960[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES7V]B:F5C
M="@D<&%R<V5D*2D@>PT*("`@("`@("`@("`@)'`@/2`D<&%R<V5D.PT*("`@
M("`@("`@("`@)'!A<G-E9"`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("=P
M86-K86=E)R`]/B`D<"T^9V5T4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@
M("=C:&%N;F5L)R`]/B`D<"T^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@
M("`@("=V97)S:6]N)R`]/B`D<"T^9V5T5F5R<VEO;B@I+`T*("`@("`@("`@
M("`@*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG
M=7)I)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'!A<G-E9%LG=7)I)UT[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1B<FEE9BD@>PT*("`@("`@("`@
M("`@:68@*"1C:&%N;F5L(#T@)'1H:7,M/F-H86YN96Q!;&EA<R@D<&%R<V5D
M6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1C:&%N
M;F5L("X@)R\G("X@)'!A<G-E9%LG<&%C:V%G92==.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("1U<&%S<R`]("<G.PT*("`@("`@("!I
M9B`H:7-S970H)'!A<G-E9%LG=7-E<B==*2D@>PT*("`@("`@("`@("`@)'5P
M87-S(#T@)'!A<G-E9%LG=7-E<B==.PT*("`@("`@("`@("`@:68@*&ES<V5T
M*"1P87)S961;)W!A<W,G72DI('L-"B`@("`@("`@("`@("`@("`D=7!A<W,@
M+CT@)SHG("X@)'!A<G-E9%LG<&%S<R==.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)'5P87-S(#T@(B1U<&%S<T`B.PT*("`@("`@("!]#0H@("`@
M("`@("1R970@/2`G8VAA;FYE;#HO+R<@+B`D=7!A<W,@+B`D<&%R<V5D6R=C
M:&%N;F5L)UT@+B`G+R<@+B`D<&%R<V5D6R=P86-K86=E)UT[#0H@("`@("`@
M(&EF("AI<W-E="@D<&%R<V5D6R=V97)S:6]N)UTI('Q\(&ES<V5T*"1P87)S
M961;)W-T871E)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<M)R`N($`D
M<&%R<V5D6R=V97)S:6]N)UT@+B!`)'!A<G-E9%LG<W1A=&4G73L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG97AT96YS:6]N)UTI
M*2![#0H@("`@("`@("`@("`D<F5T("X]("<N)R`N("1P87)S961;)V5X=&5N
M<VEO;B==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%R<V5D
M6R=O<'1S)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<_)SL-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1P87)S961;)V]P=',G72!A<R`D;F%M92`]/B`D
M=F%L=64I('L-"B`@("`@("`@("`@("`@("`D<&%R<V5D6R=O<'1S)UU;)&YA
M;65=(#T@(B1N86UE/21V86QU92([#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D<F5T("X](&EM<&QO9&4H)R8G+"`D<&%R<V5D6R=O<'1S)UTI.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%R<V5D6R=G<F]U<"==
M*2D@>PT*("`@("`@("`@("`@)')E="`N/2`G(R<@+B`D<&%R<V5D6R=G<F]U
M<"==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-
M"GT-"@T*/SX-"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+U)%4U0N<&AP````````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#,U-#8Q(#$P-3$U-#,T,3,T(#`R,#4Q,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`T*+RHJ
M#0H@*B!014%27U)%4U0-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*
M("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@4D535"YP:'`L=B`Q+C(P(#(P,#8O,#,O,#(@,#,Z,#DZ,S$@
M<&%J;WEE($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B
M;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!&;W(@
M9&]W;FQO861I;F<@>&UL(&9I;&5S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!
M4BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+UA-3%!A<G-E<BYP:'`G.PT*
M#0HO*BH-"B`J($EN=&5L;&EG96YT;'D@<F5T<FEE=F4@9&%T82P@9F]L;&]W
M:6YG(&AY<&5R;&EN:W,@:68@;F5C97-S87)Y+"!A;F0@<F4M9&ER96-T:6YG
M#0H@*B!A<R!W96QL#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]2
M15-4#0I[#0H@("`@=F%R("1C;VYF:6<[#0H@("`@=F%R("1?;W!T:6]N<SL-
M"B`@("!F=6YC=&EO;B!014%27U)%4U0H)B1C;VYF:6<L("1O<'1I;VYS(#T@
M87)R87DH*2D-"B`@("![#0H@("`@("`@("1T:&ES+3YC;VYF:6<@/2`F)&-O
M;F9I9SL-"B`@("`@("`@)'1H:7,M/E]O<'1I;VYS(#T@)&]P=&EO;G,[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@4D535"!D871A+"!B
M=70@86QW87ES(')E=')I979E('1H92!L;V-A;"!C86-H92!I9B!I="!I<R!A
M=F%I;&%B;&4N#0H@("`@("H-"B`@("`@*B!4:&ES(&ES('5S969U;"!F;W(@
M96QE;65N=',@=&AA="!S:&]U;&0@;F5V97(@8VAA;F=E+"!S=6-H(&%S(&EN
M9F]R;6%T:6]N(&]N(&$@<&%R=&EC=6QA<@T*("`@("`J(')E;&5A<V4-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&9U;&P@55),('1O('1H:7,@<F5S;W5R8V4-
M"B`@("`@*B!`<&%R86T@87)R87E\9F%L<V4@8V]N=&5N=',@;V8@=&AE(&%C
M8V5P="UE;F-O9&EN9R!H96%D97(-"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@
M("`@:68@=')U92P@>&UL('=I;&P@8F4@<F5T=7)N960@87,@82!S=')I;F<L
M(&]T:&5R=VES92P@>&UL('=I;&P@8F4-"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@<&%R<V5D('5S:6YG(%!%05)?6$U,4&%R<V5R#0H@("`@("H@0')E
M='5R;B!S=')I;F=\87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R971R
M:65V94-A8VAE1FER<W0H)'5R;"P@)&%C8V5P="`](&9A;'-E+"`D9F]R8V5S
M=')I;F<@/2!F86QS92D-"B`@("![#0H@("`@("`@("1C86-H969I;&4@/2`D
M=&AI<RT^8V]N9FEG+3YG970H)V-A8VAE7V1I<B<I("X@1$E214-43U)97U-%
M4$%2051/4B`N#0H@("`@("`@("`@("!M9#4H)'5R;"D@+B`G<F5S="YC86-H
M969I;&4G.PT*("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1C86-H969I;&4I
M*2![#0H@("`@("`@("`@("!R971U<FX@=6YS97)I86QI>F4H:6UP;&]D92@G
M)RP@9FEL92@D8V%C:&5F:6QE*2DI.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^<F5T<FEE=F5$871A*"1U<FPL("1A8V-E<'0L("1F;W)C
M97-T<FEN9RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@
M82!R96UO=&4@4D535"!R97-O=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@
M9G5L;"!54DP@=&\@=&AI<R!R97-O=7)C90T*("`@("`J($!P87)A;2!A<G)A
M>7QF86QS92!C;VYT96YT<R!O9B!T:&4@86-C97!T+65N8V]D:6YG(&AE861E
M<@T*("`@("`J($!P87)A;2!B;V]L96%N("`@("!I9B!T<G5E+"!X;6P@=VEL
M;"!B92!R971U<FYE9"!A<R!A('-T<FEN9RP@;W1H97)W:7-E+"!X;6P@=VEL
M;"!B90T*("`@("`J("`@("`@("`@("`@("`@("`@("!P87)S960@=7-I;F<@
M4$5!4E]834Q087)S97(-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQA<G)A>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(')E=')I979E1&%T82@D=7)L+"`D86-C
M97!T(#T@9F%L<V4L("1F;W)C97-T<FEN9R`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@)&-A8VAE260@/2`D=&AI<RT^9V5T0V%C:&5)9"@D=7)L*3L-"B`@
M("`@("`@:68@*"1R970@/2`D=&AI<RT^=7-E3&]C86Q#86-H92@D=7)L+"`D
M8V%C:&5)9"DI('L-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=O9F9L
M:6YE)UTI*2![#0H@("`@("`@("`@("`D=')I961D;W=N;&]A9"`]('1R=64[
M#0H@("`@("`@("`@("`D9FEL92`]("1T:&ES+3YD;W=N;&]A9$AT='`H)'5R
M;"P@)&-A8VAE260@/R`D8V%C:&5)9%LG;&%S=$-H86YG92==(#H@9F%L<V4L
M("1A8V-E<'0I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1R
M:65D9&]W;FQO860@/2!F86QS93L-"B`@("`@("`@("`@("1F:6QE(#T@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&9I
M;&4I*2![#0H@("`@("`@("`@("!I9B`H)&9I;&4M/F=E=$-O9&4H*2`]/2`M
M.3(W-BD@>PT*("`@("`@("`@("`@("`@("1T<FEE9&1O=VYL;V%D(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@)&9I;&4@/2!F86QS93L@+R\@=7-E(&QO
M8V%L(&-O<'D@:68@879A:6QA8FQE(&]N('-O8VME="!C;VYN96-T(&5R<F]R
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`D9FEL93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(21F:6QE*2![#0H@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/F=E=$-A
M8VAE*"1U<FPI.PT*("`@("`@("`@("`@:68@*"%014%2.CII<T5R<F]R*"1R
M970I("8F("1T<FEE9&1O=VYL;V%D*2![#0H@("`@("`@("`@("`@("`@+R\@
M<F5S970@=&AE(&%G92!O9B!T:&4@8V%C:&4@:68@=&AE('-E<G9E<B!S87ES
M(&ET('=A<R!U;FUO9&EF:65D#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-A
M=F5#86-H92@D=7)L+"`D<F5T+"!N=6QL+"!T<G5E+"`D8V%C:&5)9"D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-?87)R87DH)&9I;&4I*2![#0H@("`@("`@
M("`@("`D:&5A9&5R<R`]("1F:6QE6S)=.PT*("`@("`@("`@("`@)&QA<W1M
M;V1I9FEE9"`]("1F:6QE6S%=.PT*("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL95LP73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C;VYT
M96YT(#T@)&9I;&4[#0H@("`@("`@("`@("`D;&%S=&UO9&EF:65D(#T@9F%L
M<V4[#0H@("`@("`@("`@("`D:&5A9&5R<R`](&%R<F%Y*"D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1F;W)C97-T<FEN9RD@>PT*("`@("`@("`@("`@
M)'1H:7,M/G-A=F5#86-H92@D=7)L+"`D8V]N=&5N="P@)&QA<W1M;V1I9FEE
M9"P@9F%L<V4L("1C86-H94ED*3L-"B`@("`@("`@("`@(')E='5R;B`D8V]N
M=&5N=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&AE861E<G-;
M)V-O;G1E;G0M='EP92==*2D@>PT*("`@("`@("`@("`@<W=I=&-H("@D:&5A
M9&5R<ULG8V]N=&5N="UT>7!E)UTI('L-"B`@("`@("`@("`@("`@("!C87-E
M("=T97AT+WAM;"<@.@T*("`@("`@("`@("`@("`@(&-A<V4@)V%P<&QI8V%T
M:6]N+WAM;"<@.@T*("`@("`@("`@("`@("`@("`@("`D<&%R<V5R(#T@;F5W
M(%!%05)?6$U,4&%R<V5R.PT*("`@("`@("`@("`@("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`@("`@("`@("1E<G(@/2`D<&%R<V5R+3YP87)S92@D8V]N=&5N="D[
M#0H@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R
M<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR
M86ES945R<F]R*"=);G9A;&ED('AM;"!D;W=N;&]A9&5D(&9R;VT@(B<@+B`D
M=7)L("X@)R(Z("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G(M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D<&%R<V5R+3YG971$871A
M*"D[#0H@("`@("`@("`@("`@("`@8V%S92`G=&5X="]H=&UL)R`Z#0H@("`@
M("`@("`@("`@("`@9&5F875L="`Z#0H@("`@("`@("`@("`@("`@("`@("\O
M('5S92!I="!A<R!A('-T<FEN9PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@+R\@87-S=6UE(%A-3`T*("`@("`@("`@
M("`@)'!A<G-E<B`](&YE=R!014%27UA-3%!A<G-E<CL-"B`@("`@("`@("`@
M("1P87)S97(M/G!A<G-E*"1C;VYT96YT*3L-"B`@("`@("`@("`@("1C;VYT
M96YT(#T@)'!A<G-E<BT^9V5T1&%T82@I.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YS879E0V%C:&4H)'5R;"P@)&-O;G1E;G0L("1L87-T;6]D:69I
M960L(&9A;'-E+"`D8V%C:&5)9"D[#0H@("`@("`@(')E='5R;B`D8V]N=&5N
M=#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!U<V5,;V-A;$-A8VAE*"1U<FPL
M("1C86-H96ED(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D8V%C:&5I
M9"`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&-A8VAE:61F:6QE(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D:7(G*2`N($1)4D5#5$]265]315!!
M4D%43U(@+@T*("`@("`@("`@("`@("`@(&UD-2@D=7)L*2`N("=R97-T+F-A
M8VAE:60G.PT*("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D8V%C:&5I
M9&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)&-A8VAE:60@/2!U;G-E<FEA
M;&EZ92AI;7!L;V1E*"<G+"!F:6QE*"1C86-H96ED9FEL92DI*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1C86-H971T
M;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G8V%C:&5?='1L)RD[#0H@("`@("`@
M("\O($EF(&-A8VAE(&ES(&YE=V5R('1H86X@)&-A8VAE='1L('-E8V]N9',L
M('=E('5S92!T:&4@8V%C:&4A#0H@("`@("`@(&EF("AT:6UE*"D@+2`D8V%C
M:&5I9%LG86=E)UT@/"`D8V%C:&5T=&PI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^9V5T0V%C:&4H)'5R;"D[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$-A8VAE
M260H)'5R;"D-"B`@("![#0H@("`@("`@("1C86-H96ED9FEL92`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X-"B`@("`@("`@("`@(&UD-2@D=7)L*2`N("=R97-T+F-A8VAE:60G
M.PT*("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1C86-H96ED9FEL92DI('L-
M"B`@("`@("`@("`@("1R970@/2!U;G-E<FEA;&EZ92AI;7!L;V1E*"<G+"!F
M:6QE*"1C86-H96ED9FEL92DI*3L-"B`@("`@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T0V%C:&4H
M)'5R;"D-"B`@("![#0H@("`@("`@("1C86-H969I;&4@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)V-A8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N
M#0H@("`@("`@("`@("!M9#4H)'5R;"D@+B`G<F5S="YC86-H969I;&4G.PT*
M("`@("`@("!I9B`H0&9I;&5?97AI<W1S*"1C86-H969I;&4I*2![#0H@("`@
M("`@("`@("!R971U<FX@=6YS97)I86QI>F4H:6UP;&]D92@G)RP@9FEL92@D
M8V%C:&5F:6QE*2DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO(&-A8VAE9"!C;VYT96YT(&%V
M86EL86)L92!F;W(@(B<@+B`D=7)L("X@)R(G*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@9G5L;"!54DP@
M=&\@4D535"!R97-O=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@;W)I9VEN
M86P@8V]N=&5N=',@;V8@=&AE(%)%4U0@<F5S;W5R8V4-"B`@("`@*B!`<&%R
M86T@87)R87D@($A45%`@3&%S="U-;V1I9FEE9"!A;F0@151A9R!H96%D97)S
M#0H@("`@("H@0'!A<F%M(&)O;VP@("!I9B!T<G5E+"!T:&5N('1H92!C86-H
M92!I9"!F:6QE('-H;W5L9"!B92!R96=E;F5R871E9"!T;PT*("`@("`J("`@
M("`@("`@("`@("`@=')I9V=E<B!A(&YE=R!T:6UE+71O+6QI=F4@=F%L=64-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S879E0V%C:&4H)'5R;"P@)&-O;G1E
M;G1S+"`D;&%S=&UO9&EF:65D+"`D;F]C:&%N9V4@/2!F86QS92P@)&-A8VAE
M:60@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)&-A8VAE:61F:6QE(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=C86-H95]D:7(G*2`N($1)4D5#5$]265]315!!
M4D%43U(@+@T*("`@("`@("`@("`@;60U*"1U<FPI("X@)W)E<W0N8V%C:&5I
M9"<[#0H@("`@("`@("1C86-H969I;&4@/2`D=&AI<RT^8V]N9FEG+3YG970H
M)V-A8VAE7V1I<B<I("X@1$E214-43U)97U-%4$%2051/4B`N#0H@("`@("`@
M("`@("!M9#4H)'5R;"D@+B`G<F5S="YC86-H969I;&4G.PT*("`@("`@("!I
M9B`H)&-A8VAE:60@/3T](&YU;&P@)B8@)&YO8VAA;F=E*2![#0H@("`@("`@
M("`@("`D8V%C:&5I9"`]('5N<V5R:6%L:7IE*&EM<&QO9&4H)R<L(&9I;&4H
M)&-A8VAE:61F:6QE*2DI.PT*("`@("`@("!]#0H-"B`@("`@("`@)&9P(#T@
M0&9O<&5N*"1C86-H96ED9FEL92P@)W=B)RD[#0H@("`@("`@(&EF("@A)&9P
M*2![#0H@("`@("`@("`@("`D8V%C:&5?9&ER(#T@)'1H:7,M/F-O;F9I9RT^
M9V5T*"=C86-H95]D:7(G*3L-"B`@("`@("`@("`@(&EF("@A:7-?9&ER*"1C
M86-H95]D:7(I*2![#0H@("`@("`@("`@("`@("`@4WES=&5M.CIM:V1I<BAA
M<G)A>2@G+7`G+"`D8V%C:&5?9&ER*2D[#0H@("`@("`@("`@("`@("`@)&9P
M(#T@0&9O<&5N*"1C86-H96ED9FEL92P@)W=B)RD[#0H@("`@("`@("`@("`@
M("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1N;V-H86YG92D@>PT*("`@
M("`@("`@("`@9G=R:71E*"1F<"P@<V5R:6%L:7IE*&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=A9V4G("`@("`@("`]/B!T:6UE*"DL#0H@("`@("`@("`@
M("`@("`@)VQA<W1#:&%N9V4G(#T^("1C86-H96ED6R=L87-T0VAA;F=E)UTL
M#0H@("`@("`@("`@("`@("`@*2DI.PT*("`@("`@("`@("`@9F-L;W-E*"1F
M<"D[#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(&9W<FET92@D9G`L('-E<FEA;&EZ92AA<G)A>2@-
M"B`@("`@("`@("`@("`@("`G86=E)R`@("`@("`@/3X@=&EM92@I+`T*("`@
M("`@("`@("`@("`@("=L87-T0VAA;F=E)R`]/B`D;&%S=&UO9&EF:65D+`T*
M("`@("`@("`@("`@("`@("DI*3L-"B`@("`@("`@?0T*("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("`@("`@)&9P(#T@0&9O<&5N*"1C86-H969I;&4L("=W
M8B<I.PT*("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@0'5N;&EN
M:R@D8V%C:&5I9&9I;&4I.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&9W<FET92@D9G`L('-E<FEA;&EZ92@D8V]N
M=&5N=',I*3L-"B`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($5F9FEC:65N=&QY
M($1O=VYL;V%D(&$@9FEL92!T:')O=6=H($A45%`N("!2971U<FYS(&1O=VYL
M;V%D960@9FEL92!A<R!A('-T<FEN9R!I;BUM96UO<GD-"B`@("`@*B!4:&ES
M(&ES(&)E<W0@=7-E9"!F;W(@<VUA;&P@9FEL97,-"B`@("`@*@T*("`@("`J
M($EF(&%N($A45%`@<')O>'D@:&%S(&)E96X@8V]N9FEG=7)E9"`H:'1T<%]P
M<F]X>2!014%27T-O;F9I9PT*("`@("`J('-E='1I;F<I+"!T:&4@<')O>'D@
M=VEL;"!B92!U<V5D+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@
M)'5R;"`@("`@("!T:&4@55),('1O(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'-A=F5?9&ER("!D:7)E8W1O<GD@=&\@<V%V92!F:6QE(&EN
M#0H@("`@("H@0'!A<F%M(&9A;'-E?'-T<FEN9WQA<G)A>2`D;&%S=&UO9&EF
M:65D(&AE861E<B!V86QU97,@=&\@8VAE8VL@86=A:6YS="!F;W(@8V%C:&EN
M9PT*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@=7-E(&9A;'-E
M('1O(')E='5R;B!T:&4@:&5A9&5R('9A;'5E<R!F<F]M('1H:7,@9&]W;FQO
M860-"B`@("`@*B!`<&%R86T@9F%L<V5\87)R87D@)&%C8V5P="!!8V-E<'0@
M:&5A9&5R<R!T;R!S96YD#0H@("`@("H@0')E='5R;B!S=')I;F=\87)R87D@
M(%)E='5R;G,@=&AE(&-O;G1E;G1S(&]F('1H92!D;W=N;&]A9&5D(&9I;&4@
M;W(@82!014%2#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&5R<F]R
M(&]N(&9A:6QU<F4N("!)9B!T:&4@97)R;W(@:7,@8V%U<V5D(&)Y#0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@('-O8VME="UR96QA=&5D(&5R<F]R
M<RP@=&AE(&5R<F]R(&]B:F5C="!W:6QL#0H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@(&AA=F4@=&AE(&9S;V-K;W!E;B!E<G)O<B!C;V1E(&%V86EL
M86)L92!T:')O=6=H#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&=E
M=$-O9&4H*2X@($EF(&-A8VAI;F<@:7,@<F5Q=65S=&5D+"!T:&5N(')E='5R
M;B!T:&4@:&5A9&5R#0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('9A
M;'5E<RX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9&]W;FQO861(='1P*"1U<FPL("1L87-T;6]D:69I
M960@/2!N=6QL+"`D86-C97!T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D
M:6YF;R`]('!A<G-E7W5R;"@D=7)L*3L-"B`@("`@("`@:68@*"%I<W-E="@D
M:6YF;ULG<V-H96UE)UTI('Q\("%I;E]A<G)A>2@D:6YF;ULG<V-H96UE)UTL
M(&%R<F%Y*"=H='1P)RP@)VAT='!S)RDI*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V%N;F]T(&1O=VYL;V%D(&YO;BUH='1P
M(%523"`B)R`N("1U<FP@+B`G(B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A:7-S970H)&EN9F];)VAO<W0G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=#86YN;W0@9&]W;FQO860@9G)O;2!N;VXM
M55),("(G("X@)'5R;"`N("<B)RD[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D:&]S="`]("1I;F9O6R=H;W-T)UT[#0H@("`@("`@("`@("!I
M9B`H(6%R<F%Y7VME>5]E>&ES=',H)W!O<G0G+"`D:6YF;RDI('L-"B`@("`@
M("`@("`@("`@("`D:6YF;ULG<&]R="==(#T@;G5L;#L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X:7-T<R@G<&%T:"<L
M("1I;F9O*2D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=P871H)UT@/2!N
M=6QL.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!O<G0@/2`D:6YF
M;ULG<&]R="==.PT*("`@("`@("`@("`@)'!A=&@@/2`D:6YF;ULG<&%T:"==
M.PT*("`@("`@("!]#0H@("`@("`@("1P<F]X>5]H;W-T(#T@)'!R;WAY7W!O
M<G0@/2`D<')O>'E?=7-E<B`]("1P<F]X>5]P87-S(#T@)R<[#0H@("`@("`@
M(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)VAT='!?<')O>'DG*28F(`T*("`@
M("`@("`@("`@("`D<')O>'D@/2!P87)S95]U<FPH)'1H:7,M/F-O;F9I9RT^
M9V5T*"=H='1P7W!R;WAY)RDI*2![#0H@("`@("`@("`@("`D<')O>'E?:&]S
M="`]($`D<')O>'E;)VAO<W0G73L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M<')O>'E;)W-C:&5M92==*2`F)B`D<')O>'E;)W-C:&5M92==(#T]("=H='1P
M<R<I('L-"B`@("`@("`@("`@("`@("`D<')O>'E?:&]S="`]("=S<VPZ+R\G
M("X@)'!R;WAY7VAO<W0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M<')O>'E?<&]R="`]($`D<')O>'E;)W!O<G0G73L-"B`@("`@("`@("`@("1P
M<F]X>5]U<V5R(#T@0"1P<F]X>5LG=7-E<B==.PT*("`@("`@("`@("`@)'!R
M;WAY7W!A<W,@/2!`)'!R;WAY6R=P87-S)UT[#0H-"B`@("`@("`@("`@(&EF
M("@D<')O>'E?<&]R="`]/2`G)RD@>PT*("`@("`@("`@("`@("`@("1P<F]X
M>5]P;W)T(#T@.#`X,#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H96UP='DH)'!O<G0I*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&EN9F];)W-C:&5M92==*2`F)B`D:6YF;ULG<V-H96UE)UT@/3T@)VAT
M='!S)RD@>PT*("`@("`@("`@("`@("`@("1P;W)T(#T@-#0S.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&]R="`](#@P.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@($EF("AI<W-E="@D
M<')O>'E;)VAO<W0G72DI('L-"B`@("`@("`@("`@("1R97%U97-T(#T@(D=%
M5"`D=7)L($A45%`O,2XQ7')<;B([#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D<F5Q=65S="`](")'150@)'!A=&@@2%144"\Q+C%<<EQN(CL-
M"B`@("`@("`@?0T*#0H@("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`G)SL-
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1L87-T;6]D:69I960I*2![#0H@("`@
M("`@("`@("!I9B`H:7-S970H)&QA<W1M;V1I9FEE9%LG3&%S="U-;V1I9FEE
M9"==*2D@>PT*("`@("`@("`@("`@("`@("1I9FUO9&EF:65D<VEN8V4@/2`G
M268M36]D:69I960M4VEN8V4Z("<@+B`D;&%S=&UO9&EF:65D6R=,87-T+4UO
M9&EF:65D)UT@+B`B7')<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&QA<W1M;V1I9FEE9%LG151A9R==*2D@>PT*("`@("`@
M("`@("`@("`@("1I9FUO9&EF:65D<VEN8V4@+CT@(DEF+4YO;F4M36%T8V@Z
M("1L87-T;6]D:69I961;151A9UU<<EQN(CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1I9FUO9&EF:65D<VEN8V4@
M/2`H)&QA<W1M;V1I9FEE9"`_("))9BU-;V1I9FEE9"U3:6YC93H@)&QA<W1M
M;V1I9FEE9%QR7&XB(#H@)R<I.PT*("`@("`@("!]#0H@("`@("`@("1R97%U
M97-T("X](")(;W-T.B`D:&]S=#HD<&]R=%QR7&XB("X@)&EF;6]D:69I961S
M:6YC92`N#0H@("`@("`@("`@("`B57-E<BU!9V5N=#H@4$5!4B\Q+C0N.2]0
M2%`O(B`N(%!(4%]615)324].("X@(EQR7&XB.PT*("`@("`@("`D=7-E<FYA
M;64@/2`D=&AI<RT^8V]N9FEG+3YG970H)W5S97)N86UE)RD[#0H@("`@("`@
M("1P87-S=V]R9"`]("1T:&ES+3YC;VYF:6<M/F=E="@G<&%S<W=O<F0G*3L-
M"B`@("`@("`@:68@*"1U<V5R;F%M92`F)B`D<&%S<W=O<F0I('L-"B`@("`@
M("`@("`@("1T;7`@/2!B87-E-C1?96YC;V1E*"(D=7-E<FYA;64Z)'!A<W-W
M;W)D(BD[#0H@("`@("`@("`@("`D<F5Q=65S="`N/2`B075T:&]R:7IA=&EO
M;CH@0F%S:6,@)'1M<%QR7&XB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M<')O>'E?:&]S="`A/2`G)R`F)B`D<')O>'E?=7-E<B`A/2`G)RD@>PT*("`@
M("`@("`@("`@)')E<75E<W0@+CT@)U!R;WAY+4%U=&AO<FEZ871I;VXZ($)A
M<VEC("<@+@T*("`@("`@("`@("`@("`@(&)A<V4V-%]E;F-O9&4H)'!R;WAY
M7W5S97(@+B`G.B<@+B`D<')O>'E?<&%S<RD@+B`B7')<;B([#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1A8V-E<'0I('L-"B`@("`@("`@("`@("1R97%U
M97-T("X]("=!8V-E<'0Z("<@+B!I;7!L;V1E*"<L("<L("1A8V-E<'0I("X@
M(EQR7&XB.PT*("`@("`@("!]#0H@("`@("`@("1R97%U97-T("X](")#;VYN
M96-T:6]N.B!C;&]S95QR7&XB.PT*("`@("`@("`D<F5Q=65S="`N/2`B7')<
M;B([#0H@("`@("`@(&EF("@D<')O>'E?:&]S="`A/2`G)RD@>PT*("`@("`@
M("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D<')O>'E?:&]S="P@)'!R;WAY7W!O
M<G0L("1E<G)N;RP@)&5R<G-T<BP@,34I.PT*("`@("`@("`@("`@:68@*"$D
M9G`I('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@B0V]N;F5C=&EO;B!T;R!@)'!R;WAY7VAO<W0Z)'!R;WAY7W!O<G0G(&9A
M:6QE9#H@)&5R<G-T<B(L#0H@("`@("`@("`@("`@("`@("`@("TY,C<V*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D:6YF;ULG<V-H96UE)UTI("8F("1I;F9O6R=S8VAE;64G
M72`]/2`G:'1T<',G*2![#0H@("`@("`@("`@("`@("`@)&AO<W0@/2`G<W-L
M.B\O)R`N("1H;W-T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&9P
M(#T@0&9S;V-K;W!E;B@D:&]S="P@)'!O<G0L("1E<G)N;RP@)&5R<G-T<BD[
M#0H@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*")#;VYN96-T:6]N('1O(&`D:&]S=#HD
M<&]R="<@9F%I;&5D.B`D97)R<W1R(BP@)&5R<FYO*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!F=W)I=&4H)&9P+"`D<F5Q=65S="D[
M#0H@("`@("`@("1H96%D97)S(#T@87)R87DH*3L-"B`@("`@("`@=VAI;&4@
M*'1R:6TH)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2D@>PT*("`@("`@("`@
M("`@:68@*'!R96=?;6%T8V@H)R]>*%M>.ETK*3I<<RLH+BHI7',J)"\G+"`D
M;&EN92P@)&UA=&-H97,I*2![#0H@("`@("`@("`@("`@("`@)&AE861E<G-;
M<W1R=&]L;W=E<B@D;6%T8VAE<ULQ72E=(#T@=')I;2@D;6%T8VAE<ULR72D[
M#0H@("`@("`@("`@("!](&5L<V5I9B`H<')E9U]M871C:"@G?%Y(5%10+S$N
M6S`Q72`H6S`M.5U[,WTI('PG+"`D;&EN92P@)&UA=&-H97,I*2![#0H@("`@
M("`@("`@("`@("`@:68@*"1M871C:&5S6S%=(#T](#,P-"`F)B`H)&QA<W1M
M;V1I9FEE9"!\?"`H)&QA<W1M;V1I9FEE9"`]/3T@9F%L<V4I*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@D;6%T8VAE<ULQ72`A/2`R,#`I
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H(D9I;&4@:'1T<#HO+R1H;W-T.B1P;W)T)'!A=&@@;F]T('9A;&ED("AR
M96-E:79E9#H@)&QI;F4I(BP@*&EN="D@)&UA=&-H97-;,5TI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&AE861E<G-;)V-O;G1E;G0M;&5N9W1H)UTI*2![#0H@
M("`@("`@("`@("`D;&5N9W1H(#T@)&AE861E<G-;)V-O;G1E;G0M;&5N9W1H
M)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;&5N9W1H(#T@
M+3$[#0H@("`@("`@('T-"B`@("`@("`@)&1A=&$@/2`G)SL-"B`@("`@("`@
M=VAI;&4@*"1C:'5N:R`]($!F<F5A9"@D9G`L(#@Q.3(I*2![#0H@("`@("`@
M("`@("`D9&%T82`N/2`D8VAU;FL[#0H@("`@("`@('T-"B`@("`@("`@9F-L
M;W-E*"1F<"D[#0H@("`@("`@(&EF("@D;&%S=&UO9&EF:65D(#T]/2!F86QS
M92!\?"`D;&%S=&UO9&EF:65D*2![#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&AE861E<G-;)V5T86<G72DI('L-"B`@("`@("`@("`@("`@("`D;&%S=&UO
M9&EF:65D(#T@87)R87DH)T5486<G(#T^("1H96%D97)S6R=E=&%G)UTI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1H96%D97)S
M6R=L87-T+6UO9&EF:65D)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1L87-T;6]D:69I960I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1L87-T;6]D:69I961;)TQA<W0M36]D:69I960G72`]("1H96%D97)S6R=L
M87-T+6UO9&EF:65D)UT[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9"`]("1H96%D97)S6R=L
M87-T+6UO9&EF:65D)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1D871A+"`D;&%S=&UO
M9&EF:65D+"`D:&5A9&5R<RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1D871A.PT*("`@('T-"GT-"C\^#0H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4G5N5&5S
M="YP:'``````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,S0U-C`@,3`U,34T,S0Q,S0@,#(Q,S,V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?4G5N
M5&5S=`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O
M;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED
M.B!2=6Y497-T+G!H<"QV(#$N,C`@,C`P-B\P,B\P,R`P,CHP.#HQ,2!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,RXS#0H@*B\-"@T*+RHJ#0H@*B!F;W(@97)R;W(@
M:&%N9&QI;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0IR97%U
M:7)E7V]N8V4@)U!%05(O0V]N9FEG+G!H<"<[#0H-"F1E9FEN92@G1$5404E,
M140G+"`Q*3L-"G!U=&5N=B@B4$A07U!%05)?4E5.5$535%,],2(I.PT*#0HO
M*BH-"B`J(%-I;7!L:69I960@=F5R<VEO;B!O9B!02%`G<R!T97-T('-U:71E
M#0H@*@T*("H@5')Y(&ET('=I=&@Z#0H@*@T*("H@)"!P:'`@+7(@)VEN8VQU
M9&4@(BXN+U!%05(O4G5N5&5S="YP:'`B.R`D=#UN97<@4$5!4E]2=6Y497-T
M.R`D;STD="T^<G5N*"(N+W!E87)?<WES=&5M+G!H<'0B*3MP<FEN=%]R*"1O
M*3LG#0H@*@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I
M9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XS+C,-"B`J+PT*8VQA<W,@4$5!4E]2
M=6Y497-T#0I[#0H@("`@=F%R("1?;&]G9V5R.PT*("`@('9A<B`D7V]P=&EO
M;G,[#0H-"B`@("`O*BH-"B`@("`@*B!!;B!O8FIE8W0@=&AA="!S=7!P;W)T
M<R!T:&4@4$5!4E]#;VUM;VXM/FQO9R@I('-I9VYA='5R92P@;W(@;G5L;`T*
M("`@("`J($!P87)A;2!014%27T-O;6UO;GQN=6QL#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@4$5!4E]2=6Y497-T*"1L;V=G97(@/2!N=6QL+"`D;W!T:6]N
M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("!I9B`H:7-?;G5L;"@D;&]G
M9V5R*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-O;6UO
M;BYP:'`G.PT*("`@("`@("`@("`@)&QO9V=E<B`](&YE=R!014%27T-O;6UO
M;CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("1L;V=G
M97([#0H@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]("1O<'1I;VYS.PT*("`@
M('T-"@T*("`@("\O#0H@("`@+R\@(%)U;B!A;B!I;F1I=FED=6%L('1E<W0@
M8V%S92X-"B`@("`O+PT*#0H@("`@9G5N8W1I;VX@<G5N*"1F:6QE+"`D:6YI
M7W-E='1I;F=S(#T@)R<I#0H@("`@>PT*("`@("`@("`D8W=D(#T@9V5T8W=D
M*"D[#0H@("`@("`@("1C;VYF(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH
M*3L-"B`@("`@("`@)'!H<"`]("1C;VYF+3YG970H)W!H<%]B:6XG*3L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG<&AP=6YI="==*2D@
M>PT*("`@("`@("`@("`@)&-M9"`]("(D<&AP)&EN:5]S971T:6YG<R`M9B`D
M9FEL92([#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]L;V=G97(I
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]L;V=G97(M/FQO9R@R+"`G
M4G5N;FEN9R!C;VUM86YD("(G("X@)&-M9"`N("<B)RD[#0H@("`@("`@("`@
M("!]#0H@("`@#0H@("`@("`@("`@("`D<V%V961I<B`](&=E=&-W9"@I.R`O
M+R!I;B!C87-E('1H92!T97-T(&UO=F5S('5S(&%R;W5N9`T*("`@("`@("`@
M("`@8VAD:7(H9&ER;F%M92@D9FEL92DI.PT*("`@("`@("`@("`@96-H;R!@
M)&-M9&`[#0H@("`@("`@("`@("!C:&1I<B@D<V%V961I<BD[#0H@("`@("`@
M("`@("!R971U<FX@)U!!4U-%1"<[("\O('=E(&AA=F4@;F\@=V%Y(&]F(&MN
M;W=I;F<@=&AI<R!I;F9O<FUA=&EO;B!S;R!A<W-U;64@<&%S<VEN9PT*("`@
M("`@("!]#0H@("`@("`@("\O=F%R7V1U;7`H)'!H<"D[97AI=#L-"B`@("`@
M("`@9VQO8F%L("1L;V=?9F]R;6%T+"`D:6YF;U]P87)A;7,L("1I;FE?;W9E
M<G=R:71E<SL-"@T*("`@("`@("`D:6YF;U]P87)A;7,@/2`G)SL-"B`@("`@
M("`@)&QO9U]F;W)M870@/2`G3$5/1"<[#0H-"B`@("`@("`@+R\@3&]A9"!T
M:&4@<V5C=&EO;G,@;V8@=&AE('1E<W0@9FEL92X-"B`@("`@("`@)'-E8W1I
M;VY?=&5X="`](&%R<F%Y*`T*("`@("`@("`@("`@)U1%4U0G("`@(#T^("<H
M=6YN86UE9"!T97-T*2<L#0H@("`@("`@("`@("`G4TM)4$E&)R`@/3X@)R<L
M#0H@("`@("`@("`@("`G1T54)R`@("`@/3X@)R<L#0H@("`@("`@("`@("`G
M05)'4R<@("`@/3X@)R<L#0H@("`@("`@("`@("`G0TQ%04XG("`@/3X@)R<L
M#0H@("`@("`@("D[#0H-"B`@("`@("`@)&9I;&4@/2!R96%L<&%T:"@D9FEL
M92D[#0H@("`@("`@(&EF("@A:7-?9FEL92@D9FEL92D@?'P@(21F<"`](&9O
M<&5N*"1F:6QE+"`B<B(I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@B0V%N;F]T(&]P96X@=&5S="!F:6QE.B`D9FEL92(I.PT*
M("`@("`@("!]#0H-"B`@("`@("`@)'-E8W1I;VX@/2`G)SL-"B`@("`@("`@
M=VAI;&4@*"%F96]F*"1F<"DI('L-"B`@("`@("`@("`@("1L:6YE(#T@9F=E
M=',H)&9P*3L-"@T*("`@("`@("`@("`@+R\@36%T8V@@=&AE(&)E9VEN;FEN
M9R!O9B!A('-E8W1I;VXN#0H@("`@("`@("`@("!I9B`H97)E9R@G7BTM*%M!
M+5I=*RDM+2<L)&QI;F4L)'(I*2![#0H@("`@("`@("`@("`@("`@)'-E8W1I
M;VX@/2`D<ELQ73L-"B`@("`@("`@("`@("`@("`D<V5C=&EO;E]T97AT6R1S
M96-T:6]N72`]("<G.PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?2!E;'-E:68@*&5M<'1Y*"1S96-T:6]N*2D@>PT*("`@("`@
M("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"));G9A;&ED('-E8W1I;VYS(&9O<FUA=',@
M:6X@=&5S="!F:6QE.B`D9FEL92(I.PT*"0D)?0T*#0H@("`@("`@("`@("`O
M+R!!9&0@=&\@=&AE('-E8W1I;VX@=&5X="X-"B`@("`@("`@("`@("1S96-T
M:6]N7W1E>'1;)'-E8W1I;VY=("X]("1L:6YE.PT*("`@("`@("!]#0H@("`@
M("`@(&9C;&]S92@D9G`I.PT*#0H@("`@("`@("1S:&]R=&YA;64@/2!S=')?
M<F5P;&%C92@D8W=D("X@1$E214-43U)97U-%4$%2051/4BP@)R<L("1F:6QE
M*3L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)W-I;7!L
M92==*2D@>PT*("`@("`@("`@("`@)'1E<W1E9"`]('1R:6TH)'-E8W1I;VY?
M=&5X=%LG5$535"==*2`N(");)'-H;W)T;F%M95TB.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)'1E<W1E9"`]('1R:6TH)'-E8W1I;VY?=&5X
M=%LG5$535"==*2`N("<@)SL-"B`@("`@("`@?0T*#0H@("`@("`@("1T;7`@
M/2!R96%L<&%T:"AD:7)N86UE*"1F:6QE*2D[#0H@("`@("`@("1T;7!?<VMI
M<&EF(#T@)'1M<"`N('5N:7%I9"@G+W!H<'0N)RD[#0H@("`@("`@("1T;7!?
M9FEL92`@(#T@97)E9U]R97!L86-E*"=<+G!H<'0D)RPG+G!H<"<L)&9I;&4I
M.PT*("`@("`@("`D=&UP7W!O<W0@("`]("1T;7`@+B!U;FEQ:60H)R]P:'!T
M+B<I.PT*#0H@("`@("`@($!U;FQI;FLH)'1M<%]S:VEP:68I.PT*("`@("`@
M("!`=6YL:6YK*"1T;7!?9FEL92D[#0H@("`@("`@($!U;FQI;FLH)'1M<%]P
M;W-T*3L-"@T*("`@("`@("`O+R!U;FQI;FL@;VQD('1E<W0@<F5S=6QT<PT*
M("`@("`@("!`=6YL:6YK*&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYD:69F
M)RPD9FEL92DI.PT*("`@("`@("!`=6YL:6YK*&5R96=?<F5P;&%C92@G7"YP
M:'!T)"<L)RYL;V<G+"1F:6QE*2D[#0H@("`@("`@($!U;FQI;FLH97)E9U]R
M97!L86-E*"=<+G!H<'0D)RPG+F5X<"<L)&9I;&4I*3L-"B`@("`@("`@0'5N
M;&EN:RAE<F5G7W)E<&QA8V4H)UPN<&AP="0G+"<N;W5T)RPD9FEL92DI.PT*
M#0H@("`@("`@("\O($-H96-K(&EF('1E<W0@<VAO=6QD(&)E('-K:7!P960N
M#0H@("`@("`@("1I;F9O(#T@)R<[#0H@("`@("`@("1W87)N(#T@9F%L<V4[
M#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=32TE0248G+"`D<V5C
M=&EO;E]T97AT*2D@>PT*("`@("`@("`@("`@:68@*'1R:6TH)'-E8W1I;VY?
M=&5X=%LG4TM)4$E&)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-A
M=F5?=&5X="@D=&UP7W-K:7!I9BP@)'-E8W1I;VY?=&5X=%LG4TM)4$E&)UTI
M.PT*("`@("`@("`@("`@("`@("\O)&5X=')A(#T@<W5B<W1R*%!(4%]/4RP@
M,"P@,RD@(3T](")724XB(#\-"B`@("`@("`@("`@("`@("`O+R`@("`B=6YS
M970@4D5154535%]-151(3T0[(CH@(B([#0H-"B`@("`@("`@("`@("`@("`O
M+R1O=71P=70@/2!@)&5X=')A("1P:'`@)&EN9F]?<&%R86US("UF("1T;7!?
M<VMI<&EF8#L-"B`@("`@("`@("`@("`@("`D;W5T<'5T(#T@8"1P:'`@)&EN
M9F]?<&%R86US("UF("1T;7!?<VMI<&EF8#L-"B`@("`@("`@("`@("`@("!U
M;FQI;FLH)'1M<%]S:VEP:68I.PT*("`@("`@("`@("`@("`@(&EF("AE<F5G
M:2@B7G-K:7`B+"!T<FEM*"1O=71P=70I*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<VMI<')E87-O;B`](")32TE0("1T97-T960B.PT*("`@("`@("`@
M("`@("`@("`@("`D<F5A<V]N(#T@*&5R96=I*")><VMI<%M;.G-P86-E.EU=
M*B@N*RE<)"(L('1R:6TH)&]U='!U="DI*2`_(&5R96=I7W)E<&QA8V4H(EYS
M:VEP6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@(EQ<,2(L('1R:6TH)&]U='!U="DI
M(#H@1D%,4T4[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<F5A<V]N*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<VMI<')E87-O;B`N/2`B("AR
M96%S;VXZ("1R96%S;VXI(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M<75I970G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M;&]G9V5R+3YL;V<H,"P@)'-K:7!R96%S;VXI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;VQD7W!H
M<"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P:'`@/2`D;VQD7W!H
M<#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)U-+25!0140G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H97)E9VDH(EYI;F9O(BP@=')I;2@D;W5T<'5T*2DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)')E87-O;B`]("AE<F5G*")>:6YF
M;UM;.G-P86-E.EU=*B@N*RE<)"(L('1R:6TH)&]U='!U="DI*2`_(&5R96=?
M<F5P;&%C92@B7FEN9F];6SIS<&%C93I=72HH+BLI7"0B+"`B7%PQ(BP@=')I
M;2@D;W5T<'5T*2D@.B!&04Q313L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1R96%S;VXI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O(#T@
M(B`H:6YF;SH@)')E87-O;BDB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AE<F5G:2@B
M7G=A<FXB+"!T<FEM*"1O=71P=70I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F5A<V]N(#T@*&5R96<H(EYW87)N6ULZ<W!A8V4Z75TJ*"XK*5PD(BP@
M=')I;2@D;W5T<'5T*2DI(#\@97)E9U]R97!L86-E*")>=V%R;EM;.G-P86-E
M.EU=*B@N*RE<)"(L(")<7#$B+"!T<FEM*"1O=71P=70I*2`Z($9!3%-%.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E87-O;BD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'=A<FX@/2!T<G5E.R`O*B!O;FQY(&EF('1H97)E
M(&ES(&$@<F5A<V]N("HO#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;R`]("(@*'=A<FXZ("1R96%S;VXI(CL-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*#0H@("`@("`@("\O(%=E)W9E('-A=&ES9FEE9"!T:&4@<')E8V]N9&ET
M:6]N<R`M(')U;B!T:&4@=&5S="$-"B`@("`@("`@)'1H:7,M/G-A=F5?=&5X
M="@D=&UP7V9I;&4L)'-E8W1I;VY?=&5X=%LG1DE,12==*3L-"@T*("`@("`@
M("`D87)G<R`]("1S96-T:6]N7W1E>'1;)T%21U,G72`_("<@+2T@)RXD<V5C
M=&EO;E]T97AT6R=!4D=3)UT@.B`G)SL-"@T*("`@("`@("`D8VUD(#T@(B1P
M:'`D:6YI7W-E='1I;F=S("UF("1T;7!?9FEL921A<F=S(#(^)C$B.PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]L;V=G97(I*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7VQO9V=E<BT^;&]G*#(L("=2=6YN:6YG(&-O;6UA;F0@(B<@
M+B`D8VUD("X@)R(G*3L-"B`@("`@("`@?0T*#0H@("`@("`@("1S879E9&ER
M(#T@9V5T8W=D*"D[("\O(&EN(&-A<V4@=&AE('1E<W0@;6]V97,@=7,@87)O
M=6YD#0H@("`@("`@(&EF("AI<W-E="@D<V5C=&EO;E]T97AT6R=215154DY3
M)UTI*2![#0H@("`@("`@("`@("!O8E]S=&%R="@I.PT*("`@("`@("`@("`@
M<WES=&5M*"1C;60L("1R971U<FY?=F%L=64I.PT*("`@("`@("`@("`@)&]U
M="`](&]B7V=E=%]C;VYT96YT<R@I.PT*("`@("`@("`@("`@;V)?96YD7V-L
M96%N*"D[#0H@("`@("`@("`@("!`=6YL:6YK*"1T;7!?<&]S="D[#0H@("`@
M("`@("`@("`D<V5C=&EO;E]T97AT6R=215154DY3)UT@/2`H:6YT*2!T<FEM
M*"1S96-T:6]N7W1E>'1;)U)%5%523E,G72D[#0H@("`@("`@("`@("`D<F5T
M=7)N9F%I;"`]("@D<F5T=7)N7W9A;'5E("$]("1S96-T:6]N7W1E>'1;)U)%
M5%523E,G72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;W5T
M(#T@8"1C;61@.PT*("`@("`@("`@("`@)')E='5R;F9A:6P@/2!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!C:&1I<B@D<V%V961I<BD[#0H-"B`@("`@
M("`@:68@*"1S96-T:6]N7W1E>'1;)T-,14%.)UTI('L-"B`@("`@("`@("`@
M("\O('!E<F9O<FT@=&5S="!C;&5A;G5P#0H@("`@("`@("`@("`D=&AI<RT^
M<V%V95]T97AT*"1C;&5A;B`]("1T;7`@+B!U;FEQ:60H)R]P:'!T+B<I+"`D
M<V5C=&EO;E]T97AT6R=#3$5!3B==*3L-"B`@("`@("`@("`@(&`D<&AP("1C
M;&5A;F`[#0H@("`@("`@("`@("!`=6YL:6YK*"1C;&5A;BD[#0H@("`@("`@
M('T-"B`@("`@("`@+R\@1&]E<R!T:&4@;W5T<'5T(&UA=&-H('=H870@:7,@
M97AP96-T960_#0H@("`@("`@("1O=71P=70@/2!T<FEM*"1O=70I.PT*("`@
M("`@("`D;W5T<'5T(#T@<')E9U]R97!L86-E*"<O7')<;B\G+"`B7&XB+"`D
M;W5T<'5T*3L-"@T*("`@("`@("!I9B`H:7-S970H)'-E8W1I;VY?=&5X=%LG
M15A014-41B==*2!\?"!I<W-E="@D<V5C=&EO;E]T97AT6R=%6%!%0U1214=%
M6"==*2D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1S96-T:6]N7W1E>'1;
M)T584$5#5$8G72DI('L-"B`@("`@("`@("`@("`@("`D=V%N=&5D(#T@=')I
M;2@D<V5C=&EO;E]T97AT6R=%6%!%0U1&)UTI.PT*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`D=V%N=&5D(#T@=')I;2@D<V5C=&EO
M;E]T97AT6R=%6%!%0U1214=%6"==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1W86YT961?<F4@/2!P<F5G7W)E<&QA8V4H)R]<<EQN+R<L(EQN
M(BPD=V%N=&5D*3L-"B`@("`@("`@("`@(&EF("AI<W-E="@D<V5C=&EO;E]T
M97AT6R=%6%!%0U1&)UTI*2![#0H@("`@("`@("`@("`@("`@)'=A;G1E9%]R
M92`]('!R96=?<75O=&4H)'=A;G1E9%]R92P@)R\G*3L-"B`@("`@("`@("`@
M("`@("`O+R!3=&EC:R!T;R!B87-I8W,-"B`@("`@("`@("`@("`@("`D=V%N
M=&5D7W)E(#T@<W1R7W)E<&QA8V4H(B5S(BP@(BXK/R(L("1W86YT961?<F4I
M.R`O+VYO="!G<F5E9'D-"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@
M<W1R7W)E<&QA8V4H(B5I(BP@(ELK7"U=/ULP+3E=*R(L("1W86YT961?<F4I
M.PT*("`@("`@("`@("`@("`@("1W86YT961?<F4@/2!S=')?<F5P;&%C92@B
M)60B+"`B6S`M.5TK(BP@)'=A;G1E9%]R92D[#0H@("`@("`@("`@("`@("`@
M)'=A;G1E9%]R92`]('-T<E]R97!L86-E*"(E>"(L(");,"TY82UF02U&72LB
M+"`D=V%N=&5D7W)E*3L-"B`@("`@("`@("`@("`@("`D=V%N=&5D7W)E(#T@
M<W1R7W)E<&QA8V4H(B5F(BP@(ELK7"U=/UPN/ULP+3E=*UPN/ULP+3E=*BA%
M+3];,"TY72LI/R(L("1W86YT961?<F4I.PT*("`@("`@("`@("`@("`@("1W
M86YT961?<F4@/2!S=')?<F5P;&%C92@B)6,B+"`B+B(L("1W86YT961?<F4I
M.PT*("`@("`@("`@("`@("`@("\O("5F(&%L;&]W<R!T=V\@<&]I;G1S("(M
M+C`N,"(@8G5T('1H870@:7,@=&AE(&)E<W0@*G-I;7!L92H@97AP<F5S<VEO
M;@T*("`@("`@("`@("`@?0T*("`@("\J($1%0E5'(%E/55(@4D5'15@@2$52
M10T*("`@("`@("`@("`@=F%R7V1U;7`H)'=A;G1E9%]R92D[#0H@("`@("`@
M("`@("!P<FEN="AS=')?<F5P96%T*"<])RP@.#`I("X@(EQN(BD[#0H@("`@
M("`@("`@("!V87)?9'5M<"@D;W5T<'5T*3L-"B`@("`J+PT*("`@("`@("`@
M("`@:68@*"$D<F5T=7)N9F%I;"`F)B!P<F5G7VUA=&-H*"(O7B1W86YT961?
M<F5<)"]S(BP@)&]U='!U="DI('L-"B`@("`@("`@("`@("`@("!`=6YL:6YK
M*"1T;7!?9FEL92D[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@(E!!4U,@)'1E<W1E9"1I;F9O(BD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;VQD7W!H<"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!H<"`]("1O
M;&1?<&AP.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R
M971U<FX@)U!!4U-%1"<[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1W86YT960@/2!T<FEM*"1S96-T:6]N7W1E
M>'1;)T584$5#5"==*3L-"B`@("`@("`@("`@("1W86YT960@/2!P<F5G7W)E
M<&QA8V4H)R]<<EQN+R<L(EQN(BPD=V%N=&5D*3L-"B`@("`@("`@+R\@8V]M
M<&%R92!A;F0@;&5A=F4@;VX@<W5C8V5S<PT*("`@("`@("`@("`@)&]K(#T@
M*#`@/3T@<W1R8VUP*"1O=71P=70L)'=A;G1E9"DI.PT*("`@("`@("`@("`@
M:68@*"$D<F5T=7)N9F%I;"`F)B`D;VLI('L-"B`@("`@("`@("`@("`@("!`
M=6YL:6YK*"1T;7!?9FEL92D[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@(E!!4U,@)'1E<W1E9"1I
M;F9O(BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D;VQD7W!H<"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!H
M<"`]("1O;&1?<&AP.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!R971U<FX@)U!!4U-%1"<[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"@T*("`@("`@("`O+R!497-T(&9A:6QE9"!S;R!W92!N965D('1O(')E
M<&]R="!D971A:6QS+@T*("`@("`@("!I9B`H)'=A<FXI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?;&]G9V5R+3YL;V<H,"P@(E=!4DX@)'1E<W1E9"1I;F9O
M(BD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7VQO
M9V=E<BT^;&]G*#`L(")&04E,("1T97-T960D:6YF;R(I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@:68@*&ES<V5T*"1S96-T:6]N7W1E>'1;)U)%5%523E,G
M72DI('L-"B`@("`@("`@("`@("1'3$]"04Q36R=?7U!(4%]&04E,141?5$53
M5%-?7R==6UT@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W1E<W1?;F%M92<@/3X@)'1E<W1E9"P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G;W5T<'5T)R`]/B!E<F5G7W)E<&QA8V4H)UPN<&AP="0G
M+"<N;&]G)RP@)&9I;&4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=D:69F)R`@(#T^(&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYD:69F)RP@
M)&9I;&4I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I;F9O)R`@
M(#T^("1I;F9O+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R971U
M<FXG(#T^("1R971U<FY?=F%L=64-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)$=,3T)!
M3%-;)U]?4$A07T9!24Q%1%]415-44U]?)UU;72`](&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=&5S=%]N86UE)R`]/B`D=&5S=&5D
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O=71P=70G(#T^(&5R
M96=?<F5P;&%C92@G7"YP:'!T)"<L)RYL;V<G+"`D9FEL92DL#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)V1I9F8G("`@/3X@97)E9U]R97!L86-E
M*"=<+G!H<'0D)RPG+F1I9F8G+"`D9FEL92DL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VEN9F\G("`@/3X@)&EN9F\L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O('=R
M:71E("YE>'`-"B`@("`@("`@:68@*'-T<G!O<R@D;&]G7V9O<FUA="PG12<I
M("$]/2!&04Q312D@>PT*("`@("`@("`@("`@)&QO9VYA;64@/2!E<F5G7W)E
M<&QA8V4H)UPN<&AP="0G+"<N97AP)RPD9FEL92D[#0H@("`@("`@("`@("!I
M9B`H(21L;V<@/2!F;W!E;B@D;&]G;F%M92PG=R<I*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!C<F5A=&4@
M=&5S="!L;V<@+2`D;&]G;F%M92(I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@9G=R:71E*"1L;V<L)'=A;G1E9"D[#0H@("`@("`@("`@("!F8VQO
M<V4H)&QO9RD[#0H@("`@("`@('T-"@T*("`@("`@("`O+R!W<FET92`N;W5T
M#0H@("`@("`@(&EF("AS=')P;W,H)&QO9U]F;W)M870L)T\G*2`A/3T@1D%,
M4T4I('L-"B`@("`@("`@("`@("1L;V=N86UE(#T@97)E9U]R97!L86-E*"=<
M+G!H<'0D)RPG+F]U="<L)&9I;&4I.PT*("`@("`@("`@("`@:68@*"$D;&]G
M(#T@9F]P96XH)&QO9VYA;64L)W<G*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*")#86YN;W0@8W)E871E('1E<W0@;&]G
M("T@)&QO9VYA;64B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9W
M<FET92@D;&]G+"1O=71P=70I.PT*("`@("`@("`@("`@9F-L;W-E*"1L;V<I
M.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@=W)I=&4@+F1I9F8-"B`@("`@
M("`@:68@*'-T<G!O<R@D;&]G7V9O<FUA="PG1"<I("$]/2!&04Q312D@>PT*
M("`@("`@("`@("`@)&QO9VYA;64@/2!E<F5G7W)E<&QA8V4H)UPN<&AP="0G
M+"<N9&EF9B<L)&9I;&4I.PT*("`@("`@("`@("`@:68@*"$D;&]G(#T@9F]P
M96XH)&QO9VYA;64L)W<G*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*")#86YN;W0@8W)E871E('1E<W0@;&]G("T@)&QO
M9VYA;64B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9W<FET92@D
M;&]G+"`D=&AI<RT^9V5N97)A=&5?9&EF9B@D=V%N=&5D+"`D;W5T<'5T+`T*
M("`@("`@("`@("`@("`@(&ES<V5T*"1S96-T:6]N7W1E>'1;)U)%5%523E,G
M72D@/R!A<G)A>2AT<FEM*"1S96-T:6]N7W1E>'1;)U)%5%523E,G72DL#0H@
M("`@("`@("`@("`@("`@("`@("1R971U<FY?=F%L=64I(#H@;G5L;"DI.PT*
M("`@("`@("`@("`@9F-L;W-E*"1L;V<I.PT*("`@("`@("!]#0H-"B`@("`@
M("`@+R\@=W)I=&4@+FQO9PT*("`@("`@("!I9B`H<W1R<&]S*"1L;V=?9F]R
M;6%T+"=,)RD@(3T]($9!3%-%*2![#0H@("`@("`@("`@("`D;&]G;F%M92`]
M(&5R96=?<F5P;&%C92@G7"YP:'!T)"<L)RYL;V<G+"1F:6QE*3L-"B`@("`@
M("`@("`@(&EF("@A)&QO9R`](&9O<&5N*"1L;V=N86UE+"=W)RDI('L-"B`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T
M(&-R96%T92!T97-T(&QO9R`M("1L;V=N86UE(BD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F=W)I=&4H)&QO9RPB#0HM+2TM($584$5#5$5$($]5
M5%!55`T*)'=A;G1E9`T*+2TM+2!!0U1504P@3U544%54#0HD;W5T<'5T#0HM
M+2TM($9!24Q%1`T*(BD[#0H@("`@("`@("`@("!I9B`H)')E='5R;F9A:6PI
M('L-"B`@("`@("`@("`@("`@("!F=W)I=&4H)&QO9RPB#0HM+2TM($584$5#
M5$5$(%)%5%523@T*)'-E8W1I;VY?=&5X=%M215154DY370T*+2TM+2!!0U15
M04P@4D5455).#0HD<F5T=7)N7W9A;'5E#0HB*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9C;&]S92@D;&]G*3L-"B`@("`@("`@("`@("\O97)R
M;W)?<F5P;W)T*"1F:6QE+"1L;V=N86UE+"1T97-T960I.PT*("`@("`@("!]
M#0H-"B`@("`@("`@:68@*&ES<V5T*"1O;&1?<&AP*2D@>PT*("`@("`@("`@
M("`@)'!H<"`]("1O;&1?<&AP.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T
M=7)N("1W87)N(#\@)U=!4DY%1"<@.B`G1D%)3$5$)SL-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G96YE<F%T95]D:69F*"1W86YT960L("1O=71P=70L("1R
M971U<FY?=F%L=64I#0H@("`@>PT*("`@("`@("`D=R`](&5X<&QO9&4H(EQN
M(BP@)'=A;G1E9"D[#0H@("`@("`@("1O(#T@97AP;&]D92@B7&XB+"`D;W5T
M<'5T*3L-"B`@("`@("`@)'<Q(#T@87)R87E?9&EF9E]A<W-O8R@D=RPD;RD[
M#0H@("`@("`@("1O,2`](&%R<F%Y7V1I9F9?87-S;V,H)&\L)'<I.PT*("`@
M("`@("`D=S(@/2!A<G)A>2@I.PT*("`@("`@("`D;S(@/2!A<G)A>2@I.PT*
M("`@("`@("!F;W)E86-H*"1W,2!A<R`D:61X(#T^("1V86PI("1W,EMS<')I
M;G1F*"(E,#-D/"(L)&ED>"E=(#T@<W!R:6YT9B@B)3`S9"T@(BP@)&ED>"LQ
M*2XD=F%L.PT*("`@("`@("!F;W)E86-H*"1O,2!A<R`D:61X(#T^("1V86PI
M("1O,EMS<')I;G1F*"(E,#-D/B(L)&ED>"E=(#T@<W!R:6YT9B@B)3`S9"L@
M(BP@)&ED>"LQ*2XD=F%L.PT*("`@("`@("`D9&EF9B`](&%R<F%Y7VUE<F=E
M*"1W,BP@)&\R*3L-"B`@("`@("`@:W-O<G0H)&1I9F8I.PT*("`@("`@("!I
M9B`H)')E='5R;E]V86QU92D@>PT*("`@("`@("`@("`@)&5X=')A(#T@(B,C
M15A014-4140Z("1R971U<FY?=F%L=65;,%U<<EQN(R-215154DY%1#H@)')E
M='5R;E]V86QU95LQ72([#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D97AT<F$@/2`G)SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@:6UP
M;&]D92@B7')<;B(L("1D:69F*2`N("1E>'1R83L-"B`@("!]#0H-"B`@("`O
M+PT*("`@("\O("!7<FET92!T:&4@9VEV96X@=&5X="!T;R!A('1E;7!O<F%R
M>2!F:6QE+"!A;F0@<F5T=7)N('1H92!F:6QE;F%M92X-"B`@("`O+PT*#0H@
M("`@9G5N8W1I;VX@<V%V95]T97AT*"1F:6QE;F%M92P@)'1E>'0I#0H@("`@
M>PT*("`@("`@("!I9B`H(21F<"`](&9O<&5N*"1F:6QE;F%M92P@)W<G*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO
M="!O<&5N(&9I;&4@)R(@+B`D9FEL96YA;64@+B`B)R`H<V%V95]T97AT*2(I
M.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D9G`L)'1E>'0I.PT*("`@
M("`@("!F8VQO<V4H)&9P*3L-"B`@("!I9B`H,2`\($1%5$%)3$5$*2!E8VAO
M("(-"D9)3$4@)&9I;&5N86UE('M[>PT*)'1E>'0-"GU]?0T*(CL-"B`@("!]
M#0H-"GT-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O5F%L:61A=&4N<&AP````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P-30V,3`@,3`U,34T,S0Q,S0@,#(Q-#8Q`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(%!%05)?5F%L:61A=&4-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@5F%L:61A=&4N<&AP+'8@,2XT-B`R,#`V+S`Q+S(S
M(#$W.C$V.C,U(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BHC
M0"L-"B`J($-O;G-T86YT<R!F;W(@:6YS=&%L;"!S=&%G90T*("HO#0ID969I
M;F4H)U!%05)?5D%,241!5$5?24Y35$%,3$E.1R<L(#$I.PT*9&5F:6YE*"=0
M14%27U9!3$E$051%7U5.24Y35$%,3$E.1R<L(#(I.R`O+R!T:&ES(&ES(&YO
M="!B:70M;6%P<&5D(&QI:V4@=&AE(&]T:&5R<PT*9&5F:6YE*"=014%27U9!
M3$E$051%7TY/4DU!3"<L(#,I.PT*9&5F:6YE*"=014%27U9!3$E$051%7T1/
M5TY,3T%$24Y')RP@-"D[("\O('1H:7,@:7,@;F]T(&)I="UM87!P960@;&EK
M92!T:&4@;W1H97)S#0ID969I;F4H)U!%05)?5D%,241!5$5?4$%#2T%'24Y'
M)RP@-RD[#0HO*BHC0"TJ+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP
M:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+U9A;&ED871O<B]014-,+G!H<"<[
M#0H-"B\J*@T*("H@5F%L:61A=&EO;B!C;&%S<R!F;W(@<&%C:V%G92YX;6P@
M+2!C:&%N;F5L+6QE=F5L(&%D=F%N8V5D('9A;&ED871I;VX-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,0T*("HO#0IC;&%S<R!014%27U9A;&ED871E#0I[#0H@("`@=F%R("1P
M86-K86=E<F5G97@@/2!?4$5!4E]#3TU-3TY?4$%#2T%'15].04U%7U!214<[
M#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U!A8VMA9V5&:6QE7W8Q?%!%
M05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!V87(@)%]P86-K86=E
M>&UL.PT*("`@("\J*@T*("`@("`J($!V87(@:6YT(&]N92!O9B!T:&4@4$5!
M4E]604Q)1$%415\J(&-O;G-T86YT<PT*("`@("`J+PT*("`@('9A<B`D7W-T
M871E(#T@4$5!4E]604Q)1$%415].3U)-04P[#0H@("`@+RHJ#0H@("`@("H@
M1F]R;6%T.B`H)V5R<F]R)R`]/B!A<G)A>2@G9FEE;&0G(#T^(&YA;64L("=R
M96%S;VXG(#T^(')E87-O;BDL("=W87)N:6YG)R`]/B!S86UE*0T*("`@("`J
M($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!V87(@)%]F86EL=7)E<R`](&%R<F%Y*"=E<G)O<B<@/3X@87)R87DH
M*2P@)W=A<FYI;F<G(#T^(&%R<F%Y*"DI.PT*#0H@("`@+RHJ#0H@("`@("H@
M3W9E<G)I9&4@=&AI<R!M971H;V0@=&\@:&%N9&QE('9A;&ED871I;VX@;V8@
M;F]R;6%L('!A8VMA9V4@;F%M97,-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@
M("`@("H@0')E='5R;B!B;V]L#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61086-K86=E3F%M92@D;F%M
M92D-"B`@("![#0H@("`@("`@(')E='5R;B`H8F]O;"D@<')E9U]M871C:"@G
M+UXG("X@)'1H:7,M/G!A8VMA9V5R96=E>"`N("<D+R<L("1N86UE*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@
M;F%M92!T;R!V86QI9&%T90T*("`@("`J($!P87)A;2!S=')I;F<@;F%M92!O
M9B!C:&%N;F5L+7-P96-I9FEC('9A;&ED871I;VX@<&%C:V%G90T*("`@("`J
M($!F:6YA;`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED4&%C:V%G94YA
M;64H)&YA;64L("1V86QI9&%T97!A8VMA9V5N86UE(#T@9F%L<V4I#0H@("`@
M>PT*("`@("`@("!I9B`H)'9A;&ED871E<&%C:V%G96YA;64I('L-"B`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1N86UE*2`]/2!S=')T;VQO=V5R*"1V
M86QI9&%T97!A8VMA9V5N86UE*2D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`H8F]O;"D@<')E9U]M871C:"@G+UY;82UZ02U:,"TY7UTK*#\Z7"Y;82UZ
M02U:,"TY7UTK*2HD+R<L("1N86UE*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]V86QI9%!A8VMA9V5.86UE
M*"1N86UE*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES('9A;&ED
M871E<R!A(&)U;F1L92!N86UE+"!A;F0@8G5N9&QE(&YA;65S(&UU<W0@8V]N
M9F]R;0T*("`@("`J('1O('1H92!014%2(&YA;6EN9R!C;VYV96YT:6]N+"!S
M;R!T:&4@;65T:&]D(&ES(&9I;F%L(&%N9"!S=&%T:6,N#0H@("`@("H@0'!A
M<F%M('-T<FEN9PT*("`@("`J($!F:6YA;`T*("`@("`J($!S=&%T:6,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9$=R;W5P3F%M92@D;F%M92D-"B`@
M("![#0H@("`@("`@(')E='5R;B`H8F]O;"D@<')E9U]M871C:"@G+UXG("X@
M7U!%05)?0T]-34].7U!!0TM!1T5?3D%-15]04D5'("X@)R0O)RP@)&YA;64I
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W:&5T:&5R
M("1S=&%T92!R97!R97-E;G1S(&$@=F%L:60@<W1A8FEL:71Y(&QE=F5L#0H@
M("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@8F]O;`T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B!`9FEN86P-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!V86QI9%-T871E*"1S=&%T92D-"B`@("![#0H@("`@("`@(')E='5R
M;B!I;E]A<G)A>2@D<W1A=&4L(&%R<F%Y*"=S;F%P<VAO="<L("=D979E;"<L
M("=A;'!H82<L("=B971A)RP@)W-T86)L92<I*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!'970@82!L:7-T(&]F('9A;&ED('-T86)I;&ET>2!L979E
M;',-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@
M("`J($!F:6YA;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%9A;&ED4W1A
M=&5S*"D-"B`@("![#0H@("`@("`@(')E='5R;B!A<G)A>2@G<VYA<'-H;W0G
M+"`G9&5V96PG+"`G86QP:&$G+"`G8F5T82<L("=S=&%B;&4G*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!A('9E<G-I
M;VX@:7,@82!P<F]P97)L>2!F;W)M871T960@=F5R<VEO;B!N=6UB97(@=&AA
M="!C86X@8F4@=7-E9`T*("`@("`J(&)Y('9E<G-I;VY?8V]M<&%R90T*("`@
M("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@
M*B!`<W1A=&EC#0H@("`@("H@0&9I;F%L#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@=F%L:61697)S:6]N*"1V97(I#0H@("`@>PT*("`@("`@("!R971U<FX@
M*&)O;VPI('!R96=?;6%T8V@H4$5!4E]#3TU-3TY?4$%#2T%'15]615)324].
M7U!214<L("1V97(I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A
M;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!S971086-K86=E1FEL92@F)'!F*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL(#T@)B1P9CL-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?861D1F%I;'5R92@D9FEE;&0L("1R96%S;VXI#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7V9A:6QU<F5S6R=E<G)O<G,G75M=(#T@
M87)R87DH)V9I96QD)R`]/B`D9FEE;&0L("=R96%S;VXG(#T^("1R96%S;VXI
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(%]A9&1787)N:6YG*"1F:65L9"P@)')E
M87-O;BD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9F%I;'5R97-;)W=A<FYI
M;F=S)UU;72`](&%R<F%Y*"=F:65L9"<@/3X@)&9I96QD+"`G<F5A<V]N)R`]
M/B`D<F5A<V]N*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971&86EL=7)E
M<R@I#0H@("`@>PT*("`@("`@("`D9F%I;'5R97,@/2`D=&AI<RT^7V9A:6QU
M<F5S.PT*("`@("`@("`D=&AI<RT^7V9A:6QU<F5S(#T@87)R87DH)W=A<FYI
M;F=S)R`]/B!A<G)A>2@I+"`G97)R;W)S)R`]/B!A<G)A>2@I*3L-"B`@("`@
M("`@<F5T=7)N("1F86EL=7)E<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@:6YT(&]N92!O9B!T:&4@4$5!4E]604Q)1$%415\J(&-O;G-T
M86YT<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E*"1S=&%T92`]
M(&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C
M:V%G97AM;"DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'-T871E("$]/2!N=6QL*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W-T871E(#T@)'-T871E.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?9F%I;'5R97,@/2!A<G)A>2@G=V%R;FEN9W,G(#T^(&%R
M<F%Y*"DL("=E<G)O<G,G(#T^(&%R<F%Y*"DI.PT*("`@("`@("`D=&AI<RT^
M=F%L:61A=&5086-K86=E3F%M92@I.PT*("`@("`@("`D=&AI<RT^=F%L:61A
M=&5697)S:6]N*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T94UA:6YT86EN
M97)S*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T941A=&4H*3L-"B`@("`@
M("`@)'1H:7,M/G9A;&ED871E4W5M;6%R>2@I.PT*("`@("`@("`D=&AI<RT^
M=F%L:61A=&5$97-C<FEP=&EO;B@I.PT*("`@("`@("`D=&AI<RT^=F%L:61A
M=&5,:6-E;G-E*"D[#0H@("`@("`@("1T:&ES+3YV86QI9&%T94YO=&5S*"D[
M#0H@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A8VMA9V5X
M;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@("`@("`@("1T:&ES+3YV
M86QI9&%T95-T871E*"D[#0H@("`@("`@("`@("`D=&AI<RT^=F%L:61A=&5&
M:6QE;&ES="@I.PT*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]P86-K86=E
M>&UL+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]("<R+C`G*2![#0H@("`@
M("`@("`@("`D=&AI<RT^=F%L:61A=&54:6UE*"D[#0H@("`@("`@("`@("`D
M=&AI<RT^=F%L:61A=&53=&%B:6QI='DH*3L-"B`@("`@("`@("`@("1T:&ES
M+3YV86QI9&%T941E<',H*3L-"B`@("`@("`@("`@("1T:&ES+3YV86QI9&%T
M94UA:6Y&:6QE;&ES="@I.PT*("`@("`@("`@("`@)'1H:7,M/G9A;&ED871E
M4F5L96%S949I;&5L:7-T*"D[#0H@("`@("`@("`@("`O+R1T:&ES+3YV86QI
M9&%T94=L;V)A;%1A<VMS*"D[#0H@("`@("`@("`@("`D=&AI<RT^=F%L:61A
M=&5#:&%N9V5L;V<H*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@(2@H
M8F]O;"D@8V]U;G0H)'1H:7,M/E]F86EL=7)E<ULG97)R;W)S)UTI*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E4&%C:V%G94YA;64H*0T*("`@
M('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%4
M15]004-+04=)3D<@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`]
M/2!014%27U9!3$E$051%7TY/4DU!3"D@>PT*("`@("`@("`@("`@:68@*"1T
M:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G
M,BXP)R`F)@T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL
M+3YG971%>'1E;F1S*"DI('L-"B`@("`@("`@("`@("`@("`D=F5R<VEO;B`]
M("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO;B@I("X@)R<[#0H@("`@
M("`@("`@("`@("`@)&YA;64@/2`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!A
M8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`D=&5S="`](&%R<F%Y7W-H:69T
M*"1A(#T@97AP;&]D92@G+B<L("1V97)S:6]N*2D[#0H@("`@("`@("`@("`@
M("`@:68@*"1T97-T(#T]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)'9L96X@/2!S=')L96XH)'1E<W0I.PT*("`@("`@("`@("`@("`@("1M
M86IV97(@/2!S=6)S='(H)&YA;64L('-T<FQE;B@D;F%M92D@+2`D=FQE;BD[
M#0H@("`@("`@("`@("`@("`@=VAI;&4@*"1M86IV97(@)B8@(6ES7VYU;65R
M:6,H)&UA:G9E<GLP?2DI('L-"B`@("`@("`@("`@("`@("`@("`@)&UA:G9E
M<B`]('-U8G-T<B@D;6%J=F5R+"`Q*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"1M86IV97(@(3T@)'1E<W0I('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=P86-K86=E)RP@
M(G!A8VMA9V4@)&YA;64@97AT96YD<R!P86-K86=E("(@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E>&UL+3YG971%>'1E;F1S
M*"D@+B`G(&%N9"!S;R!T:&4@;F%M92!S:&]U;&0@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G:&%V92!A('!O<W1F:7@@97%U86P@=&\@=&AE(&UA
M:F]R('9E<G-I;VX@;&EK92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2`N("1T97-T("X@
M)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*'-U8G-T<B@D;F%M92P@,"P@<W1R;&5N
M*"1N86UE*2`M("1V;&5N*2`A/0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G<&%C:V%G92<L
M(")P86-K86=E("1N86UE(&5X=&5N9',@<&%C:V%G92`B("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD
M<R@I("X@)R!A;F0@<V\@=&AE(&YA;64@;75S="`G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=B92!A;B!E>'1E;G-I;VX@;&EK92`B)R`N("1T:&ES
M+3Y?<&%C:V%G97AM;"T^9V5T17AT96YD<R@I("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T97-T("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED4&%C:V%G
M94YA;64H)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E*"DI*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)VYA;64G+"`G<&%C:V%G
M92!N86UE("(G("X-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X
M;6PM/F=E=%!A8VMA9V4H*2`N("<B(&ES(&EN=F%L:60G*3L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=F%L:61A=&5697)S:6]N*"D-"B`@("![#0H@("`@("`@(&EF("@D
M=&AI<RT^7W-T871E("$](%!%05)?5D%,241!5$5?4$%#2T%'24Y'*2![#0H@
M("`@("`@("`@("!I9B`H(21T:&ES+3YV86QI9%9E<G-I;VXH)'1H:7,M/E]P
M86-K86=E>&UL+3YG971697)S:6]N*"DI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A9&1&86EL=7)E*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@
M("`@("`@)TEN=F%L:60@=F5R<VEO;B!N=6UB97(@(B<@+B`D=&AI<RT^7W!A
M8VMA9V5X;6PM/F=E=%9E<G-I;VXH*2`N("<B)RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@)'9E<G-I;VX@/2`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%9E<G-I;VXH
M*3L-"B`@("`@("`@)'9E<G-I;VYC;VUP;VYE;G1S(#T@97AP;&]D92@G+B<L
M("1V97)S:6]N*3L-"B`@("`@("`@:68@*&-O=6YT*"1V97)S:6]N8V]M<&]N
M96YT<RD@(3T@,RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG
M*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`G02!V97)S:6]N(&YU;6)E
M<B!S:&]U;&0@:&%V92`S(&1E8VEM86QS("AX+GDN>BDG*3L-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1N86UE(#T@
M)'1H:7,M/E]P86-K86=E>&UL+3YG971086-K86=E*"D[#0H@("`@("`@("\O
M('9E<G-I;VX@;75S="!B92!B87-E9"!U<&]N('-T871E#0H@("`@("`@('-W
M:71C:"`H)'1H:7,M/E]P86-K86=E>&UL+3YG9713=&%T92@I*2![#0H@("`@
M("`@("`@("!C87-E("=S;F%P<VAO="<@.@T*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@8V%S92`G9&5V96PG(#H-"B`@("`@
M("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=("X@)V$G(#T]
M("<P82<I('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D=F5R<VEO
M;F-O;7!O;F5N='-;,%T@/3T@,"D@>PT*("`@("`@("`@("`@("`@("`@("`D
M=F5R<VEO;F-O;7!O;F5N='-;,%T@/2`G,"<[#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G=F5R<VEO;B`B)R`N("1V97)S:6]N("X@)R(@<VAO
M=6QD(&)E("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H
M)RXG("PD=F5R<VEO;F-O;7!O;F5N=',I("X@)R(G*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D
M9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)W!A8VMA9V5S('=I=&@@9&5V96P@<W1A8FEL:71Y(&UU<W0@8F4@/"!V97)S
M:6]N(#$N,"XP)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E("=A;'!H82<@.@T*("`@("`@("`@("`@8V%S92`G8F5T82<@
M.@T*("`@("`@("`@("`@("`@("\O(&-H96-K(&9O<B!A('!A8VMA9V4@=&AA
M="!E>'1E;F1S(&$@<&%C:V%G92P-"B`@("`@("`@("`@("`@("`O+R!L:6ME
M($9O;R!A;F0@1F]O,@T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7W-T
M871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'24Y'*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AS=6)S='(H)'9E<G-I;VYC;VUP;VYE;G1S6S)=+"`Q
M+"`R*2`]/2`G<F,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9$9A:6QU<F4H)W9E<G-I;VXG+"`G4F5L96%S92!#86YD:61A=&4@
M=F5R<VEO;G,@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VUU
M<W0@:&%V92!C87!I=&%L(%)#+"!N;W0@;&]W97(M8V%S92!R8R<I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("@A)'1H:7,M/E]P86-K86=E>&UL+3YG971%>'1E;F1S*"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULP
M72`]/2`G,2<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R
M<VEO;F-O;7!O;F5N='-;,EU[,'T@/3T@)S`G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULR72`]/2`G
M,"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=F5R
M<VEO;B`Q+BHN,#`P,`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VX@,2XG("X@)'9E<G-I
M;VYC;VUP;VYE;G1S6S%=("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G+C`@<')O8F%B;'D@<VAO=6QD(&YO="!B92!A;'!H
M82!O<B!B971A)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("AS=')L96XH)'9E<G-I;VYC;VUP;VYE;G1S6S)=*2`^(#$I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=F5R<VEO;B`Q
M+BHN,%)#,2!O<B`Q+BHN,&)E=&$R-"!E=&,N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O('9E<G-I;VX@,2XJ+C`-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N
M(#$N)R`N("1V97)S:6]N8V]M<&]N96YT<ULQ72`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)RXP('!R;V)A8FQY('-H;W5L
M9"!N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R
M;FEN9R@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=B=6=F:7@@=F5R<VEO;G,@*#$N,RYX('=H97)E('@@/B`P*2!P<F]B
M86)L>2!S:&]U;&0@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=N;W0@8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'9E<G-I
M;VYC;VUP;VYE;G1S6S!=("$]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;6%J;W(@=F5R<VEO;G,@9W)E871E<B!T
M:&%N(#$@87)E(&YO="!A;&QO=V5D(&9O<B!P86-K86=E<R`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=VET:&]U="!A;B`\97AT96YD<SX@
M=&%G(&]R(&%N(&ED96YT:6-A;"!P;W-T9FEX("AF;V\R('8R+C`N,"DG*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R
M<VEO;F-O;7!O;F5N='-;,%T@+B`G82<@/3T@)S!A)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N
M96YT<ULP72`]/2`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R
M<VEO;F-O;7!O;F5N='-;,%T@/2`G,"<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=V97)S:6]N("(G("X@)'9E<G-I;VX@+B`G
M(B!S:&]U;&0@8F4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EM<&QO9&4H)RXG("PD=F5R<VEO;F-O;7!O;F5N=',I("X@)R(G*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1V;&5N(#T@<W1R;&5N*"1V97)S:6]N
M8V]M<&]N96YT<ULP72`N("<G*3L-"B`@("`@("`@("`@("`@("`@("`@)&UA
M:G9E<B`]('-U8G-T<B@D;F%M92P@<W1R;&5N*"1N86UE*2`M("1V;&5N*3L-
M"B`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1M86IV97(@)B8@(6ES7VYU
M;65R:6,H)&UA:G9E<GLP?2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1M86IV97(@/2!S=6)S='(H)&UA:G9E<BP@,2D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"@D=F5R<VEO;F-O
M;7!O;F5N='-;,%T@(3T@,"D@)B8@)&UA:G9E<B`A/2`D=F5R<VEO;F-O;7!O
M;F5N='-;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M861D5V%R;FEN9R@G=F5R<VEO;B<L("=F:7)S="!V97)S:6]N(&YU;6)E<B`B
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VYC;VUP
M;VYE;G1S6S!=("X@)R(@;75S="!M871C:"!T:&4@<&]S=&9I>"!O9B`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92!N86UE("(G
M("X@)&YA;64@+B`G(B`H)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&UA:G9E<B`N("<I)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#T]("1M86IV
M97(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R<VEO;F-O
M;7!O;F5N='-;,EU[,'T@/3T@)S`G*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT<ULR72`]/2`G,"<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=F5R<VEO;B`R
M+BHN,#`P,`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(G9E<G-I;VX@)&UA:G9E<BXB("X@)'9E<G-I
M;VYC;VUP;VYE;G1S6S%=("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G+C`@<')O8F%B;'D@<VAO=6QD(&YO="!B92!A;'!H
M82!O<B!B971A)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R;&5N*"1V97)S:6]N8V]M<&]N96YT<ULR72D@/B`Q*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('9E<G-I;VX@
M,BXJ+C!20S$@;W(@,BXJ+C!B971A,C0@971C+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!V97)S:6]N(#(N*BXP#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G=F5R<VEO;B<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B=F5R<VEO
M;B`D;6%J=F5R+B(@+B`D=F5R<VEO;F-O;7!O;F5N='-;,5T@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<N,"!C86YN;W0@
M8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G
M=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")B
M=6=F:7@@=F5R<VEO;G,@*"1M86IV97(N>"YY('=H97)E('D@/B`P*2!S:&]U
M;&0@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N;W0@
M8F4@86QP:&$@;W(@8F5T82<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'9E<G-I;VYC;VUP;VYE
M;G1S6S!=("$]("<P)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B;VYL>2!V97)S:6]N<R`P+G@N>2!A;F0@)&UA:G9E<BYX
M+GD@87)E(&%L;&]W960@9F]R(&%L<&AA+V)E=&$@<F5L96%S97,B*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D=F5R<VEO
M;F-O;7!O;F5N='-;,%T@+B`G82<@/3T@)S!A)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1V97)S:6]N8V]M<&]N96YT
M<ULP72`]/2`P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO
M;F-O;7!O;F5N='-;,%T@/2`G,"<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=V97)S:6]N("(G("X@)'9E<G-I;VX@+B`G(B!S
M:&]U;&0@8F4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RXG("PD=F5R<VEO;F-O;7!O;F5N=',I("X@)R(G*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@8V%S92`G<W1A8FQE)R`Z#0H@("`@("`@("`@("`@("`@:68@
M*"1V97)S:6]N8V]M<&]N96YT<ULP72`]/2`G,"<I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP@)W9E<G-I
M;VYS(&QE<W,@=&AA;B`Q+C`N,"!C86YN;W0@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("=B92!S=&%B;&4G*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@A:7-?;G5M97)I8R@D=F5R<VEO;F-O;7!O;F5N='-;,ETI*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7&0K*')C?&%\
M86QP:&%\8GQB971A*5QD*B]I)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9E<G-I;VYC;VUP;VYE;G1S6S)=*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]A9&1787)N:6YG*"=V97)S:6]N)RP@)W9E<G-I
M;VX@(B<@+B`D=F5R<VEO;B`N("<B(&]R(&%N>2`G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G4D,O8F5T82]A;'!H82!V97)S:6]N(&-A;FYO
M="!B92!S=&%B;&4G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("\O(&-H96-K(&9O<B!A('!A8VMA9V4@
M=&AA="!E>'1E;F1S(&$@<&%C:V%G92P-"B`@("`@("`@("`@("`@("`O+R!L
M:6ME($9O;R!A;F0@1F]O,@T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^
M7W!A8VMA9V5X;6PM/F=E=$5X=&5N9',H*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=FQE;B`]('-T<FQE;B@D=F5R<VEO;F-O;7!O;F5N='-;,%T@+B`G
M)RD[#0H@("`@("`@("`@("`@("`@("`@("1M86IV97(@/2!S=6)S='(H)&YA
M;64L('-T<FQE;B@D;F%M92D@+2`D=FQE;BD[#0H@("`@("`@("`@("`@("`@
M("`@('=H:6QE("@D;6%J=F5R("8F("%I<U]N=6UE<FEC*"1M86IV97)[,'TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;6%J=F5R(#T@<W5B<W1R
M*"1M86IV97(L(#$I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@H)'9E<G-I;VYC;VUP;VYE;G1S6S!=("$](#`I
M("8F("1M86IV97(@(3T@)'9E<G-I;VYC;VUP;VYE;G1S6S!=*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I
M;VXG+"`G9FER<W0@=F5R<VEO;B!N=6UB97(@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V97)S:6]N8V]M<&]N96YT<ULP72`N("<B(&UU
M<W0@;6%T8V@@=&AE('!O<W1F:7@@;V8@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V4@;F%M92`B)R`N("1N86UE("X@)R(@*"<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M86IV97(@+B`G*2<I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)'9E<G-I;VYC;VUP;VYE;G1S6S!=(#X@,2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W9E<G-I;VXG+"`G;6%J;W(@=F5R
M<VEO;B!X(&EN('@N>2YZ(&UA>2!N;W0@8F4@9W)E871E<B!T:&%N("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)S$@9F]R(&%N>2!P86-K86=E('1H
M870@9&]E<R!N;W0@:&%V92!A;B`\97AT96YD<SX@=&%G)RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A=6QT(#H-"B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5-86EN
M=&%I;F5R<R@I#0H@("`@>PT*("`@("`@("`O+R!M86EN=&%I;F5R<R!C86X@
M;VYL>2!B92!T<G5L>2!V86QI9&%T960@<V5R=F5R+7-I9&4@9F]R(&UO<W0@
M8VAA;FYE;',-"B`@("`@("`@+R\@8G5T(&%L;&]W('1H:7,@8W5S=&]M:7IA
M=&EO;B!F;W(@=&AO<V4@=VAO('=I<V@@:70-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T941A=&4H*0T*("`@
M('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!4E]604Q)1$%4
M15].3U)-04P@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]S=&%T92`]/2!0
M14%27U9!3$E$051%7U!!0TM!1TE.1RD@>PT*("`@("`@("`@("`@:68@*"%P
M<F5G7VUA=&-H*"<O7&1<9%QD7&1<+5QD7&1<+5QD7&0O)RP-"B`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T1&%T92@I*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?861D1F%I;'5R92@G9&%T92<L("=I
M;G9A;&ED(')E;&5A<V4@9&%T92`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T1&%T92@I("X@)R(G*3L-"B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H<W1R=&]T:6UE*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T
M1&%T92@I*2`]/2`M,2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D
M1F%I;'5R92@G9&%T92<L("=I;G9A;&ED(')E;&5A<V4@9&%T92`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T1&%T
M92@I("X@)R(G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]S=&%T92`]
M/2!014%27U9!3$E$051%7U!!0TM!1TE.1R`F)@T*("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E>&UL+3YG971$871E*"D@(3T@9&%T92@G62UM
M+60G*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?861D5V%R;FEN9R@G
M9&%T92<L("=296QE87-E($1A=&4@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=$1A=&4H*2`N("<B(&ES(&YO="!T
M;V1A>2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&54:6UE
M*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E>&UL+3YG
M9714:6UE*"DI('L-"B`@("`@("`@("`@("\O(&1E9F%U;'0@;V8@;F\@=&EM
M92!V86QU92!S970-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@("\O('!A8VMA9V5R(&%U=&]M871I8V%L;'D@<V5T<R!T
M:6UE+"!S;R!O;FQY('9A;&ED871E(&EF#0H@("`@("`@("\O('!E87(@=F%L
M:61A=&4@:7,@8V%L;&5D#0H@("`@("`@(&EF("@D=&AI<RT^7W-T871E(#T@
M4$5!4E]604Q)1$%415].3U)-04PI('L-"B`@("`@("`@("`@(&EF("@A<')E
M9U]M871C:"@G+UQD7&0Z7&1<9#I<9%QD+R<L#0H@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H*2DI('L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H)W1I;64G+"`G:6YV86QI9"!R
M96QE87-E('1I;64@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5X;6PM/F=E=%1I;64H*2`N("<B)RD[#0H@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*'-T<G1O=&EM92@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H*2D@
M/3T@+3$I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A:6QU<F4H
M)W1I;64G+"`G:6YV86QI9"!R96QE87-E('1I;64@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%1I;64H*2`N("<B
M)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&53=&%T92@I#0H@("`@>PT*("`@("`@
M("`O+R!T:&ES(&ES('1H92!C;&]S97-T('1O(")F:6YA;"(@<&AP-"!C86X@
M9V5T#0H@("`@("`@(&EF("@A4$5!4E]686QI9&%T93HZ=F%L:613=&%T92@D
M=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"DI*2![#0H@("`@("`@("`@
M("!I9B`H<W1R=&]L;W=E<B@D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E
M*"D@/3T@)W)C)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A
M:6QU<F4H)W-T871E)RP@)U)#(&ES(&YO="!A('-T871E+"!I="!I<R!A('9E
M<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("=P;W-T9FEX+"!U<V4@
M)R`N("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T5F5R<VEO;B@I("X@)U)#,2P@
M<W1A=&4@8F5T82<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/E]A9&1&86EL=7)E*"=S=&%T92<L("=I;G9A;&ED(')E;&5A<V4@<W1A
M=&4@(B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^
M9V5T4W1A=&4H*2`N("<B+"!M=7-T(&)E(&]N92!O9CH@)R`N#0H@("`@("`@
M("`@("`@("`@:6UP;&]D92@G+"`G+"!014%27U9A;&ED871E.CIG971686QI
M9%-T871E<R@I*2D[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!V86QI9&%T95-T86)I;&ET>2@I#0H@("`@>PT*("`@("`@("`D<F5T
M(#T@=')U93L-"B`@("`@("`@)'!A8VMA9V5S=&%B:6QI='D@/2`D=&AI<RT^
M7W!A8VMA9V5X;6PM/F=E=%-T871E*"D[#0H@("`@("`@("1A<&ES=&%B:6QI
M='D@/2`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"=A<&DG*3L-"B`@
M("`@("`@:68@*"%014%27U9A;&ED871E.CIV86QI9%-T871E*"1P86-K86=E
M<W1A8FEL:71Y*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]A9&1&86EL=7)E
M*"=S=&%T92<L("=I;G9A;&ED(')E;&5A<V4@<W1A8FEL:71Y("(G("X-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%-T871E*"D@
M+B`G(BP@;75S="!B92!O;F4@;V8Z("<@+@T*("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RP@)RP@4$5!4E]686QI9&%T93HZ9V5T5F%L:613=&%T97,H*2DI
M.PT*("`@("`@("`@("`@)')E="`](&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@("1A<&ES=&%T97,@/2!014%27U9A;&ED871E.CIG971686QI9%-T871E
M<R@I.PT*("`@("`@("!A<G)A>5]S:&EF="@D87!I<W1A=&5S*3L@+R\@<VYA
M<'-H;W0@:7,@;F]T(&%L;&]W960-"B`@("`@("`@:68@*"%I;E]A<G)A>2@D
M87!I<W1A8FEL:71Y+"`D87!I<W1A=&5S*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]A9&1&86EL=7)E*"=S=&%T92<L("=I;G9A;&ED($%022!S=&%B:6QI
M='D@(B<@+@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^
M9V5T4W1A=&4H)V%P:2<I("X@)R(L(&UU<W0@8F4@;VYE(&]F.B`G("X-"B`@
M("`@("`@("`@("`@("!I;7!L;V1E*"<L("<L("1A<&ES=&%T97,I*3L-"B`@
M("`@("`@("`@("1R970@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E4W5M
M;6%R>2@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('9A;&ED871E1&5S8W)I<'1I;VXH*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI
M9&%T94QI8V5N<V4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94YO=&5S*"D-"B`@("![#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(&9O<B!P86-K86=E+GAM;"`R+C`@;VYL>2`M(&-H86YN96QS(&-A;B=T('5S
M92!P86-K86=E+GAM;"`Q+C`-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E1&5P96YD96YC:65S*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(&9O<B!P86-K86=E+GAM;"`Q+C`@;VYL>0T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]V86QI9&%T
M949I;&5L:7-T*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.R`O+R!P
M;&%C96AO;&1E<B!F;W(@;F]W#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M9F]R('!A8VMA9V4N>&UL(#(N,"!O;FQY#0H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94UA:6Y&:6QE
M;&ES="@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L@+R\@<&QA8V5H
M;VQD97(@9F]R(&YO=PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(&9O<B!P
M86-K86=E+GAM;"`R+C`@;VYL>0T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5296QE87-E1FEL96QI
M<W0H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R=64[("\O('!L86-E:&]L
M9&5R(&9O<B!N;W<-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E0VAA
M;F=E;&]G*"D-"B`@("![#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@=F%L:61A=&5&:6QE;&ES="@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED
M871E1&5P<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]
M#0I]#0H_/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]834Q087)S97(N<&AP````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S0W,2`Q,#4Q-30S
M-#$S-"`P,C$U-3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]&5%`-"B`J#0H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`875T:&]R("`@("!3
M=&5P:&%N(%-C:&UI9'0@*&]R:6=I;F%L(%A-3%]5;G-E<FEA;&EZ97(@8V]D
M92D-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED
M.B!834Q087)S97(N<&AP+'8@,2XQ,2`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@4&%R<V5R
M(&9O<B!A;GD@>&UL(&9I;&4-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED
M="`H;W)I9VEN86P@6$U,7U5N<V5R:6%L:7IE<B!C;V1E*0T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?6$U,4&%R<V5R#0I[#0H@("`@+RHJ
M#0H@("`@("H@=6YS97)I;&EA;&EZ960@9&%T80T*("`@("`J($!V87(@<W1R
M:6YG("1?<V5R:6%L:7IE9$1A=&$-"B`@("`@*B\-"B`@("!V87(@)%]U;G-E
M<FEA;&EZ961$871A(#T@;G5L;#L-"@T*("`@("\J*@T*("`@("`J(&YA;64@
M;V8@=&AE(')O;W0@=&%G#0H@("`@("H@0'9A<B!S=')I;F<@)%]R;V]T#0H@
M("`@("HO#0H@("`@=F%R("1?<F]O="`](&YU;&P[#0H-"B`@("`O*BH-"B`@
M("`@*B!S=&%C:R!F;W(@86QL(&1A=&$@=&AA="!I<R!F;W5N9`T*("`@("`J
M($!V87(@87)R87D@("`@)%]D871A4W1A8VL-"B`@("`@*B\-"B`@("!V87(@
M)%]D871A4W1A8VL@(#T@("!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@
M<W1A8VL@9F]R(&%L;"!V86QU97,@=&AA="!A<F4@9V5N97)A=&5D#0H@("`@
M("H@0'9A<B!A<G)A>2`@("`D7W9A;%-T86-K#0H@("`@("HO#0H@("`@=F%R
M("1?=F%L4W1A8VL@(#T@("!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@
M8W5R<F5N="!T86<@9&5P=&@-"B`@("`@*B!`=F%R(&EN="`@("`D7V1E<'1H
M#0H@("`@("HO#0H@("`@=F%R("1?9&5P=&@@/2`P.PT*#0H@("`@+RHJ#0H@
M("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=$1A=&$H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=6YS97)I
M86QI>F5D1&%T83L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('AM;"!C;VYT96YT#0H@("`@("H@0')E='5R;B!T<G5E?%!%05)?
M17)R;W(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!P87)S92@D9&%T82D-"B`@
M("![#0H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@G>&UL)RDI('L-
M"B`@("`@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PT*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(EA-3"!%>'1E;G-I;VX@
M;F]T(&9O=6YD(BP@,2D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]V
M86Q3=&%C:R`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3Y?9&%T85-T86-K
M(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]D97!T:"`](#`[#0H-"B`@
M("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N
M,"<L("=L="<I*2![#0H@("`@("`@("`@("!I9B`H<W1R<&]S*"1D871A+"`G
M96YC;V1I;F<](E541BTX(B<I*2![#0H@("`@("`@("`@("`@("`@)&1A=&$@
M/2!U=&8X7V1E8V]D92@D9&%T82D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D>'`@/2!`>&UL7W!A<G-E<E]C<F5A=&4H)TE33RTX.#4Y+3$G*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("AS=')P;W,H)&1A
M=&$L("=E;F-O9&EN9STB551&+3@B)RDI('L-"B`@("`@("`@("`@("`@("`D
M>'`@/2!`>&UL7W!A<G-E<E]C<F5A=&4H)U541BTX)RD[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1X<"`]($!X;6Q?<&%R<V5R
M7V-R96%T92@G25-/+3@X-3DM,2<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D>'`L(%A-3%]/
M4%1)3TY?0T%315]&3TQ$24Y'+"`P*3L-"B`@("`@("`@>&UL7W-E=%]O8FIE
M8W0H)'AP+"`D=&AI<RD[#0H@("`@("`@('AM;%]S971?96QE;65N=%]H86YD
M;&5R*"1X<"P@)W-T87)T2&%N9&QE<B<L("=E;F1(86YD;&5R)RD[#0H@("`@
M("`@('AM;%]S971?8VAA<F%C=&5R7V1A=&%?:&%N9&QE<B@D>'`L("=C9&%T
M84AA;F1L97(G*3L-"B`@("`@("`@:68@*"%X;6Q?<&%R<V4H)'AP+"`D9&%T
M82DI('L-"B`@("`@("`@("`@("1M<V<@/2!X;6Q?97)R;W)?<W1R:6YG*'AM
M;%]G971?97)R;W)?8V]D92@D>'`I*3L-"B`@("`@("`@("`@("1L:6YE(#T@
M>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1X<"D[#0H@("`@("`@("`@
M("!X;6Q?<&%R<V5R7V9R964H)'AP*3L-"B`@("`@("`@("`@(&EN8VQU9&5?
M;VYC92`G4$5!4BYP:'`G.PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H(EA-3"!%<G)O<CH@)R1M<V<G(&]N(&QI;F4@)R1L:6YE)R(L
M(#(I.PT*("`@("`@("!]#0H@("`@("`@('AM;%]P87)S97)?9G)E92@D>'`I
M.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!3=&%R="!E;&5M96YT(&AA;F1L97(@9F]R(%A-3"!P87)S97(-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!P87)A;2`@
M;V)J96-T("1P87)S97(@(%A-3"!P87)S97(@;V)J96-T#0H@("`@("H@0'!A
M<F%M("!S=')I;F<@)&5L96UE;G0@6$U,(&5L96UE;G0-"B`@("`@*B!`<&%R
M86T@(&%R<F%Y("`D871T<FEB<R!A='1R:6)U=&5S(&]F(%A-3"!T86<-"B`@
M("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%R
M=$AA;F1L97(H)'!A<G-E<BP@)&5L96UE;G0L("1A='1R:6)S*0T*("`@('L-
M"B`@("`@("`@)'1Y<&4@/2`G<W1R:6YG)SL-"@T*("`@("`@("`D=&AI<RT^
M7V1E<'1H*RL[#0H@("`@("`@("1T:&ES+3Y?9&%T85-T86-K6R1T:&ES+3Y?
M9&5P=&A=(#T@;G5L;#L-"@T*("`@("`@("`D=F%L(#T@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("`G;F%M92<@("`@("`@("`]/B`D96QE;65N="P-
M"B`@("`@("`@("`@("`@("`@("`@("=V86QU92<@("`@("`@(#T^(&YU;&PL
M#0H@("`@("`@("`@("`@("`@("`@("`G='EP92<@("`@("`@("`]/B`D='EP
M92P-"B`@("`@("`@("`@("`@("`@("`@("=C:&EL9')E;DME>7,G(#T^(&%R
M<F%Y*"DL#0H@("`@("`@("`@("`@("`@("`@("`G86=G<F5G2V5Y<R<@("`]
M/B!A<G)A>2@I#0H@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("`@("`@
M:68@*&-O=6YT*"1A='1R:6)S*2`^(#`I('L-"B`@("`@("`@("`@("1V86Q;
M)V-H:6QD<F5N)UT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)'9A;%LG='EP
M92==(#T@)V%R<F%Y)SL-"@T*("`@("`@("`@("`@)'9A;%LG8VAI;&1R96XG
M75LG871T<FEB<R==(#T@)&%T=')I8G,[#0H-"B`@("`@("`@?0T*#0H@("`@
M("`@(&%R<F%Y7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@)'9A;"D[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@<&]S="UP<F]C97-S(&1A=&$-"B`@("`@
M*@T*("`@("`J($!P87)A;2!S=')I;F<@)&1A=&$-"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1E;&5M96YT(&5L96UE;G0@;F%M90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('!O<W10<F]C97-S*"1D871A+"`D96QE;65N="D-"B`@("![#0H@
M("`@("`@(')E='5R;B!T<FEM*"1D871A*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!%;F0@96QE;65N="!H86YD;&5R(&9O<B!834P@<&%R<V5R#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B!`<&%R86T@
M(&]B:F5C="!834P@<&%R<V5R(&]B:F5C=`T*("`@("`J($!P87)A;2`@<W1R
M:6YG#0H@("`@("H@0')E='5R;B!V;VED#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@96YD2&%N9&QE<B@D<&%R<V5R+"`D96QE;65N="D-"B`@("![#0H@("`@
M("`@("1V86QU92`](&%R<F%Y7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L-"B`@
M("`@("`@)&1A=&$@(#T@)'1H:7,M/G!O<W10<F]C97-S*"1T:&ES+3Y?9&%T
M85-T86-K6R1T:&ES+3Y?9&5P=&A=+"`D96QE;65N="D[#0H-"B`@("`@("`@
M+R\@861J=7-T('1Y<&4@;V8@=&AE('9A;'5E#0H@("`@("`@('-W:71C:"AS
M=')T;VQO=V5R*"1V86QU95LG='EP92==*2D@>PT*#0H@("`@("`@("`@("`O
M*@T*("`@("`@("`@("`@("H@=6YS97)I86QI>F4@86X@87)R87D-"B`@("`@
M("`@("`@("`J+PT*("`@("`@("`@("`@8V%S92`G87)R87DG.@T*("`@("`@
M("`@("`@("`@(&EF("@D9&%T82`A/3T@)R<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'9A;'5E6R=C:&EL9')E;B==6R=?8V]N=&5N="==(#T@)&1A=&$[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=F%L=65;)V-H:6QD<F5N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1V86QU95LG=F%L=64G72`]("1V86QU95LG8VAI;&1R96XG73L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=F%L
M=65;)W9A;'5E)UT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@("`@("`@+RH-"B`@("`@
M("`@("`@("`J('5N<V5R:6%L:7IE(&$@;G5L;"!V86QU90T*("`@("`@("`@
M("`@("HO#0H@("`@("`@("`@("!C87-E("=N=6QL)SH-"B`@("`@("`@("`@
M("`@("`D9&%T82`](&YU;&P[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-
M"B`@("`@("`@("`@("\J#0H@("`@("`@("`@("`@*B!U;G-E<FEA;&EZ92!A
M;GD@<V-A;&%R('9A;'5E#0H@("`@("`@("`@("`@*B\-"B`@("`@("`@("`@
M(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@<V5T='EP92@D9&%T82P@)'9A
M;'5E6R=T>7!E)UTI.PT*("`@("`@("`@("`@("`@("1V86QU95LG=F%L=64G
M72`]("1D871A.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]
M#0H@("`@("`@("1P87)E;G0@/2!A<G)A>5]P;W`H)'1H:7,M/E]V86Q3=&%C
M:RD[#0H@("`@("`@(&EF("@D<&%R96YT(#T]/2!N=6QL*2![#0H@("`@("`@
M("`@("`D=&AI<RT^7W5N<V5R:6%L:7IE9$1A=&$@/2`F)'9A;'5E6R=V86QU
M92==.PT*("`@("`@("`@("`@)'1H:7,M/E]R;V]T(#T@)B1V86QU95LG;F%M
M92==.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`O+R!P87)E;G0@:&%S('1O(&)E(&%N(&%R<F%Y
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)E;G1;)V-H:6QD<F5N)UTI
M('Q\("%I<U]A<G)A>2@D<&%R96YT6R=C:&EL9')E;B==*2D@>PT*("`@("`@
M("`@("`@("`@("1P87)E;G1;)V-H:6QD<F5N)UT@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@("`@(&EF("@D<&%R96YT6R=T>7!E)UT@(3T@)V%R<F%Y)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D<&%R96YT6R=T>7!E)UT@/2`G87)R
M87DG.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@:68@*"%E;7!T>2@D=F%L=65;)VYA;64G72DI('L-"B`@("`@
M("`@("`@("`@("`O+R!T:&5R92!A;')E861Y(&AA<R!B965N(&$@=&%G('=I
M=&@@=&AI<R!N86UE#0H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V
M86QU95LG;F%M92==+"`D<&%R96YT6R=C:&EL9')E;DME>7,G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@+R\@;F\@86=G<F5G871E(&AA<R!B965N(&-R
M96%T960@9F]R('1H:7,@=&%G#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:6Y?87)R87DH)'9A;'5E6R=N86UE)UTL("1P87)E;G1;)V%G9W)E9TME>7,G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%R
M96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R96YT6R=C:&EL9')E;B==6R1V86QU
M95LG;F%M92==72`](&%R<F%Y*"1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E
M6R=N86UE)UU=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N=%LG8VAI;&1R
M96XG75LD=F%L=65;)VYA;64G75T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M<'5S:"@D<&%R96YT6R=A9V=R96=+97ES)UTL("1V86QU95LG;F%M92==*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!A
M<G)A>5]P=7-H*"1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N86UE)UU=
M+"`D=F%L=65;)W9A;'5E)UTI.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1P87)E;G1;)V-H:6QD<F5N)UU;)'9A
M;'5E6R=N86UE)UU=(#T@)B1V86QU95LG=F%L=64G73L-"B`@("`@("`@("`@
M("`@("`@("`@87)R87E?<'5S:"@D<&%R96YT6R=C:&EL9')E;DME>7,G72P@
M)'9A;'5E6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D<&%R
M96YT6R=C:&EL9')E;B==+"1V86QU95LG=F%L=64G72D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?=F%L4W1A8VLL
M("1P87)E;G0I.PT*("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M/E]D97!T
M:"TM.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($AA;F1L97(@9F]R(&-H
M87)A8W1E<B!D871A#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B!`<&%R86T@(&]B:F5C="!834P@<&%R<V5R(&]B:F5C=`T*("`@
M("`J($!P87)A;2`@<W1R:6YG($-$051!#0H@("`@("H@0')E='5R;B!V;VED
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8V1A=&%(86YD;&5R*"1P87)S97(L
M("1C9&%T82D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?9&%T85-T86-K6R1T
M:&ES+3Y?9&5P=&A=("X]("1C9&%T83L-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M0G5I;&1E<BYP:'``````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,S4R-S<@,3`U,34T,S0Q,S0@,#(Q,S(V`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%
M05)?0G5I;&1E<B!F;W(@8G5I;&1I;F<@4$A0(&5X=&5N<VEO;G,@*%!%0TP@
M<&%C:V%G97,I#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T
M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z
M($)U:6QD97(N<&AP+'8@,2XR-R`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO
M9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"@T*+RHJ#0H@*B!.965D960@9F]R(&5X
M=&5N9&EN9R!014%27T)U:6QD97(-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2
M+T-O;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE
M+G!H<"<[#0HO*BH-"B`J($-L87-S('1O(&AA;F1L92!B=6EL9&EN9R`H8V]M
M<&EL:6YG*2!E>'1E;G-I;VYS+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA
M<W,@879A:6QA8FQE('-I;F-E(%!(4"`T+C`N,@T*("H@0'-E92`@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO8V]R92YP<&TN<&5A<BUB
M=6EL9&5R+G!H<`T*("HO#0IC;&%S<R!014%27T)U:6QD97(@97AT96YD<R!0
M14%27T-O;6UO;@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("!V
M87(@)'!H<%]A<&E?=F5R<VEO;B`](#`[#0H@("`@=F%R("1Z96YD7VUO9'5L
M95]A<&E?;F\@/2`P.PT*("`@('9A<B`D>F5N9%]E>'1E;G-I;VY?87!I7VYO
M(#T@,#L-"@T*("`@('9A<B`D97AT96YS:6]N<U]B=6EL="`](&%R<F%Y*"D[
M#0H-"B`@("!V87(@)&-U<G)E;G1?8V%L;&)A8VL@/2!N=6QL.PT*#0H@("`@
M+R\@=7-E9"!F;W(@;7-D978@8G5I;&1S#0H@("`@=F%R("1?;&%S=&QI;F4@
M/2!N=6QL.PT*("`@('9A<B`D7V9I<G-T;&EN92`](&YU;&P[#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@
M*B!014%27T)U:6QD97(@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@;V)J96-T("1U:2!U<V5R(&EN=&5R9F%C92!O8FIE8W0@*&EN<W1A
M;F-E(&]F(%!%05)?1G)O;G1E;F1?*BD-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]"=6EL9&5R
M*"8D=6DI#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6]N*"D[
M#0H@("`@("`@("1T:&ES+3YS971&<F]N=&5N9$]B:F5C="@D=6DI.PT*("`@
M('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]B=6EL9%]W:6XS,B@I
M#0H-"B`@("`O*BH-"B`@("`@*B!"=6EL9"!A;B!E>'1E;G-I;VX@9G)O;2!S
M;W5R8V4@;VX@=VEN9&]W<RX-"B`@("`@*B!R97%U:7)E<R!M<V1E=@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]B=6EL9%]W:6XS,B@D9&5S8V9I;&4L("1C
M86QL8F%C:R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T
M*"1D97-C9FEL92DI('L-"B`@("`@("`@("`@("1P:V<@/2`D9&5S8V9I;&4[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<&8@/2`F;F5W(%!%
M05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/F1E8G5G*3L-
M"B`@("`@("`@("`@("1P:V<@/2`F)'!F+3YF<F]M4&%C:V%G949I;&4H)&1E
M<V-F:6QE+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<&MG*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D<&MG.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1D:7(@/2!D:7)N86UE*"1P:V<M/F=E=$%R8VAI=F5&:6QE*"DI.PT*("`@
M("`@("`D;VQD7V-W9"`](&=E=&-W9"@I.PT*#0H@("`@("`@(&EF("@A0&-H
M9&ER*"1D:7(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F-O=6QD(&YO="!C:&1I<B!T;R`D9&ER(BD[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/FQO9R@R+"`B8G5I;&1I;F<@:6X@)&1I<B(I.PT*
M#0H@("`@("`@("1D<W`@/2`D<&MG+3YG971086-K86=E*"DN)RYD<W`G.PT*
M("`@("`@("!I9B`H(4!I<U]F:6QE*"(D9&ER+R1D<W`B*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")4:&4@1%-0("1D<W`@
M9&]E<R!N;W0@97AI<W0N(BD[#0H@("`@("`@('T-"B`@("`@("`@+R\@6%A8
M(%1/1$\Z(&UA:V4@<F5L96%S92!B=6EL9"!T>7!E(&-O;F9I9W5R86)L90T*
M("`@("`@("`D8V]M;6%N9"`]("=M<V1E=B`G+B1D<W`N)R`O34%+12`B)RXD
M:6YF;ULG<&%C:V%G92==+B`G("T@4F5L96%S92(G.PT*#0H@("`@("`@("1T
M:&ES+3YC=7)R96YT7V-A;&QB86-K(#T@)&-A;&QB86-K.PT*("`@("`@("`D
M97)R(#T@)'1H:7,M/E]R=6Y#;VUM86YD*"1C;VUM86YD+"!A<G)A>2@F)'1H
M:7,L("=M<V1E=D-A;&QB86-K)RDI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R!F:6=U<F4@;W5T('1H92!B=6EL9"!P;&%T
M9F]R;2!A;F0@='EP90T*("`@("`@("`D<&QA=&9O<FT@/2`G5VEN,S(G.PT*
M("`@("`@("`D8G5I;&1T>7!E(#T@)U)E;&5A<V4G.PT*("`@("`@("!I9B`H
M<')E9U]M871C:"@G+RXJ/R<N)'!K9RT^9V5T4&%C:V%G92@I+B=<<RU<<RA<
M=RLI7',H+BH_*2TK+VDG+"1T:&ES+3Y?9FER<W1L:6YE+"1M871C:&5S*2D@
M>PT*("`@("`@("`@("`@)'!L871F;W)M(#T@)&UA=&-H97-;,5T[#0H@("`@
M("`@("`@("`D8G5I;&1T>7!E(#T@)&UA=&-H97-;,ET[#0H@("`@("`@('T-
M"@T*("`@("`@("!I9B`H<')E9U]M871C:"@G+R@N*BD_7',M7',H7&0K*2XJ
M/RA<9"LI+R<L)'1H:7,M/E]L87-T;&EN92PD;6%T8VAE<RDI('L-"B`@("`@
M("`@("`@(&EF("@D;6%T8VAE<ULR72D@>PT*("`@("`@("`@("`@("`@("\O
M('1H97)E('=E<F4@97)R;W)S(&EN('1H92!B=6EL9`T*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B5&AE<F4@=V5R92!E<G)O
M<G,@9'5R:6YG(&-O;7!I;&%T:6]N+B(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&]U="`]("1M871C:&5S6S%=.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$:60@
M;F]T('5N9&5R<W1A;F0@=&AE(&-O;7!L971I;VX@<W1A='5S(')E='5R;F5D
M(&9R;VT@;7-D978N97AE+B(I.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@
M;7-D978@9&]E<VXG="!T96QL('5S('1H92!O=71P=70@9&ER96-T;W)Y(#HO
M#0H@("`@("`@("\O(&]P96X@=&AE(&1S<"P@9FEN9"`O;W5T(&%N9"!U<V4@
M=&AA="!D:7)E8W1O<GD-"B`@("`@("`@)&1S<'1E>'0@/2!J;VEN*&9I;&4H
M)&1S<"DL)R<I.PT*#0H@("`@("`@("\O('1H:7,@<F5G97@@9&5P96YD<R!O
M;B!T:&4@8G5I;&0@<&QA=&9O<FT@86YD('1Y<&4@:&%V:6YG(&)E96X-"B`@
M("`@("`@+R\@8V]R<F5C=&QY(&ED96YT:69I960@86)O=F4N#0H@("`@("`@
M("1R96=E>"`])R\N*C\A249<<RLB7"1<*$-&1UPI(EQS*ST]7',K*"(G+@T*
M("`@("`@("`@("`@("`@("`@("`D<&MG+3YG971086-K86=E*"DN)UQS+5QS
M)RX-"B`@("`@("`@("`@("`@("`@("`@)'!L871F;W)M+B=<<R<N#0H@("`@
M("`@("`@("`@("`@("`@("1B=6EL9'1Y<&4N)R(I+BH_)RX-"B`@("`@("`@
M("`@("`@("`@("`@)UPO;W5T.B(H+BH_*2(O:7,G.PT*#0H@("`@("`@(&EF
M("@D9'-P=&5X="`F)B!P<F5G7VUA=&-H*"1R96=E>"PD9'-P=&5X="PD;6%T
M8VAE<RDI('L-"B`@("`@("`@("`@("\O('=H870@=V4@9V5T(&)A8VL@:7,@
M82!R96QA=&EV92!P871H('1O('1H92!O=71P=70@9FEL92!I='-E;&8N#0H@
M("`@("`@("`@("`D;W5T9FEL92`](')E86QP871H*"1M871C:&5S6S)=*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B0V]U;&0@;F]T(')E=')I979E(&]U='!U="!I;F9O<FUA
M=&EO;B!F<F]M("1D<W`N(BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*$!C
M;W!Y*"1O=71F:6QE+"`B)&1I<B\D;W5T(BDI('L-"B`@("`@("`@("`@("1O
M=71F:6QE(#T@(B1D:7(O)&]U="([#0H@("`@("`@('T-"@T*("`@("`@("`D
M8G5I;'1?9FEL97-;72`](&%R<F%Y*`T*("`@("`@("`@("`@)V9I;&4G(#T^
M("(D;W5T9FEL92(L#0H@("`@("`@("`@("`G<&AP7V%P:2<@/3X@)'1H:7,M
M/G!H<%]A<&E?=F5R<VEO;BP-"B`@("`@("`@("`@("=Z96YD7VUO9%]A<&DG
M(#T^("1T:&ES+3YZ96YD7VUO9'5L95]A<&E?;F\L#0H@("`@("`@("`@("`G
M>F5N9%]E>'1?87!I)R`]/B`D=&AI<RT^>F5N9%]E>'1E;G-I;VY?87!I7VYO
M+`T*("`@("`@("`@("`@*3L-"@T*("`@("`@("!R971U<FX@)&)U:6QT7V9I
M;&5S.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!M<V1E=D-A
M;&QB86-K*"D-"B`@("!F=6YC=&EO;B!M<V1E=D-A;&QB86-K*"1W:&%T+"`D
M9&%T82D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]F:7)S=&QI;F4I
M#0H@("`@("`@("`@("`D=&AI<RT^7V9I<G-T;&EN92`]("1D871A.PT*("`@
M("`@("`D=&AI<RT^7VQA<W1L:6YE(#T@)&1A=&$[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]H87)V96YT26YS=$1I<@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7VAA<G9E<W1);G-T1&ER*"1D97-T7W!R
M969I>"P@)&1I<FYA;64L("8D8G5I;'1?9FEL97,I#0H@("`@>PT*("`@("`@
M("`D9"`](&]P96YD:7(H)&1I<FYA;64I.PT*("`@("`@("!I9B`H(21D*0T*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*#0H@("`@("`@("1R970@/2!T
M<G5E.PT*("`@("`@("!W:&EL92`H*"1E;G0@/2!R96%D9&ER*"1D*2D@(3T]
M(&9A;'-E*2![#0H@("`@("`@("`@("!I9B`H)&5N='LP?2`]/2`G+B<I#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H-"B`@("`@("`@("`@("1F=6QL
M(#T@)&1I<FYA;64@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&5N=#L-"B`@
M("`@("`@("`@(&EF("AI<U]D:7(H)&9U;&PI*2![#0H@("`@("`@("`@("`@
M("`@:68@*"$D=&AI<RT^7VAA<G9E<W1);G-T1&ER*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<W1?<')E9FEX("X@1$E214-43U)97U-%4$%2051/
M4B`N("1E;G0L#0H@("`@("`@("`@("`@("`@("`@("`@("`D9G5L;"P@)&)U
M:6QT7V9I;&5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M)&1E<W0@/2`D9&5S=%]P<F5F:7@@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)&5N=#L-"B`@("`@("`@("`@("`@("`D8G5I;'1?9FEL97-;72`](&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("1F=6QL+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@)V1E<W0G(#T^("1D97-T+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)W!H<%]A<&DG(#T^("1T:&ES+3YP:'!?
M87!I7W9E<G-I;VXL#0H@("`@("`@("`@("`@("`@("`@("`@("`G>F5N9%]M
M;V1?87!I)R`]/B`D=&AI<RT^>F5N9%]M;V1U;&5?87!I7VYO+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@)WIE;F1?97AT7V%P:2<@/3X@)'1H:7,M/GIE
M;F1?97AT96YS:6]N7V%P:5]N;RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@8VQO<V5D
M:7(H)&0I.PT*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!B=6EL9"@I#0H-"B`@("`O*BH-"B`@("`@
M*B!"=6EL9"!A;B!E>'1E;G-I;VX@9G)O;2!S;W5R8V4N("!2=6YS(")P:'!I
M>F4B(&EN('1H92!S;W5R8V4-"B`@("`@*B!D:7)E8W1O<GDL(&)U="!C;VUP
M:6QE<R!I;B!A('1E;7!O<F%R>2!D:7)E8W1O<GD-"B`@("`@*B`H+W9A<B]T
M;7`O<&5A<BUB=6EL9"U54T52+U!!0TM!1T4M5D524TE/3BDN#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?%!%05)?4&%C:V%G949I;&5?=BH@)&1E
M<V-F:6QE('!A=&@@=&\@6$U,('!A8VMA9V4@9&5S8W)I<'1I;VX@9FEL92P@
M;W(-"B`@("`@*B`@("`@("`@("`@("`@(&$@4$5!4E]086-K86=E1FEL92!O
M8FIE8W0-"B`@("`@*@T*("`@("`J($!P87)A;2!M:7AE9"`D8V%L;&)A8VL@
M8V%L;&)A8VL@9G5N8W1I;VX@=7-E9"!T;R!R97!O<G0@;W5T<'5T+`T*("`@
M("`J('-E92!014%27T)U:6QD97(Z.E]R=6Y#;VUM86YD(&9O<B!D971A:6QS
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y(&%N(&%R<F%Y(&]F(&%S
M<V]C:6%T:79E(&%R<F%Y<R!W:71H(&)U:6QT(&9I;&5S+`T*("`@("`J(&9O
M<FUA=#H-"B`@("`@*B!A<G)A>2@@87)R87DH("=F:6QE)R`]/B`G+W!A=&@O
M=&\O97AT+G-O)RP-"B`@("`@*B`@("`@("`@("`@("`@("=P:'!?87!I)R`]
M/B!965E934U$1"P-"B`@("`@*B`@("`@("`@("`@("`@("=Z96YD7VUO9%]A
M<&DG(#T^(%E965E-341$+`T*("`@("`J("`@("`@("`@("`@("`@)WIE;F1?
M97AT7V%P:2<@/3X@65E964U-1$0@*2P-"B`@("`@*B`@("`@("`@+BXN("D-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@
M*B!`<V5E(%!%05)?0G5I;&1E<CHZ7W)U;D-O;6UA;F0-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!B=6EL9"@D9&5S8V9I;&4L("1C86QL8F%C:R`](&YU;&PI
M#0H@("`@>PT*("`@("`@("!I9B`H4$5!4E]/4R`]/2`B5VEN9&]W<R(I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V)U:6QD7W=I;C,R*"1D97-C
M9FEL92PD8V%L;&)A8VLI.PT*("`@("`@("!]#0H@("`@("`@(&EF("A014%2
M7T]3("$]("=5;FEX)RD@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*")B=6EL9&EN9R!E>'1E;G-I;VYS(&YO="!S=7!P;W)T960@
M;VX@=&AI<R!P;&%T9F]R;2(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<U]O8FIE8W0H)&1E<V-F:6QE*2D@>PT*("`@("`@("`@("`@)'!K9R`]("1D
M97-C9FEL93L-"B`@("`@("`@("`@("1D97-C9FEL92`]("1P:V<M/F=E=%!A
M8VMA9V5&:6QE*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<&8@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RD[#0H@
M("`@("`@("`@("`D<&MG(#T@)B1P9BT^9G)O;5!A8VMA9V5&:6QE*"1D97-C
M9FEL92P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'!K9RDI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)'!K9SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M9&ER(#T@9&ER;F%M92@D9&5S8V9I;&4I.PT*("`@("`@("`D;VQD7V-W9"`]
M(&=E=&-W9"@I.PT*("`@("`@("!I9B`H(4!C:&1I<B@D9&ER*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@
M8VAD:7(@=&\@)&1I<B(I.PT*("`@("`@("!]#0H@("`@("`@("1V9&ER(#T@
M)'!K9RT^9V5T4&%C:V%G92@I("X@)RTG("X@)'!K9RT^9V5T5F5R<VEO;B@I
M.PT*("`@("`@("!I9B`H:7-?9&ER*"1V9&ER*2D@>PT*("`@("`@("`@("`@
M8VAD:7(H)'9D:7(I.PT*("`@("`@("!]#0H@("`@("`@("1D:7(@/2!G971C
M=V0H*3L-"B`@("`@("`@)'1H:7,M/FQO9R@R+"`B8G5I;&1I;F<@:6X@)&1I
M<B(I.PT*("`@("`@("`D=&AI<RT^8W5R<F5N=%]C86QL8F%C:R`]("1C86QL
M8F%C:SL-"B`@("`@("`@<'5T96YV*"=0051(/2<@+B`D=&AI<RT^8V]N9FEG
M+3YG970H)V)I;E]D:7(G*2`N("<Z)R`N(&=E=&5N=B@G4$%42"<I*3L-"B`@
M("`@("`@)&5R<B`]("1T:&ES+3Y?<G5N0V]M;6%N9"@B<&AP:7IE(BP@87)R
M87DH)B1T:&ES+"`G<&AP:7IE0V%L;&)A8VLG*2D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E<G(I*2![#0H@("`@("`@("`@("!R971U<FX@)&5R
M<CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21E<G(I('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8'!H<&EZ92<@9F%I;&5D
M(BD[#0H@("`@("`@('T-"@T*("`@("`@("`O+R![>WL@<W1A<G0@;V8@:6YT
M97)A8W1I=F4@<&%R=`T*("`@("`@("`D8V]N9FEG=7)E7V-O;6UA;F0@/2`B
M)&1I<B]C;VYF:6=U<F4B.PT*("`@("`@("`D8V]N9FEG=7)E7V]P=&EO;G,@
M/2`D<&MG+3YG971#;VYF:6=U<F5/<'1I;VYS*"D[#0H@("`@("`@(&EF("@D
M8V]N9FEG=7)E7V]P=&EO;G,I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C
M;VYF:6=U<F5?;W!T:6]N<R!A<R`D;RD@>PT*("`@("`@("`@("`@("`@(&QI
M<W0H)'(I(#T@)'1H:7,M/G5I+3YU<V5R1&EA;&]G*"=B=6EL9"<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)&];)W!R;VUP="==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&5X="<I+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*$`D;ULG9&5F875L="==*2D[#0H@("`@("`@("`@("`@("`@:68@
M*'-U8G-T<B@D;ULG;F%M92==+"`P+"`U*2`]/2`G=VET:"TG("8F#0H@("`@
M("`@("`@("`@("`@("`@("@D<B`]/2`G>65S)R!\?"`D<B`]/2`G875T;V1E
M=&5C="<I*2![#0H@("`@("`@("`@("`@("`@("`@("1C;VYF:6=U<F5?8V]M
M;6%N9"`N/2`B("TM)&];;F%M95TB.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1C;VYF:6=U<F5?8V]M;6%N9"`N
M/2`B("TM)&];;F%M95T](BYT<FEM*"1R*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@+R\@?7U](&5N
M9"!O9B!I;G1E<F%C=&EV92!P87)T#0H-"B`@("`@("`@+R\@1DE8344@;6%K
M92!C;VYF:6=U<F%B;&4-"B`@("`@("`@:68H(21U<V5R/6=E=&5N=B@G55-%
M4B<I*7L-"B`@("`@("`@("`@("1U<V5R/2=D969A=6QT=7-E<B<[#0H@("`@
M("`@('T-"B`@("`@("`@)&)U:6QD7V)A<V5D:7(@/2`B+W9A<B]T;7`O<&5A
M<BUB=6EL9"TD=7-E<B([#0H@("`@("`@("1B=6EL9%]D:7(@/2`B)&)U:6QD
M7V)A<V5D:7(O)'9D:7(B.PT*("`@("`@("`D:6YS=%]D:7(@/2`B)&)U:6QD
M7V)A<V5D:7(O:6YS=&%L;"TD=F1I<B([#0H@("`@("`@("1T:&ES+3YL;V<H
M,2P@(F)U:6QD:6YG(&EN("1B=6EL9%]D:7(B*3L-"B`@("`@("`@:68@*&ES
M7V1I<B@D8G5I;&1?9&ER*2D@>PT*("`@("`@("`@("`@4WES=&5M.CIR;2AA
M<G)A>2@G+7)F)RP@)&)U:6QD7V1I<BDI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A4WES=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D8G5I;&1?9&ER*2DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U
M;&0@;F]T(&-R96%T92!B=6EL9"!D:7(Z("1B=6EL9%]D:7(B*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^861D5&5M<$9I;&4H)&)U:6QD7V1I<BD[
M#0H@("`@("`@(&EF("@A4WES=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D:6YS
M=%]D:7(I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*")C;W5L9"!N;W0@8W)E871E('1E;7!O<F%R>2!I;G-T86QL(&1I<CH@
M)&EN<W1?9&ER(BD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F%D9%1E
M;7!&:6QE*"1I;G-T7V1I<BD[#0H-"B`@("`@("`@:68@*&=E=&5N=B@G34%+
M12<I*2![#0H@("`@("`@("`@("`D;6%K95]C;VUM86YD(#T@9V5T96YV*"=-
M04M%)RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;6%K95]C
M;VUM86YD(#T@)VUA:V4G.PT*("`@("`@("!]#0H@("`@("`@("1T;U]R=6X@
M/2!A<G)A>2@-"B`@("`@("`@("`@("1C;VYF:6=U<F5?8V]M;6%N9"P-"B`@
M("`@("`@("`@("1M86ME7V-O;6UA;F0L#0H@("`@("`@("`@("`B)&UA:V5?
M8V]M;6%N9"!)3E-404Q,7U)/3U0]7"(D:6YS=%]D:7)<(B!I;G-T86QL(BP-
M"B`@("`@("`@("`@(")F:6YD(%PB)&EN<W1?9&ER7"(@+6QS(@T*("`@("`@
M("`@("`@*3L-"B`@("`@("`@:68@*"%`8VAD:7(H)&)U:6QD7V1I<BDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@
M;F]T(&-H9&ER('1O("1B=6EL9%]D:7(B*3L-"B`@("`@("`@?0T*("`@("`@
M("!P=71E;G8H)U!(4%]014%27U9%4E-)3TX],2XT+CDG*3L-"B`@("`@("`@
M9F]R96%C:"`H)'1O7W)U;B!A<R`D8VUD*2![#0H@("`@("`@("`@("`D97)R
M(#T@)'1H:7,M/E]R=6Y#;VUM86YD*"1C;60L("1C86QL8F%C:RD[#0H@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@
M("`@("`@(&-H9&ER*"1O;&1?8W=D*3L-"B`@("`@("`@("`@("`@("!R971U
M<FX@)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A)&5R
M<BD@>PT*("`@("`@("`@("`@("`@(&-H9&ER*"1O;&1?8W=D*3L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F`D8VUD)R!F
M86EL960B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(2@D9'`@/2!O<&5N9&ER*")M;V1U;&5S(BDI*2![#0H@("`@("`@("`@
M("!C:&1I<B@D;VQD7V-W9"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(FYO(&!M;V1U;&5S)R!D:7)E8W1O<GD@9F]U;F0B*3L-
M"B`@("`@("`@?0T*("`@("`@("`D8G5I;'1?9FEL97,@/2!A<G)A>2@I.PT*
M("`@("`@("`D<')E9FEX(#T@97AE8R@B<&AP+6-O;F9I9R`M+7!R969I>"(I
M.PT*("`@("`@("`D=&AI<RT^7VAA<G9E<W1);G-T1&ER*"1P<F5F:7@L("1I
M;G-T7V1I<B`N($1)4D5#5$]265]315!!4D%43U(@+B`D<')E9FEX+"`D8G5I
M;'1?9FEL97,I.PT*("`@("`@("!C:&1I<B@D;VQD7V-W9"D[#0H@("`@("`@
M(')E='5R;B`D8G5I;'1?9FEL97,[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[('!H<&EZ94-A;&QB86-K*"D-"@T*("`@("\J*@T*("`@("`J
M($UE<W-A9V4@8V%L;&)A8VL@9G5N8W1I;VX@=7-E9"!W:&5N(')U;FYI;F<@
M=&AE(")P:'!I>F4B#0H@("`@("H@<')O9W)A;2X@($5X=')A8W1S('1H92!!
M4$D@;G5M8F5R<R!U<V5D+B`@26=N;W)E<R!O=&AE<B!M97-S86=E#0H@("`@
M("H@='EP97,@=&AA;B`B8VUD;W5T<'5T(BX-"B`@("`@*@T*("`@("`J($!P
M87)A;2!S=')I;F<@)'=H870@=&AE('1Y<&4@;V8@;65S<V%G90T*("`@("`J
M($!P87)A;2!M:7AE9"`D9&%T82!T:&4@;65S<V%G90T*("`@("`J#0H@("`@
M("H@0')E='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('!H<&EZ94-A;&QB86-K*"1W:&%T
M+"`D9&%T82D-"B`@("![#0H@("`@("`@(&EF("@D=VAA="`A/2`G8VUD;W5T
M<'5T)RD@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3YL;V<H,2P@<G1R:6TH)&1A=&$I*3L-"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]9;W4@<VAO=6QD('5P9&%T92!Y;W5R("YA8VQO8V%L
M+FTT+R<L("1D871A*2D@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@
M("!]#0H@("`@("`@("1M871C:&5S(#T@87)R87DH*3L-"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H)R]>7',K*%Q36UXZ72LI.EQS*RA<9'LX?2DO)RP@)&1A
M=&$L("1M871C:&5S*2D@>PT*("`@("`@("`@("`@)&UE;6)E<B`]('!R96=?
M<F5P;&%C92@G+UM>82UZ72\G+"`G7R<L('-T<G1O;&]W97(H)&UA=&-H97-;
M,5TI*3L-"B`@("`@("`@("`@("1A<&EN;R`]("AI;G0I)&UA=&-H97-;,ET[
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/B1M96UB97(I*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/B1M96UB97(@/2`D87!I;F\[#0H@("`@
M("`@("`@("`@("`@+R\D;7-G(#T@<W!R:6YT9B@B)2TR,G,@.B`E9"(L("1M
M871C:&5S6S%=+"`D87!I;F\I.PT*("`@("`@("`@("`@("`@("\O)'1H:7,M
M/FQO9R@Q+"`D;7-G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?<G5N0V]M;6%N9"@I#0H-
M"B`@("`O*BH-"B`@("`@*B!2=6X@86X@97AT97)N86P@8V]M;6%N9"P@=7-I
M;F<@82!M97-S86=E(&-A;&QB86-K('1O(')E<&]R=`T*("`@("`J(&]U='!U
M="X@(%1H92!C;VUM86YD('=I;&P@8F4@<G5N('1H<F]U9V@@<&]P96X@86YD
M(&]U='!U="!I<PT*("`@("`J(')E<&]R=&5D(&9O<B!E=F5R>2!L:6YE('=I
M=&@@82`B8VUD;W5T<'5T(B!M97-S86=E('=I=&@@=&AE#0H@("`@("H@;&EN
M92!S=')I;F<L(&EN8VQU9&EN9R!N97=L:6YE<RP@87,@<&%Y;&]A9"X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA;F0@=&AE(&-O;6UA
M;F0@=&\@<G5N#0H@("`@("H-"B`@("`@*B!`<&%R86T@;6EX960@)&-A;&QB
M86-K("AO<'1I;VYA;"D@9G5N8W1I;VX@=&\@=7-E(&%S(&UE<W-A9V4-"B`@
M("`@*B!C86QL8F%C:PT*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L('=H
M971H97(@=&AE(&-O;6UA;F0@=V%S('-U8V-E<W-F=6P@*&5X:70@8V]D92`P
M#0H@("`@("H@;65A;G,@<W5C8V5S<RP@86YY(&]T:&5R(&UE86YS(&9A:6QU
M<F4I#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?<G5N0V]M;6%N9"@D8V]M;6%N9"P@)&-A;&QB86-K
M(#T@;G5L;"D-"B`@("![#0H@("`@("`@("1T:&ES+3YL;V<H,2P@(G)U;FYI
M;F<Z("1C;VUM86YD(BD[#0H@("`@("`@("1P<"`]($!P;W!E;B@B)&-O;6UA
M;F0@,CXF,2(L(")R(BD[#0H@("`@("`@(&EF("@A)'!P*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F9A:6QE9"!T;R!R=6X@
M8"1C;VUM86YD)R(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D8V%L;&)A
M8VL@)B8@)&-A;&QB86-K6S!=+3YD96)U9R`]/2`Q*2![#0H@("`@("`@("`@
M("`D;VQD9&)G(#T@)&-A;&QB86-K6S!=+3YD96)U9SL-"B`@("`@("`@("`@
M("1C86QL8F%C:ULP72T^9&5B=6<@/2`R.PT*("`@("`@("!]#0H-"B`@("`@
M("`@=VAI;&4@*"1L:6YE(#T@9F=E=',H)'!P+"`Q,#(T*2D@>PT*("`@("`@
M("`@("`@:68@*"1C86QL8F%C:RD@>PT*("`@("`@("`@("`@("`@(&-A;&Q?
M=7-E<E]F=6YC*"1C86QL8F%C:RP@)V-M9&]U='!U="<L("1L:6YE*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FQO
M9R@R+"!R=')I;2@D;&EN92DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("@D8V%L;&)A8VL@)B8@:7-S970H)&]L9&1B9RDI('L-
M"B`@("`@("`@("`@("1C86QL8F%C:ULP72T^9&5B=6<@/2`D;VQD9&)G.PT*
M("`@("`@("!]#0H@("`@("`@("1E>&ET8V]D92`]($!P8VQO<V4H)'!P*3L-
M"B`@("`@("`@<F5T=7)N("@D97AI=&-O9&4@/3T@,"D[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&QO9R@I#0H-"B`@("!F=6YC=&EO;B!L
M;V<H)&QE=F5L+"`D;7-G*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YC
M=7)R96YT7V-A;&QB86-K*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/F1E
M8G5G(#X]("1L979E;"D@>PT*("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC*"1T:&ES+3YC=7)R96YT7V-A;&QB86-K+"`G;W5T<'5T)RP@)&US9RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(%!%05)?0V]M;6]N.CIL;V<H)&QE=F5L+"`D
M;7-G*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]!=71O;&]A9&5R+G!H
M<```````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3<T,2`Q
M,#4Q-30S-#$S-"`P,C(P,S$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`-"B\J*@T*("H@0VQA<W,@875T;RUL;V%D
M97(-"B`J#0H@*B!02%`@=F5R<VEO;G,@-`T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@075T;VQO861E<BYP
M:'`L=B`Q+C$S(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+VUA;G5A;"]E;B]C
M;W)E+G!P;2YP:'`C8V]R92YP<&TN<&5A<BUA=71O;&]A9&5R#0H@*B!`<VEN
M8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("H@
M0&1E<')E8V%T960@1FEL92!D97!R96-A=&5D(&EN(%)E;&5A<V4@,2XT+C!A
M,0T*("HO#0H-"B\O("\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT.B`J+PT*#0II9B`H(65X=&5N<VEO;E]L;V%D960H(F]V
M97)L;V%D(BDI('L-"B`@("`O+R!D:64@:&%R9"!W:71H;W5T(&5X="]O=F5R
M;&]A9`T*("`@(&1I92@B4F5B=6EL9"!02%`@=VET:"!T:&4@8&]V97)L;V%D
M)R!E>'1E;G-I;VX@=&\@=7-E(%!%05)?075T;VQO861E<B(I.PT*?0T*#0HO
M*BH-"B`J($EN8VQU9&4@9F]R(%!%05)?17)R;W(@86YD(%!%05(@8VQA<W-E
M<PT*("HO#0IR97%U:7)E7V]N8V4@(E!%05(N<&AP(CL-"@T*+RHJ#0H@*B!4
M:&ES(&-L87-S(&ES(&9O<B!O8FIE8W1S('=H97)E('EO=2!W86YT('1O('-E
M<&%R871E('1H92!C;V1E(&9O<@T*("H@<V]M92!M971H;V1S(&EN=&\@<V5P
M87)A=&4@8VQA<W-E<RX@(%1H:7,@:7,@=7-E9G5L(&EF('EO=2!H879E(&$-
M"B`J(&-L87-S('=I=&@@;F]T+69R97%U96YT;'DM=7-E9"!M971H;V1S('1H
M870@8V]N=&%I;B!L;W1S(&]F(&-O9&4-"B`J('1H870@>6]U('=O=6QD(&QI
M:V4@=&\@879O:60@86QW87ES('!A<G-I;F<N#0H@*@T*("H@5&AE(%!%05)?
M075T;VQO861E<B!C;&%S<R!P<F]V:61E<R!A=71O;&]A9&EN9R!A;F0@86=G
M<F5G871I;VXN#0H@*B!4:&4@875T;VQO861I;F<@;&5T<R!Y;W4@<V5T('5P
M(&EN('=H:6-H(&-L87-S97,@=&AE('-E<&%R871E9`T*("H@;65T:&]D<R!A
M<F4@9F]U;F0N("!!9V=R96=A=&EO;B!I<R!T:&4@=&5C:&YI<75E('5S960@
M=&\@:6UP;W)T(&YE=PT*("H@;65T:&]D<RP@86X@:6YS=&%N8V4@;V8@96%C
M:"!C;&%S<R!P<F]V:61I;F<@<V5P87)A=&5D(&UE=&AO9',@:7,-"B`J('-T
M;W)E9"!A;F0@8V%L;&5D(&5V97)Y('1I;64@=&AE(&%G9W)E9V%T960@;65T
M:&]D(&ES(&-A;&QE9"X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R(%-T:6<@0F%K:V5N(#QS<V)`
M<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+VUA;G5A;"]E;B]C;W)E+G!P;2YP:'`C8V]R92YP<&TN<&5A<BUA=71O
M;&]A9&5R#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#`N,0T*("H@0&1E<')E8V%T960@1FEL92!D97!R96-A=&5D(&EN
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27T%U=&]L;V%D97(@
M97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@
M("\J*@T*("`@("`J($UA<"!O9B!M971H;V1S(&%N9"!C;&%S<V5S('=H97)E
M('1H97D@87)E(&1E9FEN960-"B`@("`@*@T*("`@("`J($!V87(@87)R87D-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M('9A<B`D7V%U=&]L;V%D7VUA<"`](&%R<F%Y*"D[#0H-"B`@("`O*BH-"B`@
M("`@*B!-87`@;V8@;65T:&]D<R!A;F0@86=G<F5G871E(&]B:F5C=',-"B`@
M("`@*@T*("`@("`J($!V87(@87)R87D-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VUE=&AO9%]M87`@/2!A
M<G)A>2@I.PT*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%D9$%U=&]L;V%D
M*"D-"@T*("`@("\J*@T*("`@("`J($%D9"!O;F4@;W(@;6]R92!A=71O;&]A
M9"!E;G1R:65S+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T
M:&]D("`@("!W:&EC:"!M971H;V0@=&\@875T;VQO860-"B`@("`@*@T*("`@
M("`J($!P87)A;2!S=')I;F<@)&-L87-S;F%M92`@*&]P=&EO;F%L*2!W:&EC
M:"!C;&%S<R!T;R!F:6YD('1H92!M971H;V0@:6XN#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("!)9B!T:&4@)&UE=&AO9"!P87)A;65T97(@
M:7,@86X@87)R87DL('1H:7,-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('!A<F%M971E<B!M87D@8F4@;VUI='1E9"`H86YD('=I;&P@8F4@
M:6=N;W)E9`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M;F]T*2P@86YD('1H92`D;65T:&]D('!A<F%M971E<B!W:6QL(&)E#0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("!T<F5A=&5D(&%S(&%N(&%S
M<V]C:6%T:79E(&%R<F%Y('=I=&@@;65T:&]D#0H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("!N86UE<R!A<R!K97ES(&%N9"!C;&%S<R!N86UE
M<R!A<R!V86QU97,N#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@861D075T;VQO860H)&UE=&AO9"P@)&-L87-S;F%M92`](&YU;&PI
M#0H@("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH)&UE=&AO9"DI('L-"B`@
M("`@("`@("`@(&%R<F%Y7W=A;&LH)&UE=&AO9"P@8W)E871E7V9U;F-T:6]N
M*"<D82PF)&(G+"`G)&(@/2!S=')T;VQO=V5R*"1B*3LG*2D[#0H@("`@("`@
M("`@("`D=&AI<RT^7V%U=&]L;V%D7VUA<"`](&%R<F%Y7VUE<F=E*"1T:&ES
M+3Y?875T;VQO861?;6%P+"`D;65T:&]D*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?875T;VQO861?;6%P6W-T<G1O;&]W97(H
M)&UE=&AO9"E=(#T@)&-L87-S;F%M93L-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!R96UO=F5!=71O;&]A9"@I#0H-"B`@
M("`O*BH-"B`@("`@*B!296UO=F4@86X@875T;VQO860@96YT<GDN#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1M971H;V0@('=H:6-H(&UE=&AO
M9"!T;R!R96UO=F4@=&AE(&%U=&]L;V%D(&5N=')Y(&9O<@T*("`@("`J#0H@
M("`@("H@0')E='5R;B!B;V]L(%12544@:68@86X@96YT<GD@=V%S(')E;6]V
M960L($9!3%-%(&EF(&YO=`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96UO=F5!=71O;&]A9"@D;65T
M:&]D*0T*("`@('L-"B`@("`@("`@)&UE=&AO9"`]('-T<G1O;&]W97(H)&UE
M=&AO9"D[#0H@("`@("`@("1O:R`](&ES<V5T*"1T:&ES+3Y?875T;VQO861?
M;6%P6R1M971H;V1=*3L-"B`@("`@("`@=6YS970H)'1H:7,M/E]A=71O;&]A
M9%]M87!;)&UE=&AO9%TI.PT*("`@("`@("!R971U<FX@)&]K.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A9&1!9V=R96=A=&5/8FIE8W0H
M*0T*#0H@("`@+RHJ#0H@("`@("H@061D(&%N(&%G9W)E9V%T92!O8FIE8W0@
M=&\@=&AI<R!O8FIE8W0N("!)9B!T:&4@<W!E8VEF:65D(&-L87-S#0H@("`@
M("H@:7,@;F]T(&1E9FEN960L(&QO861I;F<@:70@=VEL;"!B92!A='1E;7!T
M960@9F]L;&]W:6YG(%!%05(G<PT*("`@("`J(&9I;&4@;F%M:6YG('-C:&5M
M92X@($%L;"!T:&4@;65T:&]D<R!I;B!T:&4@8VQA<W,@=VEL;"!B90T*("`@
M("`J(&%G9W)E9V%T960L(&5X8V5P="!P<FEV871E(&]N97,@*&YA;64@<W1A
M<G1I;F<@=VET:"!A;@T*("`@("`J('5N9&5R<V-O<F4I(&%N9"!C;VYS=')U
M8W1O<G,N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<VYA
M;64@('=H870@8VQA<W,@=&\@:6YS=&%N=&EA=&4@9F]R('1H92!O8FIE8W0N
M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D06=G
M<F5G871E3V)J96-T*"1C;&%S<VYA;64I#0H@("`@>PT*("`@("`@("`D8VQA
M<W-N86UE(#T@<W1R=&]L;W=E<B@D8VQA<W-N86UE*3L-"B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M92DI('L-"B`@("`@("`@("`@("1I
M;F-L=61E7V9I;&4@/2!P<F5G7W)E<&QA8V4H)R];7F$M>C`M.5TO:2<L("=?
M)RP@)&-L87-S;F%M92D[#0H@("`@("`@("`@("!I;F-L=61E7V]N8V4@)&EN
M8VQU9&5?9FEL93L-"B`@("`@("`@?0T*("`@("`@("`D;V)J(#TF(&YE=R`D
M8VQA<W-N86UE.PT*("`@("`@("`D;65T:&]D<R`](&=E=%]C;&%S<U]M971H
M;V1S*"1C;&%S<VYA;64I.PT*("`@("`@("!F;W)E86-H("@D;65T:&]D<R!A
M<R`D;65T:&]D*2![#0H@("`@("`@("`@("`O+R!D;VXG="!I;7!O<G0@<')I
M=FEA=&4@;65T:&]D<R!A;F0@8V]N<W1R=6-T;W)S#0H@("`@("`@("`@("!I
M9B`H)&UE=&AO9'LP?2`A/2`G7R<@)B8@)&UE=&AO9"`A/2`D8VQA<W-N86UE
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]M971H;V1?;6%P6R1M971H
M;V1=(#T@)&]B:CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!R96UO=F5!9V=R96=A=&5/8FIE
M8W0H*0T*#0H@("`@+RHJ#0H@("`@("H@4F5M;W9E(&%N(&%G9W)E9V%T92!O
M8FIE8W0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1C;&%S<VYA
M;64@('1H92!C;&%S<R!O9B!T:&4@;V)J96-T('1O(')E;6]V90T*("`@("`J
M#0H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&EF(&%N(&]B:F5C="!W87,@
M<F5M;W9E9"P@1D%,4T4@:68@;F]T#0H@("`@("H-"B`@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')E;6]V94%G9W)E9V%T
M94]B:F5C="@D8VQA<W-N86UE*0T*("`@('L-"B`@("`@("`@)&]K(#T@9F%L
M<V4[#0H@("`@("`@("1C;&%S<VYA;64@/2!S=')T;VQO=V5R*"1C;&%S<VYA
M;64I.PT*("`@("`@("!R97-E="@D=&AI<RT^7VUE=&AO9%]M87`I.PT*("`@
M("`@("!W:&EL92`H;&ES="@D;65T:&]D+"`D;V)J*2`](&5A8V@H)'1H:7,M
M/E]M971H;V1?;6%P*2D@>PT*("`@("`@("`@("`@:68@*&ES7V$H)&]B:BP@
M)&-L87-S;F%M92DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^
M7VUE=&AO9%]M87!;)&UE=&AO9%TI.PT*("`@("`@("`@("`@("`@("1O:R`]
M('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1O:SL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7U]C
M86QL*"D-"@T*("`@("\J*@T*("`@("`J($]V97)L;V%D960@;V)J96-T(&-A
M;&P@:&%N9&QE<BP@8V%L;&5D(&5A8V@@=&EM92!A;@T*("`@("`J('5N9&5F
M:6YE9"]A9V=R96=A=&5D(&UE=&AO9"!I<R!I;G9O:V5D+B`@5&AI<R!M971H
M;V0@<F5P96%T<PT*("`@("`J('1H92!C86QL(&EN('1H92!R:6=H="!A9V=R
M96=A=&4@;V)J96-T(&%N9"!P87-S97,@;VX@=&AE(')E='5R;@T*("`@("`J
M('9A;'5E+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D
M("!W:&EC:"!M971H;V0@=&AA="!W87,@8V%L;&5D#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1A<F=S("`@($%N(&%R<F%Y(&]F('1H92!P87)A
M;65T97)S('!A<W-E9"!I;B!T:&4-"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@(&]R:6=I;F%L(&-A;&P-"B`@("`@*@T*("`@("`J($!R971U<FX@
M;6EX960@(%1H92!R971U<FX@=F%L=64@9G)O;2!T:&4@86=G<F5G871E9"!M
M971H;V0L(&]R(&$@4$5!4@T*("`@("`J("`@("`@("`@("`@("`@(&5R<F]R
M(&EF('1H92!C86QL960@;65T:&]D('=A<R!U;FMN;W=N+@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%]?8V%L;"@D;65T:&]D+"`D87)G<RP@)B1R971V86PI
M#0H@("`@>PT*("`@("`@("`D;65T:&]D(#T@<W1R=&]L;W=E<B@D;65T:&]D
M*3L-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?;65T:&]D7VUA<%LD;65T
M:&]D72D@)B8@:7-S970H)'1H:7,M/E]A=71O;&]A9%]M87!;)&UE=&AO9%TI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^861D06=G<F5G871E3V)J96-T*"1T
M:&ES+3Y?875T;VQO861?;6%P6R1M971H;V1=*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]M971H;V1?;6%P6R1M971H;V1=*2D@
M>PT*("`@("`@("`@("`@)')E='9A;"`](&-A;&Q?=7-E<E]F=6YC7V%R<F%Y
M*&%R<F%Y*"1T:&ES+3Y?;65T:&]D7VUA<%LD;65T:&]D72P@)&UE=&AO9"DL
M("1A<F=S*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"GT-"@T*;W9E<FQO860H(E!%05)?075T;VQO861E<B(I.PT*#0H_/@T*````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#:&%N;F5L1FEL92YP:'``````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$V,3<W,R`Q,#4Q-30S-#$S-"`P,C(Q
M,3$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@4$5!4E]#:&%N;F5L1FEL92P@=&AE(&-H86YN96P@
M:&%N9&QI;F<@8VQA<W,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*
M("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@0VAA;FYE;$9I;&4N<&AP+'8@,2XW-2`R,#`V+S`S+S`R(#$X
M.C$T.C$R(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*
M("H@3F5E9&5D(&9O<B!E<G)O<B!H86YD;&EN9PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(O17)R;W)3=&%C:RYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2
M+UA-3%!A<G-E<BYP:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP
M:'`G.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@:68@=&AE(&-H86YN96PN>&UL
M(#QC:&%N;F5L/B!T86<@9&]E<R!N;W0@8V]N=&%I;B!A('9A;&ED('9E<G-I
M;VX-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/7U9%
M4E-)3TXG+"`Q*3L-"B\J*@T*("H@17)R;W(@8V]D92!I9B!T:&4@8VAA;FYE
M;"YX;6P@/&-H86YN96P^('1A9R!V97)S:6]N(&ES(&YO="!S=7!P;W)T960@
M*'9E<G-I;VX@,2XP(&ES('1H92!O;FQY('-U<'!O<G1E9"!V97)S:6]N+`T*
M("H@8W5R<F5N=&QY#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%
M4E)/4E])3E9!3$E$7U9%4E-)3TXG+"`R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C
M;V1E(&EF('!A<G-I;F<@:7,@871T96UP=&5D('=I=&@@;F\@>&UL(&5X=&5N
M<VEO;@T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?
M6$U,7T585"<L(#,I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@:68@8W)E871I
M;F<@=&AE('AM;"!P87)S97(@<F5S;W5R8V4@9F%I;',-"B`J+PT*9&5F:6YE
M*"=014%27T-(04Y.14Q&24Q%7T524D]27T-!3E1?34%+15]005)315(G+"`T
M*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@9F]R(&%L;"!S87@@>&UL
M('!A<G-I;F<@97)R;W)S#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E]005)315)?15)23U(G+"`U*3L-"@T*+RHJ(T`K#0H@*B!686QI
M9&%T:6]N(&5R<F]R<PT*("HO#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!C
M:&%N;F5L(&YA;64@:7,@;6ES<VEN9PT*("HO#0ID969I;F4H)U!%05)?0TA!
M3DY%3$9)3$5?15)23U)?3D]?3D%-12<L(#8I.PT*+RHJ#0H@*B!%<G)O<B!C
M;V1E('=H96X@8VAA;FYE;"!N86UE(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE
M*"=014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?3D%-12<L(#<I.PT*
M+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@8VAA;FYE;"!S=6UM87)Y(&ES(&UI
M<W-I;F<-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%7T524D]27TY/
M7U-534U!4EDG+"`X*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&-H86YN
M96P@<W5M;6%R>2!I<R!M=6QT:2UL:6YE#0H@*B\-"F1E9FEN92@G4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E]-54Q424Q)3D5?4U5-34%262<L(#DI.PT*+RHJ
M#0H@*B!%<G)O<B!C;V1E('=H96X@8VAA;FYE;"!S97)V97(@:7,@;6ES<VEN
M9R!F;W(@>&UL<G!C(&]R('-O87`@<')O=&]C;VP-"B`J+PT*9&5F:6YE*"=0
M14%27T-(04Y.14Q&24Q%7T524D]27TY/7TA/4U0G+"`Q,"D[#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!C:&%N;F5L('-E<G9E<B!I<R!I;G9A;&ED(&9O
M<B!X;6QR<&,@;W(@<V]A<"!P<F]T;V-O;`T*("HO#0ID969I;F4H)U!%05)?
M0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%](3U-4)RP@,3$I.PT*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!M:7)R;W(@;F%M92!I<R!I;G9A;&ED#0H@
M*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TU)
M4E)/4B<L(#(Q*3L-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@;6ER<F]R
M('1Y<&4@:7,@:6YV86QI9`T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)
M3$5?15)23U)?24Y604Q)1%]-25)23U)465!%)RP@,C(I.PT*+RHJ#0H@*B!%
M<G)O<B!C;V1E('=H96X@86X@871T96UP="!I<R!M861E('1O(&=E;F5R871E
M('AM;"P@8G5T('1H92!P87)S960@8V]N=&5N="!I<R!I;G9A;&ED#0H@*B\-
M"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$)RP@,C,I
M.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@86X@96UP='D@<&%C:V%G92!N
M86UE('9A;&ED871E(')E9V5X(&ES('!A<W-E9"!I;@T*("HO#0ID969I;F4H
M)U!%05)?0TA!3DY%3$9)3$5?15)23U)?14U05%E?4D5'15@G+"`R-"D[#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(#QF=6YC=&EO;CX@=&%G(&AA<R!N
M;R!V97)S:6]N#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U]&54Y#5$E/3E9%4E-)3TXG+"`R-2D[#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A(#QF=6YC=&EO;CX@=&%G(&AA<R!N;R!N86UE#0H@*B\-"F1E
M9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]&54Y#5$E/3DY!344G
M+"`R-BD[#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(#QV86QI9&%T97!A
M8VMA9V4^('1A9R!H87,@;F\@;F%M90T*("HO#0ID969I;F4H)U!%05)?0TA!
M3DY%3$9)3$5?15)23U)?3D]604Q)1$%415].04U%)RP@,C<I.PT*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82`\=F%L:61A=&5P86-K86=E/B!T86<@:&%S
M(&YO('9E<G-I;VX@871T<FEB=71E#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E].3U9!3$E$051%7U9%4E-)3TXG+"`R."D[#0HO*BH-
M"B`J($5R<F]R(&-O9&4@=VAE;B!A(&UI<G)O<B!D;V5S(&YO="!E>&ES="!B
M=70@:7,@8V%L;&5D(&9O<B!I;B!O;F4@;V8@=&AE('-E="H-"B`J(&UE=&AO
M9',N#0H@*B\-"F1E9FEN92@G4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]-25)2
M3U)?3D]47T9/54Y$)RP@,S(I.PT*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M82!S97)V97(@<&]R="!I<R!N;W0@;G5M97)I8PT*("HO#0ID969I;F4H)U!%
M05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]03U)4)RP@,S,I.PT*+RHJ
M#0H@*B!%<G)O<B!C;V1E('=H96X@/'-T871I8SX@8V]N=&%I;G,@;F\@=F5R
M<VEO;B!A='1R:6)U=&4-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%
M7T524D]27TY/7U-4051)0U9%4E-)3TXG+"`S-"D[#0HO*BH-"B`J($5R<F]R
M(&-O9&4@=VAE;B`\8F%S975R;#X@8V]N=&%I;G,@;F\@='EP92!A='1R:6)U
M=&4@:6X@82`\<F5S=#X@<')O=&]C;VP@9&5F:6YI=&EO;@T*("HO#0ID969I
M;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]"05-%55),5%E012<L(#,U
M*3L-"B\J*B`-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&UI<G)O<B!I<R!D969I
M;F5D(&%N9"!T:&4@8VAA;FYE;"YX;6P@<F5P<F5S96YT<R!T:&4@7U]U<FD@
M<'-E=61O+6-H86YN96P-"B`J+PT*9&5F:6YE*"=014%27T-(04Y.14Q&24Q%
M7U5225]#04Y47TU)4E)/4B<L(#,V*3L-"B\J*B`-"B`J($5R<F]R(&-O9&4@
M=VAE;B!S<VP@871T<FEB=71E(&ES('!R97-E;G0@86YD(&ES(&YO="`B>65S
M(@T*("HO#0ID969I;F4H)U!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)
M1%]34TPG+"`S-RD[#0HO*BHC0"TJ+PT*#0HO*BH-"B`J($UI<G)O<B!T>7!E
M<R!A;&QO=V5D+B`@0W5R<F5N=&QY(&]N;'D@:6YT97)N970@<V5R=F5R<R!A
M<F4@<F5C;V=N:7IE9"X-"B`J+PT*)$=,3T)!3%-;)U]014%27T-(04Y.14Q3
M7TU)4E)/4E]465!%4R==(#T@(&%R<F%Y*"=S97)V97(G*3L-"@T*#0HO*BH-
M"B`J(%1H92!#:&%N;F5L(&AA;F1L:6YG(&-L87-S#0H@*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B\-"F-L87-S(%!%05)?0VAA;FYE;$9I;&4@>PT*("`@("\J*@T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J($!V87(@4$5!4E]%<G)O
M<E-T86-K#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@
M=F%R("1?<W1A8VL[#0H@("`@#0H@("`@+RHJ#0H@("`@("H@4W5P<&]R=&5D
M(&-H86YN96PN>&UL('9E<G-I;VYS+"!F;W(@<&%R<VEN9PT*("`@("`J($!V
M87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!V87(@)%]S=7!P;W)T961697)S:6]N<R`](&%R<F%Y*"<Q+C`G*3L-"@T*
M("`@("\J*@T*("`@("`J(%!A<G-E9"!C:&%N;F5L(&EN9F]R;6%T:6]N#0H@
M("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@('9A<B`D7V-H86YN96Q);F9O.PT*#0H@("`@+RHJ#0H@("`@
M("H@:6YD97@@:6YT;R!T:&4@<W5B8VAA;FYE;',@87)R87DL('5S960@9F]R
M('!A<G-I;F<@>&UL#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B!`86-C97-S
M('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]S=6)C:&%N;F5L26YD97@[
M#0H-"B`@("`O*BH-"B`@("`@*B!I;F1E>"!I;G1O('1H92!M:7)R;W)S(&%R
M<F%Y+"!U<V5D(&9O<B!P87)S:6YG('AM;`T*("`@("`J($!V87(@:6YT#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?;6ER
M<F]R26YD97@[#0H@("`@#0H@("`@+RHJ#0H@("`@("H@1FQA9R!U<V5D('1O
M(&1E=&5R;6EN92!T:&4@=F%L:61I='D@;V8@<&%R<V5D(&-O;G1E;G0-"B`@
M("`@*B!`=F%R(&)O;VQE86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]I<U9A;&ED(#T@9F%L<V4[#0H-"B`@("!F=6YC
M=&EO;B!014%27T-H86YN96Q&:6QE*"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<W1A8VL@/2`F;F5W(%!%05)?17)R;W)3=&%C:R@G4$5!4E]#:&%N;F5L
M1FEL92<I.PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YS971%<G)O<DUE<W-A
M9V5496UP;&%T92@D=&AI<RT^7V=E=$5R<F]R365S<V%G92@I*3L-"B`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*("`@(`T*("`@
M("\J*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`86-C97-S('!R
M;W1E8W1E9`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971%<G)O<DUE<W-A
M9V4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N#0H@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.
M5D%,241?5D524TE/3B`]/@T*("`@("`@("`@("`@("`@("`@("`G5VAI;&4@
M<&%R<VEN9R!C:&%N;F5L+GAM;"P@86X@:6YV86QI9"!V97)S:6]N(&YU;6)E
M<B`B)79E<G-I;VXE('=A<R!P87-S960@:6XL(&5X<&5C=&EN9R!O;F4@;V8@
M)79E<G-I;VYS)2<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E].3U]615)324].(#T^#0H@("`@("`@("`@("`@("`@("`@("=.
M;R!V97)S:6]N(&YU;6)E<B!F;W5N9"!I;B`\8VAA;FYE;#X@=&%G)RP-"B`@
M("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TY/7UA-3%]%
M6%0@/3X-"B`@("`@("`@("`@("`@("`@("`@)R5E<G)O<B4G+`T*("`@("`@
M("`@("`@("`@(%!%05)?0TA!3DY%3$9)3$5?15)23U)?0T%.5%]-04M%7U!!
M4E-%4B`]/@T*("`@("`@("`@("`@("`@("`@("`G56YA8FQE('1O(&-R96%T
M92!834P@<&%R<V5R)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&
M24Q%7T524D]27U!!4E-%4E]%4E)/4B`]/@T*("`@("`@("`@("`@("`@("`@
M("`G)65R<F]R)2<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E].3U].04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("=-:7-S
M:6YG(&-H86YN96P@;F%M92<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.
M3D5,1DE,15]%4E)/4E])3E9!3$E$7TY!344@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)TEN=F%L:60@8VAA;FYE;"`E=&%G)2`B)6YA;64E(B<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9
M(#T^#0H@("`@("`@("`@("`@("`@("`@("=-:7-S:6YG(&-H86YN96P@<W5M
M;6%R>2<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E]-54Q424Q)3D5?4U5-34%262`]/@T*("`@("`@("`@("`@("`@("`@("`G
M0VAA;FYE;"!S=6UM87)Y('-H;W5L9"!B92!O;B!O;F4@;&EN92P@8G5T(&ES
M(&UU;'1I+6QI;F4G+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?3D]?2$]35"`]/@T*("`@("`@("`@("`@("`@("`@("`G36ES
M<VEN9R!C:&%N;F5L('-E<G9E<B!F;W(@)71Y<&4E('-E<G9E<B<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TA/
M4U0@/3X-"B`@("`@("`@("`@("`@("`@("`@)U-E<G9E<B!N86UE("(E<V5R
M=F5R)2(@:7,@:6YV86QI9"!F;W(@)71Y<&4E('-E<G9E<B<L#0H@("`@("`@
M("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TU)4E)/
M4B`]/@T*("`@("`@("`@("`@("`@("`@("`G26YV86QI9"!M:7)R;W(@;F%M
M92`B)6YA;64E(BP@;6ER<F]R('1Y<&4@)71Y<&4E)RP-"B`@("`@("`@("`@
M("`@("!014%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?34E24D]25%E0
M12`]/@T*("`@("`@("`@("`@("`@("`@("`G26YV86QI9"!M:7)R;W(@='EP
M92`B)71Y<&4E(B<L#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,
M15]%4E)/4E])3E9!3$E$(#T^#0H@("`@("`@("`@("`@("`@("`@("=#86YN
M;W0@9V5N97)A=&4@>&UL+"!C;VYT96YT<R!A<F4@:6YV86QI9"<L#0H@("`@
M("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E]%35!465]214=%
M6"`]/@T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G96YA;65R96=E>"!C
M86YN;W0@8F4@96UP='DG+`T*("`@("`@("`@("`@("`@(%!%05)?0TA!3DY%
M3$9)3$5?15)23U)?3D]?1E5.0U1)3TY615)324].(#T^#0H@("`@("`@("`@
M("`@("`@("`@("<E<&%R96YT)2`E<')O=&]C;VPE(&9U;F-T:6]N(&AA<R!N
M;R!V97)S:6]N)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%
M7T524D]27TY/7T953D-424].3D%-12`]/@T*("`@("`@("`@("`@("`@("`@
M("`G)7!A<F5N="4@)7!R;W1O8V]L)2!F=6YC=&EO;B!H87,@;F\@;F%M92<L
M#0H@("`@("`@("`@("`@("`@4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3T)!
M4T554DQ465!%(#T^#0H@("`@("`@("`@("`@("`@("`@("<E<&%R96YT)2!R
M97-T(&)A<V5U<FP@:&%S(&YO('1Y<&4G+`T*("`@("`@("`@("`@("`@(%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?3D]604Q)1$%415].04U%(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=686QI9&%T:6]N('!A8VMA9V4@:&%S(&YO(&YA
M;64@:6X@/'9A;&ED871E<&%C:V%G93X@=&%G)RP-"B`@("`@("`@("`@("`@
M("!014%27T-(04Y.14Q&24Q%7T524D]27TY/5D%,241!5$5?5D524TE/3B`]
M/@T*("`@("`@("`@("`@("`@("`@("`G5F%L:61A=&EO;B!P86-K86=E("(E
M<&%C:V%G924B(&AA<R!N;R!V97)S:6]N)RP-"B`@("`@("`@("`@("`@("!0
M14%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0@/3X-"B`@
M("`@("`@("`@("`@("`@("`@)TUI<G)O<B`B)6UI<G)O<B4B(&1O97,@;F]T
M(&5X:7-T)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T52
M4D]27TE.5D%,241?4$]25"`]/@T*("`@("`@("`@("`@("`@("`@("`G4&]R
M="`B)7!O<G0E(B!M=7-T(&)E(&YU;65R:6,G+`T*("`@("`@("`@("`@("`@
M(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4U1!5$E#5D524TE/3B`]/@T*
M("`@("`@("`@("`@("`@("`@("`G/'-T871I8SX@=&%G(&UU<W0@8V]N=&%I
M;B!V97)S:6]N(&%T=')I8G5T92<L#0H@("`@("`@("`@("`@("`@4$5!4E]#
M2$%.3D5,1DE,15]54DE?0T%.5%]-25)23U(@/3X-"B`@("`@("`@("`@("`@
M("`@("`@)U1H92!?7W5R:2!P<V5U9&\M8VAA;FYE;"!C86YN;W0@:&%V92!M
M:7)R;W)S)RP-"B`@("`@("`@("`@("`@("!014%27T-(04Y.14Q&24Q%7T52
M4D]27TE.5D%,241?4U-,(#T^#0H@("`@("`@("`@("`@("`@("`@("<E<V5R
M=F5R)2!H87,@:6YV86QI9"!S<VP@871T<FEB=71E("(E<W-L)2(@8V%N(&]N
M;'D@8F4@>65S(&]R(&YO="!P<F5S96YT)RP-"B`@("`@("`@("`@("D[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYT96YT
M<R!O9B!P86-K86=E+GAM;"!F:6QE#0H@("`@("H@0')E='5R;B!B;V]L('-U
M8V-E<W,@;V8@<&%R<VEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&9R;VU8
M;6Q3=')I;F<H)&1A=&$I#0H@("`@>PT*("`@("`@("!I9B`H<')E9U]M871C
M:"@G+SQC:&%N;F5L7',K=F5R<VEO;CTB*%LP+3E=*UPN6S`M.5TK*2(O)RP@
M)&1A=&$L("1C:&%N;F5L=F5R<VEO;BDI('L-"B`@("`@("`@("`@(&EF("@A
M:6Y?87)R87DH)&-H86YN96QV97)S:6]N6S%=+"`D=&AI<RT^7W-U<'!O<G1E
M9%9E<G-I;VYS*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U9%4E-)3TXL
M("=E<G)O<B<L#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N
M)R`]/B`D8VAA;FYE;'9E<G-I;VY;,5TI*3L-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%R
M<V5R(#T@;F5W(%!%05)?6$U,4&%R<V5R.PT*("`@("`@("`@("`@)')E<W5L
M="`]("1P87)S97(M/G!A<G-E*"1D871A*3L-"B`@("`@("`@("`@(&EF("@D
M<F5S=6QT("$]/2!T<G5E*2![#0H@("`@("`@("`@("`@("`@:68@*"1R97-U
M;'0M/F=E=$-O9&4H*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G!U<V@H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]8
M34Q?15A4+"`G97)R;W(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V5R<F]R)R`]/B`D97)R;W(I*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H
M*%!%05)?0TA!3DY%3$9)3$5?15)23U)?0T%.5%]-04M%7U!!4E-%4BP@)V5R
M<F]R)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES
M+3Y?8VAA;FYE;$EN9F\@/2`D<&%R<V5R+3YG971$871A*"D[#0H@("`@("`@
M("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U]615)324].+"`G97)R;W(G+"!A<G)A>2@G>&UL)R`]/B`D9&%T82DI
M.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M?0T*("`@(`T*("`@("\J*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!T;T%R<F%Y*"D-"B`@("![#0H@("`@("`@(&EF
M("@A)'1H:7,M/E]I<U9A;&ED("8F("$D=&AI<RT^=F%L:61A=&4H*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O.PT*("`@('T-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("H@0')E='5R;B!014%27T-H86YN96Q&:6QE?&9A;'-E(&9A;'-E(&EF
M(&EN=F%L:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F9G)O;4%R<F%Y*"1D
M871A+"`D8V]M<&%T:6)I;&ET>2`](&9A;'-E+"`D<W1A8VM#;&%S<R`]("=0
M14%27T5R<F]R4W1A8VLG*0T*("`@('L-"B`@("`@("`@)&$@/2!N97<@4$5!
M4E]#:&%N;F5L1FEL92@D8V]M<&%T:6)I;&ET>2P@)'-T86-K0VQA<W,I.PT*
M("`@("`@("`D82T^7V9R;VU!<G)A>2@D9&%T82D[#0H@("`@("`@(&EF("@A
M)&$M/G9A;&ED871E*"DI('L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@
M("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1A.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%5N;&EK92![0&QI
M;FL@9G)O;4%R<F%Y*"E]('1H:7,@9&]E<R!N;W0@9&\@86YY('9A;&ED871I
M;VX-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@
M("H@0')E='5R;B!014%27T-H86YN96Q&:6QE#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)F9R;VU!<G)A>5=I=&A%<G)O<G,H)&1A=&$L("1C;VUP871I8FEL
M:71Y(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T86-K0VQA<W,@/2`G4$5!4E]%<G)O<E-T86-K)RD-"B`@("![#0H@
M("`@("`@("1A(#T@;F5W(%!%05)?0VAA;FYE;$9I;&4H)&-O;7!A=&EB:6QI
M='DL("1S=&%C:T-L87-S*3L-"B`@("`@("`@)&$M/E]F<F]M07)R87DH)&1A
M=&$I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*("`@(`T*("`@("\J
M*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]F<F]M07)R87DH)&1A=&$I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O(#T@)&1A=&$[#0H@
M("`@?0T*("`@(`T*("`@("\J*@T*("`@("`J(%=R87!P97(@=&\@>T!L:6YK
M(%!%05)?17)R;W)3=&%C:SHZ9V5T17)R;W)S*"E]#0H@("`@("H@0'!A<F%M
M(&)O;VQE86X@9&5T97)M:6YE<R!W:&5T:&5R('1O('!U<F=E('1H92!E<G)O
M<B!S=&%C:R!A9G1E<B!R971R:65V:6YG#0H@("`@("H@0')E='5R;B!A<G)A
M>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$5R<F]R<R@D<'5R9V4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W-T86-K+3YG
M971%<G)O<G,H)'!U<F=E*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!5
M;FEN9&5N="!G:79E;B!S=')I;F<@*#\I#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S='(@5&AE('-T<FEN9R!T:&%T(&AA<R!T;R!B92!U;FEN
M9&5N=&5D+@T*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5N26YD96YT*"1S
M='(I#0H@("`@>PT*("`@("`@("`O+R!R96UO=F4@;&5A9&EN9R!N97=L:6YE
M<PT*("`@("`@("`D<W1R(#T@<')E9U]R97!L86-E*"<O7EM<<EQN72LO)RP@
M)R<L("1S='(I.PT*("`@("`@("`O+R!F:6YD('=H:71E<W!A8V4@870@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FER<W0@;&EN90T*("`@("`@("`D:6YD96YT
M7VQE;B`]('-T<G-P;B@D<W1R+"`B(%QT(BD[#0H@("`@("`@("1I;F1E;G0@
M/2!S=6)S='(H)'-T<BP@,"P@)&EN9&5N=%]L96XI.PT*("`@("`@("`D9&%T
M82`]("<G.PT*("`@("`@("`O+R!R96UO=F4@=&AE('-A;64@86UO=6YT(&]F
M('=H:71E<W!A8V4@9G)O;2!F;VQL;W=I;F<@;&EN97,-"B`@("`@("`@9F]R
M96%C:"`H97AP;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN92D@>PT*("`@("`@
M("`@("`@:68@*'-U8G-T<B@D;&EN92P@,"P@)&EN9&5N=%]L96XI(#T]("1I
M;F1E;G0I('L-"B`@("`@("`@("`@("`@("`D9&%T82`N/2!S=6)S='(H)&QI
M;F4L("1I;F1E;G1?;&5N*2`N(")<;B([#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%!A<G-E(&$@8VAA;FYE;"YX;6P@9FEL92X@($5X<&5C=',@
M=&AE(&YA;64@;V8-"B`@("`@*B!A(&-H86YN96P@>&UL(&9I;&4@87,@:6YP
M=70N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&5S8V9I;&4@
M(&YA;64@;V8@8VAA;FYE;"!X;6P@9FEL90T*("`@("`J($!R971U<FX@8F]O
M;"!S=6-C97-S(&]F('!A<G-I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!F
M<F]M6&UL1FEL92@D9&5S8V9I;&4I#0H@("`@>PT*("`@("`@("!I9B`H(4!I
M<U]F:6QE*"1D97-C9FEL92D@?'P@(6ES7W)E861A8FQE*"1D97-C9FEL92D@
M?'P-"B`@("`@("`@("`@("`H(21F<"`]($!F;W!E;B@D9&5S8V9I;&4L("=R
M)RDI*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")5;F%B;&4@
M=&\@;W!E;B`D9&5S8V9I;&4B*3L-"B`@("`@("`@?0T*#0H@("`@("`@("\O
M(')E860@=&AE('=H;VQE('1H:6YG('-O('=E(&]N;'D@9V5T(&]N92!C9&%T
M82!C86QL8F%C:PT*("`@("`@("`O+R!F;W(@96%C:"!B;&]C:R!O9B!C9&%T
M80T*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=F:6QE7V=E=%]C;VYT
M96YT<R<I*2![#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M("`@("1D871A(#T@9FEL95]G971?8V]N=&5N=',H)&1E<V-F:6QE*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D871A(#T@9G)E860H)&9P
M+"!F:6QE<VEZ92@D9&5S8V9I;&4I*3L-"B`@("`@("`@("`@(&9C;&]S92@D
M9G`I.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^9G)O;5AM
M;%-T<FEN9R@D9&%T82D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4&%R
M<V4@8VAA;FYE;"!I;F9O<FUA=&EO;B!F<F]M(&1I9F9E<F5N="!S;W5R8V5S
M#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!A8FQE('1O(&5X=')A
M8W0@:6YF;W)M871I;VX@86)O=70@82!C:&%N;F5L#0H@("`@("H@9G)O;2!A
M;B`N>&UL(&9I;&4@;W(@82!S=')I;F<-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("H@0'!A<F%M("!S=')I;F<@1FEL96YA;64@;V8@
M=&AE('-O=7)C92!O<B!T:&4@<V]U<F-E(&ET<V5L9@T*("`@("`J($!R971U
M<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&9R;VU!;GDH)&EN9F\I
M#0H@("`@>PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1I;F9O*2`F)B!F:6QE
M7V5X:7-T<R@D:6YF;RD@)B8@<W1R;&5N*"1I;F9O*2`\(#(U-2D@>PT*("`@
M("`@("`@("`@)'1M<"`]('-U8G-T<B@D:6YF;RP@+30I.PT*("`@("`@("`@
M("`@:68@*"1T;7`@/3T@)RYX;6PG*2![#0H@("`@("`@("`@("`@("`@)&EN
M9F\@/2`D=&AI<RT^9G)O;5AM;$9I;&4H)&EN9F\I.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9G`@/2!F;W!E;B@D:6YF;RP@
M(G(B*3L-"B`@("`@("`@("`@("`@("`D=&5S="`](&9R96%D*"1F<"P@-2D[
M#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@
M("`@:68@*"1T97-T(#T]("(\/WAM;"(I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&EN9F\@/2`D=&AI<RT^9G)O;5AM;$9I;&4H)&EN9F\I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@("`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4BYP:'`G.PT*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"1I;F9O*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-?<W1R:6YG*"1I;F9O*2D@>PT*("`@("`@
M("`@("`@)&EN9F\@/2`D=&AI<RT^9G)O;5AM;%-T<FEN9R@D:6YF;RD[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N("1I;F9O.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J(%)E='5R;B!A;B!834P@9&]C=6UE;G0@8F%S960@;VX@
M<')E=FEO=7,@<&%R<VEN9R!A;F0@;6]D:69I8V%T:6]N<PT*("`@("`J#0H@
M("`@("H@0')E='5R;B!S=')I;F<@6$U,(&1A=&$-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]8;6PH
M*0T*("`@('L-"B`@("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60@)B8@(21T
M:&ES+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$*3L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)V%T=')I8G,G75LG=F5R
M<VEO;B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG
M871T<FEB<R==6R=V97)S:6]N)UT@/2`G,2XP)SL-"B`@("`@("`@?0T*("`@
M("`@("`D8VAA;FYE;$EN9F\@/2`D=&AI<RT^7V-H86YN96Q);F9O.PT*("`@
M("`@("`D<F5T(#T@(CP_>&UL('9E<G-I;VX]7"(Q+C!<(B!E;F-O9&EN9SU<
M(DE33RTX.#4Y+3%<(B`_/EQN(CL-"B`@("`@("`@)')E="`N/2`B/&-H86YN
M96P@=F5R<VEO;CU<(B(@+@T*("`@("`@("`@("`@)&-H86YN96Q);F9O6R=A
M='1R:6)S)UU;)W9E<G-I;VXG72`N(")<(B!X;6QN<SU<(FAT='`Z+R]P96%R
M+G!H<"YN970O8VAA;FYE;"TQ+C!<(@T*("!X;6QN<SIX<VD]7")H='1P.B\O
M=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC95PB#0H@('AS:3IS
M8VAE;6%,;V-A=&EO;CU<(FAT='`Z+R]P96%R+G!H<"YN970O9'1D+V-H86YN
M96PM(@T*("`@("`@("`@("`@+B`D8VAA;FYE;$EN9F];)V%T=')I8G,G75LG
M=F5R<VEO;B==("X@(B!H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]C:&%N;F5L
M+2(@+@T*("`@("`@("`@("`@)&-H86YN96Q);F9O6R=A='1R:6)S)UU;)W9E
M<G-I;VXG72`N("(N>'-D7"(^#0H@/&YA;64^)&-H86YN96Q);F9O6VYA;65=
M/"]N86UE/@T*(#QS=6UM87)Y/B(@+B!H=&UL<W!E8VEA;&-H87)S*"1C:&%N
M;F5L26YF;ULG<W5M;6%R>2==*2XB/"]S=6UM87)Y/@T*(CL-"B`@("`@("`@
M:68@*&ES<V5T*"1C:&%N;F5L26YF;ULG<W5G9V5S=&5D86QI87,G72DI('L-
M"B`@("`@("`@("`@("1R970@+CT@)R`\<W5G9V5S=&5D86QI87,^)R`N("1C
M:&%N;F5L26YF;ULG<W5G9V5S=&5D86QI87,G72`N("(\+W-U9V=E<W1E9&%L
M:6%S/EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&-H86YN
M96Q);F9O6R=V86QI9&%T97!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("1R
M970@+CT@)R`\=F%L:61A=&5P86-K86=E('9E<G-I;VX](B<@+@T*("`@("`@
M("`@("`@("`@("1C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UU;)V%T
M=')I8G,G75LG=F5R<VEO;B==+B`G(CXG("X-"B`@("`@("`@("`@("`@("!H
M=&UL<W!E8VEA;&-H87)S*"1C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E
M)UU;)U]C;VYT96YT)UTI("X-"B`@("`@("`@("`@("`@("`B/"]V86QI9&%T
M97!A8VMA9V4^7&XB.PT*("`@("`@("!]#0H@("`@("`@("1R970@+CT@(B`\
M<V5R=F5R<SY<;B([#0H@("`@("`@("1R970@+CT@)R`@/'!R:6UA<GDG.PT*
M("`@("`@("!I9B`H:7-S970H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R
M:6UA<GDG75LG871T<FEB<R==6R=S<VPG72DI('L-"B`@("`@("`@("`@("1R
M970@+CT@)R!S<VP](B<@+B`D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I
M;6%R>2==6R=A='1R:6)S)UU;)W-S;"==("X@)R(G.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I
M;6%R>2==6R=A='1R:6)S)UU;)W!O<G0G72DI('L-"B`@("`@("`@("`@("1R
M970@+CT@)R!P;W)T/2(G("X@)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R
M:6UA<GDG75LG871T<FEB<R==6R=P;W)T)UT@+B`G(B<[#0H@("`@("`@('T-
M"B`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@("`@("`@:68@*&ES<V5T*"1C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)WAM;')P8R==*2D@
M>PT*("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^7VUA:V58;6QR<&-8;6PH
M)&-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG>&UL<G!C)UTL
M("<@("`G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&-H86YN
M96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<F5S="==*2D@>PT*("`@
M("`@("`@("`@)')E="`N/2`D=&AI<RT^7VUA:V5297-T6&UL*"1C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W)E<W0G72P@)R`@("<I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D8VAA;FYE;$EN9F];)W-E
M<G9E<G,G75LG<')I;6%R>2==6R=S;V%P)UTI*2![#0H@("`@("`@("`@("`D
M<F5T("X]("1T:&ES+3Y?;6%K95-O87!8;6PH)&-H86YN96Q);F9O6R=S97)V
M97)S)UU;)W!R:6UA<GDG75LG<V]A<"==+"`G("`@)RD[#0H@("`@("`@('T-
M"B`@("`@("`@)')E="`N/2`B("`\+W!R:6UA<GD^7&XB.PT*("`@("`@("!I
M9B`H:7-S970H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@
M>PT*("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^7VUA:V5-:7)R;W)S6&UL
M*"1C:&%N;F5L26YF;RD[#0H@("`@("`@('T-"B`@("`@("`@)')E="`N/2`B
M(#PO<V5R=F5R<SY<;B([#0H@("`@("`@("1R970@+CT@(CPO8VAA;FYE;#XB
M.PT*("`@("`@("!R971U<FX@<W1R7W)E<&QA8V4H(EQR(BP@(EQN(BP@<W1R
M7W)E<&QA8V4H(EQR7&XB+"`B7&XB+"`D<F5T*2D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5N97)A=&4@=&AE(#QX;6QR<&,^('1A9PT*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]M86ME
M6&UL<G!C6&UL*"1I;F9O+"`D:6YD96YT*0T*("`@('L-"B`@("`@("`@)')E
M="`]("1I;F1E;G0@+B`B/'AM;')P8R([#0H@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG871T<FEB<R==6R=P871H)UTI*2![#0H@("`@("`@("`@("`D<F5T
M("X]("<@<&%T:#TB)R`N(&AT;6QS<&5C:6%L8VAA<G,H)&EN9F];)V%T=')I
M8G,G75LG<&%T:"==*2`N("<B)SL-"B`@("`@("`@?0T*("`@("`@("`D<F5T
M("X]("(^7&XB.PT*("`@("`@("`D<F5T("X]("1T:&ES+3Y?;6%K949U;F-T
M:6]N<UAM;"@D:6YF;ULG9G5N8W1I;VXG72P@(B1I;F1E;G0@(BD[#0H@("`@
M("`@("1R970@+CT@)&EN9&5N="`N("(\+WAM;')P8SY<;B([#0H@("`@("`@
M(')E='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E;F5R
M871E('1H92`\<V]A<#X@=&%G#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7VUA:V53;V%P6&UL*"1I;F9O+"`D:6YD
M96YT*0T*("`@('L-"B`@("`@("`@)')E="`]("1I;F1E;G0@+B`B/'-O87`B
M.PT*("`@("`@("!I9B`H:7-S970H)&EN9F];)V%T=')I8G,G75LG<&%T:"==
M*2D@>PT*("`@("`@("`@("`@)')E="`N/2`G('!A=&@](B<@+B!H=&UL<W!E
M8VEA;&-H87)S*"1I;F9O6R=A='1R:6)S)UU;)W!A=&@G72D@+B`G(B<[#0H@
M("`@("`@('T-"B`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@("`@("`@)')E
M="`N/2`D=&AI<RT^7VUA:V5&=6YC=&EO;G-8;6PH)&EN9F];)V9U;F-T:6]N
M)UTL("(D:6YD96YT("(I.PT*("`@("`@("`D<F5T("X]("1I;F1E;G0@+B`B
M/"]S;V%P/EQN(CL-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5N97)A=&4@=&AE(#QR97-T/B!T86<-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;6%K
M95)E<W18;6PH)&EN9F\L("1I;F1E;G0I#0H@("`@>PT*("`@("`@("`D<F5T
M(#T@)&EN9&5N="`N("(\<F5S=#Y<;B([#0H@("`@("`@(&EF("@A:7-S970H
M)&EN9F];)V)A<V5U<FPG75LP72DI('L-"B`@("`@("`@("`@("1I;F9O6R=B
M87-E=7)L)UT@/2!A<G)A>2@D:6YF;ULG8F%S975R;"==*3L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D:6YF;ULG8F%S975R;"==(&%S("1U<FPI
M('L-"B`@("`@("`@("`@("1R970@+CT@(B1I;F1E;G0@/&)A<V5U<FP@='EP
M93U<(B(@+B`D=7)L6R=A='1R:6)S)UU;)W1Y<&4G72`N(")<(B([#0H@("`@
M("`@("`@("`D<F5T("X]("(^(B`N("1U<FQ;)U]C;VYT96YT)UT@+B`B/"]B
M87-E=7)L/EQN(CL-"B`@("`@("`@?0T*("`@("`@("`D<F5T("X]("1I;F1E
M;G0@+B`B/"]R97-T/EQN(CL-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1V5N97)A=&4@=&AE(#QM:7)R;W)S/B!T
M86<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?;6%K94UI<G)O<G-8;6PH)&-H86YN96Q);F9O*0T*("`@('L-"B`@
M("`@("`@)')E="`]("(B.PT*("`@("`@("!I9B`H(6ES<V5T*"1C:&%N;F5L
M26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@
M("1C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72`](&%R<F%Y*"1C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72D[#0H@("`@("`@('T-
M"B`@("`@("`@9F]R96%C:"`H)&-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==(&%S("1M:7)R;W(I('L-"B`@("`@("`@("`@("1R970@+CT@)R`@
M/&UI<G)O<B!H;W-T/2(G("X@)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UT@
M+B`G(B<[#0H@("`@("`@("`@("!I9B`H:7-S970H)&UI<G)O<ELG871T<FEB
M<R==6R=P;W)T)UTI*2![#0H@("`@("`@("`@("`@("`@)')E="`N/2`G('!O
M<G0](B<@+B`D;6ER<F]R6R=A='1R:6)S)UU;)W!O<G0G72`N("<B)SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=A
M='1R:6)S)UU;)W-S;"==*2D@>PT*("`@("`@("`@("`@("`@("1R970@+CT@
M)R!S<VP](B<@+B`D;6ER<F]R6R=A='1R:6)S)UU;)W-S;"==("X@)R(G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`N/2`B/EQN(CL-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=X;6QR<&,G72D@?'P@:7-S
M970H)&UI<G)O<ELG<V]A<"==*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D;6ER<F]R6R=X;6QR<&,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)')E="`N/2`D=&AI<RT^7VUA:V58;6QR<&-8;6PH)&UI<G)O<ELG>&UL
M<G!C)UTL("<@("`G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1M:7)R;W);)W)E<W0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^7VUA:V5297-T6&UL*"1M:7)R
M;W);)W)E<W0G72P@)R`@("<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&UI<G)O<ELG<V]A<"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<F5T("X]("1T:&ES+3Y?;6%K95-O87!8;6PH
M)&UI<G)O<ELG<V]A<"==+"`G("`@)RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1R970@+CT@(B`@/"]M:7)R;W(^7&XB.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("(O
M/EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'96YE<F%T92!T
M:&4@/&9U;F-T:6]N<SX@=&%G#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7VUA:V5&=6YC=&EO;G-8;6PH)&9U;F-T
M:6]N<RP@)&EN9&5N="P@)')E<W0@/2!F86QS92D-"B`@("![#0H@("`@("`@
M("1R970@/2`G)SL-"B`@("`@("`@:68@*"%I<W-E="@D9G5N8W1I;VYS6S!=
M*2D@>PT*("`@("`@("`@("`@)&9U;F-T:6]N<R`](&%R<F%Y*"1F=6YC=&EO
M;G,I.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1F=6YC=&EO;G,@
M87,@)&9U;F-T:6]N*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT
M/&9U;F-T:6]N('9E<G-I;VX]7"(B("X@)&9U;F-T:6]N6R=A='1R:6)S)UU;
M)W9E<G-I;VXG72`N(")<(B([#0H@("`@("`@("`@("!I9B`H)')E<W0I('L-
M"B`@("`@("`@("`@("`@("`D<F5T("X]("<@=7)I/2(G("X@)&9U;F-T:6]N
M6R=A='1R:6)S)UU;)W5R:2==("X@)R(G.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)')E="`N/2`B/B(@+B`D9G5N8W1I;VY;)U]C;VYT96YT)UT@
M+B`B/"]F=6YC=&EO;CY<;B([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5F%L:61A=&EO;B!E
M<G)O<BX@($%L<V\@;6%R:W,@=&AE(&]B:F5C="!C;VYT96YT<R!A<R!I;G9A
M;&ED#0H@("`@("H@0'!A<F%M(&5R<F]R(&-O9&4-"B`@("`@*B!`<&%R86T@
M87)R87D@97)R;W(@:6YF;W)M871I;VX-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5%<G)O<B@D8V]D
M92P@)'!A<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*"1C;V1E+"`G97)R;W(G+"`D<&%R86US*3L-"B`@("`@
M("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@5F%L:61A=&EO;B!W87)N:6YG+B`@1&]E<R!N;W0@;6%R:R!T
M:&4@;V)J96-T(&-O;G1E;G1S(&EN=F%L:60N#0H@("`@("H@0'!A<F%M(&5R
M<F]R(&-O9&4-"B`@("`@*B!`<&%R86T@87)R87D@97)R;W(@:6YF;W)M871I
M;VX-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?=F%L:61A=&5787)N:6YG*"1C;V1E+"`D<&%R86US(#T@87)R87DH
M*2D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)&-O9&4L
M("=W87)N:6YG)RP@)'!A<F%M<RD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5F%L:61A=&4@<&%R<V5D(&9I;&4N#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('9A;&ED871E*"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?:7-686QI9"`]('1R=64[#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]C
M:&%N;F5L26YF;SL-"B`@("`@("`@:68@*&5M<'1Y*"1I;F9O6R=N86UE)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E].3U].04U%*3L-"B`@("`@("`@?2!E;'-E:68@
M*"$D=&AI<RT^=F%L:61#:&%N;F5L4V5R=F5R*"1I;F9O6R=N86UE)UTI*2![
M#0H@("`@("`@("`@("!I9B`H)&EN9F];)VYA;64G72`A/2`G7U]U<FDG*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?
M0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%].04U%+"!A<G)A>2@G=&%G)R`]
M/B`G;F%M92<L#0H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D:6YF
M;ULG;F%M92==*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&5M<'1Y*"1I;F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E].3U]354U-05)9*3L-"B`@("`@("`@?2!E;'-E:68@*'-T<G!O<RAT<FEM
M*"1I;F9O6R=S=6UM87)Y)UTI+"`B7&XB*2`A/3T@9F%L<V4I('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?355,5$E,24Y%7U-534U!4EDL#0H@("`@("`@("`@("`@("`@
M87)R87DH)W-U;6UA<GDG(#T^("1I;F9O6R=S=6UM87)Y)UTI*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];)W-U9V=E<W1E9&%L:6%S
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3YV86QI9$-H86YN96Q3
M97)V97(H)&EN9F];)W-U9V=E<W1E9&%L:6%S)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?
M15)23U)?24Y604Q)1%].04U%+`T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G=&%G)R`]/B`G<W5G9V5S=&5D86QI87,G+"`G;F%M92<@/3XD:6YF;ULG
M<W5G9V5S=&5D86QI87,G72DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG;&]C86QA;&EA<R==*2D@>PT*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^=F%L:61#:&%N;F5L4V5R=F5R*"1I
M;F9O6R=L;V-A;&%L:6%S)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)
M1%].04U%+`T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@G=&%G)R`]/B`G
M;&]C86QA;&EA<R<L("=N86UE)R`]/B1I;F9O6R=L;V-A;&%L:6%S)UTI*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&EN9F];)W9A;&ED871E<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D:6YF;ULG=F%L:61A=&5P86-K86=E)UU;)U]C;VYT96YT)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?0TA!3DY%3$9)3$5?15)23U)?3D]604Q)1$%415].04U%*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)W9A;&ED
M871E<&%C:V%G92==6R=A='1R:6)S)UU;)W9E<G-I;VXG72DI('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,
M1DE,15]%4E)/4E].3U9!3$E$051%7U9%4E-)3TXL#0H@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B!`)&EN9F];)W9A;&ED871E<&%C
M:V%G92==6R=?8V]N=&5N="==*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA
M<GDG75LG871T<FEB<R==6R=P;W)T)UTI("8F#0H@("`@("`@("`@("`@("%I
M<U]N=6UE<FEC*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG871T<FEB
M<R==6R=P;W)T)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7U!/4E0L#0H@
M("`@("`@("`@("`@("`@87)R87DH)W!O<G0G(#T^("1I;F9O6R=S97)V97)S
M)UU;)W!R:6UA<GDG75LG871T<FEB<R==6R=P;W)T)UTI*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];)W-E<G9E<G,G75LG<')I;6%R
M>2==6R=A='1R:6)S)UU;)W-S;"==*2`F)@T*("`@("`@("`@("`@("`D:6YF
M;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<W-L)UT@(3T@
M)WEE<R<I('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA0
M14%27T-(04Y.14Q&24Q%7T524D]27TE.5D%,241?4U-,+`T*("`@("`@("`@
M("`@("`@(&%R<F%Y*"=S<VPG(#T^("1I;F9O6R=S97)V97)S)UU;)W!R:6UA
M<GDG75LG871T<FEB<R==6R=S<VPG72P-"B`@("`@("`@("`@("`@("`@("`@
M)W-E<G9E<B<@/3X@)&EN9F];)VYA;64G72DI.PT*("`@("`@("!]#0H-"B`@
M("`@("`@:68@*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG
M>&UL<G!C)UTI("8F#0H@("`@("`@("`@("`@(&ES<V5T*"1I;F9O6R=S97)V
M97)S)UU;)W!R:6UA<GDG75LG>&UL<G!C)UU;)V9U;F-T:6]N)UTI*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1G5N8W1I;VYS*"=X;6QR<&,G
M+"`D:6YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)WAM;')P8R==6R=F=6YC
M=&EO;B==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];
M)W-E<G9E<G,G75LG<')I;6%R>2==6R=S;V%P)UTI("8F#0H@("`@("`@("`@
M("`@(&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<V]A<"==
M6R=F=6YC=&EO;B==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T
M949U;F-T:6]N<R@G<V]A<"<L("1I;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG
M75LG<V]A<"==6R=F=6YC=&EO;B==*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=R97-T)UTI
M("8F#0H@("`@("`@("`@("`@(&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)W!R
M:6UA<GDG75LG<F5S="==6R=B87-E=7)L)UTI*2![#0H@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E1G5N8W1I;VYS*"=R97-T)RP@)&EN9F];)W-E<G9E
M<G,G75LG<')I;6%R>2==6R=R97-T)UU;)V)A<V5U<FPG72D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S97)V97)S)UU;)VUI<G)O
M<B==*2D@>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)VYA;64G72`]/2`G7U]U<FDG*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?55))7T-!3E1?34E2
M4D]2*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)&EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@/2!A<G)A>2@D:6YF
M;ULG<V5R=F5R<R==6R=M:7)R;W(G72D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D:2`](#`[#0H@("`@("`@("`@("!F;W)E86-H("@D:6YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G72!A<R`D;6ER<F]R*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?2$]35"P-"B`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G='EP92<@/3X@)VUI<G)O<B<I*3L-"B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(21T:&ES+3YV86QI9$-H86YN96Q397)V
M97(H)&UI<G)O<ELG871T<FEB<R==6R=H;W-T)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&
M24Q%7T524D]27TE.5D%,241?2$]35"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y*"=S97)V97(G(#T^("1M:7)R;W);)V%T=')I8G,G75LG:&]S
M="==+"`G='EP92<@/3X@)VUI<G)O<B<I*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1M:7)R;W);)V%T=')I8G,G
M75LG<W-L)UTI("8F("1M:7)R;W);)V%T=')I8G,G75LG<W-L)UT@(3T@)WEE
M<R<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R
M<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)1%]34TPL#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<W-L)R`]/B`D:6YF;ULG<W-L
M)UTL("=S97)V97(G(#T^("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D;6ER<F]R6R=X;6QR<&,G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]V86QI9&%T949U;F-T:6]N<R@G>&UL<G!C)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1M:7)R;W);)WAM;')P8R==6R=F=6YC=&EO;B==
M+"`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;6ER<F]R6R=S;V%P
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5&
M=6YC=&EO;G,H)W-O87`G+"`D;6ER<F]R6R=S;V%P)UU;)V9U;F-T:6]N)UTL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D;6ER<F]R6R=A='1R:6)S)UU;
M)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D;6ER<F]R6R=R97-T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5&=6YC=&EO;G,H)W)E<W0G+"`D;6ER
M<F]R6R=R97-T)UU;)V)A<V5U<FPG72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*3L-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?:7-686QI9#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!`<&%R86T@<W1R:6YG('AM;')P8R!O<B!S;V%P("T@<')O=&]C;VP@;F%M
M92!T:&ES(&9U;F-T:6]N(&%P<&QI97,@=&\-"B`@("`@*B!`<&%R86T@87)R
M87D@=&AE(&9U;F-T:6]N<PT*("`@("`J($!P87)A;2!S=')I;F<@=&AE(&YA
M;64@;V8@=&AE('!A<F5N="!E;&5M96YT("AM:7)R;W(@;F%M92P@9F]R(&EN
M<W1A;F-E*0T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]V86QI9&%T949U;F-T
M:6]N<R@D<')O=&]C;VPL("1F=6YC=&EO;G,L("1P87)E;G0@/2`G)RD-"B`@
M("![#0H@("`@("`@(&EF("@A:7-S970H)&9U;F-T:6]N<ULP72DI('L-"B`@
M("`@("`@("`@("1F=6YC=&EO;G,@/2!A<G)A>2@D9G5N8W1I;VYS*3L-"B`@
M("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9G5N8W1I;VYS(&%S("1F=6YC
M=&EO;BD@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9G5N8W1I;VY;)U]C
M;VYT96YT)UTI('Q\(&5M<'1Y*"1F=6YC=&EO;ELG7V-O;G1E;G0G72DI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E].3U]&54Y#5$E/3DY!344L#0H@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=P87)E;G0G(#T^("1P87)E;G0L("=P<F]T;V-O
M;"<@/3X@)'!R;W1O8V]L*2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H)'!R;W1O8V]L(#T]("=R97-T)RD@>PT*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&9U;F-T:6]N6R=A='1R:6)S)UU;)W1Y<&4G72D@?'P-
M"B`@("`@("`@("`@("`@("`@("`@("!E;7!T>2@D9G5N8W1I;VY;)V%T=')I
M8G,G75LG='EP92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]"05-%
M55),5%E012P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P87)E
M;G0G(#T^("1P87)E;G0L("=P<F]T;V-O;"<@/3X@)'!R;W1O8V]L*2D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1F=6YC=&EO;ELG871T<FEB<R==6R=V
M97)S:6]N)UTI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@96UP='DH)&9U
M;F-T:6]N6R=A='1R:6)S)UU;)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)
M3$5?15)23U)?3D]?1E5.0U1)3TY615)324].+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)W!A<F5N="<@/3X@)'!A<F5N="P@)W!R;W1O8V]L
M)R`]/B`D<')O=&]C;VPI*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4
M97-T('=H971H97(@82!S=')I;F<@8V]N=&%I;G,@82!V86QI9"!C:&%N;F5L
M('-E<G9E<BX-"B`@("`@*B!`<&%R86T@<W1R:6YG("1V97(@=&AE('!A8VMA
M9V4@=F5R<VEO;B!T;R!T97-T#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@=F%L:61#:&%N;F5L4V5R=F5R*"1S97)V97(I
M#0H@("`@>PT*("`@("`@("!I9B`H)'-E<G9E<B`]/2`G7U]U<FDG*2![#0H@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@*&)O;VPI('!R96=?;6%T8V@H4$5!4E]#2$%.3D5,4U]315)615)?
M4%)%1RP@)'-E<G9E<BD[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E
M='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971.
M86UE*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN
M96Q);F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG;F%M92==.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0')E='5R;B!S=')I;F=\9F%L<V4-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971397)V97(H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)VYA;64G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UT[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(&EN
M='PX,"!P;W)T(&YU;6)E<B!T;R!C;VYN96-T('1O#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9V5T4&]R="@D;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@
M("`@("!I9B`H)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"1M:7(@/2`D
M=&AI<RT^9V5T36ER<F]R*"1M:7)R;W(I*2![#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1M:7);)V%T=')I8G,G75LG<&]R="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&UI<ELG871T<FEB<R==6R=P;W)T)UT[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3YG97134TPH)&UI<G)O<BDI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`T-#,[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#@P.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C
M:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG
M<&]R="==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S)UU;)W!O<G0G
M73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/F=E=%-33"@I*2![
M#0H@("`@("`@("`@("!R971U<FX@-#0S.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`X,#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N
M(&)O;VP@1&5T97)M:6YE<R!W:&5T:&5R('-E8W5R92!S;V-K971S(&QA>65R
M("A34TPI(&ES('5S960@=&\@8V]N;F5C="!T;R!T:&ES(&-H86YN96P-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G97134TPH)&UI<G)O<B`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF
M("@D;6ER(#T@)'1H:7,M/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D;6ER6R=A='1R:6)S)UU;)W-S;"==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA
M<GDG75LG871T<FEB<R==6R=S<VPG72DI('L-"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%-U;6UA<GDH*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-U;6UA<GDG
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O
M6R=S=6UM87)Y)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@<W1R:6YG('AM;')P8R!O<B!S;V%P#0H@("`@("H@0'!A
M<F%M('-T<FEN9WQF86QS92!M:7)R;W(@;F%M92!O<B!F86QS92!F;W(@<')I
M;6%R>2!S97)V97(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9710871H*"1P
M<F]T;V-O;"P@)&UI<G)O<B`](&9A;'-E*0T*("`@('L@("`-"B`@("`@("`@
M:68@*"%I;E]A<G)A>2@D<')O=&]C;VPL(&%R<F%Y*"=X;6QR<&,G+"`G<V]A
M<"<I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H(2@D
M;6ER(#T@)'1H:7,M/F=E=$UI<G)O<B@D;6ER<F]R*2DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&UI<ELD<')O=&]C;VQ=6R=A='1R:6)S)UU;)W!A
M=&@G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)&UI<ELD<')O=&]C
M;VQ=6R=A='1R:6)S)UU;)W!A=&@G73L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P<F]T;V-O;"`N("<N<&AP)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1P<F]T;V-O
M;%U;)V%T=')I8G,G75LG<&%T:"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1P
M<F]T;V-O;%U;)V%T=')I8G,G75LG<&%T:"==.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<')O=&]C;VP@+B`G+G!H<"<[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!P<F]T;V-O;"!T>7!E("AX;6QR
M<&,L('-O87`I#0H@("`@("H@0'!A<F%M('-T<FEN9R!-:7)R;W(@;F%M90T*
M("`@("`J($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971&=6YC=&EO;G,H)'!R;W1O8V]L+"`D;6ER<F]R(#T@9F%L<V4I
M#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F=E=$YA;64H*2`]/2`G7U]U
M<FDG*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1P<F]T;V-O;"`]/2`G<F5S="<I('L-"B`@("`@("`@
M("`@("1F=6YC=&EO;B`]("=B87-E=7)L)SL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1F=6YC=&EO;B`]("=F=6YC=&EO;B<[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@("`@(&EF("@D
M;6ER(#T@)'1H:7,M/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D;6ER6R1P<F]T;V-O;%U;)&9U;F-T:6]N72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1M:7);)'!R;W1O8V]L
M75LD9G5N8W1I;VY=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=P<FEM87)Y)UU;)'!R;W1O8V]L75LD9G5N8W1I;VY=*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG
M<')I;6%R>2==6R1P<F]T;V-O;%U;)&9U;F-T:6]N73L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@4')O=&]C
M;VP@='EP90T*("`@("`J($!P87)A;2!S=')I;F<@1G5N8W1I;VX@;F%M92`H
M;G5L;"!T;R!R971U<FX@=&AE#0H@("`@("H@("`@("`@("`@("`@("!F:7)S
M="!P<F]T;V-O;"!O9B!T:&4@='EP92!R97%U97-T960I#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!-:7)R;W(@;F%M92P@:68@86YY#0H@("`@("H@0')E='5R
M;B!A<G)A>0T*("`@("`J+PT*("`@("!F=6YC=&EO;B!G971&=6YC=&EO;B@D
M='EP92P@)&YA;64@/2!N=6QL+"`D;6ER<F]R(#T@9F%L<V4I#0H@("`@('L-
M"B`@("`@("`@)'!R;W1O8V]L<R`]("1T:&ES+3YG971&=6YC=&EO;G,H)'1Y
M<&4L("1M:7)R;W(I.PT*("`@("`@("!I9B`H(21P<F]T;V-O;',I('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F
M;W)E86-H("@D<')O=&]C;VQS(&%S("1P<F]T;V-O;"D@>PT*("`@("`@("`@
M("`@:68@*"1N86UE(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1P<F]T;V-O;#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@D<')O=&]C;VQ;)U]C;VYT96YT)UT@(3T@)&YA;64I('L-"B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(')E='5R;B`D<')O=&]C;VP[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG('!R;W1O8V]L('1Y<&4-"B`@("`@*B!`<&%R86T@<W1R:6YG('!R;W1O
M8V]L(&YA;64-"B`@("`@*B!`<&%R86T@<W1R:6YG('9E<G-I;VX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&UI<G)O<B!N86UE#0H@("`@("H@0')E='5R;B!B
M;V]L96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W5P<&]R=',H)'1Y<&4L
M("1N86UE(#T@;G5L;"P@)&UI<G)O<B`](&9A;'-E+"`D=F5R<VEO;B`]("<Q
M+C`G*0T*("`@('L-"B`@("`@("`@)'!R;W1O8V]L<R`]("1T:&ES+3YG971&
M=6YC=&EO;G,H)'1Y<&4L("1M:7)R;W(I.PT*("`@("`@("!I9B`H(21P<F]T
M;V-O;',I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D<')O=&]C;VQS(&%S("1P<F]T;V-O;"D@
M>PT*("`@("`@("`@("`@:68@*"1P<F]T;V-O;%LG871T<FEB<R==6R=V97)S
M:6]N)UT@(3T@)'9E<G-I;VXI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D;F%M92`]/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"1P<F]T;V-O;%LG7V-O;G1E;G0G
M72`A/2`D;F%M92D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($1E=&5R;6EN97,@=VAE=&AE<B!A(&-H86YN96P@<W5P<&]R=',@
M4F5P<F5S96YT871I;VYA;"!3=&%T92!4<F%N<V9E<B`H4D535"D@<')O=&]C
M;VQS#0H@("`@("H@9F]R(')E=')I979I;F<@8VAA;FYE;"!I;F9O<FUA=&EO
M;@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<F5T=7)N(&)O;VP-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=7!P;W)T<U)%4U0H)&UI<G)O<B`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(@/3T@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG;F%M92==*2![#0H@("`@("`@("`@("`D;6ER<F]R
M(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M:7)R;W(I('L-
M"B`@("`@("`@("`@(&EF("@D;6ER(#T@)'1H:7,M/F=E=$UI<G)O<B@D;6ER
M<F]R*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!I<W-E="@D;6ER6R=R
M97-T)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LG<F5S="==*3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(%523"!T;R!A8V-E
M<W,@82!B87-E(')E<V]U<F-E+@T*("`@("`J#0H@("`@("H@2'EP97)L:6YK
M<R!I;B!T:&4@<F5T=7)N960@>&UL('=I;&P@8F4@=7-E9"!T;R!R971R:65V
M92!T:&4@<')O<&5R(&EN9F]R;6%T:6]N#0H@("`@("H@;F5E9&5D+B`@5&AI
M<R!A;&QO=W,@97AT<F5M92!E>'1E;G-I8FEL:71Y(&%N9"!F;&5X:6)I;&ET
M>2!I;B!I;7!L96UE;G1A=&EO;@T*("`@("`J($!P87)A;2!S=')I;F<@4F5S
M;W5R8V4@5'EP92!T;R!R971R:65V90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$)A<V554DPH)')E<V]U<F-E5'EP92P@)&UI<G)O<B`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(@/3T@)'1H:7,M/E]C:&%N;F5L
M26YF;ULG;F%M92==*2![#0H@("`@("`@("`@("`D;6ER<F]R(#T@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M:7)R;W(I('L-"B`@("`@("`@
M("`@(&EF("@D;6ER(#T@)'1H:7,M/F=E=$UI<G)O<B@D;6ER<F]R*2D@>PT*
M("`@("`@("`@("`@("`@("1R97-T(#T@)&UI<ELG<F5S="==.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<V5R=F5R(#T@)&UI<G)O
M<CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R97-T(#T@)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)W)E<W0G
M73L-"B`@("`@("`@("`@("1S97)V97(@/2`D=&AI<RT^9V5T4V5R=F5R*"D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D<F5S=%LG8F%S975R
M;"==6S!=*2D@>PT*("`@("`@("`@("`@)')E<W1;)V)A<V5U<FPG72`](&%R
M<F%Y*"1R97-T6R=B87-E=7)L)UTI.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1R97-T6R=B87-E=7)L)UT@87,@)&)A<V5U<FPI('L-"B`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1B87-E=7)L6R=A='1R:6)S)UU;)W1Y
M<&4G72D@/3T@<W1R=&]L;W=E<B@D<F5S;W5R8V54>7!E*2D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D8F%S975R;%LG7V-O;G1E;G0G73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4VEN8V4@4D535"!D;V5S(&YO="!I
M;7!L96UE;G0@4E!#+"!P<F]V:61E('1H:7,@87,@82!L;V=I8V%L('=R87!P
M97(@87)O=6YD#0H@("`@("H@<F5S971&=6YC=&EO;G,@9F]R(%)%4U0-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&UI<G)O<B!N86UE+"!I9B!A;GD-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R97-E=%)%4U0H)&UI<G)O<B`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YR97-E=$9U;F-T
M:6]N<R@G<F5S="<L("1M:7)R;W(I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($5M<'1Y(&%L;"!P<F]T;V-O;"!D969I;FET:6]N<PT*("`@("`J($!P
M87)A;2!S=')I;F<@<')O=&]C;VP@='EP92`H>&UL<G!C+"!S;V%P*0T*("`@
M("`J($!P87)A;2!S=')I;F=\9F%L<V4@;6ER<F]R(&YA;64L(&EF(&%N>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(')E<V5T1G5N8W1I;VYS*"1T>7!E+"`D
M;6ER<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)&UI<G)O<BD@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];
M)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`@("`@)&UI
M<G)O<G,@/2`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O
M<B==.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&UI<G)O<G-;,%TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1M:7)R;W)S(#T@87)R87DH)&UI
M<G)O<G,I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D;6ER<F]R<R!A<R`D:2`]/B`D;6ER*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;6ER6R=A='1R:6)S)UU;)VAO<W0G72`]/2`D;6ER
M<F]R*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LD:5U;)'1Y
M<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=6R1T
M>7!E72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)W!R:6UA<GDG75LD='EP95TI*2![#0H@("`@("`@
M("`@("`@("`@=6YS970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=P<FEM87)Y)UU;)'1Y<&5=*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@4V5T(&$@8VAA;FYE;"=S('!R;W1O8V]L<R!T;R!T:&4@<')O
M=&]C;VQS('-U<'!O<G1E9"!B>2!P96%R=V5B#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@<V5T1&5F875L=%!%05)0<F]T;V-O;',H)'9E<G-I;VX@/2`G,2XP
M)RP@)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@<W=I=&-H("@D
M=F5R<VEO;BD@>PT*("`@("`@("`@("`@8V%S92`G,2XP)R`Z#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/G)E<V5T1G5N8W1I;VYS*"=X;6QR<&,G+"`D;6ER
M<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S971&=6YC=&EO;G,H
M)W-O87`G+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S
M971215-4*"1M:7)R;W(I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YA9&1&
M=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=L;V=I;G1E<W0G+"`D;6ER<F]R
M*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N8W1I;VXH)WAM;')P
M8R<L("<Q+C`G+"`G<&%C:V%G92YL:7-T3&%T97-T4F5L96%S97,G+"`D;6ER
M<F]R*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^861D1G5N8W1I;VXH)WAM
M;')P8R<L("<Q+C`G+"`G<&%C:V%G92YL:7-T06QL)RP@)&UI<G)O<BD[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G
M,2XP)RP@)W!A8VMA9V4N:6YF;R<L("1M:7)R;W(I.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,"<L("=P86-K
M86=E+F=E=$1O=VYL;V%D55),)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XQ)RP@)W!A8VMA
M9V4N9V5T1&]W;FQO86154DPG+"`D;6ER<F]R*3L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^861D1G5N8W1I;VXH)WAM;')P8R<L("<Q+C`G+"`G<&%C:V%G
M92YG971$97!$;W=N;&]A9%523"<L("1M:7)R;W(I.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YA9&1&=6YC=&EO;B@G>&UL<G!C)RP@)S$N,2<L("=P86-K
M86=E+F=E=$1E<$1O=VYL;V%D55),)RP@)&UI<G)O<BD[#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)W!A
M8VMA9V4N<V5A<F-H)RP@)&UI<G)O<BD[#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F%D9$9U;F-T:6]N*"=X;6QR<&,G+"`G,2XP)RP@)V-H86YN96PN;&ES
M=$%L;"<L("1M:7)R;W(I.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!D969A=6QT(#H-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@?0T*("`@('T-"B`@("`-"B`@("`O*BH-"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T36ER
M<F]R<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N
M;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G72DI('L-"B`@("`@("`@("`@
M("1M:7)R;W)S(#T@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&UI<G)O<G-;,%TI
M*2![#0H@("`@("`@("`@("`@("`@)&UI<G)O<G,@/2!A<G)A>2@D;6ER<F]R
M<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&UI<G)O
M<G,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@87)R
M87DH*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($=E
M="!T:&4@=6YS97)I86QI>F5D(%A-3"!R97!R97-E;G1I;F<@82!M:7)R;W(-
M"B`@("`@*B!`<F5T=7)N(&%R<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T36ER<F]R*"1S97)V97(I#0H@("`@>PT*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^9V5T36ER<F]R<R@I(&%S("1M:7)R;W(I('L-"B`@("`@
M("`@("`@(&EF("@D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72`]/2`D<V5R
M=F5R*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1M:7)R;W([#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@
M*B!`<F5T=7)N('-T<FEN9WQF86QS90T*("`@("`J($!E<G)O<B!014%27T-(
M04Y.14Q&24Q%7T524D]27TY/7TY!344-"B`@("`@*B!`97)R;W(@4$5!4E]#
M2$%.3D5,1DE,15]%4E)/4E])3E9!3$E$7TY!344-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!S971.86UE*"1N86UE*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("1T:&ES+3YS971397)V97(H)&YA;64I.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J(%-E="!T:&4@<V]C:V5T(&YU;6)E<B`H<&]R="D@=&AA="!I<R!U
M<V5D('1O(&-O;FYE8W0@=&\@=&AI<R!C:&%N;F5L#0H@("`@("H@0'!A<F%M
M(&EN=&5G97(-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&YA;64@;V8@
M=&AE(&UI<G)O<B!S97)V97(L(&]R(&9A;'-E(&9O<B!T:&4@<')I;6%R>0T*
M("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%!O<G0H)'!O<G0L("1M:7)R;W(@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D;6ER<F]R*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M86QI9&%T945R<F]R*%!%05)?0TA!3DY%3$9)3$5?15)23U)?34E24D]27TY/
M5%]&3U5.1"P-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@
M/3X@)&UI<G)O<BDI.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1S971M:7)R;W(@/2!F86QS
M93L-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)VUI<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER
M<F]R)UT@87,@)&D@/3X@)&UI<BD@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&UI<G)O<B`]/2`D;6ER6R=A='1R:6)S)UU;)VAO<W0G72D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R
M=F5R<R==6R=M:7)R;W(G75LD:5U;)V%T=')I8G,G75LG<&]R="==(#T@)'!O
M<G0[#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!](&5L<V5I
M9B`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG
M871T<FEB<R==6R=H;W-T)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;
M)V%T=')I8G,G75LG<&]R="==(#T@)'!O<G0[#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM87)Y)UU;)V%T
M=')I8G,G75LG<&]R="==(#T@)'!O<G0[#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](&9A;'-E.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!3970@=&AE('-O8VME="!N=6UB97(@*'!O<G0I
M('1H870@:7,@=7-E9"!T;R!C;VYN96-T('1O('1H:7,@8VAA;FYE;`T*("`@
M("`J($!P87)A;2!B;V]L($1E=&5R;6EN97,@=VAE=&AE<B!T;R!T=7)N(&]N
M(%-33"!S=7!P;W)T(&]R('1U<FX@:70@;V9F#0H@("`@("H@0'!A<F%M('-T
M<FEN9WQF86QS92!N86UE(&]F('1H92!M:7)R;W(@<V5R=F5R+"!O<B!F86QS
M92!F;W(@=&AE('!R:6UA<GD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S9713
M4TPH)'-S;"`]('1R=64L("1M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(&EF("@D;6ER<F]R*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UTI*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?0TA!
M3DY%3$9)3$5?15)23U)?34E24D]27TY/5%]&3U5.1"P-"B`@("`@("`@("`@
M("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI.PT*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1S971M:7)R;W(@/2!F86QS93L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==
M6S!=*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAA
M;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@87,@)&D@/3X@)&UI<BD@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&UI<G)O<B`]/2`D;6ER6R=A
M='1R:6)S)UU;)VAO<W0G72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"$D<W-L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R
M)UU;)&E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A
M='1R:6)S)UU;)W-S;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;
M)VUI<G)O<B==6R1I75LG871T<FEB<R==6R=S<VPG72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6R1I75LG871T<FEB
M<R==6R=S<VPG72`]("=Y97,G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?2!E;'-E:68@
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T
M=')I8G,G75LG:&]S="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@("`@("`@
M("!I9B`H(21S<VPI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T
M=')I8G,G75LG<W-L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!U
M;G-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==
M6R=A='1R:6)S)UU;)W-S;"==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)V%T
M=')I8G,G75LG<W-L)UT@/2`G>65S)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1S<VPI('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R=A='1R:6)S
M)UU;)W-S;"==(#T@)WEE<R<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=P<FEM87)Y)UU;)V%T=')I8G,G75LG<W-L)UTI*2![#0H@("`@("`@("`@
M("`@("`@=6YS970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P
M<FEM87)Y)UU;)V%T=')I8G,G75LG<W-L)UTI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!3970@=&AE('-O8VME="!N=6UB97(@*'!O<G0I('1H870@:7,@=7-E9"!T
M;R!C;VYN96-T('1O('1H:7,@8VAA;FYE;`T*("`@("`J($!P87)A;2!I;G1E
M9V5R#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!N86UE(&]F('1H92!M
M:7)R;W(@<V5R=F5R+"!O<B!F86QS92!F;W(@=&AE('!R:6UA<GD-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S9710871H*"1P<F]T;V-O;"P@)'!A=&@L("1M
M:7)R;W(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:6Y?87)R87DH
M)'!R;W1O8V]L+"!A<G)A>2@G>&UL<G!C)RP@)W-O87`G*2DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)&UI<G)O<BD@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-H
M86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%
M7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D
M<V5T;6ER<F]R(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LP72DI('L-
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)VUI<G)O<B==(&%S("1I(#T^("1M:7(I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1M:7)R;W(@/3T@)&UI<ELG871T<FEB<R==
M6R=H;W-T)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=6R1P<F]T;V-O
M;%U;)V%T=')I8G,G75LG<&%T:"==(#T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%T:#L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA0
M14%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]
M(&5L<V5I9B`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R
M;W(G75LG871T<FEB<R==6R=H;W-T)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER
M<F]R)UU;)'!R;W1O8V]L75LG871T<FEB<R==6R=P871H)UT@/2`D<&%T:#L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S
M)UU;)W!R:6UA<GDG75LD<')O=&]C;VQ=6R=A='1R:6)S)UU;)W!A=&@G72`]
M("1P871H.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M('-T<FEN9PT*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E#0H@
M("`@("H@0&5R<F]R(%!%05)?0TA!3DY%3$9)3$5?15)23U)?3D]?4T525D52
M#0H@("`@("H@0&5R<F]R(%!%05)?0TA!3DY%3$9)3$5?15)23U)?24Y604Q)
M1%]315)615(-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971397)V97(H)'-E
M<G9E<BP@)&UI<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*&5M
M<'1Y*"1S97)V97(I*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E
M17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]315)615(I.PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!](&5L<V5I9B`H(21T
M:&ES+3YV86QI9$-H86YN96Q397)V97(H)'-E<G9E<BDI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T52
M4D]27TE.5D%,241?3D%-12P-"B`@("`@("`@("`@("`@("!A<G)A>2@G=&%G
M)R`]/B`G;F%M92<L("=N86UE)R`]/B`D<V5R=F5R*2D[#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1M:7)R
M;W(I('L-"B`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M
M:7)R;W(G72!A<R`D:2`]/B`D;6ER*2![#0H@("`@("`@("`@("`@("`@:68@
M*"1M:7)R;W(@/3T@)&UI<ELG871T<FEB<R==6R=H;W-T)UTI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*"$D9F]U;F0I('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/
M4E]-25)23U)?3D]47T9/54Y$+`T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G;6ER<F]R)R`]/B`D;6ER<F]R*2D[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M
M/E]C:&%N;F5L26YF;ULG;6ER<F]R)UU;)&E=6R=A='1R:6)S)UU;)VAO<W0G
M72`]("1S97)V97([#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=N86UE)UT@/2`D
M<V5R=F5R.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!B;V]L
M96%N('-U8V-E<W,-"B`@("`@*B!`97)R;W(@4$5!4E]#2$%.3D5,1DE,15]%
M4E)/4E].3U]354U-05)9#0H@("`@("H@0'=A<FYI;F<@4$5!4E]#2$%.3D5,
M1DE,15]%4E)/4E]-54Q424Q)3D5?4U5-34%260T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=%-U;6UA<GDH)'-U;6UA<GDI#0H@("`@>PT*("`@("`@("!I
M9B`H96UP='DH)'-U;6UA<GDI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E].3U]354U-05)9
M*3L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?2!E;'-E
M:68@*'-T<G!O<RAT<FEM*"1S=6UM87)Y*2P@(EQN(BD@(3T](&9A;'-E*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E5V%R;FEN9RA014%27T-(
M04Y.14Q&24Q%7T524D]27TU53%1)3$E.15]354U-05)9+`T*("`@("`@("`@
M("`@("`@(&%R<F%Y*"=S=6UM87)Y)R`]/B`D<W5M;6%R>2DI.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-U;6UA<GDG72`]
M("1S=6UM87)Y.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0'!A<F%M(&)O
M;VQE86X@9&5T97)M:6YE<R!W:&5T:&5R('1H92!A;&EA<R!I<R!I;B!C:&%N
M;F5L+GAM;"!O<B!L;V-A;`T*("`@("`J($!R971U<FX@8F]O;&5A;B!S=6-C
M97-S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T06QI87,H)&%L:6%S+"`D
M;&]C86P@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/G9A
M;&ED0VAA;FYE;%-E<G9E<B@D86QI87,I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E17)R;W(H4$5!4E]#2$%.3D5,1DE,15]%4E)/4E])3E9!
M3$E$7TY!344L#0H@("`@("`@("`@("`@("`@87)R87DH)W1A9R<@/3X@)W-U
M9V=E<W1E9&%L:6%S)RP@)VYA;64G(#T^("1A;&EA<RDI.PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;&]C
M86PI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)VQO8V%L
M86QI87,G72`]("1A;&EA<SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-U9V=E<W1E9&%L:6%S)UT@/2`D
M86QI87,[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!G971!;&EA<R@I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG;&]C86QA;&EA<R==*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8VAA;FYE;$EN9F];)VQO8V%L
M86QI87,G73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/E]C:&%N;F5L26YF;ULG<W5G9V5S=&5D86QI87,G72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7V-H86YN96Q);F9O6R=S=6=G97-T961A;&EA
M<R==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H
M86YN96Q);F9O6R=N86UE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]C:&%N;F5L26YF;ULG;F%M92==.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@4V5T('1H92!P86-K86=E('9A;&ED871I;VX@
M;V)J96-T(&EF(&ET(&1I9F9E<G,@9G)O;2!014%2)W,@9&5F875L=`T*("`@
M("`J(%1H92!C;&%S<R!M=7-T(&)E(&EN8VQU9&5A8FQE('9I82!C:&%N9VEN
M9R!?(&EN('1H92!C;&%S<VYA;64@=&\@<&%T:"!S97!A<F%T;W(L#0H@("`@
M("H@8G5T(&YO(&-H96-K:6YG(&]F('1H:7,@:7,@;6%D92X-"B`@("`@*B!`
M<&%R86T@<W1R:6YG?&9A;'-E('!A<W,@:6X@9F%L<V4@=&\@<F5S970@=&\@
M=&AE(&1E9F%U;'0@<&%C:V%G96YA;64@<F5G97@-"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@<W5C8V5S<PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%9A
M;&ED871I;VY086-K86=E*"1V86QI9&%T96-L87-S+"`D=F5R<VEO;BD-"B`@
M("![#0H@("`@("`@(&EF("AE;7!T>2@D=F%L:61A=&5C;&%S<RDI('L-"B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E
M<&%C:V%G92==*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H86YN
M96Q);F9O6R=V86QI9&%T97!A8VMA9V4G72`](&%R<F%Y*"=?8V]N=&5N="<@
M/3X@)'9A;&ED871E8VQA<W,I.PT*("`@("`@("`D=&AI<RT^7V-H86YN96Q)
M;F9O6R=V86QI9&%T97!A8VMA9V4G75LG871T<FEB<R==(#T@87)R87DH)W9E
M<G-I;VXG(#T^("1V97)S:6]N*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!!9&0@82!P<F]T;V-O;"!T;R!T:&4@<')O=FED97,@<V5C=&EO;@T*("`@
M("`J($!P87)A;2!S=')I;F<@<')O=&]C;VP@='EP90T*("`@("`J($!P87)A
M;2!S=')I;F<@<')O=&]C;VP@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I
M;F<@<')O=&]C;VP@;F%M92P@:68@86YY#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!M:7)R;W(@;F%M92P@:68@=&AI<R!I<R!A(&UI<G)O<B=S('!R;W1O8V]L
M#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M861D1G5N8W1I;VXH)'1Y<&4L("1V97)S:6]N+"`D;F%M92`]("<G+"`D;6ER
M<F]R(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)&UI<G)O<BD@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YA9&1-:7)R;W)&=6YC=&EO;B@D
M;6ER<F]R+"`D='EP92P@)'9E<G-I;VXL("1N86UE*3L-"B`@("`@("`@?0T*
M("`@("`@("`D<V5T(#T@87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=V97)S
M:6]N)R`]/B`D=F5R<VEO;BDL("=?8V]N=&5N="<@/3X@)&YA;64I.PT*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG<')I;6%R>2==6R1T>7!E75LG9G5N8W1I;VXG72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG<')I;6%R>2==
M6R1T>7!E75LG9G5N8W1I;VXG72`]("1S970[#0H@("`@("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN
M9F];)W-E<G9E<G,G75LG<')I;6%R>2==6R1T>7!E75LG9G5N8W1I;VXG75LP
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E
M<G,G75LG<')I;6%R>2==6R1T>7!E75LG9G5N8W1I;VXG72`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG<')I;6%R>2==6R1T>7!E75LG9G5N8W1I;VXG72D[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P<FEM
M87)Y)UU;)'1Y<&5=6R=F=6YC=&EO;B==6UT@/2`D<V5T.PT*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H@("`@+RHJ#0H@("`@("H@061D(&$@<')O
M=&]C;VP@=&\@82!M:7)R;W(G<R!P<F]V:61E<R!S96-T:6]N#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!M:7)R;W(@;F%M92`H<V5R=F5R*0T*("`@("`J($!P
M87)A;2!S=')I;F<@<')O=&]C;VP@='EP90T*("`@("`J($!P87)A;2!S=')I
M;F<@<')O=&]C;VP@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<')O
M=&]C;VP@;F%M92P@:68@86YY#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D
M36ER<F]R1G5N8W1I;VXH)&UI<G)O<BP@)'1Y<&4L("1V97)S:6]N+"`D;F%M
M92`]("<G*0T*("`@('L-"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@
M("`@(&EF("@A:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=M:7)R;W(G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L
M#0H@("`@("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@)&UI<G)O<BDI
M.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@("1S971M:7)R;W(@/2!F86QS93L-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;,%TI*2![
M#0H@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7V-H86YN96Q);F9O6R=S
M97)V97)S)UU;)VUI<G)O<B==(&%S("1I(#T^("1M:7(I('L-"B`@("`@("`@
M("`@("`@("!I9B`H)&UI<G)O<B`]/2`D;6ER6R=A='1R:6)S)UU;)VAO<W0G
M72D@>PT*("`@("`@("`@("`@("`@("`@("`D<V5T;6ER<F]R(#T@)B1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UU;)&E=.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=M:7)R;W(G75LG
M871T<FEB<R==6R=H;W-T)UT@/3T@)&UI<G)O<BD@>PT*("`@("`@("`@("`@
M("`@("1S971M:7)R;W(@/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R
M<R==6R=M:7)R;W(G73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21S971M:7)R;W(I('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].
M3U1?1D]53D0L#0H@("`@("`@("`@("`@("`@87)R87DH)VUI<G)O<B<@/3X@
M)&UI<G)O<BDI.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H@("`@("`@("1S970@/2!A<G)A>2@G871T<FEB<R<@/3X@87)R87DH
M)W9E<G-I;VXG(#T^("1V97)S:6]N*2P@)U]C;VYT96YT)R`]/B`D;F%M92D[
M#0H@("`@("`@(&EF("@A:7-S970H)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T
M:6]N)UTI*2![#0H@("`@("`@("`@("`D<V5T;6ER<F]R6R1T>7!E75LG9G5N
M8W1I;VXG72`]("1S970[#0H@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@
M/2!F86QS93L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]
M(&5L<V5I9B`H(6ES<V5T*"1S971M:7)R;W);)'1Y<&5=6R=F=6YC=&EO;B==
M6S!=*2D@>PT*("`@("`@("`@("`@)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T
M:6]N)UT@/2!A<G)A>2@D<V5T;6ER<F]R6R1T>7!E75LG9G5N8W1I;VXG72D[
M#0H@("`@("`@('T-"B`@("`@("`@)'-E=&UI<G)O<ELD='EP95U;)V9U;F-T
M:6]N)UU;72`]("1S970[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A
M;'-E.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(%)E<V]U<F-E(%1Y<&4@=&AI<R!U<FP@
M;&EN:W,@=&\-"B`@("`@*B!`<&%R86T@<W1R:6YG(%523`T*("`@("`J($!P
M87)A;2!S=')I;F=\9F%L<V4@;6ER<F]R(&YA;64L(&EF('1H:7,@:7,@;F]T
M(&$@<')I;6%R>2!S97)V97(@4D535"!B87-E(%523`T*("`@("`J+PT*("`@
M(&9U;F-T:6]N('-E=$)A<V554DPH)')E<V]U<F-E5'EP92P@)'5R;"P@)&UI
M<G)O<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1M:7)R;W(I('L-
M"B`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O
M<B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O
M<BA014%27T-(04Y.14Q&24Q%7T524D]27TU)4E)/4E].3U1?1D]53D0L#0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=M:7)R;W(G(#T^("1M:7)R;W(I
M*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<V5T;6ER<F]R(#T@9F%L<V4[#0H@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==
M6R=M:7)R;W(G75LP72DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==(&%S("1I
M(#T^("1M:7(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1M:7)R;W(@
M/3T@)&UI<ELG871T<FEB<R==6R=H;W-T)UTI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1S971M:7)R;W(@/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG
M<V5R=F5R<R==6R=M:7)R;W(G75LD:5T[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R
M)UU;)V%T=')I8G,G75LG:&]S="==(#T]("1M:7)R;W(I('L-"B`@("`@("`@
M("`@("`@("`@("`@)'-E=&UI<G)O<B`]("8D=&AI<RT^7V-H86YN96Q);F9O
M6R=S97)V97)S)UU;)VUI<G)O<B==.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S
M971M:7)R;W(@/2`F)'1H:7,M/E]C:&%N;F5L26YF;ULG<V5R=F5R<R==6R=P
M<FEM87)Y)UT[#0H@("`@("`@('T-"B`@("`@("`@)'-E="`](&%R<F%Y*"=A
M='1R:6)S)R`]/B!A<G)A>2@G='EP92<@/3X@)')E<V]U<F-E5'EP92DL("=?
M8V]N=&5N="<@/3X@)'5R;"D[#0H@("`@("`@(&EF("@A:7-S970H)'-E=&UI
M<G)O<ELG<F5S="==6R=B87-E=7)L)UTI*2![#0H@("`@("`@("`@("`D<V5T
M;6ER<F]R6R=R97-T)UU;)V)A<V5U<FPG72`]("1S970[#0H@("`@("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1S971M:7)R;W);
M)W)E<W0G75LG8F%S975R;"==6S!=*2D@>PT*("`@("`@("`@("`@)'-E=&UI
M<G)O<ELG<F5S="==6R=B87-E=7)L)UT@/2!A<G)A>2@D<V5T;6ER<F]R6R=R
M97-T)UU;)V)A<V5U<FPG72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H)'-E=&UI<G)O<ELG<F5S="==6R=B87-E=7)L)UT@87,@)&D@/3X@)'5R
M;"D@>PT*("`@("`@("`@("`@:68@*"1U<FQ;)V%T=')I8G,G75LG='EP92==
M(#T]("1R97-O=7)C951Y<&4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@("`@("`@("`D<V5T;6ER<F]R
M6R=R97-T)UU;)V)A<V5U<FPG75LD:5T@/2`D<V5T.PT*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@("1S971M:7)R;W);)W)E<W0G75LG8F%S975R;"==6UT@/2`D<V5T
M.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!M:7)R;W(@<V5R=F5R#0H@("`@("H@0'!A<F%M(&EN="!M:7)R
M;W(@:'1T<"!P;W)T#0H@("`@("H@0')E='5R;B!B;V]L96%N#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@861D36ER<F]R*"1S97)V97(L("1P;W)T(#T@;G5L
M;"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7V-H86YN96Q);F9O6R=N
M86UE)UT@/3T@)U]?=7)I)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.R`O+R!T:&4@7U]U<FD@8VAA;FYE;"!C86YN;W0@:&%V92!M:7)R;W)S(&)Y
M(&1E9FEN:71I;VX-"B`@("`@("`@?0T*("`@("`@("`D<V5T(#T@87)R87DH
M)V%T=')I8G,G(#T^(&%R<F%Y*"=H;W-T)R`]/B`D<V5R=F5R*2D[#0H@("`@
M("`@(&EF("AI<U]N=6UE<FEC*"1P;W)T*2D@>PT*("`@("`@("`@("`@)'-E
M=%LG871T<FEB<R==6R=P;W)T)UT@/2`D<&]R=#L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8VAA;FYE;$EN9F];)W-E<G9E<G,G
M75LG;6ER<F]R)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q)
M;F9O6R=S97)V97)S)UU;)VUI<G)O<B==(#T@)'-E=#L-"B`@("`@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE
M;$EN9F];)W-E<G9E<G,G75LG;6ER<F]R)UT@/0T*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI
M<G)O<B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7V-H86YN96Q);F9O6R=S97)V97)S)UU;)VUI<G)O<B==6UT@/2`D
M<V5T.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!2971R:65V92!T:&4@;F%M92!O9B!T:&4@=F%L:61A=&EO;B!P
M86-K86=E(&9O<B!T:&ES(&-H86YN96P-"B`@("`@*B!`<F5T=7)N('-T<FEN
M9WQF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%9A;&ED871I;VY0
M86-K86=E*"D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<U9A;&ED
M("8F("$D=&AI<RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=V97)S:6]N
M)R`]/B`G9&5F875L="<I+`T*("`@("`@("`@("`@("`@("=?8V]N=&5N="<@
M/3X@)U!%05)?5F%L:61A=&4G*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P86-K86=E)UT[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T<FEE=F4@=&AE(&]B:F5C="!T
M:&%T(&-A;B!B92!U<V5D(&9O<B!C=7-T;VT@=F%L:61A=&EO;@T*("`@("`J
M($!P87)A;2!S=')I;F=\9F%L<V4@=&AE(&YA;64@;V8@=&AE('!A8VMA9V4@
M=&\@=F%L:61A=&4N("!)9B!T:&4@<&%C:V%G92!I<PT*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@=&AE(&-H86YN96P@=F%L:61A=&EO;B!P86-K86=E
M+"!014%27U9A;&ED871E(&ES(')E='5R;F5D#0H@("`@("H@0')E='5R;B!0
M14%27U9A;&ED871E?&9A;'-E(&9A;'-E(&ES(')E='5R;F5D(&EF('1H92!V
M86QI9&%T:6]N('!A8VMA9V4-"B`@("`@*B`@("`@("`@(&-A;FYO="!B92!L
M;V-A=&5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%9A;&ED871I;VY/
M8FIE8W0H)'!A8VMA9V4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27U9A;&ED871E)RDI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]686QI9&%T92YP:'`G.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@
M("!I9B`H(21T:&ES+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("`@("`@
M)&$@/2!F86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==*2D@>PT*("`@("`@
M("`@("`@:68@*"1P86-K86=E(#T]("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A
M;&ED871E<&%C:V%G92==*2![#0H@("`@("`@("`@("`@("`@+R\@8VAA;FYE
M;"!V86QI9&%T:6]N('!A8VMA9V5S(&%R92!A;'=A>7,@=F%L:61A=&5D(&)Y
M(%!%05)?5F%L:61A=&4-"B`@("`@("`@("`@("`@("`D=F%L(#T@)FYE=R!0
M14%27U9A;&ED871E.PT*("`@("`@("`@("`@("`@(')E='5R;B`D=F%L.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M<W1R7W)E<&QA8V4H)RXG+"`G7R<L#0H@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G
M72DI*2![#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI<TEN8VQU9&5A
M8FQE*'-T<E]R97!L86-E*"=?)RP@)R\G+`T*("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;$EN9F];)W9A;&ED871E<&%C:V%G92==6R=?
M8V]N=&5N="==*2`N("<N<&AP)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M:6YC;'5D95]O;F-E('-T<E]R97!L86-E*"=?)RP@)R\G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L26YF;ULG=F%L:61A=&5P
M86-K86=E)UU;)U]C;VYT96YT)UTI("X@)RYP:'`G.PT*("`@("`@("`@("`@
M("`@("`@("`D=F-L87-S(#T@<W1R7W)E<&QA8V4H)RXG+"`G7R<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI
M9&%T97!A8VMA9V4G75LG7V-O;G1E;G0G72D[#0H@("`@("`@("`@("`@("`@
M("`@("1V86P@/2`F;F5W("1V8VQA<W,[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&$@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'9C;&%S
M<R`]('-T<E]R97!L86-E*"<N)RP@)U\G+`T*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H86YN96Q);F9O6R=V86QI9&%T97!A8VMA9V4G75LG7V-O
M;G1E;G0G72D[#0H@("`@("`@("`@("`@("`@)'9A;"`]("9N97<@)'9C;&%S
M<SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1V86P@/2`F;F5W(%!%05)?5F%L:61A=&4[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1V86P[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-)
M;F-L=61E86)L92@D<&%T:"D-"B`@("![#0H@("`@("`@("1P;W-S:6)I;&ET
M:65S(#T@97AP;&]D92A0051(7U-%4$%2051/4BP@:6YI7V=E="@G:6YC;'5D
M95]P871H)RDI.PT*("`@("`@("!F;W)E86-H("@D<&]S<VEB:6QI=&EE<R!A
M<R`D9&ER*2![#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES=',H)&1I<B`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D<&%T:"D-"B`@("`@("`@("`@("`@
M("`@("8F(&ES7W)E861A8FQE*"1D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)'!A=&@I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@9G5N8W1I;VX@:7,@
M=7-E9"!B>2!T:&4@8VAA;FYE;"!U<&1A=&5R(&%N9"!R971R:65V97,@82!V
M86QU92!S970@8GD-"B`@("`@*B!T:&4@<F5G:7-T<GDL(&]R('1H92!C=7)R
M96YT('1I;64@:68@:70@:&%S(&YO="!B965N('-E=`T*("`@("`J($!R971U
M<FX@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;&%S=$UO9&EF:65D
M*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V-H86YN96Q)
M;F9O6R=?;&%S=&UO9&EF:65D)UTI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]C:&%N;F5L26YF;ULG7VQA<W1M;V1I9FEE9"==.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!T:6UE*"D[#0H@("`@?0T*?0T*/SX-"@``
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0N
M<&AP````````````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,Q
M-C,Q(#$P-3$U-#,T,3,T(#`R,3,P-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA
M;F0L(&-O;6UA;F0@<&%T=&5R;B!C;&%S<PT*("H-"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I
M<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*
M("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A
M(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@
M82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!#;VUM86YD+G!H<"QV(#$N,S8@,C`P-B\P,2\P
M-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*
M("H@3F5E9&5D(&9O<B!E<G)O<B!H86YD;&EN9PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(N<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]&<F]N=&5N9"YP
M:'`G.PT*<F5Q=6ER95]O;F-E("=014%2+UA-3%!A<G-E<BYP:'`G.PT*#0HO
M*BH-"B`J($QI<W0@;V8@8V]M;6%N9',@86YD('=H870@8VQA<W-E<R!T:&5Y
M(&%R92!I;7!L96UE;G1E9"!I;BX-"B`J($!V87(@87)R87D@8V]M;6%N9"`]
M/B!I;7!L96UE;G1I;F<@8VQA<W,-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O
M;6UA;F1?8V]M;6%N9&QI<W0G72`](&%R<F%Y*"D[#0H-"B\J*@T*("H@3&ES
M="!O9B!S:&]R=&-U=',@=&\@8V]M;6]N(&-O;6UA;F1S+@T*("H@0'9A<B!A
M<G)A>2!S:&]R=&-U="`]/B!C;VUM86YD#0H@*B\-"B1'3$]"04Q36R=?4$5!
M4E]#;VUM86YD7W-H;W)T8W5T<R==(#T@87)R87DH*3L-"@T*+RHJ#0H@*B!!
M<G)A>2!O9B!C;VUM86YD(&]B:F5C=',-"B`J($!V87(@87)R87D@8VQA<W,@
M/3X@;V)J96-T#0H@*B\-"B1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V]B:F5C
M=',G72`](&%R<F%Y*"D[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD(&-L87-S
M+"!A('-I;7!L92!F86-T;W)Y(&-L87-S(&9O<B!A9&UI;FES=')A=&EV90T*
M("H@8V]M;6%N9',N#0H@*@T*("H@2&]W('1O(&EM<&QE;65N="!C;VUM86YD
M(&-L87-S97,Z#0H@*@T*("H@+2!4:&4@8VQA<W,@;75S="!B92!C86QL960@
M4$5!4E]#;VUM86YD7TYN;BP@:6YS=&%L;&5D(&EN('1H90T*("H@("`B4$5!
M4B]#;VUM;VXB('-U8F1I<BP@=VET:"!A(&UE=&AO9"!C86QL960@9V5T0V]M
M;6%N9',H*2!T:&%T#0H@*B`@(')E='5R;G,@86X@87)R87D@;V8@=&AE(&-O
M;6UA;F1S(&EM<&QE;65N=&5D(&)Y('1H92!C;&%S<R`H<V5E#0H@*B`@(%!%
M05(O0V]M;6%N9"]);G-T86QL+G!H<"!F;W(@86X@97AA;7!L92DN#0H@*@T*
M("H@+2!4:&4@8VQA<W,@;75S="!I;7!L96UE;G0@82!R=6XH*2!F=6YC=&EO
M;B!T:&%T(&ES(&-A;&QE9"!W:71H('1H<F5E#0H@*B`@('!A<F%M<SH-"B`J
M#0H@*B`@("`H<W1R:6YG*2!C;VUM86YD(&YA;64-"B`J("`@("AA<G)A>2D@
M(&%S<V]C(&%R<F%Y('=I=&@@;W!T:6]N<RP@9G)E96QY(&1E9FEN960@8GD@
M96%C:`T*("H@("`@("`@("`@("`@8V]M;6%N9"P@9F]R(&5X86UP;&4Z#0H@
M*B`@("`@("`@("`@("!A<G)A>2@G9F]R8V4G(#T^('1R=64I#0H@*B`@("`H
M87)R87DI("!L:7-T(&]F('1H92!O=&AE<B!P87)A;65T97)S#0H@*@T*("H@
M("!4:&4@<G5N*"D@9G5N8W1I;VX@<F5T=7)N<R!A(%!%05)?0V]M;6%N9%)E
M<W!O;G-E(&]B:F5C="X@(%5S90T*("H@("!T:&5S92!M971H;V1S('1O(&=E
M="!I;F9O<FUA=&EO;CH-"B`J#0H@*B`@("!I;G0@9V5T4W1A='5S*"D@("!2
M971U<FYS(%!%05)?0T]-34%.1%\H4U5#0T534WQ&04E,55)%?%!!4E1)04PI
M#0H@*B`@("`@("`@("`@("`@("`@("`@("`J7U!!4E1)04P@;65A;G,@=&AA
M="!Y;W4@;F5E9"!T;R!I<W-U92!A="!L96%S=`T*("H@("`@("`@("`@("`@
M("`@("`@("`@;VYE(&UO<F4@8V]M;6%N9"!T;R!C;VUP;&5T92!T:&4@;W!E
M<F%T:6]N#0H@*B`@("`@("`@("`@("`@("`@("`@("`H=7-E9"!F;W(@97AA
M;7!L92!F;W(@=F%L:61A=&EO;B!S=&5P<RDN#0H@*@T*("H@("`@<W1R:6YG
M(&=E=$UE<W-A9V4H*2`@4F5T=7)N<R!A(&UE<W-A9V4@9F]R('1H92!U<V5R
M+B`@4F5M96UB97(L#0H@*B`@("`@("`@("`@("`@("`@("`@("`@("!N;R!(
M5$U,(&]R(&]T:&5R(&EN=&5R9F%C92US<&5C:69I8R!M87)K=7`N#0H@*@T*
M("H@("!)9B!S;VUE=&AI;F<@=6YE>'!E8W1E9"!H87!P96YS+"!R=6XH*2!R
M971U<FYS(&$@4$5!4B!E<G)O<BX-"B`J#0H@*B`M($1/3B=4($]55%!55"!!
M3EE42$E.1R$@4F5T=7)N('1E>'0@9F]R(&]U='!U="!I;G-T96%D+@T*("H-
M"B`J("T@1$].)U0@55-%($A434PA(%1H92!T97AT('EO=2!R971U<FX@=VEL
M;"!B92!U<V5D(&9R;VT@8F]T:"!'=&LL#0H@*B`@('=E8B!A;F0@8V]M;6%N
M9"UL:6YE(&EN=&5R9F%C97,L('-O(&9O<B!N;W<L(&ME97`@979E<GET:&EN
M9R!T;PT*("H@("!P;&%I;B!T97AT+@T*("H-"B`J("T@1$].)U0@55-%($58
M250@3U(@1$E%(2!!;'=A>7,@=7-E('!E87(@97)R;W)S+B`@1G)O;2!S=&%T
M:6,-"B`J("`@8VQA<W-E<R!D;R!014%2.CIR86ES945R<F]R*"DL(&9R;VT@
M;W1H97(@8VQA<W-E<R!D;PT*("H@("`D=&AI<RT^<F%I<V5%<G)O<B@I+@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD#0I[#0H@("`@+R\@>WM[
M(&9A8W1O<GDH*0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!R:6=H="!O
M8FIE8W0@9F]R(&5X96-U=&EN9R!A(&-O;6UA;F0N#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1C;VUM86YD(%1H92!N86UE(&]F('1H92!C;VUM
M86YD#0H@("`@("H@0'!A<F%M(&]B:F5C="`D8V]N9FEG("!);G-T86YC92!O
M9B!014%27T-O;F9I9R!O8FIE8W0-"B`@("`@*@T*("`@("`J($!R971U<FX@
M;V)J96-T('1H92!C;VUM86YD(&]B:F5C="!O<B!A(%!%05(@97)R;W(-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*
M("`@("`J+PT*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1C;VUM86YD+"`F)&-O
M;F9I9RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG7U!%
M05)?0V]M;6%N9%]C;VUM86YD;&ES="==*2D@>PT*("`@("`@("`@("`@4$5!
M4E]#;VUM86YD.CIR96=I<W1E<D-O;6UA;F1S*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T
M8W5T<R==6R1C;VUM86YD72DI('L-"B`@("`@("`@("`@("1C;VUM86YD(#T@
M)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%TI*2![#0H@("`@
M("`@("`@("`D82`](%!%05(Z.G)A:7-E17)R;W(H(G5N:VYO=VX@8V]M;6%N
M9"!@)&-O;6UA;F0G(BD[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@
M("`@('T-"B`@("`@("`@)&-L87-S(#T@)$=,3T)!3%-;)U]014%27T-O;6UA
M;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%T[#0H@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"1C;&%S<RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC
M92`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]O8FIE8W1S)UU;)&-L87-S73L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,I
M*2![#0H@("`@("`@("`@("`D82`](%!%05(Z.G)A:7-E17)R;W(H(G5N:VYO
M=VX@8V]M;6%N9"!@)&-O;6UA;F0G(BD[#0H@("`@("`@("`@("!R971U<FX@
M)&$[#0H@("`@("`@('T-"B`@("`@("`@)'5I(#TF(%!%05)?0V]M;6%N9#HZ
M9V5T1G)O;G1E;F1/8FIE8W0H*3L-"B`@("`@("`@)&]B:B`]("9N97<@)&-L
M87-S*"1U:2P@)&-O;F9I9RD[#0H@("`@("`@(')E='5R;B`D;V)J.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R`F(&=E=$]B:F5C="@I#0H@
M("`@9G5N8W1I;VX@)F=E=$]B:F5C="@D8V]M;6%N9"D-"B`@("![#0H@("`@
M("`@("1C;&%S<R`]("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L
M:7-T)UU;)&-O;6UA;F1=.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D
M8VQA<W,I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)$=,3T)!3%-;
M)U]014%27T-O;6UA;F1?;V)J96-T<R==6R1C;&%S<UT[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(G5N:VYO=VX@8V]M;6%N
M9"!@)&-O;6UA;F0G(BD[#0H@("`@("`@('T-"B`@("`@("`@)'5I(#TF(%!%
M05)?0V]M;6%N9#HZ9V5T1G)O;G1E;F1/8FIE8W0H*3L-"B`@("`@("`@)&-O
M;F9I9R`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1O
M8FH@/2`F;F5W("1C;&%S<R@D=6DL("1C;VYF:6<I.PT*("`@("`@("!R971U
M<FX@)&]B:CL-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@)B!G
M971&<F]N=&5N9$]B:F5C="@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@:6YS
M=&%N8V4@;V8@9G)O;G1E;F0@;V)J96-T+@T*("`@("`J#0H@("`@("H@0')E
M='5R;B!O8FIE8W1\4$5!4E]%<G)O<@T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B`F9V5T1G)O;G1E;F1/8FIE8W0H*0T*("`@('L-
M"B`@("`@("`@)&$@/2`F4$5!4E]&<F]N=&5N9#HZ<VEN9VQE=&]N*"D[#0H@
M("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@)B!S971&<F]N=&5N9$-L87-S*"D-"@T*("`@("\J*@T*("`@("`J
M($QO860@8W5R<F5N="!F<F]N=&5N9"!C;&%S<RX-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@)'5I8VQA<W,@3F%M92!O9B!C;&%S<R!I;7!L96UE
M;G1I;F<@=&AE(&9R;VYT96YD#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="!T:&4@9G)O;G1E;F0@;V)J96-T+"!O<B!A(%!%05(@97)R;W(-"B`@
M("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)G-E=$9R;VYT
M96YD0VQA<W,H)'5I8VQA<W,I#0H@("`@>PT*("`@("`@("`D82`]("9014%2
M7T9R;VYT96YD.CIS971&<F]N=&5N9$-L87-S*"1U:6-L87-S*3L-"B`@("`@
M("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!S971&<F]N=&5N9%1Y<&4H*0T*#0H@("`@+RHJ#0H@("`@("H@4V5T(&-U
M<G)E;G0@9G)O;G1E;F0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1U:71Y<&4@3F%M92!O9B!T:&4@9G)O;G1E;F0@='EP92`H9F]R(&5X86UP
M;&4@(D-,22(I#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&]B:F5C="!T:&4@
M9G)O;G1E;F0@;V)J96-T+"!O<B!A(%!%05(@97)R;W(-"B`@("`@*B!`<W1A
M=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1G)O;G1E;F14>7!E*"1U
M:71Y<&4I#0H@("`@>PT*("`@("`@("`D=6EC;&%S<R`]("=014%27T9R;VYT
M96YD7R<@+B`D=6ET>7!E.PT*("`@("`@("!R971U<FX@4$5!4E]#;VUM86YD
M.CIS971&<F]N=&5N9$-L87-S*"1U:6-L87-S*3L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@<F5G:7-T97)#;VUM86YD<R@I#0H-"B`@("`O
M*BH-"B`@("`@*B!38V%N('1H<F]U9V@@=&AE($-O;6UA;F0@9&ER96-T;W)Y
M(&QO;VMI;F<@9F]R(&-L87-S97,-"B`@("`@*B!A;F0@<V5E('=H870@8V]M
M;6%N9',@=&AE>2!I;7!L96UE;G0N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M8F]O;"`@("AO<'1I;VYA;"D@:68@1D%,4T4@*&1E9F%U;'0I+"!T:&4@;F5W
M(&QI<W0@;V8-"B`@("`@*B`@("`@("`@("`@("`@(&-O;6UA;F1S('-H;W5L
M9"!R97!L86-E('1H92!C=7)R96YT(&]N92X@($EF(%12544L#0H@("`@("H@
M("`@("`@("`@("`@("!N97<@96YT<FEE<R!W:6QL(&)E(&UE<F=E9"!W:71H
M(&]L9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@*&]P=&EO;F%L
M*2!W:&5R92`H=VAA="!D:7)E8W1O<GDI('1O(&QO;VL@9F]R#0H@("`@("H@
M("`@("`@("`@("`@("!C;&%S<V5S+"!D969A=6QT<R!T;R!T:&4@0V]M;6%N
M9"!S=6)D:7)E8W1O<GD@;V8-"B`@("`@*B`@("`@("`@("`@("`@('1H92!D
M:7)E8W1O<GD@9G)O;2!W:&5R92!T:&ES(&9I;&4@*%]?1DE,15]?*2!I<PT*
M("`@("`J("`@("`@("`@("`@("`@:6YC;'5D960N#0H@("`@("H-"B`@("`@
M*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!A(%!%05(@97)R;W(@
M;VX@9F%I;'5R90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<F5G:7-T97)#
M;VUM86YD<R@D;65R9V4@/2!F86QS92P@)&1I<B`](&YU;&PI#0H@("`@>PT*
M("`@("`@("`D<&%R<V5R(#T@;F5W(%!%05)?6$U,4&%R<V5R.PT*("`@("`@
M("!I9B`H)&1I<B`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&1I<B`](&1I
M<FYA;64H7U]&24Q%7U\I("X@)R]#;VUM86YD)SL-"B`@("`@("`@?0T*("`@
M("`@("`D9'`@/2!`;W!E;F1I<B@D9&ER*3L-"B`@("`@("`@:68@*&5M<'1Y
M*"1D<"DI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R
M*")R96=I<W1E<D-O;6UA;F1S.B!O<&5N9&ER*"1D:7(I(&9A:6QE9"(I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)&UE<F=E*2![#0H@("`@("`@("`@
M("`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==(#T@87)R
M87DH*3L-"B`@("`@("`@?0T*("`@("`@("!W:&EL92`H)&5N=')Y(#T@<F5A
M9&1I<B@D9'`I*2![#0H@("`@("`@("`@("!I9B`H)&5N=')Y>S!](#T]("<N
M)R!\?"!S=6)S='(H)&5N=')Y+"`M-"D@(3T@)RYX;6PG*2![#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D8VQA<W,@/2`B4$5!4E]#;VUM86YD7R(N<W5B<W1R*"1E;G1R>2P@,"P@
M+30I.PT*("`@("`@("`@("`@)&9I;&4@/2`B)&1I<B\D96YT<GDB.PT*("`@
M("`@("`@("`@)'!A<G-E<BT^<&%R<V4H9FEL95]G971?8V]N=&5N=',H)&9I
M;&4I*3L-"B`@("`@("`@("`@("1I;7!L96UE;G1S(#T@)'!A<G-E<BT^9V5T
M1&%T82@I.PT*("`@("`@("`@("`@+R\@3&ES="!O9B!C;VUM86YD<PT*("`@
M("`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V]B
M:F5C=',G75LD8VQA<W-=*2D@>PT*("`@("`@("`@("`@("`@("1'3$]"04Q3
M6R=?4$5!4E]#;VUM86YD7V]B:F5C=',G75LD8VQA<W-=(#T@(B1D:7(O(B`N
M('-U8G-T<B@D96YT<GDL(#`L("TT*2`N#0H@("`@("`@("`@("`@("`@("`@
M("<N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1I;7!L96UE;G1S(&%S("1C;VUM86YD(#T^("1D97-C*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1C;VUM86YD(#T]("=A='1R:6)S)RD@>PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1'3$]"04Q36R=?4$5!4E]#;VUM
M86YD7V-O;6UA;F1L:7-T)UU;)&-O;6UA;F1=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G0V]M;6%N9"`B)R`N
M("1C;VUM86YD("X@)R(@86QR96%D>2!R96=I<W1E<F5D(&EN("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)V-L87-S("(G("X@)$=,3T)!3%-;)U]0
M14%27T-O;6UA;F1?8V]M;6%N9&QI<W0G75LD8V]M;6%N9%T@+B`G(B<I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG
M7U!%05)?0V]M;6%N9%]C;VUM86YD;&ES="==6R1C;VUM86YD72`]("1C;&%S
M<SL-"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C
M;VUM86YD9&5S8R==6R1C;VUM86YD72`]("1D97-C6R=S=6UM87)Y)UT[#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97-C6R=S:&]R=&-U="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<VAO<G1C=70@/2`D9&5S8ULG<VAO
M<G1C=70G73L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1'3$]"
M04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==6R1S:&]R=&-U=%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@G0V]M;6%N9"!S:&]R=&-U="`B)R`N("1S:&]R=&-U="`N("<B(&%L
M<F5A9'D@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E9VES
M=&5R960@=&\@8V]M;6%N9"`B)R`N("1C;VUM86YD("X@)R(@:6X@8VQA<W,@
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1'3$]"04Q36R=?
M4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UU;)&-O;6UA;F1=("X@)R(G*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD<VAO<G1C=71=
M(#T@)&-O;6UA;F0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5S8ULG;W!T:6]N<R==*2`F)B`D9&5S8ULG;W!T
M:6]N<R==*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97-C
M6R=O<'1I;VYS)UT@87,@)&]N86UE(#T^("1O<'1I;VXI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N6R=S:&]R=&]P="==
M*2`F)B!S=')L96XH)&]P=&EO;ELG<VAO<G1O<'0G72D@/B`Q*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)T]P=&EO;B`B)R`N("1O;F%M92`N("<B('-H;W)T(&]P=&EO;B`B)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VY;)W-H
M;W)T;W!T)UT@+B`G(B!M=7-T(&)E("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;VYL>2`Q(&-H87)A8W1E<B!I;B!#;VUM86YD("(G
M("X@)&-O;6UA;F0@+B`G(B!I;B!C;&%S<R`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;&%S<R`N("<B)RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:W-O<G0H)$=,3T)!3%-;)U]014%27T-O;6UA;F1?<VAO<G1C=71S)UTI
M.PT*("`@("`@("!K<V]R="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]C;VUM
M86YD;&ES="==*3L-"B`@("`@("`@0&-L;W-E9&ER*"1D<"D[#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!G971#;VUM86YD<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&QI
M<W0@;V8@8W5R<F5N=&QY('-U<'!O<G1E9"!C;VUM86YD<RP@86YD('=H870-
M"B`@("`@*B!C;&%S<V5S(&EM<&QE;65N="!T:&5M+@T*("`@("`J#0H@("`@
M("H@0')E='5R;B!A<G)A>2!C;VUM86YD(#T^(&EM<&QE;65N=&EN9R!C;&%S
M<PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<W1A
M=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T0V]M;6%N9',H*0T*("`@
M('L-"B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E]#;VUM86YD
M7V-O;6UA;F1L:7-T)UTI*2![#0H@("`@("`@("`@("!014%27T-O;6UA;F0Z
M.G)E9VES=&5R0V]M;6%N9',H*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)$=,3T)!3%-;)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G73L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T4VAO<G1C=71S*"D-
M"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@;&ES="!O9B!C;VUM86YD('-H
M;W)T8W5T<RX-"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87D@<VAO<G1C
M=70@/3X@8V]M;6%N9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4VAO
M<G1C=71S*"D-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D1TQ/0D%,4ULG
M7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G72DI('L-"B`@("`@("`@("`@(%!%
M05)?0V]M;6%N9#HZ<F5G:7-T97)#;VUM86YD<R@I.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U
M=',G73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1V5T
M;W!T07)G<R@I#0H-"B`@("`O*BH-"B`@("`@*B!#;VUP:6QE<R!A<F=U;65N
M=',@9F]R(&=E=&]P="X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M)&-O;6UA;F0@("`@(&-O;6UA;F0@=&\@9V5T(&]P='-T<FEN9R!F;W(-"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S:&]R=%]A<F=S("`H<F5F97)E;F-E*2!S
M:&]R="!G971O<'0@9F]R;6%T#0H@("`@("H@0'!A<F%M(&%R<F%Y("`D;&]N
M9U]A<F=S("`@*')E9F5R96YC92D@;&]N9R!G971O<'0@9F]R;6%T#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*("`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$=E=&]P=$%R9W,H)&-O;6UA;F0L("8D<VAO<G1?87)G<RP@)B1L
M;VYG7V%R9W,I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)$=,3T)!3%-;
M)U]014%27T-O;6UA;F1?8V]M;6%N9&QI<W0G72DI('L-"B`@("`@("`@("`@
M(%!%05)?0V]M;6%N9#HZ<F5G:7-T97)#;VUM86YD<R@I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S
M:&]R=&-U=',G75LD8V]M;6%N9%TI*2![#0H@("`@("`@("`@("`D8V]M;6%N
M9"`]("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7W-H;W)T8W5T<R==6R1C;VUM
M86YD73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q3
M6R=?4$5!4E]#;VUM86YD7V-O;6UA;F1L:7-T)UU;)&-O;6UA;F1=*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@("`@("`@
M)&]B:B`]("9014%27T-O;6UA;F0Z.F=E=$]B:F5C="@D8V]M;6%N9"D[#0H@
M("`@("`@(')E='5R;B`D;V)J+3YG971'971O<'1!<F=S*"1C;VUM86YD+"`D
M<VAO<G1?87)G<RP@)&QO;F=?87)G<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&=E=$1E<V-R:7!T:6]N*"D-"@T*("`@("\J*@T*("`@
M("`J($=E="!D97-C<FEP=&EO;B!F;W(@82!C;VUM86YD+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M("!S=')I;F<@)&-O;6UA;F0@3F%M92!O9B!T:&4@8V]M
M;6%N9`T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F<@8V]M;6%N9"!D
M97-C<FEP=&EO;@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@
M("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5S8W)I
M<'1I;VXH)&-O;6UA;F0I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'
M3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1D97-C)UU;)&-O;6UA;F1=
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM86YD7V-O;6UA;F1D
M97-C)UU;)&-O;6UA;F1=.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!G971(96QP*"D-"@T*("`@("\J*@T*("`@("`J($=E="!H96QP(&9O
M<B!C;VUM86YD+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D8V]M
M;6%N9"!.86UE(&]F('1H92!C;VUM86YD('1O(')E='5R;B!H96QP(&9O<@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<W1A=&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T2&5L<"@D8V]M;6%N9"D-"B`@
M("![#0H@("`@("`@("1C;61S(#T@4$5!4E]#;VUM86YD.CIG971#;VUM86YD
M<R@I.PT*("`@("`@("!I9B`H:7-S970H)$=,3T)!3%-;)U]014%27T-O;6UA
M;F1?<VAO<G1C=71S)UU;)&-O;6UA;F1=*2D@>PT*("`@("`@("`@("`@)&-O
M;6UA;F0@/2`D1TQ/0D%,4ULG7U!%05)?0V]M;6%N9%]S:&]R=&-U=',G75LD
M8V]M;6%N9%T[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1C;61S
M6R1C;VUM86YD72DI('L-"B`@("`@("`@("`@("1O8FH@/2`F4$5!4E]#;VUM
M86YD.CIG971/8FIE8W0H)&-O;6UA;F0I.PT*("`@("`@("`@("`@<F5T=7)N
M("1O8FHM/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+T-O;6UO;BYP:'``````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,3`W-S,T(#$P-3$U-#,T,3,T(#`R,3$V-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B!0
M14%27T-O;6UO;BP@=&AE(&)A<V4@8VQA<W,@9F]R('1H92!014%2($EN<W1A
M;&QE<@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J
M($!A=71H;W(@("`@(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M
M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z
M($-O;6UO;BYP:'`L=B`Q+C$U-2`R,#`V+S`S+S`R(#$X.C$T.C$R(&-E;&QO
M9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,"XQ+C`-"B`J($!D97!R96-A=&5D($9I;&4@9&5P<F5C
M871E9"!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J($EN
M8VQU9&4@97)R;W(@:&%N9&QI;F<-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2
M+G!H<"<[#0H-"B\O('M[>R!C;VYS=&%N=',@86YD(&=L;V)A;',-"@T*+RHJ
M#0H@*B!014%27T-O;6UO;B!E<G)O<B!W:&5N(&%N(&EN=F%L:60@4$A0(&9I
M;&4@:7,@<&%S<V5D('1O(%!%05)?0V]M;6]N.CIA;F%L>7IE4V]U<F-E0V]D
M92@I#0H@*B\-"F1E9FEN92@G4$5!4E]#3TU-3TY?15)23U)?24Y604Q)1%!(
M4"<L(#$I.PT*9&5F:6YE*"=?4$5!4E]#3TU-3TY?4$%#2T%'15].04U%7U!2
M14<G+"`G6T$M6F$M>EU;82UZ02U:,"TY7UTK)RD[#0ID969I;F4H)U!%05)?
M0T]-34].7U!!0TM!1T5?3D%-15]04D5')RP@)R]>)R`N(%]014%27T-/34U/
M3E]004-+04=%7TY!345?4%)%1R`N("<D+R<I.PT*#0HO+R!T:&ES('-H;W5L
M9"!A;&QO=SH@,2P@,2XP+"`Q+C!20S$L(#$N,&1E=BP@,2XP9&5V,3(S,C,T
M,C,T,C,T+"`Q+C!A,2P@,2XP8C$L(#$N,'!L,0T*9&5F:6YE*"=?4$5!4E]#
M3TU-3TY?4$%#2T%'15]615)324].7U!214<G+"`G7&0K*#\Z7"Y<9"LI*B@_
M.EMA+7I!+5I=*UQD*BD_)RD[#0ID969I;F4H)U!%05)?0T]-34].7U!!0TM!
M1T5?5D524TE/3E]04D5')RP@)R]>)R`N(%]014%27T-/34U/3E]004-+04=%
M7U9%4E-)3TY?4%)%1R`N("<D+VDG*3L-"@T*+R\@6%A8(&9A<B!F<F]M('!E
M<F9E8W0@.BTI#0ID969I;F4H)U]014%27T-/34U/3E]004-+04=%7T1/5TY,
M3T%$7U!214<G+"`G*"<@+B!?4$5!4E]#3TU-3TY?4$%#2T%'15].04U%7U!2
M14<@+@T*("`@("<I*"TH6RXP+3EA+7I!+5I=*RDI/R<I.PT*9&5F:6YE*"=0
M14%27T-/34U/3E]004-+04=%7T1/5TY,3T%$7U!214<G+"`G+UXG("X@7U!%
M05)?0T]-34].7U!!0TM!1T5?1$]73DQ/041?4%)%1R`N#0H@("`@)R0O)RD[
M#0H-"F1E9FEN92@G7U!%05)?0TA!3DY%3%-?3D%-15]04D5')RP@)UM!+5IA
M+7I=6V$M>D$M6C`M.5PN72LG*3L-"F1E9FEN92@G4$5!4E]#2$%.3D5,4U].
M04U%7U!214<G+"`G+UXG("X@7U!%05)?0TA!3DY%3%-?3D%-15]04D5'("X@
M)R0O)RD[#0H-"B\O('1H:7,@<VAO=6QD(&%L;&]W(&%N>2!D;G,@;W(@25`@
M861D<F5S<RP@<&QU<R!A('!A=&@@+2!.3R!53D1%4E-#3U)%4R!!3$Q/5T5$
M#0ID969I;F4H)U]014%27T-(04Y.14Q37U-%4E9%4E]04D5')RP@)UMA+7I!
M+5HP+3E<+5TK*#\Z7"Y;82UZ02U:,"TY7"U=*RDJ*%PO6V$M>D$M6C`M.5PM
M72LI*B<I.PT*9&5F:6YE*"=014%27T-(04Y.14Q37U-%4E9%4E]04D5')RP@
M)R]>)R`N(%]014%27T-(04Y.14Q37U-%4E9%4E]04D5'("X@)R0O:2<I.PT*
M#0ID969I;F4H)U]014%27T-(04Y.14Q37U!!0TM!1T5?4%)%1R<L("`G*"<@
M+E]014%27T-(04Y.14Q37U-%4E9%4E]04D5'("X@)RE<+R@G#0H@("`@("`@
M("`N(%]014%27T-/34U/3E]004-+04=%7TY!345?4%)%1R`N("<I)RD[#0ID
M969I;F4H)U!%05)?0TA!3DY%3%-?4$%#2T%'15]04D5')RP@)R]>)R`N(%]0
M14%27T-(04Y.14Q37U!!0TM!1T5?4%)%1R`N("<D+VDG*3L-"@T*9&5F:6YE
M*"=?4$5!4E]#3TU-3TY?0TA!3DY%3%]$3U=.3$]!1%]04D5')RP@)R@G("X@
M7U!%05)?0TA!3DY%3%-?3D%-15]04D5'("X@)RDZ.B@G#0H@("`@+B!?4$5!
M4E]#3TU-3TY?4$%#2T%'15].04U%7U!214<@+B`G*2@M*%LN,"TY82UZ02U:
M72LI*3\G*3L-"F1E9FEN92@G4$5!4E]#3TU-3TY?0TA!3DY%3%]$3U=.3$]!
M1%]04D5')RP@)R]>)R`N(%]014%27T-/34U/3E]#2$%.3D5,7T1/5TY,3T%$
M7U!214<@+B`G)"\G*3L-"@T*+RHJ#0H@*B!,:7-T(&]F('1E;7!O<F%R>2!F
M:6QE<R!A;F0@9&ER96-T;W)I97,@<F5G:7-T97)E9"!B>0T*("H@4$5!4E]#
M;VUM;VXZ.F%D9%1E;7!&:6QE*"DN#0H@*B!`=F%R(&%R<F%Y#0H@*B\-"B1'
M3$]"04Q36R=?4$5!4E]#;VUM;VY?=&5M<&9I;&5S)UT@/2!A<G)A>2@I.PT*
M#0HO*BH-"B`J(%9A;&ED(&UA:6YT86EN97(@<F]L97,-"B`J($!V87(@87)R
M87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]M86EN=&%I;F5R7W)O
M;&5S)UT@/2!A<G)A>2@G;&5A9"<L)V1E=F5L;W!E<B<L)V-O;G1R:6)U=&]R
M)RPG:&5L<&5R)RD[#0H-"B\J*@T*("H@5F%L:60@<F5L96%S92!S=&%T97,-
M"B`J($!V87(@87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]R
M96QE87-E7W-T871E<R==(#T@87)R87DH)V%L<&AA)RPG8F5T82<L)W-T86)L
M92<L)W-N87!S:&]T)RPG9&5V96PG*3L-"@T*+RHJ#0H@*B!686QI9"!D97!E
M;F1E;F-Y('1Y<&5S#0H@*B!`=F%R(&%R<F%Y#0H@*B\-"B1'3$]"04Q36R=?
M4$5!4E]#;VUM;VY?9&5P96YD96YC>5]T>7!E<R==(#T@87)R87DH)W!K9R<L
M)V5X="<L)W!H<"<L)W!R;V<G+"=L9&QI8B<L)W)T;&EB)RPG;W,G+"=W96)S
M<G8G+"=S87!I)RD[#0H-"B\J*@T*("H@5F%L:60@9&5P96YD96YC>2!R96QA
M=&EO;G,-"B`J($!V87(@87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O
M;6UO;E]D97!E;F1E;F-Y7W)E;&%T:6]N<R==(#T@87)R87DH)VAA<R<L)V5Q
M)RPG;'0G+"=L92<L)V=T)RPG9V4G+"=N;W0G+"`G;F4G*3L-"@T*+RHJ#0H@
M*B!686QI9"!F:6QE(')O;&5S#0H@*B!`=F%R(&%R<F%Y#0H@*B\-"B1'3$]"
M04Q36R=?4$5!4E]#;VUM;VY?9FEL95]R;VQE<R==(#T@87)R87DH)W!H<"<L
M)V5X="<L)W1E<W0G+"=D;V,G+"=D871A)RPG<W)C)RPG<V-R:7!T)RD[#0H-
M"B\J*@T*("H@5F%L:60@<F5P;&%C96UE;G0@='EP97,-"B`J($!V87(@87)R
M87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO;E]R97!L86-E;65N=%]T
M>7!E<R==(#T@87)R87DH)W!H<"UC;VYS="<L("=P96%R+6-O;F9I9R<L("=P
M86-K86=E+6EN9F\G*3L-"@T*+RHJ#0H@*B!686QI9"`B<')O=FED92(@='EP
M97,-"B`J($!V87(@87)R87D-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;6UO
M;E]P<F]V:61E7W1Y<&5S)UT@/2!A<G)A>2@G97AT)RP@)W!R;V<G+"`G8VQA
M<W,G+"`G9G5N8W1I;VXG+"`G9F5A='5R92<L("=A<&DG*3L-"@T*+RHJ#0H@
M*B!686QI9"`B<')O=FED92(@='EP97,-"B`J($!V87(@87)R87D-"B`J+PT*
M)$=,3T)!3%-;)U]014%27T-O;6UO;E]S8W)I<'1?<&AA<V5S)UT@/2!A<G)A
M>2@G<')E+6EN<W1A;&PG+"`G<&]S="UI;G-T86QL)RP@)W!R92UU;FEN<W1A
M;&PG+"`G<&]S="UU;FEN<W1A;&PG+"`G<')E+6)U:6QD)RP@)W!O<W0M8G5I
M;&0G+"`G<')E+6-O;F9I9W5R92<L("=P;W-T+6-O;F9I9W5R92<L("=P<F4M
M<V5T=7`G+"`G<&]S="US971U<"<I.PT*#0HO+R!]?7T-"@T*+RHJ#0H@*B!#
M;&%S<R!P<F]V:61I;F<@8V]M;6]N(&9U;F-T:6]N86QI='D@9F]R(%!%05(@
M861M:6YI<W1R871I;VX@8VQA<W-E<RX-"B`J($!C871E9V]R>2`@('!E87(-
M"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K
M:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N(%8N
M($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B!`
M9&5P<F5C871E9"!4:&ES(&-L87-S('=I;&P@9&ES87!P96%R+"!A;F0@:71S
M(&-O;7!O;F5N=',@=VEL;"!B92!S<')E860-"B`J("`@("`@("`@("`@(&EN
M=&\@<VUA;&QE<B!C;&%S<V5S+"!L:6ME('1H92!!5"94(&)R96%K=7`L(&%S
M(&]F(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27T-O;6UO;B!E
M>'1E;F1S(%!%05(-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@
M+RHJ('-T86-K(&]F(&5L96UE;G1S+"!G:79E<R!S;VUE('-O<G0@;V8@6$U,
M(&-O;G1E>'0@*B\-"B`@("!V87(@)&5L96UE;G1?<W1A8VL@/2!A<G)A>2@I
M.PT*#0H@("`@+RHJ(&YA;64@;V8@8W5R<F5N=&QY('!A<G-E9"!834P@96QE
M;65N="`J+PT*("`@('9A<B`D8W5R<F5N=%]E;&5M96YT.PT*#0H@("`@+RHJ
M(&%R<F%Y(&]F(&%T=')I8G5T97,@;V8@=&AE(&-U<G)E;G1L>2!P87)S960@
M6$U,(&5L96UE;G0@*B\-"B`@("!V87(@)&-U<G)E;G1?871T<FEB=71E<R`]
M(&%R<F%Y*"D[#0H-"B`@("`O*BH@87-S;V,@=VET:"!I;F9O<FUA=&EO;B!A
M8F]U="!A('!A8VMA9V4@*B\-"B`@("!V87(@)'!K9VEN9F\@/2!A<G)A>2@I
M.PT*#0H@("`@+RHJ#0H@("`@("H@57-E<B!);G1E<F9A8V4@;V)J96-T("A0
M14%27T9R;VYT96YD7RH@8VQA<W,I+B`@268@;G5L;"P-"B`@("`@*B!T:&4@
M;&]G*"D@;65T:&]D('5S97,@<')I;G0N#0H@("`@("H@0'9A<B!O8FIE8W0-
M"B`@("`@*B\-"B`@("!V87(@)'5I(#T@;G5L;#L-"@T*("`@("\J*@T*("`@
M("`J($-O;F9I9W5R871I;VX@;V)J96-T("A014%27T-O;F9I9RDN#0H@("`@
M("H@0'9A<B!O8FIE8W0-"B`@("`@*B\-"B`@("!V87(@)&-O;F9I9R`](&YU
M;&P[#0H-"B`@("!V87(@)&-U<G)E;G1?<&%T:"`](&YU;&P[#0H-"B`@("`O
M*BH-"B`@("`@*B!014%27U-O=7)C94%N86QY>F5R(&EN<W1A;F-E#0H@("`@
M("H@0'9A<B!O8FIE8W0-"B`@("`@*B\-"B`@("!V87(@)'-O=7)C95]A;F%L
M>7IE<B`](&YU;&P[#0H@("`@+RHJ#0H@("`@("H@1FQA9R!V87)I86)L92!U
M<V5D('1O(&UA<FL@82!V86QI9"!P86-K86=E(&9I;&4-"B`@("`@*B!`=F%R
M(&)O;VQE86X-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@
M("!V87(@)%]V86QI9%!A8VMA9V5&:6QE.PT*#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J(%!%05)?
M0V]M;6]N(&-O;G-T<G5C=&]R#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U
M8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6]N*"D-"B`@
M("![#0H@("`@("`@('!A<F5N=#HZ4$5!4B@I.PT*("`@("`@("`D=&AI<RT^
M8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-"B`@("`@("`@
M)'1H:7,M/F1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1E<W1R=6-T;W(-
M"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]M;6]N(&1E<W1R=6-T;W(-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]014%27T-O;6UO;B@I#0H@("`@>PT*("`@("`@("`O+R!D;V5S
M;B=T('=O<FL@9'5E('1O(&)U9R`C,30W-#0-"B`@("`@("`@+R\D=&5M<&9I
M;&5S(#T@)'1H:7,M/E]T96UP9FEL97,[#0H@("`@("`@("1T96UP9FEL97,@
M/28@)$=,3T)!3%-;)U]014%27T-O;6UO;E]T96UP9FEL97,G73L-"B`@("`@
M("`@=VAI;&4@*"1F:6QE(#T@87)R87E?<VAI9G0H)'1E;7!F:6QE<RDI('L-
M"B`@("`@("`@("`@(&EF("A`:7-?9&ER*"1F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!3>7-T96TZ.G)M*&%R
M<F%Y*"<M<F8G+"`D9FEL92DI.PT*("`@("`@("`@("`@?2!E;'-E:68@*&9I
M;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@('5N;&EN:R@D
M9FEL92D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@861D5&5M<$9I;&4H*0T*#0H@("`@+RHJ
M#0H@("`@("H@4F5G:7-T97(@82!T96UP;W)A<GD@9FEL92!O<B!D:7)E8W1O
M<GDN("!7:&5N('1H92!D97-T<G5C=&]R(&ES#0H@("`@("H@97AE8W5T960L
M(&%L;"!R96=I<W1E<F5D('1E;7!O<F%R>2!F:6QE<R!A;F0@9&ER96-T;W)I
M97,@87)E#0H@("`@("H@<F5M;W9E9"X-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@("1F:6QE("!N86UE(&]F(&9I;&4@;W(@9&ER96-T;W)Y#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D5&5M<$9I
M;&4H)&9I;&4I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]&<F]N=&5N9"<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O1G)O;G1E;F0N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("!014%2
M7T9R;VYT96YD.CIA9&1496UP1FEL92@D9FEL92D[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&UK1&ER2&EE<B@I#0H-"B`@("`O*BH-"B`@
M("`@*B!7<F%P<&5R('1O(%-Y<W1E;3HZ;6M$:7(H*2P@8W)E871E<R!A(&1I
M<F5C=&]R>2!A<R!W96QL(&%S#0H@("`@("H@86YY(&YE8V5S<V%R>2!P87)E
M;G0@9&ER96-T;W)I97,N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D9&ER("!D:7)E8W1O<GD@;F%M90T*("`@("`J#0H@("`@("H@0')E='5R
M;B!B;V]L(%12544@;VX@<W5C8V5S<RP@;W(@82!014%2(&5R<F]R#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&UK1&ER2&EE<B@D9&ER*0T*("`@('L-"B`@("`@("`@)'1H:7,M/FQO
M9R@R+"`B*R!C<F5A=&4@9&ER("1D:7(B*3L-"B`@("`@("`@:68@*"%C;&%S
M<U]E>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N
M8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!3
M>7-T96TZ.FUK1&ER*&%R<F%Y*"<M<"<L("1D:7(I*3L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@;&]G*"D-"@T*("`@("\J*@T*("`@("`J
M($QO9V=I;F<@;65T:&]D+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&EN="`@
M("`D;&5V96P@(&QO9R!L979E;"`H,"!I<R!Q=6EE="P@:&EG:&5R(&ES(&YO
M:7-I97(I#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;7-G("`@(&UE<W-A9V4@
M=&\@=W)I=&4@=&\@=&AE(&QO9PT*("`@("`J#0H@("`@("H@0')E='5R;B!V
M;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!S
M=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!L;V<H)&QE=F5L+"`D;7-G
M+"`D87!P96YD7V-R;&8@/2!T<G5E*0T*("`@('L-"B`@("`@("`@:68@*"1T
M:&ES+3YD96)U9R`^/2`D;&5V96PI('L-"B`@("`@("`@("`@(&EF("@A8VQA
M<W-?97AI<W1S*"=014%27T9R;VYT96YD)RDI('L-"B`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O1G)O;G1E;F0N<&AP)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1U:2`]("9014%27T9R;VYT96YD.CIS:6YG
M;&5T;VXH*3L-"B`@("`@("`@("`@(&EF("AI<U]A*"1U:2P@)U!%05)?1G)O
M;G1E;F0G*2D@>PT*("`@("`@("`@("`@("`@("1U:2T^;&]G*"1M<V<L("1A
M<'!E;F1?8W)L9BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@('!R:6YT("(D;7-G7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&UK5&5M<$1I
M<B@I#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@86YD(')E9VES=&5R(&$@
M=&5M<&]R87)Y(&1I<F5C=&]R>2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)'1M<&1I<B`H;W!T:6]N86PI($1I<F5C=&]R>2!T;R!U<V4@87,@
M=&UP9&ER+@T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!7:6QL('5S
M92!S>7-T96T@9&5F875L=',@*&9O<B!E>&%M<&QE#0H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("]T;7`@;W(@8SI<=VEN9&]W<UQT96UP*2!I9B!N
M;W0@<W!E8VEF:65D#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!N
M86UE(&]F(&-R96%T960@9&ER96-T;W)Y#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&UK5&5M<$1I<B@D
M=&UP9&ER(#T@)R<I#0H@("`@>PT*("`@("`@("!I9B`H)'1M<&1I<BD@>PT*
M("`@("`@("`@("`@)'1O<'0@/2!A<G)A>2@G+70G+"`D=&UP9&ER*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T;W!T(#T@87)R87DH*3L-
M"B`@("`@("`@?0T*("`@("`@("`D=&]P="`](&%R<F%Y7VUE<F=E*"1T;W!T
M+"!A<G)A>2@G+60G+"`G<&5A<B<I*3L-"B`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U-Y<W1E;2<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U-Y<W1E;2YP:'`G.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1M<&1I
M<B`](%-Y<W1E;3HZ;6MT96UP*"1T;W!T*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YA9&1496UP
M1FEL92@D=&UP9&ER*3L-"B`@("`@("`@<F5T=7)N("1T;7!D:7([#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-E=$9R;VYT96YD3V)J96-T
M*"D-"@T*("`@("\J*@T*("`@("`J(%-E="!O8FIE8W0@=&AA="!R97!R97-E
M;G1S('1H92!F<F]N=&5N9"!T;R!B92!U<V5D+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M("!O8FIE8W0@4F5F97)E;F-E(&]F('1H92!F<F]N=&5N9"!O8FIE
M8W0-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$9R;VYT96YD3V)J96-T*"8D
M=6DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^=6D@/2`F)'5I.PT*("`@('T-
M"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&EN9F]&<F]M5&=Z1FEL92@I
M#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T
M(&$@<&%C:V%G92!F:6QE+B`@17AP96-T<R!T:&4@;F%M92!O9@T*("`@("`J
M(&$@9WII<'!E9"!T87(@9FEL92!A<R!I;G!U="X-"B`@("`@*@T*("`@("`J
M($!P87)A;2!S=')I;F<@("1F:6QE("!N86UE(&]F("YT9WH@9FEL90T*("`@
M("`J#0H@("`@("H@0')E='5R;B!A<G)A>2`@87)R87D@=VET:"!P86-K86=E
M(&EN9F]R;6%T:6]N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*
M("`@("`J($!D97!R96-A=&5D('5S92!014%27U!A8VMA9V5&:6QE+3YF<F]M
M5&=Z1FEL92@I(&EN<W1E860-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&EN9F]&<F]M5&=Z1FEL92@D9FEL92D-"B`@("![#0H@("`@("`@("1P
M86-K86=E9FEL92`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^8V]N
M9FEG*3L-"B`@("`@("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;51G>D9I
M;&4H)&9I;&4L(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@("`@("`@)&5R<G,@/2`D
M<&8M/F=E=%5S97)I;F9O*"D[#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&5R<G,I*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R<G,@87,@
M)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@("`@("1E(#T@)'1H:7,M/G)A
M:7-E17)R;W(H)&5R<F]R6R=M97-S86=E)UTL("1E<G)O<ELG8V]D92==+"!N
M=6QL+"!N=6QL+"`D97)R;W(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<&8[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&]S=%!R;V-E<W-686QI9%!A8VMA
M9V5X;6PH)'!F*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M:6YF;T9R;VU$97-C<FEP=&EO;D9I;&4H*0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4@9FEL92X@($5X
M<&5C=',@=&AE(&YA;64@;V8-"B`@("`@*B!A('!A8VMA9V4@>&UL(&9I;&4@
M87,@:6YP=70N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`D9&5S
M8V9I;&4@(&YA;64@;V8@<&%C:V%G92!X;6P@9FEL90T*("`@("`J#0H@("`@
M("H@0')E='5R;B!A<G)A>2`@87)R87D@=VET:"!P86-K86=E(&EN9F]R;6%T
M:6]N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J($!D
M97!R96-A=&5D('5S92!014%27U!A8VMA9V5&:6QE+3YF<F]M4&%C:V%G949I
M;&4H*2!I;G-T96%D#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I
M;F9O1G)O;41E<V-R:7!T:6]N1FEL92@D9&5S8V9I;&4I#0H@("`@>PT*("`@
M("`@("`D<&%C:V%G969I;&4@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H
M:7,M/F-O;F9I9RD[#0H@("`@("`@("1P9B`]("8D<&%C:V%G969I;&4M/F9R
M;VU086-K86=E1FEL92@D9&5S8V9I;&4L(%!%05)?5D%,241!5$5?3D]234%,
M*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@
M("`@("`@)&5R<G,@/2`D<&8M/F=E=%5S97)I;F9O*"D[#0H@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&5R<G,I*2![#0H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&5R<G,@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@("`@
M("1E(#T@)'1H:7,M/G)A:7-E17)R;W(H)&5R<F]R6R=M97-S86=E)UTL("1E
M<G)O<ELG8V]D92==+"!N=6QL+"!N=6QL+"`D97)R;W(I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D
M<&8[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&]S=%!R
M;V-E<W-686QI9%!A8VMA9V5X;6PH)'!F*3L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@:6YF;T9R;VU3=')I;F<H*0T*#0H@("`@+RHJ#0H@
M("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('!A8VMA9V4@9FEL
M92X@($5X<&5C=',@=&AE(&-O;G1E;G1S#0H@("`@("H@;V8@82!P86-K86=E
M('AM;"!F:6QE(&%S(&EN<'5T+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`@)&1A=&$@(&-O;G1E;G1S(&]F('!A8VMA9V4N>&UL(&9I;&4-"B`@
M("`@*@T*("`@("`J($!R971U<FX@87)R87D@("!A<G)A>2!W:71H('!A8VMA
M9V4@:6YF;W)M871I;VX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0&1E<')E8V%T960@=7-E(%!%05)?4&%C:V%G949I;&4M/F9R
M;VU8;6QS=')I;F<H*2!I;G-T96%D#0H@("`@("H-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!I;F9O1G)O;5-T<FEN9R@D9&%T82D-"B`@("![#0H@("`@("`@
M("1P86-K86=E9FEL92`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI<RT^
M8V]N9FEG*3L-"B`@("`@("`@)'!F(#T@)B1P86-K86=E9FEL92T^9G)O;5AM
M;%-T<FEN9R@D9&%T82P@4$5!4E]604Q)1$%415].3U)-04PL(&9A;'-E*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@("`@
M("`@)&5R<G,@/2`D<&8M/F=E=%5S97)I;F9O*"D[#0H@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)&5R<G,I*2![#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&5R<G,@87,@)&5R<F]R*2![#0H@("`@("`@("`@("`@("`@("`@("1E
M(#T@)'1H:7,M/G)A:7-E17)R;W(H)&5R<F]R6R=M97-S86=E)UTL("1E<G)O
M<ELG8V]D92==+"!N=6QL+"!N=6QL+"`D97)R;W(I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<&8[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&]S=%!R;V-E
M<W-686QI9%!A8VMA9V5X;6PH)'!F*3L-"B`@("!]#0H@("`@+R\@?7U]#0H-
M"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q0
M14%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(%]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM
M;"@F)'!F*0T*("`@('L-"B`@("`@("`@:68@*&ES7V$H)'!F+"`G4$5!4E]0
M86-K86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("`O+R!S;W)T(&]F(&UA
M:V4@=&AI<R!I;G1O(&$@<&%C:V%G92YX;6P@,2XP+7-T>6QE(&%R<F%Y#0H@
M("`@("`@("`@("`O+R!C:&%N9V5L;V<@:7,@;F]T(&-O;G9E<G1E9"!T;R!O
M;&0@9F]R;6%T+@T*("`@("`@("`@("`@)&%R<B`]("1P9BT^=&]!<G)A>2AT
M<G5E*3L-"B`@("`@("`@("`@("1A<G(@/2!A<G)A>5]M97)G92@D87)R+"`D
M87)R6R=O;&0G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=O;&0G72D[
M#0H@("`@("`@("`@("!U;G-E="@D87)R6R=X<V1V97)S:6]N)UTI.PT*("`@
M("`@("`@("`@=6YS970H)&%R<ELG8V]N=&5N=',G72D[#0H@("`@("`@("`@
M("!U;G-E="@D87)R6R=C;VUP871I8FQE)UTI.PT*("`@("`@("`@("`@=6YS
M970H)&%R<ELG8VAA;FYE;"==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);
M)W5R:2==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)V1E<&5N9&5N8VEE
M<R==*3L-"B`@("`@("`@("`@('5N<V5T*"1A<G);)W!H<')E;&5A<V4G72D[
M#0H@("`@("`@("`@("!U;G-E="@D87)R6R=E>'1S<F-R96QE87-E)UTI.PT*
M("`@("`@("`@("`@=6YS970H)&%R<ELG97AT8FEN<F5L96%S92==*3L-"B`@
M("`@("`@("`@('5N<V5T*"1A<G);)V)U;F1L92==*3L-"B`@("`@("`@("`@
M('5N<V5T*"1A<G);)VQE860G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R
M6R=D979E;&]P97(G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=H96QP
M97(G72D[#0H@("`@("`@("`@("!U;G-E="@D87)R6R=C;VYT<FEB=71O<B==
M*3L-"B`@("`@("`@("`@("1A<G);)V9I;&5L:7-T)UT@/2`D<&8M/F=E=$9I
M;&5L:7-T*"D[#0H@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;R`]("1A<G([
M#0H@("`@("`@("`@("!R971U<FX@)&%R<CL-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O(#T@)'!F+3YT;T%R<F%Y*"D[
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G!K9VEN9F\[#0H@("`@("`@
M('T-"B`@("!]#0H@("`@+R\@>WM[(&EN9F]&<F]M06YY*"D-"@T*("`@("\J
M*@T*("`@("`J(%)E='5R;G,@<&%C:V%G92!I;F9O<FUA=&EO;B!F<F]M(&1I
M9F9E<F5N="!S;W5R8V5S#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO9"!I
M<R!A8FQE('1O(&5X=')A8W0@:6YF;W)M871I;VX@86)O=70@82!P86-K86=E
M#0H@("`@("H@9G)O;2!A("YT9WH@87)C:&EV92!O<B!F<F]M(&$@6$U,('!A
M8VMA9V4@9&5F:6YI=&EO;B!F:6QE+@T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`<&%R86T@('-T<FEN9R!&:6QE;F%M92!O9B!T
M:&4@<V]U<F-E("@G<&%C:V%G92YX;6PG+"`G/'!A8VMA9V4^+G1G>B<I#0H@
M("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B!`9&5P<F5C871E9"!U<V4@
M4$5!4E]086-K86=E1FEL92T^9G)O;4%N>49I;&4H*2!I;G-T96%D#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@:6YF;T9R;VU!;GDH)&EN9F\I#0H@("`@>PT*
M("`@("`@("!I9B`H:7-?<W1R:6YG*"1I;F9O*2`F)B!F:6QE7V5X:7-T<R@D
M:6YF;RDI('L-"B`@("`@("`@("`@("1P86-K86=E9FEL92`]("9N97<@4$5!
M4E]086-K86=E1FEL92@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@("`@("1P
M9B`]("8D<&%C:V%G969I;&4M/F9R;VU!;GE&:6QE*"1I;F9O+"!014%27U9!
M3$E$051%7TY/4DU!3"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<&8I*2![#0H@("`@("`@("`@("`@("`@)&5R<G,@/2`D<&8M/F=E=%5S
M97)I;F9O*"D[#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G)S
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D
M97)R;W(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1E(#T@)'1H:7,M
M/G)A:7-E17)R;W(H)&5R<F]R6R=M97-S86=E)UTL("1E<G)O<ELG8V]D92==
M+"!N=6QL+"!N=6QL+"`D97)R;W(I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D
M<&8[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]P;W-T4')O8V5S<U9A;&ED4&%C:V%G97AM;"@D<&8I.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D:6YF;SL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@>&UL1G)O;4EN9F\H*0T*#0H@("`@+RHJ#0H@("`@("H@
M4F5T=7)N(&%N(%A-3"!D;V-U;65N="!B87-E9"!O;B!T:&4@<&%C:V%G92!I
M;F9O("AA<R!R971U<FYE9`T*("`@("`J(&)Y('1H92!014%27T-O;6UO;CHZ
M:6YF;T9R;VTJ(&UE=&AO9',I+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R
M<F%Y("`D<&MG:6YF;R`@<&%C:V%G92!I;F9O#0H@("`@("H-"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R!834P@9&%T80T*("`@("`J#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!U<V4@82!014%27U!A8VMA
M9V5&:6QE7W8J(&]B:F5C="=S(&=E;F5R871O<B!I;G-T96%D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@>&UL1G)O;4EN9F\H)'!K9VEN9F\I#0H@("`@>PT*
M("`@("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-
M"B`@("`@("`@)'!A8VMA9V5F:6QE(#T@)FYE=R!014%27U!A8VMA9V5&:6QE
M*"1C;VYF:6<I.PT*("`@("`@("`D<&8@/2`F)'!A8VMA9V5F:6QE+3YF<F]M
M07)R87DH)'!K9VEN9F\I.PT*("`@("`@("`D9V5N(#T@)B1P9BT^9V5T1&5F
M875L=$=E;F5R871O<B@I.PT*("`@("`@("!R971U<FX@)&=E;BT^=&]8;6PH
M4$5!4E]604Q)1$%415]004-+04=)3D<I.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!V86QI9&%T95!A8VMA9V5);F9O*"D-"@T*("`@("\J
M*@T*("`@("`J(%9A;&ED871E(%A-3"!P86-K86=E(&1E9FEN:71I;VX@9FEL
M92X-"B`@("`@*@T*("`@("`J($!P87)A;2`@<W1R:6YG("1I;F9O($9I;&5N
M86UE(&]F('1H92!P86-K86=E(&%R8VAI=F4@;W(@;V8@=&AE#0H@("`@("H@
M("`@("`@("`@("`@("`@<&%C:V%G92!D969I;FET:6]N(&9I;&4-"B`@("`@
M*B!`<&%R86T@(&%R<F%Y("1E<G)O<G,@07)R87D@=&AA="!W:6QL(&-O;G1A
M:6X@=&AE(&5R<F]R<PT*("`@("`J($!P87)A;2`@87)R87D@)'=A<FYI;F=S
M($%R<F%Y('1H870@=VEL;"!C;VYT86EN('1H92!W87)N:6YG<PT*("`@("`J
M($!P87)A;2`@<W1R:6YG("1D:7)?<')E9FEX("AO<'1I;VYA;"D@9&ER96-T
M;W)Y('=H97)E('-O=7)C92!F:6QE<PT*("`@("`J("`@("`@("`@("`@("`@
M(&UA>2!B92!F;W5N9"P@;W(@96UP='D@:68@=&AE>2!A<F4@;F]T(&%V86EL
M86)L90T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0')E='5R;B!B
M;V]L96%N#0H@("`@("H@0&1E<')E8V%T960@=7-E('1H92!V86QI9&%T:6]N
M(&]F(%!%05)?4&%C:V%G949I;&4@;V)J96-T<PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('9A;&ED871E4&%C:V%G94EN9F\H)&EN9F\L("8D97)R;W)S+"`F
M)'=A<FYI;F=S+"`D9&ER7W!R969I>"`]("<G*0T*("`@('L-"B`@("`@("`@
M)&-O;F9I9R`]("9014%27T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@
M("1P86-K86=E9FEL92`]("9N97<@4$5!4E]086-K86=E1FEL92@D8V]N9FEG
M*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("!I9B`H<W1R<&]S*"1I;F9O+"`G
M/#]X;6PG*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1P9B`]("8D<&%C
M:V%G969I;&4M/F9R;VU8;6Q3=')I;F<H)&EN9F\L(%!%05)?5D%,241!5$5?
M3D]234%,+"`G)RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M<&8@/2`F)'!A8VMA9V5F:6QE+3YF<F]M06YY1FEL92@D:6YF;RP@4$5!4E]6
M04Q)1$%415].3U)-04PI.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z.G-T
M871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)'!F*2D@>PT*("`@("`@("`@("`@)&5R<G,@/2`D<&8M/F=E=%5S
M97)I;F9O*"D[#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)&5R<G,I*2![
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5R<G,@87,@)&5R<F]R*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@
M)V5R<F]R)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R<UM=
M(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=V%R;FEN9W-;72`]
M("1E<G)O<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!B=6EL9%!R;W9I
M9&5S07)R87DH*0T*#0H@("`@+RHJ#0H@("`@("H@0G5I;&0@82`B<')O=FED
M97,B(&%R<F%Y(&9R;VT@9&%T82!R971U<FYE9"!B>0T*("`@("`J(&%N86QY
M>F53;W5R8V5#;V1E*"DN("!4:&4@9F]R;6%T(&]F('1H92!B=6EL="!A<G)A
M>2!I<R!L:6ME#0H@("`@("H@=&AI<SH-"B`@("`@*@T*("`@("`J("!A<G)A
M>2@-"B`@("`@*B`@("`G8VQA<W,[37E#;&%S<R<@/3X@)V%R<F%Y*"=T>7!E
M)R`]/B`G8VQA<W,G+"`G;F%M92<@/3X@)TUY0VQA<W,G*2P-"B`@("`@*B`@
M("`N+BX-"B`@("`@*B`@*0T*("`@("`J#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@87)R87D@)'-R8VEN9F\@87)R87D@=VET:"!I;F9O<FUA=&EO;B!A8F]U
M="!A('-O=7)C92!F:6QE#0H@("`@("H@87,@<F5T=7)N960@8GD@=&AE(&%N
M86QY>F53;W5R8V5#;V1E*"D@;65T:&]D+@T*("`@("`J#0H@("`@("H@0')E
M='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8G5I;&10<F]V:61E<T%R<F%Y
M*"1S<F-I;F9O*0T*("`@('L-"B`@("`@("`@)&9I;&4@/2!B87-E;F%M92@D
M<W)C:6YF;ULG<V]U<F-E7V9I;&4G72D[#0H@("`@("`@("1P;B`]("<G.PT*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E3F%M92DI('L-"B`@
M("`@("`@("`@("1P;B`]("1T:&ES+3Y?<&%C:V%G94YA;64[#0H@("`@("`@
M('T-"B`@("`@("`@)'!N;"`]('-T<FQE;B@D<&XI.PT*("`@("`@("!F;W)E
M86-H("@D<W)C:6YF;ULG9&5C;&%R961?8VQA<W-E<R==(&%S("1C;&%S<RD@
M>PT*("`@("`@("`@("`@)&ME>2`](")C;&%S<SLD8VQA<W,B.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K
M97E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'1H:7,M/G!K9VEN9F];)W!R;W9I9&5S)UU;
M)&ME>5T@/0T*("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE
M+"`G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("1C;&%S<RD[#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;)&-L
M87-S72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^<&MG:6YF;ULG<')O
M=FED97,G75LD:V5Y75LG97AT96YD<R==(#T-"B`@("`@("`@("`@("`@("`@
M("`@)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;)&-L87-S73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D<W)C:6YF;ULG
M9&5C;&%R961?;65T:&]D<R==(&%S("1C;&%S<R`]/B`D;65T:&]D<RD@>PT*
M("`@("`@("`@("`@9F]R96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@>PT*
M("`@("`@("`@("`@("`@("1F=6YC=&EO;B`]("(D8VQA<W,Z.B1M971H;V0B
M.PT*("`@("`@("`@("`@("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N
M(CL-"B`@("`@("`@("`@("`@("!I9B`H)&UE=&AO9'LP?2`]/2`G7R<@?'P@
M(7-T<F-A<V5C;7`H)&UE=&AO9"P@)&-L87-S*2!\?`T*("`@("`@("`@("`@
M("`@("`@("!I<W-E="@D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T:&ES+3YP:V=I;F9O6R=P
M<F]V:61E<R==6R1K97E=(#T-"B`@("`@("`@("`@("`@("`@("`@87)R87DH
M)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]/B`G9G5N8W1I;VXG+"`G;F%M92<@
M/3X@)&9U;F-T:6]N*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@
M("`@("`@(&9O<F5A8V@@*"1S<F-I;F9O6R=D96-L87)E9%]F=6YC=&EO;G,G
M72!A<R`D9G5N8W1I;VXI('L-"B`@("`@("`@("`@("1K97D@/2`B9G5N8W1I
M;VX[)&9U;F-T:6]N(CL-"B`@("`@("`@("`@(&EF("@D9G5N8W1I;VY[,'T@
M/3T@)U\G('Q\(&ES<V5T*"1T:&ES+3YP:V=I;F9O6R=P<F]V:61E<R==6R1K
M97E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"%S=')S='(H)&9U;F-T:6]N+"`G.CHG
M*2`F)B!S=')N8V%S96-M<"@D9G5N8W1I;VXL("1P;BP@)'!N;"DI('L-"B`@
M("`@("`@("`@("`@("`D=V%R;FEN9W-;72`](")I;C$@(B`N("1F:6QE("X@
M(CH@9G5N8W1I;VX@7"(D9G5N8W1I;VY<(B!N;W0@<')E9FEX960@=VET:"!P
M86-K86=E(&YA;64@7"(D<&Y<(B([#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D=&AI<RT^<&MG:6YF;ULG<')O=FED97,G75LD:V5Y72`]#0H@("`@
M("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L("=T>7!E)R`]/B`G
M9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N*3L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A;F%L>7IE4V]U<F-E
M0V]D92@I#0H-"B`@("`O*BH-"B`@("`@*B!!;F%L>7IE('1H92!S;W5R8V4@
M8V]D92!O9B!T:&4@9VEV96X@4$A0(&9I;&4-"B`@("`@*@T*("`@("`J($!P
M87)A;2`@<W1R:6YG($9I;&5N86UE(&]F('1H92!02%`@9FEL90T*("`@("`J
M($!R971U<FX@;6EX960-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&%N86QY>F53;W5R8V5#;V1E*"1F:6QE*0T*("`@
M('L-"B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H(G1O:V5N7V=E=%]A
M;&PB*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%]$3T-?0T]-345.5"<I*2![#0H@
M("`@("`@("`@("!D969I;F4H)U1?1$]#7T-/34U%3E0G+"!47T-/34U%3E0I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%])3E1%4D9!
M0T4G*2D@>PT*("`@("`@("`@("`@9&5F:6YE*"=47TE.5$521D%#12<L("TQ
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(61E9FEN960H)U1?24U03$5-
M14Y44R<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?24U03$5-14Y44R<L
M("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21F<"`]($!F;W!E;B@D
M9FEL92P@(G(B*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T
M7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@
M("`@("`@("`@)&-O;G1E;G1S(#T@9FEL95]G971?8V]N=&5N=',H)&9I;&4I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M9G)E860H)&9P+"!F:6QE<VEZ92@D9FEL92DI.PT*("`@("`@("`@("`@9F-L
M;W-E*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@)'1O:V5N<R`]('1O:V5N
M7V=E=%]A;&PH)&-O;G1E;G1S*3L-"B\J#0H@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@("`@("`@
M0&QI<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@("`@("`@
M("`@(&EF("AI<U]S=')I;F<H)'1O:V5N*2D@>PT*("`@("`@("`@("`@("`@
M('9A<E]D=6UP*"1T;VME;BD[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@('!R:6YT('1O:V5N7VYA;64H)'1O:V5N*2`N("<@)SL-
M"B`@("`@("`@("`@("`@("!V87)?9'5M<"AR=')I;2@D9&%T82DI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0HJ+PT*("`@("`@("`D;&]O:U]F;W(@
M/2`P.PT*("`@("`@("`D<&%R96Y?;&5V96P@/2`P.PT*("`@("`@("`D8G)A
M8VME=%]L979E;"`](#`[#0H@("`@("`@("1B<F%C95]L979E;"`](#`[#0H@
M("`@("`@("1L87-T<&AP9&]C(#T@)R<[#0H@("`@("`@("1C=7)R96YT7V-L
M87-S(#T@)R<[#0H@("`@("`@("1C=7)R96YT7VEN=&5R9F%C92`]("<G.PT*
M("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ.PT*("`@("`@("`D
M8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`D8W5R<F5N=%]F=6YC
M=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`D9&5C;&%R961?8VQA<W-E<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S(#T@87)R
M87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<R`](&%R<F%Y*"D[
M#0H@("`@("`@("1D96-L87)E9%]M971H;V1S(#T@87)R87DH*3L-"B`@("`@
M("`@)'5S961?8VQA<W-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D7V9U
M;F-T:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@("1E>'1E;F1S(#T@87)R87DH
M*3L-"B`@("`@("`@)&EM<&QE;65N=',@/2!A<G)A>2@I.PT*("`@("`@("`D
M;F]D97!S(#T@87)R87DH*3L-"B`@("`@("`@)&EN<75O=&4@/2!F86QS93L-
M"B`@("`@("`@)&EN=&5R9F%C92`](&9A;'-E.PT*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!S:7IE;V8H)'1O:V5N<RD[("1I*RLI('L-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D=&]K96YS6R1I72DI('L-"B`@("`@("`@("`@
M("`@("!L:7-T*"1T;VME;BP@)&1A=&$I(#T@)'1O:V5N<ULD:5T[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T;VME;B`]("1T
M;VME;G-;)&E=.PT*("`@("`@("`@("`@("`@("1D871A(#T@)R<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&EN<75O=&4I('L-"B`@("`@
M("`@("`@("`@("!I9B`H)'1O:V5N("$]("<B)RD@>PT*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D:6YQ=6]T92`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!S=VET8V@@*"1T;VME;BD@>PT*
M("`@("`@("`@("`@("`@(&-A<V4@5%]72$E415-004-%.@T*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!C87-E("<[
M)SH-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I;G1E<F9A8V4I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@)R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L
M979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)R(G.@T*
M("`@("`@("`@("`@("`@("`@("`D:6YQ=6]T92`]('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]#
M55),65]/4$5..@T*("`@("`@("`@("`@("`@(&-A<V4@5%]$3TQ,05)?3U!%
M3E]#55),65]"4D%#15,Z#0H@("`@("`@("`@("`@("`@8V%S92`G>R<Z("1B
M<F%C95]L979E;"LK.R!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A
M<V4@)WTG.@T*("`@("`@("`@("`@("`@("`@("`D8G)A8V5?;&5V96PM+3L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT7V-L87-S7VQE=F5L
M(#T]("1B<F%C95]L979E;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-U<G)E;G1?8VQA<W,@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1C=7)R96YT7V-L87-S7VQE=F5L(#T@+3$[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT7V9U;F-T
M:6]N7VQE=F5L(#T]("1B<F%C95]L979E;"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`G)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@+3$[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("=;)SH@)&)R86-K971?
M;&5V96PK*SL@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("==
M)SH@)&)R86-K971?;&5V96PM+3L@8V]N=&EN=64@,CL-"B`@("`@("`@("`@
M("`@("!C87-E("<H)SH@)'!A<F5N7VQE=F5L*RL[("`@8V]N=&EN=64@,CL-
M"B`@("`@("`@("`@("`@("!C87-E("<I)SH@)'!A<F5N7VQE=F5L+2T[("`@
M8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?24Y415)&04-%
M.@T*("`@("`@("`@("`@("`@("`@("`D:6YT97)F86-E(#T@=')U93L-"B`@
M("`@("`@("`@("`@("!C87-E(%1?0TQ!4U,Z#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@H)&-U<G)E;G1?8VQA<W-?;&5V96P@(3T@+3$I('Q\("@D8W5R
M<F5N=%]F=6YC=&EO;E]L979E;"`A/2`M,2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H(E!A<G-E<B!E<G)O<CH@:6YV
M86QI9"!02%`@9F]U;F0@:6X@9FEL92!<(B1F:6QE7"(B+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%!%05)?0T]-34].7T524D]27TE.5D%,2410
M2%`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8V%S92!4
M7T953D-424]..@T*("`@("`@("`@("`@("`@(&-A<V4@5%].15<Z#0H@("`@
M("`@("`@("`@("`@8V%S92!47T585$5.1%,Z#0H@("`@("`@("`@("`@("`@
M8V%S92!47TE-4$Q%345.5%,Z#0H@("`@("`@("`@("`@("`@("`@("1L;V]K
M7V9O<B`]("1T;VME;CL-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@
M,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?4U1224Y'.@T*("`@("`@("`@
M("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I
M+"`G,BXP)RP@)SPG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&EN7V%R<F%Y*'-T<G1O;&]W97(H)&1A=&$I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"=P=6)L:6,G+"`G<')I=F%T92<L("=P<F]T
M96-T960G+"`G86)S=')A8W0G+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=I;G1E<F9A8V4G+"`G:6UP;&5M96YT<R<L("=T:')O=R<I
M(`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G)A:7-E17)R;W(H)T5R
M<F]R.B!02%`U('1O:V5N(&5N8V]U;G1E<F5D(&EN("<@+B`D9FEL92`N(`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P86-K86=I;F<@<VAO=6QD
M(&)E(&1O;F4@:6X@4$A0(#4G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1L;V]K7V9O<B`]/2!47T-,05-3*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D8W5R<F5N=%]C;&%S<R`]("1D871A.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@/2`D8G)A8V5?;&5V
M96P[#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?8VQA<W-E
M<UM=(#T@)&-U<G)E;G1?8VQA<W,[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS96EF("@D;&]O:U]F;W(@/3T@5%])3E1%4D9!0T4I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1C=7)R96YT7VEN=&5R9F%C92`]("1D871A.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V96P@
M/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5C
M;&%R961?:6YT97)F86-E<UM=(#T@)&-U<G)E;G1?:6YT97)F86-E.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T](%1?24U0
M3$5-14Y44RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EM<&QE;65N
M='-;)&-U<G)E;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%]%6%1%3D13*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D97AT96YD<ULD8W5R<F5N=%]C;&%S<UT@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K
M7V9O<B`]/2!47T953D-424].*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-U<G)E;G1?8VQA<W,I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("(D8W5R<F5N=%]C;&%S<SHZ
M)&1A=&$B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E
M9%]M971H;V1S6R1C=7)R96YT7V-L87-S75M=(#T@)&1A=&$[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-U<G)E;G1?:6YT97)F86-E
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N
M8W1I;VX@/2`B)&-U<G)E;G1?:6YT97)F86-E.CHD9&%T82([#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VUE=&AO9'-;)&-U<G)E
M;G1?:6YT97)F86-E75M=(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M=7)R96YT7V9U;F-T:6]N(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<UM=(#T@)&-U<G)E;G1?9G5N
M8W1I;VX[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]("1B<F%C
M95]L979E;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("1M(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]
M/2!47TY%5RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA
M<W-E<ULD9&%T85T@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("1L;V]K7V9O<B`](#`[#0H@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92!4
M7U9!4DE!0DQ%.@T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F;W(@/2`P
M.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@
M("`@("`@(&-A<V4@5%]$3T-?0T]-345.5#H-"B`@("`@("`@("`@("`@("!C
M87-E(%1?0T]-345.5#H-"B`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H)R%>+UPJ7"I<<R$G+"`D9&%T82DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1L87-T<&AP9&]C(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H<')E9U]M871C:%]A;&PH)R]`;F]D97!<<RLH7%,K
M*2\G+"`D;&%S='!H<&1O8RP@)&TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YO9&5P<R`](&%R<F%Y7VUE<F=E*"1N;V1E<',L("1M6S%=
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@
M("`@("`@("`@("`@(&-A<V4@5%]$3U5"3$5?0T],3TXZ#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A*"1T;VME;G-;)&D@+2`Q75LP72`]/2!47U=(251%
M4U!!0T4@?'P@)'1O:V5N<ULD:2`M(#%=6S!=(#T](%1?4U1224Y'*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@B4&%R
M<V5R(&5R<F]R.B!I;G9A;&ED(%!(4"!F;W5N9"!I;B!F:6QE(%PB)&9I;&5<
M(B(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E]#3TU-3TY?
M15)23U)?24Y604Q)1%!(4"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@)&-L87-S(#T@)'1O:V5N<ULD:2`M(#%=6S%=.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D8VQA<W,I("$]("=P
M87)E;G0G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=7-E9%]C;&%S
M<V5S6R1C;&%S<UT@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@("`@
M("`@(G-O=7)C95]F:6QE(B`]/B`D9FEL92P-"B`@("`@("`@("`@(")D96-L
M87)E9%]C;&%S<V5S(B`]/B`D9&5C;&%R961?8VQA<W-E<RP-"B`@("`@("`@
M("`@(")D96-L87)E9%]I;G1E<F9A8V5S(B`]/B`D9&5C;&%R961?:6YT97)F
M86-E<RP-"B`@("`@("`@("`@(")D96-L87)E9%]M971H;V1S(B`]/B`D9&5C
M;&%R961?;65T:&]D<RP-"B`@("`@("`@("`@(")D96-L87)E9%]F=6YC=&EO
M;G,B(#T^("1D96-L87)E9%]F=6YC=&EO;G,L#0H@("`@("`@("`@("`B=7-E
M9%]C;&%S<V5S(B`]/B!A<G)A>5]D:69F*&%R<F%Y7VME>7,H)'5S961?8VQA
M<W-E<RDL("1N;V1E<',I+`T*("`@("`@("`@("`@(FEN:&5R:71A;F-E(B`]
M/B`D97AT96YD<RP-"B`@("`@("`@("`@(")I;7!L96UE;G1S(B`]/B`D:6UP
M;&5M96YT<RP-"B`@("`@("`@("`@("D[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[("!B971T97)3=&%T97,H*0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5T=7)N(&%N(&%R<F%Y(&-O;G1A:6YI;F<@86QL(&]F('1H92!S=&%T
M97,@=&AA="!A<F4@;6]R92!S=&%B;&4@=&AA;@T*("`@("`J(&]R(&5Q=6%L
M('1O('1H92!P87-S960@:6X@<W1A=&4-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@4F5L96%S92!S=&%T90T*("`@("`J($!P87)A;2!B;V]L96%N
M($1E=&5R;6EN97,@=VAE=&AE<B!T;R!I;F-L=61E("1S=&%T92!I;B!T:&4@
M;&ES=`T*("`@("`J($!R971U<FX@9F%L<V5\87)R87D@1F%L<V4@:68@)'-T
M871E(&ES(&YO="!A('9A;&ED(')E;&5A<V4@<W1A=&4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!B971T97)3=&%T97,H)'-T871E+"`D:6YC;'5D92`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@<W1A=&EC("1S=&%T97,@/2!A<G)A>2@G
M<VYA<'-H;W0G+"`G9&5V96PG+"`G86QP:&$G+"`G8F5T82<L("=S=&%B;&4G
M*3L-"B`@("`@("`@)&D@/2!A<G)A>5]S96%R8V@H)'-T871E+"`D<W1A=&5S
M*3L-"B`@("`@("`@:68@*"1I(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D:6YC;'5D
M92D@>PT*("`@("`@("`@("`@)&DM+3L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@87)R87E?<VQI8V4H)'-T871E<RP@)&D@*R`Q*3L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&5T96-T1&5P96YD96YC:65S*"D-
M"@T*("`@(&9U;F-T:6]N(&1E=&5C=$1E<&5N9&5N8VEE<R@D86YY+"`D<W1A
M='5S7V-A;&QB86-K(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@A9G5N
M8W1I;VY?97AI<W1S*")T;VME;E]G971?86QL(BDI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D:6YF;R`]("1T:&ES+3YI;F9O1G)O;4%N>2@D86YY*2DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("`D9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D7V,@/2`D9&5C;%]C
M(#T@)&1E8VQ?9B`]("1D96-L7VT@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E
M86-H("@D:6YF;ULG9FEL96QI<W0G72!A<R`D9FEL92`]/B`D9F$I('L-"B`@
M("`@("`@("`@("1T;7`@/2`D=&AI<RT^86YA;'EZ95-O=7)C94-O9&4H)&9I
M;&4I.PT*("`@("`@("`@("`@)'5S961?8R`]($!A<G)A>5]M97)G92@D=7-E
M9%]C+"`D=&UP6R=U<V5D7V-L87-S97,G72D[#0H@("`@("`@("`@("`D9&5C
M;%]C(#T@0&%R<F%Y7VUE<F=E*"1D96-L7V,L("1T;7!;)V1E8VQA<F5D7V-L
M87-S97,G72D[#0H@("`@("`@("`@("`D9&5C;%]F(#T@0&%R<F%Y7VUE<F=E
M*"1D96-L7V8L("1T;7!;)V1E8VQA<F5D7V9U;F-T:6]N<R==*3L-"B`@("`@
M("`@("`@("1D96-L7VT@/2!`87)R87E?;65R9V4H)&1E8VQ?;2P@)'1M<%LG
M9&5C;&%R961?;65T:&]D<R==*3L-"B`@("`@("`@("`@("1I;FAE<FD@/2!`
M87)R87E?;65R9V4H)&EN:&5R:2P@)'1M<%LG:6YH97)I=&%N8V4G72D[#0H@
M("`@("`@('T-"B`@("`@("`@)'5S961?8R`](&%R<F%Y7W5N:7%U92@D=7-E
M9%]C*3L-"B`@("`@("`@)&1E8VQ?8R`](&%R<F%Y7W5N:7%U92@D9&5C;%]C
M*3L-"B`@("`@("`@)'5N9&5C;%]C(#T@87)R87E?9&EF9B@D=7-E9%]C+"`D
M9&5C;%]C*3L-"B`@("`@("`@<F5T=7)N(&%R<F%Y*"=U<V5D7V-L87-S97,G
M(#T^("1U<V5D7V,L#0H@("`@("`@("`@("`@("`@("`@("`G9&5C;&%R961?
M8VQA<W-E<R<@/3X@)&1E8VQ?8RP-"B`@("`@("`@("`@("`@("`@("`@("=D
M96-L87)E9%]M971H;V1S)R`]/B`D9&5C;%]M+`T*("`@("`@("`@("`@("`@
M("`@("`@)V1E8VQA<F5D7V9U;F-T:6]N<R<@/3X@)&1E8VQ?9BP-"B`@("`@
M("`@("`@("`@("`@("`@("=U;F1E8VQA<F5D7V-L87-S97,G(#T^("1U;F1E
M8VQ?8RP-"B`@("`@("`@("`@("`@("`@("`@("=I;FAE<FET86YC92<@/3X@
M)&EN:&5R:2P-"B`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=%5S97)2;VQE<R@I#0H-"B`@("`O
M*BH-"B`@("`@*B!'970@=&AE('9A;&ED(')O;&5S(&9O<B!A(%!%05(@<&%C
M:V%G92!M86EN=&%I;F5R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%5S
M97)2;VQE<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@)$=,3T)!3%-;)U]0
M14%27T-O;6UO;E]M86EN=&%I;F5R7W)O;&5S)UT[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&=E=%)E;&5A<V53=&%T97,H*0T*#0H@("`@
M+RHJ#0H@("`@("H@1V5T('1H92!V86QI9"!P86-K86=E(')E;&5A<V4@<W1A
M=&5S(&]F('!A8VMA9V5S#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%)E
M;&5A<V53=&%T97,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1'3$]"04Q3
M6R=?4$5!4E]#;VUM;VY?<F5L96%S95]S=&%T97,G73L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1&5P96YD96YC>51Y<&5S*"D-"@T*
M("`@("\J*@T*("`@("`J($=E="!T:&4@:6UP;&5M96YT960@9&5P96YD96YC
M>2!T>7!E<R`H<&AP+"!E>'0L('!K9R!E=&,N*0T*("`@("`J#0H@("`@("H@
M0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971$97!E;F1E;F-Y5'EP97,H*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM;VY?9&5P96YD96YC>5]T>7!E
M<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971$97!E
M;F1E;F-Y4F5L871I;VYS*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M:6UP;&5M96YT960@9&5P96YD96YC>2!R96QA=&EO;G,@*&AA<RP@;'0L(&=E
M(&5T8RXI#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@
M0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E<&5N9&5N8WE2
M96QA=&EO;G,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?
M4$5!4E]#;VUM;VY?9&5P96YD96YC>5]R96QA=&EO;G,G73L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1FEL95)O;&5S*"D-"@T*("`@
M("\J*@T*("`@("`J($=E="!T:&4@:6UP;&5M96YT960@9FEL92!R;VQE<PT*
M("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971&:6QE4F]L97,H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM;VY?9FEL95]R
M;VQE<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G9712
M97!L86-E;65N=%1Y<&5S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M:6UP;&5M96YT960@9FEL92!R97!L86-E;65N="!T>7!E<R!I;@T*("`@("`J
M#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971297!L86-E;65N=%1Y<&5S*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W)E<&QA
M8V5M96YT7W1Y<&5S)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=%!R;W9I9&54>7!E<R@I#0H-"B`@("`O*BH-"B`@("`@*B!'970@
M=&AE(&EM<&QE;65N=&5D(&9I;&4@<F5P;&%C96UE;G0@='EP97,@:6X-"B`@
M("`@*@T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4')O=FED951Y<&5S*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]M;6]N7W!R;W9I
M9&5?='EP97,G73L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9V5T4V-R:7!T4&AA<V5S*"D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@
M:6UP;&5M96YT960@9FEL92!R97!L86-E;65N="!T>7!E<R!I;@T*("`@("`J
M#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G97138W)I<'10:&%S97,H*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N("1'3$]"04Q36R=?4$5!4E]#;VUM;VY?<V-R:7!T7W!H
M87-E<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!V86QI
M9%!A8VMA9V5.86UE*"D-"@T*("`@("\J*@T*("`@("`J(%1E<W0@=VAE=&AE
M<B!A('-T<FEN9R!C;VYT86EN<R!A('9A;&ED('!A8VMA9V4@;F%M92X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&YA;64@=&AE('!A8VMA9V4@
M;F%M92!T;R!T97-T#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@=F%L:61086-K86=E3F%M92@D;F%M92D-"B`@("![#0H@("`@("`@
M(')E='5R;B`H8F]O;"EP<F5G7VUA=&-H*%!%05)?0T]-34].7U!!0TM!1T5?
M3D%-15]04D5'+"`D;F%M92D[#0H@("`@?0T*#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@=F%L:61086-K86=E5F5R<VEO;B@I#0H-"B`@("`O*BH-"B`@
M("`@*B!497-T('=H971H97(@82!S=')I;F<@8V]N=&%I;G,@82!V86QI9"!P
M86-K86=E('9E<G-I;VXN#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1V97(@=&AE('!A8VMA9V4@=F5R<VEO;B!T;R!T97-T#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:61086-K86=E5F5R<VEO
M;B@D=F5R*0T*("`@('L-"B`@("`@("`@<F5T=7)N("AB;V]L*7!R96=?;6%T
M8V@H4$5!4E]#3TU-3TY?4$%#2T%'15]615)324].7U!214<L("1V97(I.PT*
M("`@('T-"@T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@9&]W;FQO861(
M='1P*"D-"@T*("`@("\J*@T*("`@("`J($1O=VYL;V%D(&$@9FEL92!T:')O
M=6=H($A45%`N("!#;VYS:61E<G,@<W5G9V5S=&5D(&9I;&4@;F%M92!I;@T*
M("`@("`J($-O;G1E;G0M9&ES<&]S:71I;VXZ(&AE861E<B!A;F0@8V%N(')U
M;B!A(&-A;&QB86-K(&9U;F-T:6]N(&9O<@T*("`@("`J(&1I9F9E<F5N="!E
M=F5N=',N("!4:&4@8V%L;&)A8VL@=VEL;"!B92!C86QL960@=VET:"!T=V\-
M"B`@("`@*B!P87)A;65T97)S.B!T:&4@8V%L;&)A8VL@='EP92P@86YD('!A
M<F%M971E<G,N("!4:&4@:6UP;&5M96YT960-"B`@("`@*B!C86QL8F%C:R!T
M>7!E<R!A<F4Z#0H@("`@("H-"B`@("`@*B`@)W-E='5P)R`@("`@("!C86QL
M960@870@=&AE('9E<GD@8F5G:6YN:6YG+"!P87)A;65T97(@:7,@82!522!O
M8FIE8W0-"B`@("`@*B`@("`@("`@("`@("`@("!T:&%T('-H;W5L9"!B92!U
M<V5D(&9O<B!A;&P@;W5T<'5T#0H@("`@("H@("=M97-S86=E)R`@("`@=&AE
M('!A<F%M971E<B!I<R!A('-T<FEN9R!W:71H(&%N(&EN9F]R;6%T:6]N86P@
M;65S<V%G90T*("`@("`J("`G<V%V96%S)R`@("`@(&UA>2!B92!U<V5D('1O
M('-A=F4@=VET:"!A(&1I9F9E<F5N="!F:6QE(&YA;64L('1H90T*("`@("`J
M("`@("`@("`@("`@("`@('!A<F%M971E<B!I<R!T:&4@9FEL96YA;64@=&AA
M="!I<R!A8F]U="!T;R!B92!U<V5D+@T*("`@("`J("`@("`@("`@("`@("`@
M($EF(&$@)W-A=F5A<R<@8V%L;&)A8VL@<F5T=7)N<R!A(&YO;BUE;7!T>2!S
M=')I;F<L#0H@("`@("H@("`@("`@("`@("`@("`@=&AA="!F:6QE(&YA;64@
M=VEL;"!B92!U<V5D(&%S('1H92!F:6QE;F%M92!I;G-T96%D+@T*("`@("`J
M("`@("`@("`@("`@("`@($YO=&4@=&AA="`D<V%V95]D:7(@=VEL;"!N;W0@
M8F4@869F96-T960@8GD@=&AI<RP@;VYL>0T*("`@("`J("`@("`@("`@("`@
M("`@('1H92!B87-E;F%M92!O9B!T:&4@9FEL92X-"B`@("`@*B`@)W-T87)T
M)R`@("`@("!D;W=N;&]A9"!I<R!S=&%R=&EN9RP@<&%R86UE=&5R(&ES(&YU
M;6)E<B!O9B!B>71E<PT*("`@("`J("`@("`@("`@("`@("`@('1H870@87)E
M(&5X<&5C=&5D+"!O<B`M,2!I9B!U;FMN;W=N#0H@("`@("H@("=B>71E<W)E
M860G("`@<&%R86UE=&5R(&ES('1H92!N=6UB97(@;V8@8GET97,@<F5A9"!S
M;R!F87(-"B`@("`@*B`@)V1O;F4G("`@("`@("!D;W=N;&]A9"!I<R!C;VUP
M;&5T92P@<&%R86UE=&5R(&ES('1H92!T;W1A;"!N=6UB97(-"B`@("`@*B`@
M("`@("`@("`@("`@("!O9B!B>71E<R!R96%D#0H@("`@("H@("=C;VYN9F%I
M;&5D)R`@:68@=&AE(%1#4"!C;VYN96-T:6]N(&9A:6QS+"!T:&ES(&-A;&QB
M86-K(&ES(&-A;&QE9`T*("`@("`J("`@("`@("`@("`@("`@('=I=&@@87)R
M87DH:&]S="QP;W)T+&5R<FYO+&5R<FUS9RD-"B`@("`@*B`@)W=R:71E9F%I
M;&5D)R!I9B!W<FET:6YG('1O(&1I<VL@9F%I;',L('1H:7,@8V%L;&)A8VL@
M:7,@8V%L;&5D#0H@("`@("H@("`@("`@("`@("`@("`@=VET:"!A<G)A>2AD
M97-T9FEL92QE<G)M<V<I#0H@("`@("H-"B`@("`@*B!)9B!A;B!(5%10('!R
M;WAY(&AA<R!B965N(&-O;F9I9W5R960@*&AT='!?<')O>'D@4$5!4E]#;VYF
M:6<-"B`@("`@*B!S971T:6YG*2P@=&AE('!R;WAY('=I;&P@8F4@=7-E9"X-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@("1U<FP@("`@("`@=&AE
M(%523"!T;R!D;W=N;&]A9`T*("`@("`J($!P87)A;2!O8FIE8W0@("1U:2`@
M("`@("`@4$5!4E]&<F]N=&5N9%\J(&EN<W1A;F-E#0H@("`@("H@0'!A<F%M
M(&]B:F5C="`@)&-O;F9I9R`@("!014%27T-O;F9I9R!I;G-T86YC90T*("`@
M("`J($!P87)A;2!S=')I;F<@("1S879E7V1I<B`@*&]P=&EO;F%L*2!D:7)E
M8W1O<GD@=&\@<V%V92!F:6QE(&EN#0H@("`@("H@0'!A<F%M(&UI>&5D("`@
M)&-A;&QB86-K("`H;W!T:6]N86PI(&9U;F-T:6]N+VUE=&AO9"!T;R!C86QL
M(&9O<B!S=&%T=7,-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M('5P9&%T97,-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG("!2971U
M<FYS('1H92!F=6QL('!A=&@@;V8@=&AE(&1O=VYL;V%D960@9FEL92!O<B!A
M(%!%05(-"B`@("`@*B`@("`@("`@("`@("`@("`@97)R;W(@;VX@9F%I;'5R
M92X@($EF('1H92!E<G)O<B!I<R!C875S960@8GD-"B`@("`@*B`@("`@("`@
M("`@("`@("`@<V]C:V5T+7)E;&%T960@97)R;W)S+"!T:&4@97)R;W(@;V)J
M96-T('=I;&P-"B`@("`@*B`@("`@("`@("`@("`@("`@:&%V92!T:&4@9G-O
M8VMO<&5N(&5R<F]R(&-O9&4@879A:6QA8FQE('1H<F]U9V@-"B`@("`@*B`@
M("`@("`@("`@("`@("`@9V5T0V]D92@I+@T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B!`9&5P<F5C871E9"!I;B!F879O<B!O9B!0
M14%27T1O=VYL;V%D97(Z.F1O=VYL;V%D2'1T<"@I#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@9&]W;FQO861(='1P*"1U<FPL("8D=6DL("1S879E7V1I<B`]
M("<N)RP@)&-A;&QB86-K(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@A
M8VQA<W-?97AI<W1S*"=014%27T1O=VYL;V%D97(G*2D@>PT*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=014%2+T1O=VYL;V%D97(N<&AP)SL-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@4$5!4E]$;W=N;&]A9&5R.CID;W=N;&]A
M9$AT='`H)'5R;"P@)'5I+"`D<V%V95]D:7(L("1C86QL8F%C:RD[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1P871H(')E;&%T:79E(&]R(&%B<V]L=71E(&EN8VQU9&4@<&%T:`T*
M("`@("`J($!R971U<FX@8F]O;&5A;@T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!I<TEN8VQU9&5A8FQE*"1P871H*0T*("`@('L-
M"B`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P871H*2`F)B!I<U]R96%D86)L
M92@D<&%T:"DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@("1I<&%T:"`](&5X<&QO9&4H4$%42%]315!!4D%43U(L
M(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I*3L-"B`@("`@("`@9F]R96%C:"`H
M)&EP871H(&%S("1I;F-L=61E*2![#0H@("`@("`@("`@("`D=&5S="`](')E
M86QP871H*"1I;F-L=61E("X@1$E214-43U)97U-%4$%2051/4B`N("1P871H
M*3L-"B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=&5S="D@)B8@:7-?
M<F5A9&%B;&4H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"GT-"G)E<75I<F5?;VYC92`G4$5!4B]#;VYF:6<N
M<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*
M/SX```````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]N9FEG+G!H<```````````
M````````````````````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`R,#<S-S,@,3`U,34T
M,S0Q,S0@,#(Q,30S`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]N9FEG+"!C=7-T;VUI
M>F5D(&-O;F9I9W5R871I;VX@:&%N9&QI;F<@9F]R('1H92!014%2($EN<W1A
M;&QE<@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!5
M4DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@
M268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*
M("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VYF
M:6<N<&AP+'8@,2XQ,C0@,C`P-B\P,R\P,B`Q.#HQ-#HQ,B!C96QL;V<@17AP
M("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@4F5Q=6ER960@9F]R(&5R<F]R
M(&AA;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q
M=6ER95]O;F-E("=014%2+U)E9VES=')Y+G!H<"<[#0IR97%U:7)E7V]N8V4@
M)U!%05(O26YS=&%L;&5R+U)O;&4N<&AP)SL-"G)E<75I<F5?;VYC92`G4WES
M=&5M+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O4F5M;W1E+G!H<"<[#0H-
M"B\J*@T*("H@3&%S="!C<F5A=&5D(%!%05)?0V]N9FEG(&EN<W1A;F-E+@T*
M("H@0'9A<B!O8FIE8W0-"B`J+PT*)$=,3T)!3%-;)U]014%27T-O;F9I9U]I
M;G-T86YC92==(#T@;G5L;#L-"FEF("@A9&5F:6YE9"@G4$5!4E])3E-404Q,
M7T1)4B<I('Q\("%014%27TE.4U1!3$Q?1$E2*2![#0H@("`@)%!%05)?24Y3
M5$%,3%]$25(@/2!02%!?3$E"1$E2("X@1$E214-43U)97U-%4$%2051/4B`N
M("=P96%R)SL-"GT@96QS92![#0H@("`@)%!%05)?24Y35$%,3%]$25(@/2!0
M14%27TE.4U1!3$Q?1$E2.PT*?0T*#0HO+R!"96QO=R!W92!D969I;F4@8V]N
M<W1A;G1S('=I=&@@9&5F875L="!V86QU97,@9F]R(&%L;"!C;VYF:6=U<F%T
M:6]N#0HO+R!P87)A;65T97)S(&5X8V5P="!U<V5R;F%M92]P87-S=V]R9"X@
M($%L;"!O9B!T:&5M(&-A;B!H879E('1H96ER#0HO+R!D969A=6QT<R!S970@
M=&AR;W5G:"!E;G9I<F]N;65N="!V87)I86)L97,N("!4:&4@<F5A<V]N('=E
M('5S92!T:&4-"B\O(%!(4%\@<')E9FEX(&ES(&9O<B!S;VUE('-E8W5R:71Y
M+"!02%`@<')O=&5C=',@96YV:7)O;FUE;G0-"B\O('9A<FEA8FQE<R!S=&%R
M=&EN9R!W:71H(%!(4%\J+@T*#0HO+R!D969A=6QT(&-H86YN96P@86YD('!R
M969E<G)E9"!M:7)R;W(@:7,@8F%S960@;VX@=VAE=&AE<B!W92!A<F4@:6YV
M;VME9"!T:')O=6=H#0HO+R!T:&4@(G!E87(B(&]R('1H92`B<&5C;"(@8V]M
M;6%N9`T*#0II9B`H(61E9FEN960H)U!%05)?4E5.5%E012<I('Q\(%!%05)?
M4E5.5%E012`]/2`G<&5A<B<I('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'
M7T1%1D%53%1?0TA!3DY%3"<L("=P96%R+G!H<"YN970G*3L-"GT@96QS92![
M#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T-(04Y.14PG+"`G
M<&5C;"YP:'`N;F5T)RD[#0I]#0H-"FEF("AG971E;G8H)U!(4%]014%27U-9
M4T-/3D9?1$E2)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7U-94T-/
M3D9$25(G+"!G971E;G8H)U!(4%]014%27U-94T-/3D9?1$E2)RDI.PT*?2!E
M;'-E:68@*&=E=&5N=B@G4WES=&5M4F]O="<I*2![#0H@("`@9&5F:6YE*"=0
M14%27T-/3D9)1U]365-#3TY&1$E2)RP@9V5T96YV*"=3>7-T96U2;V]T)RDI
M.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7U-94T-/3D9$
M25(G+"!02%!?4UE30T].1D1)4BD[#0I]#0H-"B\O($1E9F%U;'0@9F]R(&UA
M<W1E<E]S97)V97(-"FEF("AG971E;G8H)U!(4%]014%27TU!4U1%4E]315)6
M15(G*2D@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]-05-4
M15)?4T525D52)RP@9V5T96YV*"=02%!?4$5!4E]-05-415)?4T525D52)RDI
M.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?
M34%35$527U-%4E9%4B<L("=P96%R+G!H<"YN970G*3L-"GT-"@T*+R\@1&5F
M875L="!F;W(@:'1T<%]P<F]X>0T*:68@*&=E=&5N=B@G4$A07U!%05)?2%14
M4%]04D]862<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q4
M7TA45%!?4%)/6%DG+"!G971E;G8H)U!(4%]014%27TA45%!?4%)/6%DG*2D[
M#0I](&5L<V5I9B`H9V5T96YV*"=H='1P7W!R;WAY)RDI('L-"B`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?2%144%]04D]862<L(&=E=&5N=B@G
M:'1T<%]P<F]X>2<I*3L-"GT@96QS92![#0H@("`@9&5F:6YE*"=014%27T-/
M3D9)1U]$149!54Q47TA45%!?4%)/6%DG+"`G)RD[#0I]#0H-"B\O($1E9F%U
M;'0@9F]R('!H<%]D:7(-"FEF("AG971E;G8H)U!(4%]014%27TE.4U1!3$Q?
M1$E2)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A0
M7T1)4B<L(&=E=&5N=B@G4$A07U!%05)?24Y35$%,3%]$25(G*2D[#0I](&5L
M<V4@>PT*("`@(&EF("A`:7-?9&ER*"1014%27TE.4U1!3$Q?1$E2*2D@>PT*
M("`@("`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4$A07T1)4B<L
M#0H@("`@("`@("`@("`@("`D4$5!4E])3E-404Q,7T1)4BD[#0H@("`@?2!E
M;'-E('L-"B`@("`@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U!(
M4%]$25(G+"`D4$5!4E])3E-404Q,7T1)4BD[#0H@("`@?0T*?0T*#0HO+R!$
M969A=6QT(&9O<B!E>'1?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!4E]%6%1%
M3E-)3TY?1$E2)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%5
M3%1?15A47T1)4B<L(&=E=&5N=B@G4$A07U!%05)?15A414Y324].7T1)4B<I
M*3L-"GT@96QS92![#0H@("`@:68@*&EN:5]G970H)V5X=&5N<VEO;E]D:7(G
M*2D@>PT*("`@("`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?15A4
M7T1)4B<L(&EN:5]G970H)V5X=&5N<VEO;E]D:7(G*2D[#0H@("`@?2!E;'-E
M:68@*&1E9FEN960H)U!%05)?15A414Y324].7T1)4B<I("8F($!I<U]D:7(H
M4$5!4E]%6%1%3E-)3TY?1$E2*2D@>PT*("`@("`@("!D969I;F4H)U!%05)?
M0T].1DE'7T1%1D%53%1?15A47T1)4B<L(%!%05)?15A414Y324].7T1)4BD[
M#0H@("`@?2!E;'-E:68@*&1E9FEN960H)U!(4%]%6%1%3E-)3TY?1$E2)RDI
M('L-"B`@("`@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T585%]$
M25(G+"!02%!?15A414Y324].7T1)4BD[#0H@("`@?2!E;'-E('L-"B`@("`@
M("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T585%]$25(G+"`G+B<I
M.PT*("`@('T-"GT-"@T*+R\@1&5F875L="!F;W(@9&]C7V1I<@T*:68@*&=E
M=&5N=B@G4$A07U!%05)?1$]#7T1)4B<I*2![#0H@("`@9&5F:6YE*"=014%2
M7T-/3D9)1U]$149!54Q47T1/0U]$25(G+"!G971E;G8H)U!(4%]014%27T1/
M0U]$25(G*2D[#0I](&5L<V4@>PT*("`@(&1E9FEN92@G4$5!4E]#3TY&24=?
M1$5&055,5%]$3T-?1$E2)RP-"B`@("`@("`@("`@)%!%05)?24Y35$%,3%]$
M25(N1$E214-43U)97U-%4$%2051/4BXG9&]C<R<I.PT*?0T*#0HO+R!$969A
M=6QT(&9O<B!B:6Y?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!4E]"24Y?1$E2
M)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?0DE.7T1)
M4B<L(&=E=&5N=B@G4$A07U!%05)?0DE.7T1)4B<I*3L-"GT@96QS92![#0H@
M("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T))3E]$25(G+"!02%!?
M0DE.1$E2*3L-"GT-"@T*+R\@1&5F875L="!F;W(@9&%T85]D:7(-"FEF("AG
M971E;G8H)U!(4%]014%27T1!5$%?1$E2)RDI('L-"B`@("!D969I;F4H)U!%
M05)?0T].1DE'7T1%1D%53%1?1$%405]$25(G+"!G971E;G8H)U!(4%]014%2
M7T1!5$%?1$E2)RDI.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?1$%405]$25(G+`T*("`@("`@("`@("`D4$5!4E])3E-4
M04Q,7T1)4BY$25)%0U1/4EE?4T5005)!5$]2+B=D871A)RD[#0I]#0H-"B\O
M($1E9F%U;'0@9F]R('1E<W1?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!4E]4
M15-47T1)4B<I*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q4
M7U1%4U1?1$E2)RP@9V5T96YV*"=02%!?4$5!4E]415-47T1)4B<I*3L-"GT@
M96QS92![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U1%4U1?
M1$E2)RP-"B`@("`@("`@("`@)%!%05)?24Y35$%,3%]$25(N1$E214-43U)9
M7U-%4$%2051/4BXG=&5S=',G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@8V%C
M:&5?9&ER#0II9B`H9V5T96YV*"=02%!?4$5!4E]#04-(15]$25(G*2D@>PT*
M("`@(&1E9FEN92@G4$5!4E]#3TY&24=?1$5&055,5%]#04-(15]$25(G+"!G
M971E;G8H)U!(4%]014%27T-!0TA%7T1)4B<I*3L-"GT@96QS92![#0H@("`@
M9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T-!0TA%7T1)4B<L#0H@("`@
M("`@("`@(%-Y<W1E;3HZ=&UP9&ER*"D@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)W!E87(G("X-"B`@("`@("`@("`@1$E214-43U)97U-%4$%2051/4B`N
M("=C86-H92<I.PT*?0T*#0HO+R!$969A=6QT(&9O<B!P:'!?8FEN#0II9B`H
M9V5T96YV*"=02%!?4$5!4E]02%!?0DE.)RDI('L-"B`@("!D969I;F4H)U!%
M05)?0T].1DE'7T1%1D%53%1?4$A07T))3B<L(&=E=&5N=B@G4$A07U!%05)?
M4$A07T))3B<I*3L-"GT@96QS92![#0H@("`@9&5F:6YE*"=014%27T-/3D9)
M1U]$149!54Q47U!(4%]"24XG+"!014%27T-/3D9)1U]$149!54Q47T))3E]$
M25(N#0H@("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(N)W!H<"<N*$]3
M7U=)3D1/5U,@/R`G+F5X92<@.B`G)RDI.PT*?0T*#0HO+R!$969A=6QT(&9O
M<B!V97)B;W-E#0II9B`H9V5T96YV*"=02%!?4$5!4E]615)"3U-%)RDI('L-
M"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?5D520D]312<L(&=E
M=&5N=B@G4$A07U!%05)?5D520D]312<I*3L-"GT@96QS92![#0H@("`@9&5F
M:6YE*"=014%27T-/3D9)1U]$149!54Q47U9%4D)/4T4G+"`Q*3L-"GT-"@T*
M+R\@1&5F875L="!F;W(@<')E9F5R<F5D7W-T871E#0II9B`H9V5T96YV*"=0
M2%!?4$5!4E]04D5&15)2141?4U1!5$4G*2D@>PT*("`@(&1E9FEN92@G4$5!
M4E]#3TY&24=?1$5&055,5%]04D5&15)2141?4U1!5$4G+"!G971E;G8H)U!(
M4%]014%27U!2149%4E)%1%]35$%412<I*3L-"GT@96QS92![#0H@("`@9&5F
M:6YE*"=014%27T-/3D9)1U]$149!54Q47U!2149%4E)%1%]35$%412<L("=S
M=&%B;&4G*3L-"GT-"@T*+R\@1&5F875L="!F;W(@=6UA<VL-"FEF("AG971E
M;G8H)U!(4%]014%27U5-05-+)RDI('L-"B`@("!D969I;F4H)U!%05)?0T].
M1DE'7T1%1D%53%1?54U!4TLG+"!G971E;G8H)U!(4%]014%27U5-05-+)RDI
M.PT*?2!E;'-E('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?
M54U!4TLG+"!D96-O8W0H=6UA<VLH*2DI.PT*?0T*#0HO+R!$969A=6QT(&9O
M<B!C86-H95]T=&P-"FEF("AG971E;G8H)U!(4%]014%27T-!0TA%7U143"<I
M*2![#0H@("`@9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47T-!0TA%7U14
M3"<L(&=E=&5N=B@G4$A07U!%05)?0T%#2$5?5%1,)RDI.PT*?2!E;'-E('L-
M"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?0T%#2$5?5%1,)RP@
M,S8P,"D[#0I]#0H-"B\O($1E9F%U;'0@9F]R('-I9U]T>7!E#0II9B`H9V5T
M96YV*"=02%!?4$5!4E]324=?5%E012<I*2![#0H@("`@9&5F:6YE*"=014%2
M7T-/3D9)1U]$149!54Q47U-)1U]465!%)RP@9V5T96YV*"=02%!?4$5!4E]3
M24=?5%E012<I*3L-"GT@96QS92![#0H@("`@9&5F:6YE*"=014%27T-/3D9)
M1U]$149!54Q47U-)1U]465!%)RP@)V=P9R<I.PT*?0T*#0HO+R!$969A=6QT
M(&9O<B!S:6=?8FEN#0II9B`H9V5T96YV*"=02%!?4$5!4E]324=?0DE.)RDI
M('L-"B`@("!D969I;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7T))3B<L
M(&=E=&5N=B@G4$A07U!%05)?4TE'7T))3B<I*3L-"GT@96QS92![#0H@("`@
M9&5F:6YE*"=014%27T-/3D9)1U]$149!54Q47U-)1U]"24XG+`T*("`@("`@
M("`@("!3>7-T96TZ.G=H:6-H*`T*("`@("`@("`@("`@("`@)V=P9R<L($]3
M7U=)3D1/5U,@/R`G8SI<9VYU<&=<9W!G+F5X92<@.B`G+W5S<B]L;V-A;"]B
M:6XO9W!G)RDI.PT*?0T*#0HO+R!$969A=6QT(&9O<B!S:6=?:V5Y9&ER#0II
M9B`H9V5T96YV*"=02%!?4$5!4E]324=?2T591$E2)RDI('L-"B`@("!D969I
M;F4H)U!%05)?0T].1DE'7T1%1D%53%1?4TE'7TM%641)4B<L(&=E=&5N=B@G
M4$A07U!%05)?4TE'7TM%641)4B<I*3L-"GT@96QS92![#0H@("`@9&5F:6YE
M*"=014%27T-/3D9)1U]$149!54Q47U-)1U]+15E$25(G+`T*("`@("`@("`@
M("!014%27T-/3D9)1U]365-#3TY&1$E2("X@1$E214-43U)97U-%4$%2051/
M4B`N("=P96%R:V5Y<R<I.PT*?0T*#0HO*BH-"B`J(%1H:7,@:7,@82!C;&%S
M<R!F;W(@<W1O<FEN9R!C;VYF:6=U<F%T:6]N(&1A=&$L(&ME97!I;F<@=')A
M8VL@;V8-"B`J('=H:6-H(&%R92!S>7-T96TM9&5F:6YE9"P@=7-E<BUD969I
M;F5D(&]R(&1E9F%U;'1E9"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS
M<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?0V]N
M9FEG(&5X=&5N9',@4$5!4@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-
M"B`@("`O*BH-"B`@("`@*B!!<G)A>2!O9B!C;VYF:6<@9FEL97,@=7-E9"X-
M"B`@("`@*@T*("`@("`J($!V87(@87)R87D@;&%Y97(@/3X@8V]N9FEG(&9I
M;&4-"B`@("`@*B\-"B`@("!V87(@)&9I;&5S(#T@87)R87DH#0H@("`@("`@
M("=S>7-T96TG(#T^("<G+`T*("`@("`@("`G=7-E<B<@/3X@)R<L#0H@("`@
M("`@("D[#0H-"B`@("!V87(@)&QA>65R<R`](&%R<F%Y*"D[#0H@("`@#0H@
M("`@+RHJ#0H@("`@("H@0V]N9FEG=7)A=&EO;B!D871A+"!T=V\M9&EM96YS
M:6]N86P@87)R87D@=VAE<F4@=&AE(&9I<G-T#0H@("`@("H@9&EM96YS:6]N
M(&ES('1H92!C;VYF:6<@;&%Y97(@*"=U<V5R)RP@)W-Y<W1E;2<@86YD("=D
M969A=6QT)RDL#0H@("`@("H@86YD('1H92!S96-O;F0@9&EM96YS:6]N(&ES
M(&ME>6YA;64@/3X@=F%L=64N#0H@("`@("H-"B`@("`@*B!4:&4@;W)D97(@
M:6X@=&AE(&9I<G-T(&1I;65N<VEO;B!I<R!I;7!O<G1A;G0A("!%87)L:65R
M#0H@("`@("H@;&%Y97)S('=I;&P@<VAA9&]W(&QA=&5R(&]N97,@=VAE;B!A
M(&-O;F9I9R!V86QU92!I<PT*("`@("`J(')E<75E<W1E9"`H:68@82`G=7-E
M<B<@=F%L=64@97AI<W1S+"!I="!W:6QL(&)E(')E='5R;F5D(&9I<G-T+`T*
M("`@("`J('1H96X@)W-Y<W1E;2<@86YD(&9I;F%L;'D@)V1E9F%U;'0G*2X-
M"B`@("`@*@T*("`@("`J($!V87(@87)R87D@;&%Y97(@/3X@87)R87DH:V5Y
M;F%M92`]/B!V86QU92P@+BXN*0T*("`@("`J+PT*("`@('9A<B`D8V]N9FEG
M=7)A=&EO;B`](&%R<F%Y*`T*("`@("`@("`G=7-E<B<@/3X@87)R87DH*2P-
M"B`@("`@("`@)W-Y<W1E;2<@/3X@87)R87DH*2P-"B`@("`@("`@)V1E9F%U
M;'0G(#T^(&%R<F%Y*"DL#0H@("`@("`@("D[#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@0V]N9FEG=7)A=&EO;B!V86QU97,@=&AA="!C86X@8F4@<V5T(&9O
M<B!A(&-H86YN96P-"B`@("`@*@T*("`@("`J($%L;"!O=&AE<B!C;VYF:6=U
M<F%T:6]N('9A;'5E<R!C86X@;VYL>2!H879E(&$@9VQO8F%L('9A;'5E#0H@
M("`@("H@0'9A<B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J+PT*("`@('9A<B`D7V-H86YN96Q#;VYF:6=);F9O(#T@87)R87DH#0H@
M("`@("`@("=P:'!?9&ER)RP@)V5X=%]D:7(G+"`G9&]C7V1I<B<L("=B:6Y?
M9&ER)RP@)V1A=&%?9&ER)RP-"B`@("`@("`@)W1E<W1?9&ER)RP@)W!H<%]B
M:6XG+"`G=7-E<FYA;64G+"`G<&%S<W=O<F0G+"`G=F5R8F]S92<L#0H@("`@
M("`@("=P<F5F97)R961?<W1A=&4G+"`G=6UA<VLG+"`G<')E9F5R<F5D7VUI
M<G)O<B<L#0H@("`@("`@("D[#0H-"B`@("`O*BH-"B`@("`@*B!#:&%N;F5L
M<R!T:&%T(&-A;B!B92!A8V-E<W-E9`T*("`@("`J($!S964@<V5T0VAA;FYE
M;',H*0T*("`@("`J($!V87(@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!V87(@)%]C:&%N;F5L<R`](&%R<F%Y*"=P96%R
M+G!H<"YN970G+"`G<&5C;"YP:'`N;F5T)RP@)U]?=7)I)RD[#0H-"B`@("`O
M*BH-"B`@("`@*B!4:&ES('9A<FEA8FQE(&ES('5S960@=&\@8V]N=')O;"!T
M:&4@9&ER96-T;W)Y('9A;'5E<R!R971U<FYE9`T*("`@("`J($!S964@<V5T
M26YS=&%L;%)O;W0H*3L-"B`@("`@*B!`=F%R('-T<FEN9WQF86QS90T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VEN<W1A
M;&Q2;V]T(#T@9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@*B!)9B!R97%U97-T
M960L('1H:7,@=VEL;"!A;'=A>7,@<F5F97(@=&\@=&AE(')E9VES=')Y#0H@
M("`@("H@8V]N=&%I;F5D(&EN('!H<%]D:7(-"B`@("`@*B!`=F%R(%!%05)?
M4F5G:7-T<GD-"B`@("`@*B\-"B`@("!V87(@)%]R96=I<W1R>2`](&%R<F%Y
M*"D[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<F5G26YI=&EA;&EZ
M960@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B;V]L#0H@
M("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?;F]2
M96=I<W1R>2`](&9A;'-E.PT*#0H@("`@+RHJ#0H@("`@("H@86UO=6YT(&]F
M(&5R<F]R<R!F;W5N9"!W:&EL92!P87)S:6YG(&-O;F9I9PT*("`@("`J($!V
M87(@:6YT96=E<@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*
M("`@('9A<B`D7V5R<F]R<T9O=6YD(#T@,#L-"B`@("!V87(@)%]L87-T17)R
M;W(@/2!N=6QL.PT*#0H@("`@+RHJ#0H@("`@("H@26YF;W)M871I;VX@86)O
M=70@=&AE(&-O;F9I9W5R871I;VX@9&%T82X@(%-T;W)E<R!T:&4@='EP92P-
M"B`@("`@*B!D969A=6QT('9A;'5E(&%N9"!A(&1O8W5M96YT871I;VX@<W1R
M:6YG(&9O<B!E86-H(&-O;F9I9W5R871I;VX-"B`@("`@*B!V86QU92X-"B`@
M("`@*@T*("`@("`J($!V87(@87)R87D@;&%Y97(@/3X@87)R87DH:6YF;W1Y
M<&4@/3X@=F%L=64L("XN+BD-"B`@("`@*B\-"B`@("!V87(@)&-O;F9I9W5R
M871I;VY?:6YF;R`](&%R<F%Y*`T*("`@("`@("`O+R!#:&%N;F5L<R]);G1E
M<FYE="!!8V-E<W,-"B`@("`@("`@)V1E9F%U;'1?8VAA;FYE;"<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-T<FEN9R<L#0H@("`@("`@
M("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]#2$%.3D5,
M+`T*("`@("`@("`@("`@)V1O8R<@/3X@)W1H92!D969A=6QT(&-H86YN96P@
M=&\@=7-E(&9O<B!A;&P@;F]N(&5X<&QI8VET(&-O;6UA;F1S)RP-"B`@("`@
M("`@("`@("=P<F]M<'0G(#T^("=$969A=6QT($-H86YN96PG+`T*("`@("`@
M("`@("`@)V=R;W5P)R`]/B`G26YT97)N970@06-C97-S)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=P<F5F97)R961?;6ER<F]R)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R:6YG)RP-"B`@("`@("`@("`@
M("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T-(04Y.14PL#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G=&AE(&1E9F%U;'0@<V5R=F5R(&]R(&UI
M<G)O<B!T;R!U<V4@9F]R(&-H86YN96P@86-T:6]N<R<L#0H@("`@("`@("`@
M("`G<')O;7!T)R`]/B`G1&5F875L="!#:&%N;F5L($UI<G)O<B<L#0H@("`@
M("`@("`@("`G9W)O=7`G(#T^("=);G1E<FYE="!!8V-E<W,G+`T*("`@("`@
M("`@("`@*2P-"B`@("`@("`@)W)E;6]T95]C;VYF:6<G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=P87-S=V]R9"<L#0H@("`@("`@("`@
M("`G9&5F875L="<@/3X@)R<L#0H@("`@("`@("`@("`G9&]C)R`]/B`G9G1P
M('5R;"!O9B!R96UO=&4@8V]N9FEG=7)A=&EO;B!F:6QE('1O('5S92!F;W(@
M<WEN8VAR;VYI>F5D(&EN<W1A;&PG+`T*("`@("`@("`@("`@)W!R;VUP="<@
M/3X@)U)E;6]T92!#;VYF:6=U<F%T:6]N($9I;&4G+`T*("`@("`@("`@("`@
M)V=R;W5P)R`]/B`G26YT97)N970@06-C97-S)RP-"B`@("`@("`@("`@("DL
M#0H@("`@("`@("=A=71O7V1I<V-O=F5R)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("=T>7!E)R`]/B`G:6YT96=E<B<L#0H@("`@("`@("`@("`G9&5F875L
M="<@/3X@,"P-"B`@("`@("`@("`@("=D;V,G(#T^("=W:&5T:&5R('1O(&%U
M=&]M871I8V%L;'D@9&ES8V]V97(@;F5W(&-H86YN96QS)RP-"B`@("`@("`@
M("`@("=P<F]M<'0G(#T^("=!=71O+61I<V-O=F5R(&YE=R!#:&%N;F5L<R<L
M#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=);G1E<FYE="!!8V-E<W,G+`T*
M("`@("`@("`@("`@*2P-"B`@("`@("`@+R\@26YT97)N970@06-C97-S#0H@
M("`@("`@("=M87-T97)?<V5R=F5R)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=T>7!E)R`]/B`G<W1R:6YG)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]
M/B`G<&5A<BYP:'`N;F5T)RP-"B`@("`@("`@("`@("=D;V,G(#T^("=N86UE
M(&]F('1H92!M86EN(%!%05(@<V5R=F5R(%M.3U0@55-%1"!)3B!42$E3(%9%
M4E-)3TY=)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=014%2('-E<G9E
M<B!;1$504D5#051%1%TG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G26YT
M97)N970@06-C97-S)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=H='1P
M7W!R;WAY)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G<W1R
M:6YG)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$
M149!54Q47TA45%!?4%)/6%DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G2%14
M4"!P<F]X>2`H:&]S=#IP;W)T*2!T;R!U<V4@=VAE;B!D;W=N;&]A9&EN9R!P
M86-K86=E<R<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G2%144"!0<F]X
M>2!397)V97(@061D<F5S<R<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=)
M;G1E<FYE="!!8V-E<W,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@+R\@
M1FEL92!,;V-A=&EO;G,-"B`@("`@("`@)W!H<%]D:7(G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*("`@("`@("`@
M("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?4$A07T1)4BP-
M"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O<GD@=VAE<F4@+G!H<"!F
M:6QE<R!A<F4@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^
M("=014%2(&1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9W)O=7`G(#T^("=&
M:6QE($QO8V%T:6]N<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G97AT
M7V1I<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)V1I<F5C
M=&]R>2<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?
M1$5&055,5%]%6%1?1$E2+`T*("`@("`@("`@("`@)V1O8R<@/3X@)V1I<F5C
M=&]R>2!W:&5R92!L;V%D86)L92!E>'1E;G-I;VYS(&%R92!I;G-T86QL960G
M+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!(4"!E>'1E;G-I;VX@9&ER
M96-T;W)Y)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T9I;&4@3&]C871I
M;VYS)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=D;V-?9&ER)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@
M("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T1/
M0U]$25(L#0H@("`@("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E
M(&1O8W5M96YT871I;VX@:7,@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@("=P
M<F]M<'0G(#T^("=014%2(&1O8W5M96YT871I;VX@9&ER96-T;W)Y)RP-"B`@
M("`@("`@("`@("=G<F]U<"<@/3X@)T9I;&4@3&]C871I;VYS)RP-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("=B:6Y?9&ER)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y)RP-"B`@("`@("`@("`@("=D
M969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T))3E]$25(L#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G9&ER96-T;W)Y('=H97)E(&5X96-U=&%B;&5S
M(&%R92!I;G-T86QL960G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%
M05(@97AE8W5T86)L97,@9&ER96-T;W)Y)RP-"B`@("`@("`@("`@("=G<F]U
M<"<@/3X@)T9I;&4@3&]C871I;VYS)RP-"B`@("`@("`@("`@("DL#0H@("`@
M("`@("=D871A7V1I<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@
M/3X@)V1I<F5C=&]R>2<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@4$5!
M4E]#3TY&24=?1$5&055,5%]$051!7T1)4BP-"B`@("`@("`@("`@("=D;V,G
M(#T^("=D:7)E8W1O<GD@=VAE<F4@9&%T82!F:6QE<R!A<F4@:6YS=&%L;&5D
M)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=014%2(&1A=&$@9&ER96-T
M;W)Y)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T9I;&4@3&]C871I;VYS
M("A!9'9A;F-E9"DG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W1E<W1?
M9&ER)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&ER96-T
M;W)Y)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$
M149!54Q47U1%4U1?1$E2+`T*("`@("`@("`@("`@)V1O8R<@/3X@)V1I<F5C
M=&]R>2!W:&5R92!R96=R97-S:6]N('1E<W1S(&%R92!I;G-T86QL960G+`T*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!%05(@=&5S="!D:7)E8W1O<GDG
M+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,@*$%D
M=F%N8V5D*2<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8V%C:&5?9&ER
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]/B`G9&ER96-T;W)Y
M)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$149!
M54Q47T-!0TA%7T1)4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O
M<GD@=VAI8V@@:7,@=7-E9"!F;W(@6$U,4E!#(&-A8VAE)RP-"B`@("`@("`@
M("`@("=P<F]M<'0G(#T^("=014%2($EN<W1A;&QE<B!C86-H92!D:7)E8W1O
M<GDG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,@
M*$%D=F%N8V5D*2<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<&AP7V)I
M;B<@/3X@87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)V9I;&4G+`T*
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?
M4$A07T))3BP-"B`@("`@("`@("`@("=D;V,G(#T^("=02%`@0TQ)+T-'22!B
M:6YA<GD@9F]R(&5X96-U=&EN9R!S8W)I<'1S)RP-"B`@("`@("`@("`@("=P
M<F]M<'0G(#T^("=02%`@0TQ)+T-'22!B:6YA<GDG+`T*("`@("`@("`@("`@
M)V=R;W5P)R`]/B`G1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<L#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`O+R!-86EN=&%I;F5R<PT*("`@("`@("`G
M=7-E<FYA;64G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=S
M=')I;F<G+`T*("`@("`@("`@("`@)V1E9F%U;'0G(#T^("<G+`T*("`@("`@
M("`@("`@)V1O8R<@/3X@)RAM86EN=&%I;F5R<RD@>6]U<B!014%2(&%C8V]U
M;G0@;F%M92<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!4B!U<V5R
M;F%M92`H9F]R(&UA:6YT86EN97)S*2<L#0H@("`@("`@("`@("`G9W)O=7`G
M(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G
M<&%S<W=O<F0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=P
M87-S=V]R9"<L#0H@("`@("`@("`@("`G9&5F875L="<@/3X@)R<L#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G*&UA:6YT86EN97)S*2!Y;W5R(%!%05(@86-C
M;W5N="!P87-S=V]R9"<L#0H@("`@("`@("`@("`G<')O;7!T)R`]/B`G4$5!
M4B!P87-S=V]R9"`H9F]R(&UA:6YT86EN97)S*2<L#0H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`O+R!!9'9A;F-E9`T*("`@("`@("`G=F5R8F]S92<@/3X@87)R87DH
M#0H@("`@("`@("`@("`G='EP92<@/3X@)VEN=&5G97(G+`T*("`@("`@("`@
M("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?5D520D]312P-
M"B`@("`@("`@("`@("=D;V,G(#T^("=V97)B;W-I='D@;&5V96P-"C`Z(')E
M86QL>2!Q=6EE=`T*,3H@<V]M97=H870@<75I970-"C(Z('9E<F)O<V4-"C,Z
M(&1E8G5G)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=$96)U9R!,;V<@
M3&5V96PG+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G061V86YC960G+`T*
M("`@("`@("`@("`@*2P-"B`@("`@("`@)W!R969E<G)E9%]S=&%T92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`G='EP92<@/3X@)W-E="<L#0H@("`@("`@
M("`@("`G9&5F875L="<@/3X@4$5!4E]#3TY&24=?1$5&055,5%]04D5&15)2
M141?4U1!5$4L#0H@("`@("`@("`@("`G9&]C)R`]/B`G=&AE(&EN<W1A;&QE
M<B!W:6QL('!R969E<B!R96QE87-E<R!W:71H('1H:7,@<W1A=&4@=VAE;B!I
M;G-T86QL:6YG('!A8VMA9V5S('=I=&AO=70@82!V97)S:6]N(&]R('-T871E
M('-P96-I9FEE9"<L#0H@("`@("`@("`@("`G=F%L:61?<V5T)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`G<W1A8FQE)RP@)V)E=&$G+"`G86QP:&$G
M+"`G9&5V96PG+"`G<VYA<'-H;W0G*2P-"B`@("`@("`@("`@("=P<F]M<'0G
M(#T^("=0<F5F97)R960@4&%C:V%G92!3=&%T92<L#0H@("`@("`@("`@("`G
M9W)O=7`G(#T^("=!9'9A;F-E9"<L#0H@("`@("`@("`@("`I+`T*("`@("`@
M("`G=6UA<VLG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=M
M87-K)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%27T-/3D9)1U]$
M149!54Q47U5-05-++`T*("`@("`@("`@("`@)V1O8R<@/3X@)W5M87-K('5S
M960@=VAE;B!C<F5A=&EN9R!F:6QE<R`H56YI>"UL:6ME('-Y<W1E;7,@;VYL
M>2DG+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U5N:7@@9FEL92!M87-K
M)RP-"B`@("`@("`@("`@("=G<F]U<"<@/3X@)T%D=F%N8V5D)RP-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("=C86-H95]T=&PG(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W1Y<&4G(#T^("=I;G1E9V5R)RP-"B`@("`@("`@("`@("=D
M969A=6QT)R`]/B!014%27T-/3D9)1U]$149!54Q47T-!0TA%7U143"P-"B`@
M("`@("`@("`@("=D;V,G(#T^("=A;6]U;G0@;V8@<V5C<R!W:&5R92!T:&4@
M;&]C86P@8V%C:&4@:7,@=7-E9"!A;F0@;F]T('5P9&%T960G+`T*("`@("`@
M("`@("`@)W!R;VUP="<@/3X@)T-A8VAE(%1I;654;TQI=F4G+`T*("`@("`@
M("`@("`@)V=R;W5P)R`]/B`G061V86YC960G+`T*("`@("`@("`@("`@*2P-
M"B`@("`@("`@)W-I9U]T>7!E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T
M>7!E)R`]/B`G<V5T)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B!014%2
M7T-/3D9)1U]$149!54Q47U-)1U]465!%+`T*("`@("`@("`@("`@)V1O8R<@
M/3X@)W=H:6-H('!A8VMA9V4@<VEG;F%T=7)E(&UE8VAA;FES;2!T;R!U<V4G
M+`T*("`@("`@("`@("`@)W9A;&ED7W-E="<@/3X@87)R87DH)V=P9R<I+`T*
M("`@("`@("`@("`@)W!R;VUP="<@/3X@)U!A8VMA9V4@4VEG;F%T=7)E(%1Y
M<&4G+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I;G1A:6YE<G,G+`T*
M("`@("`@("`@("`@*2P-"B`@("`@("`@)W-I9U]B:6XG(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W1Y<&4G(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@
M)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?4TE'7T))3BP-"B`@
M("`@("`@("`@("=D;V,G(#T^("=W:&EC:"!P86-K86=E('-I9VYA='5R92!M
M96-H86YI<VT@=&\@=7-E)RP-"B`@("`@("`@("`@("=P<F]M<'0G(#T^("=3
M:6=N871U<F4@2&%N9&QI;F<@4')O9W)A;2<L#0H@("`@("`@("`@("`G9W)O
M=7`G(#T^("=-86EN=&%I;F5R<R<L#0H@("`@("`@("`@("`I+`T*("`@("`@
M("`G<VEG7VME>6ED)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=T>7!E)R`]
M/B`G<W1R:6YG)RP-"B`@("`@("`@("`@("=D969A=6QT)R`]/B`G)RP-"B`@
M("`@("`@("`@("=D;V,G(#T^("=W:&EC:"!K97D@=&\@=7-E(&9O<B!S:6=N
M:6YG('=I=&@G+`T*("`@("`@("`@("`@)W!R;VUP="<@/3X@)U-I9VYA='5R
M92!+97D@260G+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`G36%I;G1A:6YE
M<G,G+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)W-I9U]K97ED:7(G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@)W1Y<&4G(#T^("=D:7)E8W1O<GDG+`T*
M("`@("`@("`@("`@)V1E9F%U;'0G(#T^(%!%05)?0T].1DE'7T1%1D%53%1?
M4TE'7TM%641)4BP-"B`@("`@("`@("`@("=D;V,G(#T^("=D:7)E8W1O<GD@
M=VAE<F4@<VEG;F%T=7)E(&ME>7,@87)E(&QO8V%T960G+`T*("`@("`@("`@
M("`@)W!R;VUP="<@/3X@)U-I9VYA='5R92!+97D@1&ER96-T;W)Y)RP-"B`@
M("`@("`@("`@("=G<F]U<"<@/3X@)TUA:6YT86EN97)S)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("\O(%]?8VAA;FYE;',@:7,@<F5S97)V960@+2!U
M<V5D(&9O<B!C:&%N;F5L+7-P96-I9FEC(&-O;F9I9W5R871I;VX-"B`@("`@
M("`@*3L-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%!%05)?0V]N9FEG
M*%MF:6QE72P@6V1E9F%U;'1S7V9I;&5=*0T*#0H@("`@+RHJ#0H@("`@("H@
M0V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I
M;&4@=&\@<F5A9"!U<V5R+61E9FEN960@;W!T:6]N<R!F<F]M#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!F:6QE('1O(')E860@<WES=&5M+7=I9&4@9&5F875L
M=',@9G)O;0T*("`@("`J($!P87)A;2!B;V]L("`@9&5T97)M:6YE<R!W:&5T
M:&5R(&$@<F5G:7-T<GD@;V)J96-T(")F;VQL;W=S(@T*("`@("`J("`@("`@
M("`@("`@("`@=&AE('9A;'5E(&]F('!H<%]D:7(@*&ES(&%U=&]M871I8V%L
M;'D@8W)E871E9`T*("`@("`J("`@("`@("`@("`@("`@86YD(&UO=F5D('=H
M96X@<&AP7V1I<B!I<R!C:&%N9V5D*0T*("`@("`J($!P87)A;2!B;V]L("`@
M:68@=')U92P@9F%I;',@:68@8V]N9FEG=7)A=&EO;B!F:6QE<R!C86YN;W0@
M8F4@;&]A9&5D#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J#0H@("`@("H@0'-E92!014%27T-O;F9I9SHZ<VEN9VQE=&]N#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@4$5!4E]#;VYF:6<H)'5S97)?9FEL92`]("<G
M+"`D<WES=&5M7V9I;&4@/2`G)RP@)&9T<%]F:6QE(#T@9F%L<V4L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T<FEC="`]('1R=64I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^4$5!4B@I.PT*("`@("`@("!014%27TEN<W1A;&QE
M<E]2;VQE.CII;FET:6%L:7IE0V]N9FEG*"1T:&ES*3L-"B`@("`@("`@)'-L
M(#T@1$E214-43U)97U-%4$%2051/4CL-"B`@("`@("`@:68@*&5M<'1Y*"1U
M<V5R7V9I;&4I*2![#0H@("`@("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PT*
M("`@("`@("`@("`@("`@("1U<V5R7V9I;&4@/2!014%27T-/3D9)1U]365-#
M3TY&1$E2("X@)'-L("X@)W!E87(N:6YI)SL-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@)'5S97)?9FEL92`](&=E=&5N=B@G2$]-
M12<I("X@)'-L("X@)RYP96%R<F,G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AE;7!T>2@D<WES=&5M7V9I;&4I*2![#0H@("`@
M("`@("`@("!I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@("`@("1S
M>7-T96U?9FEL92`](%!%05)?0T].1DE'7U-94T-/3D9$25(@+B`D<VP@+B`G
M<&5A<G-Y<RYI;FDG.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D<WES=&5M7V9I;&4@/2!014%27T-/3D9)1U]365-#3TY&1$E2
M("X@)'-L("X@)W!E87(N8V]N9B<[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"@T*("`@("`@("`D=&AI<RT^;&%Y97)S(#T@87)R87E?:V5Y<R@D=&AI
M<RT^8V]N9FEG=7)A=&EO;BD[#0H@("`@("`@("1T:&ES+3YF:6QE<ULG=7-E
M<B==(#T@)'5S97)?9FEL93L-"B`@("`@("`@)'1H:7,M/F9I;&5S6R=S>7-T
M96TG72`]("1S>7-T96U?9FEL93L-"B`@("`@("`@:68@*"1U<V5R7V9I;&4@
M)B8@0&9I;&5?97AI<W1S*"1U<V5R7V9I;&4I*2![#0H@("`@("`@("`@("`D
M=&AI<RT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*
M("`@("`@("`@("`@)'1H:7,M/G)E861#;VYF:6=&:6QE*"1U<V5R7V9I;&4L
M("=U<V5R)RP@)'-T<FEC="D[#0H@("`@("`@("`@("`D=&AI<RT^<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?97)R;W)S
M1F]U;F0@/B`P*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1S>7-T96U?9FEL
M92`F)B!`9FEL95]E>&ES=',H)'-Y<W1E;5]F:6QE*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/FUE<F=E0V]N9FEG1FEL92@D<WES=&5M7V9I;&4L(&9A;'-E
M+"`G<WES=&5M)RP@)'-T<FEC="D[#0H@("`@("`@("`@("!I9B`H)'1H:7,M
M/E]E<G)O<G-&;W5N9"`^(#`I('L-"B`@("`@("`@("`@("`@("!R971U<FX[
M#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@A
M)&9T<%]F:6QE*2![#0H@("`@("`@("`@("`D9G1P7V9I;&4@/2`D=&AI<RT^
M9V5T*"=R96UO=&5?8V]N9FEG)RD[#0H@("`@("`@('T-"@T*("`@("`@("!I
M9B`H)&9T<%]F:6QE("8F(&1E9FEN960H)U!%05)?4D5-3U1%24Y35$%,3%]/
M2R<I*2![#0H@("`@("`@("`@("`D=&AI<RT^<F5A9$944$-O;F9I9T9I;&4H
M)&9T<%]F:6QE*3L-"B`@("`@("`@?0T*#0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F\@87,@)&ME>2`]/B`D:6YF;RD@>PT*
M("`@("`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY;)V1E9F%U;'0G75LD
M:V5Y72`]("1I;F9O6R=D969A=6QT)UT[#0H@("`@("`@('T-"@T*("`@("`@
M("`D=&AI<RT^7W)E9VES=')Y6R=D969A=6QT)UT@/2`F;F5W(%!%05)?4F5G
M:7-T<GDH)'1H:7,M/F-O;F9I9W5R871I;VY;)V1E9F%U;'0G75LG<&AP7V1I
M<B==*3L-"B`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LG9&5F875L="==+3YS
M971#;VYF:6<H)'1H:7,I.PT*("`@("`@("`D=&AI<RT^7W)E9TEN:71I86QI
M>F5D6R=D969A=6QT)UT@/2!F86QS93L-"B`@("`@("`@+R\D1TQ/0D%,4ULG
M7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT@/2`F)'1H:7,[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[('-I;F=L971O;BA;9FEL95TL(%MD969A
M=6QT<U]F:6QE72D-"@T*("`@("\J*@T*("`@("`J(%-T871I8R!S:6YG;&5T
M;VX@;65T:&]D+B`@268@>6]U('=A;G0@=&\@:V5E<"!O;FQY(&]N92!I;G-T
M86YC90T*("`@("`J(&]F('1H:7,@8VQA<W,@:6X@=7-E+"!T:&ES(&UE=&AO
M9"!W:6QL(&=I=F4@>6]U(&$@<F5F97)E;F-E('1O#0H@("`@("H@=&AE(&QA
M<W0@8W)E871E9"!014%27T-O;F9I9R!O8FIE8W0@:68@;VYE(&5X:7-T<RP@
M;W(@8W)E871E(&$-"B`@("`@*B!N97<@;V)J96-T+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`H;W!T:6]N86PI(&9I;&4@=&\@<F5A9"!U<V5R
M+61E9FEN960@;W!T:6]N<R!F<F]M#0H@("`@("H@0'!A<F%M('-T<FEN9R`H
M;W!T:6]N86PI(&9I;&4@=&\@<F5A9"!S>7-T96TM=VED92!D969A=6QT<R!F
M<F]M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&]B:F5C="!A;B!E>&ES=&EN
M9R!O<B!N97<@4$5!4E]#;VYF:6<@:6YS=&%N8V4-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B!`<V5E(%!%05)?0V]N
M9FEG.CI014%27T-O;F9I9PT*("`@("`J+PT*("`@(&9U;F-T:6]N("9S:6YG
M;&5T;VXH)'5S97)?9FEL92`]("<G+"`D<WES=&5M7V9I;&4@/2`G)RP@)'-T
M<FEC="`]('1R=64I#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1'
M3$]"04Q36R=?4$5!4E]#;VYF:6=?:6YS=&%N8V4G72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT[
M#0H@("`@("`@('T-"@T*("`@("`@("`D=%]C;VYF(#T@)FYE=R!014%27T-O
M;F9I9R@D=7-E<E]F:6QE+"`D<WES=&5M7V9I;&4L(&9A;'-E+"`D<W1R:6-T
M*3L-"B`@("`@("`@:68@*"1T7V-O;F8M/E]E<G)O<G-&;W5N9"`^(#`I('L-
M"B`@("`@("`@("`@("!R971U<FX@)'1?8V]N9BT^;&%S=$5R<F]R.PT*("`@
M("`@("!]#0H-"B`@("`@("`@)$=,3T)!3%-;)U]014%27T-O;F9I9U]I;G-T
M86YC92==(#T@)B1T7V-O;F8[#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG
M7U!%05)?0V]N9FEG7VEN<W1A;F-E)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[('9A;&ED0V]N9FEG=7)A=&EO;B@I#0H-"B`@("`O*BH-
M"B`@("`@*B!$971E<FUI;F4@=VAE=&AE<B!A;GD@8V]N9FEG=7)A=&EO;B!F
M:6QE<R!H879E(&)E96X@9&5T96-T960L(&%N9"!W:&5T:&5R(&$-"B`@("`@
M*B!R96=I<W1R>2!O8FIE8W0@8V%N(&)E(')E=')I979E9"!F<F]M('1H:7,@
M8V]N9FEG=7)A=&EO;BX-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B!`
M<VEN8V4@4$5!4B`Q+C0N,&$Q#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L
M:61#;VYF:6=U<F%T:6]N*"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^
M:7-$969I;F5D3&%Y97(H)W5S97(G*2!\?"`D=&AI<RT^:7-$969I;F5D3&%Y
M97(H)W-Y<W1E;2<I*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(')E861#;VYF:6=&:6QE*%MF:6QE72P@6VQA
M>65R72D-"@T*("`@("\J*@T*("`@("`J(%)E861S(&-O;F9I9W5R871I;VX@
M9&%T82!F<F]M(&$@9FEL92X@($%L;"!E>&ES=&EN9R!V86QU97,@:6X-"B`@
M("`@*B!T:&4@8V]N9FEG(&QA>65R(&%R92!D:7-C87)D960@86YD(')E<&QA
M8V5D('=I=&@@9&%T82!F<F]M('1H90T*("`@("`J(&9I;&4N#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!F:6QE('1O(')E860@9G)O;2P@:68@3E5,3"!O<B!N
M;W0@<W!E8VEF:65D+"!T:&4-"B`@("`@*B`@("`@("`@("`@("`@(&QA<W0M
M=7-E9"!F:6QE(&9O<B!T:&4@<V%M92!L87EE<B`H<V5C;VYD('!A<F%M*2!I
M<R!U<V5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@;&%Y97(@=&\@
M:6YS97)T(&1A=&$@:6YT;R`H)W5S97(G(&]R("=S>7-T96TG*0T*("`@("`J
M($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,@;W(@82!014%2(&5R<F]R
M(&]N(&9A:6QU<F4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96%D0V]N9FEG
M1FEL92@D9FEL92`](&YU;&PL("1L87EE<B`]("=U<V5R)RP@)'-T<FEC="`]
M('1R=64I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M/F9I;&5S
M6R1L87EE<ETI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(G5N:VYO=VX@8V]N9FEG(&QA>65R(&`D;&%Y97(G(BD[#0H@("`@
M("`@('T-"@T*("`@("`@("!I9B`H)&9I;&4@/3T](&YU;&PI('L-"B`@("`@
M("`@("`@("1F:6QE(#T@)'1H:7,M/F9I;&5S6R1L87EE<ET[#0H@("`@("`@
M('T-"@T*("`@("`@("`D9&%T82`]("1T:&ES+3Y?<F5A9$-O;F9I9T1A=&%&
M<F]M*"1F:6QE*3L-"@T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D9&%T
M82DI('L-"B`@("`@("`@("`@(&EF("@D<W1R:6-T*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E<G)O<G-&;W5N9"LK.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3YL87-T17)R;W(@/2`D9&%T83L-"@T*("`@("`@("`@("`@("`@
M(')E='5R;B`D9&%T83L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^9FEL97-;)&QA>65R72`]
M("1F:6QE.PT*("`@("`@("!]#0H-"B`@("`@("`@)'1H:7,M/E]D96-O9&5)
M;G!U="@D9&%T82D[#0H@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L
M87EE<ET@/2`D9&%T83L-"B`@("`@("`@)'1H:7,M/E]S971U<$-H86YN96QS
M*"D[#0H@("`@("`@(&EF("@A)'1H:7,M/E]N;U)E9VES=')Y("8F("@D<&AP
M9&ER(#T@)'1H:7,M/F=E="@G<&AP7V1I<B<L("1L87EE<BP@)W!E87(N<&AP
M+FYE="<I*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y
M97)=(#T@)FYE=R!014%27U)E9VES=')Y*"1P:'!D:7(I.PT*("`@("`@("`@
M("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=+3YS971#;VYF:6<H)'1H:7,I
M.PT*("`@("`@("`@("`@)'1H:7,M/E]R96=);FET:6%L:7IE9%LD;&%Y97)=
M(#T@9F%L<V4[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!U;G-E
M="@D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETI.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!U<FP@=&\@=&AE(')E;6]T92!C
M;VYF:6<@9FEL92P@;&EK92!F='`Z+R]W=W<N97AA;7!L92YC;VTO<&5A<B]C
M;VYF:6<N:6YI#0H@("`@("H@0')E='5R;B!T<G5E?%!%05)?17)R;W(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!R96%D1E100V]N9FEG1FEL92@D<&%T:"D-
M"B`@("![#0H@("`@("`@(&1O('L@+R\@<&]O<B!M86XG<R!T<GD-"B`@("`@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=.971?1E10)RDI('L-"B`@("`@
M("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#;VUM;VXG*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6]N+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("A014%27T-O;6UO;CHZ:7-);F-L=61E86)L92@G3F5T+T944"YP:'`G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@)TYE="]&
M5%`N<&AP)SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"=.971?1E10)RD@)B8-"B`@
M("`@("`@("`@("`@("`@("AC;&%S<U]E>&ES=',H)U!%05)?1E10)RD@?'P@
M4$5!4E]#;VUM;VXZ.FES26YC;'5D96%B;&4H)U!%05(O1E10+G!H<"<I*2D@
M>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]&5%`N<&AP
M)SL-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9T<"`]("9N97<@4$5!4E]&
M5%`[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F='`M/G!U<VA%<G)O<DAA
M;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`D
M92`]("1T:&ES+3Y?9G1P+3YI;FET*"1P871H*3L-"B`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]F='`M/G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D=&UP(#T@4WES=&5M.CIM:W1E;7`H)RUD)RD[#0H@
M("`@("`@("`@("`@("`@4$5!4E]#;VUM;VXZ.F%D9%1E;7!&:6QE*"1T;7`I
M.PT*("`@("`@("`@("`@("`@("1E(#T@)'1H:7,M/E]F='`M/F=E="AB87-E
M;F%M92@D<&%T:"DL("1T;7`@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@
M("`@("`@("`@("`@("`@("`@)W!E87(N:6YI)RP@9F%L<V4L($944%]"24Y!
M4EDI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V9T<"T^<&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&4[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(%!%05)?0V]M;6]N
M.CIA9&1496UP1FEL92@D=&UP("X@1$E214-43U)97U-%4$%2051/4B`N("=P
M96%R+FEN:2<I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9G1P+3YD:7-C
M;VYN96-T*"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F='`M/G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^9FEL97-;
M)V9T<"==(#T@)'1M<"`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&5A<BYI
M;FDG.PT*("`@("`@("`@("`@("`@("1E(#T@)'1H:7,M/G)E861#;VYF:6=&
M:6QE*&YU;&PL("=F='`G*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D9F%I;"`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/F-O
M;F9I9W5R871I;VY?:6YF;R!A<R`D:V5Y(#T^("1V86PI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG971'<F]U<"@D:V5Y
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)T9I;&4@3&]C
M871I;VYS)RP@)T9I;&4@3&]C871I;VYS("A!9'9A;F-E9"DG*2D@)B8-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%1Y<&4H)&ME>2D@
M/3T@)V1I<F5C=&]R>2<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&%N>2!D:7)E8W1O<GD@8V]N9FEG<R!M=7-T(&)E('-E="!F;W(@=&AI<R!T
M;R!W;W)K#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3YC;VYF:6=U<F%T:6]N6R=F='`G75LD:V5Y72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F%I;%M=(#T@)&ME>3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)&9A
M:6PI*2![#0H@("`@("`@("`@("`@("`@("`@("1F86EL(#T@)R(G("X@:6UP
M;&]D92@G(BP@(B<L("1F86EL*2`N("<B)SL-"B`@("`@("`@("`@("`@("`@
M("`@=6YS970H)'1H:7,M/F9I;&5S6R=F='`G72D[#0H@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R=F='`G72D[#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=%
M4E)/4CH@1G1P(&-O;F9I9W5R871I;VX@9FEL92!M=7-T('-E="!A;&P@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`G9&ER96-T;W)Y(&-O;F9I9W5R
M871I;VX@=F%R:6%B;&5S+B`@5&AE<V4@=F%R:6%B;&5S('=E<F4@;F]T('-E
M=#H@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D9F%I;"D[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@G3F5T7T944"!M=7-T(&)E(&EN<W1A;&QE9"!T;R!U<V4@<F5M;W1E(&-O
M;F9I9R<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]('=H:6QE("AF86QS
M92D[("\O('!O;W(@;6%N)W,@8V%T8V@-"B`@("`@("`@=6YS970H)'1H:7,M
M/F9I;&5S6R=F='`G72D[#0H@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=N;R!R96UO=&4@:&]S="!S<&5C:69I960G*3L-"B`@("!]#0H-"B`@
M("`O+R![>WL@7W-E='5P0VAA;FYE;',H*0T*("`@(`T*("`@("\J*@T*("`@
M("`J(%)E861S('1H92!E>&ES=&EN9R!C;VYF:6=U<F%T:6]N<R!A;F0@8W)E
M871E<R!T:&4@7V-H86YN96QS(&%R<F%Y(&9R;VT@:70-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?<V5T=7!#:&%N;F5L<R@I#0H@("`@>PT*("`@("`@("`D
M<V5T(#T@87)R87E?9FQI<"AA<G)A>5]V86QU97,H)'1H:7,M/E]C:&%N;F5L
M<RDI.PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG=7)A=&EO;B!A
M<R`D;&%Y97(@/3X@)&1A=&$I('L-"B`@("`@("`@("`@("1I(#T@,3`P,#L-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG7U]C:&%N;F5L<R==*2D@
M>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=?7V-H86YN96QS
M)UT@87,@)&-H86YN96P@/3X@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'-E=%LD8VAA;FYE;%T@/2`D:2LK.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-H
M86YN96QS(#T@87)R87E?=F%L=65S*&%R<F%Y7V9L:7`H)'-E="DI.PT*("`@
M("`@("`D=&AI<RT^<V5T0VAA;FYE;',H)'1H:7,M/E]C:&%N;F5L<RD[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1E;&5T94-H86YN96PH
M8VAA;FYE;"D-"@T*("`@(&9U;F-T:6]N(&1E;&5T94-H86YN96PH)&-H86YN
M96PI#0H@("`@>PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG=7)A
M=&EO;B!A<R`D;&%Y97(@/3X@)&1A=&$I('L-"B`@("`@("`@("`@(&EF("AI
M<W-E="@D9&%T85LG7U]C:&%N;F5L<R==*2D@>PT*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D9&%T85LG7U]C:&%N;F5L<R==6W-T<G1O;&]W97(H)&-H
M86YN96PI72DI('L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M
M/F-O;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==6W-T<G1O;&]W
M97(H)&-H86YN96PI72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?8VAA;FYE;',@/2!A
M<G)A>5]F;&EP*"1T:&ES+3Y?8VAA;FYE;',I.PT*("`@("`@("!U;G-E="@D
M=&AI<RT^7V-H86YN96QS6W-T<G1O;&]W97(H)&-H86YN96PI72D[#0H@("`@
M("`@("1T:&ES+3Y?8VAA;FYE;',@/2!A<G)A>5]F;&EP*"1T:&ES+3Y?8VAA
M;FYE;',I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!M97)G
M94-O;F9I9T9I;&4H9FEL92P@6V]V97)R:61E72P@6VQA>65R72D-"@T*("`@
M("\J*@T*("`@("`J($UE<F=E<R!D871A(&EN=&\@82!C;VYF:6<@;&%Y97(@
M9G)O;2!A(&9I;&4N("!$;V5S('1H92!S86UE#0H@("`@("H@=&AI;F<@87,@
M<F5A9$-O;F9I9T9I;&4L(&5X8V5P="!I="!D;V5S(&YO="!R97!L86-E(&%L
M;`T*("`@("`J(&5X:7-T:6YG('9A;'5E<R!I;B!T:&4@8V]N9FEG(&QA>65R
M+@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!T;R!R96%D(&9R;VT-"B`@
M("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R('1O(&]V97)W<FET92!E>&ES=&EN
M9R!D871A("AD969A=6QT(%12544I#0H@("`@("H@0'!A<F%M('-T<FEN9R!C
M;VYF:6<@;&%Y97(@=&\@:6YS97)T(&1A=&$@:6YT;R`H)W5S97(G(&]R("=S
M>7-T96TG*0T*("`@("`J($!P87)A;2!S=')I;F<@:68@=')U92P@97)R;W)S
M(&%R92!R971U<FYE9"!I9B!F:6QE(&]P96YI;F<@9F%I;',-"B`@("`@*B!`
M<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S(&]R(&$@4$5!4B!E<G)O<B!O
M;B!F86EL=7)E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@;65R9V5#;VYF:6=&
M:6QE*"1F:6QE+"`D;W9E<G)I9&4@/2!T<G5E+"`D;&%Y97(@/2`G=7-E<B<L
M("1S=')I8W0@/2!T<G5E*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y*"1T
M:&ES+3YF:6QE<ULD;&%Y97)=*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")U;FMN;W=N(&-O;F9I9R!L87EE<B!@)&QA>65R
M)R(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D9FEL92`]/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^9FEL97-;)&QA>65R73L-
M"B`@("`@("`@?0T*("`@("`@("`D9&%T82`]("1T:&ES+3Y?<F5A9$-O;F9I
M9T1A=&%&<F]M*"1F:6QE*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&1A=&$I*2![#0H@("`@("`@("`@("!I9B`H)'-T<FEC="D@>PT*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?97)R;W)S1F]U;F0K*SL-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^;&%S=$5R<F]R(#T@)&1A=&$[#0H-"B`@("`@("`@("`@
M("`@("!R971U<FX@)&1A=&$[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&5C;V1E26YP=70H)&1A=&$I.PT*
M("`@("`@("!I9B`H)&]V97)R:61E*2![#0H@("`@("`@("`@("`D=&AI<RT^
M8V]N9FEG=7)A=&EO;ELD;&%Y97)=(#T-"B`@("`@("`@("`@("`@("!014%2
M7T-O;F9I9SHZ87)R87E-97)G95)E8W5R<VEV92@D=&AI<RT^8V]N9FEG=7)A
M=&EO;ELD;&%Y97)=+"`D9&%T82D[#0H@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=(#T-"B`@("`@
M("`@("`@("`@("!014%27T-O;F9I9SHZ87)R87E-97)G95)E8W5R<VEV92@D
M9&%T82P@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72D[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/E]S971U<$-H86YN96QS*"D[#0H@("`@("`@
M(&EF("@A)'1H:7,M/E]N;U)E9VES=')Y("8F("@D<&AP9&ER(#T@)'1H:7,M
M/F=E="@G<&AP7V1I<B<L("1L87EE<BP@)W!E87(N<&AP+FYE="<I*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=(#T@)FYE=R!0
M14%27U)E9VES=')Y*"1P:'!D:7(I.PT*("`@("`@("`@("`@)'1H:7,M/E]R
M96=I<W1R>5LD;&%Y97)=+3YS971#;VYF:6<H)'1H:7,I.PT*("`@("`@("`@
M("`@)'1H:7,M/E]R96=);FET:6%L:7IE9%LD;&%Y97)=(#T@9F%L<V4[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W)E
M9VES=')Y6R1L87EE<ETI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!A<G)A>4UE
M<F=E4F5C=7)S:79E*"1A<G(R+"`D87)R,2D-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&%R<F%Y365R9V5296-U<G-I=F4H)&%R<C(L("1A<G(Q*0T*("`@('L-
M"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1A
M<G(R(&%S("1K97D@/3X@)&1A=&$I('L-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)&%R<C%;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@)')E=%LD:V5Y
M72`]("1D871A.PT*("`@("`@("`@("`@("`@('5N<V5T*"1A<G(Q6R1K97E=
M*3L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D9&%T82DI('L-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<G(Q6R1K97E=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<F5T6R1K97E=(#T@)&%R<C%;)&ME>5T[#0H@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1A<G(Q6R1K97E=*3L-"B`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1R971;)&ME>5T@/2!014%27T-O;F9I9SHZ87)R87E-
M97)G95)E8W5R<VEV92@D87)R,5LD:V5Y72P@)&%R<C);)&ME>5TI.PT*("`@
M("`@("`@("`@("`@('5N<V5T*"1A<G(Q6R1K97E=*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R87E?;65R9V4H)')E
M="P@)&%R<C$I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!W
M<FET94-O;F9I9T9I;&4H6V9I;&5=+"!;;&%Y97)=*0T*#0H@("`@+RHJ#0H@
M("`@("H@5W)I=&5S(&1A=&$@:6YT;R!A(&-O;F9I9R!L87EE<B!F<F]M(&$@
M9FEL92X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;"!F:6QE
M('1O(')E860@9G)O;2P@;W(@;G5L;"!F;W(@9&5F875L=`T*("`@("`J($!P
M87)A;2!S=')I;F<@8V]N9FEG(&QA>65R('1O(&EN<V5R="!D871A(&EN=&\@
M*"=U<V5R)R!O<@T*("`@("`J("`@("`@("`@("`@("`@)W-Y<W1E;2<I#0H@
M("`@("H@0'!A<F%M('-T<FEN9WQN=6QL(&1A=&$@=&\@=W)I=&4@=&\@8V]N
M9FEG(&9I;&4@;W(@;G5L;"!F;W(@:6YT97)N86P@9&%T82!;1$504D5#051%
M1%T-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S(&]R(&$@
M4$5!4B!E<G)O<B!O;B!F86EL=7)E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M=W)I=&5#;VYF:6=&:6QE*"1F:6QE(#T@;G5L;"P@)&QA>65R(#T@)W5S97(G
M+"`D9&%T82`](&YU;&PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VQA>GE#
M:&%N;F5L4V5T=7`H)&QA>65R*3L-"B`@("`@("`@:68@*"1L87EE<B`]/2`G
M8F]T:"<@?'P@)&QA>65R(#T]("=A;&PG*2![#0H@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^9FEL97,@87,@)'1Y<&4@/3X@)&9I;&4I('L-"B`@("`@
M("`@("`@("`@("`D97)R(#T@)'1H:7,M/G=R:71E0V]N9FEG1FEL92@D9FEL
M92P@)'1Y<&4L("1D871A*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)&5R<CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M96UP='DH)'1H:7,M/F9I;&5S6R1L87EE<ETI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N:VYO=VX@8V]N9FEG(&9I;&4@
M='EP92!@)&QA>65R)R(I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D9FEL
M92`]/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^9FEL
M97-;)&QA>65R73L-"B`@("`@("`@?0T*("`@("`@("`D9&%T82`]("@D9&%T
M82`]/3T@;G5L;"D@/R`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=(#H@
M)&1A=&$[#0H@("`@("`@("1T:&ES+3Y?96YC;V1E3W5T<'5T*"1D871A*3L-
M"B`@("`@("`@)&]P="`](&%R<F%Y*"<M<"<L(&1I<FYA;64H)&9I;&4I*3L-
M"B`@("`@("`@:68@*"%`4WES=&5M.CIM:T1I<B@D;W!T*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")C;W5L9"!N;W0@8W)E
M871E(&1I<F5C=&]R>3H@(B`N(&1I<FYA;64H)&9I;&4I*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H0&ES7V9I;&4H)&9I;&4I("8F("%`:7-?=W)I=&5A
M8FQE*"1F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")N;R!W<FET92!A8V-E<W,@=&\@)&9I;&4A(BD[#0H@("`@("`@
M('T-"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`B=R(I.PT*("`@("`@
M("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")014%27T-O;F9I9SHZ=W)I=&5#;VYF:6=&:6QE(&9O<&5N*"<D
M9FEL92<L)W<G*2!F86EL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D8V]N
M=&5N=',@/2`B(U!%05)?0V]N9FEG(#`N.5QN(B`N('-E<FEA;&EZ92@D9&%T
M82D[#0H@("`@("`@(&EF("@A0&9W<FET92@D9G`L("1C;VYT96YT<RDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]#
M;VYF:6<Z.G=R:71E0V]N9FEG1FEL93H@9G=R:71E(&9A:6QE9"(I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!?<F5A9$-O;F9I9T1A=&%&<F]M*&9I;&4I#0H-
M"B`@("`O*BH-"B`@("`@*B!296%D<R!C;VYF:6=U<F%T:6]N(&1A=&$@9G)O
M;2!A(&9I;&4@86YD(')E='5R;G,@=&AE('!A<G-E9"!D871A#0H@("`@("H@
M:6X@86X@87)R87DN#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I
M;&4@=&\@<F5A9"!F<F]M#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M(&-O;F9I9W5R871I;VX@9&%T82!O<B!A(%!%05(@97)R;W(@;VX@9F%I;'5R
M90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7W)E861#;VYF:6=$871A1G)O;2@D9FEL92D-"B`@("![
M#0H@("`@("`@("1F<"`]($!F;W!E;B@D9FEL92P@(G(B*3L-"B`@("`@("`@
M:68@*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@B4$5!4E]#;VYF:6<Z.G)E861#;VYF:6=&:6QE(&9O<&5N*"<D9FEL
M92<L)W(G*2!F86EL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D<VEZ92`]
M(&9I;&5S:7IE*"1F:6QE*3L-"B`@("`@("`@)')T(#T@9V5T7VUA9VEC7W%U
M;W1E<U]R=6YT:6UE*"D[#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N
M=&EM92@P*3L-"B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G
M971?8V]N=&5N=',G*2D@>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@
M("`@("`@("`@("`D8V]N=&5N=',@/2!F:6QE7V=E=%]C;VYT96YT<R@D9FEL
M92D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8V]N=&5N=',@
M/2!`9G)E860H)&9P+"`D<VEZ92D[#0H@("`@("`@("`@("!F8VQO<V4H)&9P
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&-O;G1E;G1S*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#;VYF
M:6=U<F%T:6]N(&9I;&4@(B<@+B`D9FEL92`N("<B(&ES(&5M<'1Y)RD[#0H@
M("`@("`@('T-"B`@("`@("`@#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?
M<G5N=&EM92@D<G0I.PT*#0H@("`@("`@("1V97)S:6]N(#T@9F%L<V4[#0H@
M("`@("`@(&EF("AP<F5G7VUA=&-H*"<O7B-014%27T-O;F9I9UQS*RA<4RLI
M7',K+W-I)RP@)&-O;G1E;G1S+"`D;6%T8VAE<RDI('L-"B`@("`@("`@("`@
M("1V97)S:6]N(#T@)&UA=&-H97-;,5T[#0H@("`@("`@("`@("`D8V]N=&5N
M=',@/2!S=6)S='(H)&-O;G1E;G1S+"!S=')L96XH)&UA=&-H97-;,%TI*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O($UU<V5U;2!C;VYF
M:6<@9FEL90T*("`@("`@("`@("`@:68@*'-U8G-T<B@D8V]N=&5N=',L,"PR
M*2`]/2`G83HG*2![#0H@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`G,"XQ
M)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'9E
M<G-I;VX@)B8@=F5R<VEO;E]C;VUP87)E*"(D=F5R<VEO;B(L("<Q)RP@)SPG
M*2D@>PT*#0H@("`@("`@("`@("`O+R!N;R`G0"<L(&ET(&ES('!O<W-I8FQE
M('1H870@=6YS97)I86QI>F4-"B`@("`@("`@("`@("\O(')A:7-E<R!A(&YO
M=&EC92!B=70@:70@<V5E;7,@=&\@8FQO8VL@24\@=&\-"B`@("`@("`@("`@
M("\O(%-41$]55"!I9B!A("=`)R!I<R!U<V5D(&%N9"!A(&YO=&EC92!I<R!R
M86ES90T*("`@("`@("`@("`@)&1A=&$@/2!U;G-E<FEA;&EZ92@D8V]N=&5N
M=',I.PT*#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D871A*2`F)B`A
M)&1A=&$I('L-"B`@("`@("`@("`@("`@("!I9B`H)&-O;G1E;G1S(#T]('-E
M<FEA;&EZ92AF86QS92DI('L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1E<G(@/2`D=&AI<RT^<F%I<V5%<G)O<B@B4$5!4E]#
M;VYF:6<Z(&)A9"!D871A(&EN("1F:6QE(BD[#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&$I*2![#0H@
M("`@("`@("`@("`@("`@:68@*'-T<FQE;BAT<FEM*"1C;VYT96YT<RDI(#X@
M,"D@>PT*("`@("`@("`@("`@("`@("`@("`D97)R;W(@/2`B4$5!4E]#;VYF
M:6<Z(&)A9"!D871A(&EN("1F:6QE(CL-"B`@("`@("`@("`@("`@("`@("`@
M)&5R<B`]("1T:&ES+3YR86ES945R<F]R*"1E<G)O<BD[#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("\O(&%D
M9"!P87)S:6YG(&]F(&YE=V5R(&9O<FUA=',@:&5R92XN+@T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)&5R<B`]("1T:&ES+3YR86ES945R<F]R
M*"(D9FEL93H@=6YK;F]W;B!V97)S:6]N(&`D=F5R<VEO;B<B*3L-"B`@("`@
M("`@("`@(')E='5R;B`D97)R.R`-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E
M=$-O;F9&:6QE*&QA>65R*0T*("`@("\J*@T*("`@("H@1V5T<R!T:&4@9FEL
M92!U<V5D(&9O<B!S=&]R:6YG('1H92!C;VYF:6<@9F]R(&$@;&%Y97(-"B`@
M("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("1L87EE<B`G=7-E<B<@;W(@)W-Y
M<W1E;2<-"B`@("`J+PT*#0H@("`@9G5N8W1I;VX@9V5T0V]N9D9I;&4H)&QA
M>65R*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YF:6QE<ULD;&%Y
M97)=.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M(&%R<F%Y(&EN9F]R;6%T:6]N(&]N(&$@<F]L92!A<R!P87)S960@
M9G)O;2!I=',@>&UL(&9I;&4-"B`@("`@*B!`<F5T=7)N('1R=65\4$5!4E]%
M<G)O<@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]A9&1#;VYF:6=687)S*"1V87)S*0T*("`@('L-"B`@("`@("`@
M:68@*&-O=6YT*"1V87)S*2`^(#,I('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G4F]L97,@8V%N(&]N;'D@9&5F:6YE(#,@;F5W
M(&-O;F9I9R!V87)I86)L97,@;W(@;&5S<R<I.PT*("`@("`@("!]#0H@("`@
M("`@(&9O<F5A8V@@*"1V87)S(&%S("1N86UE(#T^("1V87(I('L-"B`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)'9A<BDI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-O;F9I9W5R871I;VX@:6YF
M;W)M871I;VX@;75S="!B92!A;B!A<G)A>2<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=F%R6R=T>7!E)UTI*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#;VYF:6=U
M<F%T:6]N(&EN9F]R;6%T:6]N(&UU<W0@8V]N=&%I;B!A('1Y<&4G*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"%I;E]A
M<G)A>2@D=F%R6R=T>7!E)UTL#0H@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W-T<FEN9R<L("=M87-K)RP@)W!A<W-W;W)D)RP@)V1I<F5C=&]R>2<L
M("=F:6QE)RP@)W-E="<I*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G0V]N9FEG=7)A=&EO;B!T>7!E(&UU<W0@8F4@;VYE(&]F(&1I<F5C=&]R
M>2P@9FEL92P@<W1R:6YG+"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=M87-K+"!S970L(&]R('!A<W-W;W)D)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<W-E="@D=F%R
M6R=D969A=6QT)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@("`@("`G0V]N9FEG=7)A
M=&EO;B!I;F9O<FUA=&EO;B!M=7-T(&-O;G1A:6X@82!D969A=6QT('9A;'5E
M("@B9&5F875L="(@:6YD97@I)RD[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%R6R=D969A=6QT)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1R96%L7V1E9F%U;'0@/2`G)SL-
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A<ELG9&5F875L="==
M(&%S("1C;VYF:6=?=F%R(#T^("1V86PI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AS=')P;W,H)&-O;F9I9U]V87(L("=T97AT)RD@/3T](#`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5A;%]D969A=6QT
M("X]("1V86P[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M<W1R<&]S*"1C;VYF:6=?=F%R+"`G8V]N<W1A;G0G*2`]/3T@,"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AD969I;F5D*"1V86PI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96%L7V1E9F%U
M;'0@+CT@8V]N<W1A;G0H)'9A;"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)U5N:VYO=VX@8V]N<W1A;G0@(B<@+B`D
M=F%L("X@)R(@<F5Q=65S=&5D(&EN("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V1E9F%U;'0@=F%L=64@9F]R(&-O;F9I9W5R
M871I;VX@=F%R:6%B;&4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@+B`G(B<I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1C;VYF:6=?=F%R
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5A;%]D969A
M=6QT("X]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC;VYF:6=U<F%T:6]N7VEN9F];)&-O;F9I9U]V87)=6R=D969A=6QT)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U5N:VYO=VX@<F5Q
M=65S="!F;W(@(B<@+B`D8V]N9FEG7W9A<B`N("<B('9A;'5E(&EN("<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9&5F875L="!V86QU
M92!F;W(@8V]N9FEG=7)A=&EO;B!V87)I86)L92`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1N86UE("X@)R(G*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D=F%R6R=D969A=6QT)UT@/2`D<F5A;%]D969A
M=6QT.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M)'9A<ELG='EP92==(#T]("=I;G1E9V5R)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`D=F%R6R=D969A=6QT)UT@/2`H:6YT96=E<BD@)'9A<ELG9&5F875L
M="==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'9A<ELG9&]C)UTI*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@("`@("`@("`@
M("`@("`@("`G0V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!M=7-T(&-O;G1A
M:6X@82!S=6UM87)Y("@B9&]C(B!I;F1E>"DG*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A<ELG<')O;7!T)UTI*2![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*`T*("`@
M("`@("`@("`@("`@("`@("`G0V]N9FEG=7)A=&EO;B!I;F9O<FUA=&EO;B!M
M=7-T(&-O;G1A:6X@82!S:6UP;&4@<')O;7!T("@B<')O;7!T(B!I;F1E>"DG
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'9A
M<ELG9W)O=7`G72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F%T
M:6]N(&EN9F]R;6%T:6]N(&UU<W0@8V]N=&%I;B!A('-I;7!L92!G<F]U<"`H
M(F=R;W5P(B!I;F1E>"DG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1N86UE72DI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)T-O;F9I9W5R871I;VX@=F%R:6%B;&4@(B<@+B`D;F%M92`N#0H@("`@("`@
M("`@("`@("`@("`@("<B(&%L<F5A9'D@97AI<W1S)RD[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1N
M86UE72`]("1V87([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+R\@>WM[(%]E;F-O9&5/=71P=70H)F1A=&$I#0H-
M"B`@("`O*BH-"B`@("`@*B!%;F-O9&5S+W-C<F%M8FQE<R!C;VYF:6=U<F%T
M:6]N(&1A=&$@8F5F;W)E('=R:71I;F<@=&\@9FEL97,N#0H@("`@("H@0W5R
M<F5N=&QY+"`G<&%S<W=O<F0G('9A;'5E<R!W:6QL(&)E(&)A<V4V-"UE;F-O
M9&5D(&%S('1O(&%V;VED#0H@("`@("H@=&AA="!P96]P;&4@<W!O="!C;&5A
M<G1E>'0@<&%S<W=O<F1S(&)Y(&%C8VED96YT+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M(&%R<F%Y("AR969E<F5N8V4I(&%R<F%Y('1O(&5N8V]D92!V86QU
M97,@:6X-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U
M8V-E<W,-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%]E;F-O9&5/=71P=70H)B1D871A*0T*("`@('L-
M"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&ME>2`]/B`D=F%L=64I('L-
M"B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=?7V-H86YN96QS)RD@>PT*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=?7V-H86YN96QS)UT@87,@
M)&-H86YN96P@/3X@)&)L86@I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]E;F-O9&5/=71P=70H)&1A=&%;)U]?8VAA;FYE;',G75LD8VAA;FYE
M;%TI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD
M:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1T>7!E(#T@)'1H:7,M/F-O;F9I9W5R871I
M;VY?:6YF;ULD:V5Y75LG='EP92==.PT*("`@("`@("`@("`@<W=I=&-H("@D
M='EP92D@>PT*("`@("`@("`@("`@("`@("\O('=E(&)A<V4V-"UE;F-O9&4@
M<&%S<W=O<F1S('-O('1H97D@87)E(&%T(&QE87-T#0H@("`@("`@("`@("`@
M("`@+R\@;F]T('-H;W=N(&EN('!L86EN(&)Y(&%C8VED96YT#0H@("`@("`@
M("`@("`@("`@8V%S92`G<&%S<W=O<F0G.B![#0H@("`@("`@("`@("`@("`@
M("`@("1D871A6R1K97E=(#T@8F%S938T7V5N8V]D92@D9&%T85LD:V5Y72D[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!C87-E("=M87-K)SH@>PT*("`@("`@("`@
M("`@("`@("`@("`D9&%T85LD:V5Y72`](&]C=&1E8R@D9&%T85LD:V5Y72D[
M#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@7V1E8V]D
M94EN<'5T*"9D871A*0T*#0H@("`@+RHJ#0H@("`@("H@1&5C;V1E<R]U;G-C
M<F%M8FQE<R!C;VYF:6=U<F%T:6]N(&1A=&$@869T97(@<F5A9&EN9R!F<F]M
M(&9I;&5S+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("AR969E<F5N
M8V4I(&%R<F%Y('1O(&5N8V]D92!V86QU97,@:6X-"B`@("`@*@T*("`@("`J
M($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,-"B`@("`@*@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J#0H@("`@("H@0'-E92!014%27T-O
M;F9I9SHZ7V5N8V]D94]U='!U=`T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]D
M96-O9&5);G!U="@F)&1A=&$I#0H@("`@>PT*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1D871A*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T-"B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&ME>2`]/B`D=F%L
M=64I('L-"B`@("`@("`@("`@(&EF("@D:V5Y(#T]("=?7V-H86YN96QS)RD@
M>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D871A6R=?7V-H86YN96QS
M)UT@87,@)&-H86YN96P@/3X@)&)L86@I('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D96-O9&5);G!U="@D9&%T85LG7U]C:&%N;F5L<R==6R1C
M:&%N;F5L72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I
M;F9O6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1Y<&4@/2`D=&AI<RT^8V]N9FEG
M=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E)UT[#0H@("`@("`@("`@("!S=VET
M8V@@*"1T>7!E*2![#0H@("`@("`@("`@("`@("`@8V%S92`G<&%S<W=O<F0G
M.B![#0H@("`@("`@("`@("`@("`@("`@("1D871A6R1K97E=(#T@8F%S938T
M7V1E8V]D92@D9&%T85LD:V5Y72D[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!C87-E
M("=M87-K)SH@>PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LD:V5Y72`]
M(&1E8V]C="@D9&%T85LD:V5Y72D[#0H@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@9V5T1&5F875L=$-H86YN96PH6VQA>65R72D-"B`@
M("`O*BH-"B`@("`@*B!2971R:65V92!T:&4@9&5F875L="!C:&%N;F5L+@T*
M("`@("`J#0H@("`@("H@3VX@<W1A<G1U<"P@8VAA;FYE;',@87)E(&YO="!I
M;FET:6%L:7IE9"P@<V\@:68@=&AE(&1E9F%U;'0@8VAA;FYE;"!I<R!N;W0-
M"B`@("`@*B!P96%R+G!H<"YN970L('1H96X@:6YI=&EA;&EZ92!T:&4@8V]N
M9FEG+@T*("`@("`J($!P87)A;2!S=')I;F<@<F5G:7-T<GD@;&%Y97(-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$1E9F%U;'1#:&%N;F5L*"1L87EE<B`](&YU;&PI#0H@("`@>PT*
M("`@("`@("`D<F5T(#T@9F%L<V4[#0H@("`@("`@(&EF("@D;&%Y97(@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YL87EE<G,@
M87,@)&QA>65R*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)V1E9F%U;'1?8VAA;FYE;"==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/F-O;F9I9W5R
M871I;VY;)&QA>65R75LG9&5F875L=%]C:&%N;F5L)UT[#0H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U
M<F%T:6]N6R1L87EE<EU;)V1E9F%U;'1?8VAA;FYE;"==*2D@>PT*("`@("`@
M("`@("`@)')E="`]("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)V1E
M9F%U;'1?8VAA;FYE;"==.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5T
M(#T]("=P96%R+G!H<"YN970G("8F(&1E9FEN960H)U!%05)?4E5.5%E012<I
M("8F(%!%05)?4E5.5%E012`]/2`G<&5C;"<I('L-"B`@("`@("`@("`@("1R
M970@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)')E="D@>PT*("`@("`@("`@("`@:68@*"1R970@(3T@)W!E87(N<&AP+FYE
M="<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VQA>GE#:&%N;F5L4V5T
M=7`H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!014%27T-/3D9)1U]$149!
M54Q47T-(04Y.14P[#0H@("`@?0T*#0H@("`@+R\@>WM[(&=E="AK97DL(%ML
M87EE<ETI#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N<R!A(&-O;F9I9W5R871I
M;VX@=F%L=64L('!R:6]R:71I>FEN9R!L87EE<G,@87,@<&5R('1H90T*("`@
M("`J(&QA>65R<R!P<F]P97)T>2X-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@("H@0')E='5R;B!M:7AE
M9"!T:&4@8V]N9FEG('9A;'5E+"!O<B!.54Q,(&EF(&YO="!F;W5N9`T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G970H)&ME>2P@)&QA>65R(#T@;G5L;"P@)&-H86YN96P@/2!F86QS
M92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F-O;F9I9W5R
M871I;VY?:6YF;ULD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D:V5Y(#T]("=?7V-H86YN96QS
M)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&YU;&P[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1K97D@/3T@)V1E9F%U;'1?8VAA;FYE;"<I('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9V5T1&5F875L=$-H86YN96PH)&QA>65R
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21C:&%N;F5L*2![#0H@("`@
M("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3YG971$969A=6QT0VAA;FYE;"@I
M.PT*("`@("`@("!](&5L<V5I9B`H)&-H86YN96P@(3T@)W!E87(N<&AP+FYE
M="<I('L-"B`@("`@("`@("`@("1T:&ES+3Y?;&%Z>4-H86YN96Q3971U<"@I
M.PT*("`@("`@("!]#0H@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D
M8VAA;FYE;"D[#0H@("`@("`@(`T*("`@("`@("`D=&5S="`]("AI;E]A<G)A
M>2@D:V5Y+"`D=&AI<RT^7V-H86YN96Q#;VYF:6=);F9O*2D@/PT*("`@("`@
M("`@("`@)'1H:7,M/E]G971#:&%N;F5L5F%L=64H)&ME>2P@)&QA>65R+"`D
M8VAA;FYE;"D@.@T*("`@("`@("`@("`@;G5L;#L-"B`@("`@("`@:68@*"1T
M97-T("$]/2!N=6QL*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]I;G-T
M86QL4F]O="D@>PT*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D=&AI
M<RT^9V5T1W)O=7`H)&ME>2DL#0H@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)T9I;&4@3&]C871I;VYS)RP@)T9I;&4@3&]C871I;VYS("A!9'9A;F-E
M9"DG*2D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T5'EP
M92@D:V5Y*2`]/2`G9&ER96-T;W)Y)RD@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P<F5P96YD4&%T:"@D=&5S="P@)'1H:7,M/E]I
M;G-T86QL4F]O="D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@<F5T=7)N("1T97-T.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D;&%Y97(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3YL87EE<G,@87,@)&QA>65R*2![#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)&ME
M>5TI*2![#0H@("`@("`@("`@("`@("`@("`@("1T97-T(#T@)'1H:7,M/F-O
M;F9I9W5R871I;VY;)&QA>65R75LD:V5Y73L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?:6YS=&%L;%)O;W0I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI;E]A<G)A>2@D=&AI<RT^9V5T1W)O=7`H)&ME>2DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G1FEL92!,
M;V-A=&EO;G,G+"`G1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<I*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%1Y<&4H
M)&ME>2D@/3T@)V1I<F5C=&]R>2<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]P<F5P96YD4&%T:"@D=&5S="P@)'1H
M:7,M/E]I;G-T86QL4F]O="D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1K97D@/3T@)W!R969E<G)E9%]M:7)R;W(G*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YG971296=I<W1R>2@I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D<F5G*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@)B1R96<M
M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A)&-H86XM/F=E=$UI<G)O<B@D=&5S="D@)B8@)&-H
M86XM/F=E=$YA;64H*2`A/2`D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P[("\O(&UI<G)O<B!D;V5S
M(&YO="!E>&ES=`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1E<W0[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI('L-
M"B`@("`@("`@("`@("1T97-T(#T@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA
M>65R75LD:V5Y73L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7VEN<W1A;&Q2
M;V]T*2![#0H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1T:&ES+3YG
M971'<F]U<"@D:V5Y*2P-"B`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M1FEL92!,;V-A=&EO;G,G+"`G1FEL92!,;V-A=&EO;G,@*$%D=F%N8V5D*2<I
M*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YG9714>7!E*"1K
M97DI(#T]("=D:7)E8W1O<GDG*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!R97!E;F10871H*"1T97-T+"`D=&AI<RT^7VEN<W1A
M;&Q2;V]T*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H)&ME>2`]/2`G<')E9F5R<F5D7VUI<G)O<B<I('L-
M"B`@("`@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YG971296=I<W1R>2@I
M.PT*("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E9RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D
M8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1C:&%N;F5L.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A)&-H86XM/F=E=$UI<G)O<B@D=&5S="D@)B8@)&-H
M86XM/F=E=$YA;64H*2`A/2`D=&5S="D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1C:&%N;F5L.R`O+R!M:7)R;W(@9&]E<R!N;W0@97AI
M<W0-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&5S=#L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@;G5L;#L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("`O+R![>WL@7V=E=$-H86YN96Q686QU92AK97DL('9A;'5E
M+"!;;&%Y97)=*0T*("`@("\J*@T*("`@("`J(%)E='5R;G,@82!C:&%N;F5L
M+7-P96-I9FEC(&-O;F9I9W5R871I;VX@=F%L=64L('!R:6]R:71I>FEN9R!L
M87EE<G,@87,@<&5R('1H90T*("`@("`J(&QA>65R<R!P<F]P97)T>2X-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0T*("`@("`J
M#0H@("`@("H@0')E='5R;B!M:7AE9"!T:&4@8V]N9FEG('9A;'5E+"!O<B!.
M54Q,(&EF(&YO="!F;W5N9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V=E=$-H86YN96Q686QU92@D
M:V5Y+"`D;&%Y97(L("1C:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@*"1K
M97D@/3T@)U]?8VAA;FYE;',G('Q\("1C:&%N;F5L(#T]("=P96%R+G!H<"YN
M970G*2![#0H@("`@("`@("`@("!R971U<FX@;G5L;#L-"B`@("`@("`@?0T*
M("`@("`@("`D<F5T(#T@;G5L;#L-"B`@("`@("`@:68@*"1L87EE<B`]/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A
M<R`D:6QA>65R*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N6R1I;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN
M96Q=6R1K97E=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H
M:7,M/F-O;F9I9W5R871I;VY;)&EL87EE<EU;)U]?8VAA;FYE;',G75LD8VAA
M;FYE;%U;)&ME>5T[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)U]?8VAA
M;FYE;',G75LD8VAA;FYE;%U;)&ME>5TI*2![#0H@("`@("`@("`@("`D<F5T
M(#T@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LG7U]C:&%N;F5L<R==
M6R1C:&%N;F5L75LD:V5Y73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&ME
M>2`]/2`G<')E9F5R<F5D7VUI<G)O<B<I('L-"B`@("`@("`@("`@(&EF("@D
M<F5T("$]/2!N=6QL*2![#0H@("`@("`@("`@("`@("`@)')E9R`]("8D=&AI
M<RT^9V5T4F5G:7-T<GDH)&QA>65R*3L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-?;V)J96-T*"1R96<I*2![#0H@("`@("`@("`@("`@("`@("`@("1C:&%N
M(#T@)B1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D8VAA;FYE;#L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H(21C:&%N+3YG
M971-:7)R;W(H)')E="D@)B8@)&-H86XM/F=E=$YA;64H*2`A/2`D<F5T*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&-H86YN96P[("\O
M(&UI<G)O<B!D;V5S(&YO="!E>&ES=`T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L
M(#T]("1T:&ES+3YG971$969A=6QT0VAA;FYE;"@D;&%Y97(I*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N("1C:&%N;F5L.R`O+R!W92!M=7-T('5S92!T
M:&4@8VAA;FYE;"!N86UE(&%S('1H92!P<F5F97)R960@;6ER<F]R#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!I9B!T:&4@=7-E<B!H
M87,@;F]T(&-H;W-E;B!A;B!A;'1E<FYA=&4-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG971$969A=6QT
M0VAA;FYE;"@D;&%Y97(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[('-E="AK97DL('9A;'5E+"!;;&%Y97)=*0T*#0H@("`@+RHJ
M#0H@("`@("H@4V5T(&$@8V]N9FEG('9A;'5E(&EN(&$@<W!E8VEF:6,@;&%Y
M97(@*&1E9F%U;'1S('1O("=U<V5R)RDN#0H@("`@("H@16YF;W)C97,@=&AE
M('1Y<&5S(&1E9FEN960@:6X@=&AE(&-O;F9I9W5R871I;VY?:6YF;R!A<G)A
M>2X@($%N#0H@("`@("H@:6YT96=E<B!C;VYF:6<@=F%R:6%B;&4@=VEL;"!B
M92!C87-T('1O(&EN="P@86YD(&$@<V5T(&-O;F9I9PT*("`@("`J('9A<FEA
M8FQE('=I;&P@8F4@=F%L:61A=&5D(&%G86EN<W0@:71S(&QE9V%L('9A;'5E
M<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0T*
M("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG('9A;'5E#0H@("`@("H@0'!A
M<F%M('-T<FEN9R`H;W!T:6]N86PI(&-O;F9I9R!L87EE<@T*("`@("`J($!P
M87)A;2!S=')I;F<@8VAA;FYE;"!T;R!S970@=&AI<R!V86QU92!F;W(L(&]R
M(&YU;&P@9F]R(&=L;V)A;"!V86QU90T*("`@("`J($!R971U<FX@8F]O;"!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!S970H)&ME>2P@)'9A;'5E+"`D;&%Y97(@/2`G=7-E<B<L
M("1C:&%N;F5L(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H)&ME>2`]
M/2`G7U]C:&%N;F5L<R<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YC;VYF:6=U
M<F%T:6]N6R1L87EE<ETI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1K97D@/3T@)V1E9F%U;'1?8VAA
M;FYE;"<I('L-"B`@("`@("`@("`@("\O(&-A;B!O;FQY('-E="!T:&ES('9A
M;'5E(&=L;V)A;&QY#0H@("`@("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H
M<"YN970G.PT*("`@("`@("`@("`@:68@*"1V86QU92`A/2`G<&5A<BYP:'`N
M;F5T)RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?;&%Z>4-H86YN96Q3
M971U<"@D;&%Y97(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("@D:V5Y(#T]("=P<F5F97)R961?;6ER<F]R)RD@>PT*("`@("`@
M("`@("`@:68@*"1C:&%N;F5L(#T]("=?7W5R:2<I('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[("\O(&-A;B=T('-E="!T:&4@7U]U<FD@<'-E
M=61O+6-H86YN96PG<R!M:7)R;W(-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1R96<@/2`F)'1H:7,M/F=E=%)E9VES=')Y*"1L87EE<BD[#0H@("`@
M("`@("`@("!I9B`H:7-?;V)J96-T*"1R96<I*2![#0H@("`@("`@("`@("`@
M("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"`_("1C:&%N
M;F5L(#H@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("@A)&-H86XM/F=E=$UI<G)O<B@D=F%L=64I("8F("1C:&%N+3YG
M971.86UE*"D@(3T@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L@+R\@;6ER<F]R(&1O97,@;F]T(&5X:7-T#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("AE;7!T>2@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@(&5X=')A8W0H)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72D[
M#0H@("`@("`@('-W:71C:"`H)'1Y<&4I('L-"B`@("`@("`@("`@(&-A<V4@
M)VEN=&5G97(G.@T*("`@("`@("`@("`@("`@("1V86QU92`]("AI;G0I)'9A
M;'5E.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G<V5T)SH@>PT*("`@("`@("`@("`@("`@("\O($EF(&$@=F%L:61?<V5T
M(&ES('-P96-I9FEE9"P@<F5Q=6ER92!T:&4@=F%L=64@=&\-"B`@("`@("`@
M("`@("`@("`O+R!B92!I;B!T:&4@<V5T+B`@268@=&AE<F4@:7,@;F\@=F%L
M:61?<V5T+"!A8V-E<'0-"B`@("`@("`@("`@("`@("`O+R!A;GD@=F%L=64N
M#0H@("`@("`@("`@("`@("`@:68@*"1V86QI9%]S970I('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5S970H)'9A;&ED7W-E="D[#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@H:V5Y*"1V86QI9%]S970I(#T]/2`P("8F("%I;E]A<G)A
M>2@D=F%L=64L("1V86QI9%]S970I*2!\?`T*("`@("`@("`@("`@("`@("`@
M("`@("`@*&ME>2@D=F%L:61?<V5T*2`A/3T@,"`F)B!E;7!T>2@D=F%L:61?
M<V5T6R1V86QU95TI*2D-"B`@("`@("`@("`@("`@("`@("`@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("@A)&-H86YN96PI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M
M/F=E="@G9&5F875L=%]C:&%N;F5L)RP@;G5L;"P@)W!E87(N<&AP+FYE="<I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R87DH)&-H86YN96PL
M("1T:&ES+3Y?8VAA;FYE;',I*2![#0H@("`@("`@("`@("`D=&AI<RT^7VQA
M>GE#:&%N;F5L4V5T=7`H)&QA>65R*3L-"B`@("`@("`@("`@("1R96<@/2`F
M)'1H:7,M/F=E=%)E9VES=')Y*"1L87EE<BD[#0H@("`@("`@("`@("!I9B`H
M)')E9RD@>PT*("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)')E9RT^8VAA
M;FYE;$YA;64H)&-H86YN96PI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"%I;E]A<G)A>2@D8VAA;FYE;"P@)'1H:7,M/E]C:&%N;F5L<RDI
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N;F5L("$]("=P96%R
M+G!H<"YN970G*2![#0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)&ME>2P@
M)'1H:7,M/E]C:&%N;F5L0V]N9FEG26YF;RDI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS)UU;
M)&-H86YN96Q=6R1K97E=(#T@)'9A;'5E.PT*("`@("`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!I9B`H)&ME>2`]/2`G9&5F875L=%]C:&%N
M;F5L)RD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')E9RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^9V5T4F5G:7-T
M<GDH)&QA>65R*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D<F5G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YG9712
M96=I<W1R>2@I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<F5G*2![#0H@("`@("`@
M("`@("`@("`@("`@("1V86QU92`]("1R96<M/F-H86YN96Q.86UE*"1V86QU
M92D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A
M)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72`]
M("1V86QU93L-"B`@("`@("`@:68@*"1K97D@/3T@)W!H<%]D:7(G("8F("$D
M=&AI<RT^7VYO4F5G:7-T<GDI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=*2!\?`T*("`@("`@("`@("`@("`@
M("`@)'9A;'5E("$]("1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72T^:6YS=&%L
M;%]D:7(I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L
M87EE<ET@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'9A;'5E*3L-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W)E9TEN:71I86QI>F5D6R1L87EE<ET@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM
M/G-E=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@9G5N8W1I;VX@7VQA>GE#:&%N;F5L4V5T=7`H)'5S96QA>65R(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]N;U)E9VES=')Y*2![
M#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)&UE
M<F=E(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<F5G:7-T
M<GD@87,@)&QA>65R(#T^("1P*2![#0H@("`@("`@("`@("!I9B`H)'5S96QA
M>65R("8F("1U<V5L87EE<B`A/2`D;&%Y97(I('L-"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]R96=);FET:6%L:7IE9%LD;&%Y97)=*2![#0H@("`@("`@("`@
M("`@("`@:68@*"1L87EE<B`]/2`G9&5F875L="<@)B8@:7-S970H)'1H:7,M
M/E]R96=I<W1R>5LG=7-E<B==*2!\?`T*("`@("`@("`@("`@("`@("`@("`@
M(&ES<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)W-Y<W1E;2==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`O+R!O;FQY('5S92!T:&4@9&5F875L="!R96=I<W1R
M>2!I9B!T:&5R92!A<F4@;F\@86QT97)N871I=F5S#0H@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H(6ES7V]B:F5C="@D=&AI<RT^7W)E9VES=')Y6R1L87EE
M<ETI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<&AP9&ER(#T@)'1H
M:7,M/F=E="@G<&AP7V1I<B<L("1L87EE<BP@)W!E87(N<&AP+FYE="<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L
M87EE<ET@/2`F;F5W(%!%05)?4F5G:7-T<GDH)'!H<&1I<BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y6R1L87EE<ETM/G-E
M=$-O;F9I9R@D=&AI<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W)E9TEN:71I86QI>F5D6R1L87EE<ET@/2!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=$-H86YN96QS*"1T:&ES+3Y?<F5G:7-T<GE;)&QA>65R72T^;&ES=$-H86YN
M96QS*"DL("1M97)G92D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=)
M;FET:6%L:7IE9%LD;&%Y97)=(#T@=')U93L-"B`@("`@("`@("`@("`@("`D
M;65R9V4@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M?0T*("`@("\O('M[>R!S971#:&%N;F5L<R@I#0H@("`@#0H@("`@+RHJ#0H@
M("`@("H@4V5T('1H92!L:7-T(&]F(&-H86YN96QS+@T*("`@("`J#0H@("`@
M("H@5&AI<R!S:&]U;&0@8F4@<V5T('9I82!A(&-A;&P@=&\@>T!L:6YK(%!%
M05)?4F5G:7-T<GDZ.FQI<W1#:&%N;F5L<R@I?0T*("`@("`J($!P87)A;2!A
M<G)A>0T*("`@("`J($!P87)A;2!B;V]L#0H@("`@("H@0')E='5R;B!B;V]L
M('-U8V-E<W,@;V8@;W!E<F%T:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M<V5T0VAA;FYE;',H)&-H86YN96QS+"`D;65R9V4@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@A:7-?87)R87DH)&-H86YN96QS*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M;65R9V4I('L-"B`@("`@("`@("`@("1T:&ES+3Y?8VAA;FYE;',@/2!A<G)A
M>5]M97)G92@D=&AI<RT^7V-H86YN96QS+"`D8VAA;FYE;',I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]C:&%N;F5L<R`]("1C
M:&%N;F5L<SL-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D8VAA;FYE
M;',@87,@)&-H86YN96PI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@<W1R
M=&]L;W=E<B@D8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@
M/3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YL87EE<G,@87,@)&QA>65R*2![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS
M)UU;)&-H86YN96Q=*0T*("`@("`@("`@("`@("`@("`@("`@('Q\("%I<U]A
M<G)A>2@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS
M)UU;)&-H86YN96Q=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN96QS)UU;)&-H86YN96Q=
M(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=%1Y<&4H:V5Y*0T*#0H@("`@+RHJ
M#0H@("`@("H@1V5T('1H92!T>7!E(&]F(&$@8V]N9FEG('9A;'5E+@T*("`@
M("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`@8V]N9FEG(&ME>0T*("`@("`J
M#0H@("`@("H@0')E='5R;B!S=')I;F<@='EP92P@;VYE(&]F(")S=')I;F<B
M+"`B:6YT96=E<B(L(")F:6QE(BP-"B`@("`@*B`B9&ER96-T;W)Y(BP@(G-E
M="(@;W(@(G!A<W-W;W)D(BX-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B
M;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9714>7!E*"1K
M97DI#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R
M871I;VY?:6YF;ULD:V5Y72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=6R=T>7!E)UT[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!G971$;V-S*&ME>2D-"@T*("`@("\J*@T*("`@("`J
M($=E="!T:&4@9&]C=6UE;G1A=&EO;B!F;W(@82!C;VYF:6<@=F%L=64N#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("!C;VYF:6<@:V5Y#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!D;V-U;65N=&%T:6]N('-T<FEN
M9PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=$1O8W,H)&ME>2D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYF:6=U<F%T:6]N
M7VEN9F];)&ME>5U;)V1O8R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H@("`@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E
M=%!R;VUP="AK97DI#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE('-H;W)T
M(&1O8W5M96YT871I;VX@9F]R(&$@8V]N9FEG('9A;'5E+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M('-T<FEN9R`@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@
M("H@0')E='5R;B!S=')I;F<@<VAO<G0@9&]C=6UE;G1A=&EO;B!S=')I;F<-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G9710<F]M<'0H)&ME>2D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O6R1K97E=
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC;VYF:6=U<F%T:6]N
M7VEN9F];)&ME>5U;)W!R;VUP="==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E
M=$=R;W5P*&ME>2D-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@<&%R86UE
M=&5R(&=R;W5P(&9O<B!A(&-O;F9I9R!K97DN#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG("!C;VYF:6<@:V5Y#0H@("`@("H-"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R!P87)A;65T97(@9W)O=7`-"B`@("`@*@T*("`@("`J($!A
M8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971'<F]U<"@D:V5Y*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5TI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y75LG9W)O=7`G
M73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&=E=$=R;W5P<R@I#0H-"B`@("`O
M*BH-"B`@("`@*B!'970@=&AE(&QI<W0@;V8@<&%R86UE=&5R(&=R;W5P<RX-
M"B`@("`@*@T*("`@("`J($!R971U<FX@87)R87D@;&ES="!O9B!P87)A;65T
M97(@9W)O=7!S#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@
M("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1W)O=7!S*"D-"B`@("![
M#0H@("`@("`@("1T;7`@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^8V]N9FEG=7)A=&EO;E]I;F9O(&%S("1K97D@/3X@)&EN9F\I('L-
M"B`@("`@("`@("`@("1T;7!;)&EN9F];)V=R;W5P)UU=(#T@,3L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=&UP*3L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T1W)O=7!+97ES*"D-"@T*
M("`@("\J*@T*("`@("`J($=E="!T:&4@;&ES="!O9B!T:&4@<&%R86UE=&5R
M<R!I;B!A(&=R;W5P+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9W)O=7`@<&%R86UE=&5R(&=R;W5P#0H@("`@("H-"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y(&QI<W0@;V8@<&%R86UE=&5R<R!I;B`D9W)O=7`-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971'<F]U<$ME>7,H)&=R;W5P*0T*("`@('L-"B`@("`@("`@
M)&ME>7,@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]N
M9FEG=7)A=&EO;E]I;F9O(&%S("1K97D@/3X@)&EN9F\I('L-"B`@("`@("`@
M("`@(&EF("@D:6YF;ULG9W)O=7`G72`]/2`D9W)O=7`I('L-"B`@("`@("`@
M("`@("`@("`D:V5Y<UM=(#T@)&ME>3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)&ME>7,[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&=E=%-E=%9A;'5E<RAK97DI#0H-"B`@("`O*BH-
M"B`@("`@*B!'970@=&AE(&QI<W0@;V8@86QL;W=E9"!S970@=F%L=65S(&9O
M<B!A(&-O;F9I9R!V86QU92X@(%)E='5R;G,-"B`@("`@*B!.54Q,(&9O<B!C
M;VYF:6<@=F%L=65S('1H870@87)E(&YO="!S971S+@T*("`@("`J#0H@("`@
M("H@0'!A<F%M('-T<FEN9R`@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@("H@
M0')E='5R;B!A<G)A>2!E;G5M97)A=&5D(&%R<F%Y(&]F('-E="!V86QU97,L
M(&]R($Y53$P@:68@=&AE#0H@("`@("H@("`@("`@("`@("`@("!C;VYF:6<@
M:V5Y(&ES('5N:VYO=VX@;W(@;F]T(&$@<V5T#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M9V5T4V5T5F%L=65S*"1K97DI#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F-O;F9I9W5R871I;VY?:6YF;ULD:V5Y72D@)B8-"B`@("`@("`@
M("`@(&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];)&ME>5U;)W1Y
M<&4G72D@)B8-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN
M9F];)&ME>5U;)W1Y<&4G72`]/2`G<V5T)RD-"B`@("`@("`@>PT*("`@("`@
M("`@("`@)'9A;&ED7W-E="`]("1T:&ES+3YC;VYF:6=U<F%T:6]N7VEN9F];
M)&ME>5U;)W9A;&ED7W-E="==.PT*("`@("`@("`@("`@<F5S970H)'9A;&ED
M7W-E="D[#0H@("`@("`@("`@("!I9B`H:V5Y*"1V86QI9%]S970I(#T]/2`P
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1V86QI9%]S970[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D=F%L
M:61?<V5T*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@;G5L;#L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T2V5Y<R@I#0H-"B`@
M("`O*BH-"B`@("`@*B!'970@86QL('1H92!C=7)R96YT(&-O;F9I9R!K97ES
M+@T*("`@("`J#0H@("`@("H@0')E='5R;B!A<G)A>2!S:6UP;&4@87)R87D@
M;V8@8V]N9FEG(&ME>7,-"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T2V5Y<R@I#0H@("`@>PT*("`@
M("`@("`D:V5Y<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES
M+3YL87EE<G,@87,@)&QA>65R*2![#0H@("`@("`@("`@("`D=&5S="`]("1T
M:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ET[#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'1E<W1;)U]?8VAA;FYE;',G72DI('L-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=&5S=%LG7U]C:&%N;F5L<R==(&%S("1C:&%N;F5L(#T^
M("1C;VYF:6=S*2![#0H@("`@("`@("`@("`@("`@("`@("1K97ES(#T@87)R
M87E?;65R9V4H)&ME>7,L("1C;VYF:6=S*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!U;G-E="@D=&5S=%LG7U]C
M:&%N;F5L<R==*3L-"B`@("`@("`@("`@("1K97ES(#T@87)R87E?;65R9V4H
M)&ME>7,L("1T97-T*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R
M87E?:V5Y<R@D:V5Y<RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(')E;6]V92AK97DL(%ML87EE<ETI#0H-"B`@("`O*BH-"B`@("`@*B!2
M96UO=F4@=&AE(&$@8V]N9FEG(&ME>2!F<F]M(&$@<W!E8VEF:6,@8V]N9FEG
M(&QA>65R+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@
M:V5Y#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("AO<'1I;VYA;"D@
M8V]N9FEG(&QA>65R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')E;6]V
M92@D:V5Y+"`D;&%Y97(@/2`G=7-E<B<I#0H@("`@>PT*("`@("`@("`D8VAA
M;FYE;"`]("1T:&ES+3YG971$969A=6QT0VAA;FYE;"@I.PT*("`@("`@("!I
M9B`H)&-H86YN96P@(3T]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LG7U]C
M:&%N;F5L<R==6R1C:&%N;F5L75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@
M("!U;G-E="@D=&AI<RT^8V]N9FEG=7)A=&EO;ELD;&%Y97)=6R=?7V-H86YN
M96QS)UU;)&-H86YN96Q=6R1K97E=*3L-"B`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R75LD:V5Y72DI
M('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L
M87EE<EU;)&ME>5TI.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!R96UO=F5,87EE<BAL87EE<BD-"@T*("`@("\J
M*@T*("`@("`J(%1E;7!O<F%R:6QY(')E;6]V92!A;B!E;G1I<F4@8V]N9FEG
M(&QA>65R+B`@55-%(%=)5$@@0T%212$-"B`@("`@*@T*("`@("`J($!P87)A
M;2!S=')I;F<@8V]N9FEG(&ME>0T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`H;W!T:6]N86PI(&-O;F9I9R!L87EE<@T*("`@("`J#0H@("`@("H@
M0')E='5R;B!B;V]L(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R
M90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!R96UO=F5,87EE<B@D;&%Y97(I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F-O;F9I9W5R871I;VY;)&QA>65R72DI('L-
M"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ET@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M("`@("\O('M[>R!S=&]R92A;;&%Y97)=*0T*#0H@("`@+RHJ#0H@("`@("H@
M4W1O<F5S(&-O;F9I9W5R871I;VX@9&%T82!I;B!A(&QA>65R+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@;&%Y97(@=&\@<W1O<F4-
M"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O;"!44E5%(&]N('-U8V-E<W,L
M(&]R(%!%05(@97)R;W(@;VX@9F%I;'5R90T*("`@("`J#0H@("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&]R92@D;&%Y
M97(@/2`G=7-E<B<L("1D871A(#T@;G5L;"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^=W)I=&5#;VYF:6=&:6QE*&YU;&PL("1L87EE<BP@)&1A
M=&$I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!T;T1E9F%U
M;'0H:V5Y*0T*#0H@("`@+RHJ#0H@("`@("H@56YS970@=&AE('5S97(M9&5F
M:6YE9"!V86QU92!O9B!A(&-O;F9I9R!K97DL(')E=F5R=&EN9R!T:&4-"B`@
M("`@*B!V86QU92!T;R!T:&4@<WES=&5M+61E9FEN960@;VYE+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!C;VYF:6<@:V5Y#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F
M86EL=7)E#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N('1O1&5F875L="@D:V5Y*0T*("`@('L-"B`@("`@
M("`@=')I9V=E<E]E<G)O<B@B4$5!4E]#;VYF:6<Z.G1O1&5F875L="@I(&1E
M<')E8V%T960L('5S92!014%27T-O;F9I9SHZ<F5M;W9E*"D@:6YS=&5A9"(L
M($5?55-%4E].3U1)0T4I.PT*("`@("`@("!R971U<FX@)'1H:7,M/G)E;6]V
M92@D:V5Y+"`G=7-E<B<I.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D969I;F5D0GDH:V5Y*0T*#0H@("`@+RHJ#0H@("`@("H@5&5L;',@
M=VAA="!C;VYF:6<@;&%Y97(@=&AA="!G971S('1O(&1E9FEN92!A(&ME>2X-
M"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@8V]N9FEG(&ME>0T*("`@
M("`J($!P87)A;2!B;V]L96%N(')E='5R;B!T:&4@9&5F:6YI;F<@8VAA;FYE
M;`T*("`@("`J#0H@("`@("H@0')E='5R;B!S=')I;F=\87)R87D@=&AE(&-O
M;F9I9R!L87EE<BP@;W(@86X@96UP='D@<W1R:6YG(&EF(&YO="!F;W5N9"X-
M"B`@("`@*@T*("`@("`J("`@("`@("`@:68@)')E='5R;F-H86YN96PL('1H
M92!R971U<FX@:7,@86X@87)R87D@87)R87DH)VQA>65R)R`]/B!L87EE<FYA
M;64L#0H@("`@("H@("`@("`@("`G8VAA;FYE;"<@/3X@8VAA;FYE;&YA;64I
M+"!O<B!A;B!E;7!T>2!S=')I;F<@:68@;F]T(&9O=6YD#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&1E
M9FEN961">2@D:V5Y+"`D<F5T=7)N8VAA;FYE;"`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FQA>65R<R!A<R`D;&%Y97(I('L-
M"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'1H:7,M/F=E=$1E9F%U;'1#:&%N
M;F5L*"D[#0H@("`@("`@("`@("!I9B`H)&-H86YN96P@(3T]("=P96%R+G!H
M<"YN970G*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC
M;VYF:6=U<F%T:6]N6R1L87EE<EU;)U]?8VAA;FYE;',G75LD8VAA;FYE;%U;
M)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D<F5T=7)N8VAA
M;FYE;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y
M*"=L87EE<B<@/3X@)&QA>65R+"`G8VAA;FYE;"<@/3X@)&-H86YN96PI.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D;&%Y97([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N
M6R1L87EE<EU;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@:68@*"1R971U
M<FYC:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@G;&%Y97(G(#T^("1L87EE<BP@)V-H86YN96PG(#T^("=P96%R+G!H<"YN
M970G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1L87EE<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)R<[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[
M(&ES1&5F875L=&5D*&ME>2D-"@T*("`@("\J*@T*("`@("`J(%1E;&QS('=H
M971H97(@82!C;VYF:6<@=F%L=64@:&%S(&$@<WES=&5M+61E9FEN960@=F%L
M=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("`@8V]N9FEG(&ME
M>0T*("`@("`J#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J#0H@("`@("H@0&1E<')E8V%T960-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I<T1E9F%U;'1E9"@D:V5Y*0T*("`@
M('L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B4$5!4E]#;VYF:6<Z.FES1&5F
M875L=&5D*"D@9&5P<F5C871E9"P@=7-E(%!%05)?0V]N9FEG.CID969I;F5D
M0GDH*2!I;G-T96%D(BP@15]54T527TY/5$E#12D[#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^9&5F:6YE9$)Y*"1K97DI(#T]("=S>7-T96TG.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I<T1E9FEN960H:V5Y*0T*#0H@
M("`@+RHJ#0H@("`@("H@5&5L;',@=VAE=&AE<B!A(&=I=F5N(&ME>2!E>&ES
M=',@87,@82!C;VYF:6<@=F%L=64N#0H@("`@("H-"B`@("`@*B!`<&%R86T@
M<W1R:6YG(&-O;F9I9R!K97D-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O
M;"!W:&5T:&5R(#QC;VYF:6<@:V5Y/B!E>&ES=',@:6X@=&AI<R!O8FIE8W0-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@:7-$969I;F5D*"1K97DI#0H@("`@>PT*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^;&%Y97)S(&%S("1L87EE<BD@>PT*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<EU;)&ME>5TI
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!I<T1E9FEN961,87EE<BAK97DI
M#0H-"B`@("`O*BH-"B`@("`@*B!496QL<R!W:&5T:&5R(&$@9VEV96X@8V]N
M9FEG(&QA>65R(&5X:7-T<RX-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I
M;F<@8V]N9FEG(&QA>65R#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@
M=VAE=&AE<B`\8V]N9FEG(&QA>65R/B!E>&ES=',@:6X@=&AI<R!O8FIE8W0-
M"B`@("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@:7-$969I;F5D3&%Y97(H)&QA>65R*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N(&ES<V5T*"1T:&ES+3YC;VYF:6=U<F%T:6]N6R1L87EE<ETI
M.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G971,87EE<G,H
M*0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N<R!T:&4@;&%Y97)S(&1E9FEN
M960@*&5X8V5P="!T:&4@)V1E9F%U;'0G(&]N92D-"B`@("`@*@T*("`@("`J
M($!R971U<FX@87)R87D@;V8@=&AE(&1E9FEN960@;&%Y97)S#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@9V5T3&%Y97)S*"D-"B`@("![#0H@("`@("`@("1C
M9B`]("1T:&ES+3YC;VYF:6=U<F%T:6]N.PT*("`@("`@("!U;G-E="@D8V9;
M)V1E9F%U;'0G72D[#0H@("`@("`@(')E='5R;B!A<G)A>5]K97ES*"1C9BD[
M#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&%P:59E<G-I;VXH
M*0T*("`@(&9U;F-T:6]N(&%P:59E<G-I;VXH*0T*("`@('L-"B`@("`@("`@
M<F5T=7)N("<Q+C$G.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\J*@T*
M("`@("`J($!R971U<FX@4$5!4E]296=I<W1R>0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N("9G971296=I<W1R>2@D=7-E(#T@;G5L;"D-"B`@("![#0H@("`@
M("`@(&EF("@D=7-E(#T]/2!N=6QL*2![#0H@("`@("`@("`@("`D;&%Y97(@
M/2`G=7-E<B<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D;&%Y
M97(@/2`D=7-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W)E9VES=')Y6R1L87EE<ETI*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/E]R96=I<W1R>5LD;&%Y97)=.PT*("`@("`@("!](&5L<V5I9B`H
M)'5S92`]/3T@;G5L;"`F)B!I<W-E="@D=&AI<RT^7W)E9VES=')Y6R=S>7-T
M96TG72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)E9VES=')Y
M6R=S>7-T96TG73L-"B`@("`@("`@?2!E;'-E:68@*"1U<V4@/3T](&YU;&P@
M)B8@:7-S970H)'1H:7,M/E]R96=I<W1R>5LG9&5F875L="==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5G:7-T<GE;)V1E9F%U;'0G73L-
M"B`@("`@("`@?2!E;'-E:68@*"1U<V4I('L-"B`@("`@("`@("`@("1A(#T@
M9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`O+R!O;FQY(&=O(&AE<F4@:68@;G5L;"!W87,@
M<&%S<V5D(&EN#0H@("`@("`@("`@("!D:64H(D-2251)0T%,($524D]2.B!2
M96=I<W1R>2!C;W5L9"!N;W0@8F4@:6YI=&EA;&EZ960@9G)O;2!A;GD@=F%L
M=64B*3L-"B`@("`@("`@?0T*("`@('T-"B`@("`O*BH-"B`@("`@*B!4:&ES
M(&ES('1O(&%L;&]W(&-U<W1O;6EZ871I;VX@;&EK92!T:&4@=7-E(&]F(&EN
M<W1A;&QR;V]T#0H@("`@("H@0'!A<F%M(%!%05)?4F5G:7-T<GD-"B`@("`@
M*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971296=I
M<W1R>2@F)')E9RP@)&QA>65R(#T@)W5S97(G*0T*("`@('L-"B`@("`@("`@
M:68@*"1T:&ES+3Y?;F]296=I<W1R>2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:6Y?87)R87DH)&QA
M>65R+"!A<G)A>2@G=7-E<B<L("=S>7-T96TG*2DI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y6R1L87EE<ET@/2`F)')E9SL-"B`@("`@("`@:68@*&ES7V]B:F5C
M="@D<F5G*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD;&%Y
M97)=+3YS971#;VYF:6<H)'1H:7,I.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&YO4F5G:7-T<GDH
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]N;U)E9VES=')Y(#T@=')U93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N(%!%05)?4F5M;W1E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%)E;6]T92@I#0H@("`@>PT*
M("`@("`@("`D<F5M;W1E(#T@)FYE=R!014%27U)E;6]T92@D=&AI<RD[#0H@
M("`@("`@(')E='5R;B`D<F5M;W1E.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!R971U<FX@4$5!4E]215-4#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M)F=E=%)%4U0H)'9E<G-I;VXL("1O<'1I;VYS(#T@87)R87DH*2D-"B`@("![
M#0H@("`@("`@("1V97)S:6]N(#T@<W1R7W)E<&QA8V4H)RXG+"`G)RP@)'9E
M<G-I;VXI.PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@D8VQA<W,@/2`G
M4$5!4E]215-47R<@+B`D=F5R<VEO;BDI('L-"B`@("`@("`@("`@(')E<75I
M<F5?;VYC92`G4$5!4B]215-4+R<@+B`D=F5R<VEO;B`N("<N<&AP)SL-"B`@
M("`@("`@?0T*("`@("`@("`D<F5M;W1E(#T@)FYE=R`D8VQA<W,H)'1H:7,L
M("1O<'1I;VYS*3L-"B`@("`@("`@<F5T=7)N("1R96UO=&4[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@5&AE(&9T<"!S97)V97(@:7,@<V5T(&EN('M`
M;&EN:R!R96%D1E100V]N9FEG1FEL92@I?2X@($ET(&5X:7-T<R!O;FQY(&EF
M(&$-"B`@("`@*B!R96UO=&4@8V]N9FEG=7)A=&EO;B!F:6QE(&AA<R!B965N
M('-P96-I9FEE9`T*("`@("`J($!R971U<FX@4$5!4E]&5%!\9F%L<V4-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B`F9V5T1E10*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7V9T<"DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V9T<#L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1A(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O+R![>WL@7W!R97!E;F10871H*"1P871H+"`D
M<')E<&5N9"D-"@T*("`@(&9U;F-T:6]N(%]P<F5P96YD4&%T:"@D<&%T:"P@
M)'!R97!E;F0I#0H@("`@>PT*("`@("`@("!I9B`H<W1R;&5N*"1P<F5P96YD
M*2`^(#`I('L-"B`@("`@("`@("`@(&EF("A/4U]724Y$3U=3("8F('!R96=?
M;6%T8V@H)R]>6V$M>ETZ+VDG+"`D<&%T:"DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H<')E9U]M871C:"@G+UY;82UZ73HO:2<L("1P<F5P96YD*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<')E<&5N9"`]('-U8G-T<B@D<')E<&5N
M9"P@,BD[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1P<F5P96YD>S!]
M("$]("=<7"<I('L-"B`@("`@("`@("`@("`@("`@("`@)'!R97!E;F0@/2`B
M7%PD<')E<&5N9"([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1P871H(#T@<W5B<W1R*"1P871H+"`P+"`R*2`N("1P<F5P96YD("X@
M<W5B<W1R*"1P871H+"`R*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@)'!A=&@@/2`D<')E<&5N9"`N("1P871H.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<&%T:#L-"B`@
M("!]#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&9A;'-E(&EN<W1A;&QA=&EO;B!D:7)E8W1O<GD@=&\@<')E<&5N9"!T
M;R!A;&P@7V1I<B!V87)I86)L97,L(&]R(&9A;'-E('1O#0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("!D:7-A8FQE#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T26YS=&%L;%)O;W0H)')O;W0I#0H@("`@>PT*("`@("`@("!I9B`H
M<W5B<W1R*"1R;V]T+"`M,2D@/3T@1$E214-43U)97U-%4$%2051/4BD@>PT*
M("`@("`@("`@("`@)')O;W0@/2!S=6)S='(H)')O;W0L(#`L("TQ*3L-"B`@
M("`@("`@?0T*("`@("`@("`D;VQD(#T@)'1H:7,M/E]I;G-T86QL4F]O=#L-
M"B`@("`@("`@)'1H:7,M/E]I;G-T86QL4F]O="`]("1R;V]T.PT*("`@("`@
M("!I9B`H*"1O;&0@(3T@)')O;W0I("8F("$D=&AI<RT^7VYO4F5G:7-T<GDI
M('L-"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H:7,M/E]R
M96=I<W1R>2D@87,@)&QA>65R*2![#0H@("`@("`@("`@("`@("`@:68@*"1L
M87EE<B`]/2`G9G1P)R!\?"`A:7-S970H)'1H:7,M/E]R96=I<W1R>5LD;&%Y
M97)=*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R
M>5LD;&%Y97)=(#T-"B`@("`@("`@("`@("`@("`@("`@)FYE=R!014%27U)E
M9VES=')Y*"1T:&ES+3YG970H)W!H<%]D:7(G+"`D;&%Y97(L("=P96%R+G!H
M<"YN970G*2D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>5LD
M;&%Y97)=+3YS971#;VYF:6<H)'1H:7,I.PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<F5G26YI=&EA;&EZ961;)&QA>65R72`](&9A;'-E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*?0T*#0H_/@T*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+T1E<&5N9&5N8WDN<&AP````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0S,C(R(#$P-3$U-#,T,3,T(#`R,C`P
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+R\-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@
M?"!02%`@5F5R<VEO;B`U("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#0@
M5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`T*+R\@?"!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!U<FPZ("`@("`@("`@("!\#0HO+R!\
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N
M;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M#0HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!4;VUA<R!6+E8N
M0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R!\("`@("`@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\-"B\O(%1(25,@1DE,12!)
M4R!$15!214-!5$5$($E.($9!5D]2($]&($1%4$5.1$5.0UDR+E!(4"P@04Y$
M($E3($Y/5"!54T5$($E.(%1(12!)3E-404Q,15(-"B\O("1)9#H@1&5P96YD
M96YC>2YP:'`L=B`Q+C0Q(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X
M<"`D#0H-"G)E<75I<F5?;VYC92`B4$5!4BYP:'`B.PT*<F5Q=6ER95]O;F-E
M(")/4R]'=65S<RYP:'`B.PT*#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]-
M25-324Y')RP@("`@("`@("TQ*3L-"F1E9FEN92@G4$5!4E]$15!%3D1%3D-9
M7T-/3D9,24-4)RP@("`@("`@+3(I.PT*9&5F:6YE*"=014%27T1%4$5.1$5.
M0UE?55!'4D%$15]-24Y/4B<L("`M,RD[#0ID969I;F4H)U!%05)?1$5014Y$
M14Y#65]54$=2041%7TU!2D]2)RP@("TT*3L-"F1E9FEN92@G4$5!4E]$15!%
M3D1%3D-97T)!1%]$15!%3D1%3D-9)RP@+34I.PT*9&5F:6YE*"=014%27T1%
M4$5.1$5.0UE?34E34TE.1U]/4%1)3TY!3"<L("TV*3L-"F1E9FEN92@G4$5!
M4E]$15!%3D1%3D-97T-/3D9,24-47T]05$E/3D%,)RP@("`@("`@+3<I.PT*
M9&5F:6YE*"=014%27T1%4$5.1$5.0UE?55!'4D%$15]-24Y/4E]/4%1)3TY!
M3"<L("`M."D[#0ID969I;F4H)U!%05)?1$5014Y$14Y#65]54$=2041%7TU!
M2D]27T]05$E/3D%,)RP@("TY*3L-"@T*+RHJ#0H@*B!$97!E;F1E;F-Y(&-H
M96-K(&9O<B!014%2('!A8VMA9V5S#0H@*@T*("H@5&AE(&-L87-S(&ES(&)A
M<V5D(&]N('1H92!D97!E;F1E;F-Y(%)&0R!T:&%T(&-A;B!B92!F;W5N9"!A
M=`T*("H@:'1T<#HO+V-V<RYP:'`N;F5T+V-V<RYP:'`O<&5A<G=E8B]R9F,N
M($ET(')E<75I<F5S(%!(4"`^/2`T+C$-"B`J#0H@*B!`875T:&]R(%1O;6%S
M(%8N5BY6;W@@/&-O>$!I9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@4W1I9R!"
M86MK96X@/'-S8D!P:'`N;F5T/@T*("HO#0IC;&%S<R!014%27T1E<&5N9&5N
M8WD-"GL-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"B`@("`O*BH-"B`@("`@
M*B!#;VYS=')U8W1O<@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-
M"B`@("`@*B!`<&%R86T@(&]B:F5C="!296=I<W1R>2!O8FIE8W0-"B`@("`@
M*B!`<F5T=7)N('9O:60-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27T1E
M<&5N9&5N8WDH)B1R96=I<W1R>2D-"B`@("![#0H@("`@("`@("1T:&ES+3YR
M96=I<W1R>2`]("8D<F5G:7-T<GD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&-A;&Q#:&5C:TUE=&AO9"@I#0H-"B`@("`O*BH-"B`@("`J
M(%1H:7,@;65T:&]D(&UA<',@=&AE(%A-3"!D97!E;F1E;F-Y(&1E9FEN:71I
M;VX@=&\@=&AE#0H@("`@*B!C;W)R97-P;VYD:6YG(&]N92!F<F]M(%!%05)?
M1&5P96YD96YC>0T*("`@("H-"B`@("`J(#QP<F4^#0H@("`@*B`D;W!T<R`]
M/B!!<G)A>0T*("`@("H@("`@*`T*("`@("H@("`@("`@(%MT>7!E72`]/B!P
M:V<-"B`@("`J("`@("`@("!;<F5L72`]/B!G90T*("`@("H@("`@("`@(%MV
M97)S:6]N72`]/B`S+C0-"B`@("`J("`@("`@("!;;F%M95T@/3X@2%1-3%]#
M;VUM;VX-"B`@("`J("`@("`@("!;;W!T:6]N86Q=(#T^(&9A;'-E#0H@("`@
M*B`@("`I#0H@("`@*B`\+W!R93X-"B`@("`J#0H@("`@*B!`<&%R86T@('-T
M<FEN9R!%<G)O<B!M97-S86=E#0H@("`@*B!`<&%R86T@(&%R<F%Y("!/<'1I
M;VYS#0H@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(&-A;&Q#:&5C:TUE=&AO9"@F)&5R<FUS9RP@)&]P=',I#0H@("`@>PT*
M("`@("`@("`D<F5L(#T@:7-S970H)&]P='-;)W)E;"==*2`_("1O<'1S6R=R
M96PG72`Z("=H87,G.PT*("`@("`@("`D<F5Q(#T@:7-S970H)&]P='-;)W9E
M<G-I;VXG72D@/R`D;W!T<ULG=F5R<VEO;B==(#H@;G5L;#L-"B`@("`@("`@
M)&YA;64@/2!I<W-E="@D;W!T<ULG;F%M92==*2`_("1O<'1S6R=N86UE)UT@
M.B!N=6QL.PT*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O<'1S6R=C:&%N
M;F5L)UTI(#\@)&]P='-;)V-H86YN96PG72`Z("=P96%R+G!H<"YN970G.PT*
M("`@("`@("`D;W!T(#T@*&ES<V5T*"1O<'1S6R=O<'1I;VYA;"==*2`F)B`D
M;W!T<ULG;W!T:6]N86PG72`]/2`G>65S)RD@/PT*("`@("`@("`@("`@)&]P
M='-;)V]P=&EO;F%L)UT@.B!N=6QL.PT*("`@("`@("`D97)R;7-G(#T@)R<[
M#0H@("`@("`@('-W:71C:"`H)&]P='-;)W1Y<&4G72D@>PT*("`@("`@("`@
M("`@8V%S92`G<&MG)SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F-H96-K4&%C:V%G92@D97)R;7-G+"`D;F%M92P@)')E<2P@)')E;"P@)&]P
M="P@)&-H86YN96PI.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G97AT)SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/F-H96-K17AT96YS:6]N*"1E<G)M<V<L("1N86UE+"`D<F5Q+"`D<F5L
M+"`D;W!T*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@
M(&-A<V4@)W!H<"<Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC
M:&5C:U!(4"@D97)R;7-G+"`D<F5Q+"`D<F5L*3L-"B`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W!R;V<G.@T*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^8VAE8VM0<F]G<F%M*"1E<G)M<V<L("1N
M86UE*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@)V]S)SH-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-H96-K
M3U,H)&5R<FUS9RP@)&YA;64I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@8V%S92`G<V%P:2<Z#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YC:&5C:U-!4$DH)&5R<FUS9RP@)&YA;64I.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G>F5N9"<Z#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YC:&5C:UIE;F0H)&5R<FUS
M9RP@)&YA;64I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("!R971U<FX@(B=[)&]P='-;
M)W1Y<&4G77TG(&1E<&5N9&5N8WD@='EP92!N;W0@<W5P<&]R=&5D(CL-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C:&5C
M:U!A8VMA9V4H*0T*#0H@("`@+RHJ#0H@("`@("H@4&%C:V%G92!D97!E;F1E
M;F-I97,@8VAE8VL@;65T:&]D#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1E<G)M<V<@("`@16UP='D@<W1R:6YG+"!I="!W:6QL(&)E('!O<'5L
M871E9"!W:71H(&%N(&5R<F]R(&UE<W-A9V4L(&EF(&%N>0T*("`@("`J($!P
M87)A;2!S=')I;F<@)&YA;64@("`@("!.86UE(&]F('1H92!P86-K86=E('1O
M('1E<W0-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R97$@("`@("`@5&AE('!A
M8VMA9V4@=F5R<VEO;B!R97%U:7)E9`T*("`@("`J($!P87)A;2!S=')I;F<@
M)')E;&%T:6]N("!(;W<@=&\@8V]M<&%R92!V97)S:6]N<R!W:71H(&5A8V@@
M;W1H97(-"B`@("`@*B!`<&%R86T@8F]O;"`@("1O<'0@("`@("`@5VAE=&AE
M<B!T:&4@<F5L871I;VYS:&EP(&ES(&]P=&EO;F%L#0H@("`@("H@0'!A<F%M
M('-T<FEN9R`D8VAA;FYE;"`@($-H86YN96P@;F%M90T*("`@("`J#0H@("`@
M("H@0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R('1H
M92!E<G)O<B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C:&5C:U!A
M8VMA9V4H)B1E<G)M<V<L("1N86UE+"`D<F5Q(#T@;G5L;"P@)')E;&%T:6]N
M(#T@)VAA<R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'0@/2!F
M86QS92P@)&-H86YN96P@/2`G<&5A<BYP:'`N;F5T)RD-"B`@("![#0H@("`@
M("`@(&EF("AI<U]S=')I;F<H)')E<2D@)B8@<W5B<W1R*"1R97$L(#`L(#(I
M(#T]("=V+B<I('L-"B`@("`@("`@("`@("1R97$@/2!S=6)S='(H)')E<2P@
M,BD[#0H@("`@("`@('T-"B`@("`@("`@<W=I=&-H("@D<F5L871I;VXI('L-
M"B`@("`@("`@("`@(&-A<V4@)VAA<R<Z#0H@("`@("`@("`@("`@("`@:68@
M*"$D=&AI<RT^<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)&YA;64L("1C:&%N
M;F5L*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&]P="D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<FUS9R`](")P86-K86=E(&`D8VAA
M;FYE;"\D;F%M92<@:7,@<F5C;VUM96YD960@=&\@=71I;&EZ92!S;VUE(&9E
M871U<F5S+B([#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!
M4E]$15!%3D1%3D-97TU)4U-)3D=?3U!424].04P[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&5R<FUS9R`](")R97%U
M:7)E<R!P86-K86=E(&`D8VAA;FYE;"\D;F%M92<B.PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%3D-97TU)4U-)3D<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@("`@(&-A<V4@)VYO="<Z#0H@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YR96=I<W1R>2T^<&%C:V%G945X:7-T<R@D;F%M92P@)&-H86YN
M96PI*2![#0H@("`@("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B8V]N9FQI
M8W1S('=I=&@@<&%C:V%G92!@)&-H86YN96PO)&YA;64G(CL-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5#L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("`@("`@8V%S92`G;'0G.@T*("`@("`@("`@("`@8V%S
M92`G;&4G.@T*("`@("`@("`@("`@8V%S92`G97$G.@T*("`@("`@("`@("`@
M8V%S92`G;F4G.@T*("`@("`@("`@("`@8V%S92`G9V4G.@T*("`@("`@("`@
M("`@8V%S92`G9W0G.@T*("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)'1H
M:7,M/G)E9VES=')Y+3YP86-K86=E26YF;R@D;F%M92P@)W9E<G-I;VXG+"`D
M8VAA;FYE;"D[#0H@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^<F5G:7-T
M<GDM/G!A8VMA9V5%>&ES=',H)&YA;64L("1C:&%N;F5L*0T*("`@("`@("`@
M("`@("`@("`@("!\?"`A=F5R<VEO;E]C;VUP87)E*"(D=F5R<VEO;B(L("(D
M<F5Q(BP@)')E;&%T:6]N*2D-"B`@("`@("`@("`@("`@("![#0H@("`@("`@
M("`@("`@("`@("`@("1C;V1E(#T@)'1H:7,M/F-O9&5&<F]M4F5L871I;VXH
M)')E;&%T:6]N+"`D=F5R<VEO;BP@)')E<2P@)&]P="D[#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D;W!T*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R;7-G(#T@(G!A8VMA9V4@8"1C:&%N;F5L+R1N86UE)R!V97)S:6]N
M("(@+B`D=&AI<RT^<VEG;D]P97)A=&]R*"1R96QA=&EO;BD@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("(@)')E<2!I<R!R96-O;6UE;F1E9"!T
M;R!U=&EL:7IE('-O;64@9F5A='5R97,N(CL-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D=F5R<VEO;BD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E<G)M<V<@+CT@(B`@26YS=&%L;&5D('9E<G-I;VX@:7,@)'9E
M<G-I;VXB.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1E<G)M<V<@/2`B<F5Q=6ER
M97,@<&%C:V%G92!@)&-H86YN96PO)&YA;64G("(@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G-I9VY/<&5R871O<B@D<F5L871I;VXI("X@
M(B`D<F5Q(CL-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@)&5R<FUS9R`](")R96QA=&EO;B`G
M)')E;&%T:6]N)R!W:71H(')E<75I<F5M96YT("<D<F5Q)R!I<R!N;W0@<W5P
M<&]R=&5D("AN86UE/21C:&%N;F5L+R1N86UE*2([#0H@("`@("`@(')E='5R
M;B!014%27T1%4$5.1$5.0UE?0D%$7T1%4$5.1$5.0UD[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&-H96-K4&%C:V%G955N:6YS=&%L;"@I
M#0H-"B`@("`O*BH-"B`@("`@*B!#:&5C:R!P86-K86=E(&1E<&5N9&5N8VEE
M<R!O;B!U;FEN<W1A;&P-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@
M)&5R<F]R("`@("!4:&4@<F5S=6QT86YT(&5R<F]R('-T<FEN9PT*("`@("`J
M($!P87)A;2!S=')I;F<@)'=A<FYI;F<@("!4:&4@<F5S=6QT86YT('=A<FYI
M;F<@<W1R:6YG#0H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@("`@($YA
M;64@;V8@=&AE('!A8VMA9V4@=&\@=&5S=`T*("`@("`J($!P87)A;2!S=')I
M;F<@)&-H86YN96P@("!#:&%N;F5L(&YA;64@;V8@=&AE('!A8VMA9V4-"B`@
M("`@*@T*("`@("`J($!R971U<FX@8F]O;"!T<G5E(&EF('1H97)E('=E<F4@
M97)R;W)S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VAE8VM086-K86=E56YI
M;G-T86QL*"8D97)R;W(L("8D=V%R;FEN9RP@)'!A8VMA9V4L("1C:&%N;F5L
M(#T@)W!E87(N<&AP+FYE="<I#0H@("`@>PT*("`@("`@("`D8VAA;FYE;"`]
M('-T<G1O;&]W97(H)&-H86YN96PI.PT*("`@("`@("`D97)R;W(@/2!N=6QL
M.PT*("`@("`@("`D8VAA;FYE;',@/2`D=&AI<RT^<F5G:7-T<GDM/FQI<W1!
M;&Q086-K86=E<R@I.PT*("`@("`@("!F;W)E86-H("@D8VAA;FYE;',@87,@
M)&-H86YN96QN86UE(#T^("1P86-K86=E<RD@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)'!A8VMA9V5S(&%S("1P:V<I('L-"B`@("`@("`@("`@("`@("!I
M9B`H)'!K9R`]/2`D<&%C:V%G92`F)B`D8VAA;FYE;"`]/2`D8VAA;FYE;&YA
M;64I('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1D97!S(#T@)'1H:7,M/G)E
M9VES=')Y+3YP86-K86=E26YF;R@D<&MG+"`G<F5L96%S95]D97!S)RP@)&-H
M86YN96PI.PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D9&5P<RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1D97`I
M('L-"B`@("`@("`@("`@("`@("`@("`@)&1E<&-H86YN96P@/2!I<W-E="@D
M9&5P6R=C:&%N;F5L)UTI(#\@)&1E<%LG8VAA;FYE;"==(#H@)W!E87(N<&AP
M+FYE="<[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@
M/3T@)W!K9R<@)B8@*'-T<F-A<V5C;7`H)&1E<%LG;F%M92==+"`D<&%C:V%G
M92D@/3T@,"D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@*"1D97!C
M:&%N;F5L(#T]("1C:&%N;F5L*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1D97!;)W)E;"==(#T]("=N92<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=O<'1I;VYA;"==*2`F)B`D9&5P6R=O<'1I;VYA;"==(#T]("=Y97,G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=A<FYI;F<@+CT@(EQN
M5V%R;FEN9SH@4&%C:V%G92`G)&1E<&-H86YN96PO)'!K9R<@;W!T:6]N86QL
M>2!D97!E;F1S(&]N("<D8VAA;FYE;#HO<&%C:V%G92<B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97)R;W(@+CT@(E!A8VMA9V4@)R1D97!C:&%N;F5L+R1P:V<G
M(&1E<&5N9',@;VX@)R1C:&%N;F5L+R1P86-K86=E)UQN(CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@*"1E<G)O<BD@/R!T<G5E(#H@9F%L<V4[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&-H96-K17AT96YS:6]N*"D-"@T*
M("`@("\J*@T*("`@("`J($5X=&5N<VEO;B!D97!E;F1E;F-I97,@8VAE8VL@
M;65T:&]D#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@
M("`@("!.86UE(&]F('1H92!E>'1E;G-I;VX@=&\@=&5S=`T*("`@("`J($!P
M87)A;2!S=')I;F<@)')E<5]E>'1?=F5R(%)E<75I<F5D(&5X=&5N<VEO;B!V
M97)S:6]N('1O(&-O;7!A<F4@=VET:`T*("`@("`J($!P87)A;2!S=')I;F<@
M)')E;&%T:6]N("`@($AO=R!T;R!C;VUP87)E('9E<G-I;VYS('=I=&@@96%C
M:&]T:&5R#0H@("`@("H@0'!A<F%M(&)O;VP@("`D;W!T("`@("`@("`@5VAE
M=&AE<B!T:&4@<F5L871I;VYS:&EP(&ES(&]P=&EO;F%L#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R;W(@;W(@
M=&AE(&5R<F]R('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&-H96-K
M17AT96YS:6]N*"8D97)R;7-G+"`D;F%M92P@)')E<2`](&YU;&PL("1R96QA
M=&EO;B`]("=H87,G+`T*("`@("`@("`D;W!T(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("!I9B`H)')E;&%T:6]N(#T]("=N;W0G*2![#0H@("`@("`@("`@
M("!I9B`H97AT96YS:6]N7VQO861E9"@D;F%M92DI('L-"B`@("`@("`@("`@
M("`@("`D97)R;7-G(#T@(F-O;F9L:6-T<R!W:71H("!02%`@97AT96YS:6]N
M("<D;F%M92<B.PT*("`@("`@("`@("`@("`@(')E='5R;B!014%27T1%4$5.
M1$5.0UE?0T].1DQ)0U0[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*#0H@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@D;F%M92DI
M('L-"B`@("`@("`@("`@(&EF("@D<F5L871I;VX@/3T@)VYE)RD@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D;W!T*2![#0H@("`@("`@("`@("`@("`@)&5R<FUS
M9R`]("(G)&YA;64G(%!(4"!E>'1E;G-I;VX@:7,@<F5C;VUM96YD960@=&\@
M=71I;&EZ92!S;VUE(&9E871U<F5S(CL-"B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4E]$15!%3D1%3D-97TU)4U-)3D=?3U!424].04P[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D97)R;7-G(#T@(B<D;F%M92<@4$A0(&5X
M=&5N<VEO;B!I<R!N;W0@:6YS=&%L;&5D(CL-"B`@("`@("`@("`@(')E='5R
M;B!014%27T1%4$5.1$5.0UE?34E34TE.1SL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)')E;&%T:6]N(#T]("=H87,G*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&-O9&4@/2!F86QS93L-
M"B`@("`@("`@:68@*&ES7W-T<FEN9R@D<F5Q*2`F)B!S=6)S='(H)')E<2P@
M,"P@,BD@/3T@)W8N)RD@>PT*("`@("`@("`@("`@)')E<2`]('-U8G-T<B@D
M<F5Q+"`R*3L-"B`@("`@("`@?0T*("`@("`@("`D97AT7W9E<B`]('!H<'9E
M<G-I;VXH)&YA;64I.PT*("`@("`@("`D;W!E<F%T;W(@/2`D<F5L871I;VX[
M#0H@("`@("`@("\O($9O<F-E('!A<F%M<R!T;R!B92!S=')I;F=S+"!O=&AE
M<G=I<V4@=&AE(&-O;7!A<F%T:6]N('=I;&P@9F%I;"`H97@N(#`N.3T],"XY
M,"D-"B`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H(B1E>'1?=F5R(BP@
M(B1R97$B+"`D;W!E<F%T;W(I*2![#0H@("`@("`@("`@("`D97)R;7-G(#T@
M(B<D;F%M92<@4$A0(&5X=&5N<VEO;B!V97)S:6]N("(@+@T*("`@("`@("`@
M("`@("`@("1T:&ES+3YS:6=N3W!E<F%T;W(H)&]P97)A=&]R*2`N("(@)')E
M<2!I<R!R97%U:7)E9"([#0H@("`@("`@("`@("`D8V]D92`]("1T:&ES+3YC
M;V1E1G)O;5)E;&%T:6]N*"1R96QA=&EO;BP@)&5X=%]V97(L("1R97$L("1O
M<'0I.PT*("`@("`@("`@("`@:68@*"1O<'0I('L-"B`@("`@("`@("`@("`@
M("`D97)R;7-G(#T@(B<D;F%M92<@4$A0(&5X=&5N<VEO;B!V97)S:6]N("(@
M+B`D=&AI<RT^<VEG;D]P97)A=&]R*"1O<&5R871O<BD@+@T*("`@("`@("`@
M("`@("`@("`@("`B("1R97$@:7,@<F5C;VUM96YD960@=&\@=71I;&EZ92!S
M;VUE(&9E871U<F5S(CL-"B`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1C
M;V1E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C:&5C:T]3
M*"D-"@T*("`@("\J*@T*("`@("`J($]P97)A=&EN9R!S>7-T96T@(&1E<&5N
M9&5N8VEE<R!C:&5C:R!M971H;V0-"B`@("`@*@T*("`@("`J($!P87)A;2!S
M=')I;F<@)&]S("!.86UE(&]F('1H92!O<&5R871I;F<@<WES=&5M#0H@("`@
M("H-"B`@("`@*B!`<F5T=7)N(&UI>&5D(&)O;VP@9F%L<V4@:68@;F\@97)R
M;W(@;W(@=&AE(&5R<F]R('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&-H96-K3U,H)B1E<G)M<V<L("1O<RD-"B`@("![#0H@("`@("`@("\O(%A8
M6"!&:7AM93H@26UP;&5M96YT(&$@;6]R92!F;&5X:6)L92!W87DL(&QI:V4-
M"B`@("`@("`@+R\@8V]M;6$@<V5P87)A=&5D('9A;'5E<R!O<B!S;VUE=&AI
M;F<@<VEM:6QA<B!T;R!014%27T]3#0H@("`@("`@('-T871I8R`D;7EO<SL-
M"B`@("`@("`@:68@*&5M<'1Y*"1M>6]S*2D@>PT*("`@("`@("`@("`@)&UY
M;W,@/2!N97<@3U-?1W5E<W,H*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!O
M;FQY("=H87,G(')E;&%T:6]N(&ES(&-U<G)E;G1L>2!S=7!P;W)T960-"B`@
M("`@("`@:68@*"1M>6]S+3YM871C:%-I9VYA='5R92@D;W,I*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&5R
M<FUS9R`]("(G)&]S)R!O<&5R871I;F<@<WES=&5M(&YO="!S=7!P;W)T960B
M.PT*("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%3D-97T-/3D9,24-4.PT*
M("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C:&5C:U!(4"@I#0H-
M"B`@("`O*BH-"B`@("`@*B!02%`@=F5R<VEO;B!C:&5C:R!M971H;V0-"B`@
M("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)')E<2`@('=H:6-H('9E<G-I
M;VX@=&\@8V]M<&%R90T*("`@("`J($!P87)A;2!S=')I;F<@)')E;&%T:6]N
M("!H;W<@=&\@8V]M<&%R92!T:&4@=F5R<VEO;@T*("`@("`J#0H@("`@("H@
M0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R('1H92!E
M<G)O<B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C:&5C:U!(4"@F
M)&5R<FUS9RP@)')E<2P@)')E;&%T:6]N(#T@)V=E)RD-"B`@("![#0H@("`@
M("`@("\O('1H:7,@=V]U;&0@8F4@82!B:70@<W1U<&ED+"!B=70@;V@@=V5L
M;"`Z*0T*("`@("`@("!I9B`H)')E;&%T:6]N(#T]("=H87,G*2![#0H@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1R96QA=&EO;B`]/2`G;F]T)RD@>PT*("`@("`@("`@("`@)&5R<FUS9R`]
M("));G9A;&ED(&1E<&5N9&5N8WD@+2`G;F]T)R!I<R!A;&QO=V5D('=H96X@
M<W!E8VEF>6EN9R!02%`L('EO=2!M=7-T(')U;B!02%`@:6X@4$A0(CL-"B`@
M("`@("`@("`@(')E='5R;B!014%27T1%4$5.1$5.0UE?0D%$7T1%4$5.1$5.
M0UD[#0H@("`@("`@('T-"B`@("`@("`@:68@*'-U8G-T<B@D<F5Q+"`P+"`R
M*2`]/2`G=BXG*2![#0H@("`@("`@("`@("`D<F5Q(#T@<W5B<W1R*"1R97$L
M,BP@<W1R;&5N*"1R97$I("T@,BD[#0H@("`@("`@('T-"B`@("`@("`@)'!H
M<%]V97(@/2!P:'!V97)S:6]N*"D[#0H@("`@("`@("1O<&5R871O<B`]("1R
M96QA=&EO;CL-"B`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H(B1P:'!?
M=F5R(BP@(B1R97$B+"`D;W!E<F%T;W(I*2![#0H@("`@("`@("`@("`D97)R
M;7-G(#T@(E!(4"!V97)S:6]N("(@+B`D=&AI<RT^<VEG;D]P97)A=&]R*"1O
M<&5R871O<BD@+@T*("`@("`@("`@("`@("`@("(@)')E<2!I<R!R97%U:7)E
M9"([#0H@("`@("`@("`@("!R971U<FX@4$5!4E]$15!%3D1%3D-97T-/3D9,
M24-4.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE8VM0<F]G<F%M*"D-"@T*
M("`@("\J*@T*("`@("`J($5X=&5R;F%L('!R;V=R86T@8VAE8VL@;65T:&]D
M+B`@3&]O:W,@9F]R(&5X96-U=&%B;&4@9FEL97,@:6X-"B`@("`@*B!D:7)E
M8W1O<FEE<R!L:7-T960@:6X@=&AE(%!!5$@@96YV:7)O;FUE;G0@=F%R:6%B
M;&4N#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<F]G<F%M("`@
M=VAI8V@@<')O9W)A;2!T;R!L;V]K(&9O<@T*("`@("`J#0H@("`@("H@0')E
M='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R<F]R(&]R('1H92!E<G)O
M<B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!C:&5C:U!R;V=R86TH
M)B1E<G)M<V<L("1P<F]G<F%M*0T*("`@('L-"B`@("`@("`@+R\@6%A8($9)
M6$U%(&AO;F]R('-A9F4@;6]D90T*("`@("`@("`D97AE7W-U9F9I>"`]($]3
M7U=)3D1/5U,@/R`G+F5X92<@.B`G)SL-"B`@("`@("`@)'!A=&A?96QE;65N
M=',@/2!E>'!L;V1E*%!!5$A?4T5005)!5$]2+"!G971E;G8H)U!!5$@G*2D[
M#0H@("`@("`@(&9O<F5A8V@@*"1P871H7V5L96UE;G1S(&%S("1D:7(I('L-
M"B`@("`@("`@("`@("1F:6QE(#T@)&1I<B`N($1)4D5#5$]265]315!!4D%4
M3U(@+B`D<')O9W)A;2`N("1E>&5?<W5F9FEX.PT*("`@("`@("`@("`@:68@
M*$!F:6QE7V5X:7-T<R@D9FEL92D@)B8@0&ES7V5X96-U=&%B;&4H)&9I;&4I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1E<G)M<V<@/2`B)R1P<F]G<F%M
M)R!P<F]G<F%M(&ES(&YO="!P<F5S96YT(&EN('1H92!0051((CL-"B`@("`@
M("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]-25-324Y'.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!C:&5C:U-!4$DH*0T*#0H@("`@+RHJ
M#0H@("`@("H@4T%022!B86-K96YD(&-H96-K(&UE=&AO9"X@(%9E<G-I;VX@
M8V]M<&%R:7-O;B!I<R!N;W0@>65T#0H@("`@("H@879A:6QA8FQE(&AE<F4N
M#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@;F%M
M92!O9B!305!)(&)A8VME;F0-"B`@("`@*B!`<&%R86T@<W1R:6YG("1R97$@
M("!W:&EC:"!V97)S:6]N('1O(&-O;7!A<F4-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1R96QA=&EO;B`@:&]W('1O(&-O;7!A<F4@=F5R<VEO;G,@*&-U<G)E
M;G1L>0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!H87)D8V]D
M960@=&\@)VAA<R<I#0H@("`@("H@0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E
M(&EF(&YO(&5R<F]R(&]R('1H92!E<G)O<B!S=')I;F<-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!C:&5C:U-!4$DH)B1E<G)M<V<L("1N86UE+"`D<F5Q(#T@
M;G5L;"P@)')E;&%T:6]N(#T@)VAA<R<I#0H@("`@>PT*("`@("`@("`O+R!8
M6%@@1FEX;64Z(%1H97)E(&ES(&YO('=A>2!T;R!K;F]W(&EF('1H92!U<V5R
M(&AA<R!O<@T*("`@("`@("`O+R!N;W0@;W1H97(@4T%022!B86-K96YD<R!I
M;G-T86QL960@=&AA;B!T:&4@:6YS=&%L;&5R(&]N90T*#0H@("`@("`@("1S
M87!I7V)A8VME;F0@/2!P:'!?<V%P:5]N86UE*"D[#0H@("`@("`@("\O(%9E
M<G-I;VX@8V]M<&%R:7-O;G,@;F]T('-U<'!O<G1E9"P@<V%P:2!B86-K96YD
M<R!D;VXG="!H879E#0H@("`@("`@("\O('9E<G-I;VX@:6YF;W)M871I;VX@
M>65T+@T*("`@("`@("!I9B`H)'-A<&E?8F%C:V5N9"`]/2`D;F%M92D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M("1E<G)M<V<@/2`B)R1S87!I7V)A8VME;F0G(%-!4$D@8F%C:V5N9"!N;W0@
M<W5P<&]R=&5D(CL-"B`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$14Y#65]#
M3TY&3$E#5#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8VAE
M8VM:96YD*"D-"@T*("`@("\J*@T*("`@("`J(%IE;F0@=F5R<VEO;B!C:&5C
M:R!M971H;V0-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)')E<2`@
M('=H:6-H('9E<G-I;VX@=&\@8V]M<&%R90T*("`@("`J($!P87)A;2!S=')I
M;F<@)')E;&%T:6]N("!H;W<@=&\@8V]M<&%R92!T:&4@=F5R<VEO;@T*("`@
M("`J#0H@("`@("H@0')E='5R;B!M:7AE9"!B;V]L(&9A;'-E(&EF(&YO(&5R
M<F]R(&]R('1H92!E<G)O<B!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!C:&5C:UIE;F0H)B1E<G)M<V<L("1R97$L("1R96QA=&EO;B`]("=G92<I
M#0H@("`@>PT*("`@("`@("!I9B`H<W5B<W1R*"1R97$L(#`L(#(I(#T]("=V
M+B<I('L-"B`@("`@("`@("`@("1R97$@/2!S=6)S='(H)')E<2PR+"!S=')L
M96XH)')E<2D@+2`R*3L-"B`@("`@("`@?0T*("`@("`@("`D>F5N9%]V97(@
M/2!Z96YD7W9E<G-I;VXH*3L-"B`@("`@("`@)&]P97)A=&]R(#T@<W5B<W1R
M*"1R96QA=&EO;BPP+#(I.PT*("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R
M92@B)'IE;F1?=F5R(BP@(B1R97$B+"`D;W!E<F%T;W(I*2![#0H@("`@("`@
M("`@("`D97)R;7-G(#T@(EIE;F0@=F5R<VEO;B`B("X@)'1H:7,M/G-I9VY/
M<&5R871O<B@D;W!E<F%T;W(I("X-"B`@("`@("`@("`@("`@("`B("1R97$@
M:7,@<F5Q=6ER960B.PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?1$5014Y$
M14Y#65]#3TY&3$E#5#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[('-I9VY/<&5R
M871O<B@I#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T<R!T97AT(&-O;7!A
M<FEN9R!O<&5R871O<G,@=&\@=&AE;2!S:6=N(&5Q=6EV86QE;G1S#0H@("`@
M("H-"B`@("`@*B!%>&%M<&QE.B`G9V4G('1O("<^/2<-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'!A<F%M("!S=')I;F<@3W!E
M<F%T;W(-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!3:6=N(&5Q=6EV86QE;G0-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S:6=N3W!E<F%T;W(H)&]P97)A=&]R
M*0T*("`@('L-"B`@("`@("`@<W=I=&-H*"1O<&5R871O<BD@>PT*("`@("`@
M("`@("`@8V%S92`G;'0G.B!R971U<FX@)SPG.PT*("`@("`@("`@("`@8V%S
M92`G;&4G.B!R971U<FX@)SP])SL-"B`@("`@("`@("`@(&-A<V4@)V=T)SH@
M<F5T=7)N("<^)SL-"B`@("`@("`@("`@(&-A<V4@)V=E)SH@<F5T=7)N("<^
M/2<[#0H@("`@("`@("`@("!C87-E("=E<2<Z(')E='5R;B`G/3TG.PT*("`@
M("`@("`@("`@8V%S92`G;F4G.B!R971U<FX@)R$])SL-"B`@("`@("`@("`@
M(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@<F5T=7)N("1O<&5R871O<CL-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C
M;V1E1G)O;5)E;&%T:6]N*"D-"@T*("`@("\J*@T*("`@("`J($-O;G9E<G0@
M<F5L871I;VX@:6YT;R!C;W)R97-P;VYD:6YG(&-O9&4-"B`@("`@*@T*("`@
M("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("H@0'!A<F%M("!S=')I;F<@4F5L
M871I;VX-"B`@("`@*B!`<&%R86T@('-T<FEN9R!697)S:6]N#0H@("`@("H@
M0'!A<F%M("!S=')I;F<@4F5Q=6ER96UE;G0-"B`@("`@*B!`<&%R86T@(&)O
M;VP@("!/<'1I;VYA;"!D97!E;F1E;F-Y(&EN9&EC871O<@T*("`@("`J($!R
M971U<FX@:6YT96=E<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&-O9&5&<F]M
M4F5L871I;VXH)')E;&%T:6]N+"`D=F5R<VEO;BP@)')E<2P@)&]P="`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@)&-O9&4@/2!014%27T1%4$5.1$5.0UE?
M0D%$7T1%4$5.1$5.0UD[#0H@("`@("`@('-W:71C:"`H)')E;&%T:6]N*2![
M#0H@("`@("`@("`@("!C87-E("=G="<Z(&-A<V4@)V=E)SH@8V%S92`G97$G
M.@T*("`@("`@("`@("`@("`@("\O('5P9W)A9&4-"B`@("`@("`@("`@("`@
M("`D:&%V95]M86IO<B`]('!R96=?<F5P;&%C92@G+UQ$+BHO)RP@)R<L("1V
M97)S:6]N*3L-"B`@("`@("`@("`@("`@("`D;F5E9%]M86IO<B`]('!R96=?
M<F5P;&%C92@G+UQ$+BHO)RP@)R<L("1R97$I.PT*("`@("`@("`@("`@("`@
M(&EF("@D;F5E9%]M86IO<B`^("1H879E7VUA:F]R*2![#0H@("`@("`@("`@
M("`@("`@("`@("1C;V1E(#T@)&]P="`_(%!%05)?1$5014Y$14Y#65]54$=2
M041%7TU!2D]27T]05$E/3D%,(#H-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4E]$15!%3D1%3D-97U501U)!1$5?34%*3U([#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)&-O9&4@/2`D;W!T(#\@4$5!4E]$15!%3D1%3D-97U501U)!1$5?34E.3U)?
M3U!424].04P@.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%27T1%4$5.1$5.0UE?55!'4D%$15]-24Y/4CL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C
M87-E("=L="<Z(&-A<V4@)VQE)SH@8V%S92`G;F4G.@T*("`@("`@("`@("`@
M("`@("1C;V1E(#T@)&]P="`_(%!%05)?1$5014Y$14Y#65]#3TY&3$E#5%]/
M4%1)3TY!3"`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E]$15!%3D1%3D-97T-/3D9,24-4.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D8V]D93L-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"GT-"C\^#0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!%05(O1&5P96YD96YC>41"+G!H<```````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-38Q-C(@,3`U,34T,S0Q,S0@,#(R,C(P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP#0HO*BH-"B`J(%!%05)?1&5P96YD96YC>41"+"!A9'9A;F-E9"!I;G-T
M86QL960@<&%C:V%G97,@9&5P96YD96YC>2!D871A8F%S90T*("H-"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@
M;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-
M"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R
M>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@
M(%1O;6%S(%8N(%8N($-O>"`\8V]X0&ED96-N970N8V]M/@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($1E<&5N9&5N8WE$
M0BYP:'`L=B`Q+C,P(#(P,#8O,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!.965D960@9F]R(&5R<F]R
M(&AA;F1L:6YG#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4BYP:'`G.PT*<F5Q
M=6ER95]O;F-E("=014%2+T-O;F9I9RYP:'`G.PT*#0HO*BH-"B`J(%1R86-K
M(&1E<&5N9&5N8WD@<F5L871I;VYS:&EP<R!B971W965N(&EN<W1A;&QE9"!P
M86-K86=E<PT*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+D-O>"`\8V]X0&ED96,N
M;F5T+F-O;3X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R
M;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA
M8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27T1E
M<&5N9&5N8WE$0@T*>PT*("`@("\O('M[>R!P<F]P97)T:65S#0H-"B`@("`O
M*BH-"B`@("`@*B!4:&ES(&ES(&EN:71I86QI>F5D(&)Y('M`;&EN:R!S971#
M;VYF:6<H*7T-"B`@("`@*B!`=F%R(%!%05)?0V]N9FEG#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?8V]N9FEG.PT*("`@
M("\J*@T*("`@("`J(%1H:7,@:7,@:6YI=&EA;&EZ960@8GD@>T!L:6YK('-E
M=$-O;F9I9R@I?0T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W)E9VES=')Y
M.PT*("`@("\J*@T*("`@("`J($9I;&5N86UE(&]F('1H92!D97!E;F1E;F-Y
M($1"("AU<W5A;&QY("YD97!D8BD-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7V1E<&1B
M(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@1FEL92!N86UE(&]F('1H92!L
M;V-K9FEL92`H=7-U86QL>2`N9&5P9&)L;V-K*0T*("`@("`J($!V87(@<W1R
M:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R
M("1?;&]C:V9I;&4@/2!F86QS93L-"B`@("`O*BH-"B`@("`@*B!/<&5N(&9I
M;&4@<F5S;W5R8V4@9F]R(&QO8VMI;F<@=&AE(&QO8VMF:6QE#0H@("`@("H@
M0'9A<B!R97-O=7)C97QF86QS90T*("`@("`J($!A8V-E<W,@<')I=F%T90T*
M("`@("`J+PT*("`@('9A<B`D7VQO8VM&<"`](&9A;'-E.PT*("`@("\J*@T*
M("`@("`J($%022!V97)S:6]N(&]F('1H:7,@8VQA<W,L('5S960@=&\@=F%L
M:61A=&4@82!F:6QE(&]N+61I<VL-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W9E<G-I
M;VX@/2`G,2XP)SL-"B`@("`O*BH-"B`@("`@*B!#86-H960@9&5P96YD96YC
M>2!D871A8F%S92!F:6QE#0H@("`@("H@0'9A<B!A<G)A>7QN=6QL#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?8V%C:&4[
M#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@)B!S:6YG;&5T;VXH*0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T(&$@<F%W(&1E<&5N9&5N8WD@9&%T86)A<V4N
M("!#86QL<R!S971#;VYF:6<H*2!A;F0@87-S97)T1&5P<T1"*"D-"B`@("`@
M*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A
M;'-E(&9U;&P@<&%T:"!T;R!T:&4@9&5P96YD96YC>2!D871A8F%S92P@;W(@
M9F%L<V4@=&\@=7-E(&1E9F%U;'0-"B`@("`@*B!`<F5T=7)N(%!%05)?1&5P
M96YD96YC>41"?%!%05)?17)R;W(-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)G-I;F=L971O;B@F)&-O;F9I9RP@)&1E<&1B(#T@
M9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1'3$]"04Q36R=?
M4$5!4E]$15!%3D1%3D-91$)?24Y35$%.0T4G70T*("`@("`@("`@("`@("!;
M)&-O;F9I9RT^9V5T*"=P:'!?9&ER)RP@;G5L;"P@)W!E87(N<&AP+FYE="<I
M72DI('L-"B`@("`@("`@("`@("1A(#T@;F5W(%!%05)?1&5P96YD96YC>41"
M.PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%27T1%4$5.1$5.0UE$0E])
M3E-404Y#12==#0H@("`@("`@("`@("`@(%LD8V]N9FEG+3YG970H)W!H<%]D
M:7(G+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RE=(#T@)B1A.PT*("`@("`@("`@
M("`@)&$M/G-E=$-O;F9I9R@D8V]N9FEG+"`D9&5P9&(I.PT*("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&4@/2`D82T^87-S97)T1&5P<T1"*"DI
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG7U!%05)?
M1$5014Y$14Y#641"7TE.4U1!3D-%)UT-"B`@("`@("`@("`@("`@6R1C;VYF
M:6<M/F=E="@G<&AP7V1I<B<L(&YU;&PL("=P96%R+G!H<"YN970G*5T[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T('5P('1H92!R96=I<W1R>2]L
M;V-A=&EO;B!O9B!D97!E;F1E;F-Y($1"#0H@("`@("H@0'!A<F%M(%!%05)?
M0V]N9FEG?&9A;'-E#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!F=6QL
M('!A=&@@=&\@=&AE(&1E<&5N9&5N8WD@9&%T86)A<V4L(&]R(&9A;'-E('1O
M('5S92!D969A=6QT#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG
M*"8D8V]N9FEG+"`D9&5P9&(@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF
M("@A)&-O;F9I9RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F
M4$5!4E]#;VYF:6<Z.G-I;F=L971O;B@I.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]C;VYF:6<@/2`F)&-O;F9I9SL-"B`@("`@
M("`@?0T*("`@("`@("`D=&AI<RT^7W)E9VES=')Y(#T@)B1T:&ES+3Y?8V]N
M9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I9B`H(21D97!D8BD@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]D97!D8B`]("1T:&ES+3Y?8V]N9FEG+3YG
M970H)W!H<%]D:7(G+"!N=6QL+"`G<&5A<BYP:'`N;F5T)RD@+@T*("`@("`@
M("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(@+B`G+F1E<&1B)SL-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&5P9&(@/2`D
M9&5P9&([#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]L;V-K9FEL92`]
M(&1I<FYA;64H)'1H:7,M/E]D97!D8BD@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)RYD97!D8FQO8VLG.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@(&9U
M;F-T:6]N(&AA<U=R:71E06-C97-S*"D-"B`@("![#0H@("`@("`@(&EF("@A
M0&9I;&5?97AI<W1S*"1T:&ES+3Y?9&5P9&(I*2![#0H@("`@("`@("`@("`D
M9&ER(#T@)'1H:7,M/E]D97!D8CL-"B`@("`@("`@("`@('=H:6QE("@D9&ER
M("8F("1D:7(@(3T@)RXG*2![#0H@("`@("`@("`@("`@("`@)&1I<B`](&1I
M<FYA;64H)&1I<BD[("\O(&-D("XN#0H@("`@("`@("`@("`@("`@:68@*"1D
M:7(@(3T@)RXG("8F($!F:6QE7V5X:7-T<R@D9&ER*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H0&ES7W=R:71E86)L92@D9&ER*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N($!I<U]W<FET96%B;&4H
M)'1H:7,M/E]D97!D8BD[#0H@("`@?0T*#0H@("`@+R\@>WM[(&%S<V5R=$1E
M<'-$0B@I#0H-"B`@("`O*BH-"B`@("`@*B!#<F5A=&4@=&AE(&1E<&5N9&5N
M8WD@9&%T86)A<V4L(&EF(&ET(&1O97-N)W0@97AI<W0N("!%<G)O<B!I9B!T
M:&4@9&%T86)A<V4@:7,-"B`@("`@*B!N97=E<B!T:&%N('1H92!C;V1E(')E
M861I;F<@:70N#0H@("`@("H@0')E='5R;B!V;VED?%!%05)?17)R;W(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!A<W-E<G1$97!S1$(H*0T*("`@('L-"B`@
M("`@("`@:68@*"%I<U]F:6QE*"1T:&ES+3Y?9&5P9&(I*2![#0H@("`@("`@
M("`@("`D=&AI<RT^<F5B=6EL9$1"*"D[#0H@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`D9&5P9&(@/2`D=&AI<RT^7V=E=$1E<$1"*"D[#0H@("`@
M("`@("`@("`O+R!$871A='EP92!F;W)M870@:&%S(&)E96X@8VAA;F=E9"P@
M<F5B=6EL9"!T:&4@1&5P<R!$0@T*("`@("`@("`@("`@:68@*"1D97!D8ELG
M7W9E<G-I;VXG72`\("1T:&ES+3Y?=F5R<VEO;BD@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YR96)U:6QD1$(H*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@D9&5P9&);)U]V97)S:6]N)UU[,'T@/B`D=&AI<RT^7W9E
M<G-I;VY[,'TI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G1&5P96YD96YC>2!D871A8F%S92!I<R!V97)S:6]N("<@+@T*
M("`@("`@("`@("`@("`@("`@("`D9&5P9&);)U]V97)S:6]N)UT@+B`G+"!A
M;F0@=V4@87)E('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F5R<VEO;B`N("<L(&-A;FYO="!C;VYT:6YU92<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M1V5T(&$@;&ES="!O9B!I;G-T86QL960@<&%C:V%G97,@=&AA="!D97!E;F0@
M;VX@=&AI<R!P86-K86=E#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I
M;&5?=C%\4$5!4E]086-K86=E1FEL95]V,GQA<G)A>0T*("`@("`J($!R971U
M<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971$97!E
M;F1E;G1086-K86=E<R@F)'!K9RD-"B`@("![#0H@("`@("`@("1D871A(#T@
M)'1H:7,M/E]G971$97!$0B@I.PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P
M:V<I*2![#0H@("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)'!K
M9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("1P86-K86=E(#T@<W1R
M=&]L;W=E<B@D<&MG+3YG971086-K86=E*"DI.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V=;)V-H
M86YN96PG72D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H
M)'!K9ULG<&%C:V%G92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&1A=&%;)W!A8VMA9V5S)UU;)&-H86YN96Q=6R1P86-K86=E72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D9&%T85LG<&%C:V%G97,G75LD8VAA;FYE
M;%U;)'!A8VMA9V5=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@82!L:7-T(&]F('1H
M92!A8W1U86P@9&5P96YD96YC:65S(&]F(&EN<W1A;&QE9"!P86-K86=E<R!T
M:&%T(&1E<&5N9"!O;@T*("`@("`J(&$@<&%C:V%G92X-"B`@("`@*B!`<&%R
M86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R?&%R
M<F%Y#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(&=E=$1E<&5N9&5N=%!A8VMA9V5$97!E;F1E;F-I97,H)B1P
M:V<I#0H@("`@>PT*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9V5T1&5P1$(H
M*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@("`@("`@
M("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH*2D[
M#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!K9RT^9V5T
M4&%C:V%G92@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C
M:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG6R=C:&%N;F5L)UTI.PT*("`@("`@
M("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V=;)W!A8VMA9V4G72D[
M#0H@("`@("`@('T-"B`@("`@("`@)&1E<&5N9"`]("1T:&ES+3YG971$97!E
M;F1E;G1086-K86=E<R@D<&MG*3L-"B`@("`@("`@:68@*"$D9&5P96YD*2![
M#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@
M("`@)&1E<&5N9&5N8VEE<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@
M*"1D97!E;F0@87,@)&EN9F\I('L-"B`@("`@("`@("`@("1T96UP(#T@)'1H
M:7,M/F=E=$1E<&5N9&5N8VEE<R@D:6YF;RD[#0H@("`@("`@("`@("!F;W)E
M86-H("@D=&5M<"!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@:68@*'-T
M<G1O;&]W97(H)&1E<%LG9&5P)UU;)V-H86YN96PG72D@/3T@<W1R=&]L;W=E
M<B@D8VAA;FYE;"D@)B8-"B`@("`@("`@("`@("`@("`@("`@("!S=')T;VQO
M=V5R*"1D97!;)V1E<"==6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)'!A8VMA
M9V4I*2![#0H@("`@("`@("`@("`@("`@("`@("1D97!E;F1E;F-I97-;)&EN
M9F];)V-H86YN96PG75U;)&EN9F];)W!A8VMA9V4G75U;72`]("1D97`[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B`D9&5P96YD96YC:65S.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($=E="!A(&QI<W0@;V8@9&5P96YD96YC:65S(&]F('1H:7,@
M:6YS=&%L;&5D('!A8VMA9V4-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E
M1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R?&%R<F%Y#0H@("`@("H@0')E
M='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1E
M<&5N9&5N8VEE<R@F)'!K9RD-"B`@("![#0H@("`@("`@(&EF("AI<U]O8FIE
M8W0H)'!K9RDI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E
M<B@D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@)'!A8VMA9V4@
M/2!S=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)'!K
M9ULG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L
M;W=E<B@D<&MG6R=P86-K86=E)UTI.PT*("`@("`@("!]#0H@("`@("`@("1D
M871A(#T@)'1H:7,M/E]G971$97!$0B@I.PT*("`@("`@("!I9B`H:7-S970H
M)&1A=&%;)V1E<&5N9&5N8VEE<R==6R1C:&%N;F5L75LD<&%C:V%G95TI*2![
M#0H@("`@("`@("`@("!R971U<FX@)&1A=&%;)V1E<&5N9&5N8VEE<R==6R1C
M:&%N;F5L75LD<&%C:V%G95T[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W
M:&5T:&5R("1P87)E;G0@9&5P96YD<R!O;B`D8VAI;&0L(&YE87(@;W(@9&5E
M<`T*("`@("`J($!P87)A;2!A<G)A>7Q014%27U!A8VMA9V5&:6QE7W8R?%!%
M05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@87)R87E\4$5!4E]0
M86-K86=E1FEL95]V,GQ014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@9&5P96YD<T]N*"1P87)E;G0L("1C:&EL9"D-"B`@("![
M#0H@("`@("`@("1C(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]G971$
M97!$0B@I.PT*("`@("`@("!R971U<FX@)'1H:7,M/E]D97!E;F1S3VXH)'!A
M<F5N="P@)&-H:6QD+"`D8RD[#0H@("`@?0T*("`@(`T*("`@(&9U;F-T:6]N
M(%]D97!E;F1S3VXH)'!A<F5N="P@)&-H:6QD+"`F)&-H96-K960I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P87)E;G0I*2![#0H@("`@("`@
M("`@("`D8VAA;FYE;"`]('-T<G1O;&]W97(H)'!A<F5N="T^9V5T0VAA;FYE
M;"@I*3L-"B`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&%R
M96YT+3YG971086-K86=E*"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P87)E;G1;)V-H86YN96PG
M72D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!A<F5N
M=%LG<&%C:V%G92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?;V)J
M96-T*"1C:&EL9"DI('L-"B`@("`@("`@("`@("1D97!C:&%N;F5L(#T@<W1R
M=&]L;W=E<B@D8VAI;&0M/F=E=$-H86YN96PH*2D[#0H@("`@("`@("`@("`D
M9&5P<&%C:V%G92`]('-T<G1O;&]W97(H)&-H:6QD+3YG971086-K86=E*"DI
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E<&-H86YN96P@
M/2!S=')T;VQO=V5R*"1C:&EL9%LG8VAA;FYE;"==*3L-"B`@("`@("`@("`@
M("1D97!P86-K86=E(#T@<W1R=&]L;W=E<B@D8VAI;&1;)W!A8VMA9V4G72D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1C:&5C:V5D6R1C:&%N
M;F5L75LD<&%C:V%G95U;)&1E<&-H86YN96Q=6R1D97!P86-K86=E72DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L@+R\@879O:60@96YD;&5S<R!R
M96-U<G-I;VX-"B`@("`@("`@?0T*("`@("`@("`D8VAE8VME9%LD8VAA;FYE
M;%U;)'!A8VMA9V5=6R1D97!C:&%N;F5L75LD9&5P<&%C:V%G95T@/2!T<G5E
M.PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?8V%C:&5;)V1E<&5N9&5N
M8VEE<R==6R1C:&%N;F5L75LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'1H
M:7,M/E]C86-H95LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=6R1P86-K86=E
M72!A<R`D:6YF;RD@>PT*("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&EN
M9F];)V1E<"==6R=C:&%N;F5L)UTI(#T]('-T<G1O;&]W97(H)&1E<&-H86YN
M96PI("8F#0H@("`@("`@("`@("`@("`@("!S=')T;VQO=V5R*"1I;F9O6R=D
M97`G75LG;F%M92==*2`]/2!S=')T;VQO=V5R*"1D97!P86-K86=E*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8V%C:&5;)V1E
M<&5N9&5N8VEE<R==6R1C:&%N;F5L75LD<&%C:V%G95T@87,@)&EN9F\I('L-
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^7V1E<&5N9'-/;BAA<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1I;F9O6R=D97`G75LG
M8VAA;FYE;"==+`T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@
M)&EN9F];)V1E<"==6R=N86UE)UTI+"`D8VAI;&0L("1C:&5C:V5D*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!296=I<W1E<B!D97!E;F1E;F-I97,@;V8@82!P86-K
M86=E('1H870@:7,@8F5I;F<@:6YS=&%L;&5D(&]R('5P9W)A9&5D#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN<W1A;&Q086-K86=E*"8D
M<&%C:V%G92D-"B`@("![#0H@("`@("`@("1D871A(#T@)'1H:7,M/E]G971$
M97!$0B@I.PT*("`@("`@("!U;G-E="@D=&AI<RT^7V-A8VAE*3L-"B`@("`@
M("`@)'1H:7,M/E]S971086-K86=E1&5P<R@D9&%T82P@)'!A8VMA9V4I.PT*
M("`@("`@("`D=&AI<RT^7W=R:71E1&5P1$(H)&1A=&$I.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J(%)E;6]V92!D97!E;F1E;F-I97,@;V8@82!P86-K
M86=E('1H870@:7,@8F5I;F<@=6YI;G-T86QL960L(&]R('5P9W)A9&5D+@T*
M("`@("`J#0H@("`@("H@57!G<F%D960@<&%C:V%G97,@9FER<W0@=6YI;G-T
M86QL+"!T:&5N(&EN<W1A;&P-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E
M1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R?&%R<F%Y($EF(&%N(&%R<F%Y
M+"!T:&5N(&ET(&UU<W0@:&%V90T*("`@("`J("`@("`@("!I;F1I8V5S("=C
M:&%N;F5L)R!A;F0@)W!A8VMA9V4G#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M=6YI;G-T86QL4&%C:V%G92@F)'!K9RD-"B`@("![#0H@("`@("`@("1D871A
M(#T@)'1H:7,M/E]G971$97!$0B@I.PT*("`@("`@("!U;G-E="@D=&AI<RT^
M7V-A8VAE*3L-"B`@("`@("`@:68@*&ES7V]B:F5C="@D<&MG*2D@>PT*("`@
M("`@("`@("`@)&-H86YN96P@/2!S=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN
M96PH*2D[#0H@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O;&]W97(H)'!K
M9RT^9V5T4&%C:V%G92@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&MG6R=C:&%N;F5L)UTI.PT*
M("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V=;)W!A8VMA
M9V4G72D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D9&%T85LG
M9&5P96YD96YC:65S)UU;)&-H86YN96Q=6R1P86-K86=E72DI('L-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1D871A6R=D97!E;F1E;F-I97,G75LD8VAA;FYE;%U;)'!A8VMA9V5=
M(&%S("1D97`I('L-"B`@("`@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!;)V1E<"==6R=U<FDG72DI('L-"B`@
M("`@("`@("`@("`@("`D9&5P8VAA;FYE;"`]("=?7W5R:2<[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1D97!C:&%N;F5L(#T@
M<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG8VAA;FYE;"==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG<&%C:V%G97,G
M75LD9&5P8VAA;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=D97`G75LG;F%M92==
M*5TI*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&1A=&%;)W!A8VMA
M9V5S)UU;)&1E<&-H86YN96Q=6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;)VYA
M;64G72E=(&%S#0H@("`@("`@("`@("`@("`@("`@("`@)&D@/3X@)&EN9F\I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I;F9O6R=C:&%N;F5L)UT@
M/3T@)&-H86YN96P@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)W!A8VMA9V4G72`]/2`D<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1F;W5N
M9"D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1D871A6R=P86-K86=E<R==
M6R1D97!C:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==6R=N86UE)UTI
M75LD:5TI.PT*("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)&1A=&%;)W!A
M8VMA9V5S)UU;)&1E<&-H86YN96Q=6W-T<G1O;&]W97(H)&1E<%LG9&5P)UU;
M)VYA;64G72E=*2D@>PT*("`@("`@("`@("`@("`@("`@("!U;G-E="@D9&%T
M85LG<&%C:V%G97,G75LD9&5P8VAA;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=D
M97`G75LG;F%M92==*5TI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6-O
M=6YT*"1D871A6R=P86-K86=E<R==6R1D97!C:&%N;F5L72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1D871A6R=P86-K86=E<R==6R1D
M97!C:&%N;F5L72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LG
M<&%C:V%G97,G75LD9&5P8VAA;FYE;%U;<W1R=&]L;W=E<B@D9&5P6R=D97`G
M75LG;F%M92==*5T@/0T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M=F%L=65S*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=P
M86-K86=E<R==6R1D97!C:&%N;F5L75MS=')T;VQO=V5R*"1D97!;)V1E<"==
M6R=N86UE)UTI72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@('5N<V5T*"1D871A6R=D97!E;F1E;F-I
M97,G75LD8VAA;FYE;%U;)'!A8VMA9V5=*3L-"B`@("`@("`@:68@*"%C;W5N
M="@D9&%T85LG9&5P96YD96YC:65S)UU;)&-H86YN96Q=*2D@>PT*("`@("`@
M("`@("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==6R1C:&%N;F5L72D[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;W5N="@D9&%T85LG9&5P96YD
M96YC:65S)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D9&%T85LG9&5P96YD
M96YC:65S)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A8V]U;G0H)&1A
M=&%;)W!A8VMA9V5S)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D9&%T85LG
M<&%C:V%G97,G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]W<FET
M941E<$1"*"1D871A*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!296)U
M:6QD('1H92!D97!E;F1E;F-Y($1"(&)Y(')E861I;F<@<F5G:7-T<GD@96YT
M<FEE<RX-"B`@("`@*B!`<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(')E8G5I;&1$0B@I#0H@("`@>PT*("`@("`@("`D
M9&5P9&(@/2!A<G)A>2@G7W9E<G-I;VXG(#T^("1T:&ES+3Y?=F5R<VEO;BD[
M#0H@("`@("`@(&EF("@A)'1H:7,M/FAA<U=R:71E06-C97-S*"DI('L-"B`@
M("`@("`@("`@("\O(&%L;&]W('-T87)T=7`@9F]R(')E860M;VYL>2!W:71H
M(&]L9&5R(%)E9VES=')Y#0H@("`@("`@("`@("!R971U<FX@)&1E<&1B.PT*
M("`@("`@("!]#0H@("`@("`@("1P86-K86=E<R`]("1T:&ES+3Y?<F5G:7-T
M<GDM/FQI<W1!;&Q086-K86=E<R@I.PT*("`@("`@("!F;W)E86-H("@D<&%C
M:V%G97,@87,@)&-H86YN96P@/3X@)'!S*2![#0H@("`@("`@("`@("!F;W)E
M86-H("@D<',@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D<&%C
M:V%G92`]("1T:&ES+3Y?<F5G:7-T<GDM/F=E=%!A8VMA9V4H)'!A8VMA9V4L
M("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-E=%!A8VMA
M9V5$97!S*"1D97!D8BP@)'!A8VMA9V4I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1E<G)O<B`]("1T:&ES+3Y?=W)I=&5$97!$0B@D
M9&5P9&(I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(I*2![
M#0H@("`@("`@("`@("!R971U<FX@)&5R<F]R.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3Y?8V%C:&4@/2`D9&5P9&([#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E9VES=&5R('5S86=E
M(&]F('1H92!D97!E;F1E;F-Y($1"('1O('!R979E;G0@<F%C92!C;VYD:71I
M;VYS#0H@("`@("H@0'!A<F%M(&EN="!O;F4@;V8@=&AE($Q/0TM?*B!C;VYS
M=&%N=',-"B`@("`@*B!`<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]L;V-K
M*"1M;V1E(#T@3$]#2U]%6"D-"B`@("![#0H@("`@("`@(&EF("@A97)E9VDH
M)U=I;F1O=W,@.2<L('!H<%]U;F%M92@I*2D@>PT*("`@("`@("`@("`@:68@
M*"1M;V1E("$]($Q/0TM?54X@)B8@:7-?<F5S;W5R8V4H)'1H:7,M/E]L;V-K
M1G`I*2![#0H@("`@("`@("`@("`@("`@+R\@6%A8(&1O97,@;F]T(&-H96-K
M('1Y<&4@;V8@;&]C:R`H3$]#2U]32"],3T-+7T58*0T*("`@("`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&]P96Y?;6]D92`]("=W)SL-"B`@("`@("`@("`@("\O(%A86"!096]P;&4@
M<F5P;W)T960@<')O8FQE;7,@=VET:"!,3T-+7U-((&%N9"`G=R<-"B`@("`@
M("`@("`@(&EF("@D;6]D92`]/3T@3$]#2U]32"D@>PT*("`@("`@("`@("`@
M("`@(&EF("A`(6ES7V9I;&4H)'1H:7,M/E]L;V-K9FEL92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@=&]U8V@H)'1H:7,M/E]L;V-K9FEL92D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1O<&5N7VUO9&4@/2`G
M<B<[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@A:7-?<F5S
M;W5R8V4H)'1H:7,M/E]L;V-K1G`I*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]L;V-K1G`@/2!`9F]P96XH)'1H:7,M/E]L;V-K9FEL92P@)&]P96Y?
M;6]D92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7W)E
M<V]U<F-E*"1T:&ES+3Y?;&]C:T9P*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*")C;W5L9"!N;W0@8W)E871E($1E<&5N
M9&5N8WD@;&]C:R!F:6QE(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("AI<W-E="@D<&AP7V5R<F]R;7-G*2`_("(Z("(@
M+B`D<&AP7V5R<F]R;7-G(#H@(B(I*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("@A*&EN="EF;&]C:R@D=&AI<RT^7VQO8VM&<"P@)&UO9&4I
M*2![#0H@("`@("`@("`@("`@("`@<W=I=&-H("@D;6]D92D@>PT*("`@("`@
M("`@("`@("`@("`@("!C87-E($Q/0TM?4T@Z("1S='(@/2`G<VAA<F5D)SL@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@3$]#2U]%6#H@
M)'-T<B`]("=E>&-L=7-I=F4G.R!B<F5A:SL-"B`@("`@("`@("`@("`@("`@
M("`@8V%S92!,3T-+7U5..B`D<W1R(#T@)W5N;&]C:R<[("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@("`@("!D969A=6QT.B`@("`@("1S='(@/2`G=6YK
M;F]W;B<[("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")C;W5L9"!N;W0@86-Q
M=6ER92`D<W1R(&QO8VL@*"1T:&ES+3Y?;&]C:V9I;&4I(BD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@4F5L96%S92!U<V%G92!O9B!D97!E;F1E
M;F-Y($1"#0H@("`@("H@0')E='5R;B!T<G5E?%!%05)?17)R;W(-"B`@("`@
M*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=6YL
M;V-K*"D-"B`@("![#0H@("`@("`@("1R970@/2`D=&AI<RT^7VQO8VLH3$]#
M2U]53BD[#0H@("`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^7VQO8VM&
M<"DI('L-"B`@("`@("`@("`@(&9C;&]S92@D=&AI<RT^7VQO8VM&<"D[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]L;V-K1G`@/2!N=6QL.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!,
M;V%D('1H92!D97!E;F1E;F-Y(&1A=&%B87-E(&9R;VT@9&ES:RP@;W(@<F5T
M=7)N('1H92!C86-H90T*("`@("`J($!R971U<FX@87)R87E\4$5!4E]%<G)O
M<@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]G971$97!$0B@I#0H@("`@>PT*
M("`@("`@("!I9B`H(21T:&ES+3YH87-7<FET94%C8V5S<R@I*2![#0H@("`@
M("`@("`@("!R971U<FX@87)R87DH)U]V97)S:6]N)R`]/B`D=&AI<RT^7W9E
M<G-I;VXI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7V-A8VAE*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8V%C:&4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D9G`@/2!F;W!E;B@D=&AI<RT^
M7V1E<&1B+"`G<B<I*2![#0H@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@B0V]U;&0@;F]T(&]P96X@9&5P96YD96YC:65S(&9I;&4@8"(N
M)'1H:7,M/E]D97!D8BXB)R(I.PT*("`@("`@("`@("`@<F5T=7)N("1E<G([
M#0H@("`@("`@('T-"B`@("`@("`@)')T(#T@9V5T7VUA9VEC7W%U;W1E<U]R
M=6YT:6UE*"D[#0H@("`@("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@P
M*3L-"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@
M("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`D9&%T82`]('5N<V5R
M:6%L:7IE*&9I;&5?9V5T7V-O;G1E;G1S*"1T:&ES+3Y?9&5P9&(I*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D871A(#T@=6YS97)I86QI
M>F4H9G)E860H)&9P+"!F:6QE<VEZ92@D=&AI<RT^7V1E<&1B*2DI.PT*("`@
M("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@('T-"B`@("`@("`@<V5T
M7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"1R="D[#0H@("`@("`@("1T:&ES+3Y?
M8V%C:&4@/2`D9&%T83L-"B`@("`@("`@<F5T=7)N("1D871A.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%=R:71E(&]U="!T:&4@9&5P96YD96YC>2!D
M871A8F%S92!T;R!D:7-K#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H92!D871A
M8F%S90T*("`@("`J($!R971U<FX@=')U97Q014%27T5R<F]R#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W=R:71E
M1&5P1$(H)B1D97!S*0T*("`@('L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&4@/2`D=&AI<RT^7VQO8VLH3$]#2U]%6"DI*2![#0H@("`@("`@("`@
M("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D9G`@/2!F
M;W!E;B@D=&AI<RT^7V1E<&1B+"`G=V(G*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")#;W5L9"!N;W0@;W!E;B!D97!E;F1E;F-I97,@9FEL92!@(BXD
M=&AI<RT^7V1E<&1B+B(G(&9O<B!W<FET:6YG(BD[#0H@("`@("`@('T-"B`@
M("`@("`@)')T(#T@9V5T7VUA9VEC7W%U;W1E<U]R=6YT:6UE*"D[#0H@("`@
M("`@('-E=%]M86=I8U]Q=6]T97-?<G5N=&EM92@P*3L-"B`@("`@("`@9G=R
M:71E*"1F<"P@<V5R:6%L:7IE*"1D97!S*2D[#0H@("`@("`@('-E=%]M86=I
M8U]Q=6]T97-?<G5N=&EM92@D<G0I.PT*("`@("`@("!F8VQO<V4H)&9P*3L-
M"B`@("`@("`@)'1H:7,M/E]U;FQO8VLH*3L-"B`@("`@("`@)'1H:7,M/E]C
M86-H92`]("1D97!S.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!296=I<W1E<B!A;&P@9&5P96YD96YC:65S(&9R
M;VT@82!P86-K86=E(&EN('1H92!D97!E;F1E;F-I97,@9&%T86)A<V4L(&EN
M(&5S<V5N8V4-"B`@("`@*B`B:6YS=&%L;&EN9R(@=&AE('!A8VMA9V4G<R!D
M97!E;F1E;F-Y(&EN9F]R;6%T:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H
M92!D871A8F%S90T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q
M?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<V5T4&%C:V%G941E<',H)B1D871A
M+"`F)'!K9RD-"B`@("![#0H@("`@("`@("1P:V<M/G-E=$-O;F9I9R@D=&AI
M<RT^7V-O;F9I9RD[#0H@("`@("`@(&EF("@D<&MG+3YG971086-K86=E>&UL
M5F5R<VEO;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`D9V5N(#T@)B1P
M:V<M/F=E=$1E9F%U;'1'96YE<F%T;W(H*3L-"B`@("`@("`@("`@("1D97!S
M(#T@)&=E;BT^9&5P96YD96YC:65S5&]6,B@I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&1E<',@/2`D<&MG+3YG971$97!S*'1R=64I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)&1E<',I('L-"B`@("`@("`@("`@
M(')E='5R;CL-"B`@("`@("`@?0T*("`@("`@("`D9&%T85LG9&5P96YD96YC
M:65S)UU;<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI75MS=')T;VQO
M=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2E=#0H@("`@("`@("`@("`](&%R<F%Y
M*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&%C
M:V%G92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG<F5Q
M=6ER960G75LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1D
M97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@/2!A<G)A>2@D9&5P<ULG<F5Q
M=6ER960G75LG<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&9O<F5A8V@@*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@87,@
M)&1E<"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T97)$97`H
M)&1A=&$L("1P:V<L("1D97`L("=R97%U:7)E9"<I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N
M86PG75LG<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D
M9&5P<ULG;W!T:6]N86PG75LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("1D97!S6R=O<'1I;VYA;"==6R=P86-K86=E)UT@/2!A<G)A>2@D
M9&5P<ULG;W!T:6]N86PG75LG<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=O<'1I;VYA;"==6R=P86-K
M86=E)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G
M:7-T97)$97`H)&1A=&$L("1P:V<L("1D97`L("=O<'1I;VYA;"<I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P
M<ULG<F5Q=6ER960G75LG<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@
M:68@*"%I<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<W5B<&%C:V%G92==6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=S=6)P
M86-K86=E)UT@/2!A<G)A>2@D9&5P<ULG<F5Q=6ER960G75LG<W5B<&%C:V%G
M92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M97!S6R=R97%U:7)E9"==6R=S=6)P86-K86=E)UT@87,@)&1E<"D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T97)$97`H)&1A=&$L("1P:V<L
M("1D97`L("=R97%U:7)E9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N86PG75LG<W5B<&%C
M:V%G92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULG;W!T
M:6]N86PG75LG<W5B<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("1D97!S6R=O<'1I;VYA;"==6R=S=6)P86-K86=E)UT@/2!A<G)A>2@D9&5P
M<ULG;W!T:6]N86PG75LG<W5B<&%C:V%G92==*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S6R=O<'1I;VYA;"==6R=S=6)P
M86-K86=E)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<F5G:7-T97)$97`H)&1A=&$L("1P:V<L("1D97`L("=O<'1I;VYA;"<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&5P<ULG9W)O=7`G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E
M<'-;)V=R;W5P)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)V=R
M;W5P)UT@/2!A<G)A>2@D9&5P<ULG9W)O=7`G72D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG9W)O=7`G72!A<R`D9W)O
M=7`I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&=R;W5P6R=P86-K
M86=E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&=R
M;W5P6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9W)O=7!;)W!A8VMA9V4G72`](&%R<F%Y*"1G<F]U<%LG<&%C:V%G92==
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9W)O=7!;)W!A8VMA9V4G72!A<R`D9&5P*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=&5R1&5P*"1D871A
M+"`D<&MG+"`D9&5P+"`G;W!T:6]N86PG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9W)O=7!;)W-U8G!A8VMA9V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9W)O=7!;)W-U8G!A8VMA
M9V4G75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<%LG
M<W5B<&%C:V%G92==(#T@87)R87DH)&=R;W5P6R=S=6)P86-K86=E)UTI.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1G<F]U<%LG<W5B<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T97)$97`H)&1A=&$L
M("1P:V<L("1D97`L("=O<'1I;VYA;"<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&=R;W5P6R=A='1R:6)S)UU;)VYA;64G72D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1D871A6R=D97!E;F1E;F-I
M97,G75MS=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH*2E=#0H@("`@("`@
M("`@("`@(%MS=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2E=(#T](&%R
M<F%Y*"DI('L-"B`@("`@("`@("`@('5N<V5T*"1D871A6R=D97!E;F1E;F-I
M97,G75MS=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH*2E=#0H@("`@("`@
M("`@("`@(%MS=')T;VQO=V5R*"1P:V<M/F=E=%!A8VMA9V4H*2E=*3L-"B`@
M("`@("`@("`@(&EF("@A8V]U;G0H)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T
M<G1O;&]W97(H)'!K9RT^9V5T0VAA;FYE;"@I*5TI*2![#0H@("`@("`@("`@
M("`@("`@=6YS970H)&1A=&%;)V1E<&5N9&5N8VEE<R==6W-T<G1O;&]W97(H
M)'!K9RT^9V5T0VAA;FYE;"@I*5TI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H
M92!D871A8F%S90T*("`@("`J($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8Q
M?%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@87)R87D@=&AE
M('-P96-I9FEC(&1E<&5N9&5N8WD-"B`@("`@*B!`<&%R86T@<F5Q=6ER961\
M;W!T:6]N86P@=VAE=&AE<B!T:&ES(&ES(&$@<F5Q=6ER960@;W(@86X@;W!T
M:6]N86P@9&5P#0H@("`@("H@0'!A<F%M('-T<FEN9WQF86QS92!D97!E;F1E
M;F-Y(&=R;W5P('1H:7,@9&5P96YD96YC>2!I<R!F<F]M+"!O<B!F86QS92!F
M;W(@;W)D:6YA<GD@9&5P#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W)E9VES
M=&5R1&5P*"8D9&%T82P@)B1P:V<L("1D97`L("1T>7!E+"`D9W)O=7`@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1I;F9O(#T@87)R87DH#0H@("`@("`@
M("`@("`G9&5P)R`]/B`D9&5P+`T*("`@("`@("`@("`@)W1Y<&4G(#T^("1T
M>7!E+`T*("`@("`@("`@("`@)V=R;W5P)R`]/B`D9W)O=7`I.PT*#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@
M("`D9&5P8VAA;FYE;"`]("1D97!;)V-H86YN96PG73L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1D97!C:&%N;F5L(#T@)U]?=7)I)SL-"B`@
M("`@("`@?0T*("`@("`@("`D9&%T85LG9&5P96YD96YC:65S)UU;<W1R=&]L
M;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI75MS=')T;VQO=V5R*"1P:V<M/F=E
M=%!A8VMA9V4H*2E=6UT-"B`@("`@("`@("`@(#T@)&EN9F\[#0H@("`@("`@
M(&EF("AI<W-E="@D9&%T85LG<&%C:V%G97,G75MS=')T;VQO=V5R*"1D97!C
M:&%N;F5L*5U;<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI72DI('L-"B`@("`@
M("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&1A=&%;)W!A8VMA9V5S)UU;<W1R=&]L;W=E<B@D9&5P8VAA;FYE;"E=6W-T
M<G1O;&]W97(H)&1E<%LG;F%M92==*5T-"B`@("`@("`@("`@("`@("`@(&%S
M("1I(#T^("1P*2![#0H@("`@("`@("`@("`@("`@:68@*"1P6R=C:&%N;F5L
M)UT@/3T@<W1R=&]L;W=E<B@D<&MG+3YG971#:&%N;F5L*"DI("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@)'!;)W!A8VMA9V4G72`]/2!S=')T;VQO=V5R
M*"1P:V<M/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"$D9F]U;F0I('L-"B`@("`@("`@("`@("`@("`D9&%T85LG<&%C:V%G
M97,G75MS=')T;VQO=V5R*"1D97!C:&%N;F5L*5U;<W1R=&]L;W=E<B@D9&5P
M6R=N86UE)UTI75M=#0H@("`@("`@("`@("`@("`@("`@(#T@87)R87DH)V-H
M86YN96PG(#T^('-T<G1O;&]W97(H)'!K9RT^9V5T0VAA;FYE;"@I*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@<W1R=&]L
M;W=E<B@D<&MG+3YG971086-K86=E*"DI*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D871A6R=P86-K86=E<R==
M6W-T<G1O;&]W97(H)&1E<&-H86YN96PI75MS=')T;VQO=V5R*"1D97!;)VYA
M;64G72E=6UT-"B`@("`@("`@("`@("`@("`](&%R<F%Y*"=C:&%N;F5L)R`]
M/B!S=')T;VQO=V5R*"1P:V<M/F=E=$-H86YN96PH*2DL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@<W1R=&]L;W=E<B@D<&MG+3YG
M971086-K86=E*"DI*3L-"B`@("`@("`@?0T*("`@('T-"GT-"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O1&5P96YD96YC>3(N<&AP````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q-#$P-C$@,3`U,34T,S0Q,S0@
M,#(R,#8U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO*BH-"B`J(%!%05)?1&5P96YD96YC>3(L(&%D=F%N8V5D
M(&1E<&5N9&5N8WD@=F%L:61A=&EO;@T*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!$97!E;F1E;F-Y,BYP:'`L=B`Q+C4P(#(P,#8O
M,#$O,#8@,#0Z-#<Z,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-
M"@T*+RHJ#0H@*B!297%U:7)E9"!F;W(@=&AE(%!%05)?5D%,241!5$5?*B!C
M;VYS=&%N=',-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U9A;&ED871E+G!H
M<"<[#0H-"B\J*@T*("H@1&5P96YD96YC>2!C:&5C:R!F;W(@4$5!4B!P86-K
M86=E<PT*("H-"B`J(%1H:7,@8VQA<W,@:&%N9&QE<R!B;W1H('9E<G-I;VX@
M,2XP(&%N9"`R+C`@9&5P96YD96YC:65S#0H@*B!705).24Y'.B`J86YY*B!C
M:&%N9V5S('1O('1H:7,@8VQA<W,@;75S="!B92!D=7!L:6-A=&5D(&EN('1H
M90T*("H@=&5S=%]014%27T1E<&5N9&5N8WDR(&-L87-S(&9O=6YD(&EN('1E
M<W1S+U!%05)?1&5P96YD96YC>3(O<V5T=7`N<&AP+FEN8RP-"B`J(&]R('5N
M:70@=&5S=',@=VEL;"!N;W0@86-T=6%L;'D@=F%L:61A=&4@=&AE(&-H86YG
M97,-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-
M"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N
M-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA
M9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27T1E<&5N9&5N8WDR
M#0I[#0H@("`@+RHJ#0H@("`@("H@3VYE(&]F('1H92!014%27U9!3$E$051%
M7RH@<W1A=&5S#0H@("`@("H@0'-E92!014%27U9!3$E$051%7TY/4DU!3`T*
M("`@("`J($!V87(@:6YT96=E<@T*("`@("`J+PT*("`@('9A<B`D7W-T871E
M.PT*("`@("\J*@T*("`@("`J($-O;6UA;F0M;&EN92!O<'1I;VYS('1O(&EN
M<W1A;&PO=7!G<F%D92]U;FEN<W1A;&P@8V]M;6%N9',-"B`@("`@*B!`<&%R
M86T@87)R87D-"B`@("`@*B\-"B`@("!V87(@)%]O<'1I;VYS.PT*("`@("\J
M*@T*("`@("`J($!V87(@3U-?1W5E<W,-"B`@("`@*B\-"B`@("!V87(@)%]O
M<SL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@
M*B\-"B`@("!V87(@)%]R96=I<W1R>3L-"B`@("`O*BH-"B`@("`@*B!`=F%R
M(%!%05)?0V]N9FEG#0H@("`@("HO#0H@("`@=F%R("1?8V]N9FEG.PT*("`@
M("\J*@T*("`@("`J($!V87(@4$5!4E]$97!E;F1E;F-Y1$(-"B`@("`@*B\-
M"B`@("!V87(@)%]D97!E;F1E;F-Y9&([#0H@("`@+RHJ#0H@("`@("H@3W5T
M<'5T(&]F(%!%05)?4F5G:7-T<GDZ.G!A<G-E9%!A8VMA9V5.86UE*"D-"B`@
M("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R("1?8W5R<F5N=%!A
M8VMA9V4[#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@
M("`@("H@0'!A<F%M(&%R<F%Y(&EN<W1A;&QA=&EO;B!O<'1I;VYS#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&9O<FUA="!O9B!014%27U)E9VES=')Y.CIP87)S
M961086-K86=E3F%M92@I#0H@("`@("H@0'!A<F%M(&EN="!I;G-T86QL871I
M;VX@<W1A=&4@*&]N92!O9B!014%27U9!3$E$051%7RHI#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@4$5!4E]$97!E;F1E;F-Y,B@F)&-O;F9I9RP@)&EN<W1A
M;&QO<'1I;VYS+"`D<&%C:V%G92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S=&%T92`](%!%05)?5D%,241!5$5?24Y35$%,3$E.1RD-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E<&5N9&5N8WE$0B<I*2![
M#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>41"
M+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1I;G-T86QL
M;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@("`@("`@+R\@
M;6%K92!S=7)E(&1E<&1B(&ES(&EN('1H92!R:6=H="!L;V-A=&EO;@T*("`@
M("`@("`@("`@)&-O;F9I9RT^<V5T26YS=&%L;%)O;W0H)&EN<W1A;&QO<'1I
M;VYS6R=P86-K86=I;F=R;V]T)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?<F5G:7-T<GD@/2`F)&-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@
M("`@("`@)'1H:7,M/E]D97!E;F1E;F-Y9&(@/2`F4$5!4E]$97!E;F1E;F-Y
M1$(Z.G-I;F=L971O;B@D8V]N9FEG*3L-"B`@("`@("`@:68@*&ES<V5T*"1I
M;G-T86QL;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@("`@
M("`@)&-O;F9I9RT^<V5T26YS=&%L;%)O;W0H9F%L<V4I.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]("1I;G-T86QL;W!T:6]N<SL-
M"B`@("`@("`@)'1H:7,M/E]S=&%T92`]("1S=&%T93L-"B`@("`@("`@:68@
M*"%C;&%S<U]E>&ES=',H)T]37T=U97-S)RDI('L-"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G3U,O1W5E<W,N<&AP)SL-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7V]S(#T@;F5W($]37T=U97-S.PT*("`@("`@("`D=&AI<RT^
M7V-U<G)E;G1086-K86=E(#T@)'!A8VMA9V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@7V=E=$5X=')A4W1R:6YG*"1D97`I#0H@("`@>PT*("`@("`@("`D
M97AT<F$@/2`G("@G.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI
M*2![#0H@("`@("`@("`@("!R971U<FX@)R<[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@
M("`@("`D97AT<F$@+CT@)W)E8V]M;65N9&5D('9E<G-I;VX@)R`N("1D97!;
M)W)E8V]M;65N9&5D)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@
M)&5X=')A("X]("=V97)S:6]N(#X]("<@+B`D9&5P6R=M:6XG73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&5X=')A("$]("<@*"<I('L-"B`@
M("`@("`@("`@("`@("`@("`@)&5X=')A("X]("<L("<[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1E>'1R82`N/2`G=F5R<VEO;B`\
M/2`G("X@)&1E<%LG;6%X)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E
M>&-L=61E)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!I9B`H)&5X=')A("$]("<@*"<I('L-"B`@("`@("`@("`@("`@("`@("`@
M)&5X=')A("X]("<L("<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1E>'1R82`N/2`G97AC;'5D960@=F5R<VEO;G,Z("<[#0H@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&1E<%LG97AC;'5D92==(&%S("1I(#T^
M("1E>&-L=61E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D:2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A("X]("<L("<[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&5X=')A
M("X]("1E>&-L=61E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D97AT<F$@+CT@)RDG.PT*("`@("`@
M("!I9B`H)&5X=')A(#T]("<@*"DG*2![#0H@("`@("`@("`@("`D97AT<F$@
M/2`G)SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&5X=')A.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;6%K97,@=6YI="UT97-T:6YG
M(&$@:&5C:R!O9B!A(&QO="!E87-I97(-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!G97102%!?3U,H*0T*("`@('L-"B`@("`@("`@<F5T=7)N(%!(4%]/4SL-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UA:V5S('5N:70M=&5S
M=&EN9R!A(&AE8VL@;V8@82!L;W0@96%S:65R#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T<WES;F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H
M:7,M/E]O<RT^9V5T4WES;F%M92@I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J(%-P96-I9GD@82!D97!E;F1E;F-Y(&]N(&%N($]3+B`@57-E(&%R8V@@
M9F]R(&1E=&%I;&5D(&]S+W!R;V-E<W-O<B!I;F9O<FUA=&EO;@T*("`@("`J
M#0H@("`@("H@5&AE<F4@87)E('1W;R!G96YE<FEC($]3(&1E<&5N9&5N8VEE
M<R!T:&%T('=I;&P@8F4@=&AE(&UO<W0@8V]M;6]N+"!U;FEX(&%N9"!W:6YD
M;W=S+@T*("`@("`J($]T:&5R(&]P=&EO;G,@87)E(&QI;G5X+"!F<F5E8G-D
M+"!D87)W:6X@*$]3(%@I+"!S=6YO<RP@:7)I>"P@:'!U>"P@86EX#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@=F%L:61A=&5/<T1E<&5N9&5N8WDH)&1E<"D-
M"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7W-T871E("$](%!%05)?5D%,
M241!5$5?24Y35$%,3$E.1R`F)@T*("`@("`@("`@("`@("`D=&AI<RT^7W-T
M871E("$](%!%05)?5D%,241!5$5?1$]73DQ/041)3D<I('L-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("1N;W0@/2!T
M<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&YO="`](&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D9&5P6R=N86UE)UT@/3T@
M)RHG*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*
M("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)&1E<%LG;F%M92==*2D@>PT*
M("`@("`@("`@("`@8V%S92`G=VEN9&]W<R<@.@T*("`@("`@("`@("`@("`@
M(&EF("@D;F]T*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO
M=V5R*'-U8G-T<B@D=&AI<RT^9V5T4$A07T]3*"DL(#`L(#,I*2`]/2`G=VEN
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(D-A;FYO="!I;G-T86QL("5S(&]N(%=I;F1O=W,B*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*")W87)N
M:6YG.B!#86YN;W0@:6YS=&%L;"`E<R!O;B!7:6YD;W=S(BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H<W1R=&]L;W=E<BAS=6)S='(H)'1H:7,M/F=E=%!(4%]/4R@I+"`P+"`S
M*2D@(3T@)W=I;B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")#86X@;VYL>2!I;G-T86QL("5S(&]N
M(%=I;F1O=W,B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW
M87)N:6YG*")W87)N:6YG.B!#86X@;VYL>2!I;G-T86QL("5S(&]N(%=I;F1O
M=W,B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G=6YI>"<@.@T*("`@("`@("`@("`@
M("`@("1U;FEC97,@/2!A<G)A>2@G;&EN=7@G+"`G9G)E96)S9"<L("=D87)W
M:6XG+"`G<W5N;W,G+"`G:7)I>"<L("=H<'5X)RP@)V%I>"<I.PT*("`@("`@
M("`@("`@("`@(&EF("@D;F]T*2![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI;E]A<G)A>2@D=&AI<RT^9V5T4WES;F%M92@I+"`D=6YI8V5S*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(D-A;FYO="!I;G-T86QL("5S(&]N(&%N>2!5;FEX('-Y<W1E;2(I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")W87)N:6YG.B!#86YN
M;W0@:6YS=&%L;"`E<R!O;B!A;GD@56YI>"!S>7-T96TB*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:6Y?87)R87DH)'1H:7,M/F=E=%-Y<VYA;64H*2P@)'5N:6-E<RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=N;V1E<',G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*")#86X@;VYL>2!I;G-T86QL("5S(&]N(&$@56YI>"!S>7-T96TB
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B=V%R;FEN9SH@0V%N
M(&]N;'D@:6YS=&%L;"`E<R!O;B!A(%5N:7@@<WES=&5M(BD[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&1E9F%U;'0@.@T*("`@("`@("`@("`@("`@(&EF("@D;F]T*2![#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;)VYA;64G
M72D@/3T@<W1R=&]L;W=E<B@D=&AI<RT^9V5T4WES;F%M92@I*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)VYO9&5P<R==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)T-A;FYO="!I;G-T86QL("5S(&]N("<@+B`D9&5P6R=N86UE)UT@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(&]P97)A=&EN9R!S
M>7-T96TG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N
M:6YG*"=W87)N:6YG.B!#86YN;W0@:6YS=&%L;"`E<R!O;B`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R!O
M<&5R871I;F<@<WES=&5M)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9&5P
M6R=N86UE)UTI("$]('-T<G1O;&]W97(H)'1H:7,M/F=E=%-Y<VYA;64H*2DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"=#86YN;W0@:6YS=&%L;"`E<R!O;B`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%-Y<VYA;64H*2`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@;W!E<F%T:6YG
M('-Y<W1E;2P@8V%N(&]N;'D@:6YS=&%L;"!O;B`G("X@)&1E<%LG;F%M92==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B!#86YN;W0@:6YS=&%L;"`E<R!O;B`G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%-Y<VYA;64H*2`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<@;W!E<F%T:6YG('-Y
M<W1E;2P@8V%N(&]N;'D@:6YS=&%L;"!O;B`G("X@)&1E<%LG;F%M92==*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UA
M:V5S('5N:70M=&5S=&EN9R!A(&AE8VL@;V8@82!L;W0@96%S:65R#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@;6%T8VA3:6=N871U<F4H)'!A='1E<FXI#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]O<RT^;6%T8VA3:6=N871U
M<F4H)'!A='1E<FXI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%-P96-I
M9GD@82!C;VUP;&5X(&1E<&5N9&5N8WD@;VX@86X@3U,O<')O8V5S<V]R+VME
M<FYE;"!V97)S:6]N+`T*("`@("`J(%5S92!/4R!F;W(@<VEM<&QE(&]P97)A
M=&EN9R!S>7-T96T@9&5P96YD96YC>2X-"B`@("`@*@T*("`@("`J(%1H:7,@
M:7,@=&AE(&]N;'D@9&5P96YD96YC>2!T:&%T(&%C8V5P=',@86X@97)E9V%B
M;&4@<&%T=&5R;BX@(%1H92!P871T97)N#0H@("`@("H@=VEL;"!B92!M871C
M:&5D(&%G86EN<W0@=&AE('!H<%]U;F%M92@I(&]U='!U="!P87)S960@8GD@
M3U-?1W5E<W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T94%R8VA$
M97!E;F1E;F-Y*"1D97`I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]S
M=&%T92`A/2!014%27U9!3$E$051%7TE.4U1!3$Q)3D<I('L-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("1N;W0@/2!T
M<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&YO="`](&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/FUA=&-H4VEG
M;F%T=7)E*"1D97!;)W!A='1E<FXG72DI('L-"B`@("`@("`@("`@(&EF("@A
M)&YO="D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG
M9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"<E<R!!<F-H:71E8W1U<F4@9&5P96YD96YC>2!F86EL
M960L(&1O97,@;F]T("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)VUA
M=&-H("(G("X@)&1E<%LG<&%T=&5R;B==("X@)R(G*3L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S($%R8VAI=&5C='5R92!D97!E;F1E
M;F-Y(&9A:6QE9"P@9&]E<R`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=N;W0@;6%T8V@@(B<@+B`D9&5P6R=P871T97)N)UT@+B`G(B<I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@
M*"1N;W0I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G)7,@07)C:&ET96-T=7)E(&1E<&5N9&5N8WD@9F%I
M;&5D+"!R97%U:7)E9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5P6R=P871T97)N)UT@+B`G(B<I.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN
M9R@G=V%R;FEN9SH@)7,@07)C:&ET96-T=7)E(&1E<&5N9&5N8WD@9F%I;&5D
M+"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"`B)R`N
M("1D97!;)W!A='1E<FXG72`N("<B)RD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UA:V5S('5N
M:70M=&5S=&EN9R!A(&AE8VL@;V8@82!L;W0@96%S:65R#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@97AT96YS:6]N7VQO861E9"@D;F%M92D-"B`@("![#0H@
M("`@("`@(')E='5R;B!E>'1E;G-I;VY?;&]A9&5D*"1N86UE*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&UA:V5S('5N:70M=&5S=&EN9R!A
M(&AE8VL@;V8@82!L;W0@96%S:65R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M<&AP=F5R<VEO;B@D;F%M92`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H
M)&YA;64@(3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!P:'!V97)S
M:6]N*"1N86UE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E
M='5R;B!P:'!V97)S:6]N*"D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!V86QI9&%T945X=&5N<VEO;D1E<&5N9&5N8WDH)&1E<"P@)')E
M<75I<F5D(#T@=')U92D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^7W-T
M871E("$](%!%05)?5D%,241!5$5?24Y35$%,3$E.1R`F)@T*("`@("`@("`@
M("`@("`D=&AI<RT^7W-T871E("$](%!%05)?5D%,241!5$5?1$]73DQ/041)
M3D<I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@
M("`@("`@("1L;V%D960@/2`D=&AI<RT^97AT96YS:6]N7VQO861E9"@D9&5P
M6R=N86UE)UTI.PT*("`@("`@("`D97AT<F$@/2`D=&AI<RT^7V=E=$5X=')A
M4W1R:6YG*"1D97`I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D
M92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L
M=61E)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@
M87)R87DH)&1E<%LG97AC;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1D97!;)VUI;B==*2`F)B`A:7-S
M970H)&1E<%LG;6%X)UTI("8F#0H@("`@("`@("`@("`@("%I<W-E="@D9&5P
M6R=R96-O;6UE;F1E9"==*2`F)B`A:7-S970H)&1E<%LG97AC;'5D92==*2D@
M>PT*("`@("`@("`@("`@:68@*"1L;V%D960I('L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G
M72D@)B8@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G)7,@8V]N9FQI8W1S('=I=&@@4$A0(&5X=&5N<VEO;B`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@
M)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R
M;FEN9SH@)7,@8V]N9FQI8W1S('=I=&@@4$A0(&5X=&5N<VEO;B`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G
M("X@)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*"1R97%U:7)E9"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S(%!(
M4"!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R82D[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I<F5S(%!(4"!E
M>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!;)VYA;64G72`N("<B)R`N("1E>'1R82D[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)R5S(&-A;B!O<'1I;VYA
M;&QY('5S92!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D97!;)VYA;64G72`N("<B)R`N("1E>'1R82D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@A)&QO861E9"D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$D<F5Q=6ER960I
M('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)R5S
M(&-A;B!O<'1I;VYA;&QY('5S92!02%`@97AT96YS:6]N("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@)&5X=')A*3L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H
M:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S(%!(4"!E
M>'1E;G-I;VX@(B<@+B`D9&5P6R=N86UE)UT@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)R(G("X@)&5X=')A*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R
M;FEN9SH@)7,@<F5Q=6ER97,@4$A0(&5X=&5N<VEO;B`B)R`N("1D97!;)VYA
M;64G72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(B<@+B`D97AT<F$I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N
M(#T@*'-T<FEN9RD@)'1H:7,M/G!H<'9E<G-I;VXH)&1E<%LG;F%M92==*3L-
M"B`@("`@("`@:68@*&5M<'1Y*"1V97)S:6]N*2D@>PT*("`@("`@("`@("`@
M)'9E<G-I;VX@/2`G,"<[#0H@("`@("`@('T-"B`@("`@("`@)&9A:6P@/2!F
M86QS93L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;
M)VUI;B==+"`G/CTG*2D@>PT*("`@("`@("`@("`@("`@("1F86EL(#T@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("!I9B`H(79E<G-I;VY?
M8V]M<&%R92@D=F5R<VEO;BP@)&1E<%LG;6%X)UTL("<\/2<I*2![#0H@("`@
M("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@D9F%I;"`F)B`A:7-S970H)&1E<%LG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"<E<R!R97%U:7)E<R!02%`@97AT96YS:6]N("(G("X@)&1E
M<%LG;F%M92==("X-"B`@("`@("`@("`@("`@("`@("`@)R(G("X@)&5X=')A
M("X@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!02%`@97AT96YS
M:6]N("(G("X@)&1E<%LG;F%M92==("X-"B`@("`@("`@("`@("`@("`@("`@
M)R(G("X@)&5X=')A("X@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1V
M97)S:6]N*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*"AI
M<W-E="@D9&5P6R=M:6XG72D@?'P@:7-S970H)&1E<%LG;6%X)UTI*2`F)B`A
M)&9A:6P@)B8@:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F
M("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!C;VYF;&EC
M=',@=VET:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@)&1E<%LG;F%M92==("X@)R(G("X@)&5X=')A("X@)RP@:6YS=&%L;&5D
M('9E<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W
M87)N:6YG.B`E<R!C;VYF;&EC=',@=VET:"!02%`@97AT96YS:6]N("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG;F%M92==("X@)R(G("X@)&5X
M=')A("X@)RP@:6YS=&%L;&5D('9E<G-I;VX@:7,@)R`N("1V97)S:6]N*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1E
M<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@("`@("`@
M:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&5X8VQU9&4L("<]/2<I
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF
M;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@:7,@;F]T(&-O;7!A=&EB;&4@=VET
M:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P6R=N86UE)UT@+B`G(B!V97)S:6]N("<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@:7,@;F]T(&-O;7!A=&EB
M;&4@=VET:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G(B!V97)S:6]N("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS96EF("AV97)S
M:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1E>&-L=61E+"`G(3TG*2`F)B!I<W-E
M="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!C;VYF
M;&EC=',@=VET:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D97AT<F$@+B`G
M+"!I;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!C;VYF;&EC
M=',@=VET:"!02%`@97AT96YS:6]N("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=N86UE)UT@+B`G(B<@+B`D97AT<F$@+B`G+"!I
M;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=R96-O;6UE
M;F1E9"==*2D@>PT*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D
M=F5R<VEO;BP@)&1E<%LG<F5C;VUM96YD960G72P@)ST])RDI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)R5S(&1E<&5N9&5N8WDZ(%!(4"!E>'1E;G-I;VX@)R`N("1D97!;
M)VYA;64G72`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G('9E<G-I;VX@
M(B<@+B`D=F5R<VEO;B`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G(&ES(&YO="!T:&4@<F5C;VUM96YD960@=F5R<VEO;B`B)R`N("1D97!;
M)W)E8V]M;65N9&5D)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(L
M(&)U="!M87D@8F4@8V]M<&%T:6)L92P@=7-E("TM9F]R8V4@=&\@:6YS=&%L
M;"<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@9&5P
M96YD96YC>3H@4$A0(&5X=&5N<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D97!;)VYA;64G72`N("<@=F5R<VEO;B`B)R`N("1V97)S:6]N
M("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<@:7,@;F]T('1H
M92!R96-O;6UE;F1E9"!V97)S:6]N("(G("X@)&1E<%LG<F5C;VUM96YD960G
M72XG(B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!V86QI9&%T95!H<$1E<&5N9&5N8WDH)&1E<"D-"B`@("![#0H@
M("`@("`@(&EF("@D=&AI<RT^7W-T871E("$](%!%05)?5D%,241!5$5?24Y3
M5$%,3$E.1R`F)@T*("`@("`@("`@("`@("`D=&AI<RT^7W-T871E("$](%!%
M05)?5D%,241!5$5?1$]73DQ/041)3D<I('L-"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@("1V97)S:6]N(#T@)'1H:7,M
M/G!H<'9E<G-I;VXH*3L-"B`@("`@("`@)&5X=')A(#T@)'1H:7,M/E]G971%
M>'1R85-T<FEN9R@D9&5P*3L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG
M97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G
M72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*
M("`@("`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D
M97!;)VUI;B==+"`G/CTG*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8@(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!02%`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82`N("<L(&EN<W1A;&QE
M9"!V97)S:6]N(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW
M87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!02%`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1E>'1R82`N("<L(&EN<W1A;&QE9"!V97)S:6]N
M(&ES("<@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M
M87@G72DI('L-"B`@("`@("`@("`@(&EF("@A=F5R<VEO;E]C;VUP87)E*"1V
M97)S:6]N+"`D9&5P6R=M87@G72P@)SP])RDI('L-"B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I
M<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@<F5Q=6ER
M97,@4$A0)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$@+B`G
M+"!I;G-T86QL960@=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@<F5Q=6ER97,@4$A0)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$@+B`G+"!I;G-T86QL
M960@=F5R<VEO;B!I<R`G("X@)'9E<G-I;VXI.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&1E<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@("`@("`@
M("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&5X8VQU9&4L("<]
M/2<I*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=N;V1E<',G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@(6ES<V5T*"1T:&ES+3Y?;W!T:6]N<ULG9F]R8V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G)7,@:7,@;F]T(&-O;7!A=&EB;&4@=VET:"!02%`@=F5R<VEO;B`G("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC;'5D92D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W=A<FYI;F<Z("5S(&ES(&YO="!C;VUP871I8FQE('=I
M=&@@4$A0('9E<G-I;VX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@
M;6%K97,@=6YI="UT97-T:6YG(&$@:&5C:R!O9B!A(&QO="!E87-I97(-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!G971014%25F5R<VEO;B@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)S$N-"XY)SL-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!V86QI9&%T95!E87)I;G-T86QL97)$97!E;F1E;F-Y*"1D97`I#0H@("`@
M>PT*("`@("`@("`D<&5A<G9E<G-I;VX@/2`D=&AI<RT^9V5T4$5!4E9E<G-I
M;VXH*3L-"B`@("`@("`@)&5X=')A(#T@)'1H:7,M/E]G971%>'1R85-T<FEN
M9R@D9&5P*3L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI
M('L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==
M*2D@>PT*("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y
M*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D<&5A<G9E<G-I;VXL("1D
M97!;)VUI;B==+"`G/"<I*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!014%2($EN<W1A;&QE<B<@
M+B`D97AT<F$@+@T*("`@("`@("`@("`@("`@("`@("`G+"!I;G-T86QL960@
M=F5R<VEO;B!I<R`G("X@)'!E87)V97)S:6]N*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG
M*"=W87)N:6YG.B`E<R!R97%U:7)E<R!014%2($EN<W1A;&QE<B<@+B`D97AT
M<F$@+@T*("`@("`@("`@("`@("`@("`@("`G+"!I;G-T86QL960@=F5R<VEO
M;B!I<R`G("X@)'!E87)V97)S:6]N*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@
M("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1P96%R=F5R<VEO;BP@)&1E
M<%LG;6%X)UTL("<^)RDI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G)7,@<F5Q=6ER97,@4$5!4B!);G-T
M86QL97(G("X@)&5X=')A("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<L
M(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D<&5A<G9E<G-I;VXI.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@<F5Q=6ER97,@4$5!
M4B!);G-T86QL97(G("X@)&5X=')A("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<L(&EN<W1A;&QE9"!V97)S:6]N(&ES("<@+B`D<&5A<G9E<G-I;VXI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@
M("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=E>&-L=61E)UU;,%TI*2![#0H@
M("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG
M97AC;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1D97!;)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@
M("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)&5X8VQU9&4L("1P96%R=F5R
M<VEO;BP@)ST])RDI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M
M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!I<R!N;W0@8V]M<&%T
M:6)L92!W:71H(%!%05(@26YS=&%L;&5R("<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=V97)S:6]N("<@+B`D97AC;'5D92D[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&ES(&YO="!C
M;VUP871I8FQE('=I=&@@4$5!4B`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G26YS=&%L;&5R('9E<G-I;VX@)R`N("1E>&-L=61E*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T95-U8G!A8VMA9V5$97!E;F1E
M;F-Y*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RD-"B`@("![#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^=F%L:61A=&5086-K86=E1&5P96YD96YC>2@D9&5P
M+"`D<F5Q=6ER960L("1P87)A;7,I.PT*("`@('T-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!A<G)A>2!D97!E;F1E;F-Y(&EN9F]R;6%T:6]N("@R+C`@
M9F]R;6%T*0T*("`@("`J($!P87)A;2!B;V]L96%N('=H971H97(@=&AI<R!I
M<R!A(')E<75I<F5D(&1E<&5N9&5N8WD-"B`@("`@*B!`<&%R86T@87)R87D@
M82!L:7-T(&]F(&1O=VYL;V%D960@<&%C:V%G97,@=&\@8F4@:6YS=&%L;&5D
M+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@8F]O;&5A;B!I9B!T<G5E+"!T:&5N
M(&1E<',@;VX@<&5A<BYP:'`N;F5T('1H870@9F%I;"!W:6QL(&%L<V\@8VAE
M8VL-"B`@("`@*B`@("`@("`@("`@("`@("!A9V%I;G-T('!E8VPN<&AP+FYE
M="!P86-K86=E<R!T;R!A8V-O;6]D871E(&5X=&5N<VEO;G,@=&AA="!H879E
M#0H@("`@("H@("`@("`@("`@("`@("`@;6]V960@=&\@<&5C;"YP:'`N;F5T
M(&9R;VT@<&5A<BYP:'`N;F5T#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=F%L
M:61A=&5086-K86=E1&5P96YD96YC>2@D9&5P+"`D<F5Q=6ER960L("1P87)A
M;7,L("1D97!V,2`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES
M+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415])3E-404Q,24Y'("8F#0H@("`@
M("`@("`@("`@("1T:&ES+3Y?<W1A=&4@(3T@4$5!4E]604Q)1$%415]$3U=.
M3$]!1$E.1RD@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)W!R;W9I9&5S97AT96YS:6]N
M)UTI*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/F5X=&5N<VEO;E]L;V%D
M960H)&1E<%LG<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@
M("`@("`D<V%V92`]("1D97`[#0H@("`@("`@("`@("`@("`@)'-U8F1E<"`]
M("1D97`[#0H@("`@("`@("`@("`@("`@)'-U8F1E<%LG;F%M92==(#T@)'-U
M8F1E<%LG<')O=FED97-E>'1E;G-I;VXG73L-"B`@("`@("`@("`@("`@("!0
M14%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@
M("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3YV86QI9&%T945X=&5N<VEO
M;D1E<&5N9&5N8WDH)'-U8F1E<"P@)')E<75I<F5D*3L-"B`@("`@("`@("`@
M("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@
M("`@:68@*"%014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]S=&%T
M92`]/2!014%27U9!3$E$051%7TE.4U1!3$Q)3D<I('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W9A;&ED871E4&%C:V%G94EN<W1A;&PH)&1E<"P@
M)')E<75I<F5D+"`D9&5P=C$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M=&AI<RT^7W-T871E(#T](%!%05)?5D%,241!5$5?1$]73DQ/041)3D<I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED871E4&%C:V%G941O
M=VYL;V%D*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RP@)&1E<'8Q*3L-"B`@
M("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T95!A8VMA
M9V5$;W=N;&]A9"@D9&5P+"`D<F5Q=6ER960L("1P87)A;7,L("1D97!V,2`]
M(&9A;'-E*0T*("`@('L-"B`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E
M<%LG;F%M92==.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG=7)I)UTI*2![
M#0H@("`@("`@("`@("`D9&5P6R=C:&%N;F5L)UT@/2`G7U]U<FDG.PT*("`@
M("`@("!]#0H@("`@("`@("1D97!N86UE(#T@)'1H:7,M/E]R96=I<W1R>2T^
M<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E*3L-"B`@("`@
M("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@
M87,@)'!A<F%M*2![#0H@("`@("`@("`@("!I9B`H)'!A<F%M+3YI<T5Q=6%L
M*`T*("`@("`@("`@("`@("`@("`@87)R87DH)W!A8VMA9V4G(#T^("1D97!;
M)VYA;64G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]
M/B`D9&5P6R=C:&%N;F5L)UTI*2D@>PT*("`@("`@("`@("`@("`@("1F;W5N
M9"`]('1R=64[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H)&1E<'8Q("8F("1D97!;)V-H86YN96PG
M72`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<&%R86TM/FES17%U86PH#0H@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C
M:V%G92<@/3X@)&1E<%LG;F%M92==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)V-H86YN96PG(#T^("=P96-L+G!H<"YN970G*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)&9O=6YD("8F(&ES<V5T*"1D97!;
M)W!R;W9I9&5S97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D<&%R86US(&%S("1P87)A;2D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<&%R86TM/FES17AT96YS:6]N*"1D97!;)W!R;W9I9&5S97AT96YS:6]N)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O=6YD*2![
M#0H@("`@("`@("`@("`D=F5R<VEO;B`]("1P87)A;2T^9V5T5F5R<VEO;B@I
M.PT*("`@("`@("`@("`@)&EN<W1A;&QE9"`](&9A;'-E.PT*("`@("`@("`@
M("`@)&1O=VYL;V%D960@/2!T<G5E.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H
M)&1E<%LG;F%M92==+"`D9&5P6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@
M("`@("`@)&EN<W1A;&QE9"`]('1R=64[#0H@("`@("`@("`@("`@("`@)&1O
M=VYL;V%D960@/2!F86QS93L-"B`@("`@("`@("`@("`@("`D=F5R<VEO;B`]
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A8VMA9V5I;F9O*"1D97!;)VYA;64G72P@
M)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L
M)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I
M9B`H)&1E<%LG8VAA;FYE;"==(#T]("=P96-L+G!H<"YN970G("8F("1T:&ES
M+3Y?<F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)&1E<%LG;F%M92==+`T*("`@
M("`@("`@("`@("`@("`@("`@("=P96%R+G!H<"YN970G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D:6YS=&%L;&5D(#T@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@)&1O=VYL;V%D960@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7W)E9VES=')Y+3YP86-K86=E:6YF
M;R@D9&5P6R=N86UE)UTL("=V97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("=P96%R+G!H<"YN970G*3L-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("=N;W0@:6YS
M=&%L;&5D(&]R(&1O=VYL;V%D960G.PT*("`@("`@("`@("`@("`@("`@("`D
M:6YS=&%L;&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("1D;W=N
M;&]A9&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1E>'1R82`]("1T:&ES+3Y?9V5T
M17AT<F%3=')I;F<H)&1E<"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E
M>&-L=61E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;
M)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E
M)UT@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI("8F
M("%I<W-E="@D9&5P6R=M87@G72D@)B8-"B`@("`@("`@("`@("`@(6ES<V5T
M*"1D97!;)W)E8V]M;65N9&5D)UTI("8F("%I<W-E="@D9&5P6R=E>&-L=61E
M)UTI*2![#0H@("`@("`@("`@("!I9B`H)&EN<W1A;&QE9"!\?"`D9&]W;FQO
M861E9"D@>PT*("`@("`@("`@("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L
M;&5D(#\@)VEN<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'9E<G-I;VXI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-T(#T@(BP@)&EN<W1A;&QE9"!V97)S:6]N(&ES("(@
M+B`D=F5R<VEO;CL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1R97-T(#T@)R<[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O
M<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!C;VYF;&EC=',@=VET:"!P
M86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1E>'1R82`N("1R97-T*3L-"B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@8V]N9FQI8W1S('=I=&@@
M<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D97AT<F$@+B`D<F5S="D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("@D<F5Q=6ER960I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO9&5P
M<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"<E<R!R97%U:7)E<R!P86-K86=E("(G("X@)&1E<&YA;64@+B`G(B<@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R82D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(')E<75I
M<F5S('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5X=')A*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G)7,@8V%N(&]P=&EO;F%L
M;'D@=7-E('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D97AT<F$I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21I;G-T
M86QL960@)B8@(21D;W=N;&]A9&5D*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)')E
M<75I<F5D*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)VYO9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)R5S(')E<75I<F5S('!A8VMA9V4@(B<@+B`D9&5P
M;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT<F$I
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@<F5Q=6ER
M97,@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1E>'1R82D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G=A<FYI;F<H)R5S(&-A;B!O<'1I;VYA;&QY('5S92!P86-K86=E("(G
M("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`D97AT
M<F$I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1F86EL
M(#T@9F%L<V4[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-
M"B`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H)'9E<G-I;VXL("1D
M97!;)VUI;B==+"`G/"<I*2![#0H@("`@("`@("`@("`@("`@)&9A:6P@/2!T
M<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;)VUA>"==+"`G/B<I*2![#0H@("`@
M("`@("`@("`@("`@)&9A:6P@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@D9F%I;"`F)B`A:7-S970H)&1E<%LG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`D:6YS=&%L;&5D(#T@)&EN<W1A
M;&QE9"`_("=I;G-T86QL960G(#H@)V1O=VYL;V%D960G.PT*("`@("`@("`@
M("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@
M("`@)&1E<"`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)&1E<"P@=')U92D[#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^
M7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"<E<R!R97%U:7)E<R!P86-K86=E("(G("X@
M)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`D97AT<F$@
M+B`B+"`D:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YW87)N:6YG*"=W87)N:6YG.B`E<R!R97%U:7)E<R!P86-K86=E("(G
M("X@)&1E<&YA;64@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`D97AT
M<F$@+B`B+"`D:6YS=&%L;&5D('9E<G-I;VX@:7,@(B`N("1V97)S:6]N*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E:68@*"AI<W-E="@D9&5P
M6R=M:6XG72D@?'P@:7-S970H)&1E<%LG;6%X)UTI*2`F)B`A)&9A:6P@)B8-
M"B`@("`@("`@("`@("`@:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI("8F("%I
M<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`D:6YS=&%L
M;&5D(#T@)&EN<W1A;&QE9"`_("=I;G-T86QL960G(#H@)V1O=VYL;V%D960G
M.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)VYO
M9&5P<R==*2`F)B`A:7-S970H)'1H:7,M/E]O<'1I;VYS6R=F;W)C92==*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M)7,@8V]N9FQI8W1S('=I=&@@<&%C:V%G92`B)R`N("1D97!N86UE("X@)R(G
M("X@)&5X=')A("X-"B`@("`@("`@("`@("`@("`@("`@(BP@)&EN<W1A;&QE
M9"!V97)S:6]N(&ES("(@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G
M=V%R;FEN9SH@)7,@8V]N9FQI8W1S('=I=&@@<&%C:V%G92`B)R`N("1D97!N
M86UE("X@)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)&5X=')A("X@(BP@
M)&EN<W1A;&QE9"!V97)S:6]N(&ES("(@+B`D=F5R<VEO;BD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X
M8VQU9&4G72DI('L-"B`@("`@("`@("`@("1I;G-T86QL960@/2`D:6YS=&%L
M;&5D(#\@)VEN<W1A;&QE9"<@.B`G9&]W;FQO861E9"<[#0H@("`@("`@("`@
M("!F;W)E86-H("@D9&5P6R=E>&-L=61E)UT@87,@)&5X8VQU9&4I('L-"B`@
M("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D
M97AC;'5D92P@)ST])RD@)B8@(6ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T
M:6]N<ULG;F]D97!S)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S
M(&ES(&YO="!C;VUP871I8FQE('=I=&@@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN<W1A;&QE9"`N("<@<&%C:V%G92`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&YA;64@+B`G(B!V97)S:6]N
M("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E*3L-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@)7,@
M:7,@;F]T(&-O;7!A=&EB;&4@=VET:"`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YS=&%L;&5D("X@)R!P86-K86=E("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5P;F%M92`N("<B('9E<G-I;VX@
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R<VEO;BP@)&5X8VQU9&4L("<A/2<I
M("8F(&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D:6YS=&%L;&5D(#T@)&EN<W1A;&QE9"`_("=I;G-T86QL960G
M(#H@)V1O=VYL;V%D960G.PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI
M<RT^7V]P=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)R5S(&-O;F9L:6-T<R!W
M:71H('!A8VMA9V4@(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&5X=')A("X@(BP@)&EN<W1A;&QE9"!V97)S
M:6]N(&ES("(@+B`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G=A<FYI;F<H)W=A<FYI;F<Z("5S(&-O;F9L:6-T<R!W:71H('!A8VMA9V4@
M(B<@+B`D9&5P;F%M92`N("<B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&5X=')A("X@(BP@)&EN<W1A;&QE9"!V97)S:6]N(&ES("(@+B`D
M=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("`D
M:6YS=&%L;&5D(#T@)&EN<W1A;&QE9"`_("=I;G-T86QL960G(#H@)V1O=VYL
M;V%D960G.PT*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=F5R
M<VEO;BP@)&1E<%LG<F5C;VUM96YD960G72P@)ST])RDI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@:68@*"$D9F]U;F0@)B8@)&EN<W1A;&QE9"D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D=&AI<RT^7W)E9VES=')Y
M+3YG971086-K86=E*"1D97!;)VYA;64G72P@)&1E<%LG8VAA;FYE;"==*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1P87)A
M;2D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R96YT
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<F5N="T^:7-%
M<75A;"@D=&AI<RT^7V-U<G)E;G1086-K86=E*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1F;W5N9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1P87)A;2T^:7-#;VUP871I8FQE*"1P87)E;G0I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![("\O
M('1H:7,@:7,@9F]R('9A;&ED4&%C:V%G92@I(&-A;&QS#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<&%R96YT(#T@)'1H:7,M/E]R96=I<W1R>2T^9V5T
M4&%C:V%G92@D=&AI<RT^7V-U<G)E;G1086-K86=E6R=P86-K86=E)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)R96YT4&%C
M:V%G95LG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D<&%R96YT("$]/2!N=6QL*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1P87)A;2T^:7-#;VUP871I8FQE*"1P87)E;G0I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;
M)V9O<F-E)UTI("8F#0H@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T
M:&ES+3Y?;W!T:6]N<ULG;&]O<V4G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"<E<R!D97!E;F1E;F-Y('!A
M8VMA9V4@(B<@+B`D9&5P;F%M92`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`G(B`G("X@)&EN<W1A;&QE9"`N("<@=F5R<VEO;B`G("X@)'9E<G-I;VX@
M+B`-"B`@("`@("`@("`@("`@("`@("`@("`@("<@:7,@;F]T('1H92!R96-O
M;6UE;F1E9"!V97)S:6]N("<@+B`D9&5P6R=R96-O;6UE;F1E9"==("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<L(&)U="!M87D@8F4@8V]M<&%T:6)L
M92P@=7-E("TM9F]R8V4@=&\@:6YS=&%L;"<I.PT*("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M=V%R;FEN9R@G=V%R;FEN9SH@)7,@9&5P96YD96YC>2!P86-K86=E("(G("X@
M)&1E<&YA;64@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(@)R`N("1I
M;G-T86QL960@+B`G('9E<G-I;VX@)R`N("1V97)S:6]N("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("<@:7,@;F]T('1H92!R96-O;6UE;F1E9"!V97)S
M:6]N("<@+B`D9&5P6R=R96-O;6UE;F1E9"==*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E4&%C:V%G
M94EN<W1A;&PH)&1E<"P@)')E<75I<F5D+"`D9&5P=C$@/2!F86QS92D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED871E4&%C:V%G941O
M=VYL;V%D*"1D97`L("1R97%U:7)E9"P@87)R87DH*2P@)&1E<'8Q*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!697)I9GD@=&AA="!U;FEN<W1A;&QI
M;F<@<&%C:V%G97,@<&%S<V5D(&EN('1O(&-O;6UA;F0@;&EN92!I<R!/2RX-
M"B`@("`@*@T*("`@("`J($!P87)A;2!014%27TEN<W1A;&QE<B`D9&P-"B`@
M("`@*B!`<F5T=7)N(%!%05)?17)R;W)\=')U90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('9A;&ED871E4&%C:V%G955N:6YS=&%L;"@F)&1L*0T*("`@('L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]D97!E;F1E;F-Y
M9&(I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D97!E;F1E;F-Y
M9&([#0H@("`@("`@('T-"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[#0H@
M("`@("`@("\O(&-O;G-T<G5C="!A;B!A<G)A>2!O9B`B9&]W;FQO861E9"(@
M<&%C:V%G97,@=&\@9F]O;"!T:&4@<&%C:V%G92!D97!E;F1E;F-Y(&-H96-K
M97(-"B`@("`@("`@+R\@:6YT;R!U<VEN9R!T:&5S92!T;R!V86QI9&%T92!U
M;FEN<W1A;&QS(&]F(&-I<F-U;&%R(&1E<&5N9&5N8VEE<PT*("`@("`@("`D
M9&]W;FQO861E9"`]("8D9&PM/F=E=%5N:6YS=&%L;%!A8VMA9V5S*"D[#0H@
M("`@("`@(&9O<F5A8V@@*"1D;W=N;&]A9&5D(&%S("1I(#T^("1P9BD@>PT*
M("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&]W;FQO861E
M<E]086-K86=E)RDI('L-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O1&]W;FQO861E<B]086-K86=E+G!H<"<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D9'`@/2`F;F5W(%!%05)?1&]W;FQO861E<E]086-K
M86=E*"1D;"D[#0H@("`@("`@("`@("`D9'`M/G-E=%!A8VMA9V5&:6QE*"1D
M;W=N;&]A9&5D6R1I72D[#0H@("`@("`@("`@("`D<&%R86US6R1I72`]("8D
M9'`[#0H@("`@("`@('T-"B`@("`@("`@)&1E<',@/2`D=&AI<RT^7V1E<&5N
M9&5N8WED8BT^9V5T1&5P96YD96YT4&%C:V%G941E<&5N9&5N8VEE<R@D=&AI
M<RT^7V-U<G)E;G1086-K86=E*3L-"B`@("`@("`@)&9A:6P@/2!F86QS93L-
M"B`@("`@("`@:68@*"1D97!S*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<R!A<R`D8VAA;FYE;"`]/B`D:6YF;RD@>PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1I;F9O(&%S("1P86-K86=E(#T^("1D<RD@>PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D9',@87,@)&0I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1D6R=D97`G75LG<&%C:V%G92==(#T@)&1;)V1E
M<"==6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8VAE8VME
M<B`]("9N97<@4$5!4E]$97!E;F1E;F-Y,B@D=&AI<RT^7V-O;F9I9RP@)'1H
M:7,M/E]O<'1I;VYS+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;FYE;"P@)W!A8VMA9V4G(#T^("1P86-K
M86=E*2P@)'1H:7,M/E]S=&%T92D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P(#T@)&1;)V1E<"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<75I<F5D(#T@)&1;)W1Y<&4G72`]/2`G<F5Q=6ER960G.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E="`]("1C:&5C:V5R+3Y?=F%L:61A=&50
M86-K86=E56YI;G-T86QL*"1D97`L("1R97%U:7)E9"P@)'!A<F%M<RP@)&1L
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D;"T^;&]G*#`L
M("1R971;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&PM/FQO9R@P+"`D<F5T+3YG971-97-S86=E*"DI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)&9A:6PI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V]P=&EO;G-;)VYO9&5P<R==*2!\?"!I<W-E="@D=&AI<RT^7V]P
M=&EO;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YW87)N:6YG*`T*("`@("`@("`@("`@("`@("`@("`G=V%R;FEN9SH@
M)7,@<VAO=6QD(&YO="!B92!U;FEN<W1A;&QE9"P@;W1H97(@:6YS=&%L;&5D
M('!A8VMA9V5S(&1E<&5N9"`G("X-"B`@("`@("`@("`@("`@("`@("`@)V]N
M('1H:7,@<&%C:V%G92<I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H#0H@("`@("`@
M("`@("`@("`@("`@("<E<R!C86YN;W0@8F4@=6YI;G-T86QL960L(&]T:&5R
M(&EN<W1A;&QE9"!P86-K86=E<R!D97!E;F0@;VX@=&AI<R!P86-K86=E)RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E4&%C:V%G955N
M:6YS=&%L;"@D9&5P+"`D<F5Q=6ER960L("1P87)A;7,L("8D9&PI#0H@("`@
M>PT*("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@
M("`@("`@("1D97!N86UE(#T@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C
M:V%G94YA;654;U-T<FEN9R@D9&5P+"!T<G5E*3L-"B`@("`@("`@)&9O=6YD
M(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M*2![#0H@("`@("`@("`@("!I9B`H)'!A<F%M+3YI<T5Q=6%L*"1T:&ES+3Y?
M8W5R<F5N=%!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@)&9O=6YD(#T@
M=')U93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?<F5G:7-T
M<GDM/G!A8VMA9V5I;F9O*"1D97!;)VYA;64G72P@)W9E<G-I;VXG+`T*("`@
M("`@("`@("`@)&1E<%LG8VAA;FYE;"==*3L-"B`@("`@("`@:68@*"$D=F5R
M<VEO;BD@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@)&5X=')A(#T@)'1H:7,M/E]G971%>'1R85-T<FEN9R@D9&5P
M*3L-"B`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@
M("`@("`@("`@(&EF("@A:7-?87)R87DH)&1E<%LG97AC;'5D92==*2D@>PT*
M("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;
M)V5X8VQU9&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[("\O('5N:6YS=&%L;"!/2R`M('1H97-E('!A8VMA
M9V5S(&-O;F9L:6-T("AP<F]B86)L>2!I;G-T86QL960@=VET:"`M+69O<F-E
M*0T*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)&1E<%LG;6EN)UTI
M("8F("%I<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@(&EF("@D
M<F5Q=6ER960I('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?;W!T:6]N<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO
M;G-;)V9O<F-E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G)7,G("X@)&5X=')A("X@)R!I<R!R97%U:7)E
M9"!B>2!I;G-T86QL960@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5P;F%M92`N("<B)RD[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N
M:6YG*"=W87)N:6YG.B`E<R<@+B`D97AT<F$@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)R!I<R!R97%U:7)E9"!B>2!I;G-T86QL960@<&%C:V%G92`B
M)R`N("1D97!N86UE("X@)R(G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^=V%R;FEN9R@G)7,G("X@)&5X=')A("X-"B`@("`@("`@("`@("`@("`@
M("`@)R!C86X@8F4@;W!T:6]N86QL>2!U<V5D(&)Y(&EN<W1A;&QE9"!P86-K
M86=E("(G("X@)&1E<&YA;64@+B`G(B<I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@("1F86EL(#T@9F%L<V4[#0H@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H)'9E<G-I;VXL("1D97!;)VUI;B==+"`G/CTG*2D@>PT*("`@
M("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@
M("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1V97)S:6]N+"`D9&5P
M6R=M87@G72P@)SP])RDI('L-"B`@("`@("`@("`@("`@("`D9F%I;"`]('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F
M86EL*2![#0H@("`@("`@("`@("!I9B`H)&9O=6YD*2![#0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D9&PM/E]?7V-H96-K961;)'1H:7,M/E]C=7)R
M96YT4&%C:V%G95LG8VAA;FYE;"==70T*("`@("`@("`@("`@("`@("`@("`@
M(%LD=&AI<RT^7V-U<G)E;G1086-K86=E6R=P86-K86=E)UU=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D9&PM/E]?7V-H96-K961;)'1H:7,M/E]C=7)R
M96YT4&%C:V%G95LG8VAA;FYE;"==70T*("`@("`@("`@("`@("`@("`@("`@
M(%LD=&AI<RT^7V-U<G)E;G1086-K86=E6R=P86-K86=E)UU=(#T@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@)&1E<',@/2`D=&AI<RT^7V1E<&5N9&5N
M8WED8BT^9V5T1&5P96YD96YT4&%C:V%G941E<&5N9&5N8VEE<R@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8W5R<F5N=%!A8VMA9V4I.PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<',I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1C:&%N;F5L(#T^("1I
M;F9O*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&EN9F\@87,@)'!A8VMA9V4@/3X@)&1S*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D<R!A<R`D9"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1;)V1E<"==6R=P86-K
M86=E)UT@/2`D9%LG9&5P)UU;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C:&5C:V5R(#T@)FYE=R!014%27T1E<&5N
M9&5N8WDR*"1T:&ES+3Y?8V]N9FEG+"`D=&AI<RT^7V]P=&EO;G,L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H
M86YN96PG(#T^("1C:&%N;F5L+"`G<&%C:V%G92<@/3X@)'!A8VMA9V4I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<W1A=&4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<"`]("1D6R=D97`G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R97%U:7)E9"`]("1D6R=T>7!E)UT@/3T@)W)E<75I
M<F5D)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M970@/2`D8VAE8VME<BT^7W9A;&ED871E4&%C:V%G955N:6YS=&%L;"@D9&5P
M+"`D<F5Q=6ER960L("1P87)A;7,L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1L*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K(#,[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&9A:6P@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@A)&9A:6PI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<F5Q=6ER960I
M('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?;W!T:6]N
M<ULG;F]D97!S)UTI("8F("%I<W-E="@D=&AI<RT^7V]P=&EO;G-;)V9O<F-E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D9&5P;F%M92`N("1E>'1R82`N("<@:7,@<F5Q=6ER960@8GD@
M:6YS=&%L;&5D('!A8VMA9V4G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("<@(B5S(B<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=V%R;FEN9R@G=V%R;FEN9SH@
M)R`N("1D97!N86UE("X@)&5X=')A("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<@:7,@<F5Q=6ER960@8GD@:6YS=&%L;&5D('!A8VMA9V4@(B5S(B<I
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YW87)N:6YG*"1D97!N86UE
M("X@)&5X=')A("X@)R!C86X@8F4@;W!T:6]N86QL>2!U<V5D(&)Y(&EN<W1A
M;&QE9"!P86-K86=E)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G("(E
M<R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!V86QI9&%T92!A
M(&1O=VYL;V%D960@<&%C:V%G92!A9V%I;G-T(&EN<W1A;&QE9"!P86-K86=E
M<PT*("`@("`J(`T*("`@("`J($%S(&]F(%!%05(@,2XT+C,L('1H:7,@=VEL
M;"!O;FQY('9A;&ED871E#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87E\
M4$5!4E]$;W=N;&]A9&5R7U!A8VMA9V5\4$5!4E]086-K86=E1FEL95]V,7Q0
M14%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@("`@("`@("`@("`@("1P:V<@
M<&%C:V%G92!I9&5N=&EF:65R("AE:71H97(-"B`@("`@*B`@("`@("`@("`@
M("`@("`@("!A<G)A>2@G<&%C:V%G92<@/3X@8FQA:"P@)V-H86YN96PG(#T^
M(&)L86@I(&]R(&%N(&%R<F%Y('=I=&@-"B`@("`@*B`@("`@("`@("`@("`@
M("`@("!I;F1E>"`G:6YF;R<@<F5F97)E;F-I;F<@86X@;V)J96-T*0T*("`@
M("`J($!P87)A;2!014%27T1O=VYL;V%D97(@)&1L#0H@("`@("H@0'!A<F%M
M(&%R<F%Y("1P87)A;7,@9G5L;"!L:7-T(&]F('!A8VMA9V5S('1O(&EN<W1A
M;&P-"B`@("`@*B!`<F5T=7)N('1R=65\4$5!4E]%<G)O<@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('9A;&ED871E4&%C:V%G92@D<&MG+"`F)&1L+"`D<&%R
M86US(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@(&EF("AI<U]A<G)A>2@D
M<&MG*2`F)B!I<W-E="@D<&MG6R=I;F9O)UTI*2![#0H@("`@("`@("`@("`D
M9&5P<R`]("1T:&ES+3Y?9&5P96YD96YC>61B+3YG971$97!E;F1E;G1086-K
M86=E1&5P96YD96YC:65S*"1P:V=;)VEN9F\G72D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`D9&5P<R`]("1T:&ES+3Y?9&5P96YD96YC>61B
M+3YG971$97!E;F1E;G1086-K86=E1&5P96YD96YC:65S*"1P:V<I.PT*("`@
M("`@("!]#0H@("`@("`@("1F86EL(#T@9F%L<V4[#0H@("`@("`@(&EF("@D
M9&5P<RD@>PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?
M1&]W;FQO861E<E]086-K86=E)RDI('L-"B`@("`@("`@("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(O1&]W;FQO861E<B]086-K86=E+G!H<"<[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9'`@/2`F;F5W(%!%05)?1&]W;FQO
M861E<E]086-K86=E*"1D;"D[#0H@("`@("`@("`@("!I9B`H:7-?;V)J96-T
M*"1P:V<I*2![#0H@("`@("`@("`@("`@("`@)&1P+3YS971086-K86=E1FEL
M92@D<&MG*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@)&1P+3YS971$;W=N;&]A9%523"@D<&MG*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)2
M3U)?4D5455).*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1C
M:&%N;F5L(#T^("1I;F9O*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)&EN9F\@87,@)'!A8VMA9V4@/3X@)&1S*2![#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A8VMD*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D<&%C:V0M/F=E=%!A8VMA
M9V4H*2D@/3T@<W1R=&]L;W=E<B@D<&%C:V%G92D@)B8-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P86-K9"T^9V5T0VAA;FYE;"@I(#T]("1C
M:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1L+3YL
M;V<H,RP@)W-K:7!P:6YG(&EN<W1A;&QE9"!P86-K86=E(&-H96-K(&]F("(G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G8VAA;FYE;"<@/3X@)&-H86YN96PL("=P86-K86=E)R`]/B`D<&%C
M:V%G92DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G(BP@=F5R<VEO;B`B)R`N("1P86-K9"T^9V5T5F5R<VEO
M;B@I("X@)R(@=VEL;"!B92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G9&]W;FQO861E9"!A;F0@:6YS=&%L;&5D)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL@+R\@
M:G5M<"!T;R!N97AT('!A8VMA9V4-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D9',@87,@)&0I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C:&5C:V5R(#T@)FYE=R!014%27T1E<&5N9&5N8WDR*"1T:&ES+3Y?
M8V]N9FEG+"`D=&AI<RT^7V]P=&EO;G,L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1C:&%N;F5L+"`G<&%C:V%G
M92<@/3X@)'!A8VMA9V4I+"`D=&AI<RT^7W-T871E*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1D97`@/2`D9%LG9&5P)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<F5Q=6ER960@/2`D9%LG='EP92==(#T]("=R97%U:7)E
M9"<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T(#T@)&-H96-K97(M
M/E]V86QI9&%T95!A8VMA9V5$;W=N;&]A9"@D9&5P+"`D<F5Q=6ER960L(&%R
M<F%Y*"8D9'`I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M;"T^;&]G*#`L("1R971;,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*%!%05(Z.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&PM/FQO9R@P+"`D<F5T+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&9A:6PI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`G)7,@8V%N;F]T
M(&)E(&EN<W1A;&QE9"P@8V]N9FQI8W1S('=I=&@@:6YS=&%L;&5D('!A8VMA
M9V5S)RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@=F%L:61A=&4@82!P86-K86=E+GAM;"`Q
M+C`@9&5P96YD96YC>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED871E
M1&5P96YD96YC>3$H)&1E<"P@)'!A<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*
M("`@("`@("!I9B`H(6ES<V5T*"1D97!;)V]P=&EO;F%L)UTI*2![#0H@("`@
M("`@("`@("`D9&5P6R=O<'1I;VYA;"==(#T@)VYO)SL-"B`@("`@("`@?0T*
M("`@("`@("!L:7-T*"1N97=D97`L("1T>7!E*2`]("1T:&ES+3YN;W)M86QI
M>F5$97`H)&1E<"D[#0H@("`@("`@(&EF("@A)&YE=V1E<"D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"));G9A;&ED($1E<&5N
M9&5N8WDB*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H;65T:&]D7V5X:7-T
M<R@D=&AI<RP@(G9A;&ED871E>R1T>7!E?41E<&5N9&5N8WDB*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y[(G9A;&ED871E>R1T>7!E?41E<&5N
M9&5N8WDB?2@D;F5W9&5P+"`D9&5P6R=O<'1I;VYA;"==(#T]("=N;R<L#0H@
M("`@("`@("`@("`@("`@)'!A<F%M<RP@=')U92D[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T(&$@,2XP(&1E<"!I;G1O
M(&$@,BXP(&1E<`T*("`@("`J+PT*("`@(&9U;F-T:6]N(&YO<FUA;&EZ941E
M<"@D9&5P*0T*("`@('L-"B`@("`@("`@)'1Y<&5S(#T@87)R87DH#0H@("`@
M("`@("`@("`G<&MG)R`]/B`G4&%C:V%G92<L#0H@("`@("`@("`@("`G97AT
M)R`]/B`G17AT96YS:6]N)RP-"B`@("`@("`@("`@("=O<R<@/3X@)T]S)RP-
M"B`@("`@("`@("`@("=P:'`G(#T^("=0:'`G#0H@("`@("`@("D[#0H@("`@
M("`@(&EF("AI<W-E="@D='EP97-;)&1E<%LG='EP92==72DI('L-"B`@("`@
M("`@("`@("1T>7!E(#T@)'1Y<&5S6R1D97!;)W1Y<&4G75T[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@87)R87DH9F%L<V4L(&9A
M;'-E*3L-"B`@("`@("`@?0T*("`@("`@("`D;F5W9&5P(#T@87)R87DH*3L-
M"B`@("`@("`@<W=I=&-H("@D='EP92D@>PT*("`@("`@("`@("`@8V%S92`G
M4&%C:V%G92<@.@T*("`@("`@("`@("`@("`@("1N97=D97!;)V-H86YN96PG
M72`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@8V%S92`G17AT96YS
M:6]N)R`Z#0H@("`@("`@("`@("!C87-E("=/<R<@.@T*("`@("`@("`@("`@
M("`@("1N97=D97!;)VYA;64G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@("1D97!;)W)E;"==(#T@
M4$5!4E]$97!E;F1E;F-Y,CHZ<VEG;D]P97)A=&]R*"1D97!;)W)E;"==*3L-
M"B`@("`@("`@<W=I=&-H("@D9&5P6R=R96PG72D@>PT*("`@("`@("`@("`@
M8V%S92`G:&%S)R`Z#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1N
M97=D97`L("1T>7!E*3L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@8V%S92`G;F]T)R`Z#0H@("`@("`@("`@("`@("`@)&YE=V1E<%LG8V]N
M9FQI8W1S)UT@/2!T<G5E.PT*("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E("<^/2<@.@T*("`@("`@("`@("`@8V%S92`G/B<@.@T*("`@
M("`@("`@("`@("`@("1N97=D97!;)VUI;B==(#T@)&1E<%LG=F5R<VEO;B==
M.PT*("`@("`@("`@("`@("`@(&EF("@D9&5P6R=R96PG72`]/2`G/B<I('L-
M"B`@("`@("`@("`@("`@("`@("`@)&YE=V1E<%LG97AC;'5D92==(#T@)&1E
M<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G/#TG(#H-"B`@("`@("`@("`@
M(&-A<V4@)SPG(#H-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M87@G72`]
M("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("!I9B`H)&1E<%LG
M<F5L)UT@/3T@)SPG*2![#0H@("`@("`@("`@("`@("`@("`@("1N97=D97!;
M)V5X8VQU9&4G72`]("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)VYE
M)R`Z#0H@("`@("`@("`@("!C87-E("<A/2<@.@T*("`@("`@("`@("`@("`@
M("1N97=D97!;)VUI;B==(#T@)S`G.PT*("`@("`@("`@("`@("`@("1N97=D
M97!;)VUA>"==(#T@)S$P,#`P,"<[#0H@("`@("`@("`@("`@("`@)&YE=V1E
M<%LG97AC;'5D92==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E("<]/2<@.@T*("`@("`@("`@("`@
M("`@("1N97=D97!;)VUI;B==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@
M("`@("`@("`@("1N97=D97!;)VUA>"==(#T@)&1E<%LG=F5R<VEO;B==.PT*
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T
M>7!E(#T]("=0:'`G*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1N97=D
M97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("1N97=D97!;)VUI;B==
M(#T@)S0N,BXP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)&YE=V1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@)&YE
M=V1E<%LG;6%X)UT@/2`G-BXP+C`G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!A<G)A>2@D;F5W9&5P+"`D='EP92D[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0V]N=F5R=',@=&5X="!C;VUP87)I
M;F<@;W!E<F%T;W)S('1O('1H96T@<VEG;B!E<75I=F%L96YT<PT*("`@("`J
M#0H@("`@("H@17AA;7!L93H@)V=E)R!T;R`G/CTG#0H@("`@("H-"B`@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("`J($!P87)A;2`@<W1R:6YG($]P97)A
M=&]R#0H@("`@("H@0')E='5R;B!S=')I;F<@4VEG;B!E<75I=F%L96YT#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<VEG;D]P97)A=&]R*"1O<&5R871O<BD-
M"B`@("![#0H@("`@("`@('-W:71C:"@D;W!E<F%T;W(I('L-"B`@("`@("`@
M("`@(&-A<V4@)VQT)SH@<F5T=7)N("<\)SL-"B`@("`@("`@("`@(&-A<V4@
M)VQE)SH@<F5T=7)N("<\/2<[#0H@("`@("`@("`@("!C87-E("=G="<Z(')E
M='5R;B`G/B<[#0H@("`@("`@("`@("!C87-E("=G92<Z(')E='5R;B`G/CTG
M.PT*("`@("`@("`@("`@8V%S92`G97$G.B!R971U<FX@)ST])SL-"B`@("`@
M("`@("`@(&-A<V4@)VYE)SH@<F5T=7)N("<A/2<[#0H@("`@("`@("`@("!D
M969A=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B`D;W!E<F%T;W([#0H@
M("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1M
M<V<I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]O<'1I;VYS
M6R=I9VYO<F4M97)R;W)S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G=A<FYI;F<H)&US9RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H<W!R:6YT9B@D;7-G+"`D=&AI<RT^7W)E9VES
M=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@
M)'1H:7,M/E]C=7)R96YT4&%C:V%G92P@=')U92DI*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!W87)N:6YG*"1M<V<I#0H@("`@>PT*("`@("`@("!R971U
M<FX@87)R87DH<W!R:6YT9B@D;7-G+"`D=&AI<RT^7W)E9VES=')Y+3YP87)S
M961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@)'1H:7,M/E]C
M=7)R96YT4&%C:V%G92P@=')U92DI*3L-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0VAA;FYE
M;$9I;&4O4&%R<V5R+G!H<```````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#0R,S`@,3`U,34T,S0Q,S0@,#(S,S(U`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0VAA
M;FYE;$9I;&5?4&%R<V5R(&9O<B!P87)S:6YG(&-H86YN96PN>&UL#0H@*@T*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A<G-E<BYP:'`L
M=B`Q+C0@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@>&UL('!A<G-E<B!C;&%S<PT*
M("HO#0IR97%U:7)E7V]N8V4@)U!%05(O6$U,4&%R<V5R+G!H<"<[#0IR97%U
M:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B\J*@T*("H@4&%R
M<V5R(&9O<B!C:&%N;F5L+GAM;`T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?0VAA;FYE;$9I;&5?4&%R<V5R(&5X=&5N9',@4$5!4E]834Q087)S
M97(-"GL-"B`@("!V87(@)%]C;VYF:6<[#0H@("`@=F%R("1?;&]G9V5R.PT*
M("`@('9A<B`D7W)E9VES=')Y.PT*#0H@("`@9G5N8W1I;VX@<V5T0V]N9FEG
M*"8D8RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8V]N9FEG(#T@)B1C.PT*
M("`@("`@("`D=&AI<RT^7W)E9VES=')Y(#T@)B1C+3YG971296=I<W1R>2@I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$QO9V=E<B@F)&PI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;#L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!P87)S92@D9&%T82P@)&9I;&4I#0H@("`@>PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@<&%R96YT.CIP87)S92@D9&%T
M82P@)&9I;&4I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@
M("`@('T-"B`@("`@("`@)')E="`](&YE=R!014%27T-H86YN96Q&:6QE.PT*
M("`@("`@("`D<F5T+3YS971#;VYF:6<H)'1H:7,M/E]C;VYF:6<I.PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]L;V=G97(I*2![#0H@("`@("`@("`@
M("`D<F5T+3YS971,;V=G97(H)'1H:7,M/E]L;V=G97(I.PT*("`@("`@("!]
M#0H@("`@("`@("1R970M/F9R;VU!<G)A>2@D=&AI<RT^7W5N<V5R:6%L:7IE
M9$1A=&$I.PT*("`@("`@("`O+R!M86ME('-U<F4@=&AE(&9I;&5L:7-T(&ES
M(&EN('1H92!E87-Y('1O(')E860@9F]R;6%T(&YE961E9`T*("`@("`@("`D
M<F5T+3YF;&%T=&5N1FEL96QI<W0H*3L-"B`@("`@("`@)')E="T^<V5T4&%C
M:V%G969I;&4H)&9I;&4L("1A<F-H:79E*3L-"B`@("`@("`@<F5T=7)N("1R
M970[#0H@("`@?0T*?0T*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U!%05(O4&%C:V%G949I;&4O1V5N97)A=&]R````````````````````````
M````````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S0@,#(S,C$S`"`U````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL92]087)S97(`````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M-"`P,C(U,C$`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA
M9V5&:6QE+W8R````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,T(#`R,38Q-``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(N<&AP````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`R,3$S,#0@,3`U,34T,S0Q,S0@,#(R-#`U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?4&%C:V%G949I;&5?=C(L('!A8VMA9V4N>&UL('9E
M<G-I;VX@,BXP#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL
M86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W
M:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@
M4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N
M;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D
M260Z('8R+G!H<"QV(#$N,3(Y+C(N,2`R,#`V+S`S+S(S(#`T.C`W.C4Q(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J($9O<B!E<G)O
M<B!H86YD;&EN9PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O17)R;W)3=&%C
M:RYP:'`G.PT*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]0
M86-K86=E1FEL95]V,@T*>PT*#0H@("`@+RHJ#0H@("`@("H@4&%R<V5D('!A
M8VMA9V4@:6YF;W)M871I;VX-"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("H@
M0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<&%C:V%G94EN
M9F\@/2!A<G)A>2@I.PT*#0H@("`@+RHJ#0H@("`@("H@<&%T:"!T;R!P86-K
M86=E("YT9WH@;W(@9F%L<V4@:68@=&AI<R!I<R!A(&QO8V%L+V5X=')A8W1E
M9"!P86-K86=E+GAM;`T*("`@("`J($!V87(@<W1R:6YG?&9A;'-E#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?87)C:&EV
M949I;&4[#0H-"B`@("`O*BH-"B`@("`@*B!P871H('1O('!A8VMA9V4@+GAM
M;"!O<B!F86QS92!I9B!T:&ES(&ES(&%N(&%B<W1R86-T('!A<G-E9"UF<F]M
M+7-T<FEN9R!X;6P-"B`@("`@*B!`=F%R('-T<FEN9WQF86QS90T*("`@("`J
M($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5&
M:6QE.PT*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I<R!U<V5D(&)Y(&9I;&4@
M86YA;'ES:7,@<F]U=&EN97,@=&\@;&]G('!R;V=R97-S(&EN9F]R;6%T:6]N
M#0H@("`@("H@0'9A<B!014%27T-O;6UO;@T*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?;&]G9V5R.PT*#0H@("`@+RHJ
M#0H@("`@("H@5&AI<R!I<R!S970@=&\@=&AE(&AI9VAE<W0@=F%L:61A=&EO
M;B!L979E;"!T:&%T(&AA<R!B965N('9A;&ED871E9`T*("`@("`J#0H@("`@
M("H@268@=&AE('!A8VMA9V4N>&UL(&ES(&EN=F%L:60@;W(@=6YK;F]W;BP@
M=&AI<R!I<R!S970@=&\@,"X@($EF#0H@("`@("H@;F]R;6%L('9A;&ED871I
M;VX@:&%S(&]C8W5R<F5D+"!T:&ES(&ES('-E="!T;R!014%27U9!3$E$051%
M7TY/4DU!3"X@($EF#0H@("`@("H@9&]W;FQO861I;F<O:6YS=&%L;&%T:6]N
M('9A;&ED871I;VX@:&%S(&]C8W5R<F5D(&ET(&ES('-E="!T;R!014%27U9!
M3$E$051%7T1/5TY,3T%$24Y'#0H@("`@("H@;W(@24Y35$%,3$E.1RP@86YD
M('-O(&]N('5P('1O(%!%05)?5D%,241!5$5?4$%#2T%'24Y'+B`@5&AI<R!A
M;&QO=W,@=F%L:61A=&EO;@T*("`@("`J(")C86-H:6YG(B!T;R!O8V-U<BP@
M=VAI8V@@:7,@<&%R=&EC=6QA<FQY(&EM<&]R=&%N="!F;W(@<&%C:V%G92!V
M86QI9&%T:6]N+"!S;PT*("`@("`J('1H870@4$A0(&9I;&5S(&%R92!N;W0@
M=F%L:61A=&5D('1W:6-E#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]I<U9A;&ED(#T@,#L-
M"@T*("`@("\J*@T*("`@("`J(%1R=64@:68@=&AE(&9I;&5L:7-T(&AA<R!B
M965N('9A;&ED871E9`T*("`@("`J($!P87)A;2!B;V]L#0H@("`@("HO#0H@
M("`@=F%R("1?9FEL97-686QI9"`](&9A;'-E.PT*#0H@("`@+RHJ#0H@("`@
M("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B\-"B`@("!V87(@)%]R96=I<W1R>3L-"@T*("`@("\J*@T*
M("`@("`J($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`T*("`@("`J+PT*("`@('9A<B`D7V-O;F9I9SL-"@T*("`@("\J*@T*
M("`@("`J($]P=&EO;F%L($1E<&5N9&5N8WD@9W)O=7`@<F5Q=65S=&5D(&9O
M<B!I;G-T86QL871I;VX-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7W)E<75E<W1E9$=R
M;W5P(#T@9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?17)R
M;W)3=&%C:PT*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@
M("`@=F%R("1?<W1A8VL[#0H-"B`@("`O*BH-"B`@("`@*B!.86UE<W!A8V4@
M<')E9FEX('5S960@9F]R('1A<VMS(&EN('1H:7,@<&%C:V%G92YX;6P@+2!U
M<V4@=&%S:W,Z('=H96YE=F5R('!O<W-I8FQE#0H@("`@("HO#0H@("`@=F%R
M("1?=&%S:W-.<SL-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN97,@=VAE
M=&AE<B!T:&ES('!A8VMA9V5F:6QE('=A<R!I;FET:6%L:7IE9"!O;FQY('=I
M=&@@<&%R=&EA;"!P86-K86=E(&EN9F\-"B`@("`@*@T*("`@("`J($EF('1H
M:7,@<&%C:V%G92!F:6QE('=A<R!C;VYS=')U8W1E9"!V:6$@<&%R<VEN9R!2
M15-4+"!I="!W:6QL(&]N;'D@8V]N=&%I;@T*("`@("`J#0H@("`@("H@+2!P
M86-K86=E(&YA;64-"B`@("`@*B`M(&-H86YN96P@;F%M90T*("`@("`J("T@
M9&5P96YD96YC:65S(`T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J($!A
M8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@('9A<B`D7VEN8V]M<&QE=&4@
M/2!T<G5E.PT*#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U!A8VMA9V5&
M:6QE7W8R7U9A;&ED871O<@T*("`@("`J+PT*("`@('9A<B`D7W8R5F%L:61A
M=&]R.PT*#0H@("`@+RHJ#0H@("`@("H@5&AE(&-O;G-T<G5C=&]R(&UE<F5L
M>2!S971S('5P('1H92!P<FEV871E(&5R<F]R('-T86-K#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@4$5!4E]086-K86=E1FEL95]V,B@I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7W-T86-K(#T@;F5W(%!%05)?17)R;W)3=&%C:R@G4$5!
M4E]086-K86=E1FEL95]V,B<L(&9A;'-E+"!N=6QL*3L-"B`@("`@("`@)'1H
M:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5&\@;6%K92!U;FET+71E<W1I;F<@96%S:65R#0H@("`@("H@0'!A<F%M
M(%!%05)?1G)O;G1E;F1?*@T*("`@("`J($!P87)A;2!A<G)A>2!O<'1I;VYS
M#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0')E='5R;B!0
M14%27T1O=VYL;V%D97(-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@
M("`J+PT*("`@(&9U;F-T:6]N("9G971014%21&]W;FQO861E<B@F)&DL("1O
M+"`F)&,I#0H@("`@>PT*("`@("`@("`D>B`]("9N97<@4$5!4E]$;W=N;&]A
M9&5R*"1I+"`D;RP@)&,I.PT*("`@("`@("!R971U<FX@)'H[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@5&\@;6%K92!U;FET+71E<W1I;F<@96%S:65R
M#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&]P=&EO;G,-"B`@("`@*B!`<&%R86T@87)R87D@<&%C:V%G92!N86UE
M(&%S(')E='5R;F5D(&9R;VT@>T!L:6YK(%!%05)?4F5G:7-T<GDZ.G!A<G-E
M4&%C:V%G94YA;64H*7T-"B`@("`@*B!`<&%R86T@:6YT(%!%05)?5D%,241!
M5$5?*B!C;VYS=&%N=`T*("`@("`J($!R971U<FX@4$5!4E]$97!E;F1E;F-Y
M,@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@)F=E=%!%05)$97!E;F1E;F-Y,B@F)&,L("1O+"`D<"P@)',@/2!0
M14%27U9!3$E$051%7TE.4U1!3$Q)3D<I#0H@("`@>PT*("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@G4$5!4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@
M("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@
M("`@("`@?0T*("`@("`@("`D>B`]("9N97<@4$5!4E]$97!E;F1E;F-Y,B@D
M8RP@)&\L("1P+"`D<RD[#0H@("`@("`@(')E='5R;B`D>CL-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!G971);G-T86QL961":6YA<GDH*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)R-B:6YA
M<GEP86-K86=E)UTI(#\@)'1H:7,M/E]P86-K86=E26YF;ULG(V)I;F%R>7!A
M8VMA9V4G72`Z#0H@("`@("`@("`@("!F86QS93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!);G-T86QL871I;VX@;V8@<V]U<F-E('!A8VMA9V4@:&%S
M(&9A:6QE9"P@871T96UP="!T;R!D;W=N;&]A9"!A;F0@:6YS=&%L;"!T:&4-
M"B`@("`@*B!B:6YA<GD@=F5R<VEO;B!O9B!T:&ES('!A8VMA9V4N#0H@("`@
M("H@0'!A<F%M(%!%05)?26YS=&%L;&5R#0H@("`@("H@0')E='5R;B!A<G)A
M>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&EN<W1A;&Q":6YA<GDH
M)B1I;G-T86QL97(I#0H@("`@>PT*("`@("`@("!I9B`H(4]37U=)3D1/5U,I
M('L-"B`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("!R971U
M<FX@)&$[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K
M86=E5'EP92@I(#T]("=E>'1S<F,G*2![#0H@("`@("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1I;G-T86QL97(M/F=E=$EN<W1A;&Q086-K86=E<R@I*2D@>PT*
M("`@("`@("`@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)&EN<W1A;&QE<BT^9V5T26YS=&%L;%!A8VMA9V5S*"D@87,@)'`I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)'`M/FES17AT96YS:6]N*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)W!R;W9I9&5S97AT96YS:6]N)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D<"T^9V5T4&%C:V%G951Y<&4H*2`A/2`G97AT
M<W)C)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&$@/2!F86QS93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D83L@+R\@=&AE('5S
M97(@<')O8F%B;'D@9&]W;FQO861E9"!I="!S97!A<F%T96QY#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG97AT<W)C<F5L96%S92==6R=B:6YA<GEP86-K86=E)UTI*2![#0H@("`@
M("`@("`@("`@("`@)&EN<W1A;&QE<BT^;&]G*#`L("=!='1E;7!T:6YG('1O
M(&1O=VYL;V%D(&)I;F%R>2!V97)S:6]N(&]F(&5X=&5N<VEO;B`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I
M9&5S97AT96YS:6]N)UT@+B`G(B<I.PT*("`@("`@("`@("`@("`@("1P87)A
M;7,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1S<F-R96QE87-E)UU;)V)I
M;F%R>7!A8VMA9V4G73L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1P87)A;7,I('Q\("%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<&%R86US(#T@87)R87DH)'!A<F%M<RD[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A<F%M*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&%R<F%Y*"=C:&%N
M;F5L)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N;F5L)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P87)A;2P@
M)W9E<G-I;VXG(#T^("1T:&ES+3YG971697)S:6]N*"DI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1D;"`]("8D=&AI<RT^9V5T4$5!4D1O=VYL;V%D97(H)&EN<W1A;&QE
M<BT^=6DL("1I;G-T86QL97(M/F=E=$]P=&EO;G,H*2P-"B`@("`@("`@("`@
M("`@("`@("`@)&EN<W1A;&QE<BT^8V]N9FEG*3L-"B`@("`@("`@("`@("`@
M("`D=F5R8F]S92`]("1D;"T^8V]N9FEG+3YG970H)W9E<F)O<V4G*3L-"B`@
M("`@("`@("`@("`@("`D9&PM/F-O;F9I9RT^<V5T*"=V97)B;W-E)RP@+3$I
M.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M*2![#0H@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`@("`@
M)')E="`]("1D;"T^9&]W;FQO860H87)R87DH)'!A<F%M*2D[#0H@("`@("`@
M("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R970I("8F(&-O=6YT*"1R
M970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D9&PM/F-O;F9I9RT^<V5T*"=V97)B;W-E)RP@)'9E<F)O<V4I
M.PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F5T*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)')E="D@/3T@,2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!F(#T@)')E=%LP72T^9V5T4&%C:V%G
M949I;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1E<G(@/2`D:6YS=&%L;&5R+3YI;G-T86QL*"1R971;
M,%TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULG(V)I;F%R>7!A8VMA9V4G72`]("1R971;,%TM
M/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R`B:6YS=&%L;"(@<V5L9BP@<V\@86QL(&1E<&5N9&5N8VEE<R!W:6QL('=O
M<FL@=')A;G-P87)E;G1L>0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GDM/F%D9%!A8VMA9V4R*"1T:&ES*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&5R+3YL;V<H,"P@)T1O
M=VYL;V%D(&%N9"!I;G-T86QL(&]F(&)I;F%R>2!E>'1E;G-I;VX@(B<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES
M=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1P
M9BT^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!A8VMA9V4G(#T^("1P9BT^9V5T4&%C:V%G92@I
M*2P@=')U92D@+B`G(B!S=6-C97-S9G5L)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&$@/2!A<G)A>2@D<F5T6S!=+"`D97)R*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)&$[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YS
M=&%L;&5R+3YL;V<H,"P@)T1O=VYL;V%D(&%N9"!I;G-T86QL(&]F(&)I;F%R
M>2!E>'1E;G-I;VX@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M8VAA;FYE;"<@/3X@)'!F+3YG971#:&%N;F5L*"DL#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)'!F
M+3YG971086-K86=E*"DI+"!T<G5E*2`N("<B(&9A:6QE9"<I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1A(#T@9F%L<V4[#0H@("`@("`@
M(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N
M('-T<FEN9WQF86QS92!%>'1E;G-I;VX@;F%M90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%!R;W9I9&5S17AT96YS:6]N*"D-"B`@("![#0H@("`@("`@
M(&EF("AI;E]A<G)A>2@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2P@87)R87DH
M)V5X='-R8R<L("=E>'1B:6XG*2DI('L-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@
M>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=P<F]V:61E<V5X=&5N<VEO;B==.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@<W1R:6YG($5X=&5N<VEO;B!N86UE#0H@("`@("H@
M0')E='5R;B!B;V]L#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-%>'1E;G-I
M;VXH)&5X=&5N<VEO;BD-"B`@("![#0H@("`@("`@(&EF("AI;E]A<G)A>2@D
M=&AI<RT^9V5T4&%C:V%G951Y<&4H*2P@87)R87DH)V5X='-R8R<L("=E>'1B
M:6XG*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=P<F]V:61E<V5X=&5N<VEO;B==(#T]("1E>'1E;G-I;VX[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%1E<W1S('=H971H97(@979E<GD@<&%R="!O9B!T:&4@<&%C
M:V%G92YX;6P@,2XP(&ES(')E<')E<V5N=&5D(&EN#0H@("`@("H@=&AI<R!P
M86-K86=E+GAM;"`R+C`-"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL
M95]V,0T*("`@("`J($!R971U<FX@8F]O;`T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(&ES17%U:79A;&5N="@D<&8Q*0T*("`@('L-"B`@("`@("`@:68@*"$D
M<&8Q*2![#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V)U;F1L
M92<I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YG971%<G)O<G,H=')U92D[#0H@("`@
M("`@(&EF("@A)'!F,2T^=F%L:61A=&4H4$5!4E]604Q)1$%415].3U)-04PI
M*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("`@("`@)'!A<W,@/2!T<G5E.PT*("`@("`@("!I9B`H)'!F,2T^9V5T4&%C
M:V%G92@I("$]("1T:&ES+3YG971086-K86=E*"DI('L-"B`@("`@("`@("`@
M("1T:&ES+3Y?9&EF9F5R96YT4&%C:V%G92@D<&8Q+3YG971086-K86=E*"DI
M.PT*("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)'!F,2T^9V5T5F5R<VEO;B@I("$]("1T:&ES+3YG971697)S
M:6]N*"DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&EF9F5R96YT5F5R<VEO
M;B@D<&8Q+3YG971697)S:6]N*"DI.PT*("`@("`@("`@("`@)'!A<W,@/2!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H=')I;2@D<&8Q+3YG9713
M=6UM87)Y*"DI("$]("1T:&ES+3YG9713=6UM87)Y*"DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?9&EF9F5R96YT4W5M;6%R>2@D<&8Q+3YG9713=6UM87)Y
M*"DI.PT*("`@("`@("`@("`@)'!A<W,@/2!F86QS93L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H<')E9U]R97!L86-E*"<O7',K+R<L("<G+"`D<&8Q+3YG
M971$97-C<FEP=&EO;B@I*2`A/0T*("`@("`@("`@("`@("!P<F5G7W)E<&QA
M8V4H)R]<<RLO)RP@)R<L("1T:&ES+3YG971$97-C<FEP=&EO;B@I*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]D:69F97)E;G1$97-C<FEP=&EO;B@D<&8Q
M+3YG971$97-C<FEP=&EO;B@I*3L-"B`@("`@("`@("`@("1P87-S(#T@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1P9C$M/F=E=%-T871E*"D@
M(3T@)'1H:7,M/F=E=%-T871E*"DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M9&EF9F5R96YT4W1A=&4H)'!F,2T^9V5T4W1A=&4H*2D[#0H@("`@("`@("`@
M("`D<&%S<R`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A<W1R
M<W1R*'!R96=?<F5P;&%C92@G+UQS*R\G+"`G)RP@)'1H:7,M/F=E=$YO=&5S
M*"DI+`T*("`@("`@("`@("`@("!P<F5G7W)E<&QA8V4H)R]<<RLO)RP@)R<L
M("1P9C$M/F=E=$YO=&5S*"DI*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]D
M:69F97)E;G1.;W1E<R@D<&8Q+3YG971.;W1E<R@I*3L-"B`@("`@("`@("`@
M("1P87-S(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)&UY;6%I;G1A
M:6YE<G,@/2`D=&AI<RT^9V5T36%I;G1A:6YE<G,H*3L-"B`@("`@("`@)'EO
M=7)M86EN=&%I;F5R<R`]("1P9C$M/F=E=$UA:6YT86EN97)S*"D[#0H@("`@
M("`@(&9O<B`H)&DQ(#T@,#L@)&DQ(#P@8V]U;G0H)'EO=7)M86EN=&%I;F5R
M<RD[("1I,2LK*2![#0H@("`@("`@("`@("`D<F5S970@/2!F86QS93L-"B`@
M("`@("`@("`@(&9O<B`H)&DR(#T@,#L@)&DR(#P@8V]U;G0H)&UY;6%I;G1A
M:6YE<G,I.R`D:3(K*RD@>PT*("`@("`@("`@("`@("`@(&EF("@D;7EM86EN
M=&%I;F5R<ULD:3)=6R=H86YD;&4G72`]/2`D>6]U<FUA:6YT86EN97)S6R1I
M,5U;)VAA;F1L92==*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;7EM
M86EN=&%I;F5R<ULD:3)=6R=R;VQE)UT@(3T@)'EO=7)M86EN=&%I;F5R<ULD
M:3%=6R=R;VQE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&EF9F5R96YT4F]L92@D;7EM86EN=&%I;F5R<ULD:3)=6R=H86YD;&4G
M72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D>6]U<FUA:6YT86EN
M97)S6R1I,5U;)W)O;&4G72P@)&UY;6%I;G1A:6YE<G-;)&DR75LG<F]L92==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87-S(#T@9F%L<V4[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1M>6UA:6YT86EN97)S6R1I,EU;)V5M86EL)UT@(3T@)'EO=7)M86EN=&%I
M;F5R<ULD:3%=6R=E;6%I;"==*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V1I9F9E<F5N=$5M86EL*"1M>6UA:6YT86EN97)S6R1I,EU;
M)VAA;F1L92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Y;W5R
M;6%I;G1A:6YE<G-;)&DQ75LG96UA:6PG72P@)&UY;6%I;G1A:6YE<G-;)&DR
M75LG96UA:6PG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%S<R`]
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D;7EM86EN=&%I;F5R<ULD:3)=6R=N86UE)UT@(3T@)'EO
M=7)M86EN=&%I;F5R<ULD:3%=6R=N86UE)UTI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?9&EF9F5R96YT3F%M92@D;7EM86EN=&%I;F5R
M<ULD:3)=6R=H86YD;&4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D>6]U<FUA:6YT86EN97)S6R1I,5U;)VYA;64G72P@)&UY;6%I;G1A:6YE
M<G-;)&DR75LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P
M87-S(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@=6YS970H)&UY;6%I;G1A:6YE<G-;)&DR72D[#0H@("`@
M("`@("`@("`@("`@("`@("1M>6UA:6YT86EN97)S(#T@87)R87E?=F%L=65S
M*"1M>6UA:6YT86EN97)S*3L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H
M)'EO=7)M86EN=&%I;F5R<ULD:3%=*3L-"B`@("`@("`@("`@("`@("`@("`@
M)'EO=7)M86EN=&%I;F5R<R`](&%R<F%Y7W9A;'5E<R@D>6]U<FUA:6YT86EN
M97)S*3L-"B`@("`@("`@("`@("`@("`@("`@)')E<V5T(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1R97-E="D@>PT*("`@
M("`@("`@("`@("`@("1I,2`]("TQ.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?=6YM871C:&5D36%I;G1A:6YE<G,H)&UY
M;6%I;G1A:6YE<G,L("1Y;W5R;6%I;G1A:6YE<G,I.PT*("`@("`@("`D9FEL
M96QI<W0@/2`D=&AI<RT^9V5T1FEL96QI<W0H*3L-"B`@("`@("`@9F]R96%C
M:"`H)'!F,2T^9V5T1FEL96QI<W0H*2!A<R`D9FEL92`]/B`D871T<RD@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D9FEL96QI<W1;)&9I;&5=*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;6ES<VEN9T9I;&4H)&9I;&4I.PT*
M("`@("`@("`@("`@("`@("1P87-S(#T@9F%L<V4[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1P87-S.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]D:69F97)E;G1086-K86=E*"1P86-K86=E*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E<G)O<B<L(&%R<F%Y*"=P86-K86=E)R`]/B`D<&%C:V%G92P-"B`@("`@
M("`@("`@("=S96QF)R`]/B`D=&AI<RT^9V5T4&%C:V%G92@I*2P-"B`@("`@
M("`@("`@("=P86-K86=E+GAM;"`Q+C`@<&%C:V%G92`B)7!A8VMA9V4E(B!D
M;V5S(&YO="!M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]D:69F97)E;G1697)S:6]N*"1V97)S:6]N*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L
M(&%R<F%Y*"=V97)S:6]N)R`]/B`D=F5R<VEO;BP-"B`@("`@("`@("`@("=S
M96QF)R`]/B`D=&AI<RT^9V5T5F5R<VEO;B@I*2P-"B`@("`@("`@("`@("=P
M86-K86=E+GAM;"`Q+C`@=F5R<VEO;B`B)79E<G-I;VXE(B!D;V5S(&YO="!M
M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D:69F
M97)E;G13=&%T92@D<W1A=&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W-T871E
M)R`]/B`D<W1A=&4L#0H@("`@("`@("`@("`G<V5L9B<@/3X@)'1H:7,M/F=E
M=%-T871E*"DI+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N,"!S=&%T
M92`B)7-T871E)2(@9&]E<R!N;W0@;6%T8V@@(B5S96QF)2(G*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT4F]L92@D:&%N9&QE+"`D<F]L
M92P@)'-E;&9R;VQE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=H86YD;&4G(#T^
M("1H86YD;&4L#0H@("`@("`@("`@("`G<F]L92<@/3X@)')O;&4L("=S96QF
M)R`]/B`D<V5L9G)O;&4I+`T*("`@("`@("`@("`@)W!A8VMA9V4N>&UL(#$N
M,"!M86EN=&%I;F5R("(E:&%N9&QE)2(@<F]L92`B)7)O;&4E(B!D;V5S(&YO
M="!M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D
M:69F97)E;G1%;6%I;"@D:&%N9&QE+"`D96UA:6PL("1S96QF96UA:6PI#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?
M7RP@)V5R<F]R)RP@87)R87DH)VAA;F1L92<@/3X@)&AA;F1L92P-"B`@("`@
M("`@("`@("=E;6%I;"<@/3X@)&5M86EL+"`G<V5L9B<@/3X@)'-E;&9E;6%I
M;"DL#0H@("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP(&UA:6YT86EN97(@
M(B5H86YD;&4E(B!E;6%I;"`B)65M86EL)2(@9&]E<R!N;W0@;6%T8V@@(B5S
M96QF)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT3F%M
M92@D:&%N9&QE+"`D;F%M92P@)'-E;&9N86UE*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R
M<F%Y*"=H86YD;&4G(#T^("1H86YD;&4L#0H@("`@("`@("`@("`G;F%M92<@
M/3X@)&YA;64L("=S96QF)R`]/B`D<V5L9FYA;64I+`T*("`@("`@("`@("`@
M)W!A8VMA9V4N>&UL(#$N,"!M86EN=&%I;F5R("(E:&%N9&QE)2(@;F%M92`B
M)6YA;64E(B!D;V5S(&YO="!M871C:"`B)7-E;&8E(B<I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]U;FUA=&-H961-86EN=&%I;F5R<R@D;7DL("1Y;W5R
M<RD-"B`@("![#0H@("`@("`@(&EF("@D;7DI('L-"B`@("`@("`@("`@(&%R
M<F%Y7W=A;&LH)&UY+"!C<F5A=&5?9G5N8W1I;VXH)R8D:2P@)&LG+"`G)&D@
M/2`D:5LB:&%N9&QE(ET[)RDI.PT*("`@("`@("`@("`@)'1H:7,M/E]S=&%C
M:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=H86YD;&5S
M)R`]/B`D;7DI+`T*("`@("`@("`@("`@("`@("=P86-K86=E+GAM;"`R+C`@
M:&%S('5N;6%T8VAE9"!E>'1R82!M86EN=&%I;F5R<R`B)6AA;F1L97,E(B<I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D>6]U<G,I('L-"B`@("`@("`@
M("`@(&%R<F%Y7W=A;&LH)'EO=7)S+"!C<F5A=&5?9G5N8W1I;VXH)R8D:2P@
M)&LG+"`G)&D@/2`D:5LB:&%N9&QE(ET[)RDI.PT*("`@("`@("`@("`@)'1H
M:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y
M*"=H86YD;&5S)R`]/B`D>6]U<G,I+`T*("`@("`@("`@("`@("`@("=P86-K
M86=E+GAM;"`Q+C`@:&%S('5N;6%T8VAE9"!E>'1R82!M86EN=&%I;F5R<R`B
M)6AA;F1L97,E(B<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7V1I9F9E<F5N=$YO=&5S*"1N;W1E<RD-"B`@("![#0H@("`@("`@("1T
M<G5N8VYO=&5S(#T@<W1R;&5N*"1N;W1E<RD@/"`R-2`_("1N;W1E<R`Z('-U
M8G-T<B@D;F]T97,L(#`L(#(T*2`N("<N+BXG.PT*("`@("`@("`D=')U;F-M
M>6YO=&5S(#T@<W1R;&5N*"1T:&ES+3YG971.;W1E<R@I*2`\(#(U(#\@)'1H
M:7,M/F=E=$YO=&5S*"D@.@T*("`@("`@("`@("`@<W5B<W1R*"1T:&ES+3YG
M971.;W1E<R@I+"`P+"`R-"D@+B`G+BXN)SL-"B`@("`@("`@)'1H:7,M/E]S
M=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=N;W1E
M<R<@/3X@)'1R=6YC;F]T97,L#0H@("`@("`@("`@("`G<V5L9B<@/3X@)'1R
M=6YC;7EN;W1E<RDL#0H@("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP(')E
M;&5A<V4@;F]T97,@(B5N;W1E<R4B(&1O(&YO="!M871C:"`B)7-E;&8E(B<I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]D:69F97)E;G13=6UM87)Y*"1S
M=6UM87)Y*0T*("`@('L-"B`@("`@("`@)'1R=6YC<W5M;6%R>2`]('-T<FQE
M;B@D<W5M;6%R>2D@/"`R-2`_("1S=6UM87)Y(#H@<W5B<W1R*"1S=6UM87)Y
M+"`P+"`R-"D@+B`G+BXN)SL-"B`@("`@("`@)'1R=6YC;7ES=6UM87)Y(#T@
M<W1R;&5N*"1T:&ES+3YG971S=6UM87)Y*"DI(#P@,C4@/R`D=&AI<RT^9V5T
M4W5M;6%R>2@I(#H-"B`@("`@("`@("`@('-U8G-T<B@D=&AI<RT^9V5T<W5M
M;6%R>2@I+"`P+"`R-"D@+B`G+BXN)SL-"B`@("`@("`@)'1H:7,M/E]S=&%C
M:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=S=6UM87)Y
M)R`]/B`D=')U;F-S=6UM87)Y+`T*("`@("`@("`@("`@)W-E;&8G(#T^("1T
M<G5N8VUY<W5M;6%R>2DL#0H@("`@("`@("`@("`G<&%C:V%G92YX;6P@,2XP
M('-U;6UA<GD@(B5S=6UM87)Y)2(@9&]E<R!N;W0@;6%T8V@@(B5S96QF)2(G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&EF9F5R96YT1&5S8W)I<'1I
M;VXH)&1E<V-R:7!T:6]N*0T*("`@('L-"B`@("`@("`@)'1R=6YC9&5S8W)I
M<'1I;VX@/2!T<FEM*'-T<FQE;B@D9&5S8W)I<'1I;VXI(#P@,C4@/R`D9&5S
M8W)I<'1I;VX@.B!S=6)S='(H)&1E<V-R:7!T:6]N+"`P+"`R-"D@+B`G+BXN
M)RD[#0H@("`@("`@("1T<G5N8VUY9&5S8W)I<'1I;VX@/2!T<FEM*'-T<FQE
M;B@D=&AI<RT^9V5T1&5S8W)I<'1I;VXH*2D@/"`R-2`_("1T:&ES+3YG971$
M97-C<FEP=&EO;B@I(#H-"B`@("`@("`@("`@('-U8G-T<B@D=&AI<RT^9V5T
M9&5S8W)I<'1I;VXH*2P@,"P@,C0I("X@)RXN+B<I.PT*("`@("`@("`D=&AI
M<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH
M)V1E<V-R:7!T:6]N)R`]/B`D=')U;F-D97-C<FEP=&EO;BP-"B`@("`@("`@
M("`@("=S96QF)R`]/B`D=')U;F-M>61E<V-R:7!T:6]N*2P-"B`@("`@("`@
M("`@("=P86-K86=E+GAM;"`Q+C`@9&5S8W)I<'1I;VX@(B5D97-C<FEP=&EO
M;B4B(&1O97,@;F]T(&UA=&-H("(E<V5L9B4B)RD[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7VUI<W-I;F=&:6QE*"1F:6QE*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R
M<F%Y*"=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`G<&%C:V%G92YX
M;6P@,2XP(&9I;&4@(B5F:6QE)2(@:7,@;F]T('!R97-E;G0@:6X@/&-O;G1E
M;G1S/B<I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D
M;R!N;W0@=7-E('1H:7,@9G5N8W1I;VX@=6YL97-S('EO=2!K;F]W('=H870@
M>6]U)W)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4F%W4W1A
M=&4H)'-T871E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG<W1A8FEL:71Y)UU;)W)E;&5A<V4G72`]("1S=&%T93L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!705).24Y'("T@9&\@;F]T('5S92!T:&ES(&9U
M;F-T:6]N('5N;&5S<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=%)A=T-O;7!A=&EB;&4H)&-O;7!A=&EB
M;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP
M871I8FQE)UT@/2`D8V]M<&%T:6)L93L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!705).24Y'("T@9&\@;F]T('5S92!T:&ES(&9U;F-T:6]N('5N;&5S
M<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N('-E=%)A=U!A8VMA9V4H)'!A8VMA9V4I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=N86UE)UT@/2`D<&%C:V%G93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!705).24Y'("T@9&\@;F]T('5S92!T
M:&ES(&9U;F-T:6]N('5N;&5S<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN
M9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%)A=T-H86YN96PH)&-H86YN
M96PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M;F5L)UT@/2`D8VAA;FYE;#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S9712
M97%U97-T961'<F]U<"@D9W)O=7`I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W)E<75E<W1E9$=R;W5P(#T@)&=R;W5P.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=%)E<75E<W1E9$=R;W5P*"D-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W)E<75E<W1E9$=R;W5P*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<F5Q=65S=&5D1W)O=7`[#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($9O<B!S879I;F<@:6X@=&AE(')E9VES=')Y+@T*("`@("`J#0H@("`@("H@
M4V5T('1H92!L87-T('9E<G-I;VX@=&AA="!W87,@:6YS=&%L;&5D#0H@("`@
M("H@0'!A<F%M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$QA
M<W1);G-T86QL961697)S:6]N*"1V97)S:6]N*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1V97)S:6]N)UT@/2`D=F5R<VEO
M;CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF
M86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$QA<W1);G-T86QL9616
M97)S:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=?;&%S='9E<G-I;VXG72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=?;&%S='9E<G-I;VXG73L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@1&5T97)M:6YE<R!W:&5T:&5R('1H:7,@<&%C:V%G92YX
M;6P@:&%S('!O<W0M:6YS=&%L;"!S8W)I<'1S(&]R(&YO=`T*("`@("`J($!R
M971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!L:7-T
M4&]S=&EN<W1A;&Q38W)I<'1S*"D-"B`@("![#0H@("`@("`@("1F:6QE;&ES
M="`]("1T:&ES+3YG971&:6QE;&ES="@I.PT*("`@("`@("`D8V]N=&5N=',@
M/2`D=&AI<RT^9V5T0V]N=&5N=',H*3L-"B`@("`@("`@)&-O;G1E;G1S(#T@
M)&-O;G1E;G1S6R=D:7(G75LG9FEL92==.PT*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1C;VYT96YT<RD@?'P@(6ES<V5T*"1C;VYT96YT<ULP72DI('L-"B`@
M("`@("`@("`@("1C;VYT96YT<R`](&%R<F%Y*"1C;VYT96YT<RD[#0H@("`@
M("`@('T-"B`@("`@("`@)'1A<VMF:6QE<R`](&%R<F%Y*"D[#0H@("`@("`@
M(&9O<F5A8V@@*"1C;VYT96YT<R!A<R`D9FEL92D@>PT*("`@("`@("`@("`@
M)&%T=',@/2`D9FEL95LG871T<FEB<R==.PT*("`@("`@("`@("`@=6YS970H
M)&9I;&5;)V%T=')I8G,G72D[#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&9I
M;&4I*2![#0H@("`@("`@("`@("`@("`@)'1A<VMF:6QE<ULD871T<ULG;F%M
M92==72`]("1F:6QE.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1C;VUM
M;VXM/F1E8G5G(#T@)'1H:7,M/E]C;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*
M("`@("`@("`D=&AI<RT^7W-C<FEP=',@/2!A<G)A>2@I.PT*("`@("`@("`D
M<F5T(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'1A<VMF:6QE<R!A
M<R`D;F%M92`]/B`D=&%S:W,I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)&9I;&5L:7-T6R1N86UE72DI('L-"B`@("`@("`@("`@("`@("`O+R!I9VYO
M<F5D(&9I;&5S('=I;&P@;F]T(&)E(&EN('1H92!F:6QE;&ES=`T*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)&%T=',@/2`D9FEL96QI<W1;)&YA;65=.PT*("`@("`@("`@("`@9F]R
M96%C:"`H)'1A<VMS(&%S("1T86<@/3X@)')A=RD@>PT*("`@("`@("`@("`@
M("`@("1T87-K(#T@)'1H:7,M/F=E=%1A<VLH)'1A9RD[#0H@("`@("`@("`@
M("`@("`@)'1A<VL@/2`F;F5W("1T87-K*"1T:&ES+3Y?8V]N9FEG+"`D8V]M
M;6]N+"!014%27U1!4TM?24Y35$%,3"D[#0H@("`@("`@("`@("`@("`@:68@
M*"1T87-K+3YI<U-C<FEP="@I*2![#0H@("`@("`@("`@("`@("`@("`@("1R
M971;72`]("1F:6QE;&ES=%LD;F%M95U;)VEN<W1A;&QE9%]A<R==.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H8V]U;G0H)')E="DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M<F5T.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!);FET:6%L:7IE('!O<W0M:6YS=&%L;"!S
M8W)I<'1S(&9O<B!R=6YN:6YG#0H@("`@("H-"B`@("`@*B!4:&ES(&UE=&AO
M9"!C86X@8F4@=7-E9"!T;R!D971E8W0@<&]S="UI;G-T86QL('-C<FEP=',L
M(&%S('1H92!R971U<FX@=F%L=64-"B`@("`@*B!I;F1I8V%T97,@=VAE=&AE
M<B!A;GD@97AI<W0-"B`@("`@*B!`<F5T=7)N(&)O;VP-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!I;FET4&]S=&EN<W1A;&Q38W)I<'1S*"D-"B`@("![#0H@
M("`@("`@("1F:6QE;&ES="`]("1T:&ES+3YG971&:6QE;&ES="@I.PT*("`@
M("`@("`D8V]N=&5N=',@/2`D=&AI<RT^9V5T0V]N=&5N=',H*3L-"B`@("`@
M("`@)&-O;G1E;G1S(#T@)&-O;G1E;G1S6R=D:7(G75LG9FEL92==.PT*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1C;VYT96YT<RD@?'P@(6ES<V5T*"1C;VYT
M96YT<ULP72DI('L-"B`@("`@("`@("`@("1C;VYT96YT<R`](&%R<F%Y*"1C
M;VYT96YT<RD[#0H@("`@("`@('T-"B`@("`@("`@)'1A<VMF:6QE<R`](&%R
M<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT<R!A<R`D9FEL92D@
M>PT*("`@("`@("`@("`@)&%T=',@/2`D9FEL95LG871T<FEB<R==.PT*("`@
M("`@("`@("`@=6YS970H)&9I;&5;)V%T=')I8G,G72D[#0H@("`@("`@("`@
M("!I9B`H8V]U;G0H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)'1A<VMF
M:6QE<ULD871T<ULG;F%M92==72`]("1F:6QE.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM;VX[
M#0H@("`@("`@("1C;VUM;VXM/F1E8G5G(#T@)'1H:7,M/E]C;VYF:6<M/F=E
M="@G=F5R8F]S92<I.PT*("`@("`@("`D=&AI<RT^7W-C<FEP=',@/2!A<G)A
M>2@I.PT*("`@("`@("!F;W)E86-H("@D=&%S:V9I;&5S(&%S("1N86UE(#T^
M("1T87-K<RD@>PT*("`@("`@("`@("`@)&%T=',@/2`D9FEL96QI<W1;)&YA
M;65=.PT*("`@("`@("`@("`@9F]R96%C:"`H)'1A<VMS(&%S("1T86<@/3X@
M)')A=RD@>PT*("`@("`@("`@("`@("`@("1T87-K;F%M92`]("1T:&ES+3YG
M971487-K*"1T86<I.PT*("`@("`@("`@("`@("`@("1T87-K(#T@)FYE=R`D
M=&%S:VYA;64H)'1H:7,M/E]C;VYF:6<L("1C;VUM;VXL(%!%05)?5$%32U])
M3E-404Q,*3L-"B`@("`@("`@("`@("`@("!I9B`H(21T87-K+3YI<U-C<FEP
M="@I*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.R`O+R!S8W)I
M<'1S(&%R92!O;FQY(&AA;F1L960@869T97(@:6YS=&%L;&%T:6]N#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1L87-T=F5R<VEO;B`]
M(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)U]L87-T=F5R<VEO;B==*2`_
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)U]L
M87-T=F5R<VEO;B==(#H@;G5L;#L-"B`@("`@("`@("`@("`@("`D=&%S:RT^
M:6YI="@D<F%W+"`D871T<RP@)&QA<W1V97)S:6]N*3L-"B`@("`@("`@("`@
M("`@("`D<F5S(#T@)'1A<VLM/G-T87)T4V5S<VEO;B@D=&AI<RP@)&%T='-;
M)VEN<W1A;&QE9%]A<R==*3L-"B`@("`@("`@("`@("`@("!I9B`H(21R97,I
M('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[("\O('-K:7`@=&AI
M<R!F:6QE#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R97,I*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<F5S.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D87-S:6=N(#T@)B1T87-K.PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V-R:7!T<UM=(#T@)B1A<W-I9VX[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?<V-R:7!T<RDI('L-
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!R=6Y0;W-T
M:6YS=&%L;%-C<FEP=',H*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YI
M;FET4&]S=&EN<W1A;&Q38W)I<'1S*"DI('L-"B`@("`@("`@("`@("1U:2`]
M("9014%27T9R;VYT96YD.CIS:6YG;&5T;VXH*3L-"B`@("`@("`@("`@(&EF
M("@D=6DI('L-"B`@("`@("`@("`@("`@("`D=6DM/G)U;E!O<W1I;G-T86QL
M4V-R:7!T<R@D=&AI<RT^7W-C<FEP=',L("1T:&ES*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@('T-"@T*#0H@("`@+RHJ#0H@("`@("H@0V]N
M=F5R="!A(')E8W5R<VEV92!S970@;V8@/&1I<CX@86YD(#QF:6QE/B!T86=S
M(&EN=&\@82!S:6YG;&4@/&1I<CX@=&%G('=I=&@-"B`@("`@*B`\9FEL93X@
M=&%G<RX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!F;&%T=&5N1FEL96QI<W0H
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V)U;F1L92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@
M("!]#0H@("`@("`@("1F:6QE;&ES="`](&%R<F%Y*"D[#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G
M75LG9&ER)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V=E=$9L871T96YE
M9$9I;&5L:7-T*"1F:6QE;&ES="P@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N
M=&5N=',G75LG9&ER)UTI.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D9FEL
M96QI<W1;,5TI*2![#0H@("`@("`@("`@("`@("`@)&9I;&5L:7-T(#T@)&9I
M;&5L:7-T6S!=.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72`]("1F
M:6QE;&ES=#L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=D:7(G72D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`O+R!E;'-E(&%L<F5A9'D@9FQA='1E;F5D(&)U
M="!C:&5C:R!F;W(@8F%S96EN<W1A;&QD:7(@<')O<&%G871I;VX-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT
M<R==6R=D:7(G75LG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O
M6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT
M96YT<R==6R=D:7(G75LG9FEL92==(&%S("1I(#T^("1F:6QE*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9I;&5;)V%T=')I8G,G
M75LG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)&E=6R=A='1R:6)S)UU;)V)A
M<V5I;G-T86QL9&ER)UT-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`]
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R
M:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S
M)UU;)V1I<B==6R=F:6QE)UU;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75LG871T<FEB<R==6R=B
M87-E:6YS=&%L;&1I<B==#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG871T
M<FEB<R==6R=B87-E:6YS=&%L;&1I<B==.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y('1H
M92!F:6YA;"!F;&%T=&5N960@9FEL92!L:7-T#0H@("`@("H@0'!A<F%M(&%R
M<F%Y('1H92!C=7)R96YT(&1I<F5C=&]R>2!B96EN9R!P<F]C97-S960-"B`@
M("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&%N>2!R96-U<G-I=F5L>2!I;FAE
M<FET960@8F%E:6YS=&%L;&1I<B!A='1R:6)U=&4-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('!R:79A=&4@<F5C=7)S:6]N('9A<FEA8FQE#0H@("`@("H@0')E
M='5R;B!A<G)A>0T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V=E=$9L871T96YE9$9I;&5L:7-T*"8D9FEL97,L
M("1D:7(L("1B87-E:6YS=&%L;"`](&9A;'-E+"`D<&%T:"`]("<G*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1D:7);)V%T=')I8G,G72D@)B8@:7-S
M970H)&1I<ELG871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@
M("`@("`@("`@)&)A<V5I;G-T86QL(#T@)&1I<ELG871T<FEB<R==6R=B87-E
M:6YS=&%L;&1I<B==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M9&ER6R=D:7(G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1I<ELG
M9&ER)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1I<ELG9&ER)UT@/2!A
M<G)A>2@D9&ER6R=D:7(G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!F;W)E86-H("@D9&ER6R=D:7(G72!A<R`D<W5B9&ER*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<W5B9&ER6R=A='1R:6)S)UTI('Q\("%I
M<W-E="@D<W5B9&ER6R=A='1R:6)S)UU;)VYA;64G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`G*G5N:VYO=VXJ)SL-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D;F%M92`]("1S
M=6)D:7);)V%T=')I8G,G75LG;F%M92==.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D;F5W<&%T:"`](&5M<'1Y*"1P871H*2`_("1N
M86UE(#H-"B`@("`@("`@("`@("`@("`@("`@)'!A=&@@+B`G+R<@+B`D;F%M
M93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V=E=$9L871T96YE9$9I;&5L
M:7-T*"1F:6QE<RP@)'-U8F1I<BP-"B`@("`@("`@("`@("`@("`@("`@)&)A
M<V5I;G-T86QL+"`D;F5W<&%T:"D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D:7);)V9I;&4G72DI('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&1I<ELG9FEL92==6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("1D:7);)V9I;&4G72`](&%R<F%Y*"1D:7);)V9I;&4G72D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&ER6R=F
M:6QE)UT@87,@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D871T<G,@/2`D
M9FEL95LG871T<FEB<R==.PT*("`@("`@("`@("`@("`@("1N86UE(#T@)&%T
M=')S6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@:68@*"1B87-E:6YS=&%L
M;"`F)B`A:7-S970H)&%T=')S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D871T<G-;)V)A<V5I;G-T86QL9&ER)UT@/2`D
M8F%S96EN<W1A;&P[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1A='1R<ULG;F%M92==(#T@96UP='DH)'!A=&@I(#\@)&YA;64@.B`D
M<&%T:"`N("<O)R`N("1N86UE.PT*("`@("`@("`@("`@("`@("1A='1R<ULG
M;F%M92==(#T@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O*R$G
M*2P@87)R87DH)R\G+"`G+R<I+`T*("`@("`@("`@("`@("`@("`@("`D871T
M<G-;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@)&9I;&5;)V%T=')I8G,G
M72`]("1A='1R<SL-"B`@("`@("`@("`@("`@("`D9FEL97-;72`]("1F:6QE
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@<V5T0V]N9FEG*"8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]C;VYF:6<@/2`F)&-O;F9I9SL-"B`@("`@("`@)'1H:7,M/E]R96=I
M<W1R>2`]("8D8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('-E=$QO9V=E<B@F)&QO9V=E<BD-"B`@("![#0H@("`@("`@
M(&EF("@A:7-?;V)J96-T*"1L;V=G97(I('Q\("%M971H;V1?97AI<W1S*"1L
M;V=G97(L("=L;V<G*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)TQO9V=E<B!M=7-T(&)E(&-O;7!A=&EB;&4@=VET:"!014%2
M7T-O;6UO;CHZ;&]G)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]L
M;V=G97(@/2`F)&QO9V=E<CL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!7
M05).24Y'("T@9&\@;F]T('5S92!T:&ES(&9U;F-T:6]N(&1I<F5C=&QY('5N
M;&5S<R!Y;W4@:VYO=R!W:&%T('EO=2=R92!D;VEN9PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N('-E=$1E<',H)&1E<',I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G72`]("1D97!S.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=%!A8VMA9V5F:6QE*"1F:6QE+"`D87)C
M:&EV92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M1FEL92`]("1F:6QE.PT*("`@("`@("`D=&AI<RT^7V%R8VAI=F5&:6QE(#T@
M)&%R8VAI=F4@/R`D87)C:&EV92`Z("1F:6QE.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J(%=R87!P97(@=&\@>T!L:6YK(%!%05)?17)R;W)3=&%C:SHZ
M9V5T17)R;W)S*"E]#0H@("`@("H@0'!A<F%M(&)O;VQE86X@9&5T97)M:6YE
M<R!W:&5T:&5R('1O('!U<F=E('1H92!E<G)O<B!S=&%C:R!A9G1E<B!R971R
M:65V:6YG#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%9A;&ED871I;VY787)N:6YG<R@D<'5R9V4@/2!T<G5E*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<W1A8VLM/F=E=$5R<F]R
M<R@D<'5R9V4I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V5&
M:6QE*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5&
M:6QE.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$%R8VAI=F5&:6QE*"D-
M"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V%R8VAI=F5&:6QE.PT*
M("`@('T-"@T*#0H@("`@+RHJ#0H@("`@("H@1&ER96-T;'D@<V5T('1H92!A
M<G)A>2!T:&%T(&1E9FEN97,@=&AI<R!P86-K86=E9FEL90T*("`@("`J#0H@
M("`@("H@5T%23DE.1SH@;F\@=F%L:61A=&EO;BX@(%1H:7,@<VAO=6QD(&]N
M;'D@8F4@<&5R9F]R;65D(&)Y(&EN=&5R;F%L(&UE=&AO9',-"B`@("`@*B!I
M;G-I9&4@4$5!4B!O<B!B>2!I;G!U='1I;F<@86X@87)R87D@<V%V960@9G)O
M;2!A;B!E>&ES=&EN9R!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A
M<F%M(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9G)O;4%R<F%Y*"1P
M:6YF;RD-"B`@("![#0H@("`@("`@('5N<V5T*"1P:6YF;ULG;VQD)UTI.PT*
M("`@("`@("!U;G-E="@D<&EN9F];)WAS9'9E<G-I;VXG72D[#0H@("`@("`@
M("1T:&ES+3Y?:6YC;VUP;&5T92`](&9A;'-E.PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O(#T@)'!I;F9O.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&ES26YC;VUP;&5T92@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M
M/E]I;F-O;7!L971E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!R971U
M<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!T;T%R<F%Y*"1F;W)R
M96<@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A)'1H:7,M/G9A;&ED
M871E*%!%05)?5D%,241!5$5?3D]234%,*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^
M9V5T07)R87DH)&9O<G)E9RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T
M07)R87DH)&9O<E)E9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"1F
M;W)296<I('L-"B`@("`@("`@("`@("1A<G(@/2`D=&AI<RT^7W!A8VMA9V5)
M;F9O.PT*("`@("`@("`@("`@)&%R<ELG;VQD)UT@/2!A<G)A>2@I.PT*("`@
M("`@("`@("`@)&%R<ELG;VQD)UU;)W9E<G-I;VXG72`]("1T:&ES+3YG9716
M97)S:6]N*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG<F5L96%S95]D
M871E)UT@/2`D=&AI<RT^9V5T1&%T92@I.PT*("`@("`@("`@("`@)&%R<ELG
M;VQD)UU;)W)E;&5A<V5?<W1A=&4G72`]("1T:&ES+3YG9713=&%T92@I.PT*
M("`@("`@("`@("`@)&%R<ELG;VQD)UU;)W)E;&5A<V5?;&EC96YS92==(#T@
M)'1H:7,M/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@("`@("1A<G);)V]L9"==
M6R=R96QE87-E7VYO=&5S)UT@/2`D=&AI<RT^9V5T3F]T97,H*3L-"B`@("`@
M("`@("`@("1A<G);)V]L9"==6R=R96QE87-E7V1E<',G72`]("1T:&ES+3YG
M971$97!S*"D[#0H@("`@("`@("`@("`D87)R6R=O;&0G75LG;6%I;G1A:6YE
M<G,G72`]("1T:&ES+3YG971-86EN=&%I;F5R<R@I.PT*("`@("`@("`@("`@
M)&%R<ELG>'-D=F5R<VEO;B==(#T@)S(N,"<[#0H@("`@("`@("`@("!R971U
M<FX@)&%R<CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1I;F9O
M(#T@)'1H:7,M/E]P86-K86=E26YF;SL-"B`@("`@("`@("`@('5N<V5T*"1I
M;F9O6R=D:7)T<F5E)UTI.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O
M6R=?;&%S='9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("!U;G-E="@D
M:6YF;ULG7VQA<W1V97)S:6]N)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*&ES<V5T*"1I;F9O6R<C8FEN87)Y<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@("`@('5N<V5T*"1I;F9O6R<C8FEN87)Y<&%C:V%G92==
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D:6YF;SL-
M"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N('!A8VMA9V5);F9O
M*"1F:65L9"D-"B`@("![#0H@("`@("`@("1A<G(@/2`D=&AI<RT^9V5T07)R
M87DH=')U92D[#0H@("`@("`@(&EF("@D9FEE;&0@/3T@)W-T871E)RD@>PT*
M("`@("`@("`@("`@<F5T=7)N("1A<G);)W-T86)I;&ET>2==6R=R96QE87-E
M)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F:65L9"`]/2`G87!I+79E
M<G-I;VXG*2![#0H@("`@("`@("`@("!R971U<FX@)&%R<ELG=F5R<VEO;B==
M6R=A<&DG73L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9I96QD(#T]("=A
M<&DM<W1A=&4G*2![#0H@("`@("`@("`@("!R971U<FX@)&%R<ELG<W1A8FEL
M:71Y)UU;)V%P:2==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M87)R6R=O;&0G75LD9FEE;&1=*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]S
M=')I;F<H)&%R<ELG;VQD)UU;)&9I96QD72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@;G5L;#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B`D87)R6R=O;&0G75LD9FEE;&1=.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D87)R6R1F:65L9%TI*2![#0H@("`@("`@("`@("!I9B`H
M(6ES7W-T<FEN9R@D87)R6R1F:65L9%TI*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&YU;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U
M<FX@)&%R<ELD9FEE;&1=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!N
M=6QL.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$YA;64H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3YG971086-K86=E*"D[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G92@I#0H@("`@>PT*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG;F%M92==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)VYA;64G73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T0VAA;FYE;"@I#0H@("`@>PT*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)U]?=7)I)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N('-T<G1O;&]W97(H)'1H:7,M/E]P86-K86=E26YF
M;ULG8VAA;FYE;"==*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T57)I*"D-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=U
M<FDG73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T17AT96YD<R@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG97AT96YD<R==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V5X
M=&5N9',G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4W5M;6%R>2@I#0H@("`@>PT*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W5M;6%R>2==
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W-U;6UA<GDG73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5S8W)I<'1I;VXH*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<V-R:7!T:6]N)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5S8W)I<'1I;VXG73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T36%I
M;G1A:6YE<G,H)')A=R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=L96%D)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1R
M87<I('L-"B`@("`@("`@("`@("1R970@/2!A<G)A>2@G;&5A9"<@/3X@)'1H
M:7,M/E]P86-K86=E26YF;ULG;&5A9"==*3L-"B`@("`@("`@("`@("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G72DI(#\-"B`@("`@
M("`@("`@("`@("`D<F5T6R=D979E;&]P97(G72`]("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E=F5L;W!E<B==(#IN=6QL.PT*("`@("`@("`@("`@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1R:6)U=&]R)UTI*2`_#0H@("`@
M("`@("`@("`@("`@)')E=%LG8V]N=')I8G5T;W(G72`]("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-O;G1R:6)U=&]R)UT@.FYU;&P[#0H@("`@("`@("`@("`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG:&5L<&5R)UTI*2`_#0H@("`@
M("`@("`@("`@("`@)')E=%LG:&5L<&5R)UT@/2`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=H96QP97(G72`Z;G5L;#L-"B`@("`@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)')E="`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("`D;&5A9',@/2!I<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=L96%D)UU;,%TI(#\@)'1H:7,M/E]P86-K86=E26YF;ULG;&5A
M9"==(#H-"B`@("`@("`@("`@("`@("!A<G)A>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=L96%D)UTI.PT*("`@("`@("`@("`@9F]R96%C:"`H)&QE861S(&%S
M("1L96%D*2![#0H@("`@("`@("`@("`@("`@)',@/2`D;&5A9#L-"B`@("`@
M("`@("`@("`@("`D<ULG:&%N9&QE)UT@/2`D<ULG=7-E<B==.PT*("`@("`@
M("`@("`@("`@('5N<V5T*"1S6R=U<V5R)UTI.PT*("`@("`@("`@("`@("`@
M("1S6R=R;VQE)UT@/2`G;&5A9"<[#0H@("`@("`@("`@("`@("`@)')E=%M=
M(#T@)',[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG9&5V96QO<&5R)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&QE861S(#T@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M9&5V96QO<&5R)UU;,%TI(#\-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5V96QO<&5R)UT@.@T*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G72D[
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QE861S(&%S("1M86EN=&%I
M;F5R*2![#0H@("`@("`@("`@("`@("`@("`@("1S(#T@)&UA:6YT86EN97([
M#0H@("`@("`@("`@("`@("`@("`@("1S6R=H86YD;&4G72`]("1S6R=U<V5R
M)UT[#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1S6R=U<V5R)UTI.PT*
M("`@("`@("`@("`@("`@("`@("`D<ULG<F]L92==(#T@)V1E=F5L;W!E<B<[
M#0H@("`@("`@("`@("`@("`@("`@("1R971;72`]("1S.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT<FEB=71O<B==*2D@>PT*("`@
M("`@("`@("`@("`@("1L96%D<R`](&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1R:6)U=&]R)UU;,%TI(#\-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=')I8G5T;W(G72`Z#0H@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1R
M:6)U=&]R)UTI.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L96%D<R!A
M<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@("`@("`@("`D<R`]("1M
M86EN=&%I;F5R.PT*("`@("`@("`@("`@("`@("`@("`D<ULG:&%N9&QE)UT@
M/2`D<ULG=7-E<B==.PT*("`@("`@("`@("`@("`@("`@("!U;G-E="@D<ULG
M=7-E<B==*3L-"B`@("`@("`@("`@("`@("`@("`@)'-;)W)O;&4G72`]("=C
M;VYT<FEB=71O<B<[#0H@("`@("`@("`@("`@("`@("`@("1R971;72`]("1S
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=H96QP97(G72DI
M('L-"B`@("`@("`@("`@("`@("`D;&5A9',@/2!I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=H96QP97(G75LP72D@/PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=H96QP97(G72`Z#0H@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==
M*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D;&5A9',@87,@)&UA:6YT
M86EN97(I('L-"B`@("`@("`@("`@("`@("`@("`@)',@/2`D;6%I;G1A:6YE
M<CL-"B`@("`@("`@("`@("`@("`@("`@)'-;)VAA;F1L92==(#T@)'-;)W5S
M97(G73L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)'-;)W5S97(G72D[
M#0H@("`@("`@("`@("`@("`@("`@("1S6R=R;VQE)UT@/2`G:&5L<&5R)SL-
M"B`@("`@("`@("`@("`@("`@("`@)')E=%M=(#T@)',[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N("1R
M970[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=$QE861S*"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=L96%D)UTI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG;&5A9"==.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G971$979E;&]P97)S*"D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E;&]P97(G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=D979E
M;&]P97(G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T0V]N=')I8G5T;W)S*"D-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT
M<FEB=71O<B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V-O;G1R:6)U=&]R)UT[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$AE;'!E
M<G,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)VAE;'!E<B==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)VAE;'!E<B==.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971$871E
M*"1D871E*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=D871E)UTI*2![#0H@("`@("`@("`@("`O+R!E;G-U<F4@
M=&AA="!T:&4@97AT96YD<R!T86<@:7,@<V5T('5P(&EN('1H92!R:6=H="!L
M;V-A=&EO;@T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T
M:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L#0H@("`@
M("`@("`@("`@("`@87)R87DH)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@
M("`@("`@("`@("`@("=S=&%B:6QI='DG+"`G;&EC96YS92<L("=N;W1E<R<L
M("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=S<F-P
M86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@("`@("`@("`@("=P:'!R
M96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@
M("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL(&%R
M<F%Y*"DL("=D871E)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG9&%T92==(#T@)&1A=&4[#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T5&EM92@D
M=&EM92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=&EM92==
M*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE('1I;64@=&%G
M(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D
M=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("=S=&%B:6QI='DG
M+"`G;&EC96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V
M:61E<V5X=&5N<VEO;B<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@
M("`@("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G
M+`T*("`@("`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD
M;&4G+"`G8VAA;F=E;&]G)RDL("1T:6UE+"`G=&EM92<I.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W1I;64G72`]("1T:6UE
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1A=&4H*0T*("`@('L-"B`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1A=&4G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=D
M871E)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&=E=%1I;64H*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W1I;64G72DI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=T:6UE)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!P86-K86=E?&%P:2!V97)S:6]N(&-A
M=&5G;W)Y('1O(')E='5R;@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%9E
M<G-I;VXH)&ME>2`]("=R96QE87-E)RD-"B`@("![#0H@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)&ME>5TI*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R
M<VEO;B==6R1K97E=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9713=&%B:6QI='DH*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-T
M86)I;&ET>2==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)W-T86)I;&ET>2==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9713=&%T92@D
M:V5Y(#T@)W)E;&5A<V4G*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R1K97E=*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET
M>2==6R1K97E=.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971,:6-E;G-E*"1R87<@/2!F86QS
M92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=L:6-E;G-E)UTI*2![#0H@("`@("`@("`@("!I9B`H)')A=RD@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L
M:6-E;G-E)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG;&EC96YS92==*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E
M;G-E)UU;)U]C;VYT96YT)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=L:6-E
M;G-E)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$QI8V5N<V5,
M;V-A=&EO;B@I#0H@("`@>PT*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VQI8V5N<V4G72D@?'P@(6ES7V%R<F%Y*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG;&EC96YS92==6R=A='1R:6)S)UT[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T3F]T97,H*0T*("`@('L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG;F]T97,G73L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@4F5T=7)N('1H92`\=7-E<W)O;&4^('1A9R!C;VYT96YT
M<RP@:68@86YY#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=%5S97-R;VQE*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L92==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S
M97-R;VQE)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!T:&4@/'5S97-T87-K
M/B!T86<@8V]N=&5N=',L(&EF(&%N>0T*("`@("`J($!R971U<FX@87)R87E\
M9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G9715<V5S=&%S:R@I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M=7-E<W1A<VLG72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=U<V5S=&%S:R==.PT*("`@("`@("!]#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES('-H
M;W5L9"!O;FQY(&)E('5S960@=&\@<F5T<FEE=F4@9FEL96YA;65S(&%N9"!I
M;G-T86QL(&%T=')I8G5T97,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971&
M:6QE;&ES="@D<')E<V5R=F4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==*2`F)B`A
M)'!R97-E<G9E*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG9FEL96QI<W0G73L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^9FQA='1E;D9I;&5L:7-T*"D[#0H@("`@("`@(&EF("@D8V]N=&5N=',@
M/2`D=&AI<RT^9V5T0V]N=&5N=',H*2D@>PT*("`@("`@("`@("`@)')E="`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1C;VYT96YT<ULG
M9&ER)UU;)V9I;&4G75LP72DI('L-"B`@("`@("`@("`@("`@("`D8V]N=&5N
M='-;)V1I<B==6R=F:6QE)UT@/2!A<G)A>2@D8V]N=&5N='-;)V1I<B==6R=F
M:6QE)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H
M)&-O;G1E;G1S6R=D:7(G75LG9FEL92==(&%S("1F:6QE*2![#0H@("`@("`@
M("`@("`@("`@)&YA;64@/2`D9FEL95LG871T<FEB<R==6R=N86UE)UT[#0H@
M("`@("`@("`@("`@("`@:68@*"$D<')E<V5R=F4I('L-"B`@("`@("`@("`@
M("`@("`@("`@)&9I;&4@/2`D9FEL95LG871T<FEB<R==.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5T6R1N86UE72`]("1F:6QE
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"$D<')E<V5R=F4I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE
M;&ES="==(#T@)')E=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@8V]N9FEG=7)E(&]P
M=&EO;G,@87)R87DL(&EF(&%N>0T*("`@("`J#0H@("`@("H@0')E='5R;B!A
M<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$-O;F9I9W5R
M94]P=&EO;G,H*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K
M86=E5'EP92@I("$]("=E>'1S<F,G*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)')E;&5A<V5S(#T@)'1H:7,M
M/F=E=%)E;&5A<V5S*"D[#0H@("`@("`@(&EF("AI<W-E="@D<F5L96%S97-;
M,%TI*2![#0H@("`@("`@("`@("`D<F5L96%S97,@/2`D<F5L96%S95LP73L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)')E;&5A<V5S6R=C;VYF
M:6=U<F5O<'1I;VXG72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)')E
M;&5A<V5S6R=C;VYF:6=U<F5O<'1I;VXG75LP72DI('L-"B`@("`@("`@("`@
M("`@("`D<F5L96%S97-;)V-O;F9I9W5R96]P=&EO;B==(#T@87)R87DH)')E
M;&5A<V5S6R=C;VYF:6=U<F5O<'1I;VXG72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C;W5N="@D<F5L96%S97-;
M)V-O;F9I9W5R96]P=&EO;B==*3L@)&DK*RD@>PT*("`@("`@("`@("`@("`@
M("1R96QE87-E<ULG8V]N9FEG=7)E;W!T:6]N)UU;)&E=(#T@)')E;&5A<V5S
M6R=C;VYF:6=U<F5O<'1I;VXG75LD:5U;)V%T=')I8G,G73L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5L96%S97-;)V-O;F9I9W5R
M96]P=&EO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&]N;'D@=7-E9"!A
M="!I;G-T86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI>F%T:6]N#0H@("`@
M("H@:7,@;W9E<BX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R97-E=$9I;&5L
M:7-T*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I
M;&5L:7-T)UT@/2!A<G)A>2@I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M(%)E=')I979E(&$@;&ES="!O9B!F:6QE<R!T:&%T('-H;W5L9"!B92!I;G-T
M86QL960@;VX@=&AI<R!C;VUP=71E<@T*("`@("`J($!R971U<FX@87)R87D-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971);G-T86QL871I;VY&:6QE;&ES
M="@D9F]R9FEL96-H96-K(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8V]N
M=&5N=',@/2`D=&AI<RT^9V5T1FEL96QI<W0H=')U92D[#0H@("`@("`@(&EF
M("AI<W-E="@D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T
M86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D8F%S92`]("1C;VYT96YT<ULG
M9&ER)UU;)V%T=')I8G,G75LG8F%S96EN<W1A;&QD:7(G73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N
M9&QE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O
M<B@-"B`@("`@("`@("`@("`@("`G17AC97!T:6]N.B!B=6YD;&5S('-H;W5L
M9"!B92!H86YD;&5D(&EN(&1O=VYL;V%D(&-O9&4@;VYL>2<I.PT*("`@("`@
M("!]#0H@("`@("`@("1R96QE87-E(#T@)'1H:7,M/F=E=%)E;&5A<V5S*"D[
M#0H@("`@("`@(&EF("@D<F5L96%S92D@>PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D<F5L96%S95LP72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1R96QE87-E6R=I;G-T86QL8V]N9&ET:6]N<R==*2`F)B`A:7-S970H
M)')E;&5A<V5;)V9I;&5L:7-T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M(&EF("@D9F]R9FEL96-H96-K*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F=E=$9I;&5L:7-T*"D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1C;VYT96YT
M<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E;&5A
M<V4@/2!A<G)A>2@D<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`D9&5P8VAE8VME<B`]("8D=&AI<RT^9V5T4$5!4D1E<&5N9&5N8WDR
M*"1T:&ES+3Y?8V]N9FEG+"!A<G)A>2@I+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*"=C:&%N;F5L)R`]/B`D=&AI<RT^9V5T0VAA;FYE;"@I+"`G<&%C:V%G
M92<@/3X@)'1H:7,M/F=E=%!A8VMA9V4H*2DL#0H@("`@("`@("`@("`@("`@
M4$5!4E]604Q)1$%415])3E-404Q,24Y'*3L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1R96QE87-E(&%S("1I;G-T86YC92D@>PT*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D:6YS=&%N8V5;)VEN<W1A;&QC;VYD:71I;VYS)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1I;G-T86QL8V]N9&ET:6]N<R`]("1I
M;G-T86YC95LG:6YS=&%L;&-O;F1I=&EO;G,G73L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1I;G-T86QL8V]N9&ET:6]N<RDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG
M*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1I;G-T86QL8V]N9&ET:6]N<R!A<R`D='EP92`]/B`D8V]N
M9&ET:6]N<RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&-O;F1I=&EO;G-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;VYD:71I;VYS(#T@87)R87DH)&-O;F1I=&EO;G,I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D8V]N9&ET:6]N<R!A<R`D8V]N
M9&ET:6]N*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M970@/2`D9&5P8VAE8VME<BT^>R)V86QI9&%T97LD='EP97U$97!E;F1E;F-Y
M(GTH)&-O;F1I=&EO;BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU92`S.R`O+R!S:VEP('1H:7,@<F5L96%S90T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("\O('1H:7,@:7,@=&AE(')E;&5A<V4@=&\@=7-E#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LG9FEL96QI<W0G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@+R\@:6=N;W)E(&9I;&5S#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D:6YS=&%N8V5;)V9I;&5L:7-T)UU;
M)VEG;F]R92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EG;F]R
M92`](&ES<V5T*"1I;G-T86YC95LG9FEL96QI<W0G75LG:6=N;W)E)UU;,%TI
M(#\-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%N8V5;)V9I
M;&5L:7-T)UU;)VEG;F]R92==(#H-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D:6YS=&%N8V5;)V9I;&5L:7-T)UU;)VEG;F]R92==*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I9VYO<F4@87,@
M)&EG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970@*"1C
M;VYT96YT<ULD:6=;)V%T=')I8G,G75LG;F%M92==72D[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@+R\@:6YS=&%L;"!F:6QE<R!A<R!T:&ES(&YA;64-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;G-T86YC95LG9FEL
M96QI<W0G75LG:6YS=&%L;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN<W1A;&QA<R`](&ES<V5T*"1I;G-T86YC95LG9FEL96QI<W0G75LG
M:6YS=&%L;"==6S!=*2`_#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&EN<W1A;F-E6R=F:6QE;&ES="==6R=I;G-T86QL)UT@.@T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1I;G-T86YC95LG9FEL96QI<W0G
M75LG:6YS=&%L;"==*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1I;G-T86QL87,@87,@)&%S*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&-O;G1E;G1S6R1A<ULG871T<FEB<R==6R=N86UE)UU=6R=A
M='1R:6)S)UU;)VEN<W1A;&PM87,G72`]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1A<ULG871T<FEB<R==6R=A<R==.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9F]R9FEL96-H
M96-K*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT
M<R!A<R`D9FEL92`]/B`D871T<G,I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYT96YT<ULD9FEL95T@/2`D871T<G-;)V%T=')I8G,G73L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!R971U<FX@)&-O;G1E;G1S.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!](&5L<V4@>R`O+R!S:6UP;&4@<F5L96%S92`M(&YO(&EN<W1A
M;&QC;VYD:71I;VYS(&]R(&EN<W1A;&PM87,-"B`@("`@("`@("`@(&EF("@D
M9F]R9FEL96-H96-K*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YG971&:6QE;&ES="@I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M<F5T=7)N("1C;VYT96YT<SL-"B`@("`@("`@?0T*("`@("`@("`O+R!N;R!R
M96QE87-E<R!M871C:&5D#0H@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=.;R!R96QE87-E<R!I;B!P86-K86=E+GAM;"!M871C:&5D('1H92!E
M>&ES=&EN9R!O<&5R871I;F<@)R`N#0H@("`@("`@("`@("`G<WES=&5M+"!E
M>'1E;G-I;VYS(&EN<W1A;&QE9"P@;W(@87)C:&ET96-T=7)E+"!C86YN;W0@
M:6YS=&%L;"<I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@:7,@
M;VYL>2!U<V5D(&%T(&EN<W1A;&PM=&EM92P@869T97(@86QL('-E<FEA;&EZ
M871I;VX-"B`@("`@*B!I<R!O=F5R+@T*("`@("`J($!P87)A;2!S=')I;F<@
M9FEL92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!I;G-T86QL960@<&%T
M:`T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$EN<W1A;&QE9$%S*"1F:6QE
M+"`D<&%T:"D-"B`@("![#0H@("`@("`@(&EF("@D<&%T:"D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;
M)&9I;&5=6R=I;G-T86QL961?87,G72`]("1P871H.PT*("`@("`@("!]#0H@
M("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;
M)&9I;&5=6R=I;G-T86QL961?87,G72D[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T26YS=&%L;&5D3&]C871I;VXH)&9I;&4I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD
M9FEL95U;)VEN<W1A;&QE9%]A<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=6R=I;G-T
M86QL961?87,G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I<R!O;FQY('5S960@
M870@:6YS=&%L;"UT:6UE+"!A9G1E<B!A;&P@<V5R:6%L:7IA=&EO;@T*("`@
M("`J(&ES(&]V97(N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YS=&%L;&5D
M1FEL92@D9FEL92P@)&%T=',I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95TI*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F
M:6QE72`]#0H@("`@("`@("`@("`@("`@87)R87E?;65R9V4H)'1H:7,M/E]P
M86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95TL("1A='1S6R=A='1R:6)S
M)UTI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95T@/2`D871T<ULG871T<FEB
M<R==.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T
M<FEE=F4@=&AE(&-O;G1E;G1S('1A9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$-O;G1E;G1S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UT[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J
M*@T*("`@("`J($!P87)A;2!S=')I;F<@9G5L;"!P871H('1O(&9I;&4-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&%T=')I8G5T92!N86UE#0H@("`@("H@0'!A
M<F%M('-T<FEN9R!A='1R:6)U=&4@=F%L=64-"B`@("`@*B!`<&%R86T@:6YT
M(')I<VMY(&)U="!F87-T("T@=7-E('1H:7,@=&\@8VAO;W-E(&$@9FEL92!B
M87-E9"!O;B!I=',@<&]S:71I;VX@:6X@=&AE(&QI<W0-"B`@("`@*B`@("`@
M("`@("`@(&]F(&9I;&5S+B`@26YD97@@:7,@>F5R;RUB87-E9"!L:6ME(%!(
M4"!A<G)A>7,N#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@;W!E
M<F%T:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1FEL94%T=')I8G5T
M92@D9FEL96YA;64L("1A='1R+"`D=F%L=64L("1I;F1E>"`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M:68@*&EN7V%R<F%Y*"1A='1R+"!A<G)A>2@G<F]L92<L("=N86UE)RP@)V)A
M<V5I;G-T86QL9&ER)RDI*2![#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&5S
M5F%L:60@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN9&5X
M("$]/2!F86QS92`F)@T*("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R1I;F1E>%U;
M)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)&EN9&5X75LG871T<FEB
M<R==6R1A='1R72`]("1V86QU93L-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D9FEL
M97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG
M9FEL92==.PT*("`@("`@("!I9B`H(6ES<V5T*"1F:6QE<ULP72DI('L-"B`@
M("`@("`@("`@("1F:6QE<R`](&%R<F%Y*"1F:6QE<RD[#0H@("`@("`@("`@
M("`D:6YD(#T@9F%L<V4[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D:6YD(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M9FEL97,@87,@)&D@/3X@)&9I;&4I('L-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D9FEL95LG871T<FEB<R==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M9FEL95LG871T<FEB<R==6R=N86UE)UT@/3T@)&9I;&5N86UE*2![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@D:6YD*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G
M75LG9FEL92==6R1I75LG871T<FEB<R==6R1A='1R72`]("1V86QU93L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==
M6R=F:6QE)UU;)V%T=')I8G,G75LD871T<ET@/2`D=F%L=64[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!S971$:7)T<F5E*"1P871H*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG9&ER=')E92==6R1P871H72`]('1R=64[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9V5T1&ER=')E92@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&ER=')E92==*2`F
M)B!C;W5N="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D:7)T<F5E)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG9&ER=')E
M92==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!R97-E=$1I<G1R964H*0T*("`@('L-"B`@("`@
M("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG9&ER=')E92==*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@=&AI
M<R!P86-K86=E(&-L86EM<R!I="!I<R!C;VUP871I8FQE('=I=&@@=&AE('9E
M<G-I;VX@;V8-"B`@("`@*B!T:&4@<&%C:V%G92!T:&%T(&AA<R!A(')E8V]M
M;65N9&5D('9E<G-I;VX@9&5P96YD96YC>0T*("`@("`J($!P87)A;2!014%2
M7U!A8VMA9V5&:6QE7W8R?%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]$;W=N
M;&]A9&5R7U!A8VMA9V4-"B`@("`@*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!I<T-O;7!A=&EB;&4H)'!F*0T*("`@('L-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP871I
M8FQE)UTI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M:&%N;F5L)UTI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)&UE(#T@)'!F+3YG971697)S:6]N*"D[#0H@("`@
M("`@("1C;VUP871I8FQE(#T@)'1H:7,M/E]P86-K86=E26YF;ULG8V]M<&%T
M:6)L92==.PT*("`@("`@("!I9B`H(6ES<V5T*"1C;VUP871I8FQE6S!=*2D@
M>PT*("`@("`@("`@("`@)&-O;7!A=&EB;&4@/2!A<G)A>2@D8V]M<&%T:6)L
M92D[#0H@("`@("`@('T-"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@
M("`@(&9O<F5A8V@@*"1C;VUP871I8FQE(&%S("1I;F9O*2![#0H@("`@("`@
M("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;ULG;F%M92==*2`]/2!S=')T;VQO
M=V5R*"1P9BT^9V5T4&%C:V%G92@I*2D@>PT*("`@("`@("`@("`@("`@(&EF
M("AS=')T;VQO=V5R*"1I;F9O6R=C:&%N;F5L)UTI(#T]('-T<G1O;&]W97(H
M)'!F+3YG971#:&%N;F5L*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("1F
M;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(21F;W5N9"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D:6YF;ULG97AC;'5D
M92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG97AC;'5D
M92==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=E>&-L=61E)UT@
M/2!A<G)A>2@D:6YF;ULG97AC;'5D92==*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=E>&-L=61E)UT@87,@)&5X8VQU
M9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1M
M92P@)&5X8VQU9&4L("<]/2<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D;64L
M("1I;F9O6R=M:6XG72P@)SX])RD@)B8@=F5R<VEO;E]C;VUP87)E*"1M92P@
M)&EN9F];)VUA>"==+"`G/#TG*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!G971#;VUP871I8FQE*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VUP871I8FQE
M)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]M<&%T:6)L92==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971$97!E;F1E;F-I97,H
M*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)V1E<&5N9&5N8VEE<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!I<U-U8G!A8VMA9V5/9B@D<"D-"B`@("![#0H@("`@("`@(')E='5R;B`D
M<"T^:7-3=6)P86-K86=E*"1T:&ES*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!$971E<FUI;F5S('=H971H97(@=&AE('!A<W-E9"!I;B!P86-K86=E
M(&ES(&$@<W5B<&%C:V%G92!O9B!T:&ES('!A8VMA9V4N#0H@("`@("H-"B`@
M("`@*B!.;R!V97)S:6]N(&-H96-K:6YG(&ES(&1O;F4L(&]N;'D@;F%M92!V
M97)I9FEC871I;VXN#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?
M=C%\4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!R971U<FX@8F]O;`T*
M("`@("`J+PT*("`@(&9U;F-T:6]N(&ES4W5B<&%C:V%G92@D<"D-"B`@("![
M#0H@("`@("`@("1S=6(@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)W)E<75I<F5D
M)UU;)W-U8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("1S=6(@/2`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG
M<W5B<&%C:V%G92==.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D<W5B6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("1S=6(@/2!A<G)A>2@D<W5B*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V]P=&EO;F%L)UU;
M)W-U8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@("1S=6(Q(#T@)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V]P=&EO;F%L)UU;)W-U
M8G!A8VMA9V4G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'-U8C%;,%TI
M*2![#0H@("`@("`@("`@("`@("`@)'-U8C$@/2!A<G)A>2@D<W5B,2D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D<W5B(#T@87)R87E?;65R9V4H
M)'-U8BP@)'-U8C$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG9W)O=7`G72DI
M('L-"B`@("`@("`@("`@("1G<F]U<"`]("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==.PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D9W)O=7!;,%TI*2![#0H@("`@("`@("`@("`@("`@)&=R;W5P(#T@
M87)R87DH)&=R;W5P*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1G<F]U<"!A<R`D9&5P<RD@>PT*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D9&5P<ULG<W5B<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<W5B,B`]("1D97!S6R=S=6)P86-K86=E)UT[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)'-U8C);,%TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<W5B,B`](&%R<F%Y*"1S=6(R*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<W5B(#T@
M87)R87E?;65R9V4H)'-U8BP@)'-U8C(I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M<W5B(&%S("1D97`I('L-"B`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D
M97!;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D<"T^9V5T4&%C:V%G92@I*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;
M)V-H86YN96PG72D@/3T@<W1R=&]L;W=E<B@D<"T^9V5T0VAA;FYE;"@I*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG=7)I)UT@/3T@)'`M/F=E
M=%5222@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&5P96YD<T]N*"1P86-K86=E
M+"`D8VAA;FYE;"D-"B`@("![#0H@("`@("`@(&EF("@A*"1D97!S(#T@)'1H
M:7,M/F=E=$1E<&5N9&5N8VEE<R@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=P
M86-K86=E)RP@)W-U8G!A8VMA9V4G*2!A<R`D='EP92D@>PT*("`@("`@("`@
M("`@9F]R96%C:"`H87)R87DH)W)E<75I<F5D)RP@)V]P=&EO;F%L)RD@87,@
M)&YE961E9"D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULD
M;F5E9&5D75LD='EP95TI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&1E<'-;)&YE961E9%U;)'1Y<&5=6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E<'-;)&YE961E9%U;)'1Y<&5=(#T@87)R87DH
M)&1E<'-;)&YE961E9%U;)'1Y<&5=*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULD;F5E9&5D
M75LD='EP95T@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<&-H86YN96P@/2!I<W-E="@D9&5P6R=C:&%N;F5L)UTI(#\@)&1E<%LG
M8VAA;FYE;"==(#H@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AS=')T;VQO=V5R*"1D97!;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D
M<&%C:V%G92D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M97!C:&%N;F5L(#T]("1C:&%N;F5L*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]("`-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M<ULG9W)O=7`G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!S6R=G<F]U<"==6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5P
M6R=G<F]U<"==(#T@87)R87DH)&1E<'-;)V=R;W5P)UTI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG9W)O
M=7`G72!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1G<F]U<%LD='EP95TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES7V%R<F%Y*"1G<F]U<%LD='EP95TI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&=R;W5P6R1T>7!E72`](&%R<F%Y*"1G<F]U
M<%LD='EP95TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R1T>7!E72!A<R`D
M9&5P*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<&-H86YN
M96P@/2!I<W-E="@D9&5P6R=C:&%N;F5L)UTI(#\@)&1E<%LG8VAA;FYE;"==
M(#H@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M<W1R=&]L;W=E<B@D9&5P6R=N86UE)UTI(#T]('-T<G1O;&]W97(H)'!A8VMA
M9V4I("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E
M<&-H86YN96P@/3T@)&-H86YN96PI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2`@#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($=E="!T:&4@8V]N=&5N=',@;V8@82!D
M97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J
M($!R971U<FX@87)R87E\9F%L<V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G
M971$97!E;F1E;F-Y1W)O=7`H)&YA;64I#0H@("`@>PT*("`@("`@("`D;F%M
M92`]('-T<G1O;&]W97(H)&YA;64I.PT*("`@("`@("!I9B`H(6ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@
M("`@("1G<F]U<',@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I
M97,G75LG9W)O=7`G73L-"B`@("`@("`@:68@*"%I<W-E="@D9W)O=7!S6S!=
M*2D@>PT*("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"1G<F]U<',I.PT*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1G<F]U<',@87,@)&=R;W5P
M*2![#0H@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D9W)O=7!;)V%T=')I
M8G,G75LG;F%M92==*2`]/2`D;F%M92D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B`D9W)O=7`[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E
M=')I979E(&$@<&%R=&EA;"!P86-K86=E+GAM;"`Q+C`@<F5P<F5S96YT871I
M;VX@;V8@9&5P96YD96YC:65S#0H@("`@("H-"B`@("`@*B!A('9E<GD@;&EM
M:71E9"!R97!R97-E;G1A=&EO;B!O9B!D97!E;F1E;F-I97,@:7,@<F5T=7)N
M960@8GD@=&AI<R!M971H;V0N#0H@("`@("H@5&AE(#QE>&-L=61E/B!T86<@
M9F]R(&5X8VQU9&EN9R!C97)T86EN('9E<G-I;VYS(&]F(&$@9&5P96YD96YC
M>2!I<PT*("`@("`J(&-O;7!L971E;'D@:6=N;W)E9"X@($EN(&%D9&ET:6]N
M+"!D97!E;F1E;F-Y(&=R;W5P<R!A<F4@:6=N;W)E9"P@=VET:"!T:&4-"B`@
M("`@*B!A<W-U;7!T:6]N('1H870@86QL(&1E<&5N9&5N8VEE<R!I;B!D97!E
M;F1E;F-Y(&=R;W5P<R!A<F4@86QS;R!L:7-T960@:6X-"B`@("`@*B!T:&4@
M;W!T:6]N86P@9W)O=7`@=&AA="!W;W)K('=I=&@@86QL(&1E<&5N9&5N8WD@
M9W)O=7!S#0H@("`@("H@0'!A<F%M(&)O;VQE86X@<F5T=7)N('!A8VMA9V4N
M>&UL(#(N,"`\9&5P96YD96YC:65S/B!T86<-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T1&5P<R@D<F%W
M(#T@9F%L<V4L("1N;W!E87)I;G-T86QL97(@/2!F86QS92D-"B`@("![#0H@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E
M;F-I97,G72DI('L-"B`@("`@("`@("`@(&EF("@D<F%W*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N
M8VEE<R==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`D;6%P(#T@87)R87DH#0H@("`@("`@("`@
M("`@("`@)W!H<"<@/3X@)W!H<"<L#0H@("`@("`@("`@("`@("`@)W!A8VMA
M9V4G(#T^("=P:V<G+`T*("`@("`@("`@("`@("`@("=S=6)P86-K86=E)R`]
M/B`G<&MG)RP-"B`@("`@("`@("`@("`@("`G97AT96YS:6]N)R`]/B`G97AT
M)RP-"B`@("`@("`@("`@("`@("`G;W,G(#T^("=O<R<L#0H@("`@("`@("`@
M("`@("`@)W!E87)I;G-T86QL97(G(#T^("=P:V<G+`T*("`@("`@("`@("`@
M("`@("D[#0H@("`@("`@("`@("!F;W)E86-H("AA<G)A>2@G<F5Q=6ER960G
M+"`G;W!T:6]N86PG*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@("`@("1O
M<'1I;VYA;"`]("@D='EP92`]/2`G;W!T:6]N86PG*2`_("=Y97,G(#H@)VYO
M)SL-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V1E<&5N9&5N8VEE<R==6R1T>7!E72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N
M9&5N8VEE<R==6R1T>7!E72!A<R`D9'1Y<&4@/3X@)&1E<',I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1D='EP92`]/2`G<&5A<FEN<W1A;&QE<B<@
M)B8@)&YO<&5A<FEN<W1A;&QE<BD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P<ULP72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1D97!S(#T@87)R87DH)&1E<',I.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!S(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&UA<%LD9'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(&YO('-U<'!O<G0@9F]R(&%R8V@@='EP90T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1D
M='EP92`]/2`G<&5A<FEN<W1A;&QE<B<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=N86UE)UT@/2`G4$5!4B<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<%LG8VAA;FYE;"==(#T@)W!E87(N<&AP
M+FYE="<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D<R`](&%R<F%Y*"=T>7!E)R`]/B`D;6%P6R1D='EP
M95TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)V-H86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<ULG8VAA;FYE;"==(#T@)&1E<%LG8VAA;FYE;"==.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S6R=U<FDG72`]("1D97!;)W5R:2==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<ULG;F%M92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1S6R=R96PG72`]("=N;W0G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1D97!;)VUI;B==*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("%I<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W)E;"==(#T@)VAA<R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S6R=O<'1I;VYA
M;"==(#T@)&]P=&EO;F%L.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("AI<W-E="@D9&5P6R=M:6XG72D@)B8-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W)E;"==(#T@
M)V=E)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)',Q(#T@
M)',[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S,5LG<F5L
M)UT@/2`G;&4G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<ULG=F5R<VEO;B==(#T@)&1E<%LG;6EN)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S,5LG=F5R<VEO;B==(#T@)&1E<%LG;6%X)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9&5P6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<S%;)V-H86YN96PG72`]("1D97!;)V-H86YN96PG73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1T>7!E("$]("=P:'`G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG;F%M
M92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)',Q6R=N86UE)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-;)V]P=&EO;F%L)UT@/2`D;W!T:6]N86P[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S,5LG;W!T:6]N
M86PG72`]("1O<'1I;VYA;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E=%M=(#T@)',Q.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU
M9&4G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<%LG97AC;'5D92==(#T]("1D97!;)VUI;B==*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG<F5L)UT@/2`G9W0G
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)W)E;"==
M(#T@)V=E)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG=F5R<VEO;B==
M(#T@)&1E<%LG;6EN)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1S6R=O<'1I;VYA;"==(#T@)&]P=&EO;F%L.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&1T>7!E("$]("=P:'`G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<ULG;F%M92==
M(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@
M*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2`F)@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=E>&-L
M=61E)UT@/3T@)&1E<%LG;6%X)UTI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S6R=R96PG72`]("=L="<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<ULG<F5L)UT@/2`G;&4G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S6R=V97)S:6]N)UT@/2`D9&5P6R=M87@G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-;)V]P=&EO
M;F%L)UT@/2`D;W!T:6]N86P[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D9'1Y<&4@(3T@)W!H<"<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S6R=N86UE)UT@/2`D9&5P6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2`D<SL-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N="@D<F5T*2D@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!`<F5T=7)N('!H<'QE>'1S<F-\97AT8FEN?&)U;F1L
M97QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V54>7!E
M*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=P:'!R96QE87-E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)W!H
M<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V5X='-R8W)E;&5A<V4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`G97AT<W)C)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG97AT8FEN<F5L96%S92==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("=E>'1B:6XG.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`G8G5N9&QE)SL-"B`@("`@("`@?0T*("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E
M=%)E;&5A<V5S*"D-"B`@("![#0H@("`@("`@("1T>7!E(#T@)'1H:7,M/F=E
M=%!A8VMA9V54>7!E*"D[#0H@("`@("`@(&EF("@D='EP92`A/2`G8G5N9&QE
M)RD@>PT*("`@("`@("`@("`@)'1Y<&4@+CT@)W)E;&5A<V4G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`F)B!I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1T>7!E72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R1T>7!E73L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$-H86YG96QO9R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UTI*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UT[#0H@
M("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&AA<T1E<',H*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==*3L-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E>&UL5F5R<VEO;B@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)S(N,"<[#0H@("`@?0T*#0H@("`@+RHJ
M#0H@("`@("H@0')E='5R;B!A<G)A>7QF86QS90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%-O=7)C95!A8VMA9V4H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V5X=&)I;G)E;&5A<V4G72DI
M('L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2@G8VAA;FYE;"<@/3X@)'1H
M:7,M/E]P86-K86=E26YF;ULG<W)C8VAA;FYE;"==+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("=P86-K86=E)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=S<F-P86-K86=E)UTI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971"=6YD;&5D4&%C:V%G
M97,H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)V)U;F1L92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V)U;F1L961P86-K86=E)UT[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&=E=$QA<W1-;V1I9FEE9"@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG7VQA<W1M;V1I9FEE
M9"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F];)U]L87-T;6]D:69I960G73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T('1H92!C
M;VYT96YT<R!O9B!A(&9I;&4@;&ES=&5D('=I=&AI;B!T:&4@<&%C:V%G92YX
M;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!S=')I
M;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971&:6QE0V]N=&5N=',H)&9I
M;&4I#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/E]A<F-H:79E1FEL92`]
M/2`D=&AI<RT^7W!A8VMA9V5&:6QE*2![("\O('5N<&%C:V5D#0H@("`@("`@
M("`@("`D9&ER(#T@9&ER;F%M92@D=&AI<RT^7W!A8VMA9V5&:6QE*3L-"B`@
M("`@("`@("`@("1F:6QE(#T@)&1I<B`N($1)4D5#5$]265]315!!4D%43U(@
M+B`D9FEL93L-"B`@("`@("`@("`@("1F:6QE(#T@<W1R7W)E<&QA8V4H87)R
M87DH)R\G+"`G7%PG*2P-"B`@("`@("`@("`@("`@("!A<G)A>2A$25)%0U1/
M4EE?4T5005)!5$]2+"!$25)%0U1/4EE?4T5005)!5$]2*2P@)&9I;&4I.PT*
M("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1F:6QE*2`F)B!I<U]R96%D
M86)L92@D9FEL92DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@:6UP;&]D
M92@G)RP@9FEL92@D9FEL92DI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>R`O+R!T9WH-"B`@("`@("`@("`@("1T87(@/2`F;F5W($%R8VAI
M=F5?5&%R*"1T:&ES+3Y?87)C:&EV949I;&4I.PT*("`@("`@("`@("`@)'1A
M<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@:68@*"1F:6QE("$]("=P86-K86=E+GAM;"<@)B8@)&9I;&4@
M(3T@)W!A8VMA9V4R+GAM;"<I('L-"B`@("`@("`@("`@("`@("`D9FEL92`]
M("1T:&ES+3YG971086-K86=E*"D@+B`G+2<@+B`D=&AI<RT^9V5T5F5R<VEO
M;B@I("X@)R\G("X@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D9FEL92`]("1T87(M/F5X=')A8W1);E-T<FEN9R@D9FEL92D[#0H@("`@
M("`@("`@("`D=&%R+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL92DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N;F]T(&QO8V%T92!F:6QE
M("<D9FEL92<@:6X@87)C:&EV92(I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@<F5T=7)N("1F:6QE.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@)F=E=%)7*"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?
M97AI<W1S*"=014%27U!A8VMA9V5&:6QE7W8R7W)W)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92]V,B]R=RYP:'`G
M.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@;F5W(%!%05)?4&%C:V%G949I
M;&5?=C)?<G<[#0H@("`@("`@(&9O<F5A8V@@*&=E=%]O8FIE8W1?=F%R<R@D
M=&AI<RD@87,@)&YA;64@/3X@)'5N=7-E9"D@>PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D=&AI<RT^)&YA;64I*2![#0H@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&YA;64@
M/3T@)U]C;VYF:6<G('Q\("1N86UE(#T]("=?;&]G9V5R)WQ\("1N86UE(#T]
M("=?<F5G:7-T<GDG('Q\#0H@("`@("`@("`@("`@("`@("`D;F%M92`]/2`G
M7W-T86-K)RD@>PT*("`@("`@("`@("`@("`@("1A+3XD;F%M92`]("8D=&AI
M<RT^)&YA;64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1A+3XD;F%M92`]("1T:&ES+3XD;F%M93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@)F=E=$1E9F%U;'1'96YE<F%T;W(H*0T*("`@('L-"B`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]0
M86-K86=E1FEL92]'96YE<F%T;W(O=C(N<&AP)SL-"B`@("`@("`@?0T*("`@
M("`@("`D82`]("9N97<@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C(H
M)'1H:7,I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@86YA;'EZ95-O=7)C94-O9&4H)&9I;&4L("1S=')I;F<@/2!F86QS
M92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]V,E9A;&ED
M871O<BD@?'P-"B`@("`@("`@("`@("`@(6ES7V$H)'1H:7,M/E]V,E9A;&ED
M871O<BP@)U!%05)?4&%C:V%G949I;&5?=C)?5F%L:61A=&]R)RDI('L-"B`@
M("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5&:6QE
M7W8R7U9A;&ED871O<B<I*2![#0H@("`@("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+U9A;&ED871O<BYP:'`G.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]V,E9A;&ED871O<B`]
M(&YE=R!014%27U!A8VMA9V5&:6QE7W8R7U9A;&ED871O<CL-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]V,E9A;&ED871O<BT^86YA;'EZ
M95-O=7)C94-O9&4H)&9I;&4L("1S=')I;F<I.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('9A;&ED871E*"1S=&%T92`](%!%05)?5D%,241!5$5?3D]234%,
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O*2!\?"`A:7-?87)R87DH)'1H:7,M/E]P86-K86=E26YF;RDI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?=C)686QI9&%T;W(I('Q\#0H@("`@("`@("`@
M("`@("%I<U]A*"1T:&ES+3Y?=C)686QI9&%T;W(L("=014%27U!A8VMA9V5&
M:6QE7W8R7U9A;&ED871O<B<I*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]V,E]686QI9&%T;W(G*2D@>PT*
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL
M92]V,B]686QI9&%T;W(N<&AP)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1T:&ES+3Y?=C)686QI9&%T;W(@/2!N97<@4$5!4E]086-K86=E1FEL
M95]V,E]686QI9&%T;W([#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)WAS9'9E<G-I;VXG72DI('L-"B`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)WAS9'9E<G-I;VXG
M72D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=C)686QI
M9&%T;W(M/G9A;&ED871E*"1T:&ES+"`D<W1A=&4I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=%1A<VMS3G,H*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7W1A<VMS3G,I*2![#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG871T<FEB<R==*2D@>PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V%T=')I
M8G,G72!A<R`D;F%M92`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"1V86QU92`]/2`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S
M:W,M,2XP)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T
M87-K<TYS(#T@<W1R7W)E<&QA8V4H)WAM;&YS.B<L("<G+"`D;F%M92D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]T87-K<TYS.PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($1E=&5R;6EN92!W:&5T:&5R(&$@=&%S
M:R!N86UE(&ES(&$@=F%L:60@=&%S:RX@($-U<W1O;2!T87-K<R!M87D@8F4@
M9&5F:6YE9`T*("`@("`J('5S:6YG('-U8F1I<F5C=&]R:65S(&)Y('!U='1I
M;F<@82`B+2(@:6X@=&AE(&YA;64L(&%S(&EN(#QT87-K<SIM>6-U<W1O;2UT
M87-K/@T*("`@("`J#0H@("`@("H@3F]T92!T:&%T('1H:7,@;65T:&]D('=I
M;&P@875T;RUL;V%D('1H92!T87-K(&-L87-S(&9I;&4@86YD('1E<W0@9F]R
M('1H92!E>&ES=&5N8V4-"B`@("`@*B!O9B!T:&4@;F%M92!W:71H("(M(B!R
M97!L86-E9"!B>2`B7R(@87,@:6X@4$5!4B]487-K+VUY8W5S=&]M+W1A<VLN
M<&AP(&UA:V5S(&-L87-S#0H@("`@("H@4$5!4E]487-K7VUY8W5S=&]M7W1A
M<VL-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("H@0')E='5R;B!B;V]L
M96%N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T5&%S:R@D=&%S:RD-"B`@
M("![#0H@("`@("`@("1T:&ES+3YG971487-K<TYS*"D[#0H@("`@("`@("\O
M('1R86YS9F]R;2!A;&P@)RTG('1O("<O)R!A;F0@)W1A<VMS.B<@=&\@)R<@
M<V\@=&%S:W,Z<F5P;&%C92!B96-O;65S(')E<&QA8V4-"B`@("`@("`@)'1A
M<VL@/2!S=')?<F5P;&%C92AA<G)A>2@D=&AI<RT^7W1A<VMS3G,@+B`G.B<L
M("<M)RDL(&%R<F%Y*"<G+"`G("<I+"`D=&%S:RD[#0H@("`@("`@("1T87-K
M(#T@<W1R7W)E<&QA8V4H)R`G+"`G+R<L('5C=V]R9',H)'1A<VLI*3L-"B`@
M("`@("`@)'!S(#T@*'-T<G1O;&]W97(H<W5B<W1R*%!(4%]/4RP@,"P@,RDI
M(#T]("=W:6XG*2`_("<[)R`Z("<Z)SL-"B`@("`@("`@9F]R96%C:"`H97AP
M;&]D92@D<',L(&EN:5]G970H)VEN8VQU9&5?<&%T:"<I*2!A<R`D<&%T:"D@
M>PT*("`@("`@("`@("`@:68@*&9I;&5?97AI<W1S*"1P871H("X@(B]014%2
M+U1A<VLO)'1A<VLN<&AP(BDI('L-"B`@("`@("`@("`@("`@("!I;F-L=61E
M7V]N8V4@(E!%05(O5&%S:R\D=&%S:RYP:'`B.PT*("`@("`@("`@("`@("`@
M("1T87-K(#T@<W1R7W)E<&QA8V4H)R\G+"`G7R<L("1T87-K*3L-"B`@("`@
M("`@("`@("`@("!I9B`H8VQA<W-?97AI<W1S*")014%27U1A<VM?)'1A<VLB
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@(E!%05)?5&%S:U\D
M=&%S:R([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!+97DM9G)I96YD;'D@87)R87E?<W!L:6-E#0H@("`@("H@
M0'!A<F%M('1A9VYA;64@=&\@<W!L:6-E(&$@=F%L=64@:6X@8F5F;W)E#0H@
M("`@("H@0'!A<F%M(&UI>&5D('1H92!V86QU92!T;R!S<&QI8V4@:6X-"B`@
M("`@*B!`<&%R86T@<W1R:6YG('1H92!N97<@=&%G(&YA;64-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!?:W-P;&EC92@D87)R87DL("1K97DL("1V86QU92P@
M)&YE=VME>2D-"B`@("![#0H@("`@("`@("1O9F9S970@/2!A<G)A>5]S96%R
M8V@H)&ME>2P@87)R87E?:V5Y<R@D87)R87DI*3L-"B`@("`@("`@)&%F=&5R
M(#T@87)R87E?<VQI8V4H)&%R<F%Y+"`D;V9F<V5T*3L-"B`@("`@("`@)&)E
M9F]R92`](&%R<F%Y7W-L:6-E*"1A<G)A>2P@,"P@)&]F9G-E="D[#0H@("`@
M("`@("1B969O<F5;)&YE=VME>5T@/2`D=F%L=64[#0H@("`@("`@(')E='5R
M;B!A<G)A>5]M97)G92@D8F5F;W)E+"`D869T97(I.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!A<G)A>2!A(&QI<W0@;V8@<&]S<VEB;&4@
M:V5Y<RP@:6X@=&AE(&]R9&5R('1H97D@;6%Y(&]C8W5R#0H@("`@("H@0'!A
M<F%M(&UI>&5D(&-O;G1E;G1S(&]F('1H92!N97<@<&%C:V%G92YX;6P@=&%G
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!T86<@;F%M90T*("`@("`J($!A8V-E
M<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]I;G-E<G1"969O
M<F4H)&%R<F%Y+"`D:V5Y<RP@)&-O;G1E;G1S+"`D;F5W:V5Y*0T*("`@('L-
M"B`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PT*("`@("`@("`@
M("`@:68@*&ES<V5T*"1A<G)A>5LD:V5Y72DI('L-"B`@("`@("`@("`@("`@
M("!R971U<FX@)&%R<F%Y(#T@)'1H:7,M/E]K<W!L:6-E*"1A<G)A>2P@)&ME
M>2P@)&-O;G1E;G1S+"`D;F5W:V5Y*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D87)R87E;)&YE=VME>5T@/2`D8V]N=&5N=',[#0H@
M("`@("`@(')E='5R;B`D87)R87D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-U8G-E8W1I;VX@;V8@>T!L:6YK("1?<&%C:V%G94EN9F]]
M#0H@("`@("H@0'!A<F%M(&%R<F%Y?'-T<FEN9R!T86<@8V]N=&5N=',-"B`@
M("`@*B!`<&%R86T@87)R87D@9F]R;6%T.@T*("`@("`J(#QP<F4^#0H@("`@
M("H@87)R87DH#0H@("`@("H@("!T86=N86UE(#T^(&%R<F%Y*&QI<W0@;V8@
M=&%G(&YA;65S('1H870@9F]L;&]W('1H:7,@;VYE*2P-"B`@("`@*B`@(&-H
M:6QD=&%G;F%M92`]/B!A<G)A>2AL:7-T(&]F(&-H:6QD('1A9R!N86UE<R!T
M:&%T(&9O;&QO=R!T:&ES(&]N92DL#0H@("`@("H@*0T*("`@("`J(#PO<')E
M/@T*("`@("`J#0H@("`@("H@5&AI<R!A;&QO=W,@8V]N<W1R=6-T:6]N(&]F
M(&YE<W1E9"!T86=S#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7VUE<F=E5&%G*"1M86YI<"P@)&-O;G1E;G1S+"`D
M;W)D97(I#0H@("`@>PT*("`@("`@("!I9B`H8V]U;G0H)&]R9&5R*2D@>PT*
M("`@("`@("`@("`@9F]R96%C:"`H)&]R9&5R(&%S("1T86<@/3X@)&-U<F]R
M9&5R*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;6%N:7!;)'1A
M9UTI*2![#0H@("`@("`@("`@("`@("`@("`@("\O(&5N<W5R92!T:&%T('1H
M92!T86<@:7,@<V5T('5P#0H@("`@("`@("`@("`@("`@("`@("1M86YI<"`]
M("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1M86YI<"P@)&-U<F]R9&5R+"!A<G)A
M>2@I+"`D=&%G*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1O<F1E<BD@/B`Q*2![#0H@("`@("`@("`@("`@("`@
M("`@("1M86YI<%LD=&%G72`]("1T:&ES+3Y?;65R9V5486<H)&UA;FEP6R1T
M86==+"`D8V]N=&5N=',L(&%R<F%Y7W-L:6-E*"1O<F1E<BP@,2DI.PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)&UA;FEP.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@(')E='5R;B`D;6%N:7`[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1M86YI<%LD=&%G72D@)B8@(65M<'1Y*"1M86YI<%LD=&%G
M72D@)B8@:7-S970H)&UA;FEP6R1T86==6S!=*2D@>PT*("`@("`@("`@("`@
M)&UA;FEP6R1T86==6UT@/2`D8V]N=&5N=',[#0H@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("!I9B`H(6-O=6YT*"1M86YI<%LD=&%G72DI('L-"B`@
M("`@("`@("`@("`@("`D;6%N:7!;)'1A9UT@/2`D8V]N=&5N=',[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1M86YI<%LD=&%G
M72`](&%R<F%Y*"1M86YI<%LD=&%G72D[#0H@("`@("`@("`@("`@("`@)&UA
M;FEP6R1T86==6UT@/2`D8V]N=&5N=',[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1M86YI<#L-"B`@("!]#0I]#0H_/@T*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E1FEL
M92]V,2YP:'``````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$T-30V
M-B`Q,#4Q-30S-#$S-"`P,C(T,C,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]086-K86=E
M1FEL95]V,2P@<&%C:V%G92YX;6P@=F5R<VEO;B`Q+C`-"B`J#0H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI
M8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@=C$N<&AP+'8@,2XV.2`R,#`V
M+S`S+S`R(#$X.C$T.C$S(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@
M("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO
M#0HO*BH-"B`J($9O<B!E<G)O<B!H86YD;&EN9PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(O17)R;W)3=&%C:RYP:'`G.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@:68@<&%R<VEN9R!I<R!A='1E;7!T960@=VET:"!N;R!X;6P@97AT96YS
M:6]N#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]8
M34Q?15A4)RP@,RD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!I9B!C<F5A=&EN
M9R!T:&4@>&UL('!A<G-E<B!R97-O=7)C92!F86EL<PT*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?0T%.5%]-04M%7U!!4E-%4B<L(#0I
M.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=7-E9"!F;W(@86QL('-A>"!X;6P@
M<&%R<VEN9R!E<G)O<G,-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%
M7T524D]27U!!4E-%4E]%4E)/4B<L(#4I.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=7-E9"!W:&5N('1H97)E(&ES(&YO(&YA;64-"B`J+PT*9&5F:6YE*"=0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7TY!344G+"`V*3L-"@T*+RHJ#0H@
M*B!%<G)O<B!C;V1E('=H96X@82!P86-K86=E(&YA;64@:7,@;F]T('9A;&ED
M#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$
M7TY!344G+"`W*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@=VAE;B!N
M;R!S=6UM87)Y(&ES('!A<G-E9`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'
M149)3$5?15)23U)?3D]?4U5-34%262<L(#@I.PT*#0HO*BH-"B`J($5R<F]R
M(&-O9&4@9F]R('-U;6UA<FEE<R!T:&%T(&%R92!M;W)E('1H86X@,2!L:6YE
M#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E]-54Q424Q)
M3D5?4U5-34%262<L(#DI.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=7-E9"!W
M:&5N(&YO(&1E<V-R:7!T:6]N(&ES('!R97-E;G0-"B`J+PT*9&5F:6YE*"=0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4T-225!424].)RP@,3`I.PT*
M#0HO*BH-"B`J($5R<F]R(&-O9&4@=7-E9"!W:&5N(&YO(&QI8V5N<V4@:7,@
M<')E<V5N=`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?
M3D]?3$E#14Y312<L(#$Q*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@
M=VAE;B!A(#QV97)S:6]N/B!V97)S:6]N(&YU;6)E<B!I<R!N;W0@<')E<V5N
M=`T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?5D52
M4TE/3B<L(#$R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('5S960@=VAE;B!A
M(#QV97)S:6]N/B!V97)S:6]N(&YU;6)E<B!I<R!I;G9A;&ED#0H@*B\-"F1E
M9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7U9%4E-)3TXG
M+"`Q,RD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(')E;&5A<V4@<W1A
M=&4@:7,@;6ES<VEN9PT*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?4U1!5$4G+"`Q-"D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(')E;&5A<V4@<W1A=&4@:7,@:6YV86QI9`T*("HO#0ID969I;F4H)U!%
M05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]35$%412<L(#$U*3L-"@T*
M+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@<F5L96%S92!S=&%T92!I<R!M:7-S
M:6YG#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$
M051%)RP@,38I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!R96QE87-E
M('-T871E(&ES(&EN=F%L:60-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&
M24Q%7T524D]27TE.5D%,241?1$%412<L(#$W*3L-"@T*+RHJ#0H@*B!%<G)O
M<B!C;V1E('=H96X@;F\@<F5L96%S92!N;W1E<R!A<F4@9F]U;F0-"B`J+PT*
M9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/7TY/5$53)RP@,3@I
M.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!N;R!M86EN=&%I;F5R<R!A
M<F4@9F]U;F0-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]2
M7TY/7TU!24Y404E.15)3)RP@,3DI.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@
M=VAE;B!A(&UA:6YT86EN97(@:&%S(&YO(&AA;F1L90T*("HO#0ID969I;F4H
M)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1(04Y$3$4G+"`R,"D[
M#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@;6%I;G1A:6YE<B!H87,@
M;F\@:&%N9&QE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]-04E.5%)/3$4G+"`R,2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W
M:&5N(&$@;6%I;G1A:6YE<B!H87,@;F\@;F%M90T*("HO#0ID969I;F4H)U!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1.04U%)RP@,C(I.PT*#0HO
M*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&UA:6YT86EN97(@:&%S(&YO(&5M
M86EL#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-
M04E.5$5-04E,)RP@,C,I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A
M(&UA:6YT86EN97(@:&%S(&YO(&AA;F1L90T*("HO#0ID969I;F4H)U!%05)?
M4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]-04E.5%)/3$4G+"`R-"D[#0H-
M"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!I<R!N;W0@
M82!02%`@9&5P96YD96YC>2P@8G5T(&AA<R!N;R!N86UE#0H@*B\-"F1E9FEN
M92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!.04U%)RP@,C4I.PT*
M#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N9&5N8WD@:&%S(&YO
M('1Y<&4@*'!K9RP@<&AP+"!E=&,N*0T*("HO#0ID969I;F4H)U!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?1$505%E012<L(#(V*3L-"@T*+RHJ#0H@*B!%
M<G)O<B!C;V1E('=H96X@82!D97!E;F1E;F-Y(&AA<R!N;R!R96QA=&EO;B`H
M;'0L(&=E+"!H87,L(&5T8RXI#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U]$15!214PG+"`R-RD[#0H-"B\J*@T*("H@17)R;W(@
M8V]D92!W:&5N(&$@9&5P96YD96YC>2!I<R!N;W0@82`G:&%S)R!R96QA=&EO
M;BP@8G5T(&AA<R!N;R!V97)S:6]N#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]$15!615)324].)RP@,C@I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N9&5N8WD@:&%S(&%N(&EN=F%L:60@
M<F5L871I;VX-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]2
M7TE.5D%,241?1$504D5,)RP@,CDI.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@
M=VAE;B!A(&1E<&5N9&5N8WD@:&%S(&%N(&EN=F%L:60@='EP90T*("HO#0ID
M969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]$15!465!%
M)RP@,S`I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N9&5N
M8WD@:&%S(&%N(&EN=F%L:60@;W!T:6]N86P@;W!T:6]N#0H@*B\-"F1E9FEN
M92@G4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7T1%4$]05$E/3D%,
M)RP@,S$I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&1E<&5N9&5N
M8WD@:7,@82!P:V<@9&5P96YD96YC>2P@86YD(&AA<R!A;B!I;G9A;&ED('!A
M8VMA9V4@;F%M90T*("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)2
M3U)?24Y604Q)1%]$15!.04U%)RP@,S(I.PT*#0HO*BH-"B`J($5R<F]R(&-O
M9&4@=VAE;B!A(&1E<&5N9&5N8WD@:&%S(&$@8VAA;FYE;#TB9F]O(B!A='1R
M:6)U=&4L(&%N9"!F;V\@:7,@;F]T(&$@<F5G:7-T97)E9"!C:&%N;F5L#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E]53DM.3U=.7T1%
M4$-(04Y.14PG+"`S,RD[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(')E
M;#TB:&%S(B!A;F0@=F5R<VEO;B!A='1R:6)U=&4@:7,@<')E<V5N="X-"B`J
M+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27T1%4%9%4E-)3TY?
M24=.3U)%1"<L(#,T*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@='EP
M93TB<&AP(B!A;F0@9&5P96YD96YC>2!N86UE(&ES('!R97-E;G0-"B`J+PT*
M9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27T1%4$Y!345?24=.3U)%
M1"<L(#,U*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82!C;VYF:6=U
M<F4@;W!T:6]N(&AA<R!N;R!N86UE#0H@*B\-"F1E9FEN92@G4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]#3TY&3D%-12<L(#,V*3L-"@T*+RHJ#0H@*B!%
M<G)O<B!C;V1E('=H96X@82!C;VYF:6=U<F4@;W!T:6]N(&AA<R!N;R!N86UE
M#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]#3TY&
M4%)/35!4)RP@,S<I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&9I
M;&4@:6X@=&AE(&9I;&5L:7-T(&AA<R!A;B!I;G9A;&ED(')O;&4-"B`J+PT*
M9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?1DE,15)/
M3$4G+"`S."D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9FEL92!I
M;B!T:&4@9FEL96QI<W0@:&%S(&YO(')O;&4-"B`J+PT*9&5F:6YE*"=014%2
M7U!!0TM!1T5&24Q%7T524D]27TY/7T9)3$523TQ%)RP@,SDI.PT*#0HO*BH-
M"B`J($5R<F]R(&-O9&4@=VAE;B!A;F%L>7II;F<@82!P:'`@<V]U<F-E(&9I
M;&4@=&AA="!H87,@<&%R<V4@97)R;W)S#0H@*B\-"F1E9FEN92@G4$5!4E]0
M04-+04=%1DE,15]%4E)/4E])3E9!3$E$7U!(4$9)3$4G+"`T,"D[#0H-"B\J
M*@T*("H@17)R;W(@8V]D92!W:&5N(&%N86QY>FEN9R!A('!H<"!S;W5R8V4@
M9FEL92!R979E86QS(&$@<V]U<F-E(&5L96UE;G0-"B`J('=I=&AO=70@82!P
M86-K86=E(&YA;64@<')E9FEX#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U]03D%-15]04D5&25@G+"`T,2D[#0H-"B\J*@T*("H@
M17)R;W(@8V]D92!W:&5N(&%N('5N:VYO=VX@8VAA;FYE;"!I<R!S<&5C:69I
M960-"B`J+PT*9&5F:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27U5.2TY/
M5TY?0TA!3DY%3"<L(#0R*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@
M;F\@9FEL97,@87)E(&9O=6YD(&EN('1H92!F:6QE;&ES=`T*("HO#0ID969I
M;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1DE,15,G+"`T,RD[#0H-
M"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9FEL92!I<R!N;W0@=F%L:60@
M<&AP(&%C8V]R9&EN9R!T;R!?86YA;'EZ95-O=7)C94-O9&4H*0T*("HO#0ID
M969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]&24Q%)RP@
M-#0I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!T:&4@8VAA;FYE;"!V
M86QI9&%T;W(@<F5T=7)N<R!A;B!E<G)O<B!O<B!W87)N:6YG#0H@*B\-"F1E
M9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E]#2$%.3D5,5D%,)RP@-#4I
M.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A('!H<#4@<&%C:V%G92!I
M<R!P86-K86=E9"!I;B!P:'`T("AA;F%L>7-I<R!D;V5S;B=T('=O<FLI#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E]02%`U)RP@-#8I
M.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A(&9I;&4@:7,@;&ES=&5D
M(&EN('!A8VMA9V4N>&UL(&)U="!D;V5S(&YO="!E>&ES=`T*("HO#0ID969I
M;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?1DE,15].3U1&3U5.1"<L(#0W
M*3L-"@T*+RHJ#0H@*B!%<G)O<B!C;V1E('=H96X@82`\9&5P('1Y<&4](G!H
M<"(@<F5L/2)N;W0B+BXN(&ES(&5N8V]U;G1E<F5D("AU<V4@<F5L/2)N92(I
M#0H@*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]02%!?3D]?3D]4)RP@
M-#@I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A('!A8VMA9V4N>&UL
M(&-O;G1A:6YS(&YO;BU)4T\M.#@U.2TQ(&-H87)A8W1E<G,-"B`J+PT*9&5F
M:6YE*"=014%27U!!0TM!1T5&24Q%7T524D]27TY/3E])4T]?0TA!4E,G+"`T
M.2D[#0H-"B\J*@T*("H@17)R;W(@8V]D92!W:&5N(&$@9&5P96YD96YC>2!I
M<R!N;W0@82`G:&%S)R!R96QA=&EO;BP@8G5T(&AA<R!N;R!V97)S:6]N#0H@
M*B\-"F1E9FEN92@G4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!02%!6
M15)324].)RP@-3`I.PT*#0HO*BH-"B`J($5R<F]R(&-O9&4@=VAE;B!A('!A
M8VMA9V4@:&%S(&YO(&QE860@9&5V96QO<&5R#0H@*B\-"F1E9FEN92@G4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U],14%$)RP@-3$I.PT*#0HO*BH-"B`J
M($5R<F]R(&-O9&4@=VAE;B!A(&9I;&5N86UE(&)E9VEN<R!W:71H("(N(@T*
M("HO#0ID969I;F4H)U!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]&
M24Q%3D%-12<L(#4R*3L-"B\J*@T*("H@<&%C:V%G92YX;6P@96YC87!S=6QA
M=&]R#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q
M+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL
M95]V,0T*>PT*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@
M("`J($!V87(@4$5!4E]%<G)O<E-T86-K#0H@("`@("H@0&%C8V5S<R!P<FEV
M871E#0H@("`@("HO#0H@("`@=F%R("1?<W1A8VL[#0H-"B`@("`O*BH-"B`@
M("`@*B!!(')E9VES=')Y(&]B:F5C="P@=7-E9"!T;R!A8V-E<W,@=&AE('!A
M8VMA9V4@;F%M92!V86QI9&%T:6]N(')E9V5X(&9O<B!N;VXM<W1A;F1A<F0@
M8VAA;FYE;',-"B`@("`@*B!`=F%R(%!%05)?4F5G:7-T<GD-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]R96=I<W1R>3L-
M"@T*("`@("\J*@T*("`@("`J($%N(&]B:F5C="!T:&%T(&-O;G1A:6YS(&$@
M;&]G(&UE=&AO9"!T:&%T(&UA=&-H97,@4$5!4E]#;VUM;VXZ.FQO9R=S('-I
M9VYA='5R90T*("`@("`J($!V87(@;V)J96-T#0H@("`@("H@0&%C8V5S<R!P
M<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?;&]G9V5R.PT*#0H@("`@+RHJ
M#0H@("`@("H@4&%R<V5D('!A8VMA9V4@:6YF;W)M871I;VX-"B`@("`@*B!`
M=F%R(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@=F%R("1?<&%C:V%G94EN9F\[#0H-"B`@("`O*BH-"B`@("`@*B!P871H
M('1O('!A8VMA9V4N>&UL#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!V87(@)%]P86-K86=E1FEL
M93L-"@T*("`@("\J*@T*("`@("`J('!A=&@@=&\@<&%C:V%G92`N=&=Z(&]R
M(&9A;'-E(&EF('1H:7,@:7,@82!L;V-A;"]E>'1R86-T960@<&%C:V%G92YX
M;6P-"B`@("`@*B!`=F%R('-T<FEN9PT*("`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("`J+PT*("`@('9A<B`D7V%R8VAI=F5&:6QE.PT*#0H@("`@+RHJ
M#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@
M("`@*B\-"B`@("!V87(@)%]I<U9A;&ED(#T@,#L-"@T*("`@("\J*@T*("`@
M("`J($1E=&5R;6EN97,@=VAE=&AE<B!T:&ES('!A8VMA9V5F:6QE('=A<R!I
M;FET:6%L:7IE9"!O;FQY('=I=&@@<&%R=&EA;"!P86-K86=E(&EN9F\-"B`@
M("`@*@T*("`@("`J($EF('1H:7,@<&%C:V%G92!F:6QE('=A<R!C;VYS=')U
M8W1E9"!V:6$@<&%R<VEN9R!215-4+"!I="!W:6QL(&]N;'D@8V]N=&%I;@T*
M("`@("`J#0H@("`@("H@+2!P86-K86=E(&YA;64-"B`@("`@*B`M(&-H86YN
M96P@;F%M90T*("`@("`J("T@9&5P96YD96YC:65S(`T*("`@("`J($!V87(@
M8F]O;&5A;@T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M('9A<B`D7VEN8V]M<&QE=&4@/2!T<G5E.PT*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M(&)O;VP@9&5T97)M:6YE<R!W:&5T:&5R('1O(')E='5R;B!A(%!%
M05)?17)R;W(@;V)J96-T+"!O<B!U<V4@=&AE(%!%05)?17)R;W)3=&%C:PT*
M("`@("`J($!P87)A;2!S=')I;F<@3F%M92!O9B!%<G)O<B!3=&%C:R!C;&%S
M<R!T;R!U<V4N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]086-K86=E
M1FEL95]V,2@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K(#T@)FYE
M=R!014%27T5R<F]R4W1A8VLH)U!%05)?4&%C:V%G949I;&5?=C$G*3L-"B`@
M("`@("`@)'1H:7,M/E]S=&%C:RT^<V5T17)R;W)-97-S86=E5&5M<&QA=&4H
M)'1H:7,M/E]G971%<G)O<DUE<W-A9V4H*2D[#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:6YS=&%L;$)I
M;F%R>2@D:6YS=&%L;&5R*0T*("`@('L-"B`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES17AT96YS:6]N*"1N86UE*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('-E=$-O;F9I9R@F)&-O;F9I9RD-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?8V]N9FEG(#T@)B1C;VYF:6<[#0H@("`@("`@("1T:&ES+3Y?<F5G
M:7-T<GD@/2`F)&-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!S971297%U97-T961'<F]U<"@I#0H@("`@>PT*("`@("`@
M("`O+R!P;&%C96AO;&1E<@T*("`@('T-"@T*("`@("\J*@T*("`@("`J($9O
M<B!S879I;F<@:6X@=&AE(')E9VES=')Y+@T*("`@("`J#0H@("`@("H@4V5T
M('1H92!L87-T('9E<G-I;VX@=&AA="!W87,@:6YS=&%L;&5D#0H@("`@("H@
M0'!A<F%M('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$QA<W1)
M;G-T86QL961697)S:6]N*"1V97)S:6]N*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULG7VQA<W1V97)S:6]N)UT@/2`D=F5R<VEO;CL-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$QA<W1);G-T86QL961697)S
M:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=?;&%S='9E<G-I;VXG72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=?;&%S='9E<G-I;VXG73L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T26YS=&%L;&5D0FEN87)Y*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!L:7-T4&]S=&EN
M<W1A;&Q38W)I<'1S*"D-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I;FET4&]S=&EN<W1A;&Q38W)I<'1S
M*"D-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!S971,;V=G97(H)B1L;V=G97(I#0H@("`@>PT*("`@("`@
M("!I9B`H)&QO9V=E<B`F)B`H(6ES7V]B:F5C="@D;&]G9V5R*2!\?"`A;65T
M:&]D7V5X:7-T<R@D;&]G9V5R+"`G;&]G)RDI*2![#0H@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G3&]G9V5R(&UU<W0@8F4@8V]M<&%T
M:6)L92!W:71H(%!%05)?0V]M;6]N.CIL;V<G*3L-"B`@("`@("`@?0T*("`@
M("`@("`D=&AI<RT^7VQO9V=E<B`]("8D;&]G9V5R.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N('-E=%!A8VMA9V5F:6QE*"1F:6QE+"`D87)C:&EV92`](&9A
M;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E1FEL92`]("1F
M:6QE.PT*("`@("`@("`D=&AI<RT^7V%R8VAI=F5&:6QE(#T@)&%R8VAI=F4@
M/R`D87)C:&EV92`Z("1F:6QE.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=%!A8VMA9V5&:6QE*"D-"B`@("![#0H@("`@("`@(')E='5R;B!I<W-E="@D
M=&AI<RT^7W!A8VMA9V5&:6QE*2`_("1T:&ES+3Y?<&%C:V%G949I;&4@.B!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971086-K86=E5'EP92@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)W!H<"<[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T07)C:&EV949I;&4H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?87)C:&EV949I;&4[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@<&%C:V%G94EN9F\H)&9I96QD*0T*("`@('L-"B`@("`@("`@:68@*"%I
M<U]S=')I;F<H)&9I96QD*2!\?"!E;7!T>2@D9FEE;&0I('Q\#0H@("`@("`@
M("`@("`A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD9FEE;&1=*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R1F:65L9%T[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@<V5T1&ER=')E92@D<&%T:"D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1I<G1R964G75LD<&%T:%T@/2!T
M<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$1I<G1R964H*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1I
M<G1R964G72D@)B8@8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULG9&ER=')E
M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V1I<G1R964G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<F5S971$:7)T<F5E*"D-"B`@
M("![#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1I<G1R
M964G72D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9G)O;4%R<F%Y*"1P:6YF
M;RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:6YC;VUP;&5T92`](&9A;'-E
M.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'!I;F9O.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&ES26YC;VUP;&5T92@I#0H@("`@>PT*("`@
M("`@("!R971U<FX@)'1H:7,M/E]I;F-O;7!L971E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=$-H86YN96PH*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("=P96%R+G!H<"YN970G.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%5R
M:2@I#0H@("`@>PT*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T5&EM92@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T17AT96YD<R@I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M97AT96YD<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V5X=&5N9',G73L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0')E='5R;B!A
M<G)A>0T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O07)R87DH*0T*("`@('L-
M"B`@("`@("`@:68@*"$D=&AI<RT^=F%L:61A=&4H4$5!4E]604Q)1$%415].
M3U)-04PI*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3YG971!<G)A>2@I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=$%R<F%Y*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&=E=$YA;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YG
M971086-K86=E*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T4&%C:V%G
M92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?<&%C:V%G94EN9F];)W!A8VMA9V4G73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5T%2
M3DE.1R`M(&1O;B=T('5S92!T:&ES('5N;&5S<R!Y;W4@:VYO=R!W:&%T('EO
M=2!A<F4@9&]I;F<-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971287=086-K
M86=E*"1P86-K86=E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG<&%C:V%G92==(#T@)'!A8VMA9V4[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@<V5T4&%C:V%G92@D<&%C:V%G92D-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)W!A8VMA9V4G72`]("1P86-K86=E.PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!G971697)S:6]N*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UTI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==.PT*
M("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!S971697)S:6]N*"1V97)S:6]N*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==(#T@)'9E<G-I;VX[
M#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&-L96%R36%I;G1A:6YE<G,H*0T*("`@('L-"B`@("`@
M("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72D[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T36%I;G1A:6YE<G,H*0T*("`@
M('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA
M:6YT86EN97)S)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG;6%I;G1A:6YE<G,G73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@061D
M<R!A(&YE=R!M86EN=&%I;F5R("T@;F\@8VAE8VMI;F<@;V8@9'5P;&EC871E
M<R!I<R!P97)F;W)M960L('5S90T*("`@("`J('5P9&%T96UA:6YT86EN97(@
M9F]R('1H870@<'5R<&]S92X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1-
M86EN=&%I;F5R*"1R;VQE+"`D:&%N9&QE+"`D;F%M92P@)&5M86EL*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G
M75M=(#T-"B`@("`@("`@("`@(&%R<F%Y*"=H86YD;&4G(#T^("1H86YD;&4L
M("=R;VQE)R`]/B`D<F]L92P@)V5M86EL)R`]/B`D96UA:6PL("=N86UE)R`]
M/B`D;F%M92D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N('5P9&%T94UA:6YT86EN97(H)')O;&4L
M("1H86YD;&4L("1N86UE+"`D96UA:6PI#0H@("`@>PT*("`@("`@("`D9F]U
M;F0@/2!F86QS93L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=M86EN=&%I;F5R<R==*2!\?`T*("`@("`@("`@("`@("`A:7-?
M87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^861D36%I;G1A:6YE<B@D<F]L
M92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"D[#0H@("`@("`@('T-"B`@("`@
M("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G
M72!A<R`D:2`]/B`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@:68@*"1M
M86EN=&%I;F5R6R=H86YD;&4G72`]/2`D:&%N9&QE*2![#0H@("`@("`@("`@
M("`@("`@)&9O=6YD(#T@)&D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"`A
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)VUA:6YT86EN97)S)UU;)&9O=6YD72D[#0H@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==(#T-"B`@("`@("`@
M("`@("`@("!A<G)A>5]V86QU97,H)'1H:7,M/E]P86-K86=E26YF;ULG;6%I
M;G1A:6YE<G,G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/F%D9$UA
M:6YT86EN97(H)')O;&4L("1H86YD;&4L("1N86UE+"`D96UA:6PI.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&1E;&5T94UA:6YT86EN97(H)&AA;F1L92D-
M"B`@("![#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==(&%S("1I
M(#T^("1M86EN=&%I;F5R*2![#0H@("`@("`@("`@("!I9B`H)&UA:6YT86EN
M97);)VAA;F1L92==(#T]("1H86YD;&4I('L-"B`@("`@("`@("`@("`@("`D
M9F]U;F0@/2`D:3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9O=6YD("$]/2!F86QS
M92D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG
M;6%I;G1A:6YE<G,G75LD9F]U;F1=*3L-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UT@/0T*("`@("`@("`@("`@("`@
M(&%R<F%Y7W9A;'5E<R@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R
M<R==*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M9713=&%T92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG<F5L96%S95]S=&%T92==*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?<W1A=&4G73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<V5T4F%W4W1A=&4H)'-T871E*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]S=&%T92==(#T@)'-T
M871E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=%-T871E*"1S=&%T92D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?
M<W1A=&4G72`]("1S=&%T93L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&%T92@I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<F5L
M96%S95]D871E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P
M86-K86=E26YF;ULG<F5L96%S95]D871E)UT[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$1A
M=&4H)&1A=&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=R96QE87-E7V1A=&4G72`]("1D871E.PT*("`@("`@("`D=&AI<RT^7VES
M5F%L:60@/2!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971,:6-E
M;G-E*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=R96QE87-E7VQI8V5N<V4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7VQI8V5N<V4G73L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<V5T3&EC96YS92@D9&%T92D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?;&EC96YS92==(#T@)&1A
M=&4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=%-U;6UA<GDH*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-U;6UA<GDG72DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=6UM
M87)Y)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N('-E=%-U;6UA<GDH)'-U;6UA<GDI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=S=6UM87)Y)UT@/2`D
M<W5M;6%R>3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@9F%L<V4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5S8W)I<'1I;VXH*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R
M:7!T:6]N)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K
M86=E26YF;ULG9&5S8W)I<'1I;VXG73L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T1&5S8W)I
M<'1I;VXH)&1E<V,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=D97-C<FEP=&EO;B==(#T@)&1E<V,[#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$YO
M=&5S*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=R96QE87-E7VYO=&5S)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]N;W1E<R==.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!S971.;W1E<R@D;F]T97,I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7VYO=&5S)UT@/2`D;F]T97,[#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(&=E=$1E<',H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&5P<R==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?
M9&5P<R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!297-E="!D97!E;F1E;F-I97,@<')I
M;W(@=&\@861D:6YG(&YE=R!O;F5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M8VQE87)$97!S*"D-"B`@("![#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)W)E;&5A<V5?9&5P<R==*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!A9&10:'!$97`H)'9E<G-I;VXL("1R96PI#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG<F5L96%S95]D97!S)UU;72`]#0H@("`@("`@("`@("!A
M<G)A>2@G='EP92<@/3X@)W!H<"<L#0H@("`@("`@("`@("`@("`@("`G<F5L
M)R`]/B`D<F5L+`T*("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1V
M97)S:6]N*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!A9&1086-K86=E1&5P
M*"1N86UE+"`D=F5R<VEO;BP@)')E;"P@)&]P=&EO;F%L(#T@)VYO)RD-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](&9A;'-E.PT*("`@("`@
M("`D9&5P(#T-"B`@("`@("`@("`@(&%R<F%Y*"=T>7!E)R`]/B`G<&MG)RP-
M"B`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@("`@
M("`@("`@("`@("=R96PG(#T^("1R96PL#0H@("`@("`@("`@("`@("`@("`G
M;W!T:6]N86PG(#T^("1O<'1I;VYA;"D[#0H@("`@("`@(&EF("@D<F5L("$]
M("=H87,G("8F("1R96P@(3T@)VYO="<I('L-"B`@("`@("`@("`@("1D97!;
M)W9E<G-I;VXG72`]("1V97)S:6]N.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&5P<R==6UT@/2`D9&5P.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&%D9$5X=&5N<VEO;D1E<"@D;F%M92P@
M)'9E<G-I;VXL("1R96PL("1O<'1I;VYA;"`]("=N;R<I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2!F86QS93L-"B`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S)UU;72`]#0H@("`@("`@("`@
M("!A<G)A>2@G='EP92<@/3X@)V5X="<L#0H@("`@("`@("`@("`@("`@("`G
M;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@("`@("`@("`G<F5L)R`]/B`D
M<F5L+`T*("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1V97)S:6]N
M+`T*("`@("`@("`@("`@("`@("`@)V]P=&EO;F%L)R`]/B`D;W!T:6]N86PI
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(%=!4DY)3D<@+2!D;R!N;W0@
M=7-E('1H:7,@9G5N8W1I;VX@9&ER96-T;'D@=6YL97-S('EO=2!K;F]W('=H
M870@>6]U)W)E(&1O:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T1&5P
M<R@D9&5P<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W)E;&5A<V5?9&5P<R==(#T@)&1E<',[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@:&%S1&5P<R@I#0H@("`@>PT*("`@("`@("!R971U<FX@:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]D97!S)UTI("8F#0H@("`@("`@
M("`@("!C;W5N="@D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E<',G
M72D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&5P96YD96YC>4=R;W5P
M*"1G<F]U<"D-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!I<T-O;7!A=&EB;&4H)'!F*0T*("`@('L-"B`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES
M4W5B<&%C:V%G94]F*"1P*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1P+3YI
M<U-U8G!A8VMA9V4H)'1H:7,I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&ES
M4W5B<&%C:V%G92@D<"D-"B`@("![#0H@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!D97!E;F1S3VXH)'!A8VMA9V4L("1C
M:&%N;F5L*0T*("`@('L-"B`@("`@("`@:68@*'-T<G1O;&]W97(H)&-H86YN
M96PI("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$H)&1E<',@/2`D=&AI
M<RT^9V5T1&5P<R@I*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S("1D97`I('L-
M"B`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@(3T@)W!K9R<I('L-"B`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!;)VYA;64G72D@/3T@<W1R=&]L
M;W=E<B@D<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T0V]N9FEG=7)E3W!T
M:6]N<R@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T:6]N
M<R==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!H87-#;VYF:6=U<F5/<'1I;VYS*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B!I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYF:6=U<F5?;W!T:6]N<R==*2`F)@T*("`@("`@("`@("`@8V]U;G0H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72D[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@861D0V]N9FEG=7)E3W!T:6]N*"1N86UE+"`D
M<')O;7!T+"`D9&5F875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)&\@
M/2!A<G)A>2@G;F%M92<@/3X@)&YA;64L("=P<F]M<'0G(#T^("1P<F]M<'0I
M.PT*("`@("`@("!I9B`H)&1E9F%U;'0@(3T](&9A;'-E*2![#0H@("`@("`@
M("`@("`D;ULG9&5F875L="==(#T@)&1E9F%U;'0[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U
M<F5?;W!T:6]N<R==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E
M26YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72`](&%R<F%Y*"D[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N9FEG=7)E7V]P
M=&EO;G,G75M=(#T@)&\[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@8VQE87)#
M;VYF:6=U<F5/<'1I;VYS*"D-"B`@("![#0H@("`@("`@('5N<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;F9I9W5R95]O<'1I;VYS)UTI.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&=E=%!R;W9I9&5S*"D-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)W!R
M;W9I9&5S)UT[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(&%D9$9I;&4H)&1I<BP@)&9I;&4L("1A
M='1R<RD-"B`@("![#0H@("`@("`@("1D:7(@/2!P<F5G7W)E<&QA8V4H87)R
M87DH)R%<7%Q<*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O)RDL("1D:7(I
M.PT*("`@("`@("!I9B`H)&1I<B`]/2`G+R<@?'P@)&1I<B`]/2`G)RD@>PT*
M("`@("`@("`@("`@)&1I<B`]("<G.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&1I<B`N/2`G+R<[#0H@("`@("`@('T-"B`@("`@("`@)&9I
M;&4@/2`D9&ER("X@)&9I;&4[#0H@("`@("`@("1F:6QE(#T@<')E9U]R97!L
M86-E*"<A6UQ<+UTK(2<L("<O)RP@)&9I;&4I.PT*("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72`]("1A='1R<SL-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!G971);G-T86QL871I;VY&:6QE;&ES="@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$9I;&5L:7-T*"D[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1FEL96QI<W0H*0T*("`@('L-
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L
M:7-T)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E
M26YF;ULG9FEL96QI<W0G73L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M9F%L<V4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T1FEL94%T=')I8G5T
M92@D9FEL92P@)&%T='(L("1V86QU92D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=6R1A='1R72`]("1V
M86QU93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!R97-E=$9I;&5L:7-T*"D-
M"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T
M)UT@/2!A<G)A>2@I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$EN<W1A
M;&QE9$%S*"1F:6QE+"`D<&%T:"D-"B`@("![#0H@("`@("`@(&EF("@D<&%T
M:"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V9I;&5L:7-T)UU;)&9I;&5=6R=I;G-T86QL961?87,G72`]("1P871H.PT*
M("`@("`@("!]#0H@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V9I;&5L:7-T)UU;)&9I;&5=6R=I;G-T86QL961?87,G72D[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@:6YS=&%L;&5D1FEL92@D9FEL92P@)&%T=',I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M9FEL96QI<W0G75LD9FEL95TI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72`]#0H@("`@("`@("`@("`@
M("`@87)R87E?;65R9V4H)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G
M75LD9FEL95TL("1A='1S*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L:7-T)UU;)&9I;&5=(#T@
M)&%T=',[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#
M:&%N9V5L;V<H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YG96QO9R==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!F86QS93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!G971086-K86=E>&UL5F5R<VEO;B@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)S$N,"<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5W)A<'!E
M<B!T;R![0&QI;FL@4$5!4E]%<G)O<E-T86-K.CIG971%<G)O<G,H*7T-"B`@
M("`@*B!`<&%R86T@8F]O;&5A;B!D971E<FUI;F5S('=H971H97(@=&\@<'5R
M9V4@=&AE(&5R<F]R('-T86-K(&%F=&5R(')E=')I979I;F<-"B`@("`@*B!`
M<F5T=7)N(&%R<F%Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5T5F%L:61A
M=&EO;E=A<FYI;F=S*"1P=7)G92`]('1R=64I#0H@("`@>PT*("`@("`@("!R
M971U<FX@)'1H:7,M/E]S=&%C:RT^9V5T17)R;W)S*"1P=7)G92D[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+RHJ#0H@("`@("H@5F%L:61A=&EO;B!E
M<G)O<BX@($%L<V\@;6%R:W,@=&AE(&]B:F5C="!C;VYT96YT<R!A<R!I;G9A
M;&ED#0H@("`@("H@0'!A<F%M(&5R<F]R(&-O9&4-"B`@("`@*B!`<&%R86T@
M87)R87D@97)R;W(@:6YF;W)M871I;VX-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5%<G)O<B@D8V]D
M92P@)'!A<F%M<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*"1C;V1E+"`G97)R;W(G+"`D<&%R86US+"!F86QS92P@
M9F%L<V4L(&1E8G5G7V)A8VMT<F%C92@I*3L-"B`@("`@("`@)'1H:7,M/E]I
M<U9A;&ED(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@5F%L
M:61A=&EO;B!W87)N:6YG+B`@1&]E<R!N;W0@;6%R:R!T:&4@;V)J96-T(&-O
M;G1E;G1S(&EN=F%L:60N#0H@("`@("H@0'!A<F%M(&5R<F]R(&-O9&4-"B`@
M("`@*B!`<&%R86T@87)R87D@97)R;W(@:6YF;W)M871I;VX-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?=F%L:61A
M=&5787)N:6YG*"1C;V1E+"`D<&%R86US(#T@87)R87DH*2D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)&-O9&4L("=W87)N:6YG)RP@
M)'!A<F%M<RP@9F%L<V4L(&9A;'-E+"!D96)U9U]B86-K=')A8V4H*2D[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&EN=&5G97(@97)R;W(@
M8V]D90T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@7V=E=$5R<F]R365S<V%G92@I#0H@("`@>PT*("`@("`@("!R
M971U<FX@87)R87DH#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,
M15]%4E)/4E].3U].04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("=-:7-S
M:6YG(%!A8VMA9V4@3F%M92<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+
M04=%1DE,15]%4E)/4E].3U]354U-05)9(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=.;R!S=6UM87)Y(&9O=6YD)RP-"B`@("`@("`@("`@("`@("!014%2
M7U!!0TM!1T5&24Q%7T524D]27TU53%1)3$E.15]354U-05)9(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=3=6UM87)Y('-H;W5L9"!B92!O;B!O;F4@;&EN
M92<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U]$15-#4DE05$E/3B`]/@T*("`@("`@("`@("`@("`@("`@("`G36ES<VEN
M9R!D97-C<FEP=&EO;B<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U],24-%3E-%(#T^#0H@("`@("`@("`@("`@("`@("`@
M("=-:7-S:6YG(&QI8V5N<V4G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#
M2T%'149)3$5?15)23U)?3D]?5D524TE/3B`]/@T*("`@("`@("`@("`@("`@
M("`@("`G3F\@<F5L96%S92!V97)S:6]N(&9O=6YD)RP-"B`@("`@("`@("`@
M("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-4051%(#T^#0H@("`@
M("`@("`@("`@("`@("`@("=.;R!R96QE87-E('-T871E(&9O=6YD)RP-"B`@
M("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1!5$4@
M/3X-"B`@("`@("`@("`@("`@("`@("`@)TYO(')E;&5A<V4@9&%T92!F;W5N
M9"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].
M3U].3U1%4R`]/@T*("`@("`@("`@("`@("`@("`@("`G3F\@<F5L96%S92!N
M;W1E<R!F;W5N9"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,
M15]%4E)/4E].3U],14%$(#T^#0H@("`@("`@("`@("`@("`@("`@("=086-K
M86=E(&UU<W0@:&%V92!A="!L96%S="!O;F4@;&5A9"!M86EN=&%I;F5R)RP-
M"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!
M24Y404E.15)3(#T^#0H@("`@("`@("`@("`@("`@("`@("=.;R!M86EN=&%I
M;F5R<R!F;W5N9"P@870@;&5A<W0@;VYE(&UU<W0@8F4@9&5F:6YE9"<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.
M5$A!3D1,12`]/@T*("`@("`@("`@("`@("`@("`@("`G36%I;G1A:6YE<B`E
M:6YD97@E(&AA<R!N;R!H86YD;&4@*'5S97(@240@870@8VAA;FYE;"!S97)V
M97(I)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]2
M7TY/7TU!24Y44D],12`]/@T*("`@("`@("`@("`@("`@("`@("`G36%I;G1A
M:6YE<B`E:6YD97@E(&AA<R!N;R!R;VQE)RP-"B`@("`@("`@("`@("`@("!0
M14%27U!!0TM!1T5&24Q%7T524D]27TY/7TU!24Y43D%-12`]/@T*("`@("`@
M("`@("`@("`@("`@("`G36%I;G1A:6YE<B`E:6YD97@E(&AA<R!N;R!N86UE
M)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/
M7TU!24Y414U!24P@/3X-"B`@("`@("`@("`@("`@("`@("`@)TUA:6YT86EN
M97(@)6EN9&5X)2!H87,@;F\@96UA:6PG+`T*("`@("`@("`@("`@("`@(%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?1$503D%-12`]/@T*("`@("`@("`@
M("`@("`@("`@("`G1&5P96YD96YC>2`E:6YD97@E(&ES(&YO="!A('!H<"!D
M97!E;F1E;F-Y+"!A;F0@:&%S(&YO(&YA;64G+`T*("`@("`@("`@("`@("`@
M(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1$504D5,(#T^#0H@("`@("`@
M("`@("`@("`@("`@("=$97!E;F1E;F-Y("5I;F1E>"4@:&%S(&YO(')E;&%T
M:6]N("AR96PI)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7T1%4%194$4@/3X-"B`@("`@("`@("`@("`@("`@("`@)T1E
M<&5N9&5N8WD@)6EN9&5X)2!H87,@;F\@='EP92<L#0H@("`@("`@("`@("`@
M("`@4$5!4E]004-+04=%1DE,15]%4E)/4E]$15!.04U%7TE'3D]2140@/3X-
M"B`@("`@("`@("`@("`@("`@("`@)U!(4"!$97!E;F1E;F-Y("5I;F1E>"4@
M:&%S(&$@;F%M92!A='1R:6)U=&4@;V8@(B5N86UE)2(@=VAI8V@@=VEL;"!B
M92<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R!I9VYO<F5D(2<L#0H@
M("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$15!6
M15)324].(#T^#0H@("`@("`@("`@("`@("`@("`@("=$97!E;F1E;F-Y("5I
M;F1E>"4@:7,@;F]T(&$@<F5L/2)H87,B(&]R(')E;#TB;F]T(B!D97!E;F1E
M;F-Y+"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=A;F0@:&%S(&YO
M('9E<G-I;VXG+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?1$504$A05D524TE/3B`]/@T*("`@("`@("`@("`@("`@("`@
M("`G1&5P96YD96YC>2`E:6YD97@E(&ES(&$@='EP93TB<&AP(B!D97!E;F1E
M;F-Y+"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=A;F0@:&%S(&YO
M('9E<G-I;VXG+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?
M15)23U)?1$505D524TE/3E])1TY/4D5$(#T^#0H@("`@("`@("`@("`@("`@
M("`@("=$97!E;F1E;F-Y("5I;F1E>"4@:7,@82!R96P](B5R96PE(B!D97!E
M;F1E;F-Y+"!V97)S:6]N:6YG(&ES(&EG;F]R960G+`T*("`@("`@("`@("`@
M("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]$15!/4%1)3TY!
M3"`]/@T*("`@("`@("`@("`@("`@("`@("`G1&5P96YD96YC>2`E:6YD97@E
M(&AA<R!I;G9A;&ED(&]P=&EO;F%L('9A;'5E("(E;W!T)2(L('-H;W5L9"!B
M92!Y97,@;W(@;F\G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)
M3$5?4$A07TY/7TY/5"`]/@T*("`@("`@("`@("`@("`@("`@("`G1&5P96YD
M96YC>2`E:6YD97@E.B!P:'`@9&5P96YD96YC:65S(&-A;FYO="!U<V4@(FYO
M="(@<F5L+"!U<V4@(FYE(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M)R!T;R!E>&-L=61E('-P96-I9FEC('9E<G-I;VYS)RP-"B`@("`@("`@("`@
M("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/7T-/3D9.04U%(#T^#0H@
M("`@("`@("`@("`@("`@("`@("=#;VYF:6=U<F4@3W!T:6]N("5I;F1E>"4@
M:&%S(&YO(&YA;64G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)
M3$5?15)23U)?3D]?0T].1E!23TU05"`]/@T*("`@("`@("`@("`@("`@("`@
M("`G0V]N9FEG=7)E($]P=&EO;B`E:6YD97@E(&AA<R!N;R!P<F]M<'0G+`T*
M("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?1DE,
M15,@/3X-"B`@("`@("`@("`@("`@("`@("`@)TYO(&9I;&5S(&EN(#QF:6QE
M;&ES=#X@<V5C=&EO;B!O9B!P86-K86=E+GAM;"<L#0H@("`@("`@("`@("`@
M("`@4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]&24Q%4D],12`]/@T*("`@
M("`@("`@("`@("`@("`@("`G1FEL92`B)69I;&4E(B!H87,@;F\@<F]L92P@
M97AP96-T:6YG(&]N92!O9B`B)7)O;&5S)2(G+`T*("`@("`@("`@("`@("`@
M(%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]&24Q%4D],12`]/@T*
M("`@("`@("`@("`@("`@("`@("`G1FEL92`B)69I;&4E(B!H87,@:6YV86QI
M9"!R;VQE("(E<F]L924B+"!E>'!E8W1I;F<@;VYE(&]F("(E<F]L97,E(B<L
M#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!
M3$E$7T9)3$5.04U%(#T^#0H@("`@("`@("`@("`@("`@("`@("=&:6QE("(E
M9FEL924B(&-A;FYO="!S=&%R="!W:71H("(N(BP@8V%N;F]T('!A8VMA9V4@
M;W(@:6YS=&%L;"<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,
M15]%4E)/4E])3E9!3$E$7U!(4$9)3$4@/3X-"B`@("`@("`@("`@("`@("`@
M("`@)U!A<G-E<B!E<G)O<CH@:6YV86QI9"!02%`@9F]U;F0@:6X@9FEL92`B
M)69I;&4E(B<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,15]%
M4E)/4E].3U]03D%-15]04D5&25@@/3X-"B`@("`@("`@("`@("`@("`@("`@
M)VEN("5F:6QE)3H@)71Y<&4E("(E;F%M924B(&YO="!P<F5F:7AE9"!W:71H
M('!A8VMA9V4@;F%M92`B)7!A8VMA9V4E(B<L#0H@("`@("`@("`@("`@("`@
M4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7T9)3$4@/3X-"B`@("`@
M("`@("`@("`@("`@("`@)U!A<G-E<B!E<G)O<CH@:6YV86QI9"!02%`@9FEL
M92`B)69I;&4E(B<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,
M15]%4E)/4E]#2$%.3D5,5D%,(#T^#0H@("`@("`@("`@("`@("`@("`@("=#
M:&%N;F5L('9A;&ED871O<B!E<G)O<CH@9FEE;&0@(B5F:65L9"4B("T@)7)E
M87-O;B4G+`T*("`@("`@("`@("`@("`@(%!%05)?4$%#2T%'149)3$5?15)2
M3U)?4$A0-2`]/@T*("`@("`@("`@("`@("`@("`@("`G17)R;W(L(%!(4#4@
M=&]K96X@96YC;W5N=&5R960@:6X@)69I;&4E+"!A;F%L>7-I<R!S:&]U;&0@
M8F4@:6X@4$A0-2<L#0H@("`@("`@("`@("`@("`@4$5!4E]004-+04=%1DE,
M15]%4E)/4E]&24Q%7TY/5$9/54Y$(#T^#0H@("`@("`@("`@("`@("`@("`@
M("=&:6QE("(E9FEL924B(&EN('!A8VMA9V4N>&UL(&1O97,@;F]T(&5X:7-T
M)RP-"B`@("`@("`@("`@("`@("!014%27U!!0TM!1T5&24Q%7T524D]27TY/
M3E])4T]?0TA!4E,@/3X-"B`@("`@("`@("`@("`@("`@("`@)U!A8VMA9V4N
M>&UL(&-O;G1A:6YS(&YO;BU)4T\M.#@U.2TQ(&-H87)A8W1E<G,L(&%N9"!M
M87D@;F]T('9A;&ED871E)RP-"B`@("`@("`@("`@("D[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@5F%L:61A=&4@6$U,('!A8VMA9V4@9&5F:6YI=&EO
M;B!F:6QE+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI
M9&%T92@D<W1A=&4@/2!014%27U9!3$E$051%7TY/4DU!3"P@)&YO9FEL96-H
M96-K:6YG(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H*"1T:&ES+3Y?
M:7-686QI9"`F("1S=&%T92D@/3T@)'-T871E*2![#0H@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L
M:60@/2!T<G5E.PT*("`@("`@("`D:6YF;R`]("1T:&ES+3Y?<&%C:V%G94EN
M9F\[#0H@("`@("`@(&EF("AE;7!T>2@D:6YF;ULG<&%C:V%G92==*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'
M149)3$5?15)23U)?3D]?3D%-12D[#0H@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5.86UE(#T@)'!N(#T@)W5N:VYO=VXG.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E3F%M92`]("1P;B`]("1I
M;F9O6R=P86-K86=E)UT[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H96UP
M='DH)&EN9F];)W-U;6UA<GDG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-534U!
M4EDI.PT*("`@("`@("!](&5L<V5I9B`H<W1R<&]S*'1R:6TH)&EN9F];)W-U
M;6UA<GDG72DL(")<;B(I("$]/2!F86QS92D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]V86QI9&%T95=A<FYI;F<H4$5!4E]004-+04=%1DE,15]%4E)/4E]-
M54Q424Q)3D5?4U5-34%262P-"B`@("`@("`@("`@("`@("!A<G)A>2@G<W5M
M;6%R>2<@/3X@)&EN9F];)W-U;6UA<GDG72DI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AE;7!T>2@D:6YF;ULG9&5S8W)I<'1I;VXG72DI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7T1%4T-225!424].*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H96UP='DH)&EN9F];)W)E;&5A<V5?;&EC96YS92==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?3$E#14Y312D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M
M<'1Y*"1I;F9O6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]615)3
M24].*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];)W)E
M;&5A<V5?<W1A=&4G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A
M=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7U-4051%*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F];)W)E;&5A<V5?9&%T
M92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%
M05)?4$%#2T%'149)3$5?15)23U)?3D]?1$%412D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&5M<'1Y*"1I;F9O6R=R96QE87-E7VYO=&5S)UTI*2![#0H@
M("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%
M1DE,15]%4E)/4E].3U].3U1%4RD[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&5M<'1Y*"1I;F9O6R=M86EN=&%I;F5R<R==*2D@>PT*("`@("`@("`@("`@
M)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?
M3D]?34%)3E1!24Y%4E,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&AA<VQE860@/2!F86QS93L-"B`@("`@("`@("`@("1I(#T@,3L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=M86EN=&%I;F5R<R==(&%S("1M
M*2![#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1M6R=H86YD;&4G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R
M*%!%05)?4$%#2T%'149)3$5?15)23U)?3D]?34%)3E1(04Y$3$4L#0H@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D
M;5LG<F]L92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.5%)/
M3$4L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^
M("1I+"`G<F]L97,G(#T^(%!%05)?0V]M;6]N.CIG9715<V5R4F]L97,H*2DI
M.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@D;5LG<F]L92==(#T]("=L
M96%D)RD@>PT*("`@("`@("`@("`@("`@("`@("`D:&%S;&5A9"`]('1R=64[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AE;7!T
M>2@D;5LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]-04E.
M5$Y!344L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G
M(#T^("1I*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("AE;7!T>2@D;5LG96UA:6PG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)2
M3U)?3D]?34%)3E1%34%)3"P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=I;F1E>"<@/3X@)&DI*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&DK*SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@A)&AA<VQE860I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U],14%$*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(65M<'1Y
M*"1I;F9O6R=R96QE87-E7V1E<',G72DI('L-"B`@("`@("`@("`@("1I(#T@
M,3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=R96QE87-E7V1E<',G
M72!A<R`D9"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1;)W1Y
M<&4G72D@?'P@96UP='DH)&1;)W1Y<&4G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?3D]?1$505%E012P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R
M<F%Y*"=I;F1E>"<@/3X@)&DL("=T>7!E<R<@/3X@4$5!4E]#;VUM;VXZ.F=E
M=$1E<&5N9&5N8WE4>7!E<R@I*2D[#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1D6R=R96PG72D@?'P@96UP='DH)&1;)W)E;"==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]%4E)/4E].3U]$15!214PL#0H@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I+"`G<F5L<R<@/3X@4$5!
M4E]#;VUM;VXZ.F=E=$1E<&5N9&5N8WE296QA=&EO;G,H*2DI.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"%E;7!T>2@D9%LG;W!T:6]N86PG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A>2@D9%LG;W!T:6]N
M86PG72P@87)R87DH)WEE<R<L("=N;R<I*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)
M3$5?15)23U)?24Y604Q)1%]$15!/4%1)3TY!3"P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I+"`G;W!T)R`]/B`D
M9%LG;W!T:6]N86PG72DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9%LG<F5L)UT@
M(3T@)VAA<R<@)B8@)&1;)W)E;"==("$]("=N;W0G("8F(&5M<'1Y*"1D6R=V
M97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L
M:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7T1%4%9%4E-)
M3TXL#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^
M("1I*2D[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"@D9%LG<F5L)UT@
M/3T@)VAA<R<@?'P@)&1;)W)E;"==(#T]("=N;W0G*2`F)B`A96UP='DH)&1;
M)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V
M86QI9&%T95=A<FYI;F<H4$5!4E]004-+04=%1DE,15]%4E)/4E]$15!615)3
M24].7TE'3D]2140L#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G
M:6YD97@G(#T^("1I+"`G<F5L)R`]/B`D9%LG<F5L)UTI*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1D6R=T>7!E)UT@/3T@
M)W!H<"<@)B8@(65M<'1Y*"1D6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'149)
M3$5?15)23U)?1$503D%-15])1TY/4D5$+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH)VEN9&5X)R`]/B`D:2P@)VYA;64G(#T^("1D6R=N86UE
M)UTI*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1;)W1Y<&4G72`A
M/2`G<&AP)R`F)B!E;7!T>2@D9%LG;F%M92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,
M15]%4E)/4E].3U]$15!.04U%+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H)&1;)W1Y<&4G72`]/2`G<&AP)R`F)B!E;7!T
M>2@D9%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/4E].3U]$
M15!02%!615)324].+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H*"1D6R=R96PG72`]/2`G;F]T)RD@)B8@*"1D6R=T>7!E
M)UT@/3T@)W!H<"<I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7U!(4%].3U].3U0L#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G:6YD97@G(#T^("1I*2D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I*RL[#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"%E;7!T>2@D
M:6YF;ULG8V]N9FEG=7)E7V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@("1I
M(#T@,3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=C;VYF:6=U<F5?
M;W!T:6]N<R==(&%S("1C*2![#0H@("`@("`@("`@("`@("`@:68@*&5M<'1Y
M*"1C6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TY/7T-/3D9.
M04U%+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)VEN9&5X)R`]
M/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H96UP='DH)&-;)W!R;VUP="==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%4E)/
M4E].3U]#3TY&4%)/35!4+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VEN9&5X)R`]/B`D:2DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D:2LK.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AE;7!T>2@D:6YF;ULG9FEL96QI<W0G72DI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!0TM!1T5&24Q%
M7T524D]27TY/7T9)3$53*3L-"B`@("`@("`@("`@("1E<G)O<G-;72`]("=N
M;R!F:6QE<R<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!F;W)E
M86-H("@D:6YF;ULG9FEL96QI<W0G72!A<R`D9FEL92`]/B`D9F$I('L-"B`@
M("`@("`@("`@("`@("!I9B`H96UP='DH)&9A6R=R;VQE)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%<G)O<BA014%27U!!
M0TM!1T5&24Q%7T524D]27TY/7T9)3$523TQ%+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G<F]L97,G(#T^(%!%
M05)?0V]M;6]N.CIG971&:6QE4F]L97,H*2DI.PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H(6EN
M7V%R<F%Y*"1F85LG<F]L92==+"!014%27T-O;6UO;CHZ9V5T1FEL95)O;&5S
M*"DI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=F%L:61A=&5%
M<G)O<BA014%27U!!0TM!1T5&24Q%7T524D]27TE.5D%,241?1DE,15)/3$4L
M#0H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<@/3X@)&9I
M;&4L("=R;VQE)R`]/B`D9F%;)W)O;&4G72P@)W)O;&5S)R`]/B!014%27T-O
M;6UO;CHZ9V5T1FEL95)O;&5S*"DI*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"1F:6QE>S!](#T]("<N)R`F)B`D9FEL97LQ
M?2`]/2`G+R<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI
M9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?15)23U)?24Y604Q)1%]&24Q%
M3D%-12P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)R`]
M/B`D9FEL92DI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]R96=I<W1R
M>2D@)B8@)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("`D8VAA;B`]
M("1T:&ES+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)W!E87(N<&AP+FYE="<I
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#
M2T%'149)3$5?15)23U)?0TA!3DY%3%9!3"P@)&-H86XM/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?:7-686QI9"`]
M(#`[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=F%L:61A=&]R(#T@
M)&-H86XM/F=E=%9A;&ED871I;VY/8FIE8W0H*3L-"B`@("`@("`@("`@("1V
M86QI9&%T;W(M/G-E=%!A8VMA9V5&:6QE*"1T:&ES*3L-"B`@("`@("`@("`@
M("1V86QI9&%T;W(M/G9A;&ED871E*"1S=&%T92D[#0H@("`@("`@("`@("`D
M9F%I;'5R97,@/2`D=F%L:61A=&]R+3YG971&86EL=7)E<R@I.PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&9A:6QU<F5S6R=E<G)O<G,G72!A<R`D97)R;W(I
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!
M4E]004-+04=%1DE,15]%4E)/4E]#2$%.3D5,5D%,+"`D97)R;W(I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&9A:6QU<F5S6R=W
M87)N:6YG<R==(&%S("1W87)N:6YG*2![#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]V86QI9&%T95=A<FYI;F<H4$5!4E]004-+04=%1DE,15]%4E)/4E]#
M2$%.3D5,5D%,+"`D=V%R;FEN9RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1T:&ES+3Y?:7-686QI9"`F)B`D<W1A=&4@/3T@
M4$5!4E]604Q)1$%415]004-+04=)3D<@)B8@(21N;V9I;&5C:&5C:VEN9RD@
M>PT*("`@("`@("`@("`@:68@*"1T:&ES+3Y?86YA;'EZ95!H<$9I;&5S*"DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2!T<G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^
M7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7VES5F%L
M:60@/2`D<W1A=&4[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V%N86QY
M>F50:'!&:6QE<R@I#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES+3Y?:7-6
M86QI9"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E1FEL92DI('L-
M"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@
M("`D9&ER7W!R969I>"`](&1I<FYA;64H)'1H:7,M/E]P86-K86=E1FEL92D[
M#0H@("`@("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@
M("1L;V<@/2!I<W-E="@D=&AI<RT^7VQO9V=E<BD@/R!A<G)A>2@F)'1H:7,M
M/E]L;V=G97(L("=L;V<G*2`Z#0H@("`@("`@("`@("!A<G)A>2@D8V]M;6]N
M+"`G;&]G)RD[#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/F=E=$9I;&5L:7-T
M*"D[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1F:6QE(#T^("1F82D@
M>PT*("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D9&ER7W!R969I>"`N
M($1)4D5#5$]265]315!!4D%43U(@+B`D9FEL92DI('L-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H4$5!4E]004-+04=%1DE,15]%
M4E)/4E]&24Q%7TY/5$9/54Y$+`T*("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G9FEL92<@/3X@<F5A;'!A=&@H)&1I<E]P<F5F:7@I("X@1$E214-43U)9
M7U-%4$%2051/4B`N("1F:6QE*2D[#0H@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&9A6R=R;VQE
M)UT@/3T@)W!H<"<@)B8@)&1I<E]P<F5F:7@I('L-"B`@("`@("`@("`@("`@
M("!C86QL7W5S97)?9G5N8U]A<G)A>2@D;&]G+"!A<G)A>2@Q+"`B06YA;'EZ
M:6YG("1F:6QE(BDI.PT*("`@("`@("`@("`@("`@("1S<F-I;F9O(#T@)'1H
M:7,M/E]A;F%L>7IE4V]U<F-E0V]D92@D9&ER7W!R969I>"`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`D9FEL92D[#0H@("`@("`@("`@("`@("`@:68@*"1S
M<F-I;F9O*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8G5I;&10
M<F]V:61E<T%R<F%Y*"1S<F-I;F9O*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E3F%M92`]("1P;B`]("1T:&ES+3YG971086-K86=E*"D[#0H@("`@("`@
M("1P;FP@/2!S=')L96XH)'!N*3L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S)UTI*2![#0H@("`@("`@("`@("!F
M;W)E86-H("@H87)R87DI("1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S
M)UT@87,@)&ME>2`]/B`D=VAA="D@>PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D=VAA=%LG97AP;&EC:70G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@+R\@<VMI<"!C;VYF;W)M86YC92!C:&5C:W,@:68@=&AE('!R;W9I9&5S
M(&5N=')Y(&ES#0H@("`@("`@("`@("`@("`@("`@("\O('-P96-I9FEE9"!I
M;B!T:&4@<&%C:V%G92YX;6P@9FEL90T*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M97AT<F%C="@D=VAA="D[#0H@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]
M("=C;&%S<R<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%S=')N8V%S
M96-M<"@D;F%M92P@)'!N+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T95=A<FYI;F<H4$5!4E]0
M04-+04=%1DE,15]%4E)/4E].3U]03D%-15]04D5&25@L#0H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G9FEL92<@/3X@)&9I;&4L("=T>7!E)R`]
M/B`D='EP92P@)VYA;64G(#T^("1N86UE+"`G<&%C:V%G92<@/3X@)'!N*2D[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T>7!E(#T]("=F=6YC=&EO
M;B<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<G-T<B@D;F%M92P@
M)SHZ)RD@?'P@(7-T<FYC87-E8VUP*"1N86UE+"`D<&XL("1P;FPI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED
M871E5V%R;FEN9RA014%27U!!0TM!1T5&24Q%7T524D]27TY/7U!.04U%7U!2
M149)6"P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)R`]
M/B`D9FEL92P@)W1Y<&4G(#T^("1T>7!E+"`G;F%M92<@/3X@)&YA;64L("=P
M86-K86=E)R`]/B`D<&XI*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?:7-6
M86QI9#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&1E9F%U
M;'0@>&UL(&=E;F5R871O<B!O8FIE8W0-"B`@("`@*@T*("`@("`J($!R971U
M<FX@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C$-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B`F9V5T1&5F875L=$=E;F5R871O<B@I#0H@("`@>PT*("`@
M("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C$G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2
M+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,2YP:'`G.PT*("`@("`@("!]#0H@
M("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,2@D=&AI<RD[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!'970@=&AE(&-O;G1E;G1S(&]F(&$@9FEL92!L:7-T960@
M=VET:&EN('1H92!P86-K86=E+GAM;`T*("`@("`J($!P87)A;2!S=')I;F<-
M"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&=E=$9I;&5#;VYT96YT<R@D9FEL92D-"B`@("![#0H@("`@("`@(&EF("@D
M=&AI<RT^7V%R8VAI=F5&:6QE(#T]("1T:&ES+3Y?<&%C:V%G949I;&4I('L@
M+R\@=6YP86-K960-"B`@("`@("`@("`@("1D:7(@/2!D:7)N86UE*"1T:&ES
M+3Y?<&%C:V%G949I;&4I.PT*("`@("`@("`@("`@)&9I;&4@/2`D9&ER("X@
M1$E214-43U)97U-%4$%2051/4B`N("1F:6QE.PT*("`@("`@("`@("`@)&9I
M;&4@/2!S=')?<F5P;&%C92AA<G)A>2@G+R<L("=<7"<I+`T*("`@("`@("`@
M("`@("`@(&%R<F%Y*$1)4D5#5$]265]315!!4D%43U(L($1)4D5#5$]265]3
M15!!4D%43U(I+"`D9FEL92D[#0H@("`@("`@("`@("!I9B`H9FEL95]E>&ES
M=',H)&9I;&4I("8F(&ES7W)E861A8FQE*"1F:6QE*2D@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B!I;7!L;V1E*"<G+"!F:6QE*"1F:6QE*2D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T@96QS92![("\O('1G>@T*("`@("`@("`@
M("`@:68@*"%C;&%S<U]E>&ES=',H)T%R8VAI=F5?5&%R)RDI('L-"B`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&%R(#T@)FYE=R!!<F-H:79E
M7U1A<B@D=&AI<RT^7V%R8VAI=F5&:6QE*3L-"B`@("`@("`@("`@("1T87(M
M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@("`@(&EF("@D9FEL92`A/2`G<&%C:V%G92YX;6PG("8F("1F:6QE("$]
M("=P86-K86=E,BYX;6PG*2![#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D
M=&AI<RT^9V5T4&%C:V%G92@I("X@)RTG("X@)'1H:7,M/F=E=%9E<G-I;VXH
M*2`N("<O)R`N("1F:6QE.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)&9I;&4@/2`D=&%R+3YE>'1R86-T26Y3=')I;F<H)&9I;&4I.PT*("`@("`@
M("`@("`@)'1A<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-A;FYO="!L;V-A=&4@9FEL92`G
M)&9I;&4G(&EN(&%R8VAI=F4B*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(')E='5R;B`D9FEL93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O
M('M[>R!A;F%L>7IE4V]U<F-E0V]D92@I#0H@("`@+RHJ#0H@("`@("H@06YA
M;'EZ92!T:&4@<V]U<F-E(&-O9&4@;V8@=&AE(&=I=F5N(%!(4"!F:6QE#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@('-T<FEN9R!&:6QE;F%M92!O9B!T:&4@
M4$A0(&9I;&4-"B`@("`@*B!`<F5T=7)N(&UI>&5D#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V%N86QY>F53;W5R
M8V5#;V1E*"1F:6QE*0T*("`@('L-"B`@("`@("`@:68@*"%F=6YC=&EO;E]E
M>&ES=',H(G1O:V5N7V=E=%]A;&PB*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%]$
M3T-?0T]-345.5"<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?1$]#7T-/
M34U%3E0G+"!47T-/34U%3E0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M9&5F:6YE9"@G5%])3E1%4D9!0T4G*2D@>PT*("`@("`@("`@("`@9&5F:6YE
M*"=47TE.5$521D%#12<L("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M(61E9FEN960H)U1?24U03$5-14Y44R<I*2![#0H@("`@("`@("`@("!D969I
M;F4H)U1?24U03$5-14Y44R<L("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(21F<"`]($!F;W!E;B@D9FEL92P@(G(B*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("AF=6YC=&EO
M;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@
M(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@9FEL95]G
M971?8V]N=&5N=',H)&9I;&4I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&-O;G1E;G1S(#T@0&9R96%D*"1F<"P@9FEL97-I>F4H)&9I;&4I
M*3L-"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@
M("`@("1T;VME;G,@/2!T;VME;E]G971?86QL*"1C;VYT96YT<RD[#0HO*@T*
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1O:V5N<RD[("1I
M*RLI('L-"B`@("`@("`@("`@($!L:7-T*"1T;VME;BP@)&1A=&$I(#T@)'1O
M:V5N<ULD:5T[#0H@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1T;VME;BDI
M('L-"B`@("`@("`@("`@("`@("!V87)?9'5M<"@D=&]K96XI.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!P<FEN="!T;VME;E]N
M86UE*"1T;VME;BD@+B`G("<[#0H@("`@("`@("`@("`@("`@=F%R7V1U;7`H
M<G1R:6TH)&1A=&$I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T**B\-
M"B`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@)'!A<F5N7VQE=F5L
M(#T@,#L-"B`@("`@("`@)&)R86-K971?;&5V96P@/2`P.PT*("`@("`@("`D
M8G)A8V5?;&5V96P@/2`P.PT*("`@("`@("`D;&%S='!H<&1O8R`]("<G.PT*
M("`@("`@("`D8W5R<F5N=%]C;&%S<R`]("<G.PT*("`@("`@("`D8W5R<F5N
M=%]I;G1E<F9A8V4@/2`G)SL-"B`@("`@("`@)&-U<G)E;G1?8VQA<W-?;&5V
M96P@/2`M,3L-"B`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`G)SL-"B`@
M("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@("`@("`@
M)&1E8VQA<F5D7V-L87-S97,@/2!A<G)A>2@I.PT*("`@("`@("`D9&5C;&%R
M961?:6YT97)F86-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1D96-L87)E9%]F
M=6YC=&EO;G,@/2!A<G)A>2@I.PT*("`@("`@("`D9&5C;&%R961?;65T:&]D
M<R`](&%R<F%Y*"D[#0H@("`@("`@("1U<V5D7V-L87-S97,@/2!A<G)A>2@I
M.PT*("`@("`@("`D=7-E9%]F=6YC=&EO;G,@/2!A<G)A>2@I.PT*("`@("`@
M("`D97AT96YD<R`](&%R<F%Y*"D[#0H@("`@("`@("1I;7!L96UE;G1S(#T@
M87)R87DH*3L-"B`@("`@("`@)&YO9&5P<R`](&%R<F%Y*"D[#0H@("`@("`@
M("1I;G%U;W1E(#T@9F%L<V4[#0H@("`@("`@("1I;G1E<F9A8V4@/2!F86QS
M93L-"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T;VME;G,I
M.R`D:2LK*2![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'1O:V5N<ULD
M:5TI*2![#0H@("`@("`@("`@("`@("`@;&ES="@D=&]K96XL("1D871A*2`]
M("1T;VME;G-;)&E=.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D=&]K96X@/2`D=&]K96YS6R1I73L-"B`@("`@("`@("`@("`@
M("`D9&%T82`]("<G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1I;G%U;W1E*2![#0H@("`@("`@("`@("`@("`@:68@*"1T;VME;B`A/2`G
M(B<@)B8@)'1O:V5N("$](%1?14Y$7TA%4D5$3T,I('L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@)&EN<75O=&4@/2!F86QS93L-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@<W=I=&-H("@D=&]K96XI('L-
M"B`@("`@("`@("`@("`@("!C87-E(%1?5TA)5$534$%#12`Z#0H@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@(&-A<V4@
M)SLG.@T*("`@("`@("`@("`@("`@("`@("!I9B`H)&EN=&5R9F%C92D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VX@/2`G
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N
M7VQE=F5L(#T@+3$[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G(B<Z
M#0H@("`@("`@("`@("`@("`@8V%S92!47U-405)47TA%4D5$3T,Z#0H@("`@
M("`@("`@("`@("`@("`@("1I;G%U;W1E(#T@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92!47T-54DQ9
M7T]014XZ#0H@("`@("`@("`@("`@("`@8V%S92!47T1/3$Q!4E]/4$5.7T-5
M4DQ97T)204-%4SH-"B`@("`@("`@("`@("`@("!C87-E("=[)SH@)&)R86-E
M7VQE=F5L*RL[(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G
M?2<Z#0H@("`@("`@("`@("`@("`@("`@("1B<F%C95]L979E;"TM.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&-U<G)E;G1?8VQA<W-?;&5V96P@/3T@
M)&)R86-E7VQE=F5L*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]C;&%S<R`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U
M<G)E;G1?8VQA<W-?;&5V96P@/2`M,3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!I9B`H)&-U<G)E;G1?9G5N8W1I;VY?
M;&5V96P@/3T@)&)R86-E7VQE=F5L*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@)ULG.B`D8G)A8VME=%]L979E
M;"LK.R!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@)UTG.B`D
M8G)A8VME=%]L979E;"TM.R!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@
M(&-A<V4@)R@G.B`D<&%R96Y?;&5V96PK*SL@("!C;VYT:6YU92`R.PT*("`@
M("`@("`@("`@("`@(&-A<V4@)RDG.B`D<&%R96Y?;&5V96PM+3L@("!C;VYT
M:6YU92`R.PT*("`@("`@("`@("`@("`@(&-A<V4@5%])3E1%4D9!0T4Z#0H@
M("`@("`@("`@("`@("`@("`@("1I;G1E<F9A8V4@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@(&-A<V4@5%]#3$%34SH-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"@D8W5R<F5N=%]C;&%S<U]L979E;"`A/2`M,2D@?'P@*"1C=7)R96YT
M7V9U;F-T:6]N7VQE=F5L("$]("TQ*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]V86QI9&%T945R<F]R*%!%05)?4$%#2T%'149)3$5?
M15)23U)?24Y604Q)1%]02%!&24Q%+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92DI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@8V%S92!47T953D-424]..@T*("`@("`@
M("`@("`@("`@(&-A<V4@5%].15<Z#0H@("`@("`@("`@("`@("`@8V%S92!4
M7T585$5.1%,Z#0H@("`@("`@("`@("`@("`@8V%S92!47TE-4$Q%345.5%,Z
M#0H@("`@("`@("`@("`@("`@("`@("1L;V]K7V9O<B`]("1T;VME;CL-"B`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@
M("!C87-E(%1?4U1224Y'.@T*("`@("`@("`@("`@("`@("`@("!I9B`H=F5R
M<VEO;E]C;VUP87)E*'IE;F1?=F5R<VEO;B@I+"`G,BXP)RP@)SPG*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T<G1O;&]W
M97(H)&1A=&$I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"=P=6)L:6,G+"`G<')I=F%T92<L("=P<F]T96-T960G+"`G86)S=')A8W0G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I;G1E<F9A
M8V4G+"`G:6UP;&5M96YT<R<L("=T:')O=R<I(`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:61A=&5787)N:6YG*%!%05)?4$%#2T%'149)
M3$5?15)23U)?4$A0-2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)&9I;&4I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&QO;VM?9F]R(#T](%1?0TQ!4U,I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1C=7)R96YT7V-L87-S(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("1B<F%C95]L979E
M;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]C;&%S<V5S
M6UT@/2`D8W5R<F5N=%]C;&%S<SL-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1L;V]K7V9O<B`]/2!47TE.5$521D%#12D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?:6YT97)F86-E(#T@)&1A=&$[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]
M("1B<F%C95]L979E;#L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D96-L
M87)E9%]I;G1E<F9A8V5S6UT@/2`D8W5R<F5N=%]I;G1E<F9A8V4[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%])35!,
M14U%3E13*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6UP;&5M96YT
M<ULD8W5R<F5N=%]C;&%S<UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1L;V]K7V9O<B`]/2!47T585$5.1%,I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1E>'1E;F1S6R1C=7)R96YT7V-L87-S72`]
M("1D871A.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?
M9F]R(#T](%1?1E5.0U1)3TXI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D8W5R<F5N=%]C;&%S<RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@(B1C=7)R96YT7V-L87-S.CHD
M9&%T82([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D
M7VUE=&AO9'-;)&-U<G)E;G1?8VQA<W-=6UT@/2`D9&%T83L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T@96QS96EF("@D8W5R<F5N=%]I;G1E<F9A8V4I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC
M=&EO;B`]("(D8W5R<F5N=%]I;G1E<F9A8V4Z.B1D871A(CL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5C;&%R961?;65T:&]D<ULD8W5R<F5N
M=%]I;G1E<F9A8V5=6UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U
M<G)E;G1?9G5N8W1I;VX@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&5C;&%R961?9G5N8W1I;VYS6UT@/2`D8W5R<F5N=%]F=6YC
M=&EO;CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N7VQE=F5L(#T@)&)R86-E
M7VQE=F5L.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&T@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T]
M(%1?3D57*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=7-E9%]C;&%S
M<V5S6R1D871A72`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?
M5D%224%"3$4Z#0H@("`@("`@("`@("`@("`@("`@("1L;V]K7V9O<B`](#`[
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@8V%S92!47T1/0U]#3TU-14Y4.@T*("`@("`@("`@("`@("`@(&-A
M<V4@5%]#3TU-14Y4.@T*("`@("`@("`@("`@("`@("`@("!I9B`H<')E9U]M
M871C:"@G(5XO7"I<*EQS(2<L("1D871A*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&QA<W1P:'!D;V,@/2`D9&%T83L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L;"@G+T!N;V1E<%QS*RA<4RLI
M+R<L("1L87-T<&AP9&]C+"`D;2DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D;F]D97!S(#T@87)R87E?;65R9V4H)&YO9&5P<RP@)&U;,5TI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@
M("`@("`@("`@("`@8V%S92!47T1/54),15]#3TQ/3CH-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"$H)'1O:V5N<ULD:2`M(#%=6S!=(#T](%1?5TA)5$53
M4$%#12!\?"`D=&]K96YS6R1I("T@,5U;,%T@/3T@5%]35%))3D<I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E17)R;W(H
M4$5!4E]004-+04=%1DE,15]%4E)/4E])3E9!3$E$7U!(4$9)3$4L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G(#T^("1F:6QE
M*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&-L
M87-S(#T@)'1O:V5N<ULD:2`M(#%=6S%=.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H<W1R=&]L;W=E<B@D8VQA<W,I("$]("=P87)E;G0G*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=7-E9%]C;&%S<V5S6R1C;&%S<UT@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N(&%R<F%Y*`T*("`@("`@("`@("`@(G-O=7)C95]F:6QE
M(B`]/B`D9FEL92P-"B`@("`@("`@("`@(")D96-L87)E9%]C;&%S<V5S(B`]
M/B`D9&5C;&%R961?8VQA<W-E<RP-"B`@("`@("`@("`@(")D96-L87)E9%]I
M;G1E<F9A8V5S(B`]/B`D9&5C;&%R961?:6YT97)F86-E<RP-"B`@("`@("`@
M("`@(")D96-L87)E9%]M971H;V1S(B`]/B`D9&5C;&%R961?;65T:&]D<RP-
M"B`@("`@("`@("`@(")D96-L87)E9%]F=6YC=&EO;G,B(#T^("1D96-L87)E
M9%]F=6YC=&EO;G,L#0H@("`@("`@("`@("`B=7-E9%]C;&%S<V5S(B`]/B!A
M<G)A>5]D:69F*&%R<F%Y7VME>7,H)'5S961?8VQA<W-E<RDL("1N;V1E<',I
M+`T*("`@("`@("`@("`@(FEN:&5R:71A;F-E(B`]/B`D97AT96YD<RP-"B`@
M("`@("`@("`@(")I;7!L96UE;G1S(B`]/B`D:6UP;&5M96YT<RP-"B`@("`@
M("`@("`@("D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0G5I;&0@82`B
M<')O=FED97,B(&%R<F%Y(&9R;VT@9&%T82!R971U<FYE9"!B>0T*("`@("`J
M(&%N86QY>F53;W5R8V5#;V1E*"DN("!4:&4@9F]R;6%T(&]F('1H92!B=6EL
M="!A<G)A>2!I<R!L:6ME#0H@("`@("H@=&AI<SH-"B`@("`@*@T*("`@("`J
M("!A<G)A>2@-"B`@("`@*B`@("`G8VQA<W,[37E#;&%S<R<@/3X@)V%R<F%Y
M*"=T>7!E)R`]/B`G8VQA<W,G+"`G;F%M92<@/3X@)TUY0VQA<W,G*2P-"B`@
M("`@*B`@("`N+BX-"B`@("`@*B`@*0T*("`@("`J#0H@("`@("H-"B`@("`@
M*B!`<&%R86T@87)R87D@)'-R8VEN9F\@87)R87D@=VET:"!I;F9O<FUA=&EO
M;B!A8F]U="!A('-O=7)C92!F:6QE#0H@("`@("H@87,@<F5T=7)N960@8GD@
M=&AE(&%N86QY>F53;W5R8V5#;V1E*"D@;65T:&]D+@T*("`@("`J#0H@("`@
M("H@0')E='5R;B!V;VED#0H@("`@("H-"B`@("`@*B!`86-C97-S('!R:79A
M=&4-"B`@("`@*@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]B=6EL9%!R;W9I
M9&5S07)R87DH)'-R8VEN9F\I#0H@("`@>PT*("`@("`@("!I9B`H(21T:&ES
M+3Y?:7-686QI9"D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@("1F:6QE(#T@8F%S96YA;64H)'-R8VEN9F];)W-O
M=7)C95]F:6QE)UTI.PT*("`@("`@("`D<&X@/2`D=&AI<RT^9V5T4&%C:V%G
M92@I.PT*("`@("`@("`D<&YL(#T@<W1R;&5N*"1P;BD[#0H@("`@("`@(&9O
M<F5A8V@@*"1S<F-I;F9O6R=D96-L87)E9%]C;&%S<V5S)UT@87,@)&-L87-S
M*2![#0H@("`@("`@("`@("`D:V5Y(#T@(F-L87-S.R1C;&%S<R([#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED
M97,G75LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)W!R;W9I9&5S)UU;)&ME>5T@/0T*("`@("`@("`@("`@("`@(&%R<F%Y*"=F
M:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^("1C
M;&%S<RD[#0H@("`@("`@("`@("!I9B`H:7-S970H)'-R8VEN9F];)VEN:&5R
M:71A;F-E)UU;)&-L87-S72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=6R=E>'1E;F1S)UT@/0T*
M("`@("`@("`@("`@("`@("`@("`D<W)C:6YF;ULG:6YH97)I=&%N8V4G75LD
M8VQA<W-=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1S<F-I;F9O6R=D96-L87)E9%]M971H;V1S)UT@87,@)&-L87-S
M(#T^("1M971H;V1S*2![#0H@("`@("`@("`@("!F;W)E86-H("@D;65T:&]D
M<R!A<R`D;65T:&]D*2![#0H@("`@("`@("`@("`@("`@)&9U;F-T:6]N(#T@
M(B1C;&%S<SHZ)&UE=&AO9"([#0H@("`@("`@("`@("`@("`@)&ME>2`](")F
M=6YC=&EO;CLD9G5N8W1I;VXB.PT*("`@("`@("`@("`@("`@(&EF("@D;65T
M:&]D>S!](#T]("=?)R!\?"`A<W1R8V%S96-M<"@D;65T:&]D+"`D8VQA<W,I
M('Q\#0H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<R==6R1K97E=(#T-
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I;&4L("=T
M>7!E)R`]/B`G9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&9O<F5A8V@@*"1S
M<F-I;F9O6R=D96-L87)E9%]F=6YC=&EO;G,G72!A<R`D9G5N8W1I;VXI('L-
M"B`@("`@("`@("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N(CL-"B`@
M("`@("`@("`@(&EF("@D9G5N8W1I;VY[,'T@/3T@)U\G('Q\(&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S)UU;)&ME>5TI*2![#0H@("`@
M("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H(7-T<G-T<B@D9G5N8W1I;VXL("<Z.B<I("8F('-T<FYC87-E
M8VUP*"1F=6YC=&EO;BP@)'!N+"`D<&YL*2D@>PT*("`@("`@("`@("`@("`@
M("1W87)N:6YG<UM=(#T@(FEN,2`B("X@)&9I;&4@+B`B.B!F=6YC=&EO;B!<
M(B1F=6YC=&EO;EPB(&YO="!P<F5F:7AE9"!W:71H('!A8VMA9V4@;F%M92!<
M(B1P;EPB(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)W!R;W9I9&5S)UU;)&ME>5T@/0T*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V9U;F-T:6]N
M)RP@)VYA;64G(#T^("1F=6YC=&EO;BD[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("`O+R!]?7T-"GT-"C\^#0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+W8R
M+W)W+G!H<```````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,38W-#$T(#$P
M-3$U-#,T,3,T(#`R,S`U,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B!014%27U!A8VMA9V5&:6QE
M7W8R+"!P86-K86=E+GAM;"!V97)S:6]N(#(N,"P@<F5A9"]W<FET92!V97)S
M:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W
M+G!H<"QV(#$N,34@,C`P-B\P,2\R."`Q-SHS-3HQ,2!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N-"XP83@-"B`J+PT*+RHJ#0H@*B!&;W(@8F%S92!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B\J
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$X#0H@*B\-"F-L87-S(%!%05)?4&%C:V%G949I;&5?
M=C)?<G<@97AT96YD<R!014%27U!A8VMA9V5&:6QE7W8R#0I[#0H@("`@+RHJ
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!%>'1E;G-I;VX@;F%M90T*("`@("`J
M($!R971U<FX@8F]O;"!S=6-C97-S(&]F(&]P97)A=&EO;@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('-E=%!R;W9I9&5S17AT96YS:6]N*"1E>'1E;G-I;VXI
M#0H@("`@>PT*("`@("`@("!I9B`H:6Y?87)R87DH)'1H:7,M/F=E=%!A8VMA
M9V54>7!E*"DL(&%R<F%Y*"=E>'1S<F,G+"`G97AT8FEN)RDI*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I
M9&5S97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@+R\@96YS=7)E
M('1H870@=&AE(&-H86YN96P@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@
M;&]C871I;VX-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP-
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH)W5S97-R;VQE)RP@)W5S97-T
M87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+`T*
M("`@("`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR
M96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@
M("`@("`@("`@)&5X=&5N<VEO;BP@)W!R;W9I9&5S97AT96YS:6]N)RD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=P<F]V:61E<V5X=&5N<VEO;B==(#T@)&5X=&5N<VEO;CL-"B`@("`@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971086-K86=E*"1P86-K
M86=E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R:6)S
M)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@87)R
M87E?;65R9V4H87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("<R+C`G+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS)R`]/B`G
M:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`G+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)WAM;&YS.G1A<VMS)R`]/B`G
M:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP)RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN<SIX<VDG(#T^("=H='1P
M.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>'-I.G-C:&5M84QO8V%T
M:6]N)R`]/B`G:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP#0H@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP+GAS9`T*("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,BXP#0H@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]D=&0O<&%C:V%G92TR+C`N>'-D)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*2DL("1T:&ES+3Y?<&%C:V%G94EN
M9F\I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG;F%M92==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%C:V%G94EN9F\@/2!A<G)A>5]M97)G92AA<G)A>2@G;F%M92<@
M/3X@)'!A8VMA9V4I+`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F\I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F];)VYA;64G72`]("1P86-K86=E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('-E=%5R:2@D=7)I*0T*("`@('L-"B`@("`@("`@=6YS970H)'1H:7,M/E]P
M86-K86=E26YF;ULG8VAA;FYE;"==*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=U<FDG72DI('L-"B`@("`@("`@("`@("\O(&5N<W5R92!T:&%T('1H
M92!U<FD@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R
M=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+"`-"B`@("`@("`@("`@("`@
M("!A<G)A>2@G97AT96YD<R<L("=S=6UM87)Y)RP@)V1E<V-R:7!T:6]N)RP@
M)VQE860G+`T*("`@("`@("`@("`@("`@("=D979E;&]P97(G+"`G8V]N=')I
M8G5T;W(G+"`G:&5L<&5R)RP@)V1A=&4G+"`G=&EM92<L("=V97)S:6]N)RP-
M"B`@("`@("`@("`@("`@("`G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T
M97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@
M("`@)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S
M<F]L92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@
M("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L
M#0H@("`@("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@
M)V-H86YG96QO9R<I+"`D=7)I+"`G=7)I)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG=7)I)UT@/2`D=7)I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('-E=$-H86YN96PH)&-H86YN96PI#0H@("`@>PT*
M("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<FDG72D[#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@("`@
M("`@("`@+R\@96YS=7)E('1H870@=&AE(&-H86YN96P@=&%G(&ES('-E="!U
M<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A
M8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=E>'1E;F1S)RP@
M)W-U;6UA<GDG+"`G9&5S8W)I<'1I;VXG+"`G;&5A9"<L#0H@("`@("`@("`@
M("`@("`@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G+"`G
M9&%T92<L("=T:6UE)RP@)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("=S
M=&%B:6QI='DG+"`G;&EC96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C
M;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@
M)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@
M)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP
M<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G
M97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL("1C:&%N
M;F5L+"`G8VAA;FYE;"<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YN96PG72`]("1C:&%N;F5L.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N('-E=$5X=&5N9',H)&5X=&5N9',I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)V5X=&5N9',G72DI('L-"B`@("`@("`@
M("`@("\O(&5N<W5R92!T:&%T('1H92!E>'1E;F1S('1A9R!I<R!S970@=7`@
M:6X@=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K
M86=E26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G<W5M;6%R>2<L("=D
M97-C<FEP=&EO;B<L("=L96%D)RP-"B`@("`@("`@("`@("`@("`G9&5V96QO
M<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<L("=D871E)RP@)W1I;64G
M+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L
M:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*
M("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E
M;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L
M("=S<F-U<FDG+`T*("`@("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X
M='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E
M)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)&5X=&5N9',L("=E>'1E;F1S
M)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M97AT96YD<R==(#T@)&5X=&5N9',[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M<V5T4W5M;6%R>2@D<W5M;6%R>2D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K
M86=E26YF;ULG<W5M;6%R>2==*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E
M('1H870@=&AE('-U;6UA<GD@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@
M;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D
M=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@
M("`@("`@("`@("`@(&%R<F%Y*"=D97-C<FEP=&EO;B<L("=L96%D)RP-"B`@
M("`@("`@("`@("`@("`G9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE
M;'!E<B<L("=D871E)RP@)W1I;64G+"`G=F5R<VEO;B<L#0H@("`@("`@("`@
M("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@)VYO=&5S)RP@)V-O;G1E
M;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@("`@("`@("=D97!E;F1E
M;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E
M<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG+`T*("`@("`@("`@("`@
M("`@("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@
M("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G
M*2P@)'-U;6UA<GDL("=S=6UM87)Y)RD[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULG<W5M;6%R>2==(#T@)'-U;6UA<GD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T1&5S8W)I<'1I;VXH)&1E<V,I#0H@
M("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I
M9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T:6]N)UTI
M*2![#0H@("`@("`@("`@("`O+R!E;G-U<F4@=&AA="!T:&4@9&5S8W)I<'1I
M;VX@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG:'0@;&]C871I;VX-"B`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E
M9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R
M<F%Y*"=L96%D)RP-"B`@("`@("`@("`@("`@("`G9&5V96QO<&5R)RP@)V-O
M;G1R:6)U=&]R)RP@)VAE;'!E<B<L("=D871E)RP@)W1I;64G+"`G=F5R<VEO
M;B<L#0H@("`@("`@("`@("`@("`@)W-T86)I;&ET>2<L("=L:6-E;G-E)RP@
M)VYO=&5S)RP@)V-O;G1E;G1S)RP@)V-O;7!A=&EB;&4G+`T*("`@("`@("`@
M("`@("`@("=D97!E;F1E;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+"`G
M=7-E<W)O;&4G+"`G=7-E<W1A<VLG+"`G<W)C<&%C:V%G92<L("=S<F-U<FDG
M+`T*("`@("`@("`@("`@("`@("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A
M<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR96QE87-E)RP@)V)U;F1L
M92<L("=C:&%N9V5L;V<G*2P@)&1E<V,L("=D97-C<FEP=&EO;B<I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<V-R:7!T
M:6]N)UT@/2`D9&5S8SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&1S
M(&$@;F5W(&UA:6YT86EN97(@+2!N;R!C:&5C:VEN9R!O9B!D=7!L:6-A=&5S
M(&ES('!E<F9O<FUE9"P@=7-E#0H@("`@("H@=7!D871E;6%I;G1A:6YE<B!F
M;W(@=&AA="!P=7)P;W-E+@T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$UA
M:6YT86EN97(H)')O;&4L("1H86YD;&4L("1N86UE+"`D96UA:6PL("1A8W1I
M=F4@/2`G>65S)RD-"B`@("![#0H@("`@("`@(&EF("@A:6Y?87)R87DH)')O
M;&4L(&%R<F%Y*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L
M("=H96QP97(G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULD<F]L95TI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)')O;&5=6S!=*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T@87)R87DH)'1H:7,M/E]P86-K
M86=E26YF;ULD<F]L95TI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;72`]#0H@("`@("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M
M92P-"B`@("`@("`@("`@("`@("`@("`@)W5S97(G(#T^("1H86YD;&4L#0H@
M("`@("`@("`@("`@("`@("`@("=E;6%I;"<@/3X@)&5M86EL+`T*("`@("`@
M("`@("`@("`@("`@("`G86-T:79E)R`]/B`D86-T:79E+`T*("`@("`@("`@
M("`@("`@("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&5S
M=&%R<B`](&%R<F%Y*"=L96%D)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E
M=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP97(G+"`G9&%T92<L("=T
M:6UE)RP@)W9E<G-I;VXG+`T*("`@("`@("`@("`@("`@("`@("`G<W1A8FEL
M:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N=&5N=',G+"`G8V]M<&%T
M:6)L92<L#0H@("`@("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G+"`G
M<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*
M("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G
M<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO9R<I
M.PT*("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)VQE860G+"`G9&5V96QO
M<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<I(&%S("1T97-T<F]L92D@
M>PT*("`@("`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1T97-T87)R*3L-"B`@
M("`@("`@("`@("`@("!I9B`H)')O;&4@/3T@)'1E<W1R;VQE*2![#0H@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@+R\@96YS
M=7)E('1H870@=&AE(&5X=&5N9',@=&%G(&ES('-E="!U<"!I;B!T:&4@<FEG
M:'0@;&]C871I;VX-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF
M;RP@)'1E<W1A<G(L#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"DL("1R
M;VQE*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)')O;&5=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)VYA;64G(#T^("1N86UE+`T*("`@("`@("`@
M("`@("`@("`@("`G=7-E<B<@/3X@)&AA;F1L92P-"B`@("`@("`@("`@("`@
M("`@("`@)V5M86EL)R`]/B`D96UA:6PL#0H@("`@("`@("`@("`@("`@("`@
M("=A8W1I=F4G(#T^("1A8W1I=F4L#0H@("`@("`@("`@("`@("`@*3L-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('5P9&%T94UA:6YT86EN97(H)&YE=W)O;&4L("1H
M86YD;&4L("1N86UE+"`D96UA:6PL("1A8W1I=F4@/2`G>65S)RD-"B`@("![
M#0H@("`@("`@("1F;W5N9"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("AA
M<G)A>2@G;&5A9"<L("=D979E;&]P97(G+"`G8V]N=')I8G5T;W(G+"`G:&5L
M<&5R)RD@87,@)')O;&4I('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D:6YF;R`]
M("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=.PT*("`@("`@("`@("`@:68@
M*"%I<W-E="@D:6YF;ULP72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN
M9F];)W5S97(G72`]/2`D:&%N9&QE*2![#0H@("`@("`@("`@("`@("`@("`@
M("1F;W5N9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1I;F9O(&%S("1I(#T^("1M86EN=&%I;F5R*2![#0H@("`@
M("`@("`@("`@("`@:68@*"1M86EN=&%I;F5R6R=U<V5R)UT@/3T@)&AA;F1L
M92D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2`D:3L-"B`@("`@
M("`@("`@("`@("`@("`@8G)E86L@,CL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"`]
M/3T@9F%L<V4I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^861D36%I
M;G1A:6YE<B@D;F5W<F]L92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C
M=&EV92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1F;W5N9"`A/3T@9F%L
M<V4I('L-"B`@("`@("`@("`@(&EF("@D9F]U;F0@/3T]('1R=64I('L-"B`@
M("`@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE
M72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=6R1F;W5N9%TI.PT*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T@87)R
M87E?=F%L=65S*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^861D36%I;G1A
M:6YE<B@D;F5W<F]L92P@)&AA;F1L92P@)&YA;64L("1E;6%I;"P@)&%C=&EV
M92D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9&5L971E36%I;G1A:6YE<B@D:&%N9&QE*0T*("`@('L-
M"B`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*&%R
M<F%Y*"=L96%D)RP@)V1E=F5L;W!E<B<L("=C;VYT<FEB=71O<B<L("=H96QP
M97(G*2!A<R`D<F]L92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^7W!A8VMA9V5);F9O6R1R;VQE72DI('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;,%TI*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/2!A<G)A>2@D
M=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE72D[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5);F9O6R1R;VQE
M72!A<R`D:2`]/B`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@("`@("`@(&EF
M("@D;6%I;G1A:6YE<ELG=7-E<B==(#T]("1H86YD;&4I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@)&D[#0H@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D9F]U;F0@(3T](&9A;'-E*2![#0H@("`@("`@("`@
M("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95U;)&9O=6YD
M72D[#0H@("`@("`@("`@("`@("`@:68@*"%C;W5N="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R1R;VQE72D@)B8@)')O;&4@/3T@)VQE860G*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)'1H:7,M/E]P
M86-K86=E26YF;ULD<F]L95TI*2![#0H@("`@("`@("`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=*3L-"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=(#T-"B`@
M("`@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)')O;&5=*3L-"B`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H
M:7,M/E]P86-K86=E26YF;ULD<F]L95TI(#T](#$I('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULD<F]L95T@/2`D=&AI<RT^
M7W!A8VMA9V5);F9O6R1R;VQE75LP73L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/E]P86-K86=E26YF;ULD<F]L
M95TI(#T](#$I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1R;VQE72`]("1T:&ES+3Y?<&%C:V%G94EN9F];)')O;&5=6S!=.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971296QE87-E5F5R<VEO;B@D
M=F5R<VEO;BD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=V97)S:6]N)UTI("8F#0H@("`@("`@("`@("`@(&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LG<F5L96%S92==*2D@
M>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R
M<VEO;B==6R=R96QE87-E)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C
M:V%G94EN9F\L("1V97)S:6]N+"!A<G)A>2@-"B`@("`@("`@("`@("=V97)S
M:6]N)R`]/B!A<G)A>2@G<W1A8FEL:71Y)RP@)VQI8V5N<V4G+"`G;F]T97,G
M+"`G8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@
M)V1E<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L
M92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@
M("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@
M("`@("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H
M86YG96QO9R<I+`T*("`@("`@("`@("`@)W)E;&5A<V4G(#T^(&%R<F%Y*"=A
M<&DG*2DI.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('-E=$%0259E<G-I;VXH)'9E<G-I;VXI#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R
M<VEO;B==*2`F)@T*("`@("`@("`@("`@("!I<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R=V97)S:6]N)UU;)V%P:2==*2D@>PT*("`@("`@("`@("`@=6YS
M970H)'1H:7,M/E]P86-K86=E26YF;ULG=F5R<VEO;B==6R=A<&DG72D[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES
M+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)'9E<G-I;VXL(&%R
M<F%Y*`T*("`@("`@("`@("`@)W9E<G-I;VXG(#T^(&%R<F%Y*"=S=&%B:6QI
M='DG+"`G;&EC96YS92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I
M8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I
M9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A
M8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S
M92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN
M<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@
M("`G87!I)R`]/B!A<G)A>2@I*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](#`[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@<VYA<'-H;W1\9&5V
M96Q\86QP:&%\8F5T87QS=&%B;&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S
M971296QE87-E4W1A8FEL:71Y*"1S=&%T92D-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG72D@)B8-
M"B`@("`@("`@("`@("`@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A
M8FEL:71Y)UU;)W)E;&5A<V4G72DI('L-"B`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R=R96QE87-E)UTI.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI
M<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1S=&%T92P@87)R
M87DH#0H@("`@("`@("`@("`G<W1A8FEL:71Y)R`]/B!A<G)A>2@G;&EC96YS
M92<L("=N;W1E<R<L("=C;VYT96YT<R<L("=C;VUP871I8FQE)RP-"B`@("`@
M("`@("`@("`@("`G9&5P96YD96YC:65S)RP@)W!R;W9I9&5S97AT96YS:6]N
M)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C
M=7)I)RP-"B`@("`@("`@("`@("`@("`G<&AP<F5L96%S92<L("=E>'1S<F-R
M96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B
M=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`G<F5L96%S92<@
M/3X@87)R87DH)V%P:2<I*2D[#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`]
M(#`[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&1E=F5L?&%L
M<&AA?&)E=&%\<W1A8FQE#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T05!)
M4W1A8FEL:71Y*"1S=&%T92D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=S=&%B:6QI='DG72D@)B8-"B`@("`@("`@
M("`@("`@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL:71Y)UU;
M)V%P:2==*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E
M26YF;ULG<W1A8FEL:71Y)UU;)V%P:2==*3L-"B`@("`@("`@?0T*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI
M<RT^7W!A8VMA9V5);F9O+"`D<W1A=&4L(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-T86)I;&ET>2<@/3X@87)R87DH)VQI8V5N<V4G+"`G;F]T97,G+"`G8V]N
M=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E<&5N
M9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U
M<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@("`@
M("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@("`@
M("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG96QO
M9R<I+`T*("`@("`@("`@("`@)V%P:2<@/3X@87)R87DH*2DI.PT*("`@("`@
M("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('-E=$QI8V5N<V4H)&QI8V5N<V4L("1U<FD@/2!F86QS92P@)&9I;&5S;W5R
M8V4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG;&EC96YS92==*2D@>PT*("`@("`@("`@("`@+R\@
M96YS=7)E('1H870@=&AE(&QI8V5N<V4@=&%G(&ES('-E="!U<"!I;B!T:&4@
M<FEG:'0@;&]C871I;VX-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN
M9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R92@D=&AI<RT^7W!A8VMA9V5);F9O
M+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=N;W1E<R<L("=C;VYT96YT<R<L
M("=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S
M)RP@)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K
M)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@("`@("`@("`@("`@("`G
M<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP-"B`@("`@("`@("`@("`@
M("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL(#`L
M("=L:6-E;G-E)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1U<FD@?'P@
M)&9I;&5S;W5R8V4I('L-"B`@("`@("`@("`@("1A='1R:6)S(#T@87)R87DH
M*3L-"B`@("`@("`@("`@(&EF("@D=7)I*2![#0H@("`@("`@("`@("`@("`@
M)&%T=')I8G-;)W5R:2==(#T@)'5R:3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1U<FD@/2!T<G5E.R`O+R!F;W(@=&5S="!B96QO=PT*("`@("`@
M("`@("`@:68@*"1F:6QE<V]U<F-E*2![#0H@("`@("`@("`@("`@("`@)&%T
M=')I8G-;)V9I;&5S;W5R8V4G72`]("1F:6QE<V]U<F-E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1L:6-E;G-E(#T@)'5R:2`_(&%R
M<F%Y*"=A='1R:6)S)R`]/B`D871T<FEB<RP@)U]C;VYT96YT)R`]/B`D;&EC
M96YS92D@.B`D;&EC96YS93L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG;&EC96YS92==(#T@)&QI8V5N<V4[#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T3F]T97,H)&YO
M=&5S*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=N;W1E<R==
M*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@=&AE(&YO=&5S('1A
M9R!I<R!S970@=7`@:6X@=&AE(')I9VAT(&QO8V%T:6]N#0H@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E<G1"969O<F4H
M)'1H:7,M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@("!A<G)A>2@G
M8V]N=&5N=',G+"`G8V]M<&%T:6)L92<L#0H@("`@("`@("`@("`@("`@)V1E
M<&5N9&5N8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L
M("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R:2<L#0H@("`@("`@
M("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L#0H@("`@
M("`@("`@("`@("`@)V5X=&)I;G)E;&5A<V4G+"`G8G5N9&QE)RP@)V-H86YG
M96QO9R<I+"`D;F]T97,L("=N;W1E<R<I.PT*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S)UT@/2`D;F]T97,[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!I<R!O;FQY('5S960@870@:6YS
M=&%L;"UT:6UE+"!A9G1E<B!A;&P@<V5R:6%L:7IA=&EO;@T*("`@("`J(&ES
M(&]V97(N#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&EN<W1A;&QE9"!P871H#0H@("`@("HO#0H@("`@
M9G5N8W1I;VX@<V5T26YS=&%L;&5D07,H)&9I;&4L("1P871H*0T*("`@('L-
M"B`@("`@("`@:68@*"1P871H*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE
M9%]A<R==(#T@)'!A=&@[#0H@("`@("`@('T-"B`@("`@("`@=6YS970H)'1H
M:7,M/E]P86-K86=E26YF;ULG9FEL96QI<W0G75LD9FEL95U;)VEN<W1A;&QE
M9%]A<R==*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&]N
M;'D@=7-E9"!A="!I;G-T86QL+71I;64L(&%F=&5R(&%L;"!S97)I86QI>F%T
M:6]N#0H@("`@("H@:7,@;W9E<BX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I
M;G-T86QL961&:6QE*"1F:6QE+"`D871T<RD-"B`@("![#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V9I;&5L
M:7-T)UU;)&9I;&5=(#T-"B`@("`@("`@("`@("`@("!A<G)A>5]M97)G92@D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72P@)&%T='-;
M)V%T=')I8G,G72D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==6R1F:6QE72`]("1A='1S
M6R=A='1R:6)S)UT[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!297-E="!T:&4@;&ES=&EN9R!O9B!P86-K86=E(&-O;G1E;G1S#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!B87-E(&EN<W1A;&QA=&EO;B!D:7(@9F]R
M('1H92!W:&]L92!P86-K86=E+"!I9B!A;GD-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!C;&5A<D-O;G1E;G1S*"1B87-E:6YS=&%L;"`](&9A;'-E*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]F:6QE<U9A;&ED(#T@9F%L<V4[#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VEN<V5R=$)E9F]R
M92@D=&AI<RT^7W!A8VMA9V5);F9O+`T*("`@("`@("`@("`@("`@(&%R<F%Y
M*"=C;VUP871I8FQE)RP-"B`@("`@("`@("`@("`@("`@("`@)V1E<&5N9&5N
M8VEE<R<L("=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S
M=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R
M8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@
M("`@("`@("`@("`@("`G97AT8FEN<F5L96%S92<L("=B=6YD;&4G+"`G8VAA
M;F=E;&]G)RDL(&%R<F%Y*"DL("=C;VYT96YT<R<I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2`A/2`G8G5N9&QE
M)RD@>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N
M=',G72`](`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=D:7(G(#T^(&%R<F%Y
M*"=A='1R:6)S)R`]/B!A<G)A>2@G;F%M92<@/3X@)R\G*2DI.PT*("`@("`@
M("`@("`@:68@*"1B87-E:6YS=&%L;"D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=A='1R:6)S
M)UU;)V)A<V5I;G-T86QL9&ER)UT@/2`D8F%S96EN<W1A;&P[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@<W1R:6YG(')E;&%T:79E('!A=&@@;V8@=&AE(&)U;F1L960@<&%C
M:V%G92X-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1"=6YD;&5D4&%C:V%G
M92@D<&%T:"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G
M951Y<&4H*2`A/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]
M(&9A;'-E.PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI
M<RT^7W!A8VMA9V5);F9O+"`D<&%T:"P@87)R87DH#0H@("`@("`@("`@("`@
M("`@)V-O;G1E;G1S)R`]/B!A<G)A>2@G8V]M<&%T:6)L92<L("=D97!E;F1E
M;F-I97,G+"`G<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@
M("=U<V5S<F]L92<L("=U<V5S=&%S:R<L("=S<F-P86-K86=E)RP@)W-R8W5R
M:2<L("=P:'!R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT<W)C<F5L
M96%S92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G
M*2P-"B`@("`@("`@("`@("`@("`G8G5N9&QE9'!A8VMA9V4G(#T^(&%R<F%Y
M*"DI*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG
M(&9I;&4@;F%M90T*("`@("`J($!P87)A;2!014%27U1A<VM?0V]M;6]N(&$@
M<F5A9"]W<FET92!T87-K#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D5&%S
M:U1O1FEL92@D9FEL96YA;64L("1T87-K*0T*("`@('L-"B`@("`@("`@:68@
M*"%M971H;V1?97AI<W1S*"1T87-K+"`G9V5T6&UL)RDI('L-"B`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6UE
M=&AO9%]E>&ES=',H)'1A<VLL("=G971.86UE)RDI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6UE=&AO
M9%]E>&ES=',H)'1A<VLL("=V86QI9&%T92<I*2![#0H@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&%S:RT^
M=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^9V5T
M5&%S:W-.<R@I.R`O+R!D:7-C;W9E<B!T:&4@=&%S:W,@;F%M97-P86-E(&EF
M(&YO="!D;VYE(&%L<F5A9'D-"B`@("`@("`@)&9I;&5S(#T@)'1H:7,M/E]P
M86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G73L-"B`@("`@
M("`@:68@*"%I<W-E="@D9FEL97-;,%TI*2![#0H@("`@("`@("`@("`D9FEL
M97,@/2!A<G)A>2@D9FEL97,I.PT*("`@("`@("`@("`@)&EN9"`](&9A;'-E
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&EN9"`]('1R=64[
M#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1I(#T^
M("1F:6QE*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&9I;&5;)V%T=')I
M8G,G72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5;)V%T=')I8G,G
M75LG;F%M92==(#T]("1F:6QE;F%M92D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&EN9"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'0@/2!I
M<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG
M9FEL92==6R1I70T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A
M='1R:6)S)UU;)'1H:7,M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<Z)R`N("1T87-K+3YG971.86UE*"E=*2`_#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R1I70T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@6R=A='1R:6)S)UU;)'1H:7,M/E]T87-K<TYS
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z)R`N("1T87-K
M+3YG971.86UE*"E=(#H@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)'0@)B8@(6ES<V5T*"1T6S!=*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;
M)V1I<B==6R=F:6QE)UU;)&E=#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%LD=&AI<RT^7W1A<VMS3G,@+B`G.B<@+B`D=&%S:RT^9V5T3F%M
M92@I72`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)&E=6R1T:&ES+3Y?=&%S:W-.
M<R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)SHG("X@)'1A<VLM
M/F=E=$YA;64H*5U;72`]("1T87-K+3YG9718;6PH*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M(#T@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER
M)UU;)V9I;&4G70T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=A
M='1R:6)S)UU;)'1H:7,M/E]T87-K<TYS("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<Z)R`N("1T87-K+3YG971.86UE*"E=*2`_("1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UT-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG871T<FEB<R==6R1T:&ES
M+3Y?=&%S:W-.<R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M.B<@+B`D=&%S:RT^9V5T3F%M92@I72`Z(&9A;'-E.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1T("8F("%I<W-E="@D=%LP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VYT96YT<R==6R=D:7(G75LG9FEL92==#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%LD=&AI<RT^7W1A<VMS3G,@+B`G.B<@+B`D=&%S:RT^
M9V5T3F%M92@I72`](&%R<F%Y*"1T*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G
M94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;)'1H:7,M/E]T87-K
M<TYS("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G.B<@+B`D=&%S
M:RT^9V5T3F%M92@I75M=(#T@)'1A<VLM/F=E=%AM;"@I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('-T<FEN9R!P871H('1O('1H92!F:6QE#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!F:6QE;F%M90T*("`@("`J($!P87)A;2!A<G)A>2!E
M>'1R82!A='1R:6)U=&5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D1FEL
M92@D9&ER+"`D9FEL92P@)&%T=')S*0T*("`@('L-"B`@("`@("`@:68@*"1T
M:&ES+3YG971086-K86=E5'EP92@I(#T]("=B=6YD;&4G*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/E]F:6QE<U9A;&ED(#T@9F%L<V4[#0H@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](#`[#0H@("`@("`@("1D:7(@/2!P<F5G7W)E<&QA8V4H87)R87DH)R%<
M7%Q<*R$G+"`G(2\K(2<I+"!A<G)A>2@G+R<L("<O)RDL("1D:7(I.PT*("`@
M("`@("!I9B`H)&1I<B`]/2`G+R<@?'P@)&1I<B`]/2`G)RD@>PT*("`@("`@
M("`@("`@)&1I<B`]("<G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)&1I<B`N/2`G+R<[#0H@("`@("`@('T-"B`@("`@("`@)&%T=')S6R=N
M86UE)UT@/2`D9&ER("X@)&9I;&4[#0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G72DI('L-"B`@("`@("`@("`@
M("\O(&5N<W5R92!T:&%T('1H92!C;VYT96YT<R!T86<@:7,@<V5T('5P#0H@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]I;G-E
M<G1"969O<F4H)'1H:7,M/E]P86-K86=E26YF;RP-"B`@("`@("`@("`@("`@
M("!A<G)A>2@G8V]M<&%T:6)L92<L("=D97!E;F1E;F-I97,G+"`G<')O=FED
M97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@
M("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E
M)RP@)V5X='-R8W)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("=E>'1B:6YR
M96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@87)R87DH*2P@)V-O
M;G1E;G1S)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI*2![
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG9&ER)UU;
M)V9I;&4G72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG
M8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G75M=6R=A='1R:6)S)UT@/2`D871T
M<G,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C;VYT96YT<R==6R=D:7(G75LG9FEL92==6R=A='1R:6)S
M)UT@/2`D871T<G,[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!`<&%R86T@<W1R:6YG($1E<&5N9&5N="!P86-K86=E(&YA;64-"B`@
M("`@*B!`<&%R86T@<W1R:6YG($1E<&5N9&5N="!P86-K86=E)W,@8VAA;FYE
M;"!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E<G-I;VX@
M;V8@<W!E8VEF:65D('!A8VMA9V4@=&AA="!T:&ES(')E;&5A<V4@:7,@9W5A
M<F%N=&5E9"!T;R!B90T*("`@("`J("`@("`@("`@("`@("`@8V]M<&%T:6)L
M92!W:71H#0H@("`@("H@0'!A<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX@
M;V8@<W!E8VEF:65D('!A8VMA9V4@=&AA="!T:&ES(')E;&5A<V4@:7,@9W5A
M<F%N=&5E9"!T;R!B90T*("`@("`J("`@("`@("`@("`@("`@8V]M<&%T:6)L
M92!W:71H#0H@("`@("H@0'!A<F%M('-T<FEN9R!V97)S:6]N<R!O9B!S<&5C
M:69I960@<&%C:V%G92!T:&%T('1H:7,@<F5L96%S92!I<R!N;W0@8V]M<&%T
M:6)L92!W:71H#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D0V]M<&%T:6)L
M95!A8VMA9V4H)&YA;64L("1C:&%N;F5L+"`D;6EN+"`D;6%X+"`D97AC;'5D
M92`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@
M,#L-"B`@("`@("`@)'-E="`](&%R<F%Y*`T*("`@("`@("`@("`@)VYA;64G
M(#T^("1N86UE+`T*("`@("`@("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L
M+`T*("`@("`@("`@("`@)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("=M
M87@G(#T^("1M87@L#0H@("`@("`@("D[#0H@("`@("`@(&EF("@D97AC;'5D
M92D@>PT*("`@("`@("`@("`@)'-E=%LG97AC;'5D92==(#T@)&5X8VQU9&4[
M#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H
M)'1H:7,M/E]P86-K86=E26YF;RP@)'-E="P@87)R87DH#0H@("`@("`@("`@
M("`@("`@)V-O;7!A=&EB;&4G(#T^(&%R<F%Y*"=D97!E;F1E;F-I97,G+"`G
M<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*
M("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G
M<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G
M+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I
M#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2
M96UO=F5S('1H92`\=7-E<W)O;&4^('1A9R!E;G1I<F5L>0T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(')E<V5T57-E<W)O;&4H*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-R;VQE)UTI*2![
M#0H@("`@("`@("`@("!U;G-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S
M<F]L92==*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@
M;F%M92!O<B!U<FD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN96P@;F%M
M92!I9B!N;VXM=7)I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D57-E<W)O
M;&4H)')O;&4L("1P86-K86=E3W)5<FDL("1C:&%N;F5L(#T@9F%L<V4I('L-
M"B`@("`@("`@)'-E="`](&%R<F%Y*"=R;VQE)R`]/B`D<F]L92D[#0H@("`@
M("`@(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)'-E=%LG<&%C:V%G
M92==(#T@)'!A8VMA9V5/<E5R:3L-"B`@("`@("`@("`@("1S971;)V-H86YN
M96PG72`]("1C:&%N;F5L.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'-E=%LG=7)I)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@("!]#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G
M94EN9F\L("1S970L(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=U<V5S<F]L
M92<@/3X@87)R87DH)W5S97-T87-K)RP@)W-R8W!A8VMA9V4G+"`G<W)C=7)I
M)RP-"B`@("`@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C
M<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L
M;V<G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@4F5M;W9E<R!T:&4@/'5S97-T87-K/B!T86<@96YT:7)E;'D-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!R97-E=%5S97-T87-K*"D-"B`@("![#0H@("`@
M("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S=&%S:R==
M*2D@>PT*("`@("`@("`@("`@=6YS970H)'1H:7,M/E]P86-K86=E26YF;ULG
M=7-E<W1A<VLG72D[#0H@("`@("`@('T-"B`@("!]#0H-"@T*("`@("\J*@T*
M("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A
M8VMA9V4@;F%M92!O<B!U<FD-"B`@("`@*B!`<&%R86T@<W1R:6YG(&-H86YN
M96P@;F%M92!I9B!N;VXM=7)I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D
M57-E<W1A<VLH)'1A<VLL("1P86-K86=E3W)5<FDL("1C:&%N;F5L(#T@9F%L
M<V4I('L-"B`@("`@("`@)'-E="`](&%R<F%Y*"=T87-K)R`]/B`D=&%S:RD[
M#0H@("`@("`@(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)'-E=%LG
M<&%C:V%G92==(#T@)'!A8VMA9V5/<E5R:3L-"B`@("`@("`@("`@("1S971;
M)V-H86YN96PG72`]("1C:&%N;F5L.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)'-E=%LG=7)I)UT@/2`D<&%C:V%G94]R57)I.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?
M<&%C:V%G94EN9F\L("1S970L(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=U
M<V5S=&%S:R<@/3X@87)R87DH)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP-"B`@
M("`@("`@("`@("`@("`@("`@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S
M92<L("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*0T*
M("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5M
M;W9E(&%L;"!C;VUP871I8FQE('1A9W,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!C;&5A<D-O;7!A=&EB;&4H*0T*("`@('L-"B`@("`@("`@=6YS970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8V]M<&%T:6)L92==*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!297-E="!D97!E;F1E;F-I97,@<')I;W(@=&\@861D
M:6YG(&YE=R!O;F5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8VQE87)$97!S
M*"D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E
M26YF;ULG9&5P96YD96YC:65S)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA
M9V5);F9O+"!A<G)A>2@I+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O
M=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@
M)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E
M;&]G)RDI*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=D97!E;F1E;F-I97,G72`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M(%!(4"!V97)S:6]N
M(&%L;&]W960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@4$A0('9E
M<G-I;VX@86QL;W=E9`T*("`@("`J($!P87)A;2!A<G)A>2`D97AC;'5D92!I
M;F-O;7!A=&EB;&4@4$A0('9E<G-I;VYS#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@<V5T4&AP1&5P*"1M:6XL("1M87@@/2!F86QS92P@)&5X8VQU9&4@/2!F
M86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@("1D97`@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("D[#0H@("`@("`@
M(&EF("@D;6%X*2![#0H@("`@("`@("`@("`D9&5P6R=M87@G72`]("1M87@[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1E>&-L=61E*2![#0H@("`@("`@
M("`@("!I9B`H8V]U;G0H)&5X8VQU9&4I(#T](#$I('L-"B`@("`@("`@("`@
M("`@("`D97AC;'5D92`]("1E>&-L=61E6S!=.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@)&5X8VQU9&4[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P:'`G72DI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R
M;FEN9R<L(&%R<F%Y*"=D97`G(#T^#0H@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER960G75LG<&AP)UTI
M+`T*("`@("`@("`@("`@("`@("=W87)N:6YG.B!02%`@9&5P96YD96YC>2!A
M;')E861Y(&5X:7-T<RP@;W9E<G=R:71I;F<G*3L-"B`@("`@("`@("`@('5N
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U
M:7)E9"==6R=P:'`G72D[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E
M26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO
M;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@
M("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X
M='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@
M("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@
M("`@)W)E<75I<F5D)R`]/B!A<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*2P-
M"B`@("`@("`@("`@("`@("`G<&AP)R`]/B!A<G)A>2@G<&5A<FEN<W1A;&QE
M<B<L("=P86-K86=E)RP@)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S
M)RP@)V%R8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@
M;6EN:6UU;2!A;&QO=V5D(%!%05(@:6YS=&%L;&5R('9E<G-I;VX-"B`@("`@
M*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@86QL;W=E9"!014%2(&EN<W1A;&QE
M<B!V97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!0
M14%2(&EN<W1A;&QE<B!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN
M8V]M<&%T:6)L92!V97)S:6]N(&]F('1H92!014%2(&EN<W1A;&QE<@T*("`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=%!E87)I;G-T86QL97)$97`H)&UI;BP@
M)&UA>"`](&9A;'-E+"`D<F5C;VUM96YD960@/2!F86QS92P@)&5X8VQU9&4@
M/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[
M#0H@("`@("`@("1D97`@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@
M("`@("`@("`@)VUI;B<@/3X@)&UI;BP-"B`@("`@("`@("`@("D[#0H@("`@
M("`@(&EF("@D;6%X*2![#0H@("`@("`@("`@("`D9&5P6R=M87@G72`]("1M
M87@[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1R96-O;6UE;F1E9"D@>PT*
M("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G72`]("1R96-O;6UE;F1E
M9#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&5X8VQU9&4I('L-"B`@("`@
M("`@("`@(&EF("AC;W5N="@D97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@
M("`@("`@("1E>&-L=61E(#T@)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G=V%R;FEN9R<L(&%R<F%Y*"=D97`G(#T^#0H@("`@("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LG<F5Q=6ER
M960G75LG<&5A<FEN<W1A;&QE<B==*2P-"B`@("`@("`@("`@("`@("`G=V%R
M;FEN9SH@4$5!4B!);G-T86QL97(@9&5P96YD96YC>2!A;')E861Y(&5X:7-T
M<RP@;W9E<G=R:71I;F<G*3L-"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P96%R
M:6YS=&%L;&5R)UTI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN
M9F\L("1D97`L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`G9&5P96YD96YC:65S)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG
M+"`G=7-E<W)O;&4G+"`G=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@
M("`G<W)C<&%C:V%G92<L("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S
M<F-R96QE87-E)RP@)V5X=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@
M("`@("`G8G5N9&QE)RP@)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@("`@
M("=R97%U:7)E9"<@/3X@87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@
M("`@("`@("`@("`@("`@)W!E87)I;G-T86QL97(G(#T^(&%R<F%Y*"=P86-K
M86=E)RP@)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@)V%R8V@G
M*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M36%R:R!A('!A8VMA9V4@87,@8V]N9FQI8W1I;F<@=VET:"!T:&ES('!A8VMA
M9V4-"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J
M($!P87)A;2!S=')I;F<@<&%C:V%G92!C:&%N;F5L#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A
M;GD-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1#;VYF;&EC=&EN9U!A8VMA
M9V5$97!7:71H0VAA;FYE;"@D;F%M92P@)&-H86YN96PL("1P<F]V:61E<V5X
M=&5N<VEO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A
M;&ED(#T@,#L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@("`@
M("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L+`T*("`@("`@("`@("`@("`@
M("=C;VYF;&EC=',G(#T^("<G+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@
M:68@*"1P<F]V:61E<V5X=&5N<VEO;BD@>PT*("`@("`@("`@("`@)&1E<%LG
M<')O=FED97-E>'1E;G-I;VXG72`]("1P<F]V:61E<V5X=&5N<VEO;CL-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M
M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<@
M/3X@87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S
M97-T87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G+"`G
M<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E>'1B
M:6YR96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L("=C
M:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^(&%R
M<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@("=P
M86-K86=E)R`]/B!A<G)A>2@G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G
M;W,G+"`G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!-87)K(&$@<&%C:V%G92!A<R!C;VYF;&EC=&EN9R!W:71H
M('1H:7,@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G92!N
M86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&5X=&5N<VEO;B!T:&ES('!A8VMA9V4@<')O
M=FED97,L(&EF(&%N>0T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$-O;F9L
M:6-T:6YG4&%C:V%G941E<%=I=&A5<FDH)&YA;64L("1U<FDL("1P<F]V:61E
M<V5X=&5N<VEO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I
M<U9A;&ED(#T@,#L-"B`@("`@("`@)&1E<"`]#0H@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&YA;64L#0H@("`@("`@
M("`@("`@("`@)W5R:2<@/3X@)'5R:2P-"B`@("`@("`@("`@("`@("`G8V]N
M9FQI8W1S)R`]/B`G)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF("@D
M<')O=FED97-E>'1E;G-I;VXI('L-"B`@("`@("`@("`@("1D97!;)W!R;W9I
M9&5S97AT96YS:6]N)UT@/2`D<')O=FED97-E>'1E;G-I;VX[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R
M9V5486<H)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@("`@("`@("`@
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R
M<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S
M:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R
M:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L
M96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E
M;&]G)RDL#0H@("`@("`@("`@("`@("`@)W)E<75I<F5D)R`]/B!A<G)A>2@G
M;W!T:6]N86PG+"`G9W)O=7`G*2P-"B`@("`@("`@("`@("`@("`G<&%C:V%G
M92<@/3X@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT96YS:6]N)RP@)V]S)RP@
M)V%R8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@861D1&5P96YD96YC>4=R;W5P*"1N86UE+"`D:&EN="D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F\@/2`D=&AI<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G
M94EN9F\L#0H@("`@("`@("`@("!A<G)A>2@G871T<FEB<R<@/3X@87)R87DH
M)VYA;64G(#T^("1N86UE+"`G:&EN="<@/3X@)&AI;G0I*2P-"B`@("`@("`@
M("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^
M(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S
M=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R
M8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN
M<F5L96%S92<L#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA
M;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@)V=R;W5P)R`]/B!A<G)A>2@I
M+`T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!P86-K86=E(&YA;64-"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&9A;'-E(&-H86YN96P@;F%M92P@9F%L<V4@:68@=&AI<R!I<R!A('5R
M:0T*("`@("`J($!P87)A;2!S=')I;F=\9F%L<V4@=7)I(&YA;64L(&9A;'-E
M(&EF('1H:7,@:7,@82!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T<FEN9WQF
M86QS92!M:6YI;75M('9E<G-I;VX@<F5Q=6ER960-"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&9A;'-E(&UA>&EM=6T@=F5R<VEO;B!A;&QO=V5D#0H@("`@("H@
M0'!A<F%M('-T<FEN9WQF86QS92!R96-O;6UE;F1E9"!I;G-T86QL871I;VX@
M=F5R<VEO;@T*("`@("`J($!P87)A;2!A<G)A>7QF86QS92!V97)S:6]N<R!T
M;R!E>&-L=61E(&9R;VT@:6YS=&%L;&%T:6]N#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!E>'1E;G-I;VX@=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-
M"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L
M;&5R('1O(&EG;F]R92!T:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y
M(&=R;W5P#0H@("`@("H@("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H
M:7,@<&%C:V%G90T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?8V]N<W1R=6-T
M1&5P*"1N86UE+"`D8VAA;FYE;"P@)'5R:2P@)&UI;BP@)&UA>"P@)')E8V]M
M;65N9&5D+"`D97AC;'5D92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F]V:61E<V5X=&5N<VEO;B`](&9A;'-E+"`D;F]D969A=6QT(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("`D9&5P(#T-"B`@("`@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92P-"B`@("`@("`@
M("`@("D[#0H@("`@("`@(&EF("@D8VAA;FYE;"D@>PT*("`@("`@("`@("`@
M)&1E<%LG8VAA;FYE;"==(#T@)&-H86YN96P[#0H@("`@("`@('T@96QS96EF
M("@D=7)I*2![#0H@("`@("`@("`@("`D9&5P6R=U<FDG72`]("1U<FD[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1M:6XI('L-"B`@("`@("`@("`@("1D
M97!;)VUI;B==(#T@)&UI;CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&UA
M>"D@>PT*("`@("`@("`@("`@)&1E<%LG;6%X)UT@/2`D;6%X.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D<F5C;VUM96YD960I('L-"B`@("`@("`@("`@
M("1D97!;)W)E8V]M;65N9&5D)UT@/2`D<F5C;VUM96YD960[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1E>&-L=61E*2![#0H@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)&5X8VQU9&4I("8F(&-O=6YT*"1E>&-L=61E*2`]/2`Q*2![
M#0H@("`@("`@("`@("`@("`@)&5X8VQU9&4@/2`D97AC;'5D95LP73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`]("1E
M>&-L=61E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;F]D969A=6QT*2![
M#0H@("`@("`@("`@("`D9&5P6R=N;V1E9F%U;'0G72`]("<G.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@D<')O=FED97-E>'1E;G-I;VXI('L-"B`@("`@
M("`@("`@("1D97!;)W!R;W9I9&5S97AT96YS:6]N)UT@/2`D<')O=FED97-E
M>'1E;G-I;VX[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1D97`[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C
M:V%G90T*("`@("`J($!P87)A;2!S=')I;F<@9W)O=7`@;F%M90T*("`@("`J
M($!P87)A;2!S=')I;F<@<&%C:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!P86-K86=E(&-H86YN96P-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI
M;FEM=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@;6%X:6UU;2!V
M97)S:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE;F1E9"!V97)S
M:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y?&9A;'-E(&]P=&EO;F%L(&5X8VQU
M9&5D('9E<G-I;VYS#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E;G-I;VX@
M=&AI<R!P86-K86=E('!R;W9I9&5S+"!I9B!A;GD-"B`@("`@*B!`<&%R86T@
M8F]O;"!I9B!T<G5E+"!T96QL<R!T:&4@:6YS=&%L;&5R('1O(&EG;F]R92!T
M:&4@9&5F875L="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("H@
M("`@("`@("`@("`@=VAE;B!I;G-T86QL:6YG('1H:7,@<&%C:V%G90T*("`@
M("`J($!R971U<FX@8F]O;"!F86QS92!I9B!T:&4@9&5P96YD96YC>2!G<F]U
M<"!H87,@;F]T(&)E96X@:6YI=&EA;&EZ960@=VET:`T*("`@("`J("`@("`@
M("`@("`@("![0&QI;FL@861D1&5P96YD96YC>4=R;W5P*"E]+"!O<B!A('-U
M8G!A8VMA9V4@:7,@861D960@=VET:`T*("`@("`J("`@("`@("`@("`@("!A
M('!R;W9I9&5S97AT96YS:6]N#0H@("`@("HO#0H@("`@9G5N8W1I;VX@861D
M1W)O=7!086-K86=E1&5P5VET:$-H86YN96PH)'1Y<&4L("1G<F]U<&YA;64L
M("1N86UE+"`D8VAA;FYE;"P@)&UI;B`](&9A;'-E+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;6%X(#T@9F%L<V4L("1R96-O
M;6UE;F1E9"`](&9A;'-E+"`D97AC;'5D92`](&9A;'-E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I
M;VX@/2!F86QS92P@)&YO9&5F875L="`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@:68@*"1T>7!E(#T]("=S=6)P86-K86=E)R`F)B`D<')O=FED97-E>'1E
M;G-I;VXI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L@+R\@<W5B<&%C
M:V%G97,@;75S="!B92!P:'`@<&%C:V%G97,-"B`@("`@("`@?0T*("`@("`@
M("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L("1C:&%N;F5L
M+"!F86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92P-
M"B`@("`@("`@("`@("1P<F]V:61E<V5X=&5N<VEO;BP@)&YO9&5F875L="D[
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V%D9$=R;W5P1&5P96YD96YC>2@D
M='EP92P@)&1E<"P@)&=R;W5P;F%M92D[#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C:V%G90T*("`@("`J($!P87)A
M;2!S=')I;F<@9W)O=7`@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@<&%C
M:V%G92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E('5R:0T*
M("`@("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H:7,@<&%C:V%G92!P
M<F]V:61E<RP@:68@86YY#0H@("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@
M=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T
M:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@("`@("`@("`@('=H
M96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@*B!`<F5T=7)N(&)O
M;VP@9F%L<V4@:68@=&AE(&1E<&5N9&5N8WD@9W)O=7`@:&%S(&YO="!B965N
M(&EN:71I86QI>F5D('=I=&@-"B`@("`@*B`@("`@("`@("`@("`@>T!L:6YK
M(&%D9$1E<&5N9&5N8WE'<F]U<"@I?0T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&%D9$=R;W5P4&%C:V%G941E<%=I=&A54DDH)'1Y<&4L("1G<F]U<&YA;64L
M("1N86UE+"`D=7)I+"`D<')O=FED97-E>'1E;G-I;VX@/2!F86QS92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E9F%U
M;'0@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D='EP92`]/2`G<W5B
M<&%C:V%G92<@)B8@)'!R;W9I9&5S97AT96YS:6]N*2![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[("\O('-U8G!A8VMA9V5S(&UU<W0@8F4@<&AP('!A
M8VMA9V5S#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES+3Y?8V]N
M<W1R=6-T1&5P*"1N86UE+"!F86QS92P@)'5R:2P@9F%L<V4L(&9A;'-E+"!F
M86QS92P@9F%L<V4L#0H@("`@("`@("`@("`D<')O=FED97-E>'1E;G-I;VXL
M("1N;V1E9F%U;'0I.PT*("`@("`@("!R971U<FX@)'1H:7,M/E]A9&1'<F]U
M<$1E<&5N9&5N8WDH)'1Y<&4L("1D97`L("1G<F]U<&YA;64I.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@9W)O=7`@;F%M92`H
M;75S="!B92!P<F4M97AI<W1I;F<I#0H@("`@("H@0'!A<F%M('-T<FEN9R!E
M>'1E;G-I;VX@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V
M97)S:6]N(&%L;&]W960-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@
M=F5R<VEO;B!A;&QO=V5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!R96-O;6UE
M;F1E9"!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R<F%Y(&EN8V]M<&%T:6)L
M92!V97)S:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$=R;W5P17AT
M96YS:6]N1&5P*"1G<F]U<&YA;64L("1N86UE+"`D;6EN(#T@9F%L<V4L("1M
M87@@/2!F86QS92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E8V]M;65N9&5D(#T@9F%L<V4L("1E>&-L=61E(#T@9F%L
M<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@
M("`@("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L(&9A;'-E
M+"!F86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC;'5D92D[
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V%D9$=R;W5P1&5P96YD96YC>2@G
M97AT96YS:6]N)RP@)&1E<"P@)&=R;W5P;F%M92D[#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@0'!A<F%M('!A8VMA9V5\<W5B<&%C:V%G97QE>'1E;G-I
M;VX-"B`@("`@*B!`<&%R86T@87)R87D@9&5P96YD96YC>2!C;VYT96YT<PT*
M("`@("`J($!P87)A;2!S=')I;F<@;F%M92!O9B!T:&4@9&5P96YD96YC>2!G
M<F]U<"!T;R!A9&0@=&AI<R!T;PT*("`@("`J($!R971U<FX@8F]O;&5A;@T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]A9&1'<F]U<$1E<&5N9&5N8WDH)'1Y<&4L("1D97`L("1G<F]U<&YA;64I
M#0H@("`@>PT*("`@("`@("`D87)R(#T@87)R87DH)W-U8G!A8VMA9V4G+"`G
M97AT96YS:6]N)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G<&%C:V%G92<I
M('L-"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D='EP92`]/2`G97AT96YS:6]N)RD@>PT*("`@("`@
M("`@("`@87)R87E?<VAI9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G
M75LG9W)O=7`G72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<&5N9&5N8VEE<R==6R=G<F]U<"==6R=A='1R:6)S)UU;)VYA;64G72`]/2`D
M9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==(#T@)'1H:7,M/E]M
M97)G951A9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==+"`D9&5P+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1Y<&4@/3X@)&%R<@T*("`@("`@("`@("`@("`@("`@
M("`@("`@*2D[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI
M9"`](#`[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%C
M:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G<F]U<"==(&%S("1I(#T^("1G
M<F]U<"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P6R=A='1R
M:6)S)UU;)VYA;64G72`]/2`D9W)O=7!N86UE*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==6R=G
M<F]U<"==6R1I72`]("1T:&ES+3Y?;65R9V5486<H#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G
M75LG9W)O=7`G75LD:5TL("1D97`L#0H@("`@("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]
M/B`D87)R#0H@("`@("`@("`@("`@("`@("`@("`@("`I*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960-
M"B`@("`@*B!`<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P
M87)A;2!S=')I;F<@<&%C:V%G92!C:&%N;F5L#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!M:6YI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA
M>&EM=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD
M960@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@97AT96YS:6]N('1H
M:7,@<&%C:V%G92!P<F]V:61E<RP@:68@86YY#0H@("`@("H@0'!A<F%M(&)O
M;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE
M(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@
M("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@
M*B!`<&%R86T@87)R87E\9F%L<V4@;W!T:6]N86P@97AC;'5D960@=F5R<VEO
M;G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1086-K86=E1&5P5VET:$-H
M86YN96PH)'1Y<&4L("1N86UE+"`D8VAA;FYE;"P@)&UI;B`](&9A;'-E+"`D
M;6%X(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1R96-O;6UE;F1E9"`](&9A;'-E+"`D97AC;'5D92`](&9A;'-E
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O
M=FED97-E>'1E;G-I;VX@/2!F86QS92P@)&YO9&5F875L="`](&9A;'-E*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@
M)&%R<B`](&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I.PT*("`@("`@("!I
M9B`H)'1Y<&4@(3T@)W)E<75I<F5D)RD@>PT*("`@("`@("`@("`@87)R87E?
M<VAI9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]("1T:&ES
M+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"`D8VAA;FYE;"P@9F%L<V4L("1M:6XL
M("1M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4L#0H@("`@("`@("`@("`D
M<')O=FED97-E>'1E;G-I;VXL("1N;V1E9F%U;'0I.PT*("`@("`@("`D=&AI
M<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]M97)G951A9R@D=&AI<RT^7W!A
M8VMA9V5);F9O+"`D9&5P+`T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@
M("`@("`@("`@)V1E<&5N9&5N8VEE<R<@/3X@87)R87DH)W!R;W9I9&5S97AT
M96YS:6]N)RP@)W5S97-R;VQE)RP@)W5S97-T87-K)RP-"B`@("`@("`@("`@
M("`@("`@("`@)W-R8W!A8VMA9V4G+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G
M+"`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE87-E)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@
M("`@("`@("`D='EP92`]/B`D87)R+`T*("`@("`@("`@("`@("`@("=P86-K
M86=E)R`]/B!A<G)A>2@G<W5B<&%C:V%G92<L("=E>'1E;G-I;VXG+"`G;W,G
M+"`G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&YA;64@;V8@=&AE('!A8VMA9V4-"B`@("`@*B!`<&%R86T@
M<W1R:6YG('5R:2!O9B!T:&4@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I
M;F<@97AT96YS:6]N('1H:7,@<&%C:V%G92!P<F]V:61E<RP@:68@86YY#0H@
M("`@("H@0'!A<F%M(&)O;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE
M<B!T;R!I9VYO<F4@=&AE(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G
M<F]U<`T*("`@("`J("`@("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES
M('!A8VMA9V4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1086-K86=E1&5P
M5VET:%5R:2@D='EP92P@)&YA;64L("1U<FDL("1P<F]V:61E<V5X=&5N<VEO
M;B`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N;V1E9F%U;'0@/2!F86QS92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?
M:7-686QI9"`](#`[#0H@("`@("`@("1A<G(@/2!A<G)A>2@G;W!T:6]N86PG
M+"`G9W)O=7`G*3L-"B`@("`@("`@:68@*"1T>7!E("$]("=R97%U:7)E9"<I
M('L-"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A<G(I.PT*("`@("`@("!]
M#0H@("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T<G5C=$1E<"@D;F%M92P@
M9F%L<V4L("1U<FDL(&9A;'-E+"!F86QS92P@9F%L<V4L(&9A;'-E+`T*("`@
M("`@("`@("`@)'!R;W9I9&5S97AT96YS:6]N+"`D;F]D969A=6QT*3L-"B`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H
M)'1H:7,M/E]P86-K86=E26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P
M<F]V:61E<V5X=&5N<VEO;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@
M("`@("`@("`@("`@("`@("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P
M:'!R96QE87-E)RP@)V5X='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L
M#0H@("`@("`@("`@("`@("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL
M#0H@("`@("`@("`@("`@("`@)'1Y<&4@/3X@)&%R<BP-"B`@("`@("`@("`@
M("`@("`G<&%C:V%G92<@/3X@87)R87DH)W-U8G!A8VMA9V4G+"`G97AT96YS
M:6]N)RP@)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*
M#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&]P=&EO;F%L?')E<75I<F5D(&]P
M=&EO;F%L+"!R97%U:7)E9`T*("`@("`J($!P87)A;2!S=')I;F<@<&%C:V%G
M92!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN9R!P86-K86=E(&-H86YN96P-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&UI;FEM=6T@=F5R<VEO;@T*("`@("`J
M($!P87)A;2!S=')I;F<@;6%X:6UU;2!V97)S:6]N#0H@("`@("H@0'!A<F%M
M('-T<FEN9R!R96-O;6UE;F1E9"!V97)S:6]N#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&EN8V]M<&%T:6)L92!V97)S:6]N<PT*("`@("`J($!P87)A;2!B;V]L
M(&EF('1R=64L('1E;&QS('1H92!I;G-T86QL97(@=&\@:6=N;W)E('1H92!D
M969A=6QT(&]P=&EO;F%L(&1E<&5N9&5N8WD@9W)O=7`-"B`@("`@*B`@("`@
M("`@("`@("!W:&5N(&EN<W1A;&QI;F<@=&AI<R!P86-K86=E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@861D4W5B<&%C:V%G941E<%=I=&A#:&%N;F5L*"1T
M>7!E+"`D;F%M92P@)&-H86YN96PL("1M:6X@/2!F86QS92P@)&UA>"`](&9A
M;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5C;VUM96YD960@/2!F86QS92P@)&5X8VQU9&4@/2!F86QS92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YO9&5F
M875L="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@,#L-"B`@("`@("`@)&%R<B`](&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U
M<"<I.PT*("`@("`@("!I9B`H)'1Y<&4@(3T@)W)E<75I<F5D)RD@>PT*("`@
M("`@("`@("`@87)R87E?<VAI9G0H)&%R<BD[#0H@("`@("`@('T-"B`@("`@
M("`@)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"`D8VAA;FYE
M;"P@9F%L<V4L("1M:6XL("1M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4L
M#0H@("`@("`@("`@("`D;F]D969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E
M26YF;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO
M;B<L("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@
M("`@("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X
M='-R8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@
M("`@("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@
M("`@)'1Y<&4@/3X@)&%R<BP-"B`@("`@("`@("`@("`@("`G<W5B<&%C:V%G
M92<@/3X@87)R87DH)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD-"B`@("`@
M("`@("`@("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O
M<'1I;VYA;'QR97%U:7)E9"!O<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`
M<&%R86T@<W1R:6YG('!A8VMA9V4@;F%M90T*("`@("`J($!P87)A;2!S=')I
M;F<@<&%C:V%G92!U<FD@9F]R(&1O=VYL;V%D#0H@("`@("H@0'!A<F%M(&)O
M;VP@:68@=')U92P@=&5L;',@=&AE(&EN<W1A;&QE<B!T;R!I9VYO<F4@=&AE
M(&1E9F%U;'0@;W!T:6]N86P@9&5P96YD96YC>2!G<F]U<`T*("`@("`J("`@
M("`@("`@("`@('=H96X@:6YS=&%L;&EN9R!T:&ES('!A8VMA9V4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&13=6)P86-K86=E1&5P5VET:%5R:2@D='EP
M92P@)&YA;64L("1U<FDL("1N;V1E9F%U;'0@/2!F86QS92D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1A<G(@/2!A
M<G)A>2@G;W!T:6]N86PG+"`G9W)O=7`G*3L-"B`@("`@("`@:68@*"1T>7!E
M("$]("=R97%U:7)E9"<I('L-"B`@("`@("`@("`@(&%R<F%Y7W-H:69T*"1A
M<G(I.PT*("`@("`@("!]#0H@("`@("`@("1D97`@/2`D=&AI<RT^7V-O;G-T
M<G5C=$1E<"@D;F%M92P@9F%L<V4L("1U<FDL(&9A;'-E+"!F86QS92P@9F%L
M<V4L(&9A;'-E+"`D;F]D969A=6QT*3L-"B`@("`@("`@)'1H:7,M/E]P86-K
M86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H)'1H:7,M/E]P86-K86=E26YF
M;RP@)&1E<"P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=D97!E;F1E;F-I97,G(#T^(&%R<F%Y*"=P<F]V:61E<V5X=&5N<VEO;B<L
M("=U<V5S<F]L92<L("=U<V5S=&%S:R<L#0H@("`@("`@("`@("`@("`@("`@
M("=S<F-P86-K86=E)RP@)W-R8W5R:2<L("=P:'!R96QE87-E)RP@)V5X='-R
M8W)E;&5A<V4G+"`G97AT8FEN<F5L96%S92<L#0H@("`@("`@("`@("`@("`@
M("`@("=B=6YD;&4G+"`G8VAA;F=E;&]G)RDL#0H@("`@("`@("`@("`@("`@
M)'1Y<&4@/3X@)&%R<BP-"B`@("`@("`@("`@("`@("`G<W5B<&%C:V%G92<@
M/3X@87)R87DH)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H)RD-"B`@("`@("`@
M("`@("DI.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!O<'1I
M;VYA;'QR97%U:7)E9"!O<'1I;VYA;"P@<F5Q=6ER960-"B`@("`@*B!`<&%R
M86T@<W1R:6YG(&5X=&5N<VEO;B!N86UE#0H@("`@("H@0'!A<F%M('-T<FEN
M9R!M:6YI;75M('9E<G-I;VX-"B`@("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM
M=6T@=F5R<VEO;@T*("`@("`J($!P87)A;2!S=')I;F<@<F5C;VUM96YD960@
M=F5R<VEO;@T*("`@("`J($!P87)A;2!A<G)A>2!I;F-O;7!A=&EB;&4@=F5R
M<VEO;G,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1%>'1E;G-I;VY$97`H
M)'1Y<&4L("1N86UE+"`D;6EN(#T@9F%L<V4L("1M87@@/2!F86QS92P@)')E
M8V]M;65N9&5D(#T@9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1E>&-L=61E(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7VES5F%L:60@/2`P.PT*("`@("`@("`D87)R(#T@87)R87DH)V]P=&EO;F%L
M)RP@)V=R;W5P)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G<F5Q=6ER960G
M*2![#0H@("`@("`@("`@("!A<G)A>5]S:&EF="@D87)R*3L-"B`@("`@("`@
M?0T*("`@("`@("`D9&5P(#T@)'1H:7,M/E]C;VYS=')U8W1$97`H)&YA;64L
M(&9A;'-E+"!F86QS92P@)&UI;BP@)&UA>"P@)')E8V]M;65N9&5D+"`D97AC
M;'5D92D[#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI<RT^
M7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@("`@
M("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S)R`]
M/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G=7-E
M<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L("=S
M<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X=&)I
M;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@)V-H
M86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("1T>7!E(#T^("1A<G(L#0H@
M("`@("`@("`@("`@("`@)V5X=&5N<VEO;B<@/3X@87)R87DH)V]S)RP@)V%R
M8V@G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M('-T<FEN9R!/<&5R871I;F<@<WES=&5M(&YA;64-"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B!T<G5E(&EF('1H:7,@<&%C:V%G92!C86YN;W0@
M8F4@:6YS=&%L;&5D(&]N('1H:7,@3U,-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!A9&1/<T1E<"@D;F%M92P@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@)&1E<"`]
M(&%R<F%Y*"=N86UE)R`]/B`D;F%M92D[#0H@("`@("`@(&EF("@D8V]N9FQI
M8W1S*2![#0H@("`@("`@("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F\@/2`D=&AI
M<RT^7VUE<F=E5&%G*"1T:&ES+3Y?<&%C:V%G94EN9F\L("1D97`L#0H@("`@
M("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9&5P96YD96YC:65S
M)R`]/B!A<G)A>2@G<')O=FED97-E>'1E;G-I;VXG+"`G=7-E<W)O;&4G+"`G
M=7-E<W1A<VLG+`T*("`@("`@("`@("`@("`@("`@("`G<W)C<&%C:V%G92<L
M("=S<F-U<FDG+"`G<&AP<F5L96%S92<L("=E>'1S<F-R96QE87-E)RP@)V5X
M=&)I;G)E;&5A<V4G+`T*("`@("`@("`@("`@("`@("`@("`G8G5N9&QE)RP@
M)V-H86YG96QO9R<I+`T*("`@("`@("`@("`@("`@("=R97%U:7)E9"<@/3X@
M87)R87DH)V]P=&EO;F%L)RP@)V=R;W5P)RDL#0H@("`@("`@("`@("`@("`@
M)V]S)R`]/B!A<G)A>2@G87)C:"<I#0H@("`@("`@("`@("`I*3L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R:6YG($%R8VAI=&5C='5R
M92!M871C:&EN9R!P871T97)N#0H@("`@("H@0'!A<F%M(&)O;VQE86X@=')U
M92!I9B!T:&ES('!A8VMA9V4@8V%N;F]T(&)E(&EN<W1A;&QE9"!O;B!T:&ES
M(&%R8VAI=&5C='5R90T*("`@("`J+PT*("`@(&9U;F-T:6]N(&%D9$%R8VA$
M97`H)'!A='1E<FXL("1C;VYF;&EC=',@/2!F86QS92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1D97`@/2!A<G)A
M>2@G<&%T=&5R;B<@/3X@)'!A='1E<FXI.PT*("`@("`@("!I9B`H)&-O;F9L
M:6-T<RD@>PT*("`@("`@("`@("`@)&1E<%LG8V]N9FQI8W1S)UT@/2`G)SL-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H
M:7,M/E]M97)G951A9R@D=&AI<RT^7W!A8VMA9V5);F9O+"`D9&5P+`T*("`@
M("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)V1E<&5N9&5N8VEE
M<R<@/3X@87)R87DH)W!R;W9I9&5S97AT96YS:6]N)RP@)W5S97-R;VQE)RP@
M)W5S97-T87-K)RP-"B`@("`@("`@("`@("`@("`@("`@)W-R8W!A8VMA9V4G
M+"`G<W)C=7)I)RP@)W!H<')E;&5A<V4G+"`G97AT<W)C<F5L96%S92<L("=E
M>'1B:6YR96QE87-E)RP-"B`@("`@("`@("`@("`@("`@("`@)V)U;F1L92<L
M("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#T^
M(&%R<F%Y*"=O<'1I;VYA;"<L("=G<F]U<"<I+`T*("`@("`@("`@("`@("`@
M("=A<F-H)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!3970@=&AE(&MI;F0@;V8@<&%C:V%G92P@86YD
M(&5R87-E(&%L;"!R96QE87-E('1A9W,-"B`@("`@*@T*("`@("`J("T@82!P
M:'`@<&%C:V%G92!I<R!A(%!%05(M<W1Y;&4@<&%C:V%G90T*("`@("`J("T@
M86X@97AT8FEN('!A8VMA9V4@:7,@82!014-,+7-T>6QE(&5X=&5N<VEO;B!B
M:6YA<GD-"B`@("`@*B`M(&%N(&5X='-R8R!P86-K86=E(&ES(&$@4$5#3"US
M='EL92!S;W5R8V4@9F]R(&$@8FEN87)Y#0H@("`@("H@+2!A(&)U;F1L92!P
M86-K86=E(&ES(&$@8V]L;&5C=&EO;B!O9B!O=&AE<B!P<F4M<&%C:V%G960@
M<&%C:V%G97,-"B`@("`@*B!`<&%R86T@<&AP?&5X=&)I;GQE>'1S<F-\8G5N
M9&QE#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!S971086-K86=E5'EP92@D='EP92D-"B`@("![#0H@("`@
M("`@("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@("`@(&EF("@A:6Y?87)R
M87DH)'1Y<&4L(&%R<F%Y*"=P:'`G+"`G97AT8FEN)RP@)V5X='-R8R<L("=B
M=6YD;&4G*2DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'1Y<&4@(3T@)V)U;F1L92<I('L-"B`@("`@
M("`@("`@("1T>7!E("X]("=R96QE87-E)SL-"B`@("`@("`@?0T*("`@("`@
M("!F;W)E86-H("AA<G)A>2@G<&AP<F5L96%S92<L("=E>'1B:6YR96QE87-E
M)RP@)V5X='-R8W)E;&5A<V4G+"`G8G5N9&QE)RD@87,@)'1E<W0I('L-"B`@
M("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)'1E<W1=*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)'1Y<&5=*2D@>PT*("`@("`@("`@("`@+R\@96YS=7)E('1H870@
M=&AE(')E;&5A<V4@=&%G(&ES('-E="!U<`T*("`@("`@("`@("`@)'1H:7,M
M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?
M<&%C:V%G94EN9F\L(&%R<F%Y*"=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@
M("`@("!A<G)A>2@I+"`D='EP92D[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULD='EP95T@/2!A<G)A>2@I.PT*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N
M(&)O;VP@=')U92!I9B!P86-K86=E('1Y<&4@:7,@<V5T('5P#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@861D4F5L96%S92@I#0H@("`@>PT*("`@("`@("!I
M9B`H)'1Y<&4@/2`D=&AI<RT^9V5T4&%C:V%G951Y<&4H*2D@>PT*("`@("`@
M("`@("`@:68@*"1T>7!E("$]("=B=6YD;&4G*2![#0H@("`@("`@("`@("`@
M("`@)'1Y<&4@+CT@)W)E;&5A<V4G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?;65R9V5486<H
M)'1H:7,M/E]P86-K86=E26YF;RP@87)R87DH*2P-"B`@("`@("`@("`@("`@
M("!A<G)A>2@D='EP92`]/B!A<G)A>2@G8VAA;F=E;&]G)RDI*3L-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!'970@=&AE(&-U
M<G)E;G0@<F5L96%S92!T86<@:6X@;W)D97(@=&\@861D('1O(&ET#0H@("`@
M("H@0'!A<F%M(&)O;VP@<F5T=7)N<R!O;FQY(')E;&5A<V5S('1H870@:&%V
M92!I;G-T86QL8V]N9&ET:6]N(&EF('1R=64-"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y?&YU;&P-"B`@("`@*B\-"B`@("!F=6YC=&EO;B`F7V=E=$-U<G)E;G12
M96QE87-E*"1S=')I8W0@/2!T<G5E*0T*("`@('L-"B`@("`@("`@:68@*"1P
M(#T@)'1H:7,M/F=E=%!A8VMA9V54>7!E*"DI('L-"B`@("`@("`@("`@(&EF
M("@D<W1R:6-T*2![#0H@("`@("`@("`@("`@("`@:68@*"1P(#T]("=E>'1S
M<F,G*2![#0H@("`@("`@("`@("`@("`@("`@("1A(#T@;G5L;#L-"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1A.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D<"`A/2`G8G5N9&QE
M)RD@>PT*("`@("`@("`@("`@("`@("1P("X]("=R96QE87-E)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5);F9O6R1P75LP72DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]P86-K86=E26YF;ULD<%U;8V]U;G0H)'1H:7,M/E]P86-K86=E26YF
M;ULD<%TI("T@,5T[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R1P73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@
M;G5L;#L-"B`@("`@("`@("`@(')E='5R;B`D83L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@("\J*@T*("`@("`J($%D9"!A(&9I;&4@=&\@=&AE(&-U<G)E
M;G0@<F5L96%S92!T:&%T('-H;W5L9"!B92!I;G-T86QL960@=6YD97(@82!D
M:69F97)E;G0@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@/&-O;G1E;G1S
M/B!P871H('1O(&9I;&4-"B`@("`@*B!`<&%R86T@<W1R:6YG(&YA;64@=&AE
M(&9I;&4@<VAO=6QD(&)E(&EN<W1A;&QE9"!A<PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&%D9$EN<W1A;&Q!<R@D<&%T:"P@)&%S*0T*("`@('L-"B`@("`@
M("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@
M("!I9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V5486<H)'(L(&%R<F%Y*"=A='1R
M:6)S)R`]/B!A<G)A>2@G;F%M92<@/3X@)'!A=&@L("=A<R<@/3X@)&%S*2DL
M#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G9FEL96QI
M<W0G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`@("`@)VEN<W1A;&PG(#T^
M(&%R<F%Y*"=I9VYO<F4G*0T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@061D(&$@9FEL92!T;R!T:&4@8W5R<F5N="!R96QE
M87-E('1H870@<VAO=6QD(&)E(&EG;F]R960-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(#QC;VYT96YT<SX@<&%T:"!T;R!F:6QE#0H@("`@("H@0')E='5R;B!B
M;V]L('-U8V-E<W,@;V8@;W!E<F%T:6]N#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@861D26=N;W)E*"1P871H*0T*("`@('L-"B`@("`@("`@)'(@/2`F)'1H
M:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@("!I9B`H)'(@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D<B`]
M("1T:&ES+3Y?;65R9V5486<H)'(L(&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A
M>2@G;F%M92<@/3X@)'!A=&@I*2P-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("=F:6QE;&ES="<@/3X@87)R87DH*2P-"B`@("`@("`@
M("`@("`@("`G:6=N;W)E)R`]/B!A<G)A>2@I#0H@("`@("`@("`@("`I*3L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!9&0@86X@97AT96YS:6]N(&)I
M;F%R>2!P86-K86=E(&9O<B!T:&ES(&5X=&5N<VEO;B!S;W5R8V4@8V]D92!R
M96QE87-E#0H@("`@("H-"B`@("`@*B!.;W1E('1H870@=&AE('!A8VMA9V4@
M;75S="!B92!F<F]M('1H92!S86UE(&-H86YN96P@87,@=&AE(&5X=&5N<VEO
M;B!S;W5R8V4@<&%C:V%G90T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!A9&1":6YA<GEP86-K86=E*"1P86-K86=E*0T*
M("`@('L-"B`@("`@("`@:68@*"1T:&ES+3YG971086-K86=E5'EP92@I("$]
M("=E>'1S<F,G*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"B`@("`@("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S
M92AF86QS92D[#0H@("`@("`@(&EF("@D<B`]/3T@;G5L;"D@>PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3Y?:7-686QI9"`](#`[#0H@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A
M9R@D<BP@)'!A8VMA9V4L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`G8FEN87)Y<&%C:V%G92<@/3X@87)R87DH)V9I;&5L:7-T)RDL
M#0H@("`@("`@("`@("`I*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!!
M9&0@82!C;VYF:6=U<F5O<'1I;VX@=&\@86X@97AT96YS:6]N('-O=7)C92!P
M86-K86=E#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!S
M=')I;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@861D0V]N9FEG=7)E3W!T:6]N*"1N86UE+"`D<')O;7!T+"`D9&5F
M875L="`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)'1H:7,M/F=E=%!A
M8VMA9V54>7!E*"D@(3T@)V5X='-R8R<I('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D<B`]("8D=&AI<RT^7V=E
M=$-U<G)E;G1296QE87-E*&9A;'-E*3L-"B`@("`@("`@:68@*"1R(#T]/2!N
M=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@)&]P="`](&%R<F%Y*"=A='1R:6)S)R`]/B!A<G)A>2@G;F%M
M92<@/3X@)&YA;64L("=P<F]M<'0G(#T^("1P<F]M<'0I*3L-"B`@("`@("`@
M:68@*"1D969A=6QT("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D;W!T6R=D
M969A=6QT)UT@/2`D9&5F875L=#L-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`D<B`]("1T:&ES+3Y?;65R9V54
M86<H)'(L("1O<'0L#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`G8V]N9FEG=7)E;W!T:6]N)R`]/B!A<G)A>2@G8FEN87)Y<&%C:V%G
M92<L("=F:6QE;&ES="<I+`T*("`@("`@("`@("`@*2D[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@4V5T(&%N(&EN<W1A;&QA=&EO;B!C;VYD:71I;VX@
M8F%S960@;VX@<&AP('9E<G-I;VX@9F]R('1H92!C=7)R96YT(')E;&5A<V4@
M<V5T#0H@("`@("H@0'!A<F%M('-T<FEN9R!M:6YI;75M('9E<G-I;VX-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(&UA>&EM=6T@=F5R<VEO;@T*("`@("`J($!P
M87)A;2!F86QS97QA<G)A>2!I;F-O;7!A=&EB;&4@=F5R<VEO;G,@;V8@4$A0
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T4&AP26YS=&%L;$-O;F1I=&EO
M;B@D;6EN+"`D;6%X+"`D97AC;'5D92`](&9A;'-E*0T*("`@('L-"B`@("`@
M("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*("`@("`@
M("!I9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*
M("`@("`@("!I9B`H:7-S970H)');)VEN<W1A;&QC;VYD:71I;VYS)UU;)W!H
M<"==*2D@>PT*("`@("`@("`@("`@=6YS970H)');)VEN<W1A;&QC;VYD:71I
M;VYS)UU;)W!H<"==*3L-"B`@("`@("`@?0T*("`@("`@("`D9&5P(#T@87)R
M87DH)VUI;B<@/3X@)&UI;BP@)VUA>"<@/3X@)&UA>"D[#0H@("`@("`@(&EF
M("@D97AC;'5D92D@>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E>&-L
M=61E*2`F)B!C;W5N="@D97AC;'5D92D@/3T@,2D@>PT*("`@("`@("`@("`@
M("`@("1E>&-L=61E(#T@)&5X8VQU9&5;,%T[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@
M)V5X='-R8R<I('L-"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A
M9R@D<BP@)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G8V]N
M9FEG=7)E;W!T:6]N)RP@)V)I;F%R>7!A8VMA9V4G+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@
M("=P:'`G(#T^(&%R<F%Y*"=E>'1E;G-I;VXG+"`G;W,G+"`G87)C:"<I#0H@
M("`@("`@("`@("`@("`@*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D<B`]("1T:&ES+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@
M("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL
M8V]N9&ET:6]N<R<@/3X@87)R87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@
M("`@("`@("`@("=P:'`G(#T^(&%R<F%Y*"=E>'1E;G-I;VXG+"`G;W,G+"`G
M87)C:"<I#0H@("`@("`@("`@("`@("`@*2D[#0H@("`@("`@('T-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@;W!T:6]N86Q\<F5Q=6ER960@
M;W!T:6]N86PL(')E<75I<F5D#0H@("`@("H@0'!A<F%M('-T<FEN9R!E>'1E
M;G-I;VX@;F%M90T*("`@("`J($!P87)A;2!S=')I;F<@;6EN:6UU;2!V97)S
M:6]N#0H@("`@("H@0'!A<F%M('-T<FEN9R!M87AI;75M('9E<G-I;VX-"B`@
M("`@*B!`<&%R86T@<W1R:6YG(')E8V]M;65N9&5D('9E<G-I;VX-"B`@("`@
M*B!`<&%R86T@87)R87D@:6YC;VUP871I8FQE('9E<G-I;VYS#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@861D17AT96YS:6]N26YS=&%L;$-O;F1I=&EO;B@D
M;F%M92P@)&UI;B`](&9A;'-E+"`D;6%X(#T@9F%L<V4L("1R96-O;6UE;F1E
M9"`](&9A;'-E+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5X8VQU9&4@/2!F86QS92D-"B`@("![#0H@("`@("`@("1R
M(#T@)B1T:&ES+3Y?9V5T0W5R<F5N=%)E;&5A<V4H*3L-"B`@("`@("`@:68@
M*"1R(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@
M("`@)&1E<"`]("1T:&ES+3Y?8V]N<W1R=6-T1&5P*"1N86UE+"!F86QS92P@
M9F%L<V4L("1M:6XL("1M87@L("1R96-O;6UE;F1E9"P@)&5X8VQU9&4I.PT*
M("`@("`@("!I9B`H)'1H:7,M/F=E=%!A8VMA9V54>7!E*"D@/3T@)V5X='-R
M8R<I('L-"B`@("`@("`@("`@("1R(#T@)'1H:7,M/E]M97)G951A9R@D<BP@
M)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]/B!A<G)A>2@G8V]N9FEG=7)E
M;W!T:6]N)RP@)V)I;F%R>7!A8VMA9V4G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=E>'1E
M;G-I;VXG(#T^(&%R<F%Y*"=O<R<L("=A<F-H)RD-"B`@("`@("`@("`@("`@
M("`I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R(#T@)'1H
M:7,M/E]M97)G951A9R@D<BP@)&1E<"P-"B`@("`@("`@("`@("`@("!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)VEN<W1A;&QC;VYD:71I;VYS)R`]
M/B!A<G)A>2@G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@("`@("`@)V5X
M=&5N<VEO;B<@/3X@87)R87DH)V]S)RP@)V%R8V@G*0T*("`@("`@("`@("`@
M("`@("DI.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@
M4V5T(&%N(&EN<W1A;&QA=&EO;B!C;VYD:71I;VX@8F%S960@;VX@;W!E<F%T
M:6YG('-Y<W1E;2!F;W(@=&AE(&-U<G)E;G0@<F5L96%S92!S970-"B`@("`@
M*B!`<&%R86T@<W1R:6YG($]3(&YA;64-"B`@("`@*B!`<&%R86T@8F]O;"!W
M:&5T:&5R('1H:7,@3U,@:7,@:6YC;VUP871I8FQE('=I=&@@=&AE(&-U<G)E
M;G0@<F5L96%S90T*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=$]S26YS=&%L
M;$-O;F1I=&EO;B@D;F%M92P@)&-O;F9L:6-T<R`](&9A;'-E*0T*("`@('L-
M"B`@("`@("`@)'(@/2`F)'1H:7,M/E]G971#=7)R96YT4F5L96%S92@I.PT*
M("`@("`@("!I9B`H)'(@/3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7VES5F%L:60@
M/2`P.PT*("`@("`@("!I9B`H:7-S970H)');)VEN<W1A;&QC;VYD:71I;VYS
M)UU;)V]S)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L;&-O
M;F1I=&EO;G,G75LG;W,G72D[#0H@("`@("`@('T-"B`@("`@("`@)&1E<"`]
M(&%R<F%Y*"=N86UE)R`]/B`D;F%M92D[#0H@("`@("`@(&EF("@D8V]N9FQI
M8W1S*2![#0H@("`@("`@("`@("`D9&5P6R=C;VYF;&EC=',G72`]("<G.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^9V5T4&%C:V%G951Y<&4H
M*2`]/2`G97AT<W)C)RD@>PT*("`@("`@("`@("`@)'(@/2`D=&AI<RT^7VUE
M<F=E5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO;G,G(#T^(&%R<F%Y
M*"=C;VYF:6=U<F5O<'1I;VXG+"`G8FEN87)Y<&%C:V%G92<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G9FEL96QI<W0G*2P-"B`@("`@("`@("`@("`@
M("`@("`@)V]S)R`]/B!A<G)A>2@G87)C:"<I#0H@("`@("`@("`@("`@("`@
M*2D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]("1T:&ES
M+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N<R<@/3X@
M87)R87DH)V9I;&5L:7-T)RDL#0H@("`@("`@("`@("`@("`@("`@("=O<R<@
M/3X@87)R87DH)V%R8V@G*0T*("`@("`@("`@("`@("`@("DI.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4V5T(&%N(&EN<W1A;&QA
M=&EO;B!C;VYD:71I;VX@8F%S960@;VX@87)C:&ET96-T=7)E(&9O<B!T:&4@
M8W5R<F5N="!R96QE87-E('-E=`T*("`@("`J($!P87)A;2!S=')I;F<@87)C
M:&ET96-T=7)E('!A='1E<FX-"B`@("`@*B!`<&%R86T@8F]O;"!W:&5T:&5R
M('1H:7,@87)C:"!I<R!I;F-O;7!A=&EB;&4@=VET:"!T:&4@8W5R<F5N="!R
M96QE87-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<V5T07)C:$EN<W1A;&Q#
M;VYD:71I;VXH)'!A='1E<FXL("1C;VYF;&EC=',@/2!F86QS92D-"B`@("![
M#0H@("`@("`@("1R(#T@)B1T:&ES+3Y?9V5T0W5R<F5N=%)E;&5A<V4H*3L-
M"B`@("`@("`@:68@*"1R(#T]/2!N=6QL*2![#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@,#L-"B`@("`@("`@:68@*&ES<V5T*"1R6R=I;G-T86QL8V]N9&ET:6]N
M<R==6R=A<F-H)UTI*2![#0H@("`@("`@("`@("!U;G-E="@D<ELG:6YS=&%L
M;&-O;F1I=&EO;G,G75LG87)C:"==*3L-"B`@("`@("`@?0T*("`@("`@("`D
M9&5P(#T@87)R87DH)W!A='1E<FXG(#T^("1P871T97)N*3L-"B`@("`@("`@
M:68@*"1C;VYF;&EC=',I('L-"B`@("`@("`@("`@("1D97!;)V-O;F9L:6-T
M<R==(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YG9710
M86-K86=E5'EP92@I(#T]("=E>'1S<F,G*2![#0H@("`@("`@("`@("`D<B`]
M("1T:&ES+3Y?;65R9V5486<H)'(L("1D97`L#0H@("`@("`@("`@("`@("`@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=I;G-T86QL8V]N9&ET:6]N
M<R<@/3X@87)R87DH)V-O;F9I9W5R96]P=&EO;B<L("=B:6YA<GEP86-K86=E
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("=F:6QE;&ES="<I+`T*("`@
M("`@("`@("`@("`@("`@("`G87)C:"<@/3X@87)R87DH*0T*("`@("`@("`@
M("`@("`@("DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'(@
M/2`D=&AI<RT^7VUE<F=E5&%G*"1R+"`D9&5P+`T*("`@("`@("`@("`@("`@
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G:6YS=&%L;&-O;F1I=&EO
M;G,G(#T^(&%R<F%Y*"=F:6QE;&ES="<I+`T*("`@("`@("`@("`@("`@("`@
M("`G87)C:"<@/3X@87)R87DH*0T*("`@("`@("`@("`@("`@("DI.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R(&5X=&5N<VEO
M;B!B:6YA<GD@<F5L96%S97,L('1H:7,@:7,@=7-E9"!T;R!S<&5C:69Y(&5I
M=&AE<B!T:&4-"B`@("`@*B!S=&%T:6,@55))('1O(&$@<V]U<F-E('!A8VMA
M9V4L(&]R('1H92!P86-K86=E(&YA;64@86YD(&-H86YN96P@;V8@=&AE(&5X
M='-R8PT*("`@("`J('!A8VMA9V4@:70@:7,@8F%S960@;VXN#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!086-K86=E(&YA;64L(&]R(&9U;&P@55))('1O('-O
M=7)C92!P86-K86=E("AE>'1S<F,@='EP92D-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S9713;W5R8V5086-K86=E*"1P86-K86=E3W)5<FDI#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;FYE;"==*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES+3Y?:6YS97)T0F5F
M;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L(&%R<F%Y*"=P:'!R96QE87-E)RP-
M"B`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L("=E>'1B:6YR96QE
M87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P-"B`@("`@("`@("`@("`@
M("`D<&%C:V%G94]R57)I+"`G<W)C<&%C:V%G92<I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`]("1T:&ES
M+3Y?:6YS97)T0F5F;W)E*"1T:&ES+3Y?<&%C:V%G94EN9F\L(&%R<F%Y*"=P
M:'!R96QE87-E)RP-"B`@("`@("`@("`@("`@("`G97AT<W)C<F5L96%S92<L
M("=E>'1B:6YR96QE87-E)RP@)V)U;F1L92<L("=C:&%N9V5L;V<G*2P@)'!A
M8VMA9V5/<E5R:2P@)W-R8W5R:2<I.PT*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5N97)A=&4@82!V86QI9"!C:&%N9V4@;&]G(&5N
M=')Y(&9R;VT@=&AE(&-U<G)E;G0@<&%C:V%G92YX;6P-"B`@("`@*B!`<&%R
M86T@<W1R:6YG?&9A;'-E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9V5N97)A
M=&5#:&%N9V5,;V=%;G1R>2@D;F]T97,@/2!F86QS92D-"B`@("![#0H@("`@
M("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@("`@("=V97)S:6]N)R`]/B`-
M"B`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W)E;&5A<V4G(#T^("1T:&ES+3YG971697)S:6]N*"=R96QE87-E)RDL#0H@
M("`@("`@("`@("`@("`@("`@("=A<&DG(#T^("1T:&ES+3YG971697)S:6]N
M*"=A<&DG*2P-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("=S=&%B:6QI='DG(#T^#0H@("`@("`@("`@("`@("`@)'1H:7,M/F=E=%-T
M86)I;&ET>2@I+`T*("`@("`@("`@("`@)V1A=&4G(#T^("1T:&ES+3YG971$
M871E*"DL#0H@("`@("`@("`@("`G;&EC96YS92<@/3X@)'1H:7,M/F=E=$QI
M8V5N<V4H=')U92DL#0H@("`@("`@("`@("`G;F]T97,G(#T^("1N;W1E<R`_
M("1N;W1E<R`Z("1T:&ES+3YG971.;W1E<R@I#0H@("`@("`@("`@("`I.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I;F<@<F5L96%S
M92!V97)S:6]N('1O('-E="!C:&%N9V4@;&]G(&YO=&5S(&9O<@T*("`@("`J
M($!P87)A;2!A<G)A>2!O=71P=70@;V8@>T!L:6YK(&=E;F5R871E0VAA;F=E
M3&]G16YT<GDH*7T-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S971#:&%N9V5L
M;V=%;G1R>2@D<F5L96%S979E<G-I;VXL("1C;VYT96YT<RD-"B`@("![#0H@
M("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E
M;&]G)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M:&%N9V5L;V<G75LG<F5L96%S92==(#T@)&-O;G1E;G1S.PT*("`@("`@("`@
M("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H
M:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UU;)W)E;&5A<V4G75LP72DI
M('L-"B`@("`@("`@("`@(&EF("@D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N
M9V5L;V<G75LG<F5L96%S92==6R=V97)S:6]N)UU;)W)E;&5A<V4G72`]/2`D
M<F5L96%S979E<G-I;VXI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG
M96QO9R==6R=R96QE87-E)UTI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G
M75LG<F5L96%S92==(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UTI.PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M:&%N9V5L;V<G75LG<F5L96%S92==6UT@/2`D8V]N=&5N=',[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==(&%S("1I;F1E>"`]
M/B`D8VAA;F=E;&]G*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&-H86YG
M96QO9ULG=F5R<VEO;B==*2`F)@T*("`@("`@("`@("`@("`@("`@<W1R;F%T
M8V%S96-M<"@D8VAA;F=E;&]G6R=V97)S:6]N)UU;)W)E;&5A<V4G72P@)')E
M;&5A<V5V97)S:6]N*2`]/2`P*2![#0H@("`@("`@("`@("`@("`@)&-U<FQO
M9R`]("1I;F1E>#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&-U<FQO9RDI('L-"B`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)V-H86YG96QO9R==6R=R96QE87-E)UU;)&-U<FQO9UT@
M/2`D8V]N=&5N=',[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L;V<G75LG<F5L96%S92==6UT@
M/2`D8V]N=&5N=',[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!296UO=F4@=&AE(&-H86YG96QO9R!E;G1I<F5L>0T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&-L96%R0VAA;F=E3&]G*"D-"B`@("![#0H@("`@("`@
M('5N<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==*3L-"B`@
M("!]#0I]#0H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+U!%05(O4&%C:V%G949I;&4O=C(O5F%L:61A=&]R+G!H
M<```````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`R,S8U-C<@,3`U,34T,S0Q,S0@,#(T
M,S4T`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP#0HO+PT*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO
M+R!\(%!(4"!697)S:6]N(#4@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P
M-"!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS92P@("`@("`@?`T*+R\@?"!T:&%T(&ES(&)U;F1L960@
M=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES
M("`@("`@("!\#0HO+R!\(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG('5R;#H@("`@("`@("`@('P-"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@?"!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R
M92!U;F%B;&4@=&\@("!\#0HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@
M('P-"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\($%U=&AO<CH@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED.B!686QI
M9&%T;W(N<&AP+'8@,2XX-B`R,#`V+S`S+S`R(#$X.C$T.C$S(&-E;&QO9R!%
M>'`@)`T*+RHJ#0H@*B!0<FEV871E('9A;&ED871I;VX@8VQA<W,@=7-E9"!B
M>2!014%27U!A8VMA9V5&:6QE7W8R("T@9&\@;F]T('5S92!D:7)E8W1L>2P@
M:71S#0H@*B!S;VQE('!U<G!O<V4@:7,@=&\@<W!L:70@=7`@=&AE(%!%05(O
M4&%C:V%G949I;&4O=C(N<&AP(&9I;&4@=&\@;6%K92!I="!S;6%L;&5R#0H@
M*B!`875T:&]R($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!A
M8V-E<W,@<')I=F%T90T*("HO#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7W8R
M7U9A;&ED871O<@T*>PT*("`@("\J*@T*("`@("`J($!V87(@87)R87D-"B`@
M("`@*B\-"B`@("!V87(@)%]P86-K86=E26YF;SL-"B`@("`O*BH-"B`@("`@
M*B!`=F%R(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!V87(@
M)%]P9CL-"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?17)R;W)3=&%C:PT*
M("`@("`J+PT*("`@('9A<B`D7W-T86-K.PT*("`@("\J*@T*("`@("`J($!V
M87(@:6YT#0H@("`@("HO#0H@("`@=F%R("1?:7-686QI9"`](#`[#0H@("`@
M+RHJ#0H@("`@("H@0'9A<B!I;G0-"B`@("`@*B\-"B`@("!V87(@)%]F:6QE
M<U9A;&ED(#T@,#L-"B`@("`O*BH-"B`@("`@*B!`=F%R(&EN=`T*("`@("`J
M+PT*("`@('9A<B`D7V-U<E-T871E(#T@,#L-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!I;G0-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T92@F)'!F+"`D<W1A=&4@
M/2!014%27U9!3$E$051%7TY/4DU!3"D-"B`@("![#0H@("`@("`@("1T:&ES
M+3Y?<&8@/2`F)'!F.PT*("`@("`@("`D=&AI<RT^7V-U<E-T871E(#T@)'-T
M871E.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O(#T@)'1H:7,M/E]P
M9BT^9V5T07)R87DH*3L-"B`@("`@("`@)'1H:7,M/E]I<U9A;&ED(#T@)'1H
M:7,M/E]P9BT^7VES5F%L:60[#0H@("`@("`@("1T:&ES+3Y?9FEL97-686QI
M9"`]("1T:&ES+3Y?<&8M/E]F:6QE<U9A;&ED.PT*("`@("`@("`D=&AI<RT^
M7W-T86-K(#T@)B1P9BT^7W-T86-K.PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YG971%<G)O<G,H=')U92D[#0H@("`@("`@(&EF("@H)'1H:7,M/E]I<U9A
M;&ED("8@)'-T871E*2`]/2`D<W1A=&4I('L-"B`@("`@("`@("`@(')E='5R
M;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/E]P86-K86=E26YF;RD@?'P@(6ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN
M9F\I*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=A='1R
M:6)S)UU;)W9E<G-I;VXG72D@?'P-"B`@("`@("`@("`@("`@)'1H:7,M/E]P
M86-K86=E26YF;ULG871T<FEB<R==6R=V97)S:6]N)UT@(3T@)S(N,"<I('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?;F]086-K86=E5F5R<VEO;B@I.PT*("`@
M("`@("!]#0H@("`@("`@("1S=')U8W1U<F4@/0T*("`@("`@("!A<G)A>2@-
M"B`@("`@("`@("`@("=N86UE)RP-"B`@("`@("`@("`@("=C:&%N;F5L?'5R
M:2<L#0H@("`@("`@("`@("`G*F5X=&5N9',G+"`O+R!C86XG="!B92!M=6QT
M:7!L92P@8G5T('1H:7,@=V]R:W,@9FEN90T*("`@("`@("`@("`@)W-U;6UA
M<GDG+`T*("`@("`@("`@("`@)V1E<V-R:7!T:6]N)RP-"B`@("`@("`@("`@
M("<K;&5A9"<L("\O('1H97-E(&%L;"!N965D(&-O;G1E;G0@8VAE8VMS#0H@
M("`@("`@("`@("`G*F1E=F5L;W!E<B<L#0H@("`@("`@("`@("`G*F-O;G1R
M:6)U=&]R)RP-"B`@("`@("`@("`@("<J:&5L<&5R)RP-"B`@("`@("`@("`@
M("=D871E)RP-"B`@("`@("`@("`@("<J=&EM92<L#0H@("`@("`@("`@("`G
M=F5R<VEO;B<L#0H@("`@("`@("`@("`G<W1A8FEL:71Y)RP-"B`@("`@("`@
M("`@("=L:6-E;G-E+3X_=7)I+3X_9FEL97-O=7)C92<L#0H@("`@("`@("`@
M("`G;F]T97,G+`T*("`@("`@("`@("`@)V-O;G1E;G1S)RP@+R]S<&5C:6%L
M('9A;&ED871I;VX@;F5E9&5D#0H@("`@("`@("`@("`G*F-O;7!A=&EB;&4G
M+`T*("`@("`@("`@("`@)V1E<&5N9&5N8VEE<R<L("\O<W!E8VEA;"!V86QI
M9&%T:6]N(&YE961E9`T*("`@("`@("`@("`@)RIU<V5S<F]L92<L#0H@("`@
M("`@("`@("`G*G5S97-T87-K)RP@+R\@<F5S97)V92!T:&5S92!F;W(@,2XT
M+C!A,2!T;R!I;7!L96UE;G0-"B`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!T:&ES('=I;&P@86QL;W<@82!P86-K86=E+GAM;"!T;R!G<F%C969U;&QY
M('-A>2!I=`T*("`@("`@("`@("`@("`@("`@("`@("`@("\O(&YE961S(&$@
M8V5R=&%I;B!P86-K86=E(&EN<W1A;&QE9"!I;B!O<F1E<B!T;R!I;7!L96UE
M;G0@82!R;VQE(&]R('1A<VL-"B`@("`@("`@("`@("<J<')O=FED97-E>'1E
M;G-I;VXG+`T*("`@("`@("`@("`@)RIS<F-P86-K86=E?"IS<F-U<FDG+`T*
M("`@("`@("`@("`@)RMP:'!R96QE87-E?"ME>'1S<F-R96QE87-E?"ME>'1B
M:6YR96QE87-E?&)U;F1L92<L("\O<W!E8VEA;"!V86QI9&%T:6]N(&YE961E
M9`T*("`@("`@("`@("`@)RIC:&%N9V5L;V<G+`T*("`@("`@("`I.PT*("`@
M("`@("`D=&5S="`]("1T:&ES+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("\O
M(&EG;F]R92!P;W-T+6EN<W1A;&QA=&EO;B!A<G)A>2!F:65L9',-"B`@("`@
M("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V9I;&5L:7-T)RP@)'1E<W0I*2![
M#0H@("`@("`@("`@("!U;G-E="@D=&5S=%LG9FEL96QI<W0G72D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)U]L87-T;6]D
M:69I960G+"`D=&5S="DI('L-"B`@("`@("`@("`@('5N<V5T*"1T97-T6R=?
M;&%S=&UO9&EF:65D)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AA<G)A
M>5]K97E?97AI<W1S*"<C8FEN87)Y<&%C:V%G92<L("1T97-T*2D@>PT*("`@
M("`@("`@("`@=6YS970H)'1E<W1;)R-B:6YA<GEP86-K86=E)UTI.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=O;&0G+"`D
M=&5S="DI('L-"B`@("`@("`@("`@('5N<V5T*"1T97-T6R=O;&0G72D[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)U]L87-T
M=F5R<VEO;B<L("1T97-T*2D@>PT*("`@("`@("`@("`@=6YS970H)'1E<W1;
M)U]L87-T=F5R<VEO;B==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T
M:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R92P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T97-T+"`G
M/'!A8VMA9V4^)RDI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H:7,M/E]P86-K86=E26YF
M;ULG;F%M92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN;W1"
M945M<'1Y*"=N86UE)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?<&%C:V%G94EN9F];)W5R:2==*2D@>PT*("`@("`@("`@("`@
M)'1E<W0@/2`G=7)I)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1T97-T(#T@)V-H86YN96PG.PT*("`@("`@("!]#0H@("`@("`@(&EF("AE
M;7!T>2@D=&AI<RT^7W!A8VMA9V5);F9O6R1T97-T72DI('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@D=&5S="D[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];
M)VQI8V5N<V4G72D@)B8-"B`@("`@("`@("`@("`@*"%I<W-E="@D=&AI<RT^
M7W!A8VMA9V5);F9O6R=L:6-E;G-E)UU;)U]C;VYT96YT)UTI('Q\#0H@("`@
M("`@("`@("`@(&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G
M75LG7V-O;G1E;G0G72DI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A
M;FYO=$)E16UP='DH)VQI8V5N<V4G*3L-"B`@("`@("`@?2!E;'-E:68@*&5M
M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VQI8V5N<V4G72DI('L-"B`@("`@
M("`@("`@("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@G;&EC96YS92<I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=S=6UM87)Y)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A
M;FYO=$)E16UP='DH)W-U;6UA<GDG*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H96UP='DH)'1H:7,M/E]P86-K86=E26YF;ULG9&5S8W)I<'1I;VXG72DI
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?=&%G0V%N;F]T0F5%;7!T>2@G9&5S
M8W)I<'1I;VXG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]P86-K86=E26YF;ULG9&%T92==*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]T86=#86YN;W1"945M<'1Y*"=D871E)RD[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VYO=&5S)UTI
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7W1A9T-A;FYO=$)E16UP='DH)VYO
M=&5S)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G94EN9F];)W1I;64G72D@)B8@96UP='DH)'1H:7,M/E]P86-K86=E
M26YF;ULG=&EM92==*2D@>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=#86YN
M;W1"945M<'1Y*"=T:6UE)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T941E<&5N9&5N8VEE<R@I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C;VUP871I8FQE)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED871E0V]M<&%T:6)L92@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E
M;G1S)UU;)V1I<B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL
M96QI<W1-=7-T0V]N=&%I;D1I<B@G8V]N=&5N=',G*3L-"B`@("`@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8V]N=&5N=',G75LG
M9FEL92==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL96QI<W1#
M86YN;W1#;VYT86EN1FEL92@G8V]N=&5N=',G*3L-"B`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]V86QI9&%T94UA:6YT86EN97)S*"D[#0H@("`@("`@
M("1T:&ES+3Y?=F%L:61A=&53=&%B:6QI='E697)S:6]N*"D[#0H@("`@("`@
M("1F86EL(#T@9F%L<V4[#0H@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"=U<V5S<F]L92<L("1T:&ES+3Y?<&%C:V%G94EN9F\I*2![#0H@("`@("`@
M("`@("`D<F]L97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=U<V5S<F]L92==
M.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F]L97,I('Q\("%I<W-E
M="@D<F]L97-;,%TI*2![#0H@("`@("`@("`@("`@("`@)')O;&5S(#T@87)R
M87DH)')O;&5S*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1R;VQE<R!A<R`D<F]L92D@>PT*("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)')O;&5;)W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]U<V5S<F]L971A<VM-=7-T2&%V95)O;&5487-K*"=U<V5S<F]L
M92<L("=R;VQE)RD[#0H@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U
M93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1R;VQE6R=C:&%N;F5L)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R;VQE6R=U<FDG72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE
M=&%S:TUU<W1(879E0VAA;FYE;$]R57)I*"1R;VQE6R=R;VQE)UTL("=U<V5S
M<F]L92<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D<F]L95LG<&%C:V%G92==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]U<V5S<F]L971A
M<VM-=7-T2&%V95!A8VMA9V4H)')O;&5;)W)O;&4G72P@)W5S97-R;VQE)RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D9F%I;"`]('1R=64[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)W5S97-T87-K)RP@)'1H:7,M/E]P86-K86=E26YF;RDI('L-"B`@("`@
M("`@("`@("1R;VQE<R`]("1T:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K
M)UT[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1R;VQE<RD@?'P@(6ES
M<V5T*"1R;VQE<ULP72DI('L-"B`@("`@("`@("`@("`@("`D<F]L97,@/2!A
M<G)A>2@D<F]L97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R
M96%C:"`H)')O;&5S(&%S("1R;VQE*2![#0H@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F]L95LG=&%S:R==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W5S97-R;VQE=&%S:TUU<W1(879E4F]L951A<VLH)W5S97-T
M87-K)RP@)W1A<VLG*3L-"B`@("`@("`@("`@("`@("`@("`@)&9A:6P@/2!T
M<G5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)')O;&5;)V-H86YN96PG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')O;&5;)W5R:2==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=7-E<W)O
M;&5T87-K375S=$AA=F5#:&%N;F5L3W)5<FDH)')O;&5;)W1A<VLG72P@)W5S
M97-T87-K)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9A:6P@
M/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H(6ES<V5T*"1R;VQE6R=P86-K86=E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5S97-R;VQE
M=&%S:TUU<W1(879E4&%C:V%G92@D<F]L95LG=&%S:R==+"`G=7-E<W1A<VLG
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F86EL(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&9A:6PI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7W9A;&ED871E1FEL96QI<W0H*3L-"B`@("`@("`@)'1H:7,M/E]V
M86QI9&%T95)E;&5A<V4H*3L-"B`@("`@("`@:68@*"$D=&AI<RT^7W-T86-K
M+3YH87-%<G)O<G,H*2D@>PT*("`@("`@("`@("`@)&-H86X@/2`D=&AI<RT^
M7W!F+3Y?<F5G:7-T<GDM/F=E=$-H86YN96PH)'1H:7,M/E]P9BT^9V5T0VAA
M;FYE;"@I+"!T<G5E*3L-"B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1C:&%N*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=6YK;F]W;D-H
M86YN96PH)'1H:7,M/E]P9BT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)'9A;'!A8VL@/2`D8VAA;BT^
M9V5T5F%L:61A=&EO;E!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`O+R!F
M;W(@8VAA;FYE;"!V86QI9&%T;W(@<&%C:V%G97,L(&%L=V%Y<R!U<V4@=&AE
M(&1E9F%U;'0@4$5!4B!V86QI9&%T;W(N#0H@("`@("`@("`@("`@("`@+R\@
M;W1H97)W:7-E+"!T:&5Y(&-A;B=T(&)E(&EN<W1A;&QE9"!O<B!P86-K86=E
M9`T*("`@("`@("`@("`@("`@("1V86QI9&%T;W(@/2`D8VAA;BT^9V5T5F%L
M:61A=&EO;D]B:F5C="@D=&AI<RT^7W!F+3YG971086-K86=E*"DI.PT*("`@
M("`@("`@("`@("`@(&EF("@A)'9A;&ED871O<BD@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]
M/B`D8VAA;BT^9V5T3F%M92@I+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P86-K86=E)R`]/B`D=&AI<RT^7W!F+3YG971086-K86=E
M*"DI+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'!A8VL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@)W!A8VMA9V4@(B5C:&%N;F5L)2\E<&%C:V%G924B(&-A
M;FYO="!B92!P<F]P97)L>2!V86QI9&%T960@=VET:&]U="`G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=V86QI9&%T:6]N('!A8VMA9V4@(B5C:&%N
M;F5L)2\E;F%M924M)79E<G-I;VXE(B<I.PT*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]I<U9A;&ED(#T@,#L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)'9A;&ED871O<BT^<V5T4&%C:V%G949I
M;&4H)'1H:7,M/E]P9BD[#0H@("`@("`@("`@("`@("`@)'9A;&ED871O<BT^
M=F%L:61A=&4H)'-T871E*3L-"B`@("`@("`@("`@("`@("`D9F%I;'5R97,@
M/2`D=F%L:61A=&]R+3YG971&86EL=7)E<R@I.PT*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1F86EL=7)E<ULG97)R;W)S)UT@87,@)&5R<F]R*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"`D97)R;W(L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`G0VAA;FYE;"!V86QI9&%T;W(@97)R;W(Z(&9I96QD("(E9FEE;&0E
M(B`M("5R96%S;VXE)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1F86EL=7)E<ULG=V%R;FEN9W,G72!A<R`D=V%R
M;FEN9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP
M=7-H*%]?1E5.0U1)3TY?7RP@)W=A<FYI;F<G+"`D=V%R;FEN9RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=#:&%N;F5L('9A;&ED871O<B!W87)N:6YG
M.B!F:65L9"`B)69I96QD)2(@+2`E<F5A<V]N)2<I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI
M<RT^7W!F+3Y?:7-686QI9"`]("1T:&ES+3Y?:7-686QI9"`]("$D=&AI<RT^
M7W-T86-K+3YH87-%<G)O<G,H)V5R<F]R)RD[#0H@("`@("`@(&EF("@D=&AI
M<RT^7VES5F%L:60@)B8@)'-T871E(#T](%!%05)?5D%,241!5$5?4$%#2T%'
M24Y'("8F("$D=&AI<RT^7V9I;&5S5F%L:60I('L-"B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7W!F+3YG971086-K86=E5'EP92@I(#T]("=B=6YD;&4G*2![
M#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?86YA;'EZ94)U;F1L9610
M86-K86=E<R@I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL
M97-686QI9"`]("1T:&ES+3Y?<&8M/E]F:6QE<U9A;&ED(#T@=')U93L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!F+3Y?:7-686QI9"`]("1T:&ES+3Y?:7-686QI9"`](#`[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("!I9B`H(21T:&ES+3Y?86YA;'EZ95!H<$9I;&5S*"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P9BT^7VES5F%L:60@/2`D
M=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL97-686QI9"`]("1T
M:&ES+3Y?<&8M/E]F:6QE<U9A;&ED(#T@=')U93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"1T
M:&ES+3Y?:7-686QI9"D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<&8M/E]I<U9A;&ED(#T@)'1H:7,M/E]I<U9A;&ED(#T@)'-T871E.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!F+3Y?:7-686QI9"`]
M("1T:&ES+3Y?:7-686QI9"`](#`[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1X;6PL("1R;V]T
M*0T*("`@('L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D>&UL*2D@>PT*("`@
M("`@("`@("`@)'AM;"`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@
M)&ME>7,@/2!A<G)A>5]K97ES*"1X;6PI.PT*("`@("`@("!R97-E="@D:V5Y
M<RD[#0H@("`@("`@("1K97D@/2!C=7)R96YT*"1K97ES*3L-"B`@("`@("`@
M=VAI;&4@*"1K97D@/3T@)V%T=')I8G,G('Q\("1K97D@/3T@)U]C;VYT96YT
M<R<I('L-"B`@("`@("`@("`@("1K97D@/2!N97AT*"1K97ES*3L-"B`@("`@
M("`@?0T*("`@("`@("`D=6YF;W5N9'1A9W,@/2`D;W!T:6]N86QT86=S(#T@
M87)R87DH*3L-"B`@("`@("`@)')E="`]('1R=64[#0H@("`@("`@("1M:7-M
M871C:"`](&9A;'-E.PT*("`@("`@("!F;W)E86-H("@D<W1R=6-T=7)E(&%S
M("1S=')U8RD@>PT*("`@("`@("`@("`@:68@*"1K97DI('L-"B`@("`@("`@
M("`@("`@("`D=&%G(#T@)'AM;%LD:V5Y73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1T97-T(#T@)'1H:7,M/E]P<F]C97-S4W1R=6-T=7)E*"1S
M=')U8RD[#0H@("`@("`@("`@("!I9B`H:7-S970H)'1E<W1;)V-H;VEC97,G
M72DI('L-"B`@("`@("`@("`@("`@("`D;&]O<V4@/2!T<G5E.PT*("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1T97-T6R=C:&]I8V5S)UT@87,@)&-H;VEC
M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&ME>2`]/2`D8VAO:6-E
M6R=T86<G72D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&ME>2`](&YE
M>'0H)&ME>7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@=VAI;&4@*"1K
M97D@/3T@)V%T=')I8G,G('Q\("1K97D@/3T@)U]C;VYT96YT<R<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@;F5X="@D:V5Y<RD[
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=6YF;W5N9'1A9W,@/2`D;W!T:6]N86QT86=S(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1M:7-M871C:"`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1K97D@)B8@)&ME>2`A
M/2`D8VAO:6-E6R=T86<G72`F)B!I<W-E="@D8VAO:6-E6R=M=6QT:7!L92==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U;F9O=6YD=&%G
M<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P=&EO;F%L=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1K97DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("8]("1T
M:&ES+3Y?<')O8V5S<T%T=')I8G,H)&-H;VEC92P@)'1A9RP@)')O;W0I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1U;F9O=6YD=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D;6ES;6%T8V@@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&-H
M;VEC95LG;75L=&EP;&4G72D@?'P@)&-H;VEC95LG;75L=&EP;&4G72`A/2`G
M*B<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1L;V]S92`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]P=&EO;F%L=&%G<UM=(#T@)&-H;VEC95LG=&%G)UT[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"$D;&]O<V4I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]I;G9A;&ED5&%G3W)D97(H)'5N9F]U;F1T86=S+"`D
M:V5Y+"`D<F]O="D[#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@(&EF("@D:V5Y("$]("1T97-T6R=T86<G72D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1E<W1;)VUU;'1I<&QE
M)UTI("8F("1T97-T6R=M=6QT:7!L92==("$]("<J)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'5N9F]U;F1T86=S6UT@/2`D=&5S=%LG=&%G)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/
M<F1E<B@D=6YF;W5N9'1A9W,L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:V5Y
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&UI<VUA=&-H(#T@
M=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1U;F9O=6YD=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;F%L=&%G<UM=(#T@)'1E
M<W1;)W1A9R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)'1E<W1;)VUU;'1I<&QE)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E
M<B@D=6YF;W5N9'1A9W,L("1K97DL("1R;V]T*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=6YF;W5N9'1A
M9W,@/2`D;W!T:6]N86QT86=S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@
M("`@("`@)&UI<VUA=&-H(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1K97D@/2!N97AT*"1K97ES*3L-"B`@("`@("`@
M("`@("`@("!W:&EL92`H)&ME>2`]/2`G871T<FEB<R<@?'P@)&ME>2`]/2`G
M7V-O;G1E;G1S)RD@>PT*("`@("`@("`@("`@("`@("`@("`D:V5Y(#T@;F5X
M="@D:V5Y<RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D:V5Y("8F("1K97D@(3T@)'1E<W1;)W1A9R==("8F(&ES<V5T*"1T
M97-T6R=M=6QT:7!L92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=6YF
M;W5N9'1A9W-;72`]("1T97-T6R=T86<G73L-"B`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;F%L=&%G<UM=(#T@)'1E<W1;)W1A9R==.PT*("`@("`@("`@
M("`@("`@("`@("`D;6ES;6%T8V@@/2!T<G5E.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D<F5T("8]("1T:&ES+3Y?<')O8V5S<T%T
M=')I8G,H)'1E<W0L("1T86<L("1R;V]T*3L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H(21M:7-M871C:"`F)B!C;W5N="@D;W!T:6]N86QT86=S*2D@>PT*("`@
M("`@("`@("`@+R\@9&]N)W0@97)R;W(@;W5T(&]N(&%N>2!O<'1I;VYA;"!T
M86=S#0H@("`@("`@("`@("`D=6YF;W5N9'1A9W,@/2!A<G)A>5]D:69F*"1U
M;F9O=6YD=&%G<RP@)&]P=&EO;F%L=&%G<RD[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&-O=6YT*"1U;F9O=6YD=&%G<RDI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?:6YV86QI9%1A9T]R9&5R*"1U;F9O=6YD=&%G<RP@)&ME>2P@)')O
M;W0I.PT*("`@("`@("!](&5L<V5I9B`H)&ME>2D@>PT*("`@("`@("`@("`@
M+R\@=6YK;F]W;B!T86=S#0H@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:614
M86=/<F1E<B@G*FYO('1A9W,@86QL;W=E9"!H97)E*B<L("1K97DL("1R;V]T
M*3L-"B`@("`@("`@("`@('=H:6QE("@D:V5Y(#T@;F5X="@D:V5Y<RDI('L-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61486=/<F1E<B@G*FYO
M('1A9W,@86QL;W=E9"!H97)E*B<L("1K97DL("1R;V]T*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?<')O8V5S<T%T=')I8G,H)&-H;VEC92P@)'1A
M9RP@)&-O;G1E>'0I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&-H;VEC
M95LG871T<FEB<R==*2D@>PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M=&%G*2D@>PT*("`@("`@("`@("`@("`@("1T86<@/2!A<G)A>2@D=&%G*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T86=S(#T@)'1A9SL-"B`@
M("`@("`@("`@(&EF("@A:7-S970H)'1A9W-;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)'1A9W,@/2!A<G)A>2@D=&%G<RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D<F5T(#T@=')U93L-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T86=S(&%S("1I(#T^("1T86<I('L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES7V%R<F%Y*"1T86<I('Q\("%I<W-E="@D=&%G6R=A='1R:6)S)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C:&]I8V5;)V%T=')I
M8G,G72!A<R`D871T<FEB*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&%T=')I8GLP?2`A/2`G/R<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5T("8]("1T:&ES+3Y?=&%G2&%S3F]!='1R:6)S*"1C:&]I
M8V5;)W1A9R==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M8V]N=&5X="D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64@,CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D8VAO:6-E6R=A='1R:6)S)UT@87,@)&%T=')I8BD@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&%T=')I8GLP?2`A/2`G/R<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'1A9ULG871T
M<FEB<R==6R1A='1R:6)=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R970@)CT@)'1H:7,M/E]T86=-:7-S:6YG071T<FEB=71E*"1C:&]I
M8V5;)W1A9R==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M871T<FEB+"`D8V]N=&5X="D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)')E=#L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?<')O8V5S<U-T<G5C='5R92@D:V5Y*0T*("`@('L-"B`@("`@("`@
M)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AC;W5N="@D<&EE8V5S(#T@
M97AP;&]D92@G?"<L("1K97DI*2`^(#$I('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1P:65C97,@87,@)'!I96-E*2![#0H@("`@("`@("`@("`@("`@)')E
M=%LG8VAO:6-E<R==6UT@/2`D=&AI<RT^7W!R;V-E<W-3=')U8W1U<F4H)'!I
M96-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D<F5T
M.PT*("`@("`@("!]#0H@("`@("`@("1M=6QT:2`]("1K97E[,'T[#0H@("`@
M("`@(&EF("@D;75L=&D@/3T@)RLG('Q\("1M=6QT:2`]/2`G*B<I('L-"B`@
M("`@("`@("`@("1R971;)VUU;'1I<&QE)UT@/2`D:V5Y>S!].PT*("`@("`@
M("`@("`@)&ME>2`]('-U8G-T<B@D:V5Y+"`Q*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H8V]U;G0H)&%T=')S(#T@97AP;&]D92@G+3XG+"`D:V5Y*2D@
M/B`Q*2![#0H@("`@("`@("`@("`D<F5T6R=T86<G72`](&%R<F%Y7W-H:69T
M*"1A='1R<RD[#0H@("`@("`@("`@("`D<F5T6R=A='1R:6)S)UT@/2`D871T
M<G,[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<F5T6R=T86<G
M72`]("1K97D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E4W1A8FEL:71Y5F5R<VEO
M;B@I#0H@("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH)W)E;&5A
M<V4G+"`G87!I)RD[#0H@("`@("`@("1A(#T@)'1H:7,M/E]S='5P:6138VAE
M;6%686QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V
M97)S:6]N)UTL("<\=F5R<VEO;CXG*3L-"B`@("`@("`@)&$@)CT@)'1H:7,M
M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A
M8VMA9V5);F9O6R=S=&%B:6QI='DG72P@)SQS=&%B:6QI='D^)RD[#0H@("`@
M("`@(&EF("@D82D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O
M7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W9E<G-I;VXG75LG<F5L
M96%S92==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E
M<G-I;VXH)W)E;&5A<V4G+"`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N
M)UU;)W)E;&5A<V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD
M*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG=F5R<VEO;B==6R=A<&DG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEN=F%L:61697)S:6]N*"=A<&DG+"`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=V97)S:6]N)UU;)V%P:2==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("@A:6Y?87)R87DH)'1H:7,M/E]P86-K86=E26YF;ULG<W1A8FEL
M:71Y)UU;)W)E;&5A<V4G72P-"B`@("`@("`@("`@("`@("`@(&%R<F%Y*"=S
M;F%P<VAO="<L("=D979E;"<L("=A;'!H82<L("=B971A)RP@)W-T86)L92<I
M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%-T871E*"=R
M96QE87-E)RP@)'1H:7,M/E]P86-K86=E:6YF;ULG<W1A8FEL:71Y)UU;)W)E
M;&5A<V4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6EN
M7V%R<F%Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-T86)I;&ET>2==6R=A<&DG
M72P-"B`@("`@("`@("`@("`@("`@(&%R<F%Y*"=D979E;"<L("=A;'!H82<L
M("=B971A)RP@)W-T86)L92<I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:6YV86QI9%-T871E*"=A<&DG+"`D=&AI<RT^7W!A8VMA9V5I;F9O6R=S
M=&%B:6QI='DG75LG87!I)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W9A;&ED871E36%I;G1A:6YE<G,H
M*0T*("`@('L-"B`@("`@("`@)'-T<G5C='5R92`]#0H@("`@("`@("`@("!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`G;F%M92<L#0H@("`@("`@("`@("`@
M("`@)W5S97(G+`T*("`@("`@("`@("`@("`@("=E;6%I;"<L#0H@("`@("`@
M("`@("`@("`@)V%C=&EV92<L#0H@("`@("`@("`@("`I.PT*("`@("`@("!F
M;W)E86-H("AA<G)A>2@G;&5A9"<L("=D979E;&]P97(G+"`G8V]N=')I8G5T
M;W(G+"`G:&5L<&5R)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@(&EF("@A
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD='EP95TI*2![#0H@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULD='EP95U;,%TI*2![
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P86-K86=E26YF
M;ULD='EP95T@87,@)&QE860I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D;&5A9"P@
M)SPG("X@)'1Y<&4@+B`G/B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S='5P
M:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R1T>7!E72P-"B`@("`@("`@("`@("`@("`@("`@)SPG("X@)'1Y<&4@
M+B`G/B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@7W9A;&ED871E4&AP1&5P*"1D97`L("1I;G-T86QL8V]N
M9&ET:6]N(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D<W1R=6-T=7)E(#T@
M87)R87DH#0H@("`@("`@("`@("`G;6EN)RP-"B`@("`@("`@("`@("<J;6%X
M)RP-"B`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("D[#0H@("`@
M("`@("1T>7!E(#T@)&EN<W1A;&QC;VYD:71I;VX@/R`G/&EN<W1A;&QC;VYD
M:71I;VX^/'!H<#XG(#H@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP:'`^
M)SL-"B`@("`@("`@)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R
M=6-T=7)E+"`D9&5P+"`D='EP92D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=M:6XG72DI('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<
M9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\H/SHM6V$M>D$M6C`M.5TK
M*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG72DI('L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"1T>7!E("X@
M)SQM:6X^)RP@)&1E<%LG;6EN)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-"B`@("`@
M("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M
M>D$M6ETK7&0J*3\H/SHM6V$M>D$M6C`M.5TK*3\D+R<L#0H@("`@("`@("`@
M("`@("`@("`D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VEN=F%L:61697)S:6]N*"1T>7!E("X@)SQM87@^)RP@)&1E<%LG;6%X
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7W9A;&ED871E4&5A<FEN<W1A;&QE<D1E<"@D9&5P*0T*("`@
M('L-"B`@("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@
M)VUI;B<L#0H@("`@("`@("`@("`G*FUA>"<L#0H@("`@("`@("`@("`G*G)E
M8V]M;65N9&5D)RP-"B`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@
M("D[#0H@("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T
M<G5C='5R92P@)&1E<"P@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQP96%R
M:6YS=&%L;&5R/B<I.PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI
M*2![#0H@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<
M9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@
M)&1E<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A
M;&ED5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T
M86QL97(^/&UI;CXG+`T*("`@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES
M<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@:68@*"%P<F5G7VUA
M=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@
M("`@("`@("`@("`@("`@("1D97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH)SQD97!E;F1E;F-I97,^/')E
M<75I<F5D/CQP96%R:6YS=&%L;&5R/CQM87@^)RP-"B`@("`@("`@("`@("`@
M("`@("`@)&1E<%LG;6%X)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=R96-O;6UE;F1E9"==*2D@>PT*
M("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH
M/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;
M)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I
M;G9A;&ED5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I
M;G-T86QL97(^/')E8V]M;65N9&5D/B<L#0H@("`@("`@("`@("`@("`@("`@
M("1D97!;)W)E8V]M;65N9&5D)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P
M6R=E>&-L=61E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R
M96%C:"`H)&1E<%LG97AC;'5D92==(&%S("1E>&-L=61E*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;
M82UZ02U:72M<9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("`@("`D97AC
M;'5D92DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED
M5F5R<VEO;B@G/&1E<&5N9&5N8VEE<SX\<F5Q=6ER960^/'!E87)I;G-T86QL
M97(^/&5X8VQU9&4^)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L
M=61E*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5086-K86=E
M1&5P*"1D97`L("1G<F]U<"P@)'1Y<&4@/2`G/'!A8VMA9V4^)RD-"B`@("![
M#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72DI('L-"B`@("`@("`@
M("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=N86UE)RP-"B`@("`@("`@("`@("`@("`@("`@)W5R:2<L#0H@("`@
M("`@("`@("`@("`@("`@("=C;VYF;&EC=',G+`T*("`@("`@("`@("`@("`@
M("`@("`G*G!R;W9I9&5S97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<W1R
M=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE)RP-
M"B`@("`@("`@("`@("`@("`@("`@)W5R:2<L#0H@("`@("`@("`@("`@("`@
M("`@("<J<')O=FED97-E>'1E;G-I;VXG+`T*("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@
M("`@("`@)'-T<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G;F%M92<L#0H@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)RP-"B`@
M("`@("`@("`@("`@("`@("`@)RIM:6XG+`T*("`@("`@("`@("`@("`@("`@
M("`G*FUA>"<L#0H@("`@("`@("`@("`@("`@("`@("<J97AC;'5D92<L#0H@
M("`@("`@("`@("`@("`@("`@("=C;VYF;&EC=',G+`T*("`@("`@("`@("`@
M("`@("`@("`G*G!R;W9I9&5S97AT96YS:6]N)RP-"B`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=N86UE
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG+`T*("`@("`@("`@
M("`@("`@("`@("`G*FUI;B<L#0H@("`@("`@("`@("`@("`@("`@("<J;6%X
M)RP-"B`@("`@("`@("`@("`@("`@("`@)RIR96-O;6UE;F1E9"<L#0H@("`@
M("`@("`@("`@("`@("`@("<J97AC;'5D92<L#0H@("`@("`@("`@("`@("`@
M("`@("<J;F]D969A=6QT)RP-"B`@("`@("`@("`@("`@("`@("`@)RIP<F]V
M:61E<V5X=&5N<VEO;B<L#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M
M92==*2D@>PT*("`@("`@("`@("`@)'1Y<&4@+CT@)SQN86UE/B<@+B`D9&5P
M6R=N86UE)UT@+B`G/"]N86UE/B<[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D9&5P+"`G
M/&1E<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@("!I
M9B`H:7-S970H)&1E<%LG=7)I)UTI("8F("AI<W-E="@D9&5P6R=M:6XG72D@
M?'P@:7-S970H)&1E<%LG;6%X)UTI('Q\#0H@("`@("`@("`@("`@(&ES<V5T
M*"1D97!;)W)E8V]M;65N9&5D)UTI('Q\(&ES<V5T*"1D97!;)V5X8VQU9&4G
M72DI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W5R:41E<'-#86YN;W1(879E
M5F5R<VEO;FEN9R@G/&1E<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L
M)UTI("8F('-T<G1O;&]W97(H)&1E<%LG8VAA;FYE;"==*2`]/2`G7U]U<FDG
M*2![#0H@("`@("`@("`@("`D=&AI<RT^7T1E<&-H86YN96Q#86YN;W1"955R
M:2@G/&1E<&5N9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@
M("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M
M>D$M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=M:6XG
M72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N
M*"<\9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\;6EN/B<L
M("1D97!;)VUI;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD
M*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E<%LG;6%X)UTI*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;B@G/&1E<&5N
M9&5N8VEE<SXG("X@)&=R;W5P("X@)'1Y<&4@+B`G/&UA>#XG+"`D9&5P6R=M
M87@G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!;)W)E8V]M;65N9&5D)UTI*2![#0H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD
M*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD960G
M72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N
M*"<\9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\<F5C;VUM
M96YD960^)RP-"B`@("`@("`@("`@("`@("`@("`@)&1E<%LG<F5C;VUM96YD
M960G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A
M:7-?87)R87DH)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@
M("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;)V5X8VQU9&4G72D[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D9&5P6R=E>&-L
M=61E)UT@87,@)&5X8VQU9&4I('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R
M96=?;6%T8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G
M+`T*("`@("`@("`@("`@("`@("`@("`@("1E>&-L=61E*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7VEN=F%L:61697)S:6]N*"<\9&5P96YD
M96YC:65S/B<@+B`D9W)O=7`@+B`D='EP92`N("<\97AC;'5D93XG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]V86QI9&%T95-U8G!A8VMA9V5$97`H)&1E<"P@)&=R;W5P
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]V86QI9&%T95!A8VMA9V5$97`H
M)&1E<"P@)&=R;W5P+"`G/'-U8G!A8VMA9V4^)RD[#0H@("`@("`@(&EF("AI
M<W-E="@D9&5P6R=P<F]V:61E<V5X=&5N<VEO;B==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]S=6)P86-K86=E0V%N;F]T4')O=FED945X=&5N<VEO;BA`
M)&1E<%LG;F%M92==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H
M)&1E<%LG8V]N9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`D=&AI<RT^7W-U
M8G!A8VMA9V5S0V%N;F]T0V]N9FQI8W0H0"1D97!;)VYA;64G72D[#0H@("`@
M("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5%>'1E;G-I
M;VY$97`H)&1E<"P@)&=R;W5P(#T@9F%L<V4L("1I;G-T86QL8V]N9&ET:6]N
M(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N
M9FQI8W1S)UTI*2![#0H@("`@("`@("`@("`D<W1R=6-T=7)E(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@("`@("`@("<J
M;6EN)RP-"B`@("`@("`@("`@("`@("`G*FUA>"<L#0H@("`@("`@("`@("`@
M("`@)RIE>&-L=61E)RP-"B`@("`@("`@("`@("`@("`G8V]N9FQI8W1S)RP-
M"B`@("`@("`@("`@("D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D<W1R=6-T=7)E(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)VYA;64G
M+`T*("`@("`@("`@("`@("`@("<J;6EN)RP-"B`@("`@("`@("`@("`@("`G
M*FUA>"<L#0H@("`@("`@("`@("`@("`@)RIR96-O;6UE;F1E9"<L#0H@("`@
M("`@("`@("`@("`@)RIE>&-L=61E)RP-"B`@("`@("`@("`@("D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1I;G-T86QL8V]N9&ET:6]N*2![#0H@("`@
M("`@("`@("`D='EP92`]("<\:6YS=&%L;&-O;F1I=&EO;CX\97AT96YS:6]N
M/B<[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D='EP92`]("<\
M9&5P96YD96YC:65S/B<@+B`D9W)O=7`@+B`G/&5X=&5N<VEO;CXG.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=N86UE)UTI*2![#0H@
M("`@("`@("`@("`D='EP92`N/2`G/&YA;64^)R`N("1D97!;)VYA;64G72`N
M("<\+VYA;64^)SL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-T=7!I
M9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L("1D97`L("1T>7!E*3L-"B`@
M("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<
M9"HI/R0O)RP-"B`@("`@("`@("`@("`@("`@("1D97!;)VUI;B==*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R
M*"1T>7!E+"`Q*2`N("<\;6EN)RP@)&1E<%LG;6EN)UTI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<
M+EQD*RDJ*#\Z6V$M>D$M6ETK7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@
M("`D9&5P6R=M87@G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VEN
M=F%L:61697)S:6]N*'-U8G-T<B@D='EP92P@,2D@+B`G/&UA>"<L("1D97!;
M)VUA>"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H:7-S970H)&1E<%LG<F5C;VUM96YD960G72DI('L-"B`@("`@("`@("`@
M(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK
M7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`D9&5P6R=R96-O;6UE;F1E
M9"==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I
M;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\<F5C;VUM96YD960G+"`D9&5P6R=R
M96-O;6UE;F1E9"==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@
M("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@
M("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@87)R87DH)&1E<%LG97AC;'5D
M92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D
M97!;)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@("`@("`@("`@("`@
M(&EF("@A<')E9U]M871C:"@G+UY<9"LH/SI<+EQD*RDJ*#\Z6V$M>D$M6ETK
M7&0J*3\D+R<L#0H@("`@("`@("`@("`@("`@("`@("`@)&5X8VQU9&4I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH
M<W5B<W1R*"1T>7!E+"`Q*2`N("<\97AC;'5D92<L("1E>&-L=61E*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5/<T1E<"@D9&5P+"`D:6YS
M=&%L;&-O;F1I=&EO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'-T<G5C
M='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@)VYA;64G+`T*("`@("`@("`@
M("`@)RIC;VYF;&EC=',G+`T*("`@("`@("`I.PT*("`@("`@("`D='EP92`]
M("1I;G-T86QL8V]N9&ET:6]N(#\@)SQI;G-T86QL8V]N9&ET:6]N/CQO<SXG
M(#H@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQO<SXG.PT*("`@("`@("!I
M9B`H)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E+"`D
M9&5P+"`D='EP92DI('L-"B`@("`@("`@("`@(&EF("@D9&5P6R=N86UE)UT@
M/3T@)RHG*2![#0H@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)V-O;F9L:6-T<R<L("1D97`I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8V%N;F]T0V]N9FQI8W17:71H06QL3W,H)'1Y<&4I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94%R8VA$97`H)&1E<"P@)&EN
M<W1A;&QC;VYD:71I;VX@/2!F86QS92D-"B`@("![#0H@("`@("`@("1S=')U
M8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("=P871T97)N)RP-"B`@("`@
M("`@("`@("<J8V]N9FQI8W1S)RP-"B`@("`@("`@*3L-"B`@("`@("`@)'1Y
M<&4@/2`D:6YS=&%L;&-O;F1I=&EO;B`_("<\:6YS=&%L;&-O;F1I=&EO;CX\
M87)C:#XG(#H@)SQD97!E;F1E;F-I97,^/')E<75I<F5D/CQA<F-H/B<[#0H@
M("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H)'-T<G5C='5R
M92P@)&1E<"P@)'1Y<&4I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI
M9&%T94EN<W1A;&Q#;VYD:71I;VYS*"1C;VYD+"`D<F5L96%S92D-"B`@("![
M#0H@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("<J
M<&AP)RP-"B`@("`@("`@("`@("<J97AT96YS:6]N)RP-"B`@("`@("`@("`@
M("<J;W,G+`T*("`@("`@("`@("`@)RIA<F-H)RP-"B`@("`@("`@*3L-"B`@
M("`@("`@:68@*"$D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U
M8W1U<F4L#0H@("`@("`@("`@("`@("1C;VYD+"`D<F5L96%S92DI('L-"B`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!F
M;W)E86-H("AA<G)A>2@G<&AP)RP@)V5X=&5N<VEO;B<L("=O<R<L("=A<F-H
M)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D8V]N9%LD
M='EP95TI*2![#0H@("`@("`@("`@("`@("`@)&ET97(@/2`D8V]N9%LD='EP
M95T[#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D:71E<BD@?'P@
M(6ES<V5T*"1I=&5R6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:71E
M<B`](&%R<F%Y*"1I=&5R*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&ET97(@87,@)'!A8VMA9V4I('L-"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=E>'1E;G-I;VXG*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^>R)?=F%L:61A=&5[)'1Y
M<&5]1&5P(GTH)'!A8VMA9V4L(&9A;'-E+"!T<G5E*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y[(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C:V%G92P@=')U92D[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!?=F%L:61A=&5$97!E;F1E;F-I97,H*0T*("`@('L-"B`@("`@("`@)'-T
M<G5C='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@)W)E<75I<F5D)RP-"B`@
M("`@("`@("`@("<J;W!T:6]N86PG+`T*("`@("`@("`@("`@)RIG<F]U<"T^
M;F%M92T^:&EN="<-"B`@("`@("`@*3L-"B`@("`@("`@:68@*"$D=&AI<RT^
M7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L#0H@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V1E<&5N9&5N8VEE<R==+"`G/&1E
M<&5N9&5N8VEE<SXG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=R97%U:7)E9"<L
M("=O<'1I;VYA;"<I(&%S("1S:6UP;&5D97`I('L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=D97!E;F1E;F-I97,G75LD
M<VEM<&QE9&5P72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'-I;7!L961E
M<"`]/2`G;W!T:6]N86PG*2![#0H@("`@("`@("`@("`@("`@("`@("1S=')U
M8W1U<F4@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("<J<&%C
M:V%G92<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*G-U8G!A8VMA9V4G
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@)RIE>'1E;G-I;VXG+`T*("`@
M("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1S=')U8W1U<F4@/2!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@("`@("=P:'`G+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)W!E87)I;G-T86QL97(G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)RIP86-K86=E)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<J
M<W5B<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*F5X=&5N
M<VEO;B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G*F]S)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("<J87)C:"<L#0H@("`@("`@("`@("`@("`@
M("`@("D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8W1U<F4L#0H@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P
M96YD96YC:65S)UU;)'-I;7!L961E<%TL#0H@("`@("`@("`@("`@("`@("`@
M("`@(CQD97!E;F1E;F-I97,^/"1S:6UP;&5D97`^(BDI('L-"B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)W!A8VMA9V4G+"`G<W5B<&%C
M:V%G92<L("=E>'1E;G-I;VXG*2!A<R`D='EP92D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V1E
M<&5N9&5N8VEE<R==6R1S:6UP;&5D97!=6R1T>7!E72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:71E<B`]("1T:&ES+3Y?<&%C:V%G94EN
M9F];)V1E<&5N9&5N8VEE<R==6R1S:6UP;&5D97!=6R1T>7!E73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I=&5R6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E<B`](&%R
M<F%Y*"1I=&5R*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET97(@87,@
M)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1T>7!E("$]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W5R:2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U5R
M;$]R0VAA;FYE;"@D='EP92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7TYO0VAA;FYE;"@D
M='EP92P@)'!A8VMA9V5;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y[(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C:V%G92P@(CPD<VEM<&QE
M9&5P/B(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H)'-I;7!L961E<"`]/2`G;W!T:6]N
M86PG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("AA<G)A>2@G<&AP)RP@)W!E87)I;G-T86QL97(G+"`G;W,G+"`G87)C
M:"<I(&%S("1T>7!E*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)'-I
M;7!L961E<%U;)'1Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I=&5R(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD96YC:65S
M)UU;)'-I;7!L961E<%U;)'1Y<&5=.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&ET97);,%TI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1I=&5R(#T@87)R87DH)&ET97(I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D:71E<B!A<R`D<&%C:V%G92D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^>R)?=F%L:61A
M=&5[)'1Y<&5]1&5P(GTH)'!A8VMA9V4I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M86-K86=E26YF;ULG9&5P96YD96YC:65S)UU;)V=R;W5P)UTI*2![#0H@("`@
M("`@("`@("`D9W)O=7!S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG9&5P96YD
M96YC:65S)UU;)V=R;W5P)UT[#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1G
M<F]U<'-;,%TI*2![#0H@("`@("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y
M*"1G<F]U<',I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'-T<G5C
M='5R92`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("<J<&%C:V%G92<L#0H@
M("`@("`@("`@("`@("`@)RIS=6)P86-K86=E)RP-"B`@("`@("`@("`@("`@
M("`G*F5X=&5N<VEO;B<L#0H@("`@("`@("`@("`I.PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&=R;W5P<R!A<R`D9W)O=7`I('L-"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]S='5P:6138VAE;6%686QI9&%T92@D<W1R=6-T=7)E
M+"`D9W)O=7`L("<\9W)O=7`^)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%014%27U9A;&ED871E.CIV86QI9$=R;W5P3F%M92@D9W)O=7!;)V%T
M=')I8G,G75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]I;G9A;&ED1&5P1W)O=7!.86UE*"1G<F]U<%LG871T<FEB<R==
M6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=P86-K86=E)RP@)W-U8G!A8VMA
M9V4G+"`G97AT96YS:6]N)RD@87,@)'1Y<&4I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)'1Y<&5=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1I=&5R(#T@)&=R;W5P6R1T>7!E73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I=&5R
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:71E
M<B`](&%R<F%Y*"1I=&5R*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ET
M97(@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T>7!E("$]("=E>'1E;G-I;VXG*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG8VAA;FYE;"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7U5R;$]R0VAA;FYE;$=R;W5P*"1T>7!E+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VYA
M;64G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1G<F]U<%LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!A8VMA9V5;)V-H
M86YN96PG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E].;T-H86YN96Q'<F]U<"@D='EP92P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P86-K86=E6R=N86UE)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7!;)VYA;64G72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y[(E]V86QI9&%T97LD='EP97U$97`B?2@D<&%C
M:V%G92P@)SQG<F]U<"!N86UE/2(G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G
M(CXG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!?=F%L:61A=&5#;VUP871I8FQE*"D-"B`@
M("![#0H@("`@("`@("1C;VUP870@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=C
M;VUP871I8FQE)UT[#0H@("`@("`@(&EF("@A:7-S970H)&-O;7!A=%LP72DI
M('L-"B`@("`@("`@("`@("1C;VUP870@/2!A<G)A>2@D8V]M<&%T*3L-"B`@
M("`@("`@?0T*("`@("`@("`D<F5Q=6ER960@/2!A<G)A>2@G;F%M92<L("=C
M:&%N;F5L)RP@)VUI;B<L("=M87@G+"`G*F5X8VQU9&4G*3L-"B`@("`@("`@
M9F]R96%C:"`H)&-O;7!A="!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@
M)'1Y<&4@/2`G/&-O;7!A=&EB;&4^)SL-"B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%C:V%G92D@)B8@87)R87E?:V5Y7V5X:7-T<R@G;F%M92<L("1P
M86-K86=E*2D@>PT*("`@("`@("`@("`@("`@("1T>7!E("X]("<\;F%M93XG
M("X@)'!A8VMA9V5;)VYA;64G72`N("<\+VYA;64^)SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H
M)')E<75I<F5D+"`D<&%C:V%G92P@)'1Y<&4I.PT*("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1P86-K86=E*2`F)B!A<G)A>5]K97E?97AI<W1S*"=M:6XG
M+"`D<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T
M8V@H)R]>7&0K*#\Z7"Y<9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]I;G9A;&ED5F5R<VEO;BAS=6)S='(H
M)'1Y<&4L(#$I("X@)SQM:6XG+"`D<&%C:V%G95LG;6EN)UTI.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D<&%C:V%G92D@)B8@87)R87E?:V5Y7V5X:7-T<R@G;6%X)RP@
M)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@:68@*"%P<F5G7VUA=&-H
M*"<O7EQD*R@_.EPN7&0K*2HH/SI;82UZ02U:72M<9"HI/R0O)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`D<&%C:V%G95LG;6%X)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T
M>7!E+"`Q*2`N("<\;6%X)RP@)'!A8VMA9V5;)VUA>"==*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-?
M87)R87DH)'!A8VMA9V4I("8F(&%R<F%Y7VME>5]E>&ES=',H)V5X8VQU9&4G
M+"`D<&%C:V%G92DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1P86-K86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("1P86-K86=E6R=E>&-L=61E)UT@/2!A<G)A>2@D<&%C:V%G95LG97AC;'5D
M92==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)'!A8VMA9V5;)V5X8VQU9&4G72!A<R`D97AC;'5D92D@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H(7!R96=?;6%T8V@H)R]>7&0K*#\Z7"Y<
M9"LI*B@_.EMA+7I!+5I=*UQD*BD_)"\G+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`D97AC;'5D92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:6YV86QI9%9E<G-I;VXH<W5B<W1R*"1T>7!E+"`Q*2`N("<\
M97AC;'5D92<L("1E>&-L=61E*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]V86QI9&%T94)U;F1L92@D;&ES="D-
M"B`@("![#0H@("`@("`@(&EF("@A:7-?87)R87DH)&QI<W0I('Q\("%I<W-E
M="@D;&ES=%LG8G5N9&QE9'!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7TYO0G5N9&QE9%!A8VMA9V5S*"D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%I<U]A<G)A>2@D;&ES=%LG8G5N9&QE9'!A8VMA9V4G
M72D@?'P@(6ES<V5T*"1L:7-T6R=B=6YD;&5D<&%C:V%G92==6S!=*2D@>PT*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?071,96%S=#)"=6YD;&5D4&%C
M:V%G97,H*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D;&ES=%LG
M8G5N9&QE9'!A8VMA9V4G72!A<R`D<&%C:V%G92D@>PT*("`@("`@("`@("`@
M:68@*"%I<U]S=')I;F<H)'!A8VMA9V4I*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]B=6YD;&5D4&%C:V%G97--=7-T0F5&:6QE;F%M92@I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7W9A;&ED871E1FEL96QI<W0H)&QI<W0@/2!F86QS92P@)&%L;&]W:6=N;W)E
M(#T@9F%L<V4L("1D:7)S(#T@)R<I#0H@("`@>PT*("`@("`@("`D:7-C;VYT
M96YT<R`](&9A;'-E.PT*("`@("`@("!I9B`H(21L:7-T*2![#0H@("`@("`@
M("`@("`D:7-C;VYT96YT<R`]('1R=64[#0H@("`@("`@("`@("`D;&ES="`]
M("1T:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UT[#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG8G5N9&QE)UTI*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&5"=6YD
M;&4H)&QI<W0I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("@D86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("1S=')U8R`](&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("<J:6YS=&%L;"T^;F%M92T^87,G+`T*
M("`@("`@("`@("`@("`@("<J:6=N;W)E+3YN86UE)PT*("`@("`@("`@("`@
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S=')U8R`](&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("<J9&ER+3YN86UE+3X_8F%S96EN<W1A
M;&QD:7(G+`T*("`@("`@("`@("`@("`@("<J9FEL92T^;F%M92T^<F]L92T^
M/V)A<V5I;G-T86QL9&ER+3X_;60U<W5M)PT*("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D;&ES=%LG9&ER)UTI("8F(&ES<V5T*"1L
M:7-T6R=F:6QE)UTI*2![#0H@("`@("`@("`@("`@("`@+R\@<W1A=F4@;V9F
M('9A;&ED871I;VX@97)R;W)S('=I=&AO=70@<F5Q=6ER:6YG(&$@<V5T(&]R
M9&5R+@T*("`@("`@("`@("`@("`@("1?;VQD(#T@)&QI<W0[#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1L:7-T6R=A='1R:6)S)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("1L:7-T(#T@87)R87DH)V%T=')I8G,G(#T^("1?
M;VQD6R=A='1R:6)S)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D;&ES=%LG9&ER)UT@/2`D7V]L9%LG9&ER)UT[#0H@("`@("`@
M("`@("`@("`@)&QI<W1;)V9I;&4G72`]("1?;VQD6R=F:6QE)UT[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D;&ES
M=%LG871T<FEB<R==*2!\?"`A:7-S970H)&QI<W1;)V%T=')I8G,G75LG;F%M
M92==*2D@>PT*("`@("`@("`@("`@)'5N:VYO=VX@/2`D86QL;W=I9VYO<F4@
M/R`G/&9I;&5L:7-T/B<@.B`G/&1I<B!N86UE/2(J=6YK;F]W;BHB/B<[#0H@
M("`@("`@("`@("`D9&ER;F%M92`]("1I<V-O;G1E;G1S(#\@)SQC;VYT96YT
M<SXG(#H@)'5N:VYO=VX[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`D9&ER;F%M92`]("<\9&ER(&YA;64](B<@+B`D;&ES=%LG871T<FEB<R==
M6R=N86UE)UT@+B`G(CXG.PT*("`@("`@("!]#0H@("`@("`@("1R97,@/2`D
M=&AI<RT^7W-T=7!I9%-C:&5M859A;&ED871E*"1S=')U8RP@)&QI<W0L("1D
M:7)N86UE*3L-"B`@("`@("`@:68@*"1A;&QO=VEG;F]R92`F)B`D<F5S*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W!F+3YG971&:6QE;&ES="@I.PT*("`@
M("`@("`@("`@)&9C;VYT96YT<R`]("1T:&ES+3Y?<&8M/F=E=$-O;G1E;G1S
M*"D[#0H@("`@("`@("`@("`D9FEL96QI<W0@/2!A<G)A>2@I.PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D9F-O;G1E;G1S6R=D:7(G75LG9FEL92==6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("1F8V]N=&5N='-;)V1I<B==6R=F:6QE
M)UT@/2!A<G)A>2@D9F-O;G1E;G1S6R=D:7(G75LG9FEL92==*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1F8V]N=&5N='-;)V1I
M<B==6R=F:6QE)UT@87,@)&9I;&4I('L-"B`@("`@("`@("`@("`@("`D9FEL
M96QI<W1;)&9I;&5;)V%T=')I8G,G75LG;F%M92==72`]('1R=64[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&QI<W1;)VEN<W1A
M;&PG72DI('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1L:7-T6R=I
M;G-T86QL)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1L:7-T6R=I
M;G-T86QL)UT@/2!A<G)A>2@D;&ES=%LG:6YS=&%L;"==*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&QI<W1;)VEN
M<W1A;&PG72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1F:6QE;&ES=%LD9FEL95LG871T<FEB<R==6R=N86UE)UU=*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N;W1);D-O;G1E
M;G1S*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72P@)VEN<W1A;&PG*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D;&ES=%LG:6=N;W)E
M)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG:6=N
M;W)E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1L:7-T6R=I9VYO
M<F4G72`](&%R<F%Y*"1L:7-T6R=I9VYO<F4G72D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T6R=I9VYO<F4G
M72!A<R`D9FEL92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1F:6QE;&ES=%LD9FEL95LG871T<FEB<R==6R=N86UE)UU=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]N;W1);D-O;G1E;G1S*"1F
M:6QE6R=A='1R:6)S)UU;)VYA;64G72P@)VEG;F]R92<I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A)&%L;&]W:6=N;W)E("8F(&ES
M<V5T*"1L:7-T6R=F:6QE)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1L:7-T6R=F:6QE)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@+R\@<VEN
M9VQE(&9I;&4-"B`@("`@("`@("`@("`@("`D;&ES=%LG9FEL92==(#T@87)R
M87DH)&QI<W1;)V9I;&4G72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!F;W)E86-H("@D;&ES=%LG9FEL92==(&%S("1I(#T^("1F:6QE*0T*("`@
M("`@("`@("`@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG
M871T<FEB<R==*2`F)B!I<W-E="@D9FEL95LG871T<FEB<R==6R=N86UE)UTI
M("8F#0H@("`@("`@("`@("`@("`@("`@("`@)&9I;&5;)V%T=')I8G,G75LG
M;F%M92==>S!](#T]("<N)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@
M)&9I;&5;)V%T=')I8G,G75LG;F%M92==>S%](#T]("<O)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`O+R!N86UE(&ES('-O;65T:&EN9R!L:6ME("(N+V1O
M8R]W:&%T979E<BYT>'0B#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:6YV86QI9$9I;&5.86UE*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9FEL95LG871T<FEB<R==*2`F)B!I<W-E="@D9FEL95LG871T<FEB<R==6R=R
M;VQE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/E]V
M86QI9&%T95)O;&4H)&9I;&5;)V%T=')I8G,G75LG<F]L92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G
M94EN9F];)W5S97-R;VQE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')O;&5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG=7-E<W)O;&4G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R
M;VQE<ULP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)')O;&5S(#T@87)R87DH)')O;&5S*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)')O;&5S(&%S("1R;VQE*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<F]L95LG<F]L92==(#T@)&9I;&5;)V%T=')I8G,G
M75LG<F]L92==*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;7-G(#T@)U1H:7,@<&%C:V%G92!C;VYT86EN<R!R;VQE("(E<F]L
M924B(&%N9"!R97%U:7)E<R`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<&%C:V%G92`B)7!A8VMA9V4E(B!T;R!B92!U
M<V5D)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<F]L95LG=7)I)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=R;VQE)R`]
M/B`D<F]L95LG<F]L92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)')O;&5;)W5R:2==*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y*"=R;VQE)R`]/B`D<F]L95LG<F]L92==+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G
M92<@/3X@)'1H:7,M/E]P9BT^7W)E9VES=')Y+3X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<&%R<V5D4&%C:V%G94YA
M;654;U-T<FEN9RAA<G)A>2@G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;VQE6R=P86-K
M86=E)UTL("=C:&%N;F5L)R`]/B`D<F]L95LG8VAA;FYE;"==*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R
M=64I*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<W1A8VLM/G!U<V@H)U]M=7-T26YS=&%L;%)O;&4G+"`G97)R;W(G+"`D<&%R
M86US+"`D;7-G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?:6YV86QI9$9I;&52;VQE*"1F:6QE6R=A='1R:6)S)UU;)VYA;64G72P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&ER;F%M92P@)&9I;&5;
M)V%T=')I8G,G75LG<F]L92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1F:6QE6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M<V%V92`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@:68@
M*"1D:7)S*2![#0H@("`@("`@("`@("`@("`@("`@("1S879E6R=N86UE)UT@
M/2`D9&ER<R`N("<O)R`N("1S879E6R=N86UE)UT[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE6R=A='1R:6)S)UTI
M.PT*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9FEL92D@)B8@)'1H:7,M
M/E]C=7)3=&%T92`A/2!014%27U9!3$E$051%7T1/5TY,3T%$24Y'*2![("\O
M(&AA<R!T87-K<PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEL
M92!A<R`D=&%S:R`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@D=&%G0VQA<W,@/2`D=&AI<RT^7W!F+3YG971487-K*"1T87-K
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?87)R
M87DH)'9A;'5E*2!\?"`A:7-S970H)'9A;'5E6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!A<G)A>2@D=F%L=64I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)'8I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E="`](&-A;&Q?=7-E
M<E]F=6YC*&%R<F%Y*"1T86=#;&%S<RP@)W9A;&ED871E6&UL)RDL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!F+"`D
M=BP@)'1H:7,M/E]P9BT^7V-O;F9I9RP@)'-A=F4I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?:6YV
M86QI9%1A<VLH)'1A<VLL("1R970L($`D<V%V95LG;F%M92==*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)W5S97-T87-K)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R;VQE<R`]("1T:&ES+3Y?<&%C:V%G
M94EN9F];)W5S97-T87-K)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)')O;&5S6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')O;&5S(#T@87)R87DH)')O;&5S
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D<F]L97,@87,@
M)')O;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D<F]L95LG=&%S:R==(#T@)'1A<VLI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;7-G(#T@)U1H:7,@<&%C:V%G
M92!C;VYT86EN<R!T87-K("(E=&%S:R4B(&%N9"!R97%U:7)E<R`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M8VMA9V4@(B5P86-K86=E)2(@=&\@8F4@=7-E9"<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R;VQE6R=U
M<FDG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"=T87-K)R`]/B`D<F]L95LG=&%S
M:R==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A8VMA9V4G(#T^("1R;VQE6R=U<FDG72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`](&%R<F%Y*"=T87-K)R`]/B`D<F]L95LG=&%S:R==+`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M8VMA9V4G(#T^("1T:&ES+3Y?<&8M/E]R96=I<W1R>2T^#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P87)S9610
M86-K86=E3F%M951O4W1R:6YG*&%R<F%Y*"=P86-K86=E)R`]/@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R;VQE6R=P86-K86=E)UTL("=C:&%N;F5L)R`]/B`D<F]L95LG8VAA;FYE
M;"==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T<G5E*2D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H)U]M=7-T26YS
M=&%L;%1A<VLG+"`G97)R;W(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86US+"`D;7-G*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W5N
M:VYO=VY487-K*"1T87-K+"`D<V%V95LG;F%M92==*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&QI<W1;)VEG;F]R92==*2D@>PT*("`@("`@("`@("`@
M:68@*"$D86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7VEG;F]R94YO=$%L;&]W960H)VEG;F]R92<I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;&ES=%LG:6YS=&%L;"==
M*2D@>PT*("`@("`@("`@("`@:68@*"$D86QL;W=I9VYO<F4I('L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VEG;F]R94YO=$%L;&]W960H)VEN<W1A;&PG
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&QI<W1;)V9I;&4G72DI('L-"B`@("`@("`@("`@(&EF("@D86QL;W=I
M9VYO<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I;&5.;W1!;&QO
M=V5D*"=F:6QE)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1L:7-T6R=D:7(G72DI('L-"B`@("`@("`@("`@(&EF
M("@D86QL;W=I9VYO<F4I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9I
M;&5.;W1!;&QO=V5D*"=D:7(G*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;&ES=%LG9&ER)UU;,%TI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1L:7-T6R=D:7(G72`](&%R<F%Y*"1L
M:7-T6R=D:7(G72D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1L:7-T6R=D:7(G72!A<R`D9&ER*2![#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&ER6R=A='1R:6)S)UTI("8F(&ES
M<V5T*"1D:7);)V%T=')I8G,G75LG;F%M92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1D:7);)V%T=')I8G,G75LG;F%M92==(#T]("<O
M)R!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V-O;G1E;G1S)UU;)V1I<B==6R=D:7(G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!A;'=A>7,@=7-E
M(&YO=&AI;F<@:68@=&AE(&9I;&5L:7-T(&AA<R!A;')E861Y(&)E96X@9FQA
M='1E;F5D#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=V1I<G,@
M/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D9&ER
M<R`]/2`G)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=D
M:7)S(#T@)&1I<ELG871T<FEB<R==6R=N86UE)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N97=D:7)S(#T@)&1I<G,@+B`G+R<@+B`D9&ER6R=A='1R:6)S)UU;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1N97=D:7)S(#T@)&1I<G,[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9&%T949I;&5L:7-T*"1D
M:7(L("1A;&QO=VEG;F]R92P@)&YE=V1I<G,I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U
M;F-T:6]N(%]V86QI9&%T95)E;&5A<V4H*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!H<')E;&5A<V4G72DI('L-
M"B`@("`@("`@("`@("1R96QE87-E(#T@)W!H<')E;&5A<V4G.PT*("`@("`@
M("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W!R;W9I9&5S
M97AT96YS:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C86YN
M;W10<F]V:61E17AT96YS:6]N*"1R96QE87-E*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S
M<F-P86-K86=E)UTI('Q\(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R
M8W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N;F]T2&%V
M95-R8W!A8VMA9V4H)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)')E;&5A<V5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG<&AP<F5L
M96%S92==.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I
M*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULP72DI('L-
M"B`@("`@("`@("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@D<F5L96%S97,I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A
M<V5S(&%S("1R96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T=7!I
M9%-C:&5M859A;&ED871E*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M*FEN<W1A;&QC;VYD:71I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@)RIF
M:6QE;&ES="<L#0H@("`@("`@("`@("`@("`@*2P@)')E;"P@)SQP:'!R96QE
M87-E/B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=E>'1S<F-R96QE87-E)UTI
M*2![#0H@("`@("`@("`@("`D<F5L96%S92`]("=E>'1S<F-R96QE87-E)SL-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG
M<')O=FED97-E>'1E;G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7VUU<W10<F]V:61E17AT96YS:6]N*"1R96QE87-E*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=S<F-P86-K86=E)UTI('Q\(&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN
M9F];)W-R8W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%N
M;F]T2&%V95-R8W!A8VMA9V4H)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)')E;&5A<V5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG
M97AT<W)C<F5L96%S92==.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D
M<F5L96%S97,I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E
M<ULP72DI('L-"B`@("`@("`@("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@D
M<F5L96%S97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C
M:"`H)')E;&5A<V5S(&%S("1R96PI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-T=7!I9%-C:&5M859A;&ED871E*&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G*FEN<W1A;&QC;VYD:71I;VYS)RP-"B`@("`@("`@("`@("`@
M("`@("`@)RIC;VYF:6=U<F5O<'1I;VXM/FYA;64M/G!R;VUP="T^/V1E9F%U
M;'0G+`T*("`@("`@("`@("`@("`@("`@("`G*F)I;F%R>7!A8VMA9V4G+`T*
M("`@("`@("`@("`@("`@("`@("`G*F9I;&5L:7-T)RP-"B`@("`@("`@("`@
M("`@("`I+"`D<F5L+"`G/&5X='-R8W)E;&5A<V4^)RD[#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1R96Q;)V)I;F%R>7!A8VMA9V4G72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L6R=B:6YA<GEP
M86-K86=E)UTI('Q\("%I<W-E="@D<F5L6R=B:6YA<GEP86-K86=E)UU;,%TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5L6R=B:6YA<GEP86-K
M86=E)UT@/2!A<G)A>2@D<F5L6R=B:6YA<GEP86-K86=E)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1R96Q;)V)I;F%R>7!A8VMA9V4G72!A<R`D8FEN*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES7W-T<FEN9R@D8FEN*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8FEN87)Y4&%C:V%G94UU
M<W1"95!A8VMA9V5N86UE*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1T
M:&ES+3Y?<&%C:V%G94EN9F];)V5X=&)I;G)E;&5A<V4G72DI('L-"B`@("`@
M("`@("`@("1R96QE87-E(#T@)V5X=&)I;G)E;&5A<V4G.PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=P<F]V:61E<V5X
M=&5N<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?;75S=%!R
M;W9I9&5%>'1E;G-I;VXH)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YN
M96PG72D@)B8-"B`@("`@("`@("`@("`@("`@("%I<W-E="@D=&AI<RT^7W!A
M8VMA9V5);F9O6R=S<F-P86-K86=E)UTI*2![#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]M=7-T4W)C4&%C:V%G92@D<F5L96%S92D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E26YF
M;ULG=7)I)UTI("8F("%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=S<F-U
M<FDG72DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7VUU<W13<F-U<FDH
M)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E;&5A
M<V5S(#T@)'1H:7,M/E]P86-K86=E26YF;ULG97AT8FEN<F5L96%S92==.PT*
M("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S97,I*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E<ULP72DI('L-"B`@("`@("`@
M("`@("`@("`D<F5L96%S97,@/2!A<G)A>2@D<F5L96%S97,I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5S(&%S("1R
M96PI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T=7!I9%-C:&5M859A
M;&ED871E*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G*FEN<W1A;&QC
M;VYD:71I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@)RIF:6QE;&ES="<L
M#0H@("`@("`@("`@("`@("`@*2P@)')E;"P@)SQE>'1B:6YR96QE87-E/B<I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G72DI('L-"B`@("`@("`@
M("`@("1R96QE87-E(#T@)V)U;F1L92<[#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'1H:7,M/E]P86-K86=E26YF;ULG<')O=FED97-E>'1E;G-I;VXG72DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-A;FYO=%!R;W9I9&5%>'1E
M;G-I;VXH)')E;&5A<V4I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G94EN9F];)W-R8W!A8VMA9V4G72D@
M?'P@:7-S970H)'1H:7,M/E]P86-K86=E26YF;ULG<W)C=7)I)UTI*2![#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C86YN;W1(879E4W)C<&%C:V%G92@D
M<F5L96%S92D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5L96%S
M97,@/2`D=&AI<RT^7W!A8VMA9V5);F9O6R=B=6YD;&4G73L-"B`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)')E;&5A<V5S*2!\?"`A:7-S970H)')E;&5A
M<V5S6S!=*2D@>PT*("`@("`@("`@("`@("`@("1R96QE87-E<R`](&%R<F%Y
M*"1R96QE87-E<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D<F5L96%S97,@87,@)')E;"D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1U<&ED4V-H96UA5F%L:61A=&4H87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("<J:6YS=&%L;&-O;F1I=&EO;G,G+`T*("`@("`@("`@("`@
M("`@("`@("`G*F9I;&5L:7-T)RP-"B`@("`@("`@("`@("`@("`I+"`D<F5L
M+"`G/&)U;F1L93XG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D<F5L96%S97,@87,@)')E;"D@>PT*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1R96PI("8F(&%R<F%Y7VME>5]E>&ES=',H)VEN
M<W1A;&QC;VYD:71I;VYS)RP@)')E;"DI('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W9A;&ED871E26YS=&%L;$-O;F1I=&EO;G,H)')E;%LG:6YS=&%L
M;&-O;F1I=&EO;G,G72P-"B`@("`@("`@("`@("`@("`@("`@(CPD<F5L96%S
M93X\:6YS=&%L;&-O;F1I=&EO;G,^(BD[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-?87)R87DH)')E;"D@)B8@87)R87E?:V5Y7V5X:7-T
M<R@G9FEL96QI<W0G+"`D<F5L*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<F5L6R=F:6QE;&ES="==*2![#0H@("`@("`@("`@("`@("`@("`@(`T*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W9A;&ED871E1FEL96QI<W0H)')E
M;%LG9FEL96QI<W0G72P@=')U92D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@5&AI<R!I<R!H97)E('1O(&%L;&]W(')O;&4@97AT96YS:6]N('1H<F]U
M9V@@<&QU9VEN<PT*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!?=F%L:61A=&52;VQE*"1R;VQE*0T*("`@('L-"B`@("`@
M("`@<F5T=7)N(&EN7V%R<F%Y*"1R;VQE+"!014%27TEN<W1A;&QE<E]2;VQE
M.CIG971686QI9%)O;&5S*"1T:&ES+3Y?<&8M/F=E=%!A8VMA9V54>7!E*"DI
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?:6YV86QI9%1A9T]R9&5R*"1O
M:W1A9W,L("1A8W1U86PL("1R;V]T*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L#0H@("`@("`@
M("`@("!A<G)A>2@G;VMT86=S)R`]/B`D;VMT86=S+"`G86-T=6%L)R`]/B`D
M86-T=6%L+"`G<F]O="<@/3X@)')O;W0I+`T*("`@("`@("`@("`@)TEN=F%L
M:60@=&%G(&]R9&5R(&EN("5R;V]T)2P@9F]U;F0@/"5A8W1U86PE/B!E>'!E
M8W1E9"!O;F4@;V8@(B5O:W1A9W,E(B<I.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(%]I9VYO<F5.;W1!;&QO=V5D*"1T>7!E*0T*("`@('L-"B`@("`@("`@
M)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R
M<F%Y*"=T>7!E)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G/"5T>7!E)3X@
M:7,@;F]T(&%L;&]W960@:6YS:61E(&=L;V)A;"`\8V]N=&5N=',^+"!O;FQY
M(&EN<VED92`G("X-"B`@("`@("`@("`@("<\<&AP<F5L96%S93XO/&5X=&)I
M;G)E;&5A<V4^+"!U<V4@/&1I<CX@86YD(#QF:6QE/B!O;FQY)RD[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@7V9I;&5.;W1!;&QO=V5D*"1T>7!E*0T*("`@
M('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L
M("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D='EP92DL#0H@("`@("`@("`@
M("`G/"5T>7!E)3X@:7,@;F]T(&%L;&]W960@:6YS:61E(')E;&5A<V4@/&9I
M;&5L:7-T/BP@;VYL>2!I;G-I9&4@)R`N#0H@("`@("`@("`@("`G/&-O;G1E
M;G1S/BP@=7-E(#QI9VYO<F4^(&%N9"`\:6YS=&%L;#X@;VYL>2<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]T86=-:7-S:6YG071T<FEB=71E*"1T86<L
M("1A='1R+"`D8V]N=&5X="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A
M8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]
M/B`D=&%G+`T*("`@("`@("`@("`@)V%T=')I8G5T92<@/3X@)&%T='(L("=C
M;VYT97AT)R`]/B`D8V]N=&5X="DL#0H@("`@("`@("`@("`G=&%G(#PE=&%G
M)3X@:6X@8V]N=&5X="`B)6-O;G1E>'0E(B!H87,@;F\@871T<FEB=71E("(E
M871T<FEB=71E)2(G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=&%G2&%S
M3F]!='1R:6)S*"1T86<L("1C;VYT97AT*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y
M*"=T86<G(#T^("1T86<L#0H@("`@("`@("`@("`G8V]N=&5X="<@/3X@)&-O
M;G1E>'0I+`T*("`@("`@("`@("`@)W1A9R`\)71A9R4^(&AA<R!N;R!A='1R
M:6)U=&5S(&EN(&-O;G1E>'0@(B5C;VYT97AT)2(G*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?:6YV86QI9$EN=&5R;F%L4W1R=6-T=7)E*"D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97AC97!T:6]N)RP@87)R87DH*2P-"B`@("`@("`@("`@("=I;G1E<FYA;"!A
M<G)A>2!W87,@;F]T(&=E;F5R871E9"!B>2!C;VUP871I8FQE('!A<G-E<BP@
M;W(@97AT<F5M92!P87)S97(@97)R;W(L(&-A;FYO="!C;VYT:6YU92<I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED1FEL95)O;&4H)&9I;&4L
M("1D:7(L("1R;VQE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*`T*("`@("`@("`@
M("`@)V9I;&4G(#T^("1F:6QE+"`G9&ER)R`]/B`D9&ER+"`G<F]L92<@/3X@
M)')O;&4L#0H@("`@("`@("`@("`G<F]L97,G(#T^(%!%05)?26YS=&%L;&5R
M7U)O;&4Z.F=E=%9A;&ED4F]L97,H)'1H:7,M/E]P9BT^9V5T4&%C:V%G951Y
M<&4H*2DI+`T*("`@("`@("`@("`@)T9I;&4@(B5F:6QE)2(@:6X@9&ER96-T
M;W)Y("(E9&ER)2(@:&%S(&EN=F%L:60@<F]L92`B)7)O;&4E(BP@<VAO=6QD
M(&)E(&]N92!O9B`E<F]L97,E)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7VEN=F%L:61&:6QE3F%M92@D9FEL92P@)&1I<BD-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A
M<G)A>2@-"B`@("`@("`@("`@("=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@
M("`@("`G1FEL92`B)69I;&4E(B!C86YN;W0@8F5G:6X@=VET:"`B+B(G*3L-
M"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9FEL96QI<W1#86YN;W1#;VYT86EN
M1FEL92@D9FEL96QI<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1A9R<@/3X@
M)&9I;&5L:7-T*2P-"B`@("`@("`@("`@("<\)71A9R4^(&-A;B!O;FQY(&-O
M;G1A:6X@/&1I<CXL(&-O;G1A:6YS(#QF:6QE/BX@(%5S92`G("X-"B`@("`@
M("`@("`@("<\9&ER(&YA;64](B\B/B!A<R!T:&4@9FER<W0@9&ER(&5L96UE
M;G0G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9FEL96QI<W1-=7-T0V]N
M=&%I;D1I<B@D9FEL96QI<W0I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1A9R<@
M/3X@)&9I;&5L:7-T*2P-"B`@("`@("`@("`@("<\)71A9R4^(&UU<W0@8V]N
M=&%I;B`\9&ER/BX@(%5S92`\9&ER(&YA;64](B\B/B!A<R!T:&4@)R`N#0H@
M("`@("`@("`@("`G9FER<W0@9&ER(&5L96UE;G0G*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?=&%G0V%N;F]T0F5%;7!T>2@D=&%G*0T*("`@('L-"B`@
M("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O
M<B<L(&%R<F%Y*"=T86<G(#T^("1T86<I+`T*("`@("`@("`@("`@)SPE=&%G
M)3X@8V%N;F]T(&)E(&5M<'1Y("@\)71A9R4O/BDG*3L-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!?57)L3W)#:&%N;F5L*"1T>7!E+"`D;F%M92D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L#0H@("`@("`@("`@("`G
M;F%M92<@/3X@)&YA;64I+`T*("`@("`@("`@("`@)U)E<75I<F5D(&1E<&5N
M9&5N8WD@/"5T>7!E)3X@(B5N86UE)2(@8V%N(&AA=F4@96ET:&5R('5R;"!/
M4B`G("X-"B`@("`@("`@("`@("=C:&%N;F5L(&%T=')I8G5T97,L(&%N9"!N
M;W0@8F]T:"<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%].;T-H86YN96PH
M)'1Y<&4L("1N86UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T>7!E)R`]/B`D
M='EP92P-"B`@("`@("`@("`@("=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@
M("`@("`G4F5Q=6ER960@9&5P96YD96YC>2`\)71Y<&4E/B`B)6YA;64E(B!M
M=7-T(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C:&%N
M;F5L(&%T=')I8G5T97,G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?57)L
M3W)#:&%N;F5L1W)O=7`H)'1Y<&4L("1N86UE+"`D9W)O=7`I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH)W1Y<&4G(#T^("1T>7!E+`T*("`@("`@("`@("`@)VYA
M;64G(#T^("1N86UE+"`G9W)O=7`G(#T^("1G<F]U<"DL#0H@("`@("`@("`@
M("`G1W)O=7`@(B5G<F]U<"4B(&1E<&5N9&5N8WD@/"5T>7!E)3X@(B5N86UE
M)2(@8V%N(&AA=F4@96ET:&5R('5R;"!/4B`G("X-"B`@("`@("`@("`@("=C
M:&%N;F5L(&%T=')I8G5T97,L(&%N9"!N;W0@8F]T:"<I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%].;T-H86YN96Q'<F]U<"@D='EP92P@)&YA;64L("1G
M<F]U<"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&
M54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L#0H@
M("`@("`@("`@("`G;F%M92<@/3X@)&YA;64L("=G<F]U<"<@/3X@)&=R;W5P
M*2P-"B`@("`@("`@("`@("='<F]U<"`B)6=R;W5P)2(@9&5P96YD96YC>2`\
M)71Y<&4E/B`B)6YA;64E(B!M=7-T(&AA=F4@96ET:&5R('5R;"!/4B`G("X-
M"B`@("`@("`@("`@("=C:&%N;F5L(&%T=')I8G5T97,G*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?=6YK;F]W;D-H86YN96PH)&-H86YN96PI#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@
M)V5R<F]R)RP@87)R87DH)V-H86YN96PG(#T^("1C:&%N;F5L*2P-"B`@("`@
M("`@("`@("=5;FMN;W=N(&-H86YN96P@(B5C:&%N;F5L)2(G*3L-"B`@("!]
M#0H-"B`@("!F=6YC=&EO;B!?;F]086-K86=E5F5R<VEO;B@I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH*2P-"B`@("`@("`@("`@("=P86-K86=E+GAM;"`\<&%C
M:V%G93X@=&%G(&AA<R!N;R!V97)S:6]N(&%T=')I8G5T92P@;W(@=F5R<VEO
M;B!I<R!N;W0@,BXP)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7TYO0G5N
M9&QE9%!A8VMA9V5S*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM
M/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@I+`T*("`@("`@
M("`@("`@)TYO(#QB=6YD;&5D<&%C:V%G93X@=&%G('=A<R!F;W5N9"!I;B`\
M8V]N=&5N=',^+"!R97%U:7)E9"!F;W(@8G5N9&QE('!A8VMA9V5S)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7T%T3&5A<W0R0G5N9&QE9%!A8VMA9V5S
M*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)T%T(&QE
M87-T(#(@<&%C:V%G97,@;75S="!B92!B=6YD;&5D(&EN(&$@8G5N9&QE('!A
M8VMA9V4G*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?0VAA;FYE;$]R57)I
M*"1N86UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=N86UE)R`]/B`D;F%M92DL
M#0H@("`@("`@("`@("`G0G5N9&QE9"!P86-K86=E("(E;F%M924B(&-A;B!H
M879E(&5I=&AE<B!A('5R:2!O<B!A(&-H86YN96PL(&YO="!B;W1H)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7VYO0VAI;&1486<H)&-H:6QD+"`D=&%G
M*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-4
M24].7U\L("=E<G)O<B<L(&%R<F%Y*"=C:&EL9"<@/3X@)&-H:6QD+"`G=&%G
M)R`]/B`D=&%G*2P-"B`@("`@("`@("`@("=486<@/"5T86<E/B!I<R!M:7-S
M:6YG(&-H:6QD('1A9R`\)6-H:6QD)3XG*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?:6YV86QI9%9E<G-I;VXH)'1Y<&4L("1V86QU92D-"B`@("![#0H@
M("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R
M;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4L("=V86QU92<@/3X@)'9A;'5E
M*2P-"B`@("`@("`@("`@("=697)S:6]N('1Y<&4@/"5T>7!E)3X@:7,@;F]T
M(&$@=F%L:60@=F5R<VEO;B`H)79A;'5E)2DG*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?:6YV86QI9%-T871E*"1T>7!E+"`D=F%L=64I#0H@("`@>PT*
M("`@("`@("`D<W1A=&5S(#T@87)R87DH)W-T86)L92<L("=B971A)RP@)V%L
M<&AA)RP@)V1E=F5L)RD[#0H@("`@("`@(&EF("@D='EP92`A/2`G87!I)RD@
M>PT*("`@("`@("`@("`@)'-T871E<UM=(#T@)W-N87!S:&]T)SL-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H<W1R=&]L;W=E<B@D=F%L=64I(#T]("=R8R<I
M('L-"B`@("`@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/
M3E]?+"`G97)R;W(G+`T*("`@("`@("`@("`@("`@(&%R<F%Y*"=V97)S:6]N
M)R`]/B`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UU;)W)E;&5A<V4G
M72DL#0H@("`@("`@("`@("`@("`@)U)#(&ES(&YO="!A('-T871E+"!I="!I
M<R!A('9E<G-I;VX@<&]S=&9I>"P@=')Y("5V97)S:6]N)5)#,2P@<W1A8FEL
M:71Y(&)E=&$G*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G(#T^
M("1T>7!E+"`G=F%L=64G(#T^("1V86QU92P-"B`@("`@("`@("`@("=T>7!E
M<R<@/3X@)'-T871E<RDL#0H@("`@("`@("`@("`G4W1A8FEL:71Y('1Y<&4@
M/"5T>7!E)3X@:7,@;F]T(&$@=F%L:60@<W1A8FEL:71Y("@E=F%L=64E*2P@
M;75S="!B92!O;F4@;V8@)R`N#0H@("`@("`@("`@("`G)71Y<&5S)2<I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED5&%S:R@D=&%S:RP@)')E
M="P@)&9I;&4I#0H@("`@>PT*("`@("`@("!S=VET8V@@*"1R971;,%TI('L-
M"B`@("`@("`@("`@(&-A<V4@4$5!4E]405-+7T524D]27TU)4U-)3D=?0514
M4DE"(#H-"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=A='1R:6(G
M(#T^("1R971;,5TL("=T87-K)R`]/B`D=&%S:RP@)V9I;&4G(#T^("1F:6QE
M*3L-"B`@("`@("`@("`@("`@("`D;7-G(#T@)W1A<VL@/"5T87-K)3X@:7,@
M;6ES<VEN9R!A='1R:6)U=&4@(B5A='1R:6(E(B!I;B!F:6QE("5F:6QE)2<[
M#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@4$5!4E]4
M05-+7T524D]27TY/05144DE"4R`Z#0H@("`@("`@("`@("`@("`@)&EN9F\@
M/2!A<G)A>2@G=&%S:R<@/3X@)'1A<VLL("=F:6QE)R`]/B`D9FEL92D[#0H@
M("`@("`@("`@("`@("`@)&US9R`]("=T87-K(#PE=&%S:R4^(&AA<R!N;R!A
M='1R:6)U=&5S(&EN(&9I;&4@)69I;&4E)SL-"B`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92!014%27U1!4TM?15)23U)?5U)/3D=?0514
M4DE"7U9!3%5%(#H-"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R<F%Y*"=A
M='1R:6(G(#T^("1R971;,5TL("=V86QU97,G(#T^("1R971;,UTL#0H@("`@
M("`@("`@("`@("`@("`@("=W87,G(#T^("1R971;,ETL("=T87-K)R`]/B`D
M=&%S:RP@)V9I;&4G(#T^("1F:6QE*3L-"B`@("`@("`@("`@("`@("`D;7-G
M(#T@)W1A<VL@/"5T87-K)3X@871T<FEB=71E("(E871T<FEB)2(@:&%S('1H
M92!W<F]N9R!V86QU92`B)7=A<R4B("<N#0H@("`@("`@("`@("`@("`@("`@
M("=I;B!F:6QE("5F:6QE)2P@97AP96-T:6YG(&]N92!O9B`B)79A;'5E<R4B
M)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!014%2
M7U1!4TM?15)23U)?24Y604Q)1"`Z#0H@("`@("`@("`@("`@("`@)&EN9F\@
M/2!A<G)A>2@G<F5A<V]N)R`]/B`D<F5T6S%=+"`G=&%S:R<@/3X@)'1A<VLL
M("=F:6QE)R`]/B`D9FEL92D[#0H@("`@("`@("`@("`@("`@)&US9R`]("=T
M87-K(#PE=&%S:R4^(&EN(&9I;&4@)69I;&4E(&ES(&EN=F%L:60@8F5C875S
M92!O9B`B)7)E87-O;B4B)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?
M+"`G97)R;W(G+"`D:6YF;RP@)&US9RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7W5N:VYO=VY487-K*"1T87-K+"`D9FEL92D-"B`@("![#0H@("`@("`@
M("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A
M<G)A>2@G=&%S:R<@/3X@)'1A<VLL("=F:6QE)R`]/B`D9FEL92DL#0H@("`@
M("`@("`@("`G56YK;F]W;B!T87-K("(E=&%S:R4B('!A<W-E9"!I;B!F:6QE
M(#QF:6QE(&YA;64](B5F:6QE)2(^)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@7W-U8G!A8VMA9V5#86YN;W10<F]V:61E17AT96YS:6]N*"1N86UE*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=N86UE)R`]/B`D;F%M92DL#0H@("`@("`@
M("`@("`G4W5B<&%C:V%G92!D97!E;F1E;F-Y("(E;F%M924B(&-A;FYO="!U
M<V4@/'!R;W9I9&5S97AT96YS:6]N/BP@)R`N#0H@("`@("`@("`@("`G;VYL
M>2!P86-K86=E(&1E<&5N9&5N8VEE<R!C86X@=7-E('1H:7,@=&%G)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7W-U8G!A8VMA9V5S0V%N;F]T0V]N9FQI
M8W0H)&YA;64I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H
M*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)VYA;64G(#T^("1N86UE
M*2P-"B`@("`@("`@("`@("=3=6)P86-K86=E(&1E<&5N9&5N8WD@(B5N86UE
M)2(@8V%N;F]T('5S92`\8V]N9FQI8W1S+SXL("<@+@T*("`@("`@("`@("`@
M)V]N;'D@<&%C:V%G92!D97!E;F1E;F-I97,@8V%N('5S92!T:&ES('1A9R<I
M.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C86YN;W10<F]V:61E17AT96YS
M:6]N*"1R96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]
M/B`D<F5L96%S92DL#0H@("`@("`@("`@("`G/"5R96QE87-E)3X@<&%C:V%G
M97,@8V%N;F]T('5S92`\<')O=FED97-E>'1E;G-I;VX^+"!O;FQY(&5X=&)I
M;G)E;&5A<V4@86YD(&5X='-R8W)E;&5A<V4@8V%N('!R;W9I9&4@82!02%`@
M97AT96YS:6]N)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VUU<W10<F]V
M:61E17AT96YS:6]N*"1R96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R
M96QE87-E)R`]/B`D<F5L96%S92DL#0H@("`@("`@("`@("`G/"5R96QE87-E
M)3X@<&%C:V%G97,@;75S="!U<V4@/'!R;W9I9&5S97AT96YS:6]N/B!T;R!I
M;F1I8V%T92!W:&EC:"!02%`@97AT96YS:6]N(&ES('!R;W9I9&5D)RD[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@7V-A;FYO=$AA=F53<F-P86-K86=E*"1R
M96QE87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?
M7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L
M96%S92DL#0H@("`@("`@("`@("`G/"5R96QE87-E)3X@<&%C:V%G97,@8V%N
M;F]T('-P96-I9GD@82!S;W5R8V4@8V]D92!P86-K86=E+"!O;FQY(&5X=&5N
M<VEO;B!B:6YA<FEE<R!M87D@=7-E('1H92`\<W)C<&%C:V%G93X@=&%G)RD[
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7VUU<W13<F-086-K86=E*"1R96QE
M87-E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=R96QE87-E)R`]/B`D<F5L96%S
M92DL#0H@("`@("`@("`@("`G/&5X=&)I;G)E;&5A<V4^('!A8VMA9V5S(&UU
M<W0@<W!E8VEF>2!A('-O=7)C92!C;V1E('!A8VMA9V4@=VET:"`\<W)C<&%C
M:V%G93XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?;75S=%-R8W5R:2@D
M<F5L96%S92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H
M7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G<F5L96%S92<@/3X@)')E
M;&5A<V4I+`T*("`@("`@("`@("`@)SQE>'1B:6YR96QE87-E/B!P86-K86=E
M<R!M=7-T('-P96-I9GD@82!S;W5R8V4@8V]D92!P86-K86=E('=I=&@@/'-R
M8W5R:3XG*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?=7)I1&5P<T-A;FYO
M=$AA=F5697)S:6]N:6YG*"1T>7!E*0T*("`@('L-"B`@("`@("`@)'1H:7,M
M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=T
M>7!E)R`]/B`D='EP92DL#0H@("`@("`@("`@("`G)71Y<&4E.B!D97!E;F1E
M;F-I97,@=VET:"!A(#QU<FD^('1A9R!C86YN;W0@:&%V92!A;GD@=F5R<VEO
M;FEN9R!I;F9O<FUA=&EO;B<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]C
M;VYF;&EC=&EN9T1E<'-#86YN;W1(879E5F5R<VEO;FEN9R@D='EP92D-"B`@
M("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?
M+"`G97)R;W(G+"!A<G)A>2@G='EP92<@/3X@)'1Y<&4I+`T*("`@("`@("`@
M("`@)R5T>7!E)3H@8V]N9FQI8W1I;F<@9&5P96YD96YC:65S(&-A;FYO="!H
M879E('9E<G-I;VYI;F<@:6YF;RP@=7-E(#QE>&-L=61E/B!T;R`G("X-"B`@
M("`@("`@("`@("=E>&-L=61E('-P96-I9FEC('9E<G-I;VYS(&]F(&$@9&5P
M96YD96YC>2<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]$97!C:&%N;F5L
M0V%N;F]T0F55<FDH)'1Y<&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T
M86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W1Y<&4G
M(#T^("1T>7!E*2P-"B`@("`@("`@("`@("<E='EP924Z(&-H86YN96P@8V%N
M;F]T(&)E(%]?=7)I+"!T:&ES(&ES(&$@<'-E=61O+6-H86YN96P@<F5S97)V
M960@9F]R('5R:2`G("X-"B`@("`@("`@("`@("=D97!E;F1E;F-I97,@;VYL
M>2<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]B=6YD;&5D4&%C:V%G97--
M=7-T0F5&:6QE;F%M92@I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH*2P-"B`@("`@
M("`@("`@("<\8G5N9&QE9'!A8VMA9V4^('1A9W,@;75S="!C;VYT86EN(&]N
M;'D@=&AE(&9I;&5N86UE(&]F(&$@<&%C:V%G92!R96QE87-E("<@+@T*("`@
M("`@("`@("`@)VEN('1H92!B=6YD;&4G*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?8FEN87)Y4&%C:V%G94UU<W1"95!A8VMA9V5N86UE*"D-"B`@("![
M#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G
M97)R;W(G+"!A<G)A>2@I+`T*("`@("`@("`@("`@)SQB:6YA<GEP86-K86=E
M/B!T86=S(&UU<W0@8V]N=&%I;B!T:&4@;F%M92!O9B!A('!A8VMA9V4@=&AA
M="!I<R`G("X-"B`@("`@("`@("`@("=A(&-O;7!I;&5D('9E<G-I;VX@;V8@
M=&AI<R!E>'1S<F,@<&%C:V%G92<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M(%]F:6QE3F]T1F]U;F0H)&9I;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I
M;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@("=&:6QE("(E9FEL924B(&EN
M('!A8VMA9V4N>&UL(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@7VYO=$EN0V]N=&5N=',H)&9I;&4L("1T86<I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH)V9I;&4G(#T^("1F:6QE+"`G=&%G)R`]/B`D=&%G*2P-
M"B`@("`@("`@("`@("<\)71A9R4@;F%M93TB)69I;&4E(CX@:7,@:6YV86QI
M9"P@9FEL92!I<R!N;W0@:6X@/&-O;G1E;G1S/B<I.PT*("`@('T-"@T*("`@
M(&9U;F-T:6]N(%]C86YN;W1686QI9&%T94YO4&%T:%-E="@I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R
M<F]R)RP@87)R87DH*2P-"B`@("`@("`@("`@("=#86YN;W0@=F%L:61A=&4@
M9FEL97,L(&YO('!A=&@@=&\@<&%C:V%G92!F:6QE(&ES('-E="`H=7-E('-E
M=%!A8VMA9V5&:6QE*"DI)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7W5S
M97-R;VQE=&%S:TUU<W1(879E0VAA;FYE;$]R57)I*"1R;VQE+"`D=&%G*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].
M7U\L("=E<G)O<B<L(&%R<F%Y*"=R;VQE)R`]/B`D<F]L92P@)W1A9R<@/3X@
M)'1A9RDL#0H@("`@("`@("`@("`G/"5T86<E/B!M=7-T(&-O;G1A:6X@96ET
M:&5R(#QU<FD^+"!O<B`\8VAA;FYE;#X@86YD(#QP86-K86=E/B<I.PT*("`@
M('T-"@T*("`@(&9U;F-T:6]N(%]U<V5S<F]L971A<VM-=7-T2&%V95!A8VMA
M9V4H)')O;&4L("1T86<I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W-T86-K
M+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)W)O;&4G(#T^
M("1R;VQE+"`G=&%G)R`]/B`D=&%G*2P-"B`@("`@("`@("`@("<\)71A9R4^
M(&UU<W0@8V]N=&%I;B`\<&%C:V%G93XG*3L-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?=7-E<W)O;&5T87-K375S=$AA=F52;VQE5&%S:R@D=&%G+"`D='EP
M92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#
M5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D=&%G+"`G='EP92<@
M/3X@)'1Y<&4I+`T*("`@("`@("`@("`@)SPE=&%G)3X@;75S="!C;VYT86EN
M(#PE='EP924^(&1E9FEN:6YG('1H92`E='EP924@=&\@8F4@=7-E9"<I.PT*
M("`@('T-"@T*("`@(&9U;F-T:6]N(%]C86YN;W1#;VYF;&EC=%=I=&A!;&Q/
M<R@D='EP92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H
M7U]&54Y#5$E/3E]?+"`G97)R;W(G+"!A<G)A>2@G=&%G)R`]/B`D=&%G*2P-
M"B`@("`@("`@("`@("<E=&%G)2!C86YN;W0@8V]N9FQI8W0@=VET:"!A;&P@
M3U-E<R<I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]I;G9A;&ED1&5P1W)O
M=7!.86UE*"1N86UE*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]S=&%C:RT^
M<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y*"=G<F]U<"<@/3X@
M)&YA;64I+`T*("`@("`@("`@("`@)TEN=F%L:60@9&5P96YD96YC>2!G<F]U
M<"!N86UE("(E;F%M924B)RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V%N
M86QY>F5"=6YD;&5D4&%C:V%G97,H*0T*("`@('L-"B`@("`@("`@:68@*"$D
M=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21T:&ES+3Y?<&8M/F=E=%!A8VMA
M9V54>7!E*"D@/3T@)V)U;F1L92<I('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?
M<&8M/E]P86-K86=E1FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@?0T*("`@("`@("`D9&ER7W!R969I>"`](&1I<FYA;64H
M)'1H:7,M/E]P9BT^7W!A8VMA9V5&:6QE*3L-"B`@("`@("`@)&QO9R`](&ES
M<V5T*"1T:&ES+3Y?<&8M/E]L;V=G97(I(#\@87)R87DH)B1T:&ES+3Y?<&8M
M/E]L;V=G97(L("=L;V<G*2`Z#0H@("`@("`@("`@("!A<G)A>2@G4$5!4E]#
M;VUM;VXG+"`G;&]G)RD[#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]P9BT^
M9V5T0V]N=&5N=',H*3L-"B`@("`@("`@)&EN9F\@/2`D:6YF;ULG8G5N9&QE
M9'!A8VMA9V4G73L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:6YF;RDI('L-
M"B`@("`@("`@("`@("1I;F9O(#T@87)R87DH)&EN9F\I.PT*("`@("`@("!]
M#0H@("`@("`@("1P:V<@/2`F;F5W(%!%05)?4&%C:V%G949I;&4H)'1H:7,M
M/E]P9BT^7V-O;F9I9RD[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O(&%S("1P
M86-K86=E*2![#0H@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D:7)?
M<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1P86-K86=E*2D@>PT*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9FEL94YO=$9O=6YD*"1D:7)?<')E
M9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1P86-K86=E*3L-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VES5F%L:60@/2`P.PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@8V%L
M;%]U<V5R7V9U;F-?87)R87DH)&QO9RP@87)R87DH,2P@(D%N86QY>FEN9R!B
M=6YD;&5D('!A8VMA9V4@)'!A8VMA9V4B*2D[#0H@("`@("`@("`@("!014%2
M.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@
M("`@("`@("`D<F5T(#T@)'!K9RT^9G)O;4%N>49I;&4H)&1I<E]P<F5F:7@@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!A8VMA9V4L#0H@("`@("`@("`@
M("`@("`@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("`@("`@4$5!
M4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?
M9G5N8U]A<G)A>2@D;&]G+"!A<G)A>2@P+"`B15)23U(Z('!A8VMA9V4@)'!A
M8VMA9V4@:7,@;F]T(&$@=F%L:60@(B`N#0H@("`@("`@("`@("`@("`@("`@
M("=P86-K86=E)RDI.PT*("`@("`@("`@("`@("`@("1I;F8@/2`D<F5T+3YG
M9715<V5R26YF;R@I.PT*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M:6YF*2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D:6YF(&%S
M("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-A;&Q?=7-E<E]F
M=6YC7V%R<F%Y*"1L;V<L(&%R<F%Y*#$L("1E<G);)VUE<W-A9V4G72DI.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?86YA;'EZ95!H<$9I;&5S*"D-"B`@("![#0H@("`@("`@(&EF
M("@A)'1H:7,M/E]I<U9A;&ED*2![#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7W!F
M+3Y?<&%C:V%G949I;&4I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V-A;FYO
M=%9A;&ED871E3F]0871H4V5T*"D[#0H@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@('T-"B`@("`@("`@)&1I<E]P<F5F:7@@/2!D:7)N86UE
M*"1T:&ES+3Y?<&8M/E]P86-K86=E1FEL92D[#0H@("`@("`@("1C;VUM;VX@
M/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1L;V<@/2!I<W-E="@D=&AI
M<RT^7W!F+3Y?;&]G9V5R*2`_(&%R<F%Y*"8D=&AI<RT^7W!F+3Y?;&]G9V5R
M+"`G;&]G)RD@.@T*("`@("`@("`@("`@87)R87DH)B1C;VUM;VXL("=L;V<G
M*3L-"B`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W!F+3YG971#;VYT96YT<R@I
M.PT*("`@("`@("`D:6YF;R`]("1I;F9O6R=D:7(G75LG9FEL92==.PT*("`@
M("`@("!I9B`H:7-S970H)&EN9F];)V%T=')I8G,G72DI('L-"B`@("`@("`@
M("`@("1I;F9O(#T@87)R87DH)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@
M("1P<F]V:61E<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O
M(&%S("1F82D@>PT*("`@("`@("`@("`@)&9A(#T@)&9A6R=A='1R:6)S)UT[
M#0H@("`@("`@("`@("`D9FEL92`]("1F85LG;F%M92==.PT*("`@("`@("`@
M("`@:68@*"%F:6QE7V5X:7-T<R@D9&ER7W!R969I>"`N($1)4D5#5$]265]3
M15!!4D%43U(@+B`D9FEL92DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V9I;&5.;W1&;W5N9"@D9&ER7W!R969I>"`N($1)4D5#5$]265]315!!4D%4
M3U(@+B`D9FEL92D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]I<U9A;&ED
M(#T@,#L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D9F%;)W)O;&4G72P@4$5!
M4E]);G-T86QL97)?4F]L93HZ9V5T4&AP4F]L97,H*2D@)B8@)&1I<E]P<F5F
M:7@I('L-"B`@("`@("`@("`@("`@("!C86QL7W5S97)?9G5N8U]A<G)A>2@D
M;&]G+"!A<G)A>2@Q+"`B06YA;'EZ:6YG("1F:6QE(BDI.PT*("`@("`@("`@
M("`@("`@("1S<F-I;F9O(#T@)'1H:7,M/F%N86QY>F53;W5R8V5#;V1E*"1D
M:7)?<')E9FEX("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE*3L-"B`@
M("`@("`@("`@("`@("!I9B`H)'-R8VEN9F\I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'!R;W9I9&5S(#T@87)R87E?;65R9V4H)'!R;W9I9&5S+"`D=&AI
M<RT^7V)U:6QD4')O=FED97-!<G)A>2@D<W)C:6YF;RDI.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7W!A8VMA9V5.86UE(#T@)'!N(#T@)'1H:7,M/E]P9BT^9V5T4&%C
M:V%G92@I.PT*("`@("`@("`D<&YL(#T@<W1R;&5N*"1P;BD[#0H@("`@("`@
M(&9O<F5A8V@@*"1P<F]V:61E<R!A<R`D:V5Y(#T^("1W:&%T*2![#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'=H871;)V5X<&QI8VET)UTI('Q\("$D=VAA
M="D@>PT*("`@("`@("`@("`@("`@("\O('-K:7`@8V]N9F]R;6%N8V4@8VAE
M8VMS(&EF('1H92!P<F]V:61E<R!E;G1R>2!I<PT*("`@("`@("`@("`@("`@
M("\O('-P96-I9FEE9"!I;B!T:&4@<&%C:V%G92YX;6P@9FEL90T*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@97AT<F%C="@D=VAA="D[#0H@("`@("`@("`@("!I9B`H)'1Y<&4@/3T@
M)V-L87-S)RD@>PT*("`@("`@("`@("`@("`@(&EF("@A<W1R;F-A<V5C;7`H
M)&YA;64L("1P;BP@)'!N;"DI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N
M=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN9R<L#0H@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92P@)W1Y
M<&4G(#T^("1T>7!E+"`G;F%M92<@/3X@)&YA;64L("=P86-K86=E)R`]/B`D
M<&XI+`T*("`@("`@("`@("`@("`@("`@("`G:6X@)69I;&4E.B`E='EP924@
M(B5N86UE)2(@;F]T('!R969I>&5D('=I=&@@<&%C:V%G92!N86UE("(E<&%C
M:V%G924B)RD[#0H@("`@("`@("`@("!](&5L<V5I9B`H)'1Y<&4@/3T@)V9U
M;F-T:6]N)RD@>PT*("`@("`@("`@("`@("`@(&EF("AS=')S='(H)&YA;64L
M("<Z.B<I('Q\("%S=')N8V%S96-M<"@D;F%M92P@)'!N+"`D<&YL*2D@>PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%C:RT^<'5S:"A?7T95
M3D-424].7U\L("=W87)N:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@87)R
M87DH)V9I;&4G(#T^("1F:6QE+"`G='EP92<@/3X@)'1Y<&4L("=N86UE)R`]
M/B`D;F%M92P@)W!A8VMA9V4G(#T^("1P;BDL#0H@("`@("`@("`@("`@("`@
M("`@("=I;B`E9FEL924Z("5T>7!E)2`B)6YA;64E(B!N;W0@<')E9FEX960@
M=VET:"!P86-K86=E(&YA;64@(B5P86-K86=E)2(G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]I<U9A;&ED
M.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($%N86QY>F4@=&AE('-O=7)C
M92!C;V1E(&]F('1H92!G:79E;B!02%`@9FEL90T*("`@("`J#0H@("`@("H@
M0'!A<F%M("!S=')I;F<@1FEL96YA;64@;V8@=&AE(%!(4"!F:6QE#0H@("`@
M("H@0'!A<F%M("!B;V]L96%N('=H971H97(@=&\@86YA;'EZ92`D9FEL92!A
M<R!T:&4@9FEL92!C;VYT96YT<PT*("`@("`J($!R971U<FX@;6EX960-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!A;F%L>7IE4V]U<F-E0V]D92@D9FEL92P@
M)'-T<FEN9R`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%F=6YC=&EO
M;E]E>&ES=',H(G1O:V5N7V=E=%]A;&PB*2D@>PT*("`@("`@("`@("`@)'1H
M:7,M/E]S=&%C:RT^<'5S:"A?7T953D-424].7U\L("=E<G)O<B<L(&%R<F%Y
M*"=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`@("`@)U!A<G-E<B!E
M<G)O<CH@=&]K96Y?9V5T7V%L;"@I(&9U;F-T:6]N(&UU<W0@97AI<W0@=&\@
M86YA;'EZ92!S;W5R8V4@8V]D92<I.PT*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F:6YE9"@G5%]$3T-?
M0T]-345.5"<I*2![#0H@("`@("`@("`@("!D969I;F4H)U1?1$]#7T-/34U%
M3E0G+"!47T-/34U%3E0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9&5F
M:6YE9"@G5%])3E1%4D9!0T4G*2D@>PT*("`@("`@("`@("`@9&5F:6YE*"=4
M7TE.5$521D%#12<L("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(61E
M9FEN960H)U1?24U03$5-14Y44R<I*2![#0H@("`@("`@("`@("!D969I;F4H
M)U1?24U03$5-14Y44R<L("TQ*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M)'-T<FEN9RD@>PT*("`@("`@("`@("`@)&-O;G1E;G1S(#T@)&9I;&4[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H(21F<"`]($!F;W!E
M;B@D9FEL92P@(G(B*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E
M>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@("`@("`@("`@("`@
M("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("`@("`D8V]N=&5N=',@/2!F
M:6QE7V=E=%]C;VYT96YT<R@D9FEL92D[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`]($!F<F5A9"@D9G`L(&9I
M;&5S:7IE*"1F:6QE*2D[#0H@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1O:V5N<R`]
M('1O:V5N7V=E=%]A;&PH)&-O;G1E;G1S*3L-"B\J#0H@("`@("`@(&9O<B`H
M)&D@/2`P.R`D:2`\('-I>F5O9B@D=&]K96YS*3L@)&DK*RD@>PT*("`@("`@
M("`@("`@0&QI<W0H)'1O:V5N+"`D9&%T82D@/2`D=&]K96YS6R1I73L-"B`@
M("`@("`@("`@(&EF("AI<U]S=')I;F<H)'1O:V5N*2D@>PT*("`@("`@("`@
M("`@("`@('9A<E]D=6UP*"1T;VME;BD[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@('!R:6YT('1O:V5N7VYA;64H)'1O:V5N*2`N
M("<@)SL-"B`@("`@("`@("`@("`@("!V87)?9'5M<"AR=')I;2@D9&%T82DI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0HJ+PT*("`@("`@("`D;&]O
M:U]F;W(@/2`P.PT*("`@("`@("`D<&%R96Y?;&5V96P@/2`P.PT*("`@("`@
M("`D8G)A8VME=%]L979E;"`](#`[#0H@("`@("`@("1B<F%C95]L979E;"`]
M(#`[#0H@("`@("`@("1L87-T<&AP9&]C(#T@)R<[#0H@("`@("`@("1C=7)R
M96YT7V-L87-S(#T@)R<[#0H@("`@("`@("1C=7)R96YT7VEN=&5R9F%C92`]
M("<G.PT*("`@("`@("`D8W5R<F5N=%]C;&%S<U]L979E;"`]("TQ.PT*("`@
M("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`D8W5R<F5N
M=%]F=6YC=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`D9&5C;&%R961?8VQA
M<W-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1D96-L87)E9%]I;G1E<F9A8V5S
M(#T@87)R87DH*3L-"B`@("`@("`@)&1E8VQA<F5D7V9U;F-T:6]N<R`](&%R
M<F%Y*"D[#0H@("`@("`@("1D96-L87)E9%]M971H;V1S(#T@87)R87DH*3L-
M"B`@("`@("`@)'5S961?8VQA<W-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1U
M<V5D7V9U;F-T:6]N<R`](&%R<F%Y*"D[#0H@("`@("`@("1E>'1E;F1S(#T@
M87)R87DH*3L-"B`@("`@("`@)&EM<&QE;65N=',@/2!A<G)A>2@I.PT*("`@
M("`@("`D;F]D97!S(#T@87)R87DH*3L-"B`@("`@("`@)&EN<75O=&4@/2!F
M86QS93L-"B`@("`@("`@)&EN=&5R9F%C92`](&9A;'-E.PT*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1O:V5N<RD[("1I*RLI('L-"B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=&]K96YS6R1I72DI('L-"B`@("`@
M("`@("`@("`@("!L:7-T*"1T;VME;BP@)&1A=&$I(#T@)'1O:V5N<ULD:5T[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1T;VME
M;B`]("1T;VME;G-;)&E=.PT*("`@("`@("`@("`@("`@("1D871A(#T@)R<[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&EN<75O=&4I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)'1O:V5N("$]("<B)R`F)B`D=&]K96X@
M(3T@5%]%3D1?2$52141/0RD@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D:6YQ=6]T92`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!S=VET8V@@*"1T;VME;BD@>PT*("`@("`@("`@("`@
M("`@(&-A<V4@5%]72$E415-004-%(#H-"B`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@8V%S92`G.R<Z#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D:6YT97)F86-E*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("<G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N8W1I;VY?;&5V96P@/2`M,3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@("`@("!C87-E("<B)SH-"B`@("`@("`@("`@
M("`@("!C87-E(%1?4U1!4E1?2$52141/0SH-"B`@("`@("`@("`@("`@("`@
M("`@)&EN<75O=&4@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("!C87-E(%1?0U523%E?3U!%3CH-"B`@("`@
M("`@("`@("`@("!C87-E(%1?1$],3$%27T]014Y?0U523%E?0E)!0T53.@T*
M("`@("`@("`@("`@("`@(&-A<V4@)WLG.B`D8G)A8V5?;&5V96PK*SL@8V]N
M=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E("=])SH-"B`@("`@("`@
M("`@("`@("`@("`@)&)R86-E7VQE=F5L+2T[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D8W5R<F5N=%]C;&%S<U]L979E;"`]/2`D8G)A8V5?;&5V96PI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT7V-L87-S(#T@
M)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]C;&%S<U]L
M979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D8W5R<F5N=%]F=6YC=&EO;E]L979E;"`]/2`D8G)A
M8V5?;&5V96PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT
M7V9U;F-T:6]N(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]F=6YC=&EO;E]L979E;"`]("TQ.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@
M("`@("`@("`@8V%S92`G6R<Z("1B<F%C:V5T7VQE=F5L*RL[(&-O;G1I;G5E
M(#([#0H@("`@("`@("`@("`@("`@8V%S92`G72<Z("1B<F%C:V5T7VQE=F5L
M+2T[(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@8V%S92`G*"<Z("1P
M87)E;E]L979E;"LK.R`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@("`@("`@
M8V%S92`G*2<Z("1P87)E;E]L979E;"TM.R`@(&-O;G1I;G5E(#([#0H@("`@
M("`@("`@("`@("`@8V%S92!47TE.5$521D%#13H-"B`@("`@("`@("`@("`@
M("`@("`@)&EN=&5R9F%C92`]('1R=64[#0H@("`@("`@("`@("`@("`@8V%S
M92!47T-,05-3.@T*("`@("`@("`@("`@("`@("`@("!I9B`H*"1C=7)R96YT
M7V-L87-S7VQE=F5L("$]("TQ*2!\?"`H)&-U<G)E;G1?9G5N8W1I;VY?;&5V
M96P@(3T@+3$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7W-T86-K+3YP=7-H*%]?1E5.0U1)3TY?7RP@)V5R<F]R)RP@87)R87DH)V9I
M;&4G(#T^("1F:6QE*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("=087)S
M97(@97)R;W(Z(&EN=F%L:60@4$A0(&9O=6YD(&EN(&9I;&4@(B5F:6QE)2(G
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&-A<V4@5%]&
M54Y#5$E/3CH-"B`@("`@("`@("`@("`@("!C87-E(%1?3D57.@T*("`@("`@
M("`@("`@("`@(&-A<V4@5%]%6%1%3D13.@T*("`@("`@("`@("`@("`@(&-A
M<V4@5%])35!,14U%3E13.@T*("`@("`@("`@("`@("`@("`@("`D;&]O:U]F
M;W(@/2`D=&]K96X[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([
M#0H@("`@("`@("`@("`@("`@8V%S92!47U-44DE.1SH-"B`@("`@("`@("`@
M("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AZ96YD7W9E<G-I;VXH*2P@
M)S(N,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M;E]A<G)A>2AS=')T;VQO=V5R*"1D871A*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@G<'5B;&EC)RP@)W!R:79A=&4G+"`G<')O=&5C
M=&5D)RP@)V%B<W1R86-T)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:6YT97)F86-E)RP@)VEM<&QE;65N=',G+"`G=&AR;W<G*2`-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W-T86-K+3YP=7-H*%]?
M1E5.0U1)3TY?7RP@)W=A<FYI;F<G+"!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V9I;&4G(#T^("1F:6QE*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)T5R<F]R+"!02%`U('1O:V5N(&5N
M8V]U;G1E<F5D(&EN("5F:6QE)2PG("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R!A;F%L>7-I<R!S:&]U;&0@8F4@:6X@4$A0-2<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&]O:U]F;W(@/3T@5%]#
M3$%34RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?8VQA
M<W,@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C=7)R96YT
M7V-L87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&1E8VQA<F5D7V-L87-S97-;72`]("1C=7)R96YT7V-L87-S
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?9F]R(#T]
M(%1?24Y415)&04-%*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D8W5R
M<F5N=%]I;G1E<F9A8V4@/2`D9&%T83L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1C=7)R96YT7V-L87-S7VQE=F5L(#T@)&)R86-E7VQE=F5L.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&1E8VQA<F5D7VEN=&5R9F%C97-;72`]
M("1C=7)R96YT7VEN=&5R9F%C93L-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1L;V]K7V9O<B`]/2!47TE-4$Q%345.5%,I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I;7!L96UE;G1S6R1C=7)R96YT7V-L87-S72`]
M("1D871A.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QO;VM?
M9F]R(#T](%1?15A414Y$4RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M)&5X=&5N9'-;)&-U<G)E;G1?8VQA<W-=(#T@)&1A=&$[#0H@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%]&54Y#5$E/3BD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1C=7)R96YT7V-L87-S
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E;G1?9G5N
M8W1I;VX@/2`B)&-U<G)E;G1?8VQA<W,Z.B1D871A(CL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5C;&%R961?;65T:&]D<ULD8W5R<F5N=%]C
M;&%S<UU;72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*"1C=7)R96YT7VEN=&5R9F%C92D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C=7)R96YT7V9U;F-T:6]N(#T@(B1C=7)R96YT7VEN
M=&5R9F%C93HZ)&1A=&$B.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D96-L87)E9%]M971H;V1S6R1C=7)R96YT7VEN=&5R9F%C95U;72`]("1D
M871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8W5R<F5N=%]F=6YC=&EO;B`]("1D
M871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D96-L87)E9%]F
M=6YC=&EO;G-;72`]("1C=7)R96YT7V9U;F-T:6]N.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)&-U<G)E
M;G1?9G5N8W1I;VY?;&5V96P@/2`D8G)A8V5?;&5V96P[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D;2`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@
M("`@('T@96QS96EF("@D;&]O:U]F;W(@/3T@5%].15<I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1U<V5D7V-L87-S97-;)&1A=&%=(#T@=')U93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M;&]O:U]F;W(@/2`P.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R
M.PT*("`@("`@("`@("`@("`@(&-A<V4@5%]605))04),13H-"B`@("`@("`@
M("`@("`@("`@("`@)&QO;VM?9F]R(#T@,#L-"B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?1$]#7T-/
M34U%3E0Z#0H@("`@("`@("`@("`@("`@8V%S92!47T-/34U%3E0Z#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"<A7B]<*EPJ7',A)RP@
M)&1A=&$I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D;&%S='!H<&1O
M8R`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*'!R96=?
M;6%T8VA?86QL*"<O0&YO9&5P7',K*%Q3*RDO)RP@)&QA<W1P:'!D;V,L("1M
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N;V1E<',@/2!A
M<G)A>5]M97)G92@D;F]D97!S+"`D;5LQ72D[#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("!C87-E(%1?
M1$]50DQ%7T-/3$]..@T*("`@("`@("`@("`@("`@("`@("!I9B`H(2@D=&]K
M96YS6R1I("T@,5U;,%T@/3T@5%]72$E415-004-%('Q\("1T;VME;G-;)&D@
M+2`Q75LP72`]/2!47U-44DE.1RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<W1A8VLM/G!U<V@H7U]&54Y#5$E/3E]?+"`G=V%R;FEN
M9R<L(&%R<F%Y*"=F:6QE)R`]/B`D9FEL92DL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U!A<G-E<B!E<G)O<CH@:6YV86QI9"!02%`@9F]U;F0@
M:6X@9FEL92`B)69I;&4E(B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("1C;&%S<R`]("1T;VME;G-;)&D@+2`Q75LQ73L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&-L87-S*2`A/2`G
M<&%R96YT)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5S961?8VQA
M<W-E<ULD8VQA<W-=(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B!A<G)A>2@-"B`@("`@("`@
M("`@(")S;W5R8V5?9FEL92(@/3X@)&9I;&4L#0H@("`@("`@("`@("`B9&5C
M;&%R961?8VQA<W-E<R(@/3X@)&1E8VQA<F5D7V-L87-S97,L#0H@("`@("`@
M("`@("`B9&5C;&%R961?:6YT97)F86-E<R(@/3X@)&1E8VQA<F5D7VEN=&5R
M9F%C97,L#0H@("`@("`@("`@("`B9&5C;&%R961?;65T:&]D<R(@/3X@)&1E
M8VQA<F5D7VUE=&AO9',L#0H@("`@("`@("`@("`B9&5C;&%R961?9G5N8W1I
M;VYS(B`]/B`D9&5C;&%R961?9G5N8W1I;VYS+`T*("`@("`@("`@("`@(G5S
M961?8VQA<W-E<R(@/3X@87)R87E?9&EF9BAA<G)A>5]K97ES*"1U<V5D7V-L
M87-S97,I+"`D;F]D97!S*2P-"B`@("`@("`@("`@(")I;FAE<FET86YC92(@
M/3X@)&5X=&5N9',L#0H@("`@("`@("`@("`B:6UP;&5M96YT<R(@/3X@)&EM
M<&QE;65N=',L#0H@("`@("`@("`@("`I.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($)U:6QD(&$@(G!R;W9I9&5S(B!A<G)A>2!F<F]M(&1A=&$@<F5T
M=7)N960@8GD-"B`@("`@*B!A;F%L>7IE4V]U<F-E0V]D92@I+B`@5&AE(&9O
M<FUA="!O9B!T:&4@8G5I;'0@87)R87D@:7,@;&EK90T*("`@("`J('1H:7,Z
M#0H@("`@("H-"B`@("`@*B`@87)R87DH#0H@("`@("H@("`@)V-L87-S.TUY
M0VQA<W,G(#T^("=A<G)A>2@G='EP92<@/3X@)V-L87-S)RP@)VYA;64G(#T^
M("=->4-L87-S)RDL#0H@("`@("H@("`@+BXN#0H@("`@("H@("D-"B`@("`@
M*@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1S<F-I;F9O(&%R<F%Y
M('=I=&@@:6YF;W)M871I;VX@86)O=70@82!S;W5R8V4@9FEL90T*("`@("`J
M(&%S(')E='5R;F5D(&)Y('1H92!A;F%L>7IE4V]U<F-E0V]D92@I(&UE=&AO
M9"X-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J#0H@("`@
M("H@0&%C8V5S<R!P<FEV871E#0H@("`@("H-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?8G5I;&10<F]V:61E<T%R<F%Y*"1S<F-I;F9O*0T*("`@('L-"B`@
M("`@("`@:68@*"$D=&AI<RT^7VES5F%L:60I('L-"B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@("1P<F]V:61E<W)E
M="`](&%R<F%Y*"D[#0H@("`@("`@("1F:6QE(#T@8F%S96YA;64H)'-R8VEN
M9F];)W-O=7)C95]F:6QE)UTI.PT*("`@("`@("`D<&X@/2`D=&AI<RT^7W!F
M+3YG971086-K86=E*"D[#0H@("`@("`@("1P;FP@/2!S=')L96XH)'!N*3L-
M"B`@("`@("`@9F]R96%C:"`H)'-R8VEN9F];)V1E8VQA<F5D7V-L87-S97,G
M72!A<R`D8VQA<W,I('L-"B`@("`@("`@("`@("1K97D@/2`B8VQA<W,[)&-L
M87-S(CL-"B`@("`@("`@("`@(&EF("AI<W-E="@D<')O=FED97-R971;)&ME
M>5TI*2![#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<')O=FED97-R971;)&ME>5T@/0T*("`@("`@
M("`@("`@("`@(&%R<F%Y*"=F:6QE)ST^("1F:6QE+"`G='EP92<@/3X@)V-L
M87-S)RP@)VYA;64G(#T^("1C;&%S<RD[#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'-R8VEN9F];)VEN:&5R:71A;F-E)UU;)&-L87-S72DI('L-"B`@("`@
M("`@("`@("`@("`D<')O=FED97-R971;)&ME>5U;)V5X=&5N9',G72`]#0H@
M("`@("`@("`@("`@("`@("`@("1S<F-I;F9O6R=I;FAE<FET86YC92==6R1C
M;&%S<UT[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R
M96%C:"`H)'-R8VEN9F];)V1E8VQA<F5D7VUE=&AO9',G72!A<R`D8VQA<W,@
M/3X@)&UE=&AO9',I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1M971H;V1S
M(&%S("1M971H;V0I('L-"B`@("`@("`@("`@("`@("`D9G5N8W1I;VX@/2`B
M)&-L87-S.CHD;65T:&]D(CL-"B`@("`@("`@("`@("`@("`D:V5Y(#T@(F9U
M;F-T:6]N.R1F=6YC=&EO;B([#0H@("`@("`@("`@("`@("`@:68@*"1M971H
M;V1[,'T@/3T@)U\G('Q\("%S=')C87-E8VUP*"1M971H;V0L("1C;&%S<RD@
M?'P-"B`@("`@("`@("`@("`@("`@("`@:7-S970H)'!R;W9I9&5S<F5T6R1K
M97E=*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!R;W9I9&5S<F5T6R1K
M97E=(#T-"B`@("`@("`@("`@("`@("`@("`@87)R87DH)V9I;&4G/3X@)&9I
M;&4L("=T>7!E)R`]/B`G9G5N8W1I;VXG+"`G;F%M92<@/3X@)&9U;F-T:6]N
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&9O<F5A
M8V@@*"1S<F-I;F9O6R=D96-L87)E9%]F=6YC=&EO;G,G72!A<R`D9G5N8W1I
M;VXI('L-"B`@("`@("`@("`@("1K97D@/2`B9G5N8W1I;VX[)&9U;F-T:6]N
M(CL-"B`@("`@("`@("`@(&EF("@D9G5N8W1I;VY[,'T@/3T@)U\G('Q\(&ES
M<V5T*"1P<F]V:61E<W)E=%LD:V5Y72DI('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A<W1R
M<W1R*"1F=6YC=&EO;BP@)SHZ)RD@)B8@<W1R;F-A<V5C;7`H)&9U;F-T:6]N
M+"`D<&XL("1P;FPI*2![#0H@("`@("`@("`@("`@("`@)'=A<FYI;F=S6UT@
M/2`B:6XQ("(@+B`D9FEL92`N("(Z(&9U;F-T:6]N(%PB)&9U;F-T:6]N7"(@
M;F]T('!R969I>&5D('=I=&@@<&%C:V%G92!N86UE(%PB)'!N7"(B.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'!R;W9I9&5S<F5T6R1K97E=(#T-
M"B`@("`@("`@("`@("`@("!A<G)A>2@G9FEL92<]/B`D9FEL92P@)W1Y<&4G
M(#T^("=F=6YC=&EO;B<L("=N86UE)R`]/B`D9G5N8W1I;VXI.PT*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D<')O=FED97-R970[#0H@("`@?0T*?0T*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]086-K86=E
M1FEL92]087)S97(O=C(N<&AP````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C<W,"`Q,#4Q-30S-#$S-"`P,C,V-3(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@<&%C:V%G92YX
M;6P@<&%R<VEN9R!C;&%S<RP@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@=C(N<&AP+'8@
M,2XQ.2`R,#`V+S`Q+S(S(#$W.C,Y.C4R(&-E;&QO9R!%>'`@)`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,0T*("HO#0HO*BH-"B`J(&)A<V4@>&UL('!A<G-E<B!C;&%S<PT*("HO
M#0IR97%U:7)E7V]N8V4@)U!%05(O6$U,4&%R<V5R+G!H<"<[#0IR97%U:7)E
M7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C(N<&AP)SL-"B\J*@T*("H@4&%R
M<V5R(&9O<B!P86-K86=E+GAM;"!V97)S:6]N(#(N,`T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@0%!%05(M5D520`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]086-K86=E1FEL95]087)S97)?=C(@
M97AT96YD<R!014%27UA-3%!A<G-E<@T*>PT*("`@('9A<B`D7V-O;F9I9SL-
M"B`@("!V87(@)%]L;V=G97([#0H@("`@=F%R("1?<F5G:7-T<GD[#0H-"B`@
M("!F=6YC=&EO;B!S971#;VYF:6<H)B1C*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]C;VYF:6<@/2`F)&,[#0H@("`@("`@("1T:&ES+3Y?<F5G:7-T<GD@
M/2`F)&,M/F=E=%)E9VES=')Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M<V5T3&]G9V5R*"8D;"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?;&]G9V5R
M(#T@)B1L.PT*("`@('T-"B`@("`O*BH-"B`@("`@*B!5;FEN9&5N="!G:79E
M;B!S=')I;F<-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B!4
M:&4@<W1R:6YG('1H870@:&%S('1O(&)E('5N:6YD96YT960N#0H@("`@("H@
M0')E='5R;B!S=')I;F<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!?=6Y);F1E;G0H)'-T<BD-"B`@("![#0H@("`@
M("`@("\O(')E;6]V92!L96%D:6YG(&YE=VQI;F5S#0H@("`@("`@("1S='(@
M/2!P<F5G7W)E<&QA8V4H)R]>6UQR7&Y=*R\G+"`G)RP@)'-T<BD[#0H@("`@
M("`@("\O(&9I;F0@=VAI=&5S<&%C92!A="!T:&4@8F5G:6YN:6YG(&]F('1H
M92!F:7)S="!L:6YE#0H@("`@("`@("1I;F1E;G1?;&5N(#T@<W1R<W!N*"1S
M='(L("(@7'0B*3L-"B`@("`@("`@)&EN9&5N="`]('-U8G-T<B@D<W1R+"`P
M+"`D:6YD96YT7VQE;BD[#0H@("`@("`@("1D871A(#T@)R<[#0H@("`@("`@
M("\O(')E;6]V92!T:&4@<V%M92!A;6]U;G0@;V8@=VAI=&5S<&%C92!F<F]M
M(&9O;&QO=VEN9R!L:6YE<PT*("`@("`@("!F;W)E86-H("AE>'!L;V1E*")<
M;B(L("1S='(I(&%S("1L:6YE*2![#0H@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1L:6YE+"`P+"`D:6YD96YT7VQE;BD@/3T@)&EN9&5N="D@>PT*("`@("`@
M("`@("`@("`@("1D871A("X]('-U8G-T<B@D;&EN92P@)&EN9&5N=%]L96XI
M("X@(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)&1A=&$[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@<&]S="UP
M<F]C97-S(&1A=&$-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&$-"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;&5M96YT(&5L96UE;G0@;F%M
M90T*("`@("`J+PT*("`@(&9U;F-T:6]N('!O<W10<F]C97-S*"1D871A+"`D
M96QE;65N="D-"B`@("![#0H@("`@("`@(&EF("@D96QE;65N="`]/2`G;F]T
M97,G*2![#0H@("`@("`@("`@("!R971U<FX@=')I;2@D=&AI<RT^7W5N26YD
M96YT*"1D871A*2D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R:6TH
M)&1A=&$I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!S=')I
M;F<-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M92!O9B!T:&4@<&%C
M:V%G92YX;6P-"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E(&YA;64@;V8@
M=&AE(&%R8VAI=F4@=&AI<R!P86-K86=E+GAM;"!C86UE(&9R;VTL(&EF(&%N
M>0T*("`@("`J($!P87)A;2!S=')I;F<@8VQA<W,@;F%M92!T;R!I;G-T86YT
M:6%T92!A;F0@<F5T=7)N+B`@5&AI<R!M=7-T(&)E(%!%05)?4&%C:V%G949I
M;&5?=C(@;W(-"B`@("`@*B`@("`@("`@("`@("`@(&$@<W5B8VQA<W,-"B`@
M("`@*B!`<F5T=7)N(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B`F<&%R<V4H)&1A=&$L("1F:6QE+"`D87)C:&EV92`](&9A
M;'-E+"`D8VQA<W,@/2`G4$5!4E]086-K86=E1FEL95]V,B<I#0H@("`@>PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@<&%R96YT.CIP87)S
M92@D9&%T82P@)&9I;&4I*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E<G([
M#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&YE=R`D8VQA<W,[#0H@("`@
M("`@("1R970M/G-E=$-O;F9I9R@D=&AI<RT^7V-O;F9I9RD[#0H@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7VQO9V=E<BDI('L-"B`@("`@("`@("`@("1R
M970M/G-E=$QO9V=E<B@D=&AI<RT^7VQO9V=E<BD[#0H@("`@("`@('T-"B`@
M("`@("`@)')E="T^9G)O;4%R<F%Y*"1T:&ES+3Y?=6YS97)I86QI>F5D1&%T
M82D[#0H@("`@("`@("1R970M/G-E=%!A8VMA9V5F:6QE*"1F:6QE+"`D87)C
M:&EV92D[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"GT-"C\^````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O4&%C:V%G
M949I;&4O4&%R<V5R+W8Q+G!H<```````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M-#$U-S`@,3`U,34T,S0Q,S0@,#(S-C0V`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP#0HO*BH-"B`J('!A8VMA9V4N
M>&UL('!A<G-I;F<@8VQA<W,L('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP#0H@
M*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4
M:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@
M=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@
M0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z('8Q+G!H<"QV
M(#$N,C$@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP83$-"B`J+PT*+RHJ#0H@*B!P86-K86=E+GAM;"!A8G-T<F%C=&EO;B!C
M;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O=C$N
M<&AP)SL-"B\J*@T*("H@4&%R<V5R(&9O<B!P86-K86=E+GAM;"!V97)S:6]N
M(#$N,`T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!
M4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T
M/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M0%!%05(M5D520`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]086-K
M86=E1FEL95]087)S97)?=C$-"GL-"B`@("!V87(@)%]R96=I<W1R>3L-"B`@
M("!V87(@)%]C;VYF:6<[#0H@("`@=F%R("1?;&]G9V5R.PT*("`@("\J*@T*
M("`@("`J($)#(&AA8VL@=&\@86QL;W<@4$5!4E]#;VUM;VXZ.FEN9F]&<F]M
M4W1R:6YG*"D@=&\@<V]R="!O9@T*("`@("`J('=O<FL@=VET:"!T:&4@=F5R
M<VEO;B`R+C`@9F]R;6%T("T@=&AE<F4G<R!N;R!F:6QE;&ES="!T:&]U9V@-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&9R;VU6,B@D<&%C:V%G969I;&4I#0H@("`@>PT*("`@
M("`@("`D:6YF;R`]("1P86-K86=E9FEL92T^9V5T07)R87DH=')U92D[#0H@
M("`@("`@("1R970@/2!N97<@4$5!4E]086-K86=E1FEL95]V,3L-"B`@("`@
M("`@)')E="T^9G)O;4%R<F%Y*"1I;F9O6R=O;&0G72D[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@<V5T0V]N9FEG*"8D8RD-"B`@("![#0H@("`@("`@("1T
M:&ES+3Y?8V]N9FEG(#T@)B1C.PT*("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M(#T@)B1C+3YG971296=I<W1R>2@I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N
M('-E=$QO9V=E<B@F)&PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7VQO9V=E
M<B`]("8D;#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@<W1R
M:6YG(&-O;G1E;G1S(&]F('!A8VMA9V4N>&UL(&9I;&4L('9E<G-I;VX@,2XP
M#0H@("`@("H@0')E='5R;B!B;V]L('-U8V-E<W,@;V8@<&%R<VEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N('!A<G-E*"1D871A+"`D9FEL92P@)&%R8VAI
M=F4@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A97AT96YS:6]N7VQO
M861E9"@G>&UL)RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*"=#86YN;W0@8W)E871E('AM;"!P87)S97(@9F]R('!A<G-I;F<@
M<&%C:V%G92YX;6PL(&YO('AM;"!E>'1E;G-I;VXG*3L-"B`@("`@("`@?0T*
M("`@("`@("`D>'`@/2!`>&UL7W!A<G-E<E]C<F5A=&4H*3L-"B`@("`@("`@
M:68@*"$D>'`I('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"=#86YN;W0@8W)E871E('AM;"!P87)S97(@9F]R('!A<G-I;F<@<&%C
M:V%G92YX;6PG*3L-"B`@("`@("`@?0T*("`@("`@("!X;6Q?<V5T7V]B:F5C
M="@D>'`L("1T:&ES*3L-"B`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L
M97(H)'AP+"`G7V5L96UE;G1?<W1A<G1?,5\P)RP@)U]E;&5M96YT7V5N9%\Q
M7S`G*3L-"B`@("`@("`@>&UL7W-E=%]C:&%R86-T97)?9&%T85]H86YD;&5R
M*"1X<"P@)U]P:V=I;F9O7V-D871A7S%?,"<I.PT*("`@("`@("!X;6Q?<&%R
M<V5R7W-E=%]O<'1I;VXH)'AP+"!834Q?3U!424].7T-!4T5?1D],1$E.1RP@
M9F%L<V4I.PT*#0H@("`@("`@("1T:&ES+3YE;&5M96YT7W-T86-K(#T@87)R
M87DH*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;R`](&%R<F%Y*"=P
M<F]V:61E<R<@/3X@87)R87DH*2D[#0H@("`@("`@("1T:&ES+3YC=7)R96YT
M7V5L96UE;G0@/2!F86QS93L-"B`@("`@("`@=6YS970H)'1H:7,M/F1I<E]I
M;G-T86QL*3L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG9FEL96QI
M<W0G72`](&%R<F%Y*"D[#0H@("`@("`@("1T:&ES+3YF:6QE;&ES="`])B`D
M=&AI<RT^7W!A8VMA9V5);F9O6R=F:6QE;&ES="==.PT*("`@("`@("`D=&AI
M<RT^9&ER7VYA;65S(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M/FEN7V-H
M86YG96QO9R`](&9A;'-E.PT*("`@("`@("`D=&AI<RT^9%]I(#T@,#L-"B`@
M("`@("`@)'1H:7,M/F-D871A(#T@)R<[#0H@("`@("`@("1T:&ES+3Y?:7-6
M86QI9"`]('1R=64[#0H-"B`@("`@("`@:68@*"%X;6Q?<&%R<V4H)'AP+"`D
M9&%T82P@,2DI('L-"B`@("`@("`@("`@("1C;V1E(#T@>&UL7V=E=%]E<G)O
M<E]C;V1E*"1X<"D[#0H@("`@("`@("`@("`D;&EN92`]('AM;%]G971?8W5R
M<F5N=%]L:6YE7VYU;6)E<B@D>'`I.PT*("`@("`@("`@("`@>&UL7W!A<G-E
M<E]F<F5E*"1X<"D[#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<BAS<')I;G1F*")834P@97)R;W(Z("5S(&%T(&QI;F4@)60B+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`]('AM;%]E<G)O<E]S=')I
M;F<H)&-O9&4I+"`D;&EN92DL(#(I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M>&UL7W!A<G-E<E]F<F5E*"1X<"D[#0H-"B`@("`@("`@)'!F(#T@;F5W(%!%
M05)?4&%C:V%G949I;&5?=C$[#0H@("`@("`@("1P9BT^<V5T0V]N9FEG*"1T
M:&ES+3Y?8V]N9FEG*3L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?;&]G
M9V5R*2D@>PT*("`@("`@("`@("`@)'!F+3YS971,;V=G97(H)'1H:7,M/E]L
M;V=G97(I.PT*("`@("`@("!]#0H@("`@("`@("1P9BT^<V5T4&%C:V%G969I
M;&4H)&9I;&4L("1A<F-H:79E*3L-"B`@("`@("`@)'!F+3YF<F]M07)R87DH
M)'1H:7,M/E]P86-K86=E26YF;RD[#0H@("`@("`@(')E='5R;B`D<&8[#0H@
M("`@?0T*("`@("\O('M[>R!?=6Y);F1E;G0H*0T*#0H@("`@+RHJ#0H@("`@
M("H@56YI;F1E;G0@9VEV96X@<W1R:6YG#0H@("`@("H-"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1S='(@5&AE('-T<FEN9R!T:&%T(&AA<R!T;R!B92!U;FEN
M9&5N=&5D+@T*("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S
M<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5N26YD96YT*"1S
M='(I#0H@("`@>PT*("`@("`@("`O+R!R96UO=F4@;&5A9&EN9R!N97=L:6YE
M<PT*("`@("`@("`D<W1R(#T@<')E9U]R97!L86-E*"<O7EM<<EQN72LO)RP@
M)R<L("1S='(I.PT*("`@("`@("`O+R!F:6YD('=H:71E<W!A8V4@870@=&AE
M(&)E9VEN;FEN9R!O9B!T:&4@9FER<W0@;&EN90T*("`@("`@("`D:6YD96YT
M7VQE;B`]('-T<G-P;B@D<W1R+"`B(%QT(BD[#0H@("`@("`@("1I;F1E;G0@
M/2!S=6)S='(H)'-T<BP@,"P@)&EN9&5N=%]L96XI.PT*("`@("`@("`D9&%T
M82`]("<G.PT*("`@("`@("`O+R!R96UO=F4@=&AE('-A;64@86UO=6YT(&]F
M('=H:71E<W!A8V4@9G)O;2!F;VQL;W=I;F<@;&EN97,-"B`@("`@("`@9F]R
M96%C:"`H97AP;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN92D@>PT*("`@("`@
M("`@("`@:68@*'-U8G-T<B@D;&EN92P@,"P@)&EN9&5N=%]L96XI(#T]("1I
M;F1E;G0I('L-"B`@("`@("`@("`@("`@("`D9&%T82`N/2!S=6)S='(H)&QI
M;F4L("1I;F1E;G1?;&5N*2`N(")<;B([#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@("\O
M(%-U<'!O<G0@9F]R('!A8VMA9V4@1%1$('8Q+C`Z#0H@("`@+R\@>WM[(%]E
M;&5M96YT7W-T87)T7S%?,"@I#0H-"B`@("`O*BH-"B`@("`@*B!834P@<&%R
M<V5R(&-A;&QB86-K(&9O<B!E;F1I;F<@96QE;65N=',N("!5<V5D(&9O<B!V
M97)S:6]N(#$N,`T*("`@("`J('!A8VMA9V5S+@T*("`@("`J#0H@("`@("H@
M0'!A<F%M(')E<V]U<F-E("`D>'`@("`@6$U,('!A<G-E<B!R97-O=7)C90T*
M("`@("`J($!P87)A;2!S=')I;F<@("`@)&YA;64@(&YA;64@;V8@96YD:6YG
M(&5L96UE;G0-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I9`T*("`@("`J
M#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@7V5L96UE;G1?<W1A<G1?,5\P*"1X<"P@)&YA;64L("1A='1R:6)S*0T*
M("`@('L-"B`@("`@("`@87)R87E?<'5S:"@D=&AI<RT^96QE;65N=%]S=&%C
M:RP@)&YA;64I.PT*("`@("`@("`D=&AI<RT^8W5R<F5N=%]E;&5M96YT(#T@
M)&YA;64[#0H@("`@("`@("1S<&]S(#T@<VEZ96]F*"1T:&ES+3YE;&5M96YT
M7W-T86-K*2`M(#([#0H@("`@("`@("1T:&ES+3YP<F5V7V5L96UE;G0@/2`H
M)'-P;W,@/CT@,"D@/R`D=&AI<RT^96QE;65N=%]S=&%C:ULD<W!O<UT@.B`G
M)SL-"B`@("`@("`@)'1H:7,M/F-U<G)E;G1?871T<FEB=71E<R`]("1A='1R
M:6)S.PT*("`@("`@("`D=&AI<RT^8V1A=&$@/2`G)SL-"B`@("`@("`@<W=I
M=&-H("@D;F%M92D@>PT*("`@("`@("`@("`@8V%S92`G9&ER)SH-"B`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)VYA;64G+"`D871T
M<FEB<RD@)B8@)&%T=')I8G-;)VYA;64G72`A/2`G+R<I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&%T=')I8G-;)VYA;64G72`]('!R96=?<F5P;&%C92AA
M<G)A>2@G(5Q<7%PK(2<L("<A+RLA)RDL(&%R<F%Y*"<O)RP@)R\G*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S6R=N86UE)UTI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H<W1R<G!O<R@D871T<FEB<ULG;F%M92==
M+"`G+R<I(#T]('-T<FQE;B@D871T<FEB<ULG;F%M92==*2`M(#$I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1A='1R:6)S6R=N86UE)UT@/2!S=6)S
M='(H)&%T=')I8G-;)VYA;64G72P@,"P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!S=')L96XH)&%T=')I8G-;)VYA;64G72D@+2`Q*3L-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M<&]S*"1A='1R:6)S6R=N86UE)UTL("<O)RD@/3T](#`I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1A='1R:6)S6R=N86UE)UT@/2!S=6)S='(H)&%T
M=')I8G-;)VYA;64G72P@,2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F1I<E]N86UE<UM=(#T@)&%T=')I
M8G-;)VYA;64G73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1A='1R:6)S6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9&ER7VEN<W1A;&P@/2`D871T
M<FEB<ULG8F%S96EN<W1A;&QD:7(G73L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S6R=R;VQE)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YD:7)?<F]L92`]("1A='1R
M:6)S6R=R;VQE)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G9FEL92<Z#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D871T<FEB<ULG;F%M92==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D<&%T:"`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)'1H:7,M/F1I<E]N86UE<RDI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD:7)?;F%M97,@87,@
M)&1I<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P871H("X]
M("1D:7(@+B`G+R<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A=&@@
M+CT@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O*R$G*2P@87)R
M87DH)R\G+"`G+R<I+`T*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I
M8G-;)VYA;64G72D[#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1A='1R
M:6)S6R=N86UE)UTI.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R
M<F5N=%]P871H(#T@)'!A=&@[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YF:6QE;&ES=%LD<&%T:%T@/2`D871T<FEB<SL-"B`@("`@("`@("`@("`@
M("`@("`@+R\@4V5T('1H92!B87-E:6YS=&%L;&1I<B!O;FQY(&EF('1H92!F
M:6QE(&1O;B=T(&AA=F4@=&AI<R!A='1R:6(-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"%I<W-E="@D=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=B87-E:6YS
M=&%L;&1I<B==*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H
M)'1H:7,M/F1I<E]I;G-T86QL*2D-"B`@("`@("`@("`@("`@("`@("`@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F9I;&5L:7-T6R1P871H
M75LG8F%S96EN<W1A;&QD:7(G72`]("1T:&ES+3YD:7)?:6YS=&%L;#L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`O+R!3
M970@=&AE(%)O;&4-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M=&AI<RT^9FEL96QI<W1;)'!A=&A=6R=R;VQE)UTI("8F(&ES<V5T*"1T:&ES
M+3YD:7)?<F]L92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YF:6QE;&ES=%LD<&%T:%U;)W)O;&4G72`]("1T:&ES+3YD:7)?<F]L93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)W)E<&QA
M8V4G.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG96QO
M9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9FEL96QI<W1;)'1H
M:7,M/F-U<G)E;G1?<&%T:%U;)W)E<&QA8V5M96YT<R==6UT@/2`D871T<FEB
M<SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!C87-E("=M86EN=&%I;F5R<R<Z#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G72`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/FU?:2`](#`[("\O(&UA
M:6YT86EN97)S(&%R<F%Y(&EN9&5X#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!C87-E("=M86EN=&%I;F5R)SH-"B`@("`@("`@("`@
M("`@("`O+R!C;VUP871I8FEL:71Y(&-H96-K#0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^7W!A8VMA9V5);F9O6R=M86EN=&%I;F5R<R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O
M6R=M86EN=&%I;F5R<R==(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/FU?:2`](#`[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;
M)'1H:7,M/FU?:5T@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT7VUA:6YT86EN97(@/28@)'1H:7,M/E]P86-K86=E26YF;ULG
M;6%I;G1A:6YE<G,G75LD=&AI<RT^;5]I73L-"B`@("`@("`@("`@("`@("!B
M<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V-H86YG96QO9R<Z#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG8VAA;F=E;&]G)UT@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@("`@("1T:&ES+3YC7VD@/2`P.R`O+R!C
M:&%N9V5L;V<@87)R87D@:6YD97@-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M:6Y?8VAA;F=E;&]G(#T@=')U93L-"B`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)W)E;&5A<V4G.@T*("`@("`@("`@("`@("`@
M(&EF("@D=&AI<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)V-H86YG96QO9R==6R1T:&ES+3YC
M7VE=(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U
M<G)E;G1?<F5L96%S92`]("8D=&AI<RT^7W!A8VMA9V5);F9O6R=C:&%N9V5L
M;V<G75LD=&AI<RT^8U]I73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E(#T@
M)B1T:&ES+3Y?<&%C:V%G94EN9F\[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G9&5P<R<Z
M#0H@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^:6Y?8VAA;F=E;&]G*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E
M;&5A<V5?9&5P<R==(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=D97`G
M.@T*("`@("`@("`@("`@("`@("\O(&1E<&5N9&5N8VEE<R!A<G)A>2!I;F1E
M>`T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG96QO9RD@
M>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9%]I*RL[#0H@("`@("`@
M("`@("`@("`@("`@(&ES<V5T*"1A='1R:6)S6R=T>7!E)UTI(#\@*"1A='1R
M:6)S6R=T>7!E)UT@/2!S=')T;VQO=V5R*"1A='1R:6)S6R=T>7!E)UTI*2`Z
M(&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=R96QE87-E7V1E<',G75LD=&AI<RT^9%]I72`]("1A='1R:6)S.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@(&-A<V4@)V-O;F9I9W5R96]P=&EO;G,G.@T*("`@("`@("`@
M("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=C;VYF:6=U<F5?;W!T
M:6]N<R==(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=C;VYF:6=U<F5O
M<'1I;VXG.@T*("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/FEN7V-H86YG
M96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=C;VYF:6=U<F5?;W!T:6]N<R==6UT@/2`D871T<FEB<SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E("=P<F]V:61E<R<Z#0H@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1A='1R:6)S6R=T>7!E)UTI('Q\(&5M<'1Y*"1A='1R:6)S6R=N86UE
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`D871T<FEB<ULG97AP;&EC:70G
M72`]('1R=64[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG<')O=FED97,G75LB)&%T=')I8G-;='EP95T[)&%T=')I8G-;;F%M95TB
M72`]("1A='1R:6)S.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G<&%C:V%G92<@.@T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D871T<FEB<ULG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=X<V1V97)S:6]N)UT@/2!T<FEM
M*"1A='1R:6)S6R=V97)S:6]N)UTI.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];
M)WAS9'9E<G-I;VXG72`]("<Q+C`G.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=')I8G-;)W!A8VMA9V5R=F5R
M<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA
M9V5);F9O6R=P86-K86=E<G9E<G-I;VXG72`]("1A='1R:6)S6R=P86-K86=E
M<G9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@
M("`O+R![>WL@7V5L96UE;G1?96YD7S%?,"@I#0H-"B`@("`O*BH-"B`@("`@
M*B!834P@<&%R<V5R(&-A;&QB86-K(&9O<B!E;F1I;F<@96QE;65N=',N("!5
M<V5D(&9O<B!V97)S:6]N(#$N,`T*("`@("`J('!A8VMA9V5S+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M(')E<V]U<F-E("`D>'`@("`@6$U,('!A<G-E<B!R
M97-O=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@("`@)&YA;64@(&YA;64@
M;V8@96YD:6YG(&5L96UE;G0-"B`@("`@*@T*("`@("`J($!R971U<FX@=F]I
M9`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@
M("`@9G5N8W1I;VX@7V5L96UE;G1?96YD7S%?,"@D>'`L("1N86UE*0T*("`@
M('L-"B`@("`@("`@)&1A=&$@/2!T<FEM*"1T:&ES+3YC9&%T82D[#0H@("`@
M("`@('-W:71C:"`H)&YA;64I('L-"B`@("`@("`@("`@(&-A<V4@)VYA;64G
M.@T*("`@("`@("`@("`@("`@('-W:71C:"`H)'1H:7,M/G!R979?96QE;65N
M="D@>PT*("`@("`@("`@("`@("`@("`@("!C87-E("=P86-K86=E)SH-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W!A
M8VMA9V4G72`]("1D871A.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUA:6YT86EN97(G.@T*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?;6%I;G1A
M:6YE<ELG;F%M92==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E("=E>'1E;F1S)R`Z#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF;ULG97AT96YD<R==(#T@)&1A
M=&$[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M("=S=6UM87)Y)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5)
M;F9O6R=S=6UM87)Y)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@(&-A<V4@)V1E<V-R:7!T:6]N)SH-"B`@("`@("`@
M("`@("`@("`D9&%T82`]("1T:&ES+3Y?=6Y);F1E;G0H)'1H:7,M/F-D871A
M*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=D97-C
M<FEP=&EO;B==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=U<V5R)SH-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^8W5R<F5N=%]M86EN=&%I;F5R6R=H86YD;&4G72`]("1D871A.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G96UA:6PG
M.@T*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT7VUA:6YT86EN97);
M)V5M86EL)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@(&-A<V4@)W)O;&4G.@T*("`@("`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT7VUA:6YT86EN97);)W)O;&4G72`]("1D871A.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G=F5R<VEO;B<Z
M#0H@("`@("`@("`@("`@("`@+R\D9&%T82`](&5R96=?<F5P;&%C92`H)UM>
M82UZ02U:,"TY+E]<+5TG+"`G7R<L("1D871A*3L-"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=V97)S:6]N)UT@/2`D9&%T
M83L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=V97)S:6]N)UT@/2`D9&%T83L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@
M("`@("`@("`@("!C87-E("=D871E)SH-"B`@("`@("`@("`@("`@("!I9B`H
M)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^8W5R<F5N=%]R96QE87-E6R=R96QE87-E7V1A=&4G72`]("1D871A
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&%C:V%G94EN9F];)W)E;&5A<V5?9&%T92==(#T@)&1A
M=&$[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92`G;F]T97,G.@T*("`@("`@("`@("`@("`@
M("\O('1R>2!T;R`B9&4M:6YD96YT(B!R96QE87-E(&YO=&5S(&EN(&-A<V4@
M<V]M96]N90T*("`@("`@("`@("`@("`@("\O(&AA<R!B965N(&]V97(M:6YD
M96YT:6YG('1H96ER('AM;"`[+2D-"B`@("`@("`@("`@("`@("`D9&%T82`]
M("1T:&ES+3Y?=6Y);F1E;G0H)'1H:7,M/F-D871A*3L-"B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8W5R<F5N=%]R96QE87-E6R=R96QE87-E7VYO=&5S
M)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7VYO
M=&5S)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=W87)N:6YG<R<Z#0H@
M("`@("`@("`@("`@("`@:68@*"1T:&ES+3YI;E]C:&%N9V5L;V<I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1?<F5L96%S95LG<F5L
M96%S95]W87)N:6YG<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]P86-K86=E26YF
M;ULG<F5L96%S95]W87)N:6YG<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G<W1A=&4G.@T*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:6Y?8VAA
M;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT
M7W)E;&5A<V5;)W)E;&5A<V5?<W1A=&4G72`]("1D871A.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<&%C:V%G94EN9F];)W)E;&5A<V5?<W1A=&4G72`]("1D871A.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@(&-A<V4@)VQI8V5N<V4G.@T*("`@("`@("`@("`@("`@(&EF("@D=&AI
M<RT^:6Y?8VAA;F=E;&]G*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YC=7)R96YT7W)E;&5A<V5;)W)E;&5A<V5?;&EC96YS92==(#T@)&1A=&$[
M#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E26YF;ULG<F5L96%S95]L:6-E;G-E)UT@/2`D
M9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E("=D97`G.@T*("`@("`@("`@("`@("`@
M(&EF("@D9&%T82`F)B`A)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5);F9O6R=R96QE87-E7V1E
M<',G75LD=&AI<RT^9%]I75LG;F%M92==(#T@)&1A=&$[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92`G9&ER)SH-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN7V-H
M86YG96QO9RD@>PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@87)R87E?<&]P*"1T:&ES
M+3YD:7)?;F%M97,I.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G9FEL92<Z#0H@("`@("`@("`@("`@("`@:68@*"1T:&ES
M+3YI;E]C:&%N9V5L;V<I('L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9&%T
M82D@>PT*("`@("`@("`@("`@("`@("`@("`D<&%T:"`]("<G.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H8V]U;G0H)'1H:7,M/F1I<E]N86UE<RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YD:7)?
M;F%M97,@87,@)&1I<BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P871H("X]("1D:7(@+B`G+R<[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)'!A=&@@+CT@)&1A=&$[#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YF:6QE;&ES=%LD<&%T:%T@/2`D=&AI<RT^8W5R<F5N=%]A='1R:6)U=&5S
M.PT*("`@("`@("`@("`@("`@("`@("`O+R!3970@=&AE(&)A<V5I;G-T86QL
M9&ER(&]N;'D@:68@=&AE(&9I;&4@9&]N)W0@:&%V92!T:&ES(&%T=')I8@T*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YF:6QE;&ES
M=%LD<&%T:%U;)V)A<V5I;G-T86QL9&ER)UTI("8F#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I<W-E="@D=&AI<RT^9&ER7VEN<W1A;&PI*0T*("`@("`@
M("`@("`@("`@("`@("![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9FEL96QI<W1;)'!A=&A=6R=B87-E:6YS=&%L;&1I<B==(#T@)'1H:7,M
M/F1I<E]I;G-T86QL.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("\O(%-E="!T:&4@4F]L90T*("`@("`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3YF:6QE;&ES=%LD<&%T:%U;)W)O;&4G
M72D@)B8@:7-S970H)'1H:7,M/F1I<E]R;VQE*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F9I;&5L:7-T6R1P871H75LG<F]L92==(#T@
M)'1H:7,M/F1I<E]R;VQE.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@("`@8V%S92`G;6%I;G1A:6YE<B<Z#0H@("`@("`@("`@("`@("`@:68@
M*&5M<'1Y*"1T:&ES+3Y?<&%C:V%G94EN9F];)VUA:6YT86EN97)S)UU;)'1H
M:7,M/FU?:5U;)W)O;&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]P86-K86=E26YF;ULG;6%I;G1A:6YE<G,G75LD=&AI<RT^;5]I75LG
M<F]L92==(#T@)VQE860G.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D=&AI<RT^;5]I*RL[#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!C87-E("=R96QE87-E)SH-"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/FEN7V-H86YG96QO9RD@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8U]I*RL[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G8VAA;F=E;&]G
M)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^:6Y?8VAA;F=E;&]G(#T@9F%L
M<V4[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@
M("`@87)R87E?<&]P*"1T:&ES+3YE;&5M96YT7W-T86-K*3L-"B`@("`@("`@
M)'-P;W,@/2!S:7IE;V8H)'1H:7,M/F5L96UE;G1?<W1A8VLI("T@,3L-"B`@
M("`@("`@)'1H:7,M/F-U<G)E;G1?96QE;65N="`]("@D<W!O<R`^(#`I(#\@
M)'1H:7,M/F5L96UE;G1?<W1A8VM;)'-P;W-=(#H@)R<[#0H@("`@("`@("1T
M:&ES+3YC9&%T82`]("<G.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!?<&MG:6YF;U]C9&%T85\Q7S`H*0T*#0H@("`@+RHJ#0H@("`@("H@
M6$U,('!A<G-E<B!C86QL8F%C:R!F;W(@8VAA<F%C=&5R(&1A=&$N("!5<V5D
M(&9O<B!V97)S:6]N(#$N,`T*("`@("`J('!A8VMA9V5S+@T*("`@("`J#0H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("`D>'`@("`@6$U,('!A<G-E<B!R97-O
M=7)C90T*("`@("`J($!P87)A;2!S=')I;F<@("`@)&YA;64@(&-H87)A8W1E
M<B!D871A#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('9O:60-"B`@("`@*@T*
M("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N
M(%]P:V=I;F9O7V-D871A7S%?,"@D>'`L("1D871A*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YC9&%T82DI('L-"B`@("`@("`@("`@("1T
M:&ES+3YC9&%T82`N/2`D9&%T83L-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M("\O('U]?0T*?0T*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U!A8VMA9V5&:6QE+T=E;F5R871O<B]V,BYP:'``````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,3<R,#`P(#$P-3$U-#,T,3,T(#`R-#,S,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B!P86-K86=E+GAM;"!G96YE<F%T:6]N(&-L87-S+"!P86-K86=E+GAM;"!V
M97)S:6]N(#(N,`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED="`H;W)I9VEN
M86P@6$U,7U-E<FEA;&EZ97(@8V]D92D-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M
M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!V,BYP:'`L=B`Q+C,T(#(P,#8O,#,O
M,#(@,C`Z-3`Z-3D@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P
M.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@
M1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J
M*@T*("H@9FEL92]D:7(@;6%N:7!U;&%T:6]N(')O=71I;F5S#0H@*B\-"G)E
M<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0HO*BH-"B`J(%1H:7,@8VQA<W,@
M8V]N=F5R=',@82!014%27U!A8VMA9V5&:6QE7W8R(&]B:F5C="!I;G1O(&%N
M>2!O=71P=70@9F]R;6%T+@T*("H-"B`J(%-U<'!O<G1E9"!O=71P=70@9F]R
M;6%T<R!I;F-L=61E(&%R<F%Y+"!834P@<W1R:6YG("AU<VEN9R!3+B!38VAM
M:61T)W,-"B`J(%A-3%]397)I86QI>F5R+"!S;&EG:'1L>2!C=7-T;VUI>F5D
M*0T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&%U=&AO<B`@("`@4W1E<&AA;B!38VAM:61T("AO<FEG:6YA;"!834Q?
M4V5R:6%L:7IE<B!C;V1E*0T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R#0I[#0H@("`O*BH-"B`@
M("`J(&1E9F%U;'0@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX-"B`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("H@0'9A<B!A<G)A>2`D7V1E9F%U
M;'1/<'1I;VYS#0H@("`@*B\-"B`@("!V87(@)%]D969A=6QT3W!T:6]N<R`]
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("=I;F1E;G0G("`@
M("`@("`@("`@(#T^("<@)RP@("`@("`@("`@("`@("`@("`@("\O('-T<FEN
M9R!U<V5D(&9O<B!I;F1E;G1A=&EO;@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("=L:6YE8G)E86LG("`@("`@("`@(#T^(")<;B(L("`@("`@("`@("`@
M("`@("`@+R\@<W1R:6YG('5S960@9F]R(&YE=VQI;F5S#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@)W1Y<&5(:6YT<R<@("`@("`@("`@/3X@9F%L<V4L
M("`@("`@("`@("`@("`@("`O+R!A=71O;6%T:6-A;&QY(&%D9"!T>7!E(&AI
M;B!A='1R:6)U=&5S#0H@("`@("`@("`@("`@("`@("`@("`@("`@)V%D9$1E
M8VPG("`@("`@("`@("`@/3X@=')U92P@("`@("`@("`@("`@("`@("\O(&%D
M9"!A;B!834P@9&5C;&%R871I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`G9&5F875L=%1A9TYA;64G("`@("`]/B`G6$U,7U-E<FEA;&EZ97)?5&%G
M)RP@("\O('1A9R!U<V5D(&9O<B!I;F1E>&5D(&%R<F%Y<R!O<B!I;G9A;&ED
M(&YA;65S#0H@("`@("`@("`@("`@("`@("`@("`@("`@)V-L87-S07-486=.
M86UE)R`@("`@/3X@9F%L<V4L("`@("`@("`@("`@("`@("`O+R!U<V4@8VQA
M<W-N86UE(&9O<B!O8FIE8W1S(&EN(&EN9&5X960@87)R87ES#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@)VME>4%T=')I8G5T92<@("`@("`@/3X@)U]O
M<FEG:6YA;$ME>2<L("`@("`@("`O+R!A='1R:6)U=&4@=VAE<F4@;W)I9VEN
M86P@:V5Y(&ES('-T;W)E9`T*("`@("`@("`@("`@("`@("`@("`@("`@("=T
M>7!E071T<FEB=71E)R`@("`@(#T^("=?='EP92<L("`@("`@("`@("`@("`@
M+R\@871T<FEB=71E(&9O<B!T>7!E("AO;FQY(&EF('1Y<&5(:6YT<R`]/B!T
M<G5E*0T*("`@("`@("`@("`@("`@("`@("`@("`@("=C;&%S<T%T=')I8G5T
M92<@("`@(#T^("=?8VQA<W,G+"`@("`@("`@("`@("`@+R\@871T<FEB=71E
M(&9O<B!C;&%S<R!O9B!O8FIE8W1S("AO;FQY(&EF('1Y<&5(:6YT<R`]/B!T
M<G5E*0T*("`@("`@("`@("`@("`@("`@("`@("`@("=S8V%L87)!<T%T=')I
M8G5T97,G(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@<V-A;&%R('9A
M;'5E<R`H<W1R:6YG<RP@:6YT<RPN+BD@=VEL;"!B92!S97)I86QI>F5D(&%S
M(&%T=')I8G5T90T*("`@("`@("`@("`@("`@("`@("`@("`@("=P<F5P96YD
M071T<FEB=71E<R<@(#T^("<G+"`@("`@("`@("`@("`@("`@("`@+R\@<')E
M<&5N9"!S=')I;F<@9F]R(&%T=')I8G5T97,-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`G:6YD96YT071T<FEB=71E<R<@("`]/B!F86QS92P@("`@("`@
M("`@("`@("`@("\O(&EN9&5N="!T:&4@871T<FEB=71E<RP@:68@<V5T('1O
M("=?875T;R<L(&ET('=I;&P@:6YD96YT(&%T=')I8G5T97,@<V\@=&AE>2!A
M;&P@<W1A<G0@870@=&AE('-A;64@8V]L=6UN#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@)VUO9&4G("`@("`@("`@("`@("`@/3X@)W-I;7!L97AM;"<L
M("`@("`@("`@("`@("\O('5S92`G<VEM<&QE>&UL)R!T;R!U<V4@<&%R96YT
M(&YA;64@87,@=&%G;F%M92!I9B!T<F%N<V9O<FUI;F<@86X@:6YD97AE9"!A
M<G)A>0T*("`@("`@("`@("`@("`@("`@("`@("`@("=A9&1$;V-T>7!E)R`@
M("`@("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@861D(&$@9&]C
M='EP92!D96-L87)A=&EO;@T*("`@("`@("`@("`@("`@("`@("`@("`@("=D
M;V-T>7!E)R`@("`@("`@("`@(#T^(&YU;&PL("`@("`@("`@("`@("`@("`@
M+R\@<W5P<&QY(&$@<W1R:6YG(&]R(&%N(&%R<F%Y('=I=&@@:60@86YD('5R
M:2`H>T!S964@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F=E=$1O8W1Y<&5$
M96-L87)A=&EO;B@I?0T*("`@("`@("`@("`@("`@("`@("`@("`@("=R;V]T
M3F%M92<@("`@("`@("`@(#T^("=P86-K86=E)RP@("`@("`@("`@("`@("`@
M("`O+R!N86UE(&]F('1H92!R;V]T('1A9PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("=R;V]T071T<FEB=71E<R<@("`@(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)S(N,"<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN<R<@/3X@)VAT='`Z
M+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,BXP)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)WAM;&YS.G1A<VMS)R`]/B`G:'1T<#HO+W!E
M87(N<&AP+FYE="]D=&0O=&%S:W,M,2XP)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)WAM;&YS.GAS:2<@/3X@)VAT='`Z+R]W=W<N=S,N;W)G
M+S(P,#$O6$U,4V-H96UA+6EN<W1A;F-E)RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)WAS:3IS8VAE;6%,;V-A=&EO;B<@/3X@)VAT='`Z+R]P
M96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,`T*:'1T<#HO+W!E87(N<&AP+FYE
M="]D=&0O=&%S:W,M,2XP+GAS9`T*:'1T<#HO+W!E87(N<&AP+FYE="]D=&0O
M<&%C:V%G92TR+C`-"FAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M
M,BXP+GAS9"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@*2P@("`@("`@
M("`@("`@("`O+R!A='1R:6)U=&5S(&]F('1H92!R;V]T('1A9PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&5S07)R87DG("`@(#T^("=A
M='1R:6)S)RP@("`@("`@("`@("`@("`@("`O+R!A;&P@=F%L=65S(&EN('1H
M:7,@:V5Y('=I;&P@8F4@=')E871E9"!A<R!A='1R:6)U=&5S#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@)V-O;G1E;G1.86UE)R`@("`@("`@/3X@)U]C
M;VYT96YT)RP@("`@("`@("`@("`@("`@("`@+R\@=&AI<R!V86QU92!W:6QL
M(&)E('5S960@9&ER96-T;'D@87,@8V]N=&5N="P@:6YS=&5A9"!O9B!C<F5A
M=&EN9R!A(&YE=R!T86<L(&UA>2!O;FQY(&)E('5S960@:6X@8V]N:G5C=&EO
M;B!W:71H(&%T=')I8G5T97-!<G)A>0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("=B96%U=&EF>49I;&5L:7-T)R`@(#T^(&9A;'-E+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("=E;F-O9&EN9R<@/3X@)U541BTX)RP-"B`@("`@
M("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("\J*@T*("`@("H@;W!T:6]N
M<R!F;W(@=&AE('-E<FEA;&EZ871I;VX-"B`@("`J($!A8V-E<W,@<')I=F%T
M90T*("`@("H@0'9A<B!A<G)A>2`D;W!T:6]N<PT*("`@("HO#0H@("`@=F%R
M("1O<'1I;VYS(#T@87)R87DH*3L-"@T*("`@+RHJ#0H@("`@*B!C=7)R96YT
M('1A9R!D97!T:`T*("`@("H@0'9A<B!I;G1E9V5R("1?=&%G1&5P=&@-"B`@
M("`J+PT*("`@('9A<B`D7W1A9T1E<'1H(#T@,#L-"@T*("`@+RHJ#0H@("`@
M*B!S97)I;&EA;&EZ960@<F5P<F5S96YT871I;VX@;V8@=&AE(&1A=&$-"B`@
M("`J($!V87(@<W1R:6YG("1?<V5R:6%L:7IE9$1A=&$-"B`@("`J+PT*("`@
M('9A<B`D7W-E<FEA;&EZ961$871A(#T@;G5L;#L-"B`@("`O*BH-"B`@("`@
M*B!`=F%R(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B\-"B`@("!V87(@
M)%]P86-K86=E9FEL93L-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]0
M86-K86=E1FEL95]V,@T*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R*"8D<&%C:V%G969I;&4I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE(#T@)B1P86-K86=E9FEL93L-
M"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`<F5T=7)N('-T<FEN9PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N(&=E=%!A8VMA9V5R5F5R<VEO;B@I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)S$N-"XY)SL-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E<@T*("`@("`J($!P87)A;2!B
M;V]L(&=E;F5R871E(&$@+G1G>B!O<B!A("YT87(-"B`@("`@*B!`<&%R86T@
M<W1R:6YG?&YU;&P@=&5M<&]R87)Y(&1I<F5C=&]R>2!T;R!P86-K86=E(&EN
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@=&]49WHH)B1P86-K86=E<BP@)&-O
M;7!R97-S(#T@=')U92P@)'=H97)E(#T@;G5L;"D-"B`@("![#0H@("`@("`@
M("1A(#T@;G5L;#L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YT;U1G>C(H)'!A
M8VMA9V5R+"`D82P@)&-O;7!R97-S+"`D=VAE<F4I.PT*("`@('T-"@T*("`@
M("\J*@T*("`@("`J(%!A8VMA9V4@=7`@8F]T:"!A('!A8VMA9V4N>&UL(&%N
M9"!P86-K86=E,BYX;6P@9F]R('1H92!S86UE(')E;&5A<V4-"B`@("`@*B!`
M<&%R86T@4$5!4E]086-K86=E<@T*("`@("`J($!P87)A;2!014%27U!A8VMA
M9V5&:6QE7W8Q#0H@("`@("H@0'!A<F%M(&)O;VP@9V5N97)A=&4@82`N=&=Z
M(&]R(&$@+G1A<@T*("`@("`J($!P87)A;2!S=')I;F=\;G5L;"!T96UP;W)A
M<GD@9&ER96-T;W)Y('1O('!A8VMA9V4@:6X-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!T;U1G>C(H)B1P86-K86=E<BP@)B1P9C$L("1C;VUP<F5S<R`]('1R
M=64L("1W:&5R92`](&YU;&PI#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N
M8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@(&EF("@A)'1H:7,M/E]P
M86-K86=E9FEL92T^:7-%<75I=F%L96YT*"1P9C$I*2![#0H@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V
M,CHZ=&]49WHZ("(G("X-"B`@("`@("`@("`@("`@("!B87-E;F%M92@D<&8Q
M+3YG971086-K86=E1FEL92@I*2`N#0H@("`@("`@("`@("`@("`@)R(@:7,@
M;F]T(&5Q=6EV86QE;G0@=&\@(B<@+B!B87-E;F%M92@D=&AI<RT^7W!A8VMA
M9V5F:6QE+3YG971086-K86=E1FEL92@I*0T*("`@("`@("`@("`@("`@("X@
M)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'=H97)E(#T]/2!N=6QL
M*2![#0H@("`@("`@("`@("!I9B`H(2@D=VAE<F4@/2!3>7-T96TZ.FUK=&5M
M<"AA<G)A>2@G+60G*2DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z.B!M
M:W1E;7`@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS
M96EF("@A0%-Y<W1E;3HZ;6M$:7(H87)R87DH)RUP)RP@)'=H97)E*2DI('L-
M"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A
M8VMA9V5F:6QE7W8R.CIT;U1G>CH@(B<@+B`D=VAE<F4@+B`G(B!C;W5L9"<@
M+@T*("`@("`@("`@("`@("`@("<@;F]T(&)E(&-R96%T960G*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H9FEL95]E>&ES=',H)'=H97)E("X@1$E214-4
M3U)97U-%4$%2051/4B`N("=P86-K86=E+GAM;"<I("8F#0H@("`@("`@("`@
M("`@("%I<U]F:6QE*"1W:&5R92`N($1)4D5#5$]265]315!!4D%43U(@+B`G
M<&%C:V%G92YX;6PG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z.B!U;F%B;&4@
M=&\@<V%V92!P86-K86=E+GAM;"!A<R<@+@T*("`@("`@("`@("`@("`@("<@
M(B<@+B`D=VAE<F4@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4N
M>&UL(B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K
M86=E9FEL92T^=F%L:61A=&4H4$5!4E]604Q)1$%415]004-+04=)3D<I*2![
M#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]0
M86-K86=E9FEL95]V,CHZ=&]49WHZ(&EN=F%L:60@<&%C:V%G92YX;6PG*3L-
M"B`@("`@("`@?0T*("`@("`@("`D97AT(#T@)&-O;7!R97-S(#\@)RYT9WHG
M(#H@)RYT87(G.PT*("`@("`@("`D<&MG=F5R(#T@)'1H:7,M/E]P86-K86=E
M9FEL92T^9V5T4&%C:V%G92@I("X@)RTG("X@)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D9&5S=%]P86-K86=E(#T@9V5T
M8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!K9W9E<B`N("1E>'0[
M#0H@("`@("`@(&EF("AF:6QE7V5X:7-T<RAG971C=V0H*2`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X="D@)B8-"B`@("`@("`@("`@
M("`@(6ES7V9I;&4H9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)'!K9W9E<B`N("1E>'0I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]49WHZ(&-A;FYO
M="!C<F5A=&4@=&=Z(&9I;&4@(B<@+@T*("`@("`@("`@("`@("`@(&=E=&-W
M9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V97(@+B`D97AT("X@
M)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!K9V9I;&4@/2`D=&AI
M<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E1FEL92@I*2![#0H@("`@("`@
M("`@("`D<&MG9&ER(#T@9&ER;F%M92AR96%L<&%T:"@D<&MG9FEL92DI.PT*
M("`@("`@("`@("`@)'!K9V9I;&4@/2!B87-E;F%M92@D<&MG9FEL92D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]49WHZ('!A8VMA9V4@
M9FEL92!O8FIE8W0@;75S="`G("X-"B`@("`@("`@("`@("`@("`G8F4@8W)E
M871E9"!F<F]M(&$@<F5A;"!F:6QE)RD[#0H@("`@("`@('T-"B`@("`@("`@
M+R\@>WM[($-R96%T92!T:&4@<&%C:V%G92!F:6QE(&QI<W0-"B`@("`@("`@
M)&9I;&5L:7-T(#T@87)R87DH*3L-"B`@("`@("`@)&D@/2`P.PT*("`@("`@
M("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YF;&%T=&5N1FEL96QI<W0H*3L-"B`@
M("`@("`@)&-O;G1E;G1S(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T0V]N
M=&5N=',H*3L-"B`@("`@("`@:68@*&ES<V5T*"1C;VYT96YT<ULG8G5N9&QE
M9'!A8VMA9V4G72DI('L@+R\@8G5N9&QE<R!O9B!P86-K86=E<PT*("`@("`@
M("`@("`@)&-O;G1E;G1S(#T@)&-O;G1E;G1S6R=B=6YD;&5D<&%C:V%G92==
M.PT*("`@("`@("`@("`@:68@*"%I<W-E="@D8V]N=&5N='-;,%TI*2![#0H@
M("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@87)R87DH)&-O;G1E;G1S*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P86-K86=E1&ER(#T@)'=H
M97)E.PT*("`@("`@("`@("`@9F]R96%C:"`H)&-O;G1E;G1S(&%S("1I(#T^
M("1P86-K86=E*2![#0H@("`@("`@("`@("`@("`@)&9N86UE(#T@)'!A8VMA
M9V4[#0H@("`@("`@("`@("`@("`@)&9I;&4@/2`D<&MG9&ER("X@1$E214-4
M3U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@("`@("`@("`@("!I9B`H
M(69I;&5?97AI<W1S*"1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'!A8VMA9V5R+3YR86ES945R<F]R*")&:6QE(&1O97,@;F]T(&5X
M:7-T.B`D9FYA;64B*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)'1F:6QE(#T@)'!A8VMA9V5$:7(@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)&9N86UE.PT*("`@("`@("`@("`@("`@(%-Y<W1E;3HZ;6MD:7(H
M87)R87DH)RUP)RP@9&ER;F%M92@D=&9I;&4I*2D[#0H@("`@("`@("`@("`@
M("`@8V]P>2@D9FEL92P@)'1F:6QE*3L-"B`@("`@("`@("`@("`@("`D9FEL
M96QI<W1;)&DK*UT@/2`D=&9I;&4[#0H@("`@("`@("`@("`@("`@)'!A8VMA
M9V5R+3YL;V<H,BP@(D%D9&EN9R!P86-K86=E("1F;F%M92(I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!](&5L<V4@>R`O+R!N;W)M86P@<&%C:V%G97,-
M"B`@("`@("`@("`@("1C;VYT96YT<R`]("1C;VYT96YT<ULG9&ER)UU;)V9I
M;&4G73L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&-O;G1E;G1S6S!=*2D@
M>PT*("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&%R<F%Y*"1C;VYT96YT
M<RD[#0H@("`@("`@("`@("!]#0H@("`@#0H@("`@("`@("`@("`D<&%C:V%G
M941I<B`]("1W:&5R93L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VYT96YT
M<R!A<R`D:2`]/B`D9FEL92D@>PT*("`@("`@("`@("`@("`@("1F;F%M92`]
M("1F:6QE6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@("`@("`D
M871T<R`]("1F:6QE6R=A='1R:6)S)UT[#0H@("`@("`@("`@("`@("`@)&]R
M:6<@/2`D9FEL93L-"B`@("`@("`@("`@("`@("`D9FEL92`]("1P:V=D:7(@
M+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9N86UE.PT*("`@("`@("`@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R;W(H(D9I;&4@9&]E
M<R!N;W0@97AI<W0Z("1F;F%M92(I.PT*("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("1T9FEL92`]("1P86-K86=E1&ER
M("X@1$E214-43U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@("`@("`@
M("`@("`@("`@=6YS970H)&]R:6=;)V%T=')I8G,G72D[#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D;W)I9RDI('L@+R\@9FEL92!W:71H('1A
M<VMS#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!R=6X@86YY('!A8VMA
M9V4M=&EM92!T87-K<PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`](&9I;&5?9V5T7V-O
M;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9P(#T@9F]P96XH
M)&9I;&4L(")R(BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O
M;G1E;G1S(#T@0&9R96%D*"1F<"P@9FEL97-I>F4H)&9I;&4I*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1O<FEG(&%S("1T86<@/3X@)')A=RD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T86<@/2!S=')?<F5P;&%C92@D=&AI<RT^7W!A
M8VMA9V5F:6QE+3YG971487-K<TYS*"D@+B`G.B<L("<G+"`D=&%G*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&%S:R`](")014%27U1A<VM?
M)'1A9R([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1A<VL@/2`F
M;F5W("1T87-K*"1T:&ES+3Y?<&%C:V%G969I;&4M/E]C;VYF:6<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G969I
M;&4M/E]L;V=G97(L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05)?5$%32U]004-+04=%*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&%S:RT^:6YI="@D<F%W+"`D871T<RP@;G5L;"D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<R`]("1T87-K+3YS=&%R=%-E<W-I
M;VXH)'1H:7,M/E]P86-K86=E9FEL92P@)&-O;G1E;G1S+"`D=&9I;&4I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A)')E<RD@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L@+R\@<VMI
M<"!T:&ES('1A<VL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1R97,[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C;VYT96YT<R`]("1R97,[("\O
M('-A=F4@8VAA;F=E<PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%-Y
M<W1E;3HZ;6MD:7(H87)R87DH)RUP)RP@9&ER;F%M92@D=&9I;&4I*2D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=P(#T@9F]P96XH)'1F:6QE
M+"`B=V(B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F=W)I=&4H
M)'=P+"`D8V]N=&5N=',I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9C;&]S92@D=W`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M9FEL95]E>&ES=',H)'1F:6QE*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@4WES=&5M.CIM:V1I<BAA<G)A>2@G+7`G+"!D:7)N86UE*"1T9FEL92DI
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O<'DH)&9I;&4L("1T9FEL
M92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)&9I;&5L:7-T6R1I*RM=(#T@)'1F:6QE.PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YS971&:6QE071T<FEB=71E*"1F
M;F%M92P@)VUD-7-U;2<L(&UD-5]F:6QE*"1T9FEL92DL("1I("T@,2D[#0H@
M("`@("`@("`@("`@("`@("`@("1P86-K86=E<BT^;&]G*#(L(")!9&1I;F<@
M9FEL92`D9FYA;64B*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@("`@("\O('U]?0T*("`@("`@("!I
M9B`H)'!F,2`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&YA;64@/2`G<&%C
M:V%G93(N>&UL)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1N
M86UE(#T@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@?0T*("`@("`@("`D<&%C
M:V%G97AM;"`]("1T:&ES+3YT;U!A8VMA9V5&:6QE*"1W:&5R92P@4$5!4E]6
M04Q)1$%415]004-+04=)3D<L("1N86UE*3L-"B`@("`@("`@:68@*"1P86-K
M86=E>&UL*2![#0H@("`@("`@("`@("`D=&%R(#TF(&YE=R!!<F-H:79E7U1A
M<B@D9&5S=%]P86-K86=E+"`D8V]M<')E<W,I.PT*("`@("`@("`@("`@)'1A
M<BT^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[("\O(%A8
M6"!$;VXG="!P<FEN="!E<G)O<G,-"B`@("`@("`@("`@("\O("TM+2TM($-R
M96%T97,@=VET:"!T:&4@<&%C:V%G92YX;6P@9FEL90T*("`@("`@("`@("`@
M)&]K(#T@)'1A<BT^8W)E871E36]D:69Y*&%R<F%Y*"1P86-K86=E>&UL*2P@
M)R<L("1W:&5R92D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M;VLI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P86-K86=E<BT^<F%I
M<V5%<G)O<B@D;VLI.PT*("`@("`@("`@("`@?2!E;'-E:68@*"$D;VLI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'!A8VMA9V5R+3YR86ES945R<F]R
M*"=014%27U!A8VMA9V5F:6QE7W8R.CIT;U1G>B@I.B!A9&1I;F<@)R`N("1N
M86UE("X-"B`@("`@("`@("`@("`@("`@("`@)R!F86EL960G*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("\O("TM+2TM($%D9"!T:&4@8V]N=&5N
M="!O9B!T:&4@<&%C:V%G90T*("`@("`@("`@("`@:68@*"$D=&%R+3YA9&1-
M;V1I9GDH)&9I;&5L:7-T+"`D<&MG=F5R+"`D=VAE<F4I*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N("1P86-K86=E<BT^<F%I<V5%<G)O<B@-"B`@("`@
M("`@("`@("`@("`@("`@)U!%05)?4&%C:V%G969I;&5?=C(Z.G1O5&=Z*"DZ
M('1A<F)A;&P@8W)E871I;VX@9F%I;&5D)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`O+R!A9&0@=&AE('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP
M#0H@("`@("`@("`@("!I9B`H)'!F,2`A/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@("`@("1P9F=E;B`]("8D<&8Q+3YG971$969A=6QT1V5N97)A=&]R*"D[
M#0H@("`@("`@("`@("`@("`@)'!A8VMA9V5X;6PQ(#T@)'!F9V5N+3YT;U!A
M8VMA9V5&:6QE*"1W:&5R92P@4$5!4E]604Q)1$%415]004-+04=)3D<L#0H@
M("`@("`@("`@("`@("`@("`@("=P86-K86=E+GAM;"<L('1R=64I.PT*("`@
M("`@("`@("`@("`@(&EF("@A)'1A<BT^861D36]D:69Y*&%R<F%Y*"1P86-K
M86=E>&UL,2DL("<G+"`D=VAE<F4I*2![#0H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D<&%C:V%G97(M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@
M("`@("`@("`@("`G4$5!4E]086-K86=E9FEL95]V,CHZ=&]49WHH*3H@861D
M:6YG('!A8VMA9V4N>&UL(&9A:6QE9"<I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D9&5S=%]P86-K
M86=E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=&]086-K
M86=E1FEL92@D=VAE<F4@/2!N=6QL+"`D<W1A=&4@/2!014%27U9!3$E$051%
M7TY/4DU!3"P@)&YA;64@/2`G<&%C:V%G92YX;6PG*0T*("`@('L-"B`@("`@
M("`@:68@*"$D=&AI<RT^7W!A8VMA9V5F:6QE+3YV86QI9&%T92@D<W1A=&4I
M*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!
M4E]086-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL93H@:6YV86QI9"!P86-K
M86=E+GAM;"<L#0H@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@
M)'1H:7,M/E]P86-K86=E9FEL92T^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"DI
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=VAE<F4@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@(&EF("@A*"1W:&5R92`](%-Y<W1E;3HZ;6MT96UP*&%R
M<F%Y*"<M9"<I*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL
M93H@;6MT96UP(&9A:6QE9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V5I9B`H(4!3>7-T96TZ.FUK1&ER*&%R<F%Y*"<M<"<L("1W:&5R92DI
M*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!
M4E]086-K86=E9FEL95]V,CHZ=&]086-K86=E1FEL93H@(B<@+B`D=VAE<F4@
M+B`G(B!C;W5L9"<@+@T*("`@("`@("`@("`@("`@("<@;F]T(&)E(&-R96%T
M960G*3L-"B`@("`@("`@?0T*("`@("`@("`D;F5W<&MG9FEL92`]("1W:&5R
M92`N($1)4D5#5$]265]315!!4D%43U(@+B`D;F%M93L-"B`@("`@("`@)&YP
M(#T@0&9O<&5N*"1N97=P:V=F:6QE+"`G=V(G*3L-"B`@("`@("`@:68@*"$D
M;G`I('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=0
M14%27U!A8VMA9V5F:6QE7W8R.CIT;U!A8VMA9V5&:6QE.B!U;F%B;&4@=&\@
M<V%V92`G("X-"B`@("`@("`@("`@("`@("(D;F%M92!A<R`D;F5W<&MG9FEL
M92(I.PT*("`@("`@("!]#0H@("`@("`@(&9W<FET92@D;G`L("1T:&ES+3YT
M;UAM;"@D<W1A=&4I*3L-"B`@("`@("`@9F-L;W-E*"1N<"D[#0H@("`@("`@
M(')E='5R;B`D;F5W<&MG9FEL93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B`F
M=&]6,B@I#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E
M9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971U<FX@86X@6$U,
M(&1O8W5M96YT(&)A<V5D(&]N('1H92!P86-K86=E(&EN9F\@*&%S(')E='5R
M;F5D#0H@("`@("H@8GD@=&AE(%!%05)?0V]M;6]N.CII;F9O1G)O;2H@;65T
M:&]D<RDN#0H@("`@("H-"B`@("`@*B!`<F5T=7)N('-T<FEN9R!834P@9&%T
M80T*("`@("`J+PT*("`@(&9U;F-T:6]N('1O6&UL*"1S=&%T92`](%!%05)?
M5D%,241!5$5?3D]234%,+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YS971$871E*&1A=&4H)UDM
M;2UD)RDI.PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE+3YS9714:6UE
M*&1A=&4H)T@Z:3IS)RDI.PT*("`@("`@("!I9B`H(21T:&ES+3Y?<&%C:V%G
M969I;&4M/G9A;&ED871E*"1S=&%T92DI('L-"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?87)R87DH)&]P
M=&EO;G,I*2![#0H@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O<'1I;VYS*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@
M)'1H:7,M/E]D969A=6QT3W!T:6]N<SL-"B`@("`@("`@?0T*("`@("`@("`D
M87)R(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T07)R87DH*3L-"B`@("`@
M("`@:68@*&ES<V5T*"1A<G);)V9I;&5L:7-T)UTI*2![#0H@("`@("`@("`@
M("!U;G-E="@D87)R6R=F:6QE;&ES="==*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H:7-S970H)&%R<ELG7VQA<W1V97)S:6]N)UTI*2![#0H@("`@("`@
M("`@("!U;G-E="@D87)R6R=?;&%S='9E<G-I;VXG72D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1S=&%T92!>(%!%05)?5D%,241!5$5?4$%#2T%'24Y'
M("8F("%I<W-E="@D87)R6R=B=6YD;&4G72DI('L-"B`@("`@("`@("`@("1U
M<V4@/2`D=&AI<RT^7W)E8W5R<VEV95AM;$9I;&5L:7-T*"1A<G);)V-O;G1E
M;G1S)UU;)V1I<B==6R=F:6QE)UTI.PT*("`@("`@("`@("`@=6YS970H)&%R
M<ELG8V]N=&5N=',G75LG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@("`@("!I
M9B`H:7-S970H)'5S95LG9&ER)UTI*2![#0H@("`@("`@("`@("`@("`@)&%R
M<ELG8V]N=&5N=',G75LG9&ER)UU;)V1I<B==(#T@)'5S95LG9&ER)UT[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'5S95LG9FEL
M92==*2D@>PT*("`@("`@("`@("`@("`@("1A<G);)V-O;G1E;G1S)UU;)V1I
M<B==6R=F:6QE)UT@/2`D=7-E6R=F:6QE)UT[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D=&AI<RT^;W!T:6]N<ULG8F5A=71I9GE&:6QE;&ES="==
M(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D87)R6R=A='1R:6)S)UU;
M)W!A8VMA9V5R=F5R<VEO;B==(#T@)S$N-"XY)SL-"B`@("`@("`@:68@*"1T
M:&ES+3YS97)I86QI>F4H)&%R<BP@)&]P=&EO;G,I*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N(")<;B([#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*#0H@("`@
M9G5N8W1I;VX@7W)E8W5R<VEV95AM;$9I;&5L:7-T*"1L:7-T*0T*("`@('L-
M"B`@("`@("`@)&1I<G,@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S970H
M)&QI<W1;)V%T=')I8G,G72DI('L-"B`@("`@("`@("`@("1F:6QE(#T@)&QI
M<W1;)V%T=')I8G,G75LG;F%M92==.PT*("`@("`@("`@("`@=6YS970H)&QI
M<W1;)V%T=')I8G,G75LG;F%M92==*3L-"B`@("`@("`@("`@("1A='1R:6)U
M=&5S(#T@)&QI<W1;)V%T=')I8G,G73L-"B`@("`@("`@("`@("1T:&ES+3Y?
M861D1&ER*"1D:7)S+"!E>'!L;V1E*"<O)RP@9&ER;F%M92@D9FEL92DI+"`D
M9FEL92P@)&%T=')I8G5T97,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@9F]R96%C:"`H)&QI<W0@87,@)&$I('L-"B`@("`@("`@("`@("`@
M("`D9FEL92`]("1A6R=A='1R:6)S)UU;)VYA;64G73L-"B`@("`@("`@("`@
M("`@("`D871T<FEB=71E<R`]("1A6R=A='1R:6)S)UT[#0H@("`@("`@("`@
M("`@("`@=6YS970H)&%;)V%T=')I8G,G72D[#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/E]A9&1$:7(H)&1I<G,L(&5X<&QO9&4H)R\G+"!D:7)N86UE*"1F
M:6QE*2DL("1F:6QE+"`D871T<FEB=71E<RP@)&$I.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9F]R;6%T1&ER*"1D:7)S
M*3L-"B`@("`@("`@)'1H:7,M/E]D949O<FUA="@D9&ER<RD[#0H@("`@("`@
M(')E='5R;B`D9&ER<SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?861D1&ER
M*"8D9&ER<RP@)&1I<BP@)&9I;&4@/2!N=6QL+"`D871T<FEB=71E<R`](&YU
M;&PL("1T87-K<R`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H(21T87-K
M<RD@>PT*("`@("`@("`@("`@)'1A<VMS(#T@87)R87DH*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H)&1I<B`]/2!A<G)A>2@I('Q\("1D:7(@/3T@87)R
M87DH)RXG*2D@>PT*("`@("`@("`@("`@)&1I<G-;)V9I;&4G75MB87-E;F%M
M92@D9FEL92E=(#T@)'1A<VMS.PT*("`@("`@("`@("`@)&%T=')I8G5T97-;
M)VYA;64G72`](&)A<V5N86UE*"1F:6QE*3L-"B`@("`@("`@("`@("1D:7)S
M6R=F:6QE)UU;8F%S96YA;64H)&9I;&4I75LG871T<FEB<R==(#T@)&%T=')I
M8G5T97,[#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@
M("`@)&-U<F1I<B`](&%R<F%Y7W-H:69T*"1D:7(I.PT*("`@("`@("!I9B`H
M(6ES<V5T*"1D:7)S6R=D:7(G75LD8W5R9&ER72DI('L-"B`@("`@("`@("`@
M("1D:7)S6R=D:7(G75LD8W5R9&ER72`](&%R<F%Y*"D[#0H@("`@("`@('T-
M"B`@("`@("`@)'1H:7,M/E]A9&1$:7(H)&1I<G-;)V1I<B==6R1C=7)D:7)=
M+"`D9&ER+"`D9FEL92P@)&%T=')I8G5T97,L("1T87-K<RD[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@7V9O<FUA=$1I<B@F)&1I<G,I#0H@("`@>PT*("`@
M("`@("!I9B`H(6-O=6YT*"1D:7)S*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*"D[#0H@("`@("`@('T-"B`@("`@("`@)&YE=V1I<G,@/2!A<G)A
M>2@I.PT*("`@("`@("!I9B`H:7-S970H)&1I<G-;)V1I<B==*2D@>PT*("`@
M("`@("`@("`@)&YE=V1I<G-;)V1I<B==(#T@)&1I<G-;)V1I<B==.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D9&ER<ULG9FEL92==*2D@>PT*
M("`@("`@("`@("`@)&YE=V1I<G-;)V9I;&4G72`]("1D:7)S6R=F:6QE)UT[
M#0H@("`@("`@('T-"B`@("`@("`@)&1I<G,@/2`D;F5W9&ER<SL-"B`@("`@
M("`@:68@*&ES<V5T*"1D:7)S6R=D:7(G72DI('L-"B`@("`@("`@("`@('5K
M<V]R="@D9&ER<ULG9&ER)UTL("=S=')N871C87-E8VUP)RD[#0H@("`@("`@
M("`@("!F;W)E86-H("@D9&ER<ULG9&ER)UT@87,@)&1I<B`]/B`D8V]N=&5N
M=',I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V9O<FUA=$1I<B@D9&ER
M<ULG9&ER)UU;)&1I<ETI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D9&ER<ULG9FEL92==*2D@>PT*("`@("`@("`@
M("`@=6MS;W)T*"1D:7)S6R=F:6QE)UTL("=S=')N871C87-E8VUP)RD[#0H@
M("`@("`@('T[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V1E1F]R;6%T*"8D
M9&ER<RD-"B`@("![#0H@("`@("`@(&EF("@A8V]U;G0H)&1I<G,I*2![#0H@
M("`@("`@("`@("!R971U<FX@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@
M("`D;F5W9&ER<R`](&%R<F%Y*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&ER
M<ULG9&ER)UTI*2![#0H@("`@("`@("`@("!F;W)E86-H("@D9&ER<ULG9&ER
M)UT@87,@)&1I<B`]/B`D8V]N=&5N=',I('L-"B`@("`@("`@("`@("`@("`D
M;F5W9&ER(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("`D;F5W9&ER6R=A
M='1R:6)S)UU;)VYA;64G72`]("1D:7([#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D949O<FUA="@D8V]N=&5N=',I.PT*("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1C;VYT96YT<R!A<R`D=&%G(#T^("1V86PI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&YE=V1I<ELD=&%G72`]("1V86P[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1N97=D:7)S6R=D:7(G75M=(#T@
M)&YE=V1I<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AC;W5N
M="@D;F5W9&ER<ULG9&ER)UTI(#T](#$I('L-"B`@("`@("`@("`@("`@("`D
M;F5W9&ER<ULG9&ER)UT@/2`D;F5W9&ER<ULG9&ER)UU;,%T[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D:7)S6R=F
M:6QE)UTI*2![#0H@("`@("`@("`@("!F;W)E86-H("@D9&ER<ULG9FEL92==
M(&%S("1N86UE(#T^("1F:6QE*2![#0H@("`@("`@("`@("`@("`@)&YE=V1I
M<G-;)V9I;&4G75M=(#T@)&9I;&4[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H8V]U;G0H)&YE=V1I<G-;)V9I;&4G72D@/3T@,2D@>PT*("`@
M("`@("`@("`@("`@("1N97=D:7)S6R=F:6QE)UT@/2`D;F5W9&ER<ULG9FEL
M92==6S!=.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1D
M:7)S(#T@)&YE=V1I<G,[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@*B!R97-E
M="!A;&P@;W!T:6]N<R!T;R!D969A=6QT(&]P=&EO;G,-"B`@("`J#0H@("`@
M*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<V5E("`@("`@<V5T3W!T:6]N
M*"DL(%A-3%]5;G-E<FEA;&EZ97(H*0T*("`@("HO#0H@("`@9G5N8W1I;VX@
M<F5S971/<'1I;VYS*"D-"B`@("![#0H@("`@("`@("1T:&ES+3YO<'1I;VYS
M(#T@)'1H:7,M/E]D969A=6QT3W!T:6]N<SL-"B`@("!]#0H-"B`@("\J*@T*
M("`@("H@<V5T(&%N(&]P=&EO;@T*("`@("H-"B`@("`J(%EO=2!C86X@=7-E
M('1H:7,@;65T:&]D(&EF('EO=2!D;R!N;W0@=V%N="!T;R!S970@86QL(&]P
M=&EO;G,@:6X@=&AE(&-O;G-T<G5C=&]R#0H@("`@*@T*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PT*("`@("H@0'-E92`@("`@(')E<V5T3W!T:6]N*"DL(%A-
M3%]397)I86QI>F5R*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N('-E=$]P=&EO
M;B@D;F%M92P@)'9A;'5E*0T*("`@('L-"B`@("`@("`@)'1H:7,M/F]P=&EO
M;G-;)&YA;65=(#T@)'9A;'5E.PT*("`@('T-"B`@("`-"B`@("\J*@T*("`@
M("H@<V5T<R!S979E<F%L(&]P=&EO;G,@870@;VYC90T*("`@("H-"B`@("`J
M(%EO=2!C86X@=7-E('1H:7,@;65T:&]D(&EF('EO=2!D;R!N;W0@=V%N="!T
M;R!S970@86QL(&]P=&EO;G,@:6X@=&AE(&-O;G-T<G5C=&]R#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-E92`@("`@(')E<V5T
M3W!T:6]N*"DL(%A-3%]5;G-E<FEA;&EZ97(H*2P@<V5T3W!T:6]N*"D-"B`@
M("`J+PT*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H)&]P=&EO;G,I#0H@("`@
M>PT*("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES
M+3YO<'1I;VYS+"`D;W!T:6]N<RD[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M('-E<FEA;&EZ92!D871A#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@("1D871A(&1A=&$@=&\@<V5R
M:6%L:7IE#0H@("`@*B!`<F5T=7)N("`@8F]O;&5A;B`@=')U92!O;B!S=6-C
M97-S+"!P96%R(&5R<F]R(&]N(&9A:6QU<F4-"B`@("`J+PT*("`@(&9U;F-T
M:6]N('-E<FEA;&EZ92@D9&%T82P@)&]P=&EO;G,@/2!N=6QL*0T*("`@('L-
M"B`@("`@("`@+R\@:68@;W!T:6]N<R!H879E(&)E96X@<W!E8VEF:65D+"!U
M<V4@=&AE;2!I;G-T96%D#0H@("`@("`@("\O(&]F('1H92!P<F5V:6]U<VQY
M(&1E9FEN960@;VYE<PT*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I
M*2![#0H@("`@("`@("`@("`D;W!T:6]N<T)A:R`]("1T:&ES+3YO<'1I;VYS
M.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=O=F5R<FED94]P
M=&EO;G,G72D@)B8@)&]P=&EO;G-;)V]V97)R:61E3W!T:6]N<R==(#T]('1R
M=64I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y
M7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P=&EO;G,L("1O<'1I;VYS*3L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]P
M=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^;W!T:6]N<RP@)&]P=&EO;G,I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&5L<V4@>PT*
M("`@("`@("`@("`@)&]P=&EO;G-"86L@/2!N=6QL.PT*("`@("`@("!]#0H@
M("`@("`@(`T*("`@("`@("`O+R`@<W1A<G0@9&5P=&@@:7,@>F5R;PT*("`@
M("`@("`D=&AI<RT^7W1A9T1E<'1H(#T@,#L-"@T*("`@("`@("`D=&AI<RT^
M7W-E<FEA;&EZ961$871A(#T@)R<[#0H@("`@("`@("\O('-E<FEA;&EZ92!A
M;B!A<G)A>0T*("`@("`@("!I9B`H:7-?87)R87DH)&1A=&$I*2![#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F]P=&EO;G-;)W)O;W1.86UE)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'1A9TYA;64@/2`D=&AI<RT^;W!T:6]N
M<ULG<F]O=$YA;64G73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)'1A9TYA;64@/2`G87)R87DG.PT*("`@("`@("`@("`@?0T*
M#0H@("`@("`@("`@("`D=&AI<RT^7W-E<FEA;&EZ961$871A("X]("1T:&ES
M+3Y?<V5R:6%L:7IE07)R87DH)&1A=&$L("1T86=.86UE+"`D=&AI<RT^;W!T
M:6]N<ULG<F]O=$%T=')I8G5T97,G72D[#0H@("`@("`@('T-"B`@("`@("`@
M#0H@("`@("`@("\O(&%D9"!D;V-T>7!E(&1E8VQA<F%T:6]N#0H@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG861D1&]C='EP92==(#T]/2!T<G5E*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W-E<FEA;&EZ961$871A(#T@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F=E=$1O8W1Y<&5$
M96-L87)A=&EO;B@D=&%G3F%M92P@)'1H:7,M/F]P=&EO;G-;)V1O8W1Y<&4G
M72D-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI
M<RT^;W!T:6]N<ULG;&EN96)R96%K)UT-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+B`D=&AI<RT^7W-E<FEA;&EZ961$871A.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@(&)U:6QD('AM;"!D96-L87)A=&EO;@T*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V%D9$1E8VPG72D@>PT*("`@
M("`@("`@("`@)&%T=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YO<'1I;VYS6R=E;F-O9&EN9R==*2`I('L-"B`@("`@("`@
M("`@("`@("`D96YC;V1I;F<@/2`D=&AI<RT^;W!T:6]N<ULG96YC;V1I;F<G
M73L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5N
M8V]D:6YG(#T@;G5L;#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T
M:&ES+3Y?<V5R:6%L:7IE9$1A=&$@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH)S$N,"<L("1E
M;F-O9&EN9RD-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`D=&AI<RT^;W!T:6]N<ULG;&EN96)R96%K)UT-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^7W-E<FEA;&EZ961$871A
M.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`-"@D):68@*"1O<'1I
M;VYS0F%K("$]/2!N=6QL*2![#0H)"0DD=&AI<RT^;W!T:6]N<R`]("1O<'1I
M;VYS0F%K.PT*"0E]#0H)"0T*("`@("`@("!R971U<FX@('1R=64[#0H@("`@
M?0T*#0H@("`O*BH-"B`@("`J(&=E="!T:&4@<F5S=6QT(&]F('1H92!S97)I
M86QI>F%T:6]N#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J
M($!R971U<FX@<W1R:6YG('-E<FEA;&EZ960@6$U,#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971397)I86QI>F5D1&%T82@I#0H@("`@>PT*("`@("`@("!I
M9B`H)'1H:7,M/E]S97)I86QI>F5D1&%T82`]/2!N=6QL("D@>PT*("`@("`@
M("`@("`@<F5T=7)N("`D=&AI<RT^<F%I<V5%<G)O<B@G3F\@<V5R:6%L:7IE
M9"!D871A(&%V86EL86)L92X@57-E(%A-3%]397)I86QI>F5R.CIS97)I86QI
M>F4H*2!F:7)S="XG+"!834Q?4T5224%,25I%4E]%4E)/4E].3U]315))04Q)
M6D%424].*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]S
M97)I86QI>F5D1&%T83L-"B`@("!]#0H@("`@#0H@("`O*BH-"B`@("`J('-E
M<FEA;&EZ92!A;GD@=F%L=64-"B`@("`J#0H@("`@*B!4:&ES(&UE=&AO9"!C
M:&5C:W,@9F]R('1H92!T>7!E(&]F('1H92!V86QU92!A;F0@8V%L;',@=&AE
M(&%P<')O<')I871E(&UE=&AO9`T*("`@("H-"B`@("`J($!A8V-E<W,@<')I
M=F%T90T*("`@("H@0'!A<F%M("!M:7AE9"`@("`@)'9A;'5E#0H@("`@*B!`
M<&%R86T@('-T<FEN9R`@("`D=&%G3F%M90T*("`@("H@0'!A<F%M("!A<G)A
M>2`@("`@)&%T=')I8G5T97,-"B`@("`J($!R971U<FX@<W1R:6YG#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!?<V5R:6%L:7IE5F%L=64H)'9A;'5E+"`D=&%G
M3F%M92`](&YU;&PL("1A='1R:6)U=&5S(#T@87)R87DH*2D-"B`@("![#0H@
M("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2![#0H@("`@("`@("`@("`D
M>&UL(#T@)'1H:7,M/E]S97)I86QI>F5!<G)A>2@D=F%L=64L("1T86=.86UE
M+"`D871T<FEB=71E<RD[#0H@("`@("`@('T@96QS96EF("AI<U]O8FIE8W0H
M)'9A;'5E*2D@>PT*("`@("`@("`@("`@)'AM;"`]("1T:&ES+3Y?<V5R:6%L
M:7IE3V)J96-T*"1V86QU92P@)'1A9TYA;64I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`G<6YA;64G("`@("`@/3X@)'1A9TYA;64L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A='1R:6)U=&5S)R`]/B`D871T<FEB=71E
M<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;G1E;G0G("`@(#T^
M("1V86QU90T*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@
M("`@("1X;6P@/2`D=&AI<RT^7V-R96%T95A-3%1A9R@D=&%G*3L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)'AM;#L-"B`@("!]#0H@("`@#0H@("`O
M*BH-"B`@("`J('-E<FEA;&EZ92!A;B!A<G)A>0T*("`@("H-"B`@("`J($!A
M8V-E<W,@("!P<FEV871E#0H@("`@*B!`<&%R86T@("`@87)R87D@("`D87)R
M87D@("`@("`@87)R87D@=&\@<V5R:6%L:7IE#0H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("`D=&%G3F%M92`@("`@;F%M92!O9B!T:&4@<F]O="!T86<-"B`@
M("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R:6)U=&5S("!A='1R:6)U=&5S
M(&9O<B!T:&4@<F]O="!T86<-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S
M=')I;F<@("`@("!S97)I86QI>F5D(&1A=&$-"B`@("`J($!U<V5S("`@("!0
M14%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ:7-686QI
M9$YA;64H*2!T;R!C:&5C:RP@=VAE=&AE<B!K97D@:&%S('1O(&)E('-U8G-T
M:71U=&5D#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?<V5R:6%L:7IE07)R87DH
M)B1A<G)A>2P@)'1A9TYA;64@/2!N=6QL+"`D871T<FEB=71E<R`](&%R<F%Y
M*"DI#0H@("`@>PT*("`@("`@("`D7V-O;G1E;G0@/2!N=6QL.PT*("`@("`@
M("`-"B`@("`@("`@+RHJ#0H@("`@("`@("`J(&-H96-K(&9O<B!S<&5C:6%L
M(&%T=')I8G5T97,-"B`@("`@("`@("HO#0H@("`@("`@(&EF("@D=&AI<RT^
M;W!T:6]N<ULG871T<FEB=71E<T%R<F%Y)UT@(3T](&YU;&PI('L-"B`@("`@
M("`@("`@(&EF("AI<W-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;)V%T=')I
M8G5T97-!<G)A>2==72DI('L-"B`@("`@("`@("`@("`@("`D871T<FEB=71E
M<R`]("1A<G)A>5LD=&AI<RT^;W!T:6]N<ULG871T<FEB=71E<T%R<F%Y)UU=
M.PT*("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N
M<ULG871T<FEB=71E<T%R<F%Y)UU=*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("\J*@T*("`@("`@("`@("`@("H@8VAE8VL@9F]R('-P96-I86P@
M8V]N=&5N=`T*("`@("`@("`@("`@("HO#0H@("`@("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)V-O;G1E;G1.86UE)UT@(3T](&YU;&PI('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&%R<F%Y6R1T:&ES+3YO<'1I;VYS6R=C
M;VYT96YT3F%M92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@)%]C;VYT
M96YT(#T@)&%R<F%Y6R1T:&ES+3YO<'1I;VYS6R=C;VYT96YT3F%M92==73L-
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&%R<F%Y6R1T:&ES+3YO<'1I
M;VYS6R=C;VYT96YT3F%M92==72D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+RH-"B`@("`@("`@
M*B!I9B!M;V1E(&ES('-E="!T;R!S:6UP;&5834PL(&-H96-K('=H971H97(-
M"B`@("`@("`@*B!T:&4@87)R87D@:7,@87-S;V-I871I=F4@;W(@:6YD97AE
M9`T*("`@("`@("`J+PT*("`@("`@("!I9B`H:7-?87)R87DH)&%R<F%Y*2`F
M)B`D=&AI<RT^;W!T:6]N<ULG;6]D92==(#T]("=S:6UP;&5X;6PG*2![#0H@
M("`@("`@("`@("`D:6YD97AE9"`]('1R=64[#0H@("`@("`@("`@("!I9B`H
M(6-O=6YT*"1A<G)A>2DI('L-"B`@("`@("`@("`@("`@("`D:6YD97AE9"`]
M(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H
M)&%R<F%Y(&%S("1K97D@/3X@)'9A;"D@>PT*("`@("`@("`@("`@("`@(&EF
M("@A:7-?:6YT*"1K97DI*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F1E
M>&5D(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@
M:68@*"1I;F1E>&5D("8F("1T:&ES+3YO<'1I;VYS6R=M;V1E)UT@/3T@)W-I
M;7!L97AM;"<I('L-"B`@("`@("`@("`@("`@("`D<W1R:6YG(#T@)R<[#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y(&%S("1K97D@/3X@)'9A
M;"D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)V)E875T:69Y1FEL96QI<W0G72`F)B`D=&%G3F%M92`]/2`G9&ER)RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^7V-U
M<F1I<BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-U<F1I<B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@)'-A=F5D:7(@/2`D=&AI<RT^7V-U<F1I
M<CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L6R=A
M='1R:6)S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1V86Q;)V%T=')I8G,G75LG;F%M92==(#T]("<O)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-U<F1I<B`]("<O)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/E]C=7)D:7(@
M/3T@)R\G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-U<F1I<B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8W5R9&ER("X]("<O)R`N("1V86Q;)V%T=')I8G,G75LG;F%M
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("1T:&ES+3Y?<V5R:6%L:7IE
M5F%L=64H("1V86PL("1T86=.86UE+"`D871T<FEB=71E<RD[#0H@("`@("`@
M("`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG8F5A=71I9GE&:6QE
M;&ES="==("8F("1T86=.86UE(#T]("=D:7(G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R:6YG("X]("<@/"$M+2`G("X@)'1H:7,M/E]C=7)D
M:7(@+B`G("TM/B<[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H96UP
M='DH)'-A=F5D:7(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=6YS970H)'1H:7,M/E]C=7)D:7(I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-U<F1I<B`]("1S879E9&ER.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(`T*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("1T:&ES+3YO
M<'1I;VYS6R=L:6YE8G)E86LG73L-"B`@("`@("`@"0D)+R\)9&\@:6YD96YT
M871I;VX-"B`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6R=I;F1E;G0G72$]/6YU;&P@)B8@)'1H:7,M/E]T86=$97!T:#XP*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]('-T<E]R97!E870H
M)'1H:7,M/F]P=&EO;G-;)VEN9&5N="==+"`D=&AI<RT^7W1A9T1E<'1H*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@<G1R:6TH)'-T<FEN9RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@#0H)"6EF("@D=&AI<RT^;W!T
M:6]N<ULG<V-A;&%R07-!='1R:6)U=&5S)UT@/3T]('1R=64I('L-"@D@("`@
M("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PT*"0D)
M"6EF("AI<U]S8V%L87(H)'9A;'5E*2`F)B`H4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES5F%L:61.86UE*"1K97DI(#T]/2!T
M<G5E*2D@>PT*"0D)"0EU;G-E="@D87)R87E;)&ME>5TI.PT*"0D)"0DD871T
M<FEB=71E<ULD=&AI<RT^;W!T:6]N<ULG<')E<&5N9$%T=')I8G5T97,G72XD
M:V5Y72`]("1V86QU93L-"@D)"0E]#0H)"0E]#0H)"7T-"@T*("`@("`@("`O
M+R!C:&5C:R!F;W(@96UP='D@87)R87D@/3X@8W)E871E(&5M<'1Y('1A9PT*
M("`@("`@("!I9B`H96UP='DH)&%R<F%Y*2D@>PT*("`@("`@("`@("`@)'1A
M9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Q;F%M
M92<@("`@("`]/B`D=&%G3F%M92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8V]N=&5N="<@("`@/3X@)%]C;VYT96YT+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A='1R:6)U=&5S)R`]/B`D871T<FEB=71E<PT*
M("`@("`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)'1H:7,M/E]T86=$97!T:"LK.PT*("`@("`@("`@
M("`@)'1M<"`]("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E86LG73L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PT*
M("`@(`D)"2\O"61O(&EN9&5N=&%T:6]N#0H@("`@("`@("`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G0G72$]/6YU;&P@)B8@)'1H:7,M/E]T
M86=$97!T:#XP*2![#0H@("`@("`@("`@("`@("`@("`@("1T;7`@+CT@<W1R
M7W)E<&5A="@D=&AI<RT^;W!T:6]N<ULG:6YD96YT)UTL("1T:&ES+3Y?=&%G
M1&5P=&@I.PT*("`@("`@("`@("`@("`@('T-"B`@("`-"B`@("`)"0DO+PEC
M;W!Y(&ME>0T*("`@(`D)"21O<FEG2V5Y"3T))&ME>3L-"B`@("`)"0DO+PEK
M97D@8V%N;F]T(&)E('5S960@87,@=&%G;F%M92`]/B!U<V4@9&5F875L="!T
M86<-"B`@("`@("`@("`@("`@("`D=F%L:60@/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ:7-686QI9$YA;64H)&ME>2D[#0H@
M("`@"2`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'9A;&ED*2D@>PT*("`@
M(`D@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V-L87-S07-486=.
M86UE)UT@)B8@:7-?;V)J96-T*"1V86QU92DI('L-"B`@("`)("`@("`@("`@
M("`@("`@("1K97D@/2!G971?8VQA<W,H)'9A;'5E*3L-"B`@("`)("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(`D@("`@("`@("1K97D@/2`D
M=&AI<RT^;W!T:6]N<ULG9&5F875L=%1A9TYA;64G73L-"B`@("`)("`@("`@
M("`@("`@?0T*("`@("`@("`@("`)(`E]#0H@("`@("`@("`@("`@("`@)&%T
M=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG='EP94AI;G1S)UT@/3T]('1R=64I('L-"B`@("`@("`@("`@("`@
M("`@("`@)&%T='-;)'1H:7,M/F]P=&EO;G-;)W1Y<&5!='1R:6)U=&4G75T@
M/2!G971T>7!E*"1V86QU92D[#0H@("`@"0D)"6EF("@D:V5Y("$]/2`D;W)I
M9TME>2D@>PT*("`@(`D)"0D))&%T='-;)'1H:7,M/F]P=&EO;G-;)VME>4%T
M=')I8G5T92==72`]("AS=')I;F<I)&]R:6=+97D[#0H@("`@"0D)"7T-"B`@
M("`-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=B96%U=&EF>49I;&5L:7-T)UT@)B8@)&ME>2`]/2`G
M9&ER)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3Y?8W5R9&ER*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C=7)D:7(@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`D<V%V961I<B`]("1T:&ES+3Y?8W5R9&ER.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'9A;'5E6R=A='1R:6)S)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'9A;'5E6R=A='1R
M:6)S)UU;)VYA;64G72`]/2`G+R<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V-U<F1I<B`]("<O)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C=7)D:7(@+CT@)R\G("X@)'9A;'5E6R=A='1R:6)S)UU;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@
M("`@("`@(&EF("AI<U]S=')I;F<H)'9A;'5E*2`F)B`D=F%L=64@)B8@*"1V
M86QU97MS=')L96XH)'9A;'5E*2`M(#%](#T](")<;B(I*2![#0H@("`@("`@
M("`@("`@("`@("`@("1V86QU92`N/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I
M;VYS6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("1T;7`@+CT@)'1H:7,M/E]C<F5A
M=&5834Q486<H87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W%N86UE)R`@("`@(#T^("1K97DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1S+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT
M96YT)R`@("`]/B`D=F%L=64@*0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG8F5A=71I9GE&:6QE;&ES="==("8F("1K97D@/3T@
M)V1I<B<I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V86QU
M95LG871T<FEB<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1M
M<"`N/2`G(#PA+2T@)R`N("1T:&ES+3Y?8W5R9&ER("X@)R`M+3XG.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y*"1S879E9&ER*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?8W5R
M9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C=7)D:7(@/2`D<V%V
M961I<CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`D=&UP("X]("1T:&ES+3YO<'1I;VYS6R=L:6YE8G)E86LG73L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(`T*("`@("`@("`@("`@)'1H:7,M/E]T
M86=$97!T:"TM.PT*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=I
M;F1E;G0G72$]/6YU;&P@)B8@)'1H:7,M/E]T86=$97!T:#XP*2![#0H@("`@
M("`@("`@("`@("`@)'1M<"`N/2!S=')?<F5P96%T*"1T:&ES+3YO<'1I;VYS
M6R=I;F1E;G0G72P@)'1H:7,M/E]T86=$97!T:"D[#0H@("`@("`@("`@("!]
M#0H@("`@#0H@("`@"0EI9B`H=')I;2@D=&UP*2`]/3T@)R<I('L-"B`@("`)
M"0DD=&UP(#T@;G5L;#L-"B`@("`)"7T-"B`@("`)"0T*("`@("`@("`@("`@
M)'1A9R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=Q
M;F%M92<@("`@("`]/B`D=&%G3F%M92P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G8V]N=&5N="<@("`@/3X@)'1M<"P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G871T<FEB=71E<R<@/3X@)&%T=')I8G5T97,-"B`@
M("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R=T>7!E2&EN=',G72`]/3T@=')U92D@>PT*
M("`@("`@("`@("`@:68@*"%I<W-E="@D=&%G6R=A='1R:6)U=&5S)UU;)'1H
M:7,M/F]P=&EO;G-;)W1Y<&5!='1R:6)U=&4G75TI*2![#0H@("`@("`@("`@
M("`@("`@)'1A9ULG871T<FEB=71E<R==6R1T:&ES+3YO<'1I;VYS6R=T>7!E
M071T<FEB=71E)UU=(#T@)V%R<F%Y)SL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*#0H@("`@("`@("1S=')I;F<@/2`D=&AI<RT^7V-R96%T95A-3%1A
M9R@D=&%G+"!F86QS92D[#0H@("`@("`@(')E='5R;B`D<W1R:6YG.PT*("`@
M('T-"B`@#0H@("`O*BH-"B`@("`J(&-R96%T92!A('1A9R!F<F]M(&%N(&%R
M<F%Y#0H@("`@*B!T:&ES(&UE=&AO9"!A=V%I=',@86X@87)R87D@:6X@=&AE
M(&9O;&QO=VEN9R!F;W)M870-"B`@("`J(&%R<F%Y*`T*("`@("H@("`@("`@
M)W%N86UE)R`@("`@("`@/3X@)'1A9TYA;64L#0H@("`@*B`@("`@("`G871T
M<FEB=71E<R<@("`]/B!A<G)A>2@I+`T*("`@("H@("`@("`@)V-O;G1E;G0G
M("`@("`@/3X@)&-O;G1E;G0L("`@("`@+R\@;W!T:6]N86P-"B`@("`J("`@
M("`@("=N86UE<W!A8V4G("`@(#T^("1N86UE<W!A8V4@("`@("\O(&]P=&EO
M;F%L#0H@("`@*B`@("`@("`G;F%M97-P86-E57)I)R`]/B`D;F%M97-P86-E
M57)I("`O+R!O<'1I;VYA;`T*("`@("H@("`I#0H@("`@*@T*("`@("H@0&%C
M8V5S<R`@('!R:79A=&4-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1T86<@
M=&%G(&1E9FEN:71I;VX-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1R97!L
M86-E16YT:71I97,@=VAE=&AE<B!T;R!R97!L86-E(%A-3"!E;G1I=&EE<R!I
M;B!C;VYT96YT(&]R(&YO=`T*("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T
M<FEN9R!834P@=&%G#0H@("`@*B\-"B`@("!F=6YC=&EO;B!?8W)E871E6$U,
M5&%G*"`D=&%G+"`D<F5P;&%C945N=&ET:65S(#T@=')U92`I#0H@("`@>PT*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)VEN9&5N=$%T=')I8G5T97,G
M72`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("1M=6QT:6QI;F4@/2!T<G5E
M.PT*("`@("`@("`@("`@)&EN9&5N="`@("`]('-T<E]R97!E870H)'1H:7,M
M/F]P=&EO;G-;)VEN9&5N="==+"`D=&AI<RT^7W1A9T1E<'1H*3L-"@T*("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=I;F1E;G1!='1R:6)U=&5S
M)UT@/3T@)U]A=71O)RD@>PT*("`@("`@("`@("`@("`@("1I;F1E;G0@+CT@
M<W1R7W)E<&5A="@G("<L("AS=')L96XH)'1A9ULG<6YA;64G72DK,BDI.PT*
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1I;F1E
M;G0@+CT@)'1H:7,M/F]P=&EO;G-;)VEN9&5N=$%T=')I8G5T97,G73L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1M
M=6QT:6QI;F4@/2!F86QS93L-"B`@("`@("`@("`@("1I;F1E;G0@("`@/2!F
M86QS93L-"B`@("`@("`@?0T*("`@(`T*("`@("`@("!I9B`H:7-?87)R87DH
M)'1A9ULG8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1T
M86=;)V-O;G1E;G0G72DI('L-"B`@("`@("`@("`@("`@("`D=&%G6R=C;VYT
M96YT)UT@/2`@("<G.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I
M9BAI<U]S8V%L87(H)'1A9ULG8V]N=&5N="==*2`F)B`H<W1R:6YG*21T86=;
M)V-O;G1E;G0G72`]/2`G)RD@>PT*("`@("`@("`@("`@)'1A9ULG8V]N=&5N
M="==(#T@("`G)SL-"B`@("`@("`@?0T*("`@(`T*("`@("`@("!I9B`H:7-?
M<V-A;&%R*"1T86=;)V-O;G1E;G0G72D@?'P@:7-?;G5L;"@D=&%G6R=C;VYT
M96YT)UTI*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)V5N
M8V]D:6YG)UT@/3T@)U541BTX)R`F)@T*("`@("`@("`@("`@("`@("`@=F5R
M<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S4N,"XP)RP@)VQT)RDI('L-
M"B`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]55$8X7UA-3#L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&5N8V]D:6YG
M(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4
M251)15-?6$U,.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1A9R`]
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A
M=&5486=&<F]M07)R87DH)'1A9RP@)')E<&QA8V5%;G1I=&EE<RP@)&UU;'1I
M;&EN92P@)&EN9&5N="P@)'1H:7,M/F]P=&EO;G-;)VQI;F5B<F5A:R==+"`D
M96YC;V1I;F<I.PT*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'1A9ULG
M8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@)'1A9R`@("`]("`@)'1H:7,M
M/E]S97)I86QI>F5!<G)A>2@D=&%G6R=C;VYT96YT)UTL("1T86=;)W%N86UE
M)UTL("1T86=;)V%T=')I8G5T97,G72D[#0H@("`@("`@('T@96QS96EF("AI
M<U]O8FIE8W0H)'1A9ULG8V]N=&5N="==*2D@>PT*("`@("`@("`@("`@)'1A
M9R`@("`]("`@)'1H:7,M/E]S97)I86QI>F5/8FIE8W0H)'1A9ULG8V]N=&5N
M="==+"`D=&%G6R=Q;F%M92==+"`D=&%G6R=A='1R:6)U=&5S)UTI.PT*("`@
M("`@("!](&5L<V5I9B`H:7-?<F5S;W5R8V4H)'1A9ULG8V]N=&5N="==*2D@
M>PT*("`@("`@("`@("`@<V5T='EP92@D=&%G6R=C;VYT96YT)UTL("=S=')I
M;F<G*3L-"B`@("`@("`@("`@("1T86<@("`@/2`@(%!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH
M)'1A9RP@)')E<&QA8V5%;G1I=&EE<RD[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("`D=&%G.PT*("`@('T-"GT-"@T*+R\@=V5L;"P@:70G<R!O;F4@
M=V%Y('1O(&1O('1H:6YG<R!W:71H;W5T(&5X=')A(&1E<',@+BXN#0HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\-
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!02%`@5F5R
M<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L-"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#(@5&AE(%!(4"!'
M<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\(%1H:7,@<V]U<F-E(&9I
M;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N
M<V4L("`@("`@('P-"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`T*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\#0HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P-"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`T*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\#0HO+R!\(&QI
M8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D
M:6%T96QY+B`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PT*+R\@?"!!=71H;W)S.B!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"UT;V]L<RYN970^("`@("`@("`@("`@("`@("`@("`@("!\#0HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O#0HO+R`@("`D260Z
M('8R+G!H<"QV(#$N,S0@,C`P-B\P,R\P,B`R,#HU,#HU.2!C96QL;V<@17AP
M("0-"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I;G9A;&ED(&-H87)S(&EN
M(%A-3"!N86UE#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?24Y604Q)1%]#2$%24R(L(#4Q*3L-
M"@T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!I;G9A;&ED(&-H87)S(&EN(%A-
M3"!N86UE#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T
M;W)?=C)?6$U,7U5T:6Q?15)23U)?24Y604Q)1%]35$%25"(L(#4R*3L-"@T*
M+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!N;VXM<V-A;&%R('1A9R!C;VYT96YT
M#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6Q?15)23U)?3D].7U-#04Q!4E]#3TY414Y4(BP@-C`I.PT*("`@
M(`T*+RHJ#0H@*B!E<G)O<B!C;V1E(&9O<B!M:7-S:6YG('1A9R!N86UE#0H@
M*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6Q?15)23U)?3D]?5$%'7TY!344B+"`V,2D[#0H@("`@#0HO*BH-"B`J
M(')E<&QA8V4@6$U,(&5N=&ET:65S#0H@*B\-"F1E9FEN92@B4$5!4E]086-K
M86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?4D503$%#15]%3E1)5$E%
M4R(L(#$I.PT*#0HO*BH-"B`J(&5M8F5D9"!C;VYT96YT(&EN(&$@0T1A=&$@
M4V5C=&EO;@T*("HO#0ID969I;F4H(E!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL7T-$051!7U-%0U1)3TXB+"`R*3L-"@T*+RHJ#0H@
M*B!D;R!N;W0@<F5P;&%C92!E;G1I=&ET97,-"B`J+PT*9&5F:6YE*")014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U].
M3TY%(BP@,"D[#0H-"B\J*@T*("H@<F5P;&%C92!A;&P@6$U,(&5N=&ET:71E
M<PT*("H@5&AI<R!S971T:6YG('=I;&P@<F5P;&%C92`\+"`^+"`B+"`G(&%N
M9"`F#0H@*B\-"F1E9FEN92@B4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,(BP@,2D[#0H-"B\J*@T*("H@<F5P
M;&%C92!O;FQY(')E<75I<F5D(%A-3"!E;G1I=&ET97,-"B`J(%1H:7,@<V5T
M=&EN9R!W:6QL(')E<&QA8V4@/"P@(B!A;F0@)@T*("HO#0ID969I;F4H(E!%
M05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E42453
M7UA-3%]215%525)%1"(L(#(I.PT*#0HO*BH-"B`J(')E<&QA8V4@2%1-3"!E
M;G1I=&ET97,-"B`J($!L:6YK("`@(&AT='`Z+R]W=W<N<&AP+FYE="]H=&UL
M96YT:71I97,-"B`J+PT*9&5F:6YE*")014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;%]%3E1)5$E%4U](5$U,(BP@,RD[#0H-"B\J*@T*
M("H@<F5P;&%C92!A;&P@6$U,(&5N=&ET:71E<RP@86YD(&5N8V]D92!F<F]M
M($E33RTX.#4Y+3$@=&\@551&+3@-"B`J(%1H:7,@<V5T=&EN9R!W:6QL(')E
M<&QA8V4@/"P@/BP@(BP@)R!A;F0@)@T*("HO#0ID969I;F4H(E!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537U541CA?
M6$U,(BP@-"D[#0H-"B\J*@T*("H@=71I;&ET>2!C;&%S<R!F;W(@=V]R:VEN
M9R!W:71H(%A-3"!D;V-U;65N=',-"B`J(`T*("H@8W5S=&]M:7IE9"!V97)S
M:6]N(&]F(%A-3%]5=&EL(#`N-BXP#0H@*@T*("H@0&-A=&5G;W)Y(%A-3`T*
M("H@0'!A8VMA9V4@(%!%05(-"B`J($!V97)S:6]N("`P+C8N,`T*("H@0&%U
M=&AO<B`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X-"B`J($!A
M=71H;W(@("!'<F5G;W)Y($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B\-
M"F-L87-S(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M('L-"@T*("`@+RHJ#0H@("`@*B!R971U<FX@05!)('9E<G-I;VX-"B`@("`J
M#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@
M*B!`<F5T=7)N("`@<W1R:6YG("`D=F5R<VEO;B!!4$D@=F5R<VEO;@T*("`@
M("HO#0H@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I#0H@("`@>PT*("`@("`@
M("!R971U<FX@(C`N-B([#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(')E<&QA
M8V4@6$U,(&5N=&ET:65S#0H@("`@*@T*("`@("H@5VET:"!T:&4@;W!T:6]N
M86P@<V5C;VYD('!A<F%M971E<BP@>6]U(&UA>2!S96QE8W0L('=H:6-H#0H@
M("`@*B!E;G1I=&EE<R!S:&]U;&0@8F4@<F5P;&%C960N#0H@("`@*@T*("`@
M("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[
M#0H@("`@*B`-"B`@("`J("\O(')E<&QA8V4@6$U,(&5N=&ET97,Z#0H@("`@
M*B`D<W1R:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@B5&AI<R!S=')I;F<@8V]N=&%I;G,@
M/"`F(#XN(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@<W1R:6YG('=H97)E(%A-3"!S<&5C:6%L(&-H87)S('-H;W5L9"!B
M92!R97!L86-E9`T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@<V5T=&EN9R!F
M;W(@96YT:71I97,@:6X@871T<FEB=71E('9A;'5E<R`H;VYE(&]F(%!%05)?
M4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537UA-
M3"P@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4
M251)15-?6$U,7U)%455)4D5$+"!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;%]%3E1)5$E%4U](5$U,*0T*("`@("H@0')E='5R;B`@
M('-T<FEN9R`@<W1R:6YG('=I=&@@<F5P;&%C960@8VAA<G,-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(')E<&QA8V5%;G1I=&EE<R@D<W1R:6YG+"`D<F5P;&%C
M945N=&ET:65S(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@("`@<W=I=&-H("@D
M<F5P;&%C945N=&ET:65S*2![#0H@("`@("`@("`@("!C87-E(%!%05)?4&%C
M:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537U541CA?
M6$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!S=')T<BAU=&8X7V5N8V]D
M92@D<W1R:6YG*2QA<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("<F)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<^)R`@/3X@)R9G=#LG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)SPG("`]/B`G)FQT.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B<@(#T^("<F<75O=#LG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)UPG)R`]/B`G)F%P;W,[
M)R`I*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A
M<V4@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?14Y4
M251)15-?6$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!S=')T<B@D<W1R
M:6YG+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)SXG("`]/B`G)F=T.R<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"<@(#T^
M("<F;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<B)R`@/3X@)R9Q=6]T.R<L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G7"<G(#T^("<F87!O<SLG("DI.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!014%2
M7U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]8
M34Q?4D5154E2140Z#0H@("`@("`@("`@("`@("`@<F5T=7)N('-T<G1R*"1S
M=')I;F<L87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G)B<@(#T^("<F86UP.R<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G/"<@(#T^("<F;'0[)RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B)R`@
M/3X@)R9Q=6]T.R<@*2D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("!C87-E(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL7T5.5$E424537TA434PZ#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&AT;6QS<&5C:6%L8VAA<G,H)'-T<FEN9RD[#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1S=')I;F<[#0H@
M("`@?0T*#0H@("`O*BH-"B`@("`J(&)U:6QD(&%N('AM;"!D96-L87)A=&EO
M;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=8
M34PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!G970@86X@6$U,(&1E
M8VQA<F%T:6]N.@T*("`@("H@)'AM;$1E8VP@/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ9V5T6$U,1&5C;&%R871I;VXH(C$N
M,"(L(")55$8M."(L('1R=64I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("1V97)S:6]N("`@("!X;6P@=F5R<VEO;@T*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@)&5N8V]D:6YG("`@(&-H87)A8W1E<B!E
M;F-O9&EN9PT*("`@("H@0'!A<F%M("`@(&)O;VQE86X@)'-T86YD06QO;F4@
M(&1O8W5M96YT(&ES('-T86YD86QO;F4@*&]R(&YO="D-"B`@("`J($!R971U
M<FX@("!S=')I;F<@("1D96-L('AM;"!D96-L87)A=&EO;@T*("`@("H@0'5S
M97,@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIA='1R:6)U=&5S5&]3=')I;F<H*2!T;R!S97)I86QI>F4@=&AE(&%T=')I
M8G5T97,@;V8@=&AE(%A-3"!D96-L87)A=&EO;@T*("`@("HO#0H@("`@9G5N
M8W1I;VX@9V5T6$U,1&5C;&%R871I;VXH)'9E<G-I;VX@/2`B,2XP(BP@)&5N
M8V]D:6YG(#T@;G5L;"P@)'-T86YD86QO;F4@/2!N=6QL*0T*("`@('L-"B`@
M("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B=F5R<VEO;B(@/3X@)'9E<G-I;VXL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`O+R!A9&0@96YC;V1I;F<-
M"B`@("`@("`@:68@*"1E;F-O9&EN9R`A/3T@;G5L;"D@>PT*("`@("`@("`@
M("`@)&%T=')I8G5T97-;(F5N8V]D:6YG(ET@/2`D96YC;V1I;F<[#0H@("`@
M("`@('T-"B`@("`@("`@+R\@861D('-T86YD86QO;F4L(&EF('-P96-I9FEE
M9`T*("`@("`@("!I9B`H)'-T86YD86QO;F4@(3T](&YU;&PI('L-"B`@("`@
M("`@("`@("1A='1R:6)U=&5S6R)S=&%N9&%L;VYE(ET@/2`D<W1A;F1A;&]N
M92`_(")Y97,B(#H@(FYO(CL-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@
M("`@<F5T=7)N('-P<FEN=&8H(CP_>&UL)7,_/B(L(%!%05)?4&%C:V%G949I
M;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H
M)&%T=')I8G5T97,L(&9A;'-E*2D[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J
M(&)U:6QD(&$@9&]C=6UE;G0@='EP92!D96-L87)A=&EO;@T*("`@("H-"B`@
M("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G
M.PT*("`@("H@#0H@("`@*B`O+R!G970@82!D;V-T>7!E(&1E8VQA<F%T:6]N
M.@T*("`@("H@)'AM;$1E8VP@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*")R;V]T5&%G
M(BPB;7E$;V-4>7!E+F1T9"(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@
M("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P
M87)A;2`@("!S=')I;F<@("1R;V]T("`@("`@("`@;F%M92!O9B!T:&4@<F]O
M="!T86<-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1U<FD@("`@("`@("`@
M=7)I(&]F('1H92!D;V-T>7!E(&1E9FEN:71I;VX@*&]R(&%R<F%Y('=I=&@@
M=7)I(&%N9"!P=6)L:6,@:60I#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D
M:6YT97)N86Q$=&0@(&EN=&5R;F%L(&1T9"!E;G1R:65S("`@#0H@("`@*B!`
M<F5T=7)N("`@<W1R:6YG("`D9&5C;"`@("`@("`@(&1O8W1Y<&4@9&5C;&%R
M871I;VX-"B`@("`J($!S:6YC92`@("`P+C(-"B`@("`J+PT*("`@(&9U;F-T
M:6]N(&=E=$1O8U1Y<&5$96-L87)A=&EO;B@D<F]O="P@)'5R:2`](&YU;&PL
M("1I;G1E<FYA;$1T9"`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H:7-?
M87)R87DH)'5R:2DI('L-"B`@("`@("`@("`@("1R968@/2!S<')I;G1F*"`G
M(%!50DQ)0R`B)7,B("(E<R(G+"`D=7)I6R)I9")=+"`D=7)I6R)U<FDB72`I
M.PT*("`@("`@("!](&5L<V5I9B`H(65M<'1Y*"1U<FDI*2![#0H@("`@("`@
M("`@("`D<F5F(#T@<W!R:6YT9B@@)R!365-414T@(B5S(B<L("1U<FD@*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1R968@/2`B(CL-"B`@
M("`@("`@?0T*#0H@("`@("`@(&EF("AE;7!T>2@D:6YT97)N86Q$=&0I*2![
M#0H@("`@("`@("`@("!R971U<FX@<W!R:6YT9B@B/"%$3T-465!%("5S)7,^
M(BP@)')O;W0L("1R968I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#5%E012`E<R5S(%M<;B5S7&Y=/B(L
M("1R;V]T+"`D<F5F+"`D:6YT97)N86Q$=&0I.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`O*BH-"B`@("`J(&-R96%T92!S=')I;F<@<F5P<F5S96YT871I
M;VX@;V8@86X@871T<FEB=71E(&QI<W0-"B`@("`J#0H@("`@*B`\8V]D93X-
M"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*
M("`@("H@+R\@8G5I;&0@86X@871T<FEB=71E('-T<FEN9PT*("`@("H@)&%T
M="`](&%R<F%Y*`T*("`@("H@("`@("`@("`@("`@(")F;V\B("`@/3X@(")B
M87(B+`T*("`@("H@("`@("`@("`@("`@(")A<F=H(B`@/3X@(")T;VUA=&\B
M#0H@("`@*B`@("`@("`@("`@("D[#0H@("`@*@T*("`@("H@)&%T=$QI<W0@
M/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ871T
M<FEB=71E<U1O4W1R:6YG*"1A='0I.R`@("`-"B`@("`J(#PO8V]D93X-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@("`@87)R87D@("`@("`@("`D871T<FEB=71E<R`@("`@
M("`@871T<FEB=71E(&%R<F%Y#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;GQA
M<G)A>2`D<V]R="`@("`@("`@("`@("`@<V]R="!A='1R:6)U=&4@;&ES="!A
M;'!H86)E=&EC86QL>2P@;6%Y(&%L<V\@8F4@86X@87-S;V,@87)R87D@8V]N
M=&%I;FEN9R!T:&4@:V5Y<R`G<V]R="<L("=M=6QT:6QI;F4G+"`G:6YD96YT
M)RP@)VQI;F5B<F5A:R<@86YD("=E;G1I=&EE<R<-"B`@("`J($!P87)A;2`@
M("!B;V]L96%N("`@("`@("1M=6QT:6QI;F4@("`@("`@("!U<V4@;&EN96)R
M96%K<RP@:68@;6]R92!T:&%N(&]N92!A='1R:6)U=&4@:7,@9VEV96X-"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("1I;F1E;G0@("`@("`@("`@
M("!S=')I;F<@=7-E9"!F;W(@:6YD96YT871I;VX@;V8@;75L=&EL:6YE(&%T
M=')I8G5T97,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("1L:6YE
M8G)E86L@("`@("`@("!S=')I;F<@=7-E9"!F;W(@;&EN96)R96%K<R!O9B!M
M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@(&EN=&5G97(@
M("`@("`@)&5N=&ET:65S("`@("`@("`@('-E='1I;F<@9F]R(&5N=&ET:65S
M(&EN(&%T=')I8G5T92!V86QU97,@*&]N92!O9B!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U].3TY%+"!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U]834PL
M(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E4
M24537UA-3%]215%525)%1"P@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6Q?14Y4251)15-?2%1-3"D-"B`@("`J($!R971U<FX@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@<F5P<F5S
M96YT871I;VX@;V8@=&AE(&%T=')I8G5T97,-"B`@("`J($!U<V5S("`@("!0
M14%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F5P;&%C
M945N=&ET:65S*"D@=&\@<F5P;&%C92!834P@96YT:71I97,@:6X@871T<FEB
M=71E('9A;'5E<PT*("`@("H@0'1O9&\@("`@(&%L;&]W('-O<G0@86QS;R!T
M;R!B92!A;B!O<'1I;VYS(&%R<F%Y#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A
M='1R:6)U=&5S5&]3=')I;F<H)&%T=')I8G5T97,L("1S;W)T(#T@=')U92P@
M)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@)R`@("`G+"`D;&EN96)R
M96%K(#T@(EQN(BP@)&5N=&ET:65S(#T@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@
M("`@+RHJ#0H@("`@("`@("`J('-E8V]N9"!P87)A;65T97(@;6%Y(&)E(&%N
M(&%R<F%Y#0H@("`@("`@("`J+PT*("`@("`@("!I9B`H:7-?87)R87DH)'-O
M<G0I*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)VUU;'1I;&EN
M92==*2D@>PT*("`@("`@("`@("`@("`@("1M=6QT:6QI;F4@/2`D<V]R=%LG
M;75L=&EL:6YE)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)'-O<G1;)VEN9&5N="==*2D@>PT*("`@("`@("`@("`@("`@("1I
M;F1E;G0@/2`D<V]R=%LG:6YD96YT)UT[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H:7-S970H)'-O<G1;)VQI;F5B<F5A:R==*2D@>PT*("`@
M("`@("`@("`@("`@("1M=6QT:6QI;F4@/2`D<V]R=%LG;&EN96)R96%K)UT[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;
M)V5N=&ET:65S)UTI*2![#0H@("`@("`@("`@("`@("`@)&5N=&ET:65S(#T@
M)'-O<G1;)V5N=&ET:65S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'-O<G1;)W-O<G0G72DI('L-"B`@("`@("`@("`@("`@
M("`D<V]R="`]("1S;W)T6R=S;W)T)UT[#0H@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("1S;W)T(#T@=')U93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("`D<W1R:6YG(#T@)R<[#0H@("`@("`@
M(&EF("AI<U]A<G)A>2@D871T<FEB=71E<RD@)B8@(65M<'1Y*"1A='1R:6)U
M=&5S*2D@>PT*("`@("`@("`@("`@:68@*"1S;W)T*2![#0H@("`@("`@("`@
M("`@("`@:W-O<G0H)&%T=')I8G5T97,I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@:68H("$D;75L=&EL:6YE('Q\(&-O=6YT*"1A='1R:6)U=&5S
M*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T
M97,@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1E;G1I=&EE<R`A/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,E]834Q?571I;%]%3E1)5$E%4U].3TY%*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=F%L=64@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,E]834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"1V86QU92P@)&5N=&ET:65S
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`D<W1R:6YG("X]("<@)RXD:V5Y+B<](B<N)'9A;'5E+B<B)SL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("1F:7)S="`]('1R=64[#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)&%T=')I8G5T97,@87,@)&ME>2`]/B`D=F%L=64I('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1E;G1I=&EE<R`A/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;%]%3E1)5$E%4U].3TY%*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=F%L=64@/2!014%27U!A8VMA9V5&:6QE
M7T=E;F5R871O<E]V,E]834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"1V86QU
M92P@)&5N=&ET:65S*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!I9B`H)&9I<G-T*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<W1R:6YG("X]("(@(BXD:V5Y+B<](B<N)'9A;'5E+B<B)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<FEN9R`N/2`D;&EN96)R96%K+B1I;F1E;G0N)&ME>2XG/2(G
M+B1V86QU92XG(B<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N("1S=')I;F<[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T
M92!A('1A9PT*("`@("H-"B`@("`J(%1H:7,@;65T:&]D('=I;&P@8V%L;"!0
M14%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E
M5&%G1G)O;4%R<F%Y*"DL('=H:6-H#0H@("`@*B!I<R!M;W)E(&9L97AI8FQE
M+@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=8
M34PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,
M('1A9SH-"B`@("`J("1T86<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O
M<E]V,E]834Q?571I;#HZ8W)E871E5&%G*")M>4YS.FUY5&%G(BP@87)R87DH
M(F9O;R(@/3X@(F)A<B(I+"`B5&AI<R!I<R!I;G-I9&4@=&AE('1A9R(L(")H
M='1P.B\O=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@("`J(#PO8V]D93X-"B`@
M("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`D<6YA;64@("`@("`@("`@("`@<75A
M;&EF:65D('1A9VYA;64@*&EN8VQU9&EN9R!N86UE<W!A8V4I#0H@("`@*B!`
M<&%R86T@("`@87)R87D@("`D871T<FEB=71E<R`@("`@("`@87)R87D@8V]N
M=&%I;F<@871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@)&-O
M;G1E;G0-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1N86UE<W!A8V55<FD@
M("`@("!54DD@;V8@=&AE(&YA;65S<&%C90T*("`@("H@0'!A<F%M("`@(&EN
M=&5G97(@)')E<&QA8V5%;G1I=&EE<R`@('=H971H97(@=&\@<F5P;&%C92!8
M34P@<W!E8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E9&0@:70@:6X@82!#
M1&%T82!S96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@("H@0'!A<F%M("`@
M(&)O;VQE86X@)&UU;'1I;&EN92`@("`@("`@('=H971H97(@=&\@8W)E871E
M(&$@;75L=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I8G5T92!G971S('=R
M:71T96X@=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A<F%M("`@('-T<FEN
M9R`@)&EN9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D('1O(&EN9&5N="!A
M='1R:6)U=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T97,@<V\@=&AE>2!S
M=&%R="!A="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`D;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B
M<F5A:W,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1E;F-O9&EN9R`@("`@
M("`@("!E;F-O9&EN9R!T:&%T('-H;W5L9"!B92!U<V5D('1O('1R86YS;&%T
M92!C;VYT96YT#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@
M("`@("`@("`@6$U,('1A9PT*("`@("H@0'-E92`@("`@(%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R
M87DH*0T*("`@("H@0'5S97,@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A
M=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH*2!T;R!C<F5A
M=&4@=&AE('1A9PT*("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E5&%G*"1Q
M;F%M92P@)&%T=')I8G5T97,@/2!A<G)A>2@I+"`D8V]N=&5N="`](&YU;&PL
M("1N86UE<W!A8V55<FD@/2!N=6QL+"`D<F5P;&%C945N=&ET:65S(#T@4$5!
M4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?4D503$%#15]%
M3E1)5$E%4RP@)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@(E]A=71O
M(BP@)&QI;F5B<F5A:R`](")<;B(L("1E;F-O9&EN9R`](%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL7T5.5$E424537UA-3"D-"B`@
M("![#0H@("`@("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@
M("`@(")Q;F%M92(@("`@("`]/B`D<6YA;64L#0H@("`@("`@("`@("`@("`@
M("`@("`B871T<FEB=71E<R(@/3X@)&%T=')I8G5T97,-"B`@("`@("`@("`@
M("`@("`@("`@*3L-"@T*("`@("`@("`O+R!A9&0@=&%G(&-O;G1E;G0-"B`@
M("`@("`@:68@*"1C;VYT96YT("$]/2!N=6QL*2![#0H@("`@("`@("`@("`D
M=&%G6R)C;VYT96YT(ET@/2`D8V]N=&5N=#L-"B`@("`@("`@?0T*("`@("`@
M("`-"B`@("`@("`@+R\@861D(&YA;65S<&%C92!5<FD-"B`@("`@("`@:68@
M*"1N86UE<W!A8V55<FD@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T86=;
M(FYA;65S<&%C955R:2)=(#T@)&YA;65S<&%C955R:3L-"B`@("`@("`@?0T*
M#0H@("`@("`@(')E='5R;B!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V
M,E]834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E
M16YT:71I97,L("1M=6QT:6QI;F4L("1I;F1E;G0L("1L:6YE8G)E86LL("1E
M;F-O9&EN9RD[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T92!A('1A
M9R!F<F]M(&%N(&%R<F%Y#0H@("`@*B!T:&ES(&UE=&AO9"!A=V%I=',@86X@
M87)R87D@:6X@=&AE(&9O;&QO=VEN9R!F;W)M870-"B`@("`J(#QP<F4^#0H@
M("`@*B!A<G)A>2@-"B`@("`J("`B<6YA;64B("`@("`@("`]/B`D<6YA;64@
M("`@("`@("`O+R!Q=6%L:69I960@;F%M92!O9B!T:&4@=&%G#0H@("`@*B`@
M(FYA;65S<&%C92(@("`@/3X@)&YA;65S<&%C92`@("`@+R\@;F%M97-P86-E
M('!R969I>"`H;W!T:6]N86PL(&EF('%N86UE(&ES('-P96-I9FEE9"!O<B!N
M;R!N86UE<W!A8V4I#0H@("`@*B`@(FQO8V%L<&%R="(@("`@/3X@)&QO8V%L
M<&%R="P@("`@+R\@;&]C86P@<&%R="!O9B!T:&4@=&%G;F%M92`H;W!T:6]N
M86PL(&EF('%N86UE(&ES('-P96-I9FEE9"D-"B`@("`J("`B871T<FEB=71E
M<R(@("`]/B!A<G)A>2@I+"`@("`@("`O+R!A<G)A>2!C;VYT86EN:6YG(&%L
M;"!A='1R:6)U=&5S("AO<'1I;VYA;"D-"B`@("`J("`B8V]N=&5N="(@("`@
M("`]/B`D8V]N=&5N="P@("`@("`O+R!T86<@8V]N=&5N="`H;W!T:6]N86PI
M#0H@("`@*B`@(FYA;65S<&%C955R:2(@/3X@)&YA;65S<&%C955R:2`@+R\@
M;F%M97-P86-E57)I(&9O<B!T:&4@9VEV96X@;F%M97-P86-E("AO<'1I;VYA
M;"D-"B`@("`J("`@*0T*("`@("H@/"]P<F4^#0H@("`@*@T*("`@("H@/&-O
M9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@
M*B`-"B`@("`J("1T86<@/2!A<G)A>2@-"B`@("`J("`@("`@("`@("`B<6YA
M;64B("`@("`@("`]/B`B9F]O.F)A<B(L#0H@("`@*B`@("`@("`@("`@(FYA
M;65S<&%C955R:2(@/3X@(FAT='`Z+R]F;V\N8V]M(BP-"B`@("`J("`@("`@
M("`@("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@@(FME>2(@/3X@(G9A;'5E
M(BP@(F%R9V@B(#T^(")F<G5I="9V96=E=&%B;&4B("DL#0H@("`@*B`@("`@
M("`@("`@(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I;G-I9&4@=&AE('1A9R(L
M#0H@("`@*B`@("`@("`@("`@("D[#0H@("`@*B`O+R!C<F5A=&EN9R!A('1A
M9R!W:71H('%U86QI9FEE9"!N86UE(&%N9"!N86UE<W!A8V55<FD-"B`@("`J
M("1S=')I;F<@/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?
M571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I.PT*("`@("H@/"]C;V1E
M/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T
M:6,-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1T86<@("`@("`@("`@("`@
M("!T86<@9&5F:6YI=&EO;@T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@)')E
M<&QA8V5%;G1I=&EE<R`@('=H971H97(@=&\@<F5P;&%C92!834P@<W!E8VEA
M;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E9&0@:70@:6X@82!#1&%T82!S96-T
M:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@("H@0'!A<F%M("`@(&)O;VQE86X@
M)&UU;'1I;&EN92`@("`@("`@('=H971H97(@=&\@8W)E871E(&$@;75L=&EL
M:6YE('1A9R!W:&5R92!E86-H(&%T=')I8G5T92!G971S('=R:71T96X@=&\@
M82!S:6YG;&4@;&EN90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN9&5N
M="`@("`@("`@("`@('-T<FEN9R!U<V5D('1O(&EN9&5N="!A='1R:6)U=&5S
M("A?875T;R!I;F1E;G1S(&%T=')I8G5T97,@<V\@=&AE>2!S=&%R="!A="!T
M:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;&EN
M96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,-"B`@
M("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!834P@
M=&%G#0H@("`@*B!`<V5E("`@("`@4$5!4E]086-K86=E1FEL95]'96YE<F%T
M;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@*B!`=7-E<R`@("`@
M4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.F%T=')I
M8G5T97-4;U-T<FEN9R@I('1O('-E<FEA;&EZ92!T:&4@871T<FEB=71E<R!O
M9B!T:&4@=&%G#0H@("`@*B!`=7-E<R`@("`@4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@I('1O
M(&=E="!L;V-A;"!P87)T(&%N9"!N86UE<W!A8V4@;V8@82!Q=6%L:69I960@
M;F%M90T*("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E5&%G1G)O;4%R<F%Y
M*"1T86<L("1R97!L86-E16YT:71I97,@/2!014%27U!A8VMA9V5&:6QE7T=E
M;F5R871O<E]V,E]834Q?571I;%]215!,04-%7T5.5$E42453+"`D;75L=&EL
M:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`B7V%U=&\B+"`D;&EN96)R96%K(#T@
M(EQN(BP@)&5N8V]D:6YG(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?
M=C)?6$U,7U5T:6Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@("`@:68@
M*&ES<V5T*"1T86=;(F-O;G1E;G0B72D@)B8@(6ES7W-C86QA<B@D=&%G6R)C
M;VYT96YT(ETI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4E]086-K86=E
M1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)A:7-E17)R;W(H(")3=7!P
M;&EE9"!N;VXM<V-A;&%R('9A;'5E(&%S('1A9R!C;VYT96YT(BP@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?3D].7U-#
M04Q!4E]#3TY414Y4("D[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H(6ES
M<V5T*"1T86=;)W%N86UE)UTI("8F("%I<W-E="@D=&%G6R=L;V-A;%!A<G0G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B!014%27U!A8VMA9V5&:6QE7T=E
M;F5R871O<E]V,E]834Q?571I;#HZ<F%I<V5%<G)O<B@@)UEO=2!M=7-T(&5I
M=&AE<B!S=7!P;'D@82!Q=6%L:69I960@;F%M92`H<6YA;64I(&]R(&QO8V%L
M('1A9R!N86UE("AL;V-A;%!A<G0I+B<L(%!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL7T524D]27TY/7U1!1U].04U%("D[#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R!I9B!N;R!A='1R:6)U=&5S(&AA=B!B965N
M('-E="P@=7-E(&5M<'1Y(&%T=')I8G5T97,-"B`@("`@("`@:68@*"%I<W-E
M="@D=&%G6R)A='1R:6)U=&5S(ETI('Q\("%I<U]A<G)A>2@D=&%G6R)A='1R
M:6)U=&5S(ETI*2![#0H@("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(ET@
M/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`O+R!Q
M=6%L:69I960@;F%M92!I<R!N;W0@9VEV96X-"B`@("`@("`@:68@*"%I<W-E
M="@D=&%G6R)Q;F%M92)=*2D@>PT*("`@("`@("`@("`@+R\@8VAE8VL@9F]R
M(&YA;65S<&%C90T*("`@("`@("`@("`@:68@*&ES<V5T*"1T86=;(FYA;65S
M<&%C92)=*2`F)B`A96UP='DH)'1A9ULB;F%M97-P86-E(ETI*2![#0H@("`@
M("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]("1T86=;(FYA;65S<&%C92)=
M+B(Z(BXD=&%G6R)L;V-A;%!A<G0B73L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]("1T86=;(FQO8V%L
M4&%R=")=.PT*("`@("`@("`@("`@?0T*("`@("`@("`O+R!N86UE<W!A8V4@
M55))(&ES('-E="P@8G5T(&YO(&YA;65S<&%C90T*("`@("`@("!](&5L<V5I
M9B`H:7-S970H)'1A9ULB;F%M97-P86-E57)I(ETI("8F("%I<W-E="@D=&%G
M6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("1P87)T<R`](%!%05)?
M4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIS<&QI=%%U86QI
M9FEE9$YA;64H)'1A9ULB<6YA;64B72D[#0H@("`@("`@("`@("`D=&%G6R)L
M;V-A;%!A<G0B72`]("1P87)T<ULB;&]C86Q087)T(ET[#0H@("`@("`@("`@
M("!I9B`H:7-S970H)'!A<G1S6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@
M("`@("`@("`D=&%G6R)N86UE<W!A8V4B72`]("1P87)T<ULB;F%M97-P86-E
M(ET[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H
M:7-S970H)'1A9ULB;F%M97-P86-E57)I(ETI("8F("%E;7!T>2@D=&%G6R)N
M86UE<W!A8V55<FDB72DI('L-"B`@("`@("`@("`@("\O(&ES(&$@;F%M97-P
M86-E(&=I=F5N#0H@("`@("`@("`@("!I9B`H:7-S970H)'1A9ULB;F%M97-P
M86-E(ETI("8F("%E;7!T>2@D=&%G6R)N86UE<W!A8V4B72DI('L-"B`@("`@
M("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(EU;(GAM;&YS.B(N)'1A9ULB
M;F%M97-P86-E(EU=(#T@)'1A9ULB;F%M97-P86-E57)I(ET[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("\O(&1E9FEN92!T:&ES
M(%5R:2!A<R!T:&4@9&5F875L="!N86UE<W!A8V4-"B`@("`@("`@("`@("`@
M("`D=&%G6R)A='1R:6)U=&5S(EU;(GAM;&YS(ET@/2`D=&%G6R)N86UE<W!A
M8V55<FDB73L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@
M("\O(&-H96-K(&9O<B!M=6QT:6QI;F4@871T<FEB=71E<PT*("`@("`@("!I
M9B`H)&UU;'1I;&EN92`]/3T@=')U92D@>PT*("`@("`@("`@("`@:68@*"1I
M;F1E;G0@/3T](")?875T;R(I('L-"B`@("`@("`@("`@("`@("`D:6YD96YT
M(#T@<W1R7W)E<&5A="@B("(L("AS=')L96XH)'1A9ULB<6YA;64B72DK,BDI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@
M("`O+R!C<F5A=&4@871T<FEB=71E(&QI<W0-"B`@("`@("`@)&%T=$QI<W0@
M("`@/2`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIA='1R:6)U=&5S5&]3=')I;F<H)'1A9ULB871T<FEB=71E<R)=+"!T<G5E
M+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K("D[#0H@("`@("`@
M(&EF("@A:7-S970H)'1A9ULB8V]N=&5N=")=*2!\?"`H<W1R:6YG*21T86=;
M(F-O;G1E;G0B72`]/2`G)RD@>PT*("`@("`@("`@("`@)'1A9R`@("`]("`@
M<W!R:6YT9B@B/"5S)7,@+SXB+"`D=&%G6R)Q;F%M92)=+"`D871T3&ES="D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)')E<&QA8V5%
M;G1I=&EE<R`]/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?
M571I;%]215!,04-%7T5.5$E42453*2![#0H@("`@("`@("`@("`@("`@)'1A
M9ULB8V]N=&5N=")=(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?
M6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=&%G6R)C;VYT96YT(ETL("1E
M;F-O9&EN9RD[#0H@("`@("`@("`@("!](&5L<V5I9B`H)')E<&QA8V5%;G1I
M=&EE<R`]/2!014%27U!A8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I
M;%]#1$%405]314-424].*2![#0H@("`@("`@("`@("`@("`@)'1A9ULB8V]N
M=&5N=")=(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T
M:6PZ.F-R96%T94-$871A4V5C=&EO;B@D=&%G6R)C;VYT96YT(ETI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)'1A9R`@("`]("`@<W!R:6YT9B@B
M/"5S)7,^)7,\+R5S/B(L("1T86=;(G%N86UE(ETL("1A='1,:7-T+"`D=&%G
M6R)C;VYT96YT(ETL("1T86=;(G%N86UE(ET@*3L-"B`@("`@("`@?2`@("`@
M("`@#0H@("`@("`@(')E='5R;B`@)'1A9SL-"B`@("!]#0H-"B`@("\J*@T*
M("`@("H@8W)E871E(&$@<W1A<G0@96QE;65N=`T*("`@("H-"B`@("`J(#QC
M;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@
M("H@#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('-T87)T(&5L96UE;G0Z#0H@
M("`@*B`D=&%G(#T@4$5!4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,
M7U5T:6PZ.F-R96%T95-T87)T16QE;65N="@B;7E.<SIM>51A9R(L(&%R<F%Y
M*")F;V\B(#T^(")B87(B*2`L(FAT='`Z+R]W=W<N=S-C+F]R9R]M>4YS(R(I
M.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1Q
M;F%M92`@("`@("`@("`@("!Q=6%L:69I960@=&%G;F%M92`H:6YC;'5D:6YG
M(&YA;65S<&%C92D-"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1A='1R:6)U
M=&5S("`@("`@("!A<G)A>2!C;VYT86EN9R!A='1R:6)U=&5S#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D;F%M97-P86-E57)I("`@("`@55))(&]F('1H
M92!N86UE<W!A8V4-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1M=6QT:6QI
M;F4@("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU;'1I;&EN92!T86<@
M=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE
M(&QI;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I;F1E;G0@("`@("`@
M("`@("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB=71E<R`H7V%U=&\@
M:6YD96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@870@=&AE('-A;64@
M8V]L=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@
M("`@("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS#0H@("`@*B!`<F5T
M=7)N("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@("`@6$U,('-T87)T(&5L
M96UE;G0-"B`@("`J($!S964@("`@("!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;#HZ8W)E871E16YD16QE;65N="@I+"!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E5&%G*"D-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T95-T87)T16QE;65N="@D<6YA
M;64L("1A='1R:6)U=&5S(#T@87)R87DH*2P@)&YA;65S<&%C955R:2`](&YU
M;&PL("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`]("=?875T;R<L("1L
M:6YE8G)E86L@/2`B7&XB*0T*("`@('L-"B`@("`@("`@+R\@:68@;F\@871T
M<FEB=71E<R!H878@8F5E;B!S970L('5S92!E;7!T>2!A='1R:6)U=&5S#0H@
M("`@("`@(&EF("@A:7-S970H)&%T=')I8G5T97,I('Q\("%I<U]A<G)A>2@D
M871T<FEB=71E<RDI('L-"B`@("`@("`@("`@("1A='1R:6)U=&5S(#T@87)R
M87DH*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*"1N86UE
M<W!A8V55<FD@(3T@;G5L;"D@>PT*("`@("`@("`@("`@)'!A<G1S(#T@4$5!
M4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G-P;&ET475A
M;&EF:65D3F%M92@D<6YA;64I.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@
M8VAE8VL@9F]R(&UU;'1I;&EN92!A='1R:6)U=&5S#0H@("`@("`@(&EF("@D
M;75L=&EL:6YE(#T]/2!T<G5E*2![#0H@("`@("`@("`@("!I9B`H)&EN9&5N
M="`]/3T@(E]A=71O(BD@>PT*("`@("`@("`@("`@("`@("1I;F1E;G0@/2!S
M=')?<F5P96%T*"(@(BP@*'-T<FQE;B@D<6YA;64I*S(I*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D;F%M97-P86-E57)I
M("$](&YU;&PI('L-"B`@("`@("`@("`@("\O(&ES(&$@;F%M97-P86-E(&=I
M=F5N#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1S6R)N86UE<W!A8V4B
M72D@)B8@(65M<'1Y*"1P87)T<ULB;F%M97-P86-E(ETI*2![#0H@("`@("`@
M("`@("`@("`@)&%T=')I8G5T97-;(GAM;&YS.B(N)'!A<G1S6R)N86UE<W!A
M8V4B75T@/2`D;F%M97-P86-E57)I.PT*("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`O+R!D969I;F4@=&AI<R!5<FD@87,@=&AE(&1E
M9F%U;'0@;F%M97-P86-E#0H@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;
M(GAM;&YS(ET@/2`D;F%M97-P86-E57)I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@8W)E871E(&%T=')I8G5T92!L:7-T#0H@
M("`@("`@("1A='1,:7-T("`@(#T@("!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,E]834Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='1R:6)U
M=&5S+"!T<G5E+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K*3L-
M"B`@("`@("`@)&5L96UE;G0@("`@/2`@('-P<FEN=&8H(CPE<R5S/B(L("1Q
M;F%M92P@)&%T=$QI<W0I.PT*("`@("`@("!R971U<FX@("1E;&5M96YT.PT*
M("`@('T-"@T*("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@96YD(&5L96UE;G0-
M"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,
M+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S
M=&%R="!E;&5M96YT.@T*("`@("H@)'1A9R`](%!%05)?4&%C:V%G949I;&5?
M1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIC<F5A=&5%;F1%;&5M96YT*")M>4YS
M.FUY5&%G(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@)'%N86UE("`@("`@("`@("`@('%U86QI9FEE9"!T86=N86UE("AI
M;F-L=61I;F<@;F%M97-P86-E*0T*("`@("H@0')E='5R;B`@('-T<FEN9R`@
M)'-T<FEN9R`@("`@("`@("`@(%A-3"!E;F0@96QE;65N=`T*("`@("H@0'-E
M92`@("`@(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL
M.CIC<F5A=&53=&%R=$5L96UE;G0H*2P@4$5!4E]086-K86=E1FEL95]'96YE
M<F%T;W)?=C)?6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!C<F5A=&5%;F1%;&5M96YT*"1Q;F%M92D-"B`@("![#0H@("`@
M("`@("1E;&5M96YT("`@(#T@("!S<')I;G1F*"(\+R5S/B(L("1Q;F%M92D[
M#0H@("`@("`@(')E='5R;B`@)&5L96UE;G0[#0H@("`@?0T*("`@(`T*("`@
M+RHJ#0H@("`@*B!C<F5A=&4@86X@6$U,(&-O;6UE;G0-"B`@("`J#0H@("`@
M*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-
M"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R="!E;&5M96YT
M.@T*("`@("H@)'1A9R`](%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R
M7UA-3%]5=&EL.CIC<F5A=&5#;VUM96YT*"))(&%M(&$@8V]M;65N="(I.PT*
M("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-
M"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1C;VYT
M96YT("`@("`@("`@("!C;VYT96YT(&]F('1H92!C;VUM96YT#0H@("`@*B!`
M<F5T=7)N("`@<W1R:6YG("`D8V]M;65N="`@("`@("`@("`@6$U,(&-O;6UE
M;G0-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T94-O;6UE;G0H)&-O;G1E
M;G0I#0H@("`@>PT*("`@("`@("`D8V]M;65N="`@("`]("`@<W!R:6YT9B@B
M/"$M+2`E<R`M+3XB+"`D8V]N=&5N="D[#0H@("`@("`@(')E='5R;B`@)&-O
M;6UE;G0[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@("`@*B!C<F5A=&4@82!#
M1&%T82!S96-T:6]N#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U
M:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(&-R
M96%T92!A($-$871A('-E8W1I;VX-"B`@("`J("1T86<@/2!014%27U!A8VMA
M9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ8W)E871E0T1A=&%396-T
M:6]N*"))(&%M(&-O;G1E;G0N(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@)&1A=&$@("`@("`@("`@("`@(&1A=&$@;V8@
M=&AE($-$871A('-E8W1I;VX-"B`@("`J($!R971U<FX@("!S=')I;F<@("1S
M=')I;F<@("`@("`@("`@("!#1&%T82!S96-T:6]N('=I=&@@8V]N=&5N=`T*
M("`@("HO#0H@("`@9G5N8W1I;VX@8W)E871E0T1A=&%396-T:6]N*"1D871A
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("!S<')I;G1F*"(\(5M#1$%405LE
M<UU=/B(L("1D871A*3L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@<W!L:70@
M<75A;&EF:65D(&YA;64@86YD(')E='5R;B!N86UE<W!A8V4@86YD(&QO8V%L
M('!A<G0-"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC
M92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@<W!L:70@<75A
M;&EF:65D('1A9PT*("`@("H@)'!A<G1S(#T@4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B>'-L
M=#IS='EL97-H965T(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*B!T:&4@<F5T
M=7)N960@87)R87D@=VEL;"!C;VYT86EN('1W;R!E;&5M96YT<SH-"B`@("`J
M(#QP<F4^#0H@("`@*B!A<G)A>2@-"B`@("`J("`@("`@(")N86UE<W!A8V4B
M(#T^(")X<VQT(BP-"B`@("`J("`@("`@(")L;V-A;%!A<G0B(#T^(")S='EL
M97-H965T(@T*("`@("H@("`@("`I.PT*("`@("H@/"]P<F4^#0H@("`@*@T*
M("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P
M87)A;2`@<W1R:6YG("`@("1Q;F%M92`@("`@('%U86QI9FEE9"!T86<@;F%M
M90T*("`@("H@0'!A<F%M("!S=')I;F<@("`@)&1E9F%U;'1.<R`@9&5F875L
M="!N86UE<W!A8V4@*&]P=&EO;F%L*0T*("`@("H@0')E='5R;B!A<G)A>2`@
M("`@)'!A<G1S("`@("`@87)R87D@8V]N=&%I;FEN9R!N86UE<W!A8V4@86YD
M(&QO8V%L('!A<G0-"B`@("`J+PT*("`@(&9U;F-T:6]N('-P;&ET475A;&EF
M:65D3F%M92@D<6YA;64L("1D969A=6QT3G,@/2!N=6QL*0T*("`@('L-"B`@
M("`@("`@:68@*'-T<G-T<B@D<6YA;64L("<Z)RDI('L-"B`@("`@("`@("`@
M("1T;7`@/2!E>'!L;V1E*"(Z(BP@)'%N86UE*3L-"B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@(FYA;65S
M<&%C92(@/3X@)'1M<%LP72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(FQO8V%L4&%R="(@/3X@)'1M<%LQ70T*("`@("`@("`@("`@("`@("`@("`@
M("`@*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("`@(FYA;65S<&%C92(@/3X@)&1E9F%U;'1.<RP-
M"B`@("`@("`@("`@("`@("`@("`@("`B;&]C86Q087)T(B`]/B`D<6YA;64-
M"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@("\J*@T*("`@
M("H@8VAE8VLL('=H971H97(@<W1R:6YG(&ES('9A;&ED(%A-3"!N86UE#0H@
M("`@*@T*("`@("H@/'`^6$U,(&YA;65S(&%R92!U<V5D(&9O<B!T86=N86UE
M+"!A='1R:6)U=&4@;F%M97,@86YD('9A<FEO=7,-"B`@("`J(&]T:&5R+"!L
M97-S97(@:VYO=VX@96YT:71I97,N/"]P/@T*("`@("H@/'`^06X@6$U,(&YA
M;64@;6%Y(&]N;'D@8V]N<VES="!O9B!A;'!H86YU;65R:6,@8VAA<F%C=&5R
M<RP-"B`@("`J(&1A<VAE<RP@=6YD97-C;W)E<R!A;F0@<&5R:6]D<RP@86YD
M(&AA<R!T;R!S=&%R="!W:71H(&$@;&5T=&5R#0H@("`@*B!O<B!A;B!U;F1E
M<G-C;W)E+@T*("`@("H@/"]P/@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@
M("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@
M*B`O+R!V97)I9GD@=&%G(&YA;64-"B`@("`J("1R97-U;'0@/2!014%27U!A
M8VMA9V5&:6QE7T=E;F5R871O<E]V,E]834Q?571I;#HZ:7-686QI9$YA;64H
M(FEN=F%L:61486<_(BD[#0H@("`@*B!I9B`H4$5!4E]086-K86=E1FEL95]'
M96YE<F%T;W)?=C)?6$U,7U5T:6PZ.FES17)R;W(H)')E<W5L="DI('L-"B`@
M("`J("`@('!R:6YT("));G9A;&ED(%A-3"!N86UE.B`B("X@)')E<W5L="T^
M9V5T365S<V%G92@I.PT*("`@("H@?0T*("`@("H@/"]C;V1E/@T*("`@("H-
M"B`@("`J($!A8V-E<W,@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@
M0'!A<F%M("`@<W1R:6YG("`D<W1R:6YG('-T<FEN9R!T:&%T('-H;W5L9"!B
M92!C:&5C:V5D#0H@("`@*B!`<F5T=7)N("!M:7AE9"`@("1V86QI9"`@=')U
M92P@:68@<W1R:6YG(&ES(&$@=F%L:60@6$U,(&YA;64L(%!%05(@97)R;W(@
M;W1H97)W:7-E#0H@("`@*B!`=&]D;R`@("!S=7!P;W)T(&9O<B!O=&AE<B!C
M:&%R<V5T<PT*("`@("HO#0H@("`@9G5N8W1I;VX@:7-686QI9$YA;64H)'-T
M<FEN9RD-"B`@("![#0H@("`@("`@("\O(&-H96-K(&9O<B!I;G9A;&ED(&-H
M87)S#0H@("`@("`@(&EF("@A<')E9U]M871C:"@B+UY;6SIA;&YU;3I=7UPM
M+ETD+R(L("1S=')I;F=[,'TI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!
M4E]086-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6PZ.G)A:7-E17)R
M;W(H(")834P@;F%M97,@;6%Y(&]N;'D@<W1A<G0@=VET:"!L971T97(@;W(@
M=6YD97)S8V]R92(L(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8R7UA-
M3%]5=&EL7T524D]27TE.5D%,241?4U1!4E0@*3L-"B`@("`@("`@?0T*("`@
M("`@("`-"B`@("`@("`@+R\@8VAE8VL@9F]R(&EN=F%L:60@8VAA<G,-"B`@
M("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7BA;82UZ02U:7UTH6V$M>D$M6C`M
M.5]<+5PN72HI/SHI/UMA+7I!+5I?72A;82UZ02U:,"TY7UPM7"Y=*RD_)"\B
M+"`D<W1R:6YG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05)?4&%C:V%G
M949I;&5?1V5N97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES945R<F]R*"`B6$U,
M(&YA;65S(&UA>2!O;FQY(&-O;G1A:6X@86QP:&%N=6UE<FEC(&-H87)S+"!P
M97)I;V0L(&AY<&AE;BP@8V]L;VX@86YD('5N9&5R<V-O<F5S(BP@4$5!4E]0
M86-K86=E1FEL95]'96YE<F%T;W)?=C)?6$U,7U5T:6Q?15)23U)?24Y604Q)
M1%]#2$%24R`I.PT*("`@("`@("`@?0T*("`@("`@("`O+R!834P@;F%M92!I
M<R!V86QI9`T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("\J
M*@T*("`@("H@<F5P;&%C96UE;G0@9F]R(%!%05)?4&%C:V%G949I;&5?1V5N
M97)A=&]R7W8R7UA-3%]5=&EL.CIR86ES945R<F]R#0H@("`@*@T*("`@("H@
M079O:61S('1H92!N96-E<W-I='D@=&\@86QW87ES(')E<75I<F4-"B`@("`J
M(%!%05(N<&AP#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&5R<F]R(&UE<W-A9V4-"B`@("`J
M($!P87)A;2`@("!I;G1E9V5R("`@("!E<G)O<B!C;V1E#0H@("`@*B!`<F5T
M=7)N("`@;V)J96-T(%!%05)?17)R;W(-"B`@("`J+PT*("`@(&9U;F-T:6]N
M(')A:7-E17)R;W(H)&US9RP@)&-O9&4I#0H@("`@>PT*("`@("`@("!R97%U
M:7)E7V]N8V4@)U!%05(N<&AP)SL-"B`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)&US9RP@)&-O9&4I.PT*("`@('T-"GT-"C\^=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U!A8VMA9V5&:6QE+T=E;F5R871O
M<B]V,2YP:'``````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,30U,3,P(#$P-3$U-#,T
M,3,T(#`R-#,S-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!P86-K86=E+GAM;"!G96YE<F%T:6]N
M(&-L87-S+"!P86-K86=E+GAM;"!V97)S:6]N(#$N,`T*("H-"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C
M96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J
M('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!V,2YP:'`L=B`Q+C<P(#(P,#8O
M,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-
M"B\J*@T*("H@;F5E9&5D(&9O<B!014%27U9!3$E$051%7RH@8V]N<W1A;G1S
M#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]686QI9&%T92YP:'`G.PT*<F5Q
M=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"G)E<75I<F5?;VYC92`G4$5!4B]0
M86-K86=E1FEL92]V,BYP:'`G.PT*+RHJ#0H@*B!4:&ES(&-L87-S(&-O;G9E
M<G1S(&$@4$5!4E]086-K86=E1FEL95]V,2!O8FIE8W0@:6YT;R!A;GD@;W5T
M<'5T(&9O<FUA="X-"B`J#0H@*B!3=7!P;W)T960@;W5T<'5T(&9O<FUA=',@
M:6YC;'5D92!A<G)A>2P@6$U,('-T<FEN9RP@86YD(&$@4$5!4E]086-K86=E
M1FEL95]V,@T*("H@;V)J96-T+"!F;W(@8V]N=F5R=&EN9R!P86-K86=E+GAM
M;"`Q+C`@:6YT;R!P86-K86=E+GAM;"`R+C`@=VET:"!N;R!S=V5A="X-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U!A8VMA9V5&:6QE7T=E;F5R
M871O<E]V,0T*>PT*("`@("\J*@T*("`@("`J($!V87(@4$5!4E]086-K86=E
M1FEL95]V,0T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5F:6QE.PT*("`@
M(&9U;F-T:6]N(%!%05)?4&%C:V%G949I;&5?1V5N97)A=&]R7W8Q*"8D<&%C
M:V%G969I;&4I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W!A8VMA9V5F:6QE
M(#T@)B1P86-K86=E9FEL93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9710
M86-K86=E<E9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<Q+C0N
M.2<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(%!%05)?4&%C
M:V%G97(-"B`@("`@*B!`<&%R86T@8F]O;"!I9B!T<G5E+"!A("YT9WH@:7,@
M=W)I='1E;BP@;W1H97)W:7-E(&$@+G1A<B!I<R!W<FET=&5N#0H@("`@("H@
M0'!A<F%M('-T<FEN9WQN=6QL(&1I<F5C=&]R>2!I;B!W:&EC:"!T;R!S879E
M('1H92`N=&=Z#0H@("`@("H@0')E='5R;B!S=')I;F=\4$5!4E]%<G)O<B!L
M;V-A=&EO;B!O9B!P86-K86=E(&]R(&5R<F]R(&]B:F5C=`T*("`@("`J+PT*
M("`@(&9U;F-T:6]N('1O5&=Z*"8D<&%C:V%G97(L("1C;VUP<F5S<R`]('1R
M=64L("1W:&5R92`](&YU;&PI#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N
M8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@("`@("`@(&EF("@D=VAE<F4@/3T]
M(&YU;&PI('L-"B`@("`@("`@("`@(&EF("@A*"1W:&5R92`](%-Y<W1E;3HZ
M;6MT96UP*&%R<F%Y*"<M9"<I*2DI('L-"B`@("`@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]4
M9WHZ(&UK=&5M<"!F86EL960G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?2!E;'-E:68@*"%`4WES=&5M.CIM:T1I<BAA<G)A>2@G+7`G+"`D=VAE<F4I
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%
M05)?4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B`B)R`N("1W:&5R92`N("<B(&-O
M=6QD)R`N#0H@("`@("`@("`@("`@("`@)R!N;W0@8F4@8W)E871E9"<I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D=VAE<F4@+B!$
M25)%0U1/4EE?4T5005)!5$]2("X@)W!A8VMA9V4N>&UL)RD@)B8-"B`@("`@
M("`@("`@("`@(6ES7V9I;&4H)'=H97)E("X@1$E214-43U)97U-%4$%2051/
M4B`N("=P86-K86=E+GAM;"<I*2![#0H@("`@("`@("`@("!R971U<FX@4$5!
M4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]49WHZ('5N
M86)L92!T;R!S879E('!A8VMA9V4N>&UL(&%S)R`N#0H@("`@("`@("`@("`@
M("`@)R`B)R`N("1W:&5R92`N($1)4D5#5$]265]315!!4D%43U(@+B`G<&%C
M:V%G92YX;6PB)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"$D=&AI<RT^
M7W!A8VMA9V5F:6QE+3YV86QI9&%T92A014%27U9!3$E$051%7U!!0TM!1TE.
M1RDI('L-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=0
M14%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@:6YV86QI9"!P86-K86=E(&9I
M;&4G*3L-"B`@("`@("`@?0T*("`@("`@("`D<&MG:6YF;R`]("1T:&ES+3Y?
M<&%C:V%G969I;&4M/F=E=$%R<F%Y*"D[#0H@("`@("`@("1E>'0@/2`D8V]M
M<')E<W,@/R`G+G1G>B<@.B`G+G1A<B<[#0H@("`@("`@("1P:V=V97(@/2`D
M<&MG:6YF;ULG<&%C:V%G92==("X@)RTG("X@)'!K9VEN9F];)W9E<G-I;VXG
M73L-"B`@("`@("`@)&1E<W1?<&%C:V%G92`](&=E=&-W9"@I("X@1$E214-4
M3U)97U-%4$%2051/4B`N("1P:V=V97(@+B`D97AT.PT*("`@("`@("!I9B`H
M9FEL95]E>&ES=',H9V5T8W=D*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@
M)'!K9W9E<B`N("1E>'0I("8F#0H@("`@("`@("`@("`@("%I<U]F:6QE*&=E
M=&-W9"@I("X@1$E214-43U)97U-%4$%2051/4B`N("1P:V=V97(@+B`D97AT
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%
M05)?4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B!C86YN;W0@8W)E871E('1G>B!F
M:6QE("(G("X-"B`@("`@("`@("`@("`@("!G971C=V0H*2`N($1)4D5#5$]2
M65]315!!4D%43U(@+B`D<&MG=F5R("X@)&5X="`N("<B)RD[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1P:V=F:6QE(#T@)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T4&%C:V%G949I;&4H*2D@>PT*("`@("`@("`@("`@)'!K9V1I<B`]
M(&1I<FYA;64H<F5A;'!A=&@H)'!K9V9I;&4I*3L-"B`@("`@("`@("`@("1P
M:V=F:6QE(#T@8F%S96YA;64H)'!K9V9I;&4I.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!%05)?
M4&%C:V%G969I;&5?=C$Z.G1O5&=Z.B!P86-K86=E(&9I;&4@;V)J96-T(&UU
M<W0@)R`N#0H@("`@("`@("`@("`@("`@)V)E(&-R96%T960@9G)O;2!A(')E
M86P@9FEL92<I.PT*("`@("`@("!]#0H@("`@("`@("\O('M[>R!#<F5A=&4@
M=&AE('!A8VMA9V4@9FEL92!L:7-T#0H@("`@("`@("1F:6QE;&ES="`](&%R
M<F%Y*"D[#0H@("`@("`@("1I(#T@,#L-"@T*("`@("`@("!F;W)E86-H("@D
M=&AI<RT^7W!A8VMA9V5F:6QE+3YG971&:6QE;&ES="@I(&%S("1F;F%M92`]
M/B`D871T<RD@>PT*("`@("`@("`@("`@)&9I;&4@/2`D<&MG9&ER("X@1$E2
M14-43U)97U-%4$%2051/4B`N("1F;F%M93L-"B`@("`@("`@("`@(&EF("@A
M9FEL95]E>&ES=',H)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(D9I;&4@9&]E<R!N;W0@97AI<W0Z("1F;F%M
M92(I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M9FEL96QI<W1;)&DK*UT@/2`D9FEL93L-"B`@("`@("`@("`@("`@("!I9B`H
M(6ES<V5T*"1A='1S6R=M9#5S=6TG72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P86-K86=E9FEL92T^<V5T1FEL94%T=')I8G5T92@D9FYA
M;64L("=M9#5S=6TG+"!M9#5?9FEL92@D9FEL92DI.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D<&%C:V%G97(M/FQO9R@R+"`B061D
M:6YG(&9I;&4@)&9N86UE(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@+R\@?7U]#0H@("`@("`@("1P86-K86=E>&UL(#T@)'1H:7,M
M/G1O4&%C:V%G949I;&4H)'=H97)E+"!014%27U9!3$E$051%7U!!0TM!1TE.
M1RP@)W!A8VMA9V4N>&UL)RP@=')U92D[#0H@("`@("`@(&EF("@D<&%C:V%G
M97AM;"D@>PT*("`@("`@("`@("`@)'1A<B`])B!N97<@07)C:&EV95]487(H
M)&1E<W1?<&%C:V%G92P@)&-O;7!R97-S*3L-"B`@("`@("`@("`@("1T87(M
M/G-E=$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.R`O+R!86%@@
M1&]N)W0@<')I;G0@97)R;W)S#0H@("`@("`@("`@("`O+R`M+2TM+2!#<F5A
M=&5S('=I=&@@=&AE('!A8VMA9V4N>&UL(&9I;&4-"B`@("`@("`@("`@("1O
M:R`]("1T87(M/F-R96%T94UO9&EF>2AA<G)A>2@D<&%C:V%G97AM;"DL("<G
M+"`D=VAE<F4I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]K
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D;VL[#0H@("`@("`@("`@
M("!](&5L<V5I9B`H(21O:RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT;U1G>CH@
M=&%R8F%L;"!C<F5A=&EO;B!F86EL960G*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("\O("TM+2TM($%D9"!T:&4@8V]N=&5N="!O9B!T:&4@<&%C
M:V%G90T*("`@("`@("`@("`@:68@*"$D=&%R+3YA9&1-;V1I9GDH)&9I;&5L
M:7-T+"`D<&MG=F5R+"`D<&MG9&ER*2D@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT
M;U1G>CH@=&%R8F%L;"!C<F5A=&EO;B!F86EL960G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(')E='5R;B`D9&5S=%]P86-K86=E.PT*("`@("`@
M("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9WQN
M=6QL(&1I<F5C=&]R>2!T;R!P;&%C92!T:&4@<&%C:V%G92YX;6P@:6XL(&]R
M(&YU;&P@9F]R(&$@=&5M<&]R87)Y(&1I<@T*("`@("`J($!P87)A;2!I;G0@
M;VYE(&]F('1H92!014%27U9!3$E$051%7RH@8V]N<W1A;G1S#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!N86UE(&]F('1H92!G96YE<F%T960@9FEL90T*("`@
M("`J($!P87)A;2!B;V]L(&EF('1R=64L('1H96X@;F\@86YA;'ES:7,@=VEL
M;"!B92!P97)F;W)M960@;VX@<F]L93TB<&AP(B!F:6QE<PT*("`@("`J($!R
M971U<FX@<W1R:6YG?%!%05)?17)R;W(@<&%T:"!T;R!T:&4@8W)E871E9"!F
M:6QE(&]N('-U8V-E<W,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!T;U!A8VMA
M9V5&:6QE*"1W:&5R92`](&YU;&PL("1S=&%T92`](%!%05)?5D%,241!5$5?
M3D]234%,+"`D;F%M92`]("=P86-K86=E+GAM;"<L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;F]F:6QE8VAE8VMI;F<@/2!F86QS92D-"B`@("![
M#0H@("`@("`@(&EF("@A)'1H:7,M/E]P86-K86=E9FEL92T^=F%L:61A=&4H
M)'-T871E+"`D;F]F:6QE8VAE8VMI;F<I*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]0
M86-K86=E1FEL93H@:6YV86QI9"!P86-K86=E+GAM;"<L#0H@("`@("`@("`@
M("`@("`@;G5L;"P@;G5L;"P@;G5L;"P@)'1H:7,M/E]P86-K86=E9FEL92T^
M9V5T5F%L:61A=&EO;E=A<FYI;F=S*"DI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@D=VAE<F4@/3T](&YU;&PI('L-"B`@("`@("`@("`@(&EF("@A*"1W
M:&5R92`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M9"<I*2DI('L-"B`@("`@
M("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K
M86=E9FEL95]V,3HZ=&]086-K86=E1FEL93H@;6MT96UP(&9A:6QE9"<I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H(4!3>7-T96TZ.FUK
M1&ER*&%R<F%Y*"<M<"<L("1W:&5R92DI*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G4$5!4E]086-K86=E9FEL95]V,3HZ=&]0
M86-K86=E1FEL93H@(B<@+B`D=VAE<F4@+B`G(B!C;W5L9"<@+@T*("`@("`@
M("`@("`@("`@("<@;F]T(&)E(&-R96%T960G*3L-"B`@("`@("`@?0T*("`@
M("`@("`D;F5W<&MG9FEL92`]("1W:&5R92`N($1)4D5#5$]265]315!!4D%4
M3U(@+B`D;F%M93L-"B`@("`@("`@)&YP(#T@0&9O<&5N*"1N97=P:V=F:6QE
M+"`G=V(G*3L-"B`@("`@("`@:68@*"$D;G`I('L-"B`@("`@("`@("`@(')E
M='5R;B!014%2.CIR86ES945R<F]R*"=014%27U!A8VMA9V5F:6QE7W8Q.CIT
M;U!A8VMA9V5&:6QE.B!U;F%B;&4@=&\@<V%V92`G("X-"B`@("`@("`@("`@
M("`@("(D;F%M92!A<R`D;F5W<&MG9FEL92(I.PT*("`@("`@("!]#0H@("`@
M("`@(&9W<FET92@D;G`L("1T:&ES+3YT;UAM;"@D<W1A=&4L('1R=64I*3L-
M"B`@("`@("`@9F-L;W-E*"1N<"D[#0H@("`@("`@(')E='5R;B`D;F5W<&MG
M9FEL93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!F:7@@8F]T:"!834P@
M96YC;V1I;F<@=&\@8F4@551&."P@86YD(')E<&QA8V4@<W1A;F1A<F0@6$U,
M(&5N=&ET:65S(#P@/B`B("8@)PT*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R:6YG#0H@("`@("H@0')E='5R;B!S=')I;F<-"B`@("`@*B!`
M86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9FEX6&UL
M16YC;V1I;F<H)'-T<FEN9RD-"B`@("![#0H@("`@("`@(&EF("AV97)S:6]N
M7V-O;7!A<F4H<&AP=F5R<VEO;B@I+"`G-2XP+C`G+"`G;'0G*2D@>PT*("`@
M("`@("`@("`@)'-T<FEN9R`]('5T9CA?96YC;V1E*"1S=')I;F<I.PT*("`@
M("`@("!]#0H@("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG+"!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<F
M)R`@/3X@)R9A;7`[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<^)R`@/3X@)R9G=#LG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)SPG("`]/B`G)FQT.R<L#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B<@
M(#T^("<F<75O=#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)UPG)R`]/B`G)F%P;W,[)R`I*3L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!2971U<FX@86X@6$U,(&1O8W5M96YT(&)A<V5D(&]N
M('1H92!P86-K86=E(&EN9F\@*&%S(')E='5R;F5D#0H@("`@("H@8GD@=&AE
M(%!%05)?0V]M;6]N.CII;F9O1G)O;2H@;65T:&]D<RDN#0H@("`@("H-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R!834P@9&%T80T*("`@("`J+PT*("`@(&9U
M;F-T:6]N('1O6&UL*"1S=&%T92`](%!%05)?5D%,241!5$5?3D]234%,+"`D
M;F]F:6QE=F%L:61A=&EO;B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'1H
M:7,M/E]P86-K86=E9FEL92T^<V5T1&%T92AD871E*"=9+6TM9"<I*3L-"B`@
M("`@("`@:68@*"$D=&AI<RT^7W!A8VMA9V5F:6QE+3YV86QI9&%T92@D<W1A
M=&4L("1N;V9I;&5V86QI9&%T:6]N*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("1P:V=I;F9O(#T@)'1H:7,M
M/E]P86-K86=E9FEL92T^9V5T07)R87DH*3L-"B`@("`@("`@<W1A=&EC("1M
M86EN=%]M87`@/2!A<G)A>2@-"B`@("`@("`@("`@(")H86YD;&4B(#T^(")U
M<V5R(BP-"B`@("`@("`@("`@(")N86UE(B`]/B`B;F%M92(L#0H@("`@("`@
M("`@("`B96UA:6PB(#T^(")E;6%I;"(L#0H@("`@("`@("`@("`B<F]L92(@
M/3X@(G)O;&4B+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@)')E="`]("(\
M/WAM;"!V97)S:6]N/5PB,2XP7"(@96YC;V1I;F<]7")55$8M.%PB(#\^7&XB
M.PT*("`@("`@("`D<F5T("X]("(\(41/0U194$4@<&%C:V%G92!365-414T@
M7")H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,%PB/EQN(CL-
M"B`@("`@("`@)')E="`N/2`B/'!A8VMA9V4@=F5R<VEO;CU<(C$N,%PB('!A
M8VMA9V5R=F5R<VEO;CU<(C$N-"XY7"(^7&XB("X-"B(@/&YA;64^)'!K9VEN
M9F];<&%C:V%G95T\+VYA;64^(CL-"B`@("`@("`@:68@*&ES<V5T*"1P:V=I
M;F9O6R=E>'1E;F1S)UTI*2![#0H@("`@("`@("`@("`D<F5T("X](")<;CQE
M>'1E;F1S/B1P:V=I;F9O6V5X=&5N9'-=/"]E>'1E;F1S/B([#0H@("`@("`@
M('T-"B`@("`@("`@)')E="`N/0T*(")<;B`\<W5M;6%R>3XB+B1T:&ES+3Y?
M9FEX6&UL16YC;V1I;F<H)'!K9VEN9F];)W-U;6UA<GDG72DN(CPO<W5M;6%R
M>3Y<;B(@+@T*(B`\9&5S8W)I<'1I;VX^(BYT<FEM*"1T:&ES+3Y?9FEX6&UL
M16YC;V1I;F<H)'!K9VEN9F];)V1E<V-R:7!T:6]N)UTI*2XB7&X@/"]D97-C
M<FEP=&EO;CY<;B(@+@T*(B`\;6%I;G1A:6YE<G,^7&XB.PT*("`@("`@("!F
M;W)E86-H("@D<&MG:6YF;ULG;6%I;G1A:6YE<G,G72!A<R`D;6%I;G0I('L-
M"B`@("`@("`@("`@("1R970@+CT@(B`@/&UA:6YT86EN97(^7&XB.PT*("`@
M("`@("`@("`@9F]R96%C:"`H)&UA:6YT7VUA<"!A<R`D:61X(#T^("1E;&TI
M('L-"B`@("`@("`@("`@("`@("`D<F5T("X]("(@("`\)&5L;3XB.PT*("`@
M("`@("`@("`@("`@("1R970@+CT@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D
M;6%I;G1;)&ED>%TI.PT*("`@("`@("`@("`@("`@("1R970@+CT@(CPO)&5L
M;3Y<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T("X]("(@
M(#PO;6%I;G1A:6YE<CY<;B([#0H@("`@("`@('T-"B`@("`@("`@)')E="`N
M/2`B("`\+VUA:6YT86EN97)S/EQN(CL-"B`@("`@("`@)')E="`N/2`D=&AI
M<RT^7VUA:V5296QE87-E6&UL*"1P:V=I;F9O+"!F86QS92P@)'-T871E*3L-
M"B`@("`@("`@:68@*&ES<V5T*"1P:V=I;F9O6R=C:&%N9V5L;V<G72D@)B8@
M8V]U;G0H)'!K9VEN9F];)V-H86YG96QO9R==*2`^(#`I('L-"B`@("`@("`@
M("`@("1R970@+CT@(B`\8VAA;F=E;&]G/EQN(CL-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P:V=I;F9O6R=C:&%N9V5L;V<G72!A<R`D;VQD<F5L96%S92D@
M>PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M/E]M86ME4F5L96%S
M95AM;"@D;VQD<F5L96%S92P@=')U92D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D<F5T("X]("(@/"]C:&%N9V5L;V<^7&XB.PT*("`@("`@("!]
M#0H@("`@("`@("1R970@+CT@(CPO<&%C:V%G93Y<;B([#0H@("`@("`@(')E
M='5R;B`D<F5T.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!?
M;6%K95)E;&5A<V58;6PH*0T*#0H@("`@+RHJ#0H@("`@("H@1V5N97)A=&4@
M<&%R="!O9B!A;B!834P@9&5S8W)I<'1I;VX@=VET:"!R96QE87-E(&EN9F]R
M;6%T:6]N+@T*("`@("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("`D<&MG:6YF
M;R`@("!A<G)A>2!W:71H(')E;&5A<V4@:6YF;W)M871I;VX-"B`@("`@*B!`
M<&%R86T@8F]O;"`@("1C:&%N9V5L;V<@('=H971H97(@=&AE(')E<W5L="!W
M:6QL(&)E(&EN(&$@8VAA;F=E;&]G(&5L96UE;G0-"B`@("`@*@T*("`@("`J
M($!R971U<FX@<W1R:6YG(%A-3"!D871A#0H@("`@("H-"B`@("`@*B!`86-C
M97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?;6%K95)E;&5A
M<V58;6PH)'!K9VEN9F\L("1C:&%N9V5L;V<@/2!F86QS92P@)'-T871E(#T@
M4$5!4E]604Q)1$%415].3U)-04PI#0H@("`@>PT*("`@("`@("`O+R!86%@@
M455/5$4@14Y4251)15,@24X@4$-$051!+"!/4B!%34)%1"!)3B!#1$%402!"
M3$]#2U,A(0T*("`@("`@("`D:6YD96YT(#T@)&-H86YG96QO9R`_("(@("(@
M.B`B(CL-"B`@("`@("`@)')E="`]("(D:6YD96YT(#QR96QE87-E/EQN(CL-
M"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG=F5R<VEO;B==*2D@>PT*
M("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/'9E<G-I;VX^)'!K9VEN
M9F];=F5R<VEO;ET\+W9E<G-I;VX^7&XB.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("@A96UP='DH)'!K9VEN9F];)W)E;&5A<V5?9&%T92==*2D@>PT*("`@
M("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/&1A=&4^)'!K9VEN9F];<F5L
M96%S95]D871E73PO9&%T93Y<;B([#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"%E;7!T>2@D<&MG:6YF;ULG<F5L96%S95]L:6-E;G-E)UTI*2![#0H@("`@
M("`@("`@("`D<F5T("X]("(D:6YD96YT("`\;&EC96YS93XD<&MG:6YF;UMR
M96QE87-E7VQI8V5N<V5=/"]L:6-E;G-E/EQN(CL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE87-E7W-T871E)UTI*2![
M#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\<W1A=&4^)'!K9VEN
M9F];<F5L96%S95]S=&%T95T\+W-T871E/EQN(CL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H(65M<'1Y*"1P:V=I;F9O6R=R96QE87-E7VYO=&5S)UTI*2![
M#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\;F]T97,^(BYT<FEM
M*"1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'!K9VEN9F];)W)E;&5A<V5?;F]T
M97,G72DI#0H@("`@("`@("`@("`N(EQN)&EN9&5N="`@/"]N;W1E<SY<;B([
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"%E;7!T>2@D<&MG:6YF;ULG<F5L
M96%S95]W87)N:6YG<R==*2D@>PT*("`@("`@("`@("`@)')E="`N/2`B)&EN
M9&5N="`@/'=A<FYI;F=S/B(N)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D<&MG
M:6YF;ULG<F5L96%S95]W87)N:6YG<R==*2XB/"]W87)N:6YG<SY<;B([#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1P:V=I;F9O6R=R96QE87-E
M7V1E<',G72D@)B8@<VEZ96]F*"1P:V=I;F9O6R=R96QE87-E7V1E<',G72D@
M/B`P*2![#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\9&5P<SY<
M;B([#0H@("`@("`@("`@("!F;W)E86-H("@D<&MG:6YF;ULG<F5L96%S95]D
M97!S)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("1R970@+CT@(B1I
M;F1E;G0@("`\9&5P('1Y<&4]7"(D9&5P6W1Y<&5=7"(@<F5L/5PB)&1E<%MR
M96Q=7"(B.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=V97)S
M:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B!V97)S
M:6]N/5PB)&1E<%MV97)S:6]N75PB(CL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R970@+CT@(B!O<'1I;VYA;#U<(B1D
M97!;;W!T:6]N86Q=7"(B.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1E<%LG;F%M92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5T("X]("(^)&1E<%MN86UE73PO9&5P/EQN(CL-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5T("X]("(O/EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D<F5T("X]("(D:6YD96YT("`\+V1E<',^7&XB
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&MG:6YF;ULG8V]N
M9FEG=7)E7V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@("1R970@+CT@(B1I
M;F1E;G0@(#QC;VYF:6=U<F5O<'1I;VYS/EQN(CL-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1P:V=I;F9O6R=C;VYF:6=U<F5?;W!T:6]N<R==(&%S("1C*2![
M#0H@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@(#QC;VYF:6=U
M<F5O<'1I;VX@;F%M93U<(B(N#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9FEX6&UL16YC;V1I;F<H)&-;)VYA;64G72D@+B`B7"(B.PT*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D8ULG9&5F875L="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<F5T("X]("(@9&5F875L=#U<(B(@+B`D=&AI<RT^
M7V9I>%AM;$5N8V]D:6YG*"1C6R=D969A=6QT)UTI("X@(EPB(CL-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E="`N/2`B('!R;VUP
M=#U<(B(@+B`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG*"1C6R=P<F]M<'0G72D@
M+B`B7"(B.PT*("`@("`@("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/"]C
M;VYF:6=U<F5O<'1I;VYS/EQN(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)'!K9VEN9F];)W!R;W9I9&5S)UTI*2![#0H@("`@("`@("`@("!F
M;W)E86-H("@D<&MG:6YF;ULG<')O=FED97,G72!A<R`D:V5Y(#T^("1W:&%T
M*2![#0H@("`@("`@("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@/'!R;W9I
M9&5S('1Y<&4]7"(D=VAA=%MT>7!E75PB("([#0H@("`@("`@("`@("`@("`@
M)')E="`N/2`B;F%M93U<(B1W:&%T6VYA;65=7"(@(CL-"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'=H871;)V5X=&5N9',G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E="`N/2`B97AT96YD<SU<(B1W:&%T6V5X=&5N9'-=
M7"(@(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E
M="`N/2`B+SY<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1P:V=I;F9O6R=F:6QE;&ES="==*2D@>PT*("`@("`@
M("`@("`@)')E="`N/2`B)&EN9&5N="`@/&9I;&5L:7-T/EQN(CL-"B`@("`@
M("`@("`@(&EF("@D<W1A=&4@7B!014%27U9!3$E$051%7U!!0TM!1TE.1RD@
M>PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M/G)E8W5R<VEV95AM
M;$9I;&5L:7-T*"1P:V=I;F9O6R=F:6QE;&ES="==*3L-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!K9VEN9F];
M)V9I;&5L:7-T)UT@87,@)&9I;&4@/3X@)&9A*2![#0H@("`@("`@("`@("`@
M("`@("`@($`D<F5T("X]("(D:6YD96YT("`@/&9I;&4@<F]L93U<(B1F85MR
M;VQE75PB(CL-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1F85LG
M8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1R970@+CT@)R!B87-E:6YS=&%L;&1I<CTB)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D9F%;)V)A
M<V5I;G-T86QL9&ER)UTI("X@)R(G.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9F%;)VUD-7-U;2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B(&UD-7-U
M;3U<(B1F85MM9#5S=6U=7"(B.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9F%;)W!L871F;W)M)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("X]("(@<&QA=&9O
M<FT]7"(D9F%;<&QA=&9O<FU=7"(B.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A96UP='DH)&9A6R=I;G-T86QL
M+6%S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5T("X]("<@
M:6YS=&%L;"UA<STB)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]F:7A8;6Q%;F-O9&EN9R@D9F%;)VEN<W1A;&PM87,G72D@+B`G
M(B<[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)')E="`N/2`G(&YA;64](B<@+B`D=&AI<RT^7V9I>%AM;$5N8V]D:6YG
M*"1F:6QE*2`N("<B)SL-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M<'1Y
M*"1F85LG<F5P;&%C96UE;G1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5T("X]("(O/EQN(CL-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R970@+CT@(CY<;B([
M#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9F%;)W)E<&QA
M8V5M96YT<R==(&%S("1R*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E="`N/2`B)&EN9&5N="`@("`\<F5P;&%C92([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'(@87,@)&L@/3X@)'8I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E="`N/2`B("1K
M/5PB(B`N("1T:&ES+3Y?9FEX6&UL16YC;V1I;F<H)'8I("XG(B<[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@0"1R970@+CT@(B1I
M;F1E;G0@("`\+V9I;&4^7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M)')E="`N/2`B)&EN9&5N="`@/"]F:6QE;&ES=#Y<;B([#0H@("`@("`@('T-
M"B`@("`@("`@)')E="`N/2`B)&EN9&5N="`\+W)E;&5A<V4^7&XB.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@87)R87D-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(')E8W5R<VEV95AM;$9I;&5L:7-T*"1L:7-T*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]D:7)S(#T@87)R87DH*3L-"B`@("`@
M("`@9F]R96%C:"`H)&QI<W0@87,@)&9I;&4@/3X@)&%T=')I8G5T97,I('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?861D1&ER*"1T:&ES+3Y?9&ER<RP@97AP
M;&]D92@G+R<L(&1I<FYA;64H)&9I;&4I*2P@)&9I;&4L("1A='1R:6)U=&5S
M*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]F;W)M871$
M:7(H)'1H:7,M/E]D:7)S*3L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!`
M<&%R86T@87)R87D-"B`@("`@*B!`<&%R86T@87)R87D-"B`@("`@*B!`<&%R
M86T@<W1R:6YG?&YU;&P-"B`@("`@*B!`<&%R86T@87)R87E\;G5L;`T*("`@
M("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T:6]N(%]A
M9&1$:7(H)B1D:7)S+"`D9&ER+"`D9FEL92`](&YU;&PL("1A='1R:6)U=&5S
M(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D9&ER(#T](&%R<F%Y*"D@
M?'P@)&1I<B`]/2!A<G)A>2@G+B<I*2![#0H@("`@("`@("`@("`D9&ER<ULG
M9FEL97,G75MB87-E;F%M92@D9FEL92E=(#T@)&%T=')I8G5T97,[#0H@("`@
M("`@("`@("!R971U<FX[#0H@("`@("`@('T-"B`@("`@("`@)&-U<F1I<B`]
M(&%R<F%Y7W-H:69T*"1D:7(I.PT*("`@("`@("!I9B`H(6ES<V5T*"1D:7)S
M6R=D:7)S)UU;)&-U<F1I<ETI*2![#0H@("`@("`@("`@("`D9&ER<ULG9&ER
M<R==6R1C=7)D:7)=(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^7V%D9$1I<B@D9&ER<ULG9&ER<R==6R1C=7)D:7)=+"`D9&ER+"`D
M9FEL92P@)&%T=')I8G5T97,I.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`
M<&%R86T@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@7V9O<FUA=$1I<B@D9&ER<RP@)&EN9&5N="`]("<G
M+"`D8W5R9&ER(#T@)R<I#0H@("`@>PT*("`@("`@("`D<F5T(#T@)R<[#0H@
M("`@("`@(&EF("@A8V]U;G0H)&1I<G,I*2![#0H@("`@("`@("`@("!R971U
M<FX@)R<[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D:7)S6R=D
M:7)S)UTI*2![#0H@("`@("`@("`@("!U:W-O<G0H)&1I<G-;)V1I<G,G72P@
M)W-T<FYA=&-A<V5C;7`G*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D:7)S
M6R=D:7)S)UT@87,@)&1I<B`]/B`D8V]N=&5N=',I('L-"B`@("`@("`@("`@
M("`@("`D=7-E9&ER(#T@(B1C=7)D:7(O)&1I<B([#0H@("`@("`@("`@("`@
M("`@)')E="`N/2`B)&EN9&5N="`@(#QD:7(@;F%M93U<(B1D:7)<(CY<;B([
M#0H@("`@("`@("`@("`@("`@)')E="`N/2`D=&AI<RT^7V9O<FUA=$1I<B@D
M8V]N=&5N=',L("(D:6YD96YT("(L("1U<V5D:7(I.PT*("`@("`@("`@("`@
M("`@("1R970@+CT@(B1I;F1E;G0@("`\+V1I<CX@/"$M+2`D=7-E9&ER("TM
M/EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M:7-S970H)&1I<G-;)V9I;&5S)UTI*2![#0H@("`@("`@("`@("!U:W-O<G0H
M)&1I<G-;)V9I;&5S)UTL("=S=')N871C87-E8VUP)RD[#0H@("`@("`@("`@
M("!F;W)E86-H("@D9&ER<ULG9FEL97,G72!A<R`D9FEL92`]/B`D871T<FEB
M<RD@>PT*("`@("`@("`@("`@("`@("1R970@+CT@)'1H:7,M/E]F;W)M871&
M:6QE*"1F:6QE+"`D871T<FEB<RP@)&EN9&5N="D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M('-T<FEN9PT*("`@("`J($!P87)A;2!A
M<G)A>0T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B!`86-C97-S('!R
M:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9F]R;6%T1FEL92@D9FEL
M92P@)&%T=')I8G5T97,L("1I;F1E;G0I#0H@("`@>PT*("`@("`@("`D<F5T
M(#T@(B1I;F1E;G0@("`\9FEL92!R;VQE/5PB)&%T=')I8G5T97-;<F]L95U<
M(B([#0H@("`@("`@(&EF("AI<W-E="@D871T<FEB=71E<ULG8F%S96EN<W1A
M;&QD:7(G72DI('L-"B`@("`@("`@("`@("1R970@+CT@)R!B87-E:6YS=&%L
M;&1I<CTB)R`N#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F:7A8;6Q%;F-O
M9&EN9R@D871T<FEB=71E<ULG8F%S96EN<W1A;&QD:7(G72D@+B`G(B<[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1A='1R:6)U=&5S6R=M9#5S
M=6TG72DI('L-"B`@("`@("`@("`@("1R970@+CT@(B!M9#5S=6T]7"(D871T
M<FEB=71E<UMM9#5S=6U=7"(B.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D871T<FEB=71E<ULG<&QA=&9O<FTG72DI('L-"B`@("`@("`@("`@
M("1R970@+CT@(B!P;&%T9F]R;3U<(B1A='1R:6)U=&5S6W!L871F;W)M75PB
M(CL-"B`@("`@("`@?0T*("`@("`@("!I9B`H(65M<'1Y*"1A='1R:6)U=&5S
M6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D<F5T("X]("<@:6YS
M=&%L;"UA<STB)R`N#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]F:7A8;6Q%
M;F-O9&EN9R@D871T<FEB=71E<ULG:6YS=&%L;"UA<R==*2`N("<B)SL-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T("X]("<@;F%M93TB)R`N("1T:&ES+3Y?
M9FEX6&UL16YC;V1I;F<H)&9I;&4I("X@)R(G.PT*("`@("`@("!I9B`H96UP
M='DH)&%T=')I8G5T97-;)W)E<&QA8V5M96YT<R==*2D@>PT*("`@("`@("`@
M("`@)')E="`N/2`B+SY<;B([#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D<F5T("X]("(^7&XB.PT*("`@("`@("`@("`@9F]R96%C:"`H)&%T
M=')I8G5T97-;)W)E<&QA8V5M96YT<R==(&%S("1R*2![#0H@("`@("`@("`@
M("`@("`@)')E="`N/2`B)&EN9&5N="`@("`\<F5P;&%C92([#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)'(@87,@)&L@/3X@)'8I('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E="`N/2`B("1K/5PB(B`N("1T:&ES+3Y?9FEX6&UL
M16YC;V1I;F<H)'8I("XG(B<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1R970@+CT@(B\^7&XB.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)')E="`N/2`B)&EN9&5N="`@(#PO9FEL93Y<;B([#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@+R\@
M>WM[(%]U;DEN9&5N="@I#0H-"B`@("`O*BH-"B`@("`@*B!5;FEN9&5N="!G
M:79E;B!S=')I;F<@*#\I#0H@("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S='(@5&AE('-T<FEN9R!T:&%T(&AA<R!T;R!B92!U;FEN9&5N=&5D+@T*
M("`@("`J($!R971U<FX@<W1R:6YG#0H@("`@("H@0&%C8V5S<R!P<FEV871E
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7W5N26YD96YT*"1S='(I#0H@("`@
M>PT*("`@("`@("`O+R!R96UO=F4@;&5A9&EN9R!N97=L:6YE<PT*("`@("`@
M("`D<W1R(#T@<')E9U]R97!L86-E*"<O7EM<<EQN72LO)RP@)R<L("1S='(I
M.PT*("`@("`@("`O+R!F:6YD('=H:71E<W!A8V4@870@=&AE(&)E9VEN;FEN
M9R!O9B!T:&4@9FER<W0@;&EN90T*("`@("`@("`D:6YD96YT7VQE;B`]('-T
M<G-P;B@D<W1R+"`B(%QT(BD[#0H@("`@("`@("1I;F1E;G0@/2!S=6)S='(H
M)'-T<BP@,"P@)&EN9&5N=%]L96XI.PT*("`@("`@("`D9&%T82`]("<G.PT*
M("`@("`@("`O+R!R96UO=F4@=&AE('-A;64@86UO=6YT(&]F('=H:71E<W!A
M8V4@9G)O;2!F;VQL;W=I;F<@;&EN97,-"B`@("`@("`@9F]R96%C:"`H97AP
M;&]D92@B7&XB+"`D<W1R*2!A<R`D;&EN92D@>PT*("`@("`@("`@("`@:68@
M*'-U8G-T<B@D;&EN92P@,"P@)&EN9&5N=%]L96XI(#T]("1I;F1E;G0I('L-
M"B`@("`@("`@("`@("`@("`D9&%T82`N/2!S=6)S='(H)&QI;F4L("1I;F1E
M;G1?;&5N*2`N(")<;B([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1D871A.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J
M($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D97!E;F1E
M;F-I97-4;U8R*"D-"B`@("![#0H@("`@("`@("1A<G(@/2!A<G)A>2@I.PT*
M("`@("`@("`D=&AI<RT^7V-O;G9E<G1$97!E;F1E;F-I97,R7S`H)&%R<BD[
M#0H@("`@("`@(')E='5R;B`D87)R6R=D97!E;F1E;F-I97,G73L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!#;VYV97)T(&$@<&%C:V%G92YX;6P@=F5R
M<VEO;B`Q+C`@:6YT;R!V97)S:6]N(#(N,`T*("`@("`J#0H@("`@("H@3F]T
M92!T:&%T('1H:7,@9&]E<R!A(&)A<VEC(&-O;G9E<G-I;VXL('1O(&%L;&]W
M(&UO<F4@861V86YC960-"B`@("`@*B!F96%T=7)E<R!L:6ME(&)U;F1L97,@
M86YD(&UU;'1I<&QE(')E;&5A<V5S#0H@("`@("H@0'!A<F%M('-T<FEN9R!T
M:&4@8VQA<W-N86UE('1O(&EN<W1A;G1I871E(&%N9"!R971U<FXN("!4:&ES
M(&UU<W0@8F4-"B`@("`@*B`@("`@("`@("`@("`@(%!%05)?4&%C:V%G949I
M;&5?=C(@;W(@82!D97-C96YD86YT#0H@("`@("H@0'!A<F%M(&)O;VQE86X@
M:68@=')U92P@;VYL>2!V86QI9"P@9&5T97)M:6YI<W1I8R!P86-K86=E+GAM
M;"`Q+C`@87,@9&5F:6YE9"!B>2!T:&4-"B`@("`@*B`@("`@("`@("`@("`@
M("!S=')I8W1E<W0@<&%R86UE=&5R<R!W:6QL(&)E(&-O;G9E<G1E9`T*("`@
M("`J($!R971U<FX@4$5!4E]086-K86=E1FEL95]V,GQ014%27T5R<F]R#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)G1O5C(H)&-L87-S(#T@)U!%05)?4&%C
M:V%G949I;&5?=C(G+"`D<W1R:6-T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@
M("!I9B`H)'-T<FEC="D@>PT*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!A
M8VMA9V5F:6QE+3YV86QI9&%T92@I*2![#0H@("`@("`@("`@("`@("`@)&$@
M/2!014%2.CIR86ES945R<F]R*"=I;G9A;&ED('!A8VMA9V4N>&UL('9E<G-I
M;VX@,2XP(&-A;FYO="!B92!C;VYV97)T960G("X-"B`@("`@("`@("`@("`@
M("`@("`@)R!T;R!V97)S:6]N(#(N,"<L(&YU;&PL(&YU;&PL(&YU;&PL#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=%9A
M;&ED871I;VY787)N:6YG<RAT<G5E*2D[#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1A.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1A
M<G(@/2!A<G)A>2@-"B`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("<R
M+C`G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G>&UL;G,G(#T^
M("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=X;6QN<SIT87-K<R<@/3X@)VAT
M='`Z+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,"<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=X;6QN<SIX<VDG(#T^("=H='1P.B\O=W=W
M+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=X<VDZ<V-H96UA3&]C871I;VXG(#T^(")H
M='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]T87-K<RTQ+C!<;B(@+@T*(FAT='`Z
M+R]P96%R+G!H<"YN970O9'1D+W1A<VMS+3$N,"YX<V1<;B(@+@T*(FAT='`Z
M+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,BXP7&XB("X-"B=H='1P.B\O
M<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3(N,"YX<V0G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`G;F%M92<@/3X@)'1H
M:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G92@I+`T*("`@("`@("`@("`@
M)V-H86YN96PG(#T^("=P96%R+G!H<"YN970G+`T*("`@("`@("`I.PT*("`@
M("`@("`D87)R6R=S=6UM87)Y)UT@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG
M9713=6UM87)Y*"D[#0H@("`@("`@("1A<G);)V1E<V-R:7!T:6]N)UT@/2`D
M=&AI<RT^7W!A8VMA9V5F:6QE+3YG971$97-C<FEP=&EO;B@I.PT*("`@("`@
M("`D;6%I;G1A:6YE<G,@/2`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971-86EN
M=&%I;F5R<R@I.PT*("`@("`@("!F;W)E86-H("@D;6%I;G1A:6YE<G,@87,@
M)&UA:6YT86EN97(I('L-"B`@("`@("`@("`@(&EF("@D;6%I;G1A:6YE<ELG
M<F]L92==("$]("=L96%D)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&YE=R`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;6%I;G1A:6YE<ELG;F%M92==
M+`T*("`@("`@("`@("`@("`@("=U<V5R)R`]/B`D;6%I;G1A:6YE<ELG:&%N
M9&QE)UTL#0H@("`@("`@("`@("`@("`@)V5M86EL)R`]/B`D;6%I;G1A:6YE
M<ELG96UA:6PG72P-"B`@("`@("`@("`@("`@("`G86-T:79E)R`]/B`G>65S
M)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("`@("`D87)R6R=L96%D)UU;
M72`]("1N97<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<W-E="@D87)R
M6R=L96%D)UTI*2![("\O('-O;64@<&5O<&QE+BXN('EO=2!K;F]W/PT*("`@
M("`@("`@("`@)&%R<ELG;&5A9"==(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@)VYA;64G(#T^("=U;FMN;W=N)RP-"B`@("`@("`@("`@("`@("`G=7-E
M<B<@/3X@)W5N:VYO=VXG+`T*("`@("`@("`@("`@("`@("=E;6%I;"<@/3X@
M)VYO;&5A9&UA:6YT86EN97)`97AA;7!L92YC;VTG+`T*("`@("`@("`@("`@
M("`@("=A8W1I=F4G(#T^("=N;R<L#0H@("`@("`@("`@("`I.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AC;W5N="@D87)R6R=L96%D)UTI(#T](#$I('L-
M"B`@("`@("`@("`@("1A<G);)VQE860G72`]("1A<G);)VQE860G75LP73L-
M"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D;6%I;G1A:6YE<G,@87,@
M)&UA:6YT86EN97(I('L-"B`@("`@("`@("`@(&EF("@D;6%I;G1A:6YE<ELG
M<F]L92==(#T]("=L96%D)RD@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&YE=R`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=N86UE)R`]/B`D;6%I;G1A:6YE<ELG;F%M92==
M+`T*("`@("`@("`@("`@("`@("=U<V5R)R`]/B`D;6%I;G1A:6YE<ELG:&%N
M9&QE)UTL#0H@("`@("`@("`@("`@("`@)V5M86EL)R`]/B`D;6%I;G1A:6YE
M<ELG96UA:6PG72P-"B`@("`@("`@("`@("`@("`G86-T:79E)R`]/B`G>65S
M)RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("`@("`D87)R6R1M86EN=&%I
M;F5R6R=R;VQE)UU=6UT@/2`D;F5W.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AI<W-E="@D87)R6R=D979E;&]P97(G72D@)B8@8V]U;G0H)&%R<ELG9&5V
M96QO<&5R)UTI(#T](#$I('L-"B`@("`@("`@("`@("1A<G);)V1E=F5L;W!E
M<B==(#T@)&%R<ELG9&5V96QO<&5R)UU;,%T[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*&ES<V5T*"1A<G);)V-O;G1R:6)U=&]R)UTI("8F(&-O=6YT*"1A
M<G);)V-O;G1R:6)U=&]R)UTI(#T](#$I('L-"B`@("`@("`@("`@("1A<G);
M)V-O;G1R:6)U=&]R)UT@/2`D87)R6R=C;VYT<FEB=71O<B==6S!=.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D87)R6R=H96QP97(G72D@)B8@
M8V]U;G0H)&%R<ELG:&5L<&5R)UTI(#T](#$I('L-"B`@("`@("`@("`@("1A
M<G);)VAE;'!E<B==(#T@)&%R<ELG:&5L<&5R)UU;,%T[#0H@("`@("`@('T-
M"B`@("`@("`@)&%R<ELG9&%T92==(#T@)'1H:7,M/E]P86-K86=E9FEL92T^
M9V5T1&%T92@I.PT*("`@("`@("`D87)R6R=V97)S:6]N)UT@/0T*("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)W)E;&5A<V4G(#T^("1T
M:&ES+3Y?<&%C:V%G969I;&4M/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@
M("`@("`G87!I)R`]/B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971697)S:6]N
M*"DL#0H@("`@("`@("`@("`I.PT*("`@("`@("`D87)R6R=S=&%B:6QI='DG
M72`]#0H@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`G<F5L
M96%S92<@/3X@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4W1A=&4H*2P-"B`@
M("`@("`@("`@("`@("`G87!I)R`]/B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG
M9713=&%T92@I+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@)&QI8V5N<V5M
M87`@/0T*("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@)W!H
M<"<@/3X@)VAT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E)RP-"B`@("`@("`@
M("`@("`@("`G<&AP(&QI8V5N<V4G(#T^("=H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92<L#0H@("`@("`@("`@("`@("`@)VQG<&PG(#T^("=H='1P.B\O
M=W=W+F=N=2YO<F<O8V]P>6QE9G0O;&5S<V5R+FAT;6PG+`T*("`@("`@("`@
M("`@("`@("=B<V0G(#T^("=H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"<L#0H@("`@("`@("`@("`@("`@)V)S
M9"!S='EL92<@/3X@)VAT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP)RP-"B`@("`@("`@("`@("`@("`G8G-D+7-T
M>6QE)R`]/B`G:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B
M<V0M;&EC96YS92YP:'`G+`T*("`@("`@("`@("`@("`@("=M:70G(#T^("=H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+VUI="UL:6-E;G-E
M+G!H<"<L#0H@("`@("`@("`@("`@("`@)V=P;"<@/3X@)VAT='`Z+R]W=W<N
M9VYU+F]R9R]C;W!Y;&5F="]G<&PN:'1M;"<L#0H@("`@("`@("`@("`@("`@
M)V%P86-H92<@/3X@)VAT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O87!A8VAE,BXP+G!H<"<-"B`@("`@("`@("`@("D[#0H@("`@("`@(&EF
M("AI<W-E="@D;&EC96YS96UA<%MS=')T;VQO=V5R*"1T:&ES+3Y?<&%C:V%G
M969I;&4M/F=E=$QI8V5N<V4H*2E=*2D@>PT*("`@("`@("`@("`@)&%R<ELG
M;&EC96YS92==(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)V%T=')I8G,G
M(#T^(&%R<F%Y*"=U<FDG(#T^#0H@("`@("`@("`@("`@("`@("`@("1L:6-E
M;G-E;6%P6W-T<G1O;&]W97(H)'1H:7,M/E]P86-K86=E9FEL92T^9V5T3&EC
M96YS92@I*5TI+`T*("`@("`@("`@("`@("`@("=?8V]N=&5N="<@/3X@)'1H
M:7,M/E]P86-K86=E9FEL92T^9V5T3&EC96YS92@I#0H@("`@("`@("`@("`@
M("`@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O(&1O;B=T
M('5S92!B;V=U<R!U<FD-"B`@("`@("`@("`@("1A<G);)VQI8V5N<V4G72`]
M("1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@
M?0T*("`@("`@("`D87)R6R=N;W1E<R==(#T@)'1H:7,M/E]P86-K86=E9FEL
M92T^9V5T3F]T97,H*3L-"B`@("`@("`@)'1E;7`@/2!A<G)A>2@I.PT*("`@
M("`@("`D87)R6R=C;VYT96YT<R==(#T@)'1H:7,M/E]C;VYV97)T1FEL96QI
M<W0R7S`H)'1E;7`I.PT*("`@("`@("`D=&AI<RT^7V-O;G9E<G1$97!E;F1E
M;F-I97,R7S`H)&%R<BD[#0H@("`@("`@("1R96QE87-E(#T@*"1T:&ES+3Y?
M<&%C:V%G969I;&4M/F=E=$-O;F9I9W5R94]P=&EO;G,H*2!\?"`D=&AI<RT^
M7VES17AT96YS:6]N*2`_#0H@("`@("`@("`@("`G97AT<W)C<F5L96%S92<@
M.B`G<&AP<F5L96%S92<[#0H@("`@("`@(&EF("@D<F5L96%S92`]/2`G97AT
M<W)C<F5L96%S92<I('L-"B`@("`@("`@("`@("1A<G);)V-H86YN96PG72`]
M("=P96-L+G!H<"YN970G.PT*("`@("`@("`@("`@)&%R<ELG<')O=FED97-E
M>'1E;G-I;VXG72`]("1A<G);)VYA;64G73L@+R\@87-S=6UP=&EO;@T*("`@
M("`@("!]#0H@("`@("`@("1A<G);)')E;&5A<V5=(#T@87)R87DH*3L-"B`@
M("`@("`@:68@*"1T:&ES+3Y?<&%C:V%G969I;&4M/F=E=$-O;F9I9W5R94]P
M=&EO;G,H*2D@>PT*("`@("`@("`@("`@)&%R<ELD<F5L96%S95U;)V-O;F9I
M9W5R96]P=&EO;B==(#T@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T0V]N9FEG
M=7)E3W!T:6]N<R@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)&%R<ELD<F5L
M96%S95U;)V-O;F9I9W5R96]P=&EO;B==(&%S("1I(#T^("1O<'0I('L-"B`@
M("`@("`@("`@("`@("`D87)R6R1R96QE87-E75LG8V]N9FEG=7)E;W!T:6]N
M)UU;)&E=(#T@87)R87DH)V%T=')I8G,G(#T^("1O<'0I.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1A<G);)')E;&5A<V5=6R=C
M;VYF:6=U<F5O<'1I;VXG72D@/3T@,2D@>PT*("`@("`@("`@("`@("`@("1A
M<G);)')E;&5A<V5=6R=C;VYF:6=U<F5O<'1I;VXG72`]("1A<G);)')E;&5A
M<V5=6R=C;VYF:6=U<F5O<'1I;VXG75LP73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D=&AI<RT^7V-O;G9E<G1296QE87-E,E\P*"1A
M<G);)')E;&5A<V5=+"`D=&5M<"D[#0H@("`@("`@(&EF("@D<F5L96%S92`]
M/2`G97AT<W)C<F5L96%S92<@)B8@8V]U;G0H)&%R<ELD<F5L96%S95TI(#X@
M,2D@>PT*("`@("`@("`@("`@+R\@;75L=&EP;&4@97AT<W)C<F5L96%S92!T
M86=S(&%D9&5D(&EN(%!%05(@,2XT+C$-"B`@("`@("`@("`@("1A<G);)V1E
M<&5N9&5N8VEE<R==6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;)VUI
M;B==(#T@)S$N-"XQ)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-L(#T@
M)'1H:7,M/E]P86-K86=E9FEL92T^9V5T0VAA;F=E;&]G*"DI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1C;"!A<R`D<F5L96%S92D@>PT*("`@("`@("`@
M("`@("`@("1R96P@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1R96Q;
M)W9E<G-I;VXG72`]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)W)E;&5A<V4G(#T^("1R96QE87-E6R=V
M97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`G87!I)R`]/B`D
M<F5L96%S95LG=F5R<VEO;B==+`T*("`@("`@("`@("`@("`@("`@("`I.PT*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)')E;&5A<V5;)W)E;&5A<V5?
M<W1A=&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)W)E
M;&5A<V5?<W1A=&4G72`]("=S=&%B;&4G.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<F5L6R=S=&%B:6QI='DG72`]#0H@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)W)E;&5A<V4G(#T^("1R96QE87-E6R=R96QE87-E7W-T871E)UTL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G87!I)R`]/B`D<F5L96%S95LG<F5L96%S
M95]S=&%T92==+`T*("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<F5L96%S95LG<F5L96%S95]D871E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R96Q;)V1A=&4G72`]("1R96QE87-E
M6R=R96QE87-E7V1A=&4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D<F5L6R=D871E)UT@/2!D871E*"=9+6TM
M9"<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)')E;&5A<V5;)W)E;&5A<V5?;&EC96YS92==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&QI8V5N<V5M87!;<W1R=&]L;W=E
M<B@D<F5L96%S95LG<F5L96%S95]L:6-E;G-E)UTI72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1U<FD@/2`D;&EC96YS96UA<%MS=')T;VQO=V5R
M*"1R96QE87-E6R=R96QE87-E7VQI8V5N<V4G72E=.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5R
M:2`]("=H='1P.B\O=W=W+F5X86UP;&4N8V]M)SL-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D<F5L6R=L:6-E;G-E)UT@
M/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB
M<R<@/3X@87)R87DH)W5R:2<@/3X@)'5R:2DL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U]C;VYT96YT)R`]/B`D<F5L96%S95LG<F5L96%S95]L
M:6-E;G-E)UT-"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)')E;%LG
M;&EC96YS92==(#T@)&%R<ELG;&EC96YS92==.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E6R=R96QE
M87-E7VYO=&5S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M6R=R96QE87-E7VYO=&5S)UT@/2`G;F\@<F5L96%S92!N;W1E<R<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1R96Q;)VYO=&5S)UT@
M/2`D<F5L96%S95LG<F5L96%S95]N;W1E<R==.PT*("`@("`@("`@("`@("`@
M("1A<G);)V-H86YG96QO9R==6R=R96QE87-E)UU;72`]("1R96P[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)')E="`](&YE=R`D8VQA
M<W,[#0H@("`@("`@("1R970M/G-E=$-O;F9I9R@D=&AI<RT^7W!A8VMA9V5F
M:6QE+3Y?8V]N9FEG*3L-"B`@("`@("`@)')E="T^<V5T3&]G9V5R*"1T:&ES
M+3Y?<&%C:V%G969I;&4M/E]L;V=G97(I.PT*("`@("`@("`D<F5T+3YF<F]M
M07)R87DH)&%R<BD[#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!B
M;V]L#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@7V-O;G9E<G1$97!E;F1E;F-I97,R7S`H)B1R96QE87-E+"`D:6YT
M97)N86P@/2!F86QS92D-"B`@("![#0H@("`@("`@("1P96%R9&5P(#T@87)R
M87DH)W!E87)I;G-T86QL97(G(#T^#0H@("`@("`@("`@("!A<G)A>2@G;6EN
M)R`]/B`G,2XT+C!B,2<I*3L@+R\@=&AI<R!I<R!A(&QO="!S869E<@T*("`@
M("`@("`D<F5Q=6ER960@/2`D;W!T:6]N86P@/2!A<G)A>2@I.PT*("`@("`@
M("`D<F5L96%S95LG9&5P96YD96YC:65S)UT@/2!A<G)A>2@I.PT*("`@("`@
M("!I9B`H)'1H:7,M/E]P86-K86=E9FEL92T^:&%S1&5P<R@I*2![#0H@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971$97!S
M*"D@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E
M<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T:6]N86PG72`]/2`G;F\G*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R97%U:7)E9%M=(#T@)&1E<#L-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M;W!T:6]N86Q;72`]("1D97`[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H87)R87DH)W)E<75I<F5D
M)RP@)V]P=&EO;F%L)RD@87,@)&%R<BD@>PT*("`@("`@("`@("`@("`@("1D
M97!S(#T@87)R87DH*3L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D)&%R
M<B!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@("`@("\O(&]R9V%N:7IE
M(&1E<',@8GD@9&5P96YD96YC>2!T>7!E(&%N9"!N86UE#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)&1E<%LG='EP92==72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R1D97!;)W1Y<&4G75T@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=N86UE)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5P<ULD9&5P6R=T>7!E)UU=6R1D97!;)VYA
M;64G75U;72`]("1D97`[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<ULD9&5P6R=T>7!E)UU=
M6UT@/2`D9&5P.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&1O('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!S6R=P:'`G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P:'`@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&-O=6YT*"1D97!S6R=P:'`G72D@/B`Q*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!H<"`]("1T:&ES+3Y?<')O8V5S
M<U!H<$1E<',H)&1E<'-;)W!H<"==*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D9&5P<ULG<&AP)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&QI<W0H)&ME>2P@)&)L86@I(#T@96%C:"`H)&1E
M<'-;)W!H<"==*3L@+R\@<W1U<&ED(&)U9V=Y('9E<G-I;VYS#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R=P:'`G72`](&%R<F%Y
M*"1B;&%H6S!=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<"`]("1T:&ES+3Y?<')O
M8V5S<T1E<"@D9&5P<ULG<&AP)UU;,%TI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A)'!H<"D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL@+R\@<&]O<B!M86YS('1H<F]W#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)V1E<&5N
M9&5N8VEE<R==6R1A<G)=6R=P:'`G72`]("1P:'`[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]('=H:6QE("AF86QS92D[#0H@
M("`@("`@("`@("`@("`@9&\@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<'-;)W!K9R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'!K9R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&MG(#T@)'1H:7,M/E]P<F]C97-S375L=&EP;&5$97!S3F%M92@D9&5P<ULG
M<&MG)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"$D<&MG*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[("\O('!O;W(@
M;6%N<R!T:')O=PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==6R1A
M<G)=6R=P86-K86=E)UT@/2`D<&MG.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?2!W:&EL92`H9F%L<V4I.PT*("`@("`@("`@
M("`@("`@(&1O('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!S6R=E>'0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P:V<@
M/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!K9R`]("1T
M:&ES+3Y?<')O8V5S<TUU;'1I<&QE1&5P<TYA;64H)&1E<'-;)V5X="==*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R=D97!E;F1E;F-I
M97,G75LD87)R75LG97AT96YS:6]N)UT@/2`D<&MG.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!W:&EL92`H9F%L<V4I.PT*
M("`@("`@("`@("`@("`@("\O('-K:7`@<V%P:2`M(&ET)W,@;F]T('-U<'!O
M<G1E9"!S;R!N;V)O9'D@=VEL;"!H879E('5S960@:70-"B`@("`@("`@("`@
M("`@("`O+R!S:VEP(&]S("T@:70G<R!N;W0@<W5P<&]R=&5D(&EN(#$N,`T*
M("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D
M<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UTI*2![#0H@("`@
M("`@("`@("`D<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UT@
M/0T*("`@("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1P96%R9&5P+"`D<F5L
M96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UTI.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@)')E;&5A<V5;)V1E<&5N9&5N8VEE<R==
M6R=R97%U:7)E9"==(#T@)'!E87)D97`[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"%I<W-E="@D<F5L96%S95LG9&5P96YD96YC:65S)UU;)W)E<75I<F5D
M)UU;)W!H<"==*2D@>PT*("`@("`@("`@("`@)')E;&5A<V5;)V1E<&5N9&5N
M8VEE<R==6R=R97%U:7)E9"==6R=P:'`G72`]#0H@("`@("`@("`@("`@("`@
M87)R87DH)VUI;B<@/3X@)S0N,"XP)RD[#0H@("`@("`@('T-"B`@("`@("`@
M)&]R9&5R(#T@87)R87DH*3L-"B`@("`@("`@)&)E=VT@/2`D<F5L96%S95LG
M9&5P96YD96YC:65S)UU;)W)E<75I<F5D)UT[#0H@("`@("`@("1O<F1E<ELG
M<&AP)UT@/2`D8F5W;5LG<&AP)UT[#0H@("`@("`@("1O<F1E<ELG<&5A<FEN
M<W1A;&QE<B==(#T@)&)E=VU;)W!E87)I;G-T86QL97(G73L-"B`@("`@("`@
M:7-S970H)&)E=VU;)W!A8VMA9V4G72D@/R`D;W)D97);)W!A8VMA9V4G72`]
M("1B97=M6R=P86-K86=E)UT@.C`[#0H@("`@("`@(&ES<V5T*"1B97=M6R=E
M>'1E;G-I;VXG72D@/R`D;W)D97);)V5X=&5N<VEO;B==(#T@)&)E=VU;)V5X
M=&5N<VEO;B==(#HP.PT*("`@("`@("`D<F5L96%S95LG9&5P96YD96YC:65S
M)UU;)W)E<75I<F5D)UT@/2`D;W)D97([#0H@("`@?0T*#0H@("`@+RHJ#0H@
M("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1&:6QE;&ES=#)?,"@F)'!A
M8VMA9V4I#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH)V1I<B<@/3X-
M"B`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G871T<FEB<R<@/3X@87)R87DH)VYA;64G(#T^("<O)RDL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G9FEL92<@/3X@87)R87DH*0T*("`@
M("`@("`@("`@("`@("`@("`@("`@*0T*("`@("`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`D<&%C:V%G95LG<&QA=&9O<FTG72`]#0H@("`@("`@("1P
M86-K86=E6R=I;G-T86QL+6%S)UT@/2!A<G)A>2@I.PT*("`@("`@("`D=&AI
M<RT^7VES17AT96YS:6]N(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1T
M:&ES+3Y?<&%C:V%G969I;&4M/F=E=$9I;&5L:7-T*"D@87,@)&YA;64@/3X@
M)&9I;&4I('L-"B`@("`@("`@("`@("1F:6QE6R=N86UE)UT@/2`D;F%M93L-
M"B`@("`@("`@("`@(&EF("AI<W-E="@D9FEL95LG<F]L92==*2`F)B`D9FEL
M95LG<F]L92==(#T]("=S<F,G*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]I<T5X=&5N<VEO;B`]('1R=64[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&9I;&5;)W)E<&QA8V5M96YT<R==*2D@>PT*("`@
M("`@("`@("`@("`@("1R97!L(#T@)&9I;&5;)W)E<&QA8V5M96YT<R==.PT*
M("`@("`@("`@("`@("`@('5N<V5T*"1F:6QE6R=R97!L86-E;65N=',G72D[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@('5N<V5T
M*"1R97!L*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D9FEL95LG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@("`@("`@("`@("1P
M86-K86=E6R=I;G-T86QL+6%S)UU;)&YA;65=(#T@)&9I;&5;)VEN<W1A;&PM
M87,G73L-"B`@("`@("`@("`@("`@("!U;G-E="@D9FEL95LG:6YS=&%L;"UA
M<R==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M9FEL95LG<&QA=&9O<FTG72DI('L-"B`@("`@("`@("`@("`@("`D<&%C:V%G
M95LG<&QA=&9O<FTG75LD;F%M95T@/2`D9FEL95LG<&QA=&9O<FTG73L-"B`@
M("`@("`@("`@("`@("!U;G-E="@D9FEL95LG<&QA=&9O<FTG72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D9FEL92`](&%R<F%Y*"=A='1R:6)S
M)R`]/B`D9FEL92D[#0H@("`@("`@("`@("!I9B`H:7-S970H)')E<&PI*2![
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E<&P@87,@)')E<&QA8V4@
M*2![#0H@("`@("`@("`@("`@("`@("`@("1F:6QE6R=T87-K<SIR97!L86-E
M)UU;72`](&%R<F%Y*"=A='1R:6)S)R`]/B`D<F5P;&%C92D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5P;"D@
M/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`D9FEL95LG=&%S:W,Z<F5P
M;&%C92==(#T@)&9I;&5;)W1A<VMS.G)E<&QA8V4G75LP73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<F5T6R=D
M:7(G75LG9FEL92==6UT@/2`D9FEL93L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!0;W-T+7!R
M;V-E<W,@<W!E8VEA;"!F:6QE<R!W:71H(&EN<W1A;&PM87,O<&QA=&9O<FT@
M871T<FEB=71E<R!A;F0-"B`@("`@*B!M86ME('1H92!R96QE87-E('1A9RX-
M"B`@("`@*B`-"B`@("`@*B!4:&ES(&-O;7!L97@@;65T:&]D(&9O;&QO=W,@
M=&AI<R!W;W)K+69L;W<@=&\@8W)E871E('1H92!R96QE87-E('1A9W,Z#0H@
M("`@("H@#0H@("`@("H@/'!R93X-"B`@("`@*B`M(&EF(&%N>2!I;G-T86QL
M+6%S+W!L871F;W)M(&5X:7-T+"!C<F5A=&4@82!G96YE<FEC(')E;&5A<V4@
M86YD(&9I;&P@:70@=VET:`T*("`@("`J("`@;R`\:6YS=&%L;"!A<STN+CX@
M=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA<STN+BX^#0H@("`@
M("H@("!O(#QI;G-T86QL(&%S/2XN/B!T86=S(&9O<B`\9FEL92!N86UE/2XN
M+B!P;&%T9F]R;3TA+BXN(&EN<W1A;&PM87,]+BX^#0H@("`@("H@("!O(#QI
M9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M/2XN+CX-
M"B`@("`@*B`@(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@
M<&QA=&9O<FT]+BXN(&EN<W1A;&PM87,]+BX^#0H@("`@("H@+2!C<F5A=&4@
M82!R96QE87-E(&9O<B!E86-H('!L871F;W)M(&5N8V]U;G1E<F5D(&%N9"!F
M:6QL('=I=&@-"B`@("`@*B`@(&\@/&EN<W1A;&P@87,N+CX@=&%G<R!F;W(@
M/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA<STN+BX^#0H@("`@("H@("!O(#QI
M;G-T86QL(&%S+BX^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M
M/71H:7,@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@*B`@(&\@/&EN
M<W1A;&P@87,N+CX@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT]
M(6]T:&5R('!L871F;W)M(&EN<W1A;&PM87,]+BX^#0H@("`@("H@("!O(#QI
M9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F;W)M/2%T:&ES
M('!L871F;W)M/@T*("`@("`J("`@;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL
M92!N86UE/2XN+B!P;&%T9F]R;3UO=&AE<B!P;&%T9F]R;3X-"B`@("`@*B`@
M(&\@/&EG;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT]
M;W1H97(@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@*B`@(&\@/&EG
M;F]R93X@=&%G<R!F;W(@/&9I;&4@;F%M93TN+BX@<&QA=&9O<FT](71H:7,@
M<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@*B`\+W!R93X-"B`@("`@
M*B`-"B`@("`@*B!)="!D;V5S('1H:7,@8GD@86-C97-S:6YG('1H92`D<&%C
M:V%G92!P87)A;65T97(L('=H:6-H(&-O;G1A:6YS(&%N(&%R<F%Y('=I=&@-
M"B`@("`@*B!I;F1I8V5S.@T*("`@("`J(`T*("`@("`J("`M('!L871F;W)M
M.B!M87!P:6YG(&]F(&9I;&4@/3X@3U,@=&AE(&9I;&4@<VAO=6QD(&)E(&EN
M<W1A;&QE9"!O;@T*("`@("`J("`M(&EN<W1A;&PM87,Z(&UA<'!I;F<@;V8@
M9FEL92`]/B!I;G-T86QL960@;F%M90T*("`@("`J("`M(&]S;6%P.B!M87!P
M:6YG(&]F($]3(#T^(&QI<W0@;V8@9FEL97,@=&AA="!S:&]U;&0@8F4@:6YS
M=&%L;&5D#0H@("`@("H@("`@;VX@=&AA="!/4PT*("`@("`J("`M(&YO=&]S
M;6%P.B!M87!P:6YG(&]F($]3(#T^(&QI<W0@;V8@9FEL97,@=&AA="!S:&]U
M;&0@;F]T(&)E#0H@("`@("H@("`@:6YS=&%L;&5D(&]N('1H870@3U,-"B`@
M("`@*@T*("`@("`J($!P87)A;2!A<G)A>0T*("`@("`J($!P87)A;2!A<G)A
M>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%]C;VYV97)T4F5L96%S93)?,"@F)')E;&5A<V4L("1P86-K86=E*0T*
M("`@('L-"B`@("`@("`@+R\M(&EF(&%N>2!I;G-T86QL+6%S+W!L871F;W)M
M(&5X:7-T+"!C<F5A=&4@82!G96YE<FEC(')E;&5A<V4@86YD(&9I;&P@:70@
M=VET:"`-"B`@("`@("`@:68@*&-O=6YT*"1P86-K86=E6R=P;&%T9F]R;2==
M*2!\?"!C;W5N="@D<&%C:V%G95LG:6YS=&%L;"UA<R==*2D@>PT*("`@("`@
M("`@("`@)&=E;F5R:6,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)&=E;F5R
M:6-)9VYO<F4@/2!A<G)A>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)'!A
M8VMA9V5;)VEN<W1A;&PM87,G72!A<R`D9FEL92`]/B`D87,I('L-"B`@("`@
M("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,]+BX^('1A9W,@9F]R(#QF:6QE
M(&YA;64]+BXN(&EN<W1A;&PM87,]+BXN/@T*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D9V5N97)I8UM=(#T@)&9I;&4[#0H@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`O+V\@/&EN<W1A;&P@87,]+BX^('1A9W,@9F]R(#QF
M:6QE(&YA;64]+BXN('!L871F;W)M/2$N+BX@:6YS=&%L;"UA<STN+CX-"B`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W!L871F;W)M)UU;
M)&9I;&5=*2`F)@T*("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P
M;&%T9F]R;2==6R1F:6QE77LP?2`]/2`G(2<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)&=E;F5R:6-;72`]("1F:6QE.PT*("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@+R]O(#QI9VYO<F4^('1A9W,@9F]R(#QF:6QE(&YA;64]+BXN('!L871F
M;W)M/2XN+B!I;G-T86QL+6%S/2XN/@T*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95TI("8F#0H@("`@("`@
M("`@("`@("`@("`@("`@)'!A8VMA9V5;)W!L871F;W)M)UU;)&9I;&5=>S!]
M("$]("<A)RD@>PT*("`@("`@("`@("`@("`@("`@("`D9V5N97)I8TEG;F]R
M95M=(#T@)&9I;&4[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1P86-K86=E6R=P;&%T9F]R;2==(&%S("1F:6QE(#T^("1P
M;&%T9F]R;2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G
M95LG:6YS=&%L;"UA<R==6R1F:6QE72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("@D<&QA=&9O<FU[,'T@(3T@)R$G*2![#0H@("`@("`@("`@("`@
M("`@("`@("\O;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!P
M;&%T9F]R;3TN+BX^#0H@("`@("`@("`@("`@("`@("`@("1G96YE<FEC26=N
M;W)E6UT@/2`D9FEL93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)'!A8VMA9V5;)W!L871F;W)M
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&]S97,@/2`D;F]T<&QA=&9O<FT@
M/2`D<&QA=&9O<FT@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P86-K86=E6R=P;&%T9F]R;2==(&%S("1F:6QE(#T^("1O<RD@>PT*
M("`@("`@("`@("`@("`@("`@("`O+R!G970@82!L:7-T(&]F(&]S97,-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1O<WLP?2`]/2`G(2<I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W-E<UMS=6)S='(H)&]S
M+"`Q*5TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;W-E<UMS=6)S='(H)&]S+"`Q*5T@/2!C;W5N="@D;W-E
M<RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&]S97-;)&]S72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1O<V5S
M6R1O<UT@/2!C;W5N="@D;W-E<RD[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@+R\M(&-R96%T
M92!A(')E;&5A<V4@9F]R(&5A8V@@<&QA=&9O<FT@96YC;W5N=&5R960@86YD
M(&9I;&P@=VET:`T*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O<V5S(&%S
M("1O<R`]/B`D<F5L96%S94YU;2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S95LD<F5L96%S94YU;5U;)VEN<W1A;&QC;VYD:71I;VYS)UU;)V]S
M)UU;)VYA;64G72`]("1O<SL-"B`@("`@("`@("`@("`@("`@("`@)')E;&5A
M<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==(#T@87)R87DH)VEN<W1A;&PG
M(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`G:6=N;W)E
M)R`]/B!A<G)A>2@I*3L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H
M)'!A8VMA9V5;)VEN<W1A;&PM87,G72!A<R`D9FEL92`]/B`D87,I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6YS=&%L;"!A<STN+CX@=&%G
M<R!F;W(@/&9I;&4@;F%M93TN+BX@:6YS=&%L;"UA<STN+BX^#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P86-K86=E6R=P;&%T9F]R
M;2==6R1F:6QE72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T)UU;)VEN<W1A;&PG75M=
M(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=A<R<@/3X@)&%S+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("\O;R`\:6YS=&%L;"!A<RXN/B!T86=S(&9O
M<@T*("`@("`@("`@("`@("`@("`@("`@("`@+R\@(#QF:6QE(&YA;64]+BXN
M('!L871F;W)M/71H:7,@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<&QA=&9O
M<FTG75LD9FEL95TI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95T@/3T@)&]S*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=
M6R=F:6QE;&ES="==6R=I;G-T86QL)UU;72`]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`]/B`D9FEL
M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M87,G(#T^("1A<RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`O
M+V\@/&EN<W1A;&P@87,N+CX@=&%G<R!F;W(-"B`@("`@("`@("`@("`@("`@
M("`@("`@("\O("`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA;W1H97(@<&QA
M=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95TI("8F#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG<&QA=&9O
M<FTG75LD9FEL95T@(3T@(B$D;W,B("8F#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95U[,'T@/3T@
M)R$G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;
M)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I;G-T86QL)UU;72`]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N
M86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G87,G(#T^("1A<RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`O+V\@/&EG;F]R93X@=&%G<R!F;W(-"B`@("`@("`@("`@
M("`@("`@("`@("`@("\O("`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA=&AI
M<R!P;&%T9F]R;2!I;G-T86QL+6%S/2XN/@T*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=P;&%T9F]R;2==6R1F:6QE72D@
M)B8-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P
M;&%T9F]R;2==6R1F:6QE72`]/2`B(21O<R(I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L:7-T
M)UU;)VEG;F]R92==6UT@/0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@+R]O(#QI9VYO<F4^('1A9W,@9F]R
M#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R`@/&9I;&4@;F%M93TN+BX@
M<&QA=&9O<FT];W1H97(@<&QA=&9O<FT@:6YS=&%L;"UA<STN+CX-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<&QA=&9O
M<FTG75LD9FEL95TI("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%C:V%G95LG<&QA=&9O<FTG75LD9FEL95U[,'T@(3T@)R$G("8F#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG<&QA=&9O
M<FTG75LD9FEL95T@(3T@)&]S*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I9VYO
M<F4G75M=(#T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G871T
M<FEB<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)VYA;64G(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<&%C:V%G95LG<&QA=&9O<FTG72!A<R`D9FEL92`]/B`D<&QA=&9O<FTI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M:6YS=&%L;"UA<R==6R1F:6QE72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O;R`\:6=N;W)E/B!T86=S(&9O
M<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3TA=&AI<R!P;&%T9F]R;3X-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<&QA=&9O<FT@/3T@(B$D;W,B
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)')E
M;&5A<V5.=6U=6R=F:6QE;&ES="==6R=I9VYO<F4G75M=(#T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("\O
M;R`\:6=N;W)E/B!T86=S(&9O<B`\9FEL92!N86UE/2XN+B!P;&%T9F]R;3UO
M=&AE<B!P;&%T9F]R;3X-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M<&QA=&9O<FU[,'T@(3T@)R$G("8F("1P;&%T9F]R;2`A/2`D;W,I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LD<F5L96%S94YU
M;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==6UT@/0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=A='1R:6)S)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F%M92<@/3X@)&9I
M;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A8V]U;G0H)')E;&5A<V5;)')E;&5A<V5.
M=6U=6R=F:6QE;&ES="==6R=I;G-T86QL)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D<F5L96%S95LD<F5L96%S94YU;5U;)V9I;&5L
M:7-T)UU;)VEN<W1A;&PG72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%C;W5N="@D<F5L96%S95LD<F5L96%S
M94YU;5U;)V9I;&5L:7-T)UU;)VEG;F]R92==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)')E;&5A<V5;)')E;&5A<V5.=6U=6R=F:6QE
M;&ES="==6R=I9VYO<F4G72D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1G
M96YE<FEC*2!\?"!C;W5N="@D9V5N97)I8TEG;F]R92DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E;&5A<V5;8V]U;G0H)&]S97,I72`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9V5N97)I8RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1G96YE<FEC(&%S
M("1F:6QE*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1P86-K86=E6R=I;G-T86QL+6%S)UU;)&9I;&5=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YS=&%L;&%S(#T@)'!A8VMA
M9V5;)VEN<W1A;&PM87,G75LD9FEL95T[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&EN<W1A;&QA<R`]("1F:6QE.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L
M96%S95MC;W5N="@D;W-E<RE=6R=F:6QE;&ES="==6R=I;G-T86QL)UU;72`]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G,G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=N86UE)R`]/B`D9FEL92P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G87,G(#T^("1I;G-T86QL87,L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*"1G96YE<FEC26=N;W)E*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&=E;F5R:6-)9VYO<F4@87,@)&9I;&4I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5L96%S95MC;W5N
M="@D;W-E<RE=6R=F:6QE;&ES="==6R=I9VYO<F4G75M=(#T-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G871T<FEB<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M(#T^("1F:6QE+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("\O(&-L96%N
M=7`-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<F5L96%S92!A<R`D:2`]
M/B`D<F5L*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<F5L
M6R=F:6QE;&ES="==6R=I;G-T86QL)UTI("8F#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-O=6YT*"1R96Q;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72D@
M/3T@,2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E;&5A<V5;)&E=
M6R=F:6QE;&ES="==6R=I;G-T86QL)UT@/0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R96QE87-E6R1I75LG9FEL96QI<W0G75LG:6YS=&%L;"==
M6S!=.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<F5L6R=F:6QE;&ES="==6R=I9VYO<F4G72D@)B8-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@8V]U;G0H)')E;%LG9FEL96QI
M<W0G75LG:6=N;W)E)UTI(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1R96QE87-E6R1I75LG9FEL96QI<W0G75LG:6=N;W)E)UT@/0T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E6R1I75LG9FEL96QI
M<W0G75LG:6=N;W)E)UU;,%T[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1R
M96QE87-E*2`]/2`Q*2![#0H@("`@("`@("`@("`@("`@("`@("1R96QE87-E
M(#T@)')E;&5A<V5;,%T[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R!N;R!P;&%T9F]R;2!A
M='1S+"!B=70@<V]M92!I;G-T86QL+6%S(&%T=',-"B`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<&%C:V%G95LG:6YS=&%L;"UA<R==(&%S("1F:6QE(#T^
M("1V86QU92D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L96%S95LG9FEL
M96QI<W0G75LG:6YS=&%L;"==6UT@/0T*("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I
M8G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F%M92<@/3X@)&9I;&4L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=A<R<@/3X@)'9A;'5E#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*0T*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1R96QE87-E
M6R=F:6QE;&ES="==6R=I;G-T86QL)UTI(#T](#$I('L-"B`@("`@("`@("`@
M("`@("`@("`@)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72`]("1R
M96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UU;,%T[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y#0H@("`@("H@0')E='5R;B!A
M<G)A>0T*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%]P<F]C97-S1&5P*"1D97`I#0H@("`@>PT*("`@("`@("!I9B`H
M)&1E<%LG='EP92==(#T]("=P:'`G*2![#0H@("`@("`@("`@("!I9B`H)&1E
M<%LG<F5L)UT@/3T@)VAA<R<I('L-"B`@("`@("`@("`@("`@("`O+R!C;VUE
M(&]N("T@979E<GEO;F4@:&%S('!H<"$-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'!H<"`](&%R<F%Y*"D[#0H@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@(3T@
M)W!H<"<I('L-"B`@("`@("`@("`@("1P:'!;)VYA;64G72`]("1D97!;)VYA
M;64G73L-"B`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@/3T@)W!K9R<I
M('L-"B`@("`@("`@("`@("`@("`D<&AP6R=C:&%N;F5L)UT@/2`G<&5A<BYP
M:'`N;F5T)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!S
M=VET8V@@*"1D97!;)W)E;"==*2![#0H@("`@("`@("`@("!C87-E("=G="<@
M.@T*("`@("`@("`@("`@("`@("1P:'!;)VUI;B==(#T@)&1E<%LG=F5R<VEO
M;B==.PT*("`@("`@("`@("`@("`@("1P:'!;)V5X8VQU9&4G72`]("1D97!;
M)W9E<G-I;VXG73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@
M8V%S92`G9V4G(#H-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;
M)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1D97!;
M)W1Y<&4G72`]/2`G<&AP)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!;)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=V97)S:6]N)UT@/2`D9&5P6R=N86UE)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!H<%LG
M;6EN)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@(&-A<V4@)VQT)R`Z#0H@("`@("`@("`@("`@("`@)'!H
M<%LG;6%X)UT@/2`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@
M)'!H<%LG97AC;'5D92==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@("`@
M("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=L92<@.@T*("`@("`@("`@
M("`@("`@("1P:'!;)VUA>"==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=E<2<@.@T*("`@("`@
M("`@("`@("`@("1P:'!;)VUI;B==(#T@)&1E<%LG=F5R<VEO;B==.PT*("`@
M("`@("`@("`@("`@("1P:'!;)VUA>"==(#T@)&1E<%LG=F5R<VEO;B==.PT*
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E("=N92<@.@T*
M("`@("`@("`@("`@("`@("1P:'!;)V5X8VQU9&4G72`]("1D97!;)W9E<G-I
M;VXG73L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G
M;F]T)R`Z#0H@("`@("`@("`@("`@("`@)'!H<%LG8V]N9FQI8W1S)UT@/2`G
M>65S)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@
M(')E='5R;B`D<&AP.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A
M;2!A<G)A>0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!?<')O8V5S<U!H<$1E<',H)&1E<',I#0H@("`@>PT*("`@("`@
M("`D=&5S="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1D97!S(&%S
M("1D97`I('L-"B`@("`@("`@("`@("1T97-T6UT@/2`D=&AI<RT^7W!R;V-E
M<W-$97`H)&1E<"D[#0H@("`@("`@('T-"B`@("`@("`@)&UI;B`](&%R<F%Y
M*"D[#0H@("`@("`@("1M87@@/2!A<G)A>2@I.PT*("`@("`@("!F;W)E86-H
M("@D=&5S="!A<R`D9&5P*2![#0H@("`@("`@("`@("!I9B`H(21D97`I('L-
M"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@
M("`@("`@("`D;6EN6R1D97!;)VUI;B==72`](&-O=6YT*"1M:6XI.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@("`@("1M87A;)&1E<%LG;6%X)UU=(#T@8V]U
M;G0H)&UA>"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&-O=6YT*"1M:6XI(#X@,"D@>PT*("`@("`@("`@("`@=6MS;W)T*"1M
M:6XL("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H8V]U;G0H)&UA>"D@/B`P*2![#0H@("`@("`@("`@("!U:W-O<G0H)&UA
M>"P@)W9E<G-I;VY?8V]M<&%R92<I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("AC;W5N="@D;6EN*2D@>PT*("`@("`@("`@("`@+R\@9V5T('1H92!H:6=H
M97-T(&UI;FEM=6T-"B`@("`@("`@("`@("1M:6X@/2!A<G)A>5]P;W`H)&$@
M/2!A<G)A>5]F;&EP*"1M:6XI*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1M:6X@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H
M8V]U;G0H)&UA>"DI('L-"B`@("`@("`@("`@("\O(&=E="!T:&4@;&]W97-T
M(&UA>&EM=6T-"B`@("`@("`@("`@("1M87@@/2!A<G)A>5]S:&EF="@D82`]
M(&%R<F%Y7V9L:7`H)&UA>"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@)&UA>"`](&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M;6EN*2![#0H@("`@("`@("`@("`D<&AP6R=M:6XG72`]("1M:6X[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1M87@I('L-"B`@("`@("`@("`@("1P:'!;
M)VUA>"==(#T@)&UA>#L-"B`@("`@("`@?0T*("`@("`@("`D97AC;'5D92`]
M(&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1T97-T(&%S("1D97`I('L-
M"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&5X8VQU9&5;72`]("1D97!;)V5X8VQU9&4G73L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&5X8VQU9&4I*2![#0H@("`@("`@
M("`@("`D<&AP6R=E>&-L=61E)UT@/2`D97AC;'5D93L-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)'!H<#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!P<F]C97-S(&UU;'1I<&QE(&1E<&5N9&5N8VEE<R!T:&%T(&AA=F4@82!N
M86UE+"!L:6ME('!A8VMA9V4@9&5P<PT*("`@("`J($!P87)A;2!A<G)A>0T*
M("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`86-C97-S('!R:79A=&4-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<')O8V5S<TUU;'1I<&QE1&5P<TYA
M;64H)&1E<',I#0H@("`@>PT*("`@("`@("`D=&5S=',@/2!A<G)A>2@I.PT*
M("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D;F%M92`]/B`D9&5P*2![#0H@
M("`@("`@("`@("!F;W)E86-H("@D9&5P(&%S("1D*2![#0H@("`@("`@("`@
M("`@("`@)'1E<W1S6R1N86UE75M=(#T@)'1H:7,M/E]P<F]C97-S1&5P*"1D
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H
M("@D=&5S=',@87,@)&YA;64@/3X@)'1E<W0I('L-"B`@("`@("`@("`@("1P
M:'`@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)&UI;B`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("`D;6%X(#T@87)R87DH*3L-"B`@("`@("`@("`@("1P:'!;
M)VYA;64G72`]("1N86UE.PT*("`@("`@("`@("`@9F]R96%C:"`H)'1E<W0@
M87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("@A)&1E<"D@>PT*("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-H86YN96PG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'!H<%LG8VAA;FYE;"==(#T@)W!E
M87(N<&AP+FYE="<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G72D@)B8@)&1E<%LG8V]N
M9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@)'!H
M<%LG8V]N9FQI8W1S)UT@/2`G>65S)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D;6EN6R1D97!;)VUI;B==72`](&-O=6YT*"1M
M:6XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1M
M87A;)&1E<%LG;6%X)UU=(#T@8V]U;G0H)&UA>"D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT*"1M
M:6XI(#X@,"D@>PT*("`@("`@("`@("`@("`@('5K<V]R="@D;6EN+"`G=F5R
M<VEO;E]C;VUP87)E)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H8V]U;G0H)&UA>"D@/B`P*2![#0H@("`@("`@("`@("`@("`@=6MS;W)T
M*"1M87@L("=V97)S:6]N7V-O;7!A<F4G*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AC;W5N="@D;6EN*2D@>PT*("`@("`@("`@("`@("`@
M("\O(&=E="!T:&4@:&EG:&5S="!M:6YI;75M#0H@("`@("`@("`@("`@("`@
M)&UI;B`](&%R<F%Y7W!O<"@D82`](&%R<F%Y7V9L:7`H)&UI;BDI.PT*("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D;6EN(#T@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&UA
M>"DI('L-"B`@("`@("`@("`@("`@("`O+R!G970@=&AE(&QO=V5S="!M87AI
M;75M#0H@("`@("`@("`@("`@("`@)&UA>"`](&%R<F%Y7W-H:69T*"1A(#T@
M87)R87E?9FQI<"@D;6%X*2D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1M87@@/2!F86QS93L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("@D;6EN*2![#0H@("`@("`@("`@("`@("`@)'!H<%LG
M;6EN)UT@/2`D;6EN.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1M87@I('L-"B`@("`@("`@("`@("`@("`D<&AP6R=M87@G72`]("1M87@[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D97AC;'5D92`](&%R<F%Y
M*"D[#0H@("`@("`@("`@("!F;W)E86-H("@D=&5S="!A<R`D9&5P*2![#0H@
M("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=E>&-L=61E)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D97AC;'5D95M=(#T@)&1E<%LG97AC
M;'5D92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*&-O=6YT
M*"1E>&-L=61E*2D@>PT*("`@("`@("`@("`@("`@("1P:'!;)V5X8VQU9&4G
M72`]("1E>&-L=61E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')E
M=%M=(#T@)'!H<#L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E=#L-
M"B`@("!]#0I]#0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O26YS=&%L;&5R+U)O;&4`````````````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S0@
M,#(Q-S<P`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92YP:'``````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R
M,#(S,B`Q,#4Q-30S-#$S-"`P,C(U-3<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]);G-T
M86QL97)?4F]L90T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!2;VQE+G!H<"QV(#$N,3,@,C`P-B\P,2\P-B`P-#HT-SHS-B!C96QL
M;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA
M<W,@9F]R(&EN<W1A;&QE<B!R;VQE<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%
M05(O26YS=&%L;&5R+U)O;&4O0V]M;6]N+G!H<"<[#0IR97%U:7)E7V]N8V4@
M)U!%05(O6$U,4&%R<V5R+G!H<"<[#0HO+R1'3$]"04Q36R=?4$5!4E])3E-4
M04Q,15)?4D],15,G72`](&%R<F%Y*"D[#0HO*BH-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*
M("HO#0IC;&%S<R!014%27TEN<W1A;&QE<E]2;VQE#0I[#0H@("`@+RHJ#0H@
M("`@("H@4V5T('5P(&%N>2!A9&1I=&EO;F%L(&-O;F9I9W5R871I;VX@=F%R
M:6%B;&5S('1H870@9FEL92!R;VQE<R!R97%U:7)E#0H@("`@("H-"B`@("`@
M*B!.979E<B!C86QL('1H:7,@9&ER96-T;'DL(&ET(&ES(&-A;&QE9"!B>2!T
M:&4@4$5!4E]#;VYF:6<@8V]N<W1R=6-T;W(-"B`@("`@*B!`<&%R86T@4$5!
M4E]#;VYF:6<-"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B!`<W1A
M=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YI=&EA;&EZ94-O;F9I9R@F
M)&-O;F9I9RD-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;
M)U]014%27TE.4U1!3$Q%4E]23TQ%4R==*2D@>PT*("`@("`@("`@("`@4$5!
M4E]);G-T86QL97)?4F]L93HZ<F5G:7-T97)2;VQE<R@I.PT*("`@("`@("!]
M#0H@("`@("`@(&9O<F5A8V@@*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?
M4D],15,G72!A<R`D8VQA<W,@/3X@)&EN9F\I('L-"B`@("`@("`@("`@(&EF
M("@A)&EN9F];)V-O;F9I9U]V87)S)UTI('L-"B`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C;VYF:6<M
M/E]A9&1#;VYF:6=687)S*"1I;F9O6R=C;VYF:6=?=F%R<R==*3L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!014%27U!A
M8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M('-T<FEN9R!R;VQE(&YA;64-
M"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<F5T=7)N(%!%
M05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N#0H@("`@("H@0'-T871I8PT*("`@
M("`J+PT*("`@(&9U;F-T:6]N("9F86-T;W)Y*"1P:V<L("1R;VQE+"`F)&-O
M;F9I9RD-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]0
M14%27TE.4U1!3$Q%4E]23TQ%4R==*2D@>PT*("`@("`@("`@("`@4$5!4E])
M;G-T86QL97)?4F]L93HZ<F5G:7-T97)2;VQE<R@I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:6Y?87)R87DH)')O;&4L(%!%05)?26YS=&%L;&5R7U)O
M;&4Z.F=E=%9A;&ED4F]L97,H)'!K9RT^9V5T4&%C:V%G951Y<&4H*2DI*2![
M#0H@("`@("`@("`@("`D82`](&9A;'-E.PT*("`@("`@("`@("`@<F5T=7)N
M("1A.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)U!%05)?26YS=&%L;&5R
M7U)O;&5?)R`N('5C9FER<W0H)')O;&4I.PT*("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@D82DI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92!S=')?
M<F5P;&%C92@G7R<L("<O)RP@)&$I("X@)RYP:'`G.PT*("`@("`@("!]#0H@
M("`@("`@("1B(#T@;F5W("1A*"1C;VYF:6<I.PT*("`@("`@("!R971U<FX@
M)&([#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&$@;&ES="!O9B!F
M:6QE(')O;&5S('1H870@87)E('9A;&ED(&9O<B!T:&4@<&%R=&EC=6QA<B!R
M96QE87-E('1Y<&4N#0H@("`@("H-"B`@("`@*B!&;W(@:6YS=&%N8V4L('-R
M8R!F:6QE<R!S97)V92!N;R!P=7)P;W-E(&EN(')E9W5L87(@<&AP(')E;&5A
M<V5S+B`@<&AP(&9I;&5S#0H@("`@("H@<V5R=F4@;F\@<'5R<&]S92!I;B!E
M>'1S<F,@;W(@97AT8FEN(')E;&5A<V5S#0H@("`@("H@0'!A<F%M('-T<FEN
M9PT*("`@("`J($!P87)A;2!B;V]L(&-L96%R(&-A8VAE#0H@("`@("H@0')E
M='5R;B!A<G)A>0T*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!G971686QI9%)O;&5S*"1R96QE87-E+"`D8VQE87(@/2!F86QS92D-
M"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;)U]014%27TE.
M4U1!3$Q%4E]23TQ%4R==*2D@>PT*("`@("`@("`@("`@4$5!4E]);G-T86QL
M97)?4F]L93HZ<F5G:7-T97)2;VQE<R@I.PT*("`@("`@("!]#0H@("`@("`@
M('-T871I8R`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@:68@*"1C;&5A<BD@
M>PT*("`@("`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1R971;)')E;&5A<V5=*2D@>PT*("`@("`@("`@
M("`@<F5T=7)N("1R971;)')E;&5A<V5=.PT*("`@("`@("!]#0H@("`@("`@
M("1R971;)')E;&5A<V5=(#T@87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H
M)$=,3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==(&%S("1R;VQE(#T^
M("1O:W)E;&5A<V5S*2![#0H@("`@("`@("`@("!I9B`H:6Y?87)R87DH)')E
M;&5A<V4L("1O:W)E;&5A<V5S6R=R96QE87-E='EP97,G72DI('L-"B`@("`@
M("`@("`@("`@("`D<F5T6R1R96QE87-E75M=(#T@<W1R=&]L;W=E<BAS=')?
M<F5P;&%C92@G4$5!4E]);G-T86QL97)?4F]L95\G+"`G)RP@)')O;&4I*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')E
M=%LD<F5L96%S95T[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@1V5T(&$@
M;&ES="!O9B!R;VQE<R!T:&%T(')E<75I<F4@=&AE:7(@9FEL97,@=&\@8F4@
M:6YS=&%L;&5D#0H@("`@("H-"B`@("`@*B!-;W-T(')O;&5S(&UU<W0@8F4@
M:6YS=&%L;&5D+"!B=70@<W)C(&%N9"!P86-K86=E(')O;&5S+"!F;W(@:6YS
M=&%N8V4-"B`@("`@*B!A<F4@<'-E=61O+7)O;&5S+B`@<W)C(&9I;&5S(&%R
M92!C;VUP:6QE9"!I;G1O(&$@;F5W(&5X=&5N<VEO;BX@(%!A8VMA9V4-"B`@
M("`@*B!R;VQE<R!A<F4@86-T=6%L;'D@9G5L;'D@8G5N9&QE9"!R96QE87-E
M<R!O9B!A('!A8VMA9V4-"B`@("`@*B!`<&%R86T@8F]O;"!C;&5A<B!C86-H
M90T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B!`<W1A=&EC#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@9V5T26YS=&%L;&%B;&52;VQE<R@D8VQE87(@
M/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@A:7-S970H)$=,3T)!3%-;
M)U]014%27TE.4U1!3$Q%4E]23TQ%4R==*2D@>PT*("`@("`@("`@("`@4$5!
M4E]);G-T86QL97)?4F]L93HZ<F5G:7-T97)2;VQE<R@I.PT*("`@("`@("!]
M#0H@("`@("`@('-T871I8R`D<F5T.PT*("`@("`@("!I9B`H)&-L96%R*2![
M#0H@("`@("`@("`@("!U;G-E="@D<F5T*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6ES<V5T*"1R970I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UT@87,@)')O;&4@/3X@
M)&]K<F5L96%S97,I('L-"B`@("`@("`@("`@("`@("!I9B`H)&]K<F5L96%S
M97-;)VEN<W1A;&QA8FQE)UTI('L-"B`@("`@("`@("`@("`@("`@("`@)')E
M=%M=(#T@<W1R=&]L;W=E<BAS=')?<F5P;&%C92@G4$5!4E]);G-T86QL97)?
M4F]L95\G+"`G)RP@)')O;&4I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@
M("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&%N(&%R<F%Y(&]F(')O
M;&5S('1H870@87)E(&%F9F5C=&5D(&)Y('1H92!B87-E:6YS=&%L;&1I<B!A
M='1R:6)U=&4-"B`@("`@*@T*("`@("`J($UO<W0@<F]L97,@:6=N;W)E('1H
M:7,@871T<FEB=71E+"!A;F0@:6YS=&5A9"!I;G-T86QL(&1I<F5C=&QY(&EN
M=&\Z#0H@("`@("H@4&%C:V%G94YA;64O9FEL97!A=&@-"B`@("`@*B!S;R!A
M('1E<W1S(&9I;&4@=&5S=',O9FEL92YP:'!T(&ES(&EN<W1A;&QE9"!I;G1O
M(%!A8VMA9V5.86UE+W1E<W1S+V9I;&5P871H+G!H<`T*("`@("`J($!P87)A
M;2!B;V]L(&-L96%R(&-A8VAE#0H@("`@("H@0')E='5R;B!A<G)A>0T*("`@
M("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971"87-E:6YS
M=&%L;%)O;&5S*"1C;&5A<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@
M*"%I<W-E="@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UTI*2![
M#0H@("`@("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIR96=I<W1E<E)O
M;&5S*"D[#0H@("`@("`@('T-"B`@("`@("`@<W1A=&EC("1R970[#0H@("`@
M("`@(&EF("@D8VQE87(I('L-"B`@("`@("`@("`@('5N<V5T*"1R970I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)')E="DI('L-"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],
M15,G72!A<R`D<F]L92`]/B`D;VMR96QE87-E<RD@>PT*("`@("`@("`@("`@
M("`@(&EF("@D;VMR96QE87-E<ULG:&]N;W)S8F%S96EN<W1A;&PG72D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<F5T6UT@/2!S=')T;VQO=V5R*'-T<E]R
M97!L86-E*"=014%27TEN<W1A;&QE<E]2;VQE7R<L("<G+"`D<F]L92DI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@
M*B!2971U<FX@86X@87)R87D@;V8@9FEL92!R;VQE<R!T:&%T('-H;W5L9"!B
M92!A;F%L>7IE9"!F;W(@4$A0(&-O;G1E;G0@870@<&%C:V%G92!T:6UE+`T*
M("`@("`J(&QI:V4@=&AE(")P:'`B(')O;&4N#0H@("`@("H@0'!A<F%M(&)O
M;VP@8VQE87(@8V%C:&4-"B`@("`@*B!`<F5T=7)N(&%R<F%Y#0H@("`@("H@
M0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(&=E=%!H<%)O;&5S*"1C
M;&5A<B`](&9A;'-E*0T*("`@('L-"B`@("`@("`@:68@*"%I<W-E="@D1TQ/
M0D%,4ULG7U!%05)?24Y35$%,3$527U)/3$53)UTI*2![#0H@("`@("`@("`@
M("!014%27TEN<W1A;&QE<E]2;VQE.CIR96=I<W1E<E)O;&5S*"D[#0H@("`@
M("`@('T-"B`@("`@("`@<W1A=&EC("1R970[#0H@("`@("`@(&EF("@D8VQE
M87(I('L-"B`@("`@("`@("`@('5N<V5T*"1R970I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A:7-S970H)')E="DI('L-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1'3$]"04Q36R=?4$5!4E])3E-404Q,15)?4D],15,G72!A<R`D<F]L
M92`]/B`D;VMR96QE87-E<RD@>PT*("`@("`@("`@("`@("`@(&EF("@D;VMR
M96QE87-E<ULG<&AP9FEL92==*2![#0H@("`@("`@("`@("`@("`@("`@("1R
M971;72`]('-T<G1O;&]W97(H<W1R7W)E<&QA8V4H)U!%05)?26YS=&%L;&5R
M7U)O;&5?)RP@)R<L("1R;VQE*2D[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%-C86X@=&AR;W5G:"!T:&4@0V]M
M;6%N9"!D:7)E8W1O<GD@;&]O:VEN9R!F;W(@8VQA<W-E<PT*("`@("`J(&%N
M9"!S964@=VAA="!C;VUM86YD<R!T:&5Y(&EM<&QE;65N="X-"B`@("`@*B!`
M<&%R86T@<W1R:6YG('=H:6-H(&1I<F5C=&]R>2!T;R!L;V]K(&9O<B!C;&%S
M<V5S+"!D969A=6QT<R!T;PT*("`@("`J("`@("`@("`@("`@("`@=&AE($EN
M<W1A;&QE<B]2;VQE<R!S=6)D:7)E8W1O<GD@;V8-"B`@("`@*B`@("`@("`@
M("`@("`@('1H92!D:7)E8W1O<GD@9G)O;2!W:&5R92!T:&ES(&9I;&4@*%]?
M1DE,15]?*2!I<PT*("`@("`J("`@("`@("`@("`@("`@:6YC;'5D960N#0H@
M("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S=6-C97-S+"!A
M(%!%05(@97)R;W(@;VX@9F%I;'5R90T*("`@("`J($!A8V-E<W,@<'5B;&EC
M#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(')E9VES
M=&5R4F]L97,H)&1I<B`](&YU;&PI#0H@("`@>PT*("`@("`@("`D<&%R<V5R
M(#T@;F5W(%!%05)?6$U,4&%R<V5R.PT*("`@("`@("!I9B`H)&1I<B`]/3T@
M;G5L;"D@>PT*("`@("`@("`@("`@)&1I<B`](&1I<FYA;64H7U]&24Q%7U\I
M("X@)R]2;VQE)SL-"B`@("`@("`@?0T*("`@("`@("`D9'`@/2!`;W!E;F1I
M<B@D9&ER*3L-"B`@("`@("`@:68@*&5M<'1Y*"1D<"DI('L-"B`@("`@("`@
M("`@(')E='5R;B!014%2.CIR86ES945R<F]R*")R96=I<W1E<E)O;&5S.B!O
M<&5N9&ER*"1D:7(I(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@('=H
M:6QE("@D96YT<GD@/2!R96%D9&ER*"1D<"DI('L-"B`@("`@("`@("`@(&EF
M("@D96YT<GE[,'T@/3T@)RXG('Q\('-U8G-T<B@D96YT<GDL("TT*2`A/2`G
M+GAM;"<I('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1C;&%S<R`](")014%27TEN<W1A;&QE<E]2
M;VQE7R(N<W5B<W1R*"1E;G1R>2P@,"P@+30I.PT*("`@("`@("`@("`@+R\@
M3&ES="!O9B!R;VQE<PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q3
M6R=?4$5!4E])3E-404Q,15)?4D],15,G75LD8VQA<W-=*2D@>PT*("`@("`@
M("`@("`@("`@("1F:6QE(#T@(B1D:7(O)&5N=')Y(CL-"B`@("`@("`@("`@
M("`@("`D<&%R<V5R+3YP87)S92AF:6QE7V=E=%]C;VYT96YT<R@D9FEL92DI
M.PT*("`@("`@("`@("`@("`@("1D871A(#T@)'!A<G-E<BT^9V5T1&%T82@I
M.PT*("`@("`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&1A=&%;)W)E;&5A
M<V5T>7!E<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LG<F5L
M96%S971Y<&5S)UT@/2!A<G)A>2@D9&%T85LG<F5L96%S971Y<&5S)UTI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D1TQ/0D%,4ULG
M7U!%05)?24Y35$%,3$527U)/3$53)UU;)&-L87-S72`]("1D871A.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@($!C;&]S961I<B@D9'`I
M.PT*("`@("`@("!K<V]R="@D1TQ/0D%,4ULG7U!%05)?24Y35$%,3$527U)/
M3$53)UTI.PT*("`@("`@("!014%27TEN<W1A;&QE<E]2;VQE.CIG971"87-E
M:6YS=&%L;%)O;&5S*'1R=64I.PT*("`@("`@("!014%27TEN<W1A;&QE<E]2
M;VQE.CIG971);G-T86QL86)L95)O;&5S*'1R=64I.PT*("`@("`@("!014%2
M7TEN<W1A;&QE<E]2;VQE.CIG9710:'!2;VQE<RAT<G5E*3L-"B`@("`@("`@
M4$5!4E]);G-T86QL97)?4F]L93HZ9V5T5F%L:612;VQE<R@G*BHJ*B<L('1R
M=64I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0I]#0H_/@T*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]#
M;VUM;VXN<&AP````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3(T-"`Q,#4Q
M-30S-#$S-"`P,C0P,38`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J*@T*("H@0F%S92!C;&%S<R!F;W(@86QL
M(&EN<W1A;&QA=&EO;B!R;VQE<RX-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@0V]M;6]N+G!H<"QV(#$N,3`@,C`P-B\P,2\P-B`P
M-#HT-SHS-R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*+RHJ#0H@
M*B!"87-E(&-L87-S(&9O<B!A;&P@:6YS=&%L;&%T:6]N(')O;&5S+@T*("H-
M"B`J(%1H:7,@8VQA<W,@86QL;W=S(&5X=&5N<VEB:6QI='D@;V8@9FEL92!R
M;VQE<RX@(%!A8VMA9V5S('=I=&@@8V]M<&QE>`T*("H@8W5S=&]M:7IA=&EO
M;B!C86X@;F]W('!R;W9I9&4@8W5S=&]M(&9I;&4@<F]L97,@86QO;F<@=VET
M:"!T:&4@<&]S<VEB:6QI='D@;V8-"B`J(&%D9&EN9R!C;VYF:6=U<F%T:6]N
M('9A;'5E<R!T;R!M871C:"X-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P
M86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC
M96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@
M4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!0
M14%27TEN<W1A;&QE<E]2;VQE7T-O;6UO;@T*>PT*("`@("\J*@T*("`@("`J
M($!V87(@4$5!4E]#;VYF:6<-"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`T*
M("`@("`J+PT*("`@('9A<B`D8V]N9FEG.PT*#0H@("`@+RHJ#0H@("`@("H@
M0'!A<F%M(%!%05)?0V]N9FEG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!
M4E]);G-T86QL97)?4F]L95]#;VUM;VXH)B1C;VYF:6<I#0H@("`@>PT*("`@
M("`@("`D=&AI<RT^8V]N9FEG(#T@)&-O;F9I9SL-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!2971R:65V92!C;VYF:6=U<F%T:6]N(&EN9F]R;6%T:6]N
M(&%B;W5T(&$@9FEL92!R;VQE(&9R;VT@:71S(%A-3"!I;F9O#0H@("`@("H-
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1R;VQE(%)O;&4@0VQA<W-N86UE+"!A
M<R!I;B`B4$5!4E]);G-T86QL97)?4F]L95]$871A(@T*("`@("`J($!R971U
M<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971);F9O*"1R;VQE
M*0T*("`@('L-"B`@("`@("`@:68@*&5M<'1Y*"1'3$]"04Q36R=?4$5!4E])
M3E-404Q,15)?4D],15,G75LD<F]L95TI*2![#0H@("`@("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@G56YK;F]W;B!2;VQE(&-L87-S.B`B)R`N
M("1R;VQE("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)$=,
M3T)!3%-;)U]014%27TE.4U1!3$Q%4E]23TQ%4R==6R1R;VQE73L-"B`@("!]
M#0H-"B`@("`O*BH-"B`@("`@*B!4:&ES(&ES(&-A;&QE9"!F;W(@96%C:"!F
M:6QE('1O('-E="!U<"!T:&4@9&ER96-T;W)I97,@86YD(&9I;&5S#0H@("`@
M("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!4E]086-K86=E1FEL
M95]V,@T*("`@("`J($!P87)A;2!A<G)A>2!A='1R:6)U=&5S(&9R;VT@=&AE
M(#QF:6QE/B!T86<-"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@;F%M90T*
M("`@("`J($!R971U<FX@87)R87D@86X@87)R87D@8V]N<VES=&EN9R!O9CH-
M"B`@("`@*@T*("`@("`J("`@(#$@=&AE(&]R:6=I;F%L+"!P<F4M8F%S96EN
M<W1A;&QD:7(@:6YS=&%L;&%T:6]N(&1I<F5C=&]R>0T*("`@("`J("`@(#(@
M=&AE(&9I;F%L(&EN<W1A;&QA=&EO;B!D:7)E8W1O<GD-"B`@("`@*B`@("`S
M('1H92!F=6QL('!A=&@@=&\@=&AE(&9I;F%L(&QO8V%T:6]N(&]F('1H92!F
M:6QE#0H@("`@("H@("`@-"!T:&4@;&]C871I;VX@;V8@=&AE('!R92UI;G-T
M86QL871I;VX@9FEL90T*("`@("`J+PT*("`@(&9U;F-T:6]N('!R;V-E<W-)
M;G-T86QL871I;VXH)'!K9RP@)&%T=',L("1F:6QE+"`D=&UP7W!A=&@L("1L
M87EE<B`](&YU;&PI#0H@("`@>PT*("`@("`@("`D<F]L94EN9F\@/2!014%2
M7TEN<W1A;&QE<E]2;VQE7T-O;6UO;CHZ9V5T26YF;R@G4$5!4E]);G-T86QL
M97)?4F]L95\G("X@#0H@("`@("`@("`@("!U8V9I<G-T*'-T<E]R97!L86-E
M*"=P96%R7VEN<W1A;&QE<E]R;VQE7R<L("<G+"!S=')T;VQO=V5R*&=E=%]C
M;&%S<R@D=&AI<RDI*2DI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F]L94EN9F\I*2![#0H@("`@("`@("`@("!R971U<FX@)')O;&5);F9O.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)')O;&5);F9O6R=L;V-A=&EO;F-O
M;F9I9R==*2![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"1R;VQE26YF;ULG:&]N;W)S8F%S96EN<W1A;&PG
M72D@>PT*("`@("`@("`@("`@)&1E<W1?9&ER(#T@)'-A=F5?9&5S=&1I<B`]
M("1T:&ES+3YC;VYF:6<M/F=E="@D<F]L94EN9F];)VQO8V%T:6]N8V]N9FEG
M)UTL("1L87EE<BP-"B`@("`@("`@("`@("`@("`D<&MG+3YG971#:&%N;F5L
M*"DI.PT*("`@("`@("`@("`@:68@*"%E;7!T>2@D871T<ULG8F%S96EN<W1A
M;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@("`D9&5S=%]D:7(@+CT@1$E2
M14-43U)97U-%4$%2051/4B`N("1A='1S6R=B87-E:6YS=&%L;&1I<B==.PT*
M("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H)')O;&5);F9O6R=U
M;G5S=6%L8F%S96EN<W1A;&PG72D@>PT*("`@("`@("`@("`@)&1E<W1?9&ER
M(#T@)'-A=F5?9&5S=&1I<B`]("1T:&ES+3YC;VYF:6<M/F=E="@D<F]L94EN
M9F];)VQO8V%T:6]N8V]N9FEG)UTL#0H@("`@("`@("`@("`@("`@("`@(&YU
M;&PL("1P:V<M/F=E=$-H86YN96PH*2D@+B!$25)%0U1/4EE?4T5005)!5$]2
M("X@)'!K9RT^9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@:68@*"%E;7!T
M>2@D871T<ULG8F%S96EN<W1A;&QD:7(G72DI('L-"B`@("`@("`@("`@("`@
M("`D9&5S=%]D:7(@+CT@1$E214-43U)97U-%4$%2051/4B`N("1A='1S6R=B
M87-E:6YS=&%L;&1I<B==.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&1E<W1?9&ER(#T@)'-A=F5?9&5S=&1I<B`]
M("1T:&ES+3YC;VYF:6<M/F=E="@D<F]L94EN9F];)VQO8V%T:6]N8V]N9FEG
M)UTL#0H@("`@("`@("`@("`@("`@("`@(&YU;&PL("1P:V<M/F=E=$-H86YN
M96PH*2D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)'!K9RT^9V5T4&%C:V%G
M92@I.PT*("`@("`@("!]#0H@("`@("`@(&EF("AD:7)N86UE*"1F:6QE*2`A
M/2`G+B<@)B8@96UP='DH)&%T='-;)VEN<W1A;&PM87,G72DI('L-"B`@("`@
M("`@("`@("1D97-T7V1I<B`N/2!$25)%0U1/4EE?4T5005)!5$]2("X@9&ER
M;F%M92@D9FEL92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&5M<'1Y*"1A
M='1S6R=I;G-T86QL+6%S)UTI*2![#0H@("`@("`@("`@("`D9&5S=%]F:6QE
M(#T@)&1E<W1?9&ER("X@1$E214-43U)97U-%4$%2051/4B`N(&)A<V5N86UE
M*"1F:6QE*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1D97-T
M7V9I;&4@/2`D9&5S=%]D:7(@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&%T
M='-;)VEN<W1A;&PM87,G73L-"B`@("`@("`@?0T*("`@("`@("`D;W)I9U]F
M:6QE(#T@)'1M<%]P871H("X@1$E214-43U)97U-%4$%2051/4B`N("1F:6QE
M.PT*#0H@("`@("`@("\O($-L96%N('5P('1H92!$25)%0U1/4EE?4T5005)!
M5$]2(&UE<W,-"B`@("`@("`@)&1S,B`]($1)4D5#5$]265]315!!4D%43U(@
M+B!$25)%0U1/4EE?4T5005)!5$]2.PT*("`@("`@("`-"B`@("`@("`@;&ES
M="@D9&5S=%]D:7(L("1D97-T7V9I;&4L("1O<FEG7V9I;&4I(#T@<')E9U]R
M97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O(2<L("(A)&1S,BLA(BDL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@87)R87DH1$E214-43U)97U-%4$%2051/4BP@1$E214-43U)97U-%
M4$%2051/4BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@D9&5S=%]D:7(L("1D97-T7V9I;&4L("1O<FEG7V9I
M;&4I*3L-"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1S879E7V1E<W1D:7(L("1D
M97-T7V1I<BP@)&1E<W1?9FEL92P@)&]R:6=?9FEL92D[#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@1V5T('1H92!N86UE(&]F('1H92!C;VYF:6=U<F%T
M:6]N('9A<FEA8FQE('1H870@<W!E8VEF:65S('1H92!L;V-A=&EO;B!O9B!T
M:&ES(&9I;&4-"B`@("`@*B!`<F5T=7)N('-T<FEN9WQF86QS90T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N0V]N9FEG*"D-"B`@("![#0H@
M("`@("`@("1R;VQE26YF;R`](%!%05)?26YS=&%L;&5R7U)O;&5?0V]M;6]N
M.CIG971);F9O*"=014%27TEN<W1A;&QE<E]2;VQE7R<@+B`-"B`@("`@("`@
M("`@('5C9FER<W0H<W1R7W)E<&QA8V4H)W!E87)?:6YS=&%L;&5R7W)O;&5?
M)RP@)R<L('-T<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2DI*2D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1R;VQE26YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D<F]L94EN9F\[#0H@("`@("`@('T-"B`@("`@("`@<F5T
M=7)N("1R;VQE26YF;ULG;&]C871I;VYC;VYF:6<G73L-"B`@("!]#0H-"B`@
M("`O*BH-"B`@("`@*B!$;R!A;GD@=6YU<W5A;"!S971U<"!H97)E#0H@("`@
M("H@0'!A<F%M(%!%05)?26YS=&%L;&5R#0H@("`@("H@0'!A<F%M(%!%05)?
M4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@87)R87D@9FEL92!A='1R
M:6)U=&5S#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!S971U<"@F)&EN<W1A;&QE<BP@)'!K9RP@)&%T
M=',L("1F:6QE*0T*("`@('L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!I<T5X
M96-U=&%B;&4H*0T*("`@('L-"B`@("`@("`@)')O;&5);F9O(#T@4$5!4E])
M;G-T86QL97)?4F]L95]#;VUM;VXZ.F=E=$EN9F\H)U!%05)?26YS=&%L;&5R
M7U)O;&5?)R`N(`T*("`@("`@("`@("`@=6-F:7)S="AS=')?<F5P;&%C92@G
M<&5A<E]I;G-T86QL97)?<F]L95\G+"`G)RP@<W1R=&]L;W=E<BAG971?8VQA
M<W,H)'1H:7,I*2DI*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')O
M;&5);F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1R;VQE26YF;SL-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)')O;&5);F9O6R=E>&5C=71A8FQE
M)UT[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-);G-T86QL86)L92@I#0H@
M("`@>PT*("`@("`@("`D<F]L94EN9F\@/2!014%27TEN<W1A;&QE<E]2;VQE
M7T-O;6UO;CHZ9V5T26YF;R@G4$5!4E]);G-T86QL97)?4F]L95\G("X@#0H@
M("`@("`@("`@("!U8V9I<G-T*'-T<E]R97!L86-E*"=P96%R7VEN<W1A;&QE
M<E]R;VQE7R<L("<G+"!S=')T;VQO=V5R*&=E=%]C;&%S<R@D=&AI<RDI*2DI
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F]L94EN9F\I*2![#0H@
M("`@("`@("`@("!R971U<FX@)')O;&5);F9O.PT*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B`D<F]L94EN9F];)VEN<W1A;&QA8FQE)UT[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@:7-%>'1E;G-I;VXH*0T*("`@('L-"B`@("`@("`@
M)')O;&5);F9O(#T@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VXZ.F=E=$EN
M9F\H)U!%05)?26YS=&%L;&5R7U)O;&5?)R`N(`T*("`@("`@("`@("`@=6-F
M:7)S="AS=')?<F5P;&%C92@G<&5A<E]I;G-T86QL97)?<F]L95\G+"`G)RP@
M<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*2DI*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)')O;&5);F9O*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1R;VQE26YF;SL-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)')O
M;&5);F9O6R=P:'!E>'1E;G-I;VXG73L-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]$871A+G!H<```````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,R,2`Q,#4Q-30S-#$S-"`P,C,T,C<`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\J*@T*("H@4$5!4E]);G-T86QL97)?4F]L95]$871A#0H@*@T*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A
M<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S
M90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($1A=&$N<&AP+'8@,2XV
M(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"@T*+RHJ#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!2
M96QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E])
M;G-T86QL97)?4F]L95]$871A(&5X=&5N9',@4$5!4E]);G-T86QL97)?4F]L
M95]#;VUM;VX@>WT-"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE
M<B]2;VQE+T1O8RYX;6P`````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M-3$S(#$P-3$U-#,T,3,T(#`R,S(W-0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\<F]L92!V97)S:6]N/2(Q+C`B/@T*(#QR
M96QE87-E='EP97,^<&AP/"]R96QE87-E='EP97,^#0H@/')E;&5A<V5T>7!E
M<SYE>'1S<F,\+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X=&)I
M;CPO<F5L96%S971Y<&5S/@T*(#QI;G-T86QL86)L93XQ/"]I;G-T86QL86)L
M93X-"B`\;&]C871I;VYC;VYF:6<^9&]C7V1I<CPO;&]C871I;VYC;VYF:6<^
M#0H@/&AO;F]R<V)A<V5I;G-T86QL("\^#0H@/'5N=7-U86QB87-E:6YS=&%L
M;"`O/@T*(#QP:'!F:6QE("\^#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP97AT
M96YS:6]N("\^#0H@/&-O;F9I9U]V87)S("\^#0H\+W)O;&4^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]$;V,N
M<&AP````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,Q-B`Q,#4Q-30S
M-#$S-"`P,C,R-C<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]);G-T86QL97)?4F]L95]$
M;V,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF
M('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J
M#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@1&]C
M+G!H<"QV(#$N-B`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V
M97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V
M(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#
M;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L
M87-S(%!%05)?26YS=&%L;&5R7U)O;&5?1&]C(&5X=&5N9',@4$5!4E]);G-T
M86QL97)?4F]L95]#;VUM;VX@>WT-"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+TEN<W1A;&QE<B]2;VQE+T5X="YX;6P`````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P-#0S(#$P-3$U-#,T,3,T(#`R,S,S,@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\<F]L92!V97)S:6]N
M/2(Q+C`B/@T*(#QR96QE87-E='EP97,^97AT8FEN/"]R96QE87-E='EP97,^
M#0H@/&EN<W1A;&QA8FQE/C$\+VEN<W1A;&QA8FQE/@T*(#QL;V-A=&EO;F-O
M;F9I9SYE>'1?9&ER/"]L;V-A=&EO;F-O;F9I9SX-"B`\:&]N;W)S8F%S96EN
M<W1A;&P^,3PO:&]N;W)S8F%S96EN<W1A;&P^#0H@/'5N=7-U86QB87-E:6YS
M=&%L;"`O/@T*(#QP:'!F:6QE("\^#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP
M97AT96YS:6]N/C$\+W!H<&5X=&5N<VEO;CX-"B`\8V]N9FEG7W9A<G,@+SX-
M"CPO<F]L93X`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL
M97(O4F]L92]%>'0N<&AP````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C,Q-B`Q,#4Q-30S-#$S-"`P,C,S,C(`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]);G-T
M86QL97)?4F]L95]%>'0-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*
M("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@
M879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F
M;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@
M*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L
M:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G
M92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G
M0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'
M<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N
M<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#
M5E,Z("1)9#H@17AT+G!H<"QV(#$N-B`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E
M;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@0&-A=&5G
M;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`
M<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B\-"F-L87-S(%!%05)?26YS=&%L;&5R7U)O;&5?17AT(&5X=&5N
M9',@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VX@>WT-"C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U!H<"YX;6P`````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-30W(#$P-3$U-#,T,3,T(#`R,S,R
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M<F]L92!V97)S:6]N/2(Q+C`B/@T*(#QR96QE87-E='EP97,^<&AP/"]R96QE
M87-E='EP97,^#0H@/')E;&5A<V5T>7!E<SYE>'1S<F,\+W)E;&5A<V5T>7!E
M<SX-"B`\<F5L96%S971Y<&5S/F5X=&)I;CPO<F5L96%S971Y<&5S/@T*(#QI
M;G-T86QL86)L93XQ/"]I;G-T86QL86)L93X-"B`\;&]C871I;VYC;VYF:6<^
M<&AP7V1I<CPO;&]C871I;VYC;VYF:6<^#0H@/&AO;F]R<V)A<V5I;G-T86QL
M/C$\+VAO;F]R<V)A<V5I;G-T86QL/@T*(#QU;G5S=6%L8F%S96EN<W1A;&P@
M+SX-"B`\<&AP9FEL93XQ/"]P:'!F:6QE/@T*(#QE>&5C=71A8FQE("\^#0H@
M/'!H<&5X=&5N<VEO;B`O/@T*(#QC;VYF:6=?=F%R<R`O/@T*/"]R;VQE/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4$5!4B]);G-T86QL97(O4F]L92]0:'`N<&AP````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,C,Q-B`Q,#4Q-30S-#$S-"`P,C,S,3$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`-"B\J*@T*
M("H@4$5!4E]);G-T86QL97)?4F]L95]0:'`-"B`J#0H@*B!02%`@=F5R<VEO
M;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-
M"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@
M=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E
M879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`
M=F5R<VEO;B`@("!#5E,Z("1)9#H@4&AP+G!H<"QV(#$N-R`R,#`V+S`Q+S`V
M(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I
M;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT
M+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S(%!%05)?26YS=&%L;&5R7U)O
M;&5?4&AP(&5X=&5N9',@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VX@>WT-
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+U-C
M<FEP="YX;6P`````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-34R(#$P-3$U
M-#,T,3,T(#`R-#`S-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\<F]L92!V97)S:6]N/2(Q+C`B/@T*(#QR96QE87-E='EP
M97,^<&AP/"]R96QE87-E='EP97,^#0H@/')E;&5A<V5T>7!E<SYE>'1S<F,\
M+W)E;&5A<V5T>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X=&)I;CPO<F5L96%S
M971Y<&5S/@T*(#QI;G-T86QL86)L93XQ/"]I;G-T86QL86)L93X-"B`\;&]C
M871I;VYC;VYF:6<^8FEN7V1I<CPO;&]C871I;VYC;VYF:6<^#0H@/&AO;F]R
M<V)A<V5I;G-T86QL/C$\+VAO;F]R<V)A<V5I;G-T86QL/@T*(#QU;G5S=6%L
M8F%S96EN<W1A;&P@+SX-"B`\<&AP9FEL92`O/@T*(#QE>&5C=71A8FQE/C$\
M+V5X96-U=&%B;&4^#0H@/'!H<&5X=&5N<VEO;B`O/@T*(#QC;VYF:6=?=F%R
M<R`O/@T*/"]R;VQE/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]38W)I<'0N<&AP````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,R-R`Q,#4Q-30S-#$S-"`P,C0P
M,S``(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@4$5!4E]);G-T86QL97)?4F]L95]38W)I<'0-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4V-R:7!T+G!H
M<"QV(#$N-B`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@
M0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!#;&%S
M<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"F-L87-S
M(%!%05)?26YS=&%L;&5R7U)O;&5?4V-R:7!T(&5X=&5N9',@4$5!4E]);G-T
M86QL97)?4F]L95]#;VUM;VX@>WT-"C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A
M;&QE<B]2;VQE+U-R8RYX;6P`````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,S,W(#$P-3$U-#,T,3,T(#`R,S,R,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\<F]L92!V97)S:6]N/2(Q+C`B/@T*
M(#QR96QE87-E='EP97,^97AT<W)C/"]R96QE87-E='EP97,^#0H@/&EN<W1A
M;&QA8FQE("\^#0H@/&QO8V%T:6]N8V]N9FEG("\^#0H@/&AO;F]R<V)A<V5I
M;G-T86QL("\^#0H@/'5N=7-U86QB87-E:6YS=&%L;"`O/@T*(#QP:'!F:6QE
M("\^#0H@/&5X96-U=&%B;&4@+SX-"B`\<&AP97AT96YS:6]N("\^#0H@/&-O
M;F9I9U]V87)S("\^#0H\+W)O;&4^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T86QL97(O4F]L92]3
M<F,N<&AP````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C0W,2`Q,#4Q
M-30S-#$S-"`P,C,S,3,`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`-"B\J*@T*("H@4$5!4E]);G-T86QL97)?4F]L
M95]3<F,-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M4W)C+G!H<"QV(#$N-B`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@
M)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A,0T*("HO#0H-"B\J*@T*("H@0&-A=&5G;W)Y("`@<&5A
M<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-
M"F-L87-S(%!%05)?26YS=&%L;&5R7U)O;&5?4W)C(&5X=&5N9',@4$5!4E])
M;G-T86QL97)?4F]L95]#;VUM;VX-"GL-"B`@("!F=6YC=&EO;B!S971U<"@F
M)&EN<W1A;&QE<BP@)'!K9RP@)&%T=',L("1F:6QE*0T*("`@('L-"B`@("`@
M("`@)&EN<W1A;&QE<BT^<V]U<F-E7V9I;&5S*RL[#0H@("`@?0T*?0T*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]014%2+TEN<W1A;&QE<B]2;VQE+U1E<W0N>&UL````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P-3$T(#$P-3$U-#,T,3,T(#`R,S4Q,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\<F]L92!V97)S
M:6]N/2(Q+C`B/@T*(#QR96QE87-E='EP97,^<&AP/"]R96QE87-E='EP97,^
M#0H@/')E;&5A<V5T>7!E<SYE>'1S<F,\+W)E;&5A<V5T>7!E<SX-"B`\<F5L
M96%S971Y<&5S/F5X=&)I;CPO<F5L96%S971Y<&5S/@T*(#QI;G-T86QL86)L
M93XQ/"]I;G-T86QL86)L93X-"B`\;&]C871I;VYC;VYF:6<^=&5S=%]D:7(\
M+VQO8V%T:6]N8V]N9FEG/@T*(#QH;VYO<G-B87-E:6YS=&%L;"`O/@T*(#QU
M;G5S=6%L8F%S96EN<W1A;&P@+SX-"B`\<&AP9FEL92`O/@T*(#QE>&5C=71A
M8FQE("\^#0H@/'!H<&5X=&5N<VEO;B`O/@T*(#QC;VYF:6=?=F%R<R`O/@T*
M/"]R;VQE/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]);G-T
M86QL97(O4F]L92]497-T+G!H<```````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,C,R,2`Q,#4Q-30S-#$S-"`P,C,T-S4`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!4E])
M;G-T86QL97)?4F]L95]497-T#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T
M(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E
M;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!0
M2%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@
M("`@0U93.B`D260Z(%1E<W0N<&AP+'8@,2XV(#(P,#8O,#$O,#8@,#0Z-#<Z
M,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"@T*+RHJ#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI
M8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!4E]);G-T86QL97)?4F]L95]497-T
M(&5X=&5N9',@4$5!4E]);G-T86QL97)?4F]L95]#;VUM;VX@>WT-"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]014%2+TEN<W1A;&QE<B]2;VQE+T1A=&$N>&UL````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-3$T(#$P-3$U-#,T,3,T(#`R
M,S0T,@`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\<F]L92!V97)S:6]N/2(Q+C`B/@T*(#QR96QE87-E='EP97,^<&AP/"]R
M96QE87-E='EP97,^#0H@/')E;&5A<V5T>7!E<SYE>'1S<F,\+W)E;&5A<V5T
M>7!E<SX-"B`\<F5L96%S971Y<&5S/F5X=&)I;CPO<F5L96%S971Y<&5S/@T*
M(#QI;G-T86QL86)L93XQ/"]I;G-T86QL86)L93X-"B`\;&]C871I;VYC;VYF
M:6<^9&%T85]D:7(\+VQO8V%T:6]N8V]N9FEG/@T*(#QH;VYO<G-B87-E:6YS
M=&%L;"`O/@T*(#QU;G5S=6%L8F%S96EN<W1A;&P@+SX-"B`\<&AP9FEL92`O
M/@T*(#QE>&5C=71A8FQE("\^#0H@/'!H<&5X=&5N<VEO;B`O/@T*(#QC;VYF
M:6=?=F%R<R`O/@T*/"]R;VQE/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]&<F]N=&5N9"]#3$DN<&AP````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`V-#0P-2`Q,#4Q-30S-#$S-"`P,C(Q,C$`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`-"B\J
M*@T*("H@4$5!4E]&<F]N=&5N9%]#3$D-"B`J#0H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@0TQ)+G!H<"QV(#$N-3D@,C`P-B\P,R\P,B`Q,SHQ
M-CHQ.2!P86IO>64@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V
M86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0HO*BH-"B`J(&)A<V4@
M8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T9R;VYT96YD+G!H<"<[
M#0H-"B\J*@T*("H@0V]M;6%N9"UL:6YE($9R;VYT96YD(&9O<B!T:&4@4$5!
M4B!);G-T86QL97(-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E
M("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?1G)O;G1E;F1?
M0TQ)(&5X=&5N9',@4$5!4E]&<F]N=&5N9`T*>PT*("`@("\O('M[>R!P<F]P
M97)T:65S#0H-"B`@("`O*BH-"B`@("`@*B!7:&%T('1Y<&4@;V8@=7-E<B!I
M;G1E<F9A8V4@=&AI<R!F<F]N=&5N9"!I<R!F;W(N#0H@("`@("H@0'9A<B!S
M=')I;F<-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@('9A
M<B`D='EP92`]("=#3$DG.PT*("`@('9A<B`D;'`@/2`G)SL@+R\@;&EN92!P
M<F5F:7@-"@T*("`@('9A<B`D<&%R86US(#T@87)R87DH*3L-"B`@("!V87(@
M)'1E<FT@/2!A<G)A>2@-"B`@("`@("`@)V)O;&0G(#T^("<G+`T*("`@("`@
M("`G;F]R;6%L)R`]/B`G)RP-"B`@("`@("`@*3L-"@T*("`@("\O('U]?0T*
M#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("!F=6YC=&EO;B!014%2
M7T9R;VYT96YD7T-,22@I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H
M*3L-"B`@("`@("`@)'1E<FT@/2!G971E;G8H)U1%4DTG*3L@+R\H8V]X*2`D
M7T5.5B!I<R!E;7!T>2!F;W(@;64@:6X@-"XQ+C$-"B`@("`@("`@:68@*&9U
M;F-T:6]N7V5X:7-T<R@G<&]S:7A?:7-A='1Y)RD@)B8@(7!O<VEX7VES871T
M>2@Q*2D@>PT*("`@("`@("`@("`@+R\@;W5T<'5T(&ES(&)E:6YG(')E9&ER
M96-T960@=&\@82!F:6QE(&]R('1H<F]U9V@@82!P:7!E#0H@("`@("`@('T@
M96QS96EF("@D=&5R;2D@>PT*("`@("`@("`@("`@+R\@6%A8(&-A;B!U<V4@
M;F-U<G-E<R!E>'1E;G-I;VX@:&5R92P@:68@879A:6QA8FQE#0H@("`@("`@
M("`@("!I9B`H<')E9U]M871C:"@G+UXH>'1E<FU\=G0R,C!\;&EN=7@I+R<L
M("1T97)M*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YT97)M6R=B;VQD
M)UT@/2!S<')I;G1F*"(E8R5C)6,E8R(L(#(W+"`Y,2P@-#DL(#$P.2D[#0H@
M("`@("`@("`@("`@("`@)'1H:7,M/G1E<FU;)VYO<FUA;"==/7-P<FEN=&8H
M(B5C)6,E8R(L(#(W+"`Y,2P@,3`Y*3L-"B`@("`@("`@("`@('T@96QS96EF
M("AP<F5G7VUA=&-H*"<O7G9T,3`P+R<L("1T97)M*2D@>PT*("`@("`@("`@
M("`@("`@("1T:&ES+3YT97)M6R=B;VQD)UT@/2!S<')I;G1F*"(E8R5C)6,E
M8R5C)6,B+"`R-RP@.3$L(#0Y+"`Q,#DL(#`L(#`I.PT*("`@("`@("`@("`@
M("`@("1T:&ES+3YT97)M6R=N;W)M86PG73US<')I;G1F*"(E8R5C)6,E8R5C
M(BP@,C<L(#DQ+"`Q,#DL(#`L(#`I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!](&5L<V5I9B`H3U-?5TE.1$]74RD@>PT*("`@("`@("`@("`@+R\@6%A8
M(&%D9"!!3E-)(&-O9&5S(&AE<F4-"B`@("`@("`@?0T*("`@('T-"@T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(&1I<W!L87E,:6YE*'1E>'0I#0H-"B`@
M("!F=6YC=&EO;B!D:7-P;&%Y3&EN92@D=&5X="D-"B`@("![#0H@("`@("`@
M('1R:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y3&EN
M92!D97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!?9&ES<&QA>4QI;F4H)'1E>'0I#0H@("`@>PT*("`@("`@("!P
M<FEN="`B)'1H:7,M/FQP)'1E>'1<;B([#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@+R\@>WM[(&1I<W!L87DH=&5X="D-"@T*("`@(&9U;F-T:6]N(&1I
M<W!L87DH)'1E>'0I#0H@("`@>PT*("`@("`@("!T<FEG9V5R7V5R<F]R*")0
M14%27T9R;VYT96YD7T-,23HZ9&ES<&QA>2!D97!R96-A=&5D(BP@15]54T52
M7T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?9&ES<&QA>2@D=&5X
M="D-"B`@("![#0H@("`@("`@('!R:6YT("1T97AT.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!D:7-P;&%Y17)R;W(H96]B:BD-"@T*("`@
M("\J*@T*("`@("`J($!P87)A;2!O8FIE8W0@4$5!4E]%<G)O<B!O8FIE8W0-
M"B`@("`@*B\-"B`@("!F=6YC=&EO;B!D:7-P;&%Y17)R;W(H)&5O8FHI#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y3&EN92@D96]B
M:BT^9V5T365S<V%G92@I*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&ES<&QA>49A=&%L17)R;W(H96]B:BD-"@T*("`@("\J*@T*("`@
M("`J($!P87)A;2!O8FIE8W0@4$5!4E]%<G)O<B!O8FIE8W0-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!D:7-P;&%Y1F%T86Q%<G)O<B@D96]B:BD-"B`@("![
M#0H@("`@("`@("1T:&ES+3YD:7-P;&%Y17)R;W(H)&5O8FHI.PT*("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"=014%27T-O;F9I9R<I*2![#0H@("`@("`@
M("`@("`D8V]N9FEG(#T@)E!%05)?0V]N9FEG.CIS:6YG;&5T;VXH*3L-"B`@
M("`@("`@("`@(&EF("@D8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#4I('L-
M"B`@("`@("`@("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]P
M<FEN=%]B86-K=')A8V4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!D96)U
M9U]P<FEN=%]B86-K=')A8V4H*3L-"B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H9G5N8W1I;VY?97AI<W1S*"=D96)U9U]B86-K=')A8V4G*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`D=')A8V4@/2!D96)U9U]B86-K=')A8V4H*3L-
M"B`@("`@("`@("`@("`@("`@("`@)')A:7-E9"`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=')A8V4@87,@)&D@/3X@)&9R86UE
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(21R86ES960I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&9R86UE
M6R=C;&%S<R==*2`F)B!S=')T;VQO=V5R*"1F<F%M95LG8VQA<W,G72D@/3T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5A<B<@)B8@
M<W1R=&]L;W=E<B@D9G)A;65;)V9U;F-T:6]N)UTI(#T]("=R86ES965R<F]R
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F%I<V5D
M(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!`)'1H:7,M
M/E]D:7-P;&%Y3&EN92@B(R1I.B`D9G)A;65;8VQA<W-=)&9R86UE6W1Y<&5=
M)&9R86UE6V9U;F-T:6]N72`D9G)A;65;;&EN95TB*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!E>&ET*#$I.PT*("`@('T-"@T*("`@("\O
M('U]?0T*("`@("\O('M[>R!D:7-P;&%Y2&5A9&EN9RAT:71L92D-"@T*("`@
M(&9U;F-T:6]N(&1I<W!L87E(96%D:6YG*"1T:71L92D-"B`@("![#0H@("`@
M("`@('1R:6=G97)?97)R;W(H(E!%05)?1G)O;G1E;F1?0TQ).CID:7-P;&%Y
M2&5A9&EN9R!D97!R96-A=&5D(BP@15]54T527T524D]2*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!?9&ES<&QA>4AE861I;F<H)'1I=&QE*0T*("`@('L-
M"B`@("`@("`@<')I;G0@)'1H:7,M/FQP+B1T:&ES+3YB;VQD*"1T:71L92DN
M(EQN(CL-"B`@("`@("`@<')I;G0@)'1H:7,M/FQP+G-T<E]R97!E870H(CTB
M+"!S=')L96XH)'1I=&QE*2DN(EQN(CL-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"@T*("`@("\J*@T*("`@("`J($EN<W1R=6-T('1H92!R=6Y);G-T86QL4V-R
M:7!T(&UE=&AO9"!T;R!S:VEP(&$@<&%R86UG<F]U<"!T:&%T(&UA=&-H97,@
M=&AE#0H@("`@("H@:60@=F%L=64@<&%S<V5D(&EN+@T*("`@("`J#0H@("`@
M("H@5&AI<R!M971H;V0@:7,@=7-E9G5L(&9O<B!D>6YA;6EC86QL>2!C;VYF
M:6=U<FEN9R!W:&EC:"!S96-T:6]N<R!O9B!A('!O<W0M:6YS=&%L;"!S8W)I
M<'0-"B`@("`@*B!W:6QL(&)E(')U;B!B87-E9"!O;B!T:&4@=7-E<B=S('-E
M='5P+"!W:&EC:"!I<R!V97)Y('5S969U;"!F;W(@;6%K:6YG(&9L97AI8FQE
M#0H@("`@("H@<&]S="UI;G-T86QL('-C<FEP=',@=VET:&]U="!L;W-I;F<@
M=&AE(&-R;W-S+49R;VYT96YD(&%B:6QI='D@=&\@<F5T<FEE=F4@=7-E<B!I
M;G!U=`T*("`@("`J($!P87)A;2!S=')I;F<-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!S:VEP4&%R86UG<F]U<"@D:60I#0H@("`@>PT*("`@("`@("`D=&AI
M<RT^7W-K:7!396-T:6]N<ULD:61=(#T@=')U93L-"B`@("!]#0H-"B`@("!F
M=6YC=&EO;B!R=6Y0;W-T:6YS=&%L;%-C<FEP=',H)B1S8W)I<'1S*0T*("`@
M('L-"B`@("`@("`@9F]R96%C:"`H)'-C<FEP=',@87,@)&D@/3X@)'-C<FEP
M="D@>PT*("`@("`@("`@("`@)'1H:7,M/G)U;DEN<W1A;&Q38W)I<'0H)'-C
M<FEP='-;)&E=+3Y?<&%R86US+"`D<V-R:7!T<ULD:5TM/E]O8FHI.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y
M("1X;6P@8V]N=&5N=',@;V8@<&]S=&EN<W1A;&QS8W)I<'0@=&%G#0H@("`@
M("H@0'!A<F%M(&]B:F5C="`D<V-R:7!T('!O<W0M:6YS=&%L;&%T:6]N('-C
M<FEP=`T*("`@("`J($!P87)A;2!S=')I;F<@:6YS=&%L;'QU<&=R861E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@<G5N26YS=&%L;%-C<FEP="@D>&UL+"`F
M)'-C<FEP="D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<VMI<%-E8W1I;VYS
M(#T@87)R87DH*3L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D>&UL*2!\?"`A
M:7-S970H)'AM;%LG<&%R86UG<F]U<"==*2D@>PT*("`@("`@("`@("`@)'-C
M<FEP="T^<G5N*&%R<F%Y*"DL("=?9&5F875L="<I.PT*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)&-O;7!L971E9%!H87-E<R`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1X;6Q;)W!A<F%M9W)O=7`G75LP
M72DI('L-"B`@("`@("`@("`@("`@("`D>&UL6R=P87)A;6=R;W5P)UT@/2!A
M<G)A>2@D>&UL6R=P87)A;6=R;W5P)UTI.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)'AM;%LG<&%R86UG<F]U<"==(&%S("1G<F]U
M<"D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W-K:7!3
M96-T:6]N<ULD9W)O=7!;)VED)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`O+R!T:&4@<&]S="UI;G-T86QL('-C<FEP="!C:&]S92!T;R!S:VEP('1H
M:7,@<V5C=&EO;B!D>6YA;6EC86QL>0T*("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1G<F]U<%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D<&%R86UN86UE(#T@97AP;&]D92@G.CHG+"`D9W)O=7!;)VYA;64G
M72D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D;&%S=&=R;W5P6R=I9"==
M("$]("1P87)A;6YA;65;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1G<F]U<%LG;F%M92==(#T@)'!A<F%M;F%M95LQ73L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;G-W97)S*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A;G-W97)S6R1G<F]U
M<%LG;F%M92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M=VET8V@@*"1G<F]U<%LG8V]N9&ET:6]N='EP92==*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)STG(#H-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D86YS=V5R<ULD9W)O=7!;
M)VYA;64G75T@(3T@)&=R;W5P6R=V86QU92==*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)R$])R`Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&%N<W=E<G-;)&=R;W5P6R=N86UE
M)UU=(#T]("1G<F]U<%LG=F%L=64G72D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E(#([#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E("=P<F5G7VUA=&-H)R`Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(4!P<F5G7VUA=&-H*"<O)R`N
M("1G<F]U<%LG=F%L=64G72`N("<O)RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1A;G-W97)S6R1G<F]U<%LG;F%M92==
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5F875L="`Z
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;CL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QA
M<W1G<F]U<"`]("1G<F]U<#L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&=R;W5P6R=I;G-T<G5C=&EO;G,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]D:7-P;&%Y*"1G<F]U<%LG:6YS=')U8W1I;VYS)UTI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1G<F]U<%LG<&%R86TG75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)&=R;W5P6R=P87)A;2==(#T@87)R87DH)&=R;W5P6R=P87)A;2==*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1G
M<F]U<%LG<&%R86TG72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&UE
M=&AO9%]E>&ES=',H)'-C<FEP="P@)W!O<W10<F]C97-S4')O;7!T<R<I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D<')O;7!T<R`]("1S8W)I<'0M
M/G!O<W10<F]C97-S4')O;7!T<R@D9W)O=7!;)W!A<F%M)UTL("1G<F]U<%LG
M:60G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y
M*"1P<F]M<'1S*2!\?"!C;W5N="@D<')O;7!T<RD@(3T@8V]U;G0H)&=R;W5P
M6R=P87)A;2==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YO=71P=71$871A*"=P;W-T:6YS=&%L;"<L("=%<G)O<CH@<&]S="UI
M;G-T86QL('-C<FEP="!D:60@;F]T("<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G<F5T=7)N('!R;W!E<B!P;W-T+7!R;V-E<W-E9"!P
M<F]M<'1S)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;VUP
M=',@/2`D9W)O=7!;)W!A<F%M)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1P<F]M<'1S(&%S("1I(#T^("1V87(I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D=F%R*2!\?"`A:7-S
M970H)'9A<ELG<')O;7!T)UTI('Q\#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("%I<W-E="@D=F%R6R=N86UE)UTI('Q\#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D=F%R6R=N86UE
M)UT@(3T@)&=R;W5P6R=P87)A;2==6R1I75LG;F%M92==*2!\?`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`H)'9A<ELG='EP92==
M("$]("1G<F]U<%LG<&%R86TG75LD:5U;)W1Y<&4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A
M*"=P;W-T:6YS=&%L;"<L("=%<G)O<CH@<&]S="UI;G-T86QL('-C<FEP="`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;6]D:69I960@=&AE('9A<FEA8FQE<R!O<B!P<F]M<'1S+"!S979E<F4@<V5C
M=7)I='D@<FES:RX@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)U=I;&P@:6YS=&5A9"!U<V4@=&AE(&1E9F%U;'1S(&9R
M;VT@=&AE('!A8VMA9V4N>&UL)RD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<')O;7!T<R`]("1G<F]U<%LG<&%R86TG73L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A;G-W97)S(#T@)'1H:7,M/F-O
M;F9I<FU$:6%L;V<H)'!R;VUP=',I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%N<W=E<G,@/2`D
M=&AI<RT^8V]N9FER;41I86QO9R@D9W)O=7!;)W!A<F%M)UTI.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(&EF("@H:7-S970H)&%N<W=E<G,I("8F("1A;G-W97)S*2!\?"`A
M:7-S970H)&=R;W5P6R=P87)A;2==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1A;G-W97)S*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)&%N<W=E<G,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W5N<VAI9G0H)&-O;7!L
M971E9%!H87-E<RP@)&=R;W5P6R=I9"==*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*"$D<V-R:7!T+3YR=6XH)&%N<W=E<G,L("1G<F]U<%LG:60G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S8W)I<'0M/G)U;B@D8V]M
M<&QE=&5D4&AA<V5S+"`G7W5N9&]/;D5R<F]R)RD[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D
M<V-R:7!T+3YR=6XH)&-O;7!L971E9%!H87-E<RP@)U]U;F1O3VY%<G)O<B<I
M.PT*("`@("`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+RHJ#0H@("`@("H@07-K(&9O<B!U<V5R(&EN<'5T+"!C;VYF:7)M('1H92!A
M;G-W97)S(&%N9"!C;VYT:6YU92!U;G1I;"!T:&4@=7-E<B!I<R!S871I<V9I
M960-"B`@("`@*B!`<&%R86T@87)R87D@86X@87)R87D@;V8@87)R87ES+"!F
M;W)M870@87)R87DH)VYA;64G(#T^("=P87)A;6YA;64G+"`G<')O;7!T)R`]
M/@T*("`@("`J("`@("`@("`@("`@("`G=&5X="!T;R!D:7-P;&%Y)RP@)W1Y
M<&4G(#T^("=S=')I;F<G6RP@9&5F875L="`]/B`G9&5F875L="!V86QU92==
M*0T*("`@("`J($!R971U<FX@87)R87D-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!C;VYF:7)M1&EA;&]G*"1P87)A;7,I#0H@("`@>PT*("`@("`@("`D86YS
M=V5R<R`](&%R<F%Y*"D[#0H@("`@("`@("1P<F]M<'1S(#T@)'1Y<&5S(#T@
M87)R87DH*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D<&%R86TI
M('L-"B`@("`@("`@("`@("1P<F]M<'1S6R1P87)A;5LG;F%M92==72`]("1P
M87)A;5LG<')O;7!T)UT[#0H@("`@("`@("`@("`D='EP97-;)'!A<F%M6R=N
M86UE)UU=(#T@)'!A<F%M6R=T>7!E)UT[#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'!A<F%M6R=D969A=6QT)UTI*2![#0H@("`@("`@("`@("`@("`@)&%N
M<W=E<G-;)'!A<F%M6R=N86UE)UU=(#T@)'!A<F%M6R=D969A=6QT)UT[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1A;G-W97)S
M6R1P87)A;5LG;F%M92==72`]("<G.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(&1O('L-"B`@("`@("`@("`@("1O:R`](&%R<F%Y*"=Y
M97-N;R<@/3X@)VYO)RD[#0H@("`@("`@("`@("!D;R![#0H@("`@("`@("`@
M("`@("`@)&%N<W=E<G,@/2`D=&AI<RT^=7-E<D1I86QO9R@G)RP@)'!R;VUP
M=',L("1T>7!E<RP@)&%N<W=E<G,I.PT*("`@("`@("`@("`@?2!W:&EL92`H
M8V]U;G0H87)R87E?9FEL=&5R*"1A;G-W97)S*2D@(3T@8V]U;G0H)'!R;VUP
M=',I*3L-"B`@("`@("`@("`@("1T:&ES+3YO=71P=71$871A*"=9;W5R(&-H
M;VEC97,Z)RD[#0H@("`@("`@("`@("!F;W)E86-H("@D<')O;7!T<R!A<R`D
M;F%M92`]/B`D<')O;7!T*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U
M='!U=$1A=&$H)'!R;VUP="`N("<Z("<@+B`D86YS=V5R<ULD;F%M95TI.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&]K(#T@)'1H:7,M/G5S97)$
M:6%L;V<H)R<L#0H@("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@
M("`@("`@("`@("=Y97-N;R<@/3X@)U1H97-E($-H;VEC97,@3TL_("AU<V4@
M(F%B;W)T(B!T;R!H86QT*2<-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G>65S;F\G
M(#T^("=S=')I;F<G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=Y97-N;R<@/3X@
M)WEE<R<-"B`@("`@("`@("`@("`@("`I#0H@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@:68@*"1O:ULG>65S;F\G72`]/2`G86)O<G0G*2![#0H@("`@
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]('=H:6QE("@D;VM;)WEE<VYO)UT@(3T@)WEE<R<I.PT*("`@("`@
M("!R971U<FX@)&%N<W=E<G,[#0H@("`@?0T*("`@("\O('M[>R!U<V5R1&EA
M;&]G*'!R;VUP="P@6W1Y<&5=+"!;9&5F875L=%TI#0H-"B`@("!F=6YC=&EO
M;B!U<V5R1&EA;&]G*"1C;VUM86YD+"`D<')O;7!T<RP@)'1Y<&5S(#T@87)R
M87DH*2P@)&1E9F%U;'1S(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@("1R
M97-U;'0@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-?87)R87DH)'!R;VUP
M=',I*2![#0H@("`@("`@("`@("`O+R!P:'`@-2XP+C`@:6YE>'!L:6-A8FQY
M(&)R96%K<R!"0R!W:71H('1H:7,@8F5H879I;W(-"B`@("`@("`@("`@("\O
M(&YO=R!R96%D:6YG(&9R;VT@4U1$24X@:7,@=&AE(&EN=&5N9&5D('-Y;G1A
M>`T*("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92AP:'!V97)S:6]N
M*"DL("<U+C`N,"<L("<\)RDI('L-"B`@("`@("`@("`@("`@("`D9G`@/2!F
M;W!E;B@B<&AP.B\O<W1D:6XB+"`B<B(I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)'!R;VUP=',@87,@)&ME>2`]/B`D<')O;7!T
M*2![#0H@("`@("`@("`@("`@("`@)'1Y<&4@/2`D='EP97-;)&ME>5T[#0H@
M("`@("`@("`@("`@("`@)&1E9F%U;'0@/2!`)&1E9F%U;'1S6R1K97E=.PT*
M("`@("`@("`@("`@("`@(&EF("@D='EP92`]/2`G<&%S<W=O<F0G*2![#0H@
M("`@("`@("`@("`@("`@("`@('-Y<W1E;2@G<W1T>2`M96-H;R<I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!P<FEN="`B)'1H:7,M
M/FQP)'!R;VUP="`B.PT*("`@("`@("`@("`@("`@(&EF("@D9&5F875L="D@
M>PT*("`@("`@("`@("`@("`@("`@("!P<FEN="`B6R1D969A=6QT72`B.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!P<FEN="`B.B`B
M.PT*("`@("`@("`@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R
M<VEO;B@I+"`G-2XP+C`G+"`G/"<I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1L:6YE(#T@9F=E=',H)&9P+"`R,#0X*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(61E9FEN960H)U-4
M1$E.)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&1E9FEN92@G4U1$
M24XG+"!F;W!E;B@G<&AP.B\O<W1D:6XG+"`G<B<I*3L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;&EN92`](&9G971S
M*%-41$E.+"`R,#0X*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<I('L-"B`@("`@("`@("`@
M("`@("`@("`@<WES=&5M*"=S='1Y(&5C:&\G*3L-"B`@("`@("`@("`@("`@
M("`@("`@<')I;G0@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*"1D969A=6QT("8F('1R:6TH)&QI;F4I(#T]("(B*2![
M#0H@("`@("`@("`@("`@("`@("`@("1R97-U;'1;)&ME>5T@/2`D9&5F875L
M=#L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT6R1K97E=(#T@=')I;2@D;&EN92D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'9E<G-I
M;VY?8V]M<&%R92AP:'!V97)S:6]N*"DL("<U+C`N,"<L("<\)RDI('L-"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)')E<W5L=#L-"B`@("!]#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@=7-E<D-O;F9I<FTH<')O;7!T+"!;9&5F
M875L=%TI#0H-"B`@("!F=6YC=&EO;B!U<V5R0V]N9FER;2@D<')O;7!T+"`D
M9&5F875L="`]("=Y97,G*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O
M<B@B4$5!4E]&<F]N=&5N9%]#3$DZ.G5S97)#;VYF:7)M(&YO="!Y970@8V]N
M=F5R=&5D(BP@15]54T527T524D]2*3L-"B`@("`@("`@<W1A=&EC("1P;W-I
M=&EV97,@/2!A<G)A>2@G>2<L("=Y97,G+"`G;VXG+"`G,2<I.PT*("`@("`@
M("!S=&%T:6,@)&YE9V%T:79E<R`](&%R<F%Y*"=N)RP@)VYO)RP@)V]F9B<L
M("<P)RD[#0H@("`@("`@('!R:6YT("(D=&AI<RT^;'`D<')O;7!T(%LD9&5F
M875L=%T@.B`B.PT*("`@("`@("`D9G`@/2!F;W!E;B@B<&AP.B\O<W1D:6XB
M+"`B<B(I.PT*("`@("`@("`D;&EN92`](&9G971S*"1F<"P@,C`T."D[#0H@
M("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`D86YS=V5R(#T@<W1R=&]L
M;W=E<BAT<FEM*"1L:6YE*2D[#0H@("`@("`@(&EF("AE;7!T>2@D86YS=V5R
M*2D@>PT*("`@("`@("`@("`@)&%N<W=E<B`]("1D969A=6QT.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("AI;E]A<G)A>2@D86YS=V5R+"`D<&]S:71I=F5S
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&EN7V%R<F%Y*"1A;G-W97(L("1N96=A=&EV97,I*2![#0H@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&EN7V%R<F%Y*"1D969A=6QT+"`D<&]S:71I=F5S*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!S=&%R
M=%1A8FQE*%MP87)A;7-=*0T*#0H@("`@9G5N8W1I;VX@<W1A<G1486)L92@D
M<&%R86US(#T@87)R87DH*2D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R
M;W(H(E!%05)?1G)O;G1E;F1?0TQ).CIS=&%R=%1A8FQE(&1E<')E8V%T960B
M+"!%7U5315)?15)23U(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]S=&%R
M=%1A8FQE*"1P87)A;7,@/2!A<G)A>2@I*0T*("`@('L-"B`@("`@("`@)'!A
M<F%M<ULG=&%B;&5?9&%T82==(#T@87)R87DH*3L-"B`@("`@("`@)'!A<F%M
M<ULG=VED97-T)UT@/2!A<G)A>2@I.R`@+R\@:6YD97AE9"!B>2!C;VQU;6X-
M"B`@("`@("`@)'!A<F%M<ULG:&EG:&5S="==(#T@87)R87DH*3L@+R\@:6YD
M97AE9"!B>2!R;W<-"B`@("`@("`@)'!A<F%M<ULG;F-O;',G72`](#`[#0H@
M("`@("`@("1T:&ES+3YP87)A;7,@/2`D<&%R86US.PT*("`@('T-"@T*("`@
M("\O('U]?0T*("`@("\O('M[>R!T86)L95)O=RAC;VQU;6YS+"!;<F]W<&%R
M86US72P@6V-O;'!A<F%M<UTI#0H-"B`@("!F=6YC=&EO;B!T86)L95)O=R@D
M8V]L=6UN<RP@)')O=W!A<F%M<R`](&%R<F%Y*"DL("1C;VQP87)A;7,@/2!A
M<G)A>2@I*0T*("`@('L-"B`@("`@("`@=')I9V=E<E]E<G)O<B@B4$5!4E]&
M<F]N=&5N9%]#3$DZ.G1A8FQE4F]W(&1E<')E8V%T960B+"!%7U5315)?15)2
M3U(I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]T86)L95)O=R@D8V]L=6UN
M<RP@)')O=W!A<F%M<R`](&%R<F%Y*"DL("1C;VQP87)A;7,@/2!A<G)A>2@I
M*0T*("`@('L-"B`@("`@("`@)&AI9VAE<W0@/2`Q.PT*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!S:7IE;V8H)&-O;'5M;G,I.R`D:2LK*2![#0H@("`@
M("`@("`@("`D8V]L(#T@)B1C;VQU;6YS6R1I73L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D8V]L<&%R86US6R1I72D@)B8@(65M<'1Y*"1C;VQP87)A;7-;
M)&E=6R=W<F%P)UTI*2![#0H@("`@("`@("`@("`@("`@)&-O;"`]('=O<F1W
M<F%P*"1C;VPL("1C;VQP87)A;7-;)&E=6R=W<F%P)UTL(")<;B(L(#`I.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*'-T<G!O<R@D8V]L+"`B
M7&XB*2`A/3T@9F%L<V4I('L-"B`@("`@("`@("`@("`@("`D;75L=&EL:6YE
M(#T@97AP;&]D92@B7&XB+"`D8V]L*3L-"B`@("`@("`@("`@("`@("`D=R`]
M(#`[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UU;'1I;&EN92!A<R`D
M;B`]/B`D;&EN92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R;&5N
M*"1L:6YE*2`^("1W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=R`]
M('-T<FQE;B@D;&EN92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&QI;F5S(#T@<VEZ96]F
M*"1M=6QT:6QI;F4I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D=R`]('-T<FQE;B@D8V]L*3L-"B`@("`@("`@("`@('T-"@T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP87)A;7-;)W=I9&5S="==
M6R1I72DI('L-"B`@("`@("`@("`@("`@("!I9B`H)'<@/B`D=&AI<RT^<&%R
M86US6R=W:61E<W0G75LD:5TI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G!A<F%M<ULG=VED97-T)UU;)&E=(#T@)'<[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^<&%R86US6R=W:61E<W0G75LD:5T@/2`D=SL-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T;7`@/2!C;W5N=%]C:&%R<R@D8V]L=6UN<ULD
M:5TL(#$I.PT*("`@("`@("`@("`@+R\@:&%N9&QE('5N:7@L(&UA8R!A;F0@
M=VEN9&]W<R!F;W)M871S#0H@("`@("`@("`@("`D;&EN97,@/2`H:7-S970H
M)'1M<%LQ,%TI(#\@)'1M<%LQ,%T@.B`H:7-S970H)'1M<%LQ,UTI(#\@)'1M
M<%LQ,UT@.B`P*2D@*R`Q.PT*("`@("`@("`@("`@:68@*"1L:6YE<R`^("1H
M:6=H97-T*2![#0H@("`@("`@("`@("`@("`@)&AI9VAE<W0@/2`D;&EN97,[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I>F5O
M9B@D8V]L=6UN<RD@/B`D=&AI<RT^<&%R86US6R=N8V]L<R==*2![#0H@("`@
M("`@("`@("`D=&AI<RT^<&%R86US6R=N8V]L<R==(#T@<VEZ96]F*"1C;VQU
M;6YS*3L-"B`@("`@("`@?0T*("`@("`@("`D;F5W7W)O=R`](&%R<F%Y*`T*
M("`@("`@("`@("`@)V1A=&$G(#T^("1C;VQU;6YS+`T*("`@("`@("`@("`@
M)VAE:6=H="<@/3X@)&AI9VAE<W0L#0H@("`@("`@("`@("`G<F]W<&%R86US
M)R`]/B`D<F]W<&%R86US+`T*("`@("`@("`@("`@)V-O;'!A<F%M<R<@/3X@
M)&-O;'!A<F%M<RP-"B`@("`@("`@("`@("D[#0H@("`@("`@("1T:&ES+3YP
M87)A;7-;)W1A8FQE7V1A=&$G75M=(#T@)&YE=U]R;W<[#0H@("`@?0T*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&5N9%1A8FQE*"D-"@T*("`@(&9U;F-T
M:6]N(&5N9%1A8FQE*"D-"B`@("![#0H@("`@("`@('1R:6=G97)?97)R;W(H
M(E!%05)?1G)O;G1E;F1?0TQ).CIE;F1486)L92!D97!R96-A=&5D(BP@15]5
M4T527T524D]2*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!?96YD5&%B;&4H
M*0T*("`@('L-"B`@("`@("`@97AT<F%C="@D=&AI<RT^<&%R86US*3L-"B`@
M("`@("`@:68@*"%E;7!T>2@D8V%P=&EO;BDI('L-"B`@("`@("`@("`@("1T
M:&ES+3Y?9&ES<&QA>4AE861I;F<H)&-A<'1I;VXI.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AC;W5N="@D=&%B;&5?9&%T82D@/3T@,"D@>PT*("`@("`@
M("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H
M)'=I9'1H*2D@>PT*("`@("`@("`@("`@)'=I9'1H(#T@)'=I9&5S=#L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1N8V]L<SL@)&DK*RD@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)'=I9'1H6R1I72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'=I9'1H6R1I
M72`]("1W:61E<W1;)&E=.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@("`D8F]R9&5R(#T@9F%L<V4[#0H@
M("`@("`@(&EF("AE;7!T>2@D8F]R9&5R*2D@>PT*("`@("`@("`@("`@)&-E
M;&QS=&%R="`]("<G.PT*("`@("`@("`@("`@)&-E;&QE;F0@/2`G("<[#0H@
M("`@("`@("`@("`D<F]W96YD(#T@)R<[#0H@("`@("`@("`@("`D<&%D<F]W
M96YD(#T@9F%L<V4[#0H@("`@("`@("`@("`D8F]R9&5R;&EN92`]("<G.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&-E;&QS=&%R="`]("=\
M("<[#0H@("`@("`@("`@("`D8V5L;&5N9"`]("<@)SL-"B`@("`@("`@("`@
M("1R;W=E;F0@/2`G?"<[#0H@("`@("`@("`@("`D<&%D<F]W96YD(#T@=')U
M93L-"B`@("`@("`@("`@("1B;W)D97)L:6YE(#T@)RLG.PT*("`@("`@("`@
M("`@9F]R96%C:"`H)'=I9'1H(&%S("1W*2![#0H@("`@("`@("`@("`@("`@
M)&)O<F1E<FQI;F4@+CT@<W1R7W)E<&5A="@G+2<L("1W("L@<W1R;&5N*"1C
M96QL<W1A<G0I("L@<W1R;&5N*"1C96QL96YD*2`M(#$I.PT*("`@("`@("`@
M("`@("`@("1B;W)D97)L:6YE("X]("<K)SL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H)&)O<F1E<FQI;F4I('L-"B`@("`@("`@
M("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O<F1E<FQI;F4I.PT*("`@("`@
M("!]#0H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&%B;&5?
M9&%T82D[("1I*RLI('L-"B`@("`@("`@("`@(&5X=')A8W0H)'1A8FQE7V1A
M=&%;)&E=*3L-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)')O=W!A<F%M
M<RDI('L-"B`@("`@("`@("`@("`@("`D<F]W<&%R86US(#T@87)R87DH*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?87)R87DH)&-O
M;'!A<F%M<RDI('L-"B`@("`@("`@("`@("`@("`D8V]L<&%R86US(#T@87)R
M87DH*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1R;W=L:6YE<R`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("!I9B`H)&AE:6=H="`^(#$I('L-"B`@
M("`@("`@("`@("`@("!F;W(@*"1C(#T@,#L@)&,@/"!S:7IE;V8H)&1A=&$I
M.R`D8RLK*2![#0H@("`@("`@("`@("`@("`@("`@("1R;W=L:6YE<ULD8UT@
M/2!P<F5G7W-P;&ET*"<O*%QR/UQN?%QR*2\G+"`D9&%T85LD8UTI.PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R;W=L:6YE<ULD8UTI(#P@
M)&AE:6=H="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')O=VQI;F5S
M6R1C72`](&%R<F%Y7W!A9"@D<F]W;&EN97-;)&-=+"`D:&5I9VAT+"`G)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&9O<B`H)&,@
M/2`P.R`D8R`\('-I>F5O9B@D9&%T82D[("1C*RLI('L-"B`@("`@("`@("`@
M("`@("`@("`@)')O=VQI;F5S6R1C72`](&%R<F%Y*"1D871A6R1C72D[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R("@D<B`](#`[("1R(#P@)&AE:6=H=#L@)'(K*RD@>PT*("`@("`@("`@
M("`@("`@("1R;W=T97AT(#T@)R<[#0H@("`@("`@("`@("`@("`@9F]R("@D
M8R`](#`[("1C(#P@<VEZ96]F*"1D871A*3L@)&,K*RD@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&-O;'!A<F%M<ULD8UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D871T<FEB<R`](&%R<F%Y7VUE<F=E*"1R
M;W=P87)A;7,L("1C;VQP87)A;7,I.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G,@/2`D
M<F]W<&%R86US.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1W(#T@:7-S970H)'=I9'1H6R1C72D@/R`D=VED=&A;)&-=
M(#H@,#L-"B`@("`@("`@("`@("`@("`@("`@+R\D8V5L;"`]("1D871A6R1C
M73L-"B`@("`@("`@("`@("`@("`@("`@)&-E;&P@/2`D<F]W;&EN97-;)&-=
M6R1R73L-"B`@("`@("`@("`@("`@("`@("`@)&P@/2!S=')L96XH)&-E;&PI
M.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&P@/B`D=RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-E;&P@/2!S=6)S='(H)&-E;&PL(#`L("1W
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&%T=')I8G-;)V)O;&0G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1C96QL(#T@)'1H:7,M/F)O;&0H)&-E;&PI.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M;"`\("1W*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!N;W0@=7-I
M;F<@<W1R7W!A9"!H97)E(&)E8V%U<V4@=V4@;6%Y#0H@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!A9&0@8F]L9"!E<V-A<&4@8VAA<F%C=&5R<R!T;R`D
M8V5L;`T*("`@("`@("`@("`@("`@("`@("`@("`@)&-E;&P@+CT@<W1R7W)E
M<&5A="@G("<L("1W("T@)&PI.PT*("`@("`@("`@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@("`@("`@("`@)')O=W1E>'0@+CT@)&-E;&QS=&%R="`N
M("1C96QL("X@)&-E;&QE;F0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("@A)&)O<F1E<BD@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F]W=&5X="`](')T<FEM*"1R;W=T97AT*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)')O=W1E>'0@+CT@)')O=V5N9#L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1R;W=T97AT*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&)O<F1E
M<FQI;F4I('L-"B`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&)O
M<F1E<FQI;F4I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&]U='!U=$1A=&$H*0T*#0H@("`@9G5N8W1I;VX@;W5T<'5T
M1&%T82@D9&%T82P@)&-O;6UA;F0@/2`G7V1E9F%U;'0G*0T*("`@('L-"B`@
M("`@("`@<W=I=&-H("@D8V]M;6%N9"D@>PT*("`@("`@("`@("`@8V%S92`G
M8VAA;FYE;"UI;F9O)SH-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D9&%T
M82!A<R`D='EP92`]/B`D<V5C=&EO;BD@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H)'1Y<&4@/3T@)VUA:6XG*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<V5C=&EO;ELG9&%T82==(#T@87)R87E?=F%L=65S*"1S96-T:6]N
M6R=D871A)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YO=71P=71$871A*"1S96-T:6]N*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("!C87-E("=I;G-T86QL)SH-"B`@("`@("`@("`@(&-A<V4@)W5P9W)A
M9&4G.@T*("`@("`@("`@("`@8V%S92`G=7!G<F%D92UA;&PG.@T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG<F5L96%S95]W87)N:6YG<R==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE
M*"<G*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S=&%R=%1A8FQE
M*&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M9F%L<V4L#0H@("`@("`@("`@("`@("`@("`@("`@("`G8V%P=&EO;B<@/3X@
M)U)E;&5A<V4@5V%R;FEN9W,G#0H@("`@("`@("`@("`@("`@("`@("`@("`I
M*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=RAA<G)A
M>2@D9&%T85LG<F5L96%S95]W87)N:6YG<R==*2P@;G5L;"P@87)R87DH,2`]
M/B!A<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]D:7-P;&%Y3&EN92@G)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&ES<&QA>4QI;F4H)&1A=&%;)V1A=&$G
M72D[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("!C87-E
M("=S96%R8V@G.@T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<W1A<G1486)L
M92@D9&%T82D[#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D871A6R=H
M96%D;&EN92==*2`F)B!I<U]A<G)A>2@D9&%T85LG:&5A9&QI;F4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T85LG
M:&5A9&QI;F4G72P@87)R87DH)V)O;&0G(#T^('1R=64I+"!A<G)A>2@Q(#T^
M(&%R<F%Y*"=W<F%P)R`]/B`U-2DI*3L-"B`@("`@("`@("`@("`@("!]#0H-
M"B`@("`@("`@("`@("`@("!F;W)E86-H*"1D871A6R=D871A)UT@87,@)&-A
M=&5G;W)Y*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&-A=&5G
M;W)Y(&%S("1P:V<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%B;&52;W<H)'!K9RP@;G5L;"P@87)R87DH,2`]/B!A<G)A>2@G=W)A
M<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!].PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?96YD5&%B;&4H
M*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@
M)VQI<W0M86QL)SH-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B
M;&4H)&1A=&$I.PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG
M:&5A9&QI;F4G72D@)B8@:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;
M)VAE861L:6YE)UTL(&%R<F%Y*"=B;VQD)R`]/B!T<G5E*2P@87)R87DH,2`]
M/B!A<G)A>2@G=W)A<"<@/3X@-34I*2D[#0H@("`@("`@("`@("`@("`@?0T*
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1C
M871E9V]R>2D@>PT*("`@("`@("`@("`@("`@("`@("!F;W)E86-H*"1C871E
M9V]R>2!A<R`D<&MG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D<&MG6S1=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P
M:V=;-5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L
M95)O=R@D<&MG+"!N=6QL+"!A<G)A>2@Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`U
M-2DI*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F1486)L92@I.PT*("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G8V]N9FEG
M+7-H;W<G.@T*("`@("`@("`@("`@("`@("1D871A6R=B;W)D97(G72`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH,"`]/B!A<G)A
M>2@G=W)A<"<@/3X@,S`I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@,2`]/B!A<G)A>2@G=W)A<"<@/3X@,C`I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@,B`]/B!A<G)A>2@G=W)A<"<@/3X@,S4I*3L-"B`@
M("`@("`@("`@("`@("`D=&AI<RT^7W-T87)T5&%B;&4H)&1A=&$I.PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG:&5A9&QI;F4G72D@)B8@
M:7-?87)R87DH)&1A=&%;)VAE861L:6YE)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)&1A=&%;)VAE861L:6YE)UTL#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O
M;&0G(#T^('1R=64I+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1O<'1S*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@9F]R96%C:"@D9&%T85LG9&%T82==(&%S("1G<F]U<"D@>PT*("`@
M("`@("`@("`@("`@("`@("!F;W)E86-H*"1G<F]U<"!A<R`D=F%L=64I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D=F%L=65;,ET@/3T@)R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=65;,ET@/2`B
M/&YO="!S970^(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)'9A;'5E+"!N
M=6QL+"`D;W!T<RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E;F1486)L92@I
M.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92`G
M<F5M;W1E+6EN9F\G.@T*("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G4&%C:V%G92!D
M971A:6QS.B<L#0H@("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^(&9A
M;'-E+`T*("`@("`@("`@("`@("`@("`@("`G9&%T82<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@B3&%T97-T(BP@("`@)&1A
M=&%;)W-T86)L92==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*"));G-T86QL960B+"`D9&%T85LG:6YS=&%L;&5D)UTI+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH(E!A8VMA9V4B+"`@("1D871A6R=N86UE
M)UTI+`T*("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH(DQI8V5N<V4B
M+"`@("1D871A6R=L:6-E;G-E)UTI+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH(D-A=&5G;W)Y(BP@("1D871A6R=C871E9V]R>2==*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*")3=6UM87)Y(BP@("`D9&%T
M85LG<W5M;6%R>2==*2P-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*")$97-C<FEP=&EO;B(L("1D871A6R=D97-C<FEP=&EO;B==*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@("`@("D[
M#0H@("`@("`@("`@("!D969A=6QT.B![#0H@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1D871A*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-T87)T5&%B;&4H)&1A=&$I.PT*("`@("`@("`@("`@("`@("`@("`D
M8V]U;G0@/2!C;W5N="@D9&%T85LG9&%T82==6S!=*3L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1C;W5N="`]/2`R*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D;W!T<R`](&%R<F%Y*#`@/3X@87)R87DH)W=R87`G(#T^(#(U
M*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,2`]
M/B!A<G)A>2@G=W)A<"<@/3X@-#@I#0H@("`@("`@("`@("`@("`@("`@("`@
M("`I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&-O=6YT(#T]
M(#,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1O<'1S(#T@87)R87DH
M,"`]/B!A<G)A>2@G=W)A<"<@/3X@,S`I+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Q(#T^(&%R<F%Y*"=W<F%P)R`]/B`R,"DL
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#(@/3X@
M87)R87DH)W=R87`G(#T^(#,U*0T*("`@("`@("`@("`@("`@("`@("`@("`@
M*3L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1O<'1S(#T@;G5L;#L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1A=&%;)VAE
M861L:6YE)UTI("8F(&ES7V%R<F%Y*"1D871A6R=H96%D;&EN92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L95)O=R@D9&%T
M85LG:&5A9&QI;F4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V)O;&0G(#T^('1R=64I+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T<RD[#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C
M:"@D9&%T85LG9&%T82==(&%S("1R;W<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=&%B;&52;W<H)')O=RP@;G5L;"P@)&]P=',I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?96YD5&%B;&4H*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1I<W!L87E,:6YE*"1D871A
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@;&]G*'1E>'0I
M#0H-"@T*("`@(&9U;F-T:6]N(&QO9R@D=&5X="P@)&%P<&5N9%]C<FQF(#T@
M=')U92D-"B`@("![#0H@("`@("`@(&EF("@D87!P96YD7V-R;&8I('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1I<W!L87E,:6YE*"1T97AT*3L-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]D:7-P;&%Y*"1T
M97AT*3L-"B`@("!]#0H-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!B;VQD
M*"1T97AT*0T*#0H@("`@9G5N8W1I;VX@8F]L9"@D=&5X="D-"B`@("![#0H@
M("`@("`@(&EF("AE;7!T>2@D=&AI<RT^=&5R;5LG8F]L9"==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N('-T<G1O=7!P97(H)'1E>'0I.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^=&5R;5LG8F]L9"==("X@)'1E>'0@
M+B`D=&AI<RT^=&5R;5LG;F]R;6%L)UT[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0I]#0H-"C\^#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]215-4+S$Q+G!H<```````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S0V-B`Q,#4Q-30S
M-#$S-"`P,C`W,S8`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`-"B\J*@T*("H@4$5!4E]215-47S$Q("T@:6UP;&5M
M96YT(&9A<W1E<B!L:7-T+6%L;"]R96UO=&4M;&ES="!C;VUM86YD#0H@*@T*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(#$Q+G!H<"QV(#$N
M-"`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C,-
M"B`J+PT*#0HO*BH-"B`J($9O<B!D;W=N;&]A9&EN9R!215-4('AM;"]T>'0@
M9FEL97,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+U)%4U0N<&AP)SL-"@T*
M+RHJ#0H@*B!);7!L96UE;G0@4D535"`Q+C$-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'
M<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q
M.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC
M92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XS#0H@
M*B\-"F-L87-S(%!%05)?4D535%\Q,0T*>PT*("`@("\J*@T*("`@("`J($!V
M87(@4$5!4E]215-4#0H@("`@("HO#0H@("`@=F%R("1?<F5S=#L-"@T*("`@
M(&9U;F-T:6]N(%!%05)?4D535%\Q,2@D8V]N9FEG+"`D;W!T:6]N<R`](&%R
M<F%Y*"DI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7W)E<W0@/2`F;F5W(%!%
M05)?4D535"@D8V]N9FEG+"`D;W!T:6]N<RD[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@;&ES=$%L;"@D8F%S92P@)&1O<W1A8FQE+"`D8F%S:6,@/2!T<G5E
M*0T*("`@('L-"B`@("`@("`@)&-A=&5G;W)Y;&ES="`]("1T:&ES+3Y?<F5S
M="T^<F5T<FEE=F5$871A*"1B87-E("X@)V,O8V%T96=O<FEE<RYX;6PG*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-A=&5G;W)Y;&ES="DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D8V%T96=O<GEL:7-T.PT*("`@("`@("!]
M#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1C871E9V]R>6QI<W1;)V,G72DI('L-"B`@("`@("`@("`@("1C871E
M9V]R>6QI<W1;)V,G72`](&%R<F%Y*"1C871E9V]R>6QI<W1;)V,G72D[#0H@
M("`@("`@('T-"B`@("`@("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!
M4E]%4E)/4E]215154DXI.PT*("`@("`@("!F;W)E86-H("@D8V%T96=O<GEL
M:7-T6R=C)UT@87,@)'!R;V=R97-S(#T^("1C871E9V]R>2D@>PT*("`@("`@
M("`@("`@)&-A=&5G;W)Y(#T@)&-A=&5G;W)Y6R=?8V]N=&5N="==.PT*("`@
M("`@("`@("`@)'!A8VMA9V5S:6YF;R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE
M=F5$871A*"1B87-E("X-"B`@("`@("`@("`@("`@("`G8R\G("X@=7)L96YC
M;V1E*"1C871E9V]R>2D@+B`G+W!A8VMA9V5S:6YF;RYX;6PG*3L-"B`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P86-K86=E<VEN9F\I*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P86-K86=E<VEN9F\I('Q\("%I<W-E
M="@D<&%C:V%G97-I;F9O6R=P:2==*2D@>PT*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]A
M<G)A>2@D<&%C:V%G97-I;F9O6R=P:2==*2!\?"`A:7-S970H)'!A8VMA9V5S
M:6YF;ULG<&DG75LP72DI('L-"B`@("`@("`@("`@("`@("`D<&%C:V%G97-I
M;F9O6R=P:2==(#T@87)R87DH)'!A8VMA9V5S:6YF;ULG<&DG72D[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D<&%C:V%G97-I;F9O
M6R=P:2==(&%S("1P86-K86=E:6YF;RD@>PT*("`@("`@("`@("`@("`@("1I
M;F9O(#T@)'!A8VMA9V5I;F9O6R=P)UT[#0H@("`@("`@("`@("`@("`@)'!A
M8VMA9V4@/2`D:6YF;ULG;B==.PT*("`@("`@("`@("`@("`@("1R96QE87-E
M<R`](&ES<V5T*"1P86-K86=E:6YF;ULG82==*2`_("1P86-K86=E:6YF;ULG
M82==(#H@9F%L<V4[#0H@("`@("`@("`@("`@("`@=6YS970H)&QA=&5S="D[
M#0H@("`@("`@("`@("`@("`@=6YS970H)'5N<W1A8FQE*3L-"B`@("`@("`@
M("`@("`@("!U;G-E="@D<W1A8FQE*3L-"B`@("`@("`@("`@("`@("!U;G-E
M="@D<W1A=&4I.PT*("`@("`@("`@("`@("`@(&EF("@D<F5L96%S97,I('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<F5L96%S97-;)W(G
M75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1R96QE87-E<ULG
M<B==(#T@87)R87DH)')E;&5A<V5S6R=R)UTI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R96QE87-E
M<ULG<B==(&%S("1R96QE87-E*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1D;W-T86)L92`F)B`D<F5L96%S95LG<R==(#T]("=S
M=&%B;&4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1L
M871E<W0@/2`D<F5L96%S95LG=B==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1A=&4@/2`G<W1A8FQE)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"$D9&]S=&%B;&4I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&QA=&5S="`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1S=&%T92`]("1R96QE87-E6R=S)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<W1A8FQE*2`F)B`D<F5L96%S95LG<R==(#T]("=S=&%B;&4G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T86)L92`]("1R96QE87-E
M6R=V)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1U;G-T86)L92`]("1S=&%B;&4[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=6YS=&%B;&4I("8F("1R
M96QE87-E6R=S)UT@(3T@)W-T86)L92<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;&%T97-T(#T@)'5N<W1A8FQE(#T@)')E;&5A<V5;)W8G
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`D<F5L
M96%S95LG<R==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1L871E<W0I("8F("%I<W-E
M="@D<W1A=&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T
M871E(#T@)')E;&5A<V5;)W,G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;&%T97-T
M*2`F)B!I<W-E="@D<W1A8FQE*2`F)B!I<W-E="@D=6YS=&%B;&4I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1B87-I8RD@>R`O
M+R!R96UO=&4M;&ES="!C;VUM86YD#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1L871E<W0@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D<F5T6R1P86-K86=E72`](&%R<F%Y*"=S=&%B
M;&4G(#T^("1L871E<W0I.PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@+R\@;&ES
M="UA;&P@8V]M;6%N9`T*("`@("`@("`@("`@("`@("1D97!S(#T@87)R87DH
M*3L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1U;G-T86)L92DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'5N<W1A8FQE(#T@9F%L<V4[#0H@("`@
M("`@("`@("`@("`@("`@("1S=&%T92`]("=S=&%B;&4G.PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'-T86)L92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1L871E<W0@/2`D=6YS=&%B;&4@/2`D<W1A8FQE.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1U;G-T86)L93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@
M9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("@D;&%T97-T*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M<&%C:V%G96EN9F];)V1E<',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-?87)R87DH)'!A8VMA9V5I;F9O6R=D97!S)UTI('Q\#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`A:7-S970H)'!A8VMA9V5I
M;F9O6R=D97!S)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A8VMA9V5I;F9O6R=D97!S)UT@/2!A<G)A>2@D<&%C:V%G96EN9F];
M)V1E<',G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&0@/2!F86QS
M93L-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5I;F9O
M6R=D97!S)UT@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1D97!;)W8G72`]/2`D;&%T97-T*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&0@/2!U;G-E<FEA;&EZ92@D9&5P6R=D)UTI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@D9"D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D6R=R97%U:7)E9"==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27U!A8VMA9V5&:6QE7W8R)RDI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R
M+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!F*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&8@/2!N97<@4$5!4E]0
M86-K86=E1FEL95]V,CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!F+3YS971$97!S*"1D
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&1E<',@/2`D<&8M
M/F=E=$1E<',H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1D97!S(#T@)&0[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D=&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D9&5P6R=T>7!E)UT@(3T]("=P:V<G*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P<UM=(#T@)&1E<#L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S=&%B;&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@("1S=&%B;&4@/2`G+6XO82TG.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D:6YF;R`](&%R
M<F%Y*"=S=&%B;&4G(#T^("1L871E<W0L("=S=6UM87)Y)R`]/B`D:6YF;ULG
M<R==+`T*("`@("`@("`@("`@("`@("`@("`G9&5S8W)I<'1I;VXG(#T^#0H@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R=D)UTL("=D97!S)R`]/B`D9&5P
M<RP@)V-A=&5G;W)Y)R`]/B`D:6YF;ULG8V$G75LG7V-O;G1E;G0G72P-"B`@
M("`@("`@("`@("`@("`@("`@)W5N<W1A8FQE)R`]/B`D=6YS=&%B;&4L("=S
M=&%T92<@/3X@)'-T871E*3L-"B`@("`@("`@("`@("`@("`D<F5T6R1P86-K
M86=E72`]("1I;F9O.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@<F5T=7)N
M("1R970[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5T=7)N(&%N(&%R
M<F%Y(&-O;G1A:6YI;F<@86QL(&]F('1H92!S=&%T97,@=&AA="!A<F4@;6]R
M92!S=&%B;&4@=&AA;@T*("`@("`J(&]R(&5Q=6%L('1O('1H92!P87-S960@
M:6X@<W1A=&4-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@4F5L96%S
M92!S=&%T90T*("`@("`J($!P87)A;2!B;V]L96%N($1E=&5R;6EN97,@=VAE
M=&AE<B!T;R!I;F-L=61E("1S=&%T92!I;B!T:&4@;&ES=`T*("`@("`J($!R
M971U<FX@9F%L<V5\87)R87D@1F%L<V4@:68@)'-T871E(&ES(&YO="!A('9A
M;&ED(')E;&5A<V4@<W1A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!B971T
M97)3=&%T97,H)'-T871E+"`D:6YC;'5D92`](&9A;'-E*0T*("`@('L-"B`@
M("`@("`@<W1A=&EC("1S=&%T97,@/2!A<G)A>2@G<VYA<'-H;W0G+"`G9&5V
M96PG+"`G86QP:&$G+"`G8F5T82<L("=S=&%B;&4G*3L-"B`@("`@("`@)&D@
M/2!A<G)A>5]S96%R8V@H)'-T871E+"`D<W1A=&5S*3L-"B`@("`@("`@:68@
M*"1I(#T]/2!F86QS92D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@D:6YC;'5D92D@>PT*("`@("`@("`@
M("`@)&DM+3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@87)R87E?<VQI
M8V4H)'-T871E<RP@)&D@*R`Q*3L-"B`@("!]#0I]#0H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O
M4D535"\Q,"YP:'``````````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P-C$S,#(@,3`U,34T,S0Q,S0@,#(P-S(Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP#0HO*BH-"B`J(%!%
M05)?4D535%\Q,`T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*
M("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H
M92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP
M+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P
M#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S
M7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B`Q,"YP:'`L=B`Q+C0P(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G
M($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C0N,&$Q,@T*("HO#0H-"B\J*@T*("H@1F]R(&1O=VYL
M;V%D:6YG(%)%4U0@>&UL+W1X="!F:6QE<PT*("HO#0IR97%U:7)E7V]N8V4@
M)U!%05(O4D535"YP:'`G.PT*#0HO*BH-"B`J($EM<&QE;65N="!215-4(#$N
M,`T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%
M05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XT+C!A,3(-"B`J+PT*8VQA<W,@4$5!4E]215-47S$P
M#0I[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!014%27U)%4U0-"B`@("`@*B\-
M"B`@("!V87(@)%]R97-T.PT*("`@(&9U;F-T:6]N(%!%05)?4D535%\Q,"@D
M8V]N9FEG+"`D;W!T:6]N<R`](&%R<F%Y*"DI#0H@("`@>PT*("`@("`@("`D
M=&AI<RT^7W)E<W0@/2`F;F5W(%!%05)?4D535"@D8V]N9FEG+"`D;W!T:6]N
M<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T1&]W;FQO86154DPH)&)A
M<V4L("1P86-K86=E:6YF;RP@)'!R969S=&%T92P@)&EN<W1A;&QE9"D-"B`@
M("![#0H@("`@("`@("1C:&%N;F5L(#T@)'!A8VMA9V5I;F9O6R=C:&%N;F5L
M)UT[#0H@("`@("`@("1P86-K86=E(#T@)'!A8VMA9V5I;F9O6R=P86-K86=E
M)UT[#0H@("`@("`@("1S=&%T97,@/2`D=&AI<RT^8F5T=&5R4W1A=&5S*"1P
M<F5F<W1A=&4L('1R=64I.PT*("`@("`@("!I9B`H(21S=&%T97,I('L-"B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"<B)R`N("1P<F5F
M<W1A=&4@+B`G(B!I<R!N;W0@82!V86QI9"!S=&%T92<I.PT*("`@("`@("!]
M#0H@("`@("`@("1S=&%T92`]("1V97)S:6]N(#T@;G5L;#L-"B`@("`@("`@
M:68@*&ES<V5T*"1P86-K86=E:6YF;ULG<W1A=&4G72DI('L-"B`@("`@("`@
M("`@("1S=&%T92`]("1P86-K86=E:6YF;ULG<W1A=&4G73L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5I;F9O6R=V97)S:6]N)UTI
M*2![#0H@("`@("`@("`@("`D=F5R<VEO;B`]("1P86-K86=E:6YF;ULG=F5R
M<VEO;B==.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O(#T@)'1H:7,M/E]R
M97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D
M<&%C:V%G92D@+B`G+V%L;')E;&5A<V5S+GAM;"<I.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=.;R!R96QE87-E<R!A=F%I;&%B;&4@9F]R('!A
M8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("1C:&%N;F5L("X@)R\G("X@
M)'!A8VMA9V4@+B`G(B<I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S
M970H)&EN9F];)W(G72DI('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-
M"B`@("`@("`@?0T*("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@
M)')E;&5A<V4@/2!F86QS93L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:6YF
M;ULG<B==*2!\?"`A:7-S970H)&EN9F];)W(G75LP72DI('L-"B`@("`@("`@
M("`@("1I;F9O6R=R)UT@/2!A<G)A>2@D:6YF;ULG<B==*3L-"B`@("`@("`@
M?0T*("`@("`@("!F;W)E86-H("@D:6YF;ULG<B==(&%S("1R96QE87-E*2![
M#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<F5S="T^7V]P=&EO
M;G-;)V9O<F-E)UTI("8F("@D:6YS=&%L;&5D("8F#0H@("`@("`@("`@("`@
M("`@("!V97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;)W8G72P@)&EN<W1A;&QE
M9"P@)SPG*2DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D<W1A=&4I*2![#0H@
M("`@("`@("`@("`@("`@:68@*"1R96QE87-E6R=S)UT@/3T@)'-T871E*2![
M#0H@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T@96QS96EF("AI<W-E="@D=F5R<VEO;BDI('L-"B`@("`@("`@
M("`@("`@("!I9B`H)')E;&5A<V5;)W8G72`]/2`D=F5R<VEO;BD@>PT*("`@
M("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D<F5L
M96%S95LG<R==+"`D<W1A=&5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F5T=7)N1&]W;FQO86154DPH)&)A<V4L
M("1P86-K86=E+"`D<F5L96%S92P@)&EN9F\L("1F;W5N9"D[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T1&5P1&]W;FQO86154DPH)&)A<V4L("1X<V1V
M97)S:6]N+"`D9&5P96YD96YC>2P@)&1E<'!A8VMA9V4L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!R969S=&%T92`]("=S=&%B;&4G+"`D
M:6YS=&%L;&5D(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D8VAA;FYE;"`]
M("1D97!E;F1E;F-Y6R=C:&%N;F5L)UT[#0H@("`@("`@("1P86-K86=E(#T@
M)&1E<&5N9&5N8WE;)VYA;64G73L-"B`@("`@("`@)'-T871E<R`]("1T:&ES
M+3YB971T97)3=&%T97,H)'!R969S=&%T92P@=')U92D[#0H@("`@("`@(&EF
M("@A)'-T871E<RD@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E
M17)R;W(H)R(G("X@)'!R969S=&%T92`N("<B(&ES(&YO="!A('9A;&ED('-T
M871E)RD[#0H@("`@("`@('T-"B`@("`@("`@)'-T871E(#T@)'9E<G-I;VX@
M/2!N=6QL.PT*("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5I;F9O6R=S=&%T
M92==*2D@>PT*("`@("`@("`@("`@)'-T871E(#T@)'!A8VMA9V5I;F9O6R=S
M=&%T92==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%C:V%G
M96EN9F];)W9E<G-I;VXG72DI('L-"B`@("`@("`@("`@("1V97)S:6]N(#T@
M)'!A8VMA9V5I;F9O6R=V97)S:6]N)UT[#0H@("`@("`@('T-"B`@("`@("`@
M)&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N("=R
M+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O86QL<F5L96%S97,N>&UL
M)RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U!A8VMA9V4@(B<@
M+B`D9&5P<&%C:V%G95LG8VAA;FYE;"==("X@)R\G("X@)&1E<'!A8VMA9V5;
M)W!A8VMA9V4G70T*("`@("`@("`@("`@("`@("X@)R(@9&5P96YD96YC>2`B
M)R`N("1C:&%N;F5L("X@)R\G("X@)'!A8VMA9V4@+B`G(B!H87,@;F\@<F5L
M96%S97,G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I
M;F9O*2!\?"`A:7-S970H)&EN9F];)W(G72DI('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D97AC;'5D92`](&%R
M<F%Y*"D[#0H@("`@("`@("1M:6X@/2`D;6%X(#T@)')E8V]M;65N9&5D(#T@
M9F%L<V4[#0H@("`@("`@(&EF("@D>'-D=F5R<VEO;B`]/2`G,2XP)RD@>PT*
M("`@("`@("`@("`@)'!I;F9O6R=P86-K86=E)UT@/2`D9&5P96YD96YC>5LG
M;F%M92==.PT*("`@("`@("`@("`@)'!I;F9O6R=C:&%N;F5L)UT@/2`G<&5A
M<BYP:'`N;F5T)SL@+R\@=&AI<R!I<R!A;'=A>7,@=')U92`M(&1O;B=T(&-H
M86YG92!T:&ES#0H@("`@("`@("`@("!S=VET8V@@*"1D97!E;F1E;F-Y6R=R
M96PG72D@>PT*("`@("`@("`@("`@("`@(&-A<V4@)V=E)R`Z#0H@("`@("`@
M("`@("`@("`@("`@("1M:6X@/2`D9&5P96YD96YC>5LG=F5R<VEO;B==.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@
M)V=T)R`Z#0H@("`@("`@("`@("`@("`@("`@("1M:6X@/2`D9&5P96YD96YC
M>5LG=F5R<VEO;B==.PT*("`@("`@("`@("`@("`@("`@("`D97AC;'5D92`]
M(&%R<F%Y*"1D97!E;F1E;F-Y6R=V97)S:6]N)UTI.PT*("`@("`@("`@("`@
M("`@(&)R96%K.PT*("`@("`@("`@("`@("`@(&-A<V4@)V5Q)R`Z#0H@("`@
M("`@("`@("`@("`@("`@("1R96-O;6UE;F1E9"`]("1D97!E;F1E;F-Y6R=V
M97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@
M("`@("`@8V%S92`G;'0G(#H-"B`@("`@("`@("`@("`@("`@("`@)&UA>"`]
M("1D97!E;F1E;F-Y6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@
M("1E>&-L=61E(#T@87)R87DH)&1E<&5N9&5N8WE;)W9E<G-I;VXG72D[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@8V%S92`G
M;&4G(#H-"B`@("`@("`@("`@("`@("`@("`@)&UA>"`]("1D97!E;F1E;F-Y
M6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@8V%S92`G;F4G(#H-"B`@("`@("`@("`@("`@("`@("`@)&5X
M8VQU9&4@/2!A<G)A>2@D9&5P96YD96YC>5LG=F5R<VEO;B==*3L-"B`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1P:6YF;ULG<&%C:V%G92==(#T@)&1E<&5N
M9&5N8WE;)VYA;64G73L-"B`@("`@("`@("`@("1M:6X@/2!I<W-E="@D9&5P
M96YD96YC>5LG;6EN)UTI(#\@)&1E<&5N9&5N8WE;)VUI;B==(#H@9F%L<V4[
M#0H@("`@("`@("`@("`D;6%X(#T@:7-S970H)&1E<&5N9&5N8WE;)VUA>"==
M*2`_("1D97!E;F1E;F-Y6R=M87@G72`Z(&9A;'-E.PT*("`@("`@("`@("`@
M)')E8V]M;65N9&5D(#T@:7-S970H)&1E<&5N9&5N8WE;)W)E8V]M;65N9&5D
M)UTI(#\-"B`@("`@("`@("`@("`@("`D9&5P96YD96YC>5LG<F5C;VUM96YD
M960G72`Z(&9A;'-E.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!E;F1E
M;F-Y6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D9&5P96YD96YC>5LG97AC;'5D92==6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D97AC;'5D92`](&%R<F%Y*"1D97!E;F1E;F-Y6R=E>&-L=61E
M)UTI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@)')E;&5A
M<V4@/2!F86QS93L-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D:6YF;ULG<B==
M*2!\?"`A:7-S970H)&EN9F];)W(G75LP72DI('L-"B`@("`@("`@("`@("1I
M;F9O6R=R)UT@/2!A<G)A>2@D:6YF;ULG<B==*3L-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D:6YF;ULG<B==(&%S("1R96QE87-E*2![#0H@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?<F5S="T^7V]P=&EO;G-;)V9O
M<F-E)UTI("8F("@D:6YS=&%L;&5D("8F#0H@("`@("`@("`@("`@("`@("!V
M97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;)W8G72P@)&EN<W1A;&QE9"P@)SPG
M*2DI('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D<F5L96%S95LG=B==+"`D
M97AC;'5D92DI('L@+R\@<VMI<"!E>&-L=61E9"!V97)S:6]N<PT*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@+R\@86QL;W<@;F5W97(@<F5L96%S97,@=&\@<V%Y(")))VT@3TL@=VET
M:"!T:&4@9&5P96YD96YT('!A8VMA9V4B#0H@("`@("`@("`@("!I9B`H)'AS
M9'9E<G-I;VX@/3T@)S(N,"<@)B8@:7-S970H)')E;&5A<V5;)V-O)UTI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S95LG8V\G
M72D@?'P@(6ES<V5T*"1R96QE87-E6R=C;R==6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<F5L96%S95LG8V\G72`](&%R<F%Y*"1R96QE87-E6R=C
M;R==*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)')E;&5A<V5;)V-O)UT@87,@)&5N=')Y*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D96YT<GE;)W@G72D@)B8@(6ES7V%R<F%Y
M*"1E;G1R>5LG>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5N
M=')Y6R=X)UT@/2!A<G)A>2@D96YT<GE;)W@G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@A:7-S970H)&5N=')Y6R=X)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D96YT<GE;)W@G72`](&%R<F%Y*"D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1E;G1R>5LG8R==(#T]("1D97!P86-K86=E6R=C:&%N;F5L)UT@)B8-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@<W1R=&]L;W=E<B@D96YT<GE;)W`G
M72D@/3T@<W1R=&]L;W=E<B@D9&5P<&%C:V%G95LG<&%C:V%G92==*2`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H)&1E
M<'!A8VMA9V5;)W9E<G-I;VXG72P@)&5N=')Y6R=M:6XG72P@)SX])RD@)B8-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@=F5R<VEO;E]C;VUP87)E*"1D
M97!P86-K86=E6R=V97)S:6]N)UTL("1E;G1R>5LG;6%X)UTL("<\/2<I("8F
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("%I;E]A<G)A>2@D<F5L96%S
M95LG=B==+"`D96YT<GE;)W@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1R96-O;6UE;F1E9"`]("1R96QE87-E6R=V)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&EF("@D<F5C;VUM96YD960I('L-"B`@("`@("`@("`@("`@("!I9B`H)')E
M;&5A<V5;)W8G72`A/2`D<F5C;VUM96YD960I('L@+R\@:68@=V4@=V%N="!A
M('-P96-I9FEC#0H@("`@("`@("`@("`@("`@("`@("\O('9E<G-I;VXL('1H
M96X@<VMI<"!A;&P@;W1H97)S#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@A:6Y?87)R87DH)')E;&5A<V5;)W,G72P@)'-T871E<RDI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O('1H92!S=&%B:6QI='D@
M:7,@=&]O(&QO=RP@8G5T('=E(&UU<W0@<F5T=7)N('1H90T*("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@<F5C;VUM96YD960@=F5R<VEO;B!I9B!P;W-S
M:6)L90T*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F5T=7)N1&]W;FQO86154DPH)&)A<V4L("1P86-K86=E+"`D<F5L96%S92P@
M)&EN9F\L('1R=64I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1M
M:6X@)B8@=F5R<VEO;E]C;VUP87)E*"1R96QE87-E6R=V)UTL("1M:6XL("=L
M="<I*2![("\O('-K:7`@=&]O(&]L9"!V97)S:6]N<PT*("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@
M*"1M87@@)B8@=F5R<VEO;E]C;VUP87)E*"1R96QE87-E6R=V)UTL("1M87@L
M("=G="<I*2![("\O('-K:7`@=&]O(&YE=R!V97)S:6]N<PT*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*"1I;G-T86QL960@)B8@=F5R<VEO;E]C;VUP87)E*"1R96QE87-E6R=V
M)UTL("1I;G-T86QL960L("<\)RDI('L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI;E]A<G)A
M>2@D<F5L96%S95LG<R==+"`D<W1A=&5S*2D@>R`O+R!I9B!I;B!T:&4@<')E
M9F5R<F5D('-T871E+BXN#0H@("`@("`@("`@("`@("`@)&9O=6YD(#T@=')U
M93L@+R\@+BXN('1H96X@=7-E(&ET#0H@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F5T=7)N1&]W;FQO86154DPH)&)A<V4L("1P86-K86=E+"`D<F5L
M96%S92P@)&EN9F\L("1F;W5N9"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@
M7W)E='5R;D1O=VYL;V%D55),*"1B87-E+"`D<&%C:V%G92P@)')E;&5A<V4L
M("1I;F9O+"`D9F]U;F0I#0H@("`@>PT*("`@("`@("!I9B`H(21F;W5N9"D@
M>PT*("`@("`@("`@("`@)')E;&5A<V4@/2`D:6YF;ULG<B==6S!=.PT*("`@
M("`@("!]#0H@("`@("`@("1R96QE87-E:6YF;R`]("1T:&ES+3Y?<F5S="T^
M<F5T<FEE=F5#86-H949I<G-T*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H
M)'!A8VMA9V4I("X@)R\G("X@#0H@("`@("`@("`@("`D<F5L96%S95LG=B==
M("X@)RYX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E;&5A
M<V5I;F9O*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R
M;W(H)U!A8VMA9V4@(B<@+B`D<&%C:V%G92`N("<B(%9E<G-I;VX@(B<@+B`D
M<F5L96%S95LG=B==("X-"B`@("`@("`@("`@("`@("`G(B!D;V5S(&YO="!H
M879E(%)%4U0@>&UL(&%V86EL86)L92<I.PT*("`@("`@("!]#0H@("`@("`@
M("1P86-K86=E>&UL(#T@)'1H:7,M/E]R97-T+3YR971R:65V94-A8VAE1FER
M<W0H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@+B`G+R<@
M+@T*("`@("`@("`@("`@)V1E<',N)R`N("1R96QE87-E6R=V)UT@+B`G+G1X
M="<L(&9A;'-E+"!T<G5E*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)'!A8VMA9V5X;6PI*2![#0H@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I
M<V5%<G)O<B@G4&%C:V%G92`B)R`N("1P86-K86=E("X@)R(@5F5R<VEO;B`B
M)R`N("1R96QE87-E6R=V)UT@+@T*("`@("`@("`@("`@("`@("<B(&1O97,@
M;F]T(&AA=F4@4D535"!D97!E;F1E;F-Y(&EN9F]R;6%T:6]N(&%V86EL86)L
M92<I.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E>&UL(#T@=6YS97)I
M86QI>F4H)'!A8VMA9V5X;6PI.PT*("`@("`@("!I9B`H(21P86-K86=E>&UL
M*2![#0H@("`@("`@("`@("`D<&%C:V%G97AM;"`](&%R<F%Y*"D[#0H@("`@
M("`@('T-"B`@("`@("`@)&%L;&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E=')I
M979E1&%T82@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N
M#0H@("`@("`@("`@("`G+V%L;')E;&5A<V5S+GAM;"<I.PT*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1A;&QI;F9O6R=R)UTI('Q\("%I<W-E="@D86QL:6YF
M;ULG<B==6S!=*2D@>PT*("`@("`@("`@("`@)&%L;&EN9F];)W(G72`](&%R
M<F%Y*"1A;&QI;F9O6R=R)UTI.PT*("`@("`@("!]#0H@("`@("`@("1C;VUP
M871I8FQE(#T@9F%L<V4[#0H@("`@("`@(&9O<F5A8V@@*"1A;&QI;F9O6R=R
M)UT@87,@)')E;&5A<V4I('L-"B`@("`@("`@("`@(&EF("@D<F5L96%S95LG
M=B==("$]("1R96QE87-E:6YF;ULG=B==*2![#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1R96QE87-E6R=C;R==*2D@>PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-O;7!A=&EB;&4@/2!A
M<G)A>2@I.PT*("`@("`@("`@("`@:68@*"%I<U]A<G)A>2@D<F5L96%S95LG
M8V\G72D@?'P@(6ES<V5T*"1R96QE87-E6R=C;R==6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("1R96QE87-E6R=C;R==(#T@87)R87DH)')E;&5A<V5;)V-O
M)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)')E
M;&5A<V5;)V-O)UT@87,@)&5N=')Y*2![#0H@("`@("`@("`@("`@("`@)&-O
M;7`@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@("1C;VUP6R=N86UE)UT@
M/2`D96YT<GE;)W`G73L-"B`@("`@("`@("`@("`@("`D8V]M<%LG8VAA;FYE
M;"==(#T@)&5N=')Y6R=C)UT[#0H@("`@("`@("`@("`@("`@)&-O;7!;)VUI
M;B==(#T@)&5N=')Y6R=M:6XG73L-"B`@("`@("`@("`@("`@("`D8V]M<%LG
M;6%X)UT@/2`D96YT<GE;)VUA>"==.PT*("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D96YT<GE;)W@G72D@)B8@(6ES7V%R<F%Y*"1E;G1R>5LG>"==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D8V]M<%LG97AC;'5D92==(#T@)&5N
M=')Y6R=X)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1C;VUP871I8FQE6UT@/2`D8V]M<#L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("AC;W5N="@D8V]M<&%T:6)L92D@/3T@,2D@>PT*("`@("`@
M("`@("`@("`@("1C;VUP871I8FQE(#T@)&-O;7!A=&EB;&5;,%T[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&9O=6YD*2![#0H@("`@("`@("`@("!R971U<FX@#0H@("`@
M("`@("`@("`@("`@87)R87DH)W9E<G-I;VXG(#T^("1R96QE87-E:6YF;ULG
M=B==+`T*("`@("`@("`@("`@("`@("`@("`@("=I;F9O)R`]/B`D<&%C:V%G
M97AM;"P-"B`@("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)')E
M;&5A<V5I;F9O6R=P)UU;)U]C;VYT96YT)UTL#0H@("`@("`@("`@("`@("`@
M("`@("`@)W-T86)I;&ET>2<@/3X@)')E;&5A<V5I;F9O6R=S="==+`T*("`@
M("`@("`@("`@("`@("`@("`@("=U<FPG(#T^("1R96QE87-E:6YF;ULG9R==
M+`T*("`@("`@("`@("`@("`@("`@("`@("=C;VUP871I8FQE)R`]/B`D8V]M
M<&%T:6)L92D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U
M<FX-"B`@("`@("`@("`@("`@("!A<G)A>2@G=F5R<VEO;B<@/3X@)')E;&5A
M<V5I;F9O6R=V)UTL#0H@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M(#T^("1R96QE87-E:6YF;ULG<"==6R=?8V]N=&5N="==+`T*("`@("`@("`@
M("`@("`@("`@("`@("=S=&%B:6QI='DG(#T^("1R96QE87-E:6YF;ULG<W0G
M72P-"B`@("`@("`@("`@("`@("`@("`@("`G:6YF;R<@/3X@)'!A8VMA9V5X
M;6PL#0H@("`@("`@("`@("`@("`@("`@("`@)V-O;7!A=&EB;&4G(#T^("1C
M;VUP871I8FQE*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&QI<W1086-K86=E<R@D8F%S92D-"B`@("![#0H@("`@("`@("1P86-K86=E
M;&ES="`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@)W`O
M<&%C:V%G97,N>&UL)RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P
M86-K86=E;&ES="DI('L-"B`@("`@("`@("`@(')E='5R;B`D<&%C:V%G96QI
M<W0[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G
M96QI<W0I('Q\("%I<W-E="@D<&%C:V%G96QI<W1;)W`G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@(&EF
M("@A:7-?87)R87DH)'!A8VMA9V5L:7-T6R=P)UTI*2![#0H@("`@("`@("`@
M("`D<&%C:V%G96QI<W1;)W`G72`](&%R<F%Y*"1P86-K86=E;&ES=%LG<"==
M*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'!A8VMA9V5L:7-T6R=P
M)UT[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@;&ES=$%L;"@D8F%S92P@)&1O
M<W1A8FQE+"`D8F%S:6,@/2!T<G5E+"`D<V5A<F-H<&%C:V%G92`](&9A;'-E
M+"`D<V5A<F-H<W5M;6%R>2`](&9A;'-E*0T*("`@('L-"B`@("`@("`@)'!A
M8VMA9V5L:7-T(#T@)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@
M+B`G<"]P86-K86=E<RYX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)'!A8VMA9V5L:7-T*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1P86-K
M86=E;&ES=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M/E]R97-T
M+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@,"D@>PT*("`@("`@("`@("`@
M)'5I(#T@)E!%05)?1G)O;G1E;F0Z.G-I;F=L971O;B@I.PT*("`@("`@("`@
M("`@)'5I+3YL;V<H)U)E=')I979I;F<@9&%T82XN+C`E)RP@9F%L<V4I.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@/2!A<G)A>2@I.PT*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1P86-K86=E;&ES="D@?'P@(6ES<V5T*"1P86-K86=E
M;&ES=%LG<"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1R970[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"%I<U]A<G)A>2@D<&%C:V%G96QI<W1;)W`G
M72DI('L-"B`@("`@("`@("`@("1P86-K86=E;&ES=%LG<"==(#T@87)R87DH
M)'!A8VMA9V5L:7-T6R=P)UTI.PT*("`@("`@("!]#0H@("`@("`@(%!%05(Z
M.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@)&YE>'0@/2`N,3L-"B`@("`@("`@9F]R96%C:"`H)'!A8VMA9V5L:7-T
M6R=P)UT@87,@)'!R;V=R97-S(#T^("1P86-K86=E*2![#0H@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]R97-T+3YC;VYF:6<M/F=E="@G=F5R8F]S92<I(#X@
M,"D@>PT*("`@("`@("`@("`@("`@(&EF("@D<')O9W)E<W,@+R!C;W5N="@D
M<&%C:V%G96QI<W1;)W`G72D@/CT@)&YE>'0I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"1N97AT(#T]("XU*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D=6DM/FQO9R@G-3`E)RP@9F%L<V4I.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'5I+3YL
M;V<H)RXG+"!F86QS92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@)&YE>'0@*ST@+C$[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1B87-I8RD@>R`O
M+R!R96UO=&4M;&ES="!C;VUM86YD#0H@("`@("`@("`@("`@("`@:68@*"1D
M;W-T86)L92D@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)'1H
M:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L
M;W=E<B@D<&%C:V%G92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R]S
M=&%B;&4N='AT)RD[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@)&QA=&5S="`]("1T:&ES+3Y?<F5S="T^<F5T<FEE
M=F5$871A*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X-
M"B`@("`@("`@("`@("`@("`@("`@("`@("<O;&%T97-T+G1X="<I.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T97-T
M(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1I;F9O(#T@87)R87DH)W-T86)L92<@/3X@)&QA=&5S="D[#0H@("`@("`@
M("`@("!](&5L<V4@>R`O+R!L:7-T+6%L;"!C;VUM86YD#0H@("`@("`@("`@
M("`@("`@)&EN9B`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E
M("X@)W`O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I("X@)R]I;F9O+GAM;"<I
M.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F8I*2![
M#0H@("`@("`@("`@("`@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H
M*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1I;F8[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<V5A<F-H<&%C:V%G
M92D@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2`H(65M<'1Y*"1S
M96%R8VAP86-K86=E*2`F)B!S=')I<W1R*"1P86-K86=E+"`D<V5A<F-H<&%C
M:V%G92D@(3T](&9A;'-E*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"$D
M9F]U;F0@)B8@(2AI<W-E="@D<V5A<F-H<W5M;6%R>2D@)B8@(65M<'1Y*"1S
M96%R8VAS=6UM87)Y*0T*("`@("`@("`@("`@("`@("`@("`@("`@)B8@*'-T
M<FES='(H)&EN9ELG<R==+"`D<V5A<F-H<W5M;6%R>2D@(3T](&9A;'-E#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?'P@<W1R:7-T<B@D:6YF6R=D
M)UTL("1S96%R8VAS=6UM87)Y*2`A/3T@9F%L<V4I*2D-"B`@("`@("`@("`@
M("`@("`@("`@>PT*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[
M#0H@("`@("`@("`@("`@("`@("`@('T[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1R96QE87-E<R`]("1T:&ES+3Y?<F5S="T^<F5T
M<FEE=F5$871A*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H)'!A8VMA9V4I
M("X-"B`@("`@("`@("`@("`@("`@("`@)R]A;&QR96QE87-E<RYX;6PG*3L-
M"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5L96%S97,I
M*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R96QE87-E
M<ULG<B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<F5L96%S97-;
M)W(G72`](&%R<F%Y*"1R96QE87-E<ULG<B==*3L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@=6YS970H)&QA=&5S="D[#0H@("`@("`@
M("`@("`@("`@=6YS970H)'5N<W1A8FQE*3L-"B`@("`@("`@("`@("`@("!U
M;G-E="@D<W1A8FQE*3L-"B`@("`@("`@("`@("`@("!U;G-E="@D<W1A=&4I
M.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R96QE87-E<ULG<B==(&%S
M("1R96QE87-E*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&]S
M=&%B;&4@)B8@)')E;&5A<V5;)W,G72`]/2`G<W1A8FQE)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D<F5L96%S95LG=B==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]("=S=&%B
M;&4G.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"$D9&]S=&%B;&4I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;&%T97-T(#T@)')E;&5A<V5;)W8G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`D<F5L96%S95LG<R==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-T86)L
M92D@)B8@)')E;&5A<V5;)W,G72`]/2`G<W1A8FQE)RD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T86)L92`]("1R96QE87-E6R=V)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1U;G-T86)L92DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=6YS=&%B;&4@/2`D<W1A
M8FQE.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'5N
M<W1A8FQE*2`F)B`D<F5L96%S95LG<R==("$]("=S=&%B;&4G*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D;&%T97-T(#T@)'5N<W1A8FQE(#T@)')E
M;&5A<V5;)W8G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S=&%T92`]
M("1R96QE87-E6R=S)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1L871E<W0I("8F("%I<W-E="@D
M<W1A=&4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2`D
M<F5L96%S95LG<R==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D;&%T97-T*2`F)B!I<W-E="@D<W1A
M8FQE*2`F)B!I<W-E="@D=6YS=&%B;&4I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D9&5P<R`](&%R<F%Y*"D[
M#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=6YS=&%B;&4I*2![#0H@
M("`@("`@("`@("`@("`@("`@("1U;G-T86)L92`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@("`@("`D<W1A=&4@/2`G<W1A8FQE)SL-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1S=&%B;&4I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D;&%T97-T(#T@)'5N<W1A8FQE(#T@)'-T86)L93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1L871E<W0@/2`D=6YS=&%B;&4[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`](&9A
M;'-E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H
M)&QA=&5S="D@>PT*("`@("`@("`@("`@("`@("`@("`D9"`]("1T:&ES+3Y?
M<F5S="T^<F5T<FEE=F5#86-H949I<G-T*"1B87-E("X@)W(O)R`N('-T<G1O
M;&]W97(H)'!A8VMA9V4I("X@)R]D97!S+B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)&QA=&5S="`N("<N='AT)RD[#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D9"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1D(#T@=6YS97)I86QI>F4H)&0I.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1D*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D6R=R97%U:7)E9"==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!
M4E]086-K86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O4&%C:V%G949I;&4O
M=C(N<&AP)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P
M9BDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M9B`](&YE=R!014%27U!A8VMA9V5&:6QE7W8R.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P9BT^<V5T1&5P<R@D9"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1T9&5P<R`]("1P9BT^9V5T1&5P<R@I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T9&5P<R`]("1D.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D=&1E<',@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1E<%LG='EP92==("$]/2`G<&MG)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<'-;72`]("1D97`[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-T86)L92DI
M('L-"B`@("`@("`@("`@("`@("`@("`@)'-T86)L92`]("<M;B]A+2<[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A)'-E87)C
M:'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F\@/2!A<G)A
M>2@G<W1A8FQE)R`]/B`D;&%T97-T+"`G<W5M;6%R>2<@/3X@)&EN9ELG<R==
M+"`G9&5S8W)I<'1I;VXG(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF6R=D)UTL("=D97!S)R`]/B`D9&5P<RP@)V-A=&5G;W)Y)R`]/B`D:6YF
M6R=C82==6R=?8V]N=&5N="==+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M)W5N<W1A8FQE)R`]/B`D=6YS=&%B;&4L("=S=&%T92<@/3X@)'-T871E*3L-
M"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`D:6YF;R`](&%R<F%Y*"=S=&%B;&4G(#T^("1S=&%B;&4L("=S=6UM87)Y
M)R`]/B`D:6YF6R=S)UTL("=D97-C<FEP=&EO;B<@/3X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9;)V0G72P@)V1E<',G(#T^("1D97!S+"`G8V%T
M96=O<GDG(#T^("1I;F9;)V-A)UU;)U]C;VYT96YT)UTL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G=6YS=&%B;&4G(#T^("1U;G-T86)L92P@)W-T871E
M)R`]/B`D<W1A=&4I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1R971;)'!A8VMA9V5=(#T@)&EN9F\[#0H@("`@
M("`@('T-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@
M("`@("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!L:7-T
M3&%T97-T57!G<F%D97,H)&)A<V4L("1S=&%T92P@)&EN<W1A;&QE9"P@)&-H
M86YN96PL("8D<F5G*0T*("`@('L-"B`@("`@("`@)'!A8VMA9V5L:7-T(#T@
M)'1H:7,M/E]R97-T+3YR971R:65V941A=&$H)&)A<V4@+B`G<"]P86-K86=E
M<RYX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!A8VMA9V5L
M:7-T*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1P86-K86=E;&ES=#L-"B`@
M("`@("`@?0T*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<&%C:V%G96QI<W0I('Q\("%I<W-E="@D<&%C:V%G96QI
M<W1;)W`G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*("`@("`@
M("!]#0H@("`@("`@(&EF("@A:7-?87)R87DH)'!A8VMA9V5L:7-T6R=P)UTI
M*2![#0H@("`@("`@("`@("`D<&%C:V%G96QI<W1;)W`G72`](&%R<F%Y*"1P
M86-K86=E;&ES=%LG<"==*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'-T
M871E*2![#0H@("`@("`@("`@("`D<W1A=&5S(#T@)'1H:7,M/F)E='1E<E-T
M871E<R@D<W1A=&4L('1R=64I.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1P86-K86=E;&ES=%LG<"==(&%S("1P86-K86=E*2![#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1I;G-T86QL961;<W1R=&]L;W=E<B@D<&%C:V%G
M92E=*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&EN<W1?=F5R<VEO;B`]("1R96<M/G!A8VMA
M9V5);F9O*"1P86-K86=E+"`G=F5R<VEO;B<L("1C:&%N;F5L*3L-"B`@("`@
M("`@("`@(%!%05(Z.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D54
M55).*3L-"B`@("`@("`@("`@("1I;F9O(#T@)'1H:7,M/E]R97-T+3YR971R
M:65V941A=&$H)&)A<V4@+B`G<B\G("X@<W1R=&]L;W=E<B@D<&%C:V%G92D@
M+@T*("`@("`@("`@("`@("`@("<O86QL<F5L96%S97,N>&UL)RD[#0H@("`@
M("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L@+R\@;F\@<F5M;W1E(')E;&5A<V5S#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=R)UTI*2![#0H@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D9F]U;F0@/2!F86QS93L-"B`@("`@("`@("`@("1R96QE87-E
M(#T@9F%L<V4[#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1I;F9O6R=R
M)UTI('Q\("%I<W-E="@D:6YF;ULG<B==6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("1I;F9O6R=R)UT@/2!A<G)A>2@D:6YF;ULG<B==*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O6R=R)UT@87,@)')E
M;&5A<V4I('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN<W1?=F5R<VEO;B`F
M)B!V97)S:6]N7V-O;7!A<F4H)')E;&5A<V5;)W8G72P@)&EN<W1?=F5R<VEO
M;BP@)SP])RDI('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D<W1A=&4I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1R96QE87-E
M6R=S)UTL("1S=&%T97,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@("`@("`D9F]U;F0@/2!T<G5E.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(21F;W5N9"D@>PT*("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)')E;&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E0V%C:&5&
M:7)S="@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O
M)R`N(`T*("`@("`@("`@("`@("`@("1R96QE87-E6R=V)UT@+B`G+GAM;"<I
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E;&EN9F\I*2![
M#0H@("`@("`@("`@("`@("`@<F5T=7)N("1R96QI;F9O.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)')E=%LD<&%C:V%G95T@/2!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^("1R96QE87-E6R=V)UTL
M#0H@("`@("`@("`@("`@("`@("`@("=S=&%T92<@/3X@)')E;&5A<V5;)W,G
M72P-"B`@("`@("`@("`@("`@("`@("`@)V9I;&5S:7IE)R`]/B`D<F5L:6YF
M;ULG9B==+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T-"B`@("`@
M("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<&%C:V%G
M94EN9F\H)&)A<V4L("1P86-K86=E*0T*("`@('L-"B`@("`@("`@4$5!4CHZ
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`D<&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E1&%T82@D8F%S92`N
M("=P+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*2`N("<O:6YF;RYX;6PG*3L-
M"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!I;F9O*2D@>PT*("`@("`@
M("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@
M<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U5N:VYO=VX@<&%C:V%G93H@(B<@
M+B`D<&%C:V%G92`N("<B("A$96)U9SH@)R`N#0H@("`@("`@("`@("`@("`@
M)'!I;F9O+3YG971-97-S86=E*"D@+B`G*2<I.PT*("`@("`@("!]#0H@("`@
M("`@("1R96QE87-E<R`](&%R<F%Y*"D[#0H@("`@("`@("1A;&QR96QE87-E
M<R`]("1T:&ES+3Y?<F5S="T^<F5T<FEE=F5$871A*"1B87-E("X@)W(O)R`N
M('-T<G1O;&]W97(H)'!A8VMA9V4I("X-"B`@("`@("`@("`@("<O86QL<F5L
M96%S97,N>&UL)RD[#0H@("`@("`@(&EF("@A4$5!4CHZ:7-%<G)O<B@D86QL
M<F5L96%S97,I*2![#0H@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]086-K86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("`@("`@<F5Q
M=6ER95]O;F-E("=014%2+U!A8VMA9V5&:6QE+W8R+G!H<"<[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A;&QR96QE87-E
M<ULG<B==*2D@>PT*("`@("`@("`@("`@("`@("1A;&QR96QE87-E<ULG<B==
M(#T@87)R87DH)&%L;')E;&5A<V5S6R=R)UTI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'!F(#T@;F5W(%!%05)?4&%C:V%G949I;&5?=C([#0H@
M("`@("`@("`@("!F;W)E86-H("@D86QL<F5L96%S97-;)W(G72!A<R`D<F5L
M96%S92D@>PT*("`@("`@("`@("`@("`@("1D<R`]("1T:&ES+3Y?<F5S="T^
M<F5T<FEE=F5#86-H949I<G-T*"1B87-E("X@)W(O)R`N('-T<G1O;&]W97(H
M)'!A8VMA9V4I("X@)R]D97!S+B<@+@T*("`@("`@("`@("`@("`@("`@("`D
M<F5L96%S95LG=B==("X@)RYT>'0G*3L-"B`@("`@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D9',I*2![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@("1L
M871E<W0@/2`D<F5L96%S95LG=B==.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D<&8M/G-E=$1E<',H=6YS97)I86QI>F4H)&1S*2D[
M#0H@("`@("`@("`@("`@("`@)&1S(#T@)'!F+3YG971$97!S*"D[#0H@("`@
M("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^7W)E<W0M/G)E=')I979E0V%C
M:&5&:7)S="@D8F%S92`N("=R+R<@+B!S=')T;VQO=V5R*"1P86-K86=E*0T*
M("`@("`@("`@("`@("`@("`@("`N("<O)R`N("1R96QE87-E6R=V)UT@+B`G
M+GAM;"<I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I
M;F9O*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)')E;&5A<V5S6R1R96QE
M87-E6R=V)UU=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=D;VYE
M8GDG(#T^("1I;F9O6R=M)UTL#0H@("`@("`@("`@("`@("`@("`@("=L:6-E
M;G-E)R`]/B`D:6YF;ULG;"==+`T*("`@("`@("`@("`@("`@("`@("`G<W5M
M;6%R>2<@/3X@)&EN9F];)W,G72P-"B`@("`@("`@("`@("`@("`@("`@)V1E
M<V-R:7!T:6]N)R`]/B`D:6YF;ULG9"==+`T*("`@("`@("`@("`@("`@("`@
M("`G<F5L96%S961A=&4G(#T^("1I;F9O6R=D82==+`T*("`@("`@("`@("`@
M("`@("`@("`G<F5L96%S96YO=&5S)R`]/B`D:6YF;ULG;B==+`T*("`@("`@
M("`@("`@("`@("`@("`G<W1A=&4G(#T^("1R96QE87-E6R=S)UTL#0H@("`@
M("`@("`@("`@("`@("`@("=D97!S)R`]/B`D9',@/R`D9',@.B!A<G)A>2@I
M+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D;&%T97-T(#T@)R<[#0H@("`@("`@
M('T-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("!R971U<FX@87)R87DH#0H@("`@("`@("`@("`G;F%M92<@/3X@)'!I;F9O
M6R=N)UTL#0H@("`@("`@("`@("`G8VAA;FYE;"<@/3X@)'!I;F9O6R=C)UTL
M#0H@("`@("`@("`@("`G8V%T96=O<GDG(#T^("1P:6YF;ULG8V$G75LG7V-O
M;G1E;G0G72P-"B`@("`@("`@("`@("=S=&%B;&4G(#T^("1L871E<W0L#0H@
M("`@("`@("`@("`G;&EC96YS92<@/3X@)'!I;F9O6R=L)UTL#0H@("`@("`@
M("`@("`G<W5M;6%R>2<@/3X@)'!I;F9O6R=S)UTL#0H@("`@("`@("`@("`G
M9&5S8W)I<'1I;VXG(#T^("1P:6YF;ULG9"==+`T*("`@("`@("`@("`@)W)E
M;&5A<V5S)R`]/B`D<F5L96%S97,L#0H@("`@("`@("`@("`I.PT*("`@('T-
M"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A;B!A<G)A>2!C;VYT86EN:6YG
M(&%L;"!O9B!T:&4@<W1A=&5S('1H870@87)E(&UO<F4@<W1A8FQE('1H86X-
M"B`@("`@*B!O<B!E<75A;"!T;R!T:&4@<&%S<V5D(&EN('-T871E#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG(%)E;&5A<V4@<W1A=&4-"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B!$971E<FUI;F5S('=H971H97(@=&\@:6YC;'5D
M92`D<W1A=&4@:6X@=&AE(&QI<W0-"B`@("`@*B!`<F5T=7)N(&9A;'-E?&%R
M<F%Y($9A;'-E(&EF("1S=&%T92!I<R!N;W0@82!V86QI9"!R96QE87-E('-T
M871E#0H@("`@("HO#0H@("`@9G5N8W1I;VX@8F5T=&5R4W1A=&5S*"1S=&%T
M92P@)&EN8VQU9&4@/2!F86QS92D-"B`@("![#0H@("`@("`@('-T871I8R`D
M<W1A=&5S(#T@87)R87DH)W-N87!S:&]T)RP@)V1E=F5L)RP@)V%L<&AA)RP@
M)V)E=&$G+"`G<W1A8FQE)RD[#0H@("`@("`@("1I(#T@87)R87E?<V5A<F-H
M*"1S=&%T92P@)'-T871E<RD[#0H@("`@("`@(&EF("@D:2`]/3T@9F%L<V4I
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&EN8VQU9&4I('L-"B`@("`@("`@("`@("1I+2T[#0H@("`@
M("`@('T-"B`@("`@("`@<F5T=7)N(&%R<F%Y7W-L:6-E*"1S=&%T97,L("1I
M("L@,2D[#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O0V]M;6%N9"]086-K86=E+G!H<"YO<FEG````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`Q,S<P-3$@,3`U,34T,S0Q,S0@,#(S-C`Q`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]086-K86=E("AP86-K86=E+"!P86-K
M86=E+79A;&ED871E+"!C=G-D:69F+"!C=G-T86<L('!A8VMA9V4M9&5P96YD
M96YC:65S+`T*("H@<VEG;BP@;6%K97)P;2P@8V]N=F5R="!C;VUM86YD<RD-
M"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T
M:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO
M<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER
M:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A8VMA9V4N<&AP
M+'8@,2XQ,3D@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E
M7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!0
M14%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!-
M87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E
M9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY
M-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@
M("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*
M#0IC;&%S<R!014%27T-O;6UA;F1?4&%C:V%G92!E>'1E;F1S(%!%05)?0V]M
M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@
M=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<&%C:V%G92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD(%!A8VMA
M9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K86=E)RP-
M"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W`G+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N;V-O;7!R
M97-S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;R!N
M;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE)PT*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=S:&]W;F%M92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G4')I;G0@=&AE(&YA;64@;V8@=&AE
M('!A8VMA9V5D(&9I;&4N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C
M9FEL95T@6V1E<V-F:6QE,ET-"D-R96%T97,@82!014%2('!A8VMA9V4@9G)O
M;2!I=',@9&5S8W)I<'1I;VX@9FEL92`H=7-U86QL>2!C86QL960-"G!A8VMA
M9V4N>&UL*2X@($EF(&$@<V5C;VYD('!A8VMA9V5F:6QE(&ES('!A<W-E9"!I
M;BP@=&AE;@T*=&AE('!A8VMA9V5R('=I;&P@8VAE8VL@=&\@;6%K92!S=7)E
M('1H870@;VYE(&ES(&$@<&%C:V%G92YX;6P-"G9E<G-I;VX@,2XP+"!A;F0@
M=&AE(&]T:&5R(&ES(&$@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`N("!4:&4-
M"G!A8VMA9V4N>&UL('9E<G-I;VX@,2XP('=I;&P@8F4@<V%V960@87,@(G!A
M8VMA9V4N>&UL(B!I;B!T:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H97(@87,@
M(G!A8VMA9V4R+GAM;"(@:6X@=&AE(&%R8VAI=F4B#0HG#0H@("`@("`@("`@
M("`I+`T*("`@("`@("`G<&%C:V%G92UV86QI9&%T92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U9A;&ED871E(%!A8VMA9V4@0V]N
M<VES=&5N8WDG+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K
M86=E5F%L:61A=&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<'8G
M+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@
M("`@("`G9&]C)R`]/B`G#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)V-V<V1I9F8G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^
M("=2=6X@82`B8W9S(&1I9F8B(&9O<B!A;&P@9FEL97,@:6X@82!P86-K86=E
M)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0W9S1&EF9B<L#0H@
M("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C9"<L#0H@("`@("`@("`@("`G
M;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)W%U:65T)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M<2<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("="92!Q=6EE="<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)E
M86QL>7%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G42<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("="92!R96%L;'D@<75I970G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("=D871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G1"<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=$:69F(&%G86EN<W0@<F5V:7-I;VX@;V8@1$%412<L
M#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$051%)RP-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5L96%S92<@
M/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@
M)U(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I
M;G-T('1A9R!F;W(@<&%C:V%G92!R96QE87-E(%)%3"<L#0H@("`@("`@("`@
M("`@("`@("`@("=A<F<G(#T^("=214PG+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=R979I<VEO;B<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES:6]N
M(%)%5B<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=2158G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=C;VYT
M97AT)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("='96YE
M<F%T92!C;VYT97AT(&1I9F8G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@("`@("=U;FEF:65D)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("='96YE<F%T92!U;FEF:65D(&1I9F8G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M
M8V%S92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)VDG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N
M;W)E(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@;&]W97(M8V%S92!L971T
M97)S(&5Q=6EV86QE;G0G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@("`@("=I9VYO<F4M=VAI=&5S<&%C92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V(G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@:6X@86UO
M=6YT(&]F('=H:71E('-P86-E)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G:6=N;W)E+6)L86YK+6QI;F5S)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G0B<L#0H@
M("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=)9VYO<F4@8VAA;F=E<R!T
M:&%T(&EN<V5R="!O<B!D96QE=&4@8FQA;FL@;&EN97,G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=B<FEE9B<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=297!O<G0@;VYL
M>2!W:&5T:&5R('1H92!F:6QE<R!D:69F97(L(&YO(&1E=&%I;',G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D<GDM<G5N
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;VY<)W0@
M9&\@86YY=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G
M(#T^("<\<&%C:V%G92YX;6P^#0I#;VUP87)E<R!A;&P@=&AE(&9I;&5S(&EN
M(&$@<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO;G,L('1H:7,-"F-O;6UA
M;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O9&4@=VET:"!T:&4@;&%S
M="!C:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@+7(@;W(@+5(@;W!T:6]N
M('EO=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AA=`T*
M;V8@82!S<&5C:69I8R!R96QE87-E+@T*)RP-"B`@("`@("`@("`@("DL#0H@
M("`@("`@("=C=G-T86<G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA
M<GDG(#T^("=3970@0U93(%)E;&5A<V4@5&%G)RP-"B`@("`@("`@("`@("=F
M=6YC=&EO;B<@/3X@)V1O0W9S5&%G)RP-"B`@("`@("`@("`@("=S:&]R=&-U
M="<@/3X@)V-T)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`G<75I970G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=Q)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V1O8R<@/3X@)T)E('%U:65T)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;&QY<75I970G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=1)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T)E(')E86QL>2!Q=6EE="<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W-L
M:61E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G1B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=-;W9E
M("AS;&ED92D@=&%G(&EF(&ET(&5X:7-T<R<L#0H@("`@("`@("`@("`@("`@
M("`@("DL#0H@("`@("`@("`@("`@("`@)V1E;&5T92<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V0G+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G4F5M;W9E('1A9R<L#0H@("`@("`@
M("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1R>2UR=6XG(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O;EPG="!D;R!A
M;GET:&EN9RP@:G5S="!P<F5T96YD)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)SQP86-K86=E+GAM;#X@6V9I;&5S+BXN70T*4V5T<R!A($-64R!T86<@;VX@
M86QL(&9I;&5S(&EN(&$@<&%C:V%G92X@(%5S92!T:&ES(&-O;6UA;F0@869T
M97(@>6]U(&AA=F4-"G!A8VMA9V5D(&$@9&ES=')I8G5T:6]N('1A<F)A;&P@
M=VET:"!T:&4@(G!A8VMA9V4B(&-O;6UA;F0@=&\@=&%G('=H870-"G)E=FES
M:6]N<R!O9B!W:&%T(&9I;&5S('=E<F4@:6X@=&AA="!R96QE87-E+B`@268@
M;F5E9"!T;R!F:7@@<V]M971H:6YG#0IA9G1E<B!R=6YN:6YG(&-V<W1A9R!O
M;F-E+"!B=70@8F5F;W)E('1H92!T87)B86QL(&ES(')E;&5A<V5D('1O('1H
M92!P=6)L:6,L#0IU<V4@=&AE(")S;&ED92(@;W!T:6]N('1O(&UO=F4@=&AE
M(')E;&5A<V4@=&%G+@T*#0IT;R!I;F-L=61E(&9I;&5S("AS=6-H(&%S(&$@
M<V5C;VYD('!A8VMA9V4N>&UL+"!O<B!T97-T<R!N;W0@:6YC;'5D960@:6X@
M=&AE#0IR96QE87-E*2P@<&%S<R!T:&5M(&%S(&%D9&ET:6]N86P@<&%R86UE
M=&5R<RX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<&%C:V%G92UD
M97!E;F1E;F-I97,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=3:&]W('!A8VMA9V4@9&5P96YD96YC:65S)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G941E<&5N9&5N8VEE<R<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=P9"<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<-"DQI
M<W0@86QL(&1E<&5N8VEE<R!T:&4@<&%C:V%G92!H87,N)PT*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)W-I9VXG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=3:6=N(&$@<&%C:V%G92!D:7-T<FEB=71I;VX@9FEL
M92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U-I9VXG+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<VDG+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A
M8VMA9V4M9FEL93X-"E-I9VYS(&$@<&%C:V%G92!D:7-T<FEB=71I;VX@*"YT
M87(@;W(@+G1G>BD@9FEL92!W:71H($=N=5!'+B<L#0H@("`@("`@("`@("`I
M+`T*("`@("`@("`G;6%K97)P;2<@/3X@87)R87DH#0H@("`@("`@("`@("`G
M<W5M;6%R>2<@/3X@)T)U:6QD<R!A;B!24$T@<W!E8R!F:6QE(&9R;VT@82!0
M14%2('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]-
M86ME4E!-)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)P;2<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@)W-P96,M=&5M<&QA=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("`@("`G<VAO<G1O<'0G(#T^("=T)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V%R9R<@/3X@)T9)3$4G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G57-E($9)3$4@87,@4E!-('-P96,@9FEL92!T96UP;&%T92<-"B`@("`@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<G!M+7!K9VYA
M;64G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T9/4DU!
M5"<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=5<V4@1D]234%4
M(&%S(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K86=E(&YA;64L("5S(&ES
M(')E<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E(&YA;64L(&1E9F%U;'1S
M('1O(")014%2.CHE<R(N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K
M86=E+69I;&4^#0H-"D-R96%T97,@86X@4E!-("YS<&5C(&9I;&4@9F]R('=R
M87!P:6YG(&$@4$5!4B!P86-K86=E(&EN<VED92!A;B!24$T-"G!A8VMA9V4N
M("!);G1E;F1E9"!T;R!B92!U<V5D(&9R;VT@=&AE(%-014-3(&1I<F5C=&]R
M>2P@=VET:"!T:&4@4$5!4@T*<&%C:V%G92!T87)B86QL(&EN('1H92!33U52
M0T53(&1I<F5C=&]R>3H-"@T*)"!P96%R(&UA:V5R<&T@+BXO4T]54D-%4R].
M971?4V]C:V5T+3$N,"YT9WH-"E=R;W1E(%)032!S<&5C(&9I;&4@4$5!4CHZ
M3F5T7T=E;RTQ+C`N<W!E8PT*)"!R<&T@+6)B(%!%05(Z.DYE=%]3;V-K970M
M,2XP+G-P96,-"BXN+@T*5W)O=&4Z("]U<W(O<W)C+W)E9&AA="]24$U3+VDS
M.#8O4$5!4CHZ3F5T7U-O8VME="TQ+C`M,2YI,S@V+G)P;0T*)RP-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("=C;VYV97)T)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G0V]N=F5R="!A('!A8VMA9V4N>&UL(#$N
M,"!T;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T)RP-"B`@("`@("`@("`@("=F
M=6YC=&EO;B<@/3X@)V1O0V]N=F5R="<L#0H@("`@("`@("`@("`G<VAO<G1C
M=70G(#T^("=C,B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@)V9L870G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=F)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V1O8R<@/3X@)V1O(&YO="!B96%U=&EF>2!T:&4@9FEL96QI<W0N
M)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL95T@6V1E<V-F:6QE
M,ET-"D-O;G9E<G1S(&$@<&%C:V%G92YX;6P@:6X@,2XP(&9O<FUA="!I;G1O
M(&$@<&%C:V%G92YX;6P-"FEN(#(N,"!F;W)M870N("!4:&4@;F5W(&9I;&4@
M=VEL;"!B92!N86UE9"!P86-K86=E,BYX;6P@8GD@9&5F875L="P-"F%N9"!P
M86-K86=E+GAM;"!W:6QL(&)E('5S960@87,@=&AE(&]L9"!F:6QE(&)Y(&1E
M9F%U;'0N#0I4:&ES(&ES(&YO="!T:&4@;6]S="!I;G1E;&QI9V5N="!C;VYV
M97)S:6]N+"!A;F0@<VAO=6QD(&]N;'D@8F4-"G5S960@9F]R(&%U=&]M871E
M9"!C;VYV97)S:6]N(&]R(&QE87)N:6YG('1H92!F;W)M870N#0HG#0H@("`@
M("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@=F%R("1O=71P=70[#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J
M*@T*("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E(&-O;G-T<G5C=&]R+@T*
M("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F
M=6YC=&EO;B!014%27T-O;6UA;F1?4&%C:V%G92@F)'5I+"`F)&-O;F9I9RD-
M"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D
M=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H*0T*#0H@("`@9G5N8W1I
M;VX@7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BP@)'-T
M<FEC="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H)&5R<B!A
M<R`D92D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B17)R;W(Z
M("1E7&XB.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1W87)N(&%S
M("1W*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X](")787)N:6YG
M.B`D=UQN(CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;W5T<'5T("X]
M('-P<FEN=&8H)U9A;&ED871I;VXZ("5D(&5R<F]R*',I+"`E9"!W87)N:6YG
M*',I)RXB7&XB+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<VEZ96]F*"1E<G(I+"!S:7IE;V8H)'=A<FXI*3L-"B`@("`@("`@
M:68@*"1S=')I8W0@)B8@<VEZ96]F*"1E<G(I(#X@,"D@>PT*("`@("`@("`@
M("`@)'1H:7,M/F]U='!U="`N/2`B1FEX('1H97-E(&5R<F]R<R!A;F0@=')Y
M(&%G86EN+B([#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]
M#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5R*"D-"B`@("![#0H@("`@("`@
M(&EF("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5R)RDI('L-"B`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E<BYP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5R.PT*("`@
M("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E=%!A
M8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9R`](&9A;'-E+"`D=&UP9&ER(#T@
M;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%2
M7T-O;6UO;B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O
M0V]M;6]N+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05(O4&%C:V%G949I;&4N<&AP)RDI('L-"B`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@
M("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C;VYF
M:6<L("1D96)U9RP@)'1M<&1I<BD[#0H@("`@("`@("1C;VUM;VX@/2!N97<@
M4$5!4E]#;VUM;VX[#0H@("`@("`@("1C;VUM;VXM/G5I(#T@)'1H:7,M/G5I
M.PT*("`@("`@("`D82T^<V5T3&]G9V5R*"1C;VUM;VXI.PT*("`@("`@("!R
M971U<FX@)&$[#0H@("`@?0T*("`@("\O('M[>R!D;U!A8VMA9V4H*0T*#0H@
M("`@9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A
M<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@
M("`@("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M<ULP72D@/R`D<&%R
M86US6S!=(#H@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@)'!K9S(@/2!I<W-E
M="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!N=6QL.PT*("`@("`@("!I
M9B`H(21P:V<R("8F("%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@
M("`@:68@*&9I;&5?97AI<W1S*"=P86-K86=E,BYX;6PG*2D@>PT*("`@("`@
M("`@("`@("`@("1P:V<R(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5R(#T@)B1T:&ES+3YG
M971086-K86=E<B@I.PT*("`@("`@("`D8V]M<')E<W,@/2!E;7!T>2@D;W!T
M:6]N<ULG;F]C;VUP<F5S<R==*2`_('1R=64@.B!F86QS93L-"B`@("`@("`@
M)')E<W5L="`]("1P86-K86=E<BT^<&%C:V%G92@D<&MG:6YF;V9I;&4L("1C
M;VUP<F5S<RP@)'!K9S(I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M<F5S=6QT*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1R97-U;'0I.PT*("`@("`@("!]#0H@("`@("`@("\O($1O;B=T('=A
M;G0@;W5T<'5T+"!O;FQY('1H92!P86-K86=E(&9I;&4@;F%M92!J=7-T(&-R
M96%T960-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S:&]W;F%M92==
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`]("1R97-U;'0[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YO=71P=70I('L-"B`@("`@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D
M8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@
M("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4&%C:V%G959A;&ED
M871E*"D-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G959A;&ED871E*"1C;VUM
M86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES
M+3YO=71P=70@/2`G)SL-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\
M(#$I('L-"B`@("`@("`@("`@("1P87)A;7-;,%T@/2`B<&%C:V%G92YX;6PB
M.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F)'1H:7,M/F=E=%!A8VMA
M9V5&:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@
M("`D;V)J+3YR87=2971U<FXH*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D
M:6YF;R`]("1O8FHM/F9R;VU49WI&:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,
M241!5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN
M9F\I*2![#0H@("`@("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU086-K86=E
M1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D87)C:&EV92`]("1I;F9O+3YG
M971!<F-H:79E1FEL92@I.PT*("`@("`@("`@("`@)'1A<B`]("9N97<@07)C
M:&EV95]487(H)&%R8VAI=F4I.PT*("`@("`@("`@("`@)'1A<BT^97AT<F%C
M="AD:7)N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I*2D[#0H@("`@("`@
M("`@("`D:6YF;RT^<V5T4&%C:V%G949I;&4H9&ER;F%M92@D:6YF;RT^9V5T
M4&%C:V%G949I;&4H*2D@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@
M("`@("`@("`@("`D:6YF;RT^9V5T4&%C:V%G92@I("X@)RTG("X@)&EN9F\M
M/F=E=%9E<G-I;VXH*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@
M("`@("`@("`@(&)A<V5N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I*2D[
M#0H@("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[
M#0H@("`@("`@('T-"B`@("`@("`@)'9A;&ED(#T@9F%L<V4[#0H@("`@("`@
M(&EF("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@
M>PT*("`@("`@("`@("`@:68@*"1V86QI9"`]("1I;F9O+3YV86QI9&%T92A0
M14%27U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@("`@("`D:6YF
M;RT^9FQA='1E;D9I;&5,:7-T*"D[#0H@("`@("`@("`@("`@("`@)'9A;&ED
M(#T@)&EN9F\M/G9A;&ED871E*%!%05)?5D%,241!5$5?4$%#2T%'24Y'*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1V86QI9"`]("1I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7U!!0TM!
M1TE.1RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`](&%R<F%Y*"D[#0H@
M("`@("`@("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@:68@*"$D=F%L:60I
M('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI9&%T:6]N
M5V%R;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H
M)&5R<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@>PT*("`@("`@("`@("`@
M("`@("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&5R<EM=
M(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&ES<&QA
M>59A;&ED871I;VY297-U;'1S*"1E<G(L("1W87)N*3L-"B`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"1T:&ES+3YO=71P=70L("1C;VUM86YD*3L-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@+R\@>WM[(&1O0W9S5&%G*"D-"@T*("`@(&9U;F-T:6]N(&1O0W9S5&%G
M*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@
M("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@)%]C;60@/2`D8V]M;6%N
M9#L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@
M("`@("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@
M;6ES<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-"B`@
M("`@("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O
M;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^
M9G)O;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI
M.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@
M("`@('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@("`@
M("`@:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E<G)O
M<BD@>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@
M)W=A<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@/2`D
M97)R;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A9V4G
M73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S
M=6QT<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!T86<@
M9F%I;&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@/2`D:6YF
M;RT^9V5T5F5R<VEO;B@I.PT*("`@("`@("`D8W9S=F5R<VEO;B`]('!R96=?
M<F5P;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D=F5R<VEO;BD[#0H@("`@
M("`@("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R<VEO;B([#0H@("`@("`@
M("1F:6QE<R`](&%R<F%Y7VME>7,H)&EN9F\M/F=E=$9I;&5L:7-T*"DI.PT*
M("`@("`@("`D8V]M;6%N9"`](")C=G,B.PT*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N
M/2`G("UQ)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;)W)E86QL>7%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N
M/2`G("U1)SL-"B`@("`@("`@?0T*("`@("`@("`D8V]M;6%N9"`N/2`G('1A
M9R<[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VQI9&4G72DI('L-
M"B`@("`@("`@("`@("1C;VUM86YD("X]("<@+48G.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5L971E)UTI*2![#0H@("`@
M("`@("`@("`D8V]M;6%N9"`N/2`G("UD)SL-"B`@("`@("`@?0T*("`@("`@
M("`D8V]M;6%N9"`N/2`G("<@+B`D8W9S=&%G("X@)R`G("X@97-C87!E<VAE
M;&QA<F<H)'!A<F%M<ULP72D[#0H@("`@("`@(&%R<F%Y7W-H:69T*"1P87)A
M;7,I.PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@
M("`@("\O(&%D9"!I;B!A9&1I=&EO;F%L(&9I;&5S('1O(&)E('1A9V=E9`T*
M("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"`D<&%R
M86US*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9FEL97,@87,@
M)&9I;&4I('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@)R`N(&5S8V%P
M97-H96QL87)G*"1F:6QE*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H
M:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@("`@("`@
M("`D=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-O;6UA;F1<;B([#0H@
M("`@("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9')Y+7)U;B==*2D@>PT*("`@
M("`@("`@("`@)&9P(#T@<&]P96XH)&-O;6UA;F0L(")R(BD[#0H@("`@("`@
M("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2![#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2!R=')I;2@D;&EN92DN(EQN
M(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('!C;&]S92@D9G`I.PT*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI
M<RT^;W5T<'5T+"`D7V-M9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@
M('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-V<T1I9F8H*0T*#0H@
M("`@9G5N8W1I;VX@9&]#=G-$:69F*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A
M<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@
M("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@("`@
M("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@;6ES<VEN
M9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-"B`@("`@("`@
M)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@
M)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;4%N
M>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-
M"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@:68@
M*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E<G)O<BD@>PT*
M("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@)W=A<FYI
M;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@/2`D97)R;W);
M)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A9V4G73L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D
M97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!D:69F(&9A:6QE
M9"<I.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O,2`]("1I;F9O+3YG971&
M:6QE;&ES="@I.PT*("`@("`@("`D9FEL97,@/2`D:6YF;S$[#0H@("`@("`@
M("1C;60@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=Q
M=6EE="==*2D@>PT*("`@("`@("`@("`@)&-M9"`N/2`G("UQ)SL-"B`@("`@
M("`@("`@('5N<V5T*"1O<'1I;VYS6R=Q=6EE="==*3L-"B`@("`@("`@?0T*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI*2![
M#0H@("`@("`@("`@("`D8VUD("X]("<@+5$G.PT*("`@("`@("`@("`@=6YS
M970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<F5L96%S92==*2D@>PT*("`@("`@
M("`@("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M>C`M.5TO
M:2<L("=?)RP@)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@("`@("`D
M8W9S=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@("`@("`@
M)&]P=&EO;G-;)W)E=FES:6]N)UT@/2`D8W9S=&%G.PT*("`@("`@("`@("`@
M=6YS970H)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@('T-"B`@("`@
M("`@)&5X96-U=&4@/2!T<G5E.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO
M;G-;)V1R>2UR=6XG72DI('L-"B`@("`@("`@("`@("1E>&5C=71E(#T@9F%L
M<V4[#0H@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG9')Y+7)U;B==*3L-
M"B`@("`@("`@?0T*("`@("`@("`D8VUD("X]("<@9&EF9B<[#0H@("`@("`@
M("\O('1H92!R97-T(&]F('1H92!O<'1I;VYS(&%R92!P87-S960@<FEG:'0@
M;VX@=&\@(F-V<R!D:69F(@T*("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A
M<R`D;W!T:6]N(#T^("1O<'1A<F<I('L-"B`@("`@("`@("`@("1A<F<@/2!`
M)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==6R1O<'1I;VY=
M6R=A<F<G73L-"B`@("`@("`@("`@("1S:&]R="`]($`D=&AI<RT^8V]M;6%N
M9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UU;)&]P=&EO;EU;)W-H;W)T;W!T)UT[
M#0H@("`@("`@("`@("`D8VUD("X]("1S:&]R="`_("(@+21S:&]R="(@.B`B
M("TM)&]P=&EO;B([#0H@("`@("`@("`@("!I9B`H)&%R9R`F)B`D;W!T87)G
M*2![#0H@("`@("`@("`@("`@("`@)&-M9"`N/2`H)'-H;W)T(#\@)R<@.B`G
M/2<I("X@97-C87!E<VAE;&QA<F<H)&]P=&%R9RD[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE
M*2![#0H@("`@("`@("`@("`D8VUD("X]("<@)R`N(&5S8V%P97-H96QL87)G
M*"1F:6QE6R=N86UE)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI
M<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#$I('L-"B`@("`@("`@("`@
M("1T:&ES+3YO=71P=70@+CT@(BL@)&-M9%QN(CL-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H)&5X96-U=&4I('L-"B`@("`@("`@("`@("1F<"`]('!O<&5N
M*"1C;60L(")R(BD[#0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T
M<R@D9G`L(#$P,C0I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U='!U
M="`N/2!R=')I;2@D;&EN92DN(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('!C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@
M("\O('M[>R!D;U!A8VMA9V5$97!E;F1E;F-I97,H*0T*#0H@("`@9G5N8W1I
M;VX@9&]086-K86=E1&5P96YD96YC:65S*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@("\O("1P87)A;7-;,%T@+3X@=&AE
M(%!%05(@<&%C:V%G92!T;R!L:7-T(&ET<R!I;F9O<FUA=&EO;@T*("`@("`@
M("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D('!A<F%M971E<BAS*2P@=')Y
M(%PB:&5L<"`D8V]M;6%N9%PB(BD[#0H@("`@("`@('T-"B`@("`@("`@)&]B
M:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H
M:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;4%N>49I
M;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@
M("`@("`@)&1E<',@/2`D:6YF;RT^9V5T1&5P<R@I.PT*("`@("`@("!I9B`H
M:7-?87)R87DH)&1E<',I*2![#0H@("`@("`@("`@("!I9B`H)&EN9F\M/F=E
M=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@("`@("`@
M("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G8V%P
M=&EO;B<@/3X@)T1E<&5N9&5N8VEE<R!F;W(@<&5A<B\G("X@)&EN9F\M/F=E
M=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M=')U92P-"B`@("`@("`@("`@("`@("`@("`@)VAE861L:6YE)R`]/B!A<G)A
M>2@B4F5Q=6ER960_(BP@(E1Y<&4B+"`B3F%M92(L(")296QA=&EO;B(L(")6
M97)S:6]N(BDL#0H@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9"D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("!I9B`H)&1;)V]P=&EO;F%L)UT@/3T@)WEE<R<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@)TYO)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7V1E<'-?<F5L7W1R86YS6R1D6R=R96PG75TI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5L(#T@)'1H:7,M/E]D97!S7W)E;%]T
M<F%N<ULD9%LG<F5L)UU=.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1D6R=R96PG73L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@=6-F:7)S
M="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==72D[#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D='EP92`]("1D6R=T>7!E)UT[#0H@("`@("`@("`@("`@("`@("`@
M('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)VYA;64G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)&1;)VYA
M;64G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@
M("`@('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)W9E
M<G-I;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N
M(#T@)&1;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)R<[#0H@
M("`@("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("`D
M9&%T85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"`D='EP92P@)&YA;64L("1R
M96PL("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!](&5L<V4@>R`O+R!P86-K86=E+GAM;"`R+C`@9&5P96YD96YC:65S(&1I
M<W!L87D-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&5P
M96YD96YC>3(N<&AP)SL-"B`@("`@("`@("`@("`@("`D9&5P<R`]("1I;F9O
M+3YG971$97!E;F1E;F-I97,H*3L-"B`@("`@("`@("`@("`@("`D<F5G(#T@
M)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D97!S*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D9"`](&YE=R!014%27T1E<&5N9&5N8WDR*"1T:&ES+3YC;VYF:6<L(&%R
M<F%Y*"DL("<G*3L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G1&5P
M96YD96YC:65S(&9O<B`G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*")297%U:7)E
M9#\B+"`B5'EP92(L(").86UE(BP@)U9E<G-I;VYI;F<G+"`G1W)O=7`G*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1D97!S(&%S("1T>7!E(#T^("1S=6)D*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@*"1T>7!E(#T]("=R97%U:7)E
M9"<I(#\@)UEE<R<@.B`G3F\G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1T>7!E(#T]("=G<F]U<"<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9W)O=7`@/2`D<W5B9%LG871T<FEB<R==6R=N86UE)UT[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1G<F]U<"`]("<G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<W5B9%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W5B9"`](&%R<F%Y*"1S=6)D*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S=6)D(&%S
M("1G<F]U<&$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D9W)O=7!A(&%S("1D97!T>7!E(#T^("1D97!I;F9O*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P='EP92`]/2`G
M871T<FEB<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P
M='EP92`]/2`G<&5A<FEN<W1A;&QE<B<I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!T>7!E(#T@)W!E87(@26YS=&%L;&5R
M)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!I;F9O
M6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<&EN9F\@/2!A<G)A>2@D9&5P:6YF;RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)&1E<&EN9F\@87,@)&EN9BD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF
M6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%L:6%S(#T@)')E9RT^8VAA;FYE;$%L:6%S*"1I;F9;
M)V-H86YN96PG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"$D86QI87,I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)RAC:&%N;F5L/RD@
M)R`N)&EN9ELG8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;F%M92`]("1A;&EA<R`N("<O)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=N86UE)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&YA;64@+CT@)&EN9ELG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1I;F9;)W!A='1E<FXG
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M92`N/2`D:6YF6R=P871T97)N)UT[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE("X]("<G.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9;)W5R:2==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE("X]("<@6R<@+B`D:6YF6R=U<FDG72`N("`G72<[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'9E<B`]("=C;VYF;&EC=',G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=F5R(#T@)&0M/E]G971%>'1R85-T
M<FEN9R@D:6YF*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M871A6R=D871A)UU;72`](&%R<F%Y*"1R97$L('5C9FER<W0H)&1E<'1Y<&4I
M+"`D;F%M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=F5R+"`D9W)O=7`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H-"B`@("`@
M("`@+R\@1F%L;&)A8VL-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A
M*")4:&ES('!A8VMA9V4@9&]E<R!N;W0@:&%V92!A;GD@9&5P96YD96YC:65S
M+B(L("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9&]3:6=N*"D-"@T*("`@(&9U;F-T:6]N(&1O4VEG;B@D8V]M;6%N9"P@
M)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N
M8V4@)U-Y<W1E;2YP:'`G.PT*("`@("`@("!R97%U:7)E7V]N8V4@)T%R8VAI
M=F4O5&%R+G!H<"<[#0H@("`@("`@("\O('-H;W5L9"!M;W9E(&UO<W0@;V8@
M=&AI<R!C;V1E(&EN=&\@4$5!4E]086-K86=E<@T*("`@("`@("`O+R!S;R!I
M="=L;"!B92!E87-Y('1O(&EM<&QE;65N="`B<&5A<B!P86-K86=E("TM<VEG
M;B(-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!P87)A;65T
M97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULP72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92!D;V5S(&YO
M="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@("!]#0H@("`@("`@("1O
M8FH@/2`D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H
M:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;51G>D9I
M;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@
M("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D<&%R86US6S!=*3L-"B`@
M("`@("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"!P96%R<VEG;B<I
M.PT*("`@("`@("!I9B`H(21T87(M/F5X=')A8W1,:7-T*"=P86-K86=E,BYX
M;6P@<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@:68@
M*"$D=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G92YX;6P@<&%C:V%G92YS:6<G
M+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B9F%I;&5D('1O(&5X=')A8W0@=&%R(&9I;&4B*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL95]E>&ES
M=',H(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*")P86-K86=E(&%L<F5A9'D@<VEG;F5D
M(BD[#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5X;6P@/2`G<&%C:V%G
M92YX;6PG.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H(B1T;7!D:7(O<&%C
M:V%G93(N>&UL(BDI('L-"B`@("`@("`@("`@("1P86-K86=E>&UL(#T@)W!A
M8VMA9V4R+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@0'5N;&EN:R@B)'1M
M<&1I<B]P86-K86=E+G-I9R(I.PT*("`@("`@("`D:6YP=70@/2`D=&AI<RT^
M=6DM/G5S97)$:6%L;V<H)&-O;6UA;F0L#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G1VYU4$<@4&%S<W!H<F%S92<I
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)W!A<W-W;W)D)RDI.PT*("`@("`@("`D9W!G(#T@<&]P96XH(F=P9R`M
M+6)A=&-H("TM<&%S<W!H<F%S92UF9"`P("TM87)M;W(@+2UD971A8V@M<VEG
M;B`M+6]U='!U="`D=&UP9&ER+W!A8VMA9V4N<VEG("1T;7!D:7(O)'!A8VMA
M9V5X;6P@,CXO9&5V+VYU;&PB+"`B=R(I.PT*("`@("`@("!I9B`H(21G<&<I
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9W!G
M(&-O;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@9G=R:71E
M*"1G<&<L("(D:6YP=71;,%U<;B(I.PT*("`@("`@("!I9B`H<&-L;W-E*"1G
M<&<I('Q\("%F:6QE7V5X:7-T<R@B)'1M<&1I<B]P86-K86=E+G-I9R(I*2![
M#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F=P9R!S
M:6=N(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1T87(M/F%D9$UO
M9&EF>2@B)'1M<&1I<B]P86-K86=E+G-I9R(L("<G+"`D=&UP9&ER*3L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@
M("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;&QE<B@F)'5I*0T*("`@('L-
M"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?26YS=&%L;&5R)RDI
M('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(N
M<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]);G-T
M86QL97(H)'5I*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"B`@("`-
M"B`@("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=$-O;6UA;F1086-K86=I;F<H)B1U
M:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R<I*2![#0H@("`@("`@("`@("!`
M:6YC;'5D95]O;F-E("=014%2+T-O;6UA;F0O4&%C:V%G:6YG+G!H<"<[#0H@
M("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H
M)U!%05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@("`@)&$@
M/2`F;F5W(%!%05)?0V]M;6%N9%]086-K86=I;F<H)'5I+"`D8V]N9FEG*3L-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@;G5L;#L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@
M>WM[(&1O36%K95)032@I#0H-"B`@("!F=6YC=&EO;B!D;TUA:V524$TH)&-O
M;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@<F5Q
M=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@<F5Q=6ER95]O;F-E
M("=!<F-H:79E+U1A<BYP:'`G.PT*#0H@("`@("`@("\O($-H96-K('1O('-E
M92!I9B!014%27T-O;6UA;F1?4&%C:V%G:6YG(&ES(&EN<W1A;&QE9"P@86YD
M#0H@("`@("`@("\O('1R86YS<&%R96YT;'D@<W=I=&-H('1O('5S92!T:&4@
M(FUA:V4M<G!M+7-P96,B(&-O;6UA;F0@9G)O;2!I=`T*("`@("`@("`O+R!I
M;G-T96%D+"!I9B!I="!D;V5S+B!/=&AE<G=I<V4L(&-O;G1I;G5E('1O('5S
M92!T:&4@;VQD('9E<G-I;VX-"B`@("`@("`@+R\@;V8@(FUA:V5R<&TB('-U
M<'!L:65D('=I=&@@=&AI<R!P86-K86=E("A014%2*2X-"B`@("`@("`@)'!A
M8VMA9VEN9U]C;60@/2`D=&AI<RT^9V5T0V]M;6%N9%!A8VMA9VEN9R@D=&AI
M<RT^=6DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I9B`H)'!A8VMA9VEN
M9U]C;60@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R!I<R!I;G-T86QL960[
M('5S:6YG("<N#0H@("`@("`@("`@("`@("`@)VYE=V5R(")M86ME+7)P;2US
M<&5C(B!C;VUM86YD(&EN<W1E860G*3L-"B`@("`@("`@("`@(')E='5R;B`D
M<&%C:V%G:6YG7V-M9"T^<G5N*"=M86ME+7)P;2US<&5C)RP@)&]P=&EO;G,L
M("1P87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"=705).24Y'.B`B<&5A<B!M86ME<G!M(B!I
M<R!N;W<@9&5P<F5C871E9#L@86X@)RX-"B`@("`@("`@("`@("`@)VEM<')O
M=F5D('9E<G-I;VX@:7,@879A:6QA8FQE('9I82`B<&5A<B!M86ME+7)P;2US
M<&5C(BP@=VAI8V@@)RX-"B`@("`@("`@("`@("`@)VES(&%V86EL86)L92!B
M>2!I;G-T86QL:6YG(%!%05)?0V]M;6%N9%]086-K86=I;F<G*3L-"B`@("`@
M("`@?0T*("`@("`@("`-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A
M/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(F)A9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULP
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B
M9FEL92!D;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@("!]
M#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH
M*3L-"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H
M:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1P9B`]("8D
M<&MG+3YF<F]M06YY1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/
M4DU!3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@
M("`@("`@("`@("1U(#T@)'!F+3YG9715<V5R:6YF;R@I.PT*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1U*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1U(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES
M7V%R<F%Y*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D97)R
M(#T@)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D97)R
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1P87)A;7-;,%T@:7,@
M;F]T(&$@=F%L:60@<&%C:V%G92(I.PT*("`@("`@("!]#0H@("`@("`@("1T
M;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G+"`G<&5A<C)R<&TG
M*2D[#0H@("`@("`@("1I;G-T<F]O="`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y
M*"<M9"<L("=P96%R,G)P;2<I*3L-"B`@("`@("`@)'1M<"`]("1T:&ES+3YC
M;VYF:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG
M+3YS970H)W9E<F)O<V4G+"`P*3L-"B`@("`@("`@)&EN<W1A;&QE<B`]("1T
M:&ES+3YG971);G-T86QL97(H)'1H:7,M/G5I*3L-"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=014%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'`G.PT*("`@("`@
M("`D<&%C:R`](&YE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D:6YS=&%L
M;&5R*3L-"B`@("`@("`@)'!A8VLM/G-E=%!A8VMA9V5&:6QE*"1P9BD[#0H@
M("`@("`@("1P87)A;7-;,%T@/2`F)'!A8VL[#0H@("`@("`@("1I;G-T86QL
M97(M/G-E=$]P=&EO;G,H87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O
M;W0L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G;F]D97!S)R`]/B!T<G5E+"`G<V]F="<@/3X@=')U92DI.PT*("`@("`@
M("`D:6YS=&%L;&5R+3YS971$;W=N;&]A9&5D4&%C:V%G97,H)'!A<F%M<RD[
M#0H@("`@("`@("1I;F9O(#T@)&EN<W1A;&QE<BT^:6YS=&%L;"@D<&%R86US
M6S!=+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R
M87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O;W0L#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]D97!S)R`]/B!T<G5E
M+"`G<V]F="<@/3X@=')U92DI.PT*("`@("`@("`D<&MG9&ER(#T@)'!F+3YG
M971086-K86=E*"D@+B`G+2<@+B`D<&8M/F=E=%9E<G-I;VXH*3L-"B`@("`@
M("`@)&EN9F];)W)P;5]X;6Q?9&ER)UT@/2`G+W9A<B]L:6(O<&5A<B<[#0H@
M("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=F5R8F]S92<L("1T;7`I.PT*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-P96,M=&5M<&QA=&4G72DI
M('L-"B`@("`@("`@("`@("1S<&5C7W1E;7!L871E(#T@)&]P=&EO;G-;)W-P
M96,M=&5M<&QA=&4G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1S<&5C7W1E;7!L871E(#T@)R]H;VUE+VQU8V5R+W=O<FLO<&5A<B]S:&%R
M92]P:'`O9&%T82]014%2+W1E;7!L871E+G-P96,G.PT*("`@("`@("!]#0H@
M("`@("`@("1I;F9O6R=P;W-S:6)L95]C:&%N;F5L)UT@/2`G)SL-"B`@("`@
M("`@)&EN9F];)V5X=')A7V-O;F9I9R==(#T@)R<[#0H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG<G!M+7!K9VYA;64G72DI('L-"B`@("`@("`@("`@
M("1R<&U?<&MG;F%M95]F;W)M870@/2`D;W!T:6]N<ULG<G!M+7!K9VYA;64G
M73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF("@D<&8M/F=E
M=$-H86YN96PH*2`]/2`G<&5A<BYP:'`N;F5T)R!\?"`D<&8M/F=E=$-H86YN
M96PH*2`]/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("1A
M;&EA<R`]("=014%2)SL-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D<&8M/F=E=$-H
M86YN96PH*2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("1A;&EA<R`]("1C:&%N+3YG971!;&EA<R@I.PT*("`@("`@
M("`@("`@("`@("1A;&EA<R`]('-T<G1O=7!P97(H)&%L:6%S*3L-"B`@("`@
M("`@("`@("`@("`D:6YF;ULG<&]S<VEB;&5?8VAA;FYE;"==(#T@)'!F+3YG
M971#:&%N;F5L*"D@+B`G+R<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`D<G!M7W!K9VYA;65?9F]R;6%T(#T@)&%L:6%S("X@)SHZ)7,G.PT*("`@
M("`@("!]#0H-"B`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`]("<G
M.PT*("`@("`@("`D:6YF;ULG9&]C7V9I;&5S)UT@/2`G)SL-"B`@("`@("`@
M)&EN9F];)V9I;&5S)UT@/2`G)SL-"B`@("`@("`@)&EN9F];)W!A8VMA9V4R
M>&UL)UT@/2`G)SL-"B`@("`@("`@)&EN9F];)W)P;5]P86-K86=E)UT@/2!S
M<')I;G1F*"1R<&U?<&MG;F%M95]F;W)M870L("1P9BT^9V5T4&%C:V%G92@I
M*3L-"B`@("`@("`@)'-R8V9I;&5S(#T@,#L-"B`@("`@("`@9F]R96%C:"`H
M)&EN9F];)V9I;&5L:7-T)UT@87,@)&YA;64@/3X@)&%T='(I('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)&%T=');)W)O;&4G72DI('L-"B`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("1N86UE(#T@<')E9U]R97!L86-E*"<A6R\Z7%Q<7%TA)RP@)R\G+"`D;F%M
M92D[#0H@("`@("`@("`@("!I9B`H)&%T=');)W)O;&4G72`]/2`G9&]C)RD@
M>PT*("`@("`@("`@("`@("`@("1I;F9O6R=D;V-?9FEL97,G72`N/2`B("1N
M86UE(CL-"B`@("`@("`@("`@("\O($UA<"!R;VQE('1O('1H92!R<&T@=F%R
M<PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D8U]P
M<F5F:7@@/2`G)7M?;&EB9&ER?2]P:'`O<&5A<B<[#0H@("`@("`@("`@("`@
M("`@<W=I=&-H("@D871T<ELG<F]L92==*2![#0H@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)W!H<"<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D<')E
M9FEX(#T@)&-?<')E9FEX.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G97AT)SH-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P<F5F:7@@/2`G)7M?;&EB9&ER?2]P:'`G.PT*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL@+R\@6%A8(&=O;V0@<&QA8V4_#0H@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)W-R8R<Z#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<W)C9FEL97,K*SL-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P<F5F:7@@/2`G)7M?:6YC;'5D961I<GTO<&AP)SL-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[("\O(%A86"!G;V]D('!L86-E/PT*("`@("`@
M("`@("`@("`@("`@("!C87-E("=T97-T)SH-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+W1E<W1S+R(@+B`D<&8M/F=E
M=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V1A=&$G.@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O9&%T82\B("X@)'!F+3YG
M971086-K86=E*"D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@
M("`@("`@("`@("`@("`@("!C87-E("=S8W)I<'0G.@T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!R969I>"`]("<E>U]B:6YD:7)])SL-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@(&1E9F%U
M;'0Z("\O(&YO;BUS=&%N9&%R9"!R;VQE<PT*("`@("`@("`@("`@("`@("`@
M("`@("`@)'!R969I>"`]("(D8U]P<F5F:7@O)&%T=');<F]L95TO(B`N("1P
M9BT^9V5T4&%C:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F];)V5X=')A7V-O;F9I9R==("X]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`B7&X@("`@("`@("UD('LD871T<EMR;VQE77U?9&ER/21C7W!R969I>"][
M)&%T=');<F]L95U](%Q<(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@<F]L92`B)R`N("1A='1R
M6R=R;VQE)UT@+B`G(B!U<V5D+"`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G86YD('=I;&P@8F4@:6YS=&%L;&5D(&EN("(G("X@)&-?<')E
M9FEX("X@)R\G("X@)&%T=');)W)O;&4G72`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R\G("X@)'!F+3YG971086-K86=E*"D@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<@+2!H86YD+65D:70@=&AE(&9I;F%L
M("YS<&5C(&EF('1H:7,@:7,@=W)O;F<G+"`D8V]M;6%N9"D[#0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D;F%M92`]('-T<E]R97!L86-E*"=<7"<L("<O)RP@)&YA
M;64I.PT*("`@("`@("`@("`@("`@("1I;F9O6R=F:6QE<R==("X]("(D<')E
M9FEX+R1N86UE7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(&EF("@D<W)C9FEL97,@/B`P*2![#0H@("`@("`@("`@("!R97%U:7)E
M7V]N8V4@)T]3+T=U97-S+G!H<"<[#0H@("`@("`@("`@("`D;W,@/2!N97<@
M3U-?1W5E<W,[#0H@("`@("`@("`@("`D87)C:"`]("1O<RT^9V5T0W!U*"D[
M#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D87)C:"`]("=N;V%R
M8V@G.PT*("`@("`@("!]#0H@("`@("`@("1C9F<@/2!A<G)A>2@G;6%S=&5R
M7W-E<G9E<B<L("=P:'!?9&ER)RP@)V5X=%]D:7(G+"`G9&]C7V1I<B<L#0H@
M("`@("`@("`@("`@("`@("`@("`G8FEN7V1I<B<L("=D871A7V1I<B<L("=T
M97-T7V1I<B<I.PT*("`@("`@("!F;W)E86-H("@D8V9G(&%S("1K*2![#0H@
M("`@("`@("`@("!I9B`H)&L@/3T@)VUA<W1E<E]S97)V97(G*2![#0H@("`@
M("`@("`@("`@("`@)&-H86X@/2`D<F5G+3YG971#:&%N;F5L*"1P9BT^9V5T
M0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D8VAA;BDI('L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&EN9F];)&M=(#T@)&-H86XM/F=E=%-E<G9E<B@I.PT*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&EN9F];)&M=(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1K*3L-
M"B`@("`@("`@?0T*("`@("`@("`D:6YF;ULG87)C:"==(#T@)&%R8V@[#0H@
M("`@("`@("1F<"`]($!F;W!E;B@D<W!E8U]T96UP;&%T92P@(G(B*3L-"B`@
M("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@B8V]U;&0@;F]T(&]P96X@4E!-('-P96,@9FEL92!T96UP
M;&%T92`D<W!E8U]T96UP;&%T93H@)'!H<%]E<G)O<FUS9R(I.PT*("`@("`@
M("!]#0H@("`@("`@("1I;F9O6R=P86-K86=E)UT@/2`D<&8M/F=E=%!A8VMA
M9V4H*3L-"B`@("`@("`@)&EN9F];)W9E<G-I;VXG72`]("1P9BT^9V5T5F5R
M<VEO;B@I.PT*("`@("`@("`D:6YF;ULG<F5L96%S95]L:6-E;G-E)UT@/2`D
M<&8M/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@:68@*"1P9BT^9V5T1&5P<R@I
M*2![#0H@("`@("`@("`@("!I9B`H)'!F+3YG971086-K86=E>&UL5F5R<VEO
M;B@I(#T]("<Q+C`G*2![#0H@("`@("`@("`@("`@("`@)')E<75I<F5S(#T@
M)&-O;F9L:6-T<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)'!F+3YG971$97!S*"D@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1E<%LG;W!T:6]N86PG72D@)B8@)&1E<%LG;W!T
M:6]N86PG72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"1D97!;)W1Y<&4G72`A/2`G<&MG)RD@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-H
M86YN96PG72D@)B8@)&1E<%LG8VAA;FYE;"==("$]("=P96%R+G!H<"YN970G
M("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)V-H86YN96PG
M72`A/2`G<&5C;"YP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)&-H86X@/2`F)')E9RT^9V5T0VAA;FYE;"@D9&5P6R=C:&%N;F5L)UTI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&-H86XI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@
M<W1R=&]U<'!E<B@D8VAA;BT^9V5T06QI87,H*2D@+B`G.CHG("X@)&1E<%LG
M;F%M92==.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`G4$5!4CHZ)R`N("1D97!;
M)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`D=')A;G,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("<^)R`]/B`G/B<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G/"<@
M/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SX])R`]/B`G/CTG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SP])R`]/B`G/#TG+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@)STG(#T^("<])RP-"B`@("`@("`@("`@
M("`@("`@("`@("`@("=G="<@/3X@)SXG+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@)VQT)R`]/B`G/"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M9V4G(#T^("<^/2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G;&4G(#T^
M("<\/2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`G97$G(#T^("<])RP-
M"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"1D97!;)W)E;"==(#T]("=H87,G*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5Q=6ER97-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@
M("`@("`@("!](&5L<V5I9B`H)&1E<%LG<F5L)UT@/3T@)VYO="<I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`]("1P86-K86=E
M.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&1E<%LG<F5L)UT@
M/3T@)VYE)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-O;F9L:6-T
M<UM=(#T@)'!A8VMA9V4@+B`G(#T@)R`N("1D97!;)W9E<G-I;VXG73L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T<F%N<ULD9&5P
M6R=R96PG75TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER
M97-;72`]("1P86-K86=E("X@)R`G("X@)'1R86YS6R1D97!;)W)E;"==72`N
M("<@)R`N("1D97!;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H8V]U
M;G0H)')E<75I<F5S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG
M97AT<F%?:&5A9&5R<R==("X]("=297%U:7)E<SH@)R`N(&EM<&QO9&4H)RP@
M)RP@)')E<75I<F5S*2`N(")<;B([#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AC;W5N="@D8V]N9FQI8W1S*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==("X]("=#;VYF
M;&EC=',Z("<@+B!I;7!L;V1E*"<L("<L("1C;VYF;&EC=',I("X@(EQN(CL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1I;F9O6R=P86-K86=E,GAM;"==(#T@)S(G.R`O+R!T
M96QL('1H92!S<&5C('1O('5S92!P86-K86=E,BYX;6P-"B`@("`@("`@("`@
M("`@("`D<F5Q=6ER97,@/2`D8V]N9FQI8W1S(#T@87)R87DH*3L-"B`@("`@
M("`@("`@("`@("`D9&5P<R`]("1P9BT^9V5T1&5P<RAT<G5E*3L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA
M9V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P
M<ULG<F5Q=6ER960G75LG<&%C:V%G92==6S!=*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72`](&%R
M<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1D
M97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@87,@)&1E<"D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1D97!;)V-H86YN96PG72`A/2`G<&5A
M<BYP:'`N;F5T)R`F)B`@)&1E<%LG8VAA;FYE;"==("$]("=P96-L+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H86X@/2`F
M)')E9RT^9V5T0VAA;FYE;"@D9&5P6R=C:&%N;F5L)UTI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G
M92`]('-T<G1O=7!P97(H)&-H86XM/F=E=$%L:6%S*"DI("X@)SHZ)R`N("1D
M97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`G4$5!
M4CHZ)R`N("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M;VYF;&EC=',G72D@)B8@*&ES<V5T*"1D97!;)VUI;B==*2!\?`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:7-S970H)&1E<%LG;6%X)UTI*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R86YG92`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P<F%N9V5;72`](&%R<F%Y*"1D97!;)VUI;B==+"<^/2<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R86YG95M=(#T@87)R
M87DH)&1E<%LG;6%X)UTL("<\/2<I.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES7V%R<F%Y*"1D97!;)V5X8VQU9&4G72D@?'P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(6ES<V5T
M*"1D97!;)V5X8VQU9&4G75LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y*"1D97!;
M)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&-O=6YT
M*"1D97!R86YG92DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E>&-L(#T@)&1E<%LG97AC;'5D92==.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@8VAA;F=E(#X]('1O(#X@:68@
M97AC;'5D:6YG('1H92!M:6X@=F5R<VEO;@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@8VAA;F=E(#P]('1O(#P@:68@97AC;'5D
M:6YG('1H92!M87@@=F5R<VEO;@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@9F]R*"1I(#T@,#L@)&D@/"!C;W5N="@D97AC;"D[("1I
M*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&1E<')A;F=E6S!=*2`F)@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>&-L6R1I72`]/2`D
M9&5P<F%N9V5;,%U;,%TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1E<')A;F=E6S!=6S%=(#T@)SPG.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E
M="@D9&5P6R=E>&-L=61E)UU;)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!R86YG95LQ72D@)B8-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97AC;%LD:5T@/3T@)&1E<')A;F=E6S%=6S!=*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!R86YG95LQ
M75LQ72`]("<^)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@=6YS970H)&1E<%LG97AC;'5D92==6R1I72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AC;W5N="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=E>&-L=61E
M)UT@/2!A<G)A>5]V86QU97,H)&1E<%LG97AC;'5D92==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=D97!R86YG92`](&%R
M<F%Y*"D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!R96UO=F4@97AC;'5D97,@=&AA="!A<F4@;W5T<VED92!T:&4@97AI<W1I
M;F<@<F%N9V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D97!;)V5X8VQU9&4G72D[("1I
M*RLI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)&1E<%LG97AC;'5D92==6R1I72`\("1D97!;)VUI;B==('Q\#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<%LG97AC;'5D92==6R1I72`^("1D97!;)VUA>"==*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1D
M97!;)V5X8VQU9&4G75LD:5TI.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!;)V5X8VQU9&4G72`](&%R<F%Y7W9A;'5E<R@D9&5P6R=E>&-L
M=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M=7-O<G0H)&1E<%LG97AC;'5D92==+"`G=F5R<VEO;E]C;VUP87)E)RD[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!T86ME('1H
M92!R96UA:6YI;F<@97AC;'5D97,@86YD#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!S<&QI="!T:&4@9&5P96YD96YC>2!I;G1O
M('-U8BUR86YG97,-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1L87-T;6EN(#T@)&1E<')A;F=E6S!=.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@8V]U;G0H
M)&1E<%LG97AC;'5D92==*2`M(#$[("1I*RLI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&5P<F%N9V5;72`]("<H
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P86-K86=E("X@(B![)&QA<W1M:6Y;,5U]('LD;&%S=&UI;ELP77T@
M86YD("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&%C:V%G92`N("<@/"`G("X@)&1E<%LG97AC;'5D92==6R1I
M72`N("<I)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;&%S=&UI;B`](&%R<F%Y*"1D97!;)V5X8VQU9&4G75LD:5TL("<^
M)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H
M)&1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YE=V1E<')A;F=E6UT@/2`G*"<@+B`D<&%C:V%G92`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("(@>R1L87-T;6EN6S%=?2![)&QA<W1M:6Y;,%U](&%N9"`B("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA
M9V4@+B`G(#P@)R`N("1D97!;)VUA>"==("X@)RDG.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;F9L:6-T<UM=(#T@:6UP;&]D92@G(&]R
M("<L("1D97!R86YG92D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(B![)&1E<')A;F=E6S!=6S%=
M?2![)&1E<')A;F=E6S!=6S!=?2(@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("AI<W-E="@D9&5P<F%N9V5;,5TI(#\@#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(B!A;F0@
M)'!A8VMA9V4@>R1D97!R86YG95LQ75LQ77T@>R1D97!R86YG95LQ75LP77TB
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@.B`G
M)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;)VUI
M;B==*2`F)B`A:7-S970H)&1E<%LG;6%X)UTI("8F#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`A:7-S970H)&1E<%LG97AC;'5D92==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C
M;VYF;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G93L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)')E<75I<F5S6UT@/2`D<&%C:V%G92`N("<@/CT@)R`N("1D97!;
M)VUI;B==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6%X)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97%U:7)E
M<UM=(#T@)'!A8VMA9V4@+B`G(#P]("<@+B`D9&5P6R=M87@G73L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X(#T@)&1E<%LG97AC;'5D
M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M7V%R<F%Y*"1E>"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E>"`](&%R<F%Y*"1E>"D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&5X(&%S("1V97(I('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`]("1P86-K86=E("X@
M)R`]("<@+B`D=F5R.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G07)C:&EV92]487(N<&AP
M)SL-"B`@("`@("`@("`@("`@("`@("`@)'1A<B`](&YE=R!!<F-H:79E7U1A
M<B@D<&8M/F=E=$%R8VAI=F5&:6QE*"DI.PT*("`@("`@("`@("`@("`@("`@
M("`D=&%R+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M#0H@("`@("`@("`@("`@("`@("`@("1A(#T@)'1A<BT^97AT<F%C=$EN4W1R
M:6YG*"=P86-K86=E,BYX;6PG*3L-"B`@("`@("`@("`@("`@("`@("`@)'1A
M<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&$@/3T](&YU;&P@?'P@4$5!4CHZ:7-%<G)O<B@D82DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E,GAM;"==(#T@)R<[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!T:&ES(&1O97-N)W0@:&%V
M92!A('!A8VMA9V4N>&UL('9E<G-I;VX@,2XP#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5Q=6ER97-;72`]("=014%2.CI014%2(#X]("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P
M96%R:6YS=&%L;&5R)UU;)VUI;B==.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<F5Q=6ER97,I*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R
M<R==("X]("=297%U:7)E<SH@)R`N(&EM<&QO9&4H)RP@)RP@)')E<75I<F5S
M*2`N(")<;B([#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@:68@*&-O=6YT*"1C;VYF;&EC=',I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG97AT<F%?:&5A9&5R<R==("X]("=#;VYF
M;&EC=',Z("<@+B!I;7!L;V1E*"<L("<L("1C;VYF;&EC=',I("X@(EQN(CL-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("\O(')E;6]V92!T
M:&4@=')A:6QI;F<@;F5W;&EN90T*("`@("`@("`D:6YF;ULG97AT<F%?:&5A
M9&5R<R==(#T@=')I;2@D:6YF;ULG97AT<F%?:&5A9&5R<R==*3L-"B`@("`@
M("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9FEL95]G971?8V]N=&5N=',G*2D@
M>PT*("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`D<W!E
M8U]C;VYT96YT<R`]('!R96=?<F5P;&%C92@G+T`H6V$M>C`M.5\M72LI0"]E
M)RP@)R1I;F9O6R)<,2)=)RP-"B`@("`@("`@("`@("`@("!F:6QE7V=E=%]C
M;VYT96YT<R@D<W!E8U]T96UP;&%T92DI.PT*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@)'-P96-?8V]N=&5N=',@/2!P<F5G7W)E<&QA8V4H)R]`
M*%MA+7HP+3E?+5TK*4`O92<L("<D:6YF;ULB7#$B72<L#0H@("`@("`@("`@
M("`@("`@9G)E860H)&9P+"!F:6QE<VEZ92@D<W!E8U]T96UP;&%T92DI*3L-
M"B`@("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@
M("1S<&5C7V9I;&4@/2`B)&EN9F];<G!M7W!A8VMA9V5=+21I;F9O6W9E<G-I
M;VY=+G-P96,B.PT*("`@("`@("`D=W`@/2!F;W!E;B@D<W!E8U]F:6QE+"`B
M=V(B*3L-"B`@("`@("`@:68@*"$D=W`I('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]U;&0@;F]T('=R:71E(%)032!S<&5C
M(&9I;&4@)'-P96-?9FEL93H@)'!H<%]E<G)O<FUS9R(I.PT*("`@("`@("!]
M#0H@("`@("`@(&9W<FET92@D=W`L("1S<&5C7V-O;G1E;G1S*3L-"B`@("`@
M("`@9F-L;W-E*"1W<"D[#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@B5W)O=&4@4E!-('-P96,@9FEL92`D<W!E8U]F:6QE(BP@)&-O;6UA;F0I
M.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T
M:6]N(&1O0V]N=F5R="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@
M("`@>PT*("`@("`@("`D<&%C:V%G97AM;"`](&ES<V5T*"1P87)A;7-;,%TI
M(#\@)'!A<F%M<ULP72`Z("=P86-K86=E+GAM;"<[#0H@("`@("`@("1N97=P
M86-K86=E>&UL(#T@:7-S970H)'!A<F%M<ULQ72D@/R`D<&%R86US6S%=(#H@
M9&ER;F%M92@D<&%C:V%G97AM;"D@+@T*("`@("`@("`@("`@1$E214-43U)9
M7U-%4$%2051/4B`N("=P86-K86=E,BYX;6PG.PT*("`@("`@("`D<&MG(#T@
M)B1T:&ES+3YG971086-K86=E1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^
M7V1E8G5G*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D<&8@/2`D<&MG+3YF
M<F]M4&%C:V%G949I;&4H)'!A8VMA9V5X;6PL(%!%05)?5D%,241!5$5?3D]2
M34%,*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)'!F*2D@>PT*("`@("`@
M("`@("`@:68@*&ES7V$H)'!F+"`G4$5!4E]086-K86=E1FEL95]V,B<I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1P86-K
M86=E>&UL("X@)R!I<R!A;')E861Y(&$@<&%C:V%G92YX;6P@=F5R<VEO;B`R
M+C`G*3L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N
M97)A=&]R*"D[#0H@("`@("`@("`@("`D;F5W<&8@/2`F)&=E;BT^=&]6,B@I
M.PT*("`@("`@("`@("`@)&YE=W!F+3YS971086-K86=E9FEL92@D;F5W<&%C
M:V%G97AM;"D[#0H@("`@("`@("`@("`D9V5N(#T@)B1N97=P9BT^9V5T1&5F
M875L=$=E;F5R871O<B@I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S
M:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@
M("`@)'-T871E(#T@*&ES<V5T*"1O<'1I;VYS6R=F;&%T)UTI(#\@4$5!4E]6
M04Q)1$%415]004-+04=)3D<@.B!014%27U9!3$E$051%7TY/4DU!3"D[#0H@
M("`@("`@("`@("`D<V%V960@/2`D9V5N+3YT;U!A8VMA9V5&:6QE*&1I<FYA
M;64H)&YE=W!A8VMA9V5X;6PI+"`D<W1A=&4L#0H@("`@("`@("`@("`@("`@
M8F%S96YA;64H)&YE=W!A8VMA9V5X;6PI*3L-"B`@("`@("`@("`@(%!%05(Z
M.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1S879E9"DI('L-"B`@("`@("`@("`@("`@("!I9B`H
M:7-?87)R87DH)'-A=F5D+3YG9715<V5R26YF;R@I*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<V%V960M/F=E=%5S97));F9O*"D@87,@
M)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D=V%R;FEN9ULG;65S<V%G92==*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'-A=F5D+3YG971-97-S86=E
M*"DI.PT*("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=7<F]T
M92!N97<@=F5R<VEO;B`R+C`@<&%C:V%G92YX;6P@=&\@(B<@+B`D<V%V960@
M+B`G(B<I.PT*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH)'!F+3YG9715<V5R
M26YF;R@I*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P9BT^9V5T
M57-E<DEN9F\H*2!A<R`D=V%R;FEN9RD@>PT*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'=A<FYI;F=;)VUE<W-A9V4G72D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P9BD[#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM
M86YD+T)U:6QD+GAM;```````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#0Q-2`Q,#4Q-30S-#$S-"`P,C(S-3``(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/&-O;6UA;F1S('9E<G-I;VX](C$N
M,"(^#0H@/&)U:6QD/@T*("`\<W5M;6%R>3Y"=6EL9"!A;B!%>'1E;G-I;VX@
M1G)O;2!#(%-O=7)C93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O0G5I;&0\
M+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8CPO<VAO<G1C=70^#0H@(#QO<'1I
M;VYS("\^#0H@(#QD;V,^6W!A8VMA9V4N>&UL70T*0G5I;&1S(&]N92!O<B!M
M;W)E(&5X=&5N<VEO;G,@8V]N=&%I;F5D(&EN(&$@<&%C:V%G92X\+V1O8SX-
M"B`\+V)U:6QD/@T*/"]C;VUM86YD<SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]"=6EL9"YP
M:'``````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4V,#`@,3`U
M,34T,S0Q,S0@,#(R,S0P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]!=71H
M("AB=6EL9"!C;VUM86YD*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U
M#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE
M(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-
M"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K
M86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`
M<&AP+FYE=#X-"B`J($!A=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I
M9&5C;F5T+F-O;3X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL
M;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0
M($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@
M($-64SH@)$ED.B!"=6EL9"YP:'`L=B`Q+C$S(#(P,#8O,#$O,#8@,#0Z-#<Z
M,S8@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@
M8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N
M+G!H<"<[#0H-"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@8G5I;&1I;F<@
M97AT96YS:6]N<RX-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B
M0'!H<"YN970^#0H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`
M:61E8VYE="YC;VT^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!014%27T-O
M;6UA;F1?0G5I;&0@97AT96YD<R!014%27T-O;6UA;F1?0V]M;6]N#0I[#0H@
M("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D8V]M;6%N9',@/2!A
M<G)A>2@-"B`@("`@("`@)V)U:6QD)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G0G5I;&0@86X@17AT96YS:6]N($9R;VT@0R!3;W5R
M8V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]"=6EL9"<L#0H@
M("`@("`@("`@("`G<VAO<G1C=70G(#T^("=B)RP-"B`@("`@("`@("`@("=O
M<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMP
M86-K86=E+GAM;%T-"D)U:6QD<R!O;F4@;W(@;6]R92!E>'1E;G-I;VYS(&-O
M;G1A:6YE9"!I;B!A('!A8VMA9V4N)PT*("`@("`@("`@("`@*2P-"B`@("`@
M("`@*3L-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R
M#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O;6UA;F1?0G5I;&0@8V]N<W1R
M=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]"=6EL9"@F)'5I+"`F)&-O
M;F9I9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O
M;6UO;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@
M("`@+R\@>WM[(&1O0G5I;&0H*0T*#0H@("`@9G5N8W1I;VX@9&]"=6EL9"@D
M8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O0G5I;&1E<BYP:'`G.PT*("`@("`@("!I9B`H
M<VEZ96]F*"1P87)A;7,I(#P@,2D@>PT*("`@("`@("`@("`@)'!A<F%M<ULP
M72`]("=P86-K86=E+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@)&)U:6QD
M97(@/2`F;F5W(%!%05)?0G5I;&1E<B@D=&AI<RT^=6DI.PT*("`@("`@("`D
M=&AI<RT^9&5B=6<@/2`D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G*3L-
M"B`@("`@("`@)&5R<B`]("1B=6EL9&5R+3YB=6EL9"@D<&%R86US6S!=+"!A
M<G)A>2@F)'1H:7,L("=B=6EL9$-A;&QB86-K)RDI.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1E
M<G([#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&)U:6QD0V%L;&)A8VLH*0T*#0H@
M("`@9G5N8W1I;VX@8G5I;&1#86QL8F%C:R@D=VAA="P@)&1A=&$I#0H@("`@
M>PT*("`@("`@("!I9B`H*"1W:&%T(#T]("=C;61O=71P=70G("8F("1T:&ES
M+3YD96)U9R`^(#$I('Q\#0H@("`@("`@("`@("`H)'=H870@/3T@)V]U='!U
M="<@)B8@)'1H:7,M/F1E8G5G(#X@,"DI('L-"B`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82AR=')I;2@D9&%T82DL("=B=6EL9"<I.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0I]#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]#;VUM86YD+T-H86YN96QS+GAM;```````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P-3(W,2`Q,#4Q-30S-#$S-"`P,C,P-3$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/&-O
M;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&QI<W0M8VAA;FYE;',^#0H@(#QS
M=6UM87)Y/DQI<W0@079A:6QA8FQE($-H86YN96QS/"]S=6UM87)Y/@T*("`\
M9G5N8W1I;VX^9&],:7-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FQC/"]S
M:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SX-"DQI<W0@86QL(&%V
M86EL86)L92!C:&%N;F5L<R!F;W(@:6YS=&%L;&%T:6]N+@T*/"]D;V,^#0H@
M/"]L:7-T+6-H86YN96QS/@T*(#QU<&1A=&4M8VAA;FYE;',^#0H@(#QS=6UM
M87)Y/E5P9&%T92!T:&4@0VAA;FYE;"!,:7-T/"]S=6UM87)Y/@T*("`\9G5N
M8W1I;VX^9&]5<&1A=&5!;&P\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^=6,\
M+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O/@T*("`\9&]C/@T*3&ES="!A;&P@
M:6YS=&%L;&5D('!A8VMA9V5S(&EN(&%L;"!C:&%N;F5L<RX-"CPO9&]C/@T*
M(#PO=7!D871E+6-H86YN96QS/@T*(#QC:&%N;F5L+61E;&5T93X-"B`@/'-U
M;6UA<GD^4F5M;W9E(&$@0VAA;FYE;"!&<F]M('1H92!,:7-T/"]S=6UM87)Y
M/@T*("`\9G5N8W1I;VX^9&]$96QE=&4\+V9U;F-T:6]N/@T*("`\<VAO<G1C
M=70^8V1E/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[
M8VAA;FYE;"!N86UE)F=T.PT*1&5L971E(&$@8VAA;FYE;"!F<F]M('1H92!R
M96=I<W1R>2X@(%EO=2!M87D@;F]T#0IR96UO=F4@86YY(&-H86YN96P@=&AA
M="!H87,@:6YS=&%L;&5D('!A8VMA9V5S+@T*/"]D;V,^#0H@/"]C:&%N;F5L
M+61E;&5T93X-"B`\8VAA;FYE;"UA9&0^#0H@(#QS=6UM87)Y/D%D9"!A($-H
M86YN96P\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T%D9#PO9G5N8W1I;VX^
M#0H@(#QS:&]R=&-U=#YC83PO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@
M(#QD;V,^)FQT.V-H86YN96PN>&UL)F=T.PT*061D(&$@<')I=F%T92!C:&%N
M;F5L('1O('1H92!C:&%N;F5L(&QI<W0N("!.;W1E('1H870@86QL#0IP=6)L
M:6,@8VAA;FYE;',@<VAO=6QD(&)E('-Y;F-E9"!U<VEN9R`F<75O=#MU<&1A
M=&4M8VAA;FYE;',F<75O=#LN#0I087)A;65T97(@;6%Y(&)E(&5I=&AE<B!A
M(&QO8V%L(&9I;&4@;W(@<F5M;W1E(%523"!T;R!A#0IC:&%N;F5L+GAM;"X-
M"CPO9&]C/@T*(#PO8VAA;FYE;"UA9&0^#0H@/&-H86YN96PM=7!D871E/@T*
M("`\<W5M;6%R>3Y5<&1A=&4@86X@17AI<W1I;F<@0VAA;FYE;#PO<W5M;6%R
M>3X-"B`@/&9U;F-T:6]N/F1O57!D871E/"]F=6YC=&EO;CX-"B`@/'-H;W)T
M8W5T/F-U/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\9F]R8V4^#0H@
M("`@/'-H;W)T;W!T/F8\+W-H;W)T;W!T/@T*("`@(#QD;V,^=VEL;"!F;W)C
M92!D;W=N;&]A9"!O9B!N97<@8VAA;FYE;"YX;6P@:68@86X@97AI<W1I;F<@
M8VAA;FYE;"!N86UE(&ES('5S960\+V1O8SX-"B`@(#PO9F]R8V4^#0H@("`\
M8VAA;FYE;#X-"B`@("`\<VAO<G1O<'0^8SPO<VAO<G1O<'0^#0H@("`@/&%R
M9SY#2$%.3D5,/"]A<F<^#0H@("`@/&1O8SYW:6QL(&9O<F-E(&1O=VYL;V%D
M(&]F(&YE=R!C:&%N;F5L+GAM;"!I9B!A;B!E>&ES=&EN9R!C:&%N;F5L(&YA
M;64@:7,@=7-E9#PO9&]C/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO;G,^
M#0H@(#QD;V,^6R9L=#MC:&%N;F5L+GAM;"9G=#M\)FQT.V-H86YN96P@;F%M
M929G=#M=#0I5<&1A=&4@82!C:&%N;F5L(&EN('1H92!C:&%N;F5L(&QI<W0@
M9&ER96-T;'DN("!.;W1E('1H870@86QL#0IP=6)L:6,@8VAA;FYE;',@8V%N
M(&)E('-Y;F-E9"!U<VEN9R`F<75O=#MU<&1A=&4M8VAA;FYE;',F<75O=#LN
M#0I087)A;65T97(@;6%Y(&)E(&$@;&]C86P@;W(@<F5M;W1E(&-H86YN96PN
M>&UL+"!O<B!T:&4@;F%M92!O9@T*86X@97AI<W1I;F<@8VAA;FYE;"X-"CPO
M9&]C/@T*(#PO8VAA;FYE;"UU<&1A=&4^#0H@/&-H86YN96PM:6YF;SX-"B`@
M/'-U;6UA<GD^4F5T<FEE=F4@26YF;W)M871I;VX@;VX@82!#:&%N;F5L/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]);F9O/"]F=6YC=&EO;CX-"B`@/'-H
M;W)T8W5T/F-I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF
M;'0[<&%C:V%G929G=#L-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE
M9"!P86-K86=E+@T*/"]D;V,^#0H@/"]C:&%N;F5L+6EN9F\^#0H@/&-H86YN
M96PM86QI87,^#0H@(#QS=6UM87)Y/E-P96-I9GD@86X@86QI87,@=&\@82!C
M:&%N;F5L(&YA;64\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T%L:6%S/"]F
M=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-H83PO<VAO<G1C=70^#0H@(#QO<'1I
M;VYS("\^#0H@(#QD;V,^)FQT.V-H86YN96PF9W0[("9L=#MA;&EA<R9G=#L-
M"E-P96-I9GD@82!S<&5C:69I8R!A;&EA<R!T;R!U<V4@9F]R(&$@8VAA;FYE
M;"!N86UE+@T*5&AE(&%L:6%S(&UA>2!N;W0@8F4@86X@97AI<W1I;F<@8VAA
M;FYE;"!N86UE(&]R#0IA;&EA<RX-"CPO9&]C/@T*(#PO8VAA;FYE;"UA;&EA
M<SX-"B`\8VAA;FYE;"UD:7-C;W9E<CX-"B`@/'-U;6UA<GD^26YI=&EA;&EZ
M92!A($-H86YN96P@9G)O;2!I=',@<V5R=F5R/"]S=6UM87)Y/@T*("`\9G5N
M8W1I;VX^9&]$:7-C;W9E<CPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YD:3PO
M<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A8VMA9V4F
M9W0[#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL960@<&%C:V%G92X-
M"CPO9&]C/@T*(#PO8VAA;FYE;"UD:7-C;W9E<CX-"CPO8V]M;6%N9',^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O
M;6UA;F0O0VAA;FYE;',N<&AP````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,3`Q-#(R(#$P-3$U-#,T,3,T(#`R,S`S,P`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`T*+R\@+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO*BH-
M"B`J(%!%05)?0V]M;6%N9%]#:&%N;F5L<R`H;&ES="UC:&%N;F5L<RP@=7!D
M871E+6-H86YN96QS+"!C:&%N;F5L+61E;&5T92P@8VAA;FYE;"UA9&0L#0H@
M*B!C:&%N;F5L+75P9&%T92P@8VAA;FYE;"UI;F9O+"!C:&%N;F5L+6%L:6%S
M+"!C:&%N;F5L+61I<V-O=F5R(&-O;6UA;F1S*0T*("H-"B`J(%!(4"!V97)S
M:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL
M92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS
M90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E
M;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E
M87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A
M=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V
M97)S:6]N("`@($-64SH@)$ED.B!#:&%N;F5L<RYP:'`L=B`Q+C0T(#(P,#8O
M,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-
M"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!
M4B]#;VUM86YD+T-O;6UO;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N
M9',@9F]R(&UA;F%G:6YG(&-H86YN96QS+@T*("H-"B`J($!C871E9V]R>2`@
M('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R
M96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y
M.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-
M"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E
M("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT+C!A,0T*
M("HO#0IC;&%S<R!014%27T-O;6UA;F1?0VAA;FYE;',@97AT96YD<R!014%2
M7T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*
M("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)VQI<W0M8VAA
M;FYE;',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,
M:7-T($%V86EL86)L92!#:&%N;F5L<R<L#0H@("`@("`@("`@("`G9G5N8W1I
M;VXG(#T^("=D;TQI<W0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M;&,G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@
M("`@("`@("`G9&]C)R`]/B`G#0I,:7-T(&%L;"!A=F%I;&%B;&4@8VAA;FYE
M;',@9F]R(&EN<W1A;&QA=&EO;BX-"B<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G=7!D871E+6-H86YN96QS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G57!D871E('1H92!#:&%N;F5L($QI<W0G+`T*("`@
M("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]5<&1A=&5!;&PG+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G=6,G+`T*("`@("`@("`@("`@)V]P=&EO
M;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G#0I,:7-T
M(&%L;"!I;G-T86QL960@<&%C:V%G97,@:6X@86QL(&-H86YN96QS+@T*)PT*
M("`@("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM9&5L971E)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4F5M;W9E(&$@0VAA
M;FYE;"!&<F]M('1H92!,:7-T)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@
M/3X@)V1O1&5L971E)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)V-D
M92<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@
M("`@("`@("=D;V,G(#T^("<\8VAA;FYE;"!N86UE/@T*1&5L971E(&$@8VAA
M;FYE;"!F<F]M('1H92!R96=I<W1R>2X@(%EO=2!M87D@;F]T#0IR96UO=F4@
M86YY(&-H86YN96P@=&AA="!H87,@:6YS=&%L;&5D('!A8VMA9V5S+@T*)PT*
M("`@("`@("`@("`@*2P-"B`@("`@("`@)V-H86YN96PM861D)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G061D(&$@0VAA;FYE;"<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T%D9"<L#0H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=C82<L#0H@("`@("`@("`@("`G;W!T:6]N
M<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\8VAA;FYE
M;"YX;6P^#0I!9&0@82!P<FEV871E(&-H86YN96P@=&\@=&AE(&-H86YN96P@
M;&ES="X@($YO=&4@=&AA="!A;&P-"G!U8FQI8R!C:&%N;F5L<R!S:&]U;&0@
M8F4@<WEN8V5D('5S:6YG(")U<&1A=&4M8VAA;FYE;',B+@T*4&%R86UE=&5R
M(&UA>2!B92!E:71H97(@82!L;V-A;"!F:6QE(&]R(')E;6]T92!54DP@=&\@
M80T*8VAA;FYE;"YX;6PN#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G
M8VAA;FYE;"UU<&1A=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA
M<GDG(#T^("=5<&1A=&4@86X@17AI<W1I;F<@0VAA;FYE;"<L#0H@("`@("`@
M("`@("`G9G5N8W1I;VXG(#T^("=D;U5P9&%T92<L#0H@("`@("`@("`@("`G
M<VAO<G1C=70G(#T^("=C=2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@)V9O<F-E)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G9B<L#0H@("`@("`@
M("`@("`@("`@("`@("=D;V,G(#T^("=W:6QL(&9O<F-E(&1O=VYL;V%D(&]F
M(&YE=R!C:&%N;F5L+GAM;"!I9B!A;B!E>&ES=&EN9R!C:&%N;F5L(&YA;64@
M:7,@=7-E9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@)V-H86YN96PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<VAO<G1O<'0G(#T^("=C)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R
M9R<@/3X@)T-(04Y.14PG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]
M/B`G=VEL;"!F;W)C92!D;W=N;&]A9"!O9B!N97<@8VAA;FYE;"YX;6P@:68@
M86X@97AI<W1I;F<@8VAA;FYE;"!N86UE(&ES('5S960G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T**2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;/&-H
M86YN96PN>&UL/GP\8VAA;FYE;"!N86UE/ET-"E5P9&%T92!A(&-H86YN96P@
M:6X@=&AE(&-H86YN96P@;&ES="!D:7)E8W1L>2X@($YO=&4@=&AA="!A;&P-
M"G!U8FQI8R!C:&%N;F5L<R!C86X@8F4@<WEN8V5D('5S:6YG(")U<&1A=&4M
M8VAA;FYE;',B+@T*4&%R86UE=&5R(&UA>2!B92!A(&QO8V%L(&]R(')E;6]T
M92!C:&%N;F5L+GAM;"P@;W(@=&AE(&YA;64@;V8-"F%N(&5X:7-T:6YG(&-H
M86YN96PN#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8VAA;FYE;"UI
M;F9O)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4F5T
M<FEE=F4@26YF;W)M871I;VX@;VX@82!#:&%N;F5L)RP-"B`@("`@("`@("`@
M("=F=6YC=&EO;B<@/3X@)V1O26YF;R<L#0H@("`@("`@("`@("`G<VAO<G1C
M=70G(#T^("=C:2<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X-"DQI<W0@=&AE
M(&9I;&5S(&EN(&%N(&EN<W1A;&QE9"!P86-K86=E+@T*)PT*("`@("`@("`@
M("`@*2P-"B`@("`@("`@)V-H86YN96PM86QI87,G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W-U;6UA<GDG(#T^("=3<&5C:69Y(&%N(&%L:6%S('1O(&$@
M8VAA;FYE;"!N86UE)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O
M06QI87,G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8VAA)RP-"B`@
M("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@I+`T*("`@("`@("`@("`@
M)V1O8R<@/3X@)SQC:&%N;F5L/B`\86QI87,^#0I3<&5C:69Y(&$@<W!E8VEF
M:6,@86QI87,@=&\@=7-E(&9O<B!A(&-H86YN96P@;F%M92X-"E1H92!A;&EA
M<R!M87D@;F]T(&)E(&%N(&5X:7-T:6YG(&-H86YN96P@;F%M92!O<@T*86QI
M87,N#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8VAA;FYE;"UD:7-C
M;W9E<B<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)TEN
M:71I86QI>F4@82!#:&%N;F5L(&9R;VT@:71S('-E<G9E<B<L#0H@("`@("`@
M("`@("`G9G5N8W1I;VXG(#T^("=D;T1I<V-O=F5R)RP-"B`@("`@("`@("`@
M("=S:&]R=&-U="<@/3X@)V1I)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]
M/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@T*
M3&ES="!T:&4@9FEL97,@:6X@86X@:6YS=&%L;&5D('!A8VMA9V4N#0HG#0H@
M("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@("`@*B!014%27T-O
M;6UA;F1?4F5G:7-T<GD@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`
M86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M
M;6%N9%]#:&%N;F5L<R@F)'5I+"`F)&-O;F9I9RD-"B`@("![#0H@("`@("`@
M('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL("1C;VYF:6<I.PT*
M("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&1O3&ES="@I#0H@
M("`@#0H@("`@9G5N8W1I;VX@7W-O<G1#:&%N;F5L<R@D82P@)&(I#0H@("`@
M>PT*("`@("`@("!R971U<FX@<W1R;F%T8V%S96-M<"@D82T^9V5T3F%M92@I
M+"`D8BT^9V5T3F%M92@I*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!D;TQI
M<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@
M("`@("`D<F5G:7-T97)E9"`]("1R96<M/F=E=$-H86YN96QS*"D[#0H@("`@
M("`@('5S;W)T*"1R96=I<W1E<F5D+"!A<G)A>2@F)'1H:7,L("=?<V]R=&-H
M86YN96QS)RDI.PT*("`@("`@("`D:2`]("1J(#T@,#L-"B`@("`@("`@)&1A
M=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`G4F5G:7-T
M97)E9"!#:&%N;F5L<SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U
M92P-"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)T-H86YN96PG
M+"`G4W5M;6%R>2<I#0H@("`@("`@("`@("`I.PT*("`@("`@("!F;W)E86-H
M("@D<F5G:7-T97)E9"!A<R`D8VAA;FYE;"D@>PT*("`@("`@("`@("`@)&1A
M=&%;)V1A=&$G75M=(#T@87)R87DH)&-H86YN96PM/F=E=$YA;64H*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-H86YN96PM
M/F=E=%-U;6UA<GDH*2D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT
M*"1R96=I<W1E<F5D*3T],"D@>PT*("`@("`@("`@("`@)&1A=&$@/2`G*&YO
M(')E9VES=&5R960@8VAA;FYE;',I)SL-"B`@("`@("`@?0T*("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@(`T*("`@(&9U;F-T:6]N(&1O
M57!D871E06QL*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH
M*3L-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)'1H:7,M/F-O;F9I9RT^9V5T
M*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("!I9B`H(21R96<M/F-H
M86YN96Q%>&ES=',H)&]P=&EO;G-;)V-H86YN96PG72DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)U5N:VYO=VX@8VAA
M;FYE;"`B)R`N("1O<'1I;VYS6R=C:&%N;F5L)UT@+B`G(B<I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A
M=6QT7V-H86YN96PG+"`D;W!T:6]N<ULG8VAA;FYE;"==*3L-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F
M875L=%]C:&%N;F5L)RP@)W!E87(N<&AP+FYE="<I.PT*("`@("`@("!]#0H@
M("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[
M#0H@("`@("`@("1C:&%N;F5L<R`]("1R96UO=&4M/F-A;&PH)V-H86YN96PN
M;&ES=$%L;"<I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;FYE
M;',I*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U
M;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U
M<FX@)&-H86YN96QS.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-?87)R
M87DH)&-H86YN96QS*2!\?"!I<W-E="@D8VAA;FYE;'-;)V9A=6QT0V]D92==
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT
M7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"));F-O<G)E8W0@8VAA;FYE;"!L:7-T:6YG
M(')E='5R;F5D(&9R;VT@8VAA;FYE;"`G)&-H86XG(BD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"%C;W5N="@D8VAA;FYE;',I*2![#0H@("`@("`@("`@
M("`D9&%T82`]("=N;R!U<&1A=&5S(&%V86EL86)L92<[#0H@("`@("`@('T-
M"B`@("`@("`@)&1L(#T@)B1T:&ES+3YG971$;W=N;&]A9&5R*"D[#0H@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG*2D@>PT*("`@("`@("`@
M("`@<F5Q=6ER95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@?0T*("`@
M("`@("`D=&UP9&ER(#T@4WES=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI.PT*
M("`@("`@("!F;W)E86-H("@D8VAA;FYE;',@87,@)&-H86YN96PI('L-"B`@
M("`@("`@("`@("1C:&%N;F5L(#T@)&-H86YN96Q;,%T[#0H@("`@("`@("`@
M("`D<V%V92`]("1C:&%N;F5L.PT*("`@("`@("`@("`@:68@*"1R96<M/F-H
M86YN96Q%>&ES=',H)&-H86YN96PL('1R=64I*2![#0H@("`@("`@("`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*")5<&1A=&EN9R!C:&%N;F5L(%PB
M)&-H86YN96Q<(B(L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("`D=&5S
M="`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PL('1R=64I.PT*("`@("`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T97-T*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(D-H86YN96P@
M)R1C:&%N;F5L)R!I<R!C;W)R=7!T(&EN(')E9VES=')Y(2(L("1C;VUM86YD
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&QA<W1M;V1I9FEE9"`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1L87-T;6]D:69I960@/2`D=&5S="T^;&%S=$UO9&EF:65D*"D[#0H@
M("`@("`@("`@("`@("`@("`@(`T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M)&1L+3YD;W=N;&]A9$AT='`H)VAT='`Z+R\G("X@)'1E<W0M/F=E=$YA;64H
M*2`N("<O8VAA;FYE;"YX;6PG+`T*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DL("1T;7!D:7(L(&YU;&PL("1L87-T;6]D:69I960I.PT*("`@("`@
M("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8V]N=&5N=',I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G
M15)23U(Z($-A;FYO="!R971R:65V92!C:&%N;F5L+GAM;"!F;W(@8VAA;FYE
M;"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&5S="T^9V5T3F%M
M92@I("X@)R(G+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!I
M9B`H(21C;VYT96YT<RD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H(D-H86YN96P@7"(D8VAA;FYE;%PB(&ES('5P+71O
M+61A=&4B+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!L:7-T
M*"1C;VYT96YT<RP@)&QA<W1M;V1I9FEE9"D@/2`D8V]N=&5N=',[#0H@("`@
M("`@("`@("`@("`@)&EN9F\@/2!I;7!L;V1E*"<G+"!F:6QE*"1C;VYT96YT
M<RDI.PT*("`@("`@("`@("`@("`@(&EF("@A)&EN9F\I('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")#:&%N;F5L(%PB
M)&-H86YN96Q<(B!I<R!U<"UT;RUD871E(BP@)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE
M;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@
M)U!%05(O0VAA;FYE;$9I;&4N<&AP)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@)&-H86YN96QI;F9O(#T@;F5W(%!%05)?0VAA;FYE
M;$9I;&4[#0H@("`@("`@("`@("`@("`@)&-H86YN96QI;F9O+3YF<F]M6&UL
M4W1R:6YG*"1I;F9O*3L-"B`@("`@("`@("`@("`@("!I9B`H)&-H86YN96QI
M;F9O+3YG971%<G)O<G,H*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H(D1O=VYL;V%D960@8VAA;FYE;"!D871A(&9R
M;VT@8VAA;FYE;"!<(B1C:&%N;F5L7"(@(B`N(`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)VES(&-O<G)U<'0L('-K:7!P:6YG)RP@)&-O;6UA;F0I.PT*
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@)&-H86YN96P@/2`D8VAA;FYE;&EN9F\[
M#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L+3YG971.86UE*"D@(3T@
M)'-A=F4I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"=%4E)/4CH@4V5C=7)I='D@<FES:R`M(&1O=VYL;V%D960@8VAA
M;FYE;"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=D969I;FET:6]N
M(&9I;&4@9F]R(&-H86YN96P@(B<-"B`@("`@("`@("`@("`@("`@("`@("`@
M("X@)&-H86YN96PM/F=E=$YA;64H*2`N("<@9G)O;2!C:&%N;F5L("(G("X@
M)'-A=F4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)R(N("!4;R!U<V4@
M86YY=V%Y+"!U<V4@8VAA;FYE;"UU<&1A=&4G+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D<F5G+3YU<&1A=&5#:&%N;F5L*"1C:&%N;F5L
M+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@:68@*"1R96<M/FES06QI87,H)&-H86YN96PI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1T96UP(#T@)B1R96<M/F=E=$-H86YN96PH
M)&-H86YN96PI.PT*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D=&5M<"DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&5M<"D[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'1E;7`M/G-E=$%L:6%S*"1T
M96UP+3YG971.86UE*"DL('1R=64I.R`O+R!S970@=&AE(&%L:6%S('1O('1H
M92!C:&%N;F5L(&YA;64-"B`@("`@("`@("`@("`@("`@("`@:68@*"1R96<M
M/F-H86YN96Q%>&ES=',H)'1E;7`M/F=E=$YA;64H*2DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G15)23U(Z
M(&5X:7-T:6YG(&-H86YN96P@(B<@+B`D=&5M<"T^9V5T3F%M92@I("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!I<R!A;&EA<V5D('1O("(G
M("X@)&-H86YN96P@+B`G(B!A;')E861Y(&%N9"!C86YN;W0@8F4@)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)E+6%L:6%S960@=&\@(B<@
M+B`D=&5M<"T^9V5T3F%M92@I("X@)R(@8F5C875S92!A(&-H86YN96P@=VET
M:"`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&AA="!N86UE
M(&]R(&%L:6%S(&%L<F5A9'D@97AI<W1S(2`@4&QE87-E(')E+6%L:6%S(&%N
M9"!T<GD@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%G86EN
M+B<L("1C;VUM86YD*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B061D
M:6YG(&YE=R!C:&%N;F5L(%PB)&-H86YN96Q<(B(L("1C;VUM86YD*3L-"B`@
M("`@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S
M(#T@)&1L+3YD;W=N;&]A9$AT='`H)VAT='`Z+R\G("X@)&-H86YN96P@+B`G
M+V-H86YN96PN>&UL)RP-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I
M+"`D=&UP9&ER+"!N=6QL+"!F86QS92D[#0H@("`@("`@("`@("`@("`@4$5!
M4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1C;VYT96YT<RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=%4E)/4CH@0V%N;F]T
M(')E=')I979E(&-H86YN96PN>&UL(&9O<B!C:&%N;F5L("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1C:&%N;F5L("X@)R(G+"`D8V]M;6%N9"D[
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!L:7-T*"1C;VYT96YT<RP@)&QA<W1M
M;V1I9FEE9"D@/2`D8V]N=&5N=',[#0H@("`@("`@("`@("`@("`@)&EN9F\@
M/2!I;7!L;V1E*"<G+"!F:6QE*"1C;VYT96YT<RDI.PT*("`@("`@("`@("`@
M("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-H86YN96Q&:6QE)RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T-H86YN
M96Q&:6QE+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1C:&%N;F5L:6YF;R`](&YE=R!014%27T-H86YN96QF:6QE.PT*("`@
M("`@("`@("`@("`@("1C:&%N;F5L:6YF;RT^9G)O;5AM;%-T<FEN9R@D:6YF
M;RD[#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N;F5L:6YF;RT^9V5T17)R
M;W)S*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*")$;W=N;&]A9&5D(&-H86YN96P@9&%T82!F<F]M(&-H86YN96P@
M7"(D8VAA;FYE;%PB(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`G(&ES
M(&-O<G)U<'0L('-K:7!P:6YG)RP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&-H86YN96P@/2`D8VAA;FYE;&EN9F\[#0H@("`@("`@("`@
M("`@("`@:68@*"1C:&%N;F5L+3YG971.86UE*"D@(3T@)'-A=F4I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=%4E)/
M4CH@4V5C=7)I='D@<FES:R`M(&1O=VYL;V%D960@8VAA;FYE;"`G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("=D969I;FET:6]N(&9I;&4@9F]R(&-H
M86YN96P@(B<-"B`@("`@("`@("`@("`@("`@("`@("`@("X@)&-H86YN96PM
M/F=E=$YA;64H*2`N("<B(&9R;VT@8VAA;FYE;"`B)R`N("1S879E("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<B+B`@5&\@=7-E(&%N>7=A>2P@=7-E
M(&-H86YN96PM=7!D871E)RP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@
M("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)')E9RT^861D0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE
M9"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN96PI
M.PT*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)W5P9&%T92UC:&%N
M;F5L<R!C;VUP;&5T92<L("1C;VUM86YD*3L-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*("`@(`T*("`@(&9U;F-T:6]N(&1O26YF;R@D8V]M;6%N
M9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H<VEZ
M96]F*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@B3F\@8VAA;FYE;"!S<&5C:69I960B*3L-"B`@("`@
M("`@?0T*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES
M=')Y*"D[#0H@("`@("`@("1C:&%N;F5L(#T@<W1R=&]L;W=E<B@D<&%R86US
M6S!=*3L-"B`@("`@("`@:68@*"1R96<M/F-H86YN96Q%>&ES=',H)&-H86YN
M96PI*2![#0H@("`@("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH
M)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H
M86XI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1C:&%N*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(&EF("AS=')P;W,H)&-H86YN96PL("<Z+R\G*2D@>PT*
M("`@("`@("`@("`@("`@("1D;W=N;&]A9&5R(#T@)B1T:&ES+3YG971$;W=N
M;&]A9&5R*"D[#0H@("`@("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)U-Y<W1E;2<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC
M92`G4WES=&5M+G!H<"<[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G*2D[
M#0H@("`@("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI
M;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@("`@("1L;V,@
M/2`D9&]W;FQO861E<BT^9&]W;FQO861(='1P*"1C:&%N;F5L+"`D=&AI<RT^
M=6DL("1T;7!D:7(I.PT*("`@("`@("`@("`@("`@(%!%05(Z.G-T871I8U!O
M<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D;&]C*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!O<&5N("(G("X@)&-H86YN96P@
M+B`G(B<I.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("1C;VYT96YT<R`](&EM<&QO9&4H)R<L(&9I;&4H)&QO8RDI
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1P87)A;7-;,%TL("=R)RD[
M#0H@("`@("`@("`@("`@("`@:68@*"$D9G`I('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*$!F:6QE7V5X:7-T<R@D<&%R86US6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#
M86YN;W0@;W!E;B`B)R`N("1P87)A;7-;,%T@+B`G(B<I.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;FMN;W=N(&-H86YN96P@(B<@
M+B`D8VAA;FYE;"`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S(#T@
M)R<[#0H@("`@("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1F<"DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S("X](&9R96%D*"1F<"P@,3`R
M-"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9C;&]S
M92@D9G`I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%C;&%S
M<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&-H86X@/2!N97<@4$5!4E]#:&%N
M;F5L1FEL93L-"B`@("`@("`@("`@("1C:&%N+3YF<F]M6&UL4W1R:6YG*"1C
M;VYT96YT<RD[#0H@("`@("`@("`@("`D8VAA;BT^=F%L:61A=&4H*3L-"B`@
M("`@("`@("`@(&EF("@D97)R<R`]("1C:&%N+3YG971%<G)O<G,H=')U92DI
M('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R<R!A<R`D97)R*2![
M#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M97)R6R=L979E;"==("X@)SH@)R`N("1E<G);)VUE<W-A9V4G72D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0VAA;FYE;"!F:6QE("(G("X@)'!A<F%M<ULP72`N("<B
M(&ES(&YO="!V86QI9"<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(&EF("@D8VAA;BD@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`D
M8VAA;BT^9V5T3F%M92@I.PT*("`@("`@("`@("`@)&-A<'1I;VX@/2`G0VAA
M;FYE;"`G("X@)&-H86YN96P@+B`G($EN9F]R;6%T:6]N.B<[#0H@("`@("`@
M("`@("`D9&%T83$@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`G8V%P=&EO
M;B<@/3X@)&-A<'1I;VXL#0H@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M=')U92D[#0H@("`@("`@("`@("`D9&%T83%;)V1A=&$G75LG<V5R=F5R)UT@
M/2!A<G)A>2@G3F%M92!A;F0@4V5R=F5R)RP@)&-H86XM/F=E=$YA;64H*2D[
M#0H@("`@("`@("`@("!I9B`H)&-H86XM/F=E=$%L:6%S*"D@(3T@)&-H86XM
M/F=E=$YA;64H*2D@>PT*("`@("`@("`@("`@("`@("1D871A,5LG9&%T82==
M6R=A;&EA<R==(#T@87)R87DH)T%L:6%S)RP@)&-H86XM/F=E=$%L:6%S*"DI
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1A=&$Q6R=D871A)UU;
M)W-U;6UA<GDG72`](&%R<F%Y*"=3=6UM87)Y)RP@)&-H86XM/F=E=%-U;6UA
M<GDH*2D[#0H@("`@("`@("`@("`D=F%L:61A=&4@/2`D8VAA;BT^9V5T5F%L
M:61A=&EO;E!A8VMA9V4H*3L-"B`@("`@("`@("`@("1D871A,5LG9&%T82==
M6R=V<&%C:V%G92==(#T@87)R87DH)U9A;&ED871I;VX@4&%C:V%G92!.86UE
M)RP@)'9A;&ED871E6R=?8V]N=&5N="==*3L-"B`@("`@("`@("`@("1D871A
M,5LG9&%T82==6R=V<&%C:V%G979E<G-I;VXG72`]#0H@("`@("`@("`@("`@
M("`@87)R87DH)U9A;&ED871I;VX@4&%C:V%G92!697)S:6]N)RP@)'9A;&ED
M871E6R=A='1R:6)S)UU;)W9E<G-I;VXG72D[#0H@("`@("`@("`@("`D9"`]
M(&%R<F%Y*"D[#0H@("`@("`@("`@("`D9%LG;6%I;B==(#T@)&1A=&$Q.PT*
M#0H@("`@("`@("`@("`D9&%T85LG9&%T82==(#T@87)R87DH*3L-"B`@("`@
M("`@("`@("1D871A6R=C87!T:6]N)UT@/2`G4V5R=F5R($-A<&%B:6QI=&EE
M<R<[#0H@("`@("`@("`@("`D9&%T85LG:&5A9&QI;F4G72`](&%R<F%Y*"=4
M>7!E)RP@)U9E<G-I;VXO4D535"!T>7!E)RP@)T9U;F-T:6]N($YA;64O4D53
M5"!B87-E)RD[#0H@("`@("`@("`@("`D8V%P86)I;&ET:65S(#T@)&-H86XM
M/F=E=$9U;F-T:6]N<R@G>&UL<G!C)RD[#0H@("`@("`@("`@("`D<V]A<',@
M/2`D8VAA;BT^9V5T1G5N8W1I;VYS*"=S;V%P)RD[#0H@("`@("`@("`@("!I
M9B`H)&-A<&%B:6QI=&EE<R!\?"`D<V]A<',@?'P@)&-H86XM/G-U<'!O<G1S
M4D535"@I*2![#0H@("`@("`@("`@("`@("`@:68@*"1C87!A8FEL:71I97,I
M('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D8V%P86)I;&ET
M:65S6S!=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&-A<&%B:6QI
M=&EE<R`](&%R<F%Y*"1C87!A8FEL:71I97,I.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C87!A8FEL
M:71I97,@87,@)'!R;W1O8V]L*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@G>&UL<G!C)RP@)'!R;W1O8V]L
M6R=A='1R:6)S)UU;)W9E<G-I;VXG72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<')O=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M(&EF("@D<V]A<',I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D<V]A<'-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D<V]A
M<',@/2!A<G)A>2@D<V]A<',I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S;V%P<R!A<R`D<')O=&]C
M;VPI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D871A6R=D871A)UU;
M72`](&%R<F%Y*"=S;V%P)RP@)'!R;W1O8V]L6R=A='1R:6)S)UU;)W9E<G-I
M;VXG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O=&]C;VQ;
M)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D8VAA;BT^<W5P<&]R
M='-215-4*"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&9U;F-S(#T@)&-H
M86XM/F=E=$9U;F-T:6]N<R@G<F5S="<I.PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1F=6YC<ULP72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1F=6YC<R`](&%R<F%Y*"1F=6YC<RD[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&9U;F-S
M(&%S("1P<F]T;V-O;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)V1A=&$G75M=(#T@87)R87DH)W)E<W0G+"`D<')O=&]C;VQ;)V%T=')I
M8G,G75LG='EP92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M<F]T;V-O;%LG7V-O;G1E;G0G72D[(`T*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@G3F\@<W5P
M<&]R=&5D('!R;W1O8V]L<R<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)&1;)W!R;W1O8V]L<R==(#T@)&1A=&$[#0H@("`@("`@("`@("`D9&%T
M85LG9&%T82==(#T@87)R87DH*3L-"B`@("`@("`@("`@("1M:7)R;W)S(#T@
M)&-H86XM/F=E=$UI<G)O<G,H*3L-"B`@("`@("`@("`@(&EF("@D;6ER<F]R
M<RD@>PT*("`@("`@("`@("`@("`@("1D871A6R=C87!T:6]N)UT@/2`G0VAA
M;FYE;"`G("X@)&-H86YN96P@+B`G($UI<G)O<G,Z)SL-"B`@("`@("`@("`@
M("`@("!U;G-E="@D9&%T85LG:&5A9&QI;F4G72D[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&UI<G)O<G,@87,@)&UI<G)O<BD@>PT*("`@("`@("`@
M("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D;6ER<F]R6R=A
M='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@("`@("1D6R=M
M:7)R;W)S)UT@/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&UI<G)O<G,@87,@)&UI<G)O<BD@>PT*("`@
M("`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==(#T@87)R87DH*3L-"B`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)V-A<'1I;VXG72`]("=-:7)R;W(@
M)R`N("1M:7)R;W);)V%T=')I8G,G75LG:&]S="==("X@)R!#87!A8FEL:71I
M97,G.PT*("`@("`@("`@("`@("`@("`@("`D9&%T85LG:&5A9&QI;F4G72`]
M(&%R<F%Y*"=4>7!E)RP@)U9E<G-I;VXO4D535"!T>7!E)RP@)T9U;F-T:6]N
M($YA;64O4D535"!B87-E)RD[#0H@("`@("`@("`@("`@("`@("`@("1C87!A
M8FEL:71I97,@/2`D8VAA;BT^9V5T1G5N8W1I;VYS*"=X;6QR<&,G+"`D;6ER
M<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@("`@
M("1S;V%P<R`]("1C:&%N+3YG971&=6YC=&EO;G,H)W-O87`G+"`D;6ER<F]R
M6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@D8V%P86)I;&ET:65S('Q\("1S;V%P<R!\?"`D8VAA;BT^<W5P<&]R='-2
M15-4*"1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1C87!A8FEL:71I97,I('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1C87!A8FEL:71I97-;
M,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C87!A
M8FEL:71I97,@/2!A<G)A>2@D8V%P86)I;&ET:65S*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&-A<&%B:6QI=&EE<R!A<R`D<')O=&]C;VPI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=
M(#T@87)R87DH)WAM;')P8R<L("1P<F]T;V-O;%LG871T<FEB<R==6R=V97)S
M:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<')O=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D<V]A<',I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1S;V%P<ULP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O87!S(#T@87)R87DH)'-O
M87!S*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'-O87!S(&%S("1P<F]T
M;V-O;"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M85LG9&%T82==6UT@/2!A<G)A>2@G<V]A<"<L("1P<F]T;V-O;%LG871T<FEB
M<R==6R=V97)S:6]N)UTL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<')O=&]C;VQ;)U]C;VYT96YT)UTI.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D8VAA;BT^<W5P<&]R='-2
M15-4*"1M:7)R;W);)V%T=')I8G,G75LG:&]S="==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1F=6YC<R`]("1C:&%N+3YG971&=6YC=&EO
M;G,H)W)E<W0G+"`D;6ER<F]R6R=A='1R:6)S)UU;)VAO<W0G72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9G5N8W-;,%TI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F=6YC<R`]
M(&%R<F%Y*"1F=6YC<RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1F=6YC
M<R!A<R`D<')O=&]C;VPI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)W)E<W0G+"`D<')O=&]C
M;VQ;)V%T=')I8G,G75LG='EP92==+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!R;W1O8V]L6R=?8V]N=&5N="==*3L@#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)TYO
M('-U<'!O<G1E9"!P<F]T;V-O;',G*3L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`D9%LG;6ER<F]R<')O=&]C;VQS)UT@
M/2`D9&%T83L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&0L("=C:&%N;F5L
M+6EN9F\G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G4V5R:6]U<R!E<G)O<CH@0VAA;FYE;"`B
M)R`N("1P87)A;7-;,%T@+@T*("`@("`@("`@("`@("`@("<B(&AA<R!A(&-O
M<G)U<'1E9"!R96=I<W1R>2!E;G1R>2<I.PT*("`@("`@("!]#0H@("`@?0T*
M#0H@("`@+R\@?7U]#0H@("`@#0H@("`@9G5N8W1I;VX@9&]$96QE=&4H)&-O
M;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@
M*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM9&5L971E.B!N;R!C:&%N;F5L
M('-P96-I9FEE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H
M:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*"$D<F5G
M+3YC:&%N;F5L17AI<W1S*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)V-H86YN96PM9&5L971E.B!C:&%N
M;F5L("(G("X@)'!A<F%M<ULP72`N("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@
M("`@("`@('T-"B`@("`@("`@)&-H86YN96P@/2`D<F5G+3YC:&%N;F5L3F%M
M92@D<&%R86US6S!=*3L-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R
M+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-A;FYO="!D96QE=&4@=&AE('!E87(N<&AP+FYE="!C:&%N;F5L
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96-L
M+G!H<"YN970G*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)T-A;FYO="!D96QE=&4@=&AE('!E8VPN<&AP+FYE="!C:&%N;F5L
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N;F5L(#T]("=?7W5R
M:2<I('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G
M0V%N;F]T(&1E;&5T92!T:&4@7U]U<FD@<'-E=61O+6-H86YN96PG*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R(#T@)')E
M9RT^;&ES=%!A8VMA9V5S*"1C:&%N;F5L*2DI('L-"B`@("`@("`@("`@(')E
M='5R;B`D97)R.PT*("`@("`@("!]#0H@("`@("`@(&EF("AC;W5N="@D97)R
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#
M:&%N;F5L("(G("X@)&-H86YN96P@+@T*("`@("`@("`@("`@("`@("<B(&AA
M<R!I;G-T86QL960@<&%C:V%G97,L(&-A;FYO="!D96QE=&4G*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H(21R96<M/F1E;&5T94-H86YN96PH)&-H86YN
M96PI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)T-H86YN96P@(B<@+B`D8VAA;FYE;"`N("<B(&1E;&5T:6]N(&9A:6QE9"<I
M.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I
M9RT^9&5L971E0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)T-H86YN96P@(B<@+B`D8VAA;FYE;"`N("<B
M(&1E;&5T960G+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!D;T%D9"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I
M#0H@("`@>PT*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE
M;"UA9&0Z(&YO(&-H86YN96P@9FEL92!S<&5C:69I960G*3L-"B`@("`@("`@
M?0T*("`@("`@("!I9B`H<W1R<&]S*"1P87)A;7-;,%TL("<Z+R\G*2D@>PT*
M("`@("`@("`@("`@)&1O=VYL;V%D97(@/2`F)'1H:7,M/F=E=$1O=VYL;V%D
M97(H*3L-"B`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=3>7-T96TG
M*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H
M<"<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&UP9&ER(#T@4WES
M=&5M.CIM:W1E;7`H87)R87DH)RUD)RDI.PT*("`@("`@("`@("`@4$5!4CHZ
M<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*
M("`@("`@("`@("`@)&QO8R`]("1D;W=N;&]A9&5R+3YD;W=N;&]A9$AT='`H
M)'!A<F%M<ULP72P@)'1H:7,M/G5I+"`D=&UP9&ER+"!N=6QL+"!F86QS92D[
M#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&]C*2D@>PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE
M;"UA9&0Z($-A;FYO="!O<&5N("(G("X@)'!A<F%M<ULP72`N("<B)RD[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&QI<W0H)&QO
M8RP@)&QA<W1M;V1I9FEE9"D@/2`D;&]C.PT*("`@("`@("`@("`@("`@("1C
M;VYT96YT<R`](&EM<&QO9&4H)R<L(&9I;&4H)&QO8RDI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&QA<W1M;V1I
M9FEE9"`](&9A;'-E.PT*("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"1P87)A
M;7-;,%TL("=R)RD[#0H@("`@("`@("`@("!I9B`H(21F<"D@>PT*("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE;"UA
M9&0Z(&-A;FYO="!O<&5N("(G("X@)'!A<F%M<ULP72`N("<B)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D8V]N=&5N=',@/2`G)SL-"B`@("`@
M("`@("`@('=H:6QE("@A9F5O9B@D9G`I*2![#0H@("`@("`@("`@("`@("`@
M)&-O;G1E;G1S("X](&9R96%D*"1F<"P@,3`R-"D[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]#:&%N;F5L1FEL92<I*2![#0H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0VAA;FYE;$9I;&4N<&AP
M)SL-"B`@("`@("`@?0T*("`@("`@("`D8VAA;FYE;"`](&YE=R!014%27T-H
M86YN96Q&:6QE.PT*("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("1R97-U;'0@/2`D
M8VAA;FYE;"T^9G)O;5AM;%-T<FEN9R@D8V]N=&5N=',I.PT*("`@("`@("!0
M14%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF("@A
M)')E<W5L="D@>PT*("`@("`@("`@("`@)&5X:70@/2!F86QS93L-"B`@("`@
M("`@("`@(&EF("AC;W5N="@D97)R;W)S(#T@)&-H86YN96PM/F=E=$5R<F]R
M<RAT<G5E*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D97)R;W)S
M(&%S("1E<G)O<BD@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM
M/F]U='!U=$1A=&$H=6-F:7)S="@D97)R;W);)VQE=F5L)UT@+B`G.B`G("X@
M)&5R<F]R6R=M97-S86=E)UTI*3L-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"$D97AI="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X:70@/2`D
M97)R;W);)VQE=F5L)UT@/3T@)V5R<F]R)R`_('1R=64@.B!F86QS93L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!I9B`H)&5X:70I('L-"B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=C:&%N;F5L+6%D9#H@:6YV86QI
M9"!C:&%N;F5L+GAM;"!F:6QE)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M
M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*"1R96<M/F-H
M86YN96Q%>&ES=',H)&-H86YN96PM/F=E=$YA;64H*2DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE;"UA9&0Z($-H
M86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M92@I("X-"B`@("`@("`@("`@
M("`@("`G(B!E>&ES=',L('5S92!C:&%N;F5L+75P9&%T92!T;R!U<&1A=&4@
M96YT<GDG*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5T(#T@)')E9RT^861D
M0VAA;FYE;"@D8VAA;FYE;"P@)&QA<W1M;V1I9FEE9"D[#0H@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("!R971U<FX@
M)')E=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R970I('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G8VAA;FYE;"UA9&0Z
M(&%D9&EN9R!#:&%N;F5L("(G("X@)&-H86YN96PM/F=E=$YA;64H*2`N#0H@
M("`@("`@("`@("`@("`@)R(@=&\@<F5G:7-T<GD@9F%I;&5D)RD[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T0VAA;FYE;',H)')E
M9RT^;&ES=$-H86YN96QS*"DI.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YW
M<FET94-O;F9I9T9I;&4H*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*"=!9&1I;F<@0VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@
M+B`G(B!S=6-C965D960G+"`D8V]M;6%N9"D[#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9&]5<&1A=&4H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U-Y<W1E;2<I*2![
M#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U-Y<W1E;2YP:'`G.PT*("`@
M("`@("!]#0H@("`@("`@("1T;7!D:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A
M>2@G+60G*2D[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(DYO
M(&-H86YN96P@9FEL92!S<&5C:69I960B*3L-"B`@("`@("`@?0T*("`@("`@
M("`D;&%S=&UO9&EF:65D(#T@9F%L<V4[#0H@("`@("`@(&EF("@H(69I;&5?
M97AI<W1S*"1P87)A;7-;,%TI('Q\(&ES7V1I<B@D<&%R86US6S!=*2D-"B`@
M("`@("`@("`@("`@)B8@)')E9RT^8VAA;FYE;$5X:7-T<RAS=')T;VQO=V5R
M*"1P87)A;7-;,%TI*2D@>PT*("`@("`@("`@("`@)&,@/2`D<F5G+3YG971#
M:&%N;F5L*'-T<G1O;&]W97(H)'!A<F%M<ULP72DI.PT*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&,I*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"1C*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G4F5T<FEE=FEN9R!C
M:&%N;F5L+GAM;"!F<F]M(')E;6]T92!S97)V97(G*3L-"B`@("`@("`@("`@
M("1D;"`]("8D=&AI<RT^9V5T1&]W;FQO861E<BAA<G)A>2@I*3L-"B`@("`@
M("`@("`@("\O(&EF(&9O<F-E(&ES('-P96-I9FEE9"P@=7-E(&$@=&EM97-T
M86UP(&]F("(Q(B!T;R!F;W)C92!R971R:65V86P-"B`@("`@("`@("`@("1L
M87-T;6]D:69I960@/2!I<W-E="@D;W!T:6]N<ULG9F]R8V4G72D@/R!F86QS
M92`Z("1C+3YL87-T36]D:69I960H*3L-"B`@("`@("`@("`@(%!%05(Z.G-T
M871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@("`@("1C;VYT96YT<R`]("1D;"T^9&]W;FQO861(='1P*"=H='1P
M.B\O)R`N("1C+3YG971.86UE*"D@+B`G+V-H86YN96PN>&UL)RP-"B`@("`@
M("`@("`@("`@("`D=&AI<RT^=6DL("1T;7!D:7(L(&YU;&PL("1L87-T;6]D
M:69I960I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-O;G1E
M;G1S*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G0V%N;F]T(')E=')I979E(&-H86YN96PN>&UL(&9O<B!C:&%N;F5L
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@)&,M/F=E=$YA;64H*2`N("<B
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!L:7-T*"1C;VYT96YT
M<RP@)&QA<W1M;V1I9FEE9"D@/2`D8V]N=&5N=',[#0H@("`@("`@("`@("!I
M9B`H(21C;VYT96YT<RD@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@B0VAA;FYE;"`D<&%R86US6S!=(&-H86YN96PN>&UL(&ES
M('5P('1O(&1A=&4B*3L-"B`@("`@("`@("`@("`@("!R971U<FX[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D8V]N=&5N=',@/2!I;7!L;V1E*"<G
M+"!F:6QE*"1C;VYT96YT<RDI.PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)&-H86YN96P@/2!N97<@4$5!4E]#:&%N
M;F5L1FEL93L-"B`@("`@("`@("`@("1C:&%N;F5L+3YF<F]M6&UL4W1R:6YG
M*"1C;VYT96YT<RD[#0H@("`@("`@("`@("!I9B`H(21C:&%N;F5L+3YG971%
M<G)O<G,H*2D@>PT*("`@("`@("`@("`@("`@("\O('-E8W5R:71Y(&-H96-K
M.B!I<R!T:&4@9&]W;FQO861E9"!F:6QE(&9O<B!T:&4@8VAA;FYE;"!W92!G
M;W0@:70@9G)O;3\-"B`@("`@("`@("`@("`@("!I9B`H<W1R=&]L;W=E<B@D
M8VAA;FYE;"T^9V5T3F%M92@I*2`A/2!S=')T;VQO=V5R*"1C+3YG971.86UE
M*"DI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG9F]R8V4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;&]G*#`L("=705).24Y'.B!D;W=N;&]A9&5D(&-H86YN96P@9&5F
M:6YI=&EO;B!F:6QE)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R!F;W(@8VAA;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@+B`G(B!F
M<F]M(&-H86YN96P@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('-T<G1O;&]W97(H)&,M/F=E=$YA;64H*2D@+B`G(B<I.PT*("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=%4E)/4CH@9&]W;FQO861E9"!C
M:&%N;F5L(&1E9FEN:71I;VX@9FEL92<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<@9F]R(&-H86YN96P@(B<@+B`D8VAA;FYE;"T^9V5T3F%M
M92@I("X@)R(@9G)O;2!C:&%N;F5L("(G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!S=')T;VQO=V5R*"1C+3YG971.86UE*"DI("X@)R(G*3L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(&EF
M("AS=')P;W,H)'!A<F%M<ULP72P@)SHO+R<I*2![#0H@("`@("`@("`@("`@
M("`@)&1L(#T@)B1T:&ES+3YG971$;W=N;&]A9&5R*"D[#0H@("`@("`@("`@
M("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/
M4E]215154DXI.PT*("`@("`@("`@("`@("`@("1L;V,@/2`D9&PM/F1O=VYL
M;V%D2'1T<"@D<&%R86US6S!=+`T*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DL("1T;7!D:7(L(&YU;&PL("1L87-T;6]D:69I960I.PT*("`@("`@
M("`@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;&]C*2D@>PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(D-A
M;FYO="!O<&5N("(@+B`D<&%R86US6S!=*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!L:7-T*"1L;V,L("1L87-T
M;6]D:69I960I(#T@)&QO8SL-"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E
M;G1S(#T@:6UP;&]D92@G)RP@9FEL92@D;&]C*2D[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D
M9G`@/2!`9F]P96XH)'!A<F%M<ULP72P@)W(G*3L-"B`@("`@("`@("`@("`@
M("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(D-A;FYO="!O<&5N("(@+B`D<&%R86US6S!=*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&-O;G1E;G1S
M(#T@)R<[#0H@("`@("`@("`@("`@("`@=VAI;&4@*"%F96]F*"1F<"DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&-O;G1E;G1S("X](&9R96%D*"1F<"P@
M,3`R-"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&9C
M;&]S92@D9G`I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%C
M;&%S<U]E>&ES=',H)U!%05)?0VAA;FYE;$9I;&4G*2D@>PT*("`@("`@("`@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#:&%N;F5L1FEL92YP:'`G.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&-H86YN96P@/2!N97<@4$5!
M4E]#:&%N;F5L1FEL93L-"B`@("`@("`@("`@("1C:&%N;F5L+3YF<F]M6&UL
M4W1R:6YG*"1C;VYT96YT<RD[#0H@("`@("`@('T-"B`@("`@("`@)&5X:70@
M/2!F86QS93L-"B`@("`@("`@:68@*&-O=6YT*"1E<G)O<G,@/2`D8VAA;FYE
M;"T^9V5T17)R;W)S*'1R=64I*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&5R<F]R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H=6-F:7)S="@D97)R;W);)VQE=F5L)UT@+B`G.B`G
M("X@)&5R<F]R6R=M97-S86=E)UTI*3L-"B`@("`@("`@("`@("`@("!I9B`H
M(21E>&ET*2![#0H@("`@("`@("`@("`@("`@("`@("1E>&ET(#T@)&5R<F]R
M6R=L979E;"==(#T]("=E<G)O<B<@/R!T<G5E(#H@9F%L<V4[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1E
M>&ET*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=);G9A;&ED(&-H86YN96PN>&UL(&9I;&4G*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R96<M/F-H86YN96Q%>&ES
M=',H)&-H86YN96PM/F=E=$YA;64H*2DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G17)R;W(Z($-H86YN96P@(B<@+B`D8VAA
M;FYE;"T^9V5T3F%M92@I("X-"B`@("`@("`@("`@("`@("`G(B!D;V5S(&YO
M="!E>&ES="P@=7-E(&-H86YN96PM861D('1O(&%D9"!A;B!E;G1R>2<I.PT*
M("`@("`@("!]#0H@("`@("`@("1R970@/2`D<F5G+3YU<&1A=&5#:&%N;F5L
M*"1C:&%N;F5L+"`D;&%S=&UO9&EF:65D*3L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)')E="DI('L-"B`@("`@("`@("`@(')E='5R;B`D<F5T.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("@A)')E="D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5<&1A=&EN9R!#:&%N;F5L("(G
M("X@)&-H86YN96PM/F=E=$YA;64H*2`N#0H@("`@("`@("`@("`@("`@)R(@
M:6X@<F5G:7-T<GD@9F%I;&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^<V5T0VAA;FYE;',H)')E9RT^;&ES=$-H86YN96QS*"DI
M.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YW<FET94-O;F9I9T9I;&4H*3L-
M"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"=5<&1A=&4@;V8@0VAA
M;FYE;"`B)R`N("1C:&%N;F5L+3YG971.86UE*"D@+B`G(B!S=6-C965D960G
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B`F9V5T1&]W;FQO861E<B@I#0H@
M("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$;W=N;&]A
M9&5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]$;W=N
M;&]A9&5R+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@)&$@/2!N97<@4$5!
M4E]$;W=N;&]A9&5R*"1T:&ES+3YU:2P@87)R87DH*2P@)'1H:7,M/F-O;F9I
M9RD[#0H@("`@("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("!F=6YC=&EO
M;B!D;T%L:6%S*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![
M#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH
M*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`]/2`Q*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TYO(&-H86YN96P@
M86QI87,@<W!E8VEF:65D)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I
M>F5O9B@D<&%R86US*2`A/2`R*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H#0H@("`@("`@("`@("`@("`@)TEN=F%L:60@9F]R
M;6%T+"!C;W)R96-T(&ES.B!C:&%N;F5L+6%L:6%S(&-H86YN96P@86QI87,G
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(21R96<M/F-H86YN96Q%>&ES
M=',H)'!A<F%M<ULP72P@=')U92DI('L-"B`@("`@("`@("`@(&EF("@D<F5G
M+3YI<T%L:6%S*"1P87)A;7-;,%TI*2![#0H@("`@("`@("`@("`@("`@)&5X
M=')A(#T@)R`H=7-E(")C:&%N;F5L+6%L:6%S("<@+B`D<F5G+3YC:&%N;F5L
M3F%M92@D<&%R86US6S!=*2`N("<@)R`N#0H@("`@("`@("`@("`@("`@("`@
M('-T<G1O;&]W97(H)'!A<F%M<ULQ72D@+B`G(BDG.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D97AT<F$@/2`G)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@G(B<@+B`D<&%R86US6S!=("X@)R(@:7,@;F]T(&$@=F%L:60@8VAA;FYE
M;"<@+B`D97AT<F$I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D<F5G+3YI
M<T%L:6%S*"1P87)A;7-;,5TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)T-H86YN96P@(B<@+B`D<F5G+3YC:&%N;F5L3F%M
M92@D<&%R86US6S%=*2`N("<B(&ES("<@+@T*("`@("`@("`@("`@("`@("=A
M;')E861Y(&%L:6%S960@=&\@(B<@+B!S=')T;VQO=V5R*"1P87)A;7-;,5TI
M("X@)R(L(&-A;FYO="!R92UA;&EA<R<I.PT*("`@("`@("!]#0H@("`@("`@
M("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)'!A<F%M<ULP72D[#0H@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#;W)R=7!T(')E9VES=')Y/R`@
M17)R;W(@<F5T<FEE=FEN9R!C:&%N;F5L("(G("X@)'!A<F%M<ULP72`N#0H@
M("`@("`@("`@("`@("`@)R(@:6YF;W)M871I;VX@*"<@+B`D8VAA;BT^9V5T
M365S<V%G92@I("X@)RDG*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!M86ME
M(&ET(&$@;&]C86P@86QI87,-"B`@("`@("`@:68@*"$D8VAA;BT^<V5T06QI
M87,H<W1R=&]L;W=E<B@D<&%R86US6S%=*2P@=')U92DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G06QI87,@(B<@+B!S=')T
M;VQO=V5R*"1P87)A;7-;,5TI("X-"B`@("`@("`@("`@("`@("`G(B!I<R!N
M;W0@82!V86QI9"!C:&%N;F5L(&%L:6%S)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)')E9RT^=7!D871E0VAA;FYE;"@D8VAA;BD[#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@G0VAA;FYE;"`B)R`N("1C:&%N+3YG971.86UE
M*"D@+B`G(B!A;&EA<V5D('-U8V-E<W-F=6QL>2!T;R`B)R`N#0H@("`@("`@
M("`@("!S=')T;VQO=V5R*"1P87)A;7-;,5TI("X@)R(G*3L-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!D;T1I<V-O=F5R*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US
M*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H(DYO(&-H86YN96P@<V5R=F5R('-P96-I9FEE9"(I.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1P87)A;7-;,%TI
M*2![#0H@("`@("`@("`@("!I9B`H)')E9RT^:7-!;&EA<R@D<&%R86US6S!=
M*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B02!C:&%N;F5L(&%L:6%S(&YA;65D(%PB)'!A<F%M<ULP75PB("(@+@T*
M("`@("`@("`@("`@("`@("`@("`G86QR96%D>2!E>&ES=',L(&%L:6%S:6YG
M(&-H86YN96P@(B<@+B`D<F5G+3YC:&%N;F5L3F%M92@D<&%R86US6S!=*0T*
M("`@("`@("`@("`@("`@("`@("`N("<B)RD[#0H@("`@("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B0VAA;FYE;"!<(B1P87)A;7-;,%U<(B!I<R!A;')E861Y(&EN:71I86QI
M>F5D(BD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H
M:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@
M("`@("`@)&5R<B`]("1T:&ES+3YD;T%D9"@D8V]M;6%N9"P@)&]P=&EO;G,L
M(&%R<F%Y*"=H='1P.B\O)R`N("1P87)A;7-;,%T@+B`G+V-H86YN96PN>&UL
M)RDI.PT*("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PT*("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*")$:7-C;W9E<GD@;V8@8VAA;FYE
M;"!<(B1P87)A;7-;,%U<(B!F86EL960@*"(@+@T*("`@("`@("`@("`@("`@
M("1E<G(M/F=E=$UE<W-A9V4H*2`N("<I)RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/G5I+3YO=71P=71$871A*")$:7-C;W9E<GD@;V8@8VAA;FYE
M;"!<(B1P87)A;7-;,%U<(B!S=6-C965D960B+"`D8V]M;6%N9"D[#0H@("`@
M?0T*?0T*/SX-"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,C$P-S,@,3`U,34T,S0Q,S0@,#(R-3,S`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]#;VUM;VX@8F%S92!C;&%S<PT*("H-
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H
M92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I
M9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!#;VUM;VXN<&AP+'8@
M,2XS,B`R,#`V+S`S+S`R(#$V.C,Y.C$T('!A:F]Y92!%>'`@)`T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,"XQ
M#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC
M92`G4$5!4BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@8F%S92!C
M;&%S<PT*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@
M(%!%05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE
M=#X-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE
M=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@
M*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N-"XY#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,"XQ#0H@*B\-"F-L87-S(%!%05)?0V]M;6%N9%]#;VUM
M;VX@97AT96YD<R!014%2#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*
M("`@("\J*@T*("`@("`J(%!%05)?0V]N9FEG(&]B:F5C="!U<V5D('1O('!A
M<W,@=7-E<B!S>7-T96T@86YD(&-O;F9I9W5R871I;VX-"B`@("`@*B!O;B!W
M:&5N(&5X96-U=&EN9R!C;VUM86YD<PT*("`@("`J#0H@("`@("H@0'9A<B!0
M14%27T-O;F9I9PT*("`@("`J+PT*("`@('9A<B`D8V]N9FEG.PT*("`@("\J
M*@T*("`@("`J($!V87(@4$5!4E]296=I<W1R>0T*("`@("`J($!A8V-E<W,@
M<')O=&5C=&5D#0H@("`@("HO#0H@("`@=F%R("1?<F5G:7-T<GD[#0H-"B`@
M("`O*BH-"B`@("`@*B!5<V5R($EN=&5R9F%C92!O8FIE8W0L(&9O<B!A;&P@
M:6YT97)A8W1I;VX@=VET:"!T:&4@=7-E<BX-"B`@("`@*B!`=F%R(&]B:F5C
M=`T*("`@("`J+PT*("`@('9A<B`D=6D[#0H-"B`@("!V87(@)%]D97!S7W)E
M;%]T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)VQT)R`]/B`G/"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G;&4G(#T^("<\/2<L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G97$G(#T^("<])RP-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=N92<@/3X@)R$])RP-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=G="<@/3X@)SXG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)V=E)R`]/B`G/CTG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)VAA<R<@/3X@)ST])PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@('9A<B`D7V1E<'-?
M='EP95]T<F%N<R`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=P:V<G(#T^("=P86-K86=E)RP-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G97AT96YS:6]N)R`]/B`G97AT96YS:6]N
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&AP)R`]
M/B`G4$A0)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M<')O9R<@/3X@)V5X=&5R;F%L('!R;V=R86TG+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=L9&QI8B<@/3X@)V5X=&5R;F%L(&QI8G)A
M<GD@9F]R(&QI;FMI;F<G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=R=&QI8B<@/3X@)V5X=&5R;F%L(')U;G1I;64@;&EB<F%R>2<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V]S)R`]/B`G
M;W!E<F%T:6YG('-Y<W1E;2<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W=E8G-R=B<@/3X@)W=E8B!S97)V97(G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=S87!I)R`]/B`G4T%022!B86-K
M96YD)PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[#0H-
M"B`@("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J
M*@T*("`@("`J(%!%05)?0V]M;6%N9%]#;VUM;VX@8V]N<W1R=6-T;W(N#0H@
M("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(%!%05)?0V]M;6%N9%]#;VUM;VXH)B1U:2P@)B1C;VYF:6<I#0H@
M("`@>PT*("`@("`@("!P87)E;G0Z.E!%05(H*3L-"B`@("`@("`@)'1H:7,M
M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI<RT^=6D@/2`F)'5I
M.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&=E=$-O;6UA
M;F1S*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A(&QI<W0@;V8@86QL
M('1H92!C;VUM86YD<R!D969I;F5D(&)Y('1H:7,@8VQA<W,N#0H@("`@("H@
M0')E='5R;B!A<G)A>2!L:7-T(&]F(&-O;6UA;F1S#0H@("`@("H@0&%C8V5S
M<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!G971#;VUM86YD<R@I
M#0H@("`@>PT*("`@("`@("`D<F5T(#T@87)R87DH*3L-"B`@("`@("`@9F]R
M96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^8V]M;6%N9',I(&%S("1C;VUM86YD
M*2![#0H@("`@("`@("`@("`D<F5T6R1C;VUM86YD72`]("1T:&ES+3YC;VUM
M86YD<ULD8V]M;6%N9%U;)W-U;6UA<GDG73L-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)')E=#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![
M>WL@9V5T4VAO<G1C=71S*"D-"@T*("`@("\J*@T*("`@("`J(%)E='5R;B!A
M(&QI<W0@;V8@86QL('1H92!C;VUM86YD('-H;W)T8W5T<R!D969I;F5D(&)Y
M('1H:7,@8VQA<W,N#0H@("`@("H@0')E='5R;B!A<G)A>2!S:&]R=&-U="`]
M/B!C;VUM86YD#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!G9713:&]R=&-U=',H*0T*("`@('L-"B`@("`@("`@)')E
M="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'1H
M:7,M/F-O;6UA;F1S*2!A<R`D8V]M;6%N9"D@>PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)W-H;W)T8W5T)UTI
M*2![#0H@("`@("`@("`@("`@("`@)')E=%LD=&AI<RT^8V]M;6%N9'-;)&-O
M;6UA;F1=6R=S:&]R=&-U="==72`]("1C;VUM86YD.PT*("`@("`@("`@("`@
M?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"@T*
M("`@("\O('U]?0T*("`@("\O('M[>R!G971/<'1I;VYS*"D-"@T*("`@(&9U
M;F-T:6]N(&=E=$]P=&EO;G,H)&-O;6UA;F0I#0H@("`@>PT*("`@("`@("`D
M<VAO<G1C=71S(#T@)'1H:7,M/F=E=%-H;W)T8W5T<R@I.PT*("`@("`@("!I
M9B`H:7-S970H)'-H;W)T8W5T<ULD8V]M;6%N9%TI*2![#0H@("`@("`@("`@
M("`D8V]M;6%N9"`]("1S:&]R=&-U='-;)&-O;6UA;F1=.PT*("`@("`@("!]
M#0H@("`@("`@(')E='5R;B!`)'1H:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG
M;W!T:6]N<R==.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!G
M971'971O<'1!<F=S*"D-"@T*("`@(&9U;F-T:6]N(&=E=$=E=&]P=$%R9W,H
M)&-O;6UA;F0L("8D<VAO<G1?87)G<RP@)B1L;VYG7V%R9W,I#0H@("`@>PT*
M("`@("`@("`D<VAO<G1?87)G<R`]("(B.PT*("`@("`@("`D;&]N9U]A<F=S
M(#T@87)R87DH*3L-"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YC;VUM86YD
M<ULD8V]M;6%N9%TI('Q\(&5M<'1Y*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N
M9%U;)V]P=&EO;G,G72DI('L-"B`@("`@("`@("`@(')E='5R;CL-"B`@("`@
M("`@?0T*("`@("`@("!R97-E="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=
M6R=O<'1I;VYS)UTI.PT*("`@("`@("!W:&EL92`H;&ES="@D;W!T:6]N+"`D
M:6YF;RD@/2!E86-H*"1T:&ES+3YC;VUM86YD<ULD8V]M;6%N9%U;)V]P=&EO
M;G,G72DI('L-"B`@("`@("`@("`@("1L87)G(#T@)'-A<F<@/2`G)SL-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D:6YF;ULG87)G)UTI*2![#0H@("`@("`@
M("`@("`@("`@:68@*"1I;F9O6R=A<F<G77LP?2`]/2`G*"<I('L-"B`@("`@
M("`@("`@("`@("`@("`@)&QA<F<@/2`G/3TG.PT*("`@("`@("`@("`@("`@
M("`@("`D<V%R9R`]("<Z.B<[#0H@("`@("`@("`@("`@("`@("`@("1A<F<@
M/2!S=6)S='(H)&EN9F];)V%R9R==+"`Q+"`M,2D[#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&QA<F<@/2`G/2<[
M#0H@("`@("`@("`@("`@("`@("`@("1S87)G(#T@)SHG.PT*("`@("`@("`@
M("`@("`@("`@("`D87)G(#T@)&EN9F];)V%R9R==.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG<VAO<G1O<'0G72DI('L-"B`@("`@("`@("`@("`@("`D<VAO<G1?
M87)G<R`N/2`D:6YF;ULG<VAO<G1O<'0G72`N("1S87)G.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&QO;F=?87)G<UM=(#T@)&]P=&EO;B`N("1L
M87)G.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@
M>WM[(&=E=$AE;'`H*0T*("`@("\J*@T*("`@("H@4F5T=7)N<R!T:&4@:&5L
M<"!M97-S86=E(&9O<B!T:&4@9VEV96X@8V]M;6%N9`T*("`@("H-"B`@("`J
M($!P87)A;2!S=')I;F<@)&-O;6UA;F0@5&AE(&-O;6UA;F0-"B`@("`J($!R
M971U<FX@;6EX960@02!F86EL('-T<FEN9R!I9B!T:&4@8V]M;6%N9"!D;V5S
M(&YO="!H879E(&AE;'`@;W(-"B`@("`J("`@("`@("`@("`@("`@82!T=V\@
M96QE;65N=',@87)R87D@8V]N=&%I;FEN9R!;,%T]/FAE;'`@<W1R:6YG+`T*
M("`@("H@("`@("`@("`@("`@("!;,5T]/B!H96QP('-T<FEN9R!F;W(@=&AE
M(&%C8V5P=&5D(&-M9"!A<F=S#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971(
M96QP*"1C;VUM86YD*0T*("`@('L-"B`@("`@("`@)&-O;F9I9R`]("9014%2
M7T-O;F9I9SHZ<VEN9VQE=&]N*"D[#0H@("`@("`@("1H96QP(#T@0"1T:&ES
M+3YC;VUM86YD<ULD8V]M;6%N9%U;)V1O8R==.PT*("`@("`@("!I9B`H96UP
M='DH)&AE;'`I*2![#0H@("`@("`@("`@("`O+R!86%@@*&-O>"D@1F%L;&)A
M8VL@=&\@<W5M;6%R>2!I9B!T:&5R92!I<R!N;R!D;V,@*'-H;W<@8F]T:#\I
M#0H@("`@("`@("`@("!I9B`H(21H96QP(#T@0"1T:&ES+3YC;VUM86YD<ULD
M8V]M;6%N9%U;)W-U;6UA<GDG72D@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B`B3F\@:&5L<"!F;W(@8V]M;6%N9"!<(B1C;VUM86YD7"(B.PT*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AP<F5G7VUA=&-H7V%L
M;"@G+WMC;VYF:6=<<RLH6UY<?5TK*7TO92<L("1H96QP+"`D;6%T8VAE<RDI
M('L-"B`@("`@("`@("`@(&9O<F5A8V@H)&UA=&-H97-;,%T@87,@)&L@/3X@
M)'8I('L-"B`@("`@("`@("`@("`@("`D:&5L<"`]('!R96=?<F5P;&%C92@B
M+R1V+R(L("1C;VYF:6<M/F=E="@D;6%T8VAE<ULQ75LD:UTI+"`D:&5L<"D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1H96QP+"`D=&AI<RT^9V5T2&5L<$%R9W,H)&-O;6UA;F0I*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9V5T2&5L<$%R9W,H*0T*
M("`@("\J*@T*("`@("H@4F5T=7)N<R!T:&4@:&5L<"!F;W(@=&AE(&%C8V5P
M=&5D(&%R9W5M96YT<R!O9B!A(&-O;6UA;F0-"B`@("`J#0H@("`@*B!`<&%R
M86T@('-T<FEN9R`D8V]M;6%N9`T*("`@("H@0')E='5R;B!S=')I;F<@5&AE
M(&AE;'`@<W1R:6YG#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971(96QP07)G
M<R@D8V]M;6%N9"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UTI("8F#0H@("`@("`@("`@
M("!C;W5N="@D=&AI<RT^8V]M;6%N9'-;)&-O;6UA;F1=6R=O<'1I;VYS)UTI
M*0T*("`@("`@("![#0H@("`@("`@("`@("`D:&5L<"`](")/<'1I;VYS.EQN
M(CL-"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUM86YD<ULD8V]M
M;6%N9%U;)V]P=&EO;G,G72!A<R`D:R`]/B`D=BD@>PT*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D=ELG87)G)UTI*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D=ELG87)G)UU[,'T@/3T@)R@G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D87)G(#T@<W5B<W1R*"1V6R=A<F<G72P@,2P@+3$I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'-A<'`@/2`B(%LD87)G72([#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D;&%P<"`](");/21A<F==(CL-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1S87!P(#T@(B`D=EMA<F==(CL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1L87!P(#T@(CTD=EMA<F==(CL-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("1S87!P(#T@)&QA<'`@/2`B(CL-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1V6R=S:&]R=&]P="==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`D<R`]("1V6R=S:&]R=&]P="==.PT*
M("`@("`@("`@("`@("`@("`@("!`)&AE;'`@+CT@(B`@+21S)'-A<'`L("TM
M)&LD;&%P<%QN(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("!`)&AE;'`@+CT@(B`@+2TD:R1L87!P7&XB.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<"`]("(@("`@("`@
M("([#0H@("`@("`@("`@("`@("`@)&1O8R`](')T<FEM*'-T<E]R97!L86-E
M*")<;B(L(")<;B1P(BP@)'9;)V1O8R==*2D[#0H@("`@("`@("`@("`@("`@
M)&AE;'`@+CT@(B`@("`@("`@)&1O8UQN(CL-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B`D:&5L<#L-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@;G5L;#L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M<G5N*"D-"@T*("`@(&9U;F-T:6]N(')U;B@D8V]M;6%N9"P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H96UP='DH)'1H:7,M/F-O
M;6UA;F1S6R1C;VUM86YD75LG9G5N8W1I;VXG72DI('L-"B`@("`@("`@("`@
M("\O(&QO;VL@9F]R('-H;W)T8W5T<PT*("`@("`@("`@("`@9F]R96%C:"`H
M87)R87E?:V5Y<R@D=&AI<RT^8V]M;6%N9',I(&%S("1C;60I('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/F-O;6UA;F1S6R1C;61=6R=S
M:&]R=&-U="==*2`F)B`D=&AI<RT^8V]M;6%N9'-;)&-M9%U;)W-H;W)T8W5T
M)UT@/3T@)&-O;6UA;F0I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&5M
M<'1Y*"1T:&ES+3YC;VUM86YD<ULD8VUD75LG9G5N8W1I;VXG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B=6YK;F]W;B!C;VUM86YD(&`D8V]M;6%N9"<B*3L-"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1F
M=6YC(#T@)'1H:7,M/F-O;6UA;F1S6R1C;61=6R=F=6YC=&EO;B==.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("1C;VUM
M86YD(#T@)&-M9#L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@)&9U;F,@/2`D=&AI<RT^8V]M;6%N9'-;)&-O;6UA
M;F1=6R=F=6YC=&EO;B==.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D
M=&AI<RT^)&9U;F,H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+T-O;F9I9RYX;6P`````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C8R,2`Q,#4Q-30S-#$S-"`P
M,C(U,C,`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&-O;F9I9RUS:&]W/@T*
M("`\<W5M;6%R>3Y3:&]W($%L;"!3971T:6YG<SPO<W5M;6%R>3X-"B`@/&9U
M;F-T:6]N/F1O0V]N9FEG4VAO=SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YC
M<V@\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@
M(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-H;W<@8V]N9FEG
M=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA;FYE;#PO9&]C/@T*
M("`@(#QA<F<^0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO
M;G,^#0H@(#QD;V,^6VQA>65R70T*1&ES<&QA>7,@86QL(&-O;F9I9W5R871I
M;VX@=F%L=65S+B`@06X@;W!T:6]N86P@87)G=6UE;G0-"FUA>2!B92!U<V5D
M('1O('1E;&P@=VAI8V@@8V]N9FEG=7)A=&EO;B!L87EE<B!T;R!D:7-P;&%Y
M+B`@5F%L:60-"F-O;F9I9W5R871I;VX@;&%Y97)S(&%R92`F<75O=#MU<V5R
M)G%U;W0[+"`F<75O=#MS>7-T96TF<75O=#L@86YD("9Q=6]T.V1E9F%U;'0F
M<75O=#LN(%1O(&1I<W!L87D-"F-O;F9I9W5R871I;VYS(&9O<B!D:69F97)E
M;G0@8VAA;FYE;',L('-E="!T:&4@9&5F875L=%]C:&%N;F5L#0IC;VYF:6=U
M<F%T:6]N('9A<FEA8FQE(&%N9"!R=6X@8V]N9FEG+7-H;W<@86=A:6XN#0H\
M+V1O8SX-"B`\+V-O;F9I9RUS:&]W/@T*(#QC;VYF:6<M9V5T/@T*("`\<W5M
M;6%R>3Y3:&]W($]N92!3971T:6YG/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^
M9&]#;VYF:6='970\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8V<\+W-H;W)T
M8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@(#QS:&]R=&]P
M=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-H;W<@8V]N9FEG=7)A=&EO;B!V
M87)I86)L97,@9F]R(&%N;W1H97(@8VAA;FYE;#PO9&]C/@T*("`@(#QA<F<^
M0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO;G,^#0H@(#QD
M;V,^)FQT.W!A<F%M971E<B9G=#L@6VQA>65R70T*1&ES<&QA>7,@=&AE('9A
M;'5E(&]F(&]N92!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX@(%1H90T*9FER
M<W0@87)G=6UE;G0@:7,@=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@86X@
M;W!T:6]N86P@<V5C;VYD(&%R9W5M96YT#0IM87D@8F4@=7-E9"!T;R!T96QL
M('=H:6-H(&-O;F9I9W5R871I;VX@;&%Y97(@=&\@;&]O:R!I;BX@(%9A;&ED
M(&-O;F9I9W5R871I;VX-"FQA>65R<R!A<F4@)G%U;W0[=7-E<B9Q=6]T.RP@
M)G%U;W0[<WES=&5M)G%U;W0[(&%N9"`F<75O=#MD969A=6QT)G%U;W0[+B`@
M268@;F\@;&%Y97(@:7,@<W!E8VEF:65D+"!A('9A;'5E#0IW:6QL(&)E('!I
M8VME9"!F<F]M('1H92!F:7)S="!L87EE<B!T:&%T(&1E9FEN97,@=&AE('!A
M<F%M971E<BP@:6X@=&AE(&]R9&5R#0IJ=7-T('-P96-I9FEE9"X@(%1H92!C
M;VYF:6=U<F%T:6]N('9A;'5E('=I;&P@8F4@<F5T<FEE=F5D(&9O<B!T:&4@
M8VAA;FYE;`T*<W!E8VEF:65D(&)Y('1H92!D969A=6QT7V-H86YN96P@8V]N
M9FEG=7)A=&EO;B!V87)I86)L92X-"CPO9&]C/@T*(#PO8V]N9FEG+6=E=#X-
M"B`\8V]N9FEG+7-E=#X-"B`@/'-U;6UA<GD^0VAA;F=E(%-E='1I;F<\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T-O;F9I9U-E=#PO9G5N8W1I;VX^#0H@
M(#QS:&]R=&-U=#YC<SPO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H
M86YN96P^#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M<VAO=R!C;VYF:6=U<F%T:6]N('9A<FEA8FQE<R!F;W(@86YO=&AE<B!C:&%N
M;F5L/"]D;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^
M#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<&%R86UE=&5R)F=T.R`F;'0[
M=F%L=64F9W0[(%ML87EE<ET-"E-E=',@=&AE('9A;'5E(&]F(&]N92!C;VYF
M:6=U<F%T:6]N('!A<F%M971E<BX@(%1H92!F:7)S="!A<F=U;65N="!I<PT*
M=&AE(&YA;64@;V8@=&AE('!A<F%M971E<BP@=&AE('-E8V]N9"!A<F=U;65N
M="!I<R!T:&4@;F5W('9A;'5E+B`@4V]M90T*<&%R86UE=&5R<R!A<F4@<W5B
M:F5C="!T;R!V86QI9&%T:6]N+"!A;F0@=&AE(&-O;6UA;F0@=VEL;"!F86EL
M('=I=&@-"F%N(&5R<F]R(&UE<W-A9V4@:68@=&AE(&YE=R!V86QU92!D;V5S
M(&YO="!M86ME('-E;G-E+B`@06X@;W!T:6]N86P-"G1H:7)D(&%R9W5M96YT
M(&UA>2!B92!U<V5D('1O('-P96-I9GD@:6X@=VAI8V@@;&%Y97(@=&\@<V5T
M('1H90T*8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9&5F875L="!L
M87EE<B!I<R`F<75O=#MU<V5R)G%U;W0[+B`@5&AE#0IC;VYF:6=U<F%T:6]N
M('9A;'5E('=I;&P@8F4@<V5T(&9O<B!T:&4@8W5R<F5N="!C:&%N;F5L+"!W
M:&EC:`T*:7,@8V]N=')O;&QE9"!B>2!T:&4@9&5F875L=%]C:&%N;F5L(&-O
M;F9I9W5R871I;VX@=F%R:6%B;&4N#0H\+V1O8SX-"B`\+V-O;F9I9RUS970^
M#0H@/&-O;F9I9RUH96QP/@T*("`\<W5M;6%R>3Y3:&]W($EN9F]R;6%T:6]N
M($%B;W5T(%-E='1I;F<\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T-O;F9I
M9TAE;'`\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^8V@\+W-H;W)T8W5T/@T*
M("`\;W!T:6]N<R`O/@T*("`\9&]C/EMP87)A;65T97)=#0I$:7-P;&%Y<R!H
M96QP(&9O<B!A(&-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5VET:&]U="!A
M<F=U;65N=',@:70-"F1I<W!L87ES(&AE;'`@9F]R(&%L;"!C;VYF:6=U<F%T
M:6]N('!A<F%M971E<G,N#0H\+V1O8SX-"B`\+V-O;F9I9RUH96QP/@T*(#QC
M;VYF:6<M8W)E871E/@T*("`\<W5M;6%R>3Y#<F5A=&4@82!$969A=6QT(&-O
M;F9I9W5R871I;VX@9FEL93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O0V]N
M9FEG0W)E871E/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-O8SPO<VAO<G1C
M=70^#0H@(#QO<'1I;VYS/@T*("`@/'=I;F1O=W,^#0H@("`@/'-H;W)T;W!T
M/G<\+W-H;W)T;W!T/@T*("`@(#QD;V,^8W)E871E(&$@8V]N9FEG(&9I;&4@
M9F]R(&$@=VEN9&]W<R!I;G-T86QL/"]D;V,^#0H@("`\+W=I;F1O=W,^#0H@
M(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[<F]O="!P871H)F=T.R`F;'0[9FEL
M96YA;64F9W0[#0I#<F5A=&4@82!D969A=6QT(&-O;F9I9W5R871I;VX@9FEL
M92!W:71H(&%L;"!D:7)E8W1O<GD@8V]N9FEG=7)A=&EO;@T*=F%R:6%B;&5S
M('-E="!T;R!S=6)D:7)E8W1O<FEE<R!O9B`F;'0[<F]O="!P871H)F=T.RP@
M86YD('-A=F4@:70@87,@)FQT.V9I;&5N86UE)F=T.RX-"E1H:7,@:7,@=7-E
M9G5L(&5S<&5C:6%L;'D@9F]R(&-R96%T:6YG(&$@8V]N9FEG=7)A=&EO;B!F
M:6QE(&9O<B!A(')E;6]T90T*4$5!4B!I;G-T86QL871I;VX@*'5S:6YG('1H
M92`M+7)E;6]T96-O;F9I9R!O<'1I;VX@;V8@:6YS=&%L;"P@=7!G<F%D92P-
M"F%N9"!U;FEN<W1A;&PI+@T*/"]D;V,^#0H@/"]C;VYF:6<M8W)E871E/@T*
M/"]C;VUM86YD<SX`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U!%05(O0V]M;6%N9"]#;VYF:6<N<&AP````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S8S,C<@,3`U,34T,S0Q,S0@
M,#(R-3(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP#0HO*BH-"B`J(%!%05)?0V]M;6%N9%]#;VYF:6<@*&-O;F9I
M9RUS:&]W+"!C;VYF:6<M9V5T+"!C;VYF:6<M<V5T+"!C;VYF:6<M:&5L<"P@
M8V]N9FEG+6-R96%T92!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@0V]N9FEG+G!H<"QV(#$N-3$@,C`P-B\P,R\P,B`Q
M,SHS,CHS."!P86IO>64@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*("H@
M8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#
M;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!M86YA
M9VEN9R!C;VYF:6=U<F%T:6]N(&1A=&$N#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA
M<W,@4$5!4E]#;VUM86YD7T-O;F9I9R!E>'1E;F1S(%!%05)?0V]M;6%N9%]#
M;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@=F%R("1C
M;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G8V]N9FEG+7-H;W<G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=3:&]W($%L;"!3971T
M:6YG<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O;F9I9U-H
M;W<G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8W-H)RP-"B`@("`@
M("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G
M8VAA;FYE;"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M<VAO=R!C;VYF:6=U<F%T:6]N('9A<FEA8FQE<R!F;W(@86YO=&AE<B!C:&%N
M;F5L)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T-(04XG+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T**2P-"B`@("`@("`@("`@("=D;V,G
M(#T^("=;;&%Y97)=#0I$:7-P;&%Y<R!A;&P@8V]N9FEG=7)A=&EO;B!V86QU
M97,N("!!;B!O<'1I;VYA;"!A<F=U;65N=`T*;6%Y(&)E('5S960@=&\@=&5L
M;"!W:&EC:"!C;VYF:6=U<F%T:6]N(&QA>65R('1O(&1I<W!L87DN("!686QI
M9`T*8V]N9FEG=7)A=&EO;B!L87EE<G,@87)E(")U<V5R(BP@(G-Y<W1E;2(@
M86YD(")D969A=6QT(BX@5&\@9&ES<&QA>0T*8V]N9FEG=7)A=&EO;G,@9F]R
M(&1I9F9E<F5N="!C:&%N;F5L<RP@<V5T('1H92!D969A=6QT7V-H86YN96P-
M"F-O;F9I9W5R871I;VX@=F%R:6%B;&4@86YD(')U;B!C;VYF:6<M<VAO=R!A
M9V%I;BX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G8V]N9FEG+6=E
M="<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U-H;W<@
M3VYE(%-E='1I;F<G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]#
M;VYF:6='970G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G8V<G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=C:&%N;F5L)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=S:&]W(&-O;F9I9W5R871I;VX@=F%R:6%B;&5S(&9O<B!A;F]T:&5R
M(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!
M3B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0HI+`T*("`@("`@("`@("`@
M)V1O8R<@/3X@)SQP87)A;65T97(^(%ML87EE<ET-"D1I<W!L87ES('1H92!V
M86QU92!O9B!O;F4@8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4-"F9I
M<G-T(&%R9W5M96YT(&ES('1H92!N86UE(&]F('1H92!P87)A;65T97(L(&%N
M(&]P=&EO;F%L('-E8V]N9"!A<F=U;65N=`T*;6%Y(&)E('5S960@=&\@=&5L
M;"!W:&EC:"!C;VYF:6=U<F%T:6]N(&QA>65R('1O(&QO;VL@:6XN("!686QI
M9"!C;VYF:6=U<F%T:6]N#0IL87EE<G,@87)E(")U<V5R(BP@(G-Y<W1E;2(@
M86YD(")D969A=6QT(BX@($EF(&YO(&QA>65R(&ES('-P96-I9FEE9"P@82!V
M86QU90T*=VEL;"!B92!P:6-K960@9G)O;2!T:&4@9FER<W0@;&%Y97(@=&AA
M="!D969I;F5S('1H92!P87)A;65T97(L(&EN('1H92!O<F1E<@T*:G5S="!S
M<&5C:69I960N("!4:&4@8V]N9FEG=7)A=&EO;B!V86QU92!W:6QL(&)E(')E
M=')I979E9"!F;W(@=&AE(&-H86YN96P-"G-P96-I9FEE9"!B>2!T:&4@9&5F
M875L=%]C:&%N;F5L(&-O;F9I9W5R871I;VX@=F%R:6%B;&4N#0HG+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)V-O;F9I9RUS970G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=#:&%N9V4@4V5T=&EN9R<L#0H@
M("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T-O;F9I9U-E="<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=C<R<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=C
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W-H;W<@8V]N9FEG
M=7)A=&EO;B!V87)I86)L97,@9F]R(&%N;W1H97(@8VAA;FYE;"<L#0H@("`@
M("`@("`@("`@("`@("`@("=A<F<G(#T^("=#2$%.)RP-"B`@("`@("`@("`@
M("`@("`@("`@*2P-"BDL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A<F%M
M971E<CX@/'9A;'5E/B!;;&%Y97)=#0I3971S('1H92!V86QU92!O9B!O;F4@
M8V]N9FEG=7)A=&EO;B!P87)A;65T97(N("!4:&4@9FER<W0@87)G=6UE;G0@
M:7,-"G1H92!N86UE(&]F('1H92!P87)A;65T97(L('1H92!S96-O;F0@87)G
M=6UE;G0@:7,@=&AE(&YE=R!V86QU92X@(%-O;64-"G!A<F%M971E<G,@87)E
M('-U8FIE8W0@=&\@=F%L:61A=&EO;BP@86YD('1H92!C;VUM86YD('=I;&P@
M9F%I;"!W:71H#0IA;B!E<G)O<B!M97-S86=E(&EF('1H92!N97<@=F%L=64@
M9&]E<R!N;W0@;6%K92!S96YS92X@($%N(&]P=&EO;F%L#0IT:&ER9"!A<F=U
M;65N="!M87D@8F4@=7-E9"!T;R!S<&5C:69Y(&EN('=H:6-H(&QA>65R('1O
M('-E="!T:&4-"F-O;F9I9W5R871I;VX@<&%R86UE=&5R+B`@5&AE(&1E9F%U
M;'0@;&%Y97(@:7,@(G5S97(B+B`@5&AE#0IC;VYF:6=U<F%T:6]N('9A;'5E
M('=I;&P@8F4@<V5T(&9O<B!T:&4@8W5R<F5N="!C:&%N;F5L+"!W:&EC:`T*
M:7,@8V]N=')O;&QE9"!B>2!T:&4@9&5F875L=%]C:&%N;F5L(&-O;F9I9W5R
M871I;VX@=F%R:6%B;&4N#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@
M)V-O;F9I9RUH96QP)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y
M)R`]/B`G4VAO=R!);F9O<FUA=&EO;B!!8F]U="!3971T:6YG)RP-"B`@("`@
M("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0V]N9FEG2&5L<"<L#0H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=C:"<L#0H@("`@("`@("`@("`G;W!T:6]N
M<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;<&%R86UE
M=&5R70T*1&ES<&QA>7,@:&5L<"!F;W(@82!C;VYF:6=U<F%T:6]N('!A<F%M
M971E<BX@(%=I=&AO=70@87)G=6UE;G1S(&ET#0ID:7-P;&%Y<R!H96QP(&9O
M<B!A;&P@8V]N9FEG=7)A=&EO;B!P87)A;65T97)S+@T*)RP-"B`@("`@("`@
M("`@*2P-"B`@("`@("`@)V-O;F9I9RUC<F5A=&4G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W-U;6UA<GDG(#T^("=#<F5A=&4@82!$969A=6QT(&-O;F9I
M9W5R871I;VX@9FEL92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D
M;T-O;F9I9T-R96%T92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C
M;V,G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=W:6YD;W=S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G=R<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=C<F5A=&4@82!C;VYF:6<@9FEL92!F;W(@82!W:6YD;W=S
M(&EN<W1A;&PG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<F]O="!P871H/B`\9FEL
M96YA;64^#0I#<F5A=&4@82!D969A=6QT(&-O;F9I9W5R871I;VX@9FEL92!W
M:71H(&%L;"!D:7)E8W1O<GD@8V]N9FEG=7)A=&EO;@T*=F%R:6%B;&5S('-E
M="!T;R!S=6)D:7)E8W1O<FEE<R!O9B`\<F]O="!P871H/BP@86YD('-A=F4@
M:70@87,@/&9I;&5N86UE/BX-"E1H:7,@:7,@=7-E9G5L(&5S<&5C:6%L;'D@
M9F]R(&-R96%T:6YG(&$@8V]N9FEG=7)A=&EO;B!F:6QE(&9O<B!A(')E;6]T
M90T*4$5!4B!I;G-T86QL871I;VX@*'5S:6YG('1H92`M+7)E;6]T96-O;F9I
M9R!O<'1I;VX@;V8@:6YS=&%L;"P@=7!G<F%D92P-"F%N9"!U;FEN<W1A;&PI
M+@T*)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("D[#0H-"B`@("`O+R!]
M?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*("`@("`J
M(%!%05)?0V]M;6%N9%]#;VYF:6<@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%
M05)?0V]M;6%N9%]#;VYF:6<H)B1U:2P@)B1C;VYF:6<I#0H@("`@>PT*("`@
M("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM;VXH)'5I+"`D8V]N9FEG
M*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!D;T-O;F9I
M9U-H;W<H*0T*#0H@("`@9G5N8W1I;VX@9&]#;VYF:6=3:&]W*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AI<U]A
M<G)A>2@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&QA>65R(#T@:7-S970H
M)'!A<F%M<ULP72D@/R`D<&%R86US6S!=(#H@3E5,3#L-"B`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("1L87EE<B`]($Y53$P[#0H@("`@("`@('T-
M"@T*("`@("`@("`O+R`D<&%R86US6S!=("T^('1H92!L87EE<@T*("`@("`@
M("!I9B`H)&5R<F]R(#T@)'1H:7,M/E]C:&5C:TQA>65R*"1L87EE<BDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]N9FEG
M+7-H;W<Z)&5R<F]R(BD[#0H@("`@("`@('T-"B`@("`@("`@)&ME>7,@/2`D
M=&AI<RT^8V]N9FEG+3YG971+97ES*"D[#0H@("`@("`@('-O<G0H)&ME>7,I
M.PT*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O<'1I;VYS6R=C:&%N;F5L
M)UTI(#\@)&]P=&EO;G-;)V-H86YN96PG72`Z#0H@("`@("`@("`@("`D=&AI
M<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D
M<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@
M(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N
M("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@("`@?0T*
M("`@("`@("`D9&%T82`](&%R<F%Y*"=C87!T:6]N)R`]/B`G0V]N9FEG=7)A
M=&EO;B`H8VAA;FYE;"`G("X@)&-H86YN96P@+B`G*3HG*3L-"B`@("`@("`@
M9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PT*("`@("`@("`@("`@)'1Y<&4@
M/2`D=&AI<RT^8V]N9FEG+3YG9714>7!E*"1K97DI.PT*("`@("`@("`@("`@
M)'9A;'5E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1K97DL("1L87EE<BP@)&-H
M86YN96PI.PT*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<@
M)B8@)'9A;'5E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)RHJ*BHJ
M*BHJ)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D=F%L=64@
M/3T](&9A;'-E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V9A;'-E
M)SL-"B`@("`@("`@("`@('T@96QS96EF("@D=F%L=64@/3T]('1R=64I('L-
M"B`@("`@("`@("`@("`@("`D=F%L=64@/2`G=')U92<[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1T:&ES+3YC;VYF:6<M
M/F=E=$=R;W5P*"1K97DI75M=(#T@87)R87DH)'1H:7,M/F-O;F9I9RT^9V5T
M4')O;7!T*"1K97DI("P@)&ME>2P@)'9A;'5E*3L-"B`@("`@("`@?0T*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^8V]N9FEG+3YG971,87EE<G,H*2!A<R`D
M;&%Y97(I('L-"B`@("`@("`@("`@("1D871A6R=D871A)UU;)T-O;F9I9R!&
M:6QE<R==6UT@/2!A<G)A>2AU8V9I<G-T*"1L87EE<BD@+B`G($-O;F9I9W5R
M871I;VX@1FEL92<L("=&:6QE;F%M92<@+"`D=&AI<RT^8V]N9FEG+3YG971#
M;VYF1FEL92@D;&%Y97(I*3L-"B`@("`@("`@?0T*#0H@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9&]#;VYF:6='970H*0T*#0H@("`@9G5N8W1I;VX@9&]#;VYF:6='970H)&-O
M;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<&%R86US*2D@>PT*("`@("`@("`@("`@)&%R9W-?8VYT
M(#T@,#L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A<F=S7V-N
M="`@/2!C;W5N="@D<&%R86US*3L-"B`@("`@("`@?0T*#0H@("`@("`@('-W
M:71C:"`H)&%R9W-?8VYT*2![#0H@("`@("`@("`@("!C87-E(#$Z#0H@("`@
M("`@("`@("`@("`@)&-O;F9I9U]K97D@/2`D<&%R86US6S!=.PT*("`@("`@
M("`@("`@("`@("1L87EE<B`]($Y53$P[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E(#(Z#0H@("`@("`@("`@("`@("`@)&-O
M;F9I9U]K97D@/2`D<&%R86US6S!=.PT*("`@("`@("`@("`@("`@("1L87EE
M<B`]("1P87)A;7-;,5T[#0H@("`@("`@("`@("`@("`@:68@*"1E<G)O<B`]
M("1T:&ES+3Y?8VAE8VM,87EE<B@D;&%Y97(I*2![#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8V]N9FEG+6=E=#HD
M97)R;W(B*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!C87-E(#`Z#0H@("`@("`@("`@("!D969A
M=6QT.@T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@B8V]N9FEG+6=E="!E>'!E8W1S(#$@;W(@,B!P87)A;65T97)S(BD[#0H@
M("`@("`@('T-"@T*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O<'1I;VYS
M6R=C:&%N;F5L)UTI(#\@)&]P=&EO;G-;)V-H86YN96PG72`Z("1T:&ES+3YC
M;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@("1R96<@
M/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"@T*("`@("`@("!I
M9B`H(21R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-H86YN96P@(B<@+B`D
M8VAA;FYE;"`N("<B(&1O97,@;F]T(&5X:7-T)RD[#0H@("`@("`@('T-"@T*
M("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)'1H:7,M/F-O;F9I9RT^
M9V5T*"1C;VYF:6=?:V5Y+"`D;&%Y97(L("1C:&%N;F5L*2P@)&-O;6UA;F0I
M.PT*#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!D;T-O;F9I9U-E="@I#0H-"B`@("!F=6YC=&EO;B!D
M;T-O;F9I9U-E="@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@
M>PT*("`@("`@("`O+R`D<&%R86U;,%T@+3X@82!P87)A;65T97(@=&\@<V5T
M#0H@("`@("`@("\O("1P87)A;5LQ72`M/B!T:&4@=F%L=64@9F]R('1H92!P
M87)A;65T97(-"B`@("`@("`@+R\@)'!A<F%M6S)=("T^('1H92!L87EE<@T*
M("`@("`@("`D9F%I;&US9R`]("<G.PT*("`@("`@("!I9B`H<VEZ96]F*"1P
M87)A;7,I(#P@,B!\?"!S:7IE;V8H)'!A<F%M<RD@/B`S*2![#0H@("`@("`@
M("`@("`D9F%I;&US9R`N/2`B8V]N9FEG+7-E="!E>'!E8W1S(#(@;W(@,R!P
M87)A;65T97)S(CL-"B`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R
M<F]R*"1F86EL;7-G*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&5R<F]R
M(#T@)'1H:7,M/E]C:&5C:TQA>65R*$`D<&%R86US6S)=*2D@>PT*("`@("`@
M("`@("`@)&9A:6QM<V<@+CT@)&5R<F]R.PT*("`@("`@("`@("`@<F5T=7)N
M(%!%05(Z.G)A:7-E17)R;W(H(F-O;F9I9RUS970Z)&9A:6QM<V<B*3L-"B`@
M("`@("`@?0T*("`@("`@("`D8VAA;FYE;"`](&ES<V5T*"1O<'1I;VYS6R=C
M:&%N;F5L)UTI(#\@)&]P=&EO;G-;)V-H86YN96PG72`Z#0H@("`@("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@
M("`@("`@(&EF("@A)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA;FYE;"DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0VAA;FYE
M;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H)'!A<F%M<ULP72`]/2`G9&5F875L=%]C:&%N
M;F5L)RD@>PT*("`@("`@("`@("`@:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S
M*"1P87)A;7-;,5TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)'!A<F%M<ULQ72`N("<B(&1O
M97,@;F]T(&5X:7-T)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&-O=6YT*"1P87)A;7,I(#T](#(I('L-"B`@("`@("`@("`@
M(&%R<F%Y7W!U<V@H)'!A<F%M<RP@)W5S97(G*3L-"B`@("`@("`@("`@("1L
M87EE<B`]("=U<V5R)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1L87EE<B`]("1P87)A;7-;,ET[#0H@("`@("`@('T-"B`@("`@("`@87)R
M87E?<'5S:"@D<&%R86US+"`D8VAA;FYE;"D[#0H@("`@("`@(&EF("@A8V%L
M;%]U<V5R7V9U;F-?87)R87DH87)R87DH)B1T:&ES+3YC;VYF:6<L("=S970G
M*2P@)'!A<F%M<RDI#0H@("`@("`@('L-"B`@("`@("`@("`@(&%R<F%Y7W!O
M<"@D<&%R86US*3L-"B`@("`@("`@("`@("1F86EL;7-G(#T@(F-O;F9I9RUS
M970@*"(@+B!I;7!L;V1E*"(L("(L("1P87)A;7,I("X@(BD@9F%I;&5D+"!C
M:&%N;F5L("1C:&%N;F5L(CL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("1T:&ES+3YC;VYF:6<M/G-T;W)E*"1L87EE<BD[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1F86EL;7-G*2![#0H@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&9A:6QM<V<I.PT*("`@("`@("!]#0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G8V]N9FEG+7-E="!S=6-C965D
M960G+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-O;F9I9TAE;'`H*0T*#0H@
M("`@9G5N8W1I;VX@9&]#;VYF:6=(96QP*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D<&%R86US*2D@
M>PT*("`@("`@("`@("`@)'!A<F%M<R`]("1T:&ES+3YC;VYF:6<M/F=E=$ME
M>7,H*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T85LG8V%P=&EO;B==("`]
M(")#;VYF:6<@:&5L<"(@+B`H*&-O=6YT*"1P87)A;7,I(#T](#$I(#\@(B!F
M;W(@)'!A<F%M<ULP72(@.B`G)RD[#0H@("`@("`@("1D871A6R=H96%D;&EN
M92==(#T@87)R87DH)TYA;64G+"`G5'EP92<L("=$97-C<FEP=&EO;B<I.PT*
M("`@("`@("`D9&%T85LG8F]R9&5R)UT@("`]('1R=64[#0H@("`@("`@(&9O
M<F5A8V@@*"1P87)A;7,@87,@)&YA;64I('L-"B`@("`@("`@("`@("1T>7!E
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T5'EP92@D;F%M92D[#0H@("`@("`@("`@
M("`D9&]C<R`]("1T:&ES+3YC;VYF:6<M/F=E=$1O8W,H)&YA;64I.PT*("`@
M("`@("`@("`@:68@*"1T>7!E(#T]("=S970G*2![#0H@("`@("`@("`@("`@
M("`@)&1O8W,@/2!R=')I;2@D9&]C<RD@+B`B7&Y686QI9"!S970Z("(@+@T*
M("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<@)RP@)'1H:7,M/F-O;F9I
M9RT^9V5T4V5T5F%L=65S*"1N86UE*2D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D;F%M92P@)'1Y<&4L
M("1D;V-S*3L-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-
M"B`@("`O+R![>WL@9&]#;VYF:6=#<F5A=&4H*0T*#0H@("`@9G5N8W1I;VX@
M9&]#;VYF:6=#<F5A=&4H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@:68@*&-O=6YT*"1P87)A;7,I("$](#(I('L-"B`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=C;VYF:6<M8W)E
M871E.B!M=7-T(&AA=F4@,B!P87)A;65T97)S+"!R;V]T('!A=&@@86YD("<@
M+@T*("`@("`@("`@("`@("`@("=F:6QE;F%M92!T;R!S879E(&%S)RD[#0H@
M("`@("`@('T-"B`@("`@("`@)')O;W0@/2`D<&%R86US6S!=.PT*("`@("`@
M("`O+R!#;&5A;B!U<"!T:&4@1$E214-43U)97U-%4$%2051/4B!M97-S#0H@
M("`@("`@("1D<S(@/2!$25)%0U1/4EE?4T5005)!5$]2("X@1$E214-43U)9
M7U-%4$%2051/4CL-"B`@("`@("`@)')O;W0@/2!P<F5G7W)E<&QA8V4H87)R
M87DH)R%<7%Q<*R$G+"`G(2\K(2<L("(A)&1S,BLA(BDL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"<O)RP@)R\G+"`G+R<I+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R;V]T*3L-"B`@("`@("`@:68@
M*"1R;V]T>S!]("$]("<O)RD@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1O
M<'1I;VYS6R=W:6YD;W=S)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*"%P
M<F5G7VUA=&-H*"<O7EM!+5IA+7I=.B\G+"`D<F]O="DI('L-"B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U)O;W0@9&ER
M96-T;W)Y(&UU<W0@8F4@86X@86)S;VQU=&4@<&%T:"!B96=I;FYI;F<@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`G=VET:"`B7%PB(&]R(")#.EQ<
M(BP@=V%S.B`B)R`N("1R;V]T("X@)R(G*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R
M;B!014%2.CIR86ES945R<F]R*"=2;V]T(&1I<F5C=&]R>2!M=7-T(&)E(&%N
M(&%B<V]L=71E('!A=&@@8F5G:6YN:6YG("<@+@T*("`@("`@("`@("`@("`@
M("`@("`G=VET:"`B+R(L('=A<SH@(B<@+B`D<F]O="`N("<B)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'=I;F1O=W,@/2!I<W-E
M="@D;W!T:6]N<ULG=VEN9&]W<R==*3L-"B`@("`@("`@:68@*"1W:6YD;W=S
M*2![#0H@("`@("`@("`@("`D<F]O="`]('-T<E]R97!L86-E*"<O)RP@)UQ<
M)RP@)')O;W0I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES
M=',H)'!A<F%M<ULQ72DI('L-"B`@("`@("`@("`@(&EF("@A0'1O=6-H*"1P
M87)A;7-;,5TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A
M:7-E17)R;W(H)T-O=6QD(&YO="!C<F5A=&4@(B<@+B`D<&%R86US6S%=("X@
M)R(G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D<&%R
M86US6S%=(#T@<F5A;'!A=&@H)'!A<F%M<ULQ72D[#0H@("`@("`@("1C;VYF
M:6<@/2`F;F5W(%!%05)?0V]N9FEG*"1P87)A;7-;,5TL("<C;F\C<WES=&5M
M(V-O;F9I9R,G+"!F86QS92P@9F%L<V4I.PT*("`@("`@("!I9B`H)')O;W1[
M<W1R;&5N*"1R;V]T*2`M(#%](#T]("<O)RD@>PT*("`@("`@("`@("`@)')O
M;W0@/2!S=6)S='(H)')O;W0L(#`L('-T<FQE;B@D<F]O="D@+2`Q*3L-"B`@
M("`@("`@?0T*("`@("`@("`D8V]N9FEG+3YN;U)E9VES=')Y*"D[#0H@("`@
M("`@("1C;VYF:6<M/G-E="@G<&AP7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T
M7%QP96%R7%QP:'`B(#H@(B1R;V]T+W!E87(O<&AP(BP@)W5S97(G*3L-"B`@
M("`@("`@)&-O;F9I9RT^<V5T*"=D871A7V1I<B<L("1W:6YD;W=S(#\@(B1R
M;V]T7%QP96%R7%QD871A(B`Z("(D<F]O="]P96%R+V1A=&$B*3L-"B`@("`@
M("`@)&-O;F9I9RT^<V5T*"=E>'1?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<
M7'!E87)<7&5X="(@.B`B)')O;W0O<&5A<B]E>'0B*3L-"B`@("`@("`@)&-O
M;F9I9RT^<V5T*"=D;V-?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<7'!E87)<
M7&1O8W,B(#H@(B1R;V]T+W!E87(O9&]C<R(I.PT*("`@("`@("`D8V]N9FEG
M+3YS970H)W1E<W1?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<7'!E87)<7'1E
M<W1S(B`Z("(D<F]O="]P96%R+W1E<W1S(BD[#0H@("`@("`@("1C;VYF:6<M
M/G-E="@G8V%C:&5?9&ER)RP@)'=I;F1O=W,@/R`B)')O;W1<7'!E87)<7&-A
M8VAE(B`Z("(D<F]O="]P96%R+V-A8VAE(BD[#0H@("`@("`@("1C;VYF:6<M
M/G-E="@G8FEN7V1I<B<L("1W:6YD;W=S(#\@(B1R;V]T7%QP96%R(B`Z("(D
M<F]O="]P96%R(BD[#0H@("`@("`@("1C;VYF:6<M/G=R:71E0V]N9FEG1FEL
M92@I.PT*("`@("`@("`D=&AI<RT^7W-H;W=#;VYF:6<H)&-O;F9I9RD[#0H@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G4W5C8V5S<V9U;&QY(&-R
M96%T960@9&5F875L="!C;VYF:6=U<F%T:6]N(&9I;&4@(B<@+B`D<&%R86US
M6S%=("X@)R(G+`T*("`@("`@("`@("`@)&-O;6UA;F0I.PT*("`@('T-"@T*
M("`@("\O('U]?0T*#0H@("`@9G5N8W1I;VX@7W-H;W=#;VYF:6<H)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("`D<&%R86US(#T@87)R87DH)W5S97(G*3L-
M"B`@("`@("`@)&ME>7,@/2`D8V]N9FEG+3YG971+97ES*"D[#0H@("`@("`@
M('-O<G0H)&ME>7,I.PT*("`@("`@("`D8VAA;FYE;"`]("=P96%R+G!H<"YN
M970G.PT*("`@("`@("`D9&%T82`](&%R<F%Y*"=C87!T:6]N)R`]/B`G0V]N
M9FEG=7)A=&EO;B`H8VAA;FYE;"`G("X@)&-H86YN96P@+B`G*3HG*3L-"B`@
M("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PT*("`@("`@("`@("`@
M)'1Y<&4@/2`D8V]N9FEG+3YG9714>7!E*"1K97DI.PT*("`@("`@("`@("`@
M)'9A;'5E(#T@)&-O;F9I9RT^9V5T*"1K97DL("=U<V5R)RP@)&-H86YN96PI
M.PT*("`@("`@("`@("`@:68@*"1T>7!E(#T]("=P87-S=V]R9"<@)B8@)'9A
M;'5E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)RHJ*BHJ*BHJ)SL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D=F%L=64@/3T](&9A
M;'-E*2![#0H@("`@("`@("`@("`@("`@)'9A;'5E(#T@)V9A;'-E)SL-"B`@
M("`@("`@("`@('T@96QS96EF("@D=F%L=64@/3T]('1R=64I('L-"B`@("`@
M("`@("`@("`@("`D=F%L=64@/2`G=')U92<[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D9&%T85LG9&%T82==6R1C;VYF:6<M/F=E=$=R;W5P*"1K
M97DI75M=(#T-"B`@("`@("`@("`@("`@("!A<G)A>2@D8V]N9FEG+3YG9710
M<F]M<'0H)&ME>2D@+"`D:V5Y+"`D=F%L=64I.PT*("`@("`@("!]#0H@("`@
M("`@(&9O<F5A8V@@*"1C;VYF:6<M/F=E=$QA>65R<R@I(&%S("1L87EE<BD@
M>PT*("`@("`@("`@("`@)&1A=&%;)V1A=&$G75LG0V]N9FEG($9I;&5S)UU;
M72`]#0H@("`@("`@("`@("`@("`@87)R87DH=6-F:7)S="@D;&%Y97(I("X@
M)R!#;VYF:6=U<F%T:6]N($9I;&4G+"`G1FEL96YA;64G("P-"B`@("`@("`@
M("`@("`@("`@("`@)&-O;F9I9RT^9V5T0V]N9D9I;&4H)&QA>65R*2D[#0H@
M("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A
M=&$L("=C;VYF:6<M<VAO=R<I.PT*("`@("`@("!R971U<FX@=')U93L-"B`@
M("!]#0H@("`@+R\@>WM[(%]C:&5C:TQA>65R*"D-"@T*("`@("\J*@T*("`@
M("`J($-H96-K<R!I9B!A(&QA>65R(&ES(&1E9FEN960@;W(@;F]T#0H@("`@
M("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1L87EE<B!4:&4@;&%Y97(@=&\@
M<V5A<F-H(&9O<@T*("`@("`J($!R971U<FX@;6EX960@1F%L<V4@;VX@;F\@
M97)R;W(@;W(@=&AE(&5R<F]R(&UE<W-A9V4-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!?8VAE8VM,87EE<B@D;&%Y97(@/2!N=6QL*0T*("`@('L-"B`@("`@
M("`@:68@*"%E;7!T>2@D;&%Y97(I("8F("1L87EE<B`A/2`G9&5F875L="<I
M('L-"B`@("`@("`@("`@("1L87EE<G,@/2`D=&AI<RT^8V]N9FEG+3YG971,
M87EE<G,H*3L-"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&QA>65R+"`D
M;&%Y97)S*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`B(&]N;'D@=&AE
M(&QA>65R<SH@7"(B("X@:6UP;&]D92@G(B!O<B`B)RP@)&QA>65R<RD@+B`B
M7"(@87)E('-U<'!O<G1E9"([#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@('T-"@T*("`@("\O('U]?0T*
M?0T*#0H_/@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O26YS=&%L;"YX;6P`
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$W-C`T(#$P-3$U-#,T
M,3,T(#`R,C<R-P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\:6YS=&%L;#X-
M"B`@/'-U;6UA<GD^26YS=&%L;"!086-K86=E/"]S=6UM87)Y/@T*("`\9G5N
M8W1I;VX^9&]);G-T86QL/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FD\+W-H
M;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QF;W)C93X-"B`@("`\<VAO<G1O
M<'0^9CPO<VAO<G1O<'0^#0H@("`@/&1O8SYW:6QL(&]V97)W<FET92!N97=E
M<B!I;G-T86QL960@<&%C:V%G97,\+V1O8SX-"B`@(#PO9F]R8V4^#0H@("`\
M;&]O<V4^#0H@("`@/'-H;W)T;W!T/FP\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M9&\@;F]T(&-H96-K(&9O<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y('9E<G-I
M;VX\+V1O8SX-"B`@(#PO;&]O<V4^#0H@("`\;F]D97!S/@T*("`@(#QS:&]R
M=&]P=#YN/"]S:&]R=&]P=#X-"B`@("`\9&]C/FEG;F]R92!D97!E;F1E;F-I
M97,L(&EN<W1A;&P@86YY=V%Y/"]D;V,^#0H@("`\+VYO9&5P<SX-"B`@(#QR
M96=I<W1E<BUO;FQY/@T*("`@(#QS:&]R=&]P=#YR/"]S:&]R=&]P=#X-"B`@
M("`\9&]C/F1O(&YO="!I;G-T86QL(&9I;&5S+"!O;FQY(')E9VES=&5R('1H
M92!P86-K86=E(&%S(&EN<W1A;&QE9#PO9&]C/@T*("`@/"]R96=I<W1E<BUO
M;FQY/@T*("`@/'-O9G0^#0H@("`@/'-H;W)T;W!T/G,\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^<V]F="!I;G-T86QL+"!F86EL('-I;&5N=&QY+"!O<B!U<&=R
M861E(&EF(&%L<F5A9'D@:6YS=&%L;&5D/"]D;V,^#0H@("`\+W-O9G0^#0H@
M("`\;F]B=6EL9#X-"B`@("`\<VAO<G1O<'0^0CPO<VAO<G1O<'0^#0H@("`@
M/&1O8SYD;VXF87!O<SMT(&)U:6QD($,@97AT96YS:6]N<SPO9&]C/@T*("`@
M/"]N;V)U:6QD/@T*("`@/&YO8V]M<')E<W,^#0H@("`@/'-H;W)T;W!T/EH\
M+W-H;W)T;W!T/@T*("`@(#QD;V,^<F5Q=65S="!U;F-O;7!R97-S960@9FEL
M97,@=VAE;B!D;W=N;&]A9&EN9SPO9&]C/@T*("`@/"]N;V-O;7!R97-S/@T*
M("`@/&EN<W1A;&QR;V]T/@T*("`@(#QS:&]R=&]P=#Y2/"]S:&]R=&]P=#X-
M"B`@("`\87)G/D1)4CPO87)G/@T*("`@(#QD;V,^<F]O="!D:7)E8W1O<GD@
M=7-E9"!W:&5N(&EN<W1A;&QI;F<@9FEL97,@*&%L82!02%`F87!O<SMS($E.
M4U1!3$Q?4D]/5"D\+V1O8SX-"B`@(#PO:6YS=&%L;')O;W0^#0H@("`\:6=N
M;W)E+65R<F]R<SX-"B`@("`\9&]C/F9O<F-E(&EN<W1A;&P@979E;B!I9B!T
M:&5R92!W97)E(&5R<F]R<SPO9&]C/@T*("`@/"]I9VYO<F4M97)R;W)S/@T*
M("`@/&%L;&1E<',^#0H@("`@/'-H;W)T;W!T/F$\+W-H;W)T;W!T/@T*("`@
M(#QD;V,^:6YS=&%L;"!A;&P@<F5Q=6ER960@86YD(&]P=&EO;F%L(&1E<&5N
M9&5N8VEE<SPO9&]C/@T*("`@/"]A;&QD97!S/@T*("`@/&]N;'ER97%D97!S
M/@T*("`@(#QS:&]R=&]P=#YO/"]S:&]R=&]P=#X-"B`@("`\9&]C/FEN<W1A
M;&P@86QL(')E<75I<F5D(&1E<&5N9&5N8VEE<SPO9&]C/@T*("`@/"]O;FQY
M<F5Q9&5P<SX-"B`@(#QO9F9L:6YE/@T*("`@(#QS:&]R=&]P=#Y//"]S:&]R
M=&]P=#X-"B`@("`\9&]C/F1O(&YO="!A='1E;7!T('1O(&1O=VYL;V%D(&%N
M>2!U<FQS(&]R(&-O;G1A8W0@8VAA;FYE;',\+V1O8SX-"B`@(#PO;V9F;&EN
M93X-"B`@(#QP<F5T96YD/@T*("`@(#QS:&]R=&]P=#YP/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/D]N;'D@;&ES="!T:&4@<&%C:V%G97,@=&AA="!W;W5L9"!B
M92!D;W=N;&]A9&5D/"]D;V,^#0H@("`\+W!R971E;F0^#0H@(#PO;W!T:6]N
M<SX-"B`@/&1O8SY;8VAA;FYE;"]=)FQT.W!A8VMA9V4F9W0[("XN+@T*26YS
M=&%L;',@;VYE(&]R(&UO<F4@4$5!4B!P86-K86=E<RX@(%EO=2!C86X@<W!E
M8VEF>2!A('!A8VMA9V4@=&\-"FEN<W1A;&P@:6X@9F]U<B!W87ES.@T*#0HF
M<75O=#M086-K86=E+3$N,"YT9WHF<75O=#L@.B!I;G-T86QL<R!F<F]M(&$@
M;&]C86P@9FEL90T*#0HF<75O=#MH='1P.B\O97AA;7!L92YC;VTO4&%C:V%G
M92TQ+C`N=&=Z)G%U;W0[(#H@:6YS=&%L;',@9G)O;0T*86YY=VAE<F4@;VX@
M=&AE(&YE="X-"@T*)G%U;W0[<&%C:V%G92YX;6PF<75O=#L@.B!I;G-T86QL
M<R!T:&4@<&%C:V%G92!D97-C<FEB960@:6X-"G!A8VMA9V4N>&UL+B`@57-E
M9G5L(&9O<B!T97-T:6YG+"!O<B!F;W(@=W)A<'!I;F<@82!014%2('!A8VMA
M9V4@:6X-"F%N;W1H97(@<&%C:V%G92!M86YA9V5R('-U8V@@87,@4E!-+@T*
M#0HF<75O=#M086-K86=E6RUV97)S:6]N+W-T871E75LN=&%R729Q=6]T.R`Z
M('%U97)I97,@>6]U<B!D969A=6QT(&-H86YN96PF87!O<SMS('-E<G9E<@T*
M*'MC;VYF:6<@;6%S=&5R7W-E<G9E<GTI(&%N9"!D;W=N;&]A9',@=&AE(&YE
M=V5S="!P86-K86=E('=I=&@-"G1H92!P<F5F97)R960@<75A;&ET>2]S=&%T
M92`H>V-O;F9I9R!P<F5F97)R961?<W1A=&5]*2X-"@T*5&\@<F5T<FEE=F4@
M4&%C:V%G92!V97)S:6]N(#$N,2P@=7-E("9Q=6]T.U!A8VMA9V4M,2XQ+"9Q
M=6]T.R!T;R!R971R:65V90T*4&%C:V%G92!S=&%T92!B971A+"!U<V4@)G%U
M;W0[4&%C:V%G92UB971A+B9Q=6]T.R`@5&\@<F5T<FEE=F4@86X@=6YC;VUP
M<F5S<V5D#0IF:6QE+"!A<'!E;F0@+G1A<B`H;6%K92!S=7)E('1H97)E(&ES
M(&YO(&9I;&4@8GD@=&AE('-A;64@;F%M92!F:7)S="D-"@T*5&\@9&]W;FQO
M860@82!P86-K86=E(&9R;VT@86YO=&AE<B!C:&%N;F5L+"!P<F5F:7@@=VET
M:"!T:&4@8VAA;FYE;"!N86UE(&QI:V4-"B9Q=6]T.V-H86YN96PO4&%C:V%G
M929Q=6]T.PT*#0I-;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y(&)E('-P96-I
M9FEE9"!A="!O;F-E+B`@270@:7,@;VL@=&\@;6EX('1H97-E#0IF;W5R('=A
M>7,@;V8@<W!E8VEF>6EN9R!P86-K86=E<RX-"CPO9&]C/@T*(#PO:6YS=&%L
M;#X-"B`\=7!G<F%D93X-"B`@/'-U;6UA<GD^57!G<F%D92!086-K86=E/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]);G-T86QL/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/G5P/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\9F]R
M8V4^#0H@("`@/'-H;W)T;W!T/F8\+W-H;W)T;W!T/@T*("`@(#QD;V,^;W9E
M<G=R:71E(&YE=V5R(&EN<W1A;&QE9"!P86-K86=E<SPO9&]C/@T*("`@/"]F
M;W)C93X-"B`@(#QL;V]S93X-"B`@("`\<VAO<G1O<'0^;#PO<VAO<G1O<'0^
M#0H@("`@/&1O8SYD;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D(&1E<&5N
M9&5N8WD@=F5R<VEO;CPO9&]C/@T*("`@/"]L;V]S93X-"B`@(#QN;V1E<',^
M#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^:6=N;W)E
M(&1E<&5N9&5N8VEE<RP@=7!G<F%D92!A;GEW87D\+V1O8SX-"B`@(#PO;F]D
M97!S/@T*("`@/')E9VES=&5R+6]N;'D^#0H@("`@/'-H;W)T;W!T/G(\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&EN<W1A;&P@9FEL97,L(&]N;'D@
M<F5G:7-T97(@=&AE('!A8VMA9V4@87,@=7!G<F%D960\+V1O8SX-"B`@(#PO
M<F5G:7-T97(M;VYL>3X-"B`@(#QN;V)U:6QD/@T*("`@(#QS:&]R=&]P=#Y"
M/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O;B9A<&]S.W0@8G5I;&0@0R!E>'1E
M;G-I;VYS/"]D;V,^#0H@("`\+VYO8G5I;&0^#0H@("`\;F]C;VUP<F5S<SX-
M"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@("`@/&1O8SYR97%U97-T
M('5N8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG/"]D;V,^#0H@
M("`\+VYO8V]M<')E<W,^#0H@("`\:6YS=&%L;')O;W0^#0H@("`@/'-H;W)T
M;W!T/E(\+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2/"]A<F<^#0H@("`@/&1O
M8SYR;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F:6QE<R`H
M86QA(%!(4"9A<&]S.W,@24Y35$%,3%]23T]4*3PO9&]C/@T*("`@/"]I;G-T
M86QL<F]O=#X-"B`@(#QI9VYO<F4M97)R;W)S/@T*("`@(#QD;V,^9F]R8V4@
M:6YS=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S/"]D;V,^#0H@("`\
M+VEG;F]R92UE<G)O<G,^#0H@("`\86QL9&5P<SX-"B`@("`\<VAO<G1O<'0^
M83PO<VAO<G1O<'0^#0H@("`@/&1O8SYI;G-T86QL(&%L;"!R97%U:7)E9"!A
M;F0@;W!T:6]N86P@9&5P96YD96YC:65S/"]D;V,^#0H@("`\+V%L;&1E<',^
M#0H@("`\;VYL>7)E<61E<',^#0H@("`@/'-H;W)T;W!T/F\\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^:6YS=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S
M/"]D;V,^#0H@("`\+V]N;'ER97%D97!S/@T*("`@/&]F9FQI;F4^#0H@("`@
M/'-H;W)T;W!T/D\\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&%T=&5M
M<'0@=&\@9&]W;FQO860@86YY('5R;',@;W(@8V]N=&%C="!C:&%N;F5L<SPO
M9&]C/@T*("`@/"]O9F9L:6YE/@T*("`@/'!R971E;F0^#0H@("`@/'-H;W)T
M;W!T/G`\+W-H;W)T;W!T/@T*("`@(#QD;V,^3VYL>2!L:7-T('1H92!P86-K
M86=E<R!T:&%T('=O=6QD(&)E(&1O=VYL;V%D960\+V1O8SX-"B`@(#PO<')E
M=&5N9#X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E)F=T.R`N
M+BX-"E5P9W)A9&5S(&]N92!O<B!M;W)E(%!%05(@<&%C:V%G97,N("!3964@
M9&]C=6UE;G1A=&EO;B!F;W(@=&AE#0HF<75O=#MI;G-T86QL)G%U;W0[(&-O
M;6UA;F0@9F]R('=A>7,@=&\@<W!E8VEF>2!A('!A8VMA9V4N#0H-"E=H96X@
M=7!G<F%D:6YG+"!Y;W5R('!A8VMA9V4@=VEL;"!B92!U<&1A=&5D(&EF('1H
M92!P<F]V:61E9"!N97<-"G!A8VMA9V4@:&%S(&$@:&EG:&5R('9E<G-I;VX@
M;G5M8F5R("AU<V4@=&AE("UF(&]P=&EO;B!I9B!Y;W4@;F5E9"!T;PT*=7!G
M<F%D92!A;GEW87DI+@T*#0I-;W)E('1H86X@;VYE('!A8VMA9V4@;6%Y(&)E
M('-P96-I9FEE9"!A="!O;F-E+@T*/"]D;V,^#0H@/"]U<&=R861E/@T*(#QU
M<&=R861E+6%L;#X-"B`@/'-U;6UA<GD^57!G<F%D92!!;&P@4&%C:V%G97,\
M+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TEN<W1A;&P\+V9U;F-T:6]N/@T*
M("`\<VAO<G1C=70^=6$\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QN
M;V1E<',^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M:6=N;W)E(&1E<&5N9&5N8VEE<RP@=7!G<F%D92!A;GEW87D\+V1O8SX-"B`@
M(#PO;F]D97!S/@T*("`@/')E9VES=&5R+6]N;'D^#0H@("`@/'-H;W)T;W!T
M/G(\+W-H;W)T;W!T/@T*("`@(#QD;V,^9&\@;F]T(&EN<W1A;&P@9FEL97,L
M(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@=7!G<F%D960\+V1O8SX-
M"B`@(#PO<F5G:7-T97(M;VYL>3X-"B`@(#QN;V)U:6QD/@T*("`@(#QS:&]R
M=&]P=#Y"/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O;B9A<&]S.W0@8G5I;&0@
M0R!E>'1E;G-I;VYS/"]D;V,^#0H@("`\+VYO8G5I;&0^#0H@("`\;F]C;VUP
M<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@("`@/&1O8SYR
M97%U97-T('5N8V]M<')E<W-E9"!F:6QE<R!W:&5N(&1O=VYL;V%D:6YG/"]D
M;V,^#0H@("`\+VYO8V]M<')E<W,^#0H@("`\:6YS=&%L;')O;W0^#0H@("`@
M/'-H;W)T;W!T/E(\+W-H;W)T;W!T/@T*("`@(#QA<F<^1$E2/"]A<F<^#0H@
M("`@/&1O8SYR;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@:6YS=&%L;&EN9R!F
M:6QE<R`H86QA(%!(4"9A<&]S.W,@24Y35$%,3%]23T]4*3PO9&]C/@T*("`@
M/"]I;G-T86QL<F]O=#X-"B`@(#QI9VYO<F4M97)R;W)S/@T*("`@(#QD;V,^
M9F]R8V4@:6YS=&%L;"!E=F5N(&EF('1H97)E('=E<F4@97)R;W)S/"]D;V,^
M#0H@("`\+VEG;F]R92UE<G)O<G,^#0H@("`\;&]O<V4^#0H@("`@/&1O8SYD
M;R!N;W0@8VAE8VL@9F]R(')E8V]M;65N9&5D(&1E<&5N9&5N8WD@=F5R<VEO
M;CPO9&]C/@T*("`@/"]L;V]S93X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/@T*
M57!G<F%D97,@86QL('!A8VMA9V5S('1H870@:&%V92!A(&YE=V5R(')E;&5A
M<V4@879A:6QA8FQE+B`@57!G<F%D97,@87)E#0ID;VYE(&]N;'D@:68@=&AE
M<F4@:7,@82!R96QE87-E(&%V86EL86)L92!O9B!T:&4@<W1A=&4@<W!E8VEF
M:65D(&EN#0HF<75O=#MP<F5F97)R961?<W1A=&4F<75O=#L@*&-U<G)E;G1L
M>2![8V]N9FEG('!R969E<G)E9%]S=&%T97TI+"!O<B!A('-T871E(&-O;G-I
M9&5R960-"FUO<F4@<W1A8FQE+@T*/"]D;V,^#0H@/"]U<&=R861E+6%L;#X-
M"B`\=6YI;G-T86QL/@T*("`\<W5M;6%R>3Y5;BUI;G-T86QL(%!A8VMA9V4\
M+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U5N:6YS=&%L;#PO9G5N8W1I;VX^
M#0H@(#QS:&]R=&-U=#YU;CPO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@
M/&YO9&5P<SX-"B`@("`\<VAO<G1O<'0^;CPO<VAO<G1O<'0^#0H@("`@/&1O
M8SYI9VYO<F4@9&5P96YD96YC:65S+"!U;FEN<W1A;&P@86YY=V%Y/"]D;V,^
M#0H@("`\+VYO9&5P<SX-"B`@(#QR96=I<W1E<BUO;FQY/@T*("`@(#QS:&]R
M=&]P=#YR/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!R96UO=F4@9FEL
M97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V5S(&%S(&YO="!I;G-T86QL
M960\+V1O8SX-"B`@(#PO<F5G:7-T97(M;VYL>3X-"B`@(#QI;G-T86QL<F]O
M=#X-"B`@("`\<VAO<G1O<'0^4CPO<VAO<G1O<'0^#0H@("`@/&%R9SY$25(\
M+V%R9SX-"B`@("`\9&]C/G)O;W0@9&ER96-T;W)Y('5S960@=VAE;B!I;G-T
M86QL:6YG(&9I;&5S("AA;&$@4$A0)F%P;W,[<R!)3E-404Q,7U)/3U0I/"]D
M;V,^#0H@("`\+VEN<W1A;&QR;V]T/@T*("`@/&EG;F]R92UE<G)O<G,^#0H@
M("`@/&1O8SYF;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@=V5R92!E<G)O
M<G,\+V1O8SX-"B`@(#PO:6=N;W)E+65R<F]R<SX-"B`@(#QO9F9L:6YE/@T*
M("`@(#QS:&]R=&]P=#Y//"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!A
M='1E;7!T('1O('5N:6YS=&%L;"!R96UO=&5L>3PO9&]C/@T*("`@/"]O9F9L
M:6YE/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^6V-H86YN96PO729L=#MP86-K
M86=E)F=T.R`N+BX-"E5N:6YS=&%L;',@;VYE(&]R(&UO<F4@4$5!4B!P86-K
M86=E<RX@($UO<F4@=&AA;B!O;F4@<&%C:V%G92!M87D@8F4-"G-P96-I9FEE
M9"!A="!O;F-E+B`@4')E9FEX('=I=&@@8VAA;FYE;"!N86UE('1O('5N:6YS
M=&%L;"!F<F]M(&$-"F-H86YN96P@;F]T(&EN('EO=7(@9&5F875L="!C:&%N
M;F5L("A[8V]N9FEG(&1E9F%U;'1?8VAA;FYE;'TI#0H\+V1O8SX-"B`\+W5N
M:6YS=&%L;#X-"B`\8G5N9&QE/@T*("`\<W5M;6%R>3Y5;G!A8VMS(&$@4&5C
M;"!086-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]"=6YD;&4\+V9U
M;F-T:6]N/@T*("`\<VAO<G1C=70^8G5N/"]S:&]R=&-U=#X-"B`@/&]P=&EO
M;G,^#0H@("`\9&5S=&EN871I;VX^#0H@("`@/'-H;W)T;W!T/F0\+W-H;W)T
M;W!T/@T*("`@(#QA<F<^1$E2/"]A<F<^#0H@("`@/&1O8SY/<'1I;VYA;"!D
M97-T:6YA=&EO;B!D:7)E8W1O<GD@9F]R('5N<&%C:VEN9R`H9&5F875L=',@
M=&\@8W5R<F5N="!P871H(&]R("9Q=6]T.V5X="9Q=6]T.R!I9B!E>&ES=',I
M/"]D;V,^#0H@("`\+V1E<W1I;F%T:6]N/@T*("`@/&9O<F-E/@T*("`@(#QS
M:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/D9O<F-E('1H92!U;G!A
M8VMI;F<@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R!I;B!T:&4@<&%C:V%G
M93PO9&]C/@T*("`@/"]F;W)C93X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L
M=#MP86-K86=E)F=T.PT*56YP86-K<R!A(%!E8VP@4&%C:V%G92!I;G1O('1H
M92!S96QE8W1E9"!L;V-A=&EO;BX@270@=VEL;"!D;W=N;&]A9"!T:&4-"G!A
M8VMA9V4@:68@;F5E9&5D+@T*/"]D;V,^#0H@/"]B=6YD;&4^#0H@/')U;BUS
M8W)I<'1S/@T*("`\<W5M;6%R>3Y2=6X@4&]S="U);G-T86QL(%-C<FEP=',@
M8G5N9&QE9"!W:71H(&$@<&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N
M/F1O4G5N4V-R:7!T<SPO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YR<SPO<VAO
M<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^)FQT.W!A8VMA9V4F9W0[
M#0I2=6X@<&]S="UI;G-T86QL871I;VX@<V-R:7!T<R!I;B!P86-K86=E("9L
M=#MP86-K86=E)F=T.RP@:68@86YY(&5X:7-T+@T*/"]D;V,^#0H@/"]R=6XM
M<V-R:7!T<SX-"CPO8V]M;6%N9',^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#
M;VUM86YD+TEN<W1A;&PN<&AP````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#$P,3$T-2`Q,#4Q-30S-#$S-"`P,C(W,3``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!
M4E]#;VUM86YD7TEN<W1A;&P@*&EN<W1A;&PL('5P9W)A9&4L('5P9W)A9&4M
M86QL+"!U;FEN<W1A;&PL(&)U;F1L92P@<G5N+7-C<FEP=',@8V]M;6%N9',I
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($EN<W1A;&PN
M<&AP+'8@,2XQ,34@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@
M*B!014%2(&-O;6UA;F1S(&9O<B!I;G-T86QL871I;VX@;W(@9&5I;G-T86QL
M871I;VXO=7!G<F%D:6YG(&]F#0H@*B!P86-K86=E<RX-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*
M("HO#0IC;&%S<R!014%27T-O;6UA;F1?26YS=&%L;"!E>'1E;F1S(%!%05)?
M0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@
M("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G:6YS=&%L;"<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)TEN<W1A;&P@
M4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TEN<W1A
M;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G:2<L#0H@("`@("`@
M("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)V9O
M<F-E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G9B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=W:6QL
M(&]V97)W<FET92!N97=E<B!I;G-T86QL960@<&%C:V%G97,G+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=L;V]S92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VPG
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&-H96-K
M(&9O<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y('9E<G-I;VXG+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V1E<',G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VEG;F]R92!D97!E
M;F1E;F-I97,L(&EN<W1A;&P@86YY=V%Y)RP-"B`@("`@("`@("`@("`@("`@
M("`@*2P-"B`@("`@("`@("`@("`@("`G<F5G:7-T97(M;VYL>2<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&EN<W1A;&P@
M9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@:6YS=&%L;&5D
M)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G
M<V]F="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)W,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<V]F
M="!I;G-T86QL+"!F86EL('-I;&5N=&QY+"!O<B!U<&=R861E(&EF(&%L<F5A
M9'D@:6YS=&%L;&5D)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`G;F]B=6EL9"<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)T(G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G9&]N7"=T(&)U:6QD($,@97AT96YS:6]N<R<L#0H@("`@
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E
M<W,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=:)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)E<75E
M<W0@=6YC;VUP<F5S<V5D(&9I;&5S('=H96X@9&]W;FQO861I;F<G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I;G-T86QL
M<F]O="<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)U(G+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER96-T
M;W)Y('5S960@=VAE;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A07"=S($E.
M4U1!3$Q?4D]/5"DL('5S92!P86-K86=I;F=R;V]T(&9O<B!24$TG+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=P86-K86=I
M;F=R;V]T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G4"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$
M25(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G<F]O="!D:7)E
M8W1O<GD@=7-E9"!W:&5N('!A8VMA9VEN9R!F:6QE<RP@;&EK92!24$T@<&%C
M:V%G:6YG)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("`@("`G:6=N;W)E+65R<F]R<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=D;V,G(#T^("=F;W)C92!I;G-T86QL(&5V96X@:68@=&AE<F4@
M=V5R92!E<G)O<G,G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("=A;&QD97!S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G82<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=I;G-T86QL(&%L;"!R97%U:7)E9"!A;F0@;W!T:6]N86P@
M9&5P96YD96YC:65S)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`G;VYL>7)E<61E<',G(#T^(&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=O)RP-"B`@("`@("`@("`@("`@
M("`@("`@)V1O8R<@/3X@)VEN<W1A;&P@86QL(')E<75I<F5D(&1E<&5N9&5N
M8VEE<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)V]F9FQI;F4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M<VAO<G1O<'0G(#T^("=/)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)V1O(&YO="!A='1E;7!T('1O(&1O=VYL;V%D(&%N>2!U<FQS(&]R(&-O
M;G1A8W0@8VAA;FYE;',G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@("`@("=P<F5T96YD)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<"<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=/;FQY(&QI<W0@=&AE('!A8VMA9V5S('1H870@=V]U
M;&0@8F4@9&]W;FQO861E9"<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@
M("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^("=;8VAA
M;FYE;"]=/'!A8VMA9V4^("XN+@T*26YS=&%L;',@;VYE(&]R(&UO<F4@4$5!
M4B!P86-K86=E<RX@(%EO=2!C86X@<W!E8VEF>2!A('!A8VMA9V4@=&\-"FEN
M<W1A;&P@:6X@9F]U<B!W87ES.@T*#0HB4&%C:V%G92TQ+C`N=&=Z(B`Z(&EN
M<W1A;&QS(&9R;VT@82!L;V-A;"!F:6QE#0H-"B)H='1P.B\O97AA;7!L92YC
M;VTO4&%C:V%G92TQ+C`N=&=Z(B`Z(&EN<W1A;&QS(&9R;VT-"F%N>7=H97)E
M(&]N('1H92!N970N#0H-"B)P86-K86=E+GAM;"(@.B!I;G-T86QL<R!T:&4@
M<&%C:V%G92!D97-C<FEB960@:6X-"G!A8VMA9V4N>&UL+B`@57-E9G5L(&9O
M<B!T97-T:6YG+"!O<B!F;W(@=W)A<'!I;F<@82!014%2('!A8VMA9V4@:6X-
M"F%N;W1H97(@<&%C:V%G92!M86YA9V5R('-U8V@@87,@4E!-+@T*#0HB4&%C
M:V%G95LM=F5R<VEO;B]S=&%T95U;+G1A<ETB(#H@<75E<FEE<R!Y;W5R(&1E
M9F%U;'0@8VAA;FYE;%PG<R!S97)V97(-"BA[8V]N9FEG(&UA<W1E<E]S97)V
M97)]*2!A;F0@9&]W;FQO861S('1H92!N97=E<W0@<&%C:V%G92!W:71H#0IT
M:&4@<')E9F5R<F5D('%U86QI='DO<W1A=&4@*'MC;VYF:6<@<')E9F5R<F5D
M7W-T871E?2DN#0H-"E1O(')E=')I979E(%!A8VMA9V4@=F5R<VEO;B`Q+C$L
M('5S92`B4&%C:V%G92TQ+C$L(B!T;R!R971R:65V90T*4&%C:V%G92!S=&%T
M92!B971A+"!U<V4@(E!A8VMA9V4M8F5T82XB("!4;R!R971R:65V92!A;B!U
M;F-O;7!R97-S960-"F9I;&4L(&%P<&5N9"`N=&%R("AM86ME('-U<F4@=&AE
M<F4@:7,@;F\@9FEL92!B>2!T:&4@<V%M92!N86UE(&9I<G-T*0T*#0I4;R!D
M;W=N;&]A9"!A('!A8VMA9V4@9G)O;2!A;F]T:&5R(&-H86YN96PL('!R969I
M>"!W:71H('1H92!C:&%N;F5L(&YA;64@;&EK90T*(F-H86YN96PO4&%C:V%G
M92(-"@T*36]R92!T:&%N(&]N92!P86-K86=E(&UA>2!B92!S<&5C:69I960@
M870@;VYC92X@($ET(&ES(&]K('1O(&UI>"!T:&5S90T*9F]U<B!W87ES(&]F
M('-P96-I9GEI;F<@<&%C:V%G97,N#0HG*2P-"B`@("`@("`@)W5P9W)A9&4G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=5<&=R861E
M(%!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]);G-T
M86QL)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W5P)RP-"B`@("`@
M("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G
M9F]R8V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=F)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V]V
M97)W<FET92!N97=E<B!I;G-T86QL960@<&%C:V%G97,G+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=L;V]S92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VPG+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&-H96-K(&9O
M<B!R96-O;6UE;F1E9"!D97!E;F1E;F-Y('9E<G-I;VXG+`T*("`@("`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V1E<',G(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VEG;F]R92!D97!E;F1E
M;F-I97,L('5P9W)A9&4@86YY=V%Y)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G<F5G:7-T97(M;VYL>2<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G+`T*("`@
M("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&EN<W1A;&P@9FEL
M97,L(&]N;'D@<F5G:7-T97(@=&AE('!A8VMA9V4@87,@=7!G<F%D960G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=N;V)U
M:6QD)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T
M)R`]/B`G0B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=D;VY<
M)W0@8G5I;&0@0R!E>'1E;G-I;VYS)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`T*("`@("`@
M("`@("`@("`@("`@("`G9&]C)R`]/B`G<F5Q=65S="!U;F-O;7!R97-S960@
M9FEL97,@=VAE;B!D;W=N;&]A9&EN9R<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)VEN<W1A;&QR;V]T)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G4B<L#0H@("`@
M("`@("`@("`@("`@("`@("=A<F<G(#T^("=$25(G+`T*("`@("`@("`@("`@
M("`@("`@("`G9&]C)R`]/B`G<F]O="!D:7)E8W1O<GD@=7-E9"!W:&5N(&EN
M<W1A;&QI;F<@9FEL97,@*&%L82!02%!<)W,@24Y35$%,3%]23T]4*2P@=7-E
M('!A8VMA9VEN9W)O;W0@9F]R(%)032<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W!A8VMA9VEN9W)O;W0G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=0)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T1)4B<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=R;V]T(&1I<F5C=&]R>2!U<V5D('=H96X@
M<&%C:V%G:6YG(&9I;&5S+"!L:6ME(%)032!P86-K86=I;F<G+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M97)R
M;W)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@
M)V9O<F-E(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V%L;&1E
M<',G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=A)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)VEN<W1A
M;&P@86QL(')E<75I<F5D(&%N9"!O<'1I;VYA;"!D97!E;F1E;F-I97,G+`T*
M("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=O;FQY
M<F5Q9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R
M=&]P="<@/3X@)V\G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M:6YS=&%L;"!A;&P@<F5Q=6ER960@9&5P96YD96YC:65S)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;V9F;&EN92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)T\G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&\@;F]T(&%T=&5M
M<'0@=&\@9&]W;FQO860@86YY('5R;',@;W(@8V]N=&%C="!C:&%N;F5L<R<L
M#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W!R
M971E;F0G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O
M<'0G(#T^("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T]N
M;'D@;&ES="!T:&4@<&%C:V%G97,@=&AA="!W;W5L9"!B92!D;W=N;&]A9&5D
M)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/B`N+BX-"E5P9W)A
M9&5S(&]N92!O<B!M;W)E(%!%05(@<&%C:V%G97,N("!3964@9&]C=6UE;G1A
M=&EO;B!F;W(@=&AE#0HB:6YS=&%L;"(@8V]M;6%N9"!F;W(@=V%Y<R!T;R!S
M<&5C:69Y(&$@<&%C:V%G92X-"@T*5VAE;B!U<&=R861I;F<L('EO=7(@<&%C
M:V%G92!W:6QL(&)E('5P9&%T960@:68@=&AE('!R;W9I9&5D(&YE=PT*<&%C
M:V%G92!H87,@82!H:6=H97(@=F5R<VEO;B!N=6UB97(@*'5S92!T:&4@+68@
M;W!T:6]N(&EF('EO=2!N965D('1O#0IU<&=R861E(&%N>7=A>2DN#0H-"DUO
M<F4@=&AA;B!O;F4@<&%C:V%G92!M87D@8F4@<W!E8VEF:65D(&%T(&]N8V4N
M#0HG*2P-"B`@("`@("`@)W5P9W)A9&4M86QL)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("=S=6UM87)Y)R`]/B`G57!G<F%D92!!;&P@4&%C:V%G97,G+`T*
M("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]);G-T86QL)RP-"B`@("`@
M("`@("`@("=S:&]R=&-U="<@/3X@)W5A)RP-"B`@("`@("`@("`@("=O<'1I
M;VYS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]D97!S)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=I9VYO<F4@9&5P96YD
M96YC:65S+"!U<&=R861E(&%N>7=A>2<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W)E9VES=&5R+6]N;'DG(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@
M("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!I;G-T86QL(&9I
M;&5S+"!O;FQY(')E9VES=&5R('1H92!P86-K86=E(&%S('5P9W)A9&5D)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G;F]B
M=6EL9"<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P
M="<@/3X@)T(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&]N
M7"=T(&)U:6QD($,@97AT96YS:6]N<R<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=:)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)W)E<75E<W0@=6YC;VUP<F5S<V5D
M(&9I;&5S('=H96X@9&]W;FQO861I;F<G+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=I;G-T86QL<F]O="<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G+`T*("`@
M("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2)RP-"B`@("`@("`@("`@
M("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER96-T;W)Y('5S960@=VAE;B!I
M;G-T86QL:6YG(&9I;&5S("AA;&$@4$A07"=S($E.4U1!3$Q?4D]/5"DL('5S
M92!P86-K86=I;F=R;V]T(&9O<B!24$TG+`T*("`@("`@("`@("`@("`@("`@
M("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M97)R;W)S)R`]/B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V9O<F-E(&EN<W1A
M;&P@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R<L#0H@("`@("`@("`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`@("`@)VQO;W-E)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)V1O(&YO="!C:&5C:R!F
M;W(@<F5C;VUM96YD960@9&5P96YD96YC>2!V97)S:6]N)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)PT*57!G<F%D97,@86QL('!A8VMA9V5S('1H870@:&%V
M92!A(&YE=V5R(')E;&5A<V4@879A:6QA8FQE+B`@57!G<F%D97,@87)E#0ID
M;VYE(&]N;'D@:68@=&AE<F4@:7,@82!R96QE87-E(&%V86EL86)L92!O9B!T
M:&4@<W1A=&4@<W!E8VEF:65D(&EN#0HB<')E9F5R<F5D7W-T871E(B`H8W5R
M<F5N=&QY('MC;VYF:6<@<')E9F5R<F5D7W-T871E?2DL(&]R(&$@<W1A=&4@
M8V]N<VED97)E9`T*;6]R92!S=&%B;&4N#0HG*2P-"B`@("`@("`@)W5N:6YS
M=&%L;"<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)U5N
M+6EN<W1A;&P@4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^
M("=D;U5N:6YS=&%L;"<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=U
M;B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@
M("`@("`@("`@)VYO9&5P<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@("`@("`@("`@("`@("`G
M9&]C)R`]/B`G:6=N;W)E(&1E<&5N9&5N8VEE<RP@=6YI;G-T86QL(&%N>7=A
M>2<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M)W)E9VES=&5R+6]N;'DG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<VAO<G1O<'0G(#T^("=R)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O
M8R<@/3X@)V1O(&YO="!R96UO=F4@9FEL97,L(&]N;'D@<F5G:7-T97(@=&AE
M('!A8VMA9V5S(&%S(&YO="!I;G-T86QL960G+`T*("`@("`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@("`@("=I;G-T86QL<F]O="<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G+`T*
M("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G1$E2)RP-"B`@("`@("`@
M("`@("`@("`@("`@)V1O8R<@/3X@)W)O;W0@9&ER96-T;W)Y('5S960@=VAE
M;B!I;G-T86QL:6YG(&9I;&5S("AA;&$@4$A07"=S($E.4U1!3$Q?4D]/5"DG
M+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I
M9VYO<F4M97)R;W)S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)V1O8R<@/3X@)V9O<F-E(&EN<W1A;&P@979E;B!I9B!T:&5R92!W97)E(&5R
M<F]R<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@
M("`@)V]F9FQI;F4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G
M<VAO<G1O<'0G(#T^("=/)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@
M/3X@)V1O(&YO="!A='1E;7!T('1O('5N:6YS=&%L;"!R96UO=&5L>2<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("=D;V,G(#T^("=;8VAA;FYE;"]=/'!A8VMA9V4^("XN+@T*
M56YI;G-T86QL<R!O;F4@;W(@;6]R92!014%2('!A8VMA9V5S+B`@36]R92!T
M:&%N(&]N92!P86-K86=E(&UA>2!B90T*<W!E8VEF:65D(&%T(&]N8V4N("!0
M<F5F:7@@=VET:"!C:&%N;F5L(&YA;64@=&\@=6YI;G-T86QL(&9R;VT@80T*
M8VAA;FYE;"!N;W0@:6X@>6]U<B!D969A=6QT(&-H86YN96P@*'MC;VYF:6<@
M9&5F875L=%]C:&%N;F5L?2D-"B<I+`T*("`@("`@("`G8G5N9&QE)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G56YP86-K<R!A(%!E
M8VP@4&%C:V%G92<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;T)U
M;F1L92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=B=6XG+`T*("`@
M("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@
M("=D97-T:6YA=&EO;B<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G9"<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G
M(#T^("=$25(G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G3W!T
M:6]N86P@9&5S=&EN871I;VX@9&ER96-T;W)Y(&9O<B!U;G!A8VMI;F<@*&1E
M9F%U;'1S('1O(&-U<G)E;G0@<&%T:"!O<B`B97AT(B!I9B!E>&ES=',I)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G9F]R
M8V4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G
M(#T^("=F)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T9O<F-E
M('1H92!U;G!A8VMI;F<@979E;B!I9B!T:&5R92!W97)E(&5R<F]R<R!I;B!T
M:&4@<&%C:V%G92<L#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^#0I5;G!A8VMS
M(&$@4&5C;"!086-K86=E(&EN=&\@=&AE('-E;&5C=&5D(&QO8V%T:6]N+B!)
M="!W:6QL(&1O=VYL;V%D('1H90T*<&%C:V%G92!I9B!N965D960N#0HG*2P-
M"B`@("`@("`@)W)U;BUS8W)I<'1S)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("=S=6UM87)Y)R`]/B`G4G5N(%!O<W0M26YS=&%L;"!38W)I<'1S(&)U;F1L
M960@=VET:"!A('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]
M/B`G9&]2=6Y38W)I<'1S)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@
M)W)S)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA9V4^#0I2
M=6X@<&]S="UI;G-T86QL871I;VX@<V-R:7!T<R!I;B!P86-K86=E(#QP86-K
M86=E/BP@:68@86YY(&5X:7-T+@T*)RDL#0H@("`@*3L-"@T*("`@("\O('U]
M?0T*("`@("\O('M[>R!C;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@
M4$5!4E]#;VUM86YD7TEN<W1A;&P@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@
M("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%
M05)?0V]M;6%N9%]);G-T86QL*"8D=6DL("8D8V]N9FEG*0T*("`@('L-"B`@
M("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I
M9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@("`@*B!&
M;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@("HO#0H@("`@9G5N8W1I
M;VX@)F=E=$1O=VYL;V%D97(H)B1U:2P@)&]P=&EO;G,L("8D8V]N9FEG*0T*
M("`@('L-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?1&]W;FQO
M861E<B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&]W
M;FQO861E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@)FYE=R!0
M14%27T1O=VYL;V%D97(H)'5I+"`D;W!T:6]N<RP@)&-O;F9I9RD[#0H@("`@
M("`@(')E='5R;B`D83L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!&;W(@
M=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M)F=E=$EN<W1A;&QE<B@F)'5I*0T*("`@('L-"B`@("`@("`@:68@*"%C;&%S
M<U]E>&ES=',H)U!%05)?26YS=&%L;&5R)RDI('L-"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(N<&AP)SL-"B`@("`@("`@?0T*
M("`@("`@("`D82`]("9N97<@4$5!4E]);G-T86QL97(H)'5I*3L-"B`@("`@
M("`@<F5T=7)N("1A.PT*("`@('T-"@T*("`@("\O('M[>R!D;TEN<W1A;&PH
M*0T*#0H@("`@9G5N8W1I;VX@9&]);G-T86QL*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^
M:6YS=&%L;&5R*2D@>PT*("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<B`]
M("8D=&AI<RT^9V5T26YS=&%L;&5R*"1T:&ES+3YU:2D[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"1C;VUM86YD(#T]("=U<&=R861E)RD@>PT*("`@("`@
M("`@("`@)&]P=&EO;G-;)W5P9W)A9&4G72`]('1R=64[#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=I;G-T86QL<F]O="==*2`F
M)B!I<W-E="@D;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=%4E)/4CH@8V%N;F]T
M('5S92!B;W1H("TM:6YS=&%L;')O;W0@86YD("TM<&%C:V%G:6YG<F]O="<I
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&%C
M:V%G:6YG<F]O="==*2`F)B`D=&AI<RT^8V]N9FEG+3YG970H)W9E<F)O<V4G
M*2`^(#(I('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G
M=7-I;F<@<&%C:V%G92!R;V]T.B`G("X@)&]P=&EO;G-;)W!A8VMA9VEN9W)O
M;W0G72D[#0H@("`@("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N
M9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("!I9B`H)&-O;6UA;F0@/3T@
M)W5P9W)A9&4M86QL)RD@>PT*("`@("`@("`@("`@)&]P=&EO;G-;)W5P9W)A
M9&4G72`]('1R=64[#0H@("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF
M:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`D<V%V96-H86YN96P@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@("`@("!F;W)E
M86-H("@D<F5G+3YL:7-T0VAA;FYE;',H*2!A<R`D8VAA;FYE;"D@>PT*("`@
M("`@("`@("`@("`@(&EF("@D8VAA;FYE;"`]/2`G7U]U<FDG*2![#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?
M8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("`D8VAA;B`]
M("8D<F5G+3YG971#:&%N;F5L*"1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1C:&%N*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1C:&%N+3YS=7!P
M;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R
M)RDI("8F#0H@("`@("`@("`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^
M9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E
M9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&]R
M97-T(#T@=')U93L-"B`@("`@("`@("`@("`@("`@("`@=6YS970H)')E;6]T
M92D[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)&1O<F5S="`](&9A;'-E.PT*("`@("`@("`@("`@("`@("`@("`D
M<F5M;W1E(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@D=&AI<RT^8V]N
M9FEG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'-T
M871E(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*3L-
M"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5D(#T@87)R87E?9FQI<"@D<F5G
M+3YL:7-T4&%C:V%G97,H)&-H86YN96PI*3L-"B`@("`@("`@("`@("`@("!0
M14%2.CIS=&%T:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD[#0H@("`@("`@("`@("`@("`@:68@*"1D;W)E<W0I('L-"B`@("`@("`@
M("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G
M,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@("`@("`@("`@("1L871E<W0@
M/2`D<F5S="T^;&ES=$QA=&5S=%5P9W)A9&5S*"1B87-E+"`D<W1A=&4L("1I
M;G-T86QL960L("1C:&%N;F5L+"`D<F5G*3L-"B`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)'-T871E
M*2!\?"`D<W1A=&4@/3T@)V%N>2<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1L871E<W0@/2`D<F5M;W1E+3YC86QL*")P86-K86=E+FQI<W1,871E
M<W1296QE87-E<R(I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&QA=&5S="`]("1R96UO=&4M/F-A
M;&PH(G!A8VMA9V4N;&ES=$QA=&5S=%)E;&5A<V5S(BP@)'-T871E*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&QA=&5S="D@?'P@
M(6ES7V%R<F%Y*"1L871E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D;&%T97-T(&%S("1P86-K86=E(#T^("1I;F9O*2![#0H@("`@
M("`@("`@("`@("`@("`@("1P86-K86=E(#T@<W1R=&]L;W=E<B@D<&%C:V%G
M92D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN<W1A;&QE
M9%LD<&%C:V%G95TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!S
M:VEP('!A8VMA9V5S('=E(&1O;B=T(&AA=F4@:6YS=&%L;&5D#0H@("`@("`@
M("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`D:6YS=%]V97)S:6]N(#T@)')E
M9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H86YN96PI
M.PT*("`@("`@("`@("`@("`@("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"(D
M:6YF;UMV97)S:6]N72(L("(D:6YS=%]V97)S:6]N(BP@(FQE(BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&EN<W1A;&QE9"!V97)S:6]N(&ES
M('5P+71O+61A=&4-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("1P87)A;7-;72`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M87)R87DH)W!A8VMA9V4G(#T^("1P86-K86=E+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@)V-H86YN96PG(#T^("1C:&%N;F5L*2D[#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AA<G)A>2@G9&%T82<@
M/3X@(E=I;&P@=7!G<F%D92`D<&%C:V%G92(I+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D<V%V96-H86YN
M96PI.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YD;W=N;&]A9&5R(#T@
M)B1T:&ES+3YG971$;W=N;&]A9&5R*"1T:&ES+3YU:2P@)&]P=&EO;G,L("1T
M:&ES+3YC;VYF:6<I.PT*("`@("`@("`D97)R;W)S(#T@87)R87DH*3L-"B`@
M("`@("`@)&1O=VYL;V%D960@/2!A<G)A>2@I.PT*("`@("`@("`D9&]W;FQO
M861E9"`]("8D=&AI<RT^9&]W;FQO861E<BT^9&]W;FQO860H)'!A<F%M<RD[
M#0H@("`@("`@("1E<G)O<G,@/2`D=&AI<RT^9&]W;FQO861E<BT^9V5T17)R
M;W)-<V=S*"D[#0H@("`@("`@(&EF("AC;W5N="@D97)R;W)S*2D@>PT*("`@
M("`@("`@("`@9F]R96%C:"`H)&5R<F]R<R!A<R`D97)R;W(I('L-"B`@("`@
M("`@("`@("`@("`D97)R6R=D871A)UU;72`](&%R<F%Y*"1E<G)O<BD[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`D97)R6R=H96%D;&EN92==(#T@
M)TEN<W1A;&P@17)R;W)S)SL-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D97)R*3L-"B`@("`@("`@("`@(&EF("@A8V]U;G0H)&1O=VYL
M;V%D960I*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"(D8V]M;6%N9"!F86EL960B*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@
M)VAE861L:6YE)R`]/B`G4&%C:V%G97,@=&AA="!W;W5L9"!B92!);G-T86QL
M960G#0H@("`@("`@("D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M<')E=&5N9"==*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&1O=VYL;V%D
M960@87,@)'!A8VMA9V4I('L-"B`@("`@("`@("`@("`@("`D9&%T85LG9&%T
M82==6UT@/2!A<G)A>2@D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG
M*"1P86-K86=E+3YG971087)S961086-K86=E*"DI*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@
M)W!R971E;F0G*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!]#0H@("`@("`@("1T:&ES+3YI;G-T86QL97(M/G-E=$]P=&EO;G,H)&]P
M=&EO;G,I.PT*("`@("`@("`D=&AI<RT^:6YS=&%L;&5R+3YS;W)T4&%C:V%G
M97-&;W));G-T86QL*"1D;W=N;&]A9&5D*3L-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&5R<B`]("1T:&ES+3YI;G-T86QL97(M/G-E=$1O=VYL;V%D
M961086-K86=E<R@D9&]W;FQO861E9"DI*2![#0H@("`@("`@("`@("`D=&AI
M<RT^<F%I<V5%<G)O<B@D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@)&5X=')A:6YF
M;R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1D;W=N;&]A9&5D(&%S
M("1P87)A;2D@>PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R
M2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@)&EN
M9F\@/2`D=&AI<RT^:6YS=&%L;&5R+3YI;G-T86QL*"1P87)A;2P@)&]P=&EO
M;G,I.PT*("`@("`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![
M#0H@("`@("`@("`@("`@("`@)&]L9&EN9F\@/2`D:6YF;SL-"B`@("`@("`@
M("`@("`@("`D<&MG(#T@)B1P87)A;2T^9V5T4&%C:V%G949I;&4H*3L-"B`@
M("`@("`@("`@("`@("!I9B`H)&EN9F\M/F=E=$-O9&4H*2`A/2!014%27TE.
M4U1!3$Q%4E].3T))3D%262D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M(2@D:6YF;R`]("1P:V<M/FEN<W1A;&Q":6YA<GDH)'1H:7,M/FEN<W1A;&QE
M<BDI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)T524D]2.B`G("XD;VQD:6YF;RT^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("\O('=E(&IU<W0@
M:6YS=&%L;&5D(&$@9&EF9F5R96YT('!A8VMA9V4@=&AA;B!R97%U97-T960L
M#0H@("`@("`@("`@("`@("`@("`@("\O(&QE="=S(&-H86YG92!T:&4@<&%R
M86T@86YD(&EN9F\@<V\@=&AA="!T:&4@<F5S="!O9B!T:&ES('=O<FMS#0H@
M("`@("`@("`@("`@("`@("`@("1P87)A;2`]("1I;F9O6S!=.PT*("`@("`@
M("`@("`@("`@("`@("`D:6YF;R`]("1I;F9O6S%=.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D:6YF;RDI('L-"B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M+3YG9710
M86-K86=E5'EP92@I(#T]("=E>'1S<F,G('Q\#0H@("`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M+3YG971086-K86=E5'EP92@I(#T]("=E>'1B:6XG*2![
M#0H@("`@("`@("`@("`@("`@("`@("1P:V<@/2`F)'!A<F%M+3YG971086-K
M86=E1FEL92@I.PT*("`@("`@("`@("`@("`@("`@("!I9B`H)&EN<W1B:6X@
M/2`D<&MG+3YG971);G-T86QL961":6YA<GDH*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&EN<W1P:V<@/2`F)')E9RT^9V5T4&%C:V%G92@D:6YS
M=&)I;BP@)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;G-T<&MG
M(#T@)B1R96<M/F=E=%!A8VMA9V4H)'!K9RT^9V5T4&%C:V%G92@I+"`D<&MG
M+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1I;G-T<&MG+3YG971&:6QE;&ES
M="@I(&%S("1N86UE(#T^("1A='1S*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<&EN9F\@/2!P871H:6YF;R@D871T<ULG:6YS=&%L;&5D7V%S)UTI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&EN9F];
M)V5X=&5N<VEO;B==*2!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:6Y?87)R87DH)'!I;F9O6R=E>'1E;G-I;VXG72P@87)R87DH)V,G+"`G
M:"<I*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.R`O+R!M86ME('-U<F4@=V4@9&]N)W0@;6%T8V@@<&AP7V)L86@N:`T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"AS=')P;W,H)'!I;F9O6R=B87-E;F%M92==+"`G<&AP7R<I(#T]
M/2`P("8F#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&EN9F];
M)V5X=&5N<VEO;B==(#T]("=D;&PG*2!\?`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@;6]S="!U;FEC97,-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P:6YF;ULG97AT96YS:6]N)UT@/3T@)W-O)R!\?`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@:'`M=7@-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P:6YF;ULG97AT96YS:6]N)UT@
M/3T@)W-L)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'1R
M86EN9F];72`]("=9;W4@<VAO=6QD(&%D9"`B97AT96YS:6]N/2<@+B`D<&EN
M9F];)V)A<V5N86UE)UT-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G(B!T;R!P:'`N:6YI)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`P
M*2![#0H@("`@("`@("`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A<F%M+3YG
M971#:&%N;F5L*"D[#0H@("`@("`@("`@("`@("`@("`@("1L86)E;"`]("1R
M96<M/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@
M("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G8VAA;FYE;"<@/3X@)&-H86YN96PL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W!A8VMA9V4G(#T^("1P87)A;2T^9V5T4&%C:V%G92@I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]/B`D<&%R
M86TM/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("`@("`@("`@("`@("DI
M.PT*("`@("`@("`@("`@("`@("`@("`D;W5T(#T@87)R87DH)V1A=&$G(#T^
M("(D8V]M;6%N9"!O:SH@)&QA8F5L(BD[#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D:6YF;ULG<F5L96%S95]W87)N:6YG<R==*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U=%LG<F5L96%S95]W87)N:6YG<R==
M(#T@)&EN9F];)W)E;&5A<V5?=V%R;FEN9W,G73L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)&]U="P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1O<'1I;VYS6R=R96=I<W1E<BUO;FQY)UTI("8F("%I<W-E
M="@D;W!T:6]N<ULG;V9F;&EN92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YC;VYF:6<M/FES1&5F:6YE9$QA>65R*"=F='`G
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!%05(Z.G-T871I
M8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D:6YF;R`]("1T:&ES+3YI;G-T86QL
M97(M/F9T<$EN<W1A;&PH)'!A<F%M*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN
M9F\I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@D:6YF;RT^9V5T365S<V%G92@I*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*")R96UO=&4@:6YS=&%L;"!F86EL960Z("1L86)E;"(I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B<F5M
M;W1E(&EN<W1A;&P@;VLZ("1L86)E;"(I.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`D9&5P<R`]("1P87)A;2T^9V5T1&5P<R@I.PT*("`@("`@("`@
M("`@("`@(&EF("@D9&5P<RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&1E<'-;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D9W)O=7!S(#T@)&1E<'-;)V=R;W5P)UT[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1G<F]U<'-;,%TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&=R;W5P<R`](&%R<F%Y*"1G<F]U<',I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&=R;W5P<R!A<R`D9W)O=7`I('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P6R=A='1R:6)S)UU;
M)VYA;64G72`]/2`G9&5F875L="<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@9&5F875L="!G<F]U<"!I<R!A;'=A>7,@:6YS=&%L
M;&5D+"!U;FQE<W,@=&AE('5S97(-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@97AP;&EC:71L>2!C:&]O<V5S('1O(&EN<W1A;&P@86YO
M=&AE<B!G<F]U<`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C
M;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A
M*"1P87)A;2T^9V5T4&%C:V%G92@I("X@)SH@3W!T:6]N86P@9F5A='5R92`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A
M='1R:6)S)UU;)VYA;64G72`N("<@879A:6QA8FQE("@G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P6R=A='1R:6)S)UU;)VAI
M;G0G72`N("<I)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D97AT<F%I;F9O6UT@/2`G5&\@:6YS=&%L
M;"!U<V4@(G!E87(@:6YS=&%L;"`G("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C:V%G92<@
M/3X@)'!A<F%M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&%R86TM/F=E=$-H
M86YN96PH*2DL('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(V9E871U<F5N86UE(B<[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1O<'1I;VYS6R=I;G-T86QL<F]O="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P:V<@/2`F
M)')E9RT^9V5T4&%C:V%G92@D<&%R86TM/F=E=%!A8VMA9V4H*2P@)'!A<F%M
M+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@("\O("1P:V<@;6%Y
M(&)E($Y53$P@:68@:6YS=&%L;"!I<R!A("=F86ME)R!I;G-T86QL('9I82`M
M+7!A8VMA9VEN9W)O;W0-"B`@("`@("`@("`@("`@("!I9B`H:7-?;V)J96-T
M*"1P:V<I*2![#0H@("`@("`@("`@("`@("`@("`@("1P:V<M/G-E=$-O;F9I
M9R@D=&AI<RT^8V]N9FEG*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1L
M:7-T(#T@)'!K9RT^;&ES=%!O<W1I;G-T86QL4V-R:7!T<R@I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&X@/2`D<F5G+3YP87)S961086-K86=E
M3F%M951O4W1R:6YG*&%R<F%Y*"=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!A<F%M+3YG971#:&%N;F5L*"DL("=P86-K86=E
M)R`]/B`D<&%R86TM/F=E=%!A8VMA9V4H*2DL('1R=64I.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&5X=')A:6YF;UM=(#T@)'!N("X@)R!H87,@<&]S
M="UI;G-T86QL('-C<FEP=',Z)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:7-T(&%S("1F:6QE*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5X=')A:6YF;UM=(#T@)&9I;&4[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D97AT
M<F%I;F9O6UT@/2`G57-E(")P96%R(')U;BUS8W)I<'1S("<@+B`D<&X@+B`G
M(B!T;R!R=6XG.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&5X=')A:6YF
M;UM=(#T@)T1/($Y/5"!254X@4T-225!44R!&4D]-(%5.5%)54U1%1"!33U52
M0T53)SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9"!F86EL960B*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H8V]U;G0H)&5X
M=')A:6YF;RDI('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1E>'1R86EN9F\@
M87,@)&EN9F\I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)&EN9F\I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D;U5N:6YS=&%L;"@I#0H-"B`@("!F=6YC=&EO;B!D;U5N:6YS=&%L
M;"@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@
M("!I9B`H96UP='DH)'1H:7,M/FEN<W1A;&QE<BDI('L-"B`@("`@("`@("`@
M("1T:&ES+3YI;G-T86QL97(@/2`F)'1H:7,M/F=E=$EN<W1A;&QE<B@D=&AI
M<RT^=6DI.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N
M<ULG<F5M;W1E8V]N9FEG)UTI*2![#0H@("`@("`@("`@("`D92`]("1T:&ES
M+3YC;VYF:6<M/G)E861&5%!#;VYF:6=&:6QE*"1O<'1I;VYS6R=R96UO=&5C
M;VYF:6<G72D[#0H@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)&4I
M*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<V5T0V]N
M9FEG*"1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(E!L96%S92!S=7!P;'D@
M=&AE('!A8VMA9V4H<RD@>6]U('=A;G0@=&\@=6YI;G-T86QL(BD[#0H@("`@
M("`@('T-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I
M<W1R>2@I.PT*("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-"B`@("`@
M("`@)&)A9'!A<F%M<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P
M87)A;7,@87,@)'!K9RD@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`D=&AI
M<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`@
M("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@)'!A<G-E9"`]("1R96<M/G!A<G-E4&%C
M:V%G94YA;64H)'!K9RP@)&-H86YN96PI.PT*("`@("`@("`@("`@4$5!4CHZ
M<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@:68@*"$D
M<&%R<V5D('Q\(%!%05(Z.FES17)R;W(H)'!A<G-E9"DI('L-"B`@("`@("`@
M("`@("`@("`D8F%D<&%R86US6UT@/2`D<&MG.PT*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'!A8VMA
M9V4@/2`D<&%R<V5D6R=P86-K86=E)UT[#0H@("`@("`@("`@("`D8VAA;FYE
M;"`]("1P87)S961;)V-H86YN96PG73L-"B`@("`@("`@("`@("1I;F9O(#T@
M)B1R96<M/F=E=%!A8VMA9V4H)'!A8VMA9V4L("1C:&%N;F5L*3L-"B`@("`@
M("`@("`@(&EF("@D:6YF;R`]/3T@;G5L;"`F)@T*("`@("`@("`@("`@("`@
M("`H)&-H86YN96P@/3T@)W!E87(N<&AP+FYE="<@?'P@)&-H86YN96P@/3T@
M)W!E8VPN<&AP+FYE="<I*2![#0H@("`@("`@("`@("`@("`@+R\@;6%K92!S
M=7)E('1H:7,@:7-N)W0@82!P86-K86=E('1H870@:&%S(&9L:7!P960@9G)O
M;2!P96%R('1O('!E8VP@8G5T#0H@("`@("`@("`@("`@("`@+R\@=7-E9"!A
M('!A8VMA9V4N>&UL(#$N,`T*("`@("`@("`@("`@("`@("1T97-T8R`]("@D
M8VAA;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@/R`G<&5C;"YP:'`N;F5T)R`Z
M("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@("`@("1I;F9O(#T@)B1R
M96<M/F=E=%!A8VMA9V4H)'!A8VMA9V4L("1T97-T8RD[#0H@("`@("`@("`@
M("`@("`@:68@*"1I;F9O("$]/2!N=6QL*2![#0H@("`@("`@("`@("`@("`@
M("`@("1C:&%N;F5L(#T@)'1E<W1C.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D:6YF;R`]/3T@;G5L;"D@
M>PT*("`@("`@("`@("`@("`@("1B861P87)A;7-;72`]("1P:V<[#0H@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1N97=P87)A;7-;
M72`]("8D:6YF;SL-"B`@("`@("`@("`@("`@("`O+R!C:&5C:R!F;W(@8FEN
M87)Y('!A8VMA9V5S("AT:&ES(&ES(&%N(&%L:6%S(&9O<B!T:&]S92!P86-K
M86=E<R!I9B!S;RD-"B`@("`@("`@("`@("`@("!I9B`H)&EN<W1A;&QE9&)I
M;F%R>2`]("1I;F9O+3YG971);G-T86QL961":6YA<GDH*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=6DM/FQO9R@G861D:6YG(&)I;F%R>2!P
M86-K86=E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)')E9RT^<&%R
M<V5D4&%C:V%G94YA;654;U-T<FEN9RAA<G)A>2@G8VAA;FYE;"<@/3X@)&-H
M86YN96PL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M(#T^("1I;G-T86QL961B:6YA<GDI+"!T<G5E*2D[#0H@("`@("`@("`@("`@
M("`@("`@("1N97=P87)A;7-;72`]("8D<F5G+3YG971086-K86=E*"1I;G-T
M86QL961B:6YA<GDL("1C:&%N;F5L*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@+R\@861D('1H92!C;VYT96YT<R!O9B!A(&1E<&5N
M9&5N8WD@9W)O=7`@=&\@=&AE(&QI<W0@;V8@:6YS=&%L;&5D('!A8VMA9V5S
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P87)S961;)V=R;W5P)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("1I;F9O+3YG971$
M97!E;F1E;F-Y1W)O=7`H)'!A<G-E9%LG9W)O=7`G72D[#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D9W)O=7`I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1I;G-T86QL960@/2`F)')E9RT^9V5T26YS=&%L;&5D1W)O=7`H)&=R
M;W5P*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D:6YS=&%L;&5D
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN
M<W1A;&QE9"!A<R`D:2`]/B`D<"D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;F5W<&%R86US6UT@/2`F)&EN<W1A;&QE9%LD:5T[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1E
M<G(@/2`D=&AI<RT^:6YS=&%L;&5R+3YS;W)T4&%C:V%G97-&;W)5;FEN<W1A
M;&PH)&YE=W!A<F%M<RD[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E
M<G(I*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&5R
M<BT^9V5T365S<V%G92@I+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("!R971U
M<FX@=')U93L-"B`@("`@("`@?0T*("`@("`@("`D<&%R86US(#T@)&YE=W!A
M<F%M<SL-"B`@("`@("`@+R\@='=I<W0@=&AI<R!T;R!U<V4@:70@=&\@8VAE
M8VL@;VX@=VAE=&AE<B!D97!E;F1E;G0@<&%C:V%G97,@87)E(&%L<V\@8F5I
M;F<@=6YI;G-T86QL960-"B`@("`@("`@+R\@9F]R(&-I<F-U;&%R(&1E<&5N
M9&5N8VEE<R!L:6ME('-U8G!A8VMA9V5S#0H@("`@("`@("1T:&ES+3YI;G-T
M86QL97(M/G-E=%5N:6YS=&%L;%!A8VMA9V5S*"1N97=P87)A;7,I.PT*("`@
M("`@("`D<&%R86US(#T@87)R87E?;65R9V4H)'!A<F%M<RP@)&)A9'!A<F%M
M<RD[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!K9RD@>PT*("`@
M("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<'5S:$5R<F]R2&%N9&QI;F<H
M4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`@("`@:68@*"1E<G(@/2`D
M=&AI<RT^:6YS=&%L;&5R+3YU;FEN<W1A;&PH)'!K9RP@)&]P=&EO;G,I*2![
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<&]P17)R;W)(
M86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D97)R+3YG971-97-S86=E*"DL("1C;VUM86YD*3L-"B`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("1S879E<&MG(#T@)'!K9SL-"B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`P*2![
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1P:V<@/2`D<F5G+3YP87)S9610
M86-K86=E3F%M951O4W1R:6YG*"1P:V<I.PT*("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@B=6YI;G-T86QL(&]K.B`D<&MG(BP@)&-O;6UA;F0I.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=O9F9L:6YE)UTI("8F(&ES7V]B:F5C="@D<V%V97!K9RD@)B8-"B`@("`@
M("`@("`@("`@("`@("`@("!D969I;F5D*"=014%27U)%34]414E.4U1!3$Q?
M3TLG*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F-O;F9I
M9RT^:7-$969I;F5D3&%Y97(H)V9T<"<I*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^:6YS=&%L;&5R+3YP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF;R`]("1T:&ES+3YI;G-T86QL97(M/F9T<%5N:6YS=&%L;"@D<V%V97!K
M9RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:6YS=&%L;&5R
M+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&EN9F\M/F=E
M=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*")R96UO=&4@=6YI;G-T86QL(&9A:6QE9#H@
M)'!K9R(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A
M=&$H(G)E;6]T92!U;FEN<W1A;&P@;VLZ("1P:V<B*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/FEN<W1A;&QE<BT^<&]P17)R;W)(86YD;&EN9R@I.PT*
M("`@("`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'!K9RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'!K9R`]("1R96<M/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)'!K9RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B=6YI;G-T86QL(&9A
M:6QE9#H@)'!K9R(I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@9&]"=6YD;&4H*0T*("`@("\J#0H@("`@
M*&-O>"D@270@:G5S="!D;W=N;&]A9',@86YD('5N=&%R<R!T:&4@<&%C:V%G
M92P@9&]E<R!N;W0@9&\-"B`@("`@("`@("`@(&%N>2!C:&5C:R!T:&%T('1H
M92!014%27TEN<W1A;&QE<CHZ7VEN<W1A;&Q&:6QE*"D@9&]E<RX-"B`@("`J
M+PT*#0H@("`@9G5N8W1I;VX@9&]"=6YD;&4H)&-O;6UA;F0L("1O<'1I;VYS
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)&1O=VYL;V%D97(@/2`F)'1H
M:7,M/F=E=$1O=VYL;V%D97(H)'1H:7,M/G5I+"!A<G)A>2@G9F]R8V4G(#T^
M('1R=64L("=N;V1E<',G(#T^('1R=64L#0H@("`@("`@("`@("`G<V]F="<@
M/3X@=')U92DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AS:7IE
M;V8H)'!A<F%M<RD@/"`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H(E!L96%S92!S=7!P;'D@=&AE('!A8VMA9V4@>6]U('=A
M;G0@=&\@8G5N9&QE(BD[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)V1E<W1I;F%T:6]N)UTI*2![#0H@("`@("`@("`@("!I
M9B`H(6ES7V1I<B@D;W!T:6]N<ULG9&5S=&EN871I;VXG72DI('L-"B`@("`@
M("`@("`@("`@("!3>7-T96TZ.FUK9&ER*"<M<"`G("X@)&]P=&EO;G-;)V1E
M<W1I;F%T:6]N)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E
M<W0@/2!R96%L<&%T:"@D;W!T:6]N<ULG9&5S=&EN871I;VXG72D[#0H@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`D<'=D(#T@9V5T8W=D*"D[#0H@
M("`@("`@("`@("!I9B`H:7-?9&ER*"1P=V0@+B!$25)%0U1/4EE?4T5005)!
M5$]2("X@)V5X="<I*2![#0H@("`@("`@("`@("`@("`@)&1E<W0@/2`D<'=D
M("X@1$E214-43U)97U-%4$%2051/4B`N("=E>'0G.PT*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9&5S="`]("1P=V0[#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&1O=VYL;V%D97(M/G-E
M=$1O=VYL;V%D1&ER*"1D97-T*3L-"B`@("`@("`@)')E<W5L="`]("8D9&]W
M;FQO861E<BT^9&]W;FQO860H87)R87DH)'!A<F%M<ULP72DI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PT*("`@("`@("`@("`@
M<F5T=7)N("1R97-U;'0[#0H@("`@("`@('T-"B`@("`@("`@)'!K9V9I;&4@
M/2`F)')E<W5L=%LP72T^9V5T4&%C:V%G949I;&4H*3L-"B`@("`@("`@)'!K
M9VYA;64@/2`D<&MG9FEL92T^9V5T3F%M92@I.PT*("`@("`@("`D<&MG=F5R
M<VEO;B`]("1P:V=F:6QE+3YG971697)S:6]N*"D[#0H-"B`@("`@("`@+R\@
M56YP86-K:6YG("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T-"B`@("`@("`@)&1E<W0@+CT@1$E214-43U)97U-%
M4$%2051/4B`N("1P:V=N86UE.PT*("`@("`@("`D;W)I9R`]("1P:V=N86UE
M("X@)RTG("X@)'!K9W9E<G-I;VX[#0H-"B`@("`@("`@)'1A<B`]("9N97<@
M07)C:&EV95]487(H)'!K9V9I;&4M/F=E=$%R8VAI=F5&:6QE*"DI.PT*("`@
M("`@("!I9B`H(4`D=&%R+3YE>'1R86-T36]D:69Y*"1D97-T+"`D;W)I9RDI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G=6YA
M8FQE('1O('5N<&%C:R`G("X@)'!K9V9I;&4M/F=E=$%R8VAI=F5&:6QE*"DI
M.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B
M4&%C:V%G92!R96%D>2!A="`G)&1E<W0G(BD[#0H@("`@+R\@?7U]#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO;B!D;U)U;E-C<FEP=',H
M)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@
M:68@*"%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=R=6XM<V-R:7!T<R!E>'!E8W1S(#$@<&%R
M86UE=&5R.B!A('!A8VMA9V4@;F%M92<I.PT*("`@("`@("!]#0H@("`@("`@
M("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@
M("`@4$5!4CHZ<W1A=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`D<&%R<V5D(#T@)')E9RT^<&%R<V5086-K86=E
M3F%M92@D<&%R86US6S!=+"`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?
M8VAA;FYE;"<I*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%R<V5D*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P87)S
M960I.PT*("`@("`@("!]#0H@("`@("`@("1P86-K86=E(#T@)B1R96<M/F=E
M=%!A8VMA9V4H)'!A<G-E9%LG<&%C:V%G92==+"`D<&%R<V5D6R=C:&%N;F5L
M)UTI.PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P86-K86=E*2D@>PT*("`@
M("`@("`@("`@)'!A8VMA9V4M/G-E=$-O;F9I9R@D=&AI<RT^8V]N9FEG*3L-
M"B`@("`@("`@("`@("1P86-K86=E+3YR=6Y0;W-T:6YS=&%L;%-C<FEP=',H
M*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@G0V]U;&0@;F]T(')E=')I979E('!A8VMA9V4@(B<@
M+B`D<&%R86US6S!=("X@)R(@9G)O;2!R96=I<W1R>2<I.PT*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G26YS=&%L;"!S8W)I
M<'1S(&-O;7!L971E)RP@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@=')U
M93L-"B`@("!]#0I]#0H_/@T*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]014%2+T-O;6UA;F0O4&%C:V%G92YX;6P`````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$S-3`S(#$P-3$U-#,T,3,T(#`R,C8T-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\8V]M
M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\<&%C:V%G93X-"B`@/'-U;6UA<GD^
M0G5I;&0@4&%C:V%G93PO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O4&%C:V%G
M93PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YP/"]S:&]R=&-U=#X-"B`@/&]P
M=&EO;G,^#0H@("`\;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO
M<G1O<'0^#0H@("`@/&1O8SY$;R!N;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE
M/"]D;V,^#0H@("`\+VYO8V]M<')E<W,^#0H@("`\<VAO=VYA;64^#0H@("`@
M/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*("`@(#QD;V,^4')I;G0@=&AE(&YA
M;64@;V8@=&AE('!A8VMA9V5D(&9I;&4N/"]D;V,^#0H@("`\+W-H;W=N86UE
M/@T*("`\+V]P=&EO;G,^#0H@(#QD;V,^6V1E<V-F:6QE72!;9&5S8V9I;&4R
M70T*0W)E871E<R!A(%!%05(@<&%C:V%G92!F<F]M(&ET<R!D97-C<FEP=&EO
M;B!F:6QE("AU<W5A;&QY(&-A;&QE9`T*<&%C:V%G92YX;6PI+B`@268@82!S
M96-O;F0@<&%C:V%G969I;&4@:7,@<&%S<V5D(&EN+"!T:&5N#0IT:&4@<&%C
M:V%G97(@=VEL;"!C:&5C:R!T;R!M86ME('-U<F4@=&AA="!O;F4@:7,@82!P
M86-K86=E+GAM;`T*=F5R<VEO;B`Q+C`L(&%N9"!T:&4@;W1H97(@:7,@82!P
M86-K86=E+GAM;"!V97)S:6]N(#(N,"X@(%1H90T*<&%C:V%G92YX;6P@=F5R
M<VEO;B`Q+C`@=VEL;"!B92!S879E9"!A<R`F<75O=#MP86-K86=E+GAM;"9Q
M=6]T.R!I;B!T:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H97(@87,@)G%U;W0[
M<&%C:V%G93(N>&UL)G%U;W0[(&EN('1H92!A<F-H:79E)G%U;W0[#0H\+V1O
M8SX-"B`\+W!A8VMA9V4^#0H@/'!A8VMA9V4M=F%L:61A=&4^#0H@(#QS=6UM
M87)Y/E9A;&ED871E(%!A8VMA9V4@0V]N<VES=&5N8WD\+W-U;6UA<GD^#0H@
M(#QF=6YC=&EO;CYD;U!A8VMA9V5686QI9&%T93PO9G5N8W1I;VX^#0H@(#QS
M:&]R=&-U=#YP=CPO<VAO<G1C=70^#0H@(#QO<'1I;VYS("\^#0H@(#QD;V,^
M#0H\+V1O8SX-"B`\+W!A8VMA9V4M=F%L:61A=&4^#0H@/&-V<V1I9F8^#0H@
M(#QS=6UM87)Y/E)U;B!A("9Q=6]T.V-V<R!D:69F)G%U;W0[(&9O<B!A;&P@
M9FEL97,@:6X@82!P86-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]#
M=G-$:69F/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/F-D/"]S:&]R=&-U=#X-
M"B`@/&]P=&EO;G,^#0H@("`\<75I970^#0H@("`@/'-H;W)T;W!T/G$\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^0F4@<75I970\+V1O8SX-"B`@(#PO<75I970^
M#0H@("`\<F5A;&QY<75I970^#0H@("`@/'-H;W)T;W!T/E$\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^0F4@<F5A;&QY('%U:65T/"]D;V,^#0H@("`\+W)E86QL
M>7%U:65T/@T*("`@/&1A=&4^#0H@("`@/'-H;W)T;W!T/D0\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^1&EF9B!A9V%I;G-T(')E=FES:6]N(&]F($1!5$4\+V1O
M8SX-"B`@("`\87)G/D1!5$4\+V%R9SX-"B`@(#PO9&%T93X-"B`@(#QR96QE
M87-E/@T*("`@(#QS:&]R=&]P=#Y2/"]S:&]R=&]P=#X-"B`@("`\9&]C/D1I
M9F8@86=A:6YS="!T86<@9F]R('!A8VMA9V4@<F5L96%S92!214P\+V1O8SX-
M"B`@("`\87)G/E)%3#PO87)G/@T*("`@/"]R96QE87-E/@T*("`@/')E=FES
M:6]N/@T*("`@(#QS:&]R=&]P=#YR/"]S:&]R=&]P=#X-"B`@("`\9&]C/D1I
M9F8@86=A:6YS="!R979I<VEO;B!2158\+V1O8SX-"B`@("`\87)G/E)%5CPO
M87)G/@T*("`@/"]R979I<VEO;CX-"B`@(#QC;VYT97AT/@T*("`@(#QS:&]R
M=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/D=E;F5R871E(&-O;G1E>'0@
M9&EF9CPO9&]C/@T*("`@/"]C;VYT97AT/@T*("`@/'5N:69I960^#0H@("`@
M/'-H;W)T;W!T/G4\+W-H;W)T;W!T/@T*("`@(#QD;V,^1V5N97)A=&4@=6YI
M9FEE9"!D:69F/"]D;V,^#0H@("`\+W5N:69I960^#0H@("`\:6=N;W)E+6-A
M<V4^#0H@("`@/'-H;W)T;W!T/FD\+W-H;W)T;W!T/@T*("`@(#QD;V,^26=N
M;W)E(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@;&]W97(M8V%S92!L971T
M97)S(&5Q=6EV86QE;G0\+V1O8SX-"B`@(#PO:6=N;W)E+6-A<V4^#0H@("`\
M:6=N;W)E+7=H:71E<W!A8V4^#0H@("`@/'-H;W)T;W!T/F(\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^26=N;W)E(&-H86YG97,@:6X@86UO=6YT(&]F('=H:71E
M('-P86-E/"]D;V,^#0H@("`\+VEG;F]R92UW:&ET97-P86-E/@T*("`@/&EG
M;F]R92UB;&%N:RUL:6YE<SX-"B`@("`\<VAO<G1O<'0^0CPO<VAO<G1O<'0^
M#0H@("`@/&1O8SY)9VYO<F4@8VAA;F=E<R!T:&%T(&EN<V5R="!O<B!D96QE
M=&4@8FQA;FL@;&EN97,\+V1O8SX-"B`@(#PO:6=N;W)E+6)L86YK+6QI;F5S
M/@T*("`@/&)R:65F/@T*("`@(#QD;V,^4F5P;W)T(&]N;'D@=VAE=&AE<B!T
M:&4@9FEL97,@9&EF9F5R+"!N;R!D971A:6QS/"]D;V,^#0H@("`\+V)R:65F
M/@T*("`@/&1R>2UR=6X^#0H@("`@/'-H;W)T;W!T/FX\+W-H;W)T;W!T/@T*
M("`@(#QD;V,^1&]N)F%P;W,[="!D;R!A;GET:&EN9RP@:G5S="!P<F5T96YD
M/"]D;V,^#0H@("`\+V1R>2UR=6X^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF
M;'0[<&%C:V%G92YX;6PF9W0[#0I#;VUP87)E<R!A;&P@=&AE(&9I;&5S(&EN
M(&$@<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO;G,L('1H:7,-"F-O;6UA
M;F0@=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O9&4@=VET:"!T:&4@;&%S
M="!C:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@+7(@;W(@+5(@;W!T:6]N
M('EO=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AA=`T*
M;V8@82!S<&5C:69I8R!R96QE87-E+@T*/"]D;V,^#0H@/"]C=G-D:69F/@T*
M(#QC=G-T86<^#0H@(#QS=6UM87)Y/E-E="!#5E,@4F5L96%S92!486<\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;T-V<U1A9SPO9G5N8W1I;VX^#0H@(#QS
M:&]R=&-U=#YC=#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/'%U:65T
M/@T*("`@(#QS:&]R=&]P=#YQ/"]S:&]R=&]P=#X-"B`@("`\9&]C/D)E('%U
M:65T/"]D;V,^#0H@("`\+W%U:65T/@T*("`@/')E86QL>7%U:65T/@T*("`@
M(#QS:&]R=&]P=#Y1/"]S:&]R=&]P=#X-"B`@("`\9&]C/D)E(')E86QL>2!Q
M=6EE=#PO9&]C/@T*("`@/"]R96%L;'EQ=6EE=#X-"B`@(#QS;&ED93X-"B`@
M("`\<VAO<G1O<'0^1CPO<VAO<G1O<'0^#0H@("`@/&1O8SY-;W9E("AS;&ED
M92D@=&%G(&EF(&ET(&5X:7-T<SPO9&]C/@T*("`@/"]S;&ED93X-"B`@(#QD
M96QE=&4^#0H@("`@/'-H;W)T;W!T/F0\+W-H;W)T;W!T/@T*("`@(#QD;V,^
M4F5M;W9E('1A9SPO9&]C/@T*("`@/"]D96QE=&4^#0H@("`\9')Y+7)U;CX-
M"B`@("`\<VAO<G1O<'0^;CPO<VAO<G1O<'0^#0H@("`@/&1O8SY$;VXF87!O
M<SMT(&1O(&%N>71H:6YG+"!J=7-T('!R971E;F0\+V1O8SX-"B`@(#PO9')Y
M+7)U;CX-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E+GAM;"9G
M=#L-"E-E=',@82!#5E,@=&%G(&]N(&%L;"!F:6QE<R!I;B!A('!A8VMA9V4N
M("!5<V4@=&AI<R!C;VUM86YD(&%F=&5R('EO=2!H879E#0IP86-K86=E9"!A
M(&1I<W1R:6)U=&EO;B!T87)B86QL('=I=&@@=&AE("9Q=6]T.W!A8VMA9V4F
M<75O=#L@8V]M;6%N9"!T;R!T86<@=VAA=`T*<F5V:7-I;VYS(&]F('=H870@
M9FEL97,@=V5R92!I;B!T:&%T(')E;&5A<V4N("!)9B!N965D('1O(&9I>"!S
M;VUE=&AI;F<-"F%F=&5R(')U;FYI;F<@8W9S=&%G(&]N8V4L(&)U="!B969O
M<F4@=&AE('1A<F)A;&P@:7,@<F5L96%S960@=&\@=&AE('!U8FQI8RP-"G5S
M92!T:&4@)G%U;W0[<VQI9&4F<75O=#L@;W!T:6]N('1O(&UO=F4@=&AE(')E
M;&5A<V4@=&%G+@T*/"]D;V,^#0H@/"]C=G-T86<^#0H@/'!A8VMA9V4M9&5P
M96YD96YC:65S/@T*("`\<W5M;6%R>3Y3:&]W('!A8VMA9V4@9&5P96YD96YC
M:65S/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]086-K86=E1&5P96YD96YC
M:65S/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G!D/"]S:&]R=&-U=#X-"B`@
M/&]P=&EO;G,@+SX-"B`@/&1O8SX-"DQI<W0@86QL(&1E<&5N8VEE<R!T:&4@
M<&%C:V%G92!H87,N/"]D;V,^#0H@/"]P86-K86=E+61E<&5N9&5N8VEE<SX-
M"B`\<VEG;CX-"B`@/'-U;6UA<GD^4VEG;B!A('!A8VMA9V4@9&ES=')I8G5T
M:6]N(&9I;&4\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U-I9VX\+V9U;F-T
M:6]N/@T*("`\<VAO<G1C=70^<VD\+W-H;W)T8W5T/@T*("`\;W!T:6]N<R`O
M/@T*("`\9&]C/B9L=#MP86-K86=E+69I;&4F9W0[#0I3:6=N<R!A('!A8VMA
M9V4@9&ES=')I8G5T:6]N("@N=&%R(&]R("YT9WHI(&9I;&4@=VET:"!';G50
M1RX\+V1O8SX-"B`\+W-I9VX^#0H@/&UA:V5R<&T^#0H@(#QS=6UM87)Y/D)U
M:6QD<R!A;B!24$T@<W!E8R!F:6QE(&9R;VT@82!014%2('!A8VMA9V4\+W-U
M;6UA<GD^#0H@(#QF=6YC=&EO;CYD;TUA:V524$T\+V9U;F-T:6]N/@T*("`\
M<VAO<G1C=70^<G!M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\<W!E
M8RUT96UP;&%T93X-"B`@("`\<VAO<G1O<'0^=#PO<VAO<G1O<'0^#0H@("`@
M/&%R9SY&24Q%/"]A<F<^#0H@("`@/&1O8SY5<V4@1DE,12!A<R!24$T@<W!E
M8R!F:6QE('1E;7!L871E/"]D;V,^#0H@("`\+W-P96,M=&5M<&QA=&4^#0H@
M("`\<G!M+7!K9VYA;64^#0H@("`@/'-H;W)T;W!T/G`\+W-H;W)T;W!T/@T*
M("`@(#QA<F<^1D]234%4/"]A<F<^#0H@("`@/&1O8SY5<V4@1D]234%4(&%S
M(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K86=E(&YA;64L("5S(&ES(')E
M<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E(&YA;64L(&1E9F%U;'1S('1O
M("9Q=6]T.U!%05(Z.B5S)G%U;W0[+CPO9&]C/@T*("`@/"]R<&TM<&MG;F%M
M93X-"B`@/"]O<'1I;VYS/@T*("`\9&]C/B9L=#MP86-K86=E+69I;&4F9W0[
M#0H-"D-R96%T97,@86X@4E!-("YS<&5C(&9I;&4@9F]R('=R87!P:6YG(&$@
M4$5!4B!P86-K86=E(&EN<VED92!A;B!24$T-"G!A8VMA9V4N("!);G1E;F1E
M9"!T;R!B92!U<V5D(&9R;VT@=&AE(%-014-3(&1I<F5C=&]R>2P@=VET:"!T
M:&4@4$5!4@T*<&%C:V%G92!T87)B86QL(&EN('1H92!33U520T53(&1I<F5C
M=&]R>3H-"@T*)"!P96%R(&UA:V5R<&T@+BXO4T]54D-%4R].971?4V]C:V5T
M+3$N,"YT9WH-"E=R;W1E(%)032!S<&5C(&9I;&4@4$5!4CHZ3F5T7T=E;RTQ
M+C`N<W!E8PT*)"!R<&T@+6)B(%!%05(Z.DYE=%]3;V-K970M,2XP+G-P96,-
M"BXN+@T*5W)O=&4Z("]U<W(O<W)C+W)E9&AA="]24$U3+VDS.#8O4$5!4CHZ
M3F5T7U-O8VME="TQ+C`M,2YI,S@V+G)P;0T*/"]D;V,^#0H@/"]M86ME<G!M
M/@T*(#QC;VYV97)T/@T*("`\<W5M;6%R>3Y#;VYV97)T(&$@<&%C:V%G92YX
M;6P@,2XP('1O('!A8VMA9V4N>&UL(#(N,"!F;W)M870\+W-U;6UA<GD^#0H@
M(#QF=6YC=&EO;CYD;T-O;G9E<G0\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^
M8S(\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QF;&%T/@T*("`@(#QS
M:&]R=&]P=#YF/"]S:&]R=&]P=#X-"B`@("`\9&]C/F1O(&YO="!B96%U=&EF
M>2!T:&4@9FEL96QI<W0N/"]D;V,^#0H@("`\+V9L870^#0H@(#PO;W!T:6]N
M<SX-"B`@/&1O8SY;9&5S8V9I;&5=(%MD97-C9FEL93)=#0I#;VYV97)T<R!A
M('!A8VMA9V4N>&UL(&EN(#$N,"!F;W)M870@:6YT;R!A('!A8VMA9V4N>&UL
M#0II;B`R+C`@9F]R;6%T+B`@5&AE(&YE=R!F:6QE('=I;&P@8F4@;F%M960@
M<&%C:V%G93(N>&UL(&)Y(&1E9F%U;'0L#0IA;F0@<&%C:V%G92YX;6P@=VEL
M;"!B92!U<V5D(&%S('1H92!O;&0@9FEL92!B>2!D969A=6QT+@T*5&AI<R!I
M<R!N;W0@=&AE(&UO<W0@:6YT96QL:6=E;G0@8V]N=F5R<VEO;BP@86YD('-H
M;W5L9"!O;FQY(&)E#0IU<V5D(&9O<B!A=71O;6%T960@8V]N=F5R<VEO;B!O
M<B!L96%R;FEN9R!T:&4@9F]R;6%T+@T*/"]D;V,^#0H@/"]C;VYV97)T/@T*
M/"]C;VUM86YD<SX`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]086-K86=E+G!H<```````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q,S<P-#<@,3`U,34T,S0Q,S0@,#(R-C0W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(%!%05)?0V]M;6%N9%]086-K86=E("AP86-K86=E+"!P86-K86=E
M+79A;&ED871E+"!C=G-D:69F+"!C=G-T86<L('!A8VMA9V4M9&5P96YD96YC
M:65S+`T*("H@<VEG;BP@;6%K97)P;2P@8V]N=F5R="!C;VUM86YD<RD-"B`J
M#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T
M:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`
M8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T
M:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R
M("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%!A8VMA9V4N<&AP+'8@
M,2XQ,3D@,C`P-B\P,R\P,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@
M*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N
M,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2
M(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@*B!`8V%T96=O<GD@
M("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!-87)T
M:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0IC
M;&%S<R!014%27T-O;6UA;F1?4&%C:V%G92!E>'1E;F1S(%!%05)?0V]M;6%N
M9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@=F%R
M("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<&%C:V%G92<@/3X@87)R
M87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)T)U:6QD(%!A8VMA9V4G
M+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K86=E)RP-"B`@
M("`@("`@("`@("=S:&]R=&-U="<@/3X@)W`G+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=N;V-O;7!R97-S
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G6B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;R!N;W0@
M9WII<"!T:&4@<&%C:V%G92!F:6QE)PT*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=S:&]W;F%M92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)VXG+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G4')I;G0@=&AE(&YA;64@;V8@=&AE('!A
M8VMA9V5D(&9I;&4N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL
M95T@6V1E<V-F:6QE,ET-"D-R96%T97,@82!014%2('!A8VMA9V4@9G)O;2!I
M=',@9&5S8W)I<'1I;VX@9FEL92`H=7-U86QL>2!C86QL960-"G!A8VMA9V4N
M>&UL*2X@($EF(&$@<V5C;VYD('!A8VMA9V5F:6QE(&ES('!A<W-E9"!I;BP@
M=&AE;@T*=&AE('!A8VMA9V5R('=I;&P@8VAE8VL@=&\@;6%K92!S=7)E('1H
M870@;VYE(&ES(&$@<&%C:V%G92YX;6P-"G9E<G-I;VX@,2XP+"!A;F0@=&AE
M(&]T:&5R(&ES(&$@<&%C:V%G92YX;6P@=F5R<VEO;B`R+C`N("!4:&4-"G!A
M8VMA9V4N>&UL('9E<G-I;VX@,2XP('=I;&P@8F4@<V%V960@87,@(G!A8VMA
M9V4N>&UL(B!I;B!T:&4@87)C:&EV92P-"F%N9"!T:&4@;W1H97(@87,@(G!A
M8VMA9V4R+GAM;"(@:6X@=&AE(&%R8VAI=F4B#0HG#0H@("`@("`@("`@("`I
M+`T*("`@("`@("`G<&%C:V%G92UV86QI9&%T92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`G<W5M;6%R>2<@/3X@)U9A;&ED871E(%!A8VMA9V4@0V]N<VES
M=&5N8WDG+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]086-K86=E
M5F%L:61A=&4G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<'8G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@
M("`G9&]C)R`]/B`G#0HG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-V
M<V1I9F8G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=2
M=6X@82`B8W9S(&1I9F8B(&9O<B!A;&P@9FEL97,@:6X@82!P86-K86=E)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O0W9S1&EF9B<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=C9"<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)W%U:65T)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("="92!Q=6EE="<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W)E86QL
M>7%U:65T)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T
M;W!T)R`]/B`G42<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("="
M92!R96%L;'D@<75I970G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@("`@("=D871E)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G1"<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=$:69F(&%G86EN<W0@<F5V:7-I;VX@;V8@1$%412<L#0H@
M("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=$051%)RP-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5L96%S92<@/3X@
M87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)U(G
M+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T
M('1A9R!F;W(@<&%C:V%G92!R96QE87-E(%)%3"<L#0H@("`@("`@("`@("`@
M("`@("`@("=A<F<G(#T^("=214PG+`T*("`@("`@("`@("`@("`@("`@("`I
M+`T*("`@("`@("`@("`@("`@("=R979I<VEO;B<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)W(G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G1&EF9B!A9V%I;G-T(')E=FES:6]N(%)%
M5B<L#0H@("`@("`@("`@("`@("`@("`@("=A<F<G(#T^("=2158G+`T*("`@
M("`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=C;VYT97AT
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("='96YE<F%T
M92!C;VYT97AT(&1I9F8G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@
M("`@("`@("`@("`@("=U;FEF:65D)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("='96YE<F%T92!U;FEF:65D(&1I9F8G+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=I9VYO<F4M8V%S
M92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@
M/3X@)VDG+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E
M(&-A<V4L(&-O;G-I9&5R('5P<&5R+2!A;F0@;&]W97(M8V%S92!L971T97)S
M(&5Q=6EV86QE;G0G+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("=I9VYO<F4M=VAI=&5S<&%C92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V(G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G26=N;W)E(&-H86YG97,@:6X@86UO=6YT
M(&]F('=H:71E('-P86-E)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@
M("`@("`@("`@("`@("`G:6=N;W)E+6)L86YK+6QI;F5S)R`]/B!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G0B<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=)9VYO<F4@8VAA;F=E<R!T:&%T
M(&EN<V5R="!O<B!D96QE=&4@8FQA;FL@;&EN97,G+`T*("`@("`@("`@("`@
M("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=B<FEE9B<@/3X@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=297!O<G0@;VYL>2!W
M:&5T:&5R('1H92!F:6QE<R!D:69F97(L(&YO(&1E=&%I;',G+`T*("`@("`@
M("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@("`@("=D<GDM<G5N)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G
M;B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=$;VY<)W0@9&\@
M86YY=&AI;F<L(&IU<W0@<')E=&5N9"<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("<\<&%C:V%G92YX;6P^#0I#;VUP87)E<R!A;&P@=&AE(&9I;&5S(&EN(&$@
M<&%C:V%G92X@(%=I=&AO=70@86YY(&]P=&EO;G,L('1H:7,-"F-O;6UA;F0@
M=VEL;"!C;VUP87)E('1H92!C=7)R96YT(&-O9&4@=VET:"!T:&4@;&%S="!C
M:&5C:V5D+6EN(&-O9&4N#0I5<VEN9R!T:&4@+7(@;W(@+5(@;W!T:6]N('EO
M=2!M87D@8V]M<&%R92!T:&4@8W5R<F5N="!C;V1E('=I=&@@=&AA=`T*;V8@
M82!S<&5C:69I8R!R96QE87-E+@T*)RP-"B`@("`@("`@("`@("DL#0H@("`@
M("`@("=C=G-T86<G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG
M(#T^("=3970@0U93(%)E;&5A<V4@5&%G)RP-"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O0W9S5&%G)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@
M/3X@)V-T)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`G<75I970G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=Q)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)T)E('%U:65T)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`G<F5A;&QY<75I970G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=1)RP-"B`@("`@
M("`@("`@("`@("`@("`@)V1O8R<@/3X@)T)E(')E86QL>2!Q=6EE="<L#0H@
M("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W-L:61E
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G1B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=-;W9E("AS
M;&ED92D@=&%G(&EF(&ET(&5X:7-T<R<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)V1E;&5T92<@/3X@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)V0G+`T*("`@("`@("`@
M("`@("`@("`@("`G9&]C)R`]/B`G4F5M;W9E('1A9R<L#0H@("`@("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)V1R>2UR=6XG(#T^(&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=N)RP-
M"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O;EPG="!D;R!A;GET
M:&EN9RP@:G5S="!P<F5T96YD)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP
M86-K86=E+GAM;#X@6V9I;&5S+BXN70T*4V5T<R!A($-64R!T86<@;VX@86QL
M(&9I;&5S(&EN(&$@<&%C:V%G92X@(%5S92!T:&ES(&-O;6UA;F0@869T97(@
M>6]U(&AA=F4-"G!A8VMA9V5D(&$@9&ES=')I8G5T:6]N('1A<F)A;&P@=VET
M:"!T:&4@(G!A8VMA9V4B(&-O;6UA;F0@=&\@=&%G('=H870-"G)E=FES:6]N
M<R!O9B!W:&%T(&9I;&5S('=E<F4@:6X@=&AA="!R96QE87-E+B`@268@;F5E
M9"!T;R!F:7@@<V]M971H:6YG#0IA9G1E<B!R=6YN:6YG(&-V<W1A9R!O;F-E
M+"!B=70@8F5F;W)E('1H92!T87)B86QL(&ES(')E;&5A<V5D('1O('1H92!P
M=6)L:6,L#0IU<V4@=&AE(")S;&ED92(@;W!T:6]N('1O(&UO=F4@=&AE(')E
M;&5A<V4@=&%G+@T*#0IT;R!I;F-L=61E(&9I;&5S("AS=6-H(&%S(&$@<V5C
M;VYD('!A8VMA9V4N>&UL+"!O<B!T97-T<R!N;W0@:6YC;'5D960@:6X@=&AE
M#0IR96QE87-E*2P@<&%S<R!T:&5M(&%S(&%D9&ET:6]N86P@<&%R86UE=&5R
M<RX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`G<&%C:V%G92UD97!E
M;F1E;F-I97,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^
M("=3:&]W('!A8VMA9V4@9&5P96YD96YC:65S)RP-"B`@("`@("`@("`@("=F
M=6YC=&EO;B<@/3X@)V1O4&%C:V%G941E<&5N9&5N8VEE<R<L#0H@("`@("`@
M("`@("`G<VAO<G1C=70G(#T^("=P9"<L#0H@("`@("`@("`@("`G;W!T:6]N
M<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<-"DQI<W0@
M86QL(&1E<&5N8VEE<R!T:&4@<&%C:V%G92!H87,N)PT*("`@("`@("`@("`@
M*2P-"B`@("`@("`@)W-I9VXG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U
M;6UA<GDG(#T^("=3:6=N(&$@<&%C:V%G92!D:7-T<FEB=71I;VX@9FEL92<L
M#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U-I9VXG+`T*("`@("`@
M("`@("`@)W-H;W)T8W5T)R`]/B`G<VDG+`T*("`@("`@("`@("`@)V]P=&EO
M;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G/'!A8VMA
M9V4M9FEL93X-"E-I9VYS(&$@<&%C:V%G92!D:7-T<FEB=71I;VX@*"YT87(@
M;W(@+G1G>BD@9FEL92!W:71H($=N=5!'+B<L#0H@("`@("`@("`@("`I+`T*
M("`@("`@("`G;6%K97)P;2<@/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M
M;6%R>2<@/3X@)T)U:6QD<R!A;B!24$T@<W!E8R!F:6QE(&9R;VT@82!014%2
M('!A8VMA9V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]-86ME
M4E!-)RP-"B`@("`@("`@("`@("=S:&]R=&-U="<@/3X@)W)P;2<L#0H@("`@
M("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@
M)W-P96,M=&5M<&QA=&4G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@
M("`G<VAO<G1O<'0G(#T^("=T)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R
M9R<@/3X@)T9)3$4G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G
M57-E($9)3$4@87,@4E!-('-P96,@9FEL92!T96UP;&%T92<-"B`@("`@("`@
M("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<G!M+7!K9VYA;64G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V%R9R<@/3X@)T9/4DU!5"<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=5<V4@1D]234%4(&%S
M(&9O<FUA="!S=')I;F<@9F]R(%)032!P86-K86=E(&YA;64L("5S(&ES(')E
M<&QA8V5D#0IB>2!T:&4@4$5!4B!P86-K86=E(&YA;64L(&1E9F%U;'1S('1O
M(")014%2.CHE<R(N)RP-"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@
M("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E
M+69I;&4^#0H-"D-R96%T97,@86X@4E!-("YS<&5C(&9I;&4@9F]R('=R87!P
M:6YG(&$@4$5!4B!P86-K86=E(&EN<VED92!A;B!24$T-"G!A8VMA9V4N("!)
M;G1E;F1E9"!T;R!B92!U<V5D(&9R;VT@=&AE(%-014-3(&1I<F5C=&]R>2P@
M=VET:"!T:&4@4$5!4@T*<&%C:V%G92!T87)B86QL(&EN('1H92!33U520T53
M(&1I<F5C=&]R>3H-"@T*)"!P96%R(&UA:V5R<&T@+BXO4T]54D-%4R].971?
M4V]C:V5T+3$N,"YT9WH-"E=R;W1E(%)032!S<&5C(&9I;&4@4$5!4CHZ3F5T
M7T=E;RTQ+C`N<W!E8PT*)"!R<&T@+6)B(%!%05(Z.DYE=%]3;V-K970M,2XP
M+G-P96,-"BXN+@T*5W)O=&4Z("]U<W(O<W)C+W)E9&AA="]24$U3+VDS.#8O
M4$5!4CHZ3F5T7U-O8VME="TQ+C`M,2YI,S@V+G)P;0T*)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=C;VYV97)T)R`]/B!A<G)A>2@-"B`@("`@("`@
M("`@("=S=6UM87)Y)R`]/B`G0V]N=F5R="!A('!A8VMA9V4N>&UL(#$N,"!T
M;R!P86-K86=E+GAM;"`R+C`@9F]R;6%T)RP-"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O0V]N=F5R="<L#0H@("`@("`@("`@("`G<VAO<G1C=70G
M(#T^("=C,B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@
M("`@("`@("`@("`@("`@)V9L870G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("`@("`G<VAO<G1O<'0G(#T^("=F)RP-"B`@("`@("`@("`@("`@("`@
M("`@)V1O8R<@/3X@)V1O(&YO="!B96%U=&EF>2!T:&4@9FEL96QI<W0N)RP-
M"B`@("`@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`I+`T*
M("`@("`@("`@("`@)V1O8R<@/3X@)UMD97-C9FEL95T@6V1E<V-F:6QE,ET-
M"D-O;G9E<G1S(&$@<&%C:V%G92YX;6P@:6X@,2XP(&9O<FUA="!I;G1O(&$@
M<&%C:V%G92YX;6P-"FEN(#(N,"!F;W)M870N("!4:&4@;F5W(&9I;&4@=VEL
M;"!B92!N86UE9"!P86-K86=E,BYX;6P@8GD@9&5F875L="P-"F%N9"!P86-K
M86=E+GAM;"!W:6QL(&)E('5S960@87,@=&AE(&]L9"!F:6QE(&)Y(&1E9F%U
M;'0N#0I4:&ES(&ES(&YO="!T:&4@;6]S="!I;G1E;&QI9V5N="!C;VYV97)S
M:6]N+"!A;F0@<VAO=6QD(&]N;'D@8F4-"G5S960@9F]R(&%U=&]M871E9"!C
M;VYV97)S:6]N(&]R(&QE87)N:6YG('1H92!F;W)M870N#0HG#0H@("`@("`@
M("`@("`I+`T*("`@("`@("`I.PT*#0H@("`@=F%R("1O=71P=70[#0H-"B`@
M("`O+R!]?7T-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-"@T*("`@("\J*@T*
M("`@("`J(%!%05)?0V]M;6%N9%]086-K86=E(&-O;G-T<G5C=&]R+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!014%27T-O;6UA;F1?4&%C:V%G92@F)'5I+"`F)&-O;F9I9RD-"B`@
M("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL
M("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(%]D:7-P;&%Y5F%L:61A=&EO;E)E<W5L=',H*0T*#0H@("`@9G5N8W1I;VX@
M7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D97)R+"`D=V%R;BP@)'-T<FEC
M="`](&9A;'-E*0T*("`@('L-"B`@("`@("`@9F]R96%C:"`H)&5R<B!A<R`D
M92D@>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N/2`B17)R;W(Z("1E
M7&XB.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*"1W87)N(&%S("1W
M*2![#0H@("`@("`@("`@("`D=&AI<RT^;W5T<'5T("X](")787)N:6YG.B`D
M=UQN(CL-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;W5T<'5T("X]('-P
M<FEN=&8H)U9A;&ED871I;VXZ("5D(&5R<F]R*',I+"`E9"!W87)N:6YG*',I
M)RXB7&XB+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<VEZ96]F*"1E<G(I+"!S:7IE;V8H)'=A<FXI*3L-"B`@("`@("`@:68@
M*"1S=')I8W0@)B8@<VEZ96]F*"1E<G(I(#X@,"D@>PT*("`@("`@("`@("`@
M)'1H:7,M/F]U='!U="`N/2`B1FEX('1H97-E(&5R<F]R<R!A;F0@=')Y(&%G
M86EN+B([#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-
M"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@
M("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5R*"D-"B`@("![#0H@("`@("`@(&EF
M("@A8VQA<W-?97AI<W1S*"=014%27U!A8VMA9V5R)RDI('L-"B`@("`@("`@
M("`@(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E<BYP:'`G.PT*("`@("`@
M("!]#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5R.PT*("`@("`@
M("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA
M9V5&:6QE*"1C;VYF:6<L("1D96)U9R`](&9A;'-E+"`D=&UP9&ER(#T@;G5L
M;"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-O
M;6UO;B<I*2![#0H@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M
M;6]N+G!H<"<[#0H@("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES
M=',H)U!%05(O4&%C:V%G949I;&4N<&AP)RDI('L-"B`@("`@("`@("`@(')E
M<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("!]
M#0H@("`@("`@("1A(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C;VYF:6<L
M("1D96)U9RP@)'1M<&1I<BD[#0H@("`@("`@("1C;VUM;VX@/2!N97<@4$5!
M4E]#;VUM;VX[#0H@("`@("`@("1C;VUM;VXM/G5I(#T@)'1H:7,M/G5I.PT*
M("`@("`@("`D82T^<V5T3&]G9V5R*"1C;VUM;VXI.PT*("`@("`@("!R971U
M<FX@)&$[#0H@("`@?0T*("`@("\O('M[>R!D;U!A8VMA9V4H*0T*#0H@("`@
M9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M
M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@
M("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M<ULP72D@/R`D<&%R86US
M6S!=(#H@)W!A8VMA9V4N>&UL)SL-"B`@("`@("`@)'!K9S(@/2!I<W-E="@D
M<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!N=6QL.PT*("`@("`@("!I9B`H
M(21P:V<R("8F("%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@
M:68@*&9I;&5?97AI<W1S*"=P86-K86=E,BYX;6PG*2D@>PT*("`@("`@("`@
M("`@("`@("1P:V<R(#T@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5R(#T@)B1T:&ES+3YG9710
M86-K86=E<B@I.PT*("`@("`@("`D8V]M<')E<W,@/2!E;7!T>2@D;W!T:6]N
M<ULG;F]C;VUP<F5S<R==*2`_('1R=64@.B!F86QS93L-"B`@("`@("`@)')E
M<W5L="`]("1P86-K86=E<BT^<&%C:V%G92@D<&MG:6YF;V9I;&4L("1C;VUP
M<F5S<RP@)'!K9S(I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1R97-U;'0I.PT*("`@("`@("!]#0H@("`@("`@("\O($1O;B=T('=A;G0@
M;W5T<'5T+"!O;FQY('1H92!P86-K86=E(&9I;&4@;F%M92!J=7-T(&-R96%T
M960-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=S:&]W;F%M92==*2D@
M>PT*("`@("`@("`@("`@)'1H:7,M/F]U='!U="`]("1R97-U;'0[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1T:&ES+3YO=71P=70I('L-"B`@("`@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M
M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4&%C:V%G959A;&ED871E
M*"D-"@T*("`@(&9U;F-T:6]N(&1O4&%C:V%G959A;&ED871E*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO
M=71P=70@/2`G)SL-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I
M('L-"B`@("`@("`@("`@("1P87)A;7-;,%T@/2`B<&%C:V%G92YX;6PB.PT*
M("`@("`@("!]#0H@("`@("`@("1O8FH@/2`F)'1H:7,M/F=E=%!A8VMA9V5&
M:6QE*"1T:&ES+3YC;VYF:6<L("1T:&ES+3Y?9&5B=6<I.PT*("`@("`@("`D
M;V)J+3YR87=2971U<FXH*3L-"B`@("`@("`@4$5!4CHZ<W1A=&EC4'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@("`D:6YF
M;R`]("1O8FHM/F9R;VU49WI&:6QE*"1P87)A;7-;,%TL(%!%05)?5D%,241!
M5$5?3D]234%,*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I
M*2![#0H@("`@("`@("`@("`D:6YF;R`]("1O8FHM/F9R;VU086-K86=E1FEL
M92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!3"D[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`D87)C:&EV92`]("1I;F9O+3YG971!
M<F-H:79E1FEL92@I.PT*("`@("`@("`@("`@)'1A<B`]("9N97<@07)C:&EV
M95]487(H)&%R8VAI=F4I.PT*("`@("`@("`@("`@)'1A<BT^97AT<F%C="AD
M:7)N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I*2D[#0H@("`@("`@("`@
M("`D:6YF;RT^<V5T4&%C:V%G949I;&4H9&ER;F%M92@D:6YF;RT^9V5T4&%C
M:V%G949I;&4H*2D@+B!$25)%0U1/4EE?4T5005)!5$]2("X-"B`@("`@("`@
M("`@("`@("`D:6YF;RT^9V5T4&%C:V%G92@I("X@)RTG("X@)&EN9F\M/F=E
M=%9E<G-I;VXH*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@
M("`@("`@(&)A<V5N86UE*"1I;F9O+3YG971086-K86=E1FEL92@I*2D[#0H@
M("`@("`@('T-"B`@("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN
M9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@
M("`@("`@('T-"B`@("`@("`@)'9A;&ED(#T@9F%L<V4[#0H@("`@("`@(&EF
M("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@>PT*
M("`@("`@("`@("`@:68@*"1V86QI9"`]("1I;F9O+3YV86QI9&%T92A014%2
M7U9!3$E$051%7TY/4DU!3"DI('L-"B`@("`@("`@("`@("`@("`D:6YF;RT^
M9FQA='1E;D9I;&5,:7-T*"D[#0H@("`@("`@("`@("`@("`@)'9A;&ED(#T@
M)&EN9F\M/G9A;&ED871E*%!%05)?5D%,241!5$5?4$%#2T%'24Y'*3L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1V
M86QI9"`]("1I;F9O+3YV86QI9&%T92A014%27U9!3$E$051%7U!!0TM!1TE.
M1RD[#0H@("`@("`@('T-"B`@("`@("`@)&5R<B`](&%R<F%Y*"D[#0H@("`@
M("`@("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@:68@*"$D=F%L:60I('L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1I;F9O+3YG971686QI9&%T:6]N5V%R
M;FEN9W,H*2!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("!I9B`H)&5R
M<F]R6R=L979E;"==(#T]("=W87)N:6YG)RD@>PT*("`@("`@("`@("`@("`@
M("`@("`D=V%R;EM=(#T@)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&5R<EM=(#T@
M)&5R<F]R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?9&ES<&QA>59A
M;&ED871I;VY297-U;'1S*"1E<G(L("1W87)N*3L-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"1T:&ES+3YO=71P=70L("1C;VUM86YD*3L-"B`@
M("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@
M+R\@>WM[(&1O0W9S5&%G*"D-"@T*("`@(&9U;F-T:6]N(&1O0W9S5&%G*"1C
M;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T
M:&ES+3YO=71P=70@/2`G)SL-"B`@("`@("`@)%]C;60@/2`D8V]M;6%N9#L-
M"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@
M("`@("1H96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@;6ES
M<VEN9R!P87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-"B`@("`@
M("`@)&]B:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I
M9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O
M;4%N>49I;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@
M('T-"B`@("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@
M:68@*"$D:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&EN9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E<G)O<BD@
M>PT*("`@("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@)W=A
M<FYI;F<G*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@/2`D97)R
M;W);)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A9V4G73L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S=6QT
M<R@D97)R+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!T86<@9F%I
M;&5D)RD[#0H@("`@("`@('T-"B`@("`@("`@)'9E<G-I;VX@/2`D:6YF;RT^
M9V5T5F5R<VEO;B@I.PT*("`@("`@("`D8W9S=F5R<VEO;B`]('!R96=?<F5P
M;&%C92@G+UM>82UZ,"TY72]I)RP@)U\G+"`D=F5R<VEO;BD[#0H@("`@("`@
M("1C=G-T86<@/2`B4D5,14%315\D8W9S=F5R<VEO;B([#0H@("`@("`@("1F
M:6QE<R`](&%R<F%Y7VME>7,H)&EN9F\M/F=E=$9I;&5L:7-T*"DI.PT*("`@
M("`@("`D8V]M;6%N9"`](")C=G,B.PT*("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)W%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G
M("UQ)SL-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W)E86QL>7%U:65T)UTI*2![#0H@("`@("`@("`@("`D8V]M;6%N9"`N/2`G
M("U1)SL-"B`@("`@("`@?0T*("`@("`@("`D8V]M;6%N9"`N/2`G('1A9R<[
M#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VQI9&4G72DI('L-"B`@
M("`@("`@("`@("1C;VUM86YD("X]("<@+48G.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&5L971E)UTI*2![#0H@("`@("`@
M("`@("`D8V]M;6%N9"`N/2`G("UD)SL-"B`@("`@("`@?0T*("`@("`@("`D
M8V]M;6%N9"`N/2`G("<@+B`D8W9S=&%G("X@)R`G("X@97-C87!E<VAE;&QA
M<F<H)'!A<F%M<ULP72D[#0H@("`@("`@(&%R<F%Y7W-H:69T*"1P87)A;7,I
M.PT*("`@("`@("!I9B`H8V]U;G0H)'!A<F%M<RDI('L-"B`@("`@("`@("`@
M("\O(&%D9"!I;B!A9&1I=&EO;F%L(&9I;&5S('1O(&)E('1A9V=E9`T*("`@
M("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H)&9I;&5S+"`D<&%R86US
M*3L-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D9FEL97,@87,@)&9I
M;&4I('L-"B`@("`@("`@("`@("1C;VUM86YD("X]("<@)R`N(&5S8V%P97-H
M96QL87)G*"1F:6QE*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)'1H:7,M
M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD@/B`Q*2![#0H@("`@("`@("`@("`D
M=&AI<RT^;W5T<'5T("X]("(K("1C;VUM86YD7&XB.PT*("`@("`@("!]#0H@
M("`@("`@("1T:&ES+3YO=71P=70@+CT@(BL@)&-O;6UA;F1<;B([#0H@("`@
M("`@(&EF("AE;7!T>2@D;W!T:6]N<ULG9')Y+7)U;B==*2D@>PT*("`@("`@
M("`@("`@)&9P(#T@<&]P96XH)&-O;6UA;F0L(")R(BD[#0H@("`@("`@("`@
M("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D9G`L(#$P,C0I*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/F]U='!U="`N/2!R=')I;2@D;&EN92DN(EQN(CL-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@('!C;&]S92@D9G`I.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D=&AI<RT^
M;W5T<'5T+"`D7V-M9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"@T*("`@("\O('U]?0T*("`@("\O('M[>R!D;T-V<T1I9F8H*0T*#0H@("`@
M9G5N8W1I;VX@9&]#=G-$:69F*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M
M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G)SL-"B`@("`@
M("`@:68@*'-I>F5O9B@D<&%R86US*2`\(#$I('L-"B`@("`@("`@("`@("1H
M96QP(#T@)'1H:7,M/F=E=$AE;'`H)&-O;6UA;F0I.PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@;6ES<VEN9R!P
M87)A;65T97(Z("1H96QP6S!=(BD[#0H@("`@("`@('T-"B`@("`@("`@)&]B
M:B`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H
M:7,M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;4%N>49I
M;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@
M("`@("`@)&5R<B`]("1W87)N(#T@87)R87DH*3L-"B`@("`@("`@:68@*"$D
M:6YF;RT^=F%L:61A=&4H*2D@>PT*("`@("`@("`@("`@9F]R96%C:"`H)&EN
M9F\M/F=E=%9A;&ED871I;VY787)N:6YG<R@I(&%S("1E<G)O<BD@>PT*("`@
M("`@("`@("`@("`@(&EF("@D97)R;W);)VQE=F5L)UT@/3T@)W=A<FYI;F<G
M*2![#0H@("`@("`@("`@("`@("`@("`@("1W87)N6UT@/2`D97)R;W);)VUE
M<W-A9V4G73L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@("`D97)R6UT@/2`D97)R;W);)VUE<W-A9V4G73L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"$D=&AI<RT^7V1I<W!L87E686QI9&%T:6]N4F5S=6QT<R@D97)R
M+"`D=V%R;BP@=')U92DI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T
M<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-64R!D:69F(&9A:6QE9"<I
M.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O,2`]("1I;F9O+3YG971&:6QE
M;&ES="@I.PT*("`@("`@("`D9FEL97,@/2`D:6YF;S$[#0H@("`@("`@("1C
M;60@/2`B8W9S(CL-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=Q=6EE
M="==*2D@>PT*("`@("`@("`@("`@)&-M9"`N/2`G("UQ)SL-"B`@("`@("`@
M("`@('5N<V5T*"1O<'1I;VYS6R=Q=6EE="==*3L-"B`@("`@("`@?0T*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI*2![#0H@
M("`@("`@("`@("`D8VUD("X]("<@+5$G.PT*("`@("`@("`@("`@=6YS970H
M)&]P=&EO;G-;)W)E86QL>7%U:65T)UTI.PT*("`@("`@("!]#0H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG<F5L96%S92==*2D@>PT*("`@("`@("`@
M("`@)&-V<W9E<G-I;VX@/2!P<F5G7W)E<&QA8V4H)R];7F$M>C`M.5TO:2<L
M("=?)RP@)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@("`@("`D8W9S
M=&%G(#T@(E)%3$5!4T5?)&-V<W9E<G-I;VXB.PT*("`@("`@("`@("`@)&]P
M=&EO;G-;)W)E=FES:6]N)UT@/2`D8W9S=&%G.PT*("`@("`@("`@("`@=6YS
M970H)&]P=&EO;G-;)W)E;&5A<V4G72D[#0H@("`@("`@('T-"B`@("`@("`@
M)&5X96-U=&4@/2!T<G5E.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)V1R>2UR=6XG72DI('L-"B`@("`@("`@("`@("1E>&5C=71E(#T@9F%L<V4[
M#0H@("`@("`@("`@("!U;G-E="@D;W!T:6]N<ULG9')Y+7)U;B==*3L-"B`@
M("`@("`@?0T*("`@("`@("`D8VUD("X]("<@9&EF9B<[#0H@("`@("`@("\O
M('1H92!R97-T(&]F('1H92!O<'1I;VYS(&%R92!P87-S960@<FEG:'0@;VX@
M=&\@(F-V<R!D:69F(@T*("`@("`@("!F;W)E86-H("@D;W!T:6]N<R!A<R`D
M;W!T:6]N(#T^("1O<'1A<F<I('L-"B`@("`@("`@("`@("1A<F<@/2!`)'1H
M:7,M/F-O;6UA;F1S6R1C;VUM86YD75LG;W!T:6]N<R==6R1O<'1I;VY=6R=A
M<F<G73L-"B`@("`@("`@("`@("1S:&]R="`]($`D=&AI<RT^8V]M;6%N9'-;
M)&-O;6UA;F1=6R=O<'1I;VYS)UU;)&]P=&EO;EU;)W-H;W)T;W!T)UT[#0H@
M("`@("`@("`@("`D8VUD("X]("1S:&]R="`_("(@+21S:&]R="(@.B`B("TM
M)&]P=&EO;B([#0H@("`@("`@("`@("!I9B`H)&%R9R`F)B`D;W!T87)G*2![
M#0H@("`@("`@("`@("`@("`@)&-M9"`N/2`H)'-H;W)T(#\@)R<@.B`G/2<I
M("X@97-C87!E<VAE;&QA<F<H)&]P=&%R9RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)&9I;&5S(&%S("1F:6QE*2![
M#0H@("`@("`@("`@("`D8VUD("X]("<@)R`N(&5S8V%P97-H96QL87)G*"1F
M:6QE6R=N86UE)UTI.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D=&AI<RT^
M8V]N9FEG+3YG970H)W9E<F)O<V4G*2`^(#$I('L-"B`@("`@("`@("`@("1T
M:&ES+3YO=71P=70@+CT@(BL@)&-M9%QN(CL-"B`@("`@("`@?0T*("`@("`@
M("!I9B`H)&5X96-U=&4I('L-"B`@("`@("`@("`@("1F<"`]('!O<&5N*"1C
M;60L(")R(BD[#0H@("`@("`@("`@("!W:&EL92`H)&QI;F4@/2!F9V5T<R@D
M9G`L(#$P,C0I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F]U='!U="`N
M/2!R=')I;2@D;&EN92DN(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@('!C;&]S92@D9G`I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D=&AI<RT^;W5T<'5T+"`D8V]M;6%N9"D[#0H@("`@
M("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O
M('M[>R!D;U!A8VMA9V5$97!E;F1E;F-I97,H*0T*#0H@("`@9G5N8W1I;VX@
M9&]086-K86=E1&5P96YD96YC:65S*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A
M<F%M<RD-"B`@("![#0H@("`@("`@("\O("1P87)A;7-;,%T@+3X@=&AE(%!%
M05(@<&%C:V%G92!T;R!L:7-T(&ET<R!I;F9O<FUA=&EO;@T*("`@("`@("!I
M9B`H<VEZ96]F*"1P87)A;7,I("$](#$I('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@B8F%D('!A<F%M971E<BAS*2P@=')Y(%PB
M:&5L<"`D8V]M;6%N9%PB(BD[#0H@("`@("`@('T-"B`@("`@("`@)&]B:B`]
M("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M
M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;4%N>49I;&4H
M)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@
M("`@)&1E<',@/2`D:6YF;RT^9V5T1&5P<R@I.PT*("`@("`@("!I9B`H:7-?
M87)R87DH)&1E<',I*2![#0H@("`@("`@("`@("!I9B`H)&EN9F\M/F=E=%!A
M8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@("`@("`@("`@
M("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G8V%P=&EO
M;B<@/3X@)T1E<&5N9&5N8VEE<R!F;W(@<&5A<B\G("X@)&EN9F\M/F=E=%!A
M8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U
M92P-"B`@("`@("`@("`@("`@("`@("`@)VAE861L:6YE)R`]/B!A<G)A>2@B
M4F5Q=6ER960_(BP@(E1Y<&4B+"`B3F%M92(L(")296QA=&EO;B(L(")697)S
M:6]N(BDL#0H@("`@("`@("`@("`@("`@("`@("D[#0H-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9&5P<R!A<R`D9"D@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&1;)V]P=&EO;F%L)UT@/3T@)WEE<R<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q(#T@)TYO)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)')E<2`]("=997,G.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V1E<'-?<F5L7W1R86YS6R1D6R=R96PG75TI*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5L(#T@)'1H:7,M/E]D97!S7W)E;%]T<F%N
M<ULD9%LG<F5L)UU=.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)')E;"`]("1D6R=R96PG73L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@=6-F:7)S="@D
M=&AI<RT^7V1E<'-?='EP95]T<F%N<ULD9%LG='EP92==72D[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D='EP92`]("1D6R=T>7!E)UT[#0H@("`@("`@("`@("`@("`@("`@('T-
M"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)VYA;64G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)&1;)VYA;64G
M73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1N86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@
M('T-"@T*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1;)W9E<G-I
M;VXG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@
M)&1;)W9E<G-I;VXG73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1V97)S:6]N(#T@)R<[#0H@("`@
M("`@("`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@("`@("`@("`D9&%T
M85LG9&%T82==6UT@/2!A<G)A>2@D<F5Q+"`D='EP92P@)&YA;64L("1R96PL
M("1V97)S:6]N*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M(&5L<V4@>R`O+R!P86-K86=E+GAM;"`R+C`@9&5P96YD96YC:65S(&1I<W!L
M87D-"B`@("`@("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O1&5P96YD
M96YC>3(N<&AP)SL-"B`@("`@("`@("`@("`@("`D9&5P<R`]("1I;F9O+3YG
M971$97!E;F1E;F-I97,H*3L-"B`@("`@("`@("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1D97!S*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M9"`](&YE=R!014%27T1E<&5N9&5N8WDR*"1T:&ES+3YC;VYF:6<L(&%R<F%Y
M*"DL("<G*3L-"B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=C87!T:6]N)R`]/B`G1&5P96YD
M96YC:65S(&9O<B`G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("=B;W)D97(G(#T^('1R=64L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G:&5A9&QI;F4G(#T^(&%R<F%Y*")297%U:7)E9#\B
M+"`B5'EP92(L(").86UE(BP@)U9E<G-I;VYI;F<G+"`G1W)O=7`G*2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1D97!S(&%S("1T>7!E(#T^("1S=6)D*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5Q(#T@*"1T>7!E(#T]("=R97%U:7)E9"<I
M(#\@)UEE<R<@.B`G3F\G.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1T>7!E(#T]("=G<F]U<"<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9W)O=7`@/2`D<W5B9%LG871T<FEB<R==6R=N86UE)UT[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1G<F]U<"`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M<W5B9%LP72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W5B
M9"`](&%R<F%Y*"1S=6)D*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1S=6)D(&%S("1G
M<F]U<&$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D9W)O=7!A(&%S("1D97!T>7!E(#T^("1D97!I;F9O*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P='EP92`]/2`G871T
M<FEB<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D9&5P='EP
M92`]/2`G<&5A<FEN<W1A;&QE<B<I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1D97!T>7!E(#T@)W!E87(@26YS=&%L;&5R)SL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!I;F9O6S!=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E
M<&EN9F\@/2!A<G)A>2@D9&5P:6YF;RD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&1E<&EN9F\@87,@)&EN9BD@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=C
M:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%L:6%S(#T@)')E9RT^8VAA;FYE;$%L:6%S*"1I;F9;)V-H
M86YN96PG72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"$D86QI87,I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%L:6%S(#T@)RAC:&%N;F5L/RD@)R`N
M)&EN9ELG8VAA;FYE;"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D;F%M92`]("1A;&EA<R`N("<O)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D:6YF6R=N86UE)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA
M;64@+CT@)&EN9ELG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1I;F9;)W!A='1E<FXG72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;F%M92`N/2`D:6YF6R=P871T97)N)UT[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1N86UE("X]("<G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9;)W5R:2==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N
M86UE("X]("<@6R<@+B`D:6YF6R=U<FDG72`N("`G72<[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&EN9ELG8V]N9FQI8W1S
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'9E<B`]("=C;VYF;&EC=',G.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=F5R(#T@)&0M/E]G971%>'1R85-T<FEN
M9R@D:6YF*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A
M6R=D871A)UU;72`](&%R<F%Y*"1R97$L('5C9FER<W0H)&1E<'1Y<&4I+"`D
M;F%M92P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=F5R+"`D9W)O=7`I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H-"B`@("`@("`@
M+R\@1F%L;&)A8VL-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*")4
M:&ES('!A8VMA9V4@9&]E<R!N;W0@:&%V92!A;GD@9&5P96YD96YC:65S+B(L
M("1C;VUM86YD*3L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@
M9&]3:6=N*"D-"@T*("`@(&9U;F-T:6]N(&1O4VEG;B@D8V]M;6%N9"P@)&]P
M=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!R97%U:7)E7V]N8V4@
M)U-Y<W1E;2YP:'`G.PT*("`@("`@("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O
M5&%R+G!H<"<[#0H@("`@("`@("\O('-H;W5L9"!M;W9E(&UO<W0@;V8@=&AI
M<R!C;V1E(&EN=&\@4$5!4E]086-K86=E<@T*("`@("`@("`O+R!S;R!I="=L
M;"!B92!E87-Y('1O(&EM<&QE;65N="`B<&5A<B!P86-K86=E("TM<VEG;B(-
M"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A9"!P87)A;65T97(H
M<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULP72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL92!D;V5S(&YO="!E
M>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@("!]#0H@("`@("`@("1O8FH@
M/2`D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M
M/E]D96)U9RD[#0H@("`@("`@("1I;F9O(#T@)&]B:BT^9G)O;51G>D9I;&4H
M)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D:6YF;RD[#0H@("`@("`@('T-"B`@("`@
M("`@)'1A<B`](&YE=R!!<F-H:79E7U1A<B@D<&%R86US6S!=*3L-"B`@("`@
M("`@)'1M<&1I<B`](%-Y<W1E;3HZ;6MT96UP*"<M9"!P96%R<VEG;B<I.PT*
M("`@("`@("!I9B`H(21T87(M/F5X=')A8W1,:7-T*"=P86-K86=E,BYX;6P@
M<&%C:V%G92YS:6<G+"`D=&UP9&ER*2D@>PT*("`@("`@("`@("`@:68@*"$D
M=&%R+3YE>'1R86-T3&ES="@G<&%C:V%G92YX;6P@<&%C:V%G92YS:6<G+"`D
M=&UP9&ER*2D@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@B9F%I;&5D('1O(&5X=')A8W0@=&%R(&9I;&4B*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H9FEL95]E>&ES=',H
M(B1T;7!D:7(O<&%C:V%G92YS:6<B*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*")P86-K86=E(&%L<F5A9'D@<VEG;F5D(BD[
M#0H@("`@("`@('T-"B`@("`@("`@)'!A8VMA9V5X;6P@/2`G<&%C:V%G92YX
M;6PG.PT*("`@("`@("!I9B`H9FEL95]E>&ES=',H(B1T;7!D:7(O<&%C:V%G
M93(N>&UL(BDI('L-"B`@("`@("`@("`@("1P86-K86=E>&UL(#T@)W!A8VMA
M9V4R+GAM;"<[#0H@("`@("`@('T-"B`@("`@("`@0'5N;&EN:R@B)'1M<&1I
M<B]P86-K86=E+G-I9R(I.PT*("`@("`@("`D:6YP=70@/2`D=&AI<RT^=6DM
M/G5S97)$:6%L;V<H)&-O;6UA;F0L#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@G1VYU4$<@4&%S<W!H<F%S92<I+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)W!A<W-W;W)D)RDI.PT*("`@("`@("`D9W!G(#T@<&]P96XH(F=P9R`M+6)A
M=&-H("TM<&%S<W!H<F%S92UF9"`P("TM87)M;W(@+2UD971A8V@M<VEG;B`M
M+6]U='!U="`D=&UP9&ER+W!A8VMA9V4N<VEG("1T;7!D:7(O)'!A8VMA9V5X
M;6P@,CXO9&5V+VYU;&PB+"`B=R(I.PT*("`@("`@("!I9B`H(21G<&<I('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9W!G(&-O
M;6UA;F0@9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@9G=R:71E*"1G
M<&<L("(D:6YP=71;,%U<;B(I.PT*("`@("`@("!I9B`H<&-L;W-E*"1G<&<I
M('Q\("%F:6QE7V5X:7-T<R@B)'1M<&1I<B]P86-K86=E+G-I9R(I*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F=P9R!S:6=N
M(&9A:6QE9"(I.PT*("`@("`@("!]#0H@("`@("`@("1T87(M/F%D9$UO9&EF
M>2@B)'1M<&1I<B]P86-K86=E+G-I9R(L("<G+"`D=&UP9&ER*3L-"B`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O
M*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)F=E=$EN<W1A;&QE<B@F)'5I*0T*("`@('L-"B`@
M("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05)?26YS=&%L;&5R)RDI('L-
M"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]);G-T86QL97(N<&AP
M)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@4$5!4E]);G-T86QL
M97(H)'5I*3L-"B`@("`@("`@<F5T=7)N("1A.PT*("`@('T-"B`@("`-"B`@
M("`O*BH-"B`@("`@*B!&;W(@=6YI="!T97-T:6YG('!U<G!O<V5S#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@)F=E=$-O;6UA;F1086-K86=I;F<H)B1U:2P@
M)B1C;VYF:6<I#0H@("`@>PT*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]#;VUM86YD7U!A8VMA9VEN9R<I*2![#0H@("`@("`@("`@("!`:6YC
M;'5D95]O;F-E("=014%2+T-O;6UA;F0O4&%C:V%G:6YG+G!H<"<[#0H@("`@
M("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("AC;&%S<U]E>&ES=',H)U!%
M05)?0V]M;6%N9%]086-K86=I;F<G*2D@>PT*("`@("`@("`@("`@)&$@/2`F
M;F5W(%!%05)?0V]M;6%N9%]086-K86=I;F<H)'5I+"`D8V]N9FEG*3L-"B`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1A(#T@;G5L;#L-"B`@("`@
M("`@?0T*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@>WM[
M(&1O36%K95)032@I#0H-"B`@("!F=6YC=&EO;B!D;TUA:V524$TH)&-O;6UA
M;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@<F5Q=6ER
M95]O;F-E("=3>7-T96TN<&AP)SL-"B`@("`@("`@<F5Q=6ER95]O;F-E("=!
M<F-H:79E+U1A<BYP:'`G.PT*#0H@("`@("`@("\O($-H96-K('1O('-E92!I
M9B!014%27T-O;6UA;F1?4&%C:V%G:6YG(&ES(&EN<W1A;&QE9"P@86YD#0H@
M("`@("`@("\O('1R86YS<&%R96YT;'D@<W=I=&-H('1O('5S92!T:&4@(FUA
M:V4M<G!M+7-P96,B(&-O;6UA;F0@9G)O;2!I=`T*("`@("`@("`O+R!I;G-T
M96%D+"!I9B!I="!D;V5S+B!/=&AE<G=I<V4L(&-O;G1I;G5E('1O('5S92!T
M:&4@;VQD('9E<G-I;VX-"B`@("`@("`@+R\@;V8@(FUA:V5R<&TB('-U<'!L
M:65D('=I=&@@=&AI<R!P86-K86=E("A014%2*2X-"B`@("`@("`@)'!A8VMA
M9VEN9U]C;60@/2`D=&AI<RT^9V5T0V]M;6%N9%!A8VMA9VEN9R@D=&AI<RT^
M=6DL("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!I9B`H)'!A8VMA9VEN9U]C
M;60@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T
M1&%T82@G4$5!4E]#;VUM86YD7U!A8VMA9VEN9R!I<R!I;G-T86QL960[('5S
M:6YG("<N#0H@("`@("`@("`@("`@("`@)VYE=V5R(")M86ME+7)P;2US<&5C
M(B!C;VUM86YD(&EN<W1E860G*3L-"B`@("`@("`@("`@(')E='5R;B`D<&%C
M:V%G:6YG7V-M9"T^<G5N*"=M86ME+7)P;2US<&5C)RP@)&]P=&EO;G,L("1P
M87)A;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"=705).24Y'.B`B<&5A<B!M86ME<G!M(B!I<R!N
M;W<@9&5P<F5C871E9#L@86X@)RX-"B`@("`@("`@("`@("`@)VEM<')O=F5D
M('9E<G-I;VX@:7,@879A:6QA8FQE('9I82`B<&5A<B!M86ME+7)P;2US<&5C
M(BP@=VAI8V@@)RX-"B`@("`@("`@("`@("`@)VES(&%V86EL86)L92!B>2!I
M;G-T86QL:6YG(%!%05)?0V]M;6%N9%]086-K86=I;F<G*3L-"B`@("`@("`@
M?0T*("`@("`@("`-"B`@("`@("`@:68@*'-I>F5O9B@D<&%R86US*2`A/2`Q
M*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F)A
M9"!P87)A;65T97(H<RDL('1R>2!<(FAE;'`@)&-O;6UA;F1<(B(I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A9FEL95]E>&ES=',H)'!A<F%M<ULP72DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B9FEL
M92!D;V5S(&YO="!E>&ES=#H@)'!A<F%M<ULP72(I.PT*("`@("`@("!]#0H@
M("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-
M"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M
M/F-O;F9I9RP@)'1H:7,M/E]D96)U9RD[#0H@("`@("`@("1P9B`]("8D<&MG
M+3YF<F]M06YY1FEL92@D<&%R86US6S!=+"!014%27U9!3$E$051%7TY/4DU!
M3"D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@
M("`@("`@("1U(#T@)'!F+3YG9715<V5R:6YF;R@I.PT*("`@("`@("`@("`@
M:68@*&ES7V%R<F%Y*"1U*2D@>PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1U(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1E<G(I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D97)R(#T@
M)&5R<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D97)R*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(B1P87)A;7-;,%T@:7,@;F]T
M(&$@=F%L:60@<&%C:V%G92(I.PT*("`@("`@("!]#0H@("`@("`@("1T;7!D
M:7(@/2!3>7-T96TZ.FUK=&5M<"AA<G)A>2@G+60G+"`G<&5A<C)R<&TG*2D[
M#0H@("`@("`@("1I;G-T<F]O="`](%-Y<W1E;3HZ;6MT96UP*&%R<F%Y*"<M
M9"<L("=P96%R,G)P;2<I*3L-"B`@("`@("`@)'1M<"`]("1T:&ES+3YC;VYF
M:6<M/F=E="@G=F5R8F]S92<I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS
M970H)W9E<F)O<V4G+"`P*3L-"B`@("`@("`@)&EN<W1A;&QE<B`]("1T:&ES
M+3YG971);G-T86QL97(H)'1H:7,M/G5I*3L-"B`@("`@("`@<F5Q=6ER95]O
M;F-E("=014%2+T1O=VYL;V%D97(O4&%C:V%G92YP:'`G.PT*("`@("`@("`D
M<&%C:R`](&YE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D:6YS=&%L;&5R
M*3L-"B`@("`@("`@)'!A8VLM/G-E=%!A8VMA9V5&:6QE*"1P9BD[#0H@("`@
M("`@("1P87)A;7-;,%T@/2`F)'!A8VL[#0H@("`@("`@("1I;G-T86QL97(M
M/G-E=$]P=&EO;G,H87)R87DH)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O;W0L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M;F]D97!S)R`]/B!T<G5E+"`G<V]F="<@/3X@=')U92DI.PT*("`@("`@("`D
M:6YS=&%L;&5R+3YS971$;W=N;&]A9&5D4&%C:V%G97,H)'!A<F%M<RD[#0H@
M("`@("`@("1I;F9O(#T@)&EN<W1A;&QE<BT^:6YS=&%L;"@D<&%R86US6S!=
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)VEN<W1A;&QR;V]T)R`]/B`D:6YS=')O;W0L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G;F]D97!S)R`]/B!T<G5E+"`G
M<V]F="<@/3X@=')U92DI.PT*("`@("`@("`D<&MG9&ER(#T@)'!F+3YG9710
M86-K86=E*"D@+B`G+2<@+B`D<&8M/F=E=%9E<G-I;VXH*3L-"B`@("`@("`@
M)&EN9F];)W)P;5]X;6Q?9&ER)UT@/2`G+W9A<B]L:6(O<&5A<B<[#0H@("`@
M("`@("1T:&ES+3YC;VYF:6<M/G-E="@G=F5R8F]S92<L("1T;7`I.PT*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W-P96,M=&5M<&QA=&4G72DI('L-
M"B`@("`@("`@("`@("1S<&5C7W1E;7!L871E(#T@)&]P=&EO;G-;)W-P96,M
M=&5M<&QA=&4G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1S
M<&5C7W1E;7!L871E(#T@)R]U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1A=&$O4$5!4B]T96UP;&%T92YS<&5C)SL-"B`@("`@("`@?0T*("`@("`@
M("`D:6YF;ULG<&]S<VEB;&5?8VAA;FYE;"==(#T@)R<[#0H@("`@("`@("1I
M;F9O6R=E>'1R85]C;VYF:6<G72`]("<G.PT*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W)P;2UP:V=N86UE)UTI*2![#0H@("`@("`@("`@("`D<G!M
M7W!K9VYA;65?9F]R;6%T(#T@)&]P=&EO;G-;)W)P;2UP:V=N86UE)UT[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("!I9B`H)'!F+3YG971#:&%N
M;F5L*"D@/3T@)W!E87(N<&AP+FYE="<@?'P@)'!F+3YG971#:&%N;F5L*"D@
M/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`D86QI87,@
M/2`G4$5!4B<[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("1C:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)'!F+3YG971#:&%N;F5L
M*"DI.PT*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&-H86XI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D86QI87,@/2`D8VAA;BT^9V5T06QI87,H*3L-"B`@("`@("`@("`@
M("`@("`D86QI87,@/2!S=')T;W5P<&5R*"1A;&EA<RD[#0H@("`@("`@("`@
M("`@("`@)&EN9F];)W!O<W-I8FQE7V-H86YN96PG72`]("1P9BT^9V5T0VAA
M;FYE;"@I("X@)R\G.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)')P
M;5]P:V=N86UE7V9O<FUA="`]("1A;&EA<R`N("<Z.B5S)SL-"B`@("`@("`@
M?0T*#0H@("`@("`@("1I;F9O6R=E>'1R85]H96%D97)S)UT@/2`G)SL-"B`@
M("`@("`@)&EN9F];)V1O8U]F:6QE<R==(#T@)R<[#0H@("`@("`@("1I;F9O
M6R=F:6QE<R==(#T@)R<[#0H@("`@("`@("1I;F9O6R=P86-K86=E,GAM;"==
M(#T@)R<[#0H@("`@("`@("1I;F9O6R=R<&U?<&%C:V%G92==(#T@<W!R:6YT
M9B@D<G!M7W!K9VYA;65?9F]R;6%T+"`D<&8M/F=E=%!A8VMA9V4H*2D[#0H@
M("`@("`@("1S<F-F:6QE<R`](#`[#0H@("`@("`@(&9O<F5A8V@@*"1I;F9O
M6R=F:6QE;&ES="==(&%S("1N86UE(#T^("1A='1R*2![#0H@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1A='1R6R=R;VQE)UTI*2![#0H@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D;F%M
M92`]('!R96=?<F5P;&%C92@G(5LO.EQ<7%Q=(2<L("<O)RP@)&YA;64I.PT*
M("`@("`@("`@("`@:68@*"1A='1R6R=R;VQE)UT@/3T@)V1O8R<I('L-"B`@
M("`@("`@("`@("`@("`D:6YF;ULG9&]C7V9I;&5S)UT@+CT@(B`D;F%M92([
M#0H@("`@("`@("`@("`O+R!-87`@<F]L92!T;R!T:&4@<G!M('9A<G,-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)&-?<')E9FEX
M(#T@)R5[7VQI8F1I<GTO<&AP+W!E87(G.PT*("`@("`@("`@("`@("`@('-W
M:71C:"`H)&%T=');)W)O;&4G72D@>PT*("`@("`@("`@("`@("`@("`@("!C
M87-E("=P:'`G.@T*("`@("`@("`@("`@("`@("`@("`@("`@)'!R969I>"`]
M("1C7W!R969I>#L-"B`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)V5X="<Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D<')E9FEX(#T@)R5[7VQI8F1I<GTO<&AP)SL-"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L[("\O(%A86"!G;V]D('!L86-E/PT*("`@("`@
M("`@("`@("`@("`@("!C87-E("=S<F,G.@T*("`@("`@("`@("`@("`@("`@
M("`@("`@)'-R8V9I;&5S*RL[#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<')E9FEX(#T@)R5[7VEN8VQU9&5D:7)]+W!H<"<[#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.R`O+R!86%@@9V]O9"!P;&%C93\-"B`@("`@("`@("`@
M("`@("`@("`@8V%S92`G=&5S="<Z#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<')E9FEX(#T@(B1C7W!R969I>"]T97-T<R\B("X@)'!F+3YG971086-K
M86=E*"D[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@
M("`@("`@("`@("!C87-E("=D871A)SH-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1P<F5F:7@@/2`B)&-?<')E9FEX+V1A=&$O(B`N("1P9BT^9V5T4&%C
M:V%G92@I.PT*("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@
M("`@("`@("`@("`@8V%S92`G<V-R:7!T)SH-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F5F:7@@/2`G)7M?8FEN9&ER?2<[#0H@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("`@("`@("`@("`@("!D969A=6QT.B`O
M+R!N;VXM<W1A;F1A<F0@<F]L97,-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F5F:7@@/2`B)&-?<')E9FEX+R1A='1R6W)O;&5=+R(@+B`D<&8M/F=E
M=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=E
M>'1R85]C;VYF:6<G72`N/0T*("`@("`@("`@("`@("`@("`@("`@("`@(EQN
M("`@("`@("`M9"![)&%T=');<F]L95U]7V1I<CTD8U]P<F5F:7@O>R1A='1R
M6W)O;&5=?2!<7"([#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(')O;&4@(B<@+B`D871T<ELG<F]L
M92==("X@)R(@=7-E9"P@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V%N9"!W:6QL(&)E(&EN<W1A;&QE9"!I;B`B)R`N("1C7W!R969I>"`N
M("<O)R`N("1A='1R6R=R;VQE)UT@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("<O)R`N("1P9BT^9V5T4&%C:V%G92@I("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G("T@:&%N9"UE9&ET('1H92!F:6YA;"`N<W!E
M8R!I9B!T:&ES(&ES('=R;VYG)RP@)&-O;6UA;F0I.PT*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&YA;64@/2!S=')?<F5P;&%C92@G7%PG+"`G+R<L("1N86UE*3L-
M"B`@("`@("`@("`@("`@("`D:6YF;ULG9FEL97,G72`N/2`B)'!R969I>"\D
M;F%M95QN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H)'-R8V9I;&5S(#X@,"D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E
M("=/4R]'=65S<RYP:'`G.PT*("`@("`@("`@("`@)&]S(#T@;F5W($]37T=U
M97-S.PT*("`@("`@("`@("`@)&%R8V@@/2`D;W,M/F=E=$-P=2@I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&%R8V@@/2`G;F]A<F-H)SL-
M"B`@("`@("`@?0T*("`@("`@("`D8V9G(#T@87)R87DH)VUA<W1E<E]S97)V
M97(G+"`G<&AP7V1I<B<L("=E>'1?9&ER)RP@)V1O8U]D:7(G+`T*("`@("`@
M("`@("`@("`@("`@("`@)V)I;E]D:7(G+"`G9&%T85]D:7(G+"`G=&5S=%]D
M:7(G*3L-"B`@("`@("`@9F]R96%C:"`H)&-F9R!A<R`D:RD@>PT*("`@("`@
M("`@("`@:68@*"1K(#T]("=M87-T97)?<V5R=F5R)RD@>PT*("`@("`@("`@
M("`@("`@("1C:&%N(#T@)')E9RT^9V5T0VAA;FYE;"@D<&8M/F=E=$-H86YN
M96PH*2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&-H
M86XI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("1I;F9O6R1K72`]("1C:&%N+3YG971397)V97(H*3L-"B`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1I;F9O6R1K72`]("1T:&ES+3YC;VYF:6<M/F=E="@D:RD[#0H@("`@
M("`@('T-"B`@("`@("`@)&EN9F];)V%R8V@G72`]("1A<F-H.PT*("`@("`@
M("`D9G`@/2!`9F]P96XH)'-P96-?=&5M<&QA=&4L(")R(BD[#0H@("`@("`@
M(&EF("@A)&9P*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F-O=6QD(&YO="!O<&5N(%)032!S<&5C(&9I;&4@=&5M<&QA=&4@
M)'-P96-?=&5M<&QA=&4Z("1P:'!?97)R;W)M<V<B*3L-"B`@("`@("`@?0T*
M("`@("`@("`D:6YF;ULG<&%C:V%G92==(#T@)'!F+3YG971086-K86=E*"D[
M#0H@("`@("`@("1I;F9O6R=V97)S:6]N)UT@/2`D<&8M/F=E=%9E<G-I;VXH
M*3L-"B`@("`@("`@)&EN9F];)W)E;&5A<V5?;&EC96YS92==(#T@)'!F+3YG
M971,:6-E;G-E*"D[#0H@("`@("`@(&EF("@D<&8M/F=E=$1E<',H*2D@>PT*
M("`@("`@("`@("`@:68@*"1P9BT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]
M/2`G,2XP)RD@>PT*("`@("`@("`@("`@("`@("1R97%U:7)E<R`]("1C;VYF
M;&EC=',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P
M9BT^9V5T1&5P<R@I(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P=&EO;F%L
M)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I
M;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D9&5P6R=T>7!E)UT@(3T@)W!K9R<I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=C:&%N;F5L
M)UTI("8F("1D97!;)V-H86YN96PG72`A/2`G<&5A<BYP:'`N;F5T)R`F)@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P6R=C:&%N;F5L)UT@(3T@
M)W!E8VPN<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C
M:&%N(#T@)B1R96<M/F=E=$-H86YN96PH)&1E<%LG8VAA;FYE;"==*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G92`]('-T<G1O
M=7!P97(H)&-H86XM/F=E=$%L:6%S*"DI("X@)SHZ)R`N("1D97!;)VYA;64G
M73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("1P86-K86=E(#T@)U!%05(Z.B<@+B`D9&5P6R=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@)'1R86YS(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@("`G
M/B<@/3X@)SXG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)SPG(#T^("<\
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("<^/2<@/3X@)SX])RP-"B`@
M("`@("`@("`@("`@("`@("`@("`@("<\/2<@/3X@)SP])RP-"B`@("`@("`@
M("`@("`@("`@("`@("`@("<])R`]/B`G/2<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`G9W0G(#T^("<^)RP-"B`@("`@("`@("`@("`@("`@("`@("`@
M("=L="<@/3X@)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V=E)R`]
M/B`G/CTG+`T*("`@("`@("`@("`@("`@("`@("`@("`@)VQE)R`]/B`G/#TG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@)V5Q)R`]/B`G/2<L#0H@("`@
M("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@("`@("`@("`@(&EF("@D
M9&5P6R=R96PG72`]/2`G:&%S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<75I<F5S6UT@/2`D<&%C:V%G93L-"B`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E:68@*"1D97!;)W)E;"==(#T]("=N;W0G*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G93L-"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D97!;)W)E;"==(#T]("=N
M92<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1C;VYF;&EC='-;72`]
M("1P86-K86=E("X@)R`]("<@+B`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D=')A;G-;)&1E<%LG<F5L
M)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)')E<75I<F5S6UT@
M/2`D<&%C:V%G92`N("<@)R`N("1T<F%N<ULD9&5P6R=R96PG75T@+B`G("<@
M+B`D9&5P6R=V97)S:6]N)UT[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1R
M97%U:7)E<RDI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)V5X=')A
M7VAE861E<G,G72`N/2`G4F5Q=6ER97,Z("<@+B!I;7!L;V1E*"<L("<L("1R
M97%U:7)E<RD@+B`B7&XB.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!I9B`H8V]U;G0H)&-O;F9L:6-T<RDI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N/2`G0V]N9FQI8W1S
M.B`G("X@:6UP;&]D92@G+"`G+"`D8V]N9FQI8W1S*2`N(")<;B([#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<R)SL@+R\@=&5L;"!T
M:&4@<W!E8R!T;R!U<V4@<&%C:V%G93(N>&UL#0H@("`@("`@("`@("`@("`@
M)')E<75I<F5S(#T@)&-O;F9L:6-T<R`](&%R<F%Y*"D[#0H@("`@("`@("`@
M("`@("`@)&1E<',@/2`D<&8M/F=E=$1E<',H=')U92D[#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)W)E
M<75I<F5D)UU;)W!A8VMA9V4G75LP72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P86-K86=E)UT@/2!A<G)A>2@D
M9&5P<ULG<F5Q=6ER960G75LG<&%C:V%G92==*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D9&5P<ULG
M<F5Q=6ER960G75LG<&%C:V%G92==(&%S("1D97`I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@(3T@)W!E87(N<&AP
M+FYE="<@)B8@("1D97!;)V-H86YN96PG72`A/2`G<&5C;"YP:'`N;F5T)RD@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@)B1R96<M
M/F=E=$-H86YN96PH)&1E<%LG8VAA;FYE;"==*3L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*"1C:&%N*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2!S
M=')T;W5P<&5R*"1C:&%N+3YG971!;&EA<R@I*2`N("<Z.B<@+B`D9&5P6R=N
M86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E(#T@)U!%05(Z.B<@
M+B`D9&5P6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI("8F("AI<W-E="@D9&5P6R=M:6XG72D@?'P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&ES<V5T*"1D97!;)VUA>"==*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V4@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P
M6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&1E<')A;F=E6UT@/2!A<G)A>2@D9&5P6R=M:6XG72PG/CTG*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;72`](&%R<F%Y*"1D
M97!;)VUA>"==+"`G/#TG*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<U]A<G)A>2@D9&5P6R=E>&-L=61E)UTI('Q\#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<W-E="@D9&5P
M6R=E>&-L=61E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5P6R=E>&-L=61E)UT@/2!A<G)A>2@D9&5P6R=E>&-L
M=61E)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D9&5P
M<F%N9V4I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97AC;"`]("1D97!;)V5X8VQU9&4G73L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(&-H86YG92`^/2!T;R`^(&EF(&5X8VQU
M9&EN9R!T:&4@;6EN('9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&-H86YG92`\/2!T;R`\(&EF(&5X8VQU9&EN9R!T
M:&4@;6%X('9E<G-I;VX-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&9O<B@D:2`](#`[("1I(#P@8V]U;G0H)&5X8VPI.R`D:2LK*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!R86YG95LP72D@)B8-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D97AC;%LD:5T@/3T@)&1E<')A
M;F=E6S!=6S!=*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D97!R86YG95LP75LQ72`]("<\)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&1E
M<%LG97AC;'5D92==6R1I72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<F%N9V5;,5TI("8F#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5X
M8VQ;)&E=(#T]("1D97!R86YG95LQ75LP72D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&5P<F%N9V5;,5U;,5T@
M/2`G/B<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1D97!;)V5X8VQU9&4G75LD:5TI.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H8V]U;G0H)&1E<%LG97AC;'5D92==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG97AC;'5D92==(#T@
M87)R87E?=F%L=65S*"1D97!;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&5P<F%N9V4@/2!A<G)A>2@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<F5M
M;W9E(&5X8VQU9&5S('1H870@87)E(&]U='-I9&4@=&AE(&5X:7-T:6YG(')A
M;F=E#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"!C;W5N="@D9&5P6R=E>&-L=61E)UTI.R`D:2LK*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*"1D97!;)V5X8VQU9&4G75LD:5T@/"`D9&5P6R=M:6XG72!\?`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97!;
M)V5X8VQU9&4G75LD:5T@/B`D9&5P6R=M87@G72D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D9&5P6R=E
M>&-L=61E)UU;)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9&5P6R=E>&-L=61E)UT@/2!A<G)A>5]V86QU97,H)&1E<%LG97AC;'5D92==
M*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('5S;W)T
M*"1D97!;)V5X8VQU9&4G72P@)W9E<G-I;VY?8V]M<&%R92<I.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&%K92!T:&4@<F5M
M86EN:6YG(&5X8VQU9&5S(&%N9`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@<W!L:70@=&AE(&1E<&5N9&5N8WD@:6YT;R!S=6(M
M<F%N9V5S#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;&%S=&UI;B`]("1D97!R86YG95LP73L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1D97!;
M)V5X8VQU9&4G72D@+2`Q.R`D:2LK*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YE=V1E<')A;F=E6UT@/2`G*"<@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%C:V%G92`N("(@>R1L87-T;6EN6S%=?2![)&QA<W1M:6Y;,%U](&%N9"`B
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A8VMA9V4@+B`G(#P@)R`N("1D97!;)V5X8VQU9&4G75LD:5T@+B`G
M*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&QA<W1M:6X@/2!A<G)A>2@D9&5P6R=E>&-L=61E)UU;)&E=+"`G/B<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1N97=D97!R86YG95M=(#T@)R@G("X@)'!A8VMA9V4@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B('LD
M;&%S=&UI;ELQ77T@>R1L87-T;6EN6S!=?2!A;F0@(B`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E("X@
M)R`\("<@+B`D9&5P6R=M87@G72`N("<I)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;VYF;&EC='-;72`](&EM<&QO9&4H)R!O<B`G+"`D
M9&5P<F%N9V4I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&-O;F9L:6-T<UM=(#T@)'!A8VMA9V4@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("(@>R1D97!R86YG95LP75LQ77T@>R1D
M97!R86YG95LP75LP77TB("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`H:7-S970H)&1E<')A;F=E6S%=*2`_(`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("(@86YD("1P86-K
M86=E('LD9&5P<F%N9V5;,5U;,5U]('LD9&5P<F%N9V5;,5U;,%U](@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@)R<I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=M:6XG72D@
M)B8@(6ES<V5T*"1D97!;)VUA>"==*2`F)@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(6ES<V5T*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG8V]N9FQI
M8W1S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C
M;VYF;&EC='-;72`]("1P86-K86=E.PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97%U:7)E<UM=(#T@)'!A8VMA9V4[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E
M<%LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1R97%U:7)E<UM=(#T@)'!A8VMA9V4@+B`G(#X]("<@+B`D9&5P6R=M:6XG
M73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUA>"==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5Q=6ER97-;72`]
M("1P86-K86=E("X@)R`\/2`G("X@)&1E<%LG;6%X)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1E>"`]("1D97!;)V5X8VQU9&4G73L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D97@I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97@@/2!A<G)A>2@D97@I.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O
M<F5A8V@@*"1E>"!A<R`D=F5R*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]N9FQI8W1S6UT@/2`D<&%C:V%G92`N("<@/2`G
M("X@)'9E<CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)T%R8VAI=F4O5&%R+G!H<"<[#0H@
M("`@("`@("`@("`@("`@("`@("1T87(@/2!N97<@07)C:&EV95]487(H)'!F
M+3YG971!<F-H:79E1FEL92@I*3L-"B`@("`@("`@("`@("`@("`@("`@)'1A
M<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@("`@("`@("`D82`]("1T87(M/F5X=')A8W1);E-T<FEN9R@G
M<&%C:V%G93(N>&UL)RD[#0H@("`@("`@("`@("`@("`@("`@("1T87(M/G!O
M<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1A
M(#T]/2!N=6QL('Q\(%!%05(Z.FES17)R;W(H)&$I*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG<&%C:V%G93)X;6PG72`]("<G.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@=&AI<R!D;V5S;B=T(&AA=F4@82!P
M86-K86=E+GAM;"!V97)S:6]N(#$N,`T*("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<75I<F5S6UT@/2`G4$5!4CHZ4$5!4B`^/2`G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN
M<W1A;&QE<B==6R=M:6XG73L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H)')E<75I<F5S*2D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N
M/2`G4F5Q=6ER97,Z("<@+B!I;7!L;V1E*"<L("<L("1R97%U:7)E<RD@+B`B
M7&XB.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@(&EF("AC;W5N="@D8V]N9FQI8W1S*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G72`N/2`G0V]N9FQI8W1S
M.B`G("X@:6UP;&]D92@G+"`G+"`D8V]N9FQI8W1S*2`N(")<;B([#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R!R96UO=F4@=&AE('1R
M86EL:6YG(&YE=VQI;F4-"B`@("`@("`@)&EN9F];)V5X=')A7VAE861E<G,G
M72`]('1R:6TH)&EN9F];)V5X=')A7VAE861E<G,G72D[#0H@("`@("`@(&EF
M("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?9V5T7V-O;G1E;G1S)RDI('L-"B`@
M("`@("`@("`@(&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@)'-P96-?8V]N
M=&5N=',@/2!P<F5G7W)E<&QA8V4H)R]`*%MA+7HP+3E?+5TK*4`O92<L("<D
M:6YF;ULB7#$B72<L#0H@("`@("`@("`@("`@("`@9FEL95]G971?8V]N=&5N
M=',H)'-P96-?=&5M<&QA=&4I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1S<&5C7V-O;G1E;G1S(#T@<')E9U]R97!L86-E*"<O0"A;82UZ
M,"TY7RU=*RE`+V4G+"`G)&EN9F];(EPQ(ETG+`T*("`@("`@("`@("`@("`@
M(&9R96%D*"1F<"P@9FEL97-I>F4H)'-P96-?=&5M<&QA=&4I*2D[#0H@("`@
M("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@?0T*("`@("`@("`D<W!E
M8U]F:6QE(#T@(B1I;F9O6W)P;5]P86-K86=E72TD:6YF;UMV97)S:6]N72YS
M<&5C(CL-"B`@("`@("`@)'=P(#T@9F]P96XH)'-P96-?9FEL92P@(G=B(BD[
M#0H@("`@("`@(&EF("@A)'=P*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H(F-O=6QD(&YO="!W<FET92!24$T@<W!E8R!F:6QE
M("1S<&5C7V9I;&4Z("1P:'!?97)R;W)M<V<B*3L-"B`@("`@("`@?0T*("`@
M("`@("!F=W)I=&4H)'=P+"`D<W!E8U]C;VYT96YT<RD[#0H@("`@("`@(&9C
M;&]S92@D=W`I.PT*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(E=R
M;W1E(%)032!S<&5C(&9I;&4@)'-P96-?9FEL92(L("1C;VUM86YD*3L-"@T*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!D
M;T-O;G9E<G0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@)'!A8VMA9V5X;6P@/2!I<W-E="@D<&%R86US6S!=*2`_("1P
M87)A;7-;,%T@.B`G<&%C:V%G92YX;6PG.PT*("`@("`@("`D;F5W<&%C:V%G
M97AM;"`](&ES<V5T*"1P87)A;7-;,5TI(#\@)'!A<F%M<ULQ72`Z(&1I<FYA
M;64H)'!A8VMA9V5X;6PI("X-"B`@("`@("`@("`@($1)4D5#5$]265]315!!
M4D%43U(@+B`G<&%C:V%G93(N>&UL)SL-"B`@("`@("`@)'!K9R`]("8D=&AI
M<RT^9V5T4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]D96)U
M9RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@)'!F(#T@)'!K9RT^9G)O;5!A
M8VMA9V5&:6QE*"1P86-K86=E>&UL+"!014%27U9!3$E$051%7TY/4DU!3"D[
M#0H@("`@("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@:68@*"%014%2.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@
M(&EF("AI<U]A*"1P9BP@)U!%05)?4&%C:V%G949I;&5?=C(G*2D@>PT*("`@
M("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D<&%C:V%G97AM
M;"`N("<@:7,@86QR96%D>2!A('!A8VMA9V4N>&UL('9E<G-I;VX@,BXP)RD[
M#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`D9V5N(#T@)B1P9BT^9V5T1&5F875L=$=E;F5R871O
M<B@I.PT*("`@("`@("`@("`@)&YE=W!F(#T@)B1G96XM/G1O5C(H*3L-"B`@
M("`@("`@("`@("1N97=P9BT^<V5T4&%C:V%G969I;&4H)&YE=W!A8VMA9V5X
M;6PI.PT*("`@("`@("`@("`@)&=E;B`]("8D;F5W<&8M/F=E=$1E9F%U;'1'
M96YE<F%T;W(H*3L-"B`@("`@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@("`@("1S
M=&%T92`]("AI<W-E="@D;W!T:6]N<ULG9FQA="==*2`_(%!%05)?5D%,241!
M5$5?4$%#2T%'24Y'(#H@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("`@("`@)'-A=F5D(#T@)&=E;BT^=&]086-K86=E1FEL92AD:7)N86UE*"1N
M97=P86-K86=E>&UL*2P@)'-T871E+`T*("`@("`@("`@("`@("`@(&)A<V5N
M86UE*"1N97=P86-K86=E>&UL*2D[#0H@("`@("`@("`@("!014%2.CIS=&%T
M:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D<V%V960I*2![#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1S879E9"T^9V5T57-E<DEN9F\H*2DI('L-"B`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)'-A=F5D+3YG9715<V5R26YF;R@I(&%S("1W87)N
M:6YG*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=6DM/F]U
M='!U=$1A=&$H)'=A<FYI;F=;)VUE<W-A9V4G72D[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1S879E9"T^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5W)O=&4@;F5W
M('9E<G-I;VX@,BXP('!A8VMA9V4N>&UL('1O("(G("X@)'-A=F5D("X@)R(G
M*3L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P9BT^9V5T57-E<DEN9F\H
M*2DI('L-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<&8M/F=E=%5S97))
M;F9O*"D@87,@)'=A<FYI;F<I('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"1W87)N:6YG6R=M97-S86=E)UTI.PT*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<&8I.PT*("`@("`@("!]#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0I]#0H-"C\^#0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD
M+U!I8VML92YX;6P`````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C<V,R`Q,#4Q-30S-#$S-"`P,C(U,S``(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^
M#0H@/'!I8VML93X-"B`@/'-U;6UA<GD^0G5I;&0@4$5#3"!086-K86=E/"]S
M=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]086-K86=E/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/G!I/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^#0H@("`\;F]C
M;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^#0H@("`@/&1O
M8SY$;R!N;W0@9WII<"!T:&4@<&%C:V%G92!F:6QE/"]D;V,^#0H@("`\+VYO
M8V]M<')E<W,^#0H@("`\<VAO=VYA;64^#0H@("`@/'-H;W)T;W!T/FX\+W-H
M;W)T;W!T/@T*("`@(#QD;V,^4')I;G0@=&AE(&YA;64@;V8@=&AE('!A8VMA
M9V5D(&9I;&4N/"]D;V,^#0H@("`\+W-H;W=N86UE/@T*("`\+V]P=&EO;G,^
M#0H@(#QD;V,^6V1E<V-F:6QE72!;9&5S8V9I;&4R70T*0W)E871E<R!A(%!%
M0TP@<&%C:V%G92!F<F]M(&ET<R!D97-C<FEP=&EO;B!F:6QE("AU<W5A;&QY
M(&-A;&QE9`T*<&%C:V%G92YX;6PI+B`@268@82!S96-O;F0@<&%C:V%G969I
M;&4@:7,@<&%S<V5D(&EN+"!T:&5N#0IT:&4@<&%C:V%G97(@=VEL;"!C:&5C
M:R!T;R!M86ME('-U<F4@=&AA="!O;F4@:7,@82!P86-K86=E+GAM;`T*=F5R
M<VEO;B`Q+C`L(&%N9"!T:&4@;W1H97(@:7,@82!P86-K86=E+GAM;"!V97)S
M:6]N(#(N,"X@(%1H90T*<&%C:V%G92YX;6P@=F5R<VEO;B`Q+C`@=VEL;"!B
M92!S879E9"!A<R`F<75O=#MP86-K86=E+GAM;"9Q=6]T.R!I;B!T:&4@87)C
M:&EV92P-"F%N9"!T:&4@;W1H97(@87,@)G%U;W0[<&%C:V%G93(N>&UL)G%U
M;W0[(&EN('1H92!A<F-H:79E)G%U;W0[#0H-"DEF(&YO('-E8V]N9"!F:6QE
M(&ES('!A<W-E9"!I;BP@86YD(%MD97-C9FEL95T@:7,@82!P86-K86=E+GAM
M;"`R+C`L#0IA;B!A=71O;6%T:6,@8V]N=F5R<VEO;B!W:6QL(&)E(&UA9&4@
M=&\@82!P86-K86=E+GAM;"`Q+C`N("!.;W1E('1H870-"F]N;'D@<VEM<&QE
M('!A8VMA9V4N>&UL(#(N,"!W:6QL(&)E(&-O;G9E<G1E9"X@('!A8VMA9V4N
M>&UL(#(N,"!W:71H.@T*#0H@+2!D97!E;F1E;F-Y('1Y<&5S(&]T:&5R('1H
M86X@<F5Q=6ER960O;W!T:6]N86P@4$5#3"!P86-K86=E+V5X="]P:'`O<&5A
M<FEN<W1A;&QE<@T*("T@;6]R92!T:&%N(&]N92!E>'1S<F-R96QE87-E#0H@
M+2!E>'1B:6YR96QE87-E+"!P:'!R96QE87-E+"!O<B!B=6YD;&4@<F5L96%S
M92!T>7!E#0H@+2!D97!E;F1E;F-Y(&=R;W5P<PT*("T@:6=N;W)E('1A9W,@
M:6X@<F5L96%S92!F:6QE;&ES=`T*("T@=&%S:W,@;W1H97(@=&AA;B!R97!L
M86-E#0H@+2!C=7-T;VT@<F]L97,-"@T*=VEL;"!C875S92!P:6-K;&4@=&\@
M9F%I;"P@86YD(&]U='!U="!A;B!E<G)O<B!M97-S86=E+B`@268@>6]U<B!P
M86-K86=E,BYX;6P-"G5S97,@86YY(&]F('1H97-E(&9E871U<F5S+"!Y;W4@
M87)E(&)E<W0@;V9F('5S:6YG(%!%05)?4&%C:V%G949I;&5-86YA9V5R('1O
M#0IG96YE<F%T92!B;W1H('!A8VMA9V4N>&UL+CPO9&]C/@T*(#PO<&EC:VQE
M/@T*/"]C;VUM86YD<SX`````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4&EC:VQE+G!H<```````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0P,#8R(#$P-3$U-#,T,3,T(#`R,C4Q
M,0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?4&EC:VQE("AP:6-K;&4@8V]M
M;6%N9"D-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)
M0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0
M($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-
M"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2
M#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^
M#0H@*B!`8V]P>7)I9VAT("`R,#`U+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M4&EC:VQE+G!H<"QV(#$N-2`R,#`V+S`Q+S`V(#`T.C0W.C,V(&-E;&QO9R!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XT+C$-"B`J+PT*#0HO*BH-"B`J(&)A<V4@8VQA<W,-"B`J
M+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M;6]N+G!H<"<[#0H-
M"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,C`P-2TR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,0T*("HO#0H-"F-L87-S(%!%05)?0V]M;6%N9%]0:6-K;&4@
M97AT96YD<R!014%27T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@=F%R("1C;VUM
M86YD<R`](&%R<F%Y*`T*("`@("`@("`G<&EC:VQE)R`]/B!A<G)A>2@-"B`@
M("`@("`@("`@("=S=6UM87)Y)R`]/B`G0G5I;&0@4$5#3"!086-K86=E)RP-
M"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O4&%C:V%G92<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=P:2<L#0H@("`@("`@("`@("`G;W!T
M:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@)VYO8V]M<')E<W,G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=:)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)T1O(&YO="!G
M>FEP('1H92!P86-K86=E(&9I;&4G#0H@("`@("`@("`@("`@("`@("`@("DL
M#0H@("`@("`@("`@("`@("`@)W-H;W=N86UE)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G;B<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=0<FEN="!T:&4@;F%M92!O9B!T:&4@<&%C
M:V%G960@9FEL92XG+`T*("`@("`@("`@("`@("`@("`@("`I+`T*("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G6V1E<V-F:6QE
M70T*0W)E871E<R!A(%!%0TP@<&%C:V%G92!F<F]M(&ET<R!P86-K86=E,BYX
M;6P@9FEL92X-"@T*06X@875T;VUA=&EC(&-O;G9E<G-I;VX@=VEL;"!B92!M
M861E('1O(&$@<&%C:V%G92YX;6P@,2XP(&%N9"!W<FET=&5N(&]U="!T;PT*
M9&ES:R!I;B!T:&4@8W5R<F5N="!D:7)E8W1O<GD@87,@(G!A8VMA9V4N>&UL
M(BX@($YO=&4@=&AA=`T*;VYL>2!S:6UP;&4@<&%C:V%G92YX;6P@,BXP('=I
M;&P@8F4@8V]N=F5R=&5D+B`@<&%C:V%G92YX;6P@,BXP('=I=&@Z#0H-"B`M
M(&1E<&5N9&5N8WD@='EP97,@;W1H97(@=&AA;B!R97%U:7)E9"]O<'1I;VYA
M;"!014-,('!A8VMA9V4O97AT+W!H<"]P96%R:6YS=&%L;&5R#0H@+2!M;W)E
M('1H86X@;VYE(&5X='-R8W)E;&5A<V4-"B`M(&5X=&)I;G)E;&5A<V4L('!H
M<')E;&5A<V4L(&]R(&)U;F1L92!R96QE87-E('1Y<&4-"B`M(&1E<&5N9&5N
M8WD@9W)O=7!S#0H@+2!I9VYO<F4@=&%G<R!I;B!R96QE87-E(&9I;&5L:7-T
M#0H@+2!T87-K<R!O=&AE<B!T:&%N(')E<&QA8V4-"B`M(&-U<W1O;2!R;VQE
M<PT*#0IW:6QL(&-A=7-E('!I8VML92!T;R!F86EL+"!A;F0@;W5T<'5T(&%N
M(&5R<F]R(&UE<W-A9V4N("!)9B!Y;W5R('!A8VMA9V4R+GAM;`T*=7-E<R!A
M;GD@;V8@=&AE<V4@9F5A='5R97,L('EO=2!A<F4@8F5S="!O9F8@=7-I;F<@
M4$5!4E]086-K86=E1FEL94UA;F%G97(@=&\-"F=E;F5R871E(&)O=&@@<&%C
M:V%G92YX;6PN#0HG#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@
M("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM86YD7U!A8VMA9V4@8V]N<W1R=6-T
M;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*
M("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]0:6-K;&4H)B1U:2P@)B1C;VYF
M:6<I#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?0V]M;6%N9%]#;VUM
M;VXH)'5I+"`D8V]N9FEG*3L-"B`@("!]#0H-"@T*("`@("\J*@T*("`@("`J
M($9O<B!U;FET+71E<W1I;F<@96%S90T*("`@("`J#0H@("`@("H@0')E='5R
M;B!014%27U!A8VMA9V5R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%!A
M8VMA9V5R*"D-"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=0
M14%27U!A8VMA9V5R)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4B]086-K86=E<BYP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A(#T@
M)FYE=R!014%27U!A8VMA9V5R.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@
M?0T*#0H@("`@+RHJ#0H@("`@("H@1F]R('5N:70M=&5S=&EN9R!E87-E#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<@)&-O;F9I9PT*("`@
M("`J($!P87)A;2!B;V]L("1D96)U9PT*("`@("`J($!P87)A;2!S=')I;F=\
M;G5L;"`D=&UP9&ER#0H@("`@("H@0')E='5R;B!014%27U!A8VMA9V5&:6QE
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5&:6QE*"1C;VYF
M:6<L("1D96)U9R`](&9A;'-E+"`D=&UP9&ER(#T@;G5L;"D-"B`@("![#0H@
M("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T-O;6UO;B<I*2![#0H@
M("`@("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%05(O4&%C
M:V%G949I;&4N<&AP)RDI('L-"B`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("!]#0H@("`@("`@("1A
M(#T@)FYE=R!014%27U!A8VMA9V5&:6QE*"1C;VYF:6<L("1D96)U9RP@)'1M
M<&1I<BD[#0H@("`@("`@("1C;VUM;VX@/2!N97<@4$5!4E]#;VUM;VX[#0H@
M("`@("`@("1C;VUM;VXM/G5I(#T@)'1H:7,M/G5I.PT*("`@("`@("`D82T^
M<V5T3&]G9V5R*"1C;VUM;VXI.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@
M?0T*#0H@("`@9G5N8W1I;VX@9&]086-K86=E*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1T:&ES+3YO=71P=70@/2`G
M)SL-"B`@("`@("`@)'!K9VEN9F]F:6QE(#T@:7-S970H)'!A<F%M<ULP72D@
M/R`D<&%R86US6S!=(#H@)W!A8VMA9V4R+GAM;"<[#0H@("`@("`@("1P86-K
M86=E<B`]("8D=&AI<RT^9V5T4&%C:V%G97(H*3L-"B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<B`]("1T:&ES+3Y?8V]N=F5R=%!A8VMA9V4H)'!K
M9VEN9F]F:6QE*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@
M("`@("!]#0H@("`@("`@("1C;VUP<F5S<R`](&5M<'1Y*"1O<'1I;VYS6R=N
M;V-O;7!R97-S)UTI(#\@=')U92`Z(&9A;'-E.PT*("`@("`@("`D<F5S=6QT
M(#T@)'!A8VMA9V5R+3YP86-K86=E*"1P:V=I;F9O9FEL92P@)&-O;7!R97-S
M+"`G<&%C:V%G92YX;6PG*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)')E<W5L="DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@D<F5S=6QT*3L-"B`@("`@("`@?0T*("`@("`@("`O+R!$;VXG="!W
M86YT(&]U='!U="P@;VYL>2!T:&4@<&%C:V%G92!F:6QE(&YA;64@:G5S="!C
M<F5A=&5D#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<VAO=VYA;64G
M72DI('L-"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D<F5S
M=6QT+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@7V-O;G9E<G1086-K86=E*"1P
M86-K86=E>&UL*0T*("`@('L-"B`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T
M4&%C:V%G949I;&4H)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("1P9C(@/2`F
M)'!K9RT^9G)O;5!A8VMA9V5&:6QE*"1P86-K86=E>&UL+"!014%27U9!3$E$
M051%7TY/4DU!3"D[#0H@("`@("`@(&EF("@A:7-?82@D<&8R+"`G4$5!4E]0
M86-K86=E1FEL95]V,B<I*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-A;FYO="!P<F]C97-S("(G("X-"B`@("`@("`@("`@
M("`@("`D<&%C:V%G97AM;"`N("<B+"!I<R!N;W0@82!P86-K86=E+GAM;"`R
M+C`G*3L-"B`@("`@("`@?0T*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O
M4&%C:V%G949I;&4O=C$N<&AP)SL-"B`@("`@("`@)'!F(#T@;F5W(%!%05)?
M4&%C:V%G949I;&5?=C$[#0H@("`@("`@("1P9BT^<V5T0V]N9FEG*"1T:&ES
M+3YC;VYF:6<I.PT*("`@("`@("!I9B`H:7-?87)R87DH)'!F,BT^9V5T4&%C
M:V%G951Y<&4H*2`A/2`G97AT<W)C)RDI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G
M("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&ES(&YO="!A;B!E
M>'1E;G-I;VX@<V]U<F-E('!A8VMA9V4N("!5<VEN9R!A(%!%05)?4&%C:V%G
M949I;&5-86YA9V5R+6)A<V5D("<@+@T*("`@("`@("`@("`@)W-C<FEP="!I
M<R!A;B!O<'1I;VXG*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-?87)R
M87DH)'!F,BT^9V5T57-E<U)O;&4H*2DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G
M("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A:6YS(&-U
M<W1O;2!R;VQE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G97(M
M8F%S960@<V-R:7!T(&]R("<@+@T*("`@("`@("`@("`@)W1H92!C;VYV97)T
M(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1P9C(M/F=E=%5S97-487-K*"DI*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@
M8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C
M;VYT86EN<R!C=7-T;VT@=&%S:W,N("!5<VEN9R!A(%!%05)?4&%C:V%G949I
M;&5-86YA9V5R+6)A<V5D('-C<FEP="!O<B`G("X-"B`@("`@("`@("`@("=T
M:&4@8V]N=F5R="!C;VUM86YD(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("!]
M#0H@("`@("`@("1D97!S(#T@)'!F,BT^9V5T1&5P96YD96YC:65S*"D[#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P<ULG9W)O=7`G72DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C
M;VYV97)T("(G("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O
M;G1A:6YS(&1E<&5N9&5N8WD@9W)O=7!S+B`@57-I;F<@82!014%27U!A8VMA
M9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@)R`N#0H@("`@("`@("`@("`G
M;W(@=&AE(&-O;G9E<G0@8V]M;6%N9"!I<R!A;B!O<'1I;VXG*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D)UU;)W-U
M8G!A8VMA9V4G72D@?'P-"B`@("`@("`@("`@("`@:7-S970H)&1E<'-;)V]P
M=&EO;F%L)UU;)W-U8G!A8VMA9V4G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G
M("X@)'!A8VMA9V5X;6P@+@T*("`@("`@("`@("`@)R(L(&-O;G1A:6YS('-U
M8G!A8VMA9V4@9&5P96YD96YC:65S+B`@57-I;F<@82!014%27U!A8VMA9V5&
M:6QE36%N86=E<BUB87-E9"`@)RX-"B`@("`@("`@("`@("=S8W)I<'0@:7,@
M86X@;W!T:6]N)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D
M97!S6R=R97%U:7)E9"==6R=O<R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E<G0@(B<@
M+B`D<&%C:V%G97AM;"`N#0H@("`@("`@("`@("`G(BP@8V]N=&%I;G,@;W,@
M9&5P96YD96YC:65S+B`@57-I;F<@82!014%27U!A8VMA9V5&:6QE36%N86=E
M<BUB87-E9"`@)RX-"B`@("`@("`@("`@("=S8W)I<'0@:7,@86X@;W!T:6]N
M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U
M:7)E9"==6R=A<F-H)UTI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K
M86=E>&UL("X-"B`@("`@("`@("`@("<B+"!C;VYT86EN<R!A<F-H(&1E<&5N
M9&5N8VEE<RX@(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S
M960@("<N#0H@("`@("`@("`@("`G<V-R:7!T(&ES(&%N(&]P=&EO;B<I.PT*
M("`@("`@("!]#0H@("`@("`@("1P9BT^<V5T4&%C:V%G92@D<&8R+3YG9710
M86-K86=E*"DI.PT*("`@("`@("`D<&8M/G-E=%-U;6UA<GDH)'!F,BT^9V5T
M4W5M;6%R>2@I*3L-"B`@("`@("`@)'!F+3YS971$97-C<FEP=&EO;B@D<&8R
M+3YG971$97-C<FEP=&EO;B@I*3L-"B`@("`@("`@9F]R96%C:"`H)'!F,BT^
M9V5T36%I;G1A:6YE<G,H*2!A<R`D;6%I;G1A:6YE<BD@>PT*("`@("`@("`@
M("`@)'!F+3YA9&1-86EN=&%I;F5R*"1M86EN=&%I;F5R6R=R;VQE)UTL("1M
M86EN=&%I;F5R6R=H86YD;&4G72P-"B`@("`@("`@("`@("`@("`D;6%I;G1A
M:6YE<ELG;F%M92==+"`D;6%I;G1A:6YE<ELG96UA:6PG72D[#0H@("`@("`@
M('T-"B`@("`@("`@)'!F+3YS971697)S:6]N*"1P9C(M/F=E=%9E<G-I;VXH
M*2D[#0H@("`@("`@("1P9BT^<V5T1&%T92@D<&8R+3YG971$871E*"DI.PT*
M("`@("`@("`D<&8M/G-E=$QI8V5N<V4H)'!F,BT^9V5T3&EC96YS92@I*3L-
M"B`@("`@("`@)'!F+3YS9713=&%T92@D<&8R+3YG9713=&%T92@I*3L-"B`@
M("`@("`@)'!F+3YS971.;W1E<R@D<&8R+3YG971.;W1E<R@I*3L-"B`@("`@
M("`@)'!F+3YA9&10:'!$97`H)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=M
M:6XG72P@)V=E)RD[#0H@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER
M960G75LG<&AP)UU;)VUA>"==*2D@>PT*("`@("`@("`@("`@)'!F+3YA9&10
M:'!$97`H)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=M87@G72P@)VQE)RD[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E
M9"==6R=P86-K86=E)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D
M97!S6R=R97%U:7)E9"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@
M("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D
M97!S6R=R97%U:7)E9"==6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;)W!A8VMA
M9V4G72!A<R`D9&5P*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M9&5P6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G
M("X@)'!A8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G
M(&-O;G1A:6YS('5R:2UB87-E9"!D97!E;F1E;F-Y(&]N(&$@<&%C:V%G92X@
M(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A8VMA
M9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C
M:&%N;F5L)UT@(3T@)W!E87(N<&AP+FYE="<@)B8@)&1E<%LG8VAA;FYE;"==
M("$]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T
M("(G("X@)'!A8VMA9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`G(&-O;G1A:6YS(&1E<&5N9&5N8WD@;VX@82!N;VXM<W1A;F1A<F0@8VAA
M;FYE;"!P86-K86=E+B`@57-I;F<@82`G("X-"B`@("`@("`@("`@("`@("`@
M("`@)U!%05)?4&%C:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="!I<R!A
M;B!O<'1I;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S
M869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X@)R(G("X-"B`@("`@
M("`@("`@("`@("`@("`@)R!C;VYT86EN<R!C;VYF;&EC=',@9&5P96YD96YC
M>2X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A
M8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T86=S(&%R
M92!I9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9%!A8VMA9V5$97`H)&1E<%LG
M;F%M92==+"`D9&5P6R=M:6XG72P@)V=E)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1086-K86=E1&5P*"1D97!;
M)VYA;64G72P@)&1E<%LG;6%X)UTL("=L92<I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)&1E<'-;)W)E<75I<F5D)UU;)V5X=&5N<VEO;B==*2D@>PT*("`@("`@
M("`@("`@:68@*"%I<W-E="@D9&5P<ULG<F5Q=6ER960G75LG97AT96YS:6]N
M)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;
M)V5X=&5N<VEO;B==(#T@87)R87DH)&1E<'-;)W)E<75I<F5D)UU;)V5X=&5N
M<VEO;B==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!S6R=R97%U:7)E9"==6R=E>'1E;G-I;VXG72!A<R`D9&5P*2![#0H@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L:6-T<R==*2D@
M>PT*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)T-A;FYO="!S869E;'D@8V]N=F5R="`B)R`N("1P86-K86=E>&UL("X@
M)R(G("X-"B`@("`@("`@("`@("`@("`@("`@)R!C;VYT86EN<R!C;VYF;&EC
M=',@9&5P96YD96YC>2X@(%5S:6YG(&$@)R`N#0H@("`@("`@("`@("`@("`@
M("`@("=014%27U!A8VMA9V5&:6QE36%N86=E<BUB87-E9"!S8W)I<'0@:7,@
M86X@;W!T:6]N)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D9&5P6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@97AC
M;'5D92!T86=S(&%R92!I9VYO<F5D(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)VUI;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9$5X=&5N
M<VEO;D1E<"@D9&5P6R=N86UE)UTL("1D97!;)VUI;B==+"`G9V4G*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D
M97!;)VUA>"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D<&8M/F%D9$5X
M=&5N<VEO;D1E<"@D9&5P6R=N86UE)UTL("1D97!;)VUA>"==+"`G;&4G*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=P86-K86=E
M)UTI*2![#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!S6R=O<'1I;VYA
M;"==6R=P86-K86=E)UU;,%TI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;
M)V]P=&EO;F%L)UU;)W!A8VMA9V4G72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA
M;"==6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<'-;)V]P=&EO;F%L)UU;)W!A8VMA9V4G72!A<R`D9&5P
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D9&5P6R=C:&%N;F5L
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA9V5X
M;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A:6YS('5R
M:2UB87-E9"!D97!E;F1E;F-Y(&]N(&$@<&%C:V%G92X@(%5S:6YG(&$@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("=014%27U!A8VMA9V5&:6QE36%N86=E
M<BUB87-E9"!S8W)I<'0@:7,@86X@;W!T:6]N)RD[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9&5P6R=C:&%N;F5L)UT@(3T@
M)W!E87(N<&AP+FYE="<@)B8@)&1E<%LG8VAA;FYE;"==("$]("=P96-L+G!H
M<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0V%N;F]T('-A9F5L>2!C;VYV97)T("(G("X@)'!A8VMA
M9V5X;6P@+B`G(B<@+@T*("`@("`@("`@("`@("`@("`@("`G(&-O;G1A:6YS
M(&1E<&5N9&5N8WD@;VX@82!N;VXM<W1A;F1A<F0@8VAA;FYE;"!P86-K86=E
M+B`@57-I;F<@82`G("X-"B`@("`@("`@("`@("`@("`@("`@)U!%05)?4&%C
M:V%G949I;&5-86YA9V5R+6)A<V5D('-C<FEP="!I<R!A;B!O<'1I;VXG*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!;)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G5I+3YO=71P=71$871A*"=705).24Y'.B!E>&-L=61E('1A9W,@87)E
M(&EG;F]R960@:6X@8V]N=F5R<VEO;B<I.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<%LG;6EN)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1P9BT^861D4&%C:V%G941E<"@D9&5P6R=N
M86UE)UTL("1D97!;)VUI;B==+"`G9V4G+"`G>65S)RD[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1086-K86=E1&5P
M*"1D97!;)VYA;64G72P@)&1E<%LG;6%X)UTL("=L92<L("=Y97,G*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==6R=E>'1E;G-I;VXG
M72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&1E<'-;)V]P=&EO;F%L
M)UU;)V5X=&5N<VEO;B==6S!=*2D@>PT*("`@("`@("`@("`@("`@("1D97!S
M6R=O<'1I;VYA;"==6R=E>'1E;G-I;VXG72`](&%R<F%Y*"1D97!S6R=O<'1I
M;VYA;"==6R=E>'1E;G-I;VXG72D[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!F;W)E86-H("@D9&5P<ULG;W!T:6]N86PG75LG97AT96YS:6]N)UT@
M87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=E
M>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^
M;W5T<'5T1&%T82@G5T%23DE.1SH@97AC;'5D92!T86=S(&%R92!I9VYO<F5D
M(&EN(&-O;G9E<G-I;VXG*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1D97!;)VUI;B==*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<&8M/F%D9$5X=&5N<VEO;D1E<"@D9&5P6R=N86UE)UTL
M("1D97!;)VUI;B==+"`G9V4G+"`G>65S)RD[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P6R=M87@G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)'!F+3YA9&1%>'1E;G-I;VY$97`H)&1E
M<%LG;F%M92==+"`D9&5P6R=M87@G72P@)VQE)RP@)WEE<R<I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D8V]N=&5N=',@/2`D<&8R+3YG971#;VYT96YT<R@I.PT*("`@("`@("`D
M<F5L96%S92`]("1P9C(M/F=E=%)E;&5A<V5S*"D[#0H@("`@("`@(&EF("AI
M<W-E="@D<F5L96%S97-;,%TI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@<')O8V5S<R`B)R`N("1P
M86-K86=E>&UL("X@)R(@8V]N=&%I;G,@)R`-"B`@("`@("`@("`@("X@)VUU
M;'1I<&QE(&5X='-R8W)E;&5A<V4@=&%G<RX@(%5S:6YG(&$@4$5!4E]086-K
M86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T("<@+@T*("`@("`@("`@("`@
M)V]R('1H92!C;VYV97)T(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*"1C;VYF:6=O<'1I;VYS(#T@)'!F,BT^9V5T
M0V]N9FEG=7)E3W!T:6]N<R@I*2![#0H@("`@("`@("`@("!F;W)E86-H("@D
M8V]N9FEG;W!T:6]N<R!A<R`D;W!T:6]N*2![#0H@("`@("`@("`@("`@("`@
M)'!F+3YA9&1#;VYF:6=U<F5/<'1I;VXH)&]P=&EO;ELG;F%M92==+"`D;W!T
M:6]N6R=P<F]M<'0G72P-"B`@("`@("`@("`@("`@("`@("`@:7-S970H)&]P
M=&EO;ELG9&5F875L="==*2`_("1O<'1I;VY;)V1E9F%U;'0G72`Z(&9A;'-E
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S
M970H)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEG;F]R92==*2D@>PT*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=#86YN;W0@<V%F96QY
M('!R;V-E<W,@(B<@+B`D<&%C:V%G97AM;"`N("<B(&-O;G1A:6YS("<@#0H@
M("`@("`@("`@("`N("=I9VYO<F4@=&%G<RX@(%5S:6YG(&$@4$5!4E]086-K
M86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T(&]R('1H92!C;VYV97)T)R`N
M#0H@("`@("`@("`@("`G(&-O;6UA;F0@:7,@86X@;W!T:6]N)RD[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1R96QE87-E6R=F:6QE;&ES="==
M6R=I;G-T86QL)UTI("8F#0H@("`@("`@("`@("`@("%I<W-E="@D<F5L96%S
M95LG9FEL96QI<W0G75LG:6YS=&%L;"==6S!=*2D@>PT*("`@("`@("`@("`@
M)')E;&5A<V5;)V9I;&5L:7-T)UU;)VEN<W1A;&PG72`](&%R<F%Y*"1R96QE
M87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("AI<W-E="@D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S)UU;)V)A
M<V5I;G-T86QL9&ER)UTI*2![#0H@("`@("`@("`@("`D8F%S96EN<W1A;&QD
M:7(@/2`D8V]N=&5N='-;)V1I<B==6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL
M9&ER)UT[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D8F%S96EN
M<W1A;&QD:7(@/2!F86QS93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6ES
M<V5T*"1C;VYT96YT<ULG9&ER)UU;)V9I;&4G75LP72DI('L-"B`@("`@("`@
M("`@("1C;VYT96YT<ULG9&ER)UU;)V9I;&4G72`](&%R<F%Y*"1C;VYT96YT
M<ULG9&ER)UU;)V9I;&4G72D[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H)&-O;G1E;G1S6R=D:7(G75LG9FEL92==(&%S("1F:6QE*2![#0H@("`@
M("`@("`@("!I9B`H)&)A<V5I;G-T86QL9&ER("8F("%I<W-E="@D9FEL95LG
M871T<FEB<R==6R=B87-E:6YS=&%L;&1I<B==*2D@>PT*("`@("`@("`@("`@
M("`@("1F:6QE6R=A='1R:6)S)UU;)V)A<V5I;G-T86QL9&ER)UT@/2`D8F%S
M96EN<W1A;&QD:7([#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<')O
M8V5S<T9I;&4@/2`D9FEL93L-"B`@("`@("`@("`@('5N<V5T*"1P<F]C97-S
M1FEL95LG871T<FEB<R==*3L-"B`@("`@("`@("`@(&EF("AC;W5N="@D<')O
M8V5S<T9I;&4I*2![#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!R;V-E
M<W-&:6QE(&%S("1N86UE(#T^("1T87-K*2![#0H@("`@("`@("`@("`@("`@
M("`@(&EF("@D;F%M92`A/2`D<&8R+3YG971487-K<TYS*"D@+B`G.G)E<&QA
M8V4G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)T-A;FYO="!S869E;'D@<')O8V5S<R`B)R`N("1P86-K
M86=E>&UL("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<B(&-O;G1A:6YS
M('1A<VMS(&]T:&5R('1H86X@<F5P;&%C92X@(%5S:6YG(&$@)R`N#0H@("`@
M("`@("`@("`@("`@("`@("`@("`G4$5!4E]086-K86=E1FEL94UA;F%G97(M
M8F%S960@<V-R:7!T(&ES(&%N(&]P=&EO;BXG*3L-"B`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D9FEL95LG871T<FEB<R==
M6R=R97!L86-E)UU;72`]("1T87-K.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:6Y?87)R87DH)&9I;&5;
M)V%T=')I8G,G75LG<F]L92==+"!014%27T-O;6UO;CHZ9V5T1FEL95)O;&5S
M*"DI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=#86YN;W0@<V%F96QY(&-O;G9E<G0@(B<@+B`D<&%C:V%G97AM;"`N
M#0H@("`@("`@("`@("`@("`@)R(L(&-O;G1A:6YS(&-U<W1O;2!R;VQE<RX@
M(%5S:6YG(&$@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T
M("<@+@T*("`@("`@("`@("`@("`@("=O<B!T:&4@8V]N=F5R="!C;VUM86YD
M(&ES(&%N(&]P=&EO;B<I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1R96QE87-E6R=F:6QE;&ES="==6R=I;G-T86QL)UTI*2![
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)')E;&5A<V5;)V9I;&5L:7-T
M)UU;)VEN<W1A;&PG72!A<R`D:6YS=&%L;&%S*2![#0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D:6YS=&%L;&%S6R=A='1R:6)S)UU;)VYA;64G72`]/2`D
M9FEL95LG871T<FEB<R==6R=N86UE)UTI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1F:6QE6R=A='1R:6)S)UU;)VEN<W1A;&PM87,G72`]("1I;G-T
M86QL87-;)V%T=')I8G,G75LG87,G73L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("1P9BT^861D1FEL92@G+R<L("1F:6QE6R=A='1R:6)S)UU;)VYA;64G
M72P@)&9I;&5;)V%T=')I8G,G72D[#0H@("`@("`@('T-"B`@("`@("`@:68@
M*"1P9C(M/F=E=$-H86YG94QO9R@I*2![#0H@("`@("`@("`@("`D=&AI<RT^
M=6DM/F]U='!U=$1A=&$H)U=!4DY)3D<Z(&-H86YG96QO9R!I<R!N;W0@=')A
M;G-L871E9"!T;R!P86-K86=E+GAM;"`G("X-"B`@("`@("`@("`@("`@("`G
M,2XP+"!U<V4@4$5!4E]086-K86=E1FEL94UA;F%G97(M8F%S960@<V-R:7!T
M(&EF('EO=2!N965D(&-H86YG96QO9RTG("X-"B`@("`@("`@("`@("`@("`G
M=')A;G-L871I;VX@9F]R('!A8VMA9V4N>&UL(#$N,"<I.PT*("`@("`@("!]
M#0H@("`@("`@("1G96X@/2`F)'!F+3YG971$969A=6QT1V5N97)A=&]R*"D[
M#0H@("`@("`@("1G96XM/G1O4&%C:V%G949I;&4H)RXG*3L-"B`@("!]#0I]
M#0H-"C\^#0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O0V]M;6%N9"]296=I<W1R>2YX;6P`````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,R-C4@,3`U,34T,S0Q,S0@,#(S,3(W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#QC;VUM86YD
M<R!V97)S:6]N/2(Q+C`B/@T*(#QL:7-T/@T*("`\<W5M;6%R>3Y,:7-T($EN
M<W1A;&QE9"!086-K86=E<R!);B!4:&4@1&5F875L="!#:&%N;F5L/"]S=6UM
M87)Y/@T*("`\9G5N8W1I;VX^9&],:7-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T
M8W5T/FP\+W-H;W)T8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*
M("`@(#QS:&]R=&]P=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/FQI<W0@:6YS
M=&%L;&5D('!A8VMA9V5S(&9R;VT@=&AI<R!C:&%N;F5L/"]D;V,^#0H@("`@
M/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@("`\86QL8VAA;FYE
M;',^#0H@("`@/'-H;W)T;W!T/F$\+W-H;W)T;W!T/@T*("`@(#QD;V,^;&ES
M="!I;G-T86QL960@<&%C:V%G97,@9G)O;2!A;&P@8VAA;FYE;',\+V1O8SX-
M"B`@(#PO86QL8VAA;FYE;',^#0H@(#PO;W!T:6]N<SX-"B`@/&1O8SXF;'0[
M<&%C:V%G929G=#L-"DEF(&EN=F]K960@=VET:&]U="!P87)A;65T97)S+"!T
M:&ES(&-O;6UA;F0@;&ES=',@=&AE(%!%05(@<&%C:V%G97,-"FEN<W1A;&QE
M9"!I;B!Y;W5R('!H<%]D:7(@*'MC;VYF:6<@<&AP7V1I<GTI+B`@5VET:"!A
M('!A<F%M971E<BP@:70-"FQI<W1S('1H92!F:6QE<R!I;B!A('!A8VMA9V4N
M#0H\+V1O8SX-"B`\+VQI<W0^#0H@/&QI<W0M9FEL97,^#0H@(#QS=6UM87)Y
M/DQI<W0@1FEL97,@26X@26YS=&%L;&5D(%!A8VMA9V4\+W-U;6UA<GD^#0H@
M(#QF=6YC=&EO;CYD;T9I;&5,:7-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T
M/F9L/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C
M:V%G929G=#L-"DQI<W0@=&AE(&9I;&5S(&EN(&%N(&EN<W1A;&QE9"!P86-K
M86=E+@T*/"]D;V,^#0H@/"]L:7-T+69I;&5S/@T*(#QS:&5L;"UT97-T/@T*
M("`\<W5M;6%R>3Y3:&5L;"!38W)I<'0@5&5S=#PO<W5M;6%R>3X-"B`@/&9U
M;F-T:6]N/F1O4VAE;&Q497-T/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G-T
M/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G
M929G=#L@6UMR96QA=&EO;ET@=F5R<VEO;ET-"E1E<W1S(&EF(&$@<&%C:V%G
M92!I<R!I;G-T86QL960@:6X@=&AE('-Y<W1E;2X@5VEL;"!E>&ET*#$I(&EF
M(&ET(&ES(&YO="X-"B`@("9L=#MR96QA=&EO;B9G=#L@("!4:&4@=F5R<VEO
M;B!C;VUP87)I<V]N(&]P97)A=&]R+B!/;F4@;V8Z#0H@("`@("`@("`@("`@
M("`@)FQT.RP@;'0L("9L=#L]+"!L92P@)F=T.RP@9W0L("9G=#L]+"!G92P@
M/3TL(#TL(&5Q+"`A/2P@)FQT.R9G=#LL(&YE#0H@("`F;'0[=F5R<VEO;B9G
M=#L@("`@5&AE('9E<G-I;VX@=&\@8V]M<&%R92!W:71H#0H\+V1O8SX-"B`\
M+W-H96QL+71E<W0^#0H@/&EN9F\^#0H@(#QS=6UM87)Y/D1I<W!L87D@:6YF
M;W)M871I;VX@86)O=70@82!P86-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I
M;VX^9&]);F9O/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FEN/"]S:&]R=&-U
M=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SXF;'0[<&%C:V%G929G=#L-"D1I
M<W!L87ES(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92X@5&AE('!A8VMA
M9V4@87)G=6UE;G0@;6%Y(&)E(&$-"FQO8V%L('!A8VMA9V4@9FEL92P@86X@
M55),('1O(&$@<&%C:V%G92!F:6QE+"!O<B!T:&4@;F%M92!O9B!A;@T*:6YS
M=&%L;&5D('!A8VMA9V4N/"]D;V,^#0H@/"]I;F9O/@T*/"]C;VUM86YD<SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+T-O;6UA;F0O4F5G:7-T<GDN<&AP````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,3(W-#4U(#$P-3$U-#,T,3,T(#`R,S$R-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B!014%27T-O;6UA;F1?4F5G:7-T<GD@*&QI<W0L(&QI<W0M9FEL97,L('-H
M96QL+71E<W0L(&EN9F\@8V]M;6%N9',I#0H@*@T*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@
M*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A
M(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*
M("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK
M96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@
M/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H
M92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(%)E9VES=')Y+G!H<"QV(#$N-S`@,C`P-B\P,2\P
M-B`P-#HT-SHS-B!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0H-"B\J*@T*
M("H@8F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@)U!%05(O0V]M;6%N
M9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O<B!R
M96=I<W1R>2!M86YI<'5L871I;VX-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R
M#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A
M:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#`N,0T*("HO#0IC;&%S<R!0
M14%27T-O;6UA;F1?4F5G:7-T<GD@97AT96YD<R!014%27T-O;6UA;F1?0V]M
M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-"@T*("`@('9A<B`D8V]M
M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)VQI<W0G(#T^(&%R<F%Y*`T*("`@
M("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T($EN<W1A;&QE9"!086-K86=E
M<R!);B!4:&4@1&5F875L="!#:&%N;F5L)RP-"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O3&ES="<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^
M("=L)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`G8VAA;FYE;"<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=S:&]R=&]P="<@/3X@)V,G+`T*("`@("`@("`@("`@("`@("`@
M("`G9&]C)R`]/B`G;&ES="!I;G-T86QL960@<&%C:V%G97,@9G)O;2!T:&ES
M(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!
M3B<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M)V%L;&-H86YN96QS)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G82<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=L:7-T(&EN<W1A;&QE9"!P86-K86=E<R!F<F]M(&%L;"!C:&%N;F5L
M<R<L#0H@("`@("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("=D;V,G(#T^("<\<&%C:V%G93X-"DEF(&EN=F]K
M960@=VET:&]U="!P87)A;65T97)S+"!T:&ES(&-O;6UA;F0@;&ES=',@=&AE
M(%!%05(@<&%C:V%G97,-"FEN<W1A;&QE9"!I;B!Y;W5R('!H<%]D:7(@*'MC
M;VYF:6<@<&AP7V1I<GTI+B`@5VET:"!A('!A<F%M971E<BP@:70-"FQI<W1S
M('1H92!F:6QE<R!I;B!A('!A8VMA9V4N#0HG+`T*("`@("`@("`@("`@*2P-
M"B`@("`@("`@)VQI<W0M9FEL97,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M)W-U;6UA<GDG(#T^("=,:7-T($9I;&5S($EN($EN<W1A;&QE9"!086-K86=E
M)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O1FEL94QI<W0G+`T*
M("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G9FPG+`T*("`@("`@("`@("`@
M)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@("`G9&]C)R`]/B`G
M/'!A8VMA9V4^#0I,:7-T('1H92!F:6QE<R!I;B!A;B!I;G-T86QL960@<&%C
M:V%G92X-"B<-"B`@("`@("`@("`@("DL#0H@("`@("`@("=S:&5L;"UT97-T
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4VAE;&P@
M4V-R:7!T(%1E<W0G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]3
M:&5L;%1E<W0G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<W0G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@("`@("`@("`@
M("`G9&]C)R`]/B`G/'!A8VMA9V4^(%M;<F5L871I;VY=('9E<G-I;VY=#0I4
M97-T<R!I9B!A('!A8VMA9V4@:7,@:6YS=&%L;&5D(&EN('1H92!S>7-T96TN
M(%=I;&P@97AI="@Q*2!I9B!I="!I<R!N;W0N#0H@("`\<F5L871I;VX^("`@
M5&AE('9E<G-I;VX@8V]M<&%R:7-O;B!O<&5R871O<BX@3VYE(&]F.@T*("`@
M("`@("`@("`@("`@(#PL(&QT+"`\/2P@;&4L(#XL(&=T+"`^/2P@9V4L(#T]
M+"`]+"!E<2P@(3TL(#P^+"!N90T*("`@/'9E<G-I;VX^("`@(%1H92!V97)S
M:6]N('1O(&-O;7!A<F4@=VET:`T*)RDL#0H@("`@("`@("=I;F9O)R`]/B!A
M<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`@/3X@)T1I<W!L87D@:6YF
M;W)M871I;VX@86)O=70@82!P86-K86=E)RP-"B`@("`@("`@("`@("=F=6YC
M=&EO;B<@/3X@)V1O26YF;R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^
M("=I;B<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@(#T^(&%R<F%Y*"DL#0H@
M("`@("`@("`@("`G9&]C)R`@("`@(#T^("<\<&%C:V%G93X-"D1I<W!L87ES
M(&EN9F]R;6%T:6]N(&%B;W5T(&$@<&%C:V%G92X@5&AE('!A8VMA9V4@87)G
M=6UE;G0@;6%Y(&)E(&$-"FQO8V%L('!A8VMA9V4@9FEL92P@86X@55),('1O
M(&$@<&%C:V%G92!F:6QE+"!O<B!T:&4@;F%M92!O9B!A;@T*:6YS=&%L;&5D
M('!A8VMA9V4N)PT*("`@("`@("`@("`@*0T*("`@("`@("`I.PT*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-"B`@
M("`@*B!014%27T-O;6UA;F1?4F5G:7-T<GD@8V]N<W1R=6-T;W(N#0H@("`@
M("H-"B`@("`@*B!`86-C97-S('!U8FQI8PT*("`@("`J+PT*("`@(&9U;F-T
M:6]N(%!%05)?0V]M;6%N9%]296=I<W1R>2@F)'5I+"`F)&-O;F9I9RD-"B`@
M("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO;B@D=6DL
M("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(&1O3&ES="@I#0H-"B`@("!F=6YC=&EO;B!?<V]R=&EN9F\H)&$L("1B*0T*
M("`@('L-"B`@("`@("`@)&%P86-K86=E(#T@:7-S970H)&%;)W!A8VMA9V4G
M72D@/R`D85LG<&%C:V%G92==(#H@)&%;)VYA;64G73L-"B`@("`@("`@)&)P
M86-K86=E(#T@:7-S970H)&);)W!A8VMA9V4G72D@/R`D8ELG<&%C:V%G92==
M(#H@)&);)VYA;64G73L-"B`@("`@("`@<F5T=7)N('-T<F-M<"@D87!A8VMA
M9V4L("1B<&%C:V%G92D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&],:7-T
M*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@
M(&EF("AI<W-E="@D;W!T:6]N<ULG86QL8VAA;FYE;',G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^9&],:7-T06QL*"1C;VUM86YD+"!A<G)A
M>2@I+"`D<&%R86US*3L-"B`@("`@("`@?0T*("`@("`@("`D<F5G(#T@)B1T
M:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AC;W5N
M="@D<&%R86US*2`]/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/F1O1FEL94QI<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*3L-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V-H86YN96PG
M72DI('L-"B`@("`@("`@("`@(&EF("@D<F5G+3YC:&%N;F5L17AI<W1S*"1O
M<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@)&-H86YN
M96P@/2`D<F5G+3YC:&%N;F5L3F%M92@D;W!T:6]N<ULG8VAA;FYE;"==*3L-
M"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=#:&%N;F5L("(G("X@)&]P=&EO;G-;)V-H
M86YN96PG72`N)R(@9&]E<R!N;W0@97AI<W0G*3L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@
M?0T*("`@("`@("`D:6YS=&%L;&5D(#T@)')E9RT^<&%C:V%G94EN9F\H;G5L
M;"P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("!U<V]R="@D:6YS=&%L;&5D
M+"!A<G)A>2@F)'1H:7,L("=?<V]R=&EN9F\G*2D[#0H@("`@("`@("1I(#T@
M)&H@/2`P.PT*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@
M)V-A<'1I;VXG(#T^("=);G-T86QL960@<&%C:V%G97,L(&-H86YN96P@)R`N
M#0H@("`@("`@("`@("`@("`@)&-H86YN96P@+B`G.B<L#0H@("`@("`@("`@
M("`G8F]R9&5R)R`]/B!T<G5E+`T*("`@("`@("`@("`@)VAE861L:6YE)R`]
M/B!A<G)A>2@G4&%C:V%G92<L("=697)S:6]N)RP@)U-T871E)RD-"B`@("`@
M("`@("`@("D[#0H@("`@("`@(&9O<F5A8V@@*"1I;G-T86QL960@87,@)'!A
M8VMA9V4I('L-"B`@("`@("`@("`@("1P;V)J(#T@)')E9RT^9V5T4&%C:V%G
M92AI<W-E="@D<&%C:V%G95LG<&%C:V%G92==*2`_#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)W!A8VMA9V4G
M72`Z("1P86-K86=E6R=N86UE)UTL("1C:&%N;F5L*3L-"B`@("`@("`@("`@
M("1D871A6R=D871A)UU;72`](&%R<F%Y*"1P;V)J+3YG971086-K86=E*"DL
M("1P;V)J+3YG971697)S:6]N*"DL#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D<&]B:BT^9V5T4W1A=&4H*2`_("1P;V)J+3YG9713
M=&%T92@I(#H@;G5L;"D[#0H@("`@("`@('T-"B`@("`@("`@:68@*&-O=6YT
M*"1I;G-T86QL960I/3TP*2![#0H@("`@("`@("`@("`D9&%T82`]("<H;F\@
M<&%C:V%G97,@:6YS=&%L;&5D(&9R;VT@8VAA;FYE;"`G("X@)&-H86YN96P@
M+B`G*2<[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$
M871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"B`@("`-"B`@("!F=6YC=&EO;B!D;TQI<W1!;&PH)&-O;6UA;F0L
M("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)')E9R`]("8D
M=&AI<RT^8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D:6YS=&%L
M;&5D(#T@)')E9RT^<&%C:V%G94EN9F\H;G5L;"P@;G5L;"P@;G5L;"D[#0H@
M("`@("`@(&9O<F5A8V@@*"1I;G-T86QL960@87,@)&-H86YN96P@/3X@)'!A
M8VMA9V5S*2![#0H@("`@("`@("`@("!U<V]R="@D<&%C:V%G97,L(&%R<F%Y
M*"1T:&ES+"`G7W-O<G1I;F9O)RDI.PT*("`@("`@("`@("`@)&D@/2`D:B`]
M(#`[#0H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=C87!T:6]N)R`]/B`G26YS=&%L;&5D('!A8VMA9V5S+"!C:&%N;F5L
M("<@+B`D8VAA;FYE;"`N("<Z)RP-"B`@("`@("`@("`@("`@("`G8F]R9&5R
M)R`]/B!T<G5E+`T*("`@("`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R
M87DH)U!A8VMA9V4G+"`G5F5R<VEO;B<L("=3=&%T92<I#0H@("`@("`@("`@
M("`@("`@*3L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P86-K86=E<R!A<R`D
M<&%C:V%G92D@>PT*("`@("`@("`@("`@("`@("1P;V)J(#T@)')E9RT^9V5T
M4&%C:V%G92AI<W-E="@D<&%C:V%G95LG<&%C:V%G92==*2`_#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E
M6R=P86-K86=E)UT@.B`D<&%C:V%G95LG;F%M92==+"`D8VAA;FYE;"D[#0H@
M("`@("`@("`@("`@("`@)&1A=&%;)V1A=&$G75M=(#T@87)R87DH)'!O8FHM
M/F=E=%!A8VMA9V4H*2P@)'!O8FHM/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]B:BT^9V5T4W1A
M=&4H*2`_("1P;V)J+3YG9713=&%T92@I(#H@;G5L;"D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)'!A8VMA9V5S*3T],"D@>PT*
M("`@("`@("`@("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("=C87!T:6]N)R`]/B`G26YS=&%L;&5D('!A8VMA9V5S+"!C:&%N
M;F5L("<@+B`D8VAA;FYE;"`N("<Z)RP-"B`@("`@("`@("`@("`@("`@("`@
M)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@("`@("`@("`@)V1A=&$G
M(#T^(&%R<F%Y*&%R<F%Y*"<H;F\@<&%C:V%G97,@:6YS=&%L;&5D*2<I*2P-
M"B`@("`@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I
M.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@
M("`-"B`@("!F=6YC=&EO;B!D;T9I;&5,:7-T*"1C;VUM86YD+"`D;W!T:6]N
M<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AC;W5N="@D<&%R86US
M*2`A/2`Q*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H)VQI<W0M9FEL97,@97AP96-T<R`Q('!A<F%M971E<B<I.PT*("`@("`@
M("!]#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@:68@*"%I<U]D:7(H)'!A<F%M<ULP72D@)B8@*&9I
M;&5?97AI<W1S*"1P87)A;7-;,%TI('Q\("1F<"`]($!F;W!E;B@D<&%R86US
M6S!=+`T*("`@("`@("`@("`@("`G<B<I*2D@>PT*("`@("`@("`@("`@0&9C
M;&]S92@D9G`I.PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)U!%
M05)?4&%C:V%G949I;&4G*2D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@)'!K9R`]("9N97<@4$5!4E]086-K86=E1FEL92@D=&AI
M<RT^8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@("`@(%!%05(Z
M.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-
M"B`@("`@("`@("`@("1I;F9O(#T@)B1P:V<M/F9R;VU!;GE&:6QE*"1P87)A
M;7-;,%TL(%!%05)?5D%,241!5$5?3D]234%,*3L-"B`@("`@("`@("`@(%!%
M05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("1H
M96%D:6YG<R`](&%R<F%Y*"=086-K86=E($9I;&4G+"`G26YS=&%L;"!0871H
M)RD[#0H@("`@("`@("`@("`D:6YS=&%L;&5D(#T@9F%L<V4[#0H@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<&%R
M<V5D(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D<&%R86US6S!=+"`D=&AI
M<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@
M("`@(%!%05(Z.G-T871I8U!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1P87)S960I*2![#0H@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1P87)S960I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)&EN9F\@/2`F)')E9RT^9V5T4&%C
M:V%G92@D<&%R<V5D6R=P86-K86=E)UTL("1P87)S961;)V-H86YN96PG72D[
M#0H@("`@("`@("`@("`D:&5A9&EN9W,@/2!A<G)A>2@G5'EP92<L("=);G-T
M86QL(%!A=&@G*3L-"B`@("`@("`@("`@("1I;G-T86QL960@/2!T<G5E.PT*
M("`@("`@("!]#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1I;F9O
M*3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&EN9F\@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B8"1P87)A
M;7-;,%TG(&YO="!I;G-T86QL960B*3L-"B`@("`@("`@?0T*("`@("`@("`D
M;&ES="`]("@D:6YF;RT^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,2XP
M)R!\?"`D:6YS=&%L;&5D*2`_#0H@("`@("`@("`@("`D:6YF;RT^9V5T1FEL
M96QI<W0H*2`Z("1I;F9O+3YG971#;VYT96YT<R@I.PT*("`@("`@("!I9B`H
M)&EN<W1A;&QE9"D@>PT*("`@("`@("`@("`@)&-A<'1I;VX@/2`G26YS=&%L
M;&5D($9I;&5S($9O<B`G("X@)'!A<F%M<ULP73L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1C87!T:6]N(#T@)T-O;G1E;G1S(&]F("<@+B!B
M87-E;F%M92@D<&%R86US6S!=*3L-"B`@("`@("`@?0T*("`@("`@("`D9&%T
M82`](&%R<F%Y*`T*("`@("`@("`@("`@)V-A<'1I;VXG(#T^("1C87!T:6]N
M+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@
M("=H96%D;&EN92<@/3X@)&AE861I;F=S*3L-"B`@("`@("`@:68@*"1I;F9O
M+3YG971086-K86=E>&UL5F5R<VEO;B@I(#T]("<Q+C`G('Q\("1I;G-T86QL
M960I('L-"B`@("`@("`@("`@(&9O<F5A8V@@*"1L:7-T(&%S("1F:6QE(#T^
M("1A='0I('L-"B`@("`@("`@("`@("`@("!I9B`H)&EN<W1A;&QE9"D@>PT*
M("`@("`@("`@("`@("`@("`@("!I9B`H96UP='DH)&%T=%LG:6YS=&%L;&5D
M7V%S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M9&%T85LG9&%T82==6UT@/2!A<G)A>2@D871T6R=R;VQE)UTL("1A='1;)VEN
M<W1A;&QE9%]A<R==*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T=%LG8F%S96EN<W1A;&QD
M:7(G72D@)B8@(6EN7V%R<F%Y*"1A='1;)W)O;&4G72P-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87DH)W1E<W0G+"`G9&%T82<L("=D;V,G*2DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97-T(#T@)&%T=%LG8F%S
M96EN<W1A;&QD:7(G72`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F:6QE.PT*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&1E<W0@
M/2`D9FEL93L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!S=VET8V@@*"1A='1;)W)O;&4G72D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`G=&5S="<Z#0H@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=D871A)SH-"B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)V1O8R<Z#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')O;&4@
M/2`D871T6R=R;VQE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1R;VQE(#T]("=T97-T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<F]L92`N/2`G<R<[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97-T
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"1R;VQE("X@)U]D:7(G*2`N($1)4D5#
M5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;RT^9V5T4&%C:V%G92@I("X@1$E214-43U)97U-%4$%2051/
M4B`N("1D97-T.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<&AP)SH-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&1E<W0@/2`D=&AI<RT^8V]N9FEG+3YG970H)W!H<%]D
M:7(G*2`N($1)4D5#5$]265]315!!4D%43U(@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D9&5S=#L-"B`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@("`@("`D9',R(#T@1$E214-43U)97U-%4$%2
M051/4B`N($1)4D5#5$]265]315!!4D%43U([#0H@("`@("`@("`@("`@("`@
M("`@("1D97-T(#T@<')E9U]R97!L86-E*&%R<F%Y*"<A7%Q<7"LA)RP@)R$O
M(2<L("(A)&1S,BLA(BDL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH1$E214-43U)97U-%4$%2
M051/4BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!$25)%0U1/4EE?4T5005)!5$]2+`T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($1)4D5#5$]265]315!!4D%43U(I+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D97-T
M*3L-"B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2!P<F5G7W)E<&QA8V4H
M)R$O*R$G+"`G+R<L("1F:6QE*3L-"B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)V1A=&$G75M=(#T@87)R87DH)&9I;&4L("1D97-T*3L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T@96QS92![("\O
M('!A8VMA9V4N>&UL(#(N,"P@;F]T(&EN<W1A;&QE9`T*("`@("`@("`@("`@
M:68@*"%I<W-E="@D;&ES=%LG9&ER)UU;)V9I;&4G75LP72DI('L-"B`@("`@
M("`@("`@("`@("`D;&ES=%LG9&ER)UU;)V9I;&4G72`](&%R<F%Y*"1L:7-T
M6R=D:7(G75LG9FEL92==*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@
M(&9O<F5A8V@@*"1L:7-T6R=D:7(G75LG9FEL92==(&%S("1A='0I('L-"B`@
M("`@("`@("`@("`@("`D871T(#T@)&%T=%LG871T<FEB<R==.PT*("`@("`@
M("`@("`@("`@("1F:6QE(#T@)&%T=%LG;F%M92==.PT*("`@("`@("`@("`@
M("`@("1R;VQE(#T@)E!%05)?26YS=&%L;&5R7U)O;&4Z.F9A8W1O<GDH)&EN
M9F\L("1A='1;)W)O;&4G72P@)'1H:7,M/F-O;F9I9RD[#0H@("`@("`@("`@
M("`@("`@)')O;&4M/G-E='5P*"1T:&ES+"`D:6YF;RP@)&%T="P@)&9I;&4I
M.PT*("`@("`@("`@("`@("`@(&EF("@A)')O;&4M/FES26YS=&%L;&%B;&4H
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&5S="`]("<H;F]T(&EN<W1A
M;&QA8FQE*2<[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&1E<W0@/2`D<F]L92T^<')O8V5S<TEN<W1A;&QA=&EO
M;B@D:6YF;RP@)&%T="P@)&9I;&4L("<G*3L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&1E<W0I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D9&5S="`]("<H56YK;F]W;B!R;VQE("(G("X@)&%T=%LG
M<F]L92==("X@)RDG.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@L+"`D9&5S="D@/2`D9&5S
M=#L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D9FEL
M92P@)&1E<W0I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@
M("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O
M+R![>WL@9&]3:&5L;%1E<W0H*0T*#0H@("`@9G5N8W1I;VX@9&]3:&5L;%1E
M<W0H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I<W1R
M>2@I.PT*("`@("`@("`D:6YF;R`]("1R96<M/G!A<G-E4&%C:V%G94YA;64H
M)'!A<F%M<ULP72P@)'1H:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN
M96PG*2D[#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1I;F9O*2D@>PT*
M("`@("`@("`@("`@97AI="@Q*3L@+R\@:6YV86QI9"!P86-K86=E(&YA;64-
M"B`@("`@("`@?0T*("`@("`@("`D<&%C:V%G92`]("1I;F9O6R=P86-K86=E
M)UT[#0H@("`@("`@("1C:&%N;F5L(#T@)&EN9F];)V-H86YN96PG73L-"B`@
M("`@("`@+R\@(G!E87(@<VAE;&PM=&5S="!&;V\B#0H@("`@("`@(&EF("@A
M)')E9RT^<&%C:V%G945X:7-T<R@D<&%C:V%G92P@)&-H86YN96PI*2![#0H@
M("`@("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE="<I('L-
M"B`@("`@("`@("`@("`@("!I9B`H)')E9RT^<&%C:V%G945X:7-T<R@D<&%C
M:V%G92P@)W!E87(N<&AP+FYE="<I*2![#0H@("`@("`@("`@("`@("`@("`@
M("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[("\O(&UA9VEC86QL>2!C:&%N
M9V4@8VAA;FYE;',@9F]R(&5X=&5N<VEO;G,-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*'-I>F5O
M9B@D<&%R86US*2`]/2`Q*2![#0H@("`@("`@("`@("!I9B`H(21R96<M/G!A
M8VMA9V5%>&ES=',H)'!A8VMA9V4L("1C:&%N;F5L*2D@>PT*("`@("`@("`@
M("`@("`@(&5X:70H,2D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O
M+R`B<&5A<B!S:&5L;"UT97-T($9O;R`Q+C`B#0H@("`@("`@('T@96QS96EF
M("AS:7IE;V8H)'!A<F%M<RD@/3T@,BD@>PT*("`@("`@("`@("`@)'8@/2`D
M<F5G+3YP86-K86=E26YF;R@D<&%C:V%G92P@)W9E<G-I;VXG+"`D8VAA;FYE
M;"D[#0H@("`@("`@("`@("!I9B`H(21V('Q\("%V97)S:6]N7V-O;7!A<F4H
M(B1V(BP@(GLD<&%R86US6S%=?2(L(")G92(I*2![#0H@("`@("`@("`@("`@
M("`@97AI="@Q*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(")P
M96%R('-H96QL+71E<W0@1F]O(&=E(#$N,"(-"B`@("`@("`@?2!E;'-E:68@
M*'-I>F5O9B@D<&%R86US*2`]/2`S*2![#0H@("`@("`@("`@("`D=B`]("1R
M96<M/G!A8VMA9V5);F9O*"1P86-K86=E+"`G=F5R<VEO;B<L("1C:&%N;F5L
M*3L-"B`@("`@("`@("`@(&EF("@A)'8@?'P@(79E<G-I;VY?8V]M<&%R92@B
M)'8B+"`B>R1P87)A;7-;,EU](BP@)'!A<F%M<ULQ72DI('L-"B`@("`@("`@
M("`@("`@("!E>&ET*#$I.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L
M<V4@>PT*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L-
M"B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R*"(D8V]M;6%N9#H@97AP
M96-T<R`Q('1O(#,@<&%R86UE=&5R<R(I.PT*("`@("`@("`@("`@97AI="@Q
M*3L-"B`@("`@("`@?0T*("`@('T-"@T*("`@("\O('U]?0T*("`@("\O('M[
M>R!D;TEN9F\-"@T*("`@(&9U;F-T:6]N(&1O26YF;R@D8V]M;6%N9"P@)&]P
M=&EO;G,L("1P87)A;7,I#0H@("`@>PT*("`@("`@("!I9B`H8V]U;G0H)'!A
M<F%M<RD@(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=P96%R(&EN9F\@97AP96-T<R`Q('!A<F%M971E<B<I.PT*("`@
M("`@("!]#0H@("`@("`@("1I;F9O(#T@9F%L<V4[#0H@("`@("`@("1R96<@
M/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@:68@
M*"A`:7-?9FEL92@D<&%R86US6S!=*2`F)B`A:7-?9&ER*"1P87)A;7-;,%TI
M*2!\?"`D9G`@/2!`9F]P96XH)'!A<F%M<ULP72P@)W(G*2D@>PT*("`@("`@
M("`@("`@0&9C;&]S92@D9G`I.PT*("`@("`@("`@("`@:68@*"%C;&%S<U]E
M>&ES=',H)U!%05)?4&%C:V%G949I;&4G*2D@>PT*("`@("`@("`@("`@("`@
M(')E<75I<F5?;VYC92`G4$5!4B]086-K86=E1FEL92YP:'`G.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@)'!K9R`]("9N97<@4$5!4E]086-K86=E
M1FEL92@D=&AI<RT^8V]N9FEG+"`D=&AI<RT^7V1E8G5G*3L-"B`@("`@("`@
M("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?
M4D5455).*3L-"B`@("`@("`@("`@("1O8FH@/2`F)'!K9RT^9G)O;4%N>49I
M;&4H)'!A<F%M<ULP72P@4$5!4E]604Q)1$%415].3U)-04PI.PT*("`@("`@
M("`@("`@4$5!4CHZ<W1A=&EC4&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@
M("`@("`@:68@*%!%05(Z.FES17)R;W(H)&]B:BDI('L-"B`@("`@("`@("`@
M("`@("`D=6EN9F\@/2`D;V)J+3YG9715<V5R26YF;R@I.PT*("`@("`@("`@
M("`@("`@(&EF("AI<U]A<G)A>2@D=6EN9F\I*2![#0H@("`@("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1U:6YF;R!A<R`D;65S<V%G92D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1M97-S86=E*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M97-S86=E(#T@)&UE<W-A
M9V5;)VUE<W-A9V4G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D
M;65S<V%G92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"1O8FHI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1O
M8FHM/F=E=%!A8VMA9V5X;6Q697)S:6]N*"D@/3T@)S$N,"<I('L-"B`@("`@
M("`@("`@("`@("`D:6YF;R`]("1O8FHM/G1O07)R87DH*3L-"B`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M9&]);F9O,B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,L("1O8FHL(&9A
M;'-E*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1P87)S960@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE*"1P87)A
M;7-;,%TL("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI
M.PT*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!A<G-E9"DI('L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!A
M<G-E9"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D<&%C:V%G92`]
M("1P87)S961;)W!A8VMA9V4G73L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@
M)'!A<G-E9%LG8VAA;FYE;"==.PT*("`@("`@("`@("`@)&EN9F\@/2`D<F5G
M+3YP86-K86=E26YF;R@D<&%C:V%G92P@;G5L;"P@)&-H86YN96PI.PT*("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=O;&0G72DI('L-"B`@("`@("`@
M("`@("`@("`D;V)J(#T@)')E9RT^9V5T4&%C:V%G92@D<&%C:V%G92P@)&-H
M86YN96PI.PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O26YF
M;S(H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US+"`D;V)J+"!T<G5E*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(')E='5R;B`D:6YF;SL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H96UP='DH)&EN9F\I*2![#0H@("`@
M("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@B3F\@:6YF;W)M871I;VX@9F]U
M;F0@9F]R(&`D<&%R86US6S!=)R(I.PT*("`@("`@("`@("`@<F5T=7)N.PT*
M("`@("`@("!]#0H@("`@("`@('5N<V5T*"1I;F9O6R=F:6QE;&ES="==*3L-
M"B`@("`@("`@=6YS970H)&EN9F];)V1I<G1R964G72D[#0H@("`@("`@('5N
M<V5T*"1I;F9O6R=C:&%N9V5L;V<G72D[#0H@("`@("`@(&EF("AI<W-E="@D
M:6YF;ULG>'-D=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@)&EN9F];)W!A
M8VMA9V4N>&UL('9E<G-I;VXG72`]("1I;F9O6R=X<V1V97)S:6]N)UT[#0H@
M("`@("`@("`@("!U;G-E="@D:6YF;ULG>'-D=F5R<VEO;B==*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H:7-S970H)&EN9F];)W!A8VMA9V5R=F5R<VEO
M;B==*2D@>PT*("`@("`@("`@("`@)&EN9F];)W!A8VMA9V5D('=I=&@@4$5!
M4B!V97)S:6]N)UT@/2`D:6YF;ULG<&%C:V%G97)V97)S:6]N)UT[#0H@("`@
M("`@("`@("!U;G-E="@D:6YF;ULG<&%C:V%G97)V97)S:6]N)UTI.PT*("`@
M("`@("!]#0H@("`@("`@("1K97ES(#T@87)R87E?:V5Y<R@D:6YF;RD[#0H@
M("`@("`@("1L;VYG=&5X="`](&%R<F%Y*"=D97-C<FEP=&EO;B<L("=S=6UM
M87)Y)RD[#0H@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S("1K97DI('L-"B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF;ULD:V5Y72DI('L-"B`@("`@
M("`@("`@("`@("!S=VET8V@@*"1K97DI('L-"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G;6%I;G1A:6YE<G,G.B![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:2`](#`[#0H@("`@("`@("`@("`@("`@("`@("`@("`D;7-T<B`]
M("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];
M)&ME>5T@87,@)&TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H)&DK*R`^(#`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&US='(@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&US='(@+CT@)&U;
M)VYA;64G72`N("(@/"([#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1M6R=E;6%I;"==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D;7-T<B`N/2`D;5LG96UA:6PG73L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;7-T<B`N/2`D;5LG:&%N9&QE)UT@+B`G0'!H
M<"YN970G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;7-T<B`N/2`B/B`H)&U;<F]L95TI
M(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R1K97E=(#T@)&US='([#0H@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("!C87-E("=R96QE87-E7V1E<',G.B![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D:2`](#`[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9'-T<B`]("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&EN9F];)&ME>5T@87,@)&0I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]D97!S7W)E;%]T<F%N
M<ULD9%LG<F5L)UU=*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5L(#T@)'1H:7,M/E]D97!S7W)E;%]T<F%N<ULD9%LG<F5L)UU=
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R96P@/2`D9%LG<F5L)UT[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1E<'-?='EP95]T
M<F%N<ULD9%LG='EP92==72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1Y<&4@/2!U8V9I<G-T*"1T:&ES+3Y?9&5P<U]T>7!E7W1R
M86YS6R1D6R=T>7!E)UU=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M='EP92`]("1D6R=T>7!E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9%LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D;F%M92`]("1D6R=N86UE)UT@+B`G("<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YA;64@/2`G)SL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1V97)S:6]N(#T@)&1;)W9E<G-I;VXG72`N("<@)SL-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("<G.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&1;)V]P=&EO;F%L)UTI("8F("1D6R=O<'1I;VYA
M;"==(#T]("=Y97,G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1O<'1I;VYA;"`]("<@*&]P=&EO;F%L*2<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&]P=&EO;F%L(#T@)R<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M<W1R("X]("(D='EP92`D;F%M921R96P@)'9E<G-I;VXD;W!T:6]N86Q<;B([
M#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULD:V5Y72`]("1D<W1R.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G<')O=FED97,G(#H@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&1E8G5G(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V
M97)B;W-E)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&1E8G5G
M(#P@,BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<W1R(#T@
M)T-L87-S97,Z("<[#0H@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<W1R(#T@)R<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:2`](#`[#0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D:6YF;ULD:V5Y72!A<R`D<"D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D9&5B=6<@/"`R("8F("1P6R=T>7!E)UT@(3T@(F-L87-S
M(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU
M93L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@3VYL>2!P<FEN="!C;&%S<V5S('=H96X@
M=F5R8F]S:71Y(&UO9&4@:7,@/"`R#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1D96)U9R`\(#(I('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1I*RL@/B`P*2![#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`B+"`B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P<W1R("X]("1P6R=N86UE)UT[#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1I*RL@/B`P*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<'-T<B`N/2`B7&XB.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P<W1R("X]('5C9FER<W0H)'!;)W1Y<&4G72D@
M+B`B("(@+B`D<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)'!;)V5X<&QI8VET)UTI("8F("1P6R=E>'!L
M:6-I="==(#T](#$I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P<W1R("X]("(@*&5X<&QI8VET*2([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULD:V5Y72`]("1P<W1R.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("`@("`@8V%S92`G8V]N9FEG=7)E7V]P=&EO;G,G
M(#H@>PT*("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&EN9F];
M)&ME>5T@87,@)&D@/3X@)'`I('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULD:V5Y75LD:5T@/2!A<G)A>5]M87`H;G5L;"P@87)R87E?
M:V5Y<R@D<"DL(&%R<F%Y7W9A;'5E<R@D<"DI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R1K97E=6R1I72`](&%R<F%Y7VUA<"AC<F5A
M=&5?9G5N8W1I;VXH)R1A)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W)E='5R;B!J;VEN*"(@/2`B+"1A*3LG*2P@)&EN9F];)&ME>5U;
M)&E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD:V5Y
M75LD:5T@/2!I;7!L;V1E*"<L("<L("1I;F9O6R1K97E=6R1I72D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULD:V5Y72`](&EM<&QO9&4H(EQN(BP@)&EN9F];)&ME>5TI.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@9&5F875L=#H@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2!I;7!L;V1E*"(L
M("(L("1I;F9O6R1K97E=*3L-"B`@("`@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"1K97D@/3T@)U]L
M87-T;6]D:69I960G*2![#0H@("`@("`@("`@("`@("`@)&AD871E(#T@9&%T
M92@G62UM+60G+"`D:6YF;ULD:V5Y72D[#0H@("`@("`@("`@("`@("`@=6YS
M970H)&EN9F];)&ME>5TI.PT*("`@("`@("`@("`@("`@("1I;F9O6R=,87-T
M($UO9&EF:65D)UT@/2`D:&1A=&4[#0H@("`@("`@("`@("!](&5L<V5I9B`H
M)&ME>2`]/2`G7VQA<W1V97)S:6]N)RD@>PT*("`@("`@("`@("`@("`@("1I
M;F9O6R=,87-T($EN<W1A;&QE9"!697)S:6]N)UT@/2`D:6YF;ULD:V5Y72`_
M("1I;F9O6R1K97E=(#H@)RT@3F]N92`M)SL-"B`@("`@("`@("`@("`@("!U
M;G-E="@D:6YF;ULD:V5Y72D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1I;F9O6R1K97E=(#T@=')I;2@D:6YF;ULD:V5Y72D[
M#0H@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1K97DL("1L;VYG=&5X
M="DI('L-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)&ME>5T@/2!P<F5G
M7W)E<&QA8V4H)R\@("LO)RP@)R`G+"`D:6YF;ULD:V5Y72D[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M("1C87!T:6]N(#T@)T%B;W5T("<@+B`D:6YF;ULG<&%C:V%G92==("X@)RTG
M("X@)&EN9F];)W9E<G-I;VXG73L-"B`@("`@("`@)&1A=&$@/2!A<G)A>2@-
M"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@("`@("`@
M("`@("=B;W)D97(G(#T^('1R=64I.PT*("`@("`@("!F;W)E86-H("@D:6YF
M;R!A<R`D:V5Y(#T^("1V86QU92D@>PT*("`@("`@("`@("`@)&ME>2`]('5C
M=V]R9',H=')I;2AS=')?<F5P;&%C92@G7R<L("<@)RP@)&ME>2DI*3L-"B`@
M("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1K97DL("1V86QU
M92D[#0H@("`@("`@('T-"B`@("`@("`@)&1A=&%;)W)A=R==(#T@)&EN9F\[
M#0H-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`G<&%C
M:V%G92UI;F9O)RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-
M"B`@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`@*B\-"B`@("!F=6YC=&EO
M;B!?9&]);F9O,B@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,L("8D;V)J
M+"`D:6YS=&%L;&5D*0T*("`@('L-"B`@("`@("`@)')E9R`]("8D=&AI<RT^
M8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`D8V%P=&EO;B`]("=!
M8F]U="`G("X@)&]B:BT^9V5T0VAA;FYE;"@I("X@)R\G("XD;V)J+3YG9710
M86-K86=E*"D@+B`G+2<@+@T*("`@("`@("`@("`@)&]B:BT^9V5T5F5R<VEO
M;B@I.PT*("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@("`@)V-A
M<'1I;VXG(#T^("1C87!T:6]N+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M=')U92D[#0H@("`@("`@('-W:71C:"`H)&]B:BT^9V5T4&%C:V%G951Y<&4H
M*2D@>PT*("`@("`@("`@("`@8V%S92`G<&AP)R`Z#0H@("`@("`@("`@("`@
M("`@)')E;&5A<V4@/2`G4$5!4BUS='EL92!02%`M8F%S960@4&%C:V%G92<[
M#0H@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@)V5X='-R
M8R<@.@T*("`@("`@("`@("`@("`@("1R96QE87-E(#T@)U!%0TPM<W1Y;&4@
M4$A0(&5X=&5N<VEO;B`H<V]U<F-E(&-O9&4I)SL-"B`@("`@("`@("`@(&)R
M96%K.PT*("`@("`@("`@("`@8V%S92`G97AT8FEN)R`Z#0H@("`@("`@("`@
M("`@("`@)')E;&5A<V4@/2`G4$5#3"US='EL92!02%`@97AT96YS:6]N("AB
M:6YA<GDI)SL-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S
M92`G8G5N9&QE)R`Z#0H@("`@("`@("`@("`@("`@)')E;&5A<V4@/2`G4&%C
M:V%G92!B=6YD;&4@*&-O;&QE8W1I;VX@;V8@<&%C:V%G97,I)SL-"B`@("`@
M("`@("`@(&)R96%K.PT*("`@("`@("!]#0H@("`@("`@("1E>'1E;F1S(#T@
M)&]B:BT^9V5T17AT96YD<R@I.PT*("`@("`@("`D97AT96YD<R`]("1E>'1E
M;F1S(#\-"B`@("`@("`@("`@("1O8FHM/F=E=%!A8VMA9V4H*2`N("<@*&5X
M=&5N9',@)R`N("1E>'1E;F1S("X@)RDG(#H@)&]B:BT^9V5T4&%C:V%G92@I
M.PT*("`@("`@("!I9B`H)'-R8R`]("1O8FHM/F=E=%-O=7)C95!A8VMA9V4H
M*2D@>PT*("`@("`@("`@("`@)&5X=&5N9',@+CT@)R`H<V]U<F-E('!A8VMA
M9V4@)R`N("1S<F-;)V-H86YN96PG72`N("<O)R`N("1S<F-;)W!A8VMA9V4G
M72`N("<I)SL-"B`@("`@("`@?0T*("`@("`@("`D:6YF;R`](&%R<F%Y*`T*
M("`@("`@("`@("`@)U)E;&5A<V4@5'EP92<@/3X@)')E;&5A<V4L#0H@("`@
M("`@("`@("`G3F%M92<@/3X@)&5X=&5N9',L#0H@("`@("`@("`@("`G0VAA
M;FYE;"<@/3X@)&]B:BT^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@)U-U
M;6UA<GDG(#T^('!R96=?<F5P;&%C92@G+R`@*R\G+"`G("<L("1O8FHM/F=E
M=%-U;6UA<GDH*2DL#0H@("`@("`@("`@("`G1&5S8W)I<'1I;VXG(#T^('!R
M96=?<F5P;&%C92@G+R`@*R\G+"`G("<L("1O8FHM/F=E=$1E<V-R:7!T:6]N
M*"DI+`T*("`@("`@("`@("`@*3L-"B`@("`@("`@)&EN9F];)TUA:6YT86EN
M97)S)UT@/2`G)SL-"B`@("`@("`@9F]R96%C:"`H87)R87DH)VQE860G+"`G
M9&5V96QO<&5R)RP@)V-O;G1R:6)U=&]R)RP@)VAE;'!E<B<I(&%S("1R;VQE
M*2![#0H@("`@("`@("`@("`D;&5A9',@/2`D;V)J+3Y[(F=E='LD<F]L97US
M(GTH*3L-"B`@("`@("`@("`@(&EF("@A)&QE861S*2![#0H@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-S970H)&QE861S6R=A8W1I=F4G72DI('L-"B`@("`@("`@("`@("`@
M("`D;&5A9',@/2!A<G)A>2@D;&5A9',I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@9F]R96%C:"`H)&QE861S(&%S("1L96%D*2![#0H@("`@("`@
M("`@("`@("`@:68@*"%E;7!T>2@D:6YF;ULG36%I;G1A:6YE<G,G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)TUA:6YT86EN97)S)UT@+CT@
M(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&EN
M9F];)TUA:6YT86EN97)S)UT@+CT@)&QE861;)VYA;64G72`N("<@/"<[#0H@
M("`@("`@("`@("`@("`@)&EN9F];)TUA:6YT86EN97)S)UT@+CT@)&QE861;
M)V5M86EL)UT@+B`B/B`H)')O;&4I(CL-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D:6YF;ULG4F5L96%S92!$871E)UT@/2`D;V)J+3YG
M971$871E*"D[#0H@("`@("`@(&EF("@D=&EM92`]("1O8FHM/F=E=%1I;64H
M*2D@>PT*("`@("`@("`@("`@)&EN9F];)U)E;&5A<V4@1&%T92==("X]("<@
M)R`N("1T:6UE.PT*("`@("`@("!]#0H@("`@("`@("1I;F9O6R=296QE87-E
M(%9E<G-I;VXG72`]("1O8FHM/F=E=%9E<G-I;VXH*2`N("<@*"<@+B`D;V)J
M+3YG9713=&%T92@I("X@)RDG.PT*("`@("`@("`D:6YF;ULG05!)(%9E<G-I
M;VXG72`]("1O8FHM/F=E=%9E<G-I;VXH)V%P:2<I("X@)R`H)R`N("1O8FHM
M/F=E=%-T871E*"=A<&DG*2`N("<I)SL-"B`@("`@("`@)&EN9F];)TQI8V5N
M<V4G72`]("1O8FHM/F=E=$QI8V5N<V4H*3L-"B`@("`@("`@)'5R:2`]("1O
M8FHM/F=E=$QI8V5N<V5,;V-A=&EO;B@I.PT*("`@("`@("!I9B`H)'5R:2D@
M>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1U<FE;)W5R:2==*2D@>PT*("`@
M("`@("`@("`@("`@("1I;F9O6R=,:6-E;G-E)UT@+CT@)R`H)R`N("1U<FE;
M)W5R:2==("X@)RDG.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`D97AT<F$@/2`D;V)J+3YG971);G-T86QL961,;V-A=&EO;B@D
M:6YF;ULG9FEL97-O=7)C92==*3L-"B`@("`@("`@("`@("`@("!I9B`H)&5X
M=')A*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=,:6-E;G-E)UT@
M+CT@)R`H)R`N("1U<FE;)V9I;&5S;W5R8V4G72`N("<I)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)&EN9F];)U)E;&5A<V4@3F]T97,G72`]("1O8FHM/F=E=$YO=&5S*"D[#0H@
M("`@("`@(&EF("@D8V]M<&%T(#T@)&]B:BT^9V5T0V]M<&%T:6)L92@I*2![
M#0H@("`@("`@("`@("`D:6YF;ULG0V]M<&%T:6)L92!W:71H)UT@/2`G)SL-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1C;VUP870@87,@)'!A8VMA9V4I('L-
M"B`@("`@("`@("`@("`@("`D:6YF;ULG0V]M<&%T:6)L92!W:71H)UT@+CT@
M)'!A8VMA9V5;)V-H86YN96PG72`N("<O)R`N("1P86-K86=E6R=P86-K86=E
M)UT@+@T*("`@("`@("`@("`@("`@("`@("`B7&Y697)S:6]N<R`^/2`B("X@
M)'!A8VMA9V5;)VUI;B==("X@)RP@/#T@)R`N("1P86-K86=E6R=M87@G73L-
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V5X8VQU9&4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P86-K
M86=E6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%C:V%G95LG97AC;'5D92==(#T@:6UP;&]D92@G+"`G+"`D<&%C:V%G95LG
M97AC;'5D92==*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@0V]M<&%T:6)L92!W
M:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I
M8FQE('=I=&@G72`N/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=P86-K86=E)UT@+B`B
M7&Y697)S:6]N<R`B("X@)'!A8VMA9V5;)V5X8VQU9&4G73L-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'5S97-R;VQE(#T@)&]B:BT^9V5T57-E<W)O;&4H*3L-"B`@("`@("`@:68@
M*"1U<V5S<F]L92D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D=7-E<W)O
M;&5;,%TI*2![#0H@("`@("`@("`@("`@("`@)'5S97-R;VQE(#T@87)R87DH
M)'5S97-R;VQE*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A
M8V@@*"1U<V5S<F]L92!A<R`D<F]L961A=&$I('L-"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&EN9F];)U5S97,@0W5S=&]M(%)O;&5S)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("1I;F9O6R=5<V5S($-U<W1O;2!2;VQE<R==
M("X](")<;B([#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&EN9F];)U5S97,@0W5S=&]M(%)O;&5S)UT@/2`G)SL-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1R;VQE9&%T85LG<&%C:V%G92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`D<F]L97!A8VMA9V4@/2`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R
M:6YG*"1R;VQE9&%T82P@=')U92D[#0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@)')O;&5P86-K86=E(#T@)')O;&5D
M871A6R=U<FDG73L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@)&EN9F];)U5S97,@0W5S=&]M(%)O;&5S)UT@+CT@)')O;&5D871A6R=R
M;VQE)UT@+B`G("@G("X@)')O;&5P86-K86=E("X@)RDG.PT*("`@("`@("`@
M("`@?0T*("`@("`@("!]#0H@("`@("`@("1U<V5S=&%S:R`]("1O8FHM/F=E
M=%5S97-T87-K*"D[#0H@("`@("`@(&EF("@D=7-E<W1A<VLI('L-"B`@("`@
M("`@("`@(&EF("@A:7-S970H)'5S97-T87-K6S!=*2D@>PT*("`@("`@("`@
M("`@("`@("1U<V5S=&%S:R`](&%R<F%Y*"1U<V5S=&%S:RD[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!F;W)E86-H("@D=7-E<W1A<VL@87,@)'1A
M<VMD871A*2![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=5
M<V5S($-U<W1O;2!487-K<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULG57-E<R!#=7-T;VT@5&%S:W,G72`N/2`B7&XB.PT*("`@("`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=5
M<V5S($-U<W1O;2!487-K<R==(#T@)R<[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&%S:V1A=&%;)W!A8VMA9V4G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1A<VMP86-K86=E(#T@)')E
M9RT^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D=&%S:V1A=&$L('1R=64I
M.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@
M("`@("1T87-K<&%C:V%G92`]("1T87-K9&%T85LG=7)I)UT[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1I;F9O6R=5<V5S($-U<W1O
M;2!487-K<R==("X]("1T87-K9&%T85LG=&%S:R==("X@)R`H)R`N("1T87-K
M<&%C:V%G92`N("<I)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@
M("`@("`D9&5P<R`]("1O8FHM/F=E=$1E<&5N9&5N8VEE<R@I.PT*("`@("`@
M("`D:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@/2`G4$A0('9E<G-I
M;VX@)R`N("1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG;6EN)UT[#0H@("`@
M("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)VUA>"==
M*2D@>PT*("`@("`@("`@("`@)&EN9F];)U)E<75I<F5D($1E<&5N9&5N8VEE
M<R==("X]("<M)R`N("1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG;6%X)UT@
M+B`B7&XB.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&EN9F];
M)U)E<75I<F5D($1E<&5N9&5N8VEE<R==("X](")<;B([#0H@("`@("`@('T-
M"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG
M97AC;'5D92==*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG
M3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@("`@("1I
M;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@/2`G)SL-"B`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I
M8FQE('=I=&@G72`N/2`B7&XB.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*&ES7V%R<F%Y*"1D97!S6R=R97%U:7)E9"==6R=P:'`G75LG97AC
M;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==
M6R=P:'`G75LG97AC;'5D92==(#T-"B`@("`@("`@("`@("`@("`@("`@:6UP
M;&]D92@G+"`G+"`D9&5P<ULG<F5Q=6ER960G75LG<&AP)UU;)V5X8VQU9&4G
M72D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D:6YF;ULG3F]T($-O
M;7!A=&EB;&4@=VET:"==("X](")02%`@=F5R<VEO;G-<;B`@(B`N#0H@("`@
M("`@("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!H<"==6R=E>&-L=61E
M)UT[#0H@("`@("`@('T-"B`@("`@("`@)&EN9F];)U)E<75I<F5D($1E<&5N
M9&5N8VEE<R==("X]("=014%2(&EN<W1A;&QE<B!V97)S:6]N)SL-"B`@("`@
M("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R
M)UU;)VUA>"==*2D@>PT*("`@("`@("`@("`@)&EN9F];)U)E<75I<F5D($1E
M<&5N9&5N8VEE<R==("X]("=S("<@+@T*("`@("`@("`@("`@("`@("1D97!S
M6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;)VUI;B==("X@)RTG("X-
M"B`@("`@("`@("`@("`@("`D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A
M;&QE<B==6R=M87@G73L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N/2`G("<@+@T*("`@
M("`@("`@("`@("`@("1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R
M)UU;)VUI;B==("X@)R!O<B!N97=E<B<[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=P96%R:6YS=&%L;&5R)UU;
M)V5X8VQU9&4G72DI('L-"B`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];
M)TYO="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@("`@("`D
M:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T
M:6)L92!W:71H)UT@+CT@(EQN(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M("`@(&EF("AI<U]A<G)A>2@D9&5P<ULG<F5Q=6ER960G75LG<&5A<FEN<W1A
M;&QE<B==6R=E>&-L=61E)UTI*2![#0H@("`@("`@("`@("`@("`@)&1E<'-;
M)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG97AC;'5D92==(#T-"B`@
M("`@("`@("`@("`@("`@("`@:6UP;&]D92@G+"`G+"`D9&5P<ULG<F5Q=6ER
M960G75LG<&5A<FEN<W1A;&QE<B==6R=E>&-L=61E)UTI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G
M72`N/2`B4$5!4B!I;G-T86QL97)<;B`@5F5R<VEO;G,@(B`N#0H@("`@("`@
M("`@("`@("`@)&1E<'-;)W)E<75I<F5D)UU;)W!E87)I;G-T86QL97(G75LG
M97AC;'5D92==.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A8V@@*&%R<F%Y
M*"=086-K86=E)RP@)T5X=&5N<VEO;B<I(&%S("1T>7!E*2![#0H@("`@("`@
M("`@("`D:6YD97@@/2!S=')T;VQO=V5R*"1T>7!E*3L-"B`@("`@("`@("`@
M(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LD:6YD97A=*2D@>PT*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG<F5Q=6ER960G75LD:6YD
M97A=6R=N86UE)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1D97!S6R=R
M97%U:7)E9"==6R1I;F1E>%T@/2!A<G)A>2@D9&5P<ULG<F5Q=6ER960G75LD
M:6YD97A=*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@
M9F]R96%C:"`H)&1E<'-;)W)E<75I<F5D)UU;)&EN9&5X72!A<R`D<&%C:V%G
M92D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;
M)V-O;F9L:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN
M9F]I;F1E>"`]("=.;W0@0V]M<&%T:6)L92!W:71H)SL-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)TYO="!#;VUP871I8FQE
M('=I=&@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN(CL-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O:6YD97@@
M/2`G4F5Q=6ER960@1&5P96YD96YC:65S)SL-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R1I;F9O:6YD97A=("X](")<;B([#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"1I;F1E>"`]
M/2`G97AT96YS:6]N)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)&YA
M;64@/2`D<&%C:V%G95LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P
M86-K86=E6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64@/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G("X@)'!A
M8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;64@/2`G7U]U
M<FDO)R`N("1P86-K86=E6R=N86UE)UT@+B`G("AS=&%T:6,@55))*2<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@
M(B1T>7!E("1N86UE(CL-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1P86-K86=E6R=U<FDG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1I;F9O6R1I;F9O:6YD97A=("X](")<;B`@1&]W;FQO860@55)).B`D<&%C
M:V%G95MU<FE=(CL-"B`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI("8F(&ES<V5T*"1P86-K86=E
M6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I
M;F9O:6YD97A=("X]("(@7&X@(%9E<G-I;VYS("(@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P86-K86=E6R=M:6XG72`N("<M)R`N("1P86-K
M86=E6R=M87@G73L-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O6R1I;F9O:6YD97A=("X]("(@7&X@(%9E<G-I;VX@(B`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@
M)R!O<B!N97=E<B<[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI
M<W-E="@D<&%C:V%G95LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N("(@+@T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E6R=M87@G72`N
M("<@;W(@;VQD97(G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG<F5C;VUM96YD960G
M72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1I;F9O:6YD
M97A=("X](")<;B`@4F5C;VUM96YD960@=F5R<VEO;CH@)'!A8VMA9V5;<F5C
M;VUM96YD961=(CL-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN9F];)TYO
M="!#;VUP871I8FQE('=I=&@G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@
M+CT@(EQN(CL-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C:V%G95LG97AC;'5D
M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P86-K86=E
M6R=E>&-L=61E)UT@/2!I;7!L;V1E*"<L("<L("1P86-K86=E6R=E>&-L=61E
M)UTI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("`@("`@)'!A8VMA9V5;)W!A8VMA9V4G72`]("1P86-K86=E6R=N
M86UE)UT[("\O(&9O<B!P87)S961086-K86=E3F%M951O4W1R:6YG#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=C;VYF
M;&EC=',G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF
M;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X]("<]/B!E>&-E<'0@)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`G4&%C:V%G92`G
M("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5G+3YP87)S9610
M86-K86=E3F%M951O4W1R:6YG*"1P86-K86=E+"!T<G5E*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@
M+CT@(EQN("!697)S:6]N<R`B("X@)'!A8VMA9V5;)V5X8VQU9&4G73L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<'-;
M)W)E<75I<F5D)UU;)V]S)UTI*2![#0H@("`@("`@("`@("!I9B`H:7-S970H
M)&1E<'-;)W)E<75I<F5D)UU;)V]S)UU;)VYA;64G72DI('L-"B`@("`@("`@
M("`@("`@("`D9&5P6R=R97%U:7)E9"==6R=O<R==6R=N86UE)UT@/2!A<G)A
M>2@D9&5P6R=R97%U:7)E9"==6R=O<R==6R=N86UE)UTI.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&1E<%LG<F5Q=6ER960G75LG
M;W,G72!A<R`D;W,I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]S
M6R=C;VYF;&EC=',G72D@)B8@)&]S6R=C;VYF;&EC=',G72`]/2`G>65S)RD@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@
M0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B)&]S6VYA;65=($]P97)A=&EN
M9R!3>7-T96TB.PT*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=297%U:7)E9"!$97!E;F1E;F-I97,G72`N
M/2`B7&XB.PT*("`@("`@("`@("`@("`@("`@("`D:6YF;ULG4F5Q=6ER960@
M1&5P96YD96YC:65S)UT@+CT@(B1O<UMN86UE72!/<&5R871I;F<@4WES=&5M
M(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R=A<F-H
M)UTI*2![#0H@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)W)E<75I<F5D
M)UU;)V%R8V@G75LG<&%T=&5R;B==*2D@>PT*("`@("`@("`@("`@("`@("1D
M97!;)W)E<75I<F5D)UU;)V%R8V@G75LG<&%T=&5R;B==(#T@87)R87DH)&1E
M<%LG<F5Q=6ER960G75LG;W,G75LG<&%T=&5R;B==*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!;)W)E<75I<F5D)UU;)V%R
M8V@G72!A<R`D;W,I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]S
M6R=C;VYF;&EC=',G72D@)B8@)&]S6R=C;VYF;&EC=',G72`]/2`G>65S)RD@
M>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=.;W0@
M0V]M<&%T:6)L92!W:71H)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==(#T@)R<[#0H@("`@("`@
M("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==("X](")<;B([#0H@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)TYO="!#;VUP871I8FQE('=I=&@G72`N/2`B3U,O07)C:"!M871C:&EN9R!P
M871T97)N("<O)&]S6W!A='1E<FY=+R<B.PT*("`@("`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R=297%U:7)E9"!$
M97!E;F1E;F-I97,G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@("`@("`D
M:6YF;ULG4F5Q=6ER960@1&5P96YD96YC:65S)UT@+CT@(D]3+T%R8V@@;6%T
M8VAI;F<@<&%T=&5R;B`G+R1O<UMP871T97)N72\G(CL-"B`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@
M*&ES<V5T*"1D97!S6R=O<'1I;VYA;"==*2D@>PT*("`@("`@("`@("`@9F]R
M96%C:"`H87)R87DH)U!A8VMA9V4G+"`G17AT96YS:6]N)RD@87,@)'1Y<&4I
M('L-"B`@("`@("`@("`@("`@("`D:6YD97@@/2!S=')T;VQO=V5R*"1T>7!E
M*3L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&1E<'-;)V]P=&EO;F%L
M)UU;)&EN9&5X72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1D97!S6R=O<'1I;VYA;"==6R1I;F1E>%U;)VYA;64G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1D97!S6R=O<'1I;VYA;"==6R1I;F1E>%T@
M/2!A<G)A>2@D9&5P<ULG;W!T:6]N86PG75LD:6YD97A=*3L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<ULG;W!T:6]N86PG75LD:6YD97A=(&%S("1P86-K86=E*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V-O;F9L
M:6-T<R==*2`F)B`D<&%C:V%G95LG8V]N9FQI8W1S)UT@/3T@)WEE<R<I('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;VEN9&5X(#T@)TYO
M="!#;VUP871I8FQE('=I=&@G.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO
M="!#;VUP871I8FQE('=I=&@G72`]("<G.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(EQN(CL-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1I;F9O:6YD97@@/2`G3W!T:6]N86P@1&5P96YD96YC:65S)SL-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1I;F9O6R=/
M<'1I;VYA;"!$97!E;F1E;F-I97,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)T]P=&EO;F%L($1E<&5N9&5N8VEE<R==
M(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)T]P=&EO
M;F%L($1E<&5N9&5N8VEE<R==("X](")<;B([#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1I;F1E>"`]/2`G97AT96YS:6]N
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N86UE(#T@)'!A
M8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P
M86-K86=E6R=C:&%N;F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1N86UE(#T@)'!A8VMA9V5;)V-H86YN96PG72`N("<O)R`N
M("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&YA;64@/2`G7U]U<FDO)R`N("1P86-K86=E6R=N86UE)UT@+B`G("AS=&%T
M:6,@55))*2<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)&EN9F]I;F1E>%T@+CT@(B1T>7!E("1N86UE(CL-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG=7)I)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I
M;F1E>%T@+CT@(EQN("!$;W=N;&]A9"!54DDZ("1P86-K86=E6W5R:5TB.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"1I;F9O:6YD97@@/3T@)TYO="!#;VUP871I8FQE('=I=&@G*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@8V]N9FQI8W1S(&ES(&]N
M;'D@=7-E9"!T;R!S87D@=&AA="!A;&P@=F5R<VEO;G,@8V]N9FQI8W0-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<&%C:V%G95LG;6%X)UTI("8F(&ES<V5T*"1P86-K86=E6R=M
M:6XG72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:6YF;ULD
M:6YF;VEN9&5X72`N/2`B(%QN("!697)S:6]N<R`B("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@)RTG("X@
M)'!A8VMA9V5;)VUA>"==.PT*("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:6YF;ULD:6YF;VEN9&5X72`N/2`B(%QN("!6
M97)S:6]N("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%C:V%G95LG;6EN)UT@+B`G(&]R(&YE=V5R)SL-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E
M>%T@+CT@(B!<;B`@5F5R<VEO;B`B("X-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!A8VMA9V5;)VUI;B==("X@)R!O<B!O;&1E<B<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'!A8VMA9V5;)W)E8V]M;65N9&5D)UTI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&EN9F]I;F1E>%T@
M+CT@(EQN("!296-O;6UE;F1E9"!V97)S:6]N.B`D<&%C:V%G95MR96-O;6UE
M;F1E9%TB.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=E>&-L=61E)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:6YF;ULG3F]T($-O;7!A=&EB;&4@=VET
M:"==(#T@)R<[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)TYO
M="!#;VUP871I8FQE('=I=&@G72`N/2`B7&XB.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A8VMA9V5;)V5X8VQU9&4G72`]
M(&EM<&QO9&4H)RP@)RP@)'!A8VMA9V5;)V5X8VQU9&4G72D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1I;F9O6R=.;W0@0V]M<&%T:6)L92!W:71H)UT@+CT@(E!A8VMA
M9V4@)'!A8VMA9V5<;B`@5F5R<VEO;G,@(B`N#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P86-K86=E6R=E>&-L=61E)UT[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1D97!S6R=G<F]U<"==*2D@>PT*("`@("`@("`@
M("`@:68@*"%I<W-E="@D9&5P<ULG9W)O=7`G75LP72DI('L-"B`@("`@("`@
M("`@("`@("`D9&5P<ULG9W)O=7`G72`](&%R<F%Y*"1D97!S6R=G<F]U<"==
M*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1D97!S
M6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@("`@("`@("`@("`@("1I;F9O
M6R=$97!E;F1E;F-Y($=R;W5P("<@+B`D9W)O=7!;)V%T=')I8G,G75LG;F%M
M92==72`]("1G<F]U<%LG871T<FEB<R==6R=H:6YT)UT[#0H@("`@("`@("`@
M("`@("`@)&=R;W5P:6YD97@@/2`D9W)O=7!;)V%T=')I8G,G75LG;F%M92==
M("X@)R!#;VYT96YT<R<[#0H@("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P
M:6YD97A=(#T@)R<[#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H87)R87DH
M)U!A8VMA9V4G+"`G17AT96YS:6]N)RD@87,@)'1Y<&4I('L-"B`@("`@("`@
M("`@("`@("`@("`@)&EN9&5X(#T@<W1R=&]L;W=E<B@D='EP92D[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)&EN9&5X72DI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9W)O=7!;)&EN
M9&5X75LG;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1G<F]U<%LD:6YD97A=(#T@87)R87DH)&=R;W5P6R1I;F1E>%TI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)&=R;W5P6R1I;F1E>%T@87,@)'!A8VMA9V4I('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R1G
M<F]U<&EN9&5X72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&EN9F];)&=R;W5P:6YD97A=("X](")<;B([#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D:6YD97@@/3T@)V5X=&5N<VEO;B<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&YA;64@/2`D<&%C:V%G95LG;F%M92==.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG
M8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YA;64@/2`D<&%C:V%G95LG8VAA;FYE;"==("X@)R\G("X@)'!A
M8VMA9V5;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N86UE(#T@)U]?=7)I+R<@+B`D<&%C:V%G95LG;F%M92==("X@)R`H
M<W1A=&EC(%5222DG.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG=7)I)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<W-E
M="@D<&%C:V%G95LG8V]N9FQI8W1S)UTI("8F("1P86-K86=E6R=C;VYF;&EC
M=',G72`]/2`G>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X](").;W0@0V]M<&%T:6)L
M92!W:71H("1T>7!E("1N86UE(CL-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B)'1Y<&4@)&YA;64B
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N
M/2`B7&X@($1O=VYL;V%D(%5223H@)'!A8VMA9V5;=7)I72([#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'!A8VMA9V5;)V-O;F9L:6-T<R==*2`F)B`D<&%C
M:V%G95LG8V]N9FQI8W1S)UT@/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X](").;W0@
M0V]M<&%T:6)L92!W:71H("1T>7!E("1N86UE(CL-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I
M;F9O6R1G<F]U<&EN9&5X72`N/2`B)'1Y<&4@)&YA;64B.PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<&%C:V%G95LG;6%X)UTI
M("8F(&ES<V5T*"1P86-K86=E6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&EN9F];)&=R;W5P:6YD97A=("X]("(@7&X@
M(%9E<G-I;VYS("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'!A8VMA9V5;)VUI;B==("X@)RTG("X@)'!A8VMA9V5;)VUA>"==
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E
M="@D<&%C:V%G95LG;6EN)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I;F9O6R1G<F]U<&EN9&5X72`N/2`B(%QN("!697)S:6]N
M("(@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M8VMA9V5;)VUI;B==("X@)R!O<B!N97=E<B<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1P86-K86=E6R=M87@G72DI
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];)&=R
M;W5P:6YD97A=("X]("(@7&X@(%9E<G-I;VX@(B`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&%C:V%G95LG;6EN)UT@+B`G(&]R
M(&]L9&5R)SL-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=R
M96-O;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:6YF;ULD9W)O=7!I;F1E>%T@+CT@(EQN("!296-O;6UE;F1E9"!V
M97)S:6]N.B`D<&%C:V%G95MR96-O;6UE;F1E9%TB.PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)'!A8VMA9V5;)V5X8VQU9&4G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D:6YF;ULG3F]T
M($-O;7!A=&EB;&4@=VET:"==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&EN9F];)TYO="!#;VUP871I8FQE('=I=&@G72`]
M("<G.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)&=R;W5P:6YD97A=("X](").;W0@0V]M<&%T:6)L92!W:71H7&XB.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<&%C:V%G95LG97AC
M;'5D92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'!A8VMA9V5;)V5X8VQU9&4G72`](&EM<&QO9&4H)RP@)RP@)'!A8VMA
M9V5;)V5X8VQU9&4G72D[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F];
M)&=R;W5P:6YD97A=("X]("(@(%!A8VMA9V4@)'!A8VMA9V5<;B`@5F5R<VEO
M;G,@(B`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%C:V%G95LG97AC;'5D92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)&]B:BT^9V5T4&%C:V%G951Y<&4H
M*2`]/2`G8G5N9&QE)RD@>PT*("`@("`@("`@("`@)&EN9F];)T)U;F1L960@
M4&%C:V%G97,G72`]("<G.PT*("`@("`@("`@("`@9F]R96%C:"`H)&]B:BT^
M9V5T0G5N9&QE9%!A8VMA9V5S*"D@87,@)'!A8VMA9V4I('L-"B`@("`@("`@
M("`@("`@("!I9B`H(65M<'1Y*"1I;F9O6R="=6YD;&5D(%!A8VMA9V5S)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("1I;F9O6R="=6YD;&5D(%!A8VMA
M9V5S)UT@+CT@(EQN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P86-K86=E6R=U<FDG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)&EN9F];)T)U;F1L960@4&%C:V%G97,G72`N/2`G7U]U
M<FDO)R`N("1P86-K86=E6R=N86UE)UT[#0H@("`@("`@("`@("`@("`@("`@
M("1I;F9O6R="=6YD;&5D(%!A8VMA9V5S)UT@+CT@(EQN("`H55)).B`D<&%C
M:V%G95MU<FE=(CL-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("`@("`D:6YF;ULG0G5N9&QE9"!086-K86=E<R==("X]("1P
M86-K86=E6R=C:&%N;F5L)UT@+B`G+R<@+B`D<&%C:V%G95LG;F%M92==.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D:6YF;ULG<&%C:V%G92YX;6P@=F5R<VEO;B==(#T@)S(N,"<[
M#0H@("`@("`@(&EF("@D:6YS=&%L;&5D*2![#0H@("`@("`@("`@("!I9B`H
M)&]B:BT^9V5T3&%S=$UO9&EF:65D*"DI('L-"B`@("`@("`@("`@("`@("`D
M:6YF;ULG3&%S="!-;V1I9FEE9"==(#T@9&%T92@G62UM+60@2#II)RP@)&]B
M:BT^9V5T3&%S=$UO9&EF:65D*"DI.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@)'8@/2`D;V)J+3YG971,87-T26YS=&%L;&5D5F5R<VEO;B@I.PT*
M("`@("`@("`@("`@)&EN9F];)TQA<W0@26YS=&%L;&5D(%9E<G-I;VXG72`]
M("1V(#\@)'8@.B`G+2!.;VYE("TG.PT*("`@("`@("!]#0H@("`@("`@(&9O
M<F5A8V@@*"1I;F9O(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@
M("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D:V5Y+"`D=F%L=64I.PT*("`@
M("`@("!]#0H@("`@("`@("1D871A6R=R87<G72`]("1O8FHM/F=E=$%R<F%Y
M*"D[("\O(&YO('9A;&ED871I;VX@;F5E9&5D#0H-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"1D871A+"`G<&%C:V%G92UI;F9O)RD[#0H@("`@
M?0T*?0T*#0H_/@T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+U)E;6]T
M92YX;6P`````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-34R,"`Q
M,#4Q-30S-#$S-"`P,C(U-#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/')E
M;6]T92UI;F9O/@T*("`\<W5M;6%R>3Y);F9O<FUA=&EO;B!!8F]U="!296UO
M=&4@4&%C:V%G97,\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U)E;6]T94EN
M9F\\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<FD\+W-H;W)T8W5T/@T*("`\
M;W!T:6]N<R`O/@T*("`\9&]C/B9L=#MP86-K86=E)F=T.PT*1V5T(&1E=&%I
M;',@;VX@82!P86-K86=E(&9R;VT@=&AE('-E<G9E<BX\+V1O8SX-"B`\+W)E
M;6]T92UI;F9O/@T*(#QL:7-T+75P9W)A9&5S/@T*("`\<W5M;6%R>3Y,:7-T
M($%V86EL86)L92!5<&=R861E<SPO<W5M;6%R>3X-"B`@/&9U;F-T:6]N/F1O
M3&ES=%5P9W)A9&5S/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/FQU/"]S:&]R
M=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O8SY;<')E9F5R<F5D7W-T871E
M70T*3&ES="!R96QE87-E<R!O;B!T:&4@<V5R=F5R(&]F('!A8VMA9V5S('EO
M=2!H879E(&EN<W1A;&QE9"!W:&5R90T*82!N97=E<B!V97)S:6]N(&ES(&%V
M86EL86)L92!W:71H('1H92!S86UE(')E;&5A<V4@<W1A=&4@*'-T86)L92!E
M=&,N*0T*;W(@=&AE('-T871E('!A<W-E9"!A<R!T:&4@<V5C;VYD('!A<F%M
M971E<BX\+V1O8SX-"B`\+VQI<W0M=7!G<F%D97,^#0H@/')E;6]T92UL:7-T
M/@T*("`\<W5M;6%R>3Y,:7-T(%)E;6]T92!086-K86=E<SPO<W5M;6%R>3X-
M"B`@/&9U;F-T:6]N/F1O4F5M;W1E3&ES=#PO9G5N8W1I;VX^#0H@(#QS:&]R
M=&-U=#YR;#PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H86YN96P^
M#0H@("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^<W!E8VEF
M>2!A(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L/"]D
M;V,^#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@(#PO
M;W!T:6]N<SX-"B`@/&1O8SX-"DQI<W1S('1H92!P86-K86=E<R!A=F%I;&%B
M;&4@;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG('=I=&@@=&AE#0IL
M871E<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K86=E+CPO9&]C/@T*
M(#PO<F5M;W1E+6QI<W0^#0H@/'-E87)C:#X-"B`@/'-U;6UA<GD^4V5A<F-H
M(')E;6]T92!P86-K86=E(&1A=&%B87-E/"]S=6UM87)Y/@T*("`\9G5N8W1I
M;VX^9&]396%R8V@\+V9U;F-T:6]N/@T*("`\<VAO<G1C=70^<W`\+W-H;W)T
M8W5T/@T*("`\;W!T:6]N<SX-"B`@(#QC:&%N;F5L/@T*("`@(#QS:&]R=&]P
M=#YC/"]S:&]R=&]P=#X-"B`@("`\9&]C/G-P96-I9GD@82!C:&%N;F5L(&]T
M:&5R('1H86X@=&AE(&1E9F%U;'0@8VAA;FYE;#PO9&]C/@T*("`@(#QA<F<^
M0TA!3CPO87)G/@T*("`@/"]C:&%N;F5L/@T*("`\+V]P=&EO;G,^#0H@(#QD
M;V,^6W!A8VMA9V5N86UE72!;<&%C:V%G96EN9F]=#0I,:7-T<R!A;&P@<&%C
M:V%G97,@=VAI8V@@;6%T8V@@=&AE('-E87)C:"!P87)A;65T97)S+B`@5&AE
M(&9I<G-T#0IP87)A;65T97(@:7,@82!F<F%G;65N="!O9B!A('!A8VMA9V5N
M86UE+B`@5&AE(&1E9F%U;'0@8VAA;FYE;`T*=VEL;"!B92!U<V5D('5N;&5S
M<R!E>'!L:6-I=&QY(&]V97)R:61D96XN("!4:&4@<V5C;VYD('!A<F%M971E
M<@T*=VEL;"!B92!U<V5D('1O(&UA=&-H(&%N>2!P;W)T:6]N(&]F('1H92!S
M=6UM87)Y+V1E<V-R:7!T:6]N/"]D;V,^#0H@/"]S96%R8V@^#0H@/&QI<W0M
M86QL/@T*("`\<W5M;6%R>3Y,:7-T($%L;"!086-K86=E<SPO<W5M;6%R>3X-
M"B`@/&9U;F-T:6]N/F1O3&ES=$%L;#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U
M=#YL83PO<VAO<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H86YN96P^#0H@
M("`@/'-H;W)T;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^<W!E8VEF>2!A
M(&-H86YN96P@;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L/"]D;V,^
M#0H@("`@/&%R9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@(#PO;W!T
M:6]N<SX-"B`@/&1O8SX-"DQI<W1S('1H92!P86-K86=E<R!A=F%I;&%B;&4@
M;VX@=&AE(&-O;F9I9W5R960@<V5R=F5R(&%L;VYG('=I=&@@=&AE#0IL871E
M<W0@<W1A8FQE(')E;&5A<V4@;V8@96%C:"!P86-K86=E+CPO9&]C/@T*(#PO
M;&ES="UA;&P^#0H@/&1O=VYL;V%D/@T*("`\<W5M;6%R>3Y$;W=N;&]A9"!0
M86-K86=E/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^9&]$;W=N;&]A9#PO9G5N
M8W1I;VX^#0H@(#QS:&]R=&-U=#YD/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,^
M#0H@("`\;F]C;VUP<F5S<SX-"B`@("`\<VAO<G1O<'0^6CPO<VAO<G1O<'0^
M#0H@("`@/&1O8SYD;W=N;&]A9"!A;B!U;F-O;7!R97-S960@*"YT87(I(&9I
M;&4\+V1O8SX-"B`@(#PO;F]C;VUP<F5S<SX-"B`@/"]O<'1I;VYS/@T*("`\
M9&]C/B9L=#MP86-K86=E)F=T.RXN+@T*1&]W;FQO860@<&%C:V%G92!T87)B
M86QL<RX@(%1H92!F:6QE<R!W:6QL(&)E(&YA;65D(&%S('-U9V=E<W1E9"!B
M>2!T:&4-"G-E<G9E<BP@9F]R(&5X86UP;&4@:68@>6]U(&1O=VYL;V%D('1H
M92!$0B!P86-K86=E(&%N9"!T:&4@;&%T97-T('-T86)L90T*=F5R<VEO;B!O
M9B!$0B!I<R`Q+C8N-2P@=&AE(&1O=VYL;V%D960@9FEL92!W:6QL(&)E($1"
M+3$N-BXU+G1G>BX\+V1O8SX-"B`\+V1O=VYL;V%D/@T*(#QC;&5A<BUC86-H
M93X-"B`@/'-U;6UA<GD^0VQE87(@5V5B(%-E<G9I8V5S($-A8VAE/"]S=6UM
M87)Y/@T*("`\9G5N8W1I;VX^9&]#;&5A<D-A8VAE/"]F=6YC=&EO;CX-"B`@
M/'-H;W)T8W5T/F-C/"]S:&]R=&-U=#X-"B`@/&]P=&EO;G,@+SX-"B`@/&1O
M8SX-"D-L96%R('1H92!834PM4E!#+U)%4U0@8V%C:&4N("!3964@86QS;R!T
M:&4@8V%C:&5?='1L(&-O;F9I9W5R871I;VX-"G!A<F%M971E<BX-"CPO9&]C
M/@T*(#PO8VQE87(M8V%C:&4^#0H\+V-O;6UA;F1S/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O4F5M;W1E+G!H<```````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8S-S(S(#$P-3$U-#,T,3,T(#`R,C4T
M-@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?4F5M;W1E("AR96UO=&4M:6YF
M;RP@;&ES="UU<&=R861E<RP@<F5M;W1E+6QI<W0L('-E87)C:"P@;&ES="UA
M;&PL(&1O=VYL;V%D+`T*("H@8VQE87(M8V%C:&4@8V]M;6%N9',I#0H@*@T*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE
M(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED
M(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L
M96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A
M=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%)E;6]T92YP:'`L=B`Q
M+CDP+C(N,B`R,#`V+S`S+S(S(#`U.C0U.C$W(&-E;&QO9R!%>'`@)`T*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-
M"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,"XQ#0H@*B\-"@T*+RHJ#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?
M;VYC92`G4$5!4B]#;VUM86YD+T-O;6UO;BYP:'`G.PT*<F5Q=6ER95]O;F-E
M("=014%2+U)%4U0N<&AP)SL-"@T*+RHJ#0H@*B!014%2(&-O;6UA;F1S(&9O
M<B!R96UO=&4@<V5R=F5R('%U97)Y:6YG#0H@*@T*("H@0&-A=&5G;W)Y("`@
M<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@1W)E9R!"
M96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR
M,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*8VQA
M<W,@4$5!4E]#;VUM86YD7U)E;6]T92!E>'1E;F1S(%!%05)?0V]M;6%N9%]#
M;VUM;VX-"GL-"B`@("`O+R![>WL@8V]M;6%N9"!D969I;FET:6]N<PT*#0H@
M("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<F5M;W1E+6EN
M9F\G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=);F9O
M<FUA=&EO;B!!8F]U="!296UO=&4@4&%C:V%G97,G+`T*("`@("`@("`@("`@
M)V9U;F-T:6]N)R`]/B`G9&]296UO=&5);F9O)RP-"B`@("`@("`@("`@("=S
M:&]R=&-U="<@/3X@)W)I)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]/B!A
M<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)SQP86-K86=E/@T*1V5T
M(&1E=&%I;',@;VX@82!P86-K86=E(&9R;VT@=&AE('-E<G9E<BXG+`T*("`@
M("`@("`@("`@*2P-"B`@("`@("`@)VQI<W0M=7!G<F%D97,G(#T^(&%R<F%Y
M*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=,:7-T($%V86EL86)L92!5
M<&=R861E<R<L#0H@("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;TQI<W15
M<&=R861E<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=L=2<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@("`@("`@
M("=D;V,G(#T^("=;<')E9F5R<F5D7W-T871E70T*3&ES="!R96QE87-E<R!O
M;B!T:&4@<V5R=F5R(&]F('!A8VMA9V5S('EO=2!H879E(&EN<W1A;&QE9"!W
M:&5R90T*82!N97=E<B!V97)S:6]N(&ES(&%V86EL86)L92!W:71H('1H92!S
M86UE(')E;&5A<V4@<W1A=&4@*'-T86)L92!E=&,N*0T*;W(@=&AE('-T871E
M('!A<W-E9"!A<R!T:&4@<V5C;VYD('!A<F%M971E<BXG#0H@("`@("`@("`@
M("`I+`T*("`@("`@("`G<F5M;W1E+6QI<W0G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@)W-U;6UA<GDG(#T^("=,:7-T(%)E;6]T92!086-K86=E<R<L#0H@
M("`@("`@("`@("`G9G5N8W1I;VXG(#T^("=D;U)E;6]T94QI<W0G+`T*("`@
M("`@("`@("`@)W-H;W)T8W5T)R`]/B`G<FPG+`T*("`@("`@("`@("`@)V]P
M=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]
M/@T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@
M("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@
M("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA;FYE;"!O=&AE<B!T:&%N('1H92!D
M969A=6QT(&-H86YN96PG+`T*("`@("`@("`@("`@("`@("`@("`G87)G)R`]
M/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@("D-"B`@("`@("`@("`@
M("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&ES=',@=&AE('!A
M8VMA9V5S(&%V86EL86)L92!O;B!T:&4@8V]N9FEG=7)E9"!S97)V97(@86QO
M;F<@=VET:"!T:&4-"FQA=&5S="!S=&%B;&4@<F5L96%S92!O9B!E86-H('!A
M8VMA9V4N)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("=S96%R8V@G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA<GDG(#T^("=396%R8V@@<F5M
M;W1E('!A8VMA9V4@9&%T86)A<V4G+`T*("`@("`@("`@("`@)V9U;F-T:6]N
M)R`]/B`G9&]396%R8V@G+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G
M<W`G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L
M#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA
M;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG+`T*("`@("`@
M("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@("`@
M("`@("`@("D-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O
M8R<@/3X@)UMP86-K86=E;F%M95T@6W!A8VMA9V5I;F9O70T*3&ES=',@86QL
M('!A8VMA9V5S('=H:6-H(&UA=&-H('1H92!S96%R8V@@<&%R86UE=&5R<RX@
M(%1H92!F:7)S=`T*<&%R86UE=&5R(&ES(&$@9G)A9VUE;G0@;V8@82!P86-K
M86=E;F%M92X@(%1H92!D969A=6QT(&-H86YN96P-"G=I;&P@8F4@=7-E9"!U
M;FQE<W,@97AP;&EC:71L>2!O=F5R<FED9&5N+B`@5&AE('-E8V]N9"!P87)A
M;65T97(-"G=I;&P@8F4@=7-E9"!T;R!M871C:"!A;GD@<&]R=&EO;B!O9B!T
M:&4@<W5M;6%R>2]D97-C<FEP=&EO;B<L#0H@("`@("`@("`@("`I+`T*("`@
M("`@("`G;&ES="UA;&PG(#T^(&%R<F%Y*`T*("`@("`@("`@("`@)W-U;6UA
M<GDG(#T^("=,:7-T($%L;"!086-K86=E<R<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;TQI<W1!;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T
M)R`]/B`G;&$G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]
M/B`G8R<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C:69Y
M(&$@8VAA;FYE;"!O=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG+`T*
M("`@("`@("`@("`@("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@
M("`@("`@("`@("`@("D-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@
M("`@)V1O8R<@/3X@)PT*3&ES=',@=&AE('!A8VMA9V5S(&%V86EL86)L92!O
M;B!T:&4@8V]N9FEG=7)E9"!S97)V97(@86QO;F<@=VET:"!T:&4-"FQA=&5S
M="!S=&%B;&4@<F5L96%S92!O9B!E86-H('!A8VMA9V4N)RP-"B`@("`@("`@
M("`@("DL#0H@("`@("`@("=D;W=N;&]A9"<@/3X@87)R87DH#0H@("`@("`@
M("`@("`G<W5M;6%R>2<@/3X@)T1O=VYL;V%D(%!A8VMA9V4G+`T*("`@("`@
M("`@("`@)V9U;F-T:6]N)R`]/B`G9&]$;W=N;&]A9"<L#0H@("`@("`@("`@
M("`G<VAO<G1C=70G(#T^("=D)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`G;F]C;VUP<F5S<R<@/3X@87)R
M87DH#0H@("`@("`@("`@("`@("`@("`@("=S:&]R=&]P="<@/3X@)UHG+`T*
M("`@("`@("`@("`@("`@("`@("`G9&]C)R`]/B`G9&]W;FQO860@86X@=6YC
M;VUP<F5S<V5D("@N=&%R*2!F:6QE)RP-"B`@("`@("`@("`@("`@("`@("`@
M*2P-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O8R<@/3X@
M)SQP86-K86=E/BXN+@T*1&]W;FQO860@<&%C:V%G92!T87)B86QL<RX@(%1H
M92!F:6QE<R!W:6QL(&)E(&YA;65D(&%S('-U9V=E<W1E9"!B>2!T:&4-"G-E
M<G9E<BP@9F]R(&5X86UP;&4@:68@>6]U(&1O=VYL;V%D('1H92!$0B!P86-K
M86=E(&%N9"!T:&4@;&%T97-T('-T86)L90T*=F5R<VEO;B!O9B!$0B!I<R`Q
M+C8N-2P@=&AE(&1O=VYL;V%D960@9FEL92!W:6QL(&)E($1"+3$N-BXU+G1G
M>BXG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)V-L96%R+6-A8VAE)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0VQE87(@5V5B
M(%-E<G9I8V5S($-A8VAE)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@
M)V1O0VQE87)#86-H92<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=C
M8R<L#0H@("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH*2P-"B`@("`@
M("`@("`@("=D;V,G(#T^("<-"D-L96%R('1H92!834PM4E!#+U)%4U0@8V%C
M:&4N("!3964@86QS;R!T:&4@8V%C:&5?='1L(&-O;F9I9W5R871I;VX-"G!A
M<F%M971E<BX-"B<L#0H@("`@("`@("`@("`I+`T*("`@("`@("`I.PT*#0H@
M("`@+R\@?7U]#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-
M"B`@("`@*B!014%27T-O;6UA;F1?4F5M;W1E(&-O;G-T<G5C=&]R+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!014%27T-O;6UA;F1?4F5M;W1E*"8D=6DL("8D8V]N9FEG*0T*("`@
M('L-"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@
M)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("!F=6YC=&EO
M;B!?8VAE8VM#:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA;BD-"B`@
M("![#0H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1C:&%N*2D@>PT*("`@
M("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)&-H86XI.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A:7-?82@D8VAA;BP@)U!%05)?0VAA;FYE;$9I;&4G
M*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=)
M;G1E<FYA;"!C;W)R=7!T:6]N(&5R<F]R.B!I;G9A;&ED(&-H86YN96P@(B<@
M+@T*("`@("`@("`@("`@("`@("1C:&%N;F5L("X@)R(G*3L-"B`@("`@("`@
M?0T*("`@("`@("`D<F5S="`](&YE=R!014%27U)%4U0H)'1H:7,M/F-O;F9I
M9RD[#0H@("`@("`@(%!%05(Z.G-T871I8U!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L-"B`@("`@("`@)&$@/2`D<F5S="T^9&]W;FQO
M861(='1P*"=H='1P.B\O)R`N("1C:&%N;F5L("X-"B`@("`@("`@("`@("<O
M8VAA;FYE;"YX;6PG+"`D8VAA;BT^;&%S=$UO9&EF:65D*"DI.PT*("`@("`@
M("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@(&EF
M("@A4$5!4CHZ:7-%<G)O<B@D82D@)B8@)&$I('L-"B`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@G5T%23DE.1SH@8VAA;FYE;"`B)R`N("1C
M:&%N;F5L("X@)R(@:&%S("<@+@T*("`@("`@("`@("`@("`@("=U<&1A=&5D
M(&ET<R!P<F]T;V-O;',L('5S92`B8VAA;FYE;"UU<&1A=&4@)R`N("1C:&%N
M;F5L("X-"B`@("`@("`@("`@("`@("`G(B!T;R!U<&1A=&4G*3L-"B`@("`@
M("`@?0T*("`@('T-"@T*("`@("\O('M[>R!D;U)E;6]T94EN9F\H*0T*#0H@
M("`@9G5N8W1I;VX@9&]296UO=&5);F9O*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@
M(3T@,2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"(D8V]M;6%N9"!E>'!E8W1S(&]N92!P87)A;3H@=&AE(')E;6]T92!P86-K
M86=E(&YA;64B*3L-"B`@("`@("`@?0T*("`@("`@("`D<V%V96-H86YN96P@
M/2`D8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RD[#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G
M:7-T<GDH*3L-"B`@("`@("`@)'!A8VMA9V4@/2`D<&%R86US6S!=.PT*("`@
M("`@("`D<&%R<V5D(#T@)')E9RT^<&%R<V5086-K86=E3F%M92@D<&%C:V%G
M92P@)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&%R
M<V5D*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"=);G9A;&ED('!A8VMA9V4@;F%M92`B)R`N("1P86-K86=E("X@)R(G*3L-
M"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@)&-H86YN96P@/2`D<&%R
M<V5D6R=C:&%N;F5L)UT[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G
M9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@("`D8VAA;B`]
M("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R4W1A='5S
M*"1C:&%N;F5L+"`D8VAA;BDI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[
M#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H
M)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@
M("`@("`@("`@("`@("1B87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q
M+C`G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI
M('L-"B`@("`@("`@("`@("1R97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%
M4U0H)S$N,"<L(&%R<F%Y*"DI.PT*("`@("`@("`@("`@)&EN9F\@/2`D<F5S
M="T^<&%C:V%G94EN9F\H)&)A<V4L("1P87)S961;)W!A8VMA9V4G72D[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]("8D=&AI<RT^8V]N
M9FEG+3YG971296UO=&4H*3L-"B`@("`@("`@("`@("1I;F9O(#T@)'(M/F-A
M;&PH)W!A8VMA9V4N:6YF;R<L("1P87)S961;)W!A8VMA9V4G72D[#0H@("`@
M("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&EN9F\I*2![#0H@
M("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE
M;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)&EN9F\I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)&EN9F];)VYA;64G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@G3F\@<F5M;W1E('!A8VMA9V4@(B<@+B`D<&%C
M:V%G92`N("<B('=A<R!F;W5N9"<I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*"1I;F9O6R=N86UE)UTL
M(&YU;&PL("1C:&%N;F5L*3L-"B`@("`@("`@)&EN9F];)VEN<W1A;&QE9"==
M(#T@)&EN<W1A;&QE9%LG=F5R<VEO;B==(#\@)&EN<W1A;&QE9%LG=F5R<VEO
M;B==(#H@)RT@;F\@+2<[#0H@("`@("`@(&EF("AI<U]A<G)A>2@D:6YF;ULG
M:6YS=&%L;&5D)UTI*2![#0H@("`@("`@("`@("`D:6YF;ULG:6YS=&%L;&5D
M)UT@/2`D:6YF;ULG:6YS=&%L;&5D)UU;)W)E;&5A<V4G73L-"B`@("`@("`@
M?0T*#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D:6YF;RP@)&-O
M;6UA;F0I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?
M8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O4F5M;W1E
M3&ES="@I#0H-"B`@("!F=6YC=&EO;B!D;U)E;6]T94QI<W0H)&-O;6UA;F0L
M("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'-A=F5C:&%N
M;F5L(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?
M8VAA;FYE;"<I.PT*("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E
M=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG8VAA
M;FYE;"==*2D@>PT*("`@("`@("`@("`@)&-H86YN96P@/2`D;W!T:6]N<ULG
M8VAA;FYE;"==.PT*("`@("`@("`@("`@:68@*"1R96<M/F-H86YN96Q%>&ES
M=',H)&-H86YN96PI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/F-O;F9I
M9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D8VAA;FYE;"D[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@G0VAA;FYE;"`B)R`N("1C:&%N;F5L("X@)R(@9&]E<R!N
M;W0@97AI<W0G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("`D8VAA;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]("1T:&ES+3Y?8VAE8VM#:&%N;F5L
M1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA;BDI*2![#0H@("`@("`@("`@("!R
M971U<FX@)&4[#0H@("`@("`@('T-"B`@("`@("`@)&QI<W1?;W!T:6]N<R`]
M(&9A;'-E.PT*("`@("`@("!I9B`H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F
M97)R961?<W1A=&4G*2`]/2`G<W1A8FQE)RD@>PT*("`@("`@("`@("`@)&QI
M<W1?;W!T:6]N<R`]('1R=64[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1C
M:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R
M961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B87-E(#T@)&-H86XM
M/F=E=$)A<V554DPH)U)%4U0Q+C$G+"`D=&AI<RT^8V]N9FEG+3YG970H)W!R
M969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@("\O('5S92!F87-T
M97(@;&ES="UA;&P@:68@879A:6QA8FQE#0H@("`@("`@("`@("`D<F5S="`]
M("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C$G+"!A<G)A>2@I*3L-"B`@
M("`@("`@("`@("1A=F%I;&%B;&4@/2`D<F5S="T^;&ES=$%L;"@D8F%S92P@
M)&QI<W1?;W!T:6]N<RD[#0H@("`@("`@('T@96QS96EF("@D8VAA;BT^<W5P
M<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O
M<B<I*2`F)@T*("`@("`@("`@("`@("`D8F%S92`]("1C:&%N+3YG971"87-E
M55),*"=215-4,2XP)RP@)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?
M;6ER<F]R)RDI*2![#0H@("`@("`@("`@("`D<F5S="`]("8D=&AI<RT^8V]N
M9FEG+3YG971215-4*"<Q+C`G+"!A<G)A>2@I*3L-"B`@("`@("`@("`@("1A
M=F%I;&%B;&4@/2`D<F5S="T^;&ES=$%L;"@D8F%S92P@)&QI<W1?;W!T:6]N
M<RD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`D<B`]("8D=&AI
M<RT^8V]N9FEG+3YG971296UO=&4H*3L-"B`@("`@("`@("`@(&EF("@D8VAA
M;FYE;"`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("\O
M(&AA8VL@8F5C875S92!O9B!P;V]R('!E87)W96(@9&5S:6=N#0H@("`@("`@
M("`@("`@("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E+FQI<W1!
M;&PG+"!T<G5E+"`D;&ES=%]O<'1I;VYS+"!F86QS92D[#0H@("`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1A=F%I;&%B;&4@/2`D<BT^
M8V%L;"@G<&%C:V%G92YL:7-T06QL)RP@=')U92P@)&QI<W1?;W!T:6]N<RD[
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z
M.FES17)R;W(H)&%V86EL86)L92DI('L-"B`@("`@("`@("`@("1T:&ES+3YC
M;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA
M8FQE*3L-"B`@("`@("`@?0T*("`@("`@("`D:2`]("1J(#T@,#L-"B`@("`@
M("`@)&1A=&$@/2!A<G)A>2@-"B`@("`@("`@("`@("=C87!T:6]N)R`]/B`G
M0VAA;FYE;"`G("X@)&-H86YN96P@+B`G($%V86EL86)L92!P86-K86=E<SHG
M+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@("`@
M("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA9V4G+"`G5F5R<VEO;B<I+`T*
M("`@("`@("`@("`@*3L-"B`@("`@("`@:68@*&-O=6YT*"1A=F%I;&%B;&4I
M/3TP*2![#0H@("`@("`@("`@("`D9&%T82`]("<H;F\@<&%C:V%G97,@879A
M:6QA8FQE('EE="DG.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M9F]R96%C:"`H)&%V86EL86)L92!A<R`D;F%M92`]/B`D:6YF;RD@>PT*("`@
M("`@("`@("`@("`@("1D871A6R=D871A)UU;72`](&%R<F%Y*"1N86UE+"`H
M:7-S970H)&EN9F];)W-T86)L92==*2`F)B`D:6YF;ULG<W1A8FQE)UTI#0H@
M("`@("`@("`@("`@("`@("`@(#\@)&EN9F];)W-T86)L92==(#H@)RUN+V$M
M)RD[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M
M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@("`@("1T
M:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N
M;F5L*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&1O3&ES=$%L;"@I#0H-"B`@("!F=6YC=&EO;B!D
M;TQI<W1!;&PH)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-
M"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@/2`D=&AI<RT^8V]N
M9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D<F5G(#T@
M)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG8VAA;FYE;"==*2D@>PT*("`@("`@("`@("`@)&-H
M86YN96P@/2`D;W!T:6]N<ULG8VAA;FYE;"==.PT*("`@("`@("`@("`@:68@
M*"1R96<M/F-H86YN96Q%>&ES=',H)&-H86YN96PI*2![#0H@("`@("`@("`@
M("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D
M8VAA;FYE;"D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B0VAA;FYE;"!<(B1C:&%N
M;F5L7"(@9&]E<R!N;W0@97AI<W0B*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D;&ES=%]O<'1I;VYS(#T@9F%L<V4[#0H@("`@("`@
M(&EF("@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I(#T]
M("=S=&%B;&4G*2![#0H@("`@("`@("`@("`D;&ES=%]O<'1I;VYS(#T@=')U
M93L-"B`@("`@("`@?0T*("`@("`@("`D8VAA;B`]("1R96<M/F=E=$-H86YN
M96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92`]
M("1T:&ES+3Y?8VAE8VM#:&%N;F5L1F]R4W1A='5S*"1C:&%N;F5L+"`D8VAA
M;BDI*2![#0H@("`@("`@("`@("!R971U<FX@)&4[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^
M9V5T*"=P<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B
M87-E(#T@)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C$G+"`D=&AI<RT^8V]N
M9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@
M("\O('5S92!F87-T97(@;&ES="UA;&P@:68@879A:6QA8FQE#0H@("`@("`@
M("`@("`D<F5S="`]("8D=&AI<RT^8V]N9FEG+3YG971215-4*"<Q+C$G+"!A
M<G)A>2@I*3L-"B`@("`@("`@("`@("1A=F%I;&%B;&4@/2`D<F5S="T^;&ES
M=$%L;"@D8F%S92P@)&QI<W1?;W!T:6]N<RP@9F%L<V4I.PT*("`@("`@("!]
M(&5L<V5I9B`H)&-H86XM/G-U<'!O<G1S4D535"@D=&AI<RT^8V]N9FEG+3YG
M970H)W!R969E<G)E9%]M:7)R;W(G*2D@)B8-"B`@("`@("`@("`@("`@)&)A
M<V4@/2`D8VAA;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF
M:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@
M)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4D535"@G,2XP)RP@87)R87DH
M*2D[#0H@("`@("`@("`@("`D879A:6QA8FQE(#T@)')E<W0M/FQI<W1!;&PH
M)&)A<V4L("1L:7-T7V]P=&EO;G,L(&9A;'-E*3L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@("1R(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T
M92@I.PT*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=P96%R+G!H<"YN
M970G*2![#0H@("`@("`@("`@("`@("`@+R\@:&%C:R!B96-A=7-E(&]F('!O
M;W(@<&5A<G=E8B!D97-I9VX-"B`@("`@("`@("`@("`@("`D879A:6QA8FQE
M(#T@)'(M/F-A;&PH)W!A8VMA9V4N;&ES=$%L;"<L('1R=64L("1L:7-T7V]P
M=&EO;G,L(&9A;'-E*3L-"B`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E+FQI<W1!
M;&PG+"!T<G5E+"`D;&ES=%]O<'1I;VYS*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?0T*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D879A:6QA8FQE
M*2D@>PT*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT
M7V-H86YN96PG+"`D<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YR86ES945R<F]R*"=4:&4@<&%C:V%G92!L:7-T(&-O=6QD(&YO
M="!B92!F971C:&5D(&9R;VT@=&AE(')E;6]T92!S97)V97(N(%!L96%S92!T
M<GD@86=A:6XN("A$96)U9R!I;F9O.B`B)R`N("1A=F%I;&%B;&4M/F=E=$UE
M<W-A9V4H*2`N("<B*2<I.PT*("`@("`@("!]#0H@("`@("`@("1D871A(#T@
M87)R87DH#0H@("`@("`@("`@("`G8V%P=&EO;B<@/3X@)T%L;"!P86-K86=E
M<SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@=')U92P-"B`@("`@("`@
M("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA9V4G+"`G3&%T97-T)RP@
M)TQO8V%L)RDL#0H@("`@("`@("`@("`I.PT*("`@("`@("`D;&]C86Q?<&MG
M<R`]("1R96<M/FQI<W1086-K86=E<R@D8VAA;FYE;"D[#0H-"B`@("`@("`@
M9F]R96%C:"`H)&%V86EL86)L92!A<R`D;F%M92`]/B`D:6YF;RD@>PT*("`@
M("`@("`@("`@)&EN<W1A;&QE9"`]("1R96<M/G!A8VMA9V5);F9O*"1N86UE
M+"!N=6QL+"`D8VAA;FYE;"D[#0H@("`@("`@("`@("!I9B`H:7-?87)R87DH
M)&EN<W1A;&QE9%LG=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("1I
M;G-T86QL961;)W9E<G-I;VXG72`]("1I;G-T86QL961;)W9E<G-I;VXG75LG
M<F5L96%S92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&1E<V,@
M/2`D:6YF;ULG<W5M;6%R>2==.PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P
M87)A;7-;)&YA;65=*2D@>PT*("`@("`@("`@("`@("`@("1D97-C("X](")<
M;EQN(BXD:6YF;ULG9&5S8W)I<'1I;VXG73L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;6]D92==*2D-"B`@("`@
M("`@("`@('L-"B`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;G-;)VUO9&4G
M72`]/2`G:6YS=&%L;&5D)R`F)B`A:7-S970H)&EN<W1A;&QE9%LG=F5R<VEO
M;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1O<'1I;VYS6R=M
M;V1E)UT@/3T@)VYO=&EN<W1A;&QE9"<@)B8@:7-S970H)&EN<W1A;&QE9%LG
M=F5R<VEO;B==*2D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"1O<'1I
M;VYS6R=M;V1E)UT@/3T@)W5P9W)A9&5S)PT*("`@("`@("`@("`@("`@("`@
M("`@("8F("@A:7-S970H)&EN<W1A;&QE9%LG=F5R<VEO;B==*2!\?"!V97)S
M:6]N7V-O;7!A<F4H)&EN<W1A;&QE9%LG=F5R<VEO;B==+`T*("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G72P@)SX])RDI*2![#0H@("`@
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1P;W,@/2!A<G)A>5]S96%R
M8V@H<W1R=&]L;W=E<B@D;F%M92DL("1L;V-A;%]P:V=S*3L-"B`@("`@("`@
M("`@(&EF("@D<&]S("$]/2!F86QS92D@>PT*("`@("`@("`@("`@("`@('5N
M<V5T*"1L;V-A;%]P:V=S6R1P;W-=*3L-"B`@("`@("`@("`@('T-"@T*("`@
M("`@("`@("`@:68@*&ES<V5T*"1I;F9O6R=S=&%B;&4G72D@)B8@(21I;F9O
M6R=S=&%B;&4G72D@>PT*("`@("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G
M72`](&YU;&P[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D9&%T85LG
M9&%T82==6R1I;F9O6R=C871E9V]R>2==75M=(#T@87)R87DH#0H@("`@("`@
M("`@("`@("`@)')E9RT^8VAA;FYE;$%L:6%S*"1C:&%N;F5L*2`N("<O)R`N
M("1N86UE+`T*("`@("`@("`@("`@("`@($`D:6YF;ULG<W1A8FQE)UTL#0H@
M("`@("`@("`@("`@("`@0"1I;G-T86QL961;)W9E<G-I;VXG72P-"B`@("`@
M("`@("`@("`@("!`)&1E<V,L#0H@("`@("`@("`@("`@("`@0"1I;F9O6R=D
M97!S)UTL#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*#0H@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG;6]D92==*2`F)B!I;E]A<G)A>2@D
M;W!T:6]N<ULG;6]D92==+"!A<G)A>2@G;F]T:6YS=&%L;&5D)RP@)W5P9W)A
M9&5S)RDI*2![#0H@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E
M9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("`@("`D
M=&AI<RT^=6DM/F]U='!U=$1A=&$H)&1A=&$L("1C;VUM86YD*3L-"B`@("`@
M("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@("`@("`@(&9O<F5A
M8V@@*"1L;V-A;%]P:V=S(&%S("1N86UE*2![#0H@("`@("`@("`@("`D:6YF
M;R`]("8D<F5G+3YG971086-K86=E*"1N86UE+"`D8VAA;FYE;"D[#0H@("`@
M("`@("`@("`D9&%T85LG9&%T82==6R=,;V-A;"==6UT@/2!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`D<F5G+3YC:&%N;F5L06QI87,H)&-H86YN96PI("X@
M)R\G("X@)&EN9F\M/F=E=%!A8VMA9V4H*2P-"B`@("`@("`@("`@("`@("`G
M)RP-"B`@("`@("`@("`@("`@("`D:6YF;RT^9V5T5F5R<VEO;B@I+`T*("`@
M("`@("`@("`@("`@("1I;F9O+3YG9713=6UM87)Y*"DL#0H@("`@("`@("`@
M("`@("`@)&EN9F\M/F=E=$1E<',H*0T*("`@("`@("`@("`@("`@("D[#0H@
M("`@("`@('T-"@T*("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H)V1E9F%U
M;'1?8VAA;FYE;"<L("1S879E8VAA;FYE;"D[#0H@("`@("`@("1T:&ES+3YU
M:2T^;W5T<'5T1&%T82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&]3
M96%R8V@H*0T*#0H@("`@9G5N8W1I;VX@9&]396%R8V@H)&-O;6UA;F0L("1O
M<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@*"@A:7-S970H
M)'!A<F%M<ULP72D@?'P@96UP='DH)'!A<F%M<ULP72DI#0H@("`@("`@("`@
M("`F)B`H(6ES<V5T*"1P87)A;7-;,5TI('Q\(&5M<'1Y*"1P87)A;7-;,5TI
M*2D-"B`@("`@("`@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=N;R!V86QI9"!S96%R8V@@<W1R:6YG('-U<'!L:65D)RD[#0H@
M("`@("`@('T[#0H-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@
M/2`D=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@
M("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@
M("`@("`@("1P86-K86=E(#T@)'!A<F%M<ULP73L-"B`@("`@("`@)'-U;6UA
M<GD@/2!I<W-E="@D<&%R86US6S%=*2`_("1P87)A;7-;,5T@.B!F86QS93L-
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=C:&%N;F5L)UTI*2![#0H@
M("`@("`@("`@("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y
M*"D[#0H@("`@("`@("`@("`D8VAA;FYE;"`]("1O<'1I;VYS6R=C:&%N;F5L
M)UT[#0H@("`@("`@("`@("!I9B`H)')E9RT^8VAA;FYE;$5X:7-T<R@D8VAA
M;FYE;"DI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^8V]N9FEG+3YS970H
M)V1E9F%U;'1?8VAA;FYE;"<L("1C:&%N;F5L*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B!D;V5S(&YO="!E>&ES
M="<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@("1C:&%N
M(#T@)')E9RT^9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1E(#T@)'1H:7,M/E]C:&5C:T-H86YN96Q&;W)3=&%T
M=7,H)&-H86YN96PL("1C:&%N*2DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M93L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)&-H86XM/G-U<'!O<G1S4D53
M5"@D=&AI<RT^8V]N9FEG+3YG970H)W!R969E<G)E9%]M:7)R;W(G*2D@)B8-
M"B`@("`@("`@("`@("`@)&)A<V4@/2`D8VAA;BT^9V5T0F%S95523"@G4D53
M5#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O<B<I
M*2D@>PT*("`@("`@("`@("`@)')E<W0@/2`F)'1H:7,M/F-O;F9I9RT^9V5T
M4D535"@G,2XP)RP@87)R87DH*2D[#0H@("`@("`@("`@("`D879A:6QA8FQE
M(#T@)')E<W0M/FQI<W1!;&PH)&)A<V4L(&9A;'-E+"!F86QS92P@)'!A8VMA
M9V4L("1S=6UM87)Y*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("1R(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E;6]T92@I.PT*("`@("`@("`@
M("`@)&%V86EL86)L92`]("1R+3YC86QL*"=P86-K86=E+G-E87)C:"<L("1P
M86-K86=E+"`D<W5M;6%R>2P@=')U92P@#0H@("`@("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2`]/2`G<W1A8FQE
M)RP@=')U92D[#0H@("`@("`@('T-"B`@("`@("`@:68@*%!%05(Z.FES17)R
M;W(H)&%V86EL86)L92DI('L-"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M
M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D879A:6QA8FQE*3L-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H(21A=F%I;&%B;&4I('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G;F\@<&%C:V%G97,@
M9F]U;F0@=&AA="!M871C:"!P871T97)N("(G("X@)'!A8VMA9V4@+B`G(B<I
M.PT*("`@("`@("!]#0H@("`@("`@("1D871A(#T@87)R87DH#0H@("`@("`@
M("`@("`G8V%P=&EO;B<@/3X@)TUA=&-H960@<&%C:V%G97,L(&-H86YN96P@
M)R`N("1C:&%N;F5L("X@)SHG+`T*("`@("`@("`@("`@)V)O<F1E<B<@/3X@
M=')U92P-"B`@("`@("`@("`@("=H96%D;&EN92<@/3X@87)R87DH)U!A8VMA
M9V4G+"`G4W1A8FQE+RA,871E<W0I)RP@)TQO8V%L)RDL#0H@("`@("`@("`@
M("`I.PT*#0H@("`@("`@(&9O<F5A8V@@*"1A=F%I;&%B;&4@87,@)&YA;64@
M/3X@)&EN9F\I('L-"B`@("`@("`@("`@("1I;G-T86QL960@/2`D<F5G+3YP
M86-K86=E26YF;R@D;F%M92P@;G5L;"P@)&-H86YN96PI.PT*("`@("`@("`@
M("`@)&1E<V,@/2`D:6YF;ULG<W5M;6%R>2==.PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1P87)A;7-;)&YA;65=*2D-"B`@("`@("`@("`@("`@("`D9&5S
M8R`N/2`B7&Y<;B(N)&EN9F];)V1E<V-R:7!T:6]N)UT[#0H-"B`@("`@("`@
M("`@("1U;G-T86)L92`]("<G.PT*("`@("`@("`@("`@:68@*"1I;F9O6R=U
M;G-T86)L92==*2![#0H@("`@("`@("`@("`@("`@)'5N<W1A8FQE(#T@)R\H
M)R`N("1I;F9O6R=U;G-T86)L92==("X@)R`G("X@)&EN9F];)W-T871E)UT@
M+B`G*2<[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1I;F9O6R=S=&%B;&4G72D@?'P@(21I;F9O6R=S=&%B;&4G72D@>PT*("`@
M("`@("`@("`@("`@("1I;F9O6R=S=&%B;&4G72`]("=N;VYE)SL-"B`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("1V97)S:6]N(#T@:7-?87)R87DH)&EN
M<W1A;&QE9%LG=F5R<VEO;B==*2`_("1I;G-T86QL961;)W9E<G-I;VXG75LG
M<F5L96%S92==(#H-"B`@("`@("`@("`@("`@("`D:6YS=&%L;&5D6R=V97)S
M:6]N)UT[#0H@("`@("`@("`@("`D9&%T85LG9&%T82==6R1I;F9O6R=C871E
M9V]R>2==75M=(#T@87)R87DH#0H@("`@("`@("`@("`@("`@)&YA;64L#0H@
M("`@("`@("`@("`@("`@)&EN9F];)W-T86)L92==("X@)'5N<W1A8FQE+`T*
M("`@("`@("`@("`@("`@("1V97)S:6]N+`T*("`@("`@("`@("`@("`@("1D
M97-C+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"1D871A+"`D8V]M;6%N9"D[#0H@("`@
M("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)&-H
M86YN96PI.PT*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O
M+R!]?7T-"B`@("!F=6YC=&EO;B`F9V5T1&]W;FQO861E<B@D;W!T:6]N<RD-
M"B`@("![#0H@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1O=VYL
M;V%D97(G*2D@>PT*("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1O
M=VYL;V%D97(N<&AP)SL-"B`@("`@("`@?0T*("`@("`@("`D82`]("9N97<@
M4$5!4E]$;W=N;&]A9&5R*"1T:&ES+3YU:2P@)&]P=&EO;G,L("1T:&ES+3YC
M;VYF:6<I.PT*("`@("`@("!R971U<FX@)&$[#0H@("`@?0T*("`@("\O('M[
M>R!D;T1O=VYL;V%D*"D-"@T*("`@(&9U;F-T:6]N(&1O1&]W;FQO860H)&-O
M;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@+R\@
M;6%K92!C97)T86EN('1H870@9&5P96YD96YC:65S(&%R92!I9VYO<F5D#0H@
M("`@("`@("1O<'1I;VYS6R=D;W=N;&]A9&]N;'DG72`](#$[#0H@("`@("`@
M("\O(&5L:6UI;F%T92!E<G)O<B!M97-S86=E<R!F;W(@<')E9F5R<F5D7W-T
M871E+7)E;&%T960@97)R;W)S#0H@("`@("`@("1O<'1I;VYS6R=I9VYO<F5P
M<F5F97)R961?<W1A=&4G72`](#$[#0H@("`@("`@("1D;W=N;&]A9&5R(#T@
M)B1T:&ES+3YG971$;W=N;&]A9&5R*"1O<'1I;VYS*3L-"B`@("`@("`@)&1O
M=VYL;V%D97(M/G-E=$1O=VYL;V%D1&ER*&=E=&-W9"@I*3L-"B`@("`@("`@
M)&5R<F]R<R`](&%R<F%Y*"D[#0H@("`@("`@("1D;W=N;&]A9&5D(#T@87)R
M87DH*3L-"B`@("`@("`@)&5R<B`]("1D;W=N;&]A9&5R+3YD;W=N;&]A9"@D
M<&%R86US*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-
M"B`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("!]#0H@("`@("`@
M("1E<G)O<G,@/2`D9&]W;FQO861E<BT^9V5T17)R;W)-<V=S*"D[#0H@("`@
M("`@(&EF("AC;W5N="@D97)R;W)S*2D@>PT*("`@("`@("`@("`@9F]R96%C
M:"`H)&5R<F]R<R!A<R`D97)R;W(I('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)&5R<F]R*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@B)&-O;6UA;F0@
M9F%I;&5D(BD[#0H@("`@("`@('T-"B`@("`@("`@)&1O=VYL;V%D960@/2`D
M9&]W;FQO861E<BT^9V5T1&]W;FQO861E9%!A8VMA9V5S*"D[#0H@("`@("`@
M(&9O<F5A8V@@*"1D;W=N;&]A9&5D(&%S("1P:V<I('L-"B`@("`@("`@("`@
M("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B1FEL92`D<&MG6V9I;&5=(&1O=VYL
M;V%D960B+"`D8V]M;6%N9"D[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9&]W;FQO861#86QL8F%C
M:R@D;7-G+"`D<&%R86US(#T@;G5L;"D-"B`@("![#0H@("`@("`@(&EF("@D
M;7-G(#T]("=D;VYE)RD@>PT*("`@("`@("`@("`@)'1H:7,M/F)Y=&5S7V1O
M=VYL;V%D960@/2`D<&%R86US.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@
M+R\@?7U]#0H@("`@+R\@>WM[(&1O3&ES=%5P9W)A9&5S*"D-"@T*("`@(&9U
M;F-T:6]N(&1O3&ES=%5P9W)A9&5S*"1C;VUM86YD+"`D;W!T:6]N<RP@)'!A
M<F%M<RD-"B`@("![#0H@("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]#;VUM
M;VXN<&AP)SL-"B`@("`@("`@:68@*&ES<V5T*"1P87)A;7-;,%TI("8F("%0
M14%27T-O;6UO;CHZ8F5T=&5R4W1A=&5S*"1P87)A;7-;,%TI*2![#0H@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!A<F%M<ULP72`N
M("<@:7,@;F]T(&$@=F%L:60@<W1A=&4@*'-T86)L92]B971A+V%L<&AA+V1E
M=F5L+V5T8RXI('1R>2`B<&5A<B!H96QP(&QI<W0M=7!G<F%D97,B)RD[#0H@
M("`@("`@('T-"B`@("`@("`@)'-A=F5C:&%N;F5L(#T@)&-H86YN96P@/2`D
M=&AI<RT^8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@
M("`D<F5G(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E9VES=')Y*"D[#0H@("`@
M("`@(&9O<F5A8V@@*"1R96<M/FQI<W1#:&%N;F5L<R@I(&%S("1C:&%N;F5L
M*2![#0H@("`@("`@("`@("`D:6YS="`](&%R<F%Y7V9L:7`H)')E9RT^;&ES
M=%!A8VMA9V5S*"1C:&%N;F5L*2D[#0H@("`@("`@("`@("!I9B`H(6-O=6YT
M*"1I;G-T*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@:68@*"1C:&%N;F5L(#T]("=?7W5R:2<I
M('L-"B`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N
M;F5L)RP@)&-H86YN96PI.PT*("`@("`@("`@("`@:68@*&5M<'1Y*"1P87)A
M;7-;,%TI*2![#0H@("`@("`@("`@("`@("`@)'-T871E(#T@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*3L-"B`@("`@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`@("`@)'-T871E(#T@)'!A<F%M<ULP73L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1C87!T:6]N(#T@)&-H86YN
M96P@+B`G($%V86EL86)L92!5<&=R861E<R<[#0H@("`@("`@("`@("`D8VAA
M;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&4@/2`D=&AI<RT^7V-H96-K0VAA;FYE;$9O
M<E-T871U<R@D8VAA;FYE;"P@)&-H86XI*2D@>PT*("`@("`@("`@("`@("`@
M(')E='5R;B`D93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D
M8VAA;BT^<W5P<&]R='-215-4*"1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R
M<F5D7VUI<G)O<B<I*2`F)@T*("`@("`@("`@("`@("`@("`@)&)A<V4@/2`D
M8VAA;BT^9V5T0F%S95523"@G4D535#$N,"<L("1T:&ES+3YC;VYF:6<M/F=E
M="@G<')E9F5R<F5D7VUI<G)O<B<I*2D@>PT*("`@("`@("`@("`@("`@("1R
M97-T(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y*"DI
M.PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\("1S=&%T
M92`]/2`G86YY)RD@>PT*("`@("`@("`@("`@("`@("`@("`D<W1A=&4@/2!F
M86QS93L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D8V%P=&EO;B`N/2`G("@G("X@:6UP;&]D92@G+"`G+"!014%2
M7T-O;6UO;CHZ8F5T=&5R4W1A=&5S*"1S=&%T92P@=')U92DI("X@)RDG.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIS=&%T
M:6-0=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@
M("`@("`@("`@("`@)&QA=&5S="`]("1R97-T+3YL:7-T3&%T97-T57!G<F%D
M97,H)&)A<V4L("1S=&%T92P@)&EN<W0L("1C:&%N;F5L+"`D<F5G*3L-"B`@
M("`@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1R96UO
M=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[#0H@("`@("`@("`@
M("`@("`@)')E;6]T92T^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@("`@(&EF("AE;7!T>2@D<W1A=&4I('Q\
M("1S=&%T92`]/2`G86YY)RD@>PT*("`@("`@("`@("`@("`@("`@("`D;&%T
M97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T3&%T97-T4F5L96%S
M97,B*3L-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M("`@("`@("`D;&%T97-T(#T@)')E;6]T92T^8V%L;"@B<&%C:V%G92YL:7-T
M3&%T97-T4F5L96%S97,B+"`D<W1A=&4I.PT*("`@("`@("`@("`@("`@("`@
M("`D8V%P=&EO;B`N/2`G("@G("X@:6UP;&]D92@G+"`G+"!014%27T-O;6UO
M;CHZ8F5T=&5R4W1A=&5S*"1S=&%T92P@=')U92DI("X@)RDG.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<F5M;W1E+3YP;W!%<G)O
M<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D;&%T97-T*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82@D;&%T97-T+3YG971-97-S86=E*"DI.PT*
M("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@)&-A<'1I;VX@+CT@)SHG.PT*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&QA=&5S="DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^8V]N9FEG+3YS970H)V1E9F%U;'1?8VAA;FYE;"<L("1S879E8VAA;FYE
M;"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1L871E<W0[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*`T*("`@("`@("`@
M("`@("`@("=C87!T:6]N)R`]/B`D8V%P=&EO;BP-"B`@("`@("`@("`@("`@
M("`G8F]R9&5R)R`]/B`Q+`T*("`@("`@("`@("`@("`@("=H96%D;&EN92<@
M/3X@87)R87DH)T-H86YN96PG+"`G4&%C:V%G92<L("=,;V-A;"<L("=296UO
M=&4G+"`G4VEZ92<I+`T*("`@("`@("`@("`@("`@("D[#0H@("`@("`@("`@
M("!F;W)E86-H("@H87)R87DI)&QA=&5S="!A<R`D<&MG(#T^("1I;F9O*2![
M#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2!S=')T;VQO=V5R*"1P:V<I
M.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&EN<W1;)'!A8VMA9V5=
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`O+R!S:VEP('!A8VMA9V5S('=E
M(&1O;B=T(&AA=F4@:6YS=&%L;&5D#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!E
M>'1R86-T*"1I;F9O*3L-"B`@("`@("`@("`@("`@("`D:6YS=%]V97)S:6]N
M(#T@)')E9RT^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H
M86YN96PI.PT*("`@("`@("`@("`@("`@("1I;G-T7W-T871E("`@/2`D<F5G
M+3YP86-K86=E26YF;R@D<&%C:V%G92P@)W)E;&5A<V5?<W1A=&4G+"`D8VAA
M;FYE;"D[#0H@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@B
M)'9E<G-I;VXB+"`B)&EN<W1?=F5R<VEO;B(L(")L92(I*2![#0H@("`@("`@
M("`@("`@("`@("`@("\O(&EN<W1A;&QE9"!V97)S:6]N(&ES('5P+71O+61A
M=&4-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@D9FEL97-I>F4@/CT@,C`T
M.#`I('L-"B`@("`@("`@("`@("`@("`@("`@)&9I;&5S:7IE("L](#$P,C0@
M+2`H)&9I;&5S:7IE("4@,3`R-"D[#0H@("`@("`@("`@("`@("`@("`@("1F
M<R`]('-P<FEN=&8H(B5D:T(B+"`D9FEL97-I>F4@+R`Q,#(T*3L-"B`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)&9I;&5S:7IE(#X@,"D@>PT*("`@("`@
M("`@("`@("`@("`@("`D9FEL97-I>F4@*ST@,3`S("T@*"1F:6QE<VEZ92`E
M(#$P,RD[#0H@("`@("`@("`@("`@("`@("`@("1F<R`]('-P<FEN=&8H(B4N
M,69K0B(L("1F:6QE<VEZ92`O(#$P,C0N,"D[#0H@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)&9S(#T@(B`@+2([("\O
M(%A86"!C96YT97(@:6YS=&5A9`T*("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`D9&%T85LG9&%T82==6UT@/2!A<G)A>2@D8VAA;FYE;"P@
M)'!K9RP@(B1I;G-T7W9E<G-I;VX@*"1I;G-T7W-T871E*2(L("(D=F5R<VEO
M;B`H)'-T871E*2(L("1F<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@
M("!I9B`H96UP='DH)&1A=&%;)V1A=&$G72DI('L-"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H)T-H86YN96P@)R`N("1C:&%N;F5L
M("X@)SH@3F\@=7!G<F%D97,@879A:6QA8FQE)RD[#0H@("`@("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@D9&%T82P@)&-O;6UA;F0I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L
M)RP@)'-A=F5C:&%N;F5L*3L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*#0H@("`@+R\@?7U]#0H@("`@+R\@>WM[(&1O0VQE87)#86-H92@I#0H-
M"B`@("!F=6YC=&EO;B!D;T-L96%R0V%C:&4H)&-O;6UA;F0L("1O<'1I;VYS
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)&-A8VAE7V1I<B`]("1T:&ES
M+3YC;VYF:6<M/F=E="@G8V%C:&5?9&ER)RD[#0H@("`@("`@("1V97)B;W-E
M(#T@)'1H:7,M/F-O;F9I9RT^9V5T*"=V97)B;W-E)RD[#0H@("`@("`@("1O
M=71P=70@/2`G)SL-"B`@("`@("`@:68@*"$H)&1P(#T@0&]P96YD:7(H)&-A
M8VAE7V1I<BDI*2![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H(F]P96YD:7(H)&-A8VAE7V1I<BD@9F%I;&5D.B`D<&AP7V5R<F]R
M;7-G(BD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1V97)B;W-E(#X](#$I
M('L-"B`@("`@("`@("`@("1O=71P=70@+CT@(G)E861I;F<@9&ER96-T;W)Y
M("1C86-H95]D:7)<;B([#0H@("`@("`@('T-"B`@("`@("`@)&YU;2`](#`[
M#0H@("`@("`@('=H:6QE("@D96YT(#T@<F5A9&1I<B@D9'`I*2![#0H@("`@
M("`@("`@("!I9B`H<')E9U]M871C:"@G+UYX;6QR<&-?8V%C:&5?6V$M>C`M
M.5U[,S)])"\G+"`D96YT*2!\?`T*("`@("`@("`@("`@("`@("`@<')E9U]M
M871C:"@G+W)E<W0N8V%C:&4H9FEL97QI9"DD+R<L("1E;G0I*2![#0H@("`@
M("`@("`@("`@("`@)'!A=&@@/2`D8V%C:&5?9&ER("X@1$E214-43U)97U-%
M4$%2051/4B`N("1E;G0[#0H@("`@("`@("`@("`@("`@)&]K(#T@0'5N;&EN
M:R@D<&%T:"D[#0H@("`@("`@("`@("`@("`@:68@*"1O:RD@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'9E<F)O<V4@/CT@,BD@>PT*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`B9&5L971E9"`D<&%T:%QN(CL-
M"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D
M;G5M*RL[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1V97)B;W-E(#X]
M(#$I('L-"B`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B9F%I;&5D
M('1O(&1E;&5T92`D<&%T:%QN(CL-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@8VQO<V5D:7(H)&1P*3L-
M"B`@("`@("`@:68@*"1V97)B;W-E(#X](#$I('L-"B`@("`@("`@("`@("1O
M=71P=70@+CT@(B1N=6T@8V%C:&4@96YT<FEE<R!C;&5A<F5D7&XB.PT*("`@
M("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82AR=')I;2@D
M;W5T<'5T*2P@)&-O;6UA;F0I.PT*("`@("`@("!R971U<FX@)&YU;3L-"B`@
M("!]#0H-"B`@("`O+R!]?7T-"GT-"@T*/SX-"@``````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+TUI<G)O<BYX;6P`````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3$W,B`Q,#4Q-30S-#$S-"`P,C(U
M-C0`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/&-O;6UA;F1S('9E<G-I;VX](C$N,"(^#0H@/&1O=VYL;V%D+6%L;#X-"B`@
M/'-U;6UA<GD^1&]W;FQO861S(&5A8V@@879A:6QA8FQE('!A8VMA9V4@9G)O
M;2!T:&4@9&5F875L="!C:&%N;F5L/"]S=6UM87)Y/@T*("`\9G5N8W1I;VX^
M9&]$;W=N;&]A9$%L;#PO9G5N8W1I;VX^#0H@(#QS:&]R=&-U=#YD83PO<VAO
M<G1C=70^#0H@(#QO<'1I;VYS/@T*("`@/&-H86YN96P^#0H@("`@/'-H;W)T
M;W!T/F,\+W-H;W)T;W!T/@T*("`@(#QD;V,^<W!E8VEF>2!A(&-H86YN96P@
M;W1H97(@=&AA;B!T:&4@9&5F875L="!C:&%N;F5L/"]D;V,^#0H@("`@/&%R
M9SY#2$%./"]A<F<^#0H@("`\+V-H86YN96P^#0H@(#PO;W!T:6]N<SX-"B`@
M/&1O8SX-"E)E<75E<W1S(&$@;&ES="!O9B!A=F%I;&%B;&4@<&%C:V%G97,@
M9G)O;2!T:&4@9&5F875L="!C:&%N;F5L("A[8V]N9FEG(&1E9F%U;'1?8VAA
M;FYE;'TI#0IA;F0@9&]W;FQO861S('1H96T@=&\@8W5R<F5N="!W;W)K:6YG
M(&1I<F5C=&]R>2X@($YO=&4Z(&]N;'D-"G!A8VMA9V5S('=I=&AI;B!P<F5F
M97)R961?<W1A=&4@*'MC;VYF:6<@<')E9F5R<F5D7W-T871E?2D@=VEL;"!B
M92!D;W=N;&]A9&5D/"]D;V,^#0H@/"]D;W=N;&]A9"UA;&P^#0H\+V-O;6UA
M;F1S/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]#;VUM86YD+TUI<G)O<BYP:'``````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C0U,B`Q,#4Q-30S-#$S
M-"`P,C(U-38`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`-"B\J*@T*("H@4$5!4E]#;VUM86YD7TUI<G)O<B`H9&]W
M;FQO860M86QL(&-O;6UA;F0I#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T
M(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T
M:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I
M;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A
M8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@06QE>&%N9&5R($UE<GH@
M/&%L97AM97)Z0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@36ER<F]R+G!H<"QV(#$N,3@@,C`P-B\P,R\P
M,B`Q.#HQ-#HQ,R!C96QL;V<@17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&
M:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,BXP#0H@*B\-"@T*+RHJ
M#0H@*B!B87-E(&-L87-S#0H@*B\-"G)E<75I<F5?;VYC92`G4$5!4B]#;VUM
M86YD+T-O;6UO;BYP:'`G.PT*#0HO*BH-"B`J(%!%05(@8V]M;6%N9',@9F]R
M('!R;W9I9&EN9R!F:6QE(&UI<G)O<G,-"B`J#0H@*B!`8V%T96=O<GD@("!P
M96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!!;&5X
M86YD97(@365R>B`\86QE>&UE<GI`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR+C`-
M"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7TUI<G)O<B!E>'1E;F1S(%!%05)?
M0V]M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@
M("`@=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G9&]W;FQO860M
M86QL)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G1&]W
M;FQO861S(&5A8V@@879A:6QA8FQE('!A8VMA9V4@9G)O;2!T:&4@9&5F875L
M="!C:&%N;F5L)RP-"B`@("`@("`@("`@("=F=6YC=&EO;B<@/3X@)V1O1&]W
M;FQO861!;&PG+`T*("`@("`@("`@("`@)W-H;W)T8W5T)R`]/B`G9&$G+`T*
M("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*`T*("`@("`@("`@("`@
M("`@("=C:&%N;F5L)R`]/@T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@-
M"B`@("`@("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G8R<L#0H@("`@
M("`@("`@("`@("`@("`@("=D;V,G(#T^("=S<&5C:69Y(&$@8VAA;FYE;"!O
M=&AE<B!T:&%N('1H92!D969A=6QT(&-H86YN96PG+`T*("`@("`@("`@("`@
M("`@("`@("`G87)G)R`]/B`G0TA!3B<L#0H@("`@("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@*2P-"B`@("`@("`@("`@("=D;V,G(#T^
M("<-"E)E<75E<W1S(&$@;&ES="!O9B!A=F%I;&%B;&4@<&%C:V%G97,@9G)O
M;2!T:&4@9&5F875L="!C:&%N;F5L("A[8V]N9FEG(&1E9F%U;'1?8VAA;FYE
M;'TI#0IA;F0@9&]W;FQO861S('1H96T@=&\@8W5R<F5N="!W;W)K:6YG(&1I
M<F5C=&]R>2X@($YO=&4Z(&]N;'D-"G!A8VMA9V5S('=I=&AI;B!P<F5F97)R
M961?<W1A=&4@*'MC;VYF:6<@<')E9F5R<F5D7W-T871E?2D@=VEL;"!B92!D
M;W=N;&]A9&5D)PT*("`@("`@("`@("`@*2P-"B`@("`@("`@*3L-"@T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R#0H-"B`@("`O*BH-
M"B`@("`@*B!014%27T-O;6UA;F1?36ER<F]R(&-O;G-T<G5C=&]R+@T*("`@
M("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B!`<&%R86T@;V)J
M96-T(%!%05)?1G)O;G1E;F0@82!R969E<F5N8V4@=&\@86X@9G)O;G1E;F0-
M"B`@("`@*B!`<&%R86T@;V)J96-T(%!%05)?0V]N9FEG(&$@<F5F97)E;F-E
M('1O('1H92!C;VYF:6=U<F%T:6]N(&1A=&$-"B`@("`@*B\-"B`@("!F=6YC
M=&EO;B!014%27T-O;6UA;F1?36ER<F]R*"8D=6DL("8D8V]N9FEG*0T*("`@
M('L-"B`@("`@("`@<&%R96YT.CI014%27T-O;6UA;F1?0V]M;6]N*"1U:2P@
M)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O*BH-"B`@
M("`@*B!&;W(@=6YI="UT97-T:6YG#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M)F9A8W1O<GDH)&$I#0H@("`@>PT*("`@("`@("`D82`]("9014%27T-O;6UA
M;F0Z.F9A8W1O<GDH)&$L("1T:&ES+3YC;VYF:6<I.PT*("`@("`@("!R971U
M<FX@)&$[#0H@("`@?0T*#0H@("`@+R\@>WM[(&1O1&]W;FQO861!;&PH*0T*
M("`@("\J*@T*("`@("H@<F5T<FEE=F5S(&$@;&ES="!O9B!A=F%I8FQE(%!A
M8VMA9V5S(&9R;VT@;6%S=&5R('-E<G9E<@T*("`@("H@86YD(&1O=VYL;V%D
M<R!T:&5M#0H@("`@*@T*("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`J($!P
M87)A;2!S=')I;F<@)&-O;6UA;F0@=&AE(&-O;6UA;F0-"B`@("`J($!P87)A
M;2!A<G)A>2`D;W!T:6]N<R!T:&4@8V]M;6%N9"!O<'1I;VYS(&)E9F]R92!T
M:&4@8V]M;6%N9`T*("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@=&AE('-T
M=69F(&%F=&5R('1H92!C;VUM86YD(&YA;64-"B`@("`J($!R971U<FX@8F]O
M;"!T<G5E(&EF('-U8V-E<V9U;`T*("`@("H@0'1H<F]W(%!%05)?17)R;W(@
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!D;T1O=VYL;V%D06QL*"1C;VUM86YD
M+"`D;W!T:6]N<RP@)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1S879E8VAA
M;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RD[
M#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5G:7-T<GDH
M*3L-"B`@("`@("`@)&-H86YN96P@/2!I<W-E="@D;W!T:6]N<ULG8VAA;FYE
M;"==*2`_("1O<'1I;VYS6R=C:&%N;F5L)UT@.@T*("`@("`@("`@("`@)'1H
M:7,M/F-O;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*3L-"B`@("`@("`@
M:68@*"$D<F5G+3YC:&%N;F5L17AI<W1S*"1C:&%N;F5L*2D@>PT*("`@("`@
M("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=D969A=6QT7V-H86YN96PG+"`D
M<V%V96-H86YN96PI.PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"=#:&%N;F5L("(G("X@)&-H86YN96P@+B`G(B!D;V5S(&YO="!E
M>&ES="<I.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-E
M="@G9&5F875L=%]C:&%N;F5L)RP@)&-H86YN96PI.PT*("`@("`@("`D=&AI
M<RT^=6DM/F]U='!U=$1A=&$H)U5S:6YG($-H86YN96P@)R`N("1T:&ES+3YC
M;VYF:6<M/F=E="@G9&5F875L=%]C:&%N;F5L)RDI.PT*("`@("`@("`D8VAA
M;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H)'1H:7,M/F-O;F9I9RT^9V5T*"=P
M<F5F97)R961?;6ER<F]R)RDI("8F#0H@("`@("`@("`@("`@("1B87-E(#T@
M)&-H86XM/F=E=$)A<V554DPH)U)%4U0Q+C`G+"`D=&AI<RT^8V]N9FEG+3YG
M970H)W!R969E<G)E9%]M:7)R;W(G*2DI('L-"B`@("`@("`@("`@("1R97-T
M(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)%4U0H)S$N,"<L(&%R<F%Y*"DI.PT*
M("`@("`@("`@("`@)')E;6]T94EN9F\@/2!A<G)A>5]F;&EP*"1R97-T+3YL
M:7-T4&%C:V%G97,H)&)A<V4I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1R96UO=&4@/2`F)'1H:7,M/F-O;F9I9RT^9V5T4F5M;W1E*"D[
M#0H@("`@("`@("`@("`D<W1A8FQE(#T@*"1T:&ES+3YC;VYF:6<M/F=E="@G
M<')E9F5R<F5D7W-T871E)RD@/3T@)W-T86)L92<I.PT*("`@("`@("`@("`@
M)')E;6]T94EN9F\@/2`D<F5M;W1E+3YC86QL*")P86-K86=E+FQI<W1!;&PB
M+"!T<G5E+"`D<W1A8FQE+"!F86QS92D[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)')E;6]T94EN9F\I*2![#0H@("`@("`@("`@
M("!R971U<FX@)')E;6]T94EN9F\[#0H@("`@("`@('T-"B`@("`@("`@)&-M
M9"`]("8D=&AI<RT^9F%C=&]R>2@B9&]W;FQO860B*3L-"B`@("`@("`@:68@
M*%!%05(Z.FES17)R;W(H)&-M9"DI('L-"B`@("`@("`@("`@(')E='5R;B`D
M8VUD.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T
M82@G57-I;F<@4')E9F5R<F5D(%-T871E(&]F("<@+@T*("`@("`@("`@("`@
M)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2D[#0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@G1V%T:&5R:6YG(')E;&5A<V4@
M:6YF;W)M871I;VXL('!L96%S92!W86ET+BXN)RD[#0H@("`@("`@("\J*@T*
M("`@("`@("`@*B!%<G)O<B!H86YD;&EN9R!N;W0@;F5C97-S87)Y+"!B96-A
M=7-E(&%L<F5A9'D@9&]N92!B>2`-"B`@("`@("`@("H@=&AE(&1O=VYL;V%D
M(&-O;6UA;F0-"B`@("`@("`@("HO#0H@("`@("`@(%!%05(Z.G-T871I8U!U
M<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L-"B`@("`@("`@
M)&5R<B`]("1C;60M/G)U;B@G9&]W;FQO860G+"!A<G)A>2@G9&]W;FQO861O
M;FQY)R`]/B!T<G5E*2P@87)R87E?:V5Y<R@D<F5M;W1E26YF;RDI.PT*("`@
M("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@
M("1T:&ES+3YC;VYF:6<M/G-E="@G9&5F875L=%]C:&%N;F5L)RP@)'-A=F5C
M:&%N;F5L*3L-"B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-
M"B`@("`@("`@("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@D97)R+3YG971-
M97-S86=E*"DI.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*
M("`@('T-"@T*("`@("\O('U]?0T*?0T*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!
M4B]#;VUM86YD+U1E<W0N>&UL````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,C,R,B`Q,#4Q-30S-#$S-"`P,C(R,C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/&-O;6UA;F1S('9E<G-I
M;VX](C$N,"(^#0H@/')U;BUT97-T<SX-"B`@/'-U;6UA<GD^4G5N(%)E9W)E
M<W-I;VX@5&5S=',\+W-U;6UA<GD^#0H@(#QF=6YC=&EO;CYD;U)U;E1E<W1S
M/"]F=6YC=&EO;CX-"B`@/'-H;W)T8W5T/G)T/"]S:&]R=&-U=#X-"B`@/&]P
M=&EO;G,^#0H@("`\<F5C=7(^#0H@("`@/'-H;W)T;W!T/G(\+W-H;W)T;W!T
M/@T*("`@(#QD;V,^4G5N('1E<W1S(&EN(&-H:6QD(&1I<F5C=&]R:65S+"!R
M96-U<G-I=F5L>2X@(#0@9&ER<R!D965P(&UA>&EM=6T\+V1O8SX-"B`@(#PO
M<F5C=7(^#0H@("`\:6YI/@T*("`@(#QS:&]R=&]P=#YI/"]S:&]R=&]P=#X-
M"B`@("`\9&]C/F%C='5A;"!S=')I;F<@;V8@<V5T=&EN9W,@=&\@<&%S<R!T
M;R!P:'`@:6X@9F]R;6%T("9Q=6]T.R`M9"!S971T:6YG/6)L86@F<75O=#L\
M+V1O8SX-"B`@("`\87)G/E-%5%1)3D=3/"]A<F<^#0H@("`\+VEN:3X-"B`@
M(#QR96%L=&EM96QO9SX-"B`@("`\<VAO<G1O<'0^;#PO<VAO<G1O<'0^#0H@
M("`@/&1O8SY,;V<@=&5S="!R=6YS+W)E<W5L=',@87,@=&AE>2!A<F4@<G5N
M/"]D;V,^#0H@("`\+W)E86QT:6UE;&]G/@T*("`@/'%U:65T/@T*("`@(#QS
M:&]R=&]P=#YQ/"]S:&]R=&]P=#X-"B`@("`\9&]C/D]N;'D@9&ES<&QA>2!D
M971A:6P@9F]R(&9A:6QE9"!T97-T<SPO9&]C/@T*("`@/"]Q=6EE=#X-"B`@
M(#QS:6UP;&4^#0H@("`@/'-H;W)T;W!T/G,\+W-H;W)T;W!T/@T*("`@(#QD
M;V,^1&ES<&QA>2!S:6UP;&4@;W5T<'5T(&9O<B!A;&P@=&5S=',\+V1O8SX-
M"B`@(#PO<VEM<&QE/@T*("`@/'!A8VMA9V4^#0H@("`@/'-H;W)T;W!T/G`\
M+W-H;W)T;W!T/@T*("`@(#QD;V,^5')E870@<&%R86UE=&5R<R!A<R!I;G-T
M86QL960@<&%C:V%G97,@9G)O;2!W:&EC:"!T;R!R=6X@=&5S=',\+V1O8SX-
M"B`@(#PO<&%C:V%G93X-"B`@(#QP:'!U;FET/@T*("`@(#QS:&]R=&]P=#YU
M/"]S:&]R=&]P=#X-"B`@("`\9&]C/E-E87)C:"!P87)A;65T97)S(&9O<B!!
M;&Q497-T<RYP:'`L(&%N9"!U<V4@=&AA="!T;R!R=6X@<&AP=6YI="UB87-E
M9"!T97-T<SPO9&]C/@T*("`@/"]P:'!U;FET/@T*("`\+V]P=&EO;G,^#0H@
M(#QD;V,^6W1E<W1F:6QE?&1I<B`N+BY=#0I2=6X@<F5G<F5S<VEO;B!T97-T
M<R!W:71H(%!(4"9A<&]S.W,@<F5G<F5S<VEO;B!T97-T:6YG('-C<FEP="`H
M<G5N+71E<W1S+G!H<"DN/"]D;V,^#0H@/"]R=6XM=&5S=',^#0H\+V-O;6UA
M;F1S/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O5&5S="YP:'``````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(S-S(P(#$P-3$U-#,T
M,3,T(#`R,C(R,P`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?5&5S="`H<G5N
M+71E<W1S*0T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B
M;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN
M9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!0
M2%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G
M:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%
M05(-"B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP+FYE=#X-
M"B`J($!A=71H;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^#0H@
M*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@
M*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI
M8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@
M4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5&5S
M="YP:'`L=B`Q+CD@,C`P-B\P,B\P,R`R,CHR.#HP."!C96QL;V<@17AP("0-
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]0
M14%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#`N,0T*("HO#0H-"B\J*@T*("H@8F%S92!C;&%S<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O0V]M;6%N9"]#;VUM;VXN<&AP)SL-"@T*+RHJ#0H@
M*B!014%2(&-O;6UA;F1S(&9O<B!L;V=I;B]L;V=O=70-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@
M("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J
M+PT*#0IC;&%S<R!014%27T-O;6UA;F1?5&5S="!E>'1E;F1S(%!%05)?0V]M
M;6%N9%]#;VUM;VX-"GL-"B`@("`O+R![>WL@<')O<&5R=&EE<PT*#0H@("`@
M=F%R("1C;VUM86YD<R`](&%R<F%Y*`T*("`@("`@("`G<G5N+71E<W1S)R`]
M/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G4G5N(%)E9W)E
M<W-I;VX@5&5S=',G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&]2
M=6Y497-T<R<L#0H@("`@("`@("`@("`G<VAO<G1C=70G(#T^("=R="<L#0H@
M("`@("`@("`@("`G;W!T:6]N<R<@/3X@87)R87DH#0H@("`@("`@("`@("`@
M("`@)W)E8W5R)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W-H
M;W)T;W!T)R`]/B`G<B<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G(#T^
M("=2=6X@=&5S=',@:6X@8VAI;&0@9&ER96-T;W)I97,L(')E8W5R<VEV96QY
M+B`@-"!D:7)S(&1E97`@;6%X:6UU;2<L#0H@("`@("`@("`@("`@("`@*2P-
M"B`@("`@("`@("`@("`@("`G:6YI)R`]/B!A<G)A>2@-"B`@("`@("`@("`@
M("`@("`@("`@)W-H;W)T;W!T)R`]/B`G:2<L#0H@("`@("`@("`@("`@("`@
M("`@("=D;V,G(#T^("=A8W1U86P@<W1R:6YG(&]F('-E='1I;F=S('1O('!A
M<W,@=&\@<&AP(&EN(&9O<FUA="`B("UD('-E='1I;F<]8FQA:"(G+`T*("`@
M("`@("`@("`@("`@("`@("`G87)G)R`]/B`G4T545$E.1U,G#0H@("`@("`@
M("`@("`@("`@*2P-"B`@("`@("`@("`@("`@("`G<F5A;'1I;65L;V<G(#T^
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^("=L
M)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)TQO9R!T97-T(')U
M;G,O<F5S=6QT<R!A<R!T:&5Y(&%R92!R=6XG+`T*("`@("`@("`@("`@("`@
M("DL#0H@("`@("`@("`@("`@("`@)W%U:65T)R`]/B!A<G)A>2@-"B`@("`@
M("`@("`@("`@("`@("`@)W-H;W)T;W!T)R`]/B`G<2<L#0H@("`@("`@("`@
M("`@("`@("`@("=D;V,G(#T^("=/;FQY(&1I<W!L87D@9&5T86EL(&9O<B!F
M86EL960@=&5S=',G+`T*("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@
M("`@("`@)W-I;7!L92<@/3X@87)R87DH#0H@("`@("`@("`@("`@("`@("`@
M("=S:&]R=&]P="<@/3X@)W,G+`T*("`@("`@("`@("`@("`@("`@("`G9&]C
M)R`]/B`G1&ES<&QA>2!S:6UP;&4@;W5T<'5T(&9O<B!A;&P@=&5S=',G+`T*
M("`@("`@("`@("`@("`@("DL#0H@("`@("`@("`@("`@("`@)W!A8VMA9V4G
M(#T^(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`G<VAO<G1O<'0G(#T^
M("=P)RP-"B`@("`@("`@("`@("`@("`@("`@)V1O8R<@/3X@)U1R96%T('!A
M<F%M971E<G,@87,@:6YS=&%L;&5D('!A8VMA9V5S(&9R;VT@=VAI8V@@=&\@
M<G5N('1E<W1S)RP-"B`@("`@("`@("`@("`@("`I+`T*("`@("`@("`@("`@
M("`@("=P:'!U;FET)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@
M)W-H;W)T;W!T)R`]/B`G=2<L#0H@("`@("`@("`@("`@("`@("`@("=D;V,G
M(#T^("=396%R8V@@<&%R86UE=&5R<R!F;W(@06QL5&5S=',N<&AP+"!A;F0@
M=7-E('1H870@=&\@<G5N('!H<'5N:70M8F%S960@=&5S=',G+`T*("`@("`@
M("`@("`@("`@("DL#0H@("`@("`@("`@("`I+`T*("`@("`@("`@("`@)V1O
M8R<@/3X@)UMT97-T9FEL97QD:7(@+BXN70T*4G5N(')E9W)E<W-I;VX@=&5S
M=',@=VET:"!02%!<)W,@<F5G<F5S<VEO;B!T97-T:6YG('-C<FEP="`H<G5N
M+71E<W1S+G!H<"DN)RP-"B`@("`@("`@("`@("DL#0H@("`@("`@("D[#0H-
M"B`@("!V87(@)&]U='!U=#L-"@T*("`@("\O('U]?0T*("`@("\O('M[>R!C
M;VYS=')U8W1O<@T*#0H@("`@+RHJ#0H@("`@("H@4$5!4E]#;VUM86YD7U1E
M<W0@8V]N<W1R=6-T;W(N#0H@("`@("H-"B`@("`@*B!`86-C97-S('!U8FQI
M8PT*("`@("`J+PT*("`@(&9U;F-T:6]N(%!%05)?0V]M;6%N9%]497-T*"8D
M=6DL("8D8V]N9FEG*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27T-O
M;6UA;F1?0V]M;6]N*"1U:2P@)&-O;F9I9RD[#0H@("`@?0T*#0H@("`@+R\@
M?7U]#0H@("`@+R\@>WM[(&1O4G5N5&5S=',H*0T*#0H@("`@9G5N8W1I;VX@
M9&]2=6Y497-T<R@D8V]M;6%N9"P@)&]P=&EO;G,L("1P87)A;7,I#0H@("`@
M>PT*("`@("`@("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@
M("`@("`@(')E<75I<F5?;VYC92`G4$5!4B]2=6Y497-T+G!H<"<[#0H@("`@
M("`@(')E<75I<F5?;VYC92`G4WES=&5M+G!H<"<[#0H@("`@("`@("1L;V<@
M/2!N97<@4$5!4E]#;VUM;VX[#0H@("`@("`@("1L;V<M/G5I(#T@)B1T:&ES
M+3YU:3L@+R\@<VQI9VAT;'D@:&%C:WDL(&)U="!I="!W:6QL('=O<FL-"B`@
M("`@("`@)')U;B`](&YE=R!014%27U)U;E1E<W0H)&QO9RP@)&]P=&EO;G,I
M.PT*("`@("`@("`D=&5S=',@/2!A<G)A>2@I.PT*("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)W)E8W5R)UTI*2![#0H@("`@("`@("`@("`D9&5P=&@@
M/2`T.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)&1E<'1H(#T@
M,3L-"B`@("`@("`@?0T*("`@("`@("!I9B`H(6-O=6YT*"1P87)A;7,I*2![
M#0H@("`@("`@("`@("`D<&%R86US6UT@/2`G+B<[#0H@("`@("`@('T-"B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P86-K86=E)UTI*2![#0H@("`@
M("`@("`@("`D;VQD<&%R86US(#T@)'!A<F%M<SL-"B`@("`@("`@("`@("1P
M87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@)')E9R`]("8D=&AI<RT^
M8V]N9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@9F]R96%C:"`H
M)&]L9'!A<F%M<R!A<R`D<&%R86TI('L-"B`@("`@("`@("`@("`@("`D<&YA
M;64@/2`D<F5G+3YP87)S95!A8VMA9V5.86UE*"1P87)A;2P@)'1H:7,M/F-O
M;F9I9RT^9V5T*"=D969A=6QT7V-H86YN96PG*2D[#0H@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)'!N86UE*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'!N86UE*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`F
M)')E9RT^9V5T4&%C:V%G92@D<&YA;65;)W!A8VMA9V4G72P@)'!N86UE6R=C
M:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@(&EF("@A)'!A8VMA9V4I('L-
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)U5N:VYO=VX@<&%C:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5G+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P;F%M92D@+B`G
M(B<I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D9FEL
M96QI<W0@/2`D<&%C:V%G92T^9V5T1FEL96QI<W0H*3L-"B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D9FEL96QI<W0@87,@)&YA;64@/3X@)&%T=',I('L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1S6R=R;VQE)UTI
M("8F("1A='1S6R=R;VQE)UT@(3T@)W1E<W0G*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!H<'5N
M:70G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M
M871C:"@G+T%L;%1E<W1S7"YP:'`D+VDG+"`D;F%M92DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C:"@G+UPN<&AP
M="0O)RP@)&YA;64I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<UM=
M(#T@)&%T='-;)VEN<W1A;&QE9%]A<R==.PT*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H("@D
M<&%R86US(&%S("1P*2![#0H@("`@("`@("`@("!I9B`H:7-?9&ER*"1P*2D@
M>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&AP=6YI
M="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D9&ER(#T@4WES=&5M.CIF
M:6YD*&%R<F%Y*"1P+"`G+71Y<&4G+"`G9B<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+6UA>&1E<'1H)RP@
M)&1E<'1H+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)RUN86UE)RP@)T%L;%1E<W1S+G!H<"<I*3L-"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D9&ER
M(#T@4WES=&5M.CIF:6YD*&%R<F%Y*"1P+"`G+71Y<&4G+"`G9B<L#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M+6UA>&1E<'1H)RP@)&1E<'1H+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)RUN86UE)RP@)RHN<&AP="<I*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)'1E<W1S(#T@
M87)R87E?;65R9V4H)'1E<W1S+"`D9&ER*3L-"B`@("`@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=P:'!U
M;FET)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A<')E9U]M871C
M:"@G+T%L;%1E<W1S7"YP:'`D+VDG+"`D<"DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@("`@("1T97-T<UM=(#T@)'`[#0H@("`@("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%`9FEL
M95]E>&ES=',H)'`I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M(7!R96=?;6%T8V@H)R]<+G!H<'0D+R<L("1P*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P("X]("<N<&AP="<[#0H@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`D9&ER(#T@
M4WES=&5M.CIF:6YD*&%R<F%Y*&1I<FYA;64H)'`I+"`G+71Y<&4G+"`G9B<L
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)RUM87AD97!T:"<L("1D97!T:"P-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G+6YA;64G
M+"`D<"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1E<W1S(#T@87)R
M87E?;65R9V4H)'1E<W1S+"`D9&ER*3L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T97-T<UM=(#T@
M)'`[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)&EN:5]S971T
M:6YG<R`]("<G.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEN:2==
M*2D@>PT*("`@("`@("`@("`@)&EN:5]S971T:6YG<R`N/2`D;W!T:6]N<ULG
M:6YI)UT[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1?14Y66R=4
M15-47U!(4%])3D-,541%7U!!5$@G72DI('L-"B`@("`@("`@("`@("1I;FE?
M<V5T=&EN9W,@+CT@(B`M9"!I;F-L=61E7W!A=&@]>R1?14Y66R=415-47U!(
M4%])3D-,541%7U!!5$@G77TB.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D
M:6YI7W-E='1I;F=S*2![#0H@("`@("`@("`@("`D=&AI<RT^=6DM/F]U='!U
M=$1A=&$H)U5S:6YG($E.22!S971T:6YG<SH@(B<@+B`D:6YI7W-E='1I;F=S
M("X@)R(G*3L-"B`@("`@("`@?0T*("`@("`@("`D<VMI<'!E9"`]("1P87-S
M960@/2`D9F%I;&5D(#T@87)R87DH*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO
M=71P=71$871A*"=2=6YN:6YG("<@+B!C;W5N="@D=&5S=',I("X@)R!T97-T
M<R<L("1C;VUM86YD*3L-"B`@("`@("`@)'-T87)T(#T@=&EM92@I.PT*("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI*2![#0H@
M("`@("`@("`@("!`=6YL:6YK*"=R=6XM=&5S=',N;&]G)RD[#0H@("`@("`@
M('T-"B`@("`@("`@9F]R96%C:"`H)'1E<W1S(&%S("1T*2![#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W)E86QT:6UE;&]G)UTI*2![#0H@
M("`@("`@("`@("`@("`@)&9P(#T@0&9O<&5N*"=R=6XM=&5S=',N;&]G)RP@
M)V$G*3L-"B`@("`@("`@("`@("`@("!I9B`H)&9P*2![#0H@("`@("`@("`@
M("`@("`@("`@(&9W<FET92@D9G`L(")2=6YN:6YG('1E<W0@)'0N+BXB*3L-
M"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[#0H@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@4$5!4CHZ<W1A
M=&EC4'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@)')E<W5L="`]("1R=6XM/G)U;B@D="P@)&EN:5]S971T:6YG
M<RD[#0H@("`@("`@("`@("!014%2.CIS=&%T:6-0;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YU:2T^;&]G*#`L("1R97-U;'0M
M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W)E86QT:6UE;&]G)UTI*2![#0H@("`@("`@("`@("`@("`@)&9P(#T@0&9O
M<&5N*"=R=6XM=&5S=',N;&]G)RP@)V$G*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)&9P*2![#0H@("`@("`@("`@("`@("`@("`@(&9W<FET92@D9G`L("(D
M<F5S=6QT7&XB*3L-"B`@("`@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"1R97-U;'0@/3T@)T9!24Q%1"<I('L-"B`@("`@("`@("`@(`DD
M9F%I;&5D6UT@/2`D=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF
M("@D<F5S=6QT(#T]("=005-3140G*2![#0H@("`@("`@("`@("`))'!A<W-E
M9%M=(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)')E
M<W5L="`]/2`G4TM)4%!%1"<I('L-"B`@("`@("`@("`@(`DD<VMI<'!E9%M=
M(#T@)'0[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1O
M=&%L(#T@9&%T92@G:3IS)RP@=&EM92@I("T@)'-T87)T*3L-"B`@("`@("`@
M:68@*&-O=6YT*"1F86EL960I*2![#0H@("`@("`@("`@("`D;W5T<'5T(#T@
M(E1/5$%,(%1)344Z("1T;W1A;%QN(CL-"B`@("`@("`@("`@("1O=71P=70@
M+CT@8V]U;G0H)'!A<W-E9"D@+B`B(%!!4U-%1"!415-44UQN(CL-"B`@("`@
M("`@("`@("1O=71P=70@+CT@8V]U;G0H)'-K:7!P960I("X@(B!32TE04$5$
M(%1%4U137&XB.PT*("`@(`D))&]U='!U="`N/2!C;W5N="@D9F%I;&5D*2`N
M("(@1D%)3$5$(%1%4U13.EQN(CL-"B`@("`@("`@"69O<F5A8V@@*"1F86EL
M960@87,@)&9A:6QU<F4I('L-"B`@("`@("`@"0DD;W5T<'5T("X]("1F86EL
M=7)E("X@(EQN(CL-"B`@("`@("`@"7T-"B`@("`@("`@("`@(&EF("AI<W-E
M="@D;W!T:6]N<ULG<F5A;'1I;65L;V<G72DI('L-"B`@("`@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)W)U;BUT97-T<RYL;V<G+"`G82<I.PT*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D9G`@/2!`9F]P96XH
M)W)U;BUT97-T<RYL;V<G+"`G=R<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1F<"D@>PT*("`@("`@("`@("`@("`@(&9W<FET92@D9G`L
M("1O=71P=70L('-T<FQE;B@D;W5T<'5T*2D[#0H@("`@("`@("`@("`@("`@
M9F-L;W-E*"1F<"D[#0H@("`@("`@("`@("`@("`@)'1H:7,M/G5I+3YO=71P
M=71$871A*"=W<F]T92!L;V<@=&\@(B<@+B!R96%L<&%T:"@G<G5N+71E<W1S
M+FQO9R<I("X@)R(G+"`D8V]M;6%N9"D[#0H@("`@("`@("`@("!]#0H@("`@
M("`@('T@96QS96EF("A`9FEL95]E>&ES=',H)W)U;BUT97-T<RYL;V<G*2`F
M)B`A0&ES7V1I<B@G<G5N+71E<W1S+FQO9R<I*2![#0H@("`@("`@("`@("!`
M=6YL:6YK*"=R=6XM=&5S=',N;&]G)RD[#0H@("`@("`@('T-"B`@("`@("`@
M)'1H:7,M/G5I+3YO=71P=71$871A*"=43U1!3"!424U%.B`G("X@)'1O=&%L
M*3L-"B`@("`@("`@)'1H:7,M/G5I+3YO=71P=71$871A*&-O=6YT*"1P87-S
M960I("X@)R!005-3140@5$535%,G+"`D8V]M;6%N9"D[#0H@("`@("`@("1T
M:&ES+3YU:2T^;W5T<'5T1&%T82AC;W5N="@D<VMI<'!E9"D@+B`G(%-+25!0
M140@5$535%,G+"`D8V]M;6%N9"D[#0H@("`@("`@(&EF("AC;W5N="@D9F%I
M;&5D*2D@>PT*("`@(`D))'1H:7,M/G5I+3YO=71P=71$871A*&-O=6YT*"1F
M86EL960I("X@)R!&04E,140@5$535%,Z)RP@)&-O;6UA;F0I.PT*("`@("`@
M("`)9F]R96%C:"`H)&9A:6QE9"!A<R`D9F%I;'5R92D@>PT*("`@("`@("`)
M"21T:&ES+3YU:2T^;W5T<'5T1&%T82@D9F%I;'5R92P@)&-O;6UA;F0I.PT*
M("`@("`@("`)?0T*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*("`@("\O('U]?0T*?0T*#0H_/@T*````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O075T:"YX;6P`````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C4P(#$P-3$U-#,T,3,T
M(#`R,C(Q-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\8V]M;6%N9',@=F5R<VEO;CTB,2XP(CX-"B`\;&]G:6X^#0H@(#QS
M=6UM87)Y/D-O;FYE8W1S(&%N9"!A=71H96YT:6-A=&5S('1O(')E;6]T92!S
M97)V97(\+W-U;6UA<GD^#0H@(#QS:&]R=&-U=#YL:3PO<VAO<G1C=70^#0H@
M(#QF=6YC=&EO;CYD;TQO9VEN/"]F=6YC=&EO;CX-"B`@/&]P=&EO;G,@+SX-
M"B`@/&1O8SX-"DQO9R!I;B!T;R!T:&4@<F5M;W1E('-E<G9E<BX@(%1O('5S
M92!R96UO=&4@9G5N8W1I;VYS(&EN('1H92!I;G-T86QL97(-"G1H870@<F5Q
M=6ER92!A;GD@:VEN9"!O9B!P<FEV:6QE9V5S+"!Y;W4@;F5E9"!T;R!L;V<@
M:6X@9FER<W0N("!4:&4-"G5S97)N86UE(&%N9"!P87-S=V]R9"!Y;W4@96YT
M97(@:&5R92!W:6QL(&)E('-T;W)E9"!I;B!Y;W5R('!E<BUU<V5R#0I014%2
M(&-O;F9I9W5R871I;VX@*'XO+G!E87)R8R!O;B!5;FEX+6QI:V4@<WES=&5M
M<RDN("!!9G1E<B!L;V=G:6YG#0II;BP@>6]U<B!U<V5R;F%M92!A;F0@<&%S
M<W=O<F0@=VEL;"!B92!S96YT(&%L;VYG(&EN('-U8G-E<75E;G0-"F]P97)A
M=&EO;G,@;VX@=&AE(')E;6]T92!S97)V97(N/"]D;V,^#0H@/"]L;V=I;CX-
M"B`\;&]G;W5T/@T*("`\<W5M;6%R>3Y,;V=S(&]U="!F<F]M('1H92!R96UO
M=&4@<V5R=F5R/"]S=6UM87)Y/@T*("`\<VAO<G1C=70^;&\\+W-H;W)T8W5T
M/@T*("`\9G5N8W1I;VX^9&],;V=O=70\+V9U;F-T:6]N/@T*("`\;W!T:6]N
M<R`O/@T*("`\9&]C/@T*3&]G<R!O=70@9G)O;2!T:&4@<F5M;W1E('-E<G9E
M<BX@(%1H:7,@8V]M;6%N9"!D;V5S(&YO="!A8W1U86QL>0T*8V]N;F5C="!T
M;R!T:&4@<F5M;W1E('-E<G9E<BP@:70@;VYL>2!D96QE=&5S('1H92!S=&]R
M960@=7-E<FYA;64@86YD#0IP87-S=V]R9"!F<F]M('EO=7(@=7-E<B!C;VYF
M:6=U<F%T:6]N+CPO9&]C/@T*(#PO;&]G;W5T/@T*/"]C;VUM86YD<SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+T-O;6UA;F0O075T:"YP:'``
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S,#4P(#$P-3$U
M-#,T,3,T(#`R,C(P,``@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`T*+RHJ#0H@*B!014%27T-O;6UA;F1?075T:"`H
M;&]G:6XL(&QO9V]U="!C;VUM86YD<RD-"B`J#0H@*B!02%`@=F5R<VEO;G,@
M-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J
M('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C
M;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@
M;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@
M8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!3=&EG($)A:VME
M;B`\<W-B0'!H<"YN970^#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@075T:"YP:'`L=B`Q+C(S(#(P,#8O,#,O,#(@,3@Z
M,30Z,3,@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P+C$-"B`J+PT*#0HO*BH-"B`J(&)A
M<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E("=014%2+T-O;6UA;F0O0V]M
M;6]N+G!H<"<[#0IR97%U:7)E7V]N8V4@)U!%05(O0V]N9FEG+G!H<"<[#0H-
M"B\J*@T*("H@4$5!4B!C;VUM86YD<R!F;W(@;&]G:6XO;&]G;W5T#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@T*("H@0&%U
M=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O
M<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`P+C$-"B`J+PT*8VQA<W,@4$5!4E]#;VUM86YD7T%U=&@@97AT96YD<R!0
M14%27T-O;6UA;F1?0V]M;6]N#0I[#0H@("`@+R\@>WM[('!R;W!E<G1I97,-
M"@T*("`@('9A<B`D8V]M;6%N9',@/2!A<G)A>2@-"B`@("`@("`@)VQO9VEN
M)R`]/B!A<G)A>2@-"B`@("`@("`@("`@("=S=6UM87)Y)R`]/B`G0V]N;F5C
M=',@86YD(&%U=&AE;G1I8V%T97,@=&\@<F5M;W1E('-E<G9E<B<L#0H@("`@
M("`@("`@("`G<VAO<G1C=70G(#T^("=L:2<L#0H@("`@("`@("`@("`G9G5N
M8W1I;VXG(#T^("=D;TQO9VEN)RP-"B`@("`@("`@("`@("=O<'1I;VYS)R`]
M/B!A<G)A>2@I+`T*("`@("`@("`@("`@)V1O8R<@/3X@)PT*3&]G(&EN('1O
M('1H92!R96UO=&4@<V5R=F5R+B`@5&\@=7-E(')E;6]T92!F=6YC=&EO;G,@
M:6X@=&AE(&EN<W1A;&QE<@T*=&AA="!R97%U:7)E(&%N>2!K:6YD(&]F('!R
M:79I;&5G97,L('EO=2!N965D('1O(&QO9R!I;B!F:7)S="X@(%1H90T*=7-E
M<FYA;64@86YD('!A<W-W;W)D('EO=2!E;G1E<B!H97)E('=I;&P@8F4@<W1O
M<F5D(&EN('EO=7(@<&5R+75S97(-"E!%05(@8V]N9FEG=7)A=&EO;B`H?B\N
M<&5A<G)C(&]N(%5N:7@M;&EK92!S>7-T96US*2X@($%F=&5R(&QO9V=I;F<-
M"FEN+"!Y;W5R('5S97)N86UE(&%N9"!P87-S=V]R9"!W:6QL(&)E('-E;G0@
M86QO;F<@:6X@<W5B<V5Q=65N=`T*;W!E<F%T:6]N<R!O;B!T:&4@<F5M;W1E
M('-E<G9E<BXG+`T*("`@("`@("`@("`@*2P-"B`@("`@("`@)VQO9V]U="<@
M/3X@87)R87DH#0H@("`@("`@("`@("`G<W5M;6%R>2<@/3X@)TQO9W,@;W5T
M(&9R;VT@=&AE(')E;6]T92!S97)V97(G+`T*("`@("`@("`@("`@)W-H;W)T
M8W5T)R`]/B`G;&\G+`T*("`@("`@("`@("`@)V9U;F-T:6]N)R`]/B`G9&],
M;V=O=70G+`T*("`@("`@("`@("`@)V]P=&EO;G,G(#T^(&%R<F%Y*"DL#0H@
M("`@("`@("`@("`G9&]C)R`]/B`G#0I,;V=S(&]U="!F<F]M('1H92!R96UO
M=&4@<V5R=F5R+B`@5&AI<R!C;VUM86YD(&1O97,@;F]T(&%C='5A;&QY#0IC
M;VYN96-T('1O('1H92!R96UO=&4@<V5R=F5R+"!I="!O;FQY(&1E;&5T97,@
M=&AE('-T;W)E9"!U<V5R;F%M92!A;F0-"G!A<W-W;W)D(&9R;VT@>6]U<B!U
M<V5R(&-O;F9I9W5R871I;VXN)RP-"B`@("`@("`@("`@("D-"@T*("`@("`@
M("`I.PT*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@8V]N<W1R=6-T;W(-
M"@T*("`@("\J*@T*("`@("`J(%!%05)?0V]M;6%N9%]!=71H(&-O;G-T<G5C
M=&]R+@T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@*B\-
M"B`@("!F=6YC=&EO;B!014%27T-O;6UA;F1?075T:"@F)'5I+"`F)&-O;F9I
M9RD-"B`@("![#0H@("`@("`@('!A<F5N=#HZ4$5!4E]#;VUM86YD7T-O;6UO
M;B@D=6DL("1C;VYF:6<I.PT*("`@('T-"@T*("`@("\O('U]?0T*#0H@("`@
M+R\@>WM[(&1O3&]G:6XH*0T*#0H@("`@+RHJ#0H@("`@("H@17AE8W5T92!T
M:&4@)VQO9VEN)R!C;VUM86YD+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T
M<FEN9R`D8V]M;6%N9"!C;VUM86YD(&YA;64-"B`@("`@*@T*("`@("`J($!P
M87)A;2!A<G)A>2`D;W!T:6]N<R!O<'1I;VY?;F%M92`]/B!V86QU90T*("`@
M("`J#0H@("`@("H@0'!A<F%M(&%R<F%Y("1P87)A;7,@;&ES="!O9B!A9&1I
M=&EO;F%L('!A<F%M971E<G,-"B`@("`@*@T*("`@("`J($!R971U<FX@8F]O
M;"!44E5%(&]N('-U8V-E<W,@;W(-"B`@("`@*B!A(%!%05(@97)R;W(@;VX@
M9F%I;'5R90T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P=6)L:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!D;TQO9VEN*"1C;VUM86YD+"`D;W!T:6]N<RP@
M)'!A<F%M<RD-"B`@("![#0H@("`@("`@("1R96<@/2`F)'1H:7,M/F-O;F9I
M9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@)&-H86YN96P@/2`D=&AI<RT^
M8V]N9FEG+3YG970H)V1E9F%U;'1?8VAA;FYE;"<I.PT*("`@("`@("`D8VAA
M;B`]("1R96<M/F=E=$-H86YN96PH)&-H86YN96PI.PT*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D8VAA;BDI('L-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<B@D8VAA;BD[#0H@("`@("`@('T-"B`@("`@("`@
M)'-E<G9E<B`]("1T:&ES+3YC;VYF:6<M/F=E="@G<')E9F5R<F5D7VUI<G)O
M<B<I.PT*("`@("`@("`D<F5M;W1E(#T@)B1T:&ES+3YC;VYF:6<M/F=E=%)E
M;6]T92@I.PT*("`@("`@("`D=7-E<FYA;64@/2`D=&AI<RT^8V]N9FEG+3YG
M970H)W5S97)N86UE)RD[#0H@("`@("`@(&EF("AE;7!T>2@D=7-E<FYA;64I
M*2![#0H@("`@("`@("`@("`D=7-E<FYA;64@/2!`)%]%3E9;)U5315(G73L-
M"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^=6DM/F]U='!U=$1A=&$H(DQO
M9V=I;F<@:6X@=&\@)'-E<G9E<BXB+"`D8V]M;6%N9"D[#0H@("`@("`@(`T*
M("`@("`@("!L:7-T*"1U<V5R;F%M92P@)'!A<W-W;W)D*2`]("1T:&ES+3YU
M:2T^=7-E<D1I86QO9R@-"B`@("`@("`@("`@("1C;VUM86YD+`T*("`@("`@
M("`@("`@87)R87DH)U5S97)N86UE)RP@)U!A<W-W;W)D)RDL#0H@("`@("`@
M("`@("!A<G)A>2@G=&5X="<L("`@("`G<&%S<W=O<F0G*2P-"B`@("`@("`@
M("`@(&%R<F%Y*"1U<V5R;F%M92P@("<G*0T*("`@("`@("`@("`@*3L-"B`@
M("`@("`@)'5S97)N86UE(#T@=')I;2@D=7-E<FYA;64I.PT*("`@("`@("`D
M<&%S<W=O<F0@/2!T<FEM*"1P87-S=V]R9"D[#0H@("`@("`@(`T*("`@("`@
M("`D=&AI<RT^8V]N9FEG+3YS970H)W5S97)N86UE)RP@)'5S97)N86UE*3L-
M"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^<V5T*"=P87-S=V]R9"<L("1P87-S
M=V]R9"D[#0H-"B`@("`@("`@:68@*"1C:&%N+3YS=7!P;W)T<U)%4U0H*2D@
M>PT*("`@("`@("`@("`@)&]K(#T@=')U93L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1R96UO=&4M/F5X<&5C=$5R<F]R*#0P,2D[#0H@("`@
M("`@("`@("`D;VL@/2`D<F5M;W1E+3YC86QL*"=L;V=I;G1E<W0G*3L-"B`@
M("`@("`@("`@("1R96UO=&4M/G!O<$5X<&5C="@I.PT*("`@("`@("!]#0H@
M("`@("`@(&EF("@D;VL@/3T]('1R=64I('L-"B`@("`@("`@("`@("1T:&ES
M+3YU:2T^;W5T<'5T1&%T82@B3&]G9V5D(&EN+B(L("1C;VUM86YD*3L-"B`@
M("`@("`@("`@("1T:&ES+3YC;VYF:6<M/G-T;W)E*"D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M(DQO9VEN(&9A:6QE9"$B*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H-"B`@("`O+R!]?7T-"B`@("`O+R![>WL@9&],;V=O
M=70H*0T*#0H@("`@+RHJ#0H@("`@("H@17AE8W5T92!T:&4@)VQO9V]U="<@
M8V]M;6%N9"X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)&-O;6UA
M;F0@8V]M;6%N9"!N86UE#0H@("`@("H-"B`@("`@*B!`<&%R86T@87)R87D@
M)&]P=&EO;G,@;W!T:6]N7VYA;64@/3X@=F%L=64-"B`@("`@*@T*("`@("`J
M($!P87)A;2!A<G)A>2`D<&%R86US(&QI<W0@;V8@861D:71I;VYA;"!P87)A
M;65T97)S#0H@("`@("H-"B`@("`@*B!`<F5T=7)N(&)O;VP@5%)512!O;B!S
M=6-C97-S(&]R#0H@("`@("H@82!014%2(&5R<F]R(&]N(&9A:6QU<F4-"B`@
M("`@*@T*("`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@("HO#0H@("`@9G5N
M8W1I;VX@9&],;V=O=70H)&-O;6UA;F0L("1O<'1I;VYS+"`D<&%R86US*0T*
M("`@('L-"B`@("`@("`@)')E9R`]("8D=&AI<RT^8V]N9FEG+3YG971296=I
M<W1R>2@I.PT*("`@("`@("`D8VAA;FYE;"`]("1T:&ES+3YC;VYF:6<M/F=E
M="@G9&5F875L=%]C:&%N;F5L)RD[#0H@("`@("`@("1C:&%N(#T@)')E9RT^
M9V5T0VAA;FYE;"@D8VAA;FYE;"D[#0H@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1C:&%N*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1C:&%N*3L-"B`@("`@("`@?0T*("`@("`@("`D<V5R=F5R(#T@
M)'1H:7,M/F-O;F9I9RT^9V5T*"=P<F5F97)R961?;6ER<F]R)RD[#0H@("`@
M("`@("1T:&ES+3YU:2T^;W5T<'5T1&%T82@B3&]G9VEN9R!O=70@9G)O;2`D
M<V5R=F5R+B(L("1C;VUM86YD*3L-"B`@("`@("`@)'1H:7,M/F-O;F9I9RT^
M<F5M;W9E*"=U<V5R;F%M92<I.PT*("`@("`@("`D=&AI<RT^8V]N9FEG+3YR
M96UO=F4H)W!A<W-W;W)D)RD[#0H@("`@("`@("1T:&ES+3YC;VYF:6<M/G-T
M;W)E*"D[#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\O
M('U]?0T*?0T*#0H_/@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!%05(O5F%L:61A=&]R+U!%0TPN<&AP````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0Q-#,@,3`U,34T,S0Q
M,S0@,#(R,S<T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP#0HO*BH-"B`J($-H86YN96P@5F%L:61A=&]R(&9O<B!T
M:&4@<&5C;"YP:'`N;F5T(&-H86YN96P-"B`J#0H@*B!02%`@-"!A;F0@4$A0
M(#4-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!0
M14%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN
M970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*
M("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P
M+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@4$5#3"YP:'`L=B`Q+C<@,C`P-B\P,B\P,R`P,CHP,CHR,B!C96QL;V<@
M17AP("0-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]014%2#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC
M92!296QE87-E(#$N-"XP834-"B`J+PT*+RHJ#0H@*B!4:&ES(&ES('1H92!P
M87)E;G0@8VQA<W,@9F]R(&%L;"!V86QI9&%T;W)S#0H@*B\-"G)E<75I<F5?
M;VYC92`G4$5!4B]686QI9&%T92YP:'`G.PT*+RHJ#0H@*B!#:&%N;F5L(%9A
M;&ED871O<B!F;W(@=&AE('!E8VPN<&AP+FYE="!C:&%N;F5L#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-"XP834-"B`J+PT*8VQA<W,@4$5!4E]686QI9&%T;W)?4$5#3"!E>'1E;F1S
M(%!%05)?5F%L:61A=&4-"GL-"B`@("!F=6YC=&EO;B!V86QI9&%T959E<G-I
M;VXH*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?<W1A=&4@/3T@4$5!
M4E]604Q)1$%415]004-+04=)3D<I('L-"B`@("`@("`@("`@("1V97)S:6]N
M(#T@)'1H:7,M/E]P86-K86=E>&UL+3YG971697)S:6]N*"D[#0H@("`@("`@
M("`@("`D=F5R<VEO;F-O;7!O;F5N=',@/2!E>'!L;V1E*"<N)RP@)'9E<G-I
M;VXI.PT*("`@("`@("`@("`@)&QA<W0@/2!A<G)A>5]P;W`H)'9E<G-I;VYC
M;VUP;VYE;G1S*3L-"B`@("`@("`@("`@(&EF("AS=6)S='(H)&QA<W0L(#$L
M(#(I(#T]("=R8R<I('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$9A
M:6QU<F4H)W9E<G-I;VXG+"`G4F5L96%S92!#86YD:61A=&4@=F5R<VEO;G,@
M;75S="!H879E("<@+@T*("`@("`@("`@("`@("`@("=U<'!E<BUC87-E(%)#
M+"!N;W0@;&]W97(M8V%S92!R8R<I.PT*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!R
M971U<FX@=')U93L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T95!A
M8VMA9V5.86UE*"D-"B`@("![#0H@("`@("`@("1R970@/2!P87)E;G0Z.G9A
M;&ED871E4&%C:V%G94YA;64H*3L-"B`@("`@("`@:68@*"1T:&ES+3Y?<&%C
M:V%G97AM;"T^9V5T4&%C:V%G951Y<&4H*2`]/2`G97AT<W)C)RD@>PT*("`@
M("`@("`@("`@:68@*'-T<G1O;&]W97(H)'1H:7,M/E]P86-K86=E>&UL+3YG
M971086-K86=E*"DI("$]#0H@("`@("`@("`@("`@("`@("!S=')T;VQO=V5R
M*"1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4')O=FED97-%>'1E;G-I;VXH*2DI
M('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%=A<FYI;F<H)W!R;W9I
M9&5S97AT96YS:6]N)RP@)W!A8VMA9V4@;F%M92`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&%C:V%G97AM;"T^9V5T4&%C:V%G92@I("X@
M)R(@:7,@9&EF9F5R96YT(&9R;VT@97AT96YS:6]N(&YA;64@(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!A8VMA9V5X;6PM/F=E=%!R;W9I
M9&5S17AT96YS:6]N*"D@+B`G(B<I.PT*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B`D<F5T.PT*("`@('T-"GT-"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]5;FEX
M96]L````````````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q,S0@,#(Q-#4W`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O4$5!4B]487-K+U=I;F1O=W-E;VP`````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S-"`P,C(Q-C8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4F5P;&%C90``````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,T(#`R,30P-P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S
M:R]0;W-T:6YS=&%L;'-C<FEP=```````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S0@,#(S-3<U`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]487-K+T-O;6UO;BYP:'``````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-3`Q,2`Q,#4Q-30S-#$S-"`P,C(P-3(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\J*@T*("H@4$5!4E]487-K7T-O;6UO;BP@8F%S92!C;&%S<R!F;W(@
M:6YS=&%L;&5R('1A<VMS#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-
M"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@
M=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES
M(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@
M9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*
M("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I
M="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@
M;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM
M961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA
M9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO
M9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@
M1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@
M0U93.B`D260Z($-O;6UO;BYP:'`L=B`Q+C$U(#(P,#8O,#$O,#8@,#0Z-#<Z
M,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I
M;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*B-`*PT*("H@
M17)R;W(@8V]D97,@9F]R('1A<VL@=F%L:61A=&EO;B!R;W5T:6YE<PT*("HO
M#0ID969I;F4H)U!%05)?5$%32U]%4E)/4E].3T%45%))0E,G+"`Q*3L-"F1E
M9FEN92@G4$5!4E]405-+7T524D]27TU)4U-)3D=?05144DE")RP@,BD[#0ID
M969I;F4H)U!%05)?5$%32U]%4E)/4E]74D].1U]!5%1224)?5D%,544G+"`S
M*3L-"F1E9FEN92@G4$5!4E]405-+7T524D]27TE.5D%,240G+"`T*3L-"B\J
M*B-`+2HO#0ID969I;F4H)U!%05)?5$%32U]004-+04=%)RP@,2D[#0ID969I
M;F4H)U!%05)?5$%32U])3E-404Q,)RP@,BD[#0ID969I;F4H)U!%05)?5$%3
M2U]004-+04=%04Y$24Y35$%,3"<L(#,I.PT*+RHJ#0H@*B!!('1A<VL@:7,@
M86X@;W!E<F%T:6]N('1H870@;6%N:7!U;&%T97,@=&AE(&-O;G1E;G1S(&]F
M(&$@9FEL92X-"B`J#0H@*B!3:6UP;&4@=&%S:W,@;W!E<F%T92!O;B`Q(&9I
M;&4N("!-=6QT:7!L92!T87-K<R!A<F4@97AE8W5T960@869T97(@86QL(&9I
M;&5S(&AA=F4@8F5E;@T*("H@<')O8V5S<V5D(&%N9"!I;G-T86QL960L(&%N
M9"!A<F4@9&5S:6=N960@=&\@;W!E<F%T92!O;B!A;&P@9FEL97,@8V]N=&%I
M;FEN9R!T:&4@=&%S:RX-"B`J(%1H92!0;W-T+6EN<W1A;&P@<V-R:7!T('1A
M<VL@<VEM<&QY('1A:V5S(&%D=F%N=&%G92!O9B!T:&4@9F%C="!T:&%T(&ET
M('=I;&P@8F4@<G5N#0H@*B!A9G1E<B!I;G-T86QL871I;VXL(')E<&QA8V4@
M:7,@82!S:6UP;&4@=&%S:RX-"B`J#0H@*B!#;VUB:6YI;F<@=&%S:W,@:7,@
M<&]S<VEB;&4L(&)U="!O<F1E<FEN9R!I<R!S:6=N:69I8V%N="X-"B`J#0H@
M*B`\9FEL92!N86UE/2)T97-T+G!H<"(@<F]L93TB<&AP(CX-"B`J("`\=&%S
M:W,Z<F5P;&%C92!F<F]M/2)`9&%T82UD:7)`(B!T;STB9&%T85]D:7(B('1Y
M<&4](G!E87(M8V]N9FEG(B\^#0H@*B`@/'1A<VMS.G!O<W1I;G-T86QL<V-R
M:7!T+SX-"B`J(#PO9FEL93X-"B`J#0H@*B!4:&ES('=I;&P@9FER<W0@<F5P
M;&%C92!A;GD@:6YS=&%N8V4@;V8@0&1A=&$M9&ER0"!I;B!T:&4@=&5S="YP
M:'`@9FEL90T*("H@=VET:"!T:&4@<&%T:"!T;R!T:&4@8W5R<F5N="!D871A
M(&1I<F5C=&]R>2X@(%1H96XL(&ET('=I;&P@:6YC;'5D92!T:&4-"B`J('1E
M<W0N<&AP(&9I;&4@86YD(')U;B!T:&4@<V-R:7!T(&ET(&-O;G1A:6YS('1O
M(&-O;F9I9W5R92!T:&4@<&%C:V%G92!P;W-T+6EN<W1A;&QA=&EO;BX-"B`J
M($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A
M=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!
M4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,0T*("H@0&%B<W1R86-T#0H@*B\-"F-L87-S(%!%05)?5&%S
M:U]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`@*B!686QI9"!T>7!E<R!F;W(@
M=&AI<R!V97)S:6]N(&%R92`G<VEM<&QE)R!A;F0@)VUU;'1I<&QE)PT*("`@
M("`J#0H@("`@("H@+2!S:6UP;&4@=&%S:W,@;W!E<F%T92!O;B!T:&4@8V]N
M=&5N=',@;V8@82!F:6QE(&%N9"!W<FET92!O=70@8VAA;F=E<R!T;R!D:7-K
M#0H@("`@("H@+2!M=6QT:7!L92!T87-K<R!O<&5R871E(&]N('1H92!C;VYT
M96YT<R!O9B!M86YY(&9I;&5S(&%N9"!W<FET92!O=70@=&AE#0H@("`@("H@
M("!C:&%N9V5S(&1I<F5C=&QY('1O(&1I<VL-"B`@("`@*@T*("`@("`J($-H
M:6QD('1A<VL@8VQA<W-E<R!M=7-T(&]V97)R:61E('1H:7,@<')O<&5R='DN
M#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@
M)'1Y<&4@/2`G<VEM<&QE)SL-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S
M('=H:6-H(&EN<W1A;&P@<&AA<V4@=&AI<R!T87-K(&ES(&5X96-U=&5D('5N
M9&5R#0H@("`@("HO#0H@("`@=F%R("1P:&%S92`](%!%05)?5$%32U])3E-4
M04Q,.PT*("`@("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@
M("HO#0H@("`@=F%R("1C;VYF:6<[#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S
M<R!P<F]T96-T960-"B`@("`@*B\-"B`@("!V87(@)')E9VES=')Y.PT*("`@
M("\J*@T*("`@("`J($!A8V-E<W,@<')O=&5C=&5D#0H@("`@("HO#0H@("`@
M=F%R("1L;V=G97([#0H@("`@+RHJ#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B\-"B`@("!V87(@)&EN<W1A;&QP:&%S93L-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]#;VYF:6<-"B`@("`@*B!`<&%R86T@4$5!
M4E]#;VUM;VX-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!014%27U1A<VM?0V]M
M;6]N*"8D8V]N9FEG+"`F)&QO9V=E<BP@)'!H87-E*0T*("`@('L-"B`@("`@
M("`@)'1H:7,M/F-O;F9I9R`]("8D8V]N9FEG.PT*("`@("`@("`D=&AI<RT^
M<F5G:7-T<GD@/2`F)&-O;F9I9RT^9V5T4F5G:7-T<GDH*3L-"B`@("`@("`@
M)'1H:7,M/FQO9V=E<B`]("8D;&]G9V5R.PT*("`@("`@("`D=&AI<RT^:6YS
M=&%L;'!H87-E(#T@)'!H87-E.PT*("`@("`@("!I9B`H)'1H:7,M/G1Y<&4@
M/3T@)VUU;'1I<&QE)RD@>PT*("`@("`@("`@("`@)$=,3T)!3%-;)U]014%2
M7U1!4TM?4$]35$E.4U1!3D-%4R==6V=E=%]C;&%S<R@D=&AI<RE=6UT@/2`F
M)'1H:7,[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!6
M86QI9&%T92!T:&4@8F%S:6,@8V]N=&5N=',@;V8@82!T87-K('1A9RX-"B`@
M("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A
M;2!A<G)A>0T*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@("`J($!P
M87)A;2!A<G)A>2!T:&4@96YT:7)E('!A<G-E9"`\9FEL93X@=&%G#0H@("`@
M("H@0')E='5R;B!T<G5E?&%R<F%Y($]N(&5R<F]R+"!R971U<FX@86X@87)R
M87D@:6X@9F]R;6%T.@T*("`@("`J("`@(&%R<F%Y*%!%05)?5$%32U]%4E)/
M4E\_/S];+"!P87)A;3%=6RP@<&%R86TR75LL("XN+ETI#0H@("`@("H-"B`@
M("`@*B`@("!&;W(@4$5!4E]405-+7T524D]27TU)4U-)3D=?05144DE"+"!P
M87-S('1H92!A='1R:6)U=&4@;F%M92!I;@T*("`@("`J("`@($9O<B!014%2
M7U1!4TM?15)23U)?5U)/3D=?05144DE"7U9!3%5%+"!P87-S('1H92!A='1R
M:6)U=&4@;F%M92!A;F0@86X@87)R87D-"B`@("`@*B`@("!O9B!L96=A;"!V
M86QU97,@:6X-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&%B<W1R86-T#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@=F%L:618;6PH)'!K9RP@)'AM;"P@)B1C
M;VYF:6<L("1F:6QE6&UL*0T*("`@('L-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!);FET:6%L:7IE(&$@=&%S:R!I;G-T86YC92!W:71H('1H92!P87)A
M;65T97)S#0H@("`@("H@0'!A<F%M(&%R<F%Y(')A=RP@<&%R<V5D('AM;`T*
M("`@("`J($!P87)A;2!A<G)A>2!A='1R:6)U=&5S(&9R;VT@=&AE(#QF:6QE
M/B!T86<@8V]N=&%I;FEN9R!T:&ES('1A<VL-"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&YU;&P@;&%S="!I;G-T86QL960@=F5R<VEO;B!O9B!T:&ES('!A8VMA
M9V4-"B`@("`@*B!`86)S=')A8W0-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!I
M;FET*"1X;6PL("1F:6QE071T<FEB=71E<RP@)&QA<W1697)S:6]N*0T*("`@
M('L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!"96=I;B!A('1A<VL@<')O
M8V5S<VEN9R!S97-S:6]N+B`@06QL(&UU;'1I<&QE('1A<VMS('=I;&P@8F4@
M<')O8V5S<V5D(&%F=&5R(&5A8V@@9FEL90T*("`@("`J(&AA<R!B965N('-U
M8V-E<W-F=6QL>2!I;G-T86QL960L(&%L;"!S:6UP;&4@=&%S:W,@<VAO=6QD
M('!E<F9O<FT@=&AE:7(@=&%S:R!H97)E(&%N9`T*("`@("`J(')E='5R;B!A
M;GD@97)R;W)S('5S:6YG('1H92!C=7-T;VT@=&AR;W=%<G)O<B@I(&UE=&AO
M9"!T;R!A;&QO=R!F;W)W87)D(&-O;7!A=&EB:6QI='D-"B`@("`@*@T*("`@
M("`J(%1H:7,@;65T:&]D($U54U0@3D]4('=R:71E(&]U="!A;GD@8VAA;F=E
M<R!T;R!D:7-K#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-
M"B`@("`@*B!`<&%R86T@<W1R:6YG(&9I;&4@8V]N=&5N=',-"B`@("`@*B!`
M<&%R86T@<W1R:6YG('1H92!E=F5N='5A;"!F:6YA;"!F:6QE(&QO8V%T:6]N
M("AI;F9O<FUA=&EO;F%L(&]N;'DI#0H@("`@("H@0')E='5R;B!S=')I;F=\
M9F%L<V5\4$5!4E]%<G)O<B!F86QS92!T;R!S:VEP('1H:7,@9FEL92P@4$5!
M4E]%<G)O<B!T;R!F86EL#0H@("`@("H@("`@("`@("`H=7-E("1T:&ES+3YT
M:')O=T5R<F]R*2P@;W1H97)W:7-E(')E='5R;B!T:&4@;F5W(&-O;G1E;G1S
M#0H@("`@("H@0&%B<W1R86-T#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<W1A
M<G1397-S:6]N*"1P:V<L("1C;VYT96YT<RP@)&1E<W0I#0H@("`@>PT*("`@
M('T-"@T*("`@("\J*@T*("`@("`J(%1H:7,@;65T:&]D(&ES('5S960@=&\@
M<')O8V5S<R!E86-H(&]F('1H92!T87-K<R!F;W(@82!P87)T:6-U;&%R(&UU
M;'1I<&QE(&-L87-S#0H@("`@("H@='EP92X@(%-I;7!L92!T87-K<R!N965D
M(&YO="!I;7!L96UE;G0@=&AI<R!M971H;V0N#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(&%N(&%R<F%Y(&]F('1A<VMS#0H@("`@("H@0&%C8V5S<R!P<F]T96-T
M960-"B`@("`@*B!`<W1A=&EC#0H@("`@("H@0&%B<W1R86-T#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@<G5N*"1T87-K<RD-"B`@("![#0H@("`@?0T*#0H@
M("`@+RHJ#0H@("`@("H@0'-T871I8PT*("`@("`J($!F:6YA;`T*("`@("`J
M+PT*("`@(&9U;F-T:6]N(&AA<U!O<W1I;G-T86QL5&%S:W,H*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N(&ES<V5T*"1'3$]"04Q36R=?4$5!4E]405-+7U!/
M4U1)3E-404Y#15,G72D[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'-T
M871I8PT*("`@("`J($!F:6YA;`T*("`@("`J+PT*("`@("!F=6YC=&EO;B!R
M=6Y0;W-T:6YS=&%L;%1A<VMS*"D-"B`@("`@>PT*("`@("`@("`@9F]R96%C
M:"`H)$=,3T)!3%-;)U]014%27U1!4TM?4$]35$E.4U1!3D-%4R==(&%S("1C
M;&%S<R`]/B`D=&%S:W,I('L-"B`@("`@("`@("`@("`D97)R(#T@8V%L;%]U
M<V5R7V9U;F,H87)R87DH)&-L87-S+"`G<G5N)RDL#0H@("`@("`@("`@("`@
M("`@("`D1TQ/0D%,4ULG7U!%05)?5$%32U]03U-424Y35$%.0T53)UU;)&-L
M87-S72D[#0H@("`@("`@("`@("`@:68@*"1E<G(I('L-"B`@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05)?5&%S:U]#;VUM;VXZ.G1H<F]W17)R;W(H)&5R
M<BD[#0H@("`@("`@("`@("`@?0T*("`@("`@("`@?0T*("`@("`@("`@=6YS
M970H)$=,3T)!3%-;)U]014%27U1!4TM?4$]35$E.4U1!3D-%4R==*3L-"B`@
M("!]#0H-"B`@("`O*BH-"B`@("`@*B!$971E<FUI;F5S('=H971H97(@82!R
M;VQE(&ES(&$@<V-R:7!T#0H@("`@("H@0')E='5R;B!B;V]L#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@:7-38W)I<'0H*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YT>7!E(#T]("=S8W)I<'0G.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N('1H<F]W17)R;W(H)&US9RP@)&-O9&4@/2`M,2D-"B`@("![#0H@
M("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G.PT*("`@("`@("!R971U
M<FX@4$5!4CHZ<F%I<V5%<G)O<B@D;7-G+"`D8V]D92D[#0H@("`@?0T*?0T*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]4
M87-K+U!O<W1I;G-T86QL<V-R:7!T+G!H<```````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`S-3,W,B`Q,#4Q-30S-#$S-"`P,C0S-S<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J*@T*("H@/'1A
M<VMS.G!O<W1I;G-T86QL<V-R:7!T/@T*("H-"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U#0H@*@T*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90T*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ#0H@*B!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O
M<'D@;V8-"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@T*("H-"B`J($!C871E9V]R>2`@('!E87(-"B`J
M($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@("`@($=R96<@0F5A=F5R
M(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4
M:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`-"B`J($!V97)S
M:6]N("`@($-64SH@)$ED.B!0;W-T:6YS=&%L;'-C<FEP="YP:'`L=B`Q+C$X
M(#(P,#8O,#(O,#@@,#$Z,C$Z-#<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N8V4@
M)U!%05(O5&%S:R]#;VUM;VXN<&AP)SL-"B\J*@T*("H@26UP;&5M96YT<R!T
M:&4@<&]S=&EN<W1A;&QS8W)I<'0@9FEL92!T87-K+@T*("H-"B`J($YO=&4@
M=&AA="!P;W-T+6EN<W1A;&P@<V-R:7!T<R!A<F4@:&%N9&QE9"!S97!A<F%T
M96QY(&9R;VT@:6YS=&%L;&%T:6]N+"!B>2!T:&4-"B`J(")P96%R(')U;BUS
M8W)I<'1S(B!C;VUM86YD#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C
M:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L
M;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(
M4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$-"B`J+PT*8VQA<W,@4$5!
M4E]487-K7U!O<W1I;G-T86QL<V-R:7!T(&5X=&5N9',@4$5!4E]487-K7T-O
M;6UO;@T*>PT*("`@('9A<B`D='EP92`]("=S8W)I<'0G.PT*("`@('9A<B`D
M7V-L87-S.PT*("`@('9A<B`D7W!A<F%M<SL-"B`@("!V87(@)%]O8FH[#0H@
M("`@+RHJ#0H@("`@("H-"B`@("`@*B!`=F%R(%!%05)?4&%C:V%G949I;&5?
M=C(-"B`@("`@*B\-"B`@("!V87(@)%]P:V<[#0H@("`@=F%R("1?8V]N=&5N
M=',[#0H@("`@=F%R("1P:&%S92`](%!%05)?5$%32U])3E-404Q,.PT*#0H@
M("`@+RHJ#0H@("`@("H@5F%L:61A=&4@=&AE(')A=R!X;6P@870@<&%R<VEN
M9RUT:6UE+@T*("`@("`J#0H@("`@("H@5&AI<R!A;'-O(&%T=&5M<'1S('1O
M('9A;&ED871E('1H92!S8W)I<'0@=&\@;6%K92!S=7)E(&ET(&UE971S('1H
M92!C<FET97)I80T*("`@("`J(&9O<B!A('!O<W0M:6YS=&%L;"!S8W)I<'0-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!P
M87)A;2!A<G)A>2!4:&4@6$U,(&-O;G1E;G1S(&]F('1H92`\<&]S=&EN<W1A
M;&QS8W)I<'0^('1A9PT*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@
M("`J($!P87)A;2!A<G)A>2!T:&4@96YT:7)E('!A<G-E9"`\9FEL93X@=&%G
M#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED
M871E6&UL*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL95AM;"D-"B`@("![
M#0H@("`@("`@(&EF("@D9FEL95AM;%LG<F]L92==("$]("=P:'`G*2![#0H@
M("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,
M240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("1F
M:6QE6&UL6R=N86UE)UT@+B`G(B!M=7-T(&)E(')O;&4](G!H<"(G*3L-"B`@
M("`@("`@?0T*("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%2
M7T524D]27U)%5%523BD[#0H@("`@("`@("1F:6QE(#T@)'!K9RT^9V5T1FEL
M94-O;G1E;G1S*"1F:6QE6&UL6R=N86UE)UTI.PT*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D9FEL92DI('L-"B`@("`@("`@("`@(%!%05(Z.G!O<$5R
M<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%2
M7U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@
M+@T*("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!I<R!N
M;W0@=F%L:60Z("<@+@T*("`@("`@("`@("`@("`@("1F:6QE+3YG971-97-S
M86=E*"DI.PT*("`@("`@("!](&5L<V5I9B`H)&9I;&4@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y6
M04Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@
M("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!C;W5L9"!N;W0@8F4@<F5T<FEE
M=F5D(&9O<B!P<F]C97-S:6YG(2<I.PT*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@)&%N86QY<VES(#T@)'!K9RT^86YA;'EZ95-O=7)C94-O9&4H
M)&9I;&4L('1R=64I.PT*("`@("`@("`@("`@:68@*"$D86YA;'ES:7,I('L-
M"B`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@
M("`@("`@("`@("`@("`@)'=A<FYI;F=S(#T@)R<[#0H@("`@("`@("`@("`@
M("`@9F]R96%C:"`H)'!K9RT^9V5T5F%L:61A=&EO;E=A<FYI;F=S*"D@87,@
M)'=A<FXI('L-"B`@("`@("`@("`@("`@("`@("`@)'=A<FYI;F=S("X]("1W
M87)N6R=M97-S86=E)UT@+B`B7&XB.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.
M5D%,240L("=!;F%L>7-I<R!O9B!P;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-
M"B`@("`@("`@("`@("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B(&9A
M:6QE9#H@)R`N("1W87)N:6YG<RD[#0H@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!I9B`H8V]U;G0H)&%N86QY<VES6R=D96-L87)E9%]C;&%S<V5S)UTI
M("$](#$I('L-"B`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L
M:6YG*"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%3
M2U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@
M("`@("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!M=7-T
M(&1E8VQA<F4@97AA8W1L>2`Q(&-L87-S)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D8VQA<W,@/2`D86YA;'ES:7-;)V1E8VQA<F5D7V-L87-S
M97,G75LP73L-"B`@("`@("`@("`@(&EF("@D8VQA<W,@(3T@<W1R7W)E<&QA
M8V4H87)R87DH)R\G+"`G+G!H<"<I+"!A<G)A>2@G7R<L("<G*2P-"B`@("`@
M("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UTI("X@)U]P;W-T:6YS=&%L
M;"<I('L-"B`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG
M*"D[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%
M4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@
M("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!C;&%S<R`B
M)R`N("1C;&%S<R`N("<B(&UU<W0@8F4@;F%M960@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("!S=')?<F5P;&%C92AA<G)A>2@G+R<L("<N<&AP)RDL(&%R
M<F%Y*"=?)RP@)R<I+`T*("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG
M;F%M92==*2`N("=?<&]S=&EN<W1A;&PB)RD[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1A;F%L>7-I<ULG9&5C;&%R961?;65T
M:&]D<R==6R1C;&%S<UTI*2![#0H@("`@("`@("`@("`@("`@4$5!4CHZ<&]P
M17)R;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@(')E='5R;B!A<G)A
M>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I
M<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==
M("X@)R(@;75S="!D96-L87)E(&UE=&AO9',@:6YI="@I(&%N9"!R=6XH*2<I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&UE=&AO9',@/2!A<G)A
M>2@G:6YI="<@/3X@,"P@)W)U;B<@/3X@,2D[#0H@("`@("`@("`@("!F;W)E
M86-H("@D86YA;'ES:7-;)V1E8VQA<F5D7VUE=&AO9',G75LD8VQA<W-=(&%S
M("1M971H;V0I('L-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&UE=&AO
M9'-;)&UE=&AO9%TI*2![#0H@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M
M971H;V1S6R1M971H;V1=*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H8V]U;G0H)&UE=&AO9',I*2![#0H@
M("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y6
M04Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@;75S="!D96-L87)E(&UE
M=&AO9',@:6YI="@I(&%N9"!R=6XH*2<I.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@
M("`@("`@)&1E9FEN961P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`D=&%S
M:W-.86UE<W!A8V4@/2`D<&MG+3YG971487-K<TYS*"D@+B`G.B<[#0H@("`@
M("`@(&EF("@A:7-S970H)'AM;%LD=&%S:W-.86UE<W!A8V4@+B`G<&%R86UG
M<F]U<"==*2`F)B!I<W-E="@D>&UL6R=P87)A;6=R;W5P)UTI*2![#0H@("`@
M("`@("`@("`O+R!I;B!O<F1E<B!T;R!S=7!P;W)T('1H92!O;&1E<B!B971A
M<RP@=VAI8V@@9&ED(&YO="!E>'!E8W0@:6YT97)N86P@=&%G<PT*("`@("`@
M("`@("`@+R\@=&\@86QS;R!U<V4@=&AE(&YA;65S<&%C90T*("`@("`@("`@
M("`@)'1A<VMS3F%M97-P86-E(#T@)R<[#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&ES<V5T*"1X;6Q;)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`G
M72DI('L-"B`@("`@("`@("`@("1P87)A;7,@/2`D>&UL6R1T87-K<TYA;65S
M<&%C92`N("=P87)A;6=R;W5P)UT[#0H@("`@("`@("`@("!I9B`H(6ES7V%R
M<F%Y*"1P87)A;7,I('Q\("%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@D<&%R86US*3L-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M*2![#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R86U;)'1A<VMS
M3F%M97-P86-E("X@)VED)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@)U!O<W0M:6YS
M=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)&9I
M;&58;6Q;)VYA;64G72`N("<B(#QP87)A;6=R;W5P/B!M=7-T(&AA=F4@)R`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`G86X@)R`N("1T87-K<TYA;65S
M<&%C92`N("=I9#X@=&%G)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@(&EF("AI<W-E="@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@
M)VYA;64G72DI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A
M>2@D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VYA;64G72P@)&1E9FEN961P
M87)A;7,I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R
M87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R
M:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM
M;%LG;F%M92==("X@)R(@)R`N("1T87-K<TYA;65S<&%C92`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W!A<F%M9W)O=7`^(&ED("(G("X@)'!A
M<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B!P87)A;65T97(@(B<@+B`D<&%R86U;)'1A<VMS
M3F%M97-P86-E("X@)VYA;64G72`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R(@:&%S(&YO="!B965N('!R979I;W5S;'D@9&5F:6YE9"<I.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=C;VYD:71I;VYT
M>7!E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@87)R
M87DH4$5!4E]405-+7T524D]27TE.5D%,240L("=0;W-T+6EN<W1A;&P@<V-R
M:7!T("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL95AM
M;%LG;F%M92==("X@)R(@)R`N("1T87-K<TYA;65S<&%C92`N#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)W!A<F%M9W)O=7`^(&ED("(G("X@)'!A
M<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G(B!M=7-T(&AA=F4@82`G("X@)'1A<VMS3F%M97-P
M86-E("X@#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-O;F1I=&EO
M;G1Y<&4^('1A9R!C;VYT86EN:6YG(&5I=&AE<B`B/2(L("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("<B(3TB+"!O<B`B<')E9U]M871C:"(G
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6EN7V%R<F%Y*"1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G8V]N
M9&ET:6]N='EP92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G/2<L("<A/2<L("=P<F5G7VUA=&-H)RDI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@87)R87DH4$5!4E]405-+7T524D]27TE.5D%,
M240L("=0;W-T+6EN<W1A;&P@<V-R:7!T("(G("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9FEL95AM;%LG;F%M92==("X@)R(@)R`N("1T87-K
M<TYA;65S<&%C92`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W!A
M<F%M9W)O=7`^(&ED("(G("X@)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=I
M9"==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!M=7-T(&AA
M=F4@82`G("X@)'1A<VMS3F%M97-P86-E("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G8V]N9&ET:6]N='EP93X@=&%G(&-O;G1A:6YI;F<@96ET
M:&5R("(](BP@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(A
M/2(L(&]R(")P<F5G7VUA=&-H(B<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'!A<F%M6R1T87-K
M<TYA;65S<&%C92`N("=V86QU92==*2D@>PT*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G
M4&]S="UI;G-T86QL('-C<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&9I;&58;6Q;)VYA;64G72`N("<B("<@+B`D=&%S:W-.86UE
M<W!A8V4@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=P87)A;6=R
M;W5P/B!I9"`B)R`N("1P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G:60G72`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(@;75S="!H879E(&$@
M)R`N("1T87-K<TYA;65S<&%C92`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W9A;'5E/B!T86<@8V]N=&%I;FEN9R!E>'!E8W1E9"!P87)A;65T
M97(@=F%L=64G*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M6R1T
M87-K<TYA;65S<&%C92`N("=I;G-T<G5C=&EO;G,G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@:68@*"%I<U]S=')I;F<H)'!A<F%M6R1T87-K<TYA;65S
M<&%C92`N("=I;G-T<G5C=&EO;G,G72DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)1"P@
M)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B`G("X@)'1A<VMS3F%M
M97-P86-E("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<&%R86UG
M<F]U<#X@:60@(B<@+B`D<&%R86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@
M+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B("<@+B`D=&%S:W-.
M86UE<W!A8V4@+B`G:6YS=')U8W1I;VYS/B!M=7-T(&)E('-I;7!L92!T97AT
M)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<&%R86U;)'1A<VMS3F%M
M97-P86-E("X@)W!A<F%M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.R`O+R`\<&%R86T^(&ES(&YO(&QO;F=E<B!R97%U:7)E9`T*("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D<W5B<&%R86US(#T@
M)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=P87)A;2==.PT*("`@("`@("`@
M("`@("`@(&EF("@A:7-?87)R87DH)'-U8G!A<F%M<RD@?'P@(6ES<V5T*"1S
M=6)P87)A;7-;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@("1S=6)P87)A
M;7,@/2!A<G)A>2@D<W5B<&%R86US*3L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@9F]R96%C:"`H)'-U8G!A<F%M<R!A<R`D<W5B<&%R
M86TI('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<W5B<&%R
M86U;)'1A<VMS3F%M97-P86-E("X@)VYA;64G72DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y6
M04Q)1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!P87)A;65T
M97(@9F]R("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T87-K
M<TYA;65S<&%C92`N("=P87)A;6=R;W5P/B!I9"`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=I
M9"==("X@)R(@;75S="!H879E("<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=A("<@+B`D=&%S:W-.86UE<W!A8V4@+B`G;F%M93X@=&%G)RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%P<F5G7VUA=&-H*"<O6V$M>D$M6C`M.5TK+R<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("1S=6)P87)A;5LD=&%S:W-.86UE<W!A8V4@+B`G
M;F%M92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G4&]S="UI;G-T86QL('-C
M<FEP="`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9I;&58
M;6Q;)VYA;64G72`N("<B('!A<F%M971E<B`B)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N
M86UE)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&9O<B`G
M("X@)'1A<VMS3F%M97-P86-E("X@)W!A<F%M9W)O=7`^(&ED("(G("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86U;)'1A<VMS3F%M97-P
M86-E("X@)VED)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B
M(&ES(&YO="!A('9A;&ED(&YA;64N("!-=7-T(&-O;G1A:6X@;VYL>2!A;'!H
M86YU;65R:6,@8VAA<F%C=&5R<R<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-U8G!A<F%M6R1T
M87-K<TYA;65S<&%C92`N("=P<F]M<'0G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)
M1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!P87)A;65T97(@
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=6)P87)A;5LD
M=&%S:W-.86UE<W!A8V4@+B`G;F%M92==("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G(B!F;W(@)R`N("1T87-K<TYA;65S<&%C92`N("=P87)A
M;6=R;W5P/B!I9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(B!M=7-T(&AA=F4@82`G("X@)'1A<VMS3F%M
M97-P86-E("X@)W!R;VUP=#X@=&%G)RD[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D<W5B<&%R86U;
M)'1A<VMS3F%M97-P86-E("X@)W1Y<&4G72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?24Y604Q)
M1"P@)U!O<W0M:6YS=&%L;"!S8W)I<'0@(B<@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1F:6QE6&UL6R=N86UE)UT@+B`G(B!P87)A;65T97(@
M(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=6)P87)A;5LD
M=&%S:W-.86UE<W!A8V4@+B`G;F%M92==("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`G(B!F;W(@)R`N("1T87-K<TYA;65S<&%C92`N("=P87)A
M;6=R;W5P/B!I9"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M6R1T87-K<TYA;65S<&%C92`N("=I9"==("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(B!M=7-T(&AA=F4@82`G("X@)'1A<VMS3F%M
M97-P86-E("X@)W1Y<&4^('1A9R<I.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@("1D969I;F5D<&%R86US6UT@/2`D<&%R
M86U;)'1A<VMS3F%M97-P86-E("X@)VED)UT@+B`G.CHG("X-"B`@("`@("`@
M("`@("`@("`@("`@)'-U8G!A<F%M6R1T87-K<TYA;65S<&%C92`N("=N86UE
M)UT[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("!]#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"@T*("`@("\J*@T*
M("`@("`J($EN:71I86QI>F4@82!T87-K(&EN<W1A;F-E('=I=&@@=&AE('!A
M<F%M971E<G,-"B`@("`@*B!`<&%R86T@87)R87D@<F%W+"!P87)S960@>&UL
M#0H@("`@("H@0'!A<F%M(&%R<F%Y(&%T=')I8G5T97,@9G)O;2!T:&4@/&9I
M;&4^('1A9R!C;VYT86EN:6YG('1H:7,@=&%S:PT*("`@("`J($!P87)A;2!S
M=')I;F=\;G5L;"!L87-T(&EN<W1A;&QE9"!V97)S:6]N(&]F('1H:7,@<&%C
M:V%G92P@:68@86YY("AU<V5F=6P@9F]R('5P9W)A9&5S*0T*("`@("`J+PT*
M("`@(&9U;F-T:6]N(&EN:70H)'AM;"P@)&9I;&5A='1R:6)S+"`D;&%S='9E
M<G-I;VXI#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V-L87-S(#T@<W1R7W)E
M<&QA8V4H)R\G+"`G7R<L("1F:6QE871T<FEB<ULG;F%M92==*3L-"B`@("`@
M("`@)'1H:7,M/E]F:6QE;F%M92`]("1F:6QE871T<FEB<ULG;F%M92==.PT*
M("`@("`@("`D=&AI<RT^7V-L87-S(#T@<W1R7W)E<&QA8V4@*"<N<&AP)RP@
M)R<L("1T:&ES+3Y?8VQA<W,I("X@)U]P;W-T:6YS=&%L;"<[#0H@("`@("`@
M("1T:&ES+3Y?<&%R86US(#T@)'AM;#L-"B`@("`@("`@)'1H:7,M/E]L87-T
M=F5R<VEO;B`]("1L87-T=F5R<VEO;CL-"B`@("!]#0H-"B`@("`O*BH-"B`@
M("`@*B!3=')I<"!T:&4@=&%S:W,Z(&YA;65S<&%C92!F<F]M(&EN=&5R;F%L
M('!A<F%M<PT*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@("`@
M("HO#0H@("`@9G5N8W1I;VX@7W-T<FEP3F%M97-P86-E*"1P87)A;7,@/2!N
M=6QL*0T*("`@('L-"B`@("`@("`@:68@*"1P87)A;7,@/3T](&YU;&PI('L-
M"B`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M:68@*"%I<U]A<G)A>2@D=&AI<RT^7W!A<F%M<RDI('L-"B`@("`@("`@("`@
M("`@("!R971U<FX[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W!A<F%M<R!A<R`D:2`]/B`D<&%R86TI('L-"B`@("`@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)'!A<F%M*2D@>PT*("`@("`@("`@
M("`@("`@("`@("`D<&%R86T@/2`D=&AI<RT^7W-T<FEP3F%M97-P86-E*"1P
M87)A;2D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("1P
M87)A;7-;<W1R7W)E<&QA8V4H)'1H:7,M/E]P:V<M/F=E=%1A<VMS3G,H*2`N
M("<Z)RP@)R<L("1I*5T@/2`D<&%R86T[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`D=&AI<RT^7W!A<F%M<R`]("1P87)A;7,[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-"B`@
M("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@)'!A<F%M*2![
M#0H@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'1H:7,M/E]S=')I<$YA;65S
M<&%C92@D<&%R86TI.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`D;F5W<&%R86US6W-T<E]R97!L86-E*"1T:&ES+3Y?<&MG+3YG9714
M87-K<TYS*"D@+B`G.B<L("<G+"`D:2E=(#T@)'!A<F%M.PT*("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@<F5T=7)N("1N97=P87)A;7,[#0H@("`@("`@
M('T-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!5;FQI:V4@;W1H97(@=&%S
M:W,L('1H92!I;G-T86QL960@9FEL92!N86UE(&ES('!A<W-E9"!I;B!I;G-T
M96%D(&]F('1H92!F:6QE(&-O;G1E;G1S+`T*("`@("`J(&)E8V%U<V4@=&AI
M<R!T87-K(&ES(&AA;F1L960@<&]S="UI;G-T86QL871I;VX-"B`@("`@*B!`
M<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R
M#0H@("`@("H@0'!A<F%M('-T<FEN9R!F:6QE(&YA;64-"B`@("`@*B!`<F5T
M=7)N(&)O;VQ\4$5!4E]%<G)O<B!F86QS92!T;R!S:VEP('1H:7,@9FEL92P@
M4$5!4E]%<G)O<B!T;R!F86EL#0H@("`@("H@("`@("`@("`H=7-E("1T:&ES
M+3YT:')O=T5R<F]R*0T*("`@("`J+PT*("`@(&9U;F-T:6]N('-T87)T4V5S
M<VEO;B@D<&MG+"`D8V]N=&5N=',I#0H@("`@>PT*("`@("`@("!I9B`H)'1H
M:7,M/FEN<W1A;&QP:&%S92`A/2!014%27U1!4TM?24Y35$%,3"D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@("\O
M(')E;6]V92!T:&4@=&%S:W,Z(&YA;65S<&%C92!I9B!P<F5S96YT#0H@("`@
M("`@("1T:&ES+3Y?<&MG(#T@)'!K9SL-"B`@("`@("`@)'1H:7,M/E]S=')I
M<$YA;65S<&%C92@I.PT*("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,"P@
M)TEN8VQU9&EN9R!E>'1E<FYA;"!P;W-T+6EN<W1A;&QA=&EO;B!S8W)I<'0@
M(B<@+@T*("`@("`@("`@("`@)&-O;G1E;G1S("X@)R(@+2!A;GD@97)R;W)S
M(&%R92!I;B!T:&ES('-C<FEP="<I.PT*("`@("`@("!I;F-L=61E7V]N8V4@
M)&-O;G1E;G1S.PT*("`@("`@("!I9B`H8VQA<W-?97AI<W1S*"1T:&ES+3Y?
M8VQA<W,I*2![#0H@("`@("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,"P@
M)TEN8VQU<VEO;B!S=6-C965D960G*3L-"B`@("`@("`@?2!E;'-E('L-"B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^=&AR;W=%<G)O<B@G:6YI="!O9B!P
M;W-T+6EN<W1A;&P@<V-R:7!T(&-L87-S("(G("X@)'1H:7,M/E]C;&%S<PT*
M("`@("`@("`@("`@("`@("X@)R(@9F%I;&5D)RD[#0H@("`@("`@('T-"B`@
M("`@("`@)'1H:7,M/E]O8FH@/2!N97<@)'1H:7,M/E]C;&%S<SL-"B`@("`@
M("`@)'1H:7,M/FQO9V=E<BT^;&]G*#$L("=R=6YN:6YG('!O<W0M:6YS=&%L
M;"!S8W)I<'0@(B<@+B`D=&AI<RT^7V-L87-S("X@)RT^:6YI="@I(B<I.PT*
M("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%
M5%523BD[#0H@("`@("`@("1R97,@/2`D=&AI<RT^7V]B:BT^:6YI="@D=&AI
M<RT^8V]N9FEG+"`D<&MG+"`D=&AI<RT^7VQA<W1V97)S:6]N*3L-"B`@("`@
M("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I9B`H)')E
M<RD@>PT*("`@("`@("`@("`@)'1H:7,M/FQO9V=E<BT^;&]G*#`L("=I;FET
M('-U8V-E961E9"<I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YT:')O=T5R<F]R*"=I;FET(&]F('!O<W0M:6YS=&%L
M;"!S8W)I<'0@(B<@+B`D=&AI<RT^7V-L87-S("X-"B`@("`@("`@("`@("`@
M("`G+3YI;FET*"DB(&9A:6QE9"<I.PT*("`@("`@("!]#0H@("`@("`@("1T
M:&ES+3Y?8V]N=&5N=',@/2`D8V]N=&5N=',[#0H@("`@("`@(')E='5R;B!T
M<G5E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($YO(&QO;F=E<B!U<V5D
M#0H@("`@("H@0'-E92!014%27U!A8VMA9V5&:6QE7W8R.CIR=6Y0;W-T:6YS
M=&%L;%-C<FEP=',H*0T*("`@("`J($!P87)A;2!A<G)A>2!A;B!A<G)A>2!O
M9B!T87-K<PT*("`@("`J($!P87)A;2!S=')I;F<@:6YS=&%L;"!O<B!U<&=R
M861E#0H@("`@("H@0&%C8V5S<R!P<F]T96-T960-"B`@("`@*B!`<W1A=&EC
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@<G5N*"D-"B`@("![#0H@("`@?0T*
M?0T*/SX`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2+U1A<VLO4F5P;&%C92YP
M:'``````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$V,C4V(#$P
M-3$U-#,T,3,T(#`R,C(Q,0`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+RHJ#0H@*B`\=&%S:W,Z<F5P;&%C93X-
M"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*
M("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@
M*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`
M875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4F5P;&%C
M92YP:'`L=B`Q+C$U(#(P,#8O,#,O,#(@,3@Z,30Z,3,@8V5L;&]G($5X<"`D
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO#0IR
M97%U:7)E7V]N8V4@)U!%05(O5&%S:R]#;VUM;VXN<&AP)SL-"B\J*@T*("H@
M26UP;&5M96YT<R!T:&4@<F5P;&%C92!F:6QE('1A<VLN#0H@*B!`8V%T96=O
M<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@
M("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP#0H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S
M:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP
M83$-"B`J+PT*8VQA<W,@4$5!4E]487-K7U)E<&QA8V4@97AT96YD<R!014%2
M7U1A<VM?0V]M;6]N#0I[#0H@("`@=F%R("1T>7!E(#T@)W-I;7!L92<[#0H@
M("`@=F%R("1P:&%S92`](%!%05)?5$%32U]004-+04=%04Y$24Y35$%,3#L-
M"B`@("!V87(@)%]R97!L86-E;65N=',[#0H-"B`@("`O*BH-"B`@("`@*B!6
M86QI9&%T92!T:&4@<F%W('AM;"!A="!P87)S:6YG+71I;64N#0H@("`@("H@
M0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C(-"B`@("`@*B!`<&%R86T@87)R
M87D@<F%W+"!P87)S960@>&UL#0H@("`@("H@0'!A<F%M(%!%05)?0V]N9FEG
M#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U;F-T:6]N('9A;&ED
M871E6&UL*"1P:V<L("1X;6PL("8D8V]N9FEG+"`D9FEL95AM;"D-"B`@("![
M#0H@("`@("`@(&EF("@A:7-S970H)'AM;%LG871T<FEB<R==*2D@>PT*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E].3T%45%))
M0E,I.PT*("`@("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'AM;%LG871T
M<FEB<R==6R=T>7!E)UTI*2![#0H@("`@("`@("`@("!R971U<FX@87)R87DH
M4$5!4E]405-+7T524D]27TU)4U-)3D=?05144DE"+"`G='EP92<I.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'AM;%LG871T<FEB<R==6R=T
M;R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%
M4E)/4E]-25-324Y'7T%45%))0BP@)W1O)RD[#0H@("`@("`@('T-"B`@("`@
M("`@:68@*"%I<W-E="@D>&UL6R=A='1R:6)S)UU;)V9R;VTG72DI('L-"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?34E34TE.
M1U]!5%1224(L("=F<F]M)RD[#0H@("`@("`@('T-"B`@("`@("`@:68@*"1X
M;6Q;)V%T=')I8G,G75LG='EP92==(#T]("=P96%R+6-O;F9I9R<I('L-"B`@
M("`@("`@("`@(&EF("@A:6Y?87)R87DH)'AM;%LG871T<FEB<R==6R=T;R==
M+"`D8V]N9FEG+3YG971+97ES*"DI*2![#0H@("`@("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E]74D].1U]!5%1224)?5D%,544L
M("=T;R<L("1X;6Q;)V%T=')I8G,G75LG=&\G72P-"B`@("`@("`@("`@("`@
M("`@("`@)&-O;F9I9RT^9V5T2V5Y<R@I*3L-"B`@("`@("`@("`@('T-"B`@
M("`@("`@?2!E;'-E:68@*"1X;6Q;)V%T=')I8G,G75LG='EP92==(#T]("=P
M:'`M8V]N<W0G*2![#0H@("`@("`@("`@("!I9B`H9&5F:6YE9"@D>&UL6R=A
M='1R:6)S)UU;)W1O)UTI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E
M='5R;B!A<G)A>2A014%27U1!4TM?15)23U)?5U)/3D=?05144DE"7U9!3%5%
M+"`G=&\G+"`D>&UL6R=A='1R:6)S)UU;)W1O)UTL#0H@("`@("`@("`@("`@
M("`@("`@(&%R<F%Y*"=V86QI9"!02%`@8V]N<W1A;G0G*2D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T@96QS96EF("@D>&UL6R=A='1R:6)S)UU;)W1Y
M<&4G72`]/2`G<&%C:V%G92UI;F9O)RD@>PT*("`@("`@("`@("`@:68@*&EN
M7V%R<F%Y*"1X;6Q;)V%T=')I8G,G75LG=&\G72P-"B`@("`@("`@("`@("`@
M("!A<G)A>2@G;F%M92<L("=S=6UM87)Y)RP@)V-H86YN96PG+"`G;F]T97,G
M+"`G97AT96YD<R<L("=D97-C<FEP=&EO;B<L#0H@("`@("`@("`@("`@("`@
M("`@("=R96QE87-E7VYO=&5S)RP@)VQI8V5N<V4G+"`G<F5L96%S92UL:6-E
M;G-E)RP@)VQI8V5N<V4M=7)I)RP-"B`@("`@("`@("`@("`@("`@("`@)W9E
M<G-I;VXG+"`G87!I+79E<G-I;VXG+"`G<W1A=&4G+"`G87!I+7-T871E)RP@
M)W)E;&5A<V5?9&%T92<L#0H@("`@("`@("`@("`@("`@("`@("=D871E)RP@
M)W1I;64G*2DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@
M("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R
M<F%Y*%!%05)?5$%32U]%4E)/4E]74D].1U]!5%1224)?5D%,544L("=T;R<L
M("1X;6Q;)V%T=')I8G,G75LG=&\G72P-"B`@("`@("`@("`@("`@("`@("`@
M87)R87DH)VYA;64G+"`G<W5M;6%R>2<L("=C:&%N;F5L)RP@)VYO=&5S)RP@
M)V5X=&5N9',G+"`G9&5S8W)I<'1I;VXG+`T*("`@("`@("`@("`@("`@("`@
M("`G<F5L96%S95]N;W1E<R<L("=L:6-E;G-E)RP@)W)E;&5A<V4M;&EC96YS
M92<L("=L:6-E;G-E+75R:2<L#0H@("`@("`@("`@("`@("`@("`@("=V97)S
M:6]N)RP@)V%P:2UV97)S:6]N)RP@)W-T871E)RP@)V%P:2US=&%T92<L("=R
M96QE87-E7V1A=&4G+`T*("`@("`@("`@("`@("`@("`@("`G9&%T92<L("=T
M:6UE)RDI.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@<F5T=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E]74D].1U]!
M5%1224)?5D%,544L("=T>7!E)RP@)'AM;%LG871T<FEB<R==6R=T>7!E)UTL
M#0H@("`@("`@("`@("`@("`@87)R87DH)W!E87(M8V]N9FEG)RP@)W!A8VMA
M9V4M:6YF;R<L("=P:'`M8V]N<W0G*2D[#0H@("`@("`@('T-"B`@("`@("`@
M<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@26YI=&EA
M;&EZ92!A('1A<VL@:6YS=&%N8V4@=VET:"!T:&4@<&%R86UE=&5R<PT*("`@
M("`J($!P87)A;2!A<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R
M86T@=6YU<V5D#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YI="@D>&UL+"`D
M871T<FEB<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<F5P;&%C96UE;G1S
M(#T@:7-S970H)'AM;%LG871T<FEB<R==*2`_(&%R<F%Y*"1X;6PI(#H@)'AM
M;#L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!$;R!A('!A8VMA9V4N>&UL
M(#$N,"!R97!L86-E;65N="P@=VET:"!A9&1I=&EO;F%L('!A8VMA9V4M:6YF
M;R!F:65L9',@879A:6QA8FQE#0H@("`@("H-"B`@("`@*B!3964@=F%L:61A
M=&58;6PH*2!S;W5R8V4@9F]R('1H92!C;VUP;&5T92!L:7-T(&]F(&%L;&]W
M960@9FEE;&1S#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\
M4$5!4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL
M92!C;VYT96YT<PT*("`@("`J($!P87)A;2!S=')I;F<@=&AE(&5V96YT=6%L
M(&9I;F%L(&9I;&4@;&]C871I;VX@*&EN9F]R;6%T:6]N86P@;VYL>2D-"B`@
M("`@*B!`<F5T=7)N('-T<FEN9WQF86QS97Q014%27T5R<F]R(&9A;'-E('1O
M('-K:7`@=&AI<R!F:6QE+"!014%27T5R<F]R('1O(&9A:6P-"B`@("`@*B`@
M("`@("`@("AU<V4@)'1H:7,M/G1H<F]W17)R;W(I+"!O=&AE<G=I<V4@<F5T
M=7)N('1H92!N97<@8V]N=&5N=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S
M=&%R=%-E<W-I;VXH)'!K9RP@)&-O;G1E;G1S+"`D9&5S="D-"B`@("![#0H@
M("`@("`@("1S=6)S=%]F<F]M(#T@)'-U8G-T7W1O(#T@87)R87DH*3L-"B`@
M("`@("`@9F]R96%C:"`H)'1H:7,M/E]R97!L86-E;65N=',@87,@)&$I('L-
M"B`@("`@("`@("`@("1A(#T@)&%;)V%T=')I8G,G73L-"B`@("`@("`@("`@
M("1T;R`]("<G.PT*("`@("`@("`@("`@:68@*"1A6R=T>7!E)UT@/3T@)W!E
M87(M8V]N9FEG)RD@>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^:6YS
M=&%L;'!H87-E(#T](%!%05)?5$%32U]004-+04=%*2![#0H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@:68@*"1A6R=T;R==(#T]("=M87-T97)?<V5R=F5R
M)RD@>PT*("`@("`@("`@("`@("`@("`@("`D8VAA;B`]("1T:&ES+3YR96=I
M<W1R>2T^9V5T0VAA;FYE;"@D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H(5!%05(Z.FES17)R;W(H)&-H86XI*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=&\@/2`D8VAA;BT^9V5T4V5R=F5R
M*"D[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;&]G9V5R+3YL;V<H,"P@(B1D97-T.B!I
M;G9A;&ED('!E87(M8V]N9FEG(')E<&QA8V5M96YT.B`D85MT;UTB*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^8V]N9FEG+3YI<T1E9FEN961,
M87EE<B@G9G1P)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("\O('1R
M>2!T:&4@<F5M;W1E(&-O;F9I9R!F:6QE(&9I<G-T#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&\@/2`D=&AI<RT^8V]N9FEG+3YG970H)&%;)W1O)UTL
M("=F='`G+"`D<&MG+3YG971#:&%N;F5L*"DI.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7VYU;&PH)'1O*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O('1H96X@9&5F875L="!T;R!L;V-A;`T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T:&ES+3YC;VYF:6<M/F=E
M="@D85LG=&\G72P@;G5L;"P@)'!K9RT^9V5T0VAA;FYE;"@I*3L-"B`@("`@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T;R`]("1T:&ES+3YC
M;VYF:6<M/F=E="@D85LG=&\G72P@;G5L;"P@)'!K9RT^9V5T0VAA;FYE;"@I
M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!I9B`H:7-?;G5L;"@D=&\I*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YL;V=G97(M/FQO9R@P+"`B)&1E<W0Z(&EN
M=F%L:60@<&5A<BUC;VYF:6<@<F5P;&%C96UE;G0Z("1A6W1O72(I.PT*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@?2!E;'-E:68@*"1A6R=T>7!E)UT@/3T@)W!H
M<"UC;VYS="<I('L-"B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/FEN<W1A
M;&QP:&%S92`]/2!014%27U1!4TM?4$%#2T%'12D@>PT*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AD969I;F5D*"1A6R=T;R==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=&\@/2!C;VYS=&%N="@D85LG=&\G72D[#0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/FQO9V=E<BT^;&]G*#`L("(D9&5S=#H@:6YV86QI9"!P:'`M8V]N<W0@
M<F5P;&%C96UE;G0Z("1A6W1O72(I.PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H)'0@/2`D<&MG+3YP86-K
M86=E26YF;R@D85LG=&\G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1O
M(#T@)'0[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/FQO9V=E<BT^;&]G*#`L("(D9&5S=#H@:6YV86QI
M9"!P86-K86=E+6EN9F\@<F5P;&%C96UE;G0Z("1A6W1O72(I.PT*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@:68@*"%I<U]N=6QL*"1T
M;RDI('L-"B`@("`@("`@("`@("`@("`D<W5B<W1?9G)O;5M=(#T@)&%;)V9R
M;VTG73L-"B`@("`@("`@("`@("`@("`D<W5B<W1?=&];72`]("1T;SL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("`D=&AI<RT^;&]G9V5R
M+3YL;V<H,RP@(F1O:6YG("(@+B!S:7IE;V8H)'-U8G-T7V9R;VTI("X-"B`@
M("`@("`@("`@("(@<W5B<W1I='5T:6]N*',I(&9O<B`D9&5S="(I.PT*("`@
M("`@("!I9B`H<VEZ96]F*"1S=6)S=%]F<F]M*2D@>PT*("`@("`@("`@("`@
M)&-O;G1E;G1S(#T@<W1R7W)E<&QA8V4H)'-U8G-T7V9R;VTL("1S=6)S=%]T
M;RP@)&-O;G1E;G1S*3L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&-O
M;G1E;G1S.PT*("`@('T-"GT-"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!%05(O5&%S:R]5;FEX96]L
M+G!H<```````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4R,C$@
M,3`U,34T,S0Q,S0@,#(R,C0W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*BH-"B`J(#QT87-K<SIU;FEX96]L
M/@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!5;FEX
M96]L+G!H<"QV(#$N."`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@
M)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!%05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A,0T*("HO#0HO*BH-"B`J($)A<V4@8VQA<W,-"B`J+PT*
M<F5Q=6ER95]O;F-E("=014%2+U1A<VLO0V]M;6]N+G!H<"<[#0HO*BH-"B`J
M($EM<&QE;65N=',@=&AE('5N:7@@;&EN92!E;F1I;F=S(&9I;&4@=&%S:RX-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY
M#0H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M4$5!4@T*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U1A<VM?56YI>&5O;"!E
M>'1E;F1S(%!%05)?5&%S:U]#;VUM;VX-"GL-"B`@("!V87(@)'1Y<&4@/2`G
M<VEM<&QE)SL-"B`@("!V87(@)'!H87-E(#T@4$5!4E]405-+7U!!0TM!1T4[
M#0H@("`@=F%R("1?<F5P;&%C96UE;G1S.PT*#0H@("`@+RHJ#0H@("`@("H@
M5F%L:61A=&4@=&AE(')A=R!X;6P@870@<&%R<VEN9RUT:6UE+@T*("`@("`J
M($!P87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M(&%R
M<F%Y(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P87)A;2!014%27T-O;F9I
M9PT*("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI
M9&%T95AM;"@D<&MG+"`D>&UL+"`F)&-O;F9I9RP@)&9I;&58;6PI#0H@("`@
M>PT*("`@("`@("!I9B`H)'AM;"`A/2`G)RD@>PT*("`@("`@("`@("`@<F5T
M=7)N(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G;F\@871T<FEB
M=71E<R!A;&QO=V5D)RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@26YI=&EA;&EZ92!A('1A
M<VL@:6YS=&%N8V4@=VET:"!T:&4@<&%R86UE=&5R<PT*("`@("`J($!P87)A
M;2!A<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@=6YU<V5D
M#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:6YI="@D>&UL+"`D871T<FEB<RD-
M"B`@("![#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5P;&%C92!A;&P@
M;&EN92!E;F1I;F=S('=I=&@@;&EN92!E;F1I;F=S(&-U<W1O;6EZ960@9F]R
M('1H92!C=7)R96YT($]3#0H@("`@("H-"B`@("`@*B!3964@=F%L:61A=&58
M;6PH*2!S;W5R8V4@9F]R('1H92!C;VUP;&5T92!L:7-T(&]F(&%L;&]W960@
M9FEE;&1S#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C%\4$5!
M4E]086-K86=E1FEL95]V,@T*("`@("`J($!P87)A;2!S=')I;F<@9FEL92!C
M;VYT96YT<PT*("`@("`J($!P87)A;2!S=')I;F<@=&AE(&5V96YT=6%L(&9I
M;F%L(&9I;&4@;&]C871I;VX@*&EN9F]R;6%T:6]N86P@;VYL>2D-"B`@("`@
M*B!`<F5T=7)N('-T<FEN9WQF86QS97Q014%27T5R<F]R(&9A;'-E('1O('-K
M:7`@=&AI<R!F:6QE+"!014%27T5R<F]R('1O(&9A:6P-"B`@("`@*B`@("`@
M("`@("AU<V4@)'1H:7,M/G1H<F]W17)R;W(I+"!O=&AE<G=I<V4@<F5T=7)N
M('1H92!N97<@8V]N=&5N=',-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!S=&%R
M=%-E<W-I;VXH)'!K9RP@)&-O;G1E;G1S+"`D9&5S="D-"B`@("![#0H@("`@
M("`@("1T:&ES+3YL;V=G97(M/FQO9R@S+"`B<F5P;&%C:6YG(&%L;"!L:6YE
M(&5N9&EN9W,@=VET:"!<7&X@:6X@)&1E<W0B*3L-"B`@("`@("`@<F5T=7)N
M('!R96=?<F5P;&%C92@B+UQR7&Y\7&Y<<GQ<<GQ<;B\B+"`B7&XB+"`D8V]N
M=&5N=',I.PT*("`@('T-"GT-"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$5!4B]487-K+U=I;F1O=W-E;VPN<&AP````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-3(Q-2`Q,#4Q-30S-#$S-"`P,C(W
M-C$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`-"B\J*@T*("H@/'1A<VMS.G=I;F1O=W-E;VP^#0H@*@T*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%=I;F1O=W-E;VPN<&AP+'8@
M,2XW(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N
M,&$Q#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO#0IR97%U:7)E7V]N
M8V4@)U!%05(O5&%S:R]#;VUM;VXN<&AP)SL-"B\J*@T*("H@26UP;&5M96YT
M<R!T:&4@=VEN9&]W<R!L:6YE(&5N9'-I;F=S(&9I;&4@=&%S:RX-"B`J($!C
M871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H
M;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*
M("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@
M,2XT+C!A,0T*("HO#0IC;&%S<R!014%27U1A<VM?5VEN9&]W<V5O;"!E>'1E
M;F1S(%!%05)?5&%S:U]#;VUM;VX-"GL-"B`@("!V87(@)'1Y<&4@/2`G<VEM
M<&QE)SL-"B`@("!V87(@)'!H87-E(#T@4$5!4E]405-+7U!!0TM!1T4[#0H@
M("`@=F%R("1?<F5P;&%C96UE;G1S.PT*#0H@("`@+RHJ#0H@("`@("H@5F%L
M:61A=&4@=&AE(')A=R!X;6P@870@<&%R<VEN9RUT:6UE+@T*("`@("`J($!P
M87)A;2!014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@0'!A<F%M(&%R<F%Y
M(')A=RP@<&%R<V5D('AM;`T*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!V86QI9&%T
M95AM;"@D<&MG+"`D>&UL+"`F)&-O;F9I9RP@)&9I;&58;6PI#0H@("`@>PT*
M("`@("`@("!I9B`H)'AM;"`A/2`G)RD@>PT*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*%!%05)?5$%32U]%4E)/4E])3E9!3$E$+"`G;F\@871T<FEB=71E
M<R!A;&QO=V5D)RD[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@26YI=&EA;&EZ92!A('1A<VL@
M:6YS=&%N8V4@=VET:"!T:&4@<&%R86UE=&5R<PT*("`@("`J($!P87)A;2!A
M<G)A>2!R87<L('!A<G-E9"!X;6P-"B`@("`@*B!`<&%R86T@=6YU<V5D#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@:6YI="@D>&UL+"`D871T<FEB<RD-"B`@
M("![#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@4F5P;&%C92!A;&P@;&EN
M92!E;F1I;F=S('=I=&@@=VEN9&]W<R!L:6YE(&5N9&EN9W,-"B`@("`@*@T*
M("`@("`J(%-E92!V86QI9&%T95AM;"@I('-O=7)C92!F;W(@=&AE(&-O;7!L
M971E(&QI<W0@;V8@86QL;W=E9"!F:65L9',-"B`@("`@*B!`<&%R86T@4$5!
M4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA9V5&:6QE7W8R#0H@("`@("H@
M0'!A<F%M('-T<FEN9R!F:6QE(&-O;G1E;G1S#0H@("`@("H@0'!A<F%M('-T
M<FEN9R!T:&4@979E;G1U86P@9FEN86P@9FEL92!L;V-A=&EO;B`H:6YF;W)M
M871I;VYA;"!O;FQY*0T*("`@("`J($!R971U<FX@<W1R:6YG?&9A;'-E?%!%
M05)?17)R;W(@9F%L<V4@=&\@<VMI<"!T:&ES(&9I;&4L(%!%05)?17)R;W(@
M=&\@9F%I;`T*("`@("`J("`@("`@("`@*'5S92`D=&AI<RT^=&AR;W=%<G)O
M<BDL(&]T:&5R=VES92!R971U<FX@=&AE(&YE=R!C;VYT96YT<PT*("`@("`J
M+PT*("`@(&9U;F-T:6]N('-T87)T4V5S<VEO;B@D<&MG+"`D8V]N=&5N=',L
M("1D97-T*0T*("`@('L-"B`@("`@("`@)'1H:7,M/FQO9V=E<BT^;&]G*#,L
M(")R97!L86-I;F<@86QL(&QI;F4@96YD:6YG<R!W:71H(%Q<<EQ<;B!I;B`D
M9&5S="(I.PT*("`@("`@("!R971U<FX@<')E9U]R97!L86-E*"(O7')<;GQ<
M;EQR?%QR?%QN+R(L(")<<EQN(BP@)&-O;G1E;G1S*3L-"B`@("!]#0I]#0H_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]014%2
M+U1A<VLO4&]S=&EN<W1A;&QS8W)I<'0O<G<N<&AP````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$T,S4U(#$P-3$U-#,T,3,T(#`R-3`R-0`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`T*+RHJ#0H@*B`\
M=&%S:W,Z<&]S=&EN<W1A;&QS8W)I<'0^("T@<F5A9"]W<FET92!V97)S:6]N
M#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O
M=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*
M("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@
M0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E
M;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(
M4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W+G!H
M<"QV(#$N,3$@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83$P#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O5&%S:R]0;W-T:6YS=&%L;'-C<FEP="YP:'`G.PT*
M+RHJ#0H@*B!!8G-T<F%C=',@=&AE('!O<W1I;G-T86QL<V-R:7!T(&9I;&4@
M=&%S:R!X;6PN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@
M("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H
M<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U
M<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!296QE
M87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-"XP83$P#0H@*B\-"F-L87-S(%!%05)?5&%S
M:U]0;W-T:6YS=&%L;'-C<FEP=%]R=R!E>'1E;F1S(%!%05)?5&%S:U]0;W-T
M:6YS=&%L;'-C<FEP=`T*>PT*("`@("\J*@T*("`@("`J('!A<F5N="!P86-K
M86=E(&9I;&4@;V)J96-T#0H@("`@("H-"B`@("`@*B!`=F%R(%!%05)?4&%C
M:V%G949I;&5?=C)?<G<-"B`@("`@*B\-"B`@("!V87(@)%]P:V<[#0H@("`@
M+RHJ#0H@("`@("H@16YT97(@9&5S8W)I<'1I;VX@:&5R92XN+@T*("`@("`J
M#0H@("`@("H@0'!A<F%M(%!%05)?4&%C:V%G949I;&5?=C)?<G<@)'!K9PT*
M("`@("`J($!P87)A;2!014%27T-O;F9I9R`D8V]N9FEG#0H@("`@("H@0'!A
M<F%M(%!%05)?1G)O;G1E;F0@)&QO9V=E<@T*("`@("`J($!P87)A;2!A<G)A
M>2`D9FEL95AM;`T*("`@("`J($!R971U<FX@4$5!4E]487-K7U!O<W1I;G-T
M86QL<V-R:7!T7W)W#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]487-K
M7U!O<W1I;G-T86QL<V-R:7!T7W)W*"8D<&MG+"`F)&-O;F9I9RP@)B1L;V=G
M97(L("1F:6QE6&UL*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27U1A
M<VM?0V]M;6]N*"1C;VYF:6<L("1L;V=G97(L(%!%05)?5$%32U]004-+04=%
M*3L-"B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("1F:6QE6&UL.PT*("`@
M("`@("`D=&AI<RT^7W!K9R`]("8D<&MG.PT*("`@("`@("`D=&AI<RT^7W!A
M<F%M<R`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3YV86QI9&%T95AM
M;"@D=&AI<RT^7W!K9RP@)'1H:7,M/E]P87)A;7,L("1T:&ES+3YC;VYF:6<L
M("1T:&ES+3Y?8V]N=&5N=',I.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E
M=$YA;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("=P;W-T:6YS=&%L;'-C
M<FEP="<[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@861D(&$@<VEM<&QE
M(#QP87)A;6=R;W5P/B!T;R!T:&4@<&]S="UI;G-T86QL('-C<FEP=`T*("`@
M("`J#0H@("`@("H@3W)D97(@:7,@<VEG;FEF:6-A;G0L('-O(&-A;&P@=&AI
M<R!M971H;V0@:6X@=&AE('-A;64-"B`@("`@*B!S97%U96YC92!T:&4@=7-E
M<G,@<VAO=6QD('-E92!T:&4@<&%R86UG<F]U<',N("!4:&4@)'!A<F%M<PT*
M("`@("`J('!A<F%M971E<B!S:&]U;&0@96ET:&5R(&)E('1H92!R97-U;'0@
M;V8@82!C86QL('1O('M`;&EN:R!G971087)A;2@I?0T*("`@("`J(&]R(&%N
M(&%R<F%Y(&]F(&-A;&QS('1O(&=E=%!A<F%M*"DN#0H@("`@("H@#0H@("`@
M("H@57-E('M`;&EN:R!A9&1#;VYD:71I;VY4>7!E1W)O=7`H*7T@=&\@861D
M(&$@/'!A<F%M9W)O=7`^(&-O;G1A:6YI;F<-"B`@("`@*B!A(#QC;VYD:71I
M;VYT>7!E/B!T86<-"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`\<&%R86UG
M<F]U<#X@:60@87,@<V5E;B!B>2!T:&4@<V-R:7!T#0H@("`@("H@0'!A<F%M
M(&%R<F%Y?&9A;'-E("1P87)A;7,@87)R87D@;V8@9V5T4&%R86TH*2!C86QL
M<RP@;W(@9F%L<V4@9F]R(&YO('!A<F%M<PT*("`@("`J($!P87)A;2!S=')I
M;F=\9F%L<V4@)&EN<W1R=6-T:6]N<PT*("`@("`J+PT*("`@(&9U;F-T:6]N
M(&%D9%!A<F%M1W)O=7`H)&ED+"`D<&%R86US(#T@9F%L<V4L("1I;G-T<G5C
M=&EO;G,@/2!F86QS92D-"B`@("![#0H@("`@("`@(&EF("@D<&%R86US("8F
M(&ES<V5T*"1P87)A;7-;,%TI("8F("%I<W-E="@D<&%R86US6S%=*2D@>PT*
M("`@("`@("`@("`@)'!A<F%M<R`]("1P87)A;7-;,%T[#0H@("`@("`@('T-
M"B`@("`@("`@)'-T=69F(#T-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.FED)R`]
M/B`D:60L#0H@("`@("`@("`@("`I.PT*("`@("`@("!I9B`H)&EN<W1R=6-T
M:6]N<RD@>PT*("`@("`@("`@("`@)'-T=69F6R1T:&ES+3Y?<&MG+3YG9714
M87-K<TYS*"D@+B`G.FEN<W1R=6-T:6]N<R==(#T@)&EN<W1R=6-T:6]N<SL-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H)'!A<F%M<RD@>PT*("`@("`@("`@
M("`@)'-T=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G!A<F%M
M)UT@/2`D<&%R86US.PT*("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?<&%R
M86US6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G!A<F%M9W)O=7`G
M75M=(#T@)'-T=69F.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J(&%D9"!A
M(&-O;7!L97@@/'!A<F%M9W)O=7`^('1O('1H92!P;W-T+6EN<W1A;&P@<V-R
M:7!T('=I=&@@8V]N9&ET:6]N<PT*("`@("`J#0H@("`@("H@5&AI<R!I;G-E
M<G1S(&$@/'!A<F%M9W)O=7`^('=I=&@-"B`@("`@*@T*("`@("`J($]R9&5R
M(&ES('-I9VYI9FEC86YT+"!S;R!C86QL('1H:7,@;65T:&]D(&EN('1H92!S
M86UE#0H@("`@("H@<V5Q=65N8V4@=&AE('5S97)S('-H;W5L9"!S964@=&AE
M('!A<F%M9W)O=7!S+B`@5&AE("1P87)A;7,-"B`@("`@*B!P87)A;65T97(@
M<VAO=6QD(&5I=&AE<B!B92!T:&4@<F5S=6QT(&]F(&$@8V%L;"!T;R![0&QI
M;FL@9V5T4&%R86TH*7T-"B`@("`@*B!O<B!A;B!A<G)A>2!O9B!C86QL<R!T
M;R!G971087)A;2@I+@T*("`@("`J(`T*("`@("`J(%5S92![0&QI;FL@861D
M4&%R86U'<F]U<"@I?2!T;R!A9&0@82!S:6UP;&4@/'!A<F%M9W)O=7`^#0H@
M("`@("H-"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9"`\<&%R86UG<F]U<#X@
M:60@87,@<V5E;B!B>2!T:&4@<V-R:7!T#0H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;VQD9W)O=7`@/'!A<F%M9W)O=7`^(&ED(&]F('1H92!S96-T:6]N(')E
M9F5R96YC960@8GD-"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`\
M8V]N9&ET:6]N='EP93X-"B`@("`@*B!`<&%R86T@<W1R:6YG("1P87)A;2!N
M86UE(&]F('1H92`\<&%R86T^(&9R;VT@=&AE(&]L9&5R('-E8W1I;VX@<F5F
M97)E;F-E9`T*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&)Y(#QC;VYT
M:71I;VYT>7!E/@T*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E('9A;'5E
M('1O(&UA=&-H(&]F('1H92!P87)A;65T97(-"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1C;VYD:71I;VYT>7!E(&]N92!O9B`G/2<L("<A/2<L("=P<F5G7VUA
M=&-H)PT*("`@("`J($!P87)A;2!A<G)A>7QF86QS92`D<&%R86US(&%R<F%Y
M(&]F(&=E=%!A<F%M*"D@8V%L;',L(&]R(&9A;'-E(&9O<B!N;R!P87)A;7,-
M"B`@("`@*B!`<&%R86T@<W1R:6YG?&9A;'-E("1I;G-T<G5C=&EO;G,-"B`@
M("`@*B\-"B`@("!F=6YC=&EO;B!A9&1#;VYD:71I;VY4>7!E1W)O=7`H)&ED
M+"`D;VQD9W)O=7`L("1P87)A;2P@)'9A;'5E+"`D8V]N9&ET:6]N='EP92`]
M("<])RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A
M<F%M<R`](&9A;'-E+"`D:6YS=')U8W1I;VYS(#T@9F%L<V4I#0H@("`@>PT*
M("`@("`@("!I9B`H)'!A<F%M<R`F)B!I<W-E="@D<&%R86US6S!=*2`F)B`A
M:7-S970H)'!A<F%M<ULQ72DI('L-"B`@("`@("`@("`@("1P87)A;7,@/2`D
M<&%R86US6S!=.PT*("`@("`@("!]#0H@("`@("`@("1S='5F9B`]#0H@("`@
M("`@("`@("!A<G)A>2@-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!K9RT^
M9V5T5&%S:W-.<R@I("X@)SII9"<@/3X@)&ED+`T*("`@("`@("`@("`@*3L-
M"B`@("`@("`@:68@*"1I;G-T<G5C=&EO;G,I('L-"B`@("`@("`@("`@("1S
M='5F9ELD=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SII;G-T<G5C=&EO
M;G,G72`]("1I;G-T<G5C=&EO;G,[#0H@("`@("`@('T-"B`@("`@("`@)'-T
M=69F6R1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.FYA;64G72`]("1O
M;&1G<F]U<"`N("<Z.B<@+B`D<&%R86T[#0H@("`@("`@("1S='5F9ELD=&AI
M<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SIC;VYD:71I;VYT>7!E)UT@/2`D
M8V]N9&ET:6]N='EP93L-"B`@("`@("`@)'-T=69F6R1T:&ES+3Y?<&MG+3YG
M971487-K<TYS*"D@+B`G.G9A;'5E)UT@/2`D=F%L=64[#0H@("`@("`@(&EF
M("@D<&%R86US*2![#0H@("`@("`@("`@("`D<W1U9F9;)'1H:7,M/E]P:V<M
M/F=E=%1A<VMS3G,H*2`N("<Z<&%R86TG72`]("1P87)A;7,[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/E]P87)A;7-;)'1H:7,M/E]P:V<M/F=E=%1A
M<VMS3G,H*2`N("<Z<&%R86UG<F]U<"==6UT@/2`D<W1U9F8[#0H@("`@?0T*
M#0H@("`@9G5N8W1I;VX@9V5T6&UL*"D-"B`@("![#0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W!A<F%M<SL-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!5
M<V4@=&\@<V5T('5P(&$@<&%R86T@=&%G(&9O<B!U<V4@:6X@8W)E871I;F<@
M82!P87)A;6=R;W5P#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@(&9U
M;F-T:6]N(&=E=%!A<F%M*"1N86UE+"`D<')O;7!T+"`D='EP92`]("=S=')I
M;F<G+"`D9&5F875L="`](&YU;&PI#0H@("`@>PT*("`@("`@("!I9B`H)&1E
M9F%U;'0@(3T](&YU;&PI('L-"B`@("`@("`@("`@(')E='5R;B`-"B`@("`@
M("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("1T:&ES+3Y?<&MG+3YG
M971487-K<TYS*"D@+B`G.FYA;64G(#T^("1N86UE+`T*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G!R;VUP="<@/3X@
M)'!R;VUP="P-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!K9RT^9V5T5&%S
M:W-.<R@I("X@)SIT>7!E)R`]/B`D='EP92P-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W!K9RT^9V5T5&%S:W-.<R@I("X@)SID969A=6QT)R`]/B`D9&5F
M875L=`T*("`@("`@("`@("`@*3L-"B`@("`@("`@?0T*("`@("`@("!R971U
M<FX-"B`@("`@("`@("`@(&%R<F%Y*`T*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.FYA;64G(#T^("1N86UE+`T*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<&MG+3YG971487-K<TYS*"D@+B`G.G!R
M;VUP="<@/3X@)'!R;VUP="P-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W!K
M9RT^9V5T5&%S:W-.<R@I("X@)SIT>7!E)R`]/B`D='EP92P-"B`@("`@("`@
M("`@("D[#0H@("`@?0T*?0T*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O4$5!4B]487-K+U)E<&QA8V4O<G<N<&AP````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,S<U-"`Q,#4Q-30S-#$S-"`P,C(V-#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`-"B\J*@T*("H@/'1A<VMS.G)E<&QA8V4^("T@<F5A9"]W<FET92!V97)S
M:6]N#0H@*@T*("H@4$A0('9E<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%52
M23H-"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)
M9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W96(L('!L96%S90T*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@
M*@T*("H@0&-A=&5G;W)Y("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*
M("H@0&%U=&AO<B`@("`@1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*
M("H@0&-O<'ER:6=H="`@,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`T*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(')W
M+G!H<"QV(#$N,R`R,#`V+S`Q+S`V(#`T.C0W.C,W(&-E;&QO9R!%>'`@)`T*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!%
M05(-"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XT+C!A,3`-"B`J+PT*+RHJ#0H@*B!"87-E(&-L87-S#0H@*B\-"G)E
M<75I<F5?;VYC92`G4$5!4B]487-K+U)E<&QA8V4N<&AP)SL-"B\J*@T*("H@
M06)S=')A8W1S('1H92!R97!L86-E('1A<VL@>&UL+@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M,`T*("HO#0IC;&%S<R!014%27U1A<VM?4F5P;&%C95]R=R!E>'1E;F1S(%!%
M05)?5&%S:U]297!L86-E#0I[#0H@("`@9G5N8W1I;VX@4$5!4E]487-K7U)E
M<&QA8V5?<G<H)B1P:V<L("8D8V]N9FEG+"`F)&QO9V=E<BP@)&9I;&58;6PI
M#0H@("`@>PT*("`@("`@("!P87)E;G0Z.E!%05)?5&%S:U]#;VUM;VXH)&-O
M;F9I9RP@)&QO9V=E<BP@4$5!4E]405-+7U!!0TM!1T4I.PT*("`@("`@("`D
M=&AI<RT^7V-O;G1E;G1S(#T@)&9I;&58;6P[#0H@("`@("`@("1T:&ES+3Y?
M<&MG(#T@)B1P:V<[#0H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@87)R87DH
M*3L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!V86QI9&%T92@I#0H@("`@>PT*
M("`@("`@("!R971U<FX@)'1H:7,M/G9A;&ED871E6&UL*"1T:&ES+3Y?<&MG
M+"`D=&AI<RT^7W!A<F%M<RP@)'1H:7,M/F-O;F9I9RP@)'1H:7,M/E]C;VYT
M96YT<RD[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T26YF;R@D9G)O;2P@
M)'1O+"`D='EP92D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%R86US(#T@
M87)R87DH)V%T=')I8G,G(#T^(&%R<F%Y*"=F<F]M)R`]/B`D9G)O;2P@)W1O
M)R`]/B`D=&\L("=T>7!E)R`]/B`D='EP92DI.PT*("`@('T-"@T*("`@(&9U
M;F-T:6]N(&=E=$YA;64H*0T*("`@('L-"B`@("`@("`@<F5T=7)N("=R97!L
M86-E)SL-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G9718;6PH*0T*("`@('L-
M"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%R86US.PT*("`@('T-"GT-"C\^
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!%05(O5&%S:R]7:6YD;W=S96]L+W)W+G!H<```````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,T,30@,3`U,34T,S0Q,S0@,#(S-#$P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP#0HO
M*BH-"B`J(#QT87-K<SIW:6YD;W=S96]L/B`M(')E860O=W)I=&4@=F5R<VEO
M;@T*("H-"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U#0H@*@T*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP
M(&]F('1H92!02%`@;&EC96YS90T*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M#0H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8-"B`J('1H92!02%`@3&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V5B+"!P;&5A<V4-"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE
M="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@T*("H-
M"B`J($!C871E9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J
M($!A=71H;W(@("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J
M($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!0
M2%`@3&EC96YS92`S+C`-"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!R=RYP
M:'`L=B`Q+C0@,C`P-B\P,2\P-B`P-#HT-SHS-R!C96QL;V<@17AP("0-"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2
M#0H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-"XP83$P#0H@*B\-"B\J*@T*("H@0F%S92!C;&%S<PT*("HO#0IR97%U
M:7)E7V]N8V4@)U!%05(O5&%S:R]7:6YD;W=S96]L+G!H<"<[#0HO*BH-"B`J
M($%B<W1R86-T<R!T:&4@=VEN9&]W<V5O;"!T87-K('AM;"X-"B`J($!C871E
M9V]R>2`@('!E87(-"B`J($!P86-K86=E("`@(%!%05(-"B`J($!A=71H;W(@
M("`@($=R96<@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-B!4:&4@4$A0($=R;W5P#0H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS
M92`S+C`-"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XY#0H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XT
M+C!A,3`-"B`J+PT*8VQA<W,@4$5!4E]487-K7U=I;F1O=W-E;VQ?<G<@97AT
M96YD<R!014%27U1A<VM?5VEN9&]W<V5O;`T*>PT*("`@(&9U;F-T:6]N(%!%
M05)?5&%S:U]7:6YD;W=S96]L7W)W*"8D<&MG+"`F)&-O;F9I9RP@)B1L;V=G
M97(L("1F:6QE6&UL*0T*("`@('L-"B`@("`@("`@<&%R96YT.CI014%27U1A
M<VM?0V]M;6]N*"1C;VYF:6<L("1L;V=G97(L(%!%05)?5$%32U]004-+04=%
M*3L-"B`@("`@("`@)'1H:7,M/E]C;VYT96YT<R`]("1F:6QE6&UL.PT*("`@
M("`@("`D=&AI<RT^7W!K9R`]("8D<&MG.PT*("`@("`@("`D=&AI<RT^7W!A
M<F%M<R`](&%R<F%Y*"D[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@=F%L:61A
M=&4H*0T*("`@('L-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@9V5T3F%M92@I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)W=I;F1O=W-E;VPG.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%AM;"@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)R<[#0H@("`@?0T*?0T*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]0
M14%2+U1A<VLO56YI>&5O;"]R=RYP:'``````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`S,S8W(#$P-3$U-#,T,3,T(#`R,C<Q,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`T*+RHJ#0H@
M*B`\=&%S:W,Z=6YI>&5O;#X@+2!R96%D+W=R:71E('9E<G-I;VX-"B`J#0H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@
M4$A0(&QI8V5N<V4-"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE
M87-E#0H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@
M8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T
M96=O<GD@("!P96%R#0H@*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R
M("`@("!'<F5G($)E879E<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I
M9VAT("`Q.3DW+3(P,#8@5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N
M<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<G<N<&AP+'8@,2XT
M(#(P,#8O,#$O,#8@,#0Z-#<Z,S<@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M,`T*("HO#0HO*BH-"B`J($)A<V4@8VQA<W,-"B`J+PT*<F5Q=6ER95]O;F-E
M("=014%2+U1A<VLO56YI>&5O;"YP:'`G.PT*+RHJ#0H@*B!!8G-T<F%C=',@
M=&AE('5N:7AE;VP@=&%S:R!X;6PN#0H@*B!`8V%T96=O<GD@("!P96%R#0H@
M*B!`<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E
M<B`\8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@
M5&AE(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N
M;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R
M<VEO;B`@("!296QE87-E.B`Q+C0N.0T*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+U!%05(-"B`J($!S:6YC92`@("`@($-L
M87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-"XP83$P#0H@*B\-"F-L
M87-S(%!%05)?5&%S:U]5;FEX96]L7W)W(&5X=&5N9',@4$5!4E]487-K7U5N
M:7AE;VP-"GL-"B`@("!F=6YC=&EO;B!014%27U1A<VM?56YI>&5O;%]R=R@F
M)'!K9RP@)B1C;VYF:6<L("8D;&]G9V5R+"`D9FEL95AM;"D-"B`@("![#0H@
M("`@("`@('!A<F5N=#HZ4$5!4E]487-K7T-O;6UO;B@D8V]N9FEG+"`D;&]G
M9V5R+"!014%27U1!4TM?4$%#2T%'12D[#0H@("`@("`@("1T:&ES+3Y?8V]N
M=&5N=',@/2`D9FEL95AM;#L-"B`@("`@("`@)'1H:7,M/E]P:V<@/2`F)'!K
M9SL-"B`@("`@("`@)'1H:7,M/E]P87)A;7,@/2!A<G)A>2@I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N('9A;&ED871E*"D-"B`@("![#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=$YA;64H*0T*
M("`@('L-"B`@("`@("`@<F5T=7)N("=U;FEX96]L)SL-"B`@("!]#0H-"B`@
M("!F=6YC=&EO;B!G9718;6PH*0T*("`@('L-"B`@("`@("`@<F5T=7)N("<G
M.PT*("`@('T-"GT-"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$5!4B]$
M;W=N;&]A9&5R+U!A8VMA9V4N<&AP````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#(Q-#$V-2`Q,#4Q-30S-#$S-"`P,C,S-C0`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`-"B\J*@T*("H@4$5!
M4E]$;W=N;&]A9&5R7U!A8VMA9V4-"B`J#0H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0T*("H-"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4-"B`J('1H
M870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M('1H92!F;VQL;W=I;F<@55)).@T*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F#0H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E#0H@*B!S96YD(&$@;F]T
M92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P
M>2!I;6UE9&EA=&5L>2X-"B`J#0H@*B!`8V%T96=O<GD@("!P96%R#0H@*B!`
M<&%C:V%G92`@("!014%2#0H@*B!`875T:&]R("`@("!'<F5G($)E879E<B`\
M8V5L;&]G0'!H<"YN970^#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#8@5&AE
M(%!(4"!'<F]U<`T*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@4&%C:V%G92YP:'`L=B`Q+CDQ(#(P,#8O,#$O,C,@
M,3DZ,#4Z-3(@8V5L;&]G($5X<"`D#0H@*B!`;&EN:R`@("`@("!H='1P.B\O
M<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$5!4@T*("H@0'-I;F-E("`@("`@1FEL
M92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q#0H@*B\-"B\J*@T*
M("H@17)R;W(@8V]D92!W:&5N('!A<F%M971E<B!I;FET:6%L:7IA=&EO;B!F
M86EL<R!B96-A=7-E(&YO(')E;&5A<V5S#0H@*B!E>&ES="!W:71H:6X@<')E
M9F5R<F5D7W-T871E+"!B=70@<F5L96%S97,@9&\@97AI<W0-"B`J+PT*9&5F
M:6YE*"=014%27T1/5TY,3T%$15)?4$%#2T%'15]35$%412<L("TQ,#`S*3L-
M"B\J*@T*("H@0V]O<F1I;F%T97,@9&]W;FQO860@<&%R86UE=&5R<R!A;F0@
M;6%N86=E<R!T:&5I<B!D97!E;F1E;F-I97,-"B`J('!R:6]R('1O(&1O=VYL
M;V%D:6YG('1H96TN#0H@*@T*("H@26YP=70@8V%N(&-O;64@9G)O;2!T:')E
M92!S;W5R8V5S.@T*("H-"B`J("T@;&]C86P@9FEL97,@*&%R8VAI=F5S(&]R
M('!A8VMA9V4N>&UL*0T*("H@+2!R96UO=&4@9FEL97,@*&1O=VYL;V%D86)L
M92!U<FQS*0T*("H@+2!A8G-T<F%C="!P86-K86=E(&YA;65S#0H@*@T*("H@
M5&AE(&9I<G-T('1W;R!E;&5M96YT<R!A<F4@:&%N9&QE9"!C;&5A;FQY(&)Y
M(%!%05)?4&%C:V%G949I;&4L(&)U="!T:&4@=&AI<F0@<F5Q=6ER97,-"B`J
M(&%C8V5S<VEN9R!P96%R=V5B)W,@>&UL+7)P8R!I;G1E<F9A8V4@=&\@9&5T
M97)M:6YE(&YE8V5S<V%R>2!D97!E;F1E;F-I97,L(&%N9"!T:&4-"B`J(&9O
M<FUA="!R971U<FYE9"!O9B!D97!E;F1E;F-I97,@:7,@<VQI9VAT;'D@9&EF
M9F5R96YT(&9R;VT@=&AA="!U<V5D(&EN('!A8VMA9V4N>&UL+@T*("H-"B`J
M(%1H:7,@8VQA<W,@:&ED97,@=&AE(&1I9F9E<F5N8V5S(&)E='=E96X@=&AE
M<V4@96QE;65N=',L(&%N9"!M86ME<R!A=71O;6%T:6,-"B`J(&1E<&5N9&5N
M8WD@<F5S;VQU=&EO;B!A('!I96-E(&]F(&-A:V4N("!)="!A;'-O(&UA;F%G
M97,@8V]N9FQI8W1S('=H96X-"B`J('1W;R!C;&%S<V5S(&1E<&5N9"!O;B!I
M;F-O;7!A=&EB;&4@9&5P96YD96YC:65S+"!O<B!D:69F97)I;F<@=F5R<VEO
M;G,@;V8@=&AE('-A;64-"B`J('!A8VMA9V4@9&5P96YD96YC>2X@($EN(&%D
M9&ET:6]N+"!D;W=N;&]A9"!W:6QL(&YO="!B92!A='1E;7!T960@:68@=&AE
M('!H<"!V97)S:6]N(&ES#0H@*B!N;W0@<W5P<&]R=&5D+"!014%2(&EN<W1A
M;&QE<B!V97)S:6]N(&ES(&YO="!S=7!P;W)T960L(&]R(&YO;BU014-,(&5X
M=&5N<VEO;G,@87)E(&YO=`T*("H@:6YS=&%L;&5D+@T*("H@0&-A=&5G;W)Y
M("`@<&5A<@T*("H@0'!A8VMA9V4@("`@4$5!4@T*("H@0&%U=&AO<B`@("`@
M1W)E9R!"96%V97(@/&-E;&QO9T!P:'`N;F5T/@T*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`V(%1H92!02%`@1W)O=7`-"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`T*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+CD-"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]014%2#0H@*B!`<VEN
M8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0N,&$Q
M#0H@*B\-"F-L87-S(%!%05)?1&]W;FQO861E<E]086-K86=E#0I[#0H@("`@
M+RHJ#0H@("`@("H@0'9A<B!014%27T1O=VYL;V%D97(-"B`@("`@*B\-"B`@
M("!V87(@)%]D;W=N;&]A9&5R.PT*("`@("\J*@T*("`@("`J($!V87(@4$5!
M4E]#;VYF:6<-"B`@("`@*B\-"B`@("!V87(@)%]C;VYF:6<[#0H@("`@+RHJ
M#0H@("`@("H@0'9A<B!014%27U)E9VES=')Y#0H@("`@("HO#0H@("`@=F%R
M("1?<F5G:7-T<GD[#0H@("`@+RHJ#0H@("`@("H@57-E9"!T;R!I;7!L96UE
M;G0@<&%C:V%G:6YG<F]O="!P<F]P97)L>0T*("`@("`J($!V87(@4$5!4E]2
M96=I<W1R>0T*("`@("`J+PT*("`@('9A<B`D7VEN<W1A;&Q296=I<W1R>3L-
M"B`@("`O*BH-"B`@("`@*B!`=F%R(%!%05)?4&%C:V%G949I;&5?=C%\4$5!
M4E]086-K86=E1FEL97QV,@T*("`@("`J+PT*("`@('9A<B`D7W!A8VMA9V5F
M:6QE.PT*("`@("\J*@T*("`@("`J($!V87(@87)R87D-"B`@("`@*B\-"B`@
M("!V87(@)%]P87)S961N86UE.PT*("`@("\J*@T*("`@("`J($!V87(@87)R
M87D-"B`@("`@*B\-"B`@("!V87(@)%]D;W=N;&]A9%523#L-"B`@("`O*BH-
M"B`@("`@*B!`=F%R(&%R<F%Y#0H@("`@("HO#0H@("`@=F%R("1?9&]W;FQO
M861$97!S(#T@87)R87DH*3L-"B`@("`O*BH-"B`@("`@*B!`=F%R(&)O;VQE
M86X-"B`@("`@*B\-"B`@("!V87(@)%]V86QI9"`](&9A;'-E.PT*("`@("\J
M*@T*("`@("`J($!V87(@8F]O;&5A;@T*("`@("`J+PT*("`@('9A<B`D7V%N
M86QY>F5D(#T@9F%L<V4[#0H@("`@+RHJ#0H@("`@("H@:68@=&AI<R!O<B!A
M('!A<F5N="!P86-K86=E('=A<R!I;G9O:V5D('=I=&@@4&%C:V%G92US=&%T
M92P@=&AI<R!I<R!S970@=&\@=&AE#0H@("`@("H@<W1A=&4@=F%R:6%B;&4N
M#0H@("`@("H-"B`@("`@*B!4:&ES(&%L;&]W<R!T96UP;W)A<GD@<F5A<W-I
M9VYM96YT(&]F('!R969E<G)E9%]S=&%T92!F;W(@82!P87)E;G0@<&%C:V%G
M92!A;F0@86QL(&]F#0H@("`@("H@:71S(&1E<&5N9&5N8VEE<RX-"B`@("`@
M*B!`=F%R('-T<FEN9WQF86QS90T*("`@("`J+PT*("`@('9A<B`D7V5X<&QI
M8VET4W1A=&4@/2!F86QS93L-"B`@("`O*BH-"B`@("`@*B!)9B!T:&ES('!A
M8VMA9V4@:7,@:6YV;VME9"!W:71H(%!A8VMA9V4C9W)O=7`L('1H:7,@=F%R
M:6%B;&4@=VEL;"!B92!T<G5E#0H@("`@("HO#0H@("`@=F%R("1?97AP;&EC
M:71'<F]U<"`](&9A;'-E.PT*("`@("\J*@T*("`@("`J(%!A8VMA9V4@='EP
M92!L;V-A;'QU<FQ\>&UL<G!C#0H@("`@("H@0'9A<B!S=')I;F<-"B`@("`@
M*B\-"B`@("!V87(@)%]T>7!E.PT*("`@("\J*@T*("`@("`J($-O;G1E;G1S
M(&]F('!A8VMA9V4N>&UL+"!I9B!D;W=N;&]A9&5D(&9R;VT@82!R96UO=&4@
M8VAA;FYE;`T*("`@("`J($!V87(@<W1R:6YG?&9A;'-E#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?<F%W<&%C:V%G969I
M;&4[#0H@("`@+RHJ#0H@("`@("H@0'9A<B!B;V]L96%N#0H@("`@("H@0&%C
M8V5S<R!P<FEV871E#0H@("`@("HO#0H@("`@=F%R("1?=F%L:61A=&5D(#T@
M9F%L<V4[#0H-"B`@("`O*BH-"B`@("`@*B!`<&%R86T@4$5!4E]$;W=N;&]A
M9&5R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@4$5!4E]$;W=N;&]A9&5R7U!A
M8VMA9V4H)B1D;W=N;&]A9&5R*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D
M;W=N;&]A9&5R(#T@)B1D;W=N;&]A9&5R.PT*("`@("`@("`D=&AI<RT^7V-O
M;F9I9R`]("8D=&AI<RT^7V1O=VYL;V%D97(M/F-O;F9I9SL-"B`@("`@("`@
M)'1H:7,M/E]R96=I<W1R>2`]("8D=&AI<RT^7V-O;F9I9RT^9V5T4F5G:7-T
M<GDH*3L-"B`@("`@("`@)&]P=&EO;G,@/2`D9&]W;FQO861E<BT^9V5T3W!T
M:6]N<R@I.PT*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W!A8VMA9VEN
M9W)O;W0G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?8V]N9FEG+3YS971)
M;G-T86QL4F]O="@D;W!T:6]N<ULG<&%C:V%G:6YG<F]O="==*3L-"B`@("`@
M("`@("`@("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y(#T@)B1T:&ES+3Y?8V]N
M9FEG+3YG971296=I<W1R>2@I.PT*("`@("`@("`@("`@)'1H:7,M/E]C;VYF
M:6<M/G-E=$EN<W1A;&Q2;V]T*&9A;'-E*3L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y(#T@)B1T:&ES
M+3Y?<F5G:7-T<GD[#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]V86QI
M9"`]("1T:&ES+3Y?86YA;'EZ960@/2!F86QS93L-"B`@("!]#0H-"B`@("`O
M*BH-"B`@("`@*B!087)S92!T:&4@:6YP=70@86YD(&1E=&5R;6EN92!W:&5T
M:&5R('1H:7,@:7,@82!L;V-A;"!F:6QE+"!A(')E;6]T92!U<FDL(&]R(&%N
M#0H@("`@("H@86)S=')A8W0@<&%C:V%G92!N86UE+@T*("`@("`J#0H@("`@
M("H@5&AI<R!I<R!T:&4@:&5A<G0@;V8@=&AE(%!%05)?1&]W;FQO861E<E]0
M86-K86=E*"DL(&%N9"!I<R!U<V5D(&EN#0H@("`@("H@>T!L:6YK(%!%05)?
M1&]W;FQO861E<CHZ9&]W;FQO860H*7T-"B`@("`@*B!`<&%R86T@<W1R:6YG
M#0H@("`@("H@0')E='5R;B!B;V]L?%!%05)?17)R;W(-"B`@("`@*B\-"B`@
M("!F=6YC=&EO;B!I;FET:6%L:7IE*"1P87)A;2D-"B`@("![#0H@("`@("`@
M("1O<FEG17)R(#T@)'1H:7,M/E]F<F]M1FEL92@D<&%R86TI.PT*("`@("`@
M("!I9B`H(21T:&ES+3Y?=F%L:60I('L-"B`@("`@("`@("`@("1O<'1I;VYS
M(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[#0H@("`@("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V]F9FQI;F4G72DI('L-"B`@("`@
M("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D;W)I9T5R<BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YL;V<H,"P@)&]R:6=%<G(M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-A;FYO="!D;W=N;&]A
M9"!N;VXM;&]C86P@<&%C:V%G92`B)R`N("1P87)A;2`N("<B)RD[#0H@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`D97)R(#T@)'1H:7,M/E]F<F]M57)L
M*"1P87)A;2D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R
M*2!\?"`A)'1H:7,M/E]V86QI9"D@>PT*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^7W1Y<&4@/3T@)W5R;"<I('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)&5R<BDI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO
M9R@P+"`D97)R+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"));G9A;&ED(&]R(&UI
M<W-I;F<@<F5M;W1E('!A8VMA9V4@9FEL92(I.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`D97)R(#T@)'1H:7,M/E]F<F]M4W1R:6YG
M*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&5R<BD@?'P@(21T:&ES+3Y?=F%L:60I('L-"B`@("`@("`@("`@("`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)&5R<BD@)B8-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&5R<BT^9V5T0V]D92@I(#T](%!%05)?1$]73DQ/041%
M4E]004-+04=%7U-4051%*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4[("\O(&EN<W1R=6-T('1H92!D;W=N;&]A9&5R('1O('-I
M;&5N=&QY('-K:7`-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T>7!E*2`F)B`D=&AI<RT^
M7W1Y<&4@/3T@)VQO8V%L)R`F)@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("!014%2.CII<T5R<F]R*"1O<FEG17)R*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1O<FEG17)R+3YG9715<V5R26YF;R@I
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1O
M<FEG17)R+3YG9715<V5R26YF;R@I(&%S("1E<G(I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1E<G(I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R(#T@)&5R
M<ELG;65S<V%G92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1E
M<G(I.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1O<FEG17)R+3YG971-
M97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86T@/2`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P87)A;2P-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=')U92D[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!R
M971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`B0V%N;F]T(&EN:71I86QI>F4@)R1P87)A;2<L(&EN=F%L:60@
M;W(@;6ES<VEN9R!P86-K86=E(&9I;&4B*3L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1E<G(M/F=E=$UE<W-A
M9V4H*2D[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y
M*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;2`]
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M)'!A<F%M+"!T<G5E*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@-"B`@("`@
M("`@("`@("`@("`@("`@("`@(")#86YN;W0@:6YI=&EA;&EZ92`G)'!A<F%M
M)RP@:6YV86QI9"!O<B!M:7-S:6YG('!A8VMA9V4@9FEL92(I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!2971R
M:65V92!A;GD@;F]N+6QO8V%L('!A8VMA9V5S#0H@("`@("H@0')E='5R;B!0
M14%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C)\4$5!4E]%
M<G)O<@T*("`@("`J+PT*("`@(&9U;F-T:6]N("9D;W=N;&]A9"@I#0H@("`@
M>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL92DI('L-
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE.PT*("`@
M("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),
M6R=U<FPG72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?:7-V86QI9"`](&9A
M;'-E.PT*("`@("`@("`@("`@)&EN9F\@/2`D=&AI<RT^9V5T4&%R<V5D4&%C
M:V%G92@I.PT*("`@("`@("`@("`@9F]R96%C:"`H)&EN9F\@87,@)&D@/3X@
M)'`I('L-"B`@("`@("`@("`@("`@("`D:6YF;ULD:5T@/2!S=')T;VQO=V5R
M*"1P*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1E<G(@/2`D=&AI
M<RT^7V9R;VU5<FPH)'1H:7,M/E]D;W=N;&]A9%523%LG=7)L)UTL#0H@("`@
M("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA
M;654;U-T<FEN9R@D=&AI<RT^7W!A<G-E9&YA;64L('1R=64I*3L-"B`@("`@
M("`@("`@("1N97=I;F9O(#T@)'1H:7,M/F=E=%!A<G-E9%!A8VMA9V4H*3L-
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1N97=I;F9O(&%S("1I(#T^("1P*2![
M#0H@("`@("`@("`@("`@("`@)&YE=VEN9F];)&E=(#T@<W1R=&]L;W=E<B@D
M<"D[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&EN9F\@(3T@
M)&YE=VEN9F\I('L-"B`@("`@("`@("`@("`@("!D;R![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D:6YF;ULG<&%C:V%G92==(#T]("=P96-L+G!H<"YN
M970G("8F("1N97=I;F9O6R=P86-K86=E)UT@/3T@)W!E87(N<&AP+FYE="<I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1I;F9O6R=P86-K86=E)UT@
M/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D:6YF;R`]/2`D;F5W:6YF;RD@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O('-K:7`@=&AE(&-H86YN96P@8VAE8VL@:68@82!P96-L('!A
M8VMA9V4@<V%Y<R!I="=S(&$@4$5!4B!P86-K86=E#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)T-2251)0T%,($524D]2.B!7
M92!A<F4@)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1I;F9O*2`N("<L
M(&)U="!T:&4@9FEL92`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("=D
M;W=N;&]A9&5D(&-L86EM<R!T;R!B92`G("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3
M=')I;F<H)'1H:7,M/F=E=%!A<G-E9%!A8VMA9V4H*2DI.PT*("`@("`@("`@
M("`@("`@('T@=VAI;&4@*&9A;'-E*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(&EF("A014%2.CII<T5R<F]R*"1E<G(I('Q\("$D=&AI<RT^7W9A
M;&ED*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@
M("`@("!]#0H@("`@("`@('T-"B`@("`@("`@)'1H:7,M/E]T>7!E(#T@)VQO
M8V%L)SL-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4[#0H@
M("`@?0T*#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5&:6QE*"D-"B`@("![
M#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N("9G971$;W=N;&]A9&5R*"D-"B`@("![#0H@("`@
M("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D97([#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T5'EP92@I(`T*("`@('L-"B`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?='EP93L-"B`@("!]#0H-"B`@("`O*BH-"B`@("`@*B!,:6ME('M`
M;&EN:R!I;FET:6%L:7IE*"E]+"!B=70@;W!E<F%T97,@;VX@82!D97!E;F1E
M;F-Y#0H@("`@("HO#0H@("`@9G5N8W1I;VX@9G)O;41E<%523"@D9&5P*0T*
M("`@('L-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A9%523"`]("1D97`[#0H@
M("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@("`@("`@("`@
M("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS*"D[
M#0H@("`@("`@("`@("!I9B`H(65X=&5N<VEO;E]L;V%D960H(GIL:6(B*2!\
M?"!I<W-E="@D;W!T:6]N<ULG;F]C;VUP<F5S<R==*2D@>PT*("`@("`@("`@
M("`@("`@("1E>'0@/2`G+G1A<B<[#0H@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("1E>'0@/2`G+G1G>B<[#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T52
M4D]27U)%5%523BD[#0H@("`@("`@("`@("`D97)R(#T@)'1H:7,M/E]F<F]M
M57)L*"1D97!;)W5R:2==("X@)&5X="D[#0H@("`@("`@("`@("!014%2.CIP
M;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D97)R*2D@>PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5R+3YL;V<H,"P@)&5R<BT^9V5T365S<V%G92@I*3L-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)TEN=F%L:60@=7)I(&1E<&5N9&5N8WD@(B<@+B`D9&5P
M6R=U<FDG72`N("1E>'0@+B`G(BP@)R`N#0H@("`@("`@("`@("`@("`@("`@
M("=C86YN;W0@9&]W;FQO860G*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5D;F%M92`]#0H@
M("`@("`@("`@("`@("`@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=P
M86-K86=E)R`]/B`D9&5P6R=I;F9O)UTM/F=E=%!A8VMA9V4H*2P-"B`@("`@
M("`@("`@("`@("`@("`@)V-H86YN96PG(#T^("1D97!;)VEN9F\G72T^9V5T
M0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@
M)&1E<%LG=F5R<VEO;B==#0H@("`@("`@("`@("`@("`@*3L-"B`@("`@("`@
M("`@(&EF("@A:7-S970H)&1E<%LG;F]D969A=6QT)UTI*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]P87)S961N86UE6R=G<F]U<"==(#T@)V1E9F%U
M;'0G.R`O+R!D;W=N;&]A9"!T:&4@9&5F875L="!D97!E;F1E;F-Y(&=R;W5P
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E>'!L:6-I=$=R;W5P(#T@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7W)A=W!A
M8VMA9V5F:6QE(#T@)&1E<%LG<F%W)UT[#0H@("`@("`@('T-"B`@("!]#0H-
M"B`@("!F=6YC=&EO;B!D971E8W1$97!E;F1E;F-I97,H)'!A<F%M<RD-"B`@
M("![#0H@("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG
M971/<'1I;VYS*"D[#0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG9&]W
M;FQO861O;FQY)UTI*2![#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@
M('T-"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=O9F9L:6YE)UTI*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@S+"`G4VMI
M<'!I;F<@9&5P96YD96YC>2!D;W=N;&]A9"!C:&5C:RP@+2UO9F9L:6YE('-P
M96-I9FEE9"<I.PT*("`@("`@("`@("`@<F5T=7)N.PT*("`@("`@("!]#0H@
M("`@("`@("1P;F%M92`]("1T:&ES+3YG971087)S961086-K86=E*"D[#0H@
M("`@("`@(&EF("@A)'!N86UE*2![#0H@("`@("`@("`@("!R971U<FX[#0H@
M("`@("`@('T-"B`@("`@("`@)&1E<',@/2`D=&AI<RT^9V5T1&5P<R@I.PT*
M("`@("`@("!I9B`H(21D97!S*2![#0H@("`@("`@("`@("!R971U<FX[#0H@
M("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==
M*2D@>R`O+R!P86-K86=E+GAM;"`R+C`-"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1E=&5C=#(H)&1E<',L("1P;F%M92P@)&]P=&EO;G,L("1P87)A
M;7,I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?9&5T96-T,2@D9&5P<RP@)'!N86UE+"`D;W!T:6]N<RP@)'!A<F%M
M<RD[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!S971686QI
M9&%T960H*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]V86QI9&%T960@/2!T
M<G5E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&%L<F5A9'E686QI9&%T960H
M*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:61A=&5D.PT*
M("`@('T-"@T*("`@("\J*@T*("`@("`J(%)E;6]V92!P86-K86=E<R!T;R!B
M92!D;W=N;&]A9&5D('1H870@87)E(&%L<F5A9'D@:6YS=&%L;&5D#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(&]F(%!%05)?1&]W;FQO861E<E]086-K86=E(&]B
M:F5C=',-"B`@("`@*B!`<W1A=&EC#0H@("`@("HO#0H@("`@9G5N8W1I;VX@
M<F5M;W9E26YS=&%L;&5D*"8D<&%R86US*0T*("`@('L-"B`@("`@("`@:68@
M*"%I<W-E="@D<&%R86US6S!=*2D@>PT*("`@("`@("`@("`@<F5T=7)N.PT*
M("`@("`@("!]#0H@("`@("`@("1O<'1I;VYS(#T@)'!A<F%M<ULP72T^7V1O
M=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI*2![#0H@("`@("`@("`@("!F;W)E
M86-H("@D<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*("`@("`@("`@("`@
M("`@("\O(')E;6]V92!S96QF(&EF(&%L<F5A9'D@:6YS=&%L;&5D('=I=&@@
M=&AI<R!V97)S:6]N#0H@("`@("`@("`@("`@("`@+R\@=&AI<R!D;V5S(&YO
M="!N965D(&%N>2!P96-L(&UA9VEC("T@=V4@;VYL>2!R96UO=F4@97AA8W0@
M;6%T8VAE<PT*("`@("`@("`@("`@("`@(&EF("@D<&%R86TM/E]I;G-T86QL
M4F5G:7-T<GDM/G!A8VMA9V5%>&ES=',H)'!A<F%M+3YG971086-K86=E*"DL
M("1P87)A;2T^9V5T0VAA;FYE;"@I*2D@>PT*("`@("`@("`@("`@("`@("`@
M("!I9B`H=F5R<VEO;E]C;VUP87)E*"1P87)A;2T^7VEN<W1A;&Q296=I<W1R
M>2T^<&%C:V%G94EN9F\H)'!A<F%M+3YG971086-K86=E*"DL("=V97)S:6]N
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3YG971#:&%N
M;F5L*"DI+"`D<&%R86TM/F=E=%9E<G-I;VXH*2P@)ST])RDI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)V9O<F-E
M)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&EN9F\@/2`D
M<&%R86TM/F=E=%!A<G-E9%!A8VMA9V4H*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D:6YF;ULG=F5R<VEO;B==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D:6YF;ULG<W1A=&4G72D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N
M<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%R86TM/E]D;W=N;&]A9&5R+3YL;V<H,2P@)U-K:7!P:6YG('!A8VMA
M9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M+3YG9713:&]R=$YA;64H*2`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G(BP@86QR96%D>2!I;G-T86QL960@87,@=F5R
M<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;2T^7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)'!A<F%M
M+3YG971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W9E<G-I;VXG+"`D<&%R86TM/F=E=$-H86YN96PH*2DI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A;'-E.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H(6ES<V5T*"1O<'1I;VYS6R=F;W)C92==*2`F)B`A:7-S970H)&]P
M=&EO;G-;)W5P9W)A9&4G72D@)B8-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D:6YF;R`]("1P87)A;2T^9V5T4&%R<V5D4&%C:V%G92@I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M+3Y?9&]W;FQO861E
M<BT^;&]G*#$L("=3:VEP<&EN9R!P86-K86=E("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&%R86TM/F=E=%-H;W)T3F%M92@I("X-"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G(BP@86QR96%D>2!I;G-T86QL
M960@87,@=F5R<VEO;B`G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&%R86TM/E]I;G-T86QL4F5G:7-T<GDM/G!A8VMA9V5);F9O*"1P87)A
M;2T^9V5T4&%C:V%G92@I+"`G=F5R<VEO;B<L#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;2T^9V5T0VAA;FYE;"@I*2D[#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<&%R86US6R1I72`](&9A;'-E.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(%!%05)?1&]W;FQO861E<E]0
M86-K86=E.CIR96UO=F5$=7!L:6-A=&5S*"1P87)A;7,I.PT*("`@('T-"@T*
M("`@(&9U;F-T:6]N(%]D971E8W0R*"1D97!S+"`D<&YA;64L("1O<'1I;VYS
M+"`D<&%R86US*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]D;W=N;&]A9$1E
M<',@/2!A<G)A>2@I.PT*("`@("`@("`D9W)O=7!N;W1F;W5N9"`](&9A;'-E
M.PT*("`@("`@("!F;W)E86-H("AA<G)A>2@G<&%C:V%G92<L("=S=6)P86-K
M86=E)RD@87,@)'!A8VMA9V5T>7!E*2![#0H@("`@("`@("`@("`O+R!G970@
M<F5Q=6ER960@9&5P96YD96YC>2!G<F]U<`T*("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=R97%U:7)E9"==6R1P86-K86=E='EP95TI*2![#0H@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1D97!S6R=R97%U:7)E9"==6R1P86-K
M86=E='EP95U;,%TI*2![#0H@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1D97!S6R=R97%U:7)E9"==6R1P86-K86=E='EP95T@87,@)&1E<"D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;)V-O;F9L
M:6-T<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('-K
M:7`@86YY('!A8VMA9V4@=&AA="!T:&ES('!A8VMA9V4@8V]N9FQI8W1S('=I
M=&@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1R970@/2`D=&AI<RT^7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE+"`G
M<F5Q=6ER960G+"`D<&%R86US*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T.PT*("`@("`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@
M)&1E<"`]("1D97!S6R=R97%U:7)E9"==6R1P86-K86=E='EP95T[#0H@("`@
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&1E<%LG8V]N9FQI8W1S)UTI
M*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`O+R!S:VEP(&%N>2!P86-K
M86=E('1H870@=&AI<R!P86-K86=E(&-O;F9L:6-T<R!W:71H#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/E]D971E8W0R1&5P*"1D
M97`L("1P;F%M92P@)W)E<75I<F5D)RP@)'!A<F%M<RD[#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E="DI('L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P<UM=(#T@
M)')E=#L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("\O(&=E="!O<'1I;VYA;"!D97!E;F1E;F-Y(&=R;W5P
M+"!I9B!A;GD-"B`@("`@("`@("`@(&EF("AI<W-E="@D9&5P<ULG;W!T:6]N
M86PG75LD<&%C:V%G971Y<&5=*2D@>PT*("`@("`@("`@("`@("`@("1S:VEP
M;F%M97,@/2!A<G)A>2@I.PT*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&1E<'-;)V]P=&EO;F%L)UU;)'!A8VMA9V5T>7!E75LP72DI('L-"B`@("`@
M("`@("`@("`@("`@("`@)&1E<'-;)V]P=&EO;F%L)UU;)'!A8VMA9V5T>7!E
M72`](&%R<F%Y*"1D97!S6R=O<'1I;VYA;"==6R1P86-K86=E='EP95TI.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!F;W)E86-H("@D
M9&5P<ULG;W!T:6]N86PG75LD<&%C:V%G971Y<&5=(&%S("1D97`I('L-"B`@
M("`@("`@("`@("`@("`@("`@)'-K:7`@/2!F86QS93L-"B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG86QL9&5P<R==*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG<&%C:V%G92==(#T@)&1E
M<%LG;F%M92==.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#,L("=.;W1I8V4Z('!A
M8VMA9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@D=&AI
M<RT^9V5T4&%R<V5D4&%C:V%G92@I+`T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@=')U92D@+B`G(B!O<'1I;VYA;"!D97!E;F1E;F-Y
M("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9RAA<G)A>2@G
M<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!;)VYA;64G72P@)V-H86YN96PG(#T^("=P96%R+G!H<"YN970G
M*2P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M(B!W:6QL(&YO="!B92!A=71O;6%T:6-A;&QY(&1O=VYL;V%D960G*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1S:VEP;F%M97-;72`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A
M8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D[#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D<VMI<"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D9&5P6R=P86-K86=E)UTI.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A*"1R970@/2`D=&AI
M<RT^7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE+"`G;W!T:6]N86PG+"`D<&%R
M86US*2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1D97!;)W!A8VMA
M9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("A`)'-K:7!N86UE<UMC;W5N="@D<VMI<&YA;65S*2`M(#%=(#T]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y
M+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S:VEP;F%M
M97,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A)'-K:7`@)B8@
M:7-?87)R87DH)')E="DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861$97!S6UT@/2`D<F5T.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF
M("AC;W5N="@D<VMI<&YA;65S*2D@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@Q+"`G1&ED(&YO
M="!D;W=N;&]A9"!O<'1I;VYA;"!D97!E;F1E;F-I97,Z("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H)RP@)RP@)'-K:7!N86UE
M<RD@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<L('5S92`M+6%L
M;&1E<',@=&\@9&]W;FQO860@875T;VUA=&EC86QL>2<I.PT*("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@+R\@9V5T(')E<75E<W1E9"!D97!E;F1E;F-Y(&=R
M;W5P+"!I9B!A;GD-"B`@("`@("`@("`@("1G<F]U<&YA;64@/2`D=&AI<RT^
M9V5T1W)O=7`H*3L-"B`@("`@("`@("`@("1E>'!L:6-I="`]("1T:&ES+3Y?
M97AP;&EC:71'<F]U<#L-"B`@("`@("`@("`@(&EF("@A)&=R;W5P;F%M92D@
M>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^8V%N1&5F875L="@I*2![
M#0H@("`@("`@("`@("`@("`@("`@("1G<F]U<&YA;64@/2`G9&5F875L="<[
M("\O('1R>2!T:&4@9&5F875L="!D97!E;F1E;F-Y(&=R;W5P#0H@("`@("`@
M("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@:68@*"1G<F]U<&YO=&9O=6YD*2![#0H@("`@("`@("`@("`@("`@
M8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<'-;)V=R;W5P)UTI*2![#0H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1D97!S6R=G<F]U<"==6R=A='1R:6)S)UTI*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("AS=')T;VQO=V5R*"1D97!S6R=G<F]U<"==6R=A='1R
M:6)S)UU;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D9W)O=7!N86UE*2D@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)&=R;W5P(#T@)&1E<'-;)V=R;W5P
M)UT[#0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D97AP;&EC:70I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO
M;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P+"`G5V%R;FEN9SH@<&%C:V%G92`B
M)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!N86UE+"!T
M<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<B(&AA
M<R!N;R!D97!E;F1E;F-Y("<@+B`G9W)O=7`@;F%M960@(B<@+B`D9W)O=7!N
M86UE("X@)R(G*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("`@("`@("`@("1G<F]U<&YO=&9O=6YD(#T@=')U93L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1D97!S6R=G<F]U<"==(&%S("1G<F]U<"D@>PT*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)&=R;W5P6R=A
M='1R:6)S)UU;)VYA;64G72D@/3T@<W1R=&]L;W=E<B@D9W)O=7!N86UE*2D@
M>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W5N9"`]('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"$D9F]U;F0I('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D97AP;&EC:70I('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W
M;FQO861E<BT^;&]G*#`L("=787)N:6YG.B!P86-K86=E("(G("X-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T
M<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)'!N86UE+"!T<G5E*2`N
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(B!H87,@
M;F\@9&5P96YD96YC>2`G("X@)V=R;W5P(&YA;65D("(G("X@)&=R;W5P;F%M
M92`N("<B)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@
M("`@)&=R;W5P;F]T9F]U;F0@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H
M:7-S970H)&=R;W5P*2D@>PT*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D
M9W)O=7!;)'!A8VMA9V5T>7!E72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1G<F]U<%LD<&%C:V%G971Y<&5=6S!=*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&=R;W5P6R1P86-K86=E='EP
M95T@87,@)&1E<"D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M970@/2`D=&AI<RT^7V1E=&5C=#)$97`H)&1E<"P@)'!N86UE+"`G9&5P96YD
M96YC>2!G<F]U<"`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G(B<L("1P87)A;7,I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D
M<F5T*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1O=VYL;V%D1&5P<UM=(#T@)')E=#L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D<F5T(#T@)'1H:7,M/E]D971E8W0R1&5P*"1G<F]U<%LD<&%C:V%G
M971Y<&5=+"`D<&YA;64L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V1E<&5N9&5N8WD@9W)O=7`@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1G<F]U<%LG871T<FEB<R==6R=N86UE)UT@+B`G(B<L("1P87)A
M;7,I.PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1R
M970I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M;W=N;&]A9$1E<'-;72`]("1R970[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC
M=&EO;B!?9&5T96-T,D1E<"@D9&5P+"`D<&YA;64L("1G<F]U<"P@)'!A<F%M
M<RD-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=C;VYF;&EC=',G
M72DI('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@("!]#0H@
M("`@("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I
M;VYS*"D[#0H@("`@("`@(&EF("AI<W-E="@D9&5P6R=U<FDG72DI('L-"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@G=7)I)R`]/B`D9&5P6R=U<FDG72P@
M)V1E<"<@/3X@)&1E<"D[.PT*("`@("`@("!]#0H@("`@("`@("1T97-T9&5P
M(#T@)&1E<#L-"B`@("`@("`@)'1E<W1D97!;)W!A8VMA9V4G72`]("1D97!;
M)VYA;64G73L-"B`@("`@("`@:68@*%!%05)?1&]W;FQO861E<E]086-K86=E
M.CIW:6QL1&]W;FQO860H)'1E<W1D97`L("1P87)A;7,I*2![#0H@("`@("`@
M("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[#0H@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@
M("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,BP@)'1H:7,M/F=E
M=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N("1G<F]U<"`N#0H@("`@
M("`@("`@("`@("`@("`@("<@9&5P96YD96YC>2`B)R`N#0H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)&1E<"P@=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`G
M(BP@=VEL;"!B92!I;G-T86QL960G*3L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@("`@("`D;W!T
M:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T3W!T:6]N<R@I.PT*("`@
M("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%52
M3BD[#0H@("`@("`@(&EF("@D=&AI<RT^7V5X<&QI8VET4W1A=&4I('L-"B`@
M("`@("`@("`@("1P;F%M95LG<W1A=&4G72`]("1T:&ES+3Y?97AP;&EC:713
M=&%T93L-"B`@("`@("`@?0T*("`@("`@("`D=7)L(#T-"B`@("`@("`@("`@
M("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=$1E<%!A8VMA9V5$;W=N;&]A9%5R
M;"@D9&5P+"`D<&YA;64I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M=7)L*2D@>PT*("`@("`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I
M.PT*("`@("`@("`@("`@<F5T=7)N("1U<FP[#0H@("`@("`@('T-"B`@("`@
M("`@)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`D
M<F5T(#T@)'1H:7,M/E]A;F%L>7IE1&]W;FQO86154DPH)'5R;"P@)V1E<&5N
M9&5N8WDG+"`D9&5P+"`D<&%R86US+"`D9W)O=7`@/3T@)V]P=&EO;F%L)R`F
M)@T*("`@("`@("`@("`@(6ES<V5T*"1O<'1I;VYS6R=A;&QD97!S)UTI*3L-
M"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PT*("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@:68@*"%I
M<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1R970M/F=E=$UE<W-A9V4H*2D[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O+R!C:&5C:R!T;R!S964@
M:68@82!D97`@:7,@86QR96%D>2!I;G-T86QL960@86YD(&ES('1H92!S86UE
M(&]R(&YE=V5R#0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1D97!;)VUI;B==
M*2`F)B`A:7-S970H)&1E<%LG;6%X)UTI("8F("%I<W-E="@D9&5P6R=R96-O
M;6UE;F1E9"==*2D@>PT*("`@("`@("`@("`@("`@("1O<&5R(#T@)VAA<R<[
M#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1O<&5R
M(#T@)V=T)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("\O(&1O(&YO
M="!T<GD@=&\@;6]V92!T:&ES(&)E9F]R92!G971$97!086-K86=E1&]W;FQO
M86154DP-"B`@("`@("`@("`@("\O('=E(&-A;B=T(&1E=&5R;6EN92!W:&5T
M:&5R('5P9W)A9&4@:7,@;F5C97-S87)Y('5N=&EL('=E(&MN;W<@=VAA=`T*
M("`@("`@("`@("`@+R\@=F5R<VEO;B!W;W5L9"!B92!D;W=N;&]A9&5D#0H@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=F;W)C92==*2`F)B`D
M=&AI<RT^:7-);G-T86QL960H)')E="P@)&]P97(I*2![#0H@("`@("`@("`@
M("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7VEN<W1A;&Q296=I<W1R>2T^<&%C
M:V%G94EN9F\H)&1E<%LG;F%M92==+"`G=F5R<VEO;B<L#0H@("`@("`@("`@
M("`@("`@("`@("1D97!;)V-H86YN96PG72D[#0H@("`@("`@("`@("`@("`@
M)&1E<%LG<&%C:V%G92==(#T@)&1E<%LG;F%M92==.PT*("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,RP@)'1H:7,M
M/F=E=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N("1G<F]U<"`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`G(&1E<&5N9&5N8WD@(B<@+@T*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K
M86=E3F%M951O4W1R:6YG*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@
M("`@("`@("`@("<B('9E<G-I;VX@)R`N("1U<FQ;)W9E<G-I;VXG72`N("<L
M(&%L<F5A9'D@:6YS=&%L;&5D(&%S('9E<G-I;VX@)R`N#0H@("`@("`@("`@
M("`@("`@("`@("`@("`D=F5R<VEO;BD[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!I9B`H:7-S970H)&1E<%LG;F]D969A=6QT
M)UTI*2![#0H@("`@("`@("`@("`D<F5T6R=N;V1E9F%U;'0G72`]('1R=64[
M#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1R970[#0H@("`@?0T*#0H@
M("`@9G5N8W1I;VX@7V1E=&5C=#$H)&1E<',L("1P;F%M92P@)&]P=&EO;G,L
M("1P87)A;7,I#0H@("`@>PT*("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P
M<R`](&%R<F%Y*"D[#0H@("`@("`@("1S:VEP;F%M97,@/2!A<G)A>2@I.PT*
M("`@("`@("!F;W)E86-H("@D9&5P<R!A<R`D9&5P*2![#0H@("`@("`@("`@
M("`D;F]D;W=N;&]A9"`](&9A;'-E.PT*("`@("`@("`@("`@:68@*"1D97!;
M)W1Y<&4G72`]/2`G<&MG)RD@>PT*("`@("`@("`@("`@("`@("1D97!;)V-H
M86YN96PG72`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@("`@("1D
M97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-"B`@("`@("`@("`@("`@
M("!S=VET8V@@*"1D97!;)W)E;"==*2![#0H@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)VYO="<@.@T*("`@("`@("`@("`@("`@("`@("`@("`@8V]N=&EN
M=64@,CL-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G9V4G(#H-"B`@("`@
M("`@("`@("`@("`@("`@8V%S92`G97$G(#H-"B`@("`@("`@("`@("`@("`@
M("`@8V%S92`G9W0G(#H-"B`@("`@("`@("`@("`@("`@("`@8V%S92`G:&%S
M)R`Z#0H@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`@/2`H(6ES<V5T
M*"1D97!;)V]P=&EO;F%L)UTI('Q\("1D97!;)V]P=&EO;F%L)UT@/3T@)VYO
M)RD@/PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=R97%U:7)E9"<@
M.@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<'1I;VYA;"<[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H4$5!4E]$;W=N;&]A9&5R7U!A
M8VMA9V4Z.G=I;&Q$;W=N;&]A9"@D9&5P+"`D<&%R86US*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G
M*#(L("1T:&ES+3YG9713:&]R=$YA;64H*2`N("<Z(%-K:7!P:6YG("<@+B`D
M9W)O=7`-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&1E
M<&5N9&5N8WD@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG
M*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R(L('=I;&P@8F4@:6YS=&%L;&5D)RD[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64@,CL-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1F86ME9'`@/2!N97<@
M4$5!4E]086-K86=E1FEL95]V,3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1F86ME9'`M/G-E=%!A8VMA9V4H)&1E<%LG;F%M92==*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("\O('-K:7`@:6YT97)N970@8VAE8VL@:68@=V4@
M87)E(&YO="!U<&=R861I;F<@*&)U9R`C-3@Q,"D-"B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;)W5P9W)A9&4G72D@)B8@
M)'1H:7,M/FES26YS=&%L;&5D*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9A:V5D<"P@)&1E<%LG<F5L)UTI*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,BP@)'1H
M:7,M/F=E=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I;F<@)R`N("1G<F]U<`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@9&5P96YD96YC
M>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@
M=')U92D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(BP@
M:7,@86QR96%D>2!I;G-T86QL960G*3L-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!C;VYT:6YU92`R.PT*("`@("`@("`@("`@("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?97AP;&EC:713=&%T92D@>PT*("`@("`@
M("`@("`@("`@("`@("`D<&YA;65;)W-T871E)UT@/2`D=&AI<RT^7V5X<&QI
M8VET4W1A=&4[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("1U<FP@/0T*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D
M97(M/E]G971$97!086-K86=E1&]W;FQO8615<FPH)&1E<"P@)'!N86UE*3L-
M"B`@("`@("`@("`@("`@("`D8VAA;B`]("=P96%R+G!H<"YN970G.PT*("`@
M("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1U<FPI*2![#0H@("`@
M("`@("`@("`@("`@("`@("\O(&-H96-K('1O('-E92!I9B!T:&ES(&ES(&$@
M<&5C;"!P86-K86=E('1H870@:&%S(&IU;7!E9`T*("`@("`@("`@("`@("`@
M("`@("`O+R!F<F]M('!E87(N<&AP+FYE="!T;R!P96-L+G!H<"YN970@8VAA
M;FYE;`T*("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G
M4$5!4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@
M("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`D;F5W9&5P
M(#T@4$5!4E]$97!E;F1E;F-Y,CHZ;F]R;6%L:7IE1&5P*"1D97`I.PT*("`@
M("`@("`@("`@("`@("`@("`D;F5W9&5P(#T@)&YE=V1E<%LP73L-"B`@("`@
M("`@("`@("`@("`@("`@)&YE=V1E<%LG8VAA;FYE;"==(#T@)W!E8VPN<&AP
M+FYE="<[#0H@("`@("`@("`@("`@("`@("`@("1C:&%N(#T@)W!E8VPN<&AP
M+FYE="<[#0H@("`@("`@("`@("`@("`@("`@("1U<FP@/0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T1&5P4&%C
M:V%G941O=VYL;V%D57)L*"1N97=D97`L("1P;F%M92D[#0H@("`@("`@("`@
M("`@("`@("`@("1O8FH@/2`F)'1H:7,M/E]I;G-T86QL4F5G:7-T<GDM/F=E
M=%!A8VMA9V4H)&1E<%LG;F%M92==*3L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*%!%05(Z.FES17)R;W(H)'5R;"DI('L-"B`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("@D;V)J("$]/2!N=6QL("8F("1T:&ES+3YI<TEN
M<W1A;&QE9"@D;V)J+"`D9&5P6R=R96PG72DI('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9W)O=7`@/2`H(6ES<V5T*"1D97!;)V]P=&EO;F%L
M)UTI('Q\("1D97!;)V]P=&EO;F%L)UT@/3T@)VYO)RD@/PT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#H-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V]P=&EO;F%L)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N
M86UE)UT[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E
M="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@S+"`D=&AI<RT^
M9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)SH@4VMI<'!I;F<@)R`N("1G<F]U<"`N("<@9&5P96YD96YC
M>2`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1D
M97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<B+"!A;')E861Y(&EN<W1A;&QE9"!A<R!V97)S:6]N("<@+B`D;V)J
M+3YG971697)S:6]N*"DI.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H0"1S:VEP;F%M
M97-;8V]U;G0H)'-K:7!N86UE<RD@+2`Q72`]/0T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A
M8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92DI('L-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S:VEP;F%M97,I.PT*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)V]P=&EO;F%L)UTI("8F("1D97!;)V]P=&EO;F%L)UT@
M/3T@)WEE<R<I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,BP@)'1H:7,M/F=E=%-H;W)T3F%M
M92@I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("<Z
M(%-K:7!P:6YG("<@+B`D9W)O=7`-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)R!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92D@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R(L(&YO(')E;&5A<V5S
M(&5X:7-T)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=7)L
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA
M;F1L:6YG*"D[#0H@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N
M<ULG86QL9&5P<R==*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)&1E<%LG;W!T:6]N86PG72D@)B8@)&1E<%LG;W!T:6]N86PG72`]/2`G
M>65S)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D
M;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#,L("=.;W1I8V4Z('!A8VMA
M9V4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^9V5T4VAO<G1.86UE*"D@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G(B!O<'1I;VYA;"!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R
M<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N;F5L)R`]/B`D8VAA;BP@)W!A
M8VMA9V4G(#T^#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&5P6R=N86UE)UTI+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("<B('=I;&P@;F]T(&)E(&%U=&]M871I8V%L;'D@9&]W
M;FQO861E9"<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@("`@("`@("`@("`@)'-K:7!N86UE<UM=(#T@)'1H:7,M/E]R96=I
M<W1R>2T^<&%R<V5D4&%C:V%G94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1C:&%N
M+"`G<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&1E<%LG;F%M92==*2P@=')U92D[#0H@("`@("`@("`@("`@("`@("`@
M("`@("`D;F]D;W=N;&]A9"`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@*"%I
M<W-E="@D;W!T:6]N<ULG86QL9&5P<R==*2`F)B`A:7-S970H)&]P=&EO;G-;
M)V]N;'ER97%D97!S)UTI*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A
M:7-S970H)&1E<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T:6]N86PG72`]
M/2`G;F\G*2![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T
M*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,RP@)TYO=&EC93H@<&%C
M:V%G92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YG9713:&]R=$YA;64H*2`N#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("<B(')E<75I<F5D(&1E<&5N9&5N8WD@(B<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E9VES=')Y+3YP
M87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH)V-H86YN96PG(#T^("1C:&%N+"`G
M<&%C:V%G92<@/3X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D97!;)VYA;64G72DL('1R=64I("X-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R(@=VEL;"!N;W0@8F4@875T;VUA=&EC86QL>2!D
M;W=N;&]A9&5D)RD[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<VMI<&YA;65S6UT@/2`D=&AI<RT^7W)E
M9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)&-H
M86XL("=P86-K86=E)R`]/@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9&5P6R=N86UE)UTI+"!T<G5E*3L-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1N;V1O=VYL;V%D(#T@=')U93L-"B`@("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`O+R!C
M:&5C:R!T;R!S964@:68@82!D97`@:7,@86QR96%D>2!I;G-T86QL960-"B`@
M("`@("`@("`@("`@("`O+R!D;R!N;W0@=')Y('1O(&UO=F4@=&AI<R!B969O
M<F4@9V5T1&5P4&%C:V%G941O=VYL;V%D55),#0H@("`@("`@("`@("`@("`@
M+R\@=V4@8V%N)W0@9&5T97)M:6YE('=H971H97(@=7!G<F%D92!I<R!N96-E
M<W-A<GD@=6YT:6P@=V4@:VYO=R!W:&%T#0H@("`@("`@("`@("`@("`@+R\@
M=F5R<VEO;B!W;W5L9"!B92!D;W=N;&]A9&5D#0H@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG9F]R8V4G72D@)B8@)'1H:7,M/FES26YS
M=&%L;&5D*`T*("`@("`@("`@("`@("`@("`@("`@("`@)'5R;"P@)&1E<%LG
M<F5L)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1G<F]U<"`]("@A:7-S
M970H)&1E<%LG;W!T:6]N86PG72D@?'P@)&1E<%LG;W!T:6]N86PG72`]/2`G
M;F\G*2`_#0H@("`@("`@("`@("`@("`@("`@("`@("`G<F5Q=6ER960G(#H-
M"B`@("`@("`@("`@("`@("`@("`@("`@("=O<'1I;VYA;"<[#0H@("`@("`@
M("`@("`@("`@("`@("1D97!;)W!A8VMA9V4G72`]("1D97!;)VYA;64G73L-
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1N97=D97`I*2![#0H@
M("`@("`@("`@("`@("`@("`@("`@("`D=F5R<VEO;B`]("1T:&ES+3Y?:6YS
M=&%L;%)E9VES=')Y+3YP86-K86=E26YF;R@D;F5W9&5P6R=N86UE)UTL("=V
M97)S:6]N)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W9&5P
M6R=C:&%N;F5L)UTI.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@)'9E<G-I;VX@/2`D=&AI<RT^7VEN
M<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)&1E<%LG;F%M92==+"`G=F5R
M<VEO;B<I.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@("`@("1D97!;)W9E<G-I;VXG72`]("1U<FQ;)W9E<G-I;VXG73L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==
M*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A
M9&5R+3YL;V<H,RP@)'1H:7,M/F=E=%-H;W)T3F%M92@I("X@)SH@4VMI<'!I
M;F<@)R`N("1G<F]U<"`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R!D97!E;F1E;F-Y("(G("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG
M*"1D97`L('1R=64I("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G
M(BP@86QR96%D>2!I;G-T86QL960@87,@=F5R<VEO;B`G("X@)'9E<G-I;VXI
M.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@
M(&EF("A`)'-K:7!N86UE<UMC;W5N="@D<VMI<&YA;65S*2`M(#%=(#T]#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F5G:7-T<GDM/G!A
M<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H)&1E<"P@=')U92DI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!O<"@D<VMI<&YA;65S*3L-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@:68@
M*"1N;V1O=VYL;V%D*2![#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1N97=D97`I*2![#0H@("`@("`@("`@("`@
M("`@("`@("1D97`@/2`D;F5W9&5P.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D9&5P6R=P86-K86=E)UT@/2`D9&5P6R=N86UE)UT[
M#0H@("`@("`@("`@("`@("`@)')E="`]("1T:&ES+3Y?86YA;'EZ941O=VYL
M;V%D55),*"1U<FPL("=D97!E;F1E;F-Y)RP@)&1E<"P@)'!A<F%M<RP-"B`@
M("`@("`@("`@("`@("`@("`@:7-S970H)&1E<%LG;W!T:6]N86PG72D@)B8@
M)&1E<%LG;W!T:6]N86PG72`]/2`G>65S)R`F)@T*("`@("`@("`@("`@("`@
M("`@("`A:7-S970H)&]P=&EO;G-;)V%L;&1E<',G72DI.PT*("`@("`@("`@
M("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PT*("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D97(M/FQO9R@P
M+"`D<F5T+3YG971-97-S86=E*"DI.PT*("`@("`@("`@("`@("`@("`@("!]
M#0H@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V1O=VYL;V%D1&5P<UM=
M(#T@)')E=#L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!I
M9B`H8V]U;G0H)'-K:7!N86UE<RDI('L-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V1O=VYL;V%D97(M/FQO9R@Q+"`G1&ED(&YO="!D;W=N;&]A9"!D97!E
M;F1E;F-I97,Z("<@+@T*("`@("`@("`@("`@("`@("`@("!I;7!L;V1E*"<L
M("<L("1S:VEP;F%M97,I("X-"B`@("`@("`@("`@("`@("`@("`@)RP@=7-E
M("TM86QL9&5P<R!O<B`M+6]N;'ER97%D97!S('1O(&1O=VYL;V%D(&%U=&]M
M871I8V%L;'DG*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-
M"@T*("`@(&9U;F-T:6]N('-E=$1O=VYL;V%D55),*"1P:V<I#0H@("`@>PT*
M("`@("`@("`D=&AI<RT^7V1O=VYL;V%D55),(#T@)'!K9SL-"B`@("!]#0H-
M"B`@("`O*BH-"B`@("`@*B!3970@=&AE('!A8VMA9V4N>&UL(&]B:F5C="!F
M;W(@=&AI<R!D;W=N;&]A9&5D('!A8VMA9V4-"B`@("`@*@T*("`@("`J($!P
M87)A;2!014%27U!A8VMA9V5&:6QE7W8Q?%!%05)?4&%C:V%G949I;&5?=C(@
M)'!K9PT*("`@("`J+PT*("`@(&9U;F-T:6]N('-E=%!A8VMA9V5&:6QE*"8D
M<&MG*0T*("`@('L-"B`@("`@("`@)'1H:7,M/E]P86-K86=E9FEL92`]("8D
M<&MG.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%-H;W)T3F%M92@I#0H@
M("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D
M4&%C:V%G94YA;654;U-T<FEN9RAA<G)A>2@G8VAA;FYE;"<@/3X@)'1H:7,M
M/F=E=$-H86YN96PH*2P-"B`@("`@("`@("`@("=P86-K86=E)R`]/B`D=&AI
M<RT^9V5T4&%C:V%G92@I*2P@=')U92D[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T4&%R<V5D4&%C:V%G92@I#0H@("`@>R`@(`T*("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/E]P86-K86=E9FEL92D@?'P@:7-S970H)'1H:7,M/E]P
M87)S961N86UE*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"=C:&%N
M;F5L)R`]/B`D=&AI<RT^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@
M("=P86-K86=E)R`]/B`D=&AI<RT^9V5T4&%C:V%G92@I+`T*("`@("`@("`@
M("`@("`@("=V97)S:6]N)R`]/B`D=&AI<RT^9V5T5F5R<VEO;B@I*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@
M9G5N8W1I;VX@9V5T1&]W;FQO86154DPH*0T*("`@('L-"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&]W;FQO86154DP[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@8V%N1&5F875L="@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]D;W=N;&]A9%523"DI('L-"B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7V1O=VYL;V%D55),6R=N;V1E9F%U;'0G72DI('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*#0H@("`@9G5N8W1I
M;VX@9V5T4&%C:V%G92@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/E]P86-K86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E*"D[#0H@("`@("`@('T@96QS
M96EF("AI<W-E="@D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG:6YF;R==
M+3YG971086-K86=E*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("`O*BH-
M"B`@("`@*B!`<&%R86T@4$5!4E]086-K86=E1FEL95]V,7Q014%27U!A8VMA
M9V5&:6QE7W8R#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-3=6)P86-K86=E
M*"8D<&8I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K
M86=E9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA
M9V5F:6QE+3YI<U-U8G!A8VMA9V4H)'!F*3L-"B`@("`@("`@?2!E;'-E:68@
M*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/FES
M4W5B<&%C:V%G92@D<&8I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T4&%C:V%G951Y<&4H*0T*("`@('L-"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G951Y<&4H*3L-"B`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN
M9F\G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D
M55),6R=I;F9O)UTM/F=E=%!A8VMA9V54>7!E*"D[#0H@("`@("`@('T@96QS
M92![#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@
M("!]#0H-"B`@("!F=6YC=&EO;B!I<T)U;F1L92@I#0H@("`@>PT*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL92DI('L-"B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG971086-K86=E5'EP
M92@I(#T]("=B=6YD;&4G.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@9G5N
M8W1I;VX@9V5T4&%C:V%G95AM;%9E<G-I;VXH*0T*("`@('L-"B`@("`@("`@
M:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T4&%C:V%G97AM;%9E
M<G-I;VXH*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?9&]W
M;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%!A8VMA9V5X;6Q697)S:6]N
M*"D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@)S$N
M,"<[#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G971#:&%N
M;F5L*"D-"B`@("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA
M9V5F:6QE*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G
M969I;&4M/F=E=$-H86YN96PH*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T
M*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=$-H86YN
M96PH*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N(&=E=%52
M22@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E
M9FEL92DI('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F
M:6QE+3YG97154DDH*3L-"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES
M+3Y?9&]W;FQO86154DQ;)VEN9F\G72DI('L-"B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=%5222@I.PT*("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@
M("`@("!]#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@9V5T5F5R<VEO;B@I#0H@
M("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P86-K86=E9FEL92DI
M('L-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG
M971697)S:6]N*"D[#0H@("`@("`@('T@96QS96EF("AI<W-E="@D=&AI<RT^
M7V1O=VYL;V%D55),6R=V97)S:6]N)UTI*2![#0H@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D;W=N;&]A9%523%LG=F5R<VEO;B==.PT*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@:7-#;VUP871I8FQE*"1P9BD-"B`@
M("![#0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W!A8VMA9V5F:6QE*2D@
M>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<&%C:V%G969I;&4M/FES
M0V]M<&%T:6)L92@D<&8I.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H
M:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^:7-#;VUP871I8FQE
M*"1P9BD[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!R971U<FX@
M=')U93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N('-E=$=R
M;W5P*"1G<F]U<"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?<&%R<V5D;F%M
M95LG9W)O=7`G72`]("1G<F]U<#L-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!G
M971'<F]U<"@I#0H@("`@>PT*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]P
M87)S961N86UE6R=G<F]U<"==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<&%R<V5D;F%M95LG9W)O=7`G73L-"B`@("`@("`@?2!E;'-E('L-
M"B`@("`@("`@("`@(')E='5R;B`G)SL-"B`@("`@("`@?0T*("`@('T-"@T*
M("`@(&9U;F-T:6]N(&ES17AT96YS:6]N*"1N86UE*0T*("`@('L-"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3Y?<&%C:V%G969I;&4I*2![#0H@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^:7-%>'1E;G-I;VXH
M)&YA;64I.PT*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]D;W=N
M;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^9V5T4')O=FED97-%>'1E;G-I;VXH
M*2`]/2`D;F%M93L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@('T-"@T*("`@(&9U;F-T:6]N
M(&=E=$1E<',H*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3Y?
M<&%C:V%G969I;&4I*2![#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]P86-K
M86=E9FEL92T^9V5T4&%C:V%G97AM;%9E<G-I;VXH*2`]/2`G,BXP)RD@>PT*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W!A8VMA9V5F:6QE+3YG
M971$97!S*'1R=64I.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]P86-K86=E9FEL92T^9V5T1&5P<R@I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H
M:7,M/E]D;W=N;&]A9%523%LG:6YF;R==*2D@>PT*("`@("`@("`@("`@:68@
M*"1T:&ES+3Y?9&]W;FQO86154DQ;)VEN9F\G72T^9V5T4&%C:V%G97AM;%9E
M<G-I;VXH*2`]/2`G,BXP)RD@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=$1E<',H=')U92D[#0H@
M("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1O=VYL;V%D55),6R=I;F9O)UTM/F=E=$1E<',H*3L-"B`@("`@
M("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@
M("H@0'!A<F%M(&%R<F%Y(%!A<G-E9"!A<G)A>2!F<F]M('M`;&EN:R!014%2
M7U)E9VES=')Y.CIP87)S95!A8VMA9V5.86UE*"E](&]R(&$@9&5P96YD96YC
M>0T*("`@("`J("`@("`@("`@("`@("`@("`@("`@<F5T=7)N960@9G)O;2!G
M971$97!$;W=N;&]A9%523"@I#0H@("`@("HO#0H@("`@9G5N8W1I;VX@:7-%
M<75A;"@D<&%R86TI#0H@("`@>PT*("`@("`@("!I9B`H:7-?;V)J96-T*"1P
M87)A;2DI('L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@)'!A<F%M+3YG971#
M:&%N;F5L*"D[#0H@("`@("`@("`@("`D<&%C:V%G92`]("1P87)A;2T^9V5T
M4&%C:V%G92@I.PT*("`@("`@("`@("`@:68@*"1P87)A;2T^9V5T55))*"DI
M('L-"B`@("`@("`@("`@("`@("`D<&%R86T@/2!A<G)A>2@-"B`@("`@("`@
M("`@("`@("`@("`@)V-H86YN96PG(#T^("1P87)A;2T^9V5T0VAA;FYE;"@I
M+`T*("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)'!A<F%M+3YG
M971086-K86=E*"DL#0H@("`@("`@("`@("`@("`@("`@("=V97)S:6]N)R`]
M/B`D<&%R86TM/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("`@("`@("`@
M)W5R:2<@/3X@)'!A<F%M+3YG97154DDH*2P-"B`@("`@("`@("`@("`@("`I
M.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<&%R
M86T@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^
M("1P87)A;2T^9V5T0VAA;FYE;"@I+`T*("`@("`@("`@("`@("`@("`@("`G
M<&%C:V%G92<@/3X@)'!A<F%M+3YG971086-K86=E*"DL#0H@("`@("`@("`@
M("`@("`@("`@("=V97)S:6]N)R`]/B`D<&%R86TM/F=E=%9E<G-I;VXH*2P-
M"B`@("`@("`@("`@("`@("`I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]
M(&5L<V4@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1P87)A;5LG=7)I)UTI
M*2![#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=C:&%N;F5L)UT@/2`G7U]U
M<FDG.PT*("`@("`@("`@("`@("`@("1P87)A;5LG<&%C:V%G92==(#T@)'!A
M<F%M6R=D97`G75LG;F%M92==.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@)'!A8VMA9V4@/2!I<W-E="@D<&%R86U;)W!A8VMA9V4G72D@/R`D<&%R
M86U;)W!A8VMA9V4G72`Z#0H@("`@("`@("`@("`@("`@)'!A<F%M6R=I;F9O
M)UTM/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@("1C:&%N;F5L(#T@:7-S
M970H)'!A<F%M6R=C:&%N;F5L)UTI(#\@)'!A<F%M6R=C:&%N;F5L)UT@.@T*
M("`@("`@("`@("`@("`@("1P87)A;5LG:6YF;R==+3YG971#:&%N;F5L*"D[
M#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<F%M6R=R96PG72DI('L-"B`@
M("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@G4$5!4E]$97!E;F1E
M;F-Y,B<I*2![#0H@("`@("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M4$5!4B]$97!E;F1E;F-Y,BYP:'`G.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D;F5W9&5P(#T@4$5!4E]$97!E;F1E;F-Y,CHZ;F]R
M;6%L:7IE1&5P*"1P87)A;2D[#0H@("`@("`@("`@("`@("`@)&YE=V1E<"`]
M("1N97=D97!;,%T[#0H@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'!A
M<F%M6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D;F5W9&5P(#T@)'!A
M<F%M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("AI
M<W-E="@D;F5W9&5P*2D@>PT*("`@("`@("`@("`@:68@*"%I<W-E="@D;F5W
M9&5P6R=M:6XG72DI('L-"B`@("`@("`@("`@("`@("`D;F5W9&5P6R=M:6XG
M72`]("<P)SL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S
M970H)&YE=V1E<%LG;6%X)UTI*2![#0H@("`@("`@("`@("`@("`@)&YE=V1E
M<%LG;6%X)UT@/2`G,3`P,#`P,#`P,#`P,#`P,#`P,#`P)SL-"B`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("\O('5S92!M86=I8R!T;R!S=7!P;W)T('!E
M8VP@<&%C:V%G97,@<W5D9&5N;'D@:G5M<&EN9R!T;R!T:&4@<&5C;"!C:&%N
M;F5L#0H@("`@("`@("`@("`O+R!W92!N965D('1O('-U<'!O<G0@8F]T:"!D
M97!E;F1E;F-Y('!O<W-I8FEL:71I97,-"B`@("`@("`@("`@(&EF("@D8VAA
M;FYE;"`]/2`G<&5A<BYP:'`N;F5T)R`F)B`D=&AI<RT^9V5T0VAA;FYE;"@I
M(#T]("=P96-L+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@:68@*"1P
M86-K86=E(#T]("1T:&ES+3YG971086-K86=E*"DI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&-H86YN96P@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)&-H
M86YN96P@/3T@)W!E8VPN<&AP+FYE="<@)B8@)'1H:7,M/F=E=$-H86YN96PH
M*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@(&EF("@D
M<&%C:V%G92`]/2`D=&AI<RT^9V5T4&%C:V%G92@I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1C:&%N;F5L(#T@)W!E87(N<&AP+FYE="<[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@("`@<F5T=7)N
M("AS=')T;VQO=V5R*"1P86-K86=E*2`]/2!S=')T;VQO=V5R*"1T:&ES+3YG
M971086-K86=E*"DI("8F#0H@("`@("`@("`@("`@("`@)&-H86YN96P@/3T@
M)'1H:7,M/F=E=$-H86YN96PH*2`F)@T*("`@("`@("`@("`@("`@('9E<G-I
M;VY?8V]M<&%R92@D;F5W9&5P6R=M:6XG72P@)'1H:7,M/F=E=%9E<G-I;VXH
M*2P@)SP])RD@)B8-"B`@("`@("`@("`@("`@("!V97)S:6]N7V-O;7!A<F4H
M)&YE=V1E<%LG;6%X)UTL("1T:&ES+3YG971697)S:6]N*"DL("<^/2<I*3L-
M"B`@("`@("`@?0T*("`@("`@("`O+R!U<V4@;6%G:6,@=&\@<W5P<&]R="!P
M96-L('!A8VMA9V5S('-U9&1E;FQY(&IU;7!I;F<@=&\@=&AE('!E8VP@8VAA
M;FYE;`T*("`@("`@("!I9B`H)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE="<@
M)B8@)'1H:7,M/F=E=$-H86YN96PH*2`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*
M("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H)'!A8VMA9V4I(#T]('-T<G1O
M;&]W97(H)'1H:7,M/F=E=%!A8VMA9V4H*2DI('L-"B`@("`@("`@("`@("`@
M("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@(&EF("AI<W-E="@D<&%R86U;)W9E<G-I;VXG
M72DI('L-"B`@("`@("`@("`@(')E='5R;B`H<W1R=&]L;W=E<B@D<&%C:V%G
M92D@/3T@<W1R=&]L;W=E<B@D=&AI<RT^9V5T4&%C:V%G92@I*2`F)@T*("`@
M("`@("`@("`@("`@("1C:&%N;F5L(#T]("1T:&ES+3YG971#:&%N;F5L*"D@
M)B8-"B`@("`@("`@("`@("`@("`D<&%R86U;)W9E<G-I;VXG72`]/2`D=&AI
M<RT^9V5T5F5R<VEO;B@I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@(')E='5R;B!S=')T;VQO=V5R*"1P86-K86=E*2`]/2!S=')T;VQO=V5R
M*"1T:&ES+3YG971086-K86=E*"DI("8F#0H@("`@("`@("`@("`@("`@)&-H
M86YN96P@/3T@)'1H:7,M/F=E=$-H86YN96PH*3L-"B`@("`@("`@?0T*("`@
M('T-"@T*("`@(&9U;F-T:6]N(&ES26YS=&%L;&5D*"1D97`L("1O<&5R(#T@
M)ST])RD-"B`@("![#0H@("`@("`@(&EF("@A)&1E<"D@>PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H@("`@("`@(&EF("@D;W!E
M<B`A/2`G9V4G("8F("1O<&5R("$]("=G="<@)B8@)&]P97(@(3T@)VAA<R<@
M)B8@)&]P97(@(3T@)ST])RD@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("!]#0H@("`@("`@(&EF("AI<U]O8FIE8W0H)&1E<"DI('L-
M"B`@("`@("`@("`@("1P86-K86=E(#T@)&1E<"T^9V5T4&%C:V%G92@I.PT*
M("`@("`@("`@("`@)&-H86YN96P@/2`D9&5P+3YG971#:&%N;F5L*"D[#0H@
M("`@("`@("`@("!I9B`H)&1E<"T^9V5T55))*"DI('L-"B`@("`@("`@("`@
M("`@("`D9&5P(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`@("=U<FDG
M(#T^("1D97`M/F=E=%5222@I+`T*("`@("`@("`@("`@("`@("`@("`G=F5R
M<VEO;B<@/3X@)&1E<"T^9V5T5F5R<VEO;B@I+`T*("`@("`@("`@("`@("`@
M("D[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("1D
M97`@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@)W9E<G-I;VXG(#T^
M("1D97`M/F=E=%9E<G-I;VXH*2P-"B`@("`@("`@("`@("`@("`I.PT*("`@
M("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@:68@
M*&ES<V5T*"1D97!;)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@("1C:&%N
M;F5L(#T@)U]?=7)I)SL-"B`@("`@("`@("`@("`@("`D<&%C:V%G92`]("1D
M97!;)V1E<"==6R=N86UE)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("1C:&%N;F5L(#T@)&1E<%LG:6YF;R==+3YG971#:&%N
M;F5L*"D[#0H@("`@("`@("`@("`@("`@)'!A8VMA9V4@/2`D9&5P6R=I;F9O
M)UTM/F=E=%!A8VMA9V4H*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*
M("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^9V5T3W!T
M:6]N<R@I.PT*("`@("`@("`D=&5S="`]("1T:&ES+3Y?:6YS=&%L;%)E9VES
M=')Y+3YP86-K86=E17AI<W1S*"1P86-K86=E+"`D8VAA;FYE;"D[#0H@("`@
M("`@(&EF("@A)'1E<W0@)B8@)&-H86YN96P@/3T@)W!E8VPN<&AP+FYE="<I
M('L-"B`@("`@("`@("`@("\O(&1O(&UA9VEC('1O(&%L;&]W('5P9W)A9&EN
M9R!F<F]M(&]L9"!P96-L('!A8VMA9V5S('1O(&YE=R!O;F5S#0H@("`@("`@
M("`@("`D=&5S="`]("1T:&ES+3Y?:6YS=&%L;%)E9VES=')Y+3YP86-K86=E
M17AI<W1S*"1P86-K86=E+"`G<&5A<BYP:'`N;F5T)RD[#0H@("`@("`@("`@
M("`D8VAA;FYE;"`]("=P96%R+G!H<"YN970G.PT*("`@("`@("!]#0H@("`@
M("`@(&EF("@D=&5S="D@>PT*("`@("`@("`@("`@:68@*&ES<V5T*"1D97!;
M)W5R:2==*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VEN<W1A
M;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H)'!A8VMA9V4L("=U<FDG+"`G7U]U
M<FDG*2`]/2`D9&5P6R=U<FDG72D@>PT*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@=')U93L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]
M#0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W5P9W)A9&4G72DI
M('L-"B`@("`@("`@("`@("`@("!I9B`H)&]P97(@/3T@)VAA<R<I('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*'9E<G-I;VY?8V]M<&%R92@D=&AI<RT^
M7VEN<W1A;&Q296=I<W1R>2T^<&%C:V%G94EN9F\H#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P86-K86=E+"`G=F5R<VEO;B<L("1C:&%N;F5L*2P-
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@)&1E<%LG=F5R<VEO;B==+"`G
M/CTG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("`@("!I9B`H=F5R<VEO;E]C;VUP87)E*"1T:&ES+3Y?:6YS=&%L;%)E9VES
M=')Y+3YP86-K86=E26YF;R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A8VMA9V4L("=V97)S:6]N)RP@)&-H86YN96PI+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&5P6R=V97)S:6]N)UTL("<^/2<I*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@<F5T=7)N('1R=64[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!P87)A;2!A<G)A>0T*
M("`@("`J($!S=&%T:6,-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!R96UO=F5$
M=7!L:6-A=&5S*"8D<&%R86US*0T*("`@('L-"B`@("`@("`@)'!N86UE<R`]
M(&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)&D@/3X@
M)'!A<F%M*2![#0H@("`@("`@("`@("!I9B`H(21P87)A;2D@>PT*("`@("`@
M("`@("`@("`@(&-O;G1I;G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@:68@*"1P87)A;2T^9V5T4&%C:V%G92@I*2![#0H@("`@("`@("`@("`@
M("`@)'!N86UE<ULD:5T@/2`D<&%R86TM/F=E=$-H86YN96PH*2`N("<O)R`N
M#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2T^9V5T4&%C:V%G92@I("X@
M)RTG("X@)'!A<F%M+3YG971697)S:6]N*"D@+B`G(R<@+B`D<&%R86TM/F=E
M=$=R;W5P*"D[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M)'!N86UE<R`](&%R<F%Y7W5N:7%U92@D<&YA;65S*3L-"B`@("`@("`@)'5N
M<V5T(#T@87)R87E?9&EF9BAA<G)A>5]K97ES*"1P87)A;7,I+"!A<G)A>5]K
M97ES*"1P;F%M97,I*3L-"B`@("`@("`@)'1E<W1P(#T@87)R87E?9FQI<"@D
M<&YA;65S*3L-"B`@("`@("`@9F]R96%C:"`H)'!A<F%M<R!A<R`D:2`]/B`D
M<&%R86TI('L-"B`@("`@("`@("`@(&EF("@A)'!A<F%M*2![#0H@("`@("`@
M("`@("`@("`@)'5N<V5T6UT@/2`D:3L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-?82@D
M<&%R86TL("=014%27T1O=VYL;V%D97)?4&%C:V%G92<I*2![#0H@("`@("`@
M("`@("`@("`@)'5N<V5T6UT@/2`D:3L-"B`@("`@("`@("`@("`@("!C;VYT
M:6YU93L-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@A:7-S970H
M)'1E<W1P6R1P87)A;2T^9V5T0VAA;FYE;"@I("X@)R\G("X@)'!A<F%M+3YG
M971086-K86=E*"D@+B`G+2<@+@T*("`@("`@("`@("`@("`@("`@)'!A<F%M
M+3YG971697)S:6]N*"D@+B`G(R<@+B`D<&%R86TM/F=E=$=R;W5P*"E=*2D@
M>PT*("`@("`@("`@("`@("`@("1U;G-E=%M=(#T@)&D[#0H@("`@("`@("`@
M("!]#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C:"`H)'5N<V5T(&%S("1I
M*2![#0H@("`@("`@("`@("!U;G-E="@D<&%R86US6R1I72D[#0H@("`@("`@
M('T-"B`@("`@("`@)')E="`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@
M*"1P87)A;7,@87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("`D<F5T
M6UT@/2`F)'!A<F%M<ULD:5T[#0H@("`@("`@('T-"B`@("`@("`@)'!A<F%M
M<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1R970@87,@)&D@/3X@
M)'!A<F%M*2![#0H@("`@("`@("`@("`D<&%R86US6UT@/2`F)')E=%LD:5T[
M#0H@("`@("`@('T-"B`@("!]#0H-"B`@("!F=6YC=&EO;B!E>'!L:6-I=%-T
M871E*"D-"B`@("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^7V5X<&QI8VET
M4W1A=&4[#0H@("`@?0T*#0H@("`@9G5N8W1I;VX@<V5T17AP;&EC:713=&%T
M92@D<RD-"B`@("![#0H@("`@("`@("1T:&ES+3Y?97AP;&EC:713=&%T92`]
M("1S.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($!S=&%T:6,-"B`@("`@
M*B\-"B`@("!F=6YC=&EO;B!M97)G941E<&5N9&5N8VEE<R@F)'!A<F%M<RD-
M"B`@("![#0H@("`@("`@("1N97=P87)A;7,@/2!A<G)A>2@I.PT*("`@("`@
M("`D8G5N9&QE<R`](&%R<F%Y*"D[#0H@("`@("`@(&9O<F5A8V@@*"1P87)A
M;7,@87,@)&D@/3X@)'!A<F%M*2![#0H@("`@("`@("`@("!I9B`H(21P87)A
M;2T^:7-"=6YD;&4H*2D@>PT*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PT*
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@)&)U;F1L97-;72`]("1I.PT*
M("`@("`@("`@("`@)'!F(#T@)B1P87)A;2T^9V5T4&%C:V%G949I;&4H*3L-
M"B`@("`@("`@("`@("1N97=D97!S(#T@87)R87DH*3L-"B`@("`@("`@("`@
M("1C;VYT96YT<R`]("1P9BT^9V5T0G5N9&QE9%!A8VMA9V5S*"D[#0H@("`@
M("`@("`@("!I9B`H(6ES7V%R<F%Y*"1C;VYT96YT<RDI('L-"B`@("`@("`@
M("`@("`@("`D8V]N=&5N=',@/2!A<G)A>2@D8V]N=&5N=',I.PT*("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@9F]R96%C:"`H)&-O;G1E;G1S(&%S("1F
M:6QE*2![#0H@("`@("`@("`@("`@("`@)&9I;&5C;VYT96YT<R`]("1P9BT^
M9V5T1FEL94-O;G1E;G1S*"1F:6QE*3L-"B`@("`@("`@("`@("`@("`D9&P@
M/2`F)'!A<F%M+3YG971$;W=N;&]A9&5R*"D[#0H@("`@("`@("`@("`@("`@
M)&]P=&EO;G,@/2`D9&PM/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@("`@("`@
M("`D9G`@/2!`9F]P96XH)&1L+3YG971$;W=N;&]A9$1I<B@I("X@1$E214-4
M3U)97U-%4$%2051/4B`N("1F:6QE+"`G=V(G*3L-"B`@("`@("`@("`@("`@
M("!I9B`H(21F<"D@>PT*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@9G=R:71E*"1F
M<"P@)&9I;&5C;VYT96YT<RP@<W1R;&5N*"1F:6QE8V]N=&5N=',I*3L-"B`@
M("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L-"B`@("`@("`@("`@("`@("!I
M9B`H)',@/2`D<&%R86US6R1I72T^97AP;&EC:713=&%T92@I*2![#0H@("`@
M("`@("`@("`@("`@("`@("1O8FHM/G-E=$5X<&QI8VET4W1A=&4H)',I.PT*
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D;V)J(#T@)FYE
M=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D<&%R86US6R1I72T^9V5T1&]W
M;FQO861E<B@I*3L-"B`@("`@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@
M)&4@/2`D;V)J+3Y?9G)O;49I;&4H)&$@/2`D9&PM/F=E=$1O=VYL;V%D1&ER
M*"D@+B!$25)%0U1/4EE?4T5005)!5$]2("X@)&9I;&4I.PT*("`@("`@("`@
M("`@("`@(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@
M("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`@("`@)&1L+3YL;V<H,"P@)&4M/F=E=$UE<W-A9V4H
M*2D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@
M("`@8V]N=&EN=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M("`@("1J(#T@)B1O8FH[#0H@("`@("`@("`@("`@("`@:68@*"%014%27T1O
M=VYL;V%D97)?4&%C:V%G93HZ=VEL;$1O=VYL;V%D*"1J+`T*("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y7VUE<F=E*"1P87)A;7,L("1N97=P87)A;7,I
M*2`F)B`A)'!A<F%M+3YI<TEN<W1A;&QE9"@D:BDI('L-"B`@("`@("`@("`@
M("`@("`@("`@)&YE=W!A<F%M<UM=(#T@)B1J.PT*("`@("`@("`@("`@("`@
M('T-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@("`@("!F;W)E86-H
M("@D8G5N9&QE<R!A<R`D:2D@>PT*("`@("`@("`@("`@=6YS970H)'!A<F%M
M<ULD:5TI.R`O+R!R96UO=F4@8G5N9&QE<R`M(&]N;'D@=&AE:7(@8V]N=&5N
M=',@;6%T=&5R(&9O<B!I;G-T86QL871I;VX-"B`@("`@("`@?0T*("`@("`@
M("!014%27T1O=VYL;V%D97)?4&%C:V%G93HZ<F5M;W9E1'5P;&EC871E<R@D
M<&%R86US*3L@+R\@<W1R:7`@86YY('5N<V5T(&EN9&EC97,-"B`@("`@("`@
M:68@*&-O=6YT*"1N97=P87)A;7,I*2![("\O(&%D9"!I;B!B=6YD;&5D('!A
M8VMA9V5S(&9O<B!I;G-T86QL#0H@("`@("`@("`@("!F;W)E86-H("@D;F5W
M<&%R86US(&%S("1I(#T^("1U;G5S960I('L-"B`@("`@("`@("`@("`@("`D
M<&%R86US6UT@/2`F)&YE=W!A<F%M<ULD:5T[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("`D;F5W<&%R86US(#T@87)R87DH*3L-"B`@("`@("`@?0T*
M("`@("`@("!F;W)E86-H("@D<&%R86US(&%S("1I(#T^("1P87)A;2D@>PT*
M("`@("`@("`@("`@)&YE=V1E<',@/2!A<G)A>2@I.PT*("`@("`@("`@("`@
M9F]R96%C:"`H)'!A<F%M+3Y?9&]W;FQO861$97!S(&%S("1D97`I('L-"B`@
M("`@("`@("`@("`@("!I9B`H(5!%05)?1&]W;FQO861E<E]086-K86=E.CIW
M:6QL1&]W;FQO860H)&1E<"P-"B`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>5]M97)G92@D<&%R86US+"`D;F5W<&%R86US*2D@)B8@(21P87)A;2T^:7-)
M;G-T86QL960H)&1E<"DI('L-"B`@("`@("`@("`@("`@("`@("`@)&YE=V1E
M<'-;72`]("1D97`[#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@+R\@9&5T96-T('9E<G-I;VYI;F<@8V]N9FQI8W1S
M(&AE<F4-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`O+R!C;VYV97)T('1H92!D97!E;F1E;F-I97,@:6YT;R!014%2
M7T1O=VYL;V%D97)?4&%C:V%G92!O8FIE8W1S(&9O<B!T:&4@;F5X="!T:6UE
M#0H@("`@("`@("`@("`O+R!A<F]U;F0-"B`@("`@("`@("`@("1P87)A;7-;
M)&E=+3Y?9&]W;FQO861$97!S(#T@87)R87DH*3L-"B`@("`@("`@("`@(&9O
M<F5A8V@@*"1N97=D97!S(&%S("1D97`I('L-"B`@("`@("`@("`@("`@("`D
M;V)J(#T@)FYE=R!014%27T1O=VYL;V%D97)?4&%C:V%G92@D<&%R86US6R1I
M72T^9V5T1&]W;FQO861E<B@I*3L-"B`@("`@("`@("`@("`@("!I9B`H)',@
M/2`D<&%R86US6R1I72T^97AP;&EC:713=&%T92@I*2![#0H@("`@("`@("`@
M("`@("`@("`@("1O8FHM/G-E=$5X<&QI8VET4W1A=&4H)',I.PT*("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(
M86YD;&EN9RA014%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`@("`@
M)&4@/2`D;V)J+3YF<F]M1&5P55),*"1D97`I.PT*("`@("`@("`@("`@("`@
M(%!%05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D92DI('L-"B`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<V]F="==*2D@>PT*("`@("`@("`@("`@
M("`@("`@("`@("`@)&]B:BT^7V1O=VYL;V%D97(M/FQO9R@P+"`D92T^9V5T
M365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@)&4@/2`D;V)J+3YD971E8W1$97!E;F1E;F-I97,H)'!A
M<F%M<RD[#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&4I
M*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P=&EO;G-;
M)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1O8FHM/E]D
M;W=N;&]A9&5R+3YL;V<H,"P@)&4M/F=E=$UE<W-A9V4H*2D[#0H@("`@("`@
M("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&H@/2`F)&]B:CL-"B`@("`@("`@("`@("`@("`D;F5W<&%R86US
M6UT@/2`F)&H[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@
M:68@*&-O=6YT*"1N97=P87)A;7,I*2![#0H@("`@("`@("`@("!F;W)E86-H
M("@D;F5W<&%R86US(&%S("1I(#T^("1U;G5S960I('L-"B`@("`@("`@("`@
M("`@("`D<&%R86US6UT@/2`F)&YE=W!A<F%M<ULD:5T[#0H@("`@("`@("`@
M("!]#0H@("`@("`@("`@("!R971U<FX@=')U93L-"B`@("`@("`@?2!E;'-E
M('L-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*("`@
M('T-"@T*#0H@("`@+RHJ#0H@("`@("H@0'-T871I8PT*("`@("`J+PT*("`@
M(&9U;F-T:6]N('=I;&Q$;W=N;&]A9"@D<&%R86TL("1P87)A;7,I#0H@("`@
M>PT*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2![#0H@("`@("`@
M("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@9F]R96%C
M:"`H)'!A<F%M<R!A<R`D;V)J*2![#0H@("`@("`@("`@("!I9B`H)&]B:BT^
M:7-%<75A;"@D<&%R86TI*2![#0H@("`@("`@("`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@('T-"@T*("`@("\J*@T*("`@("`J($9O<B!S:6UP;&5R
M('5N:70M=&5S=&EN9PT*("`@("`J($!P87)A;2!014%27T-O;F9I9PT*("`@
M("`J($!P87)A;2!I;G0-"B`@("`@*B!`<&%R86T@<W1R:6YG#0H@("`@("HO
M#0H@("`@9G5N8W1I;VX@)F=E=%!A8VMA9V5F:6QE3V)J96-T*"8D8RP@)&0L
M("1T(#T@9F%L<V4I#0H@("`@>PT*("`@("`@("`D82`]("9N97<@4$5!4E]0
M86-K86=E1FEL92@D8RP@)&0L("1T*3L-"B`@("`@("`@<F5T=7)N("1A.PT*
M("`@('T-"@T*#0H@("`@+RHJ#0H@("`@("H@5&AI<R!W:6QL(')E=')I979E
M(&9R;VT@82!L;V-A;"!F:6QE(&EF('!O<W-I8FQE+"!A;F0@<&%R<V4@;W5T
M#0H@("`@("H@82!G<F]U<"!N86UE(&%S('=E;&PN("!4:&4@;W)I9VEN86P@
M<&%R86UE=&5R('=I;&P@8F4@;6]D:69I960@=&\@<F5F;&5C="!T:&ES+@T*
M("`@("`J($!P87)A;2!S=')I;F=\87)R87D@8V%N(&)E(&$@<&%R<V5D('!A
M8VMA9V4@;F%M92!A<R!W96QL#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("HO#0H@("`@9G5N8W1I;VX@7V9R;VU&:6QE*"8D<&%R86TI#0H@("`@
M>PT*("`@("`@("!I9B`H:7-?<W1R:6YG*"1P87)A;2D@)B8@(4!I<U]F:6QE
M*"1P87)A;2DI('L-"B`@("`@("`@("`@("1T97-T(#T@97AP;&]D92@G(R<L
M("1P87)A;2D[#0H@("`@("`@("`@("`D9W)O=7`@/2!A<G)A>5]P;W`H)'1E
M<W0I.PT*("`@("`@("`@("`@:68@*$!I<U]F:6QE*&EM<&QO9&4H)R,G+"`D
M=&5S="DI*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/G-E=$=R;W5P*"1G
M<F]U<"D[#0H@("`@("`@("`@("`@("`@)'!A<F%M(#T@:6UP;&]D92@G(R<L
M("1T97-T*3L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5X<&QI8VET1W)O
M=7`@/2!T<G5E.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@
M(&EF("A`:7-?9FEL92@D<&%R86TI*2![#0H@("`@("`@("`@("`D=&AI<RT^
M7W1Y<&4@/2`G;&]C86PG.PT*("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI
M<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG9&]W;FQO861O;FQY)UTI*2![#0H@("`@("`@
M("`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G969I;&5/8FIE8W0H
M)'1H:7,M/E]C;VYF:6<L#0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M9&]W;FQO861E<BT^7V1E8G5G*3L-"B`@("`@("`@("`@('T@96QS92![#0H@
M("`@("`@("`@("`@("`@)'!K9R`]("8D=&AI<RT^9V5T4&%C:V%G969I;&5/
M8FIE8W0H)'1H:7,M/E]C;VYF:6<L#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^7V1E8G5G+"`D=&AI<RT^7V1O=VYL;V%D97(M
M/F=E=$1O=VYL;V%D1&ER*"DI.PT*("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@4$5!4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI
M.PT*("`@("`@("`@("`@)'!F(#T@)B1P:V<M/F9R;VU!;GE&:6QE*"1P87)A
M;2P@4$5!4E]604Q)1$%415])3E-404Q,24Y'*3L-"B`@("`@("`@("`@(%!%
M05(Z.G!O<$5R<F]R2&%N9&QI;F<H*3L-"B`@("`@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1P9BDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7W9A
M;&ED(#T@9F%L<V4[#0H@("`@("`@("`@("`@("`@<F5T=7)N("1P9CL-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C:V%G969I;&4@
M/2`F)'!F.PT*("`@("`@("`@("`@:68@*"$D=&AI<RT^9V5T1W)O=7`H*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3YS971'<F]U<"@G9&5F875L="<I
M.R`O+R!I;G-T86QL('1H92!D969A=6QT(&1E<&5N9&5N8WD@9W)O=7`-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED
M(#T@=')U93L-"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)'1H:7,M/E]V
M86QI9"`](&9A;'-E.PT*("`@('T-"@T*("`@(&9U;F-T:6]N(%]F<F]M57)L
M*"1P87)A;2P@)'-A=F5P87)A;2`]("<G*0T*("`@('L-"B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D<&%R86TI("8F#0H@("`@("`@("`@("`@("AP<F5G7VUA
M=&-H*"<C7BAH='1P?&9T<"DZ+R\C)RP@)'!A<F%M*2DI('L-"B`@("`@("`@
M("`@("1O<'1I;VYS(#T@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971/<'1I;VYS
M*"D[#0H@("`@("`@("`@("`D=&AI<RT^7W1Y<&4@/2`G=7)L)SL-"B`@("`@
M("`@("`@("1C86QL8F%C:R`]("1T:&ES+3Y?9&]W;FQO861E<BT^=6D@/PT*
M("`@("`@("`@("`@("`@(&%R<F%Y*"8D=&AI<RT^7V1O=VYL;V%D97(L("=?
M9&]W;FQO861#86QL8F%C:R<I(#H@;G5L;#L-"B`@("`@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E<BT^<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]2
M15154DXI.PT*("`@("`@("`@("`@)&9I;&4@/2`D=&AI<RT^7V1O=VYL;V%D
M97(M/F1O=VYL;V%D2'1T<"@D<&%R86TL("1T:&ES+3Y?9&]W;FQO861E<BT^
M=6DL#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]D;W=N;&]A9&5R+3YG971$
M;W=N;&]A9$1I<B@I+"`D8V%L;&)A8VLI.PT*("`@("`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5R+3YP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@("`@("`@
M("!I9B`H4$5!4CHZ:7-%<G)O<B@D9FEL92DI('L-"B`@("`@("`@("`@("`@
M("!I9B`H(65M<'1Y*"1S879E<&%R86TI*2![#0H@("`@("`@("`@("`@("`@
M("`@("1S879E<&%R86T@/2`B+"!C86YN;W0@9&]W;FQO860@7"(D<V%V97!A
M<F%M7"(B.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`D
M97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G0V]U;&0@;F]T(&1O=VYL;V%D(&9R
M;VT@(B<@+B`D<&%R86T@+@T*("`@("`@("`@("`@("`@("`@("`G(B<@+B`D
M<V%V97!A<F%M*3L-"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G([
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]R87=P
M86-K86=E9FEL92D@>PT*("`@("`@("`@("`@("`@(')E<75I<F5?;VYC92`G
M07)C:&EV92]487(N<&AP)SL-"B`@("`@("`@("`@("`@("`D=&%R(#T@)FYE
M=R!!<F-H:79E7U1A<B@D9FEL92D[#0H@("`@("`@("`@("`@("`@)'!A8VMA
M9V5X;6P@/2`D=&%R+3YE>'1R86-T26Y3=')I;F<H)W!A8VMA9V4R+GAM;"<I
M.PT*("`@("`@("`@("`@("`@(&EF("@A)'!A8VMA9V5X;6PI('L-"B`@("`@
M("`@("`@("`@("`@("`@)'!A8VMA9V5X;6P@/2`D=&%R+3YE>'1R86-T26Y3
M=')I;F<H)W!A8VMA9V4N>&UL)RD[#0H@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@(&EF("AS=')?<F5P;&%C92AA<G)A>2@B7&XB+"`B7'(B
M*2P@87)R87DH)R<L)R<I+"`D<&%C:V%G97AM;"D@(3T-"B`@("`@("`@("`@
M("`@("`@("`@("!S=')?<F5P;&%C92AA<G)A>2@B7&XB+"`B7'(B*2P@87)R
M87DH)R<L)R<I+"`D=&AI<RT^7W)A=W!A8VMA9V5F:6QE*2D@>PT*("`@("`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/F=E=$-H86YN96PH*2`]/2`G<&5A
M<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@+R\@8F4@
M;6]R92!L87@@9F]R('1H92!E>&ES=&EN9R!014%2('!A8VMA9V5S('1H870@
M:&%V92!N;W0M;VL-"B`@("`@("`@("`@("`@("`@("`@("`@("\O(&-H87)A
M8W1E<G,@:6X@=&AE:7(@<&%C:V%G92YX;6P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("=#4DE424-!3"!7
M05).24Y'.B!4:&4@(B<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YG971086-K86=E*"D@+B`G(B!P86-K86=E(&AA<R!I;G9A;&ED
M(&-H87)A8W1E<G,@:6X@:71S("<@+@T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("=P86-K86=E+GAM;"X@(%1H92!N97AT('9E<G-I;VX@;V8@4$5!
M4B!M87D@;F]T(&)E(&%B;&4@=&\@:6YS=&%L;"`G("X-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=&AI<R!P86-K86=E(&9O<B!S96-U<FET>2!R
M96%S;VYS+B`@4&QE87-E(&]P96X@82!B=6<@<F5P;W)T(&%T("<@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O)R`N("1T:&ES+3YG971086-K86=E*"D@+B`G+V)U9W,G*3L-
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@("`@(')E='5R;B!014%2.CIR86ES945R<F]R*"=#4DE424-!3"!%
M4E)/4CH@<&%C:V%G92YX;6P@9&]W;FQO861E9"!D;V5S("<@+@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=N;W0@;6%T8V@@=F%L=64@<F5T=7)N
M960@9G)O;2!X;6PM<G!C)RD[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O
M+R!W:&5W+"!D;W=N;&]A9"!W;W)K960A#0H@("`@("`@("`@("!I9B`H:7-S
M970H)&]P=&EO;G-;)V1O=VYL;V%D;VYL>2==*2D@>PT*("`@("`@("`@("`@
M("`@("1P:V<@/2`F)'1H:7,M/F=E=%!A8VMA9V5F:6QE3V)J96-T*"1T:&ES
M+3Y?8V]N9FEG+"`D=&AI<RT^7V1O=VYL;V%D97(M/F1E8G5G*3L-"B`@("`@
M("`@("`@('T@96QS92![#0H@("`@("`@("`@("`@("`@)'!K9R`]("8D=&AI
M<RT^9V5T4&%C:V%G969I;&5/8FIE8W0H)'1H:7,M/E]C;VYF:6<L("1T:&ES
M+3Y?9&]W;FQO861E<BT^9&5B=6<L#0H@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9&]W;FQO861E<BT^9V5T1&]W;FQO861$:7(H*2D[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!014%2.CIP=7-H17)R;W)(86YD;&EN9RA0
M14%27T524D]27U)%5%523BD[#0H@("`@("`@("`@("`D<&8@/2`F)'!K9RT^
M9G)O;4%N>49I;&4H)&9I;&4L(%!%05)?5D%,241!5$5?24Y35$%,3$E.1RD[
M#0H@("`@("`@("`@("!014%2.CIP;W!%<G)O<DAA;F1L:6YG*"D[#0H@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&8I*2![#0H@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P9BT^9V5T57-E<DEN9F\H*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'!F+3YG9715<V5R26YF;R@I
M(&%S("1E<G(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D97)R*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G(@/2`D97)R6R=M97-S86=E)UT[#0H@("`@("`@("`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I
M;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]D;W=N;&]A9&5R+3YL;V<H,"P@(E9A;&ED871I;VX@17)R;W(Z
M("1E<G(B*3L-"B`@("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?9&]W;FQO861E<BT^;&]G*#`L("1P9BT^
M9V5T365S<V%G92@I*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H)T1O=VYL;V%D(&]F("(G
M("X@*"1S879E<&%R86T@/R`D<V%V97!A<F%M(#H-"B`@("`@("`@("`@("`@
M("`@("`@)'!A<F%M*2`N("<B('-U8V-E961E9"P@8G5T(&ET(&ES(&YO="!A
M('9A;&ED('!A8VMA9V4@87)C:&EV92<I.PT*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=F%L:60@/2!F86QS93L-"B`@("`@("`@("`@("`@("!R971U<FX@
M)&5R<CL-"B`@("`@("`@("`@('T-"B`@("`@("`@("`@("1T:&ES+3Y?<&%C
M:V%G969I;&4@/2`F)'!F.PT*("`@("`@("`@("`@)'1H:7,M/G-E=$=R;W5P
M*"=D969A=6QT)RD[("\O(&EN<W1A;&P@=&AE(&1E9F%U;'0@9&5P96YD96YC
M>2!G<F]U<`T*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?=F%L:60@/2!T
M<G5E.PT*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D=&AI<RT^7W9A;&ED
M(#T@9F%L<V4[#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H-"B`@("`@*B!`
M<&%R86T@<W1R:6YG?&%R<F%Y('!A<W,@:6X@86X@87)R87D@;V8@9F]R;6%T
M#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!A<G)A>2@-"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`G<&%C:V%G92<@/3X@)W!N86UE)RP-"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@(%LG8VAA;FYE;"<@/3X@)V-H86YN
M86UE)RQ=#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;)W9E<G-I;VXG
M(#T^("=V97)S:6]N)RQ=#0H@("`@("H@("`@("`@("`@("`@("`@("`@("!;
M)W-T871E)R`]/B`G<W1A=&4G+%TI#0H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!O<B!A('-T<FEN9R!O9B!F;W)M870@6V-H86YN86UE+UUP;F%M95LM
M=F5R<VEO;GPM<W1A=&5=#0H@("`@("HO#0H@("`@9G5N8W1I;VX@7V9R;VU3
M=')I;F<H)'!A<F%M*0T*("`@('L-"B`@("`@("`@)&]P=&EO;G,@/2`D=&AI
M<RT^7V1O=VYL;V%D97(M/F=E=$]P=&EO;G,H*3L-"B`@("`@("`@4$5!4CHZ
M<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@("`@
M("`D<&YA;64@/2`D=&AI<RT^7W)E9VES=')Y+3YP87)S95!A8VMA9V5.86UE
M*"1P87)A;2P-"B`@("`@("`@("`@("1T:&ES+3Y?8V]N9FEG+3YG970H)V1E
M9F%U;'1?8VAA;FYE;"<I*3L-"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD
M;&EN9R@I.PT*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<&YA;64I*2![
M#0H@("`@("`@("`@("!I9B`H)'!N86UE+3YG971#;V1E*"D@/3T@)VEN=F%L
M:60G*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9"`](&9A;'-E
M.PT*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@D<&YA;64M/F=E=$-O9&4H*2`]/2`G8VAA
M;FYE;"<I('L-"B`@("`@("`@("`@("`@("`D<&%R<V5D(#T@)'!N86UE+3YG
M9715<V5R26YF;R@I.PT*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V1O
M=VYL;V%D97(M/F1I<V-O=F5R*"1P87)S961;)V-H86YN96PG72DI('L-"B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]N9FEG+3YG970H)V%U
M=&]?9&ES8V]V97(G*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4CHZ<'5S:$5R<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PT*("`@
M("`@("`@("`@("`@("`@("`@("`@)'!N86UE(#T@)'1H:7,M/E]R96=I<W1R
M>2T^<&%R<V5086-K86=E3F%M92@D<&%R86TL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/E]C;VYF:6<M/F=E="@G9&5F875L=%]C:&%N
M;F5L)RDI.PT*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4CHZ<&]P17)R
M;W)(86YD;&EN9R@I.PT*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D;W!T:6]N<ULG
M<V]F="==*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E<BT^;&]G*#`L("=#:&%N;F5L("(G("X@)'!A<G-E9%LG
M8VAA;FYE;"==("X-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R(@:7,@;F]T(&EN:71I86QI>F5D+"!U<V4@)R`N#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("<B<&5A<B!C:&%N;F5L+61I<V-O=F5R("<@
M+B`D<&%R<V5D6R=C:&%N;F5L)UT@+B`G(B!T;R!I;FET:6%L:7IE)R`N#0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=O<B!P96%R(&-O;F9I
M9RUS970@875T;U]D:7-C;W9E<B`Q)RD[#0H@("`@("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("!]#0H@("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'!N86UE
M*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O<'1I;VYS
M6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V1O=VYL;V%D97(M/FQO9R@P+"`D<&YA;64M/F=E=$UE<W-A9V4H*2D[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;2`]("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE
M5&]3=')I;F<H)'!A<F%M*3L-"B`@("`@("`@("`@("`@("`@("`@?0T*("`@
M("`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G:6YV
M86QI9"!P86-K86=E(&YA;64O<&%C:V%G92!F:6QE("(G("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1P87)A;2`N("<B)RD[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=F%L:60@/2!F86QS93L-"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N("1E<G([#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1O
M<'1I;VYS6R=S;V9T)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?9&]W;FQO861E<BT^;&]G*#`L("1P;F%M92T^9V5T365S<V%G92@I*3L-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@)&5R<B`](%!%
M05(Z.G)A:7-E17)R;W(H)VEN=F%L:60@<&%C:V%G92!N86UE+W!A8VMA9V4@
M9FEL92`B)R`N#0H@("`@("`@("`@("`@("`@("`@("1P87)A;2`N("<B)RD[
M#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]V86QI9"`](&9A;'-E.PT*("`@
M("`@("`@("`@("`@(')E='5R;B`D97)R.PT*("`@("`@("`@("`@?0T*("`@
M("`@("!]#0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]T>7!E*2D@>PT*
M("`@("`@("`@("`@)'1H:7,M/E]T>7!E(#T@)WAM;')P8R<[#0H@("`@("`@
M('T-"B`@("`@("`@)'1H:7,M/E]P87)S961N86UE(#T@)'!N86UE.PT*("`@
M("`@("!I9B`H:7-S970H)'!N86UE6R=S=&%T92==*2D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]E>'!L:6-I=%-T871E(#T@)'!N86UE6R=S=&%T92==.PT*
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@)'1H:7,M/E]E>'!L:6-I
M=%-T871E(#T@9F%L<V4[#0H@("`@("`@('T-"B`@("`@("`@:68@*&ES<V5T
M*"1P;F%M95LG9W)O=7`G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?97AP
M;&EC:71'<F]U<"`]('1R=64[#0H@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`D=&AI<RT^7V5X<&QI8VET1W)O=7`@/2!F86QS93L-"B`@("`@("`@
M?0T*("`@("`@("`D:6YF;R`]("1T:&ES+3Y?9&]W;FQO861E<BT^7V=E=%!A
M8VMA9V5$;W=N;&]A9%5R;"@D<&YA;64I.PT*("`@("`@("!I9B`H4$5!4CHZ
M:7-%<G)O<B@D:6YF;RDI('L-"B`@("`@("`@("`@(&EF("@D<&YA;65;)V-H
M86YN96PG72`]/2`G<&5A<BYP:'`N;F5T)RD@>PT*("`@("`@("`@("`@("`@
M("\O('1R>2!P96-L#0H@("`@("`@("`@("`@("`@)'!N86UE6R=C:&%N;F5L
M)UT@/2`G<&5C;"YP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("!I9B`H)'1E
M<W0@/2`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971086-K86=E1&]W;FQO8615
M<FPH)'!N86UE*2D@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(5!%05(Z
M.FES17)R;W(H)'1E<W0I*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`D
M:6YF;R`](%!%05(Z.G)A:7-E17)R;W(H)&EN9F\M/F=E=$UE<W-A9V4H*2`N
M("<@+2!P86-K86=E("<@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H
M)'!N86UE+"!T<G5E*2`N#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R!C86X@8F4@:6YS=&%L;&5D('=I=&@@(G!E8VP@:6YS=&%L;"`G("X@)'!N
M86UE6R=P86-K86=E)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<B)RD[#0H@("`@("`@("`@("`@("`@("`@('T@96QS92![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`D<&YA;65;)V-H86YN96PG72`]("=P96%R+G!H
M<"YN970G.PT*("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@)'!N86UE6R=C:&%N
M;F5L)UT@/2`G<&5A<BYP:'`N;F5T)SL-"B`@("`@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!]#0H@("`@("`@("`@("!R971U<FX@)&EN9F\[#0H@("`@
M("`@('T-"B`@("`@("`@)'1H:7,M/E]R87=P86-K86=E9FEL92`]("1I;F9O
M6R=R87<G73L-"B`@("`@("`@)')E="`]("1T:&ES+3Y?86YA;'EZ941O=VYL
M;V%D55),*"1I;F9O+"`D<&%R86TL("1P;F%M92D[#0H@("`@("`@(&EF("A0
M14%2.CII<T5R<F]R*"1R970I*2![#0H@("`@("`@("`@("!R971U<FX@)')E
M=#L-"B`@("`@("`@?0T*("`@("`@("!I9B`H)')E="D@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]D;W=N;&]A9%523"`]("1R970[#0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]V86QI9"`]("AB;V]L*2`D<F5T.PT*("`@("`@("!]
M#0H@("`@?0T*#0H@("`@+RHJ#0H@("`@("H@0'!A<F%M(&%R<F%Y(&]U='!U
M="!O9B!P86-K86=E+F=E=$1O=VYL;V%D55),#0H@("`@("H@0'!A<F%M('-T
M<FEN9WQA<G)A>7QO8FIE8W0@:6YF;W)M871I;VX@9F]R(&1E=&5C=&EN9R!P
M86-K86=E<R!T;R!B92!D;W=N;&]A9&5D+"!A;F0-"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!F;W(@97)R;W)S#0H@("`@("H@0'!A<F%M
M(&%R<F%Y(&YA;64@:6YF;W)M871I;VX@;V8@=&AE('!A8VMA9V4-"B`@("`@
M*B!`<&%R86T@87)R87E\;G5L;"!P86-K86=E<R!T;R!B92!D;W=N;&]A9&5D
M#0H@("`@("H@0'!A<F%M(&)O;VP@:7,@=&AI<R!A;B!O<'1I;VYA;"!D97!E
M;F1E;F-Y/PT*("`@("`J($!A8V-E<W,@<')I=F%T90T*("`@("`J+PT*("`@
M(&9U;F-T:6]N(%]A;F%L>7IE1&]W;FQO86154DPH)&EN9F\L("1P87)A;2P@
M)'!N86UE+"`D<&%R86US(#T@;G5L;"P@)&]P=&EO;F%L(#T@9F%L<V4I#0H@
M("`@>PT*("`@("`@("!I9B`H(6ES7W-T<FEN9R@D<&%R86TI("8F(%!%05)?
M1&]W;FQO861E<E]086-K86=E.CIW:6QL1&]W;FQO860H)'!A<F%M+"`D<&%R
M86US*2D@>PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]
M#0H@("`@("`@(&EF("@A)&EN9F\I('L-"B`@("`@("`@("`@(&EF("@A:7-?
M<W1R:6YG*"1P87)A;2DI('L-"B`@("`@("`@("`@("`@("`D<V%V97!A<F%M
M(#T@(BP@8V%N;F]T(&1O=VYL;V%D(%PB)'!A<F%M7"(B.PT*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D<V%V97!A<F%M(#T@)R<[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`O+R!N;R!R96QE87-E<R!E
M>&ES=`T*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)TYO
M(')E;&5A<V5S(&9O<B!P86-K86=E("(G("X-"B`@("`@("`@("`@("`@("`D
M=&AI<RT^7W)E9VES=')Y+3YP87)S961086-K86=E3F%M951O4W1R:6YG*"1P
M;F%M92P@=')U92D@+B`G(B!E>&ES="<@+B`D<V%V97!A<F%M*3L-"B`@("`@
M("`@?0T*("`@("`@("!I9B`H<W1R=&]L;W=E<B@D:6YF;ULG:6YF;R==+3YG
M971#:&%N;F5L*"DI("$]('-T<G1O;&]W97(H)'!N86UE6R=C:&%N;F5L)UTI
M*2![#0H@("`@("`@("`@("`D97)R(#T@9F%L<V4[#0H@("`@("`@("`@("!I
M9B`H)'!N86UE6R=C:&%N;F5L)UT@/3T@)W!E8VPN<&AP+FYE="<I('L-"B`@
M("`@("`@("`@("`@("!I9B`H)&EN9F];)VEN9F\G72T^9V5T0VAA;FYE;"@I
M("$]("=P96%R+G!H<"YN970G*2![#0H@("`@("`@("`@("`@("`@("`@("1E
M<G(@/2!T<G5E.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T@
M96QS96EF("@D:6YF;ULG:6YF;R==+3YG971#:&%N;F5L*"D@/3T@)W!E8VPN
M<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("!I9B`H)'!N86UE6R=C:&%N
M;F5L)UT@(3T@)W!E87(N<&AP+FYE="<I('L-"B`@("`@("`@("`@("`@("`@
M("`@)&5R<B`]('1R=64[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`D97)R(#T@=')U93L-"B`@
M("`@("`@("`@('T-"B`@("`@("`@("`@(&EF("@D97)R*2![#0H@("`@("`@
M("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H)U-%0U522519($52
M4D]2.B!P86-K86=E(&EN(&-H86YN96P@(B<@+B`D<&YA;65;)V-H86YN96PG
M72`N#0H@("`@("`@("`@("`@("`@("`@("<B(')E=')I979E9"!A;F]T:&5R
M(&-H86YN96Q<)W,@;F%M92!F;W(@9&]W;FQO860A("@B)R`N#0H@("`@("`@
M("`@("`@("`@("`@("1I;F9O6R=I;F9O)UTM/F=E=$-H86YN96PH*2`N("<B
M*2<I.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(&EF("@A
M:7-S970H)&EN9F];)W5R;"==*2D@>PT*("`@("`@("`@("`@)&EN<W1E860@
M/2`@)RP@=VEL;"!I;G-T96%D(&1O=VYL;V%D('9E<G-I;VX@)R`N("1I;F9O
M6R=V97)S:6]N)UT@+@T*("`@("`@("`@("`@("`@("`@("`@("`@)RP@<W1A
M8FEL:71Y("(G("X@)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H*2`N("<B)SL-
M"B`@("`@("`@("`@("\O(')E;&5A<V5S(&5X:7-T+"!B=70@=V4@9F%I;&5D
M('1O(&=E="!A;GD-"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7V1O
M=VYL;V%D97(M/E]O<'1I;VYS6R=F;W)C92==*2D@>PT*("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<&YA;65;)W9E<G-I;VXG72DI('L-"B`@("`@("`@
M("`@("`@("`@("`@)'9S(#T@)RP@=F5R<VEO;B`B)R`N("1P;F%M95LG=F5R
M<VEO;B==("X@)R(G.PT*("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E
M="@D<&YA;65;)W-T871E)UTI*2![#0H@("`@("`@("`@("`@("`@("`@("1V
M<R`]("<L('-T86)I;&ET>2`B)R`N("1P;F%M95LG<W1A=&4G72`N("<B)SL-
M"B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'!A<F%M(#T]("=D97!E;F1E
M;F-Y)RD@>PT*("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S7V5X:7-T
M<R@G4$5!4E]#;VUM;VXG*2D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@
M<F5Q=6ER95]O;F-E("=014%2+T-O;6UO;BYP:'`G.PT*("`@("`@("`@("`@
M("`@("`@("!]#0H@("`@("`@("`@("`@("`@("`@(&EF("@A:6Y?87)R87DH
M)&EN9F];)VEN9F\G72T^9V5T4W1A=&4H*2P-"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@4$5!4E]#;VUM;VXZ.F)E='1E<E-T871E<R@D=&AI<RT^7V-O
M;F9I9RT^9V5T*"=P<F5F97)R961?<W1A=&4G*2P@=')U92DI*2![#0H@("`@
M("`@("`@("`@("`@("`@("`@("!I9B`H)&]P=&EO;F%L*2![#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@9&]N)W0@<W!I="!O=70@8V]N9G5S
M:6YG(&5R<F]R(&UE<W-A9V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O=VYL
M;V%D57)L*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>2@G<&%C:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&YA
M;65;)V-H86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*3L-"B`@
M("`@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M("`@("1V<R`]("<@=VET:&EN('!R969E<G)E9"!S=&%T92`B)R`N("1T:&ES
M+3Y?8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I("X-"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G(B<[#0H@("`@("`@("`@("`@("`@("`@
M('T@96QS92![#0H@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6-L87-S
M7V5X:7-T<R@G4$5!4E]$97!E;F1E;F-Y,B<I*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@<F5Q=6ER95]O;F-E("=014%2+T1E<&5N9&5N8WDR
M+G!H<"<[#0H@("`@("`@("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&]P=&EO;F%L*2![#0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@9&]N)W0@<W!I="!O=70@8V]N9G5S:6YG(&5R
M<F]R(&UE<W-A9V4-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]D;W=N;&]A9&5R+3Y?9V5T4&%C:V%G941O=VYL;V%D57)L
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@G<&%C
M:V%G92<@/3X@)'!N86UE6R=P86-K86=E)UTL#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=C:&%N;F5L)R`]/B`D<&YA;65;)V-H
M86YN96PG72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)W9E<G-I;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@("1V
M<R`](%!%05)?1&5P96YD96YC>3(Z.E]G971%>'1R85-T<FEN9R@D<&YA;64I
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@)&EN<W1E860@/2`G)SL-"B`@
M("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@("`@("1V<R`]("<@=VET:&EN('!R969E<G)E
M9"!S=&%T92`B)R`N("1T:&ES+3Y?8V]N9FEG+3YG970H#0H@("`@("`@("`@
M("`@("`@("`@("`@("`G<')E9F5R<F5D7W-T871E)RD@+B`G(B<[#0H@("`@
M("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&]P
M=&EO;G-;)W-O9G0G72DI('L-"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]D;W=N;&]A9&5R+3YL;V<H,2P@)U=!4DY)3D<Z(&9A:6QE9"!T;R!D;W=N
M;&]A9"`G("X@)'!N86UE6R=C:&%N;F5L)UT@+@T*("`@("`@("`@("`@("`@
M("`@("`@("`@)R\G("X@)'!N86UE6R=P86-K86=E)UT@+B`D=G,@+B`D:6YS
M=&5A9"D[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("\O
M(&1O=VYL;V%D('1H92!L871E<W0@<F5L96%S90T*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971086-K86=E1&]W;FQO
M8615<FPH#0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]
M/B`D<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E<G-I;VXG
M72DI.PT*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O
M+R!C;VYS=')U8W0@:&5L<&9U;"!E<G)O<B!M97-S86=E#0H@("`@("`@("`@
M("`@("`@:68@*&ES<V5T*"1P;F%M95LG=F5R<VEO;B==*2D@>PT*("`@("`@
M("`@("`@("`@("`@("`D=G,@/2`G+"!V97)S:6]N("(G("X@)'!N86UE6R=V
M97)S:6]N)UT@+B`G(B<[#0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES
M<V5T*"1P;F%M95LG<W1A=&4G72DI('L-"B`@("`@("`@("`@("`@("`@("`@
M)'9S(#T@)RP@<W1A8FEL:71Y("(G("X@)'!N86UE6R=S=&%T92==("X@)R(G
M.PT*("`@("`@("`@("`@("`@('T@96QS96EF("@D<&%R86T@/3T@)V1E<&5N
M9&5N8WDG*2![#0H@("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI
M<W1S*"=014%27T-O;6UO;B<I*2![#0H@("`@("`@("`@("`@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(O0V]M;6]N+G!H<"<[#0H@("`@("`@("`@
M("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@*"%I;E]A<G)A
M>2@D:6YF;ULG:6YF;R==+3YG9713=&%T92@I+`T*("`@("`@("`@("`@("`@
M("`@("`@("`@("!014%27T-O;6UO;CHZ8F5T=&5R4W1A=&5S*"1T:&ES+3Y?
M8V]N9FEG+3YG970H)W!R969E<G)E9%]S=&%T92<I+"!T<G5E*2DI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D;W!T:6]N86PI('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!D;VXG="!S<&ET(&]U="!C;VYF
M=7-I;F<@97)R;W(@;65S<V%G92P@86YD(&1O;B=T(&1I92!O;@T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O(&]P=&EO;F%L(&1E<"!F86EL=7)E
M(0T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V1O=VYL;V%D97(M/E]G971086-K86=E1&]W;FQO8615<FPH#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=P86-K86=E)R`]/B`D
M<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+`T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=F5R<VEO
M;B<@/3X@)&EN9F];)W9E<G-I;VXG72DI.PT*("`@("`@("`@("`@("`@("`@
M("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'9S(#T@)R!W:71H
M:6X@<')E9F5R<F5D('-T871E("(G("X@)'1H:7,M/E]C;VYF:6<M/F=E="@G
M<')E9F5R<F5D7W-T871E)RD@+@T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<B)SL-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"=014%27T1E
M<&5N9&5N8WDR)RDI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R
M97%U:7)E7V]N8V4@)U!%05(O1&5P96YD96YC>3(N<&AP)SL-"B`@("`@("`@
M("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@D;W!T:6]N86PI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!D;VXG="!S<&ET(&]U="!C;VYF=7-I;F<@97)R;W(@;65S<V%G92P@86YD
M(&1O;B=T(&1I92!O;@T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(&]P=&EO;F%L(&1E<"!F86EL=7)E(0T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V1O=VYL;V%D97(M/E]G971086-K86=E
M1&]W;FQO8615<FPH#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=P86-K86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G72P-"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V-H86YN96PG(#T^
M("1P;F%M95LG8VAA;FYE;"==+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E<G-I;VXG72DI
M.PT*("`@("`@("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@
M("`@("`@("`@)'9S(#T@4$5!4E]$97!E;F1E;F-Y,CHZ7V=E=$5X=')A4W1R
M:6YG*"1P;F%M92D[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("`D=G,@/2`G
M('=I=&AI;B!P<F5F97)R960@<W1A=&4@(B<@+B`D=&AI<RT^7V1O=VYL;V%D
M97(M/F-O;F9I9RT^9V5T*`T*("`@("`@("`@("`@("`@("`@("`@("`@)W!R
M969E<G)E9%]S=&%T92<I("X@)R(G.PT*("`@("`@("`@("`@("`@('T-"B`@
M("`@("`@("`@("`@("`D;W!T:6]N<R`]("1T:&ES+3Y?9&]W;FQO861E<BT^
M9V5T3W!T:6]N<R@I.PT*("`@("`@("`@("`@("`@("\O('1H:7,@:7,@;VYL
M>2!S970@8GD@=&AE(")D;W=N;&]A9"UA;&PB(&-O;6UA;F0-"B`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)VEG;F]R97!R969E<G)E9%]S
M=&%T92==*2D@>PT*("`@("`@("`@("`@("`@("`@("`D97)R(#T@4$5!4CHZ
M<F%I<V5%<G)O<B@-"B`@("`@("`@("`@("`@("`@("`@("`@("=&86EL960@
M=&\@9&]W;FQO860@)R`N("1T:&ES+3Y?<F5G:7-T<GDM/G!A<G-E9%!A8VMA
M9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87)R87DH)V-H86YN96PG(#T^("1P;F%M95LG8VAA;FYE;"==+"`G<&%C:V%G
M92<@/3X@)'!N86UE6R=P86-K86=E)UTI+`T*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T<G5E*0T*("`@("`@("`@("`@("`@("`@("`@("`@
M("X@)'9S("X-"B`@("`@("`@("`@("`@("`@("`@("`@("<L(&QA=&5S="!R
M96QE87-E(&ES('9E<G-I;VX@)R`N("1I;F9O6R=V97)S:6]N)UT@+@T*("`@
M("`@("`@("`@("`@("`@("`@("`@)RP@<W1A8FEL:71Y("(G("X@)&EN9F];
M)VEN9F\G72T^9V5T4W1A=&4H*2`N("<B+"!U<V4@(B<@+@T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G
M94YA;654;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@G8VAA;FYE;"<@/3X@)'!N86UE6R=C:&%N;F5L)UTL("=P86-K86=E
M)R`]/B`D<&YA;65;)W!A8VMA9V4G72P-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=F5R<VEO;B<@/3X@)&EN9F];)W9E<G-I;VXG72DI("X@)R(@
M=&\@:6YS=&%L;"<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@4$5!
M4E]$3U=.3$]!1$527U!!0TM!1T5?4U1!5$4I.PT*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@
M("`@("`@("`@)&5R<B`](%!%05(Z.G)A:7-E17)R;W(H#0H@("`@("`@("`@
M("`@("`@("`@("=&86EL960@=&\@9&]W;FQO860@)R`N("1T:&ES+3Y?<F5G
M:7-T<GDM/G!A<G-E9%!A8VMA9V5.86UE5&]3=')I;F<H#0H@("`@("`@("`@
M("`@("`@("`@("`@("!A<G)A>2@G8VAA;FYE;"<@/3X@)'!N86UE6R=C:&%N
M;F5L)UTL("=P86-K86=E)R`]/B`D<&YA;65;)W!A8VMA9V4G72DL#0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=')U92D-"B`@("`@("`@("`@("`@
M("`@("`@("X@)'9S("X-"B`@("`@("`@("`@("`@("`@("`@)RP@;&%T97-T
M(')E;&5A<V4@:7,@=F5R<VEO;B`G("X@)&EN9F];)W9E<G-I;VXG72`N#0H@
M("`@("`@("`@("`@("`@("`@("<L('-T86)I;&ET>2`B)R`N("1I;F9O6R=I
M;F9O)UTM/F=E=%-T871E*"D@+B`G(BP@=7-E("(G("X-"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/E]R96=I<W1R>2T^<&%R<V5D4&%C:V%G94YA;654
M;U-T<FEN9R@-"B`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=C:&%N
M;F5L)R`]/B`D<&YA;65;)V-H86YN96PG72P@)W!A8VMA9V4G(#T^("1P;F%M
M95LG<&%C:V%G92==+`T*("`@("`@("`@("`@("`@("`@("`@("`@)W9E<G-I
M;VXG(#T^("1I;F9O6R=V97)S:6]N)UTI*2`N("<B('1O(&EN<W1A;&PG*3L-
M"B`@("`@("`@("`@("`@("!R971U<FX@)&5R<CL-"B`@("`@("`@("`@('T-
M"B`@("`@("`@?0T*("`@("`@("!R971U<FX@)&EN9F\[#0H@("`@?0T*?0T*
M/SX-"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]&:6QE+T-35BYP:'``````````````
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0P-C`P(#$P-3$U
M-#,T,3,T(#`R,#4P-0`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O
M<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($9I
M;&4Z.D-35@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%
M3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55))
M.@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@
M>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E
M;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W
M96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@($9I;&4*("H@0'!A8VMA9V4@("`@($9I;&4*("H@0&%U
M=&AO<B`@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@
M0&%U=&AO<B`@("`@($AE;&=I(-YO<FUA<B`\9'5F=7I`<&AP+FYE=#X*("H@
M0&-O<'ER:6=H="`@(#(P,#0M,C`P-2!4:&4@075T:&]R<PH@*B!`;&EC96YS
M92`@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@0U-6+G!H
M<"QV(#$N,C0@,C`P-2\P."\P.2`P.#HQ-CHP,B!D=69U>B!%>'`@)`H@*B!`
M;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T9I;&4*
M("HO"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O;F-E("=&
M:6QE+G!H<"<["@HO*BH**B!&:6QE(&-L87-S(&9O<B!H86YD;&EN9R!#4U8@
M9FEL97,@*$-O;6UA(%-E<&%R871E9"!686QU97,I+"!A(&-O;6UO;B!F;W)M
M870**B!F;W(@97AC:&%N9VEN9R!D871A+@HJ"BH@5$]$3SH**B`@+2!5<V%G
M92!E>&%M<&QE(&%N9"!$;V,**B`@+2!5<V4@9V5T4&]I;G1E<B@I(&EN(&1I
M<V-O=F5R1F]R;6%T"BH@("T@061D(&$@;&EN92!C;W5N=&5R(&9O<B!B96EN
M9R!A8FQE('1O(&]U='!U="!B971T97(@97)R;W(@<F5P;W)T<PHJ("`M(%-T
M;W)E('1H92!L87-T(&5R<F]R(&EN($=,3T)!3%,@86YD(&%D9"!&:6QE7T-3
M5CHZ9V5T3&%S=$5R<F]R*"D**@HJ(%=I<V@Z"BH@("T@3W1H97(@;65T:&]D
M<R!L:6ME(')E861!;&PH*2P@=W)I=&5!;&PH*2P@;G5M1FEE;&1S*"DL(&YU
M;5)O=W,H*0HJ("`M(%1R>2!T;R!D971E8W0@:68@82!#4U8@:&%S(&AE861E
M<B!O<B!N;W0@:6X@9&ES8V]V97)&;W)M870H*0HJ"BH@2VYO=VX@0G5G<SH*
M*B`H=&AE>2!H87,@8F5E;B!A;F%L>7IE9"!B=70@9F]R('1H92!M;VUE;G0@
M=&AE(&EM<&%C="!I;B!T:&4@<W!E960@9F]R"BH@('!R;W!E<FQY(&AA;F1L
M92!T:&ES('5N8V]M;6]N(&-A<V5S(&ES('1O;R!H:6=H(&%N9"!W;VXG="!B
M92!S=7!P;W)T960I"BH@("T@02!F:65L9"!W:&EC:"!I<R!C;VUP;W-E9"!O
M;FQY(&)Y(&$@<VEN9VQE('%U;W1E9"!S97!A<F%T;W(@*&EE("T^(#LB.R([
M*0HJ("`@(&ES(&YO="!H86YD;&5D('!R;W!E<FQY"BH@("T@5VAE;B!T:&5R
M92!I<R!E>&%C=&QY(&]N92!F:65L9"!M:6YU<R!T:&%N('1H92!E>'!E8W1E
M9"!N=6UB97(@86YD('1H97)E"BH@("`@:7,@82!F:65L9"!W:71H(&$@<V5P
M87)A=&]R(&EN<VED92P@=&AE('!A<G-E<B!W:6QL('1H<F]W('1H92`B=W)O
M;F<@8V]U;G0B(&5R<F]R"BH**B!`875T:&]R(%1O;6%S(%8N5BY#;W@@/&-O
M>$!I9&5C;F5T+F-O;3X**B!`875T:&]R("`@("`@2&5L9VD@WF]R;6%R(#QD
M=69U>D!P:'`N;F5T/@HJ($!P86-K86=E($9I;&4**B\*8VQA<W,@1FEL95]#
M4U8*>PH@("`@+RHJ"B`@("`J(%1H:7,@<F%I<V5%<G)O<B!M971H;V0@=V]R
M:W,@:6X@82!D:69F97)E;G0@=V%Y+B!)="!W:6QL(&%L=V%Y<R!R971U<FX*
M("`@("H@9F%L<V4@*&%N(&5R<F]R(&]C8W5R<F5D*2!B=70@:70@=VEL;"!C
M86QL(%!%05(Z.G)A:7-E17)R;W(H*2!B969O<F4*("`@("H@:70N($EF(&YO
M(&1E9F%U;'0@4$5!4B!G;&]B86P@:&%N9&QE<B!I<R!S970L('=I;&P@=')I
M9V=E<B!A;B!E<G)O<BX*("`@("H*("`@("H@0'!A<F%M('-T<FEN9R`D97)R
M;W(@5&AE(&5R<F]R(&UE<W-A9V4*("`@("H@0')E='5R;B!B;V]L(&%L=V%Y
M<R!F86QS90H@("`@*B\*("`@(&9U;F-T:6]N(')A:7-E17)R;W(H)&5R<F]R
M*0H@("`@>PH@("`@("`@("\O($EF(&$@9&5F875L="!014%2($5R<F]R(&AA
M;F1L97(@:7,@;F]T('-E="!T<FEG9V5R('1H92!E<G)O<@H@("`@("`@("\O
M(%A86"!!9&0@82!014%2.CII<U-E=$AA;F1L97(H*2!M971H;V0_"B`@("`@
M("`@:68@*"1'3$]"04Q36R=?4$5!4E]D969A=6QT7V5R<F]R7VUO9&4G72`]
M/2!014%27T524D]27U)%5%523BD@>PH@("`@("`@("`@("!014%2.CIR86ES
M945R<F]R*"1E<G)O<BP@;G5L;"P@4$5!4E]%4E)/4E]44DE'1T52+"!%7U53
M15)?5T%23DE.1RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@4$5!
M4CHZ<F%I<V5%<G)O<B@D97)R;W(I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`J($-H96-K<R!T:&4@8V]N
M9FEG=7)A=&EO;B!G:79E;B!B>2!T:&4@=7-E<@H@("`@*@H@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("H@0'!A<F%M('-T<FEN9R`F)&5R<F]R(%1H92!E
M<G)O<B!W:6QL(&)E('=R:71T96X@:&5R92!I9B!A;GD*("`@("H@0'!A<F%M
M(&%R<F%Y("`F)&-O;F8@(%1H92!C;VYF:6=U<F%T:6]N(&%S<V]C(&%R<F%Y
M"B`@("`J($!R971U<FX@<W1R:6YG(&5R<F]R("`@(%)E='5R;G,@82!E<G)O
M<B!M97-S86=E"B`@("`J+PH@("`@9G5N8W1I;VX@7V-O;F8H)B1E<G)O<BP@
M)B1C;VYF*0H@("`@>PH@("`@("`@("\O(&-H96-K(&-O;F8*("`@("`@("!I
M9B`H(6ES7V%R<F%Y*"1C;VYF*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R(#T@)TEN=F%L:60@8V]N9FEG=7)A=&EO;B<["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES<V5T*"1C;VYF6R=F:65L9',G72D@?'P@(6ES7VYU;65R
M:6,H)&-O;F9;)V9I96QD<R==*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R
M<F]R(#T@)U1H92!N=6UB97(@;V8@9FEE;&1S(&UU<W0@8F4@;G5M97)I8R`H
M=&AE(")F:65L9',B(&ME>2DG.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=S97`G72DI('L*("`@("`@("`@("`@:68@*'-T<FQE;B@D
M8V]N9ELG<V5P)UTI("$](#$I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M97)R;W(@/2`G4V5P87)A=&]R(&-A;B!O;FQY(&)E(&]N92!C:&%R)SL*("`@
M("`@("`@("`@?0H@("`@("`@('T@96QS96EF("@D8V]N9ELG9FEE;&1S)UT@
M/B`Q*2!["B`@("`@("`@("`@(')E='5R;B`D97)R;W(@/2`G36ES<VEN9R!S
M97!A<F%T;W(@*'1H92`B<V5P(B!K97DI)SL*("`@("`@("!]"@H@("`@("`@
M(&EF("AI<W-E="@D8V]N9ELG<75O=&4G72DI('L*("`@("`@("`@("`@:68@
M*'-T<FQE;B@D8V]N9ELG<75O=&4G72D@(3T@,2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1E<G)O<B`]("=4:&4@<75O=&4@8VAA<B!M=7-T(&)E(&]N
M92!C:&%R("AT:&4@(G%U;W1E(B!K97DI)SL*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1C;VYF6R=Q=6]T92==(#T@;G5L
M;#L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-S970H)&-O;F9;)V-R;&8G
M72DI('L*("`@("`@("`@("`@)&-O;F9;)V-R;&8G72`](")<;B(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C;VYF6R=E;VPR=6YI>"==*2D@
M>PH@("`@("`@("`@("`D8V]N9ELG96]L,G5N:7@G72`]('1R=64["B`@("`@
M("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!2971U<FX@;W(@8W)E871E('1H
M92!F:6QE(&1E<V-R:7!T;W(@87-S;V-I871E9"!W:71H(&$@9FEL90H@("`@
M*@H@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE(%1H92!N86UE(&]F('1H92!F
M:6QE"B`@("`J($!P87)A;2!A<G)A>2`@)B1C;VYF(%1H92!C;VYF:6=U<F%T
M:6]N"B`@("`J($!P87)A;2!S=')I;F<@)&UO9&4@5&AE(&]P96X@;F]D92`H
M97@Z($9)3$5?34]$15]214%$(&]R($9)3$5?34]$15]74DE412D*("`@("H@
M0'!A<F%M(&)O;VQE86X@)')E<V5T(&EF('!A<W-E9"!A<R!T<G5E(&%N9"!R
M97-O=7)C92!F;W(@=&AE(&9I;&4@97AI<W1S"B`@("`J("`@("`@("`@("`@
M("`@("`@("`@("!T:&%N('1H92!F:6QE('!O:6YT97(@=VEL;"!B92!M;W9E
M9"!T;R!T:&4@8F5G:6YN:6YG"B`@("`J"B`@("`J($!R971U<FX@;6EX960@
M02!F:6QE(')E<V]U<F-E(&]R(&9A;'-E"B`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&]I;G1E<B@D9FEL92P@)B1C;VYF+"`D;6]D92`]($9)3$5?34]$15]2
M14%$+"`D<F5S970@/2!F86QS92D*("`@('L*("`@("`@("!S=&%T:6,@)')E
M<V]U<F-E<R`@/2!A<G)A>2@I.PH@("`@("`@('-T871I8R`D8V]N9FEG.PH@
M("`@("`@(&EF("AI<W-E="@D<F5S;W5R8V5S6R1F:6QE72DI('L*("`@("`@
M("`@("`@)&-O;F8@/2`D8V]N9FEG.PH@("`@("`@("`@("!I9B`H)')E<V5T
M*2!["B`@("`@("`@("`@("`@("!F<V5E:R@D<F5S;W5R8V5S6R1F:6QE72P@
M,"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@<F5T=7)N("1R97-O=7)C
M97-;)&9I;&5=.PH@("`@("`@('T*("`@("`@("!&:6QE7T-35CHZ7V-O;F8H
M)&5R<F]R+"`D8V]N9BD["B`@("`@("`@:68@*"1E<G)O<BD@>PH@("`@("`@
M("`@("!R971U<FX@1FEL95]#4U8Z.G)A:7-E17)R;W(H)&5R<F]R*3L*("`@
M("`@("!]"B`@("`@("`@)&-O;F9I9R`]("1C;VYF.PH@("`@("`@(%!%05(Z
M.G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@
M("`D9G`@/2`F1FEL93HZ7V=E=$9I;&50;VEN=&5R*"1F:6QE+"`D;6]D92D[
M"B`@("`@("`@4$5!4CHZ<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1F<"DI('L*("`@("`@("`@("`@<F5T=7)N($9I
M;&5?0U-6.CIR86ES945R<F]R*"1F<"D["B`@("`@("`@?0H@("`@("`@("1R
M97-O=7)C97-;)&9I;&5=(#T@)&9P.PH*("`@("`@("!I9B`H)&UO9&4@/3T@
M1DE,15]-3T1%7U)%040@)B8@(65M<'1Y*"1C;VYF6R=H96%D97(G72DI('L*
M("`@("`@("`@("`@:68@*"%&:6QE7T-35CHZ<F5A9"@D9FEL92P@)&-O;F8I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1F<#L*("`@('T*"B`@("`O
M*BH*("`@("H@56YQ=6]T92!D871A"B`@("`J"B`@("`J($!P87)A;2!S=')I
M;F<@)&9I96QD(%1H92!D871A('1O('5N<75O=&4*("`@("H@0'!A<F%M('-T
M<FEN9R`D<75O=&4@5&AE('%U;W1E(&-H87(*("`@("H@0')E='5R;B!S=')I
M;F<@=&AE('5N<75O=&5D(&1A=&$*("`@("HO"B`@("!F=6YC=&EO;B!U;G%U
M;W1E*"1F:65L9"P@)'%U;W1E*0H@("`@>PH@("`@("`@("\O(%1R:6T@9FER
M<W0@=&AE('-T<FEN9RX*("`@("`@("`D9FEE;&0@/2!T<FEM*"1F:65L9"D[
M"B`@("`@("`@)'%U;W1E(#T@=')I;2@D<75O=&4I.PH*("`@("`@("`O+R!)
M;F-A<V4@;G5L;"!F:65L9',@*&9O<FTZ(#L[*0H@("`@("`@(&EF("@A<W1R
M;&5N*"1F:65L9"DI('L*("`@("`@("`@("`@<F5T=7)N("1F:65L9#L*("`@
M("`@("!]"@H@("`@("`@(&EF("@D<75O=&4@)B8@)&9I96QD>S!](#T]("1Q
M=6]T92`F)B`D9FEE;&1[<W1R;&5N*"1F:65L9"DM,7T@/3T@)'%U;W1E*2![
M"B`@("`@("`@("`@(')E='5R;B!S=6)S='(H)&9I96QD+"`Q+"`M,2D["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D9FEE;&0["B`@("!]"@H@("`@+RHJ
M"B`@("`J(%)E861S(&$@<F]W(&]F(&1A=&$@87,@86X@87)R87D@9G)O;2!A
M($-35B!F:6QE+B!)="=S(&%B;&4@=&\*("`@("H@<F5A9"!M96UO(&9I96QD
M<R!W:71H(&UU;'1I;&EN92!D871A+@H@("`@*@H@("`@*B!`<&%R86T@<W1R
M:6YG("1F:6QE("`@5&AE(&9I;&5N86UE('=H97)E('1O('=R:71E('1H92!D
M871A"B`@("`J($!P87)A;2!A<G)A>2`@)B1C;VYF("`@5&AE(&-O;F9I9W5R
M871I;VX@;V8@=&AE(&1E<W0@0U-6"B`@("`J"B`@("`J($!R971U<FX@;6EX
M960@07)R87D@=VET:"!T:&4@9&%T82!R96%D(&]R(&9A;'-E(&]N(&5R<F]R
M+VYO(&UO<F4@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N(')E8611=6]T960H
M)&9I;&4L("8D8V]N9BD*("`@('L*("`@("`@("!I9B`H(21F<"`]($9I;&5?
M0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N9BP@1DE,15]-3T1%7U)%040I
M*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@
M("`@("1B=69F(#T@)&,@/2`G)SL*("`@("`@("`D<F5T("`](&%R<F%Y*"D[
M"B`@("`@("`@)&D@/2`Q.PH@("`@("`@("1I;E]Q=6]T92`](&9A;'-E.PH@
M("`@("`@("1Q=6]T92`]("1C;VYF6R=Q=6]T92==.PH@("`@("`@("1F(#T@
M)&-O;F9;)V9I96QD<R==.PH@("`@("`@("1E;VPR=6YI>"`]("1C;VYF6R=E
M;VPR=6YI>"==.PH@("`@("`@('=H:6QE("@H)&-H(#T@9F=E=&,H)&9P*2D@
M(3T](&9A;'-E*2!["B`@("`@("`@("`@("1P<F5V(#T@)&,["B`@("`@("`@
M("`@("1C(#T@)&-H.PH@("`@("`@("`@("`O+R!#;VUM;VX@8V%S90H@("`@
M("`@("`@("!I9B`H)&,@(3T@)'%U;W1E("8F("1C("$]("1C;VYF6R=S97`G
M72`F)B`D8R`A/2`B7&XB("8F("1C("$](")<<B(I('L*("`@("`@("`@("`@
M("`@("1B=69F("X]("1C.PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%-T87)T('%U;W1E+@H@("`@
M("`@("`@("!I9B`H)'%U;W1E("8F("1C(#T]("1Q=6]T92`F)@H@("`@("`@
M("`@("`@("`@*"1P<F5V(#T]("1C;VYF6R=S97`G72!\?"`D<')E=B`]/2`B
M7&XB('Q\("1P<F5V(#T]/2!N=6QL('Q\"B`@("`@("`@("`@("`@("`@)'!R
M978@/3T@(EQR(B!\?"`D<')E=B`]/2`G)RDI"B`@("`@("`@("`@('L*("`@
M("`@("`@("`@("`@("1I;E]Q=6]T92`]('1R=64["B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("@D:6Y?<75O=&4I('L*("`@("`@("`@("`@("`@
M("\O(%=H96X@96YD<R!Q=6]T90H@("`@("`@("`@("`@("`@:68@*"1C(#T]
M("1C;VYF6R=S97`G72`F)B`D<')E=B`]/2`D8V]N9ELG<75O=&4G72D@>PH@
M("`@("`@("`@("`@("`@("`@("1I;E]Q=6]T92`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1C(#T](")<;B(@?'P@)&,@/3T@(EQR(BD@
M>PH@("`@("`@("`@("`@("`@("`@("1S=6(@/2`H)'!R978@/3T@(EQR(BD@
M/R`R(#H@,3L*("`@("`@("`@("`@("`@("`@("!I9B`H*'-T<FQE;B@D8G5F
M9BD@/CT@)'-U8BD@)B8*("`@("`@("`@("`@("`@("`@("`@("`@*"1B=69F
M>W-T<FQE;B@D8G5F9BD@+2`D<W5B?2`]/2`D<75O=&4I*0H@("`@("`@("`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@("`@("`@("`@)&EN7W%U;W1E
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H(21I;E]Q=6]T
M92`F)B`H)&,@/3T@)&-O;F9;)W-E<"==('Q\("1C(#T](")<;B(@?'P@)&,@
M/3T@(EQR(BD@)B8@)'!R978@(3T@)R<I('L*("`@("`@("`@("`@("`@("\O
M($UO<F4@9FEE;&1S('1H86X@97AP96-T960*("`@("`@("`@("`@("`@(&EF
M("@H)&,@/3T@)&-O;F9;)W-E<"==*2`F)B`H*&-O=6YT*"1R970I("L@,2D@
M/3T@)&8I*2!["B`@("`@("`@("`@("`@("`@("`@+R\@4V5E:R!T:&4@<&]I
M;G1E<B!I;G1O(&QI;F5B<F5A:R!C:&%R86-T97(N"B`@("`@("`@("`@("`@
M("`@("`@=VAI;&4@*'1R=64I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&,@/2!F9V5T8R@D9G`I.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`@
M*"1C(#T](")<;B(@?'P@)&,@/3T@(EQR(BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@("`@("\O
M($EN<V5R="!L87-T(&9I96QD('9A;'5E+@H@("`@("`@("`@("`@("`@("`@
M("1R971;72`]($9I;&5?0U-6.CIU;G%U;W1E*"1B=69F+"`D<75O=&4I.PH@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D<F5T.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("\O($QE<W,@9FEE;&1S('1H86X@97AP
M96-T960*("`@("`@("`@("`@("`@(&EF("@H)&,@/3T@(EQN(B!\?"`D8R`]
M/2`B7'(B*2`F)B`H)&D@(3T@)&8I*2!["B`@("`@("`@("`@("`@("`@("`@
M+R\@26YS97)T(&QA<W0@9FEE;&0@=F%L=64N"B`@("`@("`@("`@("`@("`@
M("`@)')E=%M=(#T@1FEL95]#4U8Z.G5N<75O=&4H)&)U9F8L("1Q=6]T92D[
M"@H@("`@("`@("`@("`@("`@("`@("\O(%!A:7(@=&AE(&%R<F%Y(&5L96UE
M;G1S('1O(&9I96QD<R!C;W5N="X*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@87)R87E?;65R9V4H)')E="P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@87)R87E?9FEL;"AC;W5N="@D<F5T*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("@D
M9B`M(#$I("T@*&-O=6YT*"1R970I("T@,2DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)RD*("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M("`@(&EF("@D<')E=B`]/2`B7'(B*2!["B`@("`@("`@("`@("`@("`@("`@
M)&)U9F8@/2!S=6)S='(H)&)U9F8L(#`L("TQ*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`O+R!#;VYV97)T($5/3"!C:&%R86-T97(@
M=&\@56YI>"!%3TP@*$Q&*2X*("`@("`@("`@("`@("`@(&EF("@D96]L,G5N
M:7@I('L*("`@("`@("`@("`@("`@("`@("`D8G5F9B`]('!R96=?<F5P;&%C
M92@G+RA<<EQN?%QR*20O)RP@(EQN(BP@)&)U9F8I.PH@("`@("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@("`@("1R971;72`]($9I;&5?0U-6.CIU;G%U
M;W1E*"1B=69F+"`D<75O=&4I.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT
M*"1R970I(#T]("1F*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1R
M970["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D8G5F9B`]
M("<G.PH@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@(&-O
M;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1B=69F("X]("1C
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@(69E;V8H)&9P*2`_("1R970@
M.B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("H@4F5A9',@82`B<F]W(B!F
M<F]M(&$@0U-6(&9I;&4@86YD(')E='5R;B!I="!A<R!A;B!A<G)A>0H@("`@
M*@H@("`@*B!`<&%R86T@<W1R:6YG("1F:6QE(%1H92!#4U8@9FEL90H@("`@
M*B!`<&%R86T@87)R87D@("8D8V]N9B!4:&4@8V]N9FEG=7)A=&EO;B!O9B!T
M:&4@9&5S="!#4U8*("`@("H*("`@("H@0')E='5R;B!M:7AE9"!!<G)A>2!O
M<B!F86QS90H@("`@*B\*("`@(&9U;F-T:6]N(')E860H)&9I;&4L("8D8V]N
M9BD*("`@('L*("`@("`@("!I9B`H(21F<"`]($9I;&5?0U-6.CIG9710;VEN
M=&5R*"1F:6QE+"`D8V]N9BP@1DE,15]-3T1%7U)%040I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@+R\@5&AE('-I
M>F4@:7,@;&EM:71E9"!T;R`T2PH@("`@("`@(&EF("@A)&QI;F4@("`](&9G
M971S*"1F<"P@-#`Y-BDI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@)&9I96QD<R`]("1C;VYF6R=F:65L9',G72`]
M/2`Q(#\@87)R87DH)&QI;F4I(#H@97AP;&]D92@D8V]N9ELG<V5P)UTL("1L
M:6YE*3L*"B`@("`@("`@:68@*"1C;VYF6R=Q=6]T92==*2!["B`@("`@("`@
M("`@("1L87-T(#TF("1F:65L9'-;8V]U;G0H)&9I96QD<RD@+2`Q73L*("`@
M("`@("`@("`@+R\@1F%L;&)A8VL@=&\@<F5A9"!T:&4@;&EN92!W:71H(')E
M8611=6]T960@=VAE;B!G=65S<PH@("`@("`@("`@("`O+R!T:&%T('1H92!S
M:6UP;&4@97AP;&]D92!W;VXG="!W;W)K(')I9VAT"B`@("`@("`@("`@(&EF
M("@H)&QA<W1[<W1R;&5N*"1L87-T*2`M(#%](#T](")<;B(*("`@("`@("`@
M("`@("`@("8F("1L87-T>S!](#T]("1C;VYF6R=Q=6]T92=="B`@("`@("`@
M("`@("`@("`F)B`D;&%S='MS=')L96XH<G1R:6TH)&QA<W0I*2`M(#%]("$]
M("1C;VYF6R=Q=6]T92==*0H@("`@("`@("`@("`@("`@?'P*("`@("`@("`@
M("`@("`@("AC;W5N="@D9FEE;&1S*2`A/2`D8V]N9ELG9FEE;&1S)UTI"B`@
M("`@("`@("`@("`@("`O+R!86%@@<&5R:&%P<R!T:&5R92!I<R!A('-E<&%R
M871O<B!I;G-I9&4@82!Q=6]T960@9FEE;&0*("`@("`@("`@("`@("`@("\O
M<')E9U]M871C:"@B?'LD8V]N9ELG<75O=&4G77TN*GLD8V]N9ELG<V5P)UU]
M+BI[)&-O;F9;)W%U;W1E)UU]?%4B+"`D;&EN92D*("`@("`@("`@("`@("`@
M("D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@9G-E96LH)&9P+"`M
M,2`J('-T<FQE;B@D;&EN92DL(%-%14M?0U52*3L*("`@("`@("`@("`@("`@
M(')E='5R;B!&:6QE7T-35CHZ<F5A9%%U;W1E9"@D9FEL92P@)&-O;F8I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&QA<W0@/2!R
M=')I;2@D;&%S="D["B`@("`@("`@("`@("`@("!F;W)E86-H("@D9FEE;&1S
M(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("`@("`@("`@)&9I96QD<ULD
M:UT@/2!&:6QE7T-35CHZ=6YQ=6]T92@D=BP@)&-O;F9;)W%U;W1E)UTI.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@
M("`@("!I9B`H8V]U;G0H)&9I96QD<RD@(3T@)&-O;F9;)V9I96QD<R==*2![
M"B`@("`@("`@("`@($9I;&5?0U-6.CIR86ES945R<F]R*")296%D('=R;VYG
M(&9I96QD<R!N=6UB97(@8V]U;G0Z("<B+B!C;W5N="@D9FEE;&1S*2`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)R!E>'!E8W1E9"`B
M+B1C;VYF6R=F:65L9',G72D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&9I96QD<SL*("`@('T*"B`@("`O
M*BH*("`@("H@26YT97)N86P@=7-E(&]N;'DL('=I;&P@8F4@<F5M;W9E9"!I
M;B!T:&4@9G5T=7)E"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)'-T<B!4
M:&4@<W1R:6YG('1O(&1E8G5G"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M*B\*("`@(&9U;F-T:6]N(%]D8F="=69F*"1S='(I"B`@("!["B`@("`@("`@
M:68@*'-T<G!O<R@D<W1R+"`B7'(B*2`A/3T@9F%L<V4I('L*("`@("`@("`@
M("`@)'-T<B`]('-T<E]R97!L86-E*")<<B(L(")?<E\B+"`D<W1R*3L*("`@
M("`@("!]"B`@("`@("`@:68@*'-T<G!O<R@D<W1R+"`B7&XB*2`A/3T@9F%L
M<V4I('L*("`@("`@("`@("`@)'-T<B`]('-T<E]R97!L86-E*")<;B(L(")?
M;E\B+"`D<W1R*3L*("`@("`@("!]"B`@("`@("`@:68@*'-T<G!O<R@D<W1R
M+"`B7'0B*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)'-T<B`]('-T<E]R
M97!L86-E*")<="(L(")?=%\B+"`D<W1R*3L*("`@("`@("!]"B`@("`@("`@
M96-H;R`B8G5F9CH@*"1S='(I7&XB.PH@("`@?0H*("`@("\J*@H@("`@*B!7
M<FET97,@82!S=')U8R`H87)R87DI(&EN(&$@9FEL92!A<R!#4U8*("`@("H*
M("`@("H@0'!A<F%M('-T<FEN9R`D9FEL92`@(%1H92!F:6QE;F%M92!W:&5R
M92!T;R!W<FET92!T:&4@9&%T80H@("`@*B!`<&%R86T@87)R87D@("1F:65L
M9',@3W)D97)E9"!A<G)A>2!W:71H('1H92!D871A"B`@("`J($!P87)A;2!A
M<G)A>2`@)B1C;VYF("`@5&AE(&-O;F9I9W5R871I;VX@;V8@=&AE(&1E<W0@
M0U-6"B`@("`J"B`@("`J($!R971U<FX@8F]O;"!4<G5E(&]N('-U8V-E<W,@
M9F%L<V4@;W1H97)W:7-E"B`@("`J+PH@("`@9G5N8W1I;VX@=W)I=&4H)&9I
M;&4L("1F:65L9',L("8D8V]N9BD*("`@('L*("`@("`@("!I9B`H(21F<"`]
M($9I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N9BP@1DE,15]-3T1%
M7U=2251%*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M?0H@("`@("`@(&EF("AC;W5N="@D9FEE;&1S*2`A/2`D8V]N9ELG9FEE;&1S
M)UTI('L*("`@("`@("`@("`@1FEL95]#4U8Z.G)A:7-E17)R;W(H(E=R;VYG
M(&9I96QD<R!N=6UB97(@8V]U;G0Z("<B+B!C;W5N="@D9FEE;&1S*2`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B)R!E>'!E8W1E9"`B
M+B1C;VYF6R=F:65L9',G72D["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@('T*("`@("`@("`D=W)I=&4@/2`G)SL*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"!C;W5N="@D9FEE;&1S*3L@)&DK*RD@>PH@("`@("`@("`@
M("!I9B`H(6ES7VYU;65R:6,H)&9I96QD<ULD:5TI("8F("1C;VYF6R=Q=6]T
M92==*2!["B`@("`@("`@("`@("`@("`D=W)I=&4@+CT@)&-O;F9;)W%U;W1E
M)UT@+B`D9FEE;&1S6R1I72`N("1C;VYF6R=Q=6]T92==.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'=R:71E("X]("1F:65L9'-;
M)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D:2`\("AC;W5N
M="@D9FEE;&1S*2`M(#$I*2!["B`@("`@("`@("`@("`@("`D=W)I=&4@+CT@
M)&-O;F9;)W-E<"==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)'=R:71E("X]("1C;VYF6R=C<FQF)UT["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@:68@*"%F=W)I=&4H)&9P+"`D=W)I=&4I*2![
M"B`@("`@("`@("`@(')E='5R;B!&:6QE7T-35CHZ<F%I<V5%<G)O<B@G0V%N
M(&YO="!W<FET92!T;R!F:6QE)RD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@*B!$:7-C;W9E<B!T:&4@9F]R
M;6%T(&]F(&$@0U-6(&9I;&4@*'1H92!N=6UB97(@;V8@9FEE;&1S+"!T:&4@
M<V5P87)A=&]R"B`@("`J(&%N9"!I9B!I="!Q=6]T92!S=')I;F<@9FEE;&1S
M*0H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG('1H92!#4U8@9FEL92!N86UE
M"B`@("`J($!P87)A;2!A<G)A>2!E>'1R82!S97!A<F%T;W)S('1H870@<VAO
M=6QD(&)E(&-H96-K960@9F]R+@H@("`@*B!`<F5T=7)N(&UI>&5D($%S<V]C
M(&%R<F%Y(&]R(&9A;'-E"B`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]V97)&
M;W)M870H)&9I;&4L("1E>'1R85-E<',@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(&EF("@A)&9P(#T@0&9O<&5N*"1F:6QE+"`G<B<I*2!["B`@("`@("`@
M("`@(')E='5R;B!&:6QE7T-35CHZ<F%I<V5%<G)O<B@B0V]U;&0@;F]T(&]P
M96X@9FEL93H@)&9I;&4B*3L*("`@("`@("!]"B`@("`@("`@)'-E<',@/2!A
M<G)A>2@B7'0B+"`G.R<L("<Z)RP@)RPG*3L*("`@("`@("`D<V5P<R`](&%R
M<F%Y7VUE<F=E*"1S97!S+"`D97AT<F%397!S*3L*("`@("`@("`D;6%T8VAE
M<R`](&%R<F%Y*"D["@H@("`@("`@("\O(%-E="!A=71O(&1E=&5C="!L:6YE
M(&5N9&EN9R!F;W(@36%C($5/3"!S=7!P;W)T(&EF(#P@4$A0(#0N,RXP+@H@
M("`@("`@("1P:'!V97(@/2!V97)S:6]N7V-O;7!A<F4H)S0N,RXP)RP@<&AP
M=F5R<VEO;B@I+"`G/"<I.PH@("`@("`@(&EF("@D<&AP=F5R*2!["B`@("`@
M("`@("`@("1O;&1I;FD@/2!I;FE?9V5T*"=A=71O7V1E=&5C=%]L:6YE7V5N
M9&EN9W,G*3L*("`@("`@("`@("`@:6YI7W-E="@G875T;U]D971E8W1?;&EN
M95]E;F1I;F=S)RP@)S$G*3L*("`@("`@("!]"@H@("`@("`@("\O(%1A:V4@
M=&AE(&9I<G-T(#$P(&QI;F5S(&%N9"!S=&]R92!T:&4@;G5M8F5R(&]F(&]C
M=7)R96YC97,*("`@("`@("`O+R!F;W(@96%C:"!S97!A<F%T;W(@:6X@96%C
M:"!L:6YE"@H@("`@("`@("1L:6YE<R`](&9I;&4H)&9I;&4I.PH@("`@("`@
M(&EF("AC;W5N="@D;&EN97,I(#X@,3`I('L*("`@("`@("`@("`@)&QI;F5S
M(#T@87)R87E?<VQI8V4H)&QI;F5S+"`P+"`Q,"D["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'!H<'9E<BD@>PH@("`@("`@("`@("!I;FE?<V5T*"=A=71O
M7V1E=&5C=%]L:6YE7V5N9&EN9W,G+"`D;VQD:6YI*3L*("`@("`@("!]"@H@
M("`@("`@(&9O<F5A8V@@*"1L:6YE<R!A<R`D;&EN92D@>PH@("`@("`@("`@
M("!F;W)E86-H("@D<V5P<R!A<R`D<V5P*2!["B`@("`@("`@("`@("`@("`D
M;6%T8VAE<ULD<V5P75M=(#T@<W5B<W1R7V-O=6YT*"1L:6YE+"`D<V5P*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&9I;F%L(#T@87)R
M87DH*3L*("`@("`@("`O+R!'<F]U<"!T:&4@<F5S=6QT<R!B>2!A;6]U;G0@
M;V8@97%U86P@;V-U<G)E;F-E<PH@("`@("`@(&9O<F5A8V@@*"1M871C:&5S
M(&%S("1S97`@/3X@)')E<RD@>PH@("`@("`@("`@("`D=&EM97,@/2!A<G)A
M>2@I.PH@("`@("`@("`@("`D=&EM97-;,%T@/2`P.PH@("`@("`@("`@("!F
M;W)E86-H("@D<F5S(&%S("1K(#T^("1N=6TI('L*("`@("`@("`@("`@("`@
M(&EF("@D;G5M(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("1T:6UE<ULD
M;G5M72`]("AI<W-E="@D=&EM97-;)&YU;5TI*2`_("1T:6UE<ULD;G5M72`K
M(#$@.B`Q.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&%R<V]R="@D=&EM97,I.PH*("`@("`@("`@("`@+R\@57-E(&UA
M>"!F:65L9',@8V]U;G0N"B`@("`@("`@("`@("1F:65L9'-;)'-E<%T@/2!M
M87@H87)R87E?9FQI<"@D=&EM97,I*3L*("`@("`@("`@("`@)&%M;W5N=%LD
M<V5P72`]("1T:6UE<UMK97DH)'1I;65S*5T["B`@("`@("`@?0H*("`@("`@
M("!A<G-O<G0H)&%M;W5N="D["B`@("`@("`@)'-E<"`@("`](&ME>2@D86UO
M=6YT*3L*"B`@("`@("`@)&-O;F9;)V9I96QD<R==(#T@)&9I96QD<ULD<V5P
M72`K(#$["B`@("`@("`@)&-O;F9;)W-E<"==("`@(#T@)'-E<#L*"B`@("`@
M("`@+R\@5&5S="!I9B!T:&5R92!A<F4@9FEE;&1S('=I=&@@<75O=&5S(&%R
M<F]U;F0@:6X@=&AE(&9I<G-T(#4@;&EN97,*("`@("`@("`D<75O=&5S(#T@
M)R)<)R<["B`@("`@("`@)'%U;W1E("`](&YU;&P["B`@("`@("`@:68@*&-O
M=6YT*"1L:6YE<RD@/B`U*2!["B`@("`@("`@("`@("1L:6YE<R`](&%R<F%Y
M7W-L:6-E*"1L:6YE<RP@,"P@-2D["B`@("`@("`@?0H*("`@("`@("!F;W)E
M86-H("@D;&EN97,@87,@)&QI;F4I('L*("`@("`@("`@("`@:68@*'!R96=?
M;6%T8V@H(GPD<V5P*%LD<75O=&5S72DN*BA;)'%U;W1E<UTI)'-E<'Q5(BP@
M)&QI;F4L("1M871C:"DI('L*("`@("`@("`@("`@("`@(&EF("@D;6%T8VA;
M,5T@/3T@)&UA=&-H6S)=*2!["B`@("`@("`@("`@("`@("`@("`@)'%U;W1E
M(#T@)&UA=&-H6S%=.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*")\7BA;)'%U;W1E<UTI+BHH6R1Q=6]T97-=*21S97![,"PQ
M?7PB+"`D;&EN92P@)&UA=&-H*0H@("`@("`@("`@("`@("`@?'P@<')E9U]M
M871C:"@B?"A;)'%U;W1E<UTI+BHH6R1Q=6]T97-=*21S97!<<R1\57,B+"`D
M;&EN92P@)&UA=&-H*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M:68@*"1M871C:%LQ72`]/2`D;6%T8VA;,ETI('L*("`@("`@("`@("`@("`@
M("`@("`D<75O=&4@/2`D;6%T8VA;,5T["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@)&-O;F9;)W%U;W1E)UT@/2`D<75O=&4["B`@("`@("`@
M9F-L;W-E*"1F<"D["B`@("`@("`@+R\@6%A8(%=H870@86)O=70@=')Y:6YG
M('1O(&1I<V-O=F5R('1H92`B:&5A9&5R(C\*("`@("`@("!R971U<FX@)&-O
M;F8["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&<F]N="!T;R!C86QL(&=E=%!O
M:6YT97(@86YD(&UO=FEN9R!T:&4@<F5S;W5R8V4@=&\@=&AE"B`@("`@*B!B
M96=I;FYI;F<@;V8@=&AE(&9I;&4*("`@("`J(%)E<V5T(&ET(&EF('EO=2!L
M:6ME+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&9I;&4@5&AE(&YA
M;64@;V8@=&AE(&9I;&4*("`@("`J($!P87)A;2!A<G)A>2`@)B1C;VYF(%1H
M92!C;VYF:6=U<F%T:6]N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1E(%1H
M92!O<&5N(&YO9&4@*&5X.B!&24Q%7TU/1$5?4D5!1"!O<B!&24Q%7TU/1$5?
M5U))5$4I"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@;VX@
M<W5C8V5S<R!F86QS92!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<V5T4&]I;G1E<B@D9FEL92P@)B1C;VYF+"`D;6]D92D*("`@('L*("`@
M("`@("!I9B`H(49I;&5?0U-6.CIG9710;VEN=&5R*"1F:6QE+"`D8V]N9BP@
M)&UO9&4L('1R=64I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0I]"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T9I;&4O571I;"YP:'``````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,S$U-#,@,3`U,34T,S0Q,S0@
M,#(P-S<U`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI
M9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@1FEL93HZ571I
M;`H@*B`*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E
M9V]R>2`@("!&:6QE"B`J($!P86-K86=E("`@("!&:6QE"B`J($!A=71H;W(@
M("`@("!-:6-H865L(%=A;&QN97(@/&UI:V5`<&AP+FYE=#X*("H@0&-O<'ER
M:6=H="`@(#(P,#0M,C`P-2!-:6-H865L(%=A;&QN97(*("H@0&QI8V5N<V4@
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("`@0U93.B`D260Z(%5T:6PN<&AP
M+'8@,2XR,2`R,#`U+S`X+S`Y(#`W.C4R.C$S(&UI:V4@17AP("0*("H@0&QI
M;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]&:6QE"B`J
M+PH*+RHJ(T`K"B`J(%-O<G1I;F<@0V]N<W1A;G1S"B`J+PID969I;F4H)T9)
M3$5?4T]25%].3TY%)RP@("`@,"D["F1E9FEN92@G1DE,15]33U)47U)%5D52
M4T4G+"`Q*3L*9&5F:6YE*"=&24Q%7U-/4E1?3D%-12<L("`@(#(I.PID969I
M;F4H)T9)3$5?4T]25%]325I%)RP@("`@-"D["F1E9FEN92@G1DE,15]33U)4
M7T1!5$4G+"`@("`X*3L*9&5F:6YE*"=&24Q%7U-/4E1?4D%.1$]-)RP@(#$V
M*3L*+RHJ(T`M*B\*"B\J*B-`*PH@*B!,:7-T:6YG($-O;G-T86YT<PH@*B\*
M9&5F:6YE*"=&24Q%7TQ)4U1?1DE,15,G+"`@(#$I.PID969I;F4H)T9)3$5?
M3$E35%]$25)3)RP@("`@,BD["F1E9FEN92@G1DE,15],25-47T1/5%,G+"`@
M("`T*3L*9&5F:6YE*"=&24Q%7TQ)4U1?04Q,)RP@("`@($9)3$5?3$E35%]&
M24Q%4R!\($9)3$5?3$E35%]$25)3('P@1DE,15],25-47T1/5%,I.PHO*BHC
M0"TJ+PH*+RHJ"B`J($!I9VYO<F4*("HO"F1E9FEN92@G1DE,15]724XS,B<L
M(&1E9FEN960H)T]37U=)3D1/5U,G*2`_($]37U=)3D1/5U,@.B`A<W1R;F-A
M<V5C;7`H4$A07T]3+"`G=VEN)RP@,RDI.PH*+RHJ(`H@*B!&:6QE7U5T:6P*
M("H*("H@1FEL92!A;F0@9&ER96-T;W)Y('5T:6QI='D@9G5N8W1I;VYS+@H@
M*B`*("H@0&%C8V5S<R`@<'5B;&EC"B`J($!S=&%T:6,*("HO"F-L87-S($9I
M;&5?571I;`I["B`@("`O*BH*("`@("`J(%)E='5R;G,@82!S=')I;F<@<&%T
M:"!B=6EL="!F<F]M('1H92!A<G)A>2`D<&%T:%!A<G1S+B!7:&5R92!A(&IO
M:6X@"B`@("`@*B!O8V-U<G,@;75L=&EP;&4@<V5P87)A=&]R<R!A<F4@<F5M
M;W9E9"X@2F]I;G,@=7-I;F<@=&AE(&]P=&EO;F%L(`H@("`@("H@<V5P87)A
M=&]R+"!D969A=6QT:6YG('1O('1H92!02%`@1$E214-43U)97U-%4$%2051/
M4B!C;VYS=&%N="X*("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@0&%C
M8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@87)R87D@("`D<&%R=',@
M07)R87D@8V]N=&%I;FEN9R!T:&4@<&%R=',@=&\@8F4@:F]I;F5D"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("1S97!A<F%T;W(@5&AE(&1I<F5C=&]R>2!S
M97!E<F%T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&10871H*"1P87)T
M<RP@)'-E<&%R871O<B`]($1)4D5#5$]265]315!!4D%43U(I"B`@("!["B`@
M("`@("`@)'%S(#T@)R]>)RX@<')E9U]Q=6]T92@D<V5P87)A=&]R+"`G+R<I
M("XG*R0O)SL*("`@("`@("!F;W(@*"1I(#T@,"P@)&,@/2!C;W5N="@D<&%R
M=',I.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@(&EF("@A<W1R;&5N
M*"1P87)T<ULD:5TI('Q\('!R96=?;6%T8V@H)'%S+"`D<&%R='-;)&E=*2D@
M>PH@("`@("`@("`@("`@("`@=6YS970H)'!A<G1S6R1I72D["B`@("`@("`@
M("`@('T@96QS96EF("@P(#T]("1I*2!["B`@("`@("`@("`@("`@("`D<&%R
M='-;)&E=(#T@<G1R:6TH)'!A<G1S6R1I72P@)'-E<&%R871O<BD["B`@("`@
M("`@("`@('T@96QS96EF("@D8R`M(#$@/3T@)&DI('L*("`@("`@("`@("`@
M("`@("1P87)T<ULD:5T@/2!L=')I;2@D<&%R='-;)&E=+"`D<V5P87)A=&]R
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P87)T
M<ULD:5T@/2!T<FEM*"1P87)T<ULD:5TL("1S97!A<F%T;W(I.PH@("`@("`@
M("`@("!](`H@("`@("`@('T@"B`@("`@("`@<F5T=7)N(&EM<&QO9&4H)'-E
M<&%R871O<BP@)'!A<G1S*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&$@<&%T:"!W:71H;W5T(&QE861I;F<@+R!O<B!#.EPN($EF('1H:7,@
M:7,@;F]T"B`@("`@*B!P<F5S96YT('1H92!P871H(&ES(')E='5R;F5D(&%S
M(&ES+@H@("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`86-C97-S("!P
M=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1P871H(%1H92!P871H
M('1O(&)E('!R;V-E<W-E9`H@("`@("H@0')E='5R;B`@<W1R:6YG("!4:&4@
M<')O8V5S<V5D('!A=&@@;W(@=&AE('!A=&@@87,@:7,*("`@("`J+PH@("`@
M9G5N8W1I;VX@<VMI<%)O;W0H)'!A=&@I"B`@("!["B`@("`@("`@:68@*$9I
M;&5?571I;#HZ:7-!8G-O;'5T92@D<&%T:"DI('L*("`@("`@("`@("`@:68@
M*$9)3$5?5TE.,S(I('L*("`@("`@("`@("`@("`@(')E='5R;B!S=6)S='(H
M)'!A=&@L("1P871H>S-](#T]("=<7"<@/R`T(#H@,RD["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N(&QT<FEM*"1P871H+"`G+R<I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'!A=&@["B`@("!](`H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@=&5M<"!D:7)E8W1O<GD@86-C;W)D:6YG('1O
M(&5I=&AE<B!T:&4@5$U0+"!435!$25(L(&]R(`H@("`@("H@5$5-4"!E;G8@
M=F%R:6%B;&5S+B!)9B!T:&5S92!A<F4@;F]T('-E="!I="!W:6QL(&%L<V\@
M8VAE8VL@9F]R('1H92`*("`@("`J(&5X:7-T96YC92!O9B`O=&UP+"`E5TE.
M1$E2)5QT96UP"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E
M<W,@('!U8FQI8R`*("`@("`J($!R971U<FX@('-T<FEN9R`@5&AE('-Y<W1E
M;2!T;7`@9&ER96-T;W)Y"B`@("`@*B\*("`@(&9U;F-T:6]N('1M<$1I<B@I
M"B`@("!["B`@("`@("`@:68@*$9)3$5?5TE.,S(I('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1?14Y66R=414U0)UTI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)%]%3E9;)U1%35`G73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-S970H)%]%3E9;)U1-4"==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1?14Y66R=435`G73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-S970H)%]%3E9;)W=I;F1I<B==*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1?14Y66R=W:6YD:7(G72`N("=<7'1E;7`G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("AI<W-E="@D7T5.5ELG4WES=&5M4F]O
M="==*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1?14Y66R=3>7-T96U2
M;V]T)UT@+B`G7%QT96UP)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H:7-S970H)%]315)615);)U1%35`G72DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D7U-%4E9%4ELG5$5-4"==.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG5$U0)UTI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)%]315)615);)U1-4"==.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("AI<W-E="@D7U-%4E9%4ELG=VEN9&ER)UTI*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)%]315)615);)W=I;F1I<B==("X@
M)UQ<=&5M<"<["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1?4T525D526R=3>7-T96U2;V]T)UTI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)%]315)615);)U-Y<W1E;5)O;W0G72`N("=<7'1E;7`G.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`G7'1E;7`G.PH@("`@("`@
M('T*("`@("`@("!I9B`H:7-S970H)%]%3E9;)U1-4$1)4B==*2D@>PH@("`@
M("`@("`@("!R971U<FX@)%]%3E9;)U1-4$1)4B==.PH@("`@("`@('T*("`@
M("`@("!I9B`H:7-S970H)%]315)615);)U1-4$1)4B==*2D@>PH@("`@("`@
M("`@("!R971U<FX@)%]315)615);)U1-4$1)4B==.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)R]T;7`G.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!A('1E;7!O<F%R>2!F:6QE;F%M92!U<VEN9R!T96UP;F%M*"D@86YD
M($9I;&4Z.G1M<$1I<B@I+@H@("`@("H@"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B!`86-C97-S("!P=6)L:6,@"B`@("`@*B!`<&%R86T@("!S=')I;F<@("1D
M:7)N86UE($]P=&EO;F%L(&1I<F5C=&]R>2!N86UE(&9O<B!T:&4@=&UP(&9I
M;&4*("`@("`J($!R971U<FX@('-T<FEN9R`@1FEL96YA;64@86YD('!A=&@@
M;V8@=&AE('1M<"!F:6QE"B`@("`@*B\*("`@(&9U;F-T:6]N('1M<$9I;&4H
M)&1I<FYA;64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)&1I
M<FYA;64I*2!["B`@("`@("`@("`@("1D:7)N86UE(#T@1FEL95]5=&EL.CIT
M;7!$:7(H*3L*("`@("`@("!](`H@("`@("`@(')E='5R;B!T96UP;F%M*"1D
M:7)N86UE+"`G=&5M<"XG*3L*("`@('T@"@H@("`@+RHJ"B`@("`@*B!2971U
M<FYS(&)O;VQE86X@8F%S960@;VX@=VAE=&AE<B!G:79E;B!P871H(&ES(&%B
M<V]L=71E(&]R(&YO="X*("`@("`J(`H@("`@("H@0'-T871I8PH@("`@("H@
M0&%C8V5S<R`@<'5B;&EC(`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<&%T
M:"!':79E;B!P871H"B`@("`@*B!`<F5T=7)N("!B;V]L96%N(%1R=64@:68@
M=&AE('!A=&@@:7,@86)S;VQU=&4L(&9A;'-E(&EF(&ET(&ES(&YO=`H@("`@
M("HO"B`@("!F=6YC=&EO;B!I<T%B<V]L=71E*"1P871H*0H@("`@>PH@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O*#\Z7"]\7%Q<*5PN7"XH/SU<+WPD*2\G
M+"`D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M('T@"B`@("`@("`@:68@*$9)3$5?5TE.,S(I('L*("`@("`@("`@("`@<F5T
M=7)N('!R96=?;6%T8V@H)R]>6V$M>D$M6ETZ*%Q<7'Q<+RDO)RP@)'!A=&@I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@*"1P871H>S!](#T]("<O)RD@
M?'P@*"1P871H>S!](#T]("=^)RD["B`@("!](`H*("`@("\J*@H@("`@("H@
M1V5T('!A=&@@<F5L871I=F4@=&\@86YO=&AE<B!P871H"B`@("`@*@H@("`@
M("H@0'-T871I8PH@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N("!S=')I;F<*("`@("`J($!P87)A;2`@('-T<FEN9R`@)'!A=&@*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@)')O;W0*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@)'-E<&%R871O<@H@("`@("HO"B`@("!F=6YC=&EO;B!R96QA=&EV
M95!A=&@H)'!A=&@L("1R;V]T+"`D<V5P87)A=&]R(#T@1$E214-43U)97U-%
M4$%2051/4BD*("`@('L*("`@("`@("`D<&%T:"`]($9I;&5?571I;#HZ<F5A
M;'!A=&@H)'!A=&@L("1S97!A<F%T;W(I.PH@("`@("`@("1R;V]T(#T@1FEL
M95]5=&EL.CIR96%L<&%T:"@D<F]O="P@)'-E<&%R871O<BD["B`@("`@("`@
M)&1I<G,@/2!E>'!L;V1E*"1S97!A<F%T;W(L("1P871H*3L*("`@("`@("`D
M8V]M<"`](&5X<&QO9&4H)'-E<&%R871O<BP@)')O;W0I.PH@("`@("`@(`H@
M("`@("`@(&EF("A&24Q%7U=)3C,R*2!["B`@("`@("`@("`@(&EF("AS=')C
M87-E8VUP*"1D:7)S6S!=+"`D8V]M<%LP72DI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D<&%T:#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!U;G-E
M="@D9&ER<ULP72P@)&-O;7!;,%TI.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("!F;W)E86-H("@D8V]M<"!A<R`D:2`]/B`D<&%R="D@>PH@("`@("`@
M("`@("!I9B`H:7-S970H)&1I<G-;)&E=*2`F)B`D<&%R="`]/2`D9&ER<ULD
M:5TI('L*("`@("`@("`@("`@("`@('5N<V5T*"1D:7)S6R1I72P@)&-O;7!;
M)&E=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("`*("`@("`@
M("!R971U<FX@<W1R7W)E<&5A="@G+BXG("X@)'-E<&%R871O<BP@8V]U;G0H
M)&-O;7`I*2`N(&EM<&QO9&4H)'-E<&%R871O<BP@)&1I<G,I.PH@("`@?0H*
M("`@("\J*@H@("`@("H@1V5T(')E86P@<&%T:"`H=V]R:W,@=VET:"!N;VXM
M97AI<W1A;G0@<&%T:',I"B`@("`@*@H@("`@("H@0'-T871I8PH@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<F5T=7)N("!S=')I;F<*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@)'!A=&@*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@)'-E<&%R871O<@H@("`@("HO"B`@("!F=6YC=&EO;B!R96%L4&%T:"@D
M<&%T:"P@)'-E<&%R871O<B`]($1)4D5#5$]265]315!!4D%43U(I"B`@("![
M"B`@("`@("`@:68@*"%S=')L96XH)'!A=&@I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<V5P87)A=&]R.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D
M9')I=F4@/2`G)SL*("`@("`@("!I9B`H1DE,15]724XS,BD@>PH@("`@("`@
M("`@("`D<&%T:"`]('!R96=?<F5P;&%C92@G+UM<7%Q<7"]=+R<L("1S97!A
M<F%T;W(L("1P871H*3L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R\H
M6V$M>D$M6EU<.BDH+BHI+R<L("1P871H+"`D;6%T8VAE<RDI('L*("`@("`@
M("`@("`@("`@("1D<FEV92`]("1M871C:&5S6S%=.PH@("`@("`@("`@("`@
M("`@)'!A=&@@(#T@)&UA=&-H97-;,ET["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D8W=D("`@/2!G971C=V0H*3L*("`@("`@("`@
M("`@("`@("1D<FEV92`]('-U8G-T<B@D8W=D+"`P+"`R*3L*("`@("`@("`@
M("`@("`@(&EF("@D<&%T:'LP?2`A/3T@)'-E<&%R871O<GLP?2D@>PH@("`@
M("`@("`@("`@("`@("`@("1P871H("`]('-U8G-T<B@D8W=D+"`S*2`N("1S
M97!A<F%T;W(@+B`D<&%T:#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS96EF("@D<&%T:'LP?2`A/3T@)'-E<&%R871O
M<BD@>PH@("`@("`@("`@("`D<&%T:"`](&=E=&-W9"@I("X@)'-E<&%R871O
M<B`N("1P871H.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D9&ER4W1A
M8VL@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*&5X<&QO9&4H)'-E<&%R
M871O<BP@)'!A=&@I(&%S("1D:7(I('L*("`@("`@("`@("`@:68@*'-T<FQE
M;B@D9&ER*2`F)B`D9&ER("$]/2`G+B<I('L*("`@("`@("`@("`@("`@(&EF
M("@D9&ER(#T]("<N+B<I('L*("`@("`@("`@("`@("`@("`@("!A<G)A>5]P
M;W`H)&1I<E-T86-K*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)&1I<E-T86-K6UT@/2`D9&ER.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(`H@("`@
M("`@(')E='5R;B`D9')I=F4@+B`D<V5P87)A=&]R("X@:6UP;&]D92@D<V5P
M87)A=&]R+"`D9&ER4W1A8VLI.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE
M8VL@=VAE=&AE<B!P871H(&ES(&EN(')O;W0@<&%T:`H@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R
M;B`@8F]O;`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`D<&%T:`H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`D<F]O=`H@("`@("HO"B`@("!F=6YC=&EO;B!P
M871H26Y2;V]T*"1P871H+"`D<F]O="D*("`@('L*("`@("`@("!S=&%T:6,@
M)')E86Q0871H<R`](&%R<F%Y*"D["B`@("`@("`@"B`@("`@("`@:68@*"%I
M<W-E="@D<F5A;%!A=&AS6R1R;V]T72DI('L*("`@("`@("`@("`@)')E86Q0
M871H<ULD<F]O=%T@/2!&:6QE7U5T:6PZ.G)E86Q0871H*"1R;V]T*3L*("`@
M("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N(&9A;'-E("$]/2!S=')S
M='(H1FEL95]5=&EL.CIR96%L4&%T:"@D<&%T:"DL("1R96%L4&%T:'-;)')O
M;W1=*3L*("`@('T*"B`@("`O*BH*("`@("`J($QI<W0@1&ER96-T;W)Y"B`@
M("`@*B`*("`@("`J(%1H92!F:6YA;"!A<F=U;65N="P@)&-B+"!I<R!A(&-A
M;&QB86-K('1H870@96ET:&5R(&5V86QU871E<R!T;R!T<G5E(&]R"B`@("`@
M*B!F86QS92!A;F0@<&5R9F]R;7,@82!F:6QT97(@;W!E<F%T:6]N+"!O<B!I
M="!C86X@86QS;R!M;V1I9GD@=&AE(`H@("`@("H@9&ER96-T;W)Y+V9I;&4@
M;F%M97,@<F5T=7)N960N("!4;R!A8VAI979E('1H92!L871T97(@969F96-T
M('5S92!A<R`*("`@("`J(&9O;&QO=W,Z"B`@("`@*B`*("`@("`J(#QC;V1E
M/@H@("`@("H@/#]P:'`*("`@("`J(&9U;F-T:6]N('5C*"8D9FEL96YA;64I
M('L*("`@("`J("`@("`D9FEL96YA;64@/2!S=')T;W5P<&5R*"1F:6QE;F%M
M92D["B`@("`@*B`@("`@<F5T=7)N('1R=64["B`@("`@*B!]"B`@("`@*B`D
M96YT<FEE<R`]($9I;&5?571I;#HZ;&ES=$1I<B@G+B<L($9)3$5?3$E35%]!
M3$PL($9)3$5?4T]25%].3TY%+"`G=6,G*3L*("`@("`J(&9O<F5A8V@@*"1E
M;G1R:65S(&%S("1E*2!["B`@("`@*B`@("`@96-H;R`D92T^;F%M92P@(EQN
M(CL*("`@("`J('T*("`@("`J(#\^"B`@("`@*B`\+V-O9&4^"B`@("`@*B`*
M("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@
M0')E='5R;B`@87)R87D*("`@("`J($!P87)A;2`@('-T<FEN9R`@)'!A=&@*
M("`@("`J($!P87)A;2`@(&EN="`@("`@)&QI<W0*("`@("`J($!P87)A;2`@
M(&EN="`@("`@)'-O<G0*("`@("`J($!P87)A;2`@(&UI>&5D("`@)&-B"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&QI<W1$:7(H)'!A=&@L("1L:7-T(#T@1DE,
M15],25-47T%,3"P@)'-O<G0@/2!&24Q%7U-/4E1?3D].12P@)&-B(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H(7-T<FQE;B@D<&%T:"D@?'P@(6ES7V1I
M<B@D<&%T:"DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@
M?0H@("`@("`@(`H@("`@("`@("1E;G1R:65S(#T@87)R87DH*3L*("`@("`@
M("!F;W(@*"1D:7(@/2!D:7(H)'!A=&@I.R!F86QS92`A/3T@)&5N=')Y(#T@
M)&1I<BT^<F5A9"@I.R`I('L*("`@("`@("`@("`@:68@*"1L:7-T("8@1DE,
M15],25-47T1/5%,@?'P@)&5N=')Y>S!]("$]/2`G+B<I('L*("`@("`@("`@
M("`@("`@("1I<U)E9B`]("@D96YT<GD@/3T]("<N)R!\?"`D96YT<GD@/3T]
M("<N+B<I.PH@("`@("`@("`@("`@("`@)&ES1&ER(#T@)&ES4F5F('Q\(&ES
M7V1I<B@D<&%T:"`N)R\G+B`D96YT<GDI.PH@("`@("`@("`@("`@("`@:68@
M*"`@("`H*"$D:7-$:7(@)B8@)&QI<W0@)B!&24Q%7TQ)4U1?1DE,15,I("`@
M?'P*("`@("`@("`@("`@("`@("`@("`@("`@("@D:7-$:7(@("8F("1L:7-T
M("8@1DE,15],25-47T1)4E,I*2`@("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("@A:7-?8V%L;&%B;&4H)&-B*2!\?"`*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C8BP@87)R87DH)B1E
M;G1R>2DI*2D@>PH@("`@("`@("`@("`@("`@("`@("1E;G1R:65S6UT@/2`H
M;V)J96-T*2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G
M("`]/B`D96YT<GDL"B`@("`@("`@("`@("`@("`@("`@("`@("=S:7IE)R`@
M/3X@)&ES1&ER(#\@;G5L;"`Z(&9I;&5S:7IE*"1P871H("XG+R<N("1E;G1R
M>2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=D871E)R`@/3X@9FEL96UT
M:6UE*"1P871H("XG+R<N("1E;G1R>2DL"B`@("`@("`@("`@("`@("`@("`@
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("`D9&ER+3YC;&]S92@I.PH@("`@("`@(`H@("`@("`@(&EF("@D
M<V]R="D@>PH@("`@("`@("`@("`D96YT<FEE<R`]($9I;&5?571I;#HZ<V]R
M=$9I;&5S*"1E;G1R:65S+"`D<V]R="D["B`@("`@("`@?0H@("`@("`@(`H@
M("`@("`@(')E='5R;B`D96YT<FEE<SL*("`@('T*("`@(`H@("`@+RHJ"B`@
M("`@*B!3;W)T($9I;&5S"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0')E='5R;B`@87)R87D*("`@("`J
M($!P87)A;2`@(&%R<F%Y("`@)&9I;&5S"B`@("`@*B!`<&%R86T@("!I;G0@
M("`@("1S;W)T"B`@("`@*B\*("`@(&9U;F-T:6]N('-O<G1&:6QE<R@D9FEL
M97,L("1S;W)T*0H@("`@>PH@("`@("`@(&EF("@A)&9I;&5S*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`*("`@
M("`@("!I9B`H(21S;W)T*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL97,[
M"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D<V]R="`]/3T@,2D@
M>PH@("`@("`@("`@("!R971U<FX@87)R87E?<F5V97)S92@D9FEL97,I.PH@
M("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H)'-O<G0@)B!&24Q%7U-/
M4E1?4D%.1$]-*2!["B`@("`@("`@("`@('-H=69F;&4H)&9I;&5S*3L*("`@
M("`@("`@("`@<F5T=7)N("1F:6QE<SL*("`@("`@("!]"B`@("`@("`@"B`@
M("`@("`@)&YA;65S(#T@87)R87DH*3L*("`@("`@("`D<VEZ97,@/2!A<G)A
M>2@I.PH@("`@("`@("1D871E<R`](&%R<F%Y*"D["B`@("`*("`@("`@("!I
M9B`H)'-O<G0@)B!&24Q%7U-/4E1?3D%-12D@>PH@("`@("`@("`@("`D<B`]
M("8D;F%M97,["B`@("`@("`@?2!E;'-E:68@*"1S;W)T("8@1DE,15]33U)4
M7T1!5$4I('L*("`@("`@("`@("`@)'(@/2`F)&1A=&5S.PH@("`@("`@('T@
M96QS96EF("@D<V]R="`F($9)3$5?4T]25%]325I%*2!["B`@("`@("`@("`@
M("1R(#T@)B1S:7IE<SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!A
M<V]R="@D9FEL97,L(%-/4E1?4D5'54Q!4BD["B`@("`@("`@("`@(')E='5R
M;B`D9FEL97,["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1S;W)T1FQA
M9W,@/2!A<G)A>2@*("`@("`@("`@("`@1DE,15]33U)47TY!344@/3X@4T]2
M5%]35%))3D<L(`H@("`@("`@("`@("!&24Q%7U-/4E1?1$%412`]/B!33U)4
M7TY5345224,L(`H@("`@("`@("`@("!&24Q%7U-/4E1?4TE:12`]/B!33U)4
M7TY5345224,L"B`@("`@("`@*3L*("`@("`@("`*("`@("`@("!F;W)E86-H
M("@D9FEL97,@87,@)&9I;&4I('L*("`@("`@("`@("`@)&YA;65S6UT@/2`D
M9FEL92T^;F%M93L*("`@("`@("`@("`@)'-I>F5S6UT@/2`D9FEL92T^<VEZ
M93L*("`@("`@("`@("`@)&1A=&5S6UT@/2`D9FEL92T^9&%T93L*("`@("`@
M("!]"B`@("`@("`@"B`@("`@("`@:68@*"1S;W)T("8@1DE,15]33U)47U)%
M5D524T4I('L*("`@("`@("`@("`@87)S;W)T*"1R+"`D<V]R=$9L86=S6R1S
M;W)T("8@?C%=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!A<V]R
M="@D<BP@)'-O<G1&;&%G<ULD<V]R=%TI.PH@("`@("`@('T*("`@(`H@("`@
M("`@("1R97-U;'0@/2!A<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1R(&%S
M("1I(#T^("1F*2!["B`@("`@("`@("`@("1R97-U;'1;72`]("1F:6QE<ULD
M:5T["B`@("`@("`@?0H@("`@"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"B`@("`*("`@("\J*@H@("`@("H@4W=I=&-H($9I;&4@17AT96YS:6]N
M"B`@("`@*B`*("`@("`J($!S=&%T:6,*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("H@0')E='5R;B`@<W1R:6YG?&%R<F%Y"B`@("`@*B!`<&%R86T@
M("!S=')I;F=\87)R87D@("`@)&9I;&5N86UE"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@)'1O(&YE=R!F:6QE(&5X=&5N<VEO;@H@("`@("H@
M0'!A<F%M("`@<W1R:6YG("`@("`@("`@("1F<F]M(&-H86YG92!O;FQY(&9I
M;&5S('=I=&@@=&AI<R!E>'1E;G-I;VX*("`@("`J($!P87)A;2`@(&)O;VP@
M("`@("`@("`@("`D<F5V97)S92!C:&%N9V4@;VYL>2!F:6QE<R!N;W0@:&%V
M:6YG("1F<F]M(&5X=&5N<VEO;@H@("`@("HO"B`@("!F=6YC=&EO;B!S=VET
M8VA%>'0H)&9I;&5N86UE+"`D=&\L("1F<F]M(#T@;G5L;"P@)')E=F5R<V4@
M/2!F86QS92D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&9I;&5N86UE
M*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D9FEL96YA;64@87,@)&ME>2`]
M/B`D9FEL92D@>PH@("`@("`@("`@("`@("`@)&9I;&5N86UE6R1K97E=(#T@
M1FEL95]5=&EL.CIS=VET8VA%>'0H)&9I;&4L("1T;RP@)&9R;VTI.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(')E='5R;B`D9FEL96YA;64["B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D;&5N(#T@<W1R;&5N*"1F<F]M
M*2D@>PH@("`@("`@("`@("`D97AT(#T@<W5B<W1R*"1F:6QE;F%M92P@+21L
M96X@+2`Q*3L*("`@("`@("`@("`@)&-F;B`]($9)3$5?5TE.,S(@/R`G<W1R
M8V%S96-M<"<@.B`G<W1R8VUP)SL*("`@("`@("`@("`@:68@*"$D<F5V97)S
M92`]/2`D8V9N*"1E>'0L("<N)RX@)&9R;VTI*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(')E='5R;B!S=6)S='(H)&9I;&5N86UE+"`P+"`M)&QE;B`M(#$I("XG+B<N
M("1T;SL*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"1P;W,@/2!S
M=')P;W,H)&9I;&5N86UE+"`G+B<I*2!["B`@("`@("`@("`@(')E='5R;B!S
M=6)S='(H)&9I;&5N86UE+"`P+"`D<&]S*2`N)RXG+B`D=&\["B`@("`@("`@
M?0H@("`@("`@(`H@("`@("`@(')E='5R;B`D9FEL96YA;64@+B<N)RX@)'1O
M.PH@("`@?0H@("`@"GT*"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O1U5)````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q,S0@,#(P,S$V`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A0
M56YI="]297!E871E9%1E<W0N<&AP````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,#8R,B`Q,#4Q-30S-#$S-"`P,C,P-30`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T
M;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H
M="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S
M=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J
M"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA
M<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R
M92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I
M=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O
M9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT
M"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB
M=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V
M92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@
M=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V
M:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@
M3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H
M92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E
M9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@
M("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@
M=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!2
M3U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E54
M3U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%2
M4D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(
M12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!
M24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%
M4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)
M3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/
M4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/
M5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13
M($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE4
M4SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%
M1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.
M62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)
M1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'
M12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!0
M2%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P
M,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN
M9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R
M<VEO;B`@("!#5E,Z("1)9#H@4F5P96%T961497-T+G!H<"QV(#$N,3,@,C`P
M-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I
M;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@
M*B\*"G)E<75I<F5?;VYC92`G4$A056YI="]497-T1&5C;W)A=&]R+G!H<"<[
M"@HO*BH*("H@02!$96-O<F%T;W(@=&AA="!R=6YS(&$@=&5S="!R97!E871E
M9&QY+@H@*@H@*B!(97)E(&ES(&%N(&5X86UP;&4Z"B`J"B`J(#QC;V1E/@H@
M*B`\/W!H<`H@*B!R97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP)SL*("H@<F5Q
M=6ER95]O;F-E("=02%!5;FET+U)E<&5A=&5D5&5S="YP:'`G.PH@*@H@*B!C
M;&%S<R!-871H5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@>PH@*B`@
M("`@=F%R("1F5F%L=64Q.PH@*B`@("`@=F%R("1F5F%L=64R.PH@*@H@*B`@
M("`@9G5N8W1I;VX@36%T:%1E<W0H)&YA;64I('L*("H@("`@("`@("`D=&AI
M<RT^4$A056YI=%]497-T0V%S92@D;F%M92D["B`J("`@("!]"B`J"B`J("`@
M("!F=6YC=&EO;B!S9715<"@I('L*("H@("`@("`@("`D=&AI<RT^9E9A;'5E
M,2`](#(["B`J("`@("`@("`@)'1H:7,M/F9686QU93(@/2`S.PH@*B`@("`@
M?0H@*@H@*B`@("`@9G5N8W1I;VX@=&5S=$%D9"@I('L*("H@("`@("`@("`D
M=&AI<RT^87-S97)T5')U92@D=&AI<RT^9E9A;'5E,2`K("1T:&ES+3YF5F%L
M=64R(#T](#4I.PH@*B`@("`@?0H@*B!]"B`J"B`J("1S=6ET92`](&YE=R!0
M2%!5;FET7U1E<W13=6ET93L*("H*("H@)'-U:71E+3YA9&1497-T*`H@*B`@
M(&YE=R!02%!5;FET7U)E<&5A=&5D5&5S="@*("H@("`@(&YE=R!-871H5&5S
M="@G=&5S=$%D9"<I+`H@*B`@("`@,3`*("H@("`I"B`J("D["B`J"B`J("1R
M97-U;'0@/2!02%!5;FET.CIR=6XH)'-U:71E*3L*("H@<')I;G0@)')E<W5L
M="T^=&]3=')I;F<H*3L*("H@/SX*("H@/"]C;V1E/@H@*@H@*B!`8V%T96=O
M<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO
M<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA
M;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC
M96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET7U)E<&5A=&5D
M5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$1E8V]R871O<B!["B`@("`O*BH*
M("`@("`J($!V87(@("`@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7W1I;65S4F5P96%T(#T@,3L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J
M96-T"B`@("`@*B!`<&%R86T@(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%!(4%5N:71?4F5P96%T961497-T
M*"8D=&5S="P@)'1I;65S4F5P96%T(#T@,2D@>PH@("`@("`@("1T:&ES+3Y0
M2%!5;FET7U1E<W1$96-O<F%T;W(H)'1E<W0I.PH@("`@("`@("1T:&ES+3Y?
M=&EM97-297!E870@/2`D=&EM97-297!E870["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;W5N=',@=&AE(&YU;6)E<B!O9B!T97-T(&-A<V5S('1H870*("`@
M("`J('=I;&P@8F4@<G5N(&)Y('1H:7,@=&5S="X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-O=6YT5&5S=$-A<V5S*"D@>PH@("`@("`@(')E='5R
M;B`D=&AI<RT^7W1I;65S4F5P96%T("H@)'1H:7,M/E]T97-T+3YC;W5N=%1E
M<W1#87-E<R@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@9&5C
M;W)A=&5D('1E<W0@86YD(&-O;&QE8W1S('1H90H@("`@("H@<F5S=6QT(&EN
M(&$@5&5S=%)E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!A8G-T<F%C=`H@("`@("HO
M"B`@("!F=6YC=&EO;B!R=6XH)B1R97-U;'0I('L*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D=&AI<RT^7W1I;65S4F5P96%T.R`D:2LK*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?=&5S="T^<G5N*"1R97-U;'0I.PH@("`@("`@('T*
M("`@('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z
M(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M
M96YD97(M<#H@;FEL"B`J($5N9#H*("HO"C\^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+U-K96QE
M=&]N+G!H<```````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#,T
M,C`U(#$P-3$U-#,T,3,T(#`R,C(U,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*
M+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P>7)I9VAT("AC*2`R,#`R
M+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E9"X*("H*("H@4F5D:7-T
M<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@
M=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E
M9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A
M<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C
M;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I<W1R:6)U=&EO;G,@:6X@
M8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H
M=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@
M=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J("`@("!T:&4@9&]C=6UE
M;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@
M=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J("`@*B!.96ET:&5R('1H
M92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N;W(@=&AE(&YA;65S(&]F
M(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B92!U<V5D('1O(&5N9&]R
M<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D"B`J("`@("!F<F]M('1H
M:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E
M<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@
M5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,*("H@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0*("H@3$E-251%1"!43RP@5$A%($E-4$Q)140@
M5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)5$Y%4U,*("H@
M1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.
M3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4($]73D52($]2($-/3E12
M24)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@
M*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%
M3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"550@3D]4($Q)34E4140@
M5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#
M15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&2513.R!/4B!"55-)
M3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@0T%54T5$($%.1"!/3B!!
M3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@
M4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'
M14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*("H@04Y9(%=!62!/550@
M3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@
M3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*@H@*B!`
M8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@
M0&%U=&AO<B`@("`@4V-O='0@36%T=&]C:W,@/'-C;W1T0&-R:7-S8V]T="YC
M;VT^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA
M;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS
M92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!3
M:V5L971O;BYP:'`L=B`Q+C@@,C`P-2\Q,2\Q,"`P.3HT-SHQ-"!S96)A<W1I
M86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C$N,`H@*B\*"B\J*@H@*B!#;&%S<R!F;W(@8W)E
M871I;F<@82!02%!5;FET7U1E<W1#87-E('-K96QE=&]N(&9I;&4N"B`J"B`J
M(%1H:7,@8VQA<W,@=VEL;"!T86ME(&$@8VQA<W-N86UE(&%S(&$@<&%R86UE
M=&5R(&]N(&-O;G-T<G5C=&EO;B!A;F0@=VEL;`H@*B!C<F5A=&4@82!02%`@
M9FEL92!T:&%T(&-O;G1A:6YS('1H92!S:V5L971O;B!O9B!A(%!(4%5N:71?
M5&5S=$-A<V4*("H@<W5B8VQA<W,N(%1H92!T97-T(&-A<V4@=VEL;"!C;VYT
M86EN(&$@=&5S="!F;W)E86-H(&UE=&AO9"!O9B!T:&4@8VQA<W,N"B`J($UE
M=&AO9',@;V8@=&AE('!A<F5N="!C;&%S<R!W:6QL+"!B>2!D969A=6QT+"!B
M92!E>&-L=61E9"!F<F]M('1H92!T97-T"B`J(&-L87-S+B!087-S:6YG(&%N
M9"!O<'1I;VYA;"!C;VYS=')U8W1I;VX@<&%R86UE=&5R('=I;&P@:6YC;'5D
M92!T:&5M+@H@*@H@*B!%>&%M<&QE"B`J"B`J("`@/#]P:'`*("H@("!R97%U
M:7)E7V]N8V4@)U!(4%5N:70O4VME;&5T;VXN<&AP)SL*("H@("`D<',@/2!N
M97<@4$A056YI=%]3:V5L971O;B@G4$A056YI=%]3:V5L971O;B<L("=02%!5
M;FET+U-K96QE=&]N+G!H<"<I.PH@*@H@*B`@("\O($=E;F5R871E('1H92!T
M97-T(&-L87-S+@H@*B`@("\O($1E9F%U;'0@<V5T=&EN9W,@=VEL;"!N;W0@
M:6YC;'5D92!A;GD@<&%R96YT(&-L87-S(&UE=&AO9',L(&)U=`H@*B`@("\O
M('=I;&P@:6YC;'5D92!P<FEV871E(&UE=&AO9',N"B`J("`@)'!S+3YC<F5A
M=&5497-T0VQA<W,H*3L*("H*("H@("`O+R!7<FET92!T:&4@;F5W('1E<W0@
M8VQA<W,@=&\@9FEL92X*("H@("`O+R!">2!D969A=6QT+"!C;V1E('1O(')U
M;B!T:&4@=&5S="!W:6QL(&)E(&EN8VQU9&5D+@H@*B`@("1P<RT^=W)I=&54
M97-T0VQA<W,H*3L*("H@("`_/@H@*@H@*B!.;W<@;W!E;B!T:&4@<VME;&5T
M;VX@8VQA<W,@86YD(&9I;&P@:6X@=&AE(&1E=&%I;',N"B`J($EF('EO=2!R
M=6X@=&AE('1E<W0@87,@:7,L(&%L;"!T97-T<R!W:6QL(&9A:6P@86YD"B`J
M('EO=2!W:6QL('-E92!P;&5N='D@;V8@=6YD969I;F5D(&-O;G-T86YT(&5R
M<F]R<RX*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@
M("!02%!5;FET"B`J($!A=71H;W(@("`@(%-C;W1T($UA='1O8VMS(#QS8V]T
M=$!C<FES<V-O='0N8V]M/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C$N,`H@*B\*8VQA<W,@4$A056YI
M=%]3:V5L971O;B!["B`@("`O*BH*("`@("`J(%!A=&@@=&\@=&AE(&-L87-S
M(&9I;&4@=&\@8W)E871E(&$@<VME;&5T;VX@9F]R+@H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1C;&%S<U!A=&@["@H@("`@+RHJ"B`@
M("`@*B!4:&4@;F%M92!O9B!T:&4@8VQA<W,*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D8VQA<W-.86UE.PH*("`@("\J*@H@("`@("H@
M4&%T:"!T;R!T:&4@8V]N9FEG=7)A=&EO;B!F:6QE(&YE961E9"!B>2!C;&%S
M<R!T;R!T97-T+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1C;VYF:6=&:6QE.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!O<B!N;W0@
M=&\@:6YC;'5D92!T:&4@;65T:&]D<R!O9B!T:&4@<&%R96YT(&-L87-S('=H
M96X@=&5S=&EN9RX*("`@("`J($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V
M87(@)&EN8VQU9&5087)E;G1S.PH*("`@("\J*@H@("`@("H@5VAE=&AE<B!O
M<B!N;W0@=&\@=&5S="!P<FEV871E(&UE=&AO9',N"B`@("`@*B!`=F%R(&)O
M;VQE86X*("`@("`J+PH@("`@=F%R("1I;F-L=61E4')I=F%T93L*"B`@("`O
M*BH*("`@("`J(%1H92!T97-T(&-L87-S('1H870@=VEL;"!B92!C<F5A=&5D
M+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1T97-T0VQA
M<W,["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<BX@4V5T<R!T:&4@8VQA
M<W,@;65M8F5R<R!A;F0@8VAE8VL@=&AA="!T:&4@8VQA<W,*("`@("`J('1O
M('1E<W0@:7,@86-C97-S:6)L92X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H@0'!A<F%M("!S=')I;F<@("1C;&%S<TYA;64*("`@("`J
M($!P87)A;2`@<W1R:6YG("`D8VQA<W-0871H"B`@("`@*B!`<&%R86T@(&)O
M;VQE86X@)&EN8VQU9&5087)E;G1S(%=H971E<B!T;R!I;F-L=61E('1H92!P
M87)E;G0G<R!M971H;V1S(&EN('1H92!T97-T+@H@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%!(4%5N:71?4VME;&5T;VXH)&-L
M87-S3F%M92P@)&-L87-S4&%T:"P@)&EN8VQU9&5087)E;G1S(#T@1D%,4T4L
M("1I;F-L=61E4')I=F%T92`](%12544I('L*("`@("`@("`O+R!3970@=7`@
M=&AE(&UE;6)E<G,N"B`@("`@("`@:68@*$!I<U]R96%D86)L92@D8VQA<W-0
M871H*2D@>PH@("`@("`@("`@("`D=&AI<RT^8VQA<W-.86UE(#T@)&-L87-S
M3F%M93L*("`@("`@("`@("`@)'1H:7,M/F-L87-S4&%T:"`]("1C;&%S<U!A
M=&@["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]H86YD
M;&5%<G)O<G,H)&-L87-S4&%T:"`N("<@:7,@;F]T(')E861A8FQE+B!#86YN
M;W0@8W)E871E('1E<W0@8VQA<W,N)RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!$;R!W92!W86YT('1O(&EN8VQU9&4@<&%R96YT(&UE=&AO9',_"B`@("`@
M("`@)'1H:7,M/FEN8VQU9&5087)E;G1S(#T@)&EN8VQU9&5087)E;G1S.PH*
M("`@("`@("`O+R!$;R!W92!W86YT('1O(&%L;&]W('!R:79A=&4@;65T:&]D
M<S\*("`@("`@("`D=&AI<RT^:6YC;'5D95!R:79A=&4@/2`D:6YC;'5D95!R
M:79A=&4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4:&4@8VQA<W,@=&\@=&5S
M="!M87D@<F5Q=6ER92!A('-P96-I86P@8V]N9FEG(&9I;&4@8F5F;W)E(&ET
M(&-A;B!B90H@("`@("H@:6YS=&%N=&EA=&5D+B!4:&ES(&UE=&AO9"!L971S
M('EO=2!S970@=&AA="!F:6QE+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@('-T<FEN9R`D8V]N9FEG4&%T:`H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$-O;F9I9T9I
M;&4H)&-O;F9I9T9I;&4I('L*("`@("`@("`O+R!#:&5C:R!T:&%T('1H92!F
M:6QE(&ES(')E861A8FQE"B`@("`@("`@:68@*$!I<U]R96%D86)L92@D8V]N
M9FEG1FEL92DI('L*("`@("`@("`@("`@)'1H:7,M/F-O;F9I9T9I;&4@/2`D
M8V]N9FEG1FEL93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^7VAA;F1L945R<F]R<R@D8V]N9FEG1FEL92`N("<@:7,@;F]T(')E861A
M8FQE+B!#86YN;W0@8W)E871E('1E<W0@8VQA<W,N)RD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;V1E('1H870@=VEL
M;"!B92!T:&4@<VME;&5T;VX@;V8@=&AE('1E<W0@8V%S92X*("`@("`J"B`@
M("`@*B!4:&4@=&5S="!C87-E(&UU<W0@:&%V92!A(&-L<W,@9&5F:6YI=&EO
M;BP@;VYE('9A<BP@82!C;VYS=')U8W1O<@H@("`@("H@<V5T57`L('1E87)$
M;W=N+"!A;F0@;65T:&]D<RX@3W!T:6]N86QL>2!A;F0@8GD@9&5F875L="!T
M:&4@8V]D90H@("`@("H@=&\@<G5N('1H92!T97-T(&ES(&%D9&5D('=H96X@
M=&AE(&-L87-S(&ES('=R:71T96X@=&\@9FEL92X*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T
M=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E5&5S=$-L87-S
M*"D@>PH@("`@("`@("\O($EN<W1A;G1I871E('1H92!O8FIE8W0N"B`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YC;VYF:6=&:6QE*2D@>PH@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)'1H:7,M/F-O;F9I9T9I;&4["B`@("`@("`@?0H*
M("`@("`@("!R97%U:7)E7V]N8V4@)'1H:7,M/F-L87-S4&%T:#L*"B`@("`@
M("`@+R\@1V5T('1H92!M971H;V1S+@H@("`@("`@("1C;&%S<TUE=&AO9',@
M/2!G971?8VQA<W-?;65T:&]D<R@D=&AI<RT^8VQA<W-.86UE*3L*"B`@("`@
M("`@+R\@4F5M;W9E('1H92!P87)E;G0@;65T:&]D<R!I9B!N965D960N"B`@
M("`@("`@:68@*"$D=&AI<RT^:6YC;'5D95!A<F5N=',I('L*("`@("`@("`@
M("`@)'!A<F5N=$UE=&AO9',@/2!G971?8VQA<W-?;65T:&]D<RAG971?<&%R
M96YT7V-L87-S*"1T:&ES+3YC;&%S<TYA;64I*3L*"B`@("`@("`@("`@(&EF
M("AC;W5N="@D<&%R96YT365T:&]D<RDI('L*("`@("`@("`@("`@("`@("1C
M;&%S<TUE=&AO9',@/2!A<G)A>5]D:69F*"1C;&%S<TUE=&AO9',L("1P87)E
M;G1-971H;V1S*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@0W)E871E('1H92!C;&%S<R!D969I;FET:6]N+"!C;VYS=')U8W1O<BP@
M<V5T57`@86YD('1E87)$;W=N+@H@("`@("`@("1T:&ES+3Y?8W)E871E1&5F
M:6YI=&EO;B@I.PH@("`@("`@("1T:&ES+3Y?8W)E871E0V]N<W1R=6-T;W(H
M*3L*("`@("`@("`D=&AI<RT^7V-R96%T95-E=%5P5&5A<D1O=VXH*3L*"B`@
M("`@("`@:68@*&-O=6YT*"1C;&%S<TUE=&AO9',I*2!["B`@("`@("`@("`@
M("\O($9O<F5A8V@@;65T:&]D(&-R96%T92!A('1E<W0@8V%S92X*("`@("`@
M("`@("`@9F]R96%C:"`H)&-L87-S365T:&]D<R!A<R`D;65T:&]D*2!["B`@
M("`@("`@("`@("`@("`O+R!5;FQE<W,@:70@:7,@=&AE(&-O;G-T<G5C=&]R
M+@H@("`@("`@("`@("`@("`@:68@*'-T<F-A<V5C;7`H)'1H:7,M/F-L87-S
M3F%M92P@)&UE=&AO9"D@(3T](#`I('L*("`@("`@("`@("`@("`@("`@+R\@
M0VAE8VL@9F]R('!R:79A=&4@;65T:&]D<RX*("`@("`@("`@("`@("`@("`@
M:68@*"$D=&AI<RT^:6YC;'5D95!R:79A=&4@)B8@<W1R<&]S*"1M971H;V0L
M("=?)RD@/3T](#`I('L*("`@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M.PH@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C<F5A=&5-971H;V0H)&UE=&AO9"D["B`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@+R\@1FEN:7,@;V9F('1H92!C;&%S<RX*("`@
M("`@("`D=&AI<RT^7V9I;FES:$-L87-S*"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#<F5A=&4@=&AE(&-L87-S(&1E9FEN:71I;VXN"B`@("`@*@H@("`@
M("H@5&AE(&1E9FEN:71I;VX@8V]N<VES="!O9B!A(&AE861E<B!C;VUM96YT
M+"!R97%U:7)E('-T871M96YT"B`@("`@*B!F;W(@9V5T=&EN9R!T:&4@4$A0
M56YI="!F:6QE+"!T:&4@86-T=6%L(&-L87-S(&1E9FEN:71I;VXL"B`@("`@
M*B!A;F0@=&AE(&1E9FEN:71I;VX@;V8@=&AE(&-L87-S(&UE;6)E<B!V87)I
M86)L92X*("`@("`J"B`@("`@*B!!;&P@;V8@=&AE(&-O9&4@;F5E9&5D(&9O
M<B!T:&4@;F5W(&-L87-S(&ES('-T;W)E9"!I;B!T:&4*("`@("`J('1E<W1#
M;&%S<R!M96UB97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8W)E871E1&5F:6YI=&EO;B@I('L*("`@("`@("`O
M+R!#<F5A=&4@:&5A9&5R(&-O;6UE;G0N"B`@("`@("`@)'1H:7,M/G1E<W1#
M;&%S<R`]"B`@("`@("`@("`B+RHJ7&XB("X*("`@("`@("`@("(@*B!02%!5
M;FET('1E<W0@8V%S92!F;W(@(B`N("1T:&ES+3YC;&%S<TYA;64@+B`B7&XB
M("X*("`@("`@("`@("(@*B!<;B(@+@H@("`@("`@("`@(B`J(%1H92!M971H
M;V0@<VME;&5T;VYS(&)E;&]W(&YE960@=&\@8F4@9FEL;&5D(&EN('=I=&@@
M7&XB("X*("`@("`@("`@("(@*B!R96%L(&1A=&$@<V\@=&AA="!T:&4@=&5S
M=',@=VEL;"!R=6X@8V]R<F5C=&QY+B!297!L86-E(%QN(B`N"B`@("`@("`@
M("`B("H@86QL($584$5#5$5$7U9!3"!A;F0@4$%204T@<W1R:6YG<R!W:71H
M(')E86P@9&%T82X@7&XB("X*("`@("`@("`@("(@*B!<;B(@+@H@("`@("`@
M("`@(B`J($-R96%T960@=VET:"!02%!5;FET7U-K96QE=&]N(&]N("(@+B!D
M871E*"=9+6TM9"<I("X@(EQN(B`N"B`@("`@("`@("`B("HO7&XB.PH*("`@
M("`@("`O+R!!9&0@=&AE(')E<75I<F4@<W1A=&5M96YT<RX*("`@("`@("`D
M=&AI<RT^=&5S=$-L87-S("X](")R97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP
M)SM<;B(["@H@("`@("`@("\O($%D9"!T:&4@8VQA<W,@9&5F:6YI=&EO;B!A
M;F0@=F%R:6%B;&4@9&5F:6YI=&EO;BX*("`@("`@("`D=&AI<RT^=&5S=$-L
M87-S("X]"B`@("`@("`@("`B8VQA<W,@(B`N("1T:&ES+3YC;&%S<TYA;64@
M+B`B5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@>UQN7&XB("X*("`@
M("`@("`@("(@("`@=F%R(%PD(B`N("1T:&ES+3YC;&%S<TYA;64@+B`B.UQN
M7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;&%S<R!C
M;VYS=')U8W1O<BX@*%!(4#0@<W1Y;&4I"B`@("`@*@H@("`@("H@5&AE(&-O
M;G-T<G5C=&]R('-I;7!L>2!C86QL<R!T:&4@4$A056YI=%]497-T0V%S92!M
M971H;V0N"B`@("`@*B!4:&ES(&-O9&4@:7,@=&%K96X@9G)O;2!T:&4@4$A0
M56YI="!D;V-U;65N=&%T:6]N+@H@("`@("H*("`@("`J($%L;"!O9B!T:&4@
M8V]D92!N965D960@9F]R('1H92!N97<@8VQA<W,@:7,@<W1O<F5D(&EN('1H
M90H@("`@("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5#;VYS=')U8W1O
M<B@I('L*("`@("`@("`O+R!#<F5A=&4@=&AE('1E<W0@8VQA<W,@8V]N<W1R
M=6-T;W(N"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<RX]"B`@("`@("`@("`B
M("`@(&9U;F-T:6]N("(@+B`D=&AI<RT^8VQA<W-.86UE("X@(E1E<W0H7"1N
M86UE*5QN(B`N"B`@("`@("`@("`B("`@('M<;B(@+@H@("`@("`@("`@(B`@
M("`@("`@7"1T:&ES+3Y02%!5;FET7U1E<W1#87-E*%PD;F%M92D[7&XB("X*
M("`@("`@("`@("(@("`@?5QN7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0W)E871E('-E=%5P(&%N9"!T96%R1&]W;B!M971H;V1S+@H@("`@("H*("`@
M("`J(%1H92!S9715<"!M971H;V0@8W)E871E<R!T:&4@:6YS=&%N8V4@;V8@
M=&AE(&]B:F5C="!T;R!T97-T+@H@("`@("H@5&AE('1E87)$;W=N(&UE=&AO
M9"!R96QE87-E<R!T:&4@:6YS=&%N8V4N"B`@("`@*B!4:&ES(&-O9&4@:7,@
M=&%K96X@9G)O;2!T:&4@4$A056YI="!D;V-U;65N=&%T:6]N+@H@("`@("H*
M("`@("`J($%L;"!O9B!T:&4@8V]D92!N965D960@9F]R('1H92!N97<@8VQA
M<W,@:7,@<W1O<F5D(&EN('1H90H@("`@("H@=&5S=$-L87-S(&UE;6)E<BX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@
M;F]N90H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]C<F5A=&539715<%1E87)$;W=N*"D@>PH@("`@("`@("\O($-R96%T92!T
M:&4@<V5T57`@;65T:&]D+@H@("`@("`@("1T:&ES+3YT97-T0VQA<W,@+CT*
M("`@("`@("`@("(@("`@9G5N8W1I;VX@<V5T57`H*5QN(B`N"B`@("`@("`@
M("`B("`@('M<;B(["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]N9FEG
M1FEL92DI('L*("`@("`@("`@("`@)'1H:7,M/G1E<W1#;&%S<R`N/0H@("`@
M("`@("`@("`B("`@("`@("!R97%U:7)E7V]N8V4@)R(@+B`D=&AI<RT^8V]N
M9FEG1FEL92`N("(G.UQN(CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YT
M97-T0VQA<W,@+CT*("`@("`@("`@("(@("`@("`@(')E<75I<F5?;VYC92`G
M(B`N("1T:&ES+3YC;&%S<U!A=&@@+B`B)SM<;B(@+@H@("`@("`@("`@(B`@
M("`@("`@7"1T:&ES+3XB("X@)'1H:7,M/F-L87-S3F%M92`N("(@/28@;F5W
M("(@+B`D=&AI<RT^8VQA<W-.86UE("X@(BA005)!32D[7&XB("X*("`@("`@
M("`@("(@("`@?5QN7&XB.PH*("`@("`@("`O+R!#<F5A=&4@=&AE('1E87)$
M;W=N(&UE=&AO9"X*("`@("`@("`D=&AI<RT^=&5S=$-L87-S("X]"B`@("`@
M("`@("`B("`@(&9U;F-T:6]N('1E87)$;W=N*"E<;B(@+@H@("`@("`@("`@
M(B`@("![7&XB("X*("`@("`@("`@("(@("`@("`@('5N<V5T*%PD=&AI<RT^
M(B`N("1T:&ES+3YC;&%S<TYA;64@+B`B*3M<;B(@+@H@("`@("`@("`@(B`@
M("!]7&Y<;B(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!B87-I
M8R!S:V5L971O;B!F;W(@=&5S="!M971H;V1S+@H@("`@("H*("`@("`J(%1H
M:7,@8V]D92!I<R!T86ME;B!F<F]M('1H92!02%!5;FET(&1O8W5M96YT871I
M;VXN"B`@("`@*@H@("`@("H@06QL(&]F('1H92!C;V1E(&YE961E9"!F;W(@
M=&AE(&YE=R!C;&%S<R!I<R!S=&]R960@:6X@=&AE"B`@("`@*B!T97-T0VQA
M<W,@;65M8F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@
M("`@9G5N8W1I;VX@7V-R96%T94UE=&AO9"@D;65T:&]D3F%M92D@>PH@("`@
M("`@("\O($-R96%T92!A('1E<W0@;65T:&]D+@H@("`@("`@("1T:&ES+3YT
M97-T0VQA<W,@+CT*("`@("`@("`@("(@("`@9G5N8W1I;VX@=&5S="(@+B`D
M;65T:&]D3F%M92`N("(H*5QN(B`N"B`@("`@("`@("`B("`@('M<;B(@+@H@
M("`@("`@("`@(B`@("`@("`@7"1R97-U;'0@("`](%PD=&AI<RT^(B`N("1T
M:&ES+3YC;&%S<TYA;64@+B`B+3XB("X@)&UE=&AO9$YA;64@+B`B*%!!4D%-
M*3M<;B(@+@H@("`@("`@("`@(B`@("`@("`@7"1E>'!E8W1E9"`]($584$5#
M5$5$7U9!3#M<;B(@+@H@("`@("`@("`@(B`@("`@("`@7"1T:&ES+3YA<W-E
M<G1%<75A;',H7"1E>'!E8W1E9"P@7"1R97-U;'0I.UQN(B`N"B`@("`@("`@
M("`B("`@('U<;EQN(CL*("`@('T*"B`@("`O*BH*("`@("`J($%D9"!T:&4@
M8VQO<VEN9R!B<F%C92!N965D960@9F]R(&$@<')O<&5R(&-L87-S(&1E9FEN
M:71I;VXN"B`@("`@*@H@("`@("H@06QL(&]F('1H92!C;V1E(&YE961E9"!F
M;W(@=&AE(&YE=R!C;&%S<R!I<R!S=&]R960@:6X@=&AE"B`@("`@*B!T97-T
M0VQA<W,@;65M8F5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@
M("`@("H@0'!A<F%M("!N;VYE"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V9I;FES:$-L87-S*"D@>PH@("`@("`@("\O($-L
M;W-E(&]F9B!T:&4@8VQA<W,N"B`@("`@("`@)'1H:7,M/G1E<W1#;&%S<RX]
M(")]7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!C;V1E
M('1H870@=VEL;"!A8W1U86QL>2!R=6X@=&AE('1E<W0N"B`@("`@*@H@("`@
M("H@5&AI<R!C;V1E(&ES(&%D9&5D(&)Y(&1E9F%U;'0@<V\@=&AA="!T:&4@
M=&5S="!C86X@8F4@<G5N"B`@("`@*B!J=7-T(&)Y(')U;FYI;F<@=&AE(&9I
M;&4N(%1O(&AA=F4@:70@;F]T(&%D9&5D('!A<W,@9F%L<V4*("`@("`J(&%S
M('1H92!S96-O;F0@<&%R86UE=&5R('1O('1H92!W<FET951E<W1#;&%S<R!M
M971H;V0N"B`@("`@*B!4:&ES(&-O9&4@:7,@=&%K96X@9G)O;2!T:&4@4$A0
M56YI="!D;V-U;65N=&%T:6]N+@H@("`@("H*("`@("`J($%L;"!O9B!T:&4@
M8V]D92!N965D960@9F]R('1H92!N97<@8VQA<W,@:7,@<W1O<F5D(&EN('1H
M90H@("`@("H@=&5S=$-L87-S(&UE;6)E<BX*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5497-T*"D@>PH@
M("`@("`@("\O($-R96%T92!A(&-A;&P@=&\@=&AE('1E<W0N"B`@("`@("`@
M)'1E<W0@/0H@("`@("`@("`@(B\O(%)U;FYI;F<@=&AE('1E<W0N7&XB("X*
M("`@("`@("`@(")<)'-U:71E("`](&YE=R!02%!5;FET7U1E<W13=6ET92@G
M(B`N("1T:&ES+3YC;&%S<TYA;64@+B`B5&5S="<I.UQN(B`N"B`@("`@("`@
M("`B7"1R97-U;'0@/2!02%!5;FET.CIR=6XH7"1S=6ET92D[7&XB("X*("`@
M("`@("`@(")E8VAO(%PD<F5S=6QT+3YT;U-T<FEN9R@I.UQN(CL*"B`@("`@
M("`@<F5T=7)N("1T97-T.PH@("`@?0H*("`@("\J*@H@("`@("H@5W)I=&4@
M=&AE('1E<W0@8VQA<W,@=&\@9FEL92X*("`@("`J"B`@("`@*B!4:&ES('=I
M;&P@=W)I=&4@=&AE('1E<W0@8VQA<W,@8W)E871E9"!U<VEN9R!T:&4@8W)E
M871E5&5S=$-L87-S"B`@("`@*B!M971H;V0@=&\@82!F:6QE(&-A;&QE9"`\
M8VQA<W-.86UE/E1E<W0N<&AP+B!">2!D969A=6QT('1H92!F:6QE"B`@("`@
M*B!I<R!W<FET=&5N('1O('1H92!C=7)R96YT(&1I<F5C=&]R>2!A;F0@=VEL
M;"!H879E(&-O9&4@=&\@<G5N"B`@("`@*B!T:&4@=&5S="!A<'!E;F1E9"!T
M;R!T:&4@8F]T=&]M(&]F('1H92!F:6QE+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@('-T<FEN9R`@)&1E<W1I;F%T:6]N
M(%1H92!D:7)E8W1O<GD@=&\@=W)I=&4@=&AE(&9I;&4@=&\N"B`@("`@*B!`
M<&%R86T@(&)O;VQE86X@)&%D9%1E<W0@("`@(%=H971E<B!T;R!A9&0@=&AE
M('1E<W0@<G5N;FEN9R!C;V1E+@H@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*B\*("`@(&9U;F-T:6]N('=R:71E5&5S=$-L87-S*"1D97-T:6YA=&EO;B`]
M("<N+R<L("1A9&1497-T(#T@5%)512D@>PH@("`@("`@("\O($-H96-K(&9O
M<B!S;VUE=&AI;F<@=&\@=W)I=&4@=&\@9FEL92X*("`@("`@("!I9B`H(6ES
M<V5T*"1T:&ES+3YT97-T0VQA<W,I*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M:&%N9&QE17)R;W)S*"=.;W1I;F<@=&\@=W)I=&4N)RP@4$A055-?5T%23DE.
M1RD["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\O
M($]P96X@=&AE(&1E<W1I;F%T:6]N(&9I;&4N"B`@("`@("`@)&9P(#T@9F]P
M96XH)&1E<W1I;F%T:6]N("X@)'1H:7,M/F-L87-S3F%M92`N("=497-T+G!H
M<"<L("=W)RD["B`@("`@("`@9G=R:71E*"1F<"P@(CP_<&AP7&XB*3L*"B`@
M("`@("`@+R\@5W)I=&4@=&AE('1E<W0@8VQA<W,N"B`@("`@("`@9G=R:71E
M*"1F<"P@)'1H:7,M/G1E<W1#;&%S<RD["@H@("`@("`@("\O($%D9"!T:&4@
M8V%L;"!T;R!T97-T('1H92!C;&%S<R!I;B!T:&4@9FEL92!I9B!W92!W97)E
M(&%S:V5D('1O+@H@("`@("`@(&EF("@D861D5&5S="D@>PH@("`@("`@("`@
M("!F=W)I=&4H)&9P+"`D=&AI<RT^7V-R96%T951E<W0H*2D["B`@("`@("`@
M?0H*("`@("`@("`O+R!#;&]S92!T:&4@9FEL92X*("`@("`@("!F=W)I=&4H
M)&9P+"`B/SY<;B(I.PH@("`@("`@(&9C;&]S92@D9G`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@17)R;W(@:&%N9&QE<BX*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!S:&]U;&0@8F4@<F5W<FET=&5N('1O('5S92!T:&4@<')E9F5R
M960@97)R;W(*("`@("`J(&AA;F1L:6YG(&UE=&AO9"X@*%!%05)?17)R;W)3
M=&%C:RD*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P
M87)A;2`@<W1R:6YG("`D;65S<V%G92!4:&4@97)R;W(@;65S<V%G92X*("`@
M("`J($!P87)A;2`@:6YT96=E<B`D='EP92`@("!!;B!I;F1I8V%T:6]N(&]F
M('1H92!S979E<FET>2!O9B!T:&4@97)R;W(N"B`@("`@*B!`<F5T=7)N('9O
M:60@("`@("`@("`@("`@0V]D92!M87D@8V%U<V4@4$A0('1O(&5X:70N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%]H86YD;&5%<G)O<G,H)&UE<W-A9V4L("1T
M>7!E(#T@15]54T527T524D]2*2!["B`@("`@("`@+R\@1F]R(&YO=R!J=7-T
M(&5C:&\@=&AE(&UE<W-A9V4N"B`@("`@("`@96-H;R`D;65S<V%G93L*"B`@
M("`@("`@+R\@0VAE8VL@=&\@<V5E(&EF('=E('-H;W5L9"!Q=6ET+@H@("`@
M("`@(&EF("@D='EP92`]/2!%7U5315)?15)23U(I('L*("`@("`@("`@("`@
M97AI=#L*("`@("`@("!]"B`@("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE
M<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M
M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]02%!5;FET+U1E<W1#87-E+G!H<```````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$V,S$R(#$P-3$U-#,T,3,T(#`R,C(P,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*B!V
M:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T
M=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*("H@0V]P
M>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R97-E<G9E
M9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD
M(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO
M;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@
M8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T<FEB=71I
M;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y
M<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@*B!2961I
M<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE
M(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN"B`J
M("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T97)I86QS
M('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN"B`J"B`J
M("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G;6%N;B!N
M;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S(&UA>2!B
M92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I=F5D
M"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P
M<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&5%=!4D4@
M25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY4
M4DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%
M1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-251%1"!4
M3RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@
M04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%($%212!$
M25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]065))1TA4
M($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$25)%
M0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!
M4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+`H@*B!"
M550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@
M1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!+"!/4B!0
M4D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(*("H@
M0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%
M4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!43U)4("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X*
M("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@
M1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P86-K86=E
M("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN
M(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P
M,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G
M;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E
M+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J
M($!V97)S:6]N("`@($-64SH@)$ED.B!497-T0V%S92YP:'`L=B`Q+C(Q(#(P
M,#4O,3$O,3`@,#DZ-#<Z,30@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S
M:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*
M("HO"@IR97%U:7)E7V]N8V4@)U!(4%5N:70O07-S97)T+G!H<"<["G)E<75I
M<F5?;VYC92`G4$A056YI="]497-T4F5S=6QT+G!H<"<["@HO*BH*("H@02!4
M97-T0V%S92!D969I;F5S('1H92!F:7AT=7)E('1O(')U;B!M=6QT:7!L92!T
M97-T<RX*("H*("H@5&\@9&5F:6YE(&$@5&5S=$-A<V4*("H*("H@("`Q*2!)
M;7!L96UE;G0@82!S=6)C;&%S<R!O9B!02%!5;FET7U1E<W1#87-E+@H@*B`@
M(#(I($1E9FEN92!I;G-T86YC92!V87)I86)L97,@=&AA="!S=&]R92!T:&4@
M<W1A=&4@;V8@=&AE(&9I>'1U<F4N"B`J("`@,RD@26YI=&EA;&EZ92!T:&4@
M9FEX='5R92!S=&%T92!B>2!O=F5R<FED:6YG('-E=%5P*"DN"B`J("`@-"D@
M0VQE86XM=7`@869T97(@82!T97-T(&)Y(&]V97)R:61I;F<@=&5A<D1O=VXH
M*2X*("H*("H@16%C:"!T97-T(')U;G,@:6X@:71S(&]W;B!F:7AT=7)E('-O
M('1H97)E(&-A;B!B92!N;R!S:61E(&5F9F5C=',*("H@86UO;F<@=&5S="!R
M=6YS+@H@*@H@*B!(97)E(&ES(&%N(&5X86UP;&4Z"B`J"B`J(#QC;V1E/@H@
M*B`\/W!H<`H@*B!C;&%S<R!-871H5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S
M=$-A<V4@>PH@*B`@("`@=F%R("1F5F%L=64Q.PH@*B`@("`@=F%R("1F5F%L
M=64R.PH@*@H@*B`@("`@9G5N8W1I;VX@36%T:%1E<W0H)&YA;64I('L*("H@
M("`@("`@("`D=&AI<RT^4$A056YI=%]497-T0V%S92@D;F%M92D["B`J("`@
M("!]"B`J"B`J("`@("!F=6YC=&EO;B!S9715<"@I('L*("H@("`@("`@("`D
M=&AI<RT^9E9A;'5E,2`](#(["B`J("`@("`@("`@)'1H:7,M/F9686QU93(@
M/2`S.PH@*B`@("`@?0H@*B!]"B`J(#\^"B`J(#PO8V]D93X*("H*("H@1F]R
M(&5A8V@@=&5S="!I;7!L96UE;G0@82!M971H;V0@=VAI8V@@:6YT97)A8W1S
M('=I=&@@=&AE(&9I>'1U<F4N"B`J(%9E<FEF>2!T:&4@97AP96-T960@<F5S
M=6QT<R!W:71H(&%S<V5R=&EO;G,@<W!E8VEF:65D(&)Y(&-A;&QI;F<*("H@
M87-S97)T('=I=&@@82!B;V]L96%N+@H@*@H@*B`\8V]D93X*("H@/#]P:'`*
M("H@9G5N8W1I;VX@=&5S=%!A<W,H*2!["B`J("`@("`D=&AI<RT^87-S97)T
M5')U92@D=&AI<RT^9E9A;'5E,2`K("1T:&ES+3YF5F%L=64R(#T](#4I.PH@
M*B!]"B`J(#\^"B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN
M9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S
M=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`
M8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S
M96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W
M=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"
M4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C,N,@H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI
M=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI=%]497-T0V%S92!E>'1E;F1S(%!(
M4%5N:71?07-S97)T('L*("`@("\J*@H@("`@("H@0'9A<B`@("!B;V]L96%N
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9F%I
M;&5D(#T@1D%,4T4["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@
M=&5S="!C87-E+@H@("`@("H*("`@("`J($!V87(@("`@<W1R:6YG"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;F%M92`]("<G
M.PH*("`@("\J*@H@("`@("H@4$A056YI=%]497-T4F5S=6QT(&]B:F5C=`H@
M("`@("H*("`@("`J($!V87(@("`@;V)J96-T"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?<F5S=6QT.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A('1E<W0@8V%S92!W:71H('1H92!G:79E;B!N86UE
M+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!02%!5;FET7U1E<W1#87-E
M*"1N86UE(#T@1D%,4T4I('L*("`@("`@("!I9B`H)&YA;64@(3T]($9!3%-%
M*2!["B`@("`@("`@("`@("1T:&ES+3YS971.86UE*"1N86UE*3L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W5N=',@=&AE(&YU;6)E<B!O
M9B!T97-T(&-A<V5S(&5X96-U=&5D(&)Y(')U;BA497-T4F5S=6QT(')E<W5L
M="DN"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;W5N=%1E<W1#87-E
M<R@I('L*("`@("`@("!R971U<FX@,3L*("`@('T*"B`@("`O*BH*("`@("`J
M($=E=',@=&AE(&YA;64@;V8@82!497-T0V%S92X*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T3F%M92@I('L*("`@("`@("!R971U<FX@)'1H:7,M
M/E]N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@=&5S="!C
M87-E(&%N9"!C;VQL96-T<R!T:&4@<F5S=6QT<R!I;B!A(&=I=F5N(%1E<W12
M97-U;'0@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`<F5T=7)N(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<G5N*"8D<F5S=6QT*2!["B`@("`@("`@)'1H
M:7,M/E]R97-U;'0@/2`F)')E<W5L=#L*("`@("`@("`D=&AI<RT^7W)E<W5L
M="T^<G5N*"1T:&ES*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F5S=6QT
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4G5N<R!T:&4@8F%R92!T97-T('-E
M<75E;F-E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(')U;D)A<F4H*2!["B`@("`@("`@)'1H:7,M/G-E=%5P
M*"D["B`@("`@("`@)'1H:7,M/G)U;E1E<W0H*3L*("`@("`@("`D=&AI<RT^
M=&5A<D1O=VXH*3L*("`@("`@("`D=&AI<RT^<&%S<R@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@3W9E<G)I9&4@=&\@<G5N('1H92!T97-T(&%N9"!A<W-E
M<G0@:71S('-T871E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;E1E<W0H*2!["B`@("`@("`@8V%L
M;%]U<V5R7V9U;F,H"B`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@)B1T
M:&ES+`H@("`@("`@("`@("`D=&AI<RT^7VYA;64*("`@("`@("`@("D*("`@
M("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@;F%M92!O
M9B!A(%1E<W1#87-E+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971.
M86UE*"1N86UE*2!["B`@("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<W1R:6YG(')E<')E<V5N
M=&%T:6]N(&]F('1H92!T97-T(&-A<V4N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N('1O4W1R:6YG*"D@>PH@("`@("`@(')E='5R;B`G)SL*("`@('T*
M"B`@("`O*BH*("`@("`J($-R96%T97,@82!D969A=6QT(%1E<W1297-U;'0@
M;V)J96-T+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B`F8W)E871E
M4F5S=6QT*"D@>PH@("`@("`@(')E='5R;B!N97<@4$A056YI=%]497-T4F5S
M=6QT.PH@("`@?0H*("`@("\J*@H@("`@("H@1F%I;',@82!T97-T('=I=&@@
M=&AE(&=I=F5N(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I
M;F<*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&9A:6PH)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@(&EF("AF=6YC=&EO
M;E]E>&ES=',H)V1E8G5G7V)A8VMT<F%C92<I*2!["B`@("`@("`@("`@("1T
M<F%C92`](&1E8G5G7V)A8VMT<F%C92@I.PH*("`@("`@("`@("`@:68@*&ES
M<V5T*"1T<F%C95LG,2==6R=F:6QE)UTI*2!["B`@("`@("`@("`@("`@("`D
M;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`@("`@("`@("(E<R!I;B`E
M<SHE<R(L"@H@("`@("`@("`@("`@("`@("`D;65S<V%G92P*("`@("`@("`@
M("`@("`@("`@)'1R86-E6R<Q)UU;)V9I;&4G72P*("`@("`@("`@("`@("`@
M("`@)'1R86-E6R<Q)UU;)VQI;F4G70H@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]R97-U;'0M
M/F%D9$9A:6QU<F4H)'1H:7,L("1M97-S86=E*3L*("`@("`@("`D=&AI<RT^
M7V9A:6QE9"`](%12544["B`@("!]"@H@("`@+RHJ"B`@("`@*B!087-S97,@
M82!T97-T+@H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!A<W,H*2!["B`@("`@("`@:68@*"$D=&AI<RT^
M7V9A:6QE9"D@>PH@("`@("`@("`@("`D=&AI<RT^7W)E<W5L="T^861D4&%S
M<V5D5&5S="@D=&AI<RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!U<"!T:&4@9FEX='5R92P@9F]R(&5X86UP;&4L(&]P96X@82!N
M971W;W)K(&-O;FYE8W1I;VXN"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!C86QL
M960@8F5F;W)E(&$@=&5S="!I<R!E>&5C=71E9"X*("`@("`J"B`@("`@*B!`
M86-C97-S('!R;W1E8W1E9`H@("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E=%5P*"D@>R`O*B!A8G-T<F%C="`J+R!]"@H@("`@+RHJ
M"B`@("`@*B!496%R<R!D;W=N('1H92!F:7AT=7)E+"!F;W(@97AA;7!L92P@
M8VQO<V4@82!N971W;W)K(&-O;FYE8W1I;VXN"B`@("`@*B!4:&ES(&UE=&AO
M9"!I<R!C86QL960@869T97(@82!T97-T(&ES(&5X96-U=&5D+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`86)S=')A8W0*("`@
M("`J+PH@("`@9G5N8W1I;VX@=&5A<D1O=VXH*2![("\J(&%B<W1R86-T("HO
M('T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*
M("H@8RUB87-I8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD
M97(M<#H@;FEL"B`J($5N9#H*("HO"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U!(4%5N:70O5&5S=$1E8V]R871O<BYP:'``````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,3`V-C8@,3`U,34T,S0Q,S0@,#(S,C4U`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#
M;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN(#QS
M8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R
M=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T
M:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN
M9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N
M<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J(%)E
M9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T
M:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*
M("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA
M;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*("H*
M("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M86YN
M(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y
M(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV
M960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)5$5$
M(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!94DE'
M2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U0
M3$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L"B`J
M($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L($]2
M(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4@H@
M*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)
M3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA
M9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA
M;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@
M,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E
M<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E<W1$96-O<F%T;W(N<&AP+'8@
M,2XQ-R`R,#`U+S$Q+S$P(#`Y.C0W.C$T('-E8F%S=&EA;B!%>'`@)`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI
M=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=02%!5;FET+U1E<W1#87-E+G!H
M<"<["G)E<75I<F5?;VYC92`G4$A056YI="]497-T4W5I=&4N<&AP)SL*"FEF
M("@A9G5N8W1I;VY?97AI<W1S*"=I<U]A)RDI('L*("`@(')E<75I<F5?;VYC
M92`G4$A0+T-O;7!A="]&=6YC=&EO;B]I<U]A+G!H<"<["GT*"B\J*@H@*B!!
M($1E8V]R871O<B!F;W(@5&5S=',N"B`J"B`J(%5S92!497-T1&5C;W)A=&]R
M(&%S('1H92!B87-E(&-L87-S(&9O<B!D969I;FEN9R!N97<*("H@=&5S="!D
M96-O<F%T;W)S+B!497-T(&1E8V]R871O<B!S=6)C;&%S<V5S(&-A;B!B92!I
M;G1R;V1U8V5D"B`J('1O(&%D9"!B96AA=FEO=7(@8F5F;W)E(&]R(&%F=&5R
M(&$@=&5S="!I<R!R=6XN"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@
M0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER
M:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI
M8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS+C(*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@
M0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP
M+C`*("HO"F-L87-S(%!(4%5N:71?5&5S=$1E8V]R871O<B!["B`@("`O*BH*
M("`@("`J(%1H92!497-T('1O(&)E(&1E8V]R871E9"X*("`@("`J"B`@("`@
M*B!`=F%R("`@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J+PH@("`@=F%R("1?=&5S="`]($Y53$P["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4$A056YI
M=%]497-T1&5C;W)A=&]R*"8D=&5S="D@>PH@("`@("`@(&EF("AI<U]O8FIE
M8W0H)'1E<W0I("8F"B`@("`@("`@("`@("AI<U]A*"1T97-T+"`G4$A056YI
M=%]497-T0V%S92<I('Q\"B`@("`@("`@("`@("!I<U]A*"1T97-T+"`G4$A0
M56YI=%]497-T4W5I=&4G*2DI('L*"B`@("`@("`@("`@("1T:&ES+3Y?=&5S
M="`]("8D=&5S=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M=6YS('1H92!T97-T(&%N9"!C;VQL96-T<R!T:&4*("`@("`J(')E<W5L="!I
M;B!A(%1E<W1297-U;'0N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&)A
M<VEC4G5N*"8D<F5S=6QT*2!["B`@("`@("`@)'1H:7,M/E]T97-T+3YR=6XH
M)')E<W5L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;W5N=',@=&AE(&YU
M;6)E<B!O9B!T97-T(&-A<V5S('1H870*("`@("`J('=I;&P@8F4@<G5N(&)Y
M('1H:7,@=&5S="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN=&5G97(*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O=6YT
M5&5S=$-A<V5S*"D@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1E<W0M/F-O
M=6YT5&5S=$-A<V5S*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!T97-T('1O(&)E(')U;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B
M:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@)F=E=%1E<W0H*2!["B`@("`@("`@<F5T=7)N("1T:&ES+3Y?=&5S=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)U;G,@=&AE(&1E8V]R871E9"!T97-T
M(&%N9"!C;VQL96-T<R!T:&4*("`@("`J(')E<W5L="!I;B!A(%1E<W1297-U
M;'0N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@("`@9G5N8W1I
M;VX@<G5N*"8D<F5S=6QT*2![("\J(&%B<W1R86-T("HO('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@82!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE
M('1E<W0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG*"D@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7W1E<W0M/G1O4W1R:6YG*"D["B`@
M("!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N
M9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4$A056YI
M="]497-T1F%I;'5R92YP:'``````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P-S8S,B`Q,#4Q-30S-#$S-"`P,C(W,C$`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RH@=FEM.B!S970@
M97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]
M-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T"B`J"B`J($-O<'ER:6=H="`H
M8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA
M;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J"B`J
M(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@
M9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R92!P
M97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO
M;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E9&ES=')I8G5T:6]N<R!O9B!S
M;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT"B`J
M("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@*B`@("H@4F5D:7-T<FEB=71I
M;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C
M;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;@H@*B`@("`@=&AE
M(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E
M9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T:6]N+@H@*@H@*B`@("H@3F5I
M=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@0F5R9VUA;FX@;F]R('1H92!N
M86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U=&]R<R!M87D@8F4@=7-E9"!T
M;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@*B`@("`@
M9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I
M='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%($E3(%!23U9)
M1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3
M"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.
M5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%
M1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J($-/4%E224=(5"!/5TY%4B!/
M4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)
M4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#
M3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP*("H@0E54($Y/5"!,
M24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2
M(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@
M3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52"B`J($-!55-%1"!!
M3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].
M5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@3U(@5$]25"`H24Y#3%5$24Y'
M($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E."B`J($%.62!7
M05D@3U54($]&(%1(12!54T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!
M1%9)4T5$($]&(%1(10H@*B!03U-324))3$E462!/1B!354-(($1!34%'12X*
M("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5
M;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B
M87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@
M4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@5&5S=$9A:6QU<F4N<&AP+'8@,2XQ,R`R,#`U+S$Q
M+S$P(#`Y.C0W.C$T('-E8F%S=&EA;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@
M("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PH*
M+RHJ"B`J($$@5&5S=$9A:6QU<F4@8V]L;&5C=',@82!F86EL960@=&5S="!T
M;V=E=&AE<B!W:71H('1H92!C875G:'0@97AC97!T:6]N+@H@*@H@*B!`8V%T
M96=O<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U
M=&AO<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A
M<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET7U1E<W1&
M86EL=7)E('L*("`@("\J*@H@("`@("H@0'9A<B`@("!O8FIE8W0*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F86EL961497-T
M.PH*("`@("\J*@H@("`@("H@0'9A<B`@("!S=')I;F<*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T:')O=VY%>&-E<'1I;VX[
M"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@5&5S=$9A:6QU<F4@=VET
M:"!T:&4@9VEV96X@=&5S="!A;F0@97AC97!T:6]N+@H@("`@("H*("`@("`J
M($!P87)A;2`@;V)J96-T"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4$A056YI=%]4
M97-T1F%I;'5R92@F)&9A:6QE9%1E<W0L("8D=&AR;W=N17AC97!T:6]N*2![
M"B`@("`@("`@)'1H:7,M/E]F86EL961497-T("`@("`@/2`F)&9A:6QE9%1E
M<W0["B`@("`@("`@)'1H:7,M/E]T:')O=VY%>&-E<'1I;VX@/2`F)'1H<F]W
M;D5X8V5P=&EO;CL*("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&9A
M:6QE9"!T97-T+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9F%I;&5D
M5&5S="@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]F86EL961497-T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@=&AR;W=N(&5X8V5P=&EO
M;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C=`H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G1H<F]W;D5X8V5P=&EO
M;B@I('L*("`@("`@("!R971U<FX@)'1H:7,M/E]T:')O=VY%>&-E<'1I;VX[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&$@<VAO<G0@9&5S8W)I
M<'1I;VX@;V8@=&AE(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1O4W1R:6YG*"D@>PH@("`@("`@(')E='5R;B!S<')I;G1F*`H@("`@
M("`@("`@(E1E<W1#87-E("5S+3XE<R@I(&9A:6QE9#H@)7-<;B(L"@H@("`@
M("`@("`@9V5T7V-L87-S*"1T:&ES+3Y?9F%I;&5D5&5S="DL"B`@("`@("`@
M("`D=&AI<RT^7V9A:6QE9%1E<W0M/F=E=$YA;64H*2P*("`@("`@("`@("1T
M:&ES+3Y?=&AR;W=N17AC97!T:6]N"B`@("`@("`@*3L*("`@('T*?0H*+RH*
M("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I
M8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL
M"B`J($5N9#H*("HO"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O4$A056YI="]497-T3&ES=&5N97(N<&AP````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,3`V-2`Q,#4Q-30S-#$S-"`P,C,Q
M,3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO;B`T
M"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R:6=H
M=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@
M<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M
M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@
M9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C
M;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(`H@
M*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P
M<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI
M<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA
M:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T:&5R
M(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I8G5T
M:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I86X@
M0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R:6)U
M=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO=70@
M<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3
M(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$52
M4R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!215-3
M($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4"B`J
M($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!
M3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@4%52
M4$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%"B`J
M($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%($9/
M4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!3
M54)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%5312P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(
M3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E462P@
M3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!
M4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@
M*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%-E8F%S=&EA
M;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P
M>7)I9VAT("`R,#`R+3(P,#4@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A
M<W1I86XM8F5R9VUA;FXN9&4^"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N
M;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@
M3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@5&5S=$QI<W1E;F5R
M+G!H<"QV(#$N,3(@,C`P-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP
M("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!(4%5N:70*("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@
M4F5L96%S92`Q+C`N,`H@*B\*"B\J*@H@*B!!($QI<W1E;F5R(&9O<B!T97-T
M('!R;V=R97-S+@H@*@H@*B!(97)E(&ES(&%N(&5X86UP;&4Z"B`J"B`J(#QC
M;V1E/@H@*B`\/W!H<`H@*B!R97%U:7)E7V]N8V4@)U!(4%5N:70N<&AP)SL*
M("H@<F5Q=6ER95]O;F-E("=02%!5;FET+U1E<W1,:7-T96YE<BYP:'`G.PH@
M*@H@*B!C;&%S<R!-871H5&5S="!E>'1E;F1S(%!(4%5N:71?5&5S=$-A<V4@
M>PH@*B`@("`@=F%R("1F5F%L=64Q.PH@*B`@("`@=F%R("1F5F%L=64R.PH@
M*@H@*B`@("`@9G5N8W1I;VX@36%T:%1E<W0H)&YA;64I('L*("H@("`@("`@
M("`D=&AI<RT^4$A056YI=%]497-T0V%S92@D;F%M92D["B`J("`@("!]"B`J
M"B`J("`@("!F=6YC=&EO;B!S9715<"@I('L*("H@("`@("`@("`D=&AI<RT^
M9E9A;'5E,2`](#(["B`J("`@("`@("`@)'1H:7,M/F9686QU93(@/2`S.PH@
M*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@=&5S=$%D9"@I('L*("H@("`@
M("`@("`D=&AI<RT^87-S97)T5')U92@D=&AI<RT^9E9A;'5E,2`K("1T:&ES
M+3YF5F%L=64R(#T](#0I.PH@*B`@("`@?0H@*B!]"B`J"B`J(&-L87-S($UY
M3&ES=&5N97(@97AT96YD<R!02%!5;FET7U1E<W1,:7-T96YE<B!["B`J("`@
M("!F=6YC=&EO;B!A9&1%<G)O<B@F)'1E<W0L("8D="D@>PH@*B`@("`@("`@
M('!R:6YT(")->4QI<W1E;F5R.CIA9&1%<G)O<B@I(&-A;&QE9"Y<;B(["B`J
M("`@("!]"B`J"B`J("`@("!F=6YC=&EO;B!A9&1&86EL=7)E*"8D=&5S="P@
M)B1T*2!["B`J("`@("`@("`@<')I;G0@(DUY3&ES=&5N97(Z.F%D9$9A:6QU
M<F4H*2!C86QL960N7&XB.PH@*B`@("`@?0H@*@H@*B`@("`@9G5N8W1I;VX@
M96YD5&5S="@F)'1E<W0I('L*("H@("`@("`@("!P<FEN="`B37E,:7-T96YE
M<CHZ96YD5&5S="@I(&-A;&QE9"Y<;B(["B`J("`@("!]"B`J"B`J("`@("!F
M=6YC=&EO;B!S=&%R=%1E<W0H)B1T97-T*2!["B`J("`@("`@("`@<')I;G0@
M(DUY3&ES=&5N97(Z.G-T87)T5&5S="@I(&-A;&QE9"Y<;B(["B`J("`@("!]
M"B`J('T*("H*("H@)'-U:71E(#T@;F5W(%!(4%5N:71?5&5S=%-U:71E.PH@
M*B`D<W5I=&4M/F%D9%1E<W0H;F5W($UA=&A497-T*"=T97-T061D)RDI.PH@
M*@H@*B`D<F5S=6QT(#T@;F5W(%!(4%5N:71?5&5S=%)E<W5L=#L*("H@)')E
M<W5L="T^861D3&ES=&5N97(H;F5W($UY3&ES=&5N97(I.PH@*@H@*B`D<W5I
M=&4M/G)U;B@D<F5S=6QT*3L*("H@<')I;G0@)')E<W5L="T^=&]3=')I;F<H
M*3L*("H@/SX*("H@/"]C;V1E/@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG
M"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J($!C
M;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)3
M1"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET7U1E<W1,:7-T96YE<B!["B`@("`O
M*BH*("`@("`J($%N(&5R<F]R(&]C8W5R<F5D+@H@("`@("H*("`@("`J($!P
M87)A;2`@;V)J96-T"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC
M=&EO;B!A9&1%<G)O<B@F)'1E<W0L("8D="D@>R`O*F%B<W1R86-T("HO('T*
M"B`@("`O*BH*("`@("`J($$@9F%I;'5R92!O8V-U<G)E9"X*("`@("`J"B`@
M("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`86)S=')A8W0*("`@("`J+PH@
M("`@9G5N8W1I;VX@861D1F%I;'5R92@F)'1E<W0L("8D="D@>R`O*F%B<W1R
M86-T("HO('T*"B`@("`O*BH*("`@("`J($$@=&5S="!E;F1E9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!A8G-T<F%C=`H@("`@("HO"B`@("!F=6YC=&EO;B!E;F1497-T
M*"8D=&5S="D@>R`O*F%B<W1R86-T("HO('T*"B`@("`O*BH*("`@("`J($$@
M=&5S="!S=&%R=&5D+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0&%B<W1R86-T"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-T87)T5&5S="@F)'1E<W0I('L@+RIA8G-T<F%C="`J
M+R!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T
M"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N
M9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U!(4%5N:70O5&5S=%)E<W5L="YP:'``````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C`U,C`@,3`U,34T,S0Q
M,S0@,#(R-3<W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@
M<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E
M<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!
M;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70*("H@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H
M870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J
M("`@*B!2961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A
M:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M+@H@*B`*("H@("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M
M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I
M8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG
M(&1I<V-L86EM97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O
M<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I
M<W1R:6)U=&EO;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B
M87-T:6%N($)E<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C
M;VYT<FEB=71O<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E
M('!R;V1U8W1S(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W
M:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*
M("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4
M($A/3$1%4E,@04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@
M15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54
M($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&
M($U%4D-(04Y404))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-5
M3$%2(%!54E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,
M(%1(10H@*B!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)
M04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL
M(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53
M("A)3D-,541)3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%
M3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/
M1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E50
M5$E/3BD@2$]7159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@
M3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"
M24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$52
M5TE312D@05))4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]3
M4TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E
M<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!3
M96)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*
M("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\
M<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H
M<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E<W12
M97-U;'0N<&AP+'8@,2XQ."`R,#`U+S$Q+S$P(#`Y.C0W.C$U('-E8F%S=&EA
M;B!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A
M8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,"XP"B`J+PH*<F5Q=6ER95]O;F-E("=02%!5;FET
M+U1E<W1&86EL=7)E+G!H<"<["G)E<75I<F5?;VYC92`G4$A056YI="]497-T
M3&ES=&5N97(N<&AP)SL*"FEF("@A9G5N8W1I;VY?97AI<W1S*"=I<U]A)RDI
M('L*("`@(')E<75I<F5?;VYC92`G4$A0+T-O;7!A="]&=6YC=&EO;B]I<U]A
M+G!H<"<["GT*"B\J*@H@*B!!(%1E<W1297-U;'0@8V]L;&5C=',@=&AE(')E
M<W5L=',@;V8@97AE8W5T:6YG(&$@=&5S="!C87-E+@H@*@H@*B!`8V%T96=O
M<GD@("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO
M<B`@("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA
M;FXN9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R
M9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC
M96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z
M(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET7U1E<W1297-U
M;'0@>PH@("`@+RHJ"B`@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`@*B!`86-C
M97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!V87(@)%]E<G)O<G,@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@0'9A<B`@("!A<G)A>0H@("`@("H@0&%C
M8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@=F%R("1?9F%I;'5R97,@/2!A
M<G)A>2@I.PH*("`@("`O*BH*("`@("`J($!V87(@("`@87)R87D*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@('9A<B`D7VQI<W1E;F5R
M<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R("`@(&%R<F%Y"B`@
M("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("HO"B`@("!V87(@)%]P87-S
M961497-T<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!`=F%R("`@(&EN
M=&5G97(*("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@('9A
M<B`D7W)U;E1E<W1S(#T@,#L*"B`@("`O*BH*("`@("`J($!V87(@("`@8F]O
M;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7W-T;W`@/2!&04Q313L*"B`@("`O*BH*("`@("`J($%D9',@86X@97)R;W(@
M=&\@=&AE(&QI<W0@;V8@97)R;W)S+@H@("`@("H@5&AE('!A<W-E9"!I;B!E
M>&-E<'1I;VX@8V%U<V5D('1H92!E<G)O<BX*("`@("`J"B`@("`@*B!`<&%R
M86T@(&]B:F5C=`H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9$5R<F]R*"8D=&5S
M="P@)B1T*2!["B`@("`@("`@)'1H:7,M/E]E<G)O<G-;72`](&YE=R!02%!5
M;FET7U1E<W1&86EL=7)E*"1T97-T+"`D="D["@H@("`@("`@(&9O<B`H)&D@
M/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^7VQI<W1E;F5R<RD[("1I*RLI('L*
M("`@("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&E=+3YA9&1%<G)O<B@D
M=&5S="P@)'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%D
M9',@82!F86EL=7)E('1O('1H92!L:7-T(&]F(&9A:6QU<F5S+@H@("`@("H@
M5&AE('!A<W-E9"!I;B!E>&-E<'1I;VX@8V%U<V5D('1H92!F86EL=7)E+@H@
M("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`<&%R86T@(&]B
M:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@861D1F%I;'5R92@F)'1E<W0L("8D="D@>PH@("`@("`@("1T:&ES+3Y?
M9F%I;'5R97-;72`](&YE=R!02%!5;FET7U1E<W1&86EL=7)E*"1T97-T+"`D
M="D["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^
M7VQI<W1E;F5R<RD[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/E]L:7-T
M96YE<G-;)&E=+3YA9&1&86EL=7)E*"1T97-T+"`D="D["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@4F5G:7-T97)S(&$@5&5S=$QI<W1E;F5R
M+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1,:7-T96YE<B@F)&QI
M<W1E;F5R*2!["B`@("`@("`@:68@*&ES7V]B:F5C="@D;&ES=&5N97(I("8F
M"B`@("`@("`@("`@(&ES7V$H)&QI<W1E;F5R+"`G4$A056YI=%]497-T3&ES
M=&5N97(G*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<UM=(#T@
M)B1L:7-T96YE<CL*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!
M9&1S(&$@<&%S<V5D('1E<W0@=&\@=&AE(&QI<W0@;V8@<&%S<V5D('1E<W1S
M+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&1087-S961497-T*"8D
M=&5S="D@>PH@("`@("`@("1T:&ES+3Y?<&%S<V5D5&5S='-;72`]("8D=&5S
M=#L*("`@('T*"B`@("`O*BH*("`@("`J($EN9F]R;7,@=&AE(')E<W5L="!T
M:&%T(&$@=&5S="!W87,@8V]M<&QE=&5D+@H@("`@("H*("`@("`J($!P87)A
M;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!E;F1497-T*"8D=&5S="D@>PH@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\('-I>F5O9B@D=&AI<RT^7VQI<W1E;F5R<RD[("1I*RLI('L*("`@
M("`@("`@("`@)'1H:7,M/E]L:7-T96YE<G-;)&E=+3YE;F1497-T*"1T97-T
M*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N
M=6UB97(@;V8@9&5T96-T960@97)R;W)S+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@97)R;W)#;W5N="@I('L*("`@("`@("!R971U<FX@<VEZ96]F
M*"1T:&ES+3Y?97)R;W)S*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R
M;G,@86X@16YU;65R871I;VX@9F]R('1H92!E<G)O<G,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@)F5R<F]R<R@I('L*("`@("`@("!R971U<FX@)'1H
M:7,M/E]E<G)O<G,["B`@("!]"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N
M=6UB97(@;V8@9&5T96-T960@9F%I;'5R97,N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!F86EL=7)E0V]U;G0H*2!["B`@("`@("`@<F5T=7)N('-I
M>F5O9B@D=&AI<RT^7V9A:6QU<F5S*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@86X@16YU;65R871I;VX@9F]R('1H92!F86EL=7)E<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B`F9F%I;'5R97,H*2!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3Y?9F%I;'5R97,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&%N($5N=6UE<F%T:6]N(&9O<B!T:&4@<&%S<V5D('1E<W1S
M+@H@("`@("H*("`@("`J($!R971U<FX@87)R87D*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N("9P87-S961497-T<R@I('L*
M("`@("`@("!R971U<FX@)'1H:7,M/E]P87-S961497-T<SL*("`@('T*"B`@
M("`O*BH*("`@("`J(%5N<F5G:7-T97)S(&$@5&5S=$QI<W1E;F5R+@H@("`@
M("H@5&AI<R!R97%U:7)E<R!T:&4@6F5N9"!%;F=I;F4@,B`H=&\@=V]R:R!P
M<F]P97)L>2DN"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(')E;6]V94QI
M<W1E;F5R*"8D;&ES=&5N97(I('L*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"!S:7IE;V8H)'1H:7,M/E]L:7-T96YE<G,I.R`D:2LK*2!["B`@("`@("`@
M("`@(&EF("@D=&AI<RT^7VQI<W1E;F5R<ULD:5T@/3T]("1L:7-T96YE<BD@
M>PH@("`@("`@("`@("`@("`@=6YS970H)'1H:7,M/E]L:7-T96YE<G-;)&E=
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J(%)U;G,@82!497-T0V%S92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B
M:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<G5N*"8D=&5S="D@>PH@("`@("`@("1T:&ES+3YS=&%R=%1E<W0H)'1E
M<W0I.PH@("`@("`@("1T:&ES+3Y?<G5N5&5S=',K*SL*("`@("`@("`D=&5S
M="T^<G5N0F%R92@I.PH@("`@("`@("1T:&ES+3YE;F1497-T*"1T97-T*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R=6X@
M=&5S=',N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!R=6Y#;W5N="@I
M('L*("`@("`@("!R971U<FX@)'1H:7,M/E]R=6Y497-T<SL*("`@('T*"B`@
M("`O*BH*("`@("`J($-H96-K<R!W:&5T:&5R('1H92!T97-T(')U;B!S:&]U
M;&0@<W1O<"X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S:&]U;&13=&]P*"D@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W-T;W`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);F9O<FUS('1H
M92!R97-U;'0@=&AA="!A('1E<W0@=VEL;"!B92!S=&%R=&5D+@H@("`@("H*
M("`@("`J($!P87)A;2`@;V)J96-T"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S=&%R=%1E<W0H)B1T97-T*2!["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3Y?;&ES=&5N97)S
M*3L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^7VQI<W1E;F5R<ULD:5TM
M/G-T87)T5&5S="@D=&5S="D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@36%R:W,@=&AA="!T:&4@=&5S="!R=6X@<VAO=6QD('-T;W`N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<W1O<"@I('L*("`@("`@("`D=&AI<RT^7W-T;W`@/2!44E5%.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A($A434P@<F5P<F5S96YT871I
M;VX@;V8@=&AE('1E<W0@<F5S=6QT+@H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!T;TA434PH*2!["B`@("`@("`@<F5T=7)N("<\<')E/B<@+B!H=&UL
M<W!E8VEA;&-H87)S*"1T:&ES+3YT;U-T<FEN9R@I*2`N("<\+W!R93XG.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A('1E>'0@<F5P<F5S96YT
M871I;VX@;V8@=&AE('1E<W0@<F5S=6QT+@H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!T;U-T<FEN9R@I('L*("`@("`@("`D<F5S=6QT(#T@)R<["@H@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?<&%S<V5D5&5S=',@87,@)'!A<W-E
M9%1E<W0I('L*("`@("`@("`@("`@)')E<W5L="`N/2!S<')I;G1F*`H@("`@
M("`@("`@("`@(")497-T0V%S92`E<RT^)7,H*2!P87-S961<;B(L"@H@("`@
M("`@("`@("`@(&=E=%]C;&%S<R@D<&%S<V5D5&5S="DL"B`@("`@("`@("`@
M("`@)'!A<W-E9%1E<W0M/F=E=$YA;64H*0H@("`@("`@("`@("`I.PH@("`@
M("`@('T*"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]F86EL=7)E<R!A<R`D
M9F%I;&5D5&5S="D@>PH@("`@("`@("`@("`D<F5S=6QT("X]("1F86EL9614
M97-T+3YT;U-T<FEN9R@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M97-U;'0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@
M=&AE(&5N=&ER92!T97-T('=A<R!S=6-C97-S9G5L(&]R(&YO="X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('=A<U-U8V-E<W-F=6PH*2!["B`@("`@
M("`@:68@*&5M<'1Y*"1T:&ES+3Y?97)R;W)S*2`F)B!E;7!T>2@D=&AI<RT^
M7V9A:6QU<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@5%)513L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@1D%,4T4["B`@("`@("`@
M?0H@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T
M:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N
M="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!(4%5N:70O5&5S=%-U:71E+G!H<```````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,34R-C0@,3`U,34T,S0Q,S0@,#(R-#(S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@
M*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S
M(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D
M:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O
M;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I
M<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B
M;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@
M("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO
M;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E
M<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O
M<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S
M(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/
M4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"
M4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7
M159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2
M(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))
M4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&
M5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@
M0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER
M:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P
M96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI
M8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%1E<W13=6ET92YP:'`L
M=B`Q+C$W(#(P,#4O,3$O,3`@,#DZ-#<Z,34@<V5B87-T:6%N($5X<"`D"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5
M;FET"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XP+C`*("HO"@IR97%U:7)E7V]N8V4@)U!(4%5N:70O5&5S=$-A<V4N
M<&AP)SL*"B\J*@H@*B!!(%1E<W13=6ET92!I<R!A($-O;7!O<VET92!O9B!4
M97-T<RX@270@<G5N<R!A(&-O;&QE8W1I;VX@;V8@=&5S="!C87-E<RX*("H*
M("H@2&5R92!I<R!A;B!E>&%M<&QE('5S:6YG('1H92!D>6YA;6EC('1E<W0@
M9&5F:6YI=&EO;BX*("H*("H@/&-O9&4^"B`J(#P_<&AP"B`J("1S=6ET92`]
M(&YE=R!02%!5;FET7U1E<W13=6ET92@I.PH@*B`D<W5I=&4M/F%D9%1E<W0H
M;F5W($UA=&A497-T*"=T97-T4&%S<R<I*3L*("H@/SX*("H@/"]C;V1E/@H@
M*@H@*B!!;'1E<FYA=&EV96QY+"!A(%1E<W13=6ET92!C86X@97AT<F%C="!T
M:&4@=&5S=',@=&\@8F4@<G5N(&%U=&]M871I8V%L;'DN"B`J(%1O(&1O('-O
M('EO=2!P87-S('1H92!C;&%S<VYA;64@;V8@>6]U<B!497-T0V%S92!C;&%S
M<R!T;R!T:&4@5&5S=%-U:71E"B`J(&-O;G-T<G5C=&]R+@H@*@H@*B`\8V]D
M93X*("H@/#]P:'`*("H@)'-U:71E(#T@;F5W(%1E<W13=6ET92@G8VQA<W-N
M86UE)RD["B`J(#\^"B`J(#PO8V]D93X*("H*("H@5&AI<R!C;VYS=')U8W1O
M<B!C<F5A=&5S(&$@<W5I=&4@=VET:"!A;&P@=&AE(&UE=&AO9',@<W1A<G1I
M;F<@=VET:`H@*B`B=&5S="(@=&AA="!T86ME(&YO(&%R9W5M96YT<RX*("H*
M("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET
M"B`J($!A=71H;W(@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T
M:6%N+6)E<F=M86YN+F1E/@H@*B!`8V]P>7)I9VAT("`R,#`R+3(P,#4@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^"B`J
M($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("!296QE87-E.B`Q+C,N,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4$A056YI=`H@*B!`<VEN8V4@("`@("!#;&%S<R!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N,`H@*B\*8VQA<W,@4$A056YI
M=%]497-T4W5I=&4@>PH@("`@+RHJ"B`@("`@*B!4:&4@;F%M92!O9B!T:&4@
M=&5S="!S=6ET92X*("`@("`J"B`@("`@*B!`=F%R("`@('-T<FEN9PH@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VYA;64@/2`G
M)SL*"B`@("`O*BH*("`@("`J(%1H92!T97-T<R!I;B!T:&4@=&5S="!S=6ET
M92X*("`@("`J"B`@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&5S=',@/2!A<G)A>2@I.PH*
M("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(%1E<W13=6ET92X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!02%!5;FET7U1E<W13=6ET92@D=&5S="`]
M($9!3%-%*2!["B`@("`@("`@:68@*"1T97-T("$]/2!&04Q312D@>PH@("`@
M("`@("`@("`D=&AI<RT^<V5T3F%M92@D=&5S="D["B`@("`@("`@("`@("1T
M:&ES+3YA9&1497-T4W5I=&4H)'1E<W0I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@82!T97-T('1O('1H92!S=6ET92X*("`@("`J
M"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J+PH@("`@9G5N8W1I;VX@861D5&5S="@F)'1E<W0I('L*("`@("`@
M("`D=&AI<RT^7W1E<W1S6UT@/2`F)'1E<W0["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!!9&1S('1H92!T97-T<R!F<F]M('1H92!G:79E;B!C;&%S<R!T;R!T
M:&4@<W5I=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%1E<W13
M=6ET92@D=&5S=$-L87-S*2!["B`@("`@("`@:68@*&-L87-S7V5X:7-T<R@D
M=&5S=$-L87-S*2D@>PH@("`@("`@("`@("`D;65T:&]D<R`@("`@("`](&=E
M=%]C;&%S<U]M971H;V1S*"1T97-T0VQA<W,I.PH@("`@("`@("`@("`D<&%R
M96YT0VQA<W-E<R`](&%R<F%Y*'-T<G1O;&]W97(H)'1E<W1#;&%S<RDI.PH@
M("`@("`@("`@("`D<&%R96YT0VQA<W,@("`]("1T97-T0VQA<W,["@H@("`@
M("`@("`@("!W:&EL92AI<U]S=')I;F<H)'!A<F5N=$-L87-S(#T@9V5T7W!A
M<F5N=%]C;&%S<R@D<&%R96YT0VQA<W,I*2D@>PH@("`@("`@("`@("`@("`@
M)'!A<F5N=$-L87-S97-;72`]("1P87)E;G1#;&%S<SL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@9F]R96%C:"`H)&UE=&AO9',@87,@)&UE=&AO9"D@
M>PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D;65T:&]D+"`P+"`T*2`]
M/2`G=&5S="<@)B8*("`@("`@("`@("`@("`@("`@("`A:6Y?87)R87DH)&UE
M=&AO9"P@)'!A<F5N=$-L87-S97,I*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F%D9%1E<W0H;F5W("1T97-T0VQA<W,H)&UE=&AO9"DI.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0V]U;G1S('1H92!N=6UB97(@;V8@=&5S="!C87-E
M<R!T:&%T('=I;&P@8F4@<G5N(&)Y('1H:7,@=&5S="X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O=6YT5&5S=$-A<V5S*"D@>PH@("`@("`@("1C
M;W5N="`](#`["@H@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?=&5S=',@87,@
M)'1E<W0I('L*("`@("`@("`@("`@)&-O=6YT("L]("1T97-T+3YC;W5N=%1E
M<W1#87-E<R@I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1C;W5N=#L*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YA;64@;V8@=&AE
M('-U:71E+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971.86UE*"D@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^7VYA;64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2=6YS('1H92!T97-T<R!A;F0@8V]L;&5C=',@=&AE:7(@<F5S
M=6QT(&EN(&$@5&5S=%)E<W5L="X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B
M:F5C=`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<G5N*"8D<F5S=6QT*2!["B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@
M<VEZ96]F*"1T:&ES+3Y?=&5S=',I("8F("$D<F5S=6QT+3YS:&]U;&13=&]P
M*"D[("1I*RLI('L*("`@("`@("`@("`@)'1H:7,M/E]T97-T<ULD:5TM/G)U
M;B@D<F5S=6QT*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M=6YS(&$@=&5S="X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@
M("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(')U;E1E<W0H)B1T97-T+"`F)')E<W5L="D@>PH@
M("`@("`@("1T97-T+3YR=6XH)')E<W5L="D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!3971S('1H92!N86UE(&]F('1H92!S=6ET92X*("`@("`J"B`@("`@
M*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T3F%M92@D;F%M92D@>PH@("`@("`@("1T:&ES
M+3Y?;F%M92`]("1N86UE.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@=&5S="!A="!T:&4@9VEV96X@:6YD97@N"B`@("`@*@H@("`@("H@
M0'!A<F%M("!I;G1E9V5R"B`@("`@*B!`<F5T=7)N(&]B:F5C=`H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)G1E<W1!="@D
M:6YD97@I('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]T97-T<ULD:6YD
M97A=*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]T97-T<ULD:6YD
M97A=.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!&04Q3
M13L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N=6UB97(@;V8@=&5S=',@:6X@=&AI<R!S=6ET92X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN=&5G97(*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('1E<W1#;W5N="@I('L*("`@("`@("!R971U<FX@
M<VEZ96]F*"1T:&ES+3Y?=&5S=',I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@=&5S=',@87,@86X@96YU;65R871I;VXN"B`@("`@*@H@
M("`@("H@0')E='5R;B!A<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@)G1E<W1S*"D@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7W1E<W1S.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!A
M('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@=&5S="!S=6ET92X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&]3=')I;F<H*2!["B`@("`@("`@
M<F5T=7)N("<G.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J
M('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I
M;F<M8V]M;65N="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U!(4%5N
M:70O07-S97)T+G!H<```````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,C<R,S0@,3`U,34T,S0Q,S0@,#(Q-S,S`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T
M(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P
M/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@*@H@*B!#;W!Y<FEG:'0@
M*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I
M86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*@H@
M*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y
M(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A<F4@
M<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I
M;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I<W1R:6)U=&EO;G,@;V8@
M<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H=`H@
M*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@("`J(%)E9&ES=')I8G5T
M:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@
M8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X*("H@("`@('1H
M92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED
M960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO;BX*("H*("H@("`J($YE
M:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E<F=M86YN(&YO<B!T:&4@
M;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O<G,@;6%Y(&)E('5S960@
M=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960*("H@("`@
M(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P96-I9FEC('!R:6]R('=R
M:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%212!)4R!04D]6
M241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]2
M4PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!
M3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,24U)5$5$(%1/+"!42$4@
M24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!3D0@1DE4
M3D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/4T4@05)%($1)4T-,04E-
M140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#3U!94DE'2%0@3U=.15(@
M3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$
M25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL($5814U03$%262P@3U(@
M0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L"B`J($)55"!.3U0@
M3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/
M4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[
M($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4@H@*B!#0553140@
M04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/
M3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.
M1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3@H@*B!!3ED@
M5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@248@
M041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N
M"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A0
M56YI=`H@*B!`875T:&]R("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U
M(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E
M/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI
M8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z($%S<V5R="YP:'`L=B`Q+C(Y(#(P,#4O,3$O,3`@
M,#DZ-#<Z,30@<V5B87-T:6%N($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@
M($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XP+C`*("HO"@HO*BH*
M("H@02!S970@;V8@87-S97)T(&UE=&AO9',N"B`J"B`J($!C871E9V]R>2`@
M(%1E<W1I;F<*("H@0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@
M("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD
M93X*("H@0&-O<'ER:6=H="`@,C`P,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/@H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XS
M+C(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U!(4%5N:70*("H@0'-I;F-E("`@("`@0VQA<W,@879A:6QA8FQE('-I;F-E
M(%)E;&5A<V4@,2XP+C`*("HO"F-L87-S(%!(4%5N:71?07-S97)T('L*("`@
M("\J*@H@("`@("H@0'9A<B`@("!B;V]L96%N"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?;&]O<V5L>51Y<&5D(#T@1D%,4T4[
M"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!H87ES=&%C:R!C;VYT
M86EN<R!A(&YE961L92X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@
M("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@365T:&]D(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N,2XP"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%S<V5R=$-O;G1A:6YS*"1N965D;&4L("1H87ES=&%C:RP@)&UE<W-A9V4@
M/2`G)RD@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)&YE961L92D@)B8@:7-?
M<W1R:6YG*"1H87ES=&%C:RDI('L*("`@("`@("`@("`@)'1H:7,M/F%S<V5R
M=%1R=64H<W1R<&]S*"1H87ES=&%C:RP@)&YE961L92D@(3T]($9!3%-%+"`D
M;65S<V%G92D["B`@("`@("`@?0H*("`@("`@("!E;'-E(&EF("AI<U]A<G)A
M>2@D:&%Y<W1A8VLI("8F("%I<U]O8FIE8W0H)&YE961L92DI('L*("`@("`@
M("`@("`@)'1H:7,M/F%S<V5R=%1R=64H:6Y?87)R87DH)&YE961L92P@)&AA
M>7-T86-K*2P@)&UE<W-A9V4I.PH@("`@("`@('T*"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1T:&ES+3YF86EL*"=5;G-U<'!O<G1E9"!P87)A;65T
M97(@<&%S<V5D('1O(&%S<V5R=$-O;G1A:6YS*"DN)RD["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T(&$@:&%Y<W1A8VL@
M9&]E<R!N;W0@8V]N=&%I;B!A(&YE961L92X*("`@("`J"B`@("`@*B!`<&%R
M86T@(&UI>&5D"B`@("`@*B!`<&%R86T@(&UI>&5D"B`@("`@*B!`<&%R86T@
M('-T<FEN9PH@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S:6YC92`@
M365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&%S<V5R=$YO=$-O;G1A:6YS*"1N965D;&4L("1H87ES
M=&%C:RP@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@(&EF("AI<U]S=')I;F<H
M)&YE961L92D@)B8@:7-?<W1R:6YG*"1H87ES=&%C:RDI('L*("`@("`@("`@
M("`@)'1H:7,M/F%S<V5R=$9A;'-E*'-T<G!O<R@D:&%Y<W1A8VLL("1N965D
M;&4I("$]/2!&04Q312P@)&UE<W-A9V4I.PH@("`@("`@('T*"B`@("`@("`@
M96QS92!I9B`H:7-?87)R87DH)&AA>7-T86-K*2`F)B`A:7-?;V)J96-T*"1N
M965D;&4I*2!["B`@("`@("`@("`@("1T:&ES+3YA<W-E<G1&86QS92AI;E]A
M<G)A>2@D;F5E9&QE+"`D:&%Y<W1A8VLI+"`D;65S<V%G92D["B`@("`@("`@
M?0H*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F9A:6PH)U5N
M<W5P<&]R=&5D('!A<F%M971E<B!P87-S960@=&\@87-S97)T3F]T0V]N=&%I
M;G,H*2XG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E
M<G1S('1H870@='=O('9A<FEA8FQE<R!A<F4@97%U86PN"B`@("`@*@H@("`@
M("H@0'!A<F%M("!M:7AE9`H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@
M0'!A<F%M("!S=')I;F<*("`@("`J($!P87)A;2`@;6EX960*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%S<V5R=$5Q=6%L
M<R@D97AP96-T960L("1A8W1U86PL("1M97-S86=E(#T@)R<L("1D96QT82`]
M(#`I('L*("`@("`@("!I9B`H*&ES7V%R<F%Y*"1A8W1U86PI("`F)B!I<U]A
M<G)A>2@D97AP96-T960I*2!\?`H@("`@("`@("`@("`H:7-?;V)J96-T*"1A
M8W1U86PI("8F(&ES7V]B:F5C="@D97AP96-T960I*2D@>PH@("`@("`@("`@
M("!I9B`H:7-?87)R87DH)&%C='5A;"D@)B8@:7-?87)R87DH)&5X<&5C=&5D
M*2D@>PH@("`@("`@("`@("`@("`@:W-O<G0H)&%C='5A;"D["B`@("`@("`@
M("`@("`@("!K<V]R="@D97AP96-T960I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!I9B`H)'1H:7,M/E]L;V]S96QY5'EP960I('L*("`@("`@("`@
M("`@("`@("1A8W1U86P@("`]("1T:&ES+3Y?8V]N=F5R=%1O4W1R:6YG*"1A
M8W1U86PI.PH@("`@("`@("`@("`@("`@)&5X<&5C=&5D(#T@)'1H:7,M/E]C
M;VYV97)T5&]3=')I;F<H)&5X<&5C=&5D*3L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@)&%C='5A;"`@(#T@<V5R:6%L:7IE*"1A8W1U86PI.PH@("`@
M("`@("`@("`D97AP96-T960@/2!S97)I86QI>F4H)&5X<&5C=&5D*3L*"B`@
M("`@("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@("`@("`G
M)7-E>'!E8W1E9"`E<RP@86-T=6%L("5S)RP*"B`@("`@("`@("`@("`@(65M
M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<L"B`@("`@("`@
M("`@("`@)&5X<&5C=&5D+`H@("`@("`@("`@("`@("1A8W1U86P*("`@("`@
M("`@("`@*3L*"B`@("`@("`@("`@(&EF("@D86-T=6%L("$]/2`D97AP96-T
M960I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S
M<V%G92D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&5L<V5I
M9B`H:7-?;G5M97)I8R@D86-T=6%L*2`F)B!I<U]N=6UE<FEC*"1E>'!E8W1E
M9"DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@
M("`@("`@("<E<V5X<&5C=&5D("5S)7,L(&%C='5A;"`E<R<L"@H@("`@("`@
M("`@("`@("%E;7!T>2@D;65S<V%G92D@/R`D;65S<V%G92`N("<@)R`Z("<G
M+`H@("`@("`@("`@("`@("1E>'!E8W1E9"P*("`@("`@("`@("`@("`H)&1E
M;'1A("$](#`I(#\@*"<K+RT@)R`N("1D96QT82D@.B`G)RP*("`@("`@("`@
M("`@("`D86-T=6%L"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!I9B`H
M(2@D86-T=6%L(#X]("@D97AP96-T960@+2`D9&5L=&$I("8F("1A8W1U86P@
M/#T@*"1E>'!E8W1E9"`K("1D96QT82DI*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)&UE<W-A9V4@
M/2!S<')I;G1F*`H@("`@("`@("`@("`@("<E<V5X<&5C=&5D("5S+"!A8W1U
M86P@)7,G+`H*("`@("`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE
M<W-A9V4@+B`G("<@.B`G)RP*("`@("`@("`@("`@("`D97AP96-T960L"B`@
M("`@("`@("`@("`@)&%C='5A;`H@("`@("`@("`@("`I.PH*("`@("`@("`@
M("`@:68@*"1A8W1U86P@(3T]("1E>'!E8W1E9"D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA
M="!T=V\@=F%R:6%B;&5S(')E9F5R96YC92!T:&4@<V%M92!O8FIE8W0N"B`@
M("`@*B!4:&ES(')E<75I<F5S('1H92!:96YD($5N9VEN92`R('1O('=O<FLN
M"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@
M;V)J96-T"B`@("`@*B!`<&%R86T@('-T<FEN9PH@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%S<V5R=%-A;64H)&5X<&5C=&5D+"`D86-T=6%L+"`D;65S<V%G92`]("<G
M*2!["B`@("`@("`@:68@*"%V97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO;B@I
M+"`G-2XP+C`G+"`G/CTG*2D@>PH@("`@("`@("`@("`D=&AI<RT^9F%I;"@G
M87-S97)T4V%M92@I(&]N;'D@=V]R:W,@=VET:"!02%`@/CT@-2XP+C`N)RD[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H*&ES7V]B:F5C="@D97AP96-T960I
M('Q\(&ES7VYU;&PH)&5X<&5C=&5D*2D@)B8*("`@("`@("`@("`@*&ES7V]B
M:F5C="@D86-T=6%L*2`@('Q\(&ES7VYU;&PH)&%C='5A;"DI*2!["B`@("`@
M("`@("`@("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@("`@("`G)7-E
M>'!E8W1E9"!T=V\@=F%R:6%B;&5S('1O(')E9F5R96YC92!T:&4@<V%M92!O
M8FIE8W0G+`H*("`@("`@("`@("`@("`A96UP='DH)&UE<W-A9V4I(#\@)&UE
M<W-A9V4@+B`G("<@.B`G)PH@("`@("`@("`@("`I.PH*("`@("`@("`@("`@
M:68@*"1E>'!E8W1E9"`A/3T@)&%C='5A;"D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YF86EL*"=5;G-U
M<'!O<G1E9"!P87)A;65T97(@<&%S<V5D('1O(&%S<V5R=%-A;64H*2XG*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!!<W-E<G1S('1H870@
M='=O('9A<FEA8FQE<R!D;R!N;W0@<F5F97)E;F-E('1H92!S86UE(&]B:F5C
M="X*("`@("`J(%1H:7,@<F5Q=6ER97,@=&AE(%IE;F0@16YG:6YE(#(@=&\@
M=V]R:RX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C=`H@("`@("H@0'!A
M<F%M("!O8FIE8W0*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0&1E<')E8V%T960*("`@("`J+PH@("`@9G5N
M8W1I;VX@87-S97)T3F]T4V%M92@D97AP96-T960L("1A8W1U86PL("1M97-S
M86=E(#T@)R<I('L*("`@("`@("!I9B`H(79E<G-I;VY?8V]M<&%R92AP:'!V
M97)S:6]N*"DL("<U+C`N,"<L("<^/2<I*2!["B`@("`@("`@("`@("1T:&ES
M+3YF86EL*"=A<W-E<G1.;W1386UE*"D@;VYL>2!W;W)K<R!W:71H(%!(4"`^
M/2`U+C`N,"XG*3L*("`@("`@("!]"@H@("`@("`@(&EF("@H:7-?;V)J96-T
M*"1E>'!E8W1E9"D@?'P@:7-?;G5L;"@D97AP96-T960I*2`F)@H@("`@("`@
M("`@("`H:7-?;V)J96-T*"1A8W1U86PI("`@?'P@:7-?;G5L;"@D86-T=6%L
M*2DI('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S<')I;G1F*`H@("`@("`@
M("`@("`@("<E<V5X<&5C=&5D('1W;R!V87)I86)L97,@=&\@<F5F97)E;F-E
M(&1I9F9E<F5N="!O8FIE8W1S)RP*"B`@("`@("`@("`@("`@(65M<'1Y*"1M
M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<*("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@(&EF("@D97AP96-T960@/3T]("1A8W1U86PI('L*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI
M<RT^9F%I;"@G56YS=7!P;W)T960@<&%R86UE=&5R('!A<W-E9"!T;R!A<W-E
M<G1.;W1386UE*"DN)RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@07-S97)T<R!T:&%T(&$@=F%R:6%B;&4@:7,@;F]T($Y53$PN"B`@("`@
M*@H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@0'!A<F%M("!S=')I;F<*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&%S
M<V5R=$YO=$YU;&PH)&%C='5A;"P@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@
M("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@("<E<V5X<&5C=&5D($Y/
M5"!.54Q,+"!A8W1U86P@3E5,3"<L"@H@("`@("`@("`@(65M<'1Y*"1M97-S
M86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<*("`@("`@("`I.PH*("`@("`@
M("!I9B`H:7-?;G5L;"@D86-T=6%L*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@('T*("`@('T*"B`@("`O
M*BH*("`@("`J($%S<V5R=',@=&AA="!A('9A<FEA8FQE(&ES($Y53$PN"B`@
M("`@*@H@("`@("H@0'!A<F%M("!M:7AE9`H@("`@("H@0'!A<F%M("!S=')I
M;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%S<V5R=$YU;&PH)&%C='5A;"P@)&UE<W-A9V4@/2`G)RD@>PH@("`@("`@
M("1M97-S86=E(#T@<W!R:6YT9B@*("`@("`@("`@("<E<V5X<&5C=&5D($Y5
M3$PL(&%C='5A;"!.3U0@3E5,3"<L"@H@("`@("`@("`@(65M<'1Y*"1M97-S
M86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<*("`@("`@("`I.PH*("`@("`@
M("!I9B`H(6ES7VYU;&PH)&%C='5A;"DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!!<W-E<G1S('1H870@82!C;VYD:71I;VX@:7,@=')U92X*
M("`@("`J"B`@("`@*B!`<&%R86T@(&)O;VQE86X*("`@("`J($!P87)A;2`@
M<W1R:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!A<W-E<G14<G5E*"1C;VYD:71I;VXL("1M97-S86=E(#T@)R<I('L*
M("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`G)7-E>'!E
M8W1E9"!44E5%+"!A8W1U86P@1D%,4T4G+`H*("`@("`@("`@("%E;7!T>2@D
M;65S<V%G92D@/R`D;65S<V%G92`N("<@)R`Z("<G"B`@("`@("`@*3L*"B`@
M("`@("`@:68@*"$D8V]N9&ET:6]N*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^9F%I;"@D;65S<V%G92D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@07-S97)T<R!T:&%T(&$@8V]N9&ET:6]N(&ES(&9A;'-E+@H@
M("`@("H*("`@("`J($!P87)A;2`@8F]O;&5A;@H@("`@("H@0'!A<F%M("!S
M=')I;F<*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&%S<V5R=$9A;'-E*"1C;VYD:71I;VXL("1M97-S86=E(#T@)R<I('L*
M("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`G)7-E>'!E
M8W1E9"!&04Q312P@86-T=6%L(%12544G+`H*("`@("`@("`@("%E;7!T>2@D
M;65S<V%G92D@/R`D;65S<V%G92`N("<@)R`Z("<G"B`@("`@("`@*3L*"B`@
M("`@("`@:68@*"1C;VYD:71I;VXI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YF86EL*"1M97-S86=E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!!<W-E<G1S('1H870@82!S=')I;F<@;6%T8VAE<R!A(&=I=F5N
M(')E9W5L87(@97AP<F5S<VEO;BX*("`@("`J"B`@("`@*B!`<&%R86T@('-T
M<FEN9PH@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!P87)A;2`@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!A<W-E<G1296=%>'`H)'!A='1E<FXL("1S=')I;F<L("1M97-S86=E(#T@
M)R<I('L*("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`G
M)7,B)7,B(&1O97,@;F]T(&UA=&-H('!A='1E<FX@(B5S(B<L"@H@("`@("`@
M("`@(65M<'1Y*"1M97-S86=E*2`_("1M97-S86=E("X@)R`G(#H@)R<L"B`@
M("`@("`@("`D<W1R:6YG+`H@("`@("`@("`@)'!A='1E<FX*("`@("`@("`I
M.PH*("`@("`@("!I9B`H(7!R96=?;6%T8V@H)'!A='1E<FXL("1S=')I;F<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%I;"@D;65S<V%G92D[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@07-S97)T<R!T:&%T
M(&$@<W1R:6YG(&1O97,@;F]T(&UA=&-H(&$@9VEV96X@<F5G=6QA<B!E>'!R
M97-S:6]N+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG"B`@("`@*B!`
M<&%R86T@('-T<FEN9PH@("`@("H@0'!A<F%M("!S=')I;F<*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I;&%B;&4@
M<VEN8V4@4F5L96%S92`Q+C$N,`H@("`@("HO"B`@("!F=6YC=&EO;B!A<W-E
M<G1.;W1296=%>'`H)'!A='1E<FXL("1S=')I;F<L("1M97-S86=E(#T@)R<I
M('L*("`@("`@("`D;65S<V%G92`]('-P<FEN=&8H"B`@("`@("`@("`G)7,B
M)7,B(&UA=&-H97,@<&%T=&5R;B`B)7,B)RP*"B`@("`@("`@("`A96UP='DH
M)&UE<W-A9V4I(#\@)&UE<W-A9V4@+B`G("<@.B`G)RP*("`@("`@("`@("1S
M=')I;F<L"B`@("`@("`@("`D<&%T=&5R;@H@("`@("`@("D["@H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"1P871T97)N+"`D<W1R:6YG*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F9A:6PH)&UE<W-A9V4I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($%S<V5R=',@=&AA="!A('9A<FEA8FQE
M(&ES(&]F(&$@9VEV96X@='EP92X*("`@("`J"B`@("`@*B!`<&%R86T@('-T
M<FEN9R`@("`@("`@("`D97AP96-T960*("`@("`J($!P87)A;2`@;6EX960@
M("`@("`@("`@("1A8W1U86P*("`@("`J($!P87)A;2`@;W!T:6]N86P@<W1R
M:6YG("1M97-S86=E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@
M("!F=6YC=&EO;B!A<W-E<G14>7!E*"1E>'!E8W1E9"P@)&%C='5A;"P@)&UE
M<W-A9V4@/2`G)RD@>PH@("`@("`@(')E='5R;B`D=&AI<RT^87-S97)T17%U
M86QS*`H@("`@("`@("`@)&5X<&5C=&5D+`H@("`@("`@("`@9V5T='EP92@D
M86-T=6%L*2P*("`@("`@("`@("1M97-S86=E"B`@("`@("`@*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($-O;G9E<G1S(&$@=F%L=64@=&\@82!S=')I;F<N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`@("1V86QU90H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T
M5&]3=')I;F<H)'9A;'5E*2!["B`@("`@("`@9F]R96%C:"`H)'9A;'5E(&%S
M("1K(#T^("1V*2!["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=BDI('L*
M("`@("`@("`@("`@("`@("1V86QU95LD:UT@/2`D=&AI<RT^7V-O;G9E<G14
M;U-T<FEN9R@D=F%L=65;)&M=*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@('-E='1Y<&4H)'9A;'5E6R1K72P@)W-T<FEN9R<I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)'9A;'5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0'!A<F%M("!B;V]L96%N("1L;V]S
M96QY5'EP960*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E=$QO;W-E;'E4>7!E9"@D;&]O<V5L>51Y<&5D*2!["B`@("`@
M("`@:68@*&ES7V)O;VPH)&QO;W-E;'E4>7!E9"DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]L;V]S96QY5'EP960@/2`D;&]O<V5L>51Y<&5D.PH@("`@("`@
M('T*("`@('T*"B`@("`O*BH*("`@("`J($9A:6QS(&$@=&5S="!W:71H('1H
M92!G:79E;B!M97-S86=E+@H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0&%B<W1R86-T"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&9A:6PH)&UE<W-A9V4@/2`G)RD@>R`O*B!A
M8G-T<F%C="`J+R!]"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B
M+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC
M;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J+PH_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4$A056YI="]'54DO2%1-3"YP:'``````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,3(Q-R`Q,#4Q-30S-#$S,R`P
M,C$V-30`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!02%`@5F5R<VEO
M;B`T"B`J"B`J($-O<'ER:6=H="`H8RD@,C`P,BTR,#`U+"!396)A<W1I86X@
M0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93XN"B`J($%L;"!R
M:6=H=',@<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@
M:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@
M*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H*("H@("`J
M(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T
M:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J
M(`H@*B`@("H@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@
M<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@
M=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES
M8VQA:6UE<B!I;@H@*B`@("`@=&AE(&1O8W5M96YT871I;VX@86YD+V]R(&]T
M:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H90H@*B`@("`@9&ES=')I
M8G5T:6]N+@H@*@H@*B`@("H@3F5I=&AE<B!T:&4@;F%M92!O9B!396)A<W1I
M86X@0F5R9VUA;FX@;F]R('1H92!N86UE<R!O9B!H:7,*("H@("`@(&-O;G1R
M:6)U=&]R<R!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O
M9'5C=',@9&5R:79E9`H@*B`@("`@9G)O;2!T:&ES('-O9G1W87)E('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!4
M2$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],
M1$524R!!3D0@0T].5%))0E543U)3"B`J(")!4R!)4R(@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M"B`J($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@3452
M0TA!3E1!0DE,2519($%.1"!&251.15-3"B`J($9/4B!!(%!!4E1)0U5,05(@
M4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%
M"B`J($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@3$E!0DQ%
M($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P*("H@24Y#241%3E1!3"P@4U!%
M0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.
M0TQ51$E.1RP*("H@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/
M1B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.PH@*B!,3U-3($]&(%53
M12P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].
M*2!(3U=%5D52"B`J($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"
M24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#"B`J($Q)04))3$E4
M62P@3U(@5$]25"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E."B`J($%.62!705D@3U54($]&(%1(12!54T4@3T8@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(10H@*B!03U-324))
M3$E462!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN
M9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%=O;&9R
M86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($!C;W!Y<FEG
M:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA
M;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!(5$U,+G!H<"QV(#$N,3D@
M,C`P-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@
M0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C`N
M,`H@*B\*"B\J*@H@*B!(5$U,($=522X*("H*("H@0&-A=&5G;W)Y("`@5&5S
M=&EN9PH@*B!`<&%C:V%G92`@("!02%!5;FET"B`J($!A=71H;W(@("`@(%=O
M;&9R86T@2W)I97-I;F<@/'=O;&9R86U`:W)I97-I;F<N9&4^"B`J($!C;W!Y
M<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S
M=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO
M<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,
M:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET"B`J
M($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M,"XP"B`J+PIC;&%S<R!02%!5;FET7T=525](5$U,"GL*("`@('9A<B`D7W-U
M:71E<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`J('1H92!C=7)R96YT(&EM
M<&QE;65N=&%T:6]N(&]F(%!(4%5N:70@:7,@9&5S:6=N960*("`@("H@=&AI
M<R!W87D@=&AA="!A9&1I;F<@82!S=6ET92!T;R!A;F]T:&5R('-U:71E(&]N
M;'D*("`@("H@9W)A8G,@86QL('1H92!T97-T<R!A;F0@861D<R!T:&5M('1O
M('1H92!S=6ET92P@<V\@>6]U"B`@("`J(&AA=F4@;F\@8VAA;F-E('1O(&9I
M;F0@;W5T('=H:6-H('1E<W0@9V]E<R!W:71H('=H:6-H('-U:71E"B`@("`J
M('1H97)E9F]R92!Y;W4@8V%N('-I;7!L>2!P87-S(&%N(&%R<F%Y(&]F('-U
M:71E<R!T;R!T:&ES(&-O;G-T<G5C=&]R(&AE<F4*("`@("H*("`@("H@0'!A
M<F%M("!A<G)A>2`@(%1H92!S=6ET97,@=&\@8F4@=&5S=&5D+B!)9B!N;W0@
M9VEV96XL('1H96X@>6]U(&UI9VAT"B`@("`J("`@("`@("`@("`@("`@("!B
M92!U<VEN9R!T:&4@4V5T=7!$96-O<F%T;W(L('=H:6-H(&1E=&5C=',@=&AE
M;2!A=71O;6%T:6-A;&QY"B`@("`J("`@("`@("`@("`@("`@("!W:&5N(&-A
M;&QI;F<@9V5T4W5I=&5S1G)O;41I<B@I"B`@("`J+PH@("`@9G5N8W1I;VX@
M4$A056YI=%]'54E?2%1-3"@D<W5I=&5S(#T@87)R87DH*2D*("`@('L*("`@
M("`@("!I9B`H(6ES7V%R<F%Y*"1S=6ET97,I*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<W5I=&5S(#T@87)R87DH)'-U:71E<RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/E]S=6ET97,@/2`D<W5I=&5S.PH@("`@
M("`@('T*("`@('T*"B`@("`O*BH*("`@("H@061D('-U:71E<R!T;R!T:&4@
M1U5)"B`@("`J"B`@("`J($!P87)A;2`@;V)J96-T("!T:&ES('-H;W5L9"!B
M92!A;B!I;G-T86YC92!O9B!02%!5;FET7U1E<W13=6ET90H@("`@*B\*("`@
M(&9U;F-T:6]N(&%D9%-U:71E<R@D<W5I=&5S*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?<W5I=&5S(#T@87)R87E?;65R9V4H)'1H:7,M/E]S=6ET97,L)'-U
M:71E<RD["B`@("!]"@H@("`@+RHJ"B`@("`J('1H:7,@<')I;G1S('1H92!(
M5$U,(&-O9&4@<W1R86EG:'0@;W5T"B`@("`J"B`@("`J+PH@("`@9G5N8W1I
M;VX@<VAO=R@I"B`@("!["B`@("`@("`@)')E<75E<W0@("`@/2`D7U)%455%
M4U0["B`@("`@("`@)'-H;W=087-S960@/2!&04Q313L*("`@("`@("`D<W5B
M;6ET=&5D("`]($`D<F5Q=65S=%LG<W5B;6ET=&5D)UT["@H@("`@("`@(&EF
M("@D<W5B;6ET=&5D*2!["B`@("`@("`@("`@("1S:&]W4&%S<V5D(#T@0"1R
M97%U97-T6R=S:&]W3TLG72`_(%12544@.B!&04Q313L*("`@("`@("!]"@H@
M("`@("`@("1S=6ET95)E<W5L=',@/2!A<G)A>2@I.PH*("`@("`@("!F;W)E
M86-H("@D=&AI<RT^7W-U:71E<R!A<R`D85-U:71E*2!["B`@("`@("`@("`@
M("1A4W5I=&5297-U;'0@/2!A<G)A>2@I.PH*("`@("`@("`@("`@+R\@<F5M
M;W9E('1H92!F:7)S="!D:7)E8W1O<GDG<R!N86UE(&9R;VT@=&AE('1E<W0M
M<W5I=&4@;F%M92P@<VEN8V4@:70*("`@("`@("`@("`@+R\@;6]S=&QY(&ES
M('-O;65T:&EN9R!L:6ME("=T97-T<R<@;W(@86QI:V4*("`@("`@("`@("`@
M)')E;6]V86)L95!R969I>"`](&5X<&QO9&4H)U\G+"1A4W5I=&4M/F=E=$YA
M;64H*2D["B`@("`@("`@("`@("1A4W5I=&5297-U;'1;)VYA;64G72`]('-T
M<E]R97!L86-E*"1R96UO=F%B;&50<F5F:7A;,%TN)U\G+"`G)RP@)&%3=6ET
M92T^9V5T3F%M92@I*3L*"B`@("`@("`@("`@(&EF("@D<W5B;6ET=&5D("8F
M(&ES<V5T*"1R97%U97-T6R1A4W5I=&5297-U;'1;)VYA;64G75TI*2!["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@4$A056YI=#HZ<G5N*"1A4W5I=&4I
M.PH*("`@("`@("`@("`@("`@("1A4W5I=&5297-U;'1;)V-O=6YT<R==6R=R
M=6XG72`]("1R97-U;'0M/G)U;D-O=6YT*"D["B`@("`@("`@("`@("`@("`D
M85-U:71E4F5S=6QT6R=C;W5N=',G75LG97)R;W(G72`]("1R97-U;'0M/F5R
M<F]R0V]U;G0H*3L*("`@("`@("`@("`@("`@("1A4W5I=&5297-U;'1;)V-O
M=6YT<R==6R=F86EL=7)E)UT@/2`D<F5S=6QT+3YF86EL=7)E0V]U;G0H*3L*
M"B`@("`@("`@("`@("`@("`D85-U:71E4F5S=6QT6R=R97-U;'1S)UT@/2`D
M=&AI<RT^7W!R97!A<F5297-U;'0H)')E<W5L="PD<VAO=U!A<W-E9"D["@H@
M("`@("`@("`@("`@("`@)'!E<B`](#$P,"\D<F5S=6QT+3YR=6Y#;W5N="@I
M.PH@("`@("`@("`@("`@("`@)&9A:6QE9"`]("@D<&5R*B1R97-U;'0M/F5R
M<F]R0V]U;G0H*2DK*"1P97(J)')E<W5L="T^9F%I;'5R94-O=6YT*"DI.PH@
M("`@("`@("`@("`@("`@)&%3=6ET95)E<W5L=%LG<&5R8V5N="==(#T@<F]U
M;F0H,3`P+21F86EL960L,BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D85-U:71E4F5S=6QT6R=A9&1);F9O)UT@/2`G3D]4($58
M14-55$5$)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'-U:71E4F5S
M=6QT<UM=(#T@)&%3=6ET95)E<W5L=#L*("`@("`@("!]"@H@("`@("`@("1F
M:6YA;%LG;F%M92==(#T@)T]615)!3$P@4D5354Q4)SL*("`@("`@("`D9FEN
M86Q;)V-O=6YT<R==(#T@87)R87DH*3L*("`@("`@("`D9FEN86Q;)W!E<F-E
M;G0G72`](#`["B`@("`@("`@)&YU;45X96-U=&5D5&5S=',@/2`P.PH*("`@
M("`@("!F;W)E86-H("@D<W5I=&5297-U;'1S(&%S("1A4W5I=&5297-U;'0I
M('L*("`@("`@("`@("`@:68@*'-I>F5O9BA`)&%3=6ET95)E<W5L=%LG8V]U
M;G1S)UTI*2!["B`@("`@("`@("`@("`@("!F;W)E86-H("@D85-U:71E4F5S
M=6QT6R=C;W5N=',G72!A<R`D:V5Y/3XD84-O=6YT*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D9FEN86Q;)V-O=6YT<R==6R1K97E=*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D9FEN86Q;)V-O=6YT<R==6R1K
M97E=(#T@,#L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("1F:6YA;%LG8V]U;G1S)UU;)&ME>5T@*ST@)&%#;W5N=#L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@:68@*&ES<V5T*"1F:6YA;%LG8V]U;G1S)UU;)W)U;B==*2D@>PH@("`@
M("`@("`@("`D<&5R(#T@,3`P+R1F:6YA;%LG8V]U;G1S)UU;)W)U;B==.PH@
M("`@("`@("`@("`D9F%I;&5D(#T@*"1P97(J)&9I;F%L6R=C;W5N=',G75LG
M97)R;W(G72DK*"1P97(J)&9I;F%L6R=C;W5N=',G75LG9F%I;'5R92==*3L*
M("`@("`@("`@("`@)&9I;F%L6R=P97)C96YT)UT@/2!R;W5N9"@Q,#`M)&9A
M:6QE9"PR*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D9FEN86Q;
M)W!E<F-E;G0G72`](#`["B`@("`@("`@?0H*("`@("`@("!A<G)A>5]U;G-H
M:69T*"1S=6ET95)E<W5L=',L)&9I;F%L*3L*"B`@("`@("`@:6YC;'5D92`G
M4$A056YI="]'54DO2%1-3"YT<&PG.PH@("`@?0H*("`@(&9U;F-T:6]N(%]P
M<F5P87)E4F5S=6QT*"1R97-U;'0L)'-H;W=087-S960I"B`@("!["B`@("`@
M("`@)')E="`](&%R<F%Y*"D["B`@("`@("`@)&9A:6QU<F5S(#T@)')E<W5L
M="T^9F%I;'5R97,H*3L*"B`@("`@("`@9F]R96%C:"@D9F%I;'5R97,@87,@
M)&%&86EL=7)E*2!["B`@("`@("`@("`@("1R971;)V9A:6QU<F5S)UU;72`]
M("1T:&ES+3Y?<')E<&%R949A:6QU<F4H)&%&86EL=7)E*3L*("`@("`@("!]
M"@H@("`@("`@("1E<G)O<G,@/2`D<F5S=6QT+3YE<G)O<G,H*3L*"B`@("`@
M("`@9F]R96%C:"@D97)R;W)S(&%S("1A17)R;W(I('L*("`@("`@("`@("`@
M)')E=%LG97)R;W)S)UU;72`]("1T:&ES+3Y?<')E<&%R945R<F]R<R@D845R
M<F]R*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D<VAO=U!A<W-E9"D@>PH@
M("`@("`@("`@("`D<&%S<V5D(#T@)')E<W5L="T^<&%S<V5D5&5S=',H*3L*
M"B`@("`@("`@("`@(&9O<F5A8V@H)'!A<W-E9"!A<R`D85!A<W-E9"D@>PH@
M("`@("`@("`@("`@("`@)')E=%LG<&%S<V5D)UU;72`]("1T:&ES+3Y?<')E
M<&%R95!A<W-E9%1E<W1S*"1A4&%S<V5D*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@9G5N8W1I
M;VX@7W!R97!A<F5&86EL=7)E*"1F86EL=7)E*0H@("`@>PH@("`@("`@("1T
M97-T(#T@)&9A:6QU<F4M/F9A:6QE9%1E<W0H*3L*("`@("`@("`D<F5T6R=T
M97-T3F%M92==(#T@)'1E<W0M/F=E=$YA;64H*3L*("`@("`@("`D97AC97!T
M:6]N(#T@)&9A:6QU<F4M/G1H<F]W;D5X8V5P=&EO;B@I.PH*("`@("`@("`O
M+R!A('-E<FEA;&EZ960@<W1R:6YG('-T87)T<R!W:71H(&$@)V-H87)A8W1E
M<CID96-I;6%L.GLG"B`@("`@("`@+R\@:68@<V\@=V4@=')Y('1O('5N<V5R
M:6%L:7IE(&ET"B`@("`@("`@+R\@=&AI<R!P:65C92!O9B!T:&4@<F5G=6QA
M<B!E>'!R97-S:6]N(&ES(&9O<B!D971E8W1I;F<@82!S97)I86QI>F5D"B`@
M("`@("`@+R\@='EP92!L:6ME("=A.C,Z)R!F;W(@86X@87)R87D@=VET:"!T
M:')E92!E;&5M96YT(&]R(&%N(&]B:F5C="!I+F4N("=/.C$R.B)C;&%S<R(Z
M,R<*("`@("`@("`D<V5R:6%L:7IE9"`]("<H7'<Z7&0K.B@_.B);7B)=*R(Z
M7&0K.BD_7'LN*EQ]*2<["@H@("`@("`@("\O(%-P86-E<R!M:6=H="!M86ME
M(&$@9&EF9BP@<V\@=V4@<VAA;&P@<VAO=R!T:&5M('!R;W!E<FQY("AS:6YC
M92!A"B`@("`@("`@+R\@=7-E<B!A9V5N="!I9VYO<F5S('1H96TI+@H@("`@
M("`@(&EF("AP<F5G7VUA=&-H*"<O7B@N*BEE>'!E8W1E9"`G("X@)'-E<FEA
M;&EZ960@+B`G+"!A8W1U86P@)R`N("1S97)I86QI>F5D("X@)R0O<U4G+"`D
M97AC97!T:6]N+"`D;6%T8VAE<RDI('L*("`@("`@("`@("`@;V)?<W1A<G0H
M*3L*("`@("`@("`@("`@<')I;G1?<BAU;G-E<FEA;&EZ92@D;6%T8VAE<ULR
M72DI.PH@("`@("`@("`@("`D<F5T6R=E>'!E8W1E9"==(#T@:'1M;'-P96-I
M86QC:&%R<R@D;6%T8VAE<ULQ72D@+B`B/'!R93XB("X@:'1M;'-P96-I86QC
M:&%R<RAR=')I;2AO8E]G971?8V]N=&5N=',H*2DI("X@(CPO<')E/B(["B`@
M("`@("`@("`@("\O($EM<')O=F5D(&-O;7!A=&EB:6QI='DL(&]B7V-L96%N
M*"D@=V]U;&0@8F4@4$A0(#X](#0N,BXP(&]N;'DN"B`@("`@("`@("`@(&]B
M7V5N9%]C;&5A;B@I.PH*("`@("`@("`@("`@;V)?<W1A<G0H*3L*("`@("`@
M("`@("`@<')I;G1?<BAU;G-E<FEA;&EZ92@D;6%T8VAE<ULS72DI.PH@("`@
M("`@("`@("`D<F5T6R=A8W1U86PG72`](&AT;6QS<&5C:6%L8VAA<G,H)&UA
M=&-H97-;,5TI("X@(CQP<F4^(B`N(&AT;6QS<&5C:6%L8VAA<G,H<G1R:6TH
M;V)?9V5T7V-O;G1E;G1S*"DI*2`N("(\+W!R93XB.PH@("`@("`@("`@("!O
M8E]E;F1?8VQE86XH*3L*("`@("`@("!]"@H@("`@("`@(&5L<V4@:68@*'!R
M96=?;6%T8V@H)R]>*"XJ*65X<&5C=&5D("@N*BDL(&%C='5A;"`H+BHI)"]S
M52<L("1E>&-E<'1I;VXL("1M871C:&5S*2D@>PH@("`@("`@("`@("`D<F5T
M6R=E>'!E8W1E9"==(#T@;FPR8G(H<W1R7W)E<&QA8V4H(B`B+"`B)FYB<W`[
M(BP@:'1M;'-P96-I86QC:&%R<R@D;6%T8VAE<ULQ72`N("1M871C:&5S6S)=
M*2DI.PH@("`@("`@("`@("`D<F5T6R=A8W1U86PG72`](&YL,F)R*'-T<E]R
M97!L86-E*"(@(BP@(B9N8G-P.R(L(&AT;6QS<&5C:6%L8VAA<G,H)&UA=&-H
M97-;,5T@+B`D;6%T8VAE<ULS72DI*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5T6R=M97-S86=E)UT@/2!N;#)B<BAS=')?<F5P;&%C92@B
M("(L("(F;F)S<#LB+"!H=&UL<W!E8VEA;&-H87)S*"1E>&-E<'1I;VXI*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("!F
M=6YC=&EO;B!?<')E<&%R95!A<W-E9%1E<W1S*"1P87-S960I"B`@("!["B`@
M("`@("`@)')E=%LG=&5S=$YA;64G72`]("1P87-S960M/F=E=$YA;64H*3L*
M("`@("`@("!R971U<FX@)')E=#L*("`@('T*"B`@("!F=6YC=&EO;B!?<')E
M<&%R945R<F]R*"1E<G)O<BD*("`@('L*("`@("`@("`D<F5T6R=T97-T3F%M
M92==(#T@)&5R<F]R+3YG971.86UE*"D["B`@("`@("`@)')E=%LG;65S<V%G
M92==(#T@)&5R<F]R+3YT;U-T<FEN9R@I.PH@("`@("`@(')E='5R;B`D<F5T
M.PH@("`@?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T
M:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N
M="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*/SX*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]02%!5;FET+T=522](5$U,+G1P;```
M````````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$U,#(S(#$P-3$U
M-#,T,3,S(#`R,38V,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\:'1M;#X*("`@(#QH96%D/@H@("`@("`@(#Q35%E,12!T
M>7!E/2)T97AT+V-S<R(^"@H@("`@("`@("`@("!B;V1Y+"!T9"!["B`@("`@
M("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!L:6=H=&=R97D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('1A8FQE+F]U=&QI;F4L(&]U=&QI;F5&
M86EL=7)E('L*("`@("`@("`@("`@("`@(&)A8VMG<F]U;F0M8V]L;W(Z(&)L
M86-K.PH@("`@("`@("`@("`@("`@8F]R9&5R+7=I9'1H.B`Q<'@["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('1D('L*("`@("`@("`@("`@("`@('!A
M9&1I;F<Z(#)P>#L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@=&@@>PH@
M("`@("`@("`@("`@("`@=&5X="UA;&EG;CH@;&5F=#L*("`@("`@("`@("`@
M("`@(&-O;&]R.B!W:&ET93L*("`@("`@("`@("`@("`@(&)A8VMG<F]U;F0M
M8V]L;W(Z(&)L86-K.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`N<W5C
M8V5S<R!["B`@("`@("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!L:6=H
M=&=R965N.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`N9F%I;'5R92![
M"B`@("`@("`@("`@("`@("!B86-K9W)O=6YD+6-O;&]R.B!O<F%N9V4["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@+FEN9F\@>PH@("`@("`@("`@("`@
M("`@<&%D9&EN9SH@,G!X.PH@("`@("`@("`@("`@("`@8V]L;W(Z(&]R86YG
M93L*("`@("`@("`@("`@?0H*("`@("`@("`\+U-464Q%/@H@("`@/"]H96%D
M/@H@("`@/&)O9'D^"B`@("`@("`@/&9O<FT@86-T:6]N/2(\/W!H<"!E8VAO
M("1?4T525D526R=02%!?4T5,1B==(#\^(B!M971H;V0](G!O<W0B(&YA;64]
M(F]P=&EO;G-&;W)M(CX*("`@("`@("`@("`@/'1A8FQE(&%L:6=N/2)C96YT
M97(B(&-L87-S/2)O=71L:6YE(B!W:61T:#TB-S`E(CX*("`@("`@("`@("`@
M("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\=&@@8V]L<W!A;CTB,3`B
M/@H@("`@("`@("`@("`@("`@("`@("`@("!/<'1I;VYS"B`@("`@("`@("`@
M("`@("`@("`@/"]T:#X*("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@
M("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&-O;'-P86X]
M(C$P(CX*("`@("`@("`@("`@("`@("`@("`@("`@/&EN<'5T('1Y<&4](F-H
M96-K8F]X(B!O;D-L:6-K/2)U;D-H96-K06QL*"DB(&YA;64](F%L;$-H96-K
M960B/@H@("`@("`@("`@("`@("`@("`@("`@("`H=6XI8VAE8VL@86QL"B`@
M("`@("`@("`@("`@("`@("`@("`@("9N8G-P.R`F;F)S<#L*("`@("`@("`@
M("`@("`@("`@("`@("`@<VAO=R!/2R`\:6YP=70@='EP93TB8VAE8VMB;W@B
M(&YA;64](G-H;W=/2R(@/#]P:'`@96-H;R!`)')E<75E<W1;)W-H;W=/2R==
M/R=C:&5C:V5D)SHG)S\^/@H@("`@("`@("`@("`@("`@("`@("`@("`F;F)S
M<#L@)FYB<W`["B`@("`@("`@("`@("`@("`@("`@("`@(#QI;G!U="!T>7!E
M/2)S=6)M:70B(&YA;64](G-U8FUI='1E9"(@=F%L=64](G)U;B!T97-T<R(^
M"B`@("`@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@(#PO
M='(^"@H@("`@("`@("`@("`@("`@/#]P:'`@9F]R96%C:"@D<W5I=&5297-U
M;'1S(&%S("1A4F5S=6QT*3H@/SX*("`@("`@("`@("`@("`@("`@("`\='(^
M"B`@("`@("`@("`@("`@("`@("`@("`@(#QT:"!C;VQS<&%N/2(Q,"(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\:6YP=70@='EP93TB8VAE8VMB
M;W@B(&YA;64](CP_<&AP(&5C:&\@)&%297-U;'1;)VYA;64G72`_/B(@/#]P
M:'`@96-H;R!`)')E<75E<W1;)&%297-U;'1;)VYA;64G75T_)V-H96-K960G
M.B<G(#\^/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@96-H
M;R`D85)E<W5L=%LG;F%M92==(#\^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`F;F)S<#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP
M(&EF("AI<W-E="@D85)E<W5L=%LG861D26YF;R==*2DZ(#\^"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@/&9O;G0@8VQA<W,](FEN9F\B/CP_
M<&AP(&5C:&\@0"1A4F5S=6QT6R=A9&1);F9O)UT@/SX\+V9O;G0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1I9B`_/@H@("`@("`@
M("`@("`@("`@("`@("`@("`\+W1H/@H@("`@("`@("`@("`@("`@("`@(#PO
M='(^"@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*$`D85)E<W5L=%LG
M<&5R8V5N="==*3H@/SX*("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&-O;'-P86X](C$P(B!N
M;W=R87`](FYO=W)A<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@/'1A8FQE('-T>6QE/2)W:61T:#HQ,#`E.R!P861D:6YG.C)P>#LB(&-E
M;&QS<&%C:6YG/2(P(B!C96QL<W!A;CTB,"(@8V5L;'!A9&1I;F<](C`B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`\=&0@=VED=&@]
M(CP_<&AP(&5C:&\@)&%297-U;'1;)W!E<F-E;G0G72`_/B4B(&-L87-S/2)S
M=6-C97-S(B!A;&EG;CTB8V5N=&5R(B!S='EL93TB<&%D9&EN9SHP.R(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P
M:'`@96-H;R`D85)E<W5L=%LG<&5R8V5N="==/R1A4F5S=6QT6R=P97)C96YT
M)UTN)R4G.B<G(#\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@/'1D('=I9'1H/2(\/W!H<"!E8VAO(#$P,"TD85)E<W5L=%LG
M<&5R8V5N="==(#\^)2(@8VQA<W,](F9A:6QU<F4B(&%L:6=N/2)C96YT97(B
M('-T>6QE/2)P861D:6YG.C`[(CX*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\/W!H<"!E8VAO("@Q,#`M)&%297-U;'1;
M)W!E<F-E;G0G72D_*#$P,"TD85)E<W5L=%LG<&5R8V5N="==+B<E)RDZ)R<@
M/SX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO
M=&0^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#PO='(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T86)L93X*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#PO='(^"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@96YD
M:68@/SX*"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@:68H0"1A4F5S=6QT
M6R=C;W5N=',G72DZ(#\^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT<CX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(Q,"(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@9F]R96%C
M:"@D85)E<W5L=%LG8V]U;G1S)UT@87,@)&%#;W5N=#T^)'9A;'5E*3H@/SX*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/#]P:'`@96-H
M;R`D84-O=6YT(#\^<R`](#P_<&AP(&5C:&\@)'9A;'5E(#\^("9N8G-P.R`F
M;F)S<#L@)FYB<W`[("9N8G-P.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#P_<&AP(&5N9&9O<F5A8V@@/SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@(#PO='(^
M"B`@("`@("`@("`@("`@("`@("`@/#]P:'`@96YD:68@/SX*"B`@("`@("`@
M("`@("`@("`@("`@/#]P:'`@:68H:7-S970H)&%297-U;'1;)W)E<W5L=',G
M75LG9F%I;'5R97,G72D@)B8@<VEZ96]F*"1A4F5S=6QT6R=R97-U;'1S)UU;
M)V9A:6QU<F5S)UTI*0H@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M*"1A4F5S=6QT6R=R97-U;'1S)UU;)V9A:6QU<F5S)UT@87,@)&%&86EL=7)E
M*3H@/SX*("`@("`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'1D(&-L87-S/2)F86EL=7)E(CX\/W!H<"!E
M8VAO("1A1F%I;'5R95LG=&5S=$YA;64G72`_/CPO=&0^"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*&ES<V5T*"1A1F%I
M;'5R95LG;65S<V%G92==*2`F)B`D849A:6QU<F5;)VUE<W-A9V4G72DZ(#\^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C
M:&\@)&%&86EL=7)E6R=M97-S86=E)UT@/SX*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`\/W!H<"!E;'-E.B`_/@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`\=&%B;&4@8VQA<W,](F]U=&QI;F5&86EL
M=7)E(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(#QT<CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\=&0^97AP96-T960\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QT9#X\/W!H<"!E8VAO("1A1F%I;'5R
M95LG97AP96-T960G72`_/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#QT9#YA8W1U86P\+W1D/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#QT9#X\/W!H
M<"!E8VAO("1A1F%I;'5R95LG86-T=6%L)UT@/SX\+W1D/@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1I9B`_/@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@("`@
M("`@("`@/"]T<CX*("`@("`@("`@("`@("`@("`@("`\/W!H<"!E;F1F;W)E
M86-H(#\^"@H@("`@("`@("`@("`@("`@("`@(#P_<&AP(&EF*&ES<V5T*"1A
M4F5S=6QT6R=R97-U;'1S)UU;)V5R<F]R<R==*2`F)B!S:7IE;V8H)&%297-U
M;'1;)W)E<W5L=',G75LG97)R;W)S)UTI*0H@("`@("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H*"1A4F5S=6QT6R=R97-U;'1S)UU;)V5R<F]R<R==(&%S
M("1A17)R;W(I.B`_/@H@("`@("`@("`@("`@("`@("`@("`@("`\='(^"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B
M/CP_<&AP(&5C:&\@)&%%<G)O<ELG=&5S=$YA;64G72`_/CPO=&0^"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`\=&0@8VQA<W,](F9A:6QU<F4B/@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_<&AP(&5C:&\@)&%%
M<G)O<ELG;65S<V%G92==(#\^"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@
M("`@("`@("`@("`@(#P_<&AP(&5N9&9O<F5A8V@@/SX*"B`@("`@("`@("`@
M("`@("`@("`@/#]P:'`@:68H:7-S970H)&%297-U;'1;)W)E<W5L=',G75LG
M<&%S<V5D)UTI("8F('-I>F5O9B@D85)E<W5L=%LG<F5S=6QT<R==6R=P87-S
M960G72DI"B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@H)&%297-U
M;'1;)W)E<W5L=',G75LG<&%S<V5D)UT@87,@)&%087-S960I.B`_/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`\=&0@8VQA<W,](G-U8V-E<W,B/CP_<&AP(&5C:&\@)&%087-S
M961;)W1E<W1.86UE)UT@/SX\+W1D/@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@/'1D(&-L87-S/2)S=6-C97-S(CX\8CY/2SPO8CX\+W1D/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\+W1R/@H@("`@("`@("`@("`@("`@("`@
M(#P_<&AP(&5N9&9O<F5A8V@@/SX*"B`@("`@("`@("`@("`@("`\/W!H<"!E
M;F1F;W)E86-H(#\^"B`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@/"]F
M;W)M/@H*("`@("`@("`\<V-R:7!T/@H@("`@("`@("`@("!V87(@86QL4W5I
M=&5.86UE<R`](&YE=R!!<G)A>2@I.PH@("`@("`@("`@("`\/W!H<"!F;W)E
M86-H*"1S=6ET95)E<W5L=',@87,@)&%297-U;'0I.B`_/@H@("`@("`@("`@
M("`@("`@86QL4W5I=&5.86UE<UMA;&Q3=6ET94YA;65S+FQE;F=T:%T@/2`B
M/#]P:'`@96-H;R`D85)E<W5L=%LG;F%M92==(#\^(CL*("`@("`@("`@("`@
M/#]P:'`@96YD9F]R96%C:"`_/@H@("`@("`@("`@("!F=6YC=&EO;B!U;D-H
M96-K06QL*"D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@7V-H96-K
M960@/2!D;V-U;65N="YO<'1I;VYS1F]R;2YA;&Q#:&5C:V5D+F-H96-K960[
M"B`@("`@("`@("`@("`@("!F;W(@*&D],#MI/&%L;%-U:71E3F%M97,N;&5N
M9W1H.VDK*RD@>PH@("`@("`@("`@("`@("`@("`@(&1O8W5M96YT+F]P=&EO
M;G-&;W)M6V%L;%-U:71E3F%M97-;:5U=+F-H96-K960@/2!?8VAE8VME9#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@(#PO<V-R
M:7!T/@H*("`@(#PO8F]D>3X*/"]H=&UL/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]02%!5;FET+T=522]3971U<$1E8V]R871O<BYP:'``````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#$V-38Q(#$P-3$U-#,T,3,S(#`R-#`V,0`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%!(4"!697)S:6]N(#0*("H*
M("H@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#4L(%-E8F%S=&EA;B!"97)G;6%N
M;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/BX*("H@06QL(')I9VAT<R!R
M97-E<G9E9"X*("H*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R
M8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF
M:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL
M;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*@H@*B`@("H@4F5D:7-T
M<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V
M92!C;W!Y<FEG:'0*("H@("`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@"B`J("`@
M*B!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U
M8V4@=&AE(&%B;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI
M<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R
M(&EN"B`J("`@("!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O;W(@;W1H97(@;6%T
M97)I86QS('!R;W9I9&5D('=I=&@@=&AE"B`J("`@("!D:7-T<FEB=71I;VXN
M"B`J"B`J("`@*B!.96ET:&5R('1H92!N86UE(&]F(%-E8F%S=&EA;B!"97)G
M;6%N;B!N;W(@=&AE(&YA;65S(&]F(&AI<PH@*B`@("`@8V]N=')I8G5T;W)S
M(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D
M97)I=F5D"B`J("`@("!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C
M:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J"B`J(%1(25,@4T]&
M5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.
M1"!#3TY44DE"551/4E,*("H@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@
M24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0*("H@3$E-
M251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"
M24Q)5%D@04Y$($9)5$Y%4U,*("H@1D]2($$@4$%25$E#54Q!4B!055)03U-%
M($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4*("H@0T]0
M65))1TA4($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.
M62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%
M6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'
M+`H@*B!"550@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-4
M25155$4@1T]/1%,@3U(@4T525DE#15,["B`J($Q/4U,@3T8@55-%+"!$051!
M+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T56
M15(*("H@0T%54T5$($%.1"!/3B!!3ED@5$A%3U)9($]&($Q)04))3$E462P@
M5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224,*("H@3$E!0DE,2519+"!/4B!4
M3U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)
M3D<@24X*("H@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&
M(%-50T@@1$%-04=%+@H@*@H@*B!`8V%T96=O<GD@("!497-T:6YG"B`J($!P
M86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@("`@5V]L9G)A;2!+<FEE
M<VEN9R`\=V]L9G)A;4!K<FEE<VEN9RYD93X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z(%-E='5P1&5C;W)A=&]R+G!H<"QV(#$N
M,34@,C`P-2\Q,2\Q,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C`N,`H@*B\*"B\J*@H@*B!4:&ES(&1E8V]R871O<B!A8W1U86QL>2!J=7-T
M(&%D9',@=&AE(&9U;F-T:6]N86QI='D@=&\@<F5A9"!T:&4*("H@=&5S="US
M=6ET92!C;&%S<V5S(&9R;VT@82!G:79E;B!D:7)E8W1O<GD@86YD(&EN<W1A
M;F-I871E('1H96T*("H@875T;VUA=&EC86QL>2P@=7-E(&ET(&%S(&=I=F5N
M(&EN('1H92!E>&%M<&QE(&)E;&]W+@H@*@H@*B`\8V]D93X*("H@/#]P:'`*
M("H@)&=U:2`](&YE=R!02%!5;FET7T=525]3971U<$1E8V]R871O<BAN97<@
M4$A056YI=%]'54E?2%1-3"@I*3L*("H@)&=U:2T^9V5T4W5I=&5S1G)O;41I
M<B@G+W!A=&@O=&\O9&ER+W1E<W1S)RPG+BI<+G!H<"0G+&%R<F%Y*"=I;F1E
M>"YP:'`G+"=S<6PN<&AP)RDI.PH@*B`D9W5I+3YS:&]W*"D["B`J(#\^"B`J
M(#PO8V]D93X*("H*("H@5&AE(&5X86UP;&4@8V%L;',@=&AI<R!C;&%S<R!A
M;F0@=&5L;',@:70@=&\Z"B`J"B`J("`@+2!F:6YD(&%L;"!F:6QE('5N9&5R
M('1H92!D:7)E8W1O<GD@+W!A=&@O=&\O9&ER+W1E<W1S"B`J("`@+2!F;W(@
M9FEL97,L('=H:6-H(&5N9"!W:71H("<N<&AP)R`H=&AI<R!I<R!A('!I96-E
M(&]F(&$@<F5G97AP+"!T:&%T)W,@=VAY('1H92`N(&ES(&5S8V%P960I"B`J
M("`@+2!A;F0@=&\@97AC;'5D92!T:&4@9FEL97,@)VEN9&5X+G!H<"<@86YD
M("=S<6PN<&AP)PH@*B`@("T@86YD(&EN8VQU9&4@86QL('1H92!F:6QE<R!T
M:&%T(&%R92!L969T(&EN('1H92!T97-T<RX*("H*("H@1VEV96X@=&AA="!T
M:&4@<&%T:"`H=&AE(&9I<G-T('!A<F%M971E<BD@96YD<R!W:71H("=T97-T
M<R<@:70@=VEL;"!B92!A<W-U;65D"B`J('1H870@=&AE(&-L87-S97,@87)E
M(&YA;65D('1E<W1S7RH@=VAE<F4@*B!I<R!T:&4@9&ER96-T;W)Y('!L=7,@
M=&AE(&9I;&5N86UE+`H@*B!A8V-O<F1I;F<@=&\@4$5!4B!S=&%N9&%R9',N
M"B`J"B`J(%-O('1H870Z"B`J"B`J("`@+2`G=&5S=$UE+G!H<"<@:6X@=&AE
M(&1I<B`G=&5S=',G(&)I;&P@8F4@87-S=6UE9"!T;R!C;VYT86EN(&$@8VQA
M<W,@=&5S='-?=&5S=$UE"B`J("`@+2`G+VUO<F5T97-T<R]A5&5S="YP:'`G
M('-H;W5L9"!C;VYT86EN(&$@8VQA<W,@)W1E<W1S7VUO<F5T97-T<U]A5&5S
M="<*("H*("H@0&-A=&5G;W)Y("`@5&5S=&EN9PH@*B!`<&%C:V%G92`@("!0
M2%!5;FET"B`J($!A=71H;W(@("`@(%=O;&9R86T@2W)I97-I;F<@/'=O;&9R
M86U`:W)I97-I;F<N9&4^"B`J($!C;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A
M<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G;6%N;BYD93X*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E
M<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@
M(%)E;&5A<V4Z(#$N,RXR"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]02%!5;FET"B`J($!S:6YC92`@("`@($-L87-S(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N,"XP"B`J+PIC;&%S<R!02%!5;FET
M7T=525]3971U<$1E8V]R871O<@I["B`@("`O*BH*("`@("H*("`@("H*("`@
M("HO"B`@("!F=6YC=&EO;B!02%!5;FET7T=525]3971U<$1E8V]R871O<B@F
M)&=U:2D*("`@('L*("`@("`@("`D=&AI<RT^7V=U:2`]("8D9W5I.PH@("`@
M?0H*("`@("\J*@H@("`@*B`@(&IU<W0@9F]R=V%R9&EN9R!T:&4@86-T:6]N
M('1O('1H92!D96-O<F%T960@8VQA<W,N"B`@("`J"B`@("`J+PH@("`@9G5N
M8W1I;VX@<VAO=R@D<VAO=U!A<W-E9#U44E5%*0H@("`@>PH@("`@("`@("1T
M:&ES+3Y?9W5I+3YS:&]W*"1S:&]W4&%S<V5D*3L*("`@('T*"B`@("`O*BH*
M("`@("H@4V5T=7`@=&5S="!S=6ET97,@=&AA="!C86X@8F4@9F]U;F0@:6X@
M=&AE(&=I=F5N(&1I<F5C=&]R>0H@("`@*B!5<VEN9R!T:&4@<V5C;VYD('!A
M<F%M971E<B!Y;W4@8V%N(&%L<V\@8VAO;W-E(&$@<W5B<V5T<R!O9B!T:&4@
M9FEL97,@9F]U;F0*("`@("H@:6X@=&AE(&=I=F5N(&1I<F5C=&]R>2X@22YE
M+B!O;FQY(&%L;"!T:&4@9FEL97,@=&AA="!C;VYT86EN("=?56YI=%1E<W1?
M)RP*("`@("H@:6X@;W)D97(@=&\@9&\@=&AI<R!S:6UP;'D@8V%L;"!I="!L
M:6ME('1H:7,Z"B`@("`J(#QC;V1E/F=E=%-U:71E<T9R;VU$:7(H)&1I<BPG
M+BI?56YI=%1E<W1?+BHG*3PO8V]D93XN"B`@("`J(%1H97)E('EO=2!C86X@
M86QR96%D>2!S964@=&AA="!T:&4@<&%T=&5R;B!I<R!B=6EL="!F;W(@=&AE
M('5S92!W:71H:6X@82!R96=U;&%R(&5X<')E<W-I;VXN"B`@("`J"B`@("`J
M($!P87)A;2`@<W1R:6YG("!T:&4@9&ER96-T;W)Y('=H97)E('1O('-E87)C
M:"!F;W(@=&5S="US=6ET92!F:6QE<PH@("`@*B!`<&%R86T@('-T<FEN9R`@
M=&AE('!A='1E<FX@*&$@<F5G97AP*2!B>2!W:&EC:"!T;R!F:6YD('1H92!F
M:6QE<PH@("`@*B!`<&%R86T@(&%R<F%Y("`@86X@87)R87D@;V8@9FEL92!N
M86UE<R!T:&%T('-H86QL(&)E(&5X8VQU9&5D"B`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4W5I=&5S1G)O;41I<B@D9&ER+"`D9FEL96YA;650871T97)N(#T@
M)R<L("1E>&-L=61E(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H)&1I
M<GMS=')L96XH)&1I<BDM,7T@/3T@1$E214-43U)97U-%4$%2051/4BD@>PH@
M("`@("`@("`@("`D9&ER(#T@<W5B<W1R*"1D:7(L(#`L("TQ*3L*("`@("`@
M("!]"@H@("`@("`@("1F:6QE<R`]("1T:&ES+3Y?9V5T1FEL97,H<F5A;'!A
M=&@H)&1I<BDL("1F:6QE;F%M95!A='1E<FXL("1E>&-L=61E+"!R96%L<&%T
M:"@D9&ER("X@)R\N+B<I*3L*("`@("`@("!A<V]R="@D9FEL97,I.PH*("`@
M("`@("!F;W)E86-H("@D9FEL97,@87,@)&-L87-S3F%M92`]/B`D849I;&4I
M('L*("`@("`@("`@("`@:6YC;'5D95]O;F-E*"1A1FEL92D["@H@("`@("`@
M("`@("!I9B`H8VQA<W-?97AI<W1S*"1C;&%S<TYA;64I*2!["B`@("`@("`@
M("`@("`@("`D<W5I=&5S6UT@/28@;F5W(%!(4%5N:71?5&5S=%-U:71E*"1C
M;&%S<TYA;64I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@=')I9V=E<E]E<G)O<B@B)&-L87-S3F%M92!C;W5L9"!N;W0@8F4@9F]U
M;F0@:6X@)&1I<B1A1FEL92$B*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@)'1H:7,M/E]G=6DM/F%D9%-U:71E<R@D<W5I=&5S*3L*("`@
M('T*"B`@("`O*BH*("`@("H@5&AI<R!M971H;V0@<V5A<F-H97,@<F5C=7)S
M:79E;'D@=&AR;W5G:"!T:&4@9&ER96-T;W)I97,*("`@("H@=&\@9FEN9"!A
M;&P@=&AE(&9I;&5S('1H870@<VAA;&P@8F4@861D960@=&\@=&AE(&)E('9I
M<VEB;&4N"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG("!T:&4@<&%T:"!W
M:&5R92!F:6YD('1H92!F:6QE<PH@("`@*B!`<&%R86T@('-R=&EN9R`@=&AE
M('-T<FEN9R!P871T97)N(&)Y('=H:6-H('1O(&9I;F0@=&AE(&9I;&5S"B`@
M("`J($!P87)A;2`@<W1R:6YG("!T:&4@9FEL92!N86UE<R!T;R!B92!E>&-L
M=61E9`H@("`@*B!`<&%R86T@('-T<FEN9R`@=&AE(')O;W0@9&ER96-T;W)Y
M+"!W:&EC:"!S97)V97,@87,@=&AE('!R969I>"!T;R!T:&4@9G5L;'D@<75A
M;&EF:65D(&9I;&5N86UE"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971&:6QE<R@D9&ER+"`D9FEL96YA;650871T97)N
M+"`D97AC;'5D92P@)')O;W1$:7(I"B`@("!["B`@("`@("`@)&9I;&5S(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"1D<"`](&]P96YD:7(H)&1I<BDI('L*
M("`@("`@("`@("`@=VAI;&4@*$9!3%-%("$]/2`H)&9I;&4@/2!R96%D9&ER
M*"1D<"DI*2!["B`@("`@("`@("`@("`@("`D9FEL96YA;64@/2`D9&ER("X@
M1$E214-43U)97U-%4$%2051/4B`N("1F:6QE.PH@("`@("`@("`@("`@("`@
M)&UA=&-H("`@(#T@5%)513L*"B`@("`@("`@("`@("`@("!I9B`H)&9I;&5N
M86UE4&%T=&5R;B`F)B`A<')E9U]M871C:"@B?B1F:6QE;F%M95!A='1E<FY^
M(BP@)&9I;&4I*2!["B`@("`@("`@("`@("`@("`@("`@)&UA=&-H(#T@1D%,
M4T4["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*'-I
M>F5O9B@D97AC;'5D92DI('L*("`@("`@("`@("`@("`@("`@("!F;W)E86-H
M("@D97AC;'5D92!A<R`D845X8VQU9&4I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*'-T<G!O<R@D9FEL92P@)&%%>&-L=61E*2`A/3T@1D%,4T4I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M871C:"`]($9!3%-%
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES7V9I;&4H)&9I
M;&5N86UE*2`F)B`D;6%T8V@I('L*("`@("`@("`@("`@("`@("`@("`D=&UP
M(#T@<W1R7W)E<&QA8V4H)')O;W1$:7(L("<G+"`D9FEL96YA;64I.PH*("`@
M("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1T;7`L($1)4D5#5$]265]3
M15!!4D%43U(I(#T]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M;7`@/2!S=6)S='(H)'1M<"P@,2D["B`@("`@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1T;7`L("<O)RD@/3T]
M(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1M<"`]('-U8G-T<B@D
M=&UP+"`Q*3L*("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@("`@("1C;&%S<TYA;64@/2!S=')?<F5P;&%C92A$25)%0U1/4EE?4T50
M05)!5$]2+"`G7R<L("1T;7`I.PH@("`@("`@("`@("`@("`@("`@("1C;&%S
M<TYA;64@/2!B87-E;F%M92@D8VQA<W-.86UE+"`G+G!H<"<I.PH*("`@("`@
M("`@("`@("`@("`@("`D9FEL97-;)&-L87-S3F%M95T@/2`D9FEL96YA;64[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*"1F:6QE
M("$]("<N)R`F)B`D9FEL92`A/2`G+BXG("8F(&ES7V1I<B@D9FEL96YA;64I
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&5S(#T@87)R87E?;65R9V4H
M)&9I;&5S+"`D=&AI<RT^7V=E=$9I;&5S*"1F:6QE;F%M92P@)&9I;&5N86UE
M4&%T=&5R;BP@)&5X8VQU9&4L("1R;V]T1&ER*2D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&-L;W-E9&ER*"1D<"D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&9I;&5S.PH@("`@?0I]"@HO
M*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A
M<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N="UE;F1E<BUP.B!N
M:6P*("H@16YD.@H@*B\*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+U!(4%5N:70O1U5)+T=T:RYP:'``````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-30S,C<@,3`U,34T,S0Q,S0@,#(Q-C0V
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@4$A0(%9E<G-I;VX@-`H@
M*@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P-2P@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^+@H@*B!!;&P@<FEG:'1S
M(')E<V5R=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O
M=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D
M:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O
M;&QO=VEN9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J"B`J("`@*B!2961I
M<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B
M;W9E(&-O<'ER:6=H=`H@*B`@("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B`*("H@
M("`J(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O
M9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT"B`J("`@("!N;W1I8V4L('1H:7,@
M;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM
M97(@:6X*("H@("`@('1H92!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M
M871E<FEA;',@<')O=FED960@=VET:"!T:&4*("H@("`@(&1I<W1R:6)U=&EO
M;BX*("H*("H@("`J($YE:71H97(@=&AE(&YA;64@;V8@4V5B87-T:6%N($)E
M<F=M86YN(&YO<B!T:&4@;F%M97,@;V8@:&ES"B`J("`@("!C;VYT<FEB=71O
M<G,@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S
M(&1E<FEV960*("H@("`@(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24PH@*B`B05,@25,B($%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5`H@*B!,
M24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534PH@*B!&3U(@02!005)424-53$%2(%!54E!/
M4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(10H@*B!#
M3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L"B`J($E.0TE$14Y404PL(%-014-)04PL
M($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L"B`J($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"
M4U1)5%5412!'3T]$4R!/4B!315)624-%4SL*("H@3$]34R!/1B!54T4L($1!
M5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7
M159%4@H@*B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519
M+"!72$542$52($E.($-/3E1204-4+"!35%))0PH@*B!,24%"24Q)5%DL($]2
M(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@05))
M4TE.1R!)3@H@*B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&
M5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@
M3T8@4U5#2"!$04U!1T4N"B`J"B`J($!C871E9V]R>2`@(%1E<W1I;F<*("H@
M0'!A8VMA9V4@("`@4$A056YI=`H@*B!`875T:&]R("`@("!38V]T="!-871T
M;V-K<R`\<V-O='1`8W)I<W-C;W1T+F-O;3X*("H@0&-O<'ER:6=H="`@,C`P
M,BTR,#`U(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M
M86YN+F1E/@H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N
M;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@
M0'9E<G-I;VX@("`@0U93.B`D260Z($=T:RYP:'`L=B`Q+C8@,C`P-2\Q,2\Q
M,"`P.3HT-SHQ-2!S96)A<W1I86X@17AP("0*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U!(4%5N:70*("H@0'-I;F-E("`@
M("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(N,`H@*B\*"FEF
M("@A9G5N8W1I;VY?97AI<W1S*"=I<U]A)RDI('L*("`@(')E<75I<F5?;VYC
M92`G4$A0+T-O;7!A="]&=6YC=&EO;B]I<U]A+G!H<"<["GT*"B\J*@H@*B!'
M5$L@1U5)(&EN=&5R9F%C92!F;W(@4$A056YI="X*("H*("H@5&AI<R!C;&%S
M<R!I<R!A(%!(4"!P;W)T(&]F(&IU;FET+F%W='5I+G1E<W1R=6YN97(N($1O
M8W5M96YT871I;VX*("H@9F]R(&IU;FET+F%W='5I+G1E<W1R=6YN97(@8V%N
M(&)E(&9O=6YD(&%T"B`J(&AT='`Z+R]J=6YI="YS;W5R8V5F;W)G92YN970*
M("H*("H@1'5E('1O('1H92!L:6UI=&%T:6]N<R!O9B!02%`T(&%N9"!02%`M
M1W1K+"!T:&ES(&-L87-S(&-A;B!N;W0*("H@9'5P;&EC871E(&%L;"!O9B!T
M:&4@9G5N8W1I;VYA;&ET>2!O9B!T:&4@2E5N:70@1U5)+B!3;VUE(&]F('1H
M90H@*B!T:&EN9W,@=&AI<R!C;&%S<R!C86YN;W0@9&\@:6YC;'5D93H*("H@
M+2!296QO861I;F<@=&AE(&-L87-S(&9O<B!E86-H(')U;@H@*B`M(%-T;W!P
M:6YG('1H92!T97-T(&EN('!R;V=R97-S"B`J"B`J(%1O('5S92!S:6UP;'D@
M:6YT86YT:6%T92!T:&4@8VQA<W,@86YD(&-A;&P@;6%I;B@I"B`J("1G=&L@
M/28@;F5W(%!(4%5N:71?1U5)7T=T:SL*("H@)&=T:RT^;6%I;B@I.PH@*@H@
M*B!/;F-E('1H92!W:6YD;W<@:&%S(&9I;FES:&5D(&QO861I;F<L('EO=2!C
M86X@96YT97(@=&AE(&YA;64@;V8*("H@82!C;&%S<R!T:&%T(&AA<R!B965N
M(&QO861E9"`H:6YC;'5D92]R97%U:7)E('-O;64@=VAE<F4@:6X@>6]U<@H@
M*B!C;V1E+"!O<B!Y;W4@8V%N('!A<W,@=&AE(&YA;64@;V8@=&AE(&9I;&4@
M8V]N=&%I;FEN9R!T:&4@8VQA<W,N"B`J"B`J(%EO=2!C86X@86QS;R!L;V%D
M(&-L87-S97,@=7-I;F<@=&AE(%-E='5P1&5C;W)A=&]R(&-L87-S+@H@*B!R
M97%U:7)E7V]N8V4@)U!(4%5N:70O1U5)+U-E='5P1&5C;W)A=&]R+G!H<"<[
M"B`J(')E<75I<F5?;VYC92`G4$A056YI="]'54DO1W1K+G!H<"<["B`J("1G
M=6D@/2!N97<@4$A056YI=%]'54E?4V5T=7!$96-O<F%T;W(H;F5W(%!(4%5N
M:71?1U5)7T=T:R@I*3L*("H@)&=U:2T^9V5T4W5I=&5S1G)O;41I<B@G+W!A
M=&@O=&\O=&5S="<L)RXJ7"YP:'`D)RQA<G)A>2@G:6YD97@N<&AP)RPG<W%L
M+G!H<"<I*3L*("H@)&=U:2T^<VAO=R@I.PH@*@H@*@H@*B!`8V%T96=O<GD@
M("!497-T:6YG"B`J($!P86-K86=E("`@(%!(4%5N:70*("H@0&%U=&AO<B`@
M("`@4V-O='0@36%T=&]C:W,@/'-C;W1T0&-R:7-S8V]T="YC;VT^"B`J($!C
M;W!Y<FEG:'0@(#(P,#(M,C`P-2!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E
M8F%S=&EA;BUB97)G;6%N;BYD93X*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)3
M1"!,:6-E;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N,RXR"B`J($!L
M:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]02%!5;FET
M"B`J($!S:6YC92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N,BXP"B`J($!T;V1O("`@("`@($%L;&]W(&9I;&4@9')O<"X@*$=T:U]&
M:6QE1')O<"D*("HO"F-L87-S(%!(4%5N:71?1U5)7T=T:R!["@H@("`@+RHJ
M"B`@("`@*B!4:&4@;6%I;B!G=&L@=VEN9&]W"B`@("`@*B!`=F%R(&]B:F5C
M=`H@("`@("HO"B`@("!V87(@)&=U:3L*("`@("\J*@H@("`@("H@5&AE('1E
M>'0@96YT<GD@=&AA="!C;VYT86EN<R!T:&4@;F%M92!O9B!T:&4*("`@("`J
M(&9I;&4@=&AA="!H;VQD<R!T:&4@=&5S="AS*2]S=6ET92AS*2X*("`@("`J
M($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D<W5I=&5&:65L9#L*("`@
M("\J*@H@("`@("H@5&AE(&QA8F5L('1H870@<VAO=W,@=&AE(&YU;6)E<B!O
M9B!T97-T<R!T:&%T"B`@("`@*B!W97)E(')U;BX*("`@("`J($!V87(@;V)J
M96-T"B`@("`@*B\*("`@('9A<B`D;G5M8F5R3V92=6YS.PH@("`@+RHJ"B`@
M("`@*B!4:&4@;&%B96P@=&AA="!S:&]W<R!T:&4@;G5M8F5R(&]F(&5R<F]R
M<R!T:&%T"B`@("`@*B!W97)E(&5N8V]U;G1E<F5D+@H@("`@("H@0'9A<B!O
M8FIE8W0*("`@("`J+PH@("`@=F%R("1N=6UB97)/9D5R<F]R<SL*("`@("\J
M*@H@("`@("H@5&AE(&QA8F5L('1H870@<VAO=W,@=&AE(&YU;6)E<B!O9B!F
M86EL=7)E<PH@("`@("H@=&AA="!W97)E(&5N8V]U;G1E<F5D+@H@("`@("H@
M0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1N=6UB97)/9D9A:6QU<F5S
M.PH@("`@+RHJ"B`@("`@*B!4:&4@;&%B96P@9F]R(')E<&]R=&EN9R!U<V5R
M(&UE<W-A9V5S+@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R
M("1S=&%T=7-,:6YE.PH@("`@+RHJ"B`@("`@*B!4:&4@=&5X="!A<F5A(&9O
M<B!R97!O<G1I;F<@;65S<V%G97,@9G)O;2!S=6-C97-S9G5L"B`@("`@*B!T
M97-T(')U;G,N("AN;W0@;F5C97-S87)I;'D@<W5C8V5S<V9U;"!T97-T<RD*
M("`@("`J($!V87(@;V)J96-T"B`@("`@*B\*("`@('9A<B`D<F5P;W)T07)E
M83L*("`@("\J*@H@("`@("H@5&AE('1E>'0@87)E82!F;W(@<F5P;W)T:6YG
M(&5R<F]R<R!E;F-O=6YT97)E9"!W:&5N"B`@("`@*B!R=6YN:6YG('1E<W1S
M+@H@("`@("H@0'9A<B!O8FIE8W0*("`@("`J+PH@("`@=F%R("1D=6UP07)E
M83L*("`@("\J*@H@("`@("H@5&AE('!R;V=R97-S(&)A<B!I;F1I8V%T;W(N
M(%-H;W=S('1H92!P97)C96YT86=E(&]F"B`@("`@*B!P87-S960@=&5S=',N
M"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO"B`@("!V87(@)'!R;V=R97-S
M.PH@("`@+RHJ"B`@("`@*B!!(&-H96-K8F]X(&9O<B!T:&4@=7-E<B!T;R!I
M;F1I8V%T92!W:&5T:&5R(&]R(&YO="!T:&5Y"B`@("`@*B!W;W5L9"!L:6ME
M('1O('-E92!R97-U;'1S(&9R;VT@86QL('1E<W1S(&]R(&IU<W0@9F%I;'5R
M97,N"B`@("`@*B!`;V)J96-T"B`@("`@*B\*("`@('9A<B`D<VAO=U!A<W-E
M9#L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J
M(%1H92!C;VYS=')U8W1O<B!C:&5C:W,@9F]R('1H92!G=&L@97AT96YS:6]N
M(&%N9"!L;V%D<R!I=`H@("`@("H@:68@;F5E9&5D+B!4:&5N(&ET(&-R96%T
M97,@=&AE($=522X@5&AE($=522!I<R!N;W0@<VAO=VX*("`@("`J(&YO<B!I
M<R!T:&4@;6%I;B!G=&L@;&]O<"!S=&%R=&5D('5N=&EL(&UA:6XH*2!I<R!C
M86QL960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P
M87)A;2`@;F]N90H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N(%!(4%5N:71?1U5)7T=T:R@I"B`@("!["B`@("`@("`@+R\@0VAE
M8VL@9F]R('!H<"UG=&L@97AT96YS:6]N+@H@("`@("`@(&EF("@A97AT96YS
M:6]N7VQO861E9"@G9W1K)RDI('L*("`@("`@("`@("`@9&PH("=P:'!?9W1K
M+B<@+B!02%!?4TA,24)?4U5&1DE8*3L*("`@("`@("!]"@H@("`@("`@("\O
M($-R96%T92!T:&4@:6YT97)F86-E(&)U="!D;VXG="!S=&%R="!T:&4@;&]O
M<`H@("`@("`@("1T:&ES+3Y?8W)E871E54DH*3L*("`@('T*("`@("\J*@H@
M("`@("H@4W1A<G0@=&AE(&UA:6X@9W1K(&QO;W`N"B`@("`@*@H@("`@("H@
M;6%I;B@I(&9I<G-T('-E=',@=&AE(&1E9F%U;'0@<W1A=&4@;V8@=&AE('-H
M;W=087-S960*("`@("`J(&-H96-K(&)O>"X@3F5X="!A;&P@=VED9V5T<R!T
M:&%T(&%R92!P87)T(&]F('1H92!'54D*("`@("`J(&%R92!S:&]W;BX@1FEN
M86QL>2!T:&4@;6%I;B!G=&L@;&]O<"!I<R!S=&%R=&5D+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@(&)O;VQE86X@)'-H
M;W=087-S960*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!M86EN*"1S:&]W4&%S<V5D(#T@=')U92D*("`@('L*("`@("`@("`D
M=&AI<RT^<VAO=U!A<W-E9"T^<V5T7V%C=&EV92@D<VAO=U!A<W-E9"D["B`@
M("`@("`@)'1H:7,M/F=U:2T^<VAO=U]A;&PH*3L*"B`@("`@("`@9W1K.CIM
M86EN*"D["B`@("!]"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@=7-E<B!I
M;G1E<F9A8V4N"B`@("`@*@H@("`@("H@5&AE('5S97(@:6YT97)F86-E(&ES
M('!R971T>2!S:6UP;&4N($ET(&-O;G-I<W1S(&]F(&$*("`@("`J(&UE;G4L
M('1E>'0@96YT<GDL(')U;B!B=71T;VXL('-O;64@;&%B96QS+"!A('!R;V=R
M97-S"B`@("`@*B!I;F1I8V%T;W(L(&%N9"!A(&-O=7!L92!O9B!A<F5A<R!F
M;W(@;F]T:69I8V%T:6]N(&]F"B`@("`@*B!A;GD@;65S<V%G97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*
M("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E
M871E54DH*0H@("`@>PH@("`@("`@("\O($-R96%T92!A('=I;F1O=RX*("`@
M("`@("`D=VEN9&]W(#TF(&YE=R!'=&M7:6YD;W<["B`@("`@("`@)'=I;F1O
M=RT^<V5T7W1I=&QE*"=02%!5;FET($=T:R<I.PH@("`@("`@("1W:6YD;W<M
M/G-E=%]U<VEZ92@T,#`L("TQ*3L*"B`@("`@("`@+R\@0W)E871E('1H92!M
M86EN(&)O>"X*("`@("`@("`D;6%I;D)O>"`])B!N97<@1W1K5D)O>#L*("`@
M("`@("`D=VEN9&]W+3YA9&0H)&UA:6Y";W@I.PH*("`@("`@("`O+R!3=&%R
M="!W:71H('1H92!M96YU+@H@("`@("`@("1M86EN0F]X+3YP86-K7W-T87)T
M*"1T:&ES+3Y?8W)E871E365N=2@I*3L*"B`@("`@("`@+R\@5&AE;B!A9&0@
M=&AE('-U:71E(&9I96QD(&5N=')Y+@H@("`@("`@("1M86EN0F]X+3YP86-K
M7W-T87)T*"1T:&ES+3Y?8W)E871E4W5I=&5%;G1R>2@I*3L*"B`@("`@("`@
M+R\@5&AE;B!A9&0@=&AE(')E<&]R="!L86)E;',N"B`@("`@("`@)&UA:6Y"
M;W@M/G!A8VM?<W1A<G0H)'1H:7,M/E]C<F5A=&5297!O<G1,86)E;',H*2D[
M"@H@("`@("`@("\O($YE>'0@861D('1H92!P<F]G<F5S<R!B87(N"B`@("`@
M("`@)&UA:6Y";W@M/G!A8VM?<W1A<G0H)'1H:7,M/E]C<F5A=&50<F]G<F5S
M<T)A<B@I*3L*"B`@("`@("`@+R\@5&AE;B!A9&0@=&AE(')E<&]R="!A<F5A
M(&%N9"!T:&4@9'5M<"!A<F5A+@H@("`@("`@("1M86EN0F]X+3YP86-K7W-T
M87)T*"1T:&ES+3Y?8W)E871E4F5P;W)T07)E87,H*2D["@H@("`@("`@("\O
M($9I;FES:"!O9F8@=VET:"!T:&4@<W1A='5S(&QI;F4N"B`@("`@("`@)&UA
M:6Y";W@M/G!A8VM?<W1A<G0H)'1H:7,M/E]C<F5A=&53=&%T=7-,:6YE*"DI
M.PH*("`@("`@("`O+R!#;VYN96-T('1H92!D97-T<F]Y('-I9VYA;"X*("`@
M("`@("`D=VEN9&]W+3YC;VYN96-T7V]B:F5C="@G9&5S=')O>2<L(&%R<F%Y
M*"=G=&LG+"`G;6%I;E]Q=6ET)RDI.PH*("`@("`@("`O+R!!<W-I9VX@=&AE
M(&UE;6)E<BX*("`@("`@("`D=&AI<RT^9W5I(#TF("1W:6YD;W<["B`@("!]
M"B`@("`O*BH*("`@("`J($-R96%T92!T:&4@;65N=2X*("`@("`J"B`@("`@
M*B!4:&4@;65N=2!I<R!V97)Y('-I;7!L92X@270@86X@97AI="!M96YU(&ET
M96TL('=H:6-H(&5X:71S"B`@("`@*B!T:&4@87!P;&EC871I;VXL(&%N9"!A
M;B!A8F]U="!M96YU(&ET96TL('=H:6-H('-H;W=S('-O;64*("`@("`J(&)A
M<VEC(&EN9F]R;6%T:6]N(&%B;W5T('1H92!A<'!L:6-A=&EO;B!I='-E;&8N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@
M(&YO;F4*("`@("`J($!R971U<FX@)F]B:F5C="!4:&4@1W1K365N=4)A<@H@
M("`@("HO"B`@("!F=6YC=&EO;B`F7V-R96%T94UE;G4H*0H@("`@>PH@("`@
M("`@("\O($-R96%T92!T:&4@;65N=2!B87(N"B`@("`@("`@)&UE;G5"87(@
M/28@;F5W($=T:TUE;G5"87(["@H@("`@("`@("\O($-R96%T92!T:&4@;6%I
M;B`H;VYL>2D@;65N=2!I=&5M+@H@("`@("`@("1P:'!(96%D97(@/28@;F5W
M($=T:TUE;G5)=&5M*"=02%!5;FET)RD["@H@("`@("`@("\O($%D9"!T:&4@
M;65N=2!I=&5M('1O('1H92!M96YU(&)A<BX*("`@("`@("`D;65N=4)A<BT^
M87!P96YD*"1P:'!(96%D97(I.PH*("`@("`@("`O+R!#<F5A=&4@=&AE(%!(
M4%5N:70@;65N=2X*("`@("`@("`D<&AP365N=2`])B!N97<@1W1K365N=3L*
M"B`@("`@("`@+R\@061D('1H92!M96YU(&ET96US"B`@("`@("`@)&%B;W5T
M(#TF(&YE=R!'=&M-96YU271E;2@G06)O=70N+BXG*3L*("`@("`@("`D86)O
M=70M/F-O;FYE8W0H)V%C=&EV871E)RP@87)R87DH)B1T:&ES+"`G86)O=70G
M*2D["B`@("`@("`@)'!H<$UE;G4M/F%P<&5N9"@D86)O=70I.PH*("`@("`@
M("`D97AI="`])B!N97<@1W1K365N=4ET96TH)T5X:70G*3L*("`@("`@("`D
M97AI="T^8V]N;F5C=%]O8FIE8W0H)V%C=&EV871E)RP@87)R87DH)V=T:R<L
M("=M86EN7W%U:70G*2D["B`@("`@("`@)'!H<$UE;G4M/F%P<&5N9"@D97AI
M="D["@H@("`@("`@("\O($-O;7!L971E('1H92!M96YU+@H@("`@("`@("1P
M:'!(96%D97(M/G-E=%]S=6)M96YU*"1P:'!-96YU*3L*"B`@("`@("`@<F5T
M=7)N("1M96YU0F%R.PH@("`@?0H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE
M('-U:71E(&5N=')Y(&%N9"!R96QA=&5D('=I9&=E=',N"B`@("`@*@H@("`@
M("H@5&AE('-U:71E(&5N=')Y(&AA<R!S;VUE('-U<'!O<G1I;F<@8V]M<&]N
M96YT<R!S=6-H(&%S(&$*("`@("`J(&QA8F5L+"!T:&4@<VAO=R!P87-S960@
M8VAE8VL@8F]X(&%N9"!T:&4@<G5N(&)U='1O;BX@06QL"B`@("`@*B!O9B!T
M:&5S92!I=&5M<R!A<F4@<&%C:V5D(&EN=&\@='=O(&YE<W1E9"!B;WAE<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@
M;F]N90H@("`@("H@0')E='5R;B`F;V)J96-T($$@8F]X('1H870@8V]N=&%I
M;G,@86QL(&]F('1H92!S=6ET92!E;G1R>2!P:65C97,N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?8W)E871E4W5I=&5%;G1R>2@I"B`@("!["B`@("`@("`@
M+R\@0W)E871E('1H92!O=71E<FUO<W0@8F]X+@H@("`@("`@("1O=71E<D)O
M>"`@("`@("`@(#TF(&YE=R!'=&M60F]X.PH*("`@("`@("`O+R!#<F5A=&4@
M=&AE('-U:71E(&QA8F5L+"!B;W@L(&%N9"!F:65L9"X*("`@("`@("`D<W5I
M=&5,86)E;"`@("`@("`])B!N97<@1W1K3&%B96PH)U1E<W0@8VQA<W,@;F%M
M93HG*3L*("`@("`@("`D<W5I=&5";W@@("`@("`@("`])B!N97<@1W1K2$)O
M>#L*("`@("`@("`D=&AI<RT^<W5I=&5&:65L9"`])B!N97<@1W1K16YT<GD[
M"B`@("`@("`@)'1H:7,M/G-U:71E1FEE;&0M/G-E=%]T97AT*"1S=6ET94YA
M;64@(3T@3E5,3"`_("1S=6ET94YA;64@.B`G)RD["@H@("`@("`@("\O($-R
M96%T92!T:&4@8G5T=&]N('1H92!U<V5R('=I;&P@=7-E('1O('-T87)T('1H
M92!T97-T+@H@("`@("`@("1R=6Y"=71T;VX@/28@;F5W($=T:T)U='1O;B@G
M4G5N)RD["B`@("`@("`@)')U;D)U='1O;BT^8V]N;F5C=%]O8FIE8W0H)V-L
M:6-K960G+"!A<G)A>2@F)'1H:7,L("=R=6XG*2D["@H@("`@("`@("\O($-R
M96%T92!T:&4@8VAE8VL@8F]X('1H870@;&5T<R!T:&4@=7-E<B!S:&]W(&]N
M;'D@9F%I;'5R97,N"B`@("`@("`@)'1H:7,M/G-H;W=087-S960@/28@;F5W
M($=T:T-H96-K0G5T=&]N*"=3:&]W('!A<W-E9"!T97-T<R<I.PH*("`@("`@
M("`O+R!!9&0@=&AE(&-O;7!O;F5N=',@=&\@=&AE:7(@<F5S<&5C=&EV92!B
M;WAE<RX*("`@("`@("`D<W5I=&5,86)E;"T^<V5T7V%L:6=N;65N="@P+"`P
M*3L*("`@("`@("`D;W5T97)";W@M/G!A8VM?<W1A<G0H)'-U:71E3&%B96PI
M.PH@("`@("`@("1O=71E<D)O>"T^<&%C:U]S=&%R="@D<W5I=&5";W@I.PH@
M("`@("`@("1O=71E<D)O>"T^<&%C:U]S=&%R="@D=&AI<RT^<VAO=U!A<W-E
M9"D["@H@("`@("`@("1S=6ET94)O>"T^<&%C:U]S=&%R="@D=&AI<RT^<W5I
M=&5&:65L9"D["B`@("`@("`@)'-U:71E0F]X+3YP86-K7W-T87)T*"1R=6Y"
M=71T;VXI.PH*("`@("`@("!R971U<FX@)&]U=&5R0F]X.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0W)E871E('1H92!L86)E;',@=&AA="!T96QL('1H92!U
M<V5R('=H870@:&%S(&AA<'!E;F5D+@H@("`@("H*("`@("`J(%1H97)E(&%R
M92!T:')E92!L86)E;',L(&]N92!E86-H(&9O<B!T;W1A;"!R=6YS+"!E<G)O
M<G,@86YD"B`@("`@*B!F86EL=7)E<RX@5&AE<F4@:7,@86QS;R!O;F4@;&%B
M96P@9F]R(&5A8V@@;V8@=&AE<V4@=&AA=`H@("`@("H@9&5S8W)I8F5S('=H
M870@=&AE(&QA8F5L(&ES+B!)="!C;W5L9"!B92!D;VYE('=I=&@@;VYE(&QA
M8F5L"B`@("`@*B!I;G-T96%D(&]F('1W;R!B=70@=&AA="!W;W5L9"!M86ME
M('5P9&%T97,@;75C:"!H87)D97(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<&%R86T@(&YO;F4*("`@("`J($!R971U<FX@)F]B
M:F5C="!!(&)O>"!C;VYT86EN:6YG('1H92!L86)E;',N"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?8W)E871E4F5P;W)T3&%B96QS*"D*("`@('L*("`@("`@
M("`O+R!#<F5A=&4@82!B;W@@=&\@:&]L9"!E=F5R>71H:6YG+@H@("`@("`@
M("1L86)E;$)O>"`@("`@("`@(#TF(&YE=R!'=&M(0F]X.PH*("`@("`@("`O
M+R!#<F5A=&4@=&AE(&YO;BUU<&1A=&5D(&QA8F5L<RX*("`@("`@("`D;G5M
M8F5R3V92=6YS("`@("`])B!N97<@1W1K3&%B96PH)U)U;G,Z)RD["B`@("`@
M("`@)&YU;6)E<D]F17)R;W)S("`@/28@;F5W($=T:TQA8F5L*"=%<G)O<G,Z
M)RD["B`@("`@("`@)&YU;6)E<D]F1F%I;'5R97,@/28@;F5W($=T:TQA8F5L
M*"=&86EL=7)E<SHG*3L*"B`@("`@("`@+R\@0W)E871E('1H92!L86)E;',@
M=&AA="!W:6QL(&)E('5P9&%T960N"B`@("`@("`@+R\@5&AE<V4@87)E(&%S
M<W-I9VYE9"!T;R!M96UB97)S('1O(&UA:V4@:70@96%S:65R('1O"B`@("`@
M("`@+R\@<V5T('1H96ER('9A;'5E<R!L871E<BX*("`@("`@("`D=&AI<RT^
M;G5M8F5R3V92=6YS("`@("`])B!N97<@1W1K3&%B96PH,"D["B`@("`@("`@
M)'1H:7,M/FYU;6)E<D]F17)R;W)S("`@/28@;F5W($=T:TQA8F5L*#`I.PH@
M("`@("`@("1T:&ES+3YN=6UB97)/9D9A:6QU<F5S(#TF(&YE=R!'=&M,86)E
M;"@P*3L*"B`@("`@("`@+R\@4&%C:R!E=F5R>71H:6YG(&EN+@H@("`@("`@
M("1L86)E;$)O>"T^<&%C:U]S=&%R="@D;G5M8F5R3V92=6YS*3L*("`@("`@
M("`D;&%B96Q";W@M/G!A8VM?<W1A<G0H)'1H:7,M/FYU;6)E<D]F4G5N<RD[
M"B`@("`@("`@)&QA8F5L0F]X+3YP86-K7W-T87)T*"1N=6UB97)/9D5R<F]R
M<RD["B`@("`@("`@)&QA8F5L0F]X+3YP86-K7W-T87)T*"1T:&ES+3YN=6UB
M97)/9D5R<F]R<RD["B`@("`@("`@)&QA8F5L0F]X+3YP86-K7W-T87)T*"1N
M=6UB97)/9D9A:6QU<F5S*3L*("`@("`@("`D;&%B96Q";W@M/G!A8VM?<W1A
M<G0H)'1H:7,M/FYU;6)E<D]F1F%I;'5R97,I.PH*("`@("`@("!R971U<FX@
M)&QA8F5L0F]X.PH@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E('1H92!S
M=6-C97-S+V9A:6QU<F4@:6YD:6-A=&]R+@H@("`@("H*("`@("`J($$@1W1K
M4')O9W)E<W-"87(@:7,@=7-E9"!T;R!V:7-U86QL>2!I;F1I8V%T92!H;W<@
M;6%N>0H@("`@("H@=&5S=',@=V5R92!S=6-C97-S9G5L(&-O;7!A<F5D('1O
M(&AO=R!M86YY('=E<F4@;F]T+B!4:&4*("`@("`J('!R;V=R97-S(&)A<B!S
M:&]W<R!T:&4@<&5R8V5N=&%G92!O9B!S=6-C97-S(&%N9"!W:6QL"B`@("`@
M*B!C:&%N9V4@9G)O;2!G<F5E;B!T;R!R960@:68@=&AE<F4@87)E(&%N>2!F
M86EL=7)E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B`F;V)J96-T(%1H92!P<F]G
M<F5S<R!B87(*("`@("`J+PH@("`@9G5N8W1I;VX@)E]C<F5A=&50<F]G<F5S
M<T)A<B@I"B`@("!["B`@("`@("`@+R\@0W)E871E('1H92!P<F]G<F5S<R!B
M87(N"B`@("`@("`@)'1H:7,M/G!R;V=R97-S(#TF(&YE=R!'=&M0<F]G<F5S
M<T)A<BAN97<@1W1K061J=7-T;65N="@P+"`P+"`Q+"`N,2P@,2P@,"DI.PH*
M("`@("`@("`O+R!3970@=&AE('!R;V=R97-S(&)A<B!T;R!P<FEN="!T:&4@
M<&5R8V5N=&%G92X*("`@("`@("`D=&AI<RT^<')O9W)E<W,M/G-E=%]S:&]W
M7W1E>'0H=')U92D["@H@("`@("`@(')E='5R;B`D=&AI<RT^<')O9W)E<W,[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE(')E<&]R="!T97AT
M(&%R96%S+@H@("`@("H*("`@("`J(%1H92!R97!O<G0@87)E82!C;VYS:7-T
M<R!O9B!O;F4@=&5X="!A<F5A(&9O<B!F86EL=7)E<RP@;VYE"B`@("`@*B!T
M97AT(&%R96$@9F]R(&5R<F]R<R!A;F0@;VYE(&QA8F5L(&9O<B!I9&5N=&EF
M:6-A=&EO;B!P=7)P;W-E<RX*("`@("`J($%L;"!T:')E92!W:61G971S(&%R
M92!P86-K960@:6YT;R!A(&)O>"X*("`@("`J"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B`F;V)J
M96-T(%1H92!B;W@@8V]N=&%I;FEN9R!T:&4@<F5P;W)T(&%R96%S+@H@("`@
M("HO"B`@("!F=6YC=&EO;B`F7V-R96%T95)E<&]R=$%R96%S*"D*("`@('L*
M("`@("`@("`O+R!#<F5A=&4@=&AE(&-O;G1A:6YI;F<@8F]X+@H@("`@("`@
M("1R97!O<G1";W@@/28@;F5W($=T:U9";W@["@H@("`@("`@("\O($-R96%T
M92!T:&4@:61E;G1I9FEC871I;VX@;&%B96P*("`@("`@("`D<F5P;W)T3&%B
M96P@/28@;F5W($=T:TQA8F5L*"=%<G)O<G,@86YD($9A:6QU<F5S.B<I.PH@
M("`@("`@("1R97!O<G1,86)E;"T^<V5T7V%L:6=N;65N="@P+"`P*3L*"B`@
M("`@("`@+R\@0W)E871E('1H92!S8W)O;&QE9"!W:6YD;W=S(&9O<B!T:&4@
M=&5X="!A<F5A<RX*("`@("`@("`D<F5P;W)T4V-R;VQL(#TF(&YE=R!'=&M3
M8W)O;&QE9%=I;F1O=SL*("`@("`@("`D9'5M<%-C<F]L;"`@(#TF(&YE=R!'
M=&M38W)O;&QE9%=I;F1O=SL*"B`@("`@("`@+R\@36%K92!T:&4@<V-R;VQL
M(&%R96%S(&)I9R!E;F]U9V@N"B`@("`@("`@)')E<&]R=%-C<F]L;"T^<V5T
M7W5S:7IE*"TQ+"`Q-3`I.PH@("`@("`@("1D=6UP4V-R;VQL+3YS971?=7-I
M>F4H+3$L(#$U,"D["@H@("`@("`@("\O($]N;'D@<VAO=R!T:&4@=F5R=&EC
M86P@<V-R;VQL(&)A<B!W:&5N(&YE961E9"X*("`@("`@("`O+R!.979E<B!S
M:&]W('1H92!H;W)I>F]N=&%L('-C<F]L;"!B87(N"B`@("`@("`@)')E<&]R
M=%-C<F]L;"T^<V5T7W!O;&EC>2A'5$M?4$],24-97TY%5D52+"!'5$M?4$],
M24-97T%55$]-051)0RD["B`@("`@("`@)&1U;7!38W)O;&PM/G-E=%]P;VQI
M8WDH1U1+7U!/3$E#65].159%4BP@1U1+7U!/3$E#65]!551/34%424,I.PH*
M("`@("`@("`O+R!#<F5A=&4@=&AE('1E>'0@87)E87,N"B`@("`@("`@)'1H
M:7,M/G)E<&]R=$%R96$@/28@;F5W($=T:U1E>'0["B`@("`@("`@)'1H:7,M
M/F1U;7!!<F5A(#TF(&YE=R!'=&M497AT.PH*("`@("`@("`O+R!$;VXG="!L
M970@=V]R9',@9V5T(&)R;VME;BX*("`@("`@("`D=&AI<RT^<F5P;W)T07)E
M82T^<V5T7W=O<F1?=W)A<"AT<G5E*3L*("`@("`@("`D=&AI<RT^9'5M<$%R
M96$M/G-E=%]W;W)D7W=R87`H=')U92D["@H@("`@("`@("\O(%!A8VL@979E
M<GET:&EN9R!I;BX*("`@("`@("`D<F5P;W)T0F]X+3YP86-K7W-T87)T*"1R
M97!O<G1,86)E;"D["B`@("`@("`@)')E<&]R=%-C<F]L;"T^861D*"1T:&ES
M+3YR97!O<G1!<F5A*3L*("`@("`@("`D<F5P;W)T0F]X+3YP86-K7W-T87)T
M*"1R97!O<G138W)O;&PI.PH@("`@("`@("1D=6UP4V-R;VQL+3YA9&0H)'1H
M:7,M/F1U;7!!<F5A*3L*("`@("`@("`D<F5P;W)T0F]X+3YP86-K7W-T87)T
M*"1D=6UP4V-R;VQL*3L*"B`@("`@("`@<F5T=7)N("1R97!O<G1";W@["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!S=&%T=7,@;&%B96PN"B`@
M("`@*@H@("`@("H@02!S=&%T=7,@;&EN92!A="!T:&4@8F]T=&]M(&]F('1H
M92!A<'!L:6-A=&EO;B!I<R!U<V5D"B`@("`@*B!T;R!N;W1I9GD@=&AE('5S
M97(@;V8@;F]N+71E<W0@<F5L871E9"!M97-S86=E<R!S=6-H(&%S"B`@("`@
M*B!F86EL=7)E<R!L;V%D:6YG(&$@=&5S="!S=6ET92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@
M0')E='5R;B`F;V)J96-T(%1H92!S=&%T=7,@;&%B96PN"B`@("`@*B\*("`@
M(&9U;F-T:6]N("9?8W)E871E4W1A='5S3&EN92@I"B`@("!["B`@("`@("`@
M+R\@0W)E871E('1H92!S=&%T=7,@;&%B96PN"B`@("`@("`@)'1H:7,M/G-T
M871U<TQI;F4@/28@;F5W($=T:TQA8F5L*"<G*3L*("`@("`@("`D=&AI<RT^
M<W1A='5S3&EN92T^<V5T7V%L:6=N;65N="@P+"`P*3L*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YS=&%T=7-,:6YE.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4VAO=R!A('!O<'5P('=I=&@@:6YF;W)M871I;VX@86)O=70@=&AE(&%P<&QI
M8V%T:6]N+@H@("`@("H*("`@("`J(%1H92!P;W!U<"!S:&]U;&0@<VAO=R!I
M;F9O<FUA=&EO;B!A8F]U="!T:&4@=F5R<VEO;BP*("`@("`J('1H92!A=71H
M;W(L('1H92!L:6-E;G-E+"!W:&5R92!T;R!G970@=&AE(&QA=&5S=`H@("`@
M("H@=F5R<VEO;B!A;F0@82!S:&]R="!D97-C<FEP=&EO;BX*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!N;VYE"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@86)O=70H*0H@
M("`@>PH@("`@("`@("\O($-R96%T92!T:&4@;F5W('=I;F1O=RX*("`@("`@
M("`D86)O=70@/28@;F5W($=T:U=I;F1O=SL*("`@("`@("`D86)O=70M/G-E
M=%]T:71L92@G06)O=70@4$A056YI="!'54D@1W1K)RD["B`@("`@("`@)&%B
M;W5T+3YS971?=7-I>F4H,C4P+"`M,2D["@H@("`@("`@("\O(%!U="!T=V\@
M=F)O>&5S(&EN('1H92!H8F]X+@H@("`@("`@("1V0F]X(#TF(&YE=R!'=&M6
M0F]X.PH@("`@("`@("1A8F]U="T^861D*"1V0F]X*3L*"B`@("`@("`@+R\@
M0W)E871E('1H92!L86)E;',N"B`@("`@("`@)'9E<G-I;VX@("`@(#TF(&YE
M=R!'=&M,86)E;"@B(%9E<G-I;VXZ(#$N,"(I.PH@("`@("`@("1L:6-E;G-E
M("`@("`])B!N97<@1W1K3&%B96PH(B!,:6-E;G-E.B!02%`@3&EC96YS92!V
M,RXP(BD["B`@("`@("`@)'=H97)E("`@("`@(#TF(&YE=R!'=&M,86)E;"@B
M($1O=VYL;V%D(&9R;VTZ(&AT='`Z+R]P96%R+G!H<"YN970O4$A056YI="\B
M*3L*("`@("`@("`D=6YI=$%U=&@@("`@/28@;F5W($=T:TQA8F5L*"(@4$A0
M56YI="!!=71H;W(Z(%-E8F%S=&EA;B!"97)G;6%N(BD["B`@("`@("`@)&=T
M:T%U=&@@("`@(#TF(&YE=R!'=&M,86)E;"@B($=T:R!'54D@075T:&]R.B!3
M8V]T="!-871T;V-K<R(I.PH*("`@("`@("`O+R!!;&EG;B!E=F5R>71H:6YG
M('1O('1H92!L969T"B`@("`@("`@)'=H97)E+3YS971?86QI9VYM96YT*#`L
M("XU*3L*("`@("`@("`D=F5R<VEO;BT^<V5T7V%L:6=N;65N="@P+"`N-2D[
M"B`@("`@("`@)&QI8V5N<V4M/G-E=%]A;&EG;FUE;G0H,"P@+C4I.PH@("`@
M("`@("1G=&M!=71H+3YS971?86QI9VYM96YT*#`L("XU*3L*("`@("`@("`D
M=6YI=$%U=&@M/G-E=%]A;&EG;FUE;G0H,"P@+C4I.PH*("`@("`@("`O+R!0
M86-K(&5V97)Y=&AI;F<@:6YT;R!T:&4@=D)O>#L*("`@("`@("`D=D)O>"T^
M<&%C:U]S=&%R="@D=F5R<VEO;BD["B`@("`@("`@)'9";W@M/G!A8VM?<W1A
M<G0H)&QI8V5N<V4I.PH@("`@("`@("1V0F]X+3YP86-K7W-T87)T*"1W:&5R
M92D["B`@("`@("`@)'9";W@M/G!A8VM?<W1A<G0H)'5N:71!=71H*3L*("`@
M("`@("`D=D)O>"T^<&%C:U]S=&%R="@D9W1K075T:"D["@H@("`@("`@("\O
M($-O;FYE8W0@=&AE(&1E<W1R;WD@<VEG;F%L+@H@("`@("`@("1A8F]U="T^
M8V]N;F5C="@G9&5S=')O>2<L(&%R<F%Y*"=G=&LG+"`G=')U92<I*3L*"B`@
M("`@("`@+R\@4VAO=R!T:&4@9V]O9',N"B`@("`@("`@)&%B;W5T+3YS:&]W
M7V%L;"@I.PH@("`@?0H*("`@("\J*@H@("`@("H@3&]A9"!T:&4@=&5S="!S
M=6ET92X*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!T<FEE<R!T;R!L;V%D
M('1E<W0@<W5I=&4@8F%S960@;VX@=&AE('5S97(*("`@("`J(&EN9F\N($EF
M('1H92!U<V5R('!A<W-E<R!T:&4@;F%M92!O9B!A('1E<W1S('-U:71E+"!I
M=`H@("`@("H@:7,@:6YS=&%N=&EA=&5D(&%N9"!A(&YE=R!O8FIE8W0@:7,@
M<F5T=7)N960N($EF('1H90H@("`@("H@=7-E<B!P87-S97,@82!F:6QE('1H
M870@8V]N=&%I;G,@82!T97-T('-U:71E+"!T:&4@8VQA<W,*("`@("`J(&ES
M(&EN<W1A;G1I871E9"!A;F0@82!N97<@;V)J96-T(&ES(')E='5R;F5D+B!)
M9B!T:&4@=7-E<@H@("`@("H@<&%S<V5S(&$@9FEL92!T:&%T(&-O;G1A:6YS
M(&$@=&5S="!C87-E+"!T:&4@=&5S="!C87-E(&ES"B`@("`@*B!P87-S960@
M=&\@82!N97<@=&5S="!S=6ET92!A;F0@=&AE(&YE=R!S=6ET92!O8FIE8W0@
M:7,*("`@("`J(')E='5R;F5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<&%R86T@('-T<FEN9R`@5&AE(&9I;&4@=&AA="!C;VYT
M86EN<R!A('1E<W0@8V%S92]S=6ET92!O<B!T:&4@8VQA<W-N86UE+@H@("`@
M("H@0')E='5R;B`F;V)J96-T(%1H92!N97<@=&5S="!S=6ET92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@)FQO861497-T*"8D9FEL92D*("`@('L*("`@("`@
M("`O+R!#:&5C:R!T;R!S964@:68@82!C;&%S<R!N86UE('=A<R!G:79E;BX*
M("`@("`@("!I9B`H:7-?82@D9FEL92P@)U!(4%5N:71?5&5S=%-U:71E)RDI
M('L*("`@("`@("`@("`@<F5T=7)N("1F:6QE.PH@("`@("`@('T@96QS96EF
M("AC;&%S<U]E>&ES=',H)&9I;&4I*2!["B`@("`@("`@("`@(')E<75I<F5?
M;VYC92`G4$A056YI="]497-T4W5I=&4N<&AP)SL*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!02%!5;FET7U1E<W13=6ET92@D9FEL92D["B`@("`@("`@?0H*
M("`@("`@("`O+R!#:&5C:R!T:&%T('1H92!F:6QE(&5X:7-T<RX*("`@("`@
M("!I9B`H(4!I<U]R96%D86)L92@D9FEL92DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]S:&]W4W1A='5S*"=#86YN;W0@9FEN9"!F:6QE.B`G("X@)&9I;&4I
M.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`D=&AI<RT^7W-H;W=3=&%T=7,H)TQO861I;F<@=&5S="!S=6ET92XN+B<I
M.PH*("`@("`@("`O+R!);G-T86YT:6%T92!T:&4@8VQA<W,N"B`@("`@("`@
M+R\@268@=&AE('!A=&@@:7,@+W!A=&@O=&\O=&5S="]497-T0VQA<W,N<&AP
M"B`@("`@("`@+R\@=&AE(&-L87-S(&YA;64@<VAO=6QD(&)E('1E<W1?5&5S
M=$-L87-S"B`@("`@("`@<F5Q=6ER95]O;F-E("1F:6QE.PH@("`@("`@("1C
M;&%S<TYA;64@/2!S=')?<F5P;&%C92A$25)%0U1/4EE?4T5005)!5$]2+"`G
M7R<L("1F:6QE*3L*("`@("`@("`D8VQA<W-.86UE(#T@<W5B<W1R*"1C;&%S
M<TYA;64L(#`L('-T<G!O<R@D8VQA<W-.86UE+"`G+B<I*3L*"B`@("`@("`@
M<F5Q=6ER95]O;F-E("=02%!5;FET+U1E<W13=6ET92YP:'`G.PH@("`@("`@
M(')E='5R;B!N97<@4$A056YI=%]497-T4W5I=&4H)&-L87-S3F%M92D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2=6X@=&AE('1E<W0@<W5I=&4N"B`@("`@
M*@H@("`@("H@5&AI<R!M971H;V0@<G5N<R!T:&4@=&5S="!S=6ET92!A;F0@
M=7!D871E<R!T:&4@;65S<V%G97,*("`@("`J(&9O<B!T:&4@=7-E<BX@5VAE
M;B!F:6YI<VAE9"!I="!C:&%N9V5S('1H92!S=&%T=7,@;&EN90H@("`@("H@
M=&\@)U1E<W0@0V]M<&QE=&4G"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@0')E='5R;B!V;VED"B`@
M("`@*B\*("`@(&9U;F-T:6]N(')U;E1E<W0H*0H@("`@>PH@("`@("`@("\O
M($YO=&EF>2!T:&4@=7-E<B!T:&%T('1H92!T97-T(&ES(')U;FYI;F<N"B`@
M("`@("`@)'1H:7,M/E]S:&]W4W1A='5S*"=2=6YN:6YG(%1E<W0N+BXG*3L*
M"B`@("`@("`@+R\@4G5N('1H92!T97-T+@H@("`@("`@("1R97-U;'0@/2!0
M2%!5;FET.CIR=6XH)'1H:7,M/G-U:71E*3L*"B`@("`@("`@+R\@57!D871E
M('1H92!L86)E;',N"B`@("`@("`@)'1H:7,M/E]S971,86)E;%9A;'5E*"1T
M:&ES+3YN=6UB97)/9E)U;G,L("`@("`D<F5S=6QT+3YR=6Y#;W5N="@I*3L*
M("`@("`@("`D=&AI<RT^7W-E=$QA8F5L5F%L=64H)'1H:7,M/FYU;6)E<D]F
M17)R;W)S+"`@("1R97-U;'0M/F5R<F]R0V]U;G0H*2D["B`@("`@("`@)'1H
M:7,M/E]S971,86)E;%9A;'5E*"1T:&ES+3YN=6UB97)/9D9A:6QU<F5S+"`D
M<F5S=6QT+3YF86EL=7)E0V]U;G0H*2D["@H@("`@("`@("\O(%5P9&%T92!T
M:&4@<')O9W)E<W,@8F%R+@H@("`@("`@("1T:&ES+3Y?=7!D871E4')O9W)E
M<W,H)')E<W5L="T^<G5N0V]U;G0H*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1R97-U;'0M/F5R<F]R0V]U;G0H*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R97-U;'0M/F9A:6QU<F5#;W5N="@I"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`O+R!3
M:&]W('1H92!E<G)O<G,N"B`@("`@("`@)'1H:7,M/E]S:&]W1F%I;'5R97,H
M)')E<W5L="T^97)R;W)S*"DL("1T:&ES+3YD=6UP07)E82D["@H@("`@("`@
M("\O(%-H;W<@=&AE(&UE<W-A9V5S(&9R;VT@=&AE('1E<W1S+@H@("`@("`@
M(&EF("@D=&AI<RT^<VAO=U!A<W-E9"T^9V5T7V%C=&EV92@I*2!["B`@("`@
M("`@("`@("\O(%-H;W<@9F%I;'5R97,@86YD('-U8V-E<W,N"B`@("`@("`@
M("`@("1T:&ES+3Y?<VAO=T%L;"@D<F5S=6QT+"`D=&AI<RT^<F5P;W)T07)E
M82D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@4VAO=R!O;FQY
M(&9A:6QU<F5S+@H@("`@("`@("`@("`D=&AI<RT^7W-H;W=&86EL=7)E<R@D
M<F5S=6QT+3YF86EL=7)E<R@I+"`D=&AI<RT^<F5P;W)T07)E82D["B`@("`@
M("`@?0H*("`@("`@("`O+R!5<&1A=&4@=&AE('-T871U<R!M97-S86=E+@H@
M("`@("`@("1T:&ES+3Y?<VAO=U-T871U<R@G5&5S="!C;VUP;&5T92<I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H92!T97AT(&]F(&$@;&%B96PN
M"B`@("`@*@H@("`@("H@0VAA;F=E('1H92!T97AT(&]F(&$@9VEV96X@;&%B
M96PN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R
M86T@('=I9&=E="`@)B1L86)E;"!4:&4@;&%B96P@=VAO<V4@=F%L=64@:7,@
M=&\@8F4@8VAA;F=E9"X*("`@("`J($!P87)A;2`@<W1R:6YG("`D=F%L=64@
M(%1H92!N97<@=&5X="!O9B!T:&4@;&%B96PN"B`@("`@*B!`<F5T=7)N('9O
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@7W-E=$QA8F5L5F%L=64H)B1L86)E
M;"P@)'9A;'5E*0H@("`@>PH@("`@("`@("1L86)E;"T^<V5T7W1E>'0H)'9A
M;'5E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!M86EN('=O<FL@;V8@
M=&AE(&%P<&QI8V%T:6]N+@H@("`@("H*("`@("`J($QO860@=&AE('1E<W0@
M<W5I=&4@86YD('1H96X@97AE8W5T92!T:&4@=&5S=',N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@;F]N90H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(')U;B@I"B`@("![
M"B`@("`@("`@+R\@3&]A9"!T:&4@=&5S="!S=6ET92X*("`@("`@("`D=&AI
M<RT^<W5I=&4@/28@)'1H:7,M/FQO861497-T*"1T:&ES+3YS=6ET949I96QD
M+3YG971?=&5X="@I*3L*"B`@("`@("`@+R\@0VAE8VL@=&\@;6%K92!S=7)E
M('1H92!S=6ET92!W87,@;&]A9&5D('!R;W!E<FQY+@H@("`@("`@(&EF("@A
M:7-?;V)J96-T*"1T:&ES+3YS=6ET92DI('L*("`@("`@("`@("`@+R\@4F%I
M<V4@86X@97)R;W(N"B`@("`@("`@("`@("1T:&ES+3Y?<VAO=U-T871U<R@G
M0V]U;&0@;F]T(&QO860@=&5S="!S=6ET92XG*3L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@4G5N('1H92!T97-T
M<RX*("`@("`@("`D=&AI<RT^<G5N5&5S="@I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@57!D871E('1H92!S=&%T=7,@;65S<V%G92X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@<W1R:6YG("`D<W1A
M='5S(%1H92!N97<@;65S<V%G92X*("`@("`J($!R971U<FX@=F]I9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!?<VAO=U-T871U<R@D<W1A='5S*0H@("`@>PH@
M("`@("`@("1T:&ES+3YS=&%T=7-,:6YE+3YS971?=&5X="@D<W1A='5S*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($%L:6%S(&9O<B!M86EN*"D*("`@("`J
M"B`@("`@*B!`<V5E(&UA:6X*("`@("`J+PH@("`@9G5N8W1I;VX@<VAO=R@D
M<VAO=U!A<W-E9"`]('1R=64I"B`@("!["B`@("`@("`@)'1H:7,M/FUA:6XH
M)'-H;W=087-S960I.PH@("`@?0H*("`@("\J*@H@("`@("H@061D(&$@<W5I
M=&4@=&\@=&AE('1E<W1S+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(')E<75I<F4@8GD@4V5T=7!$96-O<F%T;W(N($ET(&%D9',@80H@("`@("H@
M<W5I=&4@=&\@=&AE('1H92!C=7)R96YT('-E="!O9B!S=6ET97,N"B`@("`@
M*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2`@;V)J96-T
M("1T97-T4W5I=&4@5&AE('-U:71E('1O(&%D9"X*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&13=6ET97,H)'1E<W13=6ET
M92D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1T97-T4W5I=&4I*2![
M"B`@("`@("`@("`@('-E='1Y<&4H)'1E<W13=6ET92P@)V%R<F%Y)RD["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D=&5S=%-U:71E(&%S("1S=6ET
M92D@>PH*("`@("`@("`@("`@:68@*&ES7V$H)'1H:7,M/G-U:71E+"`G4$A0
M56YI=%]497-T4W5I=&4G*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-U
M:71E+3YA9&1497-T4W5I=&4H)'-U:71E+3YG971.86UE*"DI.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-U:71E(#TF
M("1T:&ES+3YL;V%D5&5S="@D<W5I=&4I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`O+R!3970@=&AE('-U:71E(&9I96QD+@H@("`@("`@("`@("`D
M=&5X="`]("1T:&ES+3YS=6ET949I96QD+3YG971?=&5X="@I.PH@("`@("`@
M("`@("!I9B`H96UP='DH)'1E>'0I*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<W5I=&5&:65L9"T^<V5T7W1E>'0H)'1H:7,M/G-U:71E+3YG971.86UE
M*"DI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4VAO=R!A;&P@=&5S="!M97-S86=E<RX*("`@("`J"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J($!P87)A;2`@;V)J96-T("!4:&4@5&5S
M=%)E<W5L="!F<F]M('1H92!T97-T('-U:71E+@H@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S:&]W06QL*"8D<F5S=6QT*0H@
M("`@>PH@("`@("`@("\O($-L96%R('1H92!A<F5A(&9I<G-T+@H@("`@("`@
M("1T:&ES+3YR97!O<G1!<F5A+3YD96QE=&5?=&5X="@P+"`M,2D["B`@("`@
M("`@)'1H:7,M/G)E<&]R=$%R96$M/FEN<V5R=%]T97AT*"1R97-U;'0M/G1O
M4W1R:6YG*"DL(#`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4VAO=R!F86EL
M=7)E+V5R<F]R(&UE<W-A9V5S(&EN('1H92!G:79E;B!T97AT(&%R96$N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@(&]B
M:F5C="`@)B1R97-U;'1S(%1H92!R97-U;'1S(&]F('1H92!T97-T+@H@("`@
M("H@0'!A<F%M("!W:61G970@("8D87)E82`@("!4:&4@87)E82!T;R!S:&]W
M('1H92!R97-U;'1S(&EN+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<VAO=T9A
M:6QU<F5S*"8D<F5S=6QT<RP@)B1A<F5A*0H@("`@>PH@("`@("`@("1A<F5A
M+3YD96QE=&5?=&5X="@P+"`M,2D["B`@("`@("`@9F]R96%C:"`H87)R87E?
M<F5V97)S92@D<F5S=6QT<RP@=')U92D@87,@)')E<W5L="D@>PH@("`@("`@
M("`@("`D87)E82T^:6YS97)T7W1E>'0H)')E<W5L="T^=&]3=')I;F<H*2P@
M,"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@57!D871E('1H
M92!P<F]G<F5S<R!I;F1I8V%T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B!`<&%R86T@(&EN=&5G97(@)')U;G,*("`@("`J($!P
M87)A;2`@:6YT96=E<B`D97)R;W)S"B`@("`@*B!`<&%R86T@(&EN=&5G97(@
M)&9A:6QU<F5S"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W5P9&%T95!R;V=R97-S*"1R=6YS+"`D97)R;W)S+"`D9F%I;'5R
M97,I"B`@("!["B`@("`@("`@)'!E<F-E;G1A9V4@/2`Q("T@*"@D97)R;W)S
M("L@)&9A:6QU<F5S*2`O("1R=6YS*3L*("`@("`@("`D=&AI<RT^<')O9W)E
M<W,M/G-E=%]P97)C96YT86=E*"1P97)C96YT86=E*3L*("`@('T*?0H*+RH*
M("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I
M8RUO9F9S970Z(#0*("H@8RUH86YG:6YG+6-O;6UE;G0M96YD97(M<#H@;FEL
M"B`J($5N9#H*("HO"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1&%T92](=6UA;BYP:'``````
M````````````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S0V-"`Q
M,#4Q-30S-#$S,R`P,C$Q,S,`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A
M8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*+R\*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#4@06QL86X@2V5N="`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=&AE($YE=R!"
M4T0@;&EC96YS92P@5&AA="!I<R!B=6YD;&5D("!\"B\O('P@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L
M92!T:')O=6=H("`@("`@?`HO+R!\('1H92!W;W)L9"UW:61E+7=E8B!A="`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(&YE=R!"4T1L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE("`@?`HO+R!\('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@
M("`@('P*+R\@?"!P96%R+61E=D!L:7-T<RYP:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@06QL86X@2V5N
M="`\86QL86Y`;&]D97-T;VYE+F-O+GIA/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@HO*BH*
M("H@0VQA<W,@=&\@8V]N=F5R="!D871E('-T<FEN9W,@8F5T=V5E;B!'<F5G
M;W)I86X@86YD($AU;6%N(&-A;&5N9&%R(&9O<FUA=',*("H*("H@5&AE($AU
M;6%N($-A;&5N9&%R(&9O<FUA="!H87,@8F5E;B!P<F]P;W-E9"!B>2!38V]T
M="!&;&%N<V)U<F<@86YD(&-A;B!B90H@*B!E>'!L86EN960@87,@9F]L;&]W
M<SH*("H@(%1H92!Y96%R(&ES(&UA9&4@=7`@;V8@,3,@;6]N=&AS"B`J("!%
M86-H(&UO;G1H(&AA<R`R."!D87ES"B`J("!#;W5N=&EN9R!O9B!M;VYT:',@
M<W1A<G1S(&9R;VT@,"`H>F5R;RD@<V\@=&AE(&UO;G1H<R!W:6QL(')U;B!F
M<F]M(#`@=&\@,3(*("H@($YE=R!996%R<R!D87D@*#`P*2!I<R!A(&UO;G1H
M;&5S<R!D87D*("H@($YO=&4Z($QE87`@665A<G,@87)E(&YO="!Y970@86-C
M;W5N=&5D(&9O<B!I;B!T:&4@2'5M86X@0V%L96YD87(@<WES=&5M"B`J"B`J
M(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($!C871E9V]R>2`@($1A=&4@
M86YD(%1I;64*("H@0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R("`@("!!
M;&QA;B!+96YT(#QA;&QA;D!L;V1E<W1O;F4N8V\N>F$^"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-2!!;&QA;B!+96YT"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP
M("!.97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@0U93.B`D260Z($AU
M;6%N+G!H<"QV(#$N-2`R,#`U+S$Q+S$U(#`P.C$V.C0P('!A:F]Y92!%>'`@
M)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M1&%T90H@*B!`<VEN8V4@("`@("!&:6QE(&%V86EL86)L92!S:6YC92!296QE
M87-E(#$N,PH@*B\*"B\J*@H@*B!#;&%S<R!T;R!C;VYV97)T(&1A=&4@<W1R
M:6YG<R!B971W965N($=R96=O<FEA;B!A;F0@2'5M86X@8V%L96YD87(@9F]R
M;6%T<PH@*@H@*B!4:&4@2'5M86X@0V%L96YD87(@9F]R;6%T(&AA<R!B965N
M('!R;W!O<V5D(&)Y(%-C;W1T($9L86YS8G5R9R!A;F0@8V%N(&)E"B`J(&5X
M<&QA:6YE9"!A<R!F;VQL;W=S.@H@*B`@5&AE('EE87(@:7,@;6%D92!U<"!O
M9B`Q,R!M;VYT:',*("H@($5A8V@@;6]N=&@@:&%S(#(X(&1A>7,*("H@($-O
M=6YT:6YG(&]F(&UO;G1H<R!S=&%R=',@9G)O;2`P("AZ97)O*2!S;R!T:&4@
M;6]N=&AS('=I;&P@<G5N(&9R;VT@,"!T;R`Q,@H@*B`@3F5W(%EE87)S(&1A
M>2`H,#`I(&ES(&$@;6]N=&AL97-S(&1A>0H@*B`@3F]T93H@3&5A<"!996%R
M<R!A<F4@;F]T('EE="!A8V-O=6YT960@9F]R(&EN('1H92!(=6UA;B!#86QE
M;F1A<B!S>7-T96T*("H*("H@0&%U=&AO<B`@("`@06QL86X@2V5N="`\86QL
M86Y`;&]D97-T;VYE+F-O+GIA/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M06QL86X@2V5N=`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+F]P96YS;W5R
M8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@3F5W($)31"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XV"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$871E"B`J($!S:6YC
M92`@("`@($-L87-S(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,PH@*B\*
M8VQA<W,@1&%T95](=6UA;@I["B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@
M87-S;V-I871I=F4@87)R87D@8V]N=&%I;FEN9R!T:&4@8V]N=F5R=&5D(&1A
M=&4@:6YF;W)M871I;VX*("`@("`J(&EN("=(=6UA;B!#86QE;F1A<B<@9F]R
M;6%T+@H@("`@("H*("`@("`J($!P87)A;2!I;G0@9&%Y(&EN($1$(&9O<FUA
M="P@9&5F875L="!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN
M="!M;VYT:"!I;B!-32!F;W)M870L(&1E9F%U;'0@8W5R<F5N="!L;V-A;"!M
M;VYT:`H@("`@("H@0'!A<F%M(&EN="!Y96%R(&EN($-#65D@9F]R;6%T+"!D
M969A=6QT('1O(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!A<W-O8VEA=&EV
M92!A<G)A>2@*("`@("`J("`@("`@("`@("`@("`@:&1O;2P@("`@("`@+R\@
M2'5M86X@1&%Y($]F($UO;G1H+"!S=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@
M("`@("`@("`@(&AD;W<L("`@("`@("\O($AU;6%N($1A>2!/9B!7965K+"!S
M=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@(&AW;VTL("`@("`@
M("\O($AU;6%N(%=E96L@;V8@36]N=&@L('-T87)T:6YG(&%T(#$*("`@("`J
M("`@("`@("`@("`@("`@:'=O>2P@("`@("`@+R\@2'5M86X@5V5E:R!O9B!9
M96%R+"!S=&%R=&EN9R!A="`Q"B`@("`@*B`@("`@("`@("`@("`@(&AM;WDL
M("`@("`@("\O($AU;6%N($UO;G1H(&]F(%EE87(L('-T87)T:6YG(&%T(#`*
M("`@("`J("`@("`@("`@("`@("`@*0H@("`@("H*("`@("`J($EF('1H92!D
M87D@:7,@3F5W(%EE87)S($1A>2P@=&AE(&9U;F-T:6]N('=I;&P@<F5T=7)N
M"B`@("`@*B`B:&1O;2(@/3X@(#`*("`@("`J(")H9&]W(B`]/B`@,`H@("`@
M("H@(FAW;VTB(#T^("`P"B`@("`@*B`B:'=O>2(@/3X@(#`*("`@("`J(")H
M;6]Y(B`]/B`M,0H@("`@("H@(%-I;F-E(#`@:7,@82!V86QI9"!M;VYT:"!N
M=6UB97(@=6YD97(@=&AE($AU;6%N($-A;&5N9&%R+"!)(&AA=F4@;&5F=`H@
M("`@("H@('1H92!M;VYT:"!A<R`M,2!F;W(@3F5W(%EE87)S($1A>2X*("`@
M("`J+PH@("`@9G5N8W1I;VX@9W)E9V]R:6%N5&](=6UA;B@D9&%Y/3`L("1M
M;VYT:#TP+"`D>65A<CTP*0H@("`@>PH@("`@("`@("\J"B`@("`@("`@("H@
M0VAE8VL@=&\@<V5E(&EF(&%N>2!O9B!T:&4@87)G=6UE;G1S(&%R92!E;7!T
M>0H@("`@("`@("`J($EF('1H97D@87)E('1H96X@<&]P=6QA=&4@=&AE("1D
M871E:6YF;R!A<G)A>0H@("`@("`@("`J(%1H96X@8VAE8VL@=&\@<V5E('=H
M:6-H(&%R9W5M96YT<R!A<F4@96UP='D@86YD(&9I;&P*("`@("`@("`@*B!T
M:&]S92!W:71H('1H92!C=7)R96YT(&1A=&4@:6YF;PH@("`@("`@("`J+PH@
M("`@("`@(&EF("@H96UP='DH)&1A>2D@?'P@*&5M<'1Y*"1M;VYT:"DI('Q\
M(&5M<'1Y*"1Y96%R*2DI('L*("`@("`@("`@("`@)&1A=&5I;F9O(#T@9V5T
M9&%T92AT:6UE*"DI.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A
M>2DI('L*("`@("`@("`@("`@)&1A>2`]("1D871E:6YF;ULB;61A>2)=.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@
M("`@("`D;6]N=&@@/2`D9&%T96EN9F];(FUO;B)=.PH@("`@("`@('T*("`@
M("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@
M)&1A=&5I;F9O6R)Y96%R(ET["B`@("`@("`@?0H@("`@("`@("\J"B`@("`@
M("`@("H@5V4@;F5E9"!T;R!K;F]W(&AO=R!M86YY(&1A>7,@:6YT;R!T:&4@
M>65A<B!W92!A<F4*("`@("`@("`@*B\*("`@("`@("`D9&%T96EN9F\@/2!G
M971D871E*&UK=&EM92@P+"`P+"`P+"`D;6]N=&@L("1D87DL("1Y96%R*2D[
M"B`@("`@("`@)&1A>6]F>65A<B`]("1D871E:6YF;ULB>61A>2)=.PH@("`@
M("`@("\J"B`@("`@("`@("H@2'5M86X@0V%L96YD87(@<W1A<G1S(&%T(#`@
M9F]R(&UO;G1H<R!A;F0@=&AE(&9I<G-T(&1A>2!O9B!T:&4@>65A<@H@("`@
M("`@("`J(&ES(&1E<VEG;F%T960@,#`L('-O('=E(&YE960@=&\@<W1A<G0@
M;W5R(&1A>2!O9B!T:&4@>65A<B!A="`P(&9O<@H@("`@("`@("`J('1H97-E
M(&-A;&-U;&%T:6]N<RX*("`@("`@("`@*B!!;'-O+"!T:&4@9&%Y(&]F('1H
M92!M;VYT:"!I<R!C86QC=6QA=&5D('=I=&@@82!M;V1U;'5S(&]F(#(X+@H@
M("`@("`@("`J($)E8V%U<V4@82!D87D@:7,@,C@@9&%Y<RP@=&AE(&QA<W0@
M9&%Y(&]F('1H92!M;VYT:"!W;W5L9"!H879E(&$*("`@("`@("`@*B!R96UA
M:6YD97(@;V8@,"!A;F0@;F]T(#(X(&%S(&ET('-H;W5L9"!B92X@($1E8W)E
M;65N=&EN9R`D9&%Y;V9Y96%R"B`@("`@("`@("H@9V5T<R!A<F]U;F0@=&AI
M<RX*("`@("`@("`@*B\*("`@("`@("`D9&%Y;V9Y96%R+2T["B`@("`@("`@
M+RH*("`@("`@("`@*B`R."!D87ES(&EN(&$@;6]N=&@N+BX*("`@("`@("`@
M*B\*("`@("`@("`D:'5M86Y-;VYT:$]F665A<B`](&9L;V]R*"1D87EO9GEE
M87(@+R`R."D["B`@("`@("`@+RH*("`@("`@("`@*B!)9B!W92!A<F4@:6X@
M=&AE(&9I<G-T(&UO;G1H('1H96X@=&AE(&1A>2!O9B!T:&4@;6]N=&@@:7,@
M)&1A>6]F>65A<@H@("`@("`@("`J(&5L<V4@=V4@;F5E9"!T;R!F:6YD('1H
M92!M;V1U;'5S(&]F(#(X+@H@("`@("`@("`J+PH@("`@("`@(&EF("@D:'5M
M86Y-;VYT:$]F665A<B`]/2`P*2!["B`@("`@("`@("`@("1H=6UA;D1A>4]F
M36]N=&@@/2`D9&%Y;V9Y96%R.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1H=6UA;D1A>4]F36]N=&@@/2`H)&1A>6]F>65A<BD@)2`R.#L*("`@
M("`@("!]"B`@("`@("`@+RH*("`@("`@("`@*B!$87D@;V8@=&AE('=E96L@
M:7,@;6]D=6QU<R`W"B`@("`@("`@("HO"B`@("`@("`@)&AU;6%N1&%Y3V97
M965K(#T@)&1A>6]F>65A<B`E(#<["B`@("`@("`@+RH*("`@("`@("`@*B!7
M92!C86X@;F]W(&EN8W)E;65N="`D9&%Y;V9Y96%R(&)A8VL@=&\@:70G<R!C
M;W)R96-T('9A;'5E(&9O<@H@("`@("`@("`J('1H92!R96UA:6YD97(@;V8@
M=&AE(&-A;&-U;&%T:6]N<PH@("`@("`@("`J+PH@("`@("`@("1D87EO9GEE
M87(K*SL*("`@("`@("`O*@H@("`@("`@("`J("1H=6UA;D1A>4]F36]N=&@@
M;F5E9',@=&\@8F4@:6YC<F5M96YT960@;F]W("T@<F5C86QL('1H870@=V4@
M9G5D9V5D"B`@("`@("`@("H@:70@82!B:70@8GD@9&5C<F5M96YT:6YG("1D
M87EO9GEE87(@96%R;&EE<@H@("`@("`@("`J(%-A;64@9V]E<R!F;W(@)&AU
M;6%N1&%Y3V97965K"B`@("`@("`@("HO"B`@("`@("`@)&AU;6%N1&%Y3V9-
M;VYT:"LK.PH@("`@("`@("1H=6UA;D1A>4]F5V5E:RLK.PH@("`@("`@("\J
M"B`@("`@("`@("H@5V5E:R!O9B!T:&4@;6]N=&@@:7,@9&%Y(&]F('1H92!M
M;VYT:"!D:79I9&5D(&)Y(#<L(')O=6YD960@=7`*("`@("`@("`@*B!386UE
M(&9O<B!W965K(&]F('1H92!Y96%R+"!B=70@=7-E("1D87EO9GEE87(@:6YS
M=&5A9"`D:'5M86Y$87E/9DUO;G1H"B`@("`@("`@("HO"B`@("`@("`@)&AU
M;6%N5V5E:T]F36]N=&@@/2!C96EL*"1H=6UA;D1A>4]F36]N=&@@+R`W*3L*
M("`@("`@("`D:'5M86Y7965K3V9996%R(#T@8V5I;"@D9&%Y;V9Y96%R("\@
M-RD["B`@("`@("`@+RH*("`@("`@("`@*B!2971U<FX@86X@87-S;V-I871I
M=F4@87)R87D@;V8@=&AE('9A;'5E<PH@("`@("`@("`J+PH@("`@("`@(')E
M='5R;B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@(FAD;VTB(#T^("1H
M=6UA;D1A>4]F36]N=&@L"B`@("`@("`@("`@("`@("`@("`@(")H9&]W(B`]
M/B`D:'5M86Y$87E/9E=E96LL"B`@("`@("`@("`@("`@("`@("`@(")H=V]M
M(B`]/B`D:'5M86Y7965K3V9-;VYT:"P*("`@("`@("`@("`@("`@("`@("`@
M(FAW;WDB(#T^("1H=6UA;E=E96M/9EEE87(L"B`@("`@("`@("`@("`@("`@
M("`@(")H;6]Y(B`]/B`D:'5M86Y-;VYT:$]F665A<B`I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!U;FEX('1I;65S=&%M<"!F;W(@82!G:79E
M;B!(=6UA;B!#86QE;F1A<B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN
M="!D87D@:6X@1$0@9F]R;6%T"B`@("`@*B!`<&%R86T@:6YT(&UO;G1H(&EN
M($U-(&9O<FUA=`H@("`@("H@0'!A<F%M(&EN="!Y96%R(&EN($-#65D@9F]R
M;6%T+"!D969A=6QT('1O(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M=6YI>"!T:6UE<W1A;7`@;V8@9&%T90H@("`@("HO"B`@("!F=6YC=&EO;B!(
M=6UA;E1O1W)E9V]R:6%N*"1D87DL("1M;VYT:"P@)'EE87(],"D*("`@('L*
M("`@("`@("`O*@H@("`@("`@("`J($-H96-K('1O('-E92!I9B!T:&4@>65A
M<B!H87,@8F5E;B!P87-S960@=&AR;W5G:"X*("`@("`@("`@*B!)9B!N;W0@
M9V5T(&-U<G)E;G0@>65A<@H@("`@("`@("`J+PH@("`@("`@(&EF("AE;7!T
M>2@D>65A<BDI('L*("`@("`@("`@("`@)&1A=&5I;F9O(#T@9V5T9&%T92AT
M:6UE*"DI.PH@("`@("`@("`@("`D>65A<B`]("1D871E:6YF;ULB>65A<B)=
M.PH@("`@("`@('T*("`@("`@("`O*@H@("`@("`@("`J(%=E(&YE960@=&\@
M9V5T('1H92!D87D@;V8@=&AE('EE87(@=&AA="!W92!A<F4@8W5R<F5N=&QY
M(&%T('-O('1H870*("`@("`@("`@*B!W92!C86X@=V]R:R!O=70@=&AE($=R
M96=O<FEA;B!-;VYT:"!A;F0@9&%Y"B`@("`@("`@("HO"B`@("`@("`@)$1A
M>4]F665A<B`]("1M;VYT:"`J(#(X.PH@("`@("`@("1$87E/9EEE87(@*ST@
M)&1A>3L*("`@("`@("`O*@H@("`@("`@("`J($AU;6%N($-A;&5N9&%R('-T
M87)T<R!A="`P+"!S;R!W92!N965D('1O(&EN8W)E;65N="`D1&%Y3V9996%R
M"B`@("`@("`@("H@=&\@=&%K92!I;G1O(&%C8V]U;G0@=&AE(&1A>2`P,`H@
M("`@("`@("`J+PH@("`@("`@("1$87E/9EEE87(K*SL*("`@("`@("`O*@H@
M("`@("`@("`J('1H92!M:W1I;64H*2!F=6YC=&EO;B!W:6QL(&-O<G)E8W1L
M>2!C86QC=6QA=&4@=&AE(&1A=&4@9F]R(&]U="!O9@H@("`@("`@("`J(')A
M;F=E('9A;'5E<RP@<V\@<'5T=&EN9R`D1&%Y3V9996%R(&EN<W1E860@;V8@
M=&AE(&1A>2!O9B!T:&4@;6]N=&@*("`@("`@("`@*B!W:6QL('=O<FL@9FEN
M92X*("`@("`@("`@*B\*("`@("`@("`D1W)E9V]R:6%N5&EM95-T86UP(#T@
M;6MT:6UE*#`L(#`L(#`L(#$L("1$87E/9EEE87(L("1Y96%R*3L*("`@("`@
M("!R971U<FX@)$=R96=O<FEA;E1I;653=&%M<#L*("`@('T*?0H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+T1A=&4O4W!A;BYP:'``````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P-S4U-#$@,3`U,34T,S0Q,S,@,#(P-S8T`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30Z("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U("!,96%N9')O($QU8V%R
M96QL82P@4&EE<G)E+4%L86EN($IO>64@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE
M9"`@?`HO+R!\('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.
M4T4L(&%N9"!I<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!N97<@0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@?"!T
M;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S
M92!S96YD(&$@;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES=',N
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+B`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W(Z($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!0:65R
M<F4M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN970^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M"B\J*@H@*B!'96YE<FEC('1I;64@<W!A;B!H86YD;&EN9R!C;&%S<R!F;W(@
M4$5!4@H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!`8V%T96=O
M<GD@("!$871E(&%N9"!4:6UE"B`J($!P86-K86=E("`@($1A=&4*("H@0&%U
M=&AO<B`@("`@3&5A;F1R;R!,=6-A<F5L;&$@/&QL=6-A>$!P:'`N;F5T/@H@
M*B!`875T:&]R("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J;WEE0'!H<"YN
M970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!,96%N9')O($QU8V%R96QL
M82P@4&EE<G)E+4%L86EN($IO>64*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W
M=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE
M=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@4W!A;BYP
M:'`L=B`Q+C@@,C`P-2\Q,2\Q-2`P,#HQ-CHT,"!P86IO>64@17AP("0*("H@
M0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1A=&4*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C0*("HO"@HO*BH*("H@1V5T('1H92!$871E(&-L87-S"B`J+PIR97%U:7)E
M7V]N8V4@)T1A=&4N<&AP)SL*"B\J*@H@*B!'970@=&AE($1A=&5?0V%L8R!C
M;&%S<PH@*B\*<F5Q=6ER95]O;F-E("=$871E+T-A;&,N<&AP)SL*"B\J*@H@
M*B!.;VX@3G5M97)I8R!397!A<F%T960@5F%L=65S("A.3E-6*2!);G!U="!&
M;W)M870N"B`J"B`J($EN<'5T(&9O<FUA="!G=65S<V5D(&9R;VT@<V]M971H
M:6YG(&QI:V4@=&AI<SH*("H@9&%Y<SQS97`^:&]U<G,\<V5P/FUI;G5T97,\
M<V5P/G-E8V]N9',*("H@5VAE<F4@/'-E<#X@:7,@86YY('%U86YT:71Y(&]F
M(&YO;B!N=6UE<FEC(&-H87)S+B!)9B!N;R!V86QU97,@87)E"B`J(&=I=F5N
M+"!T:6UE('-P86X@:7,@<V5T('1O('IE<F\L(&EF(&]N92!V86QU92!I<R!G
M:79E;BP@:70G<R!U<V5D(&9O<@H@*B!H;W5R<RP@:68@='=O('9A;'5E<R!A
M<F4@9VEV96X@:70G<R!U<V5D(&9O<B!H;W5R<R!A;F0@;6EN=71E<R!A;F0@
M:68*("H@=&AR964@=F%L=65S(&%R92!G:79E;BP@:70G<R!U<V5D(&9O<B!H
M;W5R<RP@;6EN=71E<R!A;F0@<V5C;VYD<RX\8G(^"B`J($5X86UP;&5S.CQB
M<CX*("H@)R<@("`@("`@("`@("`@("`@("`@+3X@,"P@,"P@,"P@,"`H9&%Y
M<RP@:&]U<G,L(&UI;G5T97,L('-E8V]N9',I/&)R/@H@*B`G,3(G("`@("`@
M("`@("`@("`@("`M/B`P+"`Q,BP@,"P@,`H@*B`G,3(N,S`G("`@("`@("`@
M("`@("`M/B`P+"`Q,BP@,S`L(#`\8G(^"B`J("<Q,CHS,#HQ."<@("`@("`@
M("`@("T^(#`L(#$R+"`S,"P@,3@\8G(^"B`J("<S+3$R+3,P+3$X)R`@("`@
M("`@("T^(#,L(#$R+"`S,"P@,3@\8G(^"B`J("<S(&1A>7,L(#$R+3,P+3$X
M)R`@("T^(#,L(#$R+"`S,"P@,3@\8G(^"B`J("<Q,CHS,"!W:71H(#$X('-E
M8W,G("T^(#`L(#$R+"`S,"P@,3@\8G(^"B`J"B`J($!C;VYS="!I;G0*("HO
M"F1E9FEN92@G1$%415]34$%.7TE.4%547T9/4DU!5%].3E-6)RP@,2D["@HO
M*BH*("H@1&5F875L="!T:6UE(&9O<FUA="!W:&5N(&-O;G9E<G1I;F<@=&\@
M82!S=')I;F<N"B`J"B`J($!G;&]B86P@<W1R:6YG"B`J+PHD1TQ/0D%,4ULG
M7T1!5$5?4U!!3E]&3U)-050G72`@/2`G)4,G.PH*+RHJ"B`J($1E9F%U;'0@
M=&EM92!F;W)M870@=VAE;B!C;VYV97)T:6YG(&9R;VT@82!S=')I;F<N"B`J
M"B`J($!G;&]B86P@;6EX960*("HO"B1'3$]"04Q36R=?1$%415]34$%.7TE.
M4%547T9/4DU!5"==(#T@1$%415]34$%.7TE.4%547T9/4DU!5%].3E-6.PH*
M+RHJ"B`J($=E;F5R:6,@=&EM92!S<&%N(&AA;F1L:6YG(&-L87-S(&9O<B!0
M14%2"B`J"B`J($!A=71H;W(@("`@($QE86YD<F\@3'5C87)E;&QA(#QL;'5C
M87A`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@
M1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($YE=R!"4T0@3&EC96YS90H@
M*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N-@H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1&%T90H@*B!`<VEN8V4@("`@
M("!#;&%S<R!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C0*("H*("H@0'1O
M9&\@("`@("`@1V5T(&%N9"!S970@9&5F875L="!L;V-A;"!I;G!U="!A;F0@
M;W5T<'5T(&9O<FUA=',_"B`J+PIC;&%S<R!$871E7U-P86X@>PH*("`@("\J
M*@H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1D87D["@H@("`@
M+RHJ"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&AO=7(["@H@
M("`@+RHJ"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)&UI;G5T
M93L*"B`@("`O*BH*("`@("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D
M<V5C;VYD.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@
M("`@("H@0W)E871E<R!T:&4@=&EM92!S<&%N(&]B:F5C="!C86QL:6YG('1H
M92!S970H*2!M971H;V0N"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`D
M=&EM92`@(%1I;64@<W!A;B!E>'!R97-S:6]N+@H@("`@("H@0'!A<F%M("!M
M:7AE9"`D9F]R;6%T($9O<FUA="!S=')I;F<@=&\@<V5T(&ET(&9R;VT@82!S
M=')I;F<@;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@<V5C
M;VYD(&1A=&4@<V5T(&ET(&9R;VT@82!D871E(&1I9F8N"B`@("`@*@H@("`@
M("H@0'-E92`@("!S970H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@1&%T95]3<&%N*"1T:6UE(#T@,"P@)&9O<FUA="`]
M(&YU;&PI"B`@("!["B`@("`@("`@)'1H:7,M/G-E="@D=&EM92P@)&9O<FUA
M="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@<W!A;B!T
M;R!A(&YE=R!V86QU92!I;B!A("=S;6%R="<@=V%Y+@H@("`@("H*("`@("`J
M(%-E=',@=&AE('1I;64@<W!A;B!D97!E;F1I;F<@;VX@=&AE(&%R9W5M96YT
M('1Y<&5S+"!C86QL:6YG"B`@("`@*B!T;R!T:&4@87!P<F]P<FEA=&4@<V5T
M1G)O;5AX>"@I(&UE=&AO9"X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D
M("1T:6UE("`@5&EM92!S<&%N(&5X<')E<W-I;VXN"B`@("`@*B!`<&%R86T@
M(&UI>&5D("1F;W)M870@1F]R;6%T('-T<FEN9R!T;R!S970@:70@9G)O;2!A
M('-T<FEN9R!O<B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!S
M96-O;F0@9&%T92!S970@:70@9G)O;2!A(&1A=&4@9&EF9BX*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&)O;VP@('1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@
M("`@*B!`<V5E("`@('-E=$9R;VU/8FIE8W0H*0H@("`@("H@0'-E92`@("!S
M971&<F]M07)R87DH*0H@("`@("H@0'-E92`@("!S971&<F]M4W1R:6YG*"D*
M("`@("`J($!S964@("`@<V5T1G)O;5-E8V]N9',H*0H@("`@("H@0'-E92`@
M("!S971&<F]M1&%T941I9F8H*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T*"1T:6UE(#T@,"P@)&9O<FUA="`](&YU
M;&PI"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1I;64L("=D871E7W-P86XG
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-O<'DH)'1I;64I.PH@
M("`@("`@('T@96QS96EF("AI<U]A*"1T:6UE+"`G9&%T92<I(&%N9"!I<U]A
M*"1F;W)M870L("=D871E)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YS971&<F]M1&%T941I9F8H)'1I;64L("1F;W)M870I.PH@("`@("`@('T@
M96QS96EF("AI<U]A<G)A>2@D=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YS971&<F]M07)R87DH)'1I;64I.PH@("`@("`@('T@96QS96EF
M("AI<U]S=')I;F<H)'1I;64I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<V5T1G)O;5-T<FEN9R@D=&EM92P@)&9O<FUA="D["B`@("`@("`@?2!E
M;'-E:68@*&ES7VEN="@D=&EM92DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YS971&<F]M4V5C;VYD<R@D=&EM92D["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C;VYD<R@P*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@=&AE('1I;64@
M<W!A;B!F<F]M(&%N(&%R<F%Y+@H@("`@("H*("`@("`J(%-E="!T:&4@=&EM
M92!S<&%N(&9R;VT@86X@87)R87DN($%N>2!V86QU92!C86X@8F4@82!F;&]A
M="`H8G5T(&ET"B`@("`@*B!H87,@;F\@<V5N<V4@:6X@<V5C;VYD<RDL(&9O
M<B!E>&%M<&QE(&%R<F%Y*#(S+C4L(#(P+"`P*2!I<PH@("`@("H@:6YT97)P
M<F5T960@87,@,C,@:&]U<G,L("XU*C8P("L@,C`@/2`U,"!M:6YU=&5S(&%N
M9"`P('-E8V]N9',N"B`@("`@*@H@("`@("H@0'!A<F%M("!A<G)A>2`D=&EM
M92!)=&5M<R!A<F4@8V]U;G1E9"!F<F]M(')I9VAT('1O(&QE9G0N($9I<G-T
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@(&ET96T@:7,@9F]R('-E8V]N
M9',L('-E8V]N9"!F;W(@;6EN=71E<RP@=&AI<F0*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@9F]R(&AO=7)S(&%N9"!F;W5R=&@@9F]R(&1A>7,N($EF
M('1H97)E(&%R90H@("`@("H@("`@("`@("`@("`@("`@("`@("!L97-S(&ET
M96US('1H86X@-"P@>F5R;R`H,"D@:7,@87-S=6UE9"!F;W(@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@(&%B<V5N="!V86QU97,N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L("!4<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M1G)O;4%R<F%Y*"1T:6UE*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH
M)'1I;64I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@)'1M<#$@/2!N97<@1&%T95]3<&%N.PH@("`@("`@(&EF("@A
M)'1M<#$M/G-E=$9R;VU396-O;F1S*$!A<G)A>5]P;W`H)'1I;64I*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1T
M;7`R(#T@;F5W($1A=&5?4W!A;CL*("`@("`@("!I9B`H(21T;7`R+3YS971&
M<F]M36EN=71E<RA`87)R87E?<&]P*"1T:6UE*2DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D=&UP,2T^861D*"1T
M;7`R*3L*("`@("`@("!I9B`H(21T;7`R+3YS971&<F]M2&]U<G,H0&%R<F%Y
M7W!O<"@D=&EM92DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@
M("`@("!]"B`@("`@("`@)'1M<#$M/F%D9"@D=&UP,BD["B`@("`@("`@:68@
M*"$D=&UP,BT^<V5T1G)O;41A>7,H0&%R<F%Y7W!O<"@D=&EM92DI*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)'1M
M<#$M/F%D9"@D=&UP,BD["B`@("`@("`@<F5T=7)N("1T:&ES+3YC;W!Y*"1T
M;7`Q*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N
M(&9R;VT@82!S=')I;F<@8F%S960@;VX@86X@:6YP=70@9F]R;6%T+@H@("`@
M("H*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!S=')I;F<@8F%S
M960@;VX@86X@:6YP=70@9F]R;6%T+B!4:&ES(&ES"B`@("`@*B!S;VUE(&QI
M:V4@82!M:7@@;V8@9F]R;6%T*"D@;65T:&]D(&%N9"!S<V-A;F8H*2!02%`@
M9G5N8W1I;VXN(%1H90H@("`@("H@97)R;W(@8VAE8VMI;F<@86YD('9A;&ED
M871I;VX@;V8@=&AI<R!F=6YC=&EO;B!I<R!V97)Y('!R:6UI=&EV92P*("`@
M("`J('-O('EO=2!S:&]U;&0@8F4@8V%R969U;&P@=VAE;B!U<VEN9R!I="!W
M:71H('5N:VYO=VX@)'1I;64@<W1R:6YG<RX*("`@("`J(%=I=&@@=&AI<R!M
M971H;V0@>6]U(&%R92!A<W-I9VYI;F<@9&%Y+"!H;W5R+"!M:6YU=&4@86YD
M('-E8V]N9`H@("`@("H@=F%L=65S+"!A;F0@=&AE(&QA<W0@=F%L=65S(&%R
M92!U<V5D+B!4:&ES(&UE86YS('1H870@:68@>6]U('5S90H@("`@("H@<V]M
M971H:6YG(&QI:V4@<V5T1G)O;5-T<FEN9R@G,3`L(#(P)RP@)R5(+"`E:"<I
M('EO=7(@=&EM92!S<&%N"B`@("`@*B!W;W5L9"!B92`R,"!H;W5R<R!L;VYG
M+B!!;&QW87ES(')E;65M8F5R('1H870@=&AI<R!M971H;V0@<V5T"B`@("`@
M*B`\8CYA;&P\+V(^('1H92!V86QU97,L('-O(&EF('EO=2!H860@82`D=&EM
M92!S<&%N(#,P(&UI;G5T97,@;&]N9PH@("`@("H@86YD('EO=2!M86ME("1T
M:6UE+3YS971&<F]M4W1R:6YG*"<R,"!H;W5R<R<L("<E2"!H;W5R<R<I+"`D
M=&EM90H@("`@("H@<W!A;B!W;W5L9"!B92`R,"!H;W5R<R!L;VYG("AA;F0@
M;F]T(#(P(&AO=7)S(&%N9"`S,"!M:6YU=&5S*2X*("`@("`J($EN<'5T(&9O
M<FUA="!O<'1I;VYS.CQB<CX*("`@("`J("`\8V]D93XE0SPO8V]D93X@1&%Y
M<R!W:71H('1I;64L('-A;64@87,@(B5$+"`E2#HE33HE4R(N/&)R/@H@("`@
M("H@(#QC;V1E/B5D/"]C;V1E/B!4;W1A;"!D87ES(&%S(&$@9FQO870@;G5M
M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("@R(&1A>7,L(#$R(&AO=7)S
M(#T@,BXU(&1A>7,I+CQB<CX*("`@("`J("`\8V]D93XE1#PO8V]D93X@1&%Y
M<R!A<R!A(&1E8VEM86P@;G5M8F5R+CQB<CX*("`@("`J("`\8V]D93XE93PO
M8V]D93X@5&]T86P@:&]U<G,@87,@82!F;&]A="!N=6UB97(*("`@("`J("`@
M("`@("`@("`@("`@("`@*#$@9&%Y+"`R(&AO=7)S+"`S,"!M:6YU=&5S(#T@
M,C8N-2!H;W5R<RDN/&)R/@H@("`@("H@(#QC;V1E/B5F/"]C;V1E/B!4;W1A
M;"!M:6YU=&5S(&%S(&$@9FQO870@;G5M8F5R"B`@("`@*B`@("`@("`@("`@
M("`@("`@("@R(&UI;G5T97,L(#,P('-E8V]N9',@/2`R+C4@;6EN=71E<RDN
M/&)R/@H@("`@("H@(#QC;V1E/B5G/"]C;V1E/B!4;W1A;"!S96-O;F1S(&%S
M(&$@9&5C:6UA;"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#(@
M;6EN=71E<RP@,S`@<V5C;VYD<R`](#DP('-E8V]N9',I+CQB<CX*("`@("`J
M("`\8V]D93XE:#PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(N/&)R
M/@H@("`@("H@(#QC;V1E/B5(/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU
M;6)E<B!L:6UI=&5D('1O(#(@9&EG:71S+CQB<CX*("`@("`J("`\8V]D93XE
M;3PO8V]D93X@36EN=71E<R!A<R!A(&1E8VEM86P@;G5M8F5R+CQB<CX*("`@
M("`J("`\8V]D93XE33PO8V]D93X@36EN=71E<R!A<R!A(&1E8VEM86P@;G5M
M8F5R(&QI;6ET960@=&\@,B!D:6=I=',N/&)R/@H@("`@("H@(#QC;V1E/B5N
M/"]C;V1E/B!.97=L:6YE(&-H87)A8W1E<B`H7&XI+CQB<CX*("`@("`J("`\
M8V]D93XE<#PO8V]D93X@16ET:&5R("=A;2<@;W(@)W!M)R!D97!E;F1I;F<@
M;VX@=&AE('1I;64N($EF("=P;2<*("`@("`J("`@("`@("`@("`@("`@("`@
M:7,@9&5T96-T960@:70@861D<R`Q,B!H;W5R<R!T;R!T:&4@<F5S=6QT:6YG
M('1I;64*("`@("`J("`@("`@("`@("`@("`@("`@<W!A;B`H=VET:&]U="!A
M;GD@8VAE8VMS*2X@5&AI<R!I<R!C87-E"B`@("`@*B`@("`@("`@("`@("`@
M("`@(&EN<V5N<VET:79E+CQB<CX*("`@("`J("`\8V]D93XE<CPO8V]D93X@
M5&EM92!I;B!A;2]P;2!N;W1A=&EO;BP@<V%M92!A<R`B)4@Z)4TZ)5,@)7`B
M+CQB<CX*("`@("`J("`\8V]D93XE4CPO8V]D93X@5&EM92!I;B`R-"UH;W5R
M(&YO=&%T:6]N+"!S86UE(&%S("(E2#HE32(N/&)R/@H@("`@("H@(#QC;V1E
M/B5S/"]C;V1E/B!396-O;F1S(&%S(&$@9&5C:6UA;"!N=6UB97(N/&)R/@H@
M("`@("H@(#QC;V1E/B53/"]C;V1E/B!396-O;F1S(&%S(&$@9&5C:6UA;"!N
M=6UB97(@;&EM:71E9"!T;R`R(&1I9VET<RX\8G(^"B`@("`@*B`@/&-O9&4^
M)70\+V-O9&4^(%1A8B!C:&%R86-T97(@*%QT*2X\8G(^"B`@("`@*B`@/&-O
M9&4^)50\+V-O9&4^($-U<G)E;G0@=&EM92!E<75I=F%L96YT+"!S86UE(&%S
M("(E2#HE33HE4R(N/&)R/@H@("`@("H@(#QC;V1E/B4E/"]C;V1E/B!,:71E
M<F%L("<E)RX\8G(^"B`@("`@*@H@("`@("H@0'!A<F%M("!S=')I;F<@)'1I
M;64@("!3=')I;F<@9G)O;2!W:&5R92!T;R!G970@=&AE('1I;64@<W!A;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("!I;F9O<FUA=&EO;BX*("`@
M("`J($!P87)A;2`@<W1R:6YG("1F;W)M870@1F]R;6%T('-T<FEN9RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@("!4<G5E(&]N('-U8V-E<W,N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T1G)O;5-T<FEN9R@D=&EM92P@)&9O<FUA="`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*&ES7VYU;&PH)&9O<FUA="DI('L*("`@("`@("`@("`@
M)&9O<FUA="`]("1'3$]"04Q36R=?1$%415]34$%.7TE.4%547T9/4DU!5"==
M.PH@("`@("`@('T*("`@("`@("`O+R!)9B!F;W)M870@:7,@82!S=')I;F<L
M(&ET('!A<G-E<R!T:&4@<W1R:6YG(&9O<FUA="X*("`@("`@("!I9B`H:7-?
M<W1R:6YG*"1F;W)M870I*2!["B`@("`@("`@("`@("1S='(@/2`G)SL*("`@
M("`@("`@("`@)'9A<G,@/2!A<G)A>2@I.PH@("`@("`@("`@("`D<&T@/2`G
M86TG.PH@("`@("`@("`@("`D9&%Y(#T@)&AO=7(@/2`D;6EN=71E(#T@)'-E
M8V]N9"`](#`["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-T<FQE
M;B@D9F]R;6%T*3L@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&-H87(@/2`D
M9F]R;6%T>R1I?3L*("`@("`@("`@("`@("`@(&EF("@D8VAA<B`]/2`G)2<I
M('L*("`@("`@("`@("`@("`@("`@("`D;F5X=&-H87(@/2`D9F]R;6%T>RLK
M)&E].PH@("`@("`@("`@("`@("`@("`@('-W:71C:"`H)&YE>'1C:&%R*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)V,G.@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)60L("5D.B5D.B5D)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'9A<G,L("=D87DG+"`G:&]U<B<L
M("=M:6YU=&4G+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G0R<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"P@)3)D
M.B4R9#HE,F0G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M<'5S:"@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R<RP@
M)V1A>2<L("=H;W5R)RP@)VUI;G5T92<L("=S96-O;F0G*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E("=D)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S
M='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M7W!U<V@H)'9A<G,L("=D87DG*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E("=$)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R5D)SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=D
M87DG*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("=E)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1S='(@+CT@)R5F)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=H;W5R)RD["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`G9B<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<W1R("X]("<E9B<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>5]P=7-H*"1V87)S+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G
M9R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9B<[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S
M+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G:"<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E9"<["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V87)S+"`G:&]U<B<I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@("`@(&-A<V4@)T@G.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-T<B`N/2`G)3)D)SL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%R<F%Y7W!U<V@H)'9A<G,L("=H;W5R)RD["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`G;2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]
M("<E9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H
M*"1V87)S+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G32<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0G.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)VUI
M;G5T92<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VXG.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'-T<B`N/2`B7&XB.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@)W`G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G
M)3)S)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H
M)'9A<G,L("=P;2<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)W(G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)3)D.B4R9#HE,F0@)3)S
M)SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9A<G,L("=H;W5R)RP@
M)VUI;G5T92<L("=S96-O;F0G+"`G<&TG*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("=2)SH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)R4R
M9#HE,F0G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S
M:"@D=F%R<RP@)VAO=7(G+"`G;6EN=71E)RD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`G<R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E
M9"<["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]P=7-H*"1V
M87)S+"`G<V5C;VYD)RD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G4R<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<W1R("X]("<E,F0G.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?<'5S:"@D=F%R<RP@)W-E8V]N
M9"<I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@)W0G.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'-T<B`N/2`B7'0B.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M)U0G.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<B`N/2`G)3)D
M.B4R9#HE,F0G.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?
M<'5S:"@D=F%R<RP@)VAO=7(G+"`G;6EN=71E)RP@)W-E8V]N9"<I.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)R4G.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<B`N/2`B)2(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S='(@+CT@)&-H87(@+B`D;F5X=&-H
M87(["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D<W1R("X]("1C:&%R.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1V86QS
M(#T@<W-C86YF*"1T:6UE+"`D<W1R*3L*("`@("`@("`@("`@9F]R96%C:"`H
M)'9A;',@87,@)&D@/3X@)'9A;"D@>PH@("`@("`@("`@("`@("`@:68@*&ES
M7VYU;&PH)'9A;"DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D)'9A<G-;
M)&E=(#T@)'9A;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R
M8V%S96-M<"@D<&TL("=P;2<I(#T](#`I('L*("`@("`@("`@("`@("`@("1H
M;W5R("L](#$R.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R8V%S96-M<"@D
M<&TL("=A;2<I("$](#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^<V5T1G)O;4%R
M<F%Y*&%R<F%Y*"1D87DL("1H;W5R+"`D;6EN=71E+"`D<V5C;VYD*2D["B`@
M("`@("`@+R\@268@9F]R;6%T(&ES(&$@:6YT96=E<BP@:70@=7-E<R!A('!R
M961E9FEN960@9F]R;6%T"B`@("`@("`@+R\@9&5T96-T:6]N(&UE=&AO9"X*
M("`@("`@("!](&5L<V5I9B`H:7-?:6YT96=E<B@D9F]R;6%T*2D@>PH@("`@
M("`@("`@("!S=VET8V@@*"1F;W)M870I('L*("`@("`@("`@("`@("`@(&-A
M<V4@1$%415]34$%.7TE.4%547T9/4DU!5%].3E-6.@H@("`@("`@("`@("`@
M("`@("`@("1T:6UE(#T@<')E9U]S<&QI="@G+UQ$*R\G+"`D=&EM92D["B`@
M("`@("`@("`@("`@("`@("`@<W=I=&-H("AC;W5N="@D=&EM92DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M07)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH,"P@,"P@,"P@,"DI
M.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(#$Z"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU!<G)A>2@*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@P+"`D=&EM
M95LP72P@,"P@,"DI.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(#(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E
M=$9R;VU!<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A
M<G)A>2@P+"`D=&EM95LP72P@)'1I;65;,5TL(#`I*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`S.@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YS971&<F]M07)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH,"P@)'1I;65;,%TL("1T:6UE6S%=
M+"`D=&EM95LR72DI.PH@("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS
M971&<F]M07)R87DH)'1I;64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!3970@=&AE('1I;64@<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F('-E
M8V]N9',N"B`@("`@*@H@("`@("H@0'!A<F%M("!I;G0@("1S96-O;F1S(%1O
M=&%L(&YU;6)E<B!O9B!S96-O;F1S+@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"!4<G5E(&]N('-U8V-E<W,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1G)O;5-E8V]N9',H)'-E
M8V]N9',I"B`@("!["B`@("`@("`@:68@*"1S96-O;F1S(#P@,"D@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@("1S96,@
M(#T@:6YT=F%L*"1S96-O;F1S*3L*("`@("`@("`D;6EN("`](&9L;V]R*"1S
M96,@+R`V,"D["B`@("`@("`@)&AO=7(@/2!F;&]O<B@D;6EN("\@-C`I.PH@
M("`@("`@("1D87D@(#T@:6YT=F%L*&9L;V]R*"1H;W5R("\@,C0I*3L*("`@
M("`@("`D=&AI<RT^<V5C;VYD(#T@)'-E8R`E(#8P.PH@("`@("`@("1T:&ES
M+3YM:6YU=&4@/2`D;6EN("4@-C`["B`@("`@("`@)'1H:7,M/FAO=7(@("`]
M("1H;W5R("4@,C0["B`@("`@("`@)'1H:7,M/F1A>2`@("`]("1D87D["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@
M=&AE('1I;64@<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F(&UI;G5T97,N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!F;&]A="`D;6EN=71E<R!4;W1A;"!N
M=6UB97(@;V8@;6EN=71E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@
M(%1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&<F]M36EN=71E<R@D;6EN=71E
M<RD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G-E=$9R;VU396-O;F1S
M*')O=6YD*"1M:6YU=&5S("H@-C`I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@82!T;W1A;"!N=6UB97(@;V8@:&]U
M<G,N"B`@("`@*@H@("`@("H@0'!A<F%M("!F;&]A="`D:&]U<G,@5&]T86P@
M;G5M8F5R(&]F(&AO=7)S+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@
M5')U92!O;B!S=6-C97-S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$9R;VU(;W5R<R@D:&]U<G,I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C;VYD<RAR;W5N
M9"@D:&]U<G,@*B`S-C`P*2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!3970@
M=&AE('1I;64@<W!A;B!F<F]M(&$@=&]T86P@;G5M8F5R(&]F(&1A>7,N"B`@
M("`@*@H@("`@("H@0'!A<F%M("!F;&]A="`D9&%Y<R!4;W1A;"!N=6UB97(@
M;V8@9&%Y<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%1R=64@;VX@
M<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971&<F]M1&%Y<R@D9&%Y<RD*("`@('L*("`@("`@
M("!R971U<FX@)'1H:7,M/G-E=$9R;VU396-O;F1S*')O=6YD*"1D87ES("H@
M.#8T,#`I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%-E="!T:&4@<W!A;B!F
M<F]M('1H92!E;&%P<V5D('1I;64@8F5T=V5E;B!T=V\@9&%T97,N"B`@("`@
M*@H@("`@("H@4V5T('1H92!S<&%N(&9R;VT@=&AE(&5L87!S960@=&EM92!B
M971W965N('1W;R!D871E<RX@5&AE('1I;64@<W!A;@H@("`@("H@:7,@86QL
M=V%Y<R!P;W-I=&EV92P@<V\@=&AE(&1A=&4G<R!O<F1E<B!I<R!N;W0@:6UP
M;W)T86YT+@H@("`@("H*("`@("`J($!P87)A;2`@;V)J96-T($1A=&4@)&1A
M=&4Q($9I<G-T($1A=&4N"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E("1D
M871E,B!396-O;F0@1&%T92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@
M(%1R=64@;VX@<W5C8V5S<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971&<F]M1&%T941I9F8H)&1A=&4Q
M+"`D9&%T93(I"B`@("!["B`@("`@("`@:68@*"%I<U]A*"1D871E,2P@)V1A
M=&4G*2!O<B`A:7-?82@D9&%T93(L("=D871E)RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("`D9&%T93$M/G1O551#
M*"D["B`@("`@("`@)&1A=&4R+3YT;U540R@I.PH@("`@("`@(&EF("@D9&%T
M93$M/F%F=&5R*"1D871E,BDI('L*("`@("`@("`@("`@;&ES="@D9&%T93$L
M("1D871E,BD@/2!A<G)A>2@D9&%T93(L("1D871E,2D["B`@("`@("`@?0H@
M("`@("`@("1D87ES(#T@1&%T95]#86QC.CID871E1&EF9B@*("`@("`@("`@
M("`@)&1A=&4Q+3YG971$87DH*2P@)&1A=&4Q+3YG971-;VYT:"@I+"`D9&%T
M93$M/F=E=%EE87(H*2P*("`@("`@("`@("`@)&1A=&4R+3YG971$87DH*2P@
M)&1A=&4R+3YG971-;VYT:"@I+"`D9&%T93(M/F=E=%EE87(H*0H@("`@("`@
M("D["B`@("`@("`@)&AO=7)S(#T@)&1A=&4R+3YG971(;W5R*"D@+2`D9&%T
M93$M/F=E=$AO=7(H*3L*("`@("`@("`D;6EN<R`@/2`D9&%T93(M/F=E=$UI
M;G5T92@I("T@)&1A=&4Q+3YG971-:6YU=&4H*3L*("`@("`@("`D<V5C<R`@
M/2`D9&%T93(M/F=E=%-E8V]N9"@I("T@)&1A=&4Q+3YG971396-O;F0H*3L*
M("`@("`@("`D=&AI<RT^<V5T1G)O;5-E8V]N9',H"B`@("`@("`@("`@("1D
M87ES("H@.#8T,#`@*R`D:&]U<G,@*B`S-C`P("L@)&UI;G,@*B`V,"`K("1S
M96-S"B`@("`@("`@*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!T:&4@=&EM92!S<&%N(&9R;VT@86YO=&AE<B!T
M:6UE(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$871E
M7U-P86X@)'1I;64@4V]U<F-E('1I;64@<W!A;B!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L("`@5')U92!O;B!S=6-C97-S+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M<'DH)'1I;64I"B`@("!["B`@("`@("`@:68@*&ES7V$H)'1I;64L("=D871E
M7W-P86XG*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5C;VYD(#T@)'1I;64M
M/G-E8V]N9#L*("`@("`@("`@("`@)'1H:7,M/FUI;G5T92`]("1T:6UE+3YM
M:6YU=&4["B`@("`@("`@("`@("1T:&ES+3YH;W5R("`@/2`D=&EM92T^:&]U
M<CL*("`@("`@("`@("`@)'1H:7,M/F1A>2`@("`]("1T:6UE+3YD87D["B`@
M("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!4:6UE('-P86X@<')E='1Y('!R:6YT:6YG("AS:6UI;&%R('1O
M($1A=&4Z.F9O<FUA="@I*2X*("`@("`J"B`@("`@*B!&;W)M871S('1H92!T
M:6UE('-P86X@:6X@=&AE(&=I=F5N(&9O<FUA="P@<VEM:6QA<B!T;PH@("`@
M("H@<W1R9G1I;64H*2!A;F0@1&%T93HZ9F]R;6%T*"DN/&)R/@H@("`@("H@
M/&)R/@H@("`@("H@1F]R;6%T=&EN9R!O<'1I;VYS.CQB<CX*("`@("`J("`\
M8V]D93XE0SPO8V]D93X@1&%Y<R!W:71H('1I;64L('-A;64@87,@(B5$+"`E
M2#HE33HE4R(N/&)R/@H@("`@("H@(#QC;V1E/B5D/"]C;V1E/B!4;W1A;"!D
M87ES(&%S(&$@9FQO870@;G5M8F5R"B`@("`@*B`@("`@("`@("`@("`@("`@
M("@R(&1A>7,L(#$R(&AO=7)S(#T@,BXU(&1A>7,I+CQB<CX*("`@("`J("`\
M8V]D93XE1#PO8V]D93X@1&%Y<R!A<R!A(&1E8VEM86P@;G5M8F5R+CQB<CX*
M("`@("`J("`\8V]D93XE93PO8V]D93X@5&]T86P@:&]U<G,@87,@82!F;&]A
M="!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`@*#$@9&%Y+"`R(&AO
M=7)S+"`S,"!M:6YU=&5S(#T@,C8N-2!H;W5R<RDN/&)R/@H@("`@("H@(#QC
M;V1E/B5%/"]C;V1E/B!4;W1A;"!H;W5R<R!A<R!A(&1E8VEM86P@;G5M8F5R
M"B`@("`@*B`@("`@("`@("`@("`@("`@("@Q(&1A>2P@,B!H;W5R<RP@-#`@
M;6EN=71E<R`](#(V(&AO=7)S*2X\8G(^"B`@("`@*B`@/&-O9&4^)68\+V-O
M9&4^(%1O=&%L(&UI;G5T97,@87,@82!F;&]A="!N=6UB97(*("`@("`J("`@
M("`@("`@("`@("`@("`@*#(@;6EN=71E<RP@,S`@<V5C;VYD<R`](#(N-2!M
M:6YU=&5S*2X\8G(^"B`@("`@*B`@/&-O9&4^)48\+V-O9&4^(%1O=&%L(&UI
M;G5T97,@87,@82!D96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@
M("`@("`H,2!H;W5R+"`R(&UI;G5T97,L(#0P('-E8V]N9',@/2`V,B!M:6YU
M=&5S*2X\8G(^"B`@("`@*B`@/&-O9&4^)6<\+V-O9&4^(%1O=&%L('-E8V]N
M9',@87,@82!D96-I;6%L(&YU;6)E<@H@("`@("H@("`@("`@("`@("`@("`@
M("`H,B!M:6YU=&5S+"`S,"!S96-O;F1S(#T@.3`@<V5C;VYD<RDN/&)R/@H@
M("`@("H@(#QC;V1E/B5H/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L(&YU;6)E
M<B`H,"!T;R`R,RDN/&)R/@H@("`@("H@(#QC;V1E/B5(/"]C;V1E/B!(;W5R
M<R!A<R!D96-I;6%L(&YU;6)E<B`H,#`@=&\@,C,I+CQB<CX*("`@("`J("`\
M8V]D93XE:3PO8V]D93X@2&]U<G,@87,@9&5C:6UA;"!N=6UB97(@;VX@,3(M
M:&]U<B!C;&]C:PH@("`@("H@("`@("`@("`@("`@("`@("`H,2!T;R`Q,BDN
M/&)R/@H@("`@("H@(#QC;V1E/B5)/"]C;V1E/B!(;W5R<R!A<R!D96-I;6%L
M(&YU;6)E<B!O;B`Q,BUH;W5R(&-L;V-K"B`@("`@*B`@("`@("`@("`@("`@
M("`@("@P,2!T;R`Q,BDN/&)R/@H@("`@("H@(#QC;V1E/B5M/"]C;V1E/B!-
M:6YU=&5S(&%S(&$@9&5C:6UA;"!N=6UB97(@*#`@=&\@-3DI+CQB<CX*("`@
M("`J("`\8V]D93XE33PO8V]D93X@36EN=71E<R!A<R!A(&1E8VEM86P@;G5M
M8F5R("@P,"!T;R`U.2DN/&)R/@H@("`@("H@(#QC;V1E/B5N/"]C;V1E/B!.
M97=L:6YE(&-H87)A8W1E<B`H7&XI+CQB<CX*("`@("`J("`\8V]D93XE<#PO
M8V]D93X@16ET:&5R("=A;2<@;W(@)W!M)R!D97!E;F1I;F<@;VX@=&AE('1I
M;64N/&)R/@H@("`@("H@(#QC;V1E/B50/"]C;V1E/B!%:71H97(@)T%-)R!O
M<B`G4$TG(&1E<&5N9&EN9R!O;B!T:&4@=&EM92X\8G(^"B`@("`@*B`@/&-O
M9&4^)7(\+V-O9&4^(%1I;64@:6X@86TO<&T@;F]T871I;VXL('-A;64@87,@
M(B5).B5-.B53("5P(BX\8G(^"B`@("`@*B`@/&-O9&4^)5(\+V-O9&4^(%1I
M;64@:6X@,C0M:&]U<B!N;W1A=&EO;BP@<V%M92!A<R`B)4@Z)4TB+CQB<CX*
M("`@("`J("`\8V]D93XE<SPO8V]D93X@4V5C;VYD<R!A<R!A(&1E8VEM86P@
M;G5M8F5R("@P('1O(#4Y*2X\8G(^"B`@("`@*B`@/&-O9&4^)5,\+V-O9&4^
M(%-E8V]N9',@87,@82!D96-I;6%L(&YU;6)E<B`H,#`@=&\@-3DI+CQB<CX*
M("`@("`J("`\8V]D93XE=#PO8V]D93X@5&%B(&-H87)A8W1E<B`H7'0I+CQB
M<CX*("`@("`J("`\8V]D93XE5#PO8V]D93X@0W5R<F5N="!T:6UE(&5Q=6EV
M86QE;G0L('-A;64@87,@(B5(.B5-.B53(BX\8G(^"B`@("`@*B`@/&-O9&4^
M)24\+V-O9&4^($QI=&5R86P@)R4G+CQB<CX*("`@("`J"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`D9F]R;6%T(%1H92!F;W)M870@<W1R:6YG(&9O<B!R971U
M<FYE9"!T:6UE('-P86XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M5&AE('1I;64@<W!A;B!I;B!S<&5C:69I960@9F]R;6%T+@H@("`@("H*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&9O<FUA
M="@D9F]R;6%T(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?;G5L;"@D
M9F]R;6%T*2D@>PH@("`@("`@("`@("`D9F]R;6%T(#T@)$=,3T)!3%-;)U]$
M051%7U-004Y?1D]234%4)UT["B`@("`@("`@?0H@("`@("`@("1O=71P=70@
M/2`G)SL*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&9O<FUA
M="D[("1I*RLI('L*("`@("`@("`@("`@)&-H87(@/2`D9F]R;6%T>R1I?3L*
M("`@("`@("`@("`@:68@*"1C:&%R(#T]("<E)RD@>PH@("`@("`@("`@("`@
M("`@)&YE>'1C:&%R(#T@)&9O<FUA='LK*R1I?3L*("`@("`@("`@("`@("`@
M('-W:71C:"`H)&YE>'1C:&%R*2!["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G0R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R
M:6YT9B@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E9"P@)3`R9#HE
M,#)D.B4P,F0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1A>2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUI;G5T92P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YS96-O;F0*("`@
M("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G9"<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G1O1&%Y<R@I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!C87-E("=$)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U
M='!U="`N/2`D=&AI<RT^9&%Y.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=E)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^=&](;W5R<R@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E("=%)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2!F;&]O<B@D=&AI<RT^=&](;W5R<R@I*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G9B<Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'1H:7,M/G1O
M36EN=71E<R@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!C87-E("=&)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!F;&]O<B@D=&AI<RT^=&]-:6YU=&5S*"DI.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E("=G)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2`D=&AI<RT^=&]396-O;F1S*"D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)V@G.@H@("`@
M("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1T:&ES+3YH;W5R.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E("=()SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U
M="`N/2!S<')I;G1F*"<E,#)D)RP@)'1H:7,M/FAO=7(I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=I)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&AO=7(@/0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*"1T:&ES+3YH;W5R("L@,2D@/B`Q,B`_
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`M(#$R
M(#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]("@D:&]U<B`]/2`P
M*2`_(#$R(#H@)&AO=7(["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)TDG.@H@("`@("`@("`@("`@
M("`@("`@("`@("`D:&]U<B`]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`H)'1H:7,M/FAO=7(@*R`Q*2`^(#$R(#\*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YH;W5R("T@,3(@.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FAO=7(["B`@("`@("`@("`@("`@("`@("`@
M("`@("1O=71P=70@+CT@<W!R:6YT9B@G)3`R9"<L("1H;W5R/3TP(#\@,3(@
M.B`D:&]U<BD["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)VTG.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1T:&ES+3YM:6YU=&4["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)TTG
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H
M)R4P,F0G+"1T:&ES+3YM:6YU=&4I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=N)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`B7&XB.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=P)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI
M<RT^:&]U<B`^/2`Q,B`_("=P;2<@.B`G86TG.PH@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=0)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2`D=&AI<RT^:&]U
M<B`^/2`Q,B`_("=032<@.B`G04TG.PH@("`@("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=R)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@)&AO=7(@/0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@*"1T:&ES+3YH;W5R("L@,2D@/B`Q,B`_"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U<B`M(#$R(#H*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YH;W5R.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G)3`R9#HE,#)D.B4P,F0@)7,G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&AO=7(]/3`@/R`@,3(@.B`D:&]U<BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM:6YU=&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<V5C;VYD+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FAO=7(@/CT@,3(@/R`G<&TG
M(#H@)V%M)PH@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E
M("=2)SH*("`@("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I
M;G1F*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R4P,F0Z)3`R9"<L
M("1T:&ES+3YH;W5R+"`D=&AI<RT^;6EN=71E"B`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@(&-A<V4@)W,G.@H@("`@("`@("`@("`@("`@("`@
M("`@("`D;W5T<'5T("X]("1T:&ES+3YS96-O;F0["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)U,G
M.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]('-P<FEN=&8H
M)R4P,F0G+"`D=&AI<RT^<V5C;VYD*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G="<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@(EQT(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G5"<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@<W!R
M:6YT9B@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("<E,#)D.B4P,F0Z
M)3`R9"<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&]U
M<BP@)'1H:7,M/FUI;G5T92P@)'1H:7,M/G-E8V]N9`H@("`@("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@("`@("!C87-E("<E)SH*("`@("`@("`@("`@("`@
M("`@("`@("`@)&]U='!U="`N/2`B)2(["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)&-H87(@+B`D;F5X=&-H
M87(["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;W5T<'5T("X]("1C:&%R.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]N=F5R="!T:6UE('-P86X@=&\@<V5C;VYD<RX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="!4:6UE('-P86X@87,@86X@:6YT96=E
M<B!N=6UB97(@;V8@<V5C;VYD<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;U-E8V]N9',H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^9&%Y("H@.#8T,#`@*R`D=&AI<RT^:&]U
M<B`J(#,V,#`@*PH@("`@("`@("`@("`D=&AI<RT^;6EN=71E("H@-C`@*R`D
M=&AI<RT^<V5C;VYD.PH@("`@?0H*("`@("\J*@H@("`@("H@0V]N=F5R="!T
M:6UE('-P86X@=&\@;6EN=71E<RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&9L
M;V%T(%1I;64@<W!A;B!A<R!A(&1E8VEM86P@;G5M8F5R(&]F(&UI;G5T97,N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@=&]-:6YU=&5S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/F1A>2`J(#$T-#`@*R`D=&AI<RT^:&]U<B`J(#8P("L@)'1H:7,M/FUI;G5T
M92`K"B`@("`@("`@("`@("1T:&ES+3YS96-O;F0@+R`V,#L*("`@('T*"B`@
M("`O*BH*("`@("`J($-O;G9E<G0@=&EM92!S<&%N('1O(&AO=7)S+@H@("`@
M("H*("`@("`J($!R971U<FX@9FQO870@5&EM92!S<&%N(&%S(&$@9&5C:6UA
M;"!N=6UB97(@;V8@:&]U<G,N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=&](;W5R<R@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD87D@*B`R-"`K("1T:&ES+3YH;W5R("L@)'1H
M:7,M/FUI;G5T92`O(#8P("L*("`@("`@("`@("`@)'1H:7,M/G-E8V]N9"`O
M(#,V,#`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;VYV97)T('1I;64@<W!A
M;B!T;R!D87ES+@H@("`@("H*("`@("`J($!R971U<FX@9FQO870@5&EM92!S
M<&%N(&%S(&$@9&5C:6UA;"!N=6UB97(@;V8@9&%Y<RX*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!T;T1A>7,H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9&%Y("L@)'1H:7,M/FAO
M=7(@+R`R-"`K("1T:&ES+3YM:6YU=&4@+R`Q-#0P("L*("`@("`@("`@("`@
M)'1H:7,M/G-E8V]N9"`O(#@V-#`P.PH@("`@?0H*("`@("\J*@H@("`@("H@
M061D<R!A('1I;64@<W!A;BX*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C
M="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O(&%D9"X*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A9&0H
M)'1I;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YS971&<F]M4V5C
M;VYD<R@*("`@("`@("`@("`@)'1H:7,M/G1O4V5C;VYD<R@I("L@)'1I;64M
M/G1O4V5C;VYD<R@I"B`@("`@("`@*3L*("`@('T*"B`@("`O*BH*("`@("`J
M(%-U8G1R86-T<R!A('1I;64@<W!A;BX*("`@("`J"B`@("`@*B!3=6)T<F%C
M=',@82!T:6UE('-P86XN($EF('1H92!T:6UE('-P86X@=&\@<W5B=')A8W0@
M:7,@;&%R9V5R"B`@("`@*B!T:&%N('1H92!O<FEG:6YA;"P@=&AE(')E<W5L
M="!I<R!Z97)O("AT:&5R92=S(&YO('-E;G-E(&EN"B`@("`@*B!N96=A=&EV
M92!T:6UE('-P86YS*2X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C="!$
M871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O('-U8G1R86-T+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-U
M8G1R86-T*"1T:6UE*0H@("`@>PH@("`@("`@("1S=6(@/2`D=&AI<RT^=&]3
M96-O;F1S*"D@+2`D=&EM92T^=&]396-O;F1S*"D["B`@("`@("`@:68@*"1S
M=6(@/"`P*2!["B`@("`@("`@("`@("1T:&ES+3YS971&<F]M4V5C;VYD<R@P
M*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<V5T1G)O
M;5-E8V]N9',H)'-U8BD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@
M("H@5&5L;',@:68@=&EM92!S<&%N(&ES(&5Q=6%L('1O("1T:6UE+@H@("`@
M("H*("`@("`J($!P87)A;2`@;V)J96-T($1A=&5?4W!A;B`D=&EM92!4:6UE
M('-P86X@=&\@8V]M<&%R92!T;RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VP@("!4<G5E(&EF('1H92!T:6UE('-P86YS(&%R92!E<75A;"X*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!E
M<75A;"@D=&EM92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1O4V5C
M;VYD<R@I(#T]("1T:6UE+3YT;U-E8V]N9',H*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1E;&QS(&EF('1H:7,@=&EM92!S<&%N(&ES(&=R96%T97(@;W(@
M97%U86P@=&AA;B`D=&EM92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B:F5C
M="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O(&-O;7!A<F4@=&\N"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@5')U92!I9B!T:&ES('1I;64@
M<W!A;B!I<R!G<F5A=&5R(&]R(&5Q=6%L('1H86X@)'1I;64N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9W)E
M871E<D5Q=6%L*"1T:6UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M=&]396-O;F1S*"D@/CT@)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@5&5L;',@:68@=&AI<R!T:6UE('-P86X@:7,@;&]W97(@
M;W(@97%U86P@=&AA;B`D=&EM92X*("`@("`J"B`@("`@*B!`<&%R86T@(&]B
M:F5C="!$871E7U-P86X@)'1I;64@5&EM92!S<&%N('1O(&-O;7!A<F4@=&\N
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("`@5')U92!I9B!T:&ES('1I
M;64@<W!A;B!I<R!L;W=E<B!O<B!E<75A;"!T:&%N("1T:6UE+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO
M=V5R17%U86PH)'1I;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT
M;U-E8V]N9',H*2`\/2`D=&EM92T^=&]396-O;F1S*"D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!496QL<R!I9B!T:&ES('1I;64@<W!A;B!I<R!G<F5A=&5R
M('1H86X@)'1I;64N"B`@("`@*@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T
M95]3<&%N("1T:6UE(%1I;64@<W!A;B!T;R!C;VUP87)E('1O+@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;"`@(%1R=64@:68@=&AI<R!T:6UE('-P86X@
M:7,@9W)E871E<B!T:&%N("1T:6UE+@H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=R96%T97(H)'1I;64I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YT;U-E8V]N9',H*2`^("1T:6UE
M+3YT;U-E8V]N9',H*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1E;&QS(&EF
M('1H:7,@=&EM92!S<&%N(&ES(&QO=V5R('1H86X@)'1I;64N"B`@("`@*@H@
M("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE(%1I;64@<W!A
M;B!T;R!C;VUP87)E('1O+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@
M(%1R=64@:68@=&AI<R!T:6UE('-P86X@:7,@;&]W97(@=&AA;B`D=&EM92X*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!L;W=E<B@D=&EM92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G1O4V5C;VYD<R@I(#P@)'1I;64M/G1O4V5C;VYD<R@I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0V]M<&%R97,@='=O('1I;64@<W!A;G,N"B`@("`@*@H@
M("`@("H@0V]M<&%R97,@='=O('1I;64@<W!A;G,N(%-U:71A8FQE(&9O<B!U
M<V4@:6X@<V]R=&EN9R!F=6YC=&EO;G,N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE,2!4:&4@9FER<W0@=&EM92!S<&%N
M+@H@("`@("H@0'!A<F%M("!O8FIE8W0@1&%T95]3<&%N("1T:6UE,B!4:&4@
M<V5C;VYD('1I;64@<W!A;BX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M("`P(&EF('1H92!T:6UE('-P86YS(&%R92!E<75A;"P@+3$@:68@=&EM93$@
M:7,@;&]W97(*("`@("`J("`@("`@("`@("`@("`@('1H86X@=&EM93(L(#$@
M:68@=&EM93$@:7,@9W)E871E<B!T:&%N('1I;64R+@H@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O;7!A<F4H)'1I;64Q+"`D=&EM93(I"B`@("!["B`@("`@("`@
M:68@*"1T:6UE,2T^97%U86PH)'1I;64R*2D@>PH@("`@("`@("`@("!R971U
M<FX@,#L*("`@("`@("!](&5L<V5I9B`H)'1I;64Q+3YL;W=E<B@D=&EM93(I
M*2!["B`@("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!496QL<R!I9B!T:&4@=&EM92!S<&%N(&ES(&5M<'1Y("AZ97)O
M(&QE;F=T:"DN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L(%1R=64@:7,@
M:70G<R!E;7!T>2X*("`@("`J+PH@("`@9G5N8W1I;VX@:7-%;7!T>2@I"B`@
M("!["B`@("`@("`@<F5T=7)N("$D=&AI<RT^9&%Y("8F("$D=&AI<RT^:&]U
M<B`F)B`A)'1H:7,M/FUI;G5T92`F)B`A)'1H:7,M/G-E8V]N9#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E="!T:&4@9&5F875L="!I;G!U="!F;W)M870N
M"B`@("`@*@H@("`@("H@0'!A<F%M("!M:7AE9"`D9F]R;6%T($YE=R!D969A
M=6QT(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M(%!R979I;W5S(&1E9F%U;'0@:6YP=70@9F]R;6%T+@H@("`@("H*("`@("`J
M($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&5F875L=$EN<'5T
M1F]R;6%T*"1F;W)M870I"B`@("!["B`@("`@("`@)&]L9"`]("1'3$]"04Q3
M6R=?1$%415]34$%.7TE.4%547T9/4DU!5"==.PH@("`@("`@("1'3$]"04Q3
M6R=?1$%415]34$%.7TE.4%547T9/4DU!5"==(#T@)&9O<FUA=#L*("`@("`@
M("!R971U<FX@)&]L9#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@
M9&5F875L="!I;G!U="!F;W)M870N"B`@("`@*@H@("`@("H@0')E='5R;B!M
M:7AE9"!$969A=6QT(&EN<'5T(&9O<FUA="X*("`@("`J"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'1);G!U=$9O<FUA
M="@I"B`@("!["B`@("`@("`@<F5T=7)N("1'3$]"04Q36R=?1$%415]34$%.
M7TE.4%547T9/4DU!5"==.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T('1H
M92!D969A=6QT(&9O<FUA="X*("`@("`J"B`@("`@*B!`<&%R86T@(&UI>&5D
M("1F;W)M870@3F5W(&1E9F%U;'0@9F]R;6%T+@H@("`@("H*("`@("`J($!R
M971U<FX@;6EX960@4')E=FEO=7,@9&5F875L="!F;W)M870N"B`@("`@*@H@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!S971$969A=6QT
M1F]R;6%T*"1F;W)M870I"B`@("!["B`@("`@("`@)&]L9"`]("1'3$]"04Q3
M6R=?1$%415]34$%.7T9/4DU!5"==.PH@("`@("`@("1'3$]"04Q36R=?1$%4
M15]34$%.7T9/4DU!5"==(#T@)&9O<FUA=#L*("`@("`@("!R971U<FX@)&]L
M9#L*("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@9&5F875L="!F;W)M
M870N"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"!$969A=6QT(&9O<FUA
M="X*("`@("`J"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$1E9F%U;'1&;W)M870H*0H@("`@>PH@("`@("`@(')E='5R;B`D1TQ/
M0D%,4ULG7T1!5$5?4U!!3E]&3U)-050G73L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@82!C;W!Y(&]F('1H92!O8FIE8W0@*'=O<FMA<G)O=6YD
M(&9O<B!02%`U(&9O<G=A<F0@8V]M<&%T:6)I;&ET>2DN"B`@("`@*@H@("`@
M("H@0')E='5R;B!O8FIE8W0@1&%T95]3<&%N($-O<'D@;V8@=&AE(&]B:F5C
M="X*("`@("`J+PH@("`@9G5N8W1I;VX@7U]C;&]N92@I('L*("`@("`@("`D
M8R`](&=E=%]C;&%S<R@D=&AI<RD["B`@("`@("`@)',@/2!N97<@)&,["B`@
M("`@("`@)',M/F1A>2`@("`]("1T:&ES+3YD87D["B`@("`@("`@)',M/FAO
M=7(@("`]("1T:&ES+3YH;W5R.PH@("`@("`@("1S+3YM:6YU=&4@/2`D=&AI
M<RT^;6EN=71E.PH@("`@("`@("1S+3YS96-O;F0@/2`D=&AI<RT^<V5C;VYD
M.PH@("`@("`@(')E='5R;B`D<SL*("`@('T*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1A=&4O5&EM
M95IO;F4N<&AP````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`T-C,S-S,@,3`U,34T,S0Q,S,@,#(Q-C(Q`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z
M("HO"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`U($)A8F$@0G5E:&QE<BP@4&EE<G)E+4%L
M86EN($IO>64@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('1H92!.97<@0E-$(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\
M('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I
M<R!A=F%I;&%B;&4@=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R;&0M=VED
M92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L
M:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!N97<@
M0E-$;&EC96YS92!A;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O8G1A:6X@
M:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@
M;F]T92!T;R`@("`@("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z
M($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!0:65R<F4M06QA:6X@
M2F]Y92`\<&%J;WEE0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"B\J*@H@*B!4
M:6UE6F]N92!R97!R97-E;G1A=&EO;B!C;&%S<RP@86QO;F<@=VET:"!T:6UE
M('IO;F4@:6YF;W)M871I;VX@9&%T80H@*@H@*B!02%`@=F5R<VEO;G,@-"!A
M;F0@-0H@*@H@*B!`8V%T96=O<GD@("!$871E(&%N9"!4:6UE"B`J($!P86-K
M86=E("`@($1A=&4*("H@0&%U=&AO<B`@("`@0F%B82!"=65H;&5R(#QB86)A
M0&)A8F%Z+F-O;3X*("H@0&%U=&AO<B`@("`@4&EE<G)E+4%L86EN($IO>64@
M/'!A:F]Y94!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@0F%B
M82!"=65H;&5R+"!0:65R<F4M06QA:6X@2F]Y90H@*B!`;&EC96YS92`@("!H
M='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E
M+G!H<"`@3F5W($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@($-64SH@)$ED
M.B!4:6UE6F]N92YP:'`L=B`Q+C$Q(#(P,#4O,3$O,34@,#`Z,38Z-#`@<&%J
M;WEE($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]$871E"B`J+PH*+RHJ"B`J(%1I;65:;VYE(')E<')E<V5N=&%T
M:6]N(&-L87-S+"!A;&]N9R!W:71H('1I;64@>F]N92!I;F9O<FUA=&EO;B!D
M871A"B`J"B`J(%1H92!D969A=6QT('1I;65Z;VYE(&ES('-E="!F<F]M('1H
M92!F:7)S="!V86QI9"!T:6UE>F]N92!I9"!F;W5N9`H@*B!I;B!O;F4@;V8@
M=&AE(&9O;&QO=VEN9R!P;&%C97,L(&EN('1H:7,@;W)D97(Z"B`J("`@*R!G
M;&]B86P@)%]$051%7U1)345:3TY%7T1%1D%53%0*("H@("`K('-Y<W1E;2!E
M;G9I<F]N;65N="!V87)I86)L92!02%!?5%H*("H@("`K('-Y<W1E;2!E;G9I
M<F]N;65N="!V87)I86)L92!46@H@*B`@("L@=&AE(')E<W5L="!O9B!D871E
M*"=4)RD*("H*("H@268@;F\@=F%L:60@=&EM97IO;F4@:60@:7,@9F]U;F0L
M('1H92!D969A=6QT('1I;65Z;VYE(&ES('-E="!T;R`G551#)RX*("H@66]U
M(&UA>2!A;'-O(&UA;G5A;&QY('-E="!T:&4@9&5F875L="!T:6UE>F]N92!B
M>2!P87-S:6YG(&$@=F%L:60@:60@=&\*("H@1&%T95]4:6UE6F]N93HZ<V5T
M1&5F875L="@I+@H@*@H@*B!4:&ES(&-L87-S(&EN8VQU9&5S('1I;64@>F]N
M92!D871A("AF<F]M('IO;F5I;F9O*2!I;B!T:&4@9F]R;2!O9B!A"B`J(&=L
M;V)A;"!A<G)A>2P@)%]$051%7U1)345:3TY%7T1!5$$N"B`J"B`J($!A=71H
M;W(@("`@($)A8F$@0G5E:&QE<B`\8F%B84!B86)A>BYC;VT^"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N
M<V4N<&AP("!.97<@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@4F5L96%S
M93H@,2XT+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+T1A=&4*("HO"F-L87-S($1A=&5?5&EM95IO;F4*>PH@("`@+RHJ
M"B`@("`@*B!4:6UE(%IO;F4@240@;V8@=&AI<R!T:6UE('IO;F4*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:60["B`@("`O*BH*("`@
M("`J($QO;F<@3F%M92!O9B!T:&ES('1I;64@>F]N92`H:64@0V5N=')A;"!3
M=&%N9&%R9"!4:6UE*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1L;VYG;F%M93L*("`@("\J*@H@("`@("H@4VAO<G0@3F%M92!O9B!T
M:&ES('1I;64@>F]N92`H:64@0U-4*0H@("`@("H@0'9A<B!S=')I;F<*("`@
M("`J+PH@("`@=F%R("1S:&]R=&YA;64["B`@("`O*BH*("`@("`J('1R=64@
M:68@=&AI<R!T:6UE('IO;F4@;V)S97)V97,@9&%Y;&EG:'0@<V%V:6YG<R!T
M:6UE"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J+PH@("`@=F%R("1H87-D
M<W0["B`@("`O*BH*("`@("`J($135"!,;VYG($YA;64@;V8@=&AI<R!T:6UE
M('IO;F4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9'-T
M;&]N9VYA;64["B`@("`O*BH*("`@("`J($135"!3:&]R="!.86UE(&]F('1H
M:7,@=&EM97IO;F4*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D9'-T<VAO<G1N86UE.PH@("`@+RHJ"B`@("`@*B!O9F9S970L(&EN(&UI
M;&QI<V5C;VYD<RP@;V8@=&AI<R!T:6UE>F]N90H@("`@("H@0'9A<B!I;G0*
M("`@("`J+PH@("`@=F%R("1O9F9S970["@H@("`@+RHJ"B`@("`@*B!3>7-T
M96T@1&5F875L="!4:6UE(%IO;F4*("`@("`J($!V87(@;V)J96-T($1A=&5?
M5&EM95IO;F4*("`@("`J+PH@("`@=F%R("1D969A=6QT.PH*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0W)E871E<R!A(&YE
M=R!$871E.CI4:6UE6F]N92!O8FIE8W0L(')E<')E<V5N=&EN9R!T:&4@=&EM
M92!Z;VYE"B`@("`@*B!S<&5C:69I960@:6X@)&ED+B`@268@=&AE('-U<'!L
M:65D($E$(&ES(&EN=F%L:60L('1H92!C<F5A=&5D"B`@("`@*B!T:6UE('IO
M;F4@:7,@551#+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1I9"!T:&4@=&EM92!Z;VYE(&ED"B`@("`@*B!`
M<F5T=7)N(&]B:F5C="!$871E7U1I;65:;VYE('1H92!N97<@1&%T95]4:6UE
M6F]N92!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@1&%T95]4:6UE6F]N
M92@D:60I"B`@("!["B`@("`@("`@9VQO8F%L("1?1$%415]424U%6D].15]$
M051!.PH@("`@("`@(&EF*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)1"@D:60I
M*2!["B`@("`@("`@("`@("1T:&ES+3YI9"`]("1I9#L*("`@("`@("`@("`@
M)'1H:7,M/FQO;F=N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)&ED75LG
M;&]N9VYA;64G73L*("`@("`@("`@("`@)'1H:7,M/G-H;W)T;F%M92`]("1?
M1$%415]424U%6D].15]$051!6R1I9%U;)W-H;W)T;F%M92==.PH@("`@("`@
M("`@("`D=&AI<RT^;V9F<V5T(#T@)%]$051%7U1)345:3TY%7T1!5$%;)&ED
M75LG;V9F<V5T)UT["B`@("`@("`@("`@(&EF*"1?1$%415]424U%6D].15]$
M051!6R1I9%U;)VAA<V1S="==*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M:&%S9'-T(#T@=')U93L*("`@("`@("`@("`@("`@("1T:&ES+3YD<W1L;VYG
M;F%M92`]("1?1$%415]424U%6D].15]$051!6R1I9%U;)V1S=&QO;F=N86UE
M)UT["B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T<VAO<G1N86UE(#T@)%]$
M051%7U1)345:3TY%7T1!5$%;)&ED75LG9'-T<VAO<G1N86UE)UT["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^:&%S9'-T
M(#T@9F%L<V4["B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T;&]N9VYA;64@
M/2`D=&AI<RT^;&]N9VYA;64["B`@("`@("`@("`@("`@("`D=&AI<RT^9'-T
M<VAO<G1N86UE(#T@)'1H:7,M/G-H;W)T;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YI9"`]("=55$,G
M.PH@("`@("`@("`@("`D=&AI<RT^;&]N9VYA;64@/2`D7T1!5$5?5$E-15I/
M3D5?1$%405LD=&AI<RT^:61=6R=L;VYG;F%M92==.PH@("`@("`@("`@("`D
M=&AI<RT^<VAO<G1N86UE(#T@)%]$051%7U1)345:3TY%7T1!5$%;)'1H:7,M
M/FED75LG<VAO<G1N86UE)UT["B`@("`@("`@("`@("1T:&ES+3YH87-D<W0@
M/2`D7T1!5$5?5$E-15I/3D5?1$%405LD=&AI<RT^:61=6R=H87-D<W0G73L*
M("`@("`@("`@("`@)'1H:7,M/F]F9G-E="`]("1?1$%415]424U%6D].15]$
M051!6R1T:&ES+3YI9%U;)V]F9G-E="==.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;B!A(%1I;65:;VYE(&]B:F5C="!R97!R97-E
M;G1I;F<@=&AE('-Y<W1E;2!D969A=6QT('1I;64@>F]N90H@("`@("H*("`@
M("`J(%)E='5R;B!A(%1I;65:;VYE(&]B:F5C="!R97!R97-E;G1I;F<@=&AE
M('-Y<W1E;2!D969A=6QT('1I;64@>F]N92P*("`@("`J('=H:6-H(&ES(&EN
M:71I86QI>F5D(&1U<FEN9R!T:&4@;&]A9&EN9R!O9B!4:6UE6F]N92YP:'`N
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@
M;V)J96-T($1A=&5?5&EM95IO;F4@=&AE(&1E9F%U;'0@=&EM92!Z;VYE"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&=E=$1E9F%U;'0H*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$5&055,5#L*("`@("`@("!R971U
M<FX@;F5W($1A=&5?5&EM95IO;F4H)%]$051%7U1)345:3TY%7T1%1D%53%0I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&4@<WES=&5M(&1E9F%U
M;'0@=&EM92!Z;VYE('1O('1H92!T:6UE('IO;F4@:6X@)&ED"B`@("`@*@H@
M("`@("H@4V5T<R!T:&4@<WES=&5M(&1E9F%U;'0@=&EM92!Z;VYE('1O('1H
M92!T:6UE('IO;F4@:6X@)&ED"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J($!P87)A;2!S=')I;F<@)&ED('1H92!T:6UE('IO;F4@:60@
M=&\@=7-E"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$1E9F%U;'0H)&ED*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$5&055,5#L*
M("`@("`@("!I9BA$871E7U1I;65:;VYE.CII<U9A;&ED240H)&ED*2D@>PH@
M("`@("`@("`@("`D7T1!5$5?5$E-15I/3D5?1$5&055,5"`]("1I9#L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!497-T<R!I9B!G:79E;B!I
M9"!I<R!R97!R97-E;G1E9"!I;B!T:&4@)%]$051%7U1)345:3TY%7T1!5$$@
M=&EM92!Z;VYE(&1A=&$*("`@("`J"B`@("`@*B!497-T<R!I9B!G:79E;B!I
M9"!I<R!R97!R97-E;G1E9"!I;B!T:&4@)%]$051%7U1)345:3TY%7T1!5$$@
M=&EM92!Z;VYE(&1A=&$*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'!A<F%M('-T<FEN9R`D:60@=&AE(&ED('1O('1E<W0*("`@("`J
M($!R971U<FX@8F]O;&5A;B!T<G5E(&EF('1H92!S=7!P;&EE9"!)1"!I<R!V
M86QI9`H@("`@("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED240H)&ED*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D7T1!5$5?5$E-15I/3D5?1$%403L*("`@("`@
M("!I9BAI<W-E="@D7T1!5$5?5$E-15I/3D5?1$%405LD:61=*2D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@27,@=&AI<R!T:6UE('IO;F4@97%U86P@=&\@86YO=&AE<@H@("`@
M("H*("`@("`J(%1E<W1S('1O('-E92!I9B!T:&ES('1I;64@>F]N92!I<R!E
M<75A;"`H:61S(&UA=&-H*0H@("`@("H@=&\@82!G:79E;B!$871E7U1I;65:
M;VYE(&]B:F5C="X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'!A<F%M(&]B:F5C="!$871E7U1I;65:;VYE("1T>B!T:&4@=&EM97IO
M;F4@=&\@=&5S=`H@("`@("H@0')E='5R;B!B;V]L96%N('1R=64@:68@=&AI
M<R!T:6UE('IO;F4@:7,@97%U86P@=&\@=&AE('-U<'!L:65D('1I;64@>F]N
M90H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5Q=6%L*"1T>BD*("`@('L*("`@
M("`@("!I9BAS=')C87-E8VUP*"1T:&ES+3YI9"P@)'1Z+3YI9"D@/3T@,"D@
M>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@27,@=&AI<R!T:6UE('IO;F4@97%U:79A;&5N="!T;R!A
M;F]T:&5R"B`@("`@*@H@("`@("H@5&5S=',@=&\@<V5E(&EF('1H:7,@=&EM
M92!Z;VYE(&ES(&5Q=6EV86QE;G0@=&\*("`@("`J(&$@9VEV96X@=&EM92!Z
M;VYE(&]B:F5C="X@($5Q=6EV86QE;F-E(&EN('1H:7,@8V]N=&5X=`H@("`@
M("H@:7,@9&5F:6YE9"!B>2!T:&4@='=O('1I;64@>F]N97,@:&%V:6YG(&%N
M(&5Q=6%L(')A=PH@("`@("H@;V9F<V5T(&%N9"!A;B!E<75A;"!S971T:6YG
M(&]F(")H87-D<W0B+B`@5&AI<R!I<R!N;W0@=')U90H@("`@("H@97%U:79A
M;&5N8V4L(&%S('1H92!T=V\@=&EM92!Z;VYE<R!M87D@:&%V92!D:69F97)E
M;G0@<G5L97,*("`@("`J(&9O<B!T:&4@;V)S97)V86YC92!O9B!$4U0L(&)U
M="!T:&ES(&EM<&QE;65N=&%T:6]N(&1O97,@;F]T"B`@("`@*B!K;F]W($13
M5"!R=6QE<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'!A<F%M(&]B:F5C="!$871E7U1I;65:;VYE("1T>B!T:&4@=&EM97IO;F4@
M;V)J96-T('1O('1E<W0*("`@("`J($!R971U<FX@8F]O;&5A;B!T<G5E(&EF
M('1H:7,@=&EM92!Z;VYE(&ES(&5Q=6EV86QE;G0@=&\@=&AE('-U<'!L:65D
M('1I;64@>F]N90H@("`@("HO"B`@("!F=6YC=&EO;B!I<T5Q=6EV86QE;G0H
M)'1Z*0H@("`@>PH@("`@("`@(&EF*"1T:&ES+3YO9F9S970@/3T@)'1Z+3YO
M9F9S970@)B8@)'1H:7,M/FAA<V1S="`]/2`D='HM/FAA<V1S="D@>PH@("`@
M("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T<G5E(&EF('1H:7,@>F]N92!O8G-E<G9E<R!D87EL
M:6=H="!S879I;F=S('1I;64*("`@("`J"B`@("`@*B!2971U<FYS('1R=64@
M:68@=&AI<R!Z;VYE(&]B<V5R=F5S(&1A>6QI9VAT('-A=FEN9W,@=&EM90H@
M("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X@=')U92!I9B!T:&ES('1I;64@>F]N92!H87,@1%-4"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&AA<T1A>6QI9VAT5&EM92@I"B`@("!["B`@("`@("`@
M<F5T=7)N("1T:&ES+3YH87-D<W0["B`@("!]"@H@("`@+RHJ"B`@("`@*B!)
M<R!T:&4@9VEV96X@9&%T92]T:6UE(&EN($135"!F;W(@=&AI<R!T:6UE('IO
M;F4*("`@("`J"B`@("`@*B!!='1E;7!T<R!T;R!D971E<FUI;F4@:68@82!G
M:79E;B!$871E(&]B:F5C="!R97!R97-E;G1S(&$@9&%T92]T:6UE"B`@("`@
M*B!T:&%T(&ES(&EN($135"!F;W(@=&AI<R!T:6UE('IO;F4N("!705).24Y'
M4SH@=&AI<R!B87-I8V%L;'D@871T96UP=',@=&\*("`@("`J(")T<FEC:R(@
M=&AE('-Y<W1E;2!I;G1O('1E;&QI;F<@=7,@:68@=V4G<F4@:6X@1%-4(&9O
M<B!A(&=I=F5N('1I;64@>F]N92X*("`@("`J(%1H:7,@=7-E<R!P=71E;G8H
M*2!W:&EC:"!M87D@;F]T('=O<FL@:6X@<V%F92!M;V1E+"!A;F0@<F5L:65S
M(&]N('5N:7@@=&EM90H@("`@("H@=VAI8V@@:7,@;VYL>2!V86QI9"!F;W(@
M9&%T97,@9G)O;2`Q.3<P('1O('XR,#,X+B`@5&AI<R!R96QI97,@;VX@=&AE
M"B`@("`@*B!U;F1E<FQY:6YG($]3(&-A;&QS+"!S;R!I="!M87D@;F]T('=O
M<FL@;VX@5VEN9&]W<R!O<B!O;B!A('-Y<W1E;2!W:&5R90H@("`@("H@>F]N
M96EN9F\@:7,@;F]T(&EN<W1A;&QE9"!O<B!C;VYF:6=U<F5D('!R;W!E<FQY
M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<&%R86T@
M;V)J96-T($1A=&4@)&1A=&4@=&AE(&1A=&4O=&EM92!T;R!T97-T"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@=')U92!I9B!T:&ES(&1A=&4@:7,@:6X@1%-4
M(&9O<B!T:&ES('1I;64@>F]N90H@("`@("HO"B`@("!F=6YC=&EO;B!I;D1A
M>6QI9VAT5&EM92@D9&%T92D*("`@('L*("`@("`@("`D96YV7W1Z(#T@(B([
M"B`@("`@("`@:68H9V5T96YV*")46B(I*2!["B`@("`@("`@("`@("1E;G9?
M='H@/2!G971E;G8H(E1:(BD["B`@("`@("`@?0H@("`@("`@('!U=&5N=B@B
M5%H](BXD=&AI<RT^:60I.PH@("`@("`@("1L=&EM92`](&QO8V%L=&EM92@D
M9&%T92T^9V5T5&EM92@I+"!T<G5E*3L*("`@("`@("!P=71E;G8H(E1:/2(N
M)&5N=E]T>BD["B`@("`@("`@<F5T=7)N("1L=&EM95LG=&U?:7-D<W0G73L*
M("`@('T*"B`@("`O*BH*("`@("`J($=E="!T:&4@1%-4(&]F9G-E="!F;W(@
M=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!$4U0@
M;V9F<V5T(&]F('1H:7,@=&EM92!Z;VYE+"!I;B!M:6QL:7-E8V]N9',L"B`@
M("`@*B!I9B!T:&4@>F]N92!O8G-E<G9E<R!$4U0L('IE<F\@;W1H97)W:7-E
M+B`@0W5R<F5N=&QY('1H90H@("`@("H@1%-4(&]F9G-E="!I<R!H87)D+6-O
M9&5D('1O(&]N92!H;W5R+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@1%-4(&]F9G-E="P@:6X@;6EL;&ES
M96-O;F1S(&]R('IE<F\@:68@=&AE('IO;F4@9&]E<R!N;W0@;V)S97)V92!$
M4U0*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1%-44V%V:6YG<R@I"B`@("![
M"B`@("`@("`@:68H)'1H:7,M/FAA<V1S="D@>PH@("`@("`@("`@("!R971U
M<FX@,S8P,#`P,#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U
M<FX@,#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!'970@=&AE
M($135"UC;W)R96-T960@;V9F<V5T('1O(%540R!F;W(@=&AE(&=I=F5N(&1A
M=&4*("`@("`J"B`@("`@*B!!='1E;7!T<R!T;R!G970@=&AE(&]F9G-E="!T
M;R!55$,@9F]R(&$@9VEV96X@9&%T92]T:6UE+"!T86MI;F<@:6YT;PH@("`@
M("H@86-C;W5N="!D87EL:6=H="!S879I;F=S('1I;64L(&EF('1H92!T:6UE
M('IO;F4@;V)S97)V97,@:70@86YD(&EF"B`@("`@*B!I="!I<R!I;B!E9F9E
M8W0N("!0;&5A<V4@<V5E('1H92!705).24Y'4R!O;B!$871E.CI4:6UE6F]N
M93HZ:6Y$87EL:6=H=%1I;64H*2X*("`@("`J"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!P87)A;2!O8FIE8W0@1&%T92`D9&%T92!T
M:&4@1&%T92!T;R!T97-T"B`@("`@*B!`<F5T=7)N(&EN="!T:&4@8V]R<F5C
M=&5D(&]F9G-E="!T;R!55$,@:6X@;6EL;&ES96-O;F1S"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&=E=$]F9G-E="@D9&%T92D*("`@('L*("`@("`@("!I9B@D
M=&AI<RT^:6Y$87EL:6=H=%1I;64H)&1A=&4I*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^;V9F<V5T("L@)'1H:7,M/F=E=$135%-A=FEN9W,H*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]F
M9G-E=#L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!L:7-T(&]F('9A;&ED('1I;64@>F]N92!I9"!S=')I;F=S"B`@("`@
M*@H@("`@("H@4F5T=7)N<R!T:&4@;&ES="!O9B!V86QI9"!T:6UE('IO;F4@
M:60@<W1R:6YG<PH@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B!`<F5T=7)N(&UI>&5D(&%N(&%R<F%Y(&]F('-T<FEN9W,@=VET:"!T:&4@
M=F%L:60@=&EM92!Z;VYE($E$<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971!
M=F%I;&%B;&5)1',H*0H@("`@>PH@("`@("`@(&=L;V)A;"`D7T1!5$5?5$E-
M15I/3D5?1$%403L*("`@("`@("!R971U<FX@87)R87E?:V5Y<R@D7T1!5$5?
M5$E-15I/3D5?1$%402D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!I9"!F;W(@=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U
M<FYS('1H92!T:6UE('IO;F4@:60@(&9O<B!T:&ES('1I;64@>F]N92P@:2YE
M+B`B06UE<FEC82]#:&EC86=O(@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<F5T=7)N('-T<FEN9R!T:&4@:60*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T240H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^
M:60["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!L;VYG(&YA
M;64@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T
M:&4@;&]N9R!N86UE(&9O<B!T:&ES('1I;64@>F]N92P*("`@("`J(&DN92X@
M(D-E;G1R86P@4W1A;F1A<F0@5&EM92(*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B!S=')I;F<@=&AE(&QO;F<@;F%M90H@
M("`@("HO"B`@("!F=6YC=&EO;B!G971,;VYG3F%M92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YL;VYG;F%M93L*("`@('T*"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@=&AE('-H;W)T(&YA;64@9F]R('1H:7,@=&EM92!Z;VYE
M"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@<VAO<G0@;F%M92!F;W(@=&AI
M<R!T:6UE('IO;F4L(&DN92X@(D-35"(*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0')E='5R;B!S=')I;F<@=&AE('-H;W)T(&YA;64*
M("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4VAO<G1.86UE*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/G-H;W)T;F%M93L*("`@('T*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE($135"!L;VYG(&YA;64@9F]R('1H:7,@=&EM
M92!Z;VYE"B`@("`@*@H@("`@("H@4F5T=7)N<R!T:&4@1%-4(&QO;F<@;F%M
M92!F;W(@=&AI<R!T:6UE('IO;F4L(&DN92X@(D-E;G1R86P@1&%Y;&EG:'0@
M5&EM92(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E
M='5R;B!S=')I;F<@=&AE(&1A>6QI9VAT('-A=FEN9W,@=&EM92!L;VYG(&YA
M;64*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1%-43&]N9TYA;64H*0H@("`@
M>PH@("`@("`@(')E='5R;B`D=&AI<RT^9'-T;&]N9VYA;64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!$4U0@<VAO<G0@;F%M92!F;W(@
M=&AI<R!T:6UE('IO;F4*("`@("`J"B`@("`@*B!2971U<FYS('1H92!$4U0@
M<VAO<G0@;F%M92!F;W(@=&AI<R!T:6UE('IO;F4L(&DN92X@(D-$5"(*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0')E='5R;B!S=')I
M;F<@=&AE(&1A>6QI9VAT('-A=FEN9W,@=&EM92!S:&]R="!N86UE"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&=E=$135%-H;W)T3F%M92@I"B`@("!["B`@("`@
M("`@<F5T=7)N("1T:&ES+3YD<W1S:&]R=&YA;64["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!R87<@*&YO;BU$4U0M8V]R<F5C=&5D*2!O
M9F9S970@9G)O;2!55$,O1TU4(&9O<B!T:&ES('1I;64@>F]N90H@("`@("H*
M("`@("`J(%)E='5R;G,@=&AE(')A=R`H;F]N+4135"UC;W)R96-T960I(&]F
M9G-E="!F<F]M(%540R]'350@9F]R('1H:7,@=&EM92!Z;VYE"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!R971U<FX@:6YT('1H92!O
M9F9S970L(&EN(&UI;&QI<V5C;VYD<PH@("`@("HO"B`@("!F=6YC=&EO;B!G
M971287=/9F9S970H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^;V9F
M<V5T.PH@("`@?0I]"@H*+R\*+R\@5&EM92!:;VYE($1A=&$*+R\@(&]F9G-E
M="!I<R!I;B!M:6QI<V5C;VYD<PHO+PHD1TQ/0D%,4ULG7T1!5$5?5$E-15I/
M3D5?1$%402==(#T@87)R87DH"B`@("`G171C+T=-5"LQ,B<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+30S,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"TQ,CHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"TQ,CHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=%=&,O1TU4*S$Q)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3$Q.C`P)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3$Q.C`P)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TU)5"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U=E<W0@4V%M;V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+T%P:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T(%-A;6]A(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=74U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]-:61W87DG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=386UO82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G4U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O3FEU92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYI=64@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY55"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U!A9V]?4&%G;R<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U-A;6]A(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=34U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4&%C:69I8R]386UO82<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)U-A;6]A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=34U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M55,O4V%M;V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS.38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=386UO82!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O061A:R<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G2$%35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=(87=A:6DM
M06QE=71I86X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)TA!1%0G("DL"B`@("`G06UE<FEC82]!=&MA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G2&%W86EI+4%L975T:6%N(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=(05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TAA=V%I:2U!;&5U
M=&EA;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G2$%$5"<@*2P*("`@("=%=&,O1TU4*S$P)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1TU4+3$P.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3$P
M.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TA35"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U!A8VEF:6,O1F%K86]F;R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U1O:V5L874@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U1+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+TAO;F]L=6QU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&%W86EI(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]*;VAN<W1O
M;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TAA=V%I:2!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O4F%R;W1O;F=A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0V]O:R!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=086-I9FEC+U1A:&ET:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1A:&ET:2!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5$%(5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+TA35#$P)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G2&%W86EI(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=(4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G55,O06QE=71I86XG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(
M87=A:6DM06QE=71I86X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TA!4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G2&%W86EI+4%L975T:6%N($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=(0414)R`I
M+`H@("`@)U53+TAA=V%I:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TAA=V%I:2!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2%-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O36%R
M<75E<V%S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S0R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%R<75E<V%S(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=-05)4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%35"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L
M87-K82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M04M35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82]!;F-H
M;W)A9V4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA
M<VMA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=!2T14)R`I+`H@("`@)T%M97)I8V$O2G5N96%U)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G06QA<VMA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T%L87-K82!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04M$5"<@*2P*("`@("=!;65R
M:6-A+TYO;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M06QA<VMA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=!2T14)R`I+`H@("`@)T%M97)I8V$O66%K=71A="<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T%L87-K82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G04M35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G
M171C+T=-5"LY)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S(T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`Y.C`P)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`Y.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O1V%M8FEE<B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=A;6)I97(@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4WES=&5M5B]94U0Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1V%M8FEE<B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1T%-5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+UE35#E91%0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS,C0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!;&%S:V$@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QA<VMA($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!2T14)R`I
M+`H@("`@)U53+T%L87-K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%L87-K82!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04M35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=!;&%S:V$@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T%+1%0G("DL"B`@("`G06UE<FEC82]$87=S;VXG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I
M+`H@("`@)T%M97)I8V$O16YS96YA9&$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0
M86-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O3&]S
M7T%N9V5L97,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O5&EJ=6%N82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G
M06UE<FEC82]686YC;W5V97(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T%M97)I8V$O5VAI=&5H;W)S
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC
M($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=0
M1%0G("DL"B`@("`G0V%N861A+U!A8VEF:6,G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)T-A;F%D82]9
M=6MO;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I
M9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=01%0G("DL"B`@("`G171C+T=-5"LX)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4+3`X.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`X.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUE>&EC;R]"
M86IA3F]R=&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G4$14)R`I+`H@("`@)U!35"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A
M8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL"B`@("`G4%-4.%!$5"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I9FEC($1A>6QI
M9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=01%0G("DL
M"B`@("`G4&%C:69I8R]0:71C86ER;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!I
M=&-A:7)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=04U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES
M=&5M5B]04U0X)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&ET8V%I<FX@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+U!35#A01%0G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR.#@P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=086-I9FEC(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=04U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4&%C:69I8R!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4$14
M)R`I+`H@("`@)U53+U!A8VEF:6,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=086-I
M9FEC(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G4&%C:69I8R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G4$14)R`I+`H@("`@)U53+U!A8VEF:6,M3F5W
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4&%C:69I8R!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A8VEF:6,@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!$
M5"<@*2P*("`@("=!;65R:6-A+T)O:7-E)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O
M0V%M8G)I9&=E7T)A>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+T-H:6AU86AU82<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$
M5"<@*2P*("`@("=!;65R:6-A+T1A=W-O;E]#<F5E:R<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]$96YV97(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N
M=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G06UE<FEC82]%9&UO
M;G1O;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U
M;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+TAE<FUO<VEL;&\G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O26YU=FEK)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I8V$O
M36%Z871L86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=-1%0G("DL"B`@("`G06UE<FEC82]0:&]E;FEX)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+U-H:7!R;V-K)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414)R`I+`H@("`@)T%M97)I
M8V$O665L;&]W:VYI9F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=-1%0G("DL"B`@("`G0V%N861A+TUO=6YT86EN)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-;W5N=&%I;B!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3414
M)R`I+`H@("`@)T5T8R]'350K-R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP
M-SHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP-SHP,"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=-4U0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR-3(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO=6YT86EN($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=-1%0G("DL"B`@
M("`G35-4-TU$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)TU$5"<@*2P*("`@("=-97AI8V\O0F%J85-U<B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U;G1A:6X@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU$5"<@*2P*
M("`@("=.879A:F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=-1%0G("DL"B`@("`G4$Y4)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=3>7-T96U6+TU35#<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O35-4
M-TU$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(U,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G36]U
M;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)TU$5"<@*2P*("`@("=54R]!<FEZ;VYA)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36]U;G1A:6X@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TU35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=54R]-;W5N=&%I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO=6YT86EN(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=-4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G36]U;G1A:6X@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)TU$5"<@*2P*("`@("=!;65R:6-A+T)E;&EZ92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+T-A;F-U;B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G06UE<FEC
M82]#:&EC86=O)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-$5"<@*2P*("`@("=!;65R:6-A+T-O<W1A7U)I8V$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]%;%]386QV861O<B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+T=U871E;6%L82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R
M:6-A+TUA;F%G=6$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-96YO;6EN
M964G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0T14)R`I+`H@("`@)T%M97)I8V$O365R:61A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=!;65R:6-A
M+TUE>&EC;U]#:71Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O36]N=&5R
M<F5Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-$5"<@*2P*("`@("=!;65R:6-A+TYO<G1H7T1A:V]T82]#96YT97(G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I
M+`H@("`@)T%M97)I8V$O4F%I;GE?4FEV97(G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T%M97)I8V$O
M4F%N:VEN7TEN;&5T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+U)E9VEN82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!;65R:6-A+U-W:69T7T-U<G)E;G0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G06UE<FEC82]496=U8VEG86QP82<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T-E;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+U=I;FYI<&5G)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=#4U0G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T14)R`I+`H@("`@)T-35#9#
M1%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0T14)R`I+`H@("`@)T-A;F%D82]#96YT<F%L)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=#86YA9&$O
M16%S="U387-K871C:&5W86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V%N861A+U-A
M<VMA=&-H97=A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(Q
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#:&EL92]%87-T97))<VQA
M;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97(@27,N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%05-3
M5"<@*2P*("`@("=%=&,O1TU4*S8G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M
M,#8Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#8Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G365X:6-O+T=E;F5R
M86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]%87-T97(G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=%87-T97(@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%05-35"<@*2P*("`@("=0
M86-I9FEC+T=A;&%P86=O<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=A;&%P86=O
M<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1T%,5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3>7-T96U6+T-35#8G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4WES=&5M5B]#4U0V0T14)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@1&%Y;&EG:'0@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-$5"<@*2P*("`@("=54R]#
M96YT<F%L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-$5"<@*2P*("`@("=!;65R:6-A+T)O9V]T82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-O;&]M8FEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=#3U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE
M<FEC82]#87EM86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]$971R;VET
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=!;65R:6-A+T5I<G5N97!E)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1F]R
M=%]787EN92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T=R86YD7U1U<FLG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414
M)R`I+`H@("`@)T%M97)I8V$O1W5A>6%Q=6EL)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16-U861O<B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O
M2&%V86YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-$5"<@*2P*("`@("=!;65R:6-A+TEN9&EA;F$O26YD:6%N87!O;&ES
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O26YD:6%N82]+;F]X)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%M97)I8V$O26YD:6%N82]-87)E;F=O)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%M97)I8V$O26YD:6%N82]6979A>2<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+TEN9&EA;F%P;VQI<R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+TEQ86QU:70G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O2F%M86EC82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+TME;G1U8VMY+TQO=6ES=FEL;&4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I
M+`H@("`@)T%M97)I8V$O2V5N='5C:WDO36]N=&EC96QL;R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@("`G
M06UE<FEC82]+;F]X7TE.)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O3&EM
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U!E<G4@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U!%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+TQO=6ES=FEL;&4G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O
M36]N=')E86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O3F%S<V%U)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!
M;65R:6-A+TYE=U]9;W)K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+TYI<&EG;VXG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!$87EL
M:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1414)R`I
M+`H@("`@)T%M97)I8V$O4&%N86UA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O4&%N9VYI<G1U;F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G16%S=&5R;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G1414)R`I+`H@("`@)T%M97)I8V$O4&]R="UA=2U0<FEN
M8V4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]0;W)T;U]!8W)E)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G04-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%M97)I8V$O4FEO7T)R86YC;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%C<F4@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U1H=6YD97)?0F%Y
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("="<F%Z:6PO06-R92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%C
M<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%#5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#86YA9&$O16%S=&5R;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A
M>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G
M("DL"B`@("`G0W5B82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#1%0G("DL"B`@("`G15-4)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=%4U0U1414
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5$
M5"<@*2P*("`@("=%=&,O1TU4*S4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M
M,#4Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#4Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2454)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TIA;6%I8V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4WES=&5M5B]%
M4U0U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O15-4-45$5"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%1%0G("DL"B`@
M("`G55,O16%S="U);F1I86YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U53+T5A<W1E
M<FXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R
M;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M1414)R`I+`H@("`@)U53+TEN9&EA;F$M4W1A<FME)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U53+TUI8VAI9V%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T5$5"<@*2P*("`@("=!;65R:6-A+T%N9W5I;&QA)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T%N=&EG=6$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%M97)I8V$O07)U8F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA
M;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O07-U;F-I;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=087)A9W5A>2!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%E4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!A<F%G
M=6%Y(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M4%E35"<@*2P*("`@("=!;65R:6-A+T)A<F)A9&]S)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!;65R:6-A+T)O85]6:7-T82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%M
M87IO;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O0V%R86-A<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U9E;F5Z=65L82!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5D54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O0W5I86)A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06UA>F]N(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@*2P*("`@("=!
M;65R:6-A+T-U<F%C86\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1&]M
M:6YI8V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O1VQA8V5?0F%Y)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!=&QA;G1I8R!$
M87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414
M)R`I+`H@("`@)T%M97)I8V$O1V]O<V5?0F%Y)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("=!=&QA;G1I8R!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@("`@)T%M97)I
M8V$O1W)E;F%D82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]'=6%D96QO
M=7!E)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T=U>6%N82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=U>6%N82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1UE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%M97)I8V$O2&%L:69A>"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G071L86YT:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T%$5"<@*2P*("`@("=!;65R:6-A+TQA7U!A>B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T)O;&EV:6$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T)/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+TUA;F%U<R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%M
M87IO;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I
M8V$O36%R=&EN:7%U92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]-;VYT
M<V5R<F%T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U!O<G1?;V9?4W!A
M:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4&]R=&]?5F5L:&\G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!;65R:6-A+U!U97)T;U]2:6-O)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+U-A;G1I86=O)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0VAI;&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-,5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=#:&EL92!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-,4U0G("DL"B`@("`G06UE<FEC82]386YT;U]$;VUI;F=O)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U-T7TMI='1S)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!;65R:6-A+U-T7TQU8VEA)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M;65R:6-A+U-T7U1H;VUA<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]3
M=%]6:6YC96YT)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U1H=6QE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U1O<G1O;&$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%M97)I8V$O5FER9VEN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G071L
M86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A
M<F-T:6-A+U!A;&UE<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6QE(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#3%0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0VAI;&4@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#3%-4
M)R`I+`H@("`@)T%T;&%N=&EC+T)E<FUU9&$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI9VAT(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@("`G071L86YT
M:6,O4W1A;FQE>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9A;&ML86YD($ES+B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1DM4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T9A
M;&ML86YD($ES+B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T9+4U0G("DL"B`@("`G0G)A>FEL+U=E<W0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!;6%Z;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=#86YA9&$O071L86YT:6,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA
M;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@("`G0VAI;&4O0V]N=&EN
M96YT86PG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&EL92!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0TQ4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-H:6QE(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0TQ35"<@*2P*("`@
M("=%=&,O1TU4*S0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#0Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#0Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4%)4)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G071L86YT:6,@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=3>7-T96U6+T%35#0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!=&QA;G1I8R!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U-Y<W1E;58O05-4
M-$%$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%T;&%N=&EC(%-T86YD87)D(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G071L
M86YT:6,@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T%$5"<@*2P*("`@("=!;65R:6-A+U-T7TIO:&YS)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,3(V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G3F5W9F]U;F1L86YD(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=.4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3F5W9F]U;F1L86YD($1A
M>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=.1%0G
M("DL"B`@("`G0TY4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M
M,3(V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W9F]U;F1L86YD
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G3F5W9F]U;F1L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=.1%0G("DL"B`@("`G0V%N861A+TYE=V9O
M=6YD;&%N9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$R-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=V9O=6YD;&%N9"!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3E-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TYE=V9O=6YD;&%N9"!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G3D14)R`I+`H@("`@)T%'5"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M
M97)I8V$O07)A9W5A:6YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)A
M>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M0E)35"<@*2P*("`@("=!;65R:6-A+T)E;&5M)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0G)A>FEL(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]"
M=65N;W-?06ER97,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F=E;G1I;F4@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T-A=&%M87)C82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%M97)I8V$O0V%Y96YN92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9R
M96YC:"!'=6EA;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=&
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A
M+T-O<F1O8F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F=E;G1I;F4@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+T9O<G1A;&5Z82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T)R87II;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T)R87II;"!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T)24U0G("DL"B`@("`G06UE<FEC82]'
M;V1T:&%B)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!'<F5E;FQA;F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U='5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=7
M97-T97)N($=R965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U='4U0G("DL"B`@("`G06UE<FEC82]*=6IU>2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%M97)I8V$O36%C96EO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0G)A
M>FEL(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="4E0G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0E)35"<@*2P*("`@("=!;65R:6-A+TUE;F1O>F$G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=!<F=E;G1I;F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T%25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;65R:6-A+TUI<75E;&]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&EE<G)E
M("8@36EQ=65L;VX@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U!-4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G4&EE<G)E("8@36EQ=65L;VX@1&%Y;&EG
M:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!-1%0G("DL
M"B`@("`G06UE<FEC82]-;VYT979I9&5O)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M57)U9W5A>2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G55E4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%M97)I8V$O4&%R
M86UA<FEB;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-U<FEN86UE(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=34E0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82]296-I9F4G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T%M97)I8V$O4F]S87)I
M;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T%R9V5N=&EN92!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%M97)I8V$O4V%O7U!A=6QO)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0G)A>FEL(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="
M4E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G0G)A>FEL(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*("`@("="150G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T)R87II;"]%87-T)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G0G)A>FEL(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("="4E0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)A>FEL(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E)35"<@*2P*("`@("=%=&,O
M1TU4*S,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06UE<FEC82].;W)O;FAA)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=&97)N86YD;R!D92!.;W)O;FAA(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=&3E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G071L86YT:6,O4V]U=&A?1V5O<F=I82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@+3<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G4V]U=&@@1V5O<F=I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T)R87II;"]$94YO<F]N:&$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TW,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T9E<FYA;F1O(&1E($YO<F]N:&$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T9.5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=%=&,O1TU4*S(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TW
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TP,CHP,"<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"TP,CHP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;65R:6-A+U-C;W)E<V)Y<W5N9"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!'<F5E;FQA;F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T5'5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($=R
M965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T5'4U0G("DL"B`@("`G071L86YT:6,O07IO<F5S)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=!>F]R97,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T%:3U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G07IO<F5S(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G05I/4U0G("DL"B`@("`G071L86YT:6,O0V%P
M95]697)D92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V%P92!697)D92!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U94)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350K,2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1TU4+3`Q.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`Q
M.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC
M82]!8FED:F%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T%C8W)A)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R
M965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A
M+T)A;6%K;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%F<FEC82]"86YJ=6PG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E
M96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M0FES<V%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G069R:6-A+T-A<V%B;&%N8V$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M5V5S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F
M<FEC82]#;VYA:W)Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T1A:V%R)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R
M:6-A+T5L7T%A:75N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O1G)E971O=VXG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!9G)I8V$O3&]M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]-;VYR;W9I82<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82].;W5A:V-H;W1T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+T]U86=A9&]U9V]U
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+U-A;U]4;VUE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC
M:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+U1I;6)U
M:W1U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G06UE<FEC82]$86YM87)K<VAA=FXG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!=&QA
M;G1I8R]#86YA<GDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U=E<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=715-4)R`I+`H@("`@)T%T;&%N=&EC+T9A97)O92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=797-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=7150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@
M("`G071L86YT:6,O36%D96ER82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G071L86YT:6,O4F5Y:VIA
M=FEK)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G071L86YT:6,O4W1?2&5L96YA)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R
M965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G16ER92<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TER:7-H(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G25-4)R`I+`H@("`@)T5T8R]'
M350G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`P.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T5T8R]'350K,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#`Z,#`G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"TP)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-
M5"LP,#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP,#HP,"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O1TU4,"<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("='350K,#`Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G171C+T=R965N=VEC:"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]50U0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G171C+U540R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV97)S86P@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=&,O56YI=F5R<V%L)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-O;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T5T8R]:=6QU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;W)D:6YA=&5D(%5N
M:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G551#)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]"96QF
M87-T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0G)I=&ES:"!3=6UM97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T)35"<@*2P*("`@
M("=%=7)O<&4O1'5B;&EN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=R965N=VEC:"!-96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G27)I
M<V@@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=)
M4U0G("DL"B`@("`G175R;W!E+TQI<V)O;B<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G175R;W!E+TQO
M;F1O;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T)R:71I<V@@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4U0G("DL"B`@
M("`G1T(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("="<FET:7-H(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E-4)R`I+`H@
M("`@)T="+45I<F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("="<FET:7-H
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0E-4
M)R`I+`H@("`@)T=-5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5#`G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`P
M.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`P.C`P)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=R965N=VEC:"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='<F5E;G=I8V@@365A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1TU4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)TEC96QA;F0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1W)E96YW:6-H($UE86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=0;W)T=6=A;"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T
M97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U=%4U0G("DL"B`@("`G54-4)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-O;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U540R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#;V]R9&EN871E9"!5;FEV
M97)S86P@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U540R<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=5;FEV97)S86PG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G5T54)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=7
M97-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G5T535"<@*2P*("`@("=:=6QU)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O
M;W)D:6YA=&5D(%5N:79E<G-A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G551#)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%F<FEC82]!;&=I97)S)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0F%N9W5I
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%F<FEC82]"<F%Z>F%V:6QL92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O0V5U=&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%
M=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T%F<FEC82]$;W5A
M;&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TMI;G-H87-A)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82],86=O<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F
M<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3&EB<F5V
M:6QL92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3'5A;F1A)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%F<FEC82]-86QA8F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!!
M9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TYD:F%M
M96YA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@069R:6-A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82].:6%M97DG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G069R:6-A+U!O<G1O+4YO=F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R
M;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=7050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+U1U
M;FES)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O5VEN9&AO96LG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=7050G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G5V5S=&5R;B!!9G)I8V%N(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5T%35"<@*2P*
M("`@("=!<F-T:6,O3&]N9WEE87)B>65N)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=!=&QA
M;G1I8R]*86Y?36%Y96XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!'<F5E
M;FQA;F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5'5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($=R965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T5'4U0G("DL"B`@("`G0T54)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@
M*2P*("`@("=#15-4)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@(D-E;G1R86P@175R;W!E
M86X@5&EM92(L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M(")#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE(BP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%0U0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@
M("`@)T5T8R]'350M,2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#$Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#$Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G175R;W!E+T%M<W1E<F1A;2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%
M4U0G("DL"B`@("`G175R;W!E+T%N9&]R<F$G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U
M<F]P92]"96QG<F%D92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+T)E<FQI;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O
M<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T-%4U0G("DL"B`@("`G175R;W!E+T)R871I<VQA=F$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@
M("`@)T5U<F]P92]"<G5S<V5L<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+T)U
M9&%P97-T)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT
M<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O0V]P96YH86=E;B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%
M4U0G("DL"B`@("`G175R;W!E+T=I8G)A;'1A<B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G
M175R;W!E+TQJ=6)L:F%N82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TQU>&5M
M8F]U<F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]-861R:60G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I
M+`H@("`@)T5U<F]P92]-86QT82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@
M("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+TUO
M;F%C;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A
M;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+T]S;&\G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@
M("`@)T5U<F]P92]087)I<R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U!R86=U
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%
M=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T-%4U0G("DL"B`@("`G175R;W!E+U)O;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@
M)T5U<F]P92]386Y?36%R:6YO)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=%=7)O<&4O4V%R
M86IE=F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R
M86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]3:V]P:F4G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I
M+`H@("`@)T5U<F]P92]3=&]C:VAO;&TG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]4:7)A;F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]6861U>B<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=#96YT<F%L($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!3
M=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-%4U0G
M("DL"B`@("`G175R;W!E+U9A=&EC86XG(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]6:65N;F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P92]787)S87<G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4
M)R`I+`H@("`@)T5U<F]P92]:86=R96(G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0T54)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#15-4)R`I+`H@("`@)T5U<F]P
M92]:=7)I8V@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!%=7)O<&5A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T54)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E
M;G1R86P@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=#15-4)R`I+`H@("`@)TU%5"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=-:61D;&4@175R;W!E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G36ED9&QE($5U<F]P92!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TU%4U0G("DL"B`@("`G4&]L86YD
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@175R;W!E86X@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L($5U
M<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G0T535"<@*2P*("`@("=!4E0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R
M;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T%F<FEC82]"
M;&%N='ER92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O0G5J=6UB=7)A)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%F<FEC82]#86ER;R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G069R:6-A
M+T=A8F]R;VYE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G
M:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82](87)A<F4G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0V5N=')A;"!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G069R:6-A+TIO:&%N;F5S8G5R9R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=3;W5T:"!!9G)I8V$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)U-!4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G069R:6-A+TMI9V%L:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L
M($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3'5B
M=6UB87-H:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L($%F<FEC86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O3'5S86MA)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%F<FEC82]-87!U=&\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A
M;"!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#050G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUA
M<V5R=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=3;W5T:"!!9G)I8V$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U-!4U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TUB86)A;F4G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4V]U=&@@069R:6-A(%-T86YD87)D(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=305-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%F<FEC82]4<FEP;VQI)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!<VEA+T%M;6%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=!<VEA+T)E:7)U="<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@
M)T5%4U0G("DL"B`@("`G07-I82]$86UA<V-U<R<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G
M07-I82]'87IA)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%
M87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G14535"<@*2P*("`@("=!<VEA+TES=&%N8G5L)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1453
M5"<@*2P*("`@("=!<VEA+TIE<G5S86QE;2<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=)
M<W)A96P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TE35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=)<W)A96P@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)TE$5"<@*2P*("`@("=!<VEA+TYI8V]S:6$G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R
M;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=%15-4)R`I+`H@("`@)T%S:6$O5&5L7T%V:78G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G27-R865L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=)4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G27-R865L($1A>6QI9VAT(%1I;64G+`H@("`@
M("`@("=D<W1S:&]R=&YA;64G(#T^("=)1%0G("DL"B`@("`G0T%4)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T5%5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P
M96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@
M("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]
M/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G16=Y<'0G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M
M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I
M+`H@("`@)T5T8R]'350M,B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#(Z,#`G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#(Z,#`G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G175R;W!E+T%T:&5N<R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A
M;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%
M4U0G("DL"B`@("`G175R;W!E+T)U8VAA<F5S="<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G
M175R;W!E+T-H:7-I;F%U)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R
M;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O<&4O2&5L<VEN
M:VDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92])<W1A;F)U;"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM
M97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL
M"B`@("`G175R;W!E+TMA;&EN:6YG<F%D)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A
M<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@*2P*("`@("=%=7)O
M<&4O2VEE=B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S
M=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T
M;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E+TUI;G-K)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14535"<@
M*2P*("`@("=%=7)O<&4O3FEC;W-I82<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@
M("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G175R;W!E
M+U)I9V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P92]3:6UF97)O<&]L)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N($5U<F]P96%N
M(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1453
M5"<@*2P*("`@("=%=7)O<&4O4V]F:6$G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S
M=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%15-4)R`I+`H@("`@)T5U<F]P
M92]486QL:6YN)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O5&ER87-P;VPG(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E
M86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M15-4)R`I+`H@("`@)T5U<F]P92]5>FAG;W)O9"<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N($5U<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%150G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G
M175R;W!E+U9I;&YI=7,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]:87!O<F]Z
M:'EE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@175R;W!E86X@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5%5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N
M($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G14535"<@*2P*("`@("=)<W)A96PG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M27-R865L(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=)4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S
M=&QO;F=N86UE)R`]/B`G27-R865L($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=)1%0G("DL"B`@("`G3&EB>6$G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U1U<FME>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@-S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($5U
M<F]P96%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%150G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!3=6UM97(@5&EM92<L"B`@("`@("`@
M)V1S='-H;W)T;F%M92<@/3X@)T5%4U0G("DL"B`@("`G069R:6-A+T%D9&ES
M7T%B86)A)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O07-M97)A)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!9G)I8V$O1&%R7V5S7U-A;&%A;2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%050G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M069R:6-A+T1J:6)O=71I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N($%F
M<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O2V%M<&%L
M82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G069R:6-A+TMH87)T;W5M)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=!9G)I8V$O36]G861I<VAU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T
M97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5!
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!9G)I8V$O
M3F%I<F]B:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!!9G)I8V%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%050G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]3>6]W82<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4WEO=V$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U-93U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]!9&5N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F%B:6$@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T)A9VAD860G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%R86)I82!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G0414)R`I+`H@
M("`@)T%S:6$O0F%H<F%I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T
M86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]+=7=A:70G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T%S:6$O46%T87(G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%R86)I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S
M:6$O4FEY861H)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<F%B:6$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%050G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T5T8R]'350M,R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`P)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`P)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T5U<F]P92]-;W-C;W<G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TUO<V-O=R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G35-+)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TUO<V-O=R!$87EL:6=H="!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G35-$)R`I+`H@("`@)TEN
M9&EA;B]!;G1A;F%N87)I=F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M069R:6-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TEN9&EA;B]#;VUO
M<F\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$P.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@069R:6-A;B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G14%4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)TEN9&EA;B]-87EO='1E)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=7+5-5)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W-C;W<@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU32R<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-
M;W-C;W<@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)TU31"<@*2P*("`@("=!<VEA+U)I>6%D:#@W)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350K,#,Z,#<G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K
M,#,Z,#<G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I
M82]2:7EA9&@X."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R
M,C0P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4FEY861H.#DG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"LP,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=-:61E87-T+U)I>6%D:#@W)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`Q,3(R-#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#,Z
M,#<G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#,Z,#<G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36ED96%S="]2:7EA9&@X
M."<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)TUI9&5A<W0O4FEY861H.#DG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#$Q,C(T,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=-5"LP,SHP-R<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP
M,SHP-R<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+U1E:')A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3(V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27)A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G25)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T
M<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TER86X@4W5M97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE24U0G("DL"B`@("`G
M27)A;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3(V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27)A;B!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G25)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TER86X@4W5M97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE24U0G("DL"B`@("`G07-I
M82]!<71A=2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07%T874@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T874@4W5M;65R
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!45135"<@*2P*
M("`@("=!<VEA+T)A:W4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%Z97)B86EJ86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%:5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!
M>F5R8F%I:F%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G05I35"<@*2P*("`@("=!<VEA+T1U8F%I)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='=6QF(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]-=7-C870G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=U;&8@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+U1B:6QI<VDG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=E;W)G:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@
M("`G9'-T;&]N9VYA;64G(#T^("='96]R9VEA(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G1T535"<@*2P*("`@("=!<VEA+UEE
M<F5V86XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%R;65N:6$@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!<FUE;FEA(%-U;6UE
M<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@*2P*
M("`@("=%=&,O1TU4+30G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-#HP,"<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%=7)O<&4O4V%M87)A)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=386UA<F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U-!350G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G4V%M87)A(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G4T%-4U0G("DL"B`@("`G26YD:6%N
M+TUA:&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-E>6-H96QL97,@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U-#5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=);F1I86XO36%U<FET:75S)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=-875R:71I=7,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TU55"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=)
M;F1I86XO4F5U;FEO;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4F5U;FEO;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4D54)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)TY%5"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M07)M96YI82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G04U4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T%R;65N:6$@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=!35-4)R`I+`H@("`@)T%S:6$O2V%B=6PG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#$V,C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T%F9VAA;FES=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=!1E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]!<71O8F4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%Q=&]B92!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G05%45"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!<71O
M8F4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!
M45135"<@*2P*("`@("=!<VEA+T%S:&=A8F%T)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=4=7)K;65N:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U1-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+T%S:&MH86)A9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5'5R:VUE;FES=&%N(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4350G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]":7-H:V5K)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=+:7)G:7IS=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=+1U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G2VER9VEZ<W1A;B!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TM'4U0G("DL"B`@("`G07-I
M82]$=7-H86YB92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5&%J:6MI<W1A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5$I4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O2V%R86-H:2<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G4&%K:7-T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)U!+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+U-A;6%R:V%N9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5'5R:VUE;FES=&%N
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4350G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]487-H:V5N="<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G57IB96MI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G55I4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O665K871E<FEN8G5R9R<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M665K871E<FEN8G5R9R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M645+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=996MA=&5R:6YB=7)G(%-U;6UE<B!4:6UE)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G645+4U0G("DL"B`@("`G171C+T=-
M5"TU)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#4Z,#`G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("='350K,#4Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G26YD:6%N+TME<F=U96QE;B<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1G)E;F-H(%-O=71H97)N("8@06YT87)C=&EC($QA;F1S(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=41E0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G26YD:6%N+TUA;&1I=F5S)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=-86QD:79E<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G3594)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U!,5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&%K:7-T86X@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U!+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+T-A;&-U='1A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q.3@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=);F1I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G25-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TE3
M5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3DX,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G26YD:6$@4W1A;F1A<F0@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TE35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!<VEA+TMA=&UA;F1U)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R,#<P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=.97!A;"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3E!4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%N=&%R8W1I
M8V$O36%W<V]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-87=S;VX@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU!5U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]6;W-T;VLG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)U9O<W1O:R!T:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5D]35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+T%L;6%T>2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G06QM82U!=&$@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%,350G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G06QM82U!
M=&$@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!
M3$U35"<@*2P*("`@("=!<VEA+T-O;&]M8F\G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U-R:2!,86YK82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3$M4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O1&%C
M8V$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T)A;F=L861E<V@@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T)$5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+T1H86MA)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("="
M86YG;&%D97-H(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("="1%0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82].;W9O
M<VEB:7)S:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F]V;W-I8FER<VL@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY/5E0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G3F]V;W-I
M8FER<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=.3U935"<@*2P*("`@("=!<VEA+T]M<VLG(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T]M<VL@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T]-4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G3VUS:R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T]-4U-4)R`I+`H@("`@)T%S:6$O5&AI;6)U)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=":'5T86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T)45"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+U1H:6UP:'4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)H=71A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G0E14)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T)$5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0F%N9VQA
M9&5S:"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0D14)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5T8R]'350M-B<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S`V.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S`V.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TEN9&EA;B]#:&%G;W,G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TEN9&EA
M;B!/8V5A;B!497)R:71O<GD@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)TE/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M<VEA+U)A;F=O;VXG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(S
M-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUY86YM87(@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU-5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=);F1I86XO0V]C;W,G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(S-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-O8V]S($ES;&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T-#5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=!;G1A<F-T:6-A+T1A=FES)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=$879I<R!4
M:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1$%65"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T)A;F=K;VLG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TEN9&]C:&EN82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G24-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T%S:6$O2&]V9"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&]V9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G2$]65"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TIA:V%R=&$G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U=E<W0@26YD;VYE<VEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=7250G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G07-I82]+<F%S;F]Y87)S:R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2W)A<VYO
M>6%R<VL@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM2050G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G2W)A<VYO>6%R<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=+4D%35"<@*2P*("`@("=!<VEA+U!H;F]M7U!E;F@G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)TEN9&]C:&EN82!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G24-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O4&]N=&EA;F%K)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=7
M97-T($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5TE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O
M4V%I9V]N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1O8VAI;F$@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TE#5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=!<VEA+U9I96YT:6%N92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G26YD;V-H:6YA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=)0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G171C
M+T=-5"TW)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#<Z,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,#<Z,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G26YD:6%N+T-H<FES=&UA<R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G0VAR:7-T;6%S($ES;&%N9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0UA4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U935"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G26YD;V-H:6YA(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)0U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G06YT87)C=&EC82]#87-E>2<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G5V5S=&5R;B!3=&%N9&%R9"!4:6UE("A!=7-T<F%L:6$I
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5U-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O0G)U;F5I)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("="<G5N96D@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T).5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA
M+T-H;VYG<6EN9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T-H=6YG:VEN9R<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=!<VEA+TAA<F)I;B<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI
M;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+TAO
M;F=?2V]N9R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2&]N9R!+;VYG(%1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=(2U0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G07-I82])<FMU='-K)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=)<FMU='-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)
M4DM4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)TER:W5T<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=)4DM35"<@*2P*("`@("=!<VEA+TMA<VAG87(G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07-I82]+=6%L85],=6UP=7(G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TUA;&%Y<VEA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=-650G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I
M82]+=6-H:6YG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-86QA>7-I82!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G35E4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%S:6$O36%C86\G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M07-I82]-86YI;&$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X
M.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!H:6QI<'!I;F5S(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=02%0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]3:&%N9VAA:2<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G0VAI;F$@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!<VEA+U-I;F=A<&]R92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4VEN
M9V%P;W)E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=31U0G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]486EP96DG
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G07-I82]5:G5N9U]086YD86YG)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=#96YT<F%L($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G0TE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T%S:6$O56QA86YB86%T87(G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5L
M86%N8F%A=&%R(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=53$%4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O56QA
M;E]"871O<B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G56QA86YB86%T87(@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U5,050G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]5<G5M<6DG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G075S=')A;&EA+U!E<G1H)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N
M(%-T86YD87)D(%1I;64@*$%U<W1R86QI82DG+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=74U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G075S=')A;&EA+U=E<W0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U=E<W1E<FX@
M4W1A;F1A<F0@5&EM92`H075S=')A;&EA*2<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U=35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=#5%0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G171C+T=-5"TX)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350K,#@Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K
M,#@Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2&]N
M9VMO;F<G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TAO;F<@2V]N9R!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G2$M4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U!20R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;F$@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=3:6YG87!O<F4G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)U-I;F=A<&]R92!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G4T=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%S:6$O0VAO:6)A;'-A;B<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M0VAO:6)A;'-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TA/
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+T1I
M;&DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W0@5&EM;W(@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U105"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!<VEA+TIA>6%P=7)A)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G14E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S
M:6$O4'EO;F=Y86YG)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=+;W)E82!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2U-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%S:6$O4V5O=6PG(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)TMO<F5A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=+4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G07-I82]4;VMY;R<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2F%P86X@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TI35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<VEA+UEA:W5T
M<VLG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)UEA:W5T<VL@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)UE!2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R
M=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G66%K='-K(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G64%+4U0G("DL"B`@
M("`G171C+T=-5"TY)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#DZ,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2E-4)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=*87!A;B!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G2E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TIA
M<&%N)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=*87!A;B!3=&%N9&%R9"!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G2E-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O4&%L874G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)U!A;&%U(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0
M5U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4D]+)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=+;W)E82!3=&%N9&%R9"!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G2U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%#5"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V5N=')A;"!3
M=&%N9&%R9"!4:6UE("A.;W)T:&5R;B!497)R:71O<GDI)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)T%U<W1R86QI82]!9&5L86ED92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S0R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V5N=')A;"!3=&%N9&%R9"!4:6UE("A3;W5T:"!!=7-T<F%L:6$I)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@
M4W5M;65R(%1I;64@*%-O=71H($%U<W1R86QI82DG+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=#4U0G("DL"B`@("`G075S=')A;&EA+T)R;VME;E](
M:6QL)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@
M*%-O=71H($%U<W1R86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@4W5M;65R(%1I
M;64@*%-O=71H($%U<W1R86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0U-4)R`I+`H@("`@)T%U<W1R86QI82]$
M87)W:6XG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,T,C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM
M92`H3F]R=&AE<FX@5&5R<FET;W)Y*2<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M=7-T<F%L:6$O3F]R=&@G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@4W1A
M;F1A<F0@5&EM92`H3F]R=&AE<FX@5&5R<FET;W)Y*2<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=!=7-T<F%L:6$O4V]U=&@G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W1A;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE
M<B!4:6UE("A3;W5T:"!!=7-T<F%L:6$I)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G0U-4)R`I+`H@("`@)T%U<W1R86QI82]986YC;W=I;FYA)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-#(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=#96YT<F%L(%-T86YD87)D(%1I;64@*%-O=71H
M($%U<W1R86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G0U-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T-E;G1R86P@4W5M;65R(%1I;64@*%-O
M=71H($%U<W1R86QI82].97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G0U-4)R`I+`H@("`@)T%%5"<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U=&@@5V%L97,I
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@4W5M;65R(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=%4U0G("DL"B`@("`G06YT87)C=&EC82]$=6UO
M;G1$57)V:6QL92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1'5M;VYT+61<)U5R=FEL
M;&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T1$550G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G07-I82]386MH86QI;B<@
M/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@
M("`@)VQO;F=N86UE)R`]/B`G4V%K:&%L:6X@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)U-!2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L
M"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G4V%K:&%L:6X@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=304M35"<@*2P*("`@
M("=!<VEA+U9L861I=F]S=&]K)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=6;&%D:79O
M<W1O:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5DQ!5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=6;&%D:79O<W1O:R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U9,05-4)R`I+`H@("`@)T%U<W1R86QI82]!0U0G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O
M=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R
M86QI82]"<FES8F%N92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N
M9&%R9"!4:6UE("A1=65E;G-L86YD*2<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!
M=7-T<F%L:6$O0V%N8F5R<F$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@
M4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE
M("A.97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82](;V)A<G0G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H5&%S;6%N:6$I)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W5M
M;65R(%1I;64@*%1A<VUA;FEA*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@
M/3X@)T535"<@*2P*("`@("=!=7-T<F%L:6$O3&EN9&5M86XG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H475E96YS;&%N9"DG
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G075S=')A;&EA+TUE;&)O=7)N92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A6:6-T;W)I
M82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H
M87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S
M=&5R;B!3=6UM97(@5&EM92`H5FEC=&]R:6$I)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82].4U<G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A;F1A<F0@5&EM92`H3F5W(%-O=71H
M(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=%87-T97)N(%-U;6UE<B!4:6UE("A.97<@4V]U=&@@5V%L97,I)RP*("`@
M("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T%U<W1R86QI
M82]1=65E;G-L86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S
M-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD
M87)D(%1I;64@*%%U965N<VQA;F0I)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G15-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%U
M<W1R86QI82]3>61N97DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W1E<FX@4W1A
M;F1A<F0@5&EM92`H3F5W(%-O=71H(%=A;&5S*2<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4:6UE("A.
M97<@4V]U=&@@5V%L97,I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M15-4)R`I+`H@("`@)T%U<W1R86QI82]487-M86YI82<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A487-M86YI82DG+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^
M('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM
M97(@5&EM92`H5&%S;6%N:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]
M/B`G15-4)R`I+`H@("`@)T%U<W1R86QI82]6:6-T;W)I82<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A6:6-T;W)I82DG+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3
M=6UM97(@5&EM92`H5FEC=&]R:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G15-4)R`I+`H@("`@)T5T8R]'350M,3`G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T=-5"LQ,#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ
M,#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I
M9FEC+T=U86TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H86UO<G)O(%-T86YD87)D
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#:%-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O4&]R=%]-;W)E
M<V)Y)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=087!U82!.97<@1W5I;F5A(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=01U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]386EP86XG(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T-H86UO<G)O(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S
M:&]R=&YA;64G(#T^("=#:%-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)U!A8VEF:6,O5')U:R<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5')U
M:R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5%)55"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+UEA<"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G66%P(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=905!4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T%U<W1R86QI82],2$DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#,W.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TQO860@2&]W92!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3$A35"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=,;V%D($AO=V4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=,2%-4)R`I+`H@("`@)T%U<W1R86QI82],;W)D7TAO
M=V4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,W.#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TQO860@2&]W92!3=&%N9&%R9"!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G3$A35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=,;V%D
M($AO=V4@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=,2%-4)R`I+`H@("`@)T%S:6$O36%G861A;B<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36%G861A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%'
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=-86=A9&%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G34%'4U0G("DL"B`@("`G171C+T=-5"TQ,2<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S$Q.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S$Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)U!A8VEF:6,O169A=&4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U9A;G5A
M='4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U955"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+T=U861A;&-A
M;F%L)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=3;VQO;6]N($ES+B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G4T)4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U!A8VEF:6,O2V]S<F%E)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=+;W-R864@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TM/
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I
M8R].;W5M96$G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,Y-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=R!#86QE9&]N:6$@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY#5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U!O;F%P92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4&]N87!E(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=03TY4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)U-35"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4V]L;VUO;B!)<RX@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)U-"5"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=086-I9FEC+TYO<F9O;&LG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#0Q-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TYO<F9O;&L@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TY&5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!;G1A
M<F-T:6-A+TUC375R9&\G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD
M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)TYE=R!:96%L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=.6D14)R`I+`H@("`@)T%N=&%R8W1I8V$O
M4V]U=&A?4&]L92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY:4U0G+`H@
M("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE
M)R`]/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G07-I82]!;F%D>7(G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T%N861Y<B!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G04Y!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=!;F%D>7(@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!3D%35"<@*2P*("`@("=!<VEA
M+TMA;6-H871K82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&5T<F]P879L;W9S:RU+
M86UC:&%T<VMI(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=01514
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)U!E=')O<&%V;&]V<VLM2V%M8VAA='-K:2!3=6UM97(@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)U!%5%-4)R`I+`H@("`@
M)T5T8R]'350M,3(G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LQ,CHP,"<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=-5"LQ,CHP,"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=+=V%J86QE:6XG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TUA<G-H86QL($ES;&%N9',@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)TU(5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=.4U0G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE=R!:96%L86YD(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.6E-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TYE=R!:96%L86YD($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=.6D14)R`I+`H@("`@)TY:)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=.97<@6F5A;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G3EI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3EI$5"<@*2P*
M("`@("=086-I9FEC+T%U8VML86YD)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=.97<@
M6F5A;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G3EI35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G
M9'-T;&]N9VYA;64G(#T^("=.97<@6F5A;&%N9"!$87EL:6=H="!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3EI$5"<@*2P*("`@("=086-I
M9FEC+T9I:FDG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S,C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9I:FD@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T9*5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=086-I9FEC+T9U;F%F=71I)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=4=79A;'4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U16
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC
M+TMW86IA;&5I;B<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%R<VAA;&P@27-L86YD
M<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34A4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O36%J=7)O)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=-87)S:&%L;"!)<VQA;F1S(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=-2%0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G4&%C:69I8R].875R=2<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G3F%U<G4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TY25"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=086-I9FEC+U1A
M<F%W82<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1VEL8F5R="!)<RX@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T=)3%0G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]786ME)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=786ME(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=704M4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O
M5V%L;&ES)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=786QL:7,@)B!&=71U;F$@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=&5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=.6BU#2$%4)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`T-3DP,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=#:&%T:&%M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=#2$%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("=#:&%T:&%M($1A>6QI9VAT(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=#2$%$5"<@*2P*("`@("=0
M86-I9FEC+T-H871H86TG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#0U.3`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H871H86T@4W1A
M;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-(05-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)T-H871H86T@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)T-(0414)R`I+`H@("`@)T5T8R]'350M,3,G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=-5"LQ,SHP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"LQ,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=086-I9FEC+T5N9&5R8G5R>2<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-#8X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G4&AO
M96YI>"!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!(3U0G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%C:69I8R]4
M;VYG871A<'4G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U1O;F=A(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=43U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G171C+T=-5"TQ-"<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-3`T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4*S$T.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$T.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,O
M2VER:71I;6%T:2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-3`T
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3&EN92!)<RX@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TQ)3E0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4+3$R.C`P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`M-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G1TU4+3$R.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4
M+3$R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=-
M5"TQ,3HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,Y-C`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T=-5"TQ,3HP,"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=797-T(%-A;6]A(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TS.38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=797-T(%-A;6]A(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=74U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G4V%M;V$@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3,Y-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-A
M;6]A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=3
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3FEU92!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,SDV,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G3FEU92!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G3E54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS
M92`I+`H@("`@)TAA=V%I:2U!;&5U=&EA;B!3=&%N9&%R9"!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,S8P,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G2&%W86EI+4%L975T:6%N(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=(05-4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TAA=V%I
M:2U!;&5U=&EA;B!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G2$%$5"<@*2P*("`@("='350M,3`Z,#`G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='350M,3`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350M,3`Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M2&%W86EI(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^("TS-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=(87=A
M:6D@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TA3
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4;VME;&%U
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4;VME;&%U(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=42U0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G0V]O:R!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,V,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-O;VL@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M2U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5&%H:71I
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TS-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=486AI=&D@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U1!2%0G+`H@("`@("`@("=H87-D<W0G(#T^
M(&9A;'-E("DL"B`@("`G36%R<75E<V%S(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TS-#(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=-87)Q=65S87,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)TU!4E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06QA
M<VMA(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!;&%S:V$@
M4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%+4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G06QA<VMA($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=!2T14)R`I+`H@("`@)T=-5"TP.3HP,"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,R-#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)T=-5"TP.3HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"TP.3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("='86UB:65R(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^("TS,C0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='86UB:65R
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='04U4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A8VEF:6,@4W1A;F1A<F0@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A8VEF:6,@4W1A;F1A<F0@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!35"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=086-I
M9FEC($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=01%0G("DL"B`@("`G1TU4+3`X.C`P)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M1TU4+3`X.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4+3`X.C`P
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!I=&-A:7)N
M(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TR.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0:71C86ER;B!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4%-4)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TUO=6YT86EN(%-T
M86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR
M-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=-;W5N=&%I;B!3=&%N
M9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)TUO=6YT86EN($1A>6QI9VAT(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=-1%0G("DL"B`@("`G1TU4+3`W.C`P)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`M,C4R,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1TU4+3`W.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4+3`W.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T-E;G1R86P@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E
M;G1R86P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#96YT<F%L($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#1%0G("DL"B`@("`G16%S=&5R;B!3=&%N
M9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R
M9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G15-4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)T5A<W1E<FX@1&%Y;&EG:'0@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)T5$5"<@*2P*("`@("=%87-T97(@27,N(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=%87-T97(@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=%05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@
M("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<B!)<RX@4W5M;65R(%1I;64G
M+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%05-35"<@*2P*("`@("='
M350M,#8Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TR,38P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#8Z,#`G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("='350M,#8Z,#`G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G1V%L87!A9V]S(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TR,38P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("='86QA<&%G;W,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)T=!3%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G0V]L;VUB:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-O;&]M8FEA
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#3U0G+`H@("`@("`@
M("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G06-R92!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G06-R92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G04-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T5C
M=6%D;W(@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$X
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T5C=6%D;W(@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T5#5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=097)U(%1I;64G(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^("TQ.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=097)U(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0150G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4+3`U.C`P
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3@P,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`U.C`P)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G1TU4+3`U.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T%T;&%N=&EC(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=!=&QA;G1I8R!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G05-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E
M+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%T;&%N=&EC($1A>6QI9VAT
M(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!1%0G("DL"B`@
M("`G4&%R86=U87D@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@
M/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A<F%G=6%Y
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=0650G+`H@("`@("`@
M("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G
M4&%R86=U87D@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G
M(#T^("=065-4)R`I+`H@("`@)T%M87IO;B!3=&%N9&%R9"!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G06UA>F]N(%-T86YD87)D(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=!350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G5F5N97IU96QA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=696YE>G5E;&$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U9%
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("='=7EA;F$@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=U>6%N82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1UE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T)O;&EV:6$@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T)O;&EV:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T)/5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#:&EL92!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G0VAI;&4@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T-,5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#:&EL92!3=6UM97(@5&EM92<L
M"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T-,4U0G("DL"B`@("`G1F%L
M:VQA;F0@27,N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M("TQ-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=&86QK;&%N9"!)
M<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T9+5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=&86QK;&%N9"!)<RX@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=&2U-4)R`I+`H@("`@)T=-5"TP-#HP,"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@+3$T-#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)T=-5"TP-#HP,"<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=-5"TP-#HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=.97=F;W5N9&QA;F0@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3$R-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)TYE=V9O=6YD;&%N9"!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G3E-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TYE=V9O=6YD;&%N9"!$87EL:6=H
M="!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G3D14)R`I+`H@
M("`@)T%R9V5N=&EN92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)G96YT
M:6YE(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4E0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0G)A>FEL(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ,#@P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("="<F%Z:6P@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T)25"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@
M("`@("`G9'-T;&]N9VYA;64G(#T^("="<F%Z:6P@4W5M;65R(%1I;64G+`H@
M("`@("`@("=D<W1S:&]R=&YA;64G(#T^("="4E-4)R`I+`H@("`@)T9R96YC
M:"!'=6EA;F$@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T9R96YC:"!'=6EA
M;F$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=&5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=797-T97)N($=R965N;&%N
M9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!'<F5E;FQA;F0@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U='5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=7
M97-T97)N($=R965N;&%N9"!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H
M;W)T;F%M92<@/3X@)U='4U0G("DL"B`@("`G4&EE<G)E("8@36EQ=65L;VX@
M4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!I97)R92`F($UI
M<75E;&]N(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=035-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)U!I97)R92`F($UI<75E;&]N($1A>6QI9VAT(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=03414)R`I+`H@("`@
M)U5R=6=U87D@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5R=6=U87D@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U595"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=3=7)I;F%M92!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`M,3`X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G4W5R:6YA;64@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U-25"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("='350M,#,Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^("TQ
M,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350M,#,Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350M,#,Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1F5R;F%N9&\@9&4@3F]R;VYH82!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=&97)N86YD;R!D92!.;W)O;FAA(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=&3E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4V]U=&@@1V5O<F=I82!3=&%N9&%R
M9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3;W5T:"!'96]R9VEA(%-T86YD
M87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4+3`R.C`P)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`M-S(P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("='350M,#(Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("='350M,#(Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G16%S=&5R;B!'<F5E;FQA;F0@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N($=R965N;&%N9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G14=4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@
M("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E<FX@1W)E96YL86YD(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G14=35"<@*2P*("`@
M("=!>F]R97,@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07IO<F5S(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!6D]4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T%Z;W)E
M<R!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T%:
M3U-4)R`I+`H@("`@)T-A<&4@5F5R9&4@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G0V%P92!697)D92!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M0U94)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5"TP
M,3HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@+3,V,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4+3`Q.C`P)RP*("`@("`@("`G
M<VAO<G1N86UE)R`]/B`G1TU4+3`Q.C`P)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T=R965N=VEC:"!-96%N(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G1W)E96YW:6-H($UE86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@
M/3X@)T=-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=7
M97-T97)N($5U<F]P96%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5V5S=&5R;B!%=7)O
M<&5A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G5T54)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@
M/3X@)U=E<W1E<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D
M<W1S:&]R=&YA;64G(#T^("=715-4)R`I+`H@("`@)T=-5"LP,#HP,"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='350K,#`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350K,#`Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M0V]O<F1I;F%T960@56YI=F5R<V%L(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0V]O<F1I
M;F%T960@56YI=F5R<V%L(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=55$,G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0V5N
M=')A;"!%=7)O<&5A;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R86P@
M175R;W!E86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-%5"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA
M;64G(#T^("=#96YT<F%L($5U<F]P96%N(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G0T535"<@*2P*("`@("=797-T97)N($%F
M<FEC86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=797-T97)N($%F<FEC86X@
M5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U=!5"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=7
M97-T97)N($%F<FEC86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R
M=&YA;64G(#T^("=705-4)R`I+`H@("`@)T=-5"LP,3HP,"<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='350K,#$Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350K,#$Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M36ED9&QE($5U<F]P92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUI9&1L92!%
M=7)O<&4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU%5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G
M(#T^("=-:61D;&4@175R;W!E(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T
M<VAO<G1N86UE)R`]/B`G34535"<@*2P*("`@("=%87-T97)N($5U<F]P96%N
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!%=7)O<&5A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1454)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)T5A<W1E
M<FX@175R;W!E86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA
M;64G(#T^("=%15-4)R`I+`H@("`@)T-E;G1R86P@069R:6-A;B!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)T-E;G1R86P@069R:6-A;B!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G0T%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)U-O=71H($%F<FEC82!3=&%N9&%R9"!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`W,C`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U-O=71H($%F<FEC82!3=&%N9&%R9"!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G4T%35"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=)<W)A96P@4W1A;F1A<F0@5&EM92<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@-S(P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=)<W)A96P@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)TE35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=)<W)A96P@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE$5"<@*2P*("`@("='
M350K,#(Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#<R,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G1TU4*S`R.C`P)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T5A<W1E<FX@069R:6-A;B!4:6UE)R`]/B!A
M<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G
M;&]N9VYA;64G(#T^("=%87-T97)N($%F<FEC86X@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T5!5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=3>6]W82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=3>6]W
M82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4UE/5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=!<F%B:6$@4W1A;F1A<F0@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3`X,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07)A8FEA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=!4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G1TU4*S`S.C`P)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q,#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("='350K,#,Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K
M,#,Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36]S
M8V]W(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#$P.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TUO<V-O=R!3
M=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G35-+)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M
M92<@/3X@)TUO<V-O=R!$87EL:6=H="!4:6UE)RP*("`@("`@("`G9'-T<VAO
M<G1N86UE)R`]/B`G35-$)R`I+`H@("`@)T=-5"LP,SHP-R<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,3$R,C0P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G1TU4*S`S.C`W)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M1TU4*S`S.C`W)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TER86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3(V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27)A;B!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G25)4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TER86X@4W5M97(@
M5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TE24U0G("DL"B`@
M("`G07%T874@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G07%T874@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D
M<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T874@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!4513
M5"<@*2P*("`@("=!>F5R8F%I:F%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)T%Z97)B86EJ86X@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T%:
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N
M9VYA;64G(#T^("=!>F5R8F%I:F%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G05I35"<@*2P*("`@("='=6QF(%-T86YD87)D
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=U;&8@4W1A;F1A<F0@5&EM92<L
M"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T=35"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("='96]R9VEA(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T=E;W)G:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)T=%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("='96]R9VEA(%-U;6UE<B!4:6UE)RP*("`@("`@("`G
M9'-T<VAO<G1N86UE)R`]/B`G1T535"<@*2P*("`@("=!<FUE;FEA(%1I;64G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T%R;65N:6$@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)T%-5"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!<FUE;FEA(%-U;6UE<B!4:6UE
M)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G04U35"<@*2P*("`@("='
M350K,#0Z,#`G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P
M,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)T=-5"LP-#HP,"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@9F%L<V4@*2P*("`@("=386UA<F$@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G4V%M87)A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=3
M04U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)U-A;6%R82!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)U-!35-4)R`I+`H@("`@)U-E>6-H96QL97,@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,30T,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G4V5Y8VAE;&QE<R!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G4T-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)TUA=7)I=&EU<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`Q-#0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=-875R:71I=7,@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU5
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=2975N:6]N
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$T-#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U)E=6YI;VX@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U)%5"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=!9F=H86YI<W1A;B!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`Q-C(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=!9F=H86YI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0494)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T%Q
M=&]B92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=!<71O8F4@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)T%15%0G+`H@("`@("`@("=H87-D<W0G
M(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N86UE)R`]/B`G07%T;V)E(%-U
M;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G05%44U0G
M("DL"B`@("`G5'5R:VUE;FES=&%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)U1U<FMM96YI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M5$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TMI<F=I
M>G-T86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2VER9VEZ<W1A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G2T=4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)TMI<F=I
M>G-T86X@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=+1U-4)R`I+`H@("`@)U1A:FEK:7-T86X@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G5&%J:6MI<W1A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5$I4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U!A
M:VES=&%N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X
M,#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U!A:VES=&%N(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=02U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G57IB96MI<W1A;B!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=5>F)E:VES=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("=56E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G665K871E<FEN8G5R9R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`Q.#`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=996MA
M=&5R:6YB=7)G(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=914M4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG
M;F%M92<@/3X@)UEE:V%T97)I;F)U<F<@4W5M;65R(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=914M35"<@*2P*("`@("='350K,#4Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#$X,#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"LP-3HP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LP-3HP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=&<F5N8V@@4V]U=&AE<FX@)B!!;G1A<F-T:6,@3&%N9',@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1G)E;F-H(%-O=71H97)N("8@06YT
M87)C=&EC($QA;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4
M1E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36%L9&EV
M97,@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,3@P,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%L9&EV97,@5&EM92<L"B`@
M("`@("`@)W-H;W)T;F%M92<@/3X@)TU65"<L"B`@("`@("`@)VAA<V1S="<@
M/3X@9F%L<V4@*2P*("`@("=);F1I82!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`Q.3@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=);F1I82!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G25-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TYE<&%L(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G
M(#T^(#(P-S`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYE<&%L(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.4%0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G36%W<V]N(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TUA=W-O;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G34%75"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=6
M;W-T;VL@=&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G5F]S=&]K('1I;64G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("=63U-4)RP*("`@("`@("`G:&%S9'-T
M)R`]/B!F86QS92`I+`H@("`@)T%L;6$M071A(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T%L;6$M071A(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^
M("=!3$U4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D
M<W1L;VYG;F%M92<@/3X@)T%L;6$M071A(%-U;6UE<B!4:6UE)RP*("`@("`@
M("`G9'-T<VAO<G1N86UE)R`]/B`G04Q-4U0G("DL"B`@("`G4W)I($QA;FMA
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(Q-C`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U-R:2!,86YK82!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G3$M4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)T)A;F=L861E<V@@5&EM92<@/3X@87)R87DH"B`@
M("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@)VQO;F=N86UE
M)R`]/B`G0F%N9VQA9&5S:"!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0D14)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TYO
M=F]S:6)I<G-K(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(Q-C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TYO=F]S:6)I<G-K
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=.3U94)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TYO=F]S:6)I<G-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G3D]64U0G("DL"B`@("`G3VUS:R!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=/;7-K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=/
M35-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L
M;VYG;F%M92<@/3X@)T]M<VL@4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S
M:&]R=&YA;64G(#T^("=/35-35"<@*2P*("`@("=":'5T86X@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C$V,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G0FAU=&%N(%1I;64G+`H@("`@("`@("=S:&]R=&YA
M;64G(#T^("="5%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@
M("`G1TU4*S`V.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R
M,38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#8Z,#`G+`H@
M("`@("`@("=S:&]R=&YA;64G(#T^("='350K,#8Z,#`G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G26YD:6%N($]C96%N(%1E<G)I=&]R
M>2!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,38P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=);F1I86X@3V-E86X@5&5R<FET
M;W)Y(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=)3U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G37EA;FUA<B!4:6UE)R`]
M/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R,S0P,#`P,"P*("`@("`@
M("`G;&]N9VYA;64G(#T^("=->6%N;6%R(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=-350G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL
M"B`@("`G0V]C;W,@27-L86YD<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R,S0P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M;V-O<R!)<VQA;F1S(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M0U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G1&%V:7,@
M5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L
M"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1&%V:7,@5&EM92<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T1!5E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G26YD;V-H:6YA(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@
M("=O9F9S970G(#T^(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@
M)TEN9&]C:&EN82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G24-4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TAO=F0@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C4R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G2&]V9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G2$]65"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=797-T($EN9&]N97-I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=797-T($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G5TE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TMR
M87-N;WEA<G-K(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(U,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMR87-N;WEA<G-K
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+4D%4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@
M)TMR87-N;WEA<G-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N
M86UE)R`]/B`G2U)!4U0G("DL"B`@("`G1TU4*S`W.C`P)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("='350K,#<Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='
M350K,#<Z,#`G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M0VAR:7-T;6%S($ES;&%N9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`R-3(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:')I
M<W1M87,@27-L86YD(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M6%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5V5S=&5R
M;B!3=&%N9&%R9"!4:6UE("A!=7-T<F%L:6$I)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=797-T97)N(%-T86YD87)D(%1I;64@*$%U<W1R86QI82DG+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=74U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G0G)U;F5I(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T)R
M=6YE:2!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0DY4)RP*("`@
M("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T-H:6YA(%-T86YD87)D
M(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P
M+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-H:6YA(%-T86YD87)D(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G+`H@("`@("`@("=H87-D
M<W0G(#T^(&9A;'-E("DL"B`@("`G2&]N9R!+;VYG(%1I;64G(#T^(&%R<F%Y
M*`H@("`@("`@("=O9F9S970G(#T^(#(X.#`P,#`P+`H@("`@("`@("=L;VYG
M;F%M92<@/3X@)TAO;F<@2V]N9R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G2$M4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)TER:W5T<VL@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G27)K=71S:R!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G25)+5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=)<FMU
M='-K(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M25)+4U0G("DL"B`@("`G36%L87ES:6$@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36%L87ES:6$@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TU9
M5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=0:&EL:7!P
M:6YE<R!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0:&EL:7!P:6YE<R!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4$A4)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!F86QS92`I+`H@("`@)U-I;F=A<&]R92!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=3:6YG87!O<F4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)U-'5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@
M("=#96YT<F%L($EN9&]N97-I82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`R.#@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#
M96YT<F%L($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G0TE4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U5L
M86%N8F%A=&%R(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^
M(#(X.#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)U5L86%N8F%A=&%R
M(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=53$%4)RP*("`@("`@
M("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)T=-5"LP.#HP,"<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,C@X,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G1TU4*S`X.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]
M/B`G1TU4*S`X.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)T-H;VEB86QS86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E
M="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAO:6)A
M;'-A;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G0TA/5"<L"B`@
M("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=%87-T(%1I;6]R(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)T5A<W0@5&EM;W(@5&EM92<L"B`@("`@
M("`@)W-H;W)T;F%M92<@/3X@)U105"<L"B`@("`@("`@)VAA<V1S="<@/3X@
M9F%L<V4@*2P*("`@("=%87-T($EN9&]N97-I82!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=%87-T($EN9&]N97-I82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G14E4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)TMO<F5A(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)TMO
M<F5A(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=+
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G2F%P86X@
M4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2F%P86X@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)TI35"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=986MU='-K(%1I;64G(#T^
M(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,R-#`P,#`P+`H@("`@("`@
M("=L;VYG;F%M92<@/3X@)UEA:W5T<VL@5&EM92<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)UE!2U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@
M("`@("`@)V1S=&QO;F=N86UE)R`]/B`G66%K='-K(%-U;6UE<B!4:6UE)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G64%+4U0G("DL"B`@("`G1TU4
M*S`Y.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S,C0P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("='350K,#DZ,#`G+`H@("`@("`@("=H87-D<W0G
M(#T^(&9A;'-E("DL"B`@("`G4&%L874@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,S(T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G4&%L874@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!75"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#96YT<F%L(%-T
M86YD87)D(%1I;64@*$YO<G1H97)N(%1E<G)I=&]R>2DG(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H3F]R=&AE<FX@5&5R<FET
M;W)Y*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@
M)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=#96YT<F%L(%-T86YD87)D(%1I
M;64@*%-O=71H($%U<W1R86QI82DG(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S
M970G(#T^(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T-E;G1R
M86P@4W1A;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA*2<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T-35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=#96YT<F%L(%-U;6UE<B!4
M:6UE("A3;W5T:"!!=7-T<F%L:6$I)RP*("`@("`@("`G9'-T<VAO<G1N86UE
M)R`]/B`G0U-4)R`I+`H@("`@)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H4V]U
M=&@@075S=')A;&EA+TYE=R!3;W5T:"!786QE<RDG(#T^(&%R<F%Y*`H@("`@
M("`@("=O9F9S970G(#T^(#,T,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@
M/3X@)T-E;G1R86P@4W1A;F1A<F0@5&EM92`H4V]U=&@@075S=')A;&EA+TYE
M=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#4U0G
M+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO;F=N
M86UE)R`]/B`G0V5N=')A;"!3=6UM97(@5&EM92`H4V]U=&@@075S=')A;&EA
M+TYE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^
M("=#4U0G("DL"B`@("`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A.97<@4V]U
M=&@@5V%L97,I)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P
M,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=%87-T97)N(%-T86YD87)D
M(%1I;64@*$YE=R!3;W5T:"!786QE<RDG+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=%4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@
M)V1S=&QO;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H3F5W(%-O
M=71H(%=A;&5S*2<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)T535"<@
M*2P*("`@("=$=6UO;G0M9%PG57)V:6QL92!4:6UE)R`]/B!A<G)A>2@*("`@
M("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G
M(#T^("=$=6UO;G0M9%PG57)V:6QL92!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G1$155"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*
M("`@("=386MH86QI;B!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T
M)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=386MH86QI
M;B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G4T%+5"<L"B`@("`@
M("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^
M("=386MH86QI;B!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S='-H;W)T;F%M
M92<@/3X@)U-!2U-4)R`I+`H@("`@)U9L861I=F]S=&]K(%1I;64G(#T^(&%R
M<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#,V,#`P,#`P+`H@("`@("`@("=L
M;VYG;F%M92<@/3X@)U9L861I=F]S=&]K(%1I;64G+`H@("`@("`@("=S:&]R
M=&YA;64G(#T^("=63$%4)RP*("`@("`@("`G:&%S9'-T)R`]/B!T<G5E+`H@
M("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U9L861I=F]S=&]K(%-U;6UE<B!4
M:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G5DQ!4U0G("DL"B`@
M("`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A1=65E;G-L86YD*2<@/3X@87)R
M87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P,#`P,#`L"B`@("`@("`@)VQO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R9"!4:6UE("A1=65E;G-L86YD
M*2<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@9F%L<V4@*2P*("`@("=%87-T97)N(%-T86YD87)D(%1I;64@
M*%1A<VUA;FEA*2<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G16%S=&5R;B!3=&%N9&%R
M9"!4:6UE("A487-M86YI82DG+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=%
M4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@("`@)V1S=&QO
M;F=N86UE)R`]/B`G16%S=&5R;B!3=6UM97(@5&EM92`H5&%S;6%N:6$I)RP*
M("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G15-4)R`I+`H@("`@)T5A<W1E
M<FX@4W1A;F1A<F0@5&EM92`H5FEC=&]R:6$I)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=%87-T97)N(%-T86YD87)D(%1I;64@*%9I8W1O<FEA*2<L"B`@("`@("`@
M)W-H;W)T;F%M92<@/3X@)T535"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U
M92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=%87-T97)N(%-U;6UE<B!4
M:6UE("A6:6-T;W)I82DG+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=%
M4U0G("DL"B`@("`G1TU4*S$P.C`P)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='350K
M,3`Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,3`Z,#`G+`H@
M("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G0VAA;6]R<F\@4W1A
M;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,S8P
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G0VAA;6]R<F\@4W1A;F1A
M<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)T-H4U0G+`H@("`@
M("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G4&%P=6$@3F5W($=U:6YE
M82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=087!U82!.97<@1W5I;F5A(%1I
M;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=01U0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5')U:R!4:6UE)R`]/B!A<G)A>2@*
M("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*("`@("`@("`G;&]N9VYA
M;64G(#T^("=4<G5K(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=4
M4E54)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)UEA<"!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S-C`P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=987`@5&EM92<L"B`@("`@("`@)W-H
M;W)T;F%M92<@/3X@)UE!4%0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E
M("DL"B`@("`G3&]A9"!(;W=E(%-T86YD87)D(%1I;64G(#T^(&%R<F%Y*`H@
M("`@("`@("=O9F9S970G(#T^(#,W.#`P,#`P+`H@("`@("`@("=L;VYG;F%M
M92<@/3X@)TQO860@2&]W92!3=&%N9&%R9"!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G3$A35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*
M("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=,;V%D($AO=V4@4W5M;65R(%1I
M;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=,2%-4)R`I+`H@("`@
M)TUA9V%D86X@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@
M,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G36%G861A;B!4:6UE
M)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G34%'5"<L"B`@("`@("`@)VAA
M<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=-86=A
M9&%N(%-U;6UE<B!4:6UE)RP*("`@("`@("`G9'-T<VAO<G1N86UE)R`]/B`G
M34%'4U0G("DL"B`@("`G1TU4*S$Q.C`P)R`]/B!A<G)A>2@*("`@("`@("`G
M;V9F<V5T)R`]/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("='
M350K,3$Z,#`G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='350K,3$Z,#`G
M+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G5F%N=6%T=2!4
M:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`S.38P,#`P,"P*
M("`@("`@("`G;&]N9VYA;64G(#T^("=686YU871U(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=6550G+`H@("`@("`@("=H87-D<W0G(#T^(&9A
M;'-E("DL"B`@("`G4V]L;VUO;B!)<RX@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G4V]L;VUO;B!)<RX@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@
M)U-"5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=+;W-R
M864@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P
M,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G2V]S<F%E(%1I;64G+`H@("`@
M("`@("=S:&]R=&YA;64G(#T^("=+3U-4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)TYE=R!#86QE9&]N:6$@5&EM92<@/3X@87)R87DH
M"B`@("`@("`@)V]F9G-E="<@/3X@,SDV,#`P,#`L"B`@("`@("`@)VQO;F=N
M86UE)R`]/B`G3F5W($-A;&5D;VYI82!4:6UE)RP*("`@("`@("`G<VAO<G1N
M86UE)R`]/B`G3D-4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@
M("`@)U!O;F%P92!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]
M/B`S.38P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=0;VYA<&4@5&EM
M92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U!/3E0G+`H@("`@("`@("=H
M87-D<W0G(#T^(&9A;'-E("DL"B`@("`G3F]R9F]L:R!4:6UE)R`]/B!A<G)A
M>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,30P,#`P,"P*("`@("`@("`G;&]N
M9VYA;64G(#T^("=.;W)F;VQK(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=.1E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M3F5W(%IE86QA;F0@4W1A;F1A<F0@5&EM92<@/3X@87)R87DH"B`@("`@("`@
M)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G
M3F5W(%IE86QA;F0@4W1A;F1A<F0@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M
M92<@/3X@)TY:4U0G+`H@("`@("`@("=H87-D<W0G(#T^('1R=64L"B`@("`@
M("`@)V1S=&QO;F=N86UE)R`]/B`G3F5W(%IE86QA;F0@1&%Y;&EG:'0@5&EM
M92<L"B`@("`@("`@)V1S='-H;W)T;F%M92<@/3X@)TY:1%0G("DL"B`@("`G
M06YA9'ER(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0S
M,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T%N861Y<B!4:6UE)RP*
M("`@("`@("`G<VAO<G1N86UE)R`]/B`G04Y!5"<L"B`@("`@("`@)VAA<V1S
M="<@/3X@=')U92P*("`@("`@("`G9'-T;&]N9VYA;64G(#T^("=!;F%D>7(@
M4W5M;65R(%1I;64G+`H@("`@("`@("=D<W1S:&]R=&YA;64G(#T^("=!3D%3
M5"<@*2P*("`@("=0971R;W!A=FQO=G-K+4MA;6-H871S:VD@5&EM92<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G4&5T<F]P879L;W9S:RU+86UC:&%T<VMI(%1I;64G
M+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=01514)RP*("`@("`@("`G:&%S
M9'-T)R`]/B!T<G5E+`H@("`@("`@("=D<W1L;VYG;F%M92<@/3X@)U!E=')O
M<&%V;&]V<VLM2V%M8VAA='-K:2!3=6UM97(@5&EM92<L"B`@("`@("`@)V1S
M='-H;W)T;F%M92<@/3X@)U!%5%-4)R`I+`H@("`@)T=-5"LQ,CHP,"<@/3X@
M87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@
M)VQO;F=N86UE)R`]/B`G1TU4*S$R.C`P)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G1TU4*S$R.C`P)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)TUA<G-H86QL($ES;&%N9',@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G36%R<VAA;&P@27-L86YD<R!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE
M)R`]/B`G34A4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@
M)T9I:FD@5&EM92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R
M,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1FEJ:2!4:6UE)RP*("`@
M("`@("`G<VAO<G1N86UE)R`]/B`G1DI4)RP*("`@("`@("`G:&%S9'-T)R`]
M/B!F86QS92`I+`H@("`@)U1U=F%L=2!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=4=79A;'4@5&EM92<L"B`@("`@("`@)W-H;W)T;F%M92<@/3X@)U165"<L
M"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=.875R=2!4:6UE
M)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T,S(P,#`P,"P*("`@
M("`@("`G;&]N9VYA;64G(#T^("=.875R=2!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G3E)4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I
M+`H@("`@)T=I;&)E<G0@27,N(%1I;64G(#T^(&%R<F%Y*`H@("`@("`@("=O
M9F9S970G(#T^(#0S,C`P,#`P+`H@("`@("`@("=L;VYG;F%M92<@/3X@)T=I
M;&)E<G0@27,N(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("='24Q4
M)RP*("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)U=A:V4@5&EM
M92<@/3X@87)R87DH"B`@("`@("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@
M("`@("`@)VQO;F=N86UE)R`]/B`G5V%K92!4:6UE)RP*("`@("`@("`G<VAO
M<G1N86UE)R`]/B`G5T%+5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@
M*2P*("`@("=786QL:7,@)B!&=71U;F$@5&EM92<@/3X@87)R87DH"B`@("`@
M("`@)V]F9G-E="<@/3X@-#,R,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]
M/B`G5V%L;&ES("8@1G5T=6YA(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G
M(#T^("=71E0G+`H@("`@("`@("=H87-D<W0G(#T^(&9A;'-E("DL"B`@("`G
M0VAA=&AA;2!3=&%N9&%R9"!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F
M<V5T)R`]/B`T-3DP,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=#:&%T
M:&%M(%-T86YD87)D(%1I;64G+`H@("`@("`@("=S:&]R=&YA;64G(#T^("=#
M2$%35"<L"B`@("`@("`@)VAA<V1S="<@/3X@=')U92P*("`@("`@("`G9'-T
M;&]N9VYA;64G(#T^("=#:&%T:&%M($1A>6QI9VAT(%1I;64G+`H@("`@("`@
M("=D<W1S:&]R=&YA;64G(#T^("=#2$%$5"<@*2P*("`@("='350K,3,Z,#`G
M(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#0V.#`P,#`P+`H@("`@
M("`@("=L;VYG;F%M92<@/3X@)T=-5"LQ,SHP,"<L"B`@("`@("`@)W-H;W)T
M;F%M92<@/3X@)T=-5"LQ,SHP,"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L
M<V4@*2P*("`@("=0:&]E;FEX($ES+B!4:6UE)R`]/B!A<G)A>2@*("`@("`@
M("`G;V9F<V5T)R`]/B`T-C@P,#`P,"P*("`@("`@("`G;&]N9VYA;64G(#T^
M("=0:&]E;FEX($ES+B!4:6UE)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G
M4$A/5"<L"B`@("`@("`@)VAA<V1S="<@/3X@9F%L<V4@*2P*("`@("=4;VYG
M82!4:6UE)R`]/B!A<G)A>2@*("`@("`@("`G;V9F<V5T)R`]/B`T-C@P,#`P
M,"P*("`@("`@("`G;&]N9VYA;64G(#T^("=4;VYG82!4:6UE)RP*("`@("`@
M("`G<VAO<G1N86UE)R`]/B`G5$]4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`H@("`@)T=-5"LQ-#HP,"<@/3X@87)R87DH"B`@("`@("`@)V]F
M9G-E="<@/3X@-3`T,#`P,#`L"B`@("`@("`@)VQO;F=N86UE)R`]/B`G1TU4
M*S$T.C`P)RP*("`@("`@("`G<VAO<G1N86UE)R`]/B`G1TU4*S$T.C`P)RP*
M("`@("`@("`G:&%S9'-T)R`]/B!F86QS92`I+`H@("`@)TQI;F4@27,N(%1I
M;64G(#T^(&%R<F%Y*`H@("`@("`@("=O9F9S970G(#T^(#4P-#`P,#`P+`H@
M("`@("`@("=L;VYG;F%M92<@/3X@)TQI;F4@27,N(%1I;64G+`H@("`@("`@
M("=S:&]R=&YA;64G(#T^("=,24Y4)RP*("`@("`@("`G:&%S9'-T)R`]/B!F
M86QS92`I+`HI.PH*+R\*+R\@26YI=&EA;&EZ92!D969A=6QT('1I;65Z;VYE
M"B\O("!&:7)S="!T<GD@7T1!5$5?5$E-15I/3D5?1$5&055,5"!G;&]B86PL
M"B\O("!T:&5N(%!(4%]46B!E;G9I<F]N;65N="!V87(L('1H96X@5%H@96YV
M:7)O;FUE;G0@=F%R"B\O"FEF*&ES<V5T*"1?1$%415]424U%6D].15]$149!
M54Q4*0H@("`@)B8@1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*"1?1$%415]4
M24U%6D].15]$149!54Q4*0HI('L*("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E
M9F%U;'0H)%]$051%7U1)345:3TY%7T1%1D%53%0I.PI](&5L<V5I9B`H9V5T
M96YV*"=02%!?5%HG*2`F)B!$871E7U1I;65:;VYE.CII<U9A;&ED240H9V5T
M96YV*"=02%!?5%HG*2DI('L*("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U
M;'0H9V5T96YV*"=02%!?5%HG*2D["GT@96QS96EF("AG971E;G8H)U1:)RD@
M)B8@1&%T95]4:6UE6F]N93HZ:7-686QI9$E$*&=E=&5N=B@G5%HG*2DI('L*
M("`@($1A=&5?5&EM95IO;F4Z.G-E=$1E9F%U;'0H9V5T96YV*"=46B<I*3L*
M?2!E;'-E:68@*$1A=&5?5&EM95IO;F4Z.FES5F%L:61)1"AD871E*"=4)RDI
M*2!["B`@("!$871E7U1I;65:;VYE.CIS971$969A=6QT*&1A=&4H)U0G*2D[
M"GT@96QS92!["B`@("!$871E7U1I;65:;VYE.CIS971$969A=6QT*"=55$,G
M*3L*?0H`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1A=&4O0V%L8RYP:'``````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`R,#`R-3`@,3`U
M,34T,S0Q,S,@,#(P-S$P`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"B\O"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`U($)A8F$@0G5E:&QE<BP@4&EE<G)E+4%L86EN($IO>64@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('1H92!.97<@0E-$
M(&QI8V5N<V4L(%1H870@:7,@8G5N9&QE9"`@?`HO+R!\('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@
M=&AR;W5G:"`@("`@('P*+R\@?"!T:&4@=V]R;&0M=VED92UW96(@870@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M
M;&EC96YS92YP:'`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!N97<@0E-$;&EC96YS92!A
M;F0@87)E('5N86)L92`@('P*+R\@?"!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("!\"B\O('P@<&5A<BUD979`;&ES=',N<&AP+FYE="!S;R!W92!C86X@;6%I
M;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W(Z($)A8F$@0G5E:&QE
M<B`\8F%B84!B86)A>BYC;VT^("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("!0:65R<F4M06QA:6X@2F]Y92`\<&%J;WEE
M0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"B\J*@H@*B!#86QC=6QA=&5S+"!M
M86YI<'5L871E<R!A;F0@<F5T<FEE=F5S(&1A=&5S"B`J"B`J($ET(&1O97,@
M;F]T(')E;'D@;VX@,S(M8FET('-Y<W1E;2!T:6UE('-T86UP<RP@<V\@:70@
M=V]R:W,@9&%T97,*("H@8F5F;W)E(#$Y-S`@86YD(&%F=&5R(#(P,S@N"B`J
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($!C871E9V]R>2`@($1A
M=&4@86YD(%1I;64*("H@0'!A8VMA9V4@("`@1&%T90H@*B!`875T:&]R("`@
M("!-;VYT92!/:')T(#QM;VYT94!I<W!I+FYE=#X*("H@0&%U=&AO<B`@("`@
M4&EE<G)E+4%L86EN($IO>64@/'!A:F]Y94!P:'`N;F5T/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3DM,C`P-2`@36]N=&4@3VAR="P@4&EE<G)E+4%L86EN
M($IO>64L($1A;FEE;"!#;VYV:7-S;W(*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M($YE=R!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@0V%L
M8RYP:'`L=B`Q+C,S(#(P,#4O,3$O,34@,#`Z,38Z,SD@<&%J;WEE($5X<"`D
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$
M871E"B`J($!S:6YC92`@("`@($9I;&4@879A:6QA8FQE('-I;F-E(%)E;&5A
M<V4@,2XR"B`J+PH*:68@*"%D969I;F5D*"=$051%7T-!3$-?0D5'24Y?5T5%
M2T1!62<I*2!["B`@("`O*BH*("`@("`J($1E9FEN97,@=VAA="!D87D@<W1A
M<G1S('1H92!W965K"B`@("`@*@H@("`@("H@36]N9&%Y("@Q*2!I<R!T:&4@
M:6YT97)N871I;VYA;"!S=&%N9&%R9"X*("`@("`J(%)E9&5F:6YE('1H:7,@
M=&\@,"!I9B!Y;W4@=V%N="!W965K<R!T;R!B96=I;B!O;B!3=6YD87DN"B`@
M("`@*B\*("`@(&1E9FEN92@G1$%415]#04Q#7T)%1TE.7U=%14M$05DG+"`Q
M*3L*?0H*:68@*"%D969I;F5D*"=$051%7T-!3$-?1D]234%4)RDI('L*("`@
M("\J*@H@("`@("H@5&AE(&1E9F%U;'0@=F%L=64@9F]R(&5A8V@@;65T:&]D
M)W,@)&9O<FUA="!P87)A;65T97(*("`@("`J"B`@("`@*B!4:&4@9&5F875L
M="!I<R`G)5DE;25D)RX@(%1O(&]V97)R:61E('1H:7,@9&5F875L="P@9&5F
M:6YE"B`@("`@*B!T:&ES(&-O;G-T86YT(&)E9F]R92!I;F-L=61I;F<@0V%L
M8RYP:'`N"B`@("`@*@H@("`@("H@0'-I;F-E($-O;G-T86YT(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-2XP"B`@("`@*B\*("`@(&1E9FEN92@G1$%4
M15]#04Q#7T9/4DU!5"<L("<E625M)60G*3L*?0H*+RHJ"B`J($-A;&-U;&%T
M97,L(&UA;FEP=6QA=&5S(&%N9"!R971R:65V97,@9&%T97,*("H*("H@270@
M9&]E<R!N;W0@<F5L>2!O;B`S,BUB:70@<WES=&5M('1I;64@<W1A;7!S+"!S
M;R!I="!W;W)K<R!D871E<PH@*B!B969O<F4@,3DW,"!A;F0@869T97(@,C`S
M."X*("H*("H@0&%U=&AO<B`@("`@36]N=&4@3VAR="`\;6]N=&5`:7-P:2YN
M970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY.2P@,C`P,BP@,C`P,R!I<W!I
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC
M96YS97,O8G-D+6QI8V5N<V4N<&AP("!.97<@0E-$($QI8V5N<V4*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XT+C8*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1A=&4*("H@0'-I;F-E("`@("`@0VQA
M<W,@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XR"B`J+PIC;&%S<R!$871E
M7T-A;&,*>PH@("`@+RHJ"B`@("`@*B!&;W)M871S('1H92!D871E(&EN('1H
M92!G:79E;B!F;W)M870L(&UU8V@@;&EK92!S=')F;70H*0H@("`@("H*("`@
M("`J(%1H:7,@9G5N8W1I;VX@:7,@=7-E9"!T;R!A;&QE=FEA=&4@=&AE('!R
M;V)L96T@=VET:"`S,BUB:70@;G5M8F5R<R!F;W(*("`@("`J(&1A=&5S('!R
M92`Q.3<P(&]R('!O<W0@,C`S."P@87,@<W1R9FUT*"D@:&%S(&]N(&UO<W0@
M<WES=&5M<RX*("`@("`J($UO<W0@;V8@=&AE(&9O<FUA='1I;F<@;W!T:6]N
M<R!A<F4@8V]M<&%T:6)L92X*("`@("`J"B`@("`@*B!&;W)M871T:6YG(&]P
M=&EO;G,Z"B`@("`@*B`\<')E/@H@("`@("H@)6$@("!A8F)R979I871E9"!W
M965K9&%Y(&YA;64@*%-U;BP@36]N+"!4=64I"B`@("`@*B`E02`@(&9U;&P@
M=V5E:V1A>2!N86UE("A3=6YD87DL($UO;F1A>2P@5'5E<V1A>2D*("`@("`J
M("5B("`@86)B<F5V:6%T960@;6]N=&@@;F%M92`H2F%N+"!&96(L($UA<BD*
M("`@("`J("5"("`@9G5L;"!M;VYT:"!N86UE("A*86YU87)Y+"!&96)R=6%R
M>2P@36%R8V@I"B`@("`@*B`E9"`@(&1A>2!O9B!M;VYT:"`H<F%N9V4@,#`@
M=&\@,S$I"B`@("`@*B`E92`@(&1A>2!O9B!M;VYT:"P@<VEN9VQE(&1I9VET
M("AR86YG92`P('1O(#,Q*0H@("`@("H@)44@("!N=6UB97(@;V8@9&%Y<R!S
M:6YC92!U;G-P96-I9FEE9"!E<&]C:"`H:6YT96=E<BD*("`@("`J("`@("`@
M("`H)44@:7,@=7-E9G5L(&9O<B!P87-S:6YG(&$@9&%T92!I;B!A(%523"!A
M<PH@("`@("H@("`@("`@(&%N(&EN=&5G97(@=F%L=64N(%1H96X@<VEM<&QY
M('5S90H@("`@("H@("`@("`@(&1A>7-4;T1A=&4H*2!T;R!C;VYV97)T(&)A
M8VL@=&\@82!D871E+BD*("`@("`J("5J("`@9&%Y(&]F('EE87(@*')A;F=E
M(#`P,2!T;R`S-C8I"B`@("`@*B`E;2`@(&UO;G1H(&%S(&1E8VEM86P@;G5M
M8F5R("AR86YG92`Q('1O(#$R*0H@("`@("H@)6X@("!N97=L:6YE(&-H87)A
M8W1E<B`H7&XI"B`@("`@*B`E="`@('1A8B!C:&%R86-T97(@*%QT*0H@("`@
M("H@)7<@("!W965K9&%Y(&%S(&1E8VEM86P@*#`@/2!3=6YD87DI"B`@("`@
M*B`E52`@('=E96L@;G5M8F5R(&]F(&-U<G)E;G0@>65A<BP@9FER<W0@<W5N
M9&%Y(&%S(&9I<G-T('=E96L*("`@("`J("5Y("`@>65A<B!A<R!D96-I;6%L
M("AR86YG92`P,"!T;R`Y.2D*("`@("`J("59("`@>65A<B!A<R!D96-I;6%L
M(&EN8VQU9&EN9R!C96YT=7)Y("AR86YG92`P,#`P('1O(#DY.3DI"B`@("`@
M*B`E)2`@(&QI=&5R86P@)R4G"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H
M"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<BX@(%5S92!T:&4@
M8V]M<&QE=&4@>65A<B!I;G-T96%D(&]F('1H90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@86)B<F5V:6%T960@=F5R<VEO;BX@($4N9RX@=7-E
M(#(P,#4L(&YO="`P-2X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M($1O(&YO="!A9&0@;&5A9&EN9R`P)W,@9F]R('EE87)S('!R:6]R('1O(#$P
M,#`N"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!F;W)M870@
M<W1R:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E
M(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&1A
M=&5&;W)M870H)&1A>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="D*("`@('L*
M("`@("`@("!I9B`H(41A=&5?0V%L8SHZ:7-686QI9$1A=&4H)&1A>2P@)&UO
M;G1H+"`D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@(#T@1&%T95]#86QC
M.CID871E3F]W*"<E62<I.PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@("`@("1D87D@("`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"@H@("`@("`@("1O=71P
M=70@/2`G)SL*"B`@("`@("`@9F]R("@D<W1R<&]S(#T@,#L@)'-T<G!O<R`\
M('-T<FQE;B@D9F]R;6%T*3L@)'-T<G!O<RLK*2!["B`@("`@("`@("`@("1C
M:&%R(#T@<W5B<W1R*"1F;W)M870L("1S=')P;W,L(#$I.PH@("`@("`@("`@
M("!I9B`H)&-H87(@/3T@)R4G*2!["B`@("`@("`@("`@("`@("`D;F5X=&-H
M87(@/2!S=6)S='(H)&9O<FUA="P@)'-T<G!O<R`K(#$L(#$I.PH@("`@("`@
M("`@("`@("`@<W=I=&-H*"1N97AT8VAA<BD@>PH@("`@("`@("`@("`@("`@
M("`@(&-A<V4@)V$G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T
M("X]($1A=&5?0V%L8SHZ9V5T5V5E:V1A>4%B8G)N86UE*"1D87DL("1M;VYT
M:"P@)'EE87(I.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@
M("`@("`@("`@("`@("`@("!C87-E("=!)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]U='!U="`N/2!$871E7T-A;&,Z.F=E=%=E96MD87E&=6QL;F%M
M92@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G8B<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIG971-
M;VYT:$%B8G)N86UE*"1M;VYT:"D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)T(G.@H@("`@("`@
M("`@("`@("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9V5T36]N
M=&A&=6QL;F%M92@D;6]N=&@I.PH@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=D)SH*("`@("`@("`@
M("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D)RP@)&1A
M>2D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("`@("`@("`@(&-A<V4@)V4G.@H@("`@("`@("`@("`@("`@("`@("`@("`D
M;W5T<'5T("X]("1D87D["B`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@)T4G.@H@("`@("`@("`@("`@
M("`@("`@("`@("`D;W5T<'5T("X]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D
M9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G:B<Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T95]#86QC.CIJ=6QI86Y$
M871E*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!C87-E("=M)SH*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]U='!U="`N/2!S<')I;G1F*"<E,#)D
M)RP@)&UO;G1H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@8V%S92`G;B<Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("1O=71P=70@+CT@(EQN(CL*("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G="<Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@(EQT(CL*("`@("`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S
M92`G=R<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@1&%T
M95]#86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)U4G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M($1A=&5?0V%L8SHZ=V5E:T]F665A<B@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("`@("`@8V%S92`G>2<Z"B`@("`@("`@("`@("`@("`@("`@("`@("1O=71P
M=70@+CT@<W5B<W1R*"1Y96%R+"`R+"`R*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@8V%S92`G62<Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("1O=71P=70@+CT@)'EE87(["B`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M(&-A<V4@)R4G.@H@("`@("`@("`@("`@("`@("`@("`@("`D;W5T<'5T("X]
M("<E)SL*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@
M)&]U='!U="`N/2`D8VAA<BXD;F5X=&-H87(["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D<W1R<&]S*RL["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D;W5T<'5T("X]("1C:&%R.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B`D;W5T<'5T.PH@("`@
M?0H*("`@("\J*@H@("`@("H@5'5R;G,@82!T=V\@9&EG:70@>65A<B!I;G1O
M(&$@9F]U<B!D:6=I="!Y96%R"B`@("`@*@H@("`@("H@1G)O;2`G-3$@=&\@
M)SDY(&ES(&EN('1H92`Q.3`P)W,L(&]T:&5R=VES92!I="=S(&EN('1H92`R
M,#`P)W,N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T
M:&4@,B!D:6=I="!Y96%R"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92`T(&1I9VET('EE87(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D969A=6QT
M0V5N='5R>2@D>65A<BD*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1Y96%R
M*2`]/2`Q*2!["B`@("`@("`@("`@("1Y96%R(#T@)S`G("X@)'EE87(["B`@
M("`@("`@?0H@("`@("`@(&EF("@D>65A<B`^(#4P*2!["B`@("`@("`@("`@
M(')E='5R;B`G,3DG("X@)'EE87(["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("<R,"<@+B`D>65A<CL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#;VYV97)T<R!A(&1A=&4@=&\@;G5M8F5R(&]F(&1A
M>7,@<VEN8V4@82!D:7-T86YT('5N<W!E8VEF:65D(&5P;V-H"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M
M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@*
M("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(N("!5<V4@
M=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N
M('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T
M;R`Q,#`P+@H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@=&AE(&YU
M;6)E<B!O9B!D87ES('-I;F-E('1H92!$871E7T-A;&,@97!O8V@*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!D871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I
M"B`@("!["B`@("`@("`@)&-E;G1U<GD@/2`H:6YT*7-U8G-T<B@D>65A<BP@
M,"P@,BD["B`@("`@("`@)'EE87(@/2`H:6YT*7-U8G-T<B@D>65A<BP@,BP@
M,BD["B`@("`@("`@:68@*"1M;VYT:"`^(#(I('L*("`@("`@("`@("`@)&UO
M;G1H("T](#,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&UO;G1H
M("L](#D["B`@("`@("`@("`@(&EF("@D>65A<BD@>PH@("`@("`@("`@("`@
M("`@)'EE87(M+3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1Y96%R(#T@.3D["B`@("`@("`@("`@("`@("`D8V5N='5R>2`M+3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("AF;&]O
M<B@H,30V,#DW("H@)&-E;G1U<GDI("\@-"`I("L*("`@("`@("`@("`@("`@
M(&9L;V]R*"@Q-#8Q("H@)'EE87(I("\@-"`I("L*("`@("`@("`@("`@("`@
M(&9L;V]R*"@Q-3,@*B`D;6]N=&@@*R`R*2`O(#4@*2`K"B`@("`@("`@("`@
M("`@("`D9&%Y("L@,3<R,3$Q.2D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#
M;VYV97)T<R!N=6UB97(@;V8@9&%Y<R!T;R!A(&1I<W1A;G0@=6YS<&5C:69I
M960@97!O8V@*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87ES("`@
M('1H92!N=6UB97(@;V8@9&%Y<R!S:6YC92!T:&4@1&%T95]#86QC(&5P;V-H
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD
M:6-A=&EN9R!H;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R
M;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&%Y<U1O1&%T92@D9&%Y<RP@)&9O
M<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@)&1A>7,@
M("`M/2`Q-S(Q,3$Y.PH@("`@("`@("1C96YT=7)Y(#T@9FQO;W(H*#0@*B`D
M9&%Y<R`M(#$I("\@,30V,#DW*3L*("`@("`@("`D9&%Y<R`@("`](&9L;V]R
M*#0@*B`D9&%Y<R`M(#$@+2`Q-#8P.3<@*B`D8V5N='5R>2D["B`@("`@("`@
M)&1A>2`@("`@/2!F;&]O<B@D9&%Y<R`O(#0I.PH*("`@("`@("`D>65A<B`@
M("`](&9L;V]R*"@T("H@)&1A>2`K("`S*2`O(#$T-C$I.PH@("`@("`@("1D
M87D@("`@(#T@9FQO;W(H-"`J("1D87D@*R`@,R`M(#$T-C$@*B`D>65A<BD[
M"B`@("`@("`@)&1A>2`@("`@/2!F;&]O<B@H)&1A>2`K("`T*2`O(#0I.PH*
M("`@("`@("`D;6]N=&@@("`](&9L;V]R*"@U("H@)&1A>2`M(#,I("\@,34S
M*3L*("`@("`@("`D9&%Y("`@("`](&9L;V]R*#4@*B`D9&%Y("T@,R`M(#$U
M,R`J("1M;VYT:"D["B`@("`@("`@)&1A>2`@("`@/2!F;&]O<B@H)&1A>2`K
M("`U*2`O("`U*3L*"B`@("`@("`@:68@*"1M;VYT:"`\(#$P*2!["B`@("`@
M("`@("`@("1M;VYT:"`K/3,["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)&UO;G1H("T].3L*("`@("`@("`@("`@:68@*"1Y96%R*RL@/3T@.3DI
M('L*("`@("`@("`@("`@("`@("1Y96%R(#T@,#L*("`@("`@("`@("`@("`@
M("1C96YT=7)Y*RL["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1C96YT=7)Y(#T@<W!R:6YT9B@G)3`R9"<L("1C96YT=7)Y*3L*("`@("`@
M("`D>65A<B`@("`]('-P<FEN=&8H)R4P,F0G+"`D>65A<BD["B`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1C
M96YT=7)Y("X@)'EE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@0V]N=F5R=',@9G)O;2!'<F5G;W)I86X@665A<BU-;VYT:"U$87D@=&\@
M25-/(%EE87(M5V5E:TYU;6)E<BU7965K1&%Y"B`@("`@*@H@("`@("H@57-E
M<R!)4T\@.#8P,2!D969I;FET:6]N<RX@($%L9V]R:71H;2!B>2!2:6-K($UC
M0V%R='DL(#$Y.3D@870*("`@("`J(&AT='`Z+R]P97)S;VYA;"YE8W4N961U
M+VUC8V%R='ER+TE33W=D04Q'+G1X="`N"B`@("`@*B!4<F%N<V-R:6)E9"!T
M;R!02%`@8GD@2F5S=7,@32X@0V%S=&%G;F5T=&\N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@
M("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@*("`@("`J
M($!P87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(N("!5<V4@=&AE(&-O
M;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I;VXN("!%+F<N('5S92`R
M,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!$
M;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!)
M4T\@665A<BU7965K3G5M8F5R+5=E96M$87D@9F]R;6%T"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9W)E9V]R:6%N5&])4T\H)&1A>2P@)&UO;G1H+"`D>65A<BD@
M>PH@("`@("`@("1M;G1H(#T@87)R87D@*#`L(#,Q+"`U.2P@.3`L(#$R,"P@
M,34Q+"`Q.#$L(#(Q,BP@,C0S+"`R-S,L(#,P-"P@,S,T*3L*("`@("`@("`D
M>5]I<VQE87`@/2!$871E7T-A;&,Z.FES3&5A<%EE87(H)'EE87(I.PH@("`@
M("`@("1Y7S%?:7-L96%P(#T@1&%T95]#86QC.CII<TQE87!996%R*"1Y96%R
M("T@,2D["B`@("`@("`@)&1A>5]O9E]Y96%R7VYU;6)E<B`]("1D87D@*R`D
M;6YT:%LD;6]N=&@@+2`Q73L*("`@("`@("!I9B`H)'E?:7-L96%P("8F("1M
M;VYT:"`^(#(I('L*("`@("`@("`@("`@)&1A>5]O9E]Y96%R7VYU;6)E<BLK
M.PH@("`@("`@('T*("`@("`@("`O+R!F:6YD($IA;B`Q('=E96MD87D@*&UO
M;F1A>2`](#$L('-U;F1A>2`](#<I"B`@("`@("`@)'EY(#T@*"1Y96%R("T@
M,2D@)2`Q,#`["B`@("`@("`@)&,@/2`H)'EE87(@+2`Q*2`M("1Y>3L*("`@
M("`@("`D9R`]("1Y>2`K(&EN='9A;"@D>7D@+R`T*3L*("`@("`@("`D:F%N
M,5]W965K9&%Y(#T@,2`K(&EN='9A;"@H*"@H)&,@+R`Q,#`I("4@-"D@*B`U
M*2`K("1G*2`E(#<I.PH@("`@("`@("\O('=E96MD87D@9F]R('EE87(M;6]N
M=&@M9&%Y"B`@("`@("`@)&@@/2`D9&%Y7V]F7WEE87)?;G5M8F5R("L@*"1J
M86XQ7W=E96MD87D@+2`Q*3L*("`@("`@("`D=V5E:V1A>2`](#$@*R!I;G1V
M86PH*"1H("T@,2D@)2`W*3L*("`@("`@("`O+R!F:6YD(&EF(%D@32!$(&9A
M;&QS(&EN(%EE87).=6UB97(@62TQ+"!7965K3G5M8F5R(#4R(&]R"B`@("`@
M("`@:68@*"1D87E?;V9?>65A<E]N=6UB97(@/#T@*#@@+2`D:F%N,5]W965K
M9&%Y*2`F)B`D:F%N,5]W965K9&%Y(#X@-"E["B`@("`@("`@("`@("1Y96%R
M;G5M8F5R(#T@)'EE87(@+2`Q.PH@("`@("`@("`@("!I9B`H)&IA;C%?=V5E
M:V1A>2`]/2`U('Q\("@D:F%N,5]W965K9&%Y(#T](#8@)B8@)'E?,5]I<VQE
M87`I*2!["B`@("`@("`@("`@("`@("`D=V5E:VYU;6)E<B`](#4S.PH@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'=E96MN=6UB97(@
M/2`U,CL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1Y96%R;G5M8F5R(#T@)'EE87(["B`@("`@("`@?0H@("`@("`@("\O
M(&9I;F0@:68@62!-($0@9F%L;',@:6X@665A<DYU;6)E<B!9*S$L(%=E96M.
M=6UB97(@,0H@("`@("`@(&EF("@D>65A<FYU;6)E<B`]/2`D>65A<BD@>PH@
M("`@("`@("`@("!I9B`H)'E?:7-L96%P*2!["B`@("`@("`@("`@("`@("`D
M:2`](#,V-CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1I(#T@,S8U.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@H)&D@
M+2`D9&%Y7V]F7WEE87)?;G5M8F5R*2`\("@T("T@)'=E96MD87DI*2!["B`@
M("`@("`@("`@("`@("`D>65A<FYU;6)E<BLK.PH@("`@("`@("`@("`@("`@
M)'=E96MN=6UB97(@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@("\O(&9I;F0@:68@62!-($0@9F%L;',@:6X@665A<DYU;6)E<B!9+"!7
M965K3G5M8F5R(#$@=&AR;W5G:"`U,PH@("`@("`@(&EF("@D>65A<FYU;6)E
M<B`]/2`D>65A<BD@>PH@("`@("`@("`@("`D:B`]("1D87E?;V9?>65A<E]N
M=6UB97(@*R`H-R`M("1W965K9&%Y*2`K("@D:F%N,5]W965K9&%Y("T@,2D[
M"B`@("`@("`@("`@("1W965K;G5M8F5R(#T@:6YT=F%L*"1J("\@-RD["B`@
M("`@("`@("`@(&EF("@D:F%N,5]W965K9&%Y(#X@-"D@>PH@("`@("`@("`@
M("`@("`@)'=E96MN=6UB97(M+3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("`O+R!P=70@:70@86QL('1O9V5T:&5R"B`@("`@("`@:68@*"1W
M965K;G5M8F5R(#P@,3`I('L*("`@("`@("`@("`@)'=E96MN=6UB97(@/2`G
M,"<N)'=E96MN=6UB97(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D>65A
M<FYU;6)E<B`N("<M)R`N("1W965K;G5M8F5R("X@)RTG("X@)'=E96MD87D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S(&IU;&EA;B!D871E
M(&]F('1H92!G:79E;B!S96%S;VX*("`@("`J"B`@("`@*B!!9&%P=&5D(&9R
M;VT@<')E=FEO=7,@=V]R:R!I;B!*879A(&)Y($IA;65S($UA<FL@2&%M:6QT
M;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5A<V]N("!T:&4@
M<V5A<V]N('1O(&=E="!T:&4@9&%T92!F;W(Z(%9%4DY!3$5154E.3U@L"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!354U-15)33TQ35$E#12P@
M055454U.04Q%455)3D]8+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@;W(@5TE.5$524T],4U1)0T4*("`@("`J($!P87)A;2!S=')I;F<@)'EE
M87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870N("!-=7-T(&)E
M(&)E='=E96X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("TQ,#`P
M0D,@86YD(#,P,#!!1"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&9L;V%T("!T
M:&4@:G5L:6%N(&1A=&4@=&AE('-E87-O;B!S=&%R=',@;VX*("`@("`J"B`@
M("`@*B!`875T:&]R($IA;65S($UA<FL@2&%M:6QT;VX@/&UH86UI;'1O;D!Q
M=V5S="YN970^"B`@("`@*B!`875T:&]R(%)O8F5R="!"=71L97(@/')O8D!M
M87AW96QL8W)E96LN;W)G/@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&%T95-E87-O;B@D<V5A
M<V]N+"`D>65A<B`](#`I('L*("`@("`@("!I9B`H)'EE87(@/3T@)R<I('L*
M("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@H)'EE87(@/CT@+3$P,#`I("8F("@D
M>65A<B`\/2`Q,#`P*2D@>PH@("`@("`@("`@("`D>2`]("1Y96%R("\@,3`P
M,"XP.PH@("`@("`@("`@("!S=VET8V@@*"1S96%S;VXI('L*("`@("`@("`@
M("`@("`@(&-A<V4@)U9%4DY!3$5154E.3U@G.@H@("`@("`@("`@("`@("`@
M("`@("1J=6QI86YD871E(#T@*"@H*"@H*"TP+C`P,#<Q("H@)'DI("T@,"XP
M,#$Q,2D@*B`D>2D@*R`P+C`V,3,T*2`J("1Y*2`K(#,V-3(T,BXQ,S<T*2`J
M("1Y*2`K(#$W,C$Q,SDN,CDQ.#D["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E("=354U-15)33TQ35$E#12<Z"B`@
M("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H*"@H,"XP,#`R
M-2`J("1Y*2`K(#`N,#`Y,#<I("H@)'DI("T@,"XP-3,R,RD@*B`D>2D@*R`S
M-C4R-#$N-S(U-C(I("H@)'DI("L@,3<R,3(S,RXR-30P,3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)T%55%5-
M3D%,15%524Y/6"<Z"B`@("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@
M/2`H*"@H*"@H,"XP,#`W-"`J("1Y*2`M(#`N,#`R.3<I("H@)'DI("T@,"XQ
M,38W-RD@*B`D>2D@*R`S-C4R-#(N-#DU-3@I("H@)'DI("L@,3<R,3,R-2XW
M,#0U-3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&-A<V4@)U=)3E1%4E-/3%-424-%)SH*("`@("`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@)&IU;&EA;F1A=&4@/2`H*"@H
M*"@H+3`N,#`P,#8@*B`D>2D@+2`P+C`P.3,S*2`J("1Y*2`M(#`N,#`W-CDI
M("H@)'DI("L@,S8U,C0R+C@X,C4W*2`J("1Y*2`K(#$W,C$T,30N,SDY.#<[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H*"1Y96%R(#X@,3`P
M,"D@)B8@*"1Y96%R(#P](#,P,#`I*2!["B`@("`@("`@("`@("1Y(#T@*"1Y
M96%R("T@,C`P,"D@+R`Q,#`P.PH@("`@("`@("`@("!S=VET8V@@*"1S96%S
M;VXI('L*("`@("`@("`@("`@("`@(&-A<V4@)U9%4DY!3$5154E.3U@G.@H@
M("`@("`@("`@("`@("`@("`@("1J=6QI86YD871E(#T@*"@H*"@H*"TP+C`P
M,#4W("H@)'DI("T@,"XP,#0Q,2D@*B`D>2D@*R`P+C`U,38Y*2`J("1Y*2`K
M(#,V-3(T,BXS-S0P-"D@*B`D>2D@*R`R-#4Q-C(S+C@P.3@T.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`G4U5-
M34524T],4U1)0T4G.@H@("`@("`@("`@("`@("`@("`@("1J=6QI86YD871E
M(#T@*"@H*"@H*"TP+C`P,#,@*B`D>2D@*R`P+C`P.#@X*2`J("1Y*2`K(#`N
M,#`S,C4I("H@)'DI("L@,S8U,C0Q+C8R-C`S*2`J("1Y*2`K(#(T-3$W,38N
M-38W-C<["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("!C87-E("=!551534Y!3$5154E.3U@G.@H@("`@("`@("`@("`@("`@
M("`@("1J=6QI86YD871E(#T@*"@H*"@H*#`N,#`P-S@@*B`D>2D@*R`P+C`P
M,S,W*2`J("1Y*2`M(#`N,3$U-S4I("H@)'DI("L@,S8U,C0R+C`Q-S8W*2`J
M("1Y*2`K(#(T-3$X,3`N,C$W,34["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("!C87-E("=724Y415)33TQ35$E#12<Z"B`@
M("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("1J
M=6QI86YD871E(#T@*"@H*"@H*#`N,#`P,S(@*B`D>2D@+2`P+C`P.#(S*2`J
M("1Y*2`M(#`N,#8R,C,I("H@)'DI("L@,S8U,C0R+C<T,#0Y*2`J("1Y*2`K
M(#(T-3$Y,#`N,#4Y-3(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1J=6QI86YD871E.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@8W5R<F5N="!L;V-A;"!D871E"B`@("`@*@H@("`@("H@
M3D]413H@5&AI<R!F=6YC=&EO;B!R971R:65V97,@=&AE(&QO8V%L(&1A=&4@
M=7-I;F<@<W1R9G1I;64H*2P*("`@("`J('=H:6-H(&UA>2!O<B!M87D@;F]T
M(&)E(#,R+6)I="!S869E(&]N('EO=7(@<WES=&5M+@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG
M(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@8W5R<F5N="!D871E(&EN('1H92!S<&5C:69I960@
M9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S
M=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&%T94YO=R@D9F]R;6%T(#T@
M1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!R971U<FX@<W1R9G1I
M;64H)&9O<FUA="P@=&EM92@I*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&-U<G)E;G0@;&]C86P@>65A<B!I;B!F;W)M870@0T-960H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@8W5R<F5N="!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M665A<B@I"B`@("!["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)5DG*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U
M<G)E;G0@;&]C86P@;6]N=&@@:6X@9F]R;6%T($U-"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!C=7)R96YT(&UO;G1H(&EN('1W;R!D:6=I
M="!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:"@I"B`@("![
M"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&-U<G)E;G0@;&]C86P@
M9&%Y(&EN(&9O<FUA="!$1`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG
M("!T:&4@8W5R<F5N="!D87D@;V8@=&AE(&UO;G1H(&EN('1W;R!D:6=I="!F
M;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971$87DH*0H@("`@>PH@("`@
M("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&YU;6)E<B!O9B!D87ES('-I;F-E(#,Q
M($1E8V5M8F5R(&]F('EE87(@8F5F;W)E(&=I=F5N(&1A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R
M86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@
M('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T
M:&4@:G5L:6%N(&1A=&4@9F]R('1H92!D871E"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@:G5L:6%N1&%T92@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P
M*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@
M("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M
M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1D
M87ES(#T@87)R87DH,"P@,S$L(#4Y+"`Y,"P@,3(P+"`Q-3$L(#$X,2P@,C$R
M+"`R-#,L(#(W,RP@,S`T+"`S,S0I.PH@("`@("`@("1J=6QI86X@/2`H)&1A
M>7-;)&UO;G1H("T@,5T@*R`D9&%Y*3L*("`@("`@("!I9B`H)&UO;G1H(#X@
M,B`F)B!$871E7T-A;&,Z.FES3&5A<%EE87(H)'EE87(I*2!["B`@("`@("`@
M("`@("1J=6QI86XK*SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1J=6QI
M86X["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!F=6QL('=E
M96MD87D@;F%M92!F;W(@=&AE(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT
M("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y
M96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@>65A<@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@
M9G5L;"!N86UE(&]F('1H92!D87D@;V8@=&AE('=E96L*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G9717965K9&%Y1G5L;&YA;64H)&1A>2`](#`L("1M;VYT:"`]
M(#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I
M*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E
M62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@
M("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD[
M"B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@
M("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@
M('T*("`@("`@("`D=V5E:V1A>5]N86UE<R`]($1A=&5?0V%L8SHZ9V5T5V5E
M:T1A>7,H*3L*("`@("`@("`D=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97
M965K*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@("`@(')E='5R;B`D=V5E
M:V1A>5]N86UE<ULD=V5E:V1A>5T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS('1H92!A8F)R979I871E9"!W965K9&%Y(&YA;64@9F]R('1H92!G
M:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@
M("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N
M=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A
M<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O
M<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P
M87)A;2!I;G0@("`@)&QE;F=T:"`@=&AE(&QE;F=T:"!O9B!A8F)R979I871I
M;VX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&%B8G)E=FEA
M=&5D(&YA;64@;V8@=&AE(&1A>2!O9B!T:&4@=V5E:PH@("`@("H*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A
M=&5?0V%L8SHZ9V5T5V5E:V1A>49U;&QN86UE*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T5V5E:V1A>4%B8G)N86UE*"1D87D@/2`P+"`D;6]N=&@@/2`P
M+"`D>65A<B`](#`L("1L96YG=&@@/2`S*0H@("`@>PH@("`@("`@(&EF("AE
M;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D
M;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1D87DI
M*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D
M)RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!S=6)S='(H1&%T95]#86QC
M.CIG9717965K9&%Y1G5L;&YA;64H)&1A>2P@)&UO;G1H+"`D>65A<BDL"B`@
M("`@("`@("`@("`@("`@("`@("`P+"`D;&5N9W1H*3L*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&9U;&P@;6]N=&@@;F%M92!F;W(@=&AE
M(&=I=F5N(&UO;G1H"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N
M=&@@("!T:&4@;6]N=&@*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&9U;&P@;F%M92!O9B!T:&4@;6]N=&@*("`@("`J"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!G971-;VYT:$9U;&QN86UE*"1M;VYT:"D*("`@('L*("`@("`@("`D;6]N
M=&@@/2`H:6YT*21M;VYT:#L*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@
M>PH@("`@("`@("`@("`D;6]N=&@@/2`H:6YT*41A=&5?0V%L8SHZ9&%T94YO
M=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@)&UO;G1H7VYA;65S(#T@1&%T
M95]#86QC.CIG971-;VYT:$YA;65S*"D["B`@("`@("`@<F5T=7)N("1M;VYT
M:%]N86UE<ULD;6]N=&A=.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!T:&4@86)B<F5V:6%T960@;6]N=&@@;F%M92!F;W(@=&AE(&=I=F5N(&UO
M;G1H"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@
M;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&QE;F=T:"`@=&AE(&QE;F=T
M:"!O9B!A8F)R979I871I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN
M9R`@=&AE(&%B8G)E=FEA=&5D(&YA;64@;V8@=&AE(&UO;G1H"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S
M964@1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=$UO;G1H06)B<FYA;64H)&UO;G1H+"`D;&5N9W1H(#T@,RD*
M("`@('L*("`@("`@("`D;6]N=&@@/2`H:6YT*21M;VYT:#L*("`@("`@("!I
M9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!S=6)S='(H1&%T95]#86QC.CIG971-;VYT:$9U;&QN86UE*"1M;VYT:"DL
M(#`L("1L96YG=&@I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@;G5M97)I8R!M;VYT:"!F<F]M('1H92!M;VYT:"!N86UE(&]R(&%N(&%B
M<F5V:6%T:6]N"B`@("`@*@H@("`@("H@0F]T:"!!=6=U<W0@86YD($%U9R!W
M;W5L9"!R971U<FX@."X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1M
M;VYT:"`@=&AE(&YA;64@;V8@=&AE(&UO;G1H('1O(&5X86UI;F4N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@($-A<V4@:6YS96YS:71I=F4N"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!T:&4@;6]N=&@G<R!N=6UB
M97(*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:$9R;VU&=6QL3F%M92@D
M;6]N=&@I"B`@("!["B`@("`@("`@)&UO;G1H(#T@<W1R=&]L;W=E<B@D;6]N
M=&@I.PH@("`@("`@("1M;VYT:',@/2!$871E7T-A;&,Z.F=E=$UO;G1H3F%M
M97,H*3L*("`@("`@("!W:&EL92AL:7-T*"1I9"P@)&YA;64I(#T@96%C:"@D
M;6]N=&AS*2D@>PH@("`@("`@("`@("!I9B`H97)E9R@D;6]N=&@L('-T<G1O
M;&]W97(H)&YA;64I*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1I9#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@,#L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@86X@87)R87D@;V8@;6]N=&@@
M;F%M97,*("`@("`J"B`@("`@*B!5<V5D('1O('1A:V4@861V86YT86=E(&]F
M('1H92!S971L;V-A;&4@9G5N8W1I;VX@=&\@<F5T=7)N"B`@("`@*B!L86YG
M=6%G92!S<&5C:69I8R!M;VYT:"!N86UE<RX*("`@("`J"B`@("`@*B!43T1/
M.B!C86-H92!V86QU97,@=&\@<V]M92!G;&]B86P@87)R87D@=&\@879O:60@
M<')E9F]R;6%C90H@("`@("H@:&ET<R!W:&5N(&-A;&QE9"!M;W)E('1H86X@
M;VYC92X*("`@("`J"B`@("`@*B!`<F5T=7)N<R!A<G)A>2`@86X@87)R87D@
M;V8@;6]N=&@@;F%M97,*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971-;VYT:$YA
M;65S*"D*("`@('L*("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"`Q,SL@)&DK
M*RD@>PH@("`@("`@("`@("`D;6]N=&AS6R1I72`]('-T<F9T:6UE*"<E0B<L
M(&UK=&EM92@P+"`P+"`P+"`D:2P@,2P@,C`P,2DI.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@)&UO;G1H<SL*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@86X@87)R87D@;V8@=V5E:R!D87ES"B`@("`@*@H@("`@("H@57-E
M9"!T;R!T86ME(&%D=F%N=&%G92!O9B!T:&4@<V5T;&]C86QE(&9U;F-T:6]N
M('1O"B`@("`@*B!R971U<FX@;&%N9W5A9V4@<W!E8VEF:6,@=V5E:R!D87ES
M+@H@("`@("H*("`@("`J(%1/1$\Z(&-A8VAE('9A;'5E<R!T;R!S;VUE(&=L
M;V)A;"!A<G)A>2!T;R!A=F]I9"!P<F5F;W)M86-E"B`@("`@*B!H:71S('=H
M96X@8V%L;&5D(&UO<F4@=&AA;B!O;F-E+@H@("`@("H*("`@("`J($!R971U
M<FYS(&%R<F%Y("!A;B!A<G)A>2!O9B!W965K(&1A>2!N86UE<PH@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%=E96M$87ES*"D*("`@('L*("`@("`@("!F;W(@
M*"1I(#T@,#L@)&D@/"`W.R`D:2LK*2!["B`@("`@("`@("`@("1W965K9&%Y
M<ULD:5T@/2!S=')F=&EM92@G)4$G+"!M:W1I;64H,"P@,"P@,"P@,2P@)&DL
M(#(P,#$I*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1W965K9&%Y<SL*
M("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%Y(&]F('=E96L@9F]R
M(&=I=F5N(&1A=&4@*#`@/2!3=6YD87DI"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D
M;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M
M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I
M;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M('EE87(*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O
M9B!T:&4@9&%Y(&EN('1H92!W965K"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9&%Y
M3V97965K*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A
M<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@
M1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@:68@*"1M;VYT
M:"`^(#(I('L*("`@("`@("`@("`@)&UO;G1H("T](#(["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&UO;G1H("L](#$P.PH@("`@("`@("`@("`D
M>65A<BTM.PH@("`@("`@('T*"B`@("`@("`@)&1A>2`]("AF;&]O<B@H,3,@
M*B`D;6]N=&@@+2`Q*2`O(#4I("L*("`@("`@("`@("`@("`@("1D87D@*R`H
M)'EE87(@)2`Q,#`I("L*("`@("`@("`@("`@("`@(&9L;V]R*"@D>65A<B`E
M(#$P,"D@+R`T*2`K"B`@("`@("`@("`@("`@("!F;&]O<B@H)'EE87(@+R`Q
M,#`I("\@-"D@+2`R("H*("`@("`@("`@("`@("`@(&9L;V]R*"1Y96%R("\@
M,3`P*2`K(#<W*3L*"B`@("`@("`@)'=E96MD87E?;G5M8F5R(#T@)&1A>2`M
M(#<@*B!F;&]O<B@D9&%Y("\@-RD["B`@("`@("`@<F5T=7)N("1W965K9&%Y
M7VYU;6)E<CL*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=V5E:R!O
M9B!T:&4@>65A<BP@9FER<W0@4W5N9&%Y(&ES(&9I<G-T(&1A>2!O9B!F:7)S
M="!W965K"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T
M:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L
M(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M
M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA
M="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!T:&4@=V5E:R!I;B!T:&4@
M>65A<@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A
M=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('=E96M/9EEE87(H)&1A>2`](#`L
M("1M;VYT:"`](#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I
M.PH@("`@("`@('T*("`@("`@("`D:7-O("`@(#T@1&%T95]#86QC.CIG<F5G
M;W)I86Y4;TE33R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`D<&%R
M=',@(#T@97AP;&]D92@G+2<L("1I<V\I.PH@("`@("`@("1W965K7VYU;6)E
M<B`](&EN='9A;"@D<&%R='-;,5TI.PH@("`@("`@(')E='5R;B`D=V5E:U]N
M=6UB97(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('%U87)T97(@
M;V8@=&AE('EE87(@9F]R(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@
M("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R
M(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C
M86P@>65A<@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R
M(&]F('1H92!Q=6%R=&5R(&EN('1H92!Y96%R"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75A<G1E<D]F665A<B@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@
M/2`P*0H@("`@>PH@("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@
M("`@("`@)'EE87(@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@
M("1M;VYT:"`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@
M("1Y96%R7W%U87)T97(@/2!I;G1V86PH*"1M;VYT:"`M(#$I("\@,R`K(#$I
M.PH@("`@("`@(')E='5R;B`D>65A<E]Q=6%R=&5R.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1FEN9"!T:&4@;G5M8F5R(&]F(&1A>7,@:6X@=&AE(&=I=F5N
M(&UO;G1H"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!D87ES('1H
M92!M;VYT:"!H87,*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!D87ES26Y-;VYT:"@D
M;6]N=&@@/2`P+"`D>65A<B`](#`I"B`@("!["B`@("`@("`@:68@*&5M<'1Y
M*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T
M94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT
M:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W
M*"<E;2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1Y96%R(#T](#$U.#(@
M)B8@)&UO;G1H(#T](#$P*2!["B`@("`@("`@("`@(')E='5R;B`R,3L@("\O
M($]C=&]B97(@,34X,B!O;FQY(&AA9"`Q<W0M-'1H(&%N9"`Q-71H+3,Q<W0*
M("`@("`@("!]"@H@("`@("`@(&EF("@D;6]N=&@@/3T@,BD@>PH@("`@("`@
M("`@("!I9B`H1&%T95]#86QC.CII<TQE87!996%R*"1Y96%R*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(#(Y.PH@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(')E='5R;B`R.#L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("@D;6]N=&@@/3T@-"!O<B`D;6]N=&@@/3T@-B!O<B`D
M;6]N=&@@/3T@.2!O<B`D;6]N=&@@/3T@,3$I('L*("`@("`@("`@("`@<F5T
M=7)N(#,P.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`S
M,3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H
M92!N=6UB97(@;V8@<F]W<R!O;B!A(&-A;&5N9&%R(&UO;G1H"B`@("`@*@H@
M("`@("H@57-E9G5L(&9O<B!D971E<FUI;FEN9R!T:&4@;G5M8F5R(&]F(')O
M=W,@=VAE;B!D:7-P;&%Y:6YG(&$@='EP:6-A;`H@("`@("H@;6]N=&@@8V%L
M96YD87(N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T
M:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@
M("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I
M9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!W965K<R!T
M:&4@;6]N=&@@:&%S"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@=V5E:W-);DUO;G1H
M*"1M;VYT:"`](#`L("1Y96%R(#T@,"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@("1&1$]-(#T@1&%T95]#86QC
M.CIF:7)S=$]F36]N=&A7965K9&%Y*"1M;VYT:"P@)'EE87(I.PH@("`@("`@
M(&EF("A$051%7T-!3$-?0D5'24Y?5T5%2T1!63T],2`F)B`D1D1/33T],"D@
M>PH@("`@("`@("`@("`D9FER<W1?=V5E:U]D87ES(#T@-R`M("1&1$]-("L@
M1$%415]#04Q#7T)%1TE.7U=%14M$05D["B`@("`@("`@("`@("1W965K<R`]
M(#$["B`@("`@("`@?2!E;'-E:68@*$1!5$5?0T%,0U]"14=)3E]7145+1$%9
M/3TP("8F("1&1$]-(#T](#8I('L*("`@("`@("`@("`@)&9I<G-T7W=E96M?
M9&%Y<R`](#<@+2`D1D1/32`K($1!5$5?0T%,0U]"14=)3E]7145+1$%9.PH@
M("`@("`@("`@("`D=V5E:W,@/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1F:7)S=%]W965K7V1A>7,@/2!$051%7T-!3$-?0D5'24Y?5T5%
M2T1!62`M("1&1$]-.PH@("`@("`@("`@("`D=V5E:W,@/2`P.PH@("`@("`@
M('T*("`@("`@("`D9FER<W1?=V5E:U]D87ES("4](#<["B`@("`@("`@<F5T
M=7)N(&-E:6PH*$1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A
M<BD*("`@("`@("`@("`@("`@("`@("`@+2`D9FER<W1?=V5E:U]D87ES*2`O
M(#<I("L@)'=E96MS.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N(&%N
M(&%R<F%Y('=I=&@@9&%Y<R!I;B!W965K"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D
M;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M
M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I
M;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M('EE87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN
M9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@)'=E96M;)'=E96MD87E="B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T0V%L96YD87)7965K*"1D87D@/2`P+"`D;6]N=&@@
M/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@
M*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y
M*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID
M871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A
M>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G
M)60G*3L*("`@("`@("!]"@H@("`@("`@("1W965K7V%R<F%Y(#T@87)R87DH
M*3L*"B`@("`@("`@+R\@9&%T92!F;W(@=&AE(&-O;'5M;B!O9B!W965K"@H@
M("`@("`@("1C=7)R7V1A>2`]($1A=&5?0V%L8SHZ8F5G:6Y/9E=E96LH)&1A
M>2P@)&UO;G1H+"`D>65A<BPG)44G*3L*"B`@("`@("`@9F]R("@D8V]U;G1E
M<B`](#`[("1C;W5N=&5R(#P](#8[("1C;W5N=&5R*RLI('L*("`@("`@("`@
M("`@)'=E96M?87)R87E;)&-O=6YT97)=(#T@1&%T95]#86QC.CID87ES5&]$
M871E*"1C=7)R7V1A>2P@)&9O<FUA="D["B`@("`@("`@("`@("1C=7)R7V1A
M>2LK.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'=E96M?87)R87D["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FX@82!S970@;V8@87)R87ES('1O
M(&-O;G-T<G5C="!A(&-A;&5N9&%R(&UO;G1H(&9O<B!T:&4@9VEV96X@9&%T
M90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F
M;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H
M;W<@=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("1M;VYT:%LD<F]W75LD8V]L70H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=$-A;&5N9&%R36]N=&@H)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#
M7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@
M("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@
M("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@
M("`@?0H*("`@("`@("`D;6]N=&A?87)R87D@/2!A<G)A>2@I.PH*("`@("`@
M("`O+R!D871E(&9O<B!T:&4@9FER<W0@<F]W+"!F:7)S="!C;VQU;6X@;V8@
M8V%L96YD87(@;6]N=&@*("`@("`@("!I9B`H1$%415]#04Q#7T)%1TE.7U=%
M14M$05D@/3T@,2D@>PH@("`@("`@("`@("!I9B`H1&%T95]#86QC.CIF:7)S
M=$]F36]N=&A7965K9&%Y*"1M;VYT:"P@)'EE87(I(#T](#`I('L*("`@("`@
M("`@("`@("`@("1C=7)R7V1A>2`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@G
M,#$G+"`D;6]N=&@L("1Y96%R*2`M(#8["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D8W5R<E]D87D@/2!$871E7T-A;&,Z.F1A=&54
M;T1A>7,H)S`Q)RP@)&UO;G1H+"`D>65A<BD*("`@("`@("`@("`@("`@("`@
M("`M($1A=&5?0V%L8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@D;6]N=&@L("1Y
M96%R*2`K(#$["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D8W5R<E]D87D@/2`H1&%T95]#86QC.CID871E5&]$87ES*"<P
M,2<L("1M;VYT:"P@)'EE87(I"B`@("`@("`@("`@("`@("`M($1A=&5?0V%L
M8SHZ9FER<W1/9DUO;G1H5V5E:V1A>2@D;6]N=&@L("1Y96%R*2D["B`@("`@
M("`@?0H*("`@("`@("`O+R!N=6UB97(@;V8@9&%Y<R!I;B!T:&ES(&UO;G1H
M"B`@("`@("`@)&1A>7-);DUO;G1H(#T@1&%T95]#86QC.CID87ES26Y-;VYT
M:"@D;6]N=&@L("1Y96%R*3L*"B`@("`@("`@)'=E96MS26Y-;VYT:"`]($1A
M=&5?0V%L8SHZ=V5E:W-);DUO;G1H*"1M;VYT:"P@)'EE87(I.PH@("`@("`@
M(&9O<B`H)')O=U]C;W5N=&5R(#T@,#L@)')O=U]C;W5N=&5R(#P@)'=E96MS
M26Y-;VYT:#L@)')O=U]C;W5N=&5R*RLI('L*("`@("`@("`@("`@9F]R("@D
M8V]L=6UN7V-O=6YT97(@/2`P.R`D8V]L=6UN7V-O=6YT97(@/#T@-CL@)&-O
M;'5M;E]C;W5N=&5R*RLI('L*("`@("`@("`@("`@("`@("1M;VYT:%]A<G)A
M>5LD<F]W7V-O=6YT97)=6R1C;VQU;6Y?8V]U;G1E<ET@/0H@("`@("`@("`@
M("`@("`@("`@("`@("!$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&-U<G)?9&%Y
M("P@)&9O<FUA="D["B`@("`@("`@("`@("`@("`D8W5R<E]D87DK*SL*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1M;VYT:%]A
M<G)A>3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;B!A('-E="!O9B!A
M<G)A>7,@=&\@8V]N<W1R=6-T(&$@8V%L96YD87(@>65A<B!F;W(@=&AE(&=I
M=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@
M('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&-U<G)E
M;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T
M:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`D>65A<ELD;6]N=&A=6R1R
M;W==6R1C;VQ="B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M($!S=&%T:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T0V%L96YD87)996%R
M*"1Y96%R(#T@,"P@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A
M<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"@H@("`@
M("`@("1Y96%R7V%R<F%Y(#T@87)R87DH*3L*"B`@("`@("`@9F]R("@D8W5R
M<E]M;VYT:"`](#`[("1C=7)R7VUO;G1H(#P](#$Q.R`D8W5R<E]M;VYT:"LK
M*2!["B`@("`@("`@("`@("1Y96%R7V%R<F%Y6R1C=7)R7VUO;G1H72`]"B`@
M("`@("`@("`@("`@("`@("`@1&%T95]#86QC.CIG971#86QE;F1A<DUO;G1H
M*"1C=7)R7VUO;G1H("L@,2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'EE87(L("1F;W)M870I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1Y96%R7V%R<F%Y.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4F5T=7)N<R!D871E(&]F(&1A>2!B969O<F4@9VEV96X@9&%T
M90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A
M>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!D87D*
M("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A
M=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!I;G0@
M("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R
M;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@<')E=D1A>2@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P
M+`H@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/
M4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@
M("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@
M("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@
M?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y
M(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@
M("`D9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"`D;6]N=&@L
M("1Y96%R*3L*("`@("`@("!R971U<FX@1&%T95]#86QC.CID87ES5&]$871E
M*"1D87ES("T@,2P@)&9O<FUA="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&1A=&4@;V8@9&%Y(&%F=&5R(&=I=F5N(&1A=&4*("`@("`J"B`@
M("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R
M86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R
M96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@
M('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T
M("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T
M<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN
M('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1$
M87DH)&1A>2`](#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@
M("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A
M<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@
M1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L
M8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)&1A>7,@/2!$
M871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@
M("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<R`K(#$L
M("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E
M(&]F('1H92!P<F5V:6]U<R!W965K9&%Y+"!S:VEP<&EN9R!F<F]M($UO;F1A
M>2!T;R!&<FED87D*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@
M("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M
M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`
M<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@
M9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@
M:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!R9797965K9&%Y*"1D87D@/2`P+"`D;6]N=&@@
M/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R
M;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP
M='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID
M871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO
M;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.
M;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@
M>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I
M.PH@("`@("`@('T*("`@("`@("`D9&%Y<R`]($1A=&5?0V%L8SHZ9&%T951O
M1&%Y<R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("!I9B`H1&%T95]#
M86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD@/3T@,2D@>PH@
M("`@("`@("`@("`D9&%Y<R`M/2`S.PH@("`@("`@('T@96QS96EF("A$871E
M7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y+"`D;6]N=&@L("1Y96%R*2`]/2`P*2![
M"B`@("`@("`@("`@("1D87ES("T](#(["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)&1A>7,@+3T@,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92@D9&%Y<RP@)&9O<FUA="D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&1A=&4@;V8@=&AE(&YE>'0@=V5E
M:V1A>2!O9B!G:79E;B!D871E+"!S:VEP<&EN9R!F<F]M"B`@("`@*B!&<FED
M87D@=&\@36]N9&%Y"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y
M("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@
M0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET
M(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J
M($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG
M(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!N97AT5V5E:V1A>2@D9&%Y(#T@,"P@)&UO;G1H
M(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&9O
M<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M
M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ
M9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M
M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E
M3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&1A>2DI
M('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G
M*3L*("`@("`@("!]"B`@("`@("`@)&1A>7,@/2!$871E7T-A;&,Z.F1A=&54
M;T1A>7,H)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@("`@("`@:68@*$1A=&5?
M0V%L8SHZ9&%Y3V97965K*"1D87DL("1M;VYT:"P@)'EE87(I(#T](#4I('L*
M("`@("`@("`@("`@)&1A>7,@*ST@,SL*("`@("`@("!](&5L<V5I9B`H1&%T
M95]#86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD@/3T@-BD@
M>PH@("`@("`@("`@("`D9&%Y<R`K/2`R.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1D87ES("L](#$["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B!$871E7T-A;&,Z.F1A>7-4;T1A=&4H)&1A>7,L("1F;W)M870I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D871E(&]F('1H92!P<F5V:6]U
M<R!S<&5C:69I8R!D87D@;V8@=&AE('=E96L*("`@("`J(&9R;VT@=&AE(&=I
M=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT(&1A>2!O9B!W965K
M+"`P/5-U;F1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@
M9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A
M>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E
M9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN
M="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P87)A;2!B
M;V]L("`@)&]N3W)"969O<F4@(&EF('1R=64@86YD(&1A>7,@87)E('-A;64L
M(')E='5R;G,@8W5R<F5N="!D87D*("`@("`J($!P87)A;2!S=')I;F<@)&9O
M<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE
M(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T
M92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!P
M<F5V1&%Y3V97965K*"1D;W<L("1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A
M<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$
M051%7T-!3$-?1D]234%4+"`D;VY/<D)E9F]R92`](&9A;'-E*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@("1D87ES(#T@1&%T
M95]#86QC.CID871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I.PH@("`@
M("`@("1C=7)R7W=E96MD87D@/2!$871E7T-A;&,Z.F1A>4]F5V5E:R@D9&%Y
M+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("!I9B`H)&-U<G)?=V5E:V1A>2`]
M/2`D9&]W*2!["B`@("`@("`@("`@(&EF("@A)&]N3W)"969O<F4I('L*("`@
M("`@("`@("`@("`@("1D87ES("T](#<["B`@("`@("`@("`@('T*("`@("`@
M("!](&5L<V5I9B`H)&-U<G)?=V5E:V1A>2`\("1D;W<I('L*("`@("`@("`@
M("`@)&1A>7,@+3T@-R`M("@D9&]W("T@)&-U<G)?=V5E:V1A>2D["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A>7,@+3T@)&-U<G)?=V5E:V1A
M>2`M("1D;W<["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$871E7T-A;&,Z
M.F1A>7-4;T1A=&4H)&1A>7,L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!D871E(&]F('1H92!N97AT('-P96-I9FEC(&1A>2!O
M9B!T:&4@=V5E:PH@("`@("H@9G)O;2!T:&4@9VEV96X@9&%T90H@("`@("H*
M("`@("`J($!P87)A;2!I;G0@("`@)&1O=R`@("`@=&AE(&1A>2!O9B!T:&4@
M=V5E:R`H,"`](%-U;F1A>2D*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@
M("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO
M;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P
M87)A;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F
M;W)M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`
M<&%R86T@8F]O;"`@("1O;D]R069T97(@(&EF('1R=64@86YD(&1A>7,@87)E
M('-A;64L(')E='5R;G,@8W5R<F5N="!D87D*("`@("`J($!P87)A;2!S=')I
M;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M
M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!N97AT1&%Y3V97965K*"1D;W<L("1D87D@/2`P+"`D;6]N=&@@/2`P
M+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("1F;W)M
M870@/2!$051%7T-!3$-?1D]234%4+"`D;VY/<D%F=&5R(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D
M>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H
M(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"@H@("`@("`@("1D87ES
M(#T@1&%T95]#86QC.CID871E5&]$87ES*"1D87DL("1M;VYT:"P@)'EE87(I
M.PH@("`@("`@("1C=7)R7W=E96MD87D@/2!$871E7T-A;&,Z.F1A>4]F5V5E
M:R@D9&%Y+"`D;6]N=&@L("1Y96%R*3L*"B`@("`@("`@:68@*"1C=7)R7W=E
M96MD87D@/3T@)&1O=RD@>PH@("`@("`@("`@("!I9B`H(21O;D]R069T97(I
M('L*("`@("`@("`@("`@("`@("1D87ES("L](#<["B`@("`@("`@("`@('T*
M("`@("`@("!](&5L<V5I9B`H)&-U<G)?=V5E:V1A>2`^("1D;W<I('L*("`@
M("`@("`@("`@)&1A>7,@*ST@-R`M("@D8W5R<E]W965K9&%Y("T@)&1O=RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&1A>7,@*ST@)&1O=R`M
M("1C=7)R7W=E96MD87D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@1&%T
M95]#86QC.CID87ES5&]$871E*"1D87ES+"`D9F]R;6%T*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@<')E=FEO=7,@<W!E
M8VEF:6,@9&%Y(&]F('1H92!W965K"B`@("`@*B!O;B!O<B!B969O<F4@=&AE
M(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D;W<@
M("`@('1H92!D87D@;V8@=&AE('=E96L@*#`@/2!3=6YD87DI"B`@("`@*B!`
M<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT
M("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y
M96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@
M<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D
M97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('!R979$87E/9E=E
M96M/;D]R0F5F;W)E*"1D;W<L("1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A
M<B`](#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!R971U
M<FX@1&%T95]#86QC.CIP<F5V1&%Y3V97965K*"1D;W<L("1D87DL("1M;VYT
M:"P@)'EE87(L("1F;W)M870L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!T<G5E*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@9&%T92!O9B!T:&4@;F5X="!S<&5C:69I8R!D87D@;V8@=&AE('=E
M96L*("`@("`J(&]N(&]R(&%F=&5R('1H92!G:79E;B!D871E"B`@("`@*@H@
M("`@("H@0'!A<F%M(&EN="`@("`D9&]W("`@("!T:&4@9&%Y(&]F('1H92!W
M965K("@P(#T@4W5N9&%Y*0H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y("`@
M("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@;6]N
M=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@0'!A
M<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET(&9O
M<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J($!P
M87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG(&AO
M=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!N97AT1&%Y3V97965K3VY/<D%F=&5R*"1D;W<L("1D
M87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]2
M34%4*0H@("`@>PH@("`@("`@(')E='5R;B!$871E7T-A;&,Z.FYE>'1$87E/
M9E=E96LH)&1O=RP@)&1A>2P@)&UO;G1H+"`D>65A<BP@)&9O<FUA="P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1R=64I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F('1H
M92!B96=I;FYI;F<@;V8@=V5E:R!F;W(@9VEV96X@9&%T92P*("`@("`J('5S
M:6YG($1!5$5?0T%,0U]"14=)3E]7145+1$%9"B`@("`@*@H@("`@("H@0V%N
M(')E='5R;B!W965K9&%Y(&]F('!R978@;6]N=&@N"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@
M9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN
M="`@("`D;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L
M;V-A;"!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@
M>65A<B!I;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE
M('-T<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@
M9&5S:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!B96=I;D]F5V5E
M:R@D9&%Y(#T@,"P@)&UO;G1H(#T@,"P@)'EE87(@/2`P+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@
M("!["B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D
M>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H
M(#T@1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&1A>2DI('L*("`@("`@("`@("`@)&1A>2`]($1A=&5?
M0V%L8SHZ9&%T94YO=R@G)60G*3L*("`@("`@("!]"B`@("`@("`@)'1H:7-?
M=V5E:V1A>2`]($1A=&5?0V%L8SHZ9&%Y3V97965K*"1D87DL("1M;VYT:"P@
M)'EE87(I.PH@("`@("`@("1I;G1E<G9A;"`]("@W("T@1$%415]#04Q#7T)%
M1TE.7U=%14M$05D@*R`D=&AI<U]W965K9&%Y*2`E(#<["B`@("`@("`@<F5T
M=7)N($1A=&5?0V%L8SHZ9&%Y<U1O1&%T92A$871E7T-A;&,Z.F1A=&54;T1A
M>7,H)&1A>2P@)&UO;G1H+"`D>65A<BD*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("T@)&EN=&5R=F%L+"`D9F]R;6%T*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($9I;F0@=&AE(&UO;G1H(&1A>2!O9B!T:&4@96YD
M(&]F('=E96L@9F]R(&=I=F5N(&1A=&4L"B`@("`@*B!U<VEN9R!$051%7T-!
M3$-?0D5'24Y?5T5%2T1!60H@("`@("H*("`@("`J($-A;B!R971U<FX@=V5E
M:V1A>2!O9B!F;VQL;W=I;F<@;6]N=&@N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&EN="`@("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L
M="!I<R!C=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D
M;6]N=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M
M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I
M;B!F;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L
M('EE87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN
M9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E
M9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@
M0'-T871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!E;F1/9E=E96LH)&1A>2`]
M(#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@
M("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T
M95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E
M3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("`D=&AI<U]W965K9&%Y(#T@
M1&%T95]#86QC.CID87E/9E=E96LH)&1A>2P@)&UO;G1H+"`D>65A<BD["B`@
M("`@("`@)&EN=&5R=F%L(#T@*#8@*R!$051%7T-!3$-?0D5'24Y?5T5%2T1!
M62`M("1T:&ES7W=E96MD87DI("4@-SL*("`@("`@("!R971U<FX@1&%T95]#
M86QC.CID87ES5&]$871E*$1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y+"`D
M;6]N=&@L("1Y96%R*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*R`D:6YT97)V86PL("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1FEN9"!T:&4@;6]N=&@@9&%Y(&]F('1H92!B96=I;FYI;F<@;V8@
M=V5E:R!B969O<F4@9VEV96X@9&%T92P*("`@("`J('5S:6YG($1!5$5?0T%,
M0U]"14=)3E]7145+1$%9"B`@("`@*@H@("`@("H@0V%N(')E='5R;B!W965K
M9&%Y(&]F('!R978@;6]N=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@
M("`D9&%Y("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C
M=7)R96YT(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@
M("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@
M("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R
M(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*
M("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I
M8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M
M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!B96=I;D]F4')E=E=E96LH)&1A>2`]
M(#`L("1M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*
M("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R
M(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@
M("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF
M("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC
M.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@/2!$
M871E7T-A;&,Z.F1A>7-4;T1A=&4H1&%T95]#86QC.CID871E5&]$87ES*"1D
M87DM-RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&UO;G1H+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M>65A<BDL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R59)6TE9"<I.PH*("`@("`@("`D<')E=E]W965K7WEE87(@(#T@<W5B<W1R
M*"1D871E+"`P+"`T*3L*("`@("`@("`D<')E=E]W965K7VUO;G1H(#T@<W5B
M<W1R*"1D871E+"`T+"`R*3L*("`@("`@("`D<')E=E]W965K7V1A>2`@(#T@
M<W5B<W1R*"1D871E+"`V+"`R*3L*"B`@("`@("`@<F5T=7)N($1A=&5?0V%L
M8SHZ8F5G:6Y/9E=E96LH)'!R979?=V5E:U]D87DL("1P<F5V7W=E96M?;6]N
M=&@L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M979?=V5E:U]Y96%R+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($9I;F0@=&AE(&UO;G1H(&1A>2!O9B!T:&4@8F5G:6YN:6YG(&]F('=E96L@
M869T97(@9VEV96X@9&%T92P*("`@("`J('5S:6YG($1!5$5?0T%,0U]"14=)
M3E]7145+1$%9"B`@("`@*@H@("`@("H@0V%N(')E='5R;B!W965K9&%Y(&]F
M('!R978@;6]N=&@N"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y
M("`@("!T:&4@9&%Y(&]F('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT
M(&QO8V%L(&1A>0H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@@("!T:&4@
M;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT:`H@("`@("H@
M0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F;W5R(&1I9VET
M(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE87(*("`@("`J
M($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T<FEN9R!I;F1I8V%T:6YG
M(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S:7)E9"!F;W)M870*("`@
M("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!B96=I;D]F3F5X=%=E96LH)&1A>2`](#`L("1M
M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@
M("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T
M95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H
M96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A
M;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T
M>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E
M3F]W*"<E9"<I.PH@("`@("`@('T*"B`@("`@("`@)&1A=&4@/2!$871E7T-A
M;&,Z.F1A>7-4;T1A=&4H1&%T95]#86QC.CID871E5&]$87ES*"1D87D@*R`W
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D;6]N=&@L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1Y96%R
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G)5DE
M;25D)RD["@H@("`@("`@("1N97AT7W=E96M?>65A<B`@/2!S=6)S='(H)&1A
M=&4L(#`L(#0I.PH@("`@("`@("1N97AT7W=E96M?;6]N=&@@/2!S=6)S='(H
M)&1A=&4L(#0L(#(I.PH@("`@("`@("1N97AT7W=E96M?9&%Y("`@/2!S=6)S
M='(H)&1A=&4L(#8L(#(I.PH*("`@("`@("!R971U<FX@1&%T95]#86QC.CIB
M96=I;D]F5V5E:R@D;F5X=%]W965K7V1A>2P@)&YE>'1?=V5E:U]M;VYT:"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5X=%]W
M965K7WEE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T
M=7)N(&1A=&4@;V8@9FER<W0@9&%Y(&]F(&UO;G1H(&]F(&=I=F5N(&1A=&4*
M("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT
M:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R
M86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R
M;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W
M('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*
M("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`
M<V5E($1A=&5?0V%L8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"D*("`@("`J($!D
M97!R96-A=&5D($UE=&AO9"!D97!R96-A=&5D(&EN(%)E;&5A<V4@,2XU+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@8F5G:6Y/9DUO;G1H*"1M;VYT:"`](#`L
M("1Y96%R(#T@,"P@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("![
M"B`@("`@("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A
M<B`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@
M("`@:68@*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@
M1&%T95]#86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"<P,2<L("1M;VYT:"P@)'EE
M87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!D
M871E(&]F('1H92!F:7)S="!D87D@;V8@<')E=FEO=7,@;6]N=&@@;V8@9VEV
M96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@
M=&AE(&1A>2!O9B!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A
M;"!D87D*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE(&UO;G1H
M+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A
M;2!I;G0@("`@)'EE87(@("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M
M870L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@
M=&\@9F]R;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T
M<FEN9R`@=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S
M964@1&%T95]#86QC.CIB96=I;D]F36]N=&A">5-P86XH*0H@("`@("H@0&1E
M<')E8V%T960@365T:&]D(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C4N,`H@
M("`@("HO"B`@("!F=6YC=&EO;B!B96=I;D]F4')E=DUO;G1H*"1D87D@/2`P
M+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1F;W)M870@/2!$051%7T-!3$-?1D]234%4*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D>65A<BDI('L*("`@("`@("`@("`@)'EE87(@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@?0H@("`@("`@
M(&EF("AE;7!T>2@D;6]N=&@I*2!["B`@("`@("`@("`@("1M;VYT:"`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1D87DI*2!["B`@("`@("`@("`@("1D87D@/2!$871E7T-A;&,Z
M.F1A=&5.;W<H)R5D)RD["B`@("`@("`@?0H@("`@("`@(&EF("@D;6]N=&@@
M/B`Q*2!["B`@("`@("`@("`@("1M;VYT:"TM.PH@("`@("`@("`@("`D9&%Y
M(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D>65A<BTM.PH@
M("`@("`@("`@("`D;6]N=&@@/2`Q,CL*("`@("`@("`@("`@)&1A>2`@(#T@
M,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O
M<FUA="@D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@;&%S="!D87D@;V8@
M<')E=FEO=7,@;6]N=&@@9F]R(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`
M<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D
M969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT
M("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO
M8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y
M96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@
M<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871E(&EN('1H92!D
M97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L8SHZ96YD3V9-;VYT
M:$)Y4W!A;B@I"B`@("`@*B!`9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E
M9"!I;B!296QE87-E(#$N-2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9$]F
M4')E=DUO;G1H*"1D87D@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#
M7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@
M("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@
M("`@("`@('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@
M("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@
M("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D
M9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@
M("`@("!I9B`H)&UO;G1H(#X@,2D@>PH@("`@("`@("`@("`D;6]N=&@M+3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@
M("`@("`D;6]N=&@@/2`Q,CL*("`@("`@("!]"B`@("`@("`@)&1A>2`]($1A
M=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BD["B`@("`@("`@
M<F5T=7)N($1A=&5?0V%L8SHZ9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1Y
M96%R+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M9&%T92!O9B!B96=I;B!O9B!N97AT(&UO;G1H(&]F(&=I=F5N(&1A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@("`@('1H92!D87D@;V8@
M=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@9&%Y"B`@("`@
M*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M;VYT:"P@9&5F875L="!I
M<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y
M96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@9F]R;6%T+"!D969A=6QT
M(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA="!T
M:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D
M871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B!`<V5E($1A=&5?0V%L
M8SHZ8F5G:6Y/9DUO;G1H0GE3<&%N*"D*("`@("`J($!D97!R96-A=&5D($UE
M=&AO9"!D97!R96-A=&5D(&EN(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@8F5G:6Y/9DYE>'1-;VYT:"@D9&%Y(#T@,"P@)&UO;G1H(#T@
M,"P@)'EE87(@/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H
M96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#86QC
M.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H96UP='DH
M)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E7T-A;&,Z.F1A
M=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE;7!T>2@D9&%Y
M*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID871E3F]W*"<E
M9"<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO;G1H(#P@,3(I('L*("`@
M("`@("`@("`@)&UO;G1H*RL["B`@("`@("`@("`@("1D87D@/2`Q.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1Y96%R*RL["B`@("`@("`@("`@
M("1M;VYT:"`](#$["B`@("`@("`@("`@("1D87D@/2`Q.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1D87DL("1M
M;VYT:"P@)'EE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!D871E(&]F('1H92!L87-T(&1A>2!O9B!N97AT(&UO;G1H(&]F
M(&=I=F5N(&1A=&4*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1D87D@
M("`@('1H92!D87D@;V8@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U<G)E;G0@
M;&]C86P@9&%Y"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:"`@('1H92!M
M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`
M<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@
M9F]R;6%T+"!D969A=6QT(&ES(&-U<G)E;G0@;&]C86P@>65A<@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@
M:&]W('1O(&9O<FUA="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('1H92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@
M*B!`<V5E($1A=&5?0V%L8SHZ96YD3V9-;VYT:$)Y4W!A;B@I"B`@("`@*B!`
M9&5P<F5C871E9"!-971H;V0@9&5P<F5C871E9"!I;B!296QE87-E(#$N-2XP
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&5N9$]F3F5X=$UO;G1H*"1D87D@/2`P
M+"`D;6]N=&@@/2`P+"`D>65A<B`](#`L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D9F]R;6%T(#T@1$%415]#04Q#7T9/4DU!5"D*("`@('L*("`@
M("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@
M1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I
M9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D;6]N=&@@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@("`@("`@(&EF("AE
M;7!T>2@D9&%Y*2D@>PH@("`@("`@("`@("`D9&%Y(#T@1&%T95]#86QC.CID
M871E3F]W*"<E9"<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO;G1H(#P@
M,3(I('L*("`@("`@("`@("`@)&UO;G1H*RL["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'EE87(K*SL*("`@("`@("`@("`@)&UO;G1H(#T@,3L*
M("`@("`@("!]"B`@("`@("`@)&1A>2`]($1A=&5?0V%L8SHZ9&%Y<TEN36]N
M=&@H)&UO;G1H+"`D>65A<BD["B`@("`@("`@<F5T=7)N($1A=&5?0V%L8SHZ
M9&%T949O<FUA="@D9&%Y+"`D;6]N=&@L("1Y96%R+"`D9F]R;6%T*3L*("`@
M('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@9&%T92!O9B!T:&4@9FER<W0@
M9&%Y(&]F('1H92!M;VYT:"!I;B!T:&4@;G5M8F5R(&]F(&UO;G1H<PH@("`@
M("H@9G)O;2!T:&4@9VEV96X@9&%T90H@("`@("H*("`@("`J($!P87)A;2!I
M;G0@("`@)&UO;G1H<R`@=&AE(&YU;6)E<B!O9B!M;VYT:',@9G)O;2!T:&4@
M9&%T92!P<F]V:61E9"X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M(%!O<VET:79E(&YU;6)E<G,@9V\@:6YT;R!T:&4@9G5T=7)E+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@3F5G871I=F4@;G5M8F5R<R!G;R!I
M;G1O('1H92!P87-T+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M,"!I<R!T:&4@;6]N=&@@<')E<V5N=&5D(&EN("1M;VYT:"X*("`@("`J($!P
M87)A;2!S=')I;F<@)&UO;G1H("`@=&AE(&UO;G1H+"!D969A=6QT(&ES(&-U
M<G)E;G0@;&]C86P@;6]N=&@*("`@("`J($!P87)A;2!S=')I;F<@)'EE87(@
M("`@=&AE('EE87(@:6X@9F]U<B!D:6=I="!F;W)M870L(&1E9F%U;'0@:7,@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!C=7)R96YT(&QO
M8V%L('EE87(*("`@("`J($!P87)A;2!S=')I;F<@)&9O<FUA="`@=&AE('-T
M<FEN9R!I;F1I8V%T:6YG(&AO=R!T;R!F;W)M870@=&AE(&]U='!U=`H@("`@
M("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T92!I;B!T:&4@9&5S
M:7)E9"!F;W)M870*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-T871I8PH@("`@("H@0'-I;F-E("!-971H;V0@879A:6QA8FQE('-I
M;F-E(%)E;&5A<V4@,2XU+C`*("`@("`J+PH@("`@9G5N8W1I;VX@8F5G:6Y/
M9DUO;G1H0GE3<&%N*"1M;VYT:',@/2`P+"`D;6]N=&@@/2`P+"`D>65A<B`]
M(#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<FUA="`]
M($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@("`@:68@*&5M<'1Y*"1Y
M96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A=&5?0V%L8SHZ9&%T94YO
M=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@*&5M<'1Y*"1M;VYT:"DI
M('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#86QC.CID871E3F]W*"<E
M;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO;G1H<R`^(#`I('L*("`@
M("`@("`@("`@+R\@9G5T=7)E(&UO;G1H"B`@("`@("`@("`@("1T;7!?;6\@
M/2`D;6]N=&@@*R`D;6]N=&AS.PH@("`@("`@("`@("`D;6]N=&@@(#T@)'1M
M<%]M;R`E(#$R.PH@("`@("`@("`@("!I9B`H)&UO;G1H(#T](#`I('L*("`@
M("`@("`@("`@("`@("1M;VYT:"`](#$R.PH@("`@("`@("`@("`@("`@)'EE
M87(@/2`D>65A<B`K(&9L;V]R*"@D=&UP7VUO("T@,2D@+R`Q,BD["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D>65A<B`]("1Y96%R
M("L@9FQO;W(H)'1M<%]M;R`O(#$R*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O('!A<W0@;W(@<')E<V5N="!M;VYT
M:`H@("`@("`@("`@("`D=&UP7VUO(#T@)&UO;G1H("L@)&UO;G1H<SL*("`@
M("`@("`@("`@:68@*"1T;7!?;6\@/B`P*2!["B`@("`@("`@("`@("`@("`O
M+R!S86UE('EE87(*("`@("`@("`@("`@("`@("1M;VYT:"`]("1T;7!?;6\[
M"B`@("`@("`@("`@('T@96QS96EF("@D=&UP7VUO(#T](#`I('L*("`@("`@
M("`@("`@("`@("\O('!R:6]R(&1E8PH@("`@("`@("`@("`@("`@)&UO;G1H
M(#T@,3(["B`@("`@("`@("`@("`@("`D>65A<BTM.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@<V]M92!T:6UE(&EN(&$@<')I
M;W(@>65A<@H@("`@("`@("`@("`@("`@)&UO;G1H(#T@,3(@*R`H)'1M<%]M
M;R`E(#$R*3L*("`@("`@("`@("`@("`@("1Y96%R("`]("1Y96%R("L@9FQO
M;W(H)'1M<%]M;R`O(#$R*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*#$L("1M;VYT:"P@
M)'EE87(L("1F;W)M870I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N
M<R!D871E(&]F('1H92!L87-T(&1A>2!O9B!T:&4@;6]N=&@@:6X@=&AE(&YU
M;6)E<B!O9B!M;VYT:',*("`@("`J(&9R;VT@=&AE(&=I=F5N(&1A=&4*("`@
M("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1M;VYT:',@('1H92!N=6UB97(@
M;V8@;6]N=&AS(&9R;VT@=&AE(&1A=&4@<')O=FED960N"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!0;W-I=&EV92!N=6UB97)S(&=O(&EN=&\@
M=&AE(&9U='5R92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@($YE
M9V%T:79E(&YU;6)E<G,@9V\@:6YT;R!T:&4@<&%S="X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@(#`@:7,@=&AE(&UO;G1H('!R97-E;G1E9"!I
M;B`D;6]N=&@N"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;VYT:"`@('1H92!M
M;VYT:"P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L(&UO;G1H"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1Y96%R("`@('1H92!Y96%R(&EN(&9O=7(@9&EG:70@
M9F]R;6%T+"!D969A=6QT(&ES('1H90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@8W5R<F5N="!L;V-A;"!Y96%R"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1F;W)M870@('1H92!S=')I;F<@:6YD:6-A=&EN9R!H;W<@=&\@9F]R
M;6%T('1H92!O=71P=70*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&1A=&4@:6X@=&AE(&1E<VER960@9F]R;6%T"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J($!S:6YC92`@
M365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-2XP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5N9$]F36]N=&A">5-P86XH)&UO;G1H<R`](#`L("1M
M;VYT:"`](#`L("1Y96%R(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&9O<FUA="`]($1!5$5?0T%,0U]&3U)-050I"B`@("!["B`@("`@
M("`@:68@*&5M<'1Y*"1Y96%R*2D@>PH@("`@("`@("`@("`D>65A<B`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("!]"B`@("`@("`@:68@
M*&5M<'1Y*"1M;VYT:"DI('L*("`@("`@("`@("`@)&UO;G1H(#T@1&%T95]#
M86QC.CID871E3F]W*"<E;2<I.PH@("`@("`@('T*("`@("`@("!I9B`H)&UO
M;G1H<R`^(#`I('L*("`@("`@("`@("`@+R\@9G5T=7)E(&UO;G1H"B`@("`@
M("`@("`@("1T;7!?;6\@/2`D;6]N=&@@*R`D;6]N=&AS.PH@("`@("`@("`@
M("`D;6]N=&@@(#T@)'1M<%]M;R`E(#$R.PH@("`@("`@("`@("!I9B`H)&UO
M;G1H(#T](#`I('L*("`@("`@("`@("`@("`@("1M;VYT:"`](#$R.PH@("`@
M("`@("`@("`@("`@)'EE87(@/2`D>65A<B`K(&9L;V]R*"@D=&UP7VUO("T@
M,2D@+R`Q,BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D>65A<B`]("1Y96%R("L@9FQO;W(H)'1M<%]M;R`O(#$R*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O('!A<W0@
M;W(@<')E<V5N="!M;VYT:`H@("`@("`@("`@("`D=&UP7VUO(#T@)&UO;G1H
M("L@)&UO;G1H<SL*("`@("`@("`@("`@:68@*"1T;7!?;6\@/B`P*2!["B`@
M("`@("`@("`@("`@("`O+R!S86UE('EE87(*("`@("`@("`@("`@("`@("1M
M;VYT:"`]("1T;7!?;6\["B`@("`@("`@("`@('T@96QS96EF("@D=&UP7VUO
M(#T](#`I('L*("`@("`@("`@("`@("`@("\O('!R:6]R(&1E8PH@("`@("`@
M("`@("`@("`@)&UO;G1H(#T@,3(["B`@("`@("`@("`@("`@("`D>65A<BTM
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@<V]M
M92!T:6UE(&EN(&$@<')I;W(@>65A<@H@("`@("`@("`@("`@("`@)&UO;G1H
M(#T@,3(@*R`H)'1M<%]M;R`E(#$R*3L*("`@("`@("`@("`@("`@("1Y96%R
M("`]("1Y96%R("L@9FQO;W(H)'1M<%]M;R`O(#$R*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R
M;6%T*$1A=&5?0V%L8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;6]N=&@L("1Y
M96%R+"`D9F]R;6%T*3L*("`@('T*"B`@("`O*BH*("`@("`J($9I;F0@=&AE
M(&1A>2!O9B!T:&4@=V5E:R!F;W(@=&AE(&9I<G-T(&]F('1H92!M;VYT:"!O
M9B!G:79E;B!D871E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N
M=&@@("!T:&4@;6]N=&@L(&1E9F%U;'0@:7,@8W5R<F5N="!L;V-A;"!M;VYT
M:`H@("`@("H@0'!A<F%M(&EN="`@("`D>65A<B`@("!T:&4@>65A<B!I;B!F
M;W5R(&1I9VET(&9O<FUA="P@9&5F875L="!I<R!C=7)R96YT(&QO8V%L('EE
M87(*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="!N=6UB97(@;V8@=V5E:V1A
M>2!F;W(@=&AE(&9I<G-T(&1A>2P@,#U3=6YD87D*("`@("`J"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!F:7)S=$]F36]N=&A7965K9&%Y*"1M;VYT:"`](#`L("1Y96%R(#T@
M,"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@
M("`@("1Y96%R(#T@1&%T95]#86QC.CID871E3F]W*"<E62<I.PH@("`@("`@
M('T*("`@("`@("!I9B`H96UP='DH)&UO;G1H*2D@>PH@("`@("`@("`@("`D
M;6]N=&@@/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A>4]F5V5E:R@G,#$G+"`D;6]N
M=&@L("1Y96%R*3L*("`@('T*"B`@("`O*BH*("`@("`J($-A;&-U;&%T97,@
M=&AE(&1A=&4@;V8@=&AE($YT:"!W965K9&%Y(&]F('1H92!M;VYT:"P*("`@
M("`J('-U8V@@87,@=&AE('-E8V]N9"!3871U<F1A>2!O9B!*86YU87)Y(#(P
M,#`*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("`@("1W965K("`@('1H92!N
M=6UB97(@;V8@=&AE('=E96L@=&\@9V5T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`H,2`](&9I<G-T+"!E=&,N("!!;'-O(&-A;B!B92`G;&%S
M="<N*0H@("`@("H@0'!A<F%M(&EN="`@("`D9&]W("`@("!T:&4@9&%Y(&]F
M('1H92!W965K("@P(#T@4W5N9&%Y*0H@("`@("H@0'!A<F%M(&EN="`@("`D
M;6]N=&@@("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(@
M("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O
M9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA
M=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S
M(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D9F]R;6%T("!T:&4@<W1R:6YG(&EN9&EC871I;F<@:&]W('1O(&9O<FUA
M="!T:&4@;W5T<'5T"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H
M92!D871E(&EN('1H92!D97-I<F5D(&9O<FUA=`H@("`@("H*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($Y7965K9&%Y3V9-;VYT:"@D=V5E:RP@)&1O=RP@)&UO;G1H+"`D>65A
M<BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]R;6%T(#T@1$%4
M15]#04Q#7T9/4DU!5"D*("`@('L*("`@("`@("!I9B`H:7-?;G5M97)I8R@D
M=V5E:RDI('L*("`@("`@("`@("`@)$1/5S%D87D@/2`H)'=E96L@+2`Q*2`J
M(#<@*R`Q.PH@("`@("`@("`@("`D1$]7,2`@("`]($1A=&5?0V%L8SHZ9&%Y
M3V97965K*"1$3U<Q9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@("`@("`@
M)'=D871E("`@/2`H)'=E96L@+2`Q*2`J(#<@*R`Q("L@*#<@*R`D9&]W("T@
M)$1/5S$I("4@-SL*("`@("`@("`@("`@:68@*"1W9&%T92`^($1A=&5?0V%L
M8SHZ9&%Y<TEN36]N=&@H)&UO;G1H+"`D>65A<BDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`M,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B!$871E7T-A;&,Z.F1A=&5&;W)M870H)'=D871E+"`D
M;6]N=&@L("1Y96%R+"`D9F]R;6%T*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T@96QS96EF("@D=V5E:R`]/2`G;&%S="<@)B8@)&1O=R`\(#<I('L*("`@
M("`@("`@("`@)&QA<W1D87D@/2!$871E7T-A;&,Z.F1A>7-);DUO;G1H*"1M
M;VYT:"P@)'EE87(I.PH@("`@("`@("`@("`D;&%S=&1O=R`]($1A=&5?0V%L
M8SHZ9&%Y3V97965K*"1L87-T9&%Y+"`D;6]N=&@L("1Y96%R*3L*("`@("`@
M("`@("`@)&1I9F8@("`@/2`D9&]W("T@)&QA<W1D;W<["B`@("`@("`@("`@
M(&EF("@D9&EF9B`^(#`I('L*("`@("`@("`@("`@("`@(')E='5R;B!$871E
M7T-A;&,Z.F1A=&5&;W)M870H)&QA<W1D87D@+2`H-R`M("1D:69F*2P@)&UO
M;G1H+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D>65A<BP@)&9O<FUA="D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("!R971U<FX@1&%T95]#86QC.CID871E1F]R;6%T*"1L
M87-T9&%Y("L@)&1I9F8L("1M;VYT:"P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'EE87(L("1F;W)M870I.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("TQ.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=')U92!F;W(@=F%L:60@9&%T92P@9F%L<V4@9F]R(&EN=F%L:60@9&%T90H@
M("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE(&1A>2!O
M9B!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H("`@=&AE
M(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R
M+B`@57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N
M+B`@12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@
M<')I;W(@=&\@,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!I<U9A;&ED1&%T92@D9&%Y+"`D;6]N=&@L
M("1Y96%R*0H@("`@>PH@("`@("`@(&EF("@D>65A<B`\(#`@?'P@)'EE87(@
M/B`Y.3DY*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@:68@*"%C:&5C:V1A=&4H)&UO;G1H+"`D9&%Y+"`D>65A<BDI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=')U92!F;W(@82!L96%P('EE87(L(&5L<V4@9F%L<V4*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H92!Y96%R+B`@57-E('1H92!C
M;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@
M,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P
M,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J"B`@("`@
M*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T871I8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!I<TQE87!996%R*"1Y96%R(#T@,"D*("`@('L*("`@("`@("!I
M9B`H96UP='DH)'EE87(I*2!["B`@("`@("`@("`@("1Y96%R(#T@1&%T95]#
M86QC.CID871E3F]W*"<E62<I.PH@("`@("`@('T*("`@("`@("!I9B`H<')E
M9U]M871C:"@G+UQ$+R<L("1Y96%R*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@D>65A<B`\(#$P,#`I('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'EE87(@/"`Q-3@R*2!["B`@("`@("`@("`@("\O('!R92!'<F5G;W)I
M;R!824E)("T@,34X,@H@("`@("`@("`@("!R971U<FX@*"1Y96%R("4@-"`]
M/2`P*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!P;W-T($=R
M96=O<FEO(%A)24D@+2`Q-3@R"B`@("`@("`@("`@(')E='5R;B`H*"1Y96%R
M("4@-"`]/2`P*2`F)B`H)'EE87(@)2`Q,#`@(3T@,"DI('Q\("@D>65A<B`E
M(#0P,"`]/2`P*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!$
M971E<FUI;F5S(&EF(&=I=F5N(&1A=&4@:7,@82!F=71U<F4@9&%T92!F<F]M
M(&YO=PH@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE
M(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H
M("`@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R+B`@57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V
M97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@
M>65A<G,@<')I;W(@=&\@,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<T9U='5R941A=&4H)&1A>2P@
M)&UO;G1H+"`D>65A<BD*("`@('L*("`@("`@("`D=&AI<U]Y96%R("`]($1A
M=&5?0V%L8SHZ9&%T94YO=R@G)5DG*3L*("`@("`@("`D=&AI<U]M;VYT:"`]
M($1A=&5?0V%L8SHZ9&%T94YO=R@G)6TG*3L*("`@("`@("`D=&AI<U]D87D@
M("`]($1A=&5?0V%L8SHZ9&%T94YO=R@G)60G*3L*"B`@("`@("`@:68@*"1Y
M96%R(#X@)'1H:7-?>65A<BD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*
M("`@("`@("!](&5L<V5I9B`H)'EE87(@/3T@)'1H:7-?>65A<BD@>PH@("`@
M("`@("`@("!I9B`H)&UO;G1H(#X@)'1H:7-?;6]N=&@I('L*("`@("`@("`@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V5I9B`H)&UO
M;G1H(#T]("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@("`@("!I9B`H)&1A
M>2`^("1T:&ES7V1A>2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E=&5R;6EN97,@:68@9VEV96X@9&%T92!I<R!A('!A<W0@9&%T92!F<F]M
M(&YO=PH@("`@("H*("`@("`J($!P87)A;2!I;G0@("`@)&1A>2`@("`@=&AE
M(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H
M("`@=&AE(&UO;G1H"B`@("`@*B!`<&%R86T@:6YT("`@("1Y96%R("`@('1H
M92!Y96%R+B`@57-E('1H92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V
M97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@
M>65A<G,@<')I;W(@=&\@,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O
M;VQE86X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-T
M871I8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<U!A<W1$871E*"1D87DL("1M
M;VYT:"P@)'EE87(I"B`@("!["B`@("`@("`@)'1H:7-?>65A<B`@/2!$871E
M7T-A;&,Z.F1A=&5.;W<H)R59)RD["B`@("`@("`@)'1H:7-?;6]N=&@@/2!$
M871E7T-A;&,Z.F1A=&5.;W<H)R5M)RD["B`@("`@("`@)'1H:7-?9&%Y("`@
M/2!$871E7T-A;&,Z.F1A=&5.;W<H)R5D)RD["@H@("`@("`@(&EF("@D>65A
M<B`\("1T:&ES7WEE87(I('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@
M("`@("`@?2!E;'-E:68@*"1Y96%R(#T]("1T:&ES7WEE87(I('L*("`@("`@
M("`@("`@:68@*"1M;VYT:"`\("1T:&ES7VUO;G1H*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@?2!E;'-E:68@*"1M;VYT
M:"`]/2`D=&AI<U]M;VYT:"D@>PH@("`@("`@("`@("`@("`@:68@*"1D87D@
M/"`D=&AI<U]D87DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@=')U
M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2
M971U<FYS(&YU;6)E<B!O9B!D87ES(&)E='=E96X@='=O(&=I=F5N(&1A=&5S
M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y,2`@("!T:&4@9&%Y
M(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D;6]N=&@Q("!T
M:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(Q("`@=&AE('EE
M87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O9B!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA=&5D('9E<G-I
M;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S(&9O<B!Y96%R
M<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H@0'!A<F%M(&EN="`@("`D9&%Y,B`@
M("!T:&4@9&%Y(&]F('1H92!M;VYT:`H@("`@("H@0'!A<F%M(&EN="`@("`D
M;6]N=&@R("!T:&4@;6]N=&@*("`@("`J($!P87)A;2!I;G0@("`@)'EE87(R
M("`@=&AE('EE87(N("!5<V4@=&AE(&-O;7!L971E('EE87(@:6YS=&5A9"!O
M9B!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&%B8G)E=FEA
M=&5D('9E<G-I;VXN("!%+F<N('5S92`R,#`U+"!N;W0@,#4N"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!$;R!N;W0@861D(&QE861I;F<@,"=S
M(&9O<B!Y96%R<R!P<FEO<B!T;R`Q,#`P+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@86)S;VQU=&4@;G5M8F5R(&]F(&1A>7,@8F5T=V5E;B!T
M:&4@='=O(&1A=&5S+@H@("`@("H@("`@("`@("`@("`@("!)9B!A;B!E<G)O
M<B!O8V-U<G,L("TQ(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B!`<W1A=&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1A=&5$:69F*"1D87DQ+"`D;6]N=&@Q+"`D>65A<C$L("1D87DR+"`D;6]N
M=&@R+"`D>65A<C(I"B`@("!["B`@("`@("`@:68@*"%$871E7T-A;&,Z.FES
M5F%L:61$871E*"1D87DQ+"`D;6]N=&@Q+"`D>65A<C$I*2!["B`@("`@("`@
M("`@(')E='5R;B`M,3L*("`@("`@("!]"B`@("`@("`@:68@*"%$871E7T-A
M;&,Z.FES5F%L:61$871E*"1D87DR+"`D;6]N=&@R+"`D>65A<C(I*2!["B`@
M("`@("`@("`@(')E='5R;B`M,3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&%B<RA$871E7T-A;&,Z.F1A=&54;T1A>7,H)&1A>3$L("1M;VYT:#$L("1Y
M96%R,2D*("`@("`@("`@("`@("`@("`@("T@1&%T95]#86QC.CID871E5&]$
M87ES*"1D87DR+"`D;6]N=&@R+"`D>65A<C(I*3L*("`@('T*"B`@("`O*BH*
M("`@("`J($-O;7!A<F5S('1W;R!D871E<PH@("`@("H*("`@("`J($!P87)A
M;2!I;G0@("`@)&1A>3$@("`@=&AE(&1A>2!O9B!T:&4@;6]N=&@*("`@("`J
M($!P87)A;2!I;G0@("`@)&UO;G1H,2`@=&AE(&UO;G1H"B`@("`@*B!`<&%R
M86T@:6YT("`@("1Y96%R,2`@('1H92!Y96%R+B`@57-E('1H92!C;VUP;&5T
M92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U<V4@,C`P-2P@
M;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@1&\@;F]T
M(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@,3`P,"X*("`@
M("`J($!P87)A;2!I;G0@("`@)&1A>3(@("`@=&AE(&1A>2!O9B!T:&4@;6]N
M=&@*("`@("`J($!P87)A;2!I;G0@("`@)&UO;G1H,B`@=&AE(&UO;G1H"B`@
M("`@*B!`<&%R86T@:6YT("`@("1Y96%R,B`@('1H92!Y96%R+B`@57-E('1H
M92!C;VUP;&5T92!Y96%R(&EN<W1E860@;V8@=&AE"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!A8F)R979I871E9"!V97)S:6]N+B`@12YG+B!U
M<V4@,C`P-2P@;F]T(#`U+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@1&\@;F]T(&%D9"!L96%D:6YG(#`G<R!F;W(@>65A<G,@<')I;W(@=&\@
M,3`P,"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@,"!I9B!T:&4@9&%T
M97,@87)E(&5Q=6%L+B`Q(&EF(&1A=&4@,2!I<R!L871E<BP@+3$@:68*("`@
M("`J("`@("`@("`@("`@("`@9&%T92`Q(&ES(&5A<FQI97(N"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J($!S=&%T:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]M<&%R941A=&5S*"1D87DQ+"`D;6]N=&@Q+"`D>65A
M<C$L("1D87DR+"`D;6]N=&@R+"`D>65A<C(I"B`@("!["B`@("`@("`@)&YD
M87ES,2`]($1A=&5?0V%L8SHZ9&%T951O1&%Y<R@D9&%Y,2P@)&UO;G1H,2P@
M)'EE87(Q*3L*("`@("`@("`D;F1A>7,R(#T@1&%T95]#86QC.CID871E5&]$
M87ES*"1D87DR+"`D;6]N=&@R+"`D>65A<C(I.PH@("`@("`@(&EF("@D;F1A
M>7,Q(#T]("1N9&%Y<S(I('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`H)&YD87ES,2`^("1N9&%Y<S(I(#\@,2`Z
M("TQ.PH@("`@?0I]"@H_/@H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0`
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$S,R`P,C$Q-#``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]33T%0+U-E<G9E<@``````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,S(#`R,#0Q,@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+U-/05`O5'EP90``````````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M,S,@,#(P,#8U`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]T;V]L
M<P``````````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S,R`P,C`S,#0`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]33T%0+U-E<G9E<BYP:'``````````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#<P-S,S(#$P-3$U-#,T,3,S(#`R,3(Q-``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/W!H
M<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS('1H92!C;V1E(&9O<B!T:&4@
M4T]!4"!S97)V97(N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J
M($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S
M:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L
M960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD
M(&ES(&%V86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF
M('EO=0H@*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE
M9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P
M86-K86=E("`@(%-/05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@
M/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H
M;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O
M<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E
M;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T
M:&]R("`@("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-
M86EN=&5N86YC90H@*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H
M='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?
M;VYC92`G4T]!4"]"87-E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]&875L
M="YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O4&%R<V5R+G!H<"<["G)E<75I
M<F5?;VYC92`G4T]!4"]686QU92YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O
M5U-$3"YP:'`G.PH*+RHJ"B`J(%-/05`@4V5R=F5R($-L87-S"B`J"B`J($]R
M:6=I;F%L>2!B87-E9"!O;B!33T%0>#0@8GD@1&EE=')I8V@@07EA;&$*("H@
M:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O;2]S;V%P>#0*("H*("H@0&%C8V5S
M<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA
M;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2
M(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@("!$:65T<FEC:"!!>6%L82`\9&EE
M=')I8VA`9V%N>#0N8V]M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/
M05!?4V5R=F5R(&5X=&5N9',@4T]!4%]"87-E"GL*("`@("\J*@H@("`@("H*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D:7-P871C:%]M
M87`@/2!A<G)A>2@I.R`O+R!C<F5A=&4@96UP='D@9&ES<&%T8V@@;6%P"B`@
M("!V87(@)&1I<W!A=&-H7V]B:F5C=',@/2!A<G)A>2@I.PH@("`@=F%R("1S
M;V%P;V)J96-T(#T@;G5L;#L*("`@('9A<B`D8V%L;%]M971H;V1N86UE(#T@
M;G5L;#L*("`@('9A<B`D8V%L;$AA;F1L97(@/2!N=6QL.PH@("`@=F%R("1C
M86QL5F%L:61A=&EO;B`]('1R=64["@H@("`@+RHJ"B`@("`@*B!!(&QI<W0@
M;V8@:&5A9&5R<R!T:&%T(&%R92!G;VEN9R!T;R!B92!S96YT(&)A8VL@=&\@
M=&AE(&-L:65N="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1R97%U97-T(#T@
M)R<["@H@("`@+RHJ"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<@(%A-3"U%
M;F-O9&EN9PH@("`@("HO"B`@("!V87(@)'AM;%]E;F-O9&EN9R`](%-/05!?
M1$5&055,5%]%3D-/1$E.1SL*("`@('9A<B`D<F5S<&]N<V5?96YC;V1I;F<@
M/2`G551&+3@G.PH*("`@('9A<B`D<F5S=6QT(#T@)W-U8V-E<W-F=6PG.R`O
M+R!F;W(@;&]G9VEN9R!I;G1E<F]P(')E<W5L=',@=&\@9&(*"B`@("!V87(@
M)&5N9'!O:6YT(#T@)R<[("\O('1H92!U<FD@=&\@344A"@H@("`@=F%R("1S
M97)V:6-E(#T@)R<[("\O<V]A<&%C=&EO;B!H96%D97(*("`@('9A<B`D;65T
M:&]D7VYA;65S<&%C92`](&YU;&P["B`@("!V87(@)%]?;W!T:6]N<R`](&%R
M<F%Y*"=U<V4G(#T^("=E;F-O9&5D)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W-T>6QE)R`]/B`G<G!C)RP*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)W!A<F%M971E<G,G(#T^(#`I.PH*("`@(&9U;F-T:6]N(%-/05!?
M4V5R=F5R*"1O<'1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@("!I;FE?<V5T
M*"=T<F%C:U]E<G)O<G,G+"`Q*3L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S
M92@G4V5R=F5R)RD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI
M('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=U<V4G72DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W5S92==(#T@)&]P
M=&EO;G-;)W5S92==.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG<W1Y;&4G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/2`D;W!T:6]N<ULG<W1Y;&4G73L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;
M)W!A<F%M971E<G,G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P
M=&EO;G-;)W!A<F%M971E<G,G72`]("1O<'1I;VYS6R=P87)A;65T97)S)UT[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@87-S=6UE('=E
M(&5N8V]D92!W:71H('-E8W1I;VX@-0H@("`@("`@("1T:&ES+3Y?<V5C=&EO
M;C4@/2!T<G5E.PH@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=U<V4G
M73T])VQI=&5R86PG*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5C=&EO;C4@
M/2!F86QS93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!%<G)O
M<B!H86YD;&5R(&9O<B!E<G)O<G,@=&AA="!H87!P96X@:6X@<')O>&EE9"!M
M971H;V1S+@H@("`@("H*("`@("`J(%1O(&%L=V%Y<R!R971U<FX@82!V86QI
M9"!33T%0(')E<W!O;G-E(&5V96X@;VX@97)R;W)S('1H870@9&]N)W0@:&%P
M<&5N"B`@("`@*B!I;B!T:&ES(&-O9&4L('1H92!E<G)O<G,@87)E(&-A=&-H
M960L('1R86YS9F]R;65D('1O(&$@4T]!4"!F875L="!A;F0*("`@("`J(&EM
M;65D:6%T96QY('-E;G0@=&\@=&AE(&-L:65N="X*("`@("`J"B`@("`@*B!`
M<V5E(&AT='`Z+R]W=W<N<&AP+FYE="]S971?97)R;W)?:&%N9&QE<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!?97)R;W)(86YD;&5R*"1E<G)N;RP@)&5R<FUS
M9RP@)&9I;&5N86UE+"`D;&EN96YU;2P@)'9A<G,I"B`@("!["B`@("`@("`@
M+RH@5&AE(&5R<F]R(&AA;F1L97(@<VAO=6QD(&EG;F]R92`G,"<@97)R;W)S
M+"!E9RX@:&ED9&5N(&)Y($`@+2!S964*("`@("`@("`@*B!T:&4@<V5T7V5R
M<F]R7VAA;F1L97(@;6%N=6%L('!A9V4N("AT:&%N:W,@=&\@06QA;B!+;F]W
M;&5S*2X@*B\*("`@("`@("!I9B`H(21E<G)N;R!\?"`D97)R;F\@/3T@15].
M3U1)0T4I('L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/F9A=6QT(#TF(&YE=R!33T%07T9A=6QT*"1E<G)M<V<L("=3
M97)V97(G+"`G4$A0)RP@(D5R<FYO.B`D97)R;F]<;D9I;&5N86UE.B`D9FEL
M96YA;65<;DQI;F5N;SH@)&QI;F5N=6U<;B(I.PH*("`@("`@("`D=&AI<RT^
M7W-E;F1297-P;VYS92@I.PH@("`@("`@(&5X:70["B`@("!]"@H@("`@9G5N
M8W1I;VX@7V=E=$-O;G1E;G1%;F-O9&EN9R@D8V]N=&5N=%]T>7!E*0H@("`@
M>PH@("`@("`@("\J($=E="!T:&4@8VAA<F%C=&5R(&5N8V]D:6YG(&]F('1H
M92!I;F-O;6EN9R!R97%U97-T('1R96%T(&EN8V]M:6YG"B`@("`@("`@("H@
M9&%T82!A<R!55$8M."!I9B!N;R!E;F-O9&EN9R!S970N("HO"B`@("`@("`@
M)'1H:7,M/GAM;%]E;F-O9&EN9R`]("=55$8M."<["B`@("`@("`@:68@*'-T
M<G!O<R@D8V]N=&5N=%]T>7!E+"`G/2<I*2!["B`@("`@("`@("`@("1E;F,@
M/2!S=')T;W5P<&5R*'-T<E]R97!L86-E*"<B)RP@)R<L('-U8G-T<BAS=')S
M='(H)&-O;G1E;G1?='EP92P@)STG*2P@,2DI*3L*("`@("`@("`@("`@:68@
M*"%I;E]A<G)A>2@D96YC+"`D=&AI<RT^7V5N8V]D:6YG<RDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@)&5N8SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*"B`@("`O*BH*("`@("`J(%!A
M<G-E<R!R97%U97-T(&%N9"!P;W-T<R!R97-P;VYS92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@<V5R=FEC92@D9&%T82P@)&5N9'!O:6YT(#T@)R<L("1T97-T
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)')E<W!O;G-E(#T@;G5L;#L*("`@
M("`@("`D871T86-H;65N=',@/2!A<G)A>2@I.PH@("`@("`@("1U<V5%;F-O
M9&EN9R`]("=$24U%)SL*"B`@("`@("`@+RH@1FEG=7)E(&]U="!O=7(@96YD
M<&]I;G0N("HO"B`@("`@("`@)'1H:7,M/F5N9'!O:6YT(#T@)&5N9'!O:6YT
M.PH@("`@("`@(&EF("@A)'1E<W0@)B8@(21T:&ES+3YE;F1P;VEN="D@>PH@
M("`@("`@("`@("`O*B!792=L;"!T<GD@=&\@8G5I;&0@;W5R(&5N9'!O:6YT
M+B`J+PH@("`@("`@("`@("`D=&AI<RT^96YD<&]I;G0@/2`G:'1T<#HO+R<@
M+B`D7U-%4E9%4ELG4T525D527TY!344G73L*("`@("`@("`@("`@:68@*"1?
M4T525D526R=315)615)?4$]25"==*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^96YD<&]I;G0@+CT@)SHG("X@)%]315)615);)U-%4E9%4E]03U)4)UT[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/F5N9'!O:6YT("X]
M("1?4T525D526R=30U))4%1?3D%-12==.PH@("`@("`@('T*"B`@("`@("`@
M+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I;F<@;V8@=&AE(&EN8V]M:6YG
M(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@("`@("`@*B!D871A(&%S(%54
M1BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*("`@("`@("!I9B`H:7-S970H
M)%]315)615);)T-/3E1%3E1?5%E012==*2D@>PH@("`@("`@("`@("!I9B`H
M<W1R8V%S96-M<"@D7U-%4E9%4ELG0T].5$5.5%]465!%)UTL("=A<'!L:6-A
M=&EO;B]D:6UE)RD@/3T@,"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]D
M96-O9&5$24U%365S<V%G92@D9&%T82P@)&AE861E<G,L("1A='1A8VAM96YT
M<RD["B`@("`@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["B`@
M("`@("`@("`@('T@96QS96EF("AS=')I<W1R*"1?4T525D526R=#3TY414Y4
M7U194$4G72P@)VUU;'1I<&%R="]R96QA=&5D)RDI('L*("`@("`@("`@("`@
M("`@("\J(%1H:7,@:7,@82!M:6UE(&UE<W-A9V4L(&QE="=S(&1E8V]D92!I
M="X@*B\*("`@("`@("`@("`@("`@("1D871A(#T@)T-O;G1E;G0M5'EP93H@
M)R`N"B`@("`@("`@("`@("`@("`@("`@<W1R:7!S;&%S:&5S*"1?4T525D52
M6R=#3TY414Y47U194$4G72D@+@H@("`@("`@("`@("`@("`@("`@(")<<EQN
M7')<;B(@+B`D9&%T83L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E
M36EM94UE<W-A9V4H)&1A=&$L("1H96%D97)S+"`D871T86-H;65N=',I.PH@
M("`@("`@("`@("`@("`@)'5S945N8V]D:6YG(#T@)TUI;64G.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@A:7-S970H)&AE861E<G-;)V-O;G1E
M;G0M='EP92==*2D@>PH@("`@("`@("`@("`@("`@)&AE861E<G-;)V-O;G1E
M;G0M='EP92==(#T@<W1R:7!S;&%S:&5S*"1?4T525D526R=#3TY414Y47U19
M4$4G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"$D=&AI<RT^
M9F%U;'0@)B8*("`@("`@("`@("`@("`@("$D=&AI<RT^7V=E=$-O;G1E;G1%
M;F-O9&EN9R@D:&5A9&5R<ULG8V]N=&5N="UT>7!E)UTI*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.
M0T]$24Y'.PH@("`@("`@("`@("`@("`@+RH@1F]U;F0@96YC;V1I;F<@=V4@
M9&]N)W0@=6YD97)S=&%N9#L@<F5T=7)N(&$@9F%U;'0N("HO"B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=5;G-U<'!O<G1E9"!E
M;F-O9&EN9RP@=7-E(&]N92!O9B!)4T\M.#@U.2TQ+"!54RU!4T-)22P@551&
M+3@G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@+RH@268@=&AI<R!I<R!N;W0@82!03U-4('=I=&@@0V]N
M=&5N="U4>7!E('1E>'0O>&UL+"!T<GD@=&\@<F5T=7)N(&$*("`@("`@("`@
M*B!74T1,(&9I;&4N("HO"B`@("`@("`@:68@*"$D=&AI<RT^9F%U;'0@)B8@
M(21T97-T("8F"B`@("`@("`@("`@("@D7U-%4E9%4ELG4D5154535%]-151(
M3T0G72`A/2`G4$]35"<@?'P*("`@("`@("`@("`@('-T<FYC;7`H)&AE861E
M<G-;)V-O;G1E;G0M='EP92==+"`G=&5X="]X;6PG+"`X*2`A/2`P*2D@>PH@
M("`@("`@("`@("`O*B!4:&ES(&ES(&YO="!P;W-S:6)L>2!A('9A;&ED(%-/
M05`@<F5Q=65S="P@=')Y('1O(')E='5R;B!A(%=31$P*("`@("`@("`@("`@
M("H@9FEL92X@*B\*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L
M="@G26YV86QI9"!33T%0(')E<75E<W0L(&UU<W0@8F4@4$]35"!W:71H(&-O
M;G1E;G0M='EP93H@=&5X="]X;6PL(&=O=#H@)R`N("AI<W-E="@D:&5A9&5R
M<ULG8V]N=&5N="UT>7!E)UTI(#\@)&AE861E<G-;)V-O;G1E;G0M='EP92==
M(#H@)TYO=&AI;F<A)RDL("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"$D=&AI<RT^9F%U;'0I('L*("`@("`@("`@("`@+RH@
M)')E<W!O;G-E(&ES(&$@4T]!4%]-<V<@;V)J96-T+B`J+PH@("`@("`@("`@
M("`D<V]A<%]M<V<@/2`D=&AI<RT^<&%R<V5297%U97-T*"1D871A+"`D871T
M86-H;65N=',I.PH*("`@("`@("`@("`@+RH@2&%N9&QE($UI;64@;W(@1$E-
M12!E;F-O9&EN9RX@*B\*("`@("`@("`@("`@+RH@5$]$3SH@1$E-12!D96-O
M9&EN9R!S:&]U;&0@;6]V92!T;R!T:&4@=')A;G-P;W)T+"!D;R!I="!H97)E
M"B`@("`@("`@("`@("`J(&9O<B!N;W<@86YD(&9O<B!E87-E(&]F(&=E='1I
M;F<@:70@9&]N92X@*B\*("`@("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3Y?
M7V%T=&%C:&UE;G1S*2D@>PH@("`@("`@("`@("`@("`@:68@*"1U<V5%;F-O
M9&EN9R`]/2`G36EM92<I('L*("`@("`@("`@("`@("`@("`@("`D<V]A<%]M
M<V<@/2`D=&AI<RT^7VUA:V5-:6UE365S<V%G92@D<V]A<%]M<V<I.PH@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`O+R!D
M969A=6QT(&ES(&1I;64*("`@("`@("`@("`@("`@("`@("`D<V]A<%]M<V<@
M/2`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<I.PH@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3YH96%D97)S6R=#;VYT96YT+51Y<&4G72`]
M("=A<'!L:6-A=&EO;B]D:6UE)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E4V]A<$9A=6QT
M*"1S;V%P7VUS9RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<V]A<%]M<V<I*2!["B`@("`@
M("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M<V=;)V)O9'DG73L*("`@
M("`@("`@("`@("`@(&EF("AC;W5N="@D<V]A<%]M<V=;)VAE861E<G,G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<R`]("1S;V%P
M7VUS9ULG:&5A9&5R<R==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?
M;7-G.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M7W-E;F1297-P;VYS92@D<F5S<&]N<V4I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5N9',@=&AE(&9I;F%L($A45%`@<F5S<&]N<V4@=&\@=&AE(&-L:65N
M="P@:6YC;'5D:6YG('1H92!(5%10(&AE861E<@H@("`@("H@86YD('1H92!(
M5%10(&)O9'DN"B`@("`@*@H@("`@("H@268@86X@97)R;W(@:&%P<&5N960L
M(&ET(')E='5R;G,@82!33T%0(&9A=6QT(&EN<W1E860@;V8@=&AE(')E<W!O
M;G-E"B`@("`@*B!B;V1Y+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)')E<W!O;G-E("!4:&4@<F5S<&]N<V4@8F]D>2X*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W-E;F1297-P;VYS92@D<F5S<&]N<V4@/2`G)RD*("`@('L*("`@
M("`@("`O*B!-86ME(&1I<W1I;F-T:6]N(&)E='=E96X@=&AE(&1I9F9E<F5N
M="!305!)<RP@<G5N;FEN9R!02%`@87,@0T=)(&]R"B`@("`@("`@("H@87,@
M82!M;V1U;&4N("HO"B`@("`@("`@:68@*'-T<FES='(H<&AP7W-A<&E?;F%M
M92@I+"`G8V=I)RD@/3T](#`I('L*("`@("`@("`@("`@)&AD<G-?='EP92`]
M("=3=&%T=7,Z)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D:&1R
M<U]T>7!E(#T@)TA45%`O,2XQ)SL*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&AI<RT^9F%U;'0I('L*("`@("`@("`@("`@)&AD<G,@/2`B)&AD<G-?='EP
M92`U,#`@4V]A<"!&875L=%QR7&XB.PH@("`@("`@("`@("`D<F5S<&]N<V4@
M/2`D=&AI<RT^9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D:&1R<R`]("(D:&1R<U]T>7!E(#(P,"!/2UQR7&XB.PH@
M("`@("`@('T*("`@("`@("!H96%D97(H)&AD<G,I.PH*("`@("`@("`D=&AI
M<RT^:&5A9&5R<ULG4V5R=F5R)UT@/2!33T%07TQ)0E)!4EE?3D%-13L*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3YH96%D97)S6R=#;VYT96YT+51Y<&4G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G-;)T-O;G1E;G0M5'EP
M92==(#T@)W1E>'0O>&UL.R!C:&%R<V5T/2<@+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/G)E<W!O;G-E7V5N8V]D:6YG.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^:&5A9&5R<ULG0V]N=&5N="U,96YG=&@G72`]('-T<FQE;B@D<F5S
M<&]N<V4I.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^:&5A9&5R<R!A<R`D
M:R`]/B`D=BD@>PH@("`@("`@("`@("!H96%D97(H(B1K.B`D=B(I.PH@("`@
M("`@("`@("`D:&1R<R`N/2`B)&LZ("1V7')<;B(["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^<F5S<&]N<V4@/2`D:&1R<R`N(")<<EQN(B`N("1R97-P
M;VYS93L*("`@("`@("!P<FEN="`D<F5S<&]N<V4["B`@("!]"@H@("`@9G5N
M8W1I;VX@)F-A;&Q-971H;V0H)&UE=&AO9&YA;64L("8D87)G<RD*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/F-A;&Q(86YD;&5R*2!["B`@("`@("`@("`@
M(')E='5R;B!`8V%L;%]U<V5R7V9U;F-?87)R87DH)'1H:7,M/F-A;&Q(86YD
M;&5R+"!A<G)A>2@D;65T:&]D;F%M92P@)&%R9W,I*3L*("`@("`@("!]"@H@
M("`@("`@('-E=%]E<G)O<E]H86YD;&5R*&%R<F%Y*"1T:&ES+"`G7V5R<F]R
M2&%N9&QE<B<I*3L*"B`@("`@("`@:68@*"1A<F=S*2!["B`@("`@("`@("`@
M("\J($-A;&P@;65T:&]D('=I=&@@<&%R86UE=&5R<RX@*B\*("`@("`@("`@
M("`@:68@*&ES<V5T*"1T:&ES+3YS;V%P;V)J96-T*2`F)B!I<U]O8FIE8W0H
M)'1H:7,M/G-O87!O8FIE8W0I*2!["B`@("`@("`@("`@("`@("`D<F5T(#T@
M0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*&%R<F%Y*"8D=&AI<RT^<V]A<&]B:F5C
M="P@)&UE=&AO9&YA;64I+"`D87)G<RD["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D<F5T(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y
M*"1M971H;V1N86UE+"`D87)G<RD["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`O*B!#86QL(&UE=&AO9"!W:71H;W5R('!A
M<F%M971E<G,N("HO"B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'1H:7,M
M/G-O87!O8FIE8W0I*2!["B`@("`@("`@("`@("`@("`D<F5T(#T@0&-A;&Q?
M=7-E<E]F=6YC*&%R<F%Y*"8D=&AI<RT^<V]A<&]B:F5C="P@)&UE=&AO9&YA
M;64I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R
M970@/2!`8V%L;%]U<V5R7V9U;F,H)&UE=&AO9&YA;64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("!R97-T;W)E7V5R<F]R7VAA;F1L97(H
M*3L*"B`@("`@("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!#<F5A=&5S(%-/05!?5F%L=64@;V)J96-T('=I=&@@<F5T=7)N('9A;'5E
M<R!F<F]M(&UE=&AO9"X*("`@("`J(%5S97,@;65T:&]D('-I9VYA='5R92!T
M;R!D971E<FUI;F4@='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@8G5I;&12
M97-U;'0H)B1M971H;V1?<F5S<&]N<V4L("8D<F5T=7)N7W1Y<&4L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D<F5T=7)N7VYA;64@/2`G<F5T=7)N)RP@
M)&YA;65S<&%C92`]("<G*0H@("`@>PH@("`@("`@(&EF("AI<U]A*"1M971H
M;V1?<F5S<&]N<V4L("=33T%07U9A;'5E)RDI('L*("`@("`@("`@("`@)')E
M='5R;E]V86P@/2!A<G)A>2@D;65T:&]D7W)E<W!O;G-E*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)')E='5R;E]T>7!E
M*2`F)B!I<U]A<G)A>2@D;65T:&]D7W)E<W!O;G-E*2D@>PH@("`@("`@("`@
M("`@("`@)&D@/2`P.PH*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R971U
M<FY?='EP92!A<R`D:V5Y(#T^("1T>7!E*2!["B`@("`@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;65R:6,H)&ME>2DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&ME>2`]("=I=&5M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@:68@*&ES7V$H)&UE=&AO9%]R97-P;VYS95LD
M:5TL)W-O87!?=F%L=64G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<F5T=7)N7W9A;%M=(#T@)&UE=&AO9%]R97-P;VYS95LD:2LK73L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<6X@/28@;F5W(%%.86UE*"1K97DL("1N86UE<W!A8V4I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T=7)N7W9A;%M=(#TF(&YE=R!33T%07U9A
M;'5E*"1Q;BT^9G%N*"DL("1T>7!E+"`D;65T:&]D7W)E<W!O;G-E6R1I*RM=
M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H:7-?87)R
M87DH)')E='5R;E]T>7!E*2D@>PH@("`@("`@("`@("`@("`@("`@("1K97ES
M(#T@87)R87E?:V5Y<R@D<F5T=7)N7W1Y<&4I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-?;G5M97)I8R@D:V5Y<ULP72DI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@)')E='5R;E]N86UE(#T@)&ME>7-;,%T["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1V86QU97,@/2!A
M<G)A>5]V86QU97,H)')E='5R;E]T>7!E*3L*("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N7W1Y<&4@/2`D=F%L=65S6S!=.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@)'%N(#TF(&YE=R!13F%M92@D<F5T=7)N7VYA
M;64L("1N86UE<W!A8V4I.PH@("`@("`@("`@("`@("`@)')E='5R;E]V86P@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@)')E='5R;E]V86Q;72`])B!N
M97<@4T]!4%]686QU92@D<6XM/F9Q;B@I+"`D<F5T=7)N7W1Y<&4L("1M971H
M;V1?<F5S<&]N<V4I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D<F5T=7)N7W9A;#L*("`@('T*"B`@("!F=6YC=&EO;B!P87)S
M95)E<75E<W0H)&1A=&$@/2`G)RP@)&%T=&%C:&UE;G1S(#T@;G5L;"D*("`@
M('L*("`@("`@("`O*B!087)S92!R97-P;VYS92P@9V5T(%-/05!?4&%R<V5R
M(&]B:F5C="X@*B\*("`@("`@("`D<&%R<V5R(#TF(&YE=R!33T%07U!A<G-E
M<B@D9&%T82P@)'1H:7,M/GAM;%]E;F-O9&EN9RP@)&%T=&%C:&UE;G1S*3L*
M("`@("`@("`O*B!)9B!F875L="!O8V-U<G)E9"!D=7)I;F<@;65S<V%G92!P
M87)S:6YG+B`J+PH@("`@("`@(&EF("@D<&%R<V5R+3YF875L="D@>PH@("`@
M("`@("`@("`D=&AI<RT^9F%U;'0@/2`D<&%R<V5R+3YF875L=#L*("`@("`@
M("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("`O*B!(86YD
M;&4@;65S<V%G92!H96%D97)S+B`J+PH@("`@("`@("1R97%U97-T7VAE861E
M<G,@/2`D<&%R<V5R+3YG971(96%D97)S*"D["B`@("`@("`@)&AE861E<E]R
M97-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1R97%U97-T7VAE861E
M<G,I('L*("`@("`@("`@("`@:68@*"%I<U]A*"1R97%U97-T7VAE861E<G,L
M("=33T%07U9A;'5E)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H)U!A<G-E<B!D:60@;F]T(')E='5R;B!33T%07U9A;'5E
M(&]B:F5C=#H@)R`N("1R97%U97-T7VAE861E<G,L("<G+"`G)RP@)U-E<G9E
M<B<I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1R97%U97-T7VAE861E<G,M/G9A;'5E*2![
M"B`@("`@("`@("`@("`@("`O*B!(86YD;&4@:&5A9&5R<R!N;W<N("HO"B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D<F5Q=65S=%]H96%D97)S+3YV86QU
M92!A<R`D:&5A9&5R7W9A;"D@>PH@("`@("`@("`@("`@("`@("`@("1F7V5X
M:7-T<R`]("1T:&ES+3YV86QI9&%T94UE=&AO9"@D:&5A9&5R7W9A;"T^;F%M
M92P@)&AE861E<E]V86PM/FYA;65S<&%C92D["@H@("`@("`@("`@("`@("`@
M("`@("\J(%1/1$\Z('1H:7,@9&]E<R!N;W0@=&%K92!I;G1O(&%C8V]U;G0@
M;65S<V%G92!R;W5T:6YG"B`@("`@("`@("`@("`@("`@("`@("H@>65T+B`J
M+PH@("`@("`@("`@("`@("`@("`@("1M>6%C=&]R(#T@(21H96%D97)?=F%L
M+3YA8W1O<B!\?`H@("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R7W9A
M;"T^86-T;W(@/3T@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O
M86-T;W(O;F5X="<@?'P*("`@("`@("`@("`@("`@("`@("`@("`@)&AE861E
M<E]V86PM/F%C=&]R(#T]("1T:&ES+3YE;F1P;VEN=#L*"B`@("`@("`@("`@
M("`@("`@("`@:68@*"$D9E]E>&ES=',@)B8@)&AE861E<E]V86PM/FUU<W1U
M;F1E<G-T86YD("8F("1M>6%C=&]R*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TD@9&]N7"=T('5N9&5R<W1A
M;F0@:&5A9&5R("<@+B`D:&5A9&5R7W9A;"T^;F%M92P@)R<L("<G+"`G375S
M=%5N9&5R<W1A;F0G*3L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("`@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("`@("`O*B!792!O;FQY(&AA;F1L92!T:&4@:&5A9&5R(&EF(&ET)W,@9F]R
M('5S+B`J+PH@("`@("`@("`@("`@("`@("`@("1I<V]K(#T@)&9?97AI<W1S
M("8F("1M>6%C=&]R.PH*("`@("`@("`@("`@("`@("`@("!I9B`H)&ES;VLI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@0V%L;"!O=7(@:&5A9&5R
M(&YO=R$@*B\*("`@("`@("`@("`@("`@("`@("`@("`@)&AE861E<E]M971H
M;V0@/2`D:&5A9&5R7W9A;"T^;F%M93L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&AE861E<E]D871A(#T@87)R87DH)'1H:7,M/E]D96-O9&4H)&AE861E
M<E]V86PI*3L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@268@=&AE<F4@
M87)E('!A<F%M971E<G,@=&\@<&%S<RX@*B\*("`@("`@("`@("`@("`@("`@
M("`@("`@)&AR(#TF("1T:&ES+3YC86QL365T:&]D*"1H96%D97)?;65T:&]D
M+"`D:&5A9&5R7V1A=&$I.PH@("`@("`@("`@("`@("`@("`@("`@("`D:&5A
M9&5R7W)E<W5L='-;72`](&%R<F%Y7W-H:69T*"1T:&ES+3YB=6EL9%)E<W5L
M="@D:'(L("1T:&ES+3YR971U<FY?='EP92P@)&AE861E<E]M971H;V0L("1H
M96%D97)?=F%L+3YN86UE<W!A8V4I*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("\J($AA;F1L92!T:&4@;65T:&]D(&-A;&PN("HO"B`@("`@("`@
M+RH@179A;'5A=&4@;65S<V%G92P@9V5T=&EN9R!B86-K(&$@4T]!4%]686QU
M92!O8FIE8W0N("HO"B`@("`@("`@)'1H:7,M/F-A;&Q?;65T:&]D;F%M92`]
M("1T:&ES+3YM971H;V1N86UE(#T@)'!A<G-E<BT^<F]O=%]S=')U8W1?;F%M
M95LP73L*"B`@("`@("`@+RH@1FEG=7)E(&]U="!T:&4@;65T:&]D(&YA;65S
M<&%C92X@*B\*("`@("`@("`D=&AI<RT^;65T:&]D7VYA;65S<&%C92`]("1P
M87)S97(M/FUE<W-A9V5;)'!A<G-E<BT^<F]O=%]S=')U8W1;,%U=6R=N86UE
M<W!A8V4G73L*"B`@("`@("`@:68@*"1T:&ES+3Y?=W-D;"D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH)'1H:7,M/E]W<V1L+3YX
M<V0I.PH@("`@("`@("`@("`D9&%T84AA;F1L97(@/2`D=&AI<RT^7W=S9&PM
M/F=E=$1A=&%(86YD;&5R*"1T:&ES+3YM971H;V1N86UE+"`D=&AI<RT^;65T
M:&]D7VYA;65S<&%C92D["B`@("`@("`@("`@(&EF("@D9&%T84AA;F1L97(I
M"B`@("`@("`@("`@("`@("`D=&AI<RT^8V%L;%]M971H;V1N86UE(#T@)'1H
M:7,M/FUE=&AO9&YA;64@/2`D9&%T84AA;F1L97(["@H@("`@("`@("`@("`D
M=&AI<RT^7W!O<G1.86UE(#T@)'1H:7,M/E]W<V1L+3YG9710;W)T3F%M92@D
M=&AI<RT^;65T:&]D;F%M92D["B`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1T:&ES+3Y?<&]R=$YA;64I*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D=&AI<RT^7W!O<G1.86UE*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("`D;W!$871A(#T@)'1H:7,M/E]W
M<V1L+3YG971/<&5R871I;VY$871A*"1T:&ES+3Y?<&]R=$YA;64L("1T:&ES
M+3YM971H;V1N86UE*3L*("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)&]P1&%T82DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"1O<$1A=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@/2`D;W!$871A6R=S='EL
M92==.PH@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=U<V4G72`]("1O
M<$1A=&%;)V]U='!U="==6R=U<V4G73L*("`@("`@("`@("`@)'1H:7,M/E]?
M;W!T:6]N<ULG<&%R86UE=&5R<R==(#T@)&]P1&%T85LG<&%R86UE=&5R<R==
M.PH@("`@("`@('T*"B`@("`@("`@+RH@1&]E<R!M971H;V0@97AI<W0_("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^;65T:&]D;F%M92!\?`H@("`@("`@("`@
M("`A)'1H:7,M/G9A;&ED871E365T:&]D*"1T:&ES+3YM971H;V1N86UE+"`D
M=&AI<RT^;65T:&]D7VYA;65S<&%C92DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@G;65T:&]D("(G("X@)'1H:7,M/FUE=&AO9%]N
M86UE<W!A8V4@+B`D=&AI<RT^;65T:&]D;F%M92`N("<B(&YO="!D969I;F5D
M(&EN('-E<G9I8V4G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@("`@("!I9B`H(21R97%U97-T
M7W9A;"`]("1P87)S97(M/F=E=%)E<W!O;G-E*"DI('L*("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@A:7-?82@D<F5Q
M=65S=%]V86PL("=33T%07U9A;'5E)RDI('L*("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@G4&%R<V5R(&1I9"!N;W0@<F5T=7)N(%-/05!?
M5F%L=64@;V)J96-T.B`G("X@)')E<75E<W1?=F%L+"`G)RP@)R<L("=397)V
M97(G*3L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*("`@
M("`@("`O*B!697)I9GD@=&AA="!33T%07U9A;'5E(&]B:F5C=',@:6X@<F5Q
M=65S="!M871C:"!T:&4@;65T:&]D<PH@("`@("`@("`J('-I9VYA='5R92X@
M*B\*("`@("`@("!I9B`H(21T:&ES+3YV97)I9GE-971H;V0H)')E<75E<W1?
M=F%L*2D@>PH@("`@("`@("`@("`O*B!V97)I9GE-971H;V0H*2!C<F5A=&5S
M('1H92!F875L="X@*B\*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H*("`@("`@("`O*B!.965D('1O('-E="!S<&5C:6%L(&5R<F]R(&1E
M=&5C=&EO;B!I;G-I9&4@=&AE('9A;'5E(&-L87-S('1O"B`@("`@("`@("H@
M9&EF9F5R96YT:6%T92!B971W965N(&YO('!A<F%M<R!P87-S960L(&%N9"!A
M;B!E<G)O<B!D96-O9&EN9RX@*B\*("`@("`@("`D<F5Q=65S=%]D871A(#T@
M)'1H:7,M/E]?9&5C;V1E4F5Q=65S="@D<F5Q=65S=%]V86PI.PH@("`@("`@
M(&EF("A014%2.CII<T5R<F]R*"1R97%U97-T7V1A=&$I*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1R97%U97-T7V1A
M=&$I.PH@("`@("`@('T*("`@("`@("`D;65T:&]D7W)E<W!O;G-E(#TF("1T
M:&ES+3YC86QL365T:&]D*"1T:&ES+3YC86QL7VUE=&AO9&YA;64L("1R97%U
M97-T7V1A=&$I.PH*("`@("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG<&%R
M86UE=&5R<R==('Q\"B`@("`@("`@("`@("$D;65T:&]D7W)E<W!O;G-E('Q\
M"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT]/2=R<&,G
M*2!["B`@("`@("`@("`@("\J($=E="!T:&4@;65T:&]D(')E<W5L="X@*B\*
M("`@("`@("`@("`@:68@*&ES7VYU;&PH)&UE=&AO9%]R97-P;VYS92DI('L*
M("`@("`@("`@("`@("`@("1R971U<FY?=F%L(#T@;G5L;#L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R971U<FY?=F%L(#T@)'1H
M:7,M/F)U:6QD4F5S=6QT*"1M971H;V1?<F5S<&]N<V4L("1T:&ES+3YR971U
M<FY?='EP92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1Q;B`])B!N
M97<@44YA;64H)'1H:7,M/FUE=&AO9&YA;64@+B`G4F5S<&]N<V4G+"`D=&AI
M<RT^;65T:&]D7VYA;65S<&%C92D["B`@("`@("`@("`@("1M971H;V1686QU
M92`])B!N97<@4T]!4%]686QU92@D<6XM/F9Q;B@I+"`G4W1R=6-T)RP@)')E
M='5R;E]V86PI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1M971H
M;V1686QU92`])B`D;65T:&]D7W)E<W!O;G-E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/E]M86ME16YV96QO<&4H)&UE=&AO9%9A;'5E+"`D
M:&5A9&5R7W)E<W5L=',L("1T:&ES+3YR97-P;VYS95]E;F-O9&EN9RD["B`@
M("!]"@H@("`@9G5N8W1I;VX@)E]?9&5C;V1E4F5Q=65S="@D<F5Q=65S="P@
M)'-H:69T(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"$D<F5Q=65S="D@
M>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@
M("\J($-H96-K(&9O<B!V86QI9"!R97-P;VYS92X@*B\*("`@("`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<F5Q=65S="DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)')E<75E<W0I.PH@("`@("`@('T@
M96QS92!I9B`H(6ES7V$H)')E<75E<W0L("=33T%07U9A;'5E)RDI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L
M:60@9&%T82!I;B!S97)V97(Z.E]?9&5C;V1E4F5Q=65S="<I.PH@("`@("`@
M('T*"B`@("`@("`@+RH@1&5C;V1E('1O(&YA=&EV92!P:'`@9&%T871Y<&4N
M("HO"B`@("`@("`@)')E<75E<W1!<G)A>2`]("1T:&ES+3Y?9&5C;V1E*"1R
M97%U97-T*3L*("`@("`@("`O*B!&875L=#\@*B\*("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D<F5Q=65S=$%R<F%Y*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/E]R86ES95-O87!&875L="@D<F5Q=65S=$%R<F%Y*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES7V]B:F5C="@D<F5Q=65S=$%R<F%Y*2`F
M)@H@("`@("`@("`@("!G971?8VQA<W,H)')E<75E<W1!<G)A>2D@/3T@)W-T
M9$-L87-S)RD@>PH@("`@("`@("`@("`D<F5Q=65S=$%R<F%Y(#T@9V5T7V]B
M:F5C=%]V87)S*"1R97%U97-T07)R87DI.PH@("`@("`@('T@96QS96EF("@D
M=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T]("=D;V-U;65N="<I('L*("`@
M("`@("`@("`@)')E<75E<W1!<G)A>2`](&%R<F%Y*"1R97%U97-T07)R87DI
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?87)R87DH)')E<75E<W1!<G)A
M>2DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R97%U97-T07)R87E;)V9A
M=6QT8V]D92==*2!\?`H@("`@("`@("`@("`@("`@:7-S970H)')E<75E<W1!
M<G)A>5LG4T]!4"U%3E8Z9F%U;'1C;V1E)UTI*2!["B`@("`@("`@("`@("`@
M("`D9F%U;'1C;V1E(#T@)&9A=6QT<W1R:6YG(#T@)&9A=6QT9&5T86EL(#T@
M)&9A=6QT86-T;W(@/2`G)SL*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1R
M97%U97-T07)R87D@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H<W1R:7-T<B@D:RP@)V9A=6QT8V]D92<I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1F875L=&-O9&4@/2`D=CL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FES='(H)&LL("=F
M875L='-T<FEN9R<I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1F875L
M='-T<FEN9R`]("1V.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RP@)V1E=&%I;"<I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1F875L=&1E=&%I;"`]("1V.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T
M<B@D:RP@)V9A=6QT86-T;W(G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D9F%U;'1A8W1O<B`]("1V.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1F875L='-T<FEN9RP@)&9A=6QT9&5T86EL+"`D
M9F%U;'1A8W1O<BP@)&9A=6QT8V]D92D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@+RH@4F5T=7)N(&%R<F%Y(&]F(')E='5R;B!V86QU97,N("HO"B`@
M("`@("`@("`@(&EF("@D<VAI9G0@)B8@8V]U;G0H)')E<75E<W1!<G)A>2D@
M/3T@,2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y7W-H:69T*"1R
M97%U97-T07)R87DI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(')E='5R
M;B`D<F5Q=65S=$%R<F%Y.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E
M<75E<W1!<G)A>3L*("`@('T*"B`@("!F=6YC=&EO;B!V97)I9GE-971H;V0H
M)')E<75E<W0I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^8V%L;%9A;&ED
M871I;VXI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H*
M("`@("`@("`D<&%R86US(#T@)')E<75E<W0M/G9A;'5E.PH*("`@("`@("`O
M*B!'970@=&AE(&1I<W!A=&-H(&UA<"!I9B!O;F4@97AI<W1S+B`J+PH@("`@
M("`@("1M87`@/2!N=6QL.PH@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"1T:&ES+3YM971H;V1N86UE+"`D=&AI<RT^9&ES<&%T8VA?;6%P*2D@>PH@
M("`@("`@("`@("`D;6%P(#T@)'1H:7,M/F1I<W!A=&-H7VUA<%LD=&AI<RT^
M;65T:&]D;F%M95T["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YS
M;V%P;V)J96-T*2D@>PH@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D
M=&AI<RT^<V]A<&]B:F5C="P@)U]?9&ES<&%T8V@G*2D@>PH@("`@("`@("`@
M("`@("`@)&UA<"`]("1T:&ES+3YS;V%P;V)J96-T+3Y?7V1I<W!A=&-H*"1T
M:&ES+3YM971H;V1N86UE*3L*("`@("`@("`@("`@?2!E;'-E:68@*&UE=&AO
M9%]E>&ES=',H)'1H:7,M/G-O87!O8FIE8W0L("1T:&ES+3YM971H;V1N86UE
M*2D@>PH@("`@("`@("`@("`@("`@+RH@3F\@;6%P+"!A;&P@<'5B;&EC(&9U
M;F-T:6]N<R!A<F4@4T]!4"!F=6YC=&EO;G,N("HO"B`@("`@("`@("`@("`@
M("!R971U<FX@=')U93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!I9B`H(21M87`I('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@G4T]!4"!R97%U97-T('-P96-I9FEE9"!A;B!U;FAA;F1L960@;65T
M:&]D("(G("X@)'1H:7,M/FUE=&AO9&YA;64@+B`G(B<L("<G+"`G)RP@)T-L
M:65N="<I.PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`O*B!)9B!W92!A;&EA<V5D('1H92!33T%0(&UE=&AO9"!N86UE
M('1O(&$@4$A0(&9U;F-T:6]N+"!C:&%N9V4*("`@("`@("`@*B!C86QL7VUE
M=&AO9&YA;64@<V\@=V4@9&\@=&AE(')I9VAT('1H:6YG+B`J+PH@("`@("`@
M(&EF("AA<G)A>5]K97E?97AI<W1S*"=A;&EA<R<L("1M87`I("8F("%E;7!T
M>2@D;6%P6R=A;&EA<R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^8V%L;%]M
M971H;V1N86UE(#T@)&UA<%LG86QI87,G73L*("`@("`@("!]"@H@("`@("`@
M("\J($EF('1H97)E(&%R92!I;G!U="!P87)A;65T97)S(')E<75I<F5D+B`J
M+PH@("`@("`@(&EF("@D<VEG(#T@)&UA<%LG:6XG72D@>PH@("`@("`@("`@
M("`D=&AI<RT^:6YP=71?=F%L=64@/2!C;W5N="@D<VEG*3L*("`@("`@("`@
M("`@)'1H:7,M/G)E='5R;E]T>7!E(#T@:7-?87)R87DH)&UA<%LG;W5T)UTI
M(#\@)&UA<%LG;W5T)UT@.B!F86QS93L*("`@("`@("`@("`@:68@*&ES7V%R
M<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("`@("`O*B!686QI9&%T92!T
M:&4@;G5M8F5R(&]F('!A<F%M971E<G,N("HO"B`@("`@("`@("`@("`@("!I
M9B`H8V]U;G0H)'!A<F%M<RD@/3T@8V]U;G0H)'-I9RDI('L*("`@("`@("`@
M("`@("`@("`@("`O*B!-86ME(&%R<F%Y(&]F('!A<F%M('1Y<&5S+B`J+PH@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1P87)A;7,@87,@)'!A<F%M
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1P6UT@/2!S=')T;VQO=V5R
M*"1P87)A;2T^='EP92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@("1S:6=?="`](&%R<F%Y7W9A;'5E<R@D<VEG*3L*("`@
M("`@("`@("`@("`@("`@("`O*B!686QI9&%T92!E86-H('!A<F%M)W,@='EP
M92X@*B\*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!C
M;W5N="@D<"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@
M268@4T]!4"!T>7!E<R!D;R!N;W0@;6%T8V@L(&ET)W,@<W1I;&P@9FEN92!I
M9B!T:&4*("`@("`@("`@("`@("`@("`@("`@("`@("H@;6%P<&5D('!H<"!T
M>7!E<R!M871C:"!T:&ES(&%L;&]W<R!U<VEN9R!P;&%I;B!02%`*("`@("`@
M("`@("`@("`@("`@("`@("`@("H@=F%R:6%B;&5S('1O('=O<FL@*&DN92X@
M<W1U9F8@;&EK92!$96-I;6%L('=O=6QD"B`@("`@("`@("`@("`@("`@("`@
M("`@("`J(&9A:6P@;W1H97)W:7-E*2X@5V4@8V]N<VED97(@=&AI<R!O;FQY
M(&5R<F]R(&EF('1H90H@("`@("`@("`@("`@("`@("`@("`@("`@*B!T>7!E
M<R!E>&ES="!I;B!O=7(@='EP92!M87!S+"!A;F0@=&AE>2!D:69F97(N("HO
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1S:6=?
M=%LD:5TL("1P6R1I72D@(3T@,"`F)@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:7-S970H)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,7U-#2$5-05]6
M15)324].75LD<VEG7W1;)&E=72D@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<F-A<V5C;7`H)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,7U-#
M2$5-05]615)324].75LD<VEG7W1;)&E=72P@)'1H:7,M/E]T>7!E;6%P6U-/
M05!?6$U,7U-#2$5-05]615)324].75LD<%LD:5U=*2`A/2`P*2!["@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M(#T@)'!A<F%M<ULD:5T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*")33T%0(')E<75E<W0@8V]N=&%I;F5D(&UI<VUA=&-H:6YG('!A
M<F%M971E<G,@;V8@;F%M92`D<&%R86TM/FYA;64@:&%D('1Y<&4@6WLD<%LD
M:5U]72P@=VAI8V@@9&ED(&YO="!M871C:"!S:6=N871U<F4G<R!T>7!E.B!;
M>R1S:6=?=%LD:5U]72P@;6%T8VAE9#\@(B`N("AS=')C87-E8VUP*"1S:6=?
M=%LD:5TL("1P6R1I72DI+"`G)RP@)R<L("=#;&EE;G0G*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@+RH@5W)O;F<@;G5M8F5R(&]F('!A
M<F%M<RX@*B\*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"=33T%0(')E<75E<W0@8V]N=&%I;F5D(&EN8V]R<F5C="!N=6UB
M97(@;V8@<&%R86UE=&5R<RX@;65T:&]D("(G("X@)'1H:7,M/FUE=&AO9&YA
M;64@+B`G(B!R97%U:7)E9"`G("X@8V]U;G0H)'-I9RD@+B`G(&%N9"!R97%U
M97-T('!R;W9I9&5D("<@+B!C;W5N="@D<&%R86US*2P@)R<L("<G+"`G0VQI
M96YT)RD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@+RH@3F\@<&%R86US+B`J+PH@("`@("`@("`@("`@("`@)'1H:7,M
M/E]R86ES95-O87!&875L="@G4T]!4"!R97%U97-T(&-O;G1A:6YE9"!I;F-O
M<G)E8W0@;G5M8F5R(&]F('!A<F%M971E<G,N(&UE=&AO9"`B)R`N("1T:&ES
M+3YM971H;V1N86UE("X@)R(@<F5Q=6ER97,@)R`N(&-O=6YT*"1S:6<I("X@
M)R!P87)A;65T97)S+"!A;F0@<F5Q=65S="!P<F]V:61E9"!N;VYE+B<L("<G
M+"`G)RP@)T-L:65N="<I.PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O*B!792=L;"!T
M<GD@:70@86YY=V%Y+B`J+PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*
M("`@(&9U;F-T:6]N('9A;&ED871E365T:&]D*"1M971H;V1N86UE+"`D;F%M
M97-P86-E(#T@;G5L;"D*("`@('L*("`@("`@("!U;G-E="@D=&AI<RT^<V]A
M<&]B:F5C="D["@H@("`@("`@(&EF("@A)'1H:7,M/F-A;&Q686QI9&%T:6]N
M*2!["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@3F\@4T]!4"!A8V-E<W,@=&\@<')I=F%T92!F=6YC=&EO;G,N("HO
M"B`@("`@("`@:68@*"1M971H;V1N86UE6S!=(#T]("=?)RD@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!I9B!I
M="=S(&EN(&]U<B!F=6YC=&EO;B!L:7-T+"!O:R`J+PH@("`@("`@(&EF("AA
M<G)A>5]K97E?97AI<W1S*"1M971H;V1N86UE+"`D=&AI<RT^9&ES<&%T8VA?
M;6%P*2`F)@H@("`@("`@("`@("`H(21N86UE<W!A8V4@?'P*("`@("`@("`@
M("`@("%A<G)A>5]K97E?97AI<W1S*"=N86UE<W!A8V4G+"`D=&AI<RT^9&ES
M<&%T8VA?;6%P6R1M971H;V1N86UE72D@?'P*("`@("`@("`@("`@("1N86UE
M<W!A8V4@/3T@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;)VYA
M;65S<&%C92==*2D@>PH@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T
M<R@G;F%M97-P86-E)RP@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M
M95TI*0H@("`@("`@("`@("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4@
M/2`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M971H;V1N86UE75LG;F%M97-P86-E
M)UT["B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@
M("`@+RH@:68@:70G<R!I;B!A;B!O8FIE8W0L(&ET)W,@;VL@*B\*("`@("`@
M("!I9B`H:7-S970H)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA;65S<&%C
M95TI*2!["B`@("`@("`@("`@("1C(#T@8V]U;G0H)'1H:7,M/F1I<W!A=&-H
M7V]B:F5C='-;)&YA;65S<&%C95TI.PH@("`@("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@("`@("`@("`@("`@)&]B:B`])B`D
M=&AI<RT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E75LD:5T["B`@("`@
M("`@("`@("`@("`O*B!)9B!W92!H879E(&$@9&ES<&%T8V@@;6%P+"!A;F0@
M=&AE(&9U;F-T:6]N(&ES(&YO="!I;B!T:&4*("`@("`@("`@("`@("`@("`J
M(&1I<W!A=&-H(&UA<"P@=&AE;B!I="!I<R!N;W0@8V%L;&%B;&4A("HO"B`@
M("`@("`@("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D;V)J+"`G7U]D:7-P
M871C:"<I*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1O8FHM/E]?9&ES
M<&%T8V@H)&UE=&AO9&YA;64I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YM971H;V1?;F%M97-P86-E(#T@)&YA;65S<&%C93L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-O87!O8FIE8W0@/28@)&]B:CL*
M("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E:68@*&UE=&AO
M9%]E>&ES=',H)&]B:BP@)&UE=&AO9&YA;64I*2!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/FUE=&AO9%]N86UE<W!A8V4@/2`D;F%M97-P86-E.PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS;V%P;V)J96-T(#TF("1O8FH[
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!F86QS93L*("`@('T*"B`@("!F=6YC=&EO;B!A9&1/8FIE8W1-87`H)B1O
M8FHL("1N86UE<W!A8V4@/2!N=6QL+"`D<V5R=FEC95]N86UE(#T@)T1E9F%U
M;'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1S97)V:6-E7V1E<V,@
M/2`G)RD*("`@('L*("`@("`@("!I9B`H(21N86UE<W!A8V4I('L*("`@("`@
M("`@("`@:68@*&ES<V5T*"1O8FHM/FYA;65S<&%C92DI('L*("`@("`@("`@
M("`@("`@("\O(%A86"!A(&)I="!O9B!B86-K=V%R9',@8V]M<&%T:6)I;&ET
M>0H@("`@("`@("`@("`@("`@)&YA;65S<&%C92`]("1O8FHM/FYA;65S<&%C
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H)TYO(&YA;65S<&%C92!P<F]V:61E9"!F;W(@
M8VQA<W,A)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M:68@*"%I<W-E="@D=&AI<RT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E
M72DI('L*("`@("`@("`@("`@)'1H:7,M/F1I<W!A=&-H7V]B:F5C='-;)&YA
M;65S<&%C95T@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^
M9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E75M=(#TF("1O8FH["@H@("`@
M("`@("\O($-R96%T92!I;G1E<FYA;"!74T1,('-T<G5C='5R97,@9F]R(&]B
M:F5C=`H*("`@("`@("`O+R!86%@@0F5C875S92!S;VUE(&EN=&5R;F%L('=O
M<FMI;F=S(&]F(%!%05(Z.E-/05`@9&5C:61E('=H971H97(@=&\*("`@("`@
M("`O+R!D;R!C97)T86EN('1H:6YG<R!B>2!T:&4@<')E<V5N8V4@;W(@86)S
M96YC92!O9B!?=W-D;"P@=V4@<VAO=6QD"B`@("`@("`@+R\@;VYL>2!C<F5A
M=&4@82!?=W-D;"!S=')U8W1U<F4@:68@=V4@:VYO=R!W92!C86X@9FEL;"!I
M=#L@:68*("`@("`@("`O+R!?7V1I<W!A=&-H7VUA<"!O<B!?7W1Y<&5D968@
M9F]R('1H92!O8FIE8W0@:7,@;6ES<VEN9RP@=V4@<VAO=6QD"B`@("`@("`@
M+R\@879O:60@8W)E871I;F<@:70N($QA=&5R+"!W:&5N('=E(&%R92!U<VEN
M9R!02%`@-2!I;G1R;W-P96-T:6]N+"!W90H@("`@("`@("\O('=I;&P@8F4@
M86)L92!T;R!M86ME('1H92!D871A(&9O<B!A;&P@;V)J96-T<R!W:71H;W5T
M(&%N>2!E>'1R80H@("`@("`@("\O(&EN9F]R;6%T:6]N(&9R;VT@=&AE(&1E
M=F5L;W!E<G,L(&%N9"!T:&ES(&-O;F1I=&EO;B!S:&]U;&0@8F4*("`@("`@
M("`O+R!D<F]P<&5D+@H*("`@("`@("`O+R!86%@@2VYO=VX@:7-S=64Z(&EF
M(&EM<&]R=&5D(%=31$P@*&)I;F174T1,*2!O<B!A;F]T:&5R(%=31$P@<V]U
M<F-E"B`@("`@("`@+R\@:7,@=7-E9"!T;R!A9&0@7W=S9&P@<W1R=6-T=7)E
M(&EN9F]R;6%T:6]N+"!T:&5N(&%D9$]B:F5C=%=31$P@:7,*("`@("`@("`O
M+R!U<V5D+"!T:&5R92!I<R!A(&AI9V@@<&]S<VEB:6QI='D@;V8@7W=S9&P@
M9&%T82!C;W)R=7!T:6]N.PH@("`@("`@("\O('1H97)E9F]R92!Y;W4@<VAO
M=6QD(&%V;VED('5S:6YG(%]?9&ES<&%T8VA?;6%P+U]?='EP961E9@H@("`@
M("`@("\O(&1E9FEN:71I;VYS($%.1"!O=&AE<B!74T1,(&1A=&$@<V]U<F-E
M<R!I;B!T:&4@<V%M92!S97)V:6-E+B!790H@("`@("`@("\O(&5X8VQU9&4@
M8VQA<W-E<R!T:&%T(&1O;B=T(&AA=F4@7U]T>7!E9&5F<R!T;R!A;&QO=R!E
M>'1E<FYA;"!74T1,"B`@("`@("`@+R\@9FEL97,@=&\@8F4@=7-E9"!W:71H
M(&-L87-S97,@=VET:"!N;R!I;G1E<FYA;"!T>7!E(&1E9FEN:71I;VYS"B`@
M("`@("`@+R\@*'1H92!T>7!E<R!A<F4@9&5F:6YE9"!I;B!T:&4@5U-$3"!F
M:6QE*2X@5VAE;B!A9&1/8FIE8W174T1,(&ES"B`@("`@("`@+R\@<F5F86-T
M;W)E9"!T;R!N;W0@8V%U<V4@8V]R<G5P=&EO;BP@=&AI<R!R97-T<FEC=&EO
M;B!C86X@8F4*("`@("`@("`O+R!R96QA>&5D+@H*("`@("`@("`O+R!);B!S
M=6UM87)Y+"!I9B!Y;W4@861D(&%N(&]B:F5C="!W:71H(&)O=&@@82!D:7-P
M871C:"!M87`@86YD('1Y<&4*("`@("`@("`O+R!D969I;FET:6]N<RP@=&AE
M;B!P<F5V:6]U<R!74T1,(&9I;&4@;W!E<F%T:6]N(&%N9"!T>7!E(&1E9FEN
M:71I;VYS"B`@("`@("`@+R\@=VEL;"!B92!O=F5R=W)I='1E;BX*("`@("`@
M("!I9B`H:7-S970H)&]B:BT^7U]D:7-P871C:%]M87`I("8F(&ES<V5T*"1O
M8FHM/E]?='EP961E9BDI('L*("`@("`@("`@("`@)'1H:7,M/F%D9$]B:F5C
M=%=31$PH)&]B:BP@)&YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@)'-E<G9I
M8V5?9&5S8RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@
M('T*"B`@("`O*BH*("`@("`J($%D9',@82!M971H;V0@=&\@=&AE(&1I<W!A
M=&-H(&UA<"X*("`@("`J+PH@("`@9G5N8W1I;VX@861D5&]-87`H)&UE=&AO
M9&YA;64L("1I;BP@)&]U="P@)&YA;65S<&%C92`](&YU;&PL("1A;&EA<R`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"%F=6YC=&EO;E]E>&ES=',H)&UE
M=&AO9&YA;64I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U
M;'0H)T5R<F]R(&UA<'!I;F<@9G5N8W1I;VXG+"`G)RP@)R<L("=397)V97(G
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;)VEN)UT@/2`D
M:6X["B`@("`@("`@)'1H:7,M/F1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95U;
M)V]U="==(#T@)&]U=#L*("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M
M971H;V1N86UE75LG86QI87,G72`]("1A;&EA<SL*("`@("`@("!I9B`H)&YA
M;65S<&%C92D@>PH@("`@("`@("`@("`D=&AI<RT^9&ES<&%T8VA?;6%P6R1M
M971H;V1N86UE75LG;F%M97-P86-E)UT@/2`D;F%M97-P86-E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@
M<V5T0V%L;$AA;F1L97(H)&-A;&Q(86YD;&5R+"`D=F%L:61A=&EO;B`]('1R
M=64I"B`@("!["B`@("`@("`@)'1H:7,M/F-A;&Q(86YD;&5R(#T@)&-A;&Q(
M86YD;&5R.PH@("`@("`@("1T:&ES+3YC86QL5F%L:61A=&EO;B`]("1V86QI
M9&%T:6]N.PH@("`@?0H*("`@("\J*@H@("`@("H@0&1E<')E8V%T960@=7-E
M(&)I;F174T1,(&9R;VT@;F]W(&]N"B`@("`@*B\*("`@(&9U;F-T:6]N(&)I
M;F0H)'=S9&Q?=7)L*0H@("`@>PH@("`@("`@("1T:&ES+3YB:6YD5U-$3"@D
M=W-D;%]U<FPI.PH@("`@?0H*("`@("\J*@H@("`@("H@0'!A<F%M("!S=')I
M;F<@82!U<FP@=&\@82!74T1,(')E<V]U<F-E"B`@("`@*B!`<F5T=7)N('9O
M:60*("`@("`J+PH@("`@9G5N8W1I;VX@8FEN9%=31$PH)'=S9&Q?=7)L*0H@
M("`@>PH@("`@("`@("\J($EN<W1A;G1I871E(%=31$P@8VQA<W,N("HO"B`@
M("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!33T%07U=31$PH)'=S9&Q?=7)L
M*3L*("`@("`@("!I9B`H)'1H:7,M/E]W<V1L+3YF875L="D@>PH@("`@("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1T:&ES+3Y?=W-D;"T^9F%U
M;'0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@
M=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1/8FIE8W174T1,*"8D=W-D
M;%]O8FHL("1T87)G971.86UE<W!A8V4L("1S97)V:6-E7VYA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S97)V:6-E7V1E<V,@/2`G)RD*("`@
M('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3Y?=W-D;"DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!33T%07U=31$P["B`@("`@("`@
M?0H*("`@("`@("`D=&AI<RT^7W=S9&PM/G!A<G-E3V)J96-T*"1W<V1L7V]B
M:BP@)'1A<F=E=$YA;65S<&%C92P@)'-E<G9I8V5?;F%M92P@)'-E<G9I8V5?
M9&5S8RD["@H@("`@("`@(&EF("@D=&AI<RT^7W=S9&PM/F9A=6QT*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/E]W<V1L
M+3YF875L="D["B`@("`@("`@?0H@("`@?0I]"@``````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-/05`O5')A;G-P;W)T+G!H<```````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#0U,S`@,3`U,34T,S0Q,S,@,#(Q-S,R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&%N(&%B<W1R
M86-T('1R86YS<&]R="!L87EE<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD
M(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T
M('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD
M+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N
M='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE
M(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C
M;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC
M97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!$:65T<FEC
M:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M/@H@*B!`875T:&]R("`@("!3
M:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X*("H@0&-O<'ER:6=H
M="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E;G-E
M(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S92YP:'`G.PH*
M+RHJ"B`J(%-/05`@5')A;G-P;W)T($QA>65R"B`J"B`J(%1H:7,@;&%Y97(@
M8V%N('5S92!D:69F97)E;G0@<')O=&]C;VQS(&1E<&5N9&%N="!O;B!T:&4@
M96YD<&]I;G0@=7)L('!R;W9I9&5D"B`J(&YO(&MN;W=L96=E(&]F('1H92!3
M3T%0('!R;W1O8V]L(&ES(&%V86EL86)L92!A="!T:&ES(&QE=F5L"B`J(&YO
M(&MN;W=L96=E(&]F('1H92!T<F%N<W!O<G0@<')O=&]C;VQS(&ES(&%V86EL
M86)L92!A="!T:&ES(&QE=F5L"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*("H@
M0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@/'-H
M86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%07U1R86YS<&]R=`I["B`@("!F
M=6YC=&EO;B`F9V5T5')A;G-P;W)T*"1U<FPL("1E;F-O9&EN9R`](%-/05!?
M1$5&055,5%]%3D-/1$E.1RD*("`@('L*("`@("`@("`D=7)L<&%R=',@/2!`
M<&%R<V5?=7)L*"1U<FPI.PH*("`@("`@("!I9B`H(21U<FQP87)T<ULG<V-H
M96UE)UTI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?0F%S95]/8FIE8W0Z
M.E]R86ES95-O87!&875L="@B26YV86QI9"!T<F%N<W!O<G0@55)).B`D=7)L
M(BD["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R8V%S96-M<"@D=7)L<&%R
M='-;)W-C:&5M92==+"`G;6%I;'1O)RD@/3T@,"D@>PH@("`@("`@("`@("`D
M=')A;G-P;W)T7W1Y<&4@/2`G4TU44"<["B`@("`@("`@?2!E;'-E:68@*'-T
M<F-A<V5C;7`H)'5R;'!A<G1S6R=S8VAE;64G72P@)VAT='!S)RD@/3T@,"D@
M>PH@("`@("`@("`@("`D=')A;G-P;W)T7W1Y<&4@/2`G2%144"<["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+RH@:&%N9&QE(&]T:&5R('1R86YS
M<&]R="!T>7!E<R`J+PH@("`@("`@("`@("`D=')A;G-P;W)T7W1Y<&4@/2!S
M=')T;W5P<&5R*"1U<FQP87)T<ULG<V-H96UE)UTI.PH@("`@("`@('T*("`@
M("`@("`D=')A;G-P;W)T7VEN8VQU9&4@/2`G4T]!4"]4<F%N<W!O<G0O)R`N
M("1T<F%N<W!O<G1?='EP92`N("<N<&AP)SL*("`@("`@("`D<F5S(#T@0&EN
M8VQU9&5?;VYC92@D=')A;G-P;W)T7VEN8VQU9&4I.PH@("`@("`@(&EF("@A
M)')E<R`F)B`A:6Y?87)R87DH)'1R86YS<&]R=%]I;F-L=61E+"!G971?:6YC
M;'5D961?9FEL97,H*2DI('L*("`@("`@("`@("`@<F5T=7)N(%-/05!?0F%S
M95]/8FIE8W0Z.E]R86ES95-O87!&875L="@B3F\@5')A;G-P;W)T(&9O<B![
M)'5R;'!A<G1S6R=S8VAE;64G77TB*3L*("`@("`@("!]"B`@("`@("`@)'1R
M86YS<&]R=%]C;&%S<R`](")33T%07U1R86YS<&]R=%\D=')A;G-P;W)T7W1Y
M<&4B.PH@("`@("`@(&EF("@A8VQA<W-?97AI<W1S*"1T<F%N<W!O<G1?8VQA
M<W,I*2!["B`@("`@("`@("`@(')E='5R;B!33T%07T)A<V5?3V)J96-T.CI?
M<F%I<V53;V%P1F%U;'0H(DYO(%1R86YS<&]R="!C;&%S<R`D=')A;G-P;W)T
M7V-L87-S(BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D="`])B!N97<@
M)'1R86YS<&]R=%]C;&%S<R@D=7)L+"`D96YC;V1I;F<I.PH@("`@?0H*?0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05`O5F%L=64N<&AP````````````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,34Q-C`@,3`U,34T,S0Q,S,@
M,#(Q,#$S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@
M9F]R(&-O;G9E<G1I;F<@=F%L=65S(&)E='=E96X@4T]!4"!A;F0@4$A0+@H@
M*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@
M870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J
M($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0
M"B`J($!A=71H;W(@("`@($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX
M-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B!`875T:&]R("`@("!3:&%N92!#
M87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD
M(&UO<F4*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^("`@36%I;G1E;F%N8V4*("H@0&%U=&AO<B`@("`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX@("`@("`@36%I;G1E;F%N8V4*("H@
M0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(
M4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O0F%S
M92YP:'`G.PH*+RHJ"B`J(%-/05`Z.E9A;'5E"B`J"B`J(%1H:7,@8VQA<W,@
M8V]N=F5R=',@=F%L=65S(&)E='=E96X@4$A0(&%N9"!33T%0+@H@*@H@*B!/
M<FEG:6YA;&QY(&)A<V5D(&]N(%-/05!X-"!B>2!$:65T<FEC:"!!>6%L80H@
M*B!H='1P.B\O9&EE=')I8V@N9V%N>#0N8V]M+W-O87!X-`H@*@H@*B!`86-C
M97-S('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J($!A=71H;W(@4VAA;F4@
M0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N
M9"!U<&1A=&5S"B`J($!A=71H;W(@1&EE=')I8V@@07EA;&$@/&1I971R:6-H
M0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J+PIC;&%S<R!33T%07U9A
M;'5E"GL*("`@("\J*@H@("`@("H*("`@("`J"B`@("`@*B!`=F%R("!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1V86QU92`](&YU;&P["@H@("`@+RHJ"B`@
M("`@*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D;F%M
M92`]("<G.PH*("`@("\J*@H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)'1Y<&4@/2`G)SL*"B`@("`O*BH*("`@("`J($YA
M;65S<&%C90H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&YA;65S<&%C92`]("<G.PH@("`@=F%R("1T>7!E7VYA;65S<&%C
M92`]("<G.PH*("`@('9A<B`D871T<FEB=71E<R`](&%R<F%Y*"D["@H@("`@
M+RHJ"B`@("`@*@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R
M("1A<G)A>51Y<&4@/2`G)SL*"B`@("!V87(@)&]P=&EO;G,@/2!A<G)A>2@I
M.PH*("`@('9A<B`D;G%N.PH@("`@=F%R("1T<6X["@H@("`@+RHJ"B`@("`@
M*B!#;VYS=')U8W1O<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N
M86UE("`@("`@("!N86UE(&]F('1H92!S;V%P+79A;'5E('MN86UE<W!A8V5]
M;F%M90H@("`@("H@0'!A<F%M(&UI>&5D("`D='EP92`@("`@("`@<V]A<"!V
M86QU92![;F%M97-P86-E?71Y<&4L(&EF(&YO="!S970@86X@875T;VUA=&EC
M"B`@("`@*B!`<&%R86T@;6EX960@("1V86QU92`@("`@("!V86QU92!T;R!S
M970*("`@("`J($!P87)A;2!A<G)A>2`@)&%T=')I8G5T97,@("AO<'1I;VYA
M;"D@071T<FEB=71E<RX*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]686QU
M92@D;F%M92`]("<G+"`D='EP92`](&9A;'-E+"`D=F%L=64@/2!N=6QL+"`D
M871T<FEB=71E<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@+R\@1&5T96-T
M('1Y<&4@:68@;F]T('!A<W-E9"X*("`@("`@("`D=&AI<RT^;G%N(#TF(&YE
M=R!13F%M92@D;F%M92D["B`@("`@("`@)'1H:7,M/FYA;64@/2`D=&AI<RT^
M;G%N+3YN86UE.PH@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D=&AI<RT^
M;G%N+3YN86UE<W!A8V4["B`@("`@("`@)'1H:7,M/G1Q;B`])B!N97<@44YA
M;64H)'1Y<&4I.PH@("`@("`@("1T:&ES+3YT>7!E(#T@)'1H:7,M/G1Q;BT^
M;F%M93L*("`@("`@("`D=&AI<RT^='EP95]P<F5F:7@@/2`D=&AI<RT^='%N
M+3YN<SL*("`@("`@("`D=&AI<RT^='EP95]N86UE<W!A8V4@/2`D=&AI<RT^
M='%N+3YN86UE<W!A8V4["B`@("`@("`@)'1H:7,M/G9A;'5E(#TF("1V86QU
M93L*("`@("`@("`D=&AI<RT^871T<FEB=71E<R`]("1A='1R:6)U=&5S.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4V5R:6%L:7IE+@H@("`@("H*("`@("`J
M($!P87)A;2!33T%07T)A<V4@)B1S97)I86QI>F5R("!!(%-/05!?0F%S92!I
M;G-T86YC92!O<B!S=6)C;&%S<R!T;R!S97)I86QI>F4@=VET:"X*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@6$U,(')E<')E<V5N=&%T:6]N(&]F
M("1T:&ES+@H@("`@("HO"B`@("!F=6YC=&EO;B`F<V5R:6%L:7IE*"8D<V5R
M:6%L:7IE<BD*("`@('L*("`@("`@("!R971U<FX@)'-E<FEA;&EZ97(M/E]S
M97)I86QI>F5686QU92@D=&AI<RT^=F%L=64L("1T:&ES+3YN86UE+"`D=&AI
M<RT^='EP92P@)'1H:7,M/FYA;65S<&%C92P@)'1H:7,M/G1Y<&5?;F%M97-P
M86-E+"`D=&AI<RT^;W!T:6]N<RP@)'1H:7,M/F%T=')I8G5T97,L("1T:&ES
M+3YA<G)A>51Y<&4I.PH@("`@?0H*?0H*+RHJ"B`J(%-/05`Z.DAE861E<@H@
M*@H@*B!4:&ES(&-L87-S(&-O;G9E<G1S('9A;'5E<R!B971W965N(%!(4"!A
M;F0@4T]!4"X@270@:7,@82!S:6UP;&4*("H@=W)A<'!E<B!A<F]U;F0@4T]!
M4%]686QU92P@861D:6YG('-U<'!O<G0@9F]R(%-/05`@86-T;W(@86YD"B`J
M(&UU<W1U;F1E<G-T86YD('!A<F%M971E<G,N"B`J"B`J($]R:6=I;F%L;'D@
M8F%S960@;VX@4T]!4'@T(&)Y($1I971R:6-H($%Y86QA"B`J(&AT='`Z+R]D
M:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@<'5B;&EC
M"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O(#QS
M:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T97,*
M("H@0&%U=&AO<B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M
M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/05!?2&5A9&5R(&5X=&5N
M9',@4T]!4%]686QU90I["B`@("`O*BH*("`@("`J($-O;G-T<G5C=&]R"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)&YA;64@("`@("`@("`@("!N
M86UE(&]F('1H92!S;V%P+79A;'5E('MN86UE<W!A8V5];F%M90H@("`@("H@
M0'!A<F%M(&UI>&5D("`@)'1Y<&4@("`@("`@("`@("!S;V%P('9A;'5E('MN
M86UE<W!A8V5]='EP92P@:68@;F]T('-E="!A;B!A=71O;6%T:6,*("`@("`J
M($!P87)A;2!M:7AE9"`@("1V86QU92`@("`@("`@("`@=F%L=64@=&\@<V5T
M"B`@("`@*B!`<&%R86T@:6YT96=E<B`D;75S='5N9&5R<W1A;F0@(%IE<F\@
M;W(@;VYE+@H@("`@("H@0'!A<F%M(&UI>&5D("`@)&%T=')I8G5T97,@("`@
M("`H;W!T:6]N86PI($%T=')I8G5T97,N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%-/05!?2&5A9&5R*"1N86UE(#T@)R<L("1T>7!E+"`D=F%L=64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D;75S='5N9&5R<W1A;F0@/2`P+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97,@/2!A<G)A>2@I*0H@
M("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&%T=')I8G5T97,I*2!["B`@
M("`@("`@("`@("1A8W1O<B`]("1A='1R:6)U=&5S.PH@("`@("`@("`@("`D
M871T<FEB=71E<R`](&%R<F%Y*"D["B`@("`@("`@?0H*("`@("`@("!P87)E
M;G0Z.E-/05!?5F%L=64H)&YA;64L("1T>7!E+"`D=F%L=64L("1A='1R:6)U
M=&5S*3L*"B`@("`@("`@:68@*&ES<V5T*"1A8W1O<BDI('L*("`@("`@("`@
M("`@)'1H:7,M/F%T=')I8G5T97-;)U-/05`M14Y6.F%C=&]R)UT@/2`D86-T
M;W(["B`@("`@("`@?2!E;'-E:68@*"%I<W-E="@D=&AI<RT^871T<FEB=71E
M<ULG4T]!4"U%3E8Z86-T;W(G72DI('L*("`@("`@("`@("`@)'1H:7,M/F%T
M=')I8G5T97-;)U-/05`M14Y6.F%C=&]R)UT@/2`G:'1T<#HO+W-C:&5M87,N
M>&UL<V]A<"YO<F<O<V]A<"]A8W1O<B]N97AT)SL*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/F%T=')I8G5T97-;)U-/05`M14Y6.FUU<W15;F1E<G-T86YD
M)UT@/2`H:6YT*21M=7-T=6YD97)S=&%N9#L*("`@('T*"GT*"B\J*@H@*B!3
M3T%0.CI!='1A8VAM96YT"B`J('1H:7,@8VQA<W,@8V]N=F5R=',@=F%L=65S
M(&)E='=E96X@4$A0(&%N9"!33T%0"B`J(&ET(&AA;F1L97,@36EM92!A='1A
M8VAE;65N=',@<&5R(%<S0R!.;W1E(&]N(%-O87`@071T86-H96UE;G1S(&%T
M"B`J(&AT='`Z+R]W=W<N=S,N;W)G+U12+U-/05`M871T86-H;65N=',*("H*
M("H*("H@0&%C8V5S<R!P=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T
M:&]R(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@
M=&\@4$5!4B!A;F0@=7!D871E<PH@*B\*8VQA<W,@4T]!4%]!='1A8VAM96YT
M(&5X=&5N9',@4T]!4%]686QU90I["B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@;F%M92!O9B!T
M:&4@<V]A<"UV86QU92`\=F%L=65?;F%M93X*("`@("`J($!P87)A;2`@("!M
M:7AE9"`@('-O87`@:&5A9&5R('9A;'5E"B`@("`@*B!`<&%R86T@("`@<W1R
M:6YG(&YA;65S<&%C90H@("`@("HO"B`@("!F=6YC=&EO;B!33T%07T%T=&%C
M:&UE;G0H)&YA;64@/2`G)RP@)'1Y<&4@/2`G87!P;&EC871I;VXO;V-T970M
M<W1R96%M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9FEL96YA
M;64L("1F:6QE(#T@;G5L;"D*("`@('L*("`@("`@("!G;&]B86P@)%-/05!?
M;W!T:6]N<SL*("`@("`@("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;)TUI
M;64G72DI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M)TUA:6Q?;6EM92!I<R!N;W0@:6YS=&%L;&5D+"!U;F%B;&4@=&\@<W5P<&]R
M="!33T%0($%T=&%C:&5M96YT<R<I.PH@("`@("`@('T*("`@("`@("!P87)E
M;G0Z.E-/05!?5F%L=64H)&YA;64L(&YU;&PL(&YU;&PI.PH*("`@("`@("`D
M9FEL961A=&$@/2`H)&9I;&4@/3T](&YU;&PI(#\@)'1H:7,M/E]F:6QE,G-T
M<B@D9FEL96YA;64I(#H@)&9I;&4["B`@("`@("`@)&9I;&5N86UE(#T@8F%S
M96YA;64H)&9I;&5N86UE*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D
M9FEL961A=&$I*2!["B`@("`@("`@("`@(')E='5R;B`D9FEL961A=&$["B`@
M("`@("`@?0H*("`@("`@("`D8VED(#T@;60U*'5N:7%I9"AT:6UE*"DI*3L*
M"B`@("`@("`@)'1H:7,M/F%T=')I8G5T97-;)VAR968G72`]("=C:60Z)RXD
M8VED.PH*("`@("`@("`D=&AI<RT^;W!T:6]N<ULG871T86-H;65N="==(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)O9'DG
M("`@("`]/B`D9FEL961A=&$L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1I<W!O<VET:6]N)R`@("`@/3X@)&9I;&5N86UE+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT7W1Y<&4G("`@/3X@
M)'1Y<&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V5N8V]D
M:6YG)R`]/B`G8F%S938T)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G8VED)R`]/B`D8VED"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`I.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@8V]N
M=&5N=',@;V8@=&AE(&=I=F5N(&9I;&4@;F%M92!A<R!S=')I;F<*("`@("`J
M($!P87)A;2!S=')I;F<@)&9I;&5?;F%M90H@("`@("H@0')E='5R;B!S=')I
M;F<*("`@("`J($!A8V-E<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9?9FEL93)S='(H)&9I;&5?;F%M92D*("`@('L*("`@("`@("!I9B`H(6ES
M7W)E861A8FQE*"1F:6QE7VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!0
M14%2.CIR86ES945R<F]R*"=&:6QE(&ES(&YO="!R96%D86)L92`G("X@)&9I
M;&5?;F%M92D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&9D(#T@9F]P96XH
M)&9I;&5?;F%M92P@)W)B)RDI('L*("`@("`@("`@("`@<F5T=7)N(%!%05(Z
M.G)A:7-E17)R;W(H)T-O=6QD(&YO="!O<&5N("<@+B`D9FEL95]N86UE*3L*
M("`@("`@("!]"B`@("`@("`@)&-O;G0@/2!F<F5A9"@D9F0L(&9I;&5S:7IE
M*"1F:6QE7VYA;64I*3L*("`@("`@("!F8VQO<V4H)&9D*3L*("`@("`@("!R
M971U<FX@)&-O;G0["B`@("!]"@I]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+U-/05`O5U-$3"YP:'``````````````````````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`R-#<R-C`@,3`U,34T,S0Q,S,@,#(P-3(P`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J*@H@
M*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R(&1E86QI;F<@=VET
M:"!74T1,(&%C8V5S<R!A;F0@<V5R=FEC97,N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@
M*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A=`H@*B!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@
M:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B
M(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*("H@0&%U=&AO<B`@("`@
M1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@
M075T:&]R"B`J($!A=71H;W(@("`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A
M<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@;6]R90H@*B!`875T:&]R
M("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO<F1E+F]R9SX@("!-86EN
M=&5N86YC90H@*B!`875T:&]R("`@("!*86X@4V-H;F5I9&5R(#QJ86Y`:&]R
M9&4N;W)G/B`@("`@("!-86EN=&5N86YC90H@*B!`8V]P>7)I9VAT("`R,#`S
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0($QI8V5N<V4@,BXP,@H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O4T]!
M4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"87-E+G!H<"<["G)E<75I<F5?
M;VYC92`G4T]!4"]&875L="YP:'`G.PIR97%U:7)E7V]N8V4@)TA45%`O4F5Q
M=65S="YP:'`G.PH*9&5F:6YE*"=74T1,7T-!0TA%7TU!6%]!1T4G+"`T,S(P
M,"D["F1E9FEN92@G5U-$3%]#04-(15]54T4G+"`@("`@,"D[("\O('-E="!T
M;R!Z97)O('1O('1U<FX@;V9F(&-A8VAI;F<*"B\J*@H@*B!4:&ES(&-L87-S
M('!A<G-E<R!74T1,(&9I;&5S+"!A;F0@8V%N(&)E('5S960@8GD@4T]!4#HZ
M0VQI96YT('1O"B`J('!R;W!E<FQY(')E9VES=&5R('-O87`@=F%L=65S(&9O
M<B!S97)V:6-E<RX*("H*("H@3W)I9VEN86QL>2!B87-E9"!O;B!33T%0>#0@
M8GD@1&EE=')I8V@@07EA;&$*("H@:'1T<#HO+V1I971R:6-H+F=A;G@T+F-O
M;2]S;V%P>#0*("H*("H@5$]$3SH*("H@("!A9&0@=W-D;"!C86-H:6YG"B`J
M("`@<F5F86-T;W(@;F%M97-P86-E(&AA;F1L:6YG("@D;F%M97-P86-E+R1N
M<RD*("H@("!I;7!L96UE;G0@241,('1Y<&4@<WEN=&%X(&1E8VQA<F%T:6]N
M('-O('=E(&-A;B!G96YE<F%T92!74T1,"B`J"B`J($!A8V-E<W,@<'5B;&EC
M"B`J($!P86-K86=E(%-/05`*("H@0&%U=&AO<B!3:&%N92!#87)A=F5O(#QS
M:&%N94!P:'`N;F5T/B!#;VYV97)S:6]N('1O(%!%05(@86YD('5P9&%T97,*
M("H@0&%U=&AO<B!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N8V]M
M/B!/<FEG:6YA;"!!=71H;W(*("HO"F-L87-S(%-/05!?5U-$3"!E>'1E;F1S
M(%-/05!?0F%S90I["B`@("!V87(@)'1N<R`](&YU;&P["B`@("!V87(@)&1E
M9FEN:71I;VX@/2!A<G)A>2@I.PH@("`@=F%R("1N86UE<W!A8V5S(#T@87)R
M87DH*3L*("`@('9A<B`D;G,@/2!A<G)A>2@I.PH@("`@=F%R("1X<V0@/2!3
M3T%07UA-3%]30TA%34%?5D524TE/3CL*("`@('9A<B`D8V]M<&QE>%1Y<&5S
M(#T@87)R87DH*3L*("`@('9A<B`D96QE;65N=',@/2!A<G)A>2@I.PH@("`@
M=F%R("1M97-S86=E<R`](&%R<F%Y*"D["B`@("!V87(@)'!O<G14>7!E<R`]
M(&%R<F%Y*"D["B`@("!V87(@)&)I;F1I;F=S(#T@87)R87DH*3L*("`@('9A
M<B`D:6UP;W)T<R`](&%R<F%Y*"D["B`@("!V87(@)'-E<G9I8V5S(#T@87)R
M87DH*3L*("`@('9A<B`D<V5R=FEC92`]("<G.PH@("`@=F%R("1U<FD@/2`G
M)SL*("`@('9A<B`D9&]C<R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4')O
M>'D@<&%R86UE=&5R<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J
M+PH@("`@=F%R("1P<F]X>2`](&YU;&P["@H@("`@=F%R("1T<F%C92`](#`[
M"@H@("`@+RHJ"B`@("`@*B!5<V4@5U-$3"!C86-H90H@("`@("H*("`@("`J
M($!V87(@8F]O;&5A;@H@("`@("HO"B`@("!V87(@)&-A8VAE57-E(#T@;G5L
M;#L*"B`@("`O*BH*("`@("`J($-A8VAE(&UA>"!L:69E=&EM92`H:6X@<V5C
M;VYD<RD*("`@("`J"B`@("`@*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@
M)&-A8VAE36%X06=E(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($-L87-S('1O
M('5S92!F;W(@5U-$3"!P87)S:6YG+B!#86X@8F4@;W9E<G)I9&1E;B!F;W(@
M<W!E8VEA;`H@("`@("H@8V%S97,L('-U8F-L87-S97,L(&5T8RX*("`@("`J
M($!V87(@<W1R:6YG("1W<V1L4&%R<V5R0VQA<W,*("`@("`J+PH@("`@=F%R
M("1W<V1L4&%R<V5R0VQA<W,@/2`G4T]!4%]74T1,7U!A<G-E<B<["@H@("`@
M+RHJ"B`@("`@*B!33T%07U=31$P@8V]N<W1R=6-T;W(N"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`@)'=S9&Q?=7)I("`@("!54DP@=&\@5U-$3"!F
M:6QE+@H@("`@("H@0'!A<F%M(&%R<F%Y("`@)'!R;WAY("`@("`@("!#;VYT
M86EN<R!O<'1I;VYS(&9O<B!(5%107U)E<75E<W0@8VQA<W,@*'-E92!(5%10
M+U)E<75E<W0N<&AP*2X*("`@("`J($!P87)A;2!B;V]L96%N("1C86-H955S
M92`@("`@57-E(%=31$P@8V%C:&EN9RX@1&5F875L=',@=&\@9F%L<V4N"B`@
M("`@*B!`<&%R86T@:6YT96=E<B`D8V%C:&5-87A!9V4@($-A8VAE(&UA>"!L
M:69E=&EM92`H:6X@<V5C;VYD<RDN"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D
M9&]C<R`@("`@("`@(%!A<G-E(&1O8W5M96YT871I;VX@:6X@=&AE(%=31$P_
M($1E9F%U;'1S('1O(&9A;'-E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(%-/05!?5U-$3"@D=W-D;%]U<FD@
M("`@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`D<')O>'D@("`@
M("`@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("1C86-H955S
M92`@("`](%=31$Q?0T%#2$5?55-%+`H@("`@("`@("`@("`@("`@("`@("`@
M("1C86-H94UA>$%G92`](%=31$Q?0T%#2$5?34%87T%'12P*("`@("`@("`@
M("`@("`@("`@("`@("`D9&]C<R`@("`@("`@/2!F86QS92D*("`@('L*("`@
M("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$3"<I.PH@("`@("`@("1T:&ES
M+3YU<FD@("`@("`@("`]("1W<V1L7W5R:3L*("`@("`@("`D=&AI<RT^<')O
M>'D@("`@("`@/2`D<')O>'D["B`@("`@("`@)'1H:7,M/F-A8VAE57-E("`@
M(#T@)&-A8VAE57-E.PH@("`@("`@("1T:&ES+3YC86-H94UA>$%G92`]("1C
M86-H94UA>$%G93L*("`@("`@("`D=&AI<RT^9&]C<R`@("`@("`@/2`D9&]C
M<SL*"B`@("`@("`@:68@*"1W<V1L7W5R:2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<&%R<V554DPH)'=S9&Q?=7)I*3L*("`@("`@("`@("`@<F5S970H)'1H
M:7,M/G-E<G9I8V5S*3L*("`@("`@("`@("`@)'1H:7,M/G-E<G9I8V4@/2!K
M97DH)'1H:7,M/G-E<G9I8V5S*3L*("`@("`@("!]"B`@("!]"@H@("`@9G5N
M8W1I;VX@<V5T7W-E<G9I8V4H)'-E<G9I8V4I"B`@("!["B`@("`@("`@:68@
M*&%R<F%Y7VME>5]E>&ES=',H)'-E<G9I8V4L("1T:&ES+3YS97)V:6-E<RDI
M('L*("`@("`@("`@("`@)'1H:7,M/G-E<G9I8V4@/2`D<V5R=FEC93L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!`9&5P<F5C871E9"!U<V4@
M<&%R<V554DP@:6YS=&5A9`H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S92@D
M=W-D;%]U<FDL("1P<F]X>2`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1H
M:7,M/G!A<G-E55),*"1W<V1L7W5R:2P@)'!R;WAY*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($9I;&P@=&AE(%=31$P@87)R87D@=')E92!W:71H(&1A=&$@
M9G)O;2!A(%=31$P@9FEL90H@("`@("H*("`@("`J($!P87)A;2`@<W1R:6YG
M"B`@("`@*B!`<&%R86T@(&%R<F%Y("!P<F]X>2!R96QA=&5D('!A<F%M971E
M<G,*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!P
M87)S95523"@D=W-D;%]U<FDL("1P<F]X>2`](&%R<F%Y*"DI"B`@("!["B`@
M("`@("`@)'!A<G-E<B`])B!N97<@)'1H:7,M/G=S9&Q087)S97)#;&%S<R@D
M=W-D;%]U<FDL("1T:&ES+"`D=&AI<RT^9&]C<RD["@H@("`@("`@(&EF("@D
M<&%R<V5R+3YF875L="D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*"1P87)S97(M/F9A=6QT*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&:6QL('1H92!74T1,(&%R<F%Y('1R964@=VET:"!D871A
M(&9R;VT@;VYE(&]R(&UO<F4@4$A0(&-L87-S(&]B:F5C=',*("`@("`J"B`@
M("`@*B!`<&%R86T@(&UI>&5D("`D=W-D;%]O8FH@06X@;V)J96-T(&]R(&%R
M<F%Y(&]F(&]B:F5C=',@=&\@861D('1O('1H92!I;G1E<FYA;"!74T1,('1R
M964*("`@("`J($!P87)A;2`@<W1R:6YG("`D<V5R=FEC95]N86UE($YA;64@
M;V8@=&AE(%=31$P@/'-E<G9I8V4^"B`@("`@*B!`<&%R86T@('-T<FEN9R`@
M)'-E<G9I8V5?9&5S8R!/<'1I;VYA;"!D97-C<FEP=&EO;B!O9B!T:&4@5U-$
M3"`\<V5R=FEC93X*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!P87)S94]B:F5C="@F)'=S9&Q?;V)J+"`D=&%R9V5T3F%M97-P
M86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC95]D97-C(#T@)R<I"B`@("![
M"B`@("`@("`@)'!A<G-E<B`])B!N97<@4T]!4%]74T1,7T]B:F5C=%!A<G-E
M<B@D=W-D;%]O8FHL("1T:&ES+"`D=&%R9V5T3F%M97-P86-E+"`D<V5R=FEC
M95]N86UE+"`D<V5R=FEC95]D97-C*3L*"B`@("`@("`@(&EF("@D<&%R<V5R
M+3YF875L="D@>PH@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L
M="@D<&%R<V5R+3YF875L="D["B`@("`@("`@('T*("`@('T*"B`@("!F=6YC
M=&EO;B!G971%;F1P;VEN="@D<&]R=$YA;64I"B`@("!["B`@("`@("`@<F5T
M=7)N("AI<W-E="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P
M;W)T<R==6R1P;W)T3F%M95U;)V%D9')E<W,G75LG;&]C871I;VXG72DI"B`@
M("`@("`@("`@("`@("`_("1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC
M95U;)W!O<G1S)UU;)'!O<G1.86UE75LG861D<F5S<R==6R=L;V-A=&EO;B==
M"B`@("`@("`@("`@("`@("`Z("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(FYO
M(&5N9'!O:6YT(&9O<B!P;W)T(&9O<B`D<&]R=$YA;64B+"`D=&AI<RT^=7)I
M*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5T4&]R=$YA;64H)&]P97)A=&EO
M;BP@)'-E<G9I8V4I"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YS
M97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UTI*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YS97)V:6-E<ULD<V5R=FEC95U;)W!O<G1S)UT@87,@
M)'!O<G0@/3X@)'!O<G1!='1R<RD@>PH@("`@("`@("`@("`@("`@)'1Y<&4@
M/2`D=&AI<RT^<V5R=FEC97-;)'-E<G9I8V5=6R=P;W)T<R==6R1P;W)T75LG
M='EP92==.PH@("`@("`@("`@("`@("`@:68@*"1T>7!E(#T]("=S;V%P)R`F
M)@H@("`@("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD
M<&]R=$%T=')S6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS)UU;)&]P97)A=&EO
M;ETI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1P;W)T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@?0H*("`@("\J*@H@("`@("H@9FEN9"!T:&4@
M;F%M92!O9B!T:&4@9FER<W0@<&]R="!T:&%T(&-O;G1A:6YS(&%N(&]P97)A
M=&EO;B!O9@H@("`@("H@;F%M92`D;W!E<F%T:6]N+B`@86QW87ES(')E='5R
M;G,@82!T:&4@<V]A<"!P;W)T3F%M92X*("`@("`J+PH@("`@9G5N8W1I;VX@
M9V5T4&]R=$YA;64H)&]P97)A=&EO;BP@)'-E<G9I8V4@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A)'-E<G9I8V4I("1S97)V:6-E(#T@)'1H:7,M/G-E
M<G9I8V4["B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YS97)V:6-E<ULD<V5R
M=FEC95U;)W!O<G1S)UTI*2!["B`@("`@("`@("`@("1P;W)T3F%M92`]("1T
M:&ES+3Y?9V5T4&]R=$YA;64H)&]P97)A=&EO;BP@)'-E<G9I8V4I.PH@("`@
M("`@("`@("!I9B`H)'!O<G1.86UE*2!R971U<FX@)'!O<G1.86UE.PH@("`@
M("`@('T*("`@("`@("`O+R!4<GD@86YY('-E<G9I8V4@:6X@=&AE(%=31$PN
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G-E<G9I8V5S(&%S("1S97)V:6-E
M3F%M92`]/B`D<V5R=FEC92D@>PH@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/G-E<G9I8V5S6R1S97)V:6-E3F%M95U;)W!O<G1S)UTI*2!["B`@("`@
M("`@("`@("`@("`D<&]R=$YA;64@/2`D=&AI<RT^7V=E=%!O<G1.86UE*"1O
M<&5R871I;VXL("1S97)V:6-E3F%M92D["B`@("`@("`@("`@("`@("!I9B`H
M)'!O<G1.86UE*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G-E<G9I
M8V4@/2`D<V5R=FEC94YA;64["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1P;W)T3F%M93L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@B;F\@;W!E<F%T:6]N("1O<&5R871I;VX@:6X@=W-D;"(L("1T:&ES+3YU
M<FDI.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=$]P97)A=&EO;D1A=&$H)'!O
M<G1.86UE+"`D;W!E<F%T:6]N*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T
M3F%M95U;)V)I;F1I;F<G72D*("`@("`@("`@("`@)B8@)&)I;F1I;F<@/2`D
M=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T
M3F%M95U;)V)I;F1I;F<G72D@>PH@("`@("`@("`@("`O+R!G970@;W!E<F%T
M:6]N(&1A=&$@9G)O;2!B:6YD:6YG"B`@("`@("`@("`@(&EF("AI<U]A<G)A
M>2@D=&AI<RT^8FEN9&EN9W-;)&)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P
M97)A=&EO;ETI*2!["B`@("`@("`@("`@("`@("`D;W!$871A(#T@)'1H:7,M
M/F)I;F1I;F=S6R1B:6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("\O(&=E="!O<&5R871I;VX@
M9&%T82!F<F]M('!O<G1T>7!E"B`@("`@("`@("`@("1P;W)T5'EP92`]("1T
M:&ES+3YB:6YD:6YG<ULD8FEN9&EN9UU;)W1Y<&4G73L*("`@("`@("`@("`@
M:68@*"$D<&]R=%1Y<&4I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*")N;R!P;W)T('1Y<&4@9F]R(&)I;F1I;F<@
M)&)I;F1I;F<@:6X@=W-D;"`B("X@)'1H:7,M/G5R:2D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YP;W)T5'EP97-;
M)'!O<G14>7!E75LD;W!E<F%T:6]N72DI('L*("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^<&]R=%1Y<&5S6R1P;W)T5'EP95U;)&]P97)A=&EO
M;EU;)W!A<F%M971E<D]R9&5R)UTI*0H@("`@("`@("`@("`@("`@("`@("1O
M<$1A=&%;)W!A<F%M971E<D]R9&5R)UT@/2`D=&AI<RT^<&]R=%1Y<&5S6R1P
M;W)T5'EP95U;)&]P97)A=&EO;EU;)W!A<F%M971E<D]R9&5R)UT["B`@("`@
M("`@("`@("`@("`D;W!$871A6R=I;G!U="==(#T@87)R87E?;65R9V4H)&]P
M1&%T85LG:6YP=70G72P@)'1H:7,M/G!O<G14>7!E<ULD<&]R=%1Y<&5=6R1O
M<&5R871I;VY=6R=I;G!U="==*3L*("`@("`@("`@("`@("`@("1O<$1A=&%;
M)V]U='!U="==(#T@87)R87E?;65R9V4H)&]P1&%T85LG;W5T<'5T)UTL("1T
M:&ES+3YP;W)T5'EP97-;)'!O<G14>7!E75LD;W!E<F%T:6]N75LG;W5T<'5T
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A)&]P1&%T82D*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT
M*")N;R!O<&5R871I;VX@)&]P97)A=&EO;B!F;W(@<&]R="`D<&]R=$YA;64L
M(&EN('=S9&PB+"`D=&AI<RT^=7)I*3L*("`@("`@("`@("`@)&]P1&%T85LG
M<&%R86UE=&5R<R==(#T@9F%L<V4["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^8FEN9&EN9W-;)'1H:7,M/G-E<G9I8V5S6R1T:&ES+3YS97)V:6-E
M75LG<&]R=',G75LD<&]R=$YA;65=6R=B:6YD:6YG)UU=6R=O<&5R871I;VYS
M)UU;)&]P97)A=&EO;EU;)VEN<'5T)UU;)VYA;65S<&%C92==*2D*("`@("`@
M("`@("`@("`@("1O<$1A=&%;)VYA;65S<&%C92==(#T@)'1H:7,M/F)I;F1I
M;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;
M)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I
M;VY=6R=I;G!U="==6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@+R\@;65S
M<V%G92!D871A(&9R;VT@;65S<V%G97,*("`@("`@("`@("`@)&EN<'5T37-G
M(#T@)&]P1&%T85LG:6YP=70G75LG;65S<V%G92==.PH@("`@("`@("`@("!I
M9B`H:7-?87)R87DH)'1H:7,M/FUE<W-A9V5S6R1I;G!U=$US9UTI*2!["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G97-;)&EN<'5T
M37-G72!A<R`D<&YA;64@/3X@)'!A='1R<RD@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D;W!$871A6R=S='EL92==(#T]("=D;V-U;65N="<@)B8@)&]P
M1&%T85LG:6YP=70G75LG=7-E)UT@/3T@)VQI=&5R86PG"B`@("`@("`@("`@
M("`@("`@("`@("`@("8F("1P;F%M92`]/2`G<&%R86UE=&5R<R<I('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG<&%R86UE=&5R<R==(#T@
M=')U93L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG;F%M97-P
M86-E)UT@/2`D=&AI<RT^;F%M97-P86-E<ULD<&%T=')S6R=N86UE<W!A8V4G
M75T["B`@("`@("`@("`@("`@("`@("`@("`@("1E;"`]("1T:&ES+3YE;&5M
M96YT<ULD<&%T=')S6R=N86UE<W!A8V4G75U;)'!A='1R<ULG='EP92==73L*
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1E;%LG96QE;65N
M=',G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1E;%LG96QE;65N=',G72!A<R`D96QN86UE(#T^("1E;&%T=')S*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&]P1&%T85LG:6YP=70G
M75LG<&%R=',G75LD96QN86UE72`]("1E;&%T=')S.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&]P1&%T85LG:6YP=70G75LG<&%R=',G75LD<&YA;65=(#T@)'!A
M='1R<SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&]U='!U=$US9R`]("1O<$1A
M=&%;)V]U='!U="==6R=M97-S86=E)UT["B`@("`@("`@("`@(&EF("AI<U]A
M<G)A>2@D=&AI<RT^;65S<V%G97-;)&]U='!U=$US9UTI*2!["B`@("`@("`@
M("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G97-;)&]U='!U=$US9UT@
M87,@)'!N86UE(#T^("1P871T<G,I('L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&]P1&%T85LG<W1Y;&4G72`]/2`G9&]C=6UE;G0G("8F("1O<$1A=&%;
M)V]U='!U="==6R=U<V4G72`]/2`G;&ET97)A;"<*("`@("`@("`@("`@("`@
M("`@("`@("`@)B8@)'!N86UE(#T]("=P87)A;65T97)S)RD@>PH*("`@("`@
M("`@("`@("`@("`@("`@("`@)&5L(#T@)'1H:7,M/F5L96UE;G1S6R1P871T
M<G-;)VYA;65S<&%C92==75LD<&%T=')S6R=T>7!E)UU=.PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)&5L6R=E;&5M96YT<R==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&5L6R=E;&5M
M96YT<R==(&%S("1E;&YA;64@/3X@)&5L871T<G,I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;W!$871A6R=O=71P=70G75LG<&%R=',G
M75LD96QN86UE72`]("1E;&%T=')S.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P
M1&%T85LG;W5T<'5T)UU;)W!A<G1S)UU;)'!N86UE72`]("1P871T<G,["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D;W!$871A.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B;F\@8FEN
M9&EN9R!F;W(@<&]R="`D<&]R=$YA;64@:6X@=W-D;"(L("1T:&ES+3YU<FDI
M.PH@("`@?0H*("`@(&9U;F-T:6]N(&UA=&-H365T:&]D*"8D;W!E<F%T:6]N
M*0H@("`@>PH@("`@("`@("\O($]V97)L;V%D:6YG(&QO=V5R8V%S97,@9G5N
M8W1I;VX@;F%M97,@.B@*("`@("`@("!F;W)E86-H("@D=&AI<RT^<V5R=FEC
M97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==(&%S("1P;W)T(#T^("1P;W)T
M071T<G,I('L*("`@("`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI
M<RT^8FEN9&EN9W-;)'!O<G1!='1R<ULG8FEN9&EN9R==75LG;W!E<F%T:6]N
M<R==*2!A<R`D;W`I('L*("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP
M*"1O<"P@)&]P97)A=&EO;BD@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@
M("1O<&5R871I;VX@/2`D;W`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!G971$871A
M2&%N9&QE<@H@("`@("H*("`@("`J($=I=F5N(&$@9&%T871Y<&4L('=H870@
M9G5N8W1I;VX@:&%N9&QE<R!T:&4@<')O8V5S<VEN9S\*("`@("`J('1H:7,@
M:7,@=7-E9"!F;W(@9&]C+VQI=&5R86P@<F5Q=65S=',@=VAE<F4@=V4@<F5C
M96EV90H@("`@("H@82!D871A='EP92P@86YD('=E(&YE960@=&\@<&%S<R!I
M="!T;R!A(&UE=&AO9"!I;B!O=70*("`@("`J('-E<G9E<B!C;&%S<PH@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@9&%T871Y<&4*("`@("`J($!P87)A
M;2!S=')I;F<@;F%M97-P86-E"B`@("`@*B!`<F5T=7)N<R!S=')I;F<@;65T
M:&]D;F%M90H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T1&%T84AA;F1L97(H)&1A=&%T>7!E+"`D;F%M97-P86-E*0H@
M("`@>PH@("`@("`@("\O('-E92!I9B!W92!H879E(&%N(&5L96UE;G0@8GD@
M=&AI<R!N86UE"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YN86UE<W!A8V5S
M6R1N86UE<W!A8V5=*2D*("`@("`@("`@("`@)&YA;65S<&%C92`]("1T:&ES
M+3YN86UE<W!A8V5S6R1N86UE<W!A8V5=.PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^;G-;)&YA;65S<&%C95TI*2!["B`@("`@("`@("`@("1N<W`@/2`D
M=&AI<RT^;G-;)&YA;65S<&%C95T["B`@("`@("`@("`@("\O:68@*"%I<W-E
M="@D=&AI<RT^96QE;65N='-;)&YS<%TI*0H@("`@("`@("`@("`O+R`@("`D
M;G-P(#T@)'1H:7,M/FYA;65S<&%C97-;)&YS<%T["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^96QE;65N='-;)&YS<%U;)&1A=&%T>7!E72DI('L*
M("`@("`@("`@("`@("`@("1C:&5C:VUE<W-A9V5S(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("\O(&9I;F0@=VAA="!M97-S86=E<R!U<V4@=&AI<R!D
M871A='EP90H@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A
M9V5S(&%S("1M97-S86=E;F%M92`]/B`D;65S<V%G92D@>PH@("`@("`@("`@
M("`@("`@("`@(&9O<F5A8V@@*"1M97-S86=E(&%S("1P87)T;F%M92`]/B`D
M<&%R="D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)'!A<G1;)W1Y
M<&4G72`]/2`D9&%T871Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C:&5C:VUE<W-A9V5S6UT@/2`D;65S<V%G96YA;64["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("\O(&9I;F0@=&AE(&]P97)A=&EO;B!T:&%T
M('5S97,@=&AI<R!M97-S86=E"B`@("`@("`@("`@("`@("`D9&%T84AA;F1L
M97(@/2!N=6QL.PH@("`@("`@("`@("`@("`@9F]R96%C:"@D=&AI<RT^<&]R
M=%1Y<&5S(&%S("1P;W)T;F%M92`]/B`D<&]R='1Y<&4I('L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D<&]R='1Y<&4@87,@)&]P;F%M92`]/B`D
M;W!I;F9O*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1C
M:&5C:VUE<W-A9V5S(&%S("1M97-S86=E;F%M92D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1O<&EN9F];)VEN<'5T)UU;)VUE<W-A9V4G
M72`]/2`D;65S<V%G96YA;64I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)&]P;F%M93L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@('T*"B`@("!F=6YC
M=&EO;B!G9713;V%P06-T:6]N*"1P;W)T3F%M92P@)&]P97)A=&EO;BD*("`@
M('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS
M97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;)'!O<G1.86UE75LG
M8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R871I;VY=6R=S;V%P06-T
M:6]N)UTI("8F"B`@("`@("`@("`@("1S;V%P06-T:6]N(#T@)'1H:7,M/F)I
M;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N<R==6R1O<&5R
M871I;VY=6R=S;V%P06-T:6]N)UTI('L*("`@("`@("`@("`@<F5T=7)N("1S
M;V%P06-T:6]N.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L<V4["B`@
M("!]"@H@("`@9G5N8W1I;VX@9V5T3F%M97-P86-E*"1P;W)T3F%M92P@)&]P
M97)A=&EO;BD*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/F)I;F1I
M;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UU;
M)'!O<G1.86UE75LG8FEN9&EN9R==72D@)B8*("`@("`@("`@("`@:7-S970H
M)'1H:7,M/F)I;F1I;F=S6R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC
M95U;)W!O<G1S)UU;)'!O<G1.86UE75LG8FEN9&EN9R==75LG;W!E<F%T:6]N
M<R==6R1O<&5R871I;VY=6R=I;G!U="==6R=N86UE<W!A8V4G72D@)B8*("`@
M("`@("`@("`@)&YA;65S<&%C92`]("1T:&ES+3YB:6YD:6YG<ULD=&AI<RT^
M<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==6R1P;W)T3F%M95U;
M)V)I;F1I;F<G75U;)V]P97)A=&EO;G,G75LD;W!E<F%T:6]N75LG:6YP=70G
M75LG;F%M97-P86-E)UTI('L*("`@("`@("`@("`@<F5T=7)N("1N86UE<W!A
M8V4["B`@("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@
M("!F=6YC=&EO;B!G971.86UE<W!A8V5!='1R:6)U=&5.86UE*"1N86UE<W!A
M8V4I"B`@("!["B`@("`@("`@+RH@268@:70@9&]E<VXG="!E>&ES="!A="!F
M:7)S="P@9FQI<"!T:&4@87)R87D@86YD(&-H96-K"B`@("`@("`@("H@86=A
M:6XN("HO"B`@("`@("`@:68@*&5M<'1Y*"1T:&ES+3YN<ULD;F%M97-P86-E
M72DI('L*("`@("`@("`@("`@)'1H:7,M/FYS(#T@87)R87E?9FQI<"@D=&AI
M<RT^;F%M97-P86-E<RD["B`@("`@("`@?0H@("`@("`@("\J($EF(&ET(&1O
M97-N)W0@97AI<W0@;F]W+"!A9&0@:70N("HO"B`@("`@("`@:68@*&5M<'1Y
M*"1T:&ES+3YN<ULD;F%M97-P86-E72DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YA9&1.86UE<W!A8V4H)&YA;65S<&%C92D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/FYS6R1N86UE<W!A8V5=.PH@("`@?0H*
M("`@(&9U;F-T:6]N(&%D9$YA;65S<&%C92@D;F%M97-P86-E*0H@("`@>PH@
M("`@("`@(&EF("@A96UP='DH)'1H:7,M/FYS6R1N86UE<W!A8V5=*2D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FYS6R1N86UE<W!A8V5=.PH@("`@
M("`@('T*"B`@("`@("`@)&X@/2!C;W5N="@D=&AI<RT^;G,I.PH@("`@("`@
M("1A='1R(#T@)VYS)R`N("1N.PH@("`@("`@("1T:&ES+3YN86UE<W!A8V5S
M6R=N<R<@+B`D;ET@/2`D;F%M97-P86-E.PH@("`@("`@("1T:&ES+3YN<ULD
M;F%M97-P86-E72`]("1A='1R.PH@("`@("`@(')E='5R;B`D871T<CL*("`@
M('T*"B`@("!F=6YC=&EO;B!?=F%L:61A=&53=')I;F<H)'-T<FEN9RD*("`@
M('L*("`@("`@("`O+R!86%@@=&AI<R!S:&]U;&0@8F4@9&]N92!S;V]N97(@
M;W(@;&%T97(*("`@("`@("`O+R!R971U<FX@=')U93L*("`@("`@("!R971U
M<FX@<')E9U]M871C:"@B+UY;7'=?.B-<+UTK)"\B+"`D<W1R:6YG*3L*("`@
M('T*"B`@("!F=6YC=&EO;B!?861D07)G*"8D87)G<RP@)B1A<F=A<G)A>2P@
M)&%R9VYA;64I"B`@("!["B`@("`@("`@:68@*"1A<F=S*2!["B`@("`@("`@
M("`@("1A<F=S("X]("<L("<["B`@("`@("`@?0H@("`@("`@("1A<F=S("X]
M(")<)"(@+B`D87)G;F%M93L*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A
M=&53=')I;F<H)&%R9VYA;64I*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&%R9V%R<F%Y*2!["B`@("`@("`@
M("`@("1A<F=A<G)A>2`N/2`G+"`G.PH@("`@("`@('T*("`@("`@("`D87)G
M87)R87D@+CT@(B<D87)G;F%M92<@/3X@7"0B("X@)&%R9VYA;64["B`@("!]
M"@H@("`@9G5N8W1I;VX@7V5L96UE;G1!<F<H)B1A<F=S+"`F)&%R9V%R<F%Y
M+"`F)%]A<F=T>7!E+"`D7V%R9VYA;64I"B`@("!["B`@("`@("`@)&-O;6UE
M;G1S(#T@)R<["B`@("`@("`@)&5L(#T@)'1H:7,M/F5L96UE;G1S6R1?87)G
M='EP95LG;F%M97-P86-E)UU=6R1?87)G='EP95LG='EP92==73L*("`@("`@
M("`D=&YS(#T@:7-S970H)'1H:7,M/FYS6R1E;%LG;F%M97-P86-E)UU=*2`_
M("1T:&ES+3YN<ULD96Q;)VYA;65S<&%C92==72`Z("1?87)G='EP95LG;F%M
M97-P86-E)UT["@H@("`@("`@(&EF("@A96UP='DH)&5L6R=C;VUP;&5X)UTI
M('Q\("AI<W-E="@D96Q;)W1Y<&4G72D@)B8@:7-S970H)'1H:7,M/F-O;7!L
M97A4>7!E<ULD=&YS75LD96Q;)W1Y<&4G75TI*2D@>PH@("`@("`@("`@("`O
M+R!4:&4@96QE;65N="!I<R!A(&-O;7!L97@@='EP92X*("`@("`@("`@("`@
M)&-O;6UE;G1S("X]("(@("`@("`@("\O('LD7V%R9W1Y<&5;)W1Y<&4G77T@
M:7,@82!#;VUP;&5X5'EP92P@<F5F97(@=&\@=&AE(%=31$P@9F]R(&UO<F4@
M:6YF;RY<;B(["B`@("`@("`@("`@("1A='1R;F%M92`](")[)%]A<F=T>7!E
M6R=T>7!E)UU]7V%T='(B.PH@("`@("`@("`@("!I9B`H:7-S970H)&5L6R=T
M>7!E)UTI("8F(&ES<V5T*"1T:&ES+3YC;VUP;&5X5'EP97-;)'1N<UU;)&5L
M6R=T>7!E)UU=6R=A='1R:6)U=&4G72DI('L*("`@("`@("`@("`@("`@("1C
M;VUM96YT<R`N/2`B("`@("`@("`O+R![)%]A<F=T>7!E6R=T>7!E)UU](&UA
M>2!R97%U:7)E(&%T=')I8G5T97,L(')E9F5R('1O('1H92!74T1,(&9O<B!M
M;W)E(&EN9F\N7&XB.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1C;VUM
M96YT<R`N/2`B("`@("`@("!<)'LD871T<FYA;65]6R=X;6QN<R==(#T@)WLD
M=&AI<RT^;F%M97-P86-E<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==77TG.UQN
M(CL*("`@("`@("`@("`@)&-O;6UE;G1S("X]("(@("`@("`@(%PD>R1?87)G
M='EP95LG='EP92==?2`])B!N97<@4T]!4%]686QU92@G>R1?87)G='EP95LG
M='EP92==?2<L(&9A;'-E+"!<)'LD7V%R9W1Y<&5;)W1Y<&4G77TL(%PD)&%T
M=')N86UE*3M<;B(["B`@("`@("`@("`@("1T:&ES+3Y?861D07)G*"1A<F=S
M+"`D87)G87)R87DL("1?87)G='EP95LG='EP92==*3L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1E;%LG='EP92==*2`F)B!I<W-E="@D=&AI<RT^8V]M<&QE
M>%1Y<&5S6R1T;G-=6R1E;%LG='EP92==75LG871T<FEB=71E)UTI*2!["B`@
M("`@("`@("`@("`@("!I9B`H)&%R9W,I('L*("`@("`@("`@("`@("`@("`@
M("`D87)G<R`N/2`G+"`G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@)&%R9W,@+CT@)R0G("X@)&%T=')N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1E;%LG96QE;65N=',G72DI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&5L6R=E;&5M96YT<R==(&%S("1E;F%M
M92`]/B`D96QE;65N="D@>PH@("`@("`@("`@("`@("`@)&-O;6UE;G1S("X]
M("(@("`@("`@(%PD)&5N86UE(#TF(&YE=R!33T%07U9A;'5E*"=[>R1T:&ES
M+3YN86UE<W!A8V5S6R1E;&5M96YT6R=N86UE<W!A8V4G75U]?21E;F%M92<L
M("<B("X*("`@("`@("`@("`@("`@("`@("`H:7-S970H)&5L96UE;G1;)W1Y
M<&4G72D@/R`D96QE;65N=%LG='EP92==(#H@9F%L<V4I("X@(B<L(%PD)&5N
M86UE*3M<;B(["B`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9$%R9R@D87)G
M<RP@)&%R9V%R<F%Y+"`D96YA;64I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)&-O;6UE;G1S("X]("(@("`@("`@(%PD
M)%]A<F=N86UE(#TF(&YE=R!33T%07U9A;'5E*"=[>R1T:&ES+3YN86UE<W!A
M8V5S6R1T;G-=?7TD7V%R9VYA;64G+"`G>R1E;%LG='EP92==?2<L(%PD)%]A
M<F=N86UE*3M<;B(["B`@("`@("`@("`@("1T:&ES+3Y?861D07)G*"1A<F=S
M+"`D87)G87)R87DL("1?87)G;F%M92D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)&-O;6UE;G1S.PH@("`@?0H*("`@(&9U;F-T:6]N(%]C;VUP;&5X
M5'EP94%R9R@F)&%R9W,L("8D87)G87)R87DL("8D7V%R9W1Y<&4L("1?87)G
M;F%M92D*("`@('L*("`@("`@("`D8V]M;65N=',@/2`G)SL*("`@("`@("!I
M9B`H:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD7V%R9W1Y<&5;)VYA;65S
M<&%C92==75LD7V%R9W1Y<&5;)W1Y<&4G75TI*2!["B`@("`@("`@("`@("1C
M;VUM96YT<R`@/2`B("`@("`@("`O+R`D7V%R9VYA;64@:7,@82!#;VUP;&5X
M5'EP92![)%]A<F=T>7!E6R=T>7!E)UU]+%QN(CL*("`@("`@("`@("`@)&-O
M;6UE;G1S("X]("(@("`@("`@("\O(')E9F5R('1O('=S9&P@9F]R(&UO<F4@
M:6YF;UQN(CL*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC;VUP;&5X
M5'EP97-;)%]A<F=T>7!E6R=N86UE<W!A8V4G75U;)%]A<F=T>7!E6R=T>7!E
M)UU=6R=A='1R:6)U=&4G72DI('L*("`@("`@("`@("`@("`@("1C;VUM96YT
M<R`N/2`B("`@("`@("`O+R`D7V%R9VYA;64@;6%Y(')E<75I<F4@871T<FEB
M=71E<RP@<F5F97(@=&\@=W-D;"!F;W(@;6]R92!I;F9O7&XB.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1W<F%P;F%M92`]("=[)R`N("1T:&ES+3YN
M86UE<W!A8V5S6R1?87)G='EP95LG;F%M97-P86-E)UU=+B=])R`N("1?87)G
M='EP95LG='EP92==.PH@("`@("`@("`@("`D8V]M;65N=',@+CT@(B`@("`@
M("`@7"0D7V%R9VYA;64@/28@;F5W(%-/05!?5F%L=64H)R1?87)G;F%M92<L
M("<D=W)A<&YA;64G+"!<)"1?87)G;F%M92D[7&XB.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/E]A9&1!<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=N
M86UE*3L*("`@("`@("!R971U<FX@)&-O;6UE;G1S.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5N97)A=&5S('-T=6(@8V]D92!F<F]M('1H92!74T1,('1H
M870@8V%N(&)E('-A=F5D('1O(&$@9FEL90H@("`@("H@;W(@979A;"=D(&EN
M=&\@97AI<W1E;F-E+@H@("`@("HO"B`@("!F=6YC=&EO;B!G96YE<F%T95!R
M;WAY0V]D92@D<&]R="`]("<G+"`D8VQA<W-N86UE/2<G*0H@("`@>PH@("`@
M("`@("1M=6QT:7!O<G0@/2!C;W5N="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M
M/G-E<G9I8V5=6R=P;W)T<R==*2`^(#$["B`@("`@("`@:68@*"$D<&]R="D@
M>PH@("`@("`@("`@("!R97-E="@D=&AI<RT^<V5R=FEC97-;)'1H:7,M/G-E
M<G9I8V5=6R=P;W)T<R==*3L*("`@("`@("`@("`@)'!O<G0@/2!C=7)R96YT
M*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI.PH@
M("`@("`@('T*("`@("`@("`O+R!86%@@8W5R<F5N=&QY(&1O(&YO="!S=7!P
M;W)T($A45%`@<&]R=',*("`@("`@("!I9B`H)'!O<G1;)W1Y<&4G72`A/2`G
M<V]A<"<I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H*
M("`@("`@("`O+R!86%@@8W5R<F5N=%!O<G0@:7,@0D%$"B`@("`@("`@)&-L
M:65N='5R;"`]("1P;W)T6R=A9&1R97-S)UU;)VQO8V%T:6]N)UT["B`@("`@
M("`@:68@*"$D8VQA<W-N86UE*2!["B`@("`@("`@("`@(&EF("@D;75L=&EP
M;W)T('Q\("1P;W)T*2!["B`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@
M)U=E8E-E<G9I8V5?)R`N("1T:&ES+3YS97)V:6-E("X@)U\G("X@)'!O<G1;
M)VYA;64G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("1C;&%S<VYA;64@/2`G5V5B4V5R=FEC95\G("X@)'1H:7,M/G-E<G9I8V4[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)&-L87-S;F%M92`]('!R96=?
M<F5P;&%C92@G+UL@+EPM7"A<*5TK+R<L("=?)RP@)&-L87-S;F%M92D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3Y?=F%L:61A=&53=')I;F<H
M)&-L87-S;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/G!R;WAY*2`F)B!C
M;W5N="@D=&AI<RT^<')O>'DI*2!["B`@("`@("`@("`@("1C;&%S<R`](")C
M;&%S<R`D8VQA<W-N86UE(&5X=&5N9',@4T]!4%]#;&EE;G1<;GM<;B(@+@H@
M("`@("`@("`@("`B("`@(&9U;F-T:6]N("1C;&%S<VYA;64H7"1P871H(#T@
M)R1C;&EE;G1U<FPG*5QN("`@('M<;B(@+@H@("`@("`@("`@("`B("`@("`@
M("!<)'1H:7,M/E-/05!?0VQI96YT*%PD<&%T:"P@,"P@,"Q<;B(@+@H@("`@
M("`@("`@("`G("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)SL*
M"B`@("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3YP<F]X>2!A<R`D:V5Y(#T^
M("1V86PI('L*("`@("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1C;&%S<R`N/2`B)R1K97DG(#T^(&%R
M<F%Y*"(["B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;"!A<R`D
M:V5Y,B`]/B`D=F%L,BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D8VQA
M<W,@+CT@(B<D:V5Y,B<@/3X@)R1V86PR)RP@(CL*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@)&-L87-S("X]("<I)SL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&-L
M87-S("X]("(G)&ME>2<@/3X@)R1V86PG+"`B.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1C;&%S<R`N/2`B*2D[7&X@
M("`@?5QN(CL*("`@("`@("`@("`@)&-L87-S(#T@<W1R7W)E<&QA8V4H)RP@
M*2DG+"`G*2DG+"`D8VQA<W,I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1C;&%S<R`](")C;&%S<R`D8VQA<W-N86UE(&5X=&5N9',@4T]!4%]#
M;&EE;G1<;GM<;B(@+@H@("`@("`@("`@("`B("`@(&9U;F-T:6]N("1C;&%S
M<VYA;64H7"1P871H(#T@)R1C;&EE;G1U<FPG*5QN("`@('M<;B(@+@H@("`@
M("`@("`@("`B("`@("`@("!<)'1H:7,M/E-/05!?0VQI96YT*%PD<&%T:"P@
M,"D[7&XB("X*("`@("`@("`@("`@(B`@("!]7&XB.PH@("`@("`@('T*"B`@
M("`@("`@+R\@9V5T('1H92!B:6YD:6YG+"!F<F]M('1H870@9V5T('1H92!P
M;W)T('1Y<&4*("`@("`@("`D<')I;6%R>4)I;F1I;F<@/2`D<&]R=%LG8FEN
M9&EN9R==.R`O+R1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O
M<G1S)UU;)'!O<G1;)VYA;64G75U;(F)I;F1I;F<B73L*("`@("`@("`D<')I
M;6%R>4)I;F1I;F<@/2!P<F5G7W)E<&QA8V4H(B]>*"XJ.BDO(BP@)R<L("1P
M<FEM87)Y0FEN9&EN9RD["B`@("`@("`@)'!O<G14>7!E(#T@)'1H:7,M/F)I
M;F1I;F=S6R1P<FEM87)Y0FEN9&EN9UU;)W1Y<&4G73L*("`@("`@("`D<&]R
M=%1Y<&4@/2!P<F5G7W)E<&QA8V4H(B]>*"XJ.BDO(BP@)R<L("1P;W)T5'EP
M92D["B`@("`@("`@)'-T>6QE(#T@)'1H:7,M/F)I;F1I;F=S6R1P<FEM87)Y
M0FEN9&EN9UU;)W-T>6QE)UT["@H@("`@("`@("\O(%A86"!C=7)R96YT4&]R
M=%1Y<&4@:7,@0D%$"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/G!O<G14>7!E
M<ULD<&]R=%1Y<&5=(&%S("1O<&YA;64@/3X@)&]P97)A=&EO;BD@>PH@("`@
M("`@("`@("`D<V]A<&%C=&EO;B`](&ES<V5T*"1T:&ES+3YB:6YD:6YG<ULD
M<')I;6%R>4)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P;F%M95U;)W-O87!!
M8W1I;VXG72D@/PH@("`@("`@("`@("`@("`@)'1H:7,M/F)I;F1I;F=S6R1P
M<FEM87)Y0FEN9&EN9UU;)V]P97)A=&EO;G,G75LD;W!N86UE75LG<V]A<$%C
M=&EO;B==(#H*("`@("`@("`@("`@("`@(&YU;&P["B`@("`@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG;W!E
M<F%T:6]N<R==6R1O<&YA;65=6R=S='EL92==*2D@>PH@("`@("`@("`@("`@
M("`@)&]P<W1Y;&4@/2`D=&AI<RT^8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG
M75LG;W!E<F%T:6]N<R==6R1O<&YA;65=6R=S='EL92==.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]P<W1Y;&4@/2`D<W1Y;&4[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'5S92`]("1T:&ES+3YB:6YD
M:6YG<ULD<')I;6%R>4)I;F1I;F==6R=O<&5R871I;VYS)UU;)&]P;F%M95U;
M)VEN<'5T)UU;)W5S92==.PH@("`@("`@("`@("!I9B`H)'5S92`]/2`G96YC
M;V1E9"<I('L*("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`D=&AI<RT^
M8FEN9&EN9W-;)'!R:6UA<GE":6YD:6YG75LG;W!E<F%T:6]N<R==6R1O<&YA
M;65=6R=I;G!U="==6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1B:6YD:6YG5'EP92`]("1T:&ES+3YB:6YD
M:6YG<ULD<')I;6%R>4)I;F1I;F==6R=T>7!E)UT["B`@("`@("`@("`@("`@
M("`D;G,@/2`D=&AI<RT^<&]R=%1Y<&5S6R1B:6YD:6YG5'EP95U;)&]P;F%M
M95U;)VEN<'5T)UU;)VYA;65S<&%C92==.PH@("`@("`@("`@("`@("`@)&YA
M;65S<&%C92`]("1T:&ES+3YN86UE<W!A8V5S6R1N<UT["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("1A<F=S(#T@)R<["B`@("`@("`@("`@("1A<F=A
M<G)A>2`]("<G.PH@("`@("`@("`@("`D8V]M;65N=',@/2`G)SL*("`@("`@
M("`@("`@)'=R87!P97)S(#T@)R<["B`@("`@("`@("`@(&9O<F5A8V@@*"1O
M<&5R871I;VY;)VEN<'5T)UT@87,@)&%R9VYA;64@/3X@)&%R9W1Y<&4I('L*
M("`@("`@("`@("`@("`@(&EF("@D87)G;F%M92`]/2`G;65S<V%G92<I('L*
M("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^;65S<V%G97-;
M)&%R9W1Y<&5=(&%S("1?87)G;F%M92`]/B`D7V%R9W1Y<&4I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*"1O<'-T>6QE(#T]("=D;V-U;65N="<@
M)B8@)'5S92`]/2`G;&ET97)A;"<@)B8*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1?87)G='EP95LG;F%M92==(#T]("=P87)A;65T97)S)RD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AE('1Y<&4@;W(@96QE
M;65N="!R969E<F5D('1O(&ES('5S960*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(&9O<B!P87)A;65T97)S+@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5L871T<G,@/2!N=6QL.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&5L96UE;G0@/2`D7V%R9W1Y<&5;)V5L96UE;G0G73L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1E;"`]("1T:&ES+3YE;&5M96YT
M<ULD7V%R9W1Y<&5;)VYA;65S<&%C92==75LD7V%R9W1Y<&5;)W1Y<&4G75T[
M"@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1E;%LG8V]M<&QE
M>"==*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YA;65S
M<&%C92`]("1T:&ES+3YN86UE<W!A8V5S6R1?87)G='EP95LG;F%M97-P86-E
M)UU=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%A86"!N
M965D('1O('=R87`@=&AE('!A<F%M971E<G,@:6X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!A('-O87!?=F%L=64N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&5L6R=E;&5M96YT<R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E;%LG96QE;65N=',G72!A
M<R`D96QN86UE(#T^("1E;&%T=')S*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O($ES('1H92!E;&5M96YT(&$@8V]M<&QE>"!T
M>7!E/PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD96QA='1R<ULG;F%M97-P86-E
M)UU=6R1E;&YA;65=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-O;6UE;G1S("X]("1T:&ES+3Y?8V]M<&QE>%1Y<&5!
M<F<H)&%R9W,L("1A<F=A<G)A>2P@)%]A<F=T>7!E+"`D7V%R9VYA;64I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A9&1!<F<H)&%R9W,L("1A<F=A<G)A>2P@)&5L;F%M92D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)&5L6R=C;VUP
M;&5X)UT@)B8@)&%R9V%R<F%Y*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'=R87!N86UE(#T@)WLG("X@)'1H:7,M/FYA;65S<&%C97-;
M)%]A<F=T>7!E6R=N86UE<W!A8V4G75TN)WTG("X@)&5L6R=N86UE)UT["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;6UE;G1S("X]("(@
M("`@("`@(%PD>R1E;%LG;F%M92==?2`])B!N97<@4T]!4%]686QU92@G)'=R
M87!N86UE)RP@9F%L<V4L(%PD=B`](&%R<F%Y*"1A<F=A<G)A>2DI.UQN(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D87)G87)R87D@/2`B
M)WLD96Q;)VYA;64G77TG(#T^(%PD>R1E;%LG;F%M92==?2(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S
M970H)%]A<F=T>7!E6R=E;&5M96YT)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@16QE;65N="!A<F=U;65N="X*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D8V]M;65N=',@+CT@)'1H:7,M/E]E
M;&5M96YT07)G*"1A<F=S+"`D87)G87)R87DL("1?87)G='EP92P@)%]A<F=T
M>7!E6R=T>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!#;VUP
M;&5X('1Y<&4@87)G=6UE;G0N"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&-O;6UE;G1S("X]("1T:&ES+3Y?8V]M<&QE>%1Y<&5!<F<H)&%R
M9W,L("1A<F=A<G)A>2P@)%]A<F=T>7!E+"`D7V%R9VYA;64I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!686QI9&%T92!E;G1R:65S
M+@H*("`@("`@("`@("`@+R\@3W!E<F%T:6]N(&YA;65S(&%R92!F=6YC=&EO
M;B!N86UE<RP@<V\@=')Y('1O(&UA:V4@<W5R90H@("`@("`@("`@("`O+R!I
M="=S(&QE9V%L+B!4:&ES(&-O=6QD('!O=&5N=&EA;&QY(&-A=7-E(&-O;&QI
M<VEO;G,L"B`@("`@("`@("`@("\O(&)U="!L970G<R!T<GD@=&\@;6%K92!E
M=F5R>71H:6YG(&-A;&QA8FQE(&%N9"!S964@:&]W"B`@("`@("`@("`@("\O
M(&UA;GD@<')O8FQE;7,@=&AA="!C875S97,N"B`@("`@("`@("`@("1O<&YA
M;65?<&AP(#T@<')E9U]R97!L86-E*"<O6R`N7"U<*%PI72LO)RP@)U\G+"`D
M;W!N86UE*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E4W1R
M:6YG*"1O<&YA;65?<&AP*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D87)G87)R87DI
M('L*("`@("`@("`@("`@("`@("1A<F=A<G)A>2`](")A<G)A>2@D87)G87)R
M87DI(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1A
M<F=A<G)A>2`]("=N=6QL)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M)&-L87-S("X]("(@("`@9G5N8W1I;VX@)B1O<&YA;65?<&AP*"1A<F=S*5QN
M("`@('M<;B1C;VUM96YT<R1W<F%P<&5R<R(@+@H@("`@("`@("`@("`@("`@
M(B`@("`@("`@<F5T=7)N(%PD=&AI<RT^8V%L;"@G)&]P;F%M92<L7&XB("X*
M("`@("`@("`@("`@("`@("(@("`@("`@("`@("`@("`@("`@("`@("`@("!<
M)'8@/2`D87)G87)R87DL7&XB("X*("`@("`@("`@("`@("`@("(@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A<G)A>2@G;F%M97-P86-E)R`]/B`G)&YA
M;65S<&%C92<L7&XB("X*("`@("`@("`@("`@("`@("(@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G<V]A<&%C=&EO;B<@/3X@)R1S;V%P86-T
M:6]N)RQ<;B(@+@H@("`@("`@("`@("`@("`@(B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=S='EL92<@/3X@)R1O<'-T>6QE)RQ<;B(@+@H@
M("`@("`@("`@("`@("`@(B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=U<V4G(#T^("<D=7-E)R(@+@H@("`@("`@("`@("`@("`@*"1T:&ES
M+3YT<F%C93\B+%QN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)W1R86-E)R`]/B`Q(B`Z("<G*2`N("(I*3M<;B(@+@H@("`@("`@("`@("`@
M("`@(B`@("!]7&XB.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S("X](")]
M7&XB.PH@("`@("`@(')E='5R;B`D8VQA<W,["B`@("!]"@H@("`@9G5N8W1I
M;VX@9V5N97)A=&5!;&Q0<F]X:65S*"D*("`@('L*("`@("`@("`D<')O>'EC
M;V1E(#T@)R<["B`@("`@("`@9F]R96%C:"`H87)R87E?:V5Y<R@D=&AI<RT^
M<V5R=FEC97-;)'1H:7,M/G-E<G9I8V5=6R=P;W)T<R==*2!A<R`D:V5Y*2![
M"B`@("`@("`@("`@("1P;W)T(#TF("1T:&ES+3YS97)V:6-E<ULD=&AI<RT^
M<V5R=FEC95U;)W!O<G1S)UU;)&ME>5T["B`@("`@("`@("`@("1P<F]X>6-O
M9&4@+CT@)'1H:7,M/F=E;F5R871E4')O>'E#;V1E*"1P;W)T*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1P<F]X>6-O9&4["B`@("!]"@H@("`@9G5N
M8W1I;VX@)F=E=%!R;WAY*"1P;W)T(#T@)R<L("1N86UE(#T@)R<I"B`@("![
M"B`@("`@("`@)&UU;'1I<&]R="`](&-O=6YT*"1T:&ES+3YS97)V:6-E<ULD
M=&AI<RT^<V5R=FEC95U;)W!O<G1S)UTI(#X@,3L*"B`@("`@("`@:68@*"$D
M<&]R="D@>PH@("`@("`@("`@("!R97-E="@D=&AI<RT^<V5R=FEC97-;)'1H
M:7,M/G-E<G9I8V5=6R=P;W)T<R==*3L*("`@("`@("`@("`@)'!O<G0@/2!C
M=7)R96YT*"1T:&ES+3YS97)V:6-E<ULD=&AI<RT^<V5R=FEC95U;)W!O<G1S
M)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1M=6QT:7!O<G0@?'P@)'!O
M<G0I('L*("`@("`@("`@("`@)&-L87-S;F%M92`]("=796)397)V:6-E7R<@
M+B`D=&AI<RT^<V5R=FEC92`N("=?)R`N("1P;W)T6R=N86UE)UT["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&-L87-S;F%M92`]("=796)397)V
M:6-E7R<@+B`D=&AI<RT^<V5R=FEC93L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D;F%M92D@>PH@("`@("`@("`@("`D8VQA<W-N86UE(#T@)&YA;64@+B`G
M7R<@+B`D8VQA<W-N86UE.PH@("`@("`@('T*"B`@("`@("`@)&-L87-S;F%M
M92`]('!R96=?<F5P;&%C92@G+UL@+EPM7"A<*5TK+R<L("=?)RP@)&-L87-S
M;F%M92D["B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H)&-L87-S;F%M92DI
M('L*("`@("`@("`@("`@)'!R;WAY(#T@)'1H:7,M/F=E;F5R871E4')O>'E#
M;V1E*"1P;W)T+"`D8VQA<W-N86UE*3L*("`@("`@("`@("`@<F5Q=6ER95]O
M;F-E("=33T%0+T-L:65N="YP:'`G.PH@("`@("`@("`@("!E=F%L*"1P<F]X
M>2D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@;F5W("1C;&%S<VYA;64[
M"B`@("!]"@H@("`@9G5N8W1I;VX@)E]G971#;VUP;&5X5'EP949O<D5L96UE
M;G0H)&YA;64L("1N86UE<W!A8V4I"B`@("!["B`@("`@("`@)'0@/2!N=6QL
M.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;G-;)&YA;65S<&%C95TI("8F
M"B`@("`@("`@("`@(&ES<V5T*"1T:&ES+3YE;&5M96YT<ULD=&AI<RT^;G-;
M)&YA;65S<&%C95U=6R1N86UE75LG='EP92==*2D@>PH*("`@("`@("`@("`@
M)'1Y<&4@/2`D=&AI<RT^96QE;65N='-;)'1H:7,M/FYS6R1N86UE<W!A8V5=
M75LD;F%M95U;)W1Y<&4G73L*("`@("`@("`@("`@)&YS(#T@)'1H:7,M/F5L
M96UE;G1S6R1T:&ES+3YN<ULD;F%M97-P86-E75U;)&YA;65=6R=N86UE<W!A
M8V4G73L*"B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^8V]M<&QE>%1Y
M<&5S6R1N<UU;)'1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@)'0@/2`D=&AI
M<RT^8V]M<&QE>%1Y<&5S6R1N<UU;)'1Y<&5=.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B`D=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!G971#;VUP;&5X5'EP94YA;65&;W)%;&5M96YT*"1N86UE+"`D;F%M97-P
M86-E*0H@("`@>PH@("`@("`@("1T(#T@)'1H:7,M/E]G971#;VUP;&5X5'EP
M949O<D5L96UE;G0H)&YA;64L("1N86UE<W!A8V4I.PH@("`@("`@(&EF("@D
M="D@>PH@("`@("`@("`@("!R971U<FX@)'1;)VYA;64G73L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T
M0V]M<&QE>%1Y<&5#:&EL9%1Y<&4H)&YS+"`D;F%M92P@)&-H:6QD7VYS+"`D
M8VAI;&1?;F%M92D*("`@('L*("`@("`@("`O+R!I<R!T:&4@='EP92!A;B!E
M;&5M96YT/PH@("`@("`@("1T(#T@)'1H:7,M/E]G971#;VUP;&5X5'EP949O
M<D5L96UE;G0H)&YA;64L("1N<RD["B`@("`@("`@:68@*"1T*2!["B`@("`@
M("`@("`@("\O(&YO+"!G970@:70@9G)O;2!C;VUP;&5X('1Y<&5S(&1I<F5C
M=&QY"B`@("`@("`@("`@(&EF("AI<W-E="@D=%LG96QE;65N=',G75LD8VAI
M;&1?;F%M95U;)W1Y<&4G72DI"B`@("`@("`@("`@("`@("!R971U<FX@)'1;
M)V5L96UE;G1S)UU;)&-H:6QD7VYA;65=6R=T>7!E)UT["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H*("`@(&9U;F-T:6]N(&=E=%-C
M:&5M851Y<&4H)'1Y<&4L("1N86UE+"`D='EP95]N86UE<W!A8V4I"B`@("![
M"B`@("`@("`@+R\@<V5E(&EF(&ET)W,@82!C;VUP;&5X('1Y<&4@<V\@=V4@
M8V%N(&1E86P@<')O<&5R;'D@=VET:`H@("`@("`@("\O(%-/05!%3D,Z87)R
M87E4>7!E+@H@("`@("`@(&EF("@D;F%M92`F)B`D='EP92D@>PH@("`@("`@
M("`@("`O+R!86%@@5$]$3SH*("`@("`@("`@("`@+R\@;&]O:R!U<"!T:&4@
M;F%M92!I;B!T:&4@=W-D;"!A;F0@=F%L:61A=&4@=&AE('1Y<&4N"B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T:&ES+3YC;VUP;&5X5'EP97,@87,@)&YS(#T^
M("1T>7!E<RD@>PH@("`@("`@("`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES
M=',H)'1Y<&4L("1T>7!E<RDI('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M87)R87E?:V5Y7V5X:7-T<R@G='EP92<L("1T>7!E<ULD='EP95TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)&%R<F%Y='EP95]N<RP@)&%R
M<F%Y='EP92P@)&%R<F%Y7V1E<'1H*2`](&ES<V5T*"1T>7!E<ULD='EP95U;
M)V%R<F%Y5'EP92==*3\*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?9V5T1&5E<&5S=$%R<F%Y5'EP92@D='EP97-;)'1Y<&5=6R=N86UE
M<W!A8V4G72P@)'1Y<&5S6R1T>7!E75LG87)R87E4>7!E)UTI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`Z(&%R<F%Y*"1T:&ES+3YN86UE<W!A8V5S
M6R1T>7!E<ULD='EP95U;)VYA;65S<&%C92==72P@;G5L;"P@,"D["B`@("`@
M("`@("`@("`@("`@("`@("`@(')E='5R;B!A<G)A>2@D='EP97-;)'1Y<&5=
M6R=T>7!E)UTL("1A<G)A>71Y<&4L("1A<G)A>71Y<&5?;G,L("1A<G)A>5]D
M97!T:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=A<G)A>51Y<&4G+"`D='EP97-;
M)'1Y<&5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1A<G)A
M>71Y<&5?;G,L("1A<G)A>71Y<&4L("1A<G)A>5]D97!T:"D@/0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]G971$965P97-T07)R87E4
M>7!E*"1T>7!E<ULD='EP95U;)VYA;65S<&%C92==+"`D='EP97-;)'1Y<&5=
M6R=A<G)A>51Y<&4G72D["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!A<G)A>2@G07)R87DG+"`D87)R87ET>7!E+"`D87)R87ET>7!E7VYS+"`D
M87)R87E?9&5P=&@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G96QE;65N=',G+"`D
M='EP97-;)'1Y<&5=*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("!A<G)A
M>5]K97E?97AI<W1S*"1N86UE+"`D='EP97-;)'1Y<&5=6R=E;&5M96YT<R==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("1T>7!E<ULD
M='EP95U;)V5L96UE;G1S)UU;)W1Y<&4G73L*("`@("`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&%R<F%Y*"1T>7!E+"!N=6QL+"`D=&AI<RT^;F%M97-P
M86-E<ULD='EP97-;)'1Y<&5=6R=N86UE<W!A8V4G75TL(&YU;&PI.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)'1Y<&4@)B8@)'1Y<&5?;F%M
M97-P86-E*2!["B`@("`@("`@("`@("1A<G)A>51Y<&4@/2!N=6QL.PH@("`@
M("`@("`@("`O+R!86%@@5$]$3SH*("`@("`@("`@("`@+R\@=&AI<R!C;V1E
M(&-U<G)E;G1L>2!H86YD;&5S(&]N;'D@;VYE('=A>2!O9B!E;F-O9&EN9R!A
M<G)A>2!T>7!E<R!I;B!W<V1L"B`@("`@("`@("`@("\O(&YE960@=&\@9&\@
M82!G96YE<F%L:7IE9"!F=6YC=&EO;B!T;R!F:6=U<F4@;W5T(&-O;7!L97@@
M='EP97,*("`@("`@("`@("`@)'`@/2`D=&AI<RT^;G-;)'1Y<&5?;F%M97-P
M86-E73L*("`@("`@("`@("`@:68@*"1P("8F"B`@("`@("`@("`@("`@("!A
M<G)A>5]K97E?97AI<W1S*"1P+"`D=&AI<RT^8V]M<&QE>%1Y<&5S*2`F)@H@
M("`@("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@D='EP92P@)'1H:7,M
M/F-O;7!L97A4>7!E<ULD<%TI*2!["B`@("`@("`@("`@("`@("!I9B`H)&%R
M<F%Y5'EP92`]("1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG87)R
M87E4>7!E)UTI('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("=!<G)A
M>2<["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/F-O;7!L97A4
M>7!E<ULD<%U;)'1Y<&5=6R=O<F1E<B==/3TG<V5Q=65N8V4G("8F"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@G96QE;65N
M=',G+"`D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P75LD='EP95TI*2!["B`@("`@
M("`@("`@("`@("`@("`@<F5S970H)'1H:7,M/F-O;7!L97A4>7!E<ULD<%U;
M)'1Y<&5=6R=E;&5M96YT<R==*3L*("`@("`@("`@("`@("`@("`@("`O+R!A
M<W-U;64@86X@87)R87D*("`@("`@("`@("`@("`@("`@("!I9B`H8V]U;G0H
M)'1H:7,M/F-O;7!L97A4>7!E<ULD<%U;)'1Y<&5=6R=E;&5M96YT<R==*2`]
M/2`Q*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A<F<@/2!C=7)R96YT
M*"1T:&ES+3YC;VUP;&5X5'EP97-;)'!=6R1T>7!E75LG96QE;65N=',G72D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)G6R=T
M>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@)T%R<F%Y
M)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]M<&QE>%1Y<&5S6R1P75LD
M='EP95U;)V5L96UE;G1S)UT@87,@)&5L96UE;G0I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D96QE;65N=%LG;F%M92==(#T]("1T>7!E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%R<F%Y5'EP
M92`]("1E;&5M96YT6R=T>7!E)UT["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1Y<&4@/2`D96QE;65N=%LG='EP92==.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D='EP92`]("=3=')U8W0G.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1T
M>7!E+"`D87)R87E4>7!E+"`D='EP95]N86UE<W!A8V4L(&YU;&PI.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!A<G)A>2AN=6QL
M+"!N=6QL+"!N=6QL+"!N=6QL*3L*("`@('T*"B`@("`O*BH*("`@("`J(%)E
M8W5R<V4@=&AR;W5G:"!T:&4@5U-$3"!S=')U8W1U<F4@;&]O:VEN9R!F;W(@
M=&AE(&EN;F5R;6]S=`H@("`@("H@87)R87D@='EP92!O9B!M=6QT:2UD:6UE
M;G-I;VYA;"!A<G)A>7,N"B`@("`@*@H@("`@("H@5&%K97,@82!N86UE<W!A
M8V4@<')E9FEX(&%N9"!A('1Y<&4L('=H:6-H(&-A;B!B92!I;B!T:&4@9F]R
M;0H@("`@("H@)W1Y<&4G(&]R("=T>7!E6UTG+"!A;F0@<F5T=7)N<R!T:&4@
M9G5L;"!N86UE<W!A8V4@55))+"!T:&4*("`@("`J('1Y<&4@;V8@=&AE(&UO
M<W0@9&5E<&QY(&YE<W1E9"!A<G)A>2!T>7!E(&9O=6YD+"!A;F0@=&AE(&YU
M;6)E<@H@("`@("H@;V8@;&5V96QS(&]F(&YE<W1I;F<N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<F5T=7)N(&UI>&5D(&%R<F%Y
M(&]R(&YO=&AI;F<*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$1E97!E<W1!
M<G)A>51Y<&4H)&YS4')E9FEX+"`D87)R87E4>7!E*0H@("`@>PH@("`@("`@
M('-T871I8R`D=')A:6P@/2!A<G)A>2@I.PH*("`@("`@("`D87)R87E4>7!E
M(#T@97)E9U]R97!L86-E*"=<6UQ=)"<L("<G+"`D87)R87E4>7!E*3L*"B`@
M("`@("`@+R\@4')O=&5C="!A9V%I;G-T(&-I<F-U;&%R(')E9F5R96YC97,*
M("`@("`@("`O+R!86%@@5V4@<F5A;&QY(&YE960@=&\@<F5M;W9E('1R86EL
M(&9R;VT@=&AI<R!A;'1O9V5T:&5R("AI="=S('9E<GD@:6YE9F9I8VEE;G0@
M86YD"B`@("`@("`@+R\@:6X@=&AE('=R;VYG('!L86-E(2D@86YD('!U="!C
M:7)C=6QA<B!R969E<F5N8V4@8VAE8VMI;F<@:6X@=VAE;B!T:&4@5U-$3"!I
M;F9O"B`@("`@("`@+R\@:7,@9V5N97)A=&5D(&EN('1H92!F:7)S="!P;&%C
M90H@("`@("`@(&EF("AA<G)A>5]S96%R8V@H)&YS4')E9FEX("X@)SHG("X@
M)&%R<F%Y5'EP92P@)'1R86EL*2D@>PH@("`@("`@("`@("!R971U<FX@87)R
M87DH;G5L;"P@;G5L;"P@+6-O=6YT*"1T<F%I;"DI.PH@("`@("`@('T*"B`@
M("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)&YS4')E9FEX+"`D=&AI<RT^
M8V]M<&QE>%1Y<&5S*2`F)@H@("`@("`@("`@("!A<G)A>5]K97E?97AI<W1S
M*"1A<G)A>51Y<&4L("1T:&ES+3YC;VUP;&5X5'EP97-;)&YS4')E9FEX72D@
M)B8*("`@("`@("`@("`@87)R87E?:V5Y7V5X:7-T<R@G87)R87E4>7!E)RP@
M)'1H:7,M/F-O;7!L97A4>7!E<ULD;G-0<F5F:7A=6R1A<G)A>51Y<&5=*2D@
M>PH@("`@("`@("`@("`D=')A:6Q;72`]("1N<U!R969I>"`N("<Z)R`N("1A
M<G)A>51Y<&4["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7V=E=$1E
M97!E<W1!<G)A>51Y<&4H)'1H:7,M/F-O;7!L97A4>7!E<ULD;G-0<F5F:7A=
M6R1A<G)A>51Y<&5=6R=N86UE<W!A8V4G72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V]M<&QE
M>%1Y<&5S6R1N<U!R969I>%U;)&%R<F%Y5'EP95U;)V%R<F%Y5'EP92==*3L*
M("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"1R97-U;'1;,%TL("1R97-U;'1;
M,5TL("1R97-U;'1;,ET@*R`Q*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M(&%R<F%Y*"1T:&ES+3YN86UE<W!A8V5S6R1N<U!R969I>%TL("1A<G)A>51Y
M<&4L(#`I.PH@("`@?0H*?0H*8VQA<W,@4T]!4%]74T1,7T-A8VAE(&5X=&5N
M9',@4T]!4%]"87-E"GL*("`@("\O($-A8VAE('-E='1I;F=S"@H@("`@+RHJ
M"B`@("`@*B!5<V4@5U-$3"!C86-H90H@("`@("H*("`@("`J($!V87(@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)%]C86-H955S92`](&YU;&P["@H@("`@
M+RHJ"B`@("`@*B!#86-H92!M87@@;&EF971I;64@*&EN('-E8V]N9',I"B`@
M("`@*@H@("`@("H@0'9A<B!I;G0*("`@("`J+PH@("`@=F%R("1?8V%C:&5-
M87A!9V4@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4T]!4%]74T1,7T-A8VAE
M(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("!B;V]L96%N('5S
M92!C86-H:6YG"B`@("`@*B!`<&%R86T@(&EN="`@("`@8V%C:&4@;6%X(&QI
M9F5T:6UE("AI;B!S96-O;F1S*0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@4T]!4%]74T1,7T-A8VAE*"1C86-H955S92`]
M(%=31$Q?0T%#2$5?55-%+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C86-H94UA>$%G92`](%=31$Q?0T%#2$5?34%87T%'12D*("`@('L*("`@
M("`@("!P87)E;G0Z.E-/05!?0F%S92@G5U-$3$-!0TA%)RD["B`@("`@("`@
M)'1H:7,M/E]C86-H955S92`]("1C86-H955S93L*("`@("`@("`D=&AI<RT^
M7V-A8VAE36%X06=E(#T@)&-A8VAE36%X06=E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@7V-A8VAE1&ER"B`@("`@*B!R971U<FX@=&AE('!A=&@@=&\@=&AE
M(&-A8VAE+"!I9B!I="!D;V5S;B=T(&5X:7-T+"!M86ME(&ET"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]C86-H941I<B@I"B`@("!["B`@("`@("`@)&1I<B`]
M(&=E=&5N=B@B5U-$3$-!0TA%(BD["B`@("`@("`@:68@*"$D9&ER*2`D9&ER
M(#T@(B`N+W=S9&QC86-H92(["B`@("`@("`@0&UK9&ER*"1D:7(L(#`W,#`I
M.PH@("`@("`@(')E='5R;B`D9&ER.PH@("`@?0H*("`@("\J*@H@("`@("H@
M4F5T<FEE=F5S(&$@9FEL92!F<F]M(&-A8VAE(&EF(&ET(&5X:7-T<RP@;W1H
M97)W:7-E(')E=')E:79E(&9R;VT@;F5T+`H@("`@("H@861D('1O(&-A8VAE
M+"!A;F0@<F5T=7)N(&9R;VT@8V%C:&4N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!S=')I;F<@("!54DP@=&\@5U-$3`H@("`@("H@0'!A<F%M("!A<G)A>2`@
M("!P<F]X>2!P87)A;65T97)S"B`@("`@*B!`<&%R86T@(&EN="`@("`@(&5X
M<&5C=&5D($U$-2!O9B!74T1,(%523`H@("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("`J($!R971U<FX@<W1R:6YG("!D871A"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E="@D=W-D;%]F;F%M92P@)'!R;WAY7W!A<F%M<R`](&%R<F%Y*"DL
M("1C86-H92`](#`I"B`@("!["B`@("`@("`@)&-A8VAE;F%M92`]("1M9#5?
M=W-D;"`]("1F:6QE7V1A=&$@/2`G)SL*("`@("`@("!I9B`H)'1H:7,M/E]C
M86-H955S92D@>PH@("`@("`@("`@("`O+R!4<GD@=&\@<F5T<FEE=F4@5U-$
M3"!F<F]M(&-A8VAE"B`@("`@("`@("`@("1C86-H96YA;64@/2!33T%07U=3
M1$Q?0V%C:&4Z.E]C86-H941I<B@I("X@)R\G("X@;60U*"1W<V1L7V9N86UE
M*2X@)R`N=W-D;"<["B`@("`@("`@("`@(&EF("AF:6QE7V5X:7-T<R@D8V%C
M:&5N86UE*2D@>PH@("`@("`@("`@("`@("`@)'=F(#T@9F]P96XH)&-A8VAE
M;F%M92P@)W)B)RD["B`@("`@("`@("`@("`@("!I9B`H)'=F*2!["B`@("`@
M("`@("`@("`@("`@("`@+R\@4F5A9&EN9R!C86-H960@9FEL90H@("`@("`@
M("`@("`@("`@("`@("1F:6QE7V1A=&$@/2!F<F5A9"@D=V8L(&9I;&5S:7IE
M*"1C86-H96YA;64I*3L*("`@("`@("`@("`@("`@("`@("`D;60U7W=S9&P@
M/2!M9#4H)&9I;&5?9&%T82D["B`@("`@("`@("`@("`@("`@("`@9F-L;W-E
M*"1W9BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M)&-A8VAE*2!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C86-H92`A/2`D
M;60U7W=S9&PI('L*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U=31$P@0VAE8VMS=6T@97)R;W(A)RP@
M)'=S9&Q?9FYA;64I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&9I(#T@<W1A
M="@D8V%C:&5N86UE*3L*("`@("`@("`@("`@("`@("`@("`D8V%C:&5?;71I
M;64@/2`D9FE;.%T["B`@("`@("`@("`@("`@("`@("`@+R]P<FEN="!C86-H
M95]M=&EM92P@=&EM92@I"B`@("`@("`@("`@("`@("`@("`@:68@*"1C86-H
M95]M=&EM92`K("1T:&ES+3Y?8V%C:&5-87A!9V4@/"!T:6UE*"DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@+R\@97AP:7)E9`H@("`@("`@("`@("`@
M("`@("`@("`@("`D;60U7W=S9&P@/2`G)SL@+R\@<F5F971C:`H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D;60U7W=S9&PI('L*("`@("`@
M("`@("`@+R\@3F]T(&-A8VAE9"!O<B!N;W0@=7-I;F<@8V%C:&4N(%)E=')I
M979E(%=31$P@9G)O;2!54DP*"B`@("`@("`@("`@("\O(&ES(&ET(&$@;&]C
M86P@9FEL93\*("`@("`@("`@("`@+R\@=&AI<R!S96-T:6]N('-H;W5L9"!B
M92!R97!L86-E(&)Y(&-U<FP@870@<V]M92!P;VEN=`H@("`@("`@("`@("!I
M9B`H(7!R96=?;6%T8V@H)R]>*&AT='!S/WQF:6QE*3I<+UPO+R<L("1W<V1L
M7V9N86UE*2D@>PH@("`@("`@("`@("`@("`@:68@*"%F:6QE7V5X:7-T<R@D
M=W-D;%]F;F%M92DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@B56YA8FQE('1O(')E860@;&]C86P@5U-$
M3"`D=W-D;%]F;F%M92(L("1W<V1L7V9N86UE*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("AF=6YC=&EO;E]E>&ES=',H)V9I;&5?
M9V5T7V-O;G1E;G1S)RDI('L*("`@("`@("`@("`@("`@("`@("`D9FEL95]D
M871A(#T@9FEL95]G971?8V]N=&5N=',H)'=S9&Q?9FYA;64I.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D9FEL95]D
M871A(#T@:6UP;&]D92@G)RQF:6QE*"1W<V1L7V9N86UE*2D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=7)I(#T@97AP;&]D92@G/R<L("1W<V1L7V9N86UE*3L*("`@("`@("`@
M("`@("`@("1R<2`])B!N97<@2%144%]297%U97-T*"1U<FE;,%TL("1P<F]X
M>5]P87)A;7,I.PH@("`@("`@("`@("`@("`@+R\@=&AE('5S97(@86=E;G0@
M2%144%]297%U97-T('5S97,@9F]U;',@=&AI;F=S('5P"B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'5R:5LQ72DI('L*("`@("`@("`@("`@("`@("`@
M("`D<G$M/F%D9%)A=U%U97)Y4W1R:6YG*"1U<FE;,5TI.PH@("`@("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D<')O>'E?<&%R
M86US6R=P<F]X>5]H;W-T)UTI("8F"B`@("`@("`@("`@("`@("`@("`@:7-S
M970H)'!R;WAY7W!A<F%M<ULG<')O>'E?<&]R="==*2`F)@H@("`@("`@("`@
M("`@("`@("`@(&ES<V5T*"1P<F]X>5]P87)A;7-;)W!R;WAY7W5S97(G72D@
M)B8*("`@("`@("`@("`@("`@("`@("!I<W-E="@D<')O>'E?<&%R86US6R=P
M<F]X>5]P87-S)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)')Q+3YS9710
M<F]X>2@D<')O>'E?<&%R86US6R=P<F]X>5]H;W-T)UTL("1P<F]X>5]P87)A
M;7-;)W!R;WAY7W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P<F]X>5]P87)A;7-;)W!R;WAY7W5S97(G72P@)'!R;WAY7W!A
M<F%M<ULG<')O>'E?<&%S<R==*3L*("`@("`@("`@("`@("`@('T@96QS96EF
M("AI<W-E="@D<')O>'E?<&%R86US6R=P<F]X>5]H;W-T)UTI("8F"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@:7-S970H)'!R;WAY7W!A<F%M<ULG<')O
M>'E?<&]R="==*2D@>PH@("`@("`@("`@("`@("`@("`@("1R<2T^<V5T4')O
M>'DH)'!R;WAY7W!A<F%M<ULG<')O>'E?:&]S="==+"`D<')O>'E?<&%R86US
M6R=P<F]X>5]P;W)T)UTI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D<G$M/G-E;F1297%U97-T*"D["B`@("`@("`@
M("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5
M;F%B;&4@=&\@<F5T<FEE=F4@5U-$3"`D=W-D;%]F;F%M92PB("X@)')Q+3YG
M971297-P;VYS94-O9&4H*2P@)'=S9&Q?9FYA;64I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)&9I;&5?9&%T82`]("1R<2T^9V5T4F5S
M<&]N<V5";V1Y*"D["B`@("`@("`@("`@("`@("!I9B`H(21F:6QE7V1A=&$I
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O
M87!&875L="@B56YA8FQE('1O(')E=')I979E(%=31$P@)'=S9&Q?9FYA;64L
M(&YO(&AT='`@8F]D>2(L("1W<V1L7V9N86UE*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&UD-5]W<V1L(#T@;60U
M*"1F:6QE7V1A=&$I.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&55
M<V4I('L*("`@("`@("`@("`@("`@("1F<"`](&9O<&5N*"1C86-H96YA;64L
M(")W8B(I.PH@("`@("`@("`@("`@("`@9G=R:71E*"1F<"P@)&9I;&5?9&%T
M82D["B`@("`@("`@("`@("`@("!F8VQO<V4H)&9P*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/E]C86-H955S92`F)B`D
M8V%C:&4@)B8@)&-A8VAE("$]("1M9#5?=W-D;"D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@B5U-$3"!#:&5C:W-U;2!E
M<G)O<B$B+"`D=W-D;%]F;F%M92D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D9FEL95]D871A.PH@("`@?0H*?0H*8VQA<W,@4T]!4%]74T1,7U!A<G-E
M<B!E>'1E;F1S(%-/05!?0F%S90I["@H@("`@+RHJ"B`@("`@*B!$969I;F4@
M:6YT97)N86P@87)R87ES(&]F(&)I;F1I;F=S+"!P;W)T<RP@;W!E<F%T:6]N
M<RP*("`@("`J(&UE<W-A9V5S+"!E=&,N"B`@("`@*B\*("`@('9A<B`D8W5R
M<F5N=$UE<W-A9V4["B`@("!V87(@)&-U<G)E;G1/<&5R871I;VX["B`@("!V
M87(@)&-U<G)E;G10;W)T5'EP93L*("`@('9A<B`D8W5R<F5N=$)I;F1I;F<[
M"B`@("!V87(@)&-U<G)E;G10;W)T.PH*("`@("\J*@H@("`@("H@4&%R<V5R
M('9A<G,N"B`@("`@*B\*("`@('9A<B`D8V%C:&4["@H@("`@=F%R("1T;G,@
M/2!N=6QL.PH@("`@=F%R("1S;V%P;G,@/2!A<G)A>2@G<V]A<"<I.PH@("`@
M=F%R("1U<FD@/2`G)SL*("`@('9A<B`D=W-D;"`](&YU;&P["@H@("`@=F%R
M("1S=&%T=7,@/2`G)SL*("`@('9A<B`D96QE;65N=%]S=&%C:R`](&%R<F%Y
M*"D["B`@("!V87(@)'!A<F5N=$5L96UE;G0@/2`G)SL*"B`@("!V87(@)'-C
M:&5M82`]("<G.PH@("`@=F%R("1S8VAE;6%3=&%T=7,@/2`G)SL*("`@('9A
M<B`D<V-H96UA7W-T86-K(#T@87)R87DH*3L*("`@('9A<B`D8W5R<F5N=$-O
M;7!L97A4>7!E.PH@("`@=F%R("1S8VAE;6%?96QE;65N=%]S=&%C:R`](&%R
M<F%Y*"D["B`@("!V87(@)&-U<G)E;G1%;&5M96YT.PH*("`@("\J*@H@("`@
M("H@8V]N<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]74T1,
M7U!A<G-E<B@D=7)I+"`F)'=S9&PL("1D;V-S(#T@9F%L<V4I"B`@("!["B`@
M("`@("`@<&%R96YT.CI33T%07T)A<V4H)U=31$Q005)315(G*3L*("`@("`@
M("`D=&AI<RT^8V%C:&4@/28@;F5W(%-/05!?5U-$3%]#86-H92@D=W-D;"T^
M8V%C:&55<V4L("1W<V1L+3YC86-H94UA>$%G92D["B`@("`@("`@)'1H:7,M
M/G5R:2`]("1U<FD["B`@("`@("`@)'1H:7,M/G=S9&P@/2`F)'=S9&P["B`@
M("`@("`@)'1H:7,M/F1O8W,@/2`D9&]C<SL*("`@("`@("`D=&AI<RT^<&%R
M<V4H)'5R:2D["B`@("!]"@H@("`@9G5N8W1I;VX@<&%R<V4H)'5R:2D*("`@
M('L*("`@("`@("`O+R!#:&5C:R!W:&5T:&5R(&-O;G1E;G0@:&%S(&)E96X@
M<F5A9"X*("`@("`@("`D9F0@/2`D=&AI<RT^8V%C:&4M/F=E="@D=7)I+"`D
M=&AI<RT^=W-D;"T^<')O>'DI.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1F9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H)&9D*3L*("`@("`@("!]"@H@("`@("`@("\O($-R96%T92!A;B!8
M34P@<&%R<V5R+@H@("`@("`@("1P87)S97(@/2!X;6Q?<&%R<V5R7V-R96%T
M92@I.PH@("`@("`@('AM;%]P87)S97)?<V5T7V]P=&EO;B@D<&%R<V5R+"!8
M34Q?3U!424].7T-!4T5?1D],1$E.1RP@,"D["B`@("`@("`@>&UL7W-E=%]O
M8FIE8W0H)'!A<G-E<BP@)'1H:7,I.PH@("`@("`@('AM;%]S971?96QE;65N
M=%]H86YD;&5R*"1P87)S97(L("=S=&%R=$5L96UE;G0G+"`G96YD16QE;65N
M="<I.PH@("`@("`@(&EF("@D=&AI<RT^9&]C<RD@>PH@("`@("`@("`@("!X
M;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'!A<G-E<BP@)V-H87)A
M8W1E<D1A=&$G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A>&UL7W!A<G-E
M*"1P87)S97(L("1F9"P@=')U92DI('L*("`@("`@("`@("`@)&1E=&%I;"`]
M('-P<FEN=&8H)UA-3"!E<G)O<B!O;B!L:6YE("5D.B`E<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('AM;%]G971?8W5R<F5N=%]L:6YE7VYU
M;6)E<B@D<&%R<V5R*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'!A<G-E<BDI
M*3L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M(E5N86)L92!T;R!P87)S92!74T1,(&9I;&4@)'5R:5QN)&1E=&%I;"(I.PH@
M("`@("`@('T*("`@("`@("!X;6Q?<&%R<V5R7V9R964H)'!A<G-E<BD["B`@
M("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!S=&%R
M="UE;&5M96YT(&AA;F1L97(*("`@("`J+PH@("`@9G5N8W1I;VX@<W1A<G1%
M;&5M96YT*"1P87)S97(L("1N86UE+"`D871T<G,I"B`@("!["B`@("`@("`@
M+R\@1V5T(&5L96UE;G0@<')E9FEX+@H@("`@("`@("1Q;F%M92`])B!N97<@
M44YA;64H)&YA;64I.PH@("`@("`@(&EF("@D<6YA;64M/FYS*2!["B`@("`@
M("`@("`@("1N<R`]("1Q;F%M92T^;G,["B`@("`@("`@("`@(&EF("@D;G,@
M)B8@*"@A)'1H:7,M/G1N<R`F)B!S=')C87-E8VUP*"1Q;F%M92T^;F%M92P@
M)V1E9FEN:71I;VYS)RD@/3T@,"D@?'P@)&YS(#T]("1T:&ES+3YT;G,I*2![
M"B`@("`@("`@("`@("`@("`D;F%M92`]("1Q;F%M92T^;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`D=&AI<RT^8W5R<F5N=%1A9R`]
M("1Q;F%M92T^;F%M93L*("`@("`@("`D=&AI<RT^<&%R96YT16QE;65N="`]
M("<G.PH@("`@("`@("1S=&%C:U]S:7IE(#T@8V]U;G0H)'1H:7,M/F5L96UE
M;G1?<W1A8VLI.PH@("`@("`@(&EF("@D<W1A8VM?<VEZ92D@>PH@("`@("`@
M("`@("`D=&AI<RT^<&%R96YT16QE;65N="`]("1T:&ES+3YE;&5M96YT7W-T
M86-K6R1S=&%C:U]S:7IE("T@,5T["B`@("`@("`@?0H@("`@("`@("1T:&ES
M+3YE;&5M96YT7W-T86-K6UT@/2`D=&AI<RT^8W5R<F5N=%1A9SL*"B`@("`@
M("`@+R\@1FEN9"!S=&%T=7,L(')E9VES=&5R(&1A=&$N"B`@("`@("`@<W=I
M=&-H("@D=&AI<RT^<W1A='5S*2!["B`@("`@("`@8V%S92`G='EP97,G.@H@
M("`@("`@("`@("`O+R!S96-T(#(N,B!W<V1L.G1Y<&5S"B`@("`@("`@("`@
M("\O(&-H:6QD<F5N.B!X<V0Z<V-H96UA"B`@("`@("`@("`@("1P87)E;G1?
M=&%G(#T@)R<["B`@("`@("`@("`@("1S=&%C:U]S:7IE(#T@8V]U;G0H)'1H
M:7,M/G-C:&5M85]S=&%C:RD["B`@("`@("`@("`@(&EF("@D<W1A8VM?<VEZ
M92D@>PH@("`@("`@("`@("`@("`@)'!A<F5N=%]T86<@/2`D=&AI<RT^<V-H
M96UA7W-T86-K6R1S=&%C:U]S:7IE("T@,5T["B`@("`@("`@("`@('T*"B`@
M("`@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@
M(&-A<V4@)W-C:&5M82<Z"B`@("`@("`@("`@("`@("`O+R!.;R!P87)E;G0@
M<VAO=6QD(&)E(&EN('1H92!S=&%C:RX*("`@("`@("`@("`@("`@(&EF("@A
M)'!A<F5N=%]T86<@?'P@)'!A<F5N=%]T86<@/3T@)W1Y<&5S)RD@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=T87)G971.
M86UE<W!A8V4G+"`D871T<G,I*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YS8VAE;6$@/2`D=&AI<RT^=W-D;"T^9V5T3F%M97-P86-E071T
M<FEB=71E3F%M92@D871T<G-;)W1A<F=E=$YA;65S<&%C92==*3L*("`@("`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^<V-H96UA(#T@)'1H:7,M/G=S9&PM/F=E=$YA;65S<&%C94%T
M=')I8G5T94YA;64H)'1H:7,M/G=S9&PM/G1N<RD["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP
M;&5X5'EP97-;)'1H:7,M/G-C:&5M85T@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H96UA
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V-O;7!L97A4>7!E)SH*("`@
M("`@("`@("`@("`@(&EF("@D<&%R96YT7W1A9R`]/2`G<V-H96UA)RD@>PH@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&4@
M/2`D871T<G-;)VYA;64G73L*("`@("`@("`@("`@("`@("`@("!I9B`H(6ES
M<V5T*"1A='1R<ULG;F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("1A='1R<ULG;F%M97-P86-E)UT@/2`D=&AI<RT^<V-H96UA.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC
M=7)R96YT0V]M<&QE>%1Y<&5=(#T@)&%T=')S.PH@("`@("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=B87-E)RP@)&%T=')S*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R
M<ULG8F%S92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG='EP92==(#T@)'%N+3YN86UE.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES
M+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=N86UE<W!A
M8V4G72`]("1Q;BT^;G,["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4
M>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YS8VAE;6%3=&%T=7,@/2`G8V]M
M<&QE>%1Y<&4G.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M
M85U;)'1H:7,M/F-U<G)E;G1%;&5M96YT75LG8V]M<&QE>"==(#T@=')U93L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G96QE;65N="<Z"B`@("`@("`@("`@("`@("!I9B`H
M:7-S970H)&%T=')S6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@
M)'%N(#TF(&YE=R!13F%M92@D871T<G-;)W1Y<&4G72D["B`@("`@("`@("`@
M("`@("`@("`@)&%T=')S6R=T>7!E)UT@/2`D<6XM/FYA;64["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1Q;BT^;G,@)B8@87)R87E?:V5Y7V5X:7-T<R@D
M<6XM/FYS+"`D=&AI<RT^=W-D;"T^;F%M97-P86-E<RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)&%T=')S6R=N86UE<W!A8V4G72`]("1Q;BT^;G,[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@("`@("1P87)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@("`@
M("`@("`D<W1A8VM?<VEZ92`](&-O=6YT*"1T:&ES+3YS8VAE;6%?96QE;65N
M=%]S=&%C:RD["B`@("`@("`@("`@("`@("!I9B`H)'-T86-K7W-I>F4@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)'!A<F5N=$5L96UE;G0@/2`D=&AI
M<RT^<V-H96UA7V5L96UE;G1?<W1A8VM;)'-T86-K7W-I>F4@+2`Q73L*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)&%T
M=')S6R=R968G72DI('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W
M(%%.86UE*"1A='1R<ULG<F5F)UTI.PH@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC=7)R96YT16QE;65N="`]("1Q;BT^;F%M93L*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-U<G)E
M;G1%;&5M96YT(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A8VM;
M72`]("1T:&ES+3YC=7)R96YT16QE;65N=#L*("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&%T=')S6R=N86UE<W!A8V4G72DI('L*("`@("`@("`@("`@
M("`@("`@("`D871T<G-;)VYA;65S<&%C92==(#T@)'1H:7,M/G-C:&5M83L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("!I9B`H)'!A<F5N
M=%]T86<@/3T@)W-C:&5M82<I('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E
M;G1%;&5M96YT72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^96QE;65N='-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E
M;G1%;&5M96YT75LG8V]M<&QE>"==(#T@9F%L<V4["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G-C:&5M85-T871U<R`]("=E;&5M96YT)SL*("`@("`@
M("`@("`@("`@('T@96QS96EF("@D=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E
M*2!["B`@("`@("`@("`@("`@("`@("`@+R\@=V4G<F4@:6YS:61E(&$@8V]M
M<&QE>%1Y<&4*("`@("`@("`@("`@("`@("`@("!I9B`H*&ES<V5T*"1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)V]R9&5R)UTI("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS
M8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==(#T]
M("=S97%U96YC92<I"B`@("`@("`@("`@("`@("`@("`@("`@("8F("1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]/2`G07)R87DG*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;
M)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V%R
M<F%Y5'EP92==(#T@:7-S970H)&%T=')S6R=T>7!E)UTI(#\@)&%T=')S6R=T
M>7!E)UT@.B!N=6QL.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS
M8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=E;&5M96YT<R==
M6R1T:&ES+3YC=7)R96YT16QE;65N=%T@/2`D871T<G,["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YE;&5M96YT<ULD=&AI<RT^<V-H96UA75LD<&%R96YT16QE;65N=%U;)V5L
M96UE;G1S)UU;)'1H:7,M/F-U<G)E;G1%;&5M96YT72`]("1A='1R<SL*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@8V%S92`G8V]M<&QE>$-O;G1E;G0G.@H@("`@("`@("`@("!C87-E
M("=S:6UP;&5#;VYT96YT)SH*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@8V%S92`G97AT96YS:6]N)SH*("`@("`@("`@("`@8V%S92`G
M<F5S=')I8W1I;VXG.@H@("`@("`@("`@("`@("`@:68@*"1T:&ES+3YS8VAE
M;6%3=&%T=7,@/3T@)V-O;7!L97A4>7!E)RD@>PH@("`@("`@("`@("`@("`@
M("`@(&EF("@A96UP='DH)&%T=')S6R=B87-E)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1Q;B`])B!N97<@44YA;64H)&%T=')S6R=B87-E)UTI
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M<&QE
M>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y
M<&5=6R=T>7!E)UT@/2`D<6XM/FYA;64["@H@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!4>7!E<R!T:&%T(&5X=&5N9"!F<F]M(&]T:&5R('1Y<&5S(&%R
M96XG=`H@("`@("`@("`@("`@("`@("`@("`@("`O+R`J;V8J('1H;W-E('1Y
M<&5S+B!2969L96-T('1H:7,@8GD@9&5N;W1I;F<*("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@=VAI8V@@='EP92!T:&5Y(&5X=&5N9"X@22=M(&QE879I
M;F<@=&AE"B`@("`@("`@("`@("`@("`@("`@("`@("\O("=T>7!E)R!S971T
M:6YG(&AE<F4@<VEN8V4@22=M(&YO="!S=7)E('=H870*("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@<F5M;W9I;F<@:70@;6EG:'0@8G)E86L@870@=&AE
M(&UO;65N="X*("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1Q;F%M92T^
M;F%M92`]/2`G97AT96YS:6]N)RD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA
M75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG97AT96YD<R==(#T@)'%N
M+3YN86UE.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^
M8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)U-T<G5C="<["B`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=S97%U96YC92<Z"B`@
M("`@("`@("`@("`@("!I9B`H)'1H:7,M/G-C:&5M85-T871U<R`]/2`G8V]M
M<&QE>%1Y<&4G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E75LG;W)D97(G72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@
M("`@("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP
M97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;
M)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V%L;"<Z"B`@("`@("`@("`@("`@
M("`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T
M:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=O<F1E<B==(#T@)'%N86UE+3YN
M86UE.PH@("`@("`@("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=T>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^
M8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)U-T<G5C="<["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@(&-A<V4@)V-H;VEC92<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^=W-D
M;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT
M0V]M<&QE>%1Y<&5=6R=O<F1E<B==(#T@)'%N86UE+3YN86UE.PH@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S
M6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=6R=T
M>7!E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O
M;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L
M97A4>7!E75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@(&-A<V4@)V%T=')I8G5T92<Z"B`@("`@("`@("`@("`@
M("!I9B`H)'1H:7,M/G-C:&5M85-T871U<R`]/2`G8V]M<&QE>%1Y<&4G*2![
M"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG;F%M92==
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8V]M
M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M<&QE
M>%1Y<&5=6R=A='1R:6)U=&4G75LD871T<G-;)VYA;64G75T@/2`D871T<G,[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*&ES<V5T*"1A='1R<ULG<F5F)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<2`])B!N97<@44YA;64H)&%T=')S6R=R
M968G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M871T<G,@87,@)&L@/3X@)'8I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H)&L@(3T@)W)E9B<@)B8@<W1R<W1R*"1K+"`D<2T^;F%M
M92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9Q
M(#TF(&YE=R!13F%M92@D=BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@D<2T^;F%M92`]/2`G87)R87E4>7!E)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N
M=$-O;7!L97A4>7!E75LD<2T^;F%M95T@/2`D=G$M/FYA;64N("1V<2T^87)R
M87E);F9O.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG='EP92==(#T@)T%R<F%Y)SL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U
M<G)E;G1#;VUP;&5X5'EP95U;)VYA;65S<&%C92==(#T@)'9Q+3YN<SL*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW
M<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M/F-U<G)E
M;G1#;VUP;&5X5'EP95U;)'$M/FYA;65=(#T@)'9Q+3YN86UE.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3YS8VAE;6%?
M<W1A8VM;72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`O+R!S96-T(#(N
M,R!W<V1L.FUE<W-A9V4@8VAI;&0@=W-D;#IP87)T"B`@("`@("`@("`@('-W
M:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@(&-A<V4@)W!A<G0G
M.@H@("`@("`@("`@("`@("`@)'%N(#T@;G5L;#L*("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D871T<G-;)W1Y<&4G72DI('L*("`@("`@("`@("`@("`@
M("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==*3L*("`@("`@
M("`@("`@("`@('T@96QS96EF("AI<W-E="@D871T<G-;)V5L96UE;G0G72DI
M('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A='1R
M<ULG96QE;65N="==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("@D<6XI('L*("`@("`@("`@("`@("`@("`@("`D871T<G-;)W1Y
M<&4G72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@("`@("`@("`D871T<G-;
M)VYA;65S<&%C92==(#T@)'%N+3YN<SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YM97-S86=E<ULD=&AI<RT^8W5R
M<F5N=$UE<W-A9V5=6R1A='1R<ULG;F%M92==72`]("1A='1R<SL*("`@("`@
M("`@("`@("`@("\O(&5R<F]R(&EN('=S9&P*"B`@("`@("`@("`@(&-A<V4@
M)V1O8W5M96YT871I;VXG.@H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W!O
M<G14>7!E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C0*("`@("`@("`@("`@
M<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@8V%S92`G;W!E
M<F%T:6]N)SH*("`@("`@("`@("`@("`@("\O(&%T=')I8G5T97,Z(&YA;64*
M("`@("`@("`@("`@("`@("\O(&-H:6QD<F5N.B!W<V1L.FEN<'5T('=S9&PZ
M;W5T<'5T('=S9&PZ9F%U;'0*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R
M96YT3W!E<F%T:6]N(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@("`@
M("`D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y
M<&5=6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N72`]("1A='1R<SL*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G:6YP=70G.@H@
M("`@("`@("`@("!C87-E("=O=71P=70G.@H@("`@("`@("`@("!C87-E("=F
M875L="<Z"B`@("`@("`@("`@("`@("`O+R!W<V1L.FEN<'5T('=S9&PZ;W5T
M<'5T('=S9&PZ9F%U;'0*("`@("`@("`@("`@("`@("\O(&%T=')I8G5T97,Z
M(&YA;64@;65S<V%G92!P87)A;65T97)/<F1E<BAO<'1I;VYA;"D*("`@("`@
M("`@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=$]P97)A=&EO;BD@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^=W-D;"T^<&]R=%1Y
M<&5S6R1T:&ES+3YC=7)R96YT4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E
M<F%T:6]N75LD;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;
M)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1N86UE72`](&%R<F%Y7VUE<F=E
M*"1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP
M95U;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1N86UE72P@)&%T=')S*3L*
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1T:&ES+3YC=7)R96YT
M4&]R=%1Y<&5=6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD;F%M95T@/2`D
M871T<G,["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&EF("AA<G)A>5]K97E?97AI<W1S*"=M97-S86=E)RP@)&%T=')S*2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W(%%.86UE*"1A
M='1R<ULG;65S<V%G92==*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/G!O<G14>7!E<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E75LD
M=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)&YA;65=6R=M97-S86=E)UT@/2`D
M<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;)'1H:7,M/F-U
M<G)E;G1/<&5R871I;VY=6R1N86UE75LG;F%M97-P86-E)UT@/2`D<6XM/FYS
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G9&]C=6UE
M;G1A=&EO;B<Z"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G8FEN9&EN9R<Z
M"B`@("`@("`@("`@("1N<R`]("1Q;F%M92T^;G,@/R`D=&AI<RT^=W-D;"T^
M;F%M97-P86-E<ULD<6YA;64M/FYS72`Z(%-#2$5-05]74T1,.PH@("`@("`@
M("`@("!S=VET8V@@*"1N<RD@>PH@("`@("`@("`@("!C87-E(%-#2$5-05]3
M3T%0.@H@("`@("`@("`@("`@("`@+R\@=&AI<R!D96%L<R!W:71H('=S9&P@
M<V5C=&EO;B`S('-O87`@8FEN9&EN9PH@("`@("`@("`@("`@("`@<W=I=&-H
M("@D<6YA;64M/FYA;64I('L*("`@("`@("`@("`@("`@(&-A<V4@)V)I;F1I
M;F<G.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@,RXS"B`@("`@("`@
M("`@("`@("`@("`@+R\@<V]A<#IB:6YD:6YG+"!A='1R:6)U=&5S.B!T<F%N
M<W!O<G0H<F5Q=6ER960I+"!S='EL92AO<'1I;VYA;"P@9&5F875L="`](&1O
M8W5M96YT*0H@("`@("`@("`@("`@("`@("`@("\O(&EF('-T>6QE(&ES(&UI
M<W-I;F<L(&ET(&ES(&%S<W5M960@=&\@8F4@)V1O8W5M96YT)PH@("`@("`@
M("`@("`@("`@("`@(&EF("@A:7-S970H)&%T=')S6R=S='EL92==*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D871T<G-;)W-T>6QE)UT@/2`G9&]C
M=6UE;G0G.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD
M:6YG72`](&%R<F%Y7VUE<F=E*"1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI
M<RT^8W5R<F5N=$)I;F1I;F==+"`D871T<G,I.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V]P97)A=&EO;B<Z
M"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C="`S+C0*("`@("`@("`@("`@
M("`@("`@("`O+R!S;V%P.F]P97)A=&EO;BP@871T<FEB=71E<SH@<V]A<$%C
M=&EO;BAR97%U:7)E9"DL('-T>6QE*&]P=&EO;F%L+"!D969A=6QT(#T@<V]A
M<#IB:6YD:6YG.G-T>6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)&%T=')S6R=S='EL92==*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D871T<G-;)W-T>6QE)UT@/2`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H
M:7,M/F-U<G)E;G1":6YD:6YG75LG<W1Y;&4G73L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YW
M<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I
M;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U
M<G)E;G1":6YD:6YG75LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT3W!E
M<F%T:6]N72`](&%R<F%Y7VUE<F=E*"1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD
M=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H:7,M/F-U
M<G)E;G1/<&5R871I;VY=+"`D871T<G,I.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS
M)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=(#T@)&%T=')S.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@("`@("!C87-E("=B;V1Y)SH*("`@("`@("`@("`@("`@("`@
M("`O+R!S96-T(#,N-0H@("`@("`@("`@("`@("`@("`@("\O('-O87`Z8F]D
M>2!A='1R:6)U=&5S.@H@("`@("`@("`@("`@("`@("`@("\O('!A<G0@+2!O
M<'1I;VYA;"X@(&QI<W1E9"!P87)T<R!M=7-T(&%P<&5A<B!I;B!B;V1Y+"!M
M:7-S:6YG(&UE86YS(&%L;"!P87)T<R!A<'!E87(@:6X@8F]D>0H@("`@("`@
M("`@("`@("`@("`@("\O('5S92`M(')E<75I<F5D+B!E;F-O9&5D?&QI=&5R
M86P*("`@("`@("`@("`@("`@("`@("`O+R!E;F-O9&EN9U-T>6QE("T@;W!T
M:6]N86PN("!S<&%C92!S97!E<F%T960@;&ES="!O9B!E;F-O9&EN9W,@*'5R
M:2=S*0H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG
M<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F=="B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%LG;W!E<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT
M3W!E<F%T:6]N75LD=&AI<RT^;W!3=&%T=7-=(#T@)&%T=')S.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@("`@(&-A<V4@)V9A
M=6QT)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T(#,N-@H@("`@("`@
M("`@("`@("`@("`@("\O('-O87`Z9F%U;'0@871T<FEB=71E<SH@;F%M92!U
M<V4@(&5N8V]D:6YG4W1Y;&4@;F%M97-P86-E"B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN
M9UT*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6R=O<&5R
M871I;VYS)UU;)'1H:7,M/F-U<G)E;G1/<&5R871I;VY=6R1T:&ES+3YO<%-T
M871U<UT@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G:&5A9&5R)SH*("`@("`@("`@("`@("`@
M("`@("`O+R!S96-T(#,N-PH@("`@("`@("`@("`@("`@("`@("\O('-O87`Z
M:&5A9&5R(&%T=')I8G5T97,Z(&UE<W-A9V4@<&%R="!U<V4@96YC;V1I;F=3
M='EL92!N86UE<W!A8V4*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D
M;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG70H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!;)V]P97)A=&EO;G,G75LD=&AI
M<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H:7,M/F]P4W1A='5S75LG:&5A9&5R
M<R==6UT@/2`D871T<G,["B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("`@("`@8V%S92`G:&5A9&5R9F%U;'0G.@H@("`@("`@("`@
M("`@("`@("`@("\O('-E8W0@,RXW"B`@("`@("`@("`@("`@("`@("`@+R\@
M<V]A<#IH96%D97(@871T<FEB=71E<SH@;65S<V%G92!P87)T('5S92!E;F-O
M9&EN9U-T>6QE(&YA;65S<&%C90H@("`@("`@("`@("`@("`@("`@("1H96%D
M97(@/2!C;W5N="@D=&AI<RT^=W-D;"T^8FEN9&EN9W-;)'1H:7,M/F-U<G)E
M;G1":6YD:6YG70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!;)V]P97)A=&EO;G,G75LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)'1H
M:7,M/F]P4W1A='5S75LG:&5A9&5R<R==*2TQ.PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I
M;F=="B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%LG;W!E
M<F%T:6]N<R==6R1T:&ES+3YC=7)R96YT3W!E<F%T:6]N75LD=&AI<RT^;W!3
M=&%T=7-=6R=H96%D97)S)UU;)&AE861E<EU;)V9A=6QT)UT@/2`D871T<G,[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G9&]C=6UE;G1A=&EO;B<Z"B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("`@("`O+R!E<G)O<B$@(&YO="!A('9A;&ED(&5L96UE;G0@:6YS:61E(&)I
M;F1I;F<*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92!30TA%34%?5U-$3#H*("`@("`@("`@("`@("`@("\O(%A86"!V97)I9GD@
M8V]R<F5C="!N86UE<W!A8V4*("`@("`@("`@("`@("`@("\O(&9O<B!N;W<L
M(&1E9F%U;'0@:7,@=&AE("=W<V1L)R!N86UE<W!A8V4*("`@("`@("`@("`@
M("`@("\O(&]T:&5R('!O<W-I8FQE(&YA;65S<&%C97,@:6YC;'5D92!S;71P
M+"!H='1P+"!E=&,N(&9O<B!A;'1E<FYA=&4@8FEN9&EN9W,*("`@("`@("`@
M("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE*2!["B`@("`@("`@("`@("`@
M("!C87-E("=O<&5R871I;VXG.@H@("`@("`@("`@("`@("`@("`@("\O('-E
M8W0@,BXU"B`@("`@("`@("`@("`@("`@("`@+R\@=W-D;#IO<&5R871I;VX@
M871T<FEB=71E<SH@;F%M90H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT3W!E<F%T:6]N(#T@)&%T=')S6R=N86UE)UT["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G;W5T<'5T
M)SH*("`@("`@("`@("`@("`@(&-A<V4@)VEN<'5T)SH*("`@("`@("`@("`@
M("`@(&-A<V4@)V9A=6QT)SH*("`@("`@("`@("`@("`@("`@("`O+R!S96-T
M(#(N-0H@("`@("`@("`@("`@("`@("`@("\O('=S9&PZ:6YP=70@871T<FEB
M=71E<SH@;F%M90H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YO<%-T871U
M<R`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M"B`@("`@("`@("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N)SH*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E(%-#
M2$5-05]74T1,7TA45%`Z"B`@("`@("`@("`@("`@("!S=VET8V@@*"1Q;F%M
M92T^;F%M92D@>PH@("`@("`@("`@("`@("`@8V%S92`G8FEN9&EN9R<Z"B`@
M("`@("`@("`@("`@("`@("`@+R\@<V5C="`T+C0*("`@("`@("`@("`@("`@
M("`@("`O+R!H='1P.F)I;F1I;F<@871T<FEB=71E<SH@=F5R8@H@("`@("`@
M("`@("`@("`@("`@("\O('!A<F5N=#H@=W-D;#IB:6YD:6YG"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R
M96YT0FEN9&EN9UT@/2!A<G)A>5]M97)G92@D=&AI<RT^=W-D;"T^8FEN9&EN
M9W-;)'1H:7,M/F-U<G)E;G1":6YD:6YG72P@)&%T=')S*3L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=O<&5R
M871I;VXG.@H@("`@("`@("`@("`@("`@("`@("\O('-E8W0@-"XU"B`@("`@
M("`@("`@("`@("`@("`@+R\@:'1T<#IO<&5R871I;VX@871T<FEB=71E<SH@
M;&]C871I;VX*("`@("`@("`@("`@("`@("`@("`O+R!P87)E;G0Z('=S9&PZ
M;W!E<F%T:6]N"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F)I
M;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)V]P97)A=&EO;G,G70H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;ET@/2`D871T<G,[
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@
M8V%S92`G=7)L16YC;V1E9"<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C
M="`T+C8*("`@("`@("`@("`@("`@("`@("`O+R!H='1P.G5R;$5N8V]D960@
M871T<FEB=71E<SH@;&]C871I;VX*("`@("`@("`@("`@("`@("`@("`O+R!P
M87)E;G0Z('=S9&PZ:6YP=70@=W-D;#IO=71P=70@971C+@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD:6YG<ULD=&AI<RT^8W5R<F5N
M=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H:7,M/F]P4W1A='5S70H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P97)A=&EO;EU;)W5R:2==(#T@)W5R
M;$5N8V]D960G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@
M("`@("`@("`@(&-A<V4@)W5R;%)E<&QA8V5M96YT)SH*("`@("`@("`@("`@
M("`@("`@("`O+R!S96-T(#0N-PH@("`@("`@("`@("`@("`@("`@("\O(&AT
M='`Z=7)L4F5P;&%C96UE;G0@871T<FEB=71E<SH@;&]C871I;VX*("`@("`@
M("`@("`@("`@("`@("`O+R!P87)E;G0Z('=S9&PZ:6YP=70@=W-D;#IO=71P
M=70@971C+@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YB:6YD
M:6YG<ULD=&AI<RT^8W5R<F5N=$)I;F1I;F==6R=O<&5R871I;VYS)UU;)'1H
M:7,M/F]P4W1A='5S70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%LD=&AI<RT^8W5R<F5N=$]P97)A
M=&EO;EU;)W5R:2==(#T@)W5R;%)E<&QA8V5M96YT)SL*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=D;V-U;65N
M=&%T:6]N)SH*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@
M("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O(&5R<F]R
M"B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!C87-E(%-#2$5-05]-24U%.@H@("`@("`@("`@("`@
M("`@+R\@<V5C="`U"B`@("`@("`@("`@("`@("`O+R!A;&P@;6EM92!P87)T
M<R!A<F4@8VAI;&1R96X@;V8@=W-D;#II;G!U="P@=W-D;#IO=71P=70L(&5T
M8RX*("`@("`@("`@("`@("`@("\O('5N<W5P;W)T960@87,@;V8@>65T"B`@
M("`@("`@("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@
M("`@("`@("`@8V%S92`G8V]N=&5N="<Z"B`@("`@("`@("`@("`@("`@("`@
M+R\@<V5C="`U+C,@;6EM93IC;VYT96YT"B`@("`@("`@("`@("`@("`@("`@
M+R\@/&UI;64Z8V]N=&5N="!P87)T/2)N;71O:V5N(C\@='EP93TB<W1R:6YG
M(C\O/@H@("`@("`@("`@("`@("`@("`@("\O('!A<G0@871T<FEB=71E(&]N
M;'D@<F5Q=6ER960@:68@8V]N=&5N="!I<R!C:&EL9"!O9B!M=6QT:7!A<G0@
M<F5L871E9"P*("`@("`@("`@("`@("`@("`@("`O+R`@("`@("`@:70@8V]N
M=&%I;G,@=&AE(&YA;64@;V8@=&AE('!A<G0*("`@("`@("`@("`@("`@("`@
M("`O+R!T>7!E(&%T=')I8G5T92!C;VYT86EN<R!T:&4@;6EM92!T>7!E"B`@
M("`@("`@("`@("`@("!C87-E("=M=6QT:7!A<G1296QA=&5D)SH*("`@("`@
M("`@("`@("`@("`@("`O+R!S96-T(#4N-"!M:6UE.FUU;'1I<&%R=%)E;&%T
M960*("`@("`@("`@("`@("`@(&-A<V4@)W!A<G0G.@H@("`@("`@("`@("`@
M("`@8V%S92`G;6EM95AM;"<Z"B`@("`@("`@("`@("`@("`@("`@+R\@<V5C
M="`U+C8@;6EM93IM:6UE6&UL"B`@("`@("`@("`@("`@("`@("`@+R\@/&UI
M;64Z;6EM95AM;"!P87)T/2)N;71O:V5N(C\O/@H@("`@("`@("`@("`@("`@
M("`@("\O"B`@("`@("`@("`@("`@("!C87-E("=D;V-U;65N=&%T:6]N)SH*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D
M969A=6QT.@H@("`@("`@("`@("`@("`@("`@("\O(&5R<F]R"B`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!C87-E(%-#2$5-05]$24U%.@H@("`@("`@("`@("`@("`@+R\@1$E-
M12!I<R!D969I;F5D(&EN.@H@("`@("`@("`@("`@("`@+R\@:'1T<#HO+V=O
M=&1O=&YE="YC;VTO=&5A;2]X;6Q?=W-S<&5C<R]D:6UE+U=31$PM17AT96YS
M:6]N+69O<BU$24U%+FAT;0H@("`@("`@("`@("`@("`@+R\@86QL($1)344@
M<&%R=',@87)E(&-H:6QD<F5N(&]F('=S9&PZ:6YP=70L('=S9&PZ;W5T<'5T
M+"!E=&,N"B`@("`@("`@("`@("`@("`O+R!U;G-U<&]R=&5D(&%S(&]F('EE
M=`H@("`@("`@("`@("`@("`@<W=I=&-H("@D<6YA;64M/FYA;64I('L*("`@
M("`@("`@("`@("`@(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`@("`@
M("`@("\O('-E8W0@-"XQ(&1I;64Z;65S<V%G90H@("`@("`@("`@("`@("`@
M("`@("\O(&%P<&5A<G,@:6X@8FEN9&EN9R!S96-T:6]N"B`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT
M0FEN9&EN9UU;)V1I;64G72`]("1A='1R<SL*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@9&5F875L=#H*("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=S97)V:6-E
M)SH*("`@("`@("`@("`@)&YS(#T@)'%N86UE+3YN<R`_("1T:&ES+3YW<V1L
M+3YN86UE<W!A8V5S6R1Q;F%M92T^;G-=(#H@4T-(14U!7U=31$P["@H@("`@
M("`@("`@("!S=VET8V@@*"1Q;F%M92T^;F%M92D@>PH@("`@("`@("`@("!C
M87-E("=P;W)T)SH*("`@("`@("`@("`@("`@("\O('-E8W0@,BXV('=S9&PZ
M<&]R="!A='1R:6)U=&5S.B!N86UE(&)I;F1I;F<*("`@("`@("`@("`@("`@
M("1T:&ES+3YC=7)R96YT4&]R="`]("1A='1R<ULG;F%M92==.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R96YT
M4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T72`]("1A='1R
M<SL*("`@("`@("`@("`@("`@("\O(%A86"!H86-K('1O(&1E86P@=VET:"!B
M:6YD:6YG(&YA;65S<&%C97,*("`@("`@("`@("`@("`@("1Q;B`])B!N97<@
M44YA;64H)&%T=')S6R=B:6YD:6YG)UTI.PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R96YT4V5R=FEC95U;)W!O
M<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG8FEN9&EN9R==(#T@)'%N+3YN
M86UE.PH@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T
M:&ES+3YC=7)R96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10
M;W)T75LG;F%M97-P86-E)UT@/2`D<6XM/FYS.PH@("`@("`@("`@("`@("`@
M8G)E86L["@H@("`@("`@("`@("!C87-E("=A9&1R97-S)SH*("`@("`@("`@
M("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N=%-E
M<G9I8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT4&]R=%U;)V%D9')E<W,G
M72`]("1A='1R<SL*("`@("`@("`@("`@("`@("\O('=H870@5%E012!O9B!P
M;W)T(&ES(&ET/R`@4T]!4"!O<B!(5%10/PH@("`@("`@("`@("`@("`@)&YS
M(#T@)'%N86UE+3YN<R`_("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1Q;F%M
M92T^;G-=(#H@4T-(14U!7U=31$P["B`@("`@("`@("`@("`@("!S=VET8V@@
M*"1N<RD@>PH@("`@("`@("`@("`@("`@8V%S92!30TA%34%?5U-$3%](5%10
M.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD
M=&AI<RT^8W5R<F5N=%-E<G9I8V5=6R=P;W)T<R==6R1T:&ES+3YC=7)R96YT
M4&]R=%U;)W1Y<&4G73TG:'1T<"<["B`@("`@("`@("`@("`@("`@("`@8G)E
M86L["@H@("`@("`@("`@("`@("`@8V%S92!30TA%34%?4T]!4#H*("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'1H:7,M/F-U
M<G)E;G1397)V:6-E75LG<&]R=',G75LD=&AI<RT^8W5R<F5N=%!O<G1=6R=T
M>7!E)UT])W-O87`G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`@("`@+R\@
M4VAO=6QD;B=T(&AA<'!E;BP@=V4G;&P@87-S=6UE(%-/05`N"B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G-E<G9I8V5S6R1T:&ES+3YC=7)R
M96YT4V5R=FEC95U;)W!O<G1S)UU;)'1H:7,M/F-U<G)E;G10;W)T75LG='EP
M92==/2=S;V%P)SL*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@("`@(&-A<V4@)V1O8W5M96YT871I;VXG.@H@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(%1O<"!L979E;"!E;&5M96YT<R!F;W5N9"!U;F1E<B!W
M<V1L.F1E9FEN:71I;VYS+@H@("`@("`@('-W:71C:"`H)'%N86UE+3YN86UE
M*2!["B`@("`@("`@8V%S92`G:6UP;W)T)SH*("`@("`@("`@("`@+R\@<V5C
M="`R+C$N,2!W<V1L.FEM<&]R="!A='1R:6)U=&5S.B!N86UE<W!A8V4@;&]C
M871I;VX*("`@("`@("`@("`@:68@*"AI<W-E="@D871T<G-;)VQO8V%T:6]N
M)UTI('Q\(&ES<V5T*"1A='1R<ULG<V-H96UA3&]C871I;VXG72DI("8F"B`@
M("`@("`@("`@("`@("`A:7-S970H)'1H:7,M/G=S9&PM/FEM<&]R='-;)&%T
M=')S6R=N86UE<W!A8V4G75TI*2!["B`@("`@("`@("`@("`@("`D=7)I(#T@
M:7-S970H)&%T=')S6R=L;V-A=&EO;B==*2`_("1A='1R<ULG;&]C871I;VXG
M72`Z("1A='1R<ULG<V-H96UA3&]C871I;VXG73L*("`@("`@("`@("`@("`@
M("1L;V-A=&EO;B`]($!P87)S95]U<FPH)'5R:2D["B`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1L;V-A=&EO;ELG<V-H96UE)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@)&)A<V4@/2!`<&%R<V5?=7)L*"1T:&ES+3YU<FDI.PH@
M("`@("`@("`@("`@("`@("`@("1U<FD@/2`D=&AI<RT^;65R9V55<FPH)&)A
M<V4L("1U<FDI.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1T:&ES+3YW<V1L+3YI;7!O<G1S6R1A='1R<ULG;F%M97-P86-E)UU=(#T@
M)&%T=')S.PH@("`@("`@("`@("`@("`@)&EM<&]R=%]P87)S97)?8VQA<W,@
M/2!G971?8VQA<W,H)'1H:7,I.PH@("`@("`@("`@("`@("`@)&EM<&]R=%]P
M87)S97(@/28@;F5W("1I;7!O<G1?<&%R<V5R7V-L87-S*"1U<FDL("1T:&ES
M+3YW<V1L+"`D=&AI<RT^9&]C<RD["B`@("`@("`@("`@("`@("!I9B`H)&EM
M<&]R=%]P87)S97(M/F9A=6QT*2!["B`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'1H:7,M/G=S9&PM/FEM<&]R='-;)&%T=')S6R=N86UE<W!A8V4G75TI
M.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT26UP;W)T
M(#T@)&%T=')S6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`O+R!#;VYT:6YU92!O;B!T;R!T:&4@)W1Y<&5S)R!C87-E("T@;&%C
M:R!O9B!B<F5A:SL@:7,*("`@("`@("`@("`@+R\@:6YT96YT:6]N86PN"@H@
M("`@("`@(&-A<V4@)W1Y<&5S)SH*("`@("`@("`@("`@+R\@<V5C="`R+C(@
M=W-D;#IT>7!E<PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@)W1Y<&5S
M)SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@)W-C:&5M82<Z
M"B`@("`@("`@("`@("\O(%=E(&-A;B!H:70@=&AI<R!A="!T:&4@=&]P(&QE
M=F5L(&EF('=E)W9E(&)E96X@87-K960@=&\*("`@("`@("`@("`@+R\@:6UP
M;W)T(&%N(%A31"!F:6QE+@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1A='1R
M<ULG=&%R9V5T3F%M97-P86-E)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^<V-H96UA(#T@)'1H:7,M/G=S9&PM/F=E=$YA;65S<&%C94%T=')I8G5T
M94YA;64H)&%T=')S6R=T87)G971.86UE<W!A8V4G72D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D=&AI<RT^<V-H96UA(#T@)'1H
M:7,M/G=S9&PM/F=E=$YA;65S<&%C94%T=')I8G5T94YA;64H)'1H:7,M/G=S
M9&PM/G1N<RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA72`](&%R<F%Y*"D["B`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YE;&5M96YT<ULD=&AI<RT^<V-H96UA
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("1T:&ES+3YS8VAE;6%?<W1A8VM;
M72`]("1Q;F%M92T^;F%M93L*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]
M("=T>7!E<R<["B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E("=M
M97-S86=E)SH*("`@("`@("`@("`@+R\@<V5C="`R+C,@=W-D;#IM97-S86=E
M(&%T=')I8G5T97,Z(&YA;64@8VAI;&1R96XZ=W-D;#IP87)T"B`@("`@("`@
M("`@("1T:&ES+3YS=&%T=7,@/2`G;65S<V%G92<["B`@("`@("`@("`@(&EF
M("AI<W-E="@D871T<G-;)VYA;64G72DI('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YC=7)R96YT365S<V%G92`]("1A='1R<ULG;F%M92==.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G=S9&PM/FUE<W-A9V5S6R1T:&ES+3YC=7)R96YT
M365S<V%G95T@/2!A<G)A>2@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&)R96%K.PH*("`@("`@("!C87-E("=P;W)T5'EP92<Z"B`@("`@("`@("`@
M("\O('-E8W0@,BXT('=S9&PZ<&]R=%1Y<&4*("`@("`@("`@("`@+R\@871T
M<FEB=71E<SH@;F%M90H@("`@("`@("`@("`O+R!C:&EL9')E;CH@=W-D;#IO
M<&5R871I;VX*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=P;W)T5'EP
M92<["B`@("`@("`@("`@("1T:&ES+3YC=7)R96YT4&]R=%1Y<&4@/2`D871T
M<G-;)VYA;64G73L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/G!O<G14>7!E
M<ULD=&AI<RT^8W5R<F5N=%!O<G14>7!E72`](&%R<F%Y*"D["B`@("`@("`@
M("`@(&)R96%K.PH*("`@("`@("!C87-E("=B:6YD:6YG)SH*("`@("`@("`@
M("`@+R\@<V5C="`R+C4@=W-D;#IB:6YD:6YG(&%T=')I8G5T97,Z(&YA;64@
M='EP90H@("`@("`@("`@("`O+R!C:&EL9')E;CH@=W-D;#IO<&5R871I;VX@
M<V]A<#IB:6YD:6YG(&AT='`Z8FEN9&EN9PH@("`@("`@("`@("!I9B`H)'%N
M86UE+3YN<R`F)B`D<6YA;64M/FYS("$]("1T:&ES+3YT;G,I('L*("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M:&ES+3YS=&%T=7,@/2`G8FEN9&EN9R<["B`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT0FEN9&EN9R`]("1A='1R<ULG;F%M92==.PH@("`@("`@("`@("`D
M<6X@/28@;F5W(%%.86UE*"1A='1R<ULG='EP92==*3L*("`@("`@("`@("`@
M)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;
M)W1Y<&4G72`]("1Q;BT^;F%M93L*("`@("`@("`@("`@)'1H:7,M/G=S9&PM
M/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT0FEN9&EN9UU;)VYA;65S<&%C92==
M(#T@)'%N+3YN<SL*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)W-E<G9I8V4G.@H@("`@("`@("`@("`O+R!S96-T(#(N-R!W<V1L.G-E<G9I
M8V4@871T<FEB=71E<SH@;F%M92!C:&EL9')E;CH@<&]R=',*("`@("`@("`@
M("`@)'1H:7,M/F-U<G)E;G1397)V:6-E(#T@)&%T=')S6R=N86UE)UT["B`@
M("`@("`@("`@("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N
M=%-E<G9I8V5=6R=P;W)T<R==(#T@87)R87DH*3L*("`@("`@("`@("`@)'1H
M:7,M/G-T871U<R`]("=S97)V:6-E)SL*("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@(&-A<V4@)V1E9FEN:71I;VYS)SH*("`@("`@("`@("`@+R\@<V5C
M(#(N,2!W<V1L.F1E9FEN:71I;VYS"B`@("`@("`@("`@("\O(&%T=')I8G5T
M97,Z(&YA;64@=&%R9V5T3F%M97-P86-E('AM;&YS.BH*("`@("`@("`@("`@
M+R\@8VAI;&1R96XZ('=S9&PZ:6UP;W)T('=S9&PZ='EP97,@=W-D;#IM97-S
M86=E('=S9&PZ<&]R=%1Y<&4@=W-D;#IB:6YD:6YG('=S9&PZ<V5R=FEC90H@
M("`@("`@("`@("`D=&AI<RT^=W-D;"T^9&5F:6YI=&EO;B`]("1A='1R<SL*
M("`@("`@("`@("`@9F]R96%C:"`H)&%T=')S(&%S("1K97D@/3X@)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1K97DL("=X;6QN<SHG
M*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@("`D<6X@/28@;F5W
M(%%.86UE*"1K97DI.PH@("`@("`@("`@("`@("`@("`@("\O(%A86"!N965D
M('1O(')E9F%C=&]R(&YS(&AA;F1L:6YG+@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R1Q;BT^;F%M95T@/2`D=F%L=64[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FYS6R1V86QU95T@
M/2`D<6XM/FYA;64["B`@("`@("`@("`@("`@("`@("`@:68@*"1K97D@/3T@
M)W1A<F=E=$YA;65S<&%C92<@?'P*("`@("`@("`@("`@("`@("`@("`@("`@
M<W1R8V%S96-M<"@D=F%L=64L4T]!4%]30TA%34$I(#T](#`I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G-O87!N<UM=(#T@)'%N+3YN86UE
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AI;E]A<G)A>2@D=F%L=64L("1T:&ES+3Y?6$U,4V-H
M96UA*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/GAS9"`]("1V86QU93L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H:7-S970H)&YS*2`F)B`D;G,I('L*
M("`@("`@("`@("`@("`@("1N86UE<W!A8V4@/2`G>&UL;G,Z)R`N("1N<SL*
M("`@("`@("`@("`@("`@(&EF("@A)'1H:7,M/G=S9&PM/F1E9FEN:71I;VY;
M)&YA;65S<&%C95TI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/E]R86ES95-O87!&875L="@B<&%R<V4@97)R;W(L(&YO(&YA;65S<&%C
M92!F;W(@)&YA;65S<&%C92(L("1T:&ES+3YU<FDI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@)'1H:7,M/G1N<R`]("1N<SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!E;F0M96QE;65N="!H86YD;&5R+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!E;F1%;&5M96YT*"1P87)S97(L("1N86UE*0H@("`@>PH@
M("`@("`@("1S=&%C:W-I>F4@/2!C;W5N="@D=&AI<RT^96QE;65N=%]S=&%C
M:RD["B`@("`@("`@:68@*"1S=&%C:W-I>F4I('L*("`@("`@("`@("`@:68@
M*"1T:&ES+3YE;&5M96YT7W-T86-K6R1S=&%C:W-I>F4@+2`Q72`]/2`G9&5F
M:6YI=&EO;G,G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@
M)R<["B`@("`@("`@("`@('T*("`@("`@("`@("`@87)R87E?<&]P*"1T:&ES
M+3YE;&5M96YT7W-T86-K*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')I
M<W1R*"1N86UE+"`G<V-H96UA)RDI('L*("`@("`@("`@("`@87)R87E?<&]P
M*"1T:&ES+3YS8VAE;6%?<W1A8VLI.PH@("`@("`@("`@("`D=&AI<RT^<V-H
M96UA(#T@)R<["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/G-C:&5M
M82D@>PH@("`@("`@("`@("!A<G)A>5]P;W`H)'1H:7,M/G-C:&5M85]S=&%C
M:RD["B`@("`@("`@("`@(&EF("AC;W5N="@D=&AI<RT^<V-H96UA7W-T86-K
M*2`\/2`Q*2!["B`@("`@("`@("`@("`@("`O*B!#;W)R96-T('1H92!T>7!E
M(&9O<B!S97%U96YC97,@=VET:"!M=6QT:7!L90H@("`@("`@("`@("`@("`@
M("H@96QE;65N=',N("HO"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H
M:7,M/F-U<G)E;G1#;VUP;&5X5'EP92D@)B8@:7-S970H)'1H:7,M/G=S9&PM
M/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O
M;7!L97A4>7!E75LG='EP92==*0H@("`@("`@("`@("`@("`@("`@("8F("1T
M:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C:&5M85U;)'1H:7,M
M/F-U<G)E;G1#;VUP;&5X5'EP95U;)W1Y<&4G72`]/2`G07)R87DG"B`@("`@
M("`@("`@("`@("`@("`@)B8@87)R87E?:V5Y7V5X:7-T<R@G96QE;65N=',G
M+"`D=&AI<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T
M:&ES+3YC=7)R96YT0V]M<&QE>%1Y<&5=*0H@("`@("`@("`@("`@("`@("`@
M("8F(&-O=6YT*"1T:&ES+3YW<V1L+3YC;VUP;&5X5'EP97-;)'1H:7,M/G-C
M:&5M85U;)'1H:7,M/F-U<G)E;G1#;VUP;&5X5'EP95U;)V5L96UE;G1S)UTI
M(#X@,2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^
M8V]M<&QE>%1Y<&5S6R1T:&ES+3YS8VAE;6%=6R1T:&ES+3YC=7)R96YT0V]M
M<&QE>%1Y<&5=6R=T>7!E)UT@/2`G4W1R=6-T)SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H<W1R:7-T<B@D;F%M
M92P@)V-O;7!L97A4>7!E)RDI('L*("`@("`@("`@("`@("`@("1T:&ES+3YC
M=7)R96YT0V]M<&QE>%1Y<&4@/2`G)SL*("`@("`@("`@("`@("`@(&EF("AC
M;W5N="@D=&AI<RT^<V-H96UA7V5L96UE;G1?<W1A8VLI*2!["B`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@87)R87E?<&]P
M*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C:RD["B`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC=7)R96YT
M16QE;65N="`]("<G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R:7-T<B@D;F%M92P@)V5L96UE;G0G*2D@>PH@("`@("`@
M("`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YS8VAE;6%?96QE;65N=%]S=&%C
M:RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8W5R<F5N=$5L96UE
M;G0@/2!A<G)A>5]P;W`H)'1H:7,M/G-C:&5M85]E;&5M96YT7W-T86-K*3L*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/F-U<G)E;G1%;&5M96YT(#T@)R<["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!%;&5M96YT(&-O;G1E;G0@:&%N9&QE<BX*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VAA<F%C=&5R1&%T82@D<&%R<V5R+"`D9&%T82D*("`@('L*("`@("`@
M("`O+R!3=&]R92!T:&4@9&]C=6UE;G1A=&EO;B!I;B!T:&4@5U-$3"!F:6QE
M+@H@("`@("`@(&EF("@D=&AI<RT^8W5R<F5N=%1A9R`]/2`G9&]C=6UE;G1A
M=&EO;B<I('L*("`@("`@("`@("`@)&1A=&$@/2!T<FEM*'!R96=?<F5P;&%C
M92@G+UQS*R\G+"`G("<L("1D871A*2D["B`@("`@("`@("`@(&EF("@A<W1R
M;&5N*"1D871A*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!S=VET8V@@*"1T:&ES+3YS=&%T=7,I('L*
M("`@("`@("`@("`@8V%S92`G<V5R=FEC92<Z"B`@("`@("`@("`@("`@("`D
M<'1R(#TF("1T:&ES+3YW<V1L+3YS97)V:6-E<ULD=&AI<RT^8W5R<F5N=%-E
M<G9I8V5=.PH@("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C
M87-E("=P;W)T5'EP92<Z"B`@("`@("`@("`@("`@("`D<'1R(#TF("1T:&ES
M+3YW<V1L+3YP;W)T5'EP97-;)'1H:7,M/F-U<G)E;G10;W)T5'EP95U;)'1H
M:7,M/F-U<G)E;G1/<&5R871I;VY=.PH@("`@("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@("`@("!C87-E("=B:6YD:6YG)SH*("`@("`@("`@("`@("`@
M("1P='(@/28@)'1H:7,M/G=S9&PM/F)I;F1I;F=S6R1T:&ES+3YC=7)R96YT
M0FEN9&EN9UT["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@
M(&-A<V4@)VUE<W-A9V4G.@H@("`@("`@("`@("`@("`@)'!T<B`])B`D=&AI
M<RT^=W-D;"T^;65S<V%G97-;)'1H:7,M/F-U<G)E;G1-97-S86=E73L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G;W!E<F%T
M:6]N)SH*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S
M92`G='EP97,G.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YC
M=7)R96YT0V]M<&QE>%1Y<&4I("8F"B`@("`@("`@("`@("`@("`@("`@:7-S
M970H)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA75LD
M=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E72DI('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/F-U<G)E;G1%;&5M96YT*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1P='(@/28@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E
M<ULD=&AI<RT^<V-H96UA75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E75LG
M96QE;65N=',G75LD=&AI<RT^8W5R<F5N=$5L96UE;G1=.PH@("`@("`@("`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("1P
M='(@/28@)'1H:7,M/G=S9&PM/F-O;7!L97A4>7!E<ULD=&AI<RT^<V-H96UA
M75LD=&AI<RT^8W5R<F5N=$-O;7!L97A4>7!E73L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*&ES<V5T*"1P='(I
M*2!["B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1P=');)V1O8W5M96YT
M871I;VXG72DI('L*("`@("`@("`@("`@("`@("`@("`D<'1R6R=D;V-U;65N
M=&%T:6]N)UT@/2`G)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'!T<ELG9&]C=6UE;G1A=&EO;B==("X]("<@)SL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1P=');)V1O8W5M
M96YT871I;VXG72`N/2`D9&%T83L*("`@("`@("`@("`@?0H@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J("1P87)S960@:7,@86X@87)R87D@<F5T
M=7)N960@8GD@<&%R<V5?=7)L*"DN"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(&UE<F=E57)L*"1P87)S960L
M("1P871H*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)'!A<G-E9"DI
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@
M("`@)'5R:2`]("<G.PH@("`@("`@(&EF("@A96UP='DH)'!A<G-E9%LG<V-H
M96UE)UTI*2!["B`@("`@("`@("`@("1S97`@/2`H<W1R=&]L;W=E<B@D<&%R
M<V5D6R=S8VAE;64G72D@/3T@)VUA:6QT;R<@/R`G.B<@.B`G.B\O)RD["B`@
M("`@("`@("`@("1U<FD@/2`D<&%R<V5D6R=S8VAE;64G72`N("1S97`["B`@
M("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG<&%S<R==*2D@
M>PH@("`@("`@("`@("`D=7)I("X]("(D<&%R<V5D6W5S97)=.B1P87)S961;
M<&%S<UU`(CL*("`@("`@("!](&5L<V5I9B`H:7-S970H)'!A<G-E9%LG=7-E
M<B==*2D@>PH@("`@("`@("`@("`D=7)I("X]("(D<&%R<V5D6W5S97)=0"([
M"B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)'!A<G-E9%LG:&]S="==
M*2D@>PH@("`@("`@("`@("`D=7)I("X]("1P87)S961;)VAO<W0G73L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1P87)S961;)W!O<G0G72DI('L*
M("`@("`@("`@("`@)'5R:2`N/2`B.B1P87)S961;<&]R=%TB.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'!A=&A;,%T@(3T@)R\G("8F(&ES<V5T*"1P87)S
M961;)W!A=&@G72DI('L*("`@("`@("`@("`@:68@*"1P87)S961;)W!A=&@G
M75MS=')L96XH)'!A<G-E9%LG<&%T:"==*2`M(#%=("$]("<O)RD@>PH@("`@
M("`@("`@("`@("`@)'!A=&@@/2!D:7)N86UE*"1P87)S961;)W!A=&@G72D@
M+B`G+R<@+B`D<&%T:#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1P871H(#T@)'!A<G-E9%LG<&%T:"==("X@)'!A=&@["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'!A=&@@/2`D=&AI<RT^7VYO<FUA;&EZ
M92@D<&%T:"D["B`@("`@("`@?0H@("`@("`@("1S97`@/2`D<&%T:%LP72`]
M/2`G+R<@/R`G)R`Z("<O)SL*("`@("`@("`D=7)I("X]("1S97`@+B`D<&%T
M:#L*"B`@("`@("`@<F5T=7)N("1U<FD["B`@("!]"@H@("`@9G5N8W1I;VX@
M7VYO<FUA;&EZ92@D<&%T:%]S='(I"B`@("!["B`@("`@("`@)'!W9"`]("<G
M.PH@("`@("`@("1S=')!<G(@/2!P<F5G7W-P;&ET*"<O*%PO*2\G+"`D<&%T
M:%]S='(L("TQ+"!04D5'7U-03$E47TY/7T5-4%19*3L*("`@("`@("`D<'=D
M07)R(#T@)R<["B`@("`@("`@)&H@/2`P.PH@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\(&-O=6YT*"1S=')!<G(I.R`D:2LK*2!["B`@("`@("`@("`@(&EF
M("@D<W1R07)R6R1I72`A/2`G("XN)RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1S=')!<G);)&E=("$]("<@+B<I('L*("`@("`@("`@("`@("`@("`@("`D
M<'=D07)R6R1J72`]("1S=')!<G);)&E=.PH@("`@("`@("`@("`@("`@("`@
M("1J*RL["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!A<G)A>5]P;W`H)'!W9$%R<BD["B`@("`@("`@
M("`@("`@("`D:BTM.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M("1P4W1R(#T@:6UP;&]D92@G+R<L("1P=V1!<G(I.PH@("`@("`@("1P=V0@
M/2`H<W1R;&5N*"1P4W1R*2`^(#`I(#\@*"<O)R`N("1P4W1R*2`Z("<O)SL*
M("`@("`@("!R971U<FX@)'!W9#L*("`@('T*"GT*"B\J*@H@*B!087)S97,@
M=&AE('1Y<&5S(&%N9"!M971H;V1S('5S960@:6X@=V5B('-E<G9I8V4@;V)J
M96-T<R!I;G1O('1H92!I;G1E<FYA;`H@*B!D871A('-T<G5C='5R97,@=7-E
M9"!B>2!33T%07U=31$PN"B`J"B`J($%S<W5M97,@=&AE(%-/05!?5U-$3"!C
M;&%S<R!I<R!U;G!O<'5L871E9"!T;R!S=&%R="!W:71H+@H@*@H@*B!`875T
M:&]R($-H<FES($-O92`\:6YF;T!I;G1E;&QI9V5N='-T<F5A;6EN9RYC;VT^
M"B`J+PIC;&%S<R!33T%07U=31$Q?3V)J96-T4&%R<V5R(&5X=&5N9',@4T]!
M4%]"87-E"GL*("`@("\J*@H@("`@("H@5&%R9V5T(&YA;65S<&%C92!F;W(@
M=&AE(%=31$P@9&]C=6UE;G0@=VEL;"!H879E('1H92!F;VQL;W=I;F<*("`@
M("`J('!R969I>"X*("`@("`J+PH@("`@=F%R("1T;G-0<F5F:7@@/2`G=&YS
M)SL*"B`@("`O*BH*("`@("`J(%)E9F5R96YC92!T;R!T:&4@4T]!4%]74T1,
M(&]B:F5C="!T;R!P;W!U;&%T92X*("`@("`J+PH@("`@=F%R("1W<V1L(#T@
M;G5L;#L*"B`@("`O*BH@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R
M86T@("1O8FIE8W1S(%)E9F5R96YC92!T;R!T:&4@;V)J96-T(&]R(&%R<F%Y
M(&]F(&]B:F5C=',@=&\@<&%R<V4*("`@("`J($!P87)A;2`@)'=S9&P@4F5F
M97)E;F-E('1O('1H92!33T%07U=31$P@;V)J96-T('1O('!O<'5L871E"B`@
M("`@*B!`<&%R86T@("1T87)G971.86UE<W!A8V4@5&AE('1A<F=E="!N86UE
M<W!A8V4@;V8@<V-H96UA('1Y<&5S(&5T8RX*("`@("`J($!P87)A;2`@)'-E
M<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@("H@
M0'!A<F%M("`D<V5R=FEC95]D97-C($]P=&EO;F%L(&1E<V-R:7!T:6]N(&]F
M('1H92!74T1,(#QS97)V:6-E/@H@("`@("HO"B`@("!F=6YC=&EO;B!33T%0
M7U=31$Q?3V)J96-T4&%R<V5R*"8D;V)J96-T<RP@)B1W<V1L+"`D=&%R9V5T
M3F%M97-P86-E+"`D<V5R=FEC95]N86UE+"`D<V5R=FEC95]D97-C(#T@)R<I
M"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)U=31$Q/0DI%0U10
M05)315(G*3L*"B`@("`@("`@)'1H:7,M/G=S9&P@/2`F)'=S9&P["@H@("`@
M("`@("\O(%-E="!U<"!T:&4@4T]!4%]74T1,(&]B:F5C=`H@("`@("`@("1T
M:&ES+3Y?:6YI=&EA;&ES92@D<V5R=FEC95]N86UE*3L*"B`@("`@("`@+R\@
M4&%R<V4@96%C:"!W96(@<V5R=FEC92!O8FIE8W0*("`@("`@("`D=W-D;%]R
M968@/2`H:7-?87)R87DH)&]B:F5C=',I/R`D;V)J96-T<R`Z(&%R<F%Y*"8D
M;V)J96-T<RDI.PH*("`@("`@("!F;W)E86-H("@D=W-D;%]R968@87,@)')E
M9E]I=&5M*2!["B`@("`@("`@("`@(&EF("@A:7-?;V)J96-T*"1R969?:71E
M;2DI"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&
M875L="@G26YV86QI9"!W96(@<V5R=FEC92!O8FIE8W0@<&%S<V5D('1O(&]B
M:F5C="!P87)S97(G+"`G=7)N.B<@+B!G971?8VQA<W,H)&]B:F5C="DI.PH*
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?<&%R<V4H)')E9E]I=&5M+"`D=&%R
M9V5T3F%M97-P86-E+"`D<V5R=FEC95]N86UE*2`A/2!T<G5E*0H@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O+R!"=6EL9"!B
M:6YD:6YG<R!F<F]M(&%B<W1R86-T(&1A=&$N"B`@("`@("`@:68@*"1T:&ES
M+3YF875L="`]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?9V5N97)A
M=&5":6YD:6YG<T%N9%-E<G9I8V5S*"1T87)G971.86UE<W!A8V4L("1S97)V
M:6-E7VYA;64L("1S97)V:6-E7V1E<V,I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J($EN:71I86QI<V4@=&AE(%-/05!?5U-$3"!T<F5E("AD
M97-T<G5C=&EV92DN"B`@("`@*@H@("`@("H@268@=&AE(&]B:F5C="!H87,@
M86QR96%D>2!B965N(&EN:71I86QI<V5D+"!T:&4@;VYL>2!E9F9E8W0*("`@
M("`J('=I;&P@8F4@=&\@8VAA;F=E('1H92!T;G,@;F%M97-P86-E('1O('1H
M92!N97<@<V5R=FEC92!N86UE+@H@("`@("H*("`@("`J($!P87)A;2`@)'-E
M<G9I8V5?;F%M92!.86UE(&]F('1H92!74T1,(#QS97)V:6-E/@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I;FET:6%L
M:7-E*"1S97)V:6-E7VYA;64I"B`@("!["B`@("`@("`@+R\@4V5T('5P('1H
M92!B87-I8R!N86UE<W!A8V5S('1H870@86QL(%=31$P@9&5F:6YI=&EO;G,@
M=7-E+@H@("`@("`@("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R=W<V1L)UT@
M/2!30TA%34%?5U-$3#L@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(%=31$P@;&%N9W5A9V4*("`@("`@("`D=&AI<RT^=W-D;"T^
M;F%M97-P86-E<ULG<V]A<"==(#T@4T-(14U!7U-/05`[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!74T1,(%-/05`@8FEN9&EN
M9W,*("`@("`@("`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD=&AI<RT^=&YS
M4')E9FEX72`]("=U<FXZ)R`N("1S97)V:6-E7VYA;64[("`@("`@("`@("`@
M("`@("`O+R!487)G970@;F%M97-P86-E"B`@("`@("`@)'1H:7,M/G=S9&PM
M/FYA;65S<&%C97-;)WAS9"==(#T@87)R87E?<V5A<F-H*"=X<V0G+"`D=&AI
M<RT^7VYA;65S<&%C97,I.R`@("`@("`@("`@+R\@6$U,(%-C:&5M80H@("`@
M("`@("1T:&ES+3YW<V1L+3YN86UE<W!A8V5S6R=33T%0+45.0R==(#T@87)R
M87E?<V5A<F-H*"=33T%0+45.0R<L("1T:&ES+3Y?;F%M97-P86-E<RD[("\O
M(%-/05`@='EP97,*"B`@("`@("`@+R\@6%A8(%)E9F%C=&]R("1N86UE<W!A
M8V4O)&YS(&9O<B!3:&%N92`Z+2D*("`@("`@("!U;G-E="@D=&AI<RT^=W-D
M;"T^;G-;)W5R;CHG("X@)'-E<G9I8V5?;F%M95TI.PH@("`@("`@("1T:&ES
M+3YW<V1L+3YN<R`K/2!A<G)A>5]F;&EP*"1T:&ES+3YW<V1L+3YN86UE<W!A
M8V5S*3L*"B`@("`@("`@+R\@26UP;W)T<R!A<F4@;F]T(&EM<&QE;65N=&5D
M(&EN(%=31$P@9V5N97)A=&EO;B!F<F]M(&-L87-S97,N"B`@("`@("`@+R\@
M*BHJ(#QW<V1L.FEM<&]R=#X@*BHJ"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0
M87)S97(@+2!T86ME<R!A('-I;F=L92!O8FIE8W0@=&\@861D('1O('1R964*
M("`@("`J("AN;VXM9&5S=')U8W1I=F4I+@H@("`@("H*("`@("`J($!P87)A
M;2`@)&]B:F5C="!2969E<F5N8V4@=&\@=&AE(&]B:F5C="!T;R!P87)S90H@
M("`@("H@0'!A<F%M("`D<V5R=FEC95]N86UE($YA;64@;V8@=&AE(%=31$P@
M/'-E<G9I8V4^"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F
M=6YC=&EO;B!?<&%R<V4H)B1O8FIE8W0L("1S8VAE;6%.86UE<W!A8V4L("1S
M97)V:6-E7VYA;64I"B`@("!["B`@("`@("`@+R\@0W)E871E(&YA;65S<&%C
M92!P<F5F:7@@9F]R('1H92!S8VAE;6$*("`@("`@("`O+R!86%@@;F]T('9E
M<GD@96QE9V%N="`Z+2@*"B`@("`@("`@;&ES="@D<V-H4')E9FEX+"`D9F]O
M*2`]("1T:&ES+3Y?9V5T5'EP94YS*"=[)R`N("1S8VAE;6%.86UE<W!A8V4N
M)WTG*3L*("`@("`@("!U;G-E="@D9F]O*3L*"B`@("`@("`@+R\@4&%R<V4@
M86QL('1H92!T>7!E<R!D969I;F5D(&)Y('1H92!O8FIE8W0@:6X@=VAA=&5V
M97(*("`@("`@("`O+R!S8VAE;6$@;&%N9W5A9V4@=V4@87)E('5S:6YG("AC
M=7)R96YT;'D@7U]T>7!E9&5F(&%R<F%Y<RD*("`@("`@("`O+R`J*BH@/'=S
M9&PZ='EP97,^("HJ*@H*("`@("`@("!F;W)E86-H("@D;V)J96-T+3Y?7W1Y
M<&5D968@87,@)'1Y<&5.86UE(#T^("1T>7!E5F%L=64I('L*("`@("`@("`@
M("`@+R\@1V5T+V-R96%T92!N86UE<W!A8V4@9&5F:6YI=&EO;@H*("`@("`@
M("`@("`@;&ES="@D;G-0<F5F:7@L("1T>7!E3F%M92D@/2`D=&AI<RT^7V=E
M=%1Y<&5.<R@D='EP94YA;64I.PH*("`@("`@("`@("`@+R\@0W)E871E('1Y
M<&4@9&5F:6YI=&EO;@H*("`@("`@("`@("`@)'1H:7,M/G=S9&PM/F-O;7!L
M97A4>7!E<ULD<V-H4')E9FEX75LD='EP94YA;65=(#T@87)R87DH)VYA;64G
M(#T^("1T>7!E3F%M92D["B`@("`@("`@("`@("1T:&ES5'EP92`])B`D=&AI
M<RT^=W-D;"T^8V]M<&QE>%1Y<&5S6R1S8VA0<F5F:7A=6R1T>7!E3F%M95T[
M"@H@("`@("`@("`@("`O+R!!8V-O<F1I;F<@=&\@1&UI=')I)W,@9&]C=6UE
M;G1A=&EO;BP@7U]T>7!E9&5F(&-O;65S(&EN('1W;PH@("`@("`@("`@("`O
M+R!F;&%V;W)S.@H@("`@("`@("`@("`O+R!!<G)A>2`](&%R<F%Y*&%R<F%Y
M*")I=&5M(B`]/B`B=F%L=64B*2D*("`@("`@("`@("`@+R\@4W1R=6-T(#T@
M87)R87DH(FET96TQ(B`]/B`B=F%L=64Q(BP@(FET96TR(B`]/B`B=F%L=64R
M(BP@+BXN*0H*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1T>7!E5F%L=64I
M*2!["B`@("`@("`@("`@("`@("!R97-E="@D='EP959A;'5E*3L*("`@("`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2AC=7)R96YT*"1T>7!E5F%L=64I*2`F
M)B!C;W5N="@D='EP959A;'5E*2`]/2`Q"B`@("`@("`@("`@("`@("`@("`@
M)B8@8V]U;G0H8W5R<F5N="@D='EP959A;'5E*2D@/3T@,2D@>PH@("`@("`@
M("`@("`@("`@("`@("\O($ET)W,@86X@87)R87D*"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7-4>7!E6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@("`@
M("`@("`@("`@(')E<V5T*&-U<G)E;G0H)'1Y<&5686QU92DI.PH@("`@("`@
M("`@("`@("`@("`@(&QI<W0H)&YS4')E9FEX+"`D='EP94YA;64I(#T@)'1H
M:7,M/E]G9714>7!E3G,H8W5R<F5N="AC=7)R96YT*"1T>7!E5F%L=64I*2D[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=N86UE<W!A8V4G72`]
M("1N<U!R969I>#L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V%R
M<F%Y5'EP92==(#T@)'1Y<&5.86UE("X@)UM=)SL*("`@("`@("`@("`@("`@
M('T@96QS96EF("@A:7-?87)R87DH8W5R<F5N="@D='EP959A;'5E*2DI('L*
M("`@("`@("`@("`@("`@("`@("`O+R!)="=S(&$@<W1R=6-T"@H@("`@("`@
M("`@("`@("`@("`@("1T:&ES5'EP95LG='EP92==(#T@)U-T<G5C="<["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=O<F1E<B==(#T@)V%L;"<[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7-4>7!E6R=N86UE<W!A8V4G72`]
M("1N<U!R969I>#L*("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L
M96UE;G1S)UT@/2!A<G)A>2@I.PH*("`@("`@("`@("`@("`@("`@("!F;W)E
M86-H("@D='EP959A;'5E(&%S("1E;&5M96YT3F%M92`]/B`D96QE;65N=%1Y
M<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@;&ES="@D;G-0<F5F:7@L
M("1T>7!E3F%M92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D96QE;65N=%1Y<&4I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE;G1S
M)UU;)&5L96UE;G1.86UE75LG;F%M92==(#T@)&5L96UE;G1.86UE.PH@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE;G1S)UU;)&5L
M96UE;G1.86UE75LG='EP92==(#T@)'1Y<&5.86UE.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=&AI<U1Y<&5;)V5L96UE;G1S)UU;)&5L96UE;G1.86UE
M75LG;F%M97-P86-E)UT@/2`D;G-0<F5F:7@["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`O+R!)="=S(&5R<F]N96]U<PH@("`@("`@("`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")4:&4@='EP92!D969I;FET
M:6]N(&9O<B`D;G-0<F5F:7@Z)'1Y<&5.86UE(&ES(&EN=F%L:60N(BP@)W5R
M;CHG("X@9V5T7V-L87-S*"1O8FIE8W0I*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O($ET)W,@
M97)R;VYE;W5S"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES
M95-O87!&875L="@B5&AE('1Y<&4@9&5F:6YI=&EO;B!F;W(@)&YS4')E9FEX
M.B1T>7!E3F%M92!I<R!I;G9A;&ED+B(L("=U<FXZ)R`N(&=E=%]C;&%S<R@D
M;V)J96-T*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O
M($-R96%T92!A;B!E;7!T>2!E;&5M96YT(&%R<F%Y('=I=&@@=&AE('1A<F=E
M="!N86UE<W!A8V4*("`@("`@("`O+R!P<F5F:7@L('1O(&UA=&-H('1H92!R
M97-U;'1S(&]F(%=31$P@<&%R<VEN9RX*"B`@("`@("`@)'1H:7,M/G=S9&PM
M/F5L96UE;G1S6R1S8VA0<F5F:7A=(#T@87)R87DH*3L*"B`@("`@("`@+R\@
M4&]P=6QA=&4@=')E92!W:71H(&UE<W-A9V4@:6YF;W)M871I;VX*("`@("`@
M("`O+R`J*BH@/'=S9&PZ;65S<V%G93X@*BHJ"@H@("`@("`@(&9O<F5A8V@@
M*"1O8FIE8W0M/E]?9&ES<&%T8VA?;6%P(&%S("1O<&5R871I;VY.86UE(#T^
M("1M97-S86=E<RD@>PH@("`@("`@("`@("!F;W)E86-H("@D;65S<V%G97,@
M87,@)&UE<W-A9V54>7!E(#T^("1M97-S86=E4&%R=',I('L*("`@("`@("`@
M("`@("`@('5N<V5T*"1T:&ES365S<V%G92D["@H@("`@("`@("`@("`@("`@
M<W=I=&-H("@D;65S<V%G951Y<&4I('L*("`@("`@("`@("`@("`@(&-A<V4@
M)VEN)SH*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^=W-D;"T^;65S<V%G
M97-;)&]P97)A=&EO;DYA;64@+B`G4F5Q=65S="==(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<TUE<W-A9V4@/28@)'1H:7,M/G=S9&PM
M/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@)U)E<75E<W0G73L*("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=O
M=70G.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3YW<V1L+3YM97-S86=E
M<ULD;W!E<F%T:6]N3F%M92`N("=297-P;VYS92==(#T@87)R87DH*3L*("`@
M("`@("`@("`@("`@("`@("`D=&AI<TUE<W-A9V4@/28@)'1H:7,M/G=S9&PM
M/FUE<W-A9V5S6R1O<&5R871I;VY.86UE("X@)U)E<W!O;G-E)UT["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("`@("`@8V%S92`G
M86QI87,G.@H@("`@("`@("`@("`@("`@("`@("\O($1O(&YO=&AI;F<*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A
M=6QT.@H@("`@("`@("`@("`@("`@("`@("\O($5R<F]R(&-O;F1I=&EO;@H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<TUE<W-A9V4I*2!["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UE<W-A9V5087)T<R!A<R`D
M<&%R=$YA;64@/3X@)'!A<G14>7!E*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@(&QI<W0@*"1N<U!R969I>"P@)'1Y<&5.86UE*2`]("1T:&ES+3Y?9V5T
M5'EP94YS*"1P87)T5'EP92D["@H@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<TUE<W-A9V5;)'!A<G1.86UE72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VYA;64G(#T^("1P87)T3F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=T>7!E)R`]/B`D='EP94YA;64L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D;G-0<F5F
M:7@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!0;W!U;&%T92!T<F5E('=I=&@@<&]R=%1Y
M<&4@:6YF;W)M871I;VX*("`@("`@("`O+R!86%@@0W5R<F5N="!I;7!L96UE
M;G1A=&EO;B!O;FQY('-U<'!O<G1S(&]N92!P;W)T5'EP92!T:&%T"B`@("`@
M("`@+R\@96YC;VUP87-S97,@86QL(&]F('1H92!O<&5R871I;VYS(&%V86EL
M86)L92X*("`@("`@("`O+R`J*BH@/'=S9&PZ<&]R=%1Y<&4^("HJ*@H*("`@
M("`@("!I9B`H(6ES<V5T*"1T:&ES+3YW<V1L+3YP;W)T5'EP97-;)'-E<G9I
M8V5?;F%M92`N("=0;W)T)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YW<V1L
M+3YP;W)T5'EP97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UT@/2!A<G)A>2@I
M.PH@("`@("`@('T*("`@("`@("`D=&AI<U!O<G14>7!E(#TF("1T:&ES+3YW
M<V1L+3YP;W)T5'EP97-;)'-E<G9I8V5?;F%M92`N("=0;W)T)UT["@H@("`@
M("`@(&9O<F5A8V@@*"1O8FIE8W0M/E]?9&ES<&%T8VA?;6%P(&%S("1O<&5R
M871I;VY.86UE(#T^("1M97-S86=E<RD@>PH@("`@("`@("`@("`D=&AI<U!O
M<G14>7!E6R1O<&5R871I;VY.86UE72`](&%R<F%Y*"=N86UE)R`]/B`D;W!E
M<F%T:6]N3F%M92D["@H@("`@("`@("`@("!F;W)E86-H("@D;65S<V%G97,@
M87,@)&UE<W-A9V54>7!E(#T^("1M97-S86=E4&%R=',I('L*("`@("`@("`@
M("`@("`@('-W:71C:"`H)&UE<W-A9V54>7!E*2!["B`@("`@("`@("`@("`@
M("!C87-E("=I;B<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7-0;W)T5'EP
M95LD;W!E<F%T:6]N3F%M95U;)VEN<'5T)UT@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@)VUE<W-A9V4G(#T^("1O<&5R871I;VY.86UE("X@
M)U)E<75E<W0G+`H@("`@("`@("`@("`@("`@("`@("`@("`G;F%M97-P86-E
M)R`]/B`D=&AI<RT^=&YS4')E9FEX*3L*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*"B`@("`@("`@("`@("`@("!C87-E("=O=70G.@H@("`@("`@("`@
M("`@("`@("`@("1T:&ES4&]R=%1Y<&5;)&]P97)A=&EO;DYA;65=6R=O=71P
M=70G72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G;65S<V%G
M92<@/3X@)&]P97)A=&EO;DYA;64@+B`G4F5S<&]N<V4G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D=&AI<RT^=&YS4')E9FEX
M*3L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!486ME(&%L;"!T:&4@86)S=')A
M8W0@5U-$3"!D871A(&%N9"!B=6EL9"!C;VYC<F5T92!B:6YD:6YG<R!A;F0*
M("`@("`J('-E<G9I8V5S("AD97-T<G5C=&EV92DN"B`@("`@*@H@("`@("H@
M6%A8($-U<G)E;G0@:6UP;&5M96YT871I;VX@9&ES8V%R9',@)'-E<G9I8V5?
M9&5S8RX*("`@("`J"B`@("`@*B!`<&%R86T@("1S8VAE;6%.86UE<W!A8V4@
M3F%M97-P86-E(&9O<B!T>7!E<R!E=&,N"B`@("`@*B!`<&%R86T@("1S97)V
M:6-E7VYA;64@3F%M92!O9B!T:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!P
M87)A;2`@)'-E<G9I8V5?9&5S8R!/<'1I;VYA;"!D97-C<FEP=&EO;B!O9B!T
M:&4@5U-$3"`\<V5R=FEC93X*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!F=6YC=&EO;B!?9V5N97)A=&5":6YD:6YG<T%N9%-E<G9I8V5S
M*"1S8VAE;6%.86UE<W!A8V4L("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E
M<V,@/2`G)RD*("`@('L*("`@("`@("`O+R!0;W!U;&%T92!T<F5E('=I=&@@
M8FEN9&EN9W,@:6YF;W)M871I;VX*("`@("`@("`O+R!86%@@0W5R<F5N="!I
M;7!L96UE;G1A=&EO;B!O;FQY('-U<'!O<G1S(&]N92!B:6YD:6YG('1H870*
M("`@("`@("`O+R!M871C:&5S('1H92!S:6YG;&4@<&]R=%1Y<&4@86YD(&%L
M;"!O9B!I=',@;W!E<F%T:6]N<RX*("`@("`@("`O+R!86%@@27,@=&AI<R!T
M:&4@8V]R<F5C="!U<V4@;V8@)'-C:&5M84YA;65S<&%C92!H97)E/PH@("`@
M("`@("\O("HJ*B`\=W-D;#IB:6YD:6YG/B`J*BH*"B`@("`@("`@)'1H:7,M
M/G=S9&PM/F)I;F1I;F=S6R1S97)V:6-E7VYA;64@+B`G0FEN9&EN9R==(#T@
M87)R87DH"B`@("`@("`@("`@("`@("`G='EP92<@/3X@)'-E<G9I8V5?;F%M
M92`N("=0;W)T)RP*("`@("`@("`@("`@("`@("=N86UE<W!A8V4G(#T^("1T
M:&ES+3YT;G-0<F5F:7@L"B`@("`@("`@("`@("`@("`G<W1Y;&4G(#T^("=R
M<&,G+`H@("`@("`@("`@("`@("`@)W1R86YS<&]R="<@/3X@4T-(14U!7U-/
M05!?2%144"P*("`@("`@("`@("`@("`@("=O<&5R871I;VYS)R`]/B!A<G)A
M>2@I*3L*("`@("`@("`D=&AI<T)I;F1I;F<@/28@)'1H:7,M/G=S9&PM/F)I
M;F1I;F=S6R1S97)V:6-E7VYA;64@+B`G0FEN9&EN9R==.PH*("`@("`@("!F
M;W)E86-H("@D=&AI<RT^=W-D;"T^<&]R=%1Y<&5S6R1S97)V:6-E7VYA;64@
M+B`G4&]R="==(&%S("1O<&5R871I;VY.86UE(#T^("1O<&5R871I;VY$871A
M*2!["B`@("`@("`@("`@("1T:&ES0FEN9&EN9ULG;W!E<F%T:6]N<R==6R1O
M<&5R871I;VY.86UE72`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)W-O87!!
M8W1I;VXG(#T^("1S8VAE;6%.86UE<W!A8V4@+B`G(R<@+B`D;W!E<F%T:6]N
M3F%M92P*("`@("`@("`@("`@("`@("=S='EL92<@/3X@)'1H:7-":6YD:6YG
M6R=S='EL92==*3L*"B`@("`@("`@("`@(&9O<F5A8V@@*&%R<F%Y*"=I;G!U
M="<L("=O=71P=70G*2!A<R`D;65S<V%G951Y<&4I"B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&]P97)A=&EO;D1A=&%;)&UE<W-A9V54>7!E72DI('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<T)I;F1I;F=;)V]P97)A=&EO;G,G
M75LD;W!E<F%T:6]N3F%M95U;)&UE<W-A9V54>7!E72`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)W5S92<@/3X@)V5N8V]D960G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VYA;65S<&%C92<@/3X@)'-C
M:&5M84YA;65S<&%C92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=E
M;F-O9&EN9U-T>6QE)R`]/B!33T%07U-#2$5-05]%3D-/1$E.1RD["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!0;W!U;&%T92!T
M<F5E('=I=&@@<V5R=FEC92!I;F9O<FUA=&EO;@H@("`@("`@("\O(%A86"!#
M=7)R96YT(&EM<&QE;65N=&%T:6]N('-U<'!O<G1S(&]N92!S97)V:6-E('=H
M:6-H(&=R;W5P<PH@("`@("`@("\O(&%L;"!O9B!T:&4@<&]R=',@=&]G971H
M97(L(&]N92!P;W)T('!E<B!B:6YD:6YG"B`@("`@("`@+R\@6%A8(%=H870@
M86)O=70@:'1T<',_"B`@("`@("`@+R\@*BHJ(#QW<V1L.G-E<G9I8V4^("HJ
M*@H*("`@("`@("`D=&AI<RT^=W-D;"T^<V5R=FEC97-;)'-E<G9I8V5?;F%M
M92`N("=397)V:6-E)UT@/2!A<G)A>2@G<&]R=',G(#T^(&%R<F%Y*"DI.PH@
M("`@("`@("1T:&ES4V5R=FEC92`])B`D=&AI<RT^=W-D;"T^<V5R=FEC97-;
M)'-E<G9I8V5?;F%M92`N("=397)V:6-E)UU;)W!O<G1S)UT["@H@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YW<V1L+3YB:6YD:6YG<R!A<R`D8FEN9&EN9TYA
M;64@/3X@)&)I;F1I;F=$871A*2!["B`@("`@("`@("`@("1T:&ES4V5R=FEC
M95LD8FEN9&EN9T1A=&%;)W1Y<&4G75T@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`G;F%M92<@/3X@)&)I;F1I;F=$871A6R=T>7!E)UTL"B`@("`@
M("`@("`@("`@("`@("`@)V)I;F1I;F<G(#T^("1B:6YD:6YG3F%M92P*("`@
M("`@("`@("`@("`@("`@("`G;F%M97-P86-E)R`]/B`D=&AI<RT^=&YS4')E
M9FEX+`H@("`@("`@("`@("`@("`@("`@("=A9&1R97-S)R`]/B!A<G)A>2@G
M;&]C871I;VXG(#T^"B`@("`@("`@("`@("`@("`@("`@("`@("=H='1P.B\O
M)R`N("1?4T525D526R=315)615)?3D%-12==("X@)%]315)615);)U!(4%]3
M14Q&)UT@+@H@("`@("`@("`@("`@("`@("`@("`@("`H:7-S970H)%]315)6
M15);)U%515)97U-44DE.1R==*2`_("<_)R`N("1?4T525D526R=1545265]3
M5%))3D<G72`Z("<G*2DL"B`@("`@("`@("`@("`@("`@("`@)W1Y<&4G(#T^
M("=S;V%P)RD["B`@("`@("`@?0H*("`@("`@("`O+R!3970@<V5R=FEC90H@
M("`@("`@("1T:&ES+3YW<V1L+3YS971?<V5R=FEC92@D<V5R=FEC95]N86UE
M("X@)U-E<G9I8V4G*3L*("`@("`@("`D=&AI<RT^=W-D;"T^=7)I(#T@)'1H
M:7,M/G=S9&PM/FYA;65S<&%C97-;)'1H:7,M/G1N<U!R969I>%T["@H@("`@
M("`@("\O($-R96%T92!74T1,(&1E9FEN:71I;VX*("`@("`@("`O+R`J*BH@
M/'=S9&PZ9&5F:6YI=&EO;G,^("HJ*@H*("`@("`@("`D=&AI<RT^=W-D;"T^
M9&5F:6YI=&EO;B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@)VYA;64G(#T^
M("1S97)V:6-E7VYA;64L"B`@("`@("`@("`@("`@("`G=&%R9V5T3F%M97-P
M86-E)R`]/B`D=&AI<RT^=W-D;"T^;F%M97-P86-E<ULD=&AI<RT^=&YS4')E
M9FEX72P*("`@("`@("`@("`@("`@("=X;6QN<R<@/3X@4T-(14U!7U=31$PI
M.PH*("`@("`@("!F;W)E86-H("@D=&AI<RT^=W-D;"T^;F%M97-P86-E<R!A
M<R`D;G-0<F5F:7@@/3X@)&YA;65S<&%C92D@>PH@("`@("`@("`@("`D=&AI
M<RT^=W-D;"T^9&5F:6YI=&EO;ELG>&UL;G,Z)R`N("1N<U!R969I>%T@/2`D
M;F%M97-P86-E.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J(%1H
M:7,@9G5N8W1I;VX@:7,@861A<'1E9"!F<F]M($1M:71R:2!6)W,@:6UP;&5M
M96YT871I;VX@;V8*("`@("`J($1)4T-/+U=31$P@9V5N97)A=&EO;BX@270@
M<V5P87)A=&5S(&YA;65S<&%C92!F<F]M('1Y<&4@;F%M92!I;@H@("`@("H@
M82!?7W1Y<&5D968@:V5Y(&%N9"!C<F5A=&5S(&$@;F5W(&YA;65S<&%C92!E
M;G1R>2!I;B!T:&4@5U-$3`H@("`@("H@<W1R=6-T=7)E(&EF('1H92!N86UE
M<W!A8V4@:&%S(&YO="!B965N('5S960@8F5F;W)E+B!4:&4*("`@("`J(&YA
M;65S<&%C92!P<F5F:7@@86YD('1Y<&4@;F%M92!A<F4@<F5T=7)N960N($EF
M(&YO(&YA;65S<&%C92!I<PH@("`@("H@<W!E8VEF:65D+"!X<V0@:7,@87-S
M=6UE9"X*("`@("`J"B`@("`@*B!792!W:6QL(&YO="!N965D('1H:7,@9G5N
M8W1I;VX@86YY;6]R92!O;F-E(%]?='EP961E9B!I<PH@("`@("H@96QI;6EN
M871E9"X*("`@("`J+PH@("`@9G5N8W1I;VX@7V=E=%1Y<&5.<R@D='EP92D*
M("`@('L*("`@("`@("!P<F5G7VUA=&-H7V%L;"@B)UQ[*"XJ*5Q])W-M(BP@
M)'1Y<&4L("1M*3L*("`@("`@("!I9B`H:7-S970H)&U;,5U;,%TI("8F("1M
M6S%=6S!=("$]("<G*2!["B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y7V5X
M:7-T<R@D;5LQ75LP72P@)'1H:7,M/G=S9&PM/FYS*2D@>PH@("`@("`@("`@
M("`@("`@)&YS7W!R968@/2`G;G,G("X@8V]U;G0H)'1H:7,M/G=S9&PM/FYA
M;65S<&%C97,I.PH@("`@("`@("`@("`@("`@)'1H:7,M/G=S9&PM/FYS6R1M
M6S%=6S!=72`]("1N<U]P<F5F.PH@("`@("`@("`@("`@("`@)'1H:7,M/G=S
M9&PM/FYA;65S<&%C97-;)&YS7W!R969=(#T@)&U;,5U;,%T["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)'1Y<&5N<R`]("1T:&ES+3YW<V1L+3YN<ULD
M;5LQ75LP75T["B`@("`@("`@("`@("1T>7!E(#T@97)E9U]R97!L86-E*"1M
M6S!=6S!=+"`G)RP@)'1Y<&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1T>7!E;G,@/2`G>'-D)SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!A<G)A>2@D='EP96YS+"`D='EP92D["B`@("!]"@I]"@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]#
M;&EE;G0N<&AP````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`V,3`W,2`Q,#4Q-30S-#$S,R`P,C$Q-3<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@
M9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(%-/05`@8VQI96YT+@H@
M*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P*("H@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P
M86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R!A=F%I;&%B;&4@
M870*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("!)9B!Y;W4*("H@9&ED(&YO
M="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U
M;F%B;&4@=&\@;V)T86EN(&ET"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M
M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;@H@*B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J
M($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("!33T%0
M"B`J($!A=71H;W(@("`@($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX
M-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B!`875T:&]R("`@("!3:&%N92!#
M87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD
M(&UO<F4*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^("`@36%I;G1E;F%N8V4*("H@0&%U=&AO<B`@("`@2F%N(%-C
M:&YE:61E<B`\:F%N0&AO<F1E+F]R9SX@("`@("`@36%I;G1E;F%N8V4*("H@
M0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(
M4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O5F%L
M=64N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+T)A<V4N<&AP)SL*<F5Q=6ER
M95]O;F-E("=33T%0+U1R86YS<&]R="YP:'`G.PIR97%U:7)E7V]N8V4@)U-/
M05`O5U-$3"YP:'`G.PIR97%U:7)E7V]N8V4@)U-/05`O1F%U;'0N<&AP)SL*
M<F5Q=6ER95]O;F-E("=33T%0+U!A<G-E<BYP:'`G.PH*+R\@07)N875D.B!T
M:&4@9F]L;&]W:6YG(&-O9&4@=V%S('1A:V5N(&9R;VT@1&%T84]B:F5C="!A
M;F0@861A<'1E9"!T;R!S=6ET"@HO+R!T:&ES('=I;&P@8F4@:&]R<FEF:6-A
M;&QY('-L;W<A(2$A"B\O($Y/5$4Z($]V97)L;V%D(%-%1T9!54Q44R!/3B!0
M2%`T("L@6F5N9"!/<'1I;6EZ97(*+R\@=&AE<V4@='=O(&%R92!"0R]&0R!H
M86YD;&5R<R!F;W(@8V%L;"!I;B!02%`T+S4*"FEF("@A8VQA<W-?97AI<W1S
M*"=33T%07T-L:65N=%]/=F5R;&]A9"<I*2!["B`@("!I9B`H<W5B<W1R*'!H
M<'9E<G-I;VXH*2P@,"P@,2D@/3T@-2D@>PH@("`@("`@(&-L87-S(%-/05!?
M0VQI96YT7T]V97)L;V%D(&5X=&5N9',@4T]!4%]"87-E('L*("`@("`@("`@
M("`@9G5N8W1I;VX@7U]C86QL*"1M971H;V0L("1A<F=S*0H@("`@("`@("`@
M("!["B`@("`@("`@("`@("`@("`D<F5T=7)N(#T@;G5L;#L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V%L;"@D;65T:&]D+"`D87)G<RP@)')E='5R;BD[
M"B`@("`@("`@("`@("`@("!R971U<FX@)')E='5R;CL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@:68@*"%F=6YC=&EO
M;E]E>&ES=',H)V-L;VYE)RDI('L*("`@("`@("`@("`@979A;"@G9G5N8W1I
M;VX@8VQO;F4H)'0I('L@<F5T=7)N("1T.R!])RD["B`@("`@("`@?0H@("`@
M("`@(&5V86PH)PH@("`@("`@("`@("!C;&%S<R!33T%07T-L:65N=%]/=F5R
M;&]A9"!E>'1E;F1S(%-/05!?0F%S92!["B`@("`@("`@("`@("`@("!F=6YC
M=&EO;B!?7V-A;&PH)&UE=&AO9"P@)&%R9W,L("8D<F5T=7)N*0H@("`@("`@
M("`@("`@("`@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7V-A;&PH)&UE=&AO9"P@)&%R9W,L("1R971U<FXI.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!])RD["B`@("!]"GT*"B\J*@H@*B!33T%0($-L
M:65N="!#;&%S<PH@*@H@*B!4:&ES(&-L87-S(&ES('1H92!M86EN(&EN=&5R
M9F%C92!F;W(@;6%K:6YG('-O87`@<F5Q=65S=',N"B`J"B`J(&)A<VEC('5S
M86=E.CQC;V1E/@H@*B`@("1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI96YT
M*"!S=')I;F<@<&%T:"!;("P@8F]O;&5A;B!W<V1L72`I.PH@*B`@(&5C:&\@
M)'-O87!C;&EE;G0M/F-A;&PH('-T<FEN9R!M971H;V1N86UE(%L@+"!A<G)A
M>2!P87)A;65T97)S72`I.PH@*B`\+V-O9&4^"B`J"B`J($]R:6=I;F%L;'D@
M8F%S960@;VX@4T]!4'@T(&)Y($1I971R:6-H($%Y86QA"B`J(&AT='`Z+R]D
M:65T<FEC:"YG86YX-"YC;VTO<V]A<'@T"B`J"B`J($!A8V-E<W,@("!P=6)L
M:6,*("H@0'!A8VMA9V4@(%-/05`*("H@0&%U=&AO<B`@(%-H86YE($-A<F%V
M96\@/'-H86YE0'!H<"YN970^($-O;G9E<G-I;VX@=&\@4$5!4B!A;F0@=7!D
M871E<PH@*B!`875T:&]R("`@4W1I9R!"86MK96X@/'-S8D!F87-T+FYO/B!#
M;VYV97)S:6]N('1O(%!%05(*("H@0&%U=&AO<B`@($1I971R:6-H($%Y86QA
M(#QD:65T<FEC:$!G86YX-"YC;VT^($]R:6=I;F%L($%U=&AO<@H@*B\*8VQA
M<W,@4T]!4%]#;&EE;G0@97AT96YD<R!33T%07T-L:65N=%]/=F5R;&]A9`I[
M"B`@("`O*BH*("`@("`J($-O;6UU;FEC871I;VX@96YD<&]I;G0N"B`@("`@
M*@H@("`@("H@0W5R<F5N=&QY('1H92!F;VQL;W=I;F<@=')A;G-P;W)T(&9O
M<FUA=',@87)E('-U<'!O<G1E9#H*("`@("`J("`M($A45%`*("`@("`J("`M
M(%--5%`*("`@("`J"B`@("`@*B!%>&%M<&QE(&5N9'!O:6YT<SH*("`@("`J
M("`@:'1T<#HO+W=W=RYE>&%M<&QE+F-O;2]S;V%P+W-E<G9E<BYP:'`*("`@
M("`J("`@:'1T<',Z+R]W=W<N97AA;7!L92YC;VTO<V]A<"]S97)V97(N<&AP
M"B`@("`@*B`@(&UA:6QT;SIS;V%P0&5X86UP;&4N8V]M"B`@("`@*@H@("`@
M("H@0'-E92`@4T]!4%]#;&EE;G0H*0H@("`@("H@0'9A<B`D7V5N9'!O:6YT
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)%]E;F1P;VEN="`]("<G.PH*("`@
M("\J*@H@("`@("H@5&AE(%-/05`@4$]25"!N86UE('1H870@:7,@=7-E9"!B
M>2!T:&4@8VQI96YT+@H@("`@("H*("`@("`J($!V87(@)%]P;W)T3F%M92!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1?<&]R=$YA;64@/2`G)SL*"B`@("`O
M*BH*("`@("`J($5N9'!O:6YT('1Y<&4@92YG+B`G=V1S;"<N"B`@("`@*@H@
M("`@("H@0'9A<B`D7U]E;F1P;VEN=%1Y<&4@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D7U]E;F1P;VEN=%1Y<&4@/2`G)SL*"B`@("`O*BH*("`@("`J(%1H
M92!R96-E:79E9"!X;6PN"B`@("`@*@H@("`@("H@0'9A<B`D>&UL('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)'AM;#L*"B`@("`O*BH*("`@("`J(%1H92!O
M=71G;VEN9R!A;F0@:6YC;VUI;F<@9&%T82!S=')E86T@9F]R(&1E8G5G9VEN
M9RX*("`@("`J"B`@("`@*B!`=F%R("1W:7)E('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)'=I<F4["B`@("!V87(@)%]?;&%S=%]R97%U97-T(#T@;G5L;#L*
M("`@('9A<B`D7U]L87-T7W)E<W!O;G-E(#T@;G5L;#L*"B`@("`O*BH*("`@
M("`J($]P=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B`D7U]O<'1I;VYS(&%R
M<F%Y"B`@("`@*B\*("`@('9A<B`D7U]O<'1I;VYS(#T@87)R87DH)W1R86-E
M)ST^,"D["@H@("`@+RHJ"B`@("`@*B!4:&4@8VAA<F%C=&5R(&5N8V]D:6YG
M('5S960@9F]R(%A-3"!P87)S97(L(&5T8RX*("`@("`J"B`@("`@*B!`=F%R
M("1?96YC;V1I;F<@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7V5N8V]D:6YG
M(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH*("`@("\J*@H@("`@("H@5&AE
M(&%R<F%Y(&]F(%-/05!?2&5A9&5R<R!T:&%T('=E(&%R92!S96YD:6YG+@H@
M("`@("H*("`@("`J($!V87(@)&AE861E<G-/=70@87)R87D*("`@("`J+PH@
M("`@=F%R("1H96%D97)S3W5T(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%1H
M92!H96%D97)S('=E(')E8VEE=F5D(&)A8VL@:6X@=&AE(')E<W!O;G-E+@H@
M("`@("H*("`@("`J($!V87(@)&AE861E<G-);B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&AE861E<G-);B`](&YU;&P["@H@("`@+RHJ"B`@("`@*B!/<'1I
M;VYS(&9O<B!T:&4@2%144%]297%U97-T(&-L87-S("AS964@2%144"]297%U
M97-T+G!H<"DN"B`@("`@*@H@("`@("H@0'9A<B`D7U]P<F]X>5]P87)A;7,@
M87)R87D*("`@("`J+PH@("`@=F%R("1?7W!R;WAY7W!A<F%M<R`](&%R<F%Y
M*"D["@H@("`@=F%R("1?<V]A<%]T<F%N<W!O<G0@/2!N=6QL.PH*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1E;F1P;VEN="`@
M("`@06X@55),+@H@("`@("H@0'!A<F%M(&)O;VQE86X@)'=S9&P@("`@("`@
M(%=H971H97(@=&AE(&5N9'!O:6YT(&ES(&$@5U-$3"!F:6QE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<&]R=$YA;64*("`@("`J($!P87)A;2!A<G)A>2`D
M<')O>'E?<&%R86US("!/<'1I;VYS(&9O<B!T:&4@2%144%]297%U97-T(&-L
M87-S("AS964*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!(
M5%10+U)E<75E<W0N<&AP*0H@("`@("HO"B`@("!F=6YC=&EO;B!33T%07T-L
M:65N="@D96YD<&]I;G0L("1W<V1L(#T@9F%L<V4L("1P;W)T3F%M92`](&9A
M;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;WAY7W!A<F%M<R`]
M(&%R<F%Y*"DI"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07T)A<V4H)T-L
M:65N="<I.PH*("`@("`@("`D=&AI<RT^7V5N9'!O:6YT(#T@)&5N9'!O:6YT
M.PH@("`@("`@("1T:&ES+3Y?<&]R=$YA;64@/2`D<&]R=$YA;64["B`@("`@
M("`@)'1H:7,M/E]?<')O>'E?<&%R86US(#T@)'!R;WAY7W!A<F%M<SL*"B`@
M("`@("`@+R\@5&AI<R!H86-K('-H;W5L9"!P97)H87!S(&)E(')E;6]V960@
M87,@:70@;6EG:'0@8V%U<V4@=6YE>'!E8W1E9`H@("`@("`@("\O(&)E:&%V
M:6]U<BX*("`@("`@("`D=W-D;"`]("1W<V1L"B`@("`@("`@("`@(#\@)'=S
M9&P*("`@("`@("`@("`@.B!S=')T;VQO=V5R*'-U8G-T<B@D96YD<&]I;G0L
M("TT*2D@/3T@)W=S9&PG.PH*("`@("`@("`O+R!M86ME('9A;'5E<PH@("`@
M("`@(&EF("@D=W-D;"D@>PH@("`@("`@("`@("`D=&AI<RT^7U]E;F1P;VEN
M=%1Y<&4@/2`G=W-D;"<["B`@("`@("`@("`@("\O(&EN<W1A;G1I871E('=S
M9&P@8VQA<W,*("`@("`@("`@("`@)'1H:7,M/E]W<V1L(#TF(&YE=R!33T%0
M7U=31$PH)'1H:7,M/E]E;F1P;VEN="P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]?<')O>'E?<&%R86US*3L*
M("`@("`@("`@("`@:68@*"1T:&ES+3Y?=W-D;"T^9F%U;'0I('L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/E]W<V1L
M+3YF875L="D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@7W)E<V5T*"D*("`@('L*("`@("`@("`D=&AI<RT^>&UL(#T@
M;G5L;#L*("`@("`@("`D=&AI<RT^=VER92`](&YU;&P["B`@("`@("`@)'1H
M:7,M/E]?;&%S=%]R97%U97-T(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7U]L
M87-T7W)E<W!O;G-E(#T@;G5L;#L*("`@("`@("`D=&AI<RT^:&5A9&5R<TEN
M(#T@;G5L;#L*("`@("`@("`D=&AI<RT^:&5A9&5R<T]U="`](&YU;&P["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!C:&%R86-T97(@96YC;V1I
M;F<N"B`@("`@*@H@("`@("H@3&EM:71E9"!T;R`G551&+3@G+"`G55-?05-#
M24DG(&%N9"`G25-/+3@X-3DM,2<N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG(&5N8V]D:6YG"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@4T]!4%]&875L="!O;B!E<G)O
M<BX*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T16YC;V1I;F<H)&5N8V]D:6YG
M*0H@("`@>PH@("`@("`@(&EF("AI;E]A<G)A>2@D96YC;V1I;F<L("1T:&ES
M+3Y?96YC;V1I;F=S*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V5N8V]D:6YG
M(#T@)&5N8V]D:6YG.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED
M($5N8V]D:6YG)RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&1S(&$@:&5A
M9&5R('1O('1H92!E;G9E;&]P92X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H*("`@("`J($!P87)A;2!33T%07TAE861E<B`D<V]A<%]V
M86QU92`@02!33T%07TAE861E<B!O<B!A;B!A<G)A>2!W:71H('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E;&5M96YT<R`G
M;F%M92<L("=N86UE<W!A8V4G+`H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;75S='5N9&5R<W1A;F0G+"!A;F0@)V%C=&]R)R!T
M;R!S96YD"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%S(&$@:&5A9&5R+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9&1(96%D97(H
M)B1S;V%P7W9A;'5E*0H@("`@>PH@("`@("`@("\O($%D9"!A(&YE=R!H96%D
M97(@=&\@=&AE(&UE<W-A9V4N"B`@("`@("`@:68@*&ES7V$H)'-O87!?=F%L
M=64L("=33T%07TAE861E<B<I*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D
M97)S3W5T6UT@/28@)'-O87!?=F%L=64["B`@("`@("`@?2!E;'-E:68@*&ES
M7V%R<F%Y*"1S;V%P7W9A;'5E*2D@>PH@("`@("`@("`@("`O+R!N86UE+"!V
M86QU92P@;F%M97-P86-E+"!M=7-T=6YD97)S=&%N9"P@86-T;W(*("`@("`@
M("`@("`@)'1H:7,M/FAE861E<G-/=71;72`])B!N97<@4T]!4%](96%D97(H
M)'-O87!?=F%L=65;,%TL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&YU;&PL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S;V%P7W9A;'5E
M6S%=+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<V]A<%]V86QU95LR72P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-O87!?=F%L=65;
M,UTI.SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"=);G9A;&ED('!A<F%M971E<B!P<F]V:61E9"!T;R!A
M9&1(96%D97(H*2X@($UU<W0@8F4@86X@87)R87D@;W(@82!33T%07TAE861E
M<BXG*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#86QL<R!A
M(&UE=&AO9"!O;B!T:&4@4T]!4"!E;F1P;VEN="X*("`@("`J"B`@("`@*B!4
M:&4@;F%M97-P86-E('!A<F%M971E<B!I<R!O=F5R;&]A9&5D('1O(&%C8V5P
M="!A;B!A<G)A>2!O9B!O<'1I;VYS"B`@("`@*B!T:&%T(&-A;B!C;VYT86EN
M(&1A=&$@;F5C97-S87)Y(&9O<B!V87)I;W5S('1R86YS<&]R=',@:68@:70@
M:7,@=7-E9"!A<PH@("`@("H@86X@87)R87DL(&ET($U!62!C;VYT86EN(&$@
M;F%M97-P86-E('9A;'5E(&%N9"!A('-O87!A8W1I;VX@=F%L=64N("!)9@H@
M("`@("H@:70@:7,@;W9E<FQO861E9"P@=&AE('-O87!A8W1I;VX@<&%R86UE
M=&5R(&ES(&EG;F]R960@86YD($U54U0@8F4*("`@("`J('!L86-E9"!I;B!T
M:&4@;W!T:6]N<R!A<G)A>2X@(%1H:7,@:7,@9&]N92!T;R!P<F]V:61E(&)A
M8VMW87)D<PH@("`@("H@8V]M<&%T:6)I;&ET>2!W:71H(&-U<G)E;G0@8VQI
M96YT<RP@8G5T(&UA>2!B92!R96UO=F5D(&EN('1H92!F=71U<F4N"B`@("`@
M*B!4:&4@8W5R<F5N=&QY('-U<'!O<G1E9"!V86QU97,@87)E.CQP<F4^"B`@
M("`@*B`@(&YA;65S<&%C90H@("`@("H@("!S;V%P86-T:6]N"B`@("`@*B`@
M('1I;65O=70@*$A45%`@<V]C:V5T('1I;65O=70I"B`@("`@*B`@('1R86YS
M9F5R+65N8V]D:6YG("A33510+"!#;VYT96YT+51R86YS9F5R+45N8V]D:6YG
M.B!H96%D97(I"B`@("`@*B`@(&9R;VT@*%--5%`L($9R;VTZ(&AE861E<BD*
M("`@("`J("`@<W5B:F5C="`H4TU44"P@4W5B:F5C=#H@:&5A9&5R*0H@("`@
M("H@("!H96%D97)S("A33510+"!H87-H(&]F(&5X=')A(%--5%`@:&5A9&5R
M<RD*("`@("`J(#PO<')E/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("`@("`@("`@
M("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("`@("`@("`@(%1H92!M971H;V0@<&%R86UE=&5R<RX*("`@("`J
M($!P87)A;2!S=')I;F=\87)R87D@)&YA;65S<&%C92`@3F%M97-P86-E(&]R
M(&AA<V@@=VET:"!O<'1I;VYS+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V]A
M<$%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(%1H92!M971H
M;V0@<F5S=6QT(&]R(&$@4T]!4%]&875L="!O;B!E<G)O<BX*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F-A;&PH)&UE=&AO9"P@)B1P87)A;7,L("1N86UE<W!A
M8V4@/2!F86QS92P@)'-O87!!8W1I;VX@/2!F86QS92D*("`@('L*("`@("`@
M("`D=&AI<RT^:&5A9&5R<TEN(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7U]L
M87-T7W)E<75E<W0@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y?7VQA<W1?<F5S
M<&]N<V4@/2!N=6QL.PH@("`@("`@("1T:&ES+3YW:7)E(#T@;G5L;#L*("`@
M("`@("`D=&AI<RT^>&UL(#T@;G5L;#L*"B`@("`@("`@)'-O87!?9&%T82`]
M)B`D=&AI<RT^7U]G96YE<F%T92@D;65T:&]D+"`D<&%R86US+"`D;F%M97-P
M86-E+"`D<V]A<$%C=&EO;BD["B`@("`@("`@:68@*%!%05(Z.FES17)R;W(H
M)'-O87!?9&%T82DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H)'-O87!?9&%T82D["B`@("`@("`@?0H*("`@("`@("`O
M+R!?7V=E;F5R871E*"D@;6%Y(&AA=F4@8VAA;F=E9"!T:&4@96YD<&]I;G0@
M:68@=&AE(%=31$P@:&%S(&UO<F4*("`@("`@("`O+R!T:&%N(&]N92!S97)V
M:6-E+"!S;R!W92!N965D('1O('-E92!I9B!W92!N965D('1O(&=E;F5R871E
M(&$@;F5W"B`@("`@("`@+R\@=')A;G-P;W)T('1O(&AO;VL@=&\@82!D:69F
M97)E;G0@55))+B`@4VEN8V4@=&AE('1R86YS<&]R="!P<F]T;V-O;`H@("`@
M("`@("\O(&-A;B!A;'-O(&-H86YG92P@=V4@;F5E9"!T;R!G970@86X@96YT
M:7)E;'D@;F5W(&]B:F5C="X@(%1H:7,@8V]U;&0*("`@("`@("`O+R!P<F]B
M86)L>2!B92!O<'1I;6EZ960N"B`@("`@("`@:68@*"$D=&AI<RT^7W-O87!?
M=')A;G-P;W)T('Q\"B`@("`@("`@("`@("1T:&ES+3Y?96YD<&]I;G0@(3T@
M)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^=7)L*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N<W!O<G0Z.F=E=%1R
M86YS<&]R="@D=&AI<RT^7V5N9'!O:6YT*3L*("`@("`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)'1H:7,M/E]S;V%P7W1R86YS<&]R="DI('L*("`@("`@
M("`@("`@("`@("1F875L="`])B`D=&AI<RT^7W-O87!?=')A;G-P;W)T.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S;V%P7W1R86YS<&]R="`](&YU;&P[
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@D9F%U;'0I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3Y?<V]A<%]T<F%N<W!O<G0M/F5N8V]D:6YG(#T@)'1H:7,M/E]E;F-O
M9&EN9SL*"B`@("`@("`@+R\@4V5N9"!T:&4@;65S<V%G92X*("`@("`@("`D
M=')A;G-P;W)T7V]P=&EO;G,@/2!A<G)A>5]M97)G95]R96-U<G-I=F4H)'1H
M:7,M/E]?<')O>'E?<&%R86US+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS*3L*
M("`@("`@("`D=&AI<RT^>&UL(#TF("1T:&ES+3Y?<V]A<%]T<F%N<W!O<G0M
M/G-E;F0H)'-O87!?9&%T82P@)'1R86YS<&]R=%]O<'1I;VYS*3L*"B`@("`@
M("`@+R\@4V%V92!T:&4@=VER92!I;F9O<FUA=&EO;B!F;W(@9&5B=6=G:6YG
M+@H@("`@("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=T<F%C92==(#X@,"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7U]L87-T7W)E<75E<W0@/28@)'1H:7,M
M/E]S;V%P7W1R86YS<&]R="T^;W5T9V]I;F=?<&%Y;&]A9#L*("`@("`@("`@
M("`@)'1H:7,M/E]?;&%S=%]R97-P;VYS92`])B`D=&AI<RT^7W-O87!?=')A
M;G-P;W)T+3YI;F-O;6EN9U]P87EL;V%D.PH@("`@("`@("`@("`D=&AI<RT^
M=VER92`])B`D=&AI<RT^7U]G971?=VER92@I.PH@("`@("`@('T*("`@("`@
M("!I9B`H)'1H:7,M/E]S;V%P7W1R86YS<&]R="T^9F%U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M/GAM
M;"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7U]A='1A8VAM96YT<R`]
M)B`D=&AI<RT^7W-O87!?=')A;G-P;W)T+3YA='1A8VAM96YT<SL*("`@("`@
M("`D=&AI<RT^7U]R97-U;'1?96YC;V1I;F<@/2`D=&AI<RT^7W-O87!?=')A
M;G-P;W)T+3YR97-U;'1?96YC;V1I;F<["@H@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^7U]O<'1I;VYS6R=R97-U;'0G72D@)B8*("`@("`@("`@("`@)'1H
M:7,M/E]?;W!T:6]N<ULG<F5S=6QT)UT@(3T@)W!A<G-E)RD@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/GAM;#L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7U]P87)S92@D=&AI<RT^>&UL+"`D=&AI<RT^7U]R97-U
M;'1?96YC;V1I;F<L("1T:&ES+3Y?7V%T=&%C:&UE;G1S*3L*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E=',@86X@;W!T:6]N('1O('5S92!W:71H('1H92!T
M<F%N<W!O<G0@;&%Y97)S+@H@("`@("H*("`@("`J($9O<B!E>&%M<&QE.@H@
M("`@("H@/&-O9&4^"B`@("`@*B`D<V]A<&-L:65N="T^<V5T3W!T*"=C=7)L
M)RP@0U523$]05%]615)"3U-%+"`Q*0H@("`@("H@/"]C;V1E/@H@("`@("H@
M=&\@<&%S<R!A('-P96-I9FEC(&]P=&EO;B!T;R!C=7)L(&EF('5S:6YG(&%N
M(%-33"!C;VYN96-T:6]N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D8V%T96=O<GD@($-A=&5G
M;W)Y('1O('=H:6-H('1H92!O<'1I;VX@87!P;&EE<R!O<B!O<'1I;VX*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE+@H@("`@("H@0'!A
M<F%M('-T<FEN9R`D;W!T:6]N("`@($%N(&]P=&EO;B!N86UE(&EF("1C871E
M9V]R>2!I<R!A(&-A=&5G;W)Y(&YA;64L"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@86X@;W!T:6]N('9A;'5E(&EF("1C871E9V]R>2!I<R!A
M;B!O<'1I;VX@;F%M92X*("`@("`J($!P87)A;2!S=')I;F<@)'9A;'5E("`@
M("!!;B!O<'1I;VX@=F%L=64@:68@)&-A=&5G;W)Y(&ES(&$@8V%T96=O<GD*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!N86UE+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!S971/<'0H)&-A=&5G;W)Y+"`D;W!T:6]N+"`D=F%L
M=64@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A:7-?;G5L;"@D=F%L=64I
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/E]?;W!T:6]N<ULD
M8V%T96=O<GE=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N
M<ULD8V%T96=O<GE=(#T@87)R87DH*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D=&AI<RT^7U]O<'1I;VYS6R1C871E9V]R>5U;)&]P=&EO;ET@/2`D
M=F%L=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]?
M;W!T:6]N<ULD8V%T96=O<GE=(#T@)&]P=&EO;CL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!#86QL(&UE=&AO9"!S=7!P;W)T:6YG('1H92!O
M=F5R;&]A9"!E>'1E;G-I;VXN"B`@("`@*@H@("`@("H@268@=&AE(&]V97)L
M;V%D(&5X=&5N<VEO;B!I<R!L;V%D960L('EO=2!C86X@8V%L;"!T:&4@8VQI
M96YT(&-L87-S('=I=&@*("`@("`J(&$@<V]A<"!M971H;V0@;F%M93H*("`@
M("`J(#QC;V1E/@H@("`@("H@)'-O87`@/2!N97<@4T]!4%]#;&EE;G0H+BXN
M+BD["B`@("`@*B`D=F%L=64@/2`D<V]A<"T^9V5T4W1O8VM1=6]T92@G35-&
M5"<I.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;65T:&]D("`@("`@
M("!4:&4@;65T:&]D('1O(&-A;&PN"B`@("`@*B!`<&%R86T@87)R87D@)'!A
M<F%M<R`@("`@("`@(%1H92!M971H;V0@<&%R86UE=&5R<RX*("`@("`J($!P
M87)A;2!S=')I;F<@)')E='5R;E]V86QU92`@5VEL;"!G970@=&AE(&UE=&AO
M9"=S(')E='5R;B!V86QU90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<W-I9VYE9"X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@($%L=V%Y<R!T<G5E+@H@("`@("HO"B`@("!F=6YC=&EO;B!?8V%L;"@D
M;65T:&]D+"`D<&%R86US+"`F)')E='5R;E]V86QU92D*("`@('L*("`@("`@
M("`O+R!/=F5R;&]A9&EN9R!L;W=E<F-A<V5S('1H92!M971H;V0@;F%M92P@
M=V4@;F5E9"!T;R!L;V]K(&EN=&\@=&AE"B`@("`@("`@+R\@=W-D;"!A;F0@
M=')Y('1O(&9I;F0@=&AE(&-O<G)E8W0@;65T:&]D(&YA;64@=&\@9V5T('1H
M92!C;W)R96-T"B`@("`@("`@+R\@8V%S92!F;W(@=&AE(&-A;&PN"B`@("`@
M("`@:68@*"1T:&ES+3Y?=W-D;"D@>PH@("`@("`@("`@("`D=&AI<RT^7W=S
M9&PM/FUA=&-H365T:&]D*"1M971H;V0I.PH@("`@("`@('T*"B`@("`@("`@
M)')E='5R;E]V86QU92`])B`D=&AI<RT^8V%L;"@D;65T:&]D+"`D<&%R86US
M*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@9G5N8W1I;VX@
M)E]?9V5T;&%S=')E<75E<W0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI
M<RT^7U]L87-T7W)E<75E<W0["B`@("!]"@H@("`@9G5N8W1I;VX@)E]?9V5T
M;&%S=')E<W!O;G-E*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/E]?
M;&%S=%]R97-P;VYS93L*("`@('T*"B`@("!F=6YC=&EO;B!?7W5S92@D=7-E
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W5S92==(#T@)'5S
M93L*("`@('T*"B`@("!F=6YC=&EO;B!?7W-T>6QE*"1S='EL92D*("`@('L*
M("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T@)'-T>6QE.PH@
M("`@?0H*("`@(&9U;F-T:6]N(%]?=')A8V4H)&QE=F5L*0H@("`@>PH@("`@
M("`@("1T:&ES+3Y?7V]P=&EO;G-;)W1R86-E)UT@/2`D;&5V96P["B`@("!]
M"@H@("`@9G5N8W1I;VX@)E]?9V5N97)A=&4H)&UE=&AO9"P@)B1P87)A;7,L
M("1N86UE<W!A8V4@/2!F86QS92P*("`@("`@("`@("`@("`@("`@("`@("`@
M("1S;V%P06-T:6]N(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F9A
M=6QT(#T@;G5L;#L*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=I;G!U="==
M/2=P87)S92<["B`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<F5S=6QT)UT]
M)W!A<G-E)SL*("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=P87)A;65T97)S
M)UT@/2!F86QS93L*"B`@("`@("`@:68@*"1P87)A;7,@)B8@9V5T='EP92@D
M<&%R86US*2`A/2`G87)R87DG*2!["B`@("`@("`@("`@("1P87)A;7,@/2!A
M<G)A>2@D<&%R86US*3L*("`@("`@("!]"@H@("`@("`@(&EF("AG971T>7!E
M*"1N86UE<W!A8V4I(#T]("=A<G)A>2<I('L*("`@("`@("`@("`@9F]R96%C
M:"`H)&YA;65S<&%C92!A<R`D;W!T;F%M92`]/B`D;W!T*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6W-T<G1O;&]W97(H)&]P=&YA;64I
M72`]("1O<'0["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3Y?7V]P=&EO;G-;)VYA;65S<&%C92==*2D@>PH@("`@("`@("`@
M("`@("`@)&YA;65S<&%C92`]("1T:&ES+3Y?7V]P=&EO;G-;)VYA;65S<&%C
M92==.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&YA
M;65S<&%C92`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+R\@5V4G;&P@<&QA8V4@)'-O87!!8W1I;VX@:6YT
M;R!O=7(@87)R87D@9F]R('5S86=E(&EN('1H90H@("`@("`@("`@("`O+R!T
M<F%N<W!O<G0N"B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-O87!A
M8W1I;VXG72`]("1S;V%P06-T:6]N.PH@("`@("`@("`@("`D=&AI<RT^7U]O
M<'1I;VYS6R=N86UE<W!A8V4G72`]("1N86UE<W!A8V4["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)'1H:7,M/E]?96YD<&]I;G14>7!E(#T]("=W<V1L)RD@
M>PH@("`@("`@("`@("`D=&AI<RT^7W-E=%-C:&5M859E<G-I;VXH)'1H:7,M
M/E]W<V1L+3YX<V0I.PH*("`@("`@("`@("`@+R\@1V5T('!O<G0@;F%M92X*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!O<G1.86UE*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^7W!O<G1.86UE(#T@)'1H:7,M/E]W<V1L+3YG9710
M;W)T3F%M92@D;65T:&]D*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I
M9B`H4$5!4CHZ:7-%<G)O<B@D=&AI<RT^7W!O<G1.86UE*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)'1H:7,M
M/E]P;W)T3F%M92D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($=E
M="!E;F1P;VEN="X*("`@("`@("`@("`@)'1H:7,M/E]E;F1P;VEN="`]("1T
M:&ES+3Y?=W-D;"T^9V5T16YD<&]I;G0H)'1H:7,M/E]P;W)T3F%M92D["B`@
M("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?96YD<&]I;G0I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&
M875L="@D=&AI<RT^7V5N9'!O:6YT*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+R\@1V5T(&]P97)A=&EO;B!D871A+@H@("`@("`@("`@("`D;W!$
M871A(#T@)'1H:7,M/E]W<V1L+3YG971/<&5R871I;VY$871A*"1T:&ES+3Y?
M<&]R=$YA;64L("1M971H;V0I.PH*("`@("`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)&]P1&%T82DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"1O<$1A=&$I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1N86UE<W!A8V4@/2`D;W!$871A6R=N86UE<W!A8V4G73L*
M("`@("`@("`@("`@)'1H:7,M/E]?;W!T:6]N<ULG<W1Y;&4G72`]("1O<$1A
M=&%;)W-T>6QE)UT["B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W5S
M92==(#T@)&]P1&%T85LG:6YP=70G75LG=7-E)UT["B`@("`@("`@("`@("1T
M:&ES+3Y?7V]P=&EO;G-;)W-O87!A8W1I;VXG72`]("1O<$1A=&%;)W-O87!!
M8W1I;VXG73L*"B`@("`@("`@("`@("\O(%-E="!I;G!U="!P87)A;65T97)S
M+@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG:6YP=70G72`]
M/2`G<&%R<V4G*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS
M6R=P87)A;65T97)S)UT@/2`D;W!$871A6R=P87)A;65T97)S)UT["B`@("`@
M("`@("`@("`@("`D;G!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@("`@
M("!I9B`H:7-S970H)&]P1&%T85LG:6YP=70G75LG<&%R=',G72D@)B8*("`@
M("`@("`@("`@("`@("`@("!C;W5N="@D;W!$871A6R=I;G!U="==6R=P87)T
M<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@
M("`@("`@("`@("!F;W)E86-H("@D;W!$871A6R=I;G!U="==6R=P87)T<R==
M(&%S("1N86UE(#T^("1P87)T*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1X;6QN<R`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D871T<G,@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!)<R!T:&4@
M;F%M92!A(&-O;7!L97@@='EP93\*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P87)T6R=E;&5M96YT)UTI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D>&UL;G,@/2`D=&AI<RT^7W=S9&PM/FYA;65S<&%C
M97-;)'!A<G1;)VYA;65S<&%C92==73L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P87)T(#T@)'1H:7,M/E]W<V1L+3YE;&5M96YT<ULD<&%R=%LG
M;F%M97-P86-E)UU=6R1P87)T6R=T>7!E)UU=.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&YA;64@/2`D<&%R=%LG;F%M92==.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI
M<W-E="@D<&%R86US6R1N86UE72D@?'P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?=W-D;"T^9V5T1&%T84AA;F1L97(H)&YA;64L("1P
M87)T6R=N86UE<W!A8V4G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1N<&%R86US6R1N86UE72`])B`D<&%R86US6R1N86UE73L*("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%=E(&YO=R!F;W)C92!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!F;W(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O('!A<F%M971E
M<G,@:68@=7-I;F<@5U-$3"X*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")4:&4@;F%M960@<&%R
M86UE=&5R("1N86UE(&ES(&YO="!I;B!T:&4@8V%L;"!P87)A;65T97)S+B(I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AG971T>7!E*"1N<&%R86US6R1N86UE72D@(3T@)V]B:F5C
M="<@?'P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("%I<U]A*"1N<&%R
M86US6R1N86UE72P@)U-/05!?5F%L=64G*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@5'EP92!I<R!L:6ME;'D@82!Q;F%M92P@<W!L:70@
M:70@87!A<G0L(&%N9"!G970*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O('1H92!T>7!E(&YA;65S<&%C92!F<F]M(%=31$PN"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<6YA;64@/28@;F5W(%%.86UE*"1P87)T6R=T
M>7!E)UTI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1Q;F%M
M92T^;G,I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP
M95]N86UE<W!A8V4@/2`D=&AI<RT^7W=S9&PM/FYA;65S<&%C97-;)'%N86UE
M+3YN<UT["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M:7-S970H)'!A<G1;)VYA;65S<&%C92==*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T>7!E7VYA;65S<&%C92`]("1T:&ES+3Y?=W-D
M;"T^;F%M97-P86-E<ULD<&%R=%LG;F%M97-P86-E)UU=.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D='EP95]N86UE<W!A8V4@/2!N=6QL.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'%N86UE+3YN86UE<W!A8V4@/2`D='EP95]N86UE<W!A8V4["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]("1Q;F%M92T^;F%M
M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<6YA;64@/2`D;F%M
M93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D>&UL;G,I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<'%N86UE(#T@)WLG
M("X@)'AM;&YS("X@)WTG("X@)&YA;64["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;G!A<F%M
M<ULD;F%M95T@/28@;F5W(%-/05!?5F%L=64H)'!Q;F%M92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<6YA;64M/F9Q;B@I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N<&%R
M86US6R1N86UE72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D871T<G,I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@5U-$3"!F:7AU<',@=&\@=&AE(%-/05`@=F%L=64N"B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<&%R86US(#TF
M("1N<&%R86US.PH@("`@("`@("`@("`@("`@=6YS970H)&YP87)A;7,I.PH@
M("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]S97138VAE;6%697)S:6]N*%-/05!?6$U,7U-#2$5-05]615)324].
M*3L*("`@("`@("!]"@H@("`@("`@("\O(%-E<FEA;&EZ92!T:&4@;65S<V%G
M92X*("`@("`@("`D=&AI<RT^7W-E8W1I;VXU(#T@*&ES<V5T*"1T:&ES+3Y?
M7V]P=&EO;G-;)W5S92==*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]?;W!T:6]N<ULG=7-E)UT@/3T@)VQI=&5R86PG*3L*"B`@
M("`@("`@:68@*"%I<W-E="@D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==*2!\
M?`H@("`@("`@("`@("`D=&AI<RT^7U]O<'1I;VYS6R=S='EL92==(#T]("=R
M<&,G*2!["B`@("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G-;)W-T>6QE)UT@
M/2`G<G!C)SL*("`@("`@("`@("`@)'1H:7,M/F1O8W!A<F%M<R`]('1R=64[
M"B`@("`@("`@("`@("1M<6YA;64@/28@;F5W(%%.86UE*"1M971H;V0L("1N
M86UE<W!A8V4I.PH@("`@("`@("`@("`D;65T:&]D5F%L=64@/28@;F5W(%-/
M05!?5F%L=64H)&UQ;F%M92T^9G%N*"DL("=3=')U8W0G+"`D<&%R86US*3L*
M("`@("`@("`@("`@)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K945N=F5L;W!E
M*"1M971H;V1686QU92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YH96%D97)S3W5T+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]E
M;F-O9&EN9RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3Y?7V]P=&EO;G,I.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@(&EF("@A)'!A<F%M<RD@>PH@("`@("`@("`@("`@("`@
M)&UQ;F%M92`])B!N97<@44YA;64H)&UE=&AO9"P@)&YA;65S<&%C92D["B`@
M("`@("`@("`@("`@("`D;7EN=6QL(#T@;G5L;#L*("`@("`@("`@("`@("`@
M("1P87)A;7,@/28@;F5W(%-/05!?5F%L=64H)&UQ;F%M92T^9G%N*"DL("=3
M=')U8W0G+"`D;7EN=6QL*3L*("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES
M+3Y?7V]P=&EO;G-;)VEN<'5T)UT@/3T@)W!A<G-E)RD@>PH@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1P87)A;7,I*2!["B`@("`@("`@("`@("`@
M("`@("`@)&YP87)A;7,@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M("1K97ES(#T@87)R87E?:V5Y<R@D<&%R86US*3L*("`@("`@("`@("`@("`@
M("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H9V5T='EP92@D<&%R86US6R1K72D@(3T@)V]B:F5C="<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N<&%R86US6UT@/28@
M;F5W(%-/05!?5F%L=64H)&LL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9A;'-E+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US6R1K72D["B`@("`@("`@("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;G!A<F%M<UM=
M(#TF("1P87)A;7-;)&M=.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1P87)A
M;7,@/28@)&YP87)A;7,["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H)'1H:7,M/E]?;W!T:6]N<ULG<&%R86UE=&5R<R==*2!["B`@
M("`@("`@("`@("`@("`@("`@)&UQ;F%M92`])B!N97<@44YA;64H)&UE=&AO
M9"P@)&YA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`]
M)B!N97<@4T]!4%]686QU92@D;7%N86UE+3YF<6XH*2P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=3=')U8W0G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!A<F%M<RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'-O87!?;7-G(#TF("1T:&ES+3Y?;6%K945N=F5L;W!E*"1P
M87)A;7,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^:&5A9&5R<T]U="P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?96YC;V1I;F<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^7U]O<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@=6YS970H
M)'1H:7,M/FAE861E<G-/=70I.PH*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<V]A<%]M<V<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"1S;V%P7VUS9RD["B`@("`@("`@?0H*("`@("`@("`O
M+R!(86YD;&4@34E-12!O<B!$24U%(&5N8V]D:6YG+@H@("`@("`@("\O(%1/
M1$\Z($1)344@96YC;V1I;F<@<VAO=6QD(&UO=F4@=&\@=&AE('1R86YS<&]R
M="P@9&\@:70@:&5R92!F;W(*("`@("`@("`O+R!N;W<@86YD(&9O<B!E87-E
M(&]F(&=E='1I;F<@:70@9&]N92X*("`@("`@("!I9B`H8V]U;G0H)'1H:7,M
M/E]?871T86-H;65N=',I*2!["B`@("`@("`@("`@(&EF("@H:7-S970H)'1H
M:7,M/E]?;W!T:6]N<ULG871T86-H;65N=',G72D@)B8*("`@("`@("`@("`@
M("`@("`D=&AI<RT^7U]O<'1I;VYS6R=A='1A8VAM96YT<R==(#T]("=-:6UE
M)RD@?'P*("`@("`@("`@("`@("`@(&ES<V5T*"1T:&ES+3Y?7V]P=&EO;G-;
M)TUI;64G72DI('L*("`@("`@("`@("`@("`@("1S;V%P7VUS9R`])B`D=&AI
M<RT^7VUA:V5-:6UE365S<V%G92@D<V]A<%]M<V<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]E;F-O9&EN9RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`O+R!D969A=6QT(&ES(&1I;64*("`@("`@("`@("`@("`@("1S;V%P
M7VUS9R`])B`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M<V<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]E;F-O9&EN9RD["B`@("`@("`@("`@("`@("`D=&AI
M<RT^7U]O<'1I;VYS6R=H96%D97)S)UU;)T-O;G1E;G0M5'EP92==(#T@)V%P
M<&QI8V%T:6]N+V1I;64G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"1S;V%P7VUS9RD["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($EN<W1A;G1I871E
M(&-L:65N="X*("`@("`@("!I9B`H:7-?87)R87DH)'-O87!?;7-G*2D@>PH@
M("`@("`@("`@("`D<V]A<%]D871A(#TF("1S;V%P7VUS9ULG8F]D>2==.PH@
M("`@("`@("`@("!I9B`H8V]U;G0H)'-O87!?;7-G6R=H96%D97)S)UTI*2![
M"B`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]?;W!T:6]N<ULG
M:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?7V]P
M=&EO;G-;)VAE861E<G,G72`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?7V]P=&EO
M;G-;)VAE861E<G,G72P@)'-O87!?;7-G6R=H96%D97)S)UTI.PH@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7U]O<'1I;VYS6R=H96%D97)S)UT@/2`D<V]A<%]M<V=;)VAE861E<G,G73L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S;V%P7V1A=&$@/28@)'-O87!?;7-G.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1S;V%P7V1A=&$["B`@("!]"@H@("`@
M9G5N8W1I;VX@)E]?<&%R<V4H)B1R97-P;VYS92P@)&5N8V]D:6YG+"`F)&%T
M=&%C:&UE;G1S*0H@("`@>PH@("`@("`@("\O(%!A<G-E('1H92!R97-P;VYS
M92X*("`@("`@("`D<F5S<&]N<V4@/28@;F5W(%-/05!?4&%R<V5R*"1R97-P
M;VYS92P@)&5N8V]D:6YG+"`D871T86-H;65N=',I.PH@("`@("`@(&EF("@D
M<F5S<&]N<V4M/F9A=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*"1R97-P;VYS92T^9F%U;'0I.PH@("`@("`@('T*
M"B`@("`@("`@+R\@4F5T=7)N(&%R<F%Y(&]F('!A<F%M971E<G,N"B`@("`@
M("`@)')E='5R;B`])B`D<F5S<&]N<V4M/F=E=%)E<W!O;G-E*"D["B`@("`@
M("`@)&AE861E<G,@/28@)')E<W!O;G-E+3YG971(96%D97)S*"D["B`@("`@
M("`@:68@*"1H96%D97)S*2!["B`@("`@("`@("`@("1T:&ES+3YH96%D97)S
M26X@/28@)'1H:7,M/E]?9&5C;V1E4F5S<&]N<V4H)&AE861E<G,L(&9A;'-E
M*3L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^7U]D96-O9&52
M97-P;VYS92@D<F5T=7)N*3L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]D96-O
M9&5297-P;VYS92@F)')E<W!O;G-E+"`D<VAI9G0@/2!T<G5E*0H@("`@>PH@
M("`@("`@(&EF("@A)')E<W!O;G-E*2!["B`@("`@("`@("`@(')E='5R;B!N
M=6QL.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R('9A;&ED(')E
M<W!O;G-E+@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97-P;VYS92DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M)')E<W!O;G-E*3L*("`@("`@("!](&5L<V5I9B`H(6ES7V$H)')E<W!O;G-E
M+"`G<V]A<%]V86QU92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*")$:61N)W0@9V5T(%-/05!?5F%L=64@;V)J96-T
M(&)A8VL@9G)O;2!C;&EE;G0B*3L*("`@("`@("!]"@H@("`@("`@("\O($1E
M8V]D92!T;R!N871I=F4@<&AP(&1A=&%T>7!E+@H@("`@("`@("1R971U<FY!
M<G)A>2`])B`D=&AI<RT^7V1E8V]D92@D<F5S<&]N<V4I.PH*("`@("`@("`O
M+R!&875L=#\*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5T=7)N07)R
M87DI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A
M=6QT*"1R971U<FY!<G)A>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-?
M;V)J96-T*"1R971U<FY!<G)A>2D@)B8*("`@("`@("`@("`@<W1R8V%S96-M
M<"AG971?8VQA<W,H)')E='5R;D%R<F%Y*2P@)W-T9$-L87-S)RD@/3T@,"D@
M>PH@("`@("`@("`@("`D<F5T=7)N07)R87D@/2!G971?;V)J96-T7W9A<G,H
M)')E='5R;D%R<F%Y*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1R971U<FY!<G)A>2DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1R971U
M<FY!<G)A>5LG9F%U;'1C;V1E)UTI('Q\"B`@("`@("`@("`@("`@("!I<W-E
M="@D<F5T=7)N07)R87E;)U-/05`M14Y6.F9A=6QT8V]D92==*2D@>PH@("`@
M("`@("`@("`@("`@)&9A=6QT8V]D92`]("1F875L='-T<FEN9R`]("1F875L
M=&1E=&%I;"`]("1F875L=&%C=&]R(#T@)R<["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D<F5T=7)N07)R87D@87,@)&L@/3X@)'8I('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RP@)V9A=6QT8V]D92<I*2`D9F%U
M;'1C;V1E(#T@)'8["B`@("`@("`@("`@("`@("`@("`@:68@*'-T<FES='(H
M)&LL("=F875L='-T<FEN9R<I*2`D9F%U;'1S=')I;F<@/2`D=CL*("`@("`@
M("`@("`@("`@("`@("!I9B`H<W1R:7-T<B@D:RP@)V1E=&%I;"<I*2`D9F%U
M;'1D971A:6P@/2`D=CL*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R:7-T
M<B@D:RP@)V9A=6QT86-T;W(G*2D@)&9A=6QT86-T;W(@/2`D=CL*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*"1F875L='-T<FEN9RP@)&9A=6QT9&5T86EL+"`D9F%U
M;'1A8W1O<BP@)&9A=6QT8V]D92D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@+R\@4F5T=7)N(&%R<F%Y(&]F(')E='5R;B!V86QU97,N"B`@("`@("`@
M("`@(&EF("@D<VAI9G0@)B8@8V]U;G0H)')E='5R;D%R<F%Y*2`]/2`Q*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@87)R87E?<VAI9G0H)')E='5R;D%R
M<F%Y*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')E='5R
M;D%R<F%Y.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E='5R;D%R<F%Y
M.PH@("`@?0H*("`@(&9U;F-T:6]N(%]?9V5T7W=I<F4H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^7U]O<'1I;VYS6R=T<F%C92==(#X@,"`F)@H@("`@
M("`@("`@("`H)'1H:7,M/E]?;&%S=%]R97%U97-T('Q\("1T:&ES+3Y?7VQA
M<W1?<F5S<&]N<V4I*2!["B`@("`@("`@("`@(')E='5R;B`B3U541T])3D<Z
M7&Y<;B(@+@H@("`@("`@("`@("`@("`@)'1H:7,M/E]?;&%S=%]R97%U97-T
M("X*("`@("`@("`@("`@("`@(")<;EQN24Y#3TU)3D=<;EQN(B`N"B`@("`@
M("`@("`@("`@("!P<F5G7W)E<&QA8V4H(B\^/"\B+"(^7')<;CPB+"`D=&AI
M<RT^7U]L87-T7W)E<W!O;G-E*3L*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@?0H*?0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O4T]!4"]"87-E+G!H<```````````````````````````````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#$R,C$S,R`Q,#4Q-30S-#$S,R`P,C`V,3``(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+RHJ"B`J(%1H:7,@9FEL92!L;V%D<R!A;&P@<F5Q=6ER960@;&EB<F%R:65S
M+"!D969I;F5S(&-O;G-T86YT<R!U<V5D(&%C<F]S<R!T:&4*("H@4T]!4"!P
M86-K86=E+"!A;F0@9&5F:6YE<R!T:&4@8F%S92!C;&%S<V5S('1H870@;6]S
M="!O=&AE<B!C;&%S<V5S(&]F('1H:7,*("H@<&%C:V%G92!E>'1E;F0N"B`J
M"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE
M(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A
M8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A
M=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@
M0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*
M("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A;G@T
M+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H;W(@("`@(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A;F0@
M;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K0&AO
M<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T:&]R("`@("!*86X@4V-H
M;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-86EN=&5N86YC90H@*B!`
M8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@4$A0
M($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4T]!4`H@*B\*"B\J*@H@*B!33T%07T]"2D5#5%]35%)5
M0U0@;6%K97,@4$5!4CHZ4T]!4"!U<V4@;V)J96-T<R!F;W(@4T]!4"!S=')U
M8W1U<F5S(')A=&AE<@H@*B!T:&%N(&%R<F%Y<RX@(%1H:7,@:&%S(&)E96X@
M9&]N92!T;R!P<F]V:61E(&$@8VQO<V5R(&UA=&-H('1O('!H<"US;V%P+B`@
M268*("H@=&AE(&]L9"!B96AA=FEO=7(@:7,@;F5E9&5D+"!S970@=&\@9F%L
M<V4N("!4:&4@;VQD(&)E:&%V:6]U<B!I<PH@*B!D97!R96-A=&5D+@H@*@H@
M*B!`9VQO8F%L(&)O;VP@)$=,3T)!3%-;)U-/05!?3T)*14-47U-44E5#5"==
M"B`J+PHD1TQ/0D%,4ULG4T]!4%]/0DI%0U1?4U1254-4)UT@/2!T<G5E.PH*
M+RHJ"B`J(%-/05!?4D%77T-/3E9%4E0@;6%K97,@4$5!4CHZ4T]!4"!A='1E
M;7!T('1O(&1E=&5R;6EN92!W:&%T(%-/05`@='EP92!A(%!(4`H@*B!S=')I
M;F<@0T]53$0@8F4N("!4:&ES(&UA>2!R97-U;'0@:6X@<VQI9VAT;'D@8F5T
M=&5R(&EN=&5R;W!E<F%B:6QI='D@=VAE;@H@*B!Y;W4@87)E(&YO="!U<VEN
M9R!74T1,+"!A;F0@87)E(&)E:6YG(&QA>GD@86YD(&YO="!U<VEN9R!33T%0
M7U9A;'5E('1O"B`J(&1E9FEN92!T>7!E<R!F;W(@>6]U<B!V86QU97,N"B`J
M"B`J($!G;&]B86P@8F]O;"`D1TQ/0D%,4ULG4T]!4%]205=?0T].5D525"==
M"B`J+PHD1TQ/0D%,4ULG4T]!4%]205=?0T].5D525"==(#T@9F%L<V4["@IR
M97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U1Y
M<&4O9&%T951I;64N<&AP)SL*<F5Q=6ER95]O;F-E("=33T%0+U1Y<&4O:&5X
M0FEN87)Y+G!H<"<["@HO+R!O<'1I;VYA;"!F96%T=7)E<PHD1TQ/0D%,4ULG
M4T]!4%]O<'1I;VYS)UT@/2!A<G)A>2@I.PH*0&EN8VQU9&5?;VYC92`G36%I
M;"]M:6UE4&%R="YP:'`G.PI`:6YC;'5D95]O;F-E("=-86EL+VUI;65$96-O
M9&4N<&AP)SL*:68@*&-L87-S7V5X:7-T<R@G36%I;%]M:6UE4&%R="<I*2![
M"B`@("`D1TQ/0D%,4ULG4T]!4%]O<'1I;VYS)UU;)TUI;64G72`](#$["B`@
M("!D969I;F4H)TU!24Q?34E-15!!4E1?0U),1B<L(")<<EQN(BD["GT*"D!I
M;F-L=61E7V]N8V4@)TYE="]$24U%+G!H<"<["FEF("AC;&%S<U]E>&ES=',H
M)TYE=%]$24U%7TUE<W-A9V4G*2D@>PH@("`@)$=,3T)!3%-;)U-/05!?;W!T
M:6]N<R==6R=$24U%)UT@/2`Q.PI]"@HO*BH*("H@16YA8FQE(&1E8G5G9VEN
M9R!I;F9O<FUA=&EO;C\*("H*("H@0&=L;V)A;"!B;V]L("1'3$]"04Q36R=3
M3T%07T1%0E5')UT*("H@0&YA;64@)%-/05!?1$5"54<*("HO"B1'3$]"04Q3
M6R=33T%07T1%0E5')UT@/2!F86QS93L*"FEF("@A9G5N8W1I;VY?97AI<W1S
M*"=V97)S:6]N7V-O;7!A<F4G*2!\?`H@("`@=F5R<VEO;E]C;VUP87)E*'!H
M<'9E<G-I;VXH*2P@)S0N,2<L("<\)RDI('L*("`@(&1I92@B<F5Q=6ER97,@
M4$A0(#0N,2!O<B!H:6=H97)<;B(I.PI]"FEF("AV97)S:6]N7V-O;7!A<F4H
M<&AP=F5R<VEO;B@I+"`G-"XQ)RP@)SX])RD@)B8*("`@('9E<G-I;VY?8V]M
M<&%R92AP:'!V97)S:6]N*"DL("<T+C(G+"`G/"<I*2!["B`@("!D969I;F4H
M)T9,3T%4)RP@)V1O=6)L92<I.PI](&5L<V4@>PH@("`@9&5F:6YE*"=&3$]!
M5"<L("=F;&]A="<I.PI]"@II9B`H(61E9FEN960H)TE.1B<I*2!["B`@("!D
M969I;F4H)TE.1B<L(#$N.&4S,#<I.PI]"FEF("@A9&5F:6YE9"@G3D%.)RDI
M('L*("`@(&1E9FEN92@G3D%.)RP@,"XP*3L*?0H*9&5F:6YE*"=33T%07TQ)
M0E)!4EE?5D524TE/3B<L("<P+C@N,%)#-"<I.PID969I;F4H)U-/05!?3$E"
M4D%265].04U%)RP@("`@)U!%05(M4T]!4"`P+C@N,%)#-"UD979E;"<I.PH*
M+R\@4V5T('-C:&5M82!V97)S:6]N+@ID969I;F4H)U-/05!?6$U,7U-#2$5-
M05]615)324].)RP@("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M
M82<I.PID969I;F4H)U-/05!?6$U,7U-#2$5-05])3E-404Y#12<L("=H='1P
M.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI;G-T86YC92<I.PID969I
M;F4H)U-/05!?6$U,7U-#2$5-05\Q.3DY)RP@("`@("=H='1P.B\O=W=W+G<S
M+F]R9R\Q.3DY+UA-3%-C:&5M82<I.PID969I;F4H)U-/05!?4T-(14U!)RP@
M("`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W<V1L
M+W-O87`O)RD["F1E9FEN92@G4T]!4%]30TA%34%?14Y#3T1)3D<G+"`@("`@
M)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O)RD[
M"F1E9FEN92@G4T]!4%]%3E9%3$]0)RP@("`@("`@("`@("`@)VAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YV96QO<&4O)RD["@ID969I;F4H
M)U-#2$5-05]$25-#3R<L("`@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX
M;6QS;V%P+F]R9R]D:7-C;R\G*3L*9&5F:6YE*"=30TA%34%?1$E30T]?4T-,
M)RP@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O9&ES8V\O
M<V-L+R<I.PH*9&5F:6YE*"=30TA%34%?4T]!4"<L("`@("`@("`@("`@("`G
M:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O=W-D;"]S;V%P+R<I.PID969I
M;F4H)U-#2$5-05]33T%07TA45%`G+"`@("`@("`@("=H='1P.B\O<V-H96UA
M<RYX;6QS;V%P+F]R9R]S;V%P+VAT='`G*3L*9&5F:6YE*"=30TA%34%?5U-$
M3%](5%10)RP@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M=W-D;"]H='1P+R<I.PID969I;F4H)U-#2$5-05]-24U%)RP@("`@("`@("`@
M("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W<V1L+VUI;64O)RD[
M"F1E9FEN92@G4T-(14U!7U=31$PG+"`@("`@("`@("`@("`@)VAT='`Z+R]S
M8VAE;6%S+GAM;'-O87`N;W)G+W=S9&PO)RD["F1E9FEN92@G4T-(14U!7T1)
M344G+"`@("`@("`@("`@("`@)VAT='`Z+R]S8VAE;6%S+GAM;'-O87`N;W)G
M+W=S+S(P,#(O,#0O9&EM92]W<V1L+R<I.PID969I;F4H)U-#2$5-05]#3TY4
M14Y4)RP@("`@("`@("`@("=H='1P.B\O<V-H96UA<RYX;6QS;V%P+F]R9R]W
M<R\R,#`R+S`T+V-O;G1E;G0M='EP92\G*3L*9&5F:6YE*"=30TA%34%?4D5&
M)RP@("`@("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M=W,O,C`P,B\P-"]R969E<F5N8V4O)RD["@ID969I;F4H)U-/05!?1$5&055,
M5%]%3D-/1$E.1R<L("`G551&+3@G*3L*"FEF("@A9G5N8W1I;VY?97AI<W1S
M*"=I<U]A)RDI('L*("`@(&9U;F-T:6]N(&ES7V$H)B1O8FIE8W0L("1C;&%S
M<U]N86UE*0H@("`@>PH@("`@("`@(&EF("AS=')T;VQO=V5R*&=E=%]C;&%S
M<R@D;V)J96-T*2D@/3T@)&-L87-S7VYA;64I('L*("`@("`@("`@("`@<F5T
M=7)N('1R=64["B`@("`@("`@?0H@("`@("`@(')E='5R;B!I<U]S=6)C;&%S
M<U]O9B@D;V)J96-T+"`D8VQA<W-?;F%M92D["B`@("!]"GT*"FEF("@A8VQA
M<W-?97AI<W1S*"=S=&1#;&%S<R<I*2!["B`@("`O*B!02%`U(&1O97-N)W0@
M9&5F:6YE('1H:7,_("HO"B`@("!C;&%S<R!S=&1#;&%S<R!["B`@("`@("`@
M9G5N8W1I;VX@7U]C;VYS=')U8W1O<B@I('M]"B`@("!]"GT*"F-L87-S(%-/
M05!?0F%S95]/8FIE8W0@97AT96YD<R!014%2"GL*("`@("\J*@H@("`@("H@
M4W1O<F4@9&5B=6=G:6YG(&EN9F]R;6%T:6]N(&EN("1?9&5B=6=?9&%T83\*
M("`@("`J"B`@("`@*B!`<V5E("1D96)U9U]D871A+"!33T%07T)A<V4*("`@
M("`J($!V87(@8F]O;&5A;B`D7V1E8G5G7V9L86<*("`@("`J+PH@("`@=F%R
M("1?9&5B=6=?9FQA9R`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R:6YG
M(&-O;G1A:6YI;F<@9&5B=6=G:6YG(&EN9F]R;6%T:6]N(&EF("1?9&5B=6=?
M9FQA9R!I<R!T<G5E+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B!`<V5E("1D96)U9U]F;&%G+"!33T%07T)A<V4*("`@("`J($!V87(@
M<W1R:6YG("1?9&5B=6=?9&%T80H@("`@("HO"B`@("!V87(@)%]D96)U9U]D
M871A(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=7!P;W)T960@96YC;V1I;F=S
M+"!L:6UI=&5D(&)Y(%A-3"!E>'1E;G-I;VXN"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>2`D7V5N8V]D:6YG<PH@("`@("HO"B`@("!V87(@)%]E;F-O9&EN
M9W,@/2!A<G)A>2@G25-/+3@X-3DM,2<L("=54RU!4T-)22<L("=55$8M."<I
M.PH*("`@("\J*@H@("`@("H@1F%U;'0@8V]D92X*("`@("`J"B`@("`@*B!`
M=F%R('-T<FEN9R`D7VUY9F%U;'1C;V1E"B`@("`@*B\*("`@('9A<B`D7VUY
M9F%U;'1C;V1E(#T@)R<["@H@("`@+RHJ"B`@("`@*B!296-E;G0@4$5!4E]%
M<G)O<B!O8FIE8W0N"B`@("`@*@H@("`@("H@0'9A<B!014%27T5R<F]R("1F
M875L=`H@("`@("HO"B`@("!V87(@)&9A=6QT(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J($-O;G-T<G5C=&]R+@H@("`@("H*("`@("`J($!S964@)&1E8G5G
M7V1A=&$L(%]D96)U9R@I"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M9F%U;'1C;V1E("!%<G)O<B!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!3
M3T%07T)A<V5?3V)J96-T*"1F875L=&-O9&4@/2`G0VQI96YT)RD*("`@('L*
M("`@("`@("`D=&AI<RT^7VUY9F%U;'1C;V1E(#T@)&9A=6QT8V]D93L*("`@
M("`@("`D=&AI<RT^7V1E8G5G7V9L86<@/2`D1TQ/0D%,4ULG4T]!4%]$14)5
M1R==.PH@("`@("`@('!A<F5N=#HZ4$5!4B@G4T]!4%]&875L="<I.PH@("`@
M?0H*("`@("\J*@H@("`@("H@4F%I<V5S(&$@4T]!4"!E<G)O<BX*("`@("`J
M"B`@("`@*B!0;&5A<V4@<F5F97(@=&\@=&AE(%-/05`@9&5F:6YI=&EO;B!F
M;W(@86X@:6UP<F5S<VEO;B!O9B!W:&%T(&$@8V5R=&%I;@H@("`@("H@<&%R
M86UE=&5R('-T86YD<R!F;W(N"B`@("`@*@H@("`@("H@57-E("1D96)U9U]F
M;&%G('1O('-T;W)E(&5R<F]R<R!T;R!T:&4@;65M8F5R('9A<FEA8FQE("1D
M96)U9U]D871A"B`@("`@*@H@("`@("H@0'-E92`D9&5B=6=?9FQA9RP@)&1E
M8G5G7V1A=&$L(%-/05!?1F%U;'0*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG?&]B:F5C="`D<W1R("!%<G)O<B!M97-S86=E(&]R(&]B:F5C="X*("`@
M("`J($!P87)A;2!S=')I;F<@)&1E=&%I;"`@("`@($1E=&%I;&5D(&5R<F]R
M(&UE<W-A9V4N"B`@("`@*B!`<&%R86T@<W1R:6YG("1A8W1O<E5220H@("`@
M("H@0'!A<F%M(&UI>&5D("1C;V1E"B`@("`@*B!`<&%R86T@;6EX960@)&UO
M9&4*("`@("`J($!P87)A;2!M:7AE9"`D;W!T:6]N<PH@("`@("H@0'!A<F%M
M(&)O;VQE86X@)'-K:7!M<V<*("`@("`J+PH@("`@9G5N8W1I;VX@)E]R86ES
M95-O87!&875L="@D<W1R+"`D9&5T86EL(#T@)R<L("1A8W1O<E5222`]("<G
M+"`D8V]D92`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1M;V1E(#T@;G5L;"P@)&]P=&EO;G,@/2!N=6QL+"`D<VMI<&US9R`](&9A
M;'-E*0H@("`@>PH@("`@("`@("\O(%!A<W,@=&AR;W5G:"!P<F5V:6]U<R!F
M875L=',N"B`@("`@("`@)&ES7VEN<W1A;F-E(#T@:7-S970H)'1H:7,I.PH@
M("`@("`@(&EF("AI<U]O8FIE8W0H)'-T<BDI('L*("`@("`@("`@("`@)&9A
M=6QT(#TF("1S='(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@
M*"$D8V]D92D@>PH@("`@("`@("`@("`@("`@)&-O9&4@/2`D:7-?:6YS=&%N
M8V4@/R`D=&AI<RT^7VUY9F%U;'1C;V1E(#H@)T-L:65N="<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&9A=6QT(#TF(&YE=R!33T%07T9A=6QT*"1S
M='(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8V]D
M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A8W1O
M<E5222P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M971A:6PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;6]D92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O
M<'1I;VYS*3L*("`@("`@("!]"B`@("`@("`@:68@*"1I<U]I;G-T86YC92D@
M>PH@("`@("`@("`@("`D=&AI<RT^9F%U;'0@/28@)&9A=6QT.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1F875L=#L*("`@('T*"B`@("!F=6YC=&EO
M;B!?7VES9F%U;'0H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^9F%U
M;'0@(3T@;G5L;#L*("`@('T*"B`@("!F=6YC=&EO;B`F7U]G971F875L="@I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@('T*"B`@
M("`O*BH*("`@("`J($%D9',@82!S=')I;F<@=&\@=&AE(&1E8G5G(&1A=&$N
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R:6YG("!$96)U9V=I
M;F<@;65S<V%G92X*("`@("`J+PH@("`@9G5N8W1I;VX@7V1E8G5G*"1S=')I
M;F<I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?9&5B=6=?9FQA9RD@>PH@
M("`@("`@("`@("`D=&AI<RT^7V1E8G5G7V1A=&$@+CT@9V5T7V-L87-S*"1T
M:&ES*2`N("<Z("<@+@H@("`@("`@("`@("`@("`@<W1R7W)E<&QA8V4H)SXG
M+"`B/EQR7&XB+"`D<W1R:6YG*2`N(")<;B(["B`@("`@("`@?0H@("`@?0H*
M?0H*+RHJ"B`J($-O;6UO;B!B87-E(&-L87-S(&]F(&%L;"!33T%0(&-L87-S
M97,N"B`J"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0'!A8VMA9V4@(%-/05`*
M("H@0&%U=&AO<B`@(%-H86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^($-O
M;G9E<G-I;VX@=&\@4$5!4B!A;F0@=7!D871E<PH@*B\*8VQA<W,@4T]!4%]"
M87-E(&5X=&5N9',@4T]!4%]"87-E7T]B:F5C=`I["B`@("!V87(@)%]834Q3
M8VAE;6$@/2!A<G)A>2@G:'1T<#HO+W=W=RYW,RYO<F<O,C`P,2]834Q38VAE
M;6$G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VAT='`Z+R]W=W<N
M=S,N;W)G+S$Y.3DO6$U,4V-H96UA)RD["B`@("!V87(@)%]834Q38VAE;6%6
M97)S:6]N(#T@)VAT='`Z+R]W=W<N=S,N;W)G+S(P,#$O6$U,4V-H96UA)SL*
M"B`@("`O+R!L;V%D('1Y<&5S(&EN=&\@='EP96UA<"!A<G)A>0H@("`@=F%R
M("1?='EP96UA<"`](&%R<F%Y*`H@("`@("`@("=H='1P.B\O=W=W+G<S+F]R
M9R\R,#`Q+UA-3%-C:&5M82<@/3X@87)R87DH"B`@("`@("`@("`@("=S=')I
M;F<G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G8F]O;&5A;B<@/3X@)V)O
M;VQE86XG+`H@("`@("`@("`@("`G9FQO870G(#T^($9,3T%4+`H@("`@("`@
M("`@("`G9&]U8FQE)R`]/B!&3$]!5"P*("`@("`@("`@("`@)V1E8VEM86PG
M(#T^($9,3T%4+`H@("`@("`@("`@("`G9'5R871I;VXG(#T^("=I;G1E9V5R
M)RP*("`@("`@("`@("`@)V1A=&54:6UE)R`]/B`G<W1R:6YG)RP*("`@("`@
M("`@("`@)W1I;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G9&%T92<@
M/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=G665A<DUO;G1H)R`]/B`G:6YT
M96=E<B<L"B`@("`@("`@("`@("=G665A<B<@/3X@)VEN=&5G97(G+`H@("`@
M("`@("`@("`G9TUO;G1H1&%Y)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@
M("=G1&%Y)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=G36]N=&@G(#T^
M("=I;G1E9V5R)RP*("`@("`@("`@("`@)VAE>$)I;F%R>2<@/3X@)W-T<FEN
M9R<L"B`@("`@("`@("`@("=B87-E-C1":6YA<GDG(#T^("=S=')I;F<G+`H@
M("`@("`@("`@("`O+R!D97)I=F5D(&1A=&%T>7!E<PH@("`@("`@("`@("`G
M;F]R;6%L:7IE9%-T<FEN9R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=T
M;VME;B<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=L86YG=6%G92<@/3X@
M)W-T<FEN9R<L"B`@("`@("`@("`@("=.351/2T5.)R`]/B`G<W1R:6YG)RP*
M("`@("`@("`@("`@)TY-5$]+14Y3)R`]/B`G<W1R:6YG)RP*("`@("`@("`@
M("`@)TYA;64G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G3D-.86UE)R`]
M/B`G<W1R:6YG)RP*("`@("`@("`@("`@)TE$)R`]/B`G<W1R:6YG)RP*("`@
M("`@("`@("`@)TE$4D5&)R`]/B`G<W1R:6YG)RP*("`@("`@("`@("`@)TE$
M4D5&4R<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=%3E1)5%DG(#T^("=S
M=')I;F<G+`H@("`@("`@("`@("`G14Y4251)15,G(#T^("=S=')I;F<G+`H@
M("`@("`@("`@("`G:6YT96=E<B<@/3X@)VEN=&5G97(G+`H@("`@("`@("`@
M("`G;F]N4&]S:71I=F5);G1E9V5R)R`]/B`G:6YT96=E<B<L"B`@("`@("`@
M("`@("=N96=A=&EV94EN=&5G97(G(#T^("=I;G1E9V5R)RP*("`@("`@("`@
M("`@)VQO;F<G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)VEN="<@/3X@
M)VEN=&5G97(G+`H@("`@("`@("`@("`G<VAO<G0G(#T^("=I;G1E9V5R)RP*
M("`@("`@("`@("`@)V)Y=&4G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`G
M;F]N3F5G871I=F5);G1E9V5R)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@
M("=U;G-I9VYE9$QO;F<G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)W5N
M<VEG;F5D26YT)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=U;G-I9VYE
M9%-H;W)T)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@("=U;G-I9VYE9$)Y
M=&4G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)W!O<VET:79E26YT96=E
M<B<@(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V%N>51Y<&4G(#T^("=S
M=')I;F<G+`H@("`@("`@("`@("`G86YY55)))R`]/B`G<W1R:6YG)RP*("`@
M("`@("`@("`@)U%.86UE)R`]/B`G<W1R:6YG)PH@("`@("`@("DL"B`@("`@
M("`@)VAT='`Z+R]W=W<N=S,N;W)G+S$Y.3DO6$U,4V-H96UA)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)VDT)R`]/B`G:6YT96=E<B<L"B`@("`@("`@("`@
M("=I;G0G(#T^("=I;G1E9V5R)RP*("`@("`@("`@("`@)V)O;VQE86XG(#T^
M("=B;V]L96%N)RP*("`@("`@("`@("`@)W-T<FEN9R<@/3X@)W-T<FEN9R<L
M"B`@("`@("`@("`@("=D;W5B;&4G(#T^($9,3T%4+`H@("`@("`@("`@("`G
M9FQO870G(#T^($9,3T%4+`H@("`@("`@("`@("`G9&%T951I;64G(#T^("=S
M=')I;F<G+`H@("`@("`@("`@("`G=&EM94EN<W1A;G0G(#T^("=S=')I;F<G
M+`H@("`@("`@("`@("`G8F%S938T0FEN87)Y)R`]/B`G<W1R:6YG)RP*("`@
M("`@("`@("`@)V)A<V4V-"<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("=U
M<BUT>7!E)R`]/B`G<W1R:6YG)PH@("`@("`@("DL"B`@("`@("`@)VAT='`Z
M+R]S8VAE;6%S+GAM;'-O87`N;W)G+W-O87`O96YC;V1I;F<O)R`]/B!A<G)A
M>2@*("`@("`@("`@("`@)V)A<V4V-"<@/3X@)W-T<FEN9R<L"B`@("`@("`@
M("`@("=A<G)A>2<@/3X@)V%R<F%Y)RP*("`@("`@("`@("`@)T%R<F%Y)R`]
M/B`G87)R87DG+`H@("`@("`@("`@("`G4W1R=6-T)R`]/B`G87)R87DG*0H@
M("`@*3L*"B`@("`O*BH*("`@("`J($1E9F%U;'0@8VQA<W,@;F%M92!T;R!U
M<V4@9F]R(&1E8V]D960@<F5S<&]N<V4@;V)J96-T<RX*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9R`D7V1E9F%U;'1/8FIE8W1#;&%S<VYA;64*("`@("`J
M+PH@("`@=F%R("1?9&5F875L=$]B:F5C=$-L87-S;F%M92`]("=S=&1#;&%S
M<R<["@H@("`@+R\@3&]A9"!N86UE<W!A8V4@55))<R!I;G1O(&%N(&%R<F%Y
M(&]F(%5222`]/B!P<F5F:7@N"B`@("!V87(@)%]N86UE<W!A8V5S.PH@("`@
M=F%R("1?;F%M97-P86-E.PH*("`@('9A<B`D7WAM;$5N=&ET:65S(#T@87)R
M87DH)R8G(#T^("<F86UP.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<\)R`]/B`G)FQT.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<^)R`]/B`G)F=T.R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("(G(B`]/B`G)F%P;W,[)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)R(G(#T^("<F<75O=#LG*3L*"B`@("!V87(@)%]D;V-O;G9E<G-I
M;VX@/2!F86QS93L*"B`@("!V87(@)%]?871T86-H;65N=',@/2!A<G)A>2@I
M.PH*("`@('9A<B`D7W=S9&P@/2!N=6QL.PH*("`@("\J*@H@("`@("H@5')U
M92!I9B!W92!U<V4@<V5C=&EO;B`U(&5N8V]D:6YG+"!O<B!F86QS92!I9B!T
M:&ES(&ES(&QI=&5R86PN"B`@("`@*@H@("`@("H@0'9A<B!B;V]L96%N("1?
M<V5C=&EO;C4*("`@("`J+PH@("`@=F%R("1?<V5C=&EO;C4@/2!T<G5E.PH*
M("`@("\O($AA;F1L92!T>7!E('1O(&-L87-S(&UA<'!I;F<N"B`@("!V87(@
M)%]A=71O7W1R86YS;&%T:6]N(#T@9F%L<V4["B`@("!V87(@)%]T>7!E7W1R
M86YS;&%T:6]N(#T@87)R87DH*3L*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=&]R+@H@("`@("H*("`@("`J($!S964@)&1E8G5G7V1A=&$L(%]D96)U9R@I
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D9F%U;'1C;V1E("!%<G)O
M<B!C;V1E+@H@("`@("HO"B`@("!F=6YC=&EO;B!33T%07T)A<V4H)&9A=6QT
M8V]D92`]("=#;&EE;G0G*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"
M87-E7T]B:F5C="@D9F%U;'1C;V1E*3L*("`@("`@("`D=&AI<RT^7W)E<V5T
M3F%M97-P86-E<R@I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]R97-E=$YA;65S
M<&%C97,H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;F%M97-P86-E<R`](&%R
M<F%Y*`H@("`@("`@("`@("`G:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O
M<V]A<"]E;G9E;&]P92\G(#T^("=33T%0+45.5B<L"B`@("`@("`@("`@("=H
M='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82<@/3X@)WAS9"<L"B`@
M("`@("`@("`@("=H='1P.B\O=W=W+G<S+F]R9R\R,#`Q+UA-3%-C:&5M82UI
M;G-T86YC92<@/3X@)WAS:2<L"B`@("`@("`@("`@("=H='1P.B\O<V-H96UA
M<RYX;6QS;V%P+F]R9R]S;V%P+V5N8V]D:6YG+R<@/3X@)U-/05`M14Y#)RD[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3971S('1H92!S8VAE;6$@=F5R<VEO
M;B!U<V5D(&EN('1H92!33T%0(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B!`<V5E("1?6$U,4V-H96UA"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`D<V-H96UA5F5R<VEO;B`@5&AE('-C:&5M
M82!V97)S:6]N+@H@("`@("HO"B`@("!F=6YC=&EO;B!?<V5T4V-H96UA5F5R
M<VEO;B@D<V-H96UA5F5R<VEO;BD*("`@('L*("`@("`@("!I9B`H(6EN7V%R
M<F%Y*"1S8VAE;6%697)S:6]N+"`D=&AI<RT^7UA-3%-C:&5M82DI('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(G5N<W5P
M;W)T960@6$U,4V-H96UA("1S8VAE;6%697)S:6]N(BD["B`@("`@("`@?0H@
M("`@("`@("1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;B`]("1S8VAE;6%697)S
M:6]N.PH@("`@("`@("1T;7!.4R`](&%R<F%Y7V9L:7`H)'1H:7,M/E]N86UE
M<W!A8V5S*3L*("`@("`@("`D=&UP3E-;)WAS9"==(#T@)'1H:7,M/E]834Q3
M8VAE;6%697)S:6]N.PH@("`@("`@("1T;7!.4ULG>'-I)UT@/2`D=&AI<RT^
M7UA-3%-C:&5M859E<G-I;VX@+B`G+6EN<W1A;F-E)SL*("`@("`@("`D=&AI
M<RT^7VYA;65S<&%C97,@/2!A<G)A>5]F;&EP*"1T;7!.4RD["B`@("!]"@H@
M("`@9G5N8W1I;VX@7V=E=$YA;65S<&%C95!R969I>"@D;G,I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E("8F("1N<R`]/2`D=&AI<RT^
M7VYA;65S<&%C92D@>PH@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@
M?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7VYA;65S<&%C97-;)&YS72DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?;F%M97-P86-E<ULD;G-=
M.PH@("`@("`@('T*("`@("`@("`D<')E9FEX(#T@)VYS)R`N(&-O=6YT*"1T
M:&ES+3Y?;F%M97-P86-E<RD["B`@("`@("`@)'1H:7,M/E]N86UE<W!A8V5S
M6R1N<UT@/2`D<')E9FEX.PH@("`@("`@(')E='5R;B`D<')E9FEX.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]G971.86UE<W!A8V5&;W)0<F5F:7@H)'!R969I
M>"D*("`@('L*("`@("`@("`D9FQI<'!E9"`](&%R<F%Y7V9L:7`H)'1H:7,M
M/E]N86UE<W!A8V5S*3L*("`@("`@("!I9B`H:7-S970H)&9L:7!P961;)'!R
M969I>%TI*2!["B`@("`@("`@("`@(')E='5R;B`D9FQI<'!E9%LD<')E9FEX
M73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&YU;&P["B`@("!]"@H@("`@
M9G5N8W1I;VX@7VES4V]A<%9A;'5E*"8D=F%L=64I"B`@("!["B`@("`@("`@
M<F5T=7)N(&ES7V$H)'9A;'5E+"`G4T]!4%]686QU92<I.PH@("`@?0H*("`@
M(&9U;F-T:6]N(%]S97)I86QI>F5686QU92@F)'9A;'5E+"`D;F%M92`]("<G
M+"`D='EP92`](&9A;'-E+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1E;$YA;65S<&%C92`](&YU;&PL("1T>7!E3F%M97-P86-E(#T@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<R`](&%R<F%Y
M*"DL("1A='1R:6)U=&5S(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D87)T>7!E(#T@)R<I"B`@("!["B`@("`@("`@)&YA;65S
M<&%C97,@/2!A<G)A>2@I.PH@("`@("`@("1A<G)A>51Y<&4@/2`D87)R87E?
M9&5P=&@@/2`D>&UL;W5T7W9A;'5E(#T@;G5L;#L*("`@("`@("`D='EP95!R
M969I>"`]("1E;%!R969I>"`]("1X;6QO=71?;V9F<V5T(#T@)'AM;&]U=%]A
M<G)A>51Y<&4@/2`G)SL*("`@("`@("`D>&UL;W5T7W1Y<&4@/2`D>&UL;G,@
M/2`D<'1Y<&4@/2`D87)R87E?='EP95]N<R`]("<G.PH*("`@("`@("!I9B`H
M(21N86UE('Q\(&ES7VYU;65R:6,H)&YA;64I*2!["B`@("`@("`@("`@("1N
M86UE(#T@)VET96TG.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?
M=W-D;"D@>PH@("`@("`@("`@("!L:7-T*"1P='EP92P@)&%R<F%Y5'EP92P@
M)&%R<F%Y7W1Y<&5?;G,L("1A<G)A>5]D97!T:"D*("`@("`@("`@("`@("`@
M(#T@)'1H:7,M/E]W<V1L+3YG97138VAE;6%4>7!E*"1T>7!E+"`D;F%M92P@
M)'1Y<&5.86UE<W!A8V4I.PH@("`@("`@('T*"B`@("`@("`@:68@*"$D87)R
M87E4>7!E*2!["B`@("`@("`@("`@("1A<G)A>51Y<&4@/2`D87)T>7!E.PH@
M("`@("`@('T*("`@("`@("!I9B`H(21P='EP92D@>PH@("`@("`@("`@("`D
M<'1Y<&4@/2`D=&AI<RT^7V=E=%1Y<&4H)'9A;'5E*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"$D='EP92D@>PH@("`@("`@("`@("`D='EP92`]("1P='EP
M93L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')C87-E8VUP*"1P='EP92P@
M)U-T<G5C="<I(#T](#`@?'P*("`@("`@("`@("`@<W1R8V%S96-M<"@D='EP
M92P@)U-T<G5C="<I(#T](#`I('L*("`@("`@("`@("`@+R\@4W1R=6-T"B`@
M("`@("`@("`@("1V87)S(#T@;G5L;#L*("`@("`@("`@("`@:68@*&ES7V]B
M:F5C="@D=F%L=64I*2!["B`@("`@("`@("`@("`@("`D=F%R<R`](&=E=%]O
M8FIE8W1?=F%R<R@D=F%L=64I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'9A<G,@/2`F)'9A;'5E.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D=F%R<RDI('L*("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*&%R<F%Y7VME>7,H)'9A<G,I(&%S("1K*2!["B`@("`@
M("`@("`@("`@("`@("`@+R\@2&ED92!P<FEV871E('9A<G,N"B`@("`@("`@
M("`@("`@("`@("`@:68@*"1K6S!=(#T]("=?)RD@8V]N=&EN=64["B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D=F%R<ULD:UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]A*"1V87)S6R1K72P@)U-/
M05!?5F%L=64G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'AM
M;&]U=%]V86QU92`N/2`D=F%R<ULD:UTM/G-E<FEA;&EZ92@D=&AI<RD["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!86%@@9V5T('1H92!M96UB97)S(&%N9"!S97)I
M86QI>F4@=&AE;2!I;G-T96%D"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!C;VYV97)T:6YG('1O(&%N(&%R<F%Y(&ES(&UO<F4@;W9E<FAE860@
M=&AA;B!W90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@<VAO=6QD
M(')E86QL>2!D;RX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1X;6QO
M=71?=F%L=64@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92AG971?;V)J96-T
M7W9A<G,H)'9A<G-;)&M=*2P@)&LL(&9A;'-E+"`D=&AI<RT^7W-E8W1I;VXU
M(#\@;G5L;"`Z("1E;$YA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D>&UL;W5T7W9A;'5E("X]("1T:&ES+3Y?<V5R:6%L
M:7IE5F%L=64H)'9A<G-;)&M=+"`D:RP@9F%L<V4L("1T:&ES+3Y?<V5C=&EO
M;C4@/R!N=6QL(#H@)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9B`H<W1R8V%S96-M<"@D<'1Y<&4L("=!<G)A>2<I(#T](#`@?'P*
M("`@("`@("`@("`@("`@("`@<W1R8V%S96-M<"@D='EP92P@)T%R<F%Y)RD@
M/3T@,"D@>PH@("`@("`@("`@("`O+R!!<G)A>2X*("`@("`@("`@("`@)'1Y
M<&5.86UE<W!A8V4@/2!33T%07U-#2$5-05]%3D-/1$E.1SL*("`@("`@("`@
M("`@)&]R:6=?='EP92`]("1T>7!E.PH@("`@("`@("`@("`D='EP92`]("=!
M<G)A>2<["B`@("`@("`@("`@("1N=6UT>7!E<R`](#`["B`@("`@("`@("`@
M("\O(%A86"!T:&ES('=I;&P@8F4@<VQO=R!O;B!L87)G97(@87)R87ES+B`@
M0F%S:6-A;&QY+"!I="!F;&%T=&5N<PH@("`@("`@("`@("`O+R!A<G)A>7,@
M=&\@86QL;W<@=7,@=&\@<V5R:6%L:7IE(&UU;'1I+61I;65N<VEO;F%L(&%R
M<F%Y<RX@(%=E"B`@("`@("`@("`@("\O(&]N;'D@9&\@=&AI<R!I9B!A<G)A
M>51Y<&4@:7,@<V5T+"!W:&EC:"!W:6QL('1Y<&EC86QL>2!O;FQY"B`@("`@
M("`@("`@("\O(&AA<'!E;B!I9B!W92!A<F4@=7-I;F<@5U-$3`H@("`@("`@
M("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V9L871T96XG72D@?'P*("`@("`@
M("`@("`@("`@("@D87)R87E4>7!E("8F"B`@("`@("`@("`@("`@("`@*'-T
M<F-H<B@D87)R87E4>7!E+"`G+"<I('Q\('-T<G-T<B@D87)R87E4>7!E+"`G
M75LG*2DI*2!["B`@("`@("`@("`@("`@("`D;G5M='EP97,@/2`D=&AI<RT^
M7VUU;'1I07)R87E4>7!E*"1V86QU92P@)&%R<F%Y5'EP92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&%R
M7W-I>F4L("1X;6QO=71?=F%L=64I.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`D87)R87E?='EP92`]("1A<G)A>5]T>7!E7W!R969I>"`]("<G.PH@
M("`@("`@("`@("!I9B`H)&YU;71Y<&5S("$](#$I('L*("`@("`@("`@("`@
M("`@("1A<G)A>51Y<&513F%M92`])B!N97<@44YA;64H)&%R<F%Y5'EP92D[
M"B`@("`@("`@("`@("`@("`D87)R87E4>7!E(#T@)&%R<F%Y5'EP95%.86UE
M+3YN86UE.PH@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5S(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@("1A<G)A>5]V86P@/2!N=6QL.PH*("`@("`@
M("`@("`@("`@("\O(%-E<FEA;&EZ92!E86-H(&%R<F%Y(&5L96UE;G0N"B`@
M("`@("`@("`@("`@("`D87)?<VEZ92`](&-O=6YT*"1V86QU92D["B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D=F%L=64@87,@)&%R<F%Y7W9A;"D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VES4V]A<%9A;'5E*"1A
M<G)A>5]V86PI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1A<G)A>5]T
M>7!E(#T@)&%R<F%Y7W9A;"T^='EP93L*("`@("`@("`@("`@("`@("`@("`@
M("`@)&%R<F%Y7W1Y<&5S6R1A<G)A>5]T>7!E72`](#$["B`@("`@("`@("`@
M("`@("`@("`@("`@("1A<G)A>5]T>7!E7VYS(#T@)&%R<F%Y7W9A;"T^='EP
M95]N86UE<W!A8V4["B`@("`@("`@("`@("`@("`@("`@("`@("1X;6QO=71?
M=F%L=64@+CT@)'1H:7,M/E]S97)I86QI>F5686QU92@D87)R87E?=F%L+"`D
M87)R87E?=F%L+3YN86UE+"`D87)R87E?='EP92P@)&%R<F%Y7W1Y<&5?;G,I
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1A<G)A>5]T>7!E(#T@)'1H:7,M/E]G9714>7!E*"1A<G)A
M>5]V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`D87)R87E?='EP97-;
M)&%R<F%Y7W1Y<&5=(#T@,3L*("`@("`@("`@("`@("`@("`@("`@("`@)'AM
M;&]U=%]V86QU92`N/2`D=&AI<RT^7W-E<FEA;&EZ959A;'5E*"1A<G)A>5]V
M86PL("=I=&5M)RP@)&%R<F%Y7W1Y<&4L("1T:&ES+3Y?<V5C=&EO;C4@/R!N
M=6QL(#H@)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'AM;&]U=%]O9F9S
M970@/2`G(%-/05`M14Y#.F]F9G-E=#TB6S!=(B<["B`@("`@("`@("`@("`@
M("!I9B`H(21A<G)A>51Y<&4I('L*("`@("`@("`@("`@("`@("`@("`D;G5M
M='EP97,@/2!C;W5N="@D87)R87E?='EP97,I.PH@("`@("`@("`@("`@("`@
M("`@(&EF("@D;G5M='EP97,@/3T@,2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D87)R87E4>7!E(#T@)&%R<F%Y7W1Y<&4["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("\O(%5S:6YG(&%N>51Y<&4@
M:7,@;6]R92!I;G1E<F]P97)A8FQE+@H@("`@("`@("`@("`@("`@("`@(&EF
M("@D87)R87E?='EP92`]/2`G4W1R=6-T)RD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D87)R87E?='EP92`]("<G.PH@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@D87)R87E?='EP92`]/2`G07)R87DG*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1A<G)A>51Y<&4@/2`G86YY5'EP92<["B`@("`@
M("`@("`@("`@("`@("`@("`@("1A<G)A>5]T>7!E7W!R969I>"`]("=X<V0G
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("@A)&%R<F%Y5'EP92D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R<F%Y5'EP92`]("1A<G)A>5]T>7!E.PH@("`@("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)&%R<F%Y5'EP92!\?"`D;G5M='EP97,@/B`Q*2!["B`@("`@("`@("`@("`@
M("`O+R!3:&]U;&0@<F5F97)E;F-E('=H870@<V-H96UA('=E)W)E('5S:6YG
M+@H@("`@("`@("`@("`@("`@)&%R<F%Y5'EP92`]("=X<V0Z86YY5'EP92<[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!I9B`H)&%R
M<F%Y7W1Y<&5?;G,I('L*("`@("`@("`@("`@("`@("`@("`D87)R87E?='EP
M95]P<F5F:7@@/2`D=&AI<RT^7V=E=$YA;65S<&%C95!R969I>"@D87)R87E?
M='EP95]N<RD["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H
M:7,M/E]T>7!E;6%P6R1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO;EU;)&%R<F%Y
M5'EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@)&%R<F%Y7W1Y<&5?<')E
M9FEX(#T@)'1H:7,M/E]N86UE<W!A8V5S6R1T:&ES+3Y?6$U,4V-H96UA5F5R
M<VEO;ET["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H
M)&%R<F%Y7W1Y<&5?<')E9FEX*2!["B`@("`@("`@("`@("`@("`@("`@)&%R
M<F%Y5'EP92`]("1A<G)A>5]T>7!E7W!R969I>"`N("<Z)R`N("1A<G)A>51Y
M<&4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1X;6QO=71?87)R87E4>7!E(#T@)R!33T%0+45.0SIA<G)A>51Y<&4]
M(B<@+B`D87)R87E4>7!E.PH@("`@("`@("`@("!I9B`H)&%R<F%Y7V1E<'1H
M("$](&YU;&PI('L*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\
M("1A<G)A>5]D97!T:#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1X
M;6QO=71?87)R87E4>7!E("X]("=;72<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)'AM;&]U=%]A<G)A>51Y<&4@+CT@
M(ELD87)?<VEZ95U<(B(["B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?:7-3
M;V%P5F%L=64H)'9A;'5E*2D@>PH@("`@("`@("`@("`D>&UL;W5T7W9A;'5E
M(#TF("1V86QU92T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("!](&5L<V5I
M9B`H)'1Y<&4@/3T@)W-T<FEN9R<I('L*("`@("`@("`@("`@)'AM;&]U=%]V
M86QU92`](&AT;6QS<&5C:6%L8VAA<G,H)'9A;'5E*3L*("`@("`@("!](&5L
M<V5I9B`H)'1Y<&4@/3T@)W)A=W-T<FEN9R<I('L*("`@("`@("`@("`@)'AM
M;&]U=%]V86QU92`])B`D=F%L=64["B`@("`@("`@?2!E;'-E:68@*"1T>7!E
M(#T]("=B;V]L96%N)RD@>PH@("`@("`@("`@("`D>&UL;W5T7W9A;'5E(#T@
M)'9A;'5E(#\@)W1R=64G(#H@)V9A;'-E)SL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D>&UL;W5T7W9A;'5E(#TF("1V86QU93L*("`@("`@("!]
M"@H@("`@("`@("\O($%D9"!N86UE<W!A8V5S+@H@("`@("`@(&EF("@D96Q.
M86UE<W!A8V4I('L*("`@("`@("`@("`@)&5L4')E9FEX(#T@)'1H:7,M/E]G
M971.86UE<W!A8V50<F5F:7@H)&5L3F%M97-P86-E*3L*("`@("`@("`@("`@
M:68@*"1E;%!R969I>"D@>PH@("`@("`@("`@("`@("`@)'AM;&]U=%]N86UE
M(#T@(B1E;%!R969I>#HD;F%M92(["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D>&UL;W5T7VYA;64@/2`D;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1X;6QO=71?;F%M
M92`]("1N86UE.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T>7!E3F%M97-P
M86-E*2!["B`@("`@("`@("`@("1T>7!E4')E9FEX(#T@)'1H:7,M/E]G971.
M86UE<W!A8V50<F5F:7@H)'1Y<&5.86UE<W!A8V4I.PH@("`@("`@("`@("!I
M9B`H)'1Y<&50<F5F:7@I('L*("`@("`@("`@("`@("`@("1X;6QO=71?='EP
M92`]("(D='EP95!R969I>#HD='EP92(["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D>&UL;W5T7W1Y<&4@/2`D='EP93L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("@D='EP92`F)@H@("`@("`@("`@
M("`@("`@("!I<W-E="@D=&AI<RT^7W1Y<&5M87!;)'1H:7,M/E]834Q38VAE
M;6%697)S:6]N75LD='EP95TI*2!["B`@("`@("`@("`@("1T>7!E4')E9FEX
M(#T@)'1H:7,M/E]N86UE<W!A8V5S6R1T:&ES+3Y?6$U,4V-H96UA5F5R<VEO
M;ET["B`@("`@("`@("`@(&EF("@D='EP95!R969I>"D@>PH@("`@("`@("`@
M("`@("`@)'AM;&]U=%]T>7!E(#T@(B1T>7!E4')E9FEX.B1T>7!E(CL*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1X;6QO=71?='EP
M92`]("1T>7!E.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!(86YD;&4@861D:71I;VYA;"!A='1R:6)U=&5S+@H@("`@("`@("1X;6Q?
M871T<B`]("<G.PH@("`@("`@(&EF("AC;W5N="@D871T<FEB=71E<RDI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&L@/3X@)'8I
M('L*("`@("`@("`@("`@("`@("1K<6X@/28@;F5W(%%.86UE*"1K*3L*("`@
M("`@("`@("`@("`@("1V<6X@/28@;F5W(%%.86UE*"1V*3L*("`@("`@("`@
M("`@("`@("1X;6Q?871T<B`N/2`G("<@+B`D:W%N+3YF<6XH*2`N("<](B<@
M+B`D=G%N+3YF<6XH*2`N("<B)SL*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+R\@4W1O<F4@=&AE(&%T=&%C:&UE;G0@9F]R(&UI;64@96YC
M;V1I;F<N"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=A='1A8VAM96YT
M)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?7V%T=&%C:&UE;G1S6UT@/2`D
M;W!T:6]N<ULG871T86-H;65N="==.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"1T:&ES+3Y?<V5C=&EO;C4I('L*("`@("`@("`@("`@:68@*"1X;6QO=71?
M='EP92D@>PH@("`@("`@("`@("`@("`@)'AM;&]U=%]T>7!E(#T@(B!X<VDZ
M='EP93U<(B1X;6QO=71?='EP95PB(CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!I9B`H:7-?;G5L;"@D>&UL;W5T7W9A;'5E*2D@>PH@("`@("`@("`@
M("`@("`@)'AM;"`](")<<EQN/"1X;6QO=71?;F%M921X;6QO=71?='EP921X
M;6QN<R1X;6QO=71?87)R87E4>7!E(B`N"B`@("`@("`@("`@("`@("`@("`@
M(B1X;6Q?871T<B!X<VDZ;FEL/5PB=')U95PB+SXB.PH@("`@("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`@("`@)'AM;"`](")<<EQN/"1X;6QO=71?
M;F%M921X;6QO=71?='EP921X;6QN<R1X;6QO=71?87)R87E4>7!E(B`N"B`@
M("`@("`@("`@("`@("`@("`@(B1X;6QO=71?;V9F<V5T)'AM;%]A='1R/B1X
M;6QO=71?=F%L=64\+R1X;6QO=71?;F%M93XB.PH@("`@("`@("`@("!]"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*&ES7VYU;&PH)'AM;&]U
M=%]V86QU92DI('L*("`@("`@("`@("`@("`@("1X;6P@/2`B7')<;CPD>&UL
M;W5T7VYA;64D>&UL;G,D>&UL7V%T='(O/B(["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`D>&UL(#T@(EQR7&X\)'AM;&]U=%]N86UE
M)'AM;&YS)'AM;%]A='1R/B(@+@H@("`@("`@("`@("`@("`@("`@("1X;6QO
M=71?=F%L=64@+B`B/"\D>&UL;W5T7VYA;64^(CL*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1X;6P["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!#;VYV97)T<R!A(%!(4"!T>7!E('1O(&$@4T]!4"!T>7!E+@H@
M("`@("H*("`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!V86QU92!T;R!I;G-P96-T+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!4:&4@=F%L=64G<R!33T%0
M('1Y<&4N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G9714>7!E*"8D=F%L=64I
M"B`@("!["B`@("`@("`@9VQO8F%L("133T%07T]"2D5#5%]35%)50U0L("13
M3T%07U)!5U]#3TY615)4.PH*("`@("`@("`D='EP92`](&=E='1Y<&4H)'9A
M;'5E*3L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@("`@8V%S92`G
M;V)J96-T)SH*("`@("`@("`@("`@:68@*&ES7V$H)'9A;'5E+"`G<V]A<%]V
M86QU92<I*2!["B`@("`@("`@("`@("`@("`D='EP92`]("1V86QU92T^='EP
M93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1T>7!E
M(#T@)U-T<G5C="<["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L[
M"@H@("`@("`@(&-A<V4@)V%R<F%Y)SH*("`@("`@("`@("`@+R\@2&%S:&5S
M(&%R92!A;'=A>7,@:&%N9&QE9"!A<R!S=')U8W1S+@H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]I<TAA<V@H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M)'1Y<&4@/2`G4W1R=6-T)SL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1A<E]S:7IE(#T@8V]U;G0H)'9A;'5E*3L*("`@("`@("`@
M("`@("`@(')E<V5T*"1V86QU92D["B`@("`@("`@("`@("`@("`D:V5Y,2`]
M(&ME>2@D=F%L=64I.PH@("`@("`@("`@("`@("`@:68@*"1A<E]S:7IE(#X@
M,"`F)B!I<U]A*"1K97DQ+"`G4T]!4%]686QU92<I*2!["B`@("`@("`@("`@
M("`@("`@("`@+R\@1DE8344Z(&9O<B!N;VXM=W-D;"!S=')U8W1S('1H870@
M87)E(&%L;"!T:&4@<V%M92!T>7!E"B`@("`@("`@("`@("`@("`@("`@)&ME
M>3(@/2!K97DH)'9A;'5E*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&%R
M7W-I>F4@/B`Q("8F"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?
M:7-3;V%P5F%L=64H)&ME>3$I("8F"B`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?:7-3;V%P5F%L=64H)&ME>3(I("8F"B`@("`@("`@("`@("`@
M("`@("`@("`@("1K97DQ+3YN86UE("$]("1K97DR+3YN86UE*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%1H:7,@:7,@82!S=')U8W0L(&YO="!A
M;B!A<G)A>2X*("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G4W1R
M=6-T)SL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D='EP92`]("=!<G)A>2<["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D='EP92`]("=!<G)A>2<["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["@H@("`@("`@(&-A<V4@
M)VEN=&5G97(G.@H@("`@("`@(&-A<V4@)VQO;F<G.@H@("`@("`@("`@("`D
M='EP92`]("=I;G0G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S
M92`G8F]O;&5A;B<Z"B`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!C87-E
M("=D;W5B;&4G.@H@("`@("`@("`@("`O+R!D;W5B;&4@:7,@9&5P<F5C871E
M9"!I;B!02%`@-"XR(&%N9"!L871E<BX*("`@("`@("`@("`@)'1Y<&4@/2`G
M9FQO870G.PH@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@8V%S92`G;G5L
M;"<Z"B`@("`@("`@("`@("1T>7!E(#T@)R<["B`@("`@("`@("`@(&)R96%K
M.PH*("`@("`@("!C87-E("=S=')I;F<G.@H@("`@("`@("`@("!I9B`H)%-/
M05!?4D%77T-/3E9%4E0I('L*("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1V86QU92DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H<W1R<W1R
M*"1V86QU92P@)RXG*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP
M92`]("=F;&]A="<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G:6YT)SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("A33T%07U1Y<&5?:&5X0FEN87)Y.CII<U]H97AB
M:6XH)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D='EP92`]
M("=H97A":6YA<GDG.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^7VES0F%S938T*"1V
M86QU92DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T>7!E(#T@
M)V)A<V4V-$)I;F%R>2<["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'0@/28@;F5W(%-/
M05!?5'EP95]D871E5&EM92@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"1D="T^=&]5;FEX=&EM92@I("$]("TQ*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1Y<&4@/2`G9&%T951I;64G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!D969A=6QT.@H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H@
M("`@("`@(')E='5R;B`D='EP93L*("`@('T*"B`@("!F=6YC=&EO;B!?;75L
M=&E!<G)A>51Y<&4H)B1V86QU92P@)B1T>7!E+"`F)'-I>F4L("8D>&UL*0H@
M("`@>PH@("`@("`@("1S>B`](&-O=6YT*"1V86QU92D["B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1V86QU92DI('L*("`@("`@("`@("`@+R\@4V5E;7,@=V4@
M:&%V92!A(&UU;'1I(&1I;65N<VEO;F%L(&%R<F%Y+"!F:6=U<F4@:70@;W5T
M(&EF('=E"B`@("`@("`@("`@("\O(&1O+@H@("`@("`@("`@("`D8R`](&-O
M=6YT*"1V86QU92D["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C
M.R`D:2LK*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUU;'1I07)R87E4
M>7!E*"1V86QU95LD:5TL("1T>7!E+"`D<VEZ92P@)'AM;"D["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@(&EF("@D<VEZ92D@>PH@("`@("`@("`@("`@
M("`@)'-I>F4@/2`D<WHN("<L)R`N("1S:7IE.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)'-I>F4@/2`D<WH["B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(')E='5R;B`Q.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(&EF("AI<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@("`@
M("`@("`@)'1Y<&4@/2`D=F%L=64M/G1Y<&4["B`@("`@("`@("`@("`@("`D
M>&UL("X]("1V86QU92T^<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T>7!E(#T@)'1H:7,M/E]G9714
M>7!E*"1V86QU92D["B`@("`@("`@("`@("`@("`D>&UL("X]("1T:&ES+3Y?
M<V5R:6%L:7IE5F%L=64H)'9A;'5E+"`G:71E;2<L("1T>7!E*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("`D<VEZ92`](&YU;&P["@H@("`@
M("`@(')E='5R;B`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!W
M:&5T:&5R(&$@<W1R:6YG(&ES(&)A<V4V-"!E;F-O9&5D(&1A=&$N"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=F%L=64@(%1H92!S=')I;F<@=&\@
M8VAE8VLN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF
M('1H92!S<&5C:69I960@=F%L=64@<V5E;7,@=&\@8F4@8F%S938T(&5N8V]D
M960N"B`@("`@*B\*("`@(&9U;F-T:6]N(%]I<T)A<V4V-"@F)'9A;'5E*0H@
M("`@>PH@("`@("`@("1L(#T@<W1R;&5N*"1V86QU92D["B`@("`@("`@:68@
M*"1L*2!["B`@("`@("`@("`@(')E='5R;B`D=F%L=65;)&P@+2`Q72`]/2`G
M/2<@)B8*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H)R];02U:82UZ/5PO
M7"M=*R\G+"`D=F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('=H971H97(@82!T
M>7!E(&ES(&$@8F%S938T('1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D='EP92`@02!T>7!E(&YA;64N"B`@("`@*@H@("`@("H@0')E='5R
M;B!B;V]L96%N("!4<G5E(&EF('1H92!T>7!E(&YA;64@:7,@82!B87-E-C0@
M='EP92X*("`@("`J+PH@("`@9G5N8W1I;VX@7VES0F%S938T5'EP92@D='EP
M92D*("`@('L*("`@("`@("!R971U<FX@)'1Y<&4@/3T@)V)A<V4V-"<@?'P@
M)'1Y<&4@/3T@)V)A<V4V-$)I;F%R>2<["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!2971U<FYS('=H971H97(@86X@87)R87D@:7,@82!H87-H+@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D82`@06X@87)R87D@=&\@8VAE8VLN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H92!S<&5C
M:69I960@87)R87D@:7,@82!H87-H+@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M:7-(87-H*"8D82D*("`@('L*("`@("`@("`O+R!)(')E86QL>2!D:7-L:6ME
M(&AA=FEN9R!T;R!L;V]P('1H<F]U9V@@=&AI<R!I;B!02%`@8V]D92P@<F5A
M;&QY"B`@("`@("`@+R\@;&%R9V4@87)R87ES('=I;&P@8F4@<VQO=RX@(%=E
M(&YE960@82!#(&9U;F-T:6]N('1O(&1O('1H:7,N"B`@("`@("`@)&YA;65S
M(#T@87)R87DH*3L*("`@("`@("`D:70@/2`P.PH@("`@("`@(&9O<F5A8V@@
M*"1A(&%S("1K(#T^("1V*2!["B`@("`@("`@("`@("\O($-H96-K:6YG('1H
M92!T>7!E(&ES(&9A<W1E<B!T:&%N(')E9V5X<"X*("`@("`@("`@("`@)'0@
M/2!G971T>7!E*"1K*3L*("`@("`@("`@("`@:68@*"1T("$]("=I;G1E9V5R
M)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@
M('T@96QS96EF("@D=&AI<RT^7VES4V]A<%9A;'5E*"1V*2D@>PH@("`@("`@
M("`@("`@("`@)&YA;65S6R1V+3YN86UE72`](#$["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@+R\@268@<V]M96]N92!H87,@82!L87)G92!H87-H('1H
M97D@<VAO=6QD(')E86QL>2!B92!D969I;FEN9R!T:&4*("`@("`@("`@("`@
M+R\@='EP92X*("`@("`@("`@("`@:68@*"1I="LK(#X@,3`I('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!R971U<FX@8V]U;G0H)&YA;65S*3XQ.PH@("`@?0H*("`@
M(&9U;F-T:6]N("9?=6Y?:'1M;&5N=&ET:65S*"1S=')I;F<I"B`@("!["B`@
M("`@("`@)'1R86YS7W1B;"`](&=E=%]H=&UL7W1R86YS;&%T:6]N7W1A8FQE
M*$A434Q?14Y4251)15,I.PH@("`@("`@("1T<F%N<U]T8FP@/2!A<G)A>5]F
M;&EP*"1T<F%N<U]T8FPI.PH@("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG
M+"`D=')A;G-?=&)L*3L*("`@('T*"B`@("!F=6YC=&EO;B`F7V1E8V]D92@F
M)'-O87!V86PI"B`@("!["B`@("`@("`@9VQO8F%L("133T%07T]"2D5#5%]3
M5%)50U0["@H@("`@("`@(&EF("@A)'1H:7,M/E]I<U-O87!686QU92@D<V]A
M<'9A;"DI('L*("`@("`@("`@("`@<F5T=7)N("1S;V%P=F%L.PH@("`@("`@
M('T@96QS96EF("AI<U]A<G)A>2@D<V]A<'9A;"T^=F%L=64I*2!["B`@("`@
M("`@("`@(&EF("@D4T]!4%]/0DI%0U1?4U1254-4("8F("1S;V%P=F%L+3YT
M>7!E("$]("=!<G)A>2<I('L*("`@("`@("`@("`@("`@("1C;&%S<VYA;64@
M/2`D=&AI<RT^7V1E9F%U;'1/8FIE8W1#;&%S<VYA;64["B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/E]T>7!E7W1R86YS;&%T:6]N6R1S;V%P
M=F%L+3YT<6XM/F9Q;B@I72DI('L*("`@("`@("`@("`@("`@("`@("`O+R!4
M:&ES('=I;&P@9F]R8V4@86X@97)R;W(@:6X@4$A0(&EF('1H92!C;&%S<R!D
M;V5S(&YO=`H@("`@("`@("`@("`@("`@("`@("\O(&5X:7-T+@H@("`@("`@
M("`@("`@("`@("`@("1C;&%S<VYA;64@/2`D=&AI<RT^7W1Y<&5?=')A;G-L
M871I;VY;)'-O87!V86PM/G1Q;BT^9G%N*"E=.PH@("`@("`@("`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1T:&ES+3Y?='EP95]T<F%N<VQA=&EO;ELD<V]A
M<'9A;"T^='EP95TI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@5&AI<R!W
M:6QL(&9O<F-E(&%N(&5R<F]R(&EN(%!(4"!I9B!T:&4@8VQA<W,@9&]E<R!N
M;W0*("`@("`@("`@("`@("`@("`@("`O+R!E>&ES="X*("`@("`@("`@("`@
M("`@("`@("`D8VQA<W-N86UE(#T@)'1H:7,M/E]T>7!E7W1R86YS;&%T:6]N
M6R1S;V%P=F%L+3YT>7!E73L*("`@("`@("`@("`@("`@('T@96QS96EF("@D
M=&AI<RT^7V%U=&]?=')A;G-L871I;VXI('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H8VQA<W-?97AI<W1S*"1S;V%P=F%L+3YT>7!E*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)'-O87!V86PM/G1Y<&4[
M"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:&ES+3Y?=W-D;"D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D="`]("1T:&ES+3Y?=W-D;"T^
M9V5T0V]M<&QE>%1Y<&5.86UE1F]R16QE;65N="@D<V]A<'9A;"T^;F%M92P@
M)'-O87!V86PM/FYA;65S<&%C92D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@D="`F)B!C;&%S<U]E>&ES=',H)'0I*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8VQA<W-N86UE(#T@)'0["B`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<F5T=7)N(#TF(&YE=R`D8VQA<W-N
M86UE.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E
M='5R;B`](&%R<F%Y*"D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1C
M;W5N=&5R(#T@,3L*("`@("`@("`@("`@)&ES<W1R=6-T(#T@(2133T%07T]"
M2D5#5%]35%)50U0@?'P@(6ES7V%R<F%Y*"1R971U<FXI.PH@("`@("`@("`@
M("!F;W)E86-H("@D<V]A<'9A;"T^=F%L=64@87,@)&ET96TI('L*("`@("`@
M("`@("`@("`@(&EF("AI<U]O8FIE8W0H)')E='5R;BDI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'1H:7,M/E]W<V1L*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\O($=E="!T:&ES(&-H:6QD)W,@5U-$3"!I;F9O<FUA=&EO
M;BX*("`@("`@("`@("`@("`@("`@("`@("`@+R\@+R1S;V%P=F%L+3YN<R\D
M<V]A<'9A;"T^='EP92\D:71E;2T^;G,O)&ET96TM/FYA;64*("`@("`@("`@
M("`@("`@("`@("`@("`@)&-H:6QD7W1Y<&4@/2`D=&AI<RT^7W=S9&PM/F=E
M=$-O;7!L97A4>7!E0VAI;&14>7!E*`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)'-O87!V86PM/FYA;65S<&%C92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1S;V%P=F%L+3YN86UE+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&ET96TM/FYA;65S<&%C92P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1I=&5M+3YN86UE*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*"1C:&EL9%]T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D:71E;2T^='EP92`]("1C:&EL9%]T>7!E.PH@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@(&EF("@A)&ES<W1R=6-T('Q\("1I=&5M+3YT>7!E(#T]("=!
M<G)A>2<I('L*("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R
M971U<FXM/GLD:71E;2T^;F%M97TI("8F"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I<U]O8FIE8W0H)')E='5R;BT^>R1I=&5M+3YN86UE?2DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD:71E;2T^
M;F%M97T@/28@)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)')E='5R;BT^>R1I=&5M+3YN
M86UE?2D@)B8*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ES
M7V%R<F%Y*"1R971U<FXM/GLD:71E;2T^;F%M97TI*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5T=7)N+3Y[)&ET96TM/FYA;65]6UT@/28@
M)'1H:7,M/E]D96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-?87)R87DH)')E='5R;BDI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1R971U<FY;72`])B`D=&AI<RT^7V1E8V]D92@D
M:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3Y[)&ET96TM/FYA;65]
M(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AI<W-E="@D
M<F5T=7)N+3Y[)&ET96TM/FYA;65]*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`D:7-S=')U8W0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*&-O=6YT*&=E=%]O8FIE8W1?=F%R<R@D<F5T=7)N*2D@/3T@,2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&0@/28@)'1H:7,M/E]D
M96-O9&4H)&ET96TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E
M='5R;B`](&%R<F%Y*"1R971U<FXM/GLD:71E;2T^;F%M97TL("1D*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1D(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1R971U<FXM/GLD:71E;2T^;F%M
M97T@/2!A<G)A>2@D<F5T=7)N+3Y[)&ET96TM/FYA;65]+"`D9"D["B`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<F5T=7)N+3Y[)&ET96TM
M/FYA;65](#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@+R\@4V5T('1H92!A='1R
M:6)U=&5S(&%S(&UE;6)E<G,@:6X@=&AE(&-L87-S+@H@("`@("`@("`@("`@
M("`@("`@(&EF("AM971H;V1?97AI<W1S*"1R971U<FXL("=?7W-E=%]A='1R
M:6)U=&4G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!F;W)E86-H("@D
M<V]A<'9A;"T^871T<FEB=71E<R!A<R`D:V5Y(#T^("1V86QU92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F-?87)R87DH
M87)R87DH)B1R971U<FXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`G7U]S971?871T<FEB=71E)RDL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!A<G)A>2@D:V5Y+"`D=F%L=64I*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1S;V%P=F%L+3YA
M<G)A>51Y<&4@)B8@)'1H:7,M/E]I<U-O87!686QU92@D:71E;2DI('L*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?:7-"87-E-C14>7!E
M*"1I=&5M+3YT>7!E*2`F)@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(21T:&ES+3Y?:7-"87-E-C14>7!E*"1S;V%P=F%L+3YA<G)A>51Y<&4I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$96-O9&4@=&AE('9A
M;'5E(&EF('=E)W)E(&QO<VEN9R!T:&4@8F%S938T"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!T>7!E(&EN9F]R;6%T:6]N+@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&ET96TM/G9A;'5E(#T@8F%S938T7V1E8V]D
M92@D:71E;2T^=F%L=64I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("1I=&5M+3YT>7!E(#T@)'-O87!V86PM
M/F%R<F%Y5'EP93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@:68@*"$D:7-S=')U8W0I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)')E='5R;EM=(#TF("1T:&ES+3Y?9&5C;V1E*"1I=&5M*3L*("`@
M("`@("`@("`@("`@("`@("!](&5L<V5I9B`H:7-S970H)')E='5R;ELD:71E
M;2T^;F%M95TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1I<W-T<G5C
M="`](&9A;'-E.PH@("`@("`@("`@("`@("`@("`@("`@("`D9"`])B`D=&AI
M<RT^7V1E8V]D92@D:71E;2D["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M971U<FX@/2!A<G)A>2@D<F5T=7)N6R1I=&5M+3YN86UE72P@)&0I.PH@("`@
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M("`@("1R971U<FY;)&ET96TM/FYA;65=(#TF("1T:&ES+3Y?9&5C;V1E*"1I
M=&5M*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B`D<F5T=7)N.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1S;V%P=F%L+3YT>7!E(#T]("=B;V]L
M96%N)RD@>PH@("`@("`@("`@("!I9B`H)'-O87!V86PM/G9A;'5E("$]("<P
M)R`F)@H@("`@("`@("`@("`@("`@<W1R8V%S96-M<"@D<V]A<'9A;"T^=F%L
M=64L("=F86QS92<I("$](#`I('L*("`@("`@("`@("`@("`@("1S;V%P=F%L
M+3YV86QU92`]('1R=64["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<V]A<'9A;"T^=F%L=64@/2!F86QS93L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS96EF("@D<V]A<'9A;"T^='EP92`F)@H@("`@("`@
M("`@("`@("`@("!I<W-E="@D=&AI<RT^7W1Y<&5M87!;4T]!4%]834Q?4T-(
M14U!7U9%4E-)3TY=6R1S;V%P=F%L+3YT>7!E72DI('L*("`@("`@("`@("`@
M+R\@268@=V4@8V%N+"!S970@=F%R:6%B;&4@='EP92X*("`@("`@("`@("`@
M<V5T='EP92@D<V]A<'9A;"T^=F%L=64L"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]T>7!E;6%P6U-/05!?6$U,7U-#2$5-05]615)324].75LD<V]A
M<'9A;"T^='EP95TI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3Y?
M:7-"87-E-C14>7!E*"1S;V%P=F%L+3YT>7!E*2D@>PH@("`@("`@("`@("!R
M971U<FX@8F%S938T7V1E8V]D92@D<V]A<'9A;"T^=F%L=64I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<V]A<'9A;"T^=F%L=64[
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0W)E871E<R!T:&4@
M4T]!4"!E;G9E;&]P92!W:71H('1H92!33T%0(&5N=F5L;W`@9&%T82X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J"B`@("`@*B!`<&%R
M86T*("`@("`J($!P87)A;2!A<G)A>2`D:&5A9&5R<PH@("`@("H@0'!A<F%M
M('-T<FEN9R`D96YC;V1I;F<*("`@("`J($!P87)A;2!A<G)A>2`D;W!T:6]N
M<PH@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG"B`@("`@*B\*("`@(&9U
M;F-T:6]N("9?;6%K945N=F5L;W!E*"8D;65T:&]D+"`F)&AE861E<G,L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D96YC;V1I;F<@/2!33T%07T1%
M1D%53%1?14Y#3T1)3D<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M;W!T:6]N<R`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'-M<V<@/2`D:&5A
M9&5R7WAM;"`]("1N<U]S=')I;F<@/2`G)SL*"B`@("`@("`@:68@*"1H96%D
M97)S*2!["B`@("`@("`@("`@("1C(#T@8V]U;G0H)&AE861E<G,I.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8SL@)&DK*RD@>PH@("`@("`@
M("`@("`@("`@)&AE861E<E]X;6P@+CT@)&AE861E<G-;)&E=+3YS97)I86QI
M>F4H)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1H96%D97)?
M>&UL(#T@(CQ33T%0+45.5CI(96%D97(^7')<;B1H96%D97)?>&UL7')<;CPO
M4T]!4"U%3E8Z2&5A9&5R/EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG:6YP=70G72D@?'P@)&]P=&EO;G-;)VEN<'5T
M)UT@/3T@)W!A<G-E)RD@>PH@("`@("`@("`@("!I9B`H:7-?87)R87DH)&UE
M=&AO9"DI('L*("`@("`@("`@("`@("`@("1C(#T@8V]U;G0H)&UE=&AO9"D[
M"B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8SL@)&DK*RD@
M>PH@("`@("`@("`@("`@("`@("`@("1S;7-G("X]("1M971H;V1;)&E=+3YS
M97)I86QI>F4H)'1H:7,I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'-M<V<@/28@)&UE=&AO9"T^
M<V5R:6%L:7IE*"1T:&ES*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1S;7-G(#TF("1M971H;V0["B`@("`@("`@?0H@
M("`@("`@("1B;V1Y(#T@(CQ33T%0+45.5CI";V1Y/EQR7&XB("X@)'-M<V<@
M+B`B7')<;CPO4T]!4"U%3E8Z0F]D>3Y<<EQN(CL*"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]N86UE<W!A8V5S(&%S("1K(#T^("1V*2!["B`@("`@("`@
M("`@("1N<U]S=')I;F<@+CT@(B!X;6QN<SHD=CU<(B1K7")<<EQN(CL*("`@
M("`@("!]"B`@("`@("`@:68@*"1T:&ES+3Y?;F%M97-P86-E*2!["B`@("`@
M("`@("`@("1N<U]S=')I;F<@+CT@(B!X;6QN<SU<(GLD=&AI<RT^7VYA;65S
M<&%C97U<(EQR7&XB.PH@("`@("`@('T*"B`@("`@("`@+RH@268@)W5S92<@
M/3T@)VQI=&5R86PG+"!W92!D;R!N;W0@<'5T(&EN('1H92!E;F-O9&EN9U-T
M>6QE+B`@5&AI<R!I<PH@("`@("`@("`J(&1E;F]T960@8GD@)'1H:7,M/E]S
M96-T:6]N-2!B96EN9R!F86QS92X@("=U<V4G(&-A;B!B92!D969I;F5D(&%T
M(&$*("`@("`@("`@*B!M;W)E(&=R86YU;&%R(&QE=F5L('1H86X@=V4@87)E
M(&1E86QI;F<@=VET:"!H97)E+"!S;R!T:&ES(&1O97,@;F]T"B`@("`@("`@
M("H@=V]R:R!F;W(@86QL('-E<G9I8V5S+B`J+PH@("`@("`@("1X;6P@/2`B
M/#]X;6P@=F5R<VEO;CU<(C$N,%PB(&5N8V]D:6YG/5PB)&5N8V]D:6YG7"(_
M/EQR7&Y<<EQN(BX*("`@("`@("`@("`@(CQ33T%0+45.5CI%;G9E;&]P92`D
M;G-?<W1R:6YG(BX*("`@("`@("`@("`@*"1T:&ES+3Y?<V5C=&EO;C4@/R`G
M(%-/05`M14Y6.F5N8V]D:6YG4W1Y;&4](B<@+B!33T%07U-#2$5-05]%3D-/
M1$E.1R`N("<B)R`Z("<G*2X*("`@("`@("`@("`@(CY<<EQN(BX*("`@("`@
M("`@("`@(B1H96%D97)?>&UL)&)O9'D\+U-/05`M14Y6.D5N=F5L;W!E/EQR
M7&XB.PH*("`@("`@("!R971U<FX@)'AM;#L*("`@('T*"B`@("!F=6YC=&EO
M;B`F7VUA:V5-:6UE365S<V%G92@F)'AM;"P@)&5N8V]D:6YG(#T@4T]!4%]$
M149!54Q47T5.0T]$24Y'*0H@("`@>PH@("`@("`@(&=L;V)A;"`D4T]!4%]O
M<'1I;VYS.PH*("`@("`@("!I9B`H(6ES<V5T*"133T%07V]P=&EO;G-;)TUI
M;64G72DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P
M1F%U;'0H)TUI;64@:7,@;F]T(&EN<W1A;&QE9"<I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@16YC;V1E(&%N>2!A='1A8VAM96YT<RX*("`@("`@("`O+R!3
M964@:'1T<#HO+W=W=RYW,RYO<F<O5%(O4T]!4"UA='1A8VAM96YT<PH@("`@
M("`@("\O($YO=R!W92!H879E('1O(&UI;64@96YC;V1E('1H92!M97-S86=E
M+@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@G8V]N=&5N=%]T>7!E)R`]/B`G
M;75L=&EP87)T+W)E;&%T960[('1Y<&4]=&5X="]X;6PG*3L*("`@("`@("`D
M;7-G(#TF(&YE=R!-86EL7VUI;65087)T*"<G+"`D<&%R86US*3L*"B`@("`@
M("`@+R\@061D('1H92!X;6P@<&%R="X*("`@("`@("`D<&%R86US6R=C;VYT
M96YT7W1Y<&4G72`]("=T97AT+WAM;"<["B`@("`@("`@)'!A<F%M<ULG8VAA
M<G-E="==(#T@)&5N8V]D:6YG.PH@("`@("`@("1P87)A;7-;)V5N8V]D:6YG
M)UT@/2`G8F%S938T)SL*("`@("`@("`D;7-G+3YA9&13=6)087)T*"1X;6PL
M("1P87)A;7,I.PH*("`@("`@("`O+R!!9&0@=&AE(&%T=&%C:&5M96YT<PH@
M("`@("`@("1C(#T@8V]U;G0H)'1H:7,M/E]?871T86-H;65N=',I.PH@("`@
M("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@
M("1A='1A8VAM96YT(#TF("1T:&ES+3Y?7V%T=&%C:&UE;G1S6R1I73L*("`@
M("`@("`@("`@)&US9RT^861D4W5B4&%R="@D871T86-H;65N=%LG8F]D>2==
M+"`D871T86-H;65N="D["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)&US
M9RT^96YC;V1E*"D["B`@("!]"@H@("`@+R\@5$]$3SH@=&AI<R!N965D<R!T
M;R!B92!U<V5D(&9R;VT@=&AE(%1R86YS<&]R="!S>7-T96TN"B`@("!F=6YC
M=&EO;B`F7VUA:V5$24U%365S<V%G92@F)'AM;"D*("`@('L*("`@("`@("!G
M;&]B86P@)%-/05!?;W!T:6]N<SL*"B`@("`@("`@:68@*"%I<W-E="@D4T]!
M4%]O<'1I;VYS6R=$24U%)UTI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7W)A:7-E4V]A<$9A=6QT*"=$24U%(&ES(&YO="!I;G-T86QL960G*3L*
M("`@("`@("!]"@H@("`@("`@("\O($5N8V]D92!A;GD@871T86-H;65N=',N
M"B`@("`@("`@+R\@4V5E(&AT='`Z+R]S96%R8V@N:65T9BYO<F<O:6YT97)N
M970M9')A9G1S+V1R869T+6YI96QS96XM9&EM92US;V%P+3`P+G1X=`H@("`@
M("`@("\O($YO=R!W92!H879E('1O($1)344@96YC;V1E('1H92!M97-S86=E
M"B`@("`@("`@)&1I;64@/28@;F5W($YE=%]$24U%7TUE<W-A9V4H*3L*("`@
M("`@("`D;7-G(#TF("1D:6UE+3YE;F-O9&5$871A*"1X;6PL(%-/05!?14Y6
M14Q/4"P@;G5L;"P@3D547T1)345?5%E015]54DDI.PH*("`@("`@("`O+R!!
M9&0@=&AE(&%T=&%C:&UE;G1S+@H@("`@("`@("1C(#T@8V]U;G0H)'1H:7,M
M/E]?871T86-H;65N=',I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C
M.R`D:2LK*2!["B`@("`@("`@("`@("1A='1A8VAM96YT(#TF("1T:&ES+3Y?
M7V%T=&%C:&UE;G1S6R1I73L*("`@("`@("`@("`@)&US9R`N/2`D9&EM92T^
M96YC;V1E1&%T82@D871T86-H;65N=%LG8F]D>2==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1A='1A8VAM96YT6R=C;VYT96YT
M7W1Y<&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D871T86-H;65N=%LG8VED)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@3D547T1)345?5%E015]-141)02D["B`@("`@("`@
M?0H@("`@("`@("1M<V<@+CT@)&1I;64M/F5N9$UE<W-A9V4H*3L*"B`@("`@
M("`@<F5T=7)N("1M<V<["B`@("!]"@H@("`@9G5N8W1I;VX@7V1E8V]D94UI
M;65-97-S86=E*"8D9&%T82P@)B1H96%D97)S+"`F)&%T=&%C:&UE;G1S*0H@
M("`@>PH@("`@("`@(&=L;V)A;"`D4T]!4%]O<'1I;VYS.PH*("`@("`@("!I
M9B`H(6ES<V5T*"133T%07V]P=&EO;G-;)TUI;64G72DI('L*("`@("`@("`@
M("`@)'1H:7,M/E]R86ES95-O87!&875L="@G36EM92!5;G-U<'!O<G1E9"P@
M:6YS=&%L;"!014%2.CI-86EL.CI-:6UE)RP@)R<L("<G+"`G4V5R=F5R)RD[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1P87)A
M;7-;)VEN8VQU9&5?8F]D:65S)UT@/2!T<G5E.PH@("`@("`@("1P87)A;7-;
M)V1E8V]D95]B;V1I97,G72`@/2!T<G5E.PH@("`@("`@("1P87)A;7-;)V1E
M8V]D95]H96%D97)S)UT@/2!T<G5E.PH*("`@("`@("`O+R!,86UE('1H:6YG
M('1O(&AA=F4@=&\@9&\@9F]R(&1E8V]D:6YG+@H@("`@("`@("1D96-O9&5R
M(#TF(&YE=R!-86EL7VUI;65$96-O9&4H)&1A=&$I.PH@("`@("`@("1S=')U
M8W1U<F4@/2`D9&5C;V1E<BT^9&5C;V1E*"1P87)A;7,I.PH*("`@("`@("!I
M9B`H:7-S970H)'-T<G5C='5R92T^8F]D>2DI('L*("`@("`@("`@("`@)&1A
M=&$@/2`D<W1R=6-T=7)E+3YB;V1Y.PH@("`@("`@("`@("`D:&5A9&5R<R`]
M("1S=')U8W1U<F4M/FAE861E<G,["@H@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1S=')U8W1U<F4M/G!A<G1S*2D@>PH@
M("`@("`@("`@("`D9&%T82`]("1S=')U8W1U<F4M/G!A<G1S6S!=+3YB;V1Y
M.PH@("`@("`@("`@("`D:&5A9&5R<R`](&%R<F%Y7VUE<F=E*"1S=')U8W1U
M<F4M/FAE861E<G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'-T<G5C='5R92T^<&%R='-;,%TM/FAE861E<G,I.PH@("`@("`@("`@
M("!I9B`H8V]U;G0H)'-T<G5C='5R92T^<&%R=',I(#X@,2D@>PH@("`@("`@
M("`@("`@("`@)&UI;65?<&%R=',@/2!A<G)A>5]S<&QI8V4H)'-T<G5C='5R
M92T^<&%R=',L,2D["B`@("`@("`@("`@("`@("`O+R!0<F5P87)E('1H92!P
M87)T<R!F;W(@=&AE(%-/05`@<&%R<V5R+@H*("`@("`@("`@("`@("`@("1C
M(#T@8V]U;G0H)&UI;65?<&%R=',I.PH@("`@("`@("`@("`@("`@9F]R("@D
M:2`](#`[("1I(#P@)&,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D
M<"`])B`D;6EM95]P87)T<ULD:5T["B`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1P+3YH96%D97)S6R=C;VYT96YT+6QO8V%T:6]N)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%1/1$\Z(&UO9&EF>2!L;V-A=&EO
M;B!P97(@4W=!(&YO=&4@<V5C=&EO;B`S"B`@("`@("`@("`@("`@("`@("`@
M("`@("\O(&AT='`Z+R]W=W<N=S,N;W)G+U12+U-/05`M871T86-H;65N=',*
M("`@("`@("`@("`@("`@("`@("`@("`@)&%T=&%C:&UE;G1S6R1P+3YH96%D
M97)S6R=C;VYT96YT+6QO8V%T:6]N)UU=(#T@)'`M/F)O9'D["B`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)&-I9"`]("=C:60Z)R`N('-U8G-T<B@D<"T^:&5A9&5R<ULG8V]N=&5N="UI
M9"==+"`Q+"`M,BD["B`@("`@("`@("`@("`@("`@("`@("`@("1A='1A8VAM
M96YT<ULD8VED72`]("1P+3YB;V1Y.PH@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]R86ES95-O87!&
M875L="@G36EM92!P87)S:6YG(&5R<F]R)RP@)R<L("<G+"`G4V5R=F5R)RD[
M"B`@("!]"@H@("`@9G5N8W1I;VX@7V1E8V]D941)345-97-S86=E*"8D9&%T
M82P@)B1H96%D97)S+"`F)&%T=&%C:&UE;G1S*0H@("`@>PH@("`@("`@(&=L
M;V)A;"`D4T]!4%]O<'1I;VYS.PH*("`@("`@("!I9B`H(6ES<V5T*"133T%0
M7V]P=&EO;G-;)T1)344G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES
M95-O87!&875L="@G1$E-12!5;G-U<'!O<G1E9"P@:6YS=&%L;"!014%2.CI.
M970Z.D1)344G+"`G)RP@)R<L("=397)V97(G*3L*("`@("`@("`@("`@<F5T
M=7)N.PH@("`@("`@('T*"B`@("`@("`@+R\@5&AI<R!32$]53$0@8F4@;6]V
M960@=&\@=&AE('1R86YS<&]R="!L87EE<BP@92YG+B!02%`@:71S96QF('-H
M;W5L9`H@("`@("`@("\O(&AA;F1L92!P87)S:6YG($1)344@.RD*("`@("`@
M("`D9&EM92`])B!N97<@3F5T7T1)345?365S<V%G92@I.PH@("`@("`@("1E
M<G(@/2`D9&EM92T^9&5C;V1E1&%T82@D9&%T82D["B`@("`@("`@:68@*%!%
M05(Z.FES17)R;W(H)&5R<BDI('L*("`@("`@("`@("`@)'1H:7,M/E]R86ES
M95-O87!&875L="@G1F%I;&5D('1O(&1E8V]D92!T:&4@1$E-12!M97-S86=E
M(2<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@("`@(&EF("AS=')C87-E8VUP*"1D:6UE+3YP87)T<ULP
M75LG='EP92==+"!33T%07T5.5D5,3U`I("$](#`I('L*("`@("`@("`@("`@
M)'1H:7,M/E]R86ES95-O87!&875L="@G1$E-12!R96-O<F0@,2!I<R!N;W0@
M82!33T%0(&5N=F5L;W`A)RP@)R<L("<G+"`G4V5R=F5R)RD["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1D871A(#T@)&1I;64M
M/G!A<G1S6S!=6R=D871A)UT["B`@("`@("`@+R\@1F%K92!I="!F;W(@;F]W
M+@H@("`@("`@("1H96%D97)S6R=C;VYT96YT+71Y<&4G72`]("=T97AT+WAM
M;"<["B`@("`@("`@)&,@/2!C;W5N="@D9&EM92T^<&%R=',I.PH@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@("1P
M87)T(#TF("1D:6UE+3YP87)T<ULD:5T["B`@("`@("`@("`@("\O(%=E(&YE
M960@=&\@:&%N9&QE(%5222=S(&)E='1E<BX*("`@("`@("`@("`@)&ED(#T@
M<W1R;F-M<"@D<&%R=%LG:60G72P@)V-I9#HG+"`T*0H@("`@("`@("`@("`@
M("`@/R`G8VED.B<@+B`D<&%R=%LG:60G70H@("`@("`@("`@("`@("`@.B`D
M<&%R=%LG:60G73L*("`@("`@("`@("`@)&%T=&%C:&UE;G1S6R1I9%T@/2`D
M<&%R=%LG9&%T82==.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?
M7W-E=%]T>7!E7W1R86YS;&%T:6]N*"1T>7!E+"`D8VQA<W,@/2!N=6QL*0H@
M("`@>PH@("`@("`@("1T<2`])B!N97<@44YA;64H)'1Y<&4I.PH@("`@("`@
M(&EF("@A)&-L87-S*2!["B`@("`@("`@("`@("1C;&%S<R`]("1T<2T^;F%M
M93L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]T>7!E7W1R86YS;&%T:6]N
M6R1T>7!E73TD8VQA<W,["B`@("!]"@I]"@HO*BH*("H@0VQA<W,@=7-E9"!T
M;R!H86YD;&4@44Y!344@=F%L=65S(&EN(%A-3"X*("H*("H@0&%C8V5S<R`@
M('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T:&]R("`@4VAA;F4@
M0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO;B!T;R!014%2(&%N
M9"!U<&1A=&5S"B`J+PIC;&%S<R!13F%M90I["B`@("!V87(@)&YA;64@/2`G
M)SL*("`@('9A<B`D;G,@/2`G)SL*("`@('9A<B`D;F%M97-P86-E/2<G.PH*
M("`@(&9U;F-T:6]N(%%.86UE*"1N86UE+"`D;F%M97-P86-E(#T@)R<I"B`@
M("!["B`@("`@("`@:68@*"1N86UE("8F("1N86UE6S!=(#T]("=[)RD@>PH@
M("`@("`@("`@("!P<F5G7VUA=&-H*"<O7'LH+BH_*5Q]*"XJ*2\G+"`D;F%M
M92P@)&TI.PH@("`@("`@("`@("`D=&AI<RT^;F%M92`]("1M6S)=.PH@("`@
M("`@("`@("`D=&AI<RT^;F%M97-P86-E(#T@)&U;,5T["B`@("`@("`@?2!E
M;'-E:68@*'-U8G-T<E]C;W5N="@D;F%M92P@)SHG*2`]/2`Q*2!["B`@("`@
M("`@("`@("1S(#T@97AP;&]D92@G.B<L("1N86UE*3L*("`@("`@("`@("`@
M)',@/2!A<G)A>5]R979E<G-E*"1S*3L*("`@("`@("`@("`@)'1H:7,M/FYA
M;64@/2`D<ULP73L*("`@("`@("`@("`@)'1H:7,M/FYS(#T@)'-;,5T["B`@
M("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D;F%M97-P86-E.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YN86UE(#T@)&YA;64[
M"B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A8V4@/2`D;F%M97-P86-E.PH@
M("`@("`@('T*"B`@("`@("`@+R\@02!L:71T;&4@;6]R92!M86=I8R!T:&%N
M('-H;W5L9"!B92!I;B!A('%N86UE+@H@("`@("`@("1P(#T@<W1R<&]S*"1T
M:&ES+3YN86UE+"`G6R<I.PH@("`@("`@(&EF("@D<"D@>PH@("`@("`@("`@
M("`O+R!43T1/.B!.965D('1O(')E+65X86UI;F4@=&AI<R!L;V=I8R!L871E
M<BX*("`@("`@("`@("`@+R\@0VAO<"!O9F8@6UTN"B`@("`@("`@("`@("1T
M:&ES+3YA<G)A>5-I>F4@/2!E>'!L;V1E*"<L)RP@<W5B<W1R*"1T:&ES+3YN
M86UE+"`D<"`K(#$L("TD<"`M(#(I*3L*("`@("`@("`@("`@)'1H:7,M/F%R
M<F%Y26YF;R`]('-U8G-T<B@D=&AI<RT^;F%M92P@)'`I.PH@("`@("`@("`@
M("`D=&AI<RT^;F%M92`]('-U8G-T<B@D=&AI<RT^;F%M92P@,"P@)'`I.PH@
M("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!F<6XH*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^;F%M97-P86-E*2!["B`@("`@("`@("`@(')E='5R
M;B`G>R<@+B`D=&AI<RT^;F%M97-P86-E("X@)WTG("X@)'1H:7,M/FYA;64[
M"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YN<RD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FYS("X@)SHG("X@)'1H:7,M/FYA;64["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D=&AI<RT^;F%M93L*("`@('T*"GT*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]$
M:7-C;RYP:'``````````````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`S-C$T-"`Q,#4Q-30S-#$S,R`P,C$P,#4`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@
M9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE($1)4T-/('-E<G9E<BP@
M<')O=FED:6YG($1)4T\@86YD(%=31$P*("H@<V5R=FEC97,N"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A=`H@*B!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G
M;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*("H@0&%U
M=&AO<B`@("`@1&UI=')I(%9I;F]G<F%D;W8@/&1I;6ET<FE`=FEN;V=R861O
M=BYD93X*("H@0&%U=&AO<B`@("`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H
M;W)D92YO<F<^"B`J($!A=71H;W(@("`@($IA;B!38VAN96ED97(@/&IA;D!H
M;W)D92YO<F<^"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R
M;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O
M;F-E("=33T%0+T)A<V4N<&AP)SL*"F-L87-S(%-/05!?1$E30T]?4V5R=F5R
M(&5X=&5N9',@4T]!4%]"87-E7T]B:F5C="!["@H@("`@=F%R("1N86UE<W!A
M8V5S("`@("`](&%R<F%Y*%-#2$5-05]74T1,(#T^("=W<V1L)RP@4T-(14U!
M7U-/05`@/3X@)W-O87`G*3L*("`@('9A<B`D:6UP;W)T7VYS("`@("`@/2!A
M<G)A>2@I.PH@("`@=F%R("1W<V1L("`@("`@("`@("`]("<G.PH@("`@=F%R
M("1D:7-C;R`@("`@("`@("`]("<G.PH@("`@=F%R("1?=W-D;"`@("`@("`@
M("`](&%R<F%Y*"D["B`@("!V87(@)%]D:7-C;R`@("`@("`@(#T@87)R87DH
M*3L*("`@('9A<B`D7W-E<G9I8V5?;F%M92`@/2`G)SL*("`@('9A<B`D7W-E
M<G9I8V5?;G,@("`@/2`G)SL*("`@('9A<B`D7W-E<G9I8V5?9&5S8R`@/2`G
M)SL*("`@('9A<B`D7W!O<G1N86UE("`@("`@/2`G)SL*("`@('9A<B`D7V)I
M;F1I;F=N86UE("`@/2`G)SL*("`@('9A<B`D<V]A<%]S97)V97(@("`@/2!.
M54Q,.PH*"B`@("!F=6YC=&EO;B!33T%07T1)4T-/7U-E<G9E<B@D<V]A<%]S
M97)V97(L("1S97)V:6-E7VYA;64L("1S97)V:6-E7V1E<V,@/2`G)RP*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I;7!O<G1?;G,@/2!N=6QL
M*0H@("`@>PH@("`@("`@('!A<F5N=#HZ4T]!4%]"87-E7T]B:F5C="@G4V5R
M=F5R)RD["@H@("`@("`@(&EF("@@(6ES7V]B:F5C="@D<V]A<%]S97)V97(I
M"B`@("`@("`@("`@('Q\("%G971?8VQA<W,H)'-O87!?<V5R=F5R*2`]/2`G
M<V]A<%]S97)V97(G*2!R971U<FX["@H@("`@("`@("1T:&ES+3Y?<V5R=FEC
M95]N86UE(#T@)'-E<G9I8V5?;F%M93L*("`@("`@("`D=&AI<RT^7W-E<G9I
M8V5?;G,@/2`B=7)N.B1S97)V:6-E7VYA;64B.PH@("`@("`@("1T:&ES+3Y?
M<V5R=FEC95]D97-C(#T@)'-E<G9I8V5?9&5S8SL*("`@("`@("`D=&AI<RT^
M:6UP;W)T7VYS(#T@:7-S970H)&EM<&]R=%]N<RD@/R`D:6UP;W)T7VYS(#H@
M)'1H:7,M/FEM<&]R=%]N<SL*("`@("`@("`D=&AI<RT^<V]A<%]S97)V97(@
M/2`D<V]A<%]S97)V97(["B`@("`@("`@)'1H:7,M/FAO<W0@/2!I<W-E="@D
M7U-%4E9%4ELG2%144%](3U-4)UTI(#\@)%]315)615);)TA45%!?2$]35"==
M(#H@)VQO8V%L:&]S="<["B`@("!]"@H@("`@9G5N8W1I;VX@9V5T1$E30T\H
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5N97)A=&5?1$E30T\H*3L*("`@
M("`@("!R971U<FX@)'1H:7,M/F1I<V-O.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&=E=%=31$PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9V5N97)A=&5?5U-$
M3"@I.PH@("`@("`@(')E='5R;B`D=&AI<RT^=W-D;#L*("`@('T*"B`@("!F
M=6YC=&EO;B!?9V5N97)A=&5?1$E30T\H*0H@("`@>PH@("`@("`@("\O($1)
M4T-/"B`@("`@("`@)'1H:7,M/E]D:7-C;ULG9&ES8V\Z9&ES8V]V97)Y)UU;
M)V%T='(G75LG>&UL;G,Z9&ES8V\G72`](%-#2$5-05]$25-#3SL*("`@("`@
M("`D=&AI<RT^7V1I<V-O6R=D:7-C;SID:7-C;W9E<GDG75LG871T<B==6R=X
M;6QN<SIS8VPG72`](%-#2$5-05]$25-#3U]30TP["B`@("`@("`@)'1H:7,M
M/E]D:7-C;ULG9&ES8V\Z9&ES8V]V97)Y)UU;)W-C;#IC;VYT<F%C=%)E9B==
M6R=A='1R)UU;)W)E9B==(#T*("`@("`@("`@("`@*&%R<F%Y7VME>5]E>&ES
M=',H)TA45%!3)RP@)%]315)615(I("8F("1?4T525D526R=(5%104R==(#T]
M("=O;B<I"B`@("`@("`@("`@(#\@)VAT='!S.B\O)R`N("1T:&ES+3YH;W-T
M("X@)%]315)615);)U!(4%]314Q&)UT@+B`G/W=S9&PG"B`@("`@("`@("`@
M(#H@)VAT='`Z+R\G("`N("1T:&ES+3YH;W-T("X@)%]315)615);)U!(4%]3
M14Q&)UT@+B`G/W=S9&PG.PH*("`@("`@("`O+R!G96YE<F%T92!D:7-C;R!X
M;6P*("`@("`@("`D=&AI<RT^7V=E;F5R871E7T1)4T-/7UA-3"@D=&AI<RT^
M7V1I<V-O*3L*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N97)A=&5?5U-$3"@I
M"B`@("!["B`@("`@("`@+R\@5U-$3`H@("`@("`@(&EF("AI<U]A<G)A>2@D
M=&AI<RT^<V]A<%]S97)V97(M/E]N86UE<W!A8V5S*2D@>PH@("`@("`@("`@
M("`O+R!N965D('1O(&=E=#H@='EP96YS+"!X<V0@)B!33T%0+45.0PH@("`@
M("`@("`@("`D9FQI<'!E9"`](&%R<F%Y7V9L:7`H)'1H:7,M/G-O87!?<V5R
M=F5R+3Y?;F%M97-P86-E<RD["B`@("`@("`@("`@("1T:&ES+3YN86UE<W!A
M8V5S6R1T:&ES+3Y?<V5R=FEC95]N<UT@/2`G=&YS)SL*("`@("`@("`@("`@
M)'1H:7,M/FYA;65S<&%C97-;)&9L:7!P961;)WAS9"==72`]("=X<V0G.PH@
M("`@("`@("`@("`D=&AI<RT^;F%M97-P86-E<ULD9FQI<'!E9%LG4T]!4"U%
M3D,G75T@/2`G4T]!4"U%3D,G.PH@("`@("`@('T*"B`@("`@("`@+R\@1$5&
M24Y)5$E/3E,*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;
M)V%T='(G75LG;F%M92==(#T@)'1H:7,M/E]S97)V:6-E7VYA;64["B`@("`@
M("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=A='1R)UU;)W1A<F=E
M=$YA;65S<&%C92==(#T@)'1H:7,M/E]S97)V:6-E7VYS.PH@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YN86UE<W!A8V5S(&%S("1N<R`]/B`D<')E9FEX*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T
M<B==6R=X;6QN<SHG("X@)'!R969I>%T@/2`D;G,["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T<B==6R=X;6QN
M<R==(#T@4T-(14U!7U=31$P["@H@("`@("`@("\O($EM<&]R="!N86UE<W!A
M8V5S+B!3965M<R!T;R!N;W0@=V]R:R!Y970Z('=S9&PN97AE(&9O;2`N3D54
M(&-A;B=T"B`@("`@("`@+R\@:&%N9&QE(&EM<&]R=&5D(&-O;7!L971E('=S
M9&PM9&5F:6YI=&EO;G,N"B`@("`@("`@:68@*&-O=6YT*"1T:&ES+3YI;7!O
M<G1?;G,I*2!["B`@("`@("`@("`@("1I(#T@,#L*("`@("`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/FEM<&]R=%]N<R!A<R`D7VYS(#T^("1?;&]C871I;VXI
M('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G
M75LG:6UP;W)T)UU;)&E=6R=A='1R)UU;)VQO8V%T:6]N)UT@/2`D7VQO8V%T
M:6]N.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N
M<R==6R=I;7!O<G0G75LD:5U;)V%T='(G75LG;F%M97-P86-E)UT@/2`D7VYS
M.PH@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S
M)UU;)V%T='(G75LG>&UL;G,G73TG:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO
M<F<O=W-D;"\G.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G
M75LG='EP97,G75LG<V-H96UA)UT]87)R87DH*3L*"B`@("`@("`@+R\@4&QA
M8V5H;VQD97(@9F]R(&UE<W-A9V5S"B`@("`@("`@)'1H:7,M/E]W<V1L6R=D
M969I;FET:6]N<R==6R=M97-S86=E)UT@/2!A<G)A>2@I.PH*("`@("`@("`O
M+R!03U)45%E012U.04U%"B`@("`@("`@)'1H:7,M/E]P;W)T;F%M92`]("1T
M:&ES+3Y?<V5R=FEC95]N86UE("X@)U!O<G0G.PH@("`@("`@("1T:&ES+3Y?
M=W-D;%LG9&5F:6YI=&EO;G,G75LG<&]R=%1Y<&4G75LG871T<B==6R=N86UE
M)UT@/2`D=&AI<RT^7W!O<G1N86UE.PH*("`@("`@("`O+R!"24Y$24Y'+4Y!
M344*("`@("`@("`D=&AI<RT^7V)I;F1I;F=N86UE(#T@)'1H:7,M/E]S97)V
M:6-E7VYA;64@+B`G0FEN9&EN9R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D
M969I;FET:6]N<R==6R=B:6YD:6YG)UU;)V%T='(G75LG;F%M92==(#T@)'1H
M:7,M/E]B:6YD:6YG;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN
M:71I;VYS)UU;)V)I;F1I;F<G75LG871T<B==6R=T>7!E)UT@/2`G=&YS.B<@
M+B`D=&AI<RT^7W!O<G1N86UE.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F
M:6YI=&EO;G,G75LG8FEN9&EN9R==6R=S;V%P.F)I;F1I;F<G75LG871T<B==
M6R=S='EL92==(#T@)W)P8R<["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I
M;FET:6]N<R==6R=B:6YD:6YG)UU;)W-O87`Z8FEN9&EN9R==6R=A='1R)UU;
M)W1R86YS<&]R="==(#T@4T-(14U!7U-/05!?2%144#L*"B`@("`@("`@+R\@
M4T525DE#10H@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG
M<V5R=FEC92==6R=A='1R)UU;)VYA;64G72`]("1T:&ES+3Y?<V5R=FEC95]N
M86UE("X@)U-E<G9I8V4G.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI
M=&EO;G,G75LG<V5R=FEC92==6R=D;V-U;65N=&%T:6]N)UU;)V%T='(G72`]
M("<G.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG<V5R
M=FEC92==6R=D;V-U;65N=&%T:6]N)UT@/2!H=&UL96YT:71I97,H)'1H:7,M
M/E]S97)V:6-E7V1E<V,I.PH@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI
M=&EO;G,G75LG<V5R=FEC92==6R=P;W)T)UU;)V%T='(G75LG;F%M92==(#T@
M)'1H:7,M/E]P;W)T;F%M93L*("`@("`@("`D=&AI<RT^7W=S9&Q;)V1E9FEN
M:71I;VYS)UU;)W-E<G9I8V4G75LG<&]R="==6R=A='1R)UU;)V)I;F1I;F<G
M72`]("=T;G,Z)R`N("1T:&ES+3Y?8FEN9&EN9VYA;64["B`@("`@("`@)'1H
M:7,M/E]W<V1L6R=D969I;FET:6]N<R==6R=S97)V:6-E)UU;)W!O<G0G75LG
M<V]A<#IA9&1R97-S)UU;)V%T='(G75LG;&]C871I;VXG72`]"B`@("`@("`@
M("`@("AA<G)A>5]K97E?97AI<W1S*"=(5%104R<L("1?4T525D52*2`F)B`D
M7U-%4E9%4ELG2%144%,G72`]/2`G;VXG*0H@("`@("`@("`@("`_("=H='1P
M<SHO+R<@+B`D=&AI<RT^:&]S="`N("1?4T525D526R=02%!?4T5,1B=="B`@
M("`@("`@("`@(#H@)VAT='`Z+R\G("`N("1T:&ES+3YH;W-T("X@)%]315)6
M15);)U!(4%]314Q&)UT["@H@("`@("`@("\O"B`@("`@("`@)&1I<W!A=&-H
M7VME>7,@/2!A<G)A>5]K97ES*"1T:&ES+3YS;V%P7W-E<G9E<BT^9&ES<&%T
M8VA?;V)J96-T<RD["B`@("`@("`@)&1C(#T@8V]U;G0H)&1I<W!A=&-H7VME
M>7,I.PH@("`@("`@(&9O<B`H)&1I(#T@,#L@)&1I(#P@)&1C.R`D9&DK*RD@
M>PH@("`@("`@("`@("`D;F%M97-P86-E(#T@)&1I<W!A=&-H7VME>7-;)&1I
M73L*("`@("`@("`@("`@)&YA;65S<&%C95]O8FIE8W1S(#TF("1T:&ES+3YS
M;V%P7W-E<G9E<BT^9&ES<&%T8VA?;V)J96-T<ULD;F%M97-P86-E73L*("`@
M("`@("`@("`@)&]C(#T@8V]U;G0H)&YA;65S<&%C95]O8FIE8W1S*3L*("`@
M("`@("`@("`@9F]R("@D;VD@/2`P.R`D;VD@/"`D;V,[("1O:2LK*2!["B`@
M("`@("`@("`@("`@("`D;V)J96-T(#T@)&YA;65S<&%C95]O8FIE8W1S6R1O
M:5T["B`@("`@("`@("`@("`@("`O+R!T>7!E<R!D969I;FET:6]N<PH@("`@
M("`@("`@("`@("`@)'1H:7,M/F%D9%-C:&5M849R;VU-87`H)&]B:F5C="T^
M7U]T>7!E9&5F*3L*("`@("`@("`@("`@("`@("\O($U%4U-!1T53"B`@("`@
M("`@("`@("`@("`D=&AI<RT^861D365T:&]D<T9R;VU-87`H)&]B:F5C="T^
M7U]D:7-P871C:%]M87`L("1N86UE<W!A8V4L(&=E=%]C;&%S<R@D;V)J96-T
M*2D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T
M*"1S97)V97(M/F1I<W!A=&-H7VUA<"DI('L*("`@("`@("`@("`@)'1H:7,M
M/F%D9$UE=&AO9'-&<F]M36%P*"1S97)V97(M/F1I<W!A=&-H7VUA<"P@)&YA
M;65S<&%C92D["B`@("`@("`@?0H*("`@("`@("`O+R!G96YE<F%T92!W<V1L
M"B`@("`@("`@)'1H:7,M/E]G96YE<F%T95]74T1,7UA-3"@I.PH@("`@?0H*
M("`@(&9U;F-T:6]N("9?9V5T4V-H96UA*"1N86UE<W!A8V4I"B`@("!["B`@
M("`@("`@+R\@4T-(14U!"B`@("`@("`@)&,@/2!C;W5N="@D=&AI<RT^7W=S
M9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C:&5M82==*3L*("`@("`@
M("!F;W(H)&D@/2`P.R`D:2`\("1C.R`D:2LK*2!["B`@("`@("`@("`@(&EF
M("@D=&AI<RT^7W=S9&Q;)V1E9FEN:71I;VYS)UU;)W1Y<&5S)UU;)W-C:&5M
M82==6R1I75LG871T<B==6R=T87)G971.86UE<W!A8V4G72`]/2`D;F%M97-P
M86-E*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/E]W<V1L6R=D
M969I;FET:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G75LD:5T["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&1O;B=T(&AA=F4@=&AI<R!N
M86UE<W!A8V4*("`@("`@("`D<V-H96UA(#T@87)R87DH*3L*("`@("`@("`D
M<V-H96UA6R=A='1R)UT@/2!A<G)A>2@I.PH@("`@("`@("1S8VAE;6%;)V-O
M;7!L97A4>7!E)UT@/2!A<G)A>2@I.PH@("`@("`@("1S8VAE;6%;)V%T='(G
M75LG>&UL;G,G72`](&%R<F%Y7W-E87)C:"@G>'-D)RPD=&AI<RT^;F%M97-P
M86-E<RD["B`@("`@("`@)'-C:&5M85LG871T<B==6R=T87)G971.86UE<W!A
M8V4G72`]("1N86UE<W!A8V4["B`@("`@("`@)'1H:7,M/E]W<V1L6R=D969I
M;FET:6]N<R==6R=T>7!E<R==6R=S8VAE;6$G75M=(#TF("1S8VAE;6$["@H@
M("`@("`@(')E='5R;B`D<V-H96UA.PH@("`@?0H*("`@(&9U;F-T:6]N(&%D
M9%-C:&5M849R;VU-87`H)B1M87`I"B`@("!["B`@("`@("`@:68@*"$D;6%P
M*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@(&9O
M<F5A8V@@*"1M87`@87,@)%]T>7!E7VYA;64@/3X@)%]T>7!E7V1E9BD@>PH@
M("`@("`@("`@("!L:7-T*"1T>7!E;G,L)'1Y<&4I(#T@)'1H:7,M/E]G9714
M>7!E3G,H)%]T>7!E7VYA;64I.PH@("`@("`@("`@("!I9B`H)'1Y<&5N<R`]
M/2`G>'-D)RD@>PH@("`@("`@("`@("`@("`@+R\@8V%N;F]T(&%D9"!T;R!X
M<V0L(&QE=',@=7-E(&UE=&AO9%]N86UE<W!A8V4*("`@("`@("`@("`@("`@
M("1T>7!E;G,@/2`G=&YS)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<V-H96UA(#TF("1T:&ES+3Y?9V5T4V-H96UA*&%R<F%Y7W-E87)C:"@D='EP
M96YS+"`D=&AI<RT^;F%M97-P86-E<RDI.PH@("`@("`@("`@("!I9B`H(21T
M:&ES+3Y?:69#;VUP;&5X5'EP945X:7-T<R@D<V-H96UA6R=C;VUP;&5X5'EP
M92==+"`D='EP92DI('L*("`@("`@("`@("`@("`@("1C='EP92`])B`D<V-H
M96UA6R=C;VUP;&5X5'EP92==6UT["B`@("`@("`@("`@("`@("`D8W1Y<&5;
M)V%T='(G75LG;F%M92==(#T@)'1Y<&4["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D7W1Y<&5?9&5F(&%S("1?=F%R;F%M92`]/B`D7W9A<G1Y<&4I('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES7VEN="@D7W9A<FYA;64I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H)%]V87)T>7!E;G,L)%]V
M87)T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1?=F%R='EP92D["B`@("`@
M("`@("`@("`@("`@("`@("`@("1C='EP95LG86QL)UU;)V%T='(G72`]("<G
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D96P@/28@)&-T>7!E6R=A;&PG
M75LG96QE;65N="==6UT["B`@("`@("`@("`@("`@("`@("`@("`@("1E;%LG
M871T<B==6R=N86UE)UT@/2`D7W9A<FYA;64["B`@("`@("`@("`@("`@("`@
M("`@("`@("1E;%LG871T<B==6R=T>7!E)UT@/2`D7W9A<G1Y<&5N<R`N("<Z
M)R`N("1?=F%R='EP93L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8W1Y<&5;)V-O;7!L97A#;VYT96YT
M)UU;)V%T='(G72`]("<G.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1Y
M<&5;)V-O;7!L97A#;VYT96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T='(G75LG
M8F%S92==(#T@)U-/05`M14Y#.D%R<F%Y)SL*("`@("`@("`@("`@("`@("`@
M("`@("`@9F]R96%C:"`H)%]V87)T>7!E(&%S("1A<G)A>5]V87(@/3X@)&%R
M<F%Y7W1Y<&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0H
M)%]V87)T>7!E;G,L("1?=F%R='EP92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D
M87)R87E?='EP92D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8W1Y
M<&5;)V-O;7!L97A#;VYT96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T=')I8G5T
M92==6R=A='1R)UU;)W)E9B==(#T@)U-/05`M14Y#.F%R<F%Y5'EP92<["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D8W1Y<&5;)V-O;7!L97A#;VYT
M96YT)UU;)W)E<W1R:6-T:6]N)UU;)V%T=')I8G5T92==6R=A='1R)UU;)W=S
M9&PZ87)R87E4>7!E)UT@/2`D7W9A<G1Y<&5N<R`N("<Z)R`N("1?=F%R='EP
M92`N("=;72<["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@9G5N8W1I;VX@861D365T:&]D<T9R;VU-
M87`H)B1M87`L("1N86UE<W!A8V4L("1C;&%S<VYA;64@/2!N=6QL*0H@("`@
M>PH@("`@("`@(&EF("@A)&UA<"D@>PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H*("`@("`@("!F;W)E86-H("@D;6%P(&%S("1M971H;V1?;F%M
M92`]/B`D;65T:&]D7W1Y<&5S*2!["B`@("`@("`@("`@(&EF("AA<G)A>5]K
M97E?97AI<W1S*"=N86UE<W!A8V4G+"`D;65T:&]D7W1Y<&5S*2D@>PH@("`@
M("`@("`@("`@("`@)&UE=&AO9%]N86UE<W!A8V4@/2`D;65T:&]D7W1Y<&5S
M6R=N86UE<W!A8V4G73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1M971H;V1?;F%M97-P86-E(#T@)&YA;65S<&%C93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("`O+R!)3E!55`H@("`@("`@("`@("!I9B`H
M:7-S970H)&UE=&AO9%]T>7!E<ULG:6XG72D@)B8@:7-?87)R87DH)&UE=&AO
M9%]T>7!E<ULG:6XG72DI('L*("`@("`@("`@("`@("`@("1I;G!U=%]M97-S
M86=E(#TF("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG;65S<V%G92==
M6UT["B`@("`@("`@("`@("`@("`D:6YP=71?;65S<V%G95LG871T<B==6R=N
M86UE)UT@/2`D;65T:&]D7VYA;64@+B`G4F5Q=65S="<["B`@("`@("`@("`@
M("`@("!F;W)E86-H("@D;65T:&]D7W1Y<&5S6R=I;B==(&%S("1N86UE(#T^
M("1T>7!E*2!["B`@("`@("`@("`@("`@("`@("`@;&ES="@D='EP96YS+"`D
M='EP92D@/2`D=&AI<RT^7V=E=%1Y<&5.<R@D='EP92D["B`@("`@("`@("`@
M("`@("`@("`@)'!A<G0@/28@)&EN<'5T7VUE<W-A9V5;)W!A<G0G75M=.PH@
M("`@("`@("`@("`@("`@("`@("1P87)T6R=A='1R)UU;)VYA;64G72`]("1N
M86UE.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A='1R)UU;)W1Y<&4G
M72`]("1T>7!E;G,@+B`G.B<@+B`D='EP93L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@3U544%54"B`@("`@("`@
M("`@(&EF("AI<W-E="@D;65T:&]D7W1Y<&5S6R=O=70G72D@)B8@:7-?87)R
M87DH)&UE=&AO9%]T>7!E<ULG;W5T)UTI*2!["B`@("`@("`@("`@("`@("`D
M;W5T<'5T7VUE<W-A9V4@/28@)'1H:7,M/E]W<V1L6R=D969I;FET:6]N<R==
M6R=M97-S86=E)UU;73L*("`@("`@("`@("`@("`@("1O=71P=71?;65S<V%G
M95LG871T<B==6R=N86UE)UT@/2`D;65T:&]D7VYA;64@+B`G4F5S<&]N<V4G
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&UE=&AO9%]T>7!E<ULG;W5T
M)UT@87,@)&YA;64@/3X@)'1Y<&4I('L*("`@("`@("`@("`@("`@("`@("!L
M:7-T*"1T>7!E;G,L("1T>7!E*2`]("1T:&ES+3Y?9V5T5'EP94YS*"1T>7!E
M*3L*("`@("`@("`@("`@("`@("`@("`D<&%R="`])B`D;W5T<'5T7VUE<W-A
M9V5;)W!A<G0G75M=.PH@("`@("`@("`@("`@("`@("`@("1P87)T6R=A='1R
M)UU;)VYA;64G72`]("1N86UE.PH@("`@("`@("`@("`@("`@("`@("1P87)T
M6R=A='1R)UU;)W1Y<&4G72`]("1T>7!E;G,@+B`G.B<@+B`D='EP93L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@
M4$]25%194$53"B`@("`@("`@("`@("1O<&5R871I;VX@/28@)'1H:7,M/E]W
M<V1L6R=D969I;FET:6]N<R==6R=P;W)T5'EP92==6R=O<&5R871I;VXG75M=
M.PH@("`@("`@("`@("`D;W!E<F%T:6]N6R=A='1R)UU;)VYA;64G72`]("1M
M971H;V1?;F%M93L*"B`@("`@("`@("`@("\O($E.4%54"B`@("`@("`@("`@
M("1O<&5R871I;VY;)VEN<'5T)UU;)V%T='(G75LG;65S<V%G92==(#T@)W1N
M<SHG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1I;G!U=%]M97-S
M86=E6R=A='1R)UU;)VYA;64G73L*"B`@("`@("`@("`@("\O($]55%!55`H@
M("`@("`@("`@("`D;W!E<F%T:6]N6R=O=71P=70G75LG871T<B==6R=M97-S
M86=E)UT@/2`G=&YS.B<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@
M)&]U='!U=%]M97-S86=E6R=A='1R)UU;)VYA;64G73L*"B`@("`@("`@("`@
M("\O($))3D1)3D<*("`@("`@("`@("`@)&)I;F1I;F<@/28@)'1H:7,M/E]W
M<V1L6R=D969I;FET:6]N<R==6R=B:6YD:6YG)UU;)V]P97)A=&EO;B==6UT[
M"B`@("`@("`@("`@("1B:6YD:6YG6R=A='1R)UU;)VYA;64G72`]("1M971H
M;V1?;F%M93L*("`@("`@("`@("`@)&%C=&EO;B`]("1M971H;V1?;F%M97-P
M86-E("X@)R,G("X@*"1C;&%S<VYA;64@/R`D8VQA<W-N86UE("X@)R,G(#H@
M)R<I("X@)&UE=&AO9%]N86UE.PH@("`@("`@("`@("`D8FEN9&EN9ULG<V]A
M<#IO<&5R871I;VXG75LG871T<B==6R=S;V%P06-T:6]N)UT@/2`D86-T:6]N
M.PH*("`@("`@("`@("`@+R\@24Y0550*("`@("`@("`@("`@)&)I;F1I;F=;
M)VEN<'5T)UU;)V%T='(G72`]("<G.PH@("`@("`@("`@("`D8FEN9&EN9ULG
M:6YP=70G75LG<V]A<#IB;V1Y)UU;)V%T='(G75LG=7-E)UT@/2`G96YC;V1E
M9"<["B`@("`@("`@("`@("1B:6YD:6YG6R=I;G!U="==6R=S;V%P.F)O9'DG
M75LG871T<B==6R=N86UE<W!A8V4G72`]("1M971H;V1?;F%M97-P86-E.PH@
M("`@("`@("`@("`D8FEN9&EN9ULG:6YP=70G75LG<V]A<#IB;V1Y)UU;)V%T
M='(G75LG96YC;V1I;F=3='EL92==(#T@4T]!4%]30TA%34%?14Y#3T1)3D<[
M"@H@("`@("`@("`@("`O+R!/5510550*("`@("`@("`@("`@)&)I;F1I;F=;
M)V]U='!U="==6R=A='1R)UT@/2`G)SL*("`@("`@("`@("`@)&)I;F1I;F=;
M)V]U='!U="==6R=S;V%P.F)O9'DG75LG871T<B==6R=U<V4G72`]("=E;F-O
M9&5D)SL*("`@("`@("`@("`@)&)I;F1I;F=;)V]U='!U="==6R=S;V%P.F)O
M9'DG75LG871T<B==6R=N86UE<W!A8V4G72`]("1M971H;V1?;F%M97-P86-E
M.PH@("`@("`@("`@("`D8FEN9&EN9ULG;W5T<'5T)UU;)W-O87`Z8F]D>2==
M6R=A='1R)UU;)V5N8V]D:6YG4W1Y;&4G72`](%-/05!?4T-(14U!7T5.0T]$
M24Y'.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!?9V5N97)A=&5?
M1$E30T]?6$U,*"1D:7-C;U]A<G)A>2D*("`@('L*("`@("`@("`D9&ES8V\@
M/2`G/#]X;6P@=F5R<VEO;CTB,2XP(C\^)SL*("`@("`@("!F;W)E86-H("@D
M9&ES8V]?87)R87D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("1D
M:7-C;R`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1K97DL)'9A;"D["B`@("`@
M("`@?0H@("`@("`@("1T:&ES+3YD:7-C;R`]("1D:7-C;SL*("`@('T*"B`@
M("!F=6YC=&EO;B!?9V5N97)A=&5?5U-$3%]834PH*0H@("`@>PH@("`@("`@
M("1W<V1L(#T@)SP_>&UL('9E<G-I;VX](C$N,"(_/B<["B`@("`@("`@9F]R
M96%C:"`H)'1H:7,M/E]W<V1L(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@
M("`@("`D=W-D;"`N/2`D=&AI<RT^7V%R<F%Y5&].;V1E*"1K97DL("1V86PI
M.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^=W-D;"`]("1W<V1L.PH@("`@
M?0H*("`@(&9U;F-T:6]N(%]A<G)A>51O3F]D92@D;F]D95]N86UE(#T@)R<L
M("1A<G)A>2D*("`@('L*("`@("`@("`D<F5T=7)N(#T@)R<["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1A<G)A>2DI('L*("`@("`@("`@("`@+R\@=V4@:&%V
M92!A(&YO9&4@:68@=&AE<F4G<R!K97D@)V%T='(G"B`@("`@("`@("`@(&EF
M("AA<G)A>5]K97E?97AI<W1S*"=A='1R)RPD87)R87DI*2!["B`@("`@("`@
M("`@("`@("`D<F5T=7)N("X]("(\)&YO9&5?;F%M92(["B`@("`@("`@("`@
M("`@("!I9B`H:7-?87)R87DH)&%R<F%Y6R=A='1R)UTI*2!["B`@("`@("`@
M("`@("`@("`@("`@9F]R96%C:"`H)&%R<F%Y6R=A='1R)UT@87,@)&%T=')?
M;F%M92`]/B`D871T<E]V86QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5T=7)N("X]("(@)&%T=')?;F%M93U<(B1A='1R7W9A;'5E7"(B.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`O+R!U;G-E="`G871T<B<@86YD('!R;V-E960@;W1H97(@
M8VAI;&1S+BXN"B`@("`@("`@("`@("`@("!U;G-E="@D87)R87E;)V%T='(G
M72D["@H@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1A<G)A>2D@/B`P*2![
M"B`@("`@("`@("`@("`@("`@("`@)&D@/2`P.PH@("`@("`@("`@("`@("`@
M("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D8VAI;&1?;F]D95]N86UE(#T^("1C
M:&EL9%]N;V1E7W9A;'5E*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R
M971U<FX@+CT@)&D@/3T@,"`_("(^7&XB(#H@)R<["B`@("`@("`@("`@("`@
M("`@("`@("`@("1R971U<FX@+CT@)'1H:7,M/E]A<G)A>51O3F]D92@D8VAI
M;&1?;F]D95]N86UE+"1C:&EL9%]N;V1E7W9A;'5E*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@)')E='5R;B`N/2`B/"\D;F]D95]N86UE/EQN(CL*
M("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@
M)')E='5R;B`N/2`B("\^7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@+R\@=V4@:&%V92!N;R`G
M871T<B<@:V5Y(&EN(&%R<F%Y("T@<V\@:70G<R!L:7-T(&]F(&YO9&5S('=I
M=&@*("`@("`@("`@("`@("`@("\O('1H92!S86UE(&YA;64@+BXN"B`@("`@
M("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&-H:6QD7VYO9&5?;F%M
M92`]/B`D8VAI;&1?;F]D95]V86QU92D@>PH@("`@("`@("`@("`@("`@("`@
M("1R971U<FX@+CT@)'1H:7,M/E]A<G)A>51O3F]D92@D;F]D95]N86UE+"1C
M:&EL9%]N;V1E7W9A;'5E*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O("1A<G)A>2!I
M<R!N;W0@86X@87)R87D*("`@("`@("`@("`@:68@*"1A<G)A>2`A/2<G*2![
M"B`@("`@("`@("`@("`@("`O+R!A;F0@:71S(&YO="!E;7!T>0H@("`@("`@
M("`@("`@("`@)')E='5R;B`N/2`B/"1N;V1E7VYA;64^)&%R<F%Y/"\D;F]D
M95]N86UE/EQN(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("\O(&%N9"!I=',@96UP='DN+BX*("`@("`@("`@("`@("`@("1R971U
M<FX@+CT@(CPD;F]D95]N86UE("\^7&XB.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<F5T=7)N.PH@("`@?0H*("`@(&9U;F-T
M:6]N(%]G9714>7!E3G,H)'1Y<&4I"B`@("!["B`@("`@("`@<')E9U]M871C
M:%]A;&PH(B=<>R@N*BE<?2=S;2(L("1T>7!E+"`D;2D["B`@("`@("`@:68@
M*&ES<V5T*"1M6S%=6S!=*2`F)B`D;5LQ75LP72`A/2`G)RD@>PH@("`@("`@
M("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES=',H)&U;,5U;,%TL)'1H:7,M/FYA
M;65S<&%C97,I*2!["B`@("`@("`@("`@("`@("`D;G-?<')E9B`]("=N<R<@
M+B!C;W5N="@D=&AI<RT^;F%M97-P86-E<RD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;F%M97-P86-E<ULD;5LQ75LP75T@/2`D;G-?<')E9CL*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?=W-D;%LG9&5F:6YI=&EO;G,G75LG871T<B==
M6R=X;6QN<SHG("X@)&YS7W!R969=(#T@)&U;,5U;,%T["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1Y<&5N<R`]("1T:&ES+3YN86UE<W!A8V5S6R1M
M6S%=6S!=73L*("`@("`@("`@("`@)'1Y<&4@/2!E<F5G7W)E<&QA8V4H)&U;
M,%U;,%TL)R<L)'1Y<&4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T>7!E;G,@/2`G>'-D)SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1T>7!E;G,L)'1Y<&4I.PH@("`@?0H*("`@(&9U;F-T:6]N(%]I9D-O
M;7!L97A4>7!E17AI<W1S*"1T>7!E<T%R<F%Y+"`D='EP95]N86UE*0H@("`@
M>PH@("`@("`@(&EF("AI<U]A<G)A>2@D='EP97-!<G)A>2DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)'1Y<&5S07)R87D@87,@)&EN9&5X(#T^("1T>7!E
M7V1A=&$I('L*("`@("`@("`@("`@("`@(&EF("@D='EP97-!<G)A>5LD:6YD
M97A=6R=A='1R)UU;)VYA;64G72`]/2`D='EP95]N86UE*2!["B`@("`@("`@
M("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@?0I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/
M05`O1F%U;'0N<&AP````````````````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,3`P-3(@,3`U,34T,S0Q,S,@,#(Q,#`U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&ES(&9I;&4@8V]N=&%I;G,@=&AE(%-/05!?1F%U;'0@8VQA<W,L('5S960@
M9F]R(&%L;"!E<G)O<B!O8FIE8W1S(&EN('1H:7,*("H@<&%C:V%G92X*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@
M4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C
M:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T
M"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`
M8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@
M*B!`875T:&]R("`@("!$:65T<FEC:"!!>6%L82`\9&EE=')I8VA`9V%N>#0N
M8V]M/B!/<FEG:6YA;"!!=71H;W(*("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R
M879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M
M;W)E"B`J($!A=71H;W(@("`@($-H=6-K($AA9V5N8G5C:"`\8VAU8VM`:&]R
M9&4N;W)G/B`@($UA:6YT96YA;F-E"B`J($!A=71H;W(@("`@($IA;B!38VAN
M96ED97(@/&IA;D!H;W)D92YO<F<^("`@("`@($UA:6YT96YA;F-E"B`J($!C
M;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT("!02%`@
M3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I
M.PH*+RHJ"B`J(%-/05!?1F%U;'0*("H@4$5!4CHZ17)R;W(@=W)A<'!E<B!U
M<V5D('1O(&UA=&-H(%-/05`@1F%U;'1S('1O(%!%05(@17)R;W)S"B`J"B`J
M($!P86-K86=E("!33T%0"B`J($!A8V-E<W,@("!P=6)L:6,*("H@0&%U=&AO
M<B`@(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@
M=&\@4$5!4B!A;F0@;6]R90H@*B!`875T:&]R("`@1&EE=')I8V@@07EA;&$@
M/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J+PIC;&%S
M<R!33T%07T9A=6QT(&5X=&5N9',@4$5!4E]%<G)O<@I["B`@("`*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J(`H@("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@;65S<V%G92!S=')I;F<@9F]R(&9A=6QT"B`@("`@*B!`<&%R
M86T@("`@;6EX960@("!T:&4@9F%U;'1C;V1E"B`@("`@*B!`<&%R86T@("`@
M;6EX960@("!S964@4$5!4CHZ15)23U(@"B`@("`@*B!`<&%R86T@("`@;6EX
M960@("!S964@4$5!4CHZ15)23U(@"B`@("`@*B!`<&%R86T@("`@87)R87D@
M("!T:&4@=7-E<FEN9F\@87)R87D@:7,@=7-E9"!T;R!P87-S(&EN('1H90H@
M("`@("H@("`@("`@("`@("`@("`@("`@4T]!4"!A8W1O<B!A;F0@9&5T86EL
M(&9O<B!T:&4@9F%U;'0*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!4%]&875L
M="@D9F%U;'1S=')I;F<@/2`G=6YK;F]W;B!E<G)O<B<L("1F875L=&-O9&4@
M/2`G0VQI96YT)RP@)&9A=6QT86-T;W(]3E5,3"P@)&1E=&%I;#U.54Q,+"`D
M;6]D92`](&YU;&PL("1O<'1I;VYS(#T@;G5L;"D*("`@('L*("`@("`@("!P
M87)E;G0Z.E!%05)?17)R;W(H)&9A=6QT<W1R:6YG+"`D9F%U;'1C;V1E+"`D
M;6]D92P@)&]P=&EO;G,L("1D971A:6PI.PH@("`@("`@(&EF("@D9F%U;'1A
M8W1O<BD@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX(#T@)&9A=6QT86-T
M;W(["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@;65S<V%G90H@("`@("H*
M("`@("`J(')E='5R;G,@82!33T%07TUE<W-A9V4@8VQA<W,@=&AA="!C86X@
M8F4@<V5N="!A<R!A('-E<G9E<B!R97-P;VYS90H@("`@("H*("`@("`J($!R
M971U<FX@4T]!4%]-97-S86=E(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@;65S<V%G92@I"B`@("!["B`@("`@("`@)&US
M9R`])B!N97<@4T]!4%]"87-E*"D["B`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*"D["B`@("`@("`@)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=F875L
M=&-O9&4G+"`G44YA;64G+"`G4T]!4"U%3E8Z)RXD=&AI<RT^8V]D92D["B`@
M("`@("`@)'!A<F%M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=F875L='-T<FEN
M9R<L("=S=')I;F<G+"`D=&AI<RT^;65S<V%G92D["B`@("`@("`@)'!A<F%M
M<UM=(#TF(&YE=R!33T%07U9A;'5E*"=F875L=&%C=&]R)RP@)V%N>55222<L
M("1T:&ES+3YE<G)O<E]M97-S86=E7W!R969I>"D["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YB86-K=')A8V4I*2!["B`@("`@("`@("`@("1P87)A;7-;
M72`])B!N97<@4T]!4%]686QU92@G9&5T86EL)RP@)W-T<FEN9R<L("1T:&ES
M+3YB86-K=')A8V4I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P
M87)A;7-;72`])B!N97<@4T]!4%]686QU92@G9&5T86EL)RP@)W-T<FEN9R<L
M("1T:&ES+3YU<V5R:6YF;RD["B`@("`@("`@?0H@("`@("`@(`H@("`@("`@
M("1M971H;V1686QU92`])B!N97<@4T]!4%]686QU92@G>R<N4T]!4%]%3E9%
M3$]0+B=]1F%U;'0G+"`G4W1R=6-T)RP@)'!A<F%M<RD["B`@("`@("`@)&AE
M861E<G,@/2!.54Q,.PH@("`@("`@(')E='5R;B`D;7-G+3Y?;6%K945N=F5L
M;W!E*"1M971H;V1686QU92P@)&AE861E<G,I.PH@("`@?0H@("`@"B`@("`O
M*BH*("`@("`J(&=E=$9A=6QT"B`@("`@*@H@("`@("H@<F5T=7)N<R!A('-I
M;7!L92!N871I=F4@<&AP(&%R<F%Y(&-O;G1A:6YI;F<@=&AE(&9A=6QT(&1A
M=&$*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y(`H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T1F%U;'0H*0H@("`@
M>PH@("`@("`@(&=L;V)A;"`D4T]!4%]/0DI%0U1?4U1254-4.PH@("`@("`@
M(&EF("@D4T]!4%]/0DI%0U1?4U1254-4*2!["B`@("`@("`@("`@("1F875L
M="`])B!N97<@<W1D0VQA<W,H*3L*("`@("`@("`@("`@)&9A=6QT+3YF875L
M=&-O9&4@/2`D=&AI<RT^8V]D93L*("`@("`@("`@("`@)&9A=6QT+3YF875L
M='-T<FEN9R`]("1T:&ES+3YM97-S86=E.PH@("`@("`@("`@("`D9F%U;'0M
M/F9A=6QT86-T;W(@/2`D=&AI<RT^97)R;W)?;65S<V%G95]P<F5F:7@["B`@
M("`@("`@("`@("1F875L="T^9&5T86EL(#T@)'1H:7,M/G5S97)I;F9O.PH@
M("`@("`@("`@("!R971U<FX@)&9A=6QT.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@87)R87DH"B`@("`@("`@("`@("`@("`G9F%U;'1C;V1E)R`]/B`D
M=&AI<RT^8V]D92P*("`@("`@("`@("`@("`@("=F875L='-T<FEN9R<@/3X@
M)'1H:7,M/FUE<W-A9V4L"B`@("`@("`@("`@("`@("`G9F%U;'1A8W1O<B<@
M/3X@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX+`H@("`@("`@("`@("`@
M("`@)V1E=&%I;"<@/3X@)'1H:7,M/G5S97)I;F9O"B`@("`@("`@("`@("D[
M"B`@("!]"B`@("`*("`@("\J*@H@("`@("H@9V5T06-T;W(*("`@("`J"B`@
M("`@*B!R971U<FYS('1H92!33T%0(&%C=&]R(&9O<B!T:&4@9F%U;'0*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$%C=&]R*"D*("`@('L*("`@
M("`@("!R971U<FX@)'1H:7,M/F5R<F]R7VUE<W-A9V5?<')E9FEX.PH@("`@
M?0H@("`@"B`@("`O*BH*("`@("`J(&=E=$1E=&%I;`H@("`@("H*("`@("`J
M(')E='5R;G,@=&AE(&9A=6QT(&1E=&%I;`H@("`@("H*("`@("`J($!R971U
M<FX@<W1R:6YG(`H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T1&5T86EL*"D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G5S97)I;F9O.PH@("`@?0H@("`@"GT*/SX`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]087)S97(N
M<&AP````````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T
M-C`U,"`Q,#4Q-30S-#$S,R`P,C$Q-S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C
M;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(%-/05`@;65S<V%G92!P87)S97(N
M"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H
M:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@
M=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L
M92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED
M92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*
M("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/
M05`*("H@0&%U=&AO<B`@("`@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A
M;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J($!A=71H;W(@("`@(%-H86YE
M($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@(%!O<G0@=&\@4$5!4B!A
M;F0@;6]R90H@*B!`875T:&]R("`@("!#:'5C:R!(86=E;F)U8V@@/&-H=6-K
M0&AO<F1E+F]R9SX@("!-86EN=&5N86YC90H@*B!`875T:&]R("`@("!*86X@
M4V-H;F5I9&5R(#QJ86Y`:&]R9&4N;W)G/B`@("`@("!-86EN=&5N86YC90H@
M*B!`8V]P>7)I9VAT("`R,#`S+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC
M96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="`@
M4$A0($QI8V5N<V4@,BXP,@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP
M:'`N;F5T+W!A8VMA9V4O4T]!4`H@*B\*"G)E<75I<F5?;VYC92`G4T]!4"]"
M87-E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]686QU92YP:'`G.PH*+RHJ
M"B`J(%-/05`@4&%R<V5R"B`J"B`J(%1H:7,@8VQA<W,@:7,@=7-E9"!B>2!3
M3T%0.CI-97-S86=E(&%N9"!33T%0.CI397)V97(@=&\@<&%R<V4@<V]A<`H@
M*B!P86-K971S+B!/<FEG:6YA;&QY(&)A<V5D(&]N(%-/05!X-"!B>2!$:65T
M<FEC:"!!>6%L80H@*B!H='1P.B\O9&EE=')I8V@N9V%N>#0N8V]M+W-O87!X
M-`H@*@H@*B!`86-C97-S('!U8FQI8PH@*B!`<&%C:V%G92!33T%0"B`J($!A
M=71H;W(@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X@0V]N=F5R<VEO
M;B!T;R!014%2(&%N9"!U<&1A=&5S"B`J($!A=71H;W(@1&EE=')I8V@@07EA
M;&$@/&1I971R:6-H0&=A;G@T+F-O;3X@3W)I9VEN86P@075T:&]R"B`J+PIC
M;&%S<R!33T%07U!A<G-E<B!E>'1E;F1S(%-/05!?0F%S90I["B`@("!V87(@
M)'-T871U<R`]("<G.PH@("`@=F%R("1P;W-I=&EO;B`](#`["B`@("!V87(@
M)'!O<U]S=&%T(#T@,#L*("`@('9A<B`D9&5P=&@@/2`P.PH@("`@=F%R("1D
M969A=6QT7VYA;65S<&%C92`]("<G.PH@("`@=F%R("1M97-S86=E(#T@87)R
M87DH*3L*("`@('9A<B`D9&5P=&A?87)R87D@/2!A<G)A>2@I.PH@("`@=F%R
M("1P<F5V:6]U<U]E;&5M96YT(#T@)R<["B`@("!V87(@)'-O87!R97-P;VYS
M92`](&YU;&P["B`@("!V87(@)'-O87!H96%D97)S(#T@;G5L;#L*("`@('9A
M<B`D<&%R96YT(#T@,#L*("`@('9A<B`D<F]O=%]S=')U8W1?;F%M92`](&%R
M<F%Y*"D["B`@("!V87(@)&AE861E<E]S=')U8W1?;F%M92`](&%R<F%Y*"D[
M"B`@("!V87(@)&-U<F5N=%]R;V]T7W-T<G5C=%]N86UE(#T@)R<["B`@("!V
M87(@)&5N=&ET:65S(#T@87)R87D@*"`G)B<@/3X@)R9A;7`[)RP@)SPG(#T^
M("<F;'0[)RP@)SXG(#T^("<F9W0[)RP@(B<B(#T^("<F87!O<SLG+"`G(B<@
M/3X@)R9Q=6]T.R<@*3L*("`@('9A<B`D<F]O=%]S=')U8W0@/2!A<G)A>2@I
M.PH@("`@=F%R("1H96%D97)?<W1R=6-T(#T@87)R87DH*3L*("`@('9A<B`D
M8W5R96YT7W)O;W1?<W1R=6-T(#T@,#L*("`@('9A<B`D<F5F97)E;F-E<R`]
M(&%R<F%Y*"D["B`@("!V87(@)&YE961?<F5F97)E;F-E<R`](&%R<F%Y*"D[
M"B`@("!V87(@)%A-3%-C:&5M859E<G-I;VX["B`@("!V87(@)&)O9'E$97!T
M:#L@+R\@=7-E9"!T;R!H86YD;&4@;F]N+7)O;W0@96QE;65N=',@8F5F;W)E
M(')O;W0@8F]D>2!E;&5M96YT"@H@("`@+RHJ"B`@("`@*B!33T%07U!A<G-E
M<B!C;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@>&UL
M(&-O;G1E;G0*("`@("`J($!P87)A;2!S=')I;F<@>&UL(&-H87)A8W1E<B!E
M;F-O9&EN9RP@9&5F875L=',@=&\@)U541BTX)PH@("`@("HO"B`@("!F=6YC
M=&EO;B!33T%07U!A<G-E<B@F)'AM;"P@)&5N8V]D:6YG(#T@4T]!4%]$149!
M54Q47T5.0T]$24Y'+"`D871T86-H;65N=',@/2!N=6QL*0H@("`@>PH@("`@
M("`@('!A<F5N=#HZ4T]!4%]"87-E*"=087)S97(G*3L*("`@("`@("`D=&AI
M<RT^7W-E=%-C:&5M859E<G-I;VXH4T]!4%]834Q?4T-(14U!7U9%4E-)3TXI
M.PH*("`@("`@("`D=&AI<RT^871T86-H;65N=',@/2`D871T86-H;65N=',[
M"@H@("`@("`@("\O($-H96-K('1H92!X;6P@=&%G(&9O<B!E;F-O9&EN9RX*
M("`@("`@("!I9B`H<')E9U]M871C:"@G+SQ</WAM;%M>/ETK96YC;V1I;F=<
M<RH_/5QS*C\H7"<H6UY<)UTJ*5PG?"(H6UXB72HI(BE;7CY=*C];7#]=/B\G
M+"`D>&UL+"`D;2DI('L*("`@("`@("`@("`@)&5N8V]D:6YG(#T@<W1R=&]U
M<'!E<B@D;5LR72`_("1M6S)=(#H@)&U;,UTI.PH@("`@("`@('T*"B`@("`@
M("`@+R\@1&5T97)M:6YE<R!W:&5R92!I;B!T:&4@;65S<V%G92!W92!A<F4*
M("`@("`@("`O+R`H96YV96QO<&4L:&5A9&5R+&)O9'DL;65T:&]D*2X@0VAE
M8VL@=VAE=&AE<B!C;VYT96YT(&AA<PH@("`@("`@("\O(&)E96X@<F5A9"X*
M("`@("`@("!I9B`H(65M<'1Y*"1X;6PI*2!["B`@("`@("`@("`@("\O(%!R
M97!A<F4@=&AE('AM;"!P87)S97(N"B`@("`@("`@("`@("1P87)S97(@/2!X
M;6Q?<&%R<V5R7V-R96%T92@D96YC;V1I;F<I.PH@("`@("`@("`@("!X;6Q?
M<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<BP@6$U,7T]05$E/3E]#05-%7T9/
M3$1)3D<L(#`I.PH@("`@("`@("`@("!X;6Q?<V5T7V]B:F5C="@D<&%R<V5R
M+"`D=&AI<RD["B`@("`@("`@("`@('AM;%]S971?96QE;65N=%]H86YD;&5R
M*"1P87)S97(L("=S=&%R=$5L96UE;G0G+"`G96YD16QE;65N="<I.PH@("`@
M("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D871A7VAA;F1L97(H)'!A<G-E
M<BP@)V-H87)A8W1E<D1A=&$G*3L*"B`@("`@("`@("`@("\O(%-O;64@;&%M
M92!S;V%P(&EM<&QE;65N=&%T:6]N<R!A9&0@;G5L;"!B>71E<R!A="!T:&4*
M("`@("`@("`@("`@+R\@96YD(&]F('1H92!S;V%P('-T<F5A;2P@86YD(&5X
M<&%T(&-H;V%K<R!O;B!T:&%T+@H@("`@("`@("`@("!I9B`H)'AM;%MS=')L
M96XH)'AM;"D@+2`Q72`]/2`P*2!["B`@("`@("`@("`@("`@("`D>&UL(#T@
M=')I;2@D>&UL*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R\@4&%R
M<V4@=&AE(%A-3"!F:6QE+@H@("`@("`@("`@("!I9B`H(7AM;%]P87)S92@D
M<&%R<V5R+"`D>&UL+"!T<G5E*2D@>PH@("`@("`@("`@("`@("`@)&5R<B`]
M('-P<FEN=&8H)UA-3"!E<G)O<B!O;B!L:6YE("5D(&-O;"`E9"!B>71E("5D
M("5S)RP*("`@("`@("`@("`@("`@("`@("!X;6Q?9V5T7V-U<G)E;G1?;&EN
M95]N=6UB97(H)'!A<G-E<BDL"B`@("`@("`@("`@("`@("`@("`@>&UL7V=E
M=%]C=7)R96YT7V-O;'5M;E]N=6UB97(H)'!A<G-E<BDL"B`@("`@("`@("`@
M("`@("`@("`@>&UL7V=E=%]C=7)R96YT7V)Y=&5?:6YD97@H)'!A<G-E<BDL
M"B`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T
M7V5R<F]R7V-O9&4H)'!A<G-E<BDI*3L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<F%I<V53;V%P1F%U;'0H)&5R<BQH=&UL<W!E8VEA;&-H87)S*"1X;6PI
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!X;6Q?<&%R<V5R7V9R964H
M)'!A<G-E<BD["B`@("`@("`@?0H@("`@?0H*"B`@("`O*BH*("`@("`J(&1O
M;75L=&D*("`@("`J(')E8W5R<V4@=&\@8G5I;&0@82!M=6QT:2UD:6T@87)R
M87DL('5S960@8GD@8G5I;&1297-P;VYS90H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!D;VUU;'1I*"1D+"`F
M)&%R+"`F)'(L("8D=BP@)&%D/3`I"B`@("!["B`@("`@("`@:68@*"1D*2![
M"B`@("`@("`@("`@("1T:&ES+3YD;VUU;'1I*"1D+3$L("1A<BP@)');)&%R
M6R1A9%U=+"`D=BP@)&%D*S$I.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1R(#T@)'8["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M8G5I;&1297-P;VYS90H@("`@("H@;&]O<"!T:')O=6=H(&US9RP@8G5I;&1I
M;F<@<F5S<&]N<V4@<W1R=6-T=7)E<PH@("`@("H*("`@("`J($!P87)A;2!I
M;G0@<&]S:71I;VX*("`@("`J($!R971U<FX@4T]!4%]686QU90H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N("9B=6EL9%)E
M<W!O;G-E*"1P;W,I"B`@("!["B`@("`@("`@)')E<W!O;G-E(#T@;G5L;#L*
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL
M9')E;B==*2D@>PH@("`@("`@("`@("`D8VAI;&1R96X@/2!E>'!L;V1E*"=\
M)RP@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-H:6QD<F5N)UTI.PH*("`@("`@
M("`@("`@9F]R96%C:"`H)&-H:6QD<F5N(&%S("1C(#T^("1C:&EL9%]P;W,I
M('L*("`@("`@("`@("`@("`@(&EF("@D=&AI<RT^;65S<V%G95LD8VAI;&1?
M<&]S75LG='EP92==("$](&YU;&PI('L*("`@("`@("`@("`@("`@("`@("`D
M<F5S<&]N<V5;72`])B`D=&AI<RT^8G5I;&1297-P;VYS92@D8VAI;&1?<&]S
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G87)R87E3:7IE)RP@)'1H:7,M/FUE
M<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@("`@("`D87)D97!T:"`](&-O
M=6YT*"1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>5-I>F4G72D["B`@("`@
M("`@("`@("`@("!I9B`H)&%R9&5P=&@@/B`Q*2!["B`@("`@("`@("`@("`@
M("`@("`@)&%R(#T@87)R87E?<&%D*&%R<F%Y*"DL("1A<F1E<'1H+"`P*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G87)R
M87E/9F9S970G+"`D=&AI<RT^;65S<V%G95LD<&]S72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&%R9&5P=&@[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1A<ELD:5T@*ST@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%R<F%Y3V9F<V5T)UU;)&E=.PH@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("1E;&,@/2!C;W5N="@D<F5S<&]N<V4I.PH@
M("`@("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1E;&,[("1I
M*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@+R\@<F5C=7)S92!T;R!B
M=6EL9"!A(&UU;'1I+61I;65N<VEO;F%L(&%R<F%Y"B`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YD;VUU;'1I*"1A<F1E<'1H+"`D87(L("1N97=R
M97-P+"`D<F5S<&]N<V5;)&E=*3L*"B`@("`@("`@("`@("`@("`@("`@("`@
M("\O(&EN8W)E;65N="!O=7(@87)R87D@<&]I;G1E<G,*("`@("`@("`@("`@
M("`@("`@("`@("`@)&%D(#T@)&%R9&5P=&@@+2`Q.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D87);)&%D72LK.PH@("`@("`@("`@("`@("`@("`@("`@
M("!W:&EL92`H)&%D(#X@,"`F)B`D87);)&%D72`^/2`D=&AI<RT^;65S<V%G
M95LD<&]S75LG87)R87E3:7IE)UU;)&%D72D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&%R6R1A9%T@/2`P.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&%D+2T["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M87);)&%D72LK.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("1R97-P;VYS92`]
M("1N97=R97-P.PH@("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T
M:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>4]F9G-E="==*2`F)@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A
M>4]F9G-E="==6S!=(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("\O(&-H
M96-K(&9O<B!P861D:6YG"B`@("`@("`@("`@("`@("`@("`@)'!A9"`]("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=A<G)A>4]F9G-E="==6S!=("L@8V]U;G0H
M)')E<W!O;G-E*2`J("TQ.PH@("`@("`@("`@("`@("`@("`@("1R97-P;VYS
M92`](&%R<F%Y7W!A9"@D<F5S<&]N<V4L("1P860L(&YU;&PI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O
M+R!"=6EL9"!A='1R:6)U=&5S+@H@("`@("`@("1A='1R<R`](&%R<F%Y*"D[
M"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%T=')S
M)UT@87,@)&%T;B`]/B`D871V*2!["B`@("`@("`@("`@(&EF("@A<W1R<W1R
M*"1A=&XL("=X;6QN<R<I("8F"B`@("`@("`@("`@("`@("`A<W1R<&]S*"1A
M=&XL("<Z)RDI('L*("`@("`@("`@("`@("`@("1A='1R<ULD871N72`]("1A
M='8["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O($%D9"!C
M=7)R96YT(&YO9&4G<R!V86QU92X*("`@("`@("!I9B`H)')E<W!O;G-E*2![
M"B`@("`@("`@("`@("1N<6X@/28@;F5W(%%N86UE*"1T:&ES+3YM97-S86=E
M6R1P;W-=6R=N86UE)UTL("1T:&ES+3YM97-S86=E6R1P;W-=6R=N86UE<W!A
M8V4G72D["B`@("`@("`@("`@("1T<6X@/28@;F5W(%%N86UE*"1T:&ES+3YM
M97-S86=E6R1P;W-=6R=T>7!E)UTL("1T:&ES+3YM97-S86=E6R1P;W-=6R=T
M>7!E7VYA;65S<&%C92==*3L*("`@("`@("`@("`@)')E<W!O;G-E(#TF(&YE
M=R!33T%07U9A;'5E*"1N<6XM/F9Q;B@I+"`D='%N+3YF<6XH*2P@)')E<W!O
M;G-E+"`D871T<G,I.PH@("`@("`@("`@("!I9B`H:7-S970H)'1H:7,M/FUE
M<W-A9V5;)'!O<UU;)V%R<F%Y5'EP92==*2D@>PH@("`@("`@("`@("`@("`@
M)')E<W!O;G-E+3YA<G)A>51Y<&4@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG
M87)R87E4>7!E)UT["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D;G%N(#TF(&YE=R!1;F%M92@D=&AI<RT^;65S<V%G95LD
M<&]S75LG;F%M92==+"`D=&AI<RT^;65S<V%G95LD<&]S75LG;F%M97-P86-E
M)UTI.PH@("`@("`@("`@("`D='%N(#TF(&YE=R!1;F%M92@D=&AI<RT^;65S
M<V%G95LD<&]S75LG='EP92==+"`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP
M95]N86UE<W!A8V4G72D["B`@("`@("`@("`@("1R97-P;VYS92`])B!N97<@
M4T]!4%]686QU92@D;G%N+3YF<6XH*2P@)'1Q;BT^9G%N*"DL("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=C9&%T82==+"`D871T<G,I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@:&%N9&QE(&AE861E<B!A='1R:6)U=&4@=&AA="!W92!N965D
M"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)V%C=&]R)RP@)'1H:7,M
M/FUE<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@("1R97-P;VYS92T^86-T
M;W(@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG86-T;W(G73L*("`@("`@("!]
M"B`@("`@("`@:68@*&%R<F%Y7VME>5]E>&ES=',H)VUU<W15;F1E<G-T86YD
M)RP@)'1H:7,M/FUE<W-A9V5;)'!O<UTI*2!["B`@("`@("`@("`@("1R97-P
M;VYS92T^;75S='5N9&5R<W1A;F0@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG
M;75S=%5N9&5R<W1A;F0G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R
M97-P;VYS93L*("`@('T*"B`@("`O*BH*("`@("`J('-T87)T16QE;65N=`H@
M("`@("H@<W1A<G0M96QE;65N="!H86YD;&5R('5S960@=VET:"!X;6P@<&%R
M<V5R"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-T87)T16QE;65N="@D<&%R<V5R+"`D;F%M92P@)&%T=')S
M*0H@("`@>PH@("`@("`@("\O('!O<VET:6]N(&EN(&$@=&]T86P@;G5M8F5R
M(&]F(&5L96UE;G1S+"!S=&%R=&EN9R!F<F]M(#`*("`@("`@("`O+R!U<&1A
M=&4@8VQA<W,@;&5V96P@<&]S"B`@("`@("`@)'!O<R`]("1T:&ES+3YP;W-I
M=&EO;BLK.PH*("`@("`@("`O+R!A;F0@<V5T(&UI;F4*("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<&]S72`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/FUE
M<W-A9V5;)'!O<UU;)W1Y<&4G72`]("<G.PH@("`@("`@("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=T>7!E7VYA;65S<&%C92==(#T@)R<["B`@("`@("`@)'1H
M:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@/2`G)SL*("`@("`@("`D=&AI
M<RT^;65S<V%G95LD<&]S75LG<&]S)UT@/2`D<&]S.PH@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=I9"==(#T@)R<["@H@("`@("`@("\O('!A<F5N
M="]C:&EL9"]D97!T:"!D971E<FUI;F%T:6]N<PH*("`@("`@("`O+R!D97!T
M:"`](&AO=R!M86YY(&QE=F5L<R!R96UO=F5D(&9R;VT@<F]O=#\*("`@("`@
M("`O+R!S970@;6EN92!A<R!C=7)R96YT(&=L;V)A;"!D97!T:"!A;F0@:6YC
M<F5M96YT(&=L;V)A;"!D97!T:"!V86QU90H@("`@("`@("1T:&ES+3YM97-S
M86=E6R1P;W-=6R=D97!T:"==(#T@)'1H:7,M/F1E<'1H*RL["@H@("`@("`@
M("\O(&5L<V4@861D('-E;&8@87,@8VAI;&0@=&\@=VAO979E<B!T:&4@8W5R
M<F5N="!P87)E;G0@:7,*("`@("`@("!I9B`H)'!O<R`A/2`P*2!["B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^;65S<V%G95LD=&AI<RT^<&%R96YT
M75LG8VAI;&1R96XG72DI"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G
M95LD=&AI<RT^<&%R96YT75LG8VAI;&1R96XG72`N/2`B?"1P;W,B.PH@("`@
M("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD
M=&AI<RT^<&%R96YT75LG8VAI;&1R96XG72`]("1P;W,["B`@("`@("`@?0H*
M("`@("`@("`O+R!S970@;7D@<&%R96YT"B`@("`@("`@)'1H:7,M/FUE<W-A
M9V5;)'!O<UU;)W!A<F5N="==(#T@)'1H:7,M/G!A<F5N=#L*"B`@("`@("`@
M+R\@<V5T('-E;&8@87,@8W5R<F5N="!V86QU92!F;W(@=&AI<R!D97!T:`H@
M("`@("`@("1T:&ES+3YD97!T:%]A<G)A>5LD=&AI<RT^9&5P=&A=(#T@)'!O
M<SL*("`@("`@("`O+R!S970@<V5L9B!A<R!C=7)R96YT('!A<F5N=`H@("`@
M("`@("1T:&ES+3YP87)E;G0@/2`D<&]S.PH@("`@("`@("1Q;F%M92`])B!N
M97<@44YA;64H)&YA;64I.PH@("`@("`@("\O('-E="!S=&%T=7,*("`@("`@
M("!I9B`H<W1R8V%S96-M<"@G96YV96QO<&4G+"`D<6YA;64M/FYA;64I(#T]
M(#`I('L*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=E;G9E;&]P92<[
M"B`@("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H)VAE861E<B<L("1Q;F%M
M92T^;F%M92D@/3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<W1A='5S(#T@
M)VAE861E<B<["B`@("`@("`@("`@("1T:&ES+3YH96%D97)?<W1R=6-T7VYA
M;65;72`]("1T:&ES+3YC=7)E;G1?<F]O=%]S=')U8W1?;F%M92`]("1Q;F%M
M92T^;F%M93L*("`@("`@("`@("`@)'1H:7,M/FAE861E<E]S=')U8W1;72`]
M("1T:&ES+3YC=7)E;G1?<F]O=%]S=')U8W0@/2`D<&]S.PH@("`@("`@("`@
M("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T<G5C="<["B`@
M("`@("`@?2!E;'-E:68@*'-T<F-A<V5C;7`H)V)O9'DG+"`D<6YA;64M/FYA
M;64I(#T](#`I('L*("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=B;V1Y
M)SL*("`@("`@("`@("`@)'1H:7,M/F)O9'E$97!T:"`]("1T:&ES+3YD97!T
M:#L*"B`@("`@("`@+R\@4V5T(&UE=&AO9`H@("`@("`@('T@96QS96EF("@D
M=&AI<RT^<W1A='5S(#T]("=B;V1Y)RD@>PH@("`@("`@("`@("`O+R!)<R!T
M:&ES(&5L96UE;G0@86QL;W=E9"!T;R!B92!A(')O;W0_"B`@("`@("`@("`@
M("\O(%A86"!T:&ES(&YE961S('1O(&)E(&]P=&EM:7IE9"P@=V4@;&]O<"!T
M:')O=6=H(&%T=')S('1W:6-E(&YO=RX*("`@("`@("`@("`@)&-A;E]R;V]T
M(#T@)'1H:7,M/F1E<'1H(#T]("1T:&ES+3YB;V1Y1&5P=&@@*R`Q.PH@("`@
M("`@("`@("!I9B`H)&-A;E]R;V]T*2!["B`@("`@("`@("`@("`@("!F;W)E
M86-H("@D871T<G,@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H<W1R:7-T<B@D:V5Y+"`G.G)O;W0G*2`F)B`A)'9A;'5E
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1C86Y?<F]O="`]($9!3%-%
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1C86Y?<F]O="D@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G-T871U<R`]("=M971H;V0G.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/G)O;W1?<W1R=6-T7VYA;65;72`]("1T:&ES+3YC
M=7)E;G1?<F]O=%]S=')U8W1?;F%M92`]("1Q;F%M92T^;F%M93L*("`@("`@
M("`@("`@("`@("1T:&ES+3YR;V]T7W-T<G5C=%M=(#T@)'1H:7,M/F-U<F5N
M=%]R;V]T7W-T<G5C="`]("1P;W,["B`@("`@("`@("`@("`@("`D=&AI<RT^
M;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T<G5C="<["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\O(%-E="!M>2!S=&%T=7,N"B`@("`@
M("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W-T871U<R==(#T@)'1H:7,M/G-T
M871U<SL*"B`@("`@("`@+R\@4V5T(&YA;64N"B`@("`@("`@)'1H:7,M/FUE
M<W-A9V5;)'!O<UU;)VYA;64G72`](&AT;6QS<&5C:6%L8VAA<G,H)'%N86UE
M+3YN86UE*3L*"B`@("`@("`@+R\@4V5T(&%T=')I8G5T97,N"B`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V%T=')S)UT@/2`D871T<G,["@H@("`@
M("`@("\O($QO;W`@=&AR;W5G:"!A='1R:6)U=&5S+"!L;V=G:6YG(&YS(&%N
M9"!T>7!E(&1E8VQA<F%T:6]N<RX*("`@("`@("!F;W)E86-H("@D871T<G,@
M87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`@("`@+R\@268@;G,@9&5C
M;&%R871I;VYS+"!A9&0@=&\@8VQA<W,@;&5V96P@87)R87D@;V8@=F%L:60*
M("`@("`@("`@("`@+R\@;F%M97-P86-E<RX*("`@("`@("`@("`@)&MQ;B`]
M)B!N97<@44YA;64H)&ME>2D["B`@("`@("`@("`@(&EF("@D:W%N+3YN<R`]
M/2`G>&UL;G,G*2!["B`@("`@("`@("`@("`@("`D<')E9FEX(#T@)&MQ;BT^
M;F%M93L*"B`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH)'9A;'5E+"`D
M=&AI<RT^7UA-3%-C:&5M82DI('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-E=%-C:&5M859E<G-I;VXH)'9A;'5E*3L*("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`D=&AI<RT^7VYA;65S<&%C97-;)'9A;'5E
M72`]("1P<F5F:7@["@H@("`@("`@("`@("`O+R!3970@;65T:&]D(&YA;65S
M<&%C92X*("`@("`@("`@("`@?2!E;'-E:68@*"1K97D@/3T@)WAM;&YS)RD@
M>PH@("`@("`@("`@("`@("`@)'%N86UE+3YN<R`]("1T:&ES+3Y?9V5T3F%M
M97-P86-E4')E9FEX*"1V86QU92D["B`@("`@("`@("`@("`@("`D<6YA;64M
M/FYA;65S<&%C92`]("1V86QU93L*("`@("`@("`@("`@?2!E;'-E:68@*"1K
M<6XM/FYA;64@/3T@)V%C=&]R)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)'!O<UU;)V%C=&]R)UT@/2`D=F%L=64["B`@("`@("`@("`@
M('T@96QS96EF("@D:W%N+3YN86UE(#T]("=M=7-T56YD97)S=&%N9"<I('L*
M("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=M=7-T56YD
M97)S=&%N9"==(#T@)'9A;'5E.PH*("`@("`@("`@("`@+R\@268@:70G<R!A
M('1Y<&4@9&5C;&%R871I;VXL('-E="!T>7!E+@H@("`@("`@("`@("!](&5L
M<V5I9B`H)&MQ;BT^;F%M92`]/2`G='EP92<I('L*("`@("`@("`@("`@("`@
M("1V<6X@/28@;F5W(%%.86UE*"1V86QU92D["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)'9Q;BT^;F%M93L*("`@
M("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=T>7!E7VYA;65S
M<&%C92==(#T@)'1H:7,M/E]G971.86UE<W!A8V5&;W)0<F5F:7@H)'9Q;BT^
M;G,I.PH@("`@("`@("`@("`@("`@+R\@4VAO=6QD(&1O('-O;65T:&EN9R!H
M97)E('=I=&@@=&AE(&YA;65S<&%C92!O9@H@("`@("`@("`@("`@("`@+R\@
M<W!E8VEF:65D('1Y<&4_"@H@("`@("`@("`@("!](&5L<V5I9B`H)&MQ;BT^
M;F%M92`]/2`G87)R87E4>7!E)RD@>PH@("`@("`@("`@("`@("`@)'9Q;B`]
M)B!N97<@44YA;64H)'9A;'5E*3L*("`@("`@("`@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=T>7!E)UT@/2`G07)R87DG.PH@("`@("`@("`@("`@
M("`@:68@*&ES<V5T*"1V<6XM/F%R<F%Y4VEZ92DI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E3:7IE)UT@/2`D
M=G%N+3YA<G)A>5-I>F4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E4>7!E)UT@/2`D=G%N
M+3YN86UE.PH*("`@("`@("`@("`@?2!E;'-E:68@*"1K<6XM/FYA;64@/3T@
M)V]F9G-E="<I('L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P
M;W-=6R=A<G)A>4]F9G-E="==(#T@<W!L:70H)RPG+"!S=6)S='(H)'9A;'5E
M+"`Q+"!S=')L96XH)'9A;'5E*2`M(#(I*3L*"B`@("`@("`@("`@('T@96QS
M96EF("@D:W%N+3YN86UE(#T]("=I9"<I('L*("`@("`@("`@("`@("`@("\O
M(%-A=F4@:60@=&\@<F5F97)E;F-E(&%R<F%Y+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/G)E9F5R96YC97-;)'9A;'5E72`]("1P;W,["B`@("`@("`@("`@
M("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG:60G72`]("1V86QU93L*"B`@
M("`@("`@("`@('T@96QS96EF("@D:W%N+3YN86UE(#T]("=H<F5F)RD@>PH@
M("`@("`@("`@("`@("`@:68@*"1V86QU95LP72`]/2`G(R<I('L*("`@("`@
M("`@("`@("`@("`@("`D<F5F(#T@<W5B<W1R*"1V86QU92P@,2D["B`@("`@
M("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YR969E<F5N8V5S6R1R
M969=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!C9&%T82P@='EP
M92P@:6YV86PN"B`@("`@("`@("`@("`@("`@("`@("`@("1R969?<&]S(#T@
M)'1H:7,M/G)E9F5R96YC97-;)')E9ET["B`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==(#T@)B1T:&ES
M+3YM97-S86=E6R1R969?<&]S75LG8VAI;&1R96XG73L*("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UT@/2`F
M)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C9&%T82==.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@
M)B1T:&ES+3YM97-S86=E6R1R969?<&]S75LG='EP92==.PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG87)R87E3:7IE
M)UT@/2`F)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=A<G)A>5-I>F4G73L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)V%R<F%Y5'EP92==(#T@)B1T:&ES+3YM97-S86=E6R1R969?<&]S75LG87)R
M87E4>7!E)UT["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@4F5V97)S92!R969E<F5N8V4L('-T;W)E
M(&EN("=N965D(')E9F5R96YC92<N"B`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)'1H:7,M/FYE961?<F5F97)E;F-E<ULD<F5F72DI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YN965D7W)E9F5R
M96YC97-;)')E9ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YN965D7W)E9F5R
M96YC97-;)')E9EU;72`]("1P;W,["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YA='1A8VAM
M96YT<ULD=F%L=65=*2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YM
M97-S86=E6R1P;W-=6R=C9&%T82==(#T@)'1H:7,M/F%T=&%C:&UE;G1S6R1V
M86QU95T["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@+R\@4V5E(&EF(&YA;65S<&%C92!I<R!D969I;F5D(&EN
M('1A9RX*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G>&UL;G,Z)R`N
M("1Q;F%M92T^;G,L("1A='1R<RDI('L*("`@("`@("`@("`@)&YA;65S<&%C
M92`]("1A='1R<ULG>&UL;G,Z)R`N("1Q;F%M92T^;G-=.PH@("`@("`@('T@
M96QS96EF("@D<6YA;64M/FYS("8F("$D<6YA;64M/FYA;65S<&%C92D@>PH@
M("`@("`@("`@("`D;F%M97-P86-E(#T@)'1H:7,M/E]G971.86UE<W!A8V5&
M;W)0<F5F:7@H)'%N86UE+3YN<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+R\@1V5T(&YA;65S<&%C92X*("`@("`@("`@("`@)&YA;65S<&%C
M92`]("1Q;F%M92T^;F%M97-P86-E(#\@)'%N86UE+3YN86UE<W!A8V4@.B`D
M=&AI<RT^9&5F875L=%]N86UE<W!A8V4["B`@("`@("`@?0H@("`@("`@("1T
M:&ES+3YM97-S86=E6R1P;W-=6R=N86UE<W!A8V4G72`]("1N86UE<W!A8V4[
M"B`@("`@("`@)'1H:7,M/F1E9F%U;'1?;F%M97-P86-E(#T@)&YA;65S<&%C
M93L*("`@('T*"B`@("`O*BH*("`@("`J(&5N9$5L96UE;G0*("`@("`J(&5N
M9"UE;&5M96YT(&AA;F1L97(@=7-E9"!W:71H('AM;"!P87)S97(*("`@("`J
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@
M96YD16QE;65N="@D<&%R<V5R+"`D;F%M92D*("`@('L*("`@("`@("`O+R!0
M;W-I=&EO;B!O9B!C=7)R96YT(&5L96UE;G0@:7,@97%U86P@=&\@=&AE(&QA
M<W0@=F%L=64@;&5F=`H@("`@("`@("\O(&EN(&1E<'1H7V%R<F%Y(&9O<B!M
M>2!D97!T:"X*("`@("`@("`D<&]S(#T@)'1H:7,M/F1E<'1H7V%R<F%Y6R1T
M:&ES+3YD97!T:%T["@H@("`@("`@("\O($)R:6YG(&1E<'1H(&1O=VX@82!N
M;W1C:"X*("`@("`@("`D=&AI<RT^9&5P=&@M+3L*("`@("`@("`D<6YA;64@
M/28@;F5W(%%.86UE*"1N86UE*3L*"B`@("`@("`@+R\@1V5T('1Y<&4@:68@
M;F]T(&5X<&QI8VET;'D@9&5C;&%R960@:6X@86X@>'-I.G1Y<&4@871T<FEB
M=71E+@H@("`@("`@("\O(%A86"!C:&5C:R!O;B!I;G1E9W)A=&EN9R!W<V1L
M('9A;&ED871I;VX@:&5R90H@("`@("`@(&EF("@D=&AI<RT^;65S<V%G95LD
M<&]S75LG='EP92==(#T]("<G*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^;65S<V%G95LD<&]S75LG8VAI;&1R96XG72DI('L*("`@("`@("`@
M("`@("`@("\J('1H:7,@:7,@<VQO=RP@;F5E9"!T;R!L;V]K(&%T('-O;64@
M9F%S=&5R(&UE=&AO9`H@("`@("`@("`@("`@("`@)&-H:6QD<F5N(#T@97AP
M;&]D92@G?"<L("1T:&ES+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==*3L*
M("`@("`@("`@("`@("`@(&EF("AC;W5N="@D8VAI;&1R96XI(#X@,B`F)@H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1C:&EL9')E;ELQ
M75U;)VYA;64G72`]/2`D=&AI<RT^;65S<V%G95LD8VAI;&1R96Y;,EU=6R=N
M86UE)UTI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD
M<&]S75LG='EP92==(#T@)T%R<F%Y)SL*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A9V5;)'!O<UU;
M)W1Y<&4G72`]("=3=')U8W0G.PH@("`@("`@("`@("`@("`@?2HO"B`@("`@
M("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)U-T
M<G5C="<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D
M<&%R96YT(#T@)'1H:7,M/FUE<W-A9V5;)'!O<UU;)W!A<F5N="==.PH@("`@
M("`@("`@("`@("`@:68@*"1T:&ES+3YM97-S86=E6R1P87)E;G1=6R=T>7!E
M)UT@/3T@)T%R<F%Y)R`F)@H@("`@("`@("`@("`@("`@("!A<G)A>5]K97E?
M97AI<W1S*"=A<G)A>51Y<&4G+"`D=&AI<RT^;65S<V%G95LD<&%R96YT72DI
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^;65S<V%G95LD<&]S75LG
M='EP92==(#T@)'1H:7,M/FUE<W-A9V5;)'!A<F5N=%U;)V%R<F%Y5'EP92==
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=&AI<RT^;65S<V%G95LD<&]S75LG='EP92==(#T@)W-T<FEN9R<["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@("\O($EF('1A9R!W92!A<F4@8W5R<F5N=&QY(&-L;W-I;F<@:7,@=&AE
M(&UE=&AO9"!W<F%P<&5R+@H@("`@("`@(&EF("@D<&]S(#T]("1T:&ES+3YC
M=7)E;G1?<F]O=%]S=')U8W0I('L*("`@("`@("`@("`@)'1H:7,M/G-T871U
M<R`]("=B;V1Y)SL*("`@("`@("!](&5L<V5I9B`H)'%N86UE+3YN86UE(#T]
M("=";V1Y)R!\?"`D<6YA;64M/FYA;64@/3T@)TAE861E<B<I('L*("`@("`@
M("`@("`@)'1H:7,M/G-T871U<R`]("=E;G9E;&]P92<["B`@("`@("`@?0H*
M("`@("`@("`O+R!3970@<&%R96YT(&)A8VL@=&\@;7D@<&%R96YT+@H@("`@
M("`@("1T:&ES+3YP87)E;G0@/2`D=&AI<RT^;65S<V%G95LD<&]S75LG<&%R
M96YT)UT["@H@("`@("`@("\O($AA;F1L92!A;GD@<F5V97)S92!R969E<F5N
M8V5S(&YO=RX*("`@("`@("`D:61R968@/2`D=&AI<RT^;65S<V%G95LD<&]S
M75LG:60G73L*"B`@("`@("`@:68@*"1I9')E9B`A/2`G)R`F)B!A<G)A>5]K
M97E?97AI<W1S*"1I9')E9BP@)'1H:7,M/FYE961?<F5F97)E;F-E<RDI('L*
M("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FYE961?<F5F97)E;F-E<ULD
M:61R969=(&%S("1R969?<&]S*2!["B`@("`@("`@("`@("`@("`O+R!86%@@
M:7,@=&AI<R!S='5F9B!T:&5R92!A;')E861Y/PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C:&EL9')E;B==(#T@)B1T:&ES
M+3YM97-S86=E6R1P;W-=6R=C:&EL9')E;B==.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FUE<W-A9V5;)')E9E]P;W-=6R=C9&%T82==(#T@)B1T:&ES+3YM
M97-S86=E6R1P;W-=6R=C9&%T82==.PH@("`@("`@("`@("`@("`@)'1H:7,M
M/FUE<W-A9V5;)')E9E]P;W-=6R=T>7!E)UT@/2`F)'1H:7,M/FUE<W-A9V5;
M)'!O<UU;)W1Y<&4G73L*("`@("`@("`@("`@("`@("1T:&ES+3YM97-S86=E
M6R1R969?<&]S75LG87)R87E3:7IE)UT@/2`F)'1H:7,M/FUE<W-A9V5;)'!O
M<UU;)V%R<F%Y4VEZ92==.PH@("`@("`@("`@("`@("`@)'1H:7,M/FUE<W-A
M9V5;)')E9E]P;W-=6R=A<G)A>51Y<&4G72`]("8D=&AI<RT^;65S<V%G95LD
M<&]S75LG87)R87E4>7!E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!C:&%R86-T97)$871A"B`@("`@*B!E;&5M
M96YT(&-O;G1E;G0@:&%N9&QE<B!U<V5D('=I=&@@>&UL('!A<G-E<@H@("`@
M("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO
M;B!C:&%R86-T97)$871A*"1P87)S97(L("1D871A*0H@("`@>PH@("`@("`@
M("1P;W,@/2`D=&AI<RT^9&5P=&A?87)R87E;)'1H:7,M/F1E<'1H73L*("`@
M("`@("!I9B`H:7-S970H)'1H:7,M/FUE<W-A9V5;)'!O<UU;)V-D871A)UTI
M*2!["B`@("`@("`@("`@("1T:&ES+3YM97-S86=E6R1P;W-=6R=C9&%T82==
M("X]("1D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YM97-S86=E6R1P;W-=6R=C9&%T82==(#T@)&1A=&$["B`@("`@("`@?0H@
M("`@?0H*("`@("\J*@H@("`@("H@9V5T4F5S<&]N<V4*("`@("`J"B`@("`@
M*B!R971U<FYS(&%N(&%R<F%Y(&]F(')E<W!O;G-E<PH@("`@("H@869T97(@
M<&%R<VEN9R!A('-O87`@;65S<V%G92P@=7-E('1H:7,@=&\@9V5T('1H92!R
M97-P;VYS90H@("`@("H*("`@("`J($!R971U<FX@("!A<G)A>0H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=%)E<W!O
M;G-E*"D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/G)O;W1?<W1R
M=6-T6S!=*2`F)@H@("`@("`@("`@("`D=&AI<RT^<F]O=%]S=')U8W1;,%TI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YB=6EL9%)E<W!O;G-E*"1T
M:&ES+3YR;V]T7W-T<G5C=%LP72D["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")C;W5L9&XG="!B=6EL9"!R97-P
M;VYS92(I.PH@("`@?0H*("`@("\J*@H@("`@("H@9V5T2&5A9&5R<PH@("`@
M("H*("`@("`J(')E='5R;G,@86X@87)R87D@;V8@:&5A9&5R(')E<W!O;G-E
M<PH@("`@("H@869T97(@<&%R<VEN9R!A('-O87`@;65S<V%G92P@=7-E('1H
M:7,@=&\@9V5T('1H92!R97-P;VYS90H@("`@("H*("`@("`J($!R971U<FX@
M("!A<G)A>0H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N
M8W1I;VX@)F=E=$AE861E<G,H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D
M=&AI<RT^:&5A9&5R7W-T<G5C=%LP72D@)B8*("`@("`@("`@("`@)'1H:7,M
M/FAE861E<E]S=')U8W1;,%TI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YB=6EL9%)E<W!O;G-E*"1T:&ES+3YH96%D97)?<W1R=6-T6S!=*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%=E(&1O;B=T(&9A=6QT(&EF('1H97)E(&%R
M92!N;R!H96%D97)S('1H870@8V%N(&)E(&AA;F1L960*("`@("`@("`O+R!B
M>2!T:&4@87!P(&EF(&YE8V5S<V%R>2X*("`@("`@("!R971U<FX@;G5L;#L*
M("`@('T*"B`@("`O*BH*("`@("`J(&1E8V]D945N=&ET:65S"B`@("`@*@H@
M("`@("H@<F5M;W9E<R!E;G1I=&EE<R!F<F]M('1E>'0*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG"B`@("`@*B!`<F5T=7)N("`@<W1R:6YG"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@9&5C;V1E
M16YT:71I97,H)'1E>'0I"B`@("!["B`@("`@("`@)'1R86YS7W1B;"`](&%R
M<F%Y7V9L:7`H)'1H:7,M/F5N=&ET:65S*3L*("`@("`@("!R971U<FX@<W1R
M='(H)'1E>'0L("1T<F%N<U]T8FPI.PH@("`@?0H*?0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+W1O
M;VQS+V=E;G!R;WAY+G!H<```````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P-C(S(#$P-3$U-#,T,3,S(#`R,C<U,``@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`IE<G)O<E]R97!O<G1I
M;F<H15]!3$PI.PIR97%U:7)E7V]N8V4@)U-/05`O5U-$3"YP:'`G.PH*+RHJ
M"B`J(&=E;G!R;WAY"B`J"B`J(&$@8V]M;6%N9"!L:6YE('1O;VP@9F]R(&=E
M;F5R871I;F<@4T]!4"!P<F]X:65S(&9R;VT@5U-$3"!F:6QE<PH@*@H@*B!G
M96YP<F]X>2YP:'`@:'1T<#HO+W-I=&4O9F]O+G=S9&P@/B!F;V\N<&AP"B`J
M"B`J+PH*9G5N8W1I;VX@9&]?=W-D;"@D=7)I*2!["B`@("`D=W-D;"`])B!N
M97<@4T]!4%]74T1,*"1U<FDI.PH@("`@<')I;G0@)'=S9&PM/F=E;F5R871E
M06QL4')O>&EE<R@I.PI]"F5C:&\@(CP_<&AP7&Y<;G)E<75I<F5?;VYC92`G
M4T]!4"]#;&EE;G0N<&AP)SM<;EQN(CL*9&]?=W-D;"@D7U-%4E9%4ELG87)G
M=B==6S%=*3L*96-H;R`B7&X_/B(["C\^````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+V1U<F%T:6]N
M+G!H<```````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,S0P-B`Q
M,#4Q-30S-#$S,R`P,C(U,#8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`*+RH*:'1T<#HO+W=W=RYW,RYO<F<O5%(O
M>&UL<V-H96UA+3(O"@I;1&5F:6YI=&EO;CI=("`@9'5R871I;VX@<F5P<F5S
M96YT<R!A(&1U<F%T:6]N(&]F('1I;64N(%1H92!V86QU92!S<&%C92!O9@ID
M=7)A=&EO;B!I<R!A('-I>"UD:6UE;G-I;VYA;"!S<&%C92!W:&5R92!T:&4@
M8V]O<F1I;F%T97,@9&5S:6=N871E('1H90I'<F5G;W)I86X@>65A<BP@;6]N
M=&@L(&1A>2P@:&]U<BP@;6EN=71E+"!A;F0@<V5C;VYD(&-O;7!O;F5N=',*
M9&5F:6YE9"!I;B`@-2XU+C,N,B!O9B!;25-/(#@V,#%=+"!R97-P96-T:79E
M;'DN(%1H97-E(&-O;7!O;F5N=',@87)E"F]R9&5R960@:6X@=&AE:7(@<VEG
M;FEF:6-A;F-E(&)Y('1H96ER(&]R9&5R(&]F(&%P<&5A<F%N8V4@:2YE+B!A
M<R!Y96%R+`IM;VYT:"P@9&%Y+"!H;W5R+"!M:6YU=&4L(&%N9"!S96-O;F0N
M(`H*,RXR+C8N,2!,97AI8V%L(')E<')E<V5N=&%T:6]N"E1H92!L97AI8V%L
M(')E<')E<V5N=&%T:6]N(&9O<B!D=7)A=&EO;B!I<R!T:&4@6TE33R`X-C`Q
M72!E>'1E;F1E9`IF;W)M870@4&Y9;B!-;D14;D@@;DUN4RP@=VAE<F4@;ED@
M<F5P<F5S96YT<R!T:&4@;G5M8F5R(&]F"GEE87)S+"!N32!T:&4@;G5M8F5R
M(&]F(&UO;G1H<RP@;D0@=&AE(&YU;6)E<B!O9B!D87ES+"`G5"<@:7,@=&AE
M"F1A=&4O=&EM92!S97!A<F%T;W(L(&Y(('1H92!N=6UB97(@;V8@:&]U<G,L
M(&Y-('1H92!N=6UB97(@;V8*;6EN=71E<R!A;F0@;E,@=&AE(&YU;6)E<B!O
M9B!S96-O;F1S+B!4:&4@;G5M8F5R(&]F('-E8V]N9',*8V%N(&EN8VQU9&4@
M9&5C:6UA;"!D:6=I=',@=&\@87)B:71R87)Y('!R96-I<VEO;BX*"E1H92!V
M86QU97,@;V8@=&AE(%EE87(L($UO;G1H+"!$87DL($AO=7(@86YD($UI;G5T
M97,@8V]M<&]N96YT<PIA<F4@;F]T(')E<W1R:6-T960@8G5T(&%L;&]W(&%N
M(&%R8FET<F%R>2!I;G1E9V5R+B!3:6UI;&%R;'DL('1H90IV86QU92!O9B!T
M:&4@4V5C;VYD<R!C;VUP;VYE;G0@86QL;W=S(&%N(&%R8FET<F%R>2!D96-I
M;6%L+@I4:'5S+"!T:&4@;&5X:6-A;"!R97!R97-E;G1A=&EO;B!O9B!D=7)A
M=&EO;B!D;V5S(&YO="!F;VQL;W<@=&AE"F%L=&5R;F%T:79E(&9O<FUA="!O
M9B`@-2XU+C,N,BXQ(&]F(%M)4T\@.#8P,5TN"@I!;B!O<'1I;VYA;"!P<F5C
M961I;F<@;6EN=7,@<VEG;B`H)RTG*2!I<R!A;&QO=V5D+"!T;R!I;F1I8V%T
M92!A"FYE9V%T:79E(&1U<F%T:6]N+B!)9B!T:&4@<VEG;B!I<R!O;6ET=&5D
M(&$@<&]S:71I=F4@9'5R871I;VX@:7,*:6YD:6-A=&5D+B!3964@86QS;R!)
M4T\@.#8P,2!$871E(&%N9"!4:6UE($9O<FUA=',@*$0I+B`*"D9O<B!E>&%M
M<&QE+"!T;R!I;F1I8V%T92!A(&1U<F%T:6]N(&]F(#$@>65A<BP@,B!M;VYT
M:',L(#,@9&%Y<RP*,3`@:&]U<G,L(&%N9"`S,"!M:6YU=&5S+"!O;F4@=V]U
M;&0@=W)I=&4Z(%`Q63)-,T14,3!(,S!-+@I/;F4@8V]U;&0@86QS;R!I;F1I
M8V%T92!A(&1U<F%T:6]N(&]F(&UI;G5S(#$R,"!D87ES(&%S.B`M4#$R,$0N
M(`H*4F5D=6-E9"!P<F5C:7-I;VX@86YD('1R=6YC871E9"!R97!R97-E;G1A
M=&EO;G,@;V8@=&AI<R!F;W)M870*87)E(&%L;&]W960@<')O=FED960@=&AE
M>2!C;VYF;W)M('1O('1H92!F;VQL;W=I;F<Z(`H*268@=&AE(&YU;6)E<B!O
M9B!Y96%R<RP@;6]N=&AS+"!D87ES+"!H;W5R<RP@;6EN=71E<RP@;W(@<V5C
M;VYD<PII;B!A;GD@97AP<F5S<VEO;B!E<75A;',@>F5R;RP@=&AE(&YU;6)E
M<B!A;F0@:71S(&-O<G)E<W!O;F1I;F<*9&5S:6=N871O<B`J;6%Y*B!B92!O
M;6ET=&5D+B!(;W=E=F5R+"!A="!L96%S="!O;F4@;G5M8F5R(&%N9`II=',@
M9&5S:6=N871O<B`J;75S="H@8F4@<')E<V5N="X@"E1H92!S96-O;F1S('!A
M<G0@*FUA>2H@:&%V92!A(&1E8VEM86P@9G)A8W1I;VXN(`I4:&4@9&5S:6=N
M871O<B`G5"<@<VAA;&P@8F4@86)S96YT(&EF(&%L;"!O9B!T:&4@=&EM92!I
M=&5M<R!A<F4@86)S96YT+@I4:&4@9&5S:6=N871O<B`G4"<@;75S="!A;'=A
M>7,@8F4@<')E<V5N="X@"D9O<B!E>&%M<&QE+"!0,3,T-UDL(%`Q,S0W32!A
M;F0@4#%9,DU4,D@@87)E(&%L;"!A;&QO=V5D.R!0,%DQ,S0W30IA;F0@4#!9
M,3,T-TTP1"!A<F4@86QL;W=E9"X@4"TQ,S0W32!I<R!N;W0@86QL;W=E9"!A
M;'1H;W5G:"`M4#$S-#=-"FES(&%L;&]W960N(%`Q63)-5"!I<R!N;W0@86QL
M;W=E9"X@"@HJ+PH*+RH@=&AI<R!I<R!O;FQY(&%N(&%P<F]X:6UA=&EO;B!O
M9B!D=7)A=&EO;BP@;6]R92!W;W)K('-T:6QL('1O(&1O+@H@("!S964@86)O
M=F4@<V-H96UA('5R;"!F;W(@;6]R92!I;F9O(&]N(&1U<F%T:6]N"B`@(`H@
M("!43T1/.B!F:6=U<F4@;W5T(&)E<W0@87!R;WAI;6%T:6]N(&9O<B!Y96%R
M(&%N9"!M;VYT:"!C;VYV97)S:6]N('1O('-E8V]N9',**B\*("`@"B1E<F5G
M7V1U<F%T:6]N(#T@)R@M*3]0*%LP+3E=*UDI/RA;,"TY72M-*3\H6S`M.5TK
M1"D_5#\H6S`M.5TK2"D_*%LP+3E=*TTI/RA;,"TY72M3*3\G.PIC;&%S<R!3
M3T%07U1Y<&5?9'5R871I;VX*>PH@("`@+R\@9F]R;6%T(%!N66Y-;D14;DAN
M36Y3"B`@("!F=6YC=&EO;B!U;FEX7W1O7V1U<F%T:6]N*"1S96-O;F1S*2![
M"B`@("`@("`@<F5T=7)N(%-/05!?5'EP95]D=7)A=&EO;CHZ9V5T9'5R871I
M;VXH)'-E8V]N9',I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!M;V0H)&$L
M("1B+"`F)&0L("8D<BD@>PH@("`@("`@("1D(#T@9FQO;W(H("1A("\@)&(@
M*3L*("`@("`@("`D<B`]("1A("4@)&(["B`@("!]"B`@("`*("`@(&9U;F-T
M:6]N(&=E=&1U<F%T:6]N*"1S96-O;F1S*2!["B`@("`@("`@)&YE9R`]("<G
M.PH@("`@("`@(&EF("@D<V5C;VYD<R`\(#`I('L*("`@("`@("`@("`@)&YE
M9R`]("<M)SL*("`@("`@("`@("`@)'-E8V]N9',@/2`D<V5C;VYD<R`J("TQ
M.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D7VUI(#T@-C`["B`@("`@
M("`@)%]H(#T@)%]M:2`J(#8P.PH@("`@("`@("1?9"`]("1?:"`J(#(T.PH@
M("`@("`@("\O(%A86"!H;W<@9&\@=V4@<')O<&5R;'D@:&%N9&QE(&UO;G1H
M(&%N9"!Y96%R('9A;'5E<S\*("`@("`@("`D7VT@/2`D7V0@*B`S,#L*("`@
M("`@("`D7WD@/2`D7V0@*B`S-C4["@H@("`@("`@(%-/05!?5'EP95]D=7)A
M=&EO;CHZ;6]D*"1S96-O;F1S+"`D7WDL("1Y+"`D<V5C;VYD<RD["B`@("`@
M("`@4T]!4%]4>7!E7V1U<F%T:6]N.CIM;V0H)'-E8V]N9',L("1?;2P@)&TL
M("1S96-O;F1S*3L*("`@("`@("!33T%07U1Y<&5?9'5R871I;VXZ.FUO9"@D
M<V5C;VYD<RP@)%]D+"`D9"P@)'-E8V]N9',I.PH@("`@("`@(%-/05!?5'EP
M95]D=7)A=&EO;CHZ;6]D*"1S96-O;F1S+"`D7V@L("1H+"`D<V5C;VYD<RD[
M"B`@("`@("`@4T]!4%]4>7!E7V1U<F%T:6]N.CIM;V0H)'-E8V]N9',L("1?
M;6DL("1M:2P@)',I.PH@("`@("`@(`H@("`@("`@("1D=7)A=&EO;B`]("1N
M96<N)U`G.PH@("`@("`@(&EF("@D>2D@)&1U<F%T:6]N("X]("1Y+B=9)SL*
M("`@("`@("!I9B`H)&TI("1D=7)A=&EO;B`N/2`D;2XG32<["B`@("`@("`@
M:68@*"1D*2`D9'5R871I;VX@+CT@)&0N)T0G.PH@("`@("`@(&EF("@D:"!\
M?"`D;6D@?'P@)',I("1D=7)A=&EO;B`N/2=4)SL*("`@("`@("!I9B`H)&@I
M("1D=7)A=&EO;B`N/2`D:"XG2"<["B`@("`@("`@:68@*"1M:2D@)&1U<F%T
M:6]N("X]("1M:2XG32<["B`@("`@("`@:68@*"1S*2`D9'5R871I;VX@+CT@
M)',N)U,G.PH@("`@("`@(&EF("@D9'5R871I;VX@/3T@)U`G('Q\("1D=7)A
M=&EO;B`]/2`G+5`G*2`D9'5R871I;VX@/2`G4%0P4R<["B`@("`@("`@<F5T
M=7)N("1D=7)A=&EO;CL*("`@('T*("`@(`H@("`@9G5N8W1I;VX@;6MD=7)A
M=&EO;B@D;BP@)%DL("1-;RP@)$0L("1(+"`D36DL("13*2!["B`@("`@("`@
M)%]M:2`](#8P.PH@("`@("`@("1?:"`]("1?;6D@*B`V,#L*("`@("`@("`D
M7V0@/2`D7V@@*B`R-#L*("`@("`@("`O+R!86%@@:&]W(&1O('=E('!R;W!E
M<FQY(&AA;F1L92!M;VYT:"!A;F0@>65A<B!V86QU97,_"B`@("`@("`@)%]M
M(#T@)%]D("H@,S`["B`@("`@("`@)%]Y(#T@)%]D("H@,S8U.PH@("`@("`@
M(`H@("`@("`@("1S96,@/2`D62`J("1?>2`K("1-;R`J("1?;2`K("1$("H@
M)%]D("L@)$@@*B`D7V@@*R`D36D@*B`D7VUI("L@)%,["B`@("`@("`@:68@
M*"1N(#T]("<M)RD@)'-E8R`]("1S96,@*B`M,3L*("`@("`@("!R971U<FX@
M)'-E8SL*("`@('T*("`@(`H@("`@9G5N8W1I;VX@9'5R871I;VY?=&]?=6YI
M>"@D9'5R871I;VXI('L*("`@("`@("!G;&]B86P@)&5R96=?9'5R871I;VX[
M"B`@("`@("`@:68@*&5R96<H)&5R96=?9'5R871I;VXL)&1U<F%T:6]N+"1R
M96=S*2D@>PH@("`@("`@("`@("!R971U<FX@4T]!4%]4>7!E7V1U<F%T:6]N
M.CIM:V1U<F%T:6]N*"1R96=S6S%=+"`D<F5G<ULR72P@)')E9W-;,UTL("1R
M96=S6S1=+"`D<F5G<ULU72P@)')E9W-;-ETL("1R96=S6S==*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N($9!3%-%.PH@("`@?0H@("`@"B`@("!F=6YC
M=&EO;B!I<U]D=7)A=&EO;B@D9'5R871I;VXI('L*("`@("`@("!G;&]B86P@
M)&5R96=?9'5R871I;VX["B`@("`@("`@<F5T=7)N(&5R96<H)&5R96=?9'5R
M871I;VXL)&1U<F%T:6]N+"1R96=S*3L*("`@('T*("`@(`H@("`@9G5N8W1I
M;VX@7W1E<W0H)'1I;64I('L*("`@("`@("!I9B`H4T]!4%]4>7!E7V1U<F%T
M:6]N.CII<U]D=7)A=&EO;B@D=&EM92DI('L*("`@("`@("`@("`@)'0@/2!3
M3T%07U1Y<&5?9'5R871I;VXZ.F1U<F%T:6]N7W1O7W5N:7@H)'1I;64I.PH@
M("`@("`@("`@("!E8VAO(")$=7)A=&EO;CH@)'1I;64@:7,@(BXD="XB('-E
M8V]N9'-<;B(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'0@/2!3
M3T%07U1Y<&5?9'5R871I;VXZ.G5N:7A?=&]?9'5R871I;VXH)'1I;64I.PH@
M("`@("`@("`@("!E8VAO(")396-O;F1S.B`D=&EM92!I<R`B+B1T+B(@9'5R
M871I;VY<;B(["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=#L*("`@('T*
M("`@(`H@("`@9G5N8W1I;VX@861D*"1D,2P@)&0R*2!["B`@("`@("`@)',Q
M(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T;U]U;FEX*"1D,2D[
M"B`@("`@("`@)',R(#T@4T]!4%]4>7!E7V1U<F%T:6]N.CID=7)A=&EO;E]T
M;U]U;FEX*"1D,BD["B`@("`@("`@<F5T=7)N(%-/05!?5'EP95]D=7)A=&EO
M;CHZ=6YI>%]T;U]D=7)A=&EO;B@D<S$@*R`D<S(I.PH@("`@?0H@("`@"B`@
M("!F=6YC=&EO;B!S=6)T<F%C="@D9#$L("1D,BD@>PH@("`@("`@("1S,2`]
M(%-/05!?5'EP95]D=7)A=&EO;CHZ9'5R871I;VY?=&]?=6YI>"@D9#$I.PH@
M("`@("`@("1S,B`](%-/05!?5'EP95]D=7)A=&EO;CHZ9'5R871I;VY?=&]?
M=6YI>"@D9#(I.PH@("`@("`@(')E='5R;B!33T%07U1Y<&5?9'5R871I;VXZ
M.G5N:7A?=&]?9'5R871I;VXH)',Q("T@)',R*3L*("`@('T*"GT*"B\J('1E
M<W1S("HO"@HD="`](%-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H)U`Q63)-
M,T14,3!(,S!-)RD["E-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H)'0I.PHD
M="`](%-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H)RU0,3(P1"<I.PI33T%0
M7U1Y<&5?9'5R871I;VXZ.E]T97-T*"1T*3L*"B\O(&1U<F%T:6]N('-I;F-E
M(#$Y-S`*)'0@/2!33T%07U1Y<&5?9'5R871I;VXZ.E]T97-T*'1I;64H*2D[
M"E-/05!?5'EP95]D=7)A=&EO;CHZ7W1E<W0H)'0I.PH*<')I;G0@(D%D9"!S
M:&]U;&0@8F4@4%0P4SH@(BY33T%07U1Y<&5?9'5R871I;VXZ.F%D9"@G+5`Q
M,C!$)RPG4#1-)RDN(EQN(CL*<')I;G0@(E-U8G1R86-T('-H;W5L9"!B92!0
M5#!3.B`B+E-/05!?5'EP95]D=7)A=&EO;CHZ<W5B=')A8W0H)U`Q,C!$)RPG
M4#1-)RDN(EQN(CL*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1Y<&4O:&5X0FEN87)Y+G!H
M<```````````````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-3$R(#$P-3$U
M-#,T,3,S(#`R,C8P-P`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O
M(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@
M("!\"B\O('P@075T:&]R<SH@1&EE=')I8V@@07EA;&$@/&1I971R:6-H0&=A
M;G@T+F-O;3X@3W)I9VEN86P@075T:&]R("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!H97A":6YA<GDN<&AP
M+'8@,2XV(#(P,#4O,#,O,3`@,C,Z,38Z,SD@>75N;W-H($5X<"`D"B\O"F-L
M87-S(%-/05!?5'EP95]H97A":6YA<GD*>PH@("`@9G5N8W1I;VX@=&]?8FEN
M*"1V86QU92D*("`@('L*("`@("`@("`D;&5N(#T@<W1R;&5N*"1V86QU92D[
M"B`@("`@("`@<F5T=7)N('!A8VLH)T@G("X@)&QE;BP@)'9A;'5E*3L*("`@
M('T*("`@(&9U;F-T:6]N('1O7VAE>"@D=F%L=64I"B`@("!["B`@("`@("`@
M<F5T=7)N(&)I;C)H97@H)'9A;'5E*3L*("`@('T*("`@(&9U;F-T:6]N(&ES
M7VAE>&)I;B@D=F%L=64I"B`@("!["B`@("`@("`@(R!F:7)S="!S964@:68@
M=&AE<F4@87)E(&%N>2!I;G9A;&ED(&-H87)S"B`@("`@("`@)&P@/2!S=')L
M96XH)'9A;'5E*3L*"B`@("`@("`@:68@*"1L(#P@,2!\?"!S=')S<&XH)'9A
M;'5E+"`G,#$R,S0U-C<X.4%"0T1%1F%B8V1E9B<I("$]("1L*2!R971U<FX@
M1D%,4T4["@H@("`@("`@("1B:6X@/2!33T%07U1Y<&5?:&5X0FEN87)Y.CIT
M;U]B:6XH)'9A;'5E*3L*("`@("`@("`D:&5X(#T@4T]!4%]4>7!E7VAE>$)I
M;F%R>3HZ=&]?:&5X*"1B:6XI.PH@("`@("`@(')E='5R;B!S=')C87-E8VUP
M*"1V86QU92P@)&AE>"D@/3T@,#L*("`@('T*?0H*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4>7!E+V1A=&54:6UE+G!H<```````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q,C4T,"`Q,#4Q-30S-#$S
M,R`P,C(T,3,`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P
M,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@
M<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE
M(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@
M("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R
M96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B
M;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA
M;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO
M+R!\($%U=&AO<G,Z($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC
M;VT^($]R:6=I;F%L($%U=&AO<B`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@9&%T951I;64N<&AP+'8@,2XW
M(#(P,#4O,#,O,3`@,C,Z,38Z,SD@>75N;W-H($5X<"`D"B\O"F-L87-S(%-/
M05!?5'EP95]D871E5&EM90I["B`@("!V87(@)&5R96=?:7-O.#8P,2`]("<H
M+3];,"TY77LT?2DM*%LP+3E=>S)]*2TH6S`M.5U[,GTI5"A;,"TY77LR?2DZ
M*%LP+3E=>S)]*3HH6S`M.5U[,GTI*%PN6S`M.5TJ*3\H6GQ;*UPM75LP+3E=
M>S1]?%LK7"U=6S`M.5U[,GTZ6S`M.5U[,GTI/R<["B`@("`@("`@(R(H+3];
M,"TY77LT?2DM(BX@("\O(&-E;G1U<FEE<R`F('EE87)S($-#65DM"B`@("`@
M("`@(R(H6S`M.5U[,GTI+2(N("`O+R!M;VYT:',@34TM"B`@("`@("`@(R(H
M6S`M.5U[,GTI(BX@("`@+R\@9&%Y<R!$1`H@("`@("`@(",B5"(N("`@("`@
M("`@("`@("`@("`@("`O+R!S97!A<F%T;W(@5`H@("`@("`@(",B*%LP+3E=
M>S)]*3HB+B`@+R\@:&]U<G,@:&@Z"B`@("`@("`@(R(H6S`M.5U[,GTI.B(N
M("`O+R!M:6YU=&5S(&UM.@H@("`@("`@(",B*%LP+3E=>S)]*2A<+ELP+3E=
M*BD_(BX@+R\@<V5C;VYD<R!S<RYS<RXN+@H@("`@("`@(",B*%I\6RM<+5U;
M,"TY77LT?7Q;*UPM75LP+3E=>S)].ELP+3E=>S)]*3\B.R`O+R!:('1O(&EN
M9&EC871E(%540RP@+2\K2$@Z34TZ4U,N4U,N+BX@9F]R(&QO8V%L('1Z)W,*
M("`@("`@("`C(&EF(&YO(#AT:"!R96<@*%HI(&%S<W5M97,@551#"B`@("!V
M87(@)'1I;65S=&%M<"`]("TQ.PH@("`@"B`@("!F=6YC=&EO;B!33T%07U1Y
M<&5?9&%T951I;64H)&1A=&4@/2`M,2D*("`@('L*("`@("`@("!I9B`H)&1A
M=&4@/3T@+3$I("1D871E(#T@=&EM92@I.PH*("`@("`@("!I9B`H9V5T='EP
M92@D9&%T92D@/3T@)VEN=&5G97(G*2!["B`@("`@("`@("`@("1T:&ES+3YT
M:6UE<W1A;7`@/2`D9&%T93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^=&EM97-T86UP(#T@)'1H:7,M/G1O56YI>'1I;64H)&1A=&4I
M.PH@("`@("`@('T*("`@('T*("`@(`H@("`@9G5N8W1I;VX@=&]33T%0*"1D
M871E(#T@3E5,3"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G1O551#
M*"1D871E*3L*("`@('T*("`@(`H@("`@9G5N8W1I;VX@=&]3=')I;F<H)'1I
M;65S=&%M<"`](#`I"B`@("!["B`@("`@("`@:68@*"$D=&EM97-T86UP*2`D
M=&EM97-T86UP(#T@)'1H:7,M/G1I;65S=&%M<#L*("`@("`@("!I9B`H)'1I
M;65S=&%M<"`\(#`I(')E='5R;B`P.PH*("`@("`@("!R971U<FX@9&%T92@G
M62UM+61<5$@Z:3IS3R<L)'1I;65S=&%M<"D["B`@("!]"B`@("`*("`@(&9U
M;F-T:6]N(%]S<&QI="@D9&%T97-T<BD*("`@('L*("`@("`@("!I9B`H(21D
M871E<W1R*0H@("`@("`@("`@("`D9&%T97-T<B`]("1T:&ES+3YT;U-T<FEN
M9R@I.PH@("`@("`@(&5L<V4@:68@*&=E='1Y<&4H)&1A=&5S='(I(#T]("=I
M;G1E9V5R)RD*("`@("`@("`@("`@)&1A=&5S='(@/2`D=&AI<RT^=&]3=')I
M;F<H)&1A=&5S='(I.PH@("`@("`@("`@("`*("`@("`@("!I9B`H97)E9R@D
M=&AI<RT^97)E9U]I<V\X-C`Q+"1D871E<W1R+"1R96=S*2D@>PH@("`@("`@
M("`@("!I9B`H)')E9W-;.%T@(3T@)R<@)B8@)')E9W-;.%T@(3T@)UHG*2![
M"B`@("`@("`@("`@("`@("`D;W`@/2!S=6)S='(H)')E9W-;.%TL,"PQ*3L*
M("`@("`@("`@("`@("`@("1H(#T@<W5B<W1R*"1R96=S6SA=+#$L,BD["B`@
M("`@("`@("`@("`@("!I9B`H<W1R<W1R*"1R96=S6SA=+"<Z)RDI('L*("`@
M("`@("`@("`@("`@("`@("`D;2`]('-U8G-T<B@D<F5G<ULX72PT+#(I.PH@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D
M;2`]('-U8G-T<B@D<F5G<ULX72PS+#(I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*"1O<"`]/2`G*R<I('L*("`@("`@("`@("`@
M("`@("`@("`D<F5G<ULT72`]("1R96=S6S1=("T@)&@["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1R96=S6S1=(#P@,"D@)')E9W-;-%T@*ST@,C0["B`@
M("`@("`@("`@("`@("`@("`@)')E9W-;-5T@/2`D<F5G<ULU72`M("1M.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D<F5G<ULU72`\(#`I("1R96=S6S5=
M("L](#8P.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`D<F5G<ULT72`]("1R96=S6S1=("L@)&@["B`@("`@("`@("`@
M("`@("`@("`@:68@*"1R96=S6S1=(#X@,C,I("1R96=S6S1=("T](#(T.PH@
M("`@("`@("`@("`@("`@("`@("1R96=S6S5=(#T@)')E9W-;-5T@*R`D;3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)')E9W-;-5T@/B`U.2D@)')E9W-;
M-5T@+3T@-C`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("`@("`@<F5T=7)N("1R96=S.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@1D%,4T4["B`@("!]"B`@("`*("`@(&9U;F-T:6]N('1O551#*"1D871E
M<W1R(#T@3E5,3"D*("`@('L*("`@("`@("`D<F5G<R`]("1T:&ES+3Y?<W!L
M:70H)&1A=&5S='(I.PH*("`@("`@("!I9B`H)')E9W,I('L*("`@("`@("`@
M("`@<F5T=7)N('-P<FEN=&8H)R4P-&0M)3`R9"TE,#)D5"4P,F0Z)3`R9#HE
M,#)D6B<L)')E9W-;,5TL)')E9W-;,ETL)')E9W-;,UTL)')E9W-;-%TL)')E
M9W-;-5TL)')E9W-;-ETI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("<G
M.PH@("`@?0H*("`@(&9U;F-T:6]N('1O56YI>'1I;64H)&1A=&5S='(@/2!.
M54Q,*0H@("`@>PH@("`@("`@("1R96=S(#T@)'1H:7,M/E]S<&QI="@D9&%T
M97-T<BD["B`@("`@("`@:68@*"1R96=S*2!["B`@("`@("`@("`@(')E='5R
M;B!S=')T;W1I;64H(B1R96=S6S%=+21R96=S6S)=+21R96=S6S-=("1R96=S
M6S1=.B1R96=S6S5=.B1R96=S6S9=6B(I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@+3$["B`@("!]"@H@("`@9G5N8W1I;VX@8V]M<&%R92@D9&%T93$L
M("1D871E,B`]($Y53$PI"B`@("!["B`@("`@("`@:68@*"1D871E,B`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("`D9&%T93(@/2`D9&%T93$["B`@("`@("`@
M("`@("1D871E,2`]("1T:&ES+3YT:6UE<W1A;7`["B`@("`@("`@?0H@("`@
M("`@(&EF("@A:7-?;G5M97)I8R@D9&%T93$I*0H@("`@("`@("`@("`D9&%T
M93$@/2`D=&AI<RT^=&]5;FEX=&EM92@D9&%T93$I.PH@("`@("`@(&EF("@A
M:7-?;G5M97)I8R@D9&%T93(I*0H@("`@("`@("`@("`D9&%T93(@/2`D=&AI
M<RT^=&]5;FEX=&EM92@D9&%T93(I.PH@("`@("`@(&EF("@D9&%T93$@(3T@
M+3$@)B8@)&1A=&4R("$]("TQ*2!R971U<FX@)&1A=&4Q("T@)&1A=&4R.PH@
M("`@("`@(')E='5R;B`M,3L*("`@('T*("`@(`H@("`@9G5N8W1I;VX@7W1E
M<W0H)&]R:6<@/2`G,C`P,2TP-"TR-50P.3HS,3HT,2TP-S`P)RD*("`@('L*
M("`@("`@("`D=71C(#T@)'1H:7,M/G1O551#*"1O<FEG*3L*("`@("`@("`D
M=',Q(#T@)'1H:7,M/G1O56YI>'1I;64H)&]R:6<I.PH@("`@("`@("1T<S(@
M/2`D=&AI<RT^=&]5;FEX=&EM92@D=71C*3L*("`@("`@("`D8C$@/2`D=&AI
M<RT^=&]3=')I;F<H)'1S,2D["B`@("`@("`@)&(R(#T@)'1H:7,M/G1O4W1R
M:6YG*"1T<S(I.PH@("`@("`@('!R:6YT(")O<FEG.B`D;W)I9UQN(CL*("`@
M("`@("!P<FEN="`B;W)I9R!T;U540SH@)'5T8UQN(CL*("`@("`@("!P<FEN
M="`B;W)I9R!T<SH@)'1S,5QN(CL*("`@("`@("!P<FEN="`B=71C('1S.B`D
M=',R7&XB.PH@("`@("`@('!R:6YT(")O<FEG('1S(&)A8VLZ("1B,5QN(CL*
M("`@("`@("!P<FEN="`B=71C('1S(&)A8VLZ("1B,EQN(CL*("`@("`@("!I
M9B`H)&(Q("$]("1O<FEG('Q\("1B,B`A/2`D;W)I9RD@>PH@("`@("`@("`@
M("!E8VAO(")%<G)O<B!I;B!I<V\X-C`Q(&-O;G9E<G-I;VYS7&XB.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&5C:&\@(F1A=&54:6UE($]+7&XB
M.PH@("`@("`@('T*("`@('T*?0H*(R!T:&5S92!S:&]U;&0@86QL(&UA=&-H
M"B,D9"`](&YE=R!33T%07U1Y<&5?9&%T951I;64H*3L*(V5C:&\@)&0M/F-O
M;7!A<F4H(C(P,#$M,#0M,C54,C`Z,S$Z-#%:(BPB,C`P,2TP-"TR-50R,#HS
M,3HT,5HB*2XB7&XB.PHC96-H;R`D9"T^8V]M<&%R92@B,C`P,2TP-"TR-50R
M,#HS,3HT,5HB+"(R,#`Q+3`T+3(U5#$R.C,Q.C0Q+3`X,#`B*2XB7&XB.PHC
M96-H;R`D9"T^8V]M<&%R92@B,C`P,2TP-"TR-50R,#HS,3HT,5HB+"(R,#`Q
M+3`T+3(U5#$R.C,Q.C0Q+3`X.C`P(BDN(EQN(CL*"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!
M4"]397)V97(O5$-0+G!H<```````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P-C<Q-2`Q,#4Q-30S-#$S,R`P,C$V-#$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+RHJ"B`J(%1H
M:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(%1#4"!33T%0('-E
M<G9E<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y3
M13H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W:71H
M('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@879A
M:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U"B`J
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W;W)L
M9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@
M("`@4T]!4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N94!#
M87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&-O<'ER
M:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,:6-E
M;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+G!H
M<"<["@HO*BH*("H@4T]!4"!397)V97(@0VQA<W,@=&AA="!I;7!L96UE;G1S
M(&$@5$-0(%-/05`@4V5R=F5R+@H@*B!H='1P.B\O=W=W+G!O8VME='-O87`N
M8V]M+W-P96-S+W-M='!B:6YD:6YG+PH@*@H@*B!4:&ES(&-L87-S(&]V97)R
M:61E<R!T:&4@9&5F875L="!(5%10('-E<G9E<BP@<')O=FED:6YG('1H92!A
M8FEL:71Y('1O"B`J(&%C8V5P="!S;V-K970@8V]N;F5C=&EO;G,@86YD(&5X
M96-U=&4@4T]!4"!C86QL<RX*("H*("H@5$]$3SH*("H@("!U<V4@3F5T7U-O
M8VME=`H@*B`@(&EM<&QE;65N="!S;VUE('-E8W5R:71Y('-C:&5M90H@*B`@
M(&EM<&QE;65N="!S=7!P;W)T(&9O<B!A='1A8VAM96YT<PH@*@H@*B!`86-C
M97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H;W(@("!3
M:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!4%]3
M97)V97)?5$-0(&5X=&5N9',@4T]!4%]397)V97(@>PH*("`@('9A<B`D:&5A
M9&5R<R`](&%R<F%Y*"D["B`@("!V87(@)&QO8V%L861D<CL*("`@('9A<B`D
M<&]R=#L*("`@('9A<B`D;&ES=&5N.PH@("`@=F%R("1R975S93L*"B`@("!F
M=6YC=&EO;B!33T%07U-E<G9E<E]40U`H)&QO8V%L861D<B`]("<Q,C<N,"XP
M+C$G+"`D<&]R="`](#$P,#`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1L:7-T96X@/2`U+"`D<F5U<V4@/2!T<G5E*0H@("`@>PH@("`@("`@
M('!A<F5N=#HZ4T]!4%]397)V97(H*3L*("`@("`@("`D=&AI<RT^;&]C86QA
M9&1R(#T@)&QO8V%L861D<CL*("`@("`@("`D=&AI<RT^<&]R="`]("1P;W)T
M.PH@("`@("`@("1T:&ES+3YL:7-T96X@/2`D;&ES=&5N.PH@("`@("`@("1T
M:&ES+3YR975S92`]("1R975S93L*("`@('T*"B`@("!F=6YC=&EO;B!R=6XH
M*0H@("`@>PH@("`@("`@(&EF("@H)'-O8VL@/2!S;V-K971?8W)E871E*$%&
M7TE.150L(%-/0TM?4U1214%-+"`P*2D@/"`P*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=S;V-K971?8W)E871E*"D@
M9F%I;&5D+B!296%S;VXZ("<@+B!S;V-K971?<W1R97)R;W(H)'-O8VLI*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YR975S92`F)@H@("`@("`@
M("`@("`A0'-O8VME=%]S971O<'0H)'-O8VLL(%-/3%]33T-+150L(%-/7U)%
M55-%041$4BP@,2DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H)W-O8VME=%]S971O<'0H*2!F86EL960N(%)E87-O;CH@
M)R`N('-O8VME=%]S=')E<G)O<BAS;V-K971?;&%S=%]E<G)O<B@D<V]C:RDI
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D<F5T(#T@<V]C:V5T7V)I;F0H
M)'-O8VLL("1T:&ES+3YL;V-A;&%D9'(L("1T:&ES+3YP;W)T*2D@/"`P*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=S
M;V-K971?8FEN9"@I(&9A:6QE9"X@4F5A<V]N.B`G("X@<V]C:V5T7W-T<F5R
M<F]R*"1R970I*3L*("`@("`@("!]"B`@("`@("`@:68@*"@D<F5T(#T@<V]C
M:V5T7VQI<W1E;B@D<V]C:RP@)'1H:7,M/FQI<W1E;BDI(#P@,"D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G<V]C:V5T
M7VQI<W1E;B@I(&9A:6QE9"X@4F5A<V]N.B`G("X@<V]C:V5T7W-T<F5R<F]R
M*"1R970I*3L*("`@("`@("!]"@H@("`@("`@('=H:6QE("AT<G5E*2!["B`@
M("`@("`@("`@("1D871A(#T@;G5L;#L*("`@("`@("`@("`@:68@*"@D;7-G
M<V]C:R`]('-O8VME=%]A8V-E<'0H)'-O8VLI*2`\(#`I('L*("`@("`@("`@
M("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)W-O8VME=%]A8V-E<'0H
M*2!F86EL960N(%)E87-O;CH@)R`N('-O8VME=%]S=')E<G)O<B@D;7-G<V]C
M:RDI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@=VAI;&4@*"1B=68@/2!S;V-K971?<F5A9"@D;7-G<V]C:RP@
M.#$Y,BDI('L*("`@("`@("`@("`@("`@(&EF("@A)&)U9B`]('1R:6TH)&)U
M9BDI('L*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1D871A("X]("1B=68["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&EF("@D9&%T82D@>PH@("`@("`@("`@
M("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/G-E<G9I8V4H)&1A=&$I.PH@("`@
M("`@("`@("`@("`@+RH@5W)I=&4@=&\@=&AE('-O8VME="X@*B\*("`@("`@
M("`@("`@("`@(&EF("@A<V]C:V5T7W=R:71E*"1M<V=S;V-K+"`D<F5S<&]N
M<V4L('-T<FQE;B@D<F5S<&]N<V4I*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=%<G)O<B!S96YD:6YG
M(')E<W!O;G-E(&1A=&$@<F5A<V]N("<@+B!S;V-K971?<W1R97)R;W(H*2D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M('-O8VME=%]C;&]S92`H)&US9W-O8VLI.PH@("`@("`@('T*"B`@("`@("`@
M<V]C:V5T7V-L;W-E("@D<V]C:RD["B`@("!]"@H@("`@9G5N8W1I;VX@<V5R
M=FEC92@F)&1A=&$I"B`@("!["B`@("`@("`@+RH@5$]$3SH@=V4@;F5E9"!T
M;R!H86YD;&4@871T86-H;65N=',@<V]M96AO=RX@*B\*("`@("`@("!R971U
M<FX@)'1H:7,M/G!A<G-E4F5Q=65S="@D9&%T82P@)&%T=&%C:&UE;G1S*3L*
M("`@('T*?0H`````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-/
M05`O4V5R=F5R+T5M86EL+G!H<```````````````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,38U,3<@,3`U,34T,S0Q,S,@,#(R,C0S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"B\J*@H@*B!4
M:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@9F]R('1H92!E;6%I;"!33T%0
M('-E<G9E<BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#
M14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@268@>6]U
M"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@*B!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R=FEC97,*("H@0'!A8VMA
M9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!3:&%N92!#87)A=F5O(#Q3:&%N
M94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4*("H@0&-O
M<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@
M("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0@(%!(4"!,
M:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R
M+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]#;&EE;G0N<&AP)SL*<F5Q=6ER
M95]O;F-E("=33T%0+U1R86YS<&]R="YP:'`G.PIR97%U:7)E7V]N8V4@)TUA
M:6PO;6EM941E8V]D92YP:'`G.PH*+RHJ"B`J(%-/05`@4V5R=F5R($-L87-S
M('1H870@:6UP;&5M96YT<R!A;B!E;6%I;"!33T%0('-E<G9E<BX*("H@:'1T
M<#HO+W=W=RYP;V-K971S;V%P+F-O;2]S<&5C<R]S;71P8FEN9&EN9R\*("H*
M("H@5&AI<R!C;&%S<R!O=F5R<FED97,@=&AE(&1E9F%U;'0@2%144"!S97)V
M97(L('!R;W9I9&EN9R!T:&4@86)I;&ET>2!T;PH@*B!P87)S92!A;B!E;6%I
M;"!M97-S86=E(&%N9"!E>&5C=71E(%-/05`@8V%L;',N("!4:&ES(&-L87-S
M($1/15,@3D]4('!O<"!T:&4*("H@;65S<V%G93L@=&AE(&UE<W-A9V4L(&-O
M;7!L971E('=I=&@@:&5A9&5R<RP@;75S="!B92!P87-S960@:6X@87,@80H@
M*B!P87)A;65T97(@=&\@=&AE('-E<G9I8V4@9G5N8W1I;VX@8V%L;"X*("H*
M("H@0&%C8V5S<R`@('!U8FQI8PH@*B!`<&%C:V%G92`@4T]!4`H@*B!`875T
M:&]R("`@4VAA;F4@0V%R879E;R`\<VAA;F5`<&AP+FYE=#X*("HO"F-L87-S
M(%-/05!?4V5R=F5R7T5M86EL(&5X=&5N9',@4T]!4%]397)V97(@>PH*("`@
M('9A<B`D:&5A9&5R<R`](&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4T]!4%]3
M97)V97)?16UA:6PH)'-E;F1?<F5S<&]N<V4@/2!T<G5E*0H@("`@>PH@("`@
M("`@('!A<F5N=#HZ4T]!4%]397)V97(H*3L*("`@("`@("`D=&AI<RT^<V5N
M9%]R97-P;VYS92`]("1S96YD7W)E<W!O;G-E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@4F5M;W9E<R!(5%10(&AE861E<G,@9G)O;2!R97-P;VYS92X*("`@
M("`J"B`@("`@*B!43T1/.B!U<V4@4$5!4B!E;6%I;"!C;&%S<V5S"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L96%N"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W!A<G-E16UA:6PH)B1D871A*0H@
M("`@>PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O7B@N*C\I7'(_7&Y<<C]<
M;B@N*BDO<R(L("1D871A+"`D;6%T8V@I*2!["@H@("`@("`@("`@("!I9B`H
M<')E9U]M871C:%]A;&PH)R]>*"XJ/RDZ7',K*"XJ*20O;2<L("1M871C:%LQ
M72P@)&UA=&-H97,I*2!["B`@("`@("`@("`@("`@("`D:&,@/2!C;W5N="@D
M;6%T8VAE<ULP72D["B`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@
M/"`D:&,[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^:&5A
M9&5R<UMS=')T;VQO=V5R*"1M871C:&5S6S%=6R1I72E=(#T@=')I;2@D;6%T
M8VAE<ULR75LD:5TI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]
M"@H@("`@("`@("`@("!I9B`H(7-T<FES='(H)'1H:7,M/FAE861E<G-;)V-O
M;G1E;G0M='EP92==+"`G=&5X="]X;6PG*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@0V]N=&5N="!4
M>7!E)RP@)R<L("<G+"`G0VQI96YT)RD["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H
M<W1R8V%S96-M<"@D=&AI<RT^:&5A9&5R<ULG8V]N=&5N="UT<F%N<V9E<BUE
M;F-O9&EN9R==+"`G8F%S938T)RD]/3`I('L*("`@("`@("`@("`@("`@("\J
M(%5N9F]L9"!L:6YE<RX@*B\*("`@("`@("`@("`@("`@("1E;F-T97AT(#T@
M<')E9U]R97!L86-E*"(O6UQR?%QN72\B+"`G)RP@)&UA=&-H6S)=*3L*("`@
M("`@("`@("`@("`@("1D871A(#T@8F%S938T7V1E8V]D92@D96YC=&5X="D[
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&%T82`]
M("1M871C:%LR73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@268@
M;F\@8V]N=&5N="P@<F5T=7)N(&9A;'-E+B`J+PH@("`@("`@("`@("!R971U
M<FX@<W1R;&5N*"1T:&ES+3YR97%U97-T*2`^(#`["B`@("`@("`@?0H*("`@
M("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=);G9A;&ED($5M86EL($9O
M<FUA="<L("<G+"`G)RP@)T-L:65N="<I.PH*("`@("`@("!R971U<FX@9F%L
M<V4["B`@("!]"@H@("`@9G5N8W1I;VX@8VQI96YT*"8D9&%T82D*("`@('L*
M("`@("`@("`D871T86-H;65N=',@/2!A<G)A>2@I.PH*("`@("`@("`O*B!)
M9B!N96ET:&5R(&UA=&-H97,L('=E)VQL(&IU<W0@=')Y(&ET(&%N>7=A>2X@
M*B\*("`@("`@("!I9B`H<W1R:7-T<B@D9&%T82P@)T-O;G1E;G0M5'EP93H@
M87!P;&EC871I;VXO9&EM92<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5C
M;V1E1$E-14UE<W-A9V4H)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H
M;65N=',I.PH@("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["B`@
M("`@("`@?2!E;'-E:68@*'-T<FES='(H)&1A=&$L("=-24U%+59E<G-I;VXZ
M)RDI('L*("`@("`@("`@("`@+RH@5&AI<R!I<R!A(&UI;64@;65S<V%G92P@
M;&5T)W,@9&5C;V1E(&ET+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1E8V]D
M94UI;65-97-S86=E*"1D871A+"`D=&AI<RT^:&5A9&5R<RP@)&%T=&%C:&UE
M;G1S*3L*("`@("`@("`@("`@)'5S945N8V]D:6YG(#T@)TUI;64G.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("\J(%1H92!O;&0@9F%L;&)A8VLL
M(&)U="!D96-O9&5-:6UE365S<V%G92!H86YD;&5S('1H:6YG<R!F:6YE+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^7W!A<G-E16UA:6PH)&1A=&$I.PH@("`@
M("`@('T*"B`@("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I;F<@
M;V8@=&AE(&EN8V]M:6YG(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@("`@
M("`@*B!D871A(&%S(%541BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*("`@
M("`@("!I9B`H(21T:&ES+3YS;V%P9F%U;'0@)B8*("`@("`@("`@("`@(21T
M:&ES+3Y?9V5T0V]N=&5N=$5N8V]D:6YG*"1T:&ES+3YH96%D97)S6R=C;VYT
M96YT+71Y<&4G72DI('L*("`@("`@("`@("`@)'1H:7,M/GAM;%]E;F-O9&EN
M9R`](%-/05!?1$5&055,5%]%3D-/1$E.1SL*("`@("`@("`@("`@+RH@06X@
M96YC;V1I;F<@=V4@9&]N)W0@=6YD97)S=&%N9"P@<F5T=7)N(&$@9F%U;'0N
M("HO"B`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)U5N<W5P
M<&]R=&5D(&5N8V]D:6YG+"!U<V4@;VYE(&]F($E33RTX.#4Y+3$L(%53+4%3
M0TE)+"!55$8M."<L("<G+"`G)RP@)U-E<G9E<B<I.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"1T:&ES+3YS;V%P9F%U;'0I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YS;V%P9F%U;'0M/F=E=$9A=6QT*"D["B`@("`@("`@?0H*
M("`@("`@("`D8VQI96YT(#TF(&YE=R!33T%07T-L:65N="AN=6QL*3L*"B`@
M("`@("`@<F5T=7)N("1C;&EE;G0M/E]?<&%R<V4H)&1A=&$L("1T:&ES+3YX
M;6Q?96YC;V1I;F<L("1T:&ES+3YA='1A8VAM96YT<RD["B`@("!]"@H@("`@
M9G5N8W1I;VX@<V5R=FEC92@F)&1A=&$L("1E;F1P;VEN="`]("<G+"`D<V5N
M9%]R97-P;VYS92`]('1R=64L"B`@("`@("`@("`@("`@("`@("`@("1D=6UP
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M/F5N9'!O:6YT(#T@)&5N
M9'!O:6YT.PH@("`@("`@("1A='1A8VAM96YT<R`](&%R<F%Y*"D["B`@("`@
M("`@)&AE861E<G,@/2!A<G)A>2@I.PH*("`@("`@("`O*B!)9B!N96ET:&5R
M(&UA=&-H97,L('=E)VQL(&IU<W0@=')Y(&ET(&%N>7=A>2X@*B\*("`@("`@
M("!I9B`H<W1R:7-T<B@D9&%T82P@)T-O;G1E;G0M5'EP93H@87!P;&EC871I
M;VXO9&EM92<I*2!["B`@("`@("`@("`@("1T:&ES+3Y?9&5C;V1E1$E-14UE
M<W-A9V4H)&1A=&$L("1T:&ES+3YH96%D97)S+"`D871T86-H;65N=',I.PH@
M("`@("`@("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["B`@("`@("`@?2!E
M;'-E:68@*'-T<FES='(H)&1A=&$L("=-24U%+59E<G-I;VXZ)RDI('L*("`@
M("`@("`@("`@+RH@5&AI<R!I<R!A(&UI;64@;65S<V%G92P@;&5T)W,@9&5C
M;V1E(&ET+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1E8V]D94UI;65-97-S
M86=E*"1D871A+"`D=&AI<RT^:&5A9&5R<RP@)&%T=&%C:&UE;G1S*3L*("`@
M("`@("`@("`@)'5S945N8V]D:6YG(#T@)TUI;64G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\J(%1H92!O;&0@9F%L;&)A8VLL(&)U="!D96-O
M9&5-:6UE365S<V%G92!H86YD;&5S('1H:6YG<R!F:6YE+B`J+PH@("`@("`@
M("`@("`D=&AI<RT^7W!A<G-E16UA:6PH)&1A=&$I.PH@("`@("`@('T*"B`@
M("`@("`@+RH@1V5T('1H92!C:&%R86-T97(@96YC;V1I;F<@;V8@=&AE(&EN
M8V]M:6YG(')E<75E<W0@=')E870@:6YC;VUI;F<*("`@("`@("`@*B!D871A
M(&%S(%541BTX(&EF(&YO(&5N8V]D:6YG('-E="X@*B\*("`@("`@("!I9B`H
M(21R97-P;VYS92`F)@H@("`@("`@("`@("`A)'1H:7,M/E]G971#;VYT96YT
M16YC;V1I;F<H)'1H:7,M/FAE861E<G-;)V-O;G1E;G0M='EP92==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^>&UL7V5N8V]D:6YG(#T@4T]!4%]$149!54Q4
M7T5.0T]$24Y'.PH@("`@("`@("`@("`O*B!!;B!E;F-O9&EN9R!W92!D;VXG
M="!U;F1E<G-T86YD+"!R971U<FX@82!F875L="X@*B\*("`@("`@("`@("`@
M)'1H:7,M/E]R86ES95-O87!&875L="@G56YS=7!P;W)T960@96YC;V1I;F<L
M('5S92!O;F4@;V8@25-/+3@X-3DM,2P@55,M05-#24DL(%541BTX)RP@)R<L
M("<G+"`G4V5R=F5R)RD["B`@("`@("`@("`@("1R97-P;VYS92`]("1T:&ES
M+3YG971&875L=$UE<W-A9V4H*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D
M=&AI<RT^<V]A<&9A=6QT*2!["B`@("`@("`@("`@("1R97-P;VYS92`]("1T
M:&ES+3YS;V%P9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^<&%R<V5297%U97-T*"1D
M871A+"1A='1A8VAM96YT<RD["@H@("`@("`@("`@("`O*B!(86YD;&4@36EM
M92!O<B!$24U%(&5N8V]D:6YG+B`J+PH@("`@("`@("`@("`O*B!43T1/.B!$
M24U%($5N8V]D:6YG('-H;W5L9"!M;W9E('1O('1H92!T<F%N<W!O<G0L(&1O
M(&ET(&AE<F4*("`@("`@("`@("`@("H@9F]R(&YO=R!A;F0@9F]R(&5A<V4@
M;V8@9V5T=&EN9R!I="!D;VYE+B`J+PH@("`@("`@("`@("!I9B`H8V]U;G0H
M)'1H:7,M/E]?871T86-H;65N=',I*2!["B`@("`@("`@("`@("`@("!I9B`H
M)'5S945N8V]D:6YG(#T]("=-:6UE)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1S;V%P7VUS9R`]("1T:&ES+3Y?;6%K94UI;65-97-S86=E*"1S;V%P7VUS
M9RD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("\J($1E9F%U;'0@:7,@1$E-12X@*B\*("`@("`@("`@("`@("`@("`@
M("`D<V]A<%]M<V<@/2`D=&AI<RT^7VUA:V5$24U%365S<V%G92@D<V]A<%]M
M<V<I.PH@("`@("`@("`@("`@("`@("`@("1H96%D97);)T-O;G1E;G0M5'EP
M92==(#T@)V%P<&QI8V%T:6]N+V1I;64G.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)'-O87!?;7-G*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V53;V%P
M1F%U;'0H)'-O87!?;7-G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;V%P7VUS9RDI('L*
M("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7VUS9ULG8F]D>2==
M.PH@("`@("`@("`@("`@("`@:68@*&-O=6YT*"1S;V%P7VUS9ULG:&5A9&5R
M<R==*2D@>PH@("`@("`@("`@("`@("`@("`@("1H96%D97)S(#T@)'-O87!?
M;7-G6R=H96%D97)S)UT["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]M
M<V<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI
M<RT^<V5N9%]R97-P;VYS92D@>PH@("`@("`@("`@("!I9B`H)&1U;7`I('L*
M("`@("`@("`@("`@("`@('!R:6YT("1R97-P;VYS93L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1F<F]M(#T@87)R87E?:V5Y7V5X
M:7-T<R@G<F5P;'DM=&\G+"`D=&AI<RT^:&5A9&5R<RD@/R`D=&AI<RT^:&5A
M9&5R<ULG<F5P;'DM=&\G72`Z("1T:&ES+3YH96%D97)S6R=F<F]M)UT["@H@
M("`@("`@("`@("`@("`@)'-O87!?=')A;G-P;W)T(#TF(%-/05!?5')A;G-P
M;W)T.CIG9714<F%N<W!O<G0H)VUA:6QT;SHG("X@)&9R;VTL("1T:&ES+3YR
M97-P;VYS95]E;F-O9&EN9RD["B`@("`@("`@("`@("`@("`D9G)O;2`]("1T
M:&ES+3YE;F1P;VEN="`_("1T:&ES+3YE;F1P;VEN="`Z("1T:&ES+3YH96%D
M97)S6R=T;R==.PH@("`@("`@("`@("`@("`@)&AE861E<G-;)TEN+5)E<&QY
M+51O)UT@/2`D=&AI<RT^:&5A9&5R<ULG;65S<V%G92UI9"==.PH@("`@("`@
M("`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@G9G)O;2<@/3X@)&9R;VTL("=S
M=6)J96-T)R`]/B`D=&AI<RT^:&5A9&5R<ULG<W5B:F5C="==+"`G:&5A9&5R
M<R<@/3X@)&AE861E<G,I.PH@("`@("`@("`@("`@("`@)'-O87!?=')A;G-P
M;W)T+3YS96YD*"1R97-P;VYS92P@)&]P=&EO;G,I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0I]"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4T]!4"]397)V97(O16UA:6Q?1V%T97=A>2YP:'``````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q,C4U-B`Q,#4Q-30S-#$S,R`P,C,W,C,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RHJ"B`J
M(%1H:7,@9FEL92!C;VYT86EN<R!T:&4@8V]D92!F;W(@=&AE(&5M86EL+4A4
M5%`@4T]!4"!G871E=V%Y('-E<G9E<BX*("H*("H@4$A0('9E<G-I;VYS(#0@
M86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L"B`J('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@879A:6QA8FQE(&%T"B`J('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@268@>6]U"B`J(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I=`H@
M*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N
M;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X*("H@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!796(@4V5R
M=FEC97,*("H@0'!A8VMA9V4@("`@4T]!4`H@*B!`875T:&]R("`@("!3:&%N
M92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("!0;W)T('1O(%!%05(@
M86YD(&UO<F4*("H@0&-O<'ER:6=H="`@,C`P,RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0@(%!(4"!,:6-E;G-E(#(N,#(*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-/05`*("HO"@IR97%U:7)E7V]N
M8V4@)U-/05`O4V5R=F5R+T5M86EL+G!H<"<["G)E<75I<F5?;VYC92`G4T]!
M4"]4<F%N<W!O<G0N<&AP)SL*"B\J*@H@*B!33T%0(%-E<G9E<B!#;&%S<R!T
M:&%T(&EM<&QE;65N=',@86X@96UA:6P@4T]!4"!S97)V97(N"B`J(&AT='`Z
M+R]W=W<N<&]C:V5T<V]A<"YC;VTO<W!E8W,O<VUT<&)I;F1I;F<O"B`J"B`J
M(%1H:7,@8VQA<W,@;W9E<G)I9&5S('1H92!D969A=6QT($A45%`@<V5R=F5R
M+"!P<F]V:61I;F<@=&AE(&%B:6QI='D@=&\*("H@<&%R<V4@86X@96UA:6P@
M;65S<V%G92!A;F0@97AE8W5T92!S;V%P(&-A;&QS+B`@5&AI<R!C;&%S<R!$
M3T53($Y/5"!P;W`@=&AE"B`J(&UE<W-A9V4[('1H92!M97-S86=E+"!C;VUP
M;&5T92!W:71H(&AE861E<G,L(&UU<W0@8F4@<&%S<V5D(&EN(&%S(&$*("H@
M<&%R86UE=&5R('1O('1H92!S97)V:6-E(&9U;F-T:6]N(&-A;&PN"B`J"B`J
M(%1H:7,@8VQA<W,@8V%L;',@82!P<F]V:61E9"!(5%10(%-/05`@<V5R=F5R
M+"!F;W)W87)D:6YG('1H92!E;6%I;"!R97%U97-T+`H@*B!T:&5N('-E;F1I
M;F<@=&AE($A45%`@<F5S<&]N<V4@;W5T(&%S(&%N(&5M86EL+@H@*@H@*B!`
M86-C97-S("`@<'5B;&EC"B`J($!P86-K86=E("!33T%0"B`J($!A=71H;W(@
M("!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA<W,@4T]!
M4%]397)V97)?16UA:6Q?1V%T97=A>2!E>'1E;F1S(%-/05!?4V5R=F5R7T5M
M86EL('L*"B`@("!V87(@)&=A=&5W87D@/2!N=6QL.PH@("`@=F%R("1D=6UP
M(#T@9F%L<V4["@H@("`@9G5N8W1I;VX@4T]!4%]397)V97)?16UA:6Q?1V%T
M97=A>2@D9V%T97=A>2`]("<G+"`D<V5N9%]R97-P;VYS92`]('1R=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D=6UP(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@<&%R96YT.CI33T%07U-E<G9E<B@I.PH@
M("`@("`@("1T:&ES+3YS96YD7W)E<W!O;G-E(#T@)'-E;F1?<F5S<&]N<V4[
M"B`@("`@("`@)'1H:7,M/F=A=&5W87D@/2`D9V%T97=A>3L*("`@("`@("`D
M=&AI<RT^9'5M<"`]("1D=6UP.PH@("`@?0H*("`@(&9U;F-T:6]N('-E<G9I
M8V4H)B1D871A+"`D9V%T97=A>2`]("<G+"`D96YD<&]I;G0@/2`G)RP*("`@
M("`@("`@("`@("`@("`@("`@)'-E;F1?<F5S<&]N<V4@/2!T<G5E+"`D9'5M
M<"`](&9A;'-E*0H@("`@>PH@("`@("`@("1T:&ES+3YE;F1P;VEN="`]("1E
M;F1P;VEN=#L*("`@("`@("`D<F5S<&]N<V4@/2`G)SL*("`@("`@("`D=7-E
M16YC;V1I;F<@/2`G36EM92<["B`@("`@("`@)&]P=&EO;G,@/2!A<G)A>2@I
M.PH@("`@("`@(&EF("@A)&=A=&5W87DI('L*("`@("`@("`@("`@)&=A=&5W
M87D@/2`D=&AI<RT^9V%T97=A>3L*("`@("`@("!]"@H@("`@("`@("\J(%=E
M(&AA=F4@82!F=6QL('-E="!O9B!H96%D97)S+"!N965D('1O(&9I;F0@=&AE
M(&9I<G-T(&)L86YK"B`@("`@("`@("H@;&EN92X@*B\*("`@("`@("`D=&AI
M<RT^7W!A<G-E16UA:6PH)&1A=&$I.PH@("`@("`@(&EF("@D=&AI<RT^9F%U
M;'0I('L*("`@("`@("`@("`@)')E<W!O;G-E(#T@)'1H:7,M/F9A=6QT+3YM
M97-S86=E*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^:&5A9&5R
M<ULG8V]N=&5N="UT>7!E)UT@/3T@)V%P<&QI8V%T:6]N+V1I;64G*0H@("`@
M("`@("`@("`D=7-E16YC;V1I;F<@/2`G1$E-12<["@H@("`@("`@("\J($-A
M;&P@=&AE($A45%`@4V5R=F5R+B`J+PH@("`@("`@(&EF("@A)')E<W!O;G-E
M*2!["B`@("`@("`@("`@("1S;V%P7W1R86YS<&]R="`])B!33T%07U1R86YS
M<&]R=#HZ9V5T5')A;G-P;W)T*"1G871E=V%Y+"`D=&AI<RT^>&UL7V5N8V]D
M:6YG*3L*("`@("`@("`@("`@:68@*"1S;V%P7W1R86YS<&]R="T^9F%U;'0I
M('L*("`@("`@("`@("`@("`@("1R97-P;VYS92`]("1S;V%P7W1R86YS<&]R
M="T^9F%U;'0M/FUE<W-A9V4H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*
M"B`@("`@("`@+RH@4V5N9"!T:&4@;65S<V%G92X@*B\*("`@("`@("!I9B`H
M(21R97-P;VYS92D@>PH@("`@("`@("`@("`D;W!T:6]N<ULG<V]A<&%C=&EO
M;B==(#T@)'1H:7,M/FAE861E<G-;)W-O87!A8W1I;VXG73L*("`@("`@("`@
M("`@)&]P=&EO;G-;)VAE861E<G,G75LG0V]N=&5N="U4>7!E)UT@/2`D=&AI
M<RT^:&5A9&5R<ULG8V]N=&5N="UT>7!E)UT["@H@("`@("`@("`@("`D<F5S
M<&]N<V4@/2`D<V]A<%]T<F%N<W!O<G0M/G-E;F0H)&1A=&$L("1O<'1I;VYS
M*3L*("`@("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YH96%D97)S6R=M:6UE
M+79E<G-I;VXG72DI"B`@("`@("`@("`@("`@("`D;W!T:6]N<ULG:&5A9&5R
M<R==6R=-24U%+59E<G-I;VXG72`]("1T:&ES+3YH96%D97)S6R=M:6UE+79E
M<G-I;VXG73L*"B`@("`@("`@("`@(&EF("@D<V]A<%]T<F%N<W!O<G0M/F9A
M=6QT*2!["B`@("`@("`@("`@("`@("`D<F5S<&]N<V4@/2`D<V]A<%]T<F%N
M<W!O<G0M/F9A=6QT+3YM97-S86=E*"D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("!F;W)E86-H("@D<V]A<%]T<F%N<W!O<G0M/G1R
M86YS<&]R="T^871T86-H;65N=',@87,@)&-I9"`]/B`D8F]D>2D@>PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YA='1A8VAM96YT<UM=(#T@87)R87DH
M)V)O9'DG(#T^("1B;V1Y+"`G8VED)R`]/B`D8VED+"`G96YC;V1I;F<G(#T^
M("=B87-E-C0G*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("AC;W5N="@D=&AI<RT^7U]A='1A8VAM96YT<RDI('L*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'5S945N8V]D:6YG(#T]("=-:6UE)RD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`D<V]A<%]M<V<@/2`D=&AI<RT^7VUA:V5-
M:6UE365S<V%G92@D<F5S<&]N<V4I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;W!T:6]N<ULG:&5A9&5R<R==6R=-24U%+59E<G-I;VXG72`]("<Q+C`G
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("\J($1E9F%U;'0@:7,@1$E-12X@*B\*("`@("`@("`@("`@
M("`@("`@("`@("`@)'-O87!?;7-G(#T@)'1H:7,M/E]M86ME1$E-14UE<W-A
M9V4H)')E<W!O;G-E*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO
M;G-;)VAE861E<G,G75LG0V]N=&5N="U4>7!E)UT@/2`G87!P;&EC871I;VXO
M9&EM92<["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@(&EF("A014%2.CII<T5R<F]R*"1S;V%P7VUS9RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H
M)'-O87!?;7-G*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@:68@*&ES7V%R<F%Y*"1S;V%P7VUS9RDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<W!O;G-E(#T@)'-O87!?;7-G6R=B;V1Y)UT[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("AC;W5N="@D<V]A<%]M<V=;
M)VAE861E<G,G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D;W!T:6]N<ULG:&5A9&5R<R==*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D97)S)UT@/2!A<G)A
M>5]M97)G92@D;W!T:6]N<ULG:&5A9&5R<R==+"`D<V]A<%]M<V=;)VAE861E
M<G,G72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS6R=H96%D
M97)S)UT@/2`D<V]A<%]M<V=;)VAE861E<G,G73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YS96YD7W)E<W!O
M;G-E*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^9'5M<"!\?"`D9'5M<"D@
M>PH@("`@("`@("`@("`@("`@<')I;G0@)')E<W!O;G-E.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9R;VT@/2!A<G)A>5]K97E?
M97AI<W1S*"=R97!L>2UT;R<L("1T:&ES+3YH96%D97)S*2`_("1T:&ES+3YH
M96%D97)S6R=R97!L>2UT;R==(#H@)'1H:7,M/FAE861E<G-;)V9R;VTG73L*
M"B`@("`@("`@("`@("`@("`D<V]A<%]T<F%N<W!O<G0@/28@4T]!4%]4<F%N
M<W!O<G0Z.F=E=%1R86YS<&]R="@G;6%I;'1O.B<@+B`D9G)O;2P@)'1H:7,M
M/G)E<W!O;G-E7V5N8V]D:6YG*3L*("`@("`@("`@("`@("`@("1F<F]M(#T@
M)'1H:7,M/F5N9'!O:6YT(#\@)'1H:7,M/F5N9'!O:6YT(#H@)'1H:7,M/FAE
M861E<G-;)W1O)UT["B`@("`@("`@("`@("`@("`D:&5A9&5R<R`](&%R<F%Y
M*"=);BU297!L>2U4;R<@/3X@)'1H:7,M/FAE861E<G-;)VUE<W-A9V4M:60G
M72D["B`@("`@("`@("`@("`@("`D;W!T:6]N<R`](&%R<F%Y*"=F<F]M)R`]
M/B`D9G)O;2P@)W-U8FIE8W0G/3X@)'1H:7,M/FAE861E<G-;)W-U8FIE8W0G
M72P@)VAE861E<G,G(#T^("1H96%D97)S*3L*("`@("`@("`@("`@("`@("1S
M;V%P7W1R86YS<&]R="T^<V5N9"@D<F5S<&]N<V4L("1O<'1I;VYS*3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@('T*?0H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O4T]!4"]4<F%N<W!O<G0O4TU44"YP
M:'``````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C,R-"`Q,#4Q
M-30S-#$S,R`P,C(U,C$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*+RHJ"B`J(%1H:7,@9FEL92!C;VYT86EN<R!T
M:&4@8V]D92!F;W(@86X@4TU44"!T<F%N<W!O<G0@;&%Y97(N"B`J"B`J(%1H
M:7,@8V]D92!I<R!S=&EL;"!A(')O=6=H(&%N9"!U;G1E<W1E9"!D<F%F="X*
M("H@5$]$3SH*("H@('-W:71C:"!T;R!P96%R(&UA:6P@<W1U9F8*("H@('-M
M='`@875T:&5N=&EC871I;VX*("H@('-M='`@<W-L('-U<'!O<G0*("H@(&%B
M:6QI='D@=&\@9&5F:6YE('-M='`@;W!T:6]N<R`H96YC;V1I;F<L(&9R;VTL
M(&5T8RXI"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET
M:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V
M86EL86)L92!A=`H@*B!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@
M*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E
M("`@(%-/05`*("H@0&%U=&AO<B`@("`@4VAA;F4@0V%R879E;R`\4VAA;F5`
M0V%R879E;RYC;VT^"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0
M($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@
M(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER
M95]O;F-E("=33T%0+T)A<V4N<&AP)SL*<F5Q=6ER95]O;F-E("=-86EL+W-M
M='`N<&AP)SL*"B\J*@H@*B`@4TU44"!4<F%N<W!O<G0@9F]R(%-/05`*("H*
M("H@:6UP;&5M96YT<R!33T%0+5--5%`@87,@9&5F:6YE9"!A=`H@*B!H='1P
M.B\O=W=W+G!O8VME='-O87`N8V]M+W-P96-S+W-M='!B:6YD:6YG+PH@*@H@
M*B!43T1/.B!U<V4@4$5!4B!S;71P(&%N9"!-:6UE(&-L87-S97,*("H*("H@
M0&%C8V5S<R!P=6)L:6,*("H@0'!A8VMA9V4@4T]!4`H@*B!`875T:&]R(%-H
M86YE($-A<F%V96\@/'-H86YE0'!H<"YN970^"B`J+PIC;&%S<R!33T%07U1R
M86YS<&]R=%]33510(&5X=&5N9',@4T]!4%]"87-E"GL*"B`@("!V87(@)&-R
M961E;G1I86QS(#T@)R<["B`@("!V87(@)'1I;65O=70@/2`T.R`O+R!C;VYN
M96-T('1I;65O=70*("`@('9A<B`D=7)L<&%R=',@/2!.54Q,.PH@("`@=F%R
M("1U<FP@/2`G)SL*("`@('9A<B`D:6YC;VUI;F=?<&%Y;&]A9"`]("<G.PH@
M("`@=F%R("1?=7-E<D%G96YT(#T@4T]!4%],24)205)97TY!344["B`@("!V
M87(@)&5N8V]D:6YG(#T@4T]!4%]$149!54Q47T5.0T]$24Y'.PH@("`@=F%R
M("1H;W-T(#T@)S$R-RXP+C`N,2<["B`@("!V87(@)'!O<G0@/2`R-3L*("`@
M('9A<B`D875T:"`]($Y53$P["B`@("`O*BH*("`@("H@4T]!4%]4<F%N<W!O
M<G1?4TU44"!#;VYS=')U8W1O<@H@("`@*@H@("`@*B!`<&%R86T@<W1R:6YG
M("154DP@("`@;6%I;'1O.F%D9')E<W,*("`@("H*("`@("H@0&%C8V5S<R!P
M=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!33T%07U1R86YS<&]R=%]33510
M*"154DPL("1E;F-O9&EN9STG55,M05-#24DG*0H@("`@>PH@("`@("`@('!A
M<F5N=#HZ4T]!4%]"87-E*"=33510)RD["B`@("`@("`@)'1H:7,M/F5N8V]D
M:6YG(#T@)&5N8V]D:6YG.PH@("`@("`@("1T:&ES+3YU<FQP87)T<R`]($!P
M87)S95]U<FPH)%523"D["B`@("`@("`@)'1H:7,M/G5R;"`]("154DP["B`@
M("!]"@H@("`@+RHJ"B`@("`J('-E;F0@86YD(')E8V5I=F4@<V]A<"!D871A
M"B`@("`J"B`@("`J($!P87)A;2!S=')I;F<@)B1M<V<@("`@("`@;W5T9V]I
M;F<@<&]S="!D871A"B`@("`J($!P87)A;2!S=')I;F<@)&%C=&EO;B`@("`@
M(%-/05`@06-T:6]N(&AE861E<B!D871A"B`@("`J($!P87)A;2!I;G0@)'1I
M;65O=70@('-O8VME="!T:6UE;W5T+"!D969A=6QT(#`@;W(@;V9F"B`@("`J
M"B`@("`J($!R971U<FX@<W1R:6YG("8D<F5S<&]N<V4@("!R97-P;VYS92!D
M871A+"!M:6YU<R!H='1P(&AE861E<G,*("`@("H@0&%C8V5S<R!P=6)L:6,*
M("`@("HO"B`@("!F=6YC=&EO;B!S96YD*"8D;7-G+"`@+RIA<G)A>2HO("1O
M<'1I;VYS(#T@3E5,3"D*("`@('L*("`@("`@("`D=&AI<RT^:6YC;VUI;F=?
M<&%Y;&]A9"`]("<G.PH@("`@("`@("1T:&ES+3YO=71G;VEN9U]P87EL;V%D
M(#T@)B1M<V<["B`@("`@("`@:68@*"$D=&AI<RT^7W9A;&ED871E57)L*"DI
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF875L=#L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D;W!T:6]N<R!\?"`A87)R87E?:V5Y7V5X:7-T<R@G
M9G)O;2<L)&]P=&EO;G,I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M7W)A:7-E4V]A<$9A=6QT*").;R!&4D]-(&%D9')E<W,@=&\@<V5N9"!M97-S
M86=E('=I=&@B*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG:&]S="==*2D@)'1H:7,M/FAO<W0@/2`D;W!T:6]N<ULG:&]S="==
M.PH@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&]R="==*2D@)'1H:7,M
M/G!O<G0@/2`D;W!T:6]N<ULG<&]R="==.PH@("`@("`@(&EF("AI<W-E="@D
M;W!T:6]N<ULG875T:"==*2D@)'1H:7,M/F%U=&@@/2`D;W!T:6]N<ULG875T
M:"==.PH@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG=7-E<FYA;64G72DI
M("1T:&ES+3YU<V5R;F%M92`]("1O<'1I;VYS6R=U<V5R;F%M92==.PH@("`@
M("`@(&EF("AI<W-E="@D;W!T:6]N<ULG<&%S<W=O<F0G72DI("1T:&ES+3YP
M87-S=V]R9"`]("1O<'1I;VYS6R=P87-S=V]R9"==.PH*("`@("`@("`D:&5A
M9&5R<R`](&%R<F%Y*"D["B`@("`@("`@)&AE861E<G-;)T9R;VTG72`]("1O
M<'1I;VYS6R=F<F]M)UT["B`@("`@("`@)&AE861E<G-;)U@M36%I;&5R)UT@
M/2`D=&AI<RT^7W5S97)!9V5N=#L*("`@("`@("`D:&5A9&5R<ULG34E-12U6
M97)S:6]N)UT@/2`G,2XP)SL*("`@("`@("`D:&5A9&5R<ULG365S<V%G92U)
M1"==(#T@;60U*'1I;64H*2DN)RYS;V%P0"<N)'1H:7,M/FAO<W0["B`@("`@
M("`@)&AE861E<G-;)U1O)UT@/2`D=&AI<RT^=7)L<&%R='-;)W!A=&@G73L*
M("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G<V]A<&%C=&EO;B<L("1O
M<'1I;VYS*2D@>PH@("`@("`@("`@("`D:&5A9&5R<ULG4V]A<&%C=&EO;B==
M(#T@(EPB>R1O<'1I;VYS6R=S;V%P86-T:6]N)UU]7"(B.PH@("`@("`@('T*
M"B`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=H96%D97)S)UTI*0H@("`@
M("`@("`@("`D:&5A9&5R<R`](&%R<F%Y7VUE<F=E*"1H96%D97)S+"`D;W!T
M:6]N<ULG:&5A9&5R<R==*3L*"B`@("`@("`@+R\@:68@=&AE(&-O;G1E;G0@
M='EP92!I<R!A;')E861Y('-E="P@=V4@87-S=6UE('1H870@36EM92!E;F-O
M9&EN9PH@("`@("`@("\O(&ES(&%L<F5A9'D@9&]N90H@("`@("`@(&EF("AI
M<W-E="@D:&5A9&5R<ULG0V]N=&5N="U4>7!E)UTI*2!["B`@("`@("`@("`@
M("1O=70@/2`D;7-G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O
M(&1O(&$@<VEM<&QE(&EN;&EN92!-:6UE(&5N8V]D:6YG"B`@("`@("`@("`@
M("1H96%D97)S6R=#;VYT96YT+41I<W!O<VET:6]N)UT@/2`G:6YL:6YE)SL*
M("`@("`@("`@("`@)&AE861E<G-;)T-O;G1E;G0M5'EP92==(#T@(G1E>'0O
M>&UL.R!C:&%R<V5T/5PB)'1H:7,M/F5N8V]D:6YG7"(B.PH@("`@("`@("`@
M("!I9B`H87)R87E?:V5Y7V5X:7-T<R@G=')A;G-F97(M96YC;V1I;F<G+"`D
M;W!T:6]N<RDI('L*("`@("`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1O
M<'1I;VYS6R=T<F%N<V9E<BUE;F-O9&EN9R==+"=Q=6]T960M<')I;G1A8FQE
M)RD]/3`I('L*("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<ULG0V]N=&5N
M="U4<F%N<V9E<BU%;F-O9&EN9R==(#T@)&]P=&EO;G-;)W1R86YS9F5R+65N
M8V]D:6YG)UT["B`@("`@("`@("`@("`@("`@("`@)&]U="`]("8D;7-G.PH@
M("`@("`@("`@("`@("`@?2!E;'-E(&EF("AS=')C87-E8VUP*"1O<'1I;VYS
M6R=T<F%N<V9E<BUE;F-O9&EN9R==+"=B87-E-C0G*3T],"D@>PH@("`@("`@
M("`@("`@("`@("`@("1H96%D97)S6R=#;VYT96YT+51R86YS9F5R+45N8V]D
M:6YG)UT@/2`G8F%S938T)SL*("`@("`@("`@("`@("`@("`@("`D;W5T(#T@
M8VAU;FM?<W!L:70H8F%S938T7V5N8V]D92@D;7-G*2PW-BPB7&XB*3L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DEN=F%L:60@5')A;G-F97(@
M16YC;V1I;F<Z('LD;W!T:6]N<ULG=')A;G-F97(M96YC;V1I;F<G77TB*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("\O(&1E9F%U;'0@=&\@8F%S938T"B`@("`@("`@("`@("`@
M("`D:&5A9&5R<ULG0V]N=&5N="U4<F%N<V9E<BU%;F-O9&EN9R==(#T@)V)A
M<V4V-"<["B`@("`@("`@("`@("`@("`D;W5T(#T@8VAU;FM?<W!L:70H8F%S
M938T7V5N8V]D92@D;7-G*2D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1H96%D97)S6R=3=6)J96-T)UT@/2!A<G)A>5]K97E?97AI<W1S
M*"=S=6)J96-T)RP@)&]P=&EO;G,I(#\@)&]P=&EO;G-;)W-U8FIE8W0G72`Z
M("=33T%0($UE<W-A9V4G.PH*("`@("`@("!F;W)E86-H("@D:&5A9&5R<R!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D:&5A9&5R7W1E>'0@
M+CT@(B1K97DZ("1V86QU95QN(CL*("`@("`@("!]"B`@("`@("`@)'1H:7,M
M/F]U=&=O:6YG7W!A>6QO860@/2`D:&5A9&5R7W1E>'0N(EQR7&XB+B1T:&ES
M+3YO=71G;VEN9U]P87EL;V%D.PH@("`@("`@(",@=V4@=V%N="!T;R!R971U
M<FX@82!P<F]P97(@6$U,(&UE<W-A9V4*"B`@("`@("`@)&UA:6QE<E]P87)A
M;7,@/2!A<G)A>2@*("`@("`@("`@("`@)VAO<W0G(#T^("1T:&ES+3YH;W-T
M+`H@("`@("`@("`@("`G<&]R="<@/3X@)'1H:7,M/G!O<G0L"B`@("`@("`@
M("`@("=U<V5R;F%M92<@/3X@)'1H:7,M/G5S97)N86UE+`H@("`@("`@("`@
M("`G<&%S<W=O<F0G(#T^("1T:&ES+3YP87-S=V]R9"P*("`@("`@("`@("`@
M)V%U=&@G(#T^("1T:&ES+3YA=71H"B`@("`@("`@*3L*("`@("`@("`D;6%I
M;&5R(#TF(&YE=R!-86EL7W-M='`H)&UA:6QE<E]P87)A;7,I.PH@("`@("`@
M("1R97-U;'0@/2`D;6%I;&5R+3YS96YD*"1T:&ES+3YU<FQP87)T<ULG<&%T
M:"==+"`D:&5A9&5R<RP@)&]U="D["B`@("`@("`@(R1R97-U;'0@/2!M86EL
M*"1T:&ES+3YU<FQP87)T<ULG<&%T:"==+"`D:&5A9&5R<ULG4W5B:F5C="==
M+"`D;W5T+"`D:&5A9&5R7W1E>'0I.PH*("`@("`@("!I9B`H(5!%05(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@)'9A;"`])B!N97<@4T]!
M4%]686QU92@G365S<V%G92U)1"<L)W-T<FEN9R<L)&AE861E<G-;)TUE<W-A
M9V4M240G72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-V86Q;
M72`])B!N97<@4T]!4%]686QU92@G9F%U;'1C;V1E)RPG44YA;64G+"=33T%0
M+45.5CI#;&EE;G0G*3L*("`@("`@("`@("`@)'-V86Q;72`])B!N97<@4T]!
M4%]686QU92@G9F%U;'1S=')I;F<G+"=S=')I;F<G+")C;W5L9&XG="!S96YD
M(%--5%`@;65S<V%G92!T;R![)'1H:7,M/G5R;'!A<G1S6R=P871H)UU](BD[
M"B`@("`@("`@("`@("1V86P@/28@;F5W(%-/05!?5F%L=64H)T9A=6QT)RPG
M4W1R=6-T)RPD<W9A;"D["B`@("`@("`@?0H*("`@("`@("`D;7%N86UE(#TF
M(&YE=R!13F%M92@D;65T:&]D+"`D;F%M97-P86-E*3L*("`@("`@("`D;65T
M:&]D5F%L=64@/28@;F5W(%-/05!?5F%L=64H)U)E<W!O;G-E)RP@)U-T<G5C
M="<L(&%R<F%Y*"1V86PI*3L*"B`@("`@("`@)'1H:7,M/FEN8V]M:6YG7W!A
M>6QO860@/28@)'1H:7,M/E]M86ME16YV96QO<&4H)&UE=&AO9%9A;'5E+"`D
M=&AI<RT^:&5A9&5R<RP@)'1H:7,M/F5N8V]D:6YG*3L*"B`@("`@("`@<F5T
M=7)N("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D.PH@("`@?0H*("`@("\J*@H@
M("`@*B!S970@9&%T82!F;W(@:'1T<"!A=71H96YT:6-A=&EO;@H@("`@*B!C
M<F5A=&5S($%U=&AO<FEZ871I;VX@:&5A9&5R"B`@("`J"B`@("`J($!P87)A
M;2!S=')I;F<@)'5S97)N86UE("`@=7-E<FYA;64*("`@("H@0'!A<F%M('-T
M<FEN9R`D<&%S<W=O<F0@("!R97-P;VYS92!D871A+"!M:6YU<R!H='1P(&AE
M861E<G,*("`@("H*("`@("H@0')E='5R;B!N;VYE"B`@("`J($!A8V-E<W,@
M<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T0W)E9&5N=&EA;',H)'5S
M97)N86UE+"`D<&%S<W=O<F0I"B`@("!["B`@("`@("`@)'1H:7,M/G5S97)N
M86UE(#T@)'5S97)N86UE.PH@("`@("`@("1T:&ES+3YP87-S=V]R9"`]("1P
M87-S=V]R9#L*("`@('T*"B`@("`O+R!P<FEV871E(&UE;6)E<G,*"B`@("`O
M*BH*("`@("H@=F%L:61A=&4@=7)L(&1A=&$@<&%S<V5D('1O(&-O;G-T<G5C
M=&]R"B`@("`J"B`@("`J($!R971U<FX@8F]O;&5A;@H@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&55<FPH*0H@
M("`@>PH@("`@("`@(&EF("@@(2!I<U]A<G)A>2@D=&AI<RT^=7)L<&%R=',I
M("D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B
M;&4@=&\@<&%R<V4@55),("1U<FPB*3L*("`@("`@("`@("`@<F5T=7)N($9!
M3%-%.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP
M87)T<ULG<V-H96UE)UTI('Q\"B`@("`@("`@("`@('-T<F-A<V5C;7`H)'1H
M:7,M/G5R;'!A<G1S6R=S8VAE;64G72P@)VUA:6QT;R<I("$](#`I('L*("`@
M("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(E5N86)L92!T
M;R!P87)S92!54DP@)'5R;"(I.PH@("`@("`@("`@("`@("`@<F5T=7)N($9!
M3%-%.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP
M87)T<ULG<&%T:"==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*")5;F%B;&4@=&\@<&%R<V4@55),("1U<FPB*3L*("`@("`@("`@
M("`@<F5T=7)N($9!3%-%.PH@("`@("`@('T*("`@("`@("!R971U<FX@5%)5
M13L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]33T%0+U1R86YS<&]R="]40U`N
M<&AP````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$P-C0W(#$P
M-3$U-#,T,3,S(#`R,C,V-@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`HO*BH*("H@5&AI<R!F:6QE(&-O;G1A:6YS
M('1H92!C;V1E(&9O<B!A(%1#4"!T<F%N<W!O<G0@;&%Y97(N"B`J"B`J(%!(
M4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+`H@*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@
M:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A=`H@*B!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R!O8G1A:6X@:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L
M96%S92!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M"B`J(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G
M;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*("H@0&%U
M=&AO<B`@("`@4VAA;F4@2&%N;F$@/&EO<F1Y7V%T7VEO<F1Y7V1O=%]C;VT^
M"B`J($!C;W!Y<FEG:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M("!02%`@3&EC96YS92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]33T%0"B`J+PH*<F5Q=6ER95]O;F-E("=33T%0
M+T)A<V4N<&AP)SL*"B\J*@H@*B!40U`@=')A;G-P;W)T(&9O<B!33T%0+@H@
M*@H@*B!`=&]D;R`@("!U<V4@3F5T7U-O8VME=#L@:6UP;&5M96YT('-O;64@
M<V5C=7)I='D@<V-H96UE.R!I;7!L96UE;G0@<W5P<&]R=`H@*B`@("`@("`@
M("!F;W(@871T86-H;65N=',*("H@0&%C8V5S<R`@<'5B;&EC"B`J($!P86-K
M86=E(%-/05`*("H@0&%U=&AO<B`@4VAA;F4@2&%N;F$@/&EO<F1Y7V%T7VEO
M<F1Y7V1O=%]C;VT^"B`J+PIC;&%S<R!33T%07U1R86YS<&]R=%]40U`@97AT
M96YD<R!33T%07T)A<V5?3V)J96-T"GL*"B`@("!V87(@)&AE861E<G,@/2!A
M<G)A>2@I.PH@("`@=F%R("1U<FQP87)T<R`]($Y53$P["B`@("!V87(@)'5R
M;"`]("<G.PH@("`@=F%R("1I;F-O;6EN9U]P87EL;V%D(#T@)R<["B`@("!V
M87(@)%]U<V5R06=E;G0@/2!33T%07TQ)0E)!4EE?3D%-13L*("`@('9A<B`D
M96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["B`@("!V87(@)')E
M<W5L=%]E;F-O9&EN9R`]("=55$8M."<["B`@("!V87(@)')E<W5L=%]C;VYT
M96YT7W1Y<&4["@H@("`@+RHJ"B`@("`@*B!S;V-K970*("`@("`J+PH@("`@
M=F%R("1S;V-K970@/2`G)SL*"B`@("`O*BH*("`@("`J(%-/05!?5')A;G-P
M;W)T7U1#4"!#;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)%523"`@("!H='1P('5R;"!T;R!S;V%P(&5N9'!O:6YT"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@4T]!
M4%]4<F%N<W!O<G1?5$-0*"154DPL("1E;F-O9&EN9R`](%-/05!?1$5&055,
M5%]%3D-/1$E.1RD*("`@('L*("`@("`@("!P87)E;G0Z.E-/05!?0F%S95]/
M8FIE8W0H)U1#4"<I.PH@("`@("`@("1T:&ES+3YU<FQP87)T<R`]($!P87)S
M95]U<FPH)%523"D["B`@("`@("`@)'1H:7,M/G5R;"`]("154DP["B`@("`@
M("`@)'1H:7,M/F5N8V]D:6YG(#T@)&5N8V]D:6YG.PH@("`@?0H*("`@(&9U
M;F-T:6]N(%]S;V-K971?<&EN9R@I"B`@("!["B`@("`@("`@+R\@6%A8(&AO
M=R!D;R!W92!R97-T87)T(&%F=&5R('-O8VME=%]S:'5T9&]W;C\*("`@("`@
M("`O+VEF("@A)'1H:7,M/G-O8VME="D@>PH@("`@("`@("`@("`C(&-R96%T
M92!S;V-K970@<F5S;W5R8V4*("`@("`@("`@("`@)'1H:7,M/G-O8VME="`]
M($!S;V-K971?8W)E871E*$%&7TE.150L(%-/0TM?4U1214%-+"!33TQ?5$-0
M*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YS;V-K970@/"`P*2!R971U<FX@
M,#L*"B`@("`@("`@("`@(",@8V]N;F5C=`H@("`@("`@("`@("`D<F5S=6QT
M(#T@<V]C:V5T7V-O;FYE8W0H)'1H:7,M/G-O8VME="P@)'1H:7,M/G5R;'!A
M<G1S6R=H;W-T)UTL("1T:&ES+3YU<FQP87)T<ULG<&]R="==*3L*("`@("`@
M("`@("`@:68@*"1R97-U;'0@/"`P*2!R971U<FX@,#L*("`@("`@("`O+WT*
M("`@("`@("!R971U<FX@,3L*("`@('T*"B`@("`O*BH*("`@("`J('-E;F0@
M86YD(')E8V5I=F4@<V]A<"!D871A"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`F)&US9R`@("`@("!O=71G;VEN9R!P;W-T(&1A=&$*("`@("`J($!P
M87)A;2!S=')I;F<@)&%C=&EO;B`@("`@(%-/05`@06-T:6]N(&AE861E<B!D
M871A"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F=\9F%U;'0@<F5S<&]N
M<V4*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9S96YD*"8D;7-G+"`D;W!T:6]N<R`]($Y53$PI"B`@("!["B`@("`@("`@
M)'1H:7,M/FEN8V]M:6YG7W!A>6QO860@/2`G)SL*("`@("`@("`D=&AI<RT^
M;W5T9V]I;F=?<&%Y;&]A9"`]("8D;7-G.PH@("`@("`@(&EF("@A)'1H:7,M
M/E]V86QI9&%T955R;"@I*2!R971U<FX@)'1H:7,M/F9A=6QT.PH*("`@("`@
M("`O+R!C:&5C:R!F;W(@5$-0('-C:&5M90H@("`@("`@(&EF("AS=')C87-E
M8VUP*"1T:&ES+3YU<FQP87)T<ULG<V-H96UE)UTL("=40U`G*2`]/2`P*2![
M"B`@("`@("`@("`@("\O(&-H96-K(&-O;FYE8W1I;VX*("`@("`@("`@("`@
M:68@*"$D=&AI<RT^7W-O8VME=%]P:6YG*"DI"B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G97)R;W(@;VX@)RXD=&AI
M<RT^=7)L+B<@<F5A<V]N("<N<V]C:V5T7W-T<F5R<F]R*'-O8VME=%]L87-T
M7V5R<F]R*"1T:&ES+3YS;V-K970I*2D["@H@("`@("`@("`@("`O+R!W<FET
M92!T;R!T:&4@<V]C:V5T"B`@("`@("`@("`@(&EF("@A0'-O8VME=%]W<FET
M92@D=&AI<RT^<V]C:V5T+"`D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9"P@<W1R
M;&5N*"1T:&ES+3YO=71G;VEN9U]P87EL;V%D*2DI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*"=%<G)O<B!S96YD
M:6YG(&1A=&$@=&\@)RXD=&AI<RT^=7)L+B<@<F5A<V]N("<N<V]C:V5T7W-T
M<F5R<F]R*'-O8VME=%]L87-T7V5R<F]R*"1T:&ES+3YS;V-K970I*2D["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("\O('-H=71D;W=N('=R:71I;F<*
M("`@("`@("`@("`@:68H(7-O8VME=%]S:'5T9&]W;B@D=&AI<RT^<V]C:V5T
M+"`Q*2D*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*")C86XG="!C:&%N9V4@<V]C:V5T(&UO9&4@=&\@<F5A9"XB*3L*
M"B`@("`@("`@("`@("\O(')E860@979E<GET:&EN9R!W92!C86XN"B`@("`@
M("`@("`@('=H:6QE*"1B=68@/2!`<V]C:V5T7W)E860H)'1H:7,M/G-O8VME
M="P@,3`R-"P@4$A07T))3D%265]214%$*2D@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FEN8V]M:6YG7W!A>6QO860@+CT@)&)U9CL*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@+R\@<F5T=7)N('!A>6QO860@;W(@9&EE"B`@("`@
M("`@("`@(&EF("@D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"D*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9#L*"B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")%<G)O<B!R
M979E:79I;F<@9&%T82!F<F]M("(N)'1H:7,M/G5R;"D["B`@("`@("`@?0H*
M("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L="@G26YV86QI
M9"!U<FP@<V-H96UE("<N)'1H:7,M/G5R;"D["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!V86QI9&%T92!U<FP@9&%T82!P87-S960@=&\@8V]N<W1R=6-T;W(*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?=F%L:61A=&55<FPH*0H@
M("`@>PH@("`@("`@(&EF("@@(2!I<U]A<G)A>2@D=&AI<RT^=7)L<&%R=',I
M("D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")5;F%B
M;&4@=&\@<&%R<V4@55),("1U<FPB*3L*("`@("`@("`@("`@<F5T=7)N($9!
M3%-%.PH@("`@("`@('T*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP
M87)T<ULG:&]S="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A
M<$9A=6QT*").;R!H;W-T(&EN(%523"`D=7)L(BD["B`@("`@("`@("`@(')E
M='5R;B!&04Q313L*("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI
M<RT^=7)L<&%R='-;)W!A=&@G72D@?'P@(21T:&ES+3YU<FQP87)T<ULG<&%T
M:"==*0H@("`@("`@("`@("`D=&AI<RT^=7)L<&%R='-;)W!A=&@G72`]("<O
M)SL*("`@("`@("!R971U<FX@5%)513L*("`@('T*"GT*````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+U-/05`O5')A;G-P;W)T+TA45%`N<&AP````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#<T,S$@,3`U,34T,S0Q,S,@
M,#(R-3(P`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\J*@H@*B!4:&ES(&9I;&4@8V]N=&%I;G,@=&AE(&-O9&4@
M9F]R(&$@2%144"!T<F%N<W!O<G0@;&%Y97(N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+`H@
M*B!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES(&%V86EL86)L92!A=`H@*B!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\R7S`R+G1X="X@($EF('EO=0H@*B!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@
M:70*("H@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N"B`J(&UA:6P@
M>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@5V5B
M(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%-/05`*("H@0&%U=&AO<B`@("`@
M4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^"B`J($!C;W!Y<FEG
M:'0@(#(P,#,M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT("!02%`@3&EC96YS
M92`R+C`R"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C
M:V%G92]33T%0"B`J+PH*+RHJ"B`J($A45%`@5')A;G-P;W)T(&-L87-S"B`J
M"B`J($!P86-K86=E("!33T%0"B`J($!C871E9V]R>2!796)?4V5R=FEC97,*
M("HO"@HO*BH*("H@3F5E9&5D($-L87-S97,*("HO"G)E<75I<F5?;VYC92`G
M4T]!4"]"87-E+G!H<"<["@HO*BH*("H@($A45%`@5')A;G-P;W)T(&9O<B!3
M3T%0"B`J"B`J($!A8V-E<W,@<'5B;&EC"B`J($!P86-K86=E(%-/05`*("H@
M0&%U=&AO<B!3:&%N92!#87)A=F5O(#QS:&%N94!P:'`N;F5T/@H@*B\*8VQA
M<W,@4T]!4%]4<F%N<W!O<G1?2%144"!E>'1E;F1S(%-/05!?0F%S90I["@H@
M("`@+RHJ"B`@("`@*B!"87-I8R!!=71H('-T<FEN9PH@("`@("H*("`@("`J
M($!V87(@(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D:&5A9&5R<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!#;V]K:65S"B`@("`@*@H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&-O;VMI97,["@H@("`@+RHJ"B`@
M("`@*@H@("`@("H@0'9A<B`@:6YT(&-O;FYE8W1I;VX@=&EM96]U="!I;B!S
M96-O;F1S("T@,"`](&YO;F4*("`@("`J+PH@("`@=F%R("1T:6UE;W5T(#T@
M-#L*"B`@("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@=7)L<&%R=',@
M+2!P87)S95]U<FPH*0H@("`@("H*("`@("`J($!V87(@(&UI>&5D"B`@("`@
M*B\*("`@('9A<B`D=7)L<&%R=',@/2!.54Q,.PH*("`@("\J*@H@("`@("H@
M0V]N;F5C=&EO;B!E;F1P;VEN="`M(%523`H@("`@("H*("`@("`J($!V87(@
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'5R;"`]("<G.PH*("`@("\J*@H@
M("`@("H@26YC;VUI;F<@<&%Y;&]A9`H@("`@("H*("`@("`J($!V87(@('-T
M<FEN9PH@("`@("HO"B`@("!V87(@)&EN8V]M:6YG7W!A>6QO860@/2`G)SL*
M"B`@("`O*BH*("`@("`J($A45%`M4F5Q=65S="!5<V5R+4%G96YT"B`@("`@
M*@H@("`@("H@0'9A<B`@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W5S97)!
M9V5N="`](%-/05!?3$E"4D%265].04U%.PH*("`@("\J*@H@("`@("H@2%14
M4"!%;F-O9&EN9PH@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D96YC;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<["@H@
M("`@+RHJ"B`@("`@*B!(5%10+5)E<W!O;G-E($-O;G1E;G0M5'EP92!E;F-O
M9&EN9PH@("`@("H*("`@("`J('=E(&%S<W5M92!55$8M."!I9B!N;R!E;F-O
M9&EN9R!I<R!S970*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@("!V
M87(@)')E<W5L=%]E;F-O9&EN9R`]("=55$8M."<["@H@("`@+RHJ"B`@("`@
M*B!(5%10+5)E<W!O;G-E($-O;G1E;G0M5'EP90H@("`@("HO"B`@("!V87(@
M)')E<W5L=%]C;VYT96YT7W1Y<&4["@H@("`@=F%R("1R97-U;'1?:&5A9&5R
M<R`](&%R<F%Y*"D["@H@("`@=F%R("1R97-U;'1?8V]O:VEE<R`](&%R<F%Y
M*"D["@H@("`@+RHJ"B`@("`@*B!33T%07U1R86YS<&]R=%](5%10($-O;G-T
M<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D55),("`@(&AT
M='`@=7)L('1O('-O87`@96YD<&]I;G0*("`@("`J"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("H@0'!A<F%M("!S=')I;F<@)%5220H@("`@("H@0'!A
M<F%M("!S=')I;F<@)&5N8V]D:6YG("!E;F-O9&EN9R!T;R!U<V4*("`@("`J
M+PH@("`@9G5N8W1I;VX@4T]!4%]4<F%N<W!O<G1?2%144"@D55),+"`D96YC
M;V1I;F<@/2!33T%07T1%1D%53%1?14Y#3T1)3D<I"B`@("!["B`@("`@("`@
M<&%R96YT.CI33T%07T)A<V4H)TA45%`G*3L*("`@("`@("`D=&AI<RT^=7)L
M<&%R=',@/2!`<&%R<V5?=7)L*"154DPI.PH@("`@("`@("1T:&ES+3YU<FP@
M/2`D55),.PH@("`@("`@("1T:&ES+3YE;F-O9&EN9R`]("1E;F-O9&EN9SL*
M("`@('T*"B`@("`O*BH*("`@("`J('-E;F0@86YD(')E8V5I=F4@<V]A<"!D
M871A"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R!O=71G;VEN9R!P;W-T
M(&1A=&$*("`@("`J($!P87)A;2!A<G)A>2`@;W!T:6]N<PH@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG?&9A=6QT(')E<W!O;G-E"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B`F<V5N9"@F)&US9RP@
M)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]V
M86QI9&%T955R;"@I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F%U
M;'0["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)W1I
M;65O=70G72DI"B`@("`@("`@("`@("1T:&ES+3YT:6UE;W5T(#T@*&EN="DD
M;W!T:6]N<ULG=&EM96]U="==.PH*("`@("`@("!I9B`H<W1R8V%S96-M<"@D
M=&AI<RT^=7)L<&%R='-;)W-C:&5M92==+"`G2%144"<I(#T](#`I('L*("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5N9$A45%`H)&US9RP@)&]P=&EO
M;G,I.PH@("`@("`@('T@96QS92!I9B`H<W1R8V%S96-M<"@D=&AI<RT^=7)L
M<&%R='-;)W-C:&5M92==+"`G2%144%,G*2`]/2`P*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W-E;F1(5%104R@D;7-G+"`D;W!T:6]N<RD["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]R86ES95-O87!&875L
M="@G26YV86QI9"!U<FP@<V-H96UE("<N)'1H:7,M/G5R;"D["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!S970@9&%T82!F;W(@:'1T<"!A=71H96YT:6-A=&EO
M;@H@("`@("H@8W)E871E<R!!=71H;W)I>F%T:6]N(&AE861E<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("`@=7-E<FYA;64*("`@
M("`J($!P87)A;2!S=')I;F<@)'!A<W-W;W)D("`@<F5S<&]N<V4@9&%T82P@
M;6EN=7,@:'1T<"!H96%D97)S"B`@("`@*@H@("`@("H@0')E='5R;B!N;VYE
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S
M971#<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S=V]R9"D*("`@('L*("`@
M("`@("`D=&AI<RT^:&5A9&5R<ULG075T:&]R:7IA=&EO;B==(#T@)T)A<VEC
M("<@+B!B87-E-C1?96YC;V1E*"1U<V5R;F%M92`N("<Z)R`N("1P87-S=V]R
M9"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!!9&0@82!C;V]K:64*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'!A<F%M("!S=')I;F<@
M("1N86UE("`@8V]O:VEE(&YA;64*("`@("`J($!P87)A;2`@;6EX960@("`D
M=F%L=64@(&-O;VMI92!V86QU90H@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9$-O;VMI92@D;F%M92P@)'9A;'5E*0H@("`@
M>PH@("`@("`@("1T:&ES+3YC;V]K:65S6R1N86UE73TD=F%L=64["B`@("!]
M"@H@("`@+R\@<')I=F%T92!M971H;V1S"@H@("`@+RHJ"B`@("`@*B!'96YE
M<F%T97,@=&AE(&-O<G)E8W0@:&5A9&5R<R!F;W(@=&AE(&-O;VMI97,*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!R971U<FX@=F]I
M9`H@("`@("HO"B`@("!F=6YC=&EO;B!?9V5N0V]O:VEE2&5A9&5R*"D*("`@
M('L*("`@("`@("!F;W)E86-H("@D=&AI<RT^8V]O:VEE<R!A<R`D;F%M93T^
M)'9A;'5E*2!["B`@("`@("`@("`@("1C;V]K:65S(#T@*&ES<V5T*"1C;V]K
M:65S*2`_("1C;V]K:65S+B`G.R`G(#H@)R<I("X*("`@("`@("`@("`@("`@
M("`@("`@("`@=7)L96YC;V1E*"1N86UE*2`N("<])R`N('5R;&5N8V]D92@D
M=F%L=64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;VMI97,["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!V86QI9&%T92!U<FP@9&%T82!P87-S960@
M=&\@8V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J($!R971U<FX@8F]O;&5A;@H@("`@("HO"B`@("!F=6YC=&EO;B!?
M=F%L:61A=&55<FPH*0H@("`@>PH@("`@("`@(&EF("@@(2!I<U]A<G)A>2@D
M=&AI<RT^=7)L<&%R=',I("D@>PH@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*")5;F%B;&4@=&\@<&%R<V4@55),("(@+B`D=&AI<RT^=7)L
M*3L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!I9B`H(6ES<V5T*"1T:&ES+3YU<FQP87)T<ULG:&]S="==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*").;R!H;W-T(&EN(%52
M3"`B("X@)'1H:7,M/G5R;"D["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^=7)L<&%R='-;
M)W!O<G0G72DI('L*"B`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1T:&ES
M+3YU<FQP87)T<ULG<V-H96UE)UTL("=(5%10)RD@/3T@,"D*("`@("`@("`@
M("`@("`@("1T:&ES+3YU<FQP87)T<ULG<&]R="==(#T@.#`["B`@("`@("`@
M("`@(&5L<V4@:68@*'-T<F-A<V5C;7`H)'1H:7,M/G5R;'!A<G1S6R=S8VAE
M;64G72P@)TA45%!3)RD@/3T@,"D*("`@("`@("`@("`@("`@("1T:&ES+3YU
M<FQP87)T<ULG<&]R="==(#T@-#0S.PH*("`@("`@("!]"B`@("`@("`@:68@
M*&ES<V5T*"1T:&ES+3YU<FQP87)T<ULG=7-E<B==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^<V5T0W)E9&5N=&EA;',H=7)L9&5C;V1E*"1T:&ES+3YU<FQP
M87)T<ULG=7-E<B==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=7)L9&5C;V1E*"1T:&ES+3YU<FQP87)T<ULG<&%S<R==*2D["B`@
M("`@("`@?0H@("`@("`@(&EF("@A:7-S970H)'1H:7,M/G5R;'!A<G1S6R=P
M871H)UTI('Q\("$D=&AI<RT^=7)L<&%R='-;)W!A=&@G72D*("`@("`@("`@
M("`@)'1H:7,M/G5R;'!A<G1S6R=P871H)UT@/2`G+R<["B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&:6YD<R!O=70@=VAA
M="!I<R!T:&4@96YC;V1I;F<N"B`@("`@*@H@("`@("H@4V5T<R!T:&4@;V)J
M96-T('!R;W!E<G1Y(&%C8V]R9&EN9VQY+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("H@0'!A<F%M("!A<G)A>2`D:&5A9&5R<R`@:&5A
M9&5R<PH@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N
M(%]P87)S945N8V]D:6YG*"1H96%D97)S*0H@("`@>PH@("`@("`@("1H(#T@
M<W1R:7-T<B@D:&5A9&5R<RP@)T-O;G1E;G0M5'EP92<I.PH@("`@("`@('!R
M96=?;6%T8VA?86QL*"<O7D-O;G1E;G0M5'EP93I<<RHH+BHI)"]I;2<L("1H
M+"`D8W0L(%!214=?4T547T]21$52*3L*("`@("`@("`D;B`](&-O=6YT*"1C
M="D["B`@("`@("`@)&-T(#T@)&-T6R1N("T@,5T["B`@("`@("`@)'1H:7,M
M/G)E<W5L=%]C;VYT96YT7W1Y<&4@/2!S=')?<F5P;&%C92@B7'(B+"`G)RP@
M)&-T6S%=*3L*("`@("`@("!I9B`H<')E9U]M871C:"@G+R@N*C\I*#\Z.UQS
M/V-H87)S970]*2@N*BDO:2<L("1T:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E
M+"`D;2DI('L*("`@("`@("`@("`@+R\@<W1R:7`@=&AE('-T<FEN9R!O9B!<
M<@H@("`@("`@("`@("`D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP92`]("1M
M6S%=.PH@("`@("`@("`@("!I9B`H8V]U;G0H)&TI(#X@,BD@>PH@("`@("`@
M("`@("`@("`@)&5N8R`]('-T<G1O=7!P97(H<W1R7W)E<&QA8V4H)R(G+"`G
M)RP@)&U;,ETI*3L*("`@("`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D96YC
M+"`D=&AI<RT^7V5N8V]D:6YG<RDI('L*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^<F5S=6QT7V5N8V]D:6YG(#T@)&5N8SL*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!D96%L('=I
M=&@@8G)O:V5N('-E<G9E<G,@=&AA="!D;VXG="!S970@8V]N=&5N="!T>7!E
M(&]N(&9A=6QT<PH@("`@("`@(&EF("@A)'1H:7,M/G)E<W5L=%]C;VYT96YT
M7W1Y<&4I("1T:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E(#T@)W1E>'0O>&UL
M)SL*("`@('T*"B`@("`O*BH*("`@("`J(%!A<G-E<R!T:&4@:&5A9&5R<PH@
M("`@("H*("`@("`J($!P87)A;2`@87)R87D@)&AE861E<G,@=&AE(&AE861E
M<G,*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<&%R<V5(96%D97)S*"1H96%D97)S*0H@("`@>PH@("`@("`@("\J(&QA<F=E
M;'D@8F]R<F]W960@9G)O;2!(5%107U)E<75E<W0@*B\*("`@("`@("`D=&AI
M<RT^<F5S=6QT7VAE861E<G,@/2!A<G)A>2@I.PH@("`@("`@("1H96%D97)S
M(#T@<W!L:70H(EQR/UQN(BP@)&AE861E<G,I.PH@("`@("`@(&9O<F5A8V@@
M*"1H96%D97)S(&%S("1V86QU92D@>PH@("`@("`@("`@("!I9B`H<W1R<&]S
M*"1V86QU92PG.B<I(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G)E<W5L=%]H96%D97)S6S!=/21V86QU93L*("`@("`@("`@("`@("`@
M(&-O;G1I;G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&QI<W0H)&YA
M;64L)'9A;'5E*2`]('-P;&ET*"<Z)RPD=F%L=64I.PH@("`@("`@("`@("`D
M:&5A9&5R;F%M92`]('-T<G1O;&]W97(H)&YA;64I.PH@("`@("`@("`@("`D
M:&5A9&5R=F%L=64@/2!T<FEM*"1V86QU92D["B`@("`@("`@("`@("1T:&ES
M+3YR97-U;'1?:&5A9&5R<ULD:&5A9&5R;F%M95T])&AE861E<G9A;'5E.PH*
M("`@("`@("`@("`@:68@*"1H96%D97)N86UE(#T]("=S970M8V]O:VEE)RD@
M>PH@("`@("`@("`@("`@("`@+R\@4&%R<V4@82!3971#;V]K:64@:&5A9&5R
M('1O(&9I;&P@7V-O;VMI97,@87)R87D*("`@("`@("`@("`@("`@("1C;V]K
M:64@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G97AP:7)E<R<@/3X@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`G9&]M86EN)R`@/3X@)'1H:7,M
M/G5R;'!A<G1S6R=H;W-T)UTL"B`@("`@("`@("`@("`@("`@("`@)W!A=&@G
M("`@(#T^(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@)W-E8W5R92<@(#T^
M(&9A;'-E"B`@("`@("`@("`@("`@("`I.PH*("`@("`@("`@("`@("`@("\O
M($]N;'D@82!N86UE/79A;'5E('!A:7(*("`@("`@("`@("`@("`@(&EF("@A
M<W1R<&]S*"1H96%D97)V86QU92P@)SLG*2D@>PH@("`@("`@("`@("`@("`@
M("`@(&QI<W0H)&-O;VMI95LG;F%M92==+"`D8V]O:VEE6R=V86QU92==*2`]
M(&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D:&5A9&5R=F%L=64I
M*3L*("`@("`@("`@("`@("`@("`@("`D8V]O:VEE6R=N86UE)UT@(#T@=7)L
M9&5C;V1E*"1C;V]K:65;)VYA;64G72D["B`@("`@("`@("`@("`@("`@("`@
M)&-O;VMI95LG=F%L=64G72`]('5R;&1E8V]D92@D8V]O:VEE6R=V86QU92==
M*3L*"B`@("`@("`@("`@("`@("`O+R!3;VUE(&]P=&EO;F%L('!A<F%M971E
M<G,@87)E('-U<'!L:65D"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("1E;&5M96YT<R`](&5X<&QO9&4H)SLG+"`D:&5A
M9&5R=F%L=64I.PH@("`@("`@("`@("`@("`@("`@(&QI<W0H)&-O;VMI95LG
M;F%M92==+"`D8V]O:VEE6R=V86QU92==*2`](&%R<F%Y7VUA<"@G=')I;2<L
M(&5X<&QO9&4H)STG+"`D96QE;65N='-;,%TI*3L*("`@("`@("`@("`@("`@
M("`@("`D8V]O:VEE6R=N86UE)UT@(#T@=7)L9&5C;V1E*"1C;V]K:65;)VYA
M;64G72D["B`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LG=F%L=64G72`]
M('5R;&1E8V]D92@D8V]O:VEE6R=V86QU92==*3L*"B`@("`@("`@("`@("`@
M("`@("`@9F]R("@D:2`](#$[("1I(#P@8V]U;G0H)&5L96UE;G1S*3LD:2LK
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&QI<W0@*"1E;$YA;64L("1E
M;%9A;'5E*2`](&%R<F%Y7VUA<"@G=')I;2<L(&5X<&QO9&4H)STG+"`D96QE
M;65N='-;)&E=*2D["B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@G<V5C
M=7)E)R`]/2`D96Q.86UE*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D8V]O:VEE6R=S96-U<F4G72`]('1R=64["B`@("`@("`@("`@("`@("`@
M("`@("`@('T@96QS96EF("@G97AP:7)E<R<@/3T@)&5L3F%M92D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&-O;VMI95LG97AP:7)E<R==(#T@
M<W1R7W)E<&QA8V4H)R(G+"`G)RP@)&5L5F%L=64I.PH@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V5I9B`H)W!A=&@G(#T]("1E;$YA;64@3U(@)V1O
M;6%I;B<@/3T@)&5L3F%M92D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&-O;VMI95LD96Q.86UE72`]('5R;&1E8V]D92@D96Q686QU92D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8V]O:VEE6R1E;$YA;65=(#T@)&5L5F%L=64["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S
M=6QT7V-O;VMI97-;72`]("1C;V]K:64["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F4@:'1T<"!H96%D97)S
M(&9R;VT@<F5S<&]N<V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?
M<&%R<V5297-P;VYS92@I"B`@("!["B`@("`@("`@:68@*'!R96=?;6%T8V@H
M(B]>*"XJ/RE<<C]<;EQR/UQN*"XJ*2]S(BP@)'1H:7,M/FEN8V]M:6YG7W!A
M>6QO860L("1M871C:"DI('L*("`@("`@("`@("`@(R1T:&ES+3YR97-P;VYS
M92`]('!R96=?<F5P;&%C92@B+UM<<GQ<;ETO(BP@)R<L("1M871C:%LR72D[
M"B`@("`@("`@("`@("1T:&ES+3YR97-P;VYS92`])B`D;6%T8VA;,ET["B`@
M("`@("`@("`@("\O(&9I;F0@=&AE(')E<W!O;G-E(&5R<F]R+"!S;VUE('-E
M<G9E<G,@<F5S<&]N<V4@=VET:"`U,#`@9F]R('-O87`@9F%U;'1S"B`@("`@
M("`@("`@("1T:&ES+3Y?<&%R<V5(96%D97)S*"1M871C:%LQ72D["@H@("`@
M("`@("`@("!L:7-T*"1P<F]T;V-O;"P@)&-O9&4L("1M<V<I(#T@<W-C86YF
M*"1T:&ES+3YR97-U;'1?:&5A9&5R<ULP72P@)R5S("5S("5S)RD["B`@("`@
M("`@("`@('5N<V5T*"1T:&ES+3YR97-U;'1?:&5A9&5R<ULP72D["@H@("`@
M("`@("`@("!S=VET8V@H)&-O9&4I('L*("`@("`@("`@("`@("`@(&-A<V4@
M,3`P.B`O+R!#;VYT:6YU90H@("`@("`@("`@("`@("`@("`@)'1H:7,M/FEN
M8V]M:6YG7W!A>6QO860@/2`D;6%T8VA;,ET["B`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/E]P87)S95)E<W!O;G-E*"D["B`@("`@("`@("`@
M("`@("!C87-E(#0P,#H*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*")(5%10(%)E<W!O;G-E("1C;V1E($)A9"!297%U97-T
M(BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`T,#$Z
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L="@B
M2%144"!297-P;VYS92`D8V]D92!!=71H96YT:6-A=&EO;B!&86EL960B*3L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(#0P,SH*("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")(5%10
M(%)E<W!O;G-E("1C;V1E($9O<F)I9&1E;B(I.PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&-A<V4@-#`T.@H@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N<V4@)&-O9&4@
M3F]T($9O=6YD(BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M8V%S92`T,#<Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O
M87!&875L="@B2%144"!297-P;VYS92`D8V]D92!0<F]X>2!!=71H96YT:6-A
M=&EO;B!297%U:7)E9"(I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@(&-A<V4@-#`X.@H@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I
M<V53;V%P1F%U;'0H(DA45%`@4F5S<&]N<V4@)&-O9&4@4F5Q=65S="!4:6UE
M;W5T(BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`T
M,3`Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]R86ES95-O87!&875L
M="@B2%144"!297-P;VYS92`D8V]D92!';VYE(BD["B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-O9&4@/CT@-#`P("8F("1C;V1E(#P@-3`P*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H(DA45%`@
M4F5S<&]N<V4@)&-O9&4@3F]T($9O=6YD+"!397)V97(@;65S<V%G93H@)&US
M9R(I.PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`D=&AI<RT^7W!A<G-E16YC;V1I;F<H)&UA=&-H6S%=*3L*"B`@("`@("`@
M("`@(&EF("@D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP92`]/2`G87!P;&EC
M871I;VXO9&EM92<I('L*("`@("`@("`@("`@("`@("\O(%A86"!Q=6EC:R!H
M86-K(&EN<V5R=&EO;B!O9B!$24U%"B`@("`@("`@("`@("`@("!I9B`H4$5!
M4CHZ:7-%<G)O<B@D=&AI<RT^7V1E8V]D941)345-97-S86=E*"1T:&ES+3YR
M97-P;VYS92PD=&AI<RT^:&5A9&5R<RPD=&AI<RT^871T86-H;65N=',I*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\O(%]D96-O9&5$24U%365S<V%G92!A
M;')E861Y(')A:7-E9"`D=&AI<RT^9F%U;'0*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP92`]("1T:&ES+3YH96%D
M97)S6R=C;VYT96YT+71Y<&4G73L*("`@("`@("`@("`@?2!E;'-E(&EF("AS
M=')I<W1R*"1T:&ES+3YR97-U;'1?8V]N=&5N=%]T>7!E+"=M=6QT:7!A<G0O
M<F5L871E9"<I*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^<F5S<&]N<V4@
M/2`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9#L*("`@("`@("`@("`@("`@(&EF
M("A014%2.CII<T5R<F]R*"1T:&ES+3Y?9&5C;V1E36EM94UE<W-A9V4H)'1H
M:7,M/G)E<W!O;G-E+"1T:&ES+3YH96%D97)S+"1T:&ES+3YA='1A8VAM96YT
M<RDI*2!["B`@("`@("`@("`@("`@("`@("`@+R\@7V1E8V]D94UI;65-97-S
M86=E(&%L<F5A9'D@<F%I<V5D("1T:&ES+3YF875L=`H@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E(&EF("@D=&AI<RT^<F5S=6QT7V-O;G1E;G1?='EP92`A
M/2`G=&5X="]X;6PG*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7W)A:7-E
M4V]A<$9A=6QT*"1T:&ES+3YR97-P;VYS92D["B`@("`@("`@("`@("`@("!R
M971U<FX@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("`@("`@+R\@:68@
M;F\@8V]N=&5N="P@<F5T=7)N(&9A;'-E"B`@("`@("`@("`@(')E='5R;B!S
M=')L96XH)'1H:7,M/G)E<W!O;G-E*2`^(#`["B`@("`@("`@?0H@("`@("`@
M("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)TEN=F%L:60@2%144"!297-P;VYS
M92<I.PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O*BH*("`@
M("`J($-R96%T92!H='1P(')E<75E<W0L(&EN8VQU9&EN9R!H96%D97)S+"!F
M;W(@;W5T9V]I;F<@<F5Q=65S=`H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@("`F)&US9R`@(&]U=&=O:6YG(%-/05`@<&%C:V%G90H@("`@("H@0'!A
M<F%M("1O<'1I;VYS"B`@("`@*B!`<F5T=7)N('-T<FEN9R!O=71G;VEN9U]P
M87EL;V%D"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@)E]G971297%U97-T*"8D;7-G+"`D;W!T:6]N<RD*("`@('L*("`@
M("`@("`D86-T:6]N(#T@:7-S970H)&]P=&EO;G-;)W-O87!A8W1I;VXG72D_
M)&]P=&EO;G-;)W-O87!A8W1I;VXG73HG)SL*("`@("`@("`D9G5L;'!A=&@@
M/2`D=&AI<RT^=7)L<&%R='-;)W!A=&@G72X*("`@("`@("`@("`@("`@("`@
M("`@("`@*&ES<V5T*"1T:&ES+3YU<FQP87)T<ULG<75E<GDG72D_)S\G+B1T
M:&ES+3YU<FQP87)T<ULG<75E<GDG73HG)RDN"B`@("`@("`@("`@("`@("`@
M("`@("`@("AI<W-E="@D=&AI<RT^=7)L<&%R='-;)V9R86=M96YT)UTI/R<C
M)RXD=&AI<RT^=7)L<&%R='-;)V9R86=M96YT)UTZ)R<I.PH*("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;)W!R;WAY7VAO<W0G72DI('L*("`@("`@("`@
M("`@)&9U;&QP871H(#T@)VAT='`Z+R\G("X@)'1H:7,M/G5R;'!A<G1S6R=H
M;W-T)UT@+B`G.B<@+B`D=&AI<RT^=7)L<&%R='-;)W!O<G0G72`N("1F=6QL
M<&%T:#L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG
M<')O>'E?=7-E<B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^:&5A9&5R<ULG
M4')O>'DM075T:&]R:7IA=&EO;B==(#T@)T)A<VEC("<@+B!B87-E-C1?96YC
M;V1E*"1O<'1I;VYS6R=P<F]X>5]U<V5R)UTN(CHB+B1O<'1I;VYS6R=P<F]X
M>5]P87-S)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R=U<V5R)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YS971#<F5D96YT
M:6%L<R@D;W!T:6]N<ULG=7-E<B==+"`D;W!T:6]N<ULG<&%S<R==*3L*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YH96%D97)S6R=5<V5R+4%G96YT)UT@
M/2`D=&AI<RT^7W5S97)!9V5N=#L*("`@("`@("`D=&AI<RT^:&5A9&5R<ULG
M2&]S="==(#T@)'1H:7,M/G5R;'!A<G1S6R=H;W-T)UT["B`@("`@("`@)'1H
M:7,M/FAE861E<G-;)T-O;G1E;G0M5'EP92==(#T@(G1E>'0O>&UL.R!C:&%R
M<V5T/21T:&ES+3YE;F-O9&EN9R(["B`@("`@("`@)'1H:7,M/FAE861E<G-;
M)T-O;G1E;G0M3&5N9W1H)UT@/2!S=')L96XH)&US9RD["B`@("`@("`@)'1H
M:7,M/FAE861E<G-;)U-/05!!8W1I;VXG72`](")<(B1A8W1I;VY<(B(["B`@
M("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R=H96%D97)S)UTI*2!["B`@("`@
M("`@("`@("1T:&ES+3YH96%D97)S(#T@87)R87E?;65R9V4H)'1H:7,M/FAE
M861E<G,L("1O<'1I;VYS6R=H96%D97)S)UTI.PH@("`@("`@('T*"B`@("`@
M("`@)'1H:7,M/F-O;VMI97,@/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-S
M970H)&]P=&EO;G-;)VYO8V]O:VEE<R==*2!\?"`A)&]P=&EO;G-;)VYO8V]O
M:VEE<R==*2!["B`@("`@("`@("`@("\O(&%D9"!T:&4@8V]O:VEE<R!W92!G
M;W0@9G)O;2!T:&4@;&%S="!R97%U97-T"B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^<F5S=6QT7V-O;VMI97,I*2!["B`@("`@("`@("`@("`@("!F
M;W)E86-H("@D=&AI<RT^<F5S=6QT7V-O;VMI97,@87,@)&-O;VMI92D@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D8V]O:VEE6R=D;VUA:6XG72`]/2`D
M=&AI<RT^=7)L<&%R='-;)VAO<W0G72D*("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F-O;VMI97-;)&-O;VMI95LG;F%M92==73TD8V]O:VEE6R=V
M86QU92==.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H@("`@("`@("\O(&%D9"!C;V]K:65S('1H92!U<V5R('=A;G1S('1O
M('-E=`H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULG8V]O:VEE<R==*2D@
M>PH@("`@("`@("`@("!F;W)E86-H("@D;W!T:6]N<ULG8V]O:VEE<R==(&%S
M("1C;V]K:64I('L*("`@("`@("`@("`@("`@(&EF("@D8V]O:VEE6R=D;VUA
M:6XG72`]/2`D=&AI<RT^=7)L<&%R='-;)VAO<W0G72D*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^8V]O:VEE<ULD8V]O:VEE6R=N86UE)UU=/21C;V]K
M:65;)W9A;'5E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M:68@*&-O=6YT*"1T:&ES+3YC;V]K:65S*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^:&5A9&5R<ULG0V]O:VEE)UT@/2`D=&AI<RT^7V=E;D-O;VMI94AE861E
M<B@I.PH@("`@("`@('T*("`@("`@("`D:&5A9&5R<R`]("<G.PH@("`@("`@
M(&9O<F5A8V@@*"1T:&ES+3YH96%D97)S(&%S("1K(#T^("1V*2!["B`@("`@
M("`@("`@("1H96%D97)S("X]("(D:SH@)'9<<EQN(CL*("`@("`@("!]"B`@
M("`@("`@)'1H:7,M/F]U=&=O:6YG7W!A>6QO860@/0H@("`@("`@("`@("`@
M("`@(E!/4U0@)&9U;&QP871H($A45%`O,2XP7')<;B(N"B`@("`@("`@("`@
M("`@("`D:&5A9&5R<RXB7')<;B(N"B`@("`@("`@("`@("`@("`D;7-G.PH@
M("`@("`@(')E='5R;B`D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9#L*("`@('T*
M"B`@("`O*BH*("`@("`J(%-E;F0@;W5T9V]I;F<@<F5Q=65S="P@86YD(')E
M860O<&%R<V4@<F5S<&]N<V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`F)&US9R`@(&]U=&=O:6YG(%-/05`@<&%C:V%G90H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)&%C=&EO;B`@(%-/05`@06-T:6]N"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`F)')E<W!O;G-E("`@<F5S<&]N<V4@9&%T82P@;6EN=7,@:'1T
M<"!H96%D97)S"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@)E]S96YD2%144"@F)&US9RP@)&]P=&EO;G,I"B`@("!["B`@
M("`@("`@)'1H:7,M/FEN8V]M:6YG7W!A>6QO860@/2`G)SL*("`@("`@("`D
M=&AI<RT^7V=E=%)E<75E<W0H)&US9RP@)&]P=&EO;G,I.PH@("`@("`@("1H
M;W-T(#T@)'1H:7,M/G5R;'!A<G1S6R=H;W-T)UT["B`@("`@("`@)'!O<G0@
M/2`D=&AI<RT^=7)L<&%R='-;)W!O<G0G73L*("`@("`@("!I9B`H:7-S970H
M)&]P=&EO;G-;)W!R;WAY7VAO<W0G72DI('L*("`@("`@("`@("`@)&AO<W0@
M/2`D;W!T:6]N<ULG<')O>'E?:&]S="==.PH@("`@("`@("`@("`D<&]R="`]
M(&ES<V5T*"1O<'1I;VYS6R=P<F]X>5]P;W)T)UTI(#\@)&]P=&EO;G-;)W!R
M;WAY7W!O<G0G72`Z(#@P.#`["B`@("`@("`@?0H@("`@("`@("\O('-E;F0*
M("`@("`@("!I9B`H)'1H:7,M/G1I;65O=70@/B`P*2!["B`@("`@("`@("`@
M("1F<"`]($!F<V]C:V]P96XH)&AO<W0L("1P;W)T+"`D=&AI<RT^97)R;F\L
M("1T:&ES+3YE<G)M<V<L("1T:&ES+3YT:6UE;W5T*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D9G`@/2!`9G-O8VMO<&5N*"1H;W-T+"`D<&]R
M="P@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R;7-G*3L*("`@("`@("!]"B`@
M("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?
M<F%I<V53;V%P1F%U;'0H(D-O;FYE8W0@17)R;W(@=&\@)&AO<W0Z)'!O<G0B
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YT:6UE;W5T(#X@,"D@
M>PH@("`@("`@("`@("`O+R!S;VUE(&)U:6QD<R!O9B!P:'`@9&\@;F]T('-U
M<'!O<G0@=&AI<RP@<VEL96YC90H@("`@("`@("`@("`O+R!T:&4@=V%R;FEN
M9PH@("`@("`@("`@("!`<V]C:V5T7W-E=%]T:6UE;W5T*"1F<"P@)'1H:7,M
M/G1I;65O=70I.PH@("`@("`@('T*("`@("`@("!I9B`H(69P=71S*"1F<"P@
M)'1H:7,M/F]U=&=O:6YG7W!A>6QO860L('-T<FQE;B@D=&AI<RT^;W5T9V]I
M;F=?<&%Y;&]A9"DI*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7W)A
M:7-E4V]A<$9A=6QT*")%<G)O<B!03U-4:6YG($1A=&$@=&\@)&AO<W0B*3L*
M("`@("`@("!]"@H@("`@("`@("\O(&=E="!R97!O;G-E"B`@("`@("`@+R\@
M6%A8('1I;64@8V]N<W5M97(*("`@("`@("!D;R!["B`@("`@("`@("`@("1D
M871A(#T@9G)E860H)&9P+"`T,#DV*3L*("`@("`@("`@("`@)%]T;7!?<W1A
M='5S(#T@<V]C:V5T7V=E=%]S=&%T=7,H)&9P*3L*("`@("`@("`@("`@:68@
M*"1?=&UP7W-T871U<ULG=&EM961?;W5T)UTI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^7W)A:7-E4V]A<$9A=6QT*")4:6UE9"!O=70@<F5A
M9"!F<F]M("1H;W-T(BD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"`N/2`D9&%T83L*("`@
M("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"$D7W1M<%]S=&%T=7-;)V5O
M9B==*3L*"B`@("`@("`@9F-L;W-E*"1F<"D["@H@("`@("`@(&EF("@A)'1H
M:7,M/E]P87)S95)E<W!O;G-E*"DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YF875L=#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR
M97-P;VYS93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E;F0@;W5T9V]I;F<@
M<F5Q=65S="P@86YD(')E860O<&%R<V4@<F5S<&]N<V4L('9I82!(5%104PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("8D;7-G("`@;W5T9V]I;F<@
M4T]!4"!P86-K86=E"B`@("`@*B!`<&%R86T@<W1R:6YG("`D86-T:6]N("`@
M4T]!4"!!8W1I;VX*("`@("`J($!R971U<FX@<W1R:6YG("8D<F5S<&]N<V4@
M("!R97-P;VYS92!D871A+"!M:6YU<R!H='1P(&AE861E<G,*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B`F7W-E;F1(5%10
M4R@F)&US9RP@)&]P=&EO;G,I"B`@("!["B`@("`@("`@+RH@3D]412!4:&ES
M(&9U;F-T:6]N('5S97,@=&AE($-54DP@9G5N8W1I;VYS"B`@("`@("`@("H@
M(%EO=7(@<&AP(&UU<W0@8F4@8V]M<&EL960@=VET:"!#55),"B`@("`@("`@
M("HO"B`@("`@("`@:68@*"%E>'1E;G-I;VY?;&]A9&5D*"=C=7)L)RDI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?<F%I<V53;V%P1F%U;'0H)T-5
M4DP@17AT96YS:6]N(&ES(')E<75I<F5D(&9O<B!(5%104R<I.PH@("`@("`@
M('T*"B`@("`@("`@)&-H(#T@8W5R;%]I;FET*"D["@H@("`@("`@(&EF("AI
M<W-E="@D;W!T:6]N<ULG<')O>'E?:&]S="==*2D@>PH@("`@("`@("`@("`O
M+R`D;W!T:6]N<ULG:'1T<%]P<F]X>2==(#T]("=H;W-T;F%M93IP;W)T)PH@
M("`@("`@("`@("`D:&]S="`]("1O<'1I;VYS6R=P<F]X>5]H;W-T)UT["B`@
M("`@("`@("`@("1P;W)T(#T@:7-S970H)&]P=&EO;G-;)W!R;WAY7W!O<G0G
M72D@/R`D;W!T:6]N<ULG<')O>'E?<&]R="==(#H@.#`X,#L*("`@("`@("`@
M("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U!23UA9+"`D:&]S="`N("(Z
M(B`N("1P;W)T*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N<ULG<')O>'E?=7-E<B==*2D@>PH@("`@("`@("`@("`O+R`D;W!T:6]N
M<ULG:'1T<%]P<F]X>5]U<V5R<'<G72`]/2`G=7-E<FYA;64Z<&%S<W=O<F0G
M"B`@("`@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]04D]86553
M15)05T0L("1O<'1I;VYS6R=P<F]X>5]U<V5R)UT@+B`G.B<@+B`D;W!T:6]N
M<ULG<')O>'E?<&%S<R==*3L*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E
M="@D;W!T:6]N<ULG=7-E<B==*2D@>PH@("`@("`@("`@("!C=7)L7W-E=&]P
M="@D8V@L($-54DQ/4%1?55-%4E!71"P@)&]P=&EO;G-;)W5S97(G72`N("<Z
M)R`N("1O<'1I;VYS6R=P87-S)UTI.PH@("`@("`@('T*"B`@("`@("`@:68@
M*"%I<W-E="@D;W!T:6]N<ULG<V]A<&%C=&EO;B==*2D@>PH@("`@("`@("`@
M("`D;W!T:6]N<ULG<V]A<&%C=&EO;B==(#T@)R<["B`@("`@("`@?0H@("`@
M("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%](5%102$5!1$52("P@("`@
M87)R87DH)T-O;G1E;G0M5'EP93H@=&5X="]X;6P[8VAA<G-E=#TG("X@)'1H
M:7,M/F5N8V]D:6YG+"`G4T]!4$%C=&EO;CH@(B<N)&]P=&EO;G-;)W-O87!A
M8W1I;VXG72XG(B<I*3L*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/
M4%1?55-%4D%'14Y4("P@("`@("1T:&ES+3Y?=7-E<D%G96YT*3L*"B`@("`@
M("`@:68@*"1T:&ES+3YT:6UE;W5T*2!["B`@("`@("`@("`@(&-U<FQ?<V5T
M;W!T*"1C:"P@0U523$]05%]424U%3U54+"`D=&AI<RT^=&EM96]U="D[("\O
M=&EM97,@;W5T(&%F=&5R(#1S"B`@("`@("`@?0H*("`@("`@("!C=7)L7W-E
M=&]P="@D8V@L($-54DQ/4%1?4$]35$9)14Q$4RP@("`@("`@)&US9RD["B`@
M("`@("`@8W5R;%]S971O<'0H)&-H+"!#55),3U!47U523"P@("`@("`@("`@
M("`@("1T:&ES+3YU<FPI.PH@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U52
M3$]05%]03U-4+"`@("`@("`@("`@("`Q*3L*("`@("`@("!C=7)L7W-E=&]P
M="@D8V@L($-54DQ/4%1?1D%)3$].15)23U(L("`@("`@,"D["B`@("`@("`@
M8W5R;%]S971O<'0H)&-H+"!#55),3U!47T9/3$Q/5TQ/0T%424].+"`@(#$I
M.PH@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@0U523$]05%]215154DY44D%.
M4T9%4BP@("`Q*3L*("`@("`@("!C=7)L7W-E=&]P="@D8V@L($-54DQ/4%1?
M2$5!1$52+"`@("`@("`@("`@,2D["B`@("`@("`@:68@*&1E9FEN960H)T-5
M4DQ/4%1?2%144%]615)324].)RDI('L*("`@("`@("`@("`@8W5R;%]S971O
M<'0H)&-H+"!#55),3U!47TA45%!?5D524TE/3BP@,2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;)V-U<FPG72DI('L*("`@("`@
M("`@("`@9F]R96%C:"`H)&]P=&EO;G-;)V-U<FPG72!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("`@("`@("`@(&-U<FQ?<V5T;W!T*"1C:"P@)&ME>2P@
M)'9A;"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(%-A
M=F4@=&AE(&]U=&=O:6YG(%A-3"X@5&AI<R!D;V5S;B=T('%U:71E(&UA=&-H
M(%]S96YD2%144`H@("`@("`@("\O(&%S($-54DP@9V5N97)A=&5S('1H92!H
M96%D97)S+"!B=70@:&%V:6YG('1H92!834P@:7,*("`@("`@("`O+R!U<W5A
M;&QY('1H92!M;W-T(&EM<&]R=&%N="!P87)T(&9O<B!T<F%C:6YG+V1E8G5G
M9VEN9RX*("`@("`@("`D=&AI<RT^;W5T9V]I;F=?<&%Y;&]A9"`]("1M<V<[
M"@H@("`@("`@("1T:&ES+3YI;F-O;6EN9U]P87EL;V%D(#T@8W5R;%]E>&5C
M*"1C:"D["B`@("`@("`@:68@*"$D=&AI<RT^:6YC;VUI;F=?<&%Y;&]A9"D@
M>PH@("`@("`@("`@("`D;2`]("=C=7)L7V5X96,@97)R;W(@)R`N(&-U<FQ?
M97)R;F\H)&-H*2`N("<@)R`N(&-U<FQ?97)R;W(H)&-H*3L*("`@("`@("`@
M("`@8W5R;%]C;&]S92@D8V@I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/E]R86ES95-O87!&875L="@D;2D["B`@("`@("`@?0H@("`@("`@(&-U<FQ?
M8VQO<V4H)&-H*3L*"B`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E4F5S<&]N
M<V4H*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F9A=6QT.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR97-P;VYS93L*("`@('T*
M"GT*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B],;V<O8V]M
M<&]S:71E+G!H<```````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$Q-S8W(#$P-3$U-#,T,3,S(#`R,3<S,0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO*BH*("H@)$AE861E
M<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+V-O;7!O<VET92YP:'`L=B`Q
M+C(V(#(P,#4O,#@O,C0@,#4Z,#DZ-#4@:F]N($5X<"`D"B`J("1(;W)D93H@
M:&]R9&4O;&EB+TQO9R]C;VUP;W-I=&4N<&AP+'8@,2XR(#(P,#`O,#8O,C@@
M,C$Z,S8Z,3,@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO;CH@
M,2XR-B`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7V-O
M;7!O<VET93HZ(&-L87-S(&EM<&QE;65N=',@82!#;VUP;W-I=&4@<&%T=&5R
M;B!W:&EC:`H@*B!A;&QO=W,@;75L=&EP;&4@3&]G(&EM<&QE;65N=&%T:6]N
M<R!T;R!R96-E:79E('1H92!S86UE(&5V96YT<RX*("H*("H@0&%U=&AO<B`@
M0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*@H@*B!`<VEN8V4@2&]R9&4@
M,2XS"B`J($!S:6YC92!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`
M97AA;7!L92!C;VUP;W-I=&4N<&AP("`@57-I;F<@=&AE(&-O;7!O<VET92!H
M86YD;&5R+@H@*B\*8VQA<W,@3&]G7V-O;7!O<VET92!E>'1E;F1S($QO9PI[
M"B`@("`O*BH*("`@("`J($%R<F%Y(&AO;&1I;F<@86QL(&]F('1H92!,;V<@
M:6YS=&%N8V5S('1O('=H:6-H(&QO9R!E=F5N=',@<VAO=6QD(&)E"B`@("`@
M*B!S96YT+@H@("`@("H*("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C:&EL9')E;B`](&%R<F%Y
M*"D["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!C;VUP;W-I
M=&4@3&]G(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@
M("1N86UE("`@("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@
M*B!`<&%R86T@8F]O;&5A;B`@("1I9&5N="`@("`@(%1H:7,@<&%R86UE=&5R
M(&ES(&EG;F]R960N"B`@("`@*B!`<&%R86T@8F]O;&5A;B`@("1C;VYF("`@
M("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R960N"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`@("1L979E;"`@("`@(%1H:7,@<&%R86UE=&5R(&ES(&EG;F]R
M960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@3&]G7V-O;7!O<VET92@D;F%M92P@)&ED96YT(#T@)R<L("1C
M;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@)&QE
M=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I
M9&5N="`]("1I9&5N=#L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS('1H
M92!C:&EL9"!C;VYN96-T:6]N<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@
M("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3Y?8VAI;&1R96X@87,@)&ED(#T^("1C:&EL9"D@>PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD:61=+3YO<&5N*"D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@
M("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E<R!A;GD@8VAI
M;&0@:6YS=&%N8V5S+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H
M)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD*2!["B`@("`@("`@("`@("`@
M("`D=&AI<RT^7V-H:6QD<F5N6R1I9%TM/F-L;W-E*"D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@
M("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;'5S:&5S(&%L;"!O<&5N(&-H
M:6QD(&EN<W1A;F-E<RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F
M;'5S:"@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@
M("`@("`@("`@(&9O<F5A8V@@*"1T:&ES+3Y?8VAI;&1R96X@87,@)&ED(#T^
M("1C:&EL9"D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD
M:61=+3YF;'5S:"@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@4V5N9',@)&UE<W-A9V4@86YD("1P<FEO<FET>2!T
M;R!E86-H(&-H:6QD(&]F('1H:7,@8V]M<&]S:71E+@H@("`@("H*("`@("`J
M($!P87)A;2!M:7AE9"`@("`@)&UE<W-A9V4@("`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@
M("`@)'!R:6]R:71Y("`@*&]P=&EO;F%L*2!4:&4@<')I;W)I='D@;V8@=&AE
M(&UE<W-A9V4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%9A;&ED('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U]!3$525"P@4$5!
M4E],3T=?0U))5"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%
M05)?3$]'7TE.1D\L(&%N9`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!014%27TQ/1U]$14)51RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AE(&5N=')Y(&ES('-U8V-E<W-F=6QL>2!L
M;V=G960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@
M("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E
M8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@
M*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@
M/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@9F]R96%C
M:"`H)'1H:7,M/E]C:&EL9')E;B!A<R`D:60@/3X@)&-H:6QD*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8VAI;&1R96Y;)&ED72T^;&]G*"1M97-S86=E+"`D
M<')I;W)I='DI.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC
M92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^
M("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@
M("\J*@H@("`@("H@4F5T=7)N<R!T<G5E(&EF('1H:7,@:7,@82!C;VUP;W-I
M=&4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&EF('1H
M:7,@:7,@82!C;VUP;W-I=&4@8VQA<W,N"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@:7-#;VUP;W-I=&4H*0H@
M("`@>PH@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@
M("H@4V5T<R!T:&ES(&ED96YT:69I8V%T:6]N('-T<FEN9R!F;W(@86QL(&]F
M('1H:7,@8V]M<&]S:71E)W,@8VAI;&1R96XN"B`@("`@*@H@("`@("H@0'!A
M<F%M('-T<FEN9R`@("`D:61E;G0@("`@("!4:&4@;F5W(&ED96YT:69I8V%T
M:6]N('-T<FEN9RX*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-I;F-E("!,;V<@,2XV+C<*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T
M261E;G0H)&ED96YT*0H@("`@>PH@("`@("`@("\J($-A;&P@;W5R(&)A<V4@
M8VQA<W,G<R!S971)9&5N="@I(&UE=&AO9"X@*B\*("`@("`@("!P87)E;G0Z
M.G-E=$ED96YT*"1I9&5N="D["@H@("`@("`@("\J("XN+B!A;F0@=&AE;B!C
M86QL('-E=$ED96YT*"D@;VX@86QL(&]F(&]U<B!C:&EL9')E;BX@*B\*("`@
M("`@("!F;W)E86-H("@D=&AI<RT^7V-H:6QD<F5N(&%S("1I9"`]/B`D8VAI
M;&0I('L*("`@("`@("`@("`@)'1H:7,M/E]C:&EL9')E;ELD:61=+3YS971)
M9&5N="@D:61E;G0I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M($%D9',@82!,;V<@:6YS=&%N8V4@=&\@=&AE(&QI<W0@;V8@8VAI;&1R96XN
M"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`@("`D8VAI;&0@("`@("!4
M:&4@3&]G(&EN<W1A;F-E('1O(&%D9"X*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@:68@=&AE($QO9R!I;G-T86YC92!W87,@<W5C8V5S
M<V9U;&QY(&%D9&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%D9$-H:6QD*"8D8VAI;&0I"B`@("!["B`@
M("`@("`@+RH@36%K92!S=7)E('1H:7,@:7,@82!,;V<@:6YS=&%N8V4N("HO
M"B`@("`@("`@:68@*"%I<U]A*"1C:&EL9"P@)TQO9R<I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8VAI;&1R96Y;)&-H:6QD+3Y?:61=(#T@)B1C:&EL9#L*"B`@("`@("`@<F5T
M=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!296UO=F5S(&$@3&]G
M(&EN<W1A;F-E(&9R;VT@=&AE(&QI<W0@;V8@8VAI;&1R96XN"B`@("`@*@H@
M("`@("H@0'!A<F%M(&]B:F5C="`@("`D8VAI;&0@("`@("!4:&4@3&]G(&EN
M<W1A;F-E('1O(')E;6]V92X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@:68@=&AE($QO9R!I;G-T86YC92!W87,@<W5C8V5S<V9U;&QY
M(')E;6]V960N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F5M;W9E0VAI;&0H)&-H:6QD*0H@("`@>PH@("`@
M("`@(&EF("@A:7-?82@D8VAI;&0L("=,;V<G*2!\?"`A:7-S970H)'1H:7,M
M/E]C:&EL9')E;ELD8VAI;&0M/E]I9%TI*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@('5N<V5T*"1T:&ES+3Y?8VAI
M;&1R96Y;)&-H:6QD+3Y?:61=*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"@I]"@```````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M3&]G+V1A96UO;BYP:'``````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q-3`S-"`Q,#4Q-30S-#$S,R`P,C$Q-C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+R\@)$ED
M.B!D865M;VXN<&AP+'8@,2XR(#(P,#4O,#(O,C8@,30Z-#@Z-3@@8VAA9V5N
M8G4@17AP("0*"B\J*@H@*B!4:&4@3&]G7V1A96UO;B!C;&%S<R!I<R!A(&-O
M;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.@H@*B!A8G-T<F%C
M="!C;&%S<R!W:&EC:"!S96YD<R!M97-S86=E<R!T;R!S>7-L;V<@9&%E;6]N
M(&]N(%5.25@M;&EK92!M86-H:6YE<RX*("H@5&AI<R!C;&%S<R!U<V5S('1H
M92!S>7-L;V<@<')O=&]C;VPZ(&AT='`Z+R]W=W<N:65T9BYO<F<O<F9C+W)F
M8S,Q-C0N='AT"B`J"B`J($!A=71H;W(@($)A<G0@=F%N(&1E<B!38VAA;G,@
M/'-C:&%N<T!D9',N;FP^"B`J($!V97)S:6]N("12979I<VEO;CH@,2XR("0*
M("H@0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?9&%E;6]N(&5X=&5N9',@
M3&]G"GL*("`@("\J*@H@("`@("H@26YT96=E<B!H;VQD:6YG('1H92!L;V<@
M9F%C:6QI='D@=&\@=7-E+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@
M("`@=F%R("1?;F%M92`]($Q/1U]$045-3TX["@H@("`@+RHJ"B`@("`@*B!6
M87(@:&]L9&EN9R!T:&4@<F5S;W5R8V4@<&]I;G1E<B!T;R!T:&4@<V]C:V5T
M"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D7W-O8VME
M=#L*"B`@("`O*BH*("`@("`J(%1H92!I<"!A9&1R97-S(&]R('-E<G9E<FYA
M;64*("`@("`J($!S964@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]T
M<F%N<W!O<G1S+G!H<`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1?:7`@/2`G,3(W+C`N,"XQ)SL*"B`@("`O*BH*("`@("`J(%!R;W1O
M8V]L('1O('5S92`H=&-P+"!U9'`L(&5T8RXI"B`@("`@*B!`<V5E(&AT='`Z
M+R]W=W<N<&AP+FYE="]M86YU86PO96XO=')A;G-P;W)T<RYP:'`*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D7W!R;W1O(#T@)W5D<"<[
M"@H@("`@+RHJ"B`@("`@*B!0;W)T('1O(&-O;FYE8W0@=&\*("`@("`J($!V
M87(@:6YT"B`@("`@*B\*("`@('9A<B`D7W!O<G0@/2`U,30["@H@("`@+RHJ
M"B`@("`@*B!-87AI;75M(&UE<W-A9V4@;&5N9W1H(&EN(&)Y=&5S"B`@("`@
M*B!`=F%R(&EN=`H@("`@("HO"B`@("!V87(@)%]M87AS:7IE(#T@-#`Y-CL*
M"B`@("`O*BH*("`@("`J(%-O8VME="!T:6UE;W5T(&EN('-E8V]N9',*("`@
M("`J($!V87(@:6YT"B`@("`@*B\*("`@('9A<B`D7W1I;65O=70@/2`Q.PH*
M"B`@("`O*BH*("`@("`J($-O;G-T<G5C=',@82!N97<@<WES;&]G(&]B:F5C
M="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@
M<WES;&]G(&9A8VEL:71Y+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@
M("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@
M)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A
M<F%M(&EN="`@("`D;6%X3&5V96P@36%X:6UU;2!L979E;"!A="!W:&EC:"!T
M;R!L;V<N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!,;V=?9&%E;6]N*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A
M<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%2
M7TQ/1U]$14)51RD*("`@('L*("`@("`@("`O*B!%;G-U<F4@=V4@:&%V92!A
M('9A;&ED(&EN=&5G97(@=F%L=64@9F]R("1N86UE+B`J+PH@("`@("`@(&EF
M("AE;7!T>2@D;F%M92D@?'P@(6ES7VEN="@D;F%M92DI('L*("`@("`@("`@
M("`@)&YA;64@/2!,3T=?4UE33$]'.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]N
M86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*
M("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@
M("`@("`@:68@*&ES<V5T*"1C;VYF6R=I<"==*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7VEP(#T@)&-O;F9;)VEP)UT["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<W-E="@D8V]N9ELG<')O=&\G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P<F]T;R`]("1C;VYF6R=P<F]T;R==.PH@("`@("`@('T*("`@("`@("!I
M9B`H:7-S970H)&-O;F9;)W!O<G0G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P;W)T(#T@)&-O;F9;)W!O<G0G73L*("`@("`@("!]"B`@("`@("`@:68@
M*&ES<V5T*"1C;VYF6R=M87AS:7IE)UTI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?;6%X<VEZ92`]("1C;VYF6R=M87AS:7IE)UT["B`@("`@("`@?0H@("`@
M("`@(&EF("AI<W-E="@D8V]N9ELG=&EM96]U="==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W1I;65O=70@/2`D8V]N9ELG=&EM96]U="==.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^7W!R;W1O(#T@)'1H:7,M/E]P<F]T;R`N("<Z
M+R\G.PH*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A
M>2@F)'1H:7,L("=?3&]G7V1A96UO;B<I*3L*("`@('T*"B`@("`O*BH*("`@
M("`J($1E<W1R=6-T;W(N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@(&9U;F-T:6]N(%],;V=?9&%E;6]N*"D*("`@('L*("`@
M("`@("`D=&AI<RT^8VQO<V4H*3L*("`@('T*"B`@("`O*BH*("`@("`J($]P
M96YS(&$@8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E<BP@:68@:70@
M:&%S(&YO="!A;')E861Y"B`@("`@*B!B965N(&]P96YE9"X@(%1H:7,@:7,@
M:6UP;&EC:71L>2!C86QL960@8GD@;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&]P96XH
M*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N960I('L*("`@("`@
M("`@("`@)'1H:7,M/E]O<&5N960@/2`H8F]O;"DH)'1H:7,M/E]S;V-K970@
M/2!`9G-O8VMO<&5N*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^7W!R;W1O("X@)'1H:7,M/E]I<"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]P;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D97)R;F\L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E<G)S='(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3Y?=&EM96]U="DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/E]O<&5N960["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#;&]S97,@=&AE
M(&-O;FYE8W1I;VX@=&\@=&AE('-Y<W1E;2!L;V=G97(L(&EF(&ET(&ES(&]P
M96XN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@
M("`@(')E='5R;B!F8VQO<V4H)'1H:7,M/E]S;V-K970I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E
M;F1S("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E;B!S>7-L;V<@8V]N
M;F5C=&EO;BX@($-A;&QS"B`@("`@*B!O<&5N*"D@:68@;F5C97-S87)Y+B!!
M;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R
M=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@
M3&]G+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)&UE<W-A9V4@(%1H
M92!T97AT=6%L(&UE<W-A9V4@=&\@8F4@;&]G9V5D+@H@("`@("H@0'!A<F%M
M(&EN="`D<')I;W)I='D@*&]P=&EO;F%L*2!4:&4@<')I;W)I='D@;V8@=&AE
M(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU
M97,@87)E.B!,3T=?14U%4D<L($Q/1U]!3$525"P@3$]'7T-2250L"B`@("`@
M*B`@("`@("`@("`@("`@("`@($Q/1U]%4E(L($Q/1U]705).24Y'+"!,3T=?
M3D]424-%+"!,3T=?24Y&3RP*("`@("`J("`@("`@("`@("`@("`@("`@86YD
M($Q/1U]$14)51RX@(%1H92!D969A=6QT(&ES($Q/1U])3D9/+@H@("`@("H@
M0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S
M86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@
M<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U
M;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@
M>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@
M("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R
M:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@
M("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@
M268@=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E
M;F5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?
M;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T
M<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@
M("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I
M.PH*("`@("`@("`O*B!3970@=&AE(&9A8VEL:71Y(&QE=F5L+B`J+PH@("`@
M("`@("1F86-I;&ET>5]L979E;"`](&EN='9A;"@D=&AI<RT^7VYA;64I("L*
M("`@("`@("`@("`@("`@("`@("`@("`@("!I;G1V86PH)'1H:7,M/E]T;U-Y
M<VQO9R@D<')I;W)I='DI*3L*"B`@("`@("`@+RH@4')E<&5N9"!I9&5N="!I
M;F9O+B`J+PH@("`@("`@(&EF("@A96UP='DH)'1H:7,M/E]I9&5N="DI('L*
M("`@("`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7VED96YT("X@)R`G("X@
M)&UE<W-A9V4["B`@("`@("`@?0H*("`@("`@("`O*B!#:&5C:R!F;W(@;65S
M<V%G92!L96YG=&@N("HO"B`@("`@("`@:68@*'-T<FQE;B@D;65S<V%G92D@
M/B`D=&AI<RT^7VUA>'-I>F4I('L*("`@("`@("`@("`@)&UE<W-A9V4@/2!S
M=6)S='(H)&UE<W-A9V4L(#`L("@D=&AI<RT^7VUA>'-I>F4I("T@,3`I("X@
M)R!;+BXN72<["B`@("`@("`@?0H*("`@("`@("`O*B!7<FET92!T;R!S;V-K
M970N("HO"B`@("`@("`@9G=R:71E*"1T:&ES+3Y?<V]C:V5T+"`G/"<@+B`D
M9F%C:6QI='E?;&5V96P@+B`G/B<@+B`D;65S<V%G92`N(")<;B(I.PH*("`@
M("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R
M:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($-O;G9E<G1S(&$@4$5!4E],3T=?*B!C;VYS=&%N="!I;G1O
M(&$@<WES;&]G($Q/1U\J(&-O;G-T86YT+@H@("`@("H*("`@("`J(%1H:7,@
M9G5N8W1I;VX@97AI<W1S(&)E8V%U<V4L('5N9&5R(%=I;F1O=W,L(&YO="!A
M;&P@;V8@=&AE($Q/1U\J"B`@("`@*B!C;VYS=&%N=',@:&%V92!U;FEQ=64@
M=F%L=65S+B`@26YS=&5A9"P@=&AE(%!%05)?3$]'7RH@=V5R92!I;G1R;V1U
M8V5D"B`@("`@*B!F;W(@9VQO8F%L('5S92P@=VET:"!T:&4@8V]N=F5R<VEO
M;B!T;R!T:&4@3$]'7RH@8V]N<W1A;G1S(&ME<'0@;&]C86P@=&\*("`@("`J
M('1O('1H92!S>7-L;V<@9')I=F5R+@H@("`@("H*("`@("`J($!P87)A;2!I
M;G0@)'!R:6]R:71Y("`@("!014%27TQ/1U\J('9A;'5E('1O(&-O;G9E<G0@
M=&\@3$]'7RH@=F%L=64N"B`@("`@*@H@("`@("H@0')E='5R;B`@5&AE($Q/
M1U\J(')E<')E<V5N=&%T:6]N(&]F("1P<FEO<FET>2X*("`@("`J"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7W1O4WES
M;&]G*"1P<FEO<FET>2D*("`@('L*("`@("`@("!S=&%T:6,@)'!R:6]R:71I
M97,@/2!A<G)A>2@*("`@("`@("`@("`@4$5!4E],3T=?14U%4D<@("`]/B!,
M3T=?14U%4D<L"B`@("`@("`@("`@(%!%05)?3$]'7T%,15)4("`@/3X@3$]'
M7T%,15)4+`H@("`@("`@("`@("!014%27TQ/1U]#4DE4("`@(#T^($Q/1U]#
M4DE4+`H@("`@("`@("`@("!014%27TQ/1U]%4E(@("`@(#T^($Q/1U]%4E(L
M"B`@("`@("`@("`@(%!%05)?3$]'7U=!4DY)3D<@/3X@3$]'7U=!4DY)3D<L
M"B`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12`@/3X@3$]'7TY/5$E#12P*
M("`@("`@("`@("`@4$5!4E],3T=?24Y&3R`@("`]/B!,3T=?24Y&3RP*("`@
M("`@("`@("`@4$5!4E],3T=?1$5"54<@("`]/B!,3T=?1$5"54<*("`@("`@
M("`I.PH*("`@("`@("`O*B!)9B!W92=R92!P87-S960@86X@=6YK;F]W;B!P
M<FEO<FET>2P@9&5F875L="!T;R!,3T=?24Y&3RX@*B\*("`@("`@("!I9B`H
M(6ES7VEN="@D<')I;W)I='DI('Q\("%I;E]A<G)A>2@D<')I;W)I='DL("1P
M<FEO<FET:65S*2D@>PH@("`@("`@("`@("!R971U<FX@3$]'7TE.1D\["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'!R:6]R:71I97-;)'!R:6]R:71Y
M73L*("`@('T*"GT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+V1I<W!L87DN<&AP
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-S`V
M,R`Q,#4Q-30S-#$S,R`P,C$S-C8`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O
M<VET;W)Y+W!E87(O3&]G+TQO9R]D:7-P;&%Y+G!H<"QV(#$N."`R,#`U+S`X
M+S`V(#(S.C(X.C,U(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I
M;VXZ(#$N."`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G
M7V1I<W!L87D@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@=W)I=&5S(&UE
M<W-A9V4@:6YT;R!B<F]W<V5R(&EN('5S=6%L(%!(4"!M86YE<BX*("H@5&AI
M<R!M87D@8F4@=7-E9G5L(&)E8V%U<V4@=VAE;B!Y;W4@=7-E(%!%05(Z.G-E
M=$5R<F]R2&%N9&QI;F<@:6X*("H@4$5!4E]%4E)/4E]#04Q,0D%#2R!M;V1E
M(&5R<F]R(&UE<W-A9V5S(&%R92!N;W0@9&ES<&QA>65D(&)Y"B`J(%!(4"!E
M<G)O<B!H86YD;&5R+@H@*@H@*B!`875T:&]R("!0875L(%EA;F-H96YK;R`\
M<'5S:&5R0&EN86-O+G)U/@H@*B!`<VEN8V4@("!,;V<@,2XX+C`*("H@0'!A
M8VMA9V4@3&]G"B`J"B`J($!E>&%M<&QE(&1I<W!L87DN<&AP("`@("!5<VEN
M9R!T:&4@9&ES<&QA>2!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7V1I<W!L87D@
M97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@=&\@;W5T<'5T
M(&)E9F]R92!A;B!E<G)O<B!M97-S86=E"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5R<F]R
M7W!R97!E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!T;R!O=71P
M=70@869T97(@86X@97)R;W(@;65S<V%G90H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]E<G)O
M<E]A<'!E;F0@/2`G)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!U<V5D('1O
M(')E<')E<V5N="!A(&QI;F4@8G)E86LN"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQI;F5B
M<F5A:R`]("(\8G(@+SY<;B(["@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S
M(&$@;F5W($QO9U]D:7-P;&%Y(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*("`@("`J($!P
M87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T:6]N(&%R<F%Y
M+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@3&]G(&UE<W-A9V5S
M('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]D:7-P;&%Y*"1N
M86UE(#T@)R<L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*
M("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*
M("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES
M+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H:7-S
M970H)&-O;F9;)V5R<F]R7W!R97!E;F0G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]E<G)O<E]P<F5P96YD(#T@)&-O;F9;)V5R<F]R7W!R97!E;F0G73L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7W!R
M97!E;F0@/2!I;FE?9V5T*"=E<G)O<E]P<F5P96YD7W-T<FEN9R<I.PH@("`@
M("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=E<G)O<E]A<'!E;F0G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]E<G)O<E]A<'!E;F0@/2`D8V]N
M9ELG97)R;W)?87!P96YD)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]E<G)O<E]A<'!E;F0@/2!I;FE?9V5T*"=E<G)O<E]A<'!E
M;F1?<W1R:6YG)RD["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O
M;F9;)VQI;F5B<F5A:R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI;F5B
M<F5A:R`]("1C;VYF6R=L:6YE8G)E86LG73L*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!7<FET97,@)&UE<W-A9V4@=&\@=&AE('1E>'0@8G)O
M=W-E<BX@06QS;RP@<&%S<V5S('1H92!M97-S86=E"B`@("`@*B!A;&]N9R!T
M;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T(&%R92!O8G-E<G9I
M;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D("`D;65S
M<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A
M9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I='D@5&AE
M('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@("`J("`@("`@
M("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%4D<L(%!%05)?
M3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U]#
M4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@
M("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&
M3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S
M<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)9B!A
M('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E('1H92!D969A
M=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@/3T](&YU;&PI
M('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*
M("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF('1H92!P<FEO
M<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@
M("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I='DI*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J
M($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S
M<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE
M<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!A;F0@;W5T<'5T
M('1H92!C;VUP;&5T92!L;V<@;&EN92X@*B\*("`@("`@("!E8VAO("1T:&ES
M+3Y?97)R;W)?<')E<&5N9"`N"B`@("`@("`@("`@("`G/&(^)R`N('5C9FER
M<W0H)'1H:7,M/G!R:6]R:71Y5&]3=')I;F<H)'!R:6]R:71Y*2D@+B`G/"]B
M/CH@)RX*("`@("`@("`@("`@(&YL,F)R*&AT;6QS<&5C:6%L8VAA<G,H)&UE
M<W-A9V4I*2`N"B`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R7V%P<&5N9"`N
M("1T:&ES+3Y?;&EN96)R96%K.PH*("`@("`@("`O*B!.;W1I9GD@;V)S97)V
M97)S(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N("HO"B`@("`@("`@)'1H:7,M
M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@)VUE
M<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@?0H*?0H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O3&]G+V5R<F]R7VQO9RYP:'``````````````````````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P-C`V-"`Q,#4Q-30S-#$S,R`P,C$W,3,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+RHJ
M"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]E<G)O<E]L
M;V<N<&AP+'8@,2XW(#(P,#4O,#(O,C8@,30Z-#@Z-3@@8VAA9V5N8G4@17AP
M("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C<@)`H@*B!`<&%C:V%G
M92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]E<G)O<E]L;V<@8VQA<W,@:7,@
M82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T
M"B`J(&-L87-S('1H870@;&]G<R!M97-S86=E<R!U<VEN9R!02%`G<R!E<G)O
M<E]L;V<H*2!F=6YC=&EO;BX*("H*("H@0&%U=&AO<B`@2F]N(%!A<FES92`\
M:F]N0'!H<"YN970^"B`J($!S:6YC92`@($QO9R`Q+C<N,`H@*B!`<&%C:V%G
M92!,;V<*("H*("H@0&5X86UP;&4@97)R;W)?;&]G+G!H<"`@(%5S:6YG('1H
M92!E<G)O<E]L;V<@:&%N9&QE<BX*("HO"F-L87-S($QO9U]E<G)O<E]L;V<@
M97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!4:&4@97)R;W)?;&]G*"D@
M;&]G('1Y<&4N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]T>7!E(#T@4$5!4E],3T=?5%E0
M15]365-414T["@H@("`@+RHJ"B`@("`@*B!4:&4@='EP92US<&5C:69I8R!D
M97-T:6YA=&EO;B!V86QU92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&5S=&EN871I;VX@
M/2`G)SL*"B`@("`O*BH*("`@("`J($%D9&ET:6]N86P@:&5A9&5R<R!T;R!P
M87-S('1O('1H92!M86EL*"D@9G5N8W1I;VX@=VAE;B!T:&4*("`@("`J(%!%
M05)?3$]'7U194$5?34%)3"!T>7!E(&ES('5S960N"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7V5X=')A7VAE861E<G,@/2`G)SL*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!N97<@3&]G7V5R<F]R7VQO9R!O8FIE8W0N"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A
M;2!S=')I;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@
M*B!`<&%R86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A
M<G)A>2X*("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S
M86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?97)R;W)?
M;&]G*"1N86UE+"`D:61E;G0@/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!014%27TQ/1U]$14)5
M1RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I
M*3L*("`@("`@("`D=&AI<RT^7W1Y<&4@/2`D;F%M93L*("`@("`@("`D=&AI
M<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO
M9SHZ55!43R@D;&5V96PI.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=D
M97-T:6YA=&EO;B==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V1E<W1I;F%T
M:6]N(#T@)&-O;F9;)V1E<W1I;F%T:6]N)UT["B`@("`@("`@?0H@("`@("`@
M(&EF("@A96UP='DH)&-O;F9;)V5X=')A7VAE861E<G,G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]E>'1R85]H96%D97)S(#T@)&-O;F9;)V5X=')A7VAE
M861E<G,G73L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S
M("1M97-S86=E('5S:6YG(%!(4"=S(&5R<F]R7VQO9R@I(&9U;F-T:6]N+B`@
M5&AE(&UE<W-A9V4@:7,@86QS;PH@("`@("H@<&%S<V5D(&%L;VYG('1O(&%N
M>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN9R!T
M:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E
M("`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M97-S86=E('1O
M(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO
M<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@("`@("`@("`@
M("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!014%27TQ/1U]!
M3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?0U))5"P@
M4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@("H@("`@("`@
M("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'7TE.1D\L(&%N
M9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C
M97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H)&UE<W-A9V4L
M("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@268@82!P<FEO
M<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@9&5F875L="!V
M86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N=6QL*2!["B`@
M("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I='D["B`@("`@
M("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@<')I;W)I='D@
M:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@*B\*("`@("`@
M("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@>PH@("`@("`@
M("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R
M86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N
M("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E
M*"1M97-S86=E*3L*"B`@("`@("`@)'-U8V-E<W,@/2!E<G)O<E]L;V<H)'1H
M:7,M/E]I9&5N="`N("<Z("<@+B`D;65S<V%G92P@)'1H:7,M/E]T>7!E+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?9&5S=&EN871I
M;VXL("1T:&ES+3Y?97AT<F%?:&5A9&5R<RD["@H@("`@("`@("1T:&ES+3Y?
M86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S
M86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@)'-U8V-E<W,[
M"B`@("!]"@I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+TQO9R]F:6QE+G!H<```````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,C$U-C$@,3`U,34T,S0Q,S,@,#(P-C,W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O9FEL92YP
M:'`L=B`Q+C0U(#(P,#8O,#$O,3$@,#<Z-38Z,S<@:F]N($5X<"`D"B`J"B`J
M($!V97)S:6]N("12979I<VEO;CH@,2XT-2`D"B`J($!P86-K86=E($QO9PH@
M*B\*"B\J*@H@*B!4:&4@3&]G7V9I;&4@8VQA<W,@:7,@82!C;VYC<F5T92!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J(&-L87-S('1H
M870@;&]G<R!M97-S86=E<R!T;R!A('1E>'0@9FEL92X*("H@"B`J($!A=71H
M;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`875T:&]R("!2;VUA
M;B!.975H875S97(@/&YE=6AA=7-E<D!B96QL879I<W1A+F-Z/@H@*B!`<VEN
M8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!F
M:6QE+G!H<"`@("!5<VEN9R!T:&4@9FEL92!H86YD;&5R+@H@*B\*8VQA<W,@
M3&]G7V9I;&4@97AT96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@
M8V]N=&%I;FEN9R!T:&4@;F%M92!O9B!T:&4@;&]G(&9I;&4N"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7V9I;&5N86UE(#T@)W!H<"YL;V<G.PH*("`@("\J*@H@("`@("H@
M2&%N9&QE('1O('1H92!L;V<@9FEL92X*("`@("`J($!V87(@<F5S;W5R8V4*
M("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]F<"`]
M(&9A;'-E.PH*("`@("\J*@H@("`@("H@4VAO=6QD(&YE=R!L;V<@96YT<FEE
M<R!B92!A<'!E;F0@=&\@86X@97AI<W1I;F<@;&]G(&9I;&4L(&]R('-H;W5L
M9"!T:&4*("`@("`J(&$@;F5W(&QO9R!F:6QE(&]V97)W<FET92!A;B!E>&ES
M=&EN9R!O;F4_"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]A<'!E;F0@/2!T<G5E.PH*("`@
M("\J*@H@("`@("H@4VAO=6QD(&%D=FES;W)Y(&9I;&4@;&]C:VEN9R`H:2YE
M+BP@9FQO8VLH*2D@8F4@=7-E9#\*("`@("`J($!V87(@8F]O;&5A;@H@("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQO8VMI;F<@
M/2!F86QS93L*"B`@("`O*BH*("`@("`J($EN=&5G97(@*&EN(&]C=&%L*2!C
M;VYT86EN:6YG('1H92!L;V<@9FEL92=S('!E<FUI<W-I;VYS(&UO9&4N"B`@
M("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]M;V1E(#T@,#8T-#L*"B`@("`O*BH*("`@("`J($EN
M=&5G97(@*&EN(&]C=&%L*2!S<&5C:69Y:6YG('1H92!F:6QE('!E<FUI<W-I
M;VX@;6]D92!T:&%T('=I;&P@8F4*("`@("`J('5S960@=VAE;B!C<F5A=&EN
M9R!D:7)E8W1O<FEE<R!T:&%T(&1O(&YO="!A;')E861Y(&5X:7-T+@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?9&ER;6]D92`](#`W-34["@H@("`@+RHJ"B`@("`@*B!3
M=')I;F<@8V]N=&%I;FEN9R!T:&4@9F]R;6%T(&]F(&$@;&]G(&QI;F4N"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7VQI;F5&;W)M870@/2`G)3$D<R`E,B1S(%LE,R1S72`E
M-"1S)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!T
M:6UE<W1A;7`@9F]R;6%T+B`@270@=VEL;"!B92!P87-S960@9&ER96-T;'D@
M=&\*("`@("`J('-T<F9T:6UE*"DN("!.;W1E('1H870@=&AE('1I;65S=&%M
M<"!S=')I;F<@=VEL;"!G96YE<F%T960@=7-I;F<@=&AE"B`@("`@*B!C=7)R
M96YT(&QO8V%L92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&EM949O<FUA="`]("<E8B`E
M9"`E2#HE33HE4R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN
M9R!T:&4@96YD+6]N+6QI;F4@8VAA<F%C=&5R('-E<75E;F-E+@H@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]E;VP@/2`B7&XB.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!,;V=?9FEL92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R
M86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*
M("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U
M<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?9FEL92@D;F%M92P@
M)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@
M("`@("`@("1L979E;"`](%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@
M("1T:&ES+3Y?:60@/2!M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES
M+3Y?9FEL96YA;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@
M)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V
M96PI.PH*("`@("`@("!I9B`H:7-S970H)&-O;F9;)V%P<&5N9"==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7V%P<&5N9"`]("1C;VYF6R=A<'!E;F0G73L*
M("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG;&]C:VEN9R==
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQO8VMI;F<@/2`D8V]N9ELG;&]C
M:VEN9R==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG
M;6]D92==*2D@>PH@("`@("`@("`@("!I9B`H:7-?<W1R:6YG*"1C;VYF6R=M
M;V1E)UTI*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7VUO9&4@/2!O8W1D
M96,H)&-O;F9;)VUO9&4G72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`D=&AI<RT^7VUO9&4@/2`D8V]N9ELG;6]D92==.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF
M6R=D:7)M;V1E)UTI*2!["B`@("`@("`@("`@(&EF("AI<U]S=')I;F<H)&-O
M;F9;)V1I<FUO9&4G72DI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ER
M;6]D92`](&]C=&1E8R@D8V]N9ELG9&ER;6]D92==*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?9&ER;6]D92`]("1C
M;VYF6R=D:7)M;V1E)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@
M("`@(&EF("@A96UP='DH)&-O;F9;)VQI;F5&;W)M870G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]L:6YE1F]R;6%T(#T@<W1R7W)E<&QA8V4H87)R87E?
M:V5Y<R@D=&AI<RT^7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E<R@D=&AI<RT^
M7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;VYF6R=L:6YE1F]R;6%T)UTI.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG=&EM949O<FUA="==*2D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W1I;65&;W)M870@/2`D8V]N9ELG=&EM949O
M<FUA="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N9ELG
M96]L)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?96]L(#T@)&-O;F9;)V5O
M;"==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3Y?96]L
M(#T@*'-T<G-T<BA02%!?3U,L("=724XG*2D@/R`B7')<;B(@.B`B7&XB.PH@
M("`@("`@('T*"B`@("`@("`@<F5G:7-T97)?<VAU=&1O=VY?9G5N8W1I;VXH
M87)R87DH)B1T:&ES+"`G7TQO9U]F:6QE)RDI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@1&5S=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!?3&]G7V9I
M;&4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@>PH@("`@
M("`@("`@("`D=&AI<RT^8VQO<V4H*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#<F5A=&5S('1H92!G:79E;B!D:7)E8W1O<GD@<&%T:"X@
M($EF('1H92!P87)E;G0@9&ER96-T;W)I97,@9&]N)W0*("`@("`J(&%L<F5A
M9'D@97AI<W0L('1H97D@=VEL;"!B92!C<F5A=&5D+"!T;V\N"B`@("`@*@H@
M("`@("H@5&AI<R!I;7!L96UE;G1A=&EO;B!I<R!I;G-P:7)E9"!B>2!0>71H
M;VXG<R!O<RYM86ME9&ER<R!F=6YC=&EO;BX*("`@("`J"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("1P871H("`@("`@(%1H92!F=6QL(&1I<F5C=&]R>2!P
M871H('1O(&-R96%T92X*("`@("`J($!P87)A;2`@(&EN=&5G97(@)&UO9&4@
M("`@("`@5&AE('!E<FUI<W-I;VYS(&UO9&4@=VET:"!W:&EC:"!T:&4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&ER96-T;W)I97,@
M=VEL;"!B92!C<F5A=&5D+@H@("`@("H*("`@("`J($!R971U<FX@(%1R=64@
M:68@=&AE(&9U;&P@<&%T:"!I<R!S=6-C97-S9G5L;'D@8W)E871E9"!O<B!A
M;')E861Y"B`@("`@*B`@("`@("`@("!E>&ES=',N"B`@("`@*@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?;6MP871H
M*"1P871H+"`D;6]D92`](#`W,#`I"B`@("!["B`@("`@("`@+RH@4V5P87)A
M=&4@=&AE(&QA<W0@<&%T:&YA;64@8V]M<&]N96YT(&9R;VT@=&AE(')E<W0@
M;V8@=&AE('!A=&@N("HO"B`@("`@("`@)&AE860@/2!D:7)N86UE*"1P871H
M*3L*("`@("`@("`D=&%I;"`](&)A<V5N86UE*"1P871H*3L*"B`@("`@("`@
M+RH@36%K92!S=7)E('=E)W9E('-P;&ET('1H92!P871H(&EN=&\@='=O(&-O
M;7!L971E(&-O;7!O;F5N=',N("HO"B`@("`@("`@:68@*&5M<'1Y*"1T86EL
M*2D@>PH@("`@("`@("`@("`D:&5A9"`](&1I<FYA;64H)'!A=&@I.PH@("`@
M("`@("`@("`D=&%I;"`](&)A<V5N86UE*"1P871H*3L*("`@("`@("!]"@H@
M("`@("`@("\J(%)E8W5R<V4@=7`@=&AE('!A=&@@:68@;W5R(&-U<G)E;G0@
M<V5G;65N="!D;V5S(&YO="!E>&ES="X@*B\*("`@("`@("!I9B`H(65M<'1Y
M*"1H96%D*2`F)B`A96UP='DH)'1A:6PI("8F("%I<U]D:7(H)&AE860I*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?;6MP871H*"1H96%D+"`D;6]D92D["B`@
M("`@("`@?0H*("`@("`@("`O*B!#<F5A=&4@=&AI<R!S96=M96YT(&]F('1H
M92!P871H+B`J+PH@("`@("`@(')E='5R;B!`;6MD:7(H)&AE860L("1M;V1E
M*3L*("`@('T*"B`@("`O*BH*("`@("`J($]P96YS('1H92!L;V<@9FEL92!F
M;W(@;W5T<'5T+B`@268@=&AE('-P96-I9FEE9"!L;V<@9FEL92!D;V5S(&YO
M=`H@("`@("H@86QR96%D>2!E>&ES="P@:70@=VEL;"!B92!C<F5A=&5D+B`@
M0GD@9&5F875L="P@;F5W(&QO9R!E;G1R:65S(&%R90H@("`@("H@87!P96YD
M960@=&\@=&AE(&5N9"!O9B!T:&4@;&]G(&9I;&4N"B`@("`@*@H@("`@("H@
M5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C97-S
M87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H:7,M/E]O
M<&5N960I('L*("`@("`@("`@("`@+RH@268@=&AE(&QO9R!F:6QE)W,@9&ER
M96-T;W)Y(&1O97-N)W0@97AI<W0L(&-R96%T92!I="X@*B\*("`@("`@("`@
M("`@:68@*"%I<U]D:7(H9&ER;F%M92@D=&AI<RT^7V9I;&5N86UE*2DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?;6MP871H*"1T:&ES+3Y?9FEL96YA
M;64L("1T:&ES+3Y?9&ER;6]D92D["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J($1E=&5R;6EN92!W:&5T:&5R('1H92!L;V<@9FEL92!N965D<R!T
M;R!B92!C<F5A=&5D+B`J+PH@("`@("`@("`@("`D8W)E871I;F<@/2`A9FEL
M95]E>&ES=',H)'1H:7,M/E]F:6QE;F%M92D["@H@("`@("`@("`@("`O*B!/
M8G1A:6X@82!H86YD;&4@=&\@=&AE(&QO9R!F:6QE+B`J+PH@("`@("`@("`@
M("`D=&AI<RT^7V9P(#T@9F]P96XH)'1H:7,M/E]F:6QE;F%M92P@*"1T:&ES
M+3Y?87!P96YD*2`_("=A)R`Z("=W)RD["@H@("`@("`@("`@("`O*B!792!C
M;VYS:61E<B!T:&4@9FEL92`B;W!E;F5D(B!I9B!W92!H879E(&$@=F%L:60@
M9FEL92!P;VEN=&5R+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]
M("@D=&AI<RT^7V9P("$]/2!F86QS92D["@H@("`@("`@("`@("`O*B!!='1E
M;7!T('1O('-E="!T:&4@9FEL92=S('!E<FUI<W-I;VYS(&EF('=E(&IU<W0@
M8W)E871E9"!I="X@*B\*("`@("`@("`@("`@:68@*"1C<F5A=&EN9R`F)B`D
M=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`@("`@8VAM;V0H)'1H:7,M
M/E]F:6QE;F%M92P@)'1H:7,M/E]M;V1E*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0VQO<V5S('1H92!L;V<@9FEL92!I9B!I="!I<R!O
M<&5N+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-L;W-E*"D*("`@('L*("`@("`@("`O*B!)9B!T:&4@;&]G
M(&9I;&4@:7,@;W!E;BP@8VQO<V4@:70N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?;W!E;F5D("8F(&9C;&]S92@D=&AI<RT^7V9P*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@
M("\J*@H@("`@("H@1FQU<VAE<R!A;&P@<&5N9&EN9R!D871A('1O('1H92!F
M:6QE(&AA;F1L92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@
M("H@0'-I;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S
M:"@I"B`@("!["B`@("`@("`@<F5T=7)N(&9F;'5S:"@D=&AI<RT^7V9P*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($QO9W,@)&UE<W-A9V4@=&\@=&AE(&]U
M='!U="!W:6YD;W<N("!4:&4@;65S<V%G92!I<R!A;'-O('!A<W-E9"!A;&]N
M9PH@("`@("H@=&\@86YY($QO9U]O8G-E<G9E<B!I;G-T86YC97,@=&AA="!A
M<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M
M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T
M:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`<&%R86T@<W1R:6YG("1P<FEO
M<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@
M("H@("`@("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%3452
M1RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%
M05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*
M("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%2
M7TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N
M(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E
M+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@
M;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@
M("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@
M=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]
M/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R
M:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@
M=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V
M96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET
M>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@
M("`@("`@+RH@268@=&AE(&QO9R!F:6QE(&ES;B=T(&%L<F5A9'D@;W!E;BP@
M;W!E;B!I="!N;W<N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F
M)B`A)'1H:7,M/F]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P
M<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A
M9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@
M("`@+RH@0G5I;&0@=&AE('-T<FEN9R!C;VYT86EN:6YG('1H92!C;VUP;&5T
M92!L;V<@;&EN92X@*B\*("`@("`@("`D;&EN92`]("1T:&ES+3Y?9F]R;6%T
M*"1T:&ES+3Y?;&EN949O<FUA="P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O<FUA="DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<')I;W)I='DL("1M97-S86=E*2`N
M("1T:&ES+3Y?96]L.PH*("`@("`@("`O*B!)9B!L;V-K:6YG(&ES(&5N86)L
M960L(&%C<75I<F4@86X@97AC;'5S:79E(&QO8VL@;VX@=&AE(&9I;&4N("HO
M"B`@("`@("`@:68@*"1T:&ES+3Y?;&]C:VEN9RD@>PH@("`@("`@("`@("!F
M;&]C:R@D=&AI<RT^7V9P+"!,3T-+7T58*3L*("`@("`@("!]"@H@("`@("`@
M("\J(%=R:71E('1H92!L;V<@;&EN92!T;R!T:&4@;&]G(&9I;&4N("HO"B`@
M("`@("`@)'-U8V-E<W,@/2`H9G=R:71E*"1T:&ES+3Y?9G`L("1L:6YE*2`A
M/3T@9F%L<V4I.PH*("`@("`@("`O*B!5;FQO8VL@=&AE(&9I;&4@;F]W('1H
M870@=V4G<F4@9FEN:7-H960@=W)I=&EN9R!T;R!I="X@*B\@"B`@("`@("`@
M:68@*"1T:&ES+3Y?;&]C:VEN9RD@>PH@("`@("`@("`@("!F;&]C:R@D=&AI
M<RT^7V9P+"!,3T-+7U5.*3L*("`@("`@("!]"@H@("`@("`@("\J($YO=&EF
M>2!O8G-E<G9E<G,@86)O=70@=&AI<R!L;V<@;65S<V%G92X@*B\*("`@("`@
M("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R
M:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N
M("1S=6-C97-S.PH@("`@?0H*?0H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O3&]G+VUA:6PN<&AP````````````````````````````
M```````````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q-C`P,R`Q,#4Q-30S-#$S,R`P,C`V
M,S4`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO
M9R]M86EL+G!H<"QV(#$N,C0@,C`P-B\P,2\S,"`P-3HS-SHQ."!J;VX@17AP
M("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C(T("0*("H@0'!A8VMA
M9V4@3&]G"B`J+PH*+RHJ"B`J(%1H92!,;V=?;6%I;"!C;&%S<R!I<R!A(&-O
M;F-R971E(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.B!A8G-T<F%C="!C
M;&%S<PH@*B!W:&EC:"!S96YD<R!L;V<@;65S<V%G97,@=&\@82!M86EL8F]X
M+@H@*B!4:&4@;6%I;"!I<R!A8W1U86QL>2!S96YT('=H96X@>6]U(&-L;W-E
M*"D@=&AE(&QO9V=E<BP@;W(@=VAE;B!T:&4@9&5S=')U8W1O<@H@*B!I<R!C
M86QL960@*'=H96X@=&AE('-C<FEP="!I<R!T97)M:6YA=&5D*2X*("H*("H@
M4$Q%05-%($Y/5$4@=&AA="!Y;W4@;75S="!C<F5A=&4@82!,;V=?;6%I;"!O
M8FIE8W0@=7-I;F<@/28L(&QI:V4@=&AI<R`Z"B`J("`D;&]G9V5R(#TF($QO
M9SHZ9F%C=&]R>2@B;6%I;"(L(")R96-I<&EE;G1`97AA;7!L92YC;VTB+"`N
M+BXI"B`J"B`J(%1H:7,@:7,@82!014%2(')E<75I<F5M96YT(&9O<B!D97-T
M<G5C=&]R<R!T;R!W;W)K('!R;W!E<FQY+@H@*B!3964@:'1T<#HO+W!E87(N
M<&AP+FYE="]M86YU86PO96XO8VQA<W,N<&5A<BYP:'`*("H*("H@0&%U=&AO
M<B`@4F]N;FEE($=A<F-I82`\<F]N;FEE0&UK,BYN970^"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XS
M"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!M86EL+G!H<"`@("!5
M<VEN9R!T:&4@;6%I;"!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7VUA:6P@97AT
M96YD<R!,;V<*>PH@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T:&4@
M<F5C:7!I96YT)W,@96UA:6P@861D<F5S<RX*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<F5C
M:7!I96YT(#T@)R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@:&]L9&EN9R!T
M:&4@<V5N9&5R)W,@96UA:6P@861D<F5S<RX*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9G)O
M;2`]("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&5M
M86EL)W,@<W5B:F5C="X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<W5B:F5C="`]("=;3&]G
M7VUA:6Q=($QO9R!M97-S86=E)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H
M;VQD:6YG(&%N(&]P=&EO;F%L('!R96%M8FQE(&9O<B!T:&4@;&]G(&UE<W-A
M9V5S+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]P<F5A;6)L92`]("<G.PH*("`@("\J*@H@
M("`@("H@4W1R:6YG(&-O;G1A:6YI;F<@=&AE(&9O<FUA="!O9B!A(&QO9R!L
M:6YE+@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]L:6YE1F]R;6%T(#T@)R4Q)',@)3(D<R!;
M)3,D<UT@)30D<R<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN
M9R!T:&4@=&EM97-T86UP(&9O<FUA="X@($ET('=I;&P@8F4@<&%S<V5D(&1I
M<F5C=&QY('1O"B`@("`@*B!S=')F=&EM92@I+B`@3F]T92!T:&%T('1H92!T
M:6UE<W1A;7`@<W1R:6YG('=I;&P@9V5N97)A=&5D('5S:6YG('1H90H@("`@
M("H@8W5R<F5N="!L;V-A;&4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1I;65&;W)M870@
M/2`G)6(@)60@)4@Z)4TZ)5,G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO
M;&1I;F<@=&AE(&UA:6P@;65S<V%G92!B;V1Y+@H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]M
M97-S86=E(#T@)R<["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE
M=R!,;V=?;6%I;"!O8FIE8W0N"B`@("`@*@H@("`@("H@2&5R92!I<R!H;W<@
M>6]U(&-A;B!C=7-T;VUI>F4@=&AE(&UA:6P@9')I=F5R('=I=&@@=&AE(&-O
M;F9;72!H87-H(#H*("`@("`J("`@)&-O;F9;)V9R;VTG72`@("`Z('1H92!M
M86EL)W,@(D9R;VTB(&AE861E<B!L:6YE+`H@("`@("H@("`D8V]N9ELG<W5B
M:F5C="==(#H@=&AE(&UA:6PG<R`B4W5B:F5C="(@;&EN92X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("`@5&AE(&9I;&5N86UE(&]F
M('1H92!L;V=F:6QE+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@
M(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R86T@87)R87D@("1C
M;VYF("`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R
M86T@:6YT("`@("1L979E;"`@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I
M;F-L=61I;F<@=&AI<R!L979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N($QO9U]M86EL*"1N86UE+"`D:61E;G0@/2`G
M)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@)&QE
M=F5L(#T@4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I
M9"`](&UD-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]R96-I<&EE
M;G0@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@
M("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*("`@
M("`@("!I9B`H(65M<'1Y*"1C;VYF6R=F<F]M)UTI*2!["B`@("`@("`@("`@
M("1T:&ES+3Y?9G)O;2`]("1C;VYF6R=F<F]M)UT["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'1H:7,M/E]F<F]M(#T@:6YI7V=E="@G<V5N9&UA
M:6Q?9G)O;2<I.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E;7!T>2@D8V]N
M9ELG<W5B:F5C="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W-U8FIE8W0@
M/2`D8V]N9ELG<W5B:F5C="==.PH@("`@("`@('T*"B`@("`@("`@:68@*"%E
M;7!T>2@D8V]N9ELG<')E86UB;&4G72DI('L*("`@("`@("`@("`@)'1H:7,M
M/E]P<F5A;6)L92`]("1C;VYF6R=P<F5A;6)L92==.PH@("`@("`@('T*"B`@
M("`@("`@:68@*"%E;7!T>2@D8V]N9ELG;&EN949O<FUA="==*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^7VQI;F5&;W)M870@/2!S=')?<F5P;&%C92AA<G)A
M>5]K97ES*"1T:&ES+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87E?=F%L=65S*"1T:&ES
M+3Y?9F]R;6%T36%P*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&-O;F9;)VQI;F5&;W)M870G72D["B`@("`@("`@
M?0H*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=T:6UE1F]R;6%T)UTI*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?=&EM949O<FUA="`]("1C;VYF6R=T:6UE
M1F]R;6%T)UT["B`@("`@("`@?0H*("`@("`@("`O*B!R96=I<W1E<B!T:&4@
M9&5S=')U8W1O<B`J+PH@("`@("`@(')E9VES=&5R7W-H=71D;W=N7V9U;F-T
M:6]N*&%R<F%Y*"8D=&AI<RP@)U],;V=?;6%I;"<I*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E<W1R=6-T;W(N($-A;&QS(&-L;W-E*"DN"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%],
M;V=?;6%I;"@I"B`@("!["B`@("`@("`@)'1H:7,M/F-L;W-E*"D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!3=&%R=',@82!N97<@;6%I;"!M97-S86=E+@H@
M("`@("H@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@
M;F5C97-S87)Y+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&]P96XH*0H@("`@>PH@("`@("`@(&EF("@A)'1H
M:7,M/E]O<&5N960I('L*("`@("`@("`@("`@:68@*"%E;7!T>2@D=&AI<RT^
M7W!R96%M8FQE*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]M97-S86=E
M(#T@)'1H:7,M/E]P<F5A;6)L92`N(")<<EQN7')<;B(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/E]O<&5N960@/2!T<G5E.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?;W!E;F5D.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0VQO<V5S('1H92!M97-S86=E+"!I9B!I="!I<R!O<&5N
M+"!A;F0@<V5N9',@=&AE(&UA:6PN"B`@("`@*B!4:&ES(&ES(&EM<&QI8VET
M;'D@8V%L;&5D(&)Y('1H92!D97-T<G5C=&]R+"!I9B!N96-E<W-A<GDN"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I
M;VX@8VQO<V4H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@
M>PH@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?;65S<V%G92DI('L*
M("`@("`@("`@("`@("`@("1H96%D97)S(#T@(D9R;VTZ("1T:&ES+3Y?9G)O
M;5QR7&XB.PH@("`@("`@("`@("`@("`@)&AE861E<G,@+CT@(E5S97(M06=E
M;G0Z($QO9U]M86EL(CL*"B`@("`@("`@("`@("`@("!I9B`H;6%I;"@D=&AI
M<RT^7W)E8VEP:65N="P@)'1H:7,M/E]S=6)J96-T+"`D=&AI<RT^7VUE<W-A
M9V4L"B`@("`@("`@("`@("`@("`@("`@("`@("`D:&5A9&5R<RD@/3T@9F%L
M<V4I('L*("`@("`@("`@("`@("`@("`@("!E<G)O<E]L;V<H(DQO9U]M86EL
M.B!&86EL=7)E(&5X96-U=&EN9R!M86EL*"DB+"`P*3L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@+RH@0VQE87(@=&AE(&UE<W-A9V4@<W1R:6YG(&YO=R!T
M:&%T('1H92!E;6%I;"!H87,@8F5E;B!S96YT+B`J+PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]M97-S86=E(#T@)R<["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'1H:7,M/E]O<&5N960@/2!F86QS93L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`H)'1H:7,M/E]O<&5N960@/3T](&9A;'-E*3L*("`@('T*
M"B`@("`O*BH*("`@("`J($9L=7-H97,@=&AE(&QO9R!O=71P=70@8GD@9F]R
M8VEN9R!T:&4@96UA:6P@;65S<V%G92!T;R!B92!S96YT(&YO=RX*("`@("`J
M($5V96YT<R!T:&%T(&%R92!L;V=G960@869T97(@9FQU<V@H*2!I<R!C86QL
M960@=VEL;"!B92!A<'!E;F1E9"!T;R!A"B`@("`@*B!N97<@96UA:6P@;65S
M<V%G92X*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I
M;F-E($QO9R`Q+C@N,@H@("`@("HO"B`@("!F=6YC=&EO;B!F;'5S:"@I"B`@
M("!["B`@("`@("`@+RH*("`@("`@("`@*B!)="=S('-U9F9I8VEE;G0@=&\@
M<VEM<&QY(&-A;&P@8VQO<V4H*2!T;R!F;'5S:"!T:&4@;W5T<'5T+@H@("`@
M("`@("`J(%1H92!N97AT(&-A;&P@=&\@;&]G*"D@=VEL;"!C875S92!T:&4@
M:&%N9&QE<B!T;R!B92!R96]P96YE9"X*("`@("`@("`@*B\*("`@("`@("!R
M971U<FX@)'1H:7,M/F-L;W-E*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7
M<FET97,@)&UE<W-A9V4@=&\@=&AE(&-U<G)E;G1L>2!O<&5N(&UA:6P@;65S
M<V%G92X*("`@("`J($-A;&QS(&]P96XH*2P@:68@;F5C97-S87)Y+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O
M8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE
M<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@
M87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@
M("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@
M4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!
M4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"
M54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O
M<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N
M=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E
M96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@
M("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I
M;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@
M+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M
M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^
M7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&UE<W-A9V4@:7-N
M)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R92X@
M*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E
M;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@
M("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A=&EO;B!O
M9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T:&ES+3Y?
M97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("`O*B!"=6EL9"!T
M:&4@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&-O;7!L971E(&QO9R!L:6YE+B`J
M+PH@("`@("`@("1T:&ES+3Y?;65S<V%G92`N/2`D=&AI<RT^7V9O<FUA="@D
M=&AI<RT^7VQI;F5&;W)M870L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('-T<F9T:6UE*"1T:&ES+3Y?=&EM949O<FUA="DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M<FEO<FET>2P@)&UE<W-A9V4I("X@(EQR7&XB.PH*("`@("`@("`O*B!.;W1I
M9GD@;V)S97)V97)S(&%B;W5T('1H:7,@;&]G(&UE<W-A9V4N("HO"B`@("`@
M("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO
M<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R
M;B!T<G5E.PH@("`@?0I]"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B],;V<O;6-A;"YP:'``````````````````````````
M`````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$Q-3(U(#$P-3$U-#,T,3,S(#`R
M,#8S,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O
M3&]G+VUC86PN<&AP+'8@,2XQ."`R,#`U+S`R+S(V(#$T.C0X.C4X(&-H86=E
M;F)U($5X<"`D"B`J("1(;W)D93H@:&]R9&4O;&EB+TQO9R]M8V%L+G!H<"QV
M(#$N,B`R,#`P+S`V+S(X(#(Q.C,V.C$S(&IO;B!%>'`@)`H@*@H@*B!`=F5R
M<VEO;B`D4F5V:7-I;VXZ(#$N,3@@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO
M*BH*("H@5&AE($QO9U]M8V%L(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M
M96YT871I;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H
M('-E;F1S(&UE<W-A9V5S('1O(&$@;&]C86P@;W(@<F5M;W1E(&-A;&5N9&%R
M"B`J('-T;W)E(&%C8V5S<V5D('1H<F]U9V@@34-!3"X*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92!(;W)D92`Q+C,*("H@0'-I;F-E($QO9R`Q+C`*("H@0'!A8VMA9V4@3&]G
M"B`J+PIC;&%S<R!,;V=?;6-A;"!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@
M("`J(&AO;&1I;F<@=&AE(&-A;&5N9&%R('-P96-I9FEC871I;VX@=&\@8V]N
M;F5C="!T;RX*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?8V%L96YD87(@/2`G>VQO8V%L:&]S
M="]M<W1O<F5])SL*"B`@("`O*BH*("`@("`J(&AO;&1I;F<@=&AE('5S97)N
M86UE('1O('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=7-E<FYA;64@/2`G)SL*"B`@
M("`O*BH*("`@("`J(&AO;&1I;F<@=&AE('!A<W-W;W)D('1O('5S92X*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1?<&%S<W=O<F0@/2`G)SL*"B`@("`O*BH*("`@("`J(&AO
M;&1I;F<@=&AE(&]P=&EO;G,@=&\@<&%S<R!T;R!T:&4@8V%L96YD87(@<W1R
M96%M+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`](#`["@H@("`@+RHJ"B`@
M("`@*B!297-O=7)C94E$(&]F('1H92!-0T%,('-T<F5A;2X*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?<W1R96%M(#T@)R<["@H@("`@+RHJ"B`@("`@*B!);G1E9V5R(&AO
M;&1I;F<@=&AE(&QO9R!F86-I;&ET>2!T;R!U<V4N"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7VYA;64@/2!,3T=?4UE33$]'.PH*"B`@("`O*BH*("`@("`J($-O;G-T<G5C
M=',@82!N97<@3&]G7VUC86P@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@)&YA;64@("`@(%1H92!C871E9V]R>2!T;R!U<V4@9F]R(&]U
M<B!E=F5N=',N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@("!4:&4@
M:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D8V]N9B`@
M("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R86T@:6YT
M("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN8VQU9&EN
M9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@3&]G7VUC86PH)&YA;64L("1I9&5N="`]("<G+"`D8V]N
M9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`D;&5V96P@/2!0
M14%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U
M*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VYA;64@/2`D;F%M93L*
M("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES
M+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH@("`@("`@("1T:&ES+3Y?
M8V%L96YD87(@/2`D8V]N9ELG8V%L96YD87(G73L*("`@("`@("`D=&AI<RT^
M7W5S97)N86UE(#T@)&-O;F9;)W5S97)N86UE)UT["B`@("`@("`@)'1H:7,M
M/E]P87-S=V]R9"`]("1C;VYF6R=P87-S=V]R9"==.PH@("`@("`@("1T:&ES
M+3Y?;W!T:6]N<R`]("1C;VYF6R=O<'1I;VYS)UT["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!/<&5N<R!A(&-A;&5N9&%R('-T<F5A;2P@:68@:70@:&%S(&YO
M="!A;')E861Y(&)E96X*("`@("`J(&]P96YE9"X@5&AI<R!I<R!I;7!L:6-I
M=&QY(&-A;&QE9"!B>2!L;V<H*2P@:68@;F5C97-S87)Y+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("![
M"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`D
M=&AI<RT^7W-T<F5A;2`](&UC86Q?;W!E;B@D=&AI<RT^7V-A;&5N9&%R+"`D
M=&AI<RT^7W5S97)N86UE+`H@("`@("`@("`@("`@("`@)'1H:7,M/E]P87-S
M=V]R9"P@)'1H:7,M/E]O<'1I;VYS*3L*("`@("`@("`@("`@)'1H:7,M/E]O
M<&5N960@/2!T<G5E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1T:&ES
M+3Y?;W!E;F5D.PH@("`@?0H*("`@("\J*@H@("`@("H@0VQO<V5S('1H92!C
M86QE;F1A<B!S=')E86TL(&EF(&ET(&ES(&]P96XN"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@(&UC86Q?
M8VQO<V4H)'1H:7,M/E]S=')E86TI.PH@("`@("`@("`@("`D=&AI<RT^7V]P
M96YE9"`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("@D=&AI
M<RT^7V]P96YE9"`]/3T@9F%L<V4I.PH@("`@?0H*("`@("\J*@H@("`@("H@
M3&]G<R`D;65S<V%G92!A;F0@87-S;V-I871E9"!I;F9O<FUA=&EO;B!T;R!T
M:&4@8W5R<F5N=&QY(&]P96X*("`@("`J(&-A;&5N9&%R('-T<F5A;2X@0V%L
M;',@;W!E;B@I(&EF(&YE8V5S<V%R>2X@06QS;R!P87-S97,@=&AE"B`@("`@
M*B!M97-S86=E(&%L;VYG('1O(&%N>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S
M('1H870@87)E(&]B<V5R=FEN9PH@("`@("H@=&AI<R!,;V<N"B`@("`@*@H@
M("`@("H@0'!A<F%M(&UI>&5D("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C
M="!C;VYT86EN:6YG('1H92!M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A
M;2!S=')I;F<@)'!R:6]R:71Y(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G
M92X@5F%L:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@
M4$5!4E],3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@
M("`@("`@("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?
M3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@
M("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L
M<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*
M("`@('L*("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P
M96-I9FEE9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF
M("@D<')I;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y
M(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B
M;W)T(&5A<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU
M;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA
M<VME9"@D<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("!]"@H@("`@("`@("\J($EF('1H92!C;VYN96-T:6]N(&ES;B=T
M(&]P96X@86YD(&-A;B=T(&)E(&]P96YE9"P@<F5T=7)N(&9A:6QU<F4N("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"`F)B`A)'1H:7,M/F]P96XH
M*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@
M=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X
M=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@)&1A=&5?<W1R(#T@
M9&%T92@G63IN.FHZ1SII.G,G*3L*("`@("`@("`D9&%T97,@/2!E>'!L;V1E
M*"<Z)RP@)&1A=&5?<W1R*3L*"B`@("`@("`@;6-A;%]E=F5N=%]I;FET*"1T
M:&ES+3Y?<W1R96%M*3L*("`@("`@("!M8V%L7V5V96YT7W-E=%]T:71L92@D
M=&AI<RT^7W-T<F5A;2P@)'1H:7,M/E]I9&5N="D["B`@("`@("`@;6-A;%]E
M=F5N=%]S971?8V%T96=O<GDH)'1H:7,M/E]S=')E86TL("1T:&ES+3Y?;F%M
M92D["B`@("`@("`@;6-A;%]E=F5N=%]S971?9&5S8W)I<'1I;VXH)'1H:7,M
M/E]S=')E86TL("1M97-S86=E*3L*("`@("`@("!M8V%L7V5V96YT7V%D9%]A
M='1R:6)U=&4H)'1H:7,M/E]S=')E86TL("=P<FEO<FET>2<L("1P<FEO<FET
M>2D["B`@("`@("`@;6-A;%]E=F5N=%]S971?<W1A<G0H)'1H:7,M/E]S=')E
M86TL("1D871E<ULP72P@)&1A=&5S6S%=+"`D9&%T97-;,ETL"B`@("`@("`@
M("`@("1D871E<ULS72P@)&1A=&5S6S1=+"`D9&%T97-;-5TI.PH@("`@("`@
M(&UC86Q?979E;G1?<V5T7V5N9"@D=&AI<RT^7W-T<F5A;2P@)&1A=&5S6S!=
M+"`D9&%T97-;,5TL("1D871E<ULR72P*("`@("`@("`@("`@)&1A=&5S6S-=
M+"`D9&%T97-;-%TL("1D871E<ULU72D["B`@("`@("`@;6-A;%]A<'!E;F1?
M979E;G0H)'1H:7,M/E]S=')E86TI.PH*("`@("`@("`D=&AI<RT^7V%N;F]U
M;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@
M/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@I]
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O3&]G+VUD8C(N<&AP````````````````
M````````````````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-3$U-R`Q,#4Q-30S
M-#$S,R`P,C`U-3$`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E
M87(O3&]G+TQO9R]M9&(R+G!H<"QV(#$N-2`R,#`V+S`Q+S`X(#`S.C,U.C0T
M(&IO;B!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-2`D"B`J
M($!P86-K86=E($QO9PH@*B\*"B\J*B!014%2)W,@341",B!P86-K86=E("HO
M"G)E<75I<F5?;VYC92`G341",BYP:'`G.PI-1$(R.CIL;V%D1FEL92@G1&%T
M92<I.PH*+RHJ"B`J(%1H92!,;V=?;61B,B!C;&%S<R!I<R!A(&-O;F-R971E
M(&EM<&QE;65N=&%T:6]N(&]F('1H92!,;V<Z.B!A8G-T<F%C="!C;&%S<PH@
M*B!W:&EC:"!S96YD<R!M97-S86=E<R!T;R!A;B!344P@<V5R=F5R+B`@16%C
M:"!E;G1R>2!O8V-U<&EE<R!A('-E<&%R871E(')O=PH@*B!I;B!T:&4@9&%T
M86)A<V4N"B`J"B`J(%1H:7,@:6UP;&5M96YT871I;VX@=7-E<R!014%2)W,@
M341",B!D871A8F%S92!A8G-T<F%C=&EO;B!L87EE<BX*("H*("H@0U)%051%
M(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)3E0@3D]4($Y5
M3$PL"B`J("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4($Y53$PL"B`J("!I
M9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@('!R:6]R:71Y("`@
M($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4@("`@(%9!4D-(05(H,C`P*2P*
M("H@(%!224U!4ED@2T59("AI9"D*("H@*3L*("H*("H@0&%U=&AO<B`@3'5K
M87,@4VUI=&@@/'-M:71H0&)A8VME;F1M961I82YC;VT^"B`J($!A=71H;W(@
M($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XY
M+C`*("H@0'!A8VMA9V4@3&]G"B`J+PIC;&%S<R!,;V=?;61B,B!E>'1E;F1S
M($QO9PI["B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G1A:6YI;F<@=&AE
M($133B!I;F9O<FUA=&EO;BX*("`@("`J($!V87(@;6EX960*("`@("`J($!A
M8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D<VX@/2`G)SL*"B`@
M("`O*BH*("`@("`J($%R<F%Y(&-O;G1A:6YI;F<@;W5R('-E="!O9B!$0B!C
M;VYF:6=U<F%T:6]N(&]P=&EO;G,N"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@
M*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?;W!T:6]N<R`]
M(&%R<F%Y*"=P97)S:7-T96YT)R`]/B!T<G5E*3L*"B`@("`O*BH*("`@("`J
M($]B:F5C="!H;VQD:6YG('1H92!D871A8F%S92!H86YD;&4N"B`@("`@*B!`
M=F%R(&]B:F5C=`H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7V1B(#T@;G5L;#L*"B`@("`O*BH*("`@("`J(%)E<V]U<F-E(&AO
M;&1I;F<@=&AE('!R97!A<F5D('-T871E;65N="!H86YD;&4N"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?<W1A=&5M96YT(#T@;G5L;#L*"B`@("`O*BH*("`@("`J($9L
M86<@:6YD:6-A=&EN9R!T:&%T('=E)W)E('5S:6YG(&%N(&5X:7-T:6YG(&1A
M=&%B87-E(&-O;FYE8W1I;VXN"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]E>&ES=&EN9T-O
M;FYE8W1I;VX@/2!F86QS93L*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H;VQD
M:6YG('1H92!D871A8F%S92!T86)L92!T;R!U<V4N"B`@("`@*B!`=F%R('-T
M<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7W1A8FQE(#T@)VQO9U]T86)L92<["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@
M:&]L9&EN9R!T:&4@;F%M92!O9B!T:&4@240@<V5Q=65N8V4N"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7W-E<75E;F-E(#T@)VQO9U]I9"<["@H@("`@+RHJ"B`@("`@*B!-
M87AI;75M(&QE;F=T:"!O9B!T:&4@)&ED96YT('-T<FEN9RX@(%1H:7,@8V]R
M<F5S<&]N9',@=&\@=&AE('-I>F4@;V8*("`@("`J('1H92`G:61E;G0G(&-O
M;'5M;B!I;B!T:&4@4U%,('1A8FQE+@H@("`@("H@0'9A<B!I;G1E9V5R"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?:61E;G1,
M:6UI="`](#$V.PH*("`@("\J*@H@("`@("H@4V5T(&]F(&9I96QD('1Y<&5S
M('5S960@:6X@=&AE(&1A=&%B87-E('1A8FQE+@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1Y
M<&5S(#T@87)R87DH"B`@("`@("`@)VED)R`@("`@("`@/3X@)VEN=&5G97(G
M+`H@("`@("`@("=L;V=T:6UE)R`@(#T^("=T:6UE<W1A;7`G+`H@("`@("`@
M("=I9&5N="<@("`@(#T^("=T97AT)RP*("`@("`@("`G<')I;W)I='DG("`]
M/B`G=&5X="<L"B`@("`@("`@)VUE<W-A9V4G("`@/3X@)V-L;V(G"B`@("`I
M.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S<6P@;&]G9VEN
M9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D;F%M92`@
M("`@("`@(%1H92!T87)G970@4U%,('1A8FQE+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D:61E;G0@("`@("`@(%1H92!I9&5N=&EF:6-A=&EO;B!F:65L9"X*
M("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@("`@("!4:&4@8V]N;F5C
M=&EO;B!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`D
M;&5V96P@("`@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A;F0@:6YC;'5D
M:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!,;V=?;61B,B@D;F%M92P@)&ED96YT(#T@)R<L("1C
M;VYF(#T@87)R87DH*2P*("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@
M4$5!4E],3T=?1$5"54<I"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD
M-2AM:6-R;W1I;64H*2D["B`@("`@("`@)'1H:7,M/E]T86)L92`]("1N86UE
M.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH*
M("`@("`@("`O*B!)9B!A;B!O<'1I;VYS(&%R<F%Y('=A<R!P<F]V:61E9"P@
M=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D8V]N9ELG;W!T:6]N<R==
M*2`F)B!I<U]A<G)A>2@D8V]N9ELG;W!T:6]N<R==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]P=&EO;G,@/2`D8V]N9ELG;W!T:6]N<R==.PH@("`@("`@
M('T*"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S97%U96YC92!N86UE('=A
M<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("@A96UP='DH)&-O
M;F9;)W-E<75E;F-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?<V5Q=65N
M8V4@/2`D8V]N9ELG<V5Q=65N8V4G73L*("`@("`@("!]"@H@("`@("`@("\J
M($EF(&$@<W!E8VEF:6,@<V5Q=65N8V4@;F%M92!W87,@<')O=FED960L('5S
M92!I="X@*B\*("`@("`@("!I9B`H:7-S970H)&-O;F9;)VED96YT3&EM:70G
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]I9&5N=$QI;6ET(#T@)&-O;F9;
M)VED96YT3&EM:70G73L*("`@("`@("!]"@H@("`@("`@("\J($YO=R!T:&%T
M('1H92!I9&5N="!L:6UI="!I<R!C;VYF:7)M960L('-E="!T:&4@:61E;G0@
M<W1R:6YG+B`J+PH@("`@("`@("1T:&ES+3YS971)9&5N="@D:61E;G0I.PH*
M("`@("`@("`O*B!)9B!A;B!E>&ES=&EN9R!D871A8F%S92!C;VYN96-T:6]N
M('=A<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E="@D
M8V]N9ELG9&(G72DI('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("8D8V]N
M9ELG9&(G73L*("`@("`@("`@("`@)'1H:7,M/E]E>&ES=&EN9T-O;FYE8W1I
M;VX@/2!T<G5E.PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64[
M"B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1C;VYF6R=S:6YG;&5T;VXG72DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]D8B`]("9-1$(R.CIS:6YG;&5T;VXH
M)&-O;F9;)W-I;F=L971O;B==+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@("`@
M("`@("`D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;B`]('1R=64["B`@("`@
M("`@("`@("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^7V1S;B`]("1C;VYF6R=D<VXG73L*("`@
M("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I
M;VX@=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@
M("`J(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y
M(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E
M;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@
M("`@("`@("`O*B!5<V4@=&AE($133B!A;F0@;W!T:6]N<R!T;R!C<F5A=&4@
M82!D871A8F%S92!C;VYN96-T:6]N+B`J+PH@("`@("`@("`@("`D=&AI<RT^
M7V1B(#T@)DU$0C(Z.F-O;FYE8W0H)'1H:7,M/E]D<VXL("1T:&ES+3Y?;W!T
M:6]N<RD["B`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1T:&ES+3Y?
M9&(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\J($-R96%T92!A('!R97!A<F5D('-T871E
M;65N="!F;W(@<F5P96%T960@=7-E(&EN(&QO9R@I+B`J+PH@("`@("`@("`@
M("!I9B`H(21T:&ES+3Y?<')E<&%R95-T871E;65N="@I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\J(%=E(&YO=R!C;VYS:61E<B!O=70@8V]N;F5C=&EO;B!O<&5N+B`J
M+PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`]('1R=64["B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)'1H:7,M/E]O<&5N960["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!#;&]S97,@=&AE(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B
M87-E(&EF(&ET(&ES('-T:6QL(&]P96X@86YD('=E('=E<F4*("`@("`J('1H
M92!O;F5S('1H870@;W!E;F5D(&ET+B`@270@:7,@=&AE(&-A;&QE<B=S(')E
M<W!O;G-I8FQE('1O(&-L;W-E(&%N"B`@("`@*B!E>&ES=&EN9R!C;VYN96-T
M:6]N('1H870@=V%S('!A<W-E9"!T;R!U<R!V:6$@)&-O;F9;)V1B)UTN"B`@
M("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S
M+"!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@8VQO<V4H*0H@("`@>PH@("`@("`@("\J($EF
M('=E(&AA=F4@82!S=&%T96UE;G0@;V)J96-T+"!F<F5E(&ET+B`J+PH@("`@
M("`@(&EF("AI<U]O8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?<W1A=&5M96YT+3YF<F5E*"D["B`@("`@("`@("`@
M("1T:&ES+3Y?<W1A=&5M96YT(#T@;G5L;#L*("`@("`@("!]"@H@("`@("`@
M("\J($EF('=E(&]P96YE9"!T:&4@9&%T86)A<V4@8V]N;F5C=&EO;BP@9&ES
M8V]N;F5C="!I="X@*B\*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960@)B8@
M(21T:&ES+3Y?97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@9F%L<V4["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^7V1B+3YD:7-C;VYN96-T*"D["B`@("`@("`@?0H*("`@("`@("!R971U
M<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H:7,@3&]G(&EN<W1A;F-E)W,@:61E;G1I9FEC871I
M;VX@<W1R:6YG+B`@3F]T92!T:&%T('1H:7,*("`@("`J(%-13"US<&5C:69I
M8R!I;7!L96UE;G1A=&EO;B!W:6QL(&QI;6ET('1H92!L96YG=&@@;V8@=&AE
M("1I9&5N="!S=')I;F<*("`@("`J('1O('-I>'1E96X@*#$V*2!C:&%R86-T
M97)S+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)&ED96YT("`@
M("`@5&AE(&YE=R!I9&5N=&EF:6-A=&EO;B!S=')I;F<N"B`@("`@*@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B!`<VEN8V4@("!,;V<@,2XX+C4*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5T261E;G0H)&ED96YT*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?:61E;G0@/2!S=6)S='(H)&ED96YT+"`P+"`D=&AI
M<RT^7VED96YT3&EM:70I.PH@("`@?0H*("`@("\J*@H@("`@("H@26YS97)T
M<R`D;65S<V%G92!T;R!T:&4@8W5R<F5N=&QY(&]P96X@9&%T86)A<V4N("!#
M86QL<R!O<&5N*"DL"B`@("`@*B!I9B!N96-E<W-A<GDN("!!;'-O('!A<W-E
M<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R"B`@("`@
M*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@("`@
M("H*("`@("`J($!P87)A;2!M:7AE9"`@)&UE<W-A9V4@(%-T<FEN9R!O<B!O
M8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@=&AE(&UE
M<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V86QU97,@
M87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@("`@*B`@
M("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'7T524BP@
M4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@("`@4$5!
M4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],3T=?1$5"
M54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C8V5S<R!O
M<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I='D@/2!N
M=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S;B=T(&)E
M96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO"B`@("`@
M("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<')I
M;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@("`@("`@
M+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E('1H92!M
M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D=&AI<RT^
M7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@268@=&AE(&-O;FYE8W1I;VX@
M:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@;W!E;F5D+"!R971U<FX@9F%I;'5R
M92X@*B\*("`@("`@("!I9B`H(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^
M;W!E;B@I*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("\J($EF('=E(&1O;B=T(&%L<F5A9'D@:&%V92!A('-T871E
M;65N="!O8FIE8W0L(&-R96%T92!O;F4N("HO"B`@("`@("`@:68@*"%I<U]O
M8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I("8F("$D=&AI<RT^7W!R97!A<F53
M=&%T96UE;G0H*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H*("`@("`@("`O*B!%>'1R86-T('1H92!S=')I;F<@<F5P<F5S96YT
M871I;VX@;V8@=&AE(&UE<W-A9V4N("HO"B`@("`@("`@)&UE<W-A9V4@/2`D
M=&AI<RT^7V5X=')A8W1-97-S86=E*"1M97-S86=E*3L*"B`@("`@("`@+RH@
M0G5I;&0@;W5R('-E="!O9B!V86QU97,@9F]R('1H:7,@;&]G(&5N=')Y+B`J
M+PH@("`@("`@("1V86QU97,@/2!A<G)A>2@*("`@("`@("`@("`@)VED)R`@
M("`@("`]/B`D=&AI<RT^7V1B+3YN97AT260H)'1H:7,M/E]S97%U96YC92DL
M"B`@("`@("`@("`@("=L;V=T:6UE)R`@/3X@341",E]$871E.CIM9&).;W<H
M*2P*("`@("`@("`@("`@)VED96YT)R`@("`]/B`D=&AI<RT^7VED96YT+`H@
M("`@("`@("`@("`G<')I;W)I='DG(#T^("1P<FEO<FET>2P*("`@("`@("`@
M("`@)VUE<W-A9V4G("`]/B`D;65S<V%G90H@("`@("`@("D["@H@("`@("`@
M("\J($5X96-U=&4@=&AE(%-13"!Q=65R>2!F;W(@=&AI<R!L;V<@96YT<GD@
M:6YS97)T:6]N+B`J+PH@("`@("`@("1T:&ES+3Y?9&(M/F5X<&5C=$5R<F]R
M*$U$0C)?15)23U)?3D]354-(5$%"3$4I.PH@("`@("`@("1R97-U;'0@/2`F
M)'1H:7,M/E]S=&%T96UE;G0M/F5X96-U=&4H)'9A;'5E<RD["B`@("`@("`@
M)'1H:7,M/E]D8BT^<&]P17AP96-T*"D["@H@("`@("`@("\J($%T=&5M<'0@
M=&\@:&%N9&QE(&%N>2!E<G)O<G,N("HO"B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@+RH@5V4@8V%N(&]N;'D@
M:&%N9&QE($U$0C)?15)23U)?3D]354-(5$%"3$4@97)R;W)S+B`J+PH@("`@
M("`@("`@("!I9B`H)')E<W5L="T^9V5T0V]D92@I("$]($U$0C)?15)23U)?
M3D]354-(5$%"3$4I('L*("`@("`@("`@("`@("`@(')E='5R;B!F86QS93L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@071T96UP="!T;R!C<F5A
M=&4@=&AE('1A<F=E="!T86)L92X@*B\*("`@("`@("`@("`@:68@*"$D=&AI
M<RT^7V-R96%T951A8FQE*"DI('L*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@4F5C<F5A=&4@
M;W5R('!R97!A<F5D('-T871E;65N="!R97-O=7)C92X@*B\*("`@("`@("`@
M("`@)'1H:7,M/E]S=&%T96UE;G0M/F9R964H*3L*("`@("`@("`@("`@:68@
M*"$D=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O
M*B!!='1E;7!T('1O(')E+65X96-U=&4@=&AE(&EN<V5R=&EO;B!Q=65R>2X@
M*B\*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<W1A=&5M96YT+3YE
M>&5C=71E*"1V86QU97,I.PH@("`@("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%N;F]U
M;F-E*&%R<F%Y*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@
M/3X@)&UE<W-A9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!#<F5A=&4@=&AE(&QO9R!T86)L92!I;B!T:&4@9&%T
M86)A<V4N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!4<G5E(&]N
M('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8W)E871E5&%B;&4H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y?9&(M/FQO861-;V1U;&4H)TUA;F%G97(G
M+"!N=6QL+"!T<G5E*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^
M;6%N86=E<BT^8W)E871E5&%B;&4H"B`@("`@("`@("`@("1T:&ES+3Y?=&%B
M;&4L"B`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@)VED)R`@
M("`@("`@/3X@87)R87DH)W1Y<&4G(#T^("1T:&ES+3Y?='EP97-;)VED)UTI
M+`H@("`@("`@("`@("`@("`@)VQO9W1I;64G("`@/3X@87)R87DH)W1Y<&4G
M(#T^("1T:&ES+3Y?='EP97-;)VQO9W1I;64G72DL"B`@("`@("`@("`@("`@
M("`G:61E;G0G("`@("`]/B!A<G)A>2@G='EP92<@/3X@)'1H:7,M/E]T>7!E
M<ULG:61E;G0G72DL"B`@("`@("`@("`@("`@("`G<')I;W)I='DG("`]/B!A
M<G)A>2@G='EP92<@/3X@)'1H:7,M/E]T>7!E<ULG<')I;W)I='DG72DL"B`@
M("`@("`@("`@("`@("`G;65S<V%G92<@("`]/B!A<G)A>2@G='EP92<@/3X@
M)'1H:7,M/E]T>7!E<ULG;65S<V%G92==*0H@("`@("`@("`@("`I"B`@("`@
M("`@*3L*("`@("`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/E]D8BT^;6%N86=E<BT^8W)E871E26YD97@H"B`@
M("`@("`@("`@("1T:&ES+3Y?=&%B;&4L"B`@("`@("`@("`@("=U;FEQ=65?
M:60G+`H@("`@("`@("`@("!A<G)A>2@G9FEE;&1S)R`]/B!A<G)A>2@G:60G
M(#T^('1R=64I+"`G=6YI<75E)R`]/B!T<G5E*0H@("`@("`@("D["B`@("`@
M("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<F5P87)E('1H92!344P@:6YS97)T
M:6]N('-T871E;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%1R=64@:68@=&AE('-T871E;65N="!W87,@<W5C8V5S<V9U;&QY(&-R96%T
M960N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("H@0'-I
M;F-E("`@3&]G(#$N.2XP"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P<F5P87)E
M4W1A=&5M96YT*"D*("`@('L*("`@("`@("`D=&AI<RT^7W-T871E;65N="`]
M("8D=&AI<RT^7V1B+3YP<F5P87)E*`H@("`@("`@("`@("`@("`@)TE.4T52
M5"!)3E1/("<@+B`D=&AI<RT^7W1A8FQE("X*("`@("`@("`@("`@("`@("<@
M*&ED+"!L;V=T:6UE+"!I9&5N="P@<')I;W)I='DL(&UE<W-A9V4I)R`N"B`@
M("`@("`@("`@("`@("`G(%9!3%5%4R@Z:60L(#IL;V=T:6UE+"`Z:61E;G0L
M(#IP<FEO<FET>2P@.FUE<W-A9V4I)RP*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?='EP97,L($U$0C)?4%)%4$%215]-04Y)4"D["@H@("`@("`@("\J(%)E
M='5R;B!S=6-C97-S(&EF('=E(&1I9&XG="!G96YE<F%T92!A;B!E<G)O<BX@
M*B\*("`@("`@("!R971U<FX@*%!%05(Z.FES17)R;W(H)'1H:7,M/E]S=&%T
M96UE;G0I(#T]/2!F86QS92D["B`@("!]"GT*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+TQO9R]N=6QL+G!H<```````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#0P,#8@,3`U,34T,S0Q,S,@,#(P-C8U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R+TQO9R],;V<O;G5L
M;"YP:'`L=B`Q+C0@,C`P-2\P,B\R-B`Q-#HT.#HU."!C:&%G96YB=2!%>'`@
M)`H@*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N-"`D"B`J($!P86-K86=E
M($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G7VYU;&P@8VQA<W,@:7,@82!C;VYC
M<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH@86)S=')A8W0*("H@
M8VQA<W,N("!)="!S:6UP;'D@8V]N<W5M97,@;&]G(&5V96YT<RX*("H*("H@
M0&%U=&AO<B`@2F]N(%!A<FES92`\:F]N0'!H<"YN970^"B`J($!S:6YC92`@
M($QO9R`Q+C@N,@H@*B!`<&%C:V%G92!,;V<*("H*("H@0&5X86UP;&4@;G5L
M;"YP:'`@("`@57-I;F<@=&AE(&YU;&P@:&%N9&QE<BX*("HO"F-L87-S($QO
M9U]N=6QL(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@0V]N<W1R=6-T
M<R!A(&YE=R!,;V=?;G5L;"!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D;F%M92`@("`@26=N;W)E9"X*("`@("`J($!P87)A;2!S=')I
M;F<@)&ED96YT("`@(%1H92!I9&5N=&ET>2!S=')I;F<N"B`@("`@*B!`<&%R
M86T@87)R87D@("1C;VYF("`@("!4:&4@8V]N9FEG=7)A=&EO;B!A<G)A>2X*
M("`@("`J($!P87)A;2!I;G0@("`@)&QE=F5L("`@($QO9R!M97-S86=E<R!U
M<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S
M('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?;G5L;"@D;F%M92P@
M)&ED96YT(#T@)R<L("1C;VYF(#T@87)R87DH*2P*"0D)"0D@("1L979E;"`]
M(%!%05)?3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("1T:&ES+3Y?:60@/2!M
M9#4H;6EC<F]T:6UE*"DI.PH@("`@("`@("1T:&ES+3Y?:61E;G0@/2`D:61E
M;G0["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L979E;"D[
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!3:6UP;'D@8V]N<W5M97,@=&AE(&QO
M9R!E=F5N="X@(%1H92!M97-S86=E('=I;&P@<W1I;&P@8F4@<&%S<V5D"B`@
M("`@*B!A;&]N9R!T;R!A;GD@3&]G7V]B<V5R=F5R(&EN<W1A;F-E<R!T:&%T
M(&%R92!O8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M
M(&UI>&5D("`D;65S<V%G92`@("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI
M;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*
M("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?
M14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@
M("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)
M3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@
M4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E
M='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I
M;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@
M("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@
M=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I
M='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M
M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY
M(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG
M(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I
M;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"@H@("`@("`@("1T:&ES+3Y?86YN;W5N8V4H87)R87DH)W!R:6]R:71Y)R`]
M/B`D<')I;W)I='DL("=M97-S86=E)R`]/B`D;65S<V%G92DI.PH*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"GT*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+TQO9R]O8G-E<G9E<BYP:'``````````````
M````````````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3`P-3<@,3`U,34T,S0Q
M,S,@,#(Q-30U`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I=&]R>2]P96%R
M+TQO9R],;V<O;V)S97)V97(N<&AP+'8@,2XQ."`R,#`V+S`T+S(U(#`V.C`R
M.C(S(&IO;B!%>'`@)`H@*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O;V)S97)V
M97(N<&AP+'8@,2XU(#(P,#`O,#8O,C@@,C$Z,S8Z,3,@:F]N($5X<"`D"B`J
M"B`J($!V97)S:6]N("12979I<VEO;CH@,2XQ."`D"B`J($!P86-K86=E($QO
M9PH@*B\*"B\J*@H@*B!4:&4@3&]G7V]B<V5R=F5R.CH@8VQA<W,@:6UP;&5M
M96YT<R!T:&4@3V)S97)V97(@96YD(&]F(&$@4W5B:F5C="U/8G-E<G9E<@H@
M*B!P871T97)N(&9O<B!W871C:&EN9R!L;V<@86-T:79I='D@86YD('1A:VEN
M9R!A8W1I;VYS(&]N(&5X8V5P=&EO;F%L(&5V96YT<RX*("H*("H@0&%U=&AO
M<B`@0VAU8VL@2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC
M92`@($AO<F1E(#$N,PH@*B!`<VEN8V4@("!,;V<@,2XP"B`J($!P86-K86=E
M($QO9PH@*@H@*B!`97AA;7!L92!O8G-E<G9E<E]M86EL+G!H<"`@($%N(&5X
M86UP;&4@3&]G7V]B<V5R=F5R(&EM<&QE;65N=&%T:6]N+@H@*B\*8VQA<W,@
M3&]G7V]B<V5R=F5R"GL*("`@("\J*@H@("`@("H@26YS=&%N8V4M<W!E8VEF
M:6,@=6YI<75E(&ED96YT:69I8V%T:6]N(&YU;6)E<BX*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]I9"`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@;6EN:6UU
M;2!P<FEO<FET>2!L979E;"!O9B!M97-S86=E('1H870@=V4@=V%N="!T;R!H
M96%R(&%B;W5T+@H@("`@("H@4$5!4E],3T=?14U%4D<@:7,@=&AE(&AI9VAE
M<W0@<')I;W)I='DL('-O('=E('=I;&P@;VYL>2!H96%R(&UE<W-A9V5S"B`@
M("`@*B!W:71H(&%N(&EN=&5G97(@<')I;W)I='D@=F%L=64@;&5S<R!T:&%N
M(&]R(&5Q=6%L('1O(&]U<G,N("!)="!D969A=6QT<PH@("`@("H@=&\@4$5!
M4E],3T=?24Y&3RP@=VAI8V@@;&ES=&5N<R!T;R!E=F5R>71H:6YG(&5X8V5P
M="!014%27TQ/1U]$14)51RX*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W!R:6]R
M:71Y(#T@4$5!4E],3T=?24Y&3SL*"B`@("`O*BH*("`@("`J($-R96%T97,@
M82!N97<@8F%S:6,@3&]G7V]B<V5R=F5R(&EN<W1A;F-E+@H@("`@("H*("`@
M("`J($!P87)A;2!I;G1E9V5R("`@)'!R:6]R:71Y("`@5&AE(&AI9VAE<W0@
M<')I;W)I='D@870@=VAI8V@@=&\@<F5C96EV90H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!L;V<@979E;G0@;F]T:69I8V%T:6]N<RX*
M("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!,;V=?;V)S97)V97(H)'!R:6]R:71Y(#T@4$5!4E],3T=?24Y&3RD*
M("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*
M("`@("`@("`D=&AI<RT^7W!R:6]R:71Y(#T@)'!R:6]R:71Y.PH@("`@?0H*
M("`@("\J*@H@("`@("H@071T96UP=',@=&\@<F5T=7)N(&$@;F5W(&-O;F-R
M971E($QO9U]O8G-E<G9E<B!I;G-T86YC92!O9B!T:&4@<F5Q=65S=&5D"B`@
M("`@*B!T>7!E+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)'1Y
M<&4@("`@("`@5&AE('1Y<&4@;V8@8V]N8W)E871E($QO9U]O8G-E<G9E<B!S
M=6)C;&%S<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T
M;R!R971U<FXN"B`@("`@*B!`<&%R86T@:6YT96=E<B`@("1P<FEO<FET>2`@
M(%1H92!H:6=H97-T('!R:6]R:71Y(&%T('=H:6-H('1O(')E8V5I=F4*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;&]G(&5V96YT(&YO
M=&EF:6-A=&EO;G,N"B`@("`@*B!`<&%R86T@87)R87D@("`@("1C;VYF("`@
M("`@($]P=&EO;F%L(&%S<V]C:6%T:79E(&%R<F%Y(&]F(&%D9&ET:6]N86P*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8V]N9FEG=7)A
M=&EO;B!V86QU97,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@("`@
M("`@("`@("`@("!4:&4@;F5W;'D@8W)E871E9"!C;VYC<F5T92!,;V=?;V)S
M97)V97(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YS
M=&%N8V4L(&]R(&YU;&P@;VX@86X@97)R;W(N"B`@("`@*B\*("`@(&9U;F-T
M:6]N("9F86-T;W)Y*"1T>7!E+"`D<')I;W)I='D@/2!014%27TQ/1U])3D9/
M+"`D8V]N9B`](&%R<F%Y*"DI"B`@("!["B`@("`@("`@)'1Y<&4@/2!S=')T
M;VQO=V5R*"1T>7!E*3L*("`@("`@("`D8VQA<W,@/2`G3&]G7V]B<V5R=F5R
M7R<@+B`D='EP93L*"B`@("`@("`@+RH*("`@("`@("`@*B!)9B!T:&4@9&5S
M:7)E9"!C;&%S<R!A;')E861Y(&5X:7-T<R`H8F5C875S92!T:&4@8V%L;&5R
M(&AA<R!S=7!P;&EE9`H@("`@("`@("`J(&ET(&9R;VT@<V]M92!C=7-T;VT@
M;&]C871I;VXI+"!S:6UP;'D@:6YS=&%N=&EA=&4@86YD(')E='5R;B!A(&YE
M=PH@("`@("`@("`J(&EN<W1A;F-E+@H@("`@("`@("`J+PH@("`@("`@(&EF
M("AC;&%S<U]E>&ES=',H)&-L87-S*2D@>PH@("`@("`@("`@("`D;V)J96-T
M(#T@)FYE=R`D8VQA<W,H)'!R:6]R:71Y+"`D8V]N9BD["B`@("`@("`@("`@
M(')E='5R;B`D;V)J96-T.PH@("`@("`@('T*"B`@("`@("`@+RH@4W5P<&]R
M="!B;W1H('1H92!N97<M<W1Y;&4@86YD(&]L9"US='EL92!F:6QE(&YA;6EN
M9R!C;VYV96YT:6]N<RX@*B\*("`@("`@("`D;F5W<W1Y;&4@/2!T<G5E.PH@
M("`@("`@("1C;&%S<V9I;&4@/2!D:7)N86UE*%]?1DE,15]?*2`N("<O;V)S
M97)V97)?)R`N("1T>7!E("X@)RYP:'`G.PH*("`@("`@("!I9B`H(69I;&5?
M97AI<W1S*"1C;&%S<V9I;&4I*2!["B`@("`@("`@("`@("1C;&%S<V9I;&4@
M/2`G3&]G+R<@+B`D='EP92`N("<N<&AP)SL*("`@("`@("`@("`@)&YE=W-T
M>6QE(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*@H@("`@("`@("`J
M($%T=&5M<'0@=&\@:6YC;'5D92!O=7(@=F5R<VEO;B!O9B!T:&4@;F%M960@
M8VQA<W,L(&)U="!D;VXG="!T<F5A=`H@("`@("`@("`J(&$@9F%I;'5R92!A
M<R!F871A;"X@(%1H92!C86QL97(@;6%Y(&AA=F4@86QR96%D>2!I;F-L=61E
M9"!T:&5I<B!O=VX*("`@("`@("`@*B!V97)S:6]N(&]F('1H92!N86UE9"!C
M;&%S<RX*("`@("`@("`@*B\*("`@("`@("!`:6YC;'5D95]O;F-E("1C;&%S
M<V9I;&4["@H@("`@("`@("\J($EF('1H92!C;&%S<R!E>&ES=',L(')E='5R
M;B!A(&YE=R!I;G-T86YC92!O9B!I="X@*B\*("`@("`@("!I9B`H8VQA<W-?
M97AI<W1S*"1C;&%S<RDI('L*("`@("`@("`@("`@+RH@4W5P<&]R="!B;W1H
M(&YE=RUS='EL92!A;F0@;VQD+7-T>6QE(&-O;G-T<G5C=&EO;BX@*B\*("`@
M("`@("`@("`@:68@*"1N97=S='EL92D@>PH@("`@("`@("`@("`@("`@)&]B
M:F5C="`]("9N97<@)&-L87-S*"1P<FEO<FET>2P@)&-O;F8I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&]B:F5C="`]("9N97<@
M)&-L87-S*"1P<FEO<FET>2D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1O8FIE8W0["B`@("`@("`@?0H*("`@("`@("`D;G5L;"`](&YU
M;&P["B`@("`@("`@<F5T=7)N("1N=6QL.PH@("`@?0H*("`@("\J*@H@("`@
M("H@5&AI<R!I<R!A('-T=6(@;65T:&]D('1O(&UA:V4@<W5R92!T:&%T($QO
M9U]/8G-E<G9E<B!C;&%S<V5S(&1O"B`@("`@*B!S;VUE=&AI;F<@=VAE;B!T
M:&5Y(&%R92!N;W1I9FEE9"!O9B!A(&UE<W-A9V4N("!4:&4@9&5F875L="!B
M96AA=FEO<@H@("`@("H@:7,@=&\@:G5S="!P<FEN="!T:&4@;65S<V%G92P@
M=VAI8V@@:7,@;V)V:6]U<VQY(&YO="!D97-I<F5A8FQE(&EN"B`@("`@*B!P
M<F%C=&EC86QL>2!A;GD@<VET=6%T:6]N("T@=VAI8V@@:7,@=VAY('EO=2!N
M965D('1O(&]V97)R:61E('1H:7,*("`@("`J(&UE=&AO9"X@.BD*("`@("`J
M"B`@("`@*B!`<&%R86T@87)R87D@("`@("1E=F5N="`@("`@($$@:&%S:"!D
M97-C<FEB:6YG('1H92!L;V<@979E;G0N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YO=&EF>2@D979E;G0I"B`@("!["B`@("`@("`@<')I;G1?<B@D979E;G0I
M.PH@("`@?0I]"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O3&]G+W-Q;"YP:'``````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`R,3`W,R`Q,#4Q-30S-#$S,R`P,C`U,34`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]S
M<6PN<&AP+'8@,2XT,"`R,#`V+S`Q+S`S(#`T.C$R.C0U(&IO;B!%>'`@)`H@
M*B`D2&]R9&4Z(&AO<F1E+VQI8B],;V<O<W%L+G!H<"QV(#$N,3(@,C`P,"\P
M."\Q-B`R,#HR-SHS-"!C:'5C:R!%>'`@)`H@*@H@*B!`=F5R<VEO;B`D4F5V
M:7-I;VXZ(#$N-#`@)`H@*B!`<&%C:V%G92!,;V<*("HO"@HO*@H@*B!792!R
M97%U:7)E('1H92!014%2($1"(&-L87-S+B`@5&AI<R!I<R!G96YE<F%L;'D@
M9&5F:6YE9"!I;B!T:&4@1$(N<&AP(&9I;&4L"B`J(&)U="!I="=S('!O<W-I
M8FQE('1H870@=&AE(&-A;&QE<B!M87D@:&%V92!P<F]V:61E9"!T:&4@1$(@
M8VQA<W,L(&]R(&$*("H@8V]M<&%T:6)L92!W<F%P<&5R("AS=6-H(&%S('1H
M92!O;F4@<VAI<'!E9"!W:71H($U$0C(I+"!S;R!W92!F:7)S="!C:&5C:PH@
M*B!F;W(@86X@97AI<W1I;F<@)T1")R!C;&%S<R!B969O<F4@:6YC;'5D:6YG
M("=$0BYP:'`G+@H@*B\*:68@*"%C;&%S<U]E>&ES=',H)T1")RDI('L*("`@
M(')E<75I<F5?;VYC92`G1$(N<&AP)SL*?0H*+RHJ"B`J(%1H92!,;V=?<W%L
M(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I;VX@;V8@=&AE($QO
M9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E;F1S(&UE<W-A9V5S('1O
M(&%N(%-13"!S97)V97(N("!%86-H(&5N=')Y"B`J(&]C8W5P:65S(&$@<V5P
M87)A=&4@<F]W(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I;7!L96UE
M;G1A=&EO;B!U<V5S(%!(4"=S(%!%05(@9&%T86)A<V4@86)S=')A8W1I;VX@
M;&%Y97(N"B`J"B`J($-214%412!404),12!L;V=?=&%B;&4@*`H@*B`@:60@
M("`@("`@("`@24Y4($Y/5"!.54Q,+`H@*B`@;&]G=&EM92`@("`@5$E-15-4
M04U0($Y/5"!.54Q,+`H@*B`@:61E;G0@("`@("`@0TA!4B@Q-BD@3D]4($Y5
M3$PL"B`J("!P<FEO<FET>2`@("!)3E0@3D]4($Y53$PL"B`J("!M97-S86=E
M("`@("!605)#2$%2*#(P,"DL"B`J("!04DE-05)9($M%62`H:60I"B`J("D[
M"B`J"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`
M<VEN8V4@("!(;W)D92`Q+C,*("H@0'-I;F-E("`@3&]G(#$N,`H@*B!`<&%C
M:V%G92!,;V<*("H*("H@0&5X86UP;&4@<W%L+G!H<"`@("`@57-I;F<@=&AE
M(%-13"!H86YD;&5R+@H@*B\*8VQA<W,@3&]G7W-Q;"!E>'1E;F1S($QO9PI[
M"B`@("`O*BH*("`@("`J(%9A<FEA8FQE(&-O;G1A:6YI;F<@=&AE($133B!I
M;F9O<FUA=&EO;BX*("`@("`J($!V87(@;6EX960*("`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@("HO"B`@("!V87(@)%]D<VX@/2`G)SL*"B`@("`O*BH*
M("`@("`J(%-T<FEN9R!C;VYT86EN:6YG('1H92!344P@:6YS97)T:6]N('-T
M871E;65N="X*("`@("`J"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-Q;"`]("<G.PH*("`@
M("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!O=7(@<V5T(&]F($1"(&-O
M;F9I9W5R871I;VX@;W!T:6]N<RX*("`@("`J($!V87(@87)R87D*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]O<'1I;VYS(#T@
M87)R87DH)W!E<G-I<W1E;G0G(#T^('1R=64I.PH*("`@("\J*@H@("`@("H@
M3V)J96-T(&AO;&1I;F<@=&AE(&1A=&%B87-E(&AA;F1L92X*("`@("`J($!V
M87(@;V)J96-T"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?9&(@/2!N=6QL.PH*("`@("\J*@H@("`@("H@4F5S;W5R8V4@:&]L
M9&EN9R!T:&4@<')E<&%R960@<W1A=&5M96YT(&AA;F1L92X*("`@("`J($!V
M87(@<F5S;W5R8V4*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@
M("!V87(@)%]S=&%T96UE;G0@/2!N=6QL.PH*("`@("\J*@H@("`@("H@1FQA
M9R!I;F1I8V%T:6YG('1H870@=V4G<F4@=7-I;F<@86X@97AI<W1I;F<@9&%T
M86)A<V4@8V]N;F5C=&EO;BX*("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@
M0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V5X:7-T:6YG0V]N
M;F5C=&EO;B`](&9A;'-E.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I
M;F<@=&AE(&1A=&%B87-E('1A8FQE('1O('5S92X*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M=&%B;&4@/2`G;&]G7W1A8FQE)SL*"B`@("`O*BH*("`@("`J(%-T<FEN9R!H
M;VQD:6YG('1H92!N86UE(&]F('1H92!)1"!S97%U96YC92X*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?<V5Q=65N8V4@/2`G;&]G7VED)SL*"B`@("`O*BH*("`@("`J($UA
M>&EM=6T@;&5N9W1H(&]F('1H92`D:61E;G0@<W1R:6YG+B`@5&AI<R!C;W)R
M97-P;VYD<R!T;R!T:&4@<VEZ92!O9@H@("`@("H@=&AE("=I9&5N="<@8V]L
M=6UN(&EN('1H92!344P@=&%B;&4N"B`@("`@*B!`=F%R(&EN=&5G97(*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]I9&5N=$QI
M;6ET(#T@,38["@H*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!S
M<6P@;&]G9VEN9R!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D;F%M92`@("`@("`@(%1H92!T87)G970@4U%,('1A8FQE+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:61E;G0@("`@("`@(%1H92!I9&5N=&EF:6-A=&EO
M;B!F:65L9"X*("`@("`J($!P87)A;2!A<G)A>2`D8V]N9B`@("`@("`@("!4
M:&4@8V]N;F5C=&EO;B!C;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A
M<F%M(&EN="`D;&5V96P@("`@("`@("`@($QO9R!M97-S86=E<R!U<"!T;R!A
M;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`86-C97-S('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?<W%L*"1N86UE+"`D:61E;G0@
M/2`G)RP@)&-O;F8@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`D
M;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^
M7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W1A8FQE
M(#T@)&YA;64["B`@("`@("`@)'1H:7,M/E]M87-K(#T@3&]G.CI54%1/*"1L
M979E;"D["@H@("`@("`@("\J($YO=R!T:&%T('=E(&AA=F4@82!T86)L92!N
M86UE+"!A<W-I9VX@;W5R(%-13"!S=&%T96UE;G0N("HO"B`@("`@("`@:68@
M*"%E;7!T>2@D=&AI<RT^7W-Q;"DI('L*("`@("`@("`@("`@)'1H:7,M/E]S
M<6P@/2`D8V]N9ELG<W%L)UT["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/E]S<6P@/2`G24Y315)4($E.5$\@)R`N("1T:&ES+3Y?=&%B
M;&4@+@H@("`@("`@("`@("`@("`@("`@("`@("`@("<@*&ED+"!L;V=T:6UE
M+"!I9&5N="P@<')I;W)I='DL(&UE<W-A9V4I)R`N"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@)R!604Q515,H/RP@0U524D5.5%]424U%4U1!35`L(#\L
M(#\L(#\I)SL*("`@("`@("!]"@H@("`@("`@("\J($EF(&%N(&]P=&EO;G,@
M87)R87D@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@("`@("`@:68@*&ES
M<V5T*"1C;VYF6R=O<'1I;VYS)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=O<'1I
M;VYS)UTI*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!T:6]N<R`]("1C;VYF
M6R=O<'1I;VYS)UT["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!A('-P96-I
M9FEC('-E<75E;F-E(&YA;64@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO"B`@
M("`@("`@:68@*"%E;7!T>2@D8V]N9ELG<V5Q=65N8V4G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]S97%U96YC92`]("1C;VYF6R=S97%U96YC92==.PH@
M("`@("`@('T*"B`@("`@("`@+RH@268@82!S<&5C:69I8R!S97%U96YC92!N
M86UE('=A<R!P<F]V:61E9"P@=7-E(&ET+B`J+PH@("`@("`@(&EF("AI<W-E
M="@D8V]N9ELG:61E;G1,:6UI="==*2D@>PH@("`@("`@("`@("`D=&AI<RT^
M7VED96YT3&EM:70@/2`D8V]N9ELG:61E;G1,:6UI="==.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3F]W('1H870@=&AE(&ED96YT(&QI;6ET(&ES(&-O;F9I
M<FUE9"P@<V5T('1H92!I9&5N="!S=')I;F<N("HO"B`@("`@("`@)'1H:7,M
M/G-E=$ED96YT*"1I9&5N="D["@H@("`@("`@("\J($EF(&%N(&5X:7-T:6YG
M(&1A=&%B87-E(&-O;FYE8W1I;VX@=V%S('!R;W9I9&5D+"!U<V4@:70N("HO
M"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=D8B==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7V1B(#T@)B1C;VYF6R=D8B==.PH@("`@("`@("`@("`D=&AI
M<RT^7V5X:7-T:6YG0V]N;F5C=&EO;B`]('1R=64["B`@("`@("`@("`@("1T
M:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^7V1S;B`]("1C;VYF6R=D<VXG73L*("`@("`@("!]"B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!/<&5N<R!A(&-O;FYE8W1I;VX@=&\@=&AE
M(&1A=&%B87-E+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J(&)E96X@
M;W!E;F5D+B!4:&ES(&ES(&EM<&QI8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I
M9B!N96-E<W-A<GDN"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("`@
M5')U92!O;B!S=6-C97-S+"!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("![
M"B`@("`@("`@:68@*"$D=&AI<RT^7V]P96YE9"D@>PH@("`@("`@("`@("`O
M*B!5<V4@=&AE($133B!A;F0@;W!T:6]N<R!T;R!C<F5A=&4@82!D871A8F%S
M92!C;VYN96-T:6]N+B`J+PH@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)D1"
M.CIC;VYN96-T*"1T:&ES+3Y?9'-N+"`D=&AI<RT^7V]P=&EO;G,I.PH@("`@
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'1H:7,M/E]D8BDI('L*("`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@+RH@0W)E871E(&$@<')E<&%R960@<W1A=&5M96YT(&9O<B!R97!E
M871E9"!U<V4@:6X@;&]G*"DN("HO"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]P<F5P87)E4W1A=&5M96YT*"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+RH@5V4@;F]W
M(&-O;G-I9&5R(&]U="!C;VYN96-T:6]N(&]P96XN("HO"B`@("`@("`@("`@
M("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L
M;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@:68@:70@:7,@
M<W1I;&P@;W!E;B!A;F0@=V4@=V5R90H@("`@("H@=&AE(&]N97,@=&AA="!O
M<&5N960@:70N("!)="!I<R!T:&4@8V%L;&5R)W,@<F5S<&]N<VEB;&4@=&\@
M8VQO<V4@86X*("`@("`J(&5X:7-T:6YG(&-O;FYE8W1I;VX@=&AA="!W87,@
M<&%S<V5D('1O('5S('9I82`D8V]N9ELG9&(G72X*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&9A
M:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3Y?;W!E;F5D
M("8F("$D=&AI<RT^7V5X:7-T:6YG0V]N;F5C=&EO;BD@>PH@("`@("`@("`@
M("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@("`@("`D=&AI<RT^
M7V1B+3YF<F5E4')E<&%R960H)'1H:7,M/E]S=&%T96UE;G0I.PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/E]D8BT^9&ES8V]N;F5C="@I.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("@D=&AI<RT^7V]P96YE9"`]/3T@9F%L<V4I
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4V5T<R!T:&ES($QO9R!I;G-T86YC
M92=S(&ED96YT:69I8V%T:6]N('-T<FEN9RX@($YO=&4@=&AA="!T:&ES"B`@
M("`@*B!344PM<W!E8VEF:6,@:6UP;&5M96YT871I;VX@=VEL;"!L:6UI="!T
M:&4@;&5N9W1H(&]F('1H92`D:61E;G0@<W1R:6YG"B`@("`@*B!T;R!S:7AT
M965N("@Q-BD@8VAA<F%C=&5R<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("`@("1I9&5N="`@("`@(%1H92!N97<@:61E;G1I9FEC871I;VX@<W1R
M:6YG+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'-I
M;F-E("`@3&]G(#$N."XU"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$ED96YT
M*"1I9&5N="D*("`@('L*("`@("`@("`D=&AI<RT^7VED96YT(#T@<W5B<W1R
M*"1I9&5N="P@,"P@)'1H:7,M/E]I9&5N=$QI;6ET*3L*("`@('T*"B`@("`O
M*BH*("`@("`J($EN<V5R=',@)&UE<W-A9V4@=&\@=&AE(&-U<G)E;G1L>2!O
M<&5N(&1A=&%B87-E+B`@0V%L;',@;W!E;B@I+`H@("`@("H@:68@;F5C97-S
M87)Y+B`@06QS;R!P87-S97,@=&AE(&UE<W-A9V4@86QO;F<@=&\@86YY($QO
M9U]O8G-E<G9E<@H@("`@("H@:6YS=&%N8V5S('1H870@87)E(&]B<V5R=FEN
M9R!T:&ES($QO9RX*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S
M86=E("!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@
M=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN9R`D<')I;W)I='D@5&AE('!R
M:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L:60*("`@("`J("`@("`@("`@
M("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],3T=?14U%4D<L(%!%05)?3$]'
M7T%,15)4+`H@("`@("H@("`@("`@("`@("`@("`@("!014%27TQ/1U]#4DE4
M+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!4DY)3D<L"B`@("`@*B`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#12P@4$5!4E],3T=?24Y&3RP@
M86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@0')E='5R;B!B;V]L96%N("!4
M<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@9F%I;'5R92X*("`@("`J($!A
M8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&QO9R@D;65S<V%G
M92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*("`@("`@("`O*B!)9B!A('!R
M:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE9"P@=7-E('1H92!D969A=6QT
M('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I;W)I='D@/3T](&YU;&PI('L*
M("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H:7,M/E]P<FEO<FET>3L*("`@
M("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A<FQY(&EF('1H92!P<FEO<FET
M>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G:6YG(&QE=F5L+B`J+PH@("`@
M("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D<')I;W)I='DI*2!["B`@("`@
M("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($EF
M('1H92!C;VYN96-T:6]N(&ES;B=T(&]P96X@86YD(&-A;B=T(&)E(&]P96YE
M9"P@<F5T=7)N(&9A:6QU<F4N("HO"B`@("`@("`@:68@*"$D=&AI<RT^7V]P
M96YE9"`F)B`A)'1H:7,M/F]P96XH*2D@>PH@("`@("`@("`@("!R971U<FX@
M9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!)9B!W92!D;VXG="!A;')E
M861Y(&AA=F4@;W5R('-T871E;65N="!O8FIE8W0@>65T+"!C<F5A=&4@:70N
M("HO"B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'1H:7,M/E]S=&%T96UE;G0I
M("8F("$D=&AI<RT^7W!R97!A<F53=&%T96UE;G0H*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@("`O*B!%>'1R86-T
M('1H92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@=&AE(&UE<W-A9V4N("HO
M"B`@("`@("`@)&UE<W-A9V4@/2`D=&AI<RT^7V5X=')A8W1-97-S86=E*"1M
M97-S86=E*3L*"B`@("`@("`@+RH@0G5I;&0@;W5R('-E="!O9B!V86QU97,@
M9F]R('1H:7,@;&]G(&5N=')Y+B`J+PH@("`@("`@("1I9"`]("1T:&ES+3Y?
M9&(M/FYE>'1)9"@D=&AI<RT^7W-E<75E;F-E*3L*("`@("`@("`D=F%L=65S
M(#T@87)R87DH)&ED+"`D=&AI<RT^7VED96YT+"`D<')I;W)I='DL("1M97-S
M86=E*3L*"B`@("`@("`@+RH@17AE8W5T92!T:&4@4U%,('%U97)Y(&9O<B!T
M:&ES(&QO9R!E;G1R>2!I;G-E<G1I;VXN("HO"B`@("`@("`@)')E<W5L="`]
M)B`D=&AI<RT^7V1B+3YE>&5C=71E*"1T:&ES+3Y?<W1A=&5M96YT+"`D=F%L
M=65S*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@)'1H
M:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^("1P<FEO<FET>2P@
M)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*("`@("\J*@H@("`@("H@4')E<&%R92!T:&4@4U%,(&EN<V5R
M=&EO;B!S=&%T96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N
M("!4<G5E(&EF('1H92!S=&%T96UE;G0@=V%S('-U8V-E<W-F=6QL>2!C<F5A
M=&5D+@H@("`@("H*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J($!S
M:6YC92`@($QO9R`Q+CDN,0H@("`@("HO"B`@("!F=6YC=&EO;B!?<')E<&%R
M95-T871E;65N="@I"B`@("!["B`@("`@("`@)'1H:7,M/E]S=&%T96UE;G0@
M/2`D=&AI<RT^7V1B+3YP<F5P87)E*"1T:&ES+3Y?<W%L*3L*"B`@("`@("`@
M+RH@4F5T=7)N('-U8V-E<W,@:68@=V4@9&ED;B=T(&=E;F5R871E(&%N(&5R
M<F]R+B`J+PH@("`@("`@(')E='5R;B`H1$(Z.FES17)R;W(H)'1H:7,M/E]S
M=&%T96UE;G0I(#T]/2!F86QS92D["B`@("!]"GT*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B],;V<O<W%L:71E+G!H<```````````````````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$U-38R(#$P-3$U-#,T,3,S
M(#`R,3(R-0`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`HO*BH*("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],
M;V<O3&]G+W-Q;&ET92YP:'`L=B`Q+C4@,C`P-2\Q,B\P-2`P-3HS.#HS,2!J
M;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E=FES:6]N.B`Q+C4@)`H@*B!`
M<&%C:V%G92!,;V<*("HO"@HO*BH*("H@5&AE($QO9U]S<6QI=&4@8VQA<W,@
M:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G.CH*("H@
M86)S=')A8W0@8VQA<W,@=VAI8V@@<V5N9',@;65S<V%G97,@=&\@86X@4W%L
M:71E(&1A=&%B87-E+@H@*B!%86-H(&5N=')Y(&]C8W5P:65S(&$@<V5P87)A
M=&4@<F]W(&EN('1H92!D871A8F%S92X*("H*("H@5&AI<R!I;7!L96UE;G1A
M=&EO;B!U<V5S(%!(4"!N871I=F4@4W%L:71E(&9U;F-T:6]N<RX*("H*("H@
M0U)%051%(%1!0DQ%(&QO9U]T86)L92`H"B`J("!I9"`@("`@("`@("!)3E1%
M1T52(%!224U!4ED@2T59($Y/5"!.54Q,+`H@*B`@;&]G=&EM92`@("`@3D]4
M($Y53$PL"B`J("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("H@
M('!R:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("H@(&UE<W-A9V4*("H@*3L*
M("H*("H@0&%U=&AO<B`@0F5R=')A;F0@36%N<VEO;B`\8FUA;G-I;VY`;6%M
M87-A;2YC;VT^"B`J($!A=71H;W(@($IO;B!087)I<V4@/&IO;D!P:'`N;F5T
M/@H@*B!`<VEN8V4@("!,;V<@,2XX+C,*("H@0'!A8VMA9V4@3&]G"B`J"B`J
M($!E>&%M<&QE('-Q;&ET92YP:'`@("`@("!5<VEN9R!T:&4@4W%L:71E(&AA
M;F1L97(N"B`J+PIC;&%S<R!,;V=?<W%L:71E(&5X=&5N9',@3&]G"GL*("`@
M("\J*@H@("`@("H@07)R87D@8V]N=&%I;FEN9R!T:&4@8V]N;F5C=&EO;B!D
M969A=6QT<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7V]P=&EO;G,@/2!A<G)A>2@G;6]D92<@
M("`@("`@/3X@,#8V-BP*("`@("`@("`@("`@("`@("`@("`@("`@("`G<&5R
M<VES=&5N="<@/3X@9F%L<V4I.PH*("`@("\J*@H@("`@("H@3V)J96-T(&AO
M;&1I;F<@=&AE(&1A=&%B87-E(&AA;F1L92X*("`@("`J($!V87(@;V)J96-T
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&(@
M/2!N=6QL.PH*("`@("\J*@H@("`@("H@1FQA9R!I;F1I8V%T:6YG('1H870@
M=V4G<F4@=7-I;F<@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;BX*
M("`@("`J($!V87(@8F]O;&5A;@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@
M("`@*B\*("`@('9A<B`D7V5X:7-T:6YG0V]N;F5C=&EO;B`](&9A;'-E.PH*
M("`@("\J*@H@("`@("H@4W1R:6YG(&AO;&1I;F<@=&AE(&1A=&%B87-E('1A
M8FQE('1O('5S92X*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S
M('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?=&%B;&4@/2`G;&]G7W1A8FQE
M)SL*"@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1S(&$@;F5W('-Q;"!L;V=G
M:6YG(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1N86UE
M("`@("`@("`@5&AE('1A<F=E="!344P@=&%B;&4N"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1I9&5N="`@("`@("`@5&AE(&ED96YT:69I8V%T:6]N(&9I96QD
M+@H@("`@("H@0'!A<F%M(&UI>&5D("`D8V]N9B`@("`@("`@($-A;B!B92!A
M;B!A<G)A>2!O9B!C;VYF:6=U<F%T:6]N(&]P=&EO;G,@=7-E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('1O(&]P96X@82!N97<@9&%T
M86)A<V4@8V]N;F5C=&EO;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&]R(&%N(&%L<F5A9'D@;W!E;F5D('-Q;&ET92!C;VYN96-T:6]N
M+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@("`@($QO9R!M97-S
M86=E<R!U<"!T;R!A;F0@:6YC;'5D:6YG('1H:7,@;&5V96PN"B`@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!,;V=?<W%L:71E
M*"1N86UE+"`D:61E;G0@/2`G)RP@)B1C;VYF+"`D;&5V96P@/2!014%27TQ/
M1U]$14)51RD*("`@('L*("`@("`@("`D=&AI<RT^7VED(#T@;60U*&UI8W)O
M=&EM92@I*3L*("`@("`@("`D=&AI<RT^7W1A8FQE(#T@)&YA;64["B`@("`@
M("`@)'1H:7,M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA
M<VL@/2!,;V<Z.E505$\H)&QE=F5L*3L*"B`@("`@("`@:68@*&ES7V%R<F%Y
M*"1C;VYF*2D@>PH@("`@("`@("`@("!F;W)E86-H("@D8V]N9B!A<R`D:R`]
M/B`D;W!T*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^7V]P=&EO;G-;)&M=
M(#T@)&]P=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O($EF(&%N(&5X:7-T:6YG(&1A=&%B87-E(&-O;FYE8W1I;VX@
M=V%S('!R;W9I9&5D+"!U<V4@:70N"B`@("`@("`@("`@("1T:&ES+3Y?9&(@
M/28@)&-O;F8["B`@("`@("`@("`@("1T:&ES+3Y?97AI<W1I;F=#;VYN96-T
M:6]N(#T@=')U93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!/
M<&5N<R!A(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E+"!I9B!I="!H87,@
M;F]T(&%L<F5A9'D*("`@("`J(&)E96X@;W!E;F5D+B!4:&ES(&ES(&EM<&QI
M8VET;'D@8V%L;&5D(&)Y(&QO9R@I+"!I9B!N96-E<W-A<GDN"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L96%N("`@5')U92!O;B!S=6-C97-S+"!F86QS
M92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@
M("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U
M<F-E*"1T:&ES+3Y?9&(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?;W!E;F5D
M(#T@=')U93L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3Y?8W)E871E5&%B
M;&4H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*B!3970@=&AE
M(&-O;FYE8W1I;VX@9G5N8W1I;VX@8F%S960@;VX@=&AE("=P97)S:7-T96YT
M)R!O<'1I;VXN("HO"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7V]P
M=&EO;G-;)W!E<G-I<W1E;G0G72DI('L*("`@("`@("`@("`@("`@("1C;VYN
M96-T1G5N8W1I;VX@/2`G<W%L:71E7V]P96XG.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W1&=6YC=&EO;B`]("=S<6QI
M=&5?<&]P96XG.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O*B!!='1E
M;7!T('1O(&-O;FYE8W0@=&\@=&AE(&1A=&%B87-E+B`J+PH@("`@("`@("`@
M("!I9B`H)'1H:7,M/E]D8B`]("1C;VYN96-T1G5N8W1I;VXH)'1H:7,M/E]O
M<'1I;VYS6R=F:6QE;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@*&EN="DD=&AI<RT^7V]P=&EO;G-;)VUO
M9&4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1E<G)O<BDI('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?;W!E
M;F5D(#T@=')U93L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^7V-R
M96%T951A8FQE*"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M(')E='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J
M($-L;W-E<R!T:&4@8V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@:68@:70@
M:7,@<W1I;&P@;W!E;B!A;F0@=V4@=V5R90H@("`@("H@=&AE(&]N97,@=&AA
M="!O<&5N960@:70N("!)="!I<R!T:&4@8V%L;&5R)W,@<F5S<&]N<VEB;&4@
M=&\@8VQO<V4@86X*("`@("`J(&5X:7-T:6YG(&-O;FYE8W1I;VX@=&AA="!W
M87,@<&%S<V5D('1O('5S('9I82`D8V]N9ELG9&(G72X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VQE86X@("!4<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N
M(&9A:6QU<F4N"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@+RH@5V4@;F5V97(@8VQO
M<V4@97AI<W1I;F<@8V]N;F5C=&EO;G,N("HO"B`@("`@("`@:68@*"1T:&ES
M+3Y?97AI<W1I;F=#;VYN96-T:6]N*2!["B`@("`@("`@("`@(')E='5R;B!F
M86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"D@
M>PH@("`@("`@("`@("`D=&AI<RT^7V]P96YE9"`](&9A;'-E.PH@("`@("`@
M("`@("!S<6QI=&5?8VQO<V4H)'1H:7,M/E]D8BD["B`@("`@("`@?0H*("`@
M("`@("!R971U<FX@*"1T:&ES+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!);G-E<G1S("1M97-S86=E('1O('1H92!C=7)R
M96YT;'D@;W!E;B!D871A8F%S92X@($-A;&QS(&]P96XH*2P*("`@("`J(&EF
M(&YE8V5S<V%R>2X@($%L<V\@<&%S<V5S('1H92!M97-S86=E(&%L;VYG('1O
M(&%N>2!,;V=?;V)S97)V97(*("`@("`J(&EN<W1A;F-E<R!T:&%T(&%R92!O
M8G-E<G9I;F<@=&AI<R!,;V<N"B`@("`@*@H@("`@("H@0'!A<F%M(&UI>&5D
M("`D;65S<V%G92`@4W1R:6YG(&]R(&]B:F5C="!C;VYT86EN:6YG('1H92!M
M97-S86=E('1O(&QO9RX*("`@("`J($!P87)A;2!S=')I;F<@)'!R:6]R:71Y
M(%1H92!P<FEO<FET>2!O9B!T:&4@;65S<V%G92X@(%9A;&ED"B`@("`@*B`@
M("`@("`@("`@("`@("`@('9A;'5E<R!A<F4Z(%!%05)?3$]'7T5-15)'+"!0
M14%27TQ/1U]!3$525"P*("`@("`J("`@("`@("`@("`@("`@("`@4$5!4E],
M3T=?0U))5"P@4$5!4E],3T=?15)2+"!014%27TQ/1U]705).24Y'+`H@("`@
M("H@("`@("`@("`@("`@("`@("!014%27TQ/1U].3U1)0T4L(%!%05)?3$]'
M7TE.1D\L(&%N9"!014%27TQ/1U]$14)51RX*("`@("`J($!R971U<FX@8F]O
M;&5A;B`@5')U92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!L;V<H
M)&UE<W-A9V4L("1P<FEO<FET>2`](&YU;&PI"B`@("!["B`@("`@("`@+RH@
M268@82!P<FEO<FET>2!H87-N)W0@8F5E;B!S<&5C:69I960L('5S92!T:&4@
M9&5F875L="!V86QU92X@*B\*("`@("`@("!I9B`H)'!R:6]R:71Y(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@("1P<FEO<FET>2`]("1T:&ES+3Y?<')I;W)I
M='D["B`@("`@("`@?0H*("`@("`@("`O*B!!8F]R="!E87)L>2!I9B!T:&4@
M<')I;W)I='D@:7,@86)O=F4@=&AE(&UA>&EM=6T@;&]G9VEN9R!L979E;"X@
M*B\*("`@("`@("!I9B`H(21T:&ES+3Y?:7--87-K960H)'!R:6]R:71Y*2D@
M>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*("`@("`@
M("`O*B!)9B!T:&4@8V]N;F5C=&EO;B!I<VXG="!O<&5N(&%N9"!C86XG="!B
M92!O<&5N960L(')E='5R;B!F86EL=7)E+B`J+PH@("`@("`@(&EF("@A)'1H
M:7,M/E]O<&5N960@)B8@(21T:&ES+3YO<&5N*"DI('L*("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+R\@17AT<F%C="!T
M:&4@<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+@H@("`@
M("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G
M92D["@H@("`@("`@("\O($)U:6QD('1H92!344P@<75E<GD@9F]R('1H:7,@
M;&]G(&5N=')Y(&EN<V5R=&EO;BX*("`@("`@("`D<2`]('-P<FEN=&8H)TE.
M4T525"!)3E1/(%LE<UT@*&QO9W1I;64L(&ED96YT+"!P<FEO<FET>2P@;65S
M<V%G92D@)R`N"B`@("`@("`@("`@("`@("`@("`@(")604Q515,@*"<E<R<L
M("<E<R<L("5D+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@('-T<F9T:6UE*"<E62TE
M;2TE9"`E2#HE33HE4R<L('1I;64H*2DL"B`@("`@("`@("`@("`@("`@("`@
M('-Q;&ET95]E<V-A<&5?<W1R:6YG*"1T:&ES+3Y?:61E;G0I+`H@("`@("`@
M("`@("`@("`@("`@("`D<')I;W)I='DL"B`@("`@("`@("`@("`@("`@("`@
M('-Q;&ET95]E<V-A<&5?<W1R:6YG*"1M97-S86=E*2D["B`@("`@("`@:68@
M*"$H)')E<R`]($!S<6QI=&5?=6YB=69F97)E9%]Q=65R>2@D=&AI<RT^7V1B
M+"`D<2DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG(#T^
M("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@("`@
M(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@("`@("H@0VAE8VMS('=H
M971H97(@=&AE(&QO9R!T86)L92!E>&ES=',@86YD(&-R96%T97,@:70@:68@
M;F5C97-S87)Y+@H@("`@("H*("`@("`J($!R971U<FX@8F]O;&5A;B`@5')U
M92!O;B!S=6-C97-S(&]R(&9A;'-E(&]N(&9A:6QU<F4N"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T951A8FQE
M*"D*("`@('L*("`@("`@("`D<2`](")314Q%0U0@;F%M92!&4D]-('-Q;&ET
M95]M87-T97(@5TA%4D4@;F%M93TG(B`N("1T:&ES+3Y?=&%B;&4@+@H@("`@
M("`@("`@("`@(B<@04Y$('1Y<&4])W1A8FQE)R(["@H@("`@("`@("1R97,@
M/2!S<6QI=&5?<75E<GDH)'1H:7,M/E]D8BP@)'$I.PH*("`@("`@("!I9B`H
M<W%L:71E7VYU;5]R;W=S*"1R97,I(#T](#`I('L*("`@("`@("`@("`@)'$@
M/2`G0U)%051%(%1!0DQ%(%LG("X@)'1H:7,M/E]T86)L92`N("==("@G("X*
M("`@("`@("`@("`@("`@("`G:60@24Y414=%4B!04DE-05)9($M%62!.3U0@
M3E5,3"P@)R`N"B`@("`@("`@("`@("`@("`@)VQO9W1I;64@3D]4($Y53$PL
M("<@+@H@("`@("`@("`@("`@("`@("=I9&5N="!#2$%2*#$V*2!.3U0@3E5,
M3"P@)R`N"B`@("`@("`@("`@("`@("`@)W!R:6]R:71Y($E.5"!.3U0@3E5,
M3"P@)R`N"B`@("`@("`@("`@("`@("`@)VUE<W-A9V4I)SL*"B`@("`@("`@
M("`@(&EF("@A*"1R97,@/2!S<6QI=&5?=6YB=69F97)E9%]Q=65R>2@D=&AI
M<RT^7V1B+"`D<2DI*2!["B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E
M.PH@("`@?0H*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B],;V<O<WES;&]G+G!H<```````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#$Q-#$U(#$P-3$U-#,T,3,S(#`R,3(S-0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO*BH*
M("H@)$AE861E<CH@+W)E<&]S:71O<GDO<&5A<B],;V<O3&]G+W-Y<VQO9RYP
M:'`L=B`Q+C(S(#(P,#4O,#(O,C8@,30Z-#@Z-3D@8VAA9V5N8G4@17AP("0*
M("H@)$AO<F1E.B!H;W)D92]L:6(O3&]G+W-Y<VQO9RYP:'`L=B`Q+C8@,C`P
M,"\P-B\R."`R,3HS-CHQ,R!J;VX@17AP("0*("H*("H@0'9E<G-I;VX@)%)E
M=FES:6]N.B`Q+C(S("0*("H@0'!A8VMA9V4@3&]G"B`J+PH*+RHJ"B`J(%1H
M92!,;V=?<WES;&]G(&-L87-S(&ES(&$@8V]N8W)E=&4@:6UP;&5M96YT871I
M;VX@;V8@=&AE($QO9SHZ"B`J(&%B<W1R86-T(&-L87-S('=H:6-H('-E;F1S
M(&UE<W-A9V5S('1O('-Y<VQO9R!O;B!53DE8+6QI:V4@;6%C:&EN97,*("H@
M*%!(4"!E;75L871E<R!T:&ES('=I=&@@=&AE($5V96YT($QO9R!O;B!7:6YD
M;W=S(&UA8VAI;F5S*2X*("H*("H@0&%U=&AO<B`@0VAU8VL@2&%G96YB=6-H
M(#QC:'5C:T!H;W)D92YO<F<^"B`J($!S:6YC92`@($AO<F1E(#$N,PH@*B!`
M<VEN8V4@("!,;V<@,2XP"B`J($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L
M92!S>7-L;V<N<&AP("`@("`@57-I;F<@=&AE('-Y<VQO9R!H86YD;&5R+@H@
M*B\*8VQA<W,@3&]G7W-Y<VQO9R!E>'1E;F1S($QO9PI["B`@("`O*BH*("`@
M("H@26YT96=E<B!H;VQD:6YG('1H92!L;V<@9F%C:6QI='D@=&\@=7-E+@H@
M("`@*B!`=F%R('-T<FEN9PH@("`@*B!`86-C97-S('!R:79A=&4*("`@("HO
M"B`@("!V87(@)%]N86UE(#T@3$]'7U-94TQ/1SL*"B`@("`O*BH*("`@("`J
M($-O;G-T<G5C=',@82!N97<@<WES;&]G(&]B:F5C="X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!4:&4@<WES;&]G(&9A8VEL:71Y
M+@H@("`@("H@0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y
M('-T<FEN9RX*("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C
M;VYF:6=U<F%T:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V
M96P@("`@3&]G(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L
M979E;"X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N($QO9U]S>7-L;V<H)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R
M<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("1L979E;"`](%!%05)?
M3$]'7T1%0E5'*0H@("`@>PH@("`@("`@("\J($5N<W5R92!W92!H879E(&$@
M=F%L:60@:6YT96=E<B!V86QU92!F;W(@)&YA;64N("HO"B`@("`@("`@:68@
M*&5M<'1Y*"1N86UE*2!\?"`A:7-?:6YT*"1N86UE*2D@>PH@("`@("`@("`@
M("`D;F%M92`]($Q/1U]365-,3T<["B`@("`@("`@?0H*("`@("`@("`D=&AI
M<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VYA
M;64@/2`D;F%M93L*("`@("`@("`D=&AI<RT^7VED96YT(#T@)&ED96YT.PH@
M("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!43R@D;&5V96PI.PH@("`@
M?0H*("`@("\J*@H@("`@("H@3W!E;G,@82!C;VYN96-T:6]N('1O('1H92!S
M>7-T96T@;&]G9V5R+"!I9B!I="!H87,@;F]T(&%L<F5A9'D*("`@("`J(&)E
M96X@;W!E;F5D+B`@5&AI<R!I<R!I;7!L:6-I=&QY(&-A;&QE9"!B>2!L;V<H
M*2P@:68@;F5C97-S87)Y+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@;W!E;B@I"B`@("!["B`@("`@("`@:68@*"$D=&AI
M<RT^7V]P96YE9"D@>PH@("`@("`@("`@("!O<&5N;&]G*"1T:&ES+3Y?:61E
M;G0L($Q/1U]0240L("1T:&ES+3Y?;F%M92D["B`@("`@("`@("`@("1T:&ES
M+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D
M=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L;W-E<R!T
M:&4@8V]N;F5C=&EO;B!T;R!T:&4@<WES=&5M(&QO9V=E<BP@:68@:70@:7,@
M;W!E;BX*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&-L;W-E*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/E]O<&5N960I
M('L*("`@("`@("`@("`@8VQO<V5L;V<H*3L*("`@("`@("`@("`@)'1H:7,M
M/E]O<&5N960@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(')E='5R;B`H
M)'1H:7,M/E]O<&5N960@/3T](&9A;'-E*3L*("`@('T*"B`@("`O*BH*("`@
M("`J(%-E;F1S("1M97-S86=E('1O('1H92!C=7)R96YT;'D@;W!E;B!S>7-L
M;V<@8V]N;F5C=&EO;BX@($-A;&QS"B`@("`@*B!O<&5N*"D@:68@;F5C97-S
M87)Y+B!!;'-O('!A<W-E<R!T:&4@;65S<V%G92!A;&]N9R!T;R!A;GD@3&]G
M7V]B<V5R=F5R"B`@("`@*B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG
M('1H:7,@3&]G+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D;65S<V%G
M92!3=')I;F<@;W(@;V)J96-T(&-O;G1A:6YI;F<@=&AE(&UE<W-A9V4@=&\@
M;&]G+@H@("`@("H@0'!A<F%M(&EN="`D<')I;W)I='D@*&]P=&EO;F%L*2!4
M:&4@<')I;W)I='D@;V8@=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@
M("`@("`@("`@("`@("!V86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!
M4E],3T=?04Q%4E0L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'
M7T-2250L(%!%05)?3$]'7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J
M("`@("`@("`@("`@("`@("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])
M3D9/+"!A;F0@4$5!4E],3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE
M86X@(%1R=64@;VX@<W5C8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@
M("H@0&%C8V5S<R!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M
M97-S86=E+"`D<')I;W)I='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF
M(&$@<')I;W)I='D@:&%S;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E
M9F%U;'0@=F%L=64N("HO"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y
M.PH@("`@("`@('T*"B`@("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R
M:6]R:71Y(&ES(&%B;W9E('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO
M"B`@("`@("`@:68@*"$D=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*
M("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@
M+RH@268@=&AE(&-O;FYE8W1I;VX@:7-N)W0@;W!E;B!A;F0@8V%N)W0@8F4@
M;W!E;F5D+"!R971U<FX@9F%I;'5R92X@*B\*("`@("`@("!I9B`H(21T:&ES
M+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE
M('-T<FEN9R!R97!R97-E;G1A=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@
M("`@("`D;65S<V%G92`]("1T:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A
M9V4I.PH*("`@("`@("!I9B`H(7-Y<VQO9R@D=&AI<RT^7W1O4WES;&]G*"1P
M<FEO<FET>2DL("1M97-S86=E*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^7V%N;F]U;F-E*&%R<F%Y
M*"=P<FEO<FET>2<@/3X@)'!R:6]R:71Y+"`G;65S<V%G92<@/3X@)&UE<W-A
M9V4I*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#;VYV97)T<R!A(%!%05)?3$]'7RH@8V]N<W1A;G0@:6YT;R!A('-Y
M<VQO9R!,3T=?*B!C;VYS=&%N="X*("`@("`J"B`@("`@*B!4:&ES(&9U;F-T
M:6]N(&5X:7-T<R!B96-A=7-E+"!U;F1E<B!7:6YD;W=S+"!N;W0@86QL(&]F
M('1H92!,3T=?*@H@("`@("H@8V]N<W1A;G1S(&AA=F4@=6YI<75E('9A;'5E
M<RX@($EN<W1E860L('1H92!014%27TQ/1U\J('=E<F4@:6YT<F]D=6-E9`H@
M("`@("H@9F]R(&=L;V)A;"!U<V4L('=I=&@@=&AE(&-O;G9E<G-I;VX@=&\@
M=&AE($Q/1U\J(&-O;G-T86YT<R!K97!T(&QO8V%L('1O"B`@("`@*B!T;R!T
M:&4@<WES;&]G(&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1P
M<FEO<FET>2`@("`@4$5!4E],3T=?*B!V86QU92!T;R!C;VYV97)T('1O($Q/
M1U\J('9A;'5E+@H@("`@("H*("`@("`J($!R971U<FX@(%1H92!,3T=?*B!R
M97!R97-E;G1A=&EO;B!O9B`D<')I;W)I='DN"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]T;U-Y<VQO9R@D
M<')I;W)I='DI"B`@("!["B`@("`@("`@<W1A=&EC("1P<FEO<FET:65S(#T@
M87)R87DH"B`@("`@("`@("`@(%!%05)?3$]'7T5-15)'("`@/3X@3$]'7T5-
M15)'+`H@("`@("`@("`@("!014%27TQ/1U]!3$525"`@(#T^($Q/1U]!3$52
M5"P*("`@("`@("`@("`@4$5!4E],3T=?0U))5"`@("`]/B!,3T=?0U))5"P*
M("`@("`@("`@("`@4$5!4E],3T=?15)2("`@("`]/B!,3T=?15)2+`H@("`@
M("`@("`@("!014%27TQ/1U]705).24Y'(#T^($Q/1U]705).24Y'+`H@("`@
M("`@("`@("!014%27TQ/1U].3U1)0T4@(#T^($Q/1U].3U1)0T4L"B`@("`@
M("`@("`@(%!%05)?3$]'7TE.1D\@("`@/3X@3$]'7TE.1D\L"B`@("`@("`@
M("`@(%!%05)?3$]'7T1%0E5'("`@/3X@3$]'7T1%0E5'"B`@("`@("`@*3L*
M"B`@("`@("`@+RH@268@=V4G<F4@<&%S<V5D(&%N('5N:VYO=VX@<')I;W)I
M='DL(&1E9F%U;'0@=&\@3$]'7TE.1D\N("HO"B`@("`@("`@:68@*"%I<U]I
M;G0H)'!R:6]R:71Y*2!\?"`A:6Y?87)R87DH)'!R:6]R:71Y+"`D<')I;W)I
M=&EE<RDI('L*("`@("`@("`@("`@<F5T=7)N($Q/1U])3D9/.PH@("`@("`@
M('T*"B`@("`@("`@<F5T=7)N("1P<FEO<FET:65S6R1P<FEO<FET>5T["B`@
M("!]"@I]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O3&]G+W=I;BYP:'``````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`Q-S(V,R`Q,#4Q-30S-#$S,R`P,C`U,C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*+RHJ"B`J("1(96%D97(Z("]R97!O<VET;W)Y+W!E87(O3&]G+TQO9R]W
M:6XN<&AP+'8@,2XQ."`R,#`V+S`S+S`R(#`S.C`V.C0S(&IO;B!%>'`@)`H@
M*@H@*B!`=F5R<VEO;B`D4F5V:7-I;VXZ(#$N,3@@)`H@*B!`<&%C:V%G92!,
M;V<*("HO"@HO*BH*("H@5&AE($QO9U]W:6X@8VQA<W,@:7,@82!C;VYC<F5T
M92!I;7!L96UE;G1A=&EO;B!O9B!T:&4@3&]G(&%B<W1R86-T"B`J(&-L87-S
M('1H870@;&]G<R!M97-S86=E<R!T;R!A('-E<&%R871E(&)R;W=S97(@=VEN
M9&]W+@H@*@H@*B!4:&4@8V]N8V5P="!F;W(@=&AI<R!L;V<@:&%N9&QE<B!I
M<R!B87-E9"!O;B!P87)T(&)Y($-R86EG($1A=FES)R!A<G1I8VQE"B`J(&5N
M=&ET;&5D(")*879A4V-R:7!T(%!O=V5R(%!(4"!$96)U9V=I;F<Z"B`J"B`J
M("!H='1P.B\O=W=W+GIE;F0N8V]M+WIE;F0O='5T+W1U=&]R:6%L+41E8G5G
M3&EB+G!H<`H@*@H@*B!`875T:&]R("!*;VX@4&%R:7-E(#QJ;VY`<&AP+FYE
M=#X*("H@0'-I;F-E("`@3&]G(#$N-RXP"B`J($!P86-K86=E($QO9PH@*@H@
M*B!`97AA;7!L92!W:6XN<&AP("`@("!5<VEN9R!T:&4@=VEN9&]W(&AA;F1L
M97(N"B`J+PIC;&%S<R!,;V=?=VEN(&5X=&5N9',@3&]G"GL*("`@("\J*@H@
M("`@("H@5&AE(&YA;64@;V8@=&AE(&]U='!U="!W:6YD;W<N"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7VYA;64@/2`G3&]G5VEN9&]W)SL*"B`@("`O*BH*("`@("`J(%1H
M92!T:71L92!O9B!T:&4@;W5T<'5T('=I;F1O=RX*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M=&ET;&4@/2`G3&]G($]U='!U="!7:6YD;W<G.PH*("`@("\J*@H@("`@("H@
M36%P<&EN9R!O9B!L;V<@<')I;W)I=&EE<R!T;R!C;VQO<G,N"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?8V]L;W)S(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@
M(%!%05)?3$]'7T5-15)'("`@/3X@)W)E9"<L"B`@("`@("`@("`@("`@("`@
M("`@("`@(%!%05)?3$]'7T%,15)4("`@/3X@)V]R86YG92<L"B`@("`@("`@
M("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250@("`@/3X@)WEE;&QO=R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T524B`@("`@/3X@
M)V=R965N)RP*("`@("`@("`@("`@("`@("`@("`@("`@4$5!4E],3T=?5T%2
M3DE.1R`]/B`G8FQU92<L"B`@("`@("`@("`@("`@("`@("`@("`@(%!%05)?
M3$]'7TY/5$E#12`@/3X@)VEN9&EG;R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@(%!%05)?3$]'7TE.1D\@("`@/3X@)W9I;VQE="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@(%!%05)?3$]'7T1%0E5'("`@/3X@)V)L86-K)PH@("`@
M("`@("`@("`@("`@("`@("D["@H@("`@+RHJ"B`@("`@*B!3=')I;F<@8G5F
M9F5R('1H870@:&]L9',@;&EN92!T:&%T(&%R92!P96YD:6YG(&]U='!U="X*
M("`@("`J($!V87(@87)R87D*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M("HO"B`@("!V87(@)%]B=69F97(@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@0V]N<W1R=6-T<R!A(&YE=R!,;V=?=VEN(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1N86UE("`@("!)9VYO<F5D+@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:61E;G0@("`@5&AE(&ED96YT:71Y('-T<FEN9RX*
M("`@("`J($!P87)A;2!A<G)A>2`@)&-O;F8@("`@(%1H92!C;VYF:6=U<F%T
M:6]N(&%R<F%Y+@H@("`@("H@0'!A<F%M(&EN="`@("`D;&5V96P@("`@3&]G
M(&UE<W-A9V5S('5P('1O(&%N9"!I;F-L=61I;F<@=&AI<R!L979E;"X*("`@
M("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N($QO9U]W
M:6XH)&YA;64L("1I9&5N="`]("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&QE=F5L(#T@4$5!4E],3T=?1$5"54<I
M"B`@("!["B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2AM:6-R;W1I;64H*2D[
M"B`@("`@("`@)'1H:7,M/E]N86UE(#T@)&YA;64["B`@("`@("`@)'1H:7,M
M/E]I9&5N="`]("1I9&5N=#L*("`@("`@("`D=&AI<RT^7VUA<VL@/2!,;V<Z
M.E505$\H)&QE=F5L*3L*"B`@("`@("`@:68@*&ES<V5T*"1C;VYF6R=T:71L
M92==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7W1I=&QE(#T@)&-O;F9;)W1I
M=&QE)UT["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D8V]N9ELG8V]L
M;W)S)UTI("8F(&ES7V%R<F%Y*"1C;VYF6R=C;VQO<G,G72DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]C;VQO<G,@/2`D8V]N9ELG8V]L;W)S)UT["B`@("`@
M("`@?0H*("`@("`@("!R96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A
M>2@F)'1H:7,L("=?3&]G7W=I;B<I*3L*("`@('T*"B`@("`O*BH*("`@("`J
M($1E<W1R=6-T;W(*("`@("`J+PH@("`@9G5N8W1I;VX@7TQO9U]W:6XH*0H@
M("`@>PH@("`@("`@(&EF("@D=&AI<RT^7V]P96YE9"!\?"`H8V]U;G0H)'1H
M:7,M/E]B=69F97(I(#X@,"DI('L*("`@("`@("`@("`@)'1H:7,M/F-L;W-E
M*"D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@5&AE(&9I<G-T
M('1I;64@;W!E;B@I(&ES(&-A;&QE9"P@:70@=VEL;"!O<&5N(&$@;F5W(&)R
M;W=S97(@=VEN9&]W(&%N9`H@("`@("H@<')E<&%R92!I="!F;W(@;W5T<'5T
M+@H@("`@("H*("`@("`J(%1H:7,@:7,@:6UP;&EC:71L>2!C86QL960@8GD@
M;&]G*"DL(&EF(&YE8V5S<V%R>2X*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!O<&5N*"D*("`@('L*("`@("`@
M("!I9B`H(21T:&ES+3Y?;W!E;F5D*2!["B`@("`@("`@("`@("1W:6X@/2`D
M=&AI<RT^7VYA;64["@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T:&ES+3Y?
M:61E;G0I*2!["B`@("`@("`@("`@("`@("`D:61E;G1(96%D97(@/2`B)'=I
M;BYD;V-U;65N="YW<FET96QN*"<\=&@^261E;G0\+W1H/B<I(CL*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I9&5N=$AE861E<B`]
M("<G.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!E8VAO(#P\/"!%3D1?
M3T9?4T-225!4"CQS8W)I<'0@;&%N9W5A9V4](DIA=F%38W)I<'0B/@HD=VEN
M(#T@=VEN9&]W+F]P96XH)R<L("=[)'1H:7,M/E]N86UE?2<L("=T;V]L8F%R
M/6YO+'-C<F]L;&)A<G,L=VED=&@]-C`P+&AE:6=H=#TT,#`G*3L*)'=I;BYD
M;V-U;65N="YW<FET96QN*"<\:'1M;#XG*3L*)'=I;BYD;V-U;65N="YW<FET
M96QN*"<\:&5A9#XG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\=&ET;&4^
M>R1T:&ES+3Y?=&ET;&5]/"]T:71L93XG*3L*)'=I;BYD;V-U;65N="YW<FET
M96QN*"<\<W1Y;&4@='EP93TB=&5X="]C<W,B/B<I.PHD=VEN+F1O8W5M96YT
M+G=R:71E;&XH)V)O9'D@>R!F;VYT+69A;6EL>3H@;6]N;W-P86-E.R!F;VYT
M+7-I>F4Z(#AP=#L@?2<I.PHD=VEN+F1O8W5M96YT+G=R:71E;&XH)W1D+'1H
M('L@9F]N="US:7IE.B`X<'0[('TG*3L*)'=I;BYD;V-U;65N="YW<FET96QN
M*"=T9"QT:"![(&)O<F1E<BUB;W1T;VTZ(",Y.3DY.3D@<V]L:60@,7!X.R!]
M)RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G=&0L=&@@>R!B;W)D97(M<FEG
M:'0Z(",Y.3DY.3D@<V]L:60@,7!X.R!])RD["B1W:6XN9&]C=6UE;G0N=W)I
M=&5L;B@G='(@>R!T97AT+6%L:6=N.B!L969T.R!V97)T:6-A;"UA;&EG;CH@
M=&]P.R!])RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G/"]S='EL93XG*3L*
M)'=I;BYD;V-U;65N="YW<FET96QN*"<\+VAE860^)RD["B1W:6XN9&]C=6UE
M;G0N=W)I=&5L;B@G/&)O9'D^)RD["B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G
M/'1A8FQE(&)O<F1E<CTB,"(@8V5L;'!A9&1I;F<](C(B(&-E;&QS<&%C:6YG
M/2(P(CXG*3L*)'=I;BYD;V-U;65N="YW<FET96QN*"<\='(^/'1H/E1I;64\
M+W1H/B<I.PHD:61E;G1(96%D97(*)'=I;BYD;V-U;65N="YW<FET96QN*"<\
M=&@^4')I;W)I='D\+W1H/CQT:"!W:61T:#TB,3`P)2(^365S<V%G93PO=&@^
M/"]T<CXG*3L*/"]S8W)I<'0^"D5.1%]/1E]30U))4%0["B`@("`@("`@("`@
M("1T:&ES+3Y?;W!E;F5D(#T@=')U93L*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D=&AI<RT^7V]P96YE9#L*("`@('T*"B`@("`O*BH*("`@("`J($-L
M;W-E<R!T:&4@;W5T<'5T('-T<F5A;2!I9B!I="!I<R!O<&5N+B`@268@=&AE
M<F4@87)E('-T:6QL('!E;F1I;F<*("`@("`J(&QI;F5S(&EN('1H92!O=71P
M=70@8G5F9F5R+"!T:&4@;W5T<'5T('=I;F1O=R!W:6QL(&)E(&]P96YE9"!S
M;R!T:&%T"B`@("`@*B!T:&4@8G5F9F5R(&-A;B!B92!D<F%I;F5D+@H@("`@
M("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-L;W-E*"D*("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF('1H97)E
M(&%R92!S=&EL;"!L:6YE<R!W86ET:6YG('1O(&)E('=R:71T96XL(&]P96X@
M=&AE(&]U='!U=`H@("`@("`@("`J('=I;F1O=R!S;R!T:&%T('=E(&-A;B!D
M<F%I;B!T:&4@8G5F9F5R+@H@("`@("`@("`J+PH@("`@("`@(&EF("@A)'1H
M:7,M/E]O<&5N960@)B8@*&-O=6YT*"1T:&ES+3Y?8G5F9F5R*2`^(#`I*2![
M"B`@("`@("`@("`@("1T:&ES+3YO<&5N*"D["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)'1H:7,M/E]O<&5N960I('L*("`@("`@("`@("`@)'1H:7,M/E]W
M<FET96QN*"<\+W1A8FQE/B<I.PH@("`@("`@("`@("`D=&AI<RT^7W=R:71E
M;&XH)SPO8F]D>3X\+VAT;6P^)RD["B`@("`@("`@("`@("1T:&ES+3Y?;W!E
M;F5D(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!R971U<FX@*"1T:&ES
M+3Y?;W!E;F5D(#T]/2!F86QS92D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!7
M<FET97,@82!S:6YG;&4@;&EN92!O9B!T97AT('1O('1H92!O=71P=70@=VEN
M9&]W+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("`@)&QI;F4@("!4
M:&4@;&EN92!O9B!T97AT('1O('=R:71E+@H@("`@("H*("`@("`J($!A8V-E
M<W,@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?=W)I=&5L;B@D;&EN
M92D*("`@('L*("`@("`@("`O*B!!9&0@=&AI<R!L:6YE('1O(&]U<B!O=71P
M=70@8G5F9F5R+B`J+PH@("`@("`@("1T:&ES+3Y?8G5F9F5R6UT@/2`D;&EN
M93L*"B`@("`@("`@+RH@0G5F9F5R('1H92!O=71P=70@=6YT:6P@=&AI<R!P
M86=E)W,@:&5A9&5R<R!H879E(&)E96X@<V5N="X@*B\*("`@("`@("!I9B`H
M(6AE861E<G-?<V5N="@I*2!["B`@("`@("`@("`@(')E='5R;CL*("`@("`@
M("!]"@H@("`@("`@("\J($EF('=E(&AA=F5N)W0@86QR96%D>2!O<&5N960@
M=&AE(&]U='!U="!W:6YD;W<L(&1O('-O(&YO=RX@*B\*("`@("`@("!I9B`H
M(21T:&ES+3Y?;W!E;F5D("8F("$D=&AI<RT^;W!E;B@I*2!["B`@("`@("`@
M("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J($1R86EN
M('1H92!B=69F97(@=&\@=&AE(&]U='!U="!W:6YD;W<N("HO"B`@("`@("`@
M)'=I;B`]("1T:&ES+3Y?;F%M93L*("`@("`@("!F;W)E86-H("@D=&AI<RT^
M7V)U9F9E<B!A<R`D;&EN92D@>PH@("`@("`@("`@("!E8VAO("(\<V-R:7!T
M(&QA;F=U86=E/2=*879A4V-R:7!T)SY<;B(["B`@("`@("`@("`@(&5C:&\@
M(B1W:6XN9&]C=6UE;G0N=W)I=&5L;B@G(B`N(&%D9'-L87-H97,H)&QI;F4I
M("X@(B<I.UQN(CL*("`@("`@("`@("`@96-H;R`B<V5L9BYF;V-U<R@I.UQN
M(CL*("`@("`@("`@("`@96-H;R`B/"]S8W)I<'0^7&XB.PH@("`@("`@('T*
M"B`@("`@("`@+RH@3F]W('1H870@=&AE(&)U9F9E<B!H87,@8F5E;B!D<F%I
M;F5D+"!C;&5A<B!I="X@*B\*("`@("`@("`D=&AI<RT^7V)U9F9E<B`](&%R
M<F%Y*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!,;V=S("1M97-S86=E('1O
M('1H92!O=71P=70@=VEN9&]W+B`@5&AE(&UE<W-A9V4@:7,@86QS;R!P87-S
M960@86QO;F<*("`@("`J('1O(&%N>2!,;V=?;V)S97)V97(@:6YS=&%N8V5S
M('1H870@87)E(&]B<V5R=FEN9R!T:&ES($QO9RX*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@("1M97-S86=E("!3=')I;F<@;W(@;V)J96-T(&-O;G1A
M:6YI;F<@=&AE(&UE<W-A9V4@=&\@;&]G+@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D<')I;W)I='D@5&AE('!R:6]R:71Y(&]F('1H92!M97-S86=E+B`@5F%L
M:60*("`@("`J("`@("`@("`@("`@("`@("`@=F%L=65S(&%R93H@4$5!4E],
M3T=?14U%4D<L(%!%05)?3$]'7T%,15)4+`H@("`@("H@("`@("`@("`@("`@
M("`@("!014%27TQ/1U]#4DE4+"!014%27TQ/1U]%4E(L(%!%05)?3$]'7U=!
M4DY)3D<L"B`@("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7TY/5$E#
M12P@4$5!4E],3T=?24Y&3RP@86YD(%!%05)?3$]'7T1%0E5'+@H@("`@("H@
M0')E='5R;B!B;V]L96%N("!4<G5E(&]N('-U8V-E<W,@;W(@9F%L<V4@;VX@
M9F%I;'5R92X*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&QO9R@D;65S<V%G92P@)'!R:6]R:71Y(#T@;G5L;"D*("`@('L*
M("`@("`@("`O*B!)9B!A('!R:6]R:71Y(&AA<VXG="!B965N('-P96-I9FEE
M9"P@=7-E('1H92!D969A=6QT('9A;'5E+B`J+PH@("`@("`@(&EF("@D<')I
M;W)I='D@/3T](&YU;&PI('L*("`@("`@("`@("`@)'!R:6]R:71Y(#T@)'1H
M:7,M/E]P<FEO<FET>3L*("`@("`@("!]"@H@("`@("`@("\J($%B;W)T(&5A
M<FQY(&EF('1H92!P<FEO<FET>2!I<R!A8F]V92!T:&4@;6%X:6UU;2!L;V=G
M:6YG(&QE=F5L+B`J+PH@("`@("`@(&EF("@A)'1H:7,M/E]I<TUA<VME9"@D
M<')I;W)I='DI*2!["B`@("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@
M("!]"@H@("`@("`@("\J($5X=')A8W0@=&AE('-T<FEN9R!R97!R97-E;G1A
M=&EO;B!O9B!T:&4@;65S<V%G92X@*B\*("`@("`@("`D;65S<V%G92`]("1T
M:&ES+3Y?97AT<F%C=$UE<W-A9V4H)&UE<W-A9V4I.PH*("`@("`@("!L:7-T
M*"1U<V5C+"`D<V5C*2`](&5X<&QO9&4H)R`G+"!M:6-R;W1I;64H*2D["@H@
M("`@("`@("\J($)U:6QD('1H92!O=71P=70@;&EN92!T:&%T(&-O;G1A:6YS
M('1H92!L;V<@96YT<GD@<F]W+B`J+PH@("`@("`@("1L:6YE("`]("<\='(^
M)SL*("`@("`@("`D;&EN92`N/2!S<')I;G1F*"<\=&0^)7,N)7,\+W1D/B<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("!S=')F=&EM92@G)50G+"`D<V5C
M*2P@<W5B<W1R*"1U<V5C+"`R+"`R*2D["B`@("`@("`@:68@*"%E;7!T>2@D
M=&AI<RT^7VED96YT*2D@>PH@("`@("`@("`@("`D;&EN92`N/2`G/'1D/B<@
M+B`D=&AI<RT^7VED96YT("X@)SPO=&0^)SL*("`@("`@("!]"B`@("`@("`@
M)&QI;F4@+CT@)SQT9#XG("X@=6-F:7)S="@D=&AI<RT^<')I;W)I='E4;U-T
M<FEN9R@D<')I;W)I='DI*2`N("<\+W1D/B<["B`@("`@("`@)&QI;F4@+CT@
M<W!R:6YT9B@G/'1D('-T>6QE/2)C;VQO<CH@)7,B/B5S/"]T9#XG+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C;VQO<G-;)'!R:6]R:71Y
M72P*("`@("`@("`@("`@("`@("`@("`@("`@('!R96=?<F5P;&%C92@G+UQR
M7&Y\7&Y\7'(O)RP@)SQB<B`O/B<L("1M97-S86=E*2D["B`@("`@("`@)&QI
M;F4@+CT@)SPO='(^)SL*"B`@("`@("`@)'1H:7,M/E]W<FET96QN*"1L:6YE
M*3L*"B`@("`@("`@)'1H:7,M/E]A;FYO=6YC92AA<G)A>2@G<')I;W)I='DG
M(#T^("1P<FEO<FET>2P@)VUE<W-A9V4G(#T^("1M97-S86=E*2D["@H@("`@
M("`@(')E='5R;B!T<G5E.PH@("`@?0H*?0H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+TQO9R]C;VYS;VQE+G!H<```
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(S,S,@
M,3`U,34T,S0Q,S,@,#(Q,S4W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\J*@H@*B`D2&5A9&5R.B`O<F5P;W-I
M=&]R>2]P96%R+TQO9R],;V<O8V]N<V]L92YP:'`L=B`Q+C(R(#(P,#8O,#$O
M,3$@,#<Z-38Z,S<@:F]N($5X<"`D"B`J"B`J($!V97)S:6]N("12979I<VEO
M;CH@,2XR,B`D"B`J($!P86-K86=E($QO9PH@*B\*"B\J*@H@*B!4:&4@3&]G
M7V-O;G-O;&4@8VQA<W,@:7,@82!C;VYC<F5T92!I;7!L96UE;G1A=&EO;B!O
M9B!T:&4@3&]G.CH*("H@86)S=')A8W0@8VQA<W,@=VAI8V@@=W)I=&5S(&UE
M<W-A9V4@=&\@=&AE('1E>'0@8V]N<V]L92X*("H@"B`J($!A=71H;W(@($IO
M;B!087)I<V4@/&IO;D!P:'`N;F5T/@H@*B!`<VEN8V4@("!,;V<@,2XQ"B`J
M($!P86-K86=E($QO9PH@*@H@*B!`97AA;7!L92!C;VYS;VQE+G!H<"`@("`@
M57-I;F<@=&AE(&-O;G-O;&4@:&%N9&QE<BX*("HO"F-L87-S($QO9U]C;VYS
M;VQE(&5X=&5N9',@3&]G"GL*("`@("\J*@H@("`@("H@2&%N9&QE('1O('1H
M92!C=7)R96YT(&]U='!U="!S=')E86TN"B`@("`@*B!`=F%R(')E<V]U<F-E
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?<W1R
M96%M(#T@4U1$3U54.PH*("`@("\J*@H@("`@("H@4VAO=6QD('1H92!O=71P
M=70@8F4@8G5F9F5R960@;W(@9&ES<&QA>65D(&EM;65D:6%T96QY/PH@("`@
M("H@0'9A<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)%]B=69F97)I;F<@/2!F86QS93L*"B`@("`O*BH*("`@("`J
M(%-T<FEN9R!H;VQD:6YG('1H92!B=69F97)E9"!O=71P=70N"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@
M('9A<B`D7V)U9F9E<B`]("<G.PH*("`@("\J*@H@("`@("H@4W1R:6YG(&-O
M;G1A:6YI;F<@=&AE(&9O<FUA="!O9B!A(&QO9R!L:6YE+@H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]L:6YE1F]R;6%T(#T@)R4Q)',@)3(D<R!;)3,D<UT@)30D<R<["@H@
M("`@+RHJ"B`@("`@*B!3=')I;F<@8V]N=&%I;FEN9R!T:&4@=&EM97-T86UP
M(&9O<FUA="X@($ET('=I;&P@8F4@<&%S<V5D(&1I<F5C=&QY('1O"B`@("`@
M*B!S=')F=&EM92@I+B`@3F]T92!T:&%T('1H92!T:6UE<W1A;7`@<W1R:6YG
M('=I;&P@9V5N97)A=&5D('5S:6YG('1H90H@("`@("H@8W5R<F5N="!L;V-A
M;&4N"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7W1I;65&;W)M870@/2`G)6(@)60@)4@Z)4TZ
M)5,G.PH*("`@("\J*@H@("`@("H@0V]N<W1R=6-T<R!A(&YE=R!,;V=?8V]N
M<V]L92!O8FIE8W0N"B`@("`@*B`*("`@("`J($!P87)A;2!S=')I;F<@)&YA
M;64@("`@($EG;F]R960N"B`@("`@*B!`<&%R86T@<W1R:6YG("1I9&5N="`@
M("!4:&4@:61E;G1I='D@<W1R:6YG+@H@("`@("H@0'!A<F%M(&%R<F%Y("`D
M8V]N9B`@("`@5&AE(&-O;F9I9W5R871I;VX@87)R87DN"B`@("`@*B!`<&%R
M86T@:6YT("`@("1L979E;"`@("!,;V<@;65S<V%G97,@=7`@=&\@86YD(&EN
M8VQU9&EN9R!T:&ES(&QE=F5L+@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@3&]G7V-O;G-O;&4H)&YA;64L("1I9&5N="`]
M("<G+"`D8V]N9B`](&%R<F%Y*"DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`D;&5V96P@/2!014%27TQ/1U]$14)51RD*("`@('L*("`@("`@("`D=&AI
M<RT^7VED(#T@;60U*&UI8W)O=&EM92@I*3L*("`@("`@("`D=&AI<RT^7VED
M96YT(#T@)&ED96YT.PH@("`@("`@("1T:&ES+3Y?;6%S:R`]($QO9SHZ55!4
M3R@D;&5V96PI.PH*("`@("`@("!I9B`H(65M<'1Y*"1C;VYF6R=S=')E86TG
M72DI('L*("`@("`@("`@("`@)'1H:7,M/E]S=')E86T@/2`D8V]N9ELG<W1R
M96%M)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&-O;F9;)V)U
M9F9E<FEN9R==*2D@>PH@("`@("`@("`@("`D=&AI<RT^7V)U9F9E<FEN9R`]
M("1C;VYF6R=B=69F97)I;F<G73L*("`@("`@("!]"@H@("`@("`@(&EF("@A
M96UP='DH)&-O;F9;)VQI;F5&;W)M870G72DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]L:6YE1F]R;6%T(#T@<W1R7W)E<&QA8V4H87)R87E?:V5Y<R@D=&AI
M<RT^7V9O<FUA=$UA<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y7W9A;'5E<R@D=&AI<RT^7V9O<FUA=$UA
M<"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1C;VYF6R=L:6YE1F]R;6%T)UTI.PH@("`@("`@('T*"B`@("`@("`@
M:68@*"%E;7!T>2@D8V]N9ELG=&EM949O<FUA="==*2D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W1I;65&;W)M870@/2`D8V]N9ELG=&EM949O<FUA="==.PH@
M("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!)9B!O=71P=70@8G5F
M9F5R:6YG(&AA<R!B965N(')E<75E<W1E9"P@=V4@;F5E9"!T;R!R96=I<W1E
M<B!A"B`@("`@("`@("H@<VAU=&1O=VX@9G5N8W1I;VX@=&AA="!W:6QL(&1U
M;7`@=&AE(&)U9F9E<B!U<&]N('1E<FUI;F%T:6]N+@H@("`@("`@("`J+PH@
M("`@("`@(&EF("@D=&AI<RT^7V)U9F9E<FEN9RD@>PH@("`@("`@("`@("!R
M96=I<W1E<E]S:'5T9&]W;E]F=6YC=&EO;BAA<G)A>2@F)'1H:7,L("=?3&]G
M7V-O;G-O;&4G*2D["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@
M1&5S=')U8W1O<@H@("`@("HO"B`@("!F=6YC=&EO;B!?3&]G7V-O;G-O;&4H
M*0H@("`@>PH@("`@("`@("1T:&ES+3YC;&]S92@I.PH@("`@?0H*("`@("\J
M*@H@("`@("H@0VQO<V5S('1H92!O=71P=70@<W1R96%M+@H@("`@("H*("`@
M("`J(%1H:7,@<F5S=6QT<R!I;B!A(&-A;&P@=&\@9FQU<V@H*2X*("`@("`J
M"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E($QO9R`Q+CDN
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!C;&]S92@I"B`@("!["B`@("`@("`@
M)'1H:7,M/F9L=7-H*"D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!&;'5S:&5S
M(&%L;"!P96YD:6YG("@B8G5F9F5R960B*2!D871A('1O('1H92!O=71P=70@
M<W1R96%M+@H@("`@("H*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`
M<VEN8V4@3&]G(#$N."XR"B`@("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H*"D*
M("`@('L*("`@("`@("`O*@H@("`@("`@("`J($EF(&]U='!U="!B=69F97)I
M;F<@:7,@96YA8FQE9"P@9'5M<"!T:&4@8V]N=&5N=',@;V8@=&AE(&)U9F9E
M<B!T;PH@("`@("`@("`J('1H92!O=71P=70@<W1R96%M+@H@("`@("`@("`J
M+PH@("`@("`@(&EF("@D=&AI<RT^7V)U9F9E<FEN9R`F)B`H<W1R;&5N*"1T
M:&ES+3Y?8G5F9F5R*2`^(#`I*2!["B`@("`@("`@("`@(&9W<FET92@D=&AI
M<RT^7W-T<F5A;2P@)'1H:7,M/E]B=69F97(I.PH@("`@("`@("`@("`D=&AI
M<RT^7V)U9F9E<B`]("<G.PH@("`@("`@('T*(`H@("`@("`@(')E='5R;B!F
M9FQU<V@H)'1H:7,M/E]S=')E86TI.PH@("`@?0H*("`@("\J*@H@("`@("H@
M5W)I=&5S("1M97-S86=E('1O('1H92!T97AT(&-O;G-O;&4N($%L<V\L('!A
M<W-E<R!T:&4@;65S<V%G90H@("`@("H@86QO;F<@=&\@86YY($QO9U]O8G-E
M<G9E<B!I;G-T86YC97,@=&AA="!A<F4@;V)S97)V:6YG('1H:7,@3&]G+@H@
M("`@("H@"B`@("`@*B!`<&%R86T@;6EX960@("1M97-S86=E("`@(%-T<FEN
M9R!O<B!O8FIE8W0@8V]N=&%I;FEN9R!T:&4@;65S<V%G92!T;R!L;V<N"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1P<FEO<FET>2!4:&4@<')I;W)I='D@;V8@
M=&AE(&UE<W-A9V4N("!686QI9`H@("`@("H@("`@("`@("`@("`@("`@("!V
M86QU97,@87)E.B!014%27TQ/1U]%34521RP@4$5!4E],3T=?04Q%4E0L"B`@
M("`@*B`@("`@("`@("`@("`@("`@(%!%05)?3$]'7T-2250L(%!%05)?3$]'
M7T524BP@4$5!4E],3T=?5T%23DE.1RP*("`@("`J("`@("`@("`@("`@("`@
M("`@4$5!4E],3T=?3D]424-%+"!014%27TQ/1U])3D9/+"!A;F0@4$5!4E],
M3T=?1$5"54<N"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@(%1R=64@;VX@<W5C
M8V5S<R!O<B!F86QS92!O;B!F86EL=7)E+@H@("`@("H@0&%C8V5S<R!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@;&]G*"1M97-S86=E+"`D<')I;W)I
M='D@/2!N=6QL*0H@("`@>PH@("`@("`@("\J($EF(&$@<')I;W)I='D@:&%S
M;B=T(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE(&1E9F%U;'0@=F%L=64N("HO
M"B`@("`@("`@:68@*"1P<FEO<FET>2`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("`D<')I;W)I='D@/2`D=&AI<RT^7W!R:6]R:71Y.PH@("`@("`@('T*"B`@
M("`@("`@+RH@06)O<G0@96%R;'D@:68@=&AE('!R:6]R:71Y(&ES(&%B;W9E
M('1H92!M87AI;75M(&QO9V=I;F<@;&5V96PN("HO"B`@("`@("`@:68@*"$D
M=&AI<RT^7VES36%S:V5D*"1P<FEO<FET>2DI('L*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@+RH@17AT<F%C="!T:&4@
M<W1R:6YG(')E<')E<V5N=&%T:6]N(&]F('1H92!M97-S86=E+B`J+PH@("`@
M("`@("1M97-S86=E(#T@)'1H:7,M/E]E>'1R86-T365S<V%G92@D;65S<V%G
M92D["@H@("`@("`@("\J($)U:6QD('1H92!S=')I;F<@8V]N=&%I;FEN9R!T
M:&4@8V]M<&QE=&4@;&]G(&QI;F4N("HO"B`@("`@("`@)&QI;F4@/2`D=&AI
M<RT^7V9O<FUA="@D=&AI<RT^7VQI;F5&;W)M870L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!S=')F=&EM92@D=&AI<RT^7W1I;65&;W)M870I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R:6]R:71Y+"`D
M;65S<V%G92D@+B`B7&XB.PH*("`@("`@("`O*@H@("`@("`@("`J($EF(&)U
M9F9E<FEN9R!I<R!E;F%B;&5D+"!A<'!E;F0@=&AI<R!L:6YE('1O('1H92!O
M=71P=70@8G5F9F5R+@H@("`@("`@("`J($]T:&5R=VES92P@<')I;G0@=&AE
M(&QI;F4@=&\@=&AE(&]U='!U="!S=')E86T@:6UM961I871E;'DN"B`@("`@
M("`@("HO"B`@("`@("`@:68@*"1T:&ES+3Y?8G5F9F5R:6YG*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?8G5F9F5R("X]("1L:6YE.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(&9W<FET92@D=&AI<RT^7W-T<F5A;2P@)&QI;F4I
M.PH@("`@("`@('T*"B`@("`@("`@+RH@3F]T:69Y(&]B<V5R=F5R<R!A8F]U
M="!T:&ES(&QO9R!M97-S86=E+B`J+PH@("`@("`@("1T:&ES+3Y?86YN;W5N
M8V4H87)R87DH)W!R:6]R:71Y)R`]/B`D<')I;W)I='DL("=M97-S86=E)R`]
M/B`D;65S<V%G92DI.PH*("`@("`@("!R971U<FX@=')U93L*("`@('T*"GT*
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+T1"+V-O;6UO;BYP:'``````````````````````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`R,#<U-C<@,3`U,34T,S0Q,S,@,#(P-S<P`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]
M-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($-O;G1A:6YS('1H92!$0E]C
M;VUM;VX@8F%S92!C;&%S<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@
M*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A
M:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL
M;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N
M='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE
M(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O
M=6=H('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E
M0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L
M>2X*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@
M1$(*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@
M*B!`875T:&]R("`@("!4;VUA<R!6+E8N($-O>"`\8V]X0&ED96-N970N8V]M
M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H
M<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P
M"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?
M,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)
M9#H@8V]M;6]N+G!H<"QV(#$N,3,W(#(P,#4O,#0O,#<@,30Z,C<Z,S4@9&%N
M:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O1$(*("HO"@HO*BH*("H@3V)T86EN('1H92!014%2(&-L87-S
M('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@
M)U!%05(N<&AP)SL*"B\J*@H@*B!$0E]C;VUM;VX@:7,@=&AE(&)A<V4@8VQA
M<W,@9G)O;2!W:&EC:"!E86-H(&1A=&%B87-E(&1R:79E<B!C;&%S<R!E>'1E
M;F1S"B`J"B`J($%L;"!C;VUM;VX@;65T:&]D<R!A<F4@9&5C;&%R960@:&5R
M92X@($EF(&$@9VEV96X@1$)-4R!D<FEV97(@8V]N=&%I;G,*("H@82!P87)T
M:6-U;&%R(&UE=&AO9"P@=&AA="!M971H;V0@=VEL;"!O=F5R;&]A9"!T:&4@
M;VYE(&AE<F4N"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K
M86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X*("H@0&%U=&AO<B`@("`@5&]M87,@5BY6+B!#;W@@/&-O>$!I9&5C
M;F5T+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N
M:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(
M4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC
M96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@
M4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]C;VUM;VX@97AT96YD<R!0
M14%2"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4
M:&4@8W5R<F5N="!D969A=6QT(&9E=&-H(&UO9&4*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("HO"B`@("!V87(@)&9E=&-H;6]D92`]($1"7T9%5$-(34]$
M15]/4D1%4D5$.PH*("`@("\J*@H@("`@("H@5&AE(&YA;64@;V8@=&AE(&-L
M87-S(&EN=&\@=VAI8V@@<F5S=6QT<R!S:&]U;&0@8F4@9F5T8VAE9"!W:&5N
M"B`@("`@*B!$0E]&151#2$U/1$5?3T)*14-4(&ES(&EN(&5F9F5C=`H@("`@
M("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9F5T8VAM
M;V1E7V]B:F5C=%]C;&%S<R`]("=S=&1#;&%S<R<["@H@("`@+RHJ"B`@("`@
M*B!787,@82!C;VYN96-T:6]N('!R97-E;G0@=VAE;B!T:&4@;V)J96-T('=A
M<R!S97)I86QI>F5D*"D_"B`@("`@*B!`=F%R(&)O;VP*("`@("`J($!S964@
M1$)?8V]M;6]N.CI?7W-L965P*"DL($1"7V-O;6UO;CHZ7U]W86ME*"D*("`@
M("`J+PH@("`@=F%R("1W87-?8V]N;F5C=&5D(#T@;G5L;#L*"B`@("`O*BH*
M("`@("`J(%1H92!M;W-T(')E8V5N=&QY(&5X96-U=&5D('%U97)Y"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&QA<W1?<75E<GD@/2`G
M)SL*"B`@("`O*BH*("`@("`J(%)U;BUT:6UE(&-O;F9I9W5R871I;VX@;W!T
M:6]N<PH@("`@("H*("`@("`J(%1H92`G;W!T:6UI>F4G(&]P=&EO;B!H87,@
M8F5E;B!D97!R96-A=&5D+B`@57-E('1H92`G<&]R=&%B:6QI='DG"B`@("`@
M*B!O<'1I;VX@:6YS=&5A9"X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@("`@
M=F%R("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@)W)E<W5L=%]B=69F97)I
M;F<G(#T^(#4P,"P*("`@("`@("`G<&5R<VES=&5N="<@/3X@9F%L<V4L"B`@
M("`@("`@)W-S;"<@/3X@9F%L<V4L"B`@("`@("`@)V1E8G5G)R`]/B`P+`H@
M("`@("`@("=S97%N86UE7V9O<FUA="<@/3X@)R5S7W-E<2<L"B`@("`@("`@
M)V%U=&]F<F5E)R`]/B!F86QS92P*("`@("`@("`G<&]R=&%B:6QI='DG(#T^
M($1"7U!/4E1!0DE,25197TY/3D4L"B`@("`@("`@)V]P=&EM:7IE)R`]/B`G
M<&5R9F]R;6%N8V4G+"`@+R\@1&5P<F5C871E9"X@(%5S92`G<&]R=&%B:6QI
M='DG+@H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!P87)A;65T97)S(&9R
M;VT@=&AE(&UO<W0@<F5C96YT;'D@97AE8W5T960@<75E<GD*("`@("`J($!V
M87(@87)R87D*("`@("`J($!S:6YC92!0<F]P97)T>2!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!V87(@)&QA<W1?<&%R86UE
M=&5R<R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@96QE;65N=',@
M9G)O;2!E86-H('!R97!A<F5D('-T871E;65N=`H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)'!R97!A<F5?=&]K96YS(#T@87)R87DH*3L*
M"B`@("`O*BH*("`@("`J(%1H92!D871A('1Y<&5S(&]F('1H92!V87)I;W5S
M(&5L96UE;G1S(&EN(&5A8V@@<')E<&%R960@<W1A=&5M96YT"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D<')E<&%R95]T>7!E<R`](&%R
M<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@<')E<&%R960@<75E<FEE<PH@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)'!R97!A<F5D7W%U
M97)I97,@/2!A<G)A>2@I.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!$0E]C
M;VUM;VX*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@
M/&MB9#XD=&AI<RT^4$5!4B@G1$)?17)R;W(G*3PO:V)D/@H@("`@("H*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]C;VUM
M;VXH*0H@("`@>PH@("`@("`@("1T:&ES+3Y014%2*"=$0E]%<G)O<B<I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]?<VQE97`H*0H*("`@("\J
M*@H@("`@("H@075T;VUA=&EC86QL>2!I;F1I8V%T97,@=VAI8V@@<')O<&5R
M=&EE<R!S:&]U;&0@8F4@<V%V960*("`@("`J('=H96X@4$A0)W,@<V5R:6%L
M:7IE*"D@9G5N8W1I;VX@:7,@8V%L;&5D"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@=&AE(&%R<F%Y(&]F('!R;W!E<G1I97,@;F%M97,@=&AA="!S
M:&]U;&0@8F4@<V%V960*("`@("`J+PH@("`@9G5N8W1I;VX@7U]S;&5E<"@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@
M("`@("`@("\O($1O;B=T(&1I<V-O;FYE8W0H*2P@<&5O<&QE('5S92!S97)I
M86QI>F4H*2!F;W(@;6%N>2!R96%S;VYS"B`@("`@("`@("`@("1T:&ES+3YW
M87-?8V]N;F5C=&5D(#T@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=&AI<RT^=V%S7V-O;FYE8W1E9"`](&9A;'-E.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)'1H:7,M/F%U=&]C;VUM:70I*2!["B`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@G875T;V-O;6UI="<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`G9&)S>6YT87@G+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@)V1S;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G9F5A='5R
M97,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V9E=&-H;6]D92<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`G9F5T8VAM;V1E7V]B:F5C=%]C;&%S
M<R<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G;W!T:6]N<R<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G=V%S7V-O;FYE8W1E9"<L"B`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B!A<G)A>2@G9&)S>6YT87@G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)V1S;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("`G9F5A='5R97,G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)V9E=&-H;6]D92<L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`G9F5T8VAM;V1E7V]B:F5C=%]C;&%S<R<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`G;W!T:6]N<R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`G=V%S7V-O;FYE8W1E9"<L"B`@("`@("`@("`@
M("`@("`@("`I.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!?7W=A:V5U<"@I"@H@("`@+RHJ"B`@("`@*B!!=71O;6%T:6-A;&QY
M(')E8V]N;F5C=',@=&\@=&AE(&1A=&%B87-E('=H96X@4$A0)W,@=6YS97)I
M86QI>F4H*0H@("`@("H@9G5N8W1I;VX@:7,@8V%L;&5D"B`@("`@*@H@("`@
M("H@5&AE(')E8V]N;F5C=&EO;B!A='1E;7!T(&ES(&]N;'D@<&5R9F]R;65D
M(&EF('1H92!O8FIE8W0@=V%S(&-O;FYE8W1E9`H@("`@("H@870@=&AE('1I
M;64@4$A0)W,@<V5R:6%L:7IE*"D@9G5N8W1I;VX@=V%S(')U;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@7U]W
M86ME=7`H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=V%S7V-O;FYE8W1E
M9"D@>PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C="@D=&AI<RT^9'-N+"`D
M=&AI<RT^;W!T:6]N<RD["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(%]?=&]3=')I;F<H*0H*("`@("\J*@H@("`@("H@075T;VUA
M=&EC('-T<FEN9R!C;VYV97)S:6]N(&9O<B!02%`@-0H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!A('-T<FEN9R!D97-C<FEB:6YG('1H92!C=7)R
M96YT(%!%05(@1$(@;V)J96-T"B`@("`@*@H@("`@("H@0'-I;F-E($UE=&AO
M9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F
M=6YC=&EO;B!?7W1O4W1R:6YG*"D*("`@('L*("`@("`@("`D:6YF;R`]('-T
M<G1O;&]W97(H9V5T7V-L87-S*"1T:&ES*2D["B`@("`@("`@)&EN9F\@+CT@
M("<Z("AP:'!T>7!E/2<@+B`D=&AI<RT^<&AP='EP92`N"B`@("`@("`@("`@
M("`@("`@("<L(&1B<WEN=&%X/2<@+B`D=&AI<RT^9&)S>6YT87@@+@H@("`@
M("`@("`@("`@("`@("`G*2<["B`@("`@("`@:68@*"1T:&ES+3YC;VYN96-T
M:6]N*2!["B`@("`@("`@("`@("1I;F9O("X]("<@6V-O;FYE8W1E9%TG.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&EN9F\["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@=&]3=')I;F<H*0H*("`@("\J*@H@("`@("H@1$50
M4D5#051%1#H@(%-T<FEN9R!C;VYV97)S:6]N(&UE=&AO9`H@("`@("H*("`@
M("`J($!R971U<FX@<W1R:6YG("!A('-T<FEN9R!D97-C<FEB:6YG('1H92!C
M=7)R96YT(%!%05(@1$(@;V)J96-T"B`@("`@*@H@("`@("H@0&1E<')E8V%T
M960@365T:&]D(&1E<')E8V%T960@:6X@4F5L96%S92`Q+C<N,`H@("`@("HO
M"B`@("!F=6YC=&EO;B!T;U-T<FEN9R@I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3Y?7W1O4W1R:6YG*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<75O=&53=')I;F<H*0H*("`@("\J*@H@("`@("H@1$504D5#051%
M1#H@475O=&5S(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!W
M:71H:6X@<W1R:6YG"B`@("`@*B!D96QI;6ET97)S(&EN(&$@<75E<GD*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S=')I;F<@('1H92!S=')I;F<@
M=&\@8F4@<75O=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H
M92!Q=6]T960@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.G%U;W1E4VUA<G0H*2P@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@("`@
M("H@0&1E<')E8V%T960@365T:&]D(&1E<')E8V%T960@<V]M92!T:6UE(&)E
M9F]R92!296QE87-E(#$N,@H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T95-T
M<FEN9R@D<W1R:6YG*0H@("`@>PH@("`@("`@("1S=')I;F<@/2`D=&AI<RT^
M<75O=&4H)'-T<FEN9RD["B`@("`@("`@:68@*"1S=')I;F=[,'T@/3T@(B<B
M*2!["B`@("`@("`@("`@(')E='5R;B!S=6)S='(H)'-T<FEN9RP@,2P@+3$I
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'-T<FEN9SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!Q=6]T92@I"@H@("`@+RHJ"B`@("`@*B!$
M15!214-!5$5$.B!1=6]T97,@82!S=')I;F<@<V\@:70@8V%N(&)E('-A9F5L
M>2!U<V5D(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1S=')I;F<@('1H92!S=')I;F<@=&\@<75O=&4*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE('%U;W1E9"!S=')I;F<@;W(@=&AE('-T<FEN
M9R`\<V%M<#Y.54Q,/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`@("!I
M9B!T:&4@=F%L=64@<W5B;6ET=&5D(&ES(#QK8F0^;G5L;#PO:V)D/BX*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I+"!$0E]C
M;VUM;VXZ.F5S8V%P95-I;7!L92@I"B`@("`@*B!`9&5P<F5C871E9"!$97!R
M96-A=&5D(&EN(')E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I;VX@
M<75O=&4H)'-T<FEN9R`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N("@D
M<W1R:6YG(#T]/2!N=6QL*2`_("=.54Q,)PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@.B`B)R(@+B!S=')?<F5P;&%C92@B)R(L("(G)R(L
M("1S=')I;F<I("X@(B<B.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('%U;W1E261E;G1I9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@82!S
M=')I;F<@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D(&%S(&$@=&%B;&4@;W(@
M8V]L=6UN(&YA;64*("`@("`J"B`@("`@*B!$96QI;6ET:6YG('-T>6QE(&1E
M<&5N9',@;VX@=VAI8V@@9&%T86)A<V4@9')I=F5R(&ES(&)E:6YG('5S960N
M"B`@("`@*@H@("`@("H@3D]413H@:G5S="!B96-A=7-E('EO=2!#04X@=7-E
M(&1E;&EM:71E9"!I9&5N=&EF:65R<R!D;V5S;B=T(&UE86X*("`@("`J('EO
M=2!32$]53$0@=7-E('1H96TN("!);B!G96YE<F%L+"!T:&5Y(&5N9"!U<"!C
M875S:6YG('=A>2!M;W)E"B`@("`@*B!P<F]B;&5M<R!T:&%N('1H97D@<V]L
M=F4N"B`@("`@*@H@("`@("H@4&]R=&%B:6QI='D@:7,@8G)O:V5N(&)Y('5S
M:6YG('1H92!F;VQL;W=I;F<@8VAA<F%C=&5R<R!I;G-I9&4*("`@("`J(&1E
M;&EM:71E9"!I9&5N=&EF:65R<SH*("`@("`J("`@*R!B86-K=&EC:R`H/&MB
M9#Y@/"]K8F0^*2`M+2!D=64@=&\@37E344P*("`@("`J("`@*R!D;W5B;&4@
M<75O=&4@*#QK8F0^(CPO:V)D/BD@+2T@9'5E('1O($]R86-L90H@("`@("H@
M("`K(&)R86-K971S("@\:V)D/EL\+VMB9#X@;W(@/&MB9#Y=/"]K8F0^*2`M
M+2!D=64@=&\@06-C97-S"B`@("`@*@H@("`@("H@1&5L:6UI=&5D(&ED96YT
M:69I97)S(&%R92!K;F]W;B!T;R!G96YE<F%L;'D@=V]R:R!C;W)R96-T;'D@
M=6YD97(*("`@("`J('1H92!F;VQL;W=I;F<@9')I=F5R<SH*("`@("`J("`@
M*R!M<W-Q;`H@("`@("H@("`K(&UY<W%L"B`@("`@*B`@("L@;7ES<6QI"B`@
M("`@*B`@("L@;V-I.`H@("`@("H@("`K(&]D8F,H86-C97-S*0H@("`@("H@
M("`K(&]D8F,H9&(R*0H@("`@("H@("`K('!G<W%L"B`@("`@*B`@("L@<W%L
M:71E"B`@("`@*B`@("L@<WEB87-E("AM=7-T(&5X96-U=&4@/&MB9#YS970@
M<75O=&5D7VED96YT:69I97(@;VX\+VMB9#X@<V]M971I;64*("`@("`J("`@
M("!P<FEO<B!T;R!U<V4I"B`@("`@*@H@("`@("H@26YT97)"87-E(&1O97-N
M)W0@<V5E;2!T;R!B92!A8FQE('1O('5S92!D96QI;6ET960@:61E;G1I9FEE
M<G,*("`@("`J('9I82!02%`@-"X@(%1H97D@=V]R:R!F:6YE('5N9&5R(%!(
M4"`U+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@=&AE(&ED
M96YT:69I97(@;F%M92!T;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE('%U;W1E9"!I9&5N=&EF:65R"B`@("`@*@H@("`@
M("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED96YT:69I97(H)'-T<BD*
M("`@('L*("`@("`@("!R971U<FX@)R(G("X@<W1R7W)E<&QA8V4H)R(G+"`G
M(B(G+"`D<W1R*2`N("<B)SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!Q=6]T95-M87)T*"D*"B`@("`O*BH*("`@("`J($9O<FUA=',@:6YP=70@
M<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D(&EN(&$@<75E<GD*("`@("`J"B`@
M("`@*B!4:&4@;W5T<'5T(&1E<&5N9',@;VX@=&AE(%!(4"!D871A('1Y<&4@
M;V8@:6YP=70@86YD('1H92!D871A8F%S90H@("`@("H@='EP92!B96EN9R!U
M<V5D+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`D:6X@('1H92!D871A
M('1O(&)E(&9O<FUA='1E9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M('1H92!F;W)M871T960@9&%T82X@(%1H92!F;W)M870@9&5P96YD<R!O;B!T
M:&4@:6YP=70G<PH@("`@("H@("`@("`@("`@("`@("`@(%!(4"!T>7!E.@H@
M("`@("H@/'5L/@H@("`@("H@(#QL:3X*("`@("`J("`@(#QK8F0^:6YP=70\
M+VMB9#X@+3X@/'-A;7`^<F5T=7)N<SPO<V%M<#X*("`@("`J("`\+VQI/@H@
M("`@("H@(#QL:3X*("`@("`J("`@(#QK8F0^;G5L;#PO:V)D/B`M/B!T:&4@
M<W1R:6YG(#QS86UP/DY53$P\+W-A;7`^"B`@("`@*B`@/"]L:3X*("`@("`J
M("`\;&D^"B`@("`@*B`@("`\:V)D/FEN=&5G97(\+VMB9#X@;W(@/&MB9#YD
M;W5B;&4\+VMB9#X@+3X@=&AE('5N<75O=&5D(&YU;6)E<@H@("`@("H@(#PO
M;&D^"B`@("`@*B`@/&QI/@H@("`@("H@("`@/&MB9#YB;V]L/"]K8F0^("T^
M(&]U='!U="!D97!E;F1S(&]N('1H92!D<FEV97(@:6X@=7-E"B`@("`@*B`@
M("!-;W-T(&1R:79E<G,@<F5T=7)N(&EN=&5G97)S.B`\<V%M<#XQ/"]S86UP
M/B!I9@H@("`@("H@("`@/&MB9#YT<G5E/"]K8F0^(&]R(#QS86UP/C`\+W-A
M;7`^(&EF"B`@("`@*B`@("`\:V)D/F9A;'-E/"]K8F0^+@H@("`@("H@("`@
M4V]M92!R971U<FX@<W1R:6YG<SH@/'-A;7`^5%)513PO<V%M<#X@:68*("`@
M("`J("`@(#QK8F0^=')U93PO:V)D/B!O<B`\<V%M<#Y&04Q313PO<V%M<#X@
M:68*("`@("`J("`@(#QK8F0^9F%L<V4\+VMB9#XN"B`@("`@*B`@("!&:6YA
M;&QY(&]N92!R971U<FYS('-T<FEN9W,Z(#QS86UP/E0\+W-A;7`^(&EF"B`@
M("`@*B`@("`\:V)D/G1R=64\+VMB9#X@;W(@/'-A;7`^1CPO<V%M<#X@:68*
M("`@("`J("`@(#QK8F0^9F%L<V4\+VMB9#XN($AE<F4@:7,@82!L:7-T(&]F
M(&5A8V@@1$)-4RP*("`@("`J("`@('1H92!V86QU97,@<F5T=7)N960@86YD
M('1H92!S=6=G97-T960@8V]L=6UN('1Y<&4Z"B`@("`@*B`@("`\=6P^"B`@
M("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/F1B87-E/"]K8F0^
M("T^(#QS86UP/E0O1CPO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y,;V=I
M8V%L/"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^
M"B`@("`@*B`@("`@("`@/&MB9#YF8F%S93PO:V)D/B`M/B`\<V%M<#Y44E5%
M+T9!3%-%/"]S86UP/@H@("`@("H@("`@("`@("@\:V)D/D)/3TQ%04X\+VMB
M9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J
M("`@("`@("`\:V)D/FEB87-E/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*
M("`@("`J("`@("`@("`H/&MB9#Y334%,3$E.5#PO:V)D/BD@6S%="B`@("`@
M*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\
M:V)D/FEF>#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@
M("`@*#QK8F0^4TU!3$Q)3E0\+VMB9#XI(%LQ70H@("`@("H@("`@("`\+VQI
M/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YM<W%L/"]K
M8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y)
M3E1%1T52/"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@("`@("`\
M;&D^"B`@("`@*B`@("`@("`@/&MB9#YM<W-Q;#PO:V)D/B`M/B`\<V%M<#XQ
M+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^0DE4/"]K8F0^*0H@("`@
M("H@("`@("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@
M/&MB9#YM>7-Q;#PO:V)D/B`M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@
M("`@("`@*#QK8F0^5$E.64E.5"@Q*3PO:V)D/BD*("`@("`J("`@("`@/"]L
M:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@(#QK8F0^;7ES<6QI
M/"]K8F0^("T^(#QS86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB
M9#Y424Y924Y4*#$I/"]K8F0^*0H@("`@("H@("`@("`\+VQI/@H@("`@("H@
M("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YO8VDX/"]K8F0^("T^(#QS
M86UP/C$O,#PO<V%M<#X*("`@("`J("`@("`@("`H/&MB9#Y.54U"15(H,2D\
M+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@*B`@("`@(#QL:3X*("`@
M("`J("`@("`@("`\:V)D/F]D8F,\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP
M/@H@("`@("H@("`@("`@("@\:V)D/E--04Q,24Y4/"]K8F0^*2!;,5T*("`@
M("`J("`@("`@/"]L:3X*("`@("`J("`@("`@/&QI/@H@("`@("H@("`@("`@
M(#QK8F0^<&=S<6P\+VMB9#X@+3X@/'-A;7`^5%)512]&04Q313PO<V%M<#X*
M("`@("`J("`@("`@("`H/&MB9#Y"3T],14%./"]K8F0^*0H@("`@("H@("`@
M("`\+VQI/@H@("`@("H@("`@("`\;&D^"B`@("`@*B`@("`@("`@/&MB9#YS
M<6QI=&4\+VMB9#X@+3X@/'-A;7`^,2\P/"]S86UP/@H@("`@("H@("`@("`@
M("@\:V)D/DE.5$5'15(\+VMB9#XI"B`@("`@*B`@("`@(#PO;&D^"B`@("`@
M*B`@("`@(#QL:3X*("`@("`J("`@("`@("`\:V)D/G-Y8F%S93PO:V)D/B`M
M/B`\<V%M<#XQ+S`\+W-A;7`^"B`@("`@*B`@("`@("`@*#QK8F0^5$E.64E.
M5"@Q*3PO:V)D/BD*("`@("`J("`@("`@/"]L:3X*("`@("`J("`@(#PO=6P^
M"B`@("`@*B`@("!;,5T@06-C;VUM;V1A=&4@=&AE(&QO=V5S="!C;VUM;VX@
M9&5N;VUI;F%T;W(@8F5C875S92!N;W0@86QL"B`@("`@*B`@("!V97)S:6]N
M<R!O9B!H879E(#QK8F0^0D]/3$5!3CPO:V)D/BX*("`@("`J("`\+VQI/@H@
M("`@("H@(#QL:3X*("`@("`J("`@(&]T:&5R("AI;F-L=61I;F<@<W1R:6YG
M<R!A;F0@;G5M97)I8R!S=')I;F=S*2`M/@H@("`@("H@("`@=&AE(&1A=&$@
M=VET:"!S:6YG;&4@<75O=&5S(&5S8V%P960@8GD@<')E8V5E9&EN9PH@("`@
M("H@("`@<VEN9VQE('%U;W1E<RP@8F%C:W-L87-H97,@87)E(&5S8V%P960@
M8GD@<')E8V5E9&EN9PH@("`@("H@("`@8F%C:W-L87-H97,L('1H96X@=&AE
M('=H;VQE('-T<FEN9R!I<R!E;F-A<'-U;&%T960*("`@("`J("`@(&)E='=E
M96X@<VEN9VQE('%U;W1E<PH@("`@("H@(#PO;&D^"B`@("`@*B`\+W5L/@H@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIE<V-A<&53:6UP;&4H*0H@
M("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q
M+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T95-M87)T*"1I;BD*("`@
M('L*("`@("`@("!I9B`H:7-?:6YT*"1I;BD@?'P@:7-?9&]U8FQE*"1I;BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1I;CL*("`@("`@("!](&5L<V5I9B`H
M:7-?8F]O;"@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D:6X@/R`Q(#H@
M,#L*("`@("`@("!](&5L<V5I9B`H:7-?;G5L;"@D:6XI*2!["B`@("`@("`@
M("`@(')E='5R;B`G3E5,3"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@<F5T=7)N("(G(B`N("1T:&ES+3YE<V-A<&53:6UP;&4H)&EN*2`N("(G
M(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97-C
M87!E4VEM<&QE*"D*"B`@("`O*BH*("`@("`J($5S8V%P97,@82!S=')I;F<@
M86-C;W)D:6YG('1O('1H92!C=7)R96YT($1"35,G<R!S=&%N9&%R9',*("`@
M("`J"B`@("`@*B!);B!344QI=&4L('1H:7,@;6%K97,@=&AI;F=S('-A9F4@
M9F]R(&EN<V5R=',O=7!D871E<RP@8G5T(&UA>0H@("`@("H@8V%U<V4@<')O
M8FQE;7,@=VAE;B!P97)F;W)M:6YG('1E>'0@8V]M<&%R:7-O;G,@86=A:6YS
M="!C;VQU;6YS"B`@("`@*B!C;VYT86EN:6YG(&)I;F%R>2!D871A+B!3964@
M=&AE"B`@("`@*B![0&QI;FL@:'1T<#HO+W!H<"YN970O<W%L:71E7V5S8V%P
M95]S=')I;F<@4$A0(&UA;G5A;'T@9F]R(&UO<F4@:6YF;RX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1S='(@('1H92!S=')I;F<@=&\@8F4@97-C
M87!E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@97-C87!E
M9"!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53
M;6%R="@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!2
M96QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5S8V%P95-I;7!L
M92@D<W1R*0H@("`@>PH@("`@("`@(')E='5R;B!S=')?<F5P;&%C92@B)R(L
M("(G)R(L("1S='(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('!R
M;W9I9&5S*"D*"B`@("`O*BH*("`@("`J(%1E;&QS('=H971H97(@=&AE('!R
M97-E;G0@9')I=F5R('-U<'!O<G1S(&$@9VEV96X@9F5A='5R90H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)&9E871U<F4@('1H92!F96%T=7)E('EO
M=2=R92!C=7)I;W5S(&%B;W5T"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L
M("!W:&5T:&5R('1H:7,@9')I=F5R('-U<'!O<G1S("1F96%T=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N('!R;W9I9&5S*"1F96%T=7)E*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^9F5A='5R97-;)&9E871U<F5=.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('-E=$9E=&-H36]D92@I"@H@("`@+RHJ
M"B`@("`@*B!3971S('1H92!F971C:"!M;V1E('1H870@<VAO=6QD(&)E('5S
M960@8GD@9&5F875L="!F;W(@<75E<GD@<F5S=6QT<PH@("`@("H*("`@("`J
M($!P87)A;2!I;G1E9V5R("1F971C:&UO9&4@("`@1$)?1D540TA-3T1%7T]2
M1$52140L($1"7T9%5$-(34]$15]!4U-/0PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;W(@1$)?1D540TA-3T1%7T]"2D5#5`H@("`@
M("H@0'!A<F%M('-T<FEN9R`D;V)J96-T7V-L87-S("!T:&4@8VQA<W,@;F%M
M92!O9B!T:&4@;V)J96-T('1O(&)E(')E='5R;F5D"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B>2!T:&4@9F5T8V@@;65T:&]D<R!W
M:&5N('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1$)?1D540TA-3T1%7T]"2D5#5"!M;V1E(&ES('-E;&5C=&5D+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@268@;F\@8VQA<W,@:7,@
M<W!E8VEF:65D(&)Y(&1E9F%U;'0@82!C87-T"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!T;R!O8FIE8W0@9G)O;2!T:&4@87-S;V,@
M87)R87D@<F]W('=I;&P@8F4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&1O;F4N("!4:&5R92!I<R!A;'-O('1H92!P;W-I8FEL:71Y
M('1O('5S90H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M86YD(&5X=&5N9"!T:&4@)T1"7W)O=R<@8VQA<W,N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]&151#2$U/1$5?3U)$15)%1"P@1$)?1D540TA-3T1%7T%34T]#
M+"!$0E]&151#2$U/1$5?3T)*14-4"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$9E=&-H36]D92@D9F5T8VAM;V1E+"`D;V)J96-T7V-L87-S(#T@)W-T9$-L
M87-S)RD*("`@('L*("`@("`@("!S=VET8V@@*"1F971C:&UO9&4I('L*("`@
M("`@("`@("`@8V%S92!$0E]&151#2$U/1$5?3T)*14-4.@H@("`@("`@("`@
M("`@("`@)'1H:7,M/F9E=&-H;6]D95]O8FIE8W1?8VQA<W,@/2`D;V)J96-T
M7V-L87-S.PH@("`@("`@("`@("!C87-E($1"7T9%5$-(34]$15]/4D1%4D5$
M.@H@("`@("`@("`@("!C87-E($1"7T9%5$-(34]$15]!4U-/0SH*("`@("`@
M("`@("`@("`@("1T:&ES+3YF971C:&UO9&4@/2`D9F5T8VAM;V1E.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VEN=F%L:60@
M9F5T8VAM;V1E(&UO9&4G*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@<V5T3W!T:6]N*"D*"B`@("`O*BH*("`@("`J(%-E=',@
M<G5N+71I;64@8V]N9FEG=7)A=&EO;B!O<'1I;VYS(&9O<B!014%2($1""B`@
M("`@*@H@("`@("H@3W!T:6]N<RP@=&AE:7(@9&%T82!T>7!E<RP@9&5F875L
M="!V86QU97,@86YD(&1E<V-R:7!T:6]N.@H@("`@("H@/'5L/@H@("`@("H@
M/&QI/@H@("`@("H@/'9A<CYA=71O9G)E93PO=F%R/B`\:V)D/F)O;VQE86X\
M+VMB9#X@/2`\<V%M<#YF86QS93PO<V%M<#X*("`@("`J("`@("`@/&)R("\^
M<VAO=6QD(')E<W5L=',@8F4@9G)E960@875T;VUA=&EC86QL>2!W:&5N('1H
M97)E(&%R92!N;PH@("`@("H@("`@("`@("`@("!M;W)E(')O=W,_"B`@("`@
M*B`\+VQI/CQL:3X*("`@("`J(#QV87(^<F5S=6QT7V)U9F9E<FEN9SPO=F%R
M/B`\:V)D/FEN=&5G97(\+VMB9#X@/2`\<V%M<#XU,#`\+W-A;7`^"B`@("`@
M*B`@("`@(#QB<B`O/FAO=R!M86YY(')O=W,@;V8@=&AE(')E<W5L="!S970@
M<VAO=6QD(&)E(&)U9F9E<F5D/PH@("`@("H@("`@("`\8G(@+SY);B!M>7-Q
M;#H@;7ES<6Q?=6YB=69F97)E9%]Q=65R>2@I(&ES('5S960@:6YS=&5A9"!O
M9@H@("`@("H@("`@("`@("`@("!M>7-Q;%]Q=65R>2@I(&EF('1H:7,@=F%L
M=64@:7,@,"X@("A296QE87-E(#$N-RXP*0H@("`@("H@("`@("`\8G(@+SY)
M;B!O8VDX.B!T:&ES('9A;'5E(&ES('!A<W-E9"!T;R!O8VES971P<F5F971C
M:"@I+@H@("`@("H@("`@("`@("`@("`H4F5L96%S92`Q+C<N,"D*("`@("`J
M(#PO;&D^/&QI/@H@("`@("H@/'9A<CYD96)U9SPO=F%R/B`\:V)D/FEN=&5G
M97(\+VMB9#X@/2`\<V%M<#XP/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYD
M96)U9R!L979E;`H@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R/G!E<G-I
M<W1E;G0\+W9A<CX@/&MB9#YB;V]L96%N/"]K8F0^(#T@/'-A;7`^9F%L<V4\
M+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O/G-H;W5L9"!T:&4@8V]N;F5C=&EO
M;B!B92!P97)S:7-T96YT/PH@("`@("H@/"]L:3X\;&D^"B`@("`@*B`\=F%R
M/G!O<G1A8FEL:71Y/"]V87(^(#QK8F0^:6YT96=E<CPO:V)D/B`](#QS86UP
M/D1"7U!/4E1!0DE,25197TY/3D4\+W-A;7`^"B`@("`@*B`@("`@(#QB<B`O
M/G!O<G1A8FEL:71Y(&UO9&4@8V]N<W1A;G0@*'-E92!B96QO=RD*("`@("`J
M(#PO;&D^/&QI/@H@("`@("H@/'9A<CYS97%N86UE7V9O<FUA=#PO=F%R/B`\
M:V)D/G-T<FEN9SPO:V)D/B`](#QS86UP/B5S7W-E<3PO<V%M<#X*("`@("`J
M("`@("`@/&)R("\^=&AE('-P<FEN=&8H*2!F;W)M870@<W1R:6YG('5S960@
M;VX@<V5Q=65N8V4@;F%M97,N("!4:&ES"B`@("`@*B`@("`@("`@("`@(&9O
M<FUA="!I<R!A<'!L:65D('1O('-E<75E;F-E(&YA;65S('!A<W-E9"!T;PH@
M("`@("H@("`@("`@("`@("!C<F5A=&5397%U96YC92@I+"!N97AT240H*2!A
M;F0@9')O<%-E<75E;F-E*"DN"B`@("`@*B`\+VQI/CQL:3X*("`@("`J(#QV
M87(^<W-L/"]V87(^(#QK8F0^8F]O;&5A;CPO:V)D/B`](#QS86UP/F9A;'-E
M/"]S86UP/@H@("`@("H@("`@("`\8G(@+SYU<V4@<W-L('1O(&-O;FYE8W0_
M"B`@("`@*B`\+VQI/@H@("`@("H@/"]U;#X*("`@("`J"B`@("`@*B`M+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H@("`@("H*
M("`@("`J(%!/4E1!0DE,2519($U/1$53"B`@("`@*@H@("`@("H@5&AE<V4@
M;6]D97,@87)E(&)I='=I<V5D+"!S;R!T:&5Y(&-A;B!B92!C;VUB:6YE9"!U
M<VEN9R`\:V)D/GP\+VMB9#X*("`@("`J(&%N9"!R96UO=F5D('5S:6YG(#QK
M8F0^7CPO:V)D/BX@(%-E92!T:&4@97AA;7!L97,@<V5C=&EO;B!B96QO=R!O
M;B!H;W<*("`@("`J('1O(&1O('1H:7,N"B`@("`@*@H@("`@("H@/'-A;7`^
M1$)?4$]25$%"24Q)5%E?3D].13PO<V%M<#X*("`@("`J('1U<FX@;V9F(&%L
M;"!P;W)T86)I;&ET>2!F96%T=7)E<PH@("`@("H*("`@("`J(%1H:7,@;6]D
M92!G971S(&%U=&]M871I8V%L;'D@='5R;F5D(&]N(&EF('1H92!D97!R96-A
M=&5D"B`@("`@*B`\=F%R/F]P=&EM:7IE/"]V87(^(&]P=&EO;B!G971S('-E
M="!T;R`\<V%M<#YP97)F;W)M86YC93PO<V%M<#XN"B`@("`@*@H@("`@("H*
M("`@("`J(#QS86UP/D1"7U!/4E1!0DE,25197TQ/5T520T%313PO<V%M<#X*
M("`@("`J(&-O;G9E<G0@;F%M97,@;V8@=&%B;&5S(&%N9"!F:65L9',@=&\@
M;&]W97(@8V%S92!W:&5N('5S:6YG"B`@("`@*B`\:V)D/F=E="HH*3PO:V)D
M/BP@/&MB9#YF971C:"HH*3PO:V)D/B!A;F0@/&MB9#YT86)L94EN9F\H*3PO
M:V)D/@H@("`@("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M871I8V%L
M;'D@='5R;F5D(&]N(&EN('1H92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@("`@
M*B!I9B!T:&4@9&5P<F5C871E9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO=F%R
M/B!G971S('-E="!T;PH@("`@("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A;7`^
M.@H@("`@("H@*R!O8VDX"B`@("`@*@H@("`@("H*("`@("`J(#QS86UP/D1"
M7U!/4E1!0DE,25197U)44DE-/"]S86UP/@H@("`@("H@<FEG:'0@=')I;2!T
M:&4@9&%T82!O=71P=70@8GD@/&MB9#YG970J*"D\+VMB9#X@/&MB9#YF971C
M:"HH*3PO:V)D/@H@("`@("H*("`@("`J"B`@("`@*B`\<V%M<#Y$0E]03U)4
M04))3$E465]$14Q%5$5?0T]53E0\+W-A;7`^"B`@("`@*B!F;W)C92!R97!O
M<G1I;F<@=&AE(&YU;6)E<B!O9B!R;W=S(&1E;&5T960*("`@("`J"B`@("`@
M*B!3;VUE($1"35,G<R!D;VXG="!C;W5N="!T:&4@;G5M8F5R(&]F(')O=W,@
M9&5L971E9"!W:&5N('!E<F9O<FUI;F<*("`@("`J('-I;7!L92`\:V)D/D1%
M3$5412!&4D]-('1A8FQE;F%M93PO:V)D/B!Q=65R:65S+B`@5&AI<R!P;W)T
M86)I;&ET>0H@("`@("H@;6]D92!T<FEC:W,@<W5C:"!$0DU3)W,@:6YT;R!T
M96QL:6YG('1H92!C;W5N="!B>2!A9&1I;F<*("`@("`J(#QS86UP/E=(15)%
M(#$],3PO<V%M<#X@=&\@=&AE(&5N9"!O9B`\:V)D/D1%3$5413PO:V)D/B!Q
M=65R:65S+@H@("`@("H*("`@("`J(%1H:7,@;6]D92!G971S(&%U=&]M871I
M8V%L;'D@='5R;F5D(&]N(&EN('1H92!F;VQL;W=I;F<@9&%T86)A<V5S"B`@
M("`@*B!I9B!T:&4@9&5P<F5C871E9"!O<'1I;VX@/'9A<CYO<'1I;6EZ93PO
M=F%R/B!G971S('-E="!T;PH@("`@("H@/'-A;7`^<&]R=&%B:6QI='D\+W-A
M;7`^.@H@("`@("H@*R!F8G-Q;`H@("`@("H@*R!M>7-Q;`H@("`@("H@*R!M
M>7-Q;&D*("`@("`J("L@<W%L:71E"B`@("`@*@H@("`@("H*("`@("`J(#QS
M86UP/D1"7U!/4E1!0DE,25197TY535)/5U,\+W-A;7`^"B`@("`@*B!E;F%B
M;&4@:&%C:R!T:&%T(&UA:V5S(#QK8F0^;G5M4F]W<R@I/"]K8F0^('=O<FL@
M:6X@3W)A8VQE"B`@("`@*@H@("`@("H@5&AI<R!M;V1E(&=E=',@875T;VUA
M=&EC86QL>2!T=7)N960@;VX@:6X@=&AE(&9O;&QO=VEN9R!D871A8F%S97,*
M("`@("`J(&EF('1H92!D97!R96-A=&5D(&]P=&EO;B`\=F%R/F]P=&EM:7IE
M/"]V87(^(&=E=',@<V5T('1O"B`@("`@*B`\<V%M<#YP;W)T86)I;&ET>3PO
M<V%M<#XZ"B`@("`@*B`K(&]C:3@*("`@("`J"B`@("`@*@H@("`@("H@/'-A
M;7`^1$)?4$]25$%"24Q)5%E?15)23U)3/"]S86UP/@H@("`@("H@;6%K97,@
M8V5R=&%I;B!E<G)O<B!M97-S86=E<R!I;B!C97)T86EN(&1R:79E<G,@8V]M
M<&%T:6)L90H@("`@("H@=VET:"!T:&]S92!F<F]M(&]T:&5R($1"35,G<PH@
M("`@("H*("`@("`J("L@;7ES<6PL(&UY<W%L:3H@(&-H86YG92!U;FEQ=64O
M<')I;6%R>2!K97D@8V]N<W1R86EN=',*("`@("`J("`@1$)?15)23U)?04Q2
M14%$65]%6$E35%,@+3X@1$)?15)23U)?0T].4U1204E.5`H@("`@("H*("`@
M("`J("L@;V1B8RAA8V-E<W,I.B`@35,G<R!/1$)#(&1R:79E<B!R97!O<G1S
M("=N;R!S=6-H(&9I96QD)R!A<R!C;V1E"B`@("`@*B`@(#`W,#`Q+"!W:&EC
M:"!M96%N<R`G=&]O(&9E=R!P87)A;65T97)S+B<@(%=H96X@=&AI<R!O<'1I
M;VX@:7,@;VX*("`@("`J("`@=&AA="!C;V1E(&=E=',@;6%P<&5D('1O($1"
M7T524D]27TY/4U5#2$9)14Q$+@H@("`@("H@("!$0E]%4E)/4E]-25--051#
M2"`M/B!$0E]%4E)/4E].3U-50TA&245,1`H@("`@("H*("`@("`J(#QS86UP
M/D1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%D\+W-A;7`^"B`@("`@*B!C
M;VYV97)T(&YU;&P@=F%L=65S('1O(&5M<'1Y('-T<FEN9W,@:6X@9&%T82!O
M=71P=70@8GD@9V5T*B@I(&%N9`H@("`@("H@9F5T8V@J*"DN("!.965D960@
M8F5C875S92!/<F%C;&4@8V]N<VED97)S(&5M<'1Y('-T<FEN9W,@=&\@8F4@
M;G5L;"P*("`@("`J('=H:6QE(&UO<W0@;W1H97(@1$)-4R=S(&MN;W<@=&AE
M(&1I9F9E<F5N8V4@8F5T=V5E;B!E;7!T>2!A;F0@;G5L;"X*("`@("`J"B`@
M("`@*@H@("`@("H@/'-A;7`^1$)?4$]25$%"24Q)5%E?04Q,/"]S86UP/@H@
M("`@("H@='5R;B!O;B!A;&P@<&]R=&%B:6QI='D@9F5A='5R97,*("`@("`J
M"B`@("`@*B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+0H@("`@("H*("`@("`J($5X86UP;&4@,2X@4VEM<&QE('-E=$]P=&EO
M;B@I(&5X86UP;&4*("`@("`J(#QC;V1E/@H@("`@("H@)&1B+3YS971/<'1I
M;VXH)V%U=&]F<F5E)RP@=')U92D["B`@("`@*B`\+V-O9&4^"B`@("`@*@H@
M("`@("H@17AA;7!L92`R+B!0;W)T86)I;&ET>2!F;W(@;&]W97)C87-I;F<@
M86YD('1R:6UM:6YG"B`@("`@*B`\8V]D93X*("`@("`J("1D8BT^<V5T3W!T
M:6]N*"=P;W)T86)I;&ET>2<L"B`@("`@*B`@("`@("`@("`@("`@("`@1$)?
M4$]25$%"24Q)5%E?3$]715)#05-%('P@1$)?4$]25$%"24Q)5%E?4E1224TI
M.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($5X86UP;&4@,RX@06QL
M('!O<G1A8FEL:71Y(&]P=&EO;G,@97AC97!T('1R:6UM:6YG"B`@("`@*B`\
M8V]D93X*("`@("`J("1D8BT^<V5T3W!T:6]N*"=P;W)T86)I;&ET>2<L"B`@
M("`@*B`@("`@("`@("`@("`@("`@1$)?4$]25$%"24Q)5%E?04Q,(%X@1$)?
M4$]25$%"24Q)5%E?4E1224TI.PH@("`@("H@/"]C;V1E/@H@("`@("H*("`@
M("`J($!P87)A;2!S=')I;F<@)&]P=&EO;B!O<'1I;VX@;F%M90H@("`@("H@
M0'!A<F%M(&UI>&5D("`D=F%L=64@=F%L=64@9F]R('1H92!O<'1I;VX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.B1O<'1I;VYS"B`@("`@*B\*("`@(&9U;F-T:6]N('-E
M=$]P=&EO;B@D;W!T:6]N+"`D=F%L=64I"B`@("!["B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YO<'1I;VYS6R1O<'1I;VY=*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^;W!T:6]N<ULD;W!T:6]N72`]("1V86QU93L*"B`@("`@("`@("`@
M("\J"B`@("`@("`@("`@("`J($)A8VMW87)D<R!C;VUP871I8FEL:71Y(&-H
M96-K(&9O<B!T:&4@9&5P<F5C871E9"`G;W!T:6UI>F4G"B`@("`@("`@("`@
M("`J(&]P=&EO;BX@($1O;F4@:&5R92!I;B!C87-E('-E='1I;F=S(&-H86YG
M92!A9G1E<B!C;VYN96-T:6YG+@H@("`@("`@("`@("`@*B\*("`@("`@("`@
M("`@:68@*"1O<'1I;VX@/3T@)V]P=&EM:7IE)RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1V86QU92`]/2`G<&]R=&%B:6QI='DG*2!["B`@("`@("`@("`@
M("`@("`@("`@<W=I=&-H("@D=&AI<RT^<&AP='EP92D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!C87-E("=O8VDX)SH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==(#T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@1$)?4$]25$%"24Q)
M5%E?3$]715)#05-%('P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@1$)?4$]25$%"24Q)5%E?3E5-4D]74SL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E("=F8G-Q;"<Z"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@)VUY
M<W%L)SH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G;7ES<6QI)SH*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`G<W%L:71E)SH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R=P;W)T86)I
M;&ET>2==(#T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M1$)?4$]25$%"24Q)5%E?1$5,151%7T-/54Y4.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`]($1"7U!/4E1!0DE,25197TY/
M3D4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*")U;FMN;W=N(&]P=&EO;B`D;W!T:6]N(BD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T3W!T:6]N*"D*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE('9A;'5E(&]F(&%N(&]P=&EO;@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)&]P=&EO;B`@=&AE(&]P=&EO;B!N
M86UE('EO=2=R92!C=7)I;W5S(&%B;W5T"B`@("`@*@H@("`@("H@0')E='5R
M;B!M:7AE9"`@=&AE(&]P=&EO;B=S('9A;'5E"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&=E=$]P=&EO;B@D;W!T:6]N*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^;W!T:6]N<ULD;W!T:6]N72DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YO<'1I;VYS6R1O<'1I;VY=.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(G5N:VYO=VX@;W!T:6]N("1O
M<'1I;VXB*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!P<F5P87)E
M*"D*"B`@("`O*BH*("`@("`J(%!R97!A<F5S(&$@<75E<GD@9F]R(&UU;'1I
M<&QE(&5X96-U=&EO;B!W:71H(&5X96-U=&4H*0H@("`@("H*("`@("`J($-R
M96%T97,@82!Q=65R>2!T:&%T(&-A;B!B92!R=6X@;75L=&EP;&4@=&EM97,N
M("!%86-H('1I;64@:70@:7,@<G5N+`H@("`@("H@=&AE('!L86-E:&]L9&5R
M<RP@:68@86YY+"!W:6QL(&)E(')E<&QA8V5D(&)Y('1H92!C;VYT96YT<R!O
M9@H@("`@("H@97AE8W5T92@I)W,@)&1A=&$@87)G=6UE;G0N"B`@("`@*@H@
M("`@("H@5&AR964@='EP97,@;V8@<&QA8V5H;VQD97)S(&-A;B!B92!U<V5D
M.@H@("`@("H@("`K(#QK8F0^/SPO:V)D/B`@<V-A;&%R('9A;'5E("AI+F4N
M('-T<FEN9W,L(&EN=&5G97)S*2X@(%1H92!S>7-T96T*("`@("`J("`@("`@
M("`@("`@("`@("`@('=I;&P@875T;VUA=&EC86QL>2!Q=6]T92!A;F0@97-C
M87!E('1H92!D871A+@H@("`@("H@("`K(#QK8F0^(3PO:V)D/B`@=F%L=64@
M:7,@:6YS97)T960@)V%S(&ES)PH@("`@("H@("`K(#QK8F0^)CPO:V)D/B`@
M<F5Q=6ER97,@82!F:6QE(&YA;64N("!4:&4@9FEL92=S(&-O;G1E;G1S(&=E
M=`H@("`@("H@("`@("`@("`@("`@("`@("`@:6YS97)T960@:6YT;R!T:&4@
M<75E<GD@*&DN92X@<V%V:6YG(&)I;F%R>0H@("`@("H@("`@("`@("`@("`@
M("`@("`@9&%T82!I;B!A(&1B*0H@("`@("H*("`@("`J($5X86UP;&4@,2X*
M("`@("`J(#QC;V1E/@H@("`@("H@)'-T:"`]("1D8BT^<')E<&%R92@G24Y3
M15)4($E.5$\@=&)L("AA+"!B+"!C*2!604Q515,@*#\L("$L("8I)RD["B`@
M("`@*B`D9&%T82`](&%R<F%Y*`H@("`@("H@("`@(")*;VAN)W,@=&5X="(L
M"B`@("`@*B`@("`@(B=I="<G<R!G;V]D)R(L"B`@("`@*B`@("`@)V9I;&5N
M86UE+G1X="<*("`@("`J("D["B`@("`@*B`D<F5S(#T@)&1B+3YE>&5C=71E
M*"1S=&@L("1D871A*3L*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!5
M<V4@8F%C:W-L87-H97,@=&\@97-C87!E('!L86-E:&]L9&5R(&-H87)A8W1E
M<G,@:68@>6]U(&1O;B=T('=A;G0*("`@("`J('1H96T@=&\@8F4@:6YT97)P
M<F5T960@87,@<&QA8V5H;VQD97)S.@H@("`@("H@/'!R93X*("`@("`J("`@
M(")54$1!5$4@9F]O(%-%5"!C;VP]/R!72$5212!C;VP])V]V97(@7"8@=6YD
M97(G(@H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@5VET:"!S;VUE(&1A
M=&%B87-E(&)A8VME;F1S+"!T:&ES(&ES(&5M=6QA=&5D+@H@("`@("H*("`@
M("`J('M`:6YT97)N86P@:6)A<V4@86YD(&]C:3@@:&%V92!T:&5I<B!O=VX@
M<')E<&%R92@I(&UE=&AO9',N?7T*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1Q=65R>2`@=&AE('%U97)Y('1O(&)E('!R97!A<F5D"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@1$(@<W1A=&5M96YT(')E<V]U<F-E(&]N
M('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T"B`@("`@*B`@("`@("`@("`@
M("`@("`@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ97AE8W5T92@I"B`@("`@*B\*("`@(&9U;F-T:6]N('!R97!A<F4H)'%U
M97)Y*0H@("`@>PH@("`@("`@("1T;VME;G,@("`]('!R96=?<W!L:70H)R\H
M*#\\(5Q<7"E;)C\A72DO)RP@)'%U97)Y+"`M,2P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%!214=?4U!,251?1$5,24U?0T%05%5212D["B`@
M("`@("`@)'1O:V5N("`@("`](#`["B`@("`@("`@)'1Y<&5S("`@("`](&%R
M<F%Y*"D["B`@("`@("`@)&YE=W1O:V5N<R`](&%R<F%Y*"D["@H@("`@("`@
M(&9O<F5A8V@@*"1T;VME;G,@87,@)'9A;"D@>PH@("`@("`@("`@("!S=VET
M8V@@*"1V86PI('L*("`@("`@("`@("`@("`@(&-A<V4@)S\G.@H@("`@("`@
M("`@("`@("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]30T%,
M05(["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E("<F)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N
M*RM=(#T@1$)?4$%204U?3U!!455%.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("`@("`@8V%S92`G(2<Z"B`@("`@("`@("`@("`@
M("`@("`@)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7TU)4T,["B`@("`@
M("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@("`@("1N97=T;VME;G-;72`]('!R96=?<F5P
M;&%C92@G+UQ<7"A;)C\A72DO)RP@(EQ<,2(L("1V86PI.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^<')E<&%R95]T;VME;G-;
M72`]("8D;F5W=&]K96YS.PH@("`@("`@(&5N9"@D=&AI<RT^<')E<&%R95]T
M;VME;G,I.PH*("`@("`@("`D:R`](&ME>2@D=&AI<RT^<')E<&%R95]T;VME
M;G,I.PH@("`@("`@("1T:&ES+3YP<F5P87)E7W1Y<&5S6R1K72`]("1T>7!E
M<SL*("`@("`@("`D=&AI<RT^<')E<&%R961?<75E<FEE<ULD:UT@/2!I;7!L
M;V1E*"<@)RP@)&YE=W1O:V5N<RD["@H@("`@("`@(')E='5R;B`D:SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O4')E<&%R92@I"@H@("`@
M+RHJ"B`@("`@*B!!=71O;6%T:6-A;'D@9V5N97)A=&5S(&%N(&EN<V5R="!O
M<B!U<&1A=&4@<75E<GD@86YD('!A<W,@:70@=&\@<')E<&%R92@I"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D=&%B;&4@("`@("`@("!T:&4@=&%B
M;&4@;F%M90H@("`@("H@0'!A<F%M(&%R<F%Y("`D=&%B;&5?9FEE;&1S("!T
M:&4@87)R87D@;V8@9FEE;&0@;F%M97,*("`@("`J($!P87)A;2!I;G0@("`@
M)&UO9&4@("`@("`@("`@82!T>7!E(&]F('%U97)Y('1O(&UA:V4Z"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$0E]!551/455%4EE?
M24Y315)4(&]R($1"7T%55$]1545265]54$1!5$4*("`@("`J($!P87)A;2!S
M=')I;F<@)'=H97)E("`@("`@("`@9F]R('5P9&%T92!Q=65R:65S.B!T:&4@
M5TA%4D4@8VQA=7-E('1O"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<'!E;F0@=&\@=&AE(%-13"!S=&%T96UE;G0N("!$;VXG=`H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6YC;'5D92!T
M:&4@(E=(15)%(B!K97EW;W)D+@H@("`@("H*("`@("`J($!R971U<FX@<F5S
M;W5R8V4@('1H92!Q=65R>2!H86YD;&4*("`@("`J"B`@("`@*B!`=7-E<R!$
M0E]C;VUM;VXZ.G!R97!A<F4H*2P@1$)?8V]M;6]N.CIB=6EL9$UA;FEP4U%,
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@875T;U!R97!A<F4H)'1A8FQE+"`D
M=&%B;&5?9FEE;&1S+"`D;6]D92`]($1"7T%55$]1545265])3E-%4E0L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=VAE<F4@/2!F86QS92D*("`@('L*
M("`@("`@("`D<75E<GD@/2`D=&AI<RT^8G5I;&1-86YI<%-13"@D=&%B;&4L
M("1T86)L95]F:65L9',L("1M;V1E+"`D=VAE<F4I.PH@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B`D<75E
M<GD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^<')E<&%R92@D
M<75E<GDI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]%>&5C
M=71E*"D*"B`@("`O*BH*("`@("`J($%U=&]M871I8V%L>2!G96YE<F%T97,@
M86X@:6YS97)T(&]R('5P9&%T92!Q=65R>2!A;F0@8V%L;"!P<F5P87)E*"D*
M("`@("`J(&%N9"!E>&5C=71E*"D@=VET:"!I=`H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)'1A8FQE("`@("`@("`@=&AE('1A8FQE(&YA;64*("`@
M("`J($!P87)A;2!A<G)A>2`@)&9I96QD<U]V86QU97,@=&AE(&%S<V]C:6%T
M:79E(&%R<F%Y('=H97)E("1K97D@:7,@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9FEE;&0@;F%M92!A;F0@)'9A;'5E(&ET<R!V
M86QU90H@("`@("H@0'!A<F%M(&EN="`@("`D;6]D92`@("`@("`@("!A('1Y
M<&4@;V8@<75E<GD@=&\@;6%K93H*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@($1"7T%55$]1545265])3E-%4E0@;W(@1$)?05543U%5
M15)97U501$%410H@("`@("H@0'!A<F%M('-T<FEN9R`D=VAE<F4@("`@("`@
M("!F;W(@=7!D871E('%U97)I97,Z('1H92!72$5212!C;&%U<V4@=&\*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%P<&5N9"!T;R!T
M:&4@4U%,('-T871E;65N="X@($1O;B=T"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!I;F-L=61E('1H92`B5TA%4D4B(&ME>7=O<F0N
M"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@82!N97<@1$)?<F5S=6QT
M(&]B:F5C="!F;W(@<W5C8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@
M("`@("`@("`@("`@("`@(&]R($1"7T]+(&9O<B!S=6-C97-S=6P@9&%T82!M
M86YI<'5L871I;VX@<75E<FEE<RX*("`@("`J("`@("`@("`@("`@("`@("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!U
M<V5S($1"7V-O;6UO;CHZ875T;U!R97!A<F4H*2P@1$)?8V]M;6]N.CIE>&5C
M=71E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T5X96-U=&4H)'1A8FQE
M+"`D9FEE;&1S7W9A;'5E<RP@)&UO9&4@/2!$0E]!551/455%4EE?24Y315)4
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'=H97)E(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@)'-T:"`]("1T:&ES+3YA=71O4')E<&%R92@D=&%B;&4L
M(&%R<F%Y7VME>7,H)&9I96QD<U]V86QU97,I+"`D;6]D92P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1W:&5R92D["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1H
M.PH@("`@("`@('T*("`@("`@("`D<F5T(#TF("1T:&ES+3YE>&5C=71E*"1S
M=&@L(&%R<F%Y7W9A;'5E<R@D9FEE;&1S7W9A;'5E<RDI.PH@("`@("`@("1T
M:&ES+3YF<F5E4')E<&%R960H)'-T:"D["B`@("`@("`@<F5T=7)N("1R970[
M"@H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&)U:6QD36%N:7!344PH
M*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@86X@4U%,('%U97)Y('-T<FEN
M9R!F;W(@875T;U!R97!A<F4H*0H@("`@("H*("`@("`J($5X86UP;&4Z"B`@
M("`@*B`\<')E/@H@("`@("H@8G5I;&1-86YI<%-13"@G=&%B;&5?<W%L)RP@
M87)R87DH)V9I96QD,2<L("=F:65L9#(G+"`G9FEE;&0S)RDL"B`@("`@*B`@
M("`@("`@("`@("`@($1"7T%55$]1545265])3E-%4E0I.PH@("`@("H@/"]P
M<F4^"B`@("`@*@H@("`@("H@5&AA="!R971U<FYS"B`@("`@*B`\<V%M<#X*
M("`@("`J($E.4T525"!)3E1/('1A8FQE7W-Q;"`H9FEE;&0Q+&9I96QD,BQF
M:65L9#,I(%9!3%5%4R`H/RP_+#\I"B`@("`@*B`\+W-A;7`^"B`@("`@*@H@
M("`@("H@3D]415,Z"B`@("`@*B`@("T@5&AI<R!B96QO;F=S(&UO<F4@=&\@
M82!344P@0G5I;&1E<B!C;&%S<RP@8G5T('1H:7,@:7,@82!S:6UP;&4*("`@
M("`J("`@("!F86-I;&ET>2X*("`@("`J("`@+2!"92!C87)E9G5L;"$@268@
M>6]U(&1O;B=T(&=I=F4@82`D=VAE<F4@<&%R86T@=VET:"!A;B!54$1!5$4*
M("`@("`J("`@("!Q=65R>2P@86QL('1H92!R96-O<F1S(&]F('1H92!T86)L
M92!W:6QL(&)E('5P9&%T960A"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D=&%B;&4@("`@("`@("!T:&4@=&%B;&4@;F%M90H@("`@("H@0'!A<F%M
M(&%R<F%Y("`D=&%B;&5?9FEE;&1S("!T:&4@87)R87D@;V8@9FEE;&0@;F%M
M97,*("`@("`J($!P87)A;2!I;G0@("`@)&UO9&4@("`@("`@("`@82!T>7!E
M(&]F('%U97)Y('1O(&UA:V4Z"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!$0E]!551/455%4EE?24Y315)4(&]R($1"7T%55$]15452
M65]54$1!5$4*("`@("`J($!P87)A;2!S=')I;F<@)'=H97)E("`@("`@("`@
M9F]R('5P9&%T92!Q=65R:65S.B!T:&4@5TA%4D4@8VQA=7-E('1O"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<'!E;F0@=&\@=&AE
M(%-13"!S=&%T96UE;G0N("!$;VXG=`H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:6YC;'5D92!T:&4@(E=(15)%(B!K97EW;W)D+@H@
M("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<W%L('%U97)Y(&9O
M<B!A=71O4')E<&%R92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&)U:6QD36%N
M:7!344PH)'1A8FQE+"`D=&%B;&5?9FEE;&1S+"`D;6]D92P@)'=H97)E(#T@
M9F%L<V4I"B`@("!["B`@("`@("`@:68@*&-O=6YT*"1T86)L95]F:65L9',I
M(#T](#`I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"B`@("`@("`@
M)&9I<G-T(#T@=')U93L*("`@("`@("!S=VET8V@@*"1M;V1E*2!["B`@("`@
M("`@("`@(&-A<V4@1$)?05543U%515)97TE.4T525#H*("`@("`@("`@("`@
M("`@("1V86QU97,@/2`G)SL*("`@("`@("`@("`@("`@("1N86UE<R`]("<G
M.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'1A8FQE7V9I96QD<R!A<R`D
M=F%L=64I('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&9I<G-T*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1F:7)S="`](&9A;'-E.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1N86UE<R`N/2`G+"<["B`@("`@("`@("`@("`@("`@("`@("`@("1V86QU
M97,@+CT@)RPG.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@("`@("`D;F%M97,@+CT@)'9A;'5E.PH@("`@("`@("`@("`@("`@("`@
M("1V86QU97,@+CT@)S\G.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@<F5T=7)N("))3E-%4E0@24Y43R`D=&%B;&4@*"1N86UE<RD@5D%,
M5453("@D=F%L=65S*2(["B`@("`@("`@("`@(&-A<V4@1$)?05543U%515)9
M7U501$%413H*("`@("`@("`@("`@("`@("1S970@/2`G)SL*("`@("`@("`@
M("`@("`@(&9O<F5A8V@@*"1T86)L95]F:65L9',@87,@)'9A;'5E*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1F:7)S="D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D9FER<W0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<V5T("X]("<L
M)SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M)'-E="`N/2`B)'9A;'5E(#T@/R(["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<W%L(#T@(E501$%412`D=&%B;&4@4T54("1S970B.PH@
M("`@("`@("`@("`@("`@:68@*"1W:&5R92D@>PH@("`@("`@("`@("`@("`@
M("`@("1S<6P@+CT@(B!72$5212`D=VAE<F4B.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@<F5T=7)N("1S<6P["B`@("`@("`@("`@(&1E
M9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?4UE.5$%8*3L*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@97AE8W5T92@I"@H@("`@+RHJ"B`@("`@*B!%>&5C
M=71E<R!A($1"('-T871E;65N="!P<F5P87)E9"!W:71H('!R97!A<F4H*0H@
M("`@("H*("`@("`J($5X86UP;&4@,2X*("`@("`J(#QC;V1E/@H@("`@("H@
M)'-T:"`]("1D8BT^<')E<&%R92@G24Y315)4($E.5$\@=&)L("AA+"!B+"!C
M*2!604Q515,@*#\L("$L("8I)RD["B`@("`@*B`D9&%T82`](&%R<F%Y*`H@
M("`@("H@("`@(")*;VAN)W,@=&5X="(L"B`@("`@*B`@("`@(B=I="<G<R!G
M;V]D)R(L"B`@("`@*B`@("`@)V9I;&5N86UE+G1X="<*("`@("`J("D["B`@
M("`@*B`D<F5S(#TF("1D8BT^97AE8W5T92@D<W1H+"`D9&%T82D["B`@("`@
M*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT
M("!A($1"('-T871E;65N="!R97-O=7)C92!R971U<FYE9"!F<F]M('!R97!A
M<F4H*0H@("`@("H@0'!A<F%M(&UI>&5D("`@("1D871A("!A<G)A>2P@<W1R
M:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N
M="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO
M;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y
M.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C
M96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("!A(&YE=R!$0E]R97-U;'0@;V)J96-T(&9O<B!S=6-C97-S
M9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`@;W(@
M1$)?3TL@9F]R('-U8V-E<W-U;"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S
M+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"!I8F%S92!A;F0@
M;V-I."!H879E('1H96ER(&]W;B!E>&5C=71E*"D@;65T:&]D<RY]?0H@("`@
M("H*("`@("`J($!S964@1$)?8V]M;6]N.CIP<F5P87)E*"D*("`@("`J+PH@
M("`@9G5N8W1I;VX@)F5X96-U=&4H)'-T;70L("1D871A(#T@87)R87DH*2D*
M("`@('L*("`@("`@("`D<F5A;'%U97)Y(#T@)'1H:7,M/F5X96-U=&5%;75L
M871E475E<GDH)'-T;70L("1D871A*3L*("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E86QQ=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N("1R96%L<75E
M<GD["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<VEM<&QE
M475E<GDH)')E86QQ=65R>2D["@H@("`@("`@(&EF("@D<F5S=6QT(#T]/2!$
M0E]/2R!\?"!$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M=&UP(#TF(&YE=R!$0E]R97-U;'0H)'1H:7,L("1R97-U;'0I.PH@("`@("`@
M("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97AE8W5T945M=6QA=&51=65R>2@I"@H@("`@+RHJ"B`@
M("`@*B!%;75L871E<R!E>&5C=71I;F<@<')E<&%R960@<W1A=&5M96YT<R!I
M9B!T:&4@1$)-4R!N;W0@<W5P<&]R="!T:&5M"B`@("`@*@H@("`@("H@0'!A
M<F%M(')E<V]U<F-E("1S=&UT("!A($1"('-T871E;65N="!R97-O=7)C92!R
M971U<FYE9"!F<F]M(&5X96-U=&4H*0H@("`@("H@0'!A<F%M(&UI>&5D("`@
M("1D871A("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U
M<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I
M;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q
M=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O
M<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A
M<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!A('-T<FEN9R!C;VYT86EN
M:6YG('1H92!R96%L('%U97)Y(')U;B!W:&5N(&5M=6QA=&EN9PH@("`@("H@
M("`@("`@("`@("`@("`@('!R97!A<F4O97AE8W5T92X@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIE>&5C=71E*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@97AE8W5T945M=6QA=&51=65R>2@D<W1M="P@)&1A
M=&$@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("1S=&UT(#T@*&EN="DD<W1M
M=#L*("`@("`@("`D9&%T82`]("AA<G)A>2DD9&%T83L*("`@("`@("`D=&AI
M<RT^;&%S=%]P87)A;65T97)S(#T@)&1A=&$["@H@("`@("`@(&EF("AC;W5N
M="@D=&AI<RT^<')E<&%R95]T>7!E<ULD<W1M=%TI("$](&-O=6YT*"1D871A
M*2D@>PH@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1T:&ES+3YP
M<F5P87)E9%]Q=65R:65S6R1S=&UT73L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YR86ES945R<F]R*$1"7T524D]27TU)4TU!5$-(*3L*("`@("`@("!]
M"@H@("`@("`@("1R96%L<75E<GD@/2`D=&AI<RT^<')E<&%R95]T;VME;G-;
M)'-T;71=6S!=.PH*("`@("`@("`D:2`](#`["B`@("`@("`@9F]R96%C:"`H
M)&1A=&$@87,@)'9A;'5E*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^<')E
M<&%R95]T>7!E<ULD<W1M=%U;)&E=(#T]($1"7U!!4D%-7U-#04Q!4BD@>PH@
M("`@("`@("`@("`@("`@)')E86QQ=65R>2`N/2`D=&AI<RT^<75O=&53;6%R
M="@D=F%L=64I.PH@("`@("`@("`@("!](&5L<V5I9B`H)'1H:7,M/G!R97!A
M<F5?='EP97-;)'-T;71=6R1I72`]/2!$0E]005)!35]/4$%1544I('L*("`@
M("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D=F%L=64L("=R8B<I.PH@("`@
M("`@("`@("`@("`@:68@*"$D9G`I('L*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?04-#15-37U9)3TQ!
M5$E/3BD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5A
M;'%U97)Y("X]("1T:&ES+3YQ=6]T95-M87)T*&9R96%D*"1F<"P@9FEL97-I
M>F4H)'9A;'5E*2DI.PH@("`@("`@("`@("`@("`@9F-L;W-E*"1F<"D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5A;'%U97)Y
M("X]("1V86QU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E86QQ
M=65R>2`N/2`D=&AI<RT^<')E<&%R95]T;VME;G-;)'-T;71=6RLK)&E=.PH@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R96%L<75E<GD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@97AE8W5T94UU;'1I<&QE*"D*"B`@("`O
M*BH*("`@("`J(%!E<F9O<FUS('-E=F5R86P@97AE8W5T92@I(&-A;&QS(&]N
M('1H92!S86UE('-T871E;65N="!H86YD;&4*("`@("`J"B`@("`@*B`D9&%T
M82!M=7-T(&)E(&%N(&%R<F%Y(&EN9&5X960@;G5M97)I8V%L;'D*("`@("`J
M(&9R;VT@,"P@;VYE(&5X96-U=&4@8V%L;"!I<R!D;VYE(&9O<B!E=F5R>2`B
M<F]W(B!I;B!T:&4@87)R87DN"B`@("`@*@H@("`@("H@268@86X@97)R;W(@
M;V-C=7)S(&1U<FEN9R!E>&5C=71E*"DL(&5X96-U=&5-=6QT:7!L92@I(&1O
M97,@;F]T"B`@("`@*B!E>&5C=71E('1H92!U;F9I;FES:&5D(')O=W,L(&)U
M="!R871H97(@<F5T=7)N<R!T:&%T(&5R<F]R+@H@("`@("H*("`@("`J($!P
M87)A;2!R97-O=7)C92`D<W1M="`@<75E<GD@:&%N9&QE(&9R;VT@<')E<&%R
M92@I"B`@("`@*B!`<&%R86T@87)R87D@("`@)&1A=&$@(&YU;65R:6,@87)R
M87D@8V]N=&%I;FEN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@(&1A=&$@=&\@:6YS97)T(&EN=&\@=&AE('%U97)Y"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R
M(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M
M;6]N.CIP<F5P87)E*"DL($1"7V-O;6UO;CHZ97AE8W5T92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5X96-U=&5-=6QT:7!L92@D<W1M="P@)&1A=&$I"B`@
M("!["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)'9A;'5E*2!["B`@("`@
M("`@("`@("1R97,@/28@)'1H:7,M/F5X96-U=&4H)'-T;70L("1V86QU92D[
M"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&9R9650<F5P87)E9"@I"@H@("`@+RHJ"B`@("`@*B!&<F5E<R!T
M:&4@:6YT97)N86P@<F5S;W5R8V5S(&%S<V]C:6%T960@=VET:"!A('!R97!A
M<F5D('%U97)Y"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1S=&UT
M("`@("`@("`@("!T:&4@<')E<&%R960@<W1A=&5M96YT)W,@4$A0(')E<V]U
M<F-E"B`@("`@*B!`<&%R86T@8F]O;"`@("`@)&9R965?<F5S;W5R8V4@('-H
M;W5L9"!T:&4@4$A0(')E<V]U<F-E(&)E(&9R965D('1O;S\*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%5S92!F86QS92!I9B!Y
M;W4@;F5E9"!T;R!G970@9&%T80H@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@9G)O;2!T:&4@<F5S=6QT('-E="!L871E<BX*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,
M4T4@:68@)')E<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G!R97!A<F4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E
M4')E<&%R960H)'-T;70L("1F<F5E7W)E<V]U<F-E(#T@=')U92D*("`@('L*
M("`@("`@("`D<W1M="`]("AI;G0I)'-T;70["B`@("`@("`@:68@*&ES<V5T
M*"1T:&ES+3YP<F5P87)E7W1O:V5N<ULD<W1M=%TI*2!["B`@("`@("`@("`@
M('5N<V5T*"1T:&ES+3YP<F5P87)E7W1O:V5N<ULD<W1M=%TI.PH@("`@("`@
M("`@("!U;G-E="@D=&AI<RT^<')E<&%R95]T>7!E<ULD<W1M=%TI.PH@("`@
M("`@("`@("!U;G-E="@D=&AI<RT^<')E<&%R961?<75E<FEE<ULD<W1M=%TI
M.PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]"B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO
M9&EF>5%U97)Y*"D*"B`@("`O*BH*("`@("`J($-H86YG97,@82!Q=65R>2!S
M=')I;F<@9F]R('9A<FEO=7,@1$)-4R!S<&5C:69I8R!R96%S;VYS"B`@("`@
M*@H@("`@("H@270@:7,@9&5F:6YE9"!H97)E('1O(&5N<W5R92!A;&P@9')I
M=F5R<R!H879E('1H:7,@;65T:&]D(&%V86EL86)L92X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@=&AE('%U97)Y('-T<FEN9R!T;R!M
M;V1I9GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&UO9&EF
M:65D('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C
M=&5D"B`@("`@*B!`<V5E($1"7VUY<W%L.CIM;V1I9GE1=65R>2@I+"!$0E]O
M8VDX.CIM;V1I9GE1=65R>2@I+`H@("`@("H@("`@("!$0E]S<6QI=&4Z.FUO
M9&EF>5%U97)Y*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;6]D:69Y475E<GDH
M)'%U97)Y*0H@("`@>PH@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@
M+RHJ"B`@("`@*B!!9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I
M;F<@86-C;W)D:6YG('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J
M"B`@("`@*B!)="!I<R!D969I;F5D(&AE<F4@=&\@87-S=7)E('1H870@86QL
M(&EM<&QE;65N=&%T:6]N<PH@("`@("H@:&%V92!T:&ES(&UE=&AO9"!D969I
M;F5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE
M('%U97)Y('1O(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@
M("!T:&4@<F]W('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T
M(')O=RD*("`@("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E
M<G,@;V8@<F]W<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R
M86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@
M;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N
M=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N
M;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M
M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W
M:71H($Q)34E4(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U
M97)Y*"1Q=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!Q=65R>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A
M('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!4
M:&4@<75E<GD@<W1R:6YG(&-A;B!B92!E:71H97(@82!N;W)M86P@<W1A=&5M
M96YT('1O(&)E('-E;G0@9&ER96-T;'D*("`@("`J('1O('1H92!S97)V97(@
M3U(@:68@/'9A<CXD<&%R86US/"]V87(^(&%R92!P87-S960@=&AE('%U97)Y
M(&-A;B!H879E"B`@("`@*B!P;&%C96AO;&1E<G,@86YD(&ET('=I;&P@8F4@
M<&%S<V5D('1H<F]U9V@@<')E<&%R92@I(&%N9"!E>&5C=71E*"DN"B`@("`@
M*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("!T:&4@4U%,('%U97)Y
M(&]R('1H92!S=&%T96UE;G0@=&\@<')E<&%R90H@("`@("H@0'!A<F%M(&UI
M>&5D("`D<&%R86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T
M;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E
M>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M
M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L
M9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE
M;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!A(&YE=R!$0E]R
M97-U;'0@;V)J96-T(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@
M("`@*B`@("`@("`@("`@("`@("`@;W(@1$)?3TL@9F]R('-U8V-E<W-U;"!D
M871A(&UA;FEP=6QA=&EO;B!Q=65R:65S+@H@("`@("H@("`@("`@("`@("`@
M("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@
M("H@0'-E92!$0E]R97-U;'0L($1"7V-O;6UO;CHZ<')E<&%R92@I+"!$0E]C
M;VUM;VXZ.F5X96-U=&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B`F<75E<GDH
M)'%U97)Y+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("!I9B`H
M<VEZ96]F*"1P87)A;7,I(#X@,"D@>PH@("`@("`@("`@("`D<W1H(#T@)'1H
M:7,M/G!R97!A<F4H)'%U97)Y*3L*("`@("`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-T:#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D<F5T(#TF("1T:&ES+3YE>&5C=71E
M*"1S=&@L("1P87)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A
M<F5D*"1S=&@L(&9A;'-E*3L*("`@("`@("`@("`@<F5T=7)N("1R970["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1?<&%R86UE
M=&5R<R`](&%R<F%Y*"D["B`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M<VEM<&QE475E<GDH)'%U97)Y*3L*("`@("`@("`@("`@:68@*"1R97-U;'0@
M/3T]($1"7T]+('Q\($1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1T;7`@/28@;F5W($1"7W)E<W5L="@D=&AI<RP@
M)')E<W5L="D["B`@("`@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!L:6UI=%%U97)Y*"D*"B`@("`O*BH*("`@("`J($=E;F5R871E<R!A;F0@
M97AE8W5T97,@82!,24U)5"!Q=65R>0H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'%U97)Y("`@=&AE('%U97)Y"B`@("`@*B!`<&%R86T@:6YT<B`@
M("1F<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T
M:&4@9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@("!T
M:&4@;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX
M960@("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O
M(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X
M96-U=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA
M=&-H('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD
M97(@9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M
M96YT+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(&$@;F5W($1"7W)E
M<W5L="!O8FIE8W0@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@
M("`J("`@("`@("`@("`@("`@("!O<B!$0E]/2R!F;W(@<W5C8V5S<W5L(&1A
M=&$@;6%N:7!U;&%T:6]N('%U97)I97,N"B`@("`@*B`@("`@("`@("`@("`@
M("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@
M9G5N8W1I;VX@)FQI;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D
M<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D<75E<GD@/2`D=&AI
M<RT^;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U;G0L("1P
M87)A;7,I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<75E<GDI*7L*("`@
M("`@("`@("`@<F5T=7)N("1Q=65R>3L*("`@("`@("!]"B`@("`@("`@)')E
M<W5L="`])B`D=&AI<RT^<75E<GDH)'%U97)Y+"`D<&%R86US*3L*("`@("`@
M("!I9B`H:7-?82@D<F5S=6QT+"`G1$)?<F5S=6QT)RDI('L*("`@("`@("`@
M("`@)')E<W5L="T^<V5T3W!T:6]N*"=L:6UI=%]F<F]M)RP@)&9R;VTI.PH@
M("`@("`@("`@("`D<F5S=6QT+3YS971/<'1I;VXH)VQI;6ET7V-O=6YT)RP@
M)&-O=6YT*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T3VYE*"D*"B`@("`O*BH*
M("`@("`J($9E=&-H97,@=&AE(&9I<G-T(&-O;'5M;B!O9B!T:&4@9FER<W0@
M<F]W(&9R;VT@82!Q=65R>2!R97-U;'0*("`@("`J"B`@("`@*B!486ME<R!C
M87)E(&]F(&1O:6YG('1H92!Q=65R>2!A;F0@9G)E96EN9R!T:&4@<F5S=6QT
M<R!W:&5N(&9I;FES:&5D+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@
M)'%U97)Y("`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A<F%M(&UI>&5D("`D
M<&%R86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U
M<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I
M;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q
M=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O
M<B!N;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A
M<F%M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!T:&4@<F5T=7)N960@=F%L
M=64@;V8@=&AE('%U97)Y+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9G971/;F4H)'%U97)Y+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@
M("`@("`D<&%R86US(#T@*&%R<F%Y*21P87)A;7,["B`@("`@("`@+R\@;6]D
M:69Y3&EM:711=65R>2@I('=O=6QD(&)E(&YI8V4@:&5R92P@8G5T(&ET(&-A
M=7-E<R!"0R!I<W-U97,*("`@("`@("!I9B`H<VEZ96]F*"1P87)A;7,I(#X@
M,"D@>PH@("`@("`@("`@("`D<W1H(#T@)'1H:7,M/G!R97!A<F4H)'%U97)Y
M*3L*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'-T:#L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<F5S(#TF("1T:&ES+3YE>&5C=71E*"1S=&@L("1P87)A;7,I.PH@
M("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S=&@I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1R97,@/28@)'1H:7,M/G%U97)Y*"1Q
M=65R>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H*("`@
M("`@("`D97)R(#T@)')E<RT^9F5T8VA);G1O*"1R;W<L($1"7T9%5$-(34]$
M15]/4D1%4D5$*3L*("`@("`@("`D<F5S+3YF<F5E*"D["@H@("`@("`@(&EF
M("@D97)R("$]/2!$0E]/2RD@>PH@("`@("`@("`@("!R971U<FX@)&5R<CL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F]W6S!=.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&=E=%)O=R@I"@H@("`@+RHJ"B`@("`@*B!&
M971C:&5S('1H92!F:7)S="!R;W<@;V8@9&%T82!R971U<FYE9"!F<F]M(&$@
M<75E<GD@<F5S=6QT"B`@("`@*@H@("`@("H@5&%K97,@8V%R92!O9B!D;VEN
M9R!T:&4@<75E<GD@86YD(&9R965I;F<@=&AE(')E<W5L=',@=VAE;B!F:6YI
M<VAE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H
M92!344P@<75E<GD*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R
M87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S
M=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@
M<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R
M(#$@<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*B!`<&%R
M86T@:6YT("1F971C:&UO9&4@('1H92!F971C:"!M;V1E('1O('5S90H@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@('1H92!F:7)S="!R;W<@;V8@<F5S
M=6QT<R!A<R!A;B!A<G)A>2X*("`@("`J("`@("`@("`@("`@("`@("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T4F]W*"1Q=65R>2P@)'!A<F%M<R`](&%R<F%Y*"DL"B`@("`@("`@
M("`@("`@("`@("`@("1F971C:&UO9&4@/2!$0E]&151#2$U/1$5?1$5&055,
M5"D*("`@('L*("`@("`@("`O+R!C;VUP870@8VAE8VLL('1H92!P87)A;7,@
M86YD(&9E=&-H;6]D92!P87)A;65T97)S('5S960@=&\*("`@("`@("`O+R!H
M879E('1H92!O<'!O<VET92!O<F1E<@H@("`@("`@(&EF("@A:7-?87)R87DH
M)'!A<F%M<RDI('L*("`@("`@("`@("`@:68@*&ES7V%R<F%Y*"1F971C:&UO
M9&4I*2!["B`@("`@("`@("`@("`@("!I9B`H)'!A<F%M<R`]/3T@;G5L;"D@
M>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2!$0E]&151#2$U/1$5?1$5&
M055,5#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'1M<"`]("1P87)A;7,["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D<&%R86US(#T@)&9E=&-H;6]D93L*("`@("`@("`@("`@
M("`@("1F971C:&UO9&4@/2`D=&UP.PH@("`@("`@("`@("!](&5L<V5I9B`H
M)'!A<F%M<R`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@)&9E=&-H;6]D
M92`]("1P87)A;7,["B`@("`@("`@("`@("`@("`D<&%R86US(#T@87)R87DH
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!M;V1I9GE,
M:6UI=%%U97)Y*"D@=V]U;&0@8F4@;FEC92!H97)E+"!B=70@:70@8V%U<V5S
M($)#(&ES<W5E<PH@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P*2![
M"B`@("`@("`@("`@("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI.PH@
M("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'-T:"DI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1R97,@/28@)'1H:7,M/F5X96-U=&4H)'-T:"P@)'!A<F%M<RD["B`@("`@
M("`@("`@("1T:&ES+3YF<F5E4')E<&%R960H)'-T:"D["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^<75E<GDH)'%U97)Y
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<SL*("`@("`@("!]"@H@("`@("`@
M("1E<G(@/2`D<F5S+3YF971C:$EN=&\H)')O=RP@)&9E=&-H;6]D92D["@H@
M("`@("`@("1R97,M/F9R964H*3L*"B`@("`@("`@:68@*"1E<G(@(3T]($1"
M7T]+*2!["B`@("`@("`@("`@(')E='5R;B`D97)R.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1R;W<["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9V5T0V]L*"D*"B`@("`O*BH*("`@("`J($9E=&-H97,@82!S:6YG;&4@
M8V]L=6UN(&9R;VT@82!Q=65R>2!R97-U;'0@86YD(')E='5R;G,@:70@87,@
M86X*("`@("`J(&EN9&5X960@87)R87D*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q=65R>2`@('1H92!344P@<75E<GD*("`@("`J($!P87)A;2!M
M:7AE9"`@)&-O;"`@("`@=VAI8V@@8V]L=6UN('1O(')E='5R;B`H:6YT96=E
M<B!;8V]L=6UN(&YU;6)E<BP*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('-T87)T:6YG(&%T(#!=(&]R('-T<FEN9R!;8V]L=6UN(&YA;65=*0H@
M("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A<G)A>2P@<W1R:6YG(&]R
M(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U
M86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@
M:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A
M;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R87D*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@;W(@,2!P;&%C96AO;&1E
M<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R
M<F%Y("!T:&4@<F5S=6QT<R!A<R!A;B!A<G)A>2X@($$@1$)?17)R;W(@;V)J
M96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ
M.G%U97)Y*"D*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$-O;"@D<75E<GDL
M("1C;VP@/2`P+"`D<&%R86US(#T@87)R87DH*2D*("`@('L*("`@("`@("`D
M<&%R86US(#T@*&%R<F%Y*21P87)A;7,["B`@("`@("`@:68@*'-I>F5O9B@D
M<&%R86US*2`^(#`I('L*("`@("`@("`@("`@)'-T:"`]("1T:&ES+3YP<F5P
M87)E*"1Q=65R>2D["@H@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)'-T
M:"DI('L*("`@("`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YE>&5C=71E*"1S=&@L
M("1P87)A;7,I.PH@("`@("`@("`@("`D=&AI<RT^9G)E95!R97!A<F5D*"1S
M=&@I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R97,@/28@)'1H
M:7,M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@?0H*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@
M("`@("`@?0H*("`@("`@("`D9F5T8VAM;V1E(#T@:7-?:6YT*"1C;VPI(#\@
M1$)?1D540TA-3T1%7T]21$52140@.B!$0E]&151#2$U/1$5?05-33T,["@H@
M("`@("`@(&EF("@A:7-?87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W*"1F
M971C:&UO9&4I*2D@>PH@("`@("`@("`@("`D<F5T(#T@87)R87DH*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!I9B`H(6%R<F%Y7VME>5]E>&ES
M=',H)&-O;"P@)')O=RDI('L*("`@("`@("`@("`@("`@("1R970@/28@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]354-(1DE%3$0I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)')E="`](&%R<F%Y*"1R
M;W=;)&-O;%TI.PH@("`@("`@("`@("`@("`@=VAI;&4@*&ES7V%R<F%Y*"1R
M;W<@/2`D<F5S+3YF971C:%)O=R@D9F5T8VAM;V1E*2DI('L*("`@("`@("`@
M("`@("`@("`@("`D<F5T6UT@/2`D<F]W6R1C;VQ=.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D<F5S+3YF
M<F5E*"D["@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W*2D@>PH@("`@
M("`@("`@("`D<F5T(#T@)')O=SL*("`@("`@("!]"@H@("`@("`@(')E='5R
M;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=$%S<V]C
M*"D*"B`@("`O*BH*("`@("`J($9E=&-H97,@86X@96YT:7)E('%U97)Y(')E
M<W5L="!A;F0@<F5T=7)N<R!I="!A<R!A;@H@("`@("H@87-S;V-I871I=F4@
M87)R87D@=7-I;F<@=&AE(&9I<G-T(&-O;'5M;B!A<R!T:&4@:V5Y"B`@("`@
M*@H@("`@("H@268@=&AE(')E<W5L="!S970@8V]N=&%I;G,@;6]R92!T:&%N
M('1W;R!C;VQU;6YS+"!T:&4@=F%L=64*("`@("`J('=I;&P@8F4@86X@87)R
M87D@;V8@=&AE('9A;'5E<R!F<F]M(&-O;'5M;B`R+6XN("!)9B!T:&4@<F5S
M=6QT"B`@("`@*B!S970@8V]N=&%I;G,@;VYL>2!T=V\@8V]L=6UN<RP@=&AE
M(')E='5R;F5D('9A;'5E('=I;&P@8F4@80H@("`@("H@<V-A;&%R('=I=&@@
M=&AE('9A;'5E(&]F('1H92!S96-O;F0@8V]L=6UN("AU;FQE<W,@9F]R8V5D
M('1O(&%N"B`@("`@*B!A<G)A>2!W:71H('1H92`D9F]R8V5?87)R87D@<&%R
M86UE=&5R*2X@($$@1$(@97)R;W(@8V]D92!I<PH@("`@("H@<F5T=7)N960@
M;VX@97)R;W)S+B`@268@=&AE(')E<W5L="!S970@8V]N=&%I;G,@9F5W97(@
M=&AA;B!T=V\*("`@("`J(&-O;'5M;G,L(&$@1$)?15)23U)?5%)53D-!5$5$
M(&5R<F]R(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J($9O<B!E>&%M<&QE
M+"!I9B!T:&4@=&%B;&4@(FUY=&%B;&4B(&-O;G1A:6YS.@H@("`@("H*("`@
M("`J(#QP<F4^"B`@("`@*B`@240@("`@("!415A4("`@("`@($1!5$4*("`@
M("`J("TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B`@("`@*B`@
M,2`@("`@("`G;VYE)R`@("`@(#DT-#8W.30P.`H@("`@("H@(#(@("`@("`@
M)W1W;R<@("`@("`Y-#0V-SDT,#@*("`@("`J("`S("`@("`@("=T:')E92<@
M("`@.30T-C<Y-#`X"B`@("`@*B`\+W!R93X*("`@("`J"B`@("`@*B!4:&5N
M('1H92!C86QL(&=E=$%S<V]C*"=314Q%0U0@:60L=&5X="!&4D]-(&UY=&%B
M;&4G*2!R971U<FYS.@H@("`@("H@/'!R93X*("`@("`J("`@87)R87DH"B`@
M("`@*B`@("`@)S$G(#T^("=O;F4G+`H@("`@("H@("`@("<R)R`]/B`G='=O
M)RP*("`@("`J("`@("`G,R<@/3X@)W1H<F5E)RP*("`@("`J("`@*0H@("`@
M("H@/"]P<F4^"B`@("`@*@H@("`@("H@+BXN=VAI;&4@=&AE(&-A;&P@9V5T
M07-S;V,H)U-%3$5#5"!I9"QT97AT+&1A=&4@1E)/32!M>71A8FQE)RD@<F5T
M=7)N<SH*("`@("`J(#QP<F4^"B`@("`@*B`@(&%R<F%Y*`H@("`@("H@("`@
M("<Q)R`]/B!A<G)A>2@G;VYE)RP@)SDT-#8W.30P."<I+`H@("`@("H@("`@
M("<R)R`]/B!A<G)A>2@G='=O)RP@)SDT-#8W.30P."<I+`H@("`@("H@("`@
M("<S)R`]/B!A<G)A>2@G=&AR964G+"`G.30T-C<Y-#`X)RD*("`@("`J("`@
M*0H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@268@=&AE(&UO<F4@=&AA
M;B!O;F4@<F]W(&]C8W5R<R!W:71H('1H92!S86UE('9A;'5E(&EN('1H90H@
M("`@("H@9FER<W0@8V]L=6UN+"!T:&4@;&%S="!R;W<@;W9E<G=R:71E<R!A
M;&P@<')E=FEO=7,@;VYE<R!B>0H@("`@("H@9&5F875L="X@(%5S92!T:&4@
M)&=R;W5P('!A<F%M971E<B!I9B!Y;W4@9&]N)W0@=V%N="!T;PH@("`@("H@
M;W9E<G=R:71E(&QI:V4@=&AI<RX@($5X86UP;&4Z"B`@("`@*@H@("`@("H@
M/'!R93X*("`@("`J(&=E=$%S<V]C*"=314Q%0U0@8V%T96=O<GDL:60L;F%M
M92!&4D]-(&UY=&%B;&4G+"!F86QS92P@;G5L;"P*("`@("`J("`@("`@("`@
M($1"7T9%5$-(34]$15]!4U-/0RP@=')U92D@<F5T=7)N<SH*("`@("`J"B`@
M("`@*B`@(&%R<F%Y*`H@("`@("H@("`@("<Q)R`]/B!A<G)A>2AA<G)A>2@G
M:60G(#T^("<T)RP@)VYA;64G(#T^("=N=6UB97(@9F]U<B<I+`H@("`@("H@
M("`@("`@("`@("`@("`@("!A<G)A>2@G:60G(#T^("<V)RP@)VYA;64G(#T^
M("=N=6UB97(@<VEX)RD*("`@("`J("`@("`@("`@("`@*2P*("`@("`J("`@
M("`G.2<@/3X@87)R87DH87)R87DH)VED)R`]/B`G-"<L("=N86UE)R`]/B`G
M;G5M8F5R(&9O=7(G*2P*("`@("`J("`@("`@("`@("`@("`@("`@87)R87DH
M)VED)R`]/B`G-B<L("=N86UE)R`]/B`G;G5M8F5R('-I>"<I"B`@("`@*B`@
M("`@("`@("`@("D*("`@("`J("`@*0H@("`@("H@/"]P<F4^"B`@("`@*@H@
M("`@("H@2V5E<"!I;B!M:6YD('1H870@9&%T86)A<V4@9G5N8W1I;VYS(&EN
M(%!(4"!U<W5A;&QY(')E='5R;B!S=')I;F<*("`@("`J('9A;'5E<R!F;W(@
M<F5S=6QT<R!R96=A<F1L97-S(&]F('1H92!D871A8F%S92=S(&EN=&5R;F%L
M('1Y<&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@("`@
M("`@('1H92!344P@<75E<GD*("`@("`J($!P87)A;2!B;V]L("`@)&9O<F-E
M7V%R<F%Y("!U<V5D(&]N;'D@=VAE;B!T:&4@<75E<GD@<F5T=7)N<PH@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!E>&%C=&QY('1W;R!C
M;VQU;6YS+B`@268@=')U92P@=&AE('9A;'5E<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!O9B!T:&4@<F5T=7)N960@87)R87D@=VEL
M;"!B92!O;F4M96QE;65N=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!A<G)A>7,@:6YS=&5A9"!O9B!S8V%L87)S+@H@("`@("H@0'!A
M<F%M(&UI>&5D("`D<&%R86US("`@("`@(&%R<F%Y+"!S=')I;F<@;W(@;G5M
M97)I8R!D871A('1O(&)E('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1
M=6%N=&ET>2!O9@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I=&5M<R!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!P;&%C96AO;&1E<G,@:6X@
M<75E<GDZ("!M96%N:6YG(#$*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<&QA8V5H;VQD97(@9F]R(&YO;BUA<G)A>2!P87)A;65T97)S
M(&]R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#$@<&QA
M8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*B!`<&%R86T@:6YT
M("`@)&9E=&-H;6]D92`@("`@=&AE(&9E=&-H(&UO9&4@=&\@=7-E"B`@("`@
M*B!`<&%R86T@8F]O;"`@)&=R;W5P("`@("`@("`@:68@=')U92P@=&AE('9A
M;'5E<R!O9B!T:&4@<F5T=7)N960@87)R87D*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:7,@=W)A<'!E9"!I;B!A;F]T:&5R(&%R<F%Y
M+B`@268@=&AE('-A;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:V5Y('9A;'5E("AI;B!T:&4@9FER<W0@8V]L=6UN*2!R97!E871S
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&ET<V5L9BP@
M=&AE('9A;'5E<R!W:6QL(&)E(&%P<&5N9&5D('1O"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('1H:7,@87)R87D@:6YS=&5A9"!O9B!O
M=F5R=W)I=&EN9R!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@97AI<W1I;F<@=F%L=65S+@H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@('1H92!A<W-O8VEA=&EV92!A<G)A>2!C;VYT86EN:6YG('1H92!Q
M=65R>2!R97-U;'1S+@H@("`@("H@("`@("`@("`@("`@("`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E
M=$%S<V]C*"1Q=65R>2P@)&9O<F-E7V%R<F%Y(#T@9F%L<V4L("1P87)A;7,@
M/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`@("1F971C:&UO9&4@
M/2!$0E]&151#2$U/1$5?1$5&055,5"P@)&=R;W5P(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@)'!A<F%M<R`]("AA<G)A>2DD<&%R86US.PH@("`@("`@(&EF
M("AS:7IE;V8H)'!A<F%M<RD@/B`P*2!["B`@("`@("`@("`@("1S=&@@/2`D
M=&AI<RT^<')E<&%R92@D<75E<GDI.PH*("`@("`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1S=&@I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'-T:#L*
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@)')E<R`])B`D=&AI<RT^97AE
M8W5T92@D<W1H+"`D<&%R86US*3L*("`@("`@("`@("`@)'1H:7,M/F9R9650
M<F5P87)E9"@D<W1H*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M<F5S(#TF("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@("`@("`@('T*"B`@("`@
M("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F5S.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`]/2!$
M0E]&151#2$U/1$5?1$5&055,5"D@>PH@("`@("`@("`@("`D9F5T8VAM;V1E
M(#T@)'1H:7,M/F9E=&-H;6]D93L*("`@("`@("!]"B`@("`@("`@)&-O;',@
M/2`D<F5S+3YN=6U#;VQS*"D["@H@("`@("`@(&EF("@D8V]L<R`\(#(I('L*
M("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E]44E5.0T%4140I.PH@("`@("`@("`@("!R971U<FX@)'1M<#L*("`@("`@
M("!]"@H@("`@("`@("1R97-U;'1S(#T@87)R87DH*3L*"B`@("`@("`@:68@
M*"1C;VQS(#X@,B!\?"`D9F]R8V5?87)R87DI('L*("`@("`@("`@("`@+R\@
M<F5T=7)N(&%R<F%Y('9A;'5E<PH@("`@("`@("`@("`O+R!86%@@=&AI<R!P
M87)T(&-A;B!B92!O<'1I;6EZ960*("`@("`@("`@("`@:68@*"1F971C:&UO
M9&4@/3T@1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("`@("!W
M:&EL92`H:7-?87)R87DH)')O=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(
M34]$15]!4U-/0RDI*2!["B`@("`@("`@("`@("`@("`@("`@<F5S970H)')O
M=RD["B`@("`@("`@("`@("`@("`@("`@)&ME>2`](&-U<G)E;G0H)')O=RD[
M"B`@("`@("`@("`@("`@("`@("`@=6YS970H)')O=UMK97DH)')O=RE=*3L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1R97-U;'1S6R1K97E=6UT@/2`D<F]W.PH@("`@("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@
M("1R97-U;'1S6R1K97E=(#T@)')O=SL*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@D9F5T
M8VAM;V1E(#T]($1"7T9%5$-(34]$15]/0DI%0U0I('L*("`@("`@("`@("`@
M("`@('=H:6QE("@D<F]W(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%
M7T]"2D5#5"DI('L*("`@("`@("`@("`@("`@("`@("`D87)R(#T@9V5T7V]B
M:F5C=%]V87)S*"1R;W<I.PH@("`@("`@("`@("`@("`@("`@("1K97D@/2!C
M=7)R96YT*"1A<G(I.PH@("`@("`@("`@("`@("`@("`@(&EF("@D9W)O=7`I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5U;72`]
M("1R;W<["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@)')E<W5L='-;)&ME>5T@/2`D<F]W.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@('=H:6QE("AI<U]A<G)A>2@D<F]W
M(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I*2D@>PH@
M("`@("`@("`@("`@("`@("`@("\O('=E('-H:69T(&%W87D@=&AE(&9I<G-T
M(&5L96UE;G0@=&\@9V5T"B`@("`@("`@("`@("`@("`@("`@+R\@:6YD:6-E
M<R!R=6YN:6YG(&9R;VT@,"!A9V%I;@H@("`@("`@("`@("`@("`@("`@("1K
M97D@/2!A<G)A>5]S:&EF="@D<F]W*3L*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&=R;W5P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S
M6R1K97E=6UT@/2`D<F]W.PH@("`@("`@("`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1S6R1K97E=(#T@)')O
M=SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R;W<I
M*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT<R`]("1R;W<["B`@("`@("`@
M("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!R971U<FX@
M<V-A;&%R('9A;'5E<PH@("`@("`@("`@("!W:&EL92`H:7-?87)R87DH)')O
M=R`]("1R97,M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*2DI('L*
M("`@("`@("`@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@("`@("`@("`@
M("`@("`D<F5S=6QT<ULD<F]W6S!=75M=(#T@)')O=ULQ73L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E<W5L='-;
M)')O=ULP75T@/2`D<F]W6S%=.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F]W*2D@>PH@
M("`@("`@("`@("`@("`@)')E<W5L=',@/2`D<F]W.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("`D<F5S+3YF<F5E*"D["@H@("`@("`@(')E
M='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971!;&PH*0H*("`@("\J*@H@("`@("H@1F5T8VAE<R!A;&P@;V8@=&AE(')O
M=W,@9G)O;2!A('%U97)Y(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@)'%U97)Y("`@("`@=&AE(%-13"!Q=65R>0H@("`@("H@0'!A<F%M
M(&UI>&5D("`D<&%R86US("`@("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@
M9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y
M(&]F"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I=&5M<R!P
M87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O9@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<&QA8V5H;VQD97)S(&EN('%U97)Y.B`@;65A
M;FEN9R`Q"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!P;&%C
M96AO;&1E<B!F;W(@;F]N+6%R<F%Y('!A<F%M971E<G,@;W(*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(#$@<&QA8V5H;VQD97(@<&5R(&%R
M<F%Y(&5L96UE;G0N"B`@("`@*B!`<&%R86T@:6YT("`@("1F971C:&UO9&4@
M('1H92!F971C:"!M;V1E('1O('5S93H*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("L@1$)?1D540TA-3T1%7T]21$52140*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("L@1$)?1D540TA-3T1%7T%34T]#
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`K($1"7T9%5$-(
M34]$15]/4D1%4D5$('P@1$)?1D540TA-3T1%7T9,25!0140*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("L@1$)?1D540TA-3T1%7T%34T]#
M('P@1$)?1D540TA-3T1%7T9,25!0140*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!T:&4@;F5S=&5D(&%R<F%Y+B`@02!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@)F=E=$%L;"@D<75E
M<GDL("1P87)A;7,@/2!A<G)A>2@I+`H@("`@("`@("`@("`@("`@("`@("`D
M9F5T8VAM;V1E(#T@1$)?1D540TA-3T1%7T1%1D%53%0I"B`@("!["B`@("`@
M("`@+R\@8V]M<&%T(&-H96-K+"!T:&4@<&%R86US(&%N9"!F971C:&UO9&4@
M<&%R86UE=&5R<R!U<V5D('1O"B`@("`@("`@+R\@:&%V92!T:&4@;W!P;W-I
M=&4@;W)D97(*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1P87)A;7,I*2!["B`@
M("`@("`@("`@(&EF("AI<U]A<G)A>2@D9F5T8VAM;V1E*2D@>PH@("`@("`@
M("`@("`@("`@:68@*"1P87)A;7,@/3T](&YU;&PI('L*("`@("`@("`@("`@
M("`@("`@("`D=&UP(#T@1$)?1D540TA-3T1%7T1%1D%53%0["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1T;7`@/2`D
M<&%R86US.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'!A
M<F%M<R`]("1F971C:&UO9&4["B`@("`@("`@("`@("`@("`D9F5T8VAM;V1E
M(#T@)'1M<#L*("`@("`@("`@("`@?2!E;'-E:68@*"1P87)A;7,@(3T](&YU
M;&PI('L*("`@("`@("`@("`@("`@("1F971C:&UO9&4@/2`D<&%R86US.PH@
M("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("AS:7IE;V8H)'!A<F%M<RD@/B`P
M*2!["B`@("`@("`@("`@("1S=&@@/2`D=&AI<RT^<')E<&%R92@D<75E<GDI
M.PH*("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'-T:#L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)')E<R`])B`D=&AI<RT^97AE8W5T92@D<W1H+"`D<&%R86US*3L*
M("`@("`@("`@("`@)'1H:7,M/F9R9650<F5P87)E9"@D<W1H*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S(#TF("1T:&ES+3YQ=65R>2@D
M<75E<GDI.PH@("`@("`@('T*"B`@("`@("`@:68@*"1R97,@/3T]($1"7T]+
M('Q\($1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@("`@('T*"B`@("`@("`@)')E<W5L=',@/2!A<G)A>2@I.PH@
M("`@("`@('=H:6QE("A$0E]/2R`]/3T@)')E<RT^9F5T8VA);G1O*"1R;W<L
M("1F971C:&UO9&4I*2!["B`@("`@("`@("`@(&EF("@D9F5T8VAM;V1E("8@
M1$)?1D540TA-3T1%7T9,25!0140I('L*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*"1R;W<@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@("`@("`@("`@("`@
M("`@)')E<W5L='-;)&ME>5U;72`]("1V86P["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<F5S=6QT
M<UM=(#T@)')O=SL*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M)')E<RT^9G)E92@I.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')O=RDI
M('L*("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^<F%I<V5%<G)O<B@D<F]W
M*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D<F5S=6QT<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!A=71O0V]M;6ET*"D*"B`@("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES
M86)L97,@875T;VUA=&EC(&-O;6UI=',*("`@("`J"B`@("`@*B!`<&%R86T@
M8F]O;"`D;VYO9F8@('1R=64@='5R;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET
M(&]F9@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@:68@=&AE(&1R:79E<@H@("`@("H@
M("`@("`@("`@("`@("!D;V5S;B=T('-U<'!O<G0@875T;RUC;VUM:71T:6YG
M('1R86YS86-T:6]N<RX*("`@("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI
M="@D;VYO9F8@/2!F86QS92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#
M;VUM:71S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R
M<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%0
M04),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I
M"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB97(@;V8@<F]W
M<R!I;B!A('%U97)Y(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!R97-O
M=7)C92`D<F5S=6QT("!T:&4@<75E<GD@<F5S=6QT(&ED96YI9FEE<B!P<F]D
M=6-E9"!B>2!02%`*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU
M;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?
M0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T
M9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E
M<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E
M<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H
M870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O
M=W,H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9V5T4V5Q=65N8V5.86UE*"D*"B`@("`O*BH*("`@("`J($=E;F5R
M871E<R!T:&4@;F%M92!U<V5D(&EN<VED92!T:&4@9&%T86)A<V4@9F]R(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!4:&4@8W)E871E4V5Q=65N8V4H*2!D
M;V-B;&]C:R!C;VYT86EN<R!N;W1E<R!A8F]U="!S=&]R:6YG('-E<75E;F-E
M"B`@("`@*B!N86UE<RX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M<6X@('1H92!S97%U96YC92=S('!U8FQI8R!N86UE"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!S97%U96YC92=S(&YA;64@:6X@=&AE(&)A
M8VME;F0*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@
M0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E*"DL($1"7V-O;6UO;CHZ
M9')O<%-E<75E;F-E*"DL"B`@("`@*B`@("`@($1"7V-O;6UO;CHZ;F5X=$E$
M*"DL($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@9V5T4V5Q=65N8V5.86UE*"1S<6XI"B`@("!["B`@("`@("`@<F5T=7)N
M('-P<FEN=&8H)'1H:7,M/F=E=$]P=&EO;B@G<V5Q;F%M95]F;W)M870G*2P*
M("`@("`@("`@("`@("`@("`@("`@("!P<F5G7W)E<&QA8V4H)R];7F$M>C`M
M.5\N72]I)RP@)U\G+"`D<W%N*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE(&YE
M>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC90H@("`@
M("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N('1R=64L('1H92!S
M97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N;W0@97AI<W0*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@:60@;G5M8F5R(&EN
M('1H92!S97%U96YC92X*("`@("`J("`@("`@("`@("`@("`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CID<F]P4V5Q=65N
M8V4H*2P*("`@("`J("`@("`@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H
M*0H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD
M96UA;F0@/2!T<G5E*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12D["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8W)E871E4V5Q=65N8V4H*0H*("`@("\J*@H@("`@
M("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@("H*("`@("`J(%1H92!N
M86UE(&]F(&$@9VEV96X@<V5Q=65N8V4@:7,@9&5T97)M:6YE9"!B>2!P87-S
M:6YG('1H92!S=')I;F<*("`@("`J('!R;W9I9&5D(&EN('1H92`\=F%R/B1S
M97%?;F%M93PO=F%R/B!A<F=U;65N="!T:')O=6=H(%!(4"=S('-P<FEN=&8H
M*0H@("`@("H@9G5N8W1I;VX@=7-I;F<@=&AE('9A;'5E(&9R;VT@=&AE(#QV
M87(^<V5Q;F%M95]F;W)M870\+W9A<CX@;W!T:6]N(&%S"B`@("`@*B!T:&4@
M<W!R:6YT9B@I)W,@9F]R;6%T(&%R9W5M96YT+@H@("`@("H*("`@("`J(#QV
M87(^<V5Q;F%M95]F;W)M870\+W9A<CX@:7,@<V5T('9I82!S971/<'1I;VXH
M*2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M
M92!O9B!T:&4@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q
M=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J
M("`@("`@1$)?8V]M;6]N.CIN97AT240H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!C<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*
M("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E
M;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E
M;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@
M("`@($1"7V-O;6UO;CHZ;F5X=$E$*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M9')O<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!4$%"3$4I.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')A:7-E17)R;W(H*0H*("`@("\J
M*@H@("`@("H@0V]M;75N:6-A=&5S(&%N(&5R<F]R(&%N9"!I;G9O:V4@97)R
M;W(@8V%L;&)A8VMS+"!E=&,*("`@("`J"B`@("`@*B!"87-I8V%L;'D@82!W
M<F%P<&5R(&9O<B!014%2.CIR86ES945R<F]R('=I=&AO=70@=&AE(&UE<W-A
M9V4@<W1R:6YG+@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"`@(&EN=&5G
M97(@97)R;W(@8V]D92P@;W(@82!014%2(&5R<F]R(&]B:F5C="`H86QL"B`@
M("`@*B`@("`@("`@("`@("`@("`@;W1H97(@<&%R86UE=&5R<R!A<F4@:6=N
M;W)E9"!I9B!T:&ES('!A<F%M971E<B!I<PH@("`@("H@("`@("`@("`@("`@
M("`@(&%N(&]B:F5C=`H@("`@("H@0'!A<F%M(&EN="`@("`@97)R;W(@;6]D
M92P@<V5E(%!%05)?17)R;W(@9&]C<PH@("`@("H@0'!A<F%M(&UI>&5D("`@
M:68@97)R;W(@;6]D92!I<R!014%27T524D]27U1224='15(L('1H:7,@:7,@
M=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@97)R;W(@;&5V96P@*$5?55-%
M4E].3U1)0T4@971C*2X@($EF(&5R<F]R(&UO9&4@:7,*("`@("`J("`@("`@
M("`@("`@("`@("!014%27T524D]27T-!3$Q"04-++"!T:&ES(&ES('1H92!C
M86QL8F%C:R!F=6YC=&EO;BP*("`@("`J("`@("`@("`@("`@("`@("!E:71H
M97(@87,@82!F=6YC=&EO;B!N86UE+"!O<B!A<R!A;B!A<G)A>2!O9B!A;@H@
M("`@("H@("`@("`@("`@("`@("`@(&]B:F5C="!A;F0@;65T:&]D(&YA;64N
M("!&;W(@;W1H97(@97)R;W(@;6]D97,@=&AI<PH@("`@("H@("`@("`@("`@
M("`@("`@('!A<F%M971E<B!I<R!I9VYO<F5D+@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@97AT<F$@9&5B=6<@:6YF;W)M871I;VXN("!$969A=6QT<R!T;R!T
M:&4@;&%S=`H@("`@("H@("`@("`@("`@("`@("`@('%U97)Y(&%N9"!N871I
M=F4@97)R;W(@8V]D92X*("`@("`J($!P87)A;2!M:7AE9"`@(&YA=&EV92!E
M<G)O<B!C;V1E+"!I;G1E9V5R(&]R('-T<FEN9R!D97!E;F1I;F<@=&AE"B`@
M("`@*B`@("`@("`@("`@("`@("`@8F%C:V5N9`H@("`@("H*("`@("`J($!R
M971U<FX@;V)J96-T("!T:&4@4$5!4E]%<G)O<B!O8FIE8W0*("`@("`J"B`@
M("`@*B!`<V5E(%!%05)?17)R;W(*("`@("`J+PH@("`@9G5N8W1I;VX@)G)A
M:7-E17)R;W(H)&-O9&4@/2!$0E]%4E)/4BP@)&UO9&4@/2!N=6QL+"`D;W!T
M:6]N<R`](&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=7-E<FEN
M9F\@/2!N=6QL+"`D;F%T:79E8V]D92`](&YU;&PI"B`@("!["B`@("`@("`@
M+R\@5&AE(&5R<F]R(&ES('EE="!A($1"(&5R<F]R(&]B:F5C=`H@("`@("`@
M(&EF("AI<U]O8FIE8W0H)&-O9&4I*2!["B`@("`@("`@("`@("\O(&)E8V%U
M<V4@=V4@=&AE('-T871I8R!014%2.CIR86ES945R<F]R+"!O=7(@9VQO8F%L
M"B`@("`@("`@("`@("\O(&AA;F1L97(@<VAO=6QD(&)E('5S960@:68@:70@
M:7,@<V5T"B`@("`@("`@("`@(&EF("@D;6]D92`]/3T@;G5L;"`F)B`A96UP
M='DH)'1H:7,M/E]D969A=6QT7V5R<F]R7VUO9&4I*2!["B`@("`@("`@("`@
M("`@("`D;6]D92`@("`]("1T:&ES+3Y?9&5F875L=%]E<G)O<E]M;V1E.PH@
M("`@("`@("`@("`@("`@)&]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1?97)R
M;W)?;W!T:6]N<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&UP(#T@
M4$5!4CHZ<F%I<V5%<G)O<B@D8V]D92P@;G5L;"P@)&UO9&4L("1O<'1I;VYS
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N
M=6QL+"!T<G5E*3L*("`@("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'5S97)I;F9O(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@("1U<V5R:6YF;R`]("1T:&ES+3YL87-T7W%U97)Y.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1N871I=F5C;V1E*2!["B`@("`@("`@("`@("1U<V5R
M:6YF;R`N/2`G(%MN871I=F5C;V1E/2<@+B!T<FEM*"1N871I=F5C;V1E*2`N
M("==)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=7-E<FEN9F\@
M+CT@)R!;1$(@17)R;W(Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1C;V1E*2`N
M("==)SL*("`@("`@("!]"@H@("`@("`@("1T;7`@/2!014%2.CIR86ES945R
M<F]R*&YU;&PL("1C;V1E+"`D;6]D92P@)&]P=&EO;G,L("1U<V5R:6YF;RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1$)?17)R;W(G+"!T
M<G5E*3L*("`@("`@("!R971U<FX@)'1M<#L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!$0DU3)R!N871I=F4@97)R;W(@8V]D92!P<F]D=6-E9"!B>2!T:&4@
M;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!$
M0DU3)R!E<G)O<B!C;V1E+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?
M0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)#
M;V1E*"D*"B`@("`O*BH*("`@("`J($UA<',@;F%T:79E(&5R<F]R(&-O9&5S
M('1O($1")W,@<&]R=&%B;&4@;VYE<PH@("`@("H*("`@("`J(%5S97,@=&AE
M(#QV87(^)&5R<F]R8V]D95]M87`\+W9A<CX@<')O<&5R='D@9&5F:6YE9"!I
M;B!E86-H(&1R:79E<BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG?&EN
M="`D;F%T:79E8V]D92`@=&AE(&5R<F]R(&-O9&4@<F5T=7)N960@8GD@=&AE
M($1"35,*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE('!O<G1A8FQE
M($1"(&5R<F]R(&-O9&4N("!2971U<FX@1$)?15)23U(@:68@=&AE"B`@("`@
M*B`@("`@("`@("`@("`@(&-U<G)E;G0@9')I=F5R(&1O97-N)W0@:&%V92!A
M(&UA<'!I;F<@9F]R('1H90H@("`@("H@("`@("`@("`@("`@("`D;F%T:79E
M8V]D92!S=6)M:71T960N"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D
M92@D;F%T:79E8V]D92D*("`@('L*("`@("`@("!I9B`H:7-S970H)'1H:7,M
M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O9&5=*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F5R<F]R8V]D95]M87!;)&YA=&EV96-O9&5=.PH@("`@
M("`@('T*("`@("`@("`O+R!&86QL(&)A8VL@=&\@1$)?15)23U(@:68@=&AE
M<F4@=V%S(&YO(&UA<'!I;F<N"B`@("`@("`@<F5T=7)N($1"7T524D]2.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R365S<V%G92@I"@H@
M("`@+RHJ"B`@("`@*B!-87!S(&$@1$(@97)R;W(@8V]D92!T;R!A('1E>'1U
M86P@;65S<V%G90H@("`@("H*("`@("`J($!P87)A;2!I;G1E9V5R("1D8F-O
M9&4@('1H92!$0B!E<G)O<B!C;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!E<G)O<B!M97-S86=E(&-O<G)E<W!O;F1I;F<@=&\@=&AE
M(&5R<F]R(&-O9&4*("`@("`J("`@("`@("`@("`@("`@("`@<W5B;6ET=&5D
M+B`@1D%,4T4@:68@=&AE(&5R<F]R(&-O9&4@:7,@=6YK;F]W;BX*("`@("`J
M"B`@("`@*B!`<V5E($1".CIE<G)O<DUE<W-A9V4H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<G)O<DUE<W-A9V4H)&1B8V]D92D*("`@('L*("`@("`@("!R
M971U<FX@1$(Z.F5R<F]R365S<V%G92@D=&AI<RT^97)R;W)C;V1E7VUA<%LD
M9&)C;V1E72D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@=&%B;&5)
M;F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I;VX@86)O
M=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&4@
M9F]R;6%T(&]F('1H92!R97-U;'1I;F<@87)R87D@9&5P96YD<R!O;B!W:&EC
M:"`\=F%R/B1M;V1E/"]V87(^"B`@("`@*B!Y;W4@<V5L96-T+B`@5&AE('-A
M;7!L92!O=71P=70@8F5L;W<@:7,@8F%S960@;VX@=&AI<R!Q=65R>3H*("`@
M("`J(#QP<F4^"B`@("`@*B`@("!314Q%0U0@=&)L1F]O+F9L9$E$+"!T8FQ&
M;V\N9FQD4&AO;F4L('1B;$)A<BYF;&1)9`H@("`@("H@("`@1E)/32!T8FQ&
M;V\*("`@("`J("`@($I/24X@=&)L0F%R($].('1B;$9O;RYF;&1)9"`]('1B
M;$)A<BYF;&1)9`H@("`@("H@/"]P<F4^"B`@("`@*@H@("`@("H@/'5L/@H@
M("`@("H@/&QI/@H@("`@("H*("`@("`J(#QK8F0^;G5L;#PO:V)D/B`H9&5F
M875L="D*("`@("`J("`@/'!R93X*("`@("`J("`@6S!=(#T^($%R<F%Y("@*
M("`@("`J("`@("`@(%MT86)L95T@/3X@=&)L1F]O"B`@("`@*B`@("`@("!;
M;F%M95T@/3X@9FQD260*("`@("`J("`@("`@(%MT>7!E72`]/B!I;G0*("`@
M("`J("`@("`@(%ML96Y=(#T^(#$Q"B`@("`@*B`@("`@("!;9FQA9W-=(#T^
M('!R:6UA<GE?:V5Y(&YO=%]N=6QL"B`@("`@*B`@("D*("`@("`J("`@6S%=
M(#T^($%R<F%Y("@*("`@("`J("`@("`@(%MT86)L95T@/3X@=&)L1F]O"B`@
M("`@*B`@("`@("!;;F%M95T@/3X@9FQD4&AO;F4*("`@("`J("`@("`@(%MT
M>7!E72`]/B!S=')I;F<*("`@("`J("`@("`@(%ML96Y=(#T^(#(P"B`@("`@
M*B`@("`@("!;9FQA9W-=(#T^"B`@("`@*B`@("D*("`@("`J("`@6S)=(#T^
M($%R<F%Y("@*("`@("`J("`@("`@(%MT86)L95T@/3X@=&)L0F%R"B`@("`@
M*B`@("`@("!;;F%M95T@/3X@9FQD260*("`@("`J("`@("`@(%MT>7!E72`]
M/B!I;G0*("`@("`J("`@("`@(%ML96Y=(#T^(#$Q"B`@("`@*B`@("`@("!;
M9FQA9W-=(#T^('!R:6UA<GE?:V5Y(&YO=%]N=6QL"B`@("`@*B`@("D*("`@
M("`J("`@/"]P<F4^"B`@("`@*@H@("`@("H@/"]L:3X\;&D^"B`@("`@*@H@
M("`@("H@/&MB9#Y$0E]404),14E.1D]?3U)$15(\+VMB9#X*("`@("`J"B`@
M("`@*B`@(#QP/DEN(&%D9&ET:6]N('1O('1H92!I;F9O<FUA=&EO;B!F;W5N
M9"!I;B!T:&4@9&5F875L="!O=71P=70L"B`@("`@*B`@(&$@;F]T871I;VX@
M;V8@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&ES('!R;W9I9&5D(&)Y('1H90H@
M("`@("H@("`\<V%M<#YN=6U?9FEE;&1S/"]S86UP/B!E;&5M96YT('=H:6QE
M('1H92`\<V%M<#YO<F1E<CPO<V%M<#X*("`@("`J("`@96QE;65N="!P<F]V
M:61E<R!A;B!A<G)A>2!W:71H('1H92!C;VQU;6X@;F%M97,@87,@=&AE(&ME
M>7,@86YD"B`@("`@*B`@('1H96ER(&QO8V%T:6]N(&EN9&5X(&YU;6)E<B`H
M8V]R<F5S<&]N9&EN9R!T;R!T:&4@:V5Y<R!I;B!T:&4*("`@("`J("`@=&AE
M(&1E9F%U;'0@;W5T<'5T*2!A<R!T:&4@=F%L=65S+CPO<#X*("`@("`J"B`@
M("`@*B`@(#QP/DEF(&$@<F5S=6QT('-E="!H87,@:61E;G1I8V%L(&9I96QD
M(&YA;65S+"!T:&4@;&%S="!O;F4@:7,*("`@("`J("`@=7-E9"X\+W`^"B`@
M("`@*@H@("`@("H@("`\<')E/@H@("`@("H@("!;;G5M7V9I96QD<UT@/3X@
M,PH@("`@("H@("!;;W)D97)=(#T^($%R<F%Y("@*("`@("`J("`@("`@(%MF
M;&1)9%T@/3X@,@H@("`@("H@("`@("`@6V9L9%1R86YS72`]/B`Q"B`@("`@
M*B`@("D*("`@("`J("`@/"]P<F4^"B`@("`@*@H@("`@("H@/"]L:3X\;&D^
M"B`@("`@*@H@("`@("H@/&MB9#Y$0E]404),14E.1D]?3U)$15)404),13PO
M:V)D/@H@("`@("H*("`@("`J("`@/'`^4VEM:6QA<B!T;R`\:V)D/D1"7U1!
M0DQ%24Y&3U]/4D1%4CPO:V)D/B!B=70@861D<R!M;W)E"B`@("`@*B`@(&1I
M;65N<VEO;G,@=&\@=&AE(&%R<F%Y(&EN('=H:6-H('1H92!T86)L92!N86UE
M<R!A<F4@:V5Y<R!A;F0*("`@("`J("`@=&AE(&9I96QD(&YA;65S(&%R92!S
M=6(M:V5Y<RX@(%1H:7,@:7,@:&5L<&9U;"!F;W(@<75E<FEE<R!T:&%T"B`@
M("`@*B`@(&IO:6X@=&%B;&5S('=H:6-H(&AA=F4@:61E;G1I8V%L(&9I96QD
M(&YA;65S+CPO<#X*("`@("`J"B`@("`@*B`@(#QP<F4^"B`@("`@*B`@(%MN
M=6U?9FEE;&1S72`]/B`S"B`@("`@*B`@(%MO<F1E<G1A8FQE72`]/B!!<G)A
M>2`H"B`@("`@*B`@("`@("!;=&)L1F]O72`]/B!!<G)A>2`H"B`@("`@*B`@
M("`@("`@("`@6V9L9$ED72`]/B`P"B`@("`@*B`@("`@("`@("`@6V9L9%!H
M;VYE72`]/B`Q"B`@("`@*B`@("`@("`I"B`@("`@*B`@("`@("!;=&)L0F%R
M72`]/B!!<G)A>2`H"B`@("`@*B`@("`@("`@("`@6V9L9$ED72`]/B`R"B`@
M("`@*B`@("`@("`I"B`@("`@*B`@("D*("`@("`J("`@/"]P<F4^"B`@("`@
M*@H@("`@("H@/"]L:3X*("`@("`J(#PO=6P^"B`@("`@*@H@("`@("H@5&AE
M(#QS86UP/F9L86=S/"]S86UP/B!E;&5M96YT(&-O;G1A:6YS(&$@<W!A8V4@
M<V5P87)A=&5D(&QI<W0*("`@("`J(&]F(&5X=')A(&EN9F]R;6%T:6]N(&%B
M;W5T('1H92!F:65L9"X@(%1H:7,@9&%T82!I<R!I;F-O;G-I<W1E;G0*("`@
M("`J(&)E='=E96X@1$)-4R=S(&1U92!T;R!T:&4@=V%Y(&5A8V@@1$)-4R!W
M;W)K<RX*("`@("`J("`@*R`\<V%M<#YP<FEM87)Y7VME>3PO<V%M<#X*("`@
M("`J("`@*R`\<V%M<#YU;FEQ=65?:V5Y/"]S86UP/@H@("`@("H@("`K(#QS
M86UP/FUU;'1I<&QE7VME>3PO<V%M<#X*("`@("`J("`@*R`\<V%M<#YN;W1?
M;G5L;#PO<V%M<#X*("`@("`J"B`@("`@*B!-;W-T($1"35,G<R!O;FQY('!R
M;W9I9&4@=&AE(#QS86UP/G1A8FQE/"]S86UP/B!A;F0@/'-A;7`^9FQA9W,\
M+W-A;7`^"B`@("`@*B!E;&5M96YT<R!I9B`\=F%R/B1R97-U;'0\+W9A<CX@
M:7,@82!T86)L92!N86UE+B`@5&AE(&9O;&QO=VEN9R!$0DU3)W,*("`@("`J
M('!R;W9I9&4@9G5L;"!I;F9O<FUA=&EO;B!F<F]M('%U97)I97,Z"B`@("`@
M*B`@("L@9F)S<6P*("`@("`J("`@*R!M>7-Q;`H@("`@("H*("`@("`J($EF
M('1H92`G<&]R=&%B:6QI='DG(&]P=&EO;B!H87,@/'-A;7`^1$)?4$]25$%"
M24Q)5%E?3$]715)#05-%/"]S86UP/@H@("`@("H@='5R;F5D(&]N+"!T:&4@
M;F%M97,@;V8@=&%B;&5S(&%N9"!F:65L9',@=VEL;"!B92!L;W=E<F-A<V5D
M+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT
M("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI
M;F<@=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T<R!A('%U
M97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D97!R96-A=&5D
M+@H@("`@("H@0'!A<F%M(&EN="`@)&UO9&4@("!E:71H97(@=6YU<V5D(&]R
M(&]N92!O9B!T:&4@=&%B;&5);F9O(&UO9&5S.@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`\:V)D/D1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%/"]K8F0^
M+`H@("`@("H@("`@("`@("`@("`@("`@("`@("`\:V)D/D1"7U1!0DQ%24Y&
M3U]/4D1%4CPO:V)D/B!O<@H@("`@("H@("`@("`@("`@("`@("`@("`@("`\
M:V)D/D1"7U1!0DQ%24Y&3U]&54Q,/"]K8F0^("AW:&EC:"!D;V5S(&)O=&@I
M+@H@("`@("H@("`@("`@("`@("`@("`@("`@("!4:&5S92!A<F4@8FET=VES
M92P@<V\@=&AE(&9I<G-T('1W;R!C86X@8F4*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@8V]M8FEN960@=7-I;F<@/&MB9#Y\/"]K8F0^+@H@("`@("H*
M("`@("`J($!R971U<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I
M=&@@=&AE(&EN9F]R;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@
M("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIS971/<'1I;VXH*0H@("`@("HO"B`@
M("!F=6YC=&EO;B!T86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@
M("`@>PH@("`@("`@("\J"B`@("`@("`@("H@268@=&AE($1"7SQD<FEV97(^
M(&-L87-S(&AA<R!A('1A8FQE26YF;R@I(&UE=&AO9"P@=&AA="!O;F4*("`@
M("`@("`@*B!O=F5R<FED97,@=&AI<R!O;F4N("!"=70L(&EF('1H92!D<FEV
M97(@9&]E<VXG="!H879E(&]N92P*("`@("`@("`@*B!T:&ES(&UE=&AO9"!R
M=6YS(&%N9"!T96QL<R!U<V5R<R!A8F]U="!T:&%T(&9A8W0N"B`@("`@("`@
M("HO"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M971486)L97,H*0H*("`@("\J*@H@("`@("H@3&ES=',@=&AE('1A8FQE<R!I
M;B!T:&4@8W5R<F5N="!D871A8F%S90H@("`@("H*("`@("`J($!R971U<FX@
M87)R87D@('1H92!L:7-T(&]F('1A8FQE<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&1E<')E8V%T960@365T:&]D
M(&1E<')E8V%T960@<V]M92!T:6UE(&)E9F]R92!296QE87-E(#$N,@H@("`@
M("HO"B`@("!F=6YC=&EO;B!G971486)L97,H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^9V5T3&ES=$]F*"=T86)L97,G*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!G971,:7-T3V8H*0H*("`@("\J*@H@("`@("H@
M3&ES=',@:6YT97)N86P@9&%T86)A<V4@:6YF;W)M871I;VX*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T>7!E(&]F(&EN9F]R;6%T:6]N
M(&)E:6YG('-O=6=H="X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!#
M;VUM;VX@:71E;7,@8F5I;F<@<V]U9VAT(&%R93H*("`@("`J("`@("`@("`@
M("`@("`@("`@("`@("!T86)L97,L(&1A=&%B87-E<RP@=7-E<G,L('9I97=S
M+"!F=6YC=&EO;G,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!%86-H
M($1"35,G<R!H87,@:71S(&]W;B!C87!A8FEL:71I97,N"B`@("`@*@H@("`@
M("H@0')E='5R;B!A<G)A>2`@86X@87)R87D@;&ES=&EN9R!T:&4@:71E;7,@
M<V]U9VAT+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$(@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QI
M<W1/9B@D='EP92D*("`@('L*("`@("`@("`D<W%L(#T@)'1H:7,M/F=E=%-P
M96-I86Q1=65R>2@D='EP92D["B`@("`@("`@:68@*"1S<6P@/3T](&YU;&PI
M('L*("`@("`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`G)SL*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27U5.4U50
M4$]25$5$*3L*("`@("`@("!](&5L<V5I9B`H:7-?:6YT*"1S<6PI('Q\($1"
M.CII<T5R<F]R*"1S<6PI*2!["B`@("`@("`@("`@("\O(%!R979I;W5S(&5R
M<F]R"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<W%L
M*3L*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)'-Q;"DI('L*("`@("`@
M("`@("`@+R\@06QR96%D>2!T:&4@<F5S=6QT"B`@("`@("`@("`@(')E='5R
M;B`D<W%L.PH@("`@("`@('T*("`@("`@("`O+R!,875N8V@@=&AI<R!Q=65R
M>0H@("`@("`@(')E='5R;B`D=&AI<RT^9V5T0V]L*"1S<6PI.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@
M+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O
M<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y
M;W4@=V%N="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R
M:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV
M97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H
M92!O8FIE8W0@='EP92!R97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?54Y355!03U)4140I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(%]R=')I;4%R<F%Y5F%L=65S*"D*"B`@("`O*BH*("`@("`J(%)I9VAT+71R
M:6US(&%L;"!S=')I;F=S(&EN(&%N(&%R<F%Y"B`@("`@*@H@("`@("H@0'!A
M<F%M(&%R<F%Y("1A<G)A>2`@=&AE(&%R<F%Y('1O(&)E('1R:6UM960@*'!A
M<W-E9"!B>2!R969E<F5N8V4I"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@
M9G5N8W1I;VX@7W)T<FEM07)R87E686QU97,H)B1A<G)A>2D*("`@('L*("`@
M("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@
M("`@("`@("`@:68@*&ES7W-T<FEN9R@D=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`D87)R87E;)&ME>5T@/2!R=')I;2@D=F%L=64I.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]C
M;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@I"@H@("`@+RHJ"B`@("`@
M*B!#;VYV97)T<R!A;&P@;G5L;"!V86QU97,@:6X@86X@87)R87D@=&\@96UP
M='D@<W1R:6YG<PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`@)&%R<F%Y
M("!T:&4@87)R87D@=&\@8F4@9&4M;G5L;&EF:65D("AP87-S960@8GD@<F5F
M97)E;F-E*0H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("H*("`@
M("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C
M;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@F)&%R<F%Y*0H@("`@>PH@
M("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86QU92D@>PH@
M("`@("`@("`@("!I9B`H:7-?;G5L;"@D=F%L=64I*2!["B`@("`@("`@("`@
M("`@("`D87)R87E;)&ME>5T@/2`G)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*"B`@("`O+R!]?7T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S
M.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD
M.@H@*B\*"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]F
M8G-Q;"YP:'``````````````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#4U-38U(#$P-3$U-#,T,3,S(#`R,#8P-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`H*+RH@=FEM.B!S
M970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T
M;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S
M(&9B<W%L(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!&<F]N
M=$)A<V4@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!&<F%N:R!-+B!+<F]M86YN(#QF<F%N:T!F<F]N
M=&)A<V4N8V]M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD
M86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@
M4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@9F)S<6PN<&AP+'8@,2XX,B`R,#`U+S`S+S`T(#(S.C$R
M.C,V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?
M8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR
M97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H
M;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&9B<W%L
M(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!&<F]N=$)A<V4@
M9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@=&AE(&]N
M97,@9&5C;&%R960@:6X@1$)?8V]M;6]N+@H@*@H@*B!`8V%T96=O<GD@("!$
M871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!&<F%N
M:R!-+B!+<F]M86YN(#QF<F%N:T!F<F]N=&)A<V4N8V]M/@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("H@
M0'-I;F-E("`@("`@0VQA<W,@9G5N8W1I;VYA;"!S:6YC92!296QE87-E(#$N
M-RXP"B`J+PIC;&%S<R!$0E]F8G-Q;"!E>'1E;F1S($1"7V-O;6UO;@I["B`@
M("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R
M:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=F8G-Q;"<[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@
M=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J
M($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G9F)S
M<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T:&ES
M($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N97=?;&EN
M:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F:7)S
M="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI<R!$
M0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*("`@
M("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE;G0Z"B`@
M("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H(')O=R!B
M>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T:&4@<75E
M<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@("`J"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@/2!A
M<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@)V%L=&5R)RP*("`@
M("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O
M=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@("`@(#T^
M('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A
M8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA
M<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E
M7VUA<"`](&%R<F%Y*`H@("`@("`@("`R,B`]/B!$0E]%4E)/4E]364Y405@L
M"B`@("`@("`@(#@U(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@
M("`@(#$P."`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@,3$V(#T^($1"
M7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#$R-"`]/B!$0E]%4E)/4E]6
M04Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@,C$U(#T^($1"7T524D]27TY/
M4U5#2$9)14Q$+`H@("`@("`@(#(Q-R`]/B!$0E]%4E)/4E])3E9!3$E$7TY5
M34)%4BP*("`@("`@("`R,C8@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@
M("`@("`@,C,Q(#T^($1"7T524D]27TE.5D%,240L"B`@("`@("`@,C,Y(#T^
M($1"7T524D]27U1254Y#051%1"P*("`@("`@("`R-3$@/3X@1$)?15)23U)?
M4UE.5$%8+`H@("`@("`@(#(V-B`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@
M("`@("`@,S4W(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@
M("`@("`@,S4X(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,S8P
M(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,S8Q(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(')A
M=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@8GD@4$A0"B`@("`@*B!`
M=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@
M("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I
M;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R
M(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7V9B
M<W%L*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@
M("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A
M;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL
M('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS
M=&5A9"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@)&1S;B`@("`@("`@
M('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`<&%R86T@8F]O;"`@)'!E
M<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B92!P97)S:7-T96YT
M/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S
M+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T96YT(#T@9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT96YS:6]N*"=F8G-Q;"<I
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%
M4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@("`@
M("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y;G1A
M>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;)V1B
M<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@87)R87DH
M"B`@("`@("`@("`@("1D<VY;)VAO<W1S<&5C)UT@/R`D9'-N6R=H;W-T<W!E
M8R==(#H@)VQO8V%L:&]S="<L"B`@("`@("`@("`@("1D<VY;)W5S97)N86UE
M)UT@/R`D9'-N6R=U<V5R;F%M92==(#H@;G5L;"P*("`@("`@("`@("`@)&1S
M;ELG<&%S<W=O<F0G72`_("1D<VY;)W!A<W-W;W)D)UT@.B!N=6QL+`H@("`@
M("`@("D["@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E
M;G0@/R`G9F)S<6Q?<&-O;FYE8W0G(#H@)V9B<W%L7V-O;FYE8W0G.PH*("`@
M("`@("`D:6YI(#T@:6YI7V=E="@G=')A8VM?97)R;W)S)RD["B`@("`@("`@
M)'!H<%]E<G)O<FUS9R`]("<G.PH@("`@("`@(&EF("@D:6YI*2!["B`@("`@
M("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?=7-E<E]F=6YC7V%R
M<F%Y*"1C;VYN96-T7V9U;F-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O
M<G,G+"`Q*3L*("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!`8V%L
M;%]U<V5R7V9U;F-?87)R87DH)&-O;FYE8W1?9G5N8W1I;VXL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P87)A;7,I.PH@("`@("`@("`@("!I;FE?<V5T*"=T<F%C:U]E<G)O<G,G
M+"`D:6YI*3L*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M/F-O;FYE
M8W1I;VXI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:'!?97)R;W)M<V<I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1D<VY;)V1A=&%B87-E)UTI('L*("`@
M("`@("`@("`@:68@*"%`9F)S<6Q?<V5L96-T7V1B*"1D<VY;)V1A=&%B87-E
M)UTL("1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YF8G-Q;%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@
M1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&]N
M(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@
M("!["B`@("`@("`@)')E="`]($!F8G-Q;%]C;&]S92@D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@
M("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('-I;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E<GD@
M=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!P87)A;2!S
M=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@("`@("H@0')E
M='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@9F]R('-U8V-E
M<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@
M=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S9G5L('%U97)I
M97,*("`@("`J("`@("`@("`@("`@("`@("L@82!$0E]%<G)O<B!O8FIE8W0@
M;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP;&51=65R>2@D
M<75E<GDI"B`@("!["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E
M<GD["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R
M>2D["B`@("`@("`@)')E<W5L="`]($!F8G-Q;%]Q=65R>2@B)'%U97)Y.R(L
M("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YF8G-Q;%)A:7-E17)R;W(H*3L*
M("`@("`@("!]"B`@("`@("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I97,@
M=&AA="!S:&]U;&0@<F5T=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@("`@("\O
M('-H;W5L9"!R971U<FX@86X@97)R;W(@8V]D92!O;FQY+@H@("`@("`@(&EF
M("A$0CHZ:7--86YI<"@D<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ
M"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!F8G-Q;"!R97-U;'0@<&]I;G1E
M<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@
M0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R
M=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@
M9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT
M*0H@("`@>PH@("`@("`@(')E='5R;B!`9F)S<6Q?;F5X=%]R97-U;'0H)')E
M<W5L="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O
M*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U
M;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R
M;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@
M8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O
M*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S
M90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@
M8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@
M1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@
M<F5S;W5R8V4*("`@("`J($!P87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H
M92!R969E<F5N8V5D(&%R<F%Y('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@
M0'!A<F%M(&EN="`@("`@("1F971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@
M87)R87D@<VAO=6QD(&)E(&EN9&5X960*("`@("`J($!P87)A;2!I;G0@("`@
M("`D<F]W;G5M("`@('1H92!R;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER
M<W0@<F]W*0H@("`@("H*("`@("`J($!R971U<FX@;6EX960@($1"7T]+(&]N
M('-U8V-E<W,L($Y53$P@=VAE;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I
M<PH@("`@("H@("`@("`@("`@("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R
M90H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L
M("1F971C:&UO9&4L("1R;W=N=6T@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF
M("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@(&EF("@A0&9B<W%L
M7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@
M("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@
M("`@("`@("`@)&%R<B`]($!F8G-Q;%]F971C:%]A<G)A>2@D<F5S=6QT+"!&
M0E-13%]!4U-/0RD["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D
M87)R*2!["B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME
M>5]C87-E*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)&%R<B`]($!F8G-Q;%]F971C:%]R
M;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@
M*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)
M5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L
M=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-
M4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A
M;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT
M*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@86YD
M(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@
M8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H
M*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*
M("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G
M<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I
M;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("![
M"B`@("`@("`@<F5T=7)N($!F8G-Q;%]F<F5E7W)E<W5L="@D<F5S=6QT*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A=71O0V]M;6ET*"D*"B`@
M("`O*BH*("`@("`J($5N86)L97,@;W(@9&ES86)L97,@875T;VUA=&EC(&-O
M;6UI=',*("`@("`J"B`@("`@*B!`<&%R86T@8F]O;"`D;VYO9F8@('1R=64@
M='5R;G,@:70@;VXL(&9A;'-E('1U<FYS(&ET(&]F9@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@:68@=&AE(&1R:79E<@H@("`@("H@("`@("`@("`@("`@("!D;V5S
M;B=T('-U<'!O<G0@875T;RUC;VUM:71T:6YG('1R86YS86-T:6]N<RX*("`@
M("`J+PH@("`@9G5N8W1I;VX@875T;T-O;6UI="@D;VYO9F8]9F%L<V4I"B`@
M("!["B`@("`@("`@:68@*"1O;F]F9BD@>PH@("`@("`@("`@("`D=&AI<RT^
M<75E<GDH(E-%5"!#3TU-250@5%)512(I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1T:&ES+3YQ=65R>2@B4T54($-/34U)5"!&04Q312(I.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H
M*0H*("`@("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C
M=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!`9F)S<6Q?8V]M
M;6ET*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH
M*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C
M=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C
M97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@($!F8G-Q;%]R
M;VQL8F%C:R@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O
M;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M
M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@
M:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@
M("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E
M(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L
M="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L
M=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@
M/2!`9F)S<6Q?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C
M;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F)S<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S=6QT('-E=`H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C
M86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M4F]W
M<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D
M(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(
M4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN
M=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("1R;W=S(#T@0&9B<W%L7VYU;5]R;W=S*"1R97-U
M;'0I.PH@("`@("`@(&EF("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/F9B<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@869F96-T9612;W=S*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN
M97,@=&AE(&YU;6)E<B!O9B!R;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI
M=7!L871I;VX@<75E<GD*("`@("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O
M<B!Q=65R:65S('1H870@9&]N)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO
M;B!A9F9E8W1E9%)O=W,H*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI
M<"@D=&AI<RT^;&%S=%]Q=65R>2DI('L*("`@("`@("`@("`@)')E<W5L="`]
M($!F8G-Q;%]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S=6QT(#T@,#L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N
M8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E
M+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X
M:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU
M;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E
M3F%M92@I+`H@("`@("H@("`@("!$0E]F8G-Q;#HZ8W)E871E4V5Q=65N8V4H
M*2P@1$)?9F)S<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("![
M"B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S
M97%?;F%M92D["B`@("`@("`@9&\@>PH@("`@("`@("`@("`D<F5P96%T(#T@
M,#L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?
M15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ
M=65R>2@G4T5,14-4(%5.25%512!&4D]-("<@+B`D<V5Q;F%M92D["B`@("`@
M("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@
M(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@)B8*("`@
M("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E].
M3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](#$["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E
M*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@:68@*$1".CII<T5R<F]R
M*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9F)S<6Q2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("1R97-U;'0M/F9E=&-H
M26YT;R@D=&UP+"!$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@<F5T
M=7)N("1T;7!;,%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@
M;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q
M7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA
M;64H*2P*("`@("`J("`@("`@1$)?9F)S<6PZ.FYE>'1)1"@I+"!$0E]F8G-Q
M;#HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E
M4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@
M)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R
M97,@/2`D=&AI<RT^<75E<GDH)T-214%412!404),12`G("X@)'-E<6YA;64*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R`H:60@24Y414=%4B!.
M3U0@3E5,3"PG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@4%))
M34%262!+15DH:60I*2<I.PH@("`@("`@(&EF("@D<F5S*2!["B`@("`@("`@
M("`@("1R97,@/2`D=&AI<RT^<75E<GDH)U-%5"!53DE1544@/2`P($9/4B`G
M("X@)'-E<6YA;64I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*
M("`@("\J*@H@("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@
M("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E
M;F-E('1O(&)E(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC
M92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@
M("!$0E]F8G-Q;#HZ;F5X=$E$*"DL($1"7V9B<W%L.CIC<F5A=&5397%U96YC
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA
M;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!4
M04),12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@4D535%))0U0G*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y*"D*
M"B`@("`O*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E<R!T;R!A('%U97)Y
M('-T<FEN9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3('-T86YD87)D<PH@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE('%U97)Y
M('1O(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@("!T:&4@
M<F]W('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T(')O=RD*
M("`@("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E<G,@;V8@
M<F]W<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R86US("!A
M<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE
M('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N=&ET>2!O
M9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N;VXM87)R
M87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M971E<G,@
M;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W:71H($Q)
M34E4(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E
M8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U97)Y*"1Q
M=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI"B`@("![
M"B`@("`@("`@:68@*$1".CII<TUA;FEP*"1Q=65R>2DI('L*("`@("`@("`@
M("`@<F5T=7)N('!R96=?<F5P;&%C92@G+UXH6UQS*%TI*E-%3$5#5"]I)RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B7%PQ4T5,14-4(%1/
M4"@D8V]U;G0I(BP@)'%U97)Y*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@<')E9U]R97!L86-E*"<O*%M<<RA=*2I314Q%0U0O:2<L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(EQ<,5-%3$5#5"!4
M3U`H)&9R;VTL("1C;W5N="DB+"`D<75E<GDI.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-M87)T*"D*"B`@("`O*BH*
M("`@("`J($9O<FUA=',@:6YP=70@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D
M(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)&EN("!T
M:&4@9&%T82!T;R!B92!F;W)M871T960*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&UI>&5D("!T:&4@9F]R;6%T=&5D(&1A=&$N("!4:&4@9F]R;6%T(&1E<&5N
M9',@;VX@=&AE(&EN<'5T)W,*("`@("`J("`@("`@("`@("`@("`@("!02%`@
M='EP93H*("`@("`J("`@("`@("`@("`@("`@("`K(&YU;&P@/2!T:&4@<W1R
M:6YG(#QS86UP/DY53$P\+W-A;7`^"B`@("`@*B`@("`@("`@("`@("`@("`@
M*R!B;V]L96%N(#T@<W1R:6YG(#QS86UP/E12544\+W-A;7`^(&]R(#QS86UP
M/D9!3%-%/"]S86UP/@H@("`@("H@("`@("`@("`@("`@("`@("L@:6YT96=E
M<B!O<B!D;W5B;&4@/2!T:&4@=6YQ=6]T960@;G5M8F5R"B`@("`@*B`@("`@
M("`@("`@("`@("`@*R!O=&AE<B`H:6YC;'5D:6YG('-T<FEN9W,@86YD(&YU
M;65R:6,@<W1R:6YG<RD@/0H@("`@("H@("`@("`@("`@("`@("`@("`@=&AE
M(&1A=&$@97-C87!E9"!A8V-O<F1I;F<@=&\@1G)O;G1"87-E)W,@<V5T=&EN
M9W,*("`@("`J("`@("`@("`@("`@("`@("`@('1H96X@96YC87!S=6QA=&5D
M(&)E='=E96X@<VEN9VQE('%U;W1E<PH@("`@("H*("`@("`J($!S964@1$)?
M8V]M;6]N.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-971H;V0@879A
M:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75O=&53;6%R="@D:6XI"B`@("!["B`@("`@("`@:68@*&ES7VEN="@D
M:6XI('Q\(&ES7V1O=6)L92@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`D
M:6X["B`@("`@("`@?2!E;'-E:68@*&ES7V)O;VPH)&EN*2D@>PH@("`@("`@
M("`@("!R971U<FX@)&EN(#\@)U12544G(#H@)T9!3%-%)SL*("`@("`@("!]
M(&5L<V5I9B`H:7-?;G5L;"@D:6XI*2!["B`@("`@("`@("`@(')E='5R;B`G
M3E5,3"<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("(G
M(B`N("1T:&ES+3YE<V-A<&53:6UP;&4H)&EN*2`N("(G(CL*("`@("`@("!]
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9F)S<6Q286ES945R<F]R
M*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?17)R;W(@;V)J96-T
M(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@*@H@("`@("H@
M0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I<R!B96EN9R!M86YU
M86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI<R!I<VXG="!P87-S
M960*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE(&5R<F]R(&EN9F]R
M;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@("`@*@H@("`@("H@
M0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*("`@("`J"B`@
M("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@("`@("H@("`@
M("!$0E]F8G-Q;#HZ97)R;W).871I=F4H*2P@1$)?8V]M;6]N.CIE<G)O<D-O
M9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F8G-Q;%)A:7-E17)R;W(H)&5R
M<FYO(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&5R<FYO(#T]/2!N=6QL
M*2!["B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES+3YE<G)O<D-O9&4H9F)S
M<6Q?97)R;F\H)'1H:7,M/F-O;FYE8W1I;VXI*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L
M;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&9B
M<W%L7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*2D["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@
M1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@<')O9'5C960@8GD@
M=&AE(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE
M($1"35,G(&5R<F]R(&-O9&4*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).
M871I=F4H*0H@("`@>PH@("`@("`@(')E='5R;B!`9F)S<6Q?97)R;F\H)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('1A8FQE26YF;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T
M:6]N(&%B;W5T(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@
M("H@0'!A<F%M(&]B:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O
M8FIE8W0@9G)O;2!A('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@
M;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@5VAI;&4@=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S;W5R
M8V4@:61E;G1I9FEE<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@
M0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5)
M;F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O
M8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N
M"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5)
M;F9O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L
M("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R
M97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A
M8FQY(')E8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E
M871E(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@
M("`J+PH@("`@("`@("`@("`D:60@/2!`9F)S<6Q?;&ES=%]F:65L9',H)'1H
M:7,M/F1S;ELG9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1R97-U;'0L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@
M("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF
M("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@
M("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C
M="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@
M9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@
M("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@
M:61E;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@
M("`@("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL
M>2X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0[
M"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YF8G-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-
M3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%
M*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V
M86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0&9B<W%L7VYU;5]F
M:65L9',H)&ED*3L*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@
M("!I9B`H)&UO9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==
M(#T@)&-O=6YT.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@)&-O=6YT.R`D:2LK*2!["B`@("`@("`@("`@("1R97-;)&E=(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("1C87-E7V9U;F,H0&9B
M<W%L7V9I96QD7W1A8FQE*"1I9"P@)&DI*2P*("`@("`@("`@("`@("`@("=N
M86UE)R`@/3X@)&-A<V5?9G5N8RA`9F)S<6Q?9FEE;&1?;F%M92@D:60L("1I
M*2DL"B`@("`@("`@("`@("`@("`G='EP92<@(#T^($!F8G-Q;%]F:65L9%]T
M>7!E*"1I9"P@)&DI+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B!`9F)S
M<6Q?9FEE;&1?;&5N*"1I9"P@)&DI+`H@("`@("`@("`@("`@("`@)V9L86=S
M)R`]/B!`9F)S<6Q?9FEE;&1?9FQA9W,H)&ED+"`D:2DL"B`@("`@("`@("`@
M("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%
M4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG
M;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D
M;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@
M("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R
M97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY(&EF('=E('=E<F4@
M8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O=%]S=')I;F<I('L*
M("`@("`@("`@("`@0&9B<W%L7V9R965?<F5S=6QT*"1I9"D["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&=E=%-P96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A
M:6YS('1H92!Q=65R>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV
M96X@='EP92!O9B!O8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN
M9R`D='EP92`@=&AE(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R
M:65V90H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@4U%,('%U
M97)Y('-T<FEN9R!O<B!N=6QL(&EF('1H92!D<FEV97(@9&]E<VXG=`H@("`@
M("H@("`@("`@("`@("`@("`@("!S=7!P;W)T('1H92!O8FIE8W0@='EP92!R
M97%U97-T960*("`@("`J"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@
M("H@0'-E92!$0E]C;VUM;VXZ.F=E=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&=E=%-P96-I86Q1=65R>2@D='EP92D*("`@('L*("`@("`@("!S
M=VET8V@@*"1T>7!E*2!["B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@
M("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"`B=&%B;&5?;F%M92(@1E)/
M32!I;F9O<FUA=&EO;E]S8VAE;6$N=&%B;&5S)PH@("`@("`@("`@("`@("`@
M("`@("`@("X@)R!T,"P@:6YF;W)M871I;VY?<V-H96UA+G-C:&5M871A('0Q
M)PH@("`@("`@("`@("`@("`@("`@("`@("X@)R!72$5212!T,"YS8VAE;6%?
M<&L]=#$N<V-H96UA7W!K($%.1"<*("`@("`@("`@("`@("`@("`@("`@("`N
M("<@(G1A8FQE7W1Y<&4B(#T@7"="05-%(%1!0DQ%7"<G"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G($%.1"`B<V-H96UA7VYA;64B(#T@8W5R<F5N=%]S
M8VAE;6$G.PH@("`@("`@("`@("!C87-E("=V:65W<R<Z"B`@("`@("`@("`@
M("`@("!R971U<FX@)U-%3$5#5"`B=&%B;&5?;F%M92(@1E)/32!I;F9O<FUA
M=&EO;E]S8VAE;6$N=&%B;&5S)PH@("`@("`@("`@("`@("`@("`@("`@("X@
M)R!T,"P@:6YF;W)M871I;VY?<V-H96UA+G-C:&5M871A('0Q)PH@("`@("`@
M("`@("`@("`@("`@("`@("X@)R!72$5212!T,"YS8VAE;6%?<&L]=#$N<V-H
M96UA7W!K($%.1"<*("`@("`@("`@("`@("`@("`@("`@("`N("<@(G1A8FQE
M7W1Y<&4B(#T@7"=624577"<G"B`@("`@("`@("`@("`@("`@("`@("`@+B`G
M($%.1"`B<V-H96UA7VYA;64B(#T@8W5R<F5N=%]S8VAE;6$G.PH@("`@("`@
M("`@("!C87-E("=U<V5R<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%
M3$5#5"`B=7-E<E]N86UE(B!F<F]M(&EN9F]R;6%T:6]N7W-C:&5M82YU<V5R
M<R<[(`H@("`@("`@("`@("!C87-E("=F=6YC=&EO;G,G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N("=314Q%0U0@(G)O=71I;F5?;F%M92(@1E)/32<*("`@
M("`@("`@("`@("`@("`@("`@("`N("<@:6YF;W)M871I;VY?<V-H96UA+G!S
M;5]R;W5T:6YE<R<*("`@("`@("`@("`@("`@("`@("`@("`N("<@=#`L(&EN
M9F]R;6%T:6]N7W-C:&5M82YS8VAE;6%T82!T,2<*("`@("`@("`@("`@("`@
M("`@("`@("`N("<@5TA%4D4@=#`N<V-H96UA7W!K/70Q+G-C:&5M85]P:R<*
M("`@("`@("`@("`@("`@("`@("`@("`N("<@04Y$(")R;W5T:6YE7VMI;F0B
M/5PG1E5.0U1)3TY<)R<*("`@("`@("`@("`@("`@("`@("`@("`N("<@04Y$
M(")S8VAE;6%?;F%M92(@/2!C=7)R96YT7W-C:&5M82<["B`@("`@("`@("`@
M(&-A<V4@)W!R;V-E9'5R97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N("=3
M14Q%0U0@(G)O=71I;F5?;F%M92(@1E)/32<*("`@("`@("`@("`@("`@("`@
M("`@("`N("<@:6YF;W)M871I;VY?<V-H96UA+G!S;5]R;W5T:6YE<R<*("`@
M("`@("`@("`@("`@("`@("`@("`N("<@=#`L(&EN9F]R;6%T:6]N7W-C:&5M
M82YS8VAE;6%T82!T,2<*("`@("`@("`@("`@("`@("`@("`@("`N("<@5TA%
M4D4@=#`N<V-H96UA7W!K/70Q+G-C:&5M85]P:R<*("`@("`@("`@("`@("`@
M("`@("`@("`N("<@04Y$(")R;W5T:6YE7VMI;F0B/5PG4%)/0T5$55)%7"<G
M"B`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.1"`B<V-H96UA7VYA;64B
M(#T@8W5R<F5N=%]S8VAE;6$G.PH@("`@("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@
M("\O('U]?0I]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T
M:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O:6)A<V4N<&AP````
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#$P,34T
M,"`Q,#4Q-30S-#$S,R`P,C`U-#,`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A
M8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO
M*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!I;G1E<F)A<V4@
M97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H($EN=&5R8F%S92!A
M;F0@1FER96)I<F0@9&%T86)A<V5S"B`J"B`J(%=H:6QE('1H:7,@8VQA<W,@
M=V]R:W,@=VET:"!02%`@-"P@4$A0)W,@26YT97)"87-E(&5X=&5N<VEO;B!I
M<PH@*B!U;G-T86)L92!I;B!02%`@-"X@(%5S92!02%`@-2X*("H*("H@4$A0
M('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC
M96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP
M:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L
M92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N
M9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B
M87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T97)L:6YG
M($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&EB87-E+G!H<"QV(#$N,3`Y
M(#(P,#4O,#,O,#0@,C,Z,3(Z,S8@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO*BH*
M("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E(&5X
M=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H<"<[
M"@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R86-T
M('=I=&@@4$A0)W,@:6YT97)B87-E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A
M8W1I;F<@=VET:"!);G1E<F)A<V4@86YD($9I<F5B:7)D(&1A=&%B87-E<PH@
M*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D
M(&EN($1"7V-O;6UO;BX*("H*("H@5VAI;&4@=&AI<R!C;&%S<R!W;W)K<R!W
M:71H(%!(4"`T+"!02%`G<R!);G1E<D)A<V4@97AT96YS:6]N(&ES"B`J('5N
M<W1A8FQE(&EN(%!(4"`T+B`@57-E(%!(4"`U+@H@*@H@*B!.3U1)0T4Z("!L
M:6UI=%%U97)Y*"D@;VYL>2!W;W)K<R!F;W(@1FER96)I<F0N"B`J"B`J($!C
M871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H
M;W(@("`@(%-T97)L:6YG($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("H@
M0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW
M+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1""B`J($!S:6YC92`@("`@($-L87-S(&)E8V%M92!S=&%B;&4@:6X@4F5L
M96%S92`Q+C<N,`H@*B\*8VQA<W,@1$)?:6)A<V4@97AT96YD<R!$0E]C;VUM
M;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H
M92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G
M:6)A<V4G.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V
M87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N*2P@:68@86YY
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&1B<WEN=&%X
M(#T@)VEB87-E)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@
M;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G
M;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H
M870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R
M('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T
M960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M
M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C
M:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@
M=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@
M("`@*@H@("`@("H@3D]413H@;VYL>2!F:7)E8FER9"!S=7!P;W)T<R!L:6UI
M="X*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("=N=6UR;W=S)R`@("`@("`]/B`G96UU;&%T92<L"B`@("`@("`@)W!C
M;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@
M(#T^('1R=64L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@
M("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@("`O
M*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@
M1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@+3$P-"`]/B!$
M0E]%4E)/4E]364Y405@L"B`@("`@("`@+3$U,"`]/B!$0E]%4E)/4E]!0T-%
M4U-?5DE/3$%424].+`H@("`@("`@("TQ-3$@/3X@1$)?15)23U)?04-#15-3
M7U9)3TQ!5$E/3BP*("`@("`@("`M,34U(#T^($1"7T524D]27TY/4U5#2%1!
M0DQ%+`H@("`@("`@("TQ-3<@/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@
M("`@("`@+3$U."`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@
M("`@("`@+3$W,"`]/B!$0E]%4E)/4E]-25--051#2"P*("`@("`@("`M,3<Q
M(#T^($1"7T524D]27TU)4TU!5$-(+`H@("`@("`@("TQ-S(@/3X@1$)?15)2
M3U)?24Y604Q)1"P*("`@("`@("`O+R`M,C`T(#T^("`O+R!#;W9E<G,@=&]O
M(&UA;GD@97)R;W)S+"!N965D('1O('5S92!R96=E>"!O;B!M<V<*("`@("`@
M("`M,C`U(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("TR,#8@
M/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@+3(P."`]/B!$0E]%
M4E)/4E])3E9!3$E$+`H@("`@("`@("TR,3D@/3X@1$)?15)23U)?3D]354-(
M5$%"3$4L"B`@("`@("`@+3(Y-R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@
M("`@("`@("TS,#,@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`M-#$S
M(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("TU,S`@/3X@
M1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`M-34Q(#T^($1"7T524D]2
M7T%#0T534U]624],051)3TXL"B`@("`@("`@+34U,B`]/B!$0E]%4E)/4E]!
M0T-%4U-?5DE/3$%424].+`H@("`@("`@("\O("TV,#<@/3X@("\O($-O=F5R
M<R!T;V\@;6%N>2!E<G)O<G,L(&YE960@=&\@=7-E(')E9V5X(&]N(&US9PH@
M("`@("`@("TV,C4@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*
M("`@("`@("`M.#`S(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@
M+3@P-"`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@
M+3DP-"`]/B!$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@("`M.3(R
M(#T^($1"7T524D]27TY/4U5#2$1"+`H@("`@("`@("TY,C,@/3X@1$)?15)2
M3U)?0T].3D5#5%]&04E,140L"B`@("`@("`@+3DR-"`]/B!$0E]%4E)/4E]#
M3TY.14-47T9!24Q%1`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@
M9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A
M<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@
M+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG
M('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J(%1H92!N=6UB
M97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:7!U;&%T:6]N('%U
M97)Y"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)&%F9F5C=&5D(#T@,#L*"B`@("`O*BH*("`@
M("`J(%-H;W5L9"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI
M='1E9"!A=71O;6%T:6-A;&QY/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@
M=')U93L*"B`@("`O*BH*("`@("`J(%1H92!P<F5P87)E9"!S=&%T96UE;G0@
M:&%N9&QE(&9R;VT@=&AE(&UO<W0@<F5C96YT;'D@97AE8W5T960@<W1A=&5M
M96YT"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"`@36%I;FQY(&AE<F4@8F5C
M875S92!T:&4@26YT97)"87-E+T9I<F5B:7)D($%022!I<R!O;FQY"B`@("`@
M*B!A8FQE('1O(')E=')I979E(&1A=&$@9G)O;2!R97-U;'0@<V5T<R!I9B!T
M:&4@<W1A=&5M;G0@:&%N9&QE(&ES"B`@("`@*B!S=&EL;"!I;B!S8V]P92Y]
M?0H@("`@("H*("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R
M("1L87-T7W-T;70["@H@("`@+RHJ"B`@("`@*B!)<R!T:&4@9VEV96X@<')E
M<&%R960@<W1A=&5M96YT(&$@9&%T82!M86YI<'5L871I;VX@<75E<GD_"B`@
M("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J
M+PH@("`@=F%R("1M86YI<%]Q=65R>2`](&%R<F%Y*"D["@H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES
M(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K
M8F0^"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U
M;F-T:6]N($1"7VEB87-E*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M
M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I
M"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V
M97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@
M*B!$;VXG="!C86QL('1H:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC
M;VYN96-T*"D@:6YS=&5A9"X*("`@("`J"B`@("`@*B!014%2($1")W,@:6)A
M<V4@9')I=F5R('-U<'!O<G1S('1H92!F;VQL;W=I;F<@97AT<F$@1%-.(&]P
M=&EO;G,Z"B`@("`@*B`@("L@8G5F9F5R<R`@("!4:&4@;G5M8F5R(&]F(&1A
M=&%B87-E(&)U9F9E<G,@=&\@86QL;V-A=&4@9F]R('1H90H@("`@("H@("`@
M("`@("`@("`@("`@('-E<G9E<BUS:61E(&-A8VAE+@H@("`@("H@("`K(&-H
M87)S970@("`@5&AE(&1E9F%U;'0@8VAA<F%C=&5R('-E="!F;W(@82!D871A
M8F%S92X*("`@("`J("`@*R!D:6%L96-T("`@(%1H92!D969A=6QT(%-13"!D
M:6%L96-T(&9O<B!A;GD@<W1A=&5M96YT"B`@("`@*B`@("`@("`@("`@("`@
M("`@97AE8W5T960@=VET:&EN(&$@8V]N;F5C=&EO;BX@($1E9F%U;'1S('1O
M('1H90H@("`@("H@("`@("`@("`@("`@("`@(&AI9VAE<W0@;VYE('-U<'!O
M<G1E9"!B>2!C;&EE;G0@;&EB<F%R:65S+@H@("`@("H@("`@("`@("`@("`@
M("`@($9U;F-T:6]N86P@;VYL>2!W:71H($EN=&5R0F%S92`V(&%N9"!U<"X*
M("`@("`J("`@*R!R;VQE("`@("`@($9U;F-T:6]N86P@;VYL>2!W:71H($EN
M=&5R0F%S92`U(&%N9"!U<"X*("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@
M)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@*B!`<&%R
M86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C=&EO;B!B
M92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/
M2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T96YT
M(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D17AT96YS
M:6]N*"=I;G1E<F)A<V4G*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D["B`@
M("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@("!I
M9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^9&)S
M>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*("`@("`@("!I
M9B`H)'1H:7,M/F1B<WEN=&%X(#T]("=F:7)E8FER9"<I('L*("`@("`@("`@
M("`@)'1H:7,M/F9E871U<F5S6R=L:6UI="==(#T@)V%L=&5R)SL*("`@("`@
M("!]"@H@("`@("`@("1P87)A;7,@/2!A<G)A>2@*("`@("`@("`@("`@)&1S
M;ELG:&]S='-P96,G70H@("`@("`@("`@("`@("`@("`@(#\@*"1D<VY;)VAO
M<W1S<&5C)UT@+B`G.B<@+B`D9'-N6R=D871A8F%S92==*0H@("`@("`@("`@
M("`@("`@("`@(#H@)&1S;ELG9&%T86)A<V4G72P*("`@("`@("`@("`@)&1S
M;ELG=7-E<FYA;64G72`_("1D<VY;)W5S97)N86UE)UT@.B!N=6QL+`H@("`@
M("`@("`@("`D9'-N6R=P87-S=V]R9"==(#\@)&1S;ELG<&%S<W=O<F0G72`Z
M(&YU;&PL"B`@("`@("`@("`@(&ES<V5T*"1D<VY;)V-H87)S970G72D@/R`D
M9'-N6R=C:&%R<V5T)UT@.B!N=6QL+`H@("`@("`@("`@("!I<W-E="@D9'-N
M6R=B=69F97)S)UTI(#\@)&1S;ELG8G5F9F5R<R==(#H@;G5L;"P*("`@("`@
M("`@("`@:7-S970H)&1S;ELG9&EA;&5C="==*2`_("1D<VY;)V1I86QE8W0G
M72`Z(&YU;&PL"B`@("`@("`@("`@(&ES<V5T*"1D<VY;)W)O;&4G72D@("`@
M/R`D9'-N6R=R;VQE)UT@.B!N=6QL+`H@("`@("`@("D["@H@("`@("`@("1C
M;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G:6)A<V5?<&-O;FYE
M8W0G(#H@)VEB87-E7V-O;FYE8W0G.PH*("`@("`@("`D=&AI<RT^8V]N;F5C
M=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO
M;BP@)'!A<F%M<RD["B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O<BA$
M0E]%4E)/4E]#3TY.14-47T9!24Q%1"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C
M;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE
M(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@
M5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`
M:6)A<V5?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES
M+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)')E=#L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@
M+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V
M97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y
M('-T<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@
M<F5S=6QT(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S
M"B`@("`@*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F
M;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@
M("`@("`K(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@
M("`@9G5N8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@
M("1I<VUA;FEP(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI
M<RT^;&%S=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI
M<RT^;6]D:69Y475E<GDH)'%U97)Y*3L*("`@("`@("`D<F5S=6QT(#T@0&EB
M87-E7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`D<75E<GDI.PH*("`@("`@
M("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI
M8F%S95)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3YA=71O8V]M;6ET("8F("1I<VUA;FEP*2!["B`@("`@("`@("`@($!I8F%S
M95]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('T*("`@("`@
M("!I9B`H)&ES;6%N:7`I('L*("`@("`@("`@("`@)'1H:7,M/F%F9F5C=&5D
M(#T@)')E<W5L=#L*("`@("`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YA9F9E8W1E9"`](#`["B`@
M("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U97)Y*"D*"B`@("`O
M*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E<R!T;R!A('%U97)Y('-T<FEN
M9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3('-T86YD87)D<PH@("`@("H*
M("`@("`J($]N;'D@=V]R:W,@=VET:"!&:7)E8FER9"X*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*
M("`@("`J($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R
M="!T;R!F971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R
M86T@:6YT("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T
M8V@*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN
M9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N
M("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD
M97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@
M(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H
M;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R
M;B!S=')I;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U<V5S
M(&%D9&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J
M+PH@("`@9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M
M+"`D8V]U;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^9'-N6R=D8G-Y;G1A>"==(#T]("=F:7)E8FER9"<I('L*("`@
M("`@("`@("`@)'%U97)Y(#T@<')E9U]R97!L86-E*"<O7BA;7',H72DJ4T5,
M14-4+VDG+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(E-%
M3$5#5"!&25)35"`D8V]U;G0@4TM)4"`D9G)O;2(L("1Q=65R>2D["B`@("`@
M("`@?0H@("`@("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E
M('1H92!I;G1E<FYA;"!I8F%S92!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X
M="!A=F%I;&%B;&4@<F5S=6QT"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L
M:60@9F)S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("`J"B`@("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U
M;'0@:7,@879A:6QA8FQE(&]T:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J
M+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@
M("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R
M;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@9VEV96X@87)R87D*("`@("`J
M"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T
M:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3964@1$)?<F5S=6QT
M.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN
M<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@
M("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@
M("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@("`@=&AE('%U
M97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@0'!A<F%M(&%R<F%Y("`@("1A
M<G(@("`@("`@=&AE(')E9F5R96YC960@87)R87D@=&\@<'5T('1H92!D871A
M(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@)&9E=&-H;6]D92!H;W<@=&AE
M(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE9`H@("`@("H@0'!A
M<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE(')O=R!N=6UB97(@=&\@9F5T
M8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE
M9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H92!E;F0@;V8@82!R
M97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@<F5A8VAE9"!O
M<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S
M=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;2`](&YU;&PI"B`@("![
M"B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI('L*("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E17)R;W(H1$)?15)23U)?3D]47T-!
M4$%"3$4I.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"
M7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@("!I9B`H9G5N8W1I;VY?
M97AI<W1S*"=I8F%S95]F971C:%]A<W-O8R<I*2!["B`@("`@("`@("`@("`@
M("`D87)R(#T@0&EB87-E7V9E=&-H7V%S<V]C*"1R97-U;'0I.PH@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&%R<B`](&=E=%]O8FIE
M8W1?=F%R<RAI8F%S95]F971C:%]O8FIE8W0H)')E<W5L="DI.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312`F)B`D87)R*2![
M"B`@("`@("`@("`@("`@("`D87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E
M*"1A<G(L($-!4T5?3$]715(I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&%R<B`]($!I8F%S95]F971C:%]R;W<H)')E
M<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R<BD@>PH@("`@("`@
M("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES
M+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?4E12
M24TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S*"1A
M<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O
M<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19*2![
M"B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E<U1O
M16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT*"D*"B`@
M("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@86YD(&9R965S
M('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*("`@("`J
M"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D
M(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@
M(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I;G9A;&ED
M"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@
M("`@<F5T=7)N($!I8F%S95]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E475E<GDH*0H*("`@(&9U;F-T
M:6]N(&9R9651=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@0&EB87-E7V9R
M965?<75E<GDH)'%U97)Y*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J
M*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T
M960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J
M(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L
M871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB
M97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@
M("`@:68@*&ES7VEN=&5G97(H)'1H:7,M/F%F9F5C=&5D*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/F%F9F5C=&5D.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?
M0T%004),12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L
M<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@8V]L=6UN
M<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I
M<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@
M*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@
M9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT
M(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R
M97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU
M;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@
M("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@("`D8V]L<R`]
M($!I8F%S95]N=6U?9FEE;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O
M;',I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E17)R
M;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('!R97!A<F4H*0H*("`@("\J*@H@("`@
M("H@4')E<&%R97,@82!Q=65R>2!F;W(@;75L=&EP;&4@97AE8W5T:6]N('=I
M=&@@97AE8W5T92@I+@H@("`@("H*("`@("`J('!R97!A<F4H*2!R97%U:7)E
M<R!A(&=E;F5R:6,@<75E<GD@87,@<W1R:6YG(&QI:V4@/&-O9&4^"B`@("`@
M*B`@("!)3E-%4E0@24Y43R!N=6UB97)S(%9!3%5%4R`H/RP@/RP@/RD*("`@
M("`J(#PO8V]D93XN("!4:&4@/&MB9#X_/"]K8F0^(&-H87)A8W1E<G,@87)E
M('!L86-E:&]L9&5R<RX*("`@("`J"B`@("`@*B!4:')E92!T>7!E<R!O9B!P
M;&%C96AO;&1E<G,@8V%N(&)E('5S960Z"B`@("`@*B`@("L@/&MB9#X_/"]K
M8F0^("!A('%U;W1E9"!S8V%L87(@=F%L=64L(&DN92X@<W1R:6YG<RP@:6YT
M96=E<G,*("`@("`J("`@*R`\:V)D/B$\+VMB9#X@('9A;'5E(&ES(&EN<V5R
M=&5D("=A<R!I<R<*("`@("`J("`@*R`\:V)D/B8\+VMB9#X@(')E<75I<F5S
M(&$@9FEL92!N86UE+B`@5&AE(&9I;&4G<R!C;VYT96YT<R!G970*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@:6YS97)T960@:6YT;R!T:&4@<75E<GD@
M*&DN92X@<V%V:6YG(&)I;F%R>0H@("`@("H@("`@("`@("`@("`@("`@("`@
M("!D871A(&EN(&$@9&(I"B`@("`@*@H@("`@("H@57-E(&)A8VMS;&%S:&5S
M('1O(&5S8V%P92!P;&%C96AO;&1E<B!C:&%R86-T97)S(&EF('EO=2!D;VXG
M="!W86YT"B`@("`@*B!T:&5M('1O(&)E(&EN=&5R<')E=&5D(&%S('!L86-E
M:&]L9&5R<RX@($5X86UP;&4Z(#QC;V1E/@H@("`@("H@("`@(E501$%412!F
M;V\@4T54(&-O;#T_(%=(15)%(&-O;#TG;W9E<B!<)B!U;F1E<B<B"B`@("`@
M*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@
M<75E<GD@=&\@8F4@<')E<&%R960*("`@("`J($!R971U<FX@;6EX960@1$(@
M<W1A=&5M96YT(')E<V]U<F-E(&]N('-U8V-E<W,N($1"7T5R<F]R(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N('!R97!A<F4H)'%U97)Y*0H@
M("`@>PH@("`@("`@("1T;VME;G,@("`]('!R96=?<W!L:70H)R\H*#\\(5Q<
M7"E;)C\A72DO)RP@)'%U97)Y+"`M,2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%!214=?4U!,251?1$5,24U?0T%05%5212D["B`@("`@("`@
M)'1O:V5N("`@(#T@,#L*("`@("`@("`D='EP97,@("`@/2!A<G)A>2@I.PH@
M("`@("`@("1N97=Q=65R>2`]("<G.PH*("`@("`@("!F;W)E86-H("@D=&]K
M96YS(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1V
M86PI('L*("`@("`@("`@("`@("`@(&-A<V4@)S\G.@H@("`@("`@("`@("`@
M("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]30T%,05(["B`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E
M("<F)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@
M1$)?4$%204U?3U!!455%.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@8V%S92`G(2<Z"B`@("`@("`@("`@("`@("`@("`@
M)'1Y<&5S6R1T;VME;BLK72`]($1"7U!!4D%-7TU)4T,["B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@
M("`@("`@("`@("`@("`@("1T;VME;G-;)&ME>5T@/2!P<F5G7W)E<&QA8V4H
M)R]<7%PH6R8_(5TI+R<L(")<7#$B+"`D=F%L*3L*("`@("`@("`@("`@("`@
M("`@("`D;F5W<75E<GD@+CT@)'1O:V5N<ULD:V5Y72`N("<_)SL*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&YE=W%U97)Y(#T@<W5B<W1R
M*"1N97=Q=65R>2P@,"P@+3$I.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y
M(#T@)'%U97)Y.PH@("`@("`@("1N97=Q=65R>2`]("1T:&ES+3YM;V1I9GE1
M=65R>2@D;F5W<75E<GDI.PH@("`@("`@("1S=&UT(#T@0&EB87-E7W!R97!A
M<F4H)'1H:7,M/F-O;FYE8W1I;VXL("1N97=Q=65R>2D["B`@("`@("`@)'1H
M:7,M/G!R97!A<F5?='EP97-;*&EN="DD<W1M=%T@/2`D='EP97,["B`@("`@
M("`@)'1H:7,M/FUA;FEP7W%U97)Y6RAI;G0I)'-T;71=("`@/2!$0CHZ:7--
M86YI<"@D<75E<GDI.PH@("`@("`@(')E='5R;B`D<W1M=#L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!E>&5C=71E*"D*"B`@("`O*BH*("`@("`J
M($5X96-U=&5S(&$@1$(@<W1A=&5M96YT('!R97!A<F5D('=I=&@@<')E<&%R
M92@I+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`@)'-T;70@(&$@
M1$(@<W1A=&5M96YT(')E<V]U<F-E(')E='5R;F5D(&9R;VT@<')E<&%R92@I
M"B`@("`@*B!`<&%R86T@;6EX960@("1D871A("!A<G)A>2P@<W1R:6YG(&]R
M(&YU;65R:6,@9&%T82!T;R!B92!U<V5D(&EN"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("!E>&5C=71I;VX@;V8@=&AE('-T871E;65N="X@(%%U86YT
M:71Y(&]F(&ET96US"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!P87-S
M960@;75S="!M871C:"!Q=6%N=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q(&9O
M<B!N;VXM87)R87D@:71E;7,@;W(@=&AE"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!Q=6%N=&ET>2!O9B!E;&5M96YT<R!I;B!T:&4@87)R87DN"B`@
M("`@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@1$)?4F5S=6QT(&]R(&$@1$)?
M17)R;W(@=VAE;B!F86EL"B`@("`@*B!`<V5E($1"7VEB87-E.CIP<F5P87)E
M*"D*("`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N
M("9E>&5C=71E*"1S=&UT+"`D9&%T82`](&%R<F%Y*"DI"B`@("!["B`@("`@
M("`@)&1A=&$@/2`H87)R87DI)&1A=&$["B`@("`@("`@)'1H:7,M/FQA<W1?
M<&%R86UE=&5R<R`]("1D871A.PH*("`@("`@("`D='EP97,@/28@)'1H:7,M
M/G!R97!A<F5?='EP97-;*&EN="DD<W1M=%T["B`@("`@("`@:68@*&-O=6YT
M*"1T>7!E<RD@(3T@8V]U;G0H)&1A=&$I*2!["B`@("`@("`@("`@("1T;7`@
M/28@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?34E334%40T@I.PH@("`@
M("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("!]"@H@("`@("`@("1I(#T@
M,#L*("`@("`@("!F;W)E86-H("@D9&%T82!A<R`D:V5Y(#T^("1V86QU92D@
M>PH@("`@("`@("`@("!I9B`H)'1Y<&5S6R1I72`]/2!$0E]005)!35]-25-#
M*2!["B`@("`@("`@("`@("`@("`O*@H@("`@("`@("`@("`@("`@("H@:6)A
M<V4@9&]E<VXG="!S965M('1O(&AA=F4@=&AE(&%B:6QI='D@=&\@<&%S<R!A
M"B`@("`@("`@("`@("`@("`@*B!P87)A;65T97(@86QO;F<@=6YC:&%N9V5D
M+"!S;R!S=')I<"!O9F8@<75O=&5S(&9R;VT@<W1A<G0*("`@("`@("`@("`@
M("`@("`J(&%N9"!E;F0L('!L=7,@='5R;B!T=V\@<VEN9VQE('%U;W1E<R!T
M;R!O;F4@<VEN9VQE('%U;W1E+`H@("`@("`@("`@("`@("`@("H@:6X@;W)D
M97(@=&\@879O:60@=&AE('%U;W1E<R!G971T:6YG(&5S8V%P960@8GD*("`@
M("`@("`@("`@("`@("`J(&EB87-E(&%N9"!E;F1I;F<@=7`@:6X@=&AE(&1A
M=&%B87-E+@H@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@("`D
M9&%T85LD:V5Y72`]('!R96=?<F5P;&%C92@B+UXG*"XJ*2<D+R(L(")<7#$B
M+"`D9&%T85LD:V5Y72D["B`@("`@("`@("`@("`@("`D9&%T85LD:V5Y72`]
M('-T<E]R97!L86-E*"(G)R(L("(G(BP@)&1A=&%;)&ME>5TI.PH@("`@("`@
M("`@("!](&5L<V5I9B`H)'1Y<&5S6R1I72`]/2!$0E]005)!35]/4$%1544I
M('L*("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D9&%T85LD:V5Y72P@
M)W)B)RD["B`@("`@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T;7`@/28@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?
M04-#15-37U9)3TQ!5$E/3BD["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T;7`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9&%T
M85LD:V5Y72`](&9R96%D*"1F<"P@9FEL97-I>F4H)&1A=&%;)&ME>5TI*3L*
M("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1I*RL["B`@("`@("`@?0H*("`@("`@("!A<G)A>5]U;G-H
M:69T*"1D871A+"`D<W1M="D["@H@("`@("`@("1R97,@/2!C86QL7W5S97)?
M9G5N8U]A<G)A>2@G:6)A<V5?97AE8W5T92<L("1D871A*3L*("`@("`@("!I
M9B`H(21R97,I('L*("`@("`@("`@("`@)'1M<"`])B`D=&AI<RT^:6)A<V52
M86ES945R<F]R*"D["B`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@
M('T*("`@("`@("`O*B!86%@@;F5E9"!T:&ES/PH@("`@("`@(&EF("@D=&AI
M<RT^875T;V-O;6UI="`F)B`D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD<W1M
M=%TI('L*("`@("`@("`@("`@0&EB87-E7V-O;6UI="@D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@?2HO"B`@("`@("`@)'1H:7,M/FQA<W1?<W1M="`]
M("1S=&UT.PH@("`@("`@(&EF("@D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD
M<W1M=%TI('L*("`@("`@("`@("`@)'1M<"`]($1"7T]+.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1T;7`@/28@;F5W($1"7W)E<W5L="@D=&AI
M<RP@)')E<RD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&UP.PH@("`@
M?0H*("`@("\J*@H@("`@("H@1G)E97,@=&AE(&EN=&5R;F%L(')E<V]U<F-E
M<R!A<W-O8VEA=&5D('=I=&@@82!P<F5P87)E9"!Q=65R>0H@("`@("H*("`@
M("`J($!P87)A;2!R97-O=7)C92`D<W1M="`@("`@("`@("`@=&AE('!R97!A
M<F5D('-T871E;65N="=S(%!(4"!R97-O=7)C90H@("`@("H@0'!A<F%M(&)O
M;VP@("`@("1F<F5E7W)E<V]U<F-E("!S:&]U;&0@=&AE(%!(4"!R97-O=7)C
M92!B92!F<F5E9"!T;V\_"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!5<V4@9F%L<V4@:68@>6]U(&YE960@=&\@9V5T(&1A=&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&9R;VT@
M=&AE(')E<W5L="!S970@;&%T97(N"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV
M86QI9`H@("`@("H*("`@("`J($!S964@1$)?:6)A<V4Z.G!R97!A<F4H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4')E<&%R960H)'-T;70L("1F<F5E
M7W)E<V]U<F-E(#T@=')U92D*("`@('L*("`@("`@("!I9B`H(6ES7W)E<V]U
M<F-E*"1S=&UT*2D@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?0H@("`@("`@(&EF("@D9G)E95]R97-O=7)C92D@>PH@("`@("`@("`@
M("!`:6)A<V5?9G)E95]Q=65R>2@D<W1M="D["B`@("`@("`@?0H@("`@("`@
M('5N<V5T*"1T:&ES+3YP<F5P87)E7W1O:V5N<ULH:6YT*21S=&UT72D["B`@
M("`@("`@=6YS970H)'1H:7,M/G!R97!A<F5?='EP97-;*&EN="DD<W1M=%TI
M.PH@("`@("`@('5N<V5T*"1T:&ES+3YM86YI<%]Q=65R>5LH:6YT*21S=&UT
M72D["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S
M(&]R(&1I<V%B;&5S(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@
M0'!A<F%M(&)O;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T
M=7)N<R!I="!O9F8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*
M("`@("`J("`@("`@("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M
M;6ET=&EN9R!T<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U
M=&]#;VUM:70H)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@)'1H:7,M
M/F%U=&]C;VUM:70@/2`D;VYO9F8@/R`Q(#H@,#L*("`@("`@("!R971U<FX@
M1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*
M"B`@("`O*BH*("`@("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I
M;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S
M<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@<F5T=7)N($!I8F%S
M95]C;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)E=F5R
M=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*
M("`@('L*("`@("`@("!R971U<FX@0&EB87-E7W)O;&QB86-K*"1T:&ES+3YC
M;VYN96-T:6]N*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T<F%N
M<V%C=&EO;DEN:70H*0H*("`@(&9U;F-T:6]N('1R86YS86-T:6]N26YI="@D
M=')A;G-?87)G<R`](#`I"B`@("!["B`@("`@("`@<F5T=7)N("1T<F%N<U]A
M<F=S"B`@("`@("`@("`@("`@("`_($!I8F%S95]T<F%N<R@D=')A;G-?87)G
M<RP@)'1H:7,M/F-O;FYE8W1I;VXI"B`@("`@("`@("`@("`@("`Z($!I8F%S
M95]T<F%N<R@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)
M9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@
M:6X@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S
M97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B
M;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A
M=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N
M8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N
M(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)
M1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@
M("!$0E]I8F%S93HZ8W)E871E4V5Q=65N8V4H*2P@1$)?:6)A<V4Z.F1R;W!3
M97%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA
M;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@)'-Q;B`]('-T
M<G1O=7!P97(H)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*
M("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("!D;R!["B`@("`@("`@("`@
M("1T:&ES+3YP=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD[
M"B`@("`@("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@
M1T5.7TE$*"1[<W%N?2P@,2D@(@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)T923TT@4D1")$=%3D52051/4E,@)PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@(E=(15)%(%)$0EPD1T5.15)!
M5$]27TY!344])R1[<W%N?2<B*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R
M<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1O;F1E;6%N9"`F)B!$
M0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@)')E<&5A
M="`](#$["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T
M95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)')E<W5L=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)&%R
M<B`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*
M("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@<F5T=7)N("1A<G);
M,%T["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8W)E871E4V5Q=65N
M8V4H*0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F
M('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E
M;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@
M("`@($1"7VEB87-E.CIN97AT240H*2P@1$)?:6)A<V4Z.F1R;W!397%U96YC
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?
M;F%M92D*("`@('L*("`@("`@("`D<W%N(#T@<W1R=&]U<'!E<B@D=&AI<RT^
M9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI.PH@("`@("`@("1T:&ES+3YP
M=7-H17)R;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YQ=65R>2@B0U)%051%($=%3D52051/4B`D>W-Q
M;GTB*3L*("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH*("`@
M("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!A
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E(&1E;&5T960*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E
M;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]I8F%S93HZ;F5X=$E$*"DL($1"
M7VEB87-E.CIC<F5A=&5397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&1R;W!397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YQ=65R>2@G1$5,151%($923TT@4D1")$=%3D52051/4E,@)PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`B5TA%4D4@4D1"7"1'14Y%
M4D%43U)?3D%-13TG(@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B!S
M=')T;W5P<&5R*"1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*2D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@(B<B*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!?:6)A<V5&:65L9$9L86=S*"D*"B`@("`O
M*BH*("`@("`J($=E="!T:&4@8V]L=6UN)W,@9FQA9W,*("`@("`J"B`@("`@
M*B!3=7!P;W)T<R`B<')I;6%R>5]K97DB+"`B=6YI<75E7VME>2(L(")N;W1?
M;G5L;"(L(")D969A=6QT(BP*("`@("`J(")C;VUP=71E9"(@86YD(")B;&]B
M(BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1F:65L9%]N86UE("!T
M:&4@;F%M92!O9B!T:&4@9FEE;&0*("`@("`J($!P87)A;2!S=')I;F<@)'1A
M8FQE7VYA;64@('1H92!N86UE(&]F('1H92!T86)L90H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!T:&4@9FQA9W,*("`@("`J"B`@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7VEB87-E1FEE;&1&
M;&%G<R@D9FEE;&1?;F%M92P@)'1A8FQE7VYA;64I"B`@("!["B`@("`@("`@
M)'-Q;"`]("=314Q%0U0@4BY21$(D0T].4U1204E.5%]465!%($-465!%)PH@
M("`@("`@("`@("`@("`N)R!&4D]-(%)$0B1)3D1%6%]314=-14Y44R!))PH@
M("`@("`@("`@("`@("`N)R`@2D])3B!21$(D4D5,051)3TY?0T].4U1204E.
M5%,@4B!/3B!)+E)$0B1)3D1%6%].04U%/5(N4D1")$E.1$587TY!344G"B`@
M("`@("`@("`@("`@("XG(%=(15)%($DN4D1")$9)14Q$7TY!344]7"<G("X@
M)&9I96QD7VYA;64@+B`G7"<G"B`@("`@("`@("`@("`@("XG("!!3D0@55!0
M15(H4BY21$(D4D5,051)3TY?3D%-12D]7"<G("X@<W1R=&]U<'!E<B@D=&%B
M;&5?;F%M92D@+B`G7"<G.PH*("`@("`@("`D<F5S=6QT(#T@0&EB87-E7W%U
M97)Y*"1T:&ES+3YC;VYN96-T:6]N+"`D<W%L*3L*("`@("`@("!I9B`H(21R
M97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI8F%S95)A:7-E
M17)R;W(H*3L*("`@("`@("!]"@H@("`@("`@("1F;&%G<R`]("<G.PH@("`@
M("`@(&EF("@D;V)J(#T@0&EB87-E7V9E=&-H7V]B:F5C="@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("!`:6)A<V5?9G)E95]R97-U;'0H)')E<W5L="D["B`@
M("`@("`@("`@(&EF("AI<W-E="@D;V)J+3Y#5%E012D@("8F('1R:6TH)&]B
M:BT^0U194$4I(#T]("=04DE-05)9($M%62<I('L*("`@("`@("`@("`@("`@
M("1F;&%G<R`N/2`G<')I;6%R>5]K97D@)SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)&]B:BT^0U194$4I("`F)B!T<FEM*"1O8FHM
M/D-465!%*2`]/2`G54Y)455%)RD@>PH@("`@("`@("`@("`@("`@)&9L86=S
M("X]("=U;FEQ=65?:V5Y("<["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@("1S<6P@/2`G4T5,14-4(%(N4D1")$Y53$Q?1DQ!1R!!4R!.1DQ!
M1RPG"B`@("`@("`@("`@("`@("XG("!2+E)$0B1$149!54Q47U-/55)#12!!
M4R!$4T]54D-%+"<*("`@("`@("`@("`@("`@+B<@($8N4D1")$9)14Q$7U19
M4$4@05,@1E194$4L)PH@("`@("`@("`@("`@("`N)R`@1BY21$(D0T]-4%54
M141?4T]54D-%($%3($-33U520T4G"B`@("`@("`@("`@("`@("XG($923TT@
M4D1")%)%3$%424].7T9)14Q$4R!2("<*("`@("`@("`@("`@("`@+B<@($I/
M24X@4D1")$9)14Q$4R!&($].(%(N4D1")$9)14Q$7U-/55)#13U&+E)$0B1&
M245,1%].04U%)PH@("`@("`@("`@("`@("`N)R!72$5212!54%!%4BA2+E)$
M0B1214Q!5$E/3E].04U%*3U<)R<@+B!S=')T;W5P<&5R*"1T86)L95]N86UE
M*2`N("=<)R<*("`@("`@("`@("`@("`@+B<@($%.1"!2+E)$0B1&245,1%].
M04U%/5PG)R`N("1F:65L9%]N86UE("X@)UPG)SL*"B`@("`@("`@)')E<W5L
M="`]($!I8F%S95]Q=65R>2@D=&AI<RT^8V]N;F5C=&EO;BP@)'-Q;"D["B`@
M("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^:6)A<V5286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(&EF("@D
M;V)J(#T@0&EB87-E7V9E=&-H7V]B:F5C="@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("!`:6)A<V5?9G)E95]R97-U;'0H)')E<W5L="D["B`@("`@("`@("`@
M(&EF("AI<W-E="@D;V)J+3Y.1DQ!1RDI('L*("`@("`@("`@("`@("`@("1F
M;&%G<R`N/2`G;F]T7VYU;&P@)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H:7-S970H)&]B:BT^1%-/55)#12DI('L*("`@("`@("`@("`@("`@
M("1F;&%G<R`N/2`G9&5F875L="`G.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("AI<W-E="@D;V)J+3Y#4T]54D-%*2D@>PH@("`@("`@("`@("`@
M("`@)&9L86=S("X]("=C;VUP=71E9"`G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("AI<W-E="@D;V)J+3Y&5%E012D@("8F("1O8FHM/D9465!%
M(#T](#(V,2D@>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=B;&]B("<[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<FEM
M*"1F;&%G<RD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@:6)A<V52
M86ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?17)R
M;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@("`@
M*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I<R!B
M96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI<R!I
M<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE(&5R
M<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@("`@
M*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE8W0*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I+`H@
M("`@("H@("`@("!$0E]I8F%S93HZ97)R;W).871I=F4H*2P@1$)?:6)A<V4Z
M.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N("9I8F%S95)A:7-E
M17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&5R<FYO
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES+3YE<G)O
M<D-O9&4H)'1H:7,M/F5R<F]R3F%T:79E*"DI.PH@("`@("`@('T*("`@("`@
M("`D=&UP(#TF("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@;G5L
M;"P@;G5L;"P@0&EB87-E7V5R<FUS9R@I*3L*("`@("`@("!R971U<FX@)'1M
M<#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I
M"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R;W(@
M8V]D92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@1$)-4R<@97)R;W(@8V]D92X@($Y53$P@:68@
M=&AE<F4@:7,@;F\@97)R;W(@8V]D92X*("`@("`J"B`@("`@*B!`<VEN8V4@
M365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!I9B`H
M9G5N8W1I;VY?97AI<W1S*"=I8F%S95]E<G)C;V1E)RDI('L*("`@("`@("`@
M("`@<F5T=7)N($!I8F%S95]E<G)C;V1E*"D["B`@("`@("`@?0H@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"<O7D1Y;F%M:6,@4U%,($5R<F]R(%-13"!E<G)O
M<B!C;V1E(#T@*%LP+3DM72LI+VDG+`H@("`@("`@("`@("`@("`@("`@("`@
M($!I8F%S95]E<G)M<V<H*2P@)&TI*2!["B`@("`@("`@("`@(')E='5R;B`H
M:6YT*21M6S%=.PH@("`@("`@('T*("`@("`@("!R971U<FX@;G5L;#L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@("\J
M*@H@("`@("H@36%P<R!N871I=F4@97)R;W(@8V]D97,@=&\@1$(G<R!P;W)T
M86)L92!O;F5S"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;F%T:79E8V]D
M92`@=&AE(&5R<F]R(&-O9&4@<F5T=7)N960@8GD@=&AE($1"35,*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE('!O<G1A8FQE($1"(&5R<F]R(&-O
M9&4N("!2971U<FX@1$)?15)23U(@:68@=&AE"B`@("`@*B`@("`@("`@("`@
M("`@(&-U<G)E;G0@9')I=F5R(&1O97-N)W0@:&%V92!A(&UA<'!I;F<@9F]R
M('1H90H@("`@("H@("`@("`@("`@("`@("`D;F%T:79E8V]D92!S=6)M:71T
M960N"B`@("`@*@H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<D-O
M9&4H)&YA=&EV96-O9&4@/2!N=6QL*0H@("`@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D95TI*2!["B`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^97)R;W)C;V1E7VUA<%LD;F%T:79E8V]D
M95T["B`@("`@("`@?0H*("`@("`@("!S=&%T:6,@)&5R<F]R7W)E9V5X<',[
M"B`@("`@("`@:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI('L*("`@("`@
M("`@("`@)&5R<F]R7W)E9V5X<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("<O9V5N97)A=&]R("XJ(&ES(&YO="!D969I;F5D+R<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L("`O+R!F;W(@8V]M<&%T+B!W
M(&EB87-E7V5R<F-O9&4H*0H@("`@("`@("`@("`@("`@)R]T86)L92XJ*&YO
M="!E>&ES='QN;W0@9F]U;F1\=6YK;F]W;BDO:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`@("`@("`@
M("<O=&%B;&4@+BH@86QR96%D>2!E>&ES=',O:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@("`@
M("`@("<O=6YS=6-C97-S9G5L(&UE=&%D871A('5P9&%T92`N*B!F86EL960@
M871T96UP="!T;R!S=&]R92!D=7!L:6-A=&4@=F%L=64O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@
M("`@("`@("`@("<O=6YS=6-C97-S9G5L(&UE=&%D871A('5P9&%T92`N*B!N
M;W0@9F]U;F0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].
M3U1?1D]53D0L"B`@("`@("`@("`@("`@("`G+W9A;&ED871I;VX@97)R;W(@
M9F]R(&-O;'5M;B`N*B!V86QU92`B7"I<*EPJ(&YU;&PO:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@
M("`@("`@("`@("`@("`@)R]V:6]L871I;VX@;V8@6UQW(%TK(&-O;G-T<F%I
M;G0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!
M24Y4+`H@("`@("`@("`@("`@("`@)R]C;VYV97)S:6]N(&5R<F]R(&9R;VT@
M<W1R:6YG+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y6
M04Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G+VYO('!E<FUI<W-I;VX@
M9F]R+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?04-#15-3
M7U9)3TQ!5$E/3BP*("`@("`@("`@("`@("`@("<O87)I=&AM971I8R!E>&-E
M<'1I;VXL(&YU;65R:6,@;W9E<F9L;W<L(&]R('-T<FEN9R!T<G5N8V%T:6]N
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y604Q)1"P*
M("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@("1E<G)O<FUS9R`]
M($!I8F%S95]E<G)M<V<H*3L*("`@("`@("!F;W)E86-H("@D97)R;W)?<F5G
M97AP<R!A<R`D<F5G97AP(#T^("1C;V1E*2!["B`@("`@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"1R96=E>'`L("1E<G)O<FUS9RDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D8V]D93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@1$)?15)23U(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF
M;W)M871I;VX@86)O=70@82!T86)L92!O<B!A(')E<W5L="!S970*("`@("`J
M"B`@("`@*B!.3U1%.B!O;FQY('-U<'!O<G1S("=T86)L92<@86YD("=F;&%G
M<R<@:68@/'9A<CXD<F5S=6QT/"]V87(^"B`@("`@*B!I<R!A('1A8FQE(&YA
M;64N"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS=')I;F<@("1R97-U
M;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y(&]R(&$*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&-O;G1A
M:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@5VAI;&4@=&AI<R!A;'-O(&%C8V5P=',@
M82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI<R!B96AA=FEO<B!I
M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!D97!R
M96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E("`@
M(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA
M=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B
M;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*("`@("`@("!I
M9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@;F%M92X*("`@
M("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I
M97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2!`:6)A<V5?
M<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`B4T5,14-4("H@1E)/32`D<F5S=6QT(%=(15)%(#$],"(I
M.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@
M+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@
M;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S
M;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I
M;F<@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!R97-O
M=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET+@H@("`@
M("`@("`@("`@*B!$97!R96-A=&5D+B`@2&5R92!F;W(@8V]M<&%T:6)I;&ET
M>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E
M<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@
M("!]"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].
M145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%
M4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@
M)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!`:6)A<V5?
M;G5M7V9I96QD<R@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D["@H@
M("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE
M;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@
M,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)&EN9F\@/2!`
M:6)A<V5?9FEE;&1?:6YF;R@D:60L("1I*3L*("`@("`@("`@("`@)')E<ULD
M:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&=O=%]S
M=')I;F<@/R`D8V%S95]F=6YC*"1R97-U;'0I(#H@)R<L"B`@("`@("`@("`@
M("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H)&EN9F];)VYA;64G72DL"B`@
M("`@("`@("`@("`@("`G='EP92<@(#T^("1I;F9O6R=T>7!E)UTL"B`@("`@
M("`@("`@("`@("`G;&5N)R`@(#T^("1I;F9O6R=L96YG=&@G72P*("`@("`@
M("`@("`@("`@("=F;&%G<R<@/3X@*"1G;W1?<W1R:6YG*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@/R`D=&AI<RT^7VEB87-E1FEE;&1&;&%G<R@D
M:6YF;ULG;F%M92==+"`D<F5S=6QT*0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@.B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"1M
M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D
M<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]2
M1$525$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G
M75LD<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@
M<F5S=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L90H@("`@
M("`@(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`:6)A<V5?9G)E
M95]R97-U;'0H)&ED*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y
M*"D*"B`@("`O*BH*("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N
M965D960@9F]R(&QI<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O
M8FIE8W1S('EO=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@
M=&AE(&1R:79E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U
M<'!O<G0@=&AE(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T
M3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y
M*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@
M("`@("`@8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G
M4T5,14-4($1)4U1)3D-4(%(N4D1")%)%3$%424].7TY!344@1E)/32`G"B`@
M("`@("`@("`@("`@("`@("`@("`@+B`G4D1")%)%3$%424].7T9)14Q$4R!2
M(%=(15)%(%(N4D1")%-94U1%35]&3$%'/3`G.PH@("`@("`@("`@("!C87-E
M("=V:65W<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!$25-4
M24Y#5"!21$(D5DE%5U].04U%(&9R;VT@4D1")%9)15=?4D5,051)3TY3)SL*
M("`@("`@("`@("`@8V%S92`G=7-E<G,G.@H@("`@("`@("`@("`@("`@<F5T
M=7)N("=314Q%0U0@1$E35$E.0U0@4D1")%5315(@1E)/32!21$(D55-%4E]0
M4DE624Q%1T53)SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@
M("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*
M"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J
M(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_/@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$
M0B]I9G@N<&AP````````````````````````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#0V-S(P(#$P-3$U-#,T,3,S(#`R,#(U-@`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`H*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(
M4"=S(&EF>"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@26YF
M;W)M:7@@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC
M;VT^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`
M<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O
M=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@
M)$ED.B!I9G@N<&AP+'8@,2XW,"`R,#`U+S`R+S(P(#`P.C0T.C0X(&1A;FEE
M;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P
M86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L
M87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N
M8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%05(@
M1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&EF>"!E>'1E;G-I;VX*
M("H@9F]R(&EN=&5R86-T:6YG('=I=&@@26YF;W)M:7@@9&%T86)A<V5S"B`J
M"B`J(%1H97-E(&UE=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@
M:6X@1$)?8V]M;6]N+@H@*@H@*B!-;W)E(&EN9F\@;VX@26YF;W)M:7@@97)R
M;W)S(&-A;B!B92!F;W5N9"!A=#H*("H@:'1T<#HO+W=W=RYI;F9O<FUI>"YC
M;VTO86YS=V5R<R]E;F=L:7-H+VEE<G)O<G,N:'1M"B`J"B`J(%1/1$\Z"B`J
M("`@+2!S970@;F5E9&5D(&5N=B!);F9O<FUI>"!V87)S(&]N(&-O;FYE8W0*
M("H@("`M(&EM<&QE;65N="!N871I=F4@<')E<&%R92]E>&5C=71E"B`J"B`J
M($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A
M=71H;W(@("`@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@
M0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`
M;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW
M+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+T1""B`J+PIC;&%S<R!$0E]I9G@@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@
M+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV
M97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G:69X)SL*"B`@
M("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B
M92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=I9G@G.PH*
M("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM
M<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE("=N97=?;&EN:R<@96QE
M;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F:7)S="!P<F]V
M:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@
M0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@
M("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@
M("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E=&-H(')O=R!B>2!N=6UB
M97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E<B!T:&4@<75E<GD*("`@
M("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*("`@("`J"B`@("`@*B!`
M=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A='5R97,@/2!A<G)A>2@*
M("`@("`@("`G;&EM:70G("`@("`@("`@/3X@)V5M=6QA=&4G+`H@("`@("`@
M("=N97=?;&EN:R<@("`@("`]/B!F86QS92P*("`@("`@("`G;G5M<F]W<R<@
M("`@("`@/3X@)V5M=6QA=&4G+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]
M/B!T<G5E+`H@("`@("`@("=P<F5P87)E)R`@("`@("`]/B!F86QS92P*("`@
M("`@("`G<W-L)R`@("`@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W1R86YS
M86-T:6]N<R<@(#T^('1R=64L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M
M87!P:6YG(&]F(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E
M<PH@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D
M95]M87`@/2!A<G)A>2@*("`@("`@("`G+3(P,2<@("`@/3X@1$)?15)23U)?
M4UE.5$%8+`H@("`@("`@("<M,C`V)R`@("`]/B!$0E]%4E)/4E].3U-50TA4
M04),12P*("`@("`@("`G+3(Q-R<@("`@/3X@1$)?15)23U)?3D]354-(1DE%
M3$0L"B`@("`@("`@)RTR,S8G("`@(#T^($1"7T524D]27U9!3%5%7T-/54Y4
M7T].7U)/5RP*("`@("`@("`G+3(S.2<@("`@/3X@1$)?15)23U)?0T].4U12
M04E.5"P*("`@("`@("`G+3(U,R<@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@
M("`@("`@("<M,CDR)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,+`H@("`@("`@("<M,S$P)R`@("`]/B!$0E]%4E)/4E]!3%)%04197T58
M25-44RP*("`@("`@("`G+3,Q-B<@("`@/3X@1$)?15)23U)?04Q214%$65]%
M6$E35%,L"B`@("`@("`@)RTS,3DG("`@(#T^($1"7T524D]27TY/5%]&3U5.
M1"P*("`@("`@("`G+3,R.2<@("`@/3X@1$)?15)23U)?3D]$0E-%3$5#5$5$
M+`H@("`@("`@("<M,S0V)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@
M("`@("`@("<M,S@V)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].
M54Q,+`H@("`@("`@("<M,SDQ)R`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4
M7TY/5%].54Q,+`H@("`@("`@("<M-34T)R`@("`]/B!$0E]%4E)/4E]364Y4
M05@L"B`@("`@("`@)RTV.3$G("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L
M"B`@("`@("`@)RTV.3(G("`@(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@
M("`@("`@)RTW,#,G("`@(#T^($1"7T524D]27T-/3E-44D%)3E1?3D]47TY5
M3$PL"B`@("`@("`@)RTQ,C`T)R`@(#T^($1"7T524D]27TE.5D%,241?1$%4
M12P*("`@("`@("`G+3$R,#4G("`@/3X@1$)?15)23U)?24Y604Q)1%]$051%
M+`H@("`@("`@("<M,3(P-B<@("`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L
M"B`@("`@("`@)RTQ,C`Y)R`@(#T^($1"7T524D]27TE.5D%,241?1$%412P*
M("`@("`@("`G+3$R,3`G("`@/3X@1$)?15)23U)?24Y604Q)1%]$051%+`H@
M("`@("`@("<M,3(Q,B<@("`]/B!$0E]%4E)/4E])3E9!3$E$7T1!5$4L"B`@
M("`@("`@)RTQ,C$S)R`@(#T^($1"7T524D]27TE.5D%,241?3E5-0D52+`H@
M("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C
M=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@
M("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@
M1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*
M("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A
M>2@I.PH*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D871A(&UA;FEP=6QA=&EO
M;B!Q=65R:65S(&)E(&-O;6UI='1E9"!A=71O;6%T:6-A;&QY/PH@("`@("H@
M0'9A<B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1A=71O8V]M;6ET(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H92!Q
M=6%N=&ET>2!O9B!T<F%N<V%C=&EO;G,@8F5G=6X*("`@("`J"B`@("`@*B![
M0&EN=&5R;F%L("!7:&EL92!T:&ES(&ES('!R:79A=&4L(&ET(&-A;B=T(&%C
M='5A;&QY(&)E(&1E<VEG;F%T960*("`@("`J('!R:79A=&4@:6X@4$A0(#4@
M8F5C875S92!I="!I<R!D:7)E8W1L>2!A8V-E<W-E9"!I;B!T:&4@=&5S="!S
M=6ET92Y]?0H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D=')A;G-A8W1I;VY?;W!C
M;W5N="`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@;G5M8F5R(&]F(')O=W,@
M869F96-T960@8GD@82!D871A(&UA;FEP=6QA=&EO;B!Q=65R>0H@("`@("H@
M0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1A9F9E8W1E9"`](#`["@H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R
M(&-A;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@
M("`@("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7VEF
M>"@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@
M("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD
M(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N)W0@8V%L;"!T
M:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E
M860N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T
M:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S
M:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@
M>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G:6YF;W)M:7@G
M*2`F)@H@("`@("`@("`@("`A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G26YF;W)M
M:7@G*2D*("`@("`@("!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I
M<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D
M9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A
M>"`]("1D<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("`D9&)H
M;W-T(#T@)&1S;ELG:&]S='-P96,G72`_("=`)R`N("1D<VY;)VAO<W1S<&5C
M)UT@.B`G)SL*("`@("`@("`D9&)N86UE(#T@)&1S;ELG9&%T86)A<V4G72`_
M("1D<VY;)V1A=&%B87-E)UT@+B`D9&)H;W-T(#H@)R<["B`@("`@("`@)'5S
M97(@/2`D9'-N6R=U<V5R;F%M92==(#\@)&1S;ELG=7-E<FYA;64G72`Z("<G
M.PH@("`@("`@("1P=R`]("1D<VY;)W!A<W-W;W)D)UT@/R`D9'-N6R=P87-S
M=V]R9"==(#H@)R<["@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E
M<G-I<W1E;G0@/R`G:69X7W!C;VYN96-T)R`Z("=I9GA?8V]N;F5C="<["@H@
M("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0"1C;VYN96-T7V9U;F-T:6]N
M*"1D8FYA;64L("1U<V5R+"`D<'<I.PH@("`@("`@(&EF("@A:7-?<F5S;W5R
M8V4H)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^:69X4F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"D[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J
M($1I<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*
M("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@
M("`@>PH@("`@("`@("1R970@/2!`:69X7V-L;W-E*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@
M("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T
M;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S
M<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T
M:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE
M<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q
M=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q
M=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@
M("`@("`@)'1H:7,M/F%F9F5C=&5D("`@/2!N=6QL.PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O*%-%3$5#5"DO:2<L("1Q=65R>2DI('L@("`@+R]415-4
M344Z(%5S92`A1$(Z.FES36%N:7`H*3\*("`@("`@("`@("`@+R\@=&AE('-C
M<F]L;"!I<R!N965D960@9F]R(&9E=&-H:6YG(&%B<V]L=71E(')O=R!N=6UB
M97)S"B`@("`@("`@("`@("\O(&EN(&$@<V5L96-T('%U97)Y(')E<W5L=`H@
M("`@("`@("`@("`D<F5S=6QT(#T@0&EF>%]Q=65R>2@D<75E<GDL("1T:&ES
M+3YC;VYN96-T:6]N+"!)1EA?4T-23TQ,*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("!I9B`H(21T:&ES+3YA=71O8V]M;6ET("8F("1I<VUA;FEP
M*2!["B`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P
M8V]U;G0@/3T@,"D@>PH@("`@("`@("`@("`@("`@("`@("1R97-U;'0@/2!`
M:69X7W%U97)Y*"="14=)3B!73U)+)RP@)'1H:7,M/F-O;FYE8W1I;VXI.PH@
M("`@("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FEF>%)A:7-E17)R;W(H*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="LK.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@/2!`:69X7W%U97)Y*"1Q
M=65R>2P@)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('T*("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YI9GA2
M86ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YA9F9E8W1E
M9"`]($!I9GA?869F96-T961?<F]W<R@D<F5S=6QT*3L*("`@("`@("`O+R!$
M971E<FUI;F4@=VAI8V@@<75E<FEE<R!S:&]U;&0@<F5T=7)N(&1A=&$L(&%N
M9"!W:&EC:`H@("`@("`@("\O('-H;W5L9"!R971U<FX@86X@97)R;W(@8V]D
M92!O;FQY+@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O*%-%3$5#5"DO:2<L
M("1Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@
M("`@?0H@("`@("`@("\O(%A86"!497-T;64Z(&9R964@<F5S=6QT<R!I;G-I
M9&4@82!T<F%N<V%C=&EO;@H@("`@("`@("\O(&UA>2!C875S92!T;R!S=&]P
M(&ET(&%N9"!C;VUM:70@=&AE('=O<FL_"@H@("`@("`@("\O(%)E<W5L="!H
M87,@=&\@8F4@9G)E960@979E;B!W:71H(&$@:6YS97)T(&]R('5P9&%T90H@
M("`@("`@($!I9GA?9G)E95]R97-U;'0H)')E<W5L="D["@H@("`@("`@(')E
M='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT
M4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE(&EN=&5R;F%L(&EF
M>"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@<F5S=6QT
M"B`@("`@*@H@("`@("H@0'!A<F%M(&$@=F%L:60@9F)S<6P@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@
M("`@*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T
M:&5R=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X
M=%)E<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H*0H*
M("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@
M869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*
M("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M
M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H
M92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("![
M"B`@("`@("`@:68@*$1".CII<TUA;FEP*"1T:&ES+3YL87-T7W%U97)Y*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F%F9F5C=&5D.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J
M*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT
M;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@
M=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B
M;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R
M92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N
M;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$
M0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D
M96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@
M:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@
M("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC
M960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U
M;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@
M("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@
M3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@
M("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D
M92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"@D<F]W;G5M
M("$]/2!N=6QL*2`F)B`H)')O=VYU;2`\(#`I*2!["B`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)')O=VYU;2`]/3T@
M;G5L;"D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!%=F5N('1H
M;W5G:"!F971C:%]R;W<H*2!S:&]U;&0@<F5T=7)N('1H92!N97AT(')O=R`@
M:68*("`@("`@("`@("`@("H@)')O=VYU;2!I<R!N=6QL+"!I="!D;V5S;B=T
M(&EN(&%L;"!C87-E<RX@($)U9R`U.3@N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D<F]W;G5M(#T@)TY%6%0G.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("\O($EN9&5X('-T87)T<R!A="!R;W<@,2P@=6YL:6ME(&UO
M<W0@1$)-4R=S('-T87)T:6YG(&%T(#`N"B`@("`@("`@("`@("1R;W=N=6TK
M*SL*("`@("`@("!]"B`@("`@("`@:68@*"$D87)R(#T@0&EF>%]F971C:%]R
M;W<H)')E<W5L="P@)')O=VYU;2DI('L*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("$]/2!$0E]&
M151#2$U/1$5?05-33T,I('L*("`@("`@("`@("`@)&D],#L*("`@("`@("`@
M("`@)&]R9&5R(#T@87)R87DH*3L*("`@("`@("`@("`@9F]R96%C:"`H)&%R
M<B!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D;W)D97);)&DK*UT@/2`D
M=F%L.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A<G(@/2`D;W)D97([
M"B`@("`@("`@?2!E;'-E:68@*"1F971C:&UO9&4@/3T@1$)?1D540TA-3T1%
M7T%34T]#("8F"B`@("`@("`@("`@("`@("`@("1T:&ES+3YO<'1I;VYS6R=P
M;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*0H@("`@
M("`@('L*("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S
M92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?
M4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L=65S
M*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-4%19
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A;'5E
M<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@
M("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M
M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E
M<W5L=#HZ;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E
M9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S
M97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M;G5M0V]L<R@D<F5S=6QT*0H@("`@>PH@("`@("`@(&EF("@A)&-O;',@/2!`
M:69X7VYU;5]F:65L9',H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YI9GA286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E
M4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S
M970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L
M="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@
M=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z
M.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L
M="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R
M964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I
M"B`@("!["B`@("`@("`@<F5T=7)N($!I9GA?9G)E95]R97-U;'0H)')E<W5L
M="D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@875T;T-O;6UI="@I
M"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B;&5S(&%U=&]M871I
M8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A<F%M(&)O;VP@)&]N;V9F("!T
M<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N<R!I="!O9F8*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R
M;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@("`J("`@("`@("`@("`@("`@
M9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T<F%N<V%C=&EO;G,N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H)&]N;V9F(#T@=')U
M92D*("`@('L*("`@("`@("`O+R!86%@@:68@)'1H:7,M/G1R86YS86-T:6]N
M7V]P8V]U;G0@/B`P+"!W92!S:&]U;&0@<')O8F%B;'D*("`@("`@("`O+R!I
M<W-U92!A('=A<FYI;F<@:&5R92X*("`@("`@("`D=&AI<RT^875T;V-O;6UI
M="`]("1O;F]F9B`_('1R=64@.B!F86QS93L*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]M;6ET*"D*"B`@
M("`O*BH*("`@("`J($-O;6UI=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*
M("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&-O;6UI="@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N
M<V%C=&EO;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@
M0&EF>%]Q=65R>2@G0T]-34E4(%=/4DLG+"`D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*
M("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/FEF>%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V
M97)T<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N
M="`^(#`I('L*("`@("`@("`@("`@)')E<W5L="`]($!I9GA?<75E<GDH)U)/
M3$Q"04-+(%=/4DLG+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@
M("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@
M:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/FEF>%)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@
M("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@:69X4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A
M($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE
M;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R
M;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF
M('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3
M+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@
M;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R
M;W(H*2P*("`@("`J("`@("`@1$)?:69X.CIE<G)O<DYA=&EV92@I+"!$0E]I
M9G@Z.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&EF>%)A:7-E
M17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)&5R<FYO
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES+3YE<G)O
M<D-O9&4H:69X7V5R<F]R*"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W).
M871I=F4H*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).
M871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E
M(&5R<F]R(&-O9&4@86YD(&UE<W-A9V4@<')O9'5C960@8GD@=&AE(&QA<W0@
M<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE($1"35,G
M(&5R<F]R(&-O9&4@86YD(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@
M97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E='5R;B!`:69X7V5R<F]R
M*"D@+B`G("<@+B!`:69X7V5R<F]R;7-G*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J($UA<',@
M;F%T:79E(&5R<F]R(&-O9&5S('1O($1")W,@<&]R=&%B;&4@;VYE<RX*("`@
M("`J"B`@("`@*B!297%U:7)E<R!T:&%T('1H92!$0B!I;7!L96UE;G1A=&EO
M;B=S(&-O;G-T<G5C=&]R(&9I;&QS"B`@("`@*B!I;B!T:&4@/'9A<CXD97)R
M;W)C;V1E7VUA<#PO=F%R/B!P<F]P97)T>2X*("`@("`J"B`@("`@*B!`<&%R
M86T@('-T<FEN9R`@)&YA=&EV96-O9&4@(&5R<F]R(&-O9&4@<F5T=7)N960@
M8GD@=&AE(&1A=&%B87-E"B`@("`@*B!`<F5T=7)N(&EN="!A('!O<G1A8FQE
M($1"(&5R<F]R(&-O9&4L(&]R($1"7T524D]2(&EF('1H:7,@1$(*("`@("`J
M(&EM<&QE;65N=&%T:6]N(&AA<R!N;R!M87!P:6YG(&9O<B!T:&4@9VEV96X@
M97)R;W(@8V]D92X*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E*"1N
M871I=F5C;V1E*0H@("`@>PH@("`@("`@(&EF("AE<F5G*"=344Q#3T1%/2@N
M*BE=)RP@)&YA=&EV96-O9&4L("1M871C:"DI('L*("`@("`@("`@("`@)&-O
M9&4@/2`D;6%T8VA;,5T["B`@("`@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M97)R;W)C;V1E7VUA<%LD8V]D95TI*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/F5R<F]R8V]D95]M87!;)&-O9&5=.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J($Y/5$4Z(&]N;'D@<W5P<&]R=',@)W1A
M8FQE)R!I9B`\=F%R/B1R97-U;'0\+W9A<CX@:7,@82!T86)L92!N86UE+@H@
M("`@("H*("`@("`J($EF(&%N86QY>FEN9R!A('%U97)Y(')E<W5L="!A;F0@
M=&AE(')E<W5L="!H87,@9'5P;&EC871E(&9I96QD(&YA;65S+`H@("`@("H@
M86X@97)R;W(@=VEL;"!B92!R86ES960@<V%Y:6YG"B`@("`@*B`\<V%M<#YC
M86XG="!D:7-T:6YG=6ES:"!D=7!L:6-A=&4@9FEE;&0@;F%M97,\+W-A;7`^
M+@H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT
M("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN
M:6YG('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@
M<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P<F5C
M871E9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A
M('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A
M<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I
M;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R
M;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N
M"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N
M=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0&EF
M>%]Q=65R>2@B4T5,14-4("H@1E)/32`D<F5S=6QT(%=(15)%(#$],"(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@?2!E
M;'-E:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@("`@
M+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@
M;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@<F5S
M;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@
M("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I
M;F<@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!R97-O
M=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET+@H@("`@
M("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@("`@
M("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FEF>%)A:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I
M.PH@("`@("`@('T*"B`@("`@("`@)&9L9',@/2!`:69X7V9I96QD<')O<&5R
M=&EE<R@D:60I.PH@("`@("`@("1C;W5N="`]($!I9GA?;G5M7V9I96QD<R@D
M:60I.PH*("`@("`@("!I9B`H8V]U;G0H)&9L9',I("$]("1C;W5N="D@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H(F-A;B=T(&1I
M<W1I;F=U:7-H(&1U<&QI8V%T92!F:65L9"!N86UE<R(I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E
M7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@
M("`@)&D@("`](#`["B`@("`@("`@)')E<R`](&%R<F%Y*"D["@H@("`@("`@
M(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@
M/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W)E86-H("@D9FQD<R!A
M<R`D:V5Y(#T^("1V86QU92D@>PH@("`@("`@("`@("`D<')O<',@/2!E>'!L
M;V1E*"<[)RP@)'9A;'5E*3L*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("=T86)L92<@/3X@)&=O=%]S=')I;F<@/R`D
M8V%S95]F=6YC*"1R97-U;'0I(#H@)R<L"B`@("`@("`@("`@("`@("`G;F%M
M92<@(#T^("1C87-E7V9U;F,H)&ME>2DL"B`@("`@("`@("`@("`@("`G='EP
M92<@(#T^("1P<F]P<ULP72P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@
M)'!R;W!S6S%=+`H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B`D<')O<'-;
M-%T@/3T@)TXG(#\@)VYO=%]N=6QL)R`Z("<G+`H@("`@("`@("`@("`I.PH@
M("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*
M("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G
M75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@
M)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I
M75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I
M*RL["B`@("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL
M>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G
M;W1?<W1R:6YG*2!["B`@("`@("`@("`@($!I9GA?9G)E95]R97-U;'0H)&ED
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*
M("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI
M<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W
M86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E<B!D
M;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE(&]B
M:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G
M=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4('1A8FYA
M;64@1E)/32!S>7-T86)L97,@5TA%4D4@=&%B:60@/CT@,3`P)SL*("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A
M<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T
M"B`J($5N9#H*("HO"@H_/@H`````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+T1"+VUS<6PN<&AP````````````````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P-38U-3(@,3`U,34T,S0Q,S,@,#(P-#4P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"@HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R:79E<B!F
M;W(@4$A0)W,@;7-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I
M=&@@36EN:2!344P@9&%T86)A<V5S"B`J"B`J(%!(4"=S(&U344P@97AT96YS
M:6]N(&1I9"!W96ER9"!T:&EN9W,@=VET:"!.54Q,('9A;'5E<R!P<FEO<B!T
M;R!02%`*("H@-"XS+C$Q(&%N9"`U+C`N-"X@($UA:V4@<W5R92!Y;W5R('9E
M<G-I;VX@;V8@4$A0(&UE971S(&]R(&5X8V5E9',*("H@=&AO<V4@=F5R<VEO
M;G,N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z
M(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O
M9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G
M:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E8BP@
M<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T
M96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R
M("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@;7-Q;"YP:'`L
M=B`Q+C4W(#(P,#4O,#(O,C(@,#<Z,C8Z-#8@9&%N:65L8R!%>'`@)`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO
M"@HO*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N
M(&)E(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N
M+G!H<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN
M=&5R86-T('=I=&@@4$A0)W,@;7-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R
M86-T:6YG('=I=&@@36EN:2!344P@9&%T86)A<V5S"B`J"B`J(%1H97-E(&UE
M=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@1$)?8V]M;6]N
M+@H@*@H@*B!02%`G<R!M4U%,(&5X=&5N<VEO;B!D:60@=V5I<F0@=&AI;F=S
M('=I=&@@3E5,3"!V86QU97,@<')I;W(@=&\@4$A0"B`J(#0N,RXQ,2!A;F0@
M-2XP+C0N("!-86ME('-U<F4@>6]U<B!V97)S:6]N(&]F(%!(4"!M965T<R!O
M<B!E>&-E961S"B`J('1H;W-E('9E<G-I;VYS+@H@*@H@*B!`8V%T96=O<GD@
M("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$0@H@*B!`875T:&]R("`@("!$
M86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG
M:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT
M='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E
M(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("H@0'-I;F-E
M("`@("`@0VQA<W,@;F]T(&9U;F-T:6]N86P@=6YT:6P@4F5L96%S92`Q+C<N
M,`H@*B\*8VQA<W,@1$)?;7-Q;"!E>'1E;F1S($1"7V-O;6UO;@I["B`@("`O
M+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@5&AE($1"(&1R:79E
M<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]("=M<W%L)SL*"B`@
M("`O*BH*("`@("`J(%1H92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B
M92!U<V5D("AD8C(L(&%C8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A
M<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1D8G-Y;G1A>"`]("=M<W%L)SL*
M"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I
M;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L
M96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O
M=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@
M($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@
M("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@
M("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M
M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@
M("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH
M"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=E;75L871E)RP*("`@("`@
M("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O=W,G
M("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@("`@(#T^('1R
M=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@("`@
M("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A8W1I
M;VYS)R`@/3X@9F%L<V4L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P
M:6YG(&]F(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@
M("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M
M87`@/2!A<G)A>2@*("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A
M=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@
M<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J
M*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T
M;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A
M<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@*B!4:&4@<75E<GD@
M<F5S=6QT(')E<V]U<F-E(&-R96%T960@8GD@4$A0"B`@("`@*@H@("`@("H@
M57-E9"!T;R!M86ME(&%F9F5C=&5D4F]W<R@I('=O<FLN("!/;FQY(&-O;G1A
M:6YS('1H92!R97-U;'0@9F]R"B`@("`@*B!D871A(&UA;FEP=6QA=&EO;B!Q
M=65R:65S+B`@0V]N=&%I;G,@9F%L<V4@9F]R(&]T:&5R('%U97)I97,N"B`@
M("`@*@H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D7W)E<W5L=#L*"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@8V]N
M<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*
M("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I
M;VX@1$)?;7-Q;"@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO;B@I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*("`@
M("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R+"!L
M;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@1&]N
M)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N;F5C
M="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@17AA;7!L92!O9B!H;W<@=&\@
M8V]N;F5C=#H*("`@("`J(#QC;V1E/@H@("`@("H@<F5Q=6ER95]O;F-E("=$
M0BYP:'`G.PH@("`@("H@"B`@("`@*B`O+R`D9'-N(#T@)VUS<6PZ+R]H;W-T
M;F%M92]D8FYA;64G.R`@+R\@=7-E(&$@5$-0(&-O;FYE8W1I;VX*("`@("`J
M("1D<VX@/2`G;7-Q;#HO+R]D8FYA;64G.R`@("`@("`@("`@("`O+R!U<V4@
M82!S;V-K970*("`@("`J("1O<'1I;VYS(#T@87)R87DH"B`@("`@*B`@("`@
M)W!O<G1A8FEL:71Y)R`]/B!$0E]03U)404))3$E465]!3$PL"B`@("`@*B`I
M.PH@("`@("H@"B`@("`@*B`D9&(@/28@1$(Z.F-O;FYE8W0H)&1S;BP@)&]P
M=&EO;G,I.PH@("`@("H@:68@*%!%05(Z.FES17)R;W(H)&1B*2D@>PH@("`@
M("H@("`@(&1I92@D9&(M/F=E=$UE<W-A9V4H*2D["B`@("`@*B!]"B`@("`@
M*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@
M("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@
M("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES
M=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C
M8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@
M("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E
M*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G;7-Q
M;"<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$
M0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y
M;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;
M)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("`D<&%R86US(#T@87)R
M87DH*3L*("`@("`@("!I9B`H)&1S;ELG:&]S='-P96,G72D@>PH@("`@("`@
M("`@("`D<&%R86US6UT@/2`D9'-N6R=P;W)T)UT*("`@("`@("`@("`@("`@
M("`@("`@("`@/R`D9'-N6R=H;W-T<W!E8R==("X@)RPG("X@)&1S;ELG<&]R
M="=="B`@("`@("`@("`@("`@("`@("`@("`@(#H@)&1S;ELG:&]S='-P96,G
M73L*("`@("`@("!]"@H@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E
M<G-I<W1E;G0@/R`G;7-Q;%]P8V]N;F5C="<@.B`G;7-Q;%]C;VYN96-T)SL*
M"B`@("`@("`@)&EN:2`](&EN:5]G970H)W1R86-K7V5R<F]R<R<I.PH@("`@
M("`@("1P:'!?97)R;W)M<V<@/2`G)SL*("`@("`@("!I9B`H)&EN:2D@>PH@
M("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N
M8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD[
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?
M97)R;W)S)RP@,2D["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@
M0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C;VYN96-T7V9U;F-T:6]N+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&%R86US*3L*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R
M;W)S)RP@)&EN:2D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YC
M;VYN96-T:6]N*2!["B`@("`@("`@("`@(&EF("@H)&5R<B`]($!M<W%L7V5R
M<F]R*"DI("$]("<G*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@
M;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D97)R*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!
M24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P:'!?97)R;W)M<V<I.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(4!M<W%L7W-E;&5C=%]D8B@D9'-N
M6R=D871A8F%S92==+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YM<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T
M<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@
M("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@
M("`D<F5T(#T@0&US<6Q?8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@
M("`@("1T:&ES+3YC;VYN96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@
M)')E=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R
M>2@I"@H@("`@+RHJ"B`@("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A
M8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@
M4U%,('%U97)Y('-T<FEN9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@
M("L@82!02%`@<F5S=6QT(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#
M5"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C
M;VYS=&%N="!F;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@
M("`@("`@("`@("`@("`K(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*
M("`@("`J+PH@("`@9G5N8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@
M>PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@
M("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@
M("1R97-U;'0@/2!`;7-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YM<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@
M("`O+R!$971E<FUI;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U
M<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A
M;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@:68@*$1".CII<TUA;FEP*"1Q
M=65R>2DI('L*("`@("`@("`@("`@)'1H:7,M/E]R97-U;'0@/2`D<F5S=6QT
M.PH@("`@("`@("`@("!R971U<FX@1$)?3TL["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/E]R97-U;'0@/2!F86QS93L*("`@("`@("`@
M("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@?0H*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO
M=F4@=&AE(&EN=&5R;F%L(&US<6P@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE
M>'0@879A:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A
M;&ED(&9B<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S
M=6QT(&ES(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@
M("`@("!R971U<FX@9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J(%!L86-E<R!A(')O=R!F
M<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I=F5N(&%R<F%Y"B`@("`@
M*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A>2!A;F0@=&AE(&1A=&$@
M=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@("H@4V5E($1"7W)E<W5L
M=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M871I;VXN"B`@("`@*@H@
M("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D
M:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!I
M;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@
M("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@
M("`@("H*("`@("`J(%!(4"=S(&U344P@97AT96YS:6]N(&1I9"!W96ER9"!T
M:&EN9W,@=VET:"!.54Q,('9A;'5E<R!P<FEO<B!T;R!02%`*("`@("`J(#0N
M,RXQ,2!A;F0@-2XP+C0N("!-86ME('-U<F4@>6]U<B!V97)S:6]N(&]F(%!(
M4"!M965T<R!O<B!E>&-E961S"B`@("`@*B!T:&]S92!V97)S:6]N<RX*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E
M<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R
M<B`@("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@
M:6X*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@
M<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R
M86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C
M:"`H,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E
M<W5L="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R
M(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T
M8VA);G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U
M;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I
M9B`H(4!M<W%L7V1A=&%?<V5E:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-3
M3T,I('L*("`@("`@("`@("`@)&%R<B`]($!M<W%L7V9E=&-H7V%R<F%Y*"1R
M97-U;'0L($U344Q?05-33T,I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!
M4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R<F%Y7V-H
M86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A<G(@/2!`;7-Q;%]F
M971C:%]R;W<H)')E<W5L="D["B`@("`@("`@?0H@("`@("`@(&EF("@A)&%R
M<BD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?4E1224TI('L*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R
M<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,
M7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!
M<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E
M4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S
M970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L
M="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@
M=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z
M.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L
M="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R
M964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I
M"B`@("!["B`@("`@("`@<F5T=7)N($!M<W%L7V9R965?<F5S=6QT*"1R97-U
M;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*
M("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T
M(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?
M<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@
M($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@
M0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@/2!`;7-Q
M;%]N=6U?9FEE;&1S*"1R97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W%L4F%I<V5%<G)O<B@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*
M("`@("`@("`D<F]W<R`]($!M<W%L7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@
M("`@(&EF("@D<F]W<R`]/3T@9F%L<V4I('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YM<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F
M96-T960H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R
M(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R
M>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA
M="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T
M(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W
M<R@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^7W)E<W5L="D@>PH@("`@
M("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N(&US
M<6Q?869F96-T961?<F]W<R@D=&AI<RT^7W)E<W5L="D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE(&]F('1H92!S
M97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M86YD("!W:&5N
M('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@:70@9&]E<R!N
M;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YE>'0@
M:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J("`@("`@("`@("`@
M("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO;CHZ9V5T4V5Q
M=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUS<6PZ.F-R96%T95-E<75E
M;F-E*"DL($1"7VUS<6PZ.F1R;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@
M("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE
M*"1S97%?;F%M92D["B`@("`@("`@)')E<&5A="`](&9A;'-E.PH@("`@("`@
M(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`])B`D=&AI
M<RT^<75E<GDH(E-%3$5#5"!?<V5Q($923TT@)'MS97%N86UE?2(I.PH@("`@
M("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@("`@("`@("`@
M("!I9B`H)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@
M("`@("`@("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?
M3D]354-(5$%"3$4I('L*("`@("`@("`@("`@("`@("1R97!E870@/2!T<G5E
M.PH@("`@("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<F5P96%T(#T@9F%L<V4["B`@("`@("`@("`@('T*("`@("`@("!]
M('=H:6QE("@D<F5P96%T*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("`D87)R(#T@)')E<W5L="T^
M9F5T8VA2;W<H1$)?1D540TA-3T1%7T]21$52140I.PH@("`@("`@("1R97-U
M;'0M/F9R964H*3L*("`@("`@("!R971U<FX@)&%R<ELP73L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C<F5A=&5397%U96YC92@I"@H@("`@+RHJ
M"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@
M06QS;R!C<F5A=&5S(&$@;F5W('1A8FQE('1O(&%S<V]C:6%T92!T:&4@<V5Q
M=65N8V4@=VET:"X@(%5S97,*("`@("`J(&$@<V5P87)A=&4@=&%B;&4@=&\@
M96YS=7)E('!O<G1A8FEL:71Y('=I=&@@;W1H97(@9')I=F5R<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@
M;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+
M(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC92@I
M+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$
M0E]M<W%L.CIN97AT240H*2P@1$)?;7-Q;#HZ9')O<%-E<75E;F-E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*0H@
M("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E;F-E3F%M
M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97,@/2`D=&AI<RT^<75E<GDH)T-2
M14%412!404),12`G("X@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("X@)R`H:60@24Y414=%4B!.3U0@3E5,3"DG*3L*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R
M97,["B`@("`@("`@?0H@("`@("`@("1R97,@/2`D=&AI<RT^<75E<GDH(D-2
M14%412!315%514Y#12!/3B`D>W-E<6YA;65](BD["B`@("`@("`@<F5T=7)N
M("1R97,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E
M;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H
M92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P
M4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@
M("`J("`@("`@1$)?;7-Q;#HZ;F5X=$E$*"DL($1"7VUS<6PZ.F-R96%T95-E
M<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S
M97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$
M4D]0(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M
M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('%U;W1E261E;G1I
M9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!M4U%,(&1O97,@;F]T('-U<'!O<G0@
M9&5L:6UI=&5D(&ED96YT:69I97)S"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`D<W1R("!T:&4@:61E;G1I9FEE<B!N86UE('1O(&)E('%U;W1E9`H@
M("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!A($1"7T5R<F]R(&]B:F5C
M=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T94ED96YT:69I
M97(H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L
M96%S92`Q+C<N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED96YT:69I
M97(H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R
M;W(H1$)?15)23U)?54Y355!03U)4140I.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&5S8V%P95-I;7!L92@I"@H@("`@+RHJ"B`@("`@*B!%<V-A
M<&5S(&$@<W1R:6YG(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N="!$0DU3)W,@
M<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R("!T
M:&4@<W1R:6YG('1O(&)E(&5S8V%P960*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(&5S8V%P960@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.G%U;W1E4VUA<G0H*0H@("`@("H@0'-I;F-E($UE=&AO
M9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<V-A<&53:6UP;&4H)'-T<BD*("`@('L*("`@("`@("!R971U
M<FX@861D<VQA<VAE<R@D<W1R*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!M<W%L4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E
M<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O
M8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@
M97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@
M($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$
M0DU3+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R
M;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E
M17)R;W(H*2P*("`@("`J("`@("`@1$)?;7-Q;#HZ97)R;W).871I=F4H*2P@
M1$)?;7-Q;#HZ97)R;W)#;V1E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;7-Q
M;%)A:7-E17)R;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("`D;F%T
M:79E(#T@)'1H:7,M/F5R<F]R3F%T:79E*"D["B`@("`@("`@:68@*"1E<G)N
M;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R
M;W)#;V1E*"1N871I=F4I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+"`D;F%T
M:79E*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV
M92@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R
M;W(@;65S<V%G92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*
M("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@1$)-4R<@97)R;W(@;65S<V%G
M90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@
M("`@("`@<F5T=7)N($!M<W%L7V5R<F]R*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97)R;W)#;V1E*"D*"B`@("`O*BH*("`@("`J($1E=&5R
M;6EN97,@4$5!4CHZ1$(@97)R;W(@8V]D92!F<F]M('1H92!D871A8F%S92=S
M('1E>'0@97)R;W(@;65S<V%G90H@("`@("H*("`@("`J($!P87)A;2!S=')I
M;F<@)&5R<F]R;7-G("!T:&4@97)R;W(@;65S<V%G92!R971U<FYE9"!F<F]M
M('1H92!D871A8F%S90H@("`@("H*("`@("`J($!R971U<FX@:6YT96=E<B`@
M=&AE(&5R<F]R(&YU;6)E<B!F<F]M(&$@1$)?15)23U(J(&-O;G-T86YT"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D97)R;W)M<V<I"B`@("![
M"B`@("`@("`@<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@(&EF("@A
M:7-S970H)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E<G)O<E]R
M96=E>'!S(#T@87)R87DH"B`@("`@("`@("`@("`@("`G+UY!8V-E<W,@=&\@
M9&%T86)A<V4@9&5N:65D+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?
M15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`@("`@("`@("<O7D)A
M9"!I;F1E>"!N86UE+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?04Q214%$65]%6$E35%,L"B`@("`@("`@("`@("`@("`G+UY"860@;W)D
M97(@9FEE;&0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]3
M64Y405@L"B`@("`@("`@("`@("`@("`G+UY"860@='EP92!F;W(@8V]M<&%R
M:7-O;B]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!
M6"P*("`@("`@("`@("`@("`@("<O7D-A;EPG="!P97)F;W)M($Q)2T4@;VXO
M:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@
M("`@("`@("`@("`@("`G+UY#86Y<)W0@=7-E(%1%6%0@9FEE;&1S(&EN($Q)
M2T4@8V]M<&%R:7-O;B]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T52
M4D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O7D-O=6QD;EPG="!C<F5A
M=&4@=&5M<&]R87)Y('1A8FQE+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?0T%.3D]47T-214%412P*("`@("`@("`@("`@("`@("<O7D5R
M<F]R(&-R96%T:6YG('1A8FQE(&9I;&4O:2<*("`@("`@("`@("`@("`@("`@
M("`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@("`@("`@("`@("`@("`@
M)R]>1FEE;&0@+BH@8V%N;F]T(&)E(&YU;&PD+VDG"B`@("`@("`@("`@("`@
M("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@
M("`@("`@("`@("<O7DEN9&5X("AF:65L9'QC;VYD:71I;VXI("XJ(&-A;FYO
M="!B92!N=6QL)"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7U-93E1!6"P*("`@("`@("`@("`@("`@("<O7DEN=F%L:60@9&%T92!F;W)M
M870O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E])3E9!3$E$
M7T1!5$4L"B`@("`@("`@("`@("`@("`G+UY);G9A;&ED('1I;64@9F]R;6%T
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y604Q)1"P*
M("`@("`@("`@("`@("`@("<O7DQI=&5R86P@=F%L=64@9F]R("XJ(&ES('=R
M;VYG('1Y<&4D+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M24Y604Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G+UY.;R!$871A8F%S
M92!396QE8W1E9"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7TY/1$)314Q%0U1%1"P*("`@("`@("`@("`@("`@("<O7DYO('9A;'5E('-P
M96-I9FEE9"!F;W(@9FEE;&0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E]604Q515]#3U5.5%]/3E]23U<L"B`@("`@("`@("`@("`@("`G
M+UY.;VX@=6YI<75E('9A;'5E(&9O<B!U;FEQ=64@:6YD97@O:2<*("`@("`@
M("`@("`@("`@("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M("`@("`@("`@)R]>3W5T(&]F(&UE;6]R>2!F;W(@=&5M<&]R87)Y('1A8FQE
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?0T%.3D]47T-2
M14%412P*("`@("`@("`@("`@("`@("<O7E!E<FUI<W-I;VX@9&5N:65D+VDG
M"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?04-#15-37U9)3TQ!
M5$E/3BP*("`@("`@("`@("`@("`@("<O7E)E9F5R96YC92!T;R!U;BUS96QE
M8W1E9"!T86)L92]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7U-93E1!6"P*("`@("`@("`@("`@("`@("<O7G-Y;G1A>"!E<G)O<B]I)PH@
M("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@
M("`@("`@("`@("<O7E1A8FQE("XJ(&5X:7-T<R0O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`@
M("`@("`@("<O7E5N:VYO=VX@9&%T86)A<V4O:2<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E].3U-50TA$0BP*("`@("`@("`@("`@("`@("<O
M7E5N:VYO=VX@9FEE;&0O:2<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%
M4E)/4E].3U-50TA&245,1"P*("`@("`@("`@("`@("`@("<O7E5N:VYO=VX@
M*&EN9&5X?'-Y<W1E;2!V87)I86)L92DO:2<*("`@("`@("`@("`@("`@("`@
M("`]/B!$0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@("`@("`@("`G+UY5
M;FMN;W=N('1A8FQE+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)2
M3U)?3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G+UY5;G%U86QI9FEE
M9"!F:65L9"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27U-9
M3E1!6"P*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&9O<F5A
M8V@@*"1E<G)O<E]R96=E>'!S(&%S("1R96=E>'`@/3X@)&-O9&4I('L*("`@
M("`@("`@("`@:68@*'!R96=?;6%T8V@H)')E9V5X<"P@)&5R<F]R;7-G*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1C;V1E.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]%4E)/4CL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S
M=6QT('-E=`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D
M<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C
M;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E
M<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I
M;W(@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D
M92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E
M='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF
M;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N
M"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N
M=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0&US
M<6Q?<75E<GDH(E-%3$5#5"`J($923TT@)')E<W5L="(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI
M<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@
M("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*
M("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED
M96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@/2`D
M<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L
M<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+RH*("`@("`@("`@
M("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E
M;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I="X*("`@("`@("`@("`@
M("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0["B`@
M("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!
M*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@
M("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@
M("`@("!]"@H@("`@("`@("1C;W5N="`]($!M<W%L7VYU;5]F:65L9',H)&ED
M*3L*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO
M9&4I('L*("`@("`@("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT
M.PH@("`@("`@('T*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT
M.R`D:2LK*2!["B`@("`@("`@("`@("1T;7`@/2!`;7-Q;%]F971C:%]F:65L
M9"@D:60I.PH*("`@("`@("`@("`@)&9L86=S(#T@)R<["B`@("`@("`@("`@
M(&EF("@D=&UP+3YN;W1?;G5L;"D@>PH@("`@("`@("`@("`@("`@)&9L86=S
M("X]("=N;W1?;G5L;"`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("@D=&UP+3YU;FEQ=64I('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G
M=6YI<75E7VME>2`G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F;&%G
M<R`]('1R:6TH)&9L86=S*3L*"B`@("`@("`@("`@("1R97-;)&E=(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^("1C87-E7V9U;F,H)'1M
M<"T^=&%B;&4I+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F
M=6YC*"1T;7`M/FYA;64I+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`D
M=&UP+3YT>7!E+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B!M<W%L7V9I
M96QD7VQE;B@D:60L("1I*2P*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@
M)&9L86=S+`H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@:68@*"1M;V1E
M("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D<F5S
M6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52
M5$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD
M<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@<F5S
M=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L90H@("`@("`@
M(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`;7-Q;%]F<F5E7W)E
M<W5L="@D:60I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')E<SL*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L475E<GDH*0H*
M("`@("\J*@H@("`@("H@3V)T86EN(&$@;&ES="!O9B!A(&=I=F5N('1Y<&4@
M;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!T:&4@87)R87D@8V]N=&%I;FEN
M9R!T:&4@;&ES="!O9B!O8FIE8W1S(')E<75E<W1E9`H@("`@("H*("`@("`J
M($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T
M3&ES=$]F*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y
M*"1T>7!E*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@
M("`@("`@8V%S92`G9&%T86)A<V5S)SH*("`@("`@("`@("`@("`@("1I9"`]
M($!M<W%L7VQI<W1?9&)S*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@
M("`@("`@("`@("`@)&ED(#T@0&US<6Q?;&ES=%]T86)L97,H)'1H:7,M/F1S
M;ELG9&%T86)A<V4G72P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@("`@(&EF("@A)&ED*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-Q;%)A:7-E17)R;W(H*3L*("`@
M("`@("!]"B`@("`@("`@)&]U="`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@
M*"1R;W<@/2!`;7-Q;%]F971C:%]R;W<H)&ED*2D@>PH@("`@("`@("`@("`D
M;W5T6UT@/2`D<F]W6S!=.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&]U
M=#L*("`@('T*"B`@("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE
M<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N
M9#H*("HO"@H_/@H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+T1"+VUS<W%L+G!H<```````````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P-C4V-#8@,3`U,34T,S0Q,S,@,#(P-C,W
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J(%1H92!014%2($1"(&1R
M:79E<B!F;W(@4$A0)W,@;7-S<6P@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C
M=&EN9R!W:71H($UI8W)O<V]F="!344P@4V5R=F5R(&1A=&%B87-E<PH@*@H@
M*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O
M=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(
M4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@
M=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@
M*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA
M:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@
M1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4W1E
M<FQI;F<@2'5G:&5S(#QS=&5R;&EN9T!P:'`N;F5T/@H@*B!`875T:&]R("`@
M("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@;7-S<6PN<&AP+'8@
M,2XX,R`R,#`U+S`S+S`W(#$X.C(T.C4Q(&1A;FEE;&,@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*
M+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B
M92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP
M:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E
M<F%C="!W:71H(%!(4"=S(&US<W%L(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A
M8W1I;F<@=VET:"!-:6-R;W-O9G0@4U%,(%-E<G9E<B!D871A8F%S97,*("H*
M("H@5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I
M;B!$0E]C;VUM;VXN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P
M86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T97)L:6YG($AU9VAE<R`\
M<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I
M<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E
M<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]M<W-Q;"!E
M>'1E;F1S($1"7V-O;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@
M("\J*@H@("`@("H@5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@
M;V1B8RP@971C+BD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D<&AP='EP92`]("=M<W-Q;"<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T
M86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L
M(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@
M('9A<B`D9&)S>6YT87@@/2`G;7-S<6PG.PH*("`@("\J*@H@("`@("H@5&AE
M(&-A<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@
M*@H@("`@("H@5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@
M4$A0('9E<G-I;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI
M;FL@<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@
M:70G<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H
M92`G;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU
M;&%T92!W:71H(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT
M97(G("`@/2!A;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@
M/2!S:VEP(')O=W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*
M("`@('9A<B`D9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@
M("`@("`@/3X@)V5M=6QA=&4G+`H@("`@("`@("=N97=?;&EN:R<@("`@("`]
M/B!F86QS92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U92P*("`@
M("`@("`G<&-O;FYE8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R
M92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^
M(&9A;'-E+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@
M*3L*"B`@("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@
M8V]D97,@=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@+R\@6%A8($%D9"!H97)E(&5R<F]R(&-O9&5S(&EE.B`G4S$P
M,$4G(#T^($1"7T524D]27U-93E1!6`H@("`@=F%R("1E<G)O<F-O9&5?;6%P
M(#T@87)R87DH"B`@("`@("`@,3$P("`@/3X@1$)?15)23U)?5D%,545?0T]5
M3E1?3TY?4D]7+`H@("`@("`@(#$U-2`@(#T^($1"7T524D]27TY/4U5#2$9)
M14Q$+`H@("`@("`@(#$W,"`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@
M("`R,#<@("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`R,#@@
M("`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`R-#4@("`]/B!$
M0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`U,34@("`]/B!$0E]%
M4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@(#4T-R`@(#T^($1"
M7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,3DQ,R`@/3X@1$)?15)23U)?
M04Q214%$65]%6$E35%,L"B`@("`@("`@,C8R-R`@/3X@1$)?15)23U)?0T].
M4U1204E.5"P*("`@("`@("`R-S$T("`]/B!$0E]%4E)/4E]!3%)%04197T58
M25-44RP*("`@("`@("`S-S`Q("`]/B!$0E]%4E)/4E].3U-50TA404),12P*
M("`@("`@("`X,3,T("`]/B!$0E]%4E)/4E]$259:15)/+`H@("`@*3L*"B`@
M("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A
M=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V
M87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R
M;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V
M87(@87)R87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@
M("`O*BH*("`@("`J(%-H;W5L9"!D871A(&UA;FEP=6QA=&EO;B!Q=65R:65S
M(&)E(&-O;6UI='1E9"!A=71O;6%T:6-A;&QY/PH@("`@("H@0'9A<B!B;V]L
M"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1A=71O
M8V]M;6ET(#T@=')U93L*"B`@("`O*BH*("`@("`J(%1H92!Q=6%N=&ET>2!O
M9B!T<F%N<V%C=&EO;G,@8F5G=6X*("`@("`J"B`@("`@*B![0&EN=&5R;F%L
M("!7:&EL92!T:&ES(&ES('!R:79A=&4L(&ET(&-A;B=T(&%C='5A;&QY(&)E
M(&1E<VEG;F%T960*("`@("`J('!R:79A=&4@:6X@4$A0(#4@8F5C875S92!I
M="!I<R!D:7)E8W1L>2!A8V-E<W-E9"!I;B!T:&4@=&5S="!S=6ET92Y]?0H@
M("`@("H*("`@("`J($!V87(@:6YT96=E<@H@("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`@*B\*("`@('9A<B`D=')A;G-A8W1I;VY?;W!C;W5N="`](#`[
M"@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<W!E8VEF:65D(&EN('1H
M92!$4TX*("`@("`J"B`@("`@*B!)="=S(&$@9FEX('1O(&%L;&]W(&-A;&QS
M('1O(&1I9F9E<F5N="!D871A8F%S97,@:6X@=&AE('-A;64@<V-R:7!T+@H@
M("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1?9&(@/2!N=6QL.PH*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C
M;VYS=')U8W1O<B!C86QL<R`\:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D
M/@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC
M=&EO;B!$0E]M<W-Q;"@I"B`@("!["B`@("`@("`@)'1H:7,M/D1"7V-O;6UO
M;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;FYE8W0H*0H*
M("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R=F5R
M+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E"B`@("`@*@H@("`@("H@
M1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L>2X@(%5S92!$0CHZ8V]N
M;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D
M<VX@("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M
M(&)O;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@
M<&5R<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@
M;VX@<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`]
M(&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO
M;B@G;7-S<6PG*2`F)B`A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G<WEB87-E)RD*
M("`@("`@("`@("`@)B8@(5!%05(Z.FQO861%>'1E;G-I;VXH)W-Y8F%S95]C
M="<I*0H@("`@("`@('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T585$5.4TE/3E].3U1?1D]53D0I.PH@("`@("`@
M('T*"B`@("`@("`@)'1H:7,M/F1S;B`]("1D<VX["B`@("`@("`@:68@*"1D
M<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@)'1H:7,M/F1B<WEN=&%X
M(#T@)&1S;ELG9&)S>6YT87@G73L*("`@("`@("!]"@H@("`@("`@("1P87)A
M;7,@/2!A<G)A>2@*("`@("`@("`@("`@)&1S;ELG:&]S='-P96,G72`_("1D
M<VY;)VAO<W1S<&5C)UT@.B`G;&]C86QH;W-T)RP*("`@("`@("`@("`@)&1S
M;ELG=7-E<FYA;64G72`_("1D<VY;)W5S97)N86UE)UT@.B!N=6QL+`H@("`@
M("`@("`@("`D9'-N6R=P87-S=V]R9"==(#\@)&1S;ELG<&%S<W=O<F0G72`Z
M(&YU;&PL"B`@("`@("`@*3L*("`@("`@("!I9B`H)&1S;ELG<&]R="==*2![
M"B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@*"AS=6)S='(H4$A07T]3+"`P
M+"`S*2`]/2`G5TE.)RD@/R`G+"<@.B`G.B<I"B`@("`@("`@("`@("`@("`@
M("`@("`@("X@)&1S;ELG<&]R="==.PH@("`@("`@('T*"B`@("`@("`@)&-O
M;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=M<W-Q;%]P8V]N;F5C
M="<@.B`G;7-S<6Q?8V]N;F5C="<["@H@("`@("`@("1T:&ES+3YC;VYN96-T
M:6]N(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C;VYN96-T7V9U;F-T:6]N
M+"`D<&%R86US*3L*"B`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C=&EO;BD@
M>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@0&US<W%L7V=E=%]L87-T7VUE<W-A9V4H
M*2D["B`@("`@("`@?0H@("`@("`@(&EF("@D9'-N6R=D871A8F%S92==*2![
M"B`@("`@("`@("`@(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D9'-N6R=D871A
M8F%S92==+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4
M140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!`;7-S<6Q?9V5T7VQA<W1?;65S<V%G92@I*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^7V1B(#T@)&1S;ELG9&%T
M86)A<V4G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J
M*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L
M($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N
M;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!M<W-Q;%]C;&]S92@D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N
M=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S
M(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG"B`@("`@*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U;'0@<F5S<F]U8V4@
M9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@("`J("`@("`@("`@
M("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O=&AE<B!S=6-C97-S
M9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@("L@82!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!S:6UP
M;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES;6%N:7`@/2!$0CHZ
M:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@
M)'%U97)Y.PH@("`@("`@(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D=&AI<RT^
M7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$
M*3L*("`@("`@("!]"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U
M97)Y*"1Q=65R>2D["B`@("`@("`@:68@*"$D=&AI<RT^875T;V-O;6UI="`F
M)B`D:7-M86YI<"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T
M:6]N7V]P8V]U;G0@/3T@,"D@>PH@("`@("`@("`@("`@("`@)')E<W5L="`]
M($!M<W-Q;%]Q=65R>2@G0D5'24X@5%)!3B<L("1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*"D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0K*SL*("`@("`@("!]"B`@("`@("`@
M)')E<W5L="`]($!M<W-Q;%]Q=65R>2@D<75E<GDL("1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@
M("`@+R\@1&5T97)M:6YE('=H:6-H('%U97)I97,@=&AA="!S:&]U;&0@<F5T
M=7)N(&1A=&$L(&%N9"!W:&EC:`H@("`@("`@("\O('-H;W5L9"!R971U<FX@
M86X@97)R;W(@8V]D92!O;FQY+@H@("`@("`@(')E='5R;B`D:7-M86YI<"`_
M($1"7T]+(#H@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE(&EN=&5R
M;F%L(&US<W%L(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L
M92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F8G-Q;"!R
M97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U8FQI8PH@
M("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I<R!A=F%I
M;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F=6YC
M=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T=7)N
M($!M<W-Q;%]N97AT7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@("`@("H@4&QA
M8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T:&4@9VEV96X@
M87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE(&%R<F%Y(&%N
M9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N"B`@("`@*B!3
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I;F9O<FUA=&EO
M;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O
M=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U
M;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H@0'!A<F%M
M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@87)R87D@=&\@
M<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@("`@)&9E=&-H
M;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@8F4@:6YD97AE
M9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@=&AE(')O=R!N
M=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@*@H@("`@("H@
M0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,3"!W:&5N('1H
M92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@("`@("`@("`@
M("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@("H@0'-E92!$
M0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9E
M=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@)')O=VYU;2`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T](&YU;&PI('L*
M("`@("`@("`@("`@:68@*"%`;7-S<6Q?9&%T85]S965K*"1R97-U;'0L("1R
M;W=N=6TI*2!["B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"
M7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0&US<W%L
M7V9E=&-H7V%R<F%Y*"1R97-U;'0L($U34U%,7T%34T]#*3L*("`@("`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]2
M5$%"24Q)5%E?3$]715)#05-%("8F("1A<G(I('L*("`@("`@("`@("`@("`@
M("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%
M4BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D87)R(#T@0&US<W%L7V9E=&-H7W)O=R@D<F5S=6QT*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@
M("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"
M7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H
M:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L
M971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U
M<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T
M:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*
M("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B
M92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U
M;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M
M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C
M90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S
M+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`
M<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R
M965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&US<W%L
M7V9R965?<F5S=6QT*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&YU;4-O;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M
M8F5R(&]F(&-O;'5M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L
M>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N
M=6UB97(@;V8@8V]L=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@
M("`@("`@)&-O;',@/2!`;7-S<6Q?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@
M("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;7-S<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M
M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E
M<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E
M9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S
M97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E
M("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M
M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1R;W=S(#T@0&US<W%L7VYU
M;5]R;W=S*"1R97-U;'0I.PH@("`@("`@(&EF("@D<F]W<R`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A:7-E17)R;W(H
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R;W=S.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J*@H@("`@
M("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@("`@
M("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N<R!I="!O
M;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E='5R;B!I
M;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I9B!T
M:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@<W5P<&]R
M="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO"B`@("!F
M=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@("`@>PH@("`@
M("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`L
M('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES<W5E(&$@=V%R;FEN
M9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@)&]N;V9F(#\@
M=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J*@H@("`@("H@
M0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M;6ET
M*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U
M;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@A0&US<W%L7W-E;&5C=%]D8B@D
M=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*$1"7T524D]27TY/
M1$)314Q%0U1%1"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L
M="`]($!M<W-Q;%]Q=65R>2@G0T]-34E4(%1204XG+"`D=&AI<RT^8V]N;F5C
M=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@
M("`@*B!2979E<G1S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R
M;VQL8F%C:R@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#X@,"D@>PH@("`@("`@("`@("!I9B`H(4!M<W-Q;%]S96QE
M8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<BA$0E]%
M4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1R97-U;'0@/2!`;7-S<6Q?<75E<GDH)U)/3$Q"04-+(%1204XG+"`D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS<W%L4F%I<V5%<G)O<B@I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!A9F9E8W1E9%)O=W,H
M*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O
M=W,@869F96-T960@8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@
M("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG
M="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@
M("!["B`@("`@("`@:68@*$1".CII<TUA;FEP*"1T:&ES+3YL87-T7W%U97)Y
M*2D@>PH@("`@("`@("`@("`D<F5S(#T@0&US<W%L7W%U97)Y*"=S96QE8W0@
M0$!R;W=C;W5N="<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@
M:68@*"$D<F5S*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUS
M<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A
M<B`]($!M<W-Q;%]F971C:%]R;W<H)')E<RD["B`@("`@("`@("`@(&EF("@A
M)&%R*2!["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@,#L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@($!M<W-Q;%]F<F5E7W)E<W5L
M="@D<F5S*3L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D87);,%T["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D<F5S
M=6QT(#T@,#L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97-U;'0["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=$ED*"D*"B`@("`O*BH*
M("`@("`J(%)E='5R;G,@=&AE(&YE>'0@9G)E92!I9"!I;B!A('-E<75E;F-E
M"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@)'-E<5]N86UE("!N86UE
M(&]F('1H92!S97%U96YC90H@("`@("H@0'!A<F%M(&)O;VQE86X@)&]N9&5M
M86YD("!W:&5N('1R=64L('1H92!S97%E;F-E(&ES(&%U=&]M871I8V%L;'D*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&-R96%T960@:68@
M:70@9&]E<R!N;W0@97AI<W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YE>'0@:60@;G5M8F5R(&EN('1H92!S97%U96YC92X*("`@("`J("`@
M("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ;F5X=$E$*"DL($1"7V-O;6UO
M;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUS<W%L.CIC
M<F5A=&5397%U96YC92@I+"!$0E]M<W-Q;#HZ9')O<%-E<75E;F-E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD
M(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG9713
M97%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("!I9B`H(4!M<W-Q;%]S
M96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R*$1"7T52
M4D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@?0H@("`@("`@("1R97!E870@
M/2`P.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YQ=65R>2@B24Y315)4($E.5$\@)'-E<6YA;64@*'9A
M<&]R*2!604Q515,@*#`I(BD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O
M<DAA;F1L:6YG*"D["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z
M.FES17)R;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("@D<F5S=6QT
M+3YG971#;V1E*"D@/3T@1$)?15)23U(@?'P@)')E<W5L="T^9V5T0V]D92@I
M(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2D*("`@("`@("`@("`@>PH@("`@
M("`@("`@("`@("`@)')E<&5A="`](#$["B`@("`@("`@("`@("`@("`D<F5S
M=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@
M("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L
M="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS96EF("@A
M1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("1R97-U
M;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@0$!)1$5.5$E462!&4D]-("1S
M97%N86UE(BD["B`@("`@("`@("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1R97!E870@/2!F86QS
M93L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@
M?0H@("`@("`@("1R97-U;'0@/2`D<F5S=6QT+3YF971C:%)O=RA$0E]&151#
M2$U/1$5?3U)$15)%1"D["B`@("`@("`@<F5T=7)N("1R97-U;'1;,%T["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W('-E<75E;F-E"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@
M=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ8W)E871E4V5Q=65N
M8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@
M("`@1$)?;7-S<6PZ.FYE>'1)1"@I+"!$0E]M<W-Q;#HZ9')O<%-E<75E;F-E
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N
M86UE*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T-214%4
M12!404),12`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES
M+3YG971397%U96YC94YA;64H)'-E<5]N86UE*0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G("A;:61=(%MI;G1=($E$14Y42519("@Q+"`Q*2!.
M3U0@3E5,3"PG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@6W9A
M<&]R72!;:6YT72!.54Q,*2<I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@
M<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M
M92`@;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*
M("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%
M<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N
M8V5.86UE*"DL"B`@("`@*B`@("`@($1"7VUS<W%L.CIN97AT240H*2P@1$)?
M;7-S<6PZ.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M9')O<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@+B`D=&AI<RT^9V5T4V5Q=65N
M8V5.86UE*"1S97%?;F%M92DI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[('%U;W1E261E;G1I9FEE<B@I"@H@("`@+RHJ"B`@("`@*B!1=6]T97,@
M82!S=')I;F<@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D(&%S(&$@=&%B;&4@
M;W(@8V]L=6UN(&YA;64*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M='(@(&ED96YT:69I97(@;F%M92!T;R!B92!Q=6]T960*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@<75O=&5D(&ED96YT:69I97(@<W1R:6YG"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G%U;W1E261E;G1I9FEE<B@I
M"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E261E;G1I9FEE<B@D
M<W1R*0H@("`@>PH@("`@("`@(')E='5R;B`G6R<@+B!S=')?<F5P;&%C92@G
M72<L("==72<L("1S='(I("X@)UTG.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&US<W%L4F%I<V5%<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D
M=6-E<R!A($1"7T5R<F]R(&]B:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@
M<')O8FQE;0H@("`@("H*("`@("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T
M:&4@97)R;W(@:7,@8F5I;F<@;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R
M92X@($EF('1H:7,@:7-N)W0@<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@('1H92!E<G)O<B!I;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H
M92!$0DU3+@H@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?
M17)R;W(@;V)J96-T"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A
M:7-E17)R;W(H*2P*("`@("`J("`@("`@1$)?;7-S<6PZ.F5R<F]R3F%T:79E
M*"DL($1"7VUS<W%L.CIE<G)O<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!M<W-Q;%)A:7-E17)R;W(H)&-O9&4@/2!N=6QL*0H@("`@>PH@("`@("`@
M("1M97-S86=E(#T@0&US<W%L7V=E=%]L87-T7VUE<W-A9V4H*3L*("`@("`@
M("!I9B`H(21C;V1E*2!["B`@("`@("`@("`@("1C;V1E(#T@)'1H:7,M/F5R
M<F]R3F%T:79E*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D=&AI<RT^97)R;W)#;V1E*"1C;V1E+"`D;65S<V%G92DL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL
M(&YU;&PL("(D8V]D92`M("1M97-S86=E(BD["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T
M<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@<')O9'5C960@8GD@=&AE
M(&QA<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE($1"
M35,G(&5R<F]R(&-O9&4*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I
M=F4H*0H@("`@>PH@("`@("`@("1R97,@/2!`;7-S<6Q?<75E<GDH)W-E;&5C
M="!`0$524D]2(&%S($5R<F]R0V]D92<L("1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("!I9B`H(21R97,I('L*("`@("`@("`@("`@<F5T=7)N($1"7T52
M4D]2.PH@("`@("`@('T*("`@("`@("`D<F]W(#T@0&US<W%L7V9E=&-H7W)O
M=R@D<F5S*3L*("`@("`@("!R971U<FX@)')O=ULP73L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!E<G)O<D-O9&4H*0H*("`@("\J*@H@("`@("H@
M1&5T97)M:6YE<R!014%2.CI$0B!E<G)O<B!C;V1E(&9R;VT@;7-S<6PG<R!N
M871I=F4@8V]D97,N"B`@("`@*@H@("`@("H@268@/'9A<CXD;F%T:79E8V]D
M93PO=F%R/B!I<VXG="!K;F]W;B!Y970L(&ET('=I;&P@8F4@;&]O:V5D('5P
M+@H@("`@("H*("`@("`J($!P87)A;2`@;6EX960@("1N871I=F5C;V1E("!M
M<W-Q;"!E<G)O<B!C;V1E+"!I9B!K;F]W;@H@("`@("H@0')E='5R;B!I;G1E
M9V5R("!A;B!E<G)O<B!N=6UB97(@9G)O;2!A($1"(&5R<F]R(&-O;G-T86YT
M"B`@("`@*B!`<V5E(&5R<F]R3F%T:79E*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@97)R;W)#;V1E*"1N871I=F5C;V1E(#T@;G5L;"P@)&US9R`]("<G*0H@
M("`@>PH@("`@("`@(&EF("@A)&YA=&EV96-O9&4I('L*("`@("`@("`@("`@
M)&YA=&EV96-O9&4@/2`D=&AI<RT^97)R;W).871I=F4H*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YE<G)O<F-O9&5?;6%P6R1N871I
M=F5C;V1E72DI('L*("`@("`@("`@("`@:68@*"1N871I=F5C;V1E(#T](#,W
M,#$*("`@("`@("`@("`@("`@("8F('!R96=?;6%T8V@H)R]#86YN;W0@9')O
M<"!T:&4@:6YD97@O:2<L("1M<V<I*0H@("`@("`@("`@("!["B`@("`@("`@
M("`@("`@("!R971U<FX@1$)?15)23U)?3D]47T9/54Y$.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^97)R;W)C;V1E7VUA<%LD
M;F%T:79E8V]D95T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T
M=7)N($1"7T524D]2.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I
M;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J($Y/5$4Z(&]N;'D@<W5P<&]R=',@)W1A8FQE)R!A;F0@)V9L
M86=S)R!I9B`\=F%R/B1R97-U;'0\+W9A<CX*("`@("`J(&ES(&$@=&%B;&4@
M;F%M92X*("`@("`J"B`@("`@*B!`<&%R86T@;V)J96-T?'-T<FEN9R`@)')E
M<W5L="`@1$)?<F5S=6QT(&]B:F5C="!F<F]M(&$@<75E<GD@;W(@80H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@8V]N
M=&%I;FEN9R!T:&4@;F%M92!O9B!A('1A8FQE+@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!7:&EL92!T:&ES(&%L<V\@86-C97!T
M<R!A('%U97)Y(')E<W5L=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R97-O=7)C92!I9&5N=&EF:65R+"!T:&ES(&)E:&%V:6]R
M(&ES"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&1E
M<')E8V%T960N"B`@("`@*B!`<&%R86T@:6YT("`@("`@("`@("`@)&UO9&4@
M("`@82!V86QI9"!T86)L94EN9F\@;6]D90H@("`@("H*("`@("`J($!R971U
M<FX@87)R87D@(&%N(&%S<V]C:6%T:79E(&%R<F%Y('=I=&@@=&AE(&EN9F]R
M;6%T:6]N(')E<75E<W1E9"X*("`@("`J("`@("`@("`@("`@("`@("!!($1"
M7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIT86)L94EN9F\H*0H@("`@("HO"B`@("!F=6YC=&EO;B!T
M86)L94EN9F\H)')E<W5L="P@)&UO9&4@/2!N=6QL*0H@("`@>PH@("`@("`@
M(&EF("AI<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@
M("`@("`@("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I
M9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@("`@(&EF("@A0&US<W%L
M7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7-S<6Q286ES945R<F]R
M*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&ED(#T@0&US<W%L7W%U97)Y*")314Q%0U0@*B!&4D]-("1R97-U
M;'0@5TA%4D4@,3TP(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@
M/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR97-U
M;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY
M(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT
M<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@
M("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C
M96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@
M("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@($AE
M<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO"B`@
M("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R
M:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E<V]U
M<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM<W-Q;%)A
M:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E
M7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@
M("`@)&-O=6YT(#T@0&US<W%L7VYU;5]F:65L9',H)&ED*3L*("`@("`@("`D
M<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@
M("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@
M("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G
M=&%B;&4G(#T^("1G;W1?<W1R:6YG(#\@)&-A<V5?9G5N8R@D<F5S=6QT*2`Z
M("<G+`H@("`@("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*$!M
M<W-Q;%]F:65L9%]N86UE*"1I9"P@)&DI*2P*("`@("`@("`@("`@("`@("=T
M>7!E)R`@/3X@0&US<W%L7V9I96QD7W1Y<&4H)&ED+"`D:2DL"B`@("`@("`@
M("`@("`@("`G;&5N)R`@(#T^($!M<W-Q;%]F:65L9%]L96YG=&@H)&ED+"`D
M:2DL"B`@("`@("`@("`@("`@("`O+R!792!O;FQY('-U<'!O<G0@9FQA9W,@
M9F]R('1A8FQE"B`@("`@("`@("`@("`@("`G9FQA9W,G(#T^("1G;W1?<W1R
M:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@)'1H:7,M/E]M<W-Q
M;%]F:65L9%]F;&%G<R@D<F5S=6QT+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@0&US<W%L7V9I96QD
M7VYA;64H)&ED+"`D:2DI"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@
M)R<L"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"
M7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D
M97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%
M*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD
M:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O
M;FQY(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H
M)&=O=%]S=')I;F<I('L*("`@("`@("`@("`@0&US<W%L7V9R965?<F5S=6QT
M*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(%]M<W-Q;%]F:65L9%]F;&%G<R@I"@H@
M("`@+RHJ"B`@("`@*B!'970@82!C;VQU;6XG<R!F;&%G<PH@("`@("H*("`@
M("`J(%-U<'!O<G1S(")N;W1?;G5L;"(L(")P<FEM87)Y7VME>2(L"B`@("`@
M*B`B875T;U]I;F-R96UE;G0B("AM<W-Q;"!I9&5N=&ET>2DL(")T:6UE<W1A
M;7`B("AM<W-Q;"!T:6UE<W1A;7`I+`H@("`@("H@(G5N:7%U95]K97DB("AM
M<W-Q;"!U;FEQ=64@:6YD97@L('5N:7%U92!C:&5C:R!O<B!P<FEM87)Y7VME
M>2D@86YD"B`@("`@*B`B;75L=&EP;&5?:V5Y(B`H;75L=&EK97D@:6YD97@I
M"B`@("`@*@H@("`@("H@;7-S<6P@=&EM97-T86UP(&ES($Y/5"!S:6UI;&%R
M('1O('1H92!M>7-Q;"!T:6UE<W1A;7`@<V\@=&AI<R!I<R!M87EB90H@("`@
M("H@;F]T('5S969U;"!A="!A;&P@+2!I<R!T:&4@8F5H879I;W5R(&]F(&UY
M<W%L7V9I96QD7V9L86=S('1H870@<')I;6%R>0H@("`@("H@:V5Y<R!A<F4@
M86QW87D@=6YI<75E/R!I<R!T:&4@:6YT97)P<F5T871I;VX@;V8@;75L=&EP
M;&5?:V5Y(&-O<G)E8W0_"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M=&%B;&4@("!T:&4@=&%B;&4@;F%M90H@("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]L=6UN("!T:&4@9FEE;&0@;F%M90H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@9FQA9W,*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!A=71H;W(@2F]E<FX@0F%R=&AE;"`\:E]B87)T:&5L0'=E
M8BYD93X*("`@("`J+PH@("`@9G5N8W1I;VX@7VUS<W%L7V9I96QD7V9L86=S
M*"1T86)L92P@)&-O;'5M;BD*("`@('L*("`@("`@("!S=&%T:6,@)'1A8FQE
M3F%M92`](&YU;&P["B`@("`@("`@<W1A=&EC("1F;&%G<R`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@D=&%B;&4@(3T@)'1A8FQE3F%M92D@>PH*("`@("`@
M("`@("`@)&9L86=S(#T@87)R87DH*3L*("`@("`@("`@("`@)'1A8FQE3F%M
M92`]("1T86)L93L*"B`@("`@("`@("`@("\O(&=E="!U;FEQ=64@86YD('!R
M:6UA<GD@:V5Y<PH@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F=E=$%L;"@B
M15A%0R!34%](14Q024Y$15A;)'1A8FQE72(L($1"7T9%5$-(34]$15]!4U-/
M0RD["@H@("`@("`@("`@("!F;W)E86-H("@D<F5S(&%S("1V86PI('L*("`@
M("`@("`@("`@("`@("1K97ES(#T@97AP;&]D92@G+"`G+"`D=F%L6R=I;F1E
M>%]K97ES)UTI.PH*("`@("`@("`@("`@("`@(&EF("AS:7IE;V8H)&ME>7,I
M(#X@,2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1K97ES(&%S
M("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?
M9FQA9R@D9FQA9W-;)&ME>5TL("=M=6QT:7!L95]K97DG*3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@:68@*'-T<G!O<R@D=F%L6R=I;F1E>%]D97-C<FEP=&EO;B==+"`G<')I
M;6%R>2!K97DG*2D@>PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1K
M97ES(&%S("1K97DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/E]A9&1?9FQA9R@D9FQA9W-;)&ME>5TL("=P<FEM87)Y7VME>2<I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("AS
M=')P;W,H)'9A;%LG:6YD97A?9&5S8W)I<'1I;VXG72P@)W5N:7%U92<I*2![
M"B`@("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F
M;&%G<ULD:V5Y72P@)W5N:7%U95]K97DG*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("\O(&=E="!A=71O7VEN8W)E;65N="P@;F]T7VYU;&P@86YD('1I;65S
M=&%M<`H@("`@("`@("`@("`D<F5S(#T@)'1H:7,M/F=E=$%L;"@B15A%0R!3
M4%]#3TQ534Y36R1T86)L95TB+"!$0E]&151#2$U/1$5?05-33T,I.PH*("`@
M("`@("`@("`@9F]R96%C:"`H)')E<R!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("`D=F%L(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1V86PL($-!4T5?
M3$]715(I.PH@("`@("`@("`@("`@("`@:68@*"1V86Q;)VYU;&QA8FQE)UT@
M/3T@)S`G*2!["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]A9&1?9FQA
M9R@D9FQA9W-;)'9A;%LG8V]L=6UN7VYA;64G75TL("=N;W1?;G5L;"<I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*'-T<G!O<R@D
M=F%L6R=T>7!E7VYA;64G72P@)VED96YT:71Y)RDI('L*("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD=F%L6R=C;VQU;6Y?
M;F%M92==72P@)V%U=&]?:6YC<F5M96YT)RD["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!I9B`H<W1R<&]S*"1V86Q;)W1Y<&5?;F%M92==
M+"`G=&EM97-T86UP)RDI('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V%D9%]F;&%G*"1F;&%G<ULD=F%L6R=C;VQU;6Y?;F%M92==72P@)W1I;65S
M=&%M<"<I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H87)R87E?:V5Y7V5X:7-T<R@D8V]L=6UN+"`D
M9FQA9W,I*2!["B`@("`@("`@("`@(')E='5R;BAI;7!L;V1E*"<@)RP@)&9L
M86=S6R1C;VQU;6Y=*2D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G)SL*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!?861D7V9L86<H*0H*("`@
M("\J*@H@("`@("H@061D<R!A('-T<FEN9R!T;R!T:&4@9FQA9W,@87)R87D@
M:68@=&AE(&9L86<@:7,@;F]T('EE="!I;B!T:&5R90H@("`@("H@+2!I9B!T
M:&5R92!I<R!N;R!F;&%G('!R97-E;G0@=&AE(&%R<F%Y(&ES(&-R96%T960*
M("`@("`J"B`@("`@*B!`<&%R86T@87)R87D@("8D87)R87D@('1H92!R969E
M<F5N8V4@=&\@=&AE(&9L86<M87)R87D*("`@("`J($!P87)A;2!S=')I;F<@
M)'9A;'5E("`@=&AE(&9L86<@=F%L=64*("`@("`J"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J($!A
M=71H;W(@2F]E<FX@0F%R=&AE;"`\:E]B87)T:&5L0'=E8BYD93X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7V%D9%]F;&%G*"8D87)R87DL("1V86QU92D*("`@
M('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<G)A>2DI('L*("`@("`@("`@
M("`@)&%R<F%Y(#T@87)R87DH)'9A;'5E*3L*("`@("`@("!](&5L<V5I9B`H
M(6EN7V%R<F%Y*"1V86QU92P@)&%R<F%Y*2D@>PH@("`@("`@("`@("!A<G)A
M>5]P=7-H*"1A<G)A>2P@)'9A;'5E*3L*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*
M("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI
M<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!`
M<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W
M86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E<B!D
M;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE(&]B
M:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O
M=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@
M>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G
M=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`B4T5,14-4(&YA;64@
M1E)/32!S>7-O8FIE8W1S(%=(15)%('1Y<&4@/2`G52<B"B`@("`@("`@("`@
M("`@("`@("`@("`@+B`G($]21$52($)9(&YA;64G.PH@("`@("`@("`@("!C
M87-E("=V:65W<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@(E-%3$5#5"!N
M86UE($923TT@<WES;V)J96-T<R!72$5212!T>7!E(#T@)U8G(CL*("`@("`@
M("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@
M("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*?0H*+RH*("H@3&]C86P@=F%R
M:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*
M("H@16YD.@H@*B\*"C\^"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M1$(O;7ES<6PN<&AP````````````````````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`W-S`T-R`Q,#4Q-30S-#$S,R`P,C`V-#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!0
M2%`G<R!M>7-Q;"!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@
M37E344P@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J
M"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I
M;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO
M=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT
M>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@
M4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U
M9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`
M<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY
M+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C:V%G92`@("!$
M0@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!M
M>7-Q;"YP:'`L=B`Q+C$Q-R`R,#`U+S`S+S(Y(#$U.C`S.C(V(&1A;FEE;&,@
M17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S
M('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@
M)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%05(@1$(@
M=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&UY<W%L(&5X=&5N<VEO;@H@
M*B!F;W(@:6YT97)A8W1I;F<@=VET:"!->5-13"!D871A8F%S97,*("H*("H@
M5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$
M0E]C;VUM;VXN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K
M86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS<V)`<&AP
M+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'
M<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS
M92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@4F5L
M96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]M>7-Q;"!E>'1E;F1S($1"7V-O
M;6UO;@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*("`@("\J*@H@("`@("H@
M5&AE($1"(&1R:79E<B!T>7!E("AM>7-Q;"P@;V-I."P@;V1B8RP@971C+BD*
M("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<&AP='EP92`]
M("=M>7-Q;"<["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X
M('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A
M;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT
M87@@/2`G;7ES<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&-A<&%B:6QI=&EE
M<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N"B`@("`@*@H@("`@("H@5&AE
M("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN<R!T:&4@4$A0('9E<G-I;VX@
M=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@;F5W7VQI;FL@<W5P<&]R="!F
M;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L<V4@:68@:70G<R!U;G-U<'!O
M<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG(&]F('1H92`G;&EM:70G(&5L
M96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G(#T@96UU;&%T92!W:71H(&9E
M=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@*R`G86QT97(G("`@/2!A;'1E
M<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS92`@("`@/2!S:VEP(')O=W,*
M("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9F5A
M='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM:70G("`@("`@("`@/3X@)V%L
M=&5R)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@)S0N,BXP)RP*("`@
M("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U92P*("`@("`@("`G<&-O;FYE
M8W0G("`@("`@/3X@=')U92P*("`@("`@("`G<')E<&%R92<@("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@)W-S;"<@("`@("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@("`O*BH*
M("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@=&\@1$(@
M97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`@("`@,3`P-"`]/B!$0E]%
M4E)/4E]#04Y.3U1?0U)%051%+`H@("`@("`@(#$P,#4@/3X@1$)?15)23U)?
M0T%.3D]47T-214%412P*("`@("`@("`Q,#`V(#T^($1"7T524D]27T-!3DY/
M5%]#4D5!5$4L"B`@("`@("`@,3`P-R`]/B!$0E]%4E)/4E]!3%)%04197T58
M25-44RP*("`@("`@("`Q,#`X(#T^($1"7T524D]27T-!3DY/5%]$4D]0+`H@
M("`@("`@(#$P,C(@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@
M("`@,3`T-"`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@
M(#$P-#8@/3X@1$)?15)23U)?3D]$0E-%3$5#5$5$+`H@("`@("`@(#$P-#@@
M/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`Q,#0Y(#T^($1"7T52
M4D]27TY/4U5#2$1"+`H@("`@("`@(#$P-3`@/3X@1$)?15)23U)?04Q214%$
M65]%6$E35%,L"B`@("`@("`@,3`U,2`]/B!$0E]%4E)/4E].3U-50TA404),
M12P*("`@("`@("`Q,#4T(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@
M("`@(#$P-C$@/3X@1$)?15)23U)?04Q214%$65]%6$E35%,L"B`@("`@("`@
M,3`V,B`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#8T
M(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`Q,#DQ(#T^($1"7T524D]2
M7TY/5%]&3U5.1"P*("`@("`@("`Q,3`P(#T^($1"7T524D]27TY/5%],3T-+
M140L"B`@("`@("`@,3$S-B`]/B!$0E]%4E)/4E]604Q515]#3U5.5%]/3E]2
M3U<L"B`@("`@("`@,3$T,B`]/B!$0E]%4E)/4E]!0T-%4U-?5DE/3$%424].
M+`H@("`@("`@(#$Q-#8@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@
M("`@,3(Q-B`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@(#$R,3<@
M/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("D["@H@("`@+RHJ"B`@("`@
M*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE8W1I;VX@8W)E871E9"!B>2!02%`*
M("`@("`J($!V87(@<F5S;W5R8V4*("`@("`J+PH@("`@=F%R("1C;VYN96-T
M:6]N.PH*("`@("\J*@H@("`@("H@5&AE($133B!I;F9O<FUA=&EO;B!F;W(@
M8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D9'-N(#T@87)R87DH*3L*"@H@("`@+RHJ"B`@("`@
M*B!3:&]U;&0@9&%T82!M86YI<'5L871I;VX@<75E<FEE<R!B92!C;VUM:71T
M960@875T;VUA=&EC86QL>3\*("`@("`J($!V87(@8F]O;`H@("`@("H@0&%C
M8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D875T;V-O;6UI="`]('1R
M=64["@H@("`@+RHJ"B`@("`@*B!4:&4@<75A;G1I='D@;V8@=')A;G-A8W1I
M;VYS(&)E9W5N"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"`@5VAI;&4@=&AI
M<R!I<R!P<FEV871E+"!I="!C86XG="!A8W1U86QL>2!B92!D97-I9VYA=&5D
M"B`@("`@*B!P<FEV871E(&EN(%!(4"`U(&)E8V%U<V4@:70@:7,@9&ER96-T
M;'D@86-C97-S960@:6X@=&AE('1E<W0@<W5I=&4N?7T*("`@("`J"B`@("`@
M*B!`=F%R(&EN=&5G97(*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!V87(@)'1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH*("`@("\J*@H@
M("`@("H@5&AE(&1A=&%B87-E('-P96-I9FEE9"!I;B!T:&4@1%-."B`@("`@
M*@H@("`@("H@270G<R!A(&9I>"!T;R!A;&QO=R!C86QL<R!T;R!D:69F97)E
M;G0@9&%T86)A<V5S(&EN('1H92!S86UE('-C<FEP="X*("`@("`J"B`@("`@
M*B!`=F%R('-T<FEN9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V1B(#T@)R<["@H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O
M;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R(&-A
M;&QS(#QK8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@("`@
M("H@0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7VUY<W%L
M*"D*("`@('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@
M*B!#;VYN96-T('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@
M;W!E;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H
M:7,@;65T:&]D(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A
M9"X*("`@("`J"B`@("`@*B!014%2($1")W,@;7ES<6P@9')I=F5R('-U<'!O
M<G1S('1H92!F;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@
M("L@;F5W7VQI;FL@("`@("!)9B!S970@=&\@=')U92P@8V%U<V5S('-U8G-E
M<75E;G0@8V%L;',@=&\@8V]N;F5C="@I"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@=&\@<F5T=7)N(&$@;F5W(&-O;FYE8W1I;VX@;&EN:R!I;G-T96%D
M(&]F('1H90H@("`@("H@("`@("`@("`@("`@("`@("`@(&5X:7-T:6YG(&]N
M92X@(%=!4DY)3D<Z('1H:7,@:7,@;F]T('!O<G1A8FQE('1O"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@;W1H97(@1$)-4R=S+B!!=F%I;&%B;&4@<VEN
M8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J("`@*R!C;&EE;G1?9FQA9W,@($%N
M>2!C;VUB:6YA=&EO;B!O9B!-65-13%]#3$E%3E1?*B!C;VYS=&%N=',N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@3VYL>2!U<V5D(&EF(%!(4"!I<R!A
M="!V97)S:6]N(#0N,RXP(&]R(&=R96%T97(N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XW+C`N"B`@("`@
M*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@("`@("`@("!T:&4@9&%T82!S
M;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O;VP@("1P97)S:7-T96YT("!S
M:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R<VES=&5N=#\*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]N
M;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A;'-E*0H@("`@>PH@("`@("`@
M(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G;7ES<6PG*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y3
M24].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N
M(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@
M("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@
M("`@("`@('T*"B`@("`@("`@)'!A<F%M<R`](&%R<F%Y*"D["B`@("`@("`@
M:68@*"1D<VY;)W!R;W1O8V]L)UT@)B8@)&1S;ELG<')O=&]C;VPG72`]/2`G
M=6YI>"<I('L*("`@("`@("`@("`@)'!A<F%M<ULP72`]("<Z)R`N("1D<VY;
M)W-O8VME="==.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1P87)A
M;7-;,%T@/2`D9'-N6R=H;W-T<W!E8R==(#\@)&1S;ELG:&]S='-P96,G70H@
M("`@("`@("`@("`@("`@("`@("`@("`@.B`G;&]C86QH;W-T)SL*("`@("`@
M("`@("`@:68@*"1D<VY;)W!O<G0G72D@>PH@("`@("`@("`@("`@("`@)'!A
M<F%M<ULP72`N/2`G.B<@+B`D9'-N6R=P;W)T)UT["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@)'!A<F%M<UM=(#T@)&1S;ELG=7-E<FYA;64G
M72`_("1D<VY;)W5S97)N86UE)UT@.B!N=6QL.PH@("`@("`@("1P87)A;7-;
M72`]("1D<VY;)W!A<W-W;W)D)UT@/R`D9'-N6R=P87-S=V]R9"==(#H@;G5L
M;#L*"B`@("`@("`@:68@*"$D<&5R<VES=&5N="D@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)&1S;ELG;F5W7VQI;FLG72D*("`@("`@("`@("`@("`@("8F
M("@D9'-N6R=N97=?;&EN:R==(#T]("=T<G5E)R!\?"`D9'-N6R=N97=?;&EN
M:R==(#T]/2!T<G5E*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M)'!A<F%M<UM=(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1P87)A;7-;72`](&9A;'-E.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&EF("AV97)S:6]N7V-O;7!A<F4H<&AP=F5R<VEO
M;B@I+"`G-"XS+C`G+"`G/CTG*2D@>PH@("`@("`@("`@("`D<&%R86US6UT@
M/2!I<W-E="@D9'-N6R=C;&EE;G1?9FQA9W,G72D*("`@("`@("`@("`@("`@
M("`@("`@("`@/R`D9'-N6R=C;&EE;G1?9FQA9W,G72`Z(&YU;&P["B`@("`@
M("`@?0H*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT
M(#\@)VUY<W%L7W!C;VYN96-T)R`Z("=M>7-Q;%]C;VYN96-T)SL*"B`@("`@
M("`@)&EN:2`](&EN:5]G970H)W1R86-K7V5R<F]R<R<I.PH@("`@("`@("1P
M:'!?97)R;W)M<V<@/2`G)SL*("`@("`@("!I9B`H)&EN:2D@>PH@("`@("`@
M("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A
M>2@D8V]N;F5C=%]F=6YC=&EO;BP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S
M)RP@,2D["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?
M=7-E<E]F=6YC7V%R<F%Y*"1C;VYN96-T7V9U;F-T:6]N+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&%R86US*3L*("`@("`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@
M)&EN:2D["B`@("`@("`@?0H*("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T
M:6]N*2!["B`@("`@("`@("`@(&EF("@H)&5R<B`]($!M>7-Q;%]E<G)O<B@I
M*2`A/2`G)RD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL
M(`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E
M<G(I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!H<%]E<G)O<FUS9RD["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("@D9'-N6R=D871A8F%S92==*2!["B`@("`@
M("`@("`@(&EF("@A0&UY<W%L7W-E;&5C=%]D8B@D9'-N6R=D871A8F%S92==
M+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]D8B`]("1D<VY;)V1A=&%B87-E)UT["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@9&ES8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C
M;VYN96-T<R!F<F]M('1H92!D871A8F%S92!S97)V97(*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I
M;'5R90H@("`@("HO"B`@("!F=6YC=&EO;B!D:7-C;VYN96-T*"D*("`@('L*
M("`@("`@("`D<F5T(#T@0&UY<W%L7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@
M<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM
M<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T
M:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@1V5N97)A;&QY('5S
M97,@;7ES<6Q?<75E<GDH*2X@($EF('EO=2!W86YT('1O('5S90H@("`@("H@
M;7ES<6Q?=6YB=69F97)E9%]Q=65R>2@I('-E="!T:&4@(G)E<W5L=%]B=69F
M97)I;F<B(&]P=&EO;B!T;R`P('5S:6YG"B`@("`@*B!S971/<'1I;VYS*"DN
M("!4:&ES(&]P=&EO;B!W87,@861D960@:6X@4F5L96%S92`Q+C<N,"X*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN
M9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT
M(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@
M*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H
M97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K
M(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1I<VUA
M;FEP(#T@1$(Z.FES36%N:7`H)'%U97)Y*3L*("`@("`@("`D=&AI<RT^;&%S
M=%]Q=65R>2`]("1Q=65R>3L*("`@("`@("`D<75E<GD@/2`D=&AI<RT^;6]D
M:69Y475E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H)'1H:7,M/E]D8BD@>PH@
M("`@("`@("`@("!I9B`H(4!M>7-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@
M)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/FUY<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@A)'1H:7,M
M/F%U=&]C;VUM:70@)B8@)&ES;6%N:7`I('L*("`@("`@("`@("`@:68@*"1T
M:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T](#`I('L*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2!`;7ES<6Q?<75E<GDH)U-%5"!!551/0T]-34E4/3`G
M+"`D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@0&UY<W%L7W%U97)Y*"="14=)3B<L("1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R<F]R*"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M
M/G1R86YS86-T:6]N7V]P8V]U;G0K*SL*("`@("`@("!]"B`@("`@("`@:68@
M*"$D=&AI<RT^;W!T:6]N<ULG<F5S=6QT7V)U9F9E<FEN9R==*2!["B`@("`@
M("`@("`@("1R97-U;'0@/2!`;7ES<6Q?=6YB=69F97)E9%]Q=65R>2@D<75E
M<GDL("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<F5S=6QT(#T@0&UY<W%L7W%U97)Y*"1Q=65R>2P@)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@('T*("`@("`@("!I9B`H(21R97-U;'0I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H
M*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1R97-U;'0I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@
M("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E
M<FYA;"!M>7-Q;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B
M;&4@<F5S=6QT"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:&%S(&YO="!B
M965N(&EM<&QE;65N=&5D('EE="X*("`@("`J"B`@("`@*B!`<&%R86T@82!V
M86QI9"!S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R
M;B!F86QS90H@("`@("HO"B`@("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U
M;'0I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0
M;&%C97,@82!R;W<@9G)O;2!T:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E
M;B!A<G)A>0H@("`@("H*("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@
M86YD('1H92!D871A('1H97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J
M(%-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T
M:6]N+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T
M;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ
M9F5T8VA);G1O*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P
M<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R
M871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E
M<W5L="`@("!T:&4@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R
M86T@87)R87D@("`@)&%R<B`@("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T
M;R!P=70@=&AE(&1A=&$@:6X*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T
M8VAM;V1E(&AO=R!T:&4@<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E
M>&5D"B`@("`@*B!`<&%R86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W
M(&YU;6)E<B!T;R!F971C:"`H,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@
M=&AE(&5N9"!O9B!A(')E<W5L="!S970@:7,*("`@("`J("`@("`@("`@("`@
M("`@("!R96%C:&5D(&]R(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E
M($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@
M9F5T8VA);G1O*"1R97-U;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M
M(#T@;G5L;"D*("`@('L*("`@("`@("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@
M>PH@("`@("`@("`@("!I9B`H(4!M>7-Q;%]D871A7W-E96LH)')E<W5L="P@
M)')O=VYU;2DI('L*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D9F5T8VAM;V1E("8@
M1$)?1D540TA-3T1%7T%34T]#*2!["B`@("`@("`@("`@("1A<G(@/2!`;7ES
M<6Q?9F5T8VA?87)R87DH)')E<W5L="P@35E344Q?05-33T,I.PH@("`@("`@
M("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]0
M3U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@
M("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/
M5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1A<G(@/2!`;7ES<6Q?9F5T8VA?<F]W*"1R97-U;'0I.PH@("`@("`@
M('T*("`@("`@("!I9B`H(21A<G(I('L*("`@("`@("`@("`@<F5T=7)N(&YU
M;&P["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@
M("`@("\J"B`@("`@("`@("`@("`J($5V96X@=&AO=6=H('1H:7,@1$)-4R!A
M;')E861Y('1R:6US(&]U='!U="P@=V4@9&\@=&AI<R!B96-A=7-E"B`@("`@
M("`@("`@("`J(&$@9FEE;&0@;6EG:'0@:&%V92!I;G1E;G1I;VYA;"!W:&ET
M97-P86-E(&%T('1H92!E;F0@=&AA=`H@("`@("`@("`@("`@*B!G971S(')E
M;6]V960@8GD@1$)?4$]25$%"24Q)5%E?4E1224T@=6YD97(@86YO=&AE<B!D
M<FEV97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D=&AI<RT^7W)T
M<FEM07)R87E686QU97,H)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7TY53$Q?5$]?14U05%DI('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T
M3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&9R965297-U;'0H*0H*("`@("\J*@H@("`@("H@1&5L971E<R!T:&4@<F5S
M=6QT('-E="!A;F0@9G)E97,@=&AE(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M
M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E
M<W5L=#HZ9G)E92@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B
M<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A
M<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R
M97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!I9B`D
M<F5S=6QT(&ES(&EN=F%L:60*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L
M=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R965297-U;'0H)')E
M<W5L="D*("`@('L*("`@("`@("!R971U<FX@0&UY<W%L7V9R965?<F5S=6QT
M*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O
M;',H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M
M;G,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@
M:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@
M("H@1$)?<F5S=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E
M(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L
M="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@
M<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L
M=6UN<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@
M("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!N=6U#;VQS*"1R97-U;'0I"B`@("!["B`@("`@("`@)&-O;',@
M/2!`;7ES<6Q?;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C
M;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6Q286ES945R
M<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D8V]L<SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@
M("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@<F5S=6QT('-E=`H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C
M86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M4F]W
M<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D
M(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE
M8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(
M4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U
M<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN
M=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("1R;W=S(#T@0&UY<W%L7VYU;5]R;W=S*"1R97-U
M;'0I.PH@("`@("`@(&EF("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/FUY<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R
M(&1I<V%B;&5S(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N
M<R!I="!O9F8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@
M("`J("`@("`@("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET
M=&EN9R!T<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#
M;VUM:70H)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@6%A8(&EF
M("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD('!R
M;V)A8FQY"B`@("`@("`@+R\@:7-S=64@82!W87)N:6YG(&AE<F4N"B`@("`@
M("`@)'1H:7,M/F%U=&]C;VUM:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L<V4[
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C
M=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?9&(I('L*("`@("`@("`@("`@("`@(&EF
M("@A0&UY<W%L7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^8V]N;F5C
M=&EO;BDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY
M<W%L4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,14-4140I.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1R97-U;'0@
M/2!`;7ES<6Q?<75E<GDH)T-/34U)5"<L("1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G4T54($%55$]#
M3TU-250],2<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES
M<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(')O;&QB86-K*"D*"B`@("`O*BH*("`@("`J(%)E=F5R=',@=&AE(&-U<G)E
M;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*B\*("`@(&9U;F-T:6]N(')O;&QB86-K*"D*("`@('L*("`@("`@
M("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^7V1B*2!["B`@("`@("`@("`@("`@("!I9B`H
M(4!M>7-Q;%]S96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I
M;VXI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q
M;%)A:7-E17)R;W(H1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D<F5S=6QT(#T@
M0&UY<W%L7W%U97)Y*"=23TQ,0D%#2R<L("1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@)')E<W5L="`]($!M>7-Q;%]Q=65R>2@G4T54($%55$]#
M3TU-250],2<L("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)'1H
M:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H
M(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES
M<6Q286ES945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H
M92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T
M:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E
M<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F
M96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'1H
M:7,M/FQA<W1?<75E<GDI*2!["B`@("`@("`@("`@(')E='5R;B!`;7ES<6Q?
M869F96-T961?<F]W<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT260H*0H*("`@("\J*@H@("`@
M("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED(&EN(&$@<V5Q=65N8V4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5Q7VYA;64@(&YA;64@;V8@
M=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@8F]O;&5A;B`D;VYD96UA;F0@
M('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@875T;VUA=&EC86QL>0H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8W)E871E9"!I9B!I="!D
M;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@
M;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E;F-E+@H@("`@("H@("`@("`@
M("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT240H*2P@1$)?8V]M;6]N.CIG
M971397%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;7ES<6PZ.F-R96%T
M95-E<75E;F-E*"DL($1"7VUY<W%L.CID<F]P4V5Q=65N8V4H*0H@("`@("HO
M"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@/2!T
M<G5E*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E<75E
M;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@(&1O('L*("`@("`@("`@("`@
M)')E<&5A="`](#`["B`@("`@("`@("`@("1T:&ES+3YP=7-H17)R;W)(86YD
M;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^<75E<GDH(E501$%412`D>W-E<6YA;65]("(N"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U-%5"!I9#U,05-47TE.4T52
M5%])1"AI9"LQ*2<I.PH@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD
M;&EN9R@I.PH@("`@("`@("`@("!I9B`H)')E<W5L="`]/3T@1$)?3TLI('L*
M("`@("`@("`@("`@("`@("\O($-/34U/3B!#05-%"B`@("`@("`@("`@("`@
M("`D:60@/2!`;7ES<6Q?:6YS97)T7VED*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@("`@(&EF("@D:60@(3T@,"D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B`D:60["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`O+R!%35!462!315$@5$%"3$4*("`@("`@("`@("`@("`@("\O
M(%-E<75E;F-E('1A8FQE(&UU<W0@8F4@96UP='D@9F]R('-O;64@<F5A<V]N
M+"!S;R!F:6QL"B`@("`@("`@("`@("`@("`O+R!I="!A;F0@<F5T=7)N(#$@
M86YD(&]B=&%I;B!A('5S97(M;&5V96P@;&]C:PH@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3YG971/;F4H(E-%3$5#5"!'151?3$]#2R@G)'MS
M97%N86UE?5]L;V-K)RPQ,"DB*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ
M:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT(#T](#`I('L*("`@("`@
M("`@("`@("`@("`@("`O+R!&86EL960@=&\@9V5T('1H92!L;V-K"B`@("`@
M("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R;W(H
M1$)?15)23U)?3D]47TQ/0TM%1"D["B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@+R\@861D('1H92!D969A=6QT('9A;'5E"B`@("`@("`@
M("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*")215!,04-%($E.5$\@
M)'MS97%N86UE?2`H:60I(%9!3%5%4R`H,"DB*3L*("`@("`@("`@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!296QE87-E('1H92!L
M;V-K"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@G
M4T5,14-4(%)%3$5!4T5?3$]#2R@G"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("(G)'MS97%N86UE?5]L;V-K)RDB*3L*("`@
M("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S
M=6QT*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O(%=E
M(&MN;W<@=VAA="!T:&4@<F5S=6QT('=I;&P@8F4L('-O(&YO(&YE960@=&\@
M=')Y(&%G86EN"B`@("`@("`@("`@("`@("!R971U<FX@,3L*"B`@("`@("`@
M("`@('T@96QS96EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L
M="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$
M0E]%4E)/4E].3U-50TA404),12D*("`@("`@("`@("`@>PH@("`@("`@("`@
M("`@("`@+R\@3TY$14U!3D0@5$%"3$4@0U)%051)3TX*("`@("`@("`@("`@
M("`@("1R97-U;'0@/2`D=&AI<RT^8W)E871E4V5Q=65N8V4H)'-E<5]N86UE
M*3L*("`@("`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@
M>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<B@D<F5S=6QT*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`@("`@)')E<&5A="`](#$["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!](&5L<V5I9B`H1$(Z.FES17)R;W(H)')E<W5L="D@)B8*
M("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]/2!$
M0E]%4E)/4E]!3%)%04197T5825-44RD*("`@("`@("`@("`@>PH@("`@("`@
M("`@("`@("`@+R\@0D%#2U=!4D13($-/35!!5`H@("`@("`@("`@("`@("`@
M+R\@<V5E(%]"0W-E<75E;F-E*"D@8V]M;65N=`H@("`@("`@("`@("`@("`@
M)')E<W5L="`]("1T:&ES+3Y?0D-S97%U96YC92@D<V5Q;F%M92D["B`@("`@
M("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L
M="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D<F5P96%T
M(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@('T@=VAI;&4@*"1R97!E870I
M.PH*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8W)E871E4V5Q=65N8V4H
M*0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H
M92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?
M3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E;F-E
M*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@
M($1"7VUY<W%L.CIN97AT240H*2P@1$)?;7ES<6PZ.F1R;W!397%U96YC92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?;F%M
M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC
M94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<F5S(#T@)'1H:7,M/G%U97)Y
M*"=#4D5!5$4@5$%"3$4@)R`N("1S97%N86UE"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("<@*&ED($E.5$5'15(@54Y324=.140@05543U])3D-2
M14U%3E0@3D]4($Y53$PL)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`G(%!224U!4ED@2T59*&ED*2DG*3L*("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N("1R97,["B`@("`@("`@
M?0H@("`@("`@("\O(&EN<V5R="!Y:65L9',@=F%L=64@,2P@;F5X=$ED(&-A
M;&P@=VEL;"!G96YE<F%T92!)1"`R"B`@("`@("`@)')E<R`]("1T:&ES+3YQ
M=65R>2@B24Y315)4($E.5$\@)'MS97%N86UE?2`H:60I(%9!3%5%4R`H,"DB
M*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@("\O('-O(')E<V5T
M('1O('IE<F\*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*")54$1!5$4@
M)'MS97%N86UE?2!3150@:60@/2`P(BD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T
M97,@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E
M<5]N86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG9713
M97%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;7ES<6PZ.FYE>'1)1"@I
M+"!$0E]M>7-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG9713
M97%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@7T)#<V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@0F%C:W=A
M<F1S(&-O;7!A=&EB:6QI='D@=VET:"!O;&0@<V5Q=65N8V4@96UU;&%T:6]N
M(&EM<&QE;65N=&%T:6]N"B`@("`@*B`H8VQE86X@=7`@=&AE(&1U<&5S*0H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<6YA;64@('1H92!S97%U
M96YC92!N86UE('1O(&-L96%N('5P"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!T<G5E(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?0D-S97%U96YC92@D<V5Q;F%M92D*("`@('L*("`@
M("`@("`O+R!/8G1A:6X@82!U<V5R+6QE=F5L(&QO8VLN+BX@=&AI<R!W:6QL
M(')E;&5A<V4@86YY('!R979I;W5S"B`@("`@("`@+R\@87!P;&EC871I;VX@
M;&]C:W,L(&)U="!U;FQI:V4@3$]#2R!404),15,L(&ET(&1O97,@;F]T(&%B
M;W)T"B`@("`@("`@+R\@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX@86YD(&ES
M(&UU8V@@;&5S<R!F<F5Q=65N=&QY('5S960N"B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YG971/;F4H(E-%3$5#5"!'151?3$]#2R@G)'MS97%N86UE?5]L
M;V-K)RPQ,"DB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<F5S=6QT(#T](#`I('L*("`@("`@("`@("`@+R\@1F%I;&5D
M('1O(&=E="!T:&4@;&]C:RP@8V%N)W0@9&\@=&AE(&-O;G9E<G-I;VXL(&)A
M:6P*("`@("`@("`@("`@+R\@=VET:"!A($1"7T524D]27TY/5%],3T-+140@
M97)R;W(*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A:7-E17)R
M;W(H1$)?15)23U)?3D]47TQ/0TM%1"D["B`@("`@("`@?0H*("`@("`@("`D
M:&EG:&5S=%]I9"`]("1T:&ES+3YG971/;F4H(E-%3$5#5"!-05@H:60I($92
M3TT@)'MS97%N86UE?2(I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D:&EG
M:&5S=%]I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1H:6=H97-T7VED.PH@
M("`@("`@('T*("`@("`@("`O+R!4:&ES('-H;W5L9"!K:6QL(&%L;"!R;W=S
M(&5X8V5P="!T:&4@:&EG:&5S=`H@("`@("`@("\O(%=E('-H;W5L9"!P<F]B
M86)L>2!D;R!S;VUE=&AI;F<@:68@)&AI9VAE<W1?:60@:7-N)W0*("`@("`@
M("`O+R!N=6UE<FEC+"!B=70@22=M(&%T(&$@;&]S<R!A<R!H;W<@=&\@:&%N
M9&QE('1H870N+BX*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"=$
M14Q%5$4@1E)/32`G("X@)'-E<6YA;64*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@(B!72$5212!I9"`\/B`D:&EG:&5S=%]I9"(I.PH@("`@
M("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!R
M971U<FX@)')E<W5L=#L*("`@("`@("!]"@H@("`@("`@("\O($EF(&%N;W1H
M97(@=&AR96%D(&AA<R!B965N('=A:71I;F<@9F]R('1H:7,@;&]C:RP*("`@
M("`@("`O+R!I="!W:6QL(&=O('1H<G4@=&AE(&%B;W9E('!R;V-E9'5R92P@
M8G5T('=I;&P@:&%V92!N;PH@("`@("`@("\O(')E86P@969F96-T"B`@("`@
M("`@)')E<W5L="`]("1T:&ES+3YG971/;F4H(E-%3$5#5"!214Q%05-%7TQ/
M0TLH)R1[<V5Q;F%M97U?;&]C:R<I(BD["B`@("`@("`@:68@*$1".CII<T5R
M<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!Q=6]T94ED96YT:69I97(H*0H*("`@("\J*@H@("`@
M("H@475O=&5S(&$@<W1R:6YG('-O(&ET(&-A;B!B92!S869E;'D@=7-E9"!A
M<R!A('1A8FQE(&]R(&-O;'5M;B!N86UE"B`@("`@*@H@("`@("H@37E344P@
M8V%N)W0@:&%N9&QE('1H92!B86-K=&EC:R!C:&%R86-T97(@*#QK8F0^8#PO
M:V)D/BD@:6X*("`@("`J('1A8FQE(&]R(&-O;'5M;B!N86UE<RX*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@(&ED96YT:69I97(@;F%M92!T
M;R!B92!Q=6]T960*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@<75O
M=&5D(&ED96YT:69I97(@<W1R:6YG"B`@("`@*@H@("`@("H@0'-E92!$0E]C
M;VUM;VXZ.G%U;W1E261E;G1I9FEE<B@I"B`@("`@*B!`<VEN8V4@365T:&]D
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U
M;F-T:6]N('%U;W1E261E;G1I9FEE<B@D<W1R*0H@("`@>PH@("`@("`@(')E
M='5R;B`G8"<@+B`D<W1R("X@)V`G.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[('%U;W1E*"D*"B`@("`O*BH*("`@("`J($!D97!R96-A=&5D("!$
M97!R96-A=&5D(&EN(')E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@9G5N8W1I
M;VX@<75O=&4H)'-T<BD*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U
M;W1E4VUA<G0H)'-T<BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M97-C87!E4VEM<&QE*"D*"B`@("`O*BH*("`@("`J($5S8V%P97,@82!S=')I
M;F<@86-C;W)D:6YG('1O('1H92!C=7)R96YT($1"35,G<R!S=&%N9&%R9',*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@('1H92!S=')I;F<@
M=&\@8F4@97-C87!E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T
M:&4@97-C87!E9"!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ<75O=&53;6%R="@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L
M92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N(&5S
M8V%P95-I;7!L92@D<W1R*0H@("`@>PH@("`@("`@(&EF("AF=6YC=&EO;E]E
M>&ES=',H)VUY<W%L7W)E86Q?97-C87!E7W-T<FEN9R<I*2!["B`@("`@("`@
M("`@(')E='5R;B!`;7ES<6Q?<F5A;%]E<V-A<&5?<W1R:6YG*"1S='(L("1T
M:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("!R971U<FX@0&UY<W%L7V5S8V%P95]S=')I;F<H)'-T<BD["B`@("`@("`@
M?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>5%U97)Y*"D*
M"B`@("`O*BH*("`@("`J($-H86YG97,@82!Q=65R>2!S=')I;F<@9F]R('9A
M<FEO=7,@1$)-4R!S<&5C:69I8R!R96%S;VYS"B`@("`@*@H@("`@("H@5&AI
M<R!L:71T;&4@:&%C:R!L971S('EO=2!K;F]W(&AO=R!M86YY(')O=W,@=V5R
M92!D96QE=&5D"B`@("`@*B!W:&5N(')U;FYI;F<@82`B1$5,151%($923TT@
M=&%B;&4B('%U97)Y+B`@3VYL>2!I;7!L96UE;G1E9`H@("`@("H@:68@=&AE
M($1"7U!/4E1!0DE,25197T1%3$5415]#3U5.5"!P;W)T86)I;&ET>2!O<'1I
M;VX@:7,@;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@
M('1H92!Q=65R>2!S=')I;F<@=&\@;6]D:69Y"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!M;V1I9FEE9"!Q=65R>2!S=')I;F<*("`@("`J
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>5%U
M97)Y*"1Q=65R>2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]$14Q%5$5?0T]53E0I
M('L*("`@("`@("`@("`@+R\@(D1%3$5412!&4D]-('1A8FQE(B!G:79E<R`P
M(&%F9F5C=&5D(')O=W,@:6X@37E344PN"B`@("`@("`@("`@("\O(%1H:7,@
M;&ET=&QE(&AA8VL@;&5T<R!Y;W4@:VYO=R!H;W<@;6%N>2!R;W=S('=E<F4@
M9&5L971E9"X*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J1$5,
M151%7',K1E)/35QS*RA<4RLI7',J)"]I)RP@)'%U97)Y*2D@>PH@("`@("`@
M("`@("`@("`@)'%U97)Y(#T@<')E9U]R97!L86-E*"<O7EQS*D1%3$5415QS
M*T923TU<<RLH7%,K*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G1$5,151%($923TT@7#$@5TA%4D4@,3TQ)RP@)'%U
M97)Y*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@
M)'%U97)Y.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>4QI
M;6ET475E<GDH*0H*("`@("\J*@H@("`@("H@061D<R!,24U)5"!C;&%U<V5S
M('1O(&$@<75E<GD@<W1R:6YG(&%C8V]R9&EN9R!T;R!C=7)R96YT($1"35,@
M<W1A;F1A<F1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@
M("!T:&4@<75E<GD@=&\@;6]D:69Y"B`@("`@*B!`<&%R86T@:6YT("`@("1F
M<F]M("`@('1H92!R;W<@=&\@<W1A<G0@=&\@9F5T8VAI;F<@*#`@/2!T:&4@
M9FER<W0@<F]W*0H@("`@("H@0'!A<F%M(&EN="`@("`D8V]U;G0@("!T:&4@
M;G5M8F5R<R!O9B!R;W=S('1O(&9E=&-H"B`@("`@*B!`<&%R86T@;6EX960@
M("1P87)A;7,@(&%R<F%Y+"!S=')I;F<@;W(@;G5M97)I8R!D871A('1O(&)E
M('5S960@:6X*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@(&5X96-U
M=&EO;B!O9B!T:&4@<W1A=&5M96YT+B`@475A;G1I='D@;V8@:71E;7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<W-E9"!M=7-T(&UA=&-H
M('%U86YT:71Y(&]F('!L86-E:&]L9&5R<R!I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@<75E<GDZ("!M96%N:6YG(#$@<&QA8V5H;VQD97(@
M9F]R(&YO;BUA<G)A>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M<&%R86UE=&5R<R!O<B`Q('!L86-E:&]L9&5R('!E<B!A<G)A>2!E;&5M96YT
M+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<75E<GD@<W1R
M:6YG('=I=&@@3$E-250@8VQA=7-E<R!A9&1E9`H@("`@("H*("`@("`J($!A
M8V-E<W,@<')O=&5C=&5D"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>4QI
M;6ET475E<GDH)'%U97)Y+"`D9G)O;2P@)&-O=6YT+"`D<&%R86US(#T@87)R
M87DH*2D*("`@('L*("`@("`@("!I9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@
M>PH@("`@("`@("`@("!R971U<FX@)'%U97)Y("X@(B!,24U)5"`D8V]U;G0B
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD@
M+B`B($Q)34E4("1F<F]M+"`D8V]U;G0B.PH@("`@("`@('T*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!M>7-Q;%)A:7-E17)R;W(H*0H*("`@("\J
M*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG
M('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT
M("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E
M9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)23U(J
M(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@("H@
M("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@9V%T
M:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B
M:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S964@
M1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7VUY<W%L
M.CIE<G)O<DYA=&EV92@I+"!$0E]C;VUM;VXZ.F5R<F]R0V]D92@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&UY<W%L4F%I<V5%<G)O<B@D97)R;F\@/2!N=6QL
M*0H@("`@>PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI('L*("`@("`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?
M4$]25$%"24Q)5%E?15)23U)3*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M97)R;W)C;V1E7VUA<%LQ,#(R72`]($1"7T524D]27T-/3E-44D%)3E0["B`@
M("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#0X72`]($1"
M7T524D]27T-/3E-44D%)3E1?3D]47TY53$P["B`@("`@("`@("`@("`@("`D
M=&AI<RT^97)R;W)C;V1E7VUA<%LQ,#8R72`]($1"7T524D]27T-/3E-44D%)
M3E0["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!$
M;VEN9R!T:&ES(&EN(&-A<V4@;6]D92!C:&%N9V5S(&1U<FEN9R!R=6YT:6UE
M+@H@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`R,ET@
M/2!$0E]%4E)/4E]!3%)%04197T5825-44SL*("`@("`@("`@("`@("`@("1T
M:&ES+3YE<G)O<F-O9&5?;6%P6S$P-#A=(#T@1$)?15)23U)?0T].4U1204E.
M5#L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P-C)=
M(#T@1$)?15)23U)?04Q214%$65]%6$E35%,["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92AM>7-Q;%]E<G)N
M;R@D=&AI<RT^8V]N;F5C=&EO;BDI.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`;7ES<6Q?97)R
M;F\H)'1H:7,M/F-O;FYE8W1I;VXI("X@)R`J*B`G("X*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@0&UY<W%L7V5R<F]R*"1T:&ES+3YC;VYN
M96-T:6]N*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).
M871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E
M(&5R<F]R(&-O9&4@<')O9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE($1"35,G(&5R<F]R(&-O9&4*("`@
M("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@
M(')E='5R;B!`;7ES<6Q?97)R;F\H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B;&4@;W(@
M82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C='QS=')I
M;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A('%U97)Y(&]R
M(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R
M:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI;&4@=&AI<R!A;'-O
M(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE<BP@=&AI<R!B
M96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@
M("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H
M92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@
M("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@
M*B!`<V5E($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@("`@
M("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@
M;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2!`;7ES<6Q?;&ES=%]F:65L9',H)'1H:7,M/F1S;ELG9&%T86)A<V4G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0L
M("1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@
M/2!T<G5E.PH@("`@("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR97-U
M;'0I*2!["B`@("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY
M(')E8V5I=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT
M<F%C="!T:&4@<F5S=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@
M("`@("`J+PH@("`@("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@
M("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C
M96EV960@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@
M("`@("H@0V]P>2!I="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@($AE
M<F4@9F]R(&-O;7!A=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO"B`@
M("`@("`@("`@("1I9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R
M:6YG(#T@9F%L<V4["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E<V]U
M<F-E*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;%)A
M:7-E17)R;W(H1$)?15)23U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@('T*
M"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E
M7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@
M("`@)&-O=6YT(#T@0&UY<W%L7VYU;5]F:65L9',H)&ED*3L*("`@("`@("`D
M<F5S("`@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)&UO9&4I('L*("`@("`@
M("`@("`@)')E<ULG;G5M7V9I96QD<R==(#T@)&-O=6YT.PH@("`@("`@('T*
M"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&-O=6YT.R`D:2LK*2!["B`@
M("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G
M=&%B;&4G(#T^("1C87-E7V9U;F,H0&UY<W%L7V9I96QD7W1A8FQE*"1I9"P@
M)&DI*2P*("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8RA`
M;7ES<6Q?9FEE;&1?;F%M92@D:60L("1I*2DL"B`@("`@("`@("`@("`@("`G
M='EP92<@(#T^($!M>7-Q;%]F:65L9%]T>7!E*"1I9"P@)&DI+`H@("`@("`@
M("`@("`@("`@)VQE;B<@("`]/B!`;7ES<6Q?9FEE;&1?;&5N*"1I9"P@)&DI
M+`H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B!`;7ES<6Q?9FEE;&1?9FQA
M9W,H)&ED+"`D:2DL"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@D
M;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/
M4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE
M)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("\O(&9R964@=&AE
M(')E<W5L="!O;FQY(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@
M("`@("!I9B`H)&=O=%]S=')I;F<I('L*("`@("`@("`@("`@0&UY<W%L7V9R
M965?<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P96-I86Q1=65R
M>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R>2!S=')I;F<@
M;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O8FIE8W1S"B`@
M("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE(&MI;F0@;V8@
M;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9R!O<B!N=6QL(&EF
M('1H92!D<FEV97(@9&]E<VXG=`H@("`@("H@("`@("`@("`@("`@("`@("!S
M=7!P;W)T('1H92!O8FIE8W0@='EP92!R97%U97-T960*("`@("`J"B`@("`@
M*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F=E
M=$QI<W1/9B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=%-P96-I86Q1=65R
M>2@D='EP92D*("`@('L*("`@("`@("!S=VET8V@@*"1T>7!E*2!["B`@("`@
M("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@
M)U-(3U<@5$%"3$53)SL*("`@("`@("`@("`@8V%S92`G=7-E<G,G.@H@("`@
M("`@("`@("`@("`@<F5T=7)N("=314Q%0U0@1$E35$E.0U0@57-E<B!&4D]-
M(&UY<W%L+G5S97(G.PH@("`@("`@("`@("!C87-E("=D871A8F%S97,G.@H@
M("`@("`@("`@("`@("`@<F5T=7)N("=32$]7($1!5$%"05-%4R<["B`@("`@
M("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,;V-A;"!V
M87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@
M-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+VUY<W%L:2YP:'``````````
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q,#(Q,C(@,3`U
M,34T,S0Q,S,@,#(P-S<S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B
M<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J
M(%1H92!014%2($1"(&1R:79E<B!F;W(@4$A0)W,@;7ES<6QI(&5X=&5N<VEO
M;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!->5-13"!D871A8F%S97,*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!M>7-Q;&DN<&AP+'8@,2XV
M.2`R,#`U+S`S+S`T(#(S.C$R.C,V(&1A;FEE;&,@17AP("0*("H@0&QI;FL@
M("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ
M"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E
M>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G
M.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C
M="!W:71H(%!(4"=S(&UY<W%L:2!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T
M:6YG('=I=&@@37E344P@9&%T86)A<V5S"B`J"B`J(%1H:7,@:7,@9F]R($UY
M4U%,('9E<G-I;VYS(#0N,2!A;F0@86)O=F4N("!297%U:7)E<R!02%`@-2X*
M("H*("H@3F]T92!T:&%T('!E<G-I<W1E;G0@8V]N;F5C=&EO;G,@;F\@;&]N
M9V5R(&5X:7-T+@H@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O
M;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@0&-A=&5G;W)Y("`@
M1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@1&%N
M:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@
M("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J($!S:6YC92`@
M("`@($-L87-S(&9U;F-T:6]N86P@<VEN8V4@4F5L96%S92`Q+C8N,PH@*B\*
M8VQA<W,@1$)?;7ES<6QI(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[
M>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y
M<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I
M;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)VUY<W%L:2<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@
M=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G;7ES<6QI)SL*
M"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I
M;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L
M96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O
M=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@
M($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@
M("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@
M("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M
M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@
M("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@
M0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH
M"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=A;'1E<B<L"B`@("`@("`@
M)VYE=U]L:6YK)R`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N=6UR;W=S)R`@
M("`@("`]/B!T<G5E+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!F86QS
M92P*("`@("`@("`G<')E<&%R92<@("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M)W-S;"<@("`@("`@("`@(#T^('1R=64L"B`@("`@("`@)W1R86YS86-T:6]N
M<R<@(#T^('1R=64L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG
M(&]F(&YA=&EV92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@
M/2!A<G)A>2@*("`@("`@("`Q,#`T(#T^($1"7T524D]27T-!3DY/5%]#4D5!
M5$4L"B`@("`@("`@,3`P-2`]/B!$0E]%4E)/4E]#04Y.3U1?0U)%051%+`H@
M("`@("`@(#$P,#8@/3X@1$)?15)23U)?0T%.3D]47T-214%412P*("`@("`@
M("`Q,#`W(#T^($1"7T524D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P
M,#@@/3X@1$)?15)23U)?0T%.3D]47T123U`L"B`@("`@("`@,3`R,B`]/B!$
M0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#0T(#T^($1"7T52
M4D]27T%#0T534U]624],051)3TXL"B`@("`@("`@,3`T-B`]/B!$0E]%4E)/
M4E].3T1"4T5,14-4140L"B`@("`@("`@,3`T."`]/B!$0E]%4E)/4E]#3TY3
M5%)!24Y4+`H@("`@("`@(#$P-#D@/3X@1$)?15)23U)?3D]354-(1$(L"B`@
M("`@("`@,3`U,"`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@
M("`Q,#4Q(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#$P-30@
M/3X@1$)?15)23U)?3D]354-(1DE%3$0L"B`@("`@("`@,3`V,2`]/B!$0E]%
M4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q,#8R(#T^($1"7T524D]2
M7T%,4D5!1%E?15A)4U13+`H@("`@("`@(#$P-C0@/3X@1$)?15)23U)?4UE.
M5$%8+`H@("`@("`@(#$P.3$@/3X@1$)?15)23U)?3D]47T9/54Y$+`H@("`@
M("`@(#$Q,#`@/3X@1$)?15)23U)?3D]47TQ/0TM%1"P*("`@("`@("`Q,3,V
M(#T^($1"7T524D]27U9!3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`Q,30R
M(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@("`@,3$T-B`]
M/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`Q,C$V(#T^($1"7T52
M4D]27T-/3E-44D%)3E0L"B`@("`@("`@,3(Q-R`]/B!$0E]%4E)/4E]#3TY3
M5%)!24Y4+`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T86)A
M<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R97-O
M=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ"B`@
M("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O(&$@
M9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D
M<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D871A(&UA
M;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI='1E9"!A=71O;6%T:6-A;&QY
M/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U93L*"B`@("`O*BH*("`@
M("`J(%1H92!Q=6%N=&ET>2!O9B!T<F%N<V%C=&EO;G,@8F5G=6X*("`@("`J
M"B`@("`@*B![0&EN=&5R;F%L("!7:&EL92!T:&ES(&ES('!R:79A=&4L(&ET
M(&-A;B=T(&%C='5A;&QY(&)E(&1E<VEG;F%T960*("`@("`J('!R:79A=&4@
M:6X@4$A0(#4@8F5C875S92!I="!I<R!D:7)E8W1L>2!A8V-E<W-E9"!I;B!T
M:&4@=&5S="!S=6ET92Y]?0H@("`@("H*("`@("`J($!V87(@:6YT96=E<@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D=')A;G-A
M8W1I;VY?;W!C;W5N="`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A
M<V4@<W!E8VEF:65D(&EN('1H92!$4TX*("`@("`J"B`@("`@*B!)="=S(&$@
M9FEX('1O(&%L;&]W(&-A;&QS('1O(&1I9F9E<F5N="!D871A8F%S97,@:6X@
M=&AE('-A;64@<V-R:7!T+@H@("`@("H*("`@("`J($!V87(@<W1R:6YG"B`@
M("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?9&(@/2`G
M)SL*"B`@("`O*BH*("`@("`J($%R<F%Y(&9O<B!C;VYV97)T:6YG($U94U%,
M25\J7T9,04<@8V]N<W1A;G1S('1O('1E>'0@=F%L=65S"B`@("`@*B!`=F%R
M("`@(&%R<F%Y"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("H@0'-I;F-E
M("!0<F]P97)T>2!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N-0H@("`@
M("HO"B`@("!V87(@)&UY<W%L:5]F;&%G<R`](&%R<F%Y*`H@("`@("`@($U9
M4U%,25].3U1?3E5,3%]&3$%'("`@("`@("`]/B`G;F]T7VYU;&PG+`H@("`@
M("`@($U94U%,25]04DE?2T597T9,04<@("`@("`@("`]/B`G<')I;6%R>5]K
M97DG+`H@("`@("`@($U94U%,25]53DE1545?2T597T9,04<@("`@("`]/B`G
M=6YI<75E7VME>2<L"B`@("`@("`@35E344Q)7TU53%1)4$Q%7TM%65]&3$%'
M("`@(#T^("=M=6QT:7!L95]K97DG+`H@("`@("`@($U94U%,25]"3$]"7T9,
M04<@("`@("`@("`@("`]/B`G8FQO8B<L"B`@("`@("`@35E344Q)7U5.4TE'
M3D5$7T9,04<@("`@("`@(#T^("=U;G-I9VYE9"<L"B`@("`@("`@35E344Q)
M7UI%4D]&24Q,7T9,04<@("`@("`@(#T^("=Z97)O9FEL;"<L"B`@("`@("`@
M35E344Q)7T%55$]?24Y#4D5-14Y47T9,04<@(#T^("=A=71O7VEN8W)E;65N
M="<L"B`@("`@("`@35E344Q)7U1)34535$%-4%]&3$%'("`@("`@(#T^("=T
M:6UE<W1A;7`G+`H@("`@("`@($U94U%,25]3151?1DQ!1R`@("`@("`@("`@
M("`]/B`G<V5T)RP*("`@("`@("`O+R!-65-13$E?3E5-7T9,04<@("`@("`@
M("`@("`@/3X@)VYU;65R:6,G+"`@+R\@=6YN96-E<W-A<GD*("`@("`@("`O
M+R!-65-13$E?4$%25%]+15E?1DQ!1R`@("`@("`@/3X@)VUU;'1I<&QE7VME
M>2<L("`O+R!D=7!L:6-A='9I90H@("`@("`@($U94U%,25]'4D]54%]&3$%'
M("`@("`@("`@("`]/B`G9W)O=7!?8GDG"B`@("`I.PH*("`@("\J*@H@("`@
M("H@07)R87D@9F]R(&-O;G9E<G1I;F<@35E344Q)7U194$5?*B!C;VYS=&%N
M=',@=&\@=&5X="!V86QU97,*("`@("`J($!V87(@("`@87)R87D*("`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`@*B!`<VEN8V4@(%!R;W!E<G1Y(&%V86EL
M86)L92!S:6YC92!296QE87-E(#$N-BXU"B`@("`@*B\*("`@('9A<B`D;7ES
M<6QI7W1Y<&5S(#T@87)R87DH"B`@("`@("`@35E344Q)7U194$5?1$5#24U!
M3"`@("`@/3X@)V1E8VEM86PG+`H@("`@("`@($U94U%,25]465!%7U1)3ED@
M("`@("`@(#T^("=T:6YY:6YT)RP*("`@("`@("!-65-13$E?5%E015]32$]2
M5"`@("`@("`]/B`G:6YT)RP*("`@("`@("!-65-13$E?5%E015],3TY'("`@
M("`@("`]/B`G:6YT)RP*("`@("`@("!-65-13$E?5%E015]&3$]!5"`@("`@
M("`]/B`G9FQO870G+`H@("`@("`@($U94U%,25]465!%7T1/54),12`@("`@
M(#T^("=D;W5B;&4G+`H@("`@("`@("\O($U94U%,25]465!%7TY53$P@("`@
M("`@(#T^("=$149!54Q4($Y53$PG+"`@+R\@;&5T(&9L86=S(&AA;F1L92!I
M=`H@("`@("`@($U94U%,25]465!%7U1)34535$%-4"`@(#T^("=T:6UE<W1A
M;7`G+`H@("`@("`@($U94U%,25]465!%7TQ/3D=,3TY'("`@(#T^("=B:6=I
M;G0G+`H@("`@("`@($U94U%,25]465!%7TE.5#(T("`@("`@(#T^("=M961I
M=6UI;G0G+`H@("`@("`@($U94U%,25]465!%7T1!5$4@("`@("`@(#T^("=D
M871E)RP*("`@("`@("!-65-13$E?5%E015]424U%("`@("`@("`]/B`G=&EM
M92<L"B`@("`@("`@35E344Q)7U194$5?1$%4151)344@("`@/3X@)V1A=&5T
M:6UE)RP*("`@("`@("!-65-13$E?5%E015]914%2("`@("`@("`]/B`G>65A
M<B<L"B`@("`@("`@35E344Q)7U194$5?3D571$%412`@("`@/3X@)V1A=&4G
M+`H@("`@("`@($U94U%,25]465!%7T5.54T@("`@("`@(#T^("=E;G5M)RP*
M("`@("`@("!-65-13$E?5%E015]3150@("`@("`@("`]/B`G<V5T)RP*("`@
M("`@("!-65-13$E?5%E015]424Y97T),3T(@("`]/B`G=&EN>6)L;V(G+`H@
M("`@("`@($U94U%,25]465!%7TU%1$E535]"3$]"(#T^("=M961I=6UB;&]B
M)RP*("`@("`@("!-65-13$E?5%E015],3TY'7T),3T(@("`]/B`G;&]N9V)L
M;V(G+`H@("`@("`@($U94U%,25]465!%7T),3T(@("`@("`@(#T^("=B;&]B
M)RP*("`@("`@("!-65-13$E?5%E015]605)?4U1224Y'("`]/B`G=F%R8VAA
M<B<L"B`@("`@("`@35E344Q)7U194$5?4U1224Y'("`@("`@/3X@)V-H87(G
M+`H@("`@("`@($U94U%,25]465!%7T=%3TU%5%)9("`@(#T^("=G96]M971R
M>2<L"B`@("`I.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O
M<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\:V)D
M/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R971U
M<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]M>7-Q;&DH*0H@("`@
M>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE
M8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H
M92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H
M;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@
M("H*("`@("`J(%!%05(@1$(G<R!M>7-Q;&D@9')I=F5R('-U<'!O<G1S('1H
M92!F;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@("L@5VAE
M;B!T:&4@)W-S;"<@)&]P=&EO;B!P87-S960@=&\@1$(Z.F-O;FYE8W0H*2!I
M<R!T<G5E.@H@("`@("H@("`@("L@:V5Y("`@("`@5&AE('!A=&@@=&\@=&AE
M(&ME>2!F:6QE+@H@("`@("H@("`@("L@8V5R="`@("`@5&AE('!A=&@@=&\@
M=&AE(&-E<G1I9FEC871E(&9I;&4N"B`@("`@*B`@("`@*R!C82`@("`@("!4
M:&4@<&%T:"!T;R!T:&4@8V5R=&EF:6-A=&4@875T:&]R:71Y(&9I;&4N"B`@
M("`@*B`@("`@*R!C87!A=&@@("!4:&4@<&%T:"!T;R!A(&1I<F5C=&]R>2!T
M:&%T(&-O;G1A:6YS('1R=7-T960@4U-,"B`@("`@*B`@("`@("`@("`@("`@
M("`@0T$@8V5R=&EF:6-A=&5S(&EN('!E;2!F;W)M870N"B`@("`@*B`@("`@
M*R!C:7!H97(@("!4:&4@;&ES="!O9B!A;&QO=V%B;&4@8VEP:&5R<R!F;W(@
M4U-,(&5N8W)Y<'1I;VXN"B`@("`@*@H@("`@("H@17AA;7!L92!O9B!H;W<@
M=&\@8V]N;F5C="!U<VEN9R!34TPZ"B`@("`@*B`\8V]D93X*("`@("`J(')E
M<75I<F5?;VYC92`G1$(N<&AP)SL*("`@("`J(`H@("`@("H@)&1S;B`](&%R
M<F%Y*`H@("`@("H@("`@("=P:'!T>7!E)R`@/3X@)VUY<W%L:2<L"B`@("`@
M*B`@("`@)W5S97)N86UE)R`]/B`G<V]M975S97(G+`H@("`@("H@("`@("=P
M87-S=V]R9"<@/3X@)V%P87-S=V0G+`H@("`@("H@("`@("=H;W-T<W!E8R<@
M/3X@)VQO8V%L:&]S="<L"B`@("`@*B`@("`@)V1A=&%B87-E)R`]/B`G=&AE
M9&(G+`H@("`@("H@("`@("=K97DG("`@("`@/3X@)V-L:65N="UK97DN<&5M
M)RP*("`@("`J("`@("`G8V5R="<@("`@(#T^("=C;&EE;G0M8V5R="YP96TG
M+`H@("`@("H@("`@("=C82<@("`@("`@/3X@)V-A8V5R="YP96TG+`H@("`@
M("H@("`@("=C87!A=&@G("`@/3X@)R]P871H+W1O+V-A+V1I<B<L"B`@("`@
M*B`@("`@)V-I<&AE<B<@("`]/B`G0453)RP*("`@("`J("D["B`@("`@*B`*
M("`@("`J("1O<'1I;VYS(#T@87)R87DH"B`@("`@*B`@("`@)W-S;"<@/3X@
M=')U92P*("`@("`J("D["B`@("`@*B`*("`@("`J("1D8B`])B!$0CHZ8V]N
M;F5C="@D9'-N+"`D;W!T:6]N<RD["B`@("`@*B!I9B`H4$5!4CHZ:7-%<G)O
M<B@D9&(I*2!["B`@("`@*B`@("`@9&EE*"1D8BT^9V5T365S<V%G92@I*3L*
M("`@("`J('T*("`@("`J(#PO8V]D93X*("`@("`J"B`@("`@*B!`<&%R86T@
M87)R87D@)&1S;B`@("`@("`@('1H92!D871A('-O=7)C92!N86UE"B`@("`@
M*B!`<&%R86T@8F]O;"`@)'!E<G-I<W1E;G0@('-H;W5L9"!T:&4@8V]N;F5C
M=&EO;B!B92!P97)S:7-T96YT/PH@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!$0E]/2R!O;B!S=6-C97-S+B!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VYN96-T*"1D<VXL("1P97)S
M:7-T96YT(#T@9F%L<V4I"B`@("!["B`@("`@("`@:68@*"%014%2.CIL;V%D
M17AT96YS:6]N*"=M>7-Q;&DG*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A414Y324].7TY/5%]&3U5.1"D[
M"B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9'-N(#T@)&1S;CL*("`@("`@
M("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@("`@("`@("`@("`D=&AI<RT^
M9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==.PH@("`@("`@('T*"B`@("`@
M("`@)&EN:2`](&EN:5]G970H)W1R86-K7V5R<F]R<R<I.PH@("`@("`@(&EN
M:5]S970H)W1R86-K7V5R<F]R<R<L(#$I.PH@("`@("`@("1P:'!?97)R;W)M
M<V<@/2`G)SL*"B`@("`@("`@:68@*"1T:&ES+3YG971/<'1I;VXH)W-S;"<I
M(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1I;FET(#T@;7ES<6QI7VEN:70H
M*3L*("`@("`@("`@("`@;7ES<6QI7W-S;%]S970H"B`@("`@("`@("`@("`@
M("`D:6YI="P*("`@("`@("`@("`@("`@(&5M<'1Y*"1D<VY;)VME>2==*2`@
M("`_(&YU;&P@.B`D9'-N6R=K97DG72P*("`@("`@("`@("`@("`@(&5M<'1Y
M*"1D<VY;)V-E<G0G72D@("`_(&YU;&P@.B`D9'-N6R=C97)T)UTL"B`@("`@
M("`@("`@("`@("!E;7!T>2@D9'-N6R=C82==*2`@("`@/R!N=6QL(#H@)&1S
M;ELG8V$G72P*("`@("`@("`@("`@("`@(&5M<'1Y*"1D<VY;)V-A<&%T:"==
M*2`_(&YU;&P@.B`D9'-N6R=C87!A=&@G72P*("`@("`@("`@("`@("`@(&5M
M<'1Y*"1D<VY;)V-I<&AE<B==*2`_(&YU;&P@.B`D9'-N6R=C:7!H97(G70H@
M("`@("`@("`@("`I.PH@("`@("`@("`@("!I9B`H)'1H:7,M/F-O;FYE8W1I
M;VX@/2!`;7ES<6QI7W)E86Q?8V]N;F5C="@*("`@("`@("`@("`@("`@("`@
M("`D:6YI="P*("`@("`@("`@("`@("`@("`@("`D9'-N6R=H;W-T<W!E8R==
M+`H@("`@("`@("`@("`@("`@("`@("1D<VY;)W5S97)N86UE)UTL"B`@("`@
M("`@("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@
M("`@("`@("`D9'-N6R=D871A8F%S92==+`H@("`@("`@("`@("`@("`@("`@
M("1D<VY;)W!O<G0G72P*("`@("`@("`@("`@("`@("`@("`D9'-N6R=S;V-K
M970G72DI"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1T:&ES+3YC
M;VYN96-T:6]N(#T@)&EN:70["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($!M>7-Q;&E?
M8V]N;F5C="@*("`@("`@("`@("`@("`@("1D<VY;)VAO<W1S<&5C)UTL"B`@
M("`@("`@("`@("`@("`D9'-N6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@
M("`@)&1S;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@("`@("1D<VY;)V1A
M=&%B87-E)UTL"B`@("`@("`@("`@("`@("`D9'-N6R=P;W)T)UTL"B`@("`@
M("`@("`@("`@("`D9'-N6R=S;V-K970G70H@("`@("`@("`@("`I.PH@("`@
M("`@('T*"B`@("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@)&EN:2D[
M"@H@("`@("`@(&EF("@A)'1H:7,M/F-O;FYE8W1I;VXI('L*("`@("`@("`@
M("`@:68@*"@D97)R(#T@0&UY<W%L:5]C;VYN96-T7V5R<F]R*"DI("$]("<G
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R*3L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P:'!?97)R;W)M<V<I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V1B(#T@)&1S;ELG9&%T86)A<V4G73L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R
M;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@
M8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R
M970@/2!`;7ES<6QI7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R
M970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH
M*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A
M<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@=&AE(%-1
M3"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("`K
M(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S<V9U;"!314Q%0U0@
M<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T:&4@1$)?3TL@8V]N
M<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE<PH@("`@("H@("`@
M("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q=65R>2D*("`@('L*
M("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q=65R>2D["B`@("`@
M("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@("`@("`@)'%U97)Y
M(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*"1T
M:&ES+3Y?9&(I('L*("`@("`@("`@("`@:68@*"%`;7ES<6QI7W-E;&5C=%]D
M8B@D=&AI<RT^8V]N;F5C=&EO;BP@)'1H:7,M/E]D8BDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<BA$0E]%4E)/
M4E].3T1"4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@
M("`@(&EF("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES;6%N:7`I('L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T](#`I
M('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`;7ES<6QI7W%U97)Y*"1T
M:&ES+3YC;VYN96-T:6]N+"`G4T54($%55$]#3TU-250],"<I.PH@("`@("`@
M("`@("`@("`@)')E<W5L="`]($!M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE
M8W1I;VXL("="14=)3B<I.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S=6QT
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E2
M86ES945R<F]R*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0K*SL*("`@
M("`@("!]"B`@("`@("`@)')E<W5L="`]($!M>7-Q;&E?<75E<GDH)'1H:7,M
M/F-O;FYE8W1I;VXL("1Q=65R>2D["B`@("`@("`@:68@*"$D<F5S=6QT*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?;V)J96-T*"1R97-U;'0I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA
M;"!M>7-Q;"!R97-U;'0@<&]I;G1E<B!T;R!T:&4@;F5X="!A=F%I;&%B;&4@
M<F5S=6QT+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&AA<R!N;W0@8F5E
M;B!I;7!L96UE;G1E9"!Y970N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1R97-U;'0@82!V86QI9"!S<6P@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*B!`<F5T=7)N(&9A;'-E"B`@("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&9E=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O
M;2!T:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*
M("`@("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H
M97)E:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z
M.F9E=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER
M96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS
M=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@
M*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@
M("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E
M<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R
M<B`@("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@
M:6X*("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@
M<F5S=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R
M86T@:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C
M:"`H,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D
M("!$0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E
M<W5L="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R
M(&]N(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T
M8VA);G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U
M;'0L("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I
M9B`H(4!M>7-Q;&E?9&%T85]S965K*"1R97-U;'0L("1R;W=N=6TI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!
M4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0&UY<W%L:5]F971C:%]A<G)A
M>2@D<F5S=6QT+"!-65-13$E?05-33T,I.PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],
M3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@("`@("`@("`@)&%R<B`](&%R
M<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#05-%7TQ/5T52*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1A<G(@/2!`
M;7ES<6QI7V9E=&-H7W)O=R@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@("`O*@H@("`@
M("`@("`@("`@*B!%=F5N('1H;W5G:"!T:&ES($1"35,@86QR96%D>2!T<FEM
M<R!O=71P=70L('=E(&1O('1H:7,@8F5C875S90H@("`@("`@("`@("`@*B!A
M(&9I96QD(&UI9VAT(&AA=F4@:6YT96YT:6]N86P@=VAI=&5S<&%C92!A="!T
M:&4@96YD('1H870*("`@("`@("`@("`@("H@9V5T<R!R96UO=F5D(&)Y($1"
M7U!/4E1!0DE,25197U)44DE-('5N9&5R(&%N;W1H97(@9')I=F5R+@H@("`@
M("`@("`@("`@*B\*("`@("`@("`@("`@)'1H:7,M/E]R=')I;4%R<F%Y5F%L
M=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].54Q,7U1/7T5-
M4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU;&Q!<G)A>59A
M;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F<F5E4F5S=6QT
M*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L="!S970@86YD
M(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E<W5L="!S970*
M("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@
M8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.F9R964H
M*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*
M("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T
M+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G
M<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E<W5L="!I<R!I
M;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.F9R964H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"1R97-U;'0I"B`@("![
M"B`@("`@("`@<F5T=7)N($!M>7-Q;&E?9G)E95]R97-U;'0H)')E<W5L="D[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M0V]L<R@I"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E
M<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A
M;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U
M;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@
M(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P
M87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E
M($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU
M;4-O;',H)')E<W5L="D*("`@('L*("`@("`@("`D8V]L<R`]($!M>7-Q;&E?
M;G5M7V9I96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<B@I.PH@
M("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@
M("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I
M<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T
M96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J
M(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@
M("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R
M>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E<W5L="D*("`@('L*
M("`@("`@("`D<F]W<R`]($!M>7-Q;&E?;G5M7W)O=W,H)')E<W5L="D["B`@
M("`@("`@:68@*"1R;W=S(#T]/2!N=6QL*2!["B`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^;7ES<6QI4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R(&1I<V%B
M;&5S(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A<F%M(&)O
M;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N<R!I="!O
M9F8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S
M<RX@($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@("`J("`@
M("`@("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET=&EN9R!T
M<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#;VUM:70H
M)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@6%A8(&EF("1T:&ES
M+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD('!R;V)A8FQY
M"B`@("`@("`@+R\@:7-S=64@82!W87)N:6YG(&AE<F4N"B`@("`@("`@)'1H
M:7,M/F%U=&]C;VUM:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L<V4["B`@("`@
M("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C=7)R96YT
M('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+
M(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@
M("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@("`@(&EF
M("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@("`@
M("`@:68@*"1T:&ES+3Y?9&(I('L*("`@("`@("`@("`@("`@(&EF("@A0&UY
M<W%L:5]S96QE8W1?9&(H)'1H:7,M/F-O;FYE8W1I;VXL("1T:&ES+3Y?9&(I
M*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E2
M86ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]($!M
M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL("=#3TU-250G*3L*("`@
M("`@("`@("`@)')E<W5L="`]($!M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE
M8W1I;VXL("=3150@05543T-/34U)5#TQ)RD["B`@("`@("`@("`@("1T:&ES
M+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D
M<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/FUY<W%L
M:5)A:7-E17)R;W(H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<F]L;&)A8VLH*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N
M="!T<F%N<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/
M2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@("`@
M("`@("`@:68@*"1T:&ES+3Y?9&(I('L*("`@("`@("`@("`@("`@(&EF("@A
M0&UY<W%L:5]S96QE8W1?9&(H)'1H:7,M/F-O;FYE8W1I;VXL("1T:&ES+3Y?
M9&(I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q
M;&E286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)')E<W5L="`]
M($!M>7-Q;&E?<75E<GDH)'1H:7,M/F-O;FYE8W1I;VXL("=23TQ,0D%#2R<I
M.PH@("`@("`@("`@("`D<F5S=6QT(#T@0&UY<W%L:5]Q=65R>2@D=&AI<RT^
M8V]N;F5C=&EO;BP@)U-%5"!!551/0T]-34E4/3$G*3L*("`@("`@("`@("`@
M)'1H:7,M/G1R86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I
M9B`H(21R97-U;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;7ES<6QI4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O
M('M[>R!A9F9E8W1E9%)O=W,H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE
M<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@8GD@82!D871A(&UA;FEU
M<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J(#`@:7,@<F5T=7)N960@9F]R
M('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L871E(&1A=&$N"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<F]W<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@:68@*$1".CII<TUA;FEP
M*"1T:&ES+3YL87-T7W%U97)Y*2D@>PH@("`@("`@("`@("!R971U<FX@0&UY
M<W%L:5]A9F9E8W1E9%]R;W=S*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M
M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E
M;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF
M(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM
M;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]M>7-Q;&DZ
M.F-R96%T95-E<75E;F-E*"DL($1"7VUY<W%L:3HZ9')O<%-E<75E;F-E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M
M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG
M971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("!D;R!["B`@("`@
M("`@("`@("1R97!E870@/2`P.PH@("`@("`@("`@("`D=&AI<RT^<'5S:$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`D
M<F5S=6QT(#T@)'1H:7,M/G%U97)Y*"=54$1!5$4@)R`N("1S97%N86UE"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(%-%5"!I9"`]
M($Q!4U1?24Y315)47TE$*&ED("L@,2DG*3L*("`@("`@("`@("`@)'1H:7,M
M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@("`@("`@:68@*"1R97-U;'0@
M/3T]($1"7T]+*2!["B`@("`@("`@("`@("`@("`O+R!#3TU-3TX@0T%310H@
M("`@("`@("`@("`@("`@)&ED(#T@0&UY<W%L:5]I;G-E<G1?:60H)'1H:7,M
M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("`@("`@:68@*"1I9"`A/2`P*2![
M"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1I9#L*("`@("`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("`@("`O+R!%35!462!315$@5$%"3$4*("`@
M("`@("`@("`@("`@("\O(%-E<75E;F-E('1A8FQE(&UU<W0@8F4@96UP='D@
M9F]R('-O;64@<F5A<V]N+`H@("`@("`@("`@("`@("`@+R\@<V\@9FEL;"!I
M="!A;F0@<F5T=7)N(#$*("`@("`@("`@("`@("`@("\O($]B=&%I;B!A('5S
M97(M;&5V96P@;&]C:PH@("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YG971/;F4H)U-%3$5#5"!'151?3$]#2R@G"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`N("(G)'MS97%N86UE?5]L;V-K)RP@
M,3`I(BD["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L
M="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H)')E<W5L="`]/2`P*2!["B`@("`@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YM>7-Q;&E286ES945R<F]R*$1"7T524D]27TY/5%],
M3T-+140I.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O
M(&%D9"!T:&4@9&5F875L="!V86QU90H@("`@("`@("`@("`@("`@)')E<W5L
M="`]("1T:&ES+3YQ=65R>2@G4D503$%#12!)3E1/("<@+B`D<V5Q;F%M90H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@*&ED
M*2!604Q515,@*#`I)RD["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"@H@
M("`@("`@("`@("`@("`@+R\@4F5L96%S92!T:&4@;&]C:PH@("`@("`@("`@
M("`@("`@)')E<W5L="`]("1T:&ES+3YG971/;F4H)U-%3$5#5"!214Q%05-%
M7TQ/0TLH)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`B)R1[<V5Q;F%M97U?;&]C:R<I(BD["B`@("`@("`@("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`O+R!792!K;F]W('=H870@=&AE
M(')E<W5L="!W:6QL(&)E+"!S;R!N;R!N965D('1O('1R>2!A9V%I;@H@("`@
M("`@("`@("`@("`@<F5T=7)N(#$["@H@("`@("`@("`@("!](&5L<V5I9B`H
M)&]N9&5M86YD("8F($1".CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@
M("`@("`@("`D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(
M5$%"3$4I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("\O($].1$5-
M04Y$(%1!0DQ%($-214%424]."B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["@H@("`@("`@("`@
M("`@("`@+R\@4VEN8V4@8W)E871E4V5Q=65N8V4@:6YI=&EA;&EZ97,@=&AE
M($E$('1O(&)E(#$L"B`@("`@("`@("`@("`@("`O+R!W92!D;R!N;W0@;F5E
M9"!T;R!R971R:65V92!T:&4@240@86=A:6X@*&]R('=E('=I;&P@9V5T(#(I
M"B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)')E<W5L="D["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("\O($9I<G-T($E$(&]F(&$@;F5W;'D@8W)E871E9"!S97%U
M96YC92!I<R`Q"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#$["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!](&5L<V5I9B`H1$(Z.FES17)R
M;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("`@("`@("1R97-U;'0M
M/F=E=$-O9&4H*2`]/2!$0E]%4E)/4E]!3%)%04197T5825-44RD*("`@("`@
M("`@("`@>PH@("`@("`@("`@("`@("`@+R\@0D%#2U=!4D13($-/35!!5`H@
M("`@("`@("`@("`@("`@+R\@<V5E(%]"0W-E<75E;F-E*"D@8V]M;65N=`H@
M("`@("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?0D-S97%U96YC92@D
M<V5Q;F%M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E
M<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`D<F5P96%T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*"1R97!E870I.PH*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)')E<W5L="D["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC
M94YA;64H*2P*("`@("`J("`@("`@1$)?;7ES<6QI.CIN97AT240H*2P@1$)?
M;7ES<6QI.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C
M<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@)'-E<6YA
M;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@
M("`@)')E<R`]("1T:&ES+3YQ=65R>2@G0U)%051%(%1!0DQ%("<@+B`D<V5Q
M;F%M90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G("AI9"!)3E1%
M1T52(%5.4TE'3D5$($%55$]?24Y#4D5-14Y4($Y/5"!.54Q,+"<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("X@)R!04DE-05)9($M%62AI9"DI)RD[
M"B`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S.PH@("`@("`@('T*("`@("`@("`O+R!I;G-E<G0@>6EE
M;&1S('9A;'5E(#$L(&YE>'1)9"!C86QL('=I;&P@9V5N97)A=&4@240@,@H@
M("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH(DE.4T525"!)3E1/("1[<V5Q
M;F%M97T@*&ED*2!604Q515,@*#`I(BD["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@("`O*BH*("`@("`J($1E;&5T
M97,@82!S97%U96YC90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E
M<5]N86UE("!N86UE(&]F('1H92!S97%U96YC92!T;R!B92!D96QE=&5D"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!
M($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG9713
M97%U96YC94YA;64H*2P*("`@("`J("`@("`@1$)?;7ES<6PZ.FYE>'1)1"@I
M+"!$0E]M>7-Q;#HZ8W)E871E4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC
M=&EO;B!D<F]P4V5Q=65N8V4H)'-E<5]N86UE*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^<75E<GDH)T123U`@5$%"3$4@)R`N("1T:&ES+3YG9713
M97%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@7T)#<V5Q=65N8V4H*0H*("`@("\J*@H@("`@("H@0F%C:W=A
M<F1S(&-O;7!A=&EB:6QI='D@=VET:"!O;&0@<V5Q=65N8V4@96UU;&%T:6]N
M(&EM<&QE;65N=&%T:6]N"B`@("`@*B`H8VQE86X@=7`@=&AE(&1U<&5S*0H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<6YA;64@('1H92!S97%U
M96YC92!N86UE('1O(&-L96%N('5P"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!T<G5E(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?0D-S97%U96YC92@D<V5Q;F%M92D*("`@('L*("`@
M("`@("`O+R!/8G1A:6X@82!U<V5R+6QE=F5L(&QO8VLN+BX@=&AI<R!W:6QL
M(')E;&5A<V4@86YY('!R979I;W5S"B`@("`@("`@+R\@87!P;&EC871I;VX@
M;&]C:W,L(&)U="!U;FQI:V4@3$]#2R!404),15,L(&ET(&1O97,@;F]T(&%B
M;W)T"B`@("`@("`@+R\@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX@86YD(&ES
M(&UU8V@@;&5S<R!F<F5Q=65N=&QY('5S960N"B`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YG971/;F4H(E-%3$5#5"!'151?3$]#2R@G)'MS97%N86UE?5]L
M;V-K)RPQ,"DB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI
M('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@
M("`@(&EF("@D<F5S=6QT(#T](#`I('L*("`@("`@("`@("`@+R\@1F%I;&5D
M('1O(&=E="!T:&4@;&]C:RP@8V%N)W0@9&\@=&AE(&-O;G9E<G-I;VXL(&)A
M:6P*("`@("`@("`@("`@+R\@=VET:"!A($1"7T524D]27TY/5%],3T-+140@
M97)R;W(*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YM>7-Q;&E286ES945R
M<F]R*$1"7T524D]27TY/5%],3T-+140I.PH@("`@("`@('T*"B`@("`@("`@
M)&AI9VAE<W1?:60@/2`D=&AI<RT^9V5T3VYE*")314Q%0U0@34%8*&ED*2!&
M4D]-("1[<V5Q;F%M97TB*3L*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)&AI
M9VAE<W1?:60I*2!["B`@("`@("`@("`@(')E='5R;B`D:&EG:&5S=%]I9#L*
M("`@("`@("!]"@H@("`@("`@("\O(%1H:7,@<VAO=6QD(&MI;&P@86QL(')O
M=W,@97AC97!T('1H92!H:6=H97-T"B`@("`@("`@+R\@5V4@<VAO=6QD('!R
M;V)A8FQY(&1O('-O;65T:&EN9R!I9B`D:&EG:&5S=%]I9"!I<VXG=`H@("`@
M("`@("\O(&YU;65R:6,L(&)U="!))VT@870@82!L;W-S(&%S(&AO=R!T;R!H
M86YD;&4@=&AA="XN+@H@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<75E<GDH
M)T1%3$5412!&4D]-("<@+B`D<V5Q;F%M90H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`B(%=(15)%(&ED(#P^("1H:6=H97-T7VED(BD["B`@
M("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@+R\@268@86YO
M=&AE<B!T:')E860@:&%S(&)E96X@=V%I=&EN9R!F;W(@=&AI<R!L;V-K+`H@
M("`@("`@("\O(&ET('=I;&P@9V\@=&AR=2!T:&4@86)O=F4@<')O8V5D=7)E
M+"!B=70@=VEL;"!H879E(&YO"B`@("`@("`@+R\@<F5A;"!E9F9E8W0*("`@
M("`@("`D<F5S=6QT(#T@)'1H:7,M/F=E=$]N92@B4T5,14-4(%)%3$5!4T5?
M3$]#2R@G)'MS97%N86UE?5]L;V-K)RDB*3L*("`@("`@("!I9B`H1$(Z.FES
M17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N("1R97-U;'0[
M"B`@("`@("`@?0H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[('%U;W1E261E;G1I9FEE<B@I"@H@("`@+RHJ"B`@
M("`@*B!1=6]T97,@82!S=')I;F<@<V\@:70@8V%N(&)E('-A9F5L>2!U<V5D
M(&%S(&$@=&%B;&4@;W(@8V]L=6UN(&YA;64*("`@("`J"B`@("`@*B!->5-1
M3"!C86XG="!H86YD;&4@=&AE(&)A8VMT:6-K(&-H87)A8W1E<B`H/&MB9#Y@
M/"]K8F0^*2!I;@H@("`@("H@=&%B;&4@;W(@8V]L=6UN(&YA;65S+@H@("`@
M("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T<B`@:61E;G1I9FEE<B!N86UE
M('1O(&)E('%U;W1E9`H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG("!Q
M=6]T960@:61E;G1I9FEE<B!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E($1"
M7V-O;6UO;CHZ<75O=&5)9&5N=&EF:65R*"D*("`@("`J($!S:6YC92!-971H
M;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@("`@
M9G5N8W1I;VX@<75O=&5)9&5N=&EF:65R*"1S='(I"B`@("!["B`@("`@("`@
M<F5T=7)N("=@)R`N("1S='(@+B`G8"<["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97-C87!E4VEM<&QE*"D*"B`@("`O*BH*("`@("`J($5S8V%P
M97,@82!S=')I;F<@86-C;W)D:6YG('1O('1H92!C=7)R96YT($1"35,G<R!S
M=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S='(@('1H
M92!S=')I;F<@=&\@8F4@97-C87!E9`H@("`@("H*("`@("`J($!R971U<FX@
M<W1R:6YG("!T:&4@97-C87!E9"!S=')I;F<*("`@("`J"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@("`@*B!`<VEN8V4@365T:&]D
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-BXP"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&5S8V%P95-I;7!L92@D<W1R*0H@("`@>PH@("`@("`@(')E='5R
M;B!`;7ES<6QI7W)E86Q?97-C87!E7W-T<FEN9R@D=&AI<RT^8V]N;F5C=&EO
M;BP@)'-T<BD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y
M3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!9&1S($Q)34E4(&-L875S
M97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG('1O(&-U<G)E;G0@1$)-
M4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R
M>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*("`@("`J($!P87)A;2!I;G0@("`@
M)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T;R!F971C:&EN9R`H,"`]('1H
M92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@:6YT("`@("1C;W5N="`@('1H
M92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@("`J($!P87)A;2!M:7AE
M9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@
M8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@97AE
M8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T
M8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E
M<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE
M;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!Q=65R>2!S
M=')I;F<@=VET:"!,24U)5"!C;&%U<V5S(&%D9&5D"B`@("`@*@H@("`@("H@
M0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N8W1I;VX@;6]D:69Y
M3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U;G0L("1P87)A;7,@/2!A
M<G)A>2@I*0H@("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI<"@D<75E<GDI
M*2!["B`@("`@("`@("`@(')E='5R;B`D<75E<GD@+B`B($Q)34E4("1C;W5N
M="(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N("1Q=65R
M>2`N("(@3$E-250@)&9R;VTL("1C;W5N="(["B`@("`@("`@?0H@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&UY<W%L:5)A:7-E17)R;W(H*0H*("`@
M("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D
M:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@
M:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A
M:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)2
M3U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@
M("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@
M9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S
M964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7VUY
M<W%L:3HZ97)R;W).871I=F4H*2P@1$)?8V]M;6]N.CIE<G)O<D-O9&4H*0H@
M("`@("HO"B`@("!F=6YC=&EO;B!M>7-Q;&E286ES945R<F]R*"1E<G)N;R`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@
M("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465]%4E)/4E,I('L*("`@("`@("`@("`@("`@("1T
M:&ES+3YE<G)O<F-O9&5?;6%P6S$P,C)=(#T@1$)?15)23U)?0T].4U1204E.
M5#L*("`@("`@("`@("`@("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P-#A=
M(#T@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3#L*("`@("`@("`@("`@
M("`@("1T:&ES+3YE<G)O<F-O9&5?;6%P6S$P-C)=(#T@1$)?15)23U)?0T].
M4U1204E.5#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@
M("\O($1O:6YG('1H:7,@:6X@8V%S92!M;V1E(&-H86YG97,@9'5R:6YG(')U
M;G1I;64N"B`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LQ
M,#(R72`]($1"7T524D]27T%,4D5!1%E?15A)4U13.PH@("`@("`@("`@("`@
M("`@)'1H:7,M/F5R<F]R8V]D95]M87!;,3`T.%T@/2!$0E]%4E)/4E]#3TY3
M5%)!24Y4.PH@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;
M,3`V,ET@/2!$0E]%4E)/4E]!3%)%04197T5825-44SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*&UY<W%L
M:5]E<G)N;R@D=&AI<RT^8V]N;F5C=&EO;BDI.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!`;7ES
M<6QI7V5R<FYO*"1T:&ES+3YC;VYN96-T:6]N*2`N("<@*BH@)R`N"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($!M>7-Q;&E?97)R;W(H)'1H
M:7,M/F-O;FYE8W1I;VXI*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!$0DU3
M)R!N871I=F4@97)R;W(@8V]D92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R
M>0H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@1$)-4R<@97)R;W(@
M8V]D90H@("`@("HO"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("![
M"B`@("`@("`@<F5T=7)N($!M>7-Q;&E?97)R;F\H)'1H:7,M/F-O;FYE8W1I
M;VXI.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I
M"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@
M=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@0'!A<F%M(&]B
M:F5C='QS=')I;F<@("1R97-U;'0@($1"7W)E<W5L="!O8FIE8W0@9G)O;2!A
M('%U97)Y(&]R(&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@;V8@82!T86)L92X*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5VAI;&4@
M=&AI<R!A;'-O(&%C8V5P=',@82!Q=65R>2!R97-U;'0*("`@("`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5S;W5R8V4@:61E;G1I9FEE
M<BP@=&AI<R!B96AA=FEO<B!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!D97!R96-A=&5D+@H@("`@("H@0'!A<F%M(&EN="`@
M("`@("`@("`@("1M;V1E("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A
M>2!W:71H('1H92!I;F9O<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@
M("`@("`@("`@("`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<V5T3W!T:6]N*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L
M;"D*("`@('L*("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D
M(&$@=&%B;&4@;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT
M(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@
M("`@("`D:60@/2!`;7ES<6QI7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")314Q%0U0@*B!&4D]-
M("1R97-U;'0@3$E-250@,"(I.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]
M('1R=64["B`@("`@("`@?2!E;'-E:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L
M="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@
M<F5C96EV960@82!R97-U;'0@;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R
M86-T('1H92!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@
M("`@("HO"B`@("`@("`@("`@("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@
M("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E
M:79E9"!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B!#;W!Y(&ET+@H@("`@("`@("`@("`@*B!$97!R96-A=&5D+B`@2&5R
M92!F;W(@8V]M<&%T:6)I;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@
M("`@("`@("`@)&ED(#T@)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I
M;F<@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF("@A:7-?82@D:60L
M("=M>7-Q;&E?<F5S=6QT)RDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YM>7-Q;&E286ES945R<F]R*$1"7T524D]27TY%141?34]215]$051!*3L*
M("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%312D@>PH@("`@("`@
M("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@
M("!]"@H@("`@("`@("1C;W5N="`]($!M>7-Q;&E?;G5M7V9I96QD<R@D:60I
M.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D["@H@("`@("`@(&EF("@D;6]D
M92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0[
M"B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[
M("1I*RLI('L*("`@("`@("`@("`@)'1M<"`]($!M>7-Q;&E?9F5T8VA?9FEE
M;&0H)&ED*3L*"B`@("`@("`@("`@("1F;&%G<R`]("<G.PH@("`@("`@("`@
M("!F;W)E86-H("@D=&AI<RT^;7ES<6QI7V9L86=S(&%S("1C;VYS="`]/B`D
M;65A;G,I('L*("`@("`@("`@("`@("`@(&EF("@D=&UP+3YF;&%G<R`F("1C
M;VYS="D@>PH@("`@("`@("`@("`@("`@("`@("1F;&%G<R`N/2`D;65A;G,@
M+B`G("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@
M("`@("`@:68@*"1T;7`M/F1E9BD@>PH@("`@("`@("`@("`@("`@)&9L86=S
M("X]("=D969A=6QT7R<@+B!R87=U<FQE;F-O9&4H)'1M<"T^9&5F*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D9FQA9W,@/2!T<FEM*"1F;&%G<RD[
M"@H@("`@("`@("`@("`D<F5S6R1I72`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@)W1A8FQE)R`]/B`D8V%S95]F=6YC*"1T;7`M/G1A8FQE*2P*("`@("`@
M("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8R@D=&UP+3YN86UE*2P*
M("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@:7-S970H)'1H:7,M/FUY<W%L
M:5]T>7!E<ULD=&UP+3YT>7!E72D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@/R`D=&AI<RT^;7ES<6QI7W1Y<&5S6R1T;7`M/G1Y<&5=
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#H@)W5N:VYO
M=VXG+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B`D=&UP+3YM87A?;&5N
M9W1H+`H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B`D9FQA9W,L"B`@("`@
M("`@("`@("D["@H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.
M1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E
M<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@
M("`@("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L
M92==75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("`O+R!F<F5E('1H92!R97-U;'0@;VYL>2!I9B!W
M92!W97)E(&-A;&QE9"!O;B!A('1A8FQE"B`@("`@("`@:68@*"1G;W1?<W1R
M:6YG*2!["B`@("`@("`@("`@($!M>7-Q;&E?9G)E95]R97-U;'0H)&ED*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*("`@
M("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI<W1I
M;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!`<&%R
M86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W86YT
M('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H
M92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R:79E<B!D;V5S
M;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@=&AE(&]B:F5C
M="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E<W,@<')O=&5C
M=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F*"D*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E*0H@("`@>PH@
M("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@8V%S92`G=&%B
M;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4TA/5R!404),15,G.PH@
M("`@("`@("`@("!C87-E("=U<V5R<R<Z"B`@("`@("`@("`@("`@("!R971U
M<FX@)U-%3$5#5"!$25-424Y#5"!5<V5R($923TT@;7ES<6PN=7-E<B<["B`@
M("`@("`@("`@(&-A<V4@)V1A=&%B87-E<R<Z"B`@("`@("`@("`@("`@("!R
M971U<FX@)U-(3U<@1$%404)!4T53)SL*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@('T*
M"B`@("`O+R!]?7T*"GT*"B\J"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B
M+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T"B`J($5N9#H*("HO"@H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]$0B]O8VDX+G!H<```````````````````````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,3`V-38V(#$P-3$U-#,T,3,S(#`R,#,S
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D
M<FEV97(@9F]R(%!(4"=S(&]C:3@@97AT96YS:6]N"B`J(&9O<B!I;G1E<F%C
M=&EN9R!W:71H($]R86-L92!D871A8F%S97,*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T
M:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A
M="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y
M(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@
M=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P
M86-K86=E("`@($1""B`J($!A=71H;W(@("`@($IA;65S($PN(%!I;F4@/&IL
M<$!V86QI;G5X+F-O;3X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O
M<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@
M5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E<G-I
M;VX@("`@0U93.B`D260Z(&]C:3@N<&AP+'8@,2XQ,#,@,C`P-2\P-"\Q,2`Q
M-3HQ,#HR,B!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P
M96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE
M($1"7V-O;6UO;B!C;&%S<R!S;R!I="!C86X@8F4@97AT96YD960@9G)O;0H@
M*B\*<F5Q=6ER95]O;F-E("=$0B]C;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@
M;65T:&]D<R!014%2($1"('5S97,@=&\@:6YT97)A8W0@=VET:"!02%`G<R!O
M8VDX(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!/<F%C;&4@
M9&%T86)A<V5S"B`J"B`J($1E9FEN:71E;'D@=V]R:W,@=VET:"!V97)S:6]N
M<R`X(&%N9"`Y(&]F($]R86-L92X*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R
M;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J($)E
M(&%W87)E+BXN("!/0TE%<G)O<B@I(&]N;'D@87!P96%R<R!T;R!R971U<FX@
M86YY=&AI;F<@=VAE;B!G:79E;B!A"B`J('-T871E;65N="P@<V\@9G5N8W1I
M;VYS(')E='5R;B!T:&4@9V5N97)I8R!$0E]%4E)/4B!I;G-T96%D(&]F(&UO
M<F4*("H@=7-E9G5L(&5R<F]R<R!T:&%T(&AA=F4@=&\@9&\@=VET:"!F965D
M8F%C:R!F<F]M('1H92!D871A8F%S92X*("H*("H@0&-A=&5G;W)Y("`@1&%T
M86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@2F%M97,@
M3"X@4&EN92`\:FQP0'9A;&EN=7@N8V]M/@H@*B!`875T:&]R("`@("!$86YI
M96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@
M(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z
M+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N
M,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N-@H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"F-L87-S($1"
M7V]C:3@@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I
M97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL
M(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO
M"B`@("!V87(@)'!H<'1Y<&4@/2`G;V-I."<["@H@("`@+RHJ"B`@("`@*B!4
M:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@8F4@=7-E9"`H9&(R+"!A
M8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D9&)S>6YT87@@/2`G;V-I."<["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8V%P86)I;&ET:65S(&]F('1H:7,@1$(@:6UP;&5M96YT871I;VX*
M("`@("`J"B`@("`@*B!4:&4@)VYE=U]L:6YK)R!E;&5M96YT(&-O;G1A:6YS
M('1H92!02%`@=F5R<VEO;B!T:&%T(&9I<G-T('!R;W9I9&5D"B`@("`@*B!N
M97=?;&EN:R!S=7!P;W)T(&9O<B!T:&ES($1"35,N("!#;VYT86EN<R!F86QS
M92!I9B!I="=S('5N<W5P<&]R=&5D+@H@("`@("H*("`@("`J($UE86YI;F<@
M;V8@=&AE("=L:6UI="<@96QE;65N=#H*("`@("`J("`@*R`G96UU;&%T92<@
M/2!E;75L871E('=I=&@@9F5T8V@@<F]W(&)Y(&YU;6)E<@H@("`@("H@("`K
M("=A;'1E<B<@("`](&%L=&5R('1H92!Q=65R>0H@("`@("H@("`K(&9A;'-E
M("`@("`]('-K:7`@<F]W<PH@("`@("H*("`@("`J($!V87(@87)R87D*("`@
M("`J+PH@("`@=F%R("1F96%T=7)E<R`](&%R<F%Y*`H@("`@("`@("=L:6UI
M="<@("`@("`@("`]/B`G86QT97(G+`H@("`@("`@("=N97=?;&EN:R<@("`@
M("`]/B`G-2XP+C`G+`H@("`@("`@("=N=6UR;W=S)R`@("`@("`]/B`G<W5B
M<75E<GDG+`H@("`@("`@("=P8V]N;F5C="<@("`@("`]/B!T<G5E+`H@("`@
M("`@("=P<F5P87)E)R`@("`@("`]/B!T<G5E+`H@("`@("`@("=S<VPG("`@
M("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@
M=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA<'!I;F<@;V8@;F%T
M:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S"B`@("`@*B!`=F%R
M(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E7VUA<"`](&%R<F%Y
M*`H@("`@("`@(#$@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@
M("`Y,#`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`Y,#0@(#T^($1"
M7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@(#DQ,R`@/3X@1$)?15)23U)?
M5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@(#DR,2`@/3X@1$)?15)23U)?
M4UE.5$%8+`H@("`@("`@(#DR,R`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@
M("`@(#DT,B`@/3X@1$)?15)23U)?3D]354-(5$%"3$4L"B`@("`@("`@.34U
M("`]/B!$0E]%4E)/4E]!3%)%04197T5825-44RP*("`@("`@("`Q-#`P(#T^
M($1"7T524D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@,30P,2`]
M/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@("`@(#$T,#<@/3X@1$)?15)23U)?
M0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@("`Q-#$X(#T^($1"7T524D]2
M7TY/5%]&3U5.1"P*("`@("`@("`Q-#<V(#T^($1"7T524D]27T1)5EI%4D\L
M"B`@("`@("`@,3<R,B`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@
M("`@("`R,C@Y(#T^($1"7T524D]27TY/4U5#2%1!0DQ%+`H@("`@("`@(#(R
M.3$@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`R,CDR(#T^($1"
M7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@,C0T.2`]/B!$0E]%4E)/4E]#
M3TY35%)!24Y4+`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@9&%T
M86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A<B!R
M97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@+RHJ
M"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG('1O
M(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R
M("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D871A
M(&UA;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI='1E9"!A=71O;6%T:6-A
M;&QY/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U93L*"B`@("`O*BH*
M("`@("`J(%-T;W)E<R!T:&4@)&1A=&$@<&%S<V5D('1O(&5X96-U=&4H*2!I
M;B!T:&4@;V-I."!D<FEV97(*("`@("`J"B`@("`@*B!'971S(')E<V5T('1O
M(&%R<F%Y*"D@=VAE;B!S:6UP;&51=65R>2@I(&ES(')U;BX*("`@("`J"B`@
M("`@*B!.965D960@:6X@8V%S92!U<V5R('=A;G1S('1O(&-A;&P@;G5M4F]W
M<R@I(&%F=&5R('!R97!A<F4O97AE8W5T90H@("`@("H@=V%S('5S960N"B`@
M("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7V1A=&$@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@("H@5&AE(')E<W5L="!O<B!S=&%T96UE;G0@:&%N9&QE(&9R;VT@=&AE
M(&UO<W0@<F5C96YT;'D@97AE8W5T960@<75E<GD*("`@("`J($!V87(@<F5S
M;W5R8V4*("`@("`J+PH@("`@=F%R("1L87-T7W-T;70["@H@("`@+RHJ"B`@
M("`@*B!)<R!T:&4@9VEV96X@<')E<&%R960@<W1A=&5M96YT(&$@9&%T82!M
M86YI<'5L871I;VX@<75E<GD_"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`
M86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1M86YI<%]Q=65R>2`]
M(&%R<F%Y*"D["@H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R
M"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK8F0^
M)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7V]C:3@H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O;FYE8W0@
M=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D
M871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M971H;V0@
M9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@("`@("H*
M("`@("`J($EF(%!(4"!I<R!A="!V97)S:6]N(#4N,"XP(&]R(&=R96%T97(Z
M"B`@("`@*B`@("L@1V5N97)A;&QY+"!O8VE?8V]N;F5C="@I(&]R(&]C:5]P
M8V]N;F5C="@I(&%R92!U<V5D+@H@("`@("H@("`K($)U="!I9B!T:&4@;F5W
M7VQI;FL@1%-.(&]P=&EO;B!I<R!S970@=&\@=')U92P@;V-I7VYE=U]C;VYN
M96-T*"D*("`@("`J("`@("!I<R!U<V5D+@H@("`@("H*("`@("`J(%=H96X@
M=7-I;F<@4$A0('9E<G-I;VX@-"YX+"!/0TE,;V=O;B@I(&]R($]#25!,;V=O
M;B@I(&%R92!U<V5D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!O8VDX(&1R
M:79E<B!S=7!P;W)T<R!T:&4@9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS
M.@H@("`@("H@("`K(&-H87)S970@("`@("`@5&AE(&-H87)A8W1E<B!S970@
M=&\@8F4@=7-E9"!O;B!T:&4@8V]N;F5C=&EO;BX*("`@("`J("`@("`@("`@
M("`@("`@("`@("!/;FQY('5S960@:68@4$A0(&ES(&%T('9E<G-I;VX@-2XP
M+C`@;W(@9W)E871E<@H@("`@("H@("`@("`@("`@("`@("`@("`@(&%N9"!T
M:&4@3W)A8VQE('-E<G9E<B!I<R!A="`Y+C(@;W(@9W)E871E<BX*("`@("`J
M("`@("`@("`@("`@("`@("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q
M+C<N,"X*("`@("`J("`@*R!N97=?;&EN:R`@("`@($EF('-E="!T;R!T<G5E
M+"!C875S97,@<W5B<V5Q=65N="!C86QL<R!T;PH@("`@("H@("`@("`@("`@
M("`@("`@("`@(&-O;FYE8W0H*2!T;R!R971U<FX@82!N97<@8V]N;F5C=&EO
M;B!L:6YK"B`@("`@*B`@("`@("`@("`@("`@("`@("`@:6YS=&5A9"!O9B!T
M:&4@97AI<W1I;F<@;VYE+B`@5T%23DE.1SH@=&AI<R!I<PH@("`@("H@("`@
M("`@("`@("`@("`@("`@(&YO="!P;W)T86)L92!T;R!O=&AE<B!$0DU3)W,N
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@079A:6QA8FQE('-I;F-E(%!%
M05(@1$(@,2XW+C`N"B`@("`@*@H@("`@("H@0'!A<F%M(&%R<F%Y("1D<VX@
M("`@("`@("!T:&4@9&%T82!S;W5R8V4@;F%M90H@("`@("H@0'!A<F%M(&)O
M;VP@("1P97)S:7-T96YT("!S:&]U;&0@=&AE(&-O;FYE8W1I;VX@8F4@<&5R
M<VES=&5N=#\*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@8V]N;F5C="@D9'-N+"`D<&5R<VES=&5N="`](&9A
M;'-E*0H@("`@>PH@("`@("`@(&EF("@A4$5!4CHZ;&]A9$5X=&5N<VEO;B@G
M;V-I."<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O
M<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@
M("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D
M8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D
M<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@("!I9B`H9G5N8W1I
M;VY?97AI<W1S*"=O8VE?8V]N;F5C="<I*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D9'-N6R=N97=?;&EN:R==*0H@("`@("`@("`@("`@("`@)B8@*"1D
M<VY;)VYE=U]L:6YK)UT@/3T@)W1R=64G('Q\("1D<VY;)VYE=U]L:6YK)UT@
M/3T]('1R=64I*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D8V]N
M;F5C=%]F=6YC=&EO;B`]("=O8VE?;F5W7V-O;FYE8W0G.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&-O;FYE8W1?9G5N8W1I;VX@
M/2`D<&5R<VES=&5N="`_("=O8VE?<&-O;FYE8W0G"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(#H@)V]C:5]C;VYN96-T)SL*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@+R\@0F%C:W=A<F1S(&-O;7!A=&EB:6QI
M='D@=VET:"!$0B`\(#$N-RXP"B`@("`@("`@("`@(&EF("AE;7!T>2@D9'-N
M6R=D871A8F%S92==*2`F)B`A96UP='DH)&1S;ELG:&]S='-P96,G72DI('L*
M("`@("`@("`@("`@("`@("1D8B`]("1D<VY;)VAO<W1S<&5C)UT["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D9&(@/2`D9'-N6R=D
M871A8F%S92==.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D8VAA<B`]
M(&5M<'1Y*"1D<VY;)V-H87)S970G72D@/R!N=6QL(#H@)&1S;ELG8VAA<G-E
M="==.PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C
M=%]F=6YC=&EO;B@D9'-N6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-N6R=P87-S
M=V]R9"==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9&(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1C:&%R*3L*("`@("`@("`@("`@
M)&5R<F]R(#T@3T-)17)R;W(H*3L*("`@("`@("`@("`@:68@*"%E;7!T>2@D
M97)R;W(I("8F("1E<G)O<ELG8V]D92==(#T](#$R-30Q*2!["B`@("`@("`@
M("`@("`@("`O+R!#;W5L9&XG="!F:6YD(%1.4R!L:7-T96YE<BX@(%1R>2!D
M:7)E8W0@8V]N;F5C=&EO;BX*("`@("`@("`@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1D<VY;)W5S97)N86UE)UTL
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D9'-N6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1C:&%R*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E
M;G0@/R`G3T-)4$QO9V]N)R`Z("=/0TE,;V=O;B<["B`@("`@("`@("`@(&EF
M("@D9'-N6R=H;W-T<W!E8R==*2!["B`@("`@("`@("`@("`@("`D=&AI<RT^
M8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D9'-N6R=U<V5R;F%M
M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D
M<VY;)VAO<W1S<&5C)UTI.PH@("`@("`@("`@("!](&5L<V5I9B`H)&1S;ELG
M=7-E<FYA;64G72!\?"`D9'-N6R=P87-S=V]R9"==*2!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^8V]N;F5C=&EO;B`]($`D8V]N;F5C=%]F=6YC=&EO;B@D
M9'-N6R=U<V5R;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG<&%S<W=O<F0G72D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@A)'1H:7,M
M/F-O;FYE8W1I;VXI('L*("`@("`@("`@("`@)&5R<F]R(#T@3T-)17)R;W(H
M*3L*("`@("`@("`@("`@)&5R<F]R(#T@*&ES7V%R<F%Y*"1E<G)O<BDI(#\@
M)&5R<F]R6R=M97-S86=E)UT@.B!N=6QL.PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL
M+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)&5R<F]R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O;FYE8W0H*0H*("`@("\J
M*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@9&%T86)A<V4@<V5R=F5R
M"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L
M($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I;VX@9&ES8V]N
M;F5C="@I"B`@("!["B`@("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G;V-I
M7V-L;W-E)RDI('L*("`@("`@("`@("`@)')E="`]($!O8VE?8VQO<V4H)'1H
M:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1R970@/2!`3T-)3&]G3V9F*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@
M("!]"B`@("`@("`@)'1H:7,M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@
M(')E='5R;B`D<F5T.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-I
M;7!L95%U97)Y*"D*"B`@("`O*BH*("`@("`J(%-E;F1S(&$@<75E<GD@=&\@
M=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J(%1O(&1E=&5R;6EN
M92!H;W<@;6%N>2!R;W=S(&]F(&$@<F5S=6QT('-E="!G970@8G5F9F5R960@
M=7-I;F<*("`@("`J(&]C:7-E='!R969E=&-H*"DL('-E92!T:&4@(G)E<W5L
M=%]B=69F97)I;F<B(&]P=&EO;B!I;B!S971/<'1I;VYS*"DN"B`@("`@*B!4
M:&ES(&]P=&EO;B!W87,@861D960@:6X@4F5L96%S92`Q+C<N,"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN9PH@
M("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT(')E
M<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@*B`@
M("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H97(@
M<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K(&$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N8W1I
M;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1T:&ES+3Y?
M9&%T82`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/FQA<W1?<&%R86UE=&5R
M<R`](&%R<F%Y*"D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E
M<GD["B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R
M>2D["B`@("`@("`@)')E<W5L="`]($!/0TE087)S92@D=&AI<RT^8V]N;F5C
M=&EO;BP@)'%U97)Y*3L*("`@("`@("!I9B`H(21R97-U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@I.PH@("`@("`@
M('T*("`@("`@("!I9B`H)'1H:7,M/F%U=&]C;VUM:70I('L*("`@("`@("`@
M("`@)'-U8V-E<W,@/2!`3T-)17AE8W5T92@D<F5S=6QT+$]#25]#3TU-251?
M3TY?4U5#0T534RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-U
M8V-E<W,@/2!`3T-)17AE8W5T92@D<F5S=6QT+$]#25]$149!54Q4*3L*("`@
M("`@("!]"B`@("`@("`@:68@*"$D<W5C8V5S<RD@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R*"1R97-U;'0I.PH@("`@("`@
M('T*("`@("`@("`D=&AI<RT^;&%S=%]S=&UT(#T@)')E<W5L=#L*("`@("`@
M("!I9B`H1$(Z.FES36%N:7`H)'%U97)Y*2D@>PH@("`@("`@("`@("!R971U
M<FX@1$)?3TL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&]C:7-E
M='!R969E=&-H*"1R97-U;'0L("1T:&ES+3YO<'1I;VYS6R=R97-U;'1?8G5F
M9F5R:6YG)UTI.PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@
M("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;F5X=%)E<W5L="@I
M"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I;G1E<FYA;"!O<F%C;&4@<F5S
M=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A:6QA8FQE(')E<W5L=`H@("`@
M("H*("`@("`J($!P87)A;2!A('9A;&ED(&]C:3@@<F5S=6QT(')E<V]U<F-E
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@*B!`
M<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R=VES
M92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E<W5L
M="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J*@H@
M("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT;R!T
M:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@=&AE
M(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B;&4N
M"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R92!I
M;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@
M;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R
M97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L
M87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@
M82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U
M<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@
M("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC960@
M87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT("`@
M("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U;&0@
M8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@("`@
M=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@("`@
M*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@3E5,
M3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@("`@
M("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@("`@
M("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D92P@
M)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@(3T]
M(&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R
M*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@
M("`@)&UO<F5D871A(#T@0$]#249E=&-H26YT;R@D<F5S=6QT+"1A<G(L3T-)
M7T%34T]#*T]#25]215154DY?3E5,3%,K3T-)7U)%5%523E],3T)3*3L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F"B`@("`@("`@("`@("`@("`D
M;6]R961A=&$I"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1A<G(@
M/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@
M("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;6]R
M961A=&$@/2!/0TE&971C:$EN=&\H)')E<W5L="PD87)R+$]#25]215154DY?
M3E5,3%,K3T-)7U)%5%523E],3T)3*3L*("`@("`@("!]"B`@("`@("`@:68@
M*"$D;6]R961A=&$I('L*("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@
M("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG
M72`F($1"7U!/4E1!0DE,25197U)44DE-*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?<G1R:6U!<G)A>59A;'5E<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"
M24Q)5%E?3E5,3%]43U]%35!462D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O
M;G9E<G1.=6QL07)R87E686QU97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@9G)E95)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H
M92!R97-U;'0@<V5T(&%N9"!F<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y
M('1H92!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@
M;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@
M1$)?<F5S=6QT.CIF<F5E*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA
M<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A
M('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R
M8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@
M*@H@("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%
M(&EF("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIF<F5E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L
M="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!`3T-)1G)E95-T871E
M;65N="@D<F5S=6QT*3L*("`@('T*"B`@("`O*BH*("`@("`J($9R965S('1H
M92!I;G1E<FYA;"!R97-O=7)C97,@87-S;V-I871E9"!W:71H(&$@<')E<&%R
M960@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)'-T;70@
M("`@("`@("`@('1H92!P<F5P87)E9"!S=&%T96UE;G0G<R!R97-O=7)C90H@
M("`@("H@0'!A<F%M(&)O;VP@("`@("1F<F5E7W)E<V]U<F-E("!S:&]U;&0@
M=&AE(%!(4"!R97-O=7)C92!B92!F<F5E9"!T;V\_"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!5<V4@9F%L<V4@:68@>6]U(&YE
M960@=&\@9V5T(&1A=&$*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&9R;VT@=&AE(')E<W5L="!S970@;&%T97(N"B`@("`@*@H@
M("`@("H@0')E='5R;B!B;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF
M("1R97-U;'0@:7,@:6YV86QI9`H@("`@("H*("`@("`J($!S964@1$)?;V-I
M.#HZ<')E<&%R92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&9R9650<F5P87)E
M9"@D<W1M="P@)&9R965?<F5S;W5R8V4@/2!T<G5E*0H@("`@>PH@("`@("`@
M(&EF("@A:7-?<F5S;W5R8V4H)'-T;70I*2!["B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*"1F<F5E7W)E<V]U<F-E
M*2!["B`@("`@("`@("`@($!O8VEF<F5E<W1A=&5M96YT*"1S=&UT*3L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YP<F5P87)E7W1Y<&5S
M6RAI;G0I)'-T;71=*2D@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^<')E
M<&%R95]T>7!E<ULH:6YT*21S=&UT72D["B`@("`@("`@("`@('5N<V5T*"1T
M:&ES+3YM86YI<%]Q=65R>5LH:6YT*21S=&UT72D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@=')U93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N
M=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R
M;W=S(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J($]N;'D@=V]R:W,@
M:68@=&AE($1"7U!/4E1!0DE,25197TY535)/5U,@<&]R=&%B:6QI='D@;W!T
M:6]N"B`@("`@*B!I<R!T=7)N960@;VXN"B`@("`@*@H@("`@("H@5&AI<R!M
M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S
M90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@($ET(&-A
M;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"
M7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`
M<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E
M<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@
M;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*2P@1$)?8V]M;6]N
M.CIS971/<'1I;VXH*0H@("`@("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1R
M97-U;'0I"B`@("!["B`@("`@("`@+R\@96UU;&%T92!N=6U2;W=S(&9O<B!/
M<F%C;&4N("!Y=6-K+@H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R
M=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY535)/5U,@)B8*("`@("`@
M("`@("`@)')E<W5L="`]/3T@)'1H:7,M/FQA<W1?<W1M="D*("`@("`@("![
M"B`@("`@("`@("`@("1C;W5N='%U97)Y(#T@)U-%3$5#5"!#3U5.5"@J*2!&
M4D]-("@G+B1T:&ES+3YL87-T7W%U97)Y+B<I)SL*("`@("`@("`@("`@)'-A
M=F5?<75E<GD@/2`D=&AI<RT^;&%S=%]Q=65R>3L*("`@("`@("`@("`@)'-A
M=F5?<W1M="`]("1T:&ES+3YL87-T7W-T;70["@H@("`@("`@("`@("!I9B`H
M8V]U;G0H)'1H:7,M/E]D871A*2D@>PH@("`@("`@("`@("`@("`@)'-M="`]
M("1T:&ES+3YP<F5P87)E*"=314Q%0U0@0T]53E0H*BD@1E)/32`H)RXD=&AI
M<RT^;&%S=%]Q=65R>2XG*2<I.PH@("`@("`@("`@("`@("`@)&-O=6YT(#T@
M)'1H:7,M/F5X96-U=&4H)'-M="P@)'1H:7,M/E]D871A*3L*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1C;W5N="`])B`D=&AI<RT^
M<75E<GDH)&-O=6YT<75E<GDI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)&-O=6YT*2!\?`H@("`@("`@("`@("`@("`@
M1$(Z.FES17)R;W(H)')O=R`]("1C;W5N="T^9F5T8VA2;W<H1$)?1D540TA-
M3T1%7T]21$52140I*2D*("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/FQA<W1?<75E<GD@/2`D<V%V95]Q=65R>3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YL87-T7W-T;70@/2`D<V%V95]S=&UT.PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TY/5%]#
M05!!0DQ%*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)')O
M=ULP73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27TY/5%]#05!!0DQ%*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE
M(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER
M96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I(&EN<W1E
M860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@
M8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@
M*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y
M(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T
M:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U#;VQS
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT*0H@("`@
M>PH@("`@("`@("1C;VQS(#T@0$]#24YU;4-O;',H)')E<W5L="D["B`@("`@
M("`@:68@*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C
M:3A286ES945R<F]R*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<')E<&%R
M92@I"@H@("`@+RHJ"B`@("`@*B!0<F5P87)E<R!A('%U97)Y(&9O<B!M=6QT
M:7!L92!E>&5C=71I;VX@=VET:"!E>&5C=71E*"DN"B`@("`@*@H@("`@("H@
M5VET:"!O8VDX+"!T:&ES(&ES(&5M=6QA=&5D+@H@("`@("H*("`@("`J('!R
M97!A<F4H*2!R97%U:7)E<R!A(&=E;F5R:6,@<75E<GD@87,@<W1R:6YG(&QI
M:V4@/&-O9&4^"B`@("`@*B`@("!)3E-%4E0@24Y43R!N=6UB97)S(%9!3%5%
M4R`H/RP@/RP@/RD*("`@("`J(#PO8V]D93XN("!4:&4@/&MB9#X_/"]K8F0^
M(&-H87)A8W1E<G,@87)E('!L86-E:&]L9&5R<RX*("`@("`J"B`@("`@*B!4
M:')E92!T>7!E<R!O9B!P;&%C96AO;&1E<G,@8V%N(&)E('5S960Z"B`@("`@
M*B`@("L@/&MB9#X_/"]K8F0^("!A('%U;W1E9"!S8V%L87(@=F%L=64L(&DN
M92X@<W1R:6YG<RP@:6YT96=E<G,*("`@("`J("`@*R`\:V)D/B$\+VMB9#X@
M('9A;'5E(&ES(&EN<V5R=&5D("=A<R!I<R<*("`@("`J("`@*R`\:V)D/B8\
M+VMB9#X@(')E<75I<F5S(&$@9FEL92!N86UE+B`@5&AE(&9I;&4G<R!C;VYT
M96YT<R!G970*("`@("`J("`@("`@("`@("`@("`@("`@("`@:6YS97)T960@
M:6YT;R!T:&4@<75E<GD@*&DN92X@<V%V:6YG(&)I;F%R>0H@("`@("H@("`@
M("`@("`@("`@("`@("`@("!D871A(&EN(&$@9&(I"B`@("`@*@H@("`@("H@
M57-E(&)A8VMS;&%S:&5S('1O(&5S8V%P92!P;&%C96AO;&1E<B!C:&%R86-T
M97)S(&EF('EO=2!D;VXG="!W86YT"B`@("`@*B!T:&5M('1O(&)E(&EN=&5R
M<')E=&5D(&%S('!L86-E:&]L9&5R<RX@($5X86UP;&4Z(#QC;V1E/@H@("`@
M("H@("`@(E501$%412!F;V\@4T54(&-O;#T_(%=(15)%(&-O;#TG;W9E<B!<
M)B!U;F1E<B<B"B`@("`@*B`\+V-O9&4^"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<75E<GD@('1H92!Q=65R>2!T;R!B92!P<F5P87)E9`H@("`@
M("H*("`@("`J($!R971U<FX@;6EX960@($1"('-T871E;65N="!R97-O=7)C
M92!O;B!S=6-C97-S+B!$0E]%<G)O<B!O;B!F86EL=7)E+@H@("`@("H*("`@
M("`J($!S964@1$)?;V-I.#HZ97AE8W5T92@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N('!R97!A<F4H)'%U97)Y*0H@("`@>PH@("`@("`@("1T;VME;G,@("`]
M('!R96=?<W!L:70H)R\H*#\\(5Q<7"E;)C\A72DO)RP@)'%U97)Y+"`M,2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%!214=?4U!,251?1$5,
M24U?0T%05%5212D["B`@("`@("`@)&)I;F1S("`@(#T@8V]U;G0H)'1O:V5N
M<RD@+2`Q.PH@("`@("`@("1T;VME;B`@("`](#`["B`@("`@("`@)'1Y<&5S
M("`@(#T@87)R87DH*3L*("`@("`@("`D;F5W<75E<GD@/2`G)SL*"B`@("`@
M("`@9F]R96%C:"`H)'1O:V5N<R!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@
M("`@("`@<W=I=&-H("@D=F%L*2!["B`@("`@("`@("`@("`@("!C87-E("<_
M)SH*("`@("`@("`@("`@("`@("`@("`D='EP97-;)'1O:V5N*RM=(#T@1$)?
M4$%204U?4T-!3$%2.PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1T;VME
M;G-;)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`G)B<Z"B`@("`@("`@("`@("`@("`@("`@)'1Y<&5S
M6R1T;VME;BLK72`]($1"7U!!4D%-7T]005%513L*("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D=&]K96YS6R1K97E=*3L*("`@("`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@)R$G.@H@("`@("`@("`@
M("`@("`@("`@("1T>7!E<ULD=&]K96XK*UT@/2!$0E]005)!35]-25-#.PH@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1T;VME;G-;)&ME>5TI.PH@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F875L
M=#H*("`@("`@("`@("`@("`@("`@("`D=&]K96YS6R1K97E=(#T@<')E9U]R
M97!L86-E*"<O7%Q<*%LF/R%=*2\G+"`B7%PQ(BP@)'9A;"D["B`@("`@("`@
M("`@("`@("`@("`@:68@*"1K97D@(3T@)&)I;F1S*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1N97=Q=65R>2`N/2`D=&]K96YS6R1K97E=("X@)SIB
M:6YD)R`N("1T;VME;CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W<75E<GD@+CT@)'1O:V5N<ULD
M:V5Y73L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1T:&ES+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@
M("`@("`@("1N97=Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D;F5W<75E
M<GDI.PH@("`@("`@(&EF("@A)'-T;70@/2!`3T-)4&%R<V4H)'1H:7,M/F-O
M;FYE8W1I;VXL("1N97=Q=65R>2DI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YO8VDX4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("`D=&AI
M<RT^<')E<&%R95]T>7!E<ULH:6YT*21S=&UT72`]("1T>7!E<SL*("`@("`@
M("`D=&AI<RT^;6%N:7!?<75E<GE;*&EN="DD<W1M=%T@/2!$0CHZ:7--86YI
M<"@D<75E<GDI.PH@("`@("`@(')E='5R;B`D<W1M=#L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!E>&5C=71E*"D*"B`@("`O*BH*("`@("`J($5X
M96-U=&5S(&$@1$(@<W1A=&5M96YT('!R97!A<F5D('=I=&@@<')E<&%R92@I
M+@H@("`@("H*("`@("`J(%1O(&1E=&5R;6EN92!H;W<@;6%N>2!R;W=S(&]F
M(&$@<F5S=6QT('-E="!G970@8G5F9F5R960@=7-I;F<*("`@("`J(&]C:7-E
M='!R969E=&-H*"DL('-E92!T:&4@(G)E<W5L=%]B=69F97)I;F<B(&]P=&EO
M;B!I;B!S971/<'1I;VYS*"DN"B`@("`@*B!4:&ES(&]P=&EO;B!W87,@861D
M960@:6X@4F5L96%S92`Q+C<N,"X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S
M;W5R8V4@("1S=&UT("!A($1"('-T871E;65N="!R97-O=7)C92!R971U<FYE
M9"!F<F]M('!R97!A<F4H*0H@("`@("H@0'!A<F%M(&UI>&5D("`D9&%T82`@
M87)R87DL('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S
M=&%T96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA
M8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("!Q=65R
M>3H@(&UE86YI;F<@,2!F;W(@;F]N+6%R<F%Y(&ET96US(&]R('1H90H@("`@
M("H@("`@("`@("`@("`@("`@("`@("`@<75A;G1I='D@;V8@96QE;65N=',@
M:6X@=&AE(&%R<F%Y+@H@("`@("H*("`@("`J($!R971U<FX@;6EX960@(')E
M='5R;G,@86X@;VEC."!R97-U;'0@<F5S;W5R8V4@9F]R('-U8V-E<W-F=6P@
M4T5,14-4"B`@("`@*B`@("`@("`@("`@("`@("!Q=65R:65S+"!$0E]/2R!F
M;W(@;W1H97(@<W5C8V5S<V9U;"!Q=65R:65S+@H@("`@("H@("`@("`@("`@
M("`@("`@02!$0B!E<G)O<B!O8FIE8W0@:7,@<F5T=7)N960@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7V]C:3@Z.G!R97!A<F4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B`F97AE8W5T92@D<W1M="P@)&1A=&$@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@("1D871A(#T@*&%R<F%Y*21D871A.PH@("`@
M("`@("1T:&ES+3YL87-T7W!A<F%M971E<G,@/2`D9&%T83L*("`@("`@("`D
M=&AI<RT^7V1A=&$@/2`D9&%T83L*"B`@("`@("`@)'1Y<&5S(#TF("1T:&ES
M+3YP<F5P87)E7W1Y<&5S6RAI;G0I)'-T;71=.PH@("`@("`@(&EF("AC;W5N
M="@D='EP97,I("$](&-O=6YT*"1D871A*2D@>PH@("`@("`@("`@("`D=&UP
M(#TF("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27TU)4TU!5$-(*3L*("`@
M("`@("`@("`@<F5T=7)N("1T;7`["B`@("`@("`@?0H*("`@("`@("`D:2`]
M(#`["B`@("`@("`@9F]R96%C:"`H)&1A=&$@87,@)&ME>2`]/B`D=F%L=64I
M('L*("`@("`@("`@("`@:68@*"1T>7!E<ULD:5T@/3T@1$)?4$%204U?34E3
M0RD@>PH@("`@("`@("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J($]R
M86-L92!D;V5S;B=T('-E96T@=&\@:&%V92!T:&4@86)I;&ET>2!T;R!P87-S
M(&$*("`@("`@("`@("`@("`@("`J('!A<F%M971E<B!A;&]N9R!U;F-H86YG
M960L('-O('-T<FEP(&]F9B!Q=6]T97,@9G)O;2!S=&%R=`H@("`@("`@("`@
M("`@("`@("H@86YD(&5N9"P@<&QU<R!T=7)N('1W;R!S:6YG;&4@<75O=&5S
M('1O(&]N92!S:6YG;&4@<75O=&4L"B`@("`@("`@("`@("`@("`@*B!I;B!O
M<F1E<B!T;R!A=F]I9"!T:&4@<75O=&5S(&=E='1I;F<@97-C87!E9"!B>0H@
M("`@("`@("`@("`@("`@("H@3W)A8VQE(&%N9"!E;F1I;F<@=7`@:6X@=&AE
M(&1A=&%B87-E+@H@("`@("`@("`@("`@("`@("HO"B`@("`@("`@("`@("`@
M("`D9&%T85LD:V5Y72`]('!R96=?<F5P;&%C92@B+UXG*"XJ*2<D+R(L(")<
M7#$B+"`D9&%T85LD:V5Y72D["B`@("`@("`@("`@("`@("`D9&%T85LD:V5Y
M72`]('-T<E]R97!L86-E*"(G)R(L("(G(BP@)&1A=&%;)&ME>5TI.PH@("`@
M("`@("`@("!](&5L<V5I9B`H)'1Y<&5S6R1I72`]/2!$0E]005)!35]/4$%1
M544I('L*("`@("`@("`@("`@("`@("1F<"`]($!F;W!E;B@D9&%T85LD:V5Y
M72P@)W)B)RD["B`@("`@("`@("`@("`@("!I9B`H(21F<"D@>PH@("`@("`@
M("`@("`@("`@("`@("1T;7`@/28@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)2
M3U)?04-#15-37U9)3TQ!5$E/3BD["B`@("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1T;7`["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M9&%T85LD:V5Y72`](&9R96%D*"1F<"P@9FEL97-I>F4H)&1A=&%;)&ME>5TI
M*3L*("`@("`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&EF("@A0$]#24)I;F1">4YA;64H)'-T;70L("<Z8FEN
M9"<@+B`D:2P@)&1A=&%;)&ME>5TL("TQ*2D@>PH@("`@("`@("`@("`@("`@
M)'1M<"`]("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D<W1M="D["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1M<#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("`D:2LK.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F%U=&]C;VUM
M:70I('L*("`@("`@("`@("`@)'-U8V-E<W,@/2!`3T-)17AE8W5T92@D<W1M
M="P@3T-)7T-/34U)5%]/3E]354-#15-3*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<W5C8V5S<R`]($!/0TE%>&5C=71E*"1S=&UT+"!/0TE?
M1$5&055,5"D["B`@("`@("`@?0H@("`@("`@(&EF("@A)'-U8V-E<W,I('L*
M("`@("`@("`@("`@)'1M<"`]("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@D<W1M
M="D["B`@("`@("`@("`@(')E='5R;B`D=&UP.PH@("`@("`@('T*("`@("`@
M("`D=&AI<RT^;&%S=%]S=&UT(#T@)'-T;70["B`@("`@("`@:68@*"1T:&ES
M+3YM86YI<%]Q=65R>5LH:6YT*21S=&UT72D@>PH@("`@("`@("`@("`D=&UP
M(#T@1$)?3TL["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@0&]C:7-E
M='!R969E=&-H*"1S=&UT+"`D=&AI<RT^;W!T:6]N<ULG<F5S=6QT7V)U9F9E
M<FEN9R==*3L*("`@("`@("`@("`@)'1M<"`])B!N97<@1$)?<F5S=6QT*"1T
M:&ES+"`D<W1M="D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&UP.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@
M("\J*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M
M;6ET<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T
M=7)N<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@
M0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B
M:F5C="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N
M)W0@<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@
M("`@>PH@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@*&)O;VPI)&]N;V9F
M.SL*("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@8V]M;6ET*"D*"B`@("`O*BH*("`@("`J($-O;6UI=',@=&AE
M(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A
M:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;6UI="@I"B`@("!["B`@
M("`@("`@)')E<W5L="`]($!/0TE#;VUM:70H)'1H:7,M/F-O;FYE8W1I;VXI
M.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/F]C:3A286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!R;VQL
M8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2979E<G1S('1H92!C=7)R96YT('1R
M86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I"B`@("!["B`@("`@("`@)')E
M<W5L="`]($!/0TE2;VQL8F%C:R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@
M("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;V-I.%)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C=&5D4F]W
M<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB97(@;V8@
M<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N('%U97)Y"B`@
M("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E<FEE<R!T:&%T(&1O
M;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN
M="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@
M9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F96-T9612;W=S*"D*
M("`@('L*("`@("`@("!I9B`H)'1H:7,M/FQA<W1?<W1M="`]/3T@9F%L<V4I
M('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O<B@I
M.PH@("`@("`@('T*("`@("`@("`D<F5S=6QT(#T@0$]#25)O=T-O=6YT*"1T
M:&ES+3YL87-T7W-T;70I.PH@("`@("`@(&EF("@D<F5S=6QT(#T]/2!F86QS
M92D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R
M*"1T:&ES+3YL87-T7W-T;70I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE1
M=65R>2@I"@H@("`@+RHJ"B`@("`@*B!#:&%N9V5S(&$@<75E<GD@<W1R:6YG
M(&9O<B!V87)I;W5S($1"35,@<W!E8VEF:6,@<F5A<V]N<PH@("`@("H*("`@
M("`J(")314Q%0U0@,BLR(B!M=7-T(&)E(")314Q%0U0@,BLR($923TT@9'5A
M;"(@:6X@3W)A8VQE+@H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U
M97)Y("!T:&4@<75E<GD@<W1R:6YG('1O(&UO9&EF>0H@("`@("H*("`@("`J
M($!R971U<FX@<W1R:6YG("!T:&4@;6]D:69I960@<75E<GD@<W1R:6YG"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N
M8W1I;VX@;6]D:69Y475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@(&EF("AP
M<F5G7VUA=&-H*"<O7EQS*E-%3$5#5"]I)RP@)'%U97)Y*2`F)@H@("`@("`@
M("`@("`A<')E9U]M871C:"@G+UQS1E)/35QS+VDG+"`D<75E<GDI*2!["B`@
M("`@("`@("`@("1Q=65R>2`N/2`G($923TT@9'5A;"<["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D<75E<GD["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@+RHJ"B`@("`@*B!!9&1S
M($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I;F<@86-C;W)D:6YG('1O
M(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J"B`@("`@*B!`<&%R86T@
M<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M;V1I9GD*("`@("`J($!P
M87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T;R!S=&%R="!T;R!F971C
M:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@*B!`<&%R86T@:6YT("`@
M("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@=&\@9F5T8V@*("`@("`J
M($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL('-T<FEN9R!O<B!N=6UE
M<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T96UE;G0N("!1=6%N=&ET
M>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@<&%S
M<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA8V5H;VQD97)S(&EN"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q=65R>3H@(&UE86YI;F<@
M,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@<&QA8V5H;VQD97(@<&5R
M(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C;&%U<V5S(&%D9&5D"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J+PH@("`@9G5N
M8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL("1F<F]M+"`D8V]U;G0L
M("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@("\O($QE="!/<F%C
M;&4@<F5T=7)N('1H92!N86UE(&]F('1H92!C;VQU;6YS(&EN<W1E860@;V8*
M("`@("`@("`O+R!C;V1I;F<@82`B:&]M92(@4U%,('!A<G-E<@H*("`@("`@
M("!I9B`H8V]U;G0H)'!A<F%M<RDI('L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YP<F5P87)E*")314Q%0U0@*B!&4D]-("@D<75E<GDI("(*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)U=(15)%($Y5
M3$P@/2!.54Q,)RD["B`@("`@("`@("`@("1T;7`@/28@)'1H:7,M/F5X96-U
M=&4H)')E<W5L="P@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'%?9FEE;&1S(#T@(E-%3$5#5"`J($923TT@*"1Q=65R>2D@5TA%
M4D4@3E5,3"`]($Y53$PB.PH*("`@("`@("`@("`@:68@*"$D<F5S=6QT(#T@
M0$]#25!A<G-E*"1T:&ES+3YC;VYN96-T:6]N+"`D<5]F:65L9',I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^;&%S=%]Q=65R>2`]("1Q7V9I96QD<SL*
M("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^;V-I.%)A:7-E17)R;W(H
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H(4!/0TE%>&5C=71E
M*"1R97-U;'0L($]#25]$149!54Q4*2D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/FQA<W1?<75E<GD@/2`D<5]F:65L9',["B`@("`@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F]C:3A286ES945R<F]R*"1R97-U;'0I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D;F-O;',@/2!/0TE.=6U#;VQS
M*"1R97-U;'0I.PH@("`@("`@("1C;VQS("`](&%R<F%Y*"D["B`@("`@("`@
M9F]R("@@)&D@/2`Q.R`D:2`\/2`D;F-O;',[("1I*RL@*2!["B`@("`@("`@
M("`@("1C;VQS6UT@/2`G(B<@+B!/0TE#;VQU;6Y.86UE*"1R97-U;'0L("1I
M*2`N("<B)SL*("`@("`@("!]"B`@("`@("`@)&9I96QD<R`](&EM<&QO9&4H
M)RP@)RP@)&-O;',I.PH@("`@("`@("\O(%A86"!497-T('1H870@*'1I<"!B
M>2!*;VAN($QI;2D*("`@("`@("`O+VEF("AP<F5G7VUA=&-H*"<O7EQS*E-%
M3$5#5%QS*R]I<R<L("1Q=65R>2P@)&UA=&-H*2D@>PH@("`@("`@("\O("`@
M("\O($EN=')O9'5C92!T:&4@1DE24U1?4D]74R!/<F%C;&4@<75E<GD@;W!T
M:6UI>F5R"B`@("`@("`@+R\@("`@)'%U97)Y(#T@<W5B<W1R*"1Q=65R>2P@
M<W1R;&5N*"1M871C:%LP72DL('-T<FQE;B@D<75E<GDI*3L*("`@("`@("`O
M+R`@("`D<75E<GD@/2`B4T5,14-4("\J("M&25)35%]23U=3("HO("(@+B`D
M<75E<GD["B`@("`@("`@+R]]"@H@("`@("`@("\O($-O;G-T<G5C="!T:&4@
M<75E<GD*("`@("`@("`O+R!M;W)E(&%T.B!H='1P.B\O;6%R8RYT:&5A:6US
M9W)O=7`N8V]M+S]L/7!H<"UD8B9M/3DY.#,Q.34X,3`Q,C$R)G<],@H@("`@
M("`@("\O(%!E<FAA<',@=&AI<R!C;W5L9"!B92!O<'1I;6EZ960@=VET:"!T
M:&4@=7-E(&]F(%5N:6]N<PH@("`@("`@("1Q=65R>2`](")314Q%0U0@)&9I
M96QD<R!&4D]-(BX*("`@("`@("`@("`@("`@("`B("`H4T5,14-4(')O=VYU
M;2!A<R!L:6YE;G5M+"`D9FEE;&1S($923TTB+@H@("`@("`@("`@("`@("`@
M("(@("`@("`H)'%U97)Y*2(N"B`@("`@("`@("`@("`@("`@)R`@5TA%4D4@
M<F]W;G5M(#P]("<N("@D9G)O;2`K("1C;W5N="D@+@H@("`@("`@("`@("`@
M("`@("<I(%=(15)%(&QI;F5N=6T@/CT@)R`N("LK)&9R;VT["B`@("`@("`@
M<F5T=7)N("1Q=65R>3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N
M97AT260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E
M(&ED(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R
M86T@8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@
M:7,@875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E
M<75E;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN
M97AT240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J
M("`@("`@1$)?;V-I.#HZ8W)E871E4V5Q=65N8V4H*2P@1$)?;V-I.#HZ9')O
M<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=$ED*"1S97%?
M;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@('L*("`@("`@("`D<V5Q;F%M
M92`]("1T:&ES+3YG971397%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@
M("`D<F5P96%T(#T@,#L*("`@("`@("!D;R!["B`@("`@("`@("`@("1T:&ES
M+3YE>'!E8W1%<G)O<BA$0E]%4E)/4E].3U-50TA404),12D["B`@("`@("`@
M("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@)'MS97%N86UE
M?2YN97AT=F%L($923TT@9'5A;"(I.PH@("`@("`@("`@("`D=&AI<RT^<&]P
M17AP96-T*"D["B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES
M17)R;W(H)')E<W5L="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E
M=$-O9&4H*2`]/2!$0E]%4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@
M("`@("`@)')E<&5A="`](#$["B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@
M)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D["B`@("`@("`@("`@
M("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E<W5L="D["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("`@("`D<F5P96%T(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1A<G(@/2`D<F5S=6QT+3YF
M971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@<F5T=7)N
M("1A<G);,%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&$@;F5W
M('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<V5Q7VYA
M;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@("`J($!R
M971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ
M8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H
M*2P*("`@("`J("`@("`@1$)?;V-I.#HZ;F5X=$E$*"DL($1"7V]C:3@Z.F1R
M;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E
M;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U
M97)Y*"=#4D5!5$4@4T51545.0T4@)PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1R;W!397%U96YC92@I"@H@
M("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q=65N8V4*("`@("`J"B`@("`@
M*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N
M8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$
M0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R
M92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9')O<%-E<75E;F-E
M*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@("`@
M($1"7V]C:3@Z.FYE>'1)1"@I+"!$0E]O8VDX.CIC<F5A=&5397%U96YC92@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA;64I
M"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!315%5
M14Y#12`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YG
M971397%U96YC94YA;64H)'-E<5]N86UE*2D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@;V-I.%)A:7-E17)R;W(H*0H*("`@("\J*@H@("`@("H@
M4')O9'5C97,@82!$0E]%<G)O<B!O8FIE8W0@<F5G87)D:6YG('1H92!C=7)R
M96YT('!R;V)L96T*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1E<G)N;R`@
M:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA;G5A;&QY(')A:7-E9"!P87-S(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@1$)?15)23U(J(&-O;G-T86YT
M(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A<W-E9`H@("`@("H@("`@("`@("`@
M("`@("`@("`@("!T:&4@97)R;W(@:6YF;W)M871I;VX@9V%T:&5R960@9G)O
M;2!T:&4@1$)-4RX*("`@("`J"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@=&AE
M($1"7T5R<F]R(&]B:F5C=`H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N
M.CIR86ES945R<F]R*"DL"B`@("`@*B`@("`@($1"7V]C:3@Z.F5R<F]R3F%T
M:79E*"DL($1"7V]C:3@Z.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&]C:3A286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@
M("`@:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D97)R;W(@
M/2!`3T-)17)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)'1H:7,M/F5R<F]R0V]D92@D97)R
M;W);)V-O9&4G72DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!N=6QL+"!N=6QL+"!N=6QL+"`D97)R;W);)VUE<W-A9V4G72D["B`@
M("`@("`@?2!E;'-E:68@*&ES7W)E<V]U<F-E*"1E<G)N;RDI('L*("`@("`@
M("`@("`@)&5R<F]R(#T@0$]#245R<F]R*"1E<G)N;RD["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^97)R;W)#;V1E*"1E
M<G)O<ELG8V]D92==*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL("1E<G)O<ELG;65S<V%G92==*3L*
M("`@("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1T
M:&ES+3YE<G)O<D-O9&4H)&5R<FYO*2D["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@97)R;W).871I=F4H*0H*("`@("\J*@H@("`@("H@1V5T<R!T
M:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@<')O9'5C960@8GD@=&AE(&QA
M<W0@<75E<GD*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE($1"35,G
M(&5R<F]R(&-O9&4N("!&04Q312!I9B!T:&4@8V]D92!C;W5L9"!N;W0@8F4*
M("`@("`J("`@("`@("`@("`@("`@9&5T97)M:6YE9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@:68@*&ES7W)E
M<V]U<F-E*"1T:&ES+3YL87-T7W-T;70I*2!["B`@("`@("`@("`@("1E<G)O
M<B`]($!/0TE%<G)O<B@D=&AI<RT^;&%S=%]S=&UT*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D97)R;W(@/2!`3T-)17)R;W(H)'1H:7,M/F-O
M;FYE8W1I;VXI.PH@("`@("`@('T*("`@("`@("!I9B`H:7-?87)R87DH)&5R
M<F]R*2D@>PH@("`@("`@("`@("!R971U<FX@)&5R<F]R6R=C;V1E)UT["B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!F86QS93L*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT('-E
M=`H@("`@("H*("`@("`J($Y/5$4Z(&]N;'D@<W5P<&]R=',@)W1A8FQE)R!A
M;F0@)V9L86=S)R!I9B`\=F%R/B1R97-U;'0\+W9A<CX*("`@("`J(&ES(&$@
M=&%B;&4@;F%M92X*("`@("`J"B`@("`@*B!.3U1%.B!F;&%G<R!W;VXG="!C
M;VYT86EN(&EN9&5X(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J($!P87)A
M;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T(&9R
M;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@=&%B
M;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%=H
M:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED96YT
M:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A;2!I
M;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M;V1E
M"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I=F4@
M87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@("H@
M("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`]
M(&YU;&PI"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T
M86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#05-%*2!["B`@("`@
M("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L;W=E<B<["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')V86PG.PH@("`@
M("`@('T*"B`@("`@("`@)')E<R`](&%R<F%Y*"D["@H@("`@("`@(&EF("AI
M<U]S=')I;F<H)')E<W5L="DI('L*("`@("`@("`@("`@+RH*("`@("`@("`@
M("`@("H@4')O8F%B;'D@<F5C96EV960@82!T86)L92!N86UE+@H@("`@("`@
M("`@("`@*B!#<F5A=&4@82!R97-U;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*
M("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1R97-U;'0@/2!S=')T;W5P
M<&5R*"1R97-U;'0I.PH@("`@("`@("`@("`D<5]F:65L9',@/2`G4T5,14-4
M(&-O;'5M;E]N86UE+"!D871A7W1Y<&4L(&1A=&%?;&5N9W1H+"`G"B`@("`@
M("`@("`@("`@("`@("`@("`@("X@)VYU;&QA8FQE("<*("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G1E)/32!U<V5R7W1A8E]C;VQU;6YS("<*("`@("`@
M("`@("`@("`@("`@("`@("`@+B`B5TA%4D4@=&%B;&5?;F%M93TG)')E<W5L
M="<@3U)$15(@0ED@8V]L=6UN7VED(CL*"B`@("`@("`@("`@("1T:&ES+3YL
M87-T7W%U97)Y(#T@)'%?9FEE;&1S.PH*("`@("`@("`@("`@:68@*"$D<W1M
M="`]($!/0TE087)S92@D=&AI<RT^8V]N;F5C=&EO;BP@)'%?9FEE;&1S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO8VDX4F%I<V5%<G)O
M<BA$0E]%4E)/4E].145$7TU/4D5?1$%402D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@:68@*"%`3T-)17AE8W5T92@D<W1M="P@3T-)7T1%1D%53%0I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]C:3A286ES945R
M<F]R*"1S=&UT*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)&D@/2`P
M.PH@("`@("`@("`@("!W:&EL92`H0$]#249E=&-H*"1S=&UT*2D@>PH@("`@
M("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`G=&%B;&4G(#T^("1C87-E7V9U;F,H)')E<W5L="DL"B`@("`@("`@
M("`@("`@("`@("`@)VYA;64G("`]/B`D8V%S95]F=6YC*$!/0TE297-U;'0H
M)'-T;70L(#$I*2P*("`@("`@("`@("`@("`@("`@("`G='EP92<@(#T^($!/
M0TE297-U;'0H)'-T;70L(#(I+`H@("`@("`@("`@("`@("`@("`@("=L96XG
M("`@/3X@0$]#25)E<W5L="@D<W1M="P@,RDL"B`@("`@("`@("`@("`@("`@
M("`@)V9L86=S)R`]/B`H0$]#25)E<W5L="@D<W1M="P@-"D@/3T@)TXG*2`_
M("=N;W1?;G5L;"<@.B`G)RP*("`@("`@("`@("`@("`@("D["B`@("`@("`@
M("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@
M("`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<B==6R1R97-;)&E=6R=N86UE
M)UU=(#T@)&D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!I
M9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@
M("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD<F5S6R1I75LG=&%B
M;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`@("`@)')E<ULG;G5M
M7V9I96QD<R==(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("`@("`@0$]#
M249R9653=&%T96UE;G0H)'-T;70I.PH*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!I9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@+RH*("`@("`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I
M=F5D(&$@<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("`@("`J($5X=')A
M8W0@=&AE(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@("`@("HO"B`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)')E<W5L="T^
M<F5S=6QT.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`D<F5S(#T@87)R
M87DH*3L*"B`@("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2`D=&AI<RT^;&%S
M=%]S=&UT*2!["B`@("`@("`@("`@("`@("`D8V]U;G0@/2!`3T-)3G5M0V]L
M<R@D<F5S=6QT*3L*("`@("`@("`@("`@("`@(&EF("@D;6]D92D@>PH@("`@
M("`@("`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`@("`@("`@("1R
M97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=T86)L
M92<@/3X@)R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@/3X@
M)&-A<V5?9G5N8RA`3T-)0V]L=6UN3F%M92@D<F5S=6QT+"`D:2LQ*2DL"B`@
M("`@("`@("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@0$]#24-O;'5M;E1Y
M<&4H)')E<W5L="P@)&DK,2DL"B`@("`@("`@("`@("`@("`@("`@("`@("=L
M96XG("`@/3X@0$]#24-O;'5M;E-I>F4H)')E<W5L="P@)&DK,2DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L"B`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@("!I9B`H)&UO9&4@)B!$
M0E]404),14E.1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&UO9&4@
M)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=
M6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]2
M7TY/5%]#05!!0DQ%*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G
M9713<&5C:6%L475E<GDH*0H*("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@
M<75E<GD@<W1R:6YG(&YE961E9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@
M;V8@;V)J96-T<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@
M('1H92!K:6YD(&]F(&]B:F5C=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I
M;F<@;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@
M("`@("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D
M"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@("`J($!S964@
M1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G
M9713<&5C:6%L475E<GDH)'1Y<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D
M='EP92D@>PH@("`@("`@("`@("!C87-E("=T86)L97,G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N("=314Q%0U0@=&%B;&5?;F%M92!&4D]-('5S97)?=&%B
M;&5S)SL*("`@("`@("`@("`@8V%S92`G<WEN;VYY;7,G.@H@("`@("`@("`@
M("`@("`@<F5T=7)N("=314Q%0U0@<WEN;VYY;5]N86UE($923TT@=7-E<E]S
M>6YO;GEM<R<["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"@I]
M"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C
M+6)A<VEC+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]O9&)C+G!H<```````````````````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8T-#4V(#$P-3$U-#,T
M,3,S(#`R,#0P-0`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]
M-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-#H@*B\*"B\J*@H@*B!4:&4@
M4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S(&]D8F,@97AT96YS:6]N"B`J(&9O
M<B!I;G1E<F%C=&EN9R!W:71H(&1A=&%B87-E<R!V:6$@3T1"0R!C;VYN96-T
M:6]N<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%
M.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@
M;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U
M9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@
M*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E
M(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L
M('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@
M=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A
M=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO
M<B`@("`@4W1I9R!"86MK96X@/'-S8D!P:'`N;F5T/@H@*B!`875T:&]R("`@
M("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y
M<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@
M(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E
M;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@;V1B8RYP:'`L=B`Q
M+C<X(#(P,#4O,#(O,C@@,#$Z-#(Z,3<@9&%N:65L8R!%>'`@)`H@*B!`;&EN
M:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*("HO"@HO
M*BH*("H@3V)T86EN('1H92!$0E]C;VUM;VX@8VQA<W,@<V\@:70@8V%N(&)E
M(&5X=&5N9&5D(&9R;VT*("HO"G)E<75I<F5?;VYC92`G1$(O8V]M;6]N+G!H
M<"<["@HO*BH*("H@5&AE(&UE=&AO9',@4$5!4B!$0B!U<V5S('1O(&EN=&5R
M86-T('=I=&@@4$A0)W,@;V1B8R!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T
M:6YG('=I=&@@9&%T86)A<V5S('9I82!/1$)#(&-O;FYE8W1I;VYS"B`J"B`J
M(%1H97-E(&UE=&AO9',@;W9E<FQO860@=&AE(&]N97,@9&5C;&%R960@:6X@
M1$)?8V]M;6]N+@H@*@H@*B!-;W)E(&EN9F\@;VX@3T1"0R!E<G)O<G,@8V]U
M;&0@8F4@9F]U;F0@:&5R93H*("H@:'1T<#HO+VUS9&XN;6EC<F]S;V9T+F-O
M;2]L:6)R87)Y+V1E9F%U;'0N87-P/W5R;#TO;&EB<F%R>2]E;BUU<R]T<F)L
M<W%L+W1R7V5R<E]O9&)C7S5S='HN87-P"B`J"B`J($!C871E9V]R>2`@($1A
M=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T:6<@
M0F%K:V5N(#QS<V)`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW
M+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W
M+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]O9&)C
M(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O('M[>R!P<F]P97)T:65S"@H@
M("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R('1Y<&4@*&UY<W%L+"!O8VDX
M+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1P:'!T>7!E(#T@)V]D8F,G.PH*("`@("\J*@H@("`@("H@5&AE(&1A
M=&%B87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S
M+"!E=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&1B<WEN=&%X(#T@)W-Q;#DR)SL*"B`@("`O*BH*("`@("`J(%1H
M92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@
M("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE
M(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L
M:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF
M(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T
M:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M
M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L
M=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@
M(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@3D]413H@5&AE(&9E871U<F4@
M<V5T(&]F('1H92!F;VQL;W=I;F<@9')I=F5R<R!A<F4@9&EF9F5R96YT('1H
M86X*("`@("`J('1H92!D969A=6QT.@H@("`@("H@("`K('-O;&ED.B`G=')A
M;G-A8W1I;VYS)R`]('1R=64*("`@("`J("`@*R!N879I<VEO;CH@)VQI;6ET
M)R`](&9A;'-E"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@
M("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@
M("`@(#T^("=E;75L871E)RP*("`@("`@("`G;F5W7VQI;FLG("`@("`@/3X@
M9F%L<V4L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@
M("`@)W!C;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G
M("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!F
M86QS92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@9F%L<V4L"B`@("`I
M.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E<G)O<B!C
M;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A<G)A>0H@("`@
M("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*("`@("`@("`G
M,#$P,#0G(#T^($1"7T524D]27U1254Y#051%1"P*("`@("`@("`G,#<P,#$G
M(#T^($1"7T524D]27TU)4TU!5$-(+`H@("`@("`@("<R,5,P,2<@/3X@1$)?
M15)23U)?5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("<R,5,P,B<@/3X@
M1$)?15)23U)?34E334%40T@L"B`@("`@("`@)S(R,#`Q)R`]/B!$0E]%4E)/
M4E])3E9!3$E$+`H@("`@("`@("<R,C`P,R<@/3X@1$)?15)23U)?24Y604Q)
M1%].54U"15(L"B`@("`@("`@)S(R,#`U)R`]/B!$0E]%4E)/4E])3E9!3$E$
M7TY534)%4BP*("`@("`@("`G,C(P,#@G(#T^($1"7T524D]27TE.5D%,241?
M1$%412P*("`@("`@("`G,C(P,3(G(#T^($1"7T524D]27T1)5EI%4D\L"B`@
M("`@("`@)S(S,#`P)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M("<R,S4P,B<@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@
M("`@("`G,C,U,#,G(#T^($1"7T524D]27T-/3E-44D%)3E0L"B`@("`@("`@
M)S(S-3`T)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("<R,S4P
M-2<@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`G,C0P,#`G(#T^
M($1"7T524D]27TE.5D%,240L"B`@("`@("`@)S,T,#`P)R`]/B!$0E]%4E)/
M4E])3E9!3$E$+`H@("`@("`@("<S-S`P,"<@/3X@1$)?15)23U)?4UE.5$%8
M+`H@("`@("`@("<T,C`P,"<@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@
M("<T,C8P,2<@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@("=)33`P,2<@
M/3X@1$)?15)23U)?54Y355!03U)4140L"B`@("`@("`@)U,P,#`P)R`]/B!$
M0E]%4E)/4E].3U-50TA404),12P*("`@("`@("`G4S`P,#$G(#T^($1"7T52
M4D]27T%,4D5!1%E?15A)4U13+`H@("`@("`@("=3,#`P,B<@/3X@1$)?15)2
M3U)?3D]354-(5$%"3$4L"B`@("`@("`@)U,P,#$Q)R`]/B!$0E]%4E)/4E]!
M3%)%04197T5825-44RP*("`@("`@("`G4S`P,3(G(#T^($1"7T524D]27TY/
M5%]&3U5.1"P*("`@("`@("`G4S`P,C$G(#T^($1"7T524D]27T%,4D5!1%E?
M15A)4U13+`H@("`@("`@("=3,#`R,B<@/3X@1$)?15)23U)?3D]354-(1DE%
M3$0L"B`@("`@("`@)U,Q,#`Y)R`]/B!$0E]%4E)/4E])3E9!3$E$+`H@("`@
M("`@("=3,3`Y,"<@/3X@1$)?15)23U)?24Y604Q)1"P*("`@("`@("`G4S%#
M,#`G(#T^($1"7T524D]27TY/5%]#05!!0DQ%+`H@("`@*3L*"B`@("`O*BH*
M("`@("`J(%1H92!R87<@9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y
M(%!(4`H@("`@("H@0'9A<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O
M;FYE8W1I;VX["@H@("`@+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N
M(&9O<B!C;VYN96-T:6YG('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R
M87D*("`@("`J+PH@("`@=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*
M("`@("`J(%1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@
M;6%N:7!U;&%T:6]N('%U97)Y"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J
M($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)&%F9F5C=&5D(#T@
M,#L*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O
M*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^
M1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*
M("`@("`J+PH@("`@9G5N8W1I;VX@1$)?;V1B8R@I"B`@("!["B`@("`@("`@
M)'1H:7,M/D1"7V-O;6UO;B@I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&-O;FYE8W0H*0H*("`@("\J*@H@("`@("H@0V]N;F5C="!T;R!T:&4@
M9&%T86)A<V4@<V5R=F5R+"!L;V<@:6X@86YD(&]P96X@=&AE(&1A=&%B87-E
M"B`@("`@*@H@("`@("H@1&]N)W0@8V%L;"!T:&ES(&UE=&AO9"!D:7)E8W1L
M>2X@(%5S92!$0CHZ8V]N;F5C="@I(&EN<W1E860N"B`@("`@*@H@("`@("H@
M4$5!4B!$0B=S(&]D8F,@9')I=F5R('-U<'!O<G1S('1H92!F;VQL;W=I;F<@
M97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@("L@8W5R<V]R("!4:&4@='EP
M92!O9B!C=7)S;W(@=&\@8F4@=7-E9"!F;W(@=&AI<R!C;VYN96-T:6]N+@H@
M("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A
M=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N
M="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@
M*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@
M("`@("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)V]D8F,G*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?15)23U)?15A4
M14Y324].7TY/5%]&3U5.1"D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^
M9'-N(#T@)&1S;CL*("`@("`@("!I9B`H)&1S;ELG9&)S>6YT87@G72D@>PH@
M("`@("`@("`@("`D=&AI<RT^9&)S>6YT87@@/2`D9'-N6R=D8G-Y;G1A>"==
M.PH@("`@("`@('T*("`@("`@("!S=VET8V@@*"1T:&ES+3YD8G-Y;G1A>"D@
M>PH@("`@("`@("`@("!C87-E("=A8V-E<W,G.@H@("`@("`@("`@("!C87-E
M("=D8C(G.@H@("`@("`@("`@("!C87-E("=S;VQI9"<Z"B`@("`@("`@("`@
M("`@("`D=&AI<RT^9F5A='5R97-;)W1R86YS86-T:6]N<R==(#T@=')U93L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("=N879I
M<VEO;B<Z"B`@("`@("`@("`@("`@("`D=&AI<RT^9F5A='5R97-;)VQI;6ET
M)UT@/2!F86QS93L*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@
M5&AI<R!I<R!H96%R(&9O<B!B86-K=V%R9',@8V]M<&%T:6)I;&ET>2X@4VAO
M=6QD(&AA=F4@8F5E;B!U<VEN9PH@("`@("`@("`J("=D871A8F%S92<@86QL
M(&%L;VYG+"!B=70@<')I;W(@=&\@,2XV+C!20S,@)VAO<W1S<&5C)R!W87,@
M=7-E9"X*("`@("`@("`@*B\*("`@("`@("!I9B`H)&1S;ELG9&%T86)A<V4G
M72D@>PH@("`@("`@("`@("`D;V1B8V1S;B`]("1D<VY;)V1A=&%B87-E)UT[
M"B`@("`@("`@?2!E;'-E:68@*"1D<VY;)VAO<W1S<&5C)UTI('L*("`@("`@
M("`@("`@)&]D8F-D<VX@/2`D9'-N6R=H;W-T<W!E8R==.PH@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1O9&)C9'-N(#T@)VQO8V%L:&]S="<["B`@
M("`@("`@?0H*("`@("`@("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T
M96YT(#\@)V]D8F-?<&-O;FYE8W0G(#H@)V]D8F-?8V]N;F5C="<["@H@("`@
M("`@(&EF("AE;7!T>2@D9'-N6R=C=7)S;W(G72DI('L*("`@("`@("`@("`@
M)'1H:7,M/F-O;FYE8W1I;VX@/2!`)&-O;FYE8W1?9G5N8W1I;VXH)&]D8F-D
M<VXL("1D<VY;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UTI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T
M:6]N(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1O9&)C9'-N+"`D9'-N6R=U<V5R
M;F%M92==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D9'-N6R=P87-S=V]R9"==+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9'-N6R=C
M=7)S;W(G72D["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E
M*"1T:&ES+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H
M:7,M/G)A:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F5R<F]R3F%T:79E*"DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9&ES8V]N;F5C
M="@I"@H@("`@+RHJ"B`@("`@*B!$:7-C;VYN96-T<R!F<F]M('1H92!D871A
M8F%S92!S97)V97(*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VP@(%12544@
M;VX@<W5C8V5S<RP@1D%,4T4@;VX@9F%I;'5R90H@("`@("HO"B`@("!F=6YC
M=&EO;B!D:7-C;VYN96-T*"D*("`@('L*("`@("`@("`D97)R(#T@0&]D8F-?
M8VQO<V4H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N(#T@;G5L;#L*("`@("`@("!R971U<FX@)&5R<CL*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!S:6UP;&51=65R>2@I"@H@("`@+RHJ"B`@
M("`@*B!396YD<R!A('%U97)Y('1O('1H92!D871A8F%S92!S97)V97(*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("!T:&4@4U%,('%U97)Y('-T<FEN
M9PH@("`@("H*("`@("`J($!R971U<FX@;6EX960@("L@82!02%`@<F5S=6QT
M(')E<W)O=6-E(&9O<B!S=6-C97-S9G5L(%-%3$5#5"!Q=65R:65S"B`@("`@
M*B`@("`@("`@("`@("`@("`K('1H92!$0E]/2R!C;VYS=&%N="!F;W(@;W1H
M97(@<W5C8V5S<V9U;"!Q=65R:65S"B`@("`@*B`@("`@("`@("`@("`@("`K
M(&$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4*("`@("`J+PH@("`@9G5N
M8W1I;VX@<VEM<&QE475E<GDH)'%U97)Y*0H@("`@>PH@("`@("`@("1T:&ES
M+3YL87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES
M+3YM;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@("1R97-U;'0@/2!`;V1B
M8U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`D<75E<GDI.PH@("`@("`@(&EF
M("@A)')E<W5L="D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D8F-2
M86ES945R<F]R*"D[("\O(%A86"!%4E)/4DU31PH@("`@("`@('T*("`@("`@
M("`O+R!$971E<FUI;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U
M<FX@9&%T82P@86YD('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A
M;B!E<G)O<B!C;V1E(&]N;'DN"B`@("`@("`@:68@*$1".CII<TUA;FEP*"1Q
M=65R>2DI('L*("`@("`@("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@)')E<W5L
M=#L@+R\@1F]R(&%F9F5C=&5D4F]W<R@I"B`@("`@("`@("`@(')E='5R;B!$
M0E]/2SL*("`@("`@("!]"B`@("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@,#L*
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE
M(&EN=&5R;F%L(&]D8F,@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A
M:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!A('9A;&ED(&9B
M<W%L(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!A8V-E<W,@<'5B
M;&EC"B`@("`@*@H@("`@("H@0')E='5R;B!T<G5E(&EF(&$@<F5S=6QT(&ES
M(&%V86EL86)L92!O=&AE<G=I<V4@<F5T=7)N(&9A;'-E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&YE>'1297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R
M971U<FX@0&]D8F-?;F5X=%]R97-U;'0H)')E<W5L="D["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9F5T8VA);G1O*"D*"B`@("`O*BH*("`@("`J
M(%!L86-E<R!A(')O=R!F<F]M('1H92!R97-U;'0@<V5T(&EN=&\@=&AE(&=I
M=F5N(&%R<F%Y"B`@("`@*@H@("`@("H@1F]R;6%T:6YG(&]F('1H92!A<G)A
M>2!A;F0@=&AE(&1A=&$@=&AE<F5I;B!A<F4@8V]N9FEG=7)A8FQE+@H@("`@
M("H@4V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@9F]R(&UO<F4@:6YF;W)M
M871I;VXN"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT
M('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT
M.CIF971C:$EN=&\H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@
M(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P
M87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("`@('1H92!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J($!P
M87)A;2!A<G)A>2`@("`D87)R("`@("`@('1H92!R969E<F5N8V5D(&%R<F%Y
M('1O('!U="!T:&4@9&%T82!I;@H@("`@("H@0'!A<F%M(&EN="`@("`@("1F
M971C:&UO9&4@:&]W('1H92!R97-U;'1I;F<@87)R87D@<VAO=6QD(&)E(&EN
M9&5X960*("`@("`J($!P87)A;2!I;G0@("`@("`D<F]W;G5M("`@('1H92!R
M;W<@;G5M8F5R('1O(&9E=&-H("@P(#T@9FER<W0@<F]W*0H@("`@("H*("`@
M("`J($!R971U<FX@;6EX960@($1"7T]+(&]N('-U8V-E<W,L($Y53$P@=VAE
M;B!T:&4@96YD(&]F(&$@<F5S=6QT('-E="!I<PH@("`@("H@("`@("`@("`@
M("`@("`@(')E86-H960@;W(@;VX@9F%I;'5R90H@("`@("H*("`@("`J($!S
M964@1$)?<F5S=6QT.CIF971C:$EN=&\H*0H@("`@("HO"B`@("!F=6YC=&EO
M;B!F971C:$EN=&\H)')E<W5L="P@)B1A<G(L("1F971C:&UO9&4L("1R;W=N
M=6T@/2!N=6QL*0H@("`@>PH@("`@("`@("1A<G(@/2!A<G)A>2@I.PH@("`@
M("`@(&EF("@D<F]W;G5M("$]/2!N=6QL*2!["B`@("`@("`@("`@("1R;W=N
M=6TK*SL@+R\@3T1"0R!F:7)S="!R;W<@:7,@,0H@("`@("`@("`@("!I9B`H
M=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,BXP)RP@)V=E)RDI
M('L*("`@("`@("`@("`@("`@("1C;VQS(#T@0&]D8F-?9F5T8VA?:6YT;R@D
M<F5S=6QT+"`D87)R+"`D<F]W;G5M*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("1C;VQS(#T@0&]D8F-?9F5T8VA?:6YT;R@D<F5S
M=6QT+"`D<F]W;G5M+"`D87)R*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1C;VQS(#T@0&]D8F-?9F5T8VA?:6YT;R@D
M<F5S=6QT+"`D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D8V]L<RD@
M>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"B`@("`@("`@
M:68@*"1F971C:&UO9&4@(3T]($1"7T9%5$-(34]$15]/4D1%4D5$*2!["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\(&-O=6YT*"1A<G(I.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D8V]L3F%M92`]($!O9&)C7V9I96QD7VYA
M;64H)')E<W5L="P@)&DK,2D["B`@("`@("`@("`@("`@("`D85LD8V]L3F%M
M95T@/2`D87)R6R1I73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E4
M65],3U=%4D-!4T4I('L*("`@("`@("`@("`@("`@("1A(#T@87)R87E?8VAA
M;F=E7VME>5]C87-E*"1A+"!#05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D87)R(#T@)&$["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,2519
M7U)44DE-*2!["B`@("`@("`@("`@("1T:&ES+3Y?<G1R:6U!<G)A>59A;'5E
M<R@D87)R*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3E5,3%]43U]%35!4
M62D@>PH@("`@("`@("`@("`D=&AI<RT^7V-O;G9E<G1.=6QL07)R87E686QU
M97-4;T5M<'1Y*"1A<G(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G)E95)E<W5L="@I
M"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S('1H92!R97-U;'0@<V5T(&%N9"!F
M<F5E<R!T:&4@;65M;W)Y(&]C8W5P:65D(&)Y('1H92!R97-U;'0@<V5T"B`@
M("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A
M;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIF<F5E*"D@
M:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@
M("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@
M<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!B
M;V]L("!44E5%(&]N('-U8V-E<W,L($9!3%-%(&EF("1R97-U;'0@:7,@:6YV
M86QI9`H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIF<F5E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9G)E95)E<W5L="@D<F5S=6QT*0H@("`@>PH@
M("`@("`@(')E='5R;B!`;V1B8U]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*
M("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT
M('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T
M;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ
M;G5M0V]L<R@I(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O
M=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T
M92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U
M;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R
M<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?
M<F5S=6QT.CIN=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L
M<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1C;VQS(#T@0&]D8F-?;G5M7V9I
M96QD<R@D<F5S=6QT*3L*("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1C;VQS.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&%F9F5C=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI
M;F5S('1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N
M:75P;&%T:6]N('%U97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F
M;W(@<75E<FEE<R!T:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I
M;VX@869F96-T9612;W=S*"D*("`@('L*("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/F%F9F5C=&5D*2D@>R`@+R\@26X@8V%S92!O9B!314Q%0U0@<W1M<PH@
M("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"B`@("`@("`@)&YR;W=S
M(#T@0&]D8F-?;G5M7W)O=W,H)'1H:7,M/F%F9F5C=&5D*3L*("`@("`@("!I
M9B`H)&YR;W=S(#T]("TQ*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1N
M<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N=6U2;W=S*"D*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@
M<F5S=6QT('-E=`H@("`@("H*("`@("`J($YO="!A;&P@3T1"0R!D<FEV97)S
M('-U<'!O<G0@=&AI<R!F=6YC=&EO;F%L:71Y+B`@268@=&AE>2!D;VXG=`H@
M("`@("H@82!$0E]%<G)O<B!O8FIE8W0@9F]R($1"7T524D]27U5.4U504$]2
M5$5$(&ES(')E='5R;F5D+@H@("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES
M(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*("`@("`J
M($1"7W)E<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG="!B92!D
M96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@
M:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O=7)C90H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F(')O=W,N
M("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J
M($!S964@1$)?<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@9G5N8W1I
M;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1N<F]W<R`]($!O
M9&)C7VYU;5]R;W=S*"1R97-U;'0I.PH@("`@("`@(&EF("@D;G)O=W,@/3T@
M+3$I('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O
M<BA$0E]%4E)/4E]53E-54%!/4E1%1"D["B`@("`@("`@?0H@("`@("`@(&EF
M("@D;G)O=W,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N
M("1N<F]W<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T94ED
M96YT:69I97(H*0H*("`@("\J*@H@("`@("H@475O=&5S(&$@<W1R:6YG('-O
M(&ET(&-A;B!B92!S869E;'D@=7-E9"!A<R!A('1A8FQE(&]R(&-O;'5M;B!N
M86UE"B`@("`@*@H@("`@("H@57-E("=M<W-Q;"<@87,@=&AE(&1B<WEN=&%X
M(&EN('1H92!$0B!$4TX@;VYL>2!I9B!Y;W4G=F4@=6YC:&5C:V5D"B`@("`@
M*B`B57-E($%.4TD@<75O=&5D(&ED96YT:69I97)S(B!W:&5N('-E='1I;F<@
M=7`@=&AE($]$0D,@9&%T82!S;W5R8V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<W1R("!I9&5N=&EF:65R(&YA;64@=&\@8F4@<75O=&5D"B`@
M("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('%U;W1E9"!I9&5N=&EF:65R
M('-T<FEN9PH@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIQ=6]T94ED
M96YT:69I97(H*0H@("`@("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN
M8V4@4F5L96%S92`Q+C8N,`H@("`@("HO"B`@("!F=6YC=&EO;B!Q=6]T94ED
M96YT:69I97(H)'-T<BD*("`@('L*("`@("`@("!S=VET8V@@*"1T:&ES+3YD
M<VY;)V1B<WEN=&%X)UTI('L*("`@("`@("`@("`@8V%S92`G86-C97-S)SH*
M("`@("`@("`@("`@("`@(')E='5R;B`G6R<@+B`D<W1R("X@)UTG.PH@("`@
M("`@("`@("!C87-E("=M<W-Q;"<Z"B`@("`@("`@("`@(&-A<V4@)W-Y8F%S
M92<Z"B`@("`@("`@("`@("`@("!R971U<FX@)ULG("X@<W1R7W)E<&QA8V4H
M)UTG+"`G75TG+"`D<W1R*2`N("==)SL*("`@("`@("`@("`@8V%S92`G;7ES
M<6PG.@H@("`@("`@("`@("!C87-E("=M>7-Q;&DG.@H@("`@("`@("`@("`@
M("`@<F5T=7)N("=@)R`N("1S='(@+B`G8"<["B`@("`@("`@("`@(&1E9F%U
M;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@)R(G("X@<W1R7W)E<&QA8V4H
M)R(G+"`G(B(G+"`D<W1R*2`N("<B)SL*("`@("`@("!]"B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@<75O=&4H*0H*("`@("\J*@H@("`@("H@0&1E
M<')E8V%T960@($1E<')E8V%T960@:6X@<F5L96%S92`Q+C8N,`H@("`@("H@
M0&EN=&5R;F%L"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E*"1S='(I"B`@
M("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=6]T95-M87)T*"1S='(I.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M
M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E
M;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF
M(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM
M;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]O9&)C.CIC
M<F5A=&5397%U96YC92@I+"!$0E]O9&)C.CID<F]P4V5Q=65N8V4H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!N97AT260H)'-E<5]N86UE+"`D;VYD96UA;F0@
M/2!T<G5E*0H@("`@>PH@("`@("`@("1S97%N86UE(#T@)'1H:7,M/F=E=%-E
M<75E;F-E3F%M92@D<V5Q7VYA;64I.PH@("`@("`@("1R97!E870@/2`P.PH@
M("`@("`@(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L
M:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]
M("1T:&ES+3YQ=65R>2@B=7!D871E("1[<V5Q;F%M97T@<V5T(&ED(#T@:60@
M*R`Q(BD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D[
M"B`@("`@("`@("`@(&EF("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E
M<W5L="D@)B8*("`@("`@("`@("`@("`@("1R97-U;'0M/F=E=$-O9&4H*2`]
M/2!$0E]%4E)/4E].3U-50TA404),12D@>PH@("`@("`@("`@("`@("`@)')E
M<&5A="`](#$["B`@("`@("`@("`@("`@("`D=&AI<RT^<'5S:$5R<F]R2&%N
M9&QI;F<H4$5!4E]%4E)/4E]215154DXI.PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3YC<F5A=&5397%U96YC92@D<V5Q7VYA;64I.PH@("`@
M("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H*3L*("`@("`@
M("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1R97-U;'0@
M/2`D=&AI<RT^<75E<GDH(FEN<V5R="!I;G1O("1[<V5Q;F%M97T@*&ED*2!V
M86QU97,H,"DB*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1R97!E870@/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@?2!W:&EL
M92`H)')E<&5A="D["@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)')E
M<W5L="D["B`@("`@("`@?0H*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/G%U
M97)Y*")S96QE8W0@:60@9G)O;2`D>W-E<6YA;65](BD["B`@("`@("`@:68@
M*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D
M<F5S=6QT.PH@("`@("`@('T*"B`@("`@("`@)')O=R`]("1R97-U;'0M/F9E
M=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*("`@("`@("!I9B`H1$(Z
M.FES17)R;W(H)')O=R!\?"`A)')O=RDI('L*("`@("`@("`@("`@<F5T=7)N
M("1R;W<["B`@("`@("`@?0H*("`@("`@("!R971U<FX@)')O=ULP73L*("`@
M('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*("`@
M("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O9B!T
M:&4@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U96YC
M92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@
M("!$0E]O9&)C.CIN97AT240H*2P@1$)?;V1B8SHZ9')O<%-E<75E;F-E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5Q=65N8V4H)'-E<5]N86UE
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^<75E<GDH)T-214%412!4
M04),12`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YG
M971397%U96YC94YA;64H)'-E<5]N86UE*0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`G("AI9"!I;G1E9V5R($Y/5"!.54Q,+"<*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("X@)R!04DE-05)9($M%62AI9"DI)RD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC
M92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H
M*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@
M1$)?;V1B8SHZ;F5X=$E$*"DL($1"7V]D8F,Z.F-R96%T95-E<75E;F-E*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?;F%M92D*
M("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$4D]0(%1!0DQ%
M("<@+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J
M*@H@("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET
M<PH@("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N
M<R!I="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C
M="!I9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@
M<W5P<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO
M"B`@("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@("`@
M>PH@("`@("`@(&EF("@A0&]D8F-?875T;V-O;6UI="@D=&AI<RT^8V]N;F5C
M=&EO;BP@)&]N;V9F*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F]D
M8F-286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/
M2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@
M("\J*@H@("`@("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@
M("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N
M8W1I;VX@8V]M;6ET*"D*("`@('L*("`@("`@("!I9B`H(4!O9&)C7V-O;6UI
M="@D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T
M:&ES+3YO9&)C4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F]L;&)A
M8VLH*0H*("`@("\J*@H@("`@("H@4F5V97)T<R!T:&4@8W5R<F5N="!T<F%N
M<V%C=&EO;@H@("`@("H*("`@("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S
M=6-C97-S+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J
M+PH@("`@9G5N8W1I;VX@<F]L;&)A8VLH*0H@("`@>PH@("`@("`@(&EF("@A
M0&]D8F-?<F]L;&)A8VLH)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&]D8F-286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U
M8V5S(&$@1$)?17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P
M<F]B;&5M"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H
M92!E<G)O<B!I<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E
M+B`@268@=&AI<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@=&AE(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE
M($1"35,N"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%
M<G)O<B!O8FIE8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I
M<V5%<G)O<B@I+`H@("`@("H@("`@("!$0E]O9&)C.CIE<G)O<DYA=&EV92@I
M+"!$0E]C;VUM;VXZ.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&]D8F-286ES945R<F]R*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@
M:68@*"1E<G)N;R`]/3T@;G5L;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1T
M:&ES+3YD8G-Y;G1A>"D@>PH@("`@("`@("`@("`@("`@8V%S92`G86-C97-S
M)SH*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O
M<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]%4E)/4E,I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/F5R<F]R8V]D95]M87!;)S`W,#`Q
M)UT@/2!$0E]%4E)/4E].3U-50TA&245,1#L*("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`O+R!$;VEN9R!T
M:&ES(&EN(&-A<V4@;6]D92!C:&%N9V5S(&1U<FEN9R!R=6YT:6UE+@H@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W)C;V1E7VUA<%LG,#<P
M,#$G72`]($1"7T524D]27TU)4TU!5$-(.PH@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@)&YA=&EV95]C;V1E(#T@;V1B8U]E
M<G)O<B@D=&AI<RT^8V]N;F5C=&EO;BD["@H@("`@("`@("`@("`@("`@("`@
M("\O(%,Q,#`P(&ES(&9O<B`B1V5N97)A;"!%<G)O<BXB("!,970G<R!B92!M
M;W)E('-P96-I9FEC+@H@("`@("`@("`@("`@("`@("`@(&EF("@D;F%T:79E
M7V-O9&4@/3T@)U,Q,#`P)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R;W)M<V<@/2!O9&)C7V5R<F]R;7-G*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@<W1A=&EC("1E<G)O<E]R96=E>'!S
M.PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<E]R
M96=E>'!S*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R
M7W)E9V5X<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G+VEN8VQU9&5S(')E;&%T960@<F5C;W)D<RXD+VDG("`]/B!$0E]%
M4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<O8V%N;F]T(&-O;G1A:6X@82!.=6QL('9A;'5E+VDG(#T^($1"7T52
M4D]27T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1E<G)O<E]R96=E>'!S(&%S("1R
M96=E>'`@/3X@)&-O9&4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AP<F5G7VUA=&-H*"1R96=E>'`L("1E<G)O<FUS9RDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&-O9&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&YA=&EV95]C;V1E("X@)R`G("X@)&5R
M<F]R;7-G*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D
M97)R;F\@/2!$0E]%4E)/4CL*("`@("`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R
M;W)#;V1E*"1N871I=F5?8V]D92D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R
M;W)#;V1E*&]D8F-?97)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^97)R;W).871I=F4H*2D["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W).871I=F4H*0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@1$)-4R<@;F%T:79E(&5R<F]R(&-O9&4@
M86YD(&UE<W-A9V4@<')O9'5C960@8GD@=&AE(&QA<W0@<75E<GD*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE($1"35,G(&5R<F]R(&-O9&4@
M86YD(&UE<W-A9V4*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H
M*0H@("`@>PH@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)'1H:7,M/F-O;FYE
M8W1I;VXI*2!["B`@("`@("`@("`@(')E='5R;B!`;V1B8U]E<G)O<B@I("X@
M)R`G("X@0&]D8F-?97)R;W)M<V<H*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($!O9&)C7V5R<F]R*"1T:&ES+3YC;VYN96-T:6]N*2`N("<@)R`N($!O
M9&)C7V5R<F]R;7-G*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!T86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!I;F9O<FUA=&EO;B!A8F]U="!A('1A8FQE(&]R(&$@<F5S=6QT
M('-E=`H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S
M=6QT("!$0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT
M86EN:6YG('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S
M(&$@<75E<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@
M:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P
M<F5C871E9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@
M("!A('9A;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R
M;B!A<G)A>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M
M871I;VX@<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$
M0E]C;VUM;VXZ.G1A8FQE26YF;R@I"B`@("`@*B!`<VEN8V4@365T:&]D(&%V
M86EL86)L92!S:6YC92!296QE87-E(#$N-RXP"B`@("`@*B\*("`@(&9U;F-T
M:6]N('1A8FQE26YF;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*&ES7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O
M*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA
M;64N"B`@("`@("`@("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I
M9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@
M0&]D8F-?97AE8R@D=&AI<RT^8V]N;F5C=&EO;BP@(E-%3$5#5"`J($923TT@
M)')E<W5L="(I.PH@("`@("`@("`@("!I9B`H(21I9"D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O<B@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@=')U93L*("`@("`@
M("!](&5L<V5I9B`H:7-S970H)')E<W5L="T^<F5S=6QT*2D@>PH@("`@("`@
M("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E
M<W5L="!O8FIE8W0N"B`@("`@("`@("`@("`J($5X=')A8W0@=&AE(')E<W5L
M="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B\*("`@("`@
M("`@("`@)&ED(#T@)')E<W5L="T^<F5S=6QT.PH@("`@("`@("`@("`D9V]T
M7W-T<FEN9R`](&9A;'-E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@<F5S=6QT
M(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J($-O<'D@:70N
M"B`@("`@("`@("`@("`J($1E<')E8V%T960N("!(97)E(&9O<B!C;VUP871I
M8FEL:71Y(&]N;'DN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2`D<F5S=6QT.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`](&9A;'-E.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"%I<U]R97-O=7)C92@D:60I*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;V1B8U)A:7-E17)R;W(H1$)?15)2
M3U)?3D5%1%]-3U)%7T1!5$$I.PH@("`@("`@('T*"B`@("`@("`@:68@*"1T
M:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?
M3$]715)#05-%*2!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R=&]L
M;W=E<B<["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&-A<V5?9G5N
M8R`]("=S=')V86PG.PH@("`@("`@('T*"B`@("`@("`@)&-O=6YT(#T@0&]D
M8F-?;G5M7V9I96QD<R@D:60I.PH@("`@("`@("1R97,@("`](&%R<F%Y*"D[
M"@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?
M9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@)&-O;"`]
M("1I("L@,3L*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("=T86)L92<@/3X@)&=O=%]S=')I;F<@/R`D8V%S95]F=6YC
M*"1R97-U;'0I(#H@)R<L"B`@("`@("`@("`@("`@("`G;F%M92<@(#T^("1C
M87-E7V9U;F,H0&]D8F-?9FEE;&1?;F%M92@D:60L("1C;VPI*2P*("`@("`@
M("`@("`@("`@("=T>7!E)R`@/3X@0&]D8F-?9FEE;&1?='EP92@D:60L("1C
M;VPI+`H@("`@("`@("`@("`@("`@)VQE;B<@("`]/B!`;V1B8U]F:65L9%]L
M96XH)&ED+"`D8V]L*2P*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@)R<L
M"B`@("`@("`@("`@("D["B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!
M0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D97(G
M75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4E1!0DQ%*2![
M"B`@("`@("`@("`@("`@("`D<F5S6R=O<F1E<G1A8FQE)UU;)')E<ULD:5U;
M)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@("\O(&9R964@=&AE(')E<W5L="!O;FQY
M(&EF('=E('=E<F4@8V%L;&5D(&]N(&$@=&%B;&4*("`@("`@("!I9B`H)&=O
M=%]S=')I;F<I('L*("`@("`@("`@("`@0&]D8F-?9G)E95]R97-U;'0H)&ED
M*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R97,["B`@("!]"@H@("`@
M+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@("`O*BH*
M("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@9F]R(&QI
M<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@("`@*B!4
M:&%N:W,@=&\@<WEM8F]L,4!G;6%I;"YC;VT@86YD(%!H:6QI<'!E+DIA=7-I
M;VYS0#$Q86)A8W5S+F-O;2X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S('EO=2!W86YT('1O(')E=')I
M979E"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!L:7-T(&]F
M(&]B:F5C=',@<F5Q=65S=&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T
M96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@
M("H@0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N
M,`H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L475E<GDH)'1Y<&4I
M"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@("!C
M87-E("=D871A8F%S97,G.@H@("`@("`@("`@("`@("`@:68@*"%F=6YC=&EO
M;E]E>&ES=',H)V]D8F-?9&%T85]S;W5R8V4G*2D@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@)')E<R`]($!O9&)C7V1A=&%?<V]U<F-E*"1T:&ES+3YC;VYN
M96-T:6]N+"!344Q?1D540TA?1DE24U0I.PH@("`@("`@("`@("`@("`@:68@
M*&ES7V%R<F%Y*"1R97,I*2!["B`@("`@("`@("`@("`@("`@("`@)&]U="`]
M(&%R<F%Y*"1R97-;)W-E<G9E<B==*3L*("`@("`@("`@("`@("`@("`@("!W
M:&EL92@D<F5S(#T@0&]D8F-?9&%T85]S;W5R8V4H)'1H:7,M/F-O;FYE8W1I
M;VXL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%-13%]&151#2%].15A4*2D*("`@("`@("`@("`@("`@("`@
M("!["B`@("`@("`@("`@("`@("`@("`@("`@("1O=71;72`]("1R97-;)W-E
M<G9E<B==.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@)&]U=#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO9&)C4F%I<V5%<G)O
M<B@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@(&-A<V4@
M)W-C:&5M82YT86)L97,G.@H@("`@("`@("`@("`@("`@)&ME97`@/2`G5$%"
M3$4G.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@
M)W9I97=S)SH*("`@("`@("`@("`@("`@("1K965P(#T@)U9)15<G.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@
M("`@("`@("`@("!R971U<FX@;G5L;#L*("`@("`@("!]"@H@("`@("`@("\J
M"B`@("`@("`@("H@4F5M;W9I;F<@;F]N+6-O;F9O<FUI;F<@:71E;7,@:6X@
M=&AE('=H:6QE(&QO;W`@<F%T:&5R('1H86X*("`@("`@("`@*B!I;B!T:&4@
M;V1B8U]T86)L97,H*2!C86QL(&)E8V%U<V4@<V]M92!B86-K96YD<R!C:&]K
M92!O;B!T:&ES.@H@("`@("`@("`J("`@("!O9&)C7W1A8FQE<R@D=&AI<RT^
M8V]N;F5C=&EO;BP@)R<L("<G+"`G)RP@)U1!0DQ%)RD*("`@("`@("`@*B\*
M("`@("`@("`D<F5S("`]($!O9&)C7W1A8FQE<R@D=&AI<RT^8V]N;F5C=&EO
M;BD["B`@("`@("`@:68@*"$D<F5S*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^;V1B8U)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@("`@("`@)&]U
M="`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@*"1R;W<@/2!O9&)C7V9E=&-H
M7V%R<F%Y*"1R97,I*2!["B`@("`@("`@("`@(&EF("@D<F]W6R=404),15]4
M65!%)UT@(3T@)&ME97`I('L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D='EP92`]/2`G<V-H96UA
M+G1A8FQE<R<I('L*("`@("`@("`@("`@("`@("1O=71;72`]("1R;W=;)U1!
M0DQ%7U-#2$5-)UT@+B`G+B<@+B`D<F]W6R=404),15].04U%)UT["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D;W5T6UT@/2`D<F]W
M6R=404),15].04U%)UT["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("1O=70["B`@("!]"@H@("`@+R\@?7U]"@I]"@HO*@H@*B!,
M;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC+6]F
M9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]$0B]P9W-Q
M;"YP:'``````````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,3`U-C4Q(#$P-3$U-#,T,3,S(#`R,#8Q-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`H*+RH@=FEM.B!S970@
M97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A8G-T;W`]
M-#H@*B\*"B\J*@H@*B!4:&4@4$5!4B!$0B!D<FEV97(@9F]R(%!(4"=S('!G
M<W%L(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!0;W-T9W)E
M4U%,(&1A=&%B87-E<PH@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@
M*B!,24-%3E-%.B!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R
M<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E;G-E"B`J('1H870@:7,@879A:6QA
M8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I
M;F<@55)).@H@*B!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT
M+B`@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8*("H@=&AE(%!(
M4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O(&]B=&%I;B!I="!T:')O=6=H
M('1H92!W96(L('!L96%S90H@*B!S96YD(&$@;F]T92!T;R!L:6-E;G-E0'!H
M<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X*
M("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A8VMA9V4@("`@1$(*
M("H@0&%U=&AO<B`@("`@4G5I($AI<F]K87=A(#QH:7)O:V%W84!P:'`N;F5T
M/@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W-B0'!H<"YN970^"B`J
M($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE
M=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!P
M9W-Q;"YP:'`L=B`Q+C$R-B`R,#`U+S`S+S`T(#(S.C$R.C,V(&1A;FEE;&,@
M17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@1$)?8V]M;6]N(&-L87-S
M('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J+PIR97%U:7)E7V]N8V4@
M)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M971H;V1S(%!%05(@1$(@
M=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S('!G<W%L(&5X=&5N<VEO;@H@
M*B!F;W(@:6YT97)A8W1I;F<@=VET:"!0;W-T9W)E4U%,(&1A=&%B87-E<PH@
M*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O;F5S(&1E8VQA<F5D
M(&EN($1"7V-O;6UO;BX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@
M0'!A8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@4G5I($AI<F]K87=A(#QH
M:7)O:V%W84!P:'`N;F5T/@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\
M<W-B0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@
M/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@1$)?<&=S<6P@97AT96YD
M<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*"B`@("`O*BH*
M("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C:3@L(&]D8F,L
M(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!H
M<'1Y<&4@/2`G<&=S<6PG.PH*("`@("\J*@H@("`@("H@5&AE(&1A=&%B87-E
M('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B,BP@86-C97-S+"!E=&,N
M*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@
M)&1B<WEN=&%X(#T@)W!G<W%L)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A
M8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@
M("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V
M97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@("`J(&YE=U]L:6YK('-U
M<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@
M=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI
M;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L871E)R`](&5M=6QA=&4@
M=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@
M(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI
M<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V
M87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@
M(#T^("=A;'1E<B<L"B`@("`@("`@)VYE=U]L:6YK)R`@("`@(#T^("<T+C,N
M,"<L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@
M)W!C;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@
M("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@("`]/B!T<G5E
M+`H@("`@("`@("=T<F%N<V%C=&EO;G,G("`]/B!T<G5E+`H@("`@*3L*"B`@
M("`O*BH*("`@("`J($$@;6%P<&EN9R!O9B!N871I=F4@97)R;W(@8V]D97,@
M=&\@1$(@97)R;W(@8V]D97,*("`@("`J($!V87(@87)R87D*("`@("`J+PH@
M("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`I.PH*("`@("\J
M*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N(&-R96%T960@
M8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*("`@('9A<B`D
M8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@:6YF;W)M871I
M;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D["@H*("`@("\J
M*@H@("`@("H@4VAO=6QD(&1A=&$@;6%N:7!U;&%T:6]N('%U97)I97,@8F4@
M8V]M;6ET=&5D(&%U=&]M871I8V%L;'D_"B`@("`@*B!`=F%R(&)O;VP*("`@
M("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO"B`@("!V87(@)&%U=&]C;VUM
M:70@/2!T<G5E.PH*("`@("\J*@H@("`@("H@5&AE('%U86YT:71Y(&]F('1R
M86YS86-T:6]N<R!B96=U;@H@("`@("H*("`@("`J('M`:6YT97)N86P@(%=H
M:6QE('1H:7,@:7,@<')I=F%T92P@:70@8V%N)W0@86-T=6%L;'D@8F4@9&5S
M:6=N871E9`H@("`@("H@<')I=F%T92!I;B!02%`@-2!B96-A=7-E(&ET(&ES
M(&1I<F5C=&QY(&%C8V5S<V5D(&EN('1H92!T97-T('-U:71E+GU]"B`@("`@
M*@H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1T<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*"B`@
M("`O*BH*("`@("`J(%1H92!N=6UB97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A
M(&1A=&$@;6%N:7!U;&%T:6]N('%U97)Y"B`@("`@*B!`=F%R(&EN=&5G97(*
M("`@("`J+PH@("`@=F%R("1A9F9E8W1E9"`](#`["@H@("`@+RHJ"B`@("`@
M*B!4:&4@8W5R<F5N="!R;W<@8F5I;F<@;&]O:V5D(&%T(&EN(&9E=&-H26YT
M;R@I"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B!`86-C97-S('!R:79A=&4*
M("`@("`J+PH@("`@=F%R("1R;W<@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@
M("H@5&AE(&YU;6)E<B!O9B!R;W=S(&EN(&$@9VEV96X@<F5S=6QT('-E=`H@
M("`@("H@0'9A<B!A<G)A>0H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7VYU;5]R;W=S(#T@87)R87DH*3L*"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*"B`@("`O*BH*("`@("`J(%1H:7,@
M8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD=&AI<RT^1$)?8V]M;6]N*"D\+VMB
M9#X*("`@("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N
M8W1I;VX@1$)?<&=S<6PH*0H@("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM
M;VXH*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*
M"B`@("`O*BH*("`@("`J($-O;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E
M<BP@;&]G(&EN(&%N9"!O<&5N('1H92!D871A8F%S90H@("`@("H*("`@("`J
M($1O;B=T(&-A;&P@=&AI<R!M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O
M;FYE8W0H*2!I;G-T96%D+@H@("`@("H*("`@("`J(%!%05(@1$(G<R!P9W-Q
M;"!D<FEV97(@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!E>'1R82!$4TX@;W!T
M:6]N<SH*("`@("`J("`@*R!C;VYN96-T7W1I;65O=70@($AO=R!M86YY('-E
M8V]N9',@=&\@=V%I="!F;W(@82!C;VYN96-T:6]N('1O"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@8F4@97-T86)L:7-H960N("!!=F%I;&%B;&4@
M<VEN8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J("`@*R!N97=?;&EN:R`@("`@
M("`@($EF('-E="!T;R!T<G5E+"!C875S97,@<W5B<V5Q=65N="!C86QL<R!T
M;PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&-O;FYE8W0H*2!T;R!R
M971U<FX@82!N97<@8V]N;F5C=&EO;B!L:6YK"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@:6YS=&5A9"!O9B!T:&4@97AI<W1I;F<@;VYE+B`@5T%2
M3DE.1SH@=&AI<R!I<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&YO
M="!P;W)T86)L92!T;R!O=&AE<B!$0DU3)W,N("!!=F%I;&%B;&4@;VYL>0H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@(&EF(%!(4"!I<R`^/2`T+C,N
M,"!A;F0@4$5!4B!$0B!I<R`^/2`Q+C<N,"X*("`@("`J("`@*R!O<'1I;VYS
M("`@("`@("`@($-O;6UA;F0@;&EN92!O<'1I;VYS('1O(&)E('-E;G0@=&\@
M=&AE('-E<G9E<BX*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!!=F%I
M;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C8N-"X*("`@("`J("`@*R!S97)V:6-E
M("`@("`@("`@(%-P96-I9FEE<R!A('-E<G9I8V4@;F%M92!I;B!P9U]S97)V
M:6-E+F-O;F8@=&AA=`H@("`@("H@("`@("`@("`@("`@("`@("`@("`@(&AO
M;&1S(&%D9&ET:6]N86P@8V]N;F5C=&EO;B!P87)A;65T97)S+@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@($%V86EL86)L92!S:6YC92!014%2($1"
M(#$N-RXP+@H@("`@("H@("`K('-S;&UO9&4@("`@("`@("`@2&]W('-H;W5L
M9"!34TP@8F4@=7-E9"!W:&5N(&-O;FYE8W1I;F<_("!686QU97,Z"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@9&ES86)L92P@86QL;W<L('!R969E
M<B!O<B!R97%U:7)E+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@($%V
M86EL86)L92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H@("`K('1T>2`@
M("`@("`@("`@("`@5&AI<R!W87,@=7-E9"!T;R!S<&5C:69Y('=H97)E('1O
M('-E;F0@<V5R=F5R"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@9&5B
M=6<@;W5T<'5T+B`@079A:6QA8FQE('-I;F-E(%!%05(@1$(@,2XV+C0N"B`@
M("`@*@H@("`@("H@17AA;7!L92!O9B!C;VYN96-T:6YG('1O(&$@;F5W(&QI
M;FL@=FEA(&$@<V]C:V5T.@H@("`@("H@/&-O9&4^"B`@("`@*B!R97%U:7)E
M7V]N8V4@)T1"+G!H<"<["B`@("`@*B`*("`@("`J("1D<VX@/2`G<&=S<6PZ
M+R]U<V5R.G!A<W-`=6YI>"@O=&UP*2]D8FYA;64_;F5W7VQI;FL]=')U92<[
M"B`@("`@*B`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("H@("`@("=P;W)T86)I
M;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?04Q,+`H@("`@("H@*3L*("`@("`J
M(`H@("`@("H@)&1B(#TF($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*
M("`@("`J(&EF("A014%2.CII<T5R<F]R*"1D8BDI('L*("`@("`J("`@("!D
M:64H)&1B+3YG971-97-S86=E*"DI.PH@("`@("H@?0H@("`@("H@/"]C;V1E
M/@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE
M(&1A=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES
M=&5N="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@
M("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0&QI
M;FL@:'1T<#HO+W=W=RYP;W-T9W)E<W%L+F]R9R]D;V-S+V-U<G)E;G0O<W1A
M=&EC+VQI8G!Q+FAT;6PC3$E"4%$M0T].3D5#5`H@("`@("HO"B`@("!F=6YC
M=&EO;B!C;VYN96-T*"1D<VXL("1P97)S:7-T96YT(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@:68@*"%014%2.CIL;V%D17AT96YS:6]N*"=P9W-Q;"<I*2![
M"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/
M4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@(&EF("@D9'-N6R=D8G-Y;G1A>"==
M*2!["B`@("`@("`@("`@("1T:&ES+3YD8G-Y;G1A>"`]("1D<VY;)V1B<WEN
M=&%X)UT["B`@("`@("`@?0H*("`@("`@("`D<')O=&]C;VP@/2`D9'-N6R=P
M<F]T;V-O;"==(#\@)&1S;ELG<')O=&]C;VPG72`Z("=T8W`G.PH*("`@("`@
M("`D<&%R86US(#T@87)R87DH)R<I.PH@("`@("`@(&EF("@D<')O=&]C;VP@
M/3T@)W1C<"<I('L*("`@("`@("`@("`@:68@*"1D<VY;)VAO<W1S<&5C)UTI
M('L*("`@("`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)VAO<W0])R`N("1D
M<VY;)VAO<W1S<&5C)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@
M*"1D<VY;)W!O<G0G72D@>PH@("`@("`@("`@("`@("`@)'!A<F%M<ULP72`N
M/2`G('!O<G0])R`N("1D<VY;)W!O<G0G73L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS96EF("@D<')O=&]C;VP@/3T@)W5N:7@G*2!["B`@("`@("`@
M("`@("\O($%L;&]W(&9O<B!P9R!S;V-K970@:6X@;F]N+7-T86YD87)D(&QO
M8V%T:6]N<RX*("`@("`@("`@("`@:68@*"1D<VY;)W-O8VME="==*2!["B`@
M("`@("`@("`@("`@("`D<&%R86US6S!=("X]("=H;W-T/2<@+B`D9'-N6R=S
M;V-K970G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&1S;ELG
M<&]R="==*2!["B`@("`@("`@("`@("`@("`D<&%R86US6S!=("X]("<@<&]R
M=#TG("X@)&1S;ELG<&]R="==.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@
M("`@("`@(&EF("@D9'-N6R=D871A8F%S92==*2!["B`@("`@("`@("`@("1P
M87)A;7-;,%T@+CT@)R!D8FYA;64]7"<G("X@861D<VQA<VAE<R@D9'-N6R=D
M871A8F%S92==*2`N("=<)R<["B`@("`@("`@?0H@("`@("`@(&EF("@D9'-N
M6R=U<V5R;F%M92==*2!["B`@("`@("`@("`@("1P87)A;7-;,%T@+CT@)R!U
M<V5R/5PG)R`N(&%D9'-L87-H97,H)&1S;ELG=7-E<FYA;64G72D@+B`G7"<G
M.PH@("`@("`@('T*("`@("`@("!I9B`H)&1S;ELG<&%S<W=O<F0G72D@>PH@
M("`@("`@("`@("`D<&%R86US6S!=("X]("<@<&%S<W=O<F0]7"<G("X@861D
M<VQA<VAE<R@D9'-N6R=P87-S=V]R9"==*2`N("=<)R<["B`@("`@("`@?0H@
M("`@("`@(&EF("@A96UP='DH)&1S;ELG;W!T:6]N<R==*2D@>PH@("`@("`@
M("`@("`D<&%R86US6S!=("X]("<@;W!T:6]N<STG("X@)&1S;ELG;W!T:6]N
M<R==.PH@("`@("`@('T*("`@("`@("!I9B`H(65M<'1Y*"1D<VY;)W1T>2==
M*2D@>PH@("`@("`@("`@("`D<&%R86US6S!=("X]("<@='1Y/2<@+B`D9'-N
M6R=T='DG73L*("`@("`@("!]"B`@("`@("`@:68@*"%E;7!T>2@D9'-N6R=C
M;VYN96-T7W1I;65O=70G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULP72`N
M/2`G(&-O;FYE8W1?=&EM96]U=#TG("X@)&1S;ELG8V]N;F5C=%]T:6UE;W5T
M)UT["B`@("`@("`@?0H@("`@("`@(&EF("@A96UP='DH)&1S;ELG<W-L;6]D
M92==*2D@>PH@("`@("`@("`@("`D<&%R86US6S!=("X]("<@<W-L;6]D93TG
M("X@)&1S;ELG<W-L;6]D92==.PH@("`@("`@('T*("`@("`@("!I9B`H(65M
M<'1Y*"1D<VY;)W-E<G9I8V4G72DI('L*("`@("`@("`@("`@)'!A<F%M<ULP
M72`N/2`G('-E<G9I8V4])R`N("1D<VY;)W-E<G9I8V4G73L*("`@("`@("!]
M"@H@("`@("`@(&EF("AI<W-E="@D9'-N6R=N97=?;&EN:R==*0H@("`@("`@
M("`@("`F)B`H)&1S;ELG;F5W7VQI;FLG72`]/2`G=')U92<@?'P@)&1S;ELG
M;F5W7VQI;FLG72`]/3T@=')U92DI"B`@("`@("`@>PH@("`@("`@("`@("!I
M9B`H=F5R<VEO;E]C;VUP87)E*'!H<'9E<G-I;VXH*2P@)S0N,RXP)RP@)SX]
M)RDI('L*("`@("`@("`@("`@("`@("1P87)A;7-;72`](%!'4U%,7T-/3DY%
M0U1?1D]20T5?3D57.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("`D8V]N;F5C=%]F=6YC=&EO;B`]("1P97)S:7-T96YT(#\@)W!G7W!C;VYN
M96-T)R`Z("=P9U]C;VYN96-T)SL*"B`@("`@("`@)&EN:2`](&EN:5]G970H
M)W1R86-K7V5R<F]R<R<I.PH@("`@("`@("1P:'!?97)R;W)M<V<@/2`G)SL*
M("`@("`@("!I9B`H)&EN:2D@>PH@("`@("`@("`@("`D=&AI<RT^8V]N;F5C
M=&EO;B`]($!C86QL7W5S97)?9G5N8U]A<G)A>2@D8V]N;F5C=%]F=6YC=&EO
M;BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!A<F%M<RD["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@("`@
M("1T:&ES+3YC;VYN96-T:6]N(#T@0&-A;&Q?=7-E<E]F=6YC7V%R<F%Y*"1C
M;VYN96-T7V9U;F-T:6]N+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R86US*3L*("`@("`@("`@
M("`@:6YI7W-E="@G=')A8VM?97)R;W)S)RP@)&EN:2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!
M24Q%1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D<&AP7V5R<F]R;7-G*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O
M;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@
M9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!P
M9U]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M/F-O
M;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[('-I;7!L95%U97)Y*"D*"B`@("`O*BH*
M("`@("`J(%-E;F1S(&$@<75E<GD@=&\@=&AE(&1A=&%B87-E('-E<G9E<@H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@('1H92!344P@<75E<GD@<W1R
M:6YG"B`@("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@*R!A(%!(4"!R97-U
M;'0@<F5S<F]U8V4@9F]R('-U8V-E<W-F=6P@4T5,14-4('%U97)I97,*("`@
M("`J("`@("`@("`@("`@("`@("L@=&AE($1"7T]+(&-O;G-T86YT(&9O<B!O
M=&AE<B!S=6-C97-S9G5L('%U97)I97,*("`@("`J("`@("`@("`@("`@("`@
M("L@82!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R90H@("`@("HO"B`@("!F
M=6YC=&EO;B!S:6UP;&51=65R>2@D<75E<GDI"B`@("!["B`@("`@("`@)&ES
M;6%N:7`@/2!$0CHZ:7--86YI<"@D<75E<GDI.PH@("`@("`@("1T:&ES+3YL
M87-T7W%U97)Y(#T@)'%U97)Y.PH@("`@("`@("1Q=65R>2`]("1T:&ES+3YM
M;V1I9GE1=65R>2@D<75E<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C
M;VUM:70@)B8@)&ES;6%N:7`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT
M<F%N<V%C=&EO;E]O<&-O=6YT(#T](#`I('L*("`@("`@("`@("`@("`@("1R
M97-U;'0@/2!`<&=?97AE8R@D=&AI<RT^8V]N;F5C=&EO;BP@)V)E9VEN.R<I
M.PH@("`@("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YP9W-Q;%)A:7-E17)R;W(H*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI
M<RT^=')A;G-A8W1I;VY?;W!C;W5N="LK.PH@("`@("`@('T*("`@("`@("`D
M<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("1Q=65R>2D[
M"B`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<&=S<6Q286ES945R<F]R*"D["B`@("`@("`@?0H@("`@("`@("\O
M($1E=&5R;6EN92!W:&EC:"!Q=65R:65S('1H870@<VAO=6QD(')E='5R;B!D
M871A+"!A;F0@=VAI8V@*("`@("`@("`O+R!S:&]U;&0@<F5T=7)N(&%N(&5R
M<F]R(&-O9&4@;VYL>2X*("`@("`@("!I9B`H)&ES;6%N:7`I('L*("`@("`@
M("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@0'!G7V%F9F5C=&5D7W)O=W,H)')E
M<W5L="D["B`@("`@("`@("`@(')E='5R;B!$0E]/2SL*("`@("`@("!](&5L
M<V5I9B`H<')E9U]M871C:"@G+UY<<RI<*"I<<RHH4T5,14-4?$584$Q!24Y\
M4TA/5RE<<R]S:2<L("1Q=65R>2DI('L*("`@("`@("`@("`@+RH@4&]S=&=R
M95-13"!C;VUM86YD<SH*("`@("`@("`@("`@("`@04)/4E0L($%,5$52+"!"
M14=)3BP@0TQ/4T4L($-,55-415(L($-/34U)5"P@0T]062P*("`@("`@("`@
M("`@("`@0U)%051%+"!$14-,05)%+"!$14Q%5$4L($123U`@5$%"3$4L($58
M4$Q!24XL($9%5$-(+`H@("`@("`@("`@("`@("!'4D%.5"P@24Y315)4+"!,
M25-414XL($Q/040L($Q/0TLL($U/5D4L($Y/5$E&62P@4D53150L"B`@("`@
M("`@("`@("`@(%)%5D]+12P@4D],3$)!0TLL(%-%3$5#5"P@4T5,14-4($E.
M5$\L(%-%5"P@4TA/5RP*("`@("`@("`@("`@("`@54Y,25-414XL(%501$%4
M12P@5D%#555-"B`@("`@("`@("`@("HO"B`@("`@("`@("`@("1T:&ES+3YR
M;W=;*&EN="DD<F5S=6QT72`](#`[("\O(')E<V5T('1H92!R;W<@8V]U;G1E
M<BX*("`@("`@("`@("`@)&YU;7)O=W,@/2`D=&AI<RT^;G5M4F]W<R@D<F5S
M=6QT*3L*("`@("`@("`@("`@:68@*&ES7V]B:F5C="@D;G5M<F]W<RDI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D;G5M<F]W<SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("`D=&AI<RT^7VYU;5]R;W=S6RAI;G0I)')E<W5L=%T@
M/2`D;G5M<F]W<SL*("`@("`@("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@,#L*
M("`@("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)'1H:7,M/F%F9F5C=&5D(#T@,#L*("`@("`@("`@("`@
M<F5T=7)N($1"7T]+.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!N97AT4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($UO=F4@=&AE
M(&EN=&5R;F%L('!G<W%L(')E<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V
M86EL86)L92!R97-U;'0*("`@("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!F
M8G-Q;"!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`86-C97-S('!U
M8FQI8PH@("`@("H*("`@("`J($!R971U<FX@=')U92!I9B!A(')E<W5L="!I
M<R!A=F%I;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@
M("!F=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@
M<F5T=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E
M=&-H26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T
M:&4@<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@
M("`J($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E
M:6X@87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E
M=&-H26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A
M9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B
M96-A=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J
M"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@
M<F5S=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@
M("`@("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*
M("`@("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S
M=6QT:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@
M:6YT("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H
M,"`](&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$
M0E]/2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L
M="!S970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N
M(&9A:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA)
M;G1O*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L
M("8D87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@
M("`@("`D<F5S=6QT7VEN="`]("AI;G0I)')E<W5L=#L*("`@("`@("`D<F]W
M;G5M(#T@*"1R;W=N=6T@(3T](&YU;&PI(#\@)')O=VYU;2`Z("1T:&ES+3YR
M;W=;)')E<W5L=%]I;G1=.PH@("`@("`@(&EF("@D<F]W;G5M(#X]("1T:&ES
M+3Y?;G5M7W)O=W-;)')E<W5L=%]I;G1=*2!["B`@("`@("`@("`@(')E='5R
M;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"
M7T9%5$-(34]$15]!4U-/0RD@>PH@("`@("`@("`@("`D87)R(#T@0'!G7V9E
M=&-H7V%R<F%Y*"1R97-U;'0L("1R;W=N=6TL(%!'4U%,7T%34T]#*3L*("`@
M("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6R=P;W)T86)I;&ET>2==("8@
M1$)?4$]25$%"24Q)5%E?3$]715)#05-%("8F("1A<G(I('L*("`@("`@("`@
M("`@("`@("1A<G(@/2!A<G)A>5]C:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%3
M15],3U=%4BD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D87)R(#T@0'!G7V9E=&-H7W)O=R@D<F5S=6QT+"`D<F]W;G5M
M*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@("`@("`@
M(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@
M>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD[
M"B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B
M:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@
M("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T
M>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G)O=ULD<F5S=6QT
M7VEN=%T@/2`K*R1R;W=N=6T["B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J
M*@H@("`@("H@1&5L971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE
M(&UE;6]R>2!O8V-U<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@
M("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER
M96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N
M("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C
M875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@
M("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E
M<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)5
M12!O;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@
M("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!I
M9B`H:7-?<F5S;W5R8V4H)')E<W5L="DI('L*("`@("`@("`@("`@=6YS970H
M)'1H:7,M/G)O=ULH:6YT*21R97-U;'1=*3L*("`@("`@("`@("`@=6YS970H
M)'1H:7,M/E]N=6U?<F]W<ULH:6YT*21R97-U;'1=*3L*("`@("`@("`@("`@
M)'1H:7,M/F%F9F5C=&5D(#T@,#L*("`@("`@("`@("`@<F5T=7)N($!P9U]F
M<F5E<F5S=6QT*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M9F%L<V4["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<75O=&4H*0H*
M("`@("\J*@H@("`@("H@0&1E<')E8V%T960@($1E<')E8V%T960@:6X@<F5L
M96%S92`Q+C8N,`H@("`@("H@0&EN=&5R;F%L"B`@("`@*B\*("`@(&9U;F-T
M:6]N('%U;W1E*"1S='(I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ
M=6]T95-M87)T*"1S='(I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('%U;W1E4VUA<G0H*0H*("`@("\J*@H@("`@("H@1F]R;6%T<R!I;G!U="!S
M;R!I="!C86X@8F4@<V%F96QY('5S960@:6X@82!Q=65R>0H@("`@("H*("`@
M("`J($!P87)A;2!M:7AE9"`D:6X@('1H92!D871A('1O(&)E(&9O<FUA='1E
M9`H@("`@("H*("`@("`J($!R971U<FX@;6EX960@('1H92!F;W)M871T960@
M9&%T82X@(%1H92!F;W)M870@9&5P96YD<R!O;B!T:&4@:6YP=70G<PH@("`@
M("H@("`@("`@("`@("`@("`@(%!(4"!T>7!E.@H@("`@("H@("`@("`@("`@
M("`@("`@("L@;G5L;"`]('1H92!S=')I;F<@/'-A;7`^3E5,3#PO<V%M<#X*
M("`@("`J("`@("`@("`@("`@("`@("`K(&)O;VQE86X@/2!S=')I;F<@/'-A
M;7`^5%)513PO<V%M<#X@;W(@/'-A;7`^1D%,4T4\+W-A;7`^"B`@("`@*B`@
M("`@("`@("`@("`@("`@*R!I;G1E9V5R(&]R(&1O=6)L92`]('1H92!U;G%U
M;W1E9"!N=6UB97(*("`@("`J("`@("`@("`@("`@("`@("`K(&]T:&5R("AI
M;F-L=61I;F<@<W1R:6YG<R!A;F0@;G5M97)I8R!S=')I;F=S*2`]"B`@("`@
M*B`@("`@("`@("`@("`@("`@("!T:&4@9&%T82!E<V-A<&5D(&%C8V]R9&EN
M9R!T;R!->5-13"=S('-E='1I;F=S"B`@("`@*B`@("`@("`@("`@("`@("`@
M("!T:&5N(&5N8V%P<W5L871E9"!B971W965N('-I;F=L92!Q=6]T97,*("`@
M("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@("`@
M*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N-BXP
M"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E4VUA<G0H)&EN*0H@("`@>PH@
M("`@("`@(&EF("AI<U]I;G0H)&EN*2!\?"!I<U]D;W5B;&4H)&EN*2D@>PH@
M("`@("`@("`@("!R971U<FX@)&EN.PH@("`@("`@('T@96QS96EF("AI<U]B
M;V]L*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I;B`_("=44E5%)R`Z
M("=&04Q312<["B`@("`@("`@?2!E;'-E:68@*&ES7VYU;&PH)&EN*2D@>PH@
M("`@("`@("`@("!R971U<FX@)TY53$PG.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B`B)R(@+B`D=&AI<RT^97-C87!E4VEM<&QE*"1I
M;BD@+B`B)R(["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@
M>WM[(&5S8V%P95-I;7!L92@I"@H@("`@+RHJ"B`@("`@*B!%<V-A<&5S(&$@
M<W1R:6YG(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N="!$0DU3)W,@<W1A;F1A
M<F1S"B`@("`@*@H@("`@("H@>T!I;G1E<FYA;"!0;W-T9W)E4U%,('1R96%T
M<R!A(&)A8VMS;&%S:"!A<R!A;B!E<V-A<&4@8VAA<F%C=&5R+`H@("`@("H@
M<V\@=&AE>2!A<F4@97-C87!E9"!A<R!W96QL+@H@("`@("H*("`@("`J($YO
M="!U<VEN9R!P9U]E<V-A<&5?<W1R:6YG*"D@>65T(&)E8V%U<V4@:70@<F5Q
M=6ER97,@4&]S=&=R95-13`H@("`@("H@=&\@8F4@870@=F5R<VEO;B`W+C(@
M;W(@9W)E871E<BY]?0H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-T
M<B`@=&AE('-T<FEN9R!T;R!B92!E<V-A<&5D"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!E<V-A<&5D('-T<FEN9PH@("`@("H*("`@("`J
M($!S964@1$)?8V]M;6]N.CIQ=6]T95-M87)T*"D*("`@("`J($!S:6YC92!-
M971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XV+C`*("`@("`J+PH@
M("`@9G5N8W1I;VX@97-C87!E4VEM<&QE*"1S='(I"B`@("!["B`@("`@("`@
M<F5T=7)N('-T<E]R97!L86-E*"(G(BP@(B<G(BP@<W1R7W)E<&QA8V4H)UQ<
M)RP@)UQ<7%PG+"`D<W1R*2D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![
M>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@
M;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES
M(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@
M57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D+B`@270@
M8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@
M1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J
M($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@
M<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E
M<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*
M("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*("`@("`@
M("`D8V]L<R`]($!P9U]N=6UF:65L9',H)')E<W5L="D["B`@("`@("`@:68@
M*"$D8V]L<RD@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G!G<W%L4F%I
M<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&-O;',["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W<R@I"@H@("`@+RHJ
M"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I;B!A(')E<W5L="!S
M970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@
M8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU
M;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E
M8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@
M;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT
M("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L
M=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;5)O=W,H)')E
M<W5L="D*("`@('L*("`@("`@("`D<F]W<R`]($!P9U]N=6UR;W=S*"1R97-U
M;'0I.PH@("`@("`@(&EF("@D<F]W<R`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@)')O=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@875T;T-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!%;F%B;&5S(&]R
M(&1I<V%B;&5S(&%U=&]M871I8R!C;VUM:71S"B`@("`@*@H@("`@("H@0'!A
M<F%M(&)O;VP@)&]N;V9F("!T<G5E('1U<FYS(&ET(&]N+"!F86QS92!T=7)N
M<R!I="!O9F8*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&EF('1H92!D<FEV97(*("`@
M("`J("`@("`@("`@("`@("`@9&]E<VXG="!S=7!P;W)T(&%U=&\M8V]M;6ET
M=&EN9R!T<F%N<V%C=&EO;G,N"B`@("`@*B\*("`@(&9U;F-T:6]N(&%U=&]#
M;VUM:70H)&]N;V9F(#T@9F%L<V4I"B`@("!["B`@("`@("`@+R\@6%A8(&EF
M("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#X@,"P@=V4@<VAO=6QD('!R
M;V)A8FQY"B`@("`@("`@+R\@:7-S=64@82!W87)N:6YG(&AE<F4N"B`@("`@
M("`@)'1H:7,M/F%U=&]C;VUM:70@/2`D;VYO9F8@/R!T<G5E(#H@9F%L<V4[
M"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@
M+R\@>WM[(&-O;6UI="@I"@H@("`@+RHJ"B`@("`@*B!#;VUM:71S('1H92!C
M=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!C;VUM:70H*0H@("`@>PH@("`@
M("`@(&EF("@D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^(#`I('L*("`@
M("`@("`@("`@+R\@*&1I<V%B;&5D*2!H86-K('1O('-H=70@=7`@97)R;W(@
M;65S<V%G97,@9G)O;2!L:6)P<2YA"B`@("`@("`@("`@("\O0&9C;&]S92A`
M9F]P96XH(G!H<#HO+W-T9&5R<B(L(")W(BDI.PH@("`@("`@("`@("`D<F5S
M=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL("=E;F0[)RD["B`@
M("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT(#T@,#L*("`@
M("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G!G<W%L4F%I<V5%<G)O<B@I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!R;VQL8F%C:R@I"@H@("`@+RHJ"B`@("`@*B!2979E
M<G1S('1H92!C=7)R96YT('1R86YS86-T:6]N"B`@("`@*@H@("`@("H@0')E
M='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!R;VQL8F%C:R@I
M"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT
M(#X@,"D@>PH@("`@("`@("`@("`D<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M
M/F-O;FYE8W1I;VXL("=A8F]R=#LG*3L*("`@("`@("`@("`@)'1H:7,M/G1R
M86YS86-T:6]N7V]P8V]U;G0@/2`P.PH@("`@("`@("`@("!I9B`H(21R97-U
M;'0I('L*("`@("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<&=S<6Q286ES
M945R<F]R*"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&%F9F5C
M=&5D4F]W<R@I"@H@("`@+RHJ"B`@("`@*B!$971E<FUI;F5S('1H92!N=6UB
M97(@;V8@<F]W<R!A9F9E8W1E9"!B>2!A(&1A=&$@;6%N:75P;&%T:6]N('%U
M97)Y"B`@("`@*@H@("`@("H@,"!I<R!R971U<FYE9"!F;W(@<75E<FEE<R!T
M:&%T(&1O;B=T(&UA;FEP=6QA=&4@9&%T82X*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@02!$0E]%<G)O<B!O8FIE
M8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@869F96-T9612
M;W=S*"D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/F%F9F5C=&5D.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC
M90H@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M
M92!O9B!T:&4@<V5Q=65N8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E
M;6%N9"`@=VAE;B!T<G5E+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY
M"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF
M(&ET(&1O97,@;F]T(&5X:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M('1H92!N97AT(&ED(&YU;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@
M("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@
M("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM
M;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]P9W-Q;#HZ
M8W)E871E4V5Q=65N8V4H*2P@1$)?<&=S<6PZ.F1R;W!397%U96YC92@I"B`@
M("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q7VYA;64L("1O;F1E;6%N
M9"`]('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA;64@/2`D=&AI<RT^9V5T
M4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@("`@)')E<&5A="`](&9A
M;'-E.PH@("`@("`@(&1O('L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O
M<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E
M<W5L="`])B`D=&AI<RT^<75E<GDH(E-%3$5#5"!.15A45D%,*"<D>W-E<6YA
M;65])RDB*3L*("`@("`@("`@("`@)'1H:7,M/G!O<$5R<F]R2&%N9&QI;F<H
M*3L*("`@("`@("`@("`@:68@*"1O;F1E;6%N9"`F)B!$0CHZ:7-%<G)O<B@D
M<F5S=6QT*2`F)@H@("`@("`@("`@("`@("`@)')E<W5L="T^9V5T0V]D92@I
M(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2!["B`@("`@("`@("`@("`@("`D
M<F5P96%T(#T@=')U93L*("`@("`@("`@("`@("`@("1T:&ES+3YP=7-H17)R
M;W)(86YD;&EN9RA014%27T524D]27U)%5%523BD["B`@("`@("`@("`@("`@
M("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E*"1S97%?;F%M92D[
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<&]P17)R;W)(86YD;&EN9R@I.PH@
M("`@("`@("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1R
M97-U;'0I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)')E<&5A="`](&9A;'-E.PH@("`@("`@("`@
M("!]"B`@("`@("`@?2!W:&EL92`H)')E<&5A="D["B`@("`@("`@:68@*$1"
M.CII<T5R<F]R*"1R97-U;'0I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("!]"B`@("`@("`@)&%R
M<B`]("1R97-U;'0M/F9E=&-H4F]W*$1"7T9%5$-(34]$15]/4D1%4D5$*3L*
M("`@("`@("`D<F5S=6QT+3YF<F5E*"D["B`@("`@("`@<F5T=7)N("1A<G);
M,%T["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8W)E871E4V5Q=65N
M8V4H*0H*("`@("\J*@H@("`@("H@0W)E871E<R!A(&YE=R!S97%U96YC90H@
M("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F
M('1H92!N97<@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@
M1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F-R96%T95-E<75E
M;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.86UE*"DL"B`@("`@*B`@
M("`@($1"7W!G<W%L.CIN97AT240H*2P@1$)?<&=S<6PZ.F1R;W!397%U96YC
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S97%?
M;F%M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U
M96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M
M/G%U97)Y*")#4D5!5$4@4T51545.0T4@)'MS97%N86UE?2(I.PH@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&1R;W!397%U96YC92@I"@H@("`@+RHJ"B`@("`@*B!$96QE=&5S(&$@<V5Q
M=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@
M;F%M92!O9B!T:&4@<V5Q=65N8V4@=&\@8F4@9&5L971E9`H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ9')O<%-E<75E;F-E*"DL($1"7V-O;6UO;CHZ9V5T4V5Q=65N8V5.
M86UE*"DL"B`@("`@*B`@("`@($1"7W!G<W%L.CIN97AT240H*2P@1$)?<&=S
M<6PZ.F-R96%T95-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9')O
M<%-E<75E;F-E*"1S97%?;F%M92D*("`@('L*("`@("`@("!R971U<FX@)'1H
M:7,M/G%U97)Y*"=$4D]0(%-%455%3D-%("<*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I
M*3L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!M;V1I9GE,:6UI=%%U
M97)Y*"D*"B`@("`O*BH*("`@("`J($%D9',@3$E-250@8VQA=7-E<R!T;R!A
M('%U97)Y('-T<FEN9R!A8V-O<F1I;F<@=&\@8W5R<F5N="!$0DU3('-T86YD
M87)D<PH@("`@("H*("`@("`J($!P87)A;2!S=')I;F<@)'%U97)Y("`@=&AE
M('%U97)Y('1O(&UO9&EF>0H@("`@("H@0'!A<F%M(&EN="`@("`D9G)O;2`@
M("!T:&4@<F]W('1O('-T87)T('1O(&9E=&-H:6YG("@P(#T@=&AE(&9I<G-T
M(')O=RD*("`@("`J($!P87)A;2!I;G0@("`@)&-O=6YT("`@=&AE(&YU;6)E
M<G,@;V8@<F]W<R!T;R!F971C:`H@("`@("H@0'!A<F%M(&UI>&5D("`D<&%R
M86US("!A<G)A>2P@<W1R:6YG(&]R(&YU;65R:6,@9&%T82!T;R!B92!U<V5D
M(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!E>&5C=71I;VX@
M;V8@=&AE('-T871E;65N="X@(%%U86YT:71Y(&]F(&ET96US"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("!P87-S960@;75S="!M871C:"!Q=6%N
M=&ET>2!O9B!P;&%C96AO;&1E<G,@:6X*("`@("`J("`@("`@("`@("`@("`@
M("`@("`@("`@('%U97)Y.B`@;65A;FEN9R`Q('!L86-E:&]L9&5R(&9O<B!N
M;VXM87)R87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@('!A<F%M
M971E<G,@;W(@,2!P;&%C96AO;&1E<B!P97(@87)R87D@96QE;65N="X*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE('%U97)Y('-T<FEN9R!W
M:71H($Q)34E4(&-L875S97,@861D960*("`@("`J"B`@("`@*B!`86-C97-S
M('!R;W1E8W1E9`H@("`@("HO"B`@("!F=6YC=&EO;B!M;V1I9GE,:6UI=%%U
M97)Y*"1Q=65R>2P@)&9R;VTL("1C;W5N="P@)'!A<F%M<R`](&%R<F%Y*"DI
M"B`@("!["B`@("`@("`@<F5T=7)N("(D<75E<GD@3$E-250@)&-O=6YT($]&
M1E-%5"`D9G)O;2(["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<&=S
M<6Q286ES945R<F]R*"D*"B`@("`O*BH*("`@("`J(%!R;V1U8V5S(&$@1$)?
M17)R;W(@;V)J96-T(')E9V%R9&EN9R!T:&4@8W5R<F5N="!P<F]B;&5M"B`@
M("`@*@H@("`@("H@0'!A<F%M(&EN="`D97)R;F\@(&EF('1H92!E<G)O<B!I
M<R!B96EN9R!M86YU86QL>2!R86ES960@<&%S<R!A"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@($1"7T524D]2*B!C;VYS=&%N="!H97)E+B`@268@=&AI
M<R!I<VXG="!P87-S960*("`@("`J("`@("`@("`@("`@("`@("`@("`@=&AE
M(&5R<F]R(&EN9F]R;6%T:6]N(&=A=&AE<F5D(&9R;VT@=&AE($1"35,N"B`@
M("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!$0E]%<G)O<B!O8FIE
M8W0*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<F%I<V5%<G)O<B@I
M+`H@("`@("H@("`@("!$0E]P9W-Q;#HZ97)R;W).871I=F4H*2P@1$)?<&=S
M<6PZ.F5R<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N('!G<W%L4F%I
M<V5%<G)O<B@D97)R;F\@/2!N=6QL*0H@("`@>PH@("`@("`@("1N871I=F4@
M/2`D=&AI<RT^97)R;W).871I=F4H*3L*("`@("`@("!I9B`H)&5R<FYO(#T]
M/2!N=6QL*2!["B`@("`@("`@("`@("1E<G)N;R`]("1T:&ES+3YE<G)O<D-O
M9&4H)&YA=&EV92D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<B@D97)R;F\L(&YU;&PL(&YU;&PL(&YU;&PL("1N871I=F4I
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&5R<F]R3F%T:79E*"D*
M"B`@("`O*BH*("`@("`J($=E=',@=&AE($1"35,G(&YA=&EV92!E<G)O<B!M
M97-S86=E('!R;V1U8V5D(&)Y('1H92!L87-T('%U97)Y"B`@("`@*@H@("`@
M("H@>T!I;G1E<FYA;"!%<G)O<B!M97-S86=E<R!A<F4@=7-E9"!I;G-T96%D
M(&]F(&5R<F]R(&-O9&5S(`H@("`@("H@:6X@;W)D97(@=&\@<W5P<&]R="!O
M;&1E<B!V97)S:6]N<R!O9B!0;W-T9W)E4U%,+GU]"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!$0DU3)R!E<G)O<B!M97-S86=E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&5R<F]R3F%T:79E*"D*("`@('L*("`@("`@("!R
M971U<FX@0'!G7V5R<F]R;65S<V%G92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@97)R;W)#;V1E*"D*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN97,@4$5!4CHZ1$(@97)R;W(@8V]D92!F<F]M
M('1H92!D871A8F%S92=S('1E>'0@97)R;W(@;65S<V%G92X*("`@("`J"B`@
M("`@*B!`<&%R86T@('-T<FEN9R`@)&5R<F]R;7-G("!E<G)O<B!M97-S86=E
M(')E='5R;F5D(&9R;VT@=&AE(&1A=&%B87-E"B`@("`@*B!`<F5T=7)N(&EN
M=&5G97(@(&%N(&5R<F]R(&YU;6)E<B!F<F]M(&$@1$(@97)R;W(@8V]N<W1A
M;G0*("`@("`J+PH@("`@9G5N8W1I;VX@97)R;W)#;V1E*"1E<G)O<FUS9RD*
M("`@('L*("`@("`@("!S=&%T:6,@)&5R<F]R7W)E9V5X<',["B`@("`@("`@
M:68@*"%I<W-E="@D97)R;W)?<F5G97AP<RDI('L*("`@("`@("`@("`@)&5R
M<F]R7W)E9V5X<',@/2!A<G)A>2@*("`@("`@("`@("`@("`@("<O*')E;&%T
M:6]N?'-E<75E;F-E?'1A8FQE*2XJ9&]E<R!N;W0@97AI<W1\8VQA<W,@+BH@
M;F]T(&9O=6YD+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M3D]354-(5$%"3$4L"B`@("`@("`@("`@("`@("`G+VEN9&5X("XJ(&1O97,@
M;F]T(&5X:7-T+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].
M3U1?1D]53D0L"B`@("`@("`@("`@("`@("`G+V-O;'5M;B`N*B!D;V5S(&YO
M="!E>&ES="]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27TY/
M4U5#2$9)14Q$+`H@("`@("`@("`@("`@("`@)R]R96QA=&EO;B`N*B!A;')E
M861Y(&5X:7-T<R]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7T%,4D5!1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R\H9&EV:61E?&1I
M=FES:6]N*2!B>2!Z97)O)"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"
M7T524D]27T1)5EI%4D\L"B`@("`@("`@("`@("`@("`G+W!G7V%T;VDZ(&5R
M<F]R(&EN("XJ.B!C86Y<)W0@<&%R<V4@+VDG"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?24Y604Q)1%].54U"15(L"B`@("`@("`@("`@("`@
M("`G+VEN=F%L:60@:6YP=70@<WEN=&%X(&9O<B@@='EP92D_("AI;G1E9V5R
M?&YU;65R:6,I+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M24Y604Q)1%].54U"15(L"B`@("`@("`@("`@("`@("`G+W9A;'5E("XJ(&ES
M(&]U="!O9B!R86YG92!F;W(@='EP92!<=RII;G0O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@
M("`@("`@("<O:6YT96=E<B!O=70@;V8@<F%N9V4O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E])3E9!3$E$7TY534)%4BP*("`@("`@("`@
M("`@("`@("<O=F%L=64@=&]O(&QO;F<@9F]R('1Y<&4@8VAA<F%C=&5R+VDG
M"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?24Y604Q)1"P*("`@
M("`@("`@("`@("`@("<O871T<FEB=71E("XJ(&YO="!F;W5N9'QR96QA=&EO
M;B`N*B!D;V5S(&YO="!H879E(&%T=')I8G5T92]I)PH@("`@("`@("`@("`@
M("`@("`@(#T^($1"7T524D]27TY/4U5#2$9)14Q$+`H@("`@("`@("`@("`@
M("`@)R]C;VQU;6X@+BH@<W!E8VEF:65D(&EN(%5324Y'(&-L875S92!D;V5S
M(&YO="!E>&ES="!I;B`H;&5F='QR:6=H="D@=&%B;&4O:2<*("`@("`@("`@
M("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA&245,1"P*("`@("`@("`@
M("`@("`@("<O<&%R<V5R.B!P87)S92!E<G)O<B!A="!O<B!N96%R+VDG"B`@
M("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8+`H@("`@("`@
M("`@("`@("`@)R]S>6YT87@@97)R;W(@870O)PH@("`@("`@("`@("`@("`@
M("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@("`@("<O8V]L
M=6UN(')E9F5R96YC92`N*B!I<R!A;6)I9W5O=7,O:2<*("`@("`@("`@("`@
M("`@("`@("`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@("`G
M+W!E<FUI<W-I;VX@9&5N:65D+R<*("`@("`@("`@("`@("`@("`@("`]/B!$
M0E]%4E)/4E]!0T-%4U-?5DE/3$%424].+`H@("`@("`@("`@("`@("`@)R]V
M:6]L871E<R!N;W0M;G5L;"!C;VYS=')A:6YT+R<*("`@("`@("`@("`@("`@
M("`@("`]/B!$0E]%4E)/4E]#3TY35%)!24Y47TY/5%].54Q,+`H@("`@("`@
M("`@("`@("`@)R]V:6]L871E<R!;7'<@72L@8V]N<W1R86EN="\G"B`@("`@
M("`@("`@("`@("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*("`@("`@
M("`@("`@("`@("<O<F5F97)E;G1I86P@:6YT96=R:71Y('9I;VQA=&EO;B\G
M"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?0T].4U1204E.5"P*
M("`@("`@("`@("`@("`@("<O;6]R92!E>'!R97-S:6]N<R!T:&%N('1A<F=E
M="!C;VQU;6YS+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?
M5D%,545?0T]53E1?3TY?4D]7+`H@("`@("`@("`@("`I.PH@("`@("`@('T*
M("`@("`@("!F;W)E86-H("@D97)R;W)?<F5G97AP<R!A<R`D<F5G97AP(#T^
M("1C;V1E*2!["B`@("`@("`@("`@(&EF("AP<F5G7VUA=&-H*"1R96=E>'`L
M("1E<G)O<FUS9RDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D8V]D93L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("`O+R!&86QL(&)A8VL@
M=&\@1$)?15)23U(@:68@=&AE<F4@=V%S(&YO(&UA<'!I;F<N"B`@("`@("`@
M<F5T=7)N($1"7T524D]2.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('1A8FQE26YF;R@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T
M:6]N(&%B;W5T(&$@=&%B;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@
M("H@3D]413H@;VYL>2!S=7!P;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF
M(#QV87(^)')E<W5L=#PO=F%R/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@
M("`@("H*("`@("`J($!P87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$
M0E]R97-U;'0@;V)J96-T(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG
M('1H92!N86UE(&]F(&$@=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E
M<GD@<F5S=6QT"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(')E<V]U<F-E(&ED96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@
M("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@9&5P<F5C871E
M9"X*("`@("`J($!P87)A;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A
M;&ED('1A8FQE26YF;R!M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A
M>2`@86X@87-S;V-I871I=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@
M<F5Q=65S=&5D+@H@("`@("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G1A8FQE26YF;R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF
M;R@D<F5S=6QT+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES
M7W-T<FEN9R@D<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@
M("`@*B!0<F]B86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@
M("`@("`J($-R96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@
M("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@0'!G7V5X96,H)'1H
M:7,M/F-O;FYE8W1I;VXL(")314Q%0U0@*B!&4D]-("1R97-U;'0@3$E-250@
M,"(I.PH@("`@("`@("`@("`D9V]T7W-T<FEN9R`]('1R=64["B`@("`@("`@
M?2!E;'-E:68@*&ES<V5T*"1R97-U;'0M/G)E<W5L="DI('L*("`@("`@("`@
M("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U
M;'0@;V)J96-T+@H@("`@("`@("`@("`@*B!%>'1R86-T('1H92!R97-U;'0@
M<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("HO"B`@("`@("`@
M("`@("1I9"`]("1R97-U;'0M/G)E<W5L=#L*("`@("`@("`@("`@)&=O=%]S
M=')I;F<@/2!F86QS93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O
M*@H@("`@("`@("`@("`@*B!0<F]B86)L>2!R96-E:79E9"!A(')E<W5L="!R
M97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@("`@*B!#;W!Y(&ET+@H@
M("`@("`@("`@("`@*B!$97!R96-A=&5D+B`@2&5R92!F;W(@8V]M<&%T:6)I
M;&ET>2!O;FQY+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)&ED(#T@
M)')E<W5L=#L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!F86QS93L*("`@
M("`@("!]"@H@("`@("`@(&EF("@A:7-?<F5S;W5R8V4H)&ED*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G!G<W%L4F%I<V5%<G)O<BA$0E]%4E)/
M4E].145$7TU/4D5?1$%402D["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],
M3U=%4D-!4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO
M=V5R)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC
M(#T@)W-T<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D8V]U;G0@/2!`<&=?
M;G5M9FEE;&1S*"1I9"D["B`@("`@("`@)')E<R`@(#T@87)R87DH*3L*"B`@
M("`@("`@:68@*"1M;V1E*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F:65L
M9',G72`]("1C;W5N=#L*("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1C;W5N=#L@)&DK*RD@>PH@("`@("`@("`@("`D<F5S6R1I72`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@)W1A8FQE)R`]/B`D9V]T7W-T<FEN
M9R`_("1C87-E7V9U;F,H)')E<W5L="D@.B`G)RP*("`@("`@("`@("`@("`@
M("=N86UE)R`@/3X@)&-A<V5?9G5N8RA`<&=?9FEE;&1N86UE*"1I9"P@)&DI
M*2P*("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@0'!G7V9I96QD='EP92@D
M:60L("1I*2P*("`@("`@("`@("`@("`@("=L96XG("`@/3X@0'!G7V9I96QD
M<VEZ92@D:60L("1I*2P*("`@("`@("`@("`@("`@("=F;&%G<R<@/3X@)&=O
M=%]S=')I;F<*("`@("`@("`@("`@("`@("`@("`@("`@("`@/R`D=&AI<RT^
M7W!G1FEE;&1&;&%G<R@D:60L("1I+"`D<F5S=6QT*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`Z("<G+`H@("`@("`@("`@("`I.PH@("`@("`@("`@
M("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15(I('L*("`@("`@("`@
M("`@("`@("1R97-;)V]R9&5R)UU;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),
M14E.1D]?3U)$15)404),12D@>PH@("`@("`@("`@("`@("`@)')E<ULG;W)D
M97)T86)L92==6R1R97-;)&E=6R=T86)L92==75LD<F5S6R1I75LG;F%M92==
M72`]("1I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`O+R!F
M<F5E('1H92!R97-U;'0@;VYL>2!I9B!W92!W97)E(&-A;&QE9"!O;B!A('1A
M8FQE"B`@("`@("`@:68@*"1G;W1?<W1R:6YG*2!["B`@("`@("`@("`@($!P
M9U]F<F5E<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D
M<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]P9T9I96QD1FQA
M9W,H*0H*("`@("\J*@H@("`@("H@1V5T(&$@8V]L=6UN)W,@9FQA9W,*("`@
M("`J"B`@("`@*B!3=7!P;W)T<R`B;F]T7VYU;&PB+"`B9&5F875L=%]V86QU
M92(L(")P<FEM87)Y7VME>2(L(")U;FEQ=65?:V5Y(@H@("`@("H@86YD(")M
M=6QT:7!L95]K97DB+B`@5&AE(&1E9F%U;'0@=F%L=64@:7,@<&%S<V5D('1H
M<F]U9V@*("`@("`J(')A=W5R;&5N8V]D92@I(&EN(&-A<V4@=&AE<F4@87)E
M('-P86-E<R!I;B!I="X*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1R97-O
M=7)C92`@('1H92!0;W-T9W)E4U%,(')E<W5L="!I9&5N=&EF:65R"B`@("`@
M*B!`<&%R86T@:6YT("1N=6U?9FEE;&0@('1H92!F:65L9"!N=6UB97(*("`@
M("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&9L86=S"B`@("`@*@H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P
M9T9I96QD1FQA9W,H)')E<V]U<F-E+"`D;G5M7V9I96QD+"`D=&%B;&5?;F%M
M92D*("`@('L*("`@("`@("`D9FEE;&1?;F%M92`]($!P9U]F:65L9&YA;64H
M)')E<V]U<F-E+"`D;G5M7V9I96QD*3L*"B`@("`@("`@)')E<W5L="`]($!P
M9U]E>&5C*"1T:&ES+3YC;VYN96-T:6]N+"`B4T5,14-4(&8N871T;F]T;G5L
M;"P@9BYA='1H87-D968*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!&4D]-('!G7V%T=')I8G5T92!F+"!P9U]C;&%S<R!T86(L('!G7W1Y<&4@
M='EP"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@5TA%4D4@=&%B
M+G)E;&YA;64@/2!T>7`N='EP;F%M90H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@($%.1"!T>7`N='EP<F5L:60@/2!F+F%T=')E;&ED"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@04Y$(&8N871T;F%M92`]("<D
M9FEE;&1?;F%M92<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!
M3D0@=&%B+G)E;&YA;64@/2`G)'1A8FQE7VYA;64G(BD["B`@("`@("`@:68@
M*$!P9U]N=6UR;W=S*"1R97-U;'0I(#X@,"D@>PH@("`@("`@("`@("`D<F]W
M(#T@0'!G7V9E=&-H7W)O=R@D<F5S=6QT+"`P*3L*("`@("`@("`@("`@)&9L
M86=S("`]("@D<F]W6S!=(#T]("=T)RD@/R`G;F]T7VYU;&P@)R`Z("<G.PH*
M("`@("`@("`@("`@:68@*"1R;W=;,5T@/3T@)W0G*2!["B`@("`@("`@("`@
M("`@("`D<F5S=6QT(#T@0'!G7V5X96,H)'1H:7,M/F-O;FYE8W1I;VXL(")3
M14Q%0U0@82YA9'-R8PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!&4D]-('!G7V%T=')I8G5T92!F+"!P9U]C;&%S<R!T86(L('!G7W1Y
M<&4@='EP+"!P9U]A='1R9&5F(&$*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@5TA%4D4@=&%B+G)E;&YA;64@/2!T>7`N='EP;F%M92!!
M3D0@='EP+G1Y<')E;&ED(#T@9BYA='1R96QI9`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!!3D0@9BYA='1R96QI9"`](&$N861R96QI
M9"!!3D0@9BYA='1N86UE(#T@)R1F:65L9%]N86UE)PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!!3D0@=&%B+G)E;&YA;64@/2`G)'1A
M8FQE7VYA;64G($%.1"!F+F%T=&YU;2`](&$N861N=6TB*3L*("`@("`@("`@
M("`@("`@("1R;W<@/2!`<&=?9F5T8VA?<F]W*"1R97-U;'0L(#`I.PH@("`@
M("`@("`@("`@("`@)&YU;2`]('!R96=?<F5P;&%C92@B+R<H+BHI)SHZ7'<K
M+R(L(")<7#$B+"`D<F]W6S!=*3L*("`@("`@("`@("`@("`@("1F;&%G<R`N
M/2`G9&5F875L=%\G("X@<F%W=7)L96YC;V1E*"1N=6TI("X@)R`G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&9L86=S
M(#T@)R<["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2!`<&=?97AE8R@D
M=&AI<RT^8V]N;F5C=&EO;BP@(E-%3$5#5"!I+FEN9&ES=6YI<75E+"!I+FEN
M9&ES<')I;6%R>2P@:2YI;F1K97D*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!&4D]-('!G7V%T=')I8G5T92!F+"!P9U]C;&%S<R!T86(L('!G
M7W1Y<&4@='EP+"!P9U]I;F1E>"!I"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@5TA%4D4@=&%B+G)E;&YA;64@/2!T>7`N='EP;F%M90H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@($%.1"!T>7`N='EP<F5L:60@
M/2!F+F%T=')E;&ED"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M04Y$(&8N871T<F5L:60@/2!I+FEN9')E;&ED"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@04Y$(&8N871T;F%M92`]("<D9FEE;&1?;F%M92<*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!!3D0@=&%B+G)E;&YA
M;64@/2`G)'1A8FQE7VYA;64G(BD["B`@("`@("`@)&-O=6YT(#T@0'!G7VYU
M;7)O=W,H)')E<W5L="D["@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C
M;W5N="`[("1I*RLI('L*("`@("`@("`@("`@)')O=R`]($!P9U]F971C:%]R
M;W<H)')E<W5L="P@)&DI.PH@("`@("`@("`@("`D:V5Y<R`](&5X<&QO9&4H
M)R`G+"`D<F]W6S)=*3L*"B`@("`@("`@("`@(&EF("AI;E]A<G)A>2@D;G5M
M7V9I96QD("L@,2P@)&ME>7,I*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@
M+CT@*"1R;W=;,%T@/3T@)W0G("8F("1R;W=;,5T@/3T@)V8G*2`_("=U;FEQ
M=65?:V5Y("<@.B`G)SL*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`H)')O
M=ULQ72`]/2`G="<I(#\@)W!R:6UA<GE?:V5Y("<@.B`G)SL*("`@("`@("`@
M("`@("`@(&EF("AC;W5N="@D:V5Y<RD@/B`Q*0H@("`@("`@("`@("`@("`@
M("`@("1F;&%G<R`N/2`G;75L=&EP;&5?:V5Y("<["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<FEM*"1F;&%G<RD["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9V5T4W!E8VEA;%%U97)Y*"D*"B`@
M("`O*BH*("`@("`J($]B=&%I;G,@=&AE('%U97)Y('-T<FEN9R!N965D960@
M9F]R(&QI<W1I;F<@82!G:79E;B!T>7!E(&]F(&]B:F5C=',*("`@("`J"B`@
M("`@*B!`<&%R86T@<W1R:6YG("1T>7!E("!T:&4@:VEN9"!O9B!O8FIE8W1S
M('EO=2!W86YT('1O(')E=')I979E"B`@("`@*@H@("`@("H@0')E='5R;B!S
M=')I;F<@('1H92!344P@<75E<GD@<W1R:6YG(&]R(&YU;&P@:68@=&AE(&1R
M:79E<B!D;V5S;B=T"B`@("`@*B`@("`@("`@("`@("`@("`@('-U<'!O<G0@
M=&AE(&]B:F5C="!T>7!E(')E<75E<W1E9`H@("`@("H*("`@("`J($!A8V-E
M<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ9V5T3&ES=$]F
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T4W!E8VEA;%%U97)Y*"1T>7!E
M*0H@("`@>PH@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@("`@("`@("`@
M8V%S92`G=&%B;&5S)SH*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4
M(&,N<F5L;F%M92!!4R`B3F%M92(G"B`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R!&4D]-('!G7V-L87-S(&,L('!G7W5S97(@=2<*("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G(%=(15)%(&,N<F5L;W=N97(@/2!U+G5S97-Y<VED
M)PH@("`@("`@("`@("`@("`@("`@("`@("`N("(@04Y$(&,N<F5L:VEN9"`]
M("=R)R(*("`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.1"!.3U0@15A)
M4U13)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@*%-%3$5#5"`Q($92
M3TT@<&=?=FEE=W,G"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R`@5TA%
M4D4@=FEE=VYA;64@/2!C+G)E;&YA;64I)PH@("`@("`@("`@("`@("`@("`@
M("`@("`N("(@04Y$(&,N<F5L;F%M92`A?B`G7BAP9U]\<W%L7RDG(@H@("`@
M("`@("`@("`@("`@("`@("`@("`N("<@54Y)3TXG"B`@("`@("`@("`@("`@
M("`@("`@("`@("X@)R!314Q%0U0@8RYR96QN86UE($%3(").86UE(B<*("`@
M("`@("`@("`@("`@("`@("`@("`@+B`G($923TT@<&=?8VQA<W,@8R<*("`@
M("`@("`@("`@("`@("`@("`@("`@+B`B(%=(15)%(&,N<F5L:VEN9"`]("=R
M)R(*("`@("`@("`@("`@("`@("`@("`@("`@+B`G($%.1"!.3U0@15A)4U13
M)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@*%-%3$5#5"`Q($923TT@
M<&=?=FEE=W,G"B`@("`@("`@("`@("`@("`@("`@("`@("X@)R`@5TA%4D4@
M=FEE=VYA;64@/2!C+G)E;&YA;64I)PH@("`@("`@("`@("`@("`@("`@("`@
M("`N("<@04Y$($Y/5"!%6$E35%,G"B`@("`@("`@("`@("`@("`@("`@("`@
M("X@)R`H4T5,14-4(#$@1E)/32!P9U]U<V5R)PH@("`@("`@("`@("`@("`@
M("`@("`@("`N("<@(%=(15)%('5S97-Y<VED(#T@8RYR96QO=VYE<BDG"B`@
M("`@("`@("`@("`@("`@("`@("`@("X@(B!!3D0@8RYR96QN86UE("%^("=>
M<&=?)R(["B`@("`@("`@("`@(&-A<V4@)W-C:&5M82YT86)L97,G.@H@("`@
M("`@("`@("`@("`@<F5T=7)N(")314Q%0U0@<V-H96UA;F%M92!\?"`G+B<@
M?'P@=&%B;&5N86UE(@H@("`@("`@("`@("`@("`@("`@("`@("`N("<@05,@
M(DYA;64B)PH@("`@("`@("`@("`@("`@("`@("`@("`N("<@1E)/32!P9U]C
M871A;&]G+G!G7W1A8FQE<R<*("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(%=(15)%('-C:&5M86YA;64@3D]4($E.)PH@("`@("`@("`@("`@("`@("`@
M("`@("`N("(@*"=P9U]C871A;&]G)RP@)VEN9F]R;6%T:6]N7W-C:&5M82<L
M("=P9U]T;V%S="<I(CL*("`@("`@("`@("`@8V%S92`G=FEE=W,G.@H@("`@
M("`@("`@("`@("`@+R\@5&%B;&4@8V]L<SH@=FEE=VYA;64@?"!V:65W;W=N
M97(@?"!D969I;FET:6]N"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#
M5"!V:65W;F%M92!F<F]M('!G7W9I97=S(%=(15)%('-C:&5M86YA;64G"B`@
M("`@("`@("`@("`@("`@("`@("`@("X@(B!.3U0@24X@*"=I;F9O<FUA=&EO
M;E]S8VAE;6$G+"`G<&=?8V%T86QO9R<I(CL*("`@("`@("`@("`@8V%S92`G
M=7-E<G,G.@H@("`@("`@("`@("`@("`@+R\@8V]L<SH@=7-E;F%M92!\=7-E
M<WES:61\=7-E8W)E871E9&)\=7-E=')A8V5\=7-E<W5P97)\=7-E8V%T=7!D
M?'!A<W-W9"`@?'9A;'5N=&EL"B`@("`@("`@("`@("`@("!R971U<FX@)U-%
M3$5#5"!U<V5N86UE($923TT@<&=?=7-E<B<["B`@("`@("`@("`@(&-A<V4@
M)V1A=&%B87-E<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@)U-%3$5#5"!D
M871N86UE($923TT@<&=?9&%T86)A<V4G.PH@("`@("`@("`@("!C87-E("=F
M=6YC=&EO;G,G.@H@("`@("`@("`@("!C87-E("=P<F]C961U<F5S)SH*("`@
M("`@("`@("`@("`@(')E='5R;B`G4T5,14-4('!R;VYA;64@1E)/32!P9U]P
M<F]C(%=(15)%('!R;V]W;F5R(#P^(#$G.PH@("`@("`@("`@("!D969A=6QT
M.@H@("`@("`@("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@?0H@("`@
M?0H*("`@("\O('U]?0H*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T
M86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*
M"C\^"@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O<WEB87-E+G!H<```
M````````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`V-C0P
M,R`Q,#4Q-30S-#$S,R`P,C`W-38`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A
M8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO
M*BH*("H@5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!S>6)A<V4@97AT
M96YS:6]N"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H(%-Y8F%S92!D871A8F%S
M97,*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F
M('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H
M('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A
M;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P
M;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E
M9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@
M("`@(%-T97)L:6YG($AU9VAE<R`\<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U
M=&AO<B`@("`@06YT]&YI;R!#87)L;W,@5F5NXFYC:6\@2OIN:6]R(#QF;&]R
M:7!A0'!H<"YN970^"B`J($!A=71H;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@
M/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N
M("`@($-64SH@)$ED.B!S>6)A<V4N<&AP+'8@,2XW."`R,#`U+S`R+S(P(#`P
M.C0T.C0X(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@
M1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J
M+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M
M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S('-Y
M8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T:6YG('=I=&@@4WEB87-E
M(&1A=&%B87-E<PH@*@H@*B!4:&5S92!M971H;V1S(&]V97)L;V%D('1H92!O
M;F5S(&1E8VQA<F5D(&EN($1"7V-O;6UO;BX*("H*("H@5T%23DE.1SH@(%1H
M:7,@9')I=F5R(&UA>2!F86EL('=I=&@@;75L=&EP;&4@8V]N;F5C=&EO;G,@
M=6YD97(@=&AE"B`J('-A;64@=7-E<B]P87-S+VAO<W0@86YD(&1I9F9E<F5N
M="!D871A8F%S97,N"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P
M86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%-T97)L:6YG($AU9VAE<R`\
M<W1E<FQI;F=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@06YT]&YI;R!#87)L
M;W,@5F5NXFYC:6\@2OIN:6]R(#QF;&]R:7!A0'!H<"YN970^"B`J($!A=71H
M;W(@("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@
M0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N
M<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0
M($QI8V5N<V4@,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J
M($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@
M*B\*8VQA<W,@1$)?<WEB87-E(&5X=&5N9',@1$)?8V]M;6]N"GL*("`@("\O
M('M[>R!P<F]P97)T:65S"@H@("`@+RHJ"B`@("`@*B!4:&4@1$(@9')I=F5R
M('1Y<&4@*&UY<W%L+"!O8VDX+"!O9&)C+"!E=&,N*0H@("`@("H@0'9A<B!S
M=')I;F<*("`@("`J+PH@("`@=F%R("1P:'!T>7!E(#T@)W-Y8F%S92<["@H@
M("`@+RHJ"B`@("`@*B!4:&4@9&%T86)A<V4@<WEN=&%X('9A<FEA;G0@=&\@
M8F4@=7-E9"`H9&(R+"!A8V-E<W,L(&5T8RXI+"!I9B!A;GD*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D9&)S>6YT87@@/2`G<WEB87-E
M)SL*"B`@("`O*BH*("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$
M0B!I;7!L96UE;G1A=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG
M(&5L96UE;G0@8V]N=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@
M<')O=FED960*("`@("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-
M4RX@($-O;G1A:6YS(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@
M*@H@("`@("H@365A;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@
M("H@("`K("=E;75L871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@
M;G5M8F5R"B`@("`@*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y
M"B`@("`@*B`@("L@9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R
M87DH"B`@("`@("`@)VQI;6ET)R`@("`@("`@(#T^("=E;75L871E)RP*("`@
M("`@("`G;F5W7VQI;FLG("`@("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O
M=W,G("`@("`@(#T^('1R=64L"B`@("`@("`@)W!C;VYN96-T)R`@("`@(#T^
M('1R=64L"B`@("`@("`@)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("=S<VPG("`@("`@("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A
M8W1I;VYS)R`@/3X@=')U92P*("`@("D["@H@("`@+RHJ"B`@("`@*B!!(&UA
M<'!I;F<@;V8@;F%T:79E(&5R<F]R(&-O9&5S('1O($1"(&5R<F]R(&-O9&5S
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D97)R;W)C;V1E
M7VUA<"`](&%R<F%Y*`H@("`@*3L*"B`@("`O*BH*("`@("`J(%1H92!R87<@
M9&%T86)A<V4@8V]N;F5C=&EO;B!C<F5A=&5D(&)Y(%!(4`H@("`@("H@0'9A
M<B!R97-O=7)C90H@("`@("HO"B`@("!V87(@)&-O;FYE8W1I;VX["@H@("`@
M+RHJ"B`@("`@*B!4:&4@1%-.(&EN9F]R;6%T:6]N(&9O<B!C;VYN96-T:6YG
M('1O(&$@9&%T86)A<V4*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1D<VX@/2!A<G)A>2@I.PH*"B`@("`O*BH*("`@("`J(%-H;W5L9"!D
M871A(&UA;FEP=6QA=&EO;B!Q=65R:65S(&)E(&-O;6UI='1E9"!A=71O;6%T
M:6-A;&QY/PH@("`@("H@0'9A<B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J+PH@("`@=F%R("1A=71O8V]M;6ET(#T@=')U93L*"B`@("`O
M*BH*("`@("`J(%1H92!Q=6%N=&ET>2!O9B!T<F%N<V%C=&EO;G,@8F5G=6X*
M("`@("`J"B`@("`@*B![0&EN=&5R;F%L("!7:&EL92!T:&ES(&ES('!R:79A
M=&4L(&ET(&-A;B=T(&%C='5A;&QY(&)E(&1E<VEG;F%T960*("`@("`J('!R
M:79A=&4@:6X@4$A0(#4@8F5C875S92!I="!I<R!D:7)E8W1L>2!A8V-E<W-E
M9"!I;B!T:&4@=&5S="!S=6ET92Y]?0H@("`@("H*("`@("`J($!V87(@:6YT
M96=E<@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M=')A;G-A8W1I;VY?;W!C;W5N="`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@
M9&%T86)A<V4@<W!E8VEF:65D(&EN('1H92!$4TX*("`@("`J"B`@("`@*B!)
M="=S(&$@9FEX('1O(&%L;&]W(&-A;&QS('1O(&1I9F9E<F5N="!D871A8F%S
M97,@:6X@=&AE('-A;64@<V-R:7!T+@H@("`@("H*("`@("`J($!V87(@<W1R
M:6YG"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@=F%R("1?
M9&(@/2`G)SL*"@H@("`@+R\@?7U]"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*
M"B`@("`O*BH*("`@("`J(%1H:7,@8V]N<W1R=6-T;W(@8V%L;',@/&MB9#XD
M=&AI<RT^1$)?8V]M;6]N*"D\+VMB9#X*("`@("`J"B`@("`@*B!`<F5T=7)N
M('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@1$)?<WEB87-E*"D*("`@('L*
M("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN96-T
M('1O('1H92!D871A8F%S92!S97)V97(L(&QO9R!I;B!A;F0@;W!E;B!T:&4@
M9&%T86)A<V4*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D
M(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J
M"B`@("`@*B!014%2($1")W,@<WEB87-E(&1R:79E<B!S=7!P;W)T<R!T:&4@
M9F]L;&]W:6YG(&5X=')A($133B!O<'1I;VYS.@H@("`@("H@("`K(&%P<&YA
M;64@("`@("`@5&AE(&%P<&QI8V%T:6]N(&YA;64@=&\@=7-E(&]N('1H:7,@
M8V]N;F5C=&EO;BX*("`@("`J("`@("`@("`@("`@("`@("`@($%V86EL86)L
M92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H@("`K(&-H87)S970@("`@
M("`@5&AE(&-H87)A8W1E<B!S970@=&\@=7-E(&]N('1H:7,@8V]N;F5C=&EO
M;BX*("`@("`J("`@("`@("`@("`@("`@("`@($%V86EL86)L92!S:6YC92!0
M14%2($1"(#$N-RXP+@H@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9'-N
M("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J($!P87)A;2!B
M;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T:6]N(&)E('!E
M<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"7T]+(&]N
M('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F
M86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH
M)W-Y8F%S92<I("8F"B`@("`@("`@("`@("%014%2.CIL;V%D17AT96YS:6]N
M*"=S>6)A<V5?8W0G*2D*("`@("`@("!["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$
M*3L*("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@
M("`@(&EF("@D9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES
M+3YD8G-Y;G1A>"`]("1D<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@
M("`@("`D9'-N6R=H;W-T<W!E8R==(#T@)&1S;ELG:&]S='-P96,G72`_("1D
M<VY;)VAO<W1S<&5C)UT@.B`G;&]C86QH;W-T)SL*("`@("`@("`D9'-N6R=P
M87-S=V]R9"==(#T@(65M<'1Y*"1D<VY;)W!A<W-W;W)D)UTI(#\@)&1S;ELG
M<&%S<W=O<F0G72`Z(&9A;'-E.PH@("`@("`@("1D<VY;)V-H87)S970G72`]
M(&ES<V5T*"1D<VY;)V-H87)S970G72D@/R`D9'-N6R=C:&%R<V5T)UT@.B!F
M86QS93L*("`@("`@("`D9'-N6R=A<'!N86UE)UT@/2!I<W-E="@D9'-N6R=A
M<'!N86UE)UTI(#\@)&1S;ELG87!P;F%M92==(#H@9F%L<V4["@H@("`@("`@
M("1C;VYN96-T7V9U;F-T:6]N(#T@)'!E<G-I<W1E;G0@/R`G<WEB87-E7W!C
M;VYN96-T)R`Z("=S>6)A<V5?8V]N;F5C="<["@H@("`@("`@(&EF("@D9'-N
M6R=U<V5R;F%M92==*2!["B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N
M(#T@0"1C;VYN96-T7V9U;F-T:6]N*"1D<VY;)VAO<W1S<&5C)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D<VY;)W5S97)N86UE)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1D<VY;)W!A<W-W;W)D)UTL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1D<VY;)V-H87)S970G72P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG87!P;F%M92==*3L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A
M:7-E17)R;W(H1$)?15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1H92!$4TX@
M9&ED(&YO="!C;VYT86EN(&$@=7-E<FYA;64N)RD["B`@("`@("`@?0H*("`@
M("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%
M1"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL
M(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!`<WEB87-E7V=E=%]L87-T7VUE<W-A9V4H*2D["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("!I
M9B`H(4!S>6)A<V5?<V5L96-T7V1B*"1D<VY;)V1A=&%B87-E)UTL("1T:&ES
M+3YC;VYN96-T:6]N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES
M+3YR86ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N
M=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M($!S>6)A<V5?9V5T7VQA<W1?;65S<V%G92@I*3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D=&AI<RT^7V1B(#T@)&1S;ELG9&%T86)A<V4G73L*("`@
M("`@("!]"@H@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]
M?7T*("`@("\O('M[>R!D:7-C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I
M<V-O;FYE8W1S(&9R;VT@=&AE(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"`@5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F
M86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@
M>PH@("`@("`@("1R970@/2!`<WEB87-E7V-L;W-E*"1T:&ES+3YC;VYN96-T
M:6]N*3L*("`@("`@("`D=&AI<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@
M("`@<F5T=7)N("1R970["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<VEM<&QE475E<GDH*0H*("`@("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T
M;R!T:&4@9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M('-T
M<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C8V5S
M<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!T
M:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E<FEE
M<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y*"1Q
M=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP*"1Q
M=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD["B`@
M("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI
M<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS
M>6)A<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@
M("`@?0H@("`@("`@("1Q=65R>2`]("1T:&ES+3YM;V1I9GE1=65R>2@D<75E
M<GDI.PH@("`@("`@(&EF("@A)'1H:7,M/F%U=&]C;VUM:70@)B8@)&ES;6%N
M:7`I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YT<F%N<V%C=&EO;E]O<&-O
M=6YT(#T](#`I('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2!`<WEB87-E
M7W%U97)Y*"="14=)3B!44D%.4T%#5$E/3B<L("1T:&ES+3YC;VYN96-T:6]N
M*3L*("`@("`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<B@I.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@("1T
M:&ES+3YT<F%N<V%C=&EO;E]O<&-O=6YT*RL["B`@("`@("`@?0H@("`@("`@
M("1R97-U;'0@/2!`<WEB87-E7W%U97)Y*"1Q=65R>2P@)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H*3L*("`@("`@("!]"B`@
M("`@("`@:68@*&ES7W)E<V]U<F-E*"1R97-U;'0I*2!["B`@("`@("`@("`@
M(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*("`@("`@("`O+R!$971E<FUI
M;F4@=VAI8V@@<75E<FEE<R!T:&%T('-H;W5L9"!R971U<FX@9&%T82P@86YD
M('=H:6-H"B`@("`@("`@+R\@<VAO=6QD(')E='5R;B!A;B!E<G)O<B!C;V1E
M(&]N;'DN"B`@("`@("`@<F5T=7)N("1I<VUA;FEP(#\@1$)?3TL@.B`D<F5S
M=6QT.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YE>'1297-U;'0H
M*0H*("`@("\J*@H@("`@("H@36]V92!T:&4@:6YT97)N86P@<WEB87-E(')E
M<W5L="!P;VEN=&5R('1O('1H92!N97AT(&%V86EL86)L92!R97-U;'0*("`@
M("`J"B`@("`@*B!`<&%R86T@82!V86QI9"!S>6)A<V4@<F5S=6QT(')E<V]U
M<F-E"B`@("`@*@H@("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("`J"B`@("`@
M*B!`<F5T=7)N('1R=64@:68@82!R97-U;'0@:7,@879A:6QA8FQE(&]T:&5R
M=VES92!R971U<FX@9F%L<V4*("`@("`J+PH@("`@9G5N8W1I;VX@;F5X=%)E
M<W5L="@D<F5S=6QT*0H@("`@>PH@("`@("`@(')E='5R;B!F86QS93L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F971C:$EN=&\H*0H*("`@("\J
M*@H@("`@("H@4&QA8V5S(&$@<F]W(&9R;VT@=&AE(')E<W5L="!S970@:6YT
M;R!T:&4@9VEV96X@87)R87D*("`@("`J"B`@("`@*B!&;W)M871I;F<@;V8@
M=&AE(&%R<F%Y(&%N9"!T:&4@9&%T82!T:&5R96EN(&%R92!C;VYF:6=U<F%B
M;&4N"B`@("`@*B!3964@1$)?<F5S=6QT.CIF971C:$EN=&\H*2!F;W(@;6]R
M92!I;F9O<FUA=&EO;BX*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N
M;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$
M0E]R97-U;'0Z.F9E=&-H26YT;R@I(&EN<W1E860N("!)="!C86XG="!B92!D
M96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R97-U;'0@
M:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A<F%M(')E
M<V]U<F-E("1R97-U;'0@("`@=&AE('%U97)Y(')E<W5L="!R97-O=7)C90H@
M("`@("H@0'!A<F%M(&%R<F%Y("`@("1A<G(@("`@("`@=&AE(')E9F5R96YC
M960@87)R87D@=&\@<'5T('1H92!D871A(&EN"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)&9E=&-H;6]D92!H;W<@=&AE(')E<W5L=&EN9R!A<G)A>2!S:&]U
M;&0@8F4@:6YD97AE9`H@("`@("H@0'!A<F%M(&EN="`@("`@("1R;W=N=6T@
M("`@=&AE(')O=R!N=6UB97(@=&\@9F5T8V@@*#`@/2!F:7)S="!R;W<I"B`@
M("`@*@H@("`@("H@0')E='5R;B!M:7AE9"`@1$)?3TL@;VX@<W5C8V5S<RP@
M3E5,3"!W:&5N('1H92!E;F0@;V8@82!R97-U;'0@<V5T(&ES"B`@("`@*B`@
M("`@("`@("`@("`@("`@<F5A8VAE9"!O<B!O;B!F86EL=7)E"B`@("`@*@H@
M("`@("H@0'-E92!$0E]R97-U;'0Z.F9E=&-H26YT;R@I"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&9E=&-H26YT;R@D<F5S=6QT+"`F)&%R<BP@)&9E=&-H;6]D
M92P@)')O=VYU;2`](&YU;&PI"B`@("!["B`@("`@("`@:68@*"1R;W=N=6T@
M(3T](&YU;&PI('L*("`@("`@("`@("`@:68@*"%`<WEB87-E7V1A=&%?<V5E
M:R@D<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1F
M971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I('L*("`@("`@("`@("`@
M:68@*&9U;F-T:6]N7V5X:7-T<R@G<WEB87-E7V9E=&-H7V%S<V]C)RDI('L*
M("`@("`@("`@("`@("`@("1A<G(@/2!`<WEB87-E7V9E=&-H7V%S<V]C*"1R
M97-U;'0I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M:68@*"1A<G(@/2!`<WEB87-E7V9E=&-H7V%R<F%Y*"1R97-U;'0I*2!["B`@
M("`@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%R<B!A<R`D:V5Y(#T^("1V
M86QU92D@>PH@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?:6YT*"1K
M97DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!U;G-E="@D87)R
M6R1K97E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@
M)B!$0E]03U)404))3$E465],3U=%4D-!4T4@)B8@)&%R<BD@>PH@("`@("`@
M("`@("`@("`@)&%R<B`](&%R<F%Y7V-H86YG95]K97E?8V%S92@D87)R+"!#
M05-%7TQ/5T52*3L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A<G(@/2!`<WEB87-E7V9E=&-H7W)O=R@D<F5S=6QT*3L*
M("`@("`@("!]"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@("`@("`@(')E
M='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO
M;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@
M("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H)&%R<BD["B`@
M("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI
M='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI('L*("`@("`@
M("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S5&]%;7!T>2@D
M87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&9R965297-U;'0H*0H*("`@("\J*@H@
M("`@("H@1&5L971E<R!T:&4@<F5S=6QT('-E="!A;F0@9G)E97,@=&AE(&UE
M;6]R>2!O8V-U<&EE9"!B>2!T:&4@<F5S=6QT('-E=`H@("`@("H*("`@("`J
M(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T
M;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9G)E92@I(&EN<W1E860N("!)
M="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S
M92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@
M("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L
M="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@5%)512!O
M;B!S=6-C97-S+"!&04Q312!I9B`D<F5S=6QT(&ES(&EN=F%L:60*("`@("`J
M"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9G)E92@I"B`@("`@*B\*("`@(&9U
M;F-T:6]N(&9R965297-U;'0H)')E<W5L="D*("`@('L*("`@("`@("!R971U
M<FX@0'-Y8F%S95]F<F5E7W)E<W5L="@D<F5S=6QT*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!N=6U#;VQS*"D*"B`@("`O*BH*("`@("`J($=E
M=',@=&AE(&YU;6)E<B!O9B!C;VQU;6YS(&EN(&$@<F5S=6QT('-E=`H@("`@
M("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL
M960@9&ER96-T;'DN("!5<V4*("`@("`J($1"7W)E<W5L=#HZ;G5M0V]L<R@I
M(&EN<W1E860N("!)="!C86XG="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@
M("`@("H@8F5C875S92!$0E]R97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N
M"B`@("`@*@H@("`@("H@0'!A<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S
M('%U97)Y(')E<W5L="!R97-O=7)C90H@("`@("H*("`@("`J($!R971U<FX@
M:6YT("!T:&4@;G5M8F5R(&]F(&-O;'5M;G,N("!!($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?<F5S=6QT.CIN
M=6U#;VQS*"D*("`@("`J+PH@("`@9G5N8W1I;VX@;G5M0V]L<R@D<F5S=6QT
M*0H@("`@>PH@("`@("`@("1C;VQS(#T@0'-Y8F%S95]N=6U?9FEE;&1S*"1R
M97-U;'0I.PH@("`@("`@(&EF("@A)&-O;',I('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*"D["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D8V]L<SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!N=6U2;W=S*"D*"B`@("`O*BH*("`@("`J($=E=',@=&AE(&YU;6)E<B!O
M9B!R;W=S(&EN(&$@<F5S=6QT('-E=`H@("`@("H*("`@("`J(%1H:7,@;65T
M:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN("!5<V4*
M("`@("`J($1"7W)E<W5L=#HZ;G5M4F]W<R@I(&EN<W1E860N("!)="!C86XG
M="!B92!D96-L87)E9"`B<')O=&5C=&5D(@H@("`@("H@8F5C875S92!$0E]R
M97-U;'0@:7,@82!S97!A<F%T92!O8FIE8W0N"B`@("`@*@H@("`@("H@0'!A
M<F%M(')E<V]U<F-E("1R97-U;'0@(%!(4"=S('%U97)Y(')E<W5L="!R97-O
M=7)C90H@("`@("H*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M8F5R(&]F
M(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E+@H@("`@("H*
M("`@("`J($!S964@1$)?<F5S=6QT.CIN=6U2;W=S*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@;G5M4F]W<R@D<F5S=6QT*0H@("`@>PH@("`@("`@("1R;W=S
M(#T@0'-Y8F%S95]N=6U?<F]W<R@D<F5S=6QT*3L*("`@("`@("!I9B`H)')O
M=W,@/3T](&9A;'-E*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<WEB
M87-E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')O
M=W,["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T9612;W=S
M*"D*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE(&YU;6)E<B!O9B!R
M;W=S(&%F9F5C=&5D(&)Y(&$@9&%T82!M86YI=7!L871I;VX@<75E<GD*("`@
M("`J"B`@("`@*B`P(&ES(')E='5R;F5D(&9O<B!Q=65R:65S('1H870@9&]N
M)W0@;6%N:7!U;&%T92!D871A+@H@("`@("H*("`@("`J($!R971U<FX@:6YT
M("!T:&4@;G5M8F5R(&]F(')O=W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F
M86EL=7)E+@H@("`@("HO"B`@("!F=6YC=&EO;B!A9F9E8W1E9%)O=W,H*0H@
M("`@>PH@("`@("`@(&EF("A$0CHZ:7--86YI<"@D=&AI<RT^;&%S=%]Q=65R
M>2DI('L*("`@("`@("`@("`@)')E<W5L="`]($!S>6)A<V5?869F96-T961?
M<F]W<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@)')E<W5L="`](#`["B`@("`@("`@?0H@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!N97AT
M260H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@;F5X="!F<F5E(&ED
M(&EN(&$@<V5Q=65N8V4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("`D
M<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E"B`@("`@*B!`<&%R86T@
M8F]O;&5A;B`D;VYD96UA;F0@('=H96X@=')U92P@=&AE('-E<65N8V4@:7,@
M875T;VUA=&EC86QL>0H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8W)E871E9"!I9B!I="!D;V5S(&YO="!E>&ES=`H@("`@("H*("`@("`J
M($!R971U<FX@:6YT("!T:&4@;F5X="!I9"!N=6UB97(@:6X@=&AE('-E<75E
M;F-E+@H@("`@("H@("`@("`@("`@("`@("!!($1"7T5R<F]R(&]B:F5C="!O
M;B!F86EL=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIN97AT
M240H*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@
M("`@1$)?<WEB87-E.CIC<F5A=&5397%U96YC92@I+"!$0E]S>6)A<V4Z.F1R
M;W!397%U96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&YE>'1)9"@D<V5Q
M7VYA;64L("1O;F1E;6%N9"`]('1R=64I"B`@("!["B`@("`@("`@)'-E<6YA
M;64@/2`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92D["B`@("`@
M("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI<RT^7V1B+"`D=&AI<RT^
M8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A
M<V5286ES945R<F]R*$1"7T524D]27TY/1$)314Q%0U1%1"D["B`@("`@("`@
M?0H@("`@("`@("1R97!E870@/2`P.PH@("`@("`@(&1O('L*("`@("`@("`@
M("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4D5455).
M*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES+3YQ=65R>2@B24Y315)4
M($E.5$\@)'-E<6YA;64@*'9A<&]R*2!604Q515,@*#`I(BD["B`@("`@("`@
M("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D["B`@("`@("`@("`@(&EF
M("@D;VYD96UA;F0@)B8@1$(Z.FES17)R;W(H)')E<W5L="D@)B8*("`@("`@
M("`@("`@("`@("@D<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U(@?'P@
M)')E<W5L="T^9V5T0V]D92@I(#T]($1"7T524D]27TY/4U5#2%1!0DQ%*2D*
M("`@("`@("`@("`@>PH@("`@("`@("`@("`@("`@)')E<&5A="`](#$["B`@
M("`@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/F-R96%T95-E<75E;F-E
M*"1S97%?;F%M92D["B`@("`@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M
M/G)A:7-E17)R;W(H)')E<W5L="D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T@96QS96EF("@A1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@("`@("1R97-U;'0@/28@)'1H:7,M/G%U97)Y*")314Q%0U0@
M0$!)1$5.5$E462!&4D]-("1S97%N86UE(BD["B`@("`@("`@("`@("`@("`D
M<F5P96%T(#T@,#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1R97!E870@/2!F86QS93L*("`@("`@("`@("`@?0H@("`@("`@('T@
M=VAI;&4@*"1R97!E870I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S
M=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H
M)')E<W5L="D["B`@("`@("`@?0H@("`@("`@("1R97-U;'0@/2`D<F5S=6QT
M+3YF971C:%)O=RA$0E]&151#2$U/1$5?3U)$15)%1"D["B`@("`@("`@<F5T
M=7)N("1R97-U;'1;,%T["B`@("!]"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S
M(&$@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M<V5Q7VYA;64@(&YA;64@;V8@=&AE(&YE=R!S97%U96YC90H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O
M;6UO;CHZ8W)E871E4V5Q=65N8V4H*2P@1$)?8V]M;6]N.CIG971397%U96YC
M94YA;64H*2P*("`@("`J("`@("`@1$)?<WEB87-E.CIN97AT240H*2P@1$)?
M<WEB87-E.CID<F]P4V5Q=65N8V4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!C
M<F5A=&5397%U96YC92@D<V5Q7VYA;64I"B`@("!["B`@("`@("`@<F5T=7)N
M("1T:&ES+3YQ=65R>2@G0U)%051%(%1!0DQ%("<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA
M;64I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@*&ED(&YU;65R
M:6,H,3`L(#`I($E$14Y42519($Y/5"!.54Q,+"<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)R!V87!O<B!I;G0@3E5,3"DG*3L*("`@('T*"B`@
M("`O+R!]?7T*("`@("\O('M[>R!D<F]P4V5Q=65N8V4H*0H*("`@("\J*@H@
M("`@("H@1&5L971E<R!A('-E<75E;F-E"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`D<V5Q7VYA;64@(&YA;64@;V8@=&AE('-E<75E;F-E('1O(&)E
M(&1E;&5T960*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@
M<W5C8V5S<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.F1R;W!397%U96YC92@I+"!$0E]C
M;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@("`@("!$0E]S>6)A
M<V4Z.FYE>'1)1"@I+"!$0E]S>6)A<V4Z.F-R96%T95-E<75E;F-E*"D*("`@
M("`J+PH@("`@9G5N8W1I;VX@9')O<%-E<75E;F-E*"1S97%?;F%M92D*("`@
M('L*("`@("`@("!R971U<FX@)'1H:7,M/G%U97)Y*"=$4D]0(%1!0DQ%("<@
M+B`D=&AI<RT^9V5T4V5Q=65N8V5.86UE*"1S97%?;F%M92DI.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[(&%U=&]#;VUM:70H*0H*("`@("\J*@H@
M("`@("H@16YA8FQE<R!O<B!D:7-A8FQE<R!A=71O;6%T:6,@8V]M;6ET<PH@
M("`@("H*("`@("`J($!P87)A;2!B;V]L("1O;F]F9B`@=')U92!T=7)N<R!I
M="!O;BP@9F%L<V4@='5R;G,@:70@;V9F"B`@("`@*@H@("`@("H@0')E='5R
M;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!I
M9B!T:&4@9')I=F5R"B`@("`@*B`@("`@("`@("`@("`@(&1O97-N)W0@<W5P
M<&]R="!A=71O+6-O;6UI='1I;F<@=')A;G-A8W1I;VYS+@H@("`@("HO"B`@
M("!F=6YC=&EO;B!A=71O0V]M;6ET*"1O;F]F9B`](&9A;'-E*0H@("`@>PH@
M("`@("`@("\O(%A86"!I9B`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N="`^
M(#`L('=E('-H;W5L9"!P<F]B86)L>0H@("`@("`@("\O(&ES<W5E(&$@=V%R
M;FEN9R!H97)E+@H@("`@("`@("1T:&ES+3YA=71O8V]M;6ET(#T@)&]N;V9F
M(#\@=')U92`Z(&9A;'-E.PH@("`@("`@(')E='5R;B!$0E]/2SL*("`@('T*
M"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VUM:70H*0H*("`@("\J*@H@("`@
M("H@0V]M;6ET<R!T:&4@8W5R<F5N="!T<F%N<V%C=&EO;@H@("`@("H*("`@
M("`J($!R971U<FX@:6YT("!$0E]/2R!O;B!S=6-C97-S+B`@02!$0E]%<G)O
M<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J+PH@("`@9G5N8W1I;VX@8V]M
M;6ET*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T:6]N7V]P
M8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@A0'-Y8F%S95]S96QE8W1?
M9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@("`@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H1$)?15)2
M3U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M<F5S=6QT(#T@0'-Y8F%S95]Q=65R>2@G0T]-34E4)RP@)'1H:7,M/F-O;FYE
M8W1I;VXI.PH@("`@("`@("`@("`D=&AI<RT^=')A;G-A8W1I;VY?;W!C;W5N
M="`](#`["B`@("`@("`@("`@(&EF("@A)')E<W5L="D@>PH@("`@("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*"D["B`@("`@
M("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[(')O;&QB86-K*"D*"B`@("`O*BH*
M("`@("`J(%)E=F5R=',@=&AE(&-U<G)E;G0@=')A;G-A8W1I;VX*("`@("`J
M"B`@("`@*B!`<F5T=7)N(&EN="`@1$)?3TL@;VX@<W5C8V5S<RX@($$@1$)?
M17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')O;&QB86-K*"D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/G1R86YS86-T
M:6]N7V]P8V]U;G0@/B`P*2!["B`@("`@("`@("`@(&EF("@A0'-Y8F%S95]S
M96QE8W1?9&(H)'1H:7,M/E]D8BP@)'1H:7,M/F-O;FYE8W1I;VXI*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H
M1$)?15)23U)?3D]$0E-%3$5#5$5$*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("`D<F5S=6QT(#T@0'-Y8F%S95]Q=65R>2@G4D],3$)!0TLG+"`D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("1T:&ES+3YT<F%N<V%C=&EO
M;E]O<&-O=6YT(#T@,#L*("`@("`@("`@("`@:68@*"$D<F5S=6QT*2!["B`@
M("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-Y8F%S95)A:7-E17)R;W(H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@1$)?
M3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<WEB87-E4F%I<V5%
M<G)O<B@I"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!A($1"7T5R<F]R(&]B
M:F5C="!R96=A<F1I;F<@=&AE(&-U<G)E;G0@<')O8FQE;0H@("`@("H*("`@
M("`J($!P87)A;2!I;G0@)&5R<FYO("!I9B!T:&4@97)R;W(@:7,@8F5I;F<@
M;6%N=6%L;'D@<F%I<V5D('!A<W,@80H@("`@("H@("`@("`@("`@("`@("`@
M("`@("!$0E]%4E)/4BH@8V]N<W1A;G0@:&5R92X@($EF('1H:7,@:7-N)W0@
M<&%S<V5D"B`@("`@*B`@("`@("`@("`@("`@("`@("`@('1H92!E<G)O<B!I
M;F9O<FUA=&EO;B!G871H97)E9"!F<F]M('1H92!$0DU3+@H@("`@("H*("`@
M("`J($!R971U<FX@;V)J96-T("!T:&4@1$)?17)R;W(@;V)J96-T"B`@("`@
M*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G)A:7-E17)R;W(H*2P*("`@("`J
M("`@("`@1$)?<WEB87-E.CIE<G)O<DYA=&EV92@I+"!$0E]S>6)A<V4Z.F5R
M<F]R0V]D92@I"B`@("`@*B\*("`@(&9U;F-T:6]N('-Y8F%S95)A:7-E17)R
M;W(H)&5R<FYO(#T@;G5L;"D*("`@('L*("`@("`@("`D;F%T:79E(#T@)'1H
M:7,M/F5R<F]R3F%T:79E*"D["B`@("`@("`@:68@*"1E<G)N;R`]/3T@;G5L
M;"D@>PH@("`@("`@("`@("`D97)R;F\@/2`D=&AI<RT^97)R;W)#;V1E*"1N
M871I=F4I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E
M17)R;W(H)&5R<FYO+"!N=6QL+"!N=6QL+"!N=6QL+"`D;F%T:79E*3L*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@
M+RHJ"B`@("`@*B!'971S('1H92!$0DU3)R!N871I=F4@97)R;W(@;65S<V%G
M92!P<F]D=6-E9"!B>2!T:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J($!R
M971U<FX@<W1R:6YG("!T:&4@1$)-4R<@97)R;W(@;65S<V%G90H@("`@("HO
M"B`@("!F=6YC=&EO;B!E<G)O<DYA=&EV92@I"B`@("!["B`@("`@("`@<F5T
M=7)N($!S>6)A<V5?9V5T7VQA<W1?;65S<V%G92@I.PH@("`@?0H*("`@("\O
M('U]?0H@("`@+R\@>WM[(&5R<F]R0V]D92@I"@H@("`@+RHJ"B`@("`@*B!$
M971E<FUI;F5S(%!%05(Z.D1"(&5R<F]R(&-O9&4@9G)O;2!T:&4@9&%T86)A
M<V4G<R!T97AT(&5R<F]R(&UE<W-A9V4N"B`@("`@*@H@("`@("H@0'!A<F%M
M("!S=')I;F<@("1E<G)O<FUS9R`@97)R;W(@;65S<V%G92!R971U<FYE9"!F
M<F]M('1H92!D871A8F%S90H@("`@("H@0')E='5R;B!I;G1E9V5R("!A;B!E
M<G)O<B!N=6UB97(@9G)O;2!A($1"(&5R<F]R(&-O;G-T86YT"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5R<F]R0V]D92@D97)R;W)M<V<I"B`@("!["B`@("`@
M("`@<W1A=&EC("1E<G)O<E]R96=E>'!S.PH@("`@("`@(&EF("@A:7-S970H
M)&5R<F]R7W)E9V5X<',I*2!["B`@("`@("`@("`@("1E<G)O<E]R96=E>'!S
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`G+TEN8V]R<F5C="!S>6YT87@@
M;F5A<B\G"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?4UE.5$%8
M+`H@("`@("`@("`@("`@("`@)R]>56YC;&]S960@<75O=&4@8F5F;W)E('1H
M92!C:&%R86-T97(@<W1R:6YG(%M<(EPG72XJ6UPB7"==7"XO)PH@("`@("`@
M("`@("`@("`@("`@(#T^($1"7T524D]27U-93E1!6"P*("`@("`@("`@("`@
M("`@("<O26UP;&EC:70@8V]N=F5R<VEO;B`H9G)O;2!D871A='EP97QO9B!.
M54U%4DE#('9A;'5E*2]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T52
M4D]27TE.5D%,241?3E5-0D52+`H@("`@("`@("`@("`@("`@)R]#86YN;W0@
M9')O<"!T:&4@=&%B;&4@6UPB7"==+BM;7")<)UTL(&)E8V%U<V4@:70@9&]E
M<VY<)W0@97AI<W0@:6X@=&AE('-Y<W1E;2!C871A;&]G<UPN+R<*("`@("`@
M("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA404),12P*("`@("`@
M("`@("`@("`@("<O3VYL>2!T:&4@;W=N97(@;V8@;V)J96-T(%M<(EPG72XK
M6UPB7"==(&]R(&$@=7-E<B!W:71H(%-Y<W1E;2!!9&UI;FES=')A=&]R(%PH
M4T%<*2!R;VQE(&-A;B!R=6X@=&AI<R!C;VUM86YD7"XO)PH@("`@("`@("`@
M("`@("`@("`@(#T^($1"7T524D]27T%#0T534U]624],051)3TXL"B`@("`@
M("`@("`@("`@("`G+UXN*R!P97)M:7-S:6]N(&1E;FEE9"!O;B!O8FIE8W0@
M+BLL(&1A=&%B87-E("XK+"!O=VYE<B`N*R\G"B`@("`@("`@("`@("`@("`@
M("`@/3X@1$)?15)23U)?04-#15-37U9)3TQ!5$E/3BP*("`@("`@("`@("`@
M("`@("<O7BXJ('!E<FUI<W-I;VX@9&5N:65D+"!D871A8F%S92`N*RP@;W=N
M97(@+BLO)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%#0T53
M4U]624],051)3TXL"B`@("`@("`@("`@("`@("`G+UM>+BI=(&YO="!F;W5N
M9%PN+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].3U-50TA4
M04),12P*("`@("`@("`@("`@("`@("<O5&AE<F4@:7,@86QR96%D>2!A;B!O
M8FIE8W0@;F%M960O)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7T%,4D5!1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R]);G9A;&ED(&-O
M;'5M;B!N86UE+R<*("`@("`@("`@("`@("`@("`@("`]/B!$0E]%4E)/4E].
M3U-50TA&245,1"P*("`@("`@("`@("`@("`@("<O9&]E<R!N;W0@86QL;W<@
M;G5L;"!V86QU97,O)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]2
M7T-/3E-44D%)3E1?3D]47TY53$PL"B`@("`@("`@("`@("`@("`G+T-O;6UA
M;F0@:&%S(&)E96X@86)O<G1E9"\G"B`@("`@("`@("`@("`@("`@("`@/3X@
M1$)?15)23U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@("<O7D-A;FYO
M="!D<F]P('1H92!I;F1E>"`N*B!B96-A=7-E(&ET(&1O97-N7"=T(&5X:7-T
M+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?3D]47T9/54Y$
M+`H@("`@("`@("`@("`@("`@)R]>5&AE<F4@:7,@86QR96%D>2!A;B!I;F1E
M>"]I)PH@("`@("`@("`@("`@("`@("`@(#T^($1"7T524D]27T%,4D5!1%E?
M15A)4U13+`H@("`@("`@("`@("`@("`@)R]>5&AE<F4@87)E(&9E=V5R(&-O
M;'5M;G,@:6X@=&AE($E.4T525"!S=&%T96UE;G0@=&AA;B!V86QU97,@<W!E
M8VEF:65D+VDG"B`@("`@("`@("`@("`@("`@("`@/3X@1$)?15)23U)?5D%,
M545?0T]53E1?3TY?4D]7+`H@("`@("`@("`@("`I.PH@("`@("`@('T*"B`@
M("`@("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E9V5X<"`]/B`D
M8V]D92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G97AP+"`D
M97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T524D]2
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1A8FQE26YF;R@I"@H@
M("`@+RHJ"B`@("`@*B!2971U<FYS(&EN9F]R;6%T:6]N(&%B;W5T(&$@=&%B
M;&4@;W(@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@3D]413H@;VYL>2!S
M=7!P;W)T<R`G=&%B;&4G(&%N9"`G9FQA9W,G(&EF(#QV87(^)')E<W5L=#PO
M=F%R/@H@("`@("H@:7,@82!T86)L92!N86UE+@H@("`@("H*("`@("`J($!P
M87)A;2!O8FIE8W1\<W1R:6YG("`D<F5S=6QT("!$0E]R97-U;'0@;V)J96-T
M(&9R;VT@82!Q=65R>2!O<B!A"B`@("`@*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('-T<FEN9R!C;VYT86EN:6YG('1H92!N86UE(&]F(&$@
M=&%B;&4N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%=H:6QE('1H:7,@86QS;R!A8V-E<'1S(&$@<75E<GD@<F5S=6QT"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(')E<V]U<F-E(&ED
M96YT:69I97(L('1H:7,@8F5H879I;W(@:7,*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@9&5P<F5C871E9"X*("`@("`J($!P87)A
M;2!I;G0@("`@("`@("`@("`D;6]D92`@("!A('9A;&ED('1A8FQE26YF;R!M
M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!A<G)A>2`@86X@87-S;V-I871I
M=F4@87)R87D@=VET:"!T:&4@:6YF;W)M871I;VX@<F5Q=65S=&5D+@H@("`@
M("H@("`@("`@("`@("`@("`@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*@H@("`@("H@0'-E92!$0E]C;VUM;VXZ.G1A8FQE26YF;R@I
M"B`@("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E
M(#$N-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('1A8FQE26YF;R@D<F5S=6QT
M+"`D;6]D92`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES7W-T<FEN9R@D
M<F5S=6QT*2D@>PH@("`@("`@("`@("`O*@H@("`@("`@("`@("`@*B!0<F]B
M86)L>2!R96-E:79E9"!A('1A8FQE(&YA;64N"B`@("`@("`@("`@("`J($-R
M96%T92!A(')E<W5L="!R97-O=7)C92!I9&5N=&EF:65R+@H@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@:68@*"%`<WEB87-E7W-E;&5C=%]D8B@D=&AI
M<RT^7V1B+"`D=&AI<RT^8V]N;F5C=&EO;BDI('L*("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<WEB87-E4F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"
M4T5,14-4140I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1I9"`]($!S
M>6)A<V5?<75E<GDH(E-%3$5#5"`J($923TT@)')E<W5L="!72$5212`Q/3`B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC;VYN
M96-T:6]N*3L*("`@("`@("`@("`@)&=O=%]S=')I;F<@/2!T<G5E.PH@("`@
M("`@('T@96QS96EF("AI<W-E="@D<F5S=6QT+3YR97-U;'0I*2!["B`@("`@
M("`@("`@("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@
M<F5S=6QT(&]B:F5C="X*("`@("`@("`@("`@("H@17AT<F%C="!T:&4@<F5S
M=6QT(')E<V]U<F-E(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@
M("`@("`@("`D:60@/2`D<F5S=6QT+3YR97-U;'0["B`@("`@("`@("`@("1G
M;W1?<W1R:6YG(#T@9F%L<V4["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@+RH*("`@("`@("`@("`@("H@4')O8F%B;'D@<F5C96EV960@82!R97-U
M;'0@<F5S;W5R8V4@:61E;G1I9FEE<BX*("`@("`@("`@("`@("H@0V]P>2!I
M="X*("`@("`@("`@("`@("H@1&5P<F5C871E9"X@($AE<F4@9F]R(&-O;7!A
M=&EB:6QI='D@;VYL>2X*("`@("`@("`@("`@("HO"B`@("`@("`@("`@("1I
M9"`]("1R97-U;'0["B`@("`@("`@("`@("1G;W1?<W1R:6YG(#T@9F%L<V4[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1I9"DI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS>6)A<V5286ES945R<F]R*$1"
M7T524D]27TY%141?34]215]$051!*3L*("`@("`@("!]"@H@("`@("`@(&EF
M("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,
M25197TQ/5T520T%312D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T
M<G1O;&]W97(G.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E
M7V9U;F,@/2`G<W1R=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N="`]
M($!S>6)A<V5?;G5M7V9I96QD<R@D:60I.PH@("`@("`@("1R97,@("`](&%R
M<F%Y*"D["@H@("`@("`@(&EF("@D;6]D92D@>PH@("`@("`@("`@("`D<F5S
M6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0["B`@("`@("`@?0H*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[("1I*RLI('L*("`@("`@("`@("`@
M)&8@/2!`<WEB87-E7V9E=&-H7V9I96QD*"1I9"P@)&DI.PH@("`@("`@("`@
M("`O+R!C;VQU;6Y?<V]U<F-E(&ES(&]F=&5N(&)L86YK"B`@("`@("`@("`@
M("1R97-;)&E=(#T@87)R87DH"B`@("`@("`@("`@("`@("`G=&%B;&4G(#T^
M("1G;W1?<W1R:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("`@(#\@)&-A
M<V5?9G5N8R@D<F5S=6QT*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`Z
M("1C87-E7V9U;F,H)&8M/F-O;'5M;E]S;W5R8V4I+`H@("`@("`@("`@("`@
M("`@)VYA;64G("`]/B`D8V%S95]F=6YC*"1F+3YN86UE*2P*("`@("`@("`@
M("`@("`@("=T>7!E)R`@/3X@)&8M/G1Y<&4L"B`@("`@("`@("`@("`@("`G
M;&5N)R`@(#T^("1F+3YM87A?;&5N9W1H+`H@("`@("`@("`@("`@("`@)V9L
M86=S)R`]/B`G)RP*("`@("`@("`@("`@*3L*("`@("`@("`@("`@:68@*"1R
M97-;)&E=6R=T86)L92==*2!["B`@("`@("`@("`@("`@("`D<F5S6R1I75LG
M9FQA9W,G72`]("1T:&ES+3Y?<WEB87-E7V9I96QD7V9L86=S*`H@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S6R1I75LG=&%B;&4G72P@)')E<ULD:5U;
M)VYA;64G72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"1M;V1E
M("8@1$)?5$%"3$5)3D9/7T]21$52*2!["B`@("`@("`@("`@("`@("`D<F5S
M6R=O<F1E<B==6R1R97-;)&E=6R=N86UE)UU=(#T@)&D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@:68@*"1M;V1E("8@1$)?5$%"3$5)3D9/7T]21$52
M5$%"3$4I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R=&%B;&4G75LD
M<F5S6R1I75LG=&%B;&4G75U;)')E<ULD:5U;)VYA;64G75T@/2`D:3L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@9G)E92!T:&4@<F5S
M=6QT(&]N;'D@:68@=V4@=V5R92!C86QL960@;VX@82!T86)L90H@("`@("`@
M(&EF("@D9V]T7W-T<FEN9RD@>PH@("`@("`@("`@("!`<WEB87-E7V9R965?
M<F5S=6QT*"1I9"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<F5S.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(%]S>6)A<V5?9FEE;&1?9FQA
M9W,H*0H*("`@("\J*@H@("`@("H@1V5T('1H92!F;&%G<R!F;W(@82!F:65L
M9`H@("`@("H*("`@("`J($-U<G)E;G1L>2!S=7!P;W)T<SH*("`@("`J("`K
M(#QS86UP/G5N:7%U95]K97D\+W-A;7`^("`@("AU;FEQ=64@:6YD97@L('5N
M:7%U92!C:&5C:R!O<B!P<FEM87)Y7VME>2D*("`@("`J("`K(#QS86UP/FUU
M;'1I<&QE7VME>3PO<V%M<#X@("AM=6QT:2UK97D@:6YD97@I"B`@("`@*@H@
M("`@("H@0'!A<F%M('-T<FEN9R`@)'1A8FQE("`@=&AE('1A8FQE(&YA;64*
M("`@("`J($!P87)A;2!S=')I;F<@("1C;VQU;6X@('1H92!F:65L9"!N86UE
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@('-P86-E(&1E;&EM:71E
M9"!S=')I;F<@;V8@9FQA9W,N("!%;7!T>2!S=')I;F<@:68@;F]N92X*("`@
M("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I
M;VX@7W-Y8F%S95]F:65L9%]F;&%G<R@D=&%B;&4L("1C;VQU;6XI"B`@("![
M"B`@("`@("`@<W1A=&EC("1T86)L94YA;64@/2!N=6QL.PH@("`@("`@('-T
M871I8R`D9FQA9W,@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1A8FQE("$]
M("1T86)L94YA;64I('L*("`@("`@("`@("`@)&9L86=S(#T@87)R87DH*3L*
M("`@("`@("`@("`@)'1A8FQE3F%M92`]("1T86)L93L*"B`@("`@("`@("`@
M("\O(&=E="!U;FEQ=64O<')I;6%R>2!K97ES"B`@("`@("`@("`@("1R97,@
M/2`D=&AI<RT^9V5T06QL*")S<%]H96QP:6YD97@@)'1A8FQE(BP@1$)?1D54
M0TA-3T1%7T%34T]#*3L*"B`@("`@("`@("`@(&EF("@A:7-S970H)')E<ULP
M75LG:6YD97A?9&5S8W)I<'1I;VXG72DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`G)SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@9F]R96%C:"`H
M)')E<R!A<R`D=F%L*2!["B`@("`@("`@("`@("`@("`D:V5Y<R`](&5X<&QO
M9&4H)RP@)RP@=')I;2@D=F%L6R=I;F1E>%]K97ES)UTI*3L*"B`@("`@("`@
M("`@("`@("!I9B`H<VEZ96]F*"1K97ES*2`^(#$I('L*("`@("`@("`@("`@
M("`@("`@("!F;W)E86-H("@D:V5Y<R!A<R`D:V5Y*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y?861D7V9L86<H)&9L86=S6R1K97E=+"`G
M;75L=&EP;&5?:V5Y)RD["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)'9A;%LG
M:6YD97A?9&5S8W)I<'1I;VXG72P@)W5N:7%U92<I*2!["B`@("`@("`@("`@
M("`@("`@("`@9F]R96%C:"`H)&ME>7,@87,@)&ME>2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`D=&AI<RT^7V%D9%]F;&%G*"1F;&%G<ULD:V5Y72P@
M)W5N:7%U95]K97DG*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@?0H*("`@("`@("!I
M9B`H87)R87E?:V5Y7V5X:7-T<R@D8V]L=6UN+"`D9FQA9W,I*2!["B`@("`@
M("`@("`@(')E='5R;BAI;7!L;V1E*"<@)RP@)&9L86=S6R1C;VQU;6Y=*2D[
M"B`@("`@("`@?0H*("`@("`@("!R971U<FX@)R<["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@7V%D9%]F;&%G*"D*"B`@("`O*BH*("`@("`J($%D
M9',@82!S=')I;F<@=&\@=&AE(&9L86=S(&%R<F%Y(&EF('1H92!F;&%G(&ES
M(&YO="!Y970@:6X@=&AE<F4*("`@("`J("T@:68@=&AE<F4@:7,@;F\@9FQA
M9R!P<F5S96YT('1H92!A<G)A>2!I<R!C<F5A=&5D"B`@("`@*@H@("`@("H@
M0'!A<F%M(&%R<F%Y("`D87)R87D@(')E9F5R96YC92!O9B!F;&%G<R!A<G)A
M>2!T;R!A9&0@82!V86QU92!T;PH@("`@("H@0'!A<F%M(&UI>&5D("`D=F%L
M=64@('9A;'5E('1O(&%D9"!T;R!T:&4@9FQA9R!A<G)A>0H@("`@("H*("`@
M("`J($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?861D7V9L86<H)B1A<G)A>2P@)'9A
M;'5E*0H@("`@>PH@("`@("`@(&EF("@A:7-?87)R87DH)&%R<F%Y*2D@>PH@
M("`@("`@("`@("`D87)R87D@/2!A<G)A>2@D=F%L=64I.PH@("`@("`@('T@
M96QS96EF("@A:6Y?87)R87DH)'9A;'5E+"`D87)R87DI*2!["B`@("`@("`@
M("`@(&%R<F%Y7W!U<V@H)&%R<F%Y+"`D=F%L=64I.PH@("`@("`@('T*("`@
M('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!G9713<&5C:6%L475E<GDH*0H*
M("`@("\J*@H@("`@("H@3V)T86EN<R!T:&4@<75E<GD@<W1R:6YG(&YE961E
M9"!F;W(@;&ES=&EN9R!A(&=I=F5N('1Y<&4@;V8@;V)J96-T<PH@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@('1H92!K:6YD(&]F(&]B:F5C
M=',@>6]U('=A;G0@=&\@<F5T<FEE=F4*("`@("`J"B`@("`@*B!`<F5T=7)N
M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<@;W(@;G5L;"!I9B!T:&4@
M9')I=F5R(&1O97-N)W0*("`@("`J("`@("`@("`@("`@("`@("`@<W5P<&]R
M="!T:&4@;V)J96-T('1Y<&4@<F5Q=65S=&5D"B`@("`@*@H@("`@("H@0&%C
M8V5S<R!P<F]T96-T960*("`@("`J($!S964@1$)?8V]M;6]N.CIG971,:7-T
M3V8H*0H@("`@("HO"B`@("!F=6YC=&EO;B!G9713<&5C:6%L475E<GDH)'1Y
M<&4I"B`@("!["B`@("`@("`@<W=I=&-H("@D='EP92D@>PH@("`@("`@("`@
M("!C87-E("=T86)L97,G.@H@("`@("`@("`@("`@("`@<F5T=7)N(")314Q%
M0U0@;F%M92!&4D]-('-Y<V]B:F5C=',@5TA%4D4@='EP92`]("=5)R(*("`@
M("`@("`@("`@("`@("`@("`@("`N("<@3U)$15(@0ED@;F%M92<["B`@("`@
M("`@("`@(&-A<V4@)W9I97=S)SH*("`@("`@("`@("`@("`@(')E='5R;B`B
M4T5,14-4(&YA;64@1E)/32!S>7-O8FIE8W1S(%=(15)%('1Y<&4@/2`G5B<B
M.PH@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@<F5T=7)N
M(&YU;&P["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H*?0H*+RH*("H@
M3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO
M9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T1"+W-T;W)A
M9V4N<&AP````````````````````````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,S4P,#0@,3`U,34T,S0Q,S,@,#(Q,3(U`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"@HO*B!V:6TZ('-E="!E
M>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT
M.B`J+PH*+RHJ"B`J(%!R;W9I9&5S(&%N(&]B:F5C="!I;G1E<F9A8V4@=&\@
M82!T86)L92!R;W<*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@
M3$E#14Y313H@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I
M;VX@,RXP(&]F('1H92!02%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L
M92!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG
M(%5223H*("H@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@
M3&EC96YS92!A;F0@87)E('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V5B+"!P;&5A<V4*("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N
M;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J
M"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J
M($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^"B`J($!C
M;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E
M("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,
M:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@<W1O<F%G92YP
M:'`L=B`Q+C(Q(#(P,#4O,#(O,#(@,#(Z-30Z-3$@9&%N:65L8R!%>'`@)`H@
M*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O1$(*
M("HO"@HO*BH*("H@3V)T86EN('1H92!$0B!C;&%S<R!S;R!I="!C86X@8F4@
M97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0BYP:'`G.PH*+RHJ
M"B`J(%!R;W9I9&5S(&%N(&]B:F5C="!I;G1E<F9A8V4@=&\@82!T86)L92!R
M;W<*("H*("H@270@;&5T<R!Y;W4@861D+"!D96QE=&4@86YD(&-H86YG92!R
M;W=S('5S:6YG(&]B:F5C=',@<F%T:&5R('1H86X@4U%,"B`J('-T871E;65N
M=',N"B`J"B`J($!C871E9V]R>2`@($1A=&%B87-E"B`J($!P86-K86=E("`@
M($1""B`J($!A=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^
M"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!L
M:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0@
M(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C<N
M-@H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O
M1$(*("HO"F-L87-S($1"7W-T;W)A9V4@97AT96YD<R!014%2"GL*("`@("\O
M('M[>R!P<F]P97)T:65S"@H@("`@+RHJ('1H92!N86UE(&]F('1H92!T86)L
M92`H;W(@=FEE=RP@:68@=&AE(&)A8VME;F0@9&%T86)A<V4@<W5P<&]R=',*
M("`@("`@("!U<&1A=&5S(&EN('9I97=S*2!W92!H;VQD(&1A=&$@9G)O;2`J
M+PH@("`@=F%R("1?=&%B;&4@/2!N=6QL.PH*("`@("\J*B!W:&EC:"!C;VQU
M;6XH<RD@:6X@=&AE('1A8FQE(&-O;G1A:6YS('!R:6UA<GD@:V5Y<RP@8V%N
M(&)E(&$*("`@("`@("!S=')I;F<@9F]R('-I;F=L92UC;VQU;6X@<')I;6%R
M>2!K97ES+"!O<B!A;B!A<G)A>2!O9B!S=')I;F=S"B`@("`@("`@9F]R(&UU
M;'1I<&QE+6-O;'5M;B!P<FEM87)Y(&ME>7,@*B\*("`@('9A<B`D7VME>6-O
M;'5M;B`](&YU;&P["@H@("`@+RHJ($1"(&-O;FYE8W1I;VX@:&%N9&QE('5S
M960@9F]R(&%L;"!T<F%N<V%C=&EO;G,@*B\*("`@('9A<B`D7V1B:"`](&YU
M;&P["@H@("`@+RHJ(&%N(&%S<V]C('=I=&@@=&AE(&YA;65S(&]F(&1A=&%B
M87-E(&9I96QD<R!S=&]R960@87,@<')O<&5R=&EE<PH@("`@("`@(&EN('1H
M:7,@;V)J96-T("HO"B`@("!V87(@)%]P<F]P97)T:65S(#T@87)R87DH*3L*
M"B`@("`O*BH@86X@87-S;V,@=VET:"!T:&4@;F%M97,@;V8@=&AE('!R;W!E
M<G1I97,@:6X@=&AI<R!O8FIE8W0@=&AA=`H@("`@("`@(&AA=F4@8F5E;B!C
M:&%N9V5D('-I;F-E('1H97D@=V5R92!F971C:&5D(&9R;VT@=&AE(&1A=&%B
M87-E("HO"B`@("!V87(@)%]C:&%N9V5S(#T@87)R87DH*3L*"B`@("`O*BH@
M9FQA9R!T:&%T(&1E8VED97,@:68@9&%T82!I;B!T:&ES(&]B:F5C="!C86X@
M8F4@8VAA;F=E9"X*("`@("`@("!O8FIE8W1S('1H870@9&]N)W0@:&%V92!T
M:&5I<B!T86)L92=S(&ME>2!C;VQU;6X@:6X@=&AE:7(*("`@("`@("!P<F]P
M97)T>2!L:7-T<R!W:6QL(&)E(&9L86=G960@87,@<F5A9"UO;FQY+B`J+PH@
M("`@=F%R("1?<F5A9&]N;'D@/2!F86QS93L*"B`@("`O*BH@9G5N8W1I;VX@
M;W(@;65T:&]D('1H870@:6UP;&5M96YT<R!A('9A;&ED871O<B!F;W(@9FEE
M;&1S('1H870*("`@("`@("!A<F4@<V5T+"!T:&ES('9A;&ED871O<B!F=6YC
M=&EO;B!R971U<FYS('1R=64@:68@=&AE(&9I96QD(&ES"B`@("`@("`@=F%L
M:60L(&9A;'-E(&EF(&YO="`J+PH@("`@=F%R("1?=F%L:61A=&]R(#T@;G5L
M;#L*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U8W1O<@H*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@)'1A
M8FQE('-T<FEN9R!T:&4@;F%M92!O9B!T:&4@9&%T86)A<V4@=&%B;&4*("`@
M("`J"B`@("`@*B!`<&%R86T@)&ME>6-O;'5M;B!M:7AE9"!S=')I;F<@=VET
M:"!N86UE(&]F(&ME>2!C;VQU;6XL(&]R(&%R<F%Y(&]F"B`@("`@*B!S=')I
M;F=S(&EF('1H92!T86)L92!H87,@82!P<FEM87)Y(&ME>2!O9B!M;W)E('1H
M86X@;VYE(&-O;'5M;@H@("`@("H*("`@("`J($!P87)A;2`D9&)H(&]B:F5C
M="!D871A8F%S92!C;VYN96-T:6]N(&]B:F5C=`H@("`@("H*("`@("`J($!P
M87)A;2`D=F%L:61A=&]R(&UI>&5D(&9U;F-T:6]N(&]R(&UE=&AO9"!U<V5D
M('1O('9A;&ED871E"B`@("`@*B!E86-H(&YE=R!V86QU92P@8V%L;&5D('=I
M=&@@=&AR964@<&%R86UE=&5R<SH@=&AE(&YA;64@;V8@=&AE"B`@("`@*B!F
M:65L9"]C;VQU;6X@=&AA="!I<R!C:&%N9VEN9RP@82!R969E<F5N8V4@=&\@
M=&AE(&YE=R!V86QU92!A;F0*("`@("`J(&$@<F5F97)E;F-E('1O('1H:7,@
M;V)J96-T"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]S=&]R86=E
M*"1T86)L92P@)&ME>6-O;'5M;BP@)B1D8F@L("1V86QI9&%T;W(@/2!N=6QL
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y014%2*"=$0E]%<G)O<B<I.PH@("`@
M("`@("1T:&ES+3Y?=&%B;&4@/2`D=&%B;&4["B`@("`@("`@)'1H:7,M/E]K
M97EC;VQU;6X@/2`D:V5Y8V]L=6UN.PH@("`@("`@("1T:&ES+3Y?9&)H(#T@
M)&1B:#L*("`@("`@("`D=&AI<RT^7W)E861O;FQY(#T@9F%L<V4["B`@("`@
M("`@)'1H:7,M/E]V86QI9&%T;W(@/2`D=F%L:61A=&]R.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(%]M86ME5VAE<F4H*0H*("`@("\J*@H@("`@
M("H@571I;&ET>2!M971H;V0@=&\@8G5I;&0@82`B5TA%4D4B(&-L875S92!T
M;R!L;V-A=&4@;W5R<V5L=F5S(&EN"B`@("`@*B!T:&4@=&%B;&4N"B`@("`@
M*@H@("`@("H@6%A8(&9U='5R92!I;7!R;W9E;65N=#H@=7-E(')O=VED<S\*
M("`@("`J"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7VUA:V57:&5R92@D:V5Y=F%L(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H:7-?87)R87DH)'1H:7,M/E]K97EC;VQU;6XI*2!["B`@("`@("`@
M("`@(&EF("@D:V5Y=F%L(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]K97EC;VQU;6XI.R`D
M:2LK*2!["B`@("`@("`@("`@("`@("`@("`@)&ME>79A;%M=(#T@)'1H:7,M
M/GLD=&AI<RT^7VME>6-O;'5M;ELD:5U].PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1W:&5R96-L875S92`]("<G.PH@
M("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]K
M97EC;VQU;6XI.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)&D@/B`P
M*2!["B`@("`@("`@("`@("`@("`@("`@)'=H97)E8VQA=7-E("X]("<@04Y$
M("<["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D=VAE<F5C
M;&%U<V4@+CT@)'1H:7,M/E]K97EC;VQU;6Y;)&E=.PH@("`@("`@("`@("`@
M("`@:68@*&ES7VYU;&PH)&ME>79A;%LD:5TI*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@=&AE<F4G<R!N;W0@;75C:"!P;VEN="!I;B!H879I;F<@82!.
M54Q,(&ME>2P*("`@("`@("`@("`@("`@("`@("`O+R!B=70@=V4@<W5P<&]R
M="!I="!A;GEW87D*("`@("`@("`@("`@("`@("`@("`D=VAE<F5C;&%U<V4@
M+CT@)R!)4R!.54Q,)SL*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@)'=H97)E8VQA=7-E("X]("<@/2`G("X@)'1H:7,M
M/E]D8F@M/G%U;W1E*"1K97EV86Q;)&E=*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF
M("@D:V5Y=F%L(#T]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D:V5Y=F%L
M(#T@0"1T:&ES+3Y[)'1H:7,M/E]K97EC;VQU;6Y].PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@("1W:&5R96-L875S92`]("1T:&ES+3Y?:V5Y8V]L=6UN
M.PH@("`@("`@("`@("!I9B`H:7-?;G5L;"@D:V5Y=F%L*2D@>PH@("`@("`@
M("`@("`@("`@+R\@=&AE<F4G<R!N;W0@;75C:"!P;VEN="!I;B!H879I;F<@
M82!.54Q,(&ME>2P*("`@("`@("`@("`@("`@("\O(&)U="!W92!S=7!P;W)T
M(&ET(&%N>7=A>0H@("`@("`@("`@("`@("`@)'=H97)E8VQA=7-E("X]("<@
M25,@3E5,3"<["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`D=VAE<F5C;&%U<V4@+CT@)R`]("<@+B`D=&AI<RT^7V1B:"T^<75O=&4H
M)&ME>79A;"D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1W:&5R96-L875S93L*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[
M>R!S971U<"@I"@H@("`@+RHJ"B`@("`@*B!-971H;V0@=7-E9"!T;R!I;FET
M:6%L:7IE(&$@1$)?<W1O<F%G92!O8FIE8W0@9G)O;2!T:&4*("`@("`J(&-O
M;F9I9W5R960@=&%B;&4N"B`@("`@*@H@("`@("H@0'!A<F%M("1K97EV86P@
M;6EX960@=&AE(&ME>5MS72!O9B!T:&4@<F]W('1O(&9E=&-H("AS=')I;F<@
M;W(@87)R87DI"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@1$)?3TL@;VX@
M<W5C8V5S<RP@82!$0B!E<G)O<B!I9B!N;W0*("`@("`J+PH@("`@9G5N8W1I
M;VX@<V5T=7`H)&ME>79A;"D*("`@('L*("`@("`@("`D=VAE<F5C;&%U<V4@
M/2`D=&AI<RT^7VUA:V57:&5R92@D:V5Y=F%L*3L*("`@("`@("`D<75E<GD@
M/2`G4T5,14-4("H@1E)/32`G("X@)'1H:7,M/E]T86)L92`N("<@5TA%4D4@
M)R`N("1W:&5R96-L875S93L*("`@("`@("`D<W1H(#T@)'1H:7,M/E]D8F@M
M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1S=&@I
M*2!["B`@("`@("`@("`@(')E='5R;B`D<W1H.PH@("`@("`@('T*("`@("`@
M("`D<F]W(#T@)'-T:"T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#*3L*
M("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')O=RDI('L*("`@("`@("`@("`@
M<F5T=7)N("1R;W<["B`@("`@("`@?0H@("`@("`@(&EF("@A)')O=RD@>PH@
M("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H;G5L;"P@1$)?
M15)23U)?3D]47T9/54Y$+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'%U97)Y+"!N=6QL+"!T<G5E*3L*("`@
M("`@("!]"B`@("`@("`@9F]R96%C:"`H)')O=R!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97-;)&ME>5T@/2!T
M<G5E.PH@("`@("`@("`@("`D=&AI<RT^)&ME>2`]("1V86QU93L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&EN<V5R="@I"@H@("`@+RHJ"B`@("`@*B!#<F5A=&4@82!N
M97<@*&5M<'1Y*2!R;W<@:6X@=&AE(&-O;F9I9W5R960@=&%B;&4@9F]R('1H
M:7,*("`@("`J(&]B:F5C="X*("`@("`J+PH@("`@9G5N8W1I;VX@:6YS97)T
M*"1N97=P:RD*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/E]K
M97EC;VQU;6XI*2!["B`@("`@("`@("`@("1P<FEM87)Y:V5Y(#T@)'1H:7,M
M/E]K97EC;VQU;6X["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'!R
M:6UA<GEK97D@/2!A<G)A>2@D=&AI<RT^7VME>6-O;'5M;BD["B`@("`@("`@
M?0H@("`@("`@('-E='1Y<&4H)&YE=W!K+"`B87)R87DB*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'!R:6UA<GEK97DI.R`D:2LK*2![
M"B`@("`@("`@("`@("1P:W9A;'-;72`]("1T:&ES+3Y?9&)H+3YQ=6]T92@D
M;F5W<&M;)&E=*3L*("`@("`@("!]"@H@("`@("`@("1S=&@@/2`D=&AI<RT^
M7V1B:"T^<75E<GDH(DE.4T525"!)3E1/("1T:&ES+3Y?=&%B;&4@*"(@+@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:6UP;&]D92@B+"(L
M("1P<FEM87)Y:V5Y*2`N("(I(%9!3%5%4R@B("X*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EM<&QO9&4H(BPB+"`D<&MV86QS*2`N("(I
M(BD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1S=&@I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<W1H.PH@("`@("`@('T*("`@("`@("!I9B`H<VEZ96]F
M*"1N97=P:RD@/3T@,2D@>PH@("`@("`@("`@("`D;F5W<&L@/2`D;F5W<&M;
M,%T["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YS971U<"@D;F5W<&LI.PH@
M("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('1O4W1R:6YG*"D*"B`@("`O
M*BH*("`@("`J($]U='!U="!A('-I;7!L92!D97-C<FEP=&EO;B!O9B!T:&ES
M($1"7W-T;W)A9V4@;V)J96-T+@H@("`@("H@0')E='5R;B!S=')I;F<@;V)J
M96-T(&1E<V-R:7!T:6]N"B`@("`@*B\*("`@(&9U;F-T:6]N('1O4W1R:6YG
M*"D*("`@('L*("`@("`@("`D:6YF;R`]('-T<G1O;&]W97(H9V5T7V-L87-S
M*"1T:&ES*2D["B`@("`@("`@)&EN9F\@+CT@(B`H=&%B;&4](CL*("`@("`@
M("`D:6YF;R`N/2`D=&AI<RT^7W1A8FQE.PH@("`@("`@("1I;F9O("X]("(L
M(&ME>6-O;'5M;CTB.PH@("`@("`@(&EF("AI<U]A<G)A>2@D=&AI<RT^7VME
M>6-O;'5M;BDI('L*("`@("`@("`@("`@)&EN9F\@+CT@(B@B("X@:6UP;&]D
M92@B+"(L("1T:&ES+3Y?:V5Y8V]L=6UN*2`N("(I(CL*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`D:6YF;R`N/2`D=&AI<RT^7VME>6-O;'5M;CL*
M("`@("`@("!]"B`@("`@("`@)&EN9F\@+CT@(BP@9&)H/2(["B`@("`@("`@
M:68@*&ES7V]B:F5C="@D=&AI<RT^7V1B:"DI('L*("`@("`@("`@("`@)&EN
M9F\@+CT@)'1H:7,M/E]D8F@M/G1O4W1R:6YG*"D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)&EN9F\@+CT@(FYU;&PB.PH@("`@("`@('T*("`@
M("`@("`D:6YF;R`N/2`B*2(["B`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^
M7W!R;W!E<G1I97,I*2!["B`@("`@("`@("`@("1I;F9O("X]("(@6VQO861E
M9"P@:V5Y/2(["B`@("`@("`@("`@("1K97EN86UE(#T@)'1H:7,M/E]K97EC
M;VQU;6X["B`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D:V5Y;F%M92DI('L*
M("`@("`@("`@("`@("`@("1I;F9O("X]("(H(CL*("`@("`@("`@("`@("`@
M(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D:V5Y;F%M92D[("1I*RLI('L*
M("`@("`@("`@("`@("`@("`@("!I9B`H)&D@/B`P*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("1I;F9O("X]("(L(CL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)&EN9F\@+CT@)'1H:7,M/B1K97EN
M86UE6R1I73L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("1I
M;F9O("X]("(I(CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1I;F9O("X]("1T:&ES+3XD:V5Y;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("`D:6YF;R`N/2`B72(["B`@("`@("`@?0H@("`@("`@(&EF
M("AS:7IE;V8H)'1H:7,M/E]C:&%N9V5S*2D@>PH@("`@("`@("`@("`D:6YF
M;R`N/2`B(%MM;V1I9FEE9%TB.PH@("`@("`@('T*("`@("`@("!R971U<FX@
M)&EN9F\["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9'5M<"@I"@H@
M("`@+RHJ"B`@("`@*B!$=6UP('1H92!C;VYT96YT<R!O9B!T:&ES(&]B:F5C
M="!T;R`B<W1A;F1A<F0@;W5T<'5T(BX*("`@("`J+PH@("`@9G5N8W1I;VX@
M9'5M<"@I"B`@("!["B`@("`@("`@9F]R96%C:"`H)'1H:7,M/E]P<F]P97)T
M:65S(&%S("1P<F]P(#T^("1F;V\I('L*("`@("`@("`@("`@<')I;G0@(B1P
M<F]P(#T@(CL*("`@("`@("`@("`@<')I;G0@:'1M;&5N=&ET:65S*"1T:&ES
M+3XD<')O<"D["B`@("`@("`@("`@('!R:6YT("(\8G(@+SY<;B(["B`@("`@
M("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[("9C<F5A=&4H*0H*
M("`@("\J*@H@("`@("H@4W1A=&EC(&UE=&AO9"!U<V5D('1O(&-R96%T92!N
M97<@1$(@<W1O<F%G92!O8FIE8W1S+@H@("`@("H@0'!A<F%M("1D871A(&%S
M<V]C+B!A<G)A>2!W:&5R92!T:&4@:V5Y<R!A<F4@=&AE(&YA;65S"B`@("`@
M*B`@("`@("`@("`@("`@;V8@<')O<&5R=&EE<R]C;VQU;6YS"B`@("`@*B!`
M<F5T=7)N(&]B:F5C="!A(&YE=R!I;G-T86YC92!O9B!$0E]S=&]R86=E(&]R
M(&$@<W5B8VQA<W,@;V8@:70*("`@("`J+PH@("`@9G5N8W1I;VX@)F-R96%T
M92@D=&%B;&4L("8D9&%T82D*("`@('L*("`@("`@("`D8VQA<W-N86UE(#T@
M<W1R=&]L;W=E<BAG971?8VQA<W,H)'1H:7,I*3L*("`@("`@("`D;V)J(#TF
M(&YE=R`D8VQA<W-N86UE*"1T86)L92D["B`@("`@("`@9F]R96%C:"`H)&1A
M=&$@87,@)&YA;64@/3X@)'9A;'5E*2!["B`@("`@("`@("`@("1O8FHM/E]P
M<F]P97)T:65S6R1N86UE72`]('1R=64["B`@("`@("`@("`@("1O8FHM/B1N
M86UE(#T@)B1V86QU93L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1O8FH[
M"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;&]A9$9R;VU1=65R>2@I
M"@H@("`@+RHJ"B`@("`@*B!,;V%D<R!D871A(&EN=&\@=&AI<R!O8FIE8W0@
M9G)O;2!T:&4@9VEV96X@<75E<GDN("!)9B!T:&ES"B`@("`@*B!O8FIE8W0@
M86QR96%D>2!C;VYT86EN<R!T86)L92!D871A+"!C:&%N9V5S('=I;&P@8F4@
M<V%V960@86YD"B`@("`@*B!T:&4@;V)J96-T(')E+6EN:71I86QI>F5D(&9I
M<G-T+@H@("`@("H*("`@("`J($!P87)A;2`D<75E<GD@4U%,('%U97)Y"B`@
M("`@*@H@("`@("H@0'!A<F%M("1P87)A;7,@<&%R86UE=&5R(&QI<W0@:6X@
M8V%S92!Y;W4@=V%N="!T;R!U<V4*("`@("`J('!R97!A<F4O97AE8W5T92!M
M;V1E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@1$)?3TL@;VX@<W5C8V5S
M<RP@1$)?5T%23DE.1U]214%$7T].3%D@:68@=&AE"B`@("`@*B!R971U<FYE
M9"!O8FIE8W0@:7,@<F5A9"UO;FQY("AB96-A=7-E('1H92!O8FIE8W0G<R!S
M<&5C:69I960*("`@("`J(&ME>2!C;VQU;6X@=V%S(&YO="!F;W5N9"!A;6]N
M9R!T:&4@8V]L=6UN<R!R971U<FYE9"!B>2`D<75E<GDI+`H@("`@("H@;W(@
M86YO=&AE<B!$0B!E<G)O<B!C;V1E(&EN(&-A<V4@;V8@97)R;W)S+@H@("`@
M("HO"B\O(%A86"!C;VUM96YT960@;W5T(&9O<B!N;W<*+RH*("`@(&9U;F-T
M:6]N(&QO861&<F]M475E<GDH)'%U97)Y+"`D<&%R86US(#T@;G5L;"D*("`@
M('L*("`@("`@("!I9B`H<VEZ96]F*"1T:&ES+3Y?<')O<&5R=&EE<RDI('L*
M("`@("`@("`@("`@:68@*'-I>F5O9B@D=&AI<RT^7V-H86YG97,I*2!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<W1O<F4H*3L*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?8VAA;F=E<R`](&%R<F%Y*"D["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@)'1H:7,M/E]P<F]P97)T:65S(#T@87)R87DH*3L*("`@("`@
M("!]"B`@("`@("`@)')O=V1A=&$@/2`D=&AI<RT^7V1B:"T^9V5T4F]W*"1Q
M=65R>2P@1$)?1D540TA-3T1%7T%34T]#+"`D<&%R86US*3L*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')O=V1A=&$I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<F]W9&%T83L*("`@("`@("!]"B`@("`@("`@<F5S970H)')O=V1A=&$I
M.PH@("`@("`@("1F;W5N9%]K97EC;VQU;6X@/2!F86QS93L*("`@("`@("!W
M:&EL92`H;&ES="@D:V5Y+"`D=F%L=64I(#T@96%C:"@D<F]W9&%T82DI('L*
M("`@("`@("`@("`@:68@*"1K97D@/3T@)'1H:7,M/E]K97EC;VQU;6XI('L*
M("`@("`@("`@("`@("`@("1F;W5N9%]K97EC;VQU;6X@/2!T<G5E.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?<')O<&5R=&EE<ULD:V5Y
M72`]('1R=64["B`@("`@("`@("`@("1T:&ES+3XD:V5Y(#T@)B1V86QU93L*
M("`@("`@("`@("`@=6YS970H)'9A;'5E*3L@+R\@:&%V92!T;R!U;G-E="P@
M;W(@86QL('!R;W!E<G1I97,@=VEL;`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!R969E<B!T;R!T:&4@<V%M92!V86QU90H@("`@("`@('T*("`@
M("`@("!I9B`H(21F;W5N9%]K97EC;VQU;6XI('L*("`@("`@("`@("`@)'1H
M:7,M/E]R96%D;VYL>2`]('1R=64["B`@("`@("`@("`@(')E='5R;B!$0E]7
M05).24Y'7U)%041?3TY,63L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"
M7T]+.PH@("`@?0H@*B\*"B`@("`O+R!]?7T*("`@("\O('M[>R!S970H*0H*
M("`@("\J*@H@("`@("H@36]D:69Y(&%N(&%T=')I=71E('9A;'5E+@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S970H)'!R;W!E<G1Y+"`D;F5W=F%L=64I"B`@
M("!["B`@("`@("`@+R\@;VYL>2!C:&%N9V4@:68@)'!R;W!E<G1Y(&ES(&MN
M;W=N(&%N9"!O8FIE8W0@:7,@;F]T"B`@("`@("`@+R\@<F5A9"UO;FQY"B`@
M("`@("`@:68@*"1T:&ES+3Y?<F5A9&]N;'DI('L*("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*&YU;&PL($1"7U=!4DY)3D=?4D5!1%]/
M3DQ9+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;G5L;"P@;G5L;"P@;G5L;"P@=')U92D["B`@("`@("`@?0H@("`@("`@
M(&EF("A`:7-S970H)'1H:7,M/E]P<F]P97)T:65S6R1P<F]P97)T>5TI*2![
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D=&AI<RT^7W9A;&ED871O<BDI('L*
M("`@("`@("`@("`@("`@("1V86QI9"`]('1R=64["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`D=F%L:60@/2!`8V%L;%]U<V5R7V9U
M;F,H)'1H:7,M/E]V86QI9&%T;W(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]T86)L92P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')O<&5R='DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&YE=W9A;'5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3XD<')O<&5R='DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&EF("@D=F%L:60I('L*("`@("`@("`@("`@("`@("1T:&ES+3XD<')O<&5R
M='D@/2`D;F5W=F%L=64["B`@("`@("`@("`@("`@("!I9B`H96UP='DH)'1H
M:7,M/E]C:&%N9V5S6R1P<F]P97)T>5TI*2!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/E]C:&%N9V5S6R1P<F]P97)T>5T@/2`P.PH@("`@("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V-H
M86YG97-;)'!R;W!E<G1Y72LK.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR
M86ES945R<F]R*&YU;&PL($1"7T524D]27TE.5D%,240L(&YU;&PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@;G5L;"P@(FEN
M=F%L:60@9FEE;&0Z("1P<F]P97)T>2(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@;G5L;"P@=')U92D["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BAN=6QL+"!$0E]%4E)/4E].3U-5
M0TA&245,1"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;G5L;"P@(G5N:VYO=VX@9FEE;&0Z("1P<F]P97)T>2(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL('1R=64I.PH@("`@?0H*
M("`@("\O('U]?0H@("`@+R\@>WM[("9G970H*0H*("`@("\J*@H@("`@("H@
M1F5T8V@@86X@871T<FEB=71E('9A;'5E+@H@("`@("H*("`@("`J($!P87)A
M;2!S=')I;F<@871T<FEB=71E(&YA;64*("`@("`J"B`@("`@*B!`<F5T=7)N
M(&%T=')I8G5T92!C;VYT96YT<RP@;W(@;G5L;"!I9B!T:&4@871T<FEB=71E
M(&YA;64@:7,*("`@("`J('5N:VYO=VX*("`@("`J+PH@("`@9G5N8W1I;VX@
M)F=E="@D<')O<&5R='DI"B`@("!["B`@("`@("`@+R\@;VYL>2!R971U<FX@
M:68@)'!R;W!E<G1Y(&ES(&MN;W=N"B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?<')O<&5R=&EE<ULD<')O<&5R='E=*2D@>PH@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/B1P<F]P97)T>3L*("`@("`@("!]"B`@("`@("`@)'1M<"`]
M(&YU;&P["B`@("`@("`@<F5T=7)N("1T;7`["B`@("!]"@H@("`@+R\@?7U]
M"B`@("`O+R![>WL@7T1"7W-T;W)A9V4H*0H*("`@("\J*@H@("`@("H@1&5S
M=')U8W1O<BP@8V%L;',@1$)?<W1O<F%G93HZ<W1O<F4H*2!I9B!T:&5R92!A
M<F4@8VAA;F=E<PH@("`@("H@=&AA="!A<F4@=&\@8F4@:V5P="X*("`@("`J
M+PH@("`@9G5N8W1I;VX@7T1"7W-T;W)A9V4H*0H@("`@>PH@("`@("`@(&EF
M("AS:7IE;V8H)'1H:7,M/E]C:&%N9V5S*2D@>PH@("`@("`@("`@("`D=&AI
M<RT^<W1O<F4H*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]P<F]P97)T
M:65S(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^7V-H86YG97,@/2!A<G)A
M>2@I.PH@("`@("`@("1T:&ES+3Y?=&%B;&4@/2!N=6QL.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[('-T;W)E*"D*"B`@("`O*BH*("`@("`J(%-T
M;W)E<R!C:&%N9V5S('1O('1H:7,@;V)J96-T(&EN('1H92!D871A8F%S92X*
M("`@("`J"B`@("`@*B!`<F5T=7)N($1"7T]+(&]R(&$@1$(@97)R;W(*("`@
M("`J+PH@("`@9G5N8W1I;VX@<W1O<F4H*0H@("`@>PH@("`@("`@(&9O<F5A
M8V@@*"1T:&ES+3Y?8VAA;F=E<R!A<R`D;F%M92`]/B`D9F]O*2!["B`@("`@
M("`@("`@("1P87)A;7-;72`]("8D=&AI<RT^)&YA;64["B`@("`@("`@("`@
M("1V87)S6UT@/2`D;F%M92`N("<@/2`_)SL*("`@("`@("!]"B`@("`@("`@
M:68@*"1V87)S*2!["B`@("`@("`@("`@("1Q=65R>2`]("=54$1!5$4@)R`N
M("1T:&ES+3Y?=&%B;&4@+B`G(%-%5"`G("X*("`@("`@("`@("`@("`@(&EM
M<&QO9&4H)RP@)RP@)'9A<G,I("X@)R!72$5212`G("X*("`@("`@("`@("`@
M("`@("1T:&ES+3Y?;6%K95=H97)E*"D["B`@("`@("`@("`@("1S=&UT(#T@
M)'1H:7,M/E]D8F@M/G!R97!A<F4H)'%U97)Y*3L*("`@("`@("`@("`@)')E
M<R`]("1T:&ES+3Y?9&)H+3YE>&5C=71E*"1S=&UT+"`D<&%R86US*3L*("`@
M("`@("`@("`@:68@*$1".CII<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)')E<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=&AI<RT^7V-H86YG97,@/2!A<G)A>2@I.PH@("`@("`@('T*("`@("`@("!R
M971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<F5M
M;W9E*"D*"B`@("`O*BH*("`@("`J(%)E;6]V92!T:&4@<F]W(')E<')E<V5N
M=&5D(&)Y('1H:7,@;V)J96-T(&9R;VT@=&AE(&1A=&%B87-E+@H@("`@("H*
M("`@("`J($!R971U<FX@;6EX960@1$)?3TL@;W(@82!$0B!E<G)O<@H@("`@
M("HO"B`@("!F=6YC=&EO;B!R96UO=F4H*0H@("`@>PH@("`@("`@(&EF("@D
M=&AI<RT^7W)E861O;FQY*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^
M<F%I<V5%<G)O<BAN=6QL+"!$0E]705).24Y'7U)%041?3TY,62P@;G5L;"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU
M;&PL(&YU;&PL('1R=64I.PH@("`@("`@('T*("`@("`@("`D<75E<GD@/2`G
M1$5,151%($923TT@)R`N("1T:&ES+3Y?=&%B;&4@+B<@5TA%4D4@)RX*("`@
M("`@("`@("`@)'1H:7,M/E]M86ME5VAE<F4H*3L*("`@("`@("`D<F5S(#T@
M)'1H:7,M/E]D8F@M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$1".CII
M<T5R<F]R*"1R97,I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S.PH@("`@
M("`@('T*("`@("`@("!F;W)E86-H("@D=&AI<RT^7W!R;W!E<G1I97,@87,@
M)'!R;W`@/3X@)&9O;RD@>PH@("`@("`@("`@("!U;G-E="@D=&AI<RT^)'!R
M;W`I.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^7W!R;W!E<G1I97,@/2!A
M<G)A>2@I.PH@("`@("`@("1T:&ES+3Y?8VAA;F=E<R`](&%R<F%Y*"D["B`@
M("`@("`@<F5T=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0I]"@HO*@H@
M*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T:#H@-`H@*B!C+6)A<VEC
M+6]F9G-E=#H@-`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S<B]L
M;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O1$(O<W%L:71E+G!H<```````````
M````````````````````````````````````````````````````````````
M```````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`W,C$T-2`Q,#4Q
M-30S-#$S,R`P,C`W-S$`(#``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-T87(`,#!B=6EL9&5R````
M`````````````````````````````&)R````````````````````````````
M````````````,#`P,#`P(``P,#`P,#`@````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@
M5&AE(%!%05(@1$(@9')I=F5R(&9O<B!02%`G<R!S<6QI=&4@97AT96YS:6]N
M"B`J(&9O<B!I;G1E<F%C=&EN9R!W:71H(%-13&ET92!D871A8F%S97,*("H*
M("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#14Y313H@5&AI<R!S
M;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!0
M2%`@;&EC96YS90H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W
M;W)L9"UW:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H*("H@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="X@($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F"B`J('1H92!02%`@3&EC96YS92!A;F0@87)E
M('5N86)L92!T;R!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V5B+"!P;&5A<V4*
M("H@<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN"B`J"B`J($!C871E9V]R>2`@
M($1A=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%5R
M<R!'96AR:6<@/'5R<T!C:7)C;&4N8V@^"B`J($!A=71H;W(@("`@($UI:V$@
M5'5U<&]L82`\='5U<&]L84!A<'!E;'-I:6YI+FYE=#X*("H@0&%U=&AO<B`@
M("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P
M>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@
M("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC
M96YS92`S+C`@,RXP"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!S<6QI=&4N
M<&AP+'8@,2XQ,#D@,C`P-2\P,R\Q,"`P,3HR,CHT."!D86YI96QC($5X<"`D
M"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$
M0@H@*B\*"B\J*@H@*B!/8G1A:6X@=&AE($1"7V-O;6UO;B!C;&%S<R!S;R!I
M="!C86X@8F4@97AT96YD960@9G)O;0H@*B\*<F5Q=6ER95]O;F-E("=$0B]C
M;VUM;VXN<&AP)SL*"B\J*@H@*B!4:&4@;65T:&]D<R!014%2($1"('5S97,@
M=&\@:6YT97)A8W0@=VET:"!02%`G<R!S<6QI=&4@97AT96YS:6]N"B`J(&9O
M<B!I;G1E<F%C=&EN9R!W:71H(%-13&ET92!D871A8F%S97,*("H*("H@5&AE
M<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE<R!D96-L87)E9"!I;B!$0E]C
M;VUM;VXN"B`J"B`J($Y/5$E#13H@(%1H:7,@9')I=F5R(&YE961S(%!(4"=S
M('1R86-K7V5R<F]R<R!I;FD@<V5T=&EN9R!T;R!B92!O;BX*("H@270@:7,@
M875T;VUA=&EC86QL>2!T=7)N960@;VX@=VAE;B!C;VYN96-T:6YG('1O('1H
M92!D871A8F%S92X*("H@36%K92!S=7)E('EO=7(@<V-R:7!T<R!D;VXG="!T
M=7)N(&ET(&]F9BX*("H*("H@0&-A=&5G;W)Y("`@1&%T86)A<V4*("H@0'!A
M8VMA9V4@("`@1$(*("H@0&%U=&AO<B`@("`@57)S($=E:')I9R`\=7)S0&-I
M<F-L92YC:#X*("H@0&%U=&AO<B`@("`@36EK82!4=75P;VQA(#QT=75P;VQA
M0&%P<&5L<VEI;FDN;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES
M<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P
M-2!4:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,"`S+C`*("H@
M0'9E<G-I;VX@("`@4F5L96%S93H@,2XW+C8*("H@0&QI;FL@("`@("`@:'1T
M<#HO+W!E87(N<&AP+FYE="]P86-K86=E+T1""B`J+PIC;&%S<R!$0E]S<6QI
M=&4@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E<G1I97,*
M"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES<6PL(&]C
M:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)'!H<'1Y<&4@/2`G<W%L:71E)SL*"B`@("`O*BH*("`@("`J(%1H
M92!D871A8F%S92!S>6YT87@@=F%R:6%N="!T;R!B92!U<V5D("AD8C(L(&%C
M8V5S<RP@971C+BDL(&EF(&%N>0H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1D8G-Y;G1A>"`]("=S<6QI=&4G.PH*("`@("\J*@H@("`@
M("H@5&AE(&-A<&%B:6QI=&EE<R!O9B!T:&ES($1"(&EM<&QE;65N=&%T:6]N
M"B`@("`@*@H@("`@("H@5&AE("=N97=?;&EN:R<@96QE;65N="!C;VYT86EN
M<R!T:&4@4$A0('9E<G-I;VX@=&AA="!F:7)S="!P<F]V:61E9`H@("`@("H@
M;F5W7VQI;FL@<W5P<&]R="!F;W(@=&AI<R!$0DU3+B`@0V]N=&%I;G,@9F%L
M<V4@:68@:70G<R!U;G-U<'!O<G1E9"X*("`@("`J"B`@("`@*B!-96%N:6YG
M(&]F('1H92`G;&EM:70G(&5L96UE;G0Z"B`@("`@*B`@("L@)V5M=6QA=&4G
M(#T@96UU;&%T92!W:71H(&9E=&-H(')O=R!B>2!N=6UB97(*("`@("`J("`@
M*R`G86QT97(G("`@/2!A;'1E<B!T:&4@<75E<GD*("`@("`J("`@*R!F86QS
M92`@("`@/2!S:VEP(')O=W,*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@
M("`@*B\*("`@('9A<B`D9F5A='5R97,@/2!A<G)A>2@*("`@("`@("`G;&EM
M:70G("`@("`@("`@/3X@)V%L=&5R)RP*("`@("`@("`G;F5W7VQI;FLG("`@
M("`@/3X@9F%L<V4L"B`@("`@("`@)VYU;7)O=W,G("`@("`@(#T^('1R=64L
M"B`@("`@("`@)W!C;VYN96-T)R`@("`@(#T^('1R=64L"B`@("`@("`@)W!R
M97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@("`@
M("`]/B!F86QS92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@9F%L<V4L
M"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV92!E
M<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H*("`@("`J('M`
M:6YT97)N86P@($5R<F]R(&-O9&5S(&%C8V]R9&EN9R!T;R!S<6QI=&5?97AE
M8RX@(%-E92!T:&4@;VYL:6YE"B`@("`@*B!M86YU86P@870@:'1T<#HO+W-Q
M;&ET92YO<F<O8U]I;G1E<F9A8V4N:'1M;"!F;W(@:6YF;RX*("`@("`J(%1H
M:7,@97)R;W(@:&%N9&QI;F<@8F%S960@;VX@<W%L:71E7V5X96,@:7,@;F]T
M('EE="!I;7!L96UE;G1E9"Y]?0H@("`@("H*("`@("`J($!V87(@87)R87D*
M("`@("`J+PH@("`@=F%R("1E<G)O<F-O9&5?;6%P(#T@87)R87DH"B`@("`I
M.PH*("`@("\J*@H@("`@("H@5&AE(')A=R!D871A8F%S92!C;VYN96-T:6]N
M(&-R96%T960@8GD@4$A0"B`@("`@*B!`=F%R(')E<V]U<F-E"B`@("`@*B\*
M("`@('9A<B`D8V]N;F5C=&EO;CL*"B`@("`O*BH*("`@("`J(%1H92!$4TX@
M:6YF;W)M871I;VX@9F]R(&-O;FYE8W1I;F<@=&\@82!D871A8F%S90H@("`@
M("H@0'9A<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&1S;B`](&%R<F%Y*"D[
M"@H*("`@("\J*@H@("`@("H@4U%,:71E(&1A=&$@='EP97,*("`@("`J"B`@
M("`@*B!`;&EN:R!H='1P.B\O=W=W+G-Q;&ET92YO<F<O9&%T871Y<&5S+FAT
M;6P*("`@("`J"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D
M:V5Y=V]R9',@/2!A<G)A>2`H"B`@("`@("`@)T),3T(G("`@("`@/3X@)R<L
M"B`@("`@("`@)T)/3TQ%04XG("`@/3X@)R<L"B`@("`@("`@)T-(05)!0U1%
M4B<@/3X@)R<L"B`@("`@("`@)T-,3T(G("`@("`@/3X@)R<L"B`@("`@("`@
M)T9,3T%4)R`@("`@/3X@)R<L"B`@("`@("`@)TE.5$5'15(G("`@/3X@)R<L
M"B`@("`@("`@)TM%62<@("`@("`@/3X@)R<L"B`@("`@("`@)TY!5$E/3D%,
M)R`@/3X@)R<L"B`@("`@("`@)TY5345224,G("`@/3X@)R<L"B`@("`@("`@
M)TY605)#2$%2)R`@/3X@)R<L"B`@("`@("`@)U!224U!4EDG("`@/3X@)R<L
M"B`@("`@("`@)U1%6%0G("`@("`@/3X@)R<L"B`@("`@("`@)U1)34535$%-
M4"<@/3X@)R<L"B`@("`@("`@)U5.25%512<@("`@/3X@)R<L"B`@("`@("`@
M)U9!4D-(05(G("`@/3X@)R<L"B`@("`@("`@)U9!4EE)3D<G("`@/3X@)R<L
M"B`@("`I.PH*("`@("\J*@H@("`@("H@5&AE(&UO<W0@<F5C96YT(&5R<F]R
M(&UE<W-A9V4@9G)O;2`D<&AP7V5R<F]R;7-G"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7VQA
M<W1E<G)O<B`]("<G.PH*"B`@("`O+R!]?7T*("`@("\O('M[>R!C;VYS=')U
M8W1O<@H*("`@("\J*@H@("`@("H@5&AI<R!C;VYS=')U8W1O<B!C86QL<R`\
M:V)D/B1T:&ES+3Y$0E]C;VUM;VXH*3PO:V)D/@H@("`@("H*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!$0E]S<6QI=&4H*0H@
M("`@>PH@("`@("`@("1T:&ES+3Y$0E]C;VUM;VXH*3L*("`@('T*"B`@("`O
M+R!]?7T*("`@("\O('M[>R!C;VYN96-T*"D*"B`@("`O*BH*("`@("`J($-O
M;FYE8W0@=&\@=&AE(&1A=&%B87-E('-E<G9E<BP@;&]G(&EN(&%N9"!O<&5N
M('1H92!D871A8F%S90H@("`@("H*("`@("`J($1O;B=T(&-A;&P@=&AI<R!M
M971H;V0@9&ER96-T;'DN("!5<V4@1$(Z.F-O;FYE8W0H*2!I;G-T96%D+@H@
M("`@("H*("`@("`J(%!%05(@1$(G<R!S<6QI=&4@9')I=F5R('-U<'!O<G1S
M('1H92!F;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@("L@
M;6]D92`@5&AE('!E<FUI<W-I;VYS(&9O<B!T:&4@9&%T86)A<V4@9FEL92P@
M:6X@9F]U<B!D:6=I=`H@("`@("H@("`@("`@("`@("!C:&UO9"!O8W1A;"!F
M;W)M870@*&5G("(P-C`P(BDN"B`@("`@*@H@("`@("H@17AA;7!L92!O9B!C
M;VYN96-T:6YG('1O(&$@9&%T86)A<V4@:6X@<F5A9"UO;FQY(&UO9&4Z"B`@
M("`@*B`\8V]D93X*("`@("`J(')E<75I<F5?;VYC92`G1$(N<&AP)SL*("`@
M("`J(`H@("`@("H@)&1S;B`]("=S<6QI=&4Z+R\O<&%T:"]A;F0O;F%M92]O
M9B]D8B]F:6QE/VUO9&4],#0P,"<["B`@("`@*B`D;W!T:6]N<R`](&%R<F%Y
M*`H@("`@("H@("`@("=P;W)T86)I;&ET>2<@/3X@1$)?4$]25$%"24Q)5%E?
M04Q,+`H@("`@("H@*3L*("`@("`J(`H@("`@("H@)&1B(#TF($1".CIC;VYN
M96-T*"1D<VXL("1O<'1I;VYS*3L*("`@("`J(&EF("A014%2.CII<T5R<F]R
M*"1D8BDI('L*("`@("`J("`@("!D:64H)&1B+3YG971-97-S86=E*"DI.PH@
M("`@("H@?0H@("`@("H@/"]C;V1E/@H@("`@("H*("`@("`J($!P87)A;2!A
M<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U<F-E(&YA;64*("`@("`J
M($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO=6QD('1H92!C;VYN96-T
M:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU
M<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE8W0H)&1S;BP@)'!E<G-I
M<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I9B`H(5!%05(Z.FQO861%
M>'1E;G-I;VXH)W-Q;&ET92<I*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]%6%1%3E-)3TY?3D]47T9/54Y$*3L*
M("`@("`@("!]"@H@("`@("`@("1T:&ES+3YD<VX@/2`D9'-N.PH@("`@("`@
M(&EF("@D9'-N6R=D8G-Y;G1A>"==*2!["B`@("`@("`@("`@("1T:&ES+3YD
M8G-Y;G1A>"`]("1D<VY;)V1B<WEN=&%X)UT["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)&1S;ELG9&%T86)A<V4G72D@>PH@("`@("`@("`@("!I9B`H(69I
M;&5?97AI<W1S*"1D<VY;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("`@
M("!I9B`H(71O=6-H*"1D<VY;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*$1"7T52
M4D]27TY/5%]&3U5.1"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!I9B`H(6ES<V5T*"1D<VY;)VUO9&4G72D@?'P*("`@("`@("`@("`@
M("`@("`@("`A:7-?;G5M97)I8R@D9'-N6R=M;V1E)UTI*0H@("`@("`@("`@
M("`@("`@>PH@("`@("`@("`@("`@("`@("`@("1M;V1E(#T@,#8T-#L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)&UO
M9&4@/2!O8W1D96,H)&1S;ELG;6]D92==*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&EF("@A8VAM;V0H)&1S;ELG9&%T86)A<V4G72P@
M)&UO9&4I*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS
M<6QI=&5286ES945R<F]R*$1"7T524D]27TY/5%]&3U5.1"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D
M<VY;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N
M("1T:&ES+3YS<6QI=&5286ES945R<F]R*$1"7T524D]27TY/5%]&3U5.1"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*"%I<U]F:6QE*"1D<VY;)V1A=&%B87-E)UTI*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@)'1H:7,M/G-Q;&ET95)A:7-E17)R;W(H1$)?15)23U)?
M24Y604Q)1"D["B`@("`@("`@("`@('T*("`@("`@("`@("`@:68@*"%I<U]R
M96%D86)L92@D9'-N6R=D871A8F%S92==*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*$1"7T524D]27T%#0T53
M4U]624],051)3TXI.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*$1"
M7T524D]27T%#0T534U]624],051)3TXI.PH@("`@("`@('T*"B`@("`@("`@
M)&-O;FYE8W1?9G5N8W1I;VX@/2`D<&5R<VES=&5N="`_("=S<6QI=&5?<&]P
M96XG(#H@)W-Q;&ET95]O<&5N)SL*"B`@("`@("`@+R\@=')A8VM?97)R;W)S
M(&UU<W0@<F5M86EN(&]N(&9O<B!S:6UP;&51=65R>2@I"B`@("`@("`@:6YI
M7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@)'!H<%]E<G)O<FUS
M9R`]("<G.PH*("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N(#T@0"1C
M;VYN96-T7V9U;F-T:6]N*"1D<VY;)V1A=&%B87-E)UTI*2!["B`@("`@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3T1"4T5,
M14-4140L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N
M=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!H<%]E<G)O<FUS9RD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!D:7-C
M;VYN96-T*"D*"B`@("`O*BH*("`@("`J($1I<V-O;FYE8W1S(&9R;VT@=&AE
M(&1A=&%B87-E('-E<G9E<@H@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@
M5%)512!O;B!S=6-C97-S+"!&04Q312!O;B!F86EL=7)E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(&1I<V-O;FYE8W0H*0H@("`@>PH@("`@("`@("1R970@/2!`
M<W%L:71E7V-L;W-E*"1T:&ES+3YC;VYN96-T:6]N*3L*("`@("`@("`D=&AI
M<RT^8V]N;F5C=&EO;B`](&YU;&P["B`@("`@("`@<F5T=7)N("1R970["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@<VEM<&QE475E<GDH*0H*("`@
M("\J*@H@("`@("H@4V5N9',@82!Q=65R>2!T;R!T:&4@9&%T86)A<V4@<V5R
M=F5R"B`@("`@*@H@("`@("H@3D]424-%.B`@5&AI<R!M971H;V0@;F5E9',@
M4$A0)W,@=')A8VM?97)R;W)S(&EN:2!S971T:6YG('1O(&)E(&]N+@H@("`@
M("H@270@:7,@875T;VUA=&EC86QL>2!T=7)N960@;VX@=VAE;B!C;VYN96-T
M:6YG('1O('1H92!D871A8F%S92X*("`@("`J($UA:V4@<W5R92!Y;W5R('-C
M<FEP=',@9&]N)W0@='5R;B!I="!O9F8N"B`@("`@*@H@("`@("H@0'!A<F%M
M('-T<FEN9R`@=&AE(%-13"!Q=65R>2!S=')I;F<*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("`K(&$@4$A0(')E<W5L="!R97-R;W5C92!F;W(@<W5C
M8V5S<V9U;"!314Q%0U0@<75E<FEE<PH@("`@("H@("`@("`@("`@("`@("`@
M*R!T:&4@1$)?3TL@8V]N<W1A;G0@9F]R(&]T:&5R('-U8V-E<W-F=6P@<75E
M<FEE<PH@("`@("H@("`@("`@("`@("`@("`@*R!A($1"7T5R<F]R(&]B:F5C
M="!O;B!F86EL=7)E"B`@("`@*B\*("`@(&9U;F-T:6]N('-I;7!L95%U97)Y
M*"1Q=65R>2D*("`@('L*("`@("`@("`D:7-M86YI<"`]($1".CII<TUA;FEP
M*"1Q=65R>2D["B`@("`@("`@)'1H:7,M/FQA<W1?<75E<GD@/2`D<75E<GD[
M"B`@("`@("`@)'%U97)Y(#T@)'1H:7,M/FUO9&EF>5%U97)Y*"1Q=65R>2D[
M"@H@("`@("`@("1P:'!?97)R;W)M<V<@/2`G)SL*"B`@("`@("`@)')E<W5L
M="`]($!S<6QI=&5?<75E<GDH)'%U97)Y+"`D=&AI<RT^8V]N;F5C=&EO;BD[
M"B`@("`@("`@)'1H:7,M/E]L87-T97)R;W(@/2`D<&AP7V5R<F]R;7-G(#\@
M)'!H<%]E<G)O<FUS9R`Z("<G.PH*("`@("`@("`D=&AI<RT^<F5S=6QT(#T@
M)')E<W5L=#L*("`@("`@("!I9B`H(21T:&ES+3YR97-U;'0I('L*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3YS<6QI=&5286ES945R<F]R*&YU;&PI.PH@
M("`@("`@('T*"B`@("`@("`@+R\@<W%L:71E7W%U97)Y*"D@<V5E;7,@=&\@
M86QL=V%Y<R!R971U<FX@82!R97-O=7)C90H@("`@("`@("\O('-O(&-A;G0@
M=7-E('1H870N(%5S:6YG("1I<VUA;FEP(&EN<W1E860*("`@("`@("!I9B`H
M(21I<VUA;FEP*2!["B`@("`@("`@("`@("1N=6U2;W=S(#T@)'1H:7,M/FYU
M;5)O=W,H)')E<W5L="D["B`@("`@("`@("`@(&EF("AI<U]O8FIE8W0H)&YU
M;5)O=W,I*2!["B`@("`@("`@("`@("`@("`O+R!W92=V92!G;W0@4$5!4E]%
M<G)O<@H@("`@("`@("`@("`@("`@<F5T=7)N("1N=6U2;W=S.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*
M("`@("`@("!R971U<FX@1$)?3TL["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@;F5X=%)E<W5L="@I"@H@("`@+RHJ"B`@("`@*B!-;W9E('1H92!I
M;G1E<FYA;"!S<6QI=&4@<F5S=6QT('!O:6YT97(@=&\@=&AE(&YE>'0@879A
M:6QA8FQE(')E<W5L=`H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D
M<F5S=6QT("!T:&4@=F%L:60@<W%L:71E(')E<W5L="!R97-O=7)C90H@("`@
M("H*("`@("`J($!R971U<FX@8F]O;"`@=')U92!I9B!A(')E<W5L="!I<R!A
M=F%I;&%B;&4@;W1H97)W:7-E(')E='5R;B!F86QS90H@("`@("HO"B`@("!F
M=6YC=&EO;B!N97AT4F5S=6QT*"1R97-U;'0I"B`@("!["B`@("`@("`@<F5T
M=7)N(&9A;'-E.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H
M26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@
M<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J
M($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@
M87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H
M26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN
M("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@
M("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@
M("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT
M:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H,"`]
M(&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/
M2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L="!S
M970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N(&9A
M:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D
M87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H)')O=VYU;2`A/3T@;G5L;"D@>PH@("`@("`@("`@("!I9B`H(4!S
M<6QI=&5?<V5E:R@D=&AI<RT^<F5S=6QT+"`D<F]W;G5M*2D@>PH@("`@("`@
M("`@("`@("`@<F5T=7)N(&YU;&P["B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("`@("`@:68@*"1F971C:&UO9&4@)B!$0E]&151#2$U/1$5?05-33T,I
M('L*("`@("`@("`@("`@)&%R<B`]($!S<6QI=&5?9F5T8VA?87)R87DH)')E
M<W5L="P@4U%,251%7T%34T]#*3L*("`@("`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6R=P;W)T86)I;&ET>2==("8@1$)?4$]25$%"24Q)5%E?3$]715)#
M05-%("8F("1A<G(I('L*("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]C
M:&%N9V5?:V5Y7V-A<V4H)&%R<BP@0T%315],3U=%4BD["B`@("`@("`@("`@
M('T*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D87)R(#T@0'-Q;&ET
M95]F971C:%]A<G)A>2@D<F5S=6QT+"!344Q)5$5?3E5-*3L*("`@("`@("!]
M"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;)W!O<G1A
M8FEL:71Y)UT@)B!$0E]03U)404))3$E465]25%))32D@>PH@("`@("`@("`@
M("`O*@H@("`@("`@("`@("`@*B!%=F5N('1H;W5G:"!T:&ES($1"35,@86QR
M96%D>2!T<FEM<R!O=71P=70L('=E(&1O('1H:7,@8F5C875S90H@("`@("`@
M("`@("`@*B!A(&9I96QD(&UI9VAT(&AA=F4@:6YT96YT:6]N86P@=VAI=&5S
M<&%C92!A="!T:&4@96YD('1H870*("`@("`@("`@("`@("H@9V5T<R!R96UO
M=F5D(&)Y($1"7U!/4E1!0DE,25197U)44DE-('5N9&5R(&%N;W1H97(@9')I
M=F5R+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@)'1H:7,M/E]R=')I
M;4%R<F%Y5F%L=65S*"1A<G(I.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465].
M54Q,7U1/7T5-4%19*2!["B`@("`@("`@("`@("1T:&ES+3Y?8V]N=F5R=$YU
M;&Q!<G)A>59A;'5E<U1O16UP='DH)&%R<BD["B`@("`@("`@?0H@("`@("`@
M(')E='5R;B!$0E]/2SL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!F
M<F5E4F5S=6QT*"D*"B`@("`O*BH*("`@("`J($1E;&5T97,@=&AE(')E<W5L
M="!S970@86YD(&9R965S('1H92!M96UO<GD@;V-C=7!I960@8GD@=&AE(')E
M<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A
M;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$0E]R97-U
M;'0Z.F9R964H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R
M;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A
M=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S
M=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&)O;VP@(%12544@;VX@<W5C8V5S<RP@1D%,4T4@:68@)')E
M<W5L="!I<R!I;G9A;&ED"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z
M.F9R964H*0H@("`@("HO"B`@("!F=6YC=&EO;B!F<F5E4F5S=6QT*"8D<F5S
M=6QT*0H@("`@>PH@("`@("`@("\O(%A86"!.;R!N871I=F4@9G)E93\*("`@
M("`@("!I9B`H(6ES7W)E<V]U<F-E*"1R97-U;'0I*2!["B`@("`@("`@("`@
M(')E='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@)')E<W5L="`](&YU
M;&P["B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@
M("`O+R![>WL@;G5M0V]L<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N
M=6UB97(@;V8@8V]L=6UN<R!I;B!A(')E<W5L="!S970*("`@("`J"B`@("`@
M*B!4:&ES(&UE=&AO9"!I<R!N;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C
M=&QY+B`@57-E"B`@("`@*B!$0E]R97-U;'0Z.FYU;4-O;',H*2!I;G-T96%D
M+B`@270@8V%N)W0@8F4@9&5C;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E
M8V%U<V4@1$)?<F5S=6QT(&ES(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*
M("`@("`J($!P87)A;2!R97-O=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R
M97-U;'0@<F5S;W5R8V4*("`@("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE
M(&YU;6)E<B!O9B!C;VQU;6YS+B`@02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I
M;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ;G5M0V]L<R@I
M"B`@("`@*B\*("`@(&9U;F-T:6]N(&YU;4-O;',H)')E<W5L="D*("`@('L*
M("`@("`@("`D8V]L<R`]($!S<6QI=&5?;G5M7V9I96QD<R@D<F5S=6QT*3L*
M("`@("`@("!I9B`H(21C;VQS*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI
M<RT^<W%L:71E4F%I<V5%<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)&-O;',["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@;G5M4F]W
M<R@I"@H@("`@+RHJ"B`@("`@*B!'971S('1H92!N=6UB97(@;V8@<F]W<R!I
M;B!A(')E<W5L="!S970*("`@("`J"B`@("`@*B!4:&ES(&UE=&AO9"!I<R!N
M;W0@;65A;G0@=&\@8F4@8V%L;&5D(&1I<F5C=&QY+B`@57-E"B`@("`@*B!$
M0E]R97-U;'0Z.FYU;5)O=W,H*2!I;G-T96%D+B`@270@8V%N)W0@8F4@9&5C
M;&%R960@(G!R;W1E8W1E9"(*("`@("`J(&)E8V%U<V4@1$)?<F5S=6QT(&ES
M(&$@<V5P87)A=&4@;V)J96-T+@H@("`@("H*("`@("`J($!P87)A;2!R97-O
M=7)C92`D<F5S=6QT("!02%`G<R!Q=65R>2!R97-U;'0@<F5S;W5R8V4*("`@
M("`J"B`@("`@*B!`<F5T=7)N(&EN="`@=&AE(&YU;6)E<B!O9B!R;W=S+B`@
M02!$0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`
M<V5E($1"7W)E<W5L=#HZ;G5M4F]W<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N
M(&YU;5)O=W,H)')E<W5L="D*("`@('L*("`@("`@("`D<F]W<R`]($!S<6QI
M=&5?;G5M7W)O=W,H)')E<W5L="D["B`@("`@("`@:68@*"1R;W=S(#T]/2!N
M=6QL*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<W%L:71E4F%I<V5%
M<G)O<B@I.PH@("`@("`@('T*("`@("`@("!R971U<FX@)')O=W,["B`@("!]
M"@H@("`@+R\@?7U]"B`@("`O+R![>WL@869F96-T960H*0H*("`@("\J*@H@
M("`@("H@1&5T97)M:6YE<R!T:&4@;G5M8F5R(&]F(')O=W,@869F96-T960@
M8GD@82!D871A(&UA;FEU<&QA=&EO;B!Q=65R>0H@("`@("H*("`@("`J(#`@
M:7,@<F5T=7)N960@9F]R('%U97)I97,@=&AA="!D;VXG="!M86YI<'5L871E
M(&1A=&$N"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@
M;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%F9F5C=&5D4F]W<R@I"B`@("!["B`@("`@("`@
M<F5T=7)N($!S<6QI=&5?8VAA;F=E<R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9')O<%-E<75E;F-E*"D*"B`@
M("`O*BH*("`@("`J($1E;&5T97,@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@)'-E<5]N86UE("!N86UE(&]F('1H92!S97%U96YC
M92!T;R!B92!D96QE=&5D"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@($1"
M7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL=7)E
M+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CID<F]P4V5Q=65N8V4H
M*2P@1$)?8V]M;6]N.CIG971397%U96YC94YA;64H*2P*("`@("`J("`@("`@
M1$)?<W%L:71E.CIN97AT240H*2P@1$)?<W%L:71E.CIC<F5A=&5397%U96YC
M92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&1R;W!397%U96YC92@D<V5Q7VYA
M;64I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YQ=65R>2@G1%)/4"!4
M04),12`G("X@)'1H:7,M/F=E=%-E<75E;F-E3F%M92@D<V5Q7VYA;64I*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($-R96%T97,@82!N97<@<V5Q=65N8V4*
M("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97%?;F%M92`@;F%M92!O
M9B!T:&4@;F5W('-E<75E;F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@
M($1"7T]+(&]N('-U8V-E<W,N("!!($1"7T5R<F]R(&]B:F5C="!O;B!F86EL
M=7)E+@H@("`@("H*("`@("`J($!S964@1$)?8V]M;6]N.CIC<F5A=&5397%U
M96YC92@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E3F%M92@I+`H@("`@("H@
M("`@("!$0E]S<6QI=&4Z.FYE>'1)1"@I+"!$0E]S<6QI=&4Z.F1R;W!397%U
M96YC92@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&-R96%T95-E<75E;F-E*"1S
M97%?;F%M92D*("`@('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG9713
M97%U96YC94YA;64H)'-E<5]N86UE*3L*("`@("`@("`D<75E<GD@("`]("=#
M4D5!5$4@5$%"3$4@)R`N("1S97%N86UE("X*("`@("`@("`@("`@("`@("`@
M("<@*&ED($E.5$5'15(@54Y324=.140@4%))34%262!+15DI("<["B`@("`@
M("`@)')E<W5L="`@/2`D=&AI<RT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@<F5T=7)N
M*"1R97-U;'0I.PH@("`@("`@('T*("`@("`@("`D<75E<GD@("`](")#4D5!
M5$4@5%))1T=%4B`D>W-E<6YA;65]7V-L96%N=7`@049415(@24Y315)4($].
M("1S97%N86UE"B`@("`@("`@("`@("`@("`@("`@0D5'24X*("`@("`@("`@
M("`@("`@("`@("`@("`@1$5,151%($923TT@)'-E<6YA;64@5TA%4D4@:60\
M3$%35%])3E-%4E1?4D]7240H*3L*("`@("`@("`@("`@("`@("`@("!%3D0@
M(CL*("`@("`@("`D<F5S=6QT("`]("1T:&ES+3YQ=65R>2@D<75E<GDI.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("!R971U<FXH)')E<W5L="D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]
M?0H@("`@+R\@>WM[(&YE>'1)9"@I"@H@("`@+RHJ"B`@("`@*B!2971U<FYS
M('1H92!N97AT(&9R964@:60@:6X@82!S97%U96YC90H@("`@("H*("`@("`J
M($!P87)A;2!S=')I;F<@("1S97%?;F%M92`@;F%M92!O9B!T:&4@<V5Q=65N
M8V4*("`@("`J($!P87)A;2!B;V]L96%N("1O;F1E;6%N9"`@=VAE;B!T<G5E
M+"!T:&4@<V5Q96YC92!I<R!A=71O;6%T:6-A;&QY"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!C<F5A=&5D(&EF(&ET(&1O97,@;F]T(&5X
M:7-T"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N97AT(&ED(&YU
M;6)E<B!I;B!T:&4@<V5Q=65N8V4N"B`@("`@*B`@("`@("`@("`@("`@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]C;VUM;VXZ.FYE>'1)1"@I+"!$0E]C;VUM;VXZ.F=E=%-E<75E;F-E
M3F%M92@I+`H@("`@("H@("`@("!$0E]S<6QI=&4Z.F-R96%T95-E<75E;F-E
M*"DL($1"7W-Q;&ET93HZ9')O<%-E<75E;F-E*"D*("`@("`J+PH@("`@9G5N
M8W1I;VX@;F5X=$ED*"1S97%?;F%M92P@)&]N9&5M86YD(#T@=')U92D*("`@
M('L*("`@("`@("`D<V5Q;F%M92`]("1T:&ES+3YG971397%U96YC94YA;64H
M)'-E<5]N86UE*3L*"B`@("`@("`@9&\@>PH@("`@("`@("`@("`D<F5P96%T
M(#T@,#L*("`@("`@("`@("`@)'1H:7,M/G!U<VA%<G)O<DAA;F1L:6YG*%!%
M05)?15)23U)?4D5455).*3L*("`@("`@("`@("`@)')E<W5L="`]("1T:&ES
M+3YQ=65R>2@B24Y315)4($E.5$\@)'-E<6YA;64@*&ED*2!604Q515,@*$Y5
M3$PI(BD["B`@("`@("`@("`@("1T:&ES+3YP;W!%<G)O<DAA;F1L:6YG*"D[
M"B`@("`@("`@("`@(&EF("@D<F5S=6QT(#T]/2!$0E]/2RD@>PH@("`@("`@
M("`@("`@("`@)&ED(#T@0'-Q;&ET95]L87-T7VEN<V5R=%]R;W=I9"@D=&AI
M<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@("`@("!I9B`H)&ED("$](#`I
M('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&ED.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&]N9&5M86YD("8F($1"
M.CII<T5R<F]R*"1R97-U;'0I("8F"B`@("`@("`@("`@("`@("`@("`@("`D
M<F5S=6QT+3YG971#;V1E*"D@/3T@1$)?15)23U)?3D]354-(5$%"3$4I"B`@
M("`@("`@("`@('L*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^
M8W)E871E4V5Q=65N8V4H)'-E<5]N86UE*3L*("`@("`@("`@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@D<F5S=6QT*3L*("`@("`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)')E<&5A="`]
M(#$["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M('=H:6QE("@D<F5P96%T*3L*"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES
M945R<F]R*"1R97-U;'0I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M(&=E=$1B1FEL95-T871S*"D*"B`@("`O*BH*("`@("`J($=E="!T:&4@9FEL
M92!S=&%T<R!F;W(@=&AE(&-U<G)E;G0@9&%T86)A<V4*("`@("`J"B`@("`@
M*B!0;W-S:6)L92!A<F=U;65N=',@87)E(&1E=BP@:6YO+"!M;V1E+"!N;&EN
M:RP@=6ED+"!G:60L(')D978L('-I>F4L"B`@("`@*B!A=&EM92P@;71I;64L
M(&-T:6UE+"!B;&MS:7IE+"!B;&]C:W,@;W(@82!N=6UE<FEC(&ME>2!B971W
M965N"B`@("`@*B`P(&%N9"`Q,BX*("`@("`J"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1A<F<@('1H92!A<G)A>2!K97D@9F]R('-T871S*"D*("`@("`J"B`@
M("`@*B!`<F5T=7)N(&UI>&5D("!A;B!A<G)A>2!O;B!A;B!U;G-P96-I9FEE
M9"!K97DL(&EN=&5G97(@;VX@82!P87-S960*("`@("`J("`@("`@("`@("`@
M("`@(&%R9R!A;F0@9F%L<V4@870@82!S=&%T<R!E<G)O<@H@("`@("HO"B`@
M("!F=6YC=&EO;B!G971$8D9I;&53=&%T<R@D87)G(#T@)R<I"B`@("!["B`@
M("`@("`@)'-T871S(#T@<W1A="@D=&AI<RT^9'-N6R=D871A8F%S92==*3L*
M("`@("`@("!I9B`H)'-T871S(#T](&9A;'-E*2!["B`@("`@("`@("`@(')E
M='5R;B!F86QS93L*("`@("`@("!]"B`@("`@("`@:68@*&ES7V%R<F%Y*"1S
M=&%T<RDI('L*("`@("`@("`@("`@:68@*&ES7VYU;65R:6,H)&%R9RDI('L*
M("`@("`@("`@("`@("`@(&EF("@H*&EN="DD87)G(#P](#$R*2`F("@H:6YT
M*21A<F<@/CT@,"DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!R971U<FX@
M)'-T871S6R1A<F<@73L*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H
M87)R87E?:V5Y7V5X:7-T<RAT<FEM*"1A<F<I+"`D<W1A=',I*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@)'-T871S6R1A<F<@73L*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'-T871S.PH@("`@?0H*("`@
M("\O('U]?0H@("`@+R\@>WM[(&5S8V%P95-I;7!L92@I"@H@("`@+RHJ"B`@
M("`@*B!%<V-A<&5S(&$@<W1R:6YG(&%C8V]R9&EN9R!T;R!T:&4@8W5R<F5N
M="!$0DU3)W,@<W1A;F1A<F1S"B`@("`@*@H@("`@("H@26X@4U%,:71E+"!T
M:&ES(&UA:V5S('1H:6YG<R!S869E(&9O<B!I;G-E<G1S+W5P9&%T97,L(&)U
M="!M87D*("`@("`J(&-A=7-E('!R;V)L96US('=H96X@<&5R9F]R;6EN9R!T
M97AT(&-O;7!A<FES;VYS(&%G86EN<W0@8V]L=6UN<PH@("`@("H@8V]N=&%I
M;FEN9R!B:6YA<GD@9&%T82X@4V5E('1H90H@("`@("H@>T!L:6YK(&AT='`Z
M+R]P:'`N;F5T+W-Q;&ET95]E<V-A<&5?<W1R:6YG(%!(4"!M86YU86Q](&9O
M<B!M;W)E(&EN9F\N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<W1R
M("!T:&4@<W1R:6YG('1O(&)E(&5S8V%P960*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE(&5S8V%P960@<W1R:6YG"B`@("`@*@H@("`@("H@
M0'-I;F-E($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C8N,0H@
M("`@("H@0'-E92!$0E]C;VUM;VXZ.F5S8V%P95-I;7!L92@I"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&5S8V%P95-I;7!L92@D<W1R*0H@("`@>PH@("`@("`@
M(')E='5R;B!`<W%L:71E7V5S8V%P95]S=')I;F<H)'-T<BD["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@;6]D:69Y3&EM:711=65R>2@I"@H@("`@
M+RHJ"B`@("`@*B!!9&1S($Q)34E4(&-L875S97,@=&\@82!Q=65R>2!S=')I
M;F<@86-C;W)D:6YG('1O(&-U<G)E;G0@1$)-4R!S=&%N9&%R9',*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1Q=65R>2`@('1H92!Q=65R>2!T;R!M
M;V1I9GD*("`@("`J($!P87)A;2!I;G0@("`@)&9R;VT@("`@=&AE(')O=R!T
M;R!S=&%R="!T;R!F971C:&EN9R`H,"`]('1H92!F:7)S="!R;W<I"B`@("`@
M*B!`<&%R86T@:6YT("`@("1C;W5N="`@('1H92!N=6UB97)S(&]F(')O=W,@
M=&\@9F5T8V@*("`@("`J($!P87)A;2!M:7AE9"`@)'!A<F%M<R`@87)R87DL
M('-T<FEN9R!O<B!N=6UE<FEC(&1A=&$@=&\@8F4@=7-E9"!I;@H@("`@("H@
M("`@("`@("`@("`@("`@("`@("`@("`@97AE8W5T:6]N(&]F('1H92!S=&%T
M96UE;G0N("!1=6%N=&ET>2!O9B!I=&5M<PH@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@<&%S<V5D(&UU<W0@;6%T8V@@<75A;G1I='D@;V8@<&QA
M8V5H;VQD97)S(&EN"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!Q
M=65R>3H@(&UE86YI;F<@,2!P;&%C96AO;&1E<B!F;W(@;F]N+6%R<F%Y"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("!P87)A;65T97)S(&]R(#$@
M<&QA8V5H;VQD97(@<&5R(&%R<F%Y(&5L96UE;G0N"B`@("`@*@H@("`@("H@
M0')E='5R;B!S=')I;F<@('1H92!Q=65R>2!S=')I;F<@=VET:"!,24U)5"!C
M;&%U<V5S(&%D9&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*
M("`@("`J+PH@("`@9G5N8W1I;VX@;6]D:69Y3&EM:711=65R>2@D<75E<GDL
M("1F<F]M+"`D8V]U;G0L("1P87)A;7,@/2!A<G)A>2@I*0H@("`@>PH@("`@
M("`@(')E='5R;B`B)'%U97)Y($Q)34E4("1C;W5N="!/1D93150@)&9R;VTB
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&UO9&EF>5%U97)Y*"D*
M"B`@("`O*BH*("`@("`J($-H86YG97,@82!Q=65R>2!S=')I;F<@9F]R('9A
M<FEO=7,@1$)-4R!S<&5C:69I8R!R96%S;VYS"B`@("`@*@H@("`@("H@5&AI
M<R!L:71T;&4@:&%C:R!L971S('EO=2!K;F]W(&AO=R!M86YY(')O=W,@=V5R
M92!D96QE=&5D"B`@("`@*B!W:&5N(')U;FYI;F<@82`B1$5,151%($923TT@
M=&%B;&4B('%U97)Y+B`@3VYL>2!I;7!L96UE;G1E9`H@("`@("H@:68@=&AE
M($1"7U!/4E1!0DE,25197T1%3$5415]#3U5.5"!P;W)T86)I;&ET>2!O<'1I
M;VX@:7,@;VXN"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D<75E<GD@
M('1H92!Q=65R>2!S=')I;F<@=&\@;6]D:69Y"B`@("`@*@H@("`@("H@0')E
M='5R;B!S=')I;F<@('1H92!M;V1I9FEE9"!Q=65R>2!S=')I;F<*("`@("`J
M"B`@("`@*B!`86-C97-S('!R;W1E8W1E9`H@("`@("H@0'-E92!$0E]C;VUM
M;VXZ.G-E=$]P=&EO;B@I"B`@("`@*B\*("`@(&9U;F-T:6]N(&UO9&EF>5%U
M97)Y*"1Q=65R>2D*("`@('L*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;
M)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]$14Q%5$5?0T]53E0I
M('L*("`@("`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>7',J1$5,151%7',K
M1E)/35QS*RA<4RLI7',J)"]I)RP@)'%U97)Y*2D@>PH@("`@("`@("`@("`@
M("`@)'%U97)Y(#T@<')E9U]R97!L86-E*"<O7EQS*D1%3$5415QS*T923TU<
M<RLH7%,K*5QS*B0O)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G1$5,151%($923TT@7#$@5TA%4D4@,3TQ)RP@)'%U97)Y*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)'%U97)Y
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-Q;&ET95)A:7-E17)R
M;W(H*0H*("`@("\J*@H@("`@("H@4')O9'5C97,@82!$0E]%<G)O<B!O8FIE
M8W0@<F5G87)D:6YG('1H92!C=7)R96YT('!R;V)L96T*("`@("`J"B`@("`@
M*B!`<&%R86T@:6YT("1E<G)N;R`@:68@=&AE(&5R<F]R(&ES(&)E:6YG(&UA
M;G5A;&QY(')A:7-E9"!P87-S(&$*("`@("`J("`@("`@("`@("`@("`@("`@
M("`@1$)?15)23U(J(&-O;G-T86YT(&AE<F4N("!)9B!T:&ES(&ES;B=T('!A
M<W-E9`H@("`@("H@("`@("`@("`@("`@("`@("`@("!T:&4@97)R;W(@:6YF
M;W)M871I;VX@9V%T:&5R960@9G)O;2!T:&4@1$)-4RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N(&]B:F5C="`@=&AE($1"7T5R<F]R(&]B:F5C=`H@("`@("H*
M("`@("`J($!S964@1$)?8V]M;6]N.CIR86ES945R<F]R*"DL"B`@("`@*B`@
M("`@($1"7W-Q;&ET93HZ97)R;W).871I=F4H*2P@1$)?<W%L:71E.CIE<G)O
M<D-O9&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!S<6QI=&5286ES945R<F]R
M*"1E<G)N;R`](&YU;&PI"B`@("!["B`@("`@("`@)&YA=&EV92`]("1T:&ES
M+3YE<G)O<DYA=&EV92@I.PH@("`@("`@(&EF("@D97)R;F\@/3T](&YU;&PI
M('L*("`@("`@("`@("`@)&5R<FYO(#T@)'1H:7,M/F5R<F]R0V]D92@D;F%T
M:79E*3L*("`@("`@("!]"@H@("`@("`@("1E<G)O<F-O9&4@/2!`<W%L:71E
M7VQA<W1?97)R;W(H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@("`@("1U<V5R
M:6YF;R`]("(D97)R;W)C;V1E("HJ("1T:&ES+3YL87-T7W%U97)Y(CL*"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"1E<G)N;RP@;G5L;"P@
M;G5L;"P@)'5S97)I;F9O+"`D;F%T:79E*3L*("`@('T*"B`@("`O+R!]?7T*
M("`@("\O('M[>R!E<G)O<DYA=&EV92@I"@H@("`@+RHJ"B`@("`@*B!'971S
M('1H92!$0DU3)R!N871I=F4@97)R;W(@;65S<V%G92!P<F]D=6-E9"!B>2!T
M:&4@;&%S="!Q=65R>0H@("`@("H*("`@("`J('M`:6YT97)N86P@5&AI<R!I
M<R!U<V5D('1O(')E=')I979E(&UO<F4@;65A;FEN9V9U;&P@97)R;W(@;65S
M<V%G97,*("`@("`J(&)E8V%U<V4@<W%L:71E7VQA<W1?97)R;W(H*2!D;V5S
M(&YO="!P<F]V:61E(&%D97%U871E(&EN9F\N?7T*("`@("`J"B`@("`@*B!`
M<F5T=7)N('-T<FEN9R`@=&AE($1"35,G(&5R<F]R(&UE<W-A9V4*("`@("`J
M+PH@("`@9G5N8W1I;VX@97)R;W).871I=F4H*0H@("`@>PH@("`@("`@(')E
M='5R;B`D=&AI<RT^7VQA<W1E<G)O<CL*("`@('T*"B`@("`O+R!]?7T*("`@
M("\O('M[>R!E<G)O<D-O9&4H*0H*("`@("\J*@H@("`@("H@1&5T97)M:6YE
M<R!014%2.CI$0B!E<G)O<B!C;V1E(&9R;VT@=&AE(&1A=&%B87-E)W,@=&5X
M="!E<G)O<B!M97-S86=E"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D
M97)R;W)M<V<@('1H92!E<G)O<B!M97-S86=E(')E='5R;F5D(&9R;VT@=&AE
M(&1A=&%B87-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G1E9V5R("!T:&4@
M1$(@97)R;W(@;G5M8F5R"B`@("`@*B\*("`@(&9U;F-T:6]N(&5R<F]R0V]D
M92@D97)R;W)M<V<I"B`@("!["B`@("`@("`@<W1A=&EC("1E<G)O<E]R96=E
M>'!S.PH@("`@("`@(&EF("@A:7-S970H)&5R<F]R7W)E9V5X<',I*2!["B`@
M("`@("`@("`@("1E<G)O<E]R96=E>'!S(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`G+UYN;R!S=6-H('1A8FQE.B\G(#T^($1"7T524D]27TY/4U5#2%1!
M0DQ%+`H@("`@("`@("`@("`@("`@)R]>;F\@<W5C:"!I;F1E>#HO)R`]/B!$
M0E]%4E)/4E].3U1?1D]53D0L"B`@("`@("`@("`@("`@("`G+UXH=&%B;&5\
M:6YD97@I("XJ(&%L<F5A9'D@97AI<W1S)"\G(#T^($1"7T524D]27T%,4D5!
M1%E?15A)4U13+`H@("`@("`@("`@("`@("`@)R]04DE-05)9($M%62!M=7-T
M(&)E('5N:7%U92]I)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@
M("`@("`@("`@)R]I<R!N;W0@=6YI<75E+R<@/3X@1$)?15)23U)?0T].4U12
M04E.5"P*("`@("`@("`@("`@("`@("<O8V]L=6UN<R`N*B!A<F4@;F]T('5N
M:7%U92]I)R`]/B!$0E]%4E)/4E]#3TY35%)!24Y4+`H@("`@("`@("`@("`@
M("`@)R]U;FEQ=65N97-S(&-O;G-T<F%I;G0@9F%I;&5D+R<@/3X@1$)?15)2
M3U)?0T].4U1204E.5"P*("`@("`@("`@("`@("`@("<O;6%Y(&YO="!B92!.
M54Q,+R<@/3X@1$)?15)23U)?0T].4U1204E.5%].3U1?3E5,3"P*("`@("`@
M("`@("`@("`@("<O7FYO('-U8V@@8V]L=6UN.B\G(#T^($1"7T524D]27TY/
M4U5#2$9)14Q$+`H@("`@("`@("`@("`@("`@)R]C;VQU;6X@;F]T('!R97-E
M;G0@:6X@8F]T:"!T86)L97,O:2<@/3X@1$)?15)23U)?3D]354-(1DE%3$0L
M"B`@("`@("`@("`@("`@("`G+UYN96%R("(N*B(Z('-Y;G1A>"!E<G)O<B0O
M)R`]/B!$0E]%4E)/4E]364Y405@L"B`@("`@("`@("`@("`@("`G+ULP+3E=
M*R!V86QU97,@9F]R(%LP+3E=*R!C;VQU;6YS+VDG(#T^($1"7T524D]27U9!
M3%5%7T-/54Y47T].7U)/5RP*("`@("`@("`@("`@*3L*("`@("`@("!]"B`@
M("`@("`@9F]R96%C:"`H)&5R<F]R7W)E9V5X<',@87,@)')E9V5X<"`]/B`D
M8V]D92D@>PH@("`@("`@("`@("!I9B`H<')E9U]M871C:"@D<F5G97AP+"`D
M97)R;W)M<V<I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)&-O9&4["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@+R\@1F%L;"!B86-K('1O
M($1"7T524D]2(&EF('1H97)E('=A<R!N;R!M87!P:6YG+@H@("`@("`@(')E
M='5R;B!$0E]%4E)/4CL*("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!T
M86)L94EN9F\H*0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!I;F9O<FUA=&EO
M;B!A8F]U="!A('1A8FQE"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@("`@("1R97-U;'0@(&$@<W1R:6YG(&-O;G1A:6YI;F<@=&AE(&YA;64@
M;V8@82!T86)L90H@("`@("H@0'!A<F%M(&EN="`@("`@("`@("`@("1M;V1E
M("`@(&$@=F%L:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T
M=7)N(&%R<F%Y("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O
M<FUA=&EO;B!R97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$
M0E]%<G)O<B!O8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E
M($1"7V-O;6UO;CHZ=&%B;&5);F9O*"D*("`@("`J($!S:6YC92!-971H;V0@
M879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@9G5N
M8W1I;VX@=&%B;&5);F9O*"1R97-U;'0L("1M;V1E(#T@;G5L;"D*("`@('L*
M("`@("`@("!I9B`H:7-?<W1R:6YG*"1R97-U;'0I*2!["B`@("`@("`@("`@
M("\J"B`@("`@("`@("`@("`J(%!R;V)A8FQY(')E8V5I=F5D(&$@=&%B;&4@
M;F%M92X*("`@("`@("`@("`@("H@0W)E871E(&$@<F5S=6QT(')E<V]U<F-E
M(&ED96YT:69I97(N"B`@("`@("`@("`@("`J+PH@("`@("`@("`@("`D:60@
M/2!`<W%L:71E7V%R<F%Y7W%U97)Y*"1T:&ES+3YC;VYN96-T:6]N+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")04D%'34$@=&%B
M;&5?:6YF;R@G)')E<W5L="<I.R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@4U%,251%7T%34T]#*3L*("`@("`@("`@("`@)&=O
M=%]S=')I;F<@/2!T<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1T:&ES+3YL87-T7W%U97)Y(#T@)R<["B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E].3U1?0T%004),12P@;G5L;"P@
M;G5L;"P@;G5L;"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("=4:&ES($1"35,@8V%N(&YO="!O8G1A:6X@=&%B;&5);F9O)R`N"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G(&9R;VT@<F5S
M=6QT('-E=',G*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TQ/5T520T%3
M12D@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T<G1O;&]W97(G.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("1C87-E7V9U;F,@/2`G<W1R
M=F%L)SL*("`@("`@("!]"@H@("`@("`@("1C;W5N="`](&-O=6YT*"1I9"D[
M"B`@("`@("`@)')E<R`@(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1M;V1E
M*2!["B`@("`@("`@("`@("1R97-;)VYU;5]F:65L9',G72`]("1C;W5N=#L*
M("`@("`@("!]"@H@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\("1C;W5N=#L@
M)&DK*RD@>PH@("`@("`@("`@("!I9B`H<W1R<&]S*"1I9%LD:5U;)W1Y<&4G
M72P@)R@G*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1B:71S(#T@
M97AP;&]D92@G*"<L("1I9%LD:5U;)W1Y<&4G72D["B`@("`@("`@("`@("`@
M("`D='EP92`]("1B:71S6S!=.PH@("`@("`@("`@("`@("`@)&QE;B`@/2!R
M=')I;2@D8FET<ULQ72PG*2<I.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@)'1Y<&4@/2`D:61;)&E=6R=T>7!E)UT["B`@("`@("`@
M("`@("`@("`D;&5N("`](#`["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1F;&%G<R`]("<G.PH@("`@("`@("`@("!I9B`H)&ED6R1I75LG<&LG72D@
M>PH@("`@("`@("`@("`@("`@)&9L86=S("X]("=P<FEM87)Y7VME>2`G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D:61;)&E=6R=N;W1N=6QL
M)UTI('L*("`@("`@("`@("`@("`@("1F;&%G<R`N/2`G;F]T7VYU;&P@)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)&ED6R1I75LG9&9L=%]V
M86QU92==("$]/2!N=6QL*2!["B`@("`@("`@("`@("`@("`D9FQA9W,@+CT@
M)V1E9F%U;'1?)R`N(')A=W5R;&5N8V]D92@D:61;)&E=6R=D9FQT7W9A;'5E
M)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1F;&%G<R`]('1R:6TH
M)&9L86=S*3L*"B`@("`@("`@("`@("1R97-;)&E=(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`G=&%B;&4G(#T^("1C87-E7V9U;F,H)')E<W5L="DL"B`@
M("`@("`@("`@("`@("`G;F%M92<@(#T^("1C87-E7V9U;F,H)&ED6R1I75LG
M;F%M92==*2P*("`@("`@("`@("`@("`@("=T>7!E)R`@/3X@)'1Y<&4L"B`@
M("`@("`@("`@("`@("`G;&5N)R`@(#T^("1L96XL"B`@("`@("`@("`@("`@
M("`G9FQA9W,G(#T^("1F;&%G<RP*("`@("`@("`@("`@*3L*"B`@("`@("`@
M("`@(&EF("@D;6]D92`F($1"7U1!0DQ%24Y&3U]/4D1%4BD@>PH@("`@("`@
M("`@("`@("`@)')E<ULG;W)D97(G75LD<F5S6R1I75LG;F%M92==72`]("1I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@D;6]D92`F($1"7U1!
M0DQ%24Y&3U]/4D1%4E1!0DQ%*2!["B`@("`@("`@("`@("`@("`D<F5S6R=O
M<F1E<G1A8FQE)UU;)')E<ULD:5U;)W1A8FQE)UU=6R1R97-;)&E=6R=N86UE
M)UU=(#T@)&D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M='5R;B`D<F5S.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&=E=%-P
M96-I86Q1=65R>2@I"@H@("`@+RHJ"B`@("`@*B!/8G1A:6YS('1H92!Q=65R
M>2!S=')I;F<@;F5E9&5D(&9O<B!L:7-T:6YG(&$@9VEV96X@='EP92!O9B!O
M8FIE8W1S"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D='EP92`@=&AE
M(&MI;F0@;V8@;V)J96-T<R!Y;W4@=V%N="!T;R!R971R:65V90H@("`@("H@
M0'!A<F%M(&%R<F%Y("`D87)G<R`@4U%,251%($12259%4B!/3DQ9.B!A('!R
M:79A=&4@87)R87D@;V8@87)G=6UE;G1S"B`@("`@*B`@("`@("`@("`@("`@
M("`@("`@("`@=7-E9"!B>2!T:&4@9V5T4W!E8VEA;%%U97)Y*"DN("!$;R!N
M;W0@=7-E"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@=&AI<R!D:7)E
M8W1L>2X*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(%-13"!Q
M=65R>2!S=')I;F<@;W(@;G5L;"!I9B!T:&4@9')I=F5R(&1O97-N)W0*("`@
M("`J("`@("`@("`@("`@("`@("`@<W5P<&]R="!T:&4@;V)J96-T('1Y<&4@
M<F5Q=65S=&5D"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J($!S964@1$)?8V]M;6]N.CIG971,:7-T3V8H*0H@("`@("HO"B`@("!F
M=6YC=&EO;B!G9713<&5C:6%L475E<GDH)'1Y<&4L("1A<F=S(#T@87)R87DH
M*2D*("`@('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1A<F=S*2D@>PH@("`@
M("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)VYO(&ME>2!S<&5C
M:69I960G+"!N=6QL+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)T%R9W5M96YT(&AA<R!T;R!B92!A;B!A<G)A
M>2XG*3L*("`@("`@("!]"@H@("`@("`@('-W:71C:"`H)'1Y<&4I('L*("`@
M("`@("`@("`@8V%S92`G;6%S=&5R)SH*("`@("`@("`@("`@("`@(')E='5R
M;B`G4T5,14-4("H@1E)/32!S<6QI=&5?;6%S=&5R.R<["B`@("`@("`@("`@
M(&-A<V4@)W1A8FQE<R<Z"B`@("`@("`@("`@("`@("!R971U<FX@(E-%3$5#
M5"!N86UE($923TT@<W%L:71E7VUA<W1E<B!72$5212!T>7!E/2=T86)L92<@
M(@H@("`@("`@("`@("`@("`@("`@("`@("X@)U5.24].($%,3"!314Q%0U0@
M;F%M92!&4D]-('-Q;&ET95]T96UP7VUA<W1E<B`G"B`@("`@("`@("`@("`@
M("`@("`@("`@+B`B5TA%4D4@='EP93TG=&%B;&4G($]21$52($)9(&YA;64[
M(CL*("`@("`@("`@("`@8V%S92`G<V-H96UA)SH*("`@("`@("`@("`@("`@
M(')E='5R;B`G4T5,14-4('-Q;"!&4D]-("A314Q%0U0@*B!&4D]-('-Q;&ET
M95]M87-T97(@)PH@("`@("`@("`@("`@("`@("`@("`@("X@)U5.24].($%,
M3"!314Q%0U0@*B!&4D]-('-Q;&ET95]T96UP7VUA<W1E<BD@)PH@("`@("`@
M("`@("`@("`@("`@("`@("X@(E=(15)%('1Y<&4A/2=M971A)R`B"B`@("`@
M("`@("`@("`@("`@("`@("`@+B`G3U)$15(@0ED@=&)L7VYA;64L('1Y<&4@
M1$530RP@;F%M93LG.PH@("`@("`@("`@("!C87-E("=S8VAE;6%X)SH*("`@
M("`@("`@("`@8V%S92`G<V-H96UA7W@G.@H@("`@("`@("`@("`@("`@+RH*
M("`@("`@("`@("`@("`@("`J(%5S92!L:6ME.@H@("`@("`@("`@("`@("`@
M("H@)')E<R`]("1D8BT^<75E<GDH)&1B+3YG9713<&5C:6%L475E<GDH)W-C
M:&5M85]X)RP*("`@("`@("`@("`@("`@("`J("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=T86)L92<@/3X@)W1A8FQE,R<I*2D["B`@("`@("`@("`@("`@
M("`@*B\*("`@("`@("`@("`@("`@(')E='5R;B`G4T5,14-4('-Q;"!&4D]-
M("A314Q%0U0@*B!&4D]-('-Q;&ET95]M87-T97(@)PH@("`@("`@("`@("`@
M("`@("`@("`@("X@)U5.24].($%,3"!314Q%0U0@*B!&4D]-('-Q;&ET95]T
M96UP7VUA<W1E<BD@)PH@("`@("`@("`@("`@("`@("`@("`@("X@(E=(15)%
M('1B;%]N86UE($Q)2T4@)WLD87)G<ULG=&%B;&4G77TG("(*("`@("`@("`@
M("`@("`@("`@("`@("`N(")!3D0@='EP92$])VUE=&$G("(*("`@("`@("`@
M("`@("`@("`@("`@("`N("=/4D1%4B!"62!T>7!E($1%4T,L(&YA;64[)SL*
M("`@("`@("`@("`@8V%S92`G86QT97(G.@H@("`@("`@("`@("`@("`@+RH*
M("`@("`@("`@("`@("`@("`J(%-13&ET92!D;V5S(&YO="!S=7!P;W)T($%,
M5$52(%1!0DQ%.R!T:&ES(&ES(&$@:&5L<&5R('%U97)Y"B`@("`@("`@("`@
M("`@("`@*B!T;R!H86YD;&4@=&AI<RX@)W1A8FQE)R!R97!R97-E;G1S('1H
M92!T86)L92!N86UE+"`G<F]W<R<*("`@("`@("`@("`@("`@("`J('1H92!N
M97=S(')O=W,@=&\@8W)E871E+"`G<V%V92<@=&AE(')O=RAS*2!T;R!K965P
M(%]W:71H7PH@("`@("`@("`@("`@("`@("H@=&AE(&1A=&$N"B`@("`@("`@
M("`@("`@("`@*@H@("`@("`@("`@("`@("`@("H@57-E(&QI:V4Z"B`@("`@
M("`@("`@("`@("`@*B`D87)G<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@
M("H@("`@("=T86)L92<@/3X@)'1A8FQE+`H@("`@("`@("`@("`@("`@("H@
M("`@("=R;W=S)R`@/3X@(FED($E.5$5'15(@4%))34%262!+15DL(&9I<G-T
M;F%M92!415A4+"!S=7)N86UE(%1%6%0L(&1A=&5T:6UE(%1%6%0B+`H@("`@
M("`@("`@("`@("`@("H@("`@("=S879E)R`@/3X@(DY53$PL('1I=&5L+"!C
M;VYT96YT+"!D871E=&EM92(*("`@("`@("`@("`@("`@("`J("D["B`@("`@
M("`@("`@("`@("`@*B`D<F5S(#T@)&1B+3YQ=65R>2@@)&1B+3YG9713<&5C
M:6%L475E<GDH)V%L=&5R)RP@)&%R9W,I*3L*("`@("`@("`@("`@("`@("`J
M+PH@("`@("`@("`@("`@("`@)')O=W,@/2!S=')T<B@D87)G<ULG<F]W<R==
M+"`D=&AI<RT^:V5Y=V]R9',I.PH*("`@("`@("`@("`@("`@("1Q(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@)T)%1TE.(%1204Y304-424].)RP*
M("`@("`@("`@("`@("`@("`@("`B0U)%051%(%1%35!/4D%262!404),12![
M)&%R9W-;)W1A8FQE)UU]7V)A8VMU<"`H>R1A<F=S6R=R;W=S)UU]*2(L"B`@
M("`@("`@("`@("`@("`@("`@(DE.4T525"!)3E1/('LD87)G<ULG=&%B;&4G
M77U?8F%C:W5P(%-%3$5#5"![)&%R9W-;)W-A=F4G77T@1E)/32![)&%R9W-;
M)W1A8FQE)UU](BP*("`@("`@("`@("`@("`@("`@("`B1%)/4"!404),12![
M)&%R9W-;)W1A8FQE)UU](BP*("`@("`@("`@("`@("`@("`@("`B0U)%051%
M(%1!0DQ%('LD87)G<ULG=&%B;&4G77T@*'LD87)G<ULG<F]W<R==?2DB+`H@
M("`@("`@("`@("`@("`@("`@("))3E-%4E0@24Y43R![)&%R9W-;)W1A8FQE
M)UU](%-%3$5#5"![)')O=W-]($923TT@>R1A<F=S6R=T86)L92==?5]B86-K
M=7`B+`H@("`@("`@("`@("`@("`@("`@(")$4D]0(%1!0DQ%('LD87)G<ULG
M=&%B;&4G77U?8F%C:W5P(BP*("`@("`@("`@("`@("`@("`@("`G0T]-34E4
M)RP*("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@+RH*("`@
M("`@("`@("`@("`@("`J(%1H:7,@:7,@82!D:7)T>2!H86-K+"!S:6YC92!T
M:&4@86)O=F4@<75E<GD@=VEL;"!N;W0@9V5T"B`@("`@("`@("`@("`@("`@
M*B!E>&5C=71E9"!W:71H(&$@<VEN9VQE('%U97)Y(&-A;&P@<V\@:&5R92!T
M:&4@<75E<GD@;65T:&]D"B`@("`@("`@("`@("`@("`@*B!W:6QL(&)E(&-A
M;&QE9"!D:7)E8W1L>2!A;F0@<F5T=7)N(&$@<V5L96-T(&EN<W1E860N"B`@
M("`@("`@("`@("`@("`@*B\*("`@("`@("`@("`@("`@(&9O<F5A8V@@*"1Q
M(&%S("1Q=65R>2D@>PH@("`@("`@("`@("`@("`@("`@("1T:&ES+3YQ=65R
M>2@D<75E<GDI.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M<F5T=7)N(")314Q%0U0@*B!&4D]-('LD87)G<ULG=&%B;&4G77T[(CL*("`@
M("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@(')E='5R;B!N=6QL
M.PH@("`@("`@('T*("`@('T*"B`@("`O+R!]?7T*?0H*+RH*("H@3&]C86P@
M=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*("H@8RUB87-I8RUO9F9S970Z
M(#0*("H@16YD.@H@*B\*"C\^"@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O1$(O9&)A<V4N<&AP````````````````````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`S-C8P,2`Q,#4Q-30S-#$S,R`P,C`U-#,`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T
M:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@5&AE(%!%05(@1$(@9')I
M=F5R(&9O<B!02%`G<R!D8F%S92!E>'1E;G-I;VX*("H@9F]R(&EN=&5R86-T
M:6YG('=I=&@@9$)A<V4@9&%T86)A<V5S"B`J"B`J(%!(4"!V97)S:6]N<R`T
M(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA
M="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@
M=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O
M9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O
M(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM
M;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!$871A8F%S90H@*B!`<&%C
M:V%G92`@("!$0@H@*B!`875T:&]R("`@("!4;VUA<R!6+E8N($-O>"`\8V]X
M0&ED96-N970N8V]M/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R
M(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3<M,C`P-2!4
M:&4@4$A0($=R;W5P"B`J($!L:6-E;G-E("`@(&AT='`Z+R]W=W<N<&AP+FYE
M="]L:6-E;G-E+S-?,"YT>'0@(%!(4"!,:6-E;G-E(#,N,`H@*B!`=F5R<VEO
M;B`@("!#5E,Z("1)9#H@9&)A<V4N<&AP+'8@,2XS.2`R,#`U+S`R+S$Y(#(S
M.C(U.C(U(&1A;FEE;&,@17AP("0*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+T1""B`J+PH*+RHJ"B`J($]B=&%I;B!T:&4@
M1$)?8V]M;6]N(&-L87-S('-O(&ET(&-A;B!B92!E>'1E;F1E9"!F<F]M"B`J
M+PIR97%U:7)E7V]N8V4@)T1"+V-O;6UO;BYP:'`G.PH*+RHJ"B`J(%1H92!M
M971H;V1S(%!%05(@1$(@=7-E<R!T;R!I;G1E<F%C="!W:71H(%!(4"=S(&1B
M87-E(&5X=&5N<VEO;@H@*B!F;W(@:6YT97)A8W1I;F<@=VET:"!D0F%S92!D
M871A8F%S97,*("H*("H@5&AE<V4@;65T:&]D<R!O=F5R;&]A9"!T:&4@;VYE
M<R!D96-L87)E9"!I;B!$0E]C;VUM;VXN"B`J"B`J($!C871E9V]R>2`@($1A
M=&%B87-E"B`J($!P86-K86=E("`@($1""B`J($!A=71H;W(@("`@(%1O;6%S
M(%8N5BX@0V]X(#QC;WA`:61E8VYE="YC;VT^"B`J($!A=71H;W(@("`@($1A
M;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O<'ER:6=H
M="`@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T
M<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@
M,RXP"B`J($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-RXV"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]$0@H@*B\*8VQA<W,@
M1$)?9&)A<V4@97AT96YD<R!$0E]C;VUM;VX*>PH@("`@+R\@>WM[('!R;W!E
M<G1I97,*"B`@("`O*BH*("`@("`J(%1H92!$0B!D<FEV97(@='EP92`H;7ES
M<6PL(&]C:3@L(&]D8F,L(&5T8RXI"B`@("`@*B!`=F%R('-T<FEN9PH@("`@
M("HO"B`@("!V87(@)'!H<'1Y<&4@/2`G9&)A<V4G.PH*("`@("\J*@H@("`@
M("H@5&AE(&1A=&%B87-E('-Y;G1A>"!V87)I86YT('1O(&)E('5S960@*&1B
M,BP@86-C97-S+"!E=&,N*2P@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)&1B<WEN=&%X(#T@)V1B87-E)SL*"B`@("`O*BH*
M("`@("`J(%1H92!C87!A8FEL:71I97,@;V8@=&AI<R!$0B!I;7!L96UE;G1A
M=&EO;@H@("`@("H*("`@("`J(%1H92`G;F5W7VQI;FLG(&5L96UE;G0@8V]N
M=&%I;G,@=&AE(%!(4"!V97)S:6]N('1H870@9FER<W0@<')O=FED960*("`@
M("`J(&YE=U]L:6YK('-U<'!O<G0@9F]R('1H:7,@1$)-4RX@($-O;G1A:6YS
M(&9A;'-E(&EF(&ET)W,@=6YS=7!P;W)T960N"B`@("`@*@H@("`@("H@365A
M;FEN9R!O9B!T:&4@)VQI;6ET)R!E;&5M96YT.@H@("`@("H@("`K("=E;75L
M871E)R`](&5M=6QA=&4@=VET:"!F971C:"!R;W<@8GD@;G5M8F5R"B`@("`@
M*B`@("L@)V%L=&5R)R`@(#T@86QT97(@=&AE('%U97)Y"B`@("`@*B`@("L@
M9F%L<V4@("`@(#T@<VMI<"!R;W=S"B`@("`@*@H@("`@("H@0'9A<B!A<G)A
M>0H@("`@("HO"B`@("!V87(@)&9E871U<F5S(#T@87)R87DH"B`@("`@("`@
M)VQI;6ET)R`@("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=N97=?;&EN:R<@
M("`@("`]/B!F86QS92P*("`@("`@("`G;G5M<F]W<R<@("`@("`@/3X@=')U
M92P*("`@("`@("`G<&-O;FYE8W0G("`@("`@/3X@9F%L<V4L"B`@("`@("`@
M)W!R97!A<F4G("`@("`@(#T^(&9A;'-E+`H@("`@("`@("=S<VPG("`@("`@
M("`@("`]/B!F86QS92P*("`@("`@("`G=')A;G-A8W1I;VYS)R`@/3X@9F%L
M<V4L"B`@("`I.PH*("`@("\J*@H@("`@("H@02!M87!P:6YG(&]F(&YA=&EV
M92!E<G)O<B!C;V1E<R!T;R!$0B!E<G)O<B!C;V1E<PH@("`@("H@0'9A<B!A
M<G)A>0H@("`@("HO"B`@("!V87(@)&5R<F]R8V]D95]M87`@/2!A<G)A>2@*
M("`@("D["@H@("`@+RHJ"B`@("`@*B!4:&4@<F%W(&1A=&%B87-E(&-O;FYE
M8W1I;VX@8W)E871E9"!B>2!02%`*("`@("`J($!V87(@<F5S;W5R8V4*("`@
M("`J+PH@("`@=F%R("1C;VYN96-T:6]N.PH*("`@("\J*@H@("`@("H@5&AE
M($133B!I;F9O<FUA=&EO;B!F;W(@8V]N;F5C=&EN9R!T;R!A(&1A=&%B87-E
M"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@('9A<B`D9'-N(#T@87)R
M87DH*3L*"@H@("`@+RHJ"B`@("`@*B!!(&UE86YS(&]F(&5M=6QA=&EN9R!R
M97-U;'0@<F5S;W5R8V5S"B`@("`@*B!`=F%R(&%R<F%Y"B`@("`@*B\*("`@
M('9A<B`D<F5S7W)O=R`](&%R<F%Y*"D["@H@("`@+RHJ"B`@("`@*B!4:&4@
M<75A;G1I='D@;V8@<F5S=6QT<R!S;R!F87(*("`@("`J"B`@("`@*B!&;W(@
M96UU;&%T:6YG(')E<W5L="!R97-O=7)C97,N"B`@("`@*@H@("`@("H@0'9A
M<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D<F5S=6QT(#T@,#L*"B`@("`O
M*BH*("`@("`J($UA<',@9&)A<V4@9&%T82!T>7!E(&ED)W,@=&\@:'5M86X@
M<F5A9&%B;&4@<W1R:6YG<PH@("`@("H*("`@("`J(%1H92!H=6UA;B!R96%D
M86)L92!V86QU97,@87)E(&)A<V5D(&]N('1H92!O=71P=70@;V8@4$A0)W,*
M("`@("`J(&1B87-E7V=E=%]H96%D97)?:6YF;R@I(&9U;F-T:6]N+@H@("`@
M("H*("`@("`J($!V87(@87)R87D*("`@("`J($!S:6YC92!0<F]P97)T>2!A
M=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C<N,`H@("`@("HO"B`@("!V87(@
M)'1Y<&5S(#T@87)R87DH"B`@("`@("`@)T,G(#T^("=C:&%R86-T97(G+`H@
M("`@("`@("=$)R`]/B`G9&%T92<L"B`@("`@("`@)TPG(#T^("=B;V]L96%N
M)RP*("`@("`@("`G32<@/3X@)VUE;6\G+`H@("`@("`@("=.)R`]/B`G;G5M
M8F5R)RP*("`@("D["@H*("`@("\O('U]?0H@("`@+R\@>WM[(&-O;G-T<G5C
M=&]R"@H@("`@+RHJ"B`@("`@*B!4:&ES(&-O;G-T<G5C=&]R(&-A;&QS(#QK
M8F0^)'1H:7,M/D1"7V-O;6UO;B@I/"]K8F0^"B`@("`@*@H@("`@("H@0')E
M='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N($1"7V1B87-E*"D*("`@
M('L*("`@("`@("`D=&AI<RT^1$)?8V]M;6]N*"D["B`@("!]"@H@("`@+R\@
M?7U]"B`@("`O+R![>WL@8V]N;F5C="@I"@H@("`@+RHJ"B`@("`@*B!#;VYN
M96-T('1O('1H92!D871A8F%S92!A;F0@8W)E871E(&ET(&EF(&ET(&1O97-N
M)W0@97AI<W0*("`@("`J"B`@("`@*B!$;VXG="!C86QL('1H:7,@;65T:&]D
M(&1I<F5C=&QY+B`@57-E($1".CIC;VYN96-T*"D@:6YS=&5A9"X*("`@("`J
M"B`@("`@*B!014%2($1")W,@9&)A<V4@9')I=F5R('-U<'!O<G1S('1H92!F
M;VQL;W=I;F<@97AT<F$@1%-.(&]P=&EO;G,Z"B`@("`@*B`@("L@;6]D92`@
M("!!;B!I;G1E9V5R('-P96-I9GEI;F<@=&AE(')E860O=W)I=&4@;6]D92!T
M;R!U<V4*("`@("`J("`@("`@("`@("`@("`H,"`](')E860@;VYL>2P@,2`]
M('=R:71E(&]N;'DL(#(@/2!R96%D+W=R:71E*2X*("`@("`J("`@("`@("`@
M("`@("!!=F%I;&%B;&4@<VEN8V4@4$5!4B!$0B`Q+C<N,"X*("`@("`J("`@
M*R!F:65L9',@($%N(&%R<F%Y(&]F(&%R<F%Y<R!T:&%T(%!(4"=S(&1B87-E
M7V-R96%T92@I(&9U;F-T:6]N(&YE961S"B`@("`@*B`@("`@("`@("`@("`@
M=&\@8W)E871E(&$@;F5W(&1A=&%B87-E+B`@5&AI<R!I;F9O<FUA=&EO;B!I
M<R!U<V5D(&EF('1H90H@("`@("H@("`@("`@("`@("`@(&1"87-E(&9I;&4@
M<W!E8VEF:65D(&EN('1H92`B9&%T86)A<V4B('-E9VUE;G0@;V8@=&AE($13
M3@H@("`@("H@("`@("`@("`@("`@(&1O97,@;F]T(&5X:7-T+B`@1F]R(&UO
M<F4@:6YF;RP@<V5E('1H92!02%`@;6%N=6%L)W,*("`@("`J("`@("`@("`@
M("`@("![0&QI;FL@:'1T<#HO+W!H<"YN970O9&)A<V5?8W)E871E(&1B87-E
M7V-R96%T92@I?2!P86=E+@H@("`@("H@("`@("`@("`@("`@($%V86EL86)L
M92!S:6YC92!014%2($1"(#$N-RXP+@H@("`@("H*("`@("`J($5X86UP;&4@
M;V8@:&]W('1O(&-O;FYE8W0@86YD(&5S=&%B;&ES:"!A(&YE=R!D0F%S92!F
M:6QE(&EF(&YE8V5S<V%R>3H*("`@("`J(#QC;V1E/@H@("`@("H@<F5Q=6ER
M95]O;F-E("=$0BYP:'`G.PH@("`@("H*("`@("`J("1D<VX@/2!A<G)A>2@*
M("`@("`J("`@("`G<&AP='EP92<@(#T^("=D8F%S92<L"B`@("`@*B`@("`@
M)V1A=&%B87-E)R`]/B`G+W!A=&@O86YD+VYA;64O;V8O9&)A<V4O9FEL92<L
M"B`@("`@*B`@("`@)VUO9&4G("`@("`]/B`R+`H@("`@("H@("`@("=F:65L
M9',G("`@/3X@87)R87DH"B`@("`@*B`@("`@("`@(&%R<F%Y*"=A)RP@)TXG
M+"`U+"`P*2P*("`@("`J("`@("`@("`@87)R87DH)V(G+"`G0R<L(#0P*2P*
M("`@("`J("`@("`@("`@87)R87DH)V,G+"`G0R<L(#(U-2DL"B`@("`@*B`@
M("`@("`@(&%R<F%Y*"=D)RP@)T,G+"`R,"DL"B`@("`@*B`@("`@*2P*("`@
M("`J("D["B`@("`@*B`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("H@("`@("=D
M96)U9R<@("`@("`@/3X@,BP*("`@("`J("`@("`G<&]R=&%B:6QI='DG(#T^
M($1"7U!/4E1!0DE,25197T%,3"P*("`@("`J("D["B`@("`@*@H@("`@("H@
M)&1B(#TF($1".CIC;VYN96-T*"1D<VXL("1O<'1I;VYS*3L*("`@("`J(&EF
M("A014%2.CII<T5R<F]R*"1D8BDI('L*("`@("`J("`@("!D:64H)&1B+3YG
M971-97-S86=E*"DI.PH@("`@("H@?0H@("`@("H@/"]C;V1E/@H@("`@("H*
M("`@("`J($!P87)A;2!A<G)A>2`D9'-N("`@("`@("`@=&AE(&1A=&$@<V]U
M<F-E(&YA;64*("`@("`J($!P87)A;2!B;V]L("`D<&5R<VES=&5N="`@<VAO
M=6QD('1H92!C;VYN96-T:6]N(&)E('!E<G-I<W1E;G0_"B`@("`@*@H@("`@
M("H@0')E='5R;B!I;G0@($1"7T]+(&]N('-U8V-E<W,N($$@1$)?17)R;W(@
M;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O;FYE
M8W0H)&1S;BP@)'!E<G-I<W1E;G0@/2!F86QS92D*("`@('L*("`@("`@("!I
M9B`H(5!%05(Z.FQO861%>'1E;G-I;VXH)V1B87-E)RDI('L*("`@("`@("`@
M("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T585$5.4TE/
M3E].3U1?1D]53D0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F1S;B`]
M("1D<VX["B`@("`@("`@:68@*"1D<VY;)V1B<WEN=&%X)UTI('L*("`@("`@
M("`@("`@)'1H:7,M/F1B<WEN=&%X(#T@)&1S;ELG9&)S>6YT87@G73L*("`@
M("`@("!]"@H@("`@("`@("\J"B`@("`@("`@("H@5'5R;B!T<F%C:U]E<G)O
M<G,@;VX@9F]R(&5N=&ER92!S8W)I<'0@<VEN8V4@)'!H<%]E<G)O<FUS9PH@
M("`@("`@("`J(&ES('1H92!O;FQY('=A>2!T;R!F:6YD(&5R<F]R<R!F<F]M
M('1H92!D8F%S92!E>'1E;G-I;VXN"B`@("`@("`@("HO"B`@("`@("`@:6YI
M7W-E="@G=')A8VM?97)R;W)S)RP@,2D["B`@("`@("`@)'!H<%]E<G)O<FUS
M9R`]("<G.PH*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D<VY;)V1A=&%B
M87-E)UTI*2!["B`@("`@("`@("`@("1T:&ES+3YD<VY;)VUO9&4G72`](#([
M"B`@("`@("`@("`@(&EF("AE;7!T>2@D9'-N6R=F:65L9',G72D@?'P@(6ES
M7V%R<F%Y*"1D<VY;)V9I96QD<R==*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1T:&ES+3YR86ES945R<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&YU
M;&PL(&YU;&PL(&YU;&PL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)W1H92!D8F%S92!F:6QE(&1O97,@;F]T(&5X:7-T(&%N
M9"`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+B`G:70@8V]U;&0@;F]T(&)E(&-R96%T960@8F5C875S92`G"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G=&AE(")F:65L
M9',B(&5L96UE;G0@;V8@=&AE($133B`G"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@+B`G:7,@;F]T('!R;W!E<FQY('-E="<I
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3YC;VYN96-T:6]N
M(#T@0&1B87-E7V-R96%T92@D9'-N6R=D871A8F%S92==+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&1S;ELG9FEE
M;&1S)UTI.PH@("`@("`@("`@("!I9B`H(21T:&ES+3YC;VYN96-T:6]N*2![
M"B`@("`@("`@("`@("`@("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H1$)?
M15)23U)?0T].3D5#5%]&04E,140L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@;G5L;"P@;G5L;"P@;G5L;"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&AE(&1B87-E(&9I
M;&4@9&]E<R!N;W0@97AI<W0@86YD("<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("=T:&4@871T96UP="!T;R!C<F5A=&4@
M:70@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+B`D<&AP7V5R<F]R;7-G*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1H:7,M/F1S
M;ELG;6]D92==*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F1S;ELG;6]D
M92==(#T@,#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^8V]N
M;F5C=&EO;B`]($!D8F%S95]O<&5N*"1D<VY;)V1A=&%B87-E)UTL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/F1S;ELG;6]D92==*3L*("`@("`@("`@("`@:68@*"$D=&AI<RT^8V]N;F5C
M=&EO;BD@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R
M<F]R*$1"7T524D]27T-/3DY%0U1?1D%)3$5$+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&YU;&PL(&YU;&PL(&YU;&PL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!H<%]E
M<G)O<FUS9RD["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N($1"7T]+.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&1I<V-O
M;FYE8W0H*0H*("`@("\J*@H@("`@("H@1&ES8V]N;F5C=',@9G)O;2!T:&4@
M9&%T86)A<V4@<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L("!4
M4E5%(&]N('-U8V-E<W,L($9!3%-%(&]N(&9A:6QU<F4*("`@("`J+PH@("`@
M9G5N8W1I;VX@9&ES8V]N;F5C="@I"B`@("!["B`@("`@("`@)')E="`]($!D
M8F%S95]C;&]S92@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@)'1H:7,M
M/F-O;FYE8W1I;VX@/2!N=6QL.PH@("`@("`@(')E='5R;B`D<F5T.PH@("`@
M?0H*("`@("\O('U]?0H@("`@+R\@>WM[("9Q=65R>2@I"@H@("`@9G5N8W1I
M;VX@)G%U97)Y*"1Q=65R>2`](&YU;&PI"B`@("!["B`@("`@("`@+R\@96UU
M;&%T92!R97-U;'0@<F5S;W5R8V5S"B`@("`@("`@)'1H:7,M/G)E<U]R;W=;
M*&EN="DD=&AI<RT^<F5S=6QT72`](#`["B`@("`@("`@)'1M<"`])B!N97<@
M1$)?<F5S=6QT*"1T:&ES+"`D=&AI<RT^<F5S=6QT*RLI.PH@("`@("`@(')E
M='5R;B`D=&UP.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&9E=&-H
M26YT;R@I"@H@("`@+RHJ"B`@("`@*B!0;&%C97,@82!R;W<@9G)O;2!T:&4@
M<F5S=6QT('-E="!I;G1O('1H92!G:79E;B!A<G)A>0H@("`@("H*("`@("`J
M($9O<FUA=&EN9R!O9B!T:&4@87)R87D@86YD('1H92!D871A('1H97)E:6X@
M87)E(&-O;F9I9W5R86)L92X*("`@("`J(%-E92!$0E]R97-U;'0Z.F9E=&-H
M26YT;R@I(&9O<B!M;W)E(&EN9F]R;6%T:6]N+@H@("`@("H*("`@("`J(%1H
M:7,@;65T:&]D(&ES(&YO="!M96%N="!T;R!B92!C86QL960@9&ER96-T;'DN
M("!5<V4*("`@("`J($1"7W)E<W5L=#HZ9F5T8VA);G1O*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@("!T:&4@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*B!`<&%R86T@87)R87D@("`@)&%R<B`@("`@
M("!T:&4@<F5F97)E;F-E9"!A<G)A>2!T;R!P=70@=&AE(&1A=&$@:6X*("`@
M("`J($!P87)A;2!I;G0@("`@("`D9F5T8VAM;V1E(&AO=R!T:&4@<F5S=6QT
M:6YG(&%R<F%Y('-H;W5L9"!B92!I;F1E>&5D"B`@("`@*B!`<&%R86T@:6YT
M("`@("`@)')O=VYU;2`@("!T:&4@<F]W(&YU;6)E<B!T;R!F971C:"`H,"`]
M(&9I<G-T(')O=RD*("`@("`J"B`@("`@*B!`<F5T=7)N(&UI>&5D("!$0E]/
M2R!O;B!S=6-C97-S+"!.54Q,('=H96X@=&AE(&5N9"!O9B!A(')E<W5L="!S
M970@:7,*("`@("`J("`@("`@("`@("`@("`@("!R96%C:&5D(&]R(&]N(&9A
M:6QU<F4*("`@("`J"B`@("`@*B!`<V5E($1"7W)E<W5L=#HZ9F5T8VA);G1O
M*"D*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8VA);G1O*"1R97-U;'0L("8D
M87)R+"`D9F5T8VAM;V1E+"`D<F]W;G5M(#T@;G5L;"D*("`@('L*("`@("`@
M("!I9B`H)')O=VYU;2`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<F]W;G5M
M(#T@)'1H:7,M/G)E<U]R;W=;*&EN="DD<F5S=6QT72LK.PH@("`@("`@('T*
M("`@("`@("!I9B`H)&9E=&-H;6]D92`F($1"7T9%5$-(34]$15]!4U-/0RD@
M>PH@("`@("`@("`@("`D87)R(#T@0&1B87-E7V=E=%]R96-O<F1?=VET:%]N
M86UE<R@D=&AI<RT^8V]N;F5C=&EO;BP@)')O=VYU;2D["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<ULG<&]R=&%B:6QI='DG72`F($1"7U!/4E1!
M0DE,25197TQ/5T520T%312`F)B`D87)R*2!["B`@("`@("`@("`@("`@("`D
M87)R(#T@87)R87E?8VAA;F=E7VME>5]C87-E*"1A<G(L($-!4T5?3$]715(I
M.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)&%R<B`]($!D8F%S95]G971?<F5C;W)D*"1T:&ES+3YC;VYN96-T:6]N+"`D
M<F]W;G5M*3L*("`@("`@("!]"B`@("`@("`@:68@*"$D87)R*2!["B`@("`@
M("`@("`@(')E='5R;B!N=6QL.PH@("`@("`@('T*("`@("`@("!I9B`H)'1H
M:7,M/F]P=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465]2
M5%))32D@>PH@("`@("`@("`@("`D=&AI<RT^7W)T<FEM07)R87E686QU97,H
M)&%R<BD["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<ULG
M<&]R=&%B:6QI='DG72`F($1"7U!/4E1!0DE,25197TY53$Q?5$]?14U05%DI
M('L*("`@("`@("`@("`@)'1H:7,M/E]C;VYV97)T3G5L;$%R<F%Y5F%L=65S
M5&]%;7!T>2@D87)R*3L*("`@("`@("!]"B`@("`@("`@<F5T=7)N($1"7T]+
M.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[(&YU;4-O;',H*0H*("`@
M("\J*@H@("`@("H@1V5T<R!T:&4@;G5M8F5R(&]F(&-O;'5M;G,@:6X@82!R
M97-U;'0@<V5T"B`@("`@*@H@("`@("H@5&AI<R!M971H;V0@:7,@;F]T(&UE
M86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L>2X@(%5S90H@("`@("H@1$)?<F5S
M=6QT.CIN=6U#;VQS*"D@:6YS=&5A9"X@($ET(&-A;B=T(&)E(&1E8VQA<F5D
M(")P<F]T96-T960B"B`@("`@*B!B96-A=7-E($1"7W)E<W5L="!I<R!A('-E
M<&%R871E(&]B:F5C="X*("`@("`J"B`@("`@*B!`<&%R86T@<F5S;W5R8V4@
M)')E<W5L="`@4$A0)W,@<75E<GD@<F5S=6QT(')E<V]U<F-E"B`@("`@*@H@
M("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@8V]L=6UN<RX@($$@
M1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N"B`@("`@*@H@("`@("H@0'-E
M92!$0E]R97-U;'0Z.FYU;4-O;',H*0H@("`@("HO"B`@("!F=6YC=&EO;B!N
M=6U#;VQS*"1F;V\I"B`@("!["B`@("`@("`@<F5T=7)N($!D8F%S95]N=6UF
M:65L9',H)'1H:7,M/F-O;FYE8W1I;VXI.PH@("`@?0H*("`@("\O('U]?0H@
M("`@+R\@>WM[(&YU;5)O=W,H*0H*("`@("\J*@H@("`@("H@1V5T<R!T:&4@
M;G5M8F5R(&]F(')O=W,@:6X@82!R97-U;'0@<V5T"B`@("`@*@H@("`@("H@
M5&AI<R!M971H;V0@:7,@;F]T(&UE86YT('1O(&)E(&-A;&QE9"!D:7)E8W1L
M>2X@(%5S90H@("`@("H@1$)?<F5S=6QT.CIN=6U2;W=S*"D@:6YS=&5A9"X@
M($ET(&-A;B=T(&)E(&1E8VQA<F5D(")P<F]T96-T960B"B`@("`@*B!B96-A
M=7-E($1"7W)E<W5L="!I<R!A('-E<&%R871E(&]B:F5C="X*("`@("`J"B`@
M("`@*B!`<&%R86T@<F5S;W5R8V4@)')E<W5L="`@4$A0)W,@<75E<GD@<F5S
M=6QT(')E<V]U<F-E"B`@("`@*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N
M=6UB97(@;V8@<F]W<RX@($$@1$)?17)R;W(@;V)J96-T(&]N(&9A:6QU<F4N
M"B`@("`@*@H@("`@("H@0'-E92!$0E]R97-U;'0Z.FYU;5)O=W,H*0H@("`@
M("HO"B`@("!F=6YC=&EO;B!N=6U2;W=S*"1F;V\I"B`@("!["B`@("`@("`@
M<F5T=7)N($!D8F%S95]N=6UR96-O<F1S*"1T:&ES+3YC;VYN96-T:6]N*3L*
M("`@('T*"B`@("`O+R!]?7T*("`@("\O('M[>R!Q=6]T95-M87)T*"D*"B`@
M("`O*BH*("`@("`J($9O<FUA=',@:6YP=70@<V\@:70@8V%N(&)E('-A9F5L
M>2!U<V5D(&EN(&$@<75E<GD*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)&EN("!T:&4@9&%T82!T;R!B92!F;W)M871T960*("`@("`J"B`@("`@*B!`
M<F5T=7)N(&UI>&5D("!T:&4@9F]R;6%T=&5D(&1A=&$N("!4:&4@9F]R;6%T
M(&1E<&5N9',@;VX@=&AE(&EN<'5T)W,*("`@("`J("`@("`@("`@("`@("`@
M("!02%`@='EP93H*("`@("`J("`@("`@("`@("`@("`@("`K(&YU;&P@/2!T
M:&4@<W1R:6YG(#QS86UP/DY53$P\+W-A;7`^"B`@("`@*B`@("`@("`@("`@
M("`@("`@*R!B;V]L96%N(#T@/'-A;7`^5#PO<V%M<#X@:68@=')U92!O<@H@
M("`@("H@("`@("`@("`@("`@("`@("`@/'-A;7`^1CPO<V%M<#X@:68@9F%L
M<V4N("!5<V4@=&AE(#QK8F0^3&]G:6-A;#PO:V)D/@H@("`@("H@("`@("`@
M("`@("`@("`@("`@9&%T82!T>7!E+@H@("`@("H@("`@("`@("`@("`@("`@
M("L@:6YT96=E<B!O<B!D;W5B;&4@/2!T:&4@=6YQ=6]T960@;G5M8F5R"B`@
M("`@*B`@("`@("`@("`@("`@("`@*R!O=&AE<B`H:6YC;'5D:6YG('-T<FEN
M9W,@86YD(&YU;65R:6,@<W1R:6YG<RD@/0H@("`@("H@("`@("`@("`@("`@
M("`@("`@=&AE(&1A=&$@=VET:"!S:6YG;&4@<75O=&5S(&5S8V%P960@8GD@
M<')E8V5E9&EN9PH@("`@("H@("`@("`@("`@("`@("`@("`@<VEN9VQE('%U
M;W1E<R!T:&5N('1H92!W:&]L92!S=')I;F<@:7,@96YC87!S=6QA=&5D"B`@
M("`@*B`@("`@("`@("`@("`@("`@("!B971W965N('-I;F=L92!Q=6]T97,*
M("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO;CHZ<75O=&53;6%R="@I"B`@
M("`@*B!`<VEN8V4@365T:&]D(&%V86EL86)L92!S:6YC92!296QE87-E(#$N
M-BXP"B`@("`@*B\*("`@(&9U;F-T:6]N('%U;W1E4VUA<G0H)&EN*0H@("`@
M>PH@("`@("`@(&EF("AI<U]I;G0H)&EN*2!\?"!I<U]D;W5B;&4H)&EN*2D@
M>PH@("`@("`@("`@("!R971U<FX@)&EN.PH@("`@("`@('T@96QS96EF("AI
M<U]B;V]L*"1I;BDI('L*("`@("`@("`@("`@<F5T=7)N("1I;B`_("=4)R`Z
M("=&)SL*("`@("`@("!](&5L<V5I9B`H:7-?;G5L;"@D:6XI*2!["B`@("`@
M("`@("`@(')E='5R;B`G3E5,3"<["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N("(G(B`N("1T:&ES+3YE<V-A<&53:6UP;&4H)&EN*2`N
M("(G(CL*("`@("`@("!]"B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M=&%B;&5);F9O*"D*"B`@("`O*BH*("`@("`J(%)E='5R;G,@:6YF;W)M871I
M;VX@86)O=70@=&AE(&-U<G)E;G0@9&%T86)A<V4*("`@("`J"B`@("`@*B!`
M<&%R86T@;6EX960@)')E<W5L="`@5$A)4R!)4R!53E53140@24X@1$)!4T4N
M("!4:&4@8W5R<F5N="!D871A8F%S90H@("`@("H@("`@("`@("`@("`@("`@
M("`@("`@(&ES(&5X86UI;F5D(')E9V%R9&QE<W,@;V8@=VAA="!I<R!P<F]V
M:61E9"!H97)E+@H@("`@("H@0'!A<F%M(&EN="`@("1M;V1E("`@(&$@=F%L
M:60@=&%B;&5);F9O(&UO9&4*("`@("`J"B`@("`@*B!`<F5T=7)N(&%R<F%Y
M("!A;B!A<W-O8VEA=&EV92!A<G)A>2!W:71H('1H92!I;F9O<FUA=&EO;B!R
M97%U97-T960N"B`@("`@*B`@("`@("`@("`@("`@("`@02!$0E]%<G)O<B!O
M8FIE8W0@;VX@9F%I;'5R92X*("`@("`J"B`@("`@*B!`<V5E($1"7V-O;6UO
M;CHZ=&%B;&5);F9O*"D*("`@("`J($!S:6YC92!-971H;V0@879A:6QA8FQE
M('-I;F-E(%)E;&5A<V4@,2XW+C`*("`@("`J+PH@("`@9G5N8W1I;VX@=&%B
M;&5);F9O*"1R97-U;'0@/2!N=6QL+"`D;6]D92`](&YU;&PI"B`@("!["B`@
M("`@("`@:68@*&9U;F-T:6]N7V5X:7-T<R@G9&)A<V5?9V5T7VAE861E<E]I
M;F9O)RDI('L*("`@("`@("`@("`@)&ED(#T@0&1B87-E7V=E=%]H96%D97)?
M:6YF;R@D=&AI<RT^8V]N;F5C=&EO;BD["B`@("`@("`@("`@(&EF("@A)&ED
M("8F("1P:'!?97)R;W)M<V<I('L*("`@("`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4BP*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!N=6QL+"!N=6QL+"!N=6QL+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P:'!?97)R
M;W)M<V<I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@+RH*("`@("`@("`@("`@("H@5&AI<R!S96=M96YT(&9O<B!02%`@
M-"!I<R!L;V]S96QY(&)A<V5D(&]N(&-O9&4@8GD*("`@("`@("`@("`@("H@
M2&%D:2!2=7-I86@@/&1E96=O<T!Y86AO;RYC;VT^(&EN('1H92!C;VUM96YT
M<R!O;@H@("`@("`@("`@("`@*B!T:&4@9$)A<V4@<F5F97)E;F-E('!A9V4@
M:6X@=&AE(%!(4"!M86YU86PN"B`@("`@("`@("`@("`J+PH@("`@("`@("`@
M("`D9&(@/2!`9F]P96XH)'1H:7,M/F1S;ELG9&%T86)A<V4G72P@)W(G*3L*
M("`@("`@("`@("`@:68@*"$D9&(I('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D=&AI<RT^<F%I<V5%<G)O<BA$0E]%4E)/4E]#3TY.14-47T9!24Q%1"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!N=6QL
M+"!N=6QL+"!N=6QL+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P:'!?97)R;W)M<V<I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`D:60@/2!A<G)A>2@I.PH@("`@("`@("`@("`D:2`@/2`P.PH*
M("`@("`@("`@("`@)&QI;F4@/2!F<F5A9"@D9&(L(#,R*3L*("`@("`@("`@
M("`@=VAI;&4@*"%F96]F*"1D8BDI('L*("`@("`@("`@("`@("`@("1L:6YE
M(#T@9G)E860H)&1B+"`S,BD["B`@("`@("`@("`@("`@("!I9B`H<W5B<W1R
M*"1L:6YE+"`P+"`Q*2`]/2!C:'(H,3,I*2!["B`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("1P;W,@/2!S=')P;W,H<W5B<W1R*"1L:6YE+"`P+"`Q,"DL
M(&-H<B@P*2D["B`@("`@("`@("`@("`@("`@("`@)'!O<R`]("@D<&]S(#T]
M(#`@/R`Q,"`Z("1P;W,I.PH@("`@("`@("`@("`@("`@("`@("1I9%LD:5T@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)VYA;64G("`@/3X@
M<W5B<W1R*"1L:6YE+"`P+"`D<&]S*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)W1Y<&4G("`@/3X@)'1H:7,M/G1Y<&5S6W-U8G-T<B@D;&EN92P@,3$L
M(#$I72P*("`@("`@("`@("`@("`@("`@("`@("`@)VQE;F=T:"<@/3X@;W)D
M*'-U8G-T<B@D;&EN92P@,38L(#$I*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@)W!R96-I<VEO;B<@/3X@;W)D*'-U8G-T<B@D;&EN92P@,3<L(#$I*2P*
M("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@)&DK*SL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M9F-L;W-E*"1D8BD["B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;)W!O<G1A8FEL:71Y)UT@)B!$0E]03U)404))3$E465],3U=%4D-!
M4T4I('L*("`@("`@("`@("`@)&-A<V5?9G5N8R`]("=S=')T;VQO=V5R)SL*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D8V%S95]F=6YC(#T@)W-T
M<G9A;"<["B`@("`@("`@?0H*("`@("`@("`D<F5S("`@/2!A<G)A>2@I.PH@
M("`@("`@("1C;W5N="`](&-O=6YT*"1I9"D["@H@("`@("`@(&EF("@D;6]D
M92D@>PH@("`@("`@("`@("`D<F5S6R=N=6U?9FEE;&1S)UT@/2`D8V]U;G0[
M"B`@("`@("`@?0H*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"`D8V]U;G0[
M("1I*RLI('L*("`@("`@("`@("`@)')E<ULD:5T@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("=T86)L92<@/3X@)'1H:7,M/F1S;ELG9&%T86)A<V4G72P*
M("`@("`@("`@("`@("`@("=N86UE)R`@/3X@)&-A<V5?9G5N8R@D:61;)&E=
M6R=N86UE)UTI+`H@("`@("`@("`@("`@("`@)W1Y<&4G("`]/B`D:61;)&E=
M6R=T>7!E)UTL"B`@("`@("`@("`@("`@("`G;&5N)R`@(#T^("1I9%LD:5U;
M)VQE;F=T:"==+`H@("`@("`@("`@("`@("`@)V9L86=S)R`]/B`G)PH@("`@
M("`@("`@("`I.PH@("`@("`@("`@("!I9B`H)&UO9&4@)B!$0E]404),14E.
M1D]?3U)$15(I('L*("`@("`@("`@("`@("`@("1R97-;)V]R9&5R)UU;)')E
M<ULD:5U;)VYA;64G75T@/2`D:3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!I9B`H)&UO9&4@)B!$0E]404),14E.1D]?3U)$15)404),12D@>PH@("`@
M("`@("`@("`@("`@)')E<ULG;W)D97)T86)L92==6R1R97-;)&E=6R=T86)L
M92==75LD<F5S6R1I75LG;F%M92==72`]("1I.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)')E<SL*("`@('T*"B`@("`O+R!]
M?7T*?0H*+RH*("H@3&]C86P@=F%R:6%B;&5S.@H@*B!T86(M=VED=&@Z(#0*
M("H@8RUB87-I8RUO9F9S970Z(#0*("H@16YD.@H@*B\*"C\^"@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+UA-3"]24$,`````````````````````````````````
M````````````````````````````````````````````````````,#`P-S4U
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S,@,#$W
M-#8V`"`U````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U!A<G-E<@``````
M````````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$S,R`P,C`R-S8`(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]834PO4&%R<V5R+G!H<```````````````````````````````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#0U,#4V(#$P-3$U-#,T,3,S(#`R,3$P,``@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\/W!H<`HO+PHO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO
M;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,RXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W(Z(%-T:6<@0F%K:V5N(#QS<V)`9F%S="YN;SX@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("!4;VUA
M<R!6+E8N0V]X(#QC;WA`:61E8VYE="YC;VT^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\("`@("`@("`@4W1E<&AA;B!38VAM:61T(#QS
M8VAS=$!P:'`M=&]O;',N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@4&%R
M<V5R+G!H<"QV(#$N,C8@,C`P-2\P.2\R,R`Q,3HU,3HQ,"!S8VAS="!%>'`@
M)`H*+RHJ"B`J(%A-3"!087)S97(@8VQA<W,N"B`J"B`J(%1H:7,@:7,@86X@
M6$U,('!A<G-E<B!B87-E9"!O;B!02%`G<R`B>&UL(B!E>'1E;G-I;VXL"B`J
M(&)A<V5D(&]N('1H92!B=6YD;&5D(&5X<&%T(&QI8G)A<GDN"B`J"B`J($!C
M871E9V]R>2!834P*("H@0'!A8VMA9V4@6$U,7U!A<G-E<@H@*B!`875T:&]R
M("!3=&EG($)A:VME;B`\<W-B0&9A<W0N;F\^"B`J($!A=71H;W(@(%1O;6%S
M(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U=&AO<B`@4W1E<&AA
M;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@*B\*"B\J*@H@*B!U
M<V5S(%!%05(G<R!E<G)O<B!H86YD;&EN9PH@*B\*<F5Q=6ER95]O;F-E("=0
M14%2+G!H<"<["@HO*BH*("H@<F5S;W5R8V4@8V]U;&0@;F]T(&)E(&-R96%T
M960*("HO"F1E9FEN92@G6$U,7U!!4E-%4E]%4E)/4E].3U]215-/55)#12<L
M(#(P,"D["@HO*BH*("H@=6YS=7!P;W)T960@;6]D90H@*B\*9&5F:6YE*"=8
M34Q?4$%24T527T524D]27U5.4U504$]25$5$7TU/1$4G+"`R,#$I.PH*+RHJ
M"B`J(&EN=F%L:60@96YC;V1I;F<@=V%S(&=I=F5N"B`J+PID969I;F4H)UA-
M3%]005)315)?15)23U)?24Y604Q)1%]%3D-/1$E.1R<L(#(P,BD["@HO*BH*
M("H@<W!E8VEF:65D(&9I;&4@8V]U;&0@;F]T(&)E(')E860*("HO"F1E9FEN
M92@G6$U,7U!!4E-%4E]%4E)/4E]&24Q%7TY/5%]214%$04),12<L(#(P,RD[
M"@HO*BH*("H@:6YV86QI9"!I;G!U=`H@*B\*9&5F:6YE*"=834Q?4$%24T52
M7T524D]27TE.5D%,241?24Y0550G+"`R,#0I.PH*+RHJ"B`J(')E;6]T92!F
M:6QE(&-A;FYO="!B92!R971R:65V960@:6X@<V%F92!M;V1E"B`J+PID969I
M;F4H)UA-3%]005)315)?15)23U)?4D5-3U1%)RP@,C`U*3L*"B\J*@H@*B!8
M34P@4&%R<V5R(&-L87-S+@H@*@H@*B!4:&ES(&ES(&%N(%A-3"!P87)S97(@
M8F%S960@;VX@4$A0)W,@(GAM;"(@97AT96YS:6]N+`H@*B!B87-E9"!O;B!T
M:&4@8G5N9&QE9"!E>'!A="!L:6)R87)Y+@H@*@H@*B!.;W1E<SH*("H@+2!)
M="!R97%U:7)E<R!02%`@-"XP+C1P;#$@;W(@9W)E871E<@H@*B`M($9R;VT@
M<F5V:7-I;VX@,2XQ-RP@=&AE(&9U;F-T:6]N(&YA;65S('5S960@8GD@=&AE
M("=F=6YC)R!M;V1E"B`J("`@87)E(&EN('1H92!F;W)M870@(GAM;'1A9U\D
M96QE;2(L(&9O<B!E>&%M<&QE.B!U<V4@(GAM;'1A9U]N86UE(@H@*B`@('1O
M(&AA;F1L92!T:&4@/&YA;64^/"]N86UE/B!T86=S(&]F('EO=7(@>&UL(&9I
M;&4N"B`J"B`J($!C871E9V]R>2!834P*("H@0'!A8VMA9V4@6$U,7U!A<G-E
M<@H@*B!`875T:&]R("!3=&EG($)A:VME;B`\<W-B0&9A<W0N;F\^"B`J($!A
M=71H;W(@(%1O;6%S(%8N5BY#;W@@/&-O>$!I9&5C;F5T+F-O;3X*("H@0&%U
M=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@
M*B!`=&]D;R`@("!C<F5A=&4@6$U,7U!A<G-E<E].86UE<W!A8V4@=&\@<&%R
M<V4@9&]C=6UE;G1S('=I=&@@;F%M97-P86-E<PH@*B!`=&]D;R`@("!C<F5A
M=&4@6$U,7U!A<G-E<E]0=6QL"B`J($!T;V1O("`@(%1E<W1S('1H870@;F5E
M9"!T;R!B92!M861E.@H@*B`@("`@("`@("`M(&UI>&EN9R!C:&%R86-T97(@
M96YC;V1I;F=S"B`J("`@("`@("`@("T@82!T97-T('5S:6YG(&%L;"!E>'!A
M="!H86YD;&5R<PH@*B`@("`@("`@("`M(&]P=&EO;G,@*&9O;&1I;F<L(&]U
M='!U="!C:&%R<V5T*0H@*B`@("`@("`@("`M(&1I9F9E<F5N="!P87)S:6YG
M(&UO9&5S"B`J+PIC;&%S<R!834Q?4&%R<V5R(&5X=&5N9',@4$5!4@I["B`@
M("`O+R![>WL@<')O<&5R=&EE<PH*("`@+RHJ"B`@("`@*B!834P@<&%R<V5R
M(&AA;F1L90H@("`@("H*("`@("`J($!V87(@(')E<V]U<F-E"B`@("`@*B!`
M<V5E("!X;6Q?<&%R<V5R7V-R96%T92@I"B`@("`@*B\*("`@('9A<B`D<&%R
M<V5R.PH*("`@("\J*@H@("`@("H@1FEL92!H86YD;&4@:68@<&%R<VEN9R!F
M<F]M(&$@9FEL90H@("`@("H*("`@("`J($!V87(@(')E<V]U<F-E"B`@("`@
M*B\*("`@('9A<B`D9G`["@H@("`@+RHJ"B`@("`@*B!7:&5T:&5R('1O(&1O
M(&-A<V4@9F]L9&EN9PH@("`@("H*("`@("`J($EF('-E="!T;R!T<G5E+"!A
M;&P@=&%G(&%N9"!A='1R:6)U=&4@;F%M97,@=VEL;`H@("`@("H@8F4@8V]N
M=F5R=&5D('1O(%504$52($-!4T4N"B`@("`@*@H@("`@("H@0'9A<B`@8F]O
M;&5A;@H@("`@("HO"B`@("!V87(@)&9O;&1I;F<@/2!T<G5E.PH*("`@("\J
M*@H@("`@("H@36]D92!O9B!O<&5R871I;VXL(&]N92!O9B`B979E;G0B(&]R
M(")F=6YC(@H@("`@("H*("`@("`J($!V87(@('-T<FEN9PH@("`@("HO"B`@
M("!V87(@)&UO9&4["@H@("`@+RHJ"B`@("`@*B!-87!P:6YG(&9R;VT@97AP
M870@:&%N9&QE<B!F=6YC=&EO;B!T;R!C;&%S<R!M971H;V0N"B`@("`@*@H@
M("`@("H@0'9A<B`@87)R87D*("`@("`J+PH@("`@=F%R("1H86YD;&5R(#T@
M87)R87DH"B`@("`@("`@)V-H87)A8W1E<E]D871A7VAA;F1L97(G("`@("`@
M("`@("`@/3X@)V-D871A2&%N9&QE<B<L"B`@("`@("`@)V1E9F%U;'1?:&%N
M9&QE<B<@("`@("`@("`@("`@("`@("`@/3X@)V1E9F%U;'1(86YD;&5R)RP*
M("`@("`@("`G<')O8V5S<VEN9U]I;G-T<G5C=&EO;E]H86YD;&5R)R`@("`]
M/B`G<&E(86YD;&5R)RP*("`@("`@("`G=6YP87)S961?96YT:71Y7V1E8VQ?
M:&%N9&QE<B<@("`@("`]/B`G=6YP87)S961(86YD;&5R)RP*("`@("`@("`G
M;F]T871I;VY?9&5C;%]H86YD;&5R)R`@("`@("`@("`@("`]/B`G;F]T871I
M;VY(86YD;&5R)RP*("`@("`@("`G97AT97)N86Q?96YT:71Y7W)E9E]H86YD
M;&5R)R`@("`@("`]/B`G96YT:71Y<F5F2&%N9&QE<B<*("`@("D["@H@("`@
M+RHJ"B`@("`@*B!S;W5R8V4@96YC;V1I;F<*("`@("`J"B`@("`@*B!`=F%R
M('-T<FEN9PH@("`@("HO"B`@("!V87(@)'-R8V5N8SL*"B`@("`O*BH*("`@
M("`J('1A<F=E="!E;F-O9&EN9PH@("`@("H*("`@("`J($!V87(@<W1R:6YG
M"B`@("`@*B\*("`@('9A<B`D=&=T96YC.PH*("`@("\J*@H@("`@("H@:&%N
M9&QE<B!O8FIE8W0*("`@("`J"B`@("`@*B!`=F%R(&]B:F5C=`H@("`@("HO
M"B`@("!V87(@)%]H86YD;&5R3V)J.PH*("`@("\O('U]?0H@("`@+R\@>WM[
M(&-O;G-T<G5C=&]R"@H@("`@+RHJ"B`@("`@*B!#<F5A=&5S(&%N(%A-3"!P
M87)S97(N"B`@("`@*@H@("`@("H@5&AI<R!I<R!N965D960@9F]R(%!(4#0@
M8V]M<&%T:6)I;&ET>2P@:70@=VEL;`H@("`@("H@8V%L;"!T:&4@8V]N<W1R
M=6-T;W(L('=H96X@82!N97<@:6YS=&%N8V4@:7,@8W)E871E9"X*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("1S<F-E;F,@<V]U<F-E(&-H87)S970@
M96YC;V1I;F<L('5S92!.54Q,("AD969A=6QT*2!T;R!U<V4*("`@("`J("`@
M("`@("`@("`@("`@("`@("`@("!W:&%T979E<B!T:&4@9&]C=6UE;G0@<W!E
M8VEF:65S"B`@("`@*B!`<&%R86T@<W1R:6YG("1M;V1E("`@:&]W('1H:7,@
M<&%R<V5R(&]B:F5C="!S:&]U;&0@=V]R:RP@(F5V96YT(B!F;W(*("`@("`J
M("`@("`@("`@("`@("`@("`@("`@("!S=&%R=&5L96UE;G0O96YD96QE;65N
M="UT>7!E(&5V96YT<RP@(F9U;F,B"B`@("`@*B`@("`@("`@("`@("`@("`@
M("`@("`@=&\@:&%V92!I="!C86QL(&9U;F-T:6]N<R!N86UE9"!A9G1E<B!E
M;&5M96YT<PH@("`@("H@0'!A<F%M('-T<FEN9R`D=&=E;F,@(&$@=F%L:60@
M=&%R9V5T(&5N8V]D:6YG"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]087)S
M97(H)'-R8V5N8R`](&YU;&PL("1M;V1E(#T@)V5V96YT)RP@)'1G=&5N8R`]
M(&YU;&PI"B`@("!["B`@("`@("`@6$U,7U!A<G-E<CHZ7U]C;VYS=')U8W0H
M)'-R8V5N8RP@)&UO9&4L("1T9W1E;F,I.PH@("`@?0H@("`@+R\@?7U]"@H@
M("`@+RHJ"B`@("`@*B!02%`U(&-O;G-T<G5C=&]R"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D<W)C96YC('-O=7)C92!C:&%R<V5T(&5N8V]D:6YG
M+"!U<V4@3E5,3"`H9&5F875L="D@=&\@=7-E"B`@("`@*B`@("`@("`@("`@
M("`@("`@("`@("`@=VAA=&5V97(@=&AE(&1O8W5M96YT('-P96-I9FEE<PH@
M("`@("H@0'!A<F%M('-T<FEN9R`D;6]D92`@(&AO=R!T:&ES('!A<G-E<B!O
M8FIE8W0@<VAO=6QD('=O<FLL(")E=F5N="(@9F]R"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("`@<W1A<G1E;&5M96YT+V5N9&5L96UE;G0M='EP92!E
M=F5N=',L(")F=6YC(@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@('1O
M(&AA=F4@:70@8V%L;"!F=6YC=&EO;G,@;F%M960@869T97(@96QE;65N=',*
M("`@("`J($!P87)A;2!S=')I;F<@)'1G96YC("!A('9A;&ED('1A<F=E="!E
M;F-O9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!?7V-O;G-T<G5C="@D<W)C
M96YC(#T@;G5L;"P@)&UO9&4@/2`G979E;G0G+"`D=&=T96YC(#T@;G5L;"D*
M("`@('L*("`@("`@("`D=&AI<RT^4$5!4B@G6$U,7U!A<G-E<E]%<G)O<B<I
M.PH*("`@("`@("`D=&AI<RT^;6]D92`@(#T@)&UO9&4["B`@("`@("`@)'1H
M:7,M/G-R8V5N8R`]("1S<F-E;F,["B`@("`@("`@)'1H:7,M/G1G=&5N8R`]
M("1T9W1E;F,["B`@("!]"B`@("`O+R!]?7T*"B`@("`O*BH*("`@("`J(%-E
M=',@=&AE(&UO9&4@;V8@=&AE('!A<G-E<BX*("`@("`J"B`@("`@*B!0;W-S
M:6)L92!M;V1E<R!A<F4Z"B`@("`@*B`M(&9U;F,*("`@("`J("T@979E;G0*
M("`@("`J"B`@("`@*B!9;W4@8V%N('-E="!T:&4@;6]D92!U<VEN9R!T:&4@
M<V5C;VYD('!A<F%M971E<@H@("`@("H@:6X@=&AE(&-O;G-T<G5C=&]R+@H@
M("`@("H*("`@("`J(%1H:7,@;65T:&]D(&ES(&]N;'D@;F5E9&5D+"!W:&5N
M('-W:71C:&EN9R!T;R!A(&YE=PH@("`@("H@;6]D92!A="!A(&QA=&5R('!O
M:6YT+@H@("`@("H*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("H@0'!A
M<F%M("`@<W1R:6YG("`@("`@("`@(&UO9&4L(&5I=&AE<B`G9G5N8R<@;W(@
M)V5V96YT)PH@("`@("H@0')E='5R;B`@8F]O;&5A;GQO8FIE8W0@('1R=64@
M;VX@<W5C8V5S<RP@4$5!4E]%<G)O<B!O=&AE<G=I<V4@("`*("`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T36]D92@D;6]D92D*("`@('L*("`@("`@("!I9B`H
M)&UO9&4@(3T@)V9U;F,G("8F("1M;V1E("$]("=E=F5N="<I('L*("`@("`@
M("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)U5N<W5P<&]R=&5D(&UO9&4@9VEV
M96XG+"!834Q?4$%24T527T524D]27U5.4U504$]25$5$7TU/1$4I.PH@("`@
M("`@('T*"B`@("`@("`@)'1H:7,M/FUO9&4@/2`D;6]D93L*("`@("`@("!R
M971U<FX@=')U93L*("`@('T*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&]B
M:F5C="P@=&AA="!W:6QL(&AA;F1L92!T:&4@6$U,(&5V96YT<PH@("`@("H*
M("`@("`J(%1H:7,@86QL;W=S('EO=2!T;R!C<F5A=&4@82!H86YD;&5R(&]B
M:F5C="!I;F1E<&5N9&5N="!O9B!T:&4*("`@("`J('!A<G-E<B!O8FIE8W0@
M=&AA="!Y;W4@87)E('5S:6YG(&%N9"!E87-I;'D@<W=I=&-H('1H92!U;F1E
M<FQY:6YG"B`@("`@*B!P87)S97(N"B`@("`@*@H@("`@("H@268@;F\@;V)J
M96-T('=I;&P@8F4@<V5T+"!834Q?4&%R<V5R(&%S<W5M97,@=&AA="!Y;W4*
M("`@("`J(&5X=&5N9"!T:&ES(&-L87-S(&%N9"!H86YD;&4@=&AE(&5V96YT
M<R!I;B`D=&AI<RX*("`@("`J"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J($!P87)A;2`@(&]B:F5C="`@("`@(&]B:F5C="!T;R!H86YD;&4@=&AE
M(&5V96YT<PH@("`@("H@0')E='5R;B`@8F]O;&5A;B`@("`@=VEL;"!A;'=A
M>7,@<F5T=7)N('1R=64*("`@("`J($!S:6YC92`@('8Q+C(N,&)E=&$S"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$AA;F1L97)/8FHH)B1O8FHI"B`@("![
M"B`@("`@("`@)'1H:7,M/E]H86YD;&5R3V)J(#T@)B1O8FH["B`@("`@("`@
M<F5T=7)N('1R=64["B`@("!]"@H@("`@+RHJ"B`@("`@*B!);FET('1H92!E
M;&5M96YT(&AA;F1L97)S"B`@("`@*@H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!F=6YC=&EO;B!?:6YI=$AA;F1L97)S*"D*("`@('L*
M("`@("`@("!I9B`H(6ES7W)E<V]U<F-E*"1T:&ES+3YP87)S97(I*2!["B`@
M("`@("`@("`@(')E='5R;B!F86QS93L*("`@("`@("!]"@H@("`@("`@(&EF
M("@A:7-?;V)J96-T*"1T:&ES+3Y?:&%N9&QE<D]B:BDI('L*("`@("`@("`@
M("`@)'1H:7,M/E]H86YD;&5R3V)J(#T@)B1T:&ES.PH@("`@("`@('T*("`@
M("`@("!S=VET8V@@*"1T:&ES+3YM;V1E*2!["@H@("`@("`@("`@("!C87-E
M("=F=6YC)SH*("`@("`@("`@("`@("`@('AM;%]S971?;V)J96-T*"1T:&ES
M+3YP87)S97(L("1T:&ES+3Y?:&%N9&QE<D]B:BD["B`@("`@("`@("`@("`@
M("!X;6Q?<V5T7V5L96UE;G1?:&%N9&QE<B@D=&AI<RT^<&%R<V5R+"!A<G)A
M>2@F)'1H:7,L("=F=6YC4W1A<G1(86YD;&5R)RDL(&%R<F%Y*"8D=&AI<RP@
M)V9U;F-%;F1(86YD;&5R)RDI.PH@("`@("`@("`@("`@("`@8G)E86L["@H@
M("`@("`@("`@("!C87-E("=E=F5N="<Z"B`@("`@("`@("`@("`@("!X;6Q?
M<V5T7V]B:F5C="@D=&AI<RT^<&%R<V5R+"`D=&AI<RT^7VAA;F1L97)/8FHI
M.PH@("`@("`@("`@("`@("`@>&UL7W-E=%]E;&5M96YT7VAA;F1L97(H)'1H
M:7,M/G!A<G-E<BP@)W-T87)T2&%N9&QE<B<L("=E;F1(86YD;&5R)RD["B`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@
M("`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G56YS=7!P
M;W)T960@;6]D92!G:79E;B<L(%A-3%]005)315)?15)23U)?54Y355!03U)4
M141?34]$12D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]"@H*
M("`@("`@("`O*BH*("`@("`@("`@*B!S970@861D:71I;VYA;"!H86YD;&5R
M<R!F;W(@8VAA<F%C=&5R(&1A=&$L(&5N=&ET:65S+"!E=&,N"B`@("`@("`@
M("HO"B`@("`@("`@9F]R96%C:"`H)'1H:7,M/FAA;F1L97(@87,@)'AM;%]F
M=6YC(#T^("1M971H;V0I('L*("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES
M=',H)'1H:7,M/E]H86YD;&5R3V)J+"`D;65T:&]D*2D@>PH@("`@("`@("`@
M("`@("`@)'AM;%]F=6YC(#T@)WAM;%]S971?)R`N("1X;6Q?9G5N8SL*("`@
M("`@("`@("`@("`@("1X;6Q?9G5N8R@D=&AI<RT^<&%R<V5R+"`D;65T:&]D
M*3L*("`@("`@("`@("`@?0H)"7T*("`@('T*"B`@("`O+R![>WL@7V-R96%T
M92@I"@H@("`@+RHJ"B`@("`@*B!C<F5A=&4@=&AE(%A-3"!P87)S97(@<F5S
M;W5R8V4*("`@("`J"B`@("`@*B!(87,@8F5E;B!M;W9E9"!F<F]M('1H92!C
M;VYS=')U8W1O<B!T;R!A=F]I9`H@("`@("H@<')O8FQE;7,@=VET:"!O8FIE
M8W0@<F5F97)E;F-E<RX*("`@("`J"B`@("`@*B!&=7)T:&5R;6]R92!I="!A
M;&QO=W,@=7,@<F5T=7)N:6YG(&%N(&5R<F]R"B`@("`@*B!I9B!S;VUE=&AI
M;F<@9F%I;',N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@
M("`J($!R971U<FX@("!B;V]L96%N?&]B:F5C="`@("`@=')U92!O;B!S=6-C
M97-S+"!014%27T5R<F]R(&]T:&5R=VES90H@("`@("H*("`@("`J($!S964@
M>&UL7W!A<G-E<E]C<F5A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@7V-R96%T
M92@I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YS<F-E;F,@/3T](&YU;&PI
M('L*("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?8W)E871E*"D["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'AP(#T@0'AM;%]P87)S97)?
M8W)E871E*"1T:&ES+3YS<F-E;F,I.PH@("`@("`@('T*("`@("`@("!I9B`H
M:7-?<F5S;W5R8V4H)'AP*2D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/G1G
M=&5N8R`A/3T@;G5L;"D@>PH@("`@("`@("`@("`@("`@:68@*"%`>&UL7W!A
M<G-E<E]S971?;W!T:6]N*"1X<"P@6$U,7T]05$E/3E]405)'151?14Y#3T1)
M3D<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G1G=&5N8RDI('L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)'1H:7,M/G)A:7-E17)R;W(H)VEN=F%L:60@=&%R9V5T(&5N8V]D:6YG
M)RP@6$U,7U!!4E-%4E]%4E)/4E])3E9!3$E$7T5.0T]$24Y'*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@?0H@("`@("`@("`@("`D=&AI<RT^
M<&%R<V5R(#T@)'AP.PH@("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]I
M;FET2&%N9&QE<G,H)'1H:7,M/FUO9&4I.PH@("`@("`@("`@("!I9B`H)'1H
M:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D<F5S=6QT.PH@("`@("`@("`@("!]"B`@("`@("`@("`@('AM;%]P87)S
M97)?<V5T7V]P=&EO;B@D>'`L(%A-3%]/4%1)3TY?0T%315]&3TQ$24Y'+"`D
M=&AI<RT^9F]L9&EN9RD["@H@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=5;F%B
M;&4@=&\@8W)E871E(%A-3"!P87)S97(@<F5S;W5R8V4N)RP@6$U,7U!!4E-%
M4E]%4E)/4E].3U]215-/55)#12D["B`@("!]"@H@("`@+R\@?7U]"B`@("`O
M+R![>WL@<F5S970H*0H*("`@("\J*@H@("`@("H@4F5S970@=&AE('!A<G-E
M<BX*("`@("`J"B`@("`@*B!4:&ES(&%L;&]W<R!Y;W4@=&\@=7-E(&]N92!P
M87)S97(@:6YS=&%N8V4*("`@("`J('1O('!A<G-E(&UU;'1I<&QE(%A-3"!D
M;V-U;65N=',N"B`@("`@*@H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M("H@0')E='5R;B`@(&)O;VQE86Y\;V)J96-T("`@("!T<G5E(&]N('-U8V-E
M<W,L(%!%05)?17)R;W(@;W1H97)W:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N
M(')E<V5T*"D*("`@('L*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]C<F5A
M=&4H*3L*("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H("1R97-U;'0@*2D@
M>PH@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@
M<V5T26YP=71&:6QE*"D*"B`@("`O*BH*("`@("`J(%-E=',@=&AE(&EN<'5T
M('AM;"!F:6QE('1O(&)E('!A<G-E9`H@("`@("H*("`@("`J($!P87)A;2`@
M("!S=')I;F<@("`@("!&:6QE;F%M92`H9G5L;"!P871H*0H@("`@("H@0')E
M='5R;B`@(')E<V]U<F-E("`@(&9O<&5N(&AA;F1L92!O9B!T:&4@9VEV96X@
M9FEL90H@("`@("H@0'1H<F]W<R`@(%A-3%]087)S97)?17)R;W(*("`@("`J
M($!S964@("`@("!S971);G!U="@I+"!S971);G!U=%-T<FEN9R@I+"!P87)S
M92@I"B`@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T
M:6]N('-E=$EN<'5T1FEL92@D9FEL92D*("`@('L*("`@("`@("`O*BH*("`@
M("`@("`@*B!C:&5C:RP@:68@9FEL92!I<R!A(')E;6]T92!F:6QE"B`@("`@
M("`@("HO"B`@("`@("`@:68@*&5R96=I*"=>*&AT='!\9G1P*3HO+R<L('-U
M8G-T<B@D9FEL92P@,"P@,3`I*2D@>PH@("`@("`@("`@("!I9B`H(6EN:5]G
M970H)V%L;&]W7W5R;%]F;W!E;B<I*2!["B`@("`@("`@("`@(`ER971U<FX@
M)'1H:7,M/G)A:7-E17)R;W(H)U)E;6]T92!F:6QE<R!C86YN;W0@8F4@<&%R
M<V5D+"!A<R!S869E(&UO9&4@:7,@96YA8FQE9"XG+"!834Q?4$%24T527T52
M4D]27U)%34]412D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@
M"B`@("`@("`@)&9P(#T@0&9O<&5N*"1F:6QE+"`G<F(G*3L*("`@("`@("!I
M9B`H:7-?<F5S;W5R8V4H)&9P*2D@>PH@("`@("`@("`@("`D=&AI<RT^9G`@
M/2`D9G`["B`@("`@("`@("`@(')E='5R;B`D9G`["B`@("`@("`@?0H@("`@
M("`@(')E='5R;B`D=&AI<RT^<F%I<V5%<G)O<B@G1FEL92!C;W5L9"!N;W0@
M8F4@;W!E;F5D+B<L(%A-3%]005)315)?15)23U)?1DE,15].3U1?4D5!1$%"
M3$4I.PH@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[('-E=$EN<'5T4W1R
M:6YG*"D*("`@(`H@("`@+RHJ"B`@("`@*B!834Q?4&%R<V5R.CIS971);G!U
M=%-T<FEN9R@I"B`@("`@*B`*("`@("`J(%-E=',@=&AE('AM;"!I;G!U="!F
M<F]M(&$@<W1R:6YG"B`@("`@*B`*("`@("`J($!P87)A;2!S=')I;F<@)&1A
M=&$@82!S=')I;F<@8V]N=&%I;FEN9R!T:&4@6$U,(&1O8W5M96YT"B`@("`@
M*B!`<F5T=7)N(&YU;&P*("`@("`J*B\*("`@(&9U;F-T:6]N('-E=$EN<'5T
M4W1R:6YG*"1D871A*0H@("`@>PH@("`@("`@("1T:&ES+3YF<"`]("1D871A
M.PH@("`@("`@(')E='5R;B!N=6QL.PH@("`@?0H@("`@"B`@("`O+R!]?7T*
M("`@("\O('M[>R!S971);G!U="@I"@H@("`@+RHJ"B`@("`@*B!3971S('1H
M92!F:6QE(&AA;F1L92!T;R!U<V4@=VET:"!P87)S92@I+@H@("`@("H*("`@
M("`J(%EO=2!S:&]U;&0@=7-E('-E=$EN<'5T1FEL92@I(&]R('-E=$EN<'5T
M4W1R:6YG*"D@:68@>6]U"B`@("`@*B!P87-S(&$@<W1R:6YG(`H@("`@("H*
M("`@("`J($!P87)A;2`@("!M:7AE9"`@)&9P("!#86X@8F4@96ET:&5R(&$@
M<F5S;W5R8V4@<F5T=7)N960@9G)O;2!F;W!E;B@I+`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@(&$@55),+"!A(&QO8V%L(&9I;&5N86UE(&]R(&$@
M<W1R:6YG+@H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("H@0'-E92`@
M("`@('!A<G-E*"D*("`@("`J($!U<V5S("`@("!S971);G!U=%-T<FEN9R@I
M+"!S971);G!U=$9I;&4H*0H@("`@("HO"B`@("!F=6YC=&EO;B!S971);G!U
M="@D9G`I"B`@("!["B`@("`@("`@:68@*&ES7W)E<V]U<F-E*"1F<"DI('L*
M("`@("`@("`@("`@)'1H:7,M/F9P(#T@)&9P.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!]"B`@("`@("`@+R\@<V5E(&EF(&ET)W,@86X@
M86)S;VQU=&4@55),("AH87,@82!S8VAE;64@870@=&AE(&)E9VEN;FEN9RD*
M("`@("`@("!E;'-E:68@*&5R96=I*"=>6V$M>ETK.B\O)RP@<W5B<W1R*"1F
M<"P@,"P@,3`I*2D@>PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/G-E=$EN
M<'5T1FEL92@D9G`I.PH@("`@("`@('T*("`@("`@("`O+R!S964@:68@:70G
M<R!A(&QO8V%L(&9I;&4*("`@("`@("!E;'-E:68@*&9I;&5?97AI<W1S*"1F
M<"DI('L*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YS971);G!U=$9I;&4H
M)&9P*3L*("`@("`@("!]"B`@("`@("`@+R\@:70@;75S="!B92!A('-T<FEN
M9PH@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^9G`@/2`D9G`[
M"B`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=);&QE9V%L(&EN<'5T(&9O<FUA
M="<L(%A-3%]005)315)?15)23U)?24Y604Q)1%])3E!55"D["B`@("!]"@H@
M("`@+R\@?7U]"B`@("`O+R![>WL@<&%R<V4H*0H*("`@("\J*@H@("`@("H@
M0V5N=')A;"!P87)S:6YG(&9U;F-T:6]N+@H@("`@("H*("`@("`J($!R971U
M<FX@("!T<G5E?&]B:F5C="!014%2(&5R<F]R("`@("!R971U<FYS('1R=64@
M;VX@<W5C8V5S<RP@;W(@82!014%27T5R<F]R(&]T:&5R=VES90H@("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!P87)S92@I
M"B`@("!["B`@("`@("`@+RHJ"B`@("`@("`@("H@<F5S970@=&AE('!A<G-E
M<@H@("`@("`@("`J+PH@("`@("`@("1R97-U;'0@/2`D=&AI<RT^<F5S970H
M*3L*("`@("`@("!I9B`H)'1H:7,M/FES17)R;W(H)')E<W5L="DI('L*("`@
M("`@("`@("`@<F5T=7)N("1R97-U;'0["B`@("`@("`@?0H@("`@("`@("\O
M(&EF("1T:&ES+3YF<"!W87,@9F]P96YE9"!P<F5V:6]U<VQY"B`@("`@("`@
M:68@*&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI('L*("`@("`@("`*("`@("`@
M("`@("`@=VAI;&4@*"1D871A(#T@9G)E860H)'1H:7,M/F9P+"`T,#DV*2D@
M>PH@("`@("`@("`@("`@("`@:68@*"$D=&AI<RT^7W!A<G-E4W1R:6YG*"1D
M871A+"!F96]F*"1T:&ES+3YF<"DI*2!["B`@("`@("`@("`@("`@("`@("`@
M)&5R<F]R(#T@)B1T:&ES+3YR86ES945R<F]R*"D["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@)&5R<F]R.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@+R\@;W1H97)W:7-E+"`D=&AI<RT^9G`@;75S="!B92!A('-T<FEN
M9PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]P
M87)S95-T<FEN9R@D=&AI<RT^9G`L('1R=64I*2!["B`@("`@("`@("`@("`@
M("`D97)R;W(@/2`F)'1H:7,M/G)A:7-E17)R;W(H*3L*("`@("`@("`@("`@
M("`@("1T:&ES+3YF<F5E*"D["B`@("`@("`@("`@("`@("!R971U<FX@)&5R
M<F]R.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("1T:&ES+3YF
M<F5E*"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J*@H@
M("`@("H@6$U,7U!A<G-E<CHZ7W!A<G-E4W1R:6YG*"D*("`@("`J(`H@("`@
M("H@0'!A<F%M('-T<FEN9R`D9&%T80H@("`@("H@0'!A<F%M(&)O;VQE86X@
M)&5O9@H@("`@("H@0')E='5R;B!B;V]L"B`@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("`J($!S964@<&%R<V53=')I;F<H*0H@("`@("HJ+PH@("`@9G5N
M8W1I;VX@7W!A<G-E4W1R:6YG*"1D871A+"`D96]F(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@<F5T=7)N('AM;%]P87)S92@D=&AI<RT^<&%R<V5R+"`D9&%T
M82P@)&5O9BD["B`@("!]"B`@("`*("`@("\O('U]?0H@("`@+R\@>WM[('!A
M<G-E4W1R:6YG*"D*"B`@("`O*BH*("`@("`J(%A-3%]087)S97(Z.G!A<G-E
M4W1R:6YG*"D*("`@("`J(`H@("`@("H@4&%R<V5S(&$@<W1R:6YG+@H@("`@
M("H*("`@("`J($!P87)A;2`@("!S=')I;F<@("1D871A(%A-3"!D871A"B`@
M("`@*B!`<&%R86T@("`@8F]O;&5A;B`D96]F("!)9B!S970@86YD(%12544L
M(&1A=&$@:7,@=&AE(&QA<W0@<&EE8V4@;V8@9&%T82!S96YT(&EN('1H:7,@
M<&%R<V5R"B`@("`@*B!`=&AR;W=S("`@6$U,7U!A<G-E<E]%<G)O<@H@("`@
M("H@0')E='5R;B`@(%!E87(@17)R;W)\=')U92`@('1R=64@;VX@<W5C8V5S
M<R!O<B!A(%!%05(@17)R;W(*("`@("`J($!S964@("`@("!?<&%R<V53=')I
M;F<H*0H@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95-T<FEN9R@D9&%T82P@
M)&5O9B`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'1H:7,M
M/G!A<G-E<BD@?'P@(6ES7W)E<V]U<F-E*"1T:&ES+3YP87)S97(I*2!["B`@
M("`@("`@("`@("1T:&ES+3YR97-E="@I.PH@("`@("`@('T*("`@("`@("`*
M("`@("`@("!I9B`H(21T:&ES+3Y?<&%R<V53=')I;F<H)&1A=&$L("1E;V8I
M*2!["B`@("`@("`@("`@)&5R<F]R(#T@)B1T:&ES+3YR86ES945R<F]R*"D[
M"B`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("`@("!R971U<FX@
M)&5R<F]R.PH@("`@("`@('T*"B`@("`@("`@:68@*"1E;V8@/3T]('1R=64I
M('L*("`@("`@("`@("`@)'1H:7,M/F9R964H*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N('1R=64["B`@("!]"B`@("`*("`@("\J*@H@("`@("H@6$U,
M7U!A<G-E<CHZ9G)E92@I"B`@("`@*B`*("`@("`J($9R964@=&AE(&EN=&5R
M;F%L(')E<V]U<F-E<R!A<W-O8VEA=&5D('=I=&@@=&AE('!A<G-E<@H@("`@
M("H@"B`@("`@*B!`<F5T=7)N(&YU;&P*("`@("`J*B\*("`@(&9U;F-T:6]N
M(&9R964H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^<&%R<V5R
M*2`F)B!I<U]R97-O=7)C92@D=&AI<RT^<&%R<V5R*2D@>PH@("`@("`@("`@
M("!X;6Q?<&%R<V5R7V9R964H)'1H:7,M/G!A<G-E<BD["B`@("`@("`@("`@
M('5N<V5T*"`D=&AI<RT^<&%R<V5R("D["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<W-E="@D=&AI<RT^9G`I("8F(&ES7W)E<V]U<F-E*"1T:&ES+3YF<"DI
M('L*("`@("`@("`@("`@9F-L;W-E*"1T:&ES+3YF<"D["B`@("`@("`@?0H@
M("`@("`@('5N<V5T*"1T:&ES+3YF<"D["B`@("`@("`@<F5T=7)N(&YU;&P[
M"B`@("!]"B`@("`*("`@("\J*@H@("`@("H@6$U,7U!A<G-E<CHZ<F%I<V5%
M<G)O<B@I"B`@("`@*B`*("`@("`J(%1H<F]W<R!A(%A-3%]087)S97)?17)R
M;W(*("`@("`J(`H@("`@("H@0'!A<F%M('-T<FEN9R`@)&US9R`@('1H92!E
M<G)O<B!M97-S86=E"B`@("`@*B!`<&%R86T@:6YT96=E<B`D96-O9&4@=&AE
M(&5R<F]R(&UE<W-A9V4@8V]D90H@("`@("H@0')E='5R;B!834Q?4&%R<V5R
M7T5R<F]R(`H@("`@("HJ+PH@("`@9G5N8W1I;VX@<F%I<V5%<G)O<B@D;7-G
M(#T@;G5L;"P@)&5C;V1E(#T@,"D*("`@('L*("`@("`@("`D;7-G(#T@(6ES
M7VYU;&PH)&US9RD@/R`D;7-G(#H@)'1H:7,M/G!A<G-E<CL*("`@("`@("`D
M97)R(#T@)FYE=R!834Q?4&%R<V5R7T5R<F]R*"1M<V<L("1E8V]D92D["B`@
M("`@("`@<F5T=7)N('!A<F5N=#HZ<F%I<V5%<G)O<B@D97)R*3L*("`@('T*
M("`@(`H@("`@+R\@?7U]"B`@("`O+R![>WL@9G5N8U-T87)T2&%N9&QE<B@I
M"@H@("`@9G5N8W1I;VX@9G5N8U-T87)T2&%N9&QE<B@D>'`L("1E;&5M+"`D
M871T<FEB<RD*("`@('L*("`@("`@("`D9G5N8R`]("=X;6QT86=?)R`N("1E
M;&5M.PH@("`@("`@(&EF("AS=')C:'(H)&9U;F,L("<N)RDI('L*("`@("`@
M("`@("`@)&9U;F,@/2!S=')?<F5P;&%C92@G+B<L("=?)RP@)&9U;F,I.PH@
M("`@("`@('T*("`@("`@("!I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^7VAA
M;F1L97)/8FHL("1F=6YC*2D@>PH@("`@("`@("`@("!C86QL7W5S97)?9G5N
M8RAA<G)A>2@F)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDL("1X<"P@)&5L
M96TL("1A='1R:6)S*3L*("`@("`@("!](&5L<V5I9B`H;65T:&]D7V5X:7-T
M<R@D=&AI<RT^7VAA;F1L97)/8FHL("=X;6QT86<G*2D@>PH@("`@("`@("`@
M("!C86QL7W5S97)?9G5N8RAA<G)A>2@F)'1H:7,M/E]H86YD;&5R3V)J+"`G
M>&UL=&%G)RDL("1X<"P@)&5L96TL("1A='1R:6)S*3L*("`@("`@("!]"B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@9G5N8T5N9$AA;F1L97(H*0H*
M("`@(&9U;F-T:6]N(&9U;F-%;F1(86YD;&5R*"1X<"P@)&5L96TI"B`@("![
M"B`@("`@("`@)&9U;F,@/2`G>&UL=&%G7R<@+B`D96QE;2`N("=?)SL*("`@
M("`@("!I9B`H<W1R8VAR*"1F=6YC+"`G+B<I*2!["B`@("`@("`@("`@("1F
M=6YC(#T@<W1R7W)E<&QA8V4H)RXG+"`G7R<L("1F=6YC*3L*("`@("`@("!]
M"B`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD;&5R3V)J
M+"`D9G5N8RDI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H87)R87DH
M)B1T:&ES+3Y?:&%N9&QE<D]B:BP@)&9U;F,I+"`D>'`L("1E;&5M*3L*("`@
M("`@("!](&5L<V5I9B`H;65T:&]D7V5X:7-T<R@D=&AI<RT^7VAA;F1L97)/
M8FHL("=X;6QT86=?)RDI('L*("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H
M87)R87DH)B1T:&ES+3Y?:&%N9&QE<D]B:BP@)WAM;'1A9U\G*2P@)'AP+"`D
M96QE;2D["B`@("`@("`@?0H@("`@?0H*("`@("\O('U]?0H@("`@+R\@>WM[
M('-T87)T2&%N9&QE<B@I"@H@("`@+RHJ"B`@("`@*@H@("`@("H@0&%B<W1R
M86-T"B`@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D>'`L("1E
M;&5M+"`F)&%T=')I8G,I"B`@("!["B`@("`@("`@<F5T=7)N($Y53$P["B`@
M("!]"@H@("`@+R\@?7U]"B`@("`O+R![>WL@96YD2&%N9&QE<B@I"@H@("`@
M+RHJ"B`@("`@*@H@("`@("H@0&%B<W1R86-T"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5N9$AA;F1L97(H)'AP+"`D96QE;2D*("`@('L*("`@("`@("!R971U
M<FX@3E5,3#L*("`@('T*"@H@("`@+R\@?7U];64*?0H*+RHJ"B`J(&5R<F]R
M(&-L87-S+"!R97!L86-E<R!014%27T5R<F]R"B`J"B`J($%N(&EN<W1A;F-E
M(&]F('1H:7,@8VQA<W,@=VEL;"!B92!R971U<FYE9`H@*B!I9B!A;B!E<G)O
M<B!O8V-U<G,@:6YS:61E(%A-3%]087)S97(N"B`J"B`J(%1H97)E(&%R92!T
M:')E92!A9'9A;G1A9V5S(&]V97(@=7-I;F<@=&AE('-T86YD87)D(%!%05)?
M17)R;W(Z"B`J("T@06QL(&UE<W-A9V5S('=I;&P@8F4@<')E9FEX960*("H@
M+2!C:&5C:R!F;W(@6$U,7U!A<G-E<B!E<G)O<BP@=7-I;F<@:7-?82@@)&5R
M<F]R+"`G6$U,7U!A<G-E<E]%<G)O<B<@*0H@*B`M(&UE<W-A9V5S(&-A;B!B
M92!G96YE<F%T960@9G)O;2!T:&4@>&UL7W!A<G-E<B!R97-O=7)C90H@*@H@
M*B!`<&%C:V%G92!834Q?4&%R<V5R"B`J($!A8V-E<W,@('!U8FQI8PH@*B!`
M<V5E("`@("!014%27T5R<F]R"B`J+PIC;&%S<R!834Q?4&%R<V5R7T5R<F]R
M(&5X=&5N9',@4$5!4E]%<G)O<@I["B`@("`O+R![>WL@<')O<&5R=&EE<PH*
M("`@+RHJ"B`@("`J('!R969I>"!F;W(@86QL(&UE<W-A9V5S"B`@("`J"B`@
M("`J($!V87(@("`@("!S=')I;F<*("`@("HO("`@(`H@("`@=F%R("1E<G)O
M<E]M97-S86=E7W!R969I>"`]("=834Q?4&%R<V5R.B`G.PH*("`@("\O('U]
M?0H@("`@+R\@>WM[(&-O;G-T<G5C=&]R*"D*("`@+RHJ"B`@("`J(&-O;G-T
M<G5C="!A(&YE=R!E<G)O<B!I;G-T86YC90H@("`@*@H@("`@*B!9;W4@;6%Y
M(&5I=&AE<B!P87-S(&$@;65S<V%G92!O<B!A;B!X;6Q?<&%R<V5R(')E<V]U
M<F-E(&%S(&9I<G-T"B`@("`J('!A<F%M971E<BX@268@82!R97-O=7)C92!H
M87,@8F5E;B!P87-S960L('1H92!L87-T(&5R<F]R('1H870*("`@("H@:&%P
M<&5N960@=VEL;"!B92!R971R:65V960@86YD(')E='5R;F5D+@H@("`@*@H@
M("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P87)A;2`@("!S=')I;F=\
M<F5S;W5R8V4@("`@(&UE<W-A9V4@;W(@<&%R<V5R(')E<V]U<F-E"B`@("`J
M($!P87)A;2`@("!I;G1E9V5R("`@("`@("`@("`@(&5R<F]R(&-O9&4*("`@
M("H@0'!A<F%M("`@(&EN=&5G97(@("`@("`@("`@("`@97)R;W(@:&%N9&QI
M;F<*("`@("H@0'!A<F%M("`@(&EN=&5G97(@("`@("`@("`@("`@97)R;W(@
M;&5V96P*("`@("HO("`@(`H@("`@9G5N8W1I;VX@6$U,7U!A<G-E<E]%<G)O
M<B@D;7-G;W)P87)S97(@/2`G=6YK;F]W;B!E<G)O<B<L("1C;V1E(#T@,"P@
M)&UO9&4@/2!014%27T524D]27U)%5%523BP@)&QE=F5L(#T@15]54T527TY/
M5$E#12D*("`@('L*("`@("`@("!I9B`H:7-?<F5S;W5R8V4H)&US9V]R<&%R
M<V5R*2D@>PH@("`@("`@("`@("`D8V]D92`]('AM;%]G971?97)R;W)?8V]D
M92@D;7-G;W)P87)S97(I.PH@("`@("`@("`@("`D;7-G;W)P87)S97(@/2!S
M<')I;G1F*"<E<R!A="!834P@:6YP=70@;&EN92`E9#HE9"<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9R@D
M8V]D92DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL
M7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1M<V=O<G!A<G-E<BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V=E=%]C=7)R96YT
M7V-O;'5M;E]N=6UB97(H)&US9V]R<&%R<V5R*2D["B`@("`@("`@?0H@("`@
M("`@("1T:&ES+3Y014%27T5R<F]R*"1M<V=O<G!A<G-E<BP@)&-O9&4L("1M
M;V1E+"`D;&5V96PI.PH@("`@?0H@("`@+R\@?7U]"GT*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]834PO571I;"YP
M:'``````````````````````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#8U,S8S(#$P-3$U-#,T,3,S(#`R,#4V-``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/U!(4`T*+RH@=FEM.B!S970@97AP
M86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30Z("HO#0HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+R!\
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`R(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE
M8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\
M#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P-"B\O('P@879A:6QA
M8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`T*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P-"B\O('P@
M;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@
M<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-
M"B\O('P@075T:&]R<SH@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O
M;',N;F5T/B`@("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@("`@)$ED.B!5=&EL+G!H<"QV
M(#$N,C0@,C`P-"\Q,B\R,R`Q,SHR,3HU.2!S8VAS="!%>'`@)`T*#0HO*BH-
M"B`J(&5R<F]R(&-O9&4@9F]R(&EN=F%L:60@8VAA<G,@:6X@6$U,(&YA;64-
M"B`J+PT*9&5F:6YE*")834Q?551)3%]%4E)/4E])3E9!3$E$7T-(05)3(BP@
M-3$I.PT*#0HO*BH-"B`J(&5R<F]R(&-O9&4@9F]R(&EN=F%L:60@8VAA<G,@
M:6X@6$U,(&YA;64-"B`J+PT*9&5F:6YE*")834Q?551)3%]%4E)/4E])3E9!
M3$E$7U-405)4(BP@-3(I.PT*#0HO*BH-"B`J(&5R<F]R(&-O9&4@9F]R(&YO
M;BUS8V%L87(@=&%G(&-O;G1E;G0-"B`J+PT*9&5F:6YE*")834Q?551)3%]%
M4E)/4E].3TY?4T-!3$%27T-/3E1%3E0B+"`V,"D[#0H@("`@#0HO*BH-"B`J
M(&5R<F]R(&-O9&4@9F]R(&UI<W-I;F<@=&%G(&YA;64-"B`J+PT*9&5F:6YE
M*")834Q?551)3%]%4E)/4E].3U]404=?3D%-12(L(#8Q*3L-"B`@("`-"B\J
M*@T*("H@<F5P;&%C92!834P@96YT:71I97,-"B`J+PT*9&5F:6YE*")834Q?
M551)3%]215!,04-%7T5.5$E42453(BP@,2D[#0H-"B\J*@T*("H@96UB961D
M(&-O;G1E;G0@:6X@82!#1&%T82!396-T:6]N#0H@*B\-"F1E9FEN92@B6$U,
M7U5424Q?0T1!5$%?4T5#5$E/3B(L(#4I.PT*#0HO*BH-"B`J(&1O(&YO="!R
M97!L86-E(&5N=&ET:71E<PT*("HO#0ID969I;F4H(EA-3%]55$E,7T5.5$E4
M24537TY/3D4B+"`P*3L-"@T*+RHJ#0H@*B!R97!L86-E(&%L;"!834P@96YT
M:71I=&5S#0H@*B!4:&ES('-E='1I;F<@=VEL;"!R97!L86-E(#PL(#XL("(L
M("<@86YD("8-"B`J+PT*9&5F:6YE*")834Q?551)3%]%3E1)5$E%4U]834PB
M+"`Q*3L-"@T*+RHJ#0H@*B!R97!L86-E(&]N;'D@<F5Q=6ER960@6$U,(&5N
M=&ET:71E<PT*("H@5&AI<R!S971T:6YG('=I;&P@<F5P;&%C92`\+"`B(&%N
M9"`F#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)
M4D5$(BP@,BD[#0H-"B\J*@T*("H@<F5P;&%C92!(5$U,(&5N=&ET:71E<PT*
M("H@0&QI;FL@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VAT;6QE;G1I=&EE<PT*
M("HO#0ID969I;F4H(EA-3%]55$E,7T5.5$E424537TA434PB+"`S*3L-"@T*
M+RHJ#0H@*B!#;VQL87!S92!A;&P@96UP='D@=&%G<RX-"B`J+PT*9&5F:6YE
M*")834Q?551)3%]#3TQ,05!315]!3$PB+"`Q*3L-"@T*+RHJ#0H@*B!#;VQL
M87!S92!O;FQY(&5M<'1Y(%A(5$U,('1A9W,@=&AA="!H879E(&YO(&5N9"!T
M86<N#0H@*B\-"F1E9FEN92@B6$U,7U5424Q?0T],3$%04T5?6$A434Q?3TY,
M62(L(#(I.PT*#0HO*BH-"B`J('5T:6QI='D@8VQA<W,@9F]R('=O<FMI;F<@
M=VET:"!834P@9&]C=6UE;G1S#0H@*@T*("H@0&-A=&5G;W)Y(%A-3`T*("H@
M0'!A8VMA9V4@(%A-3%]5=&EL#0H@*B!`=F5R<VEO;B`@,2XQ+C`-"B`J($!A
M=71H;W(@("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^#0H@*B\-
M"F-L87-S(%A-3%]5=&EL('L-"@T*("`@+RHJ#0H@("`@*B!R971U<FX@05!)
M('9E<G-I;VX-"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@
M*B!`<W1A=&EC#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D=F5R<VEO;B!!
M4$D@=F5R<VEO;@T*("`@("HO#0H@("`@9G5N8W1I;VX@87!I5F5R<VEO;B@I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)S$N,2<[#0H@("`@?0T*#0H@("`O
M*BH-"B`@("`J(')E<&QA8V4@6$U,(&5N=&ET:65S#0H@("`@*@T*("`@("H@
M5VET:"!T:&4@;W!T:6]N86P@<V5C;VYD('!A<F%M971E<BP@>6]U(&UA>2!S
M96QE8W0L('=H:6-H#0H@("`@*B!E;G1I=&EE<R!S:&]U;&0@8F4@<F5P;&%C
M960N#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@*B!R97%U:7)E7V]N8V4@
M)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J("\O(')E<&QA8V4@6$U,
M(&5N=&ET97,Z#0H@("`@*B`D<W1R:6YG(#T@6$U,7U5T:6PZ.G)E<&QA8V5%
M;G1I=&EE<R@B5&AI<R!S=')I;F<@8V]N=&%I;G,@/"`F(#XN(BD[#0H@("`@
M*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@
M("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@<W1R:6YG('=H
M97)E(%A-3"!S<&5C:6%L(&-H87)S('-H;W5L9"!B92!R97!L86-E9`T*("`@
M("H@0'!A<F%M("`@(&EN=&5G97(@<V5T=&EN9R!F;W(@96YT:71I97,@:6X@
M871T<FEB=71E('9A;'5E<R`H;VYE(&]F(%A-3%]55$E,7T5.5$E424537UA-
M3"P@6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$+"!834Q?551)3%]%
M3E1)5$E%4U](5$U,*0T*("`@("H@0')E='5R;B`@('-T<FEN9R`@<W1R:6YG
M('=I=&@@<F5P;&%C960@8VAA<G,-"B`@("`J($!S964@("`@("!R979E<G-E
M16YT:71I97,H*0T*("`@("HO#0H@("`@9G5N8W1I;VX@<F5P;&%C945N=&ET
M:65S*"1S=')I;F<L("1R97!L86-E16YT:71I97,@/2!834Q?551)3%]%3E1)
M5$E%4U]834PI#0H@("`@>PT*("`@("`@("!S=VET8V@@*"1R97!L86-E16YT
M:71I97,I('L-"B`@("`@("`@("`@(&-A<V4@6$U,7U5424Q?14Y4251)15-?
M6$U,.@T*("`@("`@("`@("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG+&%R
M<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R8G("`]/B`G)F%M<#LG+`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)SXG("`]/B`G)F=T.R<L#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"<@(#T^("<F;'0[
M)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("<B)R`@/3X@)R9Q=6]T.R<L#0H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`G7"<G(#T^("<F87!O<SLG("DI.PT*("`@("`@
M("`@("`@("`@(&)R96%K.PT*("`@("`@("`@("`@8V%S92!834Q?551)3%]%
M3E1)5$E%4U]834Q?4D5154E2140Z#0H@("`@("`@("`@("`@("`@<F5T=7)N
M('-T<G1R*"1S=')I;F<L87)R87DH#0H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G)B<@(#T^("<F86UP.R<L#0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G/"<@(#T^("<F
M;'0[)RP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("<B)R`@/3X@)R9Q=6]T.R<@*2D[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H@("`@("`@("`@("!C87-E(%A-3%]55$E,7T5.5$E424537TA434PZ
M#0H@("`@("`@("`@("`@("`@<F5T=7)N(&AT;6QE;G1I=&EE<R@D<W1R:6YG
M*3L-"B`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@?0T*("`@("`@
M("!R971U<FX@)'-T<FEN9SL-"B`@("!]#0H-"B`@("\J*@T*("`@("H@<F5V
M97)S92!834P@96YT:71I97,-"B`@("`J#0H@("`@*B!7:71H('1H92!O<'1I
M;VYA;"!S96-O;F0@<&%R86UE=&5R+"!Y;W4@;6%Y('-E;&5C="P@=VAI8V@-
M"B`@("`J(&5N=&ET:65S('-H;W5L9"!B92!R979E<G-E9"X-"B`@("`J#0H@
M("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP
M)SL-"B`@("`J(`T*("`@("H@+R\@<F5V97)S92!834P@96YT:71E<SH-"B`@
M("`J("1S=')I;F<@/2!834Q?571I;#HZ<F5V97)S945N=&ET:65S*")4:&ES
M('-T<FEN9R!C;VYT86EN<R`F;'0[("9A;7`[("9G=#LN(BD[#0H@("`@*B`\
M+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*("`@("H@
M0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@<W1R:6YG('=H97)E
M(%A-3"!S<&5C:6%L(&-H87)S('-H;W5L9"!B92!R97!L86-E9`T*("`@("H@
M0'!A<F%M("`@(&EN=&5G97(@<V5T=&EN9R!F;W(@96YT:71I97,@:6X@871T
M<FEB=71E('9A;'5E<R`H;VYE(&]F(%A-3%]55$E,7T5.5$E424537UA-3"P@
M6$U,7U5424Q?14Y4251)15-?6$U,7U)%455)4D5$+"!834Q?551)3%]%3E1)
M5$E%4U](5$U,*0T*("`@("H@0')E='5R;B`@('-T<FEN9R`@<W1R:6YG('=I
M=&@@<F5P;&%C960@8VAA<G,-"B`@("`J($!S964@("`@("!R97!L86-E16YT
M:71I97,H*0T*("`@("HO#0H@("`@9G5N8W1I;VX@<F5V97)S945N=&ET:65S
M*"1S=')I;F<L("1R97!L86-E16YT:71I97,@/2!834Q?551)3%]%3E1)5$E%
M4U]834PI#0H@("`@>PT*("`@("`@("!S=VET8V@@*"1R97!L86-E16YT:71I
M97,I('L-"B`@("`@("`@("`@(&-A<V4@6$U,7U5424Q?14Y4251)15-?6$U,
M.@T*("`@("`@("`@("`@("`@(')E='5R;B!S=')T<B@D<W1R:6YG+&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R9A;7`[)R`@/3X@)R8G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R9G=#LG("`@/3X@)SXG+`T*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R9L=#LG("`@/3X@)SPG
M+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)R9Q=6]T.R<@/3X@)R(G+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)R9A<&]S.R<@/3X@)UPG)R`I*3L-"B`@("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@(&-A<V4@6$U,7U5424Q?14Y4
M251)15-?6$U,7U)%455)4D5$.@T*("`@("`@("`@("`@("`@(')E='5R;B!S
M=')T<B@D<W1R:6YG+&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)R9A;7`[)R`@/3X@)R8G+`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R9L=#LG("`@/3X@
M)SPG+`T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)R9Q=6]T.R<@/3X@)R(G("DI.PT*("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@8V%S92!834Q?551)3%]%3E1)5$E%4U](5$U,.@T*
M("`@("`@("`@("`@("`@("1A<G(@/2!A<G)A>5]F;&EP*&=E=%]H=&UL7W1R
M86YS;&%T:6]N7W1A8FQE*$A434Q?14Y4251)15,I*3L-"B`@("`@("`@("`@
M("`@("!R971U<FX@<W1R='(H)'-T<FEN9RP@)&%R<BD[#0H@("`@("`@("`@
M("`@("`@8G)E86L[#0H@("`@("`@('T-"B`@("`@("`@<F5T=7)N("1S=')I
M;F<[#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&)U:6QD(&%N('AM;"!D96-L
M87)A=&EO;@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O
M;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!G970@86X@
M6$U,(&1E8VQA<F%T:6]N.@T*("`@("H@)'AM;$1E8VP@/2!834Q?571I;#HZ
M9V5T6$U,1&5C;&%R871I;VXH(C$N,"(L(")55$8M."(L('1R=64I.PT*("`@
M("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1V97)S:6]N
M("`@("!X;6P@=F5R<VEO;@T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&5N
M8V]D:6YG("`@(&-H87)A8W1E<B!E;F-O9&EN9PT*("`@("H@0'!A<F%M("`@
M(&)O;VQE86X@)'-T86YD06QO;F4@(&1O8W5M96YT(&ES('-T86YD86QO;F4@
M*&]R(&YO="D-"B`@("`J($!R971U<FX@("!S=')I;F<@("1D96-L('AM;"!D
M96-L87)A=&EO;@T*("`@("H@0'5S97,@("`@(%A-3%]5=&EL.CIA='1R:6)U
M=&5S5&]3=')I;F<H*2!T;R!S97)I86QI>F4@=&AE(&%T=')I8G5T97,@;V8@
M=&AE(%A-3"!D96-L87)A=&EO;@T*("`@("HO#0H@("`@9G5N8W1I;VX@9V5T
M6$U,1&5C;&%R871I;VXH)'9E<G-I;VX@/2`B,2XP(BP@)&5N8V]D:6YG(#T@
M;G5L;"P@)'-T86YD86QO;F4@/2!N=6QL*0T*("`@('L-"B`@("`@("`@)&%T
M=')I8G5T97,@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`B=F5R<VEO;B(@/3X@)'9E<G-I;VXL#0H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PT*("`@("`@("`O+R!A9&0@96YC;V1I;F<-"B`@("`@("`@
M:68@*"1E;F-O9&EN9R`A/3T@;G5L;"D@>PT*("`@("`@("`@("`@)&%T=')I
M8G5T97-;(F5N8V]D:6YG(ET@/2`D96YC;V1I;F<[#0H@("`@("`@('T-"B`@
M("`@("`@+R\@861D('-T86YD86QO;F4L(&EF('-P96-I9FEE9`T*("`@("`@
M("!I9B`H)'-T86YD86QO;F4@(3T](&YU;&PI('L-"B`@("`@("`@("`@("1A
M='1R:6)U=&5S6R)S=&%N9&%L;VYE(ET@/2`D<W1A;F1A;&]N92`_(")Y97,B
M(#H@(FYO(CL-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@<F5T=7)N
M('-P<FEN=&8H(CP_>&UL)7,_/B(L(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3
M=')I;F<H)&%T=')I8G5T97,L(&9A;'-E*2D[#0H@("`@?0T*#0H@("`O*BH-
M"B`@("`J(&)U:6QD(&$@9&]C=6UE;G0@='EP92!D96-L87)A=&EO;@T*("`@
M("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I
M;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!G970@82!D;V-T>7!E(&1E8VQA
M<F%T:6]N.@T*("`@("H@)'AM;$1E8VP@/2!834Q?571I;#HZ9V5T1&]C5'EP
M941E8VQA<F%T:6]N*")R;V]T5&%G(BPB;7E$;V-4>7!E+F1T9"(I.PT*("`@
M("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@
M("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1R;V]T("`@
M("`@("`@;F%M92!O9B!T:&4@<F]O="!T86<-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("1U<FD@("`@("`@("`@=7)I(&]F('1H92!D;V-T>7!E(&1E9FEN
M:71I;VX@*&]R(&%R<F%Y('=I=&@@=7)I(&%N9"!P=6)L:6,@:60I#0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("`D:6YT97)N86Q$=&0@(&EN=&5R;F%L(&1T
M9"!E;G1R:65S("`@#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D9&5C;"`@
M("`@("`@(&1O8W1Y<&4@9&5C;&%R871I;VX-"B`@("`J($!S:6YC92`@("`P
M+C(-"B`@("`J+PT*("`@(&9U;F-T:6]N(&=E=$1O8U1Y<&5$96-L87)A=&EO
M;B@D<F]O="P@)'5R:2`](&YU;&PL("1I;G1E<FYA;$1T9"`](&YU;&PI#0H@
M("`@>PT*("`@("`@("!I9B`H:7-?87)R87DH)'5R:2DI('L-"B`@("`@("`@
M("`@("1R968@/2!S<')I;G1F*"`G(%!50DQ)0R`B)7,B("(E<R(G+"`D=7)I
M6R)I9")=+"`D=7)I6R)U<FDB72`I.PT*("`@("`@("!](&5L<V5I9B`H(65M
M<'1Y*"1U<FDI*2![#0H@("`@("`@("`@("`D<F5F(#T@<W!R:6YT9B@@)R!3
M65-414T@(B5S(B<L("1U<FD@*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`@("1R968@/2`B(CL-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("AE
M;7!T>2@D:6YT97)N86Q$=&0I*2![#0H@("`@("`@("`@("!R971U<FX@<W!R
M:6YT9B@B/"%$3T-465!%("5S)7,^(BP@)')O;W0L("1R968I.PT*("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@<F5T=7)N('-P<FEN=&8H(CPA1$]#
M5%E012`E<R5S(%M<;B5S7&Y=/B(L("1R;V]T+"`D<F5F+"`D:6YT97)N86Q$
M=&0I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`O*BH-"B`@("`J(&-R96%T
M92!S=')I;F<@<F5P<F5S96YT871I;VX@;V8@86X@871T<FEB=71E(&QI<W0-
M"B`@("`J#0H@("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,
M+U5T:6PN<&AP)SL-"B`@("`J(`T*("`@("H@+R\@8G5I;&0@86X@871T<FEB
M=71E('-T<FEN9PT*("`@("H@)&%T="`](&%R<F%Y*`T*("`@("H@("`@("`@
M("`@("`@(")F;V\B("`@/3X@(")B87(B+`T*("`@("H@("`@("`@("`@("`@
M(")A<F=H(B`@/3X@(")T;VUA=&\B#0H@("`@*B`@("`@("`@("`@("D[#0H@
M("`@*@T*("`@("H@)&%T=$QI<W0@/2!834Q?571I;#HZ871T<FEB=71E<U1O
M4W1R:6YG*"1A='0I.R`@("`-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@("`@
M*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`<&%R
M86T@("`@87)R87D@("`@("`@("`D871T<FEB=71E<R`@("`@("`@871T<FEB
M=71E(&%R<F%Y#0H@("`@*B!`<&%R86T@("`@8F]O;&5A;GQA<G)A>2`D<V]R
M="`@("`@("`@("`@("`@<V]R="!A='1R:6)U=&4@;&ES="!A;'!H86)E=&EC
M86QL>2P@;6%Y(&%L<V\@8F4@86X@87-S;V,@87)R87D@8V]N=&%I;FEN9R!T
M:&4@:V5Y<R`G<V]R="<L("=M=6QT:6QI;F4G+"`G:6YD96YT)RP@)VQI;F5B
M<F5A:R<@86YD("=E;G1I=&EE<R<-"B`@("`J($!P87)A;2`@("!B;V]L96%N
M("`@("`@("1M=6QT:6QI;F4@("`@("`@("!U<V4@;&EN96)R96%K<RP@:68@
M;6]R92!T:&%N(&]N92!A='1R:6)U=&4@:7,@9VEV96X-"B`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("`@("1I;F1E;G0@("`@("`@("`@("!S=')I;F<@
M=7-E9"!F;W(@:6YD96YT871I;VX@;V8@;75L=&EL:6YE(&%T=')I8G5T97,-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("`@("1L:6YE8G)E86L@("`@
M("`@("!S=')I;F<@=7-E9"!F;W(@;&EN96)R96%K<R!O9B!M=6QT:6QI;F4@
M871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@(&EN=&5G97(@("`@("`@)&5N
M=&ET:65S("`@("`@("`@('-E='1I;F<@9F]R(&5N=&ET:65S(&EN(&%T=')I
M8G5T92!V86QU97,@*&]N92!O9B!834Q?551)3%]%3E1)5$E%4U].3TY%+"!8
M34Q?551)3%]%3E1)5$E%4U]834PL(%A-3%]55$E,7T5.5$E424537UA-3%]2
M15%525)%1"P@6$U,7U5424Q?14Y4251)15-?2%1-3"D-"B`@("`J($!R971U
M<FX@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@("`@("!S=')I;F<@
M<F5P<F5S96YT871I;VX@;V8@=&AE(&%T=')I8G5T97,-"B`@("`J($!U<V5S
M("`@("!834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"D@=&\@<F5P;&%C92!8
M34P@96YT:71I97,@:6X@871T<FEB=71E('9A;'5E<PT*("`@("H@0'1O9&\@
M("`@(&%L;&]W('-O<G0@86QS;R!T;R!B92!A;B!O<'1I;VYS(&%R<F%Y#0H@
M("`@*B\-"B`@("!F=6YC=&EO;B!A='1R:6)U=&5S5&]3=')I;F<H)&%T=')I
M8G5T97,L("1S;W)T(#T@=')U92P@)&UU;'1I;&EN92`](&9A;'-E+"`D:6YD
M96YT(#T@)R`@("`G+"`D;&EN96)R96%K(#T@(EQN(BP@)&5N=&ET:65S(#T@
M6$U,7U5424Q?14Y4251)15-?6$U,*0T*("`@('L-"B`@("`@("`@+RHJ#0H@
M("`@("`@("`J('-E8V]N9"!P87)A;65T97(@;6%Y(&)E(&%N(&%R<F%Y#0H@
M("`@("`@("`J+PT*("`@("`@("!I9B`H:7-?87)R87DH)'-O<G0I*2![#0H@
M("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)VUU;'1I;&EN92==*2D@>PT*
M("`@("`@("`@("`@("`@("1M=6QT:6QI;F4@/2`D<V]R=%LG;75L=&EL:6YE
M)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O
M<G1;)VEN9&5N="==*2D@>PT*("`@("`@("`@("`@("`@("1I;F1E;G0@/2`D
M<V]R=%LG:6YD96YT)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I
M9B`H:7-S970H)'-O<G1;)VQI;F5B<F5A:R==*2D@>PT*("`@("`@("`@("`@
M("`@("1M=6QT:6QI;F4@/2`D<V]R=%LG;&EN96)R96%K)UT[#0H@("`@("`@
M("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S970H)'-O<G1;)V5N=&ET:65S
M)UTI*2![#0H@("`@("`@("`@("`@("`@)&5N=&ET:65S(#T@)'-O<G1;)V5N
M=&ET:65S)UT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'-O<G1;)W-O<G0G72DI('L-"B`@("`@("`@("`@("`@("`D<V]R="`]
M("1S;W)T6R=S;W)T)UT[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@
M("`@("`@("`@("1S;W)T(#T@=')U93L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*("`@("`@("`D<W1R:6YG(#T@)R<[#0H@("`@("`@(&EF("AI<U]A
M<G)A>2@D871T<FEB=71E<RD@)B8@(65M<'1Y*"1A='1R:6)U=&5S*2D@>PT*
M("`@("`@("`@("`@:68@*"1S;W)T*2![#0H@("`@("`@("`@("`@("`@:W-O
M<G0H)&%T=')I8G5T97,I.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@
M:68H("$D;75L=&EL:6YE('Q\(&-O=6YT*"1A='1R:6)U=&5S*2`]/2`Q*2![
M#0H@("`@("`@("`@("`@("`@9F]R96%C:"`H)&%T=')I8G5T97,@87,@)&ME
M>2`]/B`D=F%L=64I('L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1E;G1I
M=&EE<R`A/2!834Q?551)3%]%3E1)5$E%4U].3TY%*2![#0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&5N=&ET:65S(#T]/2!834Q?551)3%]#1$%4
M05]314-424].*2![#0H@("`@("`@("`@("`@("`@("`@("`@("`))&5N=&ET
M:65S(#T@6$U,7U5424Q?14Y4251)15-?6$U,.PT*("`@("`@("`@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@
M6$U,7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=F%L=64L("1E;G1I=&EE<RD[
M#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@
M)'-T<FEN9R`N/2`G("<N)&ME>2XG/2(G+B1V86QU92XG(B<[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@
M("`@("`D9FER<W0@/2!T<G5E.PT*("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*"1A='1R:6)U=&5S(&%S("1K97D@/3X@)'9A;'5E*2![#0H@("`@("`@("`@
M("`@("`@("`@(&EF("@D96YT:71I97,@(3T@6$U,7U5424Q?14Y4251)15-?
M3D].12D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E(#T@6$U,
M7U5T:6PZ.G)E<&QA8V5%;G1I=&EE<R@D=F%L=64L("1E;G1I=&EE<RD[#0H@
M("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@("`@("`@:68@
M*"1F:7)S="D@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`N
M/2`B("(N)&ME>2XG/2(G+B1V86QU92XG(B<[#0H@("`@("`@("`@("`@("`@
M("`@("`@("`D9FER<W0@/2!F86QS93L-"B`@("`@("`@("`@("`@("`@("`@
M?2!E;'-E('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@+CT@
M)&QI;F5B<F5A:RXD:6YD96YT+B1K97DN)STB)RXD=F%L=64N)R(G.PT*("`@
M("`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@
M("`@("`@?0T*("`@("`@("!]#0H@("`@("`@(')E='5R;B`D<W1R:6YG.PT*
M("`@('T-"@T*("`@+RHJ#0H@("`@*B!#;VQL87!S97,@96UP='D@=&%G<RX-
M"B`@("`J#0H@("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC
M#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D>&UL("!834P-"B`@("`J($!P
M87)A;2`@("!I;G1E9V5R("1M;V1E(%=H971H97(@=&\@8V]L;&%P<V4@86QL
M(&5M<'1Y('1A9W,@*%A-3%]55$E,7T-/3$Q!4%-%7T%,3"D@;W(@;VYL>2!8
M2%1-3"`H6$U,7U5424Q?0T],3$%04T5?6$A434Q?3TY,62D@;VYE<RX-"B`@
M("`J($!R971U<FX@("!S=')I;F<@("1X;6P@(%A-3`T*("`@("HO#0H@("`@
M9G5N8W1I;VX@8V]L;&%P<V5%;7!T>51A9W,H)'AM;"P@)&UO9&4@/2!834Q?
M551)3%]#3TQ,05!315]!3$PI('L-"B`@("`@("`@:68@*"1M;V1E(#T](%A-
M3%]55$E,7T-/3$Q!4%-%7UA(5$U,7T].3%DI('L-"B`@("`@("`@("`@(')E
M='5R;B!P<F5G7W)E<&QA8V4H#0H@("`@("`@("`@("`@("<O/"AA<F5A?&)A
M<V5\8G)\8V]L?&AR?&EM9WQI;G!U='QL:6YK?&UE=&%\<&%R86TI*%M>/ETJ
M*3X\7"]<7#$^+W,G+`T*("`@("`@("`@("`@("`G/%Q<,5Q<,B`O/B<L#0H@
M("`@("`@("`@("`@("1X;6P-"B`@("`@("`@("`@("D[#0H@("`@("`@('T@
M96QS92![#0H@("`@("`@("`@("!R971U<FX@<')E9U]R97!L86-E*`T*("`@
M("`@("`@("`@("`G+SPH7'<K*2A;7CY=*BD^/%PO7%PQ/B]S)RP-"B`@("`@
M("`@("`@("`@)SQ<7#%<7#(@+SXG+`T*("`@("`@("`@("`@("`D>&UL#0H@
M("`@("`@("`@("`I.PT*("`@("`@("!]#0H@("`@?0T*#0H@("`O*BH-"B`@
M("`J(&-R96%T92!A('1A9PT*("`@("H-"B`@("`J(%1H:7,@;65T:&]D('=I
M;&P@8V%L;"!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"DL('=H:6-H
M#0H@("`@*B!I<R!M;W)E(&9L97AI8FQE+@T*("`@("H-"B`@("`J(#QC;V1E
M/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@
M#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('1A9SH-"B`@("`J("1T86<@/2!8
M34Q?571I;#HZ8W)E871E5&%G*")M>4YS.FUY5&%G(BP@87)R87DH(F9O;R(@
M/3X@(F)A<B(I+"`B5&AI<R!I<R!I;G-I9&4@=&AE('1A9R(L(")H='1P.B\O
M=W=W+G<S8RYO<F<O;7E.<R,B*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("`D<6YA;64@("`@("`@("`@("`@<75A;&EF:65D
M('1A9VYA;64@*&EN8VQU9&EN9R!N86UE<W!A8V4I#0H@("`@*B!`<&%R86T@
M("`@87)R87D@("`D871T<FEB=71E<R`@("`@("`@87)R87D@8V]N=&%I;F<@
M871T<FEB=71E<PT*("`@("H@0'!A<F%M("`@(&UI>&5D("`@)&-O;G1E;G0-
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("1N86UE<W!A8V55<FD@("`@("!5
M4DD@;V8@=&AE(&YA;65S<&%C90T*("`@("H@0'!A<F%M("`@(&EN=&5G97(@
M)')E<&QA8V5%;G1I=&EE<R`@('=H971H97(@=&\@<F5P;&%C92!834P@<W!E
M8VEA;"!C:&%R<R!I;B!C;VYT96YT+"!E;6)E9&0@:70@:6X@82!#1&%T82!S
M96-T:6]N(&]R(&YO;F4@;V8@8F]T:`T*("`@("H@0'!A<F%M("`@(&)O;VQE
M86X@)&UU;'1I;&EN92`@("`@("`@('=H971H97(@=&\@8W)E871E(&$@;75L
M=&EL:6YE('1A9R!W:&5R92!E86-H(&%T=')I8G5T92!G971S('=R:71T96X@
M=&\@82!S:6YG;&4@;&EN90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&EN
M9&5N="`@("`@("`@("`@('-T<FEN9R!U<V5D('1O(&EN9&5N="!A='1R:6)U
M=&5S("A?875T;R!I;F1E;G1S(&%T=')I8G5T97,@<V\@=&AE>2!S=&%R="!A
M="!T:&4@<V%M92!C;VQU;6XI#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D
M;&EN96)R96%K("`@("`@("`@<W1R:6YG('5S960@9F]R(&QI;F5B<F5A:W,-
M"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!8
M34P@=&%G#0H@("`@*B!`<V5E("`@("`@6$U,7U5T:6PZ.F-R96%T951A9T9R
M;VU!<G)A>2@I#0H@("`@*B!`=7-E<R`@("`@6$U,7U5T:6PZ.F-R96%T951A
M9T9R;VU!<G)A>2@I('1O(&-R96%T92!T:&4@=&%G#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!C<F5A=&5486<H)'%N86UE+"`D871T<FEB=71E<R`](&%R<F%Y
M*"DL("1C;VYT96YT(#T@;G5L;"P@)&YA;65S<&%C955R:2`](&YU;&PL("1R
M97!L86-E16YT:71I97,@/2!834Q?551)3%]215!,04-%7T5.5$E42453+"`D
M;75L=&EL:6YE(#T@9F%L<V4L("1I;F1E;G0@/2`B7V%U=&\B+"`D;&EN96)R
M96%K(#T@(EQN(BD-"B`@("![#0H@("`@("`@("1T86<@/2!A<G)A>2@-"B`@
M("`@("`@("`@("`@("`@("`@(")Q;F%M92(@("`@("`]/B`D<6YA;64L#0H@
M("`@("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@/3X@)&%T=')I8G5T
M97,-"B`@("`@("`@("`@("`@("`@("`@*3L-"@T*("`@("`@("`O+R!A9&0@
M=&%G(&-O;G1E;G0-"B`@("`@("`@:68@*"1C;VYT96YT("$]/2!N=6QL*2![
M#0H@("`@("`@("`@("`D=&%G6R)C;VYT96YT(ET@/2`D8V]N=&5N=#L-"B`@
M("`@("`@?0T*("`@("`@("`-"B`@("`@("`@+R\@861D(&YA;65S<&%C92!5
M<FD-"B`@("`@("`@:68@*"1N86UE<W!A8V55<FD@(3T](&YU;&PI('L-"B`@
M("`@("`@("`@("1T86=;(FYA;65S<&%C955R:2)=(#T@)&YA;65S<&%C955R
M:3L-"B`@("`@("`@?0T*#0H@("`@("`@(')E='5R;B!834Q?571I;#HZ8W)E
M871E5&%G1G)O;4%R<F%Y*"1T86<L("1R97!L86-E16YT:71I97,L("1M=6QT
M:6QI;F4L("1I;F1E;G0L("1L:6YE8G)E86LI.PT*("`@('T-"@T*("`@+RHJ
M#0H@("`@*B!C<F5A=&4@82!T86<@9G)O;2!A;B!A<G)A>0T*("`@("H@=&AI
M<R!M971H;V0@87=A:71S(&%N(&%R<F%Y(&EN('1H92!F;VQL;W=I;F<@9F]R
M;6%T#0H@("`@*B`\<')E/@T*("`@("H@87)R87DH#0H@("`@*B`@(G%N86UE
M(B`@("`@("`@/3X@)'%N86UE("`@("`@("`@+R\@<75A;&EF:65D(&YA;64@
M;V8@=&AE('1A9PT*("`@("H@(")N86UE<W!A8V4B("`@(#T^("1N86UE<W!A
M8V4@("`@("\O(&YA;65S<&%C92!P<F5F:7@@*&]P=&EO;F%L+"!I9B!Q;F%M
M92!I<R!S<&5C:69I960@;W(@;F\@;F%M97-P86-E*0T*("`@("H@(")L;V-A
M;'!A<G0B("`@(#T^("1L;V-A;'!A<G0L("`@("\O(&QO8V%L('!A<G0@;V8@
M=&AE('1A9VYA;64@*&]P=&EO;F%L+"!I9B!Q;F%M92!I<R!S<&5C:69I960I
M#0H@("`@*B`@(F%T=')I8G5T97,B("`@/3X@87)R87DH*2P@("`@("`@+R\@
M87)R87D@8V]N=&%I;FEN9R!A;&P@871T<FEB=71E<R`H;W!T:6]N86PI#0H@
M("`@*B`@(F-O;G1E;G0B("`@("`@/3X@)&-O;G1E;G0L("`@("`@+R\@=&%G
M(&-O;G1E;G0@*&]P=&EO;F%L*0T*("`@("H@(")N86UE<W!A8V55<FDB(#T^
M("1N86UE<W!A8V55<FD@("\O(&YA;65S<&%C955R:2!F;W(@=&AE(&=I=F5N
M(&YA;65S<&%C92`H;W!T:6]N86PI#0H@("`@*B`@("D-"B`@("`J(#PO<')E
M/@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=8
M34PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`D=&%G(#T@87)R87DH#0H@
M("`@*B`@("`@("`@("`@(G%N86UE(B`@("`@("`@/3X@(F9O;SIB87(B+`T*
M("`@("H@("`@("`@("`@(")N86UE<W!A8V55<FDB(#T^(")H='1P.B\O9F]O
M+F-O;2(L#0H@("`@*B`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R
M87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U:70F=F5G971A
M8FQE(B`I+`T*("`@("H@("`@("`@("`@(")C;VYT96YT(B`@("`@(#T^("))
M)VT@:6YS:61E('1H92!T86<B+`T*("`@("H@("`@("`@("`@("`I.PT*("`@
M("H@+R\@8W)E871I;F<@82!T86<@=VET:"!Q=6%L:69I960@;F%M92!A;F0@
M;F%M97-P86-E57)I#0H@("`@*B`D<W1R:6YG(#T@6$U,7U5T:6PZ.F-R96%T
M951A9T9R;VU!<G)A>2@D=&%G*3L-"B`@("`J(#PO8V]D93X-"B`@("`J#0H@
M("`@*B!`86-C97-S("`@<'5B;&EC#0H@("`@*B!`<W1A=&EC#0H@("`@*B!`
M<&%R86T@("`@87)R87D@("`D=&%G("`@("`@("`@("`@("`@=&%G(&1E9FEN
M:71I;VX-"B`@("`J($!P87)A;2`@("!I;G1E9V5R("1R97!L86-E16YT:71I
M97,@("!W:&5T:&5R('1O(')E<&QA8V4@6$U,('-P96-I86P@8VAA<G,@:6X@
M8V]N=&5N="P@96UB961D(&ET(&EN(&$@0T1A=&$@<V5C=&EO;B!O<B!N;VYE
M(&]F(&)O=&@-"B`@("`J($!P87)A;2`@("!B;V]L96%N("1M=6QT:6QI;F4@
M("`@("`@("!W:&5T:&5R('1O(&-R96%T92!A(&UU;'1I;&EN92!T86<@=VAE
M<F4@96%C:"!A='1R:6)U=&4@9V5T<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI
M;F4-"B`@("`J($!P87)A;2`@("!S=')I;F<@("1I;F1E;G0@("`@("`@("`@
M("!S=')I;F<@=7-E9"!T;R!I;F1E;G0@871T<FEB=71E<R`H7V%U=&\@:6YD
M96YT<R!A='1R:6)U=&5S('-O('1H97D@<W1A<G0@870@=&AE('-A;64@8V]L
M=6UN*0T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@
M("`@('-T<FEN9R!U<V5D(&9O<B!L:6YE8G)E86MS#0H@("`@*B!`<F5T=7)N
M("`@<W1R:6YG("`D<W1R:6YG("`@("`@("`@("`@6$U,('1A9PT*("`@("H@
M0'-E92`@("`@(%A-3%]5=&EL.CIC<F5A=&5486<H*0T*("`@("H@0'5S97,@
M("`@(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3=')I;F<H*2!T;R!S97)I86QI
M>F4@=&AE(&%T=')I8G5T97,@;V8@=&AE('1A9PT*("`@("H@0'5S97,@("`@
M(%A-3%]5=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H*2!T;R!G970@;&]C86P@
M<&%R="!A;F0@;F%M97-P86-E(&]F(&$@<75A;&EF:65D(&YA;64-"B`@("`J
M+PT*("`@(&9U;F-T:6]N(&-R96%T951A9T9R;VU!<G)A>2@D=&%G+"`D<F5P
M;&%C945N=&ET:65S(#T@6$U,7U5424Q?4D503$%#15]%3E1)5$E%4RP@)&UU
M;'1I;&EN92`](&9A;'-E+"`D:6YD96YT(#T@(E]A=71O(BP@)&QI;F5B<F5A
M:R`](")<;B(@*0T*("`@('L-"B`@("`@("`@:68@*&ES<V5T*"1T86=;)V-O
M;G1E;G0G72D@)B8@(6ES7W-C86QA<B@D=&%G6R=C;VYT96YT)UTI*2![#0H@
M("`@("`@("`@("!R971U<FX@6$U,7U5T:6PZ.G)A:7-E17)R;W(H("=3=7!P
M;&EE9"!N;VXM<V-A;&%R('9A;'5E(&%S('1A9R!C;VYT96YT)RP@6$U,7U54
M24Q?15)23U)?3D].7U-#04Q!4E]#3TY414Y4("D[#0H@("`@("`@('T-"@T*
M("`@("`@("!I9B`H(6ES<V5T*"1T86=;)W%N86UE)UTI("8F("%I<W-E="@D
M=&%G6R=L;V-A;%!A<G0G72DI('L-"B`@("`@("`@("`@(')E='5R;B!834Q?
M571I;#HZ<F%I<V5%<G)O<B@@)UEO=2!M=7-T(&5I=&AE<B!S=7!P;'D@82!Q
M=6%L:69I960@;F%M92`H<6YA;64I(&]R(&QO8V%L('1A9R!N86UE("AL;V-A
M;%!A<G0I+B<L(%A-3%]55$E,7T524D]27TY/7U1!1U].04U%("D[#0H@("`@
M("`@('T-"@T*("`@("`@("`O+R!I9B!N;R!A='1R:6)U=&5S(&AA=B!B965N
M('-E="P@=7-E(&5M<'1Y(&%T=')I8G5T97,-"B`@("`@("`@:68@*"%I<W-E
M="@D=&%G6R)A='1R:6)U=&5S(ETI('Q\("%I<U]A<G)A>2@D=&%G6R)A='1R
M:6)U=&5S(ETI*2![#0H@("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(ET@
M/2!A<G)A>2@I.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`O+R!Q
M=6%L:69I960@;F%M92!I<R!N;W0@9VEV96X-"B`@("`@("`@:68@*"%I<W-E
M="@D=&%G6R)Q;F%M92)=*2D@>PT*("`@("`@("`@("`@+R\@8VAE8VL@9F]R
M(&YA;65S<&%C90T*("`@("`@("`@("`@:68@*&ES<V5T*"1T86=;(FYA;65S
M<&%C92)=*2`F)B`A96UP='DH)'1A9ULB;F%M97-P86-E(ETI*2![#0H@("`@
M("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]("1T86=;(FYA;65S<&%C92)=
M+B(Z(BXD=&%G6R)L;V-A;%!A<G0B73L-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@)'1A9ULB<6YA;64B72`]("1T86=;(FQO8V%L
M4&%R=")=.PT*("`@("`@("`@("`@?0T*("`@("`@("`O+R!N86UE<W!A8V4@
M55))(&ES('-E="P@8G5T(&YO(&YA;65S<&%C90T*("`@("`@("!](&5L<V5I
M9B`H:7-S970H)'1A9ULB;F%M97-P86-E57)I(ETI("8F("%I<W-E="@D=&%G
M6R)N86UE<W!A8V4B72DI('L-"B`@("`@("`@("`@("1P87)T<R`](%A-3%]5
M=&EL.CIS<&QI=%%U86QI9FEE9$YA;64H)'1A9ULB<6YA;64B72D[#0H@("`@
M("`@("`@("`D=&%G6R)L;V-A;%!A<G0B72`]("1P87)T<ULB;&]C86Q087)T
M(ET[#0H@("`@("`@("`@("!I9B`H:7-S970H)'!A<G1S6R)N86UE<W!A8V4B
M72DI('L-"B`@("`@("`@("`@("`@("`D=&%G6R)N86UE<W!A8V4B72`]("1P
M87)T<ULB;F%M97-P86-E(ET[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-
M"@T*("`@("`@("!I9B`H:7-S970H)'1A9ULB;F%M97-P86-E57)I(ETI("8F
M("%E;7!T>2@D=&%G6R)N86UE<W!A8V55<FDB72DI('L-"B`@("`@("`@("`@
M("\O(&ES(&$@;F%M97-P86-E(&=I=F5N#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'1A9ULB;F%M97-P86-E(ETI("8F("%E;7!T>2@D=&%G6R)N86UE<W!A
M8V4B72DI('L-"B`@("`@("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(EU;
M(GAM;&YS.B(N)'1A9ULB;F%M97-P86-E(EU=(#T@)'1A9ULB;F%M97-P86-E
M57)I(ET[#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@
M("\O(&1E9FEN92!T:&ES(%5R:2!A<R!T:&4@9&5F875L="!N86UE<W!A8V4-
M"B`@("`@("`@("`@("`@("`D=&%G6R)A='1R:6)U=&5S(EU;(GAM;&YS(ET@
M/2`D=&%G6R)N86UE<W!A8V55<FDB73L-"B`@("`@("`@("`@('T-"B`@("`@
M("`@?0T*#0H@("`@("`@("\O(&-H96-K(&9O<B!M=6QT:6QI;F4@871T<FEB
M=71E<PT*("`@("`@("!I9B`H)&UU;'1I;&EN92`]/3T@=')U92D@>PT*("`@
M("`@("`@("`@:68@*"1I;F1E;G0@/3T](")?875T;R(I('L-"B`@("`@("`@
M("`@("`@("`D:6YD96YT(#T@<W1R7W)E<&5A="@B("(L("AS=')L96XH)'1A
M9ULB<6YA;64B72DK,BDI.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H@
M("`@("`@(`T*("`@("`@("`O+R!C<F5A=&4@871T<FEB=71E(&QI<W0-"B`@
M("`@("`@)&%T=$QI<W0@("`@/2`@(%A-3%]5=&EL.CIA='1R:6)U=&5S5&]3
M=')I;F<H)'1A9ULG871T<FEB=71E<R==+"!T<G5E+"`D;75L=&EL:6YE+"`D
M:6YD96YT+"`D;&EN96)R96%K+"`D<F5P;&%C945N=&ET:65S("D[#0H@("`@
M("`@(&EF("@A:7-S970H)'1A9ULG8V]N=&5N="==*2!\?"`H<W1R:6YG*21T
M86=;)V-O;G1E;G0G72`]/2`G)RD@>PT*("`@("`@("`@("`@)'1A9R`@("`]
M("`@<W!R:6YT9B@G/"5S)7,@+SXG+"`D=&%G6R=Q;F%M92==+"`D871T3&ES
M="D[#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("!S=VET8V@@*"1R
M97!L86-E16YT:71I97,I('L-"B`@("`@("`@("`@("`@("!C87-E(%A-3%]5
M5$E,7T5.5$E424537TY/3D4Z#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@("`@(&-A<V4@6$U,7U5424Q?0T1!5$%?4T5#5$E/
M3CH-"B`@("`@("`@("`@("`@("`@("`@)'1A9ULG8V]N=&5N="==(#T@6$U,
M7U5T:6PZ.F-R96%T94-$871A4V5C=&EO;B@D=&%G6R=C;VYT96YT)UTI.PT*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL-"B`@("`@("`@("`@("`@("!D
M969A=6QT.@T*("`@("`@("`@("`@("`@("`@("`D=&%G6R=C;VYT96YT)UT@
M/2!834Q?571I;#HZ<F5P;&%C945N=&ET:65S*"1T86=;)V-O;G1E;G0G72P@
M)')E<&QA8V5%;G1I=&EE<RD[#0H@("`@("`@("`@("`@("`@("`@(&)R96%K
M.PT*("`@("`@("`@("`@?0T*("`@("`@("`@("`@)'1A9R`@("`]("`@<W!R
M:6YT9B@G/"5S)7,^)7,\+R5S/B<L("1T86=;)W%N86UE)UTL("1A='1,:7-T
M+"`D=&%G6R=C;VYT96YT)UTL("1T86=;)W%N86UE)UT@*3L-"B`@("`@("`@
M?2`@("`@("`@#0H@("`@("`@(')E='5R;B`@)'1A9SL-"B`@("!]#0H-"B`@
M("\J*@T*("`@("H@8W)E871E(&$@<W1A<G0@96QE;65N=`T*("`@("H-"B`@
M("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER95]O;F-E("=834PO571I;"YP:'`G
M.PT*("`@("H@#0H@("`@*B`O+R!C<F5A=&4@86X@6$U,('-T87)T(&5L96UE
M;G0Z#0H@("`@*B`D=&%G(#T@6$U,7U5T:6PZ.F-R96%T95-T87)T16QE;65N
M="@B;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B(#T^(")B87(B*2`L(FAT='`Z
M+R]W=W<N=S-C+F]R9R]M>4YS(R(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("1Q;F%M92`@("`@("`@("`@("!Q=6%L:69I
M960@=&%G;F%M92`H:6YC;'5D:6YG(&YA;65S<&%C92D-"B`@("`J($!P87)A
M;2`@("!A<G)A>2`@("1A='1R:6)U=&5S("`@("`@("!A<G)A>2!C;VYT86EN
M9R!A='1R:6)U=&5S#0H@("`@*B!`<&%R86T@("`@<W1R:6YG("`D;F%M97-P
M86-E57)I("`@("`@55))(&]F('1H92!N86UE<W!A8V4-"B`@("`J($!P87)A
M;2`@("!B;V]L96%N("1M=6QT:6QI;F4@("`@("`@("!W:&5T:&5R('1O(&-R
M96%T92!A(&UU;'1I;&EN92!T86<@=VAE<F4@96%C:"!A='1R:6)U=&4@9V5T
M<R!W<FET=&5N('1O(&$@<VEN9VQE(&QI;F4-"B`@("`J($!P87)A;2`@("!S
M=')I;F<@("1I;F1E;G0@("`@("`@("`@("!S=')I;F<@=7-E9"!T;R!I;F1E
M;G0@871T<FEB=71E<R`H7V%U=&\@:6YD96YT<R!A='1R:6)U=&5S('-O('1H
M97D@<W1A<G0@870@=&AE('-A;64@8V]L=6UN*0T*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@)&QI;F5B<F5A:R`@("`@("`@('-T<FEN9R!U<V5D(&9O<B!L
M:6YE8G)E86MS#0H@("`@*B!`<F5T=7)N("`@<W1R:6YG("`D<W1R:6YG("`@
M("`@("`@("`@6$U,('-T87)T(&5L96UE;G0-"B`@("`J($!S964@("`@("!8
M34Q?571I;#HZ8W)E871E16YD16QE;65N="@I+"!834Q?571I;#HZ8W)E871E
M5&%G*"D-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T95-T87)T16QE;65N
M="@D<6YA;64L("1A='1R:6)U=&5S(#T@87)R87DH*2P@)&YA;65S<&%C955R
M:2`](&YU;&PL("1M=6QT:6QI;F4@/2!F86QS92P@)&EN9&5N="`]("=?875T
M;R<L("1L:6YE8G)E86L@/2`B7&XB*0T*("`@('L-"B`@("`@("`@+R\@:68@
M;F\@871T<FEB=71E<R!H878@8F5E;B!S970L('5S92!E;7!T>2!A='1R:6)U
M=&5S#0H@("`@("`@(&EF("@A:7-S970H)&%T=')I8G5T97,I('Q\("%I<U]A
M<G)A>2@D871T<FEB=71E<RDI('L-"B`@("`@("`@("`@("1A='1R:6)U=&5S
M(#T@87)R87DH*3L-"B`@("`@("`@?0T*("`@("`@("`-"B`@("`@("`@:68@
M*"1N86UE<W!A8V55<FD@(3T@;G5L;"D@>PT*("`@("`@("`@("`@)'!A<G1S
M(#T@6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@D<6YA;64I.PT*("`@
M("`@("!]#0H-"B`@("`@("`@+R\@8VAE8VL@9F]R(&UU;'1I;&EN92!A='1R
M:6)U=&5S#0H@("`@("`@(&EF("@D;75L=&EL:6YE(#T]/2!T<G5E*2![#0H@
M("`@("`@("`@("!I9B`H)&EN9&5N="`]/3T@(E]A=71O(BD@>PT*("`@("`@
M("`@("`@("`@("1I;F1E;G0@/2!S=')?<F5P96%T*"(@(BP@*'-T<FQE;B@D
M<6YA;64I*S(I*3L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@
M("`@(&EF("@D;F%M97-P86-E57)I("$](&YU;&PI('L-"B`@("`@("`@("`@
M("\O(&ES(&$@;F%M97-P86-E(&=I=F5N#0H@("`@("`@("`@("!I9B`H:7-S
M970H)'!A<G1S6R)N86UE<W!A8V4B72D@)B8@(65M<'1Y*"1P87)T<ULB;F%M
M97-P86-E(ETI*2![#0H@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;(GAM
M;&YS.B(N)'!A<G1S6R)N86UE<W!A8V4B75T@/2`D;F%M97-P86-E57)I.PT*
M("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@("`O+R!D969I
M;F4@=&AI<R!5<FD@87,@=&AE(&1E9F%U;'0@;F%M97-P86-E#0H@("`@("`@
M("`@("`@("`@)&%T=')I8G5T97-;(GAM;&YS(ET@/2`D;F%M97-P86-E57)I
M.PT*("`@("`@("`@("`@?0T*("`@("`@("!]#0H-"B`@("`@("`@+R\@8W)E
M871E(&%T=')I8G5T92!L:7-T#0H@("`@("`@("1A='1,:7-T("`@(#T@("!8
M34Q?571I;#HZ871T<FEB=71E<U1O4W1R:6YG*"1A='1R:6)U=&5S+"!T<G5E
M+"`D;75L=&EL:6YE+"`D:6YD96YT+"`D;&EN96)R96%K*3L-"B`@("`@("`@
M)&5L96UE;G0@("`@/2`@('-P<FEN=&8H(CPE<R5S/B(L("1Q;F%M92P@)&%T
M=$QI<W0I.PT*("`@("`@("!R971U<FX@("1E;&5M96YT.PT*("`@('T-"@T*
M("`@+RHJ#0H@("`@*B!C<F5A=&4@86X@96YD(&5L96UE;G0-"B`@("`J#0H@
M("`@*B`\8V]D93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP
M)SL-"B`@("`J(`T*("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R="!E;&5M
M96YT.@T*("`@("H@)'1A9R`](%A-3%]5=&EL.CIC<F5A=&5%;F1%;&5M96YT
M*")M>4YS.FUY5&%G(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PT*("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M
M("`@('-T<FEN9R`@)'%N86UE("`@("`@("`@("`@('%U86QI9FEE9"!T86=N
M86UE("AI;F-L=61I;F<@;F%M97-P86-E*0T*("`@("H@0')E='5R;B`@('-T
M<FEN9R`@)'-T<FEN9R`@("`@("`@("`@(%A-3"!E;F0@96QE;65N=`T*("`@
M("H@0'-E92`@("`@(%A-3%]5=&EL.CIC<F5A=&53=&%R=$5L96UE;G0H*2P@
M6$U,7U5T:6PZ.F-R96%T951A9R@I#0H@("`@*B\-"B`@("!F=6YC=&EO;B!C
M<F5A=&5%;F1%;&5M96YT*"1Q;F%M92D-"B`@("![#0H@("`@("`@("1E;&5M
M96YT("`@(#T@("!S<')I;G1F*"(\+R5S/B(L("1Q;F%M92D[#0H@("`@("`@
M(')E='5R;B`@)&5L96UE;G0[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@("`@
M*B!C<F5A=&4@86X@6$U,(&-O;6UE;G0-"B`@("`J#0H@("`@*B`\8V]D93X-
M"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J(`T*
M("`@("H@+R\@8W)E871E(&%N(%A-3"!S=&%R="!E;&5M96YT.@T*("`@("H@
M)'1A9R`](%A-3%]5=&EL.CIC<F5A=&5#;VUM96YT*"))(&%M(&$@8V]M;65N
M="(I.PT*("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@("!S=')I;F<@
M("1C;VYT96YT("`@("`@("`@("!C;VYT96YT(&]F('1H92!C;VUM96YT#0H@
M("`@*B!`<F5T=7)N("`@<W1R:6YG("`D8V]M;65N="`@("`@("`@("`@6$U,
M(&-O;6UE;G0-"B`@("`J+PT*("`@(&9U;F-T:6]N(&-R96%T94-O;6UE;G0H
M)&-O;G1E;G0I#0H@("`@>PT*("`@("`@("`D8V]M;65N="`@("`]("`@<W!R
M:6YT9B@B/"$M+2`E<R`M+3XB+"`D8V]N=&5N="D[#0H@("`@("`@(')E='5R
M;B`@)&-O;6UE;G0[#0H@("`@?0T*("`@(`T*("`@+RHJ#0H@("`@*B!C<F5A
M=&4@82!#1&%T82!S96-T:6]N#0H@("`@*@T*("`@("H@/&-O9&4^#0H@("`@
M*B!R97%U:7)E7V]N8V4@)UA-3"]5=&EL+G!H<"<[#0H@("`@*B`-"B`@("`J
M("\O(&-R96%T92!A($-$871A('-E8W1I;VX-"B`@("`J("1T86<@/2!834Q?
M571I;#HZ8W)E871E0T1A=&%396-T:6]N*"))(&%M(&-O;G1E;G0N(BD[#0H@
M("`@*B`\+V-O9&4^#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI8PT*
M("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@)&1A=&$@
M("`@("`@("`@("`@(&1A=&$@;V8@=&AE($-$871A('-E8W1I;VX-"B`@("`J
M($!R971U<FX@("!S=')I;F<@("1S=')I;F<@("`@("`@("`@("!#1&%T82!S
M96-T:6]N('=I=&@@8V]N=&5N=`T*("`@("HO#0H@("`@9G5N8W1I;VX@8W)E
M871E0T1A=&%396-T:6]N*"1D871A*0T*("`@('L-"B`@("`@("`@<F5T=7)N
M("!S<')I;G1F*"(\(5M#1$%405LE<UU=/B(L("1D871A*3L-"B`@("!]#0H-
M"B`@("\J*@T*("`@("H@<W!L:70@<75A;&EF:65D(&YA;64@86YD(')E='5R
M;B!N86UE<W!A8V4@86YD(&QO8V%L('!A<G0-"B`@("`J#0H@("`@*B`\8V]D
M93X-"B`@("`J(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"B`@("`J
M(`T*("`@("H@+R\@<W!L:70@<75A;&EF:65D('1A9PT*("`@("H@)'!A<G1S
M(#T@6$U,7U5T:6PZ.G-P;&ET475A;&EF:65D3F%M92@B>'-L=#IS='EL97-H
M965T(BD[#0H@("`@*B`\+V-O9&4^#0H@("`@*B!T:&4@<F5T=7)N960@87)R
M87D@=VEL;"!C;VYT86EN('1W;R!E;&5M96YT<SH-"B`@("`J(#QP<F4^#0H@
M("`@*B!A<G)A>2@-"B`@("`J("`@("`@(")N86UE<W!A8V4B(#T^(")X<VQT
M(BP-"B`@("`J("`@("`@(")L;V-A;%!A<G0B(#T^(")S='EL97-H965T(@T*
M("`@("H@("`@("`I.PT*("`@("H@/"]P<F4^#0H@("`@*@T*("`@("H@0&%C
M8V5S<R!P=6)L:6,-"B`@("`J($!S=&%T:6,-"B`@("`J($!P87)A;2`@<W1R
M:6YG("`@("1Q;F%M92`@("`@('%U86QI9FEE9"!T86<@;F%M90T*("`@("H@
M0'!A<F%M("!S=')I;F<@("`@)&1E9F%U;'1.<R`@9&5F875L="!N86UE<W!A
M8V4@*&]P=&EO;F%L*0T*("`@("H@0')E='5R;B!A<G)A>2`@("`@)'!A<G1S
M("`@("`@87)R87D@8V]N=&%I;FEN9R!N86UE<W!A8V4@86YD(&QO8V%L('!A
M<G0-"B`@("`J+PT*("`@(&9U;F-T:6]N('-P;&ET475A;&EF:65D3F%M92@D
M<6YA;64L("1D969A=6QT3G,@/2!N=6QL*0T*("`@('L-"B`@("`@("`@:68@
M*'-T<G-T<B@D<6YA;64L("<Z)RDI('L-"B`@("`@("`@("`@("1T;7`@/2!E
M>'!L;V1E*"(Z(BP@)'%N86UE*3L-"B`@("`@("`@("`@(')E='5R;B!A<G)A
M>2@-"B`@("`@("`@("`@("`@("`@("`@("`@("`@(FYA;65S<&%C92(@/3X@
M)'1M<%LP72P-"B`@("`@("`@("`@("`@("`@("`@("`@("`@(FQO8V%L4&%R
M="(@/3X@)'1M<%LQ70T*("`@("`@("`@("`@("`@("`@("`@("`@*3L-"B`@
M("`@("`@?0T*("`@("`@("!R971U<FX@87)R87DH#0H@("`@("`@("`@("`@
M("`@("`@("`@(FYA;65S<&%C92(@/3X@)&1E9F%U;'1.<RP-"B`@("`@("`@
M("`@("`@("`@("`@("`B;&]C86Q087)T(B`]/B`D<6YA;64-"B`@("`@("`@
M("`@("`@("`@("`@*3L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@8VAE8VLL
M('=H971H97(@<W1R:6YG(&ES('9A;&ED(%A-3"!N86UE#0H@("`@*@T*("`@
M("H@/'`^6$U,(&YA;65S(&%R92!U<V5D(&9O<B!T86=N86UE+"!A='1R:6)U
M=&4@;F%M97,@86YD('9A<FEO=7,-"B`@("`J(&]T:&5R+"!L97-S97(@:VYO
M=VX@96YT:71I97,N/"]P/@T*("`@("H@/'`^06X@6$U,(&YA;64@;6%Y(&]N
M;'D@8V]N<VES="!O9B!A;'!H86YU;65R:6,@8VAA<F%C=&5R<RP-"B`@("`J
M(&1A<VAE<RP@=6YD97-C;W)E<R!A;F0@<&5R:6]D<RP@86YD(&AA<R!T;R!S
M=&%R="!W:71H(&$@;&5T=&5R#0H@("`@*B!O<B!A;B!U;F1E<G-C;W)E+@T*
M("`@("H@/"]P/@T*("`@("H-"B`@("`J(#QC;V1E/@T*("`@("H@<F5Q=6ER
M95]O;F-E("=834PO571I;"YP:'`G.PT*("`@("H@#0H@("`@*B`O+R!V97)I
M9GD@=&%G(&YA;64-"B`@("`J("1R97-U;'0@/2!834Q?571I;#HZ:7-686QI
M9$YA;64H(FEN=F%L:61486<_(BD[#0H@("`@*B!I9B`H6$U,7U5T:6PZ.FES
M17)R;W(H)')E<W5L="DI('L-"B`@("`J("`@('!R:6YT("));G9A;&ED(%A-
M3"!N86UE.B`B("X@)')E<W5L="T^9V5T365S<V%G92@I.PT*("`@("H@?0T*
M("`@("H@/"]C;V1E/@T*("`@("H-"B`@("`J($!A8V-E<W,@('!U8FQI8PT*
M("`@("H@0'-T871I8PT*("`@("H@0'!A<F%M("`@<W1R:6YG("`D<W1R:6YG
M('-T<FEN9R!T:&%T('-H;W5L9"!B92!C:&5C:V5D#0H@("`@*B!`<F5T=7)N
M("!M:7AE9"`@("1V86QI9"`@=')U92P@:68@<W1R:6YG(&ES(&$@=F%L:60@
M6$U,(&YA;64L(%!%05(@97)R;W(@;W1H97)W:7-E#0H@("`@*B!`=&]D;R`@
M("!S=7!P;W)T(&9O<B!O=&AE<B!C:&%R<V5T<PT*("`@("HO#0H@("`@9G5N
M8W1I;VX@:7-686QI9$YA;64H)'-T<FEN9RD-"B`@("![#0H@("`@("`@("\O
M(&-H96-K(&9O<B!I;G9A;&ED(&-H87)S#0H@("`@("`@(&EF("@A<')E9U]M
M871C:"@B+UY;6SIA;&YU;3I=7UPM+ETD+R(L("1S=')I;F=[,'TI*2![#0H@
M("`@("`@("`@("!R971U<FX@6$U,7U5T:6PZ.G)A:7-E17)R;W(H(")834P@
M;F%M97,@;6%Y(&]N;'D@<W1A<G0@=VET:"!L971T97(@;W(@=6YD97)S8V]R
M92(L(%A-3%]55$E,7T524D]27TE.5D%,241?4U1!4E0@*3L-"B`@("`@("`@
M?0T*("`@("`@("`-"B`@("`@("`@+R\@8VAE8VL@9F]R(&EN=F%L:60@8VAA
M<G,-"B`@("`@("`@:68@*"%P<F5G7VUA=&-H*"(O7BA;82UZ02U:7UTH6V$M
M>D$M6C`M.5]<+5PN72HI/SHI/UMA+7I!+5I?72A;82UZ02U:,"TY7UPM7"Y=
M*RD_)"\B+"`D<W1R:6YG*2D@>PT*("`@("`@("`@("`@<F5T=7)N(%A-3%]5
M=&EL.CIR86ES945R<F]R*"`B6$U,(&YA;65S(&UA>2!O;FQY(&-O;G1A:6X@
M86QP:&%N=6UE<FEC(&-H87)S+"!P97)I;V0L(&AY<&AE;BP@8V]L;VX@86YD
M('5N9&5R<V-O<F5S(BP@6$U,7U5424Q?15)23U)?24Y604Q)1%]#2$%24R`I
M.PT*("`@("`@("`@?0T*("`@("`@("`O+R!834P@;F%M92!I<R!V86QI9`T*
M("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H-"B`@("\J*@T*("`@("H@
M<F5P;&%C96UE;G0@9F]R(%A-3%]5=&EL.CIR86ES945R<F]R#0H@("`@*@T*
M("`@("H@079O:61S('1H92!N96-E<W-I='D@=&\@86QW87ES(')E<75I<F4-
M"B`@("`J(%!%05(N<&AP#0H@("`@*@T*("`@("H@0&%C8V5S<R`@('!U8FQI
M8PT*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&5R<F]R(&UE<W-A9V4-
M"B`@("`J($!P87)A;2`@("!I;G1E9V5R("`@("!E<G)O<B!C;V1E#0H@("`@
M*B!`<F5T=7)N("`@;V)J96-T(%!%05)?17)R;W(-"B`@("`J+PT*("`@(&9U
M;F-T:6]N(')A:7-E17)R;W(H)&US9RP@)&-O9&4I#0H@("`@>PT*("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL-"B`@("`@("`@<F5T=7)N(%!%
M05(Z.G)A:7-E17)R;W(H)&US9RP@)&-O9&4I.PT*("`@('T-"GT-"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+UA-3"]5;G-E<FEA;&EZ97(N<&AP
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-C<T,S$@,3`U
M,34T,S0Q,S,@,#(R,S(Q`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_4$A0"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO*BH*("H@
M6$U,7U5N<V5R:6%L:7IE<@H@*@H@*B!087)S97,@86YY(%A-3"!D;V-U;65N
M="!I;G1O(%!(4"!D871A('-T<G5C='5R97,N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J($Q)0T5.4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@
M<W5B:F5C="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@
M=&AA="!I<R!A=F%I;&%B;&4@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@=&AE(&9O;&QO=VEN9R!54DDZ"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9@H@*B!T:&4@4$A0($QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=E8BP@<&QE87-E"B`J('-E;F0@82!N;W1E
M('1O(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y
M(&EM;65D:6%T96QY+@H@*@H@*B!`8V%T96=O<GD@("!834P*("H@0'!A8VMA
M9V4@("`@6$U,7U-E<FEA;&EZ97(*("H@0&%U=&AO<B`@("`@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P
M,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S+C`*("H@0'9E
M<G-I;VX@("`@0U93.B`D260Z(%5N<V5R:6%L:7IE<BYP:'`L=B`Q+C,Y(#(P
M,#4O,#DO,C@@,3$Z,3DZ-38@<V-H<W0@17AP("0*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]397)I86QI>F5R"B`J
M($!S964@("`@("`@(%A-3%]5;G-E<FEA;&EZ97(*("HO"@HO*BH*("H@=7-E
M<R!014%2(&5R<F]R(&UA;F%G96UT"B`J+PIR97%U:7)E7V]N8V4@)U!%05(N
M<&AP)SL*"B\J*@H@*B!U<V5S(%A-3%]087)S97(@=&\@=6YS97)I86QI>F4@
M9&]C=6UE;G0*("HO"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E<BYP:'`G.PH*
M+RHJ"B`J(&]P=&EO;CH@0V]N=F5R="!N97-T960@=&%G<R!T;R!A<G)A>2!O
M<B!O8FIE8W0*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%R<F%Y"B`J
M("T@;V)J96-T"B`J("T@87-S;V-I871I=F4@87)R87D@=&\@9&5F:6YE('1H
M:7,@;W!T:6]N('!E<B!T86<@;F%M90H@*B\*9&5F:6YE*"=834Q?54Y315))
M04Q)6D527T]05$E/3E]#3TU03$585%E012<L("=C;VUP;&5X5'EP92<I.PH*
M+RHJ"B`J(&]P=&EO;CH@3F%M92!O9B!T:&4@871T<FEB=71E('1H870@<W1O
M<F5S('1H92!O<FEG:6YA;"!K97D*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@
M*B`M(&%N>2!S=')I;F<*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7TM%62<L("=K97E!='1R:6)U=&4G*3L*"B\J*@H@
M*B!O<'1I;VXZ($YA;64@;V8@=&AE(&%T=')I8G5T92!T:&%T('-T;W)E<R!T
M:&4@='EP90H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T<FEN
M9PH@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)5
M5$5?5%E012<L("=T>7!E071T<FEB=71E)RD["@HO*BH*("H@;W!T:6]N.B!.
M86UE(&]F('1H92!A='1R:6)U=&4@=&AA="!S=&]R97,@=&AE(&-L87-S(&YA
M;64*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<*("HO
M"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7T-,
M05-3)RP@)V-L87-S071T<FEB=71E)RD["@HO*BH*("H@;W!T:6]N.B!7:&5T
M:&5R('1O('5S92!T:&4@=&%G(&YA;64@87,@82!C;&%S<R!N86UE"B`J"B`J
M(%!O<W-I8FQE('9A;'5E<SH*("H@+2!T<G5E(&]R(&9A;'-E"B`J+PID969I
M;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]!4U]#3$%34TY!344G
M+"`G=&%G07-#;&%S<R<I.PH*+RHJ"B`J(&]P=&EO;CH@3F%M92!O9B!T:&4@
M9&5F875L="!C;&%S<PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY
M('-T<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]$
M149!54Q47T-,05-3)RP@)V1E9F%U;'1#;&%S<R<I.PH*+RHJ"B`J(&]P=&EO
M;CH@5VAE=&AE<B!T;R!P87)S92!A='1R:6)U=&5S"B`J"B`J(%!O<W-I8FQE
M('9A;'5E<SH*("H@+2!T<G5E(&]R(&9A;'-E"B`J+PID969I;F4H)UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4$%24T4G+"`G<&%R<V5!
M='1R:6)U=&5S)RD["@HO*BH*("H@;W!T:6]N.B!+97D@;V8@=&AE(&%R<F%Y
M('1O('-T;W)E(&%T=')I8G5T97,@*&EF(&%N>2D*("H*("H@4&]S<VEB;&4@
M=F%L=65S.@H@*B`M(&%N>2!S=')I;F<*("H@+2!F86QS92`H9&ES86)L960I
M"B`J+PID969I;F4H)UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E54
M15-?05)205E+15DG+"`G871T<FEB=71E<T%R<F%Y)RD["@HO*BH*("H@;W!T
M:6]N.B!S=')I;F<@=&\@<')E<&5N9"!A='1R:6)U=&4@;F%M92`H:68@86YY
M*0H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T<FEN9PH@*B`M
M(&9A;'-E("AD:7-A8FQE9"D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?05144DE"551%4U]04D5014Y$)RP@)W!R97!E;F1!='1R:6)U
M=&5S)RD["@HO*BH*("H@;W!T:6]N.B!K97D@=&\@<W1O<F4@=&AE(&-O;G1E
M;G0L(&EF(%A-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4$%2
M4T4@:7,@=7-E9`H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T
M<FEN9PH@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]#3TY4
M14Y47TM%62<L("=C;VYT96YT3F%M92<I.PH*+RHJ"B`J(&]P=&EO;CH@;6%P
M('1A9R!N86UE<PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@87-S;V-I
M871I=F4@87)R87D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?5$%'7TU!4"<L("=T86=-87`G*3L*"B\J*@H@*B!O<'1I;VXZ(&QI<W0@
M;V8@=&%G<R!T:&%T('=I;&P@86QW87ES(&)E(&5N=6UE<F%T960*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M(&EN9&5X960@87)R87D*("HO"F1E9FEN
M92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1D]20T5?14Y532<L("=F;W)C
M945N=6TG*3L*"B\J*@H@*B!O<'1I;VXZ($5N8V]D:6YG(&]F('1H92!834P@
M9&]C=6UE;G0*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(%541BTX"B`J
M("T@25-/+3@X-3DM,0H@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]0
M5$E/3E]%3D-/1$E.1U]33U520T4G+"`G96YC;V1I;F<G*3L*"B\J*@H@*B!O
M<'1I;VXZ($1E<VER960@=&%R9V5T(&5N8V]D:6YG(&]F('1H92!D871A"B`J
M"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!55$8M.`H@*B`M($E33RTX.#4Y
M+3$*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)
M3D=?5$%21T54)RP@)W1A<F=E=$5N8V]D:6YG)RD["@HO*BH*("H@;W!T:6]N
M.B!#86QL8F%C:R!T:&%T('=I;&P@8F4@87!P;&EE9"!T;R!T97AT=6%L(&1A
M=&$*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!V86QI9"!02%`@
M8V%L;&)A8VL*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M1$5#3T1%7T953D,G+"`G9&5C;V1E1G5N8W1I;VXG*3L*"B\J*@H@*B!O<'1I
M;VXZ('=H971H97(@=&\@<F5T=7)N('1H92!R97-U;'0@;V8@=&AE('5N<V5R
M:6%L:7IA=&EO;B!F<F]M('5N<V5R:6%L:7IE*"D*("H*("H@4&]S<VEB;&4@
M=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E
M9FEN92@G6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"<L
M("=R971U<FY297-U;'0G*3L*"B\J*@H@*B!O<'1I;VXZ('-E="!T:&4@=VAI
M=&5S<&%C92!B96AA=FEO=7(*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M
M(%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]+1450"B`J("T@6$U,7U5.
M4T5224%,25I%4E]72$E415-004-%7U1224T*("H@+2!834Q?54Y315))04Q)
M6D527U=(251%4U!!0T5?3D]234%,25I%"B`J+PID969I;F4H)UA-3%]53E-%
M4DE!3$E:15)?3U!424].7U=(251%4U!!0T4G+"`G=VAI=&5S<&%C92<I.PH*
M+RHJ"B`J($ME97`@86QL('=H:71E<W!A8V4*("HO"F1E9FEN92@G6$U,7U5.
M4T5224%,25I%4E]72$E415-004-%7TM%15`G+"`G:V5E<"<I.PH*+RHJ"B`J
M(')E;6]V92!W:&ET97-P86-E(&9R;VT@<W1A<G0@86YD(&5N9"!O9B!T:&4@
M9&%T80H@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527U=(251%4U!!0T5?
M5%))32<L("=T<FEM)RD["@HO*BH*("H@;F]R;6%L:7IE('=H:71E<W!A8V4*
M("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]72$E415-004-%7TY/4DU!
M3$E:12<L("=N;W)M86QI>F4G*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@
M=&\@;W9V97)R:61E(&%L;"!O<'1I;VYS('1H870@:&%V92!B965N('-E="!B
M969O<F4*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F
M86QS92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?3U9%4E))1$5?3U!424].4R<L("=O=F5R<FED94]P=&EO;G,G*3L*
M"B\J*@H@*B!O<'1I;VXZ(&QI<W0@;V8@=&%G<RP@=&AA="!W:6QL(&YO="!B
M92!U<V5D(&%S(&ME>7,*("HO"F1E9FEN92@G6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?24=.3U)%7TM%65,G+"`G:6=N;W)E2V5Y<R<I.PH*+RHJ"B`J(&]P
M=&EO;CH@=VAE=&AE<B!T;R!U<V4@='EP92!G=65S<VEN9R!F;W(@<V-A;&%R
M('9A;'5E<PH@*B\*9&5F:6YE*"=834Q?54Y315))04Q)6D527T]05$E/3E]'
M54534U]465!%4R<L("=G=65S<U1Y<&5S)RD["@HO*BH*("H@97)R;W(@8V]D
M92!F;W(@;F\@<V5R:6%L:7IA=&EO;B!D;VYE"B`J+PID969I;F4H)UA-3%]5
M3E-%4DE!3$E:15)?15)23U)?3D]?54Y315))04Q)6D%424].)RP@,34Q*3L*
M"B\J*@H@*B!834Q?56YS97)I86QI>F5R"B`J"B`J(&-L87-S('1O('5N<V5R
M:6%L:7IE(%A-3"!D;V-U;65N=',@=&AA="!H879E(&)E96X@8W)E871E9"!W
M:71H"B`J(%A-3%]397)I86QI>F5R+B!4;R!U;G-E<FEA;&EZ92!A;B!834P@
M9&]C=6UE;G0@>6]U(&AA=F4@=&\@861D"B`J('1Y<&4@:&EN=',@=&\@=&AE
M(%A-3%]397)I86QI>F5R(&]P=&EO;G,N"B`J"B`J($EF(&YO('1Y<&4@:&EN
M=',@87)E(&%V86EL86)L92P@6$U,7U5N<V5R:6%L:7IE<B!W:6QL(&=U97-S
M(&AO=PH@*B!T:&4@=&%G<R!S:&]U;&0@8F4@=')E871E9"P@=&AA="!M96%N
M<R!C;VUP;&5X('-T<G5C='5R97,@=VEL;"!B90H@*B!A<G)A>7,@86YD('1A
M9W,@=VET:"!O;FQY($-$871A(&EN('1H96T@=VEL;"!B92!S=')I;F=S+@H@
M*@H@*B`\8V]D93X*("H@<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R
M+G!H<"<["B`J"B`J("\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE
M(&%M<&5R<V%N9"!I;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R"B`J("1U
M;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H*3L*("H*("H@
M)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"D["B`J"B`J("1D871A
M(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@*B`\
M8V]D93X*("H*("H*("H@0&-A=&5G;W)Y("`@6$U,"B`J($!P86-K86=E("`@
M(%A-3%]397)I86QI>F5R"B`J($!A=71H;W(@("`@(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@,3DY-RTR,#`U(%1H
M92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP"B`J($!V97)S:6]N
M("`@(%)E;&5A<V4Z(#`N,3@N,`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A
M<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U-E<FEA;&EZ97(*("H@0'-E92`@("`@
M("`@6$U,7U-E<FEA;&EZ97(*("HO"F-L87-S(%A-3%]5;G-E<FEA;&EZ97(@
M97AT96YD<R!014%2"GL*("`@+RHJ"B`@("`J(&QI<W0@;V8@86QL(&%V86EL
M86)L92!O<'1I;VYS"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?:VYO=VY/<'1I;VYS
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%7TM%62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?5%E012P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D52
M7T]05$E/3E]!5%1224)55$5?0TQ!4U,L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7T%37T-,
M05-33D%-12P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M54Y315))04Q)6D527T]05$E/3E]$149!54Q47T-,05-3+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415-?4$%24T4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]!4E)!
M64M%62P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y3
M15))04Q)6D527T]05$E/3E]!5%1224)55$537U!215!%3D0L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?0T].5$5.5%]+15DL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4"P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/
M3E]&3U)#15]%3E5-+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]53E-%4DE!3$E:15)?3U!424].7T5.0T]$24Y'7U-/55)#12P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D52
M7T]05$E/3E]%3D-/1$E.1U]405)'150L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5#3T1%7T95
M3D,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]72$E4
M15-004-%+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7TE'3D]215]+15E3+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T=5
M15-37U194$53"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["B`@
M("\J*@H@("`@*B!D969A=6QT(&]P=&EO;G,@9F]R('1H92!S97)I86QI>F%T
M:6]N"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@
M(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?9&5F875L=$]P=&EO;G,@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:15)?
M3U!424].7T-/35!,15A465!%("`@("`@("`@/3X@)V%R<F%Y)RP@("`@("`@
M("`@("`@("`@+R\@8V]M<&QE>"!T>7!E<R!W:6QL(&)E(&-O;G9E<G1E9"!T
M;R!A<G)A>7,L(&EF(&YO('1Y<&4@:&EN="!I<R!G:79E;@H@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"
M551%7TM%62`@("`@("`]/B`G7V]R:6=I;F%L2V5Y)RP@("`@("`@("`O+R!G
M970@87)R87D@:V5Y+W!R;W!E<G1Y(&YA;64@9G)O;2!T:&ES(&%T=')I8G5T
M90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7U194$4@("`@("`]/B`G7W1Y<&4G+"`@("`@("`@
M("`@("`@("`O+R!G970@='EP92!F<F]M('1H:7,@871T<FEB=71E"B`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!
M5%1224)55$5?0TQ!4U,@("`@(#T^("=?8VQA<W,G+"`@("`@("`@("`@("`@
M("\O(&=E="!C;&%S<R!F<F]M('1H:7,@871T<FEB=71E("AI9B!N;W0@9VEV
M96XL('5S92!T86<@;F%M92D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-
M3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]!4U]#3$%34TY!344@("`@/3X@
M=')U92P@("`@("`@("`@("`@("`@("`@+R\@=7-E('1H92!T86=N86UE(&%S
M('1H92!C;&%S<VYA;64*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7T1%1D%53%1?0TQ!4U,@("`@("`@/3X@)W-T
M9$-L87-S)RP@("`@("`@("`@("`@+R\@;F%M92!O9B!T:&4@8VQA<W,@=&AA
M="!I<R!U<V5D('1O(&-R96%T92!O8FIE8W1S"B`@("`@("`@("`@("`@("`@
M("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$537U!!
M4E-%("`@(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@("\O('!A<G-E('1H
M92!A='1R:6)U=&5S(&]F('1H92!T86<@:6YT;R!A;B!A<G)A>0H@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0514
M4DE"551%4U]!4E)!64M%62`]/B!F86QS92P@("`@("`@("`@("`@("`@("`O
M+R!P87)S92!T:&5M(&EN=&\@<W!E<F%T92!A<G)A>2`H<W!E8VEF>2!N86UE
M(&]F(&%R<F%Y(&AE<F4I"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M54Y315))04Q)6D527T]05$E/3E]!5%1224)55$537U!215!%3D0@(#T^("<G
M+"`@("`@("`@("`@("`@("`@("`@("\O('!R97!E;F0@871T<FEB=71E(&YA
M;65S('=I=&@@=&AI<R!S=')I;F<*("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]53E-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T59("`@("`@("`@
M/3X@)U]C;VYT96YT)RP@("`@("`@("`@("`@+R\@<'5T(&-D871A(&9O=6YD
M(&EN(&$@=&%G('1H870@:&%S(&)E96X@8V]N=F5R=&5D('1O(&$@8V]M<&QE
M>"!T>7!E(&EN('1H:7,@:V5Y"B`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?54Y315))04Q)6D527T]05$E/3E]404=?34%0("`@("`@("`@("`@(#T^
M(&%R<F%Y*"DL("`@("`@("`@("`@("`@("\O('5S92!T:&ES('1O(&UA<"!T
M86=N86UE<PH@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1D]20T5?14Y532`@("`@("`@("`]/B!A<G)A>2@I+"`@
M("`@("`@("`@("`@("`O+R!T:&5S92!T86=S('=I;&P@86QW87ES(&)E(&%N
M(&EN9&5X960@87)R87D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7T5.0T]$24Y'7U-/55)#12`@("`@/3X@;G5L
M;"P@("`@("`@("`@("`@("`@("`@+R\@<W!E8VEF>2!T:&4@96YC;V1I;F<@
M8VAA<F%C=&5R(&]F('1H92!D;V-U;65N="!T;R!P87)S90H@("`@("`@("`@
M("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)
M3D=?5$%21T54("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("`O+R!S
M<&5C:69Y('1H92!T87)G970@96YC;V1I;F<*("`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]53E-%4DE!3$E:15)?3U!424].7T1%0T]$15]&54Y#("`@
M("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`@+R\@9G5N8W1I;VX@
M=7-E9"!T;R!D96-O9&4@9&%T80H@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"`@("`@("`]
M/B!F86QS92P@("`@("`@("`@("`@("`@("`O+R!U;G-E<FEA;&EZ92@I(')E
M='5R;G,@=&AE(')E<W5L="!O9B!T:&4@=6YS97)I86QI>F%T:6]N(&EN<W1E
M860@;V8@=')U90H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?5TA)5$534$%#12`@("`@("`@("`]/B!834Q?54Y3
M15))04Q)6D527U=(251%4U!!0T5?5%))32P@+R\@<F5M;W9E('=H:71E<W!A
M8V4@87)O=6YD(&1A=&$*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]5
M3E-%4DE!3$E:15)?3U!424].7TE'3D]215]+15E3("`@("`@("`@/3X@87)R
M87DH*2P@("`@("`@("`@("`@("`@+R\@3&ES="!O9B!T86=S('1H870@=VEL
M;"!A=71O;6%T:6-A;&QY(&)E(&%D9&5D('1O('1H92!P87)E;G0L(&EN<W1E
M860@;V8@861D:6YG(&$@;F5W(&ME>0H@("`@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1U5%4U-?5%E015,@("`@("`@
M("`]/B!F86QS92`@("`@("`@("`@("`@("`@("`O+R!7:&5T:&5R('1O('5S
M92!T>7!E(&=U97-S:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@
M("`O*BH*("`@("H@8W5R<F5N="!O<'1I;VYS(&9O<B!T:&4@<V5R:6%L:7IA
M=&EO;@H@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`=F%R("`@
M(&%R<F%Y"B`@("`J+PH@("`@=F%R("1O<'1I;VYS(#T@87)R87DH*3L*"B`@
M("\J*@H@("`@*B!U;G-E<FEA;&EZ960@9&%T80H@("`@*@H@("`@*B!`86-C
M97-S('!R:79A=&4*("`@("H@0'9A<B`@("!S=')I;F<*("`@("HO"B`@("!V
M87(@)%]U;G-E<FEA;&EZ961$871A(#T@;G5L;#L*"B`@("\J*@H@("`@*B!N
M86UE(&]F('1H92!R;V]T('1A9PH@("`@*@H@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("H@0'9A<B`@("!S=')I;F<*("`@("HO"B`@("!V87(@)%]R;V]T
M(#T@;G5L;#L*"B`@("\J*@H@("`@*B!S=&%C:R!F;W(@86QL(&1A=&$@=&AA
M="!I<R!F;W5N9`H@("`@*@H@("`@*B!`86-C97-S('!R:79A=&4*("`@("H@
M0'9A<B`@("!A<G)A>0H@("`@*B\*("`@('9A<B`D7V1A=&%3=&%C:R`@/2`@
M(&%R<F%Y*"D["@H@("`O*BH*("`@("H@<W1A8VL@9F]R(&%L;"!V86QU97,@
M=&AA="!A<F4@9V5N97)A=&5D"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T
M90H@("`@*B!`=F%R("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?=F%L4W1A
M8VL@(#T@("!A<G)A>2@I.PH*("`@+RHJ"B`@("`J(&-U<G)E;G0@=&%G(&1E
M<'1H"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`=F%R("`@
M(&EN=`H@("`@*B\*("`@('9A<B`D7V1E<'1H(#T@,#L*"B`@("\J*@H@("`@
M*B!834Q?4&%R<V5R(&EN<W1A;F-E"B`@("`J"B`@("`J($!A8V-E<W,@("!P
M<FEV871E"B`@("`J($!V87(@("`@("!O8FIE8W0@6$U,7U!A<G-E<@H@("`@
M*B\*("`@('9A<B`D7W!A<G-E<B`](&YU;&P["B`@("`*("`@+RHJ"B`@("`J
M(&-O;G-T<G5C=&]R"B`@("`J"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@
M("H@0'!A<F%M("`@(&UI>&5D("`@)&]P=&EO;G,@("`@87)R87D@8V]N=&%I
M;FEN9R!O<'1I;VYS(&9O<B!T:&4@=6YS97)I86QI>F%T:6]N"B`@("`J+PH@
M("`@9G5N8W1I;VX@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<R`](&YU;&PI
M"B`@("!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D@>PH@("`@
M("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?
M9&5F875L=$]P=&EO;G,L("1O<'1I;VYS*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D=&AI<RT^;W!T:6]N<R`]("1T:&ES+3Y?9&5F875L=$]P
M=&EO;G,["B`@("`@("`@?0H@("`@?0H*("`@+RHJ"B`@("`J(')E='5R;B!!
M4$D@=F5R<VEO;@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J
M($!S=&%T:6,*("`@("H@0')E='5R;B`@('-T<FEN9R`@)'9E<G-I;VX@05!)
M('9E<G-I;VX*("`@("HO"B`@("!F=6YC=&EO;B!A<&E697)S:6]N*"D*("`@
M('L*("`@("`@("!R971U<FX@)S`N,3@N,"<["B`@("!]"@H@("`O*BH*("`@
M("H@<F5S970@86QL(&]P=&EO;G,@=&\@9&5F875L="!O<'1I;VYS"B`@("`J
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0'-E92`@("`@('-E=$]P
M=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"DL('-E=$]P=&EO;G,H*0H@("`@
M*B\*("`@(&9U;F-T:6]N(')E<V5T3W!T:6]N<R@I"B`@("!["B`@("`@("`@
M)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1/<'1I;VYS.PH@("`@
M?0H*("`@+RHJ"B`@("`J('-E="!A;B!O<'1I;VX*("`@("H*("`@("H@66]U
M(&-A;B!U<V4@=&AI<R!M971H;V0@:68@>6]U(&1O(&YO="!W86YT('1O('-E
M="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N<W1R=6-T;W(*("`@("H*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@<F5S971/<'1I;VXH
M*2P@6$U,7U5N<V5R:6%L:7IE<B@I+"!S971/<'1I;VYS*"D*("`@("HO"B`@
M("!F=6YC=&EO;B!S971/<'1I;VXH)&YA;64L("1V86QU92D*("`@('L*("`@
M("`@("`D=&AI<RT^;W!T:6]N<ULD;F%M95T@/2`D=F%L=64["B`@("!]"@H@
M("`O*BH*("`@("H@<V5T<R!S979E<F%L(&]P=&EO;G,@870@;VYC90H@("`@
M*@H@("`@*B!9;W4@8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@9&\@;F]T
M('=A;G0@=&\@<V5T(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U8W1O<@H@
M("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!R
M97-E=$]P=&EO;B@I+"!834Q?56YS97)I86QI>F5R*"DL('-E=$]P=&EO;B@I
M"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T3W!T:6]N<R@D;W!T:6]N<RD*("`@
M('L*("`@("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES
M+3YO<'1I;VYS+"`D;W!T:6]N<RD["B`@("!]"@H@("`O*BH*("`@("H@=6YS
M97)I86QI>F4@9&%T80H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@
M("`J($!P87)A;2`@("!M:7AE9"`@("`D9&%T82`@("`@9&%T82!T;R!U;G-E
M<FEA;&EZ92`H<W1R:6YG+"!F:6QE;F%M92!O<B!R97-O=7)C92D*("`@("H@
M0'!A<F%M("`@(&)O;VQE86X@("1I<T9I;&4@("!D871A('-H;W5L9"!B92!T
M<F5A=&5D(&%S(&$@9FEL90H@("`@*B!`<&%R86T@("`@87)R87D@("`@)&]P
M=&EO;G,@(&]P=&EO;G,@=&AA="!W:6QL(&]V97)R:61E('1H92!G;&]B86P@
M;W!T:6]N<R!F;W(@=&AI<R!C86QL"B`@("`J($!R971U<FX@("!B;V]L96%N
M("`D<W5C8V5S<PH@("`@*B\*("`@(&9U;F-T:6]N('5N<V5R:6%L:7IE*"1D
M871A+"`D:7-&:6QE(#T@9F%L<V4L("1O<'1I;VYS(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^7W5N<V5R:6%L:7IE9$1A=&$@/2!N=6QL.PH@("`@
M("`@("1T:&ES+3Y?<F]O="`](&YU;&P["@H@("`@("`@("\O(&EF(&]P=&EO
M;G,@:&%V92!B965N('-P96-I9FEE9"P@=7-E('1H96T@:6YS=&5A9`H@("`@
M("`@("\O(&]F('1H92!P<F5V:6]U<VQY(&1E9FEN960@;VYE<PH@("`@("`@
M(&EF("AI<U]A<G)A>2@D;W!T:6]N<RDI('L*("`@("`@("`@("`@)&]P=&EO
M;G-"86L@/2`D=&AI<RT^;W!T:6]N<SL*("`@("`@("`@("`@:68@*&ES<V5T
M*"1O<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T]615)2241%7T]0
M5$E/3E-=*2`F)B`D;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]/
M5D524DE$15]/4%1)3TY372`]/2!T<G5E*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3Y?9&5F875L=$]P
M=&EO;G,L("1O<'1I;VYS*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1T:&ES+3YO<'1I;VYS(#T@87)R87E?;65R9V4H)'1H:7,M
M/F]P=&EO;G,L("1O<'1I;VYS*3L*("`@("`@("`@("`@?0H@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("1O<'1I;VYS0F%K(#T@;G5L;#L*("`@("`@
M("!]"@H@("`@("`@("1T:&ES+3Y?=F%L4W1A8VL@/2!A<G)A>2@I.PH@("`@
M("`@("1T:&ES+3Y?9&%T85-T86-K(#T@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^7V1E<'1H(#T@,#L*"B`@("`@("`@)'1H:7,M/E]C<F5A=&5087)S97(H
M*3L*("`@("`@("`*("`@("`@("!I9B`H:7-?<W1R:6YG*"1D871A*2D@>PH@
M("`@("`@("`@("!I9B`H)&ES1FEL92D@>PH@("`@("`@("`@("`@("`@)')E
M<W5L="`]("1T:&ES+3Y?<&%R<V5R+3YS971);G!U=$9I;&4H)&1A=&$I.PH@
M("`@("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)')E<W5L="DI('L*
M("`@("`@("`@("`@("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W!A
M<G-E<BT^<&%R<V4H*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1R97-U;'0@/2`D=&AI<RT^7W!A<G-E<BT^<&%R<V53=')I;F<H
M)&1A=&$L=')U92D["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("1T:&ES+3Y?<&%R<V5R+3YS971);G!U="@D9&%T82D["B`@
M("`@("`@("`@)')E<W5L="`]("1T:&ES+3Y?<&%R<V5R+3YP87)S92@I.PH@
M("`@("`@('T*"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%
M4DE!3$E:15)?3U!424].7U)%5%523E]215-53%1=(#T]/2!T<G5E*2!["B`@
M("`@("`@"21R971U<FX@/2`D=&AI<RT^7W5N<V5R:6%L:7IE9$1A=&$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)')E='5R;B`]('1R=64["B`@
M("`@("`@?0H*("`@("`@("!I9B`H)&]P=&EO;G-"86L@(3T](&YU;&PI('L*
M("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D;W!T:6]N<T)A:SL*("`@
M("`@("!]"@H@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97-U;'0I*2![
M"B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N("1R971U<FX["B`@("!]"@H@("`O*BH*("`@("H@9V5T('1H
M92!R97-U;'0@;V8@=&AE('-E<FEA;&EZ871I;VX*("`@("H*("`@("H@0&%C
M8V5S<R!P=6)L:6,*("`@("H@0')E='5R;B!S=')I;F<@("1S97)I86QI>F5D
M1&%T80H@("`@*B\*("`@(&9U;F-T:6]N(&=E=%5N<V5R:6%L:7IE9$1A=&$H
M*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W)O;W0@/3T](&YU;&PI('L*
M("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YR86ES945R<F]R*"=.;R!U;G-E
M<FEA;&EZ960@9&%T82!A=F%I;&%B;&4N(%5S92!834Q?56YS97)I86QI>F5R
M.CIU;G-E<FEA;&EZ92@I(&9I<G-T+B<L(%A-3%]53E-%4DE!3$E:15)?15)2
M3U)?3D]?54Y315))04Q)6D%424].*3L*("`@("`@("!]"B`@("`@("`@<F5T
M=7)N("1T:&ES+3Y?=6YS97)I86QI>F5D1&%T83L*("`@('T*"B`@("\J*@H@
M("`@*B!G970@=&AE(&YA;64@;V8@=&AE(')O;W0@=&%G"B`@("`J"B`@("`J
M($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@<W1R:6YG("`D<F]O=$YA
M;64*("`@("HO"B`@("!F=6YC=&EO;B!G9712;V]T3F%M92@I"B`@("!["B`@
M("`@("`@:68@*"1T:&ES+3Y?<F]O="`]/3T@;G5L;"D@>PH@("`@("`@("`@
M("!R971U<FX@)'1H:7,M/G)A:7-E17)R;W(H)TYO('5N<V5R:6%L:7IE9"!D
M871A(&%V86EL86)L92X@57-E(%A-3%]5;G-E<FEA;&EZ97(Z.G5N<V5R:6%L
M:7IE*"D@9FER<W0N)RP@6$U,7U5.4T5224%,25I%4E]%4E)/4E].3U]53E-%
M4DE!3$E:051)3TXI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M
M/E]R;V]T.PH@("`@?0H*("`@+RHJ"B`@("`J(%-T87)T(&5L96UE;G0@:&%N
M9&QE<B!F;W(@6$U,('!A<G-E<@H@("`@*@H@("`@*B!`86-C97-S('!R:79A
M=&4*("`@("H@0'!A<F%M("!O8FIE8W0@)'!A<G-E<B`@6$U,('!A<G-E<B!O
M8FIE8W0*("`@("H@0'!A<F%M("!S=')I;F<@)&5L96UE;G0@6$U,(&5L96UE
M;G0*("`@("H@0'!A<F%M("!A<G)A>2`@)&%T=')I8G,@871T<FEB=71E<R!O
M9B!834P@=&%G"B`@("`J($!R971U<FX@=F]I9`H@("`@*B\*("`@(&9U;F-T
M:6]N('-T87)T2&%N9&QE<B@D<&%R<V5R+"`D96QE;65N="P@)&%T=')I8G,I
M"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1A='1R:6)S6R1T:&ES+3YO<'1I
M;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415]465!%75TI
M*2!["B`@("`@("`@("`@("1T>7!E(#T@)&%T=')I8G-;)'1H:7,M/F]P=&EO
M;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%7U194$5=73L*
M("`@("`@("`@("`@)&=U97-S5'EP92`](&9A;'-E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T>7!E(#T@)W-T<FEN9R<["B`@("`@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]'
M54534U]465!%4UT@/3T]('1R=64I('L*("`@("`@("`@("`@("`@("1G=65S
M<U1Y<&4@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@)&=U97-S5'EP92`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?1$5#3T1%7T953D-=("$]/2!N=6QL*2!["B`@("`@("`@
M("`@("1A='1R:6)S(#T@87)R87E?;6%P*"1T:&ES+3YO<'1I;VYS6UA-3%]5
M3E-%4DE!3$E:15)?3U!424].7T1%0T]$15]&54Y#72P@)&%T=')I8G,I.PH@
M("`@("`@('T*("`@("`@("`*("`@("`@("`D=&AI<RT^7V1E<'1H*RL["B`@
M("`@("`@)'1H:7,M/E]D871A4W1A8VM;)'1H:7,M/E]D97!T:%T@/2!N=6QL
M.PH*("`@("`@("!I9B`H:7-?87)R87DH)'1H:7,M/F]P=&EO;G-;6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?5$%'7TU!4%TI("8F(&ES<V5T*"1T:&ES+3YO
M<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7U1!1U]-05!=6R1E;&5M
M96YT72DI('L*("`@("`@("`@("`@)&5L96UE;G0@/2`D=&AI<RT^;W!T:6]N
M<UM834Q?54Y315))04Q)6D527T]05$E/3E]404=?34%075LD96QE;65N=%T[
M"B`@("`@("`@?0H*("`@("`@("`D=F%L(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("=N86UE)R`@("`@("`@(#T^("1E;&5M96YT+`H@("`@("`@
M("`@("`@("`@("`@("`G=F%L=64G("`@("`@("`]/B!N=6QL+`H@("`@("`@
M("`@("`@("`@("`@("`G='EP92<@("`@("`@("`]/B`D='EP92P*("`@("`@
M("`@("`@("`@("`@("`@)V=U97-S5'EP92<@("`@/3X@)&=U97-S5'EP92P*
M("`@("`@("`@("`@("`@("`@("`@)V-H:6QD<F5N2V5Y<R<@/3X@87)R87DH
M*2P*("`@("`@("`@("`@("`@("`@("`@)V%G9W)E9TME>7,G("`@/3X@87)R
M87DH*0H@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$53
M7U!!4E-%72`]/2!T<G5E("8F("AC;W5N="@D871T<FEB<RD@/B`P*2D@>PH@
M("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==(#T@87)R87DH*3L*("`@("`@
M("`@("`@)'9A;%LG='EP92==("`]("1T:&ES+3Y?9V5T0V]M<&QE>%1Y<&4H
M)&5L96UE;G0I.PH@("`@("`@("`@("`D=F%L6R=C;&%S<R==(#T@)&5L96UE
M;G0["@H@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?1U5%4U-?5%E015-=(#T]/2!T<G5E*2!["B`@("`@
M("`@("`@(`DD871T<FEB<R`]("1T:&ES+3Y?9W5E<W-!;F139714>7!E<R@D
M871T<FEB<RD["B`@("`@("`@("`@('T@("`@("`@("`@("`*("`@("`@("`@
M("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415-?05)205E+15E=("$](&9A;'-E*2!["B`@("`@("`@("`@
M("`@("`D=F%L6R=C:&EL9')E;B==6R1T:&ES+3YO<'1I;VYS6UA-3%]53E-%
M4DE!3$E:15)?3U!424].7T%45%))0E5415-?05)205E+15E=72`]("1A='1R
M:6)S.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@9F]R
M96%C:"`H)&%T=')I8G,@87,@)&%T=')I8B`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@("`@("`D=F%L6R=C:&EL9')E;B==6R1T:&ES+3YO<'1I;VYS
M6UA-3%]53E-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?4%)%4$5.1%TN
M)&%T=')I8ET@/2`D=F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@("1K97E!='1R(#T@9F%L<V4["B`@
M("`@("`@"B`@("`@("`@:68@*&ES7W-T<FEN9R@D=&AI<RT^;W!T:6]N<UM8
M34Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)55$5?2T5972DI('L*("`@
M("`@("`@("`@)&ME>4%T='(@/2`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))
M04Q)6D527T]05$E/3E]!5%1224)55$5?2T5973L*("`@("`@("!](&5L<V5I
M9B`H:7-?87)R87DH)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/
M4%1)3TY?05144DE"551%7TM%65TI*2!["B`@("`@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]!5%12
M24)55$5?2T5975LD96QE;65N=%TI*2!["B`@("`@("`@("`@("`@("`D:V5Y
M071T<B`]("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415]+15E=6R1E;&5M96YT73L*("`@("`@("`@("`@?2!E;'-E
M:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7T%45%))0E5415]+15E=6R<C9&5F875L="==*2D@>PH@("`@("`@("`@
M("`@("`@)&ME>4%T='(@/2`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)
M6D527T]05$E/3E]!5%1224)55$5?2T5975LG(V1E9F%U;'0G73L*("`@("`@
M("`@("`@?2!E;'-E:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%
M4DE!3$E:15)?3U!424].7T%45%))0E5415]+15E=6R=?7V1E9F%U;'0G72DI
M('L*("`@("`@("`@("`@("`@("\O(&ME97`@=&AI<R!F;W(@0D,*("`@("`@
M("`@("`@("`@("1K97E!='1R(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T52
M24%,25I%4E]/4%1)3TY?05144DE"551%7TM%65U;)U]?9&5F875L="==.PH@
M("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D
M:V5Y071T<B`A/3T@9F%L<V4@)B8@:7-S970H)&%T=')I8G-;)&ME>4%T=')=
M*2D@>PH@("`@("`@("`@("`D=F%L6R=N86UE)UT@/2`D871T<FEB<ULD:V5Y
M071T<ET["B`@("`@("`@?0H*("`@("`@("!I9B`H:7-S970H)&%T=')I8G-;
M)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"
M551%7T-,05-375TI*2!["B`@("`@("`@("`@("1V86Q;)V-L87-S)UT@/2`D
M871T<FEB<ULD=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/
M3E]!5%1224)55$5?0TQ!4U-=73L*("`@("`@("!]"@H@("`@("`@(&%R<F%Y
M7W!U<V@H)'1H:7,M/E]V86Q3=&%C:RP@)'9A;"D["B`@("!]"@H@("`O*BH*
M("`@("H@5')Y('1O(&=U97-S('1H92!T>7!E(&]F('-E=F5R86P@=F%L=65S
M(&%N9`H@("`@*B!S970@=&AE;2!A8V-O<F1I;F=L>0H@("`@*@H@("`@*B!`
M86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@87)R87D@("`@("!A
M<G)A>2P@8V]N=&%I;FEN9R!T:&4@=F%L=65S"B`@("`J($!R971U<FX@("!A
M<G)A>2`@("`@(&%R<F%Y+"!C;VYT86EN:6YG('1H92!V86QU97,@=VET:"!T
M:&5I<B!C;W)R96-T('1Y<&5S(`H@("`@*B\*("`@(&9U;F-T:6]N(%]G=65S
M<T%N9%-E=%1Y<&5S*"1A<G)A>2D*("`@('L*("`@("`@("!F;W)E86-H("@D
M87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@("`))&%R<F%Y6R1K
M97E=(#T@)'1H:7,M/E]G=65S<T%N9%-E=%1Y<&4H)'9A;'5E*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1A<G)A>3L*("`@('T*("`@(`H@("`O*BH*
M("`@("H@5')Y('1O(&=U97-S('1H92!T>7!E(&]F(&$@=F%L=64@86YD"B`@
M("`J('-E="!I="!A8V-O<F1I;F=L>0H@("`@*@H@("`@*B!`86-C97-S("`@
M<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@8VAA<F%C=&5R
M(&1A=&$*("`@("H@0')E='5R;B`@(&UI>&5D("`@("`@('9A;'5E('=I=&@@
M=&AE(&)E<W0@;6%T8VAI;F<@='EP90H@("`@*B\*("`@(&9U;F-T:6]N(%]G
M=65S<T%N9%-E=%1Y<&4H)'9A;'5E*0H@("`@>PH@("`@("`@(&EF("@D=F%L
M=64@/3T]("=T<G5E)RD@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@
M("`@("!]"B`@("`@("`@:68@*"1V86QU92`]/3T@)V9A;'-E)RD@>PH@("`@
M("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@D
M=F%L=64@/3T]("=.54Q,)RD@>PH@("`@("`@("`@("!R971U<FX@;G5L;#L*
M("`@("`@("!]"B`@("`@("`@:68@*'!R96=?;6%T8V@H)R]>6RTK73];,"TY
M77LQ+'TD+R<L("1V86QU92DI('L*("`@("`@("`)<F5T=7)N(&EN='9A;"@D
M=F%L=64I.PH@("`@("`@('T*("`@("`@("!I9B`H<')E9U]M871C:"@G+UY;
M+2M=/ULP+3E=>S$L?5PN6S`M.5U[,2Q])"\G+"`D=F%L=64I*2!["B`@("`@
M("`@"7)E='5R;B!D;W5B;&5V86PH)'9A;'5E*3L*("`@("`@("!]"B`@("`@
M("`@<F5T=7)N("AS=')I;F<I)'9A;'5E.PH@("`@?0H@("`@"B`@("\J*@H@
M("`@*B!%;F0@96QE;65N="!H86YD;&5R(&9O<B!834P@<&%R<V5R"B`@("`J
M"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`<&%R86T@(&]B:F5C="!8
M34P@<&%R<V5R(&]B:F5C=`H@("`@*B!`<&%R86T@('-T<FEN9PH@("`@*B!`
M<F5T=7)N('9O:60*("`@("HO"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R*"1P
M87)S97(L("1E;&5M96YT*0H@("`@>PH@("`@("`@("1V86QU92`](&%R<F%Y
M7W!O<"@D=&AI<RT^7W9A;%-T86-K*3L*("`@("`@("!S=VET8V@@*"1T:&ES
M+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7U=(251%4U!!0T5=
M*2!["B`@("`@("`@("`@(&-A<V4@6$U,7U5.4T5224%,25I%4E]72$E415-0
M04-%7TM%15`Z"B`@("`@("`@("`@("`@("`D9&%T82`]("1T:&ES+3Y?9&%T
M85-T86-K6R1T:&ES+3Y?9&5P=&A=.PH@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@(&-A<V4@6$U,7U5.4T5224%,25I%4E]72$E415-004-%
M7TY/4DU!3$E:13H*("`@("`@("`@("`@("`@("1D871A(#T@=')I;2AP<F5G
M7W)E<&QA8V4H)R]<<UQS*R]M)RP@)R`G+"`D=&AI<RT^7V1A=&%3=&%C:ULD
M=&AI<RT^7V1E<'1H72DI.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@6$U,7U5.4T5224%,25I%4E]72$E415-004-%7U1224TZ
M"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("`D9&%T82`@
M/2!T<FEM*"1T:&ES+3Y?9&%T85-T86-K6R1T:&ES+3Y?9&5P=&A=*3L*("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@861J
M=7-T('1Y<&4@;V8@=&AE('9A;'5E"B`@("`@("`@<W=I=&-H*'-T<G1O;&]W
M97(H)'9A;'5E6R=T>7!E)UTI*2!["@H@("`@("`@("`@("`O+R!U;G-E<FEA
M;&EZ92!A;B!O8FIE8W0*("`@("`@("`@("`@8V%S92`G;V)J96-T)SH*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D=F%L=65;)V-L87-S)UTI*2!["B`@
M("`@("`@("`@("`@("`@("`@)&-L87-S;F%M92`@/2`D=F%L=65;)V-L87-S
M)UT["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("1C;&%S<VYA;64@/2`G)SL*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("\O(&EN<W1A;G1I871E('1H92!C;&%S<PH@("`@("`@("`@
M("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7U1!1U]!4U]#3$%34TY!345=(#T]/2!T<G5E("8F(&-L87-S7V5X:7-T
M<R@D8VQA<W-N86UE*2D@>PH@("`@("`@("`@("`@("`@("`@("1V86QU95LG
M=F%L=64G72`]("9N97<@)&-L87-S;F%M93L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@
M)FYE=R`D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]$
M149!54Q47T-,05-373L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@(&EF("AT<FEM*"1D871A*2`A/3T@)R<I('L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'9A;'5E6R=G=65S<U1Y<&4G72`]/3T@=')U92D@>PH@("`@
M("`@("`@("`@("`@("`@(`DD9&%T82`]("1T:&ES+3Y?9W5E<W-!;F139714
M>7!E*"1D871A*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)'9A;'5E6R=C:&EL9')E;B==6R1T:&ES+3YO<'1I;VYS6UA-
M3%]53E-%4DE!3$E:15)?3U!424].7T-/3E1%3E1?2T5975T@/2`D9&%T83L*
M("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!S970@<')O
M<&5R=&EE<PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)'9A;'5E6R=C:&EL
M9')E;B==(&%S("1P<F]P(#T^("1P<F]P5F%L*2!["B`@("`@("`@("`@("`@
M("`@("`@+R\@8VAE8VL@=VAE=&AE<B!T:&5R92!I<R!A('-P96-I86P@;65T
M:&]D('1O('-E="!T:&ES('!R;W!E<G1Y"B`@("`@("`@("`@("`@("`@("`@
M)'-E=$UE=&AO9"`]("=S970G+B1P<F]P.PH@("`@("`@("`@("`@("`@("`@
M(&EF("AM971H;V1?97AI<W1S*"1V86QU95LG=F%L=64G72P@)'-E=$UE=&AO
M9"DI('L*("`@("`@("`@("`@("`@("`@("`@("`@8V%L;%]U<V5R7V9U;F,H
M87)R87DH)B1V86QU95LG=F%L=64G72P@)'-E=$UE=&AO9"DL("1P<F]P5F%L
M*3L*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D=F%L=65;)W9A;'5E)UTM/B1P<F]P(#T@)'!R;W!686P[
M"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@+R\@(&-H96-K(&9O<B!M86=I8R!F=6YC=&EO;@H@("`@
M("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'9A;'5E6R=V86QU92==
M+"`G7U]W86ME=7`G*2D@>PH@("`@("`@("`@("`@("`@("`@("1V86QU95LG
M=F%L=64G72T^7U]W86ME=7`H*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@+R\@=6YS97)I86QI>F4@
M86X@87)R87D*("`@("`@("`@("`@8V%S92`G87)R87DG.@H@("`@("`@("`@
M("`@("`@:68@*'1R:6TH)&1A=&$I("$]/2`G)RD@>PH@("`@("`@("`@("`@
M("`@("`@(&EF("@D=F%L=65;)V=U97-S5'EP92==(#T]/2!T<G5E*2!["B`@
M("`@("`@("`@("`@("`@("`@"21D871A(#T@)'1H:7,M/E]G=65S<T%N9%-E
M=%1Y<&4H)&1A=&$I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`D=F%L=65;)V-H:6QD<F5N)UU;)'1H:7,M/F]P=&EO;G-;
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15E=72`]("1D871A
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*&ES<V5T
M*"1V86QU95LG8VAI;&1R96XG72DI('L*("`@("`@("`@("`@("`@("`@("`D
M=F%L=65;)W9A;'5E)UT@/2`D=F%L=65;)V-H:6QD<F5N)UT["B`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V86QU95LG
M=F%L=64G72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O('5N<V5R:6%L:7IE(&$@
M;G5L;"!V86QU90H@("`@("`@("`@("!C87-E("=N=6QL)SH*("`@("`@("`@
M("`@("`@("1D871A(#T@;G5L;#L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@+R\@=6YS97)I86QI>F4@82!R97-O=7)C92`]/B!T:&ES
M(&ES(&YO="!P;W-S:6)L92`Z+2@*("`@("`@("`@("`@8V%S92`G<F5S;W5R
M8V4G.@H@("`@("`@("`@("`@("`@)'9A;'5E6R=V86QU92==(#T@)&1A=&$[
M"B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("\O('5N<V5R
M:6%L:7IE(&%N>2!S8V%L87(@=F%L=64*("`@("`@("`@("`@9&5F875L=#H*
M("`@("`@("`@("`@("`@(&EF("@D=F%L=65;)V=U97-S5'EP92==(#T]/2!T
M<G5E*2!["B`@("`@("`@("`@("`@("`@("`@)&1A=&$@/2`D=&AI<RT^7V=U
M97-S06YD4V5T5'EP92@D9&%T82D["B`@("`@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@("`@('-E='1Y<&4H)&1A=&$L("1V86QU95LG
M='EP92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@
M("`@("`@("`@("`D=F%L=65;)W9A;'5E)UT@/2`D9&%T83L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*("`@("`@("`D<&%R96YT(#T@87)R
M87E?<&]P*"1T:&ES+3Y?=F%L4W1A8VLI.PH@("`@("`@(&EF("@D<&%R96YT
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1T:&ES+3Y?=6YS97)I86QI>F5D
M1&%T82`]("8D=F%L=65;)W9A;'5E)UT["B`@("`@("`@("`@("1T:&ES+3Y?
M<F]O="`]("8D=F%L=65;)VYA;64G73L*("`@("`@("`@("`@<F5T=7)N('1R
M=64["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@<&%R96YT(&AA
M<R!T;R!B92!A;B!A<G)A>0H@("`@("`@("`@("!I9B`H(6ES<V5T*"1P87)E
M;G1;)V-H:6QD<F5N)UTI('Q\("%I<U]A<G)A>2@D<&%R96YT6R=C:&EL9')E
M;B==*2D@>PH@("`@("`@("`@("`@("`@)'!A<F5N=%LG8VAI;&1R96XG72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("!I9B`H(6EN7V%R<F%Y*"1P87)E
M;G1;)W1Y<&4G72P@87)R87DH)V%R<F%Y)RP@)V]B:F5C="<I*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1P87)E;G1;)W1Y<&4G72`]("1T:&ES+3Y?9V5T
M0V]M<&QE>%1Y<&4H)'!A<F5N=%LG;F%M92==*3L*("`@("`@("`@("`@("`@
M("`@("!I9B`H)'!A<F5N=%LG='EP92==(#T]("=O8FIE8W0G*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1P87)E;G1;)V-L87-S)UT@/2`D<&%R96YT
M6R=N86UE)UT["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:6Y?87)R87DH
M)&5L96UE;G0L("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!4
M24].7TE'3D]215]+15E372DI('L*("`@("`@("`@("`@("`@("1I9VYO<F5+
M97D@/2!T<G5E.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`)
M)&EG;F]R94ME>2`](&9A;'-E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(`H@("`@("`@("`@("!I9B`H(65M<'1Y*"1V86QU95LG;F%M92==*2`F)B`D
M:6=N;W)E2V5Y(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@+R\@=&AE
M<F4@86QR96%D>2!H87,@8F5E;B!A('1A9R!W:71H('1H:7,@;F%M90H@("`@
M("`@("`@("`@("`@:68@*&EN7V%R<F%Y*"1V86QU95LG;F%M92==+"`D<&%R
M96YT6R=C:&EL9')E;DME>7,G72D@?'P@:6Y?87)R87DH)'9A;'5E6R=N86UE
M)UTL("1T:&ES+3YO<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T9/
M4D-%7T5.54U=*2D@>PH@("`@("`@("`@("`@("`@("`@("\O(&YO(&%G9W)E
M9V%T92!H87,@8F5E;B!C<F5A=&5D(&9O<B!T:&ES('1A9PH@("`@("`@("`@
M("`@("`@("`@(&EF("@A:6Y?87)R87DH)'9A;'5E6R=N86UE)UTL("1P87)E
M;G1;)V%G9W)E9TME>7,G72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*&ES<V5T*"1P87)E;G1;)V-H:6QD<F5N)UU;)'9A;'5E6R=N86UE)UU=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F5N=%LG8VAI
M;&1R96XG75LD=F%L=65;)VYA;64G75T@/2!A<G)A>2@D<&%R96YT6R=C:&EL
M9')E;B==6R1V86QU95LG;F%M92==72D["B`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&%R
M96YT6R=C:&EL9')E;B==6R1V86QU95LG;F%M92==72`](&%R<F%Y*"D["B`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87E?<'5S:"@D<&%R96YT6R=A9V=R96=+97ES)UTL("1V86QU95LG
M;F%M92==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@87)R87E?<'5S:"@D<&%R96YT6R=C:&EL9')E;B==6R1V86QU95LG
M;F%M92==72P@)'9A;'5E6R=V86QU92==*3L*("`@("`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("`@("`@)'!A<F5N=%LG8VAI;&1R96XG
M75LD=F%L=65;)VYA;64G75T@/2`F)'9A;'5E6R=V86QU92==.PH@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A<F5N=%LG8VAI;&1R96Y+97ES
M)UTL("1V86QU95LG;F%M92==*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&%R<F%Y7W!U<V@H)'!A
M<F5N=%LG8VAI;&1R96XG72P@)'9A;'5E6R=V86QU92==*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!A<G)A>5]P=7-H*"1T:&ES+3Y?=F%L4W1A8VLL
M("1P87)E;G0I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/E]D97!T:"TM
M.PH@("`@?0H*("`@+RHJ"B`@("`J($AA;F1L97(@9F]R(&-H87)A8W1E<B!D
M871A"B`@("`J"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@*B!`<&%R86T@
M(&]B:F5C="!834P@<&%R<V5R(&]B:F5C=`H@("`@*B!`<&%R86T@('-T<FEN
M9R!#1$%400H@("`@*B!`<F5T=7)N('9O:60*("`@("HO"B`@("!F=6YC=&EO
M;B!C9&%T84AA;F1L97(H)'!A<G-E<BP@)&-D871A*0H@("`@>PH@("`@("`@
M(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]$
M14-/1$5?1E5.0UT@(3T](&YU;&PI('L*("`@("`@("`@("`@)&-D871A(#T@
M8V%L;%]U<V5R7V9U;F,H)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%
M4E]/4%1)3TY?1$5#3T1%7T953D-=+"`D8V1A=&$I.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^7V1A=&%3=&%C:ULD=&AI<RT^7V1E<'1H72`N/2`D8V1A
M=&$["B`@("!]"@H@("`O*BH*("`@("H@9V5T('1H92!C;VUP;&5X('1Y<&4L
M('1H870@<VAO=6QD(&)E('5S960@9F]R(&$@<W!E8VEF:65D('1A9PH@("`@
M*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("`@("`@;F%M92!O9B!T:&4@=&%G"B`@("`J($!R971U<FX@("!S=')I
M;F<@("`@("!C;VUP;&5X('1Y<&4@*"=A<G)A>2<@;W(@)V]B:F5C="<I"B`@
M("`J+PH@("`@9G5N8W1I;VX@7V=E=$-O;7!L97A4>7!E*"1T86=N86UE*0H@
M("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)'1H:7,M/F]P=&EO;G-;6$U,
M7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$5=*2D@>PH@("`@("`@
M(`ER971U<FX@)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?0T]-4$Q%6%194$5=.PH@("`@("`@('T*("`@("`@("!I9B`H:7-S970H
M)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%
M6%194$5=6R1T86=N86UE72DI('L*("`@("`@("`)<F5T=7)N("1T:&ES+3YO
M<'1I;VYS6UA-3%]53E-%4DE!3$E:15)?3U!424].7T-/35!,15A465!%75LD
M=&%G;F%M95T["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^
M;W!T:6]N<UM834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E015U;
M)R-D969A=6QT)UTI*2!["B`@("`@("`@"7)E='5R;B`D=&AI<RT^;W!T:6]N
M<UM834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E015U;)R-D969A
M=6QT)UT["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G87)R87DG.PH@("`@
M?0H@("`@"B`@("\J*@H@("`@*B!C<F5A=&4@=&AE(%A-3%]087)S97(@:6YS
M=&%N8V4*("`@("H*("`@("H@0&%C8V5S<R`@("!P<FEV871E"B`@("`J($!R
M971U<FX@("`@8F]O;&5A;@H@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&50
M87)S97(H*0H@("`@>PH@("`@("`@(&EF("AI<U]O8FIE8W0H)'1H:7,M/E]P
M87)S97(I*2!["B`@("`@("`@("`@("1T:&ES+3Y?<&%R<V5R+3YF<F5E*"D[
M"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3Y?<&%R<V5R*3L*("`@("`@("!]
M"B`@("`@("`@)'1H:7,M/E]P87)S97(@/2`F;F5W(%A-3%]087)S97(H)'1H
M:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?
M4T]54D-%72P@)V5V96YT)RP@)'1H:7,M/F]P=&EO;G-;6$U,7U5.4T5224%,
M25I%4E]/4%1)3TY?14Y#3T1)3D=?5$%21T5472D["B`@("`@("`@)'1H:7,M
M/E]P87)S97(M/F9O;&1I;F<@/2!F86QS93L*("`@("`@("`D=&AI<RT^7W!A
M<G-E<BT^<V5T2&%N9&QE<D]B:B@D=&AI<RD["B`@("`@("`@<F5T=7)N('1R
M=64["B`@("!]"GT*/SX`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+UA-3"]397)I86QI>F5R+G!H<```````````````````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`Q,3(T-S(@,3`U,34T,S0Q,S,@,#(Q-S4R`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_4$A0"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30Z("HO"@HO*BH*("H@6$U,7U-E<FEA;&EZ97(*("H*("H@
M0W)E871E<R!834P@9&]C=6UE;G1S(&9R;VT@4$A0(&1A=&$@<W1R=6-T=7)E
M<R!L:6ME(&%R<F%Y<RP@;V)J96-T<R!O<B!S8V%L87)S+@H@*@H@*B!02%`@
M=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E"B`J('1H870@:7,@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@55)).@H@*B!H='1P.B\O=W=W+G!H
M<"YN970O;&EC96YS92\S7S`N='AT+B`@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA8FQE
M('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90H@*B!S96YD
M(&$@;F]T92!T;R!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X*("H*("H@0&-A=&5G;W)Y("`@6$U,"B`J
M($!P86-K86=E("`@(%A-3%]397)I86QI>F5R"B`J($!A=71H;W(@("`@(%-T
M97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@0&-O<'ER:6=H="`@
M,3DY-RTR,#`U(%1H92!02%`@1W)O=7`*("H@0&QI8V5N<V4@("`@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X="`@4$A0($QI8V5N<V4@,RXP
M"B`J($!V97)S:6]N("`@($-64SH@)$ED.B!397)I86QI>F5R+G!H<"QV(#$N
M-#<@,C`P-2\P.2\S,"`Q,SHT,#HS,"!S8VAS="!%>'`@)`H@*B!`;&EN:R`@
M("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U-E<FEA;&EZ
M97(*("H@0'-E92`@("`@("`@6$U,7U5N<V5R:6%L:7IE<@H@*B\*"B\J*@H@
M*B!U<V5S(%!%05(@97)R;W(@;6%N86=E;65N=`H@*B\*<F5Q=6ER95]O;F-E
M("=014%2+G!H<"<["@HO*BH*("H@=7-E<R!834Q?571I;"!T;R!C<F5A=&4@
M6$U,('1A9W,*("HO"G)E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL*"B\J
M*@H@*B!O<'1I;VXZ('-T<FEN9R!U<V5D(&9O<B!I;F1E;G1A=&EO;@H@*@H@
M*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T<FEN9R`H9&5F875L="!I
M<R!A;GD@<W1R:6YG*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)
M3TY?24Y$14Y4)RP@)VEN9&5N="<I.PH*+RHJ"B`J(&]P=&EO;CH@<W1R:6YG
M('5S960@9F]R(&QI;F5B<F5A:W,*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@
M*B`M(&%N>2!S=')I;F<@*&1E9F%U;'0@:7,@7&XI"B`J+PID969I;F4H)UA-
M3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3)RP@)VQI;F5B<F5A:R<I
M.PH*+RHJ"B`J(&]P=&EO;CH@96YA8FQE('1Y<&4@:&EN=',*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS90H@*B\*9&5F:6YE
M*"=834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13)RP@)W1Y<&5(:6YT
M<R<I.PH*+RHJ"B`J(&]P=&EO;CH@861D(&%N(%A-3"!D96-L87)A=&EO;@H@
M*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U90H@*B`M(&9A;'-E"B`J
M+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]834Q?1$5#3%]%3D%"
M3$5$)RP@)V%D9$1E8VPG*3L*"B\J*@H@*B!O<'1I;VXZ(&5N8V]D:6YG(&]F
M('1H92!D;V-U;65N=`H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY
M('9A;&ED(&5N8V]D:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO"F1E9FEN
M92@G6$U,7U-%4DE!3$E:15)?3U!424].7UA-3%]%3D-/1$E.1R<L("=E;F-O
M9&EN9R<I.PH*+RHJ"B`J(&]P=&EO;CH@9&5F875L="!N86UE(&9O<B!T86=S
M"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!A;GD@<W1R:6YG("A834Q?
M4V5R:6%L:7IE<E]486<@:7,@9&5F875L="D*("HO"F1E9FEN92@G6$U,7U-%
M4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%')RP@)V1E9F%U;'1486=.86UE
M)RD["@HO*BH*("H@;W!T:6]N.B!U<V4@8VQA<W-N86UE(&9O<B!O8FIE8W1S
M(&EN(&EN9&5X960@87)R87ES"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@
M+2!T<G5E("AD969A=6QT*0H@*B`M(&9A;'-E"B`J+PID969I;F4H)UA-3%]3
M15))04Q)6D527T]05$E/3E]#3$%34TY!345?05-?5$%'3D%-12<L("=C;&%S
M<T%S5&%G3F%M92<I.PH*+RHJ"B`J(&]P=&EO;CH@871T<FEB=71E('=H97)E
M(&]R:6=I;F%L(&ME>2!I<R!S=&]R960*("H*("H@4&]S<VEB;&4@=F%L=65S
M.@H@*B`M(&%N>2!S=')I;F<@*&1E9F%U;'0@:7,@7V]R:6=I;F%L2V5Y*0H@
M*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%7TM%
M62<L("=K97E!='1R:6)U=&4G*3L*"B\J*@H@*B!O<'1I;VXZ(&%T=')I8G5T
M92!F;W(@='EP92`H;VYL>2!I9B!T>7!E2&EN=',@/3X@=')U92D*("H*("H@
M4&]S<VEB;&4@=F%L=65S.@H@*B`M(&%N>2!S=')I;F<@*&1E9F%U;'0@:7,@
M7W1Y<&4I"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]!5%12
M24)55$5?5%E012<L("=T>7!E071T<FEB=71E)RD["@HO*BH*("H@;W!T:6]N
M.B!A='1R:6)U=&4@9F]R(&-L87-S("AO;FQY(&EF('1Y<&5(:6YT<R`]/B!T
M<G5E*0H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T<FEN9R`H
M9&5F875L="!I<R!?8VQA<W,I"B`J+PID969I;F4H)UA-3%]315))04Q)6D52
M7T]05$E/3E]!5%1224)55$5?0TQ!4U,G+"`G8VQA<W-!='1R:6)U=&4G*3L*
M"B\J*@H@*B!O<'1I;VXZ('-C86QA<B!V86QU97,@*'-T<FEN9W,L(&EN=',L
M+BXI('=I;&P@8F4@<V5R:6%L:7IE9"!A<R!A='1R:6)U=&4*("H*("H@4&]S
M<VEB;&4@=F%L=65S.@H@*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*
M("H@+2!A<G)A>2!W:&EC:"!S971S('1H:7,@;W!T:6]N(&]N(&$@<&5R+71A
M9R!B87-I<PH@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?4T-!
M3$%27T%37T%45%))0E5415,G+"`G<V-A;&%R07-!='1R:6)U=&5S)RD["@HO
M*BH*("H@;W!T:6]N.B!P<F5P96YD('-T<FEN9R!F;W(@871T<FEB=71E<PH@
M*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@86YY('-T<FEN9R`H9&5F875L
M="!I<R!A;GD@<W1R:6YG*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/
M4%1)3TY?4%)%4$5.1%]!5%1224)55$53)RP@)W!R97!E;F1!='1R:6)U=&5S
M)RD["@HO*BH*("H@;W!T:6]N.B!I;F1E;G0@=&AE(&%T=')I8G5T97,L(&EF
M('-E="!T;R`G7V%U=&\G+"!I="!W:6QL(&EN9&5N="!A='1R:6)U=&5S('-O
M('1H97D@86QL('-T87)T(&%T('1H92!S86UE(&-O;'5M;@H@*@H@*B!0;W-S
M:6)L92!V86QU97,Z"B`J("T@=')U90H@*B`M(&9A;'-E("AD969A=6QT*0H@
M*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y47T%45%))
M0E5415,G+"`G:6YD96YT071T<FEB=71E<R<I.PH*+RHJ"B`J(&]P=&EO;CH@
M=7-E("=S:6UP;&5X;6PG('1O('5S92!P87)E;G0@;F%M92!A<R!T86=N86UE
M(&EF('1R86YS9F]R;6EN9R!A;B!I;F1E>&5D(&%R<F%Y"B`J"B`J(%!O<W-I
M8FQE('9A;'5E<SH*("H@+2!834Q?4T5224%,25I%4E]-3T1%7T1%1D%53%0@
M*&1E9F%U;'0I"B`J("T@6$U,7U-%4DE!3$E:15)?34]$15]324U03$5834P*
M("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$4G+"`G;6]D
M92<I.PH*+RHJ"B`J(&]P=&EO;CH@861D(&$@9&]C='EP92!D96-L87)A=&EO
M;@H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U90H@*B`M(&9A;'-E
M("AD969A=6QT*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)3TY?
M1$]#5%E015]%3D%"3$5$)RP@)V%D9$1O8W1Y<&4G*3L*"B\J*@H@*B!O<'1I
M;VXZ('-U<'!L>2!A('-T<FEN9R!O<B!A;B!A<G)A>2!W:71H(&ED(&%N9"!U
M<FD@*'M`<V5E(%A-3%]5=&EL.CIG971$;V-T>7!E1&5C;&%R871I;VXH*7T*
M("H*("H@4&]S<VEB;&4@=F%L=65S.@H@*B`M('-T<FEN9PH@*B`M(&%R<F%Y
M"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]$3T-465!%)RP@
M)V1O8W1Y<&4G*3L*"B\J*@H@*B!O<'1I;VXZ(&YA;64@;V8@=&AE(')O;W0@
M=&%G"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@+2!S=')I;F<*("H@+2!N
M=6QL("AD969A=6QT*0H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]/4%1)
M3TY?4D]/5%].04U%)RP@)W)O;W1.86UE)RD["@HO*BH*("H@;W!T:6]N.B!A
M='1R:6)U=&5S(&]F('1H92!R;V]T('1A9PH@*@H@*B!0;W-S:6)L92!V86QU
M97,Z"B`J("T@87)R87D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!4
M24].7U)/3U1?05144DE"4R<L("=R;V]T071T<FEB=71E<R<I.PH*+RHJ"B`J
M(&]P=&EO;CH@86QL('9A;'5E<R!I;B!T:&ES(&ME>2!W:6QL(&)E('1R96%T
M960@87,@871T<FEB=71E<PH@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@
M87)R87D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))
M0E5415-?2T59)RP@)V%T=')I8G5T97-!<G)A>2<I.PH*+RHJ"B`J(&]P=&EO
M;CH@=&AI<R!V86QU92!W:6QL(&)E('5S960@9&ER96-T;'D@87,@8V]N=&5N
M="P@:6YS=&5A9"!O9B!C<F5A=&EN9R!A(&YE=R!T86<L(&UA>2!O;FQY(&)E
M('5S960@:6X@8V]N:G5C=&EO;B!W:71H(&%T=')I8G5T97-!<G)A>0H@*@H@
M*B!0;W-S:6)L92!V86QU97,Z"B`J("T@<W1R:6YG"B`J("T@;G5L;"`H9&5F
M875L="D*("HO"F1E9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7T-/3E1%
M3E1?2T59)RP@)V-O;G1E;G1.86UE)RD["@HO*BH*("H@;W!T:6]N.B!T:&ES
M('9A;'5E('=I;&P@8F4@=7-E9"!I;B!A(&-O;6UE;G0L(&EN<W1E860@;V8@
M8W)E871I;F<@82!N97<@=&%G"B`J"B`J(%!O<W-I8FQE('9A;'5E<SH*("H@
M+2!S=')I;F<*("H@+2!N=6QL("AD969A=6QT*0H@*B\*9&5F:6YE*"=834Q?
M4T5224%,25I%4E]/4%1)3TY?0T]-345.5%]+15DG+"`G8V]M;65N=$YA;64G
M*3L*"B\J*@H@*B!O<'1I;VXZ('1A9R!N86UE<R!T:&%T('=I;&P@8F4@8VAA
M;F=E9`H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@87)R87D*("HO"F1E
M9FEN92@G6$U,7U-%4DE!3$E:15)?3U!424].7U1!1TU!4"<L("=T86=-87`G
M*3L*"B\J*@H@*B!O<'1I;VXZ(&9U;F-T:6]N('1H870@=VEL;"!B92!A<'!L
M:65D(&)E9F]R92!S97)I86QI>FEN9PH@*@H@*B!0;W-S:6)L92!V86QU97,Z
M"B`J("T@86YY('9A;&ED(%!(4"!C86QL8F%C:PH@*B\*9&5F:6YE*"=834Q?
M4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T953D,G+"`G96YC;V1E1G5N8W1I
M;VXG*3L*"B\J*@H@*B!O<'1I;VXZ(&9U;F-T:6]N('1H870@=VEL;"!B92!A
M<'!L:65D(&)E9F]R92!S97)I86QI>FEN9PH@*@H@*B!0;W-S:6)L92!V86QU
M97,Z"B`J("T@<W1R:6YG"B`J("T@;G5L;"`H9&5F875L="D*("HO"F1E9FEN
M92@G6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#12<L("=N86UE<W!A
M8V4G*3L*"B\J*@H@*B!O<'1I;VXZ('1Y<&4@;V8@96YT:71I97,@=&\@<F5P
M;&%C90H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@6$U,7U-%4DE!3$E:
M15)?14Y4251)15-?3D].10H@*B`M(%A-3%]315))04Q)6D527T5.5$E42453
M7UA-3"`H9&5F875L="D*("H@+2!834Q?4T5224%,25I%4E]%3E1)5$E%4U]8
M34Q?4D5154E2140*("H@+2!834Q?4T5224%,25I%4E]%3E1)5$E%4U](5$U,
M"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T]05$E/3E]%3E1)5$E%4R<L
M("=R97!L86-E16YT:71I97,G*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@
M=&\@<F5T=7)N('1H92!R97-U;'0@;V8@=&AE('-E<FEA;&EZ871I;VX@9G)O
M;2!S97)I86QI>F4H*0H@*@H@*B!0;W-S:6)L92!V86QU97,Z"B`J("T@=')U
M90H@*B`M(&9A;'-E("AD969A=6QT*0H@*B\*9&5F:6YE*"=834Q?4T5224%,
M25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"<L("=R971U<FY297-U;'0G*3L*
M"B\J*@H@*B!O<'1I;VXZ('=H971H97(@=&\@:6=N;W)E('!R;W!E<G1I97,@
M=&AA="!A<F4@<V5T('1O(&YU;&P*("H*("H@4&]S<VEB;&4@=F%L=65S.@H@
M*B`M('1R=64*("H@+2!F86QS92`H9&5F875L="D*("HO"F1E9FEN92@G6$U,
M7U-%4DE!3$E:15)?3U!424].7TE'3D]215].54Q,)RP@)VEG;F]R94YU;&PG
M*3L*"B\J*@H@*B!O<'1I;VXZ('=H971H97(@=&\@=7-E(&-D871A('-E8W1I
M;VYS(&9O<B!C:&%R86-T97(@9&%T80H@*@H@*B!0;W-S:6)L92!V86QU97,Z
M"B`J("T@=')U90H@*B`M(&9A;'-E("AD969A=6QT*0H@*B\*9&5F:6YE*"=8
M34Q?4T5224%,25I%4E]/4%1)3TY?0T1!5$%?4T5#5$E/3E,G+"`G8V1A=&$G
M*3L*"@HO*BH*("H@9&5F875L="!M;V1E"B`J+PID969I;F4H)UA-3%]315))
M04Q)6D527TU/1$5?1$5&055,5"<L("=D969A=6QT)RD["@HO*BH*("H@4VEM
M<&QE6$U,(&UO9&4*("H*("H@5VAE;B!S97)I86QI>FEN9R!I;F1E>&5D(&%R
M<F%Y<RP@=&AE(&ME>2!O9B!T:&4@<&%R96YT('9A;'5E(&ES('5S960@87,@
M82!T86=N86UE+@H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]-3T1%7U-)
M35!,15A-3"<L("=S:6UP;&5X;6PG*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@(`HO*BH*("H@97)R;W(@8V]D92!F;W(@;F\@<V5R:6%L:7IA=&EO;B!D
M;VYE"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T524D]27TY/7U-%4DE!
M3$E:051)3TXG+"`U,2D["@HO*BH*("H@9&\@;F]T(')E<&QA8V4@96YT:71I
M=&5S"B`J+PID969I;F4H)UA-3%]315))04Q)6D527T5.5$E424537TY/3D4G
M+"!834Q?551)3%]%3E1)5$E%4U].3TY%*3L*"B\J*@H@*B!R97!L86-E(&%L
M;"!834P@96YT:71I=&5S"B`J(%1H:7,@<V5T=&EN9R!W:6QL(')E<&QA8V4@
M/"P@/BP@(BP@)R!A;F0@)@H@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%
M3E1)5$E%4U]834PG+"!834Q?551)3%]%3E1)5$E%4U]834PI.PH*+RHJ"B`J
M(')E<&QA8V4@;VYL>2!R97%U:7)E9"!834P@96YT:71I=&5S"B`J(%1H:7,@
M<V5T=&EN9R!W:6QL(')E<&QA8V4@/"P@(B!A;F0@)@H@*B\*9&5F:6YE*"=8
M34Q?4T5224%,25I%4E]%3E1)5$E%4U]834Q?4D5154E2140G+"!834Q?551)
M3%]%3E1)5$E%4U]834Q?4D5154E2140I.PH*+RHJ"B`J(')E<&QA8V4@2%1-
M3"!E;G1I=&ET97,*("H@0&QI;FL@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VAT
M;6QE;G1I=&EE<PH@*B\*9&5F:6YE*"=834Q?4T5224%,25I%4E]%3E1)5$E%
M4U](5$U,)RP@6$U,7U5424Q?14Y4251)15-?2%1-3"D["@HO*BH*("H@0W)E
M871E<R!834P@9&]C=6UE;G1S(&9R;VT@4$A0(&1A=&$@<W1R=6-T=7)E<R!L
M:6ME(&%R<F%Y<RP@;V)J96-T<R!O<B!S8V%L87)S+@H@*@H@*B!T:&ES(&-L
M87-S(&-A;B!B92!U<V5D(&EN('1W;R!M;V1E<SH*("H*("H@(#$N(&-R96%T
M92!A;B!834P@9&]C=6UE;G0@9G)O;2!A;B!A<G)A>2!O<B!O8FIE8W0@=&AA
M="!I<R!P<F]C97-S960@8GD@;W1H97(*("H@("`@87!P;&EC871I;VYS+B!4
M:&%T(&UE86YS+"!Y;W4@8V%N(&-R96%T92!A(%)$1B!D;V-U;65N="!F<F]M
M(&%N(&%R<F%Y(&EN('1H90H@*B`@("!F;VQL;W=I;F<@9F]R;6%T.@H@*@H@
M*B`@("`D9&%T82`](&%R<F%Y*`H@*B`@("`@("`@("`@("`@)V-H86YN96PG
M(#T^(&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=&ET
M;&4G(#T^("=%>&%M<&QE(%)$1B!C:&%N;F5L)RP*("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)VQI;FLG("`]/B`G:'1T<#HO+W=W=RYP:'`M=&]O
M;',N9&4G+`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G:6UA9V4G
M(#T^(&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G=&ET;&4G(#T^("=%>&%M<&QE(&EM86=E)RP*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W5R;"<@("`]/B`G
M:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4O:6UA9V4N9VEF)RP*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG("`]/B`G
M:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4G"B`J("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("DL"B`J("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=T:71L92<@/3X@)T5X86UP;&4@:71E;2<L"B`J("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)VQI;FLG("`]/B`G:'1T<#HO
M+V5X86UP;&4N8V]M)PH@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("DL"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@(&%R<F%Y*`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=T:71L92<@/3X@
M)T%N;W1H97(@17AA;7!L92!I=&5M)RP*("H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`G;&EN:R<@(#T^("=H='1P.B\O97AA;7!L92YO<F<G
M"B`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*0H@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D*("H@("`@("`@("`@("`@*3L*
M("H*("H@("!T;R!C<F5A=&4@82!21$8@9&]C=6UE;G0@9G)O;2!T:&ES(&%R
M<F%Y(&1O('1H92!F;VQL;W=I;F<Z"B`J"B`J("`@<F5Q=6ER95]O;F-E("=8
M34PO4V5R:6%L:7IE<BYP:'`G.PH@*@H@*B`@("1O<'1I;VYS(#T@87)R87DH
M"B`J("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7TE.1$5.5"`@("`@(#T^(")<="(L("`@("`@("`O+R!I;F1E;G0@=VET:"!T
M86)S"B`J("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!4
M24].7TQ)3D5"4D5!2U,@(#T^(")<;B(L("`@("`@("`O+R!U<V4@54Y)6"!L
M:6YE(&)R96%K<PH@*B`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]23T]47TY!344@("`]/B`G<F1F.E)$1B<L("`@+R\@<F]O
M="!T86<*("H@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?1$5&055,5%]404<@/3X@)VET96TG("`@("`@("\O('1A9R!F;W(@
M=F%L=65S('=I=&@@;G5M97)I8R!K97ES"B`J("`@*3L*("H*("H@("`D<V5R
M:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B`J("`@
M)')D9B`@("`@("`@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1D871A*3L*
M("H*("H@66]U('=I;&P@9V5T(&$@8V]M<&QE=&4@6$U,(&1O8W5M96YT('1H
M870@8V%N(&)E('!R;V-E<W-E9"!L:6ME(&%N>2!21$8@9&]C=6UE;G0N"B`J
M"B`J(#(N('1H:7,@8VQA<W-E<R!C86X@8F4@=7-E9"!T;R!S97)I86QI>F4@
M86YY(&1A=&$@<W1R=6-T=7)E(&EN(&$@=V%Y('1H870@:70@8V%N"B`J("`@
M(&QA=&5R(&)E('5N<V5R:6%L:7IE9"!A9V%I;BX*("H@("`@6$U,7U-E<FEA
M;&EZ97(@=VEL;"!S=&]R92!T:&4@='EP92!O9B!T:&4@=F%L=64@86YD(&%D
M9&ET:6]N86P@;65T82!I;F9O<FUA=&EO;@H@*B`@("!I;B!A='1R:6)U=&5S
M(&]F('1H92!S=7)R;W5N9&EN9R!T86<N(%1H:7,@;65A="!I;F9O<FUA=&EO
M;B!C86X@;&%T97(@8F4@=7-E9`H@*B`@("!T;R!R97-T;W)E('1H92!O<FEG
M:6YA;"!D871A('-T<G5C='5R92!I;B!02%`N($EF('EO=2!W86YT(%A-3%]3
M97)I86QI>F5R"B`J("`@('1O(&%D9"!M971A(&EN9F]R;6%T:6]N('1O('1H
M92!T86=S+"!A9&0*("H*("H@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M5%E014A)3E13(#T^('1R=64*("H*("H@("`@=&\@=&AE(&]P=&EO;G,@87)R
M87D@:6X@=&AE(&-O;G-T<G5C=&]R+@H@*@H@*B!`8V%T96=O<GD@("!834P*
M("H@0'!A8VMA9V4@("`@6$U,7U-E<FEA;&EZ97(*("H@0&%U=&AO<B`@("`@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS92`@("!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@3&EC96YS92`S
M+C`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,"XQ."XP"B`J($!L:6YK("`@
M("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4V5R:6%L:7IE
M<@H@*B!`<V5E("`@("`@("!834Q?56YS97)I86QI>F5R"B`J+PIC;&%S<R!8
M34Q?4V5R:6%L:7IE<B!E>'1E;F1S(%!%05(*>PH@("`O*BH*("`@("H@;&ES
M="!O9B!A;&P@879A:6QA8FQE(&]P=&EO;G,*("`@("H*("`@("H@0&%C8V5S
M<R!P<FEV871E"B`@("`J($!V87(@("`@87)R87D*("`@("HO"B`@("!V87(@
M)%]K;F]W;D]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7TQ)3D5"4D5!2U,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]465!%2$E.5%,L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]834Q?1$5#3%]%3D%"3$5$+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?6$U,7T5.0T]$24Y'
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?1$5&055,5%]404<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]#3$%34TY!345?
M05-?5$%'3D%-12P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415]+15DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]!5%1224)55$5?5%E012P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415]#3$%34RP*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:
M15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$53+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?4%)%
M4$5.1%]!5%1224)55$53+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y47T%45%))0E5415,L
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]-3T1%+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$]#5%E015]%3D%"3$5$+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?1$]#5%E012P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?3D%-12P*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!4
M24].7U)/3U1?05144DE"4RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?2T59+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?0T].5$5.5%]+15DL"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]#3TU-14Y47TM%62P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:
M15)?3U!424].7U1!1TU!4"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?3D%-15-004-%+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?14Y4251)15,L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]215154DY?4D5354Q4+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?24=.3U)%7TY53$PL"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E]#1$%405]314-424].4PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`*("`@+RHJ"B`@("`J(&1E9F%U;'0@;W!T:6]N<R!F
M;W(@=&AE('-E<FEA;&EZ871I;VX*("`@("H*("`@("H@0&%C8V5S<R!P<FEV
M871E"B`@("`J($!V87(@("`@87)R87D*("`@("HO"B`@("!V87(@)%]D969A
M=6QT3W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5"`@("`@("`@("`@("`@(#T^
M("<G+"`@("`@("`@("`@("`@("`@("`@+R\@<W1R:6YG('5S960@9F]R(&EN
M9&5N=&%T:6]N"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?3$E.14)214%+4R`@("`@("`@("`@/3X@(EQN(BP@("`@
M("`@("`@("`@("`@("`O+R!S=')I;F<@=7-E9"!F;W(@;F5W;&EN97,*("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]4
M65!%2$E.5%,@("`@("`@("`@("`]/B!F86QS92P@("`@("`@("`@("`@("`@
M("\O(&%U=&]M871I8V%L;'D@861D('1Y<&4@:&EN(&%T=')I8G5T97,*("`@
M("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]8
M34Q?1$5#3%]%3D%"3$5$("`@("`]/B!F86QS92P@("`@("`@("`@("`@("`@
M("\O(&%D9"!A;B!834P@9&5C;&%R871I;VX*("`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]834Q?14Y#3T1)3D<@("`@
M("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O(&5N8V]D:6YG('-P
M96-I9FEE9"!I;B!T:&4@6$U,(&1E8VQA<F%T:6]N"B`@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404<@
M("`@("`@("`@/3X@)UA-3%]397)I86QI>F5R7U1A9R<L("`O+R!T86<@=7-E
M9"!F;W(@:6YD97AE9"!A<G)A>7,@;W(@:6YV86QI9"!N86UE<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T-,05-3
M3D%-15]!4U]404=.04U%(#T^(&9A;'-E+"`@("`@("`@("`@("`@("`@+R\@
M=7-E(&-L87-S;F%M92!F;W(@;V)J96-T<R!I;B!I;F1E>&5D(&%R<F%Y<PH@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415]+15D@("`@("`@(#T^("=?;W)I9VEN86Q+97DG+"`@("`@
M("`@+R\@871T<FEB=71E('=H97)E(&]R:6=I;F%L(&ME>2!I<R!S=&]R960*
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/
M3E]!5%1224)55$5?5%E012`@("`@("`]/B`G7W1Y<&4G+"`@("`@("`@("`@
M("`@("\O(&%T=')I8G5T92!F;W(@='EP92`H;VYL>2!I9B!T>7!E2&EN=',@
M/3X@=')U92D*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)
M6D527T]05$E/3E]!5%1224)55$5?0TQ!4U,@("`@("`]/B`G7V-L87-S)RP@
M("`@("`@("`@("`@("\O(&%T=')I8G5T92!F;W(@8VQA<W,@;V8@;V)J96-T
M<R`H;VYL>2!I9B!T>7!E2&EN=',@/3X@=')U92D*("`@("`@("`@("`@("`@
M("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?0514
M4DE"551%4R`]/B!F86QS92P@("`@("`@("`@("`@("`@("\O('-C86QA<B!V
M86QU97,@*'-T<FEN9W,L(&EN=',L+BXI('=I;&P@8F4@<V5R:6%L:7IE9"!A
M<R!A='1R:6)U=&4*("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))
M04Q)6D527T]05$E/3E]04D5014Y$7T%45%))0E5415,@("`]/B`G)RP@("`@
M("`@("`@("`@("`@("`@("\O('!R97!E;F0@<W1R:6YG(&9O<B!A='1R:6)U
M=&5S"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?24Y$14Y47T%45%))0E5415,@("`@/3X@9F%L<V4L("`@("`@("`@
M("`@("`@("`O+R!I;F1E;G0@=&AE(&%T=')I8G5T97,L(&EF('-E="!T;R`G
M7V%U=&\G+"!I="!W:6QL(&EN9&5N="!A='1R:6)U=&5S('-O('1H97D@86QL
M('-T87)T(&%T('1H92!S86UE(&-O;'5M;@H@("`@("`@("`@("`@("`@("`@
M("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$4@("`@("`@("`@("`@
M("`@(#T^(%A-3%]315))04Q)6D527TU/1$5?1$5&055,5"P@("`@("`@("`@
M("`@+R\@=7-E(%A-3%]315))04Q)6D527TU/1$5?4TE-4$Q%6$U,('1O('5S
M92!P87)E;G0@;F%M92!A<R!T86=N86UE(&EF('1R86YS9F]R;6EN9R!A;B!I
M;F1E>&5D(&%R<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T52
M24%,25I%4E]/4%1)3TY?1$]#5%E015]%3D%"3$5$("`@("`@/3X@9F%L<V4L
M("`@("`@("`@("`@("`@("`O+R!A9&0@82!D;V-T>7!E(&1E8VQA<F%T:6]N
M"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?1$]#5%E012`@("`@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@
M("`@("`O+R!S=7!P;'D@82!S=')I;F<@;W(@86X@87)R87D@=VET:"!I9"!A
M;F0@=7)I("A[0'-E92!834Q?571I;#HZ9V5T1&]C='EP941E8VQA<F%T:6]N
M*"E]"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?4D]/5%].04U%("`@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@
M("`@("`@("`O+R!N86UE(&]F('1H92!R;V]T('1A9PH@("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?05144DE"
M4R`@("`@("`@(#T^(&%R<F%Y*"DL("`@("`@("`@("`@("`@+R\@871T<FEB
M=71E<R!O9B!T:&4@<F]O="!T86<*("`@("`@("`@("`@("`@("`@("`@("`@
M(%A-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$537TM%62`@("`@("`]
M/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O(&%L;"!V86QU97,@:6X@=&AI
M<R!K97D@=VEL;"!B92!T<F5A=&5D(&%S(&%T=')I8G5T97,*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]#3TY414Y4
M7TM%62`@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O('1H
M:7,@=F%L=64@=VEL;"!B92!U<V5D(&1I<F5C=&QY(&%S(&-O;G1E;G0L(&EN
M<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G+"!M87D@;VYL>2!B92!U<V5D
M(&EN(&-O;FIU8W1I;VX@=VET:"!A='1R:6)U=&5S07)R87D*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]#3TU-14Y4
M7TM%62`@("`@("`@("`]/B!N=6QL+"`@("`@("`@("`@("`@("`@("\O('1H
M:7,@=F%L=64@=VEL;"!B92!U<V5D(&1I<F5C=&QY(&%S(&-O;6UE;G0L(&EN
M<W1E860@;V8@8W)E871I;F<@82!N97<@=&%G+"!M87D@;VYL>2!B92!U<V5D
M(&EN(&-O;FIU8W1I;VX@=VET:"!A='1R:6)U=&5S07)R87D*("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]404=-05`@
M("`@("`@("`@("`@("`]/B!A<G)A>2@I+"`@("`@("`@("`@("`@("\O('1A
M9R!N86UE<R!T:&%T('=I;&P@8F4@8VAA;F=E9`H@("`@("`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#("`@
M("`@("`@(#T^(&YU;&PL("`@("`@("`@("`@("`@("`@+R\@9G5N8W1I;VX@
M=&AA="!W:6QL(&)E(&%P<&QI960@8F5F;W)E('-E<FEA;&EZ:6YG"B`@("`@
M("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?3D%-
M15-004-%("`@("`@("`@("`@/3X@;G5L;"P@("`@("`@("`@("`@("`@("`O
M+R!N86UE<W!A8V4@=&\@=7-E"B`@("`@("`@("`@("`@("`@("`@("`@("!8
M34Q?4T5224%,25I%4E]/4%1)3TY?14Y4251)15,@("`@("`@("`@("`@/3X@
M6$U,7U-%4DE!3$E:15)?14Y4251)15-?6$U,+"`O+R!T>7!E(&]F(&5N=&ET
M:65S('1O(')E<&QA8V4L"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?
M4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"`@("`@("`@/3X@9F%L
M<V4L("`@("`@("`@("`@("`@("`O+R!S97)I86QI>F4H*2!R971U<FYS('1H
M92!R97-U;'0@;V8@=&AE('-E<FEA;&EZ871I;VX@:6YS=&5A9"!O9B!T<G5E
M"B`@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)
M3TY?24=.3U)%7TY53$P@("`@("`@("`@/3X@9F%L<V4L("`@("`@("`@("`@
M("`@("`O+R!I9VYO<F4@<')O<&5R=&EE<R!T:&%T(&%R92!S970@=&\@;G5L
M;`H@("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!4
M24].7T-$051!7U-%0U1)3TY3("`@("`@(#T^(&9A;'-E("`@("`@("`@("`@
M("`@("`@+R\@5VAE=&AE<B!T;R!U<V4@8V1A=&$@<V5C=&EO;G,@9F]R('!L
M86EN(&-H87)A8W1E<B!D871A"B`@("`@("`@("`@("`@("`@("`@("`@("D[
M"@H@("`O*BH*("`@("H@;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX*
M("`@("H*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("H@0'9A<B`@("!A<G)A
M>0H@("`@*B\*("`@('9A<B`D;W!T:6]N<R`](&%R<F%Y*"D["@H@("`O*BH*
M("`@("H@8W5R<F5N="!T86<@9&5P=&@*("`@("H*("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`J($!V87(@("`@:6YT96=E<@H@("`@*B\*("`@('9A<B`D
M7W1A9T1E<'1H(#T@,#L*"B`@("\J*@H@("`@*B!S97)I;&EA;&EZ960@<F5P
M<F5S96YT871I;VX@;V8@=&AE(&1A=&$*("`@("H*("`@("H@0&%C8V5S<R!P
M<FEV871E"B`@("`J($!V87(@("`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1?
M<V5R:6%L:7IE9$1A=&$@/2!N=6QL.PH@("`@"B`@("\J*@H@("`@*B!C;VYS
M=')U8W1O<@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!P
M87)A;2`@("!M:7AE9"`@("1O<'1I;VYS("`@(&%R<F%Y(&-O;G1A:6YI;F<@
M;W!T:6]N<R!F;W(@=&AE('-E<FEA;&EZ871I;VX*("`@("HO"B`@("!F=6YC
M=&EO;B!834Q?4V5R:6%L:7IE<B@@)&]P=&EO;G,@/2!N=6QL("D*("`@('L*
M("`@("`@("`D=&AI<RT^4$5!4B@I.PH@("`@("`@(&EF("AI<U]A<G)A>2@D
M;W!T:6]N<RDI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2!A<G)A
M>5]M97)G92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS+"`D;W!T:6]N<RD["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D
M=&AI<RT^7V1E9F%U;'1/<'1I;VYS.PH@("`@("`@('T*("`@('T*"B`@("\J
M*@H@("`@*B!R971U<FX@05!)('9E<G-I;VX*("`@("H*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PH@("`@*B!`<W1A=&EC"B`@("`J($!R971U<FX@("!S=')I
M;F<@("1V97)S:6]N($%022!V97)S:6]N"B`@("`J+PH@("`@9G5N8W1I;VX@
M87!I5F5R<VEO;B@I"B`@("!["B`@("`@("`@<F5T=7)N("<P+C$X+C`G.PH@
M("`@?0H*("`@+RHJ"B`@("`J(')E<V5T(&%L;"!O<'1I;VYS('1O(&1E9F%U
M;'0@;W!T:6]N<PH@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J
M($!S964@("`@("!S971/<'1I;VXH*2P@6$U,7U-E<FEA;&EZ97(H*0H@("`@
M*B\*("`@(&9U;F-T:6]N(')E<V5T3W!T:6]N<R@I"B`@("!["B`@("`@("`@
M)'1H:7,M/F]P=&EO;G,@/2`D=&AI<RT^7V1E9F%U;'1/<'1I;VYS.PH@("`@
M?0H*("`@+RHJ"B`@("`J('-E="!A;B!O<'1I;VX*("`@("H*("`@("H@66]U
M(&-A;B!U<V4@=&AI<R!M971H;V0@:68@>6]U(&1O(&YO="!W86YT('1O('-E
M="!A;&P@;W!T:6]N<R!I;B!T:&4@8V]N<W1R=6-T;W(*("`@("H*("`@("H@
M0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@<F5S971/<'1I;VXH
M*2P@6$U,7U-E<FEA;&EZ97(H*0H@("`@*B\*("`@(&9U;F-T:6]N('-E=$]P
M=&EO;B@D;F%M92P@)'9A;'5E*0H@("`@>PH@("`@("`@("1T:&ES+3YO<'1I
M;VYS6R1N86UE72`]("1V86QU93L*("`@('T*("`@(`H@("`O*BH*("`@("H@
M<V5T<R!S979E<F%L(&]P=&EO;G,@870@;VYC90H@("`@*@H@("`@*B!9;W4@
M8V%N('5S92!T:&ES(&UE=&AO9"!I9B!Y;W4@9&\@;F]T('=A;G0@=&\@<V5T
M(&%L;"!O<'1I;VYS(&EN('1H92!C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`
M86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!R97-E=$]P=&EO;B@I
M+"!834Q?56YS97)I86QI>F5R*"DL('-E=$]P=&EO;B@I"B`@("`J+PH@("`@
M9G5N8W1I;VX@<V5T3W!T:6]N<R@D;W!T:6]N<RD*("`@('L*("`@("`@("`D
M=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YO<'1I;VYS+"`D
M;W!T:6]N<RD["B`@("!]"@H@("`O*BH*("`@("H@<V5R:6%L:7IE(&1A=&$*
M("`@("H*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`<&%R86T@("`@
M;6EX960@("`@)&1A=&$@9&%T82!T;R!S97)I86QI>F4*("`@("H@0')E='5R
M;B`@(&)O;VQE86X@('1R=64@;VX@<W5C8V5S<RP@<&5A<B!E<G)O<B!O;B!F
M86EL=7)E"B`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"1D871A+"`D
M;W!T:6]N<R`](&YU;&PI"B`@("!["B`@("`@("`@+R\@:68@;W!T:6]N<R!H
M879E(&)E96X@<W!E8VEF:65D+"!U<V4@=&AE;2!I;G-T96%D"B`@("`@("`@
M+R\@;V8@=&AE('!R979I;W5S;'D@9&5F:6YE9"!O;F5S"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1O<'1I;VYS*2D@>PH@("`@("`@("`@("`D;W!T:6]N<T)A
M:R`]("1T:&ES+3YO<'1I;VYS.PH@("`@("`@("`@("!I9B`H:7-S970H)&]P
M=&EO;G-;)V]V97)R:61E3W!T:6]N<R==*2`F)B`D;W!T:6]N<ULG;W9E<G)I
M9&5/<'1I;VYS)UT@/3T@=')U92D@>PH@("`@("`@("`@("`@("`@)'1H:7,M
M/F]P=&EO;G,@/2!A<G)A>5]M97)G92@D=&AI<RT^7V1E9F%U;'1/<'1I;VYS
M+"`D;W!T:6]N<RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D=&AI<RT^;W!T:6]N<R`](&%R<F%Y7VUE<F=E*"1T:&ES+3YO<'1I
M;VYS+"`D;W!T:6]N<RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D;W!T:6]N<T)A:R`](&YU;&P["B`@("`@("`@?0H@
M("`@("`@(`H@("`@("`@("\O("!S=&%R="!D97!T:"!I<R!Z97)O"B`@("`@
M("`@)'1H:7,M/E]T86=$97!T:"`](#`["@H@("`@("`@("1R;V]T071T<FEB
M=71E<R`]("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]2
M3T]47T%45%))0E-=.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N
M<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-004-%72D@)B8@:7-?87)R
M87DH)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TY!3453
M4$%#15TI*2!["B`@("`@("`@"21R;V]T071T<FEB=71E<ULG>&UL;G,Z)RXD
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-004-%
M75LP75T@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M3D%-15-004-%75LQ73L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@)'1H
M:7,M/E]S97)I86QI>F5D1&%T82`]("<G.PH@("`@("`@("\O('-E<FEA;&EZ
M92!A;B!A<G)A>0H@("`@("`@(&EF("AI<U]A<G)A>2@D9&%T82DI('L*("`@
M("`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)
M6D527T]05$E/3E]23T]47TY!345=*2D@>PH@("`@("`@("`@("`@("`@)'1A
M9TYA;64@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M4D]/5%].04U%73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T86=.86UE(#T@)V%R<F%Y)SL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`N/2`D=&AI<RT^7W-E<FEA
M;&EZ94%R<F%Y*"1D871A+"`D=&%G3F%M92P@)')O;W1!='1R:6)U=&5S*3L*
M("`@("`@("!](&5L<V5I9B`H:7-?;V)J96-T*"1D871A*2D@>PH@("`@("`@
M("`@("`O+R!S97)I86QI>F4@86X@;V)J96-T"B`@("`@("`@("`@(&EF("AI
M<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?4D]/
M5%].04U%72DI('L*("`@("`@("`@("`@("`@("1T86=.86UE(#T@)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?3D%-15T["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D=&%G3F%M92`]
M(&=E=%]C;&%S<R@D9&%T82D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M)'1H:7,M/E]S97)I86QI>F5D1&%T82`N/2`D=&AI<RT^7W-E<FEA;&EZ94]B
M:F5C="@D9&%T82P@)'1A9TYA;64L("1R;V]T071T<FEB=71E<RD["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@)'1A9R`](&%R<F%Y*"D["B`@("`@
M("`@("`@(&EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?4D]/5%].04U%72DI('L*("`@("`@("`@("`@("`@("1T86=;
M)W%N86UE)UT@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?4D]/5%].04U%73L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("1T86=;)W%N86UE)UT@/2!G971T>7!E*"1D871A*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7U194$5(24Y44UT@/3T]('1R=64I('L*("`@("`@
M("`@("`@("`@("1R;V]T071T<FEB=71E<ULD=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?05144DE"551%7U194$5=72`](&=E='1Y<&4H
M)&1A=&$I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@($!S971T>7!E*"1D
M871A+"`G<W1R:6YG)RD["B`@("`@("`@("`@("1T86=;)V-O;G1E;G0G72`@
M("`]("1D871A.PH@("`@("`@("`@("`D=&%G6R=A='1R:6)U=&5S)UT@/2`D
M<F]O=$%T=')I8G5T97,["B`@("`@("`@("`@("1T:&ES+3Y?<V5R:6%L:7IE
M9$1A=&$@/2`D=&AI<RT^7V-R96%T95A-3%1A9R@D=&%G*3L*("`@("`@("!]
M"B`@("`@("`@"B`@("`@("`@+R\@861D(&1O8W1Y<&4@9&5C;&%R871I;VX*
M("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!4
M24].7T1/0U194$5?14Y!0DQ%1%T@/3T]('1R=64I('L*("`@("`@("`@("`@
M)'1H:7,M/E]S97)I86QI>F5D1&%T82`](%A-3%]5=&EL.CIG971$;V-T>7!E
M1&5C;&%R871I;VXH)'1A9TYA;64L("1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]$3T-465!%72D*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E],24Y%0E)%04M370H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)'1H:7,M/E]S97)I86QI>F5D1&%T83L*("`@("`@("!]
M"@H@("`@("`@("\O("!B=6EL9"!X;6P@9&5C;&%R871I;VX*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7UA-3%]$
M14-,7T5.04),141=*2!["B`@("`@("`@("`@("1A='1S(#T@87)R87DH*3L*
M("`@("`@("`@("`@)'1H:7,M/E]S97)I86QI>F5D1&%T82`](%A-3%]5=&EL
M.CIG971834Q$96-L87)A=&EO;B@G,2XP)RP@)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7UA-3%]%3D-/1$E.1UTI"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4UT*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$[
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%
M4DE!3$E:15)?3U!424].7U)%5%523E]215-53%1=(#T]/2!T<G5E*2!["B`@
M("`@("`@"21R97-U;'0@/2`D=&AI<RT^7W-E<FEA;&EZ961$871A.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R97-U;'0@/2!T<G5E.PH@("`@
M("`@('T*("`@("`@("`*("`@("`@("!I9B`H)&]P=&EO;G-"86L@(3T](&YU
M;&PI('L*("`@("`@("`@("`@)'1H:7,M/F]P=&EO;G,@/2`D;W!T:6]N<T)A
M:SL*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@?0H*
M("`@+RHJ"B`@("`J(&=E="!T:&4@<F5S=6QT(&]F('1H92!S97)I86QI>F%T
M:6]N"B`@("`J"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J($!R971U<FX@
M<W1R:6YG('-E<FEA;&EZ960@6$U,"B`@("`J+PH@("`@9G5N8W1I;VX@9V5T
M4V5R:6%L:7IE9$1A=&$H*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^7W-E
M<FEA;&EZ961$871A(#T](&YU;&PI('L*("`@("`@("`@("`@<F5T=7)N("`D
M=&AI<RT^<F%I<V5%<G)O<B@G3F\@<V5R:6%L:7IE9"!D871A(&%V86EL86)L
M92X@57-E(%A-3%]397)I86QI>F5R.CIS97)I86QI>F4H*2!F:7)S="XG+"!8
M34Q?4T5224%,25I%4E]%4E)/4E].3U]315))04Q)6D%424].*3L*("`@("`@
M("!]"B`@("`@("`@<F5T=7)N("1T:&ES+3Y?<V5R:6%L:7IE9$1A=&$["B`@
M("!]"B`@("`*("`@+RHJ"B`@("`J('-E<FEA;&EZ92!A;GD@=F%L=64*("`@
M("H*("`@("H@5&AI<R!M971H;V0@8VAE8VMS(&9O<B!T:&4@='EP92!O9B!T
M:&4@=F%L=64@86YD(&-A;&QS('1H92!A<'!R;W!R:6%T92!M971H;V0*("`@
M("H*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J($!P87)A;2`@;6EX960@
M("`@("1V86QU90H@("`@*B!`<&%R86T@('-T<FEN9R`@("`D=&%G3F%M90H@
M("`@*B!`<&%R86T@(&%R<F%Y("`@("`D871T<FEB=71E<PH@("`@*B!`<F5T
M=7)N('-T<FEN9PH@("`@*B\*("`@(&9U;F-T:6]N(%]S97)I86QI>F5686QU
M92@D=F%L=64L("1T86=.86UE(#T@;G5L;"P@)&%T=')I8G5T97,@/2!A<G)A
M>2@I*0H@("`@>PH@("`@("`@(&EF("AI<U]A<G)A>2@D=F%L=64I*2!["B`@
M("`@("`@("`@("1X;6P@/2`D=&AI<RT^7W-E<FEA;&EZ94%R<F%Y*"1V86QU
M92P@)'1A9TYA;64L("1A='1R:6)U=&5S*3L*("`@("`@("!](&5L<V5I9B`H
M:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@("`@)'AM;"`]("1T:&ES
M+3Y?<V5R:6%L:7IE3V)J96-T*"1V86QU92P@)'1A9TYA;64I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1T86<@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@("`@("`@("`G<6YA;64G("`@("`@/3X@)'1A9TYA;64L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^("1A='1R
M:6)U=&5S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("=C;VYT96YT)R`@
M("`]/B`D=F%L=64*("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@
M("`@("`@)'AM;"`]("1T:&ES+3Y?8W)E871E6$U,5&%G*"1T86<I.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@)'AM;#L*("`@('T*("`@(`H@("`O*BH*
M("`@("H@<V5R:6%L:7IE(&%N(&%R<F%Y"B`@("`J"B`@("`J($!A8V-E<W,@
M("!P<FEV871E"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1A<G)A>2`@("`@
M("!A<G)A>2!T;R!S97)I86QI>F4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M)'1A9TYA;64@("`@(&YA;64@;V8@=&AE(')O;W0@=&%G"B`@("`J($!P87)A
M;2`@("!A<G)A>2`@("1A='1R:6)U=&5S("!A='1R:6)U=&5S(&9O<B!T:&4@
M<F]O="!T86<*("`@("H@0')E='5R;B`@('-T<FEN9R`@)'-T<FEN9R`@("`@
M('-E<FEA;&EZ960@9&%T80H@("`@*B!`=7-E<R`@("`@6$U,7U5T:6PZ.FES
M5F%L:61.86UE*"D@=&\@8VAE8VLL('=H971H97(@:V5Y(&AA<R!T;R!B92!S
M=6)S=&ET=71E9`H@("`@*B\*("`@(&9U;F-T:6]N(%]S97)I86QI>F5!<G)A
M>2@F)&%R<F%Y+"`D=&%G3F%M92`](&YU;&PL("1A='1R:6)U=&5S(#T@87)R
M87DH*2D*("`@('L*("`@("`@("`D7V-O;G1E;G0@/2!N=6QL.PH@("`@("`@
M("1?8V]M;65N="`](&YU;&P["@H@("`@("`@("\O(&-H96-K(&9O<B!C;VUM
M96YT"B`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D52
M7T]05$E/3E]#3TU-14Y47TM%65T@(3T](&YU;&PI('L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?0T]-345.5%]+15E=72DI('L*("`@("`@("`@("`@("`@("1?
M8V]M;65N="`]("1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?0T]-345.5%]+15E=73L*("`@("`@("`@("`@("`@('5N<V5T
M*"1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M0T]-345.5%]+15E=72D["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@"B`@("`@("`@+RHJ"B`@("`@("`@("H@8VAE8VL@9F]R('-P96-I86P@
M871T<FEB=71E<PH@("`@("`@("`J+PH@("`@("`@(&EF("@D=&AI<RT^;W!T
M:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]+15E=("$]
M/2!N=6QL*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D87)R87E;)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415-?2T59
M75TI*2!["B`@("`@("`@("`@("`@("`D871T<FEB=71E<R`]("1A<G)A>5LD
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%
M4U]+15E=73L*("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]+15E=
M72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@+RHJ"B`@("`@("`@("`@
M("`J(&-H96-K(&9O<B!S<&5C:6%L(&-O;G1E;G0*("`@("`@("`@("`@("HO
M"B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?0T].5$5.5%]+15E=("$]/2!N=6QL*2!["B`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)&%R<F%Y6R1T:&ES+3YO<'1I;VYS6UA-3%]315))
M04Q)6D527T]05$E/3E]#3TY414Y47TM%65U=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1?8V]N=&5N="`]("1A<G)A>5LD=&AI<RT^;W!T:6]N<UM834Q?
M4T5224%,25I%4E]/4%1)3TY?0T].5$5.5%]+15E=73L*("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D87)R87E;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7T-/3E1%3E1?2T5975TI.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H:7,M
M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE'3D]215].54Q,72`]
M/3T@=')U92D@>PH@("`@("`@(`EF;W)E86-H("AA<G)A>5]K97ES*"1A<G)A
M>2D@87,@)&ME>2D@>PH@("`@("`@(`D):68@*&ES7VYU;&PH)&%R<F%Y6R1K
M97E=*2D@>PH@("`@("`@(`D)"75N<V5T*"1A<G)A>5LD:V5Y72D["B`@("`@
M("`@"0E]"B`@("`@("`@"7T*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@
M("`@*B!I9B!M;V1E(&ES('-E="!T;R!S:6UP;&5834PL(&-H96-K('=H971H
M97(*("`@("`@("`J('1H92!A<G)A>2!I<R!A<W-O8VEA=&EV92!O<B!I;F1E
M>&5D"B`@("`@("`@*B\*("`@("`@("!I9B`H:7-?87)R87DH)&%R<F%Y*2`F
M)B`A96UP='DH)&%R<F%Y*2`F)B`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,
M25I%4E]/4%1)3TY?34]$15T@/3T@6$U,7U-%4DE!3$E:15)?34]$15]324U0
M3$5834PI('L*("`@("`@("`@("`@)&EN9&5X960@/2!T<G5E.PH@("`@("`@
M("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L*2!["B`@("`@
M("`@("`@("`@("!I9B`H(6ES7VEN="@D:V5Y*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1I;F1E>&5D(#T@9F%L<V4["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&EF("@D:6YD97AE9"`F)B`D=&AI<RT^;W!T:6]N<UM834Q?4T52
M24%,25I%4E]/4%1)3TY?34]$15T@/3T@6$U,7U-%4DE!3$E:15)?34]$15]3
M24U03$5834PI('L*("`@("`@("`@("`@("`@("1S=')I;F<@/2`G)SL*("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1A<G)A>2!A<R`D:V5Y(#T^("1V86PI
M('L*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG("X]("1T:&ES+3Y?<V5R
M:6%L:7IE5F%L=64H("1V86PL("1T86=.86UE+"`D871T<FEB=71E<RD["B`@
M("`@("`@("`@("`@("`@("`@"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN
M9R`N/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3$E.
M14)214%+4UT["B`@("`@("`@("`@("`@("`@("`@+R\@9&\@:6YD96YT871I
M;VX*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P=&EO;G-;6$U,
M7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TA/3UN=6QL("8F("1T:&ES+3Y?
M=&%G1&5P=&@^,"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG
M("X]('-T<E]R97!E870H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?
M3U!424].7TE.1$5.5%TL("1T:&ES+3Y?=&%G1&5P=&@I.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(')E='5R;B!R=')I;2@D<W1R:6YG*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("`*("`@("`@("`D<V-A;&%R07-!='1R:6)U=&5S(#T@9F%L
M<V4["B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YO<'1I;VYS6UA-3%]3
M15))04Q)6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4UTI("8F(&ES
M<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]30T%,
M05)?05-?05144DE"551%4UU;)'1A9TYA;65=*2D@>PH@("`@("`@("`@("`D
M<V-A;&%R07-!='1R:6)U=&5S(#T@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$5375LD=&%G3F%M95T[
M"B`@("`@("`@?2!E;'-E:68@*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)
M6D527T]05$E/3E]30T%,05)?05-?05144DE"551%4UT@/3T]('1R=64I('L*
M("`@("`@("`@("`@)'-C86QA<D%S071T<FEB=71E<R`]('1R=64["B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@(&EF("@D<V-A;&%R07-!='1R:6)U=&5S
M(#T]/2!T<G5E*2!["B`@("`@("`@("`@("1T:&ES+3YE>'!E8W1%<G)O<B@G
M*B<I.PH@("`@("`@("`@("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D
M=F%L=64I('L*("`@("`@("`@("`@("`@(&EF("AI<U]S8V%L87(H)'9A;'5E
M*2`F)B`H6$U,7U5T:6PZ.FES5F%L:61.86UE*"1K97DI(#T]/2!T<G5E*2D@
M>PH@("`@("`@("`@("`@("`@("`@('5N<V5T*"1A<G)A>5LD:V5Y72D["B`@
M("`@("`@("`@("`@("`@("`@)&%T=')I8G5T97-;)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7U!215!%3D1?05144DE"551%4UTN)&ME
M>5T@/2`D=F%L=64["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@)'1H:7,M/G!O<$5X<&5C="@I.PH@("`@("`@('T@96QS
M96EF("AI<U]A<G)A>2@D<V-A;&%R07-!='1R:6)U=&5S*2D@>PH@("`@("`@
M("`@("`D=&AI<RT^97AP96-T17)R;W(H)RHG*3L*("`@("`@("`@("`@9F]R
M96%C:"`H)'-C86QA<D%S071T<FEB=71E<R!A<R`D:V5Y*2!["B`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1A<G)A>5LD:V5Y72DI('L*("`@("`@("`@
M("`@("`@("`@("!C;VYT:6YU93L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("1V86QU92`]("1A<G)A>5LD:V5Y73L*("`@("`@("`@("`@
M("`@(&EF("AI<U]S8V%L87(H)'9A;'5E*2`F)B`H6$U,7U5T:6PZ.FES5F%L
M:61.86UE*"1K97DI(#T]/2!T<G5E*2D@>PH@("`@("`@("`@("`@("`@("`@
M('5N<V5T*"1A<G)A>5LD:V5Y72D["B`@("`@("`@("`@("`@("`@("`@)&%T
M=')I8G5T97-;)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].
M7U!215!%3D1?05144DE"551%4UTN)&ME>5T@/2`D=F%L=64["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H:7,M/G!O
M<$5X<&5C="@I.PH@("`@("`@('T*"B`@("`@("`@+R\@8VAE8VL@9F]R(&5M
M<'1Y(&%R<F%Y(#T^(&-R96%T92!E;7!T>2!T86<*("`@("`@("!I9B`H96UP
M='DH)&%R<F%Y*2D@>PH@("`@("`@("`@("`D=&%G(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G<6YA;64G("`@("`@/3X@)'1A9TYA
M;64L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G8V]N=&5N="<@("`@
M/3X@)%]C;VYT96YT+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T
M=')I8G5T97,G(#T^("1A='1R:6)U=&5S"B`@("`@("`@("`@("`@("`@("`@
M("`@("D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/E]T
M86=$97!T:"LK.PH@("`@("`@("`@("`D=&UP(#T@)'1H:7,M/F]P=&EO;G-;
M6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U-=.PH@("`@("`@("`@
M("!F;W)E86-H("@D87)R87D@87,@)&ME>2`]/B`D=F%L=64I('L*("`@("`@
M("`@("`@("`@("\O(&1O(&EN9&5N=&%T:6]N"B`@("`@("`@("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5%TA/3UN=6QL("8F("1T:&ES+3Y?=&%G1&5P=&@^,"D@>PH@("`@("`@("`@
M("`@("`@("`@("1T;7`@+CT@<W1R7W)E<&5A="@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y472P@)'1H:7,M/E]T86=$97!T
M:"D["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]404=-
M05!=6R1K97E=*2D@>PH@("`@("`@("`@("`@("`@("`@("1K97D@/2`D=&AI
M<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?5$%'34%075LD:V5Y
M73L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`O+R!C;W!Y
M(&ME>0H@("`@("`@("`@("`@("`@)&]R:6=+97D@/2`D:V5Y.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/F5X<&5C=$5R<F]R*"<J)RD["B`@("`@("`@("`@
M("`@("`O+R!K97D@8V%N;F]T(&)E('5S960@87,@=&%G;F%M92`]/B!U<V4@
M9&5F875L="!T86<*("`@("`@("`@("`@("`@("1V86QI9"`](%A-3%]5=&EL
M.CII<U9A;&ED3F%M92@D:V5Y*3L*("`@("`@("`@("`@("`@("1T:&ES+3YP
M;W!%>'!E8W0H*3L*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R<F]R
M*"1V86QI9"DI('L*("`@("`@("`@("`@("`@("`@("!I9B`H)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T-,05-33D%-15]!4U]404=.
M04U%72`F)B!I<U]O8FIE8W0H)'9A;'5E*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:V5Y(#T@9V5T7V-L87-S*"1V86QU92D["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@)&ME
M>2`]("1T:&ES+3Y?9V5T1&5F875L=%1A9VYA;64H)'1A9TYA;64I.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("1A='1S(#T@87)R87DH*3L*("`@("`@("`@("`@("`@(&EF("@D
M=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13
M72`]/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@("1A='1S6R1T:&ES
M+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?5%E0
M15U=(#T@9V5T='EP92@D=F%L=64I.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D:V5Y("$]/2`D;W)I9TME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`D871T<ULD=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?
M05144DE"551%7TM%65U=(#T@*'-T<FEN9RDD;W)I9TME>3L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@
M("`@)'1M<"`N/2`D=&AI<RT^7V-R96%T95A-3%1A9RAA<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("=Q;F%M92<@("`@("`]/B`D:V5Y+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V%T=')I8G5T97,G(#T^
M("1A='1S+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)V-O;G1E;G0G("`@(#T^("1V86QU92`I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`@("`@("`@("1T;7`@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!
M3$E:15)?3U!424].7TQ)3D5"4D5!2U-=.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(`H@("`@("`@("`@("`D=&AI<RT^7W1A9T1E<'1H+2T["B`@("`@
M("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?24Y$14Y472$]/6YU;&P@)B8@)'1H:7,M/E]T86=$97!T:#XP*2!["B`@
M("`@("`@("`@("`@("`D=&UP("X]('-T<E]R97!E870H)'1H:7,M/F]P=&EO
M;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.5%TL("1T:&ES+3Y?=&%G
M1&5P=&@I.PH@("`@("`@("`@("!]"B`@("`*("`@("`@("`@("`@:68@*'1R
M:6TH)'1M<"D@/3T]("<G*2!["B`@("`@("`@("`@("`@("`D=&UP(#T@;G5L
M;#L*("`@("`@("`@("`@?0H@("`@("`@("`@("`*("`@("`@("`@("`@)'1A
M9R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("=Q;F%M92<@
M("`@("`]/B`D=&%G3F%M92P*("`@("`@("`@("`@("`@("`@("`@("`@("`G
M8V]N=&5N="<@("`@/3X@)'1M<"P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`G871T<FEB=71E<R<@/3X@)&%T=')I8G5T97,*("`@("`@("`@("`@("`@
M("`@("`@("`@*3L*("`@("`@("!]"B`@("`@("`@:68@*"1T:&ES+3YO<'1I
M;VYS6UA-3%]315))04Q)6D527T]05$E/3E]465!%2$E.5%-=(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@(&EF("@A:7-S970H)'1A9ULG871T<FEB=71E<R==
M6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!5%1224)5
M5$5?5%E015U=*2D@>PH@("`@("`@("`@("`@("`@)'1A9ULG871T<FEB=71E
M<R==6R1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!5%12
M24)55$5?5%E015U=(#T@)V%R<F%Y)SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)'-T<FEN9R`]("<G.PH@("`@("`@(&EF("@A:7-?;G5L
M;"@D7V-O;6UE;G0I*2!["B`@("`@("`@"21S=')I;F<@+CT@6$U,7U5T:6PZ
M.F-R96%T94-O;6UE;G0H)%]C;VUM96YT*3L*("`@("`@("`))'-T<FEN9R`N
M/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)2
M14%+4UT["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T52
M24%,25I%4E]/4%1)3TY?24Y$14Y472$]/6YU;&P@)B8@)'1H:7,M/E]T86=$
M97!T:#XP*2!["B`@("`@("`@("`@("`@("`D<W1R:6YG("X]('-T<E]R97!E
M870H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5%TL("1T:&ES+3Y?=&%G1&5P=&@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@("1S=')I;F<@+CT@)'1H:7,M/E]C<F5A=&5834Q486<H)'1A
M9RP@9F%L<V4I.PH@("`@("`@(')E='5R;B`D<W1R:6YG.PH@("`@?0H*("`@
M+RHJ"B`@("`J(&=E="!T:&4@;F%M92!O9B!T:&4@9&5F875L="!T86<N"B`@
M("`J"B`@("`J(%1H92!N86UE(&]F('1H92!P87)E;G0@=&%G(&YE961S('1O
M(&)E('!A<W-E9"!A<R!T:&4*("`@("H@9&5F875L="!N86UE(&-A;B!D97!E
M;F0@;VX@=&AE(&-O;G1E>'0N"B`@("`J"B`@("`J($!P87)A;2`@<W1R:6YG
M("`@("!N86UE(&]F('1H92!P87)E;G0@=&%G"B`@("`J($!R971U<FX@<W1R
M:6YG("`@("!D969A=6QT('1A9R!N86UE"B`@("`J+PH@("`@9G5N8W1I;VX@
M7V=E=$1E9F%U;'1486=N86UE*"1P87)E;G0I"B`@("!["B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?1$5&055,5%]404==*2D@>PH@("`@("`@(`ER971U<FX@)'1H:7,M/F]P
M=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T1%1D%53%1?5$%'73L*("`@
M("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1T:&ES+3YO<'1I;VYS6UA-3%]3
M15))04Q)6D527T]05$E/3E]$149!54Q47U1!1UU;)'!A<F5N=%TI*2!["B`@
M("`@("`@("`@(')E='5R;B`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?1$5&055,5%]404==6R1P87)E;G1=.PH@("`@("`@('T@96QS
M96EF("AI<W-E="@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)
M3TY?1$5&055,5%]404==6R<C9&5F875L="==*2D@>PH@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T1%
M1D%53%1?5$%'75LG(V1E9F%U;'0G73L*("`@("`@("!](&5L<V5I9B`H:7-S
M970H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T1%1D%5
M3%1?5$%'75LG7U]D969A=6QT)UTI*2!["B`@("`@("`@("`@("\O(&ME97`@
M=&AI<R!F;W(@0D,*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YO<'1I;VYS
M6UA-3%]315))04Q)6D527T]05$E/3E]$149!54Q47U1!1UU;)U]?9&5F875L
M="==.PH@("`@("`@('T*("`@("`@("!R971U<FX@)UA-3%]397)I86QI>F5R
M7U1A9R<["B`@("!]"B`@("`*("`@+RHJ"B`@("`J('-E<FEA;&EZ92!A;B!O
M8FIE8W0*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'!A
M<F%M("`@(&]B:F5C="`@)&]B:F5C="!O8FIE8W0@=&\@<V5R:6%L:7IE"B`@
M("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@<V5R:6%L:7IE9"!D871A
M"B`@("`J+PH@("`@9G5N8W1I;VX@7W-E<FEA;&EZ94]B:F5C="@F)&]B:F5C
M="P@)'1A9TYA;64@/2!N=6QL+"`D871T<FEB=71E<R`](&%R<F%Y*"DI"B`@
M("!["B`@("`@("`@+R\@8VAE8VL@9F]R(&UA9VEC(&9U;F-T:6]N"B`@("`@
M("`@:68@*&UE=&AO9%]E>&ES=',H)&]B:F5C="P@)U]?<VQE97`G*2D@>PH@
M("`@("`@("`@("`D<')O<$YA;65S(#T@)&]B:F5C="T^7U]S;&5E<"@I.PH@
M("`@("`@("`@("!I9B`H:7-?87)R87DH)'!R;W!.86UE<RDI('L*("`@("`@
M("`@("`@"21P<F]P97)T:65S(#T@87)R87DH*3L*("`@("`@("`@("`@"69O
M<F5A8V@@*"1P<F]P3F%M97,@87,@)'!R;W!.86UE*2!["B`@("`@("`@("`@
M(`D))'!R;W!E<G1I97-;)'!R;W!.86UE72`]("1O8FIE8W0M/B1P<F]P3F%M
M93L*("`@("`@("`@("`@"7T*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("1P<F]P97)T:65S(#T@9V5T7V]B:F5C=%]V87)S*"1O8FIE
M8W0I.PH@("`@("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'!R;W!E<G1I97,@/2!G971?;V)J96-T7W9A<G,H)&]B:F5C="D["B`@
M("`@("`@?0H*("`@("`@("!I9B`H96UP='DH)'1A9TYA;64I*2!["B`@("`@
M("`@("`@("1T86=.86UE(#T@9V5T7V-L87-S*"1O8FIE8W0I.PH@("`@("`@
M('T*"B`@("`@("`@+R\@='EP96AI;G1S(&%C=&EV871E9#\*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7U194$5(
M24Y44UT@/3T]('1R=64I('L*("`@("`@("`@("`@)&%T=')I8G5T97-;)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T%45%))0E5415]4
M65!%75T@(#T@)V]B:F5C="<["B`@("`@("`@("`@("1A='1R:6)U=&5S6R1T
M:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E]!5%1224)55$5?
M0TQ!4U-=72`]("!G971?8VQA<W,H)&]B:F5C="D["B`@("`@("`@?0H@("`@
M("`@("1S=')I;F<@/2`D=&AI<RT^7W-E<FEA;&EZ94%R<F%Y*"1P<F]P97)T
M:65S+"`D=&%G3F%M92P@)&%T=')I8G5T97,I.PH@("`@("`@(')E='5R;B`D
M<W1R:6YG.PH@("`@?0H@(`H@("`O*BH*("`@("H@8W)E871E(&$@=&%G(&9R
M;VT@86X@87)R87D*("`@("H@=&AI<R!M971H;V0@87=A:71S(&%N(&%R<F%Y
M(&EN('1H92!F;VQL;W=I;F<@9F]R;6%T"B`@("`J(&%R<F%Y*`H@("`@*B`@
M("`@("`G<6YA;64G("`@("`@("`]/B`D=&%G3F%M92P*("`@("H@("`@("`@
M)V%T=')I8G5T97,G("`@/3X@87)R87DH*2P*("`@("H@("`@("`@)V-O;G1E
M;G0G("`@("`@/3X@)&-O;G1E;G0L("`@("`@+R\@;W!T:6]N86P*("`@("H@
M("`@("`@)VYA;65S<&%C92<@("`@/3X@)&YA;65S<&%C92`@("`@+R\@;W!T
M:6]N86P*("`@("H@("`@("`@)VYA;65S<&%C955R:2<@/3X@)&YA;65S<&%C
M955R:2`@+R\@;W!T:6]N86P*("`@("H@("`I"B`@("`J"B`@("`J($!A8V-E
M<W,@("!P<FEV871E"B`@("`J($!P87)A;2`@("!A<G)A>2`@("1T86<@=&%G
M(&1E9FEN:71I;VX*("`@("H@0'!A<F%M("`@(&)O;VQE86X@)')E<&QA8V5%
M;G1I=&EE<R!W:&5T:&5R('1O(')E<&QA8V4@6$U,(&5N=&ET:65S(&EN(&-O
M;G1E;G0@;W(@;F]T"B`@("`J($!R971U<FX@("!S=')I;F<@("1S=')I;F<@
M6$U,('1A9PH@("`@*B\*("`@(&9U;F-T:6]N(%]C<F5A=&5834Q486<H)'1A
M9RP@)&9I<G-T0V%L;"`]('1R=64I"B`@("!["B`@("`@("`@+R\@8G5I;&0@
M9G5L;'D@<75A;&EF:65D('1A9R!N86UE"B`@("`@("`@:68@*"1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E].04U%4U!!0T5=("$]/2!N
M=6QL*2!["B`@("`@("`@"6EF("AI<U]A<G)A>2@D=&AI<RT^;W!T:6]N<UM8
M34Q?4T5224%,25I%4E]/4%1)3TY?3D%-15-004-%72DI('L*("`@("`@("`)
M"21T86=;)W%N86UE)UT@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,25I%
M4E]/4%1)3TY?3D%-15-004-%75LP72`N("<Z)R`N("1T86=;)W%N86UE)UT[
M"B`@("`@("`@"7T@96QS92!["B`@("`@("`@"0DD=&%G6R=Q;F%M92==(#T@
M)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TY!34534$%#
M15T@+B`G.B<@+B`D=&%G6R=Q;F%M92==.PH@("`@("`@(`E]"B`@("`@("`@
M?0H*("`@("`@("`O+R!A='1R:6)U=&4@:6YD96YT871I;VX*("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.1$5.
M5%]!5%1224)55$5372`A/3T@9F%L<V4I('L*("`@("`@("`@("`@)&UU;'1I
M;&EN92`]('1R=64["B`@("`@("`@("`@("1I;F1E;G0@("`@/2!S=')?<F5P
M96%T*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E])3D1%
M3E1=+"`D=&AI<RT^7W1A9T1E<'1H*3L*"B`@("`@("`@("`@(&EF("@D=&AI
M<RT^;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?24Y$14Y47T%45%))
M0E5415-=(#T]("=?875T;R<I('L*("`@("`@("`@("`@("`@("1I;F1E;G0@
M+CT@<W1R7W)E<&5A="@G("<L("AS=')L96XH)'1A9ULG<6YA;64G72DK,BDI
M.PH*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1I;F1E
M;G0@+CT@)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7TE.
M1$5.5%]!5%1224)55$5373L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1M=6QT:6QI;F4@/2!F86QS93L*("`@("`@("`@
M("`@)&EN9&5N="`@("`](&9A;'-E.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&ES7V%R<F%Y*"1T86=;)V-O;G1E;G0G72DI('L*("`@("`@("`@("`@:68@
M*&5M<'1Y*"1T86=;)V-O;G1E;G0G72DI('L*("`@("`@("`@("`@("`@("1T
M86=;)V-O;G1E;G0G72`]("`@)R<["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V5I9BAI<U]S8V%L87(H)'1A9ULG8V]N=&5N="==*2`F)B`H<W1R:6YG
M*21T86=;)V-O;G1E;G0G72`]/2`G)RD@>PH@("`@("`@("`@("`D=&%G6R=C
M;VYT96YT)UT@/2`@("<G.PH@("`@("`@('T*"B`@("`@("`@+R\@<F5P;&%C
M92!834P@96YT:71I97,@*&]N;'D@;F5E9&5D+"!I9B!T:&ES(&ES(&YO="!A
M(&YE<W1E9"!C86QL*0H@("`@("`@(&EF("@D9FER<W1#86QL(#T]/2!T<G5E
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,
M25I%4E]/4%1)3TY?0T1!5$%?4T5#5$E/3E-=(#T]/2!T<G5E*2!["B`@("`@
M("`@("`@("`@("`D<F5P;&%C945N=&ET:65S(#T@6$U,7U5424Q?0T1!5$%?
M4T5#5$E/3CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`)("`@
M("1R97!L86-E16YT:71I97,@/2`D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,
M25I%4E]/4%1)3TY?14Y4251)15-=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@)')E<&QA8V5%;G1I=&EE<R`](%A-3%]3
M15))04Q)6D527T5.5$E424537TY/3D4["B`@("`@("`@?0H@("`@("`@(&EF
M("AI<U]S8V%L87(H)'1A9ULG8V]N=&5N="==*2!\?"!I<U]N=6QL*"1T86=;
M)V-O;G1E;G0G72DI('L*("`@("`@("`@("`@:68@*"1T:&ES+3YO<'1I;VYS
M6UA-3%]315))04Q)6D527T]05$E/3E]%3D-/1$5?1E5.0UTI('L*("`@("`@
M("`@("`@("`@(&EF("@D9FER<W1#86QL(#T]/2!T<G5E*2!["B`@("`@("`@
M("`@("`@("`))'1A9ULG8V]N=&5N="==(#T@8V%L;%]U<V5R7V9U;F,H)'1H
M:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#
M72P@)'1A9ULG8V]N=&5N="==*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@"21T86=;)V%T=')I8G5T97,G72`](&%R<F%Y7VUA<"@D=&AI<RT^
M;W!T:6]N<UM834Q?4T5224%,25I%4E]/4%1)3TY?14Y#3T1%7T953D-=+"`D
M=&%G6R=A='1R:6)U=&5S)UTI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M("1T86<@/2!834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L("1R
M97!L86-E16YT:71I97,L("1M=6QT:6QI;F4L("1I;F1E;G0L("1T:&ES+3YO
M<'1I;VYS6UA-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M372D["B`@
M("`@("`@?2!E;'-E:68@*&ES7V%R<F%Y*"1T86=;)V-O;G1E;G0G72DI('L*
M("`@("`@("`@("`@)'1A9R`@("`]("`@)'1H:7,M/E]S97)I86QI>F5!<G)A
M>2@D=&%G6R=C;VYT96YT)UTL("1T86=;)W%N86UE)UTL("1T86=;)V%T=')I
M8G5T97,G72D["B`@("`@("`@?2!E;'-E:68@*&ES7V]B:F5C="@D=&%G6R=C
M;VYT96YT)UTI*2!["B`@("`@("`@("`@("1T86<@("`@/2`@("1T:&ES+3Y?
M<V5R:6%L:7IE3V)J96-T*"1T86=;)V-O;G1E;G0G72P@)'1A9ULG<6YA;64G
M72P@)'1A9ULG871T<FEB=71E<R==*3L*("`@("`@("!](&5L<V5I9B`H:7-?
M<F5S;W5R8V4H)'1A9ULG8V]N=&5N="==*2D@>PH@("`@("`@("`@("!S971T
M>7!E*"1T86=;)V-O;G1E;G0G72P@)W-T<FEN9R<I.PH@("`@("`@("`@("!I
M9B`H)'1H:7,M/F]P=&EO;G-;6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$
M15]&54Y#72D@>PH@("`@("`@("`@("`):68@*"1R97!L86-E16YT:71I97,@
M/3T]('1R=64I('L*("`@("`@("`@("`@("`@("`@("`D=&%G6R=C;VYT96YT
M)UT@/2!C86QL7W5S97)?9G5N8R@D=&AI<RT^;W!T:6]N<UM834Q?4T5224%,
M25I%4E]/4%1)3TY?14Y#3T1%7T953D-=+"`D=&%G6R=C;VYT96YT)UTI.PH@
M("`@("`@("`@("`)?0H@("`@("`@("`@("`))'1A9ULG871T<FEB=71E<R==
M(#T@87)R87E?;6%P*"1T:&ES+3YO<'1I;VYS6UA-3%]315))04Q)6D527T]0
M5$E/3E]%3D-/1$5?1E5.0UTL("1T86=;)V%T=')I8G5T97,G72D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'1A9R`](%A-3%]5=&EL.CIC<F5A=&54
M86=&<F]M07)R87DH)'1A9RP@)')E<&QA8V5%;G1I=&EE<RD["B`@("`@("`@
M?0H@("`@("`@(')E='5R;B`@)'1A9SL*("`@('T*?0H_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U)00RYP
M:'``````````````````````````````````````````````````````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#$V,#,S,B`Q,#4Q-30S-#$S,R`P,C`R-C,`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X
M<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z
M("HO"@HO*BH*("H@4$A0(&EM<&QE;65N=&%T:6]N(&]F('1H92!834PM4E!#
M('!R;W1O8V]L"B`J"B`J(%1H:7,@:7,@82!014%2+6EF:65D('9E<G-I;VX@
M;V8@57-E9G5L(&EN8R=S(%A-3"U24$,@9F]R(%!(4"X*("H@270@:&%S('-U
M<'!O<G0@9F]R($A45%`@=')A;G-P;W)T+"!P<F]X:65S(&%N9"!A=71H96YT
M:6-A=&EO;BX*("H*("H@4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@3$E#
M14Y313H@3&EC96YS92!I<R!G<F%N=&5D('1O('5S92!O<B!M;V1I9GD@=&AI
M<R!S;V9T=V%R90H@*B`H(EA-3"U24$,@9F]R(%!(4"(I(&9O<B!C;VUM97)C
M:6%L(&]R(&YO;BUC;VUM97)C:6%L('5S92!P<F]V:61E9"!T:&4*("H@8V]P
M>7)I9VAT(&]F('1H92!A=71H;W(@:7,@<')E<V5R=F5D(&EN(&%N>2!D:7-T
M<FEB=71E9"!O<B!D97)I=F%T:79E('=O<FLN"B`J"B`J(%1(25,@4T]&5%=!
M4D4@25,@4%)/5DE$140@0ED@5$A%($%55$A/4B`B05,@25,B($%.1"!!3ED@
M15A04D534T5$($]2"B`J($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'
M+"!"550@3D]4($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,*
M("H@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X*("H@24X@3D\@159%3E0@
M4TA!3$P@5$A%($%55$A/4B!"12!,24%"3$4@1D]2($%.62!$25)%0U0L($E.
M1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#24%,+"!%6$5-4$Q!4EDL($]2
M($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550*("H@3D]4
M($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@
M3U(@4T525DE#15,[($Q/4U,@3T8@55-%+`H@*B!$051!+"!/4B!04D]&2513
M.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$($%.
M1"!/3B!!3ED*("H@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#
M3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25`H@*B`H24Y#3%5$
M24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!7
M05D@3U54($]&(%1(12!54T4@3T8*("H@5$A)4R!33T945T%212P@159%3B!)
M1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X*
M("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@
M(%A-3%]24$,*("H@0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D9$!U<V5F
M=6QI;F,N8V]M/@H@*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W1I9T!P
M:'`N;F5T/@H@*B!`875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N
M;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC
M0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@1'5M8FEL
M;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("`@0U93
M.B`D260Z(%)00RYP:'`L=B`Q+CDU(#(P,#8O,#0O,38@,34Z,#0Z-3,@9&%N
M:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T
M+W!A8VMA9V4O6$U,7U)00PH@*B\*"@II9B`H(69U;F-T:6]N7V5X:7-T<R@G
M>&UL7W!A<G-E<E]C<F5A=&4G*2D@>PH@("`@:6YC;'5D95]O;F-E("=014%2
M+G!H<"<["B`@("!014%2.CIL;V%D17AT96YS:6]N*"=X;6PG*3L*?0H*+RHJ
M(T`K"B`J($5R<F]R(&-O;G-T86YT<PH@*B\*+RHJ"B`J(%!A<F%M971E<B!V
M86QU97,@9&]N)W0@;6%T8V@@<&%R86UE=&5R('1Y<&5S"B`J+PID969I;F4H
M)UA-3%]24$-?15)23U)?24Y604Q)1%]465!%)RP@,3`Q*3L*+RHJ"B`J(%!A
M<F%M971E<B!D96-L87)E9"!T;R!B92!N=6UE<FEC(&)U="!T:&4@=F%L=65S
M(&%R92!N;W0*("HO"F1E9FEN92@G6$U,7U)00U]%4E)/4E].3TY?3E5-15))
M0U]&3U5.1"<L(#$P,BD["B\J*@H@*B!#;VUM=6YI8V%T:6]N(&5R<F]R"B`J
M+PID969I;F4H)UA-3%]24$-?15)23U)?0T].3D5#5$E/3E]&04E,140G+"`Q
M,#,I.PHO*BH*("H@5&AE(&%R<F%Y(&]R('-T<G5C="!H87,@86QR96%D>2!B
M965N('-T87)T960*("HO"F1E9FEN92@G6$U,7U)00U]%4E)/4E]!3%)%0419
M7TE.251)04Q)6D5$)RP@,3`T*3L*+RHJ"B`J($EN8V]R<F5C="!P87)A;65T
M97)S('-U8FUI='1E9`H@*B\*9&5F:6YE*"=834Q?4E!#7T524D]27TE.0T]2
M4D5#5%]005)!35,G+"`Q,#4I.PHO*BH*("H@4')O9W)A;6UI;F<@97)R;W(@
M8GD@9&5V96QO<&5R"B`J+PID969I;F4H)UA-3%]24$-?15)23U)?4%)/1U)!
M34U)3D<G+"`Q,#8I.PHO*BHC0"TJ+PH*"B\J*@H@*B!$871A('1Y<&5S"B`J
M($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7TDT)UT*("HO"B1'
M3$]"04Q36R=834Q?4E!#7TDT)UT@/2`G:30G.PH*+RHJ"B`J($1A=&$@='EP
M97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?26YT)UT*
M("HO"B1'3$]"04Q36R=834Q?4E!#7TEN="==(#T@)VEN="<["@HO*BH*("H@
M1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)0
M0U]";V]L96%N)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7T)O;VQE86XG72`]
M("=B;V]L96%N)SL*"B\J*@H@*B!$871A('1Y<&5S"B`J($!G;&]B86P@<W1R
M:6YG("1'3$]"04Q36R=834Q?4E!#7T1O=6)L92=="B`J+PHD1TQ/0D%,4ULG
M6$U,7U)00U]$;W5B;&4G72`]("=D;W5B;&4G.PH*+RHJ"B`J($1A=&$@='EP
M97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG
M)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R==(#T@)W-T<FEN9R<[
M"@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,
M4ULG6$U,7U)00U]$871E5&EM92=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]$
M871E5&EM92==(#T@)V1A=&54:6UE+FES;S@V,#$G.PH*+RHJ"B`J($1A=&$@
M='EP97,*("H@0&=L;V)A;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?0F%S
M938T)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7T)A<V4V-"==(#T@)V)A<V4V
M-"<["@HO*BH*("H@1&%T82!T>7!E<PH@*B!`9VQO8F%L('-T<FEN9R`D1TQ/
M0D%,4ULG6$U,7U)00U]!<G)A>2=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]!
M<G)A>2==(#T@)V%R<F%Y)SL*"B\J*@H@*B!$871A('1Y<&5S"B`J($!G;&]B
M86P@<W1R:6YG("1'3$]"04Q36R=834Q?4E!#7U-T<G5C="=="B`J+PHD1TQ/
M0D%,4ULG6$U,7U)00U]3=')U8W0G72`]("=S=')U8W0G.PH*"B\J*@H@*B!$
M871A('1Y<&4@;65T82UT>7!E<PH@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q3
M6R=834Q?4E!#7U1Y<&5S)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U1Y<&5S
M)UT@/2!A<G)A>2@*("`@("1'3$]"04Q36R=834Q?4E!#7TDT)UT@("`@("`@
M/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#7TEN="==("`@("`@/3X@,2P*
M("`@("1'3$]"04Q36R=834Q?4E!#7T)O;VQE86XG72`@/3X@,2P*("`@("1'
M3$]"04Q36R=834Q?4E!#7U-T<FEN9R==("`@/3X@,2P*("`@("1'3$]"04Q3
M6R=834Q?4E!#7T1O=6)L92==("`@/3X@,2P*("`@("1'3$]"04Q36R=834Q?
M4E!#7T1A=&54:6UE)UT@/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#7T)A
M<V4V-"==("`@/3X@,2P*("`@("1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UT@
M("`@/3X@,BP*("`@("1'3$]"04Q36R=834Q?4E!#7U-T<G5C="==("`@/3X@
M,RP**3L*"@HO*BH*("H@17)R;W(@;65S<V%G92!N=6UB97)S"B`J($!G;&]B
M86P@87)R87D@)$=,3T)!3%-;)UA-3%]24$-?97)R)UT*("HO"B1'3$]"04Q3
M6R=834Q?4E!#7V5R<B==(#T@87)R87DH"B`@("`G=6YK;F]W;E]M971H;V0G
M("`@("`@/3X@,2P*("`@("=I;G9A;&ED7W)E='5R;B<@("`@("`]/B`R+`H@
M("`@)VEN8V]R<F5C=%]P87)A;7,G("`@(#T^(#,L"B`@("`G:6YT<F]S<&5C
M=%]U;FMN;W=N)R`@/3X@-"P*("`@("=H='1P7V5R<F]R)R`@("`@("`@("`]
M/B`U+`H@("`@)VYO=%]R97-P;VYS95]O8FIE8W0G(#T^(#8L"B`@("`G:6YV
M86QI9%]R97%U97-T)R`@("`@/3X@-RP**3L*"B\J*@H@*B!%<G)O<B!M97-S
M86=E('-T<FEN9W,*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)0
M0U]S='(G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?<W1R)UT@/2!A<G)A>2@*
M("`@("=U;FMN;W=N7VUE=&AO9"<@("`@("`]/B`G56YK;F]W;B!M971H;V0G
M+`H@("`@)VEN=F%L:61?<F5T=7)N)R`@("`@(#T^("=);G9A;&ED(')E='5R
M;B!P87EL;V%D.B!E;F%B;&4@9&5B=6=G:6YG('1O(&5X86UI;F4@:6YC;VUI
M;F<@<&%Y;&]A9"<L"B`@("`G:6YC;W)R96-T7W!A<F%M<R<@("`@/3X@)TEN
M8V]R<F5C="!P87)A;65T97)S('!A<W-E9"!T;R!M971H;V0G+`H@("`@)VEN
M=')O<W!E8W1?=6YK;F]W;B<@(#T^("=#86Y<)W0@:6YT<F]S<&5C=#H@;65T
M:&]D('5N:VYO=VXG+`H@("`@)VAT='!?97)R;W(G("`@("`@("`@(#T^("=$
M:61N7"=T(')E8V5I=F4@,C`P($]+(&9R;VT@<F5M;W1E('-E<G9E<BXG+`H@
M("`@)VYO=%]R97-P;VYS95]O8FIE8W0G(#T^("=4:&4@<F5Q=65S=&5D(&UE
M=&AO9"!D:61N7"=T(')E='5R;B!A;B!834Q?4E!#7U)E<W!O;G-E(&]B:F5C
M="XG+`H@("`@)VEN=F%L:61?<F5Q=65S="<@("`@(#T^("=);G9A;&ED(')E
M<75E<W0@<&%Y;&]A9"<L"BD["@H*+RHJ"B`J($1E9F%U;'0@6$U,(&5N8V]D
M:6YG("A)4T\M.#@U.2TQ+"!55$8M."!O<B!54RU!4T-)22D*("H@0&=L;V)A
M;"!S=')I;F<@)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G70H@*B\*
M)$=,3T)!3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G72`]("=55$8M."<["@HO
M*BH*("H@57-E<B!E<G)O<B!C;V1E<R!S=&%R="!A="`X,#`*("H@0&=L;V)A
M;"!I;G0@)$=,3T)!3%-;)UA-3%]24$-?97)R=7-E<B=="B`J+PHD1TQ/0D%,
M4ULG6$U,7U)00U]E<G)U<V5R)UT@/2`X,#`["@HO*BH*("H@6$U,('!A<G-E
M(&5R<F]R(&-O9&5S('-T87)T(&%T(#$P,`H@*B!`9VQO8F%L(&EN="`D1TQ/
M0D%,4ULG6$U,7U)00U]E<G)X;6PG70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?
M97)R>&UL)UT@/2`Q,#`["@H*+RHJ"B`J($-O;7!O<V4@8F%C:W-L87-H97,@
M9F]R(&5S8V%P:6YG(')E9V5X<`H@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,
M4ULG6$U,7U)00U]B86-K<VQA<V@G70H@*B\*)$=,3T)!3%-;)UA-3%]24$-?
M8F%C:W-L87-H)UT@/2!C:'(H.3(I("X@8VAR*#DR*3L*"@HO*BH*("H@5F%L
M:60@<&%R96YT<R!O9B!834P@96QE;65N=',*("H@0&=L;V)A;"!A<G)A>2`D
M1TQ/0D%,4ULG6$U,7U)00U]V86QI9%]P87)E;G1S)UT*("HO"B1'3$]"04Q3
M6R=834Q?4E!#7W9A;&ED7W!A<F5N=',G72`](&%R<F%Y*`H@("`@)T)/3TQ%
M04XG(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)TDT)R`]/B!A<G)A>2@G5D%,
M544G*2P*("`@("=)3E0G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)U-44DE.
M1R<@/3X@87)R87DH)U9!3%5%)RDL"B`@("`G1$]50DQ%)R`]/B!A<G)A>2@G
M5D%,544G*2P*("`@("=$051%5$E-12Y)4T\X-C`Q)R`]/B!A<G)A>2@G5D%,
M544G*2P*("`@("="05-%-C0G(#T^(&%R<F%Y*"=604Q512<I+`H@("`@)T%2
M4D%9)R`]/B!A<G)A>2@G5D%,544G*2P*("`@("=35%)50U0G(#T^(&%R<F%Y
M*"=604Q512<I+`H@("`@)U!!4D%-)R`]/B!A<G)A>2@G4$%204U3)RDL"B`@
M("`G34542$]$3D%-12<@/3X@87)R87DH)TU%5$A/1$-!3$PG*2P*("`@("=0
M05)!35,G(#T^(&%R<F%Y*"=-151(3T1#04Q,)RP@)TU%5$A/1%)%4U!/3E-%
M)RDL"B`@("`G345-0D52)R`]/B!A<G)A>2@G4U1254-4)RDL"B`@("`G3D%-
M12<@/3X@87)R87DH)TU%34)%4B<I+`H@("`@)T1!5$$G(#T^(&%R<F%Y*"=!
M4E)!62<I+`H@("`@)T9!54Q4)R`]/B!A<G)A>2@G34542$]$4D534$].4T4G
M*2P*("`@("=604Q512<@/3X@87)R87DH)TU%34)%4B<L("=$051!)RP@)U!!
M4D%-)RP@)T9!54Q4)RDL"BD["@H*+RHJ"B`J(%-T;W)E<R!S=&%T92!D=7)I
M;F<@<&%R<VEN9PH@*@H@*B!Q=6EC:R!E>'!L86YA=&EO;B!O9B!C;VUP;VYE
M;G1S.@H@*B`@("L@86,@("`@(#T@86-C=6UU;&%T97,@=F%L=65S"B`J("`@
M*R!Q="`@("`@/2!D96-I9&5S(&EF('%U;W1E<R!A<F4@;F5E9&5D(&9O<B!E
M=F%L=6%T:6]N"B`J("`@*R!C;2`@("`@/2!D96YO=&5S('-T<G5C="!O<B!A
M<G)A>2`H8V]M;6$@;F5E9&5D*0H@*B`@("L@:7-F("`@(#T@:6YD:6-A=&5S
M(&$@9F%U;'0*("H@("`K(&QV("`@("`](&EN9&EC871E<R`B;&]O:VEN9R!F
M;W(@82!V86QU92(Z(&EM<&QE;65N=',@=&AE(&QO9VEC"B`J("`@("`@("`@
M("`@("`@=&\@86QL;W<@=F%L=65S('=I=&@@;F\@='EP97,@=&\@8F4@<W1R
M:6YG<PH@*B`@("L@<&%R86US(#T@<W1O<F5S('!A<F%M971E<G,@:6X@;65T
M:&]D(&-A;&QS"B`J("`@*R!M971H;V0@/2!S=&]R97,@;65T:&]D(&YA;64*
M("H*("H@0&=L;V)A;"!A<G)A>2`D1TQ/0D%,4ULG6$U,7U)00U]X:"=="B`J
M+PHD1TQ/0D%,4ULG6$U,7U)00U]X:"==(#T@87)R87DH*3L*"@HO*BH*("H@
M4W1A<G0@96QE;65N="!H86YD;&5R(&9O<B!T:&4@6$U,('!A<G-E<@H@*@H@
M*B!`<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(%A-3%]24$-?<V4H)'!A<G-E
M<E]R97-O=7)C92P@)&YA;64L("1A='1R<RD*>PH@("`@9VQO8F%L("1834Q?
M4E!#7WAH+"`D6$U,7U)00U]V86QI9%]P87)E;G1S.PH*("`@("1P87)S97(@
M/2`H:6YT*2`D<&%R<V5R7W)E<V]U<F-E.PH*("`@("\O(&EF(&EN=F%L:60@
M>&UL<G!C(&%L<F5A9'D@9&5T96-T960L('-K:7`@86QL('!R;V-E<W-I;F<*
M("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UT@/CT@,BD@>PH@
M("`@("`@(')E='5R;CL*("`@('T*"B`@("`O+R!C:&5C:R!F;W(@8V]R<F5C
M="!E;&5M96YT(&YE<W1I;F<*("`@("\O('1O<"!L979E;"!E;&5M96YT(&-A
M;B!O;FQY(&)E(&]F(#(@='EP97,*("`@(&EF("AC;W5N="@D6$U,7U)00U]X
M:%LD<&%R<V5R75LG<W1A8VLG72D@/3T@,"D@>PH@("`@("`@(&EF("@D;F%M
M92`A/2`G34542$]$4D534$].4T4G("8F("1N86UE("$]("=-151(3T1#04Q,
M)RD@>PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F)UT@
M/2`R.PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG:7-F7W)E
M87-O;B==(#T@)VUI<W-I;F<@=&]P(&QE=F5L('AM;')P8R!E;&5M96YT)SL*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T@96QS92!["B`@
M("`@("`@+R\@;F]T('1O<"!L979E;"!E;&5M96YT.B!S964@:68@<&%R96YT
M(&ES($]+"B`@("`@("`@:68@*"%I;E]A<G)A>2@D6$U,7U)00U]X:%LD<&%R
M<V5R75LG<W1A8VLG75LP72P@)%A-3%]24$-?=F%L:61?<&%R96YT<ULD;F%M
M95TI*2!["B`@("`@("`@("`@("1N86UE(#T@<')E9U]R97!L86-E*"=;7F$M
M>D$M6C`M.2Y?+5TG+"`G)RP@)&YA;64I.PH@("`@("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG:7-F)UT@/2`R.PH@("`@("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG:7-F7W)E87-O;B==(#T@(GAM;')P8R!E;&5M96YT
M("1N86UE(&-A;FYO="!B92!C:&EL9"!O9B![)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)W-T86-K)UU;,%U](CL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@('T*"B`@("!S=VET8V@@*"1N86UE*2!["B`@("!C87-E("=35%)5
M0U0G.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=C;2==*RL["@H@
M("`@("`@("\O('1U<FX@<75O=&EN9R!O9F8*("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG<70G72`](#`["@H@("`@("`@("1C=7)?=F%L(#T@87)R
M87DH*3L*("`@("`@("`D8W5R7W9A;%LG=F%L=64G72`](&%R<F%Y*"D["B`@
M("`@("`@)&-U<E]V86Q;)VUE;6)E<G,G72`](#$["B`@("`@("`@87)R87E?
M=6YS:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=65S=&%C:R==+"`D
M8W5R7W9A;"D["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G05)205DG.@H@
M("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=C;2==*RL["@H@("`@("`@
M("\O('1U<FX@<75O=&EN9R!O9F8*("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG<70G72`](#`["@H@("`@("`@("1C=7)?=F%L(#T@87)R87DH*3L*
M("`@("`@("`D8W5R7W9A;%LG=F%L=64G72`](&%R<F%Y*"D["B`@("`@("`@
M)&-U<E]V86Q;)VUE;6)E<G,G72`](#`["B`@("`@("`@87)R87E?=6YS:&EF
M="@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=65S=&%C:R==+"`D8W5R7W9A
M;"D["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G3D%-12<Z"B`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT@/2`G)SL*("`@("`@("!B<F5A
M:SL*"B`@("!C87-E("=&055,5"<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A
M<G-E<EU;)VES9B==(#T@,3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=0
M05)!32<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A
M8VLG72`](&%R<F%Y*"D["B`@("`@("`@8G)E86L["@H@("`@8V%S92`G5D%,
M544G.@H@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=L=B==(#T@,3L*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G72`]("1'3$]"04Q3
M6R=834Q?4E!#7U-T<FEN9R==.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=A8R==(#T@)R<["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)W%T)UT@/2`P.PH@("`@("`@("\O(&QO;VL@9F]R(&$@=F%L=64Z(&EF('1H
M:7,@:7,@<W1I;&P@,2!B>2!T:&4*("`@("`@("`O+R!T:6UE('=E(')E86-H
M('1H92!F:7)S="!D871A('-E9VUE;G0@=&AE;B!T:&4@='EP92!I<R!S=')I
M;F<*("`@("`@("`O+R!B>2!I;7!L:6-A=&EO;B!A;F0@=V4@;F5E9"!T;R!A
M9&0@:6X@82!Q=6]T90H@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)TDT)SH*
M("`@(&-A<V4@)TE.5"<Z"B`@("!C87-E("=35%))3D<G.@H@("`@8V%S92`G
M0D]/3$5!3B<Z"B`@("!C87-E("=$3U5"3$4G.@H@("`@8V%S92`G1$%4151)
M344N25-/.#8P,2<Z"B`@("!C87-E("="05-%-C0G.@H@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<[("\O(')E<V5T('1H92!A8V-U
M;75L871O<@H*("`@("`@("!I9B`H)&YA;64@/3T@)T1!5$5424U%+DE33S@V
M,#$G('Q\("1N86UE(#T]("=35%))3D<G*2!["B`@("`@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=Q="==(#T@,3L*"B`@("`@("`@("`@(&EF("@D
M;F%M92`]/2`G1$%4151)344N25-/.#8P,2<I('L*("`@("`@("`@("`@("`@
M("1834Q?4E!#7WAH6R1P87)S97)=6R=V="==(#T@)$=,3T)!3%-;)UA-3%]2
M4$-?1&%T951I;64G73L*("`@("`@("`@("`@?0H*("`@("`@("!](&5L<V5I
M9B`H)&YA;64@/3T@)T)!4T4V-"<I('L*("`@("`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W%T)UT@/2`R.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("\O($YO('%U;W1I;F<@:7,@<F5Q=6ER960@:&5R92`M+2!B=70*
M("`@("`@("`@("`@+R\@870@=&AE(&5N9"!O9B!T:&4@96QE;65N="!W92!M
M=7-T(&-H96-K"B`@("`@("`@("`@("\O(&9O<B!D871A(&9O<FUA="!E<G)O
M<G,N"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=Q="==(#T@
M,#L*("`@("`@("!]"B`@("`@("`@8G)E86L["@H@("`@8V%S92`G345-0D52
M)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.PH@
M("`@("`@(&)R96%K.PH*("`@(&-A<V4@)T1!5$$G.@H@("`@8V%S92`G3454
M2$]$0T%,3"<Z"B`@("!C87-E("=-151(3T1.04U%)SH*("`@(&-A<V4@)TU%
M5$A/1%)%4U!/3E-%)SH*("`@(&-A<V4@)U!!4D%-4R<Z"B`@("`@("`@+R\@
M=F%L:60@96QE;65N=',@=&AA="!A9&0@;&ET=&QE('1O('!R;V-E<W-I;F<*
M("`@("`@("!B<F5A:SL*("`@('T*"@H@("`@+R\@4V%V92!C=7)R96YT(&5L
M96UE;G0@=&\@<W1A8VL*("`@(&%R<F%Y7W5N<VAI9G0H)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W-T86-K)UTL("1N86UE*3L*"B`@("!I9B`H)&YA;64@(3T@
M)U9!3%5%)RD@>PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=L=B==
M(#T@,#L*("`@('T*?0H*+RHJ"B`J($5N9"!E;&5M96YT(&AA;F1L97(@9F]R
M('1H92!834P@<&%R<V5R"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I
M;VX@6$U,7U)00U]E92@D<&%R<V5R7W)E<V]U<F-E+"`D;F%M92D*>PH@("`@
M9VQO8F%L("1834Q?4E!#7WAH.PH*("`@("1P87)S97(@/2`H:6YT*2`D<&%R
M<V5R7W)E<V]U<F-E.PH*("`@(&EF("@D6$U,7U)00U]X:%LD<&%R<V5R75LG
M:7-F)UT@/CT@,BD@>PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("`O+R!P
M=7-H('1H:7,@96QE;65N="!F<F]M('-T86-K"B`@("`O+R!.0CH@:68@6$U,
M('9A;&ED871E<RP@8V]R<F5C="!O<&5N:6YG+V-L;W-I;F<@:7,@9W5A<F%N
M=&5E9"!A;F0*("`@("\O('=E(&1O(&YO="!H879E('1O(&-H96-K(&9O<B`D
M;F%M92`]/2`D8W5R<E]E;&5M+@H@("`@+R\@=V4@86QS;R!C:&5C:V5D(&9O
M<B!P<F]P97(@;F5S=&EN9R!A="!S=&%R="!O9B!E;&5M96YT<RXN+@H@("`@
M)&-U<G)?96QE;2`](&%R<F%Y7W-H:69T*"1834Q?4E!#7WAH6R1P87)S97)=
M6R=S=&%C:R==*3L*"B`@("!S=VET8V@@*"1N86UE*2!["B`@("!C87-E("=3
M5%)50U0G.@H@("`@8V%S92`G05)205DG.@H@("`@)&-U<E]V86P@/2!A<G)A
M>5]S:&EF="@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=65S=&%C:R==*3L*
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==(#T@)&-U<E]V86Q;
M)W9A;'5E)UT["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T)UT@
M/2!S=')T;VQO=V5R*"1N86UE*3L*("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG8VTG72TM.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)TY!344G
M.@H@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A8VLG75LP75LG
M;F%M92==(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT["B`@("`@("`@
M8G)E86L["@H@("`@8V%S92`G0D]/3$5!3B<Z"B`@("`@("`@+R\@<W!E8VEA
M;"!C87-E(&AE<F4Z('=E('1R86YS;&%T92!B;V]L96%N(#$@;W(@,"!I;G1O
M(%!(4`H@("`@("`@("\O(&-O;G-T86YT<R!T<G5E(&]R(&9A;'-E"B`@("`@
M("`@:68@*"1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T]("<Q)RD@>PH@
M("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("=T<G5E
M)SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D6$U,7U)00U]X:%LD
M<&%R<V5R75LG86,G72`]("=F86QS92<["B`@("`@("`@?0H*("`@("`@("`D
M6$U,7U)00U]X:%LD<&%R<V5R75LG=G0G72`]('-T<G1O;&]W97(H)&YA;64I
M.PH@("`@("`@("\O($1R;W`@=&AR;W5G:"!I;G1E;G1I;VYA;&QY+@H*("`@
M(&-A<V4@)TDT)SH*("`@(&-A<V4@)TE.5"<Z"B`@("!C87-E("=35%))3D<G
M.@H@("`@8V%S92`G1$]50DQ%)SH*("`@(&-A<V4@)T1!5$5424U%+DE33S@V
M,#$G.@H@("`@8V%S92`G0D%3138T)SH*("`@("`@("!I9B`H)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W%T)UT@/3T@,2D@>PH@("`@("`@("`@("`O+R!W92!U
M<V4@9&]U8FQE('%U;W1E<R!R871H97(@=&AA;B!S:6YG;&4@<V\@8F%C:W-L
M87-H:69I8V%T:6]N('=O<FMS($]+"B`@("`@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=V86QU92==(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C
M)UT["B`@("`@("`@?2!E;'-E:68@*"1834Q?4E!#7WAH6R1P87)S97)=6R=Q
M="==(#T](#(I('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)W9A;'5E)UT@/2!B87-E-C1?9&5C;V1E*"1834Q?4E!#7WAH6R1P87)S97)=
M6R=A8R==*3L*("`@("`@("!](&5L<V5I9B`H)&YA;64@/3T@)T)/3TQ%04XG
M*2!["B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==
M(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C)UT["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+R\@=V4@:&%V92!A;B!)-"P@24Y4(&]R(&$@1$]5
M0DQ%"B`@("`@("`@("`@("\O('=E(&UU<W0@8VAE8VL@=&AA="!O;FQY(#`Q
M,C,T-38W.#DM+CQS<&%C93X@87)E(&-H87)A8W1E<G,@:&5R90H@("`@("`@
M("`@("!I9B`H(65R96<H(EY;*RU=/ULP,3(S-#4V-S@Y(%QT7"Y=*R0B+"`D
M6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72DI('L*("`@("`@("`@("`@("`@
M(%A-3%]24$-?0F%S93HZ<F%I<V5%<G)O<B@G3F]N+6YU;65R:6,@=F%L=64@
M<F5C96EV960@:6X@24Y4(&]R($1/54),12<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U)00U]%4E)/4E].3TY?3E5-
M15))0U]&3U5.1"D["B`@("`@("`@("`@("`@("`D6$U,7U)00U]X:%LD<&%R
M<V5R75LG=F%L=64G72`](%A-3%]24$-?15)23U)?3D].7TY5345224-?1D]5
M3D0["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O+R!I
M="=S(&]K+"!A9&0@:70@;VX*("`@("`@("`@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=V86QU92==(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)V%C
M)UT["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1834Q?4E!#
M7WAH6R1P87)S97)=6R=A8R==(#T@)R<["B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W%T)UT@/2`P.PH@("`@("`@("1834Q?4E!#7WAH6R1P87)S
M97)=6R=L=B==(#T@,SL@+R\@:6YD:6-A=&4@=V4G=F4@9F]U;F0@82!V86QU
M90H@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)U9!3%5%)SH*("`@("`@("!I
M9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9T)UT@/3T@)$=,3T)!3%-;)UA-
M3%]24$-?4W1R:6YG)UTI('L*("`@("`@("`@("`@:68@*'-T<FQE;B@D6$U,
M7U)00U]X:%LD<&%R<V5R75LG86,G72D@/B`P*2!["B`@("`@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`]("1834Q?4E!#7WAH
M6R1P87)S97)=6R=A8R==.PH@("`@("`@("`@("!](&5L<V5I9B`H)%A-3%]2
M4$-?>&A;)'!A<G-E<EU;)VQV)UT@/3T@,2D@>PH@("`@("`@("`@("`@("`@
M+R\@5&AE(#QV86QU93X@96QE;65N="!W87,@96UP='DN"B`@("`@("`@("`@
M("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`]("<G.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D=&5M<"`](&YE=R!834Q?
M4E!#7U9A;'5E*"1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==+"`D6$U,
M7U)00U]X:%LD<&%R<V5R75LG=G0G72D["@H@("`@("`@("1C=7)?=F%L(#T@
M87)R87E?<VAI9G0H)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E<W1A8VLG
M72D["B`@("`@("`@:68@*&ES7V%R<F%Y*"1C=7)?=F%L*2D@>PH@("`@("`@
M("`@("!I9B`H)&-U<E]V86Q;)VUE;6)E<G,G73T],"D@>PH@("`@("`@("`@
M("`@("`@)&-U<E]V86Q;)W9A;'5E)UU;72`]("1T96UP.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)W9A;'5E)UT@/2`D=&5M<#L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!A<G)A>5]U;G-H:69T*"1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU97-T
M86-K)UTL("1C=7)?=F%L*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72`]("1T96UP.PH@("`@
M("`@('T*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=-14U"15(G.@H@("`@
M("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<["B`@("`@("`@
M)%A-3%]24$-?>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH*("`@("`@("`D8W5R
M7W9A;"`](&%R<F%Y7W-H:69T*"1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU
M97-T86-K)UTI.PH@("`@("`@(&EF("AI<U]A<G)A>2@D8W5R7W9A;"DI('L*
M("`@("`@("`@("`@:68@*"1C=7)?=F%L6R=M96UB97)S)UT]/3$I('L*("`@
M("`@("`@("`@("`@("1C=7)?=F%L6R=V86QU92==6R1C=7)?=F%L6R=N86UE
M)UU=(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@87)R87E?=6YS:&EF="@D6$U,7U)00U]X:%LD
M<&%R<V5R75LG=F%L=65S=&%C:R==+"`D8W5R7W9A;"D["B`@("`@("`@?0H@
M("`@("`@(&)R96%K.PH*("`@(&-A<V4@)T1!5$$G.@H@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=A8R==(#T@)R<["B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W%T)UT@/2`P.PH@("`@("`@(&)R96%K.PH*("`@(&-A
M<V4@)U!!4D%-)SH*("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG<&%R
M86US)UU;72`]("1834Q?4E!#7WAH6R1P87)S97)=6R=V86QU92==.PH@("`@
M("`@(&)R96%K.PH*("`@(&-A<V4@)TU%5$A/1$Y!344G.@H@("`@8V%S92`G
M4E!#34542$]$3D%-12<Z"B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;
M)VUE=&AO9"==(#T@97)E9U]R97!L86-E*")>6UQN7')<="!=*R(L("<G+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72D["B`@("`@("`@
M8G)E86L["B`@("!]"@H@("`@+R\@:68@:70G<R!A('9A;&ED('1Y<&4@;F%M
M92P@<V5T('1H92!T>7!E"B`@("!I9B`H:7-S970H)$=,3T)!3%-;)UA-3%]2
M4$-?5'EP97,G75MS=')T;VQO=V5R*"1N86UE*5TI*2!["B`@("`@("`@)%A-
M3%]24$-?>&A;)'!A<G-E<EU;)W9T)UT@/2!S=')T;VQO=V5R*"1N86UE*3L*
M("`@('T*?0H*+RHJ"B`J($-H87)A8W1E<B!D871A(&AA;F1L97(@9F]R('1H
M92!834P@<&%R<V5R"B`J"B`J($!R971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@
M6$U,7U)00U]C9"@D<&%R<V5R7W)E<V]U<F-E+"`D9&%T82D*>PH@("`@9VQO
M8F%L("1834Q?4E!#7WAH+"`D6$U,7U)00U]B86-K<VQA<V@["@H@("`@)'!A
M<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R8V4["@H@("`@:68@*"1834Q?
M4E!#7WAH6R1P87)S97)=6R=L=B==("$](#,I('L*("`@("`@("`O+R`B;&]O
M:V9O<G9A;'5E/3TS(B!M96%N<R!T:&%T('=E)W9E(&9O=6YD(&%N(&5N=&ER
M92!V86QU90H@("`@("`@("\O(&%N9"!S:&]U;&0@9&ES8V%R9"!A;GD@9G5R
M=&AE<B!C:&%R86-T97(@9&%T80H*("`@("`@("!I9B`H)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)VQV)UT@/3T@,2D@>PH@("`@("`@("`@("`O+R!I9B!W92=V
M92!F;W5N9"!T97AT(&%N9"!W92=R92!J=7-T(&EN(&$@/'9A;'5E/B!T:&5N
M"B`@("`@("`@("`@("\O('1U<FX@<75O=&EN9R!O;BP@87,@=&AI<R!W:6QL
M(&)E(&$@<W1R:6YG"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=
M6R=Q="==(#T@,3L*("`@("`@("`@("`@+R\@86YD('-A>2!W92=V92!F;W5N
M9"!A('9A;'5E"B`@("`@("`@("`@("1834Q?4E!#7WAH6R1P87)S97)=6R=L
M=B==(#T@,CL*("`@("`@("!]"@H@("`@("`@("\O(')E<&QA8V4@8VAA<F%C
M=&5R<R!T:&%T(&5V86P@=V]U;&0*("`@("`@("`O+R!D;R!S<&5C:6%L('1H
M:6YG<R!W:71H"B`@("`@("`@:68@*"%I<W-E="@D6$U,7U)00U]X:%LD<&%R
M<V5R75LG86,G72DI('L*("`@("`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)V%C)UT@/2`G)SL*("`@("`@("!]"B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)V%C)UT@+CT@)&1A=&$["B`@("!]"GT*"B\J*@H@*B!4:&4@
M8V]M;6]N(&UE=&AO9',@86YD('!R;W!E<G1I97,@9F]R(&%L;"!O9B!T:&4@
M6$U,7U)00R!C;&%S<V5S"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E
M<PH@*B!`<&%C:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$
M=6UB:6QL(#QE9&1`=7-E9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I
M9R!"86MK96X@/'-T:6=`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN
M($IA;G-E;B`\;6I`<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O
M;G9I<W-O<B`\9&%N:65L8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY
M+3(P,#$@161D($1U;6)I;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J
M($!V97)S:6]N("`@(%)E;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@(&AT
M='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S<R!8
M34Q?4E!#7T)A<V4@>PH*("`@("\J*@H@("`@("H@4$5!4B!%<G)O<B!H86YD
M;&EN9PH@("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!014%27T5R<F]R
M(&]B:F5C=`H@("`@("HO"B`@("!F=6YC=&EO;B!R86ES945R<F]R*"1M<V<L
M("1C;V1E*0H@("`@>PH@("`@("`@(&EN8VQU9&5?;VYC92`G4$5!4BYP:'`G
M.PH@("`@("`@(&EF("AI<U]O8FIE8W0H0"1T:&ES*2D@>PH@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<BAG971?8VQA<W,H)'1H:7,I("X@
M)SH@)R`N("1M<V<L("1C;V1E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G6$U,7U)00SH@)R`N("1M
M<V<L("1C;V1E*3L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!4
M96QL('=H971H97(@<V]M971H:6YG(&ES(&$@4$5!4E]%<G)O<B!O8FIE8W0*
M("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@)'9A;'5E("!T:&4@:71E;2!T
M;R!C:&5C:PH@("`@("H*("`@("`J($!R971U<FX@8F]O;"`@=VAE=&AE<B`D
M=F%L=64@:7,@82!014%27T5R<F]R(&]B:F5C="!O<B!N;W0*("`@("`J"B`@
M("`@*B!`86-C97-S('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<T5R
M<F]R*"1V86QU92D*("`@('L*("`@("`@("!R971U<FX@:7-?82@D=F%L=64L
M("=014%27T5R<F]R)RD["B`@("!]"GT*"B\J*@H@*B!4:&4@;65T:&]D<R!A
M;F0@<')O<&5R=&EE<R!F;W(@<W5B;6ET=&EN9R!834P@4E!#(')E<75E<W1S
M"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$=6UB:6QL(#QE9&1`=7-E
M9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-T:6=`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP
M+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY+3(P,#$@161D($1U;6)I
M;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S<R!834Q?4E!#7T-L:65N="!E
M>'1E;F1S(%A-3%]24$-?0F%S92!["@H@("`@+RHJ"B`@("`@*B!4:&4@<&%T
M:"!A;F0@;F%M92!O9B!T:&4@4E!#('-E<G9E<B!S8W)I<'0@>6]U('=A;G0@
M=&AE(')E<75E<W0@=&\@9V\@=&\*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D<&%T:"`]("<G.PH*("`@("\J*@H@("`@("H@5&AE(&YA
M;64@;V8@=&AE(')E;6]T92!S97)V97(@=&\@8V]N;F5C="!T;PH@("`@("H@
M0'9A<B!S=')I;F<*("`@("`J+PH@("`@=F%R("1S97)V97(@/2`G)SL*"B`@
M("`O*BH*("`@("`J(%1H92!P<F]T;V-O;"!T;R!U<V4@:6X@8V]N=&%C=&EN
M9R!T:&4@<F5M;W1E('-E<G9E<@H@("`@("H@0'9A<B!S=')I;F<*("`@("`J
M+PH@("`@=F%R("1P<F]T;V-O;"`]("=H='1P.B\O)SL*"B`@("`O*BH*("`@
M("`J(%1H92!P;W)T(&9O<B!C;VYN96-T:6YG('1O('1H92!R96UO=&4@<V5R
M=F5R"B`@("`@*@H@("`@("H@5&AE(&1E9F%U;'0@:7,@.#`@9F]R(&AT='`Z
M+R\@8V]N;F5C=&EO;G,*("`@("`J(&%N9"`T-#,@9F]R(&AT='!S.B\O(&%N
M9"!S<VPZ+R\@8V]N;F5C=&EO;G,N"B`@("`@*@H@("`@("H@0'9A<B!I;G1E
M9V5R"B`@("`@*B\*("`@('9A<B`D<&]R="`](#@P.PH*("`@("\J*@H@("`@
M("H@02!U<V5R(&YA;64@9F]R(&%C8V5S<VEN9R!T:&4@4E!#('-E<G9E<@H@
M("`@("H@0'9A<B!S=')I;F<*("`@("`J($!S964@6$U,7U)00U]#;&EE;G0Z
M.G-E=$-R961E;G1I86QS*"D*("`@("`J+PH@("`@=F%R("1U<V5R;F%M92`]
M("<G.PH*("`@("\J*@H@("`@("H@02!P87-S=V]R9"!F;W(@86-C97-S:6YG
M('1H92!24$,@<V5R=F5R"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("H@0'-E
M92!834Q?4E!#7T-L:65N=#HZ<V5T0W)E9&5N=&EA;',H*0H@("`@("HO"B`@
M("!V87(@)'!A<W-W;W)D(#T@)R<["@H@("`@+RHJ"B`@("`@*B!4:&4@;F%M
M92!O9B!T:&4@<')O>'D@<V5R=F5R('1O('5S92P@:68@86YY"B`@("`@*B!`
M=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)'!R;WAY(#T@)R<["@H@("`@
M+RHJ"B`@("`@*B!4:&4@<')O=&]C;VP@=&\@=7-E(&EN(&-O;G1A8W1I;F<@
M=&AE('!R;WAY('-E<G9E<BP@:68@86YY"B`@("`@*B!`=F%R('-T<FEN9PH@
M("`@("HO"B`@("!V87(@)'!R;WAY7W!R;W1O8V]L(#T@)VAT='`Z+R\G.PH*
M("`@("\J*@H@("`@("H@5&AE('!O<G0@9F]R(&-O;FYE8W1I;F<@=&\@=&AE
M('!R;WAY('-E<G9E<@H@("`@("H*("`@("`J(%1H92!D969A=6QT(&ES(#@P
M.#`@9F]R(&AT='`Z+R\@8V]N;F5C=&EO;G,*("`@("`J(&%N9"`T-#,@9F]R
M(&AT='!S.B\O(&%N9"!S<VPZ+R\@8V]N;F5C=&EO;G,N"B`@("`@*@H@("`@
M("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*("`@('9A<B`D<')O>'E?<&]R="`]
M(#@P.#`["@H@("`@+RHJ"B`@("`@*B!!('5S97(@;F%M92!F;W(@86-C97-S
M:6YG('1H92!P<F]X>2!S97)V97(*("`@("`J($!V87(@<W1R:6YG"B`@("`@
M*B\*("`@('9A<B`D<')O>'E?=7-E<B`]("<G.PH*("`@("\J*@H@("`@("H@
M02!P87-S=V]R9"!F;W(@86-C97-S:6YG('1H92!P<F]X>2!S97)V97(*("`@
M("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A<B`D<')O>'E?<&%S<R`]
M("<G.PH*("`@("\J*@H@("`@("H@5&AE(&5R<F]R(&YU;6)E<BP@:68@86YY
M"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@("`@=F%R("1E<G)N;R`]
M(#`["@H@("`@+RHJ"B`@("`@*B!4:&4@97)R;W(@;65S<V%G92P@:68@86YY
M"B`@("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&5R<G-T<B`]
M("<G.PH*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@9&5B=6<@;6]D92`H
M,2`](&]N+"`P(#T@;V9F*0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D9&5B=6<@/2`P.PH*("`@("\J*@H@("`@("H@5&AE($A45%`@
M:&5A9&5R<R!F;W(@=&AE(&-U<G)E;G0@<F5Q=65S="X*("`@("`J($!V87(@
M<W1R:6YG"B`@("`@*B\*("`@('9A<B`D:&5A9&5R<R`]("<G.PH*"B`@("`O
M*BH*("`@("`J(%-E=',@=&AE(&]B:F5C="=S('!R;W!E<G1I97,*("`@("`J
M"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<&%T:"`@("`@("`@=&AE('!A=&@@
M86YD(&YA;64@;V8@=&AE(%)00R!S97)V97(@<V-R:7!T"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('EO=2!W86YT('1H92!R97%U97-T
M('1O(&=O('1O"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<V5R=F5R("`@("`@
M=&AE(%523"!O9B!T:&4@<F5M;W1E('-E<G9E<B!T;R!C;VYN96-T('1O+@H@
M("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!)9B!T:&ES('!A
M<F%M971E<B!D;V5S;B=T('-P96-I9GD@80H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!P<F]T;V-O;"!A;F0@)'!O<G0@:7,@-#0S+"!S
M<VPZ+R\@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M87-S=6UE9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1P;W)T("`@("`@("!A
M('!O<G0@9F]R(&-O;FYE8W1I;F<@=&\@=&AE(')E;6]T92!S97)V97(N"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E9F%U;'1S('1O
M(#@P(&9O<B!H='1P.B\O(&-O;FYE8W1I;VYS(&%N9`H@("`@("H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`T-#,@9F]R(&AT='!S.B\O(&%N9"!S
M<VPZ+R\@8V]N;F5C=&EO;G,N"B`@("`@*B!`<&%R86T@<W1R:6YG("`D<')O
M>'D@("`@("`@=&AE(%523"!O9B!T:&4@<')O>'D@<V5R=F5R('1O('5S92P@
M:68@86YY+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!)
M9B!T:&ES('!A<F%M971E<B!D;V5S;B=T('-P96-I9GD@80H@("`@("H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!P<F]T;V-O;"!A;F0@)'!O<G0@
M:7,@-#0S+"!S<VPZ+R\@:7,*("`@("`J("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@87-S=6UE9"X*("`@("`J($!P87)A;2!I;G1E9V5R("1P<F]X
M>5]P;W)T("!A('!O<G0@9F]R(&-O;FYE8W1I;F<@=&\@=&AE(')E;6]T92!S
M97)V97(N"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@($1E
M9F%U;'1S('1O(#@P.#`@9F]R(&AT='`Z+R\@8V]N;F5C=&EO;G,@86YD"B`@
M("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(#0T,R!F;W(@:'1T
M<',Z+R\@86YD('-S;#HO+R!C;VYN96-T:6]N<RX*("`@("`J($!P87)A;2!S
M=')I;F<@("1P<F]X>5]U<V5R("!A('5S97(@;F%M92!F;W(@86-C97-S:6YG
M('1H92!P<F]X>2!S97)V97(*("`@("`J($!P87)A;2!S=')I;F<@("1P<F]X
M>5]P87-S("!A('!A<W-W;W)D(&9O<B!A8V-E<W-I;F<@=&AE('!R;WAY('-E
M<G9E<@H@("`@("H*("`@("`J($!R971U<FX@=F]I9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!834Q?4E!#7T-L:65N="@D<&%T:"P@)'-E<G9E<BP@)'!O<G0@
M/2`P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R;WAY(#T@)R<L
M("1P<F]X>5]P;W)T(#T@,"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F]X>5]U<V5R(#T@)R<L("1P<F]X>5]P87-S(#T@)R<I"B`@("!["B`@
M("`@("`@)'1H:7,M/G!A=&@@("`@("`@/2`D<&%T:#L*("`@("`@("`D=&AI
M<RT^<')O>'E?=7-E<B`]("1P<F]X>5]U<V5R.PH@("`@("`@("1T:&ES+3YP
M<F]X>5]P87-S(#T@)'!R;WAY7W!A<W,["@H@("`@("`@('!R96=?;6%T8V@H
M)T!>*&AT='`Z+R]\:'1T<',Z+R]\<W-L.B\O*3\H+BHI)$`G+"`D<V5R=F5R
M+"`D;6%T8V@I.PH@("`@("`@(&EF("@D;6%T8VA;,5T@/3T@)R<I('L*("`@
M("`@("`@("`@:68@*"1P;W)T(#T](#0T,RD@>PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G-E<G9E<B`@(#T@)&UA=&-H6S)=.PH@("`@("`@("`@("`@("`@
M)'1H:7,M/G!R;W1O8V]L(#T@)W-S;#HO+R<["B`@("`@("`@("`@("`@("`D
M=&AI<RT^<&]R="`@("`@/2`T-#,["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D=&AI<RT^<V5R=F5R(#T@)&UA=&-H6S)=.PH@("`@
M("`@("`@("`@("`@:68@*"1P;W)T*2!["B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/G!O<G0@/2`D<&]R=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS96EF("@D;6%T8VA;,5T@/3T@)VAT='`Z
M+R\G*2!["B`@("`@("`@("`@("1T:&ES+3YS97)V97(@/2`D;6%T8VA;,ET[
M"B`@("`@("`@("`@(&EF("@D<&]R="D@>PH@("`@("`@("`@("`@("`@)'1H
M:7,M/G!O<G0@/2`D<&]R=#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("1T:&ES+3YS97)V97(@("`]("1M871C:%LR73L*
M("`@("`@("`@("`@)'1H:7,M/G!R;W1O8V]L(#T@)W-S;#HO+R<["B`@("`@
M("`@("`@(&EF("@D<&]R="D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G!O
M<G0@/2`D<&]R=#L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M("`@("1T:&ES+3YP;W)T(#T@-#0S.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H)'!R;WAY*2!["B`@("`@("`@("`@('!R96=?;6%T
M8V@H)T!>*&AT='`Z+R]\:'1T<',Z+R]\<W-L.B\O*3\H+BHI)$`G+"`D<')O
M>'DL("1M871C:"D["B`@("`@("`@("`@(&EF("@D;6%T8VA;,5T@/3T@)R<I
M('L*("`@("`@("`@("`@("`@(&EF("@D<')O>'E?<&]R="`]/2`T-#,I('L*
M("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<')O>'D@("`@("`@("`@/2`D
M;6%T8VA;,ET["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY7W!R
M;W1O8V]L(#T@)W-S;#HO+R<["B`@("`@("`@("`@("`@("`@("`@)'1H:7,M
M/G!R;WAY7W!O<G0@("`@(#T@-#0S.PH@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^<')O>'D@/2`D;6%T8VA;
M,ET["B`@("`@("`@("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YP<F]X>5]P;W)T(#T@)'!R
M;WAY7W!O<G0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("!](&5L<V5I9B`H)&UA=&-H6S%=(#T]("=H='1P
M.B\O)RD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY(#T@)&UA=&-H
M6S)=.PH@("`@("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T*2!["B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY7W!O<G0@/2`D<')O>'E?<&]R
M=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1T:&ES+3YP<F]X>2`@("`@("`@("`]("1M871C:%LR
M73L*("`@("`@("`@("`@("`@("1T:&ES+3YP<F]X>5]P<F]T;V-O;"`]("=S
M<VPZ+R\G.PH@("`@("`@("`@("`@("`@:68@*"1P<F]X>5]P;W)T*2!["B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/G!R;WAY7W!O<G0@/2`D<')O>'E?
M<&]R=#L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G!R;WAY7W!O<G0@/2`T-#,["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@
M("`@*B!#:&%N9V4@=&AE(&-U<G)E;G0@9&5B=6<@;6]D90H@("`@("H*("`@
M("`J($!P87)A;2!I;G0@)&EN("!W:&5R92`Q(#T@;VXL(#`@/2!O9F8*("`@
M("`J"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@
M<V5T1&5B=6<H)&EN*0H@("`@>PH@("`@("`@(&EF("@D:6XI('L*("`@("`@
M("`@("`@)'1H:7,M/F1E8G5G(#T@,3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^9&5B=6<@/2`P.PH@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("`J(%-E="!U<V5R;F%M92!A;F0@<&%S<W=O<F0@<')O<&5R
M=&EE<R!F;W(@8V]N;F5C=&EN9R!T;R!T:&4@4E!#('-E<G9E<@H@("`@("H*
M("`@("`J($!P87)A;2!S=')I;F<@)'4@('1H92!U<V5R(&YA;64*("`@("`J
M($!P87)A;2!S=')I;F<@)'`@('1H92!P87-S=V]R9`H@("`@("H*("`@("`J
M($!R971U<FX@=F]I9`H@("`@("H*("`@("`J($!S964@6$U,7U)00U]#;&EE
M;G0Z.B1U<V5R;F%M92P@6$U,7U)00U]#;&EE;G0Z.B1P87-S=V]R9`H@("`@
M("HO"B`@("!F=6YC=&EO;B!S971#<F5D96YT:6%L<R@D=2P@)'`I"B`@("![
M"B`@("`@("`@)'1H:7,M/G5S97)N86UE(#T@)'4["B`@("`@("`@)'1H:7,M
M/G!A<W-W;W)D(#T@)'`["B`@("!]"@H@("`@+RHJ"B`@("`@*B!4<F%N<VUI
M="!T:&4@4E!#(')E<75E<W0@=FEA($A45%`@,2XP('!R;W1O8V]L"B`@("`@
M*@H@("`@("H@0'!A<F%M(&]B:F5C="`D;7-G("`@("`@('1H92!834Q?4E!#
M7TUE<W-A9V4@;V)J96-T"B`@("`@*B!`<&%R86T@:6YT("`@("1T:6UE;W5T
M("`@:&]W(&UA;GD@<V5C;VYD<R!T;R!W86ET(&9O<B!T:&4@<F5Q=65S=`H@
M("`@("H*("`@("`J($!R971U<FX@;V)J96-T("!A;B!834Q?4E!#7U)E<W!O
M;G-E(&]B:F5C="X@(#`@:7,@<F5T=7)N960@:68@86YY"B`@("`@*B`@("`@
M("`@("`@("`@("`@('!R;V)L96US(&AA<'!E;BX*("`@("`J"B`@("`@*B!`
M<V5E(%A-3%]24$-?365S<V%G92P@6$U,7U)00U]#;&EE;G0Z.EA-3%]24$-?
M0VQI96YT*"DL"B`@("`@*B`@("`@(%A-3%]24$-?0VQI96YT.CIS971#<F5D
M96YT:6%L<R@I"B`@("`@*B\*("`@(&9U;F-T:6]N('-E;F0H)&US9RP@)'1I
M;65O=70@/2`P*0H@("`@>PH@("`@("`@(&EF("@A:7-?82@D;7-G+"`G6$U,
M7U)00U]-97-S86=E)RDI('L*("`@("`@("`@("`@)'1H:7,M/F5R<G-T<B`]
M("=S96YD*"E<)W,@)&US9R!P87)A;65T97(@;75S="!B92!A;B<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`N("<@6$U,7U)00U]-97-S86=E(&]B:F5C
M="XG.PH@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@D=&AI<RT^97)R
M<W1R+"!834Q?4E!#7T524D]27U!23T=204U-24Y'*3L*("`@("`@("`@("`@
M<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@("1M<V<M/F1E8G5G(#T@)'1H
M:7,M/F1E8G5G.PH@("`@("`@(')E='5R;B`D=&AI<RT^<V5N9%!A>6QO861(
M5%10,3`H)&US9RP@)'1H:7,M/G-E<G9E<BP@)'1H:7,M/G!O<G0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&EM96]U="P@
M)'1H:7,M/G5S97)N86UE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/G!A<W-W;W)D*3L*("`@('T*"B`@("`O*BH*
M("`@("`J(%1R86YS;6ET('1H92!24$,@<F5Q=65S="!V:6$@2%144"`Q+C`@
M<')O=&]C;VP*("`@("`J"B`@("`@*B!297%U97-T<R!S:&]U;&0@8F4@<V5N
M="!U<VEN9R!834Q?4E!#7T-L:65N="!S96YD*"D@<F%T:&5R('1H86X*("`@
M("`J(&-A;&QI;F<@=&AI<R!M971H;V0@9&ER96-T;'DN"B`@("`@*@H@("`@
M("H@0'!A<F%M(&]B:F5C="`D;7-G("`@("`@('1H92!834Q?4E!#7TUE<W-A
M9V4@;V)J96-T"B`@("`@*B!`<&%R86T@<W1R:6YG("1S97)V97(@("`@=&AE
M('-E<G9E<B!T;R!S96YD('1H92!R97%U97-T('1O"B`@("`@*B!`<&%R86T@
M:6YT("`@("1P;W)T("`@("`@=&AE('-E<G9E<B!P;W)T('-E;F0@=&AE(')E
M<75E<W0@=&\*("`@("`J($!P87)A;2!I;G0@("`@)'1I;65O=70@("!H;W<@
M;6%N>2!S96-O;F1S('1O('=A:70@9F]R('1H92!R97%U97-T"B`@("`@*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)E9F]R92!G:79I;F<@=7`*("`@
M("`J($!P87)A;2!S=')I;F<@)'5S97)N86UE("!A('5S97(@;F%M92!F;W(@
M86-C97-S:6YG('1H92!24$,@<V5R=F5R"B`@("`@*B!`<&%R86T@<W1R:6YG
M("1P87-S=V]R9"`@82!P87-S=V]R9"!F;W(@86-C97-S:6YG('1H92!24$,@
M<V5R=F5R"B`@("`@*@H@("`@("H@0')E='5R;B!O8FIE8W0@(&%N(%A-3%]2
M4$-?4F5S<&]N<V4@;V)J96-T+B`@,"!I<R!R971U<FYE9"!I9B!A;GD*("`@
M("`J("`@("`@("`@("`@("`@("`@<')O8FQE;7,@:&%P<&5N+@H@("`@("H*
M("`@("`J($!A8V-E<W,@<')O=&5C=&5D"B`@("`@*B!`<V5E(%A-3%]24$-?
M0VQI96YT.CIS96YD*"D*("`@("`J+PH@("`@9G5N8W1I;VX@<V5N9%!A>6QO
M861(5%10,3`H)&US9RP@)'-E<G9E<BP@)'!O<G0L("1T:6UE;W5T(#T@,"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1U<V5R;F%M92`]("<G
M+"`D<&%S<W=O<F0@/2`G)RD*("`@('L*("`@("`@("`O*@H@("`@("`@("`J
M($EF('=E)W)E('5S:6YG(&$@<')O>'D@;W!E;B!A('-O8VME="!T;R!T:&4@
M<')O>'D@<V5R=F5R"B`@("`@("`@("H@:6YS=&5A9"!T;R!T:&4@>&UL+7)P
M8R!S97)V97(*("`@("`@("`@*B\*("`@("`@("!I9B`H)'1H:7,M/G!R;WAY
M*2!["B`@("`@("`@("`@(&EF("@D=&AI<RT^<')O>'E?<')O=&]C;VP@/3T@
M)VAT='`Z+R\G*2!["B`@("`@("`@("`@("`@("`D<')O=&]C;VP@/2`G)SL*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1P<F]T;V-O
M;"`]("1T:&ES+3YP<F]X>5]P<F]T;V-O;#L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H)'1I;65O=70@/B`P*2!["B`@("`@("`@("`@("`@("`D
M9G`@/2!`9G-O8VMO<&5N*"1P<F]T;V-O;"`N("1T:&ES+3YP<F]X>2P@)'1H
M:7,M/G!R;WAY7W!O<G0L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3YE<G)N;RP@)'1H:7,M/F5R<G-T<BP@)'1I;65O=70I.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&9P(#T@0&9S
M;V-K;W!E;B@D<')O=&]C;VP@+B`D=&AI<RT^<')O>'DL("1T:&ES+3YP<F]X
M>5]P;W)T+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^97)R;F\L("1T:&ES+3YE<G)S='(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"1T:&ES+3YP<F]T;V-O;"`]
M/2`G:'1T<#HO+R<I('L*("`@("`@("`@("`@("`@("1P<F]T;V-O;"`]("<G
M.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)'!R;W1O
M8V]L(#T@)'1H:7,M/G!R;W1O8V]L.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&EF("@D=&EM96]U="`^(#`I('L*("`@("`@("`@("`@("`@("1F<"`]
M($!F<V]C:V]P96XH)'!R;W1O8V]L("X@)'-E<G9E<BP@)'!O<G0L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YE<G)N;RP@)'1H
M:7,M/F5R<G-T<BP@)'1I;65O=70I.PH@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@)&9P(#T@0&9S;V-K;W!E;B@D<')O=&]C;VP@+B`D
M<V5R=F5R+"`D<&]R="P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/F5R<FYO+"`D=&AI<RT^97)R<W1R*3L*("`@("`@("`@("`@
M?0H@("`@("`@('T*"B`@("`@("`@+RH*("`@("`@("`@*B!*=7-T(')A:7-I
M;F<@=&AE(&5R<F]R('=I=&AO=70@<F5T=7)N:6YG(&ET(&ES('-T<F%N9V4L
M"B`@("`@("`@("H@8G5T(&ME97`@:70@:&5R92!F;W(@8F%C:W=A<F1S(&-O
M;7!A=&EB:6QI='DN"B`@("`@("`@("HO"B`@("`@("`@:68@*"$D9G`@)B8@
M)'1H:7,M/G!R;WAY*2!["B`@("`@("`@("`@("1T:&ES+3YR86ES945R<F]R
M*"=#;VYN96-T:6]N('1O('!R;WAY('-E<G9E<B`G"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("X@)'1H:7,M/G!R;WAY("X@)SHG("X@)'1H:7,M
M/G!R;WAY7W!O<G0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G
M(&9A:6QE9"X@)R`N("1T:&ES+3YE<G)S='(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(%A-3%]24$-?15)23U)?0T].3D5#5$E/3E]&04E,140I
M.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!](&5L<V5I9B`H(21F
M<"D@>PH@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@G0V]N;F5C=&EO
M;B!T;R!24$,@<V5R=F5R("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`D<V5R=F5R("X@)SHG("X@)'!O<G0*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+B`G(&9A:6QE9"X@)R`N("1T:&ES+3YE<G)S='(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?15)23U)?0T].
M3D5#5$E/3E]&04E,140I.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@
M("!]"@H@("`@("`@(&EF("@D=&EM96]U="D@>PH@("`@("`@("`@("`O*@H@
M("`@("`@("`@("`@*B!5<VEN9R!S;V-K971?<V5T7W1I;65O=70H*2!B96-A
M=7-E('-T<F5A;5]S971?=&EM96]U="@I"B`@("`@("`@("`@("`J('=A<R!I
M;G1R;V1U8V5D(&EN(#0N,RXP+"!B=70@=V4@;F5E9"!T;R!S=7!P;W)T(#0N
M,BXP+@H@("`@("`@("`@("`@*B\*("`@("`@("`@("`@<V]C:V5T7W-E=%]T
M:6UE;W5T*"1F<"P@)'1I;65O=70I.PH@("`@("`@('T*"B`@("`@("`@+R\@
M4')E+65M<'1I=F4@0D,@:&%C:W,@9F]R(&9O;VQS(&-A;&QI;F<@<V5N9%!A
M>6QO861(5%10,3`H*2!D:7)E8W1L>0H@("`@("`@(&EF("@D=7-E<FYA;64@
M(3T@)'1H:7,M/G5S97)N86UE*2!["B`@("`@("`@("`@("1T:&ES+3YS971#
M<F5D96YT:6%L<R@D=7-E<FYA;64L("1P87-S=V]R9"D["B`@("`@("`@?0H*
M("`@("`@("`O+R!/;FQY(&-R96%T92!T:&4@<&%Y;&]A9"!I9B!I="!W87,@
M;F]T(&-R96%T960@<')E=FEO=7-L>0H@("`@("`@(&EF("AE;7!T>2@D;7-G
M+3YP87EL;V%D*2D@>PH@("`@("`@("`@("`D;7-G+3YC<F5A=&5087EL;V%D
M*"D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YC<F5A=&5(96%D97)S*"1M
M<V<I.PH*("`@("`@("`D;W`@(#T@)'1H:7,M/FAE861E<G,@+B`B7')<;EQR
M7&XB.PH@("`@("`@("1O<"`N/2`D;7-G+3YP87EL;V%D.PH*("`@("`@("!I
M9B`H(69P=71S*"1F<"P@)&]P+"!S=')L96XH)&]P*2DI('L*("`@("`@("`@
M("`@)'1H:7,M/F5R<G-T<B`]("=7<FET92!E<G)O<B<["B`@("`@("`@("`@
M(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("`D<F5S<"`]("1M<V<M/G!A
M<G-E4F5S<&]N<V5&:6QE*"1F<"D["@H@("`@("`@("1M971A(#T@<V]C:V5T
M7V=E=%]S=&%T=7,H)&9P*3L*("`@("`@("!I9B`H)&UE=&%;)W1I;65D7V]U
M="==*2!["B`@("`@("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@("`@("`D
M=&AI<RT^97)R<W1R(#T@)U)00R!S97)V97(@9&ED(&YO="!S96YD(')E<W!O
M;G-E(&)E9F]R92!T:6UE;W5T+B<["B`@("`@("`@("`@("1T:&ES+3YR86ES
M945R<F]R*"1T:&ES+3YE<G)S='(L(%A-3%]24$-?15)23U)?0T].3D5#5$E/
M3E]&04E,140I.PH@("`@("`@("`@("!R971U<FX@,#L*("`@("`@("!]"@H@
M("`@("`@(&9C;&]S92@D9G`I.PH@("`@("`@(')E='5R;B`D<F5S<#L*("`@
M('T*"B`@("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE($A45%`@:&5A9&5R
M<R!A;F0@<'5T<R!I="!I;B!T:&4@)&AE861E<G,@<')O<&5R='D*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T("1M<V<@("`@("`@=&AE(%A-3%]24$-?
M365S<V%G92!O8FIE8W0*("`@("`J"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@
M(%12544@:68@;VMA>2P@1D%,4T4@:68@=&AE(&UE<W-A9V4@<&%Y;&]A9"!I
M<VXG="!S970N"B`@("`@*@H@("`@("H@0&%C8V5S<R!P<F]T96-T960*("`@
M("`J+PH@("`@9G5N8W1I;VX@8W)E871E2&5A9&5R<R@D;7-G*0H@("`@>PH@
M("`@("`@(&EF("AE;7!T>2@D;7-G+3YP87EL;V%D*2D@>PH@("`@("`@("`@
M("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@("`@(&EF("@D=&AI<RT^
M<')O>'DI('L*("`@("`@("`@("`@)'1H:7,M/FAE861E<G,@/2`G4$]35"`G
M("X@)'1H:7,M/G!R;W1O8V]L("X@)'1H:7,M/G-E<G9E<CL*("`@("`@("`@
M("`@:68@*"1T:&ES+3YP<F]X>5]P;W)T*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^:&5A9&5R<R`N/2`G.B<@+B`D=&AI<RT^<&]R=#L*("`@("`@("`@
M("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@)'1H:7,M/FAE861E
M<G,@/2`G4$]35"`G.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^:&5A9&5R
M<R`N/2`D=&AI<RT^<&%T:"X@(B!(5%10+S$N,%QR7&XB.PH*("`@("`@("`D
M=&AI<RT^:&5A9&5R<R`N/2`B57-E<BU!9V5N=#H@4$5!4B!834Q?4E!#7')<
M;B(["B`@("`@("`@)'1H:7,M/FAE861E<G,@+CT@)TAO<W0Z("<@+B`D=&AI
M<RT^<V5R=F5R("X@(EQR7&XB.PH*("`@("`@("!I9B`H)'1H:7,M/G!R;WAY
M("8F("1T:&ES+3YP<F]X>5]U<V5R*2!["B`@("`@("`@("`@("1T:&ES+3YH
M96%D97)S("X]("=0<F]X>2U!=71H;W)I>F%T:6]N.B!"87-I8R`G"B`@("`@
M("`@("`@("`@("`@("`@("X@8F%S938T7V5N8V]D92@B)'1H:7,M/G!R;WAY
M7W5S97(Z)'1H:7,M/G!R;WAY7W!A<W,B*0H@("`@("`@("`@("`@("`@("`@
M("`N(")<<EQN(CL*("`@("`@("!]"@H@("`@("`@("\O('1H86YK<R!T;R!'
M<F%N="!2875S8VAE<B`\9W)A;G0W0&9I<G-T=V]R;&0N;F5T/B!F;W(@=&AI
M<PH@("`@("`@(&EF("@D=&AI<RT^=7-E<FYA;64I('L*("`@("`@("`@("`@
M)'1H:7,M/FAE861E<G,@+CT@)T%U=&AO<FEZ871I;VXZ($)A<VEC("<*("`@
M("`@("`@("`@("`@("`@("`@+B!B87-E-C1?96YC;V1E*"(D=&AI<RT^=7-E
M<FYA;64Z)'1H:7,M/G!A<W-W;W)D(BD*("`@("`@("`@("`@("`@("`@("`@
M+B`B7')<;B(["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^:&5A9&5R<R`N
M/2`B0V]N=&5N="U4>7!E.B!T97AT+WAM;%QR7&XB.PH@("`@("`@("1T:&ES
M+3YH96%D97)S("X]("=#;VYT96YT+4QE;F=T:#H@)R`N('-T<FQE;B@D;7-G
M+3YP87EL;V%D*3L*("`@("`@("!R971U<FX@=')U93L*("`@('T*?0H*+RHJ
M"B`J(%1H92!M971H;V1S(&%N9"!P<F]P97)T:65S(&9O<B!I;G1E<G!R971I
M;F<@<F5S<&]N<V5S('1O(%A-3"!24$,@<F5Q=65S=',*("H*("H@0&-A=&5G
M;W)Y("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@
M0&%U=&AO<B`@("`@161D($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@
M*B!`875T:&]R("`@("!3=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`
M875T:&]R("`@("!-87)T:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T
M:&]R("`@("!$86YI96P@0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J
M($!C;W!Y<FEG:'0@(#$Y.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U
M(%1H92!02%`@1W)O=7`*("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C@*
M("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-
M3%]24$,*("HO"F-L87-S(%A-3%]24$-?4F5S<&]N<V4@97AT96YD<R!834Q?
M4E!#7T)A<V4*>PH@("`@=F%R("1X=CL*("`@('9A<B`D9FX["B`@("!V87(@
M)&9S.PH@("`@=F%R("1H9')S.PH*("`@("\J*@H@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]24$-?4F5S<&]N<V4H)'9A
M;"P@)&9C;V1E(#T@,"P@)&9S='(@/2`G)RD*("`@('L*("`@("`@("!I9B`H
M)&9C;V1E("$](#`I('L*("`@("`@("`@("`@)'1H:7,M/F9N(#T@)&9C;V1E
M.PH@("`@("`@("`@("`D=&AI<RT^9G,@/2!H=&UL<W!E8VEA;&-H87)S*"1F
M<W1R*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^>'8@
M/2`D=F%L.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J($!R971U
M<FX@:6YT("!T:&4@97)R;W(@8V]D90H@("`@("HO"B`@("!F=6YC=&EO;B!F
M875L=$-O9&4H*0H@("`@>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9FXI
M*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^9FX["B`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@?0H*
M("`@("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!E<G)O<B!S=')I
M;F<*("`@("`J+PH@("`@9G5N8W1I;VX@9F%U;'13=')I;F<H*0H@("`@>PH@
M("`@("`@(')E='5R;B`D=&AI<RT^9G,["B`@("!]"@H@("`@+RHJ"B`@("`@
M*B!`<F5T=7)N(&UI>&5D("!T:&4@=F%L=64*("`@("`J+PH@("`@9G5N8W1I
M;VX@=F%L=64H*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^>'8["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&5R<F]R
M(&UE<W-A9V4@:6X@6$U,(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO;B!S
M97)I86QI>F4H*0H@("`@>PH@("`@("`@("1R<R`]("(\;65T:&]D4F5S<&]N
M<V4^7&XB.PH@("`@("`@(&EF("@D=&AI<RT^9FXI('L*("`@("`@("`@("`@
M)')S("X]("(\9F%U;'0^"B`@/'9A;'5E/@H@("`@/'-T<G5C=#X*("`@("`@
M/&UE;6)E<CX*("`@("`@("`\;F%M93YF875L=$-O9&4\+VYA;64^"B`@("`@
M("`@/'9A;'5E/CQI;G0^(B`N("1T:&ES+3YF;B`N("(\+VEN=#X\+W9A;'5E
M/@H@("`@("`\+VUE;6)E<CX*("`@("`@/&UE;6)E<CX*("`@("`@("`\;F%M
M93YF875L=%-T<FEN9SPO;F%M93X*("`@("`@("`\=F%L=64^/'-T<FEN9SXB
M("X@)'1H:7,M/F9S("X@(CPO<W1R:6YG/CPO=F%L=64^"B`@("`@(#PO;65M
M8F5R/@H@("`@/"]S=')U8W0^"B`@/"]V86QU93X*/"]F875L=#XB.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1R<R`N/2`B/'!A<F%M<SY<;CQP
M87)A;3Y<;B(@+B`D=&AI<RT^>'8M/G-E<FEA;&EZ92@I("X*("`@("`@("`B
M/"]P87)A;3Y<;CPO<&%R86US/B(["B`@("`@("`@?0H@("`@("`@("1R<R`N
M/2`B7&X\+VUE=&AO9%)E<W!O;G-E/B(["B`@("`@("`@<F5T=7)N("1R<SL*
M("`@('T*?0H*+RHJ"B`J(%1H92!M971H;V1S(&%N9"!P<F]P97)T:65S(&9O
M<B!C;VUP;W-I;F<@6$U,(%)00R!M97-S86=E<PH@*@H@*B!`8V%T96=O<GD@
M("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@6$U,7U)00PH@*B!`875T
M:&]R("`@("!%9&0@1'5M8FEL;"`\961D0'5S969U;&EN8RYC;VT^"B`J($!A
M=71H;W(@("`@(%-T:6<@0F%K:V5N(#QS=&EG0'!H<"YN970^"B`J($!A=71H
M;W(@("`@($UA<G1I;B!*86YS96X@/&UJ0'!H<"YN970^"B`J($!A=71H;W(@
M("`@($1A;FEE;"!#;VYV:7-S;W(@/&1A;FEE;&-`<&AP+FYE=#X*("H@0&-O
M<'ER:6=H="`@,3DY.2TR,#`Q($5D9"!$=6UB:6QL+"`R,#`Q+3(P,#4@5&AE
M(%!(4"!'<F]U<`H@*B!`=F5R<VEO;B`@("!296QE87-E.B`Q+C0N.`H@*B!`
M;&EN:R`@("`@("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)0
M0PH@*B\*8VQA<W,@6$U,7U)00U]-97-S86=E(&5X=&5N9',@6$U,7U)00U]"
M87-E"GL*("`@("\J*@H@("`@("H@5&AE(&-U<G)E;G0@9&5B=6<@;6]D92`H
M,2`](&]N+"`P(#T@;V9F*0H@("`@("H@0'9A<B!I;G1E9V5R"B`@("`@*B\*
M("`@('9A<B`D9&5B=6<@/2`P.PH*("`@("\J*@H@("`@("H@5&AE(&5N8V]D
M:6YG('1O(&)E('5S960@9F]R(&]U=&=O:6YG(&UE<W-A9V5S"B`@("`@*@H@
M("`@("H@1&5F875L=',@=&\@=&AE('9A;'5E(&]F(#QV87(^)$=,3T)!3%-;
M)UA-3%]24$-?9&5F96YC;V1I;F<G73PO=F%R/@H@("`@("H*("`@("`J($!V
M87(@<W1R:6YG"B`@("`@*B!`<V5E(%A-3%]24$-?365S<V%G93HZ<V5T4V5N
M9$5N8V]D:6YG*"DL"B`@("`@*B`@("`@("1'3$]"04Q36R=834Q?4E!#7V1E
M9F5N8V]D:6YG)UTL(%A-3%]24$-?365S<V%G93HZ>&UL7VAE861E<B@I"B`@
M("`@*B\*("`@('9A<B`D<V5N9%]E;F-O9&EN9R`]("<G.PH*("`@("\J*@H@
M("`@("H@5&AE(&UE=&AO9"!P<F5S96YT;'D@8F5I;F<@979A;'5A=&5D"B`@
M("`@*B!`=F%R('-T<FEN9PH@("`@("HO"B`@("!V87(@)&UE=&AO9&YA;64@
M/2`G)SL*"B`@("`O*BH*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@
M=F%R("1P87)A;7,@/2!A<G)A>2@I.PH*("`@("\J*@H@("`@("H@5&AE(%A-
M3"!M97-S86=E(&)E:6YG(&=E;F5R871E9`H@("`@("H@0'9A<B!S=')I;F<*
M("`@("`J+PH@("`@=F%R("1P87EL;V%D(#T@)R<["@H@("`@+RHJ"B`@("`@
M*B!3:&]U;&0@97AT<F$@;&EN92!B<F5A:W,@8F4@<F5M;W9E9"!F<F]M('1H
M92!P87EL;V%D/PH@("`@("H@0'-I;F-E(%!R;W!E<G1Y(&%V86EL86)L92!S
M:6YC92!296QE87-E(#$N-"XV"B`@("`@*B!`=F%R(&)O;VQE86X*("`@("`J
M+PH@("`@=F%R("1R96UO=F5?97AT<F%?;&EN97,@/2!T<G5E.PH*("`@("\J
M*@H@("`@("H@5&AE(%A-3"!R97-P;VYS92!F<F]M('1H92!R96UO=&4@<V5R
M=F5R"B`@("`@*B!`<VEN8V4@4')O<&5R='D@879A:6QA8FQE('-I;F-E(%)E
M;&5A<V4@,2XT+C8*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*("`@('9A
M<B`D<F5S<&]N<V5?<&%Y;&]A9"`]("<G.PH*"B`@("`O*BH*("`@("`J($!R
M971U<FX@=F]I9`H@("`@("HO"B`@("!F=6YC=&EO;B!834Q?4E!#7TUE<W-A
M9V4H)&UE=&@L("1P87)S(#T@,"D*("`@('L*("`@("`@("`D=&AI<RT^;65T
M:&]D;F%M92`]("1M971H.PH@("`@("`@(&EF("AI<U]A<G)A>2@D<&%R<RD@
M)B8@<VEZ96]F*"1P87)S*2`^(#`I('L*("`@("`@("`@("`@9F]R("@D:2`]
M(#`[("1I(#P@<VEZ96]F*"1P87)S*3L@)&DK*RD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/F%D9%!A<F%M*"1P87)S6R1I72D["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!0<F]D=6-E<R!T:&4@
M6$U,(&1E8VQA<F%T:6]N(&EN8VQU9&EN9R!T:&4@96YC;V1I;F<@871T<FEB
M=71E"B`@("`@*@H@("`@("H@5&AE(&5N8V]D:6YG(&ES(&1E=&5R;6EN960@
M8GD@=&AI<R!C;&%S<R<@/'9A<CXD<V5N9%]E;F-O9&EN9SPO=F%R/@H@("`@
M("H@<')O<&5R='DN("!)9B!T:&4@/'9A<CXD<V5N9%]E;F-O9&EN9SPO=F%R
M/B!P<F]P97)T>2!I<R!N;W0@<V5T+"!U<V4*("`@("`J(#QV87(^)$=,3T)!
M3%-;)UA-3%]24$-?9&5F96YC;V1I;F<G73PO=F%R/BX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('-T<FEN9R`@=&AE(%A-3"!D96-L87)A=&EO;B!A;F0@/&UE
M=&AO9$-A;&P^(&5L96UE;G0*("`@("`J"B`@("`@*B!`<V5E(%A-3%]24$-?
M365S<V%G93HZ<V5T4V5N9$5N8V]D:6YG*"DL"B`@("`@*B`@("`@(%A-3%]2
M4$-?365S<V%G93HZ)'-E;F1?96YC;V1I;F<L("1'3$]"04Q36R=834Q?4E!#
M7V1E9F5N8V]D:6YG)UT*("`@("`J+PH@("`@9G5N8W1I;VX@>&UL7VAE861E
M<B@I"B`@("!["B`@("`@("`@9VQO8F%L("1834Q?4E!#7V1E9F5N8V]D:6YG
M.PH*("`@("`@("!I9B`H(21T:&ES+3YS96YD7V5N8V]D:6YG*2!["B`@("`@
M("`@("`@("1T:&ES+3YS96YD7V5N8V]D:6YG(#T@)%A-3%]24$-?9&5F96YC
M;V1I;F<["B`@("`@("`@?0H@("`@("`@(')E='5R;B`G/#]X;6P@=F5R<VEO
M;CTB,2XP(B!E;F-O9&EN9STB)R`N("1T:&ES+3YS96YD7V5N8V]D:6YG("X@
M)R(_/B<*("`@("`@("`@("`@("`@+B`B7&X\;65T:&]D0V%L;#Y<;B(["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&-L;W-I
M;F<@/"]M971H;V1#86QL/B!T86<*("`@("`J+PH@("`@9G5N8W1I;VX@>&UL
M7V9O;W1E<B@I"B`@("!["B`@("`@("`@<F5T=7)N("(\+VUE=&AO9$-A;&P^
M7&XB.PH@("`@?0H*("`@("\J*@H@("`@("H@1FEL;',@=&AE(%A-3%]24$-?
M365S<V%G93HZ)'!A>6QO860@<')O<&5R='D*("`@("`J"B`@("`@*B!087)T
M(&]F('1H92!P<F]C97-S(&UA:V5S('-U<F4@86QL(&QI;F4@96YD:6YG<R!A
M<F4@:6X@1$]3(&9O<FUA=`H@("`@("H@*$-23$8I+"!W:&EC:"!I<R!P<F]B
M86)L>2!R97%U:7)E9"!B>2!S<&5C:69I8V%T:6]N<RX*("`@("`J"B`@("`@
M*B!`<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`=7-E<R!834Q?4E!#7TUE
M<W-A9V4Z.GAM;%]H96%D97(H*2P@6$U,7U)00U]-97-S86=E.CIX;6Q?9F]O
M=&5R*"D*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4&%Y;&]A9"@I"B`@
M("!["B`@("`@("`@)'1H:7,M/G!A>6QO860@/2`D=&AI<RT^>&UL7VAE861E
M<B@I.PH@("`@("`@("1T:&ES+3YP87EL;V%D("X]("<\;65T:&]D3F%M93XG
M("X@)'1H:7,M/FUE=&AO9&YA;64@+B`B/"]M971H;V1.86UE/EQN(CL*("`@
M("`@("`D=&AI<RT^<&%Y;&]A9"`N/2`B/'!A<F%M<SY<;B(["B`@("`@("`@
M9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1T:&ES+3YP87)A;7,I.R`D:2LK
M*2!["B`@("`@("`@("`@("1P(#T@)'1H:7,M/G!A<F%M<ULD:5T["B`@("`@
M("`@("`@("1T:&ES+3YP87EL;V%D("X]("(\<&%R86T^7&XB("X@)'`M/G-E
M<FEA;&EZ92@I("X@(CPO<&%R86T^7&XB.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^<&%Y;&]A9"`N/2`B/"]P87)A;7,^7&XB.PH@("`@("`@("1T:&ES
M+3YP87EL;V%D("X]("1T:&ES+3YX;6Q?9F]O=&5R*"D["B`@("`@("`@:68@
M*"1T:&ES+3YR96UO=F5?97AT<F%?;&EN97,I('L*("`@("`@("`@("`@)'1H
M:7,M/G!A>6QO860@/2!E<F5G7W)E<&QA8V4H(EM<<EQN72LB+"`B7')<;B(L
M("1T:&ES+3YP87EL;V%D*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D=&AI<RT^<&%Y;&]A9"`](&5R96=?<F5P;&%C92@B7')<;GQ<;GQ<<GQ<
M;EQR(BP@(EQR7&XB+"`D=&AI<RT^<&%Y;&]A9"D["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!N86UE(&]F
M('1H92!M971H;V0*("`@("`J+PH@("`@9G5N8W1I;VX@;65T:&]D*"1M971H
M(#T@)R<I"B`@("!["B`@("`@("`@:68@*"1M971H("$]("<G*2!["B`@("`@
M("`@("`@("1T:&ES+3YM971H;V1N86UE(#T@)&UE=&@["B`@("`@("`@?0H@
M("`@("`@(')E='5R;B`D=&AI<RT^;65T:&]D;F%M93L*("`@('T*"B`@("`O
M*BH*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@<&%Y;&]A9`H@("`@("HO
M"B`@("!F=6YC=&EO;B!S97)I86QI>F4H*0H@("`@>PH@("`@("`@("1T:&ES
M+3YC<F5A=&5087EL;V%D*"D["B`@("`@("`@<F5T=7)N("1T:&ES+3YP87EL
M;V%D.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@
M*B\*("`@(&9U;F-T:6]N(&%D9%!A<F%M*"1P87(I"B`@("!["B`@("`@("`@
M)'1H:7,M/G!A<F%M<UM=(#T@)'!A<CL*("`@('T*"B`@("`O*BH*("`@("`J
M($]B=&%I;G,@86X@6$U,7U)00U]686QU92!O8FIE8W0@9F]R('1H92!G:79E
M;B!P87)A;65T97(*("`@("`J"B`@("`@*B!`<&%R86T@:6YT("1I("!T:&4@
M:6YD97@@;G5M8F5R(&]F('1H92!P87)A;65T97(@=&\@;V)T86EN"B`@("`@
M*@H@("`@("H@0')E='5R;B!O8FIE8W0@('1H92!834Q?4E!#7U9A;'5E(&]B
M:F5C="X*("`@("`J("`@("`@("`@("`@("`@("`@268@=&AE('!A<F%M971E
M<B!D;V5S;B=T(&5X:7-T+"!A;B!834Q?4E!#7U)E<W!O;G-E(&]B:F5C="X*
M("`@("`J"B`@("`@*B!`<VEN8V4@4F5T=7)N<R!834Q?4E!#7U)E<W!O;G-E
M(&]B:F5C="!O;B!E<G)O<B!S:6YC92!296QE87-E(#$N,RXP"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&=E=%!A<F%M*"1I*0H@("`@>PH@("`@("`@(&=L;V)A
M;"`D6$U,7U)00U]E<G(L("1834Q?4E!#7W-T<CL*"B`@("`@("`@:68@*&ES
M<V5T*"1T:&ES+3YP87)A;7-;)&E=*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'1H:7,M/G!A<F%M<ULD:5T["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@)'1H:7,M/G)A:7-E17)R;W(H)U1H92!S=6)M:71T960@<F5Q=65S="!D
M:60@;F]T(&-O;G1A:6X@=&AI<R!P87)A;65T97(G+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!834Q?4E!#7T524D]27TE.0T]24D5#5%]005)!
M35,I.PH@("`@("`@("`@("!R971U<FX@;F5W(%A-3%]24$-?4F5S<&]N<V4H
M,"P@)%A-3%]24$-?97)R6R=I;F-O<G)E8W1?<&%R86US)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');
M)VEN8V]R<F5C=%]P87)A;7,G72D["B`@("`@("`@?0H@("`@?0H*("`@("\J
M*@H@("`@("H@0')E='5R;B!I;G0@('1H92!N=6UB97(@;V8@<&%R86UE=&5R
M<PH@("`@("HO"B`@("!F=6YC=&EO;B!G971.=6U087)A;7,H*0H@("`@>PH@
M("`@("`@(')E='5R;B!S:7IE;V8H)'1H:7,M/G!A<F%M<RD["B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!3971S('1H92!834P@9&5C;&%R871I;VXG<R!E;F-O
M9&EN9R!A='1R:6)U=&4*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1T
M>7!E("!T:&4@96YC;V1I;F<@='EP92`H25-/+3@X-3DM,2P@551&+3@@;W(@
M55,M05-#24DI"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@
M("`@("H@0'-E92!834Q?4E!#7TUE<W-A9V4Z.B1S96YD7V5N8V]D:6YG+"!8
M34Q?4E!#7TUE<W-A9V4Z.GAM;%]H96%D97(H*0H@("`@("H@0'-I;F-E($UE
M=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`Q+C(N,`H@("`@("HO"B`@
M("!F=6YC=&EO;B!S971396YD16YC;V1I;F<H)'1Y<&4I"B`@("!["B`@("`@
M("`@)'1H:7,M/G-E;F1?96YC;V1I;F<@/2`D='EP93L*("`@('T*"B`@("`O
M*BH*("`@("`J($1E=&5R;6EN92!T:&4@6$U,)W,@96YC;V1I;F<@=FEA('1H
M92!E;F-O9&EN9R!A='1R:6)U=&4*("`@("`J(&EN('1H92!834P@9&5C;&%R
M871I;VX*("`@("`J"B`@("`@*B!)9B!T:&4@96YC;V1I;F<@<&%R86UE=&5R
M(&ES(&YO="!S970@;W(@:7,@;F]T($E33RTX.#4Y+3$L(%541BTX"B`@("`@
M*B!O<B!54RU!4T-)22P@)%A-3%]24$-?9&5F96YC;V1I;F<@=VEL;"!B92!R
M971U<FYE9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1D871A("!T
M:&4@6$U,('1H870@=VEL;"!B92!P87)S960*("`@("`J"B`@("`@*B!`<F5T
M=7)N('-T<FEN9R`@=&AE(&5N8V]D:6YG('1O(&)E('5S960*("`@("`J"B`@
M("`@*B!`;&EN:R`@(&AT='`Z+R]P:'`N;F5T+WAM;%]P87)S97)?8W)E871E
M"B`@("`@*B!`<VEN8V4@($UE=&AO9"!A=F%I;&%B;&4@<VEN8V4@4F5L96%S
M92`Q+C(N,`H@("`@("HO"B`@("!F=6YC=&EO;B!G971%;F-O9&EN9R@D9&%T
M82D*("`@('L*("`@("`@("!G;&]B86P@)%A-3%]24$-?9&5F96YC;V1I;F<[
M"@H@("`@("`@(&EF("AP<F5G7VUA=&-H*"<O/%P_>&UL6UX^72I<<RIE;F-O
M9&EN9UQS*CU<<RI;7"<B72A;7B)<)UTJ*5M<)R)=+VDG+`H@("`@("`@("`@
M("`@("`@("`@("`@("1D871A+"`D;6%T8V@I*0H@("`@("`@('L*("`@("`@
M("`@("`@)&UA=&-H6S%=(#T@=')I;2AS=')T;W5P<&5R*"1M871C:%LQ72DI
M.PH@("`@("`@("`@("!S=VET8V@@*"1M871C:%LQ72D@>PH@("`@("`@("`@
M("`@("`@8V%S92`G25-/+3@X-3DM,2<Z"B`@("`@("`@("`@("`@("!C87-E
M("=55$8M."<Z"B`@("`@("`@("`@("`@("!C87-E("=54RU!4T-)22<Z"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1M871C:%LQ73L*("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*"B`@("`@("`@("`@("`@("!D969A=6QT.@H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`D6$U,7U)00U]D969E;F-O9&EN
M9SL*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(')E='5R;B`D6$U,7U)00U]D969E;F-O9&EN9SL*("`@("`@("!]"B`@("!]
M"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@6$U,7U)0
M0U]297-P;VYS92!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V52
M97-P;VYS949I;&4H)&9P*0H@("`@>PH@("`@("`@("1I<&0@/2`G)SL*("`@
M("`@("!W:&EL92`H)&1A=&$@/2!`9G)E860H)&9P+"`X,3DR*2D@>PH@("`@
M("`@("`@("`D:7!D("X]("1D871A.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'1H:7,M/G!A<G-E4F5S<&]N<V4H)&EP9"D["B`@("!]"@H@("`@+RHJ
M"B`@("`@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@6$U,7U)00U]297-P;VYS
M92!O8FIE8W0*("`@("`J+PH@("`@9G5N8W1I;VX@<&%R<V5297-P;VYS92@D
M9&%T82`]("<G*0H@("`@>PH@("`@("`@(&=L;V)A;"`D6$U,7U)00U]X:"P@
M)%A-3%]24$-?97)R+"`D6$U,7U)00U]S='(L("1834Q?4E!#7V1E9F5N8V]D
M:6YG.PH*("`@("`@("`D96YC;V1I;F<@/2`D=&AI<RT^9V5T16YC;V1I;F<H
M)&1A=&$I.PH@("`@("`@("1P87)S97)?<F5S;W5R8V4@/2!X;6Q?<&%R<V5R
M7V-R96%T92@D96YC;V1I;F<I.PH@("`@("`@("1P87)S97(@/2`H:6YT*2`D
M<&%R<V5R7W)E<V]U<F-E.PH*("`@("`@("`D6$U,7U)00U]X:"`](&%R<F%Y
M*"D["B`@("`@("`@)%A-3%]24$-?>&A;)'!A<G-E<ET@/2!A<G)A>2@I.PH*
M("`@("`@("`D6$U,7U)00U]X:%LD<&%R<V5R75LG8VTG72`](#`["B`@("`@
M("`@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==(#T@,#L*("`@("`@("`D
M6$U,7U)00U]X:%LD<&%R<V5R75LG86,G72`]("<G.PH@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=Q="==(#T@)R<["B`@("`@("`@)%A-3%]24$-?
M>&A;)'!A<G-E<EU;)W-T86-K)UT@/2!A<G)A>2@I.PH@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=6R=V86QU97-T86-K)UT@/2!A<G)A>2@I.PH*("`@
M("`@("!X;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<E]R97-O=7)C92P@
M6$U,7T]05$E/3E]#05-%7T9/3$1)3D<L('1R=64I.PH@("`@("`@('AM;%]S
M971?96QE;65N=%]H86YD;&5R*"1P87)S97)?<F5S;W5R8V4L("=834Q?4E!#
M7W-E)RP@)UA-3%]24$-?964G*3L*("`@("`@("!X;6Q?<V5T7V-H87)A8W1E
M<E]D871A7VAA;F1L97(H)'!A<G-E<E]R97-O=7)C92P@)UA-3%]24$-?8V0G
M*3L*"B`@("`@("`@)&AD<F9N9"`](#`["B`@("`@("`@:68@*"1T:&ES+3YD
M96)U9RD@>PH@("`@("`@("`@("!P<FEN="`B7&X\<')E/BTM+4=/5"TM+5QN
M(CL*("`@("`@("`@("`@<')I;G0@:7-S970H)%]315)615);)U-%4E9%4E]0
M4D]43T-/3"==*2`_(&AT;6QS<&5C:6%L8VAA<G,H)&1A=&$I(#H@)&1A=&$[
M"B`@("`@("`@("`@('!R:6YT(")<;BTM+45.1"TM+3PO<')E/EQN(CL*("`@
M("`@("!]"@H@("`@("`@("\O(%-E92!I9B!R97-P;VYS92!I<R!A(#(P,"!O
M<B!A(#$P,"!T:&5N(&$@,C`P+"!E;'-E(')A:7-E(&5R<F]R+@H@("`@("`@
M("\O($)U="!O;FQY(&1O('1H:7,@:68@=V4G<F4@=7-I;F<@=&AE($A45%`@
M<')O=&]C;VPN"B`@("`@("`@:68@*&5R96<H)UY(5%10)RP@)&1A=&$I("8F
M"B`@("`@("`@("`@("%E<F5G*"=>2%144"];,"TY7"Y=*R`R,#`@)RP@)&1A
M=&$I("8F"B`@("`@("`@("`@("%P<F5G7VUA=&-H*"=`7DA45%`O6S`M.5PN
M72L@,3!;,"TY72A;02U:82UZ(%TK*3];7')<;ETK2%144"];,"TY7"Y=*R`R
M,#!`)RP@)&1A=&$I*0H@("`@("`@('L*("`@("`@("`@("`@("`@("1E<G)S
M='(@/2!S=6)S='(H)&1A=&$L(#`L('-T<G!O<R@D9&%T82P@(EQN(BD@+2`Q
M*3L*("`@("`@("`@("`@("`@(&5R<F]R7VQO9R@G2%144"!E<G)O<BP@9V]T
M(')E<W!O;G-E.B`G("X@)&5R<G-T<BD["B`@("`@("`@("`@("`@("`D<B`]
M(&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG:'1T<%]E
M<G)O<B==+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D6$U,7U)00U]S=');)VAT='!?97)R;W(G72`N("<@*"<@+@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D97)R<W1R
M("X@)RDG*3L*("`@("`@("`@("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R
M<V5R7W)E<V]U<F-E*3L*("`@("`@("`@("`@("`@(')E='5R;B`D<CL*("`@
M("`@("!]"@H@("`@("`@("\O(&=O='1A(&=E="!R:60@;V8@:&5A9&5R<R!H
M97)E"B`@("`@("`@:68@*"$D:&1R9FYD("8F("@D8G)P;W,@/2!S=')P;W,H
M)&1A=&$L(EQR7&Y<<EQN(BDI*2!["B`@("`@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=H82==(#T@<W5B<W1R*"1D871A+"`P+"`D8G)P;W,I.PH@
M("`@("`@("`@("`D9&%T82`]('-U8G-T<B@D9&%T82P@)&)R<&]S("L@-"D[
M"B`@("`@("`@("`@("1H9')F;F0@/2`Q.PH@("`@("`@('T*"B`@("`@("`@
M+RH*("`@("`@("`@*B!B92!T;VQE<F%N="!O9B!J=6YK(&%F=&5R(&UE=&AO
M9%)E<W!O;G-E"B`@("`@("`@("H@*&4N9RX@:F%V87-C<FEP="!A=71O;6%T
M:6-A;&QY(&EN<V5R=&5D(&)Y(&9R964@:&]S=',I"B`@("`@("`@("H@=&AA
M;FMS('1O($QU8V$@36%R:6%N;R`\;'5C82YM87)I86YO0&5M86EL+FET/@H@
M("`@("`@("`J+PH@("`@("`@("1D871A(#T@<W5B<W1R*"1D871A+"`P+"!S
M=')P;W,H)&1A=&$L("(\+VUE=&AO9%)E<W!O;G-E/B(I("L@,3<I.PH@("`@
M("`@("1T:&ES+3YR97-P;VYS95]P87EL;V%D(#T@)&1A=&$["@H@("`@("`@
M(&EF("@A>&UL7W!A<G-E*"1P87)S97)?<F5S;W5R8V4L("1D871A+"!S:7IE
M;V8H)&1A=&$I*2D@>PH@("`@("`@("`@("`O+R!T:&%N:W,@=&\@4&5T97(@
M2V]C:W,@/'!E=&5R+FMO8VMS0&)A>6=A=&4N8V]M/@H@("`@("`@("`@("!I
M9B`H>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1P87)S97)?<F5S;W5R
M8V4I(#T](#$I('L*("`@("`@("`@("`@("`@("1E<G)S='(@/2`G6$U,(&5R
M<F]R(&%T(&QI;F4@,2P@8VAE8VL@55),)SL*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("1E<G)S='(@/2!S<')I;G1F*"=834P@97)R
M;W(Z("5S(&%T(&QI;F4@)60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@>&UL7V5R<F]R7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H
M)'!A<G-E<E]R97-O=7)C92DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1P87)S97)?
M<F5S;W5R8V4I*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E<G)O<E]L
M;V<H)&5R<G-T<BD["B`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S
M<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;G9A;&ED7W)E='5R;B==+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T
M<ELG:6YV86QI9%]R971U<FXG72D["B`@("`@("`@("`@('AM;%]P87)S97)?
M9G)E92@D<&%R<V5R7W)E<V]U<F-E*3L*("`@("`@("`@("`@<F5T=7)N("1R
M.PH@("`@("`@('T*"B`@("`@("`@>&UL7W!A<G-E<E]F<F5E*"1P87)S97)?
M<F5S;W5R8V4I.PH*("`@("`@("!I9B`H)'1H:7,M/F1E8G5G*2!["B`@("`@
M("`@("`@('!R:6YT(")<;CQP<F4^+2TM4$%24T5$+2TM7&XB.PH@("`@("`@
M("`@("!V87)?9'5M<"@D6$U,7U)00U]X:%LD<&%R<V5R75LG=F%L=64G72D[
M"B`@("`@("`@("`@('!R:6YT("(M+2U%3D0M+2T\+W!R93Y<;B(["B`@("`@
M("`@?0H*("`@("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9B==
M(#X@,2D@>PH@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E
M*#`L("1834Q?4E!#7V5R<ELG:6YV86QI9%]R971U<FXG72P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VEN
M=F%L:61?<F5T=7)N)UTN)R`G+B1834Q?4E!#7WAH6R1P87)S97)=6R=I<V9?
M<F5A<V]N)UTI.PH@("`@("`@('T@96QS96EF("@A:7-?;V)J96-T*"1834Q?
M4E!#7WAH6R1P87)S97)=6R=V86QU92==*2D@>PH@("`@("`@("`@("`O+R!T
M:&5N('-O;65T:&EN9R!O9&0@:&%S(&AA<'!E;F5D"B`@("`@("`@("`@("\O
M(&%N9"!I="=S('1I;64@=&\@9V5N97)A=&4@82!C;&EE;G0@<VED92!E<G)O
M<@H@("`@("`@("`@("`O+R!I;F1I8V%T:6YG('-O;65T:&EN9R!O9&0@=V5N
M="!O;@H@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L
M("1834Q?4E!#7V5R<ELG:6YV86QI9%]R971U<FXG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VEN=F%L
M:61?<F5T=7)N)UTI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1V
M(#T@)%A-3%]24$-?>&A;)'!A<G-E<EU;)W9A;'5E)UT["B`@("`@("`@("`@
M("1A;&Q/2STQ.PH@("`@("`@("`@("!I9B`H)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)VES9B==*2!["B`@("`@("`@("`@("`@("`D9B`]("1V+3YS=')U8W1M
M96TH)V9A=6QT0V]D92<I.PH@("`@("`@("`@("`@("`@)&9S(#T@)'8M/G-T
M<G5C=&UE;2@G9F%U;'13=')I;F<G*3L*("`@("`@("`@("`@("`@("1R(#T@
M;F5W(%A-3%]24$-?4F5S<&]N<V4H)'8L("1F+3YS8V%L87)V86PH*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9S+3YS
M8V%L87)V86PH*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*"1V*3L*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("`D<BT^:&1R<R`]('-P;&ET*")<<C]<
M;B(L("1834Q?4E!#7WAH6R1P87)S97)=6R=H82==6S%=*3L*("`@("`@("!R
M971U<FX@)'(["B`@("!]"GT*"B\J*@H@*B!4:&4@;65T:&]D<R!A;F0@<')O
M<&5R=&EE<R!T:&%T(')E<')E<V5N="!D871A(&EN(%A-3"!24$,@9F]R;6%T
M"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@
M("!834Q?4E!#"B`J($!A=71H;W(@("`@($5D9"!$=6UB:6QL(#QE9&1`=7-E
M9G5L:6YC+F-O;3X*("H@0&%U=&AO<B`@("`@4W1I9R!"86MK96X@/'-T:6=`
M<&AP+FYE=#X*("H@0&%U=&AO<B`@("`@36%R=&EN($IA;G-E;B`\;6I`<&AP
M+FYE=#X*("H@0&%U=&AO<B`@("`@1&%N:65L($-O;G9I<W-O<B`\9&%N:65L
M8T!P:'`N;F5T/@H@*B!`8V]P>7)I9VAT("`Q.3DY+3(P,#$@161D($1U;6)I
M;&PL(#(P,#$M,C`P-2!4:&4@4$A0($=R;W5P"B`J($!V97)S:6]N("`@(%)E
M;&5A<V4Z(#$N-"XX"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]834Q?4E!#"B`J+PIC;&%S<R!834Q?4E!#7U9A;'5E(&5X
M=&5N9',@6$U,7U)00U]"87-E"GL*("`@('9A<B`D;64@/2!A<G)A>2@I.PH@
M("`@=F%R("1M>71Y<&4@/2`P.PH*("`@("\J*@H@("`@("H@0')E='5R;B!V
M;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(%A-3%]24$-?5F%L=64H)'9A;"`]
M("TQ+"`D='EP92`]("<G*0H@("`@>PH@("`@("`@("1T:&ES+3YM92`](&%R
M<F%Y*"D["B`@("`@("`@)'1H:7,M/FUY='EP92`](#`["B`@("`@("`@:68@
M*"1V86P@(3T@+3$@?'P@)'1Y<&4@(3T@)R<I('L*("`@("`@("`@("`@:68@
M*"1T>7!E(#T]("<G*2!["B`@("`@("`@("`@("`@("`D='EP92`]("=S=')I
M;F<G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A87)R87E?:V5Y
M7V5X:7-T<R@D='EP92P@)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G72DI('L*
M("`@("`@("`@("`@("`@("\O(%A86`H@("`@("`@("`@("`@("`@+R\@;F5E
M9"!S;VUE('=A>2!T;R!R97!O<G0@=&AI<R!E<G)O<@H@("`@("`@("`@("!]
M(&5L<V5I9B`H)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75LD='EP95T@/3T@
M,2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/F%D9%-C86QA<B@D=F%L+"`D
M='EP92D["B`@("`@("`@("`@('T@96QS96EF("@D1TQ/0D%,4ULG6$U,7U)0
M0U]4>7!E<R==6R1T>7!E72`]/2`R*2!["B`@("`@("`@("`@("`@("`D=&AI
M<RT^861D07)R87DH)'9A;"D["B`@("`@("`@("`@('T@96QS96EF("@D1TQ/
M0D%,4ULG6$U,7U)00U]4>7!E<R==6R1T>7!E72`]/2`S*2!["B`@("`@("`@
M("`@("`@("`D=&AI<RT^861D4W1R=6-T*"1V86PI.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!I;G0@
M(')E='5R;G,@,2!I9B!S=6-C97-S9G5L(&]R(#`@:68@=&AE<F4@87)E('!R
M;V)L96US"B`@("`@*B\*("`@(&9U;F-T:6]N(&%D9%-C86QA<B@D=F%L+"`D
M='EP92`]("=S=')I;F<G*0H@("`@>PH@("`@("`@(&EF("@D=&AI<RT^;7ET
M>7!E(#T](#$I('L*("`@("`@("`@("`@)'1H:7,M/G)A:7-E17)R;W(H)U-C
M86QA<B!C86X@:&%V92!O;FQY(&]N92!V86QU92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(%A-3%]24$-?15)23U)?24Y604Q)1%]465!%*3L*
M("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H@("`@("`@("1T>7!E
M;V8@/2`D1TQ/0D%,4ULG6$U,7U)00U]4>7!E<R==6R1T>7!E73L*("`@("`@
M("!I9B`H)'1Y<&5O9B`A/2`Q*2!["B`@("`@("`@("`@("1T:&ES+3YR86ES
M945R<F]R*").;W0@82!S8V%L87(@='EP92`H)'MT>7!E;V9]*2(L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?15)23U)?24Y604Q)
M1%]465!%*3L*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@?0H*("`@
M("`@("!I9B`H)'1Y<&4@/3T@)$=,3T)!3%-;)UA-3%]24$-?0F]O;&5A;B==
M*2!["B`@("`@("`@("`@(&EF("AS=')C87-E8VUP*"1V86PL("=T<G5E)RD@
M/3T@,`H@("`@("`@("`@("`@("`@?'P@)'9A;"`]/2`Q"B`@("`@("`@("`@
M("`@("!\?"`H)'9A;"`]/2!T<G5E("8F('-T<F-A<V5C;7`H)'9A;"P@)V9A
M;'-E)RDI*0H@("`@("`@("`@("!["B`@("`@("`@("`@("`@("`D=F%L(#T@
M,3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1V86P@
M/2`P.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!I9B`H)'1H
M:7,M/FUY='EP92`]/2`R*2!["B`@("`@("`@("`@("\O('=E)W)E(&%D9&EN
M9R!T;R!A;B!A<G)A>2!H97)E"B`@("`@("`@("`@("1A<B`]("1T:&ES+3YM
M95LG87)R87DG73L*("`@("`@("`@("`@)&%R6UT@/2!N97<@6$U,7U)00U]6
M86QU92@D=F%L+"`D='EP92D["B`@("`@("`@("`@("1T:&ES+3YM95LG87)R
M87DG72`]("1A<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!A
M('-C86QA<BP@<V\@<V5T('1H92!V86QU92!A;F0@<F5M96UB97(@=V4G<F4@
M<V-A;&%R"B`@("`@("`@("`@("1T:&ES+3YM95LD='EP95T@/2`D=F%L.PH@
M("`@("`@("`@("`D=&AI<RT^;7ET>7!E(#T@)'1Y<&5O9CL*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N(#$["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T
M=7)N(&EN="`@<F5T=7)N<R`Q(&EF('-U8V-E<W-F=6P@;W(@,"!I9B!T:&5R
M92!A<F4@<')O8FQE;7,*("`@("`J+PH@("`@9G5N8W1I;VX@861D07)R87DH
M)'9A;',I"B`@("!["B`@("`@("`@:68@*"1T:&ES+3YM>71Y<&4@(3T@,"D@
M>PH@("`@("`@("`@("`D=&AI<RT^<F%I<V5%<G)O<B@*("`@("`@("`@("`@
M("`@("`@("`G06QR96%D>2!I;FET:6%L:7IE9"!A<R!A(%LG("X@)'1H:7,M
M/FMI;F1/9B@I("X@)UTG+`H@("`@("`@("`@("`@("`@("`@(%A-3%]24$-?
M15)23U)?04Q214%$65])3DE424%,25I%1"D["B`@("`@("`@("`@(')E='5R
M;B`P.PH@("`@("`@('T*("`@("`@("`D=&AI<RT^;7ET>7!E(#T@)$=,3T)!
M3%-;)UA-3%]24$-?5'EP97,G75LG87)R87DG73L*("`@("`@("`D=&AI<RT^
M;65;)V%R<F%Y)UT@/2`D=F%L<SL*("`@("`@("!R971U<FX@,3L*("`@('T*
M"B`@("`O*BH*("`@("`J($!R971U<FX@:6YT("!R971U<FYS(#$@:68@<W5C
M8V5S<V9U;"!O<B`P(&EF('1H97)E(&%R92!P<F]B;&5M<PH@("`@("HO"B`@
M("!F=6YC=&EO;B!A9&13=')U8W0H)'9A;',I"B`@("!["B`@("`@("`@:68@
M*"1T:&ES+3YM>71Y<&4@(3T@,"D@>PH@("`@("`@("`@("`D=&AI<RT^<F%I
M<V5%<G)O<B@*("`@("`@("`@("`@("`@("`@("`G06QR96%D>2!I;FET:6%L
M:7IE9"!A<R!A(%LG("X@)'1H:7,M/FMI;F1/9B@I("X@)UTG+`H@("`@("`@
M("`@("`@("`@("`@(%A-3%]24$-?15)23U)?04Q214%$65])3DE424%,25I%
M1"D["B`@("`@("`@("`@(')E='5R;B`P.PH@("`@("`@('T*("`@("`@("`D
M=&AI<RT^;7ET>7!E(#T@)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G75LG<W1R
M=6-T)UT["B`@("`@("`@)'1H:7,M/FUE6R=S=')U8W0G72`]("1V86QS.PH@
M("`@("`@(')E='5R;B`Q.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R
M;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N(&1U;7`H)&%R*0H@("`@>PH@
M("`@("`@(')E<V5T*"1A<BD["B`@("`@("`@9F]R96%C:"`H)&%R(&%S("1K
M97D@/3X@)'9A;"D@>PH@("`@("`@("`@("!E8VAO("(D:V5Y(#T^("1V86P\
M8G(@+SXB.PH@("`@("`@("`@("!I9B`H)&ME>2`]/2`G87)R87DG*2!["B`@
M("`@("`@("`@("`@("!F;W)E86-H("@D=F%L(&%S("1K97DR(#T^("1V86PR
M*2!["B`@("`@("`@("`@("`@("`@("`@96-H;R`B+2T@)&ME>3(@/3X@)'9A
M;#(\8G(@+SXB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@
M('1H92!D871A('1Y<&4@;V8@=&AE(&-U<G)E;G0@=F%L=64*("`@("`J+PH@
M("`@9G5N8W1I;VX@:VEN9$]F*"D*("`@('L*("`@("`@("!S=VET8V@@*"1T
M:&ES+3YM>71Y<&4I('L*("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@(')E
M='5R;B`G<W1R=6-T)SL*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("!R
M971U<FX@)V%R<F%Y)SL*"B`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("!R
M971U<FX@)W-C86QA<B<["@H@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@
M(')E='5R;B`G=6YD968G.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@
M("`J($!R971U<FX@<W1R:6YG("!T:&4@9&%T82!I;B!834P@9F]R;6%T"B`@
M("`@*B\*("`@(&9U;F-T:6]N('-E<FEA;&EZ961A=&$H)'1Y<"P@)'9A;"D*
M("`@('L*("`@("`@("`D<G,@/2`G)SL*("`@("`@("!I9B`H(6%R<F%Y7VME
M>5]E>&ES=',H)'1Y<"P@)$=,3T)!3%-;)UA-3%]24$-?5'EP97,G72DI('L*
M("`@("`@("`@("`@+R\@6%A8"B`@("`@("`@("`@("\O(&YE960@<V]M92!W
M87D@=&\@<F5P;W)T('1H:7,@97)R;W(*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*("`@("`@("!S=VET8V@@*"1'3$]"04Q36R=834Q?4E!#7U1Y
M<&5S)UU;)'1Y<%TI('L*("`@("`@("!C87-E(#,Z"B`@("`@("`@("`@("\O
M('-T<G5C=`H@("`@("`@("`@("`D<G,@+CT@(CQS=')U8W0^7&XB.PH@("`@
M("`@("`@("!R97-E="@D=F%L*3L*("`@("`@("`@("`@9F]R96%C:"`H)'9A
M;"!A<R`D:V5Y,B`]/B`D=F%L,BD@>PH@("`@("`@("`@("`@("`@)')S("X]
M("(\;65M8F5R/CQN86UE/B1[:V5Y,GT\+VYA;64^7&XB.PH@("`@("`@("`@
M("`@("`@)')S("X]("1T:&ES+3YS97)I86QI>F5V86PH)'9A;#(I.PH@("`@
M("`@("`@("`@("`@)')S("X]("(\+VUE;6)E<CY<;B(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)')S("X]("<\+W-T<G5C=#XG.PH@("`@("`@("`@
M("!B<F5A:SL*"B`@("`@("`@8V%S92`R.@H@("`@("`@("`@("`O+R!A<G)A
M>0H@("`@("`@("`@("`D<G,@+CT@(CQA<G)A>3Y<;CQD871A/EQN(CL*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1V86PI.R`D:2LK
M*2!["B`@("`@("`@("`@("`@("`D<G,@+CT@)'1H:7,M/G-E<FEA;&EZ979A
M;"@D=F%L6R1I72D["B`@("`@("`@("`@('T*("`@("`@("`@("`@)')S("X]
M("(\+V1A=&$^7&X\+V%R<F%Y/B(["B`@("`@("`@("`@(&)R96%K.PH*("`@
M("`@("!C87-E(#$Z"B`@("`@("`@("`@('-W:71C:"`H)'1Y<"D@>PH@("`@
M("`@("`@("!C87-E("1'3$]"04Q36R=834Q?4E!#7T)A<V4V-"==.@H@("`@
M("`@("`@("`@("`@)')S("X]("(\)'MT>7!]/B(@+B!B87-E-C1?96YC;V1E
M*"1V86PI("X@(CPO)'MT>7!]/B(["B`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@8V%S92`D1TQ/0D%,4ULG6$U,7U)00U]";V]L96%N)UTZ
M"B`@("`@("`@("`@("`@("`D<G,@+CT@(CPD>W1Y<'T^(B`N("@D=F%L(#\@
M)S$G(#H@)S`G*2`N("(\+R1[='EP?3XB.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG
M)UTZ"B`@("`@("`@("`@("`@("`D<G,@+CT@(CPD>W1Y<'T^(B`N(&AT;6QS
M<&5C:6%L8VAA<G,H)'9A;"DN("(\+R1[='EP?3XB.PH@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@
M("`D<G,@+CT@(CPD>W1Y<'T^)'MV86Q]/"\D>W1Y<'T^(CL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!R971U<FX@)')S.PH@("`@?0H*("`@
M("\J*@H@("`@("H@0')E='5R;B!S=')I;F<@('1H92!D871A(&EN(%A-3"!F
M;W)M870*("`@("`J+PH@("`@9G5N8W1I;VX@<V5R:6%L:7IE*"D*("`@('L*
M("`@("`@("!R971U<FX@)'1H:7,M/G-E<FEA;&EZ979A;"@D=&AI<RD["B`@
M("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1A=&$@
M:6X@6$U,(&9O<FUA=`H@("`@("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F5V
M86PH)&\I"B`@("!["B`@("`@("`@:68@*"%I<U]O8FIE8W0H)&\I('Q\(&5M
M<'1Y*"1O+3YM92D@?'P@(6ES7V%R<F%Y*"1O+3YM92DI('L*("`@("`@("`@
M("`@<F5T=7)N("<G.PH@("`@("`@('T*("`@("`@("`D87(@/2`D;RT^;64[
M"B`@("`@("`@<F5S970H)&%R*3L*("`@("`@("!L:7-T*"1T>7`L("1V86PI
M(#T@96%C:"@D87(I.PH@("`@("`@(')E='5R;B`G/'9A;'5E/B<@+B`@)'1H
M:7,M/G-E<FEA;&EZ961A=&$H)'1Y<"P@)'9A;"D@+B`@(CPO=F%L=64^7&XB
M.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE(&-O
M;G1E;G1S(&]F('1H92!E;&5M96YT(')E<75E<W1E9`H@("`@("HO"B`@("!F
M=6YC=&EO;B!S=')U8W1M96TH)&TI"B`@("!["B`@("`@("`@<F5T=7)N("1T
M:&ES+3YM95LG<W1R=6-T)UU;)&U=.PH@("`@?0H*("`@("\J*@H@("`@("H@
M0')E='5R;B!V;VED"B`@("`@*B\*("`@(&9U;F-T:6]N('-T<G5C=')E<V5T
M*"D*("`@('L*("`@("`@("!R97-E="@D=&AI<RT^;65;)W-T<G5C="==*3L*
M("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@('1H92!K97DO=F%L=64@
M<&%I<B!O9B!T:&4@<W1R=6-T)W,@8W5R<F5N="!E;&5M96YT"B`@("`@*B\*
M("`@(&9U;F-T:6]N('-T<G5C=&5A8V@H*0H@("`@>PH@("`@("`@(')E='5R
M;B!E86-H*"1T:&ES+3YM95LG<W1R=6-T)UTI.PH@("`@?0H*("`@("\J*@H@
M("`@("H@0')E='5R;B!M:7AE9"`@=&AE(&-U<G)E;G0@=F%L=64*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T=F%L*"D*("`@('L*("`@("`@("`O+R!53E-4
M04),10H*("`@("`@("!R97-E="@D=&AI<RT^;64I.PH@("`@("`@("1B(#T@
M8W5R<F5N="@D=&AI<RT^;64I.PH*("`@("`@("`O+R!C;VYT<FEB=71E9"!B
M>2!)(%-O9F5R+"`R,#`Q+3`S+3(T"B`@("`@("`@+R\@861D('-U<'!O<G0@
M9F]R(&YE<W1E9"!A<G)A>7,@=&\@<V-A;&%R=F%L"B`@("`@("`@+R\@:2=V
M92!C<F5A=&5D(&$@;F5W(&UE=&AO9"!H97)E+"!S;R!A<R!T;PH@("`@("`@
M("\O('!R97-E<G9E(&)A8VL@8V]M<&%T:6)I;&ET>0H*("`@("`@("!I9B`H
M:7-?87)R87DH)&(I*2!["B`@("`@("`@("`@(&9O<F5A8V@@*"1B(&%S("1I
M9"`]/B`D8V]N="D@>PH@("`@("`@("`@("`@("`@)&);)&ED72`]("1C;VYT
M+3YS8V%L87)V86PH*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@
M("`@+R\@861D('-U<'!O<G0@9F]R('-T<G5C='5R97,@9&ER96-T;'D@96YC
M;V1I;F<@<&AP(&]B:F5C=',*("`@("`@("!I9B`H:7-?;V)J96-T*"1B*2D@
M>PH@("`@("`@("`@("`D="`](&=E=%]O8FIE8W1?=F%R<R@D8BD["B`@("`@
M("`@("`@(&9O<F5A8V@@*"1T(&%S("1I9"`]/B`D8V]N="D@>PH@("`@("`@
M("`@("`@("`@)'1;)&ED72`]("1C;VYT+3YS8V%L87)V86PH*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!F;W)E86-H("@D="!A<R`D:60@/3X@)&-O
M;G0I('L*("`@("`@("`@("`@("`@("1B+3XD:60@/2`D8V]N=#L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@96YD(&-O;G1R:6(*("`@
M("`@("!R971U<FX@)&(["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`<F5T=7)N
M(&UI>&5D"B`@("`@*B\*("`@(&9U;F-T:6]N('-C86QA<G9A;"@I"B`@("![
M"B`@("`@("`@<F5S970H)'1H:7,M/FUE*3L*("`@("`@("!R971U<FX@8W5R
M<F5N="@D=&AI<RT^;64I.PH@("`@?0H*("`@("\J*@H@("`@("H@0')E='5R
M;B!S=')I;F<*("`@("`J+PH@("`@9G5N8W1I;VX@<V-A;&%R='EP*"D*("`@
M('L*("`@("`@("!R97-E="@D=&AI<RT^;64I.PH@("`@("`@("1A(#T@:V5Y
M*"1T:&ES+3YM92D["B`@("`@("`@:68@*"1A(#T]("1'3$]"04Q36R=834Q?
M4E!#7TDT)UTI('L*("`@("`@("`@("`@)&$@/2`D1TQ/0D%,4ULG6$U,7U)0
M0U]);G0G73L*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1A.PH@("`@?0H*
M("`@("\J*@H@("`@("H@0')E='5R;B!M:7AE9"`@=&AE('-T<G5C="=S(&-U
M<G)E;G0@96QE;65N=`H@("`@("HO"B`@("!F=6YC=&EO;B!A<G)A>6UE;2@D
M;2D*("`@('L*("`@("`@("!R971U<FX@)'1H:7,M/FUE6R=A<G)A>2==6R1M
M73L*("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@:6YT("!T:&4@;G5M
M8F5R(&]F(&5L96UE;G1S(&EN('1H92!A<G)A>0H@("`@("HO"B`@("!F=6YC
M=&EO;B!A<G)A>7-I>F4H*0H@("`@>PH@("`@("`@(')E<V5T*"1T:&ES+3YM
M92D["B`@("`@("`@;&ES="@D82P@)&(I(#T@96%C:"@D=&AI<RT^;64I.PH@
M("`@("`@(')E='5R;B!S:7IE;V8H)&(I.PH@("`@?0H*("`@("\J*@H@("`@
M("H@1&5T97)M:6YE<R!I9B!T:&4@:71E;2!S=6)M:71T960@:7,@86X@6$U,
M7U)00U]686QU92!O8FIE8W0*("`@("`J"B`@("`@*B!`<&%R86T@;6EX960@
M)'9A;"`@=&AE('9A<FEA8FQE('1O(&)E(&5V86QU871E9`H@("`@("H*("`@
M("`J($!R971U<FX@8F]O;"`@5%)512!I9B!T:&4@:71E;2!I<R!A;B!834Q?
M4E!#7U9A;'5E(&]B:F5C=`H@("`@("H*("`@("`J($!S=&%T:6,*("`@("`J
M($!S:6YC92!-971H;V0@879A:6QA8FQE('-I;F-E(%)E;&5A<V4@,2XS+C`*
M("`@("`J+PH@("`@9G5N8W1I;VX@:7-686QU92@D=F%L*0H@("`@>PH@("`@
M("`@(')E='5R;B`H<W1R=&]L;W=E<BAG971?8VQA<W,H)'9A;"DI(#T]("=X
M;6Q?<G!C7W9A;'5E)RD["B`@("!]"GT*"B\J*@H@*B!2971U<FX@86X@25-/
M.#8P,2!E;F-O9&5D('-T<FEN9PH@*@H@*B!7:&EL92!T:6UE>F]N97,@;W5G
M:'0@=&\@8F4@<W5P<&]R=&5D+"!T:&4@6$U,+5)00R!S<&5C('-A>7,Z"B`J
M"B`J(")$;VXG="!A<W-U;64@82!T:6UE>F]N92X@270@<VAO=6QD(&)E('-P
M96-I9FEE9"!B>2!T:&4@<V5R=F5R(&EN(&ET<PH@*B!D;V-U;65N=&%T:6]N
M('=H870@87-S=6UP=&EO;G,@:70@;6%K97,@86)O=70@=&EM97IO;F5S+B(*
M("H*("H@5&AI<R!R;W5T:6YE(&%L=V%Y<R!A<W-U;65S(&QO8V%L=&EM92!U
M;FQE<W,@)'5T8R!I<R!S970@=&\@,2P@:6X@=VAI8V@*("H@8V%S92!55$,@
M:7,@87-S=6UE9"!A;F0@86X@861J=7-T;65N="!F;W(@;&]C86QE(&ES(&UA
M9&4@=VAE;B!E;F-O9&EN9RX*("H*("H@0')E='5R;B!S=')I;F<@('1H92!F
M;W)M871T960@9&%T90H@*B\*9G5N8W1I;VX@6$U,7U)00U]I<V\X-C`Q7V5N
M8V]D92@D=&EM970L("1U=&,@/2`P*0I["B`@("!I9B`H(21U=&,I('L*("`@
M("`@("`D="`]('-T<F9T:6UE*"<E625M)614)4@Z)4TZ)5,G+"`D=&EM970I
M.PH@("`@?2!E;'-E('L*("`@("`@("!I9B`H9G5N8W1I;VY?97AI<W1S*"=G
M;7-T<F9T:6UE)RDI('L*("`@("`@("`@("`@+R\@9VUS=')F=&EM92!D;V5S
M;B=T(&5X:7-T(&EN('-O;64@=F5R<VEO;G,*("`@("`@("`@("`@+R\@;V8@
M4$A0"B`@("`@("`@("`@("1T(#T@9VUS=')F=&EM92@G)5DE;25D5"5(.B5-
M.B53)RP@)'1I;65T*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D
M="`]('-T<F9T:6UE*"<E625M)614)4@Z)4TZ)5,G+"`D=&EM970@+2!D871E
M*"=:)RDI.PH@("`@("`@('T*("`@('T*("`@(')E='5R;B`D=#L*?0H*+RHJ
M"B`J($-O;G9E<G0@82!D871E=&EM92!S=')I;F<@:6YT;R!A(%5N:7@@=&EM
M97-T86UP"B`J"B`J(%=H:6QE('1I;65Z;VYE<R!O=6=H="!T;R!B92!S=7!P
M;W)T960L('1H92!834PM4E!#('-P96,@<V%Y<SH*("H*("H@(D1O;B=T(&%S
M<W5M92!A('1I;65Z;VYE+B!)="!S:&]U;&0@8F4@<W!E8VEF:65D(&)Y('1H
M92!S97)V97(@:6X@:71S"B`J(&1O8W5M96YT871I;VX@=VAA="!A<W-U;7!T
M:6]N<R!I="!M86ME<R!A8F]U="!T:6UE>F]N97,N(@H@*@H@*B!4:&ES(')O
M=71I;F4@86QW87ES(&%S<W5M97,@;&]C86QT:6UE('5N;&5S<R`D=71C(&ES
M('-E="!T;R`Q+"!I;B!W:&EC:`H@*B!C87-E(%540R!I<R!A<W-U;65D(&%N
M9"!A;B!A9&IU<W1M96YT(&9O<B!L;V-A;&4@:7,@;6%D92!W:&5N(&5N8V]D
M:6YG+@H@*@H@*B!`<F5T=7)N(&EN="`@=&AE('5N:7@@=&EM97-T86UP(&]F
M('1H92!D871E('-U8FUI='1E9`H@*B\*9G5N8W1I;VX@6$U,7U)00U]I<V\X
M-C`Q7V1E8V]D92@D:61A=&4L("1U=&,@/2`P*0I["B`@("`D="`](#`["B`@
M("!I9B`H97)E9R@G*%LP+3E=>S1]*2A;,"TY77LR?2DH6S`M.5U[,GTI5"A;
M,"TY77LR?2DZ*%LP+3E=>S)]*3HH6S`M.5U[,GTI)RP@)&ED871E+"`D<F5G
M<RDI('L*("`@("`@("!I9B`H)'5T8RD@>PH@("`@("`@("`@("`D="`](&=M
M;6MT:6UE*"1R96=S6S1=+"`D<F5G<ULU72P@)')E9W-;-ETL("1R96=S6S)=
M+"`D<F5G<ULS72P@)')E9W-;,5TI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T(#T@;6MT:6UE*"1R96=S6S1=+"`D<F5G<ULU72P@)')E9W-;
M-ETL("1R96=S6S)=+"`D<F5G<ULS72P@)')E9W-;,5TI.PH@("`@("`@('T*
M("`@('T*("`@(')E='5R;B`D=#L*?0H*+RHJ"B`J($-O;G9E<G1S(&%N(%A-
M3%]24$-?5F%L=64@;V)J96-T(&EN=&\@;F%T:79E(%!(4"!T>7!E<PH@*@H@
M*B!`<&%R86T@;V)J96-T("1834Q?4E!#7W9A;"`@=&AE(%A-3%]24$-?5F%L
M=64@;V)J96-T('1O(&1E8V]D90H@*@H@*B!`<F5T=7)N(&UI>&5D("!T:&4@
M4$A0('9A;'5E<PH@*B\*9G5N8W1I;VX@6$U,7U)00U]D96-O9&4H)%A-3%]2
M4$-?=F%L*0I["B`@("`D:VEN9"`]("1834Q?4E!#7W9A;"T^:VEN9$]F*"D[
M"@H@("`@:68@*"1K:6YD(#T]("=S8V%L87(G*2!["B`@("`@("`@<F5T=7)N
M("1834Q?4E!#7W9A;"T^<V-A;&%R=F%L*"D["@H@("`@?2!E;'-E:68@*"1K
M:6YD(#T]("=A<G)A>2<I('L*("`@("`@("`D<VEZ92`]("1834Q?4E!#7W9A
M;"T^87)R87ES:7IE*"D["B`@("`@("`@)&%R<B`](&%R<F%Y*"D["B`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@)'-I>F4[("1I*RLI('L*("`@("`@("`@
M("`@)&%R<EM=(#T@6$U,7U)00U]D96-O9&4H)%A-3%]24$-?=F%L+3YA<G)A
M>6UE;2@D:2DI.PH@("`@("`@('T*("`@("`@("!R971U<FX@)&%R<CL*"B`@
M("!](&5L<V5I9B`H)&MI;F0@/3T@)W-T<G5C="<I('L*("`@("`@("`D6$U,
M7U)00U]V86PM/G-T<G5C=')E<V5T*"D["B`@("`@("`@)&%R<B`](&%R<F%Y
M*"D["B`@("`@("`@=VAI;&4@*&QI<W0H)&ME>2P@)'9A;'5E*2`]("1834Q?
M4E!#7W9A;"T^<W1R=6-T96%C:"@I*2!["B`@("`@("`@("`@("1A<G);)&ME
M>5T@/2!834Q?4E!#7V1E8V]D92@D=F%L=64I.PH@("`@("`@('T*("`@("`@
M("!R971U<FX@)&%R<CL*("`@('T*?0H*+RHJ"B`J($-O;G9E<G1S(&YA=&EV
M92!02%`@='EP97,@:6YT;R!A;B!834Q?4E!#7U9A;'5E(&]B:F5C=`H@*@H@
M*B!`<&%R86T@;6EX960@)'!H<%]V86P@('1H92!02%`@=F%L=64@;W(@=F%R
M:6%B;&4@>6]U('=A;G0@96YC;V1E9`H@*@H@*B!`<F5T=7)N(&]B:F5C="`@
M=&AE(%A-3%]24$-?5F%L=64@;V)J96-T"B`J+PIF=6YC=&EO;B!834Q?4E!#
M7V5N8V]D92@D<&AP7W9A;"D*>PH@("`@)'1Y<&4@/2!G971T>7!E*"1P:'!?
M=F%L*3L*("`@("1834Q?4E!#7W9A;"`](&YE=R!834Q?4E!#7U9A;'5E.PH*
M("`@('-W:71C:"`H)'1Y<&4I('L*("`@(&-A<V4@)V%R<F%Y)SH*("`@("`@
M("!I9B`H96UP='DH)'!H<%]V86PI*2!["B`@("`@("`@("`@("1834Q?4E!#
M7W9A;"T^861D07)R87DH)'!H<%]V86PI.PH@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("!]"B`@("`@("`@)'1M<"`](&%R<F%Y7V1I9F8H87)R87E?:V5Y
M<R@D<&AP7W9A;"DL(')A;F=E*#`L(&-O=6YT*"1P:'!?=F%L*2TQ*2D["B`@
M("`@("`@:68@*&5M<'1Y*"1T;7`I*2!["B`@("`@("`@("`@)&%R<B`](&%R
M<F%Y*"D["B`@("`@("`@("`@9F]R96%C:"`H)'!H<%]V86P@87,@)&L@/3X@
M)'8I('L*("`@("`@("`@("`@("`@)&%R<ELD:UT@/2!834Q?4E!#7V5N8V]D
M92@D=BD["B`@("`@("`@("`@?0H@("`@("`@("`@("1834Q?4E!#7W9A;"T^
M861D07)R87DH)&%R<BD["B`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@
M("`@("`@("\O(&9A;&P@=&AO=6=H(&EF(&ET)W,@;F]T(&%N(&5N=6UE<F%T
M960@87)R87D*"B`@("!C87-E("=O8FIE8W0G.@H@("`@("`@("1A<G(@/2!A
M<G)A>2@I.PH@("`@("`@(&9O<F5A8V@@*"1P:'!?=F%L(&%S("1K(#T^("1V
M*2!["B`@("`@("`@("`@("1A<G);)&M=(#T@6$U,7U)00U]E;F-O9&4H)'8I
M.PH@("`@("`@('T*("`@("`@("`D6$U,7U)00U]V86PM/F%D9%-T<G5C="@D
M87)R*3L*("`@("`@("!B<F5A:SL*"B`@("!C87-E("=I;G1E9V5R)SH*("`@
M("`@("`D6$U,7U)00U]V86PM/F%D9%-C86QA<B@D<&AP7W9A;"P@)$=,3T)!
M3%-;)UA-3%]24$-?26YT)UTI.PH@("`@("`@(&)R96%K.PH*("`@(&-A<V4@
M)V1O=6)L92<Z"B`@("`@("`@)%A-3%]24$-?=F%L+3YA9&138V%L87(H)'!H
M<%]V86PL("1'3$]"04Q36R=834Q?4E!#7T1O=6)L92==*3L*("`@("`@("!B
M<F5A:SL*"B`@("!C87-E("=S=')I;F<G.@H@("`@8V%S92`G3E5,3"<Z"B`@
M("`@("`@:68@*&5R96<H)UY;,"TY77LX?5Q4>S%]6S`M.5U[,GU<.ELP+3E=
M>S)]7#I;,"TY77LR?20G+"`D<&AP7W9A;"DI('L*("`@("`@("`@("`@)%A-
M3%]24$-?=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1'3$]"04Q36R=834Q?
M4E!#7T1A=&54:6UE)UTI.PH@("`@("`@('T@96QS96EF("AP<F5G7VUA=&-H
M*"<O6UY<>#(P+5QX-T5<>#`Y7'@P05QX,$1=+R<L("1P:'!?=F%L*2D@>PH@
M("`@("`@("`@("`O+R!#:&%R86-T97)S(&]T:&5R('1H86X@86QP:&$M;G5M
M97)I8RP@<'5N8W1U871I;VXL(%-0+"!404(L"B`@("`@("`@("`@("\O($Q&
M(&%N9"!#4B!B<F5A:R!T:&4@6$U,('!A<G-E<BP@96YC;V1E('9A;'5E('9I
M82!"87-E(#8T+@H@("`@("`@("`@("`D6$U,7U)00U]V86PM/F%D9%-C86QA
M<B@D<&AP7W9A;"P@)$=,3T)!3%-;)UA-3%]24$-?0F%S938T)UTI.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1834Q?4E!#7W9A;"T^861D4V-A
M;&%R*"1P:'!?=F%L+"`D1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G72D["B`@
M("`@("`@?0H@("`@("`@(&)R96%K.PH*("`@(&-A<V4@)V)O;VQE86XG.@H@
M("`@("`@("\O($%D9"!S=7!P;W)T(&9O<B!E;F-O9&EN9R]D96-O9&EN9R!O
M9B!B;V]L96%N<RP@<VEN8V4@=&AE>0H@("`@("`@("\O(&%R92!S=7!P;W)T
M960@:6X@4$A0"B`@("`@("`@+R\@8GD@/$=?1VEU;G1A7S(P,#$M,#(M,CD^
M"B`@("`@("`@)%A-3%]24$-?=F%L+3YA9&138V%L87(H)'!H<%]V86PL("1'
M3$]"04Q36R=834Q?4E!#7T)O;VQE86XG72D["B`@("`@("`@8G)E86L["@H@
M("`@8V%S92`G=6YK;F]W;B!T>7!E)SH*("`@(&1E9F%U;'0Z"B`@("`@("`@
M)%A-3%]24$-?=F%L(#T@9F%L<V4["B`@("!]"B`@("!R971U<FX@)%A-3%]2
M4$-?=F%L.PI]"@HO*@H@*B!,;V-A;"!V87)I86)L97,Z"B`J('1A8BUW:61T
M:#H@-`H@*B!C+6)A<VEC+6]F9G-E=#H@-`H@*B!C+6AA;F=I;F<M8V]M;65N
M="UE;F1E<BUP.B!N:6P*("H@16YD.@H@*B\*"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U!A
M<G-E<B]3:6UP;&4N<&AP````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`R,#(P-"`Q,#4Q-30S-#$S,R`P,C(S,34`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#
M;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P-"!4:&4@4$A0($=R;W5P("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T
M;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@
M?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I
M;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E
M+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0
M(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO
M=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C
M86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R
M.B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\*+R\@)$ED.B!3:6UP;&4N<&AP+'8@,2XV(#(P,#4O,#,O,C4@
M,3<Z,3,Z,3`@<V-H<W0@17AP("0*"B\J*@H@*B!3:6UP;&4@6$U,('!A<G-E
M<B!C;&%S<RX*("H*("H@5&AI<R!C;&%S<R!I<R!A('-I;7!L:69I960@=F5R
M<VEO;B!O9B!834Q?4&%R<V5R+@H@*B!);B!M;W-T(%A-3"!A<'!L:6-A=&EO
M;G,@=&AE(')E86P@86-T:6]N(&ES(&5X96-U=&5D+`H@*B!W:&5N(&$@8VQO
M<VEN9R!T86<@:7,@9F]U;F0N"B`J"B`J(%A-3%]087)S97)?4VEM<&QE(&%L
M;&]W<R!Y;W4@=&\@:G5S="!I;7!L96UE;G0@;VYE(&-A;&QB86-K"B`J(&9O
M<B!E86-H('1A9R!T:&%T('=I;&P@<F5C96EV92!T:&4@=&%G('=I=&@@:71S
M(&%T=')I8G5T97,*("H@86YD($-$871A"B`J"B`J($!C871E9V]R>2!834P*
M("H@0'!A8VMA9V4@6$U,7U!A<G-E<@H@*B!`875T:&]R("!3=&5P:&%N(%-C
M:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^"B`J+PH*+RHJ"B`J(&)U:6QT
M(&]N(%A-3%]087)S97(*("HO"G)E<75I<F5?;VYC92`G6$U,+U!A<G-E<BYP
M:'`G.PH*+RHJ"B`J(%-I;7!L92!834P@<&%R<V5R(&-L87-S+@H@*@H@*B!4
M:&ES(&-L87-S(&ES(&$@<VEM<&QI9FEE9"!V97)S:6]N(&]F(%A-3%]087)S
M97(N"B`J($EN(&UO<W0@6$U,(&%P<&QI8V%T:6]N<R!T:&4@<F5A;"!A8W1I
M;VX@:7,@97AE8W5T960L"B`J('=H96X@82!C;&]S:6YG('1A9R!I<R!F;W5N
M9"X*("H*("H@6$U,7U!A<G-E<E]3:6UP;&4@86QL;W=S('EO=2!T;R!J=7-T
M(&EM<&QE;65N="!O;F4@8V%L;&)A8VL*("H@9F]R(&5A8V@@=&%G('1H870@
M=VEL;"!R96-E:79E('1H92!T86<@=VET:"!I=',@871T<FEB=71E<PH@*B!A
M;F0@0T1A=&$N"B`J"B`J(#QC;V1E/@H@*B!R97%U:7)E7V]N8V4@)RXN+U!A
M<G-E<B]3:6UP;&4N<&AP)SL*("H*("H@8VQA<W,@;7E087)S97(@97AT96YD
M<R!834Q?4&%R<V5R7U-I;7!L90H@*B!["B`J("`@("!F=6YC=&EO;B!M>5!A
M<G-E<B@I"B`J("`@("!["B`J("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<E]3
M:6UP;&4H*3L*("H@("`@("!]"B`J(`H@*B`@("!F=6YC=&EO;B!H86YD;&5%
M;&5M96YT*"1N86UE+"`D871T<FEB<RP@)&1A=&$I"B`J("`@("!["B`J("`@
M("`@("`@<')I;G1F*"=H86YD;&4@)7,\8G(^)RP@)&YA;64I.PH@*B`@("`@
M?0H@*B!]"B`J(`H@*B`D<"`]("9N97<@;7E087)S97(H*3L*("H@"B`J("1R
M97-U;'0@/2`D<"T^<V5T26YP=71&:6QE*"=M>41O8RYX;6PG*3L*("H@)')E
M<W5L="`]("1P+3YP87)S92@I.PH@*B`\+V-O9&4^"B`J"B`J($!C871E9V]R
M>2!834P*("H@0'!A8VMA9V4@6$U,7U!A<G-E<@H@*B!`875T:&]R("!3=&5P
M:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"UT;V]L<RYN970^"B`J+PIC;&%S<R!8
M34Q?4&%R<V5R7U-I;7!L92!E>'1E;F1S(%A-3%]087)S97(*>PH@("`O*BH*
M("`@("H@96QE;65N="!S=&%C:PH@("`@*@H@("`@*B!`86-C97-S("`@<')I
M=F%T90H@("`@*B!`=F%R("`@("`@87)R87D*("`@("HO"B`@("!V87(@)%]E
M;%-T86-K(#T@87)R87DH*3L*"B`@("\J*@H@("`@*B!A;&P@8VAA<F%C=&5R
M(&1A=&$*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@0'9A
M<B`@("`@(&%R<F%Y"B`@("`J+PH@("`@=F%R("1?9&%T82`](&%R<F%Y*"D[
M"@H@("`O*BH*("`@("H@96QE;65N="!D97!T:`H@("`@*@H@("`@*B!`86-C
M97-S("`@<')I=F%T90H@("`@*B!`=F%R("`@("`@:6YT96=E<@H@("`@*B\*
M("`@('9A<B`D7V1E<'1H(#T@,#L*"B`@("`O*BH*("`@("`J($UA<'!I;F<@
M9G)O;2!E>'!A="!H86YD;&5R(&9U;F-T:6]N('1O(&-L87-S(&UE=&AO9"X*
M("`@("`J"B`@("`@*B!`=F%R("!A<G)A>0H@("`@("HO"B`@("!V87(@)&AA
M;F1L97(@/2!A<G)A>2@*("`@("`@("`G9&5F875L=%]H86YD;&5R)R`@("`@
M("`@("`@("`@("`@("`]/B`G9&5F875L=$AA;F1L97(G+`H@("`@("`@("=P
M<F]C97-S:6YG7VEN<W1R=6-T:6]N7VAA;F1L97(G("`@(#T^("=P:4AA;F1L
M97(G+`H@("`@("`@("=U;G!A<G-E9%]E;G1I='E?9&5C;%]H86YD;&5R)R`@
M("`@(#T^("=U;G!A<G-E9$AA;F1L97(G+`H@("`@("`@("=N;W1A=&EO;E]D
M96-L7VAA;F1L97(G("`@("`@("`@("`@(#T^("=N;W1A=&EO;DAA;F1L97(G
M+`H@("`@("`@("=E>'1E<FYA;%]E;G1I='E?<F5F7VAA;F1L97(G("`@("`@
M(#T^("=E;G1I='ER969(86YD;&5R)PH@("`@*3L*("`@(`H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S(&%N(%A-3"!P87)S97(N"B`@("`@*@H@("`@("H@5&AI
M<R!I<R!N965D960@9F]R(%!(4#0@8V]M<&%T:6)I;&ET>2P@:70@=VEL;`H@
M("`@("H@8V%L;"!T:&4@8V]N<W1R=6-T;W(L('=H96X@82!N97<@:6YS=&%N
M8V4@:7,@8W)E871E9"X*("`@("`J"B`@("`@*B!`<&%R86T@<W1R:6YG("1S
M<F-E;F,@<V]U<F-E(&-H87)S970@96YC;V1I;F<L('5S92!.54Q,("AD969A
M=6QT*2!T;R!U<V4*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!W:&%T
M979E<B!T:&4@9&]C=6UE;G0@<W!E8VEF:65S"B`@("`@*B!`<&%R86T@<W1R
M:6YG("1M;V1E("`@:&]W('1H:7,@<&%R<V5R(&]B:F5C="!S:&]U;&0@=V]R
M:RP@(F5V96YT(B!F;W(*("`@("`J("`@("`@("`@("`@("`@("`@("`@("!H
M86YD;&5%;&5M96YT*"DL(")F=6YC(B!T;R!H879E(&ET(&-A;&P@9G5N8W1I
M;VYS"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@;F%M960@869T97(@
M96QE;65N=',@*&AA;F1L945L96UE;G1?)&YA;64H*2D*("`@("`J($!P87)A
M;2!S=')I;F<@)'1G96YC("!A('9A;&ED('1A<F=E="!E;F-O9&EN9PH@("`@
M("HO"B`@("!F=6YC=&EO;B!834Q?4&%R<V5R7U-I;7!L92@D<W)C96YC(#T@
M;G5L;"P@)&UO9&4@/2`G979E;G0G+"`D=&=T96YC(#T@;G5L;"D*("`@('L*
M("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<B@D<W)C96YC+"`D;6]D92P@)'1G
M=&5N8RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!I;FET<R!T:&4@:&%N9&QE
M<G,*("`@("`J"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%]I;FET2&%N9&QE<G,H*0H@("`@>PH@("`@("`@(&EF("@A
M:7-?;V)J96-T*"1T:&ES+3Y?:&%N9&QE<D]B:BDI('L*("`@("`@("`@("`@
M)'1H:7,M/E]H86YD;&5R3V)J(#T@)B1T:&ES.PH@("`@("`@('T*"B`@("`@
M("`@:68@*"1T:&ES+3YM;V1E("$]("=F=6YC)R`F)B`D=&AI<RT^;6]D92`A
M/2`G979E;G0G*2!["B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^<F%I<V5%
M<G)O<B@G56YS=7!P;W)T960@;6]D92!G:79E;B<L(%A-3%]005)315)?15)2
M3U)?54Y355!03U)4141?34]$12D["B`@("`@("`@?0H@("`@("`@('AM;%]S
M971?;V)J96-T*"1T:&ES+3YP87)S97(L("1T:&ES+3Y?:&%N9&QE<D]B:BD[
M"@H@("`@("`@('AM;%]S971?96QE;65N=%]H86YD;&5R*"1T:&ES+3YP87)S
M97(L(&%R<F%Y*"8D=&AI<RP@)W-T87)T2&%N9&QE<B<I+"!A<G)A>2@F)'1H
M:7,L("=E;F1(86YD;&5R)RDI.PH@("`@("`@('AM;%]S971?8VAA<F%C=&5R
M7V1A=&%?:&%N9&QE<B@D=&AI<RT^<&%R<V5R+"!A<G)A>2@F)'1H:7,L("=C
M9&%T84AA;F1L97(G*2D["B`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@
M("H@<V5T(&%D9&ET:6]N86P@:&%N9&QE<G,@9F]R(&-H87)A8W1E<B!D871A
M+"!E;G1I=&EE<RP@971C+@H@("`@("`@("`J+PH@("`@("`@(&9O<F5A8V@@
M*"1T:&ES+3YH86YD;&5R(&%S("1X;6Q?9G5N8R`]/B`D;65T:&]D*2!["B`@
M("`@("`@("`@(&EF("AM971H;V1?97AI<W1S*"1T:&ES+3Y?:&%N9&QE<D]B
M:BP@)&UE=&AO9"DI('L*("`@("`@("`@("`@("`@("1X;6Q?9G5N8R`]("=X
M;6Q?<V5T7R<@+B`D>&UL7V9U;F,["B`@("`@("`@("`@("`@("`D>&UL7V9U
M;F,H)'1H:7,M/G!A<G-E<BP@)&UE=&AO9"D["B`@("`@("`@("`@('T*"0E]
M"B`@("!]"@H@("`@+RHJ"B`@("`@*B!297-E="!T:&4@<&%R<V5R+@H@("`@
M("H*("`@("`J(%1H:7,@86QL;W=S('EO=2!T;R!U<V4@;VYE('!A<G-E<B!I
M;G-T86YC90H@("`@("H@=&\@<&%R<V4@;75L=&EP;&4@6$U,(&1O8W5M96YT
M<RX*("`@("`J"B`@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`@*B!`<F5T
M=7)N("`@8F]O;&5A;GQO8FIE8W0@("`@('1R=64@;VX@<W5C8V5S<RP@4$5!
M4E]%<G)O<B!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<F5S970H
M*0H@("`@>PH@("`@("`@("1T:&ES+3Y?96Q3=&%C:R`](&%R<F%Y*"D["B`@
M("`@("`@)'1H:7,M/E]D871A("`@(#T@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^7V1E<'1H("`@/2`P.PH@("`@("`@(`H@("`@("`@("1R97-U;'0@/2`D
M=&AI<RT^7V-R96%T92@I.PH@("`@("`@(&EF("@D=&AI<RT^:7-%<G)O<B@@
M)')E<W5L="`I*2!["B`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@
M("`@('T*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@("\J*@H@("`@
M*B!S=&%R="!H86YD;&5R"B`@("`J"B`@("`J(%!U<VAE<R!A='1R:6)U=&5S
M(&%N9"!T86=N86UE(&]N=&\@82!S=&%C:PH@("`@*@H@("`@*B!`86-C97-S
M("`@<')I=F%T90H@("`@*B!`9FEN86P*("`@("H@0'!A<F%M("`@(')E<V]U
M<F-E("`@('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@0'!A<F%M("`@('-T
M<FEN9R`@("`@(&5L96UE;G0@;F%M90H@("`@*B!`<&%R86T@("`@87)R87D@
M("`@("`@871T<FEB=71E<PH@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N
M9&QE<B@D>'`L("1E;&5M+"`F)&%T=')I8G,I"B`@("!["B`@("`@("`@87)R
M87E?<'5S:"@D=&AI<RT^7V5L4W1A8VLL(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=N86UE)R`@("`]/B`D
M96QE;2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G871T<FEB<R<@/3X@)&%T=')I8G,*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@*3L*
M("`@("`@("`D=&AI<RT^7V1E<'1H*RL["B`@("`@("`@)'1H:7,M/E]D871A
M6R1T:&ES+3Y?9&5P=&A=(#T@)R<["B`@("!]"@H@("`O*BH*("`@("H@96YD
M(&AA;F1L97(*("`@("H*("`@("H@4'5L;',@871T<FEB=71E<R!A;F0@=&%G
M;F%M92!F<F]M(&$@<W1A8VL*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A
M=&4*("`@("H@0&9I;F%L"B`@("`J($!P87)A;2`@("!R97-O=7)C92`@("!X
M;6P@<&%R<V5R(')E<V]U<F-E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@
M("!E;&5M96YT(&YA;64*("`@("HO"B`@("!F=6YC=&EO;B!E;F1(86YD;&5R
M*"1X<"P@)&5L96TI"B`@("!["B`@("`@("`@)&5L("`@/2!A<G)A>5]P;W`H
M)'1H:7,M/E]E;%-T86-K*3L*("`@("`@("`D9&%T82`]("1T:&ES+3Y?9&%T
M85LD=&AI<RT^7V1E<'1H73L*("`@("`@("`D=&AI<RT^7V1E<'1H+2T["@H@
M("`@("`@('-W:71C:"`H)'1H:7,M/FUO9&4I('L*("`@("`@("`@("`@8V%S
M92`G979E;G0G.@H@("`@("`@("`@("`@("`@)'1H:7,M/E]H86YD;&5R3V)J
M+3YH86YD;&5%;&5M96YT*"1E;%LG;F%M92==+"`D96Q;)V%T=')I8G,G72P@
M)&1A=&$I.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@)V9U;F,G.@H@("`@("`@("`@("`@("`@)&9U;F,@/2`G:&%N9&QE16QE
M;65N=%\G("X@)&5L96T["B`@("`@("`@("`@("`@("!I9B`H<W1R8VAR*"1F
M=6YC+"`G+B<I*2!["B`@("`@("`@("`@("`@("`@("`@)&9U;F,@/2!S=')?
M<F5P;&%C92@G+B<L("=?)RP@)&9U;F,I.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@:68@*&UE=&AO9%]E>&ES=',H)'1H:7,M/E]H86YD
M;&5R3V)J+"`D9G5N8RDI('L*("`@("`@("`@("`@("`@("`@("!C86QL7W5S
M97)?9G5N8RAA<G)A>2@F)'1H:7,M/E]H86YD;&5R3V)J+"`D9G5N8RDL("1E
M;%LG;F%M92==+"`D96Q;)V%T=')I8G,G72P@)&1A=&$I.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H@("`@
M?0H*("`@+RHJ"B`@("`J(&AA;F1L92!C:&%R86-T97(@9&%T80H@("`@*@H@
M("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`9FEN86P*("`@("H@0'!A
M<F%M("`@(')E<V]U<F-E("`@('AM;"!P87)S97(@<F5S;W5R8V4*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&1A=&$*("`@("HO"B`@("!F=6YC=&EO
M;B!C9&%T84AA;F1L97(H)'AP+"`D9&%T82D*("`@('L*("`@("`@("`D=&AI
M<RT^7V1A=&%;)'1H:7,M/E]D97!T:%T@+CT@)&1A=&$["B`@("!]"@H@("`O
M*BH*("`@("H@:&%N9&QE(&$@=&%G"B`@("`J"B`@("`J($EM<&QE;65N="!T
M:&ES(&EN('EO=7(@<&%R<V5R(`H@("`@*@H@("`@*B!`86-C97-S("`@<'5B
M;&EC"B`@("`J($!A8G-T<F%C=`H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@
M("`@96QE;65N="!N86UE"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A
M='1R:6)U=&5S"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!C:&%R86-T
M97(@9&%T80H@("`@*B\*("`@(&9U;F-T:6]N(&AA;F1L945L96UE;G0H)&YA
M;64L("1A='1R:6)S+"`D9&%T82D*("`@('L*("`@('T*"B`@("\J*@H@("`@
M*B!G970@=&AE(&-U<G)E;G0@=&%G(&1E<'1H"B`@("`J"B`@("`J(%1H92!R
M;V]T('1A9R!I<R!I;B!D97!T:"`P+@H@("`@*@H@("`@*B!`86-C97-S("`@
M<'5B;&EC"B`@("`J($!R971U<FX@("!I;G1E9V5R"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V5T0W5R<F5N=$1E<'1H*"D*("`@('L*("`@("`@("!R971U<FX@
M)'1H:7,M/E]D97!T:#L*("`@('T*"B`@("\J*@H@("`@*B!A9&0@<V]M92!S
M=')I;F<@=&\@=&AE(&-U<G)E;G0@9&1A=&$N"B`@("`J"B`@("`J(%1H:7,@
M:7,@8V]M;6]N;'D@;F5E9&5D+"!W:&5N(&$@9&]C=6UE;G0@:7,@<&%R<V5D
M(')E8W5R<VEV96QY+@H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@
M("`J($!P87)A;2`@("!S=')I;F<@("`@("!D871A('1O(&%D9`H@("`@*B!`
M<F5T=7)N("`@=F]I9`H@("`@*B\*("`@(&9U;F-T:6]N(&%D9%1O1&%T82@@
M)&1A=&$@*0H@("`@>PH@("`@("`@("1T:&ES+3Y?9&%T85LD=&AI<RT^7V1E
M<'1H72`N/2`D9&%T83L*("`@('T*?0H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O6$U,+U)00R]397)V97(N
M<&AP````````````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`U,C,T
M-R`Q,#4Q-30S-#$S,R`P,C$U,S<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*"B\J('9I;3H@<V5T(&5X<&%N9'1A
M8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO"@HO
M*BH*("H@4V5R=F5R(&-O;6UA;F1S(&9O<B!O=7(@4$A0(&EM<&QE;65N=&%T
M:6]N(&]F('1H92!834PM4E!#('!R;W1O8V]L"B`J"B`J(%1H:7,@:7,@82!0
M14%2+6EF:65D('9E<G-I;VX@;V8@57-E9G5L(&EN8R=S(%A-3"U24$,@9F]R
M(%!(4"X*("H@270@:&%S('-U<'!O<G0@9F]R($A45%`@=')A;G-P;W)T+"!P
M<F]X:65S(&%N9"!A=71H96YT:6-A=&EO;BX*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@3$E#14Y313H@3&EC96YS92!I<R!G<F%N=&5D('1O
M('5S92!O<B!M;V1I9GD@=&AI<R!S;V9T=V%R90H@*B`H(EA-3"U24$,@9F]R
M(%!(4"(I(&9O<B!C;VUM97)C:6%L(&]R(&YO;BUC;VUM97)C:6%L('5S92!P
M<F]V:61E9"!T:&4*("H@8V]P>7)I9VAT(&]F('1H92!A=71H;W(@:7,@<')E
M<V5R=F5D(&EN(&%N>2!D:7-T<FEB=71E9"!O<B!D97)I=F%T:79E('=O<FLN
M"B`J"B`J(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($%55$A/
M4B`B05,@25,B($%.1"!!3ED@15A04D534T5$($]2"B`J($E-4$Q)140@5T%2
M4D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,*("H@3T8@34520TA!3E1!0DE,2519($%.1"!&
M251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%
M1"X*("H@24X@3D\@159%3E0@4TA!3$P@5$A%($%55$A/4B!"12!,24%"3$4@
M1D]2($%.62!$25)%0U0L($E.1$E214-4+`H@*B!)3D-)1$5.5$%,+"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550*("H@3D]4($Q)34E4140@5$\L(%!23T-54D5-14Y4($]&
M(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+`H@
M*B!$051!+"!/4B!04D]&2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI
M($A/5T5615(@0T%54T5$($%.1"!/3B!!3ED*("H@5$A%3U)9($]&($Q)04))
M3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@
M3U(@5$]25`H@*B`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@3T8*("H@5$A)
M4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E4
M62!/1B!354-(($1!34%'12X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I
M8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@161D
M($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!-87)T
M:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O=7`*
M("H@0'9E<G-I;VX@("`@0U93.B`D260Z(%-E<G9E<BYP:'`L=B`Q+C,S(#(P
M,#8O,#$O,30@,C(Z,S`Z,S$@9&%N:65L8R!%>'`@)`H@*B!`;&EN:R`@("`@
M("!H='1P.B\O<&5A<BYP:'`N;F5T+W!A8VMA9V4O6$U,7U)00PH@*B\*"@HO
M*BH*("H@4'5L;"!I;B!T:&4@6$U,7U)00R!C;&%S<PH@*B\*<F5Q=6ER95]O
M;F-E("=834PO4E!#+G!H<"<["@H*+RHJ"B`J('-I9VYA='5R92!F;W(@<WES
M=&5M+FQI<W1-971H;V1S.B!R971U<FX@/2!A<G)A>2P*("H@<&%R86UE=&5R
M<R`](&$@<W1R:6YG(&]R(&YO=&AI;F<*("H@0&=L;V)A;"!A<G)A>2`D1TQ/
M0D%,4ULG6$U,7U)00U]397)V97)?;&ES=$UE=&AO9'-?<VEG)UT*("HO"B1'
M3$]"04Q36R=834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<U]S:6<G72`](&%R
M<F%Y*`H@("`@87)R87DH)$=,3T)!3%-;)UA-3%]24$-?07)R87DG72P*("`@
M("`@("`@("1'3$]"04Q36R=834Q?4E!#7U-T<FEN9R=="B`@("`I+`H@("`@
M87)R87DH)$=,3T)!3%-;)UA-3%]24$-?07)R87DG72D**3L*"B\J*@H@*B!D
M;V-S=')I;F<@9F]R('-Y<W1E;2YL:7-T365T:&]D<PH@*B!`9VQO8F%L('-T
M<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;&ES=$UE=&AO9'-?9&]C
M)UT*("HO"B1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<U]D
M;V,G72`]("=4:&ES(&UE=&AO9"!L:7-T<R!A;&P@=&AE)PH@("`@("`@("X@
M)R!M971H;V1S('1H870@=&AE(%A-3"U24$,@<V5R=F5R(&MN;W=S(&AO=R!T
M;R!D:7-P871C:"<["@HO*BH*("H@<VEG;F%T=7)E(&9O<B!S>7-T96TN;65T
M:&]D4VEG;F%T=7)E.B!R971U<FX@/2!A<G)A>2P*("H@<&%R86UE=&5R<R`]
M('-T<FEN9PH@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?4E!#7U-E
M<G9E<E]M971H;V13:6=N871U<F5?<VEG)UT*("HO"B1'3$]"04Q36R=834Q?
M4E!#7U-E<G9E<E]M971H;V13:6=N871U<F5?<VEG)UT@/2!A<G)A>2@*("`@
M(&%R<F%Y*"1'3$]"04Q36R=834Q?4E!#7T%R<F%Y)UTL"B`@("`@("`@("`D
M1TQ/0D%,4ULG6$U,7U)00U]3=')I;F<G70H@("`@*0HI.PH*+RHJ"B`J(&1O
M8W-T<FEN9R!F;W(@<WES=&5M+FUE=&AO9%-I9VYA='5R90H@*B!`9VQO8F%L
M('-T<FEN9R`D1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T:&]D4VEG;F%T
M=7)E7V1O8R=="B`J+PHD1TQ/0D%,4ULG6$U,7U)00U]397)V97)?;65T:&]D
M4VEG;F%T=7)E7V1O8R==(#T@)U)E='5R;G,@86X@87)R87D@;V8@:VYO=VXG
M"B`@("`@("`@+B`G('-I9VYA='5R97,@*&%N(&%R<F%Y(&]F(&%R<F%Y<RD@
M9F]R('1H92!M971H;V0@;F%M92!P87-S960N($EF)PH@("`@("`@("X@)R!N
M;R!S:6=N871U<F5S(&%R92!K;F]W;BP@<F5T=7)N<R!A(&YO;F4M87)R87D@
M*'1E<W0@9F]R('1Y<&4@(3TG"B`@("`@("`@+B`G(&%R<F%Y('1O(&1E=&5C
M="!M:7-S:6YG('-I9VYA='5R92DG.PH*+RHJ"B`J('-I9VYA='5R92!F;W(@
M<WES=&5M+FUE=&AO9$AE;'`Z(')E='5R;B`]('-T<FEN9RP*("H@<&%R86UE
M=&5R<R`]('-T<FEN9PH@*B!`9VQO8F%L(&%R<F%Y("1'3$]"04Q36R=834Q?
M4E!#7U-E<G9E<E]M971H;V1(96QP7W-I9R=="B`J+PHD1TQ/0D%,4ULG6$U,
M7U)00U]397)V97)?;65T:&]D2&5L<%]S:6<G72`](&%R<F%Y*`H@("`@87)R
M87DH)$=,3T)!3%-;)UA-3%]24$-?4W1R:6YG)UTL"B`@("`@("`@("`D1TQ/
M0D%,4ULG6$U,7U)00U]3=')I;F<G70H@("`@*0HI.PH*+RHJ"B`J(&1O8W-T
M<FEN9R!F;W(@;65T:&]D2&5L<`H@*B!`9VQO8F%L('-T<FEN9R`D1TQ/0D%,
M4ULG6$U,7U)00U]397)V97)?;65T:&]D2&5L<%]D;V,G70H@*B\*)$=,3T)!
M3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'!?9&]C)UT@/2`G4F5T=7)N
M<R!H96QP('1E>'0@:68@9&5F:6YE9"<*("`@("`@("`N("<@9F]R('1H92!M
M971H;V0@<&%S<V5D+"!O=&AE<G=I<V4@<F5T=7)N<R!A;B!E;7!T>2!S=')I
M;F<G.PH*+RHJ"B`J(&1I<W!A=&-H(&UA<"!F;W(@=&AE(&%U=&]M871I8V%L
M;'D@9&5C;&%R960@6$U,+5)00R!M971H;V1S+@H@*B!`9VQO8F%L(&%R<F%Y
M("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]D;6%P)UT*("HO"B1'3$]"04Q3
M6R=834Q?4E!#7U-E<G9E<E]D;6%P)UT@/2!A<G)A>2@*("`@("=S>7-T96TN
M;&ES=$UE=&AO9',G(#T^(&%R<F%Y*`H@("`@("`@("=F=6YC=&EO;B<@(#T^
M("=834Q?4E!#7U-E<G9E<E]L:7-T365T:&]D<R<L"B`@("`@("`@)W-I9VYA
M='5R92<@/3X@)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VQI<W1-971H;V1S
M7W-I9R==+`H@("`@("`@("=D;V-S=')I;F<G(#T^("1'3$]"04Q36R=834Q?
M4E!#7U-E<G9E<E]L:7-T365T:&]D<U]D;V,G70H@("`@*2P*("`@("=S>7-T
M96TN;65T:&]D2&5L<"<@/3X@87)R87DH"B`@("`@("`@)V9U;F-T:6]N)R`@
M/3X@)UA-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'`G+`H@("`@("`@("=S:6=N
M871U<F4G(#T^("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M971H;V1(96QP
M7W-I9R==+`H@("`@("`@("=D;V-S=')I;F<G(#T^("1'3$]"04Q36R=834Q?
M4E!#7U-E<G9E<E]M971H;V1(96QP7V1O8R=="B`@("`I+`H@("`@)W-Y<W1E
M;2YM971H;V13:6=N871U<F4G(#T^(&%R<F%Y*`H@("`@("`@("=F=6YC=&EO
M;B<@(#T^("=834Q?4E!#7U-E<G9E<E]M971H;V13:6=N871U<F4G+`H@("`@
M("`@("=S:6=N871U<F4G(#T^("1'3$]"04Q36R=834Q?4E!#7U-E<G9E<E]M
M971H;V13:6=N871U<F5?<VEG)UTL"B`@("`@("`@)V1O8W-T<FEN9R<@/3X@
M)$=,3T)!3%-;)UA-3%]24$-?4V5R=F5R7VUE=&AO9%-I9VYA='5R95]D;V,G
M70H@("`@*0HI.PH*+RHJ"B`J($!G;&]B86P@<W1R:6YG("1'3$]"04Q36R=8
M34Q?4E!#7U-E<G9E<E]D96)U9VEN9F\G70H@*B\*)$=,3T)!3%-;)UA-3%]2
M4$-?4V5R=F5R7V1E8G5G:6YF;R==(#T@)R<["@H*+RHJ"B`J($QI<W1S(&%L
M;"!T:&4@;65T:&]D<R!T:&%T('1H92!834PM4E!#('-E<G9E<B!K;F]W<R!H
M;W<@=&\@9&ES<&%T8V@*("H*("H@0')E='5R;B!O8FIE8W0@(&$@;F5W(%A-
M3%]24$-?4F5S<&]N<V4@;V)J96-T"B`J+PIF=6YC=&EO;B!834Q?4E!#7U-E
M<G9E<E]L:7-T365T:&]D<R@D<V5R=F5R+"`D;2D*>PH@("`@9VQO8F%L("18
M34Q?4E!#7V5R<BP@)%A-3%]24$-?<W1R+"`D6$U,7U)00U]397)V97)?9&UA
M<#L*"B`@("`D=B`](&YE=R!834Q?4E!#7U9A;'5E*"D["B`@("`D;W5T07(@
M/2!A<G)A>2@I.PH@("`@9F]R96%C:"`H)'-E<G9E<BT^9&UA<"!A<R`D:V5Y
M(#T^("1V86PI('L*("`@("`@("`D;W5T07);72`](&YE=R!834Q?4E!#7U9A
M;'5E*"1K97DL("=S=')I;F<G*3L*("`@('T*("`@(&9O<F5A8V@@*"1834Q?
M4E!#7U-E<G9E<E]D;6%P(&%S("1K97D@/3X@)'9A;"D@>PH@("`@("`@("1O
M=71!<EM=(#T@;F5W(%A-3%]24$-?5F%L=64H)&ME>2P@)W-T<FEN9R<I.PH@
M("`@?0H@("`@)'8M/F%D9$%R<F%Y*"1O=71!<BD["B`@("!R971U<FX@;F5W
M(%A-3%]24$-?4F5S<&]N<V4H)'8I.PI]"@HO*BH*("H@4F5T=7)N<R!A;B!A
M<G)A>2!O9B!K;F]W;B!S:6=N871U<F5S("AA;B!A<G)A>2!O9B!A<G)A>7,I
M"B`J(&9O<B!T:&4@9VEV96X@;65T:&]D"B`J"B`J($EF(&YO('-I9VYA='5R
M97,@87)E(&MN;W=N+"!R971U<FYS(&$@;F]N92UA<G)A>0H@*B`H=&5S="!F
M;W(@='EP92`A/2!A<G)A>2!T;R!D971E8W0@;6ES<VEN9R!S:6=N871U<F4I
M"B`J"B`J($!R971U<FX@;V)J96-T("!A(&YE=R!834Q?4E!#7U)E<W!O;G-E
M(&]B:F5C=`H@*B\*9G5N8W1I;VX@6$U,7U)00U]397)V97)?;65T:&]D4VEG
M;F%T=7)E*"1S97)V97(L("1M*0I["B`@("!G;&]B86P@)%A-3%]24$-?97)R
M+"`D6$U,7U)00U]S='(L("1834Q?4E!#7U-E<G9E<E]D;6%P.PH*("`@("1M
M971H3F%M92`]("1M+3YG971087)A;2@P*3L*("`@("1M971H3F%M92`]("1M
M971H3F%M92T^<V-A;&%R=F%L*"D["B`@("!I9B`H<W1R<&]S*"1M971H3F%M
M92P@)W-Y<W1E;2XG*2`]/3T@,"D@>PH@("`@("`@("1D;6%P(#T@)%A-3%]2
M4$-?4V5R=F5R7V1M87`["B`@("`@("`@)'-Y<T-A;&P@/2`Q.PH@("`@?2!E
M;'-E('L*("`@("`@("`D9&UA<"`]("1S97)V97(M/F1M87`["B`@("`@("`@
M)'-Y<T-A;&P@/2`P.PH@("`@?0H@("`@+R\@('!R:6YT("(\(2TM("1[;65T
M:$YA;65]("TM/EQN(CL*("`@(&EF("AI<W-E="@D9&UA<%LD;65T:$YA;65=
M*2D@>PH@("`@("`@(&EF("@D9&UA<%LD;65T:$YA;65=6R=S:6=N871U<F4G
M72D@>PH@("`@("`@("`@("`D<VEG<R`](&%R<F%Y*"D["B`@("`@("`@("`@
M("1T:&5S:6=S(#T@)&1M87!;)&UE=&A.86UE75LG<VEG;F%T=7)E)UT["B`@
M("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AE<VEG<RD[
M("1I*RLI('L*("`@("`@("`@("`@("`@("1C=7)S:6<@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@)&EN4VEG(#T@)'1H97-I9W-;)&E=.PH@("`@("`@
M("`@("`@("`@9F]R("@D:B`](#`[("1J(#P@<VEZ96]F*"1I;E-I9RD[("1J
M*RLI('L*("`@("`@("`@("`@("`@("`@("`D8W5R<VEG6UT@/2!N97<@6$U,
M7U)00U]686QU92@D:6Y3:6=;)&I=+"`G<W1R:6YG)RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`D<VEG<UM=(#T@;F5W(%A-3%]24$-?
M5F%L=64H)&-U<G-I9RP@)V%R<F%Y)RD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92AN97<@6$U,7U)00U]6
M86QU92@D<VEG<RP@)V%R<F%Y)RDI.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H;F5W(%A-3%]24$-?
M5F%L=64H)W5N9&5F)RP@)W-T<FEN9R<I*3L*("`@("`@("!]"B`@("!](&5L
M<V4@>PH@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-
M3%]24$-?97)R6R=I;G1R;W-P96-T7W5N:VYO=VXG72P*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELG:6YT<F]S<&5C
M=%]U;FMN;W=N)UTI.PH@("`@?0H@("`@<F5T=7)N("1R.PI]"@HO*BH*("H@
M4F5T=7)N<R!H96QP('1E>'0@:68@9&5F:6YE9"!F;W(@=&AE(&UE=&AO9"!P
M87-S960L(&]T:&5R=VES92!R971U<FYS"B`J(&%N(&5M<'1Y('-T<FEN9PH@
M*@H@*B!`<F5T=7)N(&]B:F5C="`@82!N97<@6$U,7U)00U]297-P;VYS92!O
M8FIE8W0*("HO"F9U;F-T:6]N(%A-3%]24$-?4V5R=F5R7VUE=&AO9$AE;'`H
M)'-E<G9E<BP@)&TI"GL*("`@(&=L;V)A;"`D6$U,7U)00U]E<G(L("1834Q?
M4E!#7W-T<BP@)%A-3%]24$-?4V5R=F5R7V1M87`["@H@("`@)&UE=&A.86UE
M(#T@)&TM/F=E=%!A<F%M*#`I.PH@("`@)&UE=&A.86UE(#T@)&UE=&A.86UE
M+3YS8V%L87)V86PH*3L*("`@(&EF("AS=')P;W,H)&UE=&A.86UE+"`G<WES
M=&5M+B<I(#T]/2`P*2!["B`@("`@("`@)&1M87`@/2`D6$U,7U)00U]397)V
M97)?9&UA<#L*("`@("`@("`D<WES0V%L;"`](#$["B`@("!](&5L<V4@>PH@
M("`@("`@("1D;6%P(#T@)'-E<G9E<BT^9&UA<#L*("`@("`@("`D<WES0V%L
M;"`](#`["B`@("!]"@H@("`@:68@*&ES<V5T*"1D;6%P6R1M971H3F%M95TI
M*2!["B`@("`@("`@:68@*"1D;6%P6R1M971H3F%M95U;)V1O8W-T<FEN9R==
M*2!["B`@("`@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N<V4H;F5W
M(%A-3%]24$-?5F%L=64H)&1M87!;)&UE=&A.86UE75LG9&]C<W1R:6YG)UTI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=S=')I;F<G*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*&YE=R!834Q?4E!#
M7U9A;'5E*"<G+"`G<W1R:6YG)RDI.PH@("`@("`@('T*("`@('T@96QS92![
M"B`@("`@("`@)'(@/2!N97<@6$U,7U)00U]297-P;VYS92@P+"`D6$U,7U)0
M0U]E<G);)VEN=')O<W!E8W1?=6YK;F]W;B==+`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)%A-3%]24$-?<W1R6R=I;G1R;W-P96-T
M7W5N:VYO=VXG72D["B`@("!]"B`@("!R971U<FX@)'(["GT*"B\J*@H@*B!`
M<F5T=7)N('9O:60*("HO"F9U;F-T:6]N(%A-3%]24$-?4V5R=F5R7V1E8G5G
M;7-G*"1M*0I["B`@("!G;&]B86P@)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF
M;SL*("`@("1834Q?4E!#7U-E<G9E<E]D96)U9VEN9F\@/2`D6$U,7U)00U]3
M97)V97)?9&5B=6=I;F9O("X@)&T@+B`B7&XB.PI]"@H*+RHJ"B`J($$@<V5R
M=F5R(&9O<B!R96-E:79I;F<@86YD(')E<&QY:6YG('1O(%A-3"!24$,@<F5Q
M=65S=',*("H*("H@/&-O9&4^"B`J("1S97)V97(@/2!N97<@6$U,7U)00U]3
M97)V97(H"B`J("`@("!A<G)A>2@*("H@("`@("`@("`G:7-A;C@G(#T^"B`J
M("`@("`@("`@("`@(&%R<F%Y*`H@*B`@("`@("`@("`@("`@("`@)V9U;F-T
M:6]N)R`]/B`G:7-?."<L"B`J("`@("`@("`@("`@("`@("`G<VEG;F%T=7)E
M)R`]/@H@*B`@("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("H@("`@("`@
M("`@("`@("`@("`@("`@("`@(&%R<F%Y*"=B;V]L96%N)RP@)VEN="<I+`H@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH)V)O;VQE86XG+"`G
M:6YT)RP@)V)O;VQE86XG*2P*("H@("`@("`@("`@("`@("`@("`@("`@("`@
M(&%R<F%Y*"=B;V]L96%N)RP@)W-T<FEN9R<I+`H@*B`@("`@("`@("`@("`@
M("`@("`@("`@("`@87)R87DH)V)O;VQE86XG+"`G<W1R:6YG)RP@)V)O;VQE
M86XG*2P*("H@("`@("`@("`@("`@("`@("`@("`@*2P*("H@("`@("`@("`@
M("`@("`@("=D;V-S=')I;F<G(#T^("=)<R!T:&4@=F%L=64@86X@.#\G"B`J
M("`@("`@("`@("`@("DL"B`J("`@("`I+`H@*B`@("`@,2P*("H@("`@(#`*
M("H@*3L@"B`J(#PO8V]D93X*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I
M8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@161D
M($1U;6)I;&P@/&5D9$!U<V5F=6QI;F,N8V]M/@H@*B!`875T:&]R("`@("!3
M=&EG($)A:VME;B`\<W1I9T!P:'`N;F5T/@H@*B!`875T:&]R("`@("!-87)T
M:6X@2F%N<V5N(#QM:D!P:'`N;F5T/@H@*B!`875T:&]R("`@("!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`J($!C;W!Y<FEG:'0@(#$Y
M.3DM,C`P,2!%9&0@1'5M8FEL;"P@,C`P,2TR,#`U(%1H92!02%`@1W)O=7`*
M("H@0'9E<G-I;VX@("`@4F5L96%S93H@,2XT+C@*("H@0&QI;FL@("`@("`@
M:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+UA-3%]24$,*("HO"F-L87-S
M(%A-3%]24$-?4V5R=F5R"GL*("`@("\J*@H@("`@("H@5&AE(&1I<W!A=&-H
M(&UA<"P@;&ES=&EN9R!T:&4@;65T:&]D<R!T:&ES('-E<G9E<B!P<F]V:61E
M<RX*("`@("`J($!V87(@87)R87D*("`@("`J+PH@("`@=F%R("1D;6%P(#T@
M87)R87DH*3L*"B`@("`O*BH*("`@("`J(%1H92!P<F5S96YT(')E<W!O;G-E
M)W,@96YC;V1I;F<*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B!`<V5E(%A-
M3%]24$-?365S<V%G93HZ9V5T16YC;V1I;F<H*0H@("`@("HO"B`@("!V87(@
M)&5N8V]D:6YG(#T@)R<["@H@("`@+RHJ"B`@("`@*B!$96)U9R!M;V1E("@P
M(#T@;V9F+"`Q(#T@;VXI"B`@("`@*B!`=F%R(&EN=&5G97(*("`@("`J+PH@
M("`@=F%R("1D96)U9R`](#`["@H@("`@+RHJ"B`@("`@*B!4:&4@<F5S<&]N
M<V4G<R!(5%10(&AE861E<G,*("`@("`J($!V87(@<W1R:6YG"B`@("`@*B\*
M("`@('9A<B`D<V5R=F5R7VAE861E<G,@/2`G)SL*"B`@("`O*BH*("`@("`J
M(%1H92!R97-P;VYS92=S(%A-3"!P87EL;V%D"B`@("`@*B!`=F%R('-T<FEN
M9PH@("`@("HO"B`@("!V87(@)'-E<G9E<E]P87EL;V%D(#T@)R<["@H*("`@
M("\J*@H@("`@("H@0V]N<W1R=6-T;W(@9F]R('1H92!834Q?4E!#7U-E<G9E
M<B!C;&%S<PH@("`@("H*("`@("`J($!P87)A;2!A<G)A>2`D9&ES<$UA<"`@
M('1H92!D:7-P871C:"!M87`N($%N(&%S<V]C:6%T:79E(&%R<F%Y"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@97AP;&%I;FEN9R!E86-H(&9U
M;F-T:6]N+B!4:&4@:V5Y<R!O9B!T:&4@;6%I;@H@("`@("H@("`@("`@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y(&%R92!T:&4@<')O8V5D=7)E(&YA;65S
M('5S960@8GD@=&AE"B`@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@
M8VQI96YT<RX@5&AE('9A;'5E(&ES(&%N;W1H97(@87-S;V-I871I=F4@87)R
M87D*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("!T:&%T(&-O;G1A
M:6YS('5P('1O('1H<F5E(&5L96UE;G1S.@H@("`@("H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@*R!4:&4@)V9U;F-T:6]N)R!E;&5M96YT)W,@=F%L
M=64@:7,@=&AE(&YA;64*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@;V8@=&AE(&9U;F-T:6]N(&]R(&UE=&AO9"!T:&%T(&=E=',@8V%L
M;&5D+@H@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!4;R!D
M969I;F4@82!C;&%S<R<@;65T:&]D.B`G8VQA<W,Z.FUE=&AO9"<N"B`@("`@
M*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`K(%1H92`G<VEG;F%T=7)E
M)R!E;&5M96YT("AO<'1I;VYA;"D@:7,@86X*("`@("`J("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87D@9&5S8W)I8FEN9R!T:&4@<F5T=7)N
M('9A;'5E<R!A;F0*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@<&%R86UE=&5R<PH@("`@("H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@*R!4:&4@)V1O8W-T<FEN9R<@96QE;65N="`H;W!T:6]N86PI(&ES(&$*
M("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<W1R:6YG(&1E
M<V-R:6)I;F<@=VAA="!T:&4@;65T:&]D(&1O97,*("`@("`J($!P87)A;2!I
M;G0@)'-E<G9I8V5.;W<@('-H;W5L9"!T:&4@2%144"!R97-P;VYS92!B92!S
M96YT(&YO=S\*("`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`H,2`]
M('EE<RP@,"`](&YO*0H@("`@("H@0'!A<F%M(&EN="`D9&5B=6<@("`@("`@
M<VAO=6QD(&1E8G5G(&]U='!U="!B92!D:7-P;&%Y960_"B`@("`@*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@*#$@/2!Y97,L(#`@/2!N;RD*("`@("`J
M"B`@("`@*B!`<F5T=7)N('9O:60*("`@("`J+PH@("`@9G5N8W1I;VX@6$U,
M7U)00U]397)V97(H)&1I<W!-87`L("1S97)V:6-E3F]W(#T@,2P@)&1E8G5G
M(#T@,"D*("`@('L*("`@("`@("!G;&]B86P@)$A45%!?4D%77U!/4U1?1$%4
M03L*"B`@("`@("`@:68@*"1D96)U9RD@>PH@("`@("`@("`@("`D=&AI<RT^
M9&5B=6<@/2`Q.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1T:&ES
M+3YD96)U9R`](#`["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9&UA<"`]
M("1D:7-P36%P.PH*("`@("`@("!I9B`H)'-E<G9I8V5.;W<I('L*("`@("`@
M("`@("`@)'1H:7,M/G-E<G9I8V4H*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`D=&AI<RT^8W)E871E4V5R=F5R4&%Y;&]A9"@I.PH@("`@("`@
M("`@("`D=&AI<RT^8W)E871E4V5R=F5R2&5A9&5R<R@I.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@<W1R:6YG("!T:&4@9&5B
M=6<@:6YF;W)M871I;VX@:68@9&5B=6<@9&5B=6<@;6]D92!I<R!O;@H@("`@
M("HO"B`@("!F=6YC=&EO;B!S97)I86QI>F5$96)U9R@I"B`@("!["B`@("`@
M("`@9VQO8F%L("1834Q?4E!#7U-E<G9E<E]D96)U9VEN9F\L("1(5%107U)!
M5U]03U-47T1!5$$["@H@("`@("`@(&EF("@D=&AI<RT^9&5B=6<I('L*("`@
M("`@("`@("`@6$U,7U)00U]397)V97)?9&5B=6=M<V<H)W9V=B!03U-4($1!
M5$$@4D5#14E6140@0ED@4T525D52('9V=B<@+B`B7&XB"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("X@)$A45%!?4D%77U!/4U1?1$%4
M00H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N(")<;B(@
M+B`G7EY>($5.1"!03U-4($1!5$$@7EY>)RD["B`@("`@("`@?0H*("`@("`@
M("!I9B`H)%A-3%]24$-?4V5R=F5R7V1E8G5G:6YF;R`A/2`G)RD@>PH@("`@
M("`@("`@("!R971U<FX@(CPA+2T@4$5!4B!834Q?4E!#(%-%4E9%4B!$14)5
M1R!)3D9/.EQN7&XB"B`@("`@("`@("`@("`@("`@("`N('!R96=?<F5P;&%C
M92@G+RTH/STM*2\G+"`G+2`G+"`D6$U,7U)00U]397)V97)?9&5B=6=I;F9O
M*0H@("`@("`@("`@("`@("`@("`@+B`B+2T^7&XB.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@(')E='5R;B`G)SL*("`@("`@("!]"B`@("!]"@H@
M("`@+RHJ"B`@("`@*B!396YD<R!T:&4@<F5S<&]N<V4*("`@("`J"B`@("`@
M*B!4:&4@96YC;V1I;F<@86YD(&-O;G1E;G0M='EP92!A<F4@9&5T97)M:6YE
M9"!B>0H@("`@("H@6$U,7U)00U]-97-S86=E.CIG971%;F-O9&EN9R@I"B`@
M("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@("`@("H@0'5S97,@
M6$U,7U)00U]397)V97(Z.F-R96%T95-E<G9E<E!A>6QO860H*2P*("`@("`J
M("`@("`@(%A-3%]24$-?4V5R=F5R.CIC<F5A=&5397)V97)(96%D97)S*"D*
M("`@("`J+PH@("`@9G5N8W1I;VX@<V5R=FEC92@I"B`@("!["B`@("`@("`@
M:68@*"$D=&AI<RT^<V5R=F5R7W!A>6QO860I('L*("`@("`@("`@("`@)'1H
M:7,M/F-R96%T95-E<G9E<E!A>6QO860H*3L*("`@("`@("!]"B`@("`@("`@
M:68@*"$D=&AI<RT^<V5R=F5R7VAE861E<G,I('L*("`@("`@("`@("`@)'1H
M:7,M/F-R96%T95-E<G9E<DAE861E<G,H*3L*("`@("`@("!]"@H@("`@("`@
M("\J"B`@("`@("`@("H@)'-E<G9E<E]H96%D97)S(&YE961S('1O(')E;6%I
M;B!A('-T<FEN9R!F;W(@8V]M<&%T:6)I;&ET>2!W:71H"B`@("`@("`@("H@
M;VQD('-C<FEP=',@=7-I;F<@=&AI<R!P86-K86=E+"!B=70@4$A0(#0N-"XR
M(&YO(&QO;F=E<B!A;&QO=W,*("`@("`@("`@*B!L:6YE(&)R96%K<R!I;B!H
M96%D97(H*2!C86QL<RX@(%-O+"!W92!S<&QI="!E86-H(&AE861E<B!I;G1O
M"B`@("`@("`@("H@86X@:6YD:79I9'5A;"!C86QL+B`@5&AE(&EN:71I86P@
M<F5P;&%C92!H86YD;&5S('1H92!O9F8@8VAA;F-E"B`@("`@("`@("H@=&AA
M="!S;VUE;VYE(&-O;7!O<V5D(&$@<VEN9VQE(&AE861E<B!W:71H(&UU;'1I
M<&QE(&QI;F5S+"!W:&EC:`H@("`@("`@("`J('1H92!21D-S(&%L;&]W+@H@
M("`@("`@("`J+PH@("`@("`@("1T:&ES+3YS97)V97)?:&5A9&5R<R`]('!R
M96=?<F5P;&%C92@B+UM<<EQN72M;(%QT72LO(BP@)R`G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T<FEM*"1T:&ES
M+3YS97)V97)?:&5A9&5R<RDI.PH@("`@("`@("1H96%D97)S(#T@<')E9U]S
M<&QI="@B+UM<<EQN72LO(BP@)'1H:7,M/G-E<G9E<E]H96%D97)S*3L*("`@
M("`@("!F;W)E86-H("@D:&5A9&5R<R!A<R`D:&5A9&5R*0H@("`@("`@('L*
M("`@("`@("`@("`@:&5A9&5R*"1H96%D97(I.PH@("`@("`@('T*"B`@("`@
M("`@<')I;G0@)'1H:7,M/G-E<G9E<E]P87EL;V%D.PH@("`@?0H*("`@("\J
M*@H@("`@("H@1V5N97)A=&5S('1H92!P87EL;V%D(&%N9"!P=71S(&ET(&EN
M('1H92`D<V5R=F5R7W!A>6QO860@<')O<&5R='D*("`@("`J"B`@("`@*B!`
M<F5T=7)N('9O:60*("`@("`J"B`@("`@*B!`=7-E<R!834Q?4E!#7U-E<G9E
M<CHZ<&%R<V5297%U97-T*"DL(%A-3%]24$-?4V5R=F5R.CHD96YC;V1I;F<L
M"B`@("`@*B`@("`@("!834Q?4E!#7U)E<W!O;G-E.CIS97)I86QI>F4H*2P@
M6$U,7U)00U]397)V97(Z.G-E<FEA;&EZ941E8G5G*"D*("`@("`J+PH@("`@
M9G5N8W1I;VX@8W)E871E4V5R=F5R4&%Y;&]A9"@I"B`@("!["B`@("`@("`@
M)'(@/2`D=&AI<RT^<&%R<V5297%U97-T*"D["B`@("`@("`@)'1H:7,M/G-E
M<G9E<E]P87EL;V%D(#T@)SP_>&UL('9E<G-I;VX](C$N,"(@96YC;V1I;F<]
M(B<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^96YC
M;V1I;F<@+B`G(C\^)R`N(")<;B(*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+B`D=&AI<RT^<V5R:6%L:7IE1&5B=6<H*0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("1R+3YS97)I86QI>F4H*3L*("`@('T*"B`@
M("`O*BH*("`@("`J($1E=&5R;6EN97,@=&AE($A45%`@:&5A9&5R<R!A;F0@
M<'5T<R!T:&5M(&EN('1H92`D<V5R=F5R7VAE861E<G,*("`@("`J('!R;W!E
M<G1Y"B`@("`@*@H@("`@("H@0')E='5R;B!B;V]L96%N("!44E5%(&EF(&]K
M87DL($9!3%-%(&EF("1S97)V97)?<&%Y;&]A9"!I<VXG="!S970N"B`@("`@
M*@H@("`@("H@0'5S97,@6$U,7U)00U]397)V97(Z.F-R96%T95-E<G9E<E!A
M>6QO860H*2P*("`@("`J("`@("`@(%A-3%]24$-?4V5R=F5R.CHD<V5R=F5R
M7VAE861E<G,*("`@("`J+PH@("`@9G5N8W1I;VX@8W)E871E4V5R=F5R2&5A
M9&5R<R@I"B`@("!["B`@("`@("`@:68@*"$D=&AI<RT^<V5R=F5R7W!A>6QO
M860I('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*("`@
M("`@("`D=&AI<RT^<V5R=F5R7VAE861E<G,@/2`G0V]N=&5N="U,96YG=&@Z
M("<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B!S=')L96XH)'1H
M:7,M/G-E<G9E<E]P87EL;V%D*2`N(")<<EQN(@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`N("=#;VYT96YT+51Y<&4Z('1E>'0O>&UL.R<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+B`G(&-H87)S970])R`N("1T
M:&ES+3YE;F-O9&EN9SL*("`@("`@("!R971U<FX@=')U93L*("`@('T*"B`@
M("`O*BH*("`@("`J($!R971U<FX@87)R87D*("`@("`J+PH@("`@9G5N8W1I
M;VX@=F5R:69Y4VEG;F%T=7)E*"1I;BP@)'-I9RD*("`@('L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'-I9RD[("1I*RLI('L*("`@("`@
M("`@("`@+R\@8VAE8VL@96%C:"!P;W-S:6)L92!S:6=N871U<F4@:6X@='5R
M;@H@("`@("`@("`@("`D8W5R<VEG(#T@)'-I9ULD:5T["B`@("`@("`@("`@
M(&EF("AS:7IE;V8H)&-U<G-I9RD@/3T@)&EN+3YG971.=6U087)A;7,H*2`K
M(#$I('L*("`@("`@("`@("`@("`@("1I='-/2R`](#$["B`@("`@("`@("`@
M("`@("!F;W(@*"1N(#T@,#L@)&X@/"`D:6XM/F=E=$YU;5!A<F%M<R@I.R`D
M;BLK*2!["B`@("`@("`@("`@("`@("`@("`@)'`@/2`D:6XM/F=E=%!A<F%M
M*"1N*3L*("`@("`@("`@("`@("`@("`@("`O+R!P<FEN="`B/"$M+2`D<"`M
M+3Y<;B(["B`@("`@("`@("`@("`@("`@("`@:68@*"1P+3YK:6YD3V8H*2`]
M/2`G<V-A;&%R)RD@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<'0@/2`D
M<"T^<V-A;&%R='EP*"D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)'!T(#T@)'`M/FMI;F1/9B@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`O+R`D
M;BLQ(&%S(&9I<G-T('1Y<&4@;V8@<VEG(&ES(')E='5R;B!T>7!E"B`@("`@
M("`@("`@("`@("`@("`@:68@*"1P="`A/2`D8W5R<VEG6R1N*S%=*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1I='-/2R`](#`["B`@("`@("`@("`@
M("`@("`@("`@("`@("1P;F\@/2`D;BLQ.PH@("`@("`@("`@("`@("`@("`@
M("`@("`D=V%N=&5D(#T@)&-U<G-I9ULD;BLQ73L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&=O="`]("1P=#L*("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@:68@*"1I='-/2RD@>PH@("`@("`@("`@("`@
M("`@("`@(')E='5R;B!A<G)A>2@Q*3L*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H:7-S970H)'=A;G1E
M9"DI('L*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*#`L(")786YT960@)'MW
M86YT961]+"!G;W0@)'MG;W1](&%T('!A<F%M("1[<&YO?2(I.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1A;&QO=V5D(#T@87)R87DH*3L*("`@
M("`@("`@("`@9F]R96%C:"`H)'-I9R!A<R`D=F%L*2!["B`@("`@("`@("`@
M("`@("!E;F0H)'9A;"D["B`@("`@("`@("`@("`@("`D86QL;W=E9%M=(#T@
M:V5Y*"1V86PI.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1A;&QO=V5D
M(#T@87)R87E?=6YI<75E*"1A;&QO=V5D*3L*("`@("`@("`@("`@)&QA<W0@
M/2!C;W5N="@D86QL;W=E9"D@+2`Q.PH@("`@("`@("`@("!I9B`H)&QA<W0@
M/B`P*2!["B`@("`@("`@("`@("`@("`D86QL;W=E9%LD;&%S=%T@/2`G;W(@
M)R`N("1A;&QO=V5D6R1L87-T73L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!R971U<FX@87)R87DH,"P*("`@("`@("`@("`@("`@("`@("`@("`@("=3
M:6=N871U<F4@<&5R;6ET<R`G("X@:6UP;&]D92@G+"`G+"`D86QL;W=E9"D*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`N("<@<&%R86UE=&5R
M<R!B=70@=&AE(')E<75E<W0@:&%D("<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`N("1I;BT^9V5T3G5M4&%R86US*"DI.PH@("`@("`@('T*
M("`@('T*"B`@("`O*BH*("`@("`J($!R971U<FX@;V)J96-T("!A(&YE=R!8
M34Q?4E!#7U)E<W!O;G-E(&]B:F5C=`H@("`@("H*("`@("`J($!U<V5S(%A-
M3%]24$-?365S<V%G93HZ9V5T16YC;V1I;F<H*2P@6$U,7U)00U]397)V97(Z
M.B1E;F-O9&EN9PH@("`@("HO"B`@("!F=6YC=&EO;B!P87)S95)E<75E<W0H
M)&1A=&$@/2`G)RD*("`@('L*("`@("`@("!G;&]B86P@)%A-3%]24$-?>&@L
M("1(5%107U)!5U]03U-47T1!5$$L"B`@("`@("`@("`@("`@("`D6$U,7U)0
M0U]E<G(L("1834Q?4E!#7W-T<BP@)%A-3%]24$-?97)R>&UL+`H@("`@("`@
M("`@("`@("`@)%A-3%]24$-?9&5F96YC;V1I;F<L("1834Q?4E!#7U-E<G9E
M<E]D;6%P.PH*("`@("`@("!I9B`H)&1A=&$@/3T@)R<I('L*("`@("`@("`@
M("`@)&1A=&$@/2`D2%144%]205=?4$]35%]$051!.PH@("`@("`@('T*"B`@
M("`@("`@)'1H:7,M/F5N8V]D:6YG(#T@6$U,7U)00U]-97-S86=E.CIG971%
M;F-O9&EN9R@D9&%T82D["B`@("`@("`@)'!A<G-E<E]R97-O=7)C92`]('AM
M;%]P87)S97)?8W)E871E*"1T:&ES+3YE;F-O9&EN9RD["B`@("`@("`@)'!A
M<G-E<B`]("AI;G0I("1P87)S97)?<F5S;W5R8V4["@H@("`@("`@("1834Q?
M4E!#7WAH6R1P87)S97)=(#T@87)R87DH*3L*("`@("`@("`D6$U,7U)00U]X
M:%LD<&%R<V5R75LG8VTG72`@("`@/2`P.PH@("`@("`@("1834Q?4E!#7WAH
M6R1P87)S97)=6R=I<V8G72`@("`](#`["B`@("`@("`@)%A-3%]24$-?>&A;
M)'!A<G-E<EU;)W!A<F%M<R==(#T@87)R87DH*3L*("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG;65T:&]D)UT@/2`G)SL*("`@("`@("`D6$U,7U)0
M0U]X:%LD<&%R<V5R75LG<W1A8VLG72`](&%R<F%Y*"D["0H@("`@("`@("18
M34Q?4E!#7WAH6R1P87)S97)=6R=V86QU97-T86-K)UT@/2!A<G)A>2@I.PD*
M"B`@("`@("`@)'!L:7-T(#T@)R<["@H@("`@("`@("\O(&1E8V]M<&]S92!I
M;F-O;6EN9R!834P@:6YT;R!R97%U97-T('-T<G5C='5R90H*("`@("`@("!X
M;6Q?<&%R<V5R7W-E=%]O<'1I;VXH)'!A<G-E<E]R97-O=7)C92P@6$U,7T]0
M5$E/3E]#05-%7T9/3$1)3D<L('1R=64I.PH@("`@("`@('AM;%]S971?96QE
M;65N=%]H86YD;&5R*"1P87)S97)?<F5S;W5R8V4L("=834Q?4E!#7W-E)RP@
M)UA-3%]24$-?964G*3L*("`@("`@("!X;6Q?<V5T7V-H87)A8W1E<E]D871A
M7VAA;F1L97(H)'!A<G-E<E]R97-O=7)C92P@)UA-3%]24$-?8V0G*3L*("`@
M("`@("!I9B`H(7AM;%]P87)S92@D<&%R<V5R7W)E<V]U<F-E+"`D9&%T82P@
M,2DI('L*("`@("`@("`@("`@+R\@<F5T=7)N(%A-3"!E<G)O<B!A<R!A(&9A
M=6QT0V]D90H@("`@("`@("`@("`D<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E
M*#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%A-
M3%]24$-?97)R>&UL*WAM;%]G971?97)R;W)?8V]D92@D<&%R<V5R7W)E<V]U
M<F-E*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!S
M<')I;G1F*"=834P@97)R;W(Z("5S(&%T(&QI;F4@)60G+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@>&UL7V5R<F]R
M7W-T<FEN9RAX;6Q?9V5T7V5R<F]R7V-O9&4H)'!A<G-E<E]R97-O=7)C92DI
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@>&UL7V=E=%]C=7)R96YT7VQI;F5?;G5M8F5R*"1P87)S97)?<F5S;W5R
M8V4I*2D["B`@("`@("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R<V5R7W)E
M<V]U<F-E*3L*("`@("`@("!](&5L<V5I9B`H)%A-3%]24$-?>&A;)'!A<G-E
M<EU;)VES9B==/C$I('L*("`@("`@("`@("`@)'(@/2!N97<@6$U,7U)00U]2
M97-P;VYS92@P+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1834Q?4E!#7V5R<ELG:6YV86QI9%]R97%U97-T)UTL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)%A-3%]24$-?<W1R6R=I
M;G9A;&ED7W)E<75E<W0G70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)SH@)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("X@)%A-3%]24$-?>&A;)'!A<G-E<EU;)VES9E]R96%S;VXG
M72D["B`@("`@("`@("`@('AM;%]P87)S97)?9G)E92@D<&%R<V5R7W)E<V]U
M<F-E*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!X;6Q?<&%R<V5R
M7V9R964H)'!A<G-E<E]R97-O=7)C92D["B`@("`@("`@("`@("1M(#T@;F5W
M(%A-3%]24$-?365S<V%G92@D6$U,7U)00U]X:%LD<&%R<V5R75LG;65T:&]D
M)UTI.PH@("`@("`@("`@("`O+R!N;W<@861D('!A<F%M971E<G,@:6X*("`@
M("`@("`@("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1834Q?4E!#7WAH
M6R1P87)S97)=6R=P87)A;7,G72D[("1I*RLI('L*("`@("`@("`@("`@("`@
M("\O('!R:6YT("<\(2TM("<@+B`D6$U,7U)00U]X:%LD<&%R<V5R75LG<&%R
M86US)UU;)&E=+B`B+2T^7&XB.PH@("`@("`@("`@("`@("`@)'!L:7-T("X]
M("(D:2`M("(@+B!V87)?97AP;W)T*"1834Q?4E!#7WAH6R1P87)S97)=6R=P
M87)A;7,G75LD:5TL('1R=64I("X@(B!<;B(["B`@("`@("`@("`@("`@("`D
M;2T^861D4&%R86TH)%A-3%]24$-?>&A;)'!A<G-E<EU;)W!A<F%M<R==6R1I
M72D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D=&AI<RT^9&5B
M=6<I('L*("`@("`@("`@("`@("`@(%A-3%]24$-?4V5R=F5R7V1E8G5G;7-G
M*"1P;&ES="D["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(&YO=R!T
M;R!D96%L('=I=&@@=&AE(&UE=&AO9`H@("`@("`@("`@("`D;65T:$YA;64@
M/2`D6$U,7U)00U]X:%LD<&%R<V5R75LG;65T:&]D)UT["B`@("`@("`@("`@
M(&EF("AS=')P;W,H)&UE=&A.86UE+"`G<WES=&5M+B<I(#T]/2`P*2!["B`@
M("`@("`@("`@("`@("`D9&UA<"`]("1834Q?4E!#7U-E<G9E<E]D;6%P.PH@
M("`@("`@("`@("`@("`@)'-Y<T-A;&P@/2`Q.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@)&1M87`@/2`D=&AI<RT^9&UA<#L*("`@
M("`@("`@("`@("`@("1S>7-#86QL(#T@,#L*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@:68@*&ES<V5T*"1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N
M)UTI"B`@("`@("`@("`@("`@("`F)B!I<U]S=')I;F<H)&1M87!;)&UE=&A.
M86UE75LG9G5N8W1I;VXG72D*("`@("`@("`@("`@("`@("8F('-T<G!O<R@D
M9&UA<%LD;65T:$YA;65=6R=F=6YC=&EO;B==+"`G.CHG*2`A/3T@9F%L<V4I
M"B`@("`@("`@("`@('L*("`@("`@("`@("`@("`@("1D;6%P6R1M971H3F%M
M95U;)V9U;F-T:6]N)UT@/0H@("`@("`@("`@("`@("`@("`@("`@("!E>'!L
M;V1E*"<Z.B<L("1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N)UTI.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!I9B`H:7-S970H)&1M87!;)&UE=&A.
M86UE75LG9G5N8W1I;VXG72D*("`@("`@("`@("`@("`@("8F(&ES7V-A;&QA
M8FQE*"1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N)UTI*0H@("`@("`@("`@
M("!["B`@("`@("`@("`@("`@("`O+R!D:7-P871C:"!I9B!E>&ES=',*("`@
M("`@("`@("`@("`@(&EF("AI<W-E="@D9&UA<%LD;65T:$YA;65=6R=S:6=N
M871U<F4G72DI('L*("`@("`@("`@("`@("`@("`@("`D<W(@/2`D=&AI<RT^
M=F5R:69Y4VEG;F%T=7)E*"1M+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)&1M87!;)&UE=&A.86UE75LG<VEG
M;F%T=7)E)UT@*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&EF("@A:7-S970H)&1M87!;)&UE=&A.86UE75LG<VEG;F%T=7)E)UTI('Q\
M("1S<ELP72D@>PH@("`@("`@("`@("`@("`@("`@("\O(&EF(&YO('-I9VYA
M='5R92!O<B!C;W)R96-T('-I9VYA='5R90H@("`@("`@("`@("`@("`@("`@
M(&EF("@D<WES0V%L;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<B`]
M(&-A;&Q?=7-E<E]F=6YC*"1D;6%P6R1M971H3F%M95U;)V9U;F-T:6]N)UTL
M("1T:&ES+"`D;2D["B`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@)'(@/2!C86QL7W5S97)?9G5N8R@D9&UA
M<%LD;65T:$YA;65=6R=F=6YC=&EO;B==+"`D;2D["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&EF("@A:7-?82@D<BP@)UA-
M3%]24$-?4F5S<&]N<V4G*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<B`](&YE=R!834Q?4E!#7U)E<W!O;G-E*#`L("1834Q?4E!#7V5R<ELG;F]T
M7W)E<W!O;G-E7V]B:F5C="==+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1834Q?4E!#7W-T<ELG;F]T7W)E
M<W!O;G-E7V]B:F5C="==*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1R(#T@
M;F5W(%A-3%]24$-?4F5S<&]N<V4H,"P@)%A-3%]24$-?97)R6R=I;F-O<G)E
M8W1?<&%R86US)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D6$U,7U)00U]S=');)VEN8V]R<F5C=%]P87)A;7,G
M70H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+B`G.B`G("X@)'-R6S%=*3L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("\O(&5L<V4@<')E<&%R
M92!E<G)O<B!R97-P;VYS90H@("`@("`@("`@("`@("`@)'(@/2!N97<@6$U,
M7U)00U]297-P;VYS92@P+"`D6$U,7U)00U]E<G);)W5N:VYO=VY?;65T:&]D
M)UTL"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1834Q?4E!#7W-T<ELG=6YK;F]W;E]M971H;V0G72D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("`@("`@<F5T=7)N("1R.PH@("`@?0H*("`@("\J
M*@H@("`@("H@16-H;W,@8F%C:R!T:&4@:6YP=70@<&%C:V5T(&%S(&$@<W1R
M:6YG('9A;'5E"B`@("`@*@H@("`@("H@0')E='5R;B!V;VED"B`@("`@*@H@
M("`@("H@57-E9G5L(&9O<B!D96)U9V=I;F<N"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&5C:&]);G!U="@I"B`@("!["B`@("`@("`@9VQO8F%L("1(5%107U)!
M5U]03U-47T1!5$$["@H@("`@("`@("1R(#T@;F5W(%A-3%]24$-?4F5S<&]N
M<V4H,"D["B`@("`@("`@)'(M/GAV(#T@;F5W(%A-3%]24$-?5F%L=64H(B=!
M:&$@<V%I9"!).B`G(B`N("1(5%107U)!5U]03U-47T1!5$$L("=S=')I;F<G
M*3L*("`@("`@("!P<FEN="`D<BT^<V5R:6%L:7IE*"D["B`@("!]"GT*"B\J
M"B`J($QO8V%L('9A<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S
M:6,M;V9F<V5T.B`T"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI
M;`H@*B!%;F0Z"B`J+PH*/SX*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+UA-3"]24$,O1'5M<"YP:'``````````````````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(P-S0@,3`U,34T,S0Q,S,@,#(Q
M,38W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"@HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!S;V9T=&%B<W1O<#TT.B`J+PH*+RHJ"B`J($9U;F-T:6]N(&%N
M9"!C;&%S<R!T;R!D=6UP(%A-3%]24$-?5F%L=64@;V)J96-T<R!I;B!A(&YI
M8V4@=V%Y"B`J"B`J(%-H;W5L9"!B92!H96QP9G5L(&%S(&$@;F]R;6%L('9A
M<E]D=6UP*"XN*2!D:7-P;&%Y<R!A;&P@:6YT97)N86QS('=H:6-H"B`J(&1O
M97-N)W0@<F5A;&QY(&=I=F4@>6]U(&%N(&]V97)V:65W(&1U92!T;R!T;V\@
M;75C:"!I;F9O<FUA=&EO;BX*("H*("H@0&-A=&5G;W)Y("`@5V5B(%-E<G9I
M8V5S"B`J($!P86-K86=E("`@(%A-3%]24$,*("H@0&%U=&AO<B`@("`@0VAR
M:7-T:6%N(%=E:7-K92`\8W=E:7-K94!P:'`N;F5T/@H@*B!`=F5R<VEO;B`@
M("!#5E,Z("1)9#H@1'5M<"YP:'`L=B`Q+C<@,C`P-2\P,2\R-"`P,SHT-SHU
M-2!D86YI96QC($5X<"`D"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]834Q?4E!#"B`J+PH*"B\J*@H@*B!0=6QL(&EN('1H
M92!834Q?4E!#(&-L87-S"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]24$,N<&AP
M)SL*"@HO*BH*("H@1V5N97)A=&5S('1H92!D=6UP(&]F('1H92!834Q?4E!#
M7U9A;'5E(&%N9"!E8VAO97,@:70*("H*("H@0'!A<F%M(&]B:F5C="`D=F%L
M=64@('1H92!834Q?4E!#7U9A;'5E(&]B:F5C="!T;R!D=6UP"B`J"B`J($!R
M971U<FX@=F]I9`H@*B\*9G5N8W1I;VX@6$U,7U)00U]$=6UP*"1V86QU92D*
M>PH@("`@)&1U;7!E<B`](&YE=R!834Q?4E!#7T1U;7`H*3L*("`@(&5C:&\@
M)&1U;7!E<BT^9V5N97)A=&5$=6UP*"1V86QU92D["GT*"@HO*BH*("H@0VQA
M<W,@=VAI8V@@9V5N97)A=&5S(&$@9'5M<"!O9B!A(%A-3%]24$-?5F%L=64@
M;V)J96-T"B`J"B`J($!C871E9V]R>2`@(%=E8B!397)V:6-E<PH@*B!`<&%C
M:V%G92`@("!834Q?4E!#"B`J($!A=71H;W(@("`@($-H<FES=&EA;B!796ES
M:V4@/&-W96ES:V5`<&AP+FYE=#X*("H@0'9E<G-I;VX@("`@4F5L96%S93H@
M,2XT+C@*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+UA-3%]24$,*("HO"F-L87-S(%A-3%]24$-?1'5M<`I["B`@("`O*BH*
M("`@("`J(%1H92!I;F1E;G1A=&EO;B!A<G)A>2!C86-H90H@("`@("H@0'9A
M<B!A<G)A>0H@("`@("HO"B`@("!V87(@)&%R26YD96YT("`@("`@/2!A<G)A
M>2@I.PH*("`@("\J*@H@("`@("H@5&AE('-P86-E<R!U<V5D(&9O<B!I;F1E
M;G1I;F<@=&AE(%A-3`H@("`@("H@0'9A<B!S=')I;F<*("`@("`J+PH@("`@
M=F%R("1S=')"87-E26YD96YT(#T@)R`@("`G.PH*("`@("\J*@H@("`@("H@
M4F5T=7)N<R!T:&4@9'5M<"!I;B!834P@9F]R;6%T('=I=&AO=70@<')I;G1I
M;F<@:70@;W5T"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C="`D=F%L=64@
M("!T:&4@6$U,7U)00U]686QU92!O8FIE8W0@=&\@9'5M<`H@("`@("H@0'!A
M<F%M(&EN="`@("`D;DQE=F5L("!T:&4@;&5V96P@;V8@:6YD96YT871I;VX*
M("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@=&AE(&1U;7`*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5N97)A=&5$=6UP*"1V86QU92P@)&Y,979E;"`]
M(#`I"B`@("!["B`@("`@("`@:68@*"%I<U]O8FIE8W0H)'9A;'5E*2`F)B!G
M971?8VQA<W,H)'9A;'5E*2`A/2`G>&UL7W)P8U]V86QU92<I('L*("`@("`@
M("`@("`@<F5Q=6ER95]O;F-E("=014%2+G!H<"<["B`@("`@("`@("`@(%!%
M05(Z.G)A:7-E17)R;W(H)U1R:65D('1O(&1U;7`@;F]N+5A-3%]24$-?5F%L
M=64@=F%R:6%B;&4G("X@(EQR7&XB+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(#`L(%!%05)?15)23U)?4%))3E0I.PH@("`@("`@("`@("!I9B`H
M:7-?;V)J96-T*"1V86QU92DI('L*("`@("`@("`@("`@("`@("1S=')4>7!E
M(#T@9V5T7V-L87-S*"1V86QU92D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D<W1R5'EP92`](&=E='1Y<&4H)'9A;'5E*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)'1H:7,M/F=E=$EN9&5N
M="@D;DQE=F5L*2`N("=.3U0@02!834Q?4E!#7U9A;'5E.B`G"B`@("`@("`@
M("`@("`@("`@("`N("1S=')4>7!E("X@(EQR7&XB.PH@("`@("`@('T*"B`@
M("`@("`@<W=I=&-H("@D=F%L=64M/FMI;F1/9B@I*2!["B`@("`@("`@8V%S
M92`G<W1R=6-T)SH*("`@("`@("`@("`@)')E="`]("1T:&ES+3YG96Y3=')U
M8W0H)'9A;'5E+"`D;DQE=F5L*3L*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@8V%S92`G87)R87DG.@H@("`@("`@("`@("`D<F5T(#T@)'1H:7,M/F=E
M;D%R<F%Y*"1V86QU92P@)&Y,979E;"D["B`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@(&-A<V4@)W-C86QA<B<Z"B`@("`@("`@("`@("1R970@/2`D=&AI
M<RT^9V5N4V-A;&%R*"1V86QU92T^<V-A;&%R=F%L*"DL("1N3&5V96PI.PH@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("!D969A=6QT.@H@("`@("`@("`@
M("!R97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*("`@("`@("`@("`@4$5!4CHZ
M<F%I<V5%<G)O<B@G26QL96=A;"!T>7!E("(G("X@)'9A;'5E+3YK:6YD3V8H
M*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("X@)R(@:6X@6$U,7U)0
M0U]686QU92<@+B`B7')<;B(L(#`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@4$5!4E]%4E)/4E]04DE.5"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@)')E=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE
M('-C86QA<B!V86QU92!D=6UP"B`@("`@*@H@("`@("H@0'!A<F%M(&]B:F5C
M="`D=F%L=64@("!T:&4@<V-A;&%R(%A-3%]24$-?5F%L=64@;V)J96-T('1O
M(&1U;7`*("`@("`J($!P87)A;2!I;G0@("`@)&Y,979E;"`@=&AE(&QE=F5L
M(&]F(&EN9&5N=&%T:6]N"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@
M($1U;7!E9"!V97)S:6]N(&]F('1H92!S8V%L87(@=F%L=64*("`@("`J+PH@
M("`@9G5N8W1I;VX@9V5N4V-A;&%R*"1V86QU92P@)&Y,979E;"D*("`@('L*
M("`@("`@("!I9B`H9V5T='EP92@D=F%L=64I(#T]("=O8FIE8W0G*2!["B`@
M("`@("`@("`@("1S=')#;&%S<R`]("<@)R`N(&=E=%]C;&%S<R@D=F%L=64I
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1S=')#;&%S<R`]("<G
M.PH@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M/F=E=$EN9&5N="@D
M;DQE=F5L*2`N(&=E='1Y<&4H)'9A;'5E*2`N("1S=')#;&%S<PH@("`@("`@
M("`@("`@("`N("<@)R`N("1V86QU92`N(")<<EQN(CL*("`@('T*"B`@("`O
M*BH*("`@("`J(%)E='5R;G,@=&AE(&1U;7`@;V8@82!S=')U8W0*("`@("`J
M"B`@("`@*B!`<&%R86T@;V)J96-T("1V86QU92`@('1H92!S=')U8W0@6$U,
M7U)00U]686QU92!O8FIE8W0@=&\@9'5M<`H@("`@("H@0'!A<F%M(&EN="`@
M("`D;DQE=F5L("!T:&4@;&5V96P@;V8@:6YD96YT871I;VX*("`@("`J"B`@
M("`@*B!`<F5T=7)N('-T<FEN9R`@1'5M<&5D('9E<G-I;VX@;V8@=&AE('-C
M86QA<B!V86QU90H@("`@("HO"B`@("!F=6YC=&EO;B!G96Y3=')U8W0H)'9A
M;'5E+"`D;DQE=F5L*0H@("`@>PH@("`@("`@("1V86QU92T^<W1R=6-T<F5S
M970H*3L*("`@("`@("`D<W1R3W5T<'5T(#T@)'1H:7,M/F=E=$EN9&5N="@D
M;DQE=F5L*2`N("=S=')U8W0G("X@(EQR7&XB.PH@("`@("`@('=H:6QE("AL
M:7-T*"1K97DL("1K97EV86PI(#T@)'9A;'5E+3YS=')U8W1E86-H*"DI('L*
M("`@("`@("`@("`@)'-T<D]U='!U="`N/2`D=&AI<RT^9V5T26YD96YT*"1N
M3&5V96P@*R`Q*2`N("1K97D@+B`B7')<;B(["B`@("`@("`@("`@("1S=')/
M=71P=70@+CT@)'1H:7,M/F=E;F5R871E1'5M<"@D:V5Y=F%L+"`D;DQE=F5L
M("L@,BD["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D<W1R3W5T<'5T.PH@
M("`@?0H*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9'5M<"!O9B!A;B!A
M<G)A>0H@("`@("H*("`@("`J($!P87)A;2!O8FIE8W0@)'9A;'5E("`@=&AE
M(&%R<F%Y(%A-3%]24$-?5F%L=64@;V)J96-T('1O(&1U;7`*("`@("`J($!P
M87)A;2!I;G0@("`@)&Y,979E;"`@=&AE(&QE=F5L(&]F(&EN9&5N=&%T:6]N
M"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@($1U;7!E9"!V97)S:6]N
M(&]F('1H92!S8V%L87(@=F%L=64*("`@("`J+PH@("`@9G5N8W1I;VX@9V5N
M07)R87DH)'9A;'5E+"`D;DQE=F5L*0H@("`@>PH@("`@("`@("1N4VEZ92`@
M("`@/2`D=F%L=64M/F%R<F%Y<VEZ92@I.PH@("`@("`@("1S=')/=71P=70@
M/2`D=&AI<RT^9V5T26YD96YT*"1N3&5V96PI("X@)V%R<F%Y)R`N(")<<EQN
M(CL*("`@("`@("!F;W(H)&Y!(#T@,#L@)&Y!(#P@)&Y3:7IE.R`D;D$K*RD@
M>PH@("`@("`@("`@("`D<W1R3W5T<'5T("X]("1T:&ES+3YG971);F1E;G0H
M)&Y,979E;"`K(#$I("X@)&Y!("X@(EQR7&XB.PH@("`@("`@("`@("`D<W1R
M3W5T<'5T("X]("1T:&ES+3YG96YE<F%T941U;7`H)'9A;'5E+3YA<G)A>6UE
M;2@D;D$I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&Y,979E;"`K(#(I.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@)'-T<D]U='!U=#L*("`@('T*"B`@("`O*BH*("`@("`J(%)E='5R;G,@
M=&AE(&EN9&5N="!F;W(@82!S<&5C:69I8R!L979E;"!A;F0@8V%C:&5S(&ET
M(&9O<B!F87-T97(@=7-E"B`@("`@*@H@("`@("H@0'!A<F%M(&EN="`D;DQE
M=F5L("!T:&4@;&5V96P*("`@("`J"B`@("`@*B!`<F5T=7)N('-T<FEN9R`@
M=&AE(&EN9&5N=&5D('-T<FEN9PH@("`@("HO"B`@("!F=6YC=&EO;B!G971)
M;F1E;G0H)&Y,979E;"D*("`@('L*("`@("`@("!I9B`H(6ES<V5T*"1T:&ES
M+3YA<DEN9&5N=%LD;DQE=F5L72DI('L*("`@("`@("`@("`@)'1H:7,M/F%R
M26YD96YT6R1N3&5V96Q=(#T@<W1R7W)E<&5A="@D=&AI<RT^<W1R0F%S94EN
M9&5N="P@)&Y,979E;"D["B`@("`@("`@?0H@("`@("`@(')E='5R;B`D=&AI
M<RT^87));F1E;G1;)&Y,979E;%T["B`@("!]"GT*"B\J"B`J($QO8V%L('9A
M<FEA8FQE<SH*("H@=&%B+7=I9'1H.B`T"B`J(&,M8F%S:6,M;V9F<V5T.B`T
M"B`J(&,M:&%N9VEN9RUC;VUM96YT+65N9&5R+7`Z(&YI;`H@*B!%;F0Z"B`J
M+PH*/SX*````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4$5!
M4@``````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S,@,#(P,#0R`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&%T82]-86EL7TUI;64`````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,R`P,C$Q-#0`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TQO9P``````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,S(#`R,#`S-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1A
M=&$O4V5R=FEC97-?5V5A=&AE<@``````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S,@,#(R-34U`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&%T82]834Q?4V5R:6%L:7IE<@``````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,R`P
M,C(Q-#0`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+T-A8VAE````
M````````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,3,S(#`R,#,Q-@`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1A=&$O0V%C:&4O0V]N=&%I;F5R````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S,@,#(R,C0P`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]#86-H92]#;VYT86EN97(O;61B
M7V-A8VAE7W-C:&5M82YX;6P`````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C4W-2`Q,#4Q-30S
M-#$S,R`P,C8R-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]X;6P@=F5R<VEO;CTB,2XP(B!E;F-O9&EN9STB25-/+3@X
M-3DM,2(@/SX-"CQD871A8F%S93X-"@T*(#QN86UE/F1B;F%M93PO;F%M93X-
M"B`\8W)E871E/C$\+V-R96%T93X-"B`\9&5S8W)I<'1I;VX^(#PO9&5S8W)I
M<'1I;VX^#0H-"B`\=&%B;&4^#0H@(#QN86UE/F-A8VAE/"]N86UE/@T*("`\
M9&5S8W)I<'1I;VX^(#PO9&5S8W)I<'1I;VX^#0H-"B`@/&1E8VQA<F%T:6]N
M/@T*#0H@("`\9FEE;&0^#0H@("`@("`\;F%M93Y)1#PO;F%M93X-"B`@("`@
M(#QT>7!E/G1E>'0\+W1Y<&4^#0H@("`@("`\;&5N9W1H/C,R/"]L96YG=&@^
M#0H@("`@("`\9&5F875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ
M/"]N;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@("`@
M/&YA;64^8V%C:&5G<F]U<#PO;F%M93X-"B`@("`@(#QT>7!E/G1E>'0\+W1Y
M<&4^#0H@("`@("`\;&5N9W1H/C$R-SPO;&5N9W1H/@T*("`@("`@/&1E9F%U
M;'0^/"]D969A=6QT/@T*("`@("`@/&YO=&YU;&P^,3PO;F]T;G5L;#X-"B`@
M(#PO9FEE;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE/F-A8VAE9&%T
M83PO;F%M93X-"B`@("`@(#QT>7!E/F-L;V(\+W1Y<&4^#0H@("`@("`\9&5F
M875L=#X\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N;W1N=6QL/@T*
M("`@/"]F:65L9#X-"@T*("`@/&9I96QD/@T*("`@("`@/&YA;64^=7-E<F1A
M=&$\+VYA;64^#0H@("`@("`\='EP93YT97AT/"]T>7!E/@T*("`@("`@/&QE
M;F=T:#XR-34\+VQE;F=T:#X-"B`@("`@(#QD969A=6QT/CPO9&5F875L=#X-
M"B`@(#PO9FEE;&0^#0H-"B`@(#QF:65L9#X-"B`@("`@(#QN86UE/F5X<&ER
M97,\+VYA;64^#0H@("`@("`\='EP93YI;G1E9V5R/"]T>7!E/@T*("`@("`@
M/&1E9F%U;'0^,#PO9&5F875L=#X-"B`@("`@(#QN;W1N=6QL/C$\+VYO=&YU
M;&P^#0H@("`\+V9I96QD/@T*#0H@("`\9FEE;&0^#0H@("`@("`\;F%M93YC
M:&%N9V5D/"]N86UE/@T*("`@("`@/'1Y<&4^:6YT96=E<CPO='EP93X-"B`@
M("`@(#QD969A=6QT/C`\+V1E9F%U;'0^#0H@("`@("`\;F]T;G5L;#XQ/"]N
M;W1N=6QL/@T*("`@/"]F:65L9#X-"@T*#0H@("`\:6YD97@^#0H@("`@/&YA
M;64^:61?:6YD97@\+VYA;64^#0H@("`@/'5N:7%U93XQ/"]U;FEQ=64^#0H@
M("`@/&9I96QD/B`\;F%M93YI9#PO;F%M93X@/"]F:65L9#X-"B`@("`\9FEE
M;&0^(#QN86UE/F-A8VAE9W)O=7`\+VYA;64^(#PO9FEE;&0^#0H@("`\+VEN
M9&5X/@T*#0H-"B`@(#QI;F1E>#X-"B`@("`\;F%M93YE>'!I<F5S7VEN9&5X
M/"]N86UE/@T*("`@(#QF:65L9#X@/&YA;64^97AP:7)E<SPO;F%M93X@/"]F
M:65L9#X-"B`@(#PO:6YD97@^#0H-"B`@/"]D96-L87)A=&EO;CX-"B`\+W1A
M8FQE/@T*#0H\+V1A=&%B87-E/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M871A+UA-3%]397)I86QI>F5R+V1O8P``````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,S(#`R,C<Q,0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1A=&$O6$U,7U-E<FEA;&EZ97(O9&]C+W1O9&\N
M='AT````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$P-C`@,3`U,34T,S0Q,S,@
M,#(T-#<S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````%1/1$\Z"BTM+2TM"BT@:6YT<F]D=6-E(&-O;G-T86YT<R!F;W(@;W!T
M:6]N<R!T;R!A=F]I9"!T>7!O<PH*5$]$3R!834Q?4V5R:6%L:7IE<CH*+2TM
M+2TM+2TM+2TM+2TM+2TM+2T*+2!F:6YD(&$@=V%Y('1O(&1E=&5C="!R969E
M<F5N8V5S(&EN('1H92!S=')U8W1U<F4@86YD(&%D9"!I9"]I9')E9B!A='1R
M:6)U=&5S"BT@<V5R:6%L:7IE('-O;64@;W1H97(@<W1R=6-T=7)E<RP@97-P
M96-I86QL>2!84&%T:"!R971U<FX@=F%L=65S"BT@8W5S=&]M('-E<FEA;&EZ
M871I;VX@;V8@;V)J96-T<PH*5$]$3R!834Q?56YS97)I86QI>F5R.@HM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"BT@<W5P<&]R="!F;W(@>&UL.G-P86-E(&%T
M=')I8G5T90HM('-E="!T>7!E<R!F;W(@8V5R=&%I;B!T86=S("AL:6ME(&EN
M('!A=$-O;F9I9W5R871I;VXI"BT@;F%M97-P86-E('-U<'!O<G0*+2!C=7-T
M;VT@=6YS97)I86QI>F%T:6]N(&9O<B!O8FIE8W1S("AS=&%T:6,@=6YS97)I
M86QI>F4H*2!O<B!F<F]M6$U,*"D@;65T:&]D<RD*+2!U;G-E<FEA;&EZ92!R
M969E<F5N8V5S('5S:6YG(&ED+VED<F5F````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]I
M;6%G97,`````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q,S,@,#(T,#(R`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&%T82]3
M97)V:6-E<U]796%T:&5R+V)U:6QD365T87)$0BYP:'``````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`S-S0W,B`Q,#4Q-30S-#$S,R`P,C4V-C``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````(R$O=7-R+VQO8V%L+V)I;B]P
M:'`*/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*
M"B\J*@H@*B!4:&ES('-C<FEP="!D;W=N;&]A9',L('-A=F5S(&%N9"!P<F]C
M97-S97,@=&AE('1E>'1F:6QE<R!N965D960@9F]R"B`J('1H92!B=6EL9&EN
M9R!T:&4@9&%T86)A<V5S('1O(&5N86)L92!S96%R8VAI;F<@9F]R($U%5$%2
M('-T871I;VYS+@H@*@H@*B!9;W4@8V%N(&1O=VYL;V%D('1H92!L;V-A=&EO
M;G,L('=H:6-H(&ES(&$@9&%T86)A<V4@;V8@86)O=70@,3(P,#`@=V]R;&0M
M"B`J('=I9&4@;&]C871I;VYS+"!W:&EC:"!C86X@8F4@=7-E9"!T;R!D971E
M<FUI;F4@=&AE(&-O;W)D:6YA=&5S(&]F('EO=7(*("H@8VET>2!O<B!Y;W4@
M8V%N(&1O=VYL;V%D(&$@9FEL92!W:71H(#8U,#`@86ER<&]R=',@<')O=FED
M:6YG('1H92!M971A<@H@*B!D871A+B!4:&ES(&1A=&%B87-E(&ES('5S960@
M9F]R('1H92!N97AT+4U%5$%2+7-T871I;VX@<V5A<F-H+B!0;&5A<V4@<V5E
M"B`J('1H92!A<')O<')I871E(&1O8W5M96YT871I;VX@:6X@=&AE(%-E<G9I
M8V5S7U=E871H97)?365T87(@8VQA<W,N"B`J"B`J($9O<B!U<V%G92!O9B!T
M:&ES('-C<FEP="P@:6YV;VME('=I=&@@)RUH)RX*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@
M,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N
M"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B
M:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@
M<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N
M;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@
M8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@
M*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@
M9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O
M9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@
M(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D
M97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF
M:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E17
M05)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@
M0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-
M4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@
M5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,
M2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!
M4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(
M5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@
M0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4
M551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52
M($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.
M1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G;W)Y("`@(%=E
M8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@
M*B!`<W5B<&%C:V%G92`@8G5I;&1-971A<D1""B`J($!A=71H;W(@("`@("!!
M;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@
M("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO
M+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@
M($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@8G5I;&1-
M971A<D1"+G!H<"QV(#$N,C,@,C`P-2\Q,2\Q,R`R,3HU-CHQ-2!E<G4@17AP
M("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P.B\O=V5A
M=&AE<BYN;V%A+F=O=B]T9R]S:71E+G-H=&UL"B`J($!F:6QE<V]U<F-E"B`J
M+PH*<F5Q=6ER95]O;F-E(")$0BYP:'`B.PH*+R\@>WM[(&-O;G-T86YT<PHO
M+R![>WL@;F%T=7)A;"!C;VYS=&%N=',@86YD(&UE87-U<F5S"F1E9FEN92@B
M4T525DE#15-?5T5!5$A%4E]2041)55-?14%25$@B+"`V,S<X+C$U*3L*+R\@
M?7U]"B\O('U]?0H*+R\@>WM[(%-E<G9I8V5S7U=E871H97)?8VAE8VM$871A
M*"D*+RHJ"B`J(%-E<G9I8V5S7U=E871H97)?8VAE8VM$871A"B`J"B`J($-H
M96-K<R!T:&4@9&%T82!F;W(@82!C97)T86EN('-T<FEN9RUL96YG=&@@86YD
M(&EF(&ET(&5I=&AE<B!C;VYS:7-T<R!O9@H@*B!A(&-E<G1A:6X@8VAA<BUT
M>7!E(&]R(&$@<W1R:6YG(&]F("(M(B!A<R!R97!L86-E;65N="X*("H*("H@
M0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("`@("`D9&%T
M82`@("`@("`@("`@5&AE(&1A=&$@=&\@8F4@8VAE8VME9`H@*B!`<&%R86T@
M("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@("`@("1D871A3W)D97(@
M("`@("!"96-A=7-E('1H92!D871A(&ES(&EN(&1I9F9E<F5N="!L;V-A=&EO
M;G,L('=E('!R;W9I9&4@=&AI<PH@*B!`<F5T=7)N("!B;V]L"B`J+PIF=6YC
M=&EO;B!397)V:6-E<U]796%T:&5R7V-H96-K1&%T82@D9&%T82P@)&1A=&%/
M<F1E<BD*>PH@("`@)')E='5R;B`]('1R=64["B`@("!F;W)E86-H("@D9&%T
M84]R9&5R(&%S("1T>7!E(#T^("1I9'@I('L*("`@("`@("!S=VET8V@@*'-T
M<G1O;&]W97(H)'1Y<&4I*2!["B`@("`@("`@("`@(&-A<V4@(F(B.@H@("`@
M("`@("`@("`@("`@)&QE;B`@/2`R.PH@("`@("`@("`@("`@("`@)&9U;F,@
M/2`B8W1Y<&5?9&EG:70B.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@(G,B.@H@("`@("`@("`@("`@("`@)&QE;B`@/2`S.PH@
M("`@("`@("`@("`@("`@)&9U;F,@/2`B8W1Y<&5?9&EG:70B.PH@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(FDB.@H@("`@("`@
M("`@("`@("`@)&QE;B`@/2`T.PH@("`@("`@("`@("`@("`@)&9U;F,@/2`B
M8W1Y<&5?86QN=6TB.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("!]
M"B`@("`@("`@:68@*"AS=')L96XH)&1A=&%;)&ED>%TI("$]("1L96XI('Q\
M("@A)&9U;F,H)&1A=&%;)&ED>%TI("8F("@D9&%T85LD:61X72`A/2!S=')?
M<F5P96%T*"(M(BP@)&QE;BDI*2D@>PH@("`@("`@("`@("`D<F5T=7)N(#T@
M9F%L<V4["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@('T*("`@('T*("`@
M(')E='5R;B`D<F5T=7)N.PI]"B\O('U]?0H*+R\@>WM[(%-E<G9I8V5S7U=E
M871H97)?9V5T3F5X=$%R9R@I"B\J*@H@*B!397)V:6-E<U]796%T:&5R7V=E
M=$YE>'1!<F<*("H*("H@0VAE8VMS+"!I9B!T:&4@;F5X="!A<F=U;65N="!I
M<R!A('!A<F%M971E<B!T;R!A('!R961E8V5S<VEN9R!O<'1I;VXN"B`J(%)E
M='5R;G,@96ET:&5R('1H870@<&%R86UE=&5R(&]R(&9A;'-E+"!I9B!T:&4@
M;F5X="!A<F=U;65N="!I<R!A;B!O<'1I;VX*("H*("H@0'!A<F%M("`@:6YT
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D8R`@("`@("`@("`@("`@
M26YT97)N86P@87)G=6UE;G0@8V]U;G1E<@H@*B!`<F5T=7)N("!S=')I;F=\
M8F]O;`H@*B\*9G5N8W1I;VX@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G
M*"8D8RD*>PH@("`@:68@*"@H)&,@*R`Q*2`\("1?4T525D526R)A<F=C(ETI
M("8F("@D7U-%4E9%4ELB87)G=B)=6R1C("L@,5U[,'T@(3T@(BTB*2D@>PH@
M("`@("`@("1C*RL["B`@("`@("`@<F5T=7)N("1?4T525D526R)A<F=V(EU;
M)&-=.PH@("`@?2!E;'-E('L*("`@("`@("!R971U<FX@9F%L<V4["B`@("!]
M"GT*+R\@?7U]"@HO+R!&:7)S="!S970@82!F97<@=F%R:6%B;&5S(&9O<B!P
M<F]C97-S:6YG('1H92!O<'1I;VYS"B1M;V1E4V5T("`@/2!F86QS93L*)'-A
M=F5&:6QE("`](&9A;'-E.PHD<')I;G1(96QP(#T@9F%L<V4["B1I;G9/<'0@
M("`@/2!F86QS93L*)'9E<F)O<V4@("`](#`["B1D8E1Y<&4@("`@/2`B;7ES
M<6PB.PHD9&)0<F]T("`@(#T@(G5N:7@B.PHD9&).86UE("`@(#T@(G-E<G9I
M8V5S5V5A=&AE<D1"(CL*)&1B57-E<B`@("`](")R;V]T(CL*)&1B4&%S<R`@
M("`]("(B.PHD9&)(;W-T("`@(#T@(FQO8V%L:&]S="(["B1D8D]P=&EO;G,@
M/2!A<G)A>2@I.PHD=7-E<D9I;&4@(#T@(B(["@HO+R!)=&5R871E('1H<F]U
M9V@@=&AE(&%R9W5M96YT<R!A;F0@8VAE8VL@=&AE:7(@=F%L:61I='D*9F]R
M("@D8R`](#$[("1C(#P@)%]315)615);(F%R9V,B73L@)&,K*RD@>PH@("`@
M<W=I=&-H("@D7U-%4E9%4ELB87)G=B)=6R1C77LQ?2D@>PH@("`@("`@(&-A
M<V4@(FPB.@H@("`@("`@("`@("`O+R!L;V-A=&EO;BUM;V1E+"!I9B!A;F]T
M:&5R(&UO9&4@:7,@<V5T+"!B86EL(&]U=`H@("`@("`@("`@("!I9B`H)&UO
M9&53970I('L*("`@("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@)&UO9&53970@
M("`]('1R=64["B`@("`@("`@("`@("`@("`D9FEL95!A<G0@(#T@(F)B<W-S
M(CL*("`@("`@("`@("`@("`@("1T86)L94YA;64@/2`B;65T87),;V-A=&EO
M;G,B.PH@("`@("`@("`@("`@("`@)&1A=&%/<F1E<B`](&%R<F%Y*")B(B`]
M/B`P+"`B<R(@/3X@,2P@(FDB(#T^(#(I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(F$B.@H@("`@("`@("`@("`O
M+R!D:71O(&9O<B!A:7)P;W)T+6UO9&4*("`@("`@("`@("`@:68@*"1M;V1E
M4V5T*2!["B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1M;V1E4V5T("`@
M/2!T<G5E.PH@("`@("`@("`@("`@("`@)&9I;&5087)T("`](")C8V-C(CL*
M("`@("`@("`@("`@("`@("1T86)L94YA;64@/2`B;65T87)!:7)P;W)T<R([
M"B`@("`@("`@("`@("`@("`D9&%T84]R9&5R(#T@87)R87DH(F(B(#T^(#$L
M(")S(B`]/B`R+"`B:2(@/3X@,"D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@8V%S92`B9B(Z"B`@("`@("`@("`@("\O(&9I
M;&4M9FQA9R!W87,@<')O=FED960L(&-H96-K(&EF(&YE>'0@87)G=6UE;G0@
M:7,@82!S=')I;F<*("`@("`@("`@("`@:68@*"@D=7-E<D9I;&4@/2!397)V
M:6-E<U]796%T:&5R7V=E=$YE>'1!<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@
M("`@("`@("`@("`@("1P<FEN=$AE;'`@/2!T<G5E.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(G,B.@H@("`@("`@
M("`@("`O+R!)9B!Y;W4@9&]W;FQO860@=&AE(&9I;&4L(&ET('=I;&P@8F4@
M<V%V960@=&\@9&ES:PH@("`@("`@("`@("`D<V%V949I;&4@("`@("`]('1R
M=64["B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&-A<V4@(G0B.@H@("`@
M("`@("`@("`O+R!4:&4@='EP92!O9B!T:&4@1$(@=&\@8F4@=7-E9`H@("`@
M("`@("`@("!I9B`H*"1D8E1Y<&4@/2!397)V:6-E<U]796%T:&5R7V=E=$YE
M>'1!<F<H)&,I*2`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("1P<FEN
M=$AE;'`@/2!T<G5E.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&)R96%K
M.PH@("`@("`@(&-A<V4@(G(B.@H@("`@("`@("`@("`O+R!4:&4@<')O=&]C
M;VP@;V8@=&AE($1"('1O(&)E('5S960*("`@("`@("`@("`@:68@*"@D9&)0
M<F]T(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T](&9A
M;'-E*2!["B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E(")D
M(CH*("`@("`@("`@("`@+R\@5&AE(&YA;64@;V8@=&AE($1"('1O(&)E('5S
M960*("`@("`@("`@("`@:68@*"@D9&).86UE(#T@4V5R=FEC97-?5V5A=&AE
M<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("!C87-E(")U(CH*("`@("`@("`@("`@+R\@5&AE
M('5S97(@;V8@=&AE($1"('1O(&)E('5S960*("`@("`@("`@("`@:68@*"@D
M9&)5<V5R(#T@4V5R=FEC97-?5V5A=&AE<E]G971.97AT07)G*"1C*2D@/3T]
M(&9A;'-E*2!["B`@("`@("`@("`@("`@("`D<')I;G1(96QP(#T@=')U93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!B<F5A:SL*("`@("`@("!C87-E
M(")P(CH*("`@("`@("`@("`@+R\@5&AE('!A<W-W;W)D(&]F('1H92!$0B!T
M;R!B92!U<V5D"B`@("`@("`@("`@(&EF("@H)&1B4&%S<R`](%-E<G9I8V5S
M7U=E871H97)?9V5T3F5X=$%R9R@D8RDI(#T]/2!F86QS92D@>PH@("`@("`@
M("`@("`@("`@)'!R:6YT2&5L<"`]('1R=64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92`B:"(Z"B`@("`@("`@("`@
M("\O(%1H92!H;W-T(&]F('1H92!$0B!T;R!B92!U<V5D"B`@("`@("`@("`@
M(&EF("@H)&1B2&]S="`](%-E<G9I8V5S7U=E871H97)?9V5T3F5X=$%R9R@D
M8RDI(#T]/2!F86QS92D@>PH@("`@("`@("`@("`@("`@)'!R:6YT2&5L<"`]
M('1R=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@8V%S92`B;R(Z"B`@("`@("`@("`@("\O($]P=&EO;G,@9F]R('1H92!$
M0@H@("`@("`@("`@("!I9B`H*"1O<'1I;VYS(#T@4V5R=FEC97-?5V5A=&AE
M<E]G971.97AT07)G*"1C*2D@/3T](&9A;'-E*2!["B`@("`@("`@("`@("`@
M("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("1O<'1I;VYS("`@/2!E>'!L;V1E*"(L(BP@)&]P=&EO
M;G,I.PH@("`@("`@("`@("`@("`@9F]R96%C:"`H)&]P=&EO;G,@87,@)&]P
M=&EO;BD@>PH@("`@("`@("`@("`@("`@("`@("1O<'1086ER(#T@97AP;&]D
M92@B/2(L("1O<'1I;VXI.PH@("`@("`@("`@("`@("`@("`@("1D8D]P=&EO
M;G-;)&]P=%!A:7);,%U=(#T@)&]P=%!A:7);,5T["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M8V%S92`B=B(Z"B`@("`@("`@("`@("\O(&EN8W)E87-E('9E<F)O<VET>0H@
M("`@("`@("`@("!F;W(@*"1I(#T@,3L@)&D@/"!S=')L96XH)%]315)615);
M(F%R9W8B75LD8UTI.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)%]3
M15)615);(F%R9W8B75LD8UU[)&E](#T](")V(BD@>PH@("`@("`@("`@("`@
M("`@("`@("1V97)B;W-E*RL["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("1I;G9/<'0@("`@/2!T<G5E.PH@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@
M("`@("`@("`@("\O(&%R9W5M96YT(&YO="!V86QI9"P@8F%I;"!O=70*("`@
M("`@("`@("`@)&EN=D]P="`@("`]('1R=64["B`@("`@("`@("`@(&)R96%K
M.PH@("`@?0H@("`@:68@*"1I;G9/<'0I('L*("`@("`@("`O+R!S964@86)O
M=F4*("`@("`@("`D<')I;G1(96QP(#T@=')U93L*("`@("`@("!E8VAO("))
M;G9A;&ED(&]P=&EO;CH@)R(N)%]315)615);(F%R9W8B75LD8UTN(B=<;B([
M"B`@("`@("`@8G)E86L["B`@("!]"GT*"B\O(&AE;'`M;65S<V%G90II9B`H
M(21M;V1E4V5T('Q\("1P<FEN=$AE;'`I('L*("`@(&5C:&\@(E5S86=E.B`B
M+F)A<V5N86UE*"1?4T525D526R)A<F=V(EU;,%TL("(N<&AP(BDN(B`M;'PM
M82!;;W!T:6]N<UU<;B(["B`@("!E8VAO(")/<'1I;VYS.EQN(CL*("`@(&5C
M:&\@(B`@+6P@("`@("`@("`@("`@(&)U:6QD(&QO8V%T:6]N<T1"7&XB.PH@
M("`@96-H;R`B("`M82`@("`@("`@("`@("`@8G5I;&0@86ER<&]R='-$0EQN
M(CL*("`@(&5C:&\@(B`@+68@/&9I;&4^("`@("`@('5S92`\9FEL93X@87,@
M:6YP=71<;B(["B`@("!E8VAO("(@("US("`@("`@("`@("`@("!S879E(&1O
M=VYL;V%D960@9FEL92!T;R!D:7-K7&XB.PH@("`@96-H;R`B("`M="`\9&)T
M>7!E/B`@("`@='EP92!O9B!T:&4@1$(@=&\@8F4@=7-E9%QN(CL*("`@(&5C
M:&\@(B`@+7(@/&1B<')O=&]C;VP^('!R;W1O8V]L("TM+2TM7"(M+2TM+2TM
M+2TM7&XB.PH@("`@96-H;R`B("`M9"`\9&)N86UE/B`@("`@;F%M92`M+2TM
M+2TM+2U<(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UU(#QD8G5S97(^
M("`@("!U<V5R("TM+2TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C:&\@
M(B`@+7`@/&1B<&%S<SX@("`@('!A<W,@+2TM+2TM+2TM7"(M+2TM+2TM+2TM
M7&XB.PH@("`@96-H;R`B("`M:"`\9&)H;W-T/B`@("`@:&]S="`M+2TM+2TM
M+2U<(BTM+2TM+2TM+2U<;B(["B`@("!E8VAO("(@("UO(#QD8F]P=&EO;G,^
M("!O<'1I;VYS("TM+2TM+5PB+2TM+2TM+2TM+5QN(CL*("`@(&5C:&\@(B`@
M("`@("`@("`@("`@("`@(&EN('1H92!N;W1A=&EO;B!O<'1I;VX]=F%L=64L
M+BXN7&XB.PH@("`@96-H;R`B("`M=B`@("`@("`@("`@("`@9&ES<&QA>2!V
M97)B;W-E(&1E8G5G9VEN9R!M97-S86=E<UQN(CL*("`@(&5C:&\@(B`@("`@
M("`@("`@("`@("`@(&UU;'1I<&QE("UV(&EN8W)E87-E<R!V97)B;W-I='E<
M;B(["B`@("!E>&ET*#(U-2D["GT*"B\O(&-H96-K+"!I9B!Z;&EB(&ES(&%V
M86EL86)L90II9B`H97AT96YS:6]N7VQO861E9"@B>FQI8B(I*2!["B`@("`D
M;W!E;B`@/2`B9WIO<&5N(CL*("`@("1C;&]S92`](")G>F-L;W-E(CL*("`@
M("1F:6QE<R`](&%R<F%Y*`H@("`@("`@("1U<V5R1FEL92P@(FYS9%\B+B1F
M:6QE4&%R="P@(FYS9%\B+B1F:6QE4&%R="XB+G1X="(L"B`@("`@("`@(FYS
M9%\B+B1F:6QE4&%R="XB+F=Z(BP@(FAT='`Z+R]W96%T:&5R+FYO86$N9V]V
M+V1A=&$O;G-D7R(N)&9I;&5087)T+B(N9WHB"B`@("`I.PI](&5L<V4@>PH@
M("`@)&]P96X@(#T@(F9O<&5N(CL*("`@("1C;&]S92`](")F8VQO<V4B.PH@
M("`@)&9I;&5S(#T@87)R87DH"B`@("`@("`@)'5S97)&:6QE+"`B;G-D7R(N
M)&9I;&5087)T+"`B;G-D7R(N)&9I;&5087)T+B(N='AT(BP*("`@("`@("`B
M:'1T<#HO+W=E871H97(N;F]A82YG;W8O9&%T82]N<V1?(BXD9FEL95!A<G0N
M(BYT>'0B"B`@("`I.PI]"B\O('1H96X@=')Y('1O(&]P96X@82!S;W5R8V4@
M:6X@=&AE(&=I=F5N(&]R9&5R"F9O<F5A8V@@*"1F:6QE<R!A<R`D9FEL92D@
M>PH@("`@)&9P(#T@0"1O<&5N*"1F:6QE+"`B<F(B*3L*("`@(&EF("@D9G`I
M('L*("`@("`@("`O+R!F;W5N9"!A('9A;&ED('-O=7)C90H@("`@("`@(&EF
M("@D=F5R8F]S92`^(#`I('L*("`@("`@("`@("`@96-H;R`B4V5R=FEC97-?
M5V5A=&AE<CH@57-I;F<@)R(N)&9I;&4N(B<@87,@<V]U<F-E+EQN(CL*("`@
M("`@("!]"B`@("`@("`@:68@*"1S879E1FEL92`F)B`A9FEL95]E>&ES=',H
M)&9I;&4I*2!["B`@("`@("`@("`@("\O(&%P<&%R96YT;'D@=V4@=V%N="!T
M;R!S879E('1H92!F:6QE+"!A;F0@:70G<R!A(')E;6]T92!F:6QE"B`@("`@
M("`@("`@("1F:6QE(#T@8F%S96YA;64H)&9I;&4I.PH@("`@("`@("`@("`D
M9G!S(#T@0"1O<&5N*"1F:6QE+"`B=V(B*3L*("`@("`@("`@("`@:68@*"$D
M9G!S*2!["B`@("`@("`@("`@("`@("!E8VAO(")397)V:6-E<U]796%T:&5R
M.B!#;W5L9&XG="!S879E('1O("<B+B1F:6QE+B(G(5QN(CL*("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D=F5R8F]S92`^(#`I
M('L*("`@("`@("`@("`@("`@("`@("!E8VAO(")397)V:6-E<U]796%T:&5R
M.B!3879I;F<@<V]U<F-E('1O("<B+B1F:6QE+B(G+EQN(CL*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("\O(')E860@9G)O;2!F:6QE<&]I
M;G1E<B!A;F0@<V%V92!T;R!D:7-K"B`@("`@("`@("`@("`@("!W:&EL92`H
M)&QI;F4@/2!F<F5A9"@D9G`L(#$P,C0I*2!["B`@("`@("`@("`@("`@("`@
M("`@9G=R:71E*"1F<',L("1L:6YE+"!S=')L96XH)&QI;F4I*3L*("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("\O('5N9F]R='5N871E;'D@
M>FQI8B!D;V5S(&YO="!S=7!P;W)T('(O=R!O;B!A(')E<V]U<F-E+`H@("`@
M("`@("`@("`@("`@+R\@<V\@;F\@<F5W:6YD("T^(&UO=F4@)&9P('1O(&YE
M=R!F:6QE(&]N(&1I<VL*("`@("`@("`@("`@("`@("1C;&]S92@D9G`I.PH@
M("`@("`@("`@("`@("`@)&-L;W-E*"1F<',I.PH@("`@("`@("`@("`@("`@
M)&9P(#T@0"1O<&5N*"1F:6QE+"`B<F(B*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!B<F5A:SL*("`@('T*?0II9B`H(21F<"D@>PH@("`@
M+R\@;F\@9FEL97,@9F]U;F0L(&]R(&-O;FYE8W1I;VX@;F]T(&%V86EL86)L
M92XN+B!B86EL(&]U=`H@("`@9&EE*")397)V:6-E<U]796%T:&5R.B!3;W5R
M8V5F:6QE(&YS9%\B+B1F:6QE4&%R="XB(&YO="!F;W5N9"%<;B(I.PI]"@HD
M9'-N("`@("`]("1D8E1Y<&4N(CHO+R(N)&1B57-E<BXB.B(N)&1B4&%S<RXB
M0"(N)&1B4')O="XB*R(N)&1B2&]S="XB+R(N)&1B3F%M93L*)&1S;FEN9F\@
M/2!A<G)A>2@*("`@(")P:'!T>7!E(B`@/3X@)&1B5'EP92P*("`@(")P<F]T
M;V-O;"(@/3X@)&1B4')O="P*("`@(")U<V5R;F%M92(@/3X@)&1B57-E<BP*
M("`@(")P87-S=V]R9"(@/3X@)&1B4&%S<RP*("`@(")H;W-T<W!E8R(@/3X@
M)&1B2&]S="P*("`@(")D871A8F%S92(@/3X@)&1B3F%M92P*("`@(")M;V1E
M(B`@("`@/3X@(C`V-#0B"BD["@HD9&(@(#T@1$(Z.F-O;FYE8W0H)&1S;FEN
M9F\L("1D8D]P=&EO;G,I.PII9B`H1$(Z.FES17)R;W(H)&1B*2D@>PH@("`@
M96-H;R`B4V5R=FEC97-?5V5A=&AE<CH@0V]N;F5C=&EO;B!T;R!$0B!W:71H
M("<B+B1D8E1Y<&4N(CHO+R(N)&1B57-E<BXB.E!!4U-`(BXD9&)(;W-T+B(O
M(BXD9&).86UE+B(G(&9A:6QE9"%<;B(["B`@("!D:64H)&1B+3YG971-97-S
M86=E*"DN(EQN(BD["GT@96QS92!["B`@("`O+R!497-T+"!I9B!W92!H879E
M('1O('-W:7!E(&]R(&-R96%T92!T:&4@=&%B;&4@9FER<W0*("`@("1S96QE
M8W0@/2`B4T5,14-4("H@1E)/32`B+B1T86)L94YA;64["B`@("`D<F5S=6QT
M(#T@)&1B+3YQ=65R>2@D<V5L96-T*3L*"B`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<W5L="DI('L*("`@("`@("`O+R!#<F5A=&4@;F5W('1A8FQE"B`@("`@
M("`@)&-R96%T92`](")#4D5!5$4@5$%"3$4@(BXD=&%B;&5.86UE+B(H:60@
M:6YT+&)L;V-K(&EN="QS=&%T:6]N(&EN="QI8V%O('9A<F-H87(H-"DL;F%M
M92!V87)C:&%R*#@P*2QS=&%T92!V87)C:&%R*#(I+&-O=6YT<GD@=F%R8VAA
M<B@U,"DL=VUO(&EN="QL871I='5D92!F;&]A="QL;VYG:71U9&4@9FQO870L
M96QE=F%T:6]N(&9L;V%T+'@@9FQO870L>2!F;&]A="QZ(&9L;V%T*2(["B`@
M("`@("`@:68@*"1V97)B;W-E(#X@,"D@>PH@("`@("`@("`@("!E8VAO(")3
M97)V:6-E<U]796%T:&5R.B!#<F5A=&EN9R!T86)L92`G(BXD=&%B;&5.86UE
M+B(G+EQN(CL*("`@("`@("!]"B`@("`@("`@)')E<W5L="`@/2`D9&(M/G%U
M97)Y*"1C<F5A=&4I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT
M*2D@>PH@("`@("`@("`@("!D:64H)')E<W5L="T^9V5T365S<V%G92@I+B)<
M;B(I.PH@("`@("`@('T*("`@('T@96QS92!["B`@("`@("`@+R\@1&5L971E
M('1H92!O;&0@<W1U9F8*("`@("`@("`D9&5L971E(#T@(D1%3$5412!&4D]-
M("(N)'1A8FQE3F%M93L*("`@("`@("!I9B`H)'9E<F)O<V4@/B`P*2!["B`@
M("`@("`@("`@(&5C:&\@(E-E<G9I8V5S7U=E871H97(Z($1E;&5T:6YG(&9R
M;VT@=&%B;&4@)R(N)'1A8FQE3F%M92XB)RY<;B(["B`@("`@("`@?0H@("`@
M("`@("1R97-U;'0@/2`D9&(M/G%U97)Y*"1D96QE=&4I.PH@("`@("`@(&EF
M("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@("!D:64H)')E
M<W5L="T^9V5T365S<V%G92@I+B)<;B(I.PH@("`@("`@('T*("`@('T*"B`@
M("`O+R!/:RP@1$(@<VAO=6QD(&)E('5P(&%N9"!R=6YN:6YG(&YO=RP@;&5T
M)W,@<VAO=F4@:6X@=&AE(&1A=&$*("`@("1L:6YE("`@/2`P.PH@("`@)&5R
M<F]R("`](#`["B`@("`O+R!R96%D(&1A=&$@9G)O;2!F:6QE"B`@("!W:&EL
M92`H)&1A=&$@/2!F9V5T8W-V*"1F<"P@,3`P,"P@(CLB*2D@>PH@("`@("`@
M("\O($-H96-K(&9O<B!V86QI9"!D871A"B`@("`@("`@:68@*"AS:7IE;V8H
M)&1A=&$I(#P@.2D@?'P@(5-E<G9I8V5S7U=E871H97)?8VAE8VM$871A*"1D
M871A+"`D9&%T84]R9&5R*2D@>PH@("`@("`@("`@("`@("`@96-H;R`B4V5R
M=FEC97-?5V5A=&AE<CH@26YV86QI9"!D871A(&EN(&9I;&4A7&XB.PH@("`@
M("`@("`@("`@("`@96-H;R`B7'1,:6YE("(N*"1L:6YE("L@,2DN(CH@(BYI
M;7!L;V1E*"([(BP@)&1A=&$I+B)<;B(["B`@("`@("`@("`@("`@("`D97)R
M;W(K*SL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!C86QC=6QA
M=&4@;&%T:71U9&4@86YD(&QO;F=I='5D90H@("`@("`@("`@("`O+R!I="!C
M;VUE<R!I;B!A(&1D9"UM;5LM<W-=3GQ3?$5\5R!F;W)M870*("`@("`@("`@
M("`@)&-O;W)D(#T@87)R87DH(")L871I='5D92(@/3X@-RP@(FQO;F=I='5D
M92(@/3X@."D["B`@("`@("`@("`@(&9O<F5A8V@@*"1C;V]R9"!A<R`D;&%T
M;&]N(#T^("1A260I('L*("`@("`@("`@("`@("`@('!R96=?;6%T8V@H(B]>
M*%QD>S$L,WTI+2A<9'LQ+#)]*2@M*%QD>S$L,GTI*3\H6TY315==*20O(BP@
M)&1A=&%;)&%)9%TL("1R97-U;'0I.PH@("`@("`@("`@("`@("`@)'LD;&%T
M;&]N?2`](#`[("1F86-T;W(@/2`Q.PH@("`@("`@("`@("`@("`@9F]R96%C
M:"`H)')E<W5L="!A<R`D=F%R*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*"AS=')L96XH)'9A<BD@/B`P*2`F)B!C='EP95]D:6=I="@D=F%R*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D>R1L871L;VY]("L]("1V87(@+R`D
M9F%C=&]R.PH@("`@("`@("`@("`@("`@("`@("`@("`D9F%C=&]R("H](#8P
M.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF("AC='EP95]A;'!H82@D
M=F%R*2`F)B!I;E]A<G)A>2@D=F%R+"!A<G)A>2@B4R(L(")7(BDI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("1[)&QA=&QO;GT@*CT@*"TQ*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@('T*"B`@("`@("`@("`@("\O($-A;&-U;&%T92!T:&4@8V%R=&5S:6%N
M(&-O;W)D:6YA=&5S(&9O<B!L871I='5D92!A;F0@;&]N9VET=61E"B`@("`@
M("`@("`@("1T:&5T82`](&1E9S)R860H)&QA=&ET=61E*3L*("`@("`@("`@
M("`@)'!H:2`@(#T@9&5G,G)A9"@D;&]N9VET=61E*3L*"B`@("`@("`@("`@
M("1X(#T@4T525DE#15-?5T5!5$A%4E]2041)55-?14%25$@@*B!C;W,H)'!H
M:2D@*B!C;W,H)'1H971A*3L*("`@("`@("`@("`@)'D@/2!315)624-%4U]7
M14%42$527U)!1$E54U]%05)42"`J('-I;B@D<&AI*2`J(&-O<R@D=&AE=&$I
M.PH@("`@("`@("`@("`D>B`](%-%4E9)0T537U=%051(15)?4D%$25537T5!
M4E1(("`@("`@("`@("`@("H@<VEN*"1T:&5T82D["@H@("`@("`@("`@("`O
M+R!#:&5C:R!F;W(@96QE=F%T:6]N(&EN(&1A=&$*("`@("`@("`@("`@)&5L
M979A=&EO;B`](&ES7VYU;65R:6,H)&1A=&%;,3%=*2`_("1D871A6S$Q72`Z
M(#`["@H@("`@("`@("`@("`O+R!I;G1E9V5R<SH@8V]N=F5R="`B+2TB(&9I
M96QD<R!T;R!N=6QL+"!E;7!T>2!F:65L9',@=&\@,`H@("`@("`@("`@("!F
M;W)E86-H("AA<G)A>2@D9&%T84]R9&5R6R)B(ETL("1D871A3W)D97);(G,B
M72P@-BD@87,@)&DI('L*("`@("`@("`@("`@("`@(&EF("AS=')P;W,H)&1A
M=&%;)&E=+"`B+2TB*2`A/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@("`@
M("`D9&%T85LD:5T@/2`B;G5L;"(["B`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H)&1A=&%;)&E=(#T]("(B*2!["B`@("`@("`@("`@("`@("`@("`@)&1A
M=&%;)&E=(#T@,#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@+R\@<W1R:6YG<SH@<75O=&4*("`@("`@("`@("`@9F]R
M96%C:"`H87)R87DH)&1A=&%/<F1E<ELB:2)=+"`S+"`T+"`U*2!A<R`D:2D@
M>PH@("`@("`@("`@("`@("`@)&1A=&%;)&E=(#T@)&1B+3YQ=6]T92@D9&%T
M85LD:5TI.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!I;G-E<G0@
M9&%T80H@("`@("`@("`@("`D:6YS97)T("`]("))3E-%4E0@24Y43R`B+B1T
M86)L94YA;64N(B!604Q515,H(BXH)&QI;F4@+2`D97)R;W(I+B(L(CL*("`@
M("`@("`@("`@)&EN<V5R="`N/2`D9&%T85LD9&%T84]R9&5R6R)B(EU=+B(L
M(BXD9&%T85LD9&%T84]R9&5R6R)S(EU=+B(L(CL*("`@("`@("`@("`@)&EN
M<V5R="`N/2`D9&%T85LD9&%T84]R9&5R6R)I(EU=+B(L(BXD9&%T85LS72XB
M+"(N)&1A=&%;-%TN(BPB.PH@("`@("`@("`@("`D:6YS97)T("X]("1D871A
M6S5=+B(L(BXD9&%T85LV72XB+"(N<F]U;F0H)&QA=&ET=61E+"`T*2XB+"([
M"B`@("`@("`@("`@("1I;G-E<G0@+CT@<F]U;F0H)&QO;F=I='5D92P@-"DN
M(BPB+B1E;&5V871I;VXN(BPB+G)O=6YD*"1X+"`T*2XB+"(["B`@("`@("`@
M("`@("1I;G-E<G0@+CT@<F]U;F0H)'DL(#0I+B(L(BYR;W5N9"@D>BP@-"DN
M(BDB.PH*("`@("`@("`@("`@)')E<W5L="`]("1D8BT^<75E<GDH)&EN<V5R
M="D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@
M("`@("`@("`@("`@("`@96-H;R`B7'1,:6YE("(N*"1L:6YE("L@,2DN(CH@
M(BXD:6YS97)T+B)<;B(["B`@("`@("`@("`@("`@("!E8VAO("1R97-U;'0M
M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@("`@("`@("`@)&5R<F]R*RL[
M"B`@("`@("`@("`@('T@96QS96EF*"1V97)B;W-E(#X@,BD@>PH@("`@("`@
M("`@("`@("`@96-H;R`D:6YS97)T+B)<;B(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@)&QI;F4K*SL*("`@('T*("`@("\O(&-O;6UI="!A
M;F0@8VQO<V4*("`@("1D8BT^9&ES8V]N;F5C="@I.PH@("`@:68@*"1V97)B
M;W-E(#X@,"!\?"`D97)R;W(@/B`P*2!["B`@("`@("`@96-H;R`B4V5R=FEC
M97-?5V5A=&AE<CH@(BXH)&QI;F4@+2`D97)R;W(I+B(@(BXD=&%B;&5.86UE
M+B(@861D960@(CL*("`@("`@("!E8VAO(")T;R!D871A8F%S92`G(BXD9&).
M86UE+B(G("@B+B1E<G)O<BXB(&5R<F]R*',I*2Y<;B(["B`@("!]"GT*)&-L
M;W-E*"1F<"D["C\^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&%T82]397)V:6-E<U]796%T:&5R+VEM86=E<R]S
M=6YS970N9VEF```````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#0S-"`Q,#4Q-30S-#$S,R`P
M,C8Q,3(`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````1TE&.#EA'@`/`,0``/[MZOE6&?]A1_]Z)/^#;O\\&VXX(/W-Q?ZTI]6T
MJ8MC2\4\#+JBF*F+?OR6@M*2@O^9,____P``````````````````````````
M`````````````````````````````"'Y!```````+``````>``\```698"2.
M9&F>:*JNIB.8R,N>1R$BAR@@[$&0.4`A)\@A"@`6("!(1G9/QS,9D,Z6R$@L
MDG@`'MHL=`40-"./AL+`5C02$<(Y`N"EY`G#HA#H!Q8&#%8`!`4R)0@$20T&
M?0./CWT&<$<%5B8^!'D!D!">$)$*#P6*,`=.``J<GZR@`PL-(TXC`@6&!`X*
M`ZVM`P$*!RZ',\3%QB(A`#L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]I;6%G97,O<W5N<FES92YG:68`
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`T-#$@,3`U,34T,S0Q,S,@,#(V,C4W`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````$=)1C@Y81P`
M#0#$``#LL)W]CW5<5"3_^?CPPPK_633_<T__]"C\QK?]X]K_X1:?DH#_.A:0
M?D'_[NN^D'G__S/___\`````````````````````````````````````````
M```````````````A^00``````"P`````'``-```%GF`DCF1IGN@8%"90#&D$
MEPCC1`$B%T",&+.!SL'0%70`1B+F*!26$5[$$(@Z!HSJ8'9J*B._".#A>(AM
M45W*87A&'HN&8"YHF-NW2$)M6@$$!`0*@P1R"P$P;`P&)0`&2PN`@P<'@PH$
M`CT!#`P`7"()`0%_@I0'$)2$`@]9>2(`"%<R#0V3$+>WE9@-(@.N;4ZB`K:X
MN:H(*T`QRR@A`#L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+TQO
M9R]M:7-C````````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,3,S(#`R,#<V-P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1A=&$O3&]G+VUI<V,O;&]G+G-Q;```````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T,#<@,3`U,34T,S0Q,S,@,#(R,S4Q
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"TM
M("1)9#H@;&]G+G-Q;"QV(#$N,2`R,#`T+S`S+S$Y(#`X.C`P.C$P(&IO;B!%
M>'`@)`H*0U)%051%(%1!0DQ%(&QO9U]T86)L92`H"B`@("!I9"`@("`@("`@
M("!)3E0@3D]4($Y53$PL"B`@("!L;V=T:6UE("`@("!424U%4U1!35`@3D]4
M($Y53$PL"B`@("!I9&5N="`@("`@("!#2$%2*#$V*2!.3U0@3E5,3"P*("`@
M('!R:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("`@(&UE<W-A9V4@("`@(%9!
M4D-(05(H,C`P*2P*("`@(%!224U!4ED@2T59("AI9"D**3L*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M871A+TUA:6Q?36EM92]X;6%I;"YX<VP`````````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`T,3(W(#$P-3$U-#,T,3,S(#`R,S`W,0`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/WAM;"!V97)S:6]N
M/2(Q+C`B(&5N8V]D:6YG/2))4T\M.#@U.2TQ(C\^#0H\>'-L.G-T>6QE<VAE
M970@=F5R<VEO;CTB,2XP(B!X;6QN<SIX<VP](FAT='`Z+R]W=W<N=S,N;W)G
M+S$Y.3DO6%-,+U1R86YS9F]R;2(@>&UL;G,Z9F\](FAT='`Z+R]W=W<N=S,N
M;W)G+S$Y.3DO6%-,+T9O<FUA="(^#0H\>'-L.F]U='!U="!M971H;V0](G1E
M>'0B(&]M:70M>&UL+61E8VQA<F%T:6]N/2)Y97,B(&EN9&5N=#TB;F\B+SX-
M"CQX<VPZ<')E<V5R=F4M<W!A8V4@96QE;65N=',](FAE861E<G9A;'5E('!A
M<F%M=F%L=64@8F]D>2(O/@T*#0H)/'AS;#IT96UP;&%T92!N86UE/2)M:6UE
M<&%R="(^#0H-"@D)/'AS;#IV87)I86)L92!N86UE/2)B;W5N9&%R>2(^#0H)
M"0D)/'AS;#IF;W(M96%C:"!S96QE8W0](BXO:&5A9&5R(CX-"@D)"0D)/'AS
M;#II9B!T97-T/2)S=')I;F<H+B]H96%D97)N86UE*2`]("=#;VYT96YT+51Y
M<&4G(CX-"@D)"0D)"3QX<VPZ9F]R+65A8V@@<V5L96-T/2(N+W!A<F%M971E
M<B(^#0H)"0D)"0D)/'AS;#II9B!T97-T/2)S=')I;F<H+B]P87)A;6YA;64I
M(#T@)V)O=6YD87)Y)R(^#0H)"0D)"0D)"3QX<VPZ=F%L=64M;V8@<V5L96-T
M/2)P87)A;79A;'5E(B\^#0H)"0D)"0D)/"]X<VPZ:68^#0H)"0D)"0D\+WAS
M;#IF;W(M96%C:#X-"@D)"0D)/"]X<VPZ:68^#0H)"0D)/"]X<VPZ9F]R+65A
M8V@^#0H)"3PO>'-L.G9A<FEA8FQE/@T*#0H)"3QX<VPZ9F]R+65A8V@@<V5L
M96-T/2)H96%D97(B/@T*#0H)"0D\>'-L.G9A;'5E+6]F('-E;&5C=#TB:&5A
M9&5R;F%M92(O/@T*"0D)/'AS;#IT97AT/CH@/"]X<VPZ=&5X=#X-"@D)"3QX
M<VPZ=F%L=64M;V8@<V5L96-T/2)H96%D97)V86QU92(O/@T*#0H)"0D\>'-L
M.FEF('1E<W0](F-O=6YT*"XO<&%R86UE=&5R*2`](#`B/@T*"0D)"3QX<VPZ
M=&5X=#XF(S$S.R8C,3`[/"]X<VPZ=&5X=#X-"@D)"3PO>'-L.FEF/@T*#0H)
M"0D\>'-L.F9O<BUE86-H('-E;&5C=#TB<&%R86UE=&5R(CX-"@D)"0D\>'-L
M.G1E>'0^.R8C,3,[)B,Q,#LF(S`Y.SPO>'-L.G1E>'0^#0H)"0D)/'AS;#IV
M86QU92UO9B!S96QE8W0](G!A<F%M;F%M92(O/@T*"0D)"3QX<VPZ=&5X=#X]
M(CPO>'-L.G1E>'0^#0H)"0D)/'AS;#IV86QU92UO9B!S96QE8W0](G!A<F%M
M=F%L=64B+SX-"@D)"0D\>'-L.G1E>'0^(CPO>'-L.G1E>'0^#0H)"0D\+WAS
M;#IF;W(M96%C:#X-"@T*"0D)/'AS;#II9B!T97-T/2)C;W5N="@N+W!A<F%M
M971E<BD@/B`P(CX-"@D)"0D\>'-L.G1E>'0^)B,Q,SLF(S$P.SPO>'-L.G1E
M>'0^#0H)"0D\+WAS;#II9CX-"@T*"0D\+WAS;#IF;W(M96%C:#X-"@T*"0D\
M>'-L.G1E>'0^)B,Q,SLF(S$P.SPO>'-L.G1E>'0^#0H-"@D)/"$M+2!7:&EC
M:"!T;R!D;RP@<')I;G0@82!B;V1Y(&]R('!R;V-E<W,@<W5B<&%R=',_("TM
M/@T*"0D\>'-L.F-H;V]S93X-"@D)"3QX<VPZ=VAE;B!T97-T/2)C;W5N="@N
M+VUI;65P87)T*2`](#`B/@T*"0D)"3QX<VPZ=F%L=64M;V8@<V5L96-T/2)B
M;V1Y(B\^#0H)"0D)/'AS;#IT97AT/B8C,3,[)B,Q,#L\+WAS;#IT97AT/@T*
M"0D)/"]X<VPZ=VAE;CX-"@T*"0D)/'AS;#IO=&AE<G=I<V4^#0H)"0D)/'AS
M;#IF;W(M96%C:"!S96QE8W0](FUI;65P87)T(CX-"@D)"0D)/'AS;#IT97AT
M/BTM/"]X<VPZ=&5X=#X\>'-L.G9A;'5E+6]F('-E;&5C=#TB)&)O=6YD87)Y
M(B\^/'AS;#IT97AT/B8C,3,[)B,Q,#L\+WAS;#IT97AT/@T*"0D)"0D\>'-L
M.F-A;&PM=&5M<&QA=&4@;F%M93TB;6EM97!A<G0B+SX-"@D)"0D\+WAS;#IF
M;W(M96%C:#X-"@T*"0D)"3QX<VPZ=&5X=#XM+3PO>'-L.G1E>'0^/'AS;#IV
M86QU92UO9B!S96QE8W0](B1B;W5N9&%R>2(O/CQX<VPZ=&5X=#XM+28C,3,[
M)B,Q,#L\+WAS;#IT97AT/@T*#0H)"0D\+WAS;#IO=&AE<G=I<V4^#0H)"3PO
M>'-L.F-H;V]S93X-"@D\+WAS;#IT96UP;&%T93X-"@T*/"$M+2!4:&ES(&ES
M('=H97)E('1H92!S='EL97-H965T(')E86QL>2!S=&%R=',L(&UA=&-H:6YG
M('1H92!T;W`@;&5V96P@96UA:6P@96QE;65N="`M+3X-"@D\>'-L.G1E;7!L
M871E(&UA=&-H/2)E;6%I;"(^#0H)"3QX<VPZ8V%L;"UT96UP;&%T92!N86UE
M/2)M:6UE<&%R="(O/@T*"3PO>'-L.G1E;7!L871E/@T*#0H\+WAS;#IS='EL
M97-H965T/@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D871A+TUA:6Q?36EM92]X;6%I;"YD=&0`````````````
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#8V(#$P-3$U-#,T,3,S(#`R,S`S
M-0`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/WAM;"!V97)S:6]N/2(Q+C`B(&5N8V]D:6YG/2))4T\M.#@U.2TQ(C\^#0H-
M"CPA14Y42519(&QT("(F(S,X.R,V,#LB/@T*/"%%3E1)5%D@9W0@(B8C-C([
M(CX-"CPA14Y42519(&%M<"`B)B,S.#LC,S@[(CX-"CPA14Y42519(&%P;W,@
M(B8C,SD[(CX-"CPA14Y42519('%U;W0@(B8C,S0[(CX-"CPA14Y42519(&-R
M;&8@(B8C,3,[)B,Q,#LB/@T*#0H\(45,14U%3E0@96UA:6P@*&AE861E<BLL
M("AB;V1Y('P@;6EM97!A<G0K*2D^#0H\(45,14U%3E0@;6EM97!A<G0@*&AE
M861E<BLL("AB;V1Y('P@;6EM97!A<G0K*2D^#0H\(45,14U%3E0@8F]D>2`H
M(U!#1$%402D^#0H\(45,14U%3E0@:&5A9&5R("@H:&5A9&5R;F%M97QH96%D
M97)V86QU97QP87)A;65T97(I*BD^#0H\(45,14U%3E0@:&5A9&5R;F%M92`H
M(U!#1$%402D^#0H\(45,14U%3E0@:&5A9&5R=F%L=64@*"-00T1!5$$I/@T*
M/"%%3$5-14Y4('!A<F%M971E<B`H*'!A<F%M;F%M97QP87)A;79A;'5E*2LI
M/@T*/"%%3$5-14Y4('!A<F%M=F%L=64@*"-00T1!5$$I/@T*/"%%3$5-14Y4
M('!A<F%M;F%M92`H(U!#1$%402D^#0H-"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D871A+U!%05(O=&5M<&QA=&4N<W!E8P``````
M`````````````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,#,U(#$P-3$U-#,T,3,S
M(#`R,C8Q,@`@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!3=6UM87)Y.B!014%2.B!`<W5M;6%R>4`-"DYA;64Z($!R<&U?<&%C
M:V%G94`-"E9E<G-I;VXZ($!V97)S:6]N0`T*4F5L96%S93H@,0T*3&EC96YS
M93H@0')E;&5A<V5?;&EC96YS94`-"D=R;W5P.B!$979E;&]P;65N="],:6)R
M87)I97,-"E-O=7)C93H@:'1T<#HO+T!M87-T97)?<V5R=F5R0"]G970O0'!A
M8VMA9V5`+25[=F5R<VEO;GTN=&=Z#0I"=6EL9%)O;W0Z("5[7W1M<'!A=&A]
M+R5[;F%M97TM<F]O=`T*55),.B!H='1P.B\O0&UA<W1E<E]S97)V97)`+W!A
M8VMA9V4O0'!A8VMA9V5`#0I0<F5F:7@Z("5[7W!R969I>'T-"D)U:6QD07)C
M:&ET96-T=7)E<SH@0&%R8VA`#0I`97AT<F%?:&5A9&5R<T`-"@T*)61E<V-R
M:7!T:6]N#0I`9&5S8W)I<'1I;VY`#0H-"B5P<F5P#0IR;2`M<F8@)7MB=6EL
M9')O;W1]+RH-"B5S971U<"`M8R`M5`T*(R!86%@@4V]U<F-E(&9I;&5S(&QO
M8V%T:6]N(&ES(&UI<W-I;F<@:&5R92!I;B!P96%R(&-M9`T*<&5A<B`M=B`M
M8R`E>V)U:6QD<F]O='TO<&5A<G)C(%P-"B`@("`@("`@+60@<&AP7V1I<CTE
M>U]L:6)D:7)]+W!H<"]P96%R(%P-"B`@("`@("`@+60@9&]C7V1I<CTO9&]C
M<R!<#0H@("`@("`@("UD(&)I;E]D:7(])7M?8FEN9&ER?2!<#0H@("`@("`@
M("UD(&1A=&%?9&ER/25[7VQI8F1I<GTO<&AP+W!E87(O9&%T82!<#0H@("`@
M("`@("UD('1E<W1?9&ER/25[7VQI8F1I<GTO<&AP+W!E87(O=&5S=',@7`T*
M("`@("`@("`M9"!E>'1?9&ER/25[7VQI8F1I<GT@7$!E>'1R85]C;VYF:6=`
M#0H@("`@("`@("US#0H-"B5B=6EL9`T*96-H;R!"=6EL9%)O;W0])7MB=6EL
M9')O;W1]#0H-"B5P;W-T=6X-"B,@:68@<F5F8V]U;G0@/2`P('1H96X@<&%C
M:V%G92!H87,@8F5E;B!R96UO=F5D("AN;W0@=7!G<F%D960I#0II9B!;("(D
M,2(@+65Q("(P(B!=.R!T:&5N#0H@("`@<&5A<B!U;FEN<W1A;&P@+2UN;V1E
M<',@+7(@0'!O<W-I8FQE7V-H86YN96Q`0'!A8VMA9V5`#0H@("`@<FT@0')P
M;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL#0IF:0T*#0H-"B5P;W-T#0HC(&EF
M(')E9F-O=6YT(#T@,B!T:&5N('!A8VMA9V4@:&%S(&)E96X@=7!G<F%D960-
M"FEF(%L@(B0Q(B`M9V4@(C(B(%T[('1H96X-"B`@("!P96%R('5P9W)A9&4@
M+2UN;V1E<',@+7(@0')P;5]X;6Q?9&ER0"]`<&%C:V%G94`N>&UL#0IE;'-E
M#0H@("`@<&5A<B!I;G-T86QL("TM;F]D97!S("UR($!R<&U?>&UL7V1I<D`O
M0'!A8VMA9V5`+GAM;`T*9FD-"@T*)6EN<W1A;&P-"G!E87(@+6,@)7MB=6EL
M9')O;W1]+W!E87)R8R!I;G-T86QL("TM;F]D97!S("U2("5[8G5I;&1R;V]T
M?2!<#0H@("`@("`@("124$U?4T]54D-%7T1)4B]`<&%C:V%G94`M)7MV97)S
M:6]N?2YT9WH-"G)M("5[8G5I;&1R;V]T?2]P96%R<F,-"G)M("5[8G5I;&1R
M;V]T?2\E>U]L:6)D:7)]+W!H<"]P96%R+RYF:6QE;6%P#0IR;2`E>V)U:6QD
M<F]O='TO)7M?;&EB9&ER?2]P:'`O<&5A<B\N;&]C:PT*<FT@+7)F("5[8G5I
M;&1R;V]T?2\E>U]L:6)D:7)]+W!H<"]P96%R+RYR96=I<W1R>0T*:68@6R`B
M0&1O8U]F:6QE<T`B("$]("(B(%T[('1H96X-"B`@("`@;78@)7MB=6EL9')O
M;W1]+V1O8W,O0'!A8VMA9V5`+RH@+@T*("`@("!R;2`M<F8@)7MB=6EL9')O
M;W1]+V1O8W,-"F9I#0IM:V1I<B`M<"`E>V)U:6QD<F]O='U`<G!M7WAM;%]D
M:7)`#0IT87(@+7AZ9B`D4E!-7U-/55)#15]$25(O0'!A8VMA9V5`+25[=F5R
M<VEO;GTN=&=Z('!A8VMA9V5`<&%C:V%G93)X;6Q`+GAM;`T*8W`@+7`@<&%C
M:V%G94!P86-K86=E,GAM;$`N>&UL("5[8G5I;&1R;V]T?4!R<&U?>&UL7V1I
M<D`O0'!A8VMA9V5`+GAM;`T*#0HC<FT@+7)F("5[8G5I;&1R;V]T?2\J#0HC
M<&5A<B`M<2!I;G-T86QL("U2("5[8G5I;&1R;V]T?2`M;B!P86-K86=E0'!A
M8VMA9V4R>&UL0"YX;6P-"B-M:V1I<B`M<"`E>V)U:6QD<F]O='U`<G!M7WAM
M;%]D:7)`#0HC8W`@+7`@<&%C:V%G94!P86-K86=E,GAM;$`N>&UL("5[8G5I
M;&1R;V]T?4!R<&U?>&UL7V1I<D`O0'!A8VMA9V5`+GAM;`T*#0HE9FEL97,-
M"B`@("`E9&5F871T<B@M+')O;W0L<F]O="D-"B`@("`E9&]C($!D;V-?9FEL
M97-`#0H@("`@+PT*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D871A+U!%05(O<&%C:V%G
M92YD=&0`````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-C0V
M(#$P-3$U-#,T,3,S(#`R,C(R-0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\(2TM#0H@("`@("1)9#H@<&%C:V%G92YD=&0L
M=B`Q+C,X(#(P,#4O,3$O,3(@,#(Z,C,Z,#<@8V5L;&]G($5X<"`D#0H-"B`@
M("`@5&AI<R!I<R!T:&4@4$5!4B!P86-K86=E(&1E<V-R:7!T:6]N+"!V97)S
M:6]N(#$N,"X-"B`@("`@270@<VAO=6QD(&)E('5S960@=VET:"!T:&4@:6YF
M;W)M86P@<'5B;&EC(&ED96YT:69I97(Z#0H-"B`@("`@("`@("(M+R]02%`@
M1W)O=7`O+T141"!014%2(%!A8VMA9V4@,2XP+R]%3B\O6$U,(@T*#0H@("`@
M($-O<'ER:6=H="`H8RD@,3DY-RTR,#`U(%1H92!02%`@1W)O=7`@("`@("`@
M("`@("`@#0H-"B`@("`@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,RXP,"!O9B!T:&4@4$A0(&QI8V5N<V4L#0H@("`@('1H870@
M:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%
M3E-%+"!A;F0@:7,-"B`@("`@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O
M<FQD+7=I9&4M=V5B(&%T#0H@("`@(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N(`T*("`@("!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@
M8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\-"B`@
M("`@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\-"B`@("`@;&EC96YS94!P:'`N;F5T('-O('=E
M(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H-"B`@("`@075T
M:&]R<SH-"B`@("`@("`@(%-T:6<@4RX@0F%K:V5N(#QS<V)`9F%S="YN;SX-
M"B`@("`@("`@($=R96=O<GD@0F5A=F5R(#QC96QL;V=`<&AP+FYE=#X-"@T*
M("`M+3X-"CPA14Y42519("4@3E5-0D52(")#1$%402(^#0H\(45,14U%3E0@
M<&%C:V%G92`H;F%M92QS=6UM87)Y+&1E<V-R:7!T:6]N+&QI8V5N<V4_+&UA
M:6YT86EN97)S+')E;&5A<V4L8VAA;F=E;&]G/RD^#0H\(4%45$Q)4U0@<&%C
M:V%G92!T>7!E("`@("AS;W5R8V5\8FEN87)Y?&5M<'1Y*2`B96UP='DB#0H@
M("`@("`@("`@("`@("`@("!V97)S:6]N($-$051!("`@("`@("`@("`@("`@
M("`C4D5154E2140-"B`@("`@("`@("`@("`@("`@('!A8VMA9V5R=F5R<VEO
M;B!#1$%402`@("`@("`@("-)35!,245$/@T*#0H\(45,14U%3E0@;F%M92`H
M(U!#1$%402D^#0H-"CPA14Q%345.5"!S=6UM87)Y("@C4$-$051!*3X-"@T*
M/"%%3$5-14Y4(&QI8V5N<V4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@9&5S
M8W)I<'1I;VX@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@;6%I;G1A:6YE<G,@
M*&UA:6YT86EN97(I*SX-"@T*/"%%3$5-14Y4(&UA:6YT86EN97(@*'5S97)\
M<F]L97QN86UE?&5M86EL*2L^#0H-"CPA14Q%345.5"!U<V5R("@C4$-$051!
M*3X-"@T*/"%%3$5-14Y4(')O;&4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@
M96UA:6P@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@8VAA;F=E;&]G("AR96QE
M87-E*2L^#0H-"CPA14Q%345.5"!R96QE87-E("AV97)S:6]N+&1A=&4L;&EC
M96YS92QS=&%T92QN;W1E<RQW87)N:6YG<S\L<')O=FED97,J+&1E<',_+&-O
M;F9I9W5R96]P=&EO;G,_+&9I;&5L:7-T/RD^#0H-"CPA14Q%345.5"!V97)S
M:6]N("@C4$-$051!*3X-"@T*/"%%3$5-14Y4(&1A=&4@*"-00T1!5$$I/@T*
M#0H\(45,14U%3E0@<W1A=&4@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@;F]T
M97,@*"-00T1!5$$I/@T*#0H\(45,14U%3E0@=V%R;FEN9W,@*"-00T1!5$$I
M/@T*#0H\(45,14U%3E0@9&5P<R`H9&5P*BD^#0H-"CPA14Q%345.5"!D97`@
M*"-00T1!5$$I/@T*/"%!5%1,25-4(&1E<"!T>7!E("`@("AP:V=\97AT?'!H
M<"D@(U)%455)4D5$#0H)("`@("`@("`@("`@("`@("`@("`@("!R96P@("`@
M("AH87-\97%\;'1\;&5\9W1\9V4I("`@("`@("`@("`@("`@("`@("`@("`@
M("`C24U03$E%1`T*"2`@("`@("`@("`@("`@("`@("`@("`@=F5R<VEO;B!#
M1$%402`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C24U0
M3$E%1`T*"2`@("`@("`@("`@("`@("`@("`@("`@;W!T:6]N86P@*'EE<WQN
M;RD@("`@("=N;R<^#0H-"CPA14Q%345.5"!C;VYF:6=U<F5O<'1I;VYS("AC
M;VYF:6=U<F5O<'1I;VXI*SX-"@T*/"%%3$5-14Y4(&-O;F9I9W5R96]P=&EO
M;B!%35!463X-"CPA05143$E35"!C;VYF:6=U<F5O<'1I;VX@;F%M92!#1$%4
M02`C4D5154E2140-"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!D969A=6QT($-$051!("-)35!,245$#0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<')O;7!T($-$051!
M("-215%525)%1#X-"@T*/"%%3$5-14Y4('!R;W9I9&5S($5-4%19/@T*/"%!
M5%1,25-4('!R;W9I9&5S('1Y<&4@*&5X='QP<F]G?&-L87-S?&9U;F-T:6]N
M?&9E871U<F5\87!I*2`C4D5154E2140-"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@;F%M92!#1$%402`C4D5154E2140-"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@97AT96YD<R!#1$%402`C24U03$E%1#X-
M"CPA14Q%345.5"!F:6QE;&ES="`H9&ER?&9I;&4I*SX-"@T*/"%%3$5-14Y4
M(&1I<B`H9&ER?&9I;&4I*SX-"CPA05143$E35"!D:7(@;F%M92`@("`@("`@
M("`@0T1!5$$@(U)%455)4D5$#0H@("`@("`@("`@("`@(')O;&4@("`@("`@
M("`@("AP:'!\97AT?'-R8WQT97-T?&1O8WQD871A?'-C<FEP="D@)W!H<"<-
M"B`@("`@("`@("`@("`@8F%S96EN<W1A;&QD:7(@0T1!5$$@(TE-4$Q)140^
M#0H-"CPA14Q%345.5"!F:6QE("AR97!L86-E*BD^#0H\(4%45$Q)4U0@9FEL
M92!R;VQE("`@("`@("`@("`H<&AP?&5X='QS<F-\=&5S='QD;V-\9&%T87QS
M8W)I<'0I("=P:'`G#0H@("`@("`@("`@("`@("!D96)U9R`@("`@("`@("`H
M;F%\;VY\;V9F*2`@("`@("`@)VYA)PT*("`@("`@("`@("`@("`@9F]R;6%T
M("`@("`@("`@0T1!5$$@("`@("`@("`@("`@("-)35!,245$#0H@("`@("`@
M("`@("`@("!B87-E:6YS=&%L;&1I<B!#1$%402`@("`@("`@("`@("`@(TE-
M4$Q)140-"B`@("`@("`@("`@("`@('!L871F;W)M("`@("`@($-$051!("`@
M("`@("`@("`@("`C24U03$E%1`T*("`@("`@("`@("`@("`@;60U<W5M("`@
M("`@("`@0T1!5$$@("`@("`@("`@("`@("-)35!,245$#0H@("`@("`@("`@
M("`@("!N86UE("`@("`@("`@("!#1$%402`@("`@("`@("`@("`@(U)%455)
M4D5$#0H@("`@("`@("`@("`@("!I;G-T86QL+6%S("`@("!#1$%402`@("`@
M("`@("`@("`@(TE-4$Q)140^#0H-"CPA14Q%345.5"!R97!L86-E($5-4%19
M/@T*/"%!5%1,25-4(')E<&QA8V4@='EP92`H<&AP+6-O;G-T?'!E87(M8V]N
M9FEG?'!A8VMA9V4M:6YF;RD@(U)%455)4D5$#0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!F<F]M($-$051!("-215%525)%1`T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=&\@0T1!5$$@(U)%455)4D5$/@T*#0H-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R](5%107U)E<75E
M<W0`````````````````````````````````````````````````````````
M```````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P
M,"`Q,#4Q-30S-#$S,B`P,C$V,C``(#4`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+T1"````````````````````````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,R(#`Q-S8Q-@`@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7U--5%``````````````````
M````````````````````````````````````````````````````````````
M,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q
M,S(@,#(P-S(R`"`U````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?
M4&%R<V5R````````````````````````````````````````````````````
M```````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,C$S,#4`(#4`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+TQO9P``````````````````````````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,R(#`R,#`U,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1&%T90``````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q,S(@,#(P,C`V`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R].971?55),````````````````````````````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,C`V,#$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+T%R8VAI=F5?5&%R````````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,R(#`R
M,34R,``@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4V5R=FEC97-?
M5V5A=&AE<@``````````````````````````````````````````````````
M````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P
M,#`@,3`U,34T,S0Q,S(@,#(R-3<S`"`U````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?571I;```````````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,C`W-C8`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,R(#`R,C$V,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!
M4```````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S(@,#(P,#<S`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R].971?1E10````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,R`P,C`U-S$`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]&5%`O97AA;7!L
M90``````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,S(#`R,C(R-``@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O3F5T7T944"]E>&%M<&QE+VEN9&5X+G!H<```````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,3(S,#,@,3`U,34T,S0Q,S,@,#(T,3(R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@HO*B!V:6TZ
M('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B
M<W1O<#TT.B`J+PH*+RHJ"B`J($YE=%]&5%`@9V5N97)A;"!E>&%M<&QE+@H@
M*@H@*B!'96YE<F%L(&5X86UP;&4@9FEL92!F;W(@=&AE('5S86=E(&]F($YE
M=%]&5%`N"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J($Q)0T5.
M4T4Z(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#,N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4*("H@=&AA="!I<R!A=F%I;&%B;&4@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@=&AE(&9O;&QO=VEN9R!54DDZ
M"B`J(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9@H@*B!T:&4@4$A0($QI8V5N
M<V4@86YD(&%R92!U;F%B;&4@=&\@;V)T86EN(&ET('1H<F]U9V@@=&AE('=E
M8BP@<&QE87-E"B`J('-E;F0@82!N;W1E('1O(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+@H@*@H@*B!`
M8V%T96=O<GD@("!.971W;W)K:6YG"B`J($!P86-K86=E("`@($944`H@*B!`
M875T:&]R("`@("!4;V)I87,@4V-H;&ET="`\=&]B>4!P:'`N;F5T/@H@*B!`
M8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`H@*B!`;&EC96YS
M92`@("!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT("!02%`@
M3&EC96YS92`S+C`*("H@0'9E<G-I;VX@("`@0U93.B`D260Z(&EN9&5X+G!H
M<"QV(#$N-"`R,#`U+S`R+S(S(#$R.C$R.C(S('1O8GD@17AP("0*("H@0&QI
M;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TYE=%]&5%`*
M("H@0'-I;F-E("`@("`@1FEL92!A=F%I;&%B;&4@<VEN8V4@4F5L96%S92`P
M+C`N,0H@*B\*"G)E<75I<F5?;VYC92`G3F5T+T944"YP:'`G.PIR97%U:7)E
M7V]N8V4@)U9A<E]$=6UP+G!H<"<["@HO*BH*("H@4V5T=&EN9R!U<"!T97-T
M('9A<FEA8FQE<RX@5&AE(&9O;&QO=VEN9R!V87)I86)L97,@:&%V92!T;R!B
M92!S970*("H@=7`L('1O('-U:71E('1H92!N965D<R!O9B!Y;W5R(&5N=FER
M;VYM96YT+@H@*B\*"B1H;W-T("`@("`@("`@("`]("<G.PHD<&]R="`@("`@
M("`@("`@/2`R,3L*)'5S97(@("`@("`@("`@(#T@)R<["B1P87-S("`@("`@
M("`@("`]("<G.PH*+R\@5&AE(&QO8V%L(&)A<V4@9&ER96-T;W)Y(&9O<B!&
M5%`@;W!E<F%T:6]N<RX*)&)A<V5$:7(@("`@("`@(#T@)RXO=&5S="\G.PHO
M+R!4:&4@9&ER96-T;W)Y('1O('5P;&]A9"!T;R!T:&4@1E10('-E<G9E<B!F
M;W(@=&5S=&EN9RX*)'1E<W15<$1I<B`@("`@(#T@)W1E<W1?=7`O)SL*+R\@
M5&AE(&1I<F5C=&]R>2!T;R!D;W=N;&]A9"!T;R!F;W(@=&5S=&EN9RX*)'1E
M<W1$;W=N1&ER("`@(#T@)W1E<W1?9&]W;B\G.PHO+R!4:&4@9FEL92!F;W(@
M<VEN9VQE(&9I;&4@=7`M(&%N9"!D;W=N;&]A9"!T97-T:6YG+@HD<VEN9VQE
M5&5S=$9I;&4@/2`G=&5S="YZ:7`G.PH*+R\@26YI=&EA;&EZ:6YG(%9A<E]6
M87)?1'5M<#HZ9&ES<&QA>0II9B`H:7-S970H)%]315)615(I*2!["B`@("`O
M+R!3971U<"!F;W(@9&ES<&QA>6EN9R!82%1-3"!O=71P=70N"B`@("!687)?
M1'5M<#HZ9&ES<&QA>4EN:70H87)R87DH"B`@("`@("`@)V1I<W!L87E?;6]D
M92<]/B=82%1-3%]497AT)PH@("`@*2P@87)R87DH"B`@("`@("`@)VUO9&4G
M/3XG;F]R;6%L)RP*("`@("`@("`G;V9F<V5T)ST^-`H@("`@*2D["B`@("`O
M+R!(96%D;&EN92!F=6YC=&EO;B!F;W(@6$A434P@;W5T<'5T+@H@("`@9G5N
M8W1I;VX@:&5A9"`H("1T97AT("D@>PH@("`@("`@(&5C:&\@)SQB<B`O/CQB
M/B<N)'1E>'0N)SPO8CX\8G(@+SXG.PH@("`@?0I](&5L<V4@>PH@("`@+R\@
M4V5T=7`@9F]R(&1I<W!L87EI;F<@8V]N<V]L92!O=71P=70N"B`@("!687)?
M1'5M<#HZ9&ES<&QA>4EN:70H87)R87DH)V1I<W!L87E?;6]D92<]/B=497AT
M)RDI.PH@("`@+R\@2&5A9&QI;F4@9G5N8W1I;VX@9F]R(%A(5$U,(&]U='!U
M="X*("`@(&9U;F-T:6]N(&AE860@*"`D=&5X="`I('L*("`@("`@("!E8VAO
M(")<;BTM+2`B+B1T97AT+B(@+2TM7&XB.PH@("`@?0I]"@IH96%D*")<)&9T
M<"`](&YE=R!.971?1E10*"D[(BD["B1F='`@/2!N97<@3F5T7T944"@I.PH*
M:&5A9"@B7"1F='`M/G-E=$AO<W1N86UE*"1H;W-T*2(I.PI687)?1'5M<#HZ
M9&ES<&QA>2@D9G1P+3YS971(;W-T;F%M92@D:&]S="DI.PH*:&5A9"@B7"1F
M='`M/G-E=%!O<G0H)'!O<G0I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M
M/G-E=%!O<G0H)'!O<G0I*3L*"FAE860H(EPD9G1P+3YC;VYN96-T*"1H;W-T
M+"`D<&]R="DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^8V]N;F5C="@I
M*3L*"FAE860H(EPD9G1P+3YS9715<V5R;F%M92@D=7-E<BDB*3L*5F%R7T1U
M;7`Z.F1I<W!L87DH)&9T<"T^<V5T57-E<FYA;64H)'5S97(I*3L*"FAE860H
M(EPD9G1P+3YS971087-S=V]R9"AX>'@I(BD["E9A<E]$=6UP.CID:7-P;&%Y
M*"1F='`M/G-E=%!A<W-W;W)D*"1P87-S*2D["@IH96%D*")<)&9T<"T^;&]G
M:6XH)'5S97(L('AX>"DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;&]G
M:6XH)'5S97(L("1P87-S*2D["@IH96%D*")<)&9T<"T^<'=D*"DB*3L*5F%R
M7T1U;7`Z.F1I<W!L87DH)&9T<"T^<'=D*"DI.PH*:&5A9"@B7"1F='`M/FQS
M*&YU;&PL($Y%5%]&5%!?1$E24U]&24Q%4RDB*3L*5F%R7T1U;7`Z.F1I<W!L
M87DH)&9T<"T^;',H;G5L;"P@3D547T944%]$25)37T9)3$53*2D["@IH96%D
M*")<)&9T<"T^;6MD:7(H)&)A<V5$:7(I(BD["E9A<E]$=6UP.CID:7-P;&%Y
M*"1F='`M/FUK9&ER*"1B87-E1&ER*2D["@IH96%D*")<)&9T<"T^8V0H)&)A
M<V5$:7(I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/F-D*"1B87-E1&ER
M*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D547T944%]205=,25-4*2(I
M.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107U)!
M5TQ)4U0I*3L*"FAE860H(EPD9G1P+3YP=70H)&)A<V5$:7(D<VEN9VQE5&5S
M=$9I;&4L("1S:6YG;&5497-T1FEL92DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH
M)&9T<"T^<'5T*"1B87-E1&ER+B1S:6YG;&5497-T1FEL92P@)'-I;F=L951E
M<W1&:6QE*2D["@IH96%D*")<)&9T<"T^;',H;G5L;"P@3D547T944%]&24Q%
M4U]/3DQ9*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.
M151?1E107T9)3$537T].3%DI*3L*"FAE860H(EPD9G1P+3YP=70H)&)A<V5$
M:7(D<VEN9VQE5&5S=$9I;&4L("1S:6YG;&5497-T1FEL92P@=')U92DB*3L*
M5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^<'5T*"1B87-E1&ER+B1S:6YG;&54
M97-T1FEL92P@)'-I;F=L951E<W1&:6QE+"!T<G5E*2D["@IH96%D*")<)&9T
M<"T^;',H;G5L;"P@3D547T944%]&24Q%4U]/3DQ9*2(I.PI687)?1'5M<#HZ
M9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107T9)3$537T].3%DI*3L*
M"FAE860H(EPD9G1P+3YM9'1M*"1S:6YG;&5497-T1FEL92P@)V0N;2Y9($@Z
M:3IS)RDB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;61T;2@D<VEN9VQE
M5&5S=$9I;&4L("=D+FTN62<I*3L*"FAE860H(EPD9G1P+3YS:7IE*"1S:6YG
M;&5497-T1FEL92DB*3L*5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^<VEZ92@D
M<VEN9VQE5&5S=$9I;&4I*3L*"FAE860H(EPD9G1P+3YG970H)'-I;F=L951E
M<W1&:6QE+"`D8F%S941I<B1S:6YG;&5497-T1FEL92P@=')U92DB*3L*5F%R
M7T1U;7`Z.F1I<W!L87DH)&9T<"T^9V5T*"1S:6YG;&5497-T1FEL92P@)&)A
M<V5$:7(N)'-I;F=L951E<W1&:6QE+"!T<G5E*2D["@IH96%D*")<)&9T<"T^
M8VAM;V0H)'-I;F=L951E<W1&:6QE+"`W,#`I(BD["E9A<E]$=6UP.CID:7-P
M;&%Y*"1F='`M/F-H;6]D*"1S:6YG;&5497-T1FEL92P@-S`P*2D["@IH96%D
M*")<)&9T<"T^;',H;G5L;"P@3D547T944%]&24Q%4U]/3DQ9*2(I.PI687)?
M1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107T9)3$537T].
M3%DI*3L*"FAE860H(EPD9G1P+3YC9"@G+BXO)RDB*3L*5F%R7T1U;7`Z.F1I
M<W!L87DH)&9T<"T^8V0H)RXN+R<I*3L*"FAE860H(EPD9G1P+3YC:&UO9%)E
M8W5R<VEV92@D8F%S941I<BP@-S<W*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D
M9G1P+3YC:&UO9%)E8W5R<VEV92@D8F%S941I<BP@-S<W*2D["@IH96%D*")<
M)&9T<"T^;',H;G5L;"P@3D547T944%]$25)37T].3%DI(BD["E9A<E]$=6UP
M.CID:7-P;&%Y*"1F='`M/FQS*&YU;&PL($Y%5%]&5%!?1$E24U]/3DQ9*2D[
M"@IH96%D*")<)&9T<"T^<'5T4F5C=7)S:79E*"1B87-E1&ER)'1E<W15<$1I
M<BP@)&)A<V5$:7(D=&5S=%5P1&ER*2(I.PI687)?1'5M<#HZ9&ES<&QA>2@D
M9G1P+3YP=71296-U<G-I=F4H)&)A<V5$:7(N)'1E<W15<$1I<BP@)&)A<V5$
M:7(N)'1E<W15<$1I<BDI.PH*:&5A9"@B7"1F='`M/G!U=%)E8W5R<VEV92@D
M8F%S941I<B1T97-T57!$:7(L("1B87-E1&ER)'1E<W15<$1I<BDB*3L*5F%R
M7T1U;7`Z.F1I<W!L87DH)&9T<"T^<'5T4F5C=7)S:79E*"1B87-E1&ER+B1T
M97-T57!$:7(L("1B87-E1&ER+B1T97-T57!$:7(L('1R=64I*3L*"FAE860H
M(EPD9G1P+3YC9"@D8F%S941I<CHD=&5S=%5P1&ER*2(I.PI687)?1'5M<#HZ
M9&ES<&QA>2@D9G1P+3YC9"@D8F%S941I<BXD=&5S=%5P1&ER*2D["@IH96%D
M*")<)&9T<"T^;',H;G5L;"P@3D547T944%]$25)37T9)3$53*2(I.PI687)?
M1'5M<#HZ9&ES<&QA>2@D9G1P+3YL<RAN=6QL+"!.151?1E107T1)4E-?1DE,
M15,I*3L*"FAE860H(EPD9G1P+3YC9"@N+B\N+B\I(BD["E9A<E]$=6UP.CID
M:7-P;&%Y*"1F='`M/F-D*"<N+B\N+B\G*2D["@IH96%D*")<)&9T<"T^9V5T
M4F5C=7)S:79E*"1B87-E1&ER)'1E<W15<$1I<BP@)&)A<V5$:7(D=&5S=$1O
M=VY$:7(I(BD["E9A<E]$=6UP.CID:7-P;&%Y*"1F='`M/F=E=%)E8W5R<VEV
M92@D8F%S941I<BXD=&5S=%5P1&ER+"`D8F%S941I<BXD=&5S=$1O=VY$:7(L
M('1R=64I*3L*"FAE860H(EPD9G1P+3YR;2@D8F%S941I<BP@=')U92DB*3L*
M5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^<FTH)&)A<V5$:7(L('1R=64I*3L*
M"FAE860H(EPD9G1P+3YL<RAN=6QL+"!.151?1E107T1)4E-?3TY,62DB*3L*
M5F%R7T1U;7`Z.F1I<W!L87DH)&9T<"T^;',H;G5L;"P@3D547T944%]$25)3
M7T].3%DI*3L*"FAE860H(EPD9G1P+3YD:7-C;VYN96-T*"DB*3L*5F%R7T1U
M;7`Z.F1I<W!L87DH)&9T<"T^9&ES8V]N;F5C="@I*3L*/SX*````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3F5T7T944"]E>&%M<&QE+V]B
M<V5R=F5R+G!H<```````````````````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3,P-S(@,3`U,34T
M,S0Q,S,@,#(T-C0V`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP#0H-"B\J('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30Z("HO#0H-"B\J*@T*
M("H@3F5T7T944"!O8G-E<G9E<B!E>&%M<&QE+@T*("H-"B`J($YE="!&5%`@
M3V)S97)V97(@97AA;7!L92!T;R!U<V4@=VET:"!(5$U,7U!R;V=R97-S('!A
M8VMA9V4-"B`J("A02%`@-"`^/2!02%`@-"XS+C`I#0H@*@T*("H@4$A0('9E
M<G-I;VYS(#0@86YD(#4-"B`J#0H@*B!,24-%3E-%.B!4:&ES('-O=7)C92!F
M:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L:6-E
M;G-E#0H@*B!T:&%T(&ES(&%V86EL86)L92!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="!T:&4@9F]L;&]W:6YG(%5223H-"B`J(&AT='`Z+R]W=W<N
M<&AP+FYE="]L:6-E;G-E+S-?,"YT>'0N("!)9B!Y;W4@9&ED(&YO="!R96-E
M:79E(&$@8V]P>2!O9@T*("H@=&AE(%!(4"!,:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O(&]B=&%I;B!I="!T:')O=6=H('1H92!W96(L('!L96%S90T*("H@
M<V5N9"!A(&YO=&4@=&\@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL
M('EO=2!A(&-O<'D@:6UM961I871E;'DN#0H@*@T*("H@0&-A=&5G;W)Y("`@
M3F5T=V]R:VEN9PT*("H@0'!A8VMA9V4@("`@1E10#0H@*B!`875T:&]R("`@
M("!4;V)I87,@4V-H;&ET="`\=&]B>4!P:'`N;F5T/@T*("H@0&%U=&AO<B`@
M("`@3&%U<F5N="!,879I;&QE(#QP96%R0&QA=7)E;G0M;&%V:6QL92YO<F<^
M#0H@*B!`8V]P>7)I9VAT("`Q.3DW+3(P,#4@5&AE(%!(4"!'<F]U<`T*("H@
M0&QI8V5N<V4@("`@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,U\P+G1X
M="`@4$A0($QI8V5N<V4@,RXP#0H@*B!`=F5R<VEO;B`@("!#5E,Z("1)9#H@
M;V)S97)V97(N<&AP+'8@,2XR(#(P,#4O,#(O,C,@,3(Z,3(Z,C,@=&]B>2!%
M>'`@)`T*("H@0&QI;FL@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+TYE=%]&5%`-"B`J($!L:6YK("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92](5$U,7U!R;V=R97-S#0H@*B!`<VEN8V4@("`@("!&:6QE
M(&%V86EL86)L92!S:6YC92!296QE87-E(#$N,RXP#0H@*B\-"@T*<F5Q=6ER
M95]O;F-E("=.970O1E10+G!H<"<[#0IR97%U:7)E7V]N8V4@)TYE="]&5%`O
M3V)S97)V97(N<&AP)SL-"G)E<75I<F5?;VYC92`G2%1-3"]0<F]G<F5S<RYP
M:'`G.PT*#0HO*BH-"B`J($EN:71I86QI>FEN9R!T97-T('9A<FEA8FQE<R`H
M<F5Q=6ER960A*0T*("HO#0HD9G1P(#T@87)R87DH#0H@("`@)VAO<W0G(#T^
M("<G+`T*("`@("=P;W)T)R`]/B`R,2P-"B`@("`G=7-E<B<@/3X@)R<L#0H@
M("`@)W!A<W,G(#T^("<G#0HI.R`@("`-"@T*)&1E<W0@/2`G=&UP)SL@("`@
M("`@("`@("`@("`@("`@+R\@=&AI<R!D:7)E8W1O<GD@;75S="!E>&ES=',@
M:6X@>6]U<B!F='`@<V5R=F5R("$-"B1O=F5R=W)I=&4@/2!T<G5E.R`@("`@
M("`@("`@("`@("\O(&]V97)W<FET92!A;&P@97AI<W1I;F<@9FEL97,@;VX@
M=&AE(&9T<"!S97)V97(-"B1F:6QE<R`](&%R<F%Y*`T*("`@("=(5$U,7U!R
M;V=R97-S+3$N,BXP+G1G>B<L#0H@("`@)W!H<#1E=F5R+G!N9R<@("`@("`@
M("`@("`@("`O+R!I;FET:6%L:7II;F<@8V]N=&5N=',@*')E<75I<F5D(2D@
M9FEL92AS*2!M=7-T(&5X:7-T<PT**3L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@9FEL92AS*2!T;R!U<&QO860-"@T*#0HO+PT*+R\@,2X@
M1&5F:6YE<R!T:&4@1E10+U!R;V=R97-S($]B<V5R=F5R(`T*+R\-"F-L87-S
M($]B<V5R=F5R7U!R;V=R97-S57!L;V%D(&5X=&5N9',@3F5T7T944%]/8G-E
M<G9E<@T*>PT*("`@('9A<B`D<')O9W)E<W,[#0H-"B`@("!F=6YC=&EO;B!/
M8G-E<G9E<E]0<F]G<F5S<U5P;&]A9"@F)'!R;V=R97-S*0T*("`@('L-"B`@
M("`@("`@+RH@0V%L;"!T:&4@8F%S92!C;&%S<R!C;VYS=')U8W1O<BX@*B\-
M"B`@("`@("`@<&%R96YT.CI.971?1E107T]B<V5R=F5R*"D[#0H-"B`@("`@
M("`@+RHJ#0H@("`@("`@("`@($-O;F9I9W5R92!T:&4@;V)S97)V97(Z#0H@
M("`@("`@("`@(`T*("`@("`@("`@("!"92!S=7)E('1O(&AA=F4@86X@:6YD
M971E<FUI;F%T92!P<F]G<F5S<R!M971E<B!W:&5N#0H@("`@("`@("`@($!L
M:6YK(&AT='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN9G1P
M+6YB+7!U="YP:'`-"B`@("`@("`@("`@<W1O<F5S(&$@9FEL92!O;B!T:&4@
M1E10('-E<G9E<B`H;F]N+6)L;V-K:6YG*0T*("`@("`@("`@*B\-"B`@("`@
M("`@)'1H:7,M/G!R;V=R97-S(#TF("1P<F]G<F5S<SL-"B`@("`@("`@)'1H
M:7,M/G!R;V=R97-S+3YS971);F1E=&5R;6EN871E*'1R=64I.PT*("`@('T-
M"@T*("`@(&9U;F-T:6]N(&YO=&EF>2@D979E;G0I#0H@("`@>PT*("`@("`@
M("`D=&AI<RT^<')O9W)E<W,M/F1I<W!L87DH*3L-"B`@("`@("`@)'1H:7,M
M/G!R;V=R97-S+3YS;&5E<"@I.PT*("`@("`@("`@("`@("`@("`-"B`@("`@
M("`@:68@*"1T:&ES+3YP<F]G<F5S<RT^9V5T4&5R8V5N=$-O;7!L971E*"D@
M/3T@,2D@>PT*("`@("`@("`@("`@)'1H:7,M/G!R;V=R97-S+3YS971686QU
M92@P*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("1T:&ES+3YP
M<F]G<F5S<RT^:6YC5F%L=64H*3L-"B`@("`@("`@?0T*("`@('T-"GT-"@T*
M+R\-"B\O(#(N(&1E9FEN97,@=&AE('!R;V=R97-S(&UE=&5R(`T*+R\-"B1M
M971E<B`](&YE=R!(5$U,7U!R;V=R97-S*"D[#0HD=6D@/2`F("1M971E<BT^
M9V5T54DH*3L-"B1U:2T^<V5T4')O9W)E<W-!='1R:6)U=&5S*&%R<F%Y*`T*
M("`@("=B86-K9W)O=6YD+6-O;&]R)R`]/B`G(V4P93!E,"<-"BDI.R`@("`@
M("`@#0HD=6DM/G-E=%-T<FEN9T%T=')I8G5T97,H87)R87DH#0H@("`@)V-O
M;&]R)R`@/3X@)R,Y.38G+`T*("`@("=B86-K9W)O=6YD+6-O;&]R)R`]/B`G
M(T-#0T,Y.2<-"BDI.R`@("`@("`@#0HD=6DM/G-E=$-E;&Q!='1R:6)U=&5S
M*&%R<F%Y*`T*("`@("=A8W1I=F4M8V]L;W(G(#T^("<C.3DV)PT**2D[#0H-
M"B1M971E<BT^<V5T06YI;5-P965D*#(P,"D[#0HD;65T97(M/G-E=$EN8W)E
M;65N="@Q,"D[#0HD;65T97(M/G-E=%-T<FEN9U!A:6YT960H=')U92D[("`@
M("`O+R!G970@<W!A8V4@9F]R('1H92!S=')I;F<-"B1M971E<BT^<V5T4W1R
M:6YG*"(B*3L@("`@("`@("`@("`@("\O(&)U="!D;VXG="!P86EN="!I=`T*
M)&UE=&5R+3YS971);F1E=&5R;6EN871E*'1R=64I.R`@("`@+R\@<')O9W)E
M<W,@;65T97(@<W1A<G0@:6X@:6YD971E<FUI;F%T92!M;V1E#0H_/@T*/"%$
M3T-465!%(&AT;6P@4%5"3$E#("(M+R]7,T,O+T141"!82%1-3"`Q+C`@5')A
M;G-I=&EO;F%L+R]%3B(-"B`@("`B:'1T<#HO+W=W=RYW,RYO<F<O5%(O>&AT
M;6PQ+T141"]X:'1M;#$M=')A;G-I=&EO;F%L+F1T9"(^#0H\:'1M;"!X;6QN
M<STB:'1T<#HO+W=W=RYW,RYO<F<O,3DY.2]X:'1M;"(^#0H\:&5A9#X-"CQT
M:71L93Y&5%`O4')O9W)E<W,@3V)S97)V97(@97AA;7!L93PO=&ET;&4^#0H\
M<W1Y;&4@='EP93TB=&5X="]C<W,B/@T*/"$M+0T*8F]D>2![#0H@("`@8F%C
M:V=R;W5N9"UC;VQO<CH@(T-#0T,Y.3L-"B`@("!C;VQO<CH@(SDY-CL-"B`@
M("!F;VYT+69A;6EL>3H@5F5R9&%N82P@07)I86P[#0I]#0H-"CP_<&AP(&5C
M:&\@)&UE=&5R+3YG9713='EL92@I.R`_/@T*+R\@+2T^#0H\+W-T>6QE/@T*
M/'-C<FEP="!T>7!E/2)T97AT+VIA=F%S8W)I<'0B/@T*/"$M+0T*/#]P:'`@
M96-H;R`D;65T97(M/F=E=%-C<FEP="@I.R`_/@T*+R\M+3X-"CPO<V-R:7!T
M/@T*/"]H96%D/@T*/&)O9'D^#0H-"CP_<&AP(`T*96-H;R`D;65T97(M/G1O
M2'1M;"@I.PT*0'-E=%]T:6UE7VQI;6ET*#`I.R`@+R\@=6YL:6UI=&5D('1I
M;64@;W!E<F%T:6]N("AR96UO=F5D(#,P<R!D969A=6QT(')E<W1R:6-T:6]N
M*0T*#0HD9B`](&YE=R!.971?1E10*"D[#0H-"B\O#0HO+R`S+B!C;VYN96-T
M('1O('1H92!&5%`@<V5R=F5R(`T*+R\-"B1R970@/2`D9BT^8V]N;F5C="@D
M9G1P6R=H;W-T)UTL("1F='!;)W!O<G0G72D[#0II9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5T*2D@>PT*("`@(&1I92@D<F5T+3YG971-97-S86=E*"DI.PT*?0T*
M<')I;G1F*"=C;VYN96-T960@870@/&(^)7,\+V(^/&)R("\^)RP@)&9T<%LG
M:&]S="==*3L-"@T*+R\-"B\O(#0N(&QO9VEN('1O('1H92!&5%`@<V5R=F5R
M(&%S(&$@=V5L;"UK;F]W;B!U<V5R#0HO+PT*)')E="`]("1F+3YL;V=I;B@D
M9G1P6R=U<V5R)UTL("1F='!;)W!A<W,G72D[#0II9B`H4$5!4CHZ:7-%<G)O
M<B@D<F5T*2D@>PT*("`@("1F+3YD:7-C;VYN96-T*"D[#0H@("`@9&EE*"1R
M970M/F=E=$UE<W-A9V4H*2D[#0I]#0IP<FEN=&8H)VQO9VEN(&%S(#QB/B5S
M/"]B/CQB<B`O/B<L("1F='!;)W5S97(G72D[#0H-"B\O#0HO+R`U+B!C:&%N
M9V5S(&1I<F5C=&]R>2!T;R!F:6YA;"!D97-T:6YA=&EO;B!F;W(@=7!L;V%D
M(&]P97)A=&EO;@T*+R\-"B1R970@/2`D9BT^8V0H)&1E<W0I.PT*:68@*%!%
M05(Z.FES17)R;W(H)')E="DI('L-"B`@("`D9BT^9&ES8V]N;F5C="@I.PT*
M("`@(&1I92@D<F5T+3YG971-97-S86=E*"DI.PT*?0T*#0HO+PT*+R\@-BX@
M871T86-H<R!A;B!I;G-T86YC92!O9B!T:&4@1E10+U!R;V=R97-S('-U8F-L
M87-S(&]B<V5R=F5R#0HO+PT*)&]B<V5R=F5R(#T@;F5W($]B<V5R=F5R7U!R
M;V=R97-S57!L;V%D*"1M971E<BD[#0HD;VL@/2`D9BT^871T86-H*"1O8G-E
M<G9E<BD[#0II9B`H(21O:RD@>PT*("`@(&1I92@G8V%N;F]T(&%T=&%C:"!A
M($944"!/8G-E<G9E<B<I.PT*?0T*#0HO+PT*+R\@-RX@;6]V97,@9FEL97,@
M;VX@=&AE($944"!S97)V97(-"B\O#0IF;W)E86-H*"1F:6QE<R!A<R`D9FEL
M92D@>PT*("`@("1R970@/2`D9BT^<'5T*"1F:6QE+"!B87-E;F%M92@D9FEL
M92DL("1O=F5R=W)I=&4I.PT*("`@(&EF("A014%2.CII<T5R<F]R*"1R970I
M*2![#0H@("`@"6EF("@H)')E="T^9V5T0V]D92@I(#T]($Y%5%]&5%!?15)2
M7T]615)74DE415)%34]4149)3$5?1D]20DE$1$5.*2!A;F0@*"$D;W9E<G=R
M:71E*2D@>PT*("`@(`D@("`@<')I;G1F*"<E<R`\8G(@+SXG+"`D<F5T+3YG
M971-97-S86=E*"DI.PT*("`@(`D@("`@8V]N=&EN=64[("`O+R!I="!I<R!J
M=7-T(&$@=V%R;FEN9R!W:&5N(%PD;W9E<G=R:71E('9A<FEA8FQE(&ES('-E
M="!T;R!F86QS90T*("`@(`E]#0H@("`@("`@(&1I92@D<F5T+3YG971-97-S
M86=E*"DI.PT*("`@('T-"B`@("!P<FEN=&8H)SQB/B5S/"]B/B!T<F%N<V9E
M<B!C;VUP;&5T960@/&)R("\^)RP@8F%S96YA;64H)&9I;&4I*3L-"GT-"B1F
M+3YD971A8V@H)&]B<V5R=F5R*3L-"@T*+R\-"B\O(#@N(&-H96-K<R!I9B!F
M:6QE<R!A<F4@<F5A;&QY(&]N('1H92!&5%`@<V5R=F5R#0HO+PT*)')E="`]
M("1F+3YL<RAN=6QL+"!.151?1E107U)!5TQ)4U0I.PT*:68@*%!%05(Z.FES
M17)R;W(H)')E="DI('L-"B`@("`D9BT^9&ES8V]N;F5C="@I.PT*("`@(&1I
M92@D<F5T+3YG971-97-S86=E*"DI.PT*?0T*<')I;G0@)SQP<F4^)SL-"G9A
M<E]D=6UP*"1R970I.PT*<')I;G0@)SPO<')E/B<[#0H-"B\O#0HO+R`Y+B!S
M87ES(&=O;V1B>64@=&\@=&AE($944"!S97)V97(@(0T*+R\-"B1F+3YD:7-C
M;VYN96-T*"D[#0IE8VAO("=$;VYE(2<[#0H_/@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?1E10+V5X86UP;&4O97AT96YS
M:6]N<RYI;FD````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(Q,R`Q,#4Q-30S-#$S
M,R`P,C4R,#$`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````.R!4:&ES(&9I;&4@8V%N(&1E=&5R;6EN92!F:6QE+65X=&5N<VEO
M;B!A;F0@=V5T:&5R('1O('1R86YS9F5R('1H96T@:6X@"CL@8FEN87)Y+2!O
M<B!A<V-I:2UM;V1E+B!4:&4@='=O(&1I9F9E<F5N="!V86QU97,@9F]R(&9I
M;&4M;6]D97,@87)E.@H["CL@1E107T%30TE)("AW:&EC:"!E<75A;',@,"D*
M.R!&5%!?0DE.05)9("AW:&EC:"!E<75A;',@,2D*.PH[(%1H:7,@9FEL92!W
M:6QL(&)E(&1I<F5C=&QY('!A<G-E9"!B>2!P87)S95]I;FE?9FEL92@I+"!S
M;R!B97=A<F4@;V8@;6%K:6YG(&UI<W1A:V5S"CL@:6YS:61E('1H:7,@9FEL
M92P@;W(@>6]U<B!A<'!L:6-A=&EO;B!M87D@8W)A<V@L(&5V97)Y=&EM92!Y
M;W4@<&%R<V4@>6]U<B!F:6QE+@H["CL@66]U(&-A;B!H879E(&UO<F4@=&AA
M;B`Q(&9I;&4@8V]N=&%I;FEN9R!E>'1E;G-I;VXM<V5T=&EN9W,L(&9O<B!D
M:69F97)E;G0@:VEN9',@;V8*.R!A<'!L:6-A=&EO;BP@<V5R=F5R(&]R(&-A
M<V4N($)U="!B97=A<F4L(&EF('EO=2=V92!P87)S960@82!F:6QE(&EN=&\@
M>6]U<B!.971?1E10+6]B:F5C="P*.R!A;F0@869T97(@=&AA="!Y;W4@<&%R
M<V4@86YO=&AE<B!F:6QE+"!T:&4@;VQD('-E='1I;F=S('=I;&P@8F4@;W9E
M<G=R:71E;B$*.PH[($%30TE)+45X=&5N<VEO;G,Z"@I;05-#24E="@IA<V,@
M/2`P"F%S8W@@/2`P"F%S<"`](#`*87-P>"`](#`*8F%S(#T@,`IB87-H(#T@
M,`IB870@/2`P"F,@/2`P"F-F8R`](#`*8V9M(#T@,`IC9VD@/2`P"F-L87-S
M(#T@,`IC;VYF(#T@,`IC<W,@/2`P"F@@/2`P"FAH8R`](#`*:&AK(#T@,`IH
M<'`@/2`P"FAT82`](#`*:'1M(#T@,`IH=&UL(#T@,`II;F,@/2`P"FYF;R`]
M(#`*:6YI(#T@,`II;F8@/2`P"FIA=B`](#`*:F%V82`](#`*:G,@/2`P"FIS
M<"`](#`*;&]G(#T@,`IN9F\@/2`P"G!A<R`](#`*<&AP(#T@,`IP:'`S(#T@
M,`IP:'`T(#T@,`IP:'1M;"`](#`*<&P@/2`P"G-V9R`](#`*<V@@/2`P"G-H
M=&UL(#T@,`IT8VP@/2`P"G1E>'0@/2`P"G1X="`](#`*=F(@/2`P"G9B<R`]
M(#`*=VUL(#T@,`IX:'1M(#T@,`IX:'1M;"`](#`*>&UL(#T@,`IX<V0@/2`P
M"GAS;"`](#`*>'-L(#T@,`IX<VQT(#T@,`IX=6P@/2`P"@H[($))3D%262U%
M>'1E;G-I;VYS"@I;0DE.05)970H*:G!G(#T@,0IG:68@/2`Q"F)M<"`](#$`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+U-/05`O97AA;7!L90``````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,S(#`R,34R-P`@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V%T=&%C:&UE;G0N<&AP
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$U,C4@,3`U,34T,S0Q,S(@,#(T
M-#4Q`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_<&AP"G)E<75I<F5?;VYC92@B4T]!4"]#;&EE;G0N<&AP(BD["G)E<75I
M<F5?;VYC92@B4T]!4"]T97-T+W1E<W0N=71I;&ET>2YP:'`B*3L*<F5Q=6ER
M95]O;F-E*")33T%0+U9A;'5E+G!H<"(I.PH*)&9I;&5N86UE(#T@)V%T=&%C
M:&UE;G0N<&AP)SL*)'8@/2`@;F5W(%-/05!?071T86-H;65N="@G=&5S="<L
M)W1E>'0O<&QA:6XG+"1F:6QE;F%M92D["B1M971H;V1686QU92`](&YE=R!3
M3T%07U9A;'5E*"=T97-T871T86-H)RP@)U-T<G5C="<L(&%R<F%Y*"1V*2D[
M"@HD8VQI96YT(#T@;F5W(%-/05!?0VQI96YT*"=M86EL=&\Z=7-E<D!D;VUA
M:6XN8V]M)RD["B,@8V%L;&EN9R!W:71H(&UI;64*)')E<W`@/2`D8VQI96YT
M+3YC86QL*"=E8VAO36EM94%T=&%C:&UE;G0G+&%R<F%Y*"1V*2P*("`@("`@
M("`@("`@("`@(&%R<F%Y*"=A='1A8VAM96YT<R<]/B=-:6UE)RP*("`@("`@
M("`@("`@("`@("=N86UE<W!A8V4G/3XG:'1T<#HO+W-O87!I;G1E<F]P+F]R
M9R\G+`H@("`@("`@("`@("`@("`@)V9R;VTG/3XG=7-E<D!D;VUA:6XN8V]M
M)RP*("`@("`@("`@("`@("`@("=H;W-T)ST^)W-M='`N9&]M86EN+F-O;2<I
M*3L*<')I;G0@)&-L:65N="T^=VER92XB7&Y<;EQN(CL*<')I;G1?<B@D<F5S
M<"D["@HC(&-A;&QI;F<@=VET:"!$24U%"B1R97-P(#T@)&-L:65N="T^8V%L
M;"@G96-H;TUI;65!='1A8VAM96YT)RQA<G)A>2@D=BDI.PHC($1)344@:&%S
M(&YU;&P@<W!A8V5S+"!C:&%N9V4@=&AE;2!S;R!W92!C86X@<V5E('1H92!W
M:7)E"B1W:7)E(#T@<W1R7W)E<&QA8V4H(EPP(BPG*B<L)&-L:65N="T^=VER
M92D["G!R:6YT("1W:7)E+B)<;EQN7&XB.PIP<FEN=%]R*"1R97-P*3L*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+V-O;5]C;&EE
M;G0N<&AP````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0R,C8@,3`U,34T,S0Q
M,S(@,#(T-#,V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P
M,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES
M('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H
M92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I
M=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@
M("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H
M='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@
M<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA
M8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW
M:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H
M86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@8V]M
M7V-L:65N="YP:'`L=B`Q+C,@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@
M17AP("0*+R\*+R\@4T]!4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F;VQL
M;W=I;F<@9FEL90IR97%U:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP)SL*
M"B\J(&IU<W0@82!S:6UP;&4@97AA;7!L92!O9B!U<VEN9R!-4R!33T%0(&]N
M('=I;C,R(&%S(&$@8VQI96YT"B`@('1O('1H92!P:'`@<V5R=F5R+B`@*B\*
M"B\O;&]A9"!#3TT@4T]!4"!C;&EE;G0@;V)J96-T"B1S;V%P8VQI96YT(#T@
M;F5W($-/32@B35-33T%0+E-O87!#;&EE;G0S,"(I.PH*+R]C;VYN96-T('1O
M('=E8B!S97)V:6-E"B1S;V%P8VQI96YT+3YM<W-O87!I;FET*")H='1P.B\O
M;&]C86QH;W-T+U-/05`O97AA;7!L92]S97)V97(N<&AP/W=S9&PB*3L*"B\O
M;V)T86EN(')E<W5L="!F<F]M('=E8B!S97)V:6-E(&UE=&AO9`HD<F5T(#T@
M)'-O87!C;&EE;G0M/F5C:&]3=')I;F<H(E1H:7,@:7,@82!T97-T(2(I.PIP
M<FEN="@B)')E=%QN(BD["@HD<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')I
M;F=3:6UP;&4H(E1H:7,@:7,@86YO=&AE<B!T97-T(2(I.PIP<FEN="@B)')E
M=%QN(BD["@HC('1H92!F;VQL;W=I;F<@8V%U<V5S(&%N(&5X8V5P=&EO;B!I
M;B!T:&4@0T]-(&5X=&5N<VEO;@H*(R1R970@/2`D<V]A<&-L:65N="T^9&EV
M:61E*#(R+#<I.PHC<')I;G0@)'-O87!C;&EE;G0M/F9A=6QT8V]D93L*(W!R
M:6YT("1S;V%P8VQI96YT+3YF875L='-T<FEN9SL*(W!R:6YT*"(R,B\W/21R
M971<;B(I.PHC<')I;G1?<B@D<F5T*3L*(R1R970@/2`D<V]A<&-L:65N="T^
M9&EV:61E*#(R+#`I.PHC<')I;G0H(C(R+S`])')E=%QN(BD["@HC)'-T<G5C
M="`](&YE=R!33T%04W1R=6-T*"=T97-T('-T<FEN9R<L,3(S+#$R,RXQ,C,I
M.PHC)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R=6-T*"1S=')U8W0I.PHC
M<')I;G1?<B@D<F5T*3L*"B,D<F5T(#T@)'-O87!C;&EE;G0M/F5C:&]3=')U
M8W1!<U-I;7!L951Y<&5S*"1S=')U8W0I.PHC<')I;G1?<B@D<F5T*3L*"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M
M<&QE+V1I<V-O7W-E<G9E<BYP:'``````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C(R
M,#`@,3`U,34T,S0Q,S(@,#(U,#`Q`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<CH@1&UI=')I(%9I
M;F]G<F%D;W8@/&1I;6ET<FE`=FEN;V=R861O=BYD93X@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@9&ES8V]?<V5R=F5R+G!H<"QV(#$N-2`R,#`U+S`S+S$P(#(S.C$V
M.C0P('EU;F]S:"!%>'`@)`H*+RH*("!4:&ES(&5X86UP;&4@<VAO=W,@:&]W
M('1O(&UA<FL@=7`@82!S97)V97(@;V)J96-T('-O('1H870*("!W<V1L(&9I
M;&5S(&UA>2!B92!D>6YA;6EC86QY(&=E;F5R871E9"!B>2!T:&4@<V]A<`H@
M('-E<G9E<BX@(%1H:7,@86QS;R!P<F]V:61E<R!A8V-E<W,@=&\@82!G96YE
M<F%T960@1$E30T\@9&]C=6UE;G0N"B`@5&AE(&9A8W0@=&AA="!T:&ES(&5X
M86UP;&4@:&%S(&%N($U0,R!C;&%S<R!I<R!I;B!N;R!W87D*("!R96QA=&5D
M('1O($1)4T-/+B`[*0H@(`H@($1)4T-/.B!H='1P.B\O;7-D;BYM:6-R;W-O
M9G0N8V]M+VUS9&YM86<O:7-S=65S+S`R+S`R+WAM;"]D969A=6QT+F%S<'@*
M("`*("!!('5R;"!A8V-E<W-I;F<@=&AI<R!S97)V97(@=V]U;&0@;&]O:R!L
M:6ME.@H@(`H@(&AT='`Z+R]L;V-A;&AO<W0O9&ES8V]?<V5R=F5R+G!H<#]W
M<V1L("AG96YE<F%T92!74T1,(&9I;&4I"B`@:'1T<#HO+VQO8V%L:&]S="]D
M:7-C;U]S97)V97(N<&AP("A'150@<F5Q=65S="!G96YE<F%T97,@1$E30T\I
M"B`@:'1T<#HO+VQO8V%L:&]S="]D:7-C;U]S97)V97(N<&AP("A03U-4(&9O
M<B!N;W)M86P@<V]A<"!R97%U97-T<RD**B\*"F5R<F]R7W)E<&]R=&EN9RA%
M7T%,3"D["G)E<75I<F5?;VYC92`G4T]!4"]397)V97(N<&AP)SL*"F-L87-S
M($U0,T1"7T-L87-S('L*("`@('9A<B`D7U]D:7-P871C:%]M87`@/2!A<G)A
M>2@I.PH@("`@=F%R("1?7W1Y<&5D968@("`@(#T@87)R87DH*3L*("`@(`H@
M("`@9G5N8W1I;VX@35`S1$)?0VQA<W,@*"D@>PH@("`@("`@("\J*@H@("`@
M("`@("H@=&AE(&]N;'D@=V%Y('1O(&1E<V-R:6)E(&%L;"!M971H;V1S(&EN
M(%=31$P@*&UE<W-A9V5S+`H@("`@("`@("H@4&]R=%1Y<&4M;W!E<F%T:6]N
M<R!A;F0@8FEN9&EN9W,I(&ES('1O('5S92!?7V1I<W!A=&-H7VUA<`H@("`@
M("`@("H@=&\@9&5S8W)I8F4@979E<GD@;65T:&]D("AE=F5N(&UE=&AO9',@
M=7-I;F<@<VEM<&QE(&1A=&$@"B`@("`@("`@*B!T>7!E<R!I;B`G:6XG(&%N
M9"`G;W5T)R!P87)A;65T97)S+BXN*0H@("`@("`@("HO"B`@("`@("`@"B`@
M("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=387E(86QL;R==(#T*("`@
M("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@
M("`@)VEN)R`]/B!A<G)A>2@G:6YP=70G(#T^("=S=')I;F<G*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@)V]U="<@/3X@87)R87DH)W)E='5R;B<@/3X@
M)W-T<FEN9R<I"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@
M("`@("`@("`*("`@("`@("`D=&AI<RT^7U]D:7-P871C:%]M87!;)U-A>51H
M:7-.5&EM97,G72`]"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@
M("`@("`@("`@("`@("`@("`@("=I;B<@/3X@87)R87DH)U-A>51H:7,G/3XG
M<W1R:6YG)RPG3E1I;65S)R`]/B`G:6YT)RDL"B`@("`@("`@("`@("`@("`@
M("`@("`@("=O=70G(#T^(&%R<F%Y*"=R971U<FXG(#T^("=[=7)N.DU0,T1"
M?4%R<F%Y3V93=')I;F=S)RD*("`@("`@("`@("`@("`@("`@("`I.PH@("`@
M("`@("`@("`@("`@("`@(`H@("`@("`@("1T:&ES+3Y?7V1I<W!A=&-H7VUA
M<%LG1V5T35`S5')A8VMS)UT@/0H@("`@("`@("`@("`@("`@("`@(&%R<F%Y
M*`H@("`@("`@("`@("`@("`@("`@("`@("`G:6XG(#T^(&%R<F%Y*"=Q=65R
M>2<@/3X@)W-T<FEN9R<I+`H@("`@("`@("`@("`@("`@("`@("`@("`G;W5T
M)R`]/B!A<G)A>2@G<F5T=7)N)R`]/B`G>W5R;CI-4#-$0GU'971-4#-4<F%C
M:W-297-U;'0G*0H@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@
M("`@("`@("`@"B`@("`@("`@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R=!9&1-
M4#-4<F%C:R==(#T*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@)VEN)R`]/B!A<G)A>2@G35`S5')A8VLG(#T^
M("=[=7)N.DU0,T1"?4U0,U1R86-K)RDL"B`@("`@("`@("`@("`@("`@("`@
M("`@("=O=70G(#T^(&%R<F%Y*"=R971U<FXG(#T^("=[=7)N.DU0,T1"?4%D
M9$U0,U1R86-K4F5S=6QT)RD*("`@("`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`O*BH*("`@("`@("`J($D@=7-E(%]?='EP961E9B!T;R!D97-C<FEB
M92!U<V5R9&5F:6YE9"!4>7!E<R!I;B!74T1,+@H@("`@("`@("H@4W1R=6-T
M<R!A;F0@;VYE+61I;65N<VEO;F%L(&%R<F%Y<R!A<F4@<W5P<&]R=&5D.@H@
M("`@("`@("H@4W1R=6-T(&5X86UP;&4Z("1T:&ES+3Y?7W1Y<&5D969;)U1Y
M<&5.86UE)UT@/2!A<G)A>2@G5F%R3F%M92<@/3X@)WAS9%1Y<&4G+"`N+BX@
M*3L*("`@("`@("`J("`@(&]R("1T:&ES+3Y?7W1Y<&5D969;)U1Y<&5.86UE
M)UT@/2!A<G)A>2@G5F%R3F%M92<@/3X@)WMN86UE<W!A8V5]4V]M94]T:&5R
M5'EP92<I.PH@("`@("`@("H@07)R87D@97AA;7!L93H@)'1H:7,M/E]?='EP
M961E9ELG5'EP94YA;64G72`](&%R<F%Y*&%R<F%Y*"=I=&5M)R`]/B`G>'-D
M5'EP92<I*3L*("`@("`@("`J("`@(&]R("1T:&ES+3Y?7W1Y<&5D969;)U1Y
M<&5.86UE)UT@/2!A<G)A>2AA<G)A>2@G:71E;2<@/3X@)WMN86UE<W!A8V5]
M4V]M94]T:&5R5'EP92<I*3L*("`@("`@("`J+PH@("`@"B`@("`@("`@+RHJ
M"B`@("`@("`@*B!3=')U8W0@)TU0,U1R86-K)PH@("`@("`@("HO"B`@("`@
M("`@)'1H:7,M/E]?='EP961E9ELG35`S5')A8VLG72`](`H@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`G5&ET
M;&4G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G07)T
M:7-T)R`]/B`G<W1R:6YG)RP@"B`@("`@("`@("`@("`@("`@("`@("`@("=!
M;&)U;2<@/3X@)W-T<FEN9R<L(`H@("`@("`@("`@("`@("`@("`@("`@("`G
M665A<B<@/3X@)VEN="<L(`H@("`@("`@("`@("`@("`@("`@("`@("`G1V5N
M<F4G(#T^("=I;G0G+`H@("`@("`@("`@("`@("`@("`@("`@("`G0V]M;65N
M="<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=#;VUP
M;W-E<B<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@("`@("=/
M<FEG7T%R=&ES="<@/3X@)W-T<FEN9R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("=54DPG(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G16YC;V1E9%]B>2<@/3X@)W-T<FEN9R<*("`@("`@("`@("`@("`@("`@
M("`I.PH@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@("`@
M(`H@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("H@
M35`S5')A8VMS07)R87D@+2!A<G)A>2!O9B`G35`S5')A8VLG('-T<G5C=',*
M("`@("`@("`J+PH@("`@("`@("1T:&ES+3Y?7W1Y<&5D969;)TU0,U1R86-K
M<T%R<F%Y)UT@/2`*("`@("`@("`@("`@("`@("`@("!A<G)A>2@*("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:71E;2<@/3X@)WMU<FXZ35`S1$)]35`S5')A8VLG"B`@("`@
M("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`I.PH@
M("`@("`@("`@("`@("`@("`@(`H@("`@("`@("\J*@H@("`@("`@("H@4W1R
M=6-T("=-971H;V1$96)U9R<*("`@("`@("`J+PH@("`@("`@("1T:&ES+3Y?
M7W1Y<&5D969;)TUE=&AO9$1E8G5G)UT@/2`*("`@("`@("`@("`@("`@("`@
M("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)W)C)R`]/B`G8F]O
M;&5A;B<L"B`@("`@("`@("`@("`@("`@("`@("`@("=%<G).;R<@/3X@)VEN
M="<L(`H@("`@("`@("`@("`@("`@("`@("`@("`G17)R;W(G(#T^("=S=')I
M;F<G"B`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@("`@
M("`*("`@("`@("`O*BH*("`@("`@("`J(')E='5R;B!3=')U8W0@;V8@;65T
M:&]D($=E=$U0,U1R86-K<PH@("`@("`@("HO"B`@("`@("`@)'1H:7,M/E]?
M='EP961E9ELG1V5T35`S5')A8VMS4F5S=6QT)UT@/2`*("`@("`@("`@("`@
M("`@("`@("!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@)TUE=&AO
M9$1E8G5G)R`]/B`G>W5R;CI-4#-$0GU-971H;V1$96)U9R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("=-4#-4<F%C:W,G(#T^("=[=7)N.DU0,T1"?4U0
M,U1R86-K<T%R<F%Y)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@
M("`@("`@("`@("`@"B`@("`@("`@+RHJ"B`@("`@("`@*B!R971U<FX@4W1R
M=6-T(&]F(&UE=&AO9"!!9&1-4#-4<F%C:PH@("`@("`@("HO"B`@("`@("`@
M)'1H:7,M/E]?='EP961E9ELG061D35`S5')A8VM297-U;'0G72`](`H@("`@
M("`@("`@("`@("`@("`@(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`G365T:&]D1&5B=6<G(#T^("=[=7)N.DU0,T1"?4UE=&AO9$1E8G5G)PH@
M("`@("`@("`@("`@("`@("`@("D["B`@("`@("`@("`@("`@("`@("`@"B`@
M("`@("`@+RHJ"B`@("`@("`@*B!!<G)A>2!O9B!S=')I;F=S"B`@("`@("`@
M*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F6R=!<G)A>4]F4W1R:6YG<R==
M(#T@"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y*"=I=&5M)ST^)W-T<FEN9R<I"B`@("`@("`@("`@
M("`@("`@("`@*3L*("`@(`H@("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N
M(%-A>4AA;&QO*"1N86UE*2!["B`@("`@("`@<F5T=7)N(")(86QL;RP@(B`N
M("1N86UE.PH@("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N(%-A>51H:7-.
M5&EM97,H)%-A>51H:7,L)$Y4:6UE<RD@>PH@("`@("`@(&9O<B`H)&D@/2`P
M.R`D:2`\("1.5&EM97,[("1I*RLI('L*("`@("`@("`@("`@)')E='5R;ELD
M:5T@/2`D4V%Y5&AI<R`N("(@)&DB.PH@("`@("`@('T*("`@("`@("!R971U
M<FX@;F5W(%-/05!?5F%L=64H)W)E='5R;B<L)WMU<FXZ35`S1$)]07)R87E/
M9E-T<FEN9W,G+"1R971U<FXI.PH@("`@?0H@("`@"B`@("`*("`@(&9U;F-T
M:6]N($=E=$U0,U1R86-K<R@D<75E<GD@/2`B(BD@>PH@("`@("`@(&9O<B@D
M:2`](#`[("1I(#P@-3L@)&DK*RD@>PH@("`@("`@("`@("`D=&AI<RT^35`S
M5')A8VMS6R1I72`](&YE=R!33T%07U9A;'5E*`H@("`@("`@("`@("`@("`@
M("`@("=I=&5M)RP*("`@("`@("`@("`@("`@("`@("`G>W5R;CI-4#-$0GU-
M4#-4<F%C:R<L"B`@("`@("`@("`@("`@("`@("`@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@("`@(")4:71L92(@("`@("`@("`]/B!N97<@4T]!4%]6
M86QU92@B5&ET;&4B+")S=')I;F<B+")S;VUE('1R86-K("1I(BDL"B`@("`@
M("`@("`@("`@("`@("`@("`@(")!<G1I<W0B("`@("`@("`]/B!N97<@4T]!
M4%]686QU92@B07)T:7-T(BPB<W1R:6YG(BPB<V]M92!A<G1I<W0@)&DB*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(D%L8G5M(B`@("`@("`@(#T^(&YE
M=R!33T%07U9A;'5E*")!;&)U;2(L(G-T<FEN9R(L(G-O;64@86QB=6T@)&DB
M*2P*("`@("`@("`@("`@("`@("`@("`@("`@(EEE87(B("`@("`@("`@(#T^
M(&YE=R!33T%07U9A;'5E*")996%R(BPB:6YT(BPH:6YT96=E<BDQ.3DY*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(D=E;G)E(B`@("`@("`@(#T^(&YE
M=R!33T%07U9A;'5E*")'96YR92(L(FEN="(L*&EN=&5G97(I,3`P*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@(D-O;6UE;G0B("`@("`@(#T^(&YE=R!3
M3T%07U9A;'5E*")#;VUM96YT(BPB<W1R:6YG(BPB8FQA8FQA("1I(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@(")#;VUP;W-E<B(@("`@("`]/B!N97<@
M4T]!4%]686QU92@B0V]M<&]S97(B+")S=')I;F<B+"(B*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@(D]R:6=?07)T:7-T(B`@(#T^(&YE=R!33T%07U9A
M;'5E*")/<FEG7T%R=&ES="(L(G-T<FEN9R(L(B(I+`H@("`@("`@("`@("`@
M("`@("`@("`@("`B55),(B`@("`@("`@("`@/3X@;F5W(%-/05!?5F%L=64H
M(E523"(L(G-T<FEN9R(L(B(I+`H@("`@("`@("`@("`@("`@("`@("`@("`B
M16YC;V1E9%]B>2(@("`@/3X@;F5W(%-/05!?5F%L=64H(D5N8V]D961?8GDB
M+")S=')I;F<B+"(B*0H@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@
M("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`D365T
M:&]D1&5B=6=;(G)C(ET@("`@/2!N97<@4T]!4%]686QU92@B<F,B+")B;V]L
M96%N(BQT<G5E*3L*("`@("`@("`D365T:&]D1&5B=6=;(D5R<DYO(ET@/2!N
M97<@4T]!4%]686QU92@B17)R3F\B+")I;G0B+"AI;G1E9V5R*3`I.PH@("`@
M("`@("1-971H;V1$96)U9ULB17)R;W(B72`](&YE=R!33T%07U9A;'5E*")%
M<G)O<B(L(G-T<FEN9R(L(B(I.PH@("`@("`@("`@("`*("`@("`@("!R971U
M<FX@;F5W(%-/05!?5F%L=64H)W)E='5R;B<L)WMU<FXZ35`S1$)]1V5T35`S
M5')A8VMS4F5S=6QT)RQA<G)A>2@*("`@("`@("`@("`@("`@("`@("`B365T
M:&]D1&5B=6<B(#T^(&YE=R!33T%07U9A;'5E*"=-971H;V1$96)U9R<L)WMU
M<FXZ35`S1$)]365T:&]D1&5B=6<G+"1-971H;V1$96)U9RDL"B`@("`@("`@
M("`@("`@("`@("`@(DU0,U1R86-K<R(@("`]/B!N97<@4T]!4%]686QU92@G
M35`S5')A8VMS)RPG>W5R;CI-4#-$0GU-4#-4<F%C:W-!<G)A>2<L)'1H:7,M
M/DU0,U1R86-K<RD*("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@
M("`@("`I.PH@("`@?0H@("`@"B`@("`*("`@(&9U;F-T:6]N($%D9$U0,U1R
M86-K*"1-4#-4<F%C:RD@>PH@("`@("`@(",@=V5L;"P@;&5T<R!I;6%G:6YE
M(&AE<F4@<V]M92!C;V1E(&9O<B!A9&1I;F<@9VEV96X@;7`S=')A8VL@=&\@
M9&(@;W(@=VAA=&5V97(N+BX*("`@("`@("`D365T:&]D1&5B=6=;(G)C(ET@
M("`@/2!N97<@4T]!4%]686QU92@B<F,B+")B;V]L96%N(BQT<G5E*3L*("`@
M("`@("`D365T:&]D1&5B=6=;(D5R<DYO(ET@/2!N97<@4T]!4%]686QU92@B
M17)R3F\B+")I;G0B+"AI;G1E9V5R*3`I.PH@("`@("`@("1-971H;V1$96)U
M9ULB17)R;W(B72`](&YE=R!33T%07U9A;'5E*")%<G)O<B(L(G-T<FEN9R(L
M(B(I.PH@("`@("`@(`H@("`@("`@(')E='5R;B!N97<@4T]!4%]686QU92@G
M<F5T=7)N)RPG>W5R;CI-4#-$0GU!9&1-4#-4<F%C:U)E<W5L="<L87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@(DUE=&AO9$1E8G5G(B`]/B!N97<@4T]!
M4%]686QU92@G365T:&]D1&5B=6<G+"=[=7)N.DU0,T1"?4UE=&AO9$1E8G5G
M)RPD365T:&]D1&5B=6<I"B`@("`@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`@("`@*3L*("`@('T*("`@(`H@("`@"B`@("!F=6YC=&EO;B!?7V1I
M<W!A=&-H*"1M971H;V1N86UE*2!["B`@("`@("`@:68@*&ES<V5T*"1T:&ES
M+3Y?7V1I<W!A=&-H7VUA<%LD;65T:&]D;F%M95TI*0H@("`@("`@("`@("!R
M971U<FX@)'1H:7,M/E]?9&ES<&%T8VA?;6%P6R1M971H;V1N86UE73L*("`@
M("`@("!R971U<FX@3E5,3#L*("`@('T*?0H*)'-E<G9E<B`](&YE=R!33T%0
M7U-E<G9E<CL*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PHD
M35`S1$)?0VQA<W,@/2!N97<@35`S1$)?0VQA<W,H*3L*)'-E<G9E<BT^861D
M3V)J96-T36%P*"1-4#-$0E]#;&%S<RPG=7)N.DU0,T1")RD["@H*:68@*&ES
M<V5T*"1?4T525D526R=215%515-47TU%5$A/1"==*2`F)@H@("`@)%]315)6
M15);)U)%455%4U1?34542$]$)UT]/2=03U-4)RD@>PH@("`@)'-E<G9E<BT^
M<V5R=FEC92@D2%144%]205=?4$]35%]$051!*3L*?2!E;'-E('L*("`@(')E
M<75I<F5?;VYC92`G4T]!4"]$:7-C;RYP:'`G.PH@("`@)&1I<V-O(#T@;F5W
M(%-/05!?1$E30T]?4V5R=F5R*"1S97)V97(L(DU0,T1"(BD["B`@("!H96%D
M97(H(D-O;G1E;G0M='EP93H@=&5X="]X;6PB*3L*("`@(&EF("AI<W-E="@D
M7U-%4E9%4ELG455%4EE?4U1224Y')UTI("8F"B`@("`@("!S=')C87-E8VUP
M*"1?4T525D526R=1545265]35%))3D<G72PG=W-D;"<I/3TP*2!["B`@("`@
M("`@96-H;R`D9&ES8V\M/F=E=%=31$PH*3L*("`@('T@96QS92!["B`@("`@
M("`@96-H;R`D9&ES8V\M/F=E=$1)4T-/*"D["B`@("!]"B`@("!E>&ET.PI]
M"C\^````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]E;6%I;%]C;&EE;G0N<&AP
M`````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,S(R(#$P-3$U-#,T,3,R(#`R-#<T
M,P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!0
M2%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@
M9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI
M8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@
M<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*
M+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@
M870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W
M=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@
M82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@
M('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L
M('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS
M94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E
M;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A
M=F5O+F-O;3X@("!0;W)T('1O(%!%05(@86YD(&UO<F4@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z(&5M86EL7V-L:65N
M="YP:'`L=B`Q+C0@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*
M+R\*"B\J"E1H:7,@<F5A9',@82!M97-S86=E(&9R;VT@<W1D:6XL(&%N9"!C
M86QL<R!T:&4@<V]A<"!S97)V97(@9&5F:6YE9`H*66]U(&-A;B!U<V4@=&AI
M<R!F<F]M('%M86EL(&)Y(&-R96%T:6YG(&$@+G%M86EL+7-O87!T97-T(&9I
M;&4@=VET:#H*("`@('P@+W5S<B]B:6XO<&AP("]P871H+W1O+V5M86EL7W-E
M<G9E<BYP:'`**B\*"B,@:6YC;'5D92!T:&4@96UA:6P@<V5R=F5R(&-L87-S
M"G)E<75I<F5?;VYC92`G4T]!4"]397)V97(O16UA:6PN<&AP)SL*"B1S97)V
M97(@/2!N97<@4T]!4%]397)V97)?16UA:6P["@HC(')E860@<W1D:6X*)&9I
M;B`](&9O<&5N*"=P:'`Z+R]S=&1I;B<L)W)B)RD["FEF("@A)&9I;BD@97AI
M="@P*3L*"B1E;6%I;"`]("<G.PIW:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A
M=&$@/2!F<F5A9"@D9FEN+"`X,#DV*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*
M?0H*9F-L;W-E*"1F:6XI.PH*"B1R97-P;VYS92`]("1S97)V97(M/F-L:65N
M="@D96UA:6PI.PH*<')I;G1?<B@D<F5S<&]N<V4I.PH*/SX`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]33T%0+V5X86UP;&4O96UA:6Q?9V%T97=A>2YP:'``````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,S0W,R`Q,#4Q-30S-#$S,B`P,C4Q,S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E
M<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R
M;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@
M:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E
M+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA
M9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@
M879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP
M+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P
M>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O
M('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A
M<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP
M+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC
M;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]G871E=V%Y+G!H
M<"QV(#$N-2`R,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*
M+RH*5&AI<R!R96%D<R!A(&UE<W-A9V4@9G)O;2!S=&1I;BP@86YD('!A<W-E
M<R!T:&4@<F5Q=65S="!T;PIA('-O87`@<V5R=F5R(')E<VED:6YG(&]N(&$@
M=V5B('-E<G9E<BP@<V5N9',@=&AE(')E<W!O;G-E"F]U="!A<R!A;B!E;6%I
M;`H*66]U(&-A;B!U<V4@=&AI<R!F<F]M('%M86EL(&)Y(&-R96%T:6YG(&$@
M+G%M86EL+7-O87!G871E=V%Y(&9I;&4@=VET:#H*("`@('P@+W5S<B]B:6XO
M<&AP("]P871H+W1O+V5M86EL7W-E<G9E<BYP:'`**B\*"B,@:6YC;'5D92!T
M:&4@96UA:6P@<V5R=F5R(&-L87-S"G)E<75I<F5?;VYC92`G4T]!4"]397)V
M97(O16UA:6Q?1V%T97=A>2YP:'`G.PH*(R!R96%D('-T9&EN"B1F:6X@/2!F
M;W!E;B@G<&AP.B\O<W1D:6XG+"=R8B<I.PII9B`H(21F:6XI(&5X:70H,"D[
M"@HD96UA:6P@/2`G)SL*=VAI;&4@*"%F96]F*"1F:6XI("8F("1D871A(#T@
M9G)E860H)&9I;BP@.#`Y-BDI('L*("`D96UA:6P@+CT@)&1A=&$["GT*"F9C
M;&]S92@D9FEN*3L*"B,@9&]I="$*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E
M<E]%;6%I;%]'871E=V%Y*"D["B1S97)V97(M/G-E<G9I8V4H)&1A=&$L("=H
M='1P.B\O;&]C86QH;W-T+W-O87`O97AA;7!L92]S97)V97(N<&AP)RD["C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O4T]!4"]E>&%M<&QE+V5M86EL7W!O<%]G871E=V%Y+G!H<```````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#4P,#,@,3`U,34T,S0Q,S(@,#(V,#`R`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\O"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N
M(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U
M8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@
M("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN
M('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL
M86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O
M;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@
M=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B
M=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E
M;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@
M<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@
M("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@
M(%!O<G0@=&\@4$5!4B!A;F0@;6]R92`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@96UA:6Q?<&]P7V=A=&5W87DN<&AP
M+'8@,2XV(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO
M*B!I;F-L=61E('1H92!%;6%I;"!S97)V97(@8VQA<W,L('=H:6-H(&MN;W=S
M(&AO=R!T;PH@("!P87)S92!A('-T86YD87)D(&5M86EL(&%S(&$@<V]A<"!M
M97-S86=E("HO"@IR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+T5M86EL7T=A
M=&5W87DN<&AP)SL*"B\J(&EN8VQU9&4@82!C;&%S<R!T;R!A8V-E<W,@4$]0
M,R`J+PH*<F5Q=6ER95]O;F-E("=.970O4$]0,RYP:'`G.PH*+RH@8W)E871E
M('1H92!33T%0(%-E<G9E<B!O8FIE8W0@*B\*"B1S97)V97(@/2!N97<@4T]!
M4%]397)V97)?16UA:6Q?1V%T97=A>2@G:'1T<#HO+VQO8V%L:&]S="]S;V%P
M7VEN=&5R;W`O<V5R=F5R7W)O=6YD,BYP:'`G*3L*"B\J('1E;&P@<V5R=F5R
M('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@:68@<&]S<VEB
M;&4@*B\*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E.PH*<F5Q
M=6ER95]O;F-E("=E>&%M<&QE7W-E<G9E<BYP:'`G.PH*)'-O87!C;&%S<R`]
M(&YE=R!33T%07T5X86UP;&5?4V5R=F5R*"D["B1S97)V97(M/F%D9$]B:F5C
M=$UA<"@D<V]A<&-L87-S+"=U<FXZ4T]!4%]%>&%M<&QE7U-E<G9E<B<I.PH*
M"B\J($-O;FYE8W0@=&\@82!03U`S('-E<G9E<B!A;F0@<F5A9"!T:&4@;65S
M<V%G97,@*B\*"B1P;W`S(#TF(&YE=R!.971?4$]0,R@I.PII9B`H)'!O<#,M
M/F-O;FYE8W0H)VQO8V%L:&]S="<L(#$Q,"DI('L*("`@(&EF("@D<&]P,RT^
M;&]G:6XH)W5S97)N86UE)RP@)W!A<W-W;W)D)RDI('L*("`@("`@("`D;&ES
M=&EN9R`]("1P;W`S+3YG971,:7-T:6YG*"D["@H)+RH@;F]W(&QO;W`@=&AR
M;W5G:"!E86-H(&UE<W-A9V4L(&%N9"!C86QL('1H92`*("`@("`@("`@("!3
M3T%0('-E<G9E<B!W:71H('1H870@;65S<V%G92`J+PH*("`@("`@("!F;W)E
M86-H("@D;&ES=&EN9R!A<R`D;7-G*2!["@H@("`@("`@("`@("`D96UA:6P@
M/2`D<&]P,RT^9V5T37-G*"1M<V=;)VUS9U]I9"==*3L*"B`@("`@("`@("`@
M("\J('1H:7,@:7,@=VAE<F4@=V4@86-T=6%L;'D@:&%N9&QE('1H92!33T%0
M"B`@("`@("`@("`@("`@(')E<W!O;G-E+B`@5&AE(%-/05`Z.E-E<G9E<CHZ
M16UA:6P@8VQA<W,@=V4*("`@("`@("`@("`@("`@87)E('5S:6YG('=I;&P@
M<V5N9"!T:&4@4T]!4"!R97-P;VYS92!T;R`*("`@("`@("`@("`@("`@=&AE
M('-E;F1E<B!V:6$@96UA:6PN("HO"@H@("`@("`@("`@("!I9B`H)&5M86EL
M*2`D<V5R=F5R+3YS97)V:6-E*"1E;6%I;"D["@H@("`@("`@("`@("`C)'!O
M<#,M/F1E;&5T94US9R@D;7-G6R=M<V=?:60G72D["B`@("`@("`@?0H@("`@
M?0H@("`@)'!O<#,M/F1I<V-O;FYE8W0H*3L*?0H_/@H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]33T%0+V5X86UP
M;&4O96UA:6Q?<&]P7W-E<G9E<BYP:'``````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-#<T
M,2`Q,#4Q-30S-#$S,B`P,C4V-3<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+R\*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@
M0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N
M9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!E;6%I;%]P;W!?<V5R=F5R+G!H<"QV(#$N-B`R,#`U+S`S+S$P
M(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PH*+RH@:6YC;'5D92!T:&4@16UA
M:6P@<V5R=F5R(&-L87-S+"!W:&EC:"!K;F]W<R!H;W<@=&\*("`@<&%R<V4@
M82!S=&%N9&%R9"!E;6%I;"!A<R!A('-O87`@;65S<V%G92`J+PH*<F5Q=6ER
M95]O;F-E("=33T%0+U-E<G9E<B]%;6%I;"YP:'`G.PH*+RH@:6YC;'5D92!A
M(&-L87-S('1O(&%C8V5S<R!03U`S("HO"@IR97%U:7)E7V]N8V4@)TYE="]0
M3U`S+G!H<"<["@HO*B!C<F5A=&4@=&AE(%-/05`@4V5R=F5R(&]B:F5C="`J
M+PH*)'-E<G9E<B`](&YE=R!33T%07U-E<G9E<E]%;6%I;#L*"B\J('1E;&P@
M<V5R=F5R('1O('1R86YS;&%T92!T;R!C;&%S<V5S('=E('!R;W9I9&4@:68@
M<&]S<VEB;&4@*B\*)'-E<G9E<BT^7V%U=&]?=')A;G-L871I;VX@/2!T<G5E
M.PH*<F5Q=6ER95]O;F-E("=E>&%M<&QE7W-E<G9E<BYP:'`G.PH*)'-O87!C
M;&%S<R`](&YE=R!33T%07T5X86UP;&5?4V5R=F5R*"D["B1S97)V97(M/F%D
M9$]B:F5C=$UA<"@D<V]A<&-L87-S+"=U<FXZ4T]!4%]%>&%M<&QE7U-E<G9E
M<B<I.PH*"B\J($-O;FYE8W0@=&\@82!03U`S('-E<G9E<B!A;F0@<F5A9"!T
M:&4@;65S<V%G97,@*B\*"B1P;W`S(#TF(&YE=R!.971?4$]0,R@I.PII9B`H
M)'!O<#,M/F-O;FYE8W0H)VQO8V%L:&]S="<L(#$Q,"DI('L*("`@(&EF("@D
M<&]P,RT^;&]G:6XH)W5S97)N86UE)RP@)W!A<W-W;W)D)RDI('L*("`@("`@
M("`D;&ES=&EN9R`]("1P;W`S+3YG971,:7-T:6YG*"D["@H)+RH@;F]W(&QO
M;W`@=&AR;W5G:"!E86-H(&UE<W-A9V4L(&%N9"!C86QL('1H92`*("`@("`@
M("`@("!33T%0('-E<G9E<B!W:71H('1H870@;65S<V%G92`J+PH*("`@("`@
M("!F;W)E86-H("@D;&ES=&EN9R!A<R`D;7-G*2!["@H@("`@("`@("`@("`D
M96UA:6P@/2`D<&]P,RT^9V5T37-G*"1M<V=;)VUS9U]I9"==*3L*"B`@("`@
M("`@("`@("\J('1H:7,@:7,@=VAE<F4@=V4@86-T=6%L;'D@:&%N9&QE('1H
M92!33T%0"B`@("`@("`@("`@("`@(')E<W!O;G-E+B`@5&AE(%-/05`Z.E-E
M<G9E<CHZ16UA:6P@8VQA<W,@=V4*("`@("`@("`@("`@("`@87)E('5S:6YG
M('=I;&P@<V5N9"!T:&4@4T]!4"!R97-P;VYS92!T;R`*("`@("`@("`@("`@
M("`@=&AE('-E;F1E<B!V:6$@96UA:6PN("HO"@H@("`@("`@("`@("!I9B`H
M)&5M86EL*2!["B`@("`@("`@("`@("`@("`D<V5R=F5R+3YC;&EE;G0H)&5M
M86EL*3L*"B`@("`@("`@("`@("`@("`D<&]P,RT^9&5L971E37-G*"1M<V=;
M)VUS9U]I9"==*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@
M("1P;W`S+3YD:7-C;VYN96-T*"D["GT*/SX*````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]33T%0+V5X86UP;&4O96UA:6Q?<V5R=F5R+G!H<```````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,S8U,"`Q,#4Q-30S-#$S,B`P,C0W-S<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`*+R\*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@4&]R
M="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!E;6%I;%]S97)V97(N<&AP+'8@,2XU(#(P
M,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO*@I4:&ES(')E
M861S(&$@;65S<V%G92!F<F]M('-T9&EN+"!A;F0@8V%L;',@=&AE('-O87`@
M<V5R=F5R(&1E9FEN960*"EEO=2!C86X@=7-E('1H:7,@9G)O;2!Q;6%I;"!B
M>2!C<F5A=&EN9R!A("YQ;6%I;"US;V%P=&5S="!F:6QE('=I=&@Z"B`@("!\
M("]U<W(O8FEN+W!H<"`O<&%T:"]T;R]E;6%I;%]S97)V97(N<&AP"BHO"@HC
M(&EN8VQU9&4@=&AE(&5M86EL('-E<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@
M)U-/05`O4V5R=F5R+T5M86EL+G!H<"<["@HD<V5R=F5R(#T@;F5W(%-/05!?
M4V5R=F5R7T5M86EL.PH*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O
M(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?
M875T;U]T<F%N<VQA=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP
M;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L
M95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L
M)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@HC(')E860@<W1D:6X*)&9I
M;B`](&9O<&5N*"=P:'`Z+R]S=&1I;B<L)W)B)RD["FEF("@A)&9I;BD@97AI
M="@P*3L*"B1E;6%I;"`]("<G.PIW:&EL92`H(69E;V8H)&9I;BD@)B8@)&1A
M=&$@/2!F<F5A9"@D9FEN+"`X,#DV*2D@>PH@("1E;6%I;"`N/2`D9&%T83L*
M?0H*9F-L;W-E*"1F:6XI.PH*(R!D;VET(0HD<V5R=F5R+3YS97)V:6-E*"1E
M;6%I;"D["@H_/@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!
M4"]E>&%M<&QE+V5X86UP;&5?<V5R=F5R+G!H<```````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,30R-34@,3`U,34T,S0Q,S(@,#(U,S0V`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z
M(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@97AA;7!L95]S97)V97(N<&AP+'8@,2XU(#(P,#4O
M,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D"B\O"@HO+R!F:7)S="P@:6YC
M;'5D92!T:&4@4T]!4"]397)V97(@8VQA<W,*<F5Q=6ER95]O;F-E("=33T%0
M+U9A;'5E+G!H<"<["G)E<75I<F5?;VYC92`G4T]!4"]&875L="YP:'`G.PH*
M+R\@4T]!4%-T<G5C="!I<R!D969I;F5D(&EN('1H92!F;VQL;W=I;F<@9FEL
M90IR97%U:7)E7V]N8V4@)V5X86UP;&5?='EP97,N<&AP)SL*"B\O(&-R96%T
M92!A(&-L87-S(&9O<B!Y;W5R('-O87`@9G5N8W1I;VYS"F-L87-S(%-/05!?
M17AA;7!L95]397)V97(@>PH@("`@+RHJ"B`@("`@*B!4:&4@9&ES<&%C=&-H
M(&UA<"!D;V5S(&YO="!N965D('1O(&)E('5S960L(&)U="!A:61S"B`@("`@
M*B!T:&4@<V5R=F5R(&-L87-S(&EN(&MN;W=I;F<@=VAA="!P87)A;65T97)S
M(&%R92!U<V5D"B`@("`@*B!W:71H('1H92!F=6YC=&EO;G,N("!4:&ES(&ES
M('1H92!/3DQ9('=A>2!T;R!H879E"B`@("`@*B!M=6QT:7!L92!/550@<&%R
M86UE=&5R<RX@($EF('EO=2!U<V4@82!D:7-P871C:"!M87`L('EO=0H@("`@
M("H@35535"!A9&0@04Q,(&9U;F-T:6]N<R!Y;W4@=VES:"!T;R!A;&QO=R!B
M92!C86QL960N("!)9@H@("`@("H@>6]U(&1O(&YO="!U<V4@82!D:7-P871C
M:"!M87`L('1H96X@86YY('!U8FQI8R!F=6YC=&EO;@H@("`@("H@8V%N(&)E
M(&-A;&QE9"!F<F]M('-O87`@*&EN('!H<#0L('=E(&-O;G-I9&5R('1H:7,@
M=&\@8F4*("`@("`J(&%N>2!F=6YC=&EO;B!I;B!T:&4@8VQA<W,@=6YL97-S
M(&ET('-T87)T<R!W:71H('5N9&5R<V-O<F4L"B`@("`@*B!P:'`U('-U<'!O
M<G0@:7,@;F]T(&-O;7!L971E('EE="!I;B!T:&ES(')E9V%R9"DN("`*("`@
M("`J(&EF('EO=2!D;R!N;W0@9&5F:6YE(&EN+V]U="!P87)A;65T97)S+"!T
M:&4@9G5N8W1I;VX@8V%N(&)E"B`@("`@*B!C86QL960@=VET:"!P87)A;65T
M97)S+"!B=70@;F\@=F%L:61A=&EO;B!O;B!P87)A;65T97)S('=I;&P*("`@
M("`J(&]C8W5R92X*("`@("`J+PH@("`@=F%R("1?7V1I<W!A=&-H7VUA<"`]
M(&%R<F%Y*"D["@H@("`@9G5N8W1I;VX@4T]!4%]%>&%M<&QE7U-E<G9E<B@I
M('L*("`@("`@("`O*BH*("`@("`@("`J('=H96X@9V5N97)A=&EN9R!W<V1L
M(&9O<B!A('-E<G9E<BP@>6]U(&AA=F4@=&\@9&5F:6YE"B`@("`@("`@*B!A
M;GD@<W!E8VEA;"!C;VUP;&5X('1Y<&5S('1H870@>6]U('5S92`H:64@8VQA
M<W-E<RDN"B`@("`@("`@*B!U<VEN9R!A(&YA;65S<&%C92!I9"!B969O<F4@
M=&AE('1Y<&4@=VEL;"!C<F5A=&4@86X*("`@("`@("`J('AM;"!S8VAE;6$@
M=VET:"!T:&4@=&%R9V5T3F%M97-P86-E(&9O<B!T:&4@='EP90H@("`@("`@
M("H@;75L=&EP;&4@='EP97,@=VET:"!T:&4@<V%M92!N86UE<W!A8V4@=VEL
M;"!A<'!E87(*("`@("`@("`J(&EN('1H92!S86UE('-C:&5M82!S96-T:6]N
M+B`@='EP97,@=VET:"!D:69F97)E;G0*("`@("`@("`J(&YA;65S<&%C97,@
M=VEL;"!B92!I;B!S97!E<F%T92!S8VAE;6$@<V5C=&EO;G,N"B`@("`@("`@
M*B!T:&4@9F]L;&]W:6YG(%-/05!3=')U8W0@='EP961E9B!C;V]R97-P;VYD
M<R!T;R!T:&4*("`@("`@("`J(%-/05!3=')U8W0@8VQA<W,@86)O=F4N"B`@
M("`@("`@*B\*("`@("`@("`D=&AI<RT^7U]T>7!E9&5F6R=[:'1T<#HO+W-O
M87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="==(#T@"B`@("`@("`@("`@
M("`@("`@("`@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("=V87)3
M=')I;F<G(#T^("=S=')I;F<G+`H@("`@("`@("`@("`@("`@("`@("`@("`G
M=F%R26YT)R`]/B`G:6YT)RP@"B`@("`@("`@("`@("`@("`@("`@("`@("=V
M87)&;&]A="<@/3X@)V9L;V%T)PH@("`@("`@("`@("`@("`@("`@("`@("`@
M*3L*"B`@("`@("`@+R\@86X@86QI87-E9"!F=6YC=&EO;B!W:71H(&UU;'1I
M<&QE(&]U="!P87)A;65T97)S"@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V5C
M:&]3=')U8W1!<U-I;7!L951Y<&5S)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R
M87DH)VEN<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O
M>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T
M<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RP@)V]U='!U=$EN=&5G97(G(#T^("=I
M;G0G+"`G;W5T<'5T1FQO870G(#T^("=F;&]A="<I+`H)"2`@("`@("=A;&EA
M<R<@/3X@)VUY16-H;U-T<G5C=$%S4VEM<&QE5'EP97,G"@D)("`@("`@*3L*
M"21T:&ES+3Y?7V1I<W!A=&-H7VUA<%LG96-H;U-T<FEN9U-I;7!L92==(#T*
M"0EA<G)A>2@G:6XG(#T^(&%R<F%Y*"=I;G!U=%-T<FEN9U-I;7!L92<@/3X@
M)W-T<FEN9R<I+`H)"2`@("`@("=O=70G(#T^(&%R<F%Y*"=O=71P=713=')I
M;F=3:6UP;&4G(#T^("=S=')I;F<G*2P*"0D@("`@("`I.PH))'1H:7,M/E]?
M9&ES<&%T8VA?;6%P6R=E8VAO4W1R:6YG)UT@/0H)"6%R<F%Y*"=I;B<@/3X@
M87)R87DH)VEN<'5T4W1R:6YG)R`]/B`G<W1R:6YG)RDL"@D)("`@("`@)V]U
M="<@/3X@87)R87DH)V]U='!U=%-T<FEN9R<@/3X@)W-T<FEN9R<I+`H)"2`@
M("`@("D["@DD=&AI<RT^7U]D:7-P871C:%]M87!;)V1I=FED92==(#T*"0EA
M<G)A>2@G:6XG(#T^(&%R<F%Y*"=D:79I9&5N9"<@/3X@)VEN="<L("=D:79I
M<V]R)R`]/B`G:6YT)RDL"@D)("`@("`@)V]U="<@/3X@87)R87DH)V]U='!U
M=$9L;V%T)R`]/B`G9FQO870G*2P*"0D@("`@("`I.PH))'1H:7,M/E]?9&ES
M<&%T8VA?;6%P6R=E8VAO4W1R=6-T)UT@/0H)"6%R<F%Y*"=I;B<@/3X@87)R
M87DH)VEN<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O
M>'-D?5-/05!3=')U8W0G*2P*"0D@("`@("`G;W5T)R`]/B!A<G)A>2@G;W5T
M<'5T4W1R=6-T)R`]/B`G>VAT='`Z+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/
M05!3=')U8W0G*2P*"0D@("`@("`I.PH)"@DD=&AI<RT^7U]D:7-P871C:%]M
M87!;)V5C:&]-:6UE071T86-H;65N="==(#T@87)R87DH*3L*("`@('T*"B`@
M("`O*B!T:&ES('!R:79A=&4@9G5N8W1I;VX@:7,@8V%L;&5D(&]N(&)Y(%-/
M05!?4V5R=F5R('1O(&1E=&5R;6EN92!A;GD*("`@("`@("!S<&5C:6%L(&1I
M<W!A=&-H(&EN9F]R;6%T:6]N('1H870@;6EG:'0@8F4@;F5C97-S87)Y+B`@
M5&AI<RP@9F]R(&5X86UP;&4L"B`@("`@("`@8V%N(&)E('5S960@=&\@<V5T
M('5P(&$@9&ES<&%T8V@@;6%P(&9O<B!F=6YC=&EO;G,@=&AA="!R971U<FX@
M;75L=&EP;&4*("`@("`@("!/550@<&%R86UE=&5R<R`J+PH@("`@9G5N8W1I
M;VX@7U]D:7-P871C:"@D;65T:&]D;F%M92D@>PH@("`@("`@(&EF("AI<W-E
M="@D=&AI<RT^7U]D:7-P871C:%]M87!;)&UE=&AO9&YA;65=*2D*("`@("`@
M("`@("`@<F5T=7)N("1T:&ES+3Y?7V1I<W!A=&-H7VUA<%LD;65T:&]D;F%M
M95T["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]"@H@("`@+R\@82!S:6UP
M;&4@96-H;U-T<FEN9R!F=6YC=&EO;@H@("`@9G5N8W1I;VX@96-H;U-T<FEN
M9U-I;7!L92@D:6YP=713=')I;F<I"B`@("!["@ER971U<FX@)&EN<'5T4W1R
M:6YG.PH@("`@?0H@("`@"B`@("`O+R!A;B!E>'!L:6-I="!E8VAO<W1R:6YG
M(&9U;F-T:6]N"B`@("!F=6YC=&EO;B!E8VAO4W1R:6YG*"1I;G!U=%-T<FEN
M9RD*("`@('L*"7)E='5R;B!N97<@4T]!4%]686QU92@G;W5T<'5T4W1R:6YG
M)RPG<W1R:6YG)RPD:6YP=713=')I;F<I.PH@("`@?0H*("`@(&9U;F-T:6]N
M(&1I=FED92@D9&EV:61E;F0L("1D:79I<V]R*0H@("`@>PH@("`@("`@("\O
M('1H92!S;V%P('-E<G9E<B!W;W5L9"!N;W)M86QL>2!C871C:"!E<G)O<G,@
M;&EK92!T:&ES"B`@("`@("`@+R\@86YD(')E='5R;B!A(&9A=6QT+"!B=70@
M=&AI<R!I<R!H;W<@>6]U(&1O(&ET('EO=7)S96QF+@H@("`@("`@(&EF("@D
M9&EV:7-O<B`]/2`P*0H@("`@("`@("`@("!R971U<FX@;F5W(%-/05!?1F%U
M;'0H)UEO=2!C86YN;W0@9&EV:61E(&)Y('IE<F\G+"`G0VQI96YT)RD["B`@
M("`@("`@96QS90H@("`@("`@("`@("!R971U<FX@)&1I=FED96YD("\@)&1I
M=FES;W(["B`@("!]"@H@("`@9G5N8W1I;VX@96-H;U-T<G5C="@D:6YP=713
M=')U8W0I"B`@("!["B`@("`@("`@<F5T=7)N("1I;G!U=%-T<G5C="T^7U]T
M;U]S;V%P*"=O=71P=713=')U8W0G*3L*"2-R971U<FX@;F5W(%-/05!?5F%L
M=64H)V]U='!U=%-T<G5C="<L)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS
M9'U33T%04W1R=6-T)RPD:6YP=713=')U8W0I.PH@("`@?0H@("`@"B`@("`O
M*BH*("`@("`J(&5C:&]3=')U8W1!<U-I;7!L951Y<&5S"B`@("`@*B!T86ME
M<R!A(%-/05!3=')U8W0@87,@:6YP=70L(&%N9"!R971U<FYS(&5A8V@@;V8@
M:71S(&5L96UE;G1S"B`@("`@*B!A<R!/550@<&%R86UE=&5R<PH@("`@("H*
M("`@("`J('1H:7,@9G5N8W1I;VX@:7,@86QS;R!A;&EA<V5D('-O('EO=2!H
M879E('1O(&-A;&P@:70@=VET:`H@("`@("H@96-H;U-T<G5C=$%S4VEM<&QE
M5'EP97,*("`@("`J"B`@("`@*B!33T%04W1R=6-T(&ES(&1E9FEN960@87,Z
M"B`@("`@*@H@("`@("H@<W1R=6-T(%-/05!3=')U8W0Z"B`@("`@*B`@("!S
M=')I;F<@=F%R4W1R:6YG"B`@("`@*B`@("!I;G1E9V5R('9A<DEN=`H@("`@
M("H@("`@9FQO870@=F%R1FQO870*("`@("`J"B`@("`@*B\*("`@(&9U;F-T
M:6]N(&UY16-H;U-T<G5C=$%S4VEM<&QE5'EP97,H)'-T<G5C="D*("`@('L*
M"2,@8V]N=F5R="!A(%-/05!3=')U8W0@=&\@86X@87)R87D*"7)E='5R;B!A
M<G)A>2@*"2`@("!N97<@4T]!4%]686QU92@G;W5T<'5T4W1R:6YG)RPG<W1R
M:6YG)RPD<W1R=6-T+3YV87)3=')I;F<I+`H)("`@(&YE=R!33T%07U9A;'5E
M*"=O=71P=71);G1E9V5R)RPG:6YT)RPD<W1R=6-T+3YV87));G0I+`H)("`@
M(&YE=R!33T%07U9A;'5E*"=O=71P=71&;&]A="<L)V9L;V%T)RPD<W1R=6-T
M+3YV87)&;&]A="D*"2`@("`I.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B!E
M8VAO36EM94%T=&%C:&UE;G0H)'-T=69F*0H@("`@>PH@("`@("`@(')E='5R
M;B!N97<@4T]!4%]!='1A8VAM96YT*"=R971U<FXG+"=A<'!L:6-A=&EO;B]O
M8W1E="US=')E86TG+$Y53$PL)'-T=69F*3L*("`@('T@("`@"GT*"C\^````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]D;V-S+U-/05`O97AA;7!L92]E>&%M<&QE7W1Y<&5S+G!H<```````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`R-C,W(#$P-3$U-#,T,3,S(#`R-3(P-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`H*
M+RH**B!T:&ES(&ES(&$@9&%T82!T>7!E('1H870@:7,@=7-E9"!I;B!33T%0
M($EN=&5R;W`@=&5S=&EN9RP@8G5T(&ES"BH@:&5R92!A<R!A;B!E>&%M<&QE
M(&]F('5S:6YG(&-O;7!L97@@='EP97,N("!7:&5N('1H92!C;&%S<R!I<PHJ
M(&1E<V5R:6%L:7IE9"!F<F]M(&$@4T]!4"!M97-S86=E+"!I="=S(&-O;G-T
M<G5C=&]R($E3($Y/5"!#04Q,140A"BH@4V\@>6]U<B!T>7!E(&-L87-S97,@
M;F5E9"!T;R!B96AA=F4@:6X@82!W87D@=&AA="!W:6QL('=O<FL**B!W:71H
M('1H870N"BH**B!3;VUE('1Y<&5S(&UA>2!N965D(&UO<F4@97AP;&EC:70@
M<V5R:6%L:7IA=&EO;B!F;W(@4T]!4"X@(%1H90HJ(%]?=&]?<V]A<"!F=6YC
M=&EO;B!A;&QO=W,@>6]U('1O(&)E('9E<GD@97AP;&EC:70@:6X@8G5I;&1I
M;F<@=&AE"BH@4T]!4%]686QU92!S=')U8W1U<F5S+B`@5&AE('-O87`@;&EB
M<F%R>2!D;V5S(&YO="!C86QL('1H:7,@9&ER96-T;'DL"BH@>6]U('=O=6QD
M(&-A;&P@:70@9G)O;2!Y;W5R('-O87`@<V5R=F5R(&-L87-S+"!E8VAO4W1R
M=6-T(&EN('1H92!S97)V97(**B!C;&%S<R!I<R!A;B!E>&%M<&QE(&]F(&1O
M:6YG('1H:7,N"BHO"F-L87-S(%-/05!3=')U8W0@>PH@("`@=F%R("1V87)3
M=')I;F<["B`@("!V87(@)'9A<DEN=#L*("`@('9A<B`D=F%R1FQO870["B`@
M("!F=6YC=&EO;B!33T%04W1R=6-T*"1S/4Y53$PL("1I/4Y53$PL("1F/4Y5
M3$PI('L*("`@("`@("`D=&AI<RT^=F%R4W1R:6YG(#T@)',["B`@("`@("`@
M)'1H:7,M/G9A<DEN="`]("1I.PH@("`@("`@("1T:&ES+3YV87)&;&]A="`]
M("1F.PH@("`@?0H@("`@"B`@("!F=6YC=&EO;B`F7U]T;U]S;V%P*"1N86UE
M(#T@)VEN<'5T4W1R=6-T)RP@)&AE861E<CUF86QS92P@)&UU<W15;F1E<G-T
M86YD/3`L("1A8W1O<CTG:'1T<#HO+W-C:&5M87,N>&UL<V]A<"YO<F<O<V]A
M<"]A8W1O<B]N97AT)RD*("`@('L*("`@("`@("`D:6YN97);72`])B!N97<@
M4T]!4%]686QU92@G=F%R4W1R:6YG)RPG<W1R:6YG)RPD=&AI<RT^=F%R4W1R
M:6YG*3L*("`@("`@("`D:6YN97);72`])B!N97<@4T]!4%]686QU92@G=F%R
M26YT)RPG:6YT)RPD=&AI<RT^=F%R26YT*3L*("`@("`@("`D:6YN97);72`]
M)B!N97<@4T]!4%]686QU92@G=F%R1FQO870G+"=F;&]A="<L)'1H:7,M/G9A
M<D9L;V%T*3L*("`@("`@("!I9B`H)&AE861E<BD@>PH@("`@("`@("`@("!R
M971U<FX@;F5W(%-/05!?2&5A9&5R*"1N86UE+"=[:'1T<#HO+W-O87!I;G1E
M<F]P+F]R9R]X<V1]4T]!4%-T<G5C="<L)&EN;F5R+"1M=7-T56YD97)S=&%N
M9"PD86-T;W(I.PH@("`@("`@('T*("`@("`@("!R971U<FX@;F5W(%-/05!?
M5F%L=64H)&YA;64L)WMH='1P.B\O<V]A<&EN=&5R;W`N;W)G+WAS9'U33T%0
M4W1R=6-T)RPD:6YN97(I.PH@("`@("`@(`H@("`@?0I]"@H_/@``````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE
M+W-E<G9E<BYP:'``````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#,W-#4@
M,3`U,34T,S0Q,S,@,#(S-C,V`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S:6]N(#0@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`R(&]F('1H92!02%`@;&EC96YS92P@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%-H86YE($-A
M<F%V96\@/%-H86YE0$-A<F%V96\N8V]M/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O
M("1)9#H@<V5R=F5R+G!H<"QV(#$N,3`@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y
M=6YO<V@@17AP("0*+R\*"B\O(&9I<G-T+"!I;F-L=61E('1H92!33T%0+U-E
M<G9E<B!C;&%S<PIR97%U:7)E7V]N8V4@)U-/05`O4V5R=F5R+G!H<"<["@HD
M<V5R=F5R(#T@;F5W(%-/05!?4V5R=F5R.PHO*B!T96QL('-E<G9E<B!T;R!T
M<F%N<VQA=&4@=&\@8VQA<W-E<R!W92!P<F]V:61E(&EF('!O<W-I8FQE("HO
M"B1S97)V97(M/E]A=71O7W1R86YS;&%T:6]N(#T@=')U93L*"G)E<75I<F5?
M;VYC92`G97AA;7!L95]S97)V97(N<&AP)SL*"B1S;V%P8VQA<W,@/2!N97<@
M4T]!4%]%>&%M<&QE7U-E<G9E<B@I.PHD<V5R=F5R+3YA9&1/8FIE8W1-87`H
M)'-O87!C;&%S<RPG=7)N.E-/05!?17AA;7!L95]397)V97(G*3L*"FEF("AI
M<W-E="@D7U-%4E9%4ELG4D5154535%]-151(3T0G72D@)B8*("`@("1?4T52
M5D526R=215%515-47TU%5$A/1"==/3TG4$]35"<I('L*("`@("1S97)V97(M
M/G-E<G9I8V4H)$A45%!?4D%77U!/4U1?1$%402D["GT@96QS92!["B`@("!R
M97%U:7)E7V]N8V4@)U-/05`O1&ES8V\N<&AP)SL*("`@("1D:7-C;R`](&YE
M=R!33T%07T1)4T-/7U-E<G9E<B@D<V5R=F5R+"=397)V97)%>&%M<&QE)RD[
M"B`@("!H96%D97(H(D-O;G1E;G0M='EP93H@=&5X="]X;6PB*3L*("`@(&EF
M("AI<W-E="@D7U-%4E9%4ELG455%4EE?4U1224Y')UTI("8F"B`@("`@("!S
M=')C87-E8VUP*"1?4T525D526R=1545265]35%))3D<G72PG=W-D;"<I/3TP
M*2!["B`@("`@("`@96-H;R`D9&ES8V\M/F=E=%=31$PH*3L*("`@('T@96QS
M92!["B`@("`@("`@96-H;R`D9&ES8V\M/F=E=$1)4T-/*"D["B`@("!]"B`@
M("!E>&ET.PI]"C\^````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]S97)V
M97(R+G!H<```````````````````````````````````````````````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U,#4S(#$P-3$U
M-#,T,3,S(#`R,S<Q,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY
M-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O
M9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE
M9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@
M:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@
M;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E
M('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R
M;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\
M"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O
M<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!#87)A=F5O
M(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z
M('-E<G9E<C(N<&AP+'8@,2XS(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H
M($5X<"`D"B\O"@HO+R!F:7)S="P@:6YC;'5D92!T:&4@4T]!4"]397)V97(@
M8VQA<W,*<F5Q=6ER95]O;F-E("=33T%0+U-E<G9E<BYP:'`G.PH*)'-E<G9E
M<B`](&YE=R!33T%07U-E<G9E<CL*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L
M871E('1O(&-L87-S97,@=V4@<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R
M=F5R+3Y?875T;U]T<F%N<VQA=&EO;B`]('1R=64["@HO*B!4:&ES(&ES(&$@
M<VEM<&QE(&5X86UP;&4@;V8@:6UP;&5M96YT:6YG(&$@8W5S=&]M"B`@(&-A
M;&P@:&%N9&QE<BX@($EF('EO=2!D;R!T:&ES+"!T:&4@<V]A<"!S97)V97(@
M=VEL;"!I9VYO<F4*("`@;V)J96-T<R!O<B!F=6YC=&EO;G,@861D960@=&\@
M:70L(&%N9"!W:6QL(&-A;&P@>6]U<B!H86YD;&5R"B`@(&9O<B`J*D%,3"HJ
M('-O87`@8V%L;',@=&AE('-E<G9E<B!R96-E:79E<RP@=V5T:&5R('1H92!C
M86QL"B`@(&ES(&1E9FEN960@:6X@>6]U<B!74T1,(&]R(&YO="X@(%1H92!H
M86YD;&5R(')E8V5I=F5S('1W;PH@("!A<F=U;65N=',L('1H92!M971H;V0@
M;F%M92!B96EN9R!C86QL960L(&%N9"!T:&4@87)G=6UE;G1S"B`@('-E;G0@
M9F]R('1H870@8V%L;"X**B\*9G5N8W1I;VX@;7E#86QL2&%N9&QE<B@D;65T
M:&]D;F%M92P@)&%R9W,I"GL*("`@(&=L;V)A;"`D<V]A<&-L87-S.PH@("`@
M<F5T=7)N($!C86QL7W5S97)?9G5N8U]A<G)A>2AA<G)A>2@D<V]A<&-L87-S
M+"`D;65T:&]D;F%M92DL)&%R9W,I.PI]"B1S97)V97(M/G-E=$-A;&Q(86YD
M;&5R*"=M>4-A;&Q(86YD;&5R)RQF86QS92D["@IR97%U:7)E7V]N8V4@)V5X
M86UP;&5?<V5R=F5R+G!H<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA
M;7!L95]397)V97(H*3L*)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA
M<W,L)W5R;CI33T%07T5X86UP;&5?4V5R=F5R)RD["@II9B`H:7-S970H)%]3
M15)615);)U)%455%4U1?34542$]$)UTI("8F"B`@("`D7U-%4E9%4ELG4D51
M54535%]-151(3T0G73T])U!/4U0G*2!["B`@("`D<V5R=F5R+3YS97)V:6-E
M*"1(5%107U)!5U]03U-47T1!5$$I.PI](&5L<V4@>PH@("`@<F5Q=6ER95]O
M;F-E("=33T%0+T1I<V-O+G!H<"<["B`@("`D9&ES8V\@/2!N97<@4T]!4%]$
M25-#3U]397)V97(H)'-E<G9E<BPG4V5R=F5R17AA;7!L92<I.PH@("`@:&5A
M9&5R*")#;VYT96YT+71Y<&4Z('1E>'0O>&UL(BD["B`@("!I9B`H:7-S970H
M)%]315)615);)U%515)97U-44DE.1R==*2`F)@H@("`@("`@<W1R8V%S96-M
M<"@D7U-%4E9%4ELG455%4EE?4U1224Y')UTL)W=S9&PG*3T],"D@>PH@("`@
M("`@(&5C:&\@)&1I<V-O+3YG97174T1,*"D["B`@("!](&5L<V4@>PH@("`@
M("`@(&5C:&\@)&1I<V-O+3YG971$25-#3R@I.PH@("`@?0H@("`@97AI=#L*
M?0H_/@``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O4T]!4"]E>&%M<&QE+W-M='`N<&AP````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#,R-S,@,3`U,34T,S0Q,S,@,#(S,S`W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_"B\O
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<VUT<"YP:'`L=B`Q+C4@,C`P
M-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*+R\@:6YC;'5D92!S
M;V%P(&-L:65N="!C;&%S<PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*
M"B1S;V%P8VQI96YT(#T@;F5W(%-/05!?0VQI96YT*")M86EL=&\Z=7-E<D!D
M;VUA:6XN8V]M(BD["B1O<'1I;VYS(#T@87)R87DH)VYA;65S<&%C92<]/B=H
M='1P.B\O<V]A<&EN=&5R;W`N;W)G+R<L)V9R;VTG/3XG=7-E<D!D;VUA:6XN
M8V]M)RPG:&]S="<]/B=L;V-A;&AO<W0G*3L*)')E='5R;B`]("1S;V%P8VQI
M96YT+3YC86QL*")E8VAO4W1R:6YG(BQA<G)A>2@B:6YP=713=')I;F<B/3XB
M=&AI<R!I<R!A('1E<W0B*2P@)&]P=&EO;G,I.PHD<F5T=7)N(#T@)'-O87!C
M;&EE;G0M/F-A;&PH(F5C:&]3=')I;F=!<G)A>2(L87)R87DH)VEN<'5T4W1R
M:6YG07)R87DG(#T^(&%R<F%Y*"=G;V]D)RPG8F%D)RPG=6=L>2<I*2P@)&]P
M=&EO;G,I.PHO+R!D;VXG="!E>'!E8W0@;75C:"!O9B!A(')E<W5L="$*<')I
M;G1?<B@D<F5T=7)N*3L*<')I;G0@(CQB<CY<;B(N)'-O87!C;&EE;G0M/G=I
M<F4["C\^"@H`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+U-/05`O97AA;7!L92]S=&]C:W%U;W1E+G!H<```````````````
M`````````````````````````````````````#`P,#8T-"``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`T-#$R(#$P-3$U-#,T,3,S(#`R-#4R,0`@,```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````\:'1M;#X\8F]D
M>3X*/#\*+R\*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M4$A0(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@
M4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E
M(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES
M('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\
M"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W
M=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E
M(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@
M("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N
M<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T
M96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R
M879E;RYC;VT^("`@4&]R="!T;R!014%2(&%N9"!M;W)E("`@?`HO+R!\($%U
M=&AO<G,Z($1I971R:6-H($%Y86QA(#QD:65T<FEC:$!G86YX-"YC;VT^($]R
M:6=I;F%L($%U=&AO<B`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@<W1O8VMQ=6]T92YP:'`L=B`Q+C<@,C`P
M-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*+R\@:6YC;'5D92!S
M;V%P(&-L:65N="!C;&%S<PII;F-L=61E*")33T%0+T-L:65N="YP:'`B*3L*
M"G!R:6YT("(\8G(^7&X\<W1R;VYG/G=S9&PZ/"]S=')O;F<^(CL*)'=S9&P@
M/2!N97<@4T]!4%]74T1,*")H='1P.B\O<V5R=FEC97,N>&UE=&AO9',N;F5T
M+W-O87`O=7)N.GAM971H;V1S+61E;&%Y960M<75O=&5S+G=S9&PB*3L*)'-O
M87!C;&EE;G0@/2`D=W-D;"T^9V5T4')O>'DH*3L*<')I;G1?<B@D<V]A<&-L
M:65N="T^9V5T475O=&4H(FEB;2(I*3L*<')I;G0@(EQN7&XB.PH*:68@*&5X
M=&5N<VEO;E]L;V%D960H)V]V97)L;V%D)RDI('L*"7!R:6YT(")<;CQB<CX\
M<W1R;VYG/F]V97)L;V%D960Z/"]S=')O;F<^(CL*"21R970@/2`D<V]A<&-L
M:65N="T^9V5T475O=&4H(FEB;2(I.PH)<')I;G1?<B@D<F5T*3L*"7!R:6YT
M(")<;EQN(CL*?0IU;G-E="@D<V]A<&-L:65N="D["@IP<FEN="`B7&X\8G(^
M/'-T<F]N9SYN;VX@=W-D;#H\+W-T<F]N9SXB.PHD<V]A<&-L:65N="`](&YE
M=R!33T%07T-L:65N="@B:'1T<#HO+W-E<G9I8V5S+GAM971H;V1S+FYE=#HX
M,"]S;V%P(BD["B1N86UE<W!A8V4@/2`B=7)N.GAM971H;V1S+61E;&%Y960M
M<75O=&5S(CL*+RHJ"B`J('-O;64@<V]A<"!S97)V97)S(')E<75I<F4@82!3
M;V%P86-T:6]N(&AT='`@:&5A9&5R+B`@4$5!4CHZ4T]!4"!D;V5S"B`J(&YO
M="!U<V4@=&AE;2!I;B!A;GD@=V%Y+"!O=&AE<B!T;R!S96YD('1H96T@:68@
M>6]U('-U<'!L>2!T:&5M+@H@*B!S;V%P86-T:6]N(&ES(&1E<')E8V%T960@
M:6X@;&%T97(@4T]!4"!V97)S:6]N<RX*("HO"B1S;V%P86-T:6]N(#T@(G5R
M;CIX;65T:&]D<RUD96QA>65D+7%U;W1E<R-G9711=6]T92(["B1R970@/2`D
M<V]A<&-L:65N="T^8V%L;"@B9V5T475O=&4B+&%R<F%Y*")S>6UB;VPB/3XB
M:6)M(BDL)&YA;65S<&%C92PD<V]A<&%C=&EO;BD["G!R:6YT7W(H)')E="D[
M"G!R:6YT(")<;EQN(CL*=6YS970H)'-O87!C;&EE;G0I.PH*/SX*/"]H=&UL
M/CPO8F]D>3X*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+U-/05`O97AA;7!L92]T8W!?8VQI96YT+G!H
M<````````````````````````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-#`P(#$P-3$U-#,T,3,S(#`R
M-#0T,``@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!02%`@5F5R<VEO;B`T("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H
M92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R
M8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0
M(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO
M+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I
M=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T
M;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW
M96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC
M96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I
M871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!3:&%N92!(86YN82`\:6]R9'E?871?
M:6]R9'E?9&]T7V-O;3X@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z('1C<%]C;&EE
M;G0N<&AP+'8@,2XS(#(P,#4O,#,O,3`@,C,Z,38Z-#`@>75N;W-H($5X<"`D
M"B\O"@IR97%U:7)E7V]N8V4H)U-/05`O0VQI96YT+G!H<"<I.PH*(R!C;&EE
M;G0*)'-O87!C;&EE;G0@/2!N97<@4T]!4%]#;&EE;G0H(G1C<#HO+S$R-RXP
M+C`N,3HX,B(I.PH*(R!N86UE<W!A8V4*)&]P=&EO;G,@/2!A<G)A>2@G;F%M
M97-P86-E)R`]/B`G=7)N.E-/05!?17AA;7!L95]397)V97(G+"`G=')A8V4G
M(#T^(#$I.PH*(R!O;F4*)'!A<F%M<R`](&%R<F%Y*")S=')I;F<B(#T^(")T
M:&ES(&ES('-T<FEN9R`Q(BD["B1R970Q(#T@)'-O87!C;&EE;G0M/F-A;&PH
M(F5C:&]3=')I;F<B+"`D<&%R86US+"`D;W!T:6]N<RD["B,@96-H;R`B5TE2
M13H@7&XB+B1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E
M=#$I.PIE8VAO("(\8G(@+SY<;B(["@HC('1W;PHD<&%R86US(#T@87)R87DH
M(G-T<FEN9R(@/3X@(G1H:7,@:7,@<W1R:6YG(#(B*3L*)')E=#(@/2`D<V]A
M<&-L:65N="T^8V%L;"@B96-H;U-T<FEN9R(L("1P87)A;7,L("1O<'1I;VYS
M*3L*(R!E8VAO(")725)%.B!<;B(N)'-O87!C;&EE;G0M/E]?9V5T7W=I<F4H
M*3L*<')I;G1?<B@D<F5T,BD["F5C:&\@(CQB<B`O/EQN(CL*"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]33T%0+V5X86UP;&4O=&-P7V1A96UO;BYP;```````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,S$U-R`Q,#4Q-30S-#$S,R`P,C0R-C(`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````(R$O
M=7-R+V)I;B]P97)L("UW"G5S92!S=')I8W0["@H]:&5A9#$@4VEM<&QE(%-/
M05`@5$-0(%-E<G9E<@H*("`@(%-I;7!L92!33T%0(%1#4"!397)V97(@=VET
M:"!T97-T(&-L87-S("AJ=7-T('1O(&-H96-K('1H:6YG<R!A<F4@=V]R:VEN
M9RD*"B`@("!"969O<F4@>6]U(')U;B!T:&ES('1E<W0@<V5R=F5R('EO=2!W
M:6QL(&YE960@<V]M92!P97)L(&-L87-S97,L(&YA;65L>3H*("`@("`@("!3
M3T%0.CI,:71E"B`@("`@("`@2&]O:SHZ3&5X5W)A<"`H:68@>6]U('=A;G0@
M=&\@<V5E('-O;64@9&5B=6=G:6YG*0H*("`@("`@("!&;&5E(&]F9B!T;R!T
M:&4@0U!!3B!I9B!Y;W4@;F5E9"!T:&5M(#HI"@H@("`@5&\@<G5N('1Y<&4@
M)W!E<FP@/&9I;&5N86UE/B<@86YD(&EF('EO=2!D;VYT(&=E="!A;GD@97)R
M;W)S+"!I="=S('1I;64*("`@('1O(&=O('=R:71E('-O;64@8V]D92!T;R!C
M;VYN96-T+@H]8W5T"@IU<V4@4T]!4#HZ5')A;G-P;W)T.CI40U`@<7<H=')A
M8V4I.PIU<V4@1&%T83HZ1'5M<&5R.PH*"B,C(R,C(R,C(R,C(R,*(R,@:68@
M>6]U('=A;G0@=&\@<V5E(&EN8V]M:6YG+V]U=&=O:6YG(')A=R!X;6P*(R,@
M=6YC;VUM96YT('1H92!F;VQL;W=I;F<N"@HC=7-E($AO;VLZ.DQE>%=R87`[
M"B-W<F%P("I)3SHZ4V5S<VEO;D1A=&$Z.G)E860L('!O<W0@/3X@7"9S:&]W
M7W)E860["B-W<F%P("I)3SHZ4V5S<VEO;D1A=&$Z.G=R:71E+"!P;W-T(#T^
M(%PF<VAO=U]W<FET93L*"B,C"B,C(R,C(R,C(R,C(R,*"@IM>2`D9&%E;6]N
M(#T@4T]!4#HZ5')A;G-P;W)T.CI40U`Z.E-E<G9E<BT^;F5W*`H@("`@3&]C
M86Q!9&1R(#T^("<Q,C<N,"XP+C$G+`H@("`@3&]C86Q0;W)T(#T^("<X,B<L
M"B`@("!,:7-T96X@("`@/3X@-2P*("`@(%)E=7-E("`@("`]/B`Q"BD["@HC
M(&1I<W!A=&-H"B1D865M;VXM/F1I<W!A=&-H7W1O*"=33T%07T5X86UP;&5?
M4V5R=F5R)RD["B1D865M;VXM/FAA;F1L93L*"B,C(R,C(R,C(R,C(R,*(R,@
M8V%L;&)A8VL@9G5N8W1I;VYS(&9O<B!(;V]K.CI,97A7<F%P.PHC(PH*(R!S
M:&]W(&EN8V]M:6YG('AM;`IS=6(@<VAO=U]R96%D('L*("`@('!R:6YT("0O
M+"<C(R!R96%D(",C)RPD+SL*("`@('!R:6YT($1U;7!E<B@D7ULP72D["GT*
M"B,@<VAO=R!O=71G;VEN9R!X;6P*<W5B('-H;W=?=W)I=&4@>PH@("`@<')I
M;G0@)"\L)R,C('=R:71E(",C)RPD+SL*("`@('!R:6YT($1U;7!E<B@D7ULP
M72D["GT*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*"@H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!33T%07T5X
M86UP;&5?4V5R=F5R"B,@4VEM<&QE('1E<W0@8VQA<W,L(&UE=&AO9"!T97-T
M(')E='5R;G,@9&]U8FQE('=H870@>6]U('-E;F0@=&\@:70L('1H871S(&%L
M;"$*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*<&%C:V%G
M92!33T%07T5X86UP;&5?4V5R=F5R.PH*<W5B(&5C:&]3=')I;F<@>PH@("`@
M<F5T=7)N("1?6S%=('@@,CL*?0H*,3L*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+V1O8W,O4T]!4"]E>&%M<&QE+W1C<%]S97)V97(N<&AP````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#,Q,C$@,3`U,34T,S0Q,S,@,#(T-#<P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\O
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!(4"!697)S
M:6]N(#0@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U
M<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES
M('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`R(&]F('1H92!02%`@;&EC96YS92P@
M("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E
M(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V
M86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN
M970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@
M;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\
M(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E
M('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN
M970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($%U=&AO<G,Z(%-H86YE($-A<F%V96\@/%-H86YE0$-A<F%V96\N8V]M
M/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=&-P7W-E<G9E<BYP:'`L=B`Q
M+C0@,C`P-2\P,R\Q,"`R,SHQ-CHT,"!Y=6YO<V@@17AP("0*+R\*"B\O(&9I
M<G-T+"!I;F-L=61E('1H92!33T%0+U-E<G9E<B!C;&%S<PIR97%U:7)E7V]N
M8V4@)U-/05`O4V5R=F5R+U1#4"YP:'`G.PIS971?=&EM95]L:6UI="@P*3L*
M"B1S97)V97(@/2!N97<@4T]!4%]397)V97)?5$-0*"(Q,C<N,"XP+C$B+#@R
M*3L*+RH@=&5L;"!S97)V97(@=&\@=')A;G-L871E('1O(&-L87-S97,@=V4@
M<')O=FED92!I9B!P;W-S:6)L92`J+PHD<V5R=F5R+3Y?875T;U]T<F%N<VQA
M=&EO;B`]('1R=64["@IR97%U:7)E7V]N8V4@)V5X86UP;&5?<V5R=F5R+G!H
M<"<["@HD<V]A<&-L87-S(#T@;F5W(%-/05!?17AA;7!L95]397)V97(H*3L*
M)'-E<G9E<BT^861D3V)J96-T36%P*"1S;V%P8VQA<W,L)W5R;CI33T%07T5X
M86UP;&5?4V5R=F5R)RD["B1S97)V97(M/G)U;B@I.PH_/@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+U-/05`O97AA;7!L92]W<V1L7V-L:65N="YP:'``````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`V-#8T(#$P-3$U-#,T,3,S(#`R-#8T,``@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````\/W!H<`HO+PHO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!02%`@5F5R<VEO;B`T
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J
M96-T('1O('9E<G-I;VX@,BXP,B!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T
M:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B
M;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI
M8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H
M92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A
M:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD
M(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O
M('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@
M("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!
M=71H;W)S.B!3:&%N92!#87)A=F5O(#Q3:&%N94!#87)A=F5O+F-O;3X@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+PHO+R`D260Z('=S9&Q?8VQI96YT+G!H<"QV(#$N,R`R
M,#`U+S`S+S$P(#(S.C$V.C0P('EU;F]S:"!%>'`@)`HO+PII;F-L=61E*")3
M3T%0+T-L:65N="YP:'`B*3L*"B\J*@H@*B!T:&ES(&-L:65N="!R=6YS(&%G
M86EN<W0@=&AE(&5X86UP;&4@<V5R=F5R(&EN(%-/05`O97AA;7!L92]S97)V
M97(N<&AP"B`J(&ET(&1O97,@;F]T('5S92!74T1,('1O(')U;B!T:&5S92!R
M97%U97-T<RP@8G5T('1H870@8V%N(&)E(&-H86YG960@96%S:6QY(&)Y('-I
M;7!L>0H@*B!A9&1I;F<@)S]W<V1L)R!T;R!T:&4@96YD(&]F('1H92!U<FPN
M"B`J+PHD=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]L;V-A;&AO<W0O
M4T]!4"]E>&%M<&QE+W-E<G9E<BYP:'`_=W-D;"(I.PHD<V]A<&-L:65N="`]
M("1W<V1L+3YG9710<F]X>2@I.PH*)')E="`]("1S;V%P8VQI96YT+3YE8VAO
M4W1R:6YG4VEM<&QE*")T:&ES(&ES(&$@=&5S="!S=')I;F<B*3L*(W!R:6YT
M("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["G!R:6YT7W(H)')E="D[96-H
M;R`B/&)R/EQN(CL*"B1R970@/2`D<V]A<&-L:65N="T^96-H;U-T<FEN9R@B
M=&AI<R!I<R!A('1E<W0@<W1R:6YG(BD["G!R:6YT7W(H)')E="D[96-H;R`B
M/&)R/EQN(CL*"B1R970@/2`D<V]A<&-L:65N="T^9&EV:61E*#(R+#<I.PHC
M('!R:6YT("1S;V%P8VQI96YT+3Y?7V=E=%]W:7)E*"D["FEF("A014%2.CII
M<T5R<F]R*"1R970I*0H@("`@<')I;G0H(D5R<F]R.B`B("X@)')E="T^9V5T
M365S<V%G92@I("X@(CQB<CY<;B(I.PIE;'-E"B`@("!P<FEN="@B475O=&EE
M;G0@:7,@(B`N("1R970@+B`B/&)R/EQN(BD["@HD<F5T(#T@)'-O87!C;&EE
M;G0M/F1I=FED92@R,BPP*3L*:68@*%!%05(Z.FES17)R;W(H)')E="DI"B`@
M("!P<FEN="@B17)R;W(Z("(@+B`D<F5T+3YG971-97-S86=E*"D@+B`B/&)R
M/EQN(BD["F5L<V4*("`@('!R:6YT*")1=6]T:65N="!I<R`B("X@)')E="`N
M("(\8G(^7&XB*3L*"@HO+R!33T%04W1R=6-T(&ES(&1E9FEN960@:6X@=&AE
M(&9O;&QO=VEN9R!F:6QE"G)E<75I<F5?;VYC92`G97AA;7!L95]T>7!E<RYP
M:'`G.PH*)'-T<G5C="`](&YE=R!33T%04W1R=6-T*"=T97-T('-T<FEN9R<L
M,3(S+#$R,RXQ,C,I.PH*+RH@<V5N9"!A;B!O8FIE8W0L(&=E="!A;B!O8FIE
M8W0@8F%C:R`J+PHO*B!T96QL(&-L:65N="!T;R!T<F%N<VQA=&4@=&\@8VQA
M<W-E<R!W92!P<F]V:61E(&EF('!O<W-I8FQE("HO"B1S;V%P8VQI96YT+3Y?
M875T;U]T<F%N<VQA=&EO;B`]('1R=64["B\J(&]R('EO=2!C86X@97AP;&EC
M:71L>2!S970@=&AE('1R86YS;&%T:6]N(&9O<@H@("!A('-P96-I9FEC(&-L
M87-S+B`@875T;U]T<F%N<VQA=&EO;B!W;W)K<R!F;W(@86QL(&-A<V5S+`H@
M("!B=70@;W!E;G,@04Y9(&-L87-S(&EN('1H92!S8W)I<'0@=&\@8F4@=7-E
M9"!A<R!A(&1A=&$@='EP92P*("`@86YD(&UA>2!N;W0@8F4@9&5S:7)E86)L
M92X@(&)O=&@@8V%N(&)E('5S960@;VX@8VQI96YT(&]R"B`@('-E<G9E<B`J
M+PHD<V]A<&-L:65N="T^7U]S971?='EP95]T<F%N<VQA=&EO;B@G>VAT='`Z
M+R]S;V%P:6YT97)O<"YO<F<O>'-D?5-/05!3=')U8W0G+"=33T%04W1R=6-T
M)RD["B1R970@/2`D<V]A<&-L:65N="T^96-H;U-T<G5C="@D<W1R=6-T+3Y?
M7W1O7W-O87`H*2D["B-P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER92@I
M.PIP<FEN=%]R*"1R970I.PH*+RHJ"B`J(%!(4"!D;V5S;B=T('-U<'!O<G0@
M;75L=&EP;&4@3U54('!A<F%M971E<G,@:6X@9G5N8W1I;VX@8V%L;',L('-O
M('=E"B`J(&UU<W0@9&\@82!L:71T;&4@=V]R:R!T;R!M86ME(&ET(&AA<'!E
M;B!H97)E+B`@5&AI<R!R97%U:7)E<R!K;F]W;&5D9V4@;VX@=&AE"B`J(&1E
M=F5L;W!E<G,@<&%R="!T;R!F:6=U<F4@;W5T(&AO=R!T:&5Y('=A;G0@=&\@
M9&5A;"!W:71H(&ET+@H@*B\*)')E="`]("1S;V%P8VQI96YT+3YE8VAO4W1R
M=6-T07-3:6UP;&54>7!E<R@D<W1R=6-T+3Y?7W1O7W-O87`H*2D["FEF("A0
M14%2.CII<T5R<F]R*"1R970I*2!["B`@("!P<FEN="@B17)R;W(Z("(@+B`D
M<F5T+3YG971-97-S86=E*"D@+B`B/&)R/EQN(BD["GT@96QS92!["B`@("!L
M:7-T*"1S=')I;F<L("1I;G0L("1F;&]A="D@/2!A<G)A>5]V86QU97,H)')E
M="D["GT*96-H;R`B=F%R4W1R:6YG.B`D<W1R:6YG/&)R/EQN=F%R26YT.B`D
M:6YT/&)R/EQN=F%R1FQO870Z("1F;&]A=#QB<CY<;B(["@H_/@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]33T%0+V5X86UP;&4O8VQI96YT+G!H<```````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`Q,#`Q-2`Q,#4Q-30S-#$S,R`P,C,U-S(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+R\*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@
M-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,#(@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@
M('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA
M8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R<SH@4VAA;F4@0V%R879E;R`\4VAA;F5`0V%R879E;RYC;VT^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!C;&EE;G0N<&AP+'8@,2XQ,"`R,#`U
M+S`S+S$P(#(S.C$V.C,Y('EU;F]S:"!%>'`@)`HO+PII;F-L=61E*")33T%0
M+T-L:65N="YP:'`B*3L*"B\J*@H@*B!T:&ES(&-L:65N="!R=6YS(&%G86EN
M<W0@=&AE(&5X86UP;&4@<V5R=F5R(&EN(%-/05`O97AA;7!L92]S97)V97(N
M<&AP"B`J(&ET(&1O97,@;F]T('5S92!74T1,('1O(')U;B!T:&5S92!R97%U
M97-T<RP@8G5T('1H870@8V%N(&)E(&-H86YG960@96%S:6QY(&)Y('-I;7!L
M>0H@*B!A9&1I;F<@)S]W<V1L)R!T;R!T:&4@96YD(&]F('1H92!U<FPN"B`J
M+PHD<V]A<&-L:65N="`](&YE=R!33T%07T-L:65N="@B:'1T<#HO+VQO8V%L
M:&]S="]33T%0+V5X86UP;&4O<V5R=F5R+G!H<"(I.PHO+R!T:&ES(&YA;65S
M<&%C92!I<R!T:&4@<V%M92!A<R!D96-L87)E9"!I;B!S97)V97(N<&AP"B1O
M<'1I;VYS(#T@87)R87DH)VYA;65S<&%C92<@/3X@)W5R;CI33T%07T5X86UP
M;&5?4V5R=F5R)RP*("`@("`@("`@("`@("`@("`G=')A8V4G(#T^(#$I.PH*
M)')E="`]("1S;V%P8VQI96YT+3YC86QL*")E8VAO4W1R:6YG4VEM<&QE(BP*
M("`@("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@B:6YP
M=713=')I;F=3:6UP;&4B/3XB=&AI<R!I<R!A('1E<W0@<W1R:6YG(BDL"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D;W!T:6]N<RD["B-P<FEN="`D<V]A
M<&-L:65N="T^7U]G971?=VER92@I.PIP<FEN=%]R*"1R970I.V5C:&\@(CQB
M<CY<;B(["@HD<F5T(#T@)'-O87!C;&EE;G0M/F-A;&PH(F5C:&]3=')I;F<B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y*")I
M;G!U=%-T<FEN9R(]/B)T:&ES(&ES(&$@=&5S="!S=')I;F<B*2P*("`@("`@
M("`@("`@("`@("`@("`@("`@("1O<'1I;VYS*3L*<')I;G1?<B@D<F5T*3ME
M8VAO("(\8G(^7&XB.PH*)')E="`]("1S;V%P8VQI96YT+3YC86QL*")D:79I
M9&4B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'!A<F%M<R`](&%R<F%Y
M*")D:79I9&5N9"(]/C(R+")D:79I<V]R(CT^-RDL"B`@("`@("`@("`@("`@
M("`@("`@("`@("`D;W!T:6]N<RD["B,@<')I;G0@)'-O87!C;&EE;G0M/E]?
M9V5T7W=I<F4H*3L*:68@*%!%05(Z.FES17)R;W(H)')E="DI"B`@("!P<FEN
M="@B17)R;W(Z("(@+B`D<F5T+3YG971-97-S86=E*"D@+B`B/&)R/EQN(BD[
M"F5L<V4*("`@('!R:6YT*")1=6]T:65N="!I<R`B("X@)')E="`N("(\8G(^
M7&XB*3L*"B1R970@/2`D<V]A<&-L:65N="T^8V%L;"@B9&EV:61E(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1P87)A;7,@/2!A<G)A>2@B9&EV:61E
M;F0B/3XR,BPB9&EV:7-O<B(]/C`I+`H@("`@("`@("`@("`@("`@("`@("`@
M("`@)&]P=&EO;G,I.PII9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D*("`@('!R
M:6YT*")%<G)O<CH@(B`N("1R970M/F=E=$UE<W-A9V4H*2`N("(\8G(^7&XB
M*3L*96QS90H@("`@<')I;G0H(E%U;W1I96YT(&ES("(@+B`D<F5T("X@(CQB
M<CY<;B(I.PH*"B\O(%-/05!3=')U8W0@:7,@9&5F:6YE9"!I;B!T:&4@9F]L
M;&]W:6YG(&9I;&4*<F5Q=6ER95]O;F-E("=E>&%M<&QE7W1Y<&5S+G!H<"<[
M"@HD<W1R=6-T(#T@;F5W(%-/05!3=')U8W0H)W1E<W0@<W1R:6YG)RPQ,C,L
M,3(S+C$R,RD["@HO*B!S96YD(&%N(&]B:F5C="P@9V5T(&%N(&]B:F5C="!B
M86-K("HO"B\J('1E;&P@8VQI96YT('1O('1R86YS;&%T92!T;R!C;&%S<V5S
M('=E('!R;W9I9&4@:68@<&]S<VEB;&4@*B\*)'-O87!C;&EE;G0M/E]A=71O
M7W1R86YS;&%T:6]N(#T@=')U93L*+RH@;W(@>6]U(&-A;B!E>'!L:6-I=&QY
M('-E="!T:&4@=')A;G-L871I;VX@9F]R"B`@(&$@<W!E8VEF:6,@8VQA<W,N
M("!A=71O7W1R86YS;&%T:6]N('=O<FMS(&9O<B!A;&P@8V%S97,L"B`@(&)U
M="!O<&5N<R!!3ED@8VQA<W,@:6X@=&AE('-C<FEP="!T;R!B92!U<V5D(&%S
M(&$@9&%T82!T>7!E+`H@("!A;F0@;6%Y(&YO="!B92!D97-I<F5A8FQE+B`@
M8F]T:"!C86X@8F4@=7-E9"!O;B!C;&EE;G0@;W(*("`@<V5R=F5R("HO"B1S
M;V%P8VQI96YT+3Y?7W-E=%]T>7!E7W1R86YS;&%T:6]N*"=[:'1T<#HO+W-O
M87!I;G1E<F]P+F]R9R]X<V1]4T]!4%-T<G5C="<L)U-/05!3=')U8W0G*3L*
M)')E="`]("1S;V%P8VQI96YT+3YC86QL*")E8VAO4W1R=6-T(BP*("`@("`@
M("`@("`@("`@("`@("`@("`@("1P(#T@87)R87DH)VEN<'5T4W1R=6-T)R`]
M/B`D<W1R=6-T+3Y?7W1O7W-O87`H*2DL"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D;W!T:6]N<RD["B-P<FEN="`D<V]A<&-L:65N="T^7U]G971?=VER
M92@I.PIP<FEN=%]R*"1R970I.PH*+RHJ"B`J(%!(4"!D;V5S;B=T('-U<'!O
M<G0@;75L=&EP;&4@3U54('!A<F%M971E<G,@:6X@9G5N8W1I;VX@8V%L;',L
M('-O('=E"B`J(&UU<W0@9&\@82!L:71T;&4@=V]R:R!T;R!M86ME(&ET(&AA
M<'!E;B!H97)E+B`@5&AI<R!R97%U:7)E<R!K;F]W;&5D9V4@;VX@=&AE"B`J
M(&1E=F5L;W!E<G,@<&%R="!T;R!F:6=U<F4@;W5T(&AO=R!T:&5Y('=A;G0@
M=&\@9&5A;"!W:71H(&ET+@H@*B\*)')E="`]("1S;V%P8VQI96YT+3YC86QL
M*")E8VAO4W1R=6-T07-3:6UP;&54>7!E<R(L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`D<"`](&%R<F%Y*"=I;G!U=%-T<G5C="<@/3X@)'-T<G5C="T^
M7U]T;U]S;V%P*"DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO
M;G,I.PII9B`H4$5!4CHZ:7-%<G)O<B@D<F5T*2D@>PH@("`@<')I;G0H(D5R
M<F]R.B`B("X@)')E="T^9V5T365S<V%G92@I("X@(CQB<CY<;B(I.PI](&5L
M<V4@>PH@("`@;&ES="@D<W1R:6YG+"`D:6YT+"`D9FQO870I(#T@87)R87E?
M=F%L=65S*"1R970I.PI]"F5C:&\@(G9A<E-T<FEN9SH@)'-T<FEN9SQB<CY<
M;G9A<DEN=#H@)&EN=#QB<CY<;G9A<D9L;V%T.B`D9FQO870\8G(^7&XB.PH*
M/SX`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]3
M97)I86QI>F5R+V5X86UP;&5S````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,R(#`R-#`P,``@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE
M06YD16YC;V1E+G!H<```````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#(V,S8@,3`U,34T,S0Q,S(@,#,P,S(W`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_4$A0
M"B\J*@H@*B!%>&%M<&QE('1O(&1E;6]N<W1R871E('1H92!E;F-O9&5&=6YC
M=&EO;B!A;F0@9&5C;V1E1G5N8W1I;VX*("H@;W!T:6]N<RX*("H*("H@5&AI
M<R!A;&QO=W,@>6]U('1O(&%P<&QY(&-A;&QB86-K<R!T;R!Y;W5R(&1A=&$@
M=&AA="!I<R!C86QL960*("H@;VX@86QL('-T<FEN9W,@=VAI;&4@<V5R:6%L
M:7II;F<@86YD('5N<V5R:6%L:7II;F<N"B`J"B`J($!A=71H;W(@4W1E<&AA
M;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E<&]R
M=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE
M<BYP:'`G.PH@("`@<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H
M<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@(%A-3%]315))04Q)6D527T]05$E/3E])3D1%3E0@("`@("`@("`@("`@
M("`]/B`G("`@("<L"B`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,
M25I%4E]/4%1)3TY?3$E.14)214%+4R`@("`@("`@("`@/3X@(EQN(BP*("`@
M("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E]30T%,
M05)?05-?05144DE"551%4R`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@6$U,7U-%4DE!3$E:15)?3U!424].7T5.0T]$15]&54Y#("`@("`@("`@
M(#T^("=S=')T;W5P<&5R)PH@("`@("`@("`@("`@("`@("`@("D["B`@("`*
M("`@("1F;V\@/2!N97<@<W1D0VQA<W,H*3L*("`@("1F;V\M/F)A<B`](&YE
M=R!S=&1#;&%S<R@I.PH@("`@)&9O;RT^8F%R+3YT97-T("`]("=4:&ES(&ES
M(&$@=&5S="XG.PH@("`@)&9O;RT^8F%R+3YV86QU92`]("=4:&ES(&ES(&$@
M=F%L=64N)SL*("`@(`H@("`@)'-E<FEA;&EZ97(@/2`F;F5W(%A-3%]397)I
M86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI
M>F5R+3YS97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF("@D<F5S=6QT(#T]
M/2!T<G5E*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG971397)I86QI>F5D
M1&%T82@I.PH@("`@?0H*("`@(&5C:&\)(CQP<F4^(CL*("`@('!R:6YT7W(H
M(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*("`@(&5C:&\)(CPO<')E/B([
M"@H@("`@)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@I
M.PH@("`@)'5N<V5R:6%L:7IE<BT^<V5T3W!T:6]N*"=P87)S94%T=')I8G5T
M97,G+"!T<G5E*3L*("`@("1U;G-E<FEA;&EZ97(M/G-E=$]P=&EO;B@G9&5C
M;V1E1G5N8W1I;VXG+"`G<W1R=&]L;W=E<B<I.PH*("`@("1R97-U;'0@/2`D
M=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L*("`@(`H@("`@96-H
M;R`G/'!R93XG.PH@("`@<')I;G1?<B@D=6YS97)I86QI>F5R+3YG9715;G-E
M<FEA;&EZ961$871A*"DI.PH@("`@96-H;R`G/"]P<F4^)SL*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L
M:7IE<B]E>&%M<&QE<R]S97)I86QI>F5!<G)A>5=I=&A/8FIE8W1S+G!H<```
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C,W
M,B`Q,#4Q-30S-#$S,B`P,S$W,S``(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!S
M:&]W<R!H;W<@=&\@8W)E871E(&%N(%)$1B!D;V-U;65N=`H@*B!W:71H(&$@
M9F5W(&QI;F5S(&]F(&-O9&4N"B`J(%1H:7,@8V%N(&%L<V\@8F4@9&]N92!W
M:71H(&UO9&4@/3X@<VEM<&QE>&UL"B`J"B`J($!A=71H;W(@4W1E<&AA;B!3
M8VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B!`<V5E("`@('-E<FEA;&EZ94EN
M9&5X961!<G)A>2YP:'`*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI
M.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@
M("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`B
M:6YD96YT(B`@("`@("`@("`]/B`B("`@("(L"B`@("`@("`@("`@("`@("`@
M("`@("`@(")L:6YE8G)E86LB("`@("`@(#T^(")<;B(L"B`@("`@("`@("`@
M("`@("`@("`@("`@(")T>7!E2&EN=',B("`@("`@(#T^(&9A;'-E+`H@("`@
M("`@("`@("`@("`@("`@("`@("`B861D1&5C;"(@("`@("`@("`]/B!T<G5E
M+`H@("`@("`@("`@("`@("`@("`@("`@("`B96YC;V1I;F<B("`@("`@("`]
M/B`B551&+3@B"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@("`@)'-E
M<FEA;&EZ97(@/2!N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*("`@
M("1S97)I86QI>F5R+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?1$E%
M*3L*("`@(`H@("`@)&%R<F%Y(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@;F5W('-T9$-L87-S*"DL"B`@("`@("`@("`@("`@("`@("`@;F5W('-T
M9$-L87-S*"D*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<F5S
M=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D87)R87DI.PH@("`@"B`@
M("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\
M<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ
M97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO
M<')E/B(["B`@("!]"@H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I
M86QI>F4H)&%R<F%Y+"!A<G)A>2@@)V-L87-S07-486=.86UE)R`]/B!T<G5E
M("DI.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@
M("!E8VAO("`@("(\<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I
M97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@
M(&5C:&\@("`@(CPO<')E/B(["B`@("!]"B`@("`*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ
M94-$871A+G!H<````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#<R(#$P-3$U-#,T,3,R(#`R-S0V,``@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````\/U!(
M4`HO*BH*("H@6$U,(%-E<FEA;&EZ97(@97AA;7!L90H@*@H@*B!4:&ES(&5X
M86UP;&4@;6%K97,@=7-E(&]F('1H92!#1&%T82!S96-T:6]N<R!O<'1I;VX*
M("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T
M/@H@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*<F5Q=6ER95]O;F-E("=8
M34PO4V5R:6%L:7IE<BYP:'`G.PH*)'-E<FEA;&EZ97(@/2!N97<@6$U,7U-E
M<FEA;&EZ97(H*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T5224%,
M25I%4E]/4%1)3TY?24Y$14Y4+"`G("`@("<I.PHD<V5R:6%L:7IE<BT^<V5T
M3W!T:6]N*%A-3%]315))04Q)6D527T]05$E/3E]$149!54Q47U1!1RP@)VET
M96TG*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T5224%,25I%4E]/
M4%1)3TY?0T1!5$%?4T5#5$E/3E,L('1R=64I.PH*)&1A=&$@/2!A<G)A>2@*
M("`@("`@("`@("`G9F]O)R`]/B`G5&AI<R!I<R!S;VUE('1E>'0N+BXG+`H@
M("`@("`@("`@("=B87(G(#T^("<F(&5V96X@;6]R92!T97AT+BXN)RP*("`@
M("`@("`@("`G=&5S="<@/3X@87)R87DH)T9O;R<L("=&;V\@)B!B87(G*0H)
M"0DI.PH*)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I
M.PH*:68H("1R97-U;'0@/3T]('1R=64@*2!["@DD>&UL(#T@)'-E<FEA;&EZ
M97(M/F=E=%-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E/B<["B`@
M("!E8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D["B`@("!E8VAO("<\+W!R
M93XG.PI](&5L<V4@>PH@("`@)')E<W5L="T^9V5T365S<V%G92@I.PH@("`@
M97AI="@I.PI]"C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E
M<FEA;&EZ945M<'1Y07)R87DN<&AP`````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q,#8Q(#$P-3$U-#,T,3,R(#`S
M,#4W,P`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/U!(4`HO*BH*("H@5&AI<R!S:&]W<R!T:&%T(%A-3%]397)I86QI>F5R
M(&ES(&%B;&4@=&\@=V]R:R!W:71H"B`J(&5M<'1Y(&%R<F%Y<PH@*@H@*B!`
M875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R
M<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?;VYC92`G6$U,+U5N<V5R
M:6%L:7IE<BYP:'`G.PH*)'AM;"`](#P\/"!%3T8*/&%U=&]P86=E7V]P=&EO
M;G,@7V-L87-S/2)A=71O<&%G95]O<'1I;VYS(B`*7W1Y<&4](F]B:F5C="(^
M"CQV97)S:6]N(%]T>7!E/2)S=')I;F<B/C$N,#PO=F5R<VEO;CX*/&]P=&EO
M;G,@7W1Y<&4](F%R<F%Y(B`O/@H\+V%U=&]P86=E7V]P=&EO;G,^"D5/1CL*
M"B1U;G-E<FEA;&EZ97(@/2!N97<@6$U,7U5N<V5R:6%L:7IE<B@I.PHD<F5S
M=6QT(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"D["@II9B@@
M)')E<W5L="`]/3T@=')U92`I('L*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R
M:6YT7W(H)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I*3L*
M("`@(&5C:&\@)SPO<')E/B<["GT*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP
M;&5S+W-E<FEA;&EZ94EN9&5X961!<G)A>2YP:'``````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S-S`U(#$P-3$U-#,T
M,3,R(#`S,3`V-``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E
M<R!T:&4@=7-E(&]F"B`J(&UO9&4@/3X@<VEM<&QE>&UL"B`J"B`J($ET(&-A
M;B!B92!U<V5D('1O('-E<FEA;&EZ92!A;B!I;F1E>&5D(&%R<F%Y"B`J(&QI
M:V4@97AT+W-I;7!L97AM;"!D;V5S+"!B>2!U<VEN9R!T:&4@;F%M90H@*B!O
M9B!T:&4@<&%R96YT('1A9RP@=VAI;&4@;VUI='1I;F<@=&AI<R!T86<N"B`J
M"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@
M*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["B`@("`*("`@(')E<75I
M<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@("`D;W!T:6]N<R`]
M(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?24Y$14Y4("`@("`@(#T^("<@("`@)RP*("`@("`@("`@("`@
M("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7TQ)3D5"4D5!2U,@
M("`]/B`B7&XB+`H)"0D)"0E834Q?4T5224%,25I%4E]/4%1)3TY?4D]/5%].
M04U%("`@(#T^("=R9&8Z4D1&)RP*("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7U)/3U1?05144DE"4R`]/B!A<G)A>2@G
M=F5R<VEO;B<@/3X@)S`N.3$G*2P*("`@("`@("`@("`@("`@("`@("`@("`@
M6$U,7U-%4DE!3$E:15)?3U!424].7TU/1$4@("`@("`@("`]/B!834Q?4T52
M24%,25I%4E]-3T1%7U-)35!,15A-3`H@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O
M<'1I;VYS*3L*"B`@("`*("`@("1R9&8@/2!A<G)A>2@*"0D)"2=C:&%N;F5L
M)R`]/B!A<G)A>2@*"0D)"0D)"0D))W1I=&QE)R`]/B`G17AA;7!L92!21$8@
M8VAA;FYE;"<L"@D)"0D)"0D)"2=L:6YK)R`@/3X@)VAT='`Z+R]W=W<N<&AP
M+71O;VQS+F1E)RP*"0D)"0D)"0D))VEM86=E)PD]/@EA<G)A>2@*"0D)"0D)
M"0D)"0D)"0DG=&ET;&4G"3T^("=%>&%M<&QE(&EM86=E)RP*"0D)"0D)"0D)
M"0D)"0DG=7)L)PD]/@DG:'1T<#HO+W=W=RYP:'`M=&]O;',N9&4O:6UA9V4N
M9VEF)RP*"0D)"0D)"0D)"0D)"0DG;&EN:R<)/3X))VAT='`Z+R]W=W<N<&AP
M+71O;VQS+F1E)PH)"0D)"0D)"0D)"0D)*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)VET96TG("`@/3X@(&%R<F%Y*`H@("`@("`@
M("`@("`)"0D)"0D)"0D)"6%R<F%Y*`H@("`@("`@("`@("`)"0D)"0D)"0D)
M"0DG=&ET;&4G"3T^("=%>&%M<&QE(&ET96TG+`H@("`@("`@("`@("`)"0D)
M"0D)"0D)"0DG;&EN:R<)/3X@)VAT='`Z+R]E>&%M<&QE+F-O;2<*("`@("`@
M("`@("`@"0D)"0D)"0D)"0DI+`H@("`@("`@("`@("`)"0D)"0D)"0D)"6%R
M<F%Y*`H@("`@("`@("`@("`)"0D)"0D)"0D)"0DG=&ET;&4G"3T^("=!;F]T
M:&5R(&ET96TG+`H@("`@("`@("`@("`)"0D)"0D)"0D)"0DG;&EN:R<)/3X@
M)VAT='`Z+R]E>&%M<&QE+F-O;2<*("`@("`@("`@("`@"0D)"0D)"0D)"0DI
M+`H@("`@("`@("`@("`)"0D)"0D)"0D)"6%R<F%Y*`H@("`@("`@("`@("`)
M"0D)"0D)"0D)"0DG=&ET;&4G"3T^("=)('1H:6YK('EO=2!G970@:70N+BXG
M+`H@("`@("`@("`@("`)"0D)"0D)"0D)"0DG;&EN:R<)/3X@)VAT='`Z+R]E
M>&%M<&QE+F-O;2<*("`@("`@("`@("`@"0D)"0D)"0D)"0DI"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("D*"0D)"0D)"0DI"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@("`@
M)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)')D9BD["B`@("`*
M("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@("`@
M)SQP<F4^)SL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L
M:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@("`G
M/"]P<F4^)SL*("`@('T*/SX`````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S
M97)I86QI>F5);F1E>&5D07)R87E7:71H0V]N=&5X="YP:'`````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C$V-2`Q,#4Q-30S-#$S,B`P
M,S,R-C0`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]02%`*+RHJ"B`J(%1H:7,@97AA;7!L92!D96UO;G-T<F%T97,@=&AE
M('5S92!O9@H@*B!M;V1E(#T^('-I;7!L97AM;`H@*@H@*B!)="!C86X@8F4@
M=7-E9"!T;R!S97)I86QI>F4@86X@:6YD97AE9"!A<G)A>0H@*B!L:6ME(&5X
M="]S:6UP;&5X;6P@9&]E<RP@8GD@=7-I;F<@=&AE(&YA;64*("H@;V8@=&AE
M('!A<F5N="!T86<L('=H:6QE(&]M:71T:6YG('1H:7,@=&%G+@H@*@H@*B!`
M875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@
M("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PH@("`@"B`@("!R97%U:7)E7V]N
M8V4@)UA-3"]397)I86QI>F5R+G!H<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!4
M24].7TE.1$5.5"`@("`@("`]/B`G("`@("<L"B`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3("`@/3X@
M(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7T1%1D%53%1?5$%'("`]/B!A<G)A>2@I+`H@("`@("`@("`@("`@
M("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]404<@
M(#T^(&%R<F%Y*"=F;V]S)R`]/B`G9F]O)RP@)V)A<G,G(#T^("=B87(G*0H@
M("`@("`@("`@("`@("`@("`@("D["B`@("`*("`@("1S97)I86QI>F5R(#T@
M;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)&1A=&$@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`G9F]O<R<@/3X@87)R87DH
M)V]N92!F;V\G+"`G='=O(&9O;W,G+"`G=&AR964@9F]O<R<I+`H@("`@("`@
M("`@("`@("`@("`@("=B87)S)R`]/B!A<G)A>2@G;VYE(&)A<B<L("=T=V\@
M8F%R<R<L("=T:')E92!B87)S)RDL"B`@("`@("`@("`@("`@("`I.PH*("`@
M("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1D871A*3L*("`@
M(`H@("`@:68H("1R97-U;'0@/3T]('1R=64@*2!["B`@("`@("`@96-H;R`@
M("`G/'!R93XG.PH@("`@("`@(&5C:&\@("`@:'1M;&5N=&ET:65S*"1S97)I
M86QI>F5R+3YG971397)I86QI>F5D1&%T82@I*3L*("`@("`@("!E8VAO("`@
M("<\+W!R93XG.PH@("`@?0H_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-
M3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ94YU;&Q0<F]P97)T:65S
M+G!H<````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S,3$S(#$P-3$U-#,T,3,R(#`S,30V-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/U!(4`HO*BH*("H@5&AI<R!E
M>&%M<&QE(&1E;6]N<W1R871E<R!T:&4@=7-E(&]F"B`J(&EG;F]R94YU;&P@
M/3X@=')U90H@*@H@*B!)="!C86X@8F4@=7-E9"!T;R!S97)I86QI>F4@86X@
M:6YD97AE9"!A<G)A>0H@*B!L:6ME(&5X="]S:6UP;&5X;6P@9&]E<RP@8GD@
M=7-I;F<@=&AE(&YA;64*("H@;V8@=&AE('!A<F5N="!T86<L('=H:6QE(&]M
M:71T:6YG('1H:7,@=&%G+@H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!
M3$PI.PH@("`@"B`@("!R97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R+G!H
M<"<["@H@("`@)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@
M("`@("`@(FEN9&5N="(@("`@("`@("`]/B`G("`@("<L"B`@("`@("`@("`@
M("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@/3X@(EQN(BP*("`@("`@
M("`@("`@("`@("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!8
M34Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B`@("`*("`@("1O8FIE8W0@/2!N
M97<@<W1D0VQA<W,H*3L*("`@("1O8FIE8W0M/F9O;R`]("=B87(G.PH@("`@
M)&]B:F5C="T^8F%R(#T@;G5L;#L*("`@(`H@("`@)&%R<F%Y(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@)V9O;R<@/3X@)V)A<B<L"B`@("`@("`@
M("`@("`@("`@("`@)V)A<B<@/3X@;G5L;`H@("`@("`@("`@("`@("`@*3L*
M("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&]B
M:F5C="D["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@
M("`@(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I
M=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@
M("`@96-H;R`@("`B/"]P<F4^(CL*("`@('T*"B`@("`D<F5S=6QT(#T@)'-E
M<FEA;&EZ97(M/G-E<FEA;&EZ92@D87)R87DI.PH@("`@"B`@("!I9B@@)')E
M<W5L="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\<')E/B(["B`@
M("`@("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E
M<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO<')E/B(["B`@
M("!]"B`@("`*("`@("1S97)I86QI>F5R+3YS971/<'1I;VXH)VEG;F]R94YU
M;&PG+"!T<G5E*3L*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L
M:7IE*"1O8FIE8W0I.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I
M('L*("`@("`@("!E8VAO("`@("(\<')E/B(["B`@("`@("`@96-H;R`@("!H
M=&UL96YT:71I97,H)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI
M.PH@("`@("`@(&5C:&\@("`@(CPO<')E/B(["B`@("!]"B`@("`*("`@("1R
M97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1A<G)A>2D["B`@("`*
M("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH@("`@("`@(&5C:&\@("`@
M(CQP<F4^(CL*("`@("`@("!E8VAO("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L
M:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*2D["B`@("`@("`@96-H;R`@("`B
M/"]P<F4^(CL*("`@('T*/SX`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5/8FIE8W0N<&AP````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,C,T-B`Q,#4Q-30S-#$S,B`P,C<W,3,`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@:7,@:G5S
M="!A(&)A<VEC(&5X86UP;&4@=&AA="!S:&]W<PH@*B!H;W<@;V)J96-T<R!C
M86X@8F4@<V5R:6%L:7IE9"!S;R!T:&5Y(&-A;@H@*B!B92!F=6QL>2!R97-T
M;W)E9"!L871E<BX*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C
M:'-T0'!H<"YN970^"B`J+PH*+RHJ"B`J($5X86UP;&4@8VQA<W,@=&AA="!I
M;7!L96UE;G1S(%]?<VQE97`H*0H@*@H@*B!`<&%C:V%G92`@("!834Q?4V5R
M:6%L:7IE<@H@*B!`<W5B<&%C:V%G92!%>&%M<&QE<PH@*B\*8VQA<W,@37E#
M;&%S<PI["B`@("!V87(@)&9O;R`]("=4:&ES(&ES(&9O;RXG.PH@("`@=F%R
M("1B87(@/2`G5&AI<R!I<R!B87(N)SL*("`@(`H@("`@9G5N8W1I;VX@7U]S
M;&5E<"@I"B`@("!["B`@("`@("`@<F5T=7)N(&%R<F%Y*"=F;V\G*3L*("`@
M('T*?0H*97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L*"B\J*@H@*B!,;V%D(%A-
M3%]397)I86QI>F5R"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]397)I86QI>F5R
M+G!H<"<["@H*+R\@=&AI<R!I<R!J=7-T('1O(&=E="!A(&YE<W1E9"!O8FIE
M8W0*)'!E87)%<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@:G5S
M="!A;B!E<G)O<B!O8FIE8W0G+#$R,RD["@HD;W!T:6]N<R`](&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@/3X@(B`@("`B
M+`H@("`@("`@("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@/3X@(EQN
M(BP*("`@("`@("`@("`@("`@("`@("`B9&5F875L=%1A9TYA;64B(#T^(")U
M;FYA;65D271E;2(L"B`@("`@("`@("`@("`@("`@("`@(G1Y<&5(:6YT<R(@
M("`@("`]/B!T<G5E"B`@("`@("`@("`@("`@("`I.PH*)&9O;R`@("`]("`@
M;F5W('-T9$-L87-S.PHD9F]O+3YV86QU92`](")->2!V86QU92(["B1F;V\M
M/F5R<F]R(#T@)'!E87)%<G)O<CL*)&9O;RT^>&UL("`@/2`B8V]O;"(["@HD
M9F]O+3YO8FH)/2!N97<@37E#;&%S<R@I.PHD9F]O+3YA<G(@("`](&%R<F%Y
M*"D["B1F;V\M/GIE<F\@(#T@,#L*"@HD<V5R:6%L:7IE<B`]("9N97<@6$U,
M7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*)')E<W5L="`]("1S97)I86QI>F5R
M+3YS97)I86QI>F4H)&9O;RD["@II9B@@)')E<W5L="`]/3T@=')U92`I('L*
M"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H*3L*?0H*
M96-H;R`G/'!R93XG.PIE8VAO(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D["F5C
M:&\@)SPO<')E/B<["C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA
M;&EZ95)$1BYP:'```````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`T,S8T(#$P-3$U-#,T,3,R(#`R-S$R
M,@`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S(&AO=R!T;R!C<F5A=&4@
M86X@4D1&(&1O8W5M96YT"B`J('=I=&@@82!F97<@;&EN97,@;V8@8V]D92X*
M("H@5&AI<R!C86X@86QS;R!B92!D;VYE('=I=&@@;6]D92`]/B!S:6UP;&5X
M;6P*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN
M970^"B`J($!S964@("`@<V5R:6%L:7IE26YD97AE9$%R<F%Y+G!H<`H@*B\*
M("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O;F-E
M("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@("`@(")I;F1E;G0B("`@("`@("`@(#T^
M("(@("`@(BP*("`@("`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@
M("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G1Y<&5(
M:6YT<R(@("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@
M(")A9&1$96-L(B`@("`@("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@
M("`@("`@(")E;F-O9&EN9R(@("`@("`@(#T^(")55$8M."(L"@D)"0D)"2)R
M;V]T3F%M92(@("`@("`@(#T^(")R9&8Z4D1&(BP*("`@("`@("`@("`@("`@
M("`@("`@("`@(G)O;W1!='1R:6)U=&5S(B`@/3X@87)R87DH(G9E<G-I;VXB
M(#T^("(P+CDQ(BDL"@D)"0D)"2)D969A=6QT5&%G3F%M92(@(#T^(")I=&5M
M(BP*("`@("`@("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97-!<G)A>2(@
M/3X@(E]A='1R:6)U=&5S(@H@("`@("`@("`@("`@("`@("`@("D["B`@("`*
M("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS
M*3L*"B`@("`*("`@("1R9&8@("`@/2`@(&%R<F%Y*`H)"0D)"0DB8VAA;FYE
M;"(@/3X@87)R87DH"@D)"0D)"0D)"0D)(G1I=&QE(B`]/B`B17AA;7!L92!2
M1$8@8VAA;FYE;"(L"@D)"0D)"0D)"0D)(FQI;FLB("`]/B`B:'1T<#HO+W=W
M=RYP:'`M=&]O;',N9&4B+`H)"0D)"0D)"0D)"2)I;6%G92()/3X)87)R87DH
M"@D)"0D)"0D)"0D)"0D)"0DB=&ET;&4B"3T^(")%>&%M<&QE(&EM86=E(BP*
M"0D)"0D)"0D)"0D)"0D)"2)U<FPB"3T^"2)H='1P.B\O=W=W+G!H<"UT;V]L
M<RYD92]I;6%G92YG:68B+`H)"0D)"0D)"0D)"0D)"0D)(FQI;FLB"3T^"2)H
M='1P.B\O=W=W+G!H<"UT;V]L<RYD92(*"0D)"0D)"0D)"0D)"0D)*2P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B7V%T
M=')I8G5T97,B(#T^(&%R<F%Y*"`B<F1F.F%B;W5T(B`]/B`B:'1T<#HO+V5X
M86UP;&4N8V]M+V9O;V)A<BYH=&UL(B`I+`H)"0D)"0D)"0D)"6%R<F%Y*`H)
M"0D)"0D)"0D)"0DB=&ET;&4B"3T^(")%>&%M<&QE(&ET96TB+`H)"0D)"0D)
M"0D)"0DB;&EN:R()/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2(L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(")?871T
M<FEB=71E<R(@/3X@87)R87DH(")R9&8Z86)O=70B(#T^(")H='1P.B\O97AA
M;7!L92YC;VTO9F]O8F%R+FAT;6PB("D*"0D)"0D)"0D)"0DI+`H)"0D)"0D)
M"0D)"6%R<F%Y*`H)"0D)"0D)"0D)"0DB=&ET;&4B"3T^(")!;F]T:&5R(&ET
M96TB+`H)"0D)"0D)"0D)"0DB;&EN:R()/3X@(FAT='`Z+R]E>&%M<&QE+F-O
M;2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(")?871T<FEB=71E<R(@/3X@87)R87DH(")R9&8Z86)O=70B(#T^
M(")H='1P.B\O97AA;7!L92YC;VTO9F]O8F%R+FAT;6PB("D*"0D)"0D)"0D)
M"0DI+`H)"0D)"0D)"0D)"6%R<F%Y*`H)"0D)"0D)"0D)"0DB=&ET;&4B"3T^
M("))('1H:6YK('EO=2!G970@:70N+BXB+`H)"0D)"0D)"0D)"0DB;&EN:R()
M/3X@(FAT='`Z+R]E>&%M<&QE+F-O;2(L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(")?871T<FEB=71E<R(@/3X@
M87)R87DH(")R9&8Z86)O=70B(#T^(")H='1P.B\O97AA;7!L92YC;VTO9F]O
M8F%R+FAT;6PB("D*"0D)"0D)"0D)"0DI"@D)"0D)"0D)"0DI"B`@("`@("`@
M("`@("`@("`@("`@*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R
M+3YS97)I86QI>F4H)')D9BD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T
M<G5E("D@>PH@("`@("`@(&5C:&\@("`@(CQP<F4^(CL*("`@("`@("!E8VAO
M("`@(&AT;6QE;G1I=&EE<R@D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A
M=&$H*2D["B`@("`@("`@96-H;R`@("`B/"]P<F4^(CL*("`@('T*/SX`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R+V5X
M86UP;&5S+W-E<FEA;&EZ95-E;&5C=&EV94%T=')I8G5T97,N<&AP````````
M`````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S,34Q(#$P-3$U
M-#,T,3,R(#`S,C0W,@`@,```````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````\/U!(4`HO*BH*("H@5&AI<R!S:&]W<R!T:&%T(%A-3%]3
M97)I86QI>F5R(&ES(&%B;&4@=&\@=V]R:R!W:71H"B`J(&5M<'1Y(&%R<F%Y
M<PH@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE
M=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["G)E<75I<F5?;VYC92`G
M6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B1D871A(#T@87)R87DH"B`@("`@("`@
M("`@("`@("!A<G)A>2@G;F%M92<@/3X@)U-U<&5R;6%N)RP@)V%G92<@/3X@
M,S0L("=R96%L;F%M92<@/3X@)T-L87)K($ME;G0G*2P*("`@("`@("`@("`@
M("`@(&%R<F%Y*"=N86UE)R`]/B`G0F%T;6%N)RP@)V%G92<@/3X@,S(L("=R
M96%L;F%M92<@/3X@)T)R=6-E(%=A>6YE)RDL"B`@("`@("`@("`@("`@("`G
M=FEL;&%I;B<@/3X@87)R87DH)VYA;64G(#T^("=0<F]F97-S;W(@6F]O;2<L
M("=A9V4G(#T^("=U;FMN;W=N)RP@)W)E86QN86UE)R`]/B`G2'5N=&5R(%IO
M;&]M;VXG*0H@("`@("`@("`@("`I.PH*)'-E<FEA;&EZ97(@/2!N97<@6$U,
M7U-E<FEA;&EZ97(H*3L*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T52
M24%,25I%4E]/4%1)3TY?24Y$14Y4+"`G("`@("<I.PHD<V5R:6%L:7IE<BT^
M<V5T3W!T:6]N*%A-3%]315))04Q)6D527T]05$E/3E]$149!54Q47U1!1RP@
M)VAE<F\G*3L*"B1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PIE8VAO
M("<\<')E/B<["F5C:&\@(D1E9F%U;'0@8F5H879I;W5R.EQN(CL*96-H;R!H
M=&UL<W!E8VEA;&-H87)S*"1S97)I86QI>F5R+3YG971397)I86QI>F5D1&%T
M82@I*3L*96-H;R`G/"]P<F4^)SL*"B1S97)I86QI>F5R+3YS971/<'1I;VXH
M6$U,7U-%4DE!3$E:15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$53+"!T
M<G5E*3L*"B1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PIE8VAO("<\
M<')E/B<["F5C:&\@(EA-3%]315))04Q)6D527T]05$E/3E]30T%,05)?05-?
M05144DE"551%4R`]('1R=64Z7&XB.PIE8VAO(&AT;6QS<&5C:6%L8VAA<G,H
M)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PIE8VAO("<\+W!R
M93XG.PH*)'-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?4T5224%,25I%4E]/
M4%1)3TY?4T-!3$%27T%37T%45%))0E5415,L(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=H97)O)R`@("`]/B!A<G)A>2@G;F%M92<L("=A
M9V4G*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=FEL;&%I;B<@/3X@
M87)R87DH)W)E86QN86UE)RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I
M"B`@("`@("`@("`@("`@("`@("`@("`I.PH*)'-E<FEA;&EZ97(M/G-E<FEA
M;&EZ92@D9&%T82D["F5C:&\@)SQP<F4^)SL*96-H;R`B6$U,7U-%4DE!3$E:
M15)?3U!424].7U-#04Q!4E]!4U]!5%1224)55$53(&ES(&%N(&%R<F%Y.EQN
M(CL*96-H;R!H=&UL<W!E8VEA;&-H87)S*"1S97)I86QI>F5R+3YG971397)I
M86QI>F5D1&%T82@I*3L*96-H;R`G/"]P<F4^)SL*/SX`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE
M<R]S97)I86QI>F57:71H071T<FEB=71E<RYP:'`````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,C(S-B`Q,#4Q-30S-#$S
M,B`P,S$T-C4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]02%`*+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X86UP;&4*("H*
M("H@5&AI<R!E>&%M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-3%]397)I86QI
M>F5R(&ES(&%B;&4*("H@=&\@<V5R:6%L:7IE('-C86QA<B!V86QU97,@87,@
M86X@871T<FEB=71E(&EN<W1E860@;V8@82!N97-T960@=&%G+@H@*@H@*B!4
M:&4@<V%M92!S=')U8W1U<F4@;&EK92!I;B!S97)I86QI>F5/8FIE8W0N<&AP
M(&ES('-E<FEA;&EZ960N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!
M3$PI.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*
M"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@
M("`B:6YD96YT(B`@("`@("`@("`@("`]/B`B("`@("(L"B`@("`@("`@("`@
M("`@("`@("`@("`@(")L:6YE8G)E86LB("`@("`@("`@(#T^(")<;B(L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")D969A=6QT5&%G3F%M92(@("`@(#T^
M(")U;FYA;65D271E;2(L"@D)"0D)"2)S8V%L87)!<T%T=')I8G5T97,B(#T^
M('1R=64L"B`@("`@("`@("`@("`@("`@("`@*3L*("`@(`H@("`@+R\@=&AI
M<R!I<R!J=7-T('1O(&=E="!A(&YE<W1E9"!O8FIE8W0*("`@("1P96%R17)R
M;W(@/2!014%2.CIR86ES945R<F]R*"=4:&ES(&ES(&IU<W0@86X@97)R;W(@
M;V)J96-T)RPQ,C,I.PH)"B`@("`D9F]O("`@(#T@("!N97<@<W1D0VQA<W,[
M"B`@("`*("`@("1F;V\M/G9A;'5E(#T@(DUY('9A;'5E(CL*("`@("1F;V\M
M/F5R<F]R(#T@)'!E87)%<G)O<CL*("`@("1F;V\M/GAM;"`@(#T@(F-O;VPB
M.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D
M;W!T:6]N<RD["B`@("`*("`@("1R97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R
M:6%L:7IE*"1F;V\I.PH@("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I
M('L*"0DD>&UL(#T@)'-E<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D[
M"@H)("`@(&5C:&\)(CQP<F4^(CL*"2`@("!P<FEN=%]R*"!H=&UL<W!E8VEA
M;&-H87)S*"1X;6PI("D["@D@("`@96-H;PDB/"]P<F4^(CL*("`@('T@96QS
M92!["@D)96-H;PDB/'!R93XB.PH)"7!R:6YT7W(H)')E<W5L="D["@D)96-H
M;PDB/"]P<F4^(CL*"7T*"C\^````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+UA-3%]397)I86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A!='1R:6)U
M=&5S,BYP:'```````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`R-#,U(#$P-3$U-#,T,3,R(#`S,34U,``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/U!(4`HO*BH*("H@6$U,
M(%-E<FEA;&EZ97(@97AA;7!L90H@*@H@*B!4:&ES(&5X86UP;&4@9&5M;VYS
M=')A=&5S+"!H;W<@6$U,7U-E<FEA;&EZ97(@:7,@86)L90H@*B!T;R!S97)I
M86QI>F4@<')E9&5F:6YE9"!V86QU97,@87,@=&AE(&%T=')I8G5T97,@;V8@
M82!T86<*("H*("H@0&%U=&AO<B`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P
M:'`N;F5T/@H@*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@
M<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I
M;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@(")I;F1E;G0B
M("`@("`@("`@("`@(#T^("(@("`@(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@(FQI;F5B<F5A:R(@("`@("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@
M("`@("`@("`@("`@(F1E9F%U;'1486=.86UE(B`@("`@/3X@(G5N;F%M961)
M=&5M(BP*"0D)"0D)(G-C86QA<D%S071T<FEB=71E<R(@/3X@9F%L<V4L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")A='1R:6)U=&5S07)R87DB("`@(#T^
M("=?871T<FEB=71E<R<L"B`@("`@("`@("`@("`@("`@("`@("`@(")C;VYT
M96YT3F%M92(@("`@("`@(#T^("=?8V]N=&5N="<*("`@("`@("`@("`@("`@
M("`@("`I.PH*("`@("1D871A(#T@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@)V9O;R<@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("=?871T<FEB=71E<R<@/3X@87)R87DH("=V97)S:6]N)R`]
M/B`G,2XP)RP@)V9O;R<@/3X@)V)A<B<@*2P*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U]C;VYT96YT)R`@("`]/B`G=&5S="<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@
M("`@("`@("`@)W-C:'-T)R`]/B`G4W1E<&AA;B!38VAM:61T)PH@("`@("`@
M("`@("`@("`@*3L@("`@"B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-
M3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S
M97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PH@("`@"B`@("!I9B@@)')E
M<W5L="`]/3T@=')U92`I('L*"0DD>&UL(#T@)'-E<FEA;&EZ97(M/F=E=%-E
M<FEA;&EZ961$871A*"D["@H)("`@(&5C:&\)(CQP<F4^(CL*"2`@("!P<FEN
M=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D["@D@("`@96-H;PDB/"]P
M<F4^(CL*("`@('T@96QS92!["@D)96-H;PDB/'!R93XB.PH)"7!R:6YT7W(H
M)')E<W5L="D["@D)96-H;PDB/"]P<F4^(CL*"7T*"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L
M97,O<V5R:6%L:7IE5VET:$-O;6UE;G0N<&AP````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q,#`@,3`U,34T,S0Q
M,S(@,#,P-S(W`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0"B\J*@H@*B!4:&ES(&ES(&IU<W0@82!B87-I8R!E>&%M
M<&QE('1H870@<VAO=W,*("H@:&]W(&]B:F5C=',@8V%N(&)E('-E<FEA;&EZ
M960@<V\@=&AE>2!C86X*("H@8F4@9G5L;'D@<F5S=&]R960@;&%T97(N"B`J
M"B`J($!A=71H;W(@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@
M*B\*("`@(&5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@H@("`@<F5Q=6ER95]O
M;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@("`@(%A-3%]315))04Q)6D527T]0
M5$E/3E])3D1%3E0@("`@("`]/B`G("`@("<L"B`@("`@("`@("`@("`@("`@
M("`@("`@(%A-3%]315))04Q)6D527T]05$E/3E],24Y%0E)%04M3("`]/B`B
M7&XB+`H@("`@("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/
M4%1)3TY?0T]-345.5%]+15D@/3X@)V-O;6UE;G0G"B`@("`@("`@("`@("`@
M("`@("`@*3L*("`@(`H@("`@)&9O;R`](&YE=R!S=&1#;&%S<SL*("`@("1F
M;V\M/F-O;6UE;G0@/2`G5&AI<R!I<R!A(&-O;6UE;G0G.PH@("`@)&9O;RT^
M=F%L=64@("`]("=->2!V86QU92<["B`@("`*("`@("1F;V\M/F)A<B`@("`@
M/2!N97<@<W1D0VQA<W,H*3L*("`@("1F;V\M/F)A<BT^=F%L=64@("`]("=!
M;F]T:&5R('9A;'5E)SL*("`@("1F;V\M/F)A<BT^8V]M;65N="`]("=!;F]T
M:&5R(&-O;6UE;G0G.PH@("`@"B`@("`D9F]O+3YT;VUA=&\@("`@("`@("`@
M/2!N97<@<W1D0VQA<W,H*3L*("`@("1F;V\M/G1O;6%T;RT^8V]M;65N="`]
M("=!;F0@82!L87-T(&-O;6UE;G0G.PH@("`@"B`@("`D<V5R:6%L:7IE<B`]
M("9N97<@6$U,7U-E<FEA;&EZ97(H)&]P=&EO;G,I.PH@("`@"B`@("`D<F5S
M=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ92@D9F]O*3L*("`@(`H@("`@
M:68@*"1R97-U;'0@/3T]('1R=64I('L*"0DD>&UL(#T@)'-E<FEA;&EZ97(M
M/F=E=%-E<FEA;&EZ961$871A*"D["B`@("!]"@H@("`@96-H;R`G/'!R93XG
M.PH@("`@<')I;G1?<BAH=&UL<W!E8VEA;&-H87)S*"1X;6PI*3L*("`@(&5C
M:&\@)SPO<')E/B<["C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]E>&%M<&QE+GAM;```````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#$R,B`Q,#4Q-30S-#$S,B`P,C8R,C<`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/'AM;#X*("`@(#QT97-T
M(&9O;STB8F%R(CX*("`@("`@("!497-T"B`@("`@("`@/'1A9SYT97-T/"]T
M86<^"B`@("`\+W1E<W0^"CPO>&UL/@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA
M;&EZ97(O97AA;7!L97,O<V5R:6%L:7IE5VET:$1T9"YP:'``````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(P
M,#<@,3`U,34T,S0Q,S(@,#,P,#0V`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@
M<VAO=W,@:&]W('1O(&%D9"!A($1O8U1Y<&4@1&5C;&%R871I;VX@=&\@=&AE
M(%A-3"!D;V-U;65N=`H@*@H@*B!`875T:&]R(%-T97!H86X@4V-H;6ED="`\
M<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O<G1I;F<H15]!3$PI
M.PH*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N<&AP)SL*"B`@
M("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`B
M:6YD96YT(B`@("`@/3X@(B`@("`B+`H@("`@("`@("`@("`@("`@("`@("`@
M("`B;&EN96)R96%K(B`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@("`@
M("`@(F%D9$1E8VPB("`@(#T^('1R=64L"B`@("`@("`@("`@("`@("`@("`@
M("`@(")A9&1$;V-T>7!E(B`]/B!T<G5E+`H@("`@("`@("`@("`@("`@("`@
M("`@("`B9&]C='EP92(@("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<FDG(#T^("=H='1P
M.B\O<&5A<BYP:'`N;F5T+V1T9"]P86-K86=E+3$N,"<L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=I9"<@/3X@
M)RTO+U!(4"\O4$5!4B]$5$0@4$%#2T%'12`P+C$G"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@
M("`@("`@("`I.PH@("`@"B`@("`D<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R
M:6%L:7IE<B@D;W!T:6]N<RD["@H@("`@)&9O;R`@("`]("`@4$5!4CHZ<F%I
M<V5%<G)O<B@B2G5S="!A('1E<W0B+"`Q,C,T*3L@("`@"B`@("`*("`@("1R
M97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH@("`@"B`@
M("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*("`@("`@("!E8VAO("`@("(\
M<')E/B(["B`@("`@("`@96-H;R`@("!H=&UL96YT:71I97,H)'-E<FEA;&EZ
M97(M/F=E=%-E<FEA;&EZ961$871A*"DI.PH@("`@("`@(&5C:&\@("`@(CPO
M<')E/B(["B`@("!]"C\^````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI
M>F57:71H26YD96YT961!='1R:6)U=&5S+G!H<``````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,C8Q,B`Q,#4Q-30S-#$S,B`P,S,Q,S8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]0
M2%`*+RHJ"B`J(%A-3"!397)I86QI>F5R(&5X86UP;&4*("H*("H@5&AI<R!E
M>&%M<&QE(&1E;6]N<W1R871E<RP@:&]W(%A-3%]397)I86QI>F5R(&ES(&%B
M;&4*("H@=&\@<V5R:6%L:7IE('-C86QA<B!V86QU97,@87,@86X@871T<FEB
M=71E(&EN<W1E860@;V8@82!N97-T960@=&%G+@H@*@H@*B!);B!T:&ES(&5X
M86UP;&4@=&%G<R!W:71H(&UO<F4@=&AA;B!O;F4@871T<FEB=71E(&)E8V]M
M90H@*B!M=6QT:6QI;F4@=&%G<RP@87,@96%C:"!A='1R:6)U=&4@9V5T<R!W
M<FET=&5N('1O(&$*("H@<V5P87)A=&4@;&EN92!A<R`G:6YD96YT071T<FEB
M=71E<R<@:7,@<V5T('1O("=?875T;R<N"B`J"B`J($!A=71H;W(@(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"B`@("!E<G)O<E]R97!O
M<G1I;F<H15]!3$PI.PH@("`@<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE
M<BYP:'`G.PH*("`@("1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@("`@("`@(")I;F1E;G0B("`@("`@("`@("`@(#T^("(@("`@(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@(FQI;F5B<F5A:R(@("`@("`@("`@/3X@
M(EQN(BP*("`@("`@("`@("`@("`@("`@("`@("`@(G1Y<&5(:6YT<R(@("`@
M("`@("`@/3X@9F%L<V4L"B`@("`@("`@("`@("`@("`@("`@("`@(")D969A
M=6QT5&%G3F%M92(@("`@(#T^(")U;FYA;65D271E;2(L"B`@("`@("`@("`@
M("`@("`@("`@("`@(")S8V%L87)!<T%T=')I8G5T97,B(#T^('1R=64L"B`@
M("`@("`@("`@("`@("`@("`@("`@(")I;F1E;G1!='1R:6)U=&5S(B`@(#T^
M(")?875T;R(*("`@("`@("`@("`@("`@("`@("`I.PH@("`@"B`@("`O+R!T
M:&ES(&ES(&IU<W0@=&\@9V5T(&$@;F5S=&5D(&]B:F5C=`H@("`@)'!E87)%
M<G)O<B`](%!%05(Z.G)A:7-E17)R;W(H)U1H:7,@:7,@:G5S="!A;B!E<G)O
M<B!O8FIE8W0G+#$R,RD["@D*("`@("1F;V\@("`@/2`@(&YE=R!S=&1#;&%S
M<SL*("`@(`H@("`@)&9O;RT^=F%L=64@/2`B37D@=F%L=64B.PH@("`@)&9O
M;RT^97)R;W(@/2`D<&5A<D5R<F]R.PH@("`@)&9O;RT^>&UL("`@/2`B8V]O
M;"(["B`@("`*("`@("1S97)I86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R
M*"1O<'1I;VYS*3L*("`@(`H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS
M97)I86QI>F4H)&9O;RD["B`@("`*("`@(&EF*"`D<F5S=6QT(#T]/2!T<G5E
M("D@>PH)"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L:7IE9$1A=&$H
M*3L*"@D@("`@96-H;PDB/'!R93XB.PH)("`@('!R:6YT7W(H(&AT;6QS<&5C
M:6%L8VAA<G,H)'AM;"D@*3L*"2`@("!E8VAO"2(\+W!R93XB.PH@("`@?2!E
M;'-E('L*"0EE8VAO"2(\<')E/B(["@D)<')I;G1?<B@D<F5S=6QT*3L*"0EE
M8VAO"2(\+W!R93XB.PH)?0H*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W-E<FEA;&EZ95=I=&A.86UE<W!A8V4N<&AP````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`R
M,#,S(#$P-3$U-#,T,3,R(#`S,3(R-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/U!(4`HO*BH*("H@17AA;7!L92!T:&%T
M(&-R96%T97,@=&%G<R!W:71H(&$@;F%M97-P86-E"B`J"B`J($!A=71H;W(@
M4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`N;F5T/@H@*B\*97)R;W)?<F5P
M;W)T:6YG*$5?04Q,*3L*"G)E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ97(N
M<&AP)SL*"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M)VEN9&5N="<@("`@("`@("`]/B`G("`G+`H@("`@("`@("`@("`@("`@("`@
M("=L:6YE8G)E86LG("`@("`@/3X@(EQN(BP*("`@("`@("`@("`@("`@("`@
M("`G9&5F875L=%1A9TYA;64G(#T^("=I=&5M)RP*("`@("`@("`@("`@("`@
M("`@("`G;F%M97-P86-E)R`@("`@(#T^("=F;V\G"B`@("`@("`@("`@("`@
M("`I.PH*)&9O;R`@("`]("`@;F5W('-T9$-L87-S.PHD9F]O+3YV86QU92`]
M("=->2!V86QU92<["B1F;V\M/GAM;"`@(#T@)V-O;VPG.PH*)&9O;RT^;V)J
M"3T@;F5W('-T9$-L87-S.PHD9F]O+3YA<G(@("`](&%R<F%Y*"D["B1F;V\M
M/GIE<F\@(#T@,#L*"B1S97)I86QI>F5R(#T@)FYE=R!834Q?4V5R:6%L:7IE
M<B@D;W!T:6]N<RD["@HD<F5S=6QT(#T@)'-E<FEA;&EZ97(M/G-E<FEA;&EZ
M92@D9F]O*3L*"FEF*"`D<F5S=6QT(#T]/2!T<G5E("D@>PH))'AM;"`]("1S
M97)I86QI>F5R+3YG971397)I86QI>F5D1&%T82@I.PI]"@IE8VAO"2<\<')E
M/B<["G!R:6YT7W(H(&AT;6QS<&5C:6%L8VAA<G,H)'AM;"D@*3L*96-H;PDG
M/"]P<F4^)SL*"B\O(&%L<V\@<&%S<R!T:&4@55))"B1S97)I86QI>F5R+3YS
M971/<'1I;VXH)VYA;65S<&%C92<L(&%R<F%Y*"=B87(G+"`G:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+UA-3%]397)I86QI>F5R)RDI.PH*)')E<W5L
M="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&9O;RD["@II9B@@)')E<W5L
M="`]/3T@=')U92`I('L*"21X;6P@/2`D<V5R:6%L:7IE<BT^9V5T4V5R:6%L
M:7IE9$1A=&$H*3L*?0H*96-H;PDG/'!R93XG.PIP<FEN=%]R*"!H=&UL<W!E
M8VEA;&-H87)S*"1X;6PI("D["F5C:&\))SPO<')E/B<["C\^````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O<V5R:6%L
M:7IE5VET:%1A9TUA<"YP:'``````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#0Q-#0@,3`U,34T,S0Q,S(@,#,P-3$P
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M4$A0"B\J*@H@*B!834P@4V5R:6%L:7IE<B!E>&%M<&QE"B`J"B`J(%1H:7,@
M97AA;7!L92!D96UO;G-T<F%T97,L(&AO=R!834Q?4V5R:6%L:7IE<B!I<R!A
M8FQE"B`J('1O('-E<FEA;&EZ92!S8V%L87(@=F%L=65S(&%S(&%N(&%T=')I
M8G5T92!I;G-T96%D(&]F(&$@;F5S=&5D('1A9RX*("H*("H@26X@=&AI<R!E
M>&%M<&QE('1A9W,@=VET:"!M;W)E('1H86X@;VYE(&%T=')I8G5T92!B96-O
M;64*("H@;75L=&EL:6YE('1A9W,L(&%S(&5A8V@@871T<FEB=71E(&=E=',@
M=W)I='1E;B!T;R!A"B`J('-E<&%R871E(&QI;F4@87,@)VEN9&5N=$%T=')I
M8G5T97,G(&ES('-E="!T;R`G7V%U=&\G+@H@*@H@*B!`875T:&]R("!3=&5P
M:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J+PH@("`@97)R;W)?<F5P
M;W)T:6YG*$5?04Q,*3L*("`@(')E<75I<F5?;VYC92`G6$U,+U-E<FEA;&EZ
M97(N<&AP)SL*"B`@("`D;W!T:6]N<R`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`G:6YD96YT)R`@("`@("`@("`@("`]/B`G("`@("<L"B`@
M("`@("`@("`@("`@("`@("`@("`@("=L:6YE8G)E86LG("`@("`@("`@(#T^
M(")<;B(L"B`@("`@("`@("`@("`@("`@("`@("`@("=M;V1E)R`@("`@("`@
M("`@("`@(#T^("=S:6UP;&5X;6PG+`H@("`@("`@("`@("`@("`@("`@("`@
M("`G<F]O=$YA;64G"0D)(#T^("=I=&5M<R<*("`@("`@("`@("`@("`@("`@
M("`I.PH*("`@("1D871A(#T@87)R87DH"@D)"0D))VET96TG(#T^(&%R<F%Y
M*"!A<G)A>2@*"0D)"0D)"0D)"2=T:71L92<@("`@("`@/3X@)T9O;V)A<B$G
M+`H)"0D)"0D)"0D))V1E<V-R:7!T:6]N)R`]/B`G5&AI<R!I<R!S;VUE('1E
M>'0N+BXN)RP*"0D)"0D)"0D)"2=L:6YK)R`@("`@("`@/3X@)VAT='`Z+R]F
M;V]B87(N8V]M)PH)"0D)"0D)"0DI+`H)"0D)"0D)"0EA<G)A>2@*"0D)"0D)
M"0D)"2=T:71L92<@("`@("`@/3X@)T9O;V)A<C(A)RP*"0D)"0D)"0D)"2=D
M97-C<FEP=&EO;B<@/3X@)U1H:7,@:7,@<V]M92!T97AT+OP@)G5U;6P[(.0@
M]B<L"@D)"0D)"0D)"0DG;&EN:R<@("`@("`@(#T^("=H='1P.B\O9F]O8F%R
M+F-O;2<*"0D)"0D)"0D)*0H)"0D)"0D)"2D*"2`@("`)"0D)"0D)"0D)"0D*
M("`@(`D)"2D["B`@("`@("`@("`@("`@("`@("`@"B`@("`*("`@("1S97)I
M86QI>F5R(#T@;F5W(%A-3%]397)I86QI>F5R*"1O<'1I;VYS*3L*("`@(`H@
M("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I86QI>F4H)&1A=&$I.PH@
M("`@"B`@("!I9B@@)')E<W5L="`]/3T@=')U92`I('L*"0DD>&UL(#T@)'-E
M<FEA;&EZ97(M/F=E=%-E<FEA;&EZ961$871A*"D["@H)("`@(&5C:&\))SQP
M<F4^)SL*"2`@("!P<FEN=%]R*"!H=&UL<W!E8VEA;&-H87)S*"1X;6PI("D[
M"@D@("`@96-H;PDG/"]P<F4^)SL*("`@('T@96QS92!["@D)96-H;PDG/'!R
M93XG.PH)"7!R:6YT7W(H)')E<W5L="D["@D)96-H;PDG/"]P<F4^)SL*"7T*
M"@DD;F5W3W!T:6]N<R`](&%R<F%Y*`H)"0D)"0DG<F]O=$YA;64G(#T^("=B
M;V1Y)RP*"0D)"0D))W)E<&QA8V5%;G1I=&EE<R<@/3X@6$U,7U-%4DE!3$E:
M15)?14Y4251)15-?2%1-3"P*"0D)"0D))W1A9TUA<"<@("`]/B!A<G)A>2@*
M"0D)"0D)("`@("`@("`@("`@("`@("`@("`@("=I=&5M)R`@("`@("`@/3X@
M)V1I=B<L"@D)"0D)"2`@("`@("`@("`@("`@("`@("`@("`G=&ET;&4G("`@
M("`@(#T^("=H,2<L"@D)"0D)"2`@("`@("`@("`@("`@("`@("`@("`G9&5S
M8W)I<'1I;VXG(#T^("=P)RP*"0D)"0D)("`@("`@("`@("`@("`@("`@("`@
M("=L:6YK)R`@("`@("`@/3X@)W1T)PH)"0D)"0D@("`@("`@("`@("`@("`@
M("`I"@D)"0D)*3L*"0H@("`@)')E<W5L="`]("1S97)I86QI>F5R+3YS97)I
M86QI>F4H)&1A=&$L("1N97=/<'1I;VYS*3L*("`@(`H@("`@:68H("1R97-U
M;'0@/3T]('1R=64@*2!["@D))'AM;"`]("1S97)I86QI>F5R+3YG971397)I
M86QI>F5D1&%T82@I.PH*"2`@("!E8VAO"2<\<')E/B<["@D@("`@<')I;G1?
M<B@@:'1M;'-P96-I86QC:&%R<R@D>&UL*2`I.PH)("`@(&5C:&\))SPO<')E
M/B<["B`@("!](&5L<V4@>PH)"65C:&\))SQP<F4^)SL*"0EP<FEN=%]R*"1R
M97-U;'0I.PH)"65C:&\))SPO<')E/B<["@E]"@H_/@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA
M;7!L97,O=6YS97)I86QI>F5!;GE834PN<&AP````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4P-C$@,3`U,34T
M,S0Q,S(@,#,P,34U`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@9&EF
M9F5R96YT(&UE=&AO9',@:&]W"B`J(%A-3%]5;G-E<FEA;&EZ97(@8V%N(&)E
M('5S960@=&\@8W)E871E(&1A=&$@<W1R=6-T=7)E<PH@*B!F<F]M(%A-3"!D
M;V-U;65N=',N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H
M<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO+R!T
M:&ES(&ES(&$@<VEM<&QE(%A-3"!D;V-U;65N=`HD>&UL(#T@)SQU<V5R<SXG
M("X*("`@("`@("<@(#QU<V5R(&AA;F1L93TB<V-H<W0B/E-T97!H86X@4V-H
M;6ED=#PO=7-E<CXG("X*("`@("`@("<@(#QU<V5R(&AA;F1L93TB;6HB/DUA
M<G1I;B!*86YS96X\+W5S97(^)R`N"B`@("`@("`G("`\9W)O=7`@;F%M93TB
M<6$B/E!%05(@44$@5&5A;3PO9W)O=7`^)R`N"B`@("`@("`G("`\9F]O(&ED
M/2)T97-T(CY4:&ES(&ES(&AA;F1L960@8GD@=&AE(&1E9F%U;'0@:V5Y071T
M<FEB=71E/"]F;V\^)R`N"B`@("`@("`G("`\9F]O(&ED/2)T97-T,B(^06YO
M=&AE<B!F;V\@=&%G/"]F;V\^)R`N"B`@("`@("`G/"]U<V5R<SXG.PH*<F5Q
M=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HO+R!C;VUP;&5X
M('-T<G5C='5R97,@87)E(&%R<F%Y<RP@=&AE(&ME>2!I<R!T:&4@871T<FEB
M=71E("=H86YD;&4G(&]R("=N86UE)RP@:68@:&%N9&QE(&ES(&YO="!P<F5S
M96YT"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4@/3X@)V%R<F%Y)RP*("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]!5%1224)5
M5$5?2T59(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G=7-E<B<@
M("`@(#T^("=H86YD;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G9W)O=7`G
M("`@(#T^("=N86UE)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)R-D969A=6QT
M)R`]/B`G:60G"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@
M("`I.PH*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S92!T:&4@86UP97)S
M86YD(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@"B1U;G-E<FEA;&EZ
M97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*+R\@=7-E
M<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M
M/G5N<V5R:6%L:7IE*"1X;6PL(&9A;'-E*3L@("`@"@II9B`H4$5!4CHZ:7-%
M<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S
M+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA
M;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^
M)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H*
M"B\O('5N<V5R:6%L:7IE(&ET(&%G86EN(&%N9"!C:&%N9V4@=&AE(&-O;7!L
M97A4>7!E(&]P=&EO;@HO+R!B=70@;&5A=F4@;W1H97(@;W!T:6]N<R!U;G1O
M=6-H960*+R\@;F]W(&-O;7!L97@@='EP97,@=VEL;"!B92!A;B!O8FIE8W0L
M(&%N9"!T:&4@<')O<&5R='D@;F%M92!W:6QL(&)E(&EN('1H90HO+R!A='1R
M:6)U=&4@)VAA;F1L92<*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R
M:6%L:7IE*"1X;6PL(&9A;'-E+"!A<G)A>2A834Q?54Y315))04Q)6D527T]0
M5$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RDI.PH*:68@*%!%05(Z.FES
M17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@)'-T871U
M<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=6YS97)I
M86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E
M/B<["B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E/B<["GT*
M"B\O('5N<V5R:6%L:7IE(&ET(&%G86EN(&%N9"!C:&%N9V4@=&AE(&-O;7!L
M97A4>7!E(&]P=&EO;@HO+R!A;F0@<F5S970@86QL(&]T:&5R(&]P=&EO;G,*
M+R\@3F]W+"!T:&5R92=S(&YO(&ME>2!S;R!T:&4@=&%G<R!A<F4@<W1O<F5D
M(&EN(&%N(&%R<F%Y"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA
M;&EZ92@D>&UL+"!F86QS92P@87)R87DH6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?3U9%4E))1$5?3U!424].4R`]/B!T<G5E+"!834Q?54Y315))04Q)6D52
M7T]05$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RDI.R`@("`*"FEF("A0
M14%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N
M("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@
M)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H
M;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R
M93XG.PI]"C\^````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ
M94-L87-S3F%M97,N<&AP```````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,C,P-B`Q,#4Q-30S-#$S,B`P,S$P-S4`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]02%`*
M+RHJ"B`J($5X86UP;&4@=&AA="!S:&]W<R!H;W<@=&\@:6YF;'5E;F-E('1H
M92!C;&%S<V5S('1H870@87)E(&-R96%T960N"B`J"B`J($!A=71H;W(@("`@
M("!3=&5P:&%N(%-C:&UI9'0@/'-C:'-T0'!H<"YN970^"B`J($!C871E9V]R
M>2`@("!834P*("H@0'!A8VMA9V4@("`@(%A-3%]397)I86QI>F5R"B`J($!S
M=6)P86-K86=E("!%>&%M<&QE<PH@*B\*97)R;W)?<F5P;W)T:6YG*$5?04Q,
M*3L*"B\J*@H@*B!U<V5S(%A-3%]5;G-E<FEA;&EZ97(*("HO"G)E<75I<F5?
M;VYC92`G6$U,+U5N<V5R:6%L:7IE<BYP:'`G.PH*)'AM;"`](#P\/$5/5`H\
M<F]O=#X*("`@/&9O;SX*("`@("`\='EP93YB87(\+W1Y<&4^"B`@(#PO9F]O
M/@H@("`\8F%R('1Y<&4](F9O;R(O/@H\+W)O;W0^"D5/5#L*"F-L87-S(&9O
M;PI["GT*8VQA<W,@8F%R"GL*?0H*96-H;R`G/'!R93XG.PHO+R`@8F4@8V%R
M969U;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@
M=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N
M<V5R:6%L:7IE<B@I.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.
M4T5224%,25I%4E]/4%1)3TY?0T]-4$Q%6%194$4L("=O8FIE8W0G*3L*)'5N
M<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].
M7T%45%))0E5415-?4$%24T4L('1R=64I.PHD=6YS97)I86QI>F5R+3YS971/
M<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?4D5455).7U)%4U5,5"P@
M=')U92D["@HD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X
M;6PI.R`@("`*=F%R7V1U;7`H)&1A=&$I.PH*96-H;R`B1&\@;F]T('5S92!T
M86=N86UE(&%S(&-L87-S(&YA;65<;B(["B1U;G-E<FEA;&EZ97(M/G-E=$]P
M=&EO;BA834Q?54Y315))04Q)6D527T]05$E/3E]404=?05-?0TQ!4U-.04U%
M+"!F86QS92D["B1D871A(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H
M)'AM;"D[("`@(`IV87)?9'5M<"@@)&1A=&$@*3L*"F5C:&\@(E5S92!A(&1I
M9F9E<F5N="!D969A=6QT(&-L87-S7&XB.PHD=6YS97)I86QI>F5R+3YS971/
M<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1$5&055,5%]#3$%34RP@
M)V9O;R<I.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X
M;6PI.R`@("`*=F%R7V1U;7`H("1D871A("D["@IE8VAO("<\+W!R93XG.PH_
M/@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI
M>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE16YC;V1E9"YP:'``````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-C8U
M(#$P-3$U-#,T,3,R(#`S,#0Q-``@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H
M;W=S(&AO=R!T;R!S970@82!D:69F97)E;G0@=&%R9V5T(&5N8V]D:6YG"B`J
M"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*
M("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-
M3"]5;G-E<FEA;&EZ97(N<&AP)SL*"B1X;6P@/2`G/&1I8W0^"B`@(#QW;W)D
M/@H@("`@(#QE;CYC:&EC:V5N=VEN9W,\+V5N/@H@("`@(#QD93XG+G5T9CA?
M96YC;V1E*"=(Y&AN8VAE;F9L_&=E;"<I+B<\+V1E/@H@("`\+W=O<F0^"B`\
M+V1I8W0^)SL*("`@(`HO+R!S<&5C:69Y(&1I9F9E<F5N="!S;W5R8V4@86YD
M('1A<F=E="!E;F-O9&EN9W,*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@
M("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?14Y#3T1)3D=?4T]5
M4D-%(#T^("=55$8M."<L"B`@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!
M3$E:15)?3U!424].7T5.0T]$24Y'7U1!4D=%5"`]/B`G25-/+3@X-3DM,2<*
M("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@"B\O("!B92!C
M87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I;B!F<F]N="!O
M9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@)FYE=R!834Q?
M56YS97)I86QI>F5R*"1O<'1I;VYS*3L*"B\O('5S97)I86QI>F4@=&AE(&1O
M8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D
M>&UL*3L*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO
M("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*
M("`@("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS97)I86QI>F5D1&%T
M82@I.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?<B@D9&%T82D["B`@
M("!E8VAO("<\+W!R93XG.PI]"C\^````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]3
M97)I86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE16YU;2YP:'``````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,C0S(#$P-3$U-#,T,3,R(#`R-S<U,``@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M
M<&QE('-H;W=S(&AO=R!T;R!U<V4@=&AE(%A-3%]53E-%4DE!3$E:15)?3U!4
M24].7T9/4D-%7T5.54T*("H@;W!T:6]N"B`J"B`J($!A=71H;W(@(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN
M9RA%7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP
M)SL*"B1X;6PQ(#T@)SQR;V]T/@H@("`\:71E;3X*("`@("`\;F%M93YS8VAS
M=#PO;F%M93X*("`@/"]I=&5M/@H@("`\:71E;3X*("`@("`\;F%M93YL=6-K
M96,\+VYA;64^"B`@(#PO:71E;3X*(#PO<F]O=#XG.PH@("`@"B1X;6PR(#T@
M)SQR;V]T/@H@("`\:71E;3X*("`@("`\;F%M93YS8VAS=#PO;F%M93X*("`@
M/"]I=&5M/@H@/"]R;V]T/B<["B`@("`*)&]P=&EO;G,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?1D]20T5?
M14Y532`]/B!A<G)A>2@G:71E;2<I"B`@("`@("`@("`@("`@("`I.PH*("`@
M("`@("`@("`@("`@(`HO+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H
M92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N
M<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<RD[
M"@HO+R!U<V5R:6%L:7IE('1H92!D;V-U;65N=`HD<W1A='5S(#T@)'5N<V5R
M:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;#$I.PH*:68@*%!%05(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R.B`G("X@)'-T871U<RT^
M9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)&1A=&$@/2`D=6YS97)I86QI
M>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("!E8VAO("<\<')E/B<[
M"B`@("!P<FEN=%]R*"1D871A*3L*("`@(&5C:&\@)SPO<')E/B<["GT*"B\O
M('5S97)I86QI>F4@=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI
M>F5R+3YU;G-E<FEA;&EZ92@D>&UL,BD["@II9B`H4$5!4CHZ:7-%<G)O<B@D
M<W1A='5S*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG971-
M97-S86=E*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ97(M
M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*("`@
M('!R:6YT7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H_/@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U-E<FEA;&EZ97(O97AA;7!L97,O=6YS
M97)I86QI>F5/8FIE8W0N<&AP````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(W,#`@,3`U,34T,S0Q,S(@,#,P
M,C4P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_4$A0"B\J*@H@*B!4:&ES(&5X86UP;&4@<VAO=W,@:&]W(%A-3%]397)I
M86QI>F5R(&%N9"!834Q?56YS97)I86QI>F5R"B`J('=O<FL@=&]G971H97(N
M"B`J"B`J($$@<W1R=6-T=7)E(&ES('-E<FEA;&EZ960@86YD(&QA=&5R(&ET
M)W,@=6YS97)I86QI>F5D(&9R;VT@=&AE"B`J(')E<W5L=&EN9R!834P@9&]C
M=6UE;G0N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`
M<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D["@IR97%U:7)E
M7V]N8V4@)UA-3"]397)I86QI>F5R+G!H<"<["G)E<75I<F5?;VYC92`G6$U,
M+U5N<V5R:6%L:7IE<BYP:'`G.PHO+R!T:&ES(&ES(&IU<W0@=&\@9V5T(&$@
M;F5S=&5D(&]B:F5C=`HD<&5A<D5R<F]R(#T@4$5!4CHZ<F%I<V5%<G)O<B@G
M5&AI<R!I<R!J=7-T(&%N(&5R<F]R(&]B:F5C="<L,3(S*3L*"B1O<'1I;VYS
M(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@6$U,7U-%4DE!3$E:15)?
M3U!424].7TE.1$5.5"`@("`@(#T^("<@("`@)RP*("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?3$E.14)214%+4R`@/3X@(EQN
M(BP*("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?
M1$5&055,5%]404<@/3X@)W5N;F%M961)=&5M)RP*("`@("`@("`@("`@("`@
M("`@("!834Q?4T5224%,25I%4E]/4%1)3TY?5%E014A)3E13("`@/3X@=')U
M90H@("`@("`@("`@("`@("`@*3L*"B1F;V\@/2!N97<@<W1D0VQA<W,H*3L*
M)&9O;RT^=F%L=64@/2`G37D@=F%L=64G.PHD9F]O+3YE<G)O<B`]("1P96%R
M17)R;W(["B1F;V\M/GAM;"`@(#T@87)R87DH)U1H:7,@:7,G(#T^("=C;V]L
M)RD["B1F;V\M/G)E<V]U<F-E(#T@9F]P96XH7U]&24Q%7U\L("=R)RD["@HD
M<V5R:6%L:7IE<B`](&YE=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["B1R
M97-U;'0@/2`D<V5R:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH*:68@*"1R
M97-U;'0@/3T]('1R=64I('L*("`@("1X;6P@/2`D<V5R:6%L:7IE<BT^9V5T
M4V5R:6%L:7IE9$1A=&$H*3L*?0H*96-H;R`G/'!R93XG.PIE8VAO(&AT;6QS
M<&5C:6%L8VAA<G,H)'AM;"D["F5C:&\@)SPO<')E/B<["@HO+R`@8F4@8V%R
M969U;"!T;R!A;'=A>7,@=7-E('1H92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@
M=&AE(&YE=R!O<&5R871O<B`*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N
M<V5R:6%L:7IE<B@I.PH*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R
M:6%L:7IE*"1X;6PI.R`@("`*"FEF("A014%2.CII<T5R<F]R*"1S=&%T=7,I
M*2!["B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M/F=E=$UE<W-A9V4H
M*3L*?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L:7IE<BT^9V5T56YS
M97)I86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG.PH@("`@<')I;G1?
M<B@D9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^````````````````
M````````````````````````````````````````````````````````````
M`````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?
M4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95)$1BYP:'``````````
M```````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P
M,#`P-#$R,B`Q,#4Q-30S-#$S,B`P,C<T-34`(#``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-T87(`
M,#!B=6EL9&5R`````````````````````````````````&)R````````````
M````````````````````````````,#`P,#`P(``P,#`P,#`@````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````/#]02%`*+RHJ"B`J(%1H:7,@97AA
M;7!L92!S:&]W<R!H;W<@=&\@8W)E871E(&%N>2!O8FIE8W0*("H@9G)O;2!A
M;B!834P@9&]C=6UE;G0N($EN('1H:7,@8V%S92!W92!G970*("H@<V]M92!A
M9V=R96=A=&5D(&]B:F5C=',@9F]R(&-H86YN96P@86YD(&ET96US"B`J(&9R
M;VT@86X@4E-3(&9E960N"B`J"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED
M="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R<F]R7W)E<&]R=&EN9RA%7T%,3"D[
M"@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*"B\J*@HJ
M(&-L87-S(&9O<B!T:&4@4D1&(&1O8W5E;6YT"BH**@HJ+PIC;&%S<R!R9&9$
M;V-U;65N=`I["B`@("!V87(@)&-H86YN96P["B`@("!V87(@)&ET96T["@H@
M("`@9G5N8W1I;VX@9V5T271E;7,H)&%M;W5N="D*("`@('L*("`@("`@("!R
M971U<FX@87)R87E?<W!L:6-E*"1T:&ES+3YI=&5M+#`L)&%M;W5N="D["B`@
M("!]"GT*"@HO*BH**B!C;&%S<R!T:&%T(&ES('5S960@9F]R(&$@8VAA;FYE
M;"!I;B!T:&4@4E-3(&9I;&4**@HJ('EO=2!C;W5L9"!I;7!L96UE;G0@=VAA
M=&5V97(@>6]U(&QI:V4@:6X@=&AI<R!C;&%S<RP**B!P<F]P97)T:65S('=I
M;&P@8F4@<V5T(&9R;VT@=&AE(%A-3"!D;V-U;65N=`HJ+PIC;&%S<R!C:&%N
M;F5L"GL*("`@(&9U;F-T:6]N(&=E=%1I=&QE*"D*("`@('L*("`@("`@("!R
M971U<FX@("1T:&ES+3YT:71L93L*("`@('T*?0H*+RHJ"BH@8VQA<W,@=&AA
M="!I<R!U<V5D(&9O<B!A;B!I=&5M(&EN('1H92!24U,@9FEL90HJ"BH@>6]U
M(&-O=6QD(&EM<&QE;65N="!W:&%T979E<B!Y;W4@;&EK92!I;B!T:&ES(&-L
M87-S+`HJ('!R;W!E<G1I97,@=VEL;"!B92!S970@9G)O;2!T:&4@6$U,(&1O
M8W5M96YT"BHO"F-L87-S(&ET96T*>PH@("`@9G5N8W1I;VX@9V5T5&ET;&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`@)'1H:7,M/G1I=&QE.PH@("`@?0I]
M"@H*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("!834Q?54Y3
M15))04Q)6D527T]05$E/3E]#3TU03$585%E012`]/B`G;V)J96-T)RP*("`@
M("`@("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]404=?34%0
M("`@("`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)W)D9CI21$8G(#T^("=R
M9&9$;V-U;65N="<L("`@+R\@=&AI<R!I<R!U<V5D('1O('-P96-I9GD@82!C
M;&%S<VYA;64@9F]R('1H92!R;V]T('1A9PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@
M("`@("`@("`@("D["@HO+R`@8F4@8V%R969U;"!T;R!A;'=A>7,@=7-E('1H
M92!A;7!E<G-A;F0@:6X@9G)O;G0@;V8@=&AE(&YE=R!O<&5R871O<B`*)'5N
M<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@D;W!T:6]N<RD[
M"@HD<W1A='5S(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I86QI>F4H)VAT='`Z
M+R]P96%R+G!H<"YN970O9F5E9',O;&%T97-T+G)S<R<L=')U92D[("`@(`H*
M:68@*%!%05(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@)T5R<F]R
M.B`G("X@)'-T871U<RT^9V5T365S<V%G92@I.PI](&5L<V4@>PH@("`@)')S
M<R`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*"B`@
M("!E8VAO("=4:&ES(&AA<R!B965N(')E='5R;F5D(&)Y(%A-3%]5;G-E<FEA
M;&EZ97(Z/&)R/B<["B`@("`*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT
M7W(H)')S<RD["B`@("!E8VAO("<\+W!R93XG.PH*("`@(&5C:&\@)SQB<CX\
M8G(^4F]O="!486=N86UE.B`G+B1U;G-E<FEA;&EZ97(M/F=E=%)O;W1.86UE
M*"DN)SQB<CXG.PH@("`@"B`@("!E8VAO("=4:71L92!O9B!T:&4@8VAA;FYE
M;#H@)RXD<G-S+3YC:&%N;F5L+3YG9714:71L92@I+B<\8G(^)SL*"B`@("`D
M:71E;7,@/2`D<G-S+3YG971)=&5M<R@S*3L*("`@(&5C:&\@)SQB<CY4:71L
M97,@;V8@=&AE(&QA<W0@=&AR964@<F5L96%S97,Z/&)R/B<["B`@("!F;W)E
M86-H("@D:71E;7,@87,@)&ET96TI('L*("`@("`@("!E8VAO("=4:71L92`Z
M("<N)&ET96TM/F=E=%1I=&QE*"DN)SQB<CXG.PH@("`@?0I]"C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O9&]C<R]834Q?4V5R:6%L:7IE<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=H
M:71E<W!A8V4N<&AP```````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,C$S,"`Q,#4Q-30S-#$S,B`P,S$Q,S,`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]02%`*+RHJ
M"B`J(%1H:7,@97AA;7!L92!S:&]W<R!H;W<@=&\@<V5T(&$@9&EF9F5R96YT
M('1A<F=E="!E;F-O9&EN9PH@*@H@*B!`875T:&]R("!3=&5P:&%N(%-C:&UI
M9'0@/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I;F<H15]!3$PI
M.PH*<F5Q=6ER95]O;F-E("=834PO56YS97)I86QI>F5R+G!H<"<["@HD>&UL
M(#T@)SQX;6P^"B`@(#QS=')I;F<^"B`@(`H@("`@5&AI<R!834P*("`@(&1O
M8W5M96YT"B`@("!C;VYT86EN<PH@("`@;&EN92!B<F5A:W,N"@H@("`\+W-T
M<FEN9SX*(#PO>&UL/B<["@H*+R\@(&)E(&-A<F5F=6P@=&\@86QW87ES('5S
M92!T:&4@86UP97)S86YD(&EN(&9R;VYT(&]F('1H92!N97<@;W!E<F%T;W(@
M"B1U;G-E<FEA;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H*3L*)'5N
M<V5R:6%L:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].
M7U)%5%523E]215-53%0L('1R=64I.PH*96-H;R`G/'!R93XG.PH*96-H;R`B
M1&5F875L="!B96AA=FEO<B`H6$U,7U5.4T5224%,25I%4E]72$E415-004-%
M7U1224TI7&XB.PHD9&%T82`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE
M*"1X;6PI.PIV87)?9'5M<"@D9&%T82D["F5C:&\@(EQN7&XB.PH*96-H;R`B
M3F]R;6%L:7IE('=H:71E<W!A8V4@*%A-3%]53E-%4DE!3$E:15)?5TA)5$53
M4$%#15].3U)-04Q)6D4I7&XB.PHD=6YS97)I86QI>F5R+3YS971/<'1I;VXH
M6$U,7U5.4T5224%,25I%4E]/4%1)3TY?5TA)5$534$%#12P@6$U,7U5.4T52
M24%,25I%4E]72$E415-004-%7TY/4DU!3$E:12D["B1D871A(#T@)'5N<V5R
M:6%L:7IE<BT^=6YS97)I86QI>F4H)'AM;"D["G9A<E]D=6UP*"1D871A*3L*
M96-H;R`B7&Y<;B(["@IE8VAO(")+965P('=H:71E<W!A8V4@*%A-3%]53E-%
M4DE!3$E:15)?5TA)5$534$%#15]+1450*5QN(CL*)'5N<V5R:6%L:7IE<BT^
M<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7U=(251%4U!!0T4L
M(%A-3%]53E-%4DE!3$E:15)?5TA)5$534$%#15]+1450*3L*)&1A=&$@/2`D
M=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D>&UL*3L*=F%R7V1U;7`H)&1A
M=&$I.PH*96-H;R`G/"]P<F4^)SL*/SX`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I86QI>F5R
M+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:$%T=')I8G5T97,N<&AP````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`Q-#,T(#$P
M-3$U-#,T,3,R(#`S,C`R-P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE('-H;W=S
M(&AO=R!T;R!P87)S92!A='1R:6)U=&5S(&9R;VT*("H@6$U,('1A9W,N"B`J
M"B`J($!A=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*
M("H@0'5S97,@("`@97AA;7!L92YX;6P*("HO"F5R<F]R7W)E<&]R=&EN9RA%
M7T%,3"D["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N<&AP)SL*
M"B1O<'1I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`@(%A-3%]53E-%
M4DE!3$E:15)?3U!424].7T%45%))0E5415-?4$%24T4@("`@/3X@=')U92P*
M("`@("`@("`@("`@("`@("`@6$U,7U5.4T5224%,25I%4E]/4%1)3TY?0514
M4DE"551%4U]!4E)!64M%62`]/B!F86QS90H@("`@("`@("`@("`@("`@*3L*
M"B\O("!B92!C87)E9G5L('1O(&%L=V%Y<R!U<V4@=&AE(&%M<&5R<V%N9"!I
M;B!F<F]N="!O9B!T:&4@;F5W(&]P97)A=&]R(`HD=6YS97)I86QI>F5R(#T@
M)FYE=R!834Q?56YS97)I86QI>F5R*"1O<'1I;VYS*3L*"B\O('5S97)I86QI
M>F4@=&AE(&1O8W5M96YT"B1S=&%T=7,@/2`D=6YS97)I86QI>F5R+3YU;G-E
M<FEA;&EZ92@G97AA;7!L92YX;6PG+"!T<G5E*3L*"FEF("A014%2.CII<T5R
M<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO("=%<G)O<CH@)R`N("1S=&%T=7,M
M/F=E=$UE<W-A9V4H*3L*?2!E;'-E('L*("`@("1D871A(#T@)'5N<V5R:6%L
M:7IE<BT^9V5T56YS97)I86QI>F5D1&%T82@I.PH@("`@96-H;R`G/'!R93XG
M.PH@("`@<')I;G1?<B@D9&%T82D["B`@("!E8VAO("<\+W!R93XG.PI]"C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]397)I
M86QI>F5R+V5X86UP;&5S+W5N<V5R:6%L:7IE5VET:%1A9TUA<"YP:'``````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`S
M,3<U(#$P-3$U-#,T,3,R(#`S,3`U-@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/U!(4`HO*BH*("H@5&AI<R!E>&%M<&QE
M('-H;W=S(&AO=R!T;R!U<V4@=&AE('1A9TUA<"!O<'1I;VXN"B`J"B`J($!A
M=71H;W(@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("HO"F5R
M<F]R7W)E<&]R=&EN9RA%7T%,3"D["@HO+R!T:&ES(&ES(&$@<VEM<&QE(%A-
M3"!D;V-U;65N=`HD>&UL(#T@)SQR;V]T/B<@+@H@("`@("`@)R`@/&9O;SY&
M3T\\+V9O;SXG("X*("`@("`@("<@(#QB87(^0D%2/"]B87(^)R`N"B`@("`@
M("`G/"]R;V]T/B<["@IR97%U:7)E7V]N8V4@)UA-3"]5;G-E<FEA;&EZ97(N
M<&AP)SL*"B\O(&-O;7!L97@@<W1R=6-T=7)E<R!A<F4@87)R87ES+"!T:&4@
M:V5Y(&ES('1H92!A='1R:6)U=&4@)VAA;F1L92<@;W(@)VYA;64G+"!I9B!H
M86YD;&4@:7,@;F]T('!R97-E;G0*)&]P=&EO;G,@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@("!834Q?54Y315))04Q)6D527T]05$E/3E]#3TU03$585%E0
M12`]/B`G87)R87DG+`H@("`@("`@("`@("`@("`@(%A-3%]53E-%4DE!3$E:
M15)?3U!424].7U1!1U]-05`@("`@(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`G9F]O)R`]/B`G8F%R)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)V)A<B<@/3X@)V9O
M;R<*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`I.PH*+R\@(&)E
M(&-A<F5F=6P@=&\@86QW87ES('5S92!T:&4@86UP97)S86YD(&EN(&9R;VYT
M(&]F('1H92!N97<@;W!E<F%T;W(@"B1U;G-E<FEA;&EZ97(@/2`F;F5W(%A-
M3%]5;G-E<FEA;&EZ97(H)&]P=&EO;G,I.PH*+R\@=7-E<FEA;&EZ92!T:&4@
M9&]C=6UE;G0*)'-T871U<R`]("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE
M*"1X;6PL(&9A;'-E*3L@("`@"@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S
M*2D@>PH@("`@96-H;R`G17)R;W(Z("<@+B`D<W1A='5S+3YG971-97-S86=E
M*"D["GT@96QS92!["B`@("`D9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N
M<V5R:6%L:7IE9$1A=&$H*3L*("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT
M7W(H)&1A=&$I.PH@("`@96-H;R`G/"]P<F4^)SL*?0H*+R\@82!T860@;6]R
M92!C;VUP;&5X"B1X;6P@/2`G/')O;W0^)R`N"B`@("`@("`G("`\9F]O/B<N
M"B`@("`@("`G("`@(#QT;VUA=&\^-#4\+W1O;6%T;SXG+@H@("`@("`@)R`@
M/"]F;V\^)RX*("`@("`@("<@(#QB87(^)RX*("`@("`@("<@("`@/'1O;6%T
M;SXS,3PO=&]M871O/B<N"B`@("`@("`G("`\+V)A<CXG+@H@("`@("`@)SPO
M<F]O=#XG.PH*+R\@=7-E<FEA;&EZ92!T:&4@9&]C=6UE;G0*)'-T871U<R`]
M("1U;G-E<FEA;&EZ97(M/G5N<V5R:6%L:7IE*"1X;6PL(&9A;'-E*3L@("`@
M"@II9B`H4$5!4CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@96-H;R`G17)R
M;W(Z("<@+B`D<W1A='5S+3YG971-97-S86=E*"D["GT@96QS92!["B`@("`D
M9&%T82`]("1U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L:7IE9$1A=&$H*3L*
M("`@(&5C:&\@)SQP<F4^)SL*("`@('!R:6YT7W(H)&1A=&$I.PH@("`@96-H
M;R`G/"]P<F4^)SL*?0H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R:6%L:7IE
M<B]E>&%M<&QE<R]U;G-E<FEA;&EZ95=I=&A4>7!E1W5E<W-I;F<N<&AP````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,38V-B`Q
M,#4Q-30S-#$S,B`P,S(S,S8`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]02%`*+RHJ"B`J($5X86UP;&4@=&AA="!S:&]W
M<R!H;W<@=&\@=7-E(%A-3%]5;G-E<FEA;&EZ97(@=&\*("H@875T;VUA=&EC
M86QL>2!A9&IU<W0@=&AE('1Y<&4@;V8@=&AE(&1A=&$*("H*("H@0&%U=&AO
M<B`@("`@(%-T97!H86X@4V-H;6ED="`\<V-H<W1`<&AP+FYE=#X*("H@0&-A
M=&5G;W)Y("`@(%A-3`H@*B!`<&%C:V%G92`@("`@6$U,7U-E<FEA;&EZ97(*
M("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PIE<G)O<E]R97!O<G1I;F<H
M15]!3$PI.PH*+RHJ"B`J('5S97,@6$U,7U5N<V5R:6%L:7IE<@H@*B\*<F5Q
M=6ER95]O;F-E("<N+B]5;G-E<FEA;&EZ97(N<&AP)SL*"B1X;6P@/2`\/#Q%
M3U0*/')O;W0^"B`@(#QS=')I;F<^2G5S="!A('-T<FEN9RXN+CPO<W1R:6YG
M/@H@("`\8F]O;&5A;E9A;'5E/G1R=64\+V)O;VQE86Y686QU93X*("`@/&9O
M;SXM-38S/"]F;V\^"B`@(#QB87(^-"XW,S<S-CPO8F%R/@H@("`\87)R87D@
M9F]O/2)F86QS92(@8F%R/2(Q,B(^=')U93PO87)R87D^"CPO<F]O=#X*14]4
M.PH*)'5N<V5R:6%L:7IE<B`]("9N97<@6$U,7U5N<V5R:6%L:7IE<B@I.PHD
M=6YS97)I86QI>F5R+3YS971/<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)
M3TY?0T]-4$Q%6%194$4L("=A<G)A>2<I.PHD=6YS97)I86QI>F5R+3YS971/
M<'1I;VXH6$U,7U5.4T5224%,25I%4E]/4%1)3TY?05144DE"551%4U]005)3
M12P@=')U92D["B1U;G-E<FEA;&EZ97(M/G-E=$]P=&EO;BA834Q?54Y315))
M04Q)6D527T]05$E/3E]215154DY?4D5354Q4+"!T<G5E*3L*)'5N<V5R:6%L
M:7IE<BT^<V5T3W!T:6]N*%A-3%]53E-%4DE!3$E:15)?3U!424].7T=515-3
M7U194$53+"!T<G5E*3L*"B1D871A(#T@)'5N<V5R:6%L:7IE<BT^=6YS97)I
M86QI>F4H)'AM;"D[("`@(`IE8VAO("<\<')E/B<["G9A<E]D=6UP*"1D871A
M*3L*96-H;R`G/"]P<F4^)SL*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4V5R
M:6%L:7IE<B]E>&%M<&QE<R]S97)I86QI>F5!;F12971U<FXN<&AP````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,3$T,2`Q,#4Q-30S-#$S,B`P,S`S-S<`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]02%`*+RHJ"B`J($5X86UP;&4@=&AA
M="!U<V5S('1H92!R971U<FY297-U;'0@;W!T:6]N('1O(&1I<F5C=&QY(')E
M='5R;B!T:&4@<V5R:6%L:7IE9`H@*B!834P@9&]C=6UE;G0@:6X@=&AE('-E
M<FEA;&EZ92@I(&UE=&AO9"X*("H*("H@0&%U=&AO<B!3=&5P:&%N(%-C:&UI
M9'0@/'-C:'-T0'!H<"YN970^"B`J+PIE<G)O<E]R97!O<G1I;F<H15]!3$PI
M.PH*<F5Q=6ER95]O;F-E("=834PO4V5R:6%L:7IE<BYP:'`G.PH*)&]P=&EO
M;G,@/2!A<G)A>2@*("`@("`@("`@("`@("`@("`@("!834Q?4T5224%,25I%
M4E]/4%1)3TY?24Y$14Y4("`@("`@("`]/B`G("`@("<L"B`@("`@("`@("`@
M("`@("`@("`@6$U,7U-%4DE!3$E:15)?3U!424].7U)%5%523E]215-53%0@
M/3X@=')U90H@("`@("`@("`@("`@("`@*3L*"B1S97)I86QI>F5R(#T@)FYE
M=R!834Q?4V5R:6%L:7IE<B@D;W!T:6]N<RD["@HD9F]O(#T@4$5!4CHZ<F%I
M<V5%<G)O<B@G2G5S="!A('1E<W0G+"`Q,C,T*3L*"B1R97-U;'0@/2`D<V5R
M:6%L:7IE<BT^<V5R:6%L:7IE*"1F;V\I.PH*96-H;R`G/'!R93XG.PIE8VAO
M(&AT;6QS<&5C:6%L8VAA<G,H)')E<W5L="D["F5C:&\@)SPO<')E/B<["C\^
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]8
M34Q?571I;"]E>&%M<&QE<P``````````````````````````````````````
M```````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,C(V,#0`(#4`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+UA-3%]5=&EL+V5X86UP;&5S+V5X86UP;&4R+G!H
M<````````````````````````````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`U-S`U(#$P-3$U-#,T,3,R(#`R-3$R
M,``@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/U!(4`T*+RHJ#0H@*B!S979E<F%L(&5X86UP;&5S(&9O<B!T:&4@;65T:&]D
M<R!O9B!834Q?571I;`T*("H-"B`J("1)9#H@97AA;7!L93(N<&AP+'8@,2XX
M(#(P,#0O,#8O,C<@,3@Z,3<Z,SD@<V-H<W0@17AP("0-"B`J#0H@*B!`875T
M:&]R("`@("`@4W1E<&AA;B!38VAM:61T#0H@*B!`<&%C:V%G92`@("`@6$U,
M7U5T:6P-"B`J($!S=6)P86-K86=E("!E>&%M<&QE<PT*("H@0&-A=&5G;W)Y
M("`@(%A-3`T*("HO#0H@("`@97)R;W)?<F5P;W)T:6YG*$5?04Q,*3L-"@T*
M("`@(')E<75I<F5?;VYC92`G6$U,+U5T:6PN<&AP)SL-"@T*("`@("\J*@T*
M("`@("H@8W)E871I;F<@82!S=&%R="!E;&5M96YT#0H@("`@*B\-"B`@("!P
M<FEN="`B8W)E871I;F<@82!S=&%R="!E;&5M96YT.CQB<CXB.PT*("`@('!R
M:6YT(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E4W1A<G1%;&5M96YT
M*")M>4YS.FUY5&%G(BP@87)R87DH(F9O;R(@/3X@(F)A<B(I+"`B:'1T<#HO
M+W=W=RYW,V,N;W)G+VUY3G,C(BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^
M7&XB.PT*#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&$@<W1A<G0@96QE
M;65N=`T*("`@("HO#0H@("`@<')I;G0@(F-R96%T:6YG(&$@<W1A<G0@96QE
M;65N=#H\8G(^(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ
M.F-R96%T95-T87)T16QE;65N="@B;7E486<B+"!A<G)A>2@I+"`B:'1T<#HO
M+W=W=RYW,V,N;W)G+VUY3G,C(BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^
M7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A('-T87)T(&5L96UE
M;G0-"B`@("`J+PT*("`@('!R:6YT(")C<F5A=&EN9R!A('-T87)T(&5L96UE
M;G0Z/&)R/B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN="!H=&UL
M96YT:71I97,H6$U,7U5T:6PZ.F-R96%T95-T87)T16QE;65N="@B;7E486<B
M+"!A<G)A>2@@(F9O;R(@/3X@(F)A<B(L(")A<F=H(B`]/B`B=&]M871O(B`I
M+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY3G,C(BP@=')U92DI.PT*("`@('!R
M:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-
M"B`@("`O*BH-"B`@("`J(&-R96%T:6YG(&%N(&5N9"!E;&5M96YT#0H@("`@
M*B\-"B`@("!P<FEN="`B8W)E871I;F<@86X@96YD(&5L96UE;G0Z/&)R/B([
M#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC<F5A=&5%;F1%
M;&5M96YT*")M>4YS.FUY5&%G(BDI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^
M7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A($-$871A('-E8W1I
M;VX-"B`@("`J+PT*("`@('!R:6YT(")C<F5A=&EN9R!A($-$871A('-E8W1I
M;VXZ/&)R/B([#0H@("`@<')I;G0@:'1M;&5N=&ET:65S*%A-3%]5=&EL.CIC
M<F5A=&5#1&%T85-E8W1I;VXH(DD@86T@8V]N=&5N="XB*2D[#0H@("`@<')I
M;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T:6YG
M(&$@8V]M;65N=`T*("`@("HO#0H@("`@<')I;G0@(F-R96%T:6YG(&$@8V]M
M;65N=#H\8G(^(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ
M.F-R96%T94-O;6UE;G0H(DD@86T@82!C;VUM96YT+B(I*3L-"B`@("!P<FEN
M="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@
M86X@6$U,('1A9R!W:71H(&UU;'1I;&EN92!M;V1E#0H@("`@*B\-"B`@("`D
M=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@
M("`]/B`B9F]O.F)A<B(L#0H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E
M57)I(B`]/B`B:'1T<#HO+V9O;RYC;VTB+`T*("`@("`@("`@("`@("`@("`@
M(F%T=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A
M<F=H(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*("`@("`@("`@("`@("`@
M("`@(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I;G-I9&4@=&AE('1A9R`F(&-O
M;G1A:6X@9&%N9V5R;W5S(&-H87)S(@T*("`@("`@("`@("`@("`@("D[#0H-
M"B`@("!P<FEN="`B8W)E871I;F<@82!T86<@=VET:"!Q=6%L:69I960@;F%M
M92!A;F0@;F%M97-P86-E57)I.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^
M(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A
M9T9R;VU!<G)A>2@D=&%G+"!834Q?551)3%]215!,04-%7T5.5$E42453+"!T
M<G5E*2D[#0H@("`@<')I;G0@(CPO<')E/B([#0H@("`@<')I;G0@(EQN/&)R
M/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R96%T92!A;B!A='1R:6)U
M=&4@<W1R:6YG('=I=&AO=70@<F5P;&%C:6YG('1H92!E;G1I=&EE<PT*("`@
M("HO#0H@("`@)&%T=',@/2!A<G)A>2@@)W-E<FEE<R<@/3X@)U-T87)S:WD@
M)F%M<#L@2'5T8V@G+"`G8VAA;FYE;"<@/3X@)T%"0R<@*3L-"B`@("!P<FEN
M="`B8W)E871I;F<@82!A='1R:6)U=&4@<W1R:6YG+"!E;G1I=&EE<R!I;B!V
M86QU97,@86QR96%D>2!H860@8F5E;B!R97!L86-E9#H\8G(^(CL-"B`@("!P
M<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN
M9R@D871T<RP@=')U92P@9F%L<V4L(&9A;'-E+"!F86QS92P@6$U,7U5424Q?
M14Y4251)15-?3D].12DI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*
M#0H@("`@+RHJ#0H@("`@*B!U<VEN9R!T:&4@87)R87DM<WEN=&%X(&9O<B!A
M='1R:6)U=&5S5&]3=')I;F<H*0T*("`@("HO#0H@("`@)&%T=',@/2!A<G)A
M>2@@)W-E<FEE<R<@/3X@)U-T87)S:WD@)F%M<#L@2'5T8V@G+"`G8VAA;FYE
M;"<@/3X@)T%"0R<@*3L-"B`@("!P<FEN="`B=7-I;F<@=&AE(&%R<F%Y+7-Y
M;G1A>"!F;W(@871T<FEB=71E<U1O4W1R:6YG*"D\8G(^(CL-"B`@("!P<FEN
M="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN9R@D
M871T<RP@87)R87DH)V5N=&ET:65S)R`]/B!834Q?551)3%]%3E1)5$E%4U].
M3TY%*2DI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-"C\^````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M6$U,7U5T:6PO97AA;7!L97,O97AA;7!L92YP:'``````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,38P-C`@,3`U,34T,S0Q,S(@,#(U,#,R`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_4$A0#0HO*BH-"B`J('-E
M=F5R86P@97AA;7!L97,@9F]R('1H92!M971H;V1S(&]F(%A-3%]5=&EL#0H@
M*@T*("H@)$ED.B!E>&%M<&QE+G!H<"QV(#$N,3(@,C`P-"\Q,B\R,R`Q,SHR
M,CHP,"!S8VAS="!%>'`@)`T*("H-"B`J($!A=71H;W(@("`@("!3=&5P:&%N
M(%-C:&UI9'0-"B`J($!P86-K86=E("`@("!834Q?571I;`T*("H@0'-U8G!A
M8VMA9V4@(&5X86UP;&5S#0H@*B!`8V%T96=O<GD@("`@6$U,#0H@*B\-"B`@
M("!E<G)O<E]R97!O<G1I;F<H15]!3$PI.PT*#0H@("`@<F5Q=6ER95]O;F-E
M("=834PO571I;"YP:'`G.PT*("`@(`T*("`@("\J*@T*("`@("H@<F5P;&%C
M:6YG(%A-3"!E;G1I=&EE<PT*("`@("HO#0H@("`@<')I;G0@(G)E<&QA8V4@
M6$U,(&5N=&ET:65S.CQB<CY<;B([#0H@("`@<')I;G0@6$U,7U5T:6PZ.G)E
M<&QA8V5%;G1I=&EE<R@B5&AI<R!S=')I;F<@8V]N=&%I;G,@/"`F(#XN(BD[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J
M(')E=F5R<VEN9R!834P@96YT:71I97,-"B`@("`J+PT*("`@('!R:6YT(")R
M97!L86-E(%A-3"!E;G1I=&EE<SH\8G(^7&XB.PT*("`@('!R:6YT(%A-3%]5
M=&EL.CIR979E<G-E16YT:71I97,H(E1H:7,@<W1R:6YG(&-O;G1A:6YS("9L
M=#L@)F%M<#L@)F=T.RXB*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-
M"@T*("`@("\J*@T*("`@("H@8G5I;&1I;F<@6$U,(&1E8VQA<F%T:6]N#0H@
M("`@*B\-"B`@("!P<FEN="`B8G5I;&1I;F<@6$U,(&1E8VQA<F%T:6]N.CQB
M<CY<;B([#0H@("`@<')I;G0@:'1M;'-P96-I86QC:&%R<RA834Q?571I;#HZ
M9V5T6$U,1&5C;&%R871I;VXH*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<
M;B([#0H-"B`@("!P<FEN="`B8G5I;&1I;F<@6$U,(&1E8VQA<F%T:6]N('=I
M=&@@861D:71I;VYA;"!A='1R:6)U=&5S.CQB<CXB.PT*("`@('!R:6YT(&AT
M;6QS<&5C:6%L8VAA<G,H6$U,7U5T:6PZ.F=E=%A-3$1E8VQA<F%T:6]N*"(Q
M+C`B+"`B551&+3@B+"!T<G5E*2D[#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<
M;B([#0H-"B`@("`O*BH-"B`@("`J(&)U:6QD:6YG(&1O8W5M96YT('1Y<&4@
M9&5C;&%R871I;VX-"B`@("`J+PT*("`@('!R:6YT(")B=6EL9&EN9R!$;V-4
M>7!E(&1E8VQA<F%T:6]N.CQB<CY<;B([#0H@("`@<')I;G0@:'1M;'-P96-I
M86QC:&%R<RA834Q?571I;#HZ9V5T1&]C5'EP941E8VQA<F%T:6]N*"=P86-K
M86=E)RP@)VAT='`Z+R]P96%R+G!H<"YN970O9'1D+W!A8VMA9V4M,2XP)RDI
M.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@<')I;G0@(F)U
M:6QD:6YG($1O8U1Y<&4@9&5C;&%R871I;VX@=VET:"!P=6)L:6,@240@*&1O
M97,@;F]T(&5X:7-T*3H\8G(^7&XB.PT*("`@('!R:6YT(&AT;6QS<&5C:6%L
M8VAA<G,H6$U,7U5T:6PZ.F=E=$1O8U1Y<&5$96-L87)A=&EO;B@G<&%C:V%G
M92<L(&%R<F%Y*"=U<FDG(#T^("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P
M86-K86=E+3$N,"<L("=I9"<@/3X@)RTO+U!(4"\O4$5!4B]$5$0@4$%#2T%'
M12`P+C$G*2DI.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@
M<')I;G0@(F)U:6QD:6YG($1O8U1Y<&4@9&5C;&%R871I;VX@=VET:"!I;G1E
M<FYA;"!$5$0Z/&)R/EQN(CL-"B`@("!P<FEN="`B/'!R93XB.PT*("`@('!R
M:6YT(&AT;6QS<&5C:6%L8VAA<G,H6$U,7U5T:6PZ.F=E=$1O8U1Y<&5$96-L
M87)A=&EO;B@G<&%C:V%G92<L("=H='1P.B\O<&5A<BYP:'`N;F5T+V1T9"]P
M86-K86=E+3$N,"<L("<\(45,14U%3E0@861D:71I;VYA;$EN9F\@*"-00T1!
M5$$I/B<I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\
M8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@86X@871T
M<FEB=71E('-T<FEN9PT*("`@("HO#0H@("`@)&%T="`](&%R<F%Y*`T*("`@
M("`@("`@("`@("`@("`@(F9O;R(@("`]/B`@(F)A<B(L#0H@("`@("`@("`@
M("`@("`@("`B87)G:"(@(#T^("`B=&]M871O(@T*("`@("`@("`@("`@("`@
M("D[#0H-"B`@("!P<FEN="`B8V]N=F5R=&EN9R!A<G)A>2!T;R!S=')I;F<Z
M/&)R/EQN(CL-"B`@("!P<FEN="!834Q?571I;#HZ871T<FEB=71E<U1O4W1R
M:6YG*"1A='0I.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H-"B`@
M("`O*BH-"B`@("`J(&-R96%T:6YG(&%N(&%T=')I8G5T92!S=')I;F<@=VET
M:"!L:6YE8G)E86MS#0H@("`@*B\-"B`@("`D871T(#T@87)R87DH#0H@("`@
M("`@("`@("`@("`@("`B9F]O(B`@(#T^("`B8F%R(BP-"B`@("`@("`@("`@
M("`@("`@(")A<F=H(B`@/3X@(")T;VUA=&\B#0H@("`@("`@("`@("`@("`@
M*3L-"@T*("`@('!R:6YT(")C;VYV97)T:6YG(&%R<F%Y('1O('-T<FEN9R`H
M:6YC;'5D:6YG(&QI;F4@8G)E86MS*3H\8G(^7&XB.PT*("`@('!R:6YT("(\
M<')E/B([#0H@("`@<')I;G0@6$U,7U5T:6PZ.F%T=')I8G5T97-4;U-T<FEN
M9R@D871T+"!T<G5E+"!T<G5E*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@
M("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*#0H@("`@+RHJ#0H@("`@*B!S
M<&QI='1I;F<@82!Q=6%L:69I960@=&%G(&YA;64-"B`@("`J+PT*("`@('!R
M:6YT(")S<&QI='1I;F<@<75A;&EF:65D('1A9R!N86UE.CQB<CY<;B([#0H@
M("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R*%A-3%]5=&EL.CIS<&QI
M=%%U86QI9FEE9$YA;64H(GAS;'0Z<W1Y;&5S:&5E="(I*3L-"B`@("!P<FEN
M="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^7&XB.PT*#0H-"B`@("`O
M*BH-"B`@("`J('-P;&ET=&EN9R!A('%U86QI9FEE9"!T86<@;F%M92`H;F\@
M;F%M97-P86-E*0T*("`@("HO#0H@("`@<')I;G0@(G-P;&ET=&EN9R!Q=6%L
M:69I960@=&%G(&YA;64@*&YO(&YA;65S<&%C92DZ/&)R/EQN(CL-"B`@("!P
M<FEN="`B/'!R93XB.PT*("`@('!R:6YT7W(H6$U,7U5T:6PZ.G-P;&ET475A
M;&EF:65D3F%M92@B9F]O(BDI.PT*("`@('!R:6YT("(\+W!R93XB.PT*("`@
M('!R:6YT(")<;CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J('-P;&ET=&EN
M9R!A('%U86QI9FEE9"!T86<@;F%M92`H;F\@;F%M97-P86-E+"!B=70@9&5F
M875L="!N86UE<W!A8V4@<W!E8VEF:65D*0T*("`@("HO#0H@("`@<')I;G0@
M(G-P;&ET=&EN9R!Q=6%L:69I960@=&%G(&YA;64@*&YO(&YA;65S<&%C92P@
M8G5T(&1E9F%U;'0@;F%M97-P86-E('-P96-I9FEE9"DZ/&)R/EQN(CL-"B`@
M("!P<FEN="`B/'!R93XB.PT*("`@('!R:6YT7W(H6$U,7U5T:6PZ.G-P;&ET
M475A;&EF:65D3F%M92@B9F]O(BP@(F)A<B(I*3L-"B`@("!P<FEN="`B/"]P
M<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@
M*B!V97)I9GEI;F<@6$U,(&YA;65S#0H@("`@*B\-"B`@("!P<FEN="`B=F5R
M:69Y:6YG("=->2!P<FEV871E('1A9R<Z/&)R/EQN(CL-"B`@("!P<FEN="`B
M/'!R93XB.PT*("`@('!R:6YT7W(H6$U,7U5T:6PZ.FES5F%L:61N86UE*"=-
M>2!0<FEV871E(%1A9R<I*3L-"B`@("!P<FEN="`B/"]P<F4^(CL-"B`@("!P
M<FEN="`B7&X\8G(^/&)R/EQN(CL-"B`@("`-"B`@("!P<FEN="`B=F5R:69Y
M:6YG("<M37E486<G.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@
M("!P<FEN=%]R*%A-3%]5=&EL.CII<U9A;&ED;F%M92@G+4UY5&%G)RDI.PT*
M("`@('!R:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB
M.PT*#0H@("`@+RHJ#0H@("`@*B!C<F5A=&EN9R!A;B!834P@=&%G#0H@("`@
M*B\-"B`@("`D=&%G(#T@87)R87DH#0H@("`@("`@("`@("`@("`@("`B;F%M
M97-P86-E(B`@(#T^(")F;V\B+`T*("`@("`@("`@("`@("`@("`@(FQO8V%L
M4&%R="(@("`]/B`B8F%R(BP-"B`@("`@("`@("`@("`@("`@(")A='1R:6)U
M=&5S(B`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B
M9G)U:70F=F5G971A8FQE(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E
M;G0B("`@("`]/B`B22=M(&EN<VED92!T:&4@=&%G(@T*("`@("`@("`@("`@
M("`@("D[#0H-"B`@("!P<FEN="`B8W)E871I;F<@82!T86<@=VET:"!N86UE
M<W!A8V4@86YD(&QO8V%L('!A<G0Z/&)R/B([#0H@("`@<')I;G0@:'1M;&5N
M=&ET:65S*%A-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PT*
M("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@+RHJ#0H@("`@*B!C
M<F5A=&EN9R!A;B!834P@=&%G#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH
M#0H@("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@("`]/B`B9F]O.F)A
M<B(L#0H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E57)I(B`]/B`B:'1T
M<#HO+V9O;RYC;VTB+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B
M("`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B9G)U
M:70F=F5G971A8FQE(B`I+`T*("`@("`@("`@("`@("`@("`@(F-O;G1E;G0B
M("`@("`@/3X@(DDG;2!I;G-I9&4@=&AE('1A9R(-"B`@("`@("`@("`@("`@
M("`I.PT*#0H@("`@<')I;G0@(F-R96%T:6YG(&$@=&%G('=I=&@@<75A;&EF
M:65D(&YA;64@86YD(&YA;65S<&%C955R:3H\8G(^7&XB.PT*("`@('!R:6YT
M(&AT;6QE;G1I=&EE<RA834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T
M86<I*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-"@T*("`@("\J*@T*
M("`@("H@8W)E871I;F<@86X@6$U,('1A9PT*("`@("HO#0H@("`@)'1A9R`]
M(&%R<F%Y*`T*("`@("`@("`@("`@("`@("`@(G%N86UE(B`@("`@("`@/3X@
M(F)A<B(L#0H@("`@("`@("`@("`@("`@("`B;F%M97-P86-E57)I(B`]/B`B
M:'1T<#HO+V9O;RYC;VTB+`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T
M97,B("`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H(B`]/B`B
M9G)U:70F=F5G971A8FQE(B`I#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@
M('!R:6YT(")C<F5A=&EN9R!A;B!E;7!T>2!T86<@=VET:&]U="!N86UE<W!A
M8V4@8G5T(&YA;65S<&%C92!5<FDZ/&)R/EQN(CL-"B`@("!P<FEN="!H=&UL
M96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A9T9R;VU!<G)A>2@D=&%G*2D[
M#0H@("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J
M(&-R96%T:6YG(&%N(%A-3"!T86<@=VET:"!A($-$871A(%-E8W1I;VX-"B`@
M("`J+PT*("`@("1T86<@/2!A<G)A>2@-"B`@("`@("`@("`@("`@("`@(")Q
M;F%M92(@("`@("`@(#T^(")F;V\B+`T*("`@("`@("`@("`@("`@("`@(F%T
M=')I8G5T97,B("`@/3X@87)R87DH(")K97DB(#T^(")V86QU92(L(")A<F=H
M(B`]/B`B9G)U:70F=F5G971A8FQE(B`I+`T*("`@("`@("`@("`@("`@("`@
M(F-O;G1E;G0B("`@("`@/3X@(DDG;2!I;G-I9&4@=&AE('1A9R(-"B`@("`@
M("`@("`@("`@("`I.PT*#0H@("`@<')I;G0@(F-R96%T:6YG(&$@=&%G('=I
M=&@@0T1A=&$@<V5C=&EO;CH\8G(^7&XB.PT*("`@('!R:6YT(&AT;6QE;G1I
M=&EE<RA834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<L(%A-3%]5
M5$E,7T-$051!7U-%0U1)3TXI*3L-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN
M(CL-"@T*("`@("\J*@T*("`@("H@8W)E871I;F<@86X@6$U,('1A9R!W:71H
M(&$@0T1A=&$@4V5C=&EO;@T*("`@("HO#0H@("`@)'1A9R`](&%R<F%Y*`T*
M("`@("`@("`@("`@("`@("`@(G%N86UE(B`@("`@("`@/3X@(F9O;R(L#0H@
M("`@("`@("`@("`@("`@("`B871T<FEB=71E<R(@("`]/B!A<G)A>2@@(FME
M>2(@/3X@(G9A;'5E(BP@(F%R9V@B(#T^(")T_'3\(B`I+`T*("`@("`@("`@
M("`@("`@("`@(F-O;G1E;G0B("`@("`@/3X@(D%L<V\@6$A434PM=&%G<R!C
M86X@8F4@8W)E871E9"!A;F0@2%1-3"!E;G1I=&EE<R!C86X@8F4@<F5P;&%C
M960@Q"#D(-P@]B`\/BXB#0H@("`@("`@("`@("`@("`@*3L-"@T*("`@('!R
M:6YT(")C<F5A=&EN9R!A('1A9R!W:71H($A434P@96YT:71I97,Z/&)R/EQN
M(CL-"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A
M9T9R;VU!<G)A>2@D=&%G+"!834Q?551)3%]%3E1)5$E%4U](5$U,*2D[#0H@
M("`@<')I;G0@(EQN/&)R/CQB<CY<;B([#0H-"B`@("`O*BH-"B`@("`J(&-R
M96%T:6YG(&%N(%A-3"!T86<@=VET:"!C<F5A=&5486<-"B`@("`J+PT*("`@
M('!R:6YT(")C<F5A=&EN9R!A('1A9R!W:71H(&-R96%T951A9SH\8G(^(CL-
M"B`@("!P<FEN="!H=&UL96YT:71I97,H6$U,7U5T:6PZ.F-R96%T951A9R@B
M;7E.<SIM>51A9R(L(&%R<F%Y*")F;V\B(#T^(")B87(B*2P@(E1H:7,@:7,@
M:6YS:61E('1H92!T86<B+"`B:'1T<#HO+W=W=RYW,V,N;W)G+VUY3G,C(BDI
M.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*#0H@("`@#0H@("`@+RHJ
M#0H@("`@*B!T<GEI;F<@=&\@8W)E871E(&%N(%A-3"!T86<@=VET:"!A;B!A
M<G)A>2!A<R!C;VYT96YT#0H@("`@*B\-"B`@("`D=&%G(#T@87)R87DH#0H@
M("`@("`@("`@("`@("`@("`B<6YA;64B("`@("`@("`]/B`B8F%R(BP-"B`@
M("`@("`@("`@("`@("`@(")C;VYT96YT(B`@("`@(#T^(&%R<F%Y*"`B9F]O
M(B`]/B`B8F%R(B`I#0H@("`@("`@("`@("`@("`@*3L-"B`@("!P<FEN="`B
M=')Y:6YG('1O(&-R96%T92!A;B!834P@=&%G('=I=&@@86X@87)R87D@87,@
M8V]N=&5N=#H\8G(^7&XB.PT*("`@('!R:6YT("(\<')E/B([#0H@("`@<')I
M;G1?<BA834Q?571I;#HZ8W)E871E5&%G1G)O;4%R<F%Y*"1T86<I*3L-"B`@
M("!P<FEN="`B/"]P<F4^(CL-"B`@("!P<FEN="`B7&X\8G(^/&)R/EQN(CL-
M"B`@("`-"B`@("`O*BH-"B`@("`J('1R>6EN9R!T;R!C<F5A=&4@86X@6$U,
M('1A9R!W:71H;W5T(&$@;F%M90T*("`@("HO#0H@("`@)'1A9R`](&%R<F%Y
M*`T*("`@("`@("`@("`@("`@("`@(F%T=')I8G5T97,B("`@/3X@87)R87DH
M(")F;V\B(#T^(")B87(B("DL#0H@("`@("`@("`@("`@("`@*3L-"B`@("!P
M<FEN="`B=')Y:6YG('1O(&-R96%T92!A;B!834P@=&%G('=I=&AO=70@82!N
M86UE.CQB<CY<;B([#0H@("`@<')I;G0@(CQP<F4^(CL-"B`@("!P<FEN=%]R
M*%A-3%]5=&EL.CIC<F5A=&5486=&<F]M07)R87DH)'1A9RDI.PT*("`@('!R
M:6YT("(\+W!R93XB.PT*("`@('!R:6YT(")<;CQB<CX\8G(^7&XB.PT*/SX`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S````````````````````````
M```````````````````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,C0T,3$`(#4`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]P
M<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O
M;65T87(M8F%S:6,N<&AP`````````````````````````````````#`P,#8T
M-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`W,#4S(#$P-3$U-#,T,3,R(#`R
M-S,W-0`@,```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T
M=VED=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*
M+RHJ"B`J($)A<VEC(&5X86UP;&4@9F]R('1H92!-151!4B]4048M<V5R=FEC
M90H@*@H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*
M("H@0V]P>7)I9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL
M(')I9VAT<R!R97-E<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U
M<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U
M=`H@*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA
M="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2
M961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE
M(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2
M961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@
M=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F
M(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T
M:&4@9&]C=6UE;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@
M<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@
M=&AE(&YA;64@;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S
M(&-O;G1R:6)U=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@
M<')O;6]T92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@
M*B`@('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N
M+@H@*B`*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]0
M65))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.
M1"!!3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.
M1RP@0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y4
M2453($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)4
M24-53$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4
M(%-(04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%
M"B`J($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y4
M04PL(%-014-)04PL($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$
M04U!1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]3
M4R!/1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.
M5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@
M3T8@3$E!0DE,2519+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@
M3$E!0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/
M5$A%4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%53
M12!/1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J
M(%!/4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J
M(`H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@
M("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@
M5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L
M97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N
M<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E
M;G-E"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@;65T87(M8F%S:6,N<&AP
M+'8@,2XQ,2`R,#`U+S$Q+S`X(#$W.C4R.C0R(&5R=2!%>'`@)`H@*B!`;&EN
M:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S
M7U=E871H97(*("H@0&9I;&5S;W5R8V4*("HO"@IR97%U:7)E7V]N8V4@(E-E
M<G9I8V5S+U=E871H97(N<&AP(CL*"B\O($]B:F5C="!I;FET:6%L:7IA=&EO
M;B`M(&5R<F]R(&-H96-K:6YG(&ES(&EM<&]R=&%N="P@8F5C875S92!O9@HO
M+R!H86YD;&EN9R!E>&-E<'1I;VYS('-U8V@@87,@;6ES<VEN9R!014%2(&UO
M9'5L97,*)&UE=&%R(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H(DU%
M5$%2(BP@87)R87DH(F1E8G5G(B`]/B`P*2D["FEF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1M971A<BDI('L*("`@(&1I92@B17)R;W(Z("(N)&UE
M=&%R+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\O(%-E="!P87)A;65T97)S
M(&9O<B!$0B!A8V-E<W,L(&YE961E9"!F;W(@;&]C871I;VX@<V5A<F-H97,*
M)&UE=&%R+3YS971-971A<D1"*")S<6QI=&4Z+R]L;V-A;&AO<W0O+W5S<B]L
M;V-A;"]L:6(O<&AP+V1A=&$O4V5R=FEC97-?5V5A=&AE<B]S97)V:6-E<U=E
M871H97)$0B(I.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D;65T
M87(I*2!["B`@("!E8VAO(")%<G)O<CH@(BXD;65T87(M/F=E=$UE<W-A9V4H
M*2XB7&XB.PI]"@HO*B!%<F%S92!C;VUM96YT<R!T;R!E;F%B;&4@8V%C:&EN
M9PHD<W1A='5S(#T@)&UE=&%R+3YS971#86-H92@B9FEL92(L(&%R<F%Y*")C
M86-H95]D:7(B(#T^("(O=&UP+V-A8VAE+R(I*3L*:68@*%-E<G9I8V5S7U=E
M871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C:&\@(D5R<F]R.B`B
M+B1S=&%T=7,M/F=E=$UE<W-A9V4H*2XB7&XB.PI]"BHO"@HD;65T87(M/G-E
M=%5N:71S1F]R;6%T*")C=7-T;VTB+"!A<G)A>2@*("`@(")W:6YD(B`@(#T^
M(")K="(L"B`@("`B=FES(B`@("`]/B`B:VTB+`H@("`@(FAE:6=H="(@/3X@
M(F9T(BP*("`@(")T96UP(B`@(#T^(")C(BP*("`@(")P<F5S(B`@(#T^(")H
M<&$B+`H@("`@(G)A:6XB("`@/3X@(FEN(BDI.PHD;65T87(M/G-E=$1A=&54
M:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L*"B\O($9I<G-T(&=E="!C;V1E
M(&9O<B!L;V-A=&EO;@HD<V5A<F-H(#T@)&UE=&%R+3YS96%R8VA,;V-A=&EO
M;B@B0F]N;BP@1V5R;6%N>2(I.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<V5A<F-H*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD<V5A<F-H+3YG
M971-97-S86=E*"DN(EQN(BD["GT*"B\O($YO=R!I=&5R871E('1H<F]U9V@@
M879A:6QA8FQE(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9R!D871A"F9O<F5A
M8V@@*&%R<F%Y*")G971,;V-A=&EO;B(L(")G971796%T:&5R(BP@(F=E=$9O
M<F5C87-T(BD@87,@)&9U;F-T:6]N*2!["B`@("`D9&%T82`]("1M971A<BT^
M)&9U;F-T:6]N*"1S96%R8V@I.PH@("`@:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)&1A=&$I*2!["B`@("`@("`@96-H;R`B17)R;W(Z("(N)&1A
M=&$M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@
M?0H*("`@('9A<E]D=6UP*"1D871A*3L*?0H_/@H`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S
M7U=E871H97(O97AA;7!L97,O;65T87(M97AT96YS:79E+G!H<```````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#8W
M,34R(#$P-3$U-#,T,3,R(#`S,#,S-``@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T
M86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M
M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J($5L86)O<F%T92!E>&%M<&QE(&9O
M<B!T:&4@345405(O5$%&+7-E<G9I8V4*("H*("H@5V5L;"P@=&AI<R!I<R!A
M(&UO<F4@96QA8F]R871E(&5X86UP;&4@:&]W('1O(&-R96%T92!A(&YE870@
M;&ET=&QE('!A9V4*("H@=VET:"!F971C:&EN9R!-151!4B]4048@9&%T82!F
M<F]M($Y/04$@86YD('!U='1I;F<@:70@:6YT;R!A(&1E<VEG;BX*("H@22=M
M(&YO="!T;V\@<')O=60@;V8@;7D@9&5S:6=N+7-K:6QL<RP@;6]S="!O9B!T
M:&4@<W1U9F8@:&5R92!I<R!T86ME;@H@*B!F<F]M('1H92!M971A<BUB;&]C
M:R!W:&EC:"!C86X@8F4@9F]U;F0@=VET:&EN('1H92!(;W)D92!&<F%M97=O
M<FLL"B`J(&-O=7)T97-Y(&]F(%)I8VL@16UE<GD@+2!C<F5A=&EV92!P:7AE
M;'-H;W9I;F<@:7-N)W0@;7D@9&]M86EN(#HM4`H@*B!))W9E('5S960@82!&
M:7)E9F]X(&9O<B!C:&5C:VEN9R!T:&4@9&5S:6=N+"!S;R!D;VXG="!B92!T
M;V\*("H@9&ES87!P;VEN=&5D+"!I9B!T:&4@<&%G92!L;V]K<R!S:&%B8GD@
M=VET:"!T:&4@244L(&YO="!T:&%T($D@8V%R90H@*B!V97)Y(&UU8V@@86YY
M=V%Y(#LM*0H@*B!(879E(&9U;B$*("H@"B`J(%!(4"!V97)S:6]N<R`T(&%N
M9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L
M97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@*B`*("H@
M4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F
M;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E
M<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N
M<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@
M8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*
M("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@
M9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC
M92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO
M=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N"B`J("`@86YD
M+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB
M=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@;F%M92!O9B!T:&4@<V]F='=A<F4@
M;F]R('1H92!N86UE<R!O9B!I=',@8V]N=')I8G5T;W)S"B`J("`@;6%Y(&)E
M('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E<FEV960@
M9G)O;2!T:&ES('-O9G1W87)E"B`J("`@=VET:&]U="!S<&5C:69I8R!P<FEO
M<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J(`H@*B!42$E3(%-/1E1705)%($E3
M(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))
M0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@
M5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L(%1(
M10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.
M1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!4D4@1$E3
M0TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"!/5TY%
M4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@1$E214-4
M+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9+"!/
M4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/
M5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@4%)/1DE4
M4SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52($-!55-%
M1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X*
M("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ5
M1$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.1R!)3B!!
M3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!
M1T4N"B`J(#PO3$E#14Y313X*("H@"B`J($!C871E9V]R>2`@("!796(@4V5R
M=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@0&%U
M=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@
M0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E
M("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL
M:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-64SH@
M)$ED.B!M971A<BUE>'1E;G-I=F4N<&AP+'8@,2XQ-R`R,#`U+S$Q+S$S(#(R
M.C0U.C(Q(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&9I;&5S;W5R
M8V4*("HO"@HO+RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*+R\@5&AI
M<R!I<R!T:&4@87)E82P@=VAE<F4@>6]U(&-A;B!C=7-T;VUI>F4@=&AE('-C
M<FEP=`HO+RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*)&QO8V%T:6]N
M("`@("`@("`](")";VYN+"!'97)M86YY(CL@+R\@5&AE(&-I='D@=V4@=V%N
M="!T;R!F971C:"!T:&4@9&%T82!F;W(N"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%=H97)E('1H92!S96%R8V@@9G5N8W1I;VX@
M=VEL;"!L;V]K(&9O<@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!T:&4@24-!3R!D871A8F%S92`H9V5N97)A=&5D('=I=&@@=&AE
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&)U:6QD
M365T87)$0BYP:'`@<V-R:7!T*0HD9'-N("`@("`@("`@("`@(#T@(G-Q;&ET
M93HO+VQO8V%L:&]S="\O=7-R+VQO8V%L+VQI8B]P:'`O9&%T82]397)V:6-E
M<U]796%T:&5R+W-E<G9I8V5S5V5A=&AE<D1"(CL@"B1S;W5R8V5-971A<B`@
M("`@/2`B:'1T<"([("`@("`@("`@("\O(%1H:7,@<V-R:7!T('=I;&P@<'5L
M;"!T:&4@345405(@9&%T82!V:6$@:'1T<`HD<V]U<F-E5&%F("`@("`@(#T@
M(FAT='`B.R`@("`@("`@("`O+R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(%1!1@HD<V]U<F-E4&%T:$UE=&%R(#T@(B([("`@("`@("`@("`@("`O+R!/
M;FQY(&YE961E9"!W:&5N(&YO;BUS=&%N9&%R9"!A8V-E<W,@:7,@=7-E9`HD
M<V]U<F-E4&%T:%1A9B`@(#T@(B([("`@("`@("`@("`@("`O+PHD8V%C:&54
M>7!E("`@("`@(#T@(B([("`@("`@("`@("`@("`O+R!3970@82!T>7!E("AF
M:6QE+"!D8BP@;61B+"`N+BXI('1O"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&5N86)L92!C86-H:6YG+@HD8V%C:&5/<'0@("`@
M("`@(#T@87)R87DH*3L@("`@("`@("`O+R!#86-H92!N965D<R!V87)I;W5S
M(&]P=&EO;G,L(&1E<&5N9&EN9PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!O;B!T:&4@8V]N=&%I;F5R+71Y<&4@+2!P;&5A<V4@
M8V]N<W5L=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!T:&4@0V%C:&4@;6%N=6%L("\@<V]U<F-E8V]D92$*)'5N:71S1F]R;6%T
M("`@("`](")M971R:6,B.R`@("`@("`@+R\@5&AE(&9O<FUA="!T:&4@=6YI
M=',@87)E(&1I<W!L87EE9"!I;B`M"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(&UE=')I8RP@<W1A;F1A<F0@;W(@<V]M92!C=7-T
M;VUI>F%T:6]N+@HD9&%T949O<FUA="`@("`@(#T@(FHN($T@62([("`@("`@
M("`O+R!3970@=&AE(&9O<FUA="!T:&4@9&%T92!I<R!D:7-P;&%Y960@:6X*
M)'1I;65&;W)M870@("`@("`](")(.FDB.R`@("`@("`@("`@+R\@("`@("`@
M("`@("`@("`@("`@('1I;64*+R\M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM"@HO+R!,;V%D('1H92!796%T:&5R(&-L87-S"G)E<75I<F5?;VYC92`B
M4V5R=FEC97,O5V5A=&AE<BYP:'`B.PH*+R\@3V)J96-T(&EN:71I86QI>F%T
M:6]N("T@97)R;W(@8VAE8VMI;F<@:7,@:6UP;W)T86YT+"!B96-A=7-E(&]F
M"B\O(&AA;F1L:6YG(&5X8V5P=&EO;G,@<W5C:"!A<R!M:7-S:6YG(%!%05(@
M;6]D=6QE<PHD;65T87(@/2`F4V5R=FEC97-?5V5A=&AE<CHZ<V5R=FEC92@B
M365T87(B*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&UE=&%R
M*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD;65T87(M/F=E=$UE<W-A9V4H*2XB
M7&XB*3L*?0H*+R\@4V5T('!A<F%M971E<G,@9F]R($1"(&%C8V5S<RP@;F5E
M9&5D(&9O<B!L;V-A=&EO;B!S96%R8VAE<PHD;65T87(M/G-E=$UE=&%R1$(H
M)&1S;BD["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1M971A<BDI
M('L*("`@(&5C:&\@(D5R<F]R.B`B+B1M971A<BT^9V5T365S<V%G92@I+B)<
M;B(["GT*"B\O($EN:71I86QI>F4@8V%C:&EN9PII9B`H<W1R;&5N*"1C86-H
M951Y<&4I*2!["B`@("`D<W1A='5S(#T@)&UE=&%R+3YS971#86-H92@D8V%C
M:&54>7!E+"`D8V%C:&5/<'0I.PH@("`@:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("!E8VAO(")%<G)O<CH@(BXD
M<W1A='5S+3YG971-97-S86=E*"DN(EQN(CL*("`@('T*?0H*+R\@1&5F:6YE
M('1H92!U;FET<R!F;W)M870L(&)R:6YG('1H92!R971R:65V960@9F]R;6%T
M(&EN=&\*+R\@<V]M971H:6YG(&UO<F4@8V]M;6]N+BXN"B1M971A<BT^<V5T
M56YI='-&;W)M870H)'5N:71S1F]R;6%T*3L*)'5N:71S(#T@)&UE=&%R+3YG
M9715;FET<T9O<FUA="@I.PHD=6YI='-;(G1E;7`B72`@(#T@(B9D96<[(BYS
M=')T;W5P<&5R*"1U;FET<ULB=&5M<")=*3L*)'5N:71S6R)W:6YD(ET@("`]
M("(F;F)S<#LB+G-T<E]R97!L86-E*")K;6@B+"`B:VTO:"(L("1U;FET<ULB
M=VEN9")=*3L*)'5N:71S6R)V:7,B72`@("`]("(F;F)S<#LB+B1U;FET<ULB
M=FES(ET["B1U;FET<ULB:&5I9VAT(ET@/2`B)FYB<W`[(BXD=6YI='-;(FAE
M:6=H=")=.PHD=6YI='-;(G!R97,B72`@(#T@(B9N8G-P.R(N)'5N:71S6R)P
M<F5S(ET["B1U;FET<ULB<F%I;B)=("`@/2`B)FYB<W`[(BXD=6YI='-;(G)A
M:6XB73L*"B1M971A<BT^<V5T365T87)3;W5R8V4H)'-O=7)C94UE=&%R+"`D
M<V]U<F-E4&%T:$UE=&%R+"`D<V]U<F-E5&%F+"`D<V]U<F-E4&%T:%1A9BD[
M"@HO+R!3970@9&%T92TO=&EM92UF;W)M870*)&UE=&%R+3YS971$871E5&EM
M949O<FUA="@D9&%T949O<FUA="P@)'1I;65&;W)M870I.PH*+R\@4V5A<F-H
M(&9O<B!D969I;F5D(&QO8V%T:6]N(&%N9"!F971C:"!T:&4@9FER<W0@:71E
M;2!F;W5N9"X*+R\@0F%I;"!O=70@:68@<V]M971H:6YG(&)A9"!H87!P96YS
M+BXN"B1S96%R8V@@/2`D;65T87(M/G-E87)C:$QO8V%T:6]N*"1L;V-A=&EO
M;BP@=')U92D["FEF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S96%R
M8V@I*2!["B`@("!D:64H(D5R<F]R.B`B+B1S96%R8V@M/F=E=$UE<W-A9V4H
M*2XB7&XB*3L*?0H*+R\@4F5T<FEE=F4@9&%T82P@<W1O<F4@:6X@=F%R:6%B
M;&5S+"!B86EL(&]U="!O;B!E<G)O<@HD9F5T8V@@/2!A<G)A>2@*("`@(")L
M;V-A=&EO;B(@/3X@(F=E=$QO8V%T:6]N(BP*("`@(")W96%T:&5R(B`@/3X@
M(F=E=%=E871H97(B+`H@("`@(F9O<F5C87-T(B`]/B`B9V5T1F]R96-A<W0B
M"BD["F9O<F5A8V@@*"1F971C:"!A<R`D=F%R:6%B;&4@/3X@)&9U;F-T:6]N
M*2!["B`@("`D)'9A<FEA8FQE(#T@)&UE=&%R+3XD9G5N8W1I;VXH)'-E87)C
M:"D["B`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D)'9A<FEA
M8FQE*2D@>PH@("`@("`@(&5C:&\@(D5R<F]R.B`B+B0D=F%R:6%B;&4M/F=E
M=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@(&-O;G1I;G5E.PH@("`@?0I]"@HO
M+R!.;W<@=V4@;W5T<'5T(&%L;"!T:&4@9&%T82P@<&QE87-E(&1O;B=T(&5X
M<&5C="!E>'1E;G-I=F4@8V]M;65N=',@:&5R92P@=&AI<R!I<R!B87-I8PHO
M+R!(5$U,+T-34R!S='5F9BX@06QS;R!T:&ES(&ES;B=T(&$@=F5R>2!F86YC
M>2!D97-I9VXL(&ET)W,@:G5S="!T;R!S:&]W('EO=2P@=VAA=`HO+R!T:&4@
M<V-R:7!T(&ES(&%B;&4@=&\@9&\@*&%N9"!M;W)E(#LM*2DN+BX*/SX*/&AT
M;6P^"CQH96%D/@H@("`@/'1I=&QE/E-E<G9I8V5S7U=E871H97(Z.DU%5$%2
M+U1!1CPO=&ET;&4^"B`@("`\<W1Y;&4@='EP93TB=&5X="]C<W,B/@H@("`@
M("`@("YN;W)M86P@("`@('L@9F]N="UF86UI;'DZ($%R:6%L+"!(96QV971I
M8V$L('-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3%P=#L@9F]N="UW96EG:'0Z
M(&YO<FUA;#L@9F]N="US='EL93H@;F]R;6%L('T*("`@("`@("`N:71A;&EC
M("`@("![(&9O;G0M=V5I9VAT.B!N;W)M86P[(&9O;G0M<W1Y;&4Z(&ET86QI
M8R!]"B`@("`@("`@+F)O;&0@("`@("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@
M9F]N="US='EL93H@;F]R;6%L('T*("`@("`@("`N8F]L9&ET86QI8R![(&9O
M;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!I=&%L:6,@?0H@("`@("`@
M("YR961B;VQD("`@('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z
M(&YO<FUA;#L@8V]L;W(Z("-F9C`P,#`@?0H@("`@("`@("YB;'5E8F]L9"`@
M('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&YO<FUA;#L@8V]L
M;W(Z(",P,#`P9F8@?0H@("`@("`@("YB9V=R97D@("`@('L@8F%C:V=R;W5N
M9"UC;VQO<CH@(V4Y93EE.2!]"B`@("`@("`@+F)G:VAA:VD@("`@>R!B86-K
M9W)O=6YD+6-O;&]R.B`C9#AD.&,P('T*("`@("`@("`N<F5G("`@("`@("![
M(&9O;G0M<VEZ93H@-W!T.R!V97)T:6-A;"UA;&EG;CH@<W5P97(@?0H@("`@
M("`@(&EM9R`@("`@("`@('L@=F5R=&EC86PM86QI9VXZ(&UI9&1L93L@8F]R
M9&5R+7-T>6QE.B!N;VYE.R!B;W)D97(M=VED=&@Z(#!P>"!]"B`@("`@("`@
M82`@("`@("`@("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@
M:71A;&EC.R!C;VQO<CH@(SDY,S,P,#L@=&5X="UD96-O<F%T:6]N.B!N;VYE
M('T*("`@("`@("!A.G9I<VET960@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F
M;VYT+7-T>6QE.B!I=&%L:6,[(&-O;&]R.B`C.3DS,S`P.R!T97AT+61E8V]R
M871I;VXZ(&YO;F4@?0H@("`@("`@(&$Z:&]V97(@("`@('L@9F]N="UW96EG
M:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8SL@8V]L;W(Z("-C8S,S,#`[
M('1E>'0M9&5C;W)A=&EO;CH@=6YD97)L:6YE('T*("`@("`@("!T86)L92`@
M("`@("![(&)O<F1E<CH@,'!X(&YO;F4@8FQA8VL[(&)O<F1E<BUS<&%C:6YG
M.B`P<'@@?0H@("`@("`@('1D("`@("`@("`@('L@9F]N="UF86UI;'DZ($%R
M:6%L+"!(96QV971I8V$L('-A;G,M<V5R:68[(&9O;G0M<VEZ93H@,3%P=#L@
M9F]N="UW96EG:'0Z(&YO<FUA;#L@9F]N="US='EL93H@;F]R;6%L('T*("`@
M(#PO<W1Y;&4^"CPO:&5A9#X*/&)O9'D@8VQA<W,](FYO<FUA;"(^"CP_<&AP
M"B\O($1E8G5G(&]U='!U=',@=&AE(')A=R!D871A(&9E=&-H960@8GD@=&AE
M(&9O<F5A8V@M;&]O<"!A8F]V92P@:G5S="!F;W(@8VAE8VMI;F<N+BX*:68@
M*&ES<V5T*"1?1T546R)D96)U9R)=*2D@>PH@("`@96-H;R`B/'!R93Y<;B([
M"B`@("!V87)?9'5M<"@D;&]C871I;VXL("1W96%T:&5R+"`D9F]R96-A<W0I
M.PH@("`@96-H;R`B/"]P<F4^7&XB.PI](`H_/@H\<W!A;B!C;&%S<STB8FQU
M96)O;&0B('-T>6QE/2)F;VYT+7-I>F4Z(#$S<'0B/E=E871H97(@1F]R96-A
M<W0\+W-P86X^(&-R96%T960@=VET:"`\82!S='EL93TB9F]N="US:7IE.B`Q
M,W!T(B!H<F5F/2)H='1P.B\O<&5A<BYP:'`N;F5T+R(^4$5!4G,\+V$^(#QA
M('-T>6QE/2)F;VYT+7-I>F4Z(#$S<'0B(&AR968](FAT='`Z+R]P96%R+G!H
M<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R+R(^4V5R=FEC97-?5V5A
M=&AE<CPO83X\8G(^"CQT86)L92!S='EL93TB=VED=&@Z(#$P,"4B/@H\='(^
M"B`@("`\=&0^"B`@("`@("`@/'1A8FQE(&)O<F1E<CTB,"(@<W1Y;&4](F)O
M<F1E<BUT;W`Z(#)P>"!S;VQI9"`C-3(T8CDX.R!B;W)D97(M8F]T=&]M.B`R
M<'@@<V]L:60@(V4P93-C93L@8F]R9&5R+6QE9G0Z(#)P>"!S;VQI9"`C8CAB
M-F,Q.R!B;W)D97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P.R!W:61T:#H@
M,3`P)2(^"B`@("`@("`@/'1R(&-L87-S/2)B9VMH86MI(CX*("`@("`@("`@
M("`@/'1D(&-O;'-P86X](C0B('-T>6QE/2)B;W)D97(M8F]T=&]M.B`R<'@@
M<V]L:60@(V%B861A,B(^/'-P86X@8VQA<W,](F)O;&0B/CP_/21L;V-A=&EO
M;ELB;F%M92)=/SX@*#P_/21S96%R8V@_/BD\+W-P86X^/"]T9#X*("`@("`@
M("`\+W1R/@H@("`@("`@(#QT<CX*("`@("`@("`@("`@/'1D/CQS<&%N(&-L
M87-S/2)B;VQD(CY3=6YR:7-E.CPO<W!A;CX@/&EM9R!S='EL93TB=VED=&@Z
M(#(X<'@[(&AE:6=H=#H@,3-P>#L@=F5R=&EC86PM86QI9VXZ(&)A<V5L:6YE
M(B!A;'0](E-U;G)I<V4B('-R8STB:6UA9V5S+W-U;G)I<V4N9VEF(CX@/#\]
M)&QO8V%T:6]N6R)S=6YR:7-E(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9#X\
M<W!A;B!C;&%S<STB8F]L9"(^4W5N<V5T.CPO<W!A;CX@/&EM9R!S='EL93TB
M=VED=&@Z(#,P<'@[(&AE:6=H=#H@,35P>#L@=F5R=&EC86PM86QI9VXZ(&)A
M<V5L:6YE(B!A;'0](E-U;G-E="(@<W)C/2)I;6%G97,O<W5N<V5T+F=I9B(^
M(#P_/21L;V-A=&EO;ELB<W5N<V5T(ET_/CPO=&0^"B`@("`@("`@("`@(#QT
M9"!S='EL93TB=VED=&@Z(#$Y,'!X(CXF;F)S<#L\+W1D/@H@("`@("`@("`@
M("`\=&0@<W1Y;&4](G=I9'1H.B!A=71O(CXF;F)S<#L\+W1D/@H@("`@("`@
M(#PO='(^"B`@("`@("`@/'1R('-T>6QE/2)H96EG:'0Z(#$U<'@B/@H@("`@
M("`@("`@("`\=&0@;F]W<F%P/CQS<&%N(&-L87-S/2)B;VQD(CY496UP97)A
M='5R93H\+W-P86X^(#P_/7)O=6YD*"1W96%T:&5R6R)T96UP97)A='5R92)=
M+"`Q*2XD=6YI='-;(G1E;7`B73\^/"]T9#X*("`@("`@("`@("`@/'1D(&YO
M=W)A<#X\<W!A;B!C;&%S<STB8F]L9"(^1&5W('!O:6YT.CPO<W!A;CX@/#\]
M<F]U;F0H)'=E871H97);(F1E=U!O:6YT(ETL(#$I+B1U;FET<ULB=&5M<")=
M/SX\+W1D/@H@("`@("`@("`@("`\=&0@;F]W<F%P/CQS<&%N(&-L87-S/2)B
M;VQD(CY&96QT('1E;7!E<F%T=7)E.CPO<W!A;CX@/#\]<F]U;F0H)'=E871H
M97);(F9E;'1496UP97)A='5R92)=+"`Q*2XD=6YI='-;(G1E;7`B73\^/"]T
M9#X*("`@("`@("`@("`@/'1D(')O=W-P86X](C0B('9A;&EG;CTB=&]P(CX*
M("`@("`@("`@("`@("`@(#QS<&%N(&-L87-S/2)B;VQD(CY4<F5N9#H\+W-P
M86X^/&)R/@H\/W!H<`II9B`H:7-S970H)'=E871H97);(G1R96YD(ETI("8F
M('-I>F5O9B@D=V5A=&AE<ELB=')E;F0B72DI('L*("`@("\O($]U='!U="!T
M:&4@=')E;F1S+"!L;V]P('1H<F]U9V@@=&AE(&%R<F%Y<RP*("`@("\O(&-O
M;G9E<G0@=&AE('-T=69F('1O(&YI8V4@;&]O:VEN9R!D97-I9VXL(&IA9&1A
M+"!J861D82XN+@H@("`@9F]R96%C:"`H)'=E871H97);(G1R96YD(ET@87,@
M)'1R96YD*2!["B`@("`@("`@9F]R96%C:"`H)'1R96YD(&%S("1K97D@/3X@
M)'9A;"D@>PH@("`@("`@("`@("!S=VET8V@@*"1K97DI('L*("`@("`@("`@
M("`@("`@(&-A<V4@(G1Y<&4B.@H@("`@("`@("`@("`@("`@("`@('-W:71C
M:"`H)'9A;"D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(").3U-)
M1R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(DYO
M(%-I9VYI9FEC86YT(%=E871H97(B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(E1%
M35!/(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B
M5&5M<&]R87)Y(%=E871H97(B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(D)%0TU'
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B5V5A
M=&AE<B!"96-O;6EN9R(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@)'9A;'5E("`]("(B.PH@("`@("`@("`@("`@("`@("`@(&9O<F5A8V@@
M*&%R<F%Y*")F<F]M(BP@(G1O(BP@(F%T(BD@87,@)'1I;64I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1T<F5N9%LD=&EM95TI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@+CT@(B`B+B1T
M:6UE+B(@(BXD=')E;F1;)'1I;65=.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("@D=F%L=64@(3T@(B(I(#\@)'9A;'5E("`]('1R:6TH)'9A;'5E*2XB.B(Z
M(B(["B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]("<\<W!A;B!C;&%S
M<STB:71A;&EC(CXG+B1S=')I;F<N)SPO<W!A;CXG.PH@("`@("`@("`@("`@
M("`@("`@("1V86QU92`@/2`G/'-P86X@8VQA<W,](FET86QI8R(^)RXD=F%L
M=64N)SPO<W!A;CXG.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B=VEN9"(Z"B`@("`@("`@("`@("`@("`@("`@
M)'-T<FEN9R`](")7:6YD.B(["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M("`]("AS=')T;VQO=V5R*"1T<F5N9%LB=VEN9$1I<F5C=&EO;B)=*2`]/2`B
M8V%L;2(I(#\@(D-A;&TB(#H@(D9R;VT@=&AE("(N)'1R96YD6R)W:6YD1&ER
M96-T:6]N(ETN(B`H(BXD=')E;F1;(G=I;F1$96=R965S(ETN(B9D96<[*2!A
M="`B+G)O=6YD*"1T<F5N9%LB=VEN9")=+"`Q*2XD=6YI='-;(G=I;F0B73L*
M("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1R96YD6R)W:6YD5F%R
M:6%B:6QI='DB72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'9A;'5E
M("X]("(L('9A<FEA8FQE(&9R;VT@(BXD=')E;F1;(G=I;F1687)I86)I;&ET
M>2)=6R)F<F]M(ETN(B9D96<[('1O("(N)'1R96YD6R)W:6YD5F%R:6%B:6QI
M='DB75LB=&\B72XB)F1E9SLB.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'1R96YD6R)W:6YD1W5S=")=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@+CT@(BP@=VET
M:"!G=7-T<R!U<"!T;R`B+G)O=6YD*"1T<F5N9%LB=VEN9$=U<W0B72P@,2DN
M)'5N:71S6R)W:6YD(ET["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B=FES
M:6)I;&ET>2(Z"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`](")6:7-I
M8FEL:71Y.B(["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E("`]('-T<G1O
M;&]W97(H)'1R96YD6R)V:7-1=6%L:69I97(B72DN(B`B+G)O=6YD*"1T<F5N
M9%LB=FES:6)I;&ET>2)=+"`Q*2XD=6YI='-;(G9I<R)=.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B8VQO=61S
M(CH*("`@("`@("`@("`@("`@("`@("`D<W1R:6YG(#T@(D-L;W5D<SHB.PH@
M("`@("`@("`@("`@("`@("`@("1V86QU92`@/2`B(CL*("`@("`@("`@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'9A;"D[("1I*RLI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@)&-L;W5D(#T@=6-W;W)D<R@D
M=F%L6R1I75LB86UO=6YT(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'9A;%LD:5U;(G1Y<&4B72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1C;&]U9"`N/2`B("(N)'9A;%LD:5U;(G1Y<&4B73L*
M("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-S970H)'9A;%LD:5U;(FAE:6=H=")=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-L;W5D("X]("(@870@(BXD=F%L6R1I
M75LB:&5I9VAT(ETN)'5N:71S6R)H96EG:'0B73L*("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`D=F%L=64@+CT@
M)&-L;W5D+B(@(CL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")C;VYD:71I
M;VXB.@H@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B0V]N9&ET:6]N
M.B(["B`@("`@("`@("`@("`@("`@("`@)'9A;'5E("`]('5C=V]R9',H)'9A
M;"D["B`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@
M("!C87-E(")P<F5S<W5R92(Z"B`@("`@("`@("`@("`@("`@("`@)'-T<FEN
M9R`](")0<F5S<W5R93HB.PH@("`@("`@("`@("`@("`@("`@("1V86QU92`@
M/2!R;W5N9"@D=F%L+"`Q*2XD=6YI='-;(G!R97,B73L*("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(F9R;VTB.@H@
M("`@("`@("`@("`@("`@8V%S92`B=&\B.@H@("`@("`@("`@("`@("`@8V%S
M92`B870B.@H@("`@("`@("`@("`@("`@8V%S92`B=VEN9$1I<F5C=&EO;B(Z
M"B`@("`@("`@("`@("`@("!C87-E(")W:6YD1&5G<F5E<R(Z"B`@("`@("`@
M("`@("`@("!C87-E(")W:6YD5F%R:6%B:6QI='DB.@H@("`@("`@("`@("`@
M("`@8V%S92`B=VEN9$=U<W0B.@H@("`@("`@("`@("`@("`@8V%S92`B=FES
M475A;&EF:65R(CH*("`@("`@("`@("`@("`@("`@("!C;VYT:6YU92`R.PH@
M("`@("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@("`@("`D
M<W1R:6YG(#T@(B([("1V86QU92`]("(B.PH@("`@("`@("`@("`@("`@("`@
M('9A<E]D=6UP*"1K97DL("1V86PI.PH@("`@("`@("`@("`@("`@("`@(&)R
M96%K.PH@("`@("`@("`@("!]"C\^"B`@("`@("`@("`@("`@("`\/STD<W1R
M:6YG/SX@/#\])'9A;'5E/SX\8G(^"CP_<&AP"B`@("`@("`@?0H*("`@('T*
M?2!E;'-E('L*/SX*("`@("`@("`@("`@("`@(&YO;F4\8G(^"CP_<&AP"GT*
M/SX*("`@("`@("`@("`@("`@(#QS<&%N(&-L87-S/2)B;VQD(CY296UA<FMS
M.CPO<W!A;CX\8G(^"CP_<&AP"FEF("AI<W-E="@D=V5A=&AE<ELB<F5M87)K
M(ETI("8F('-I>F5O9B@D=V5A=&AE<ELB<F5M87)K(ETI*2!["B`@("`O+R!3
M86UE(&9O<B!T:&4@<F5M87)K<RP@979E;B!L97-S('-P96-T86-U;&%R+BXN
M"B`@("!F;W)E86-H*"1W96%T:&5R6R)R96UA<FLB72!A<R`D:V5Y(#T^("1V
M86PI('L*("`@("`@("!S=VET8V@@*"1K97DI('L*("`@("`@("`@("`@8V%S
M92`B875T;W-T871I;VXB.@H@("`@("`@("`@("!C87-E(")P<F5S<V-H9R(Z
M"B`@("`@("`@("`@(&-A<V4@(FYO<W!E8VDB.@H@("`@("`@("`@("!C87-E
M(")S=6YD=7)A=&EO;B(Z"B`@("`@("`@("`@(&-A<V4@(FUA:6YT86EN(CH*
M("`@("`@("`@("`@("`@("1S=')I;F<@/2`B(CL*("`@("`@("`@("`@("`@
M("1V86QU92`@/2`D=F%L.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@
M("`@("`@(&-A<V4@(G-E87!R97-S=7)E(CH*("`@("`@("`@("`@("`@("1S
M=')I;F<@/2`B4')E<W-U<F4@870@<V5A;&5V96PZ(CL*("`@("`@("`@("`@
M("`@("1V86QU92`@/2!R;W5N9"@D=F%L+"`Q*2XD=6YI='-;(G!R97,B73L*
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E("(Q:'1E
M;7`B.@H@("`@("`@("`@("`@("`@)'-T<FEN9R`](")496UP97)A='5R92!F
M;W(@;&%S="!H;W5R.B(["B`@("`@("`@("`@("`@("`D=F%L=64@(#T@<F]U
M;F0H)'9A;"P@,2DN)'5N:71S6R)T96UP(ET["B`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@8V%S92`B,6AD97<B.@H@("`@("`@("`@("`@
M("`@)'-T<FEN9R`](")$97<@4&]I;G0@9F]R(&QA<W0@:&]U<CHB.PH@("`@
M("`@("`@("`@("`@)'9A;'5E("`](')O=6YD*"1V86PL(#$I+B1U;FET<ULB
M=&5M<")=.PH@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@(&-A
M<V4@(C9H;6%X=&5M<"(Z"B`@("`@("`@("`@(&-A<V4@(C9H;6EN=&5M<"(Z
M"B`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1W96%T:&5R6R)R96UA<FLB
M75LB-FAM87AT96UP(ETI("8F("%I<W-E="@D=V5A=&AE<ELB<F5M87)K(EU;
M(C9H;6EN=&5M<")=*2D@>PH@("`@("`@("`@("`@("`@("`@(&-O;G1I;G5E
M*#(I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@)'-T<FEN
M9R`](")-87@O36EN(%1E;7`@9F]R(&QA<W0@-B!H;W5R<SHB.PH@("`@("`@
M("`@("`@("`@)'9A;'5E("`]("AI<W-E="@D=V5A=&AE<ELB<F5M87)K(EU;
M(C9H;6%X=&5M<")=*2D@/R!R;W5N9"@D=V5A=&AE<ELB<F5M87)K(EU;(C9H
M;6%X=&5M<")=+"`Q*2XD=6YI='-;(G1E;7`B72`Z("(M(CL*("`@("`@("`@
M("`@("`@("1V86QU92`N/2`B+R(["B`@("`@("`@("`@("`@("`D=F%L=64@
M+CT@*&ES<V5T*"1W96%T:&5R6R)R96UA<FLB75LB-FAM:6YT96UP(ETI*2`_
M(')O=6YD*"1W96%T:&5R6R)R96UA<FLB75LB-FAM:6YT96UP(ETL(#$I+B1U
M;FET<ULB=&5M<")=(#H@(BTB.PH@("`@("`@("`@("`@("`@=6YS970H)'=E
M871H97);(G)E;6%R:R)=6R(V:&UA>'1E;7`B72D[('5N<V5T*"1W96%T:&5R
M6R)R96UA<FLB75LB-FAM:6YT96UP(ETI.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@(C(T:&UA>'1E;7`B.@H@("`@("`@("`@
M("!C87-E("(R-&AM:6YT96UP(CH*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'=E871H97);(G)E;6%R:R)=6R(R-&AM87AT96UP(ETI("8F("%I<W-E
M="@D=V5A=&AE<ELB<F5M87)K(EU;(C(T:&UI;G1E;7`B72DI('L*("`@("`@
M("`@("`@("`@("`@("!C;VYT:6YU92@R*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("1S=')I;F<@/2`B36%X+TUI;B!496UP(&9O<B!L
M87-T(#(T(&AO=7)S.B(["B`@("`@("`@("`@("`@("`D=F%L=64@(#T@*&ES
M<V5T*"1W96%T:&5R6R)R96UA<FLB75LB,C1H;6%X=&5M<")=*2D@/R!R;W5N
M9"@D=V5A=&AE<ELB<F5M87)K(EU;(C(T:&UA>'1E;7`B72P@,2DN)'5N:71S
M6R)T96UP(ET@.B`B+2(["B`@("`@("`@("`@("`@("`D=F%L=64@+CT@(B\B
M.PH@("`@("`@("`@("`@("`@)'9A;'5E("X]("AI<W-E="@D=V5A=&AE<ELB
M<F5M87)K(EU;(C(T:&UI;G1E;7`B72DI(#\@<F]U;F0H)'=E871H97);(G)E
M;6%R:R)=6R(R-&AM:6YT96UP(ETL(#$I+B1U;FET<ULB=&5M<")=(#H@(BTB
M.PH@("`@("`@("`@("`@("`@=6YS970H)'=E871H97);(G)E;6%R:R)=6R(R
M-&AM87AT96UP(ETI.R!U;G-E="@D=V5A=&AE<ELB<F5M87)K(EU;(C(T:&UI
M;G1E;7`B72D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M8V%S92`B<VYO=V1E<'1H(CH*("`@("`@("`@("`@("`@("1S=')I;F<@/2`B
M4VYO=R!D97!T:#HB.PH@("`@("`@("`@("`@("`@)'9A;'5E("`]("1V86PN
M)'5N:71S6R)R86EN(ET["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@8V%S92`B<VYO=V5Q=6EV(CH*("`@("`@("`@("`@("`@("1S=')I
M;F<@/2`B5V%T97(@97%U:79A;&5N="!O9B!S;F]W.B(["B`@("`@("`@("`@
M("`@("`D=F%L=64@(#T@)'9A;"XD=6YI='-;(G)A:6XB73L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("!C87-E(")S96YS;W)S(CH*("`@
M("`@("`@("`@("`@("1S=')I;F<@/2`B(CL*("`@("`@("`@("`@("`@("1V
M86QU92`@/2!I;7!L;V1E*"(\8G(^(BP@)'9A;"D["B`@("`@("`@("`@("`@
M("!B<F5A:SL*("`@("`@("`@("`@9&5F875L=#H*("`@("`@("`@("`@("`@
M("1S=')I;F<@/2`B(CL@)'9A;'5E(#T@(B(["B`@("`@("`@("`@("`@("!V
M87)?9'5M<"@D:V5Y+"`D=F%L*3L*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@('T*/SX*("`@("`@("`@("`@("`@(#P_/21S=')I;F<_/B`\/STD
M=F%L=64_/CQB<CX*/#]P:'`*("`@('T*?2!E;'-E('L*/SX*("`@("`@("`@
M("`@("`@(&YO;F4\8G(^"CP_<&AP"GT*/SX*("`@("`@("`@("`@/"]T9#X*
M("`@("`@("`\+W1R/@H@("`@("`@(#QT<B!S='EL93TB:&5I9VAT.B`Q-7!X
M(CX*("`@("`@("`@("`@/'1D(&-O;'-P86X](C(B('-T>6QE/2)W:61T:#H@
M,S$P<'@B(&YO=W)A<#X\<W!A;B!C;&%S<STB8F]L9"(^4')E<W-U<F4Z/"]S
M<&%N/B`\/SUR;W5N9"@D=V5A=&AE<ELB<')E<W-U<F4B72P@,2DN)'5N:71S
M6R)P<F5S(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9"!N;W=R87`^/'-P86X@
M8VQA<W,](F)O;&0B/DAU;6ED:71Y.CPO<W!A;CX@/#\])'=E871H97);(FAU
M;6ED:71Y(ET_/B4\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R('-T
M>6QE/2)H96EG:'0Z(#$U<'@B/@H@("`@("`@("`@("`\=&0@8V]L<W!A;CTB
M,B(@;F]W<F%P/@H@("`@("`@("`@("`@("`@/'-P86X@8VQA<W,](F)O;&0B
M/E=I;F0Z/"]S<&%N/B`\/SUS=')T;VQO=V5R*"1W96%T:&5R6R)W:6YD1&ER
M96-T:6]N(ETI(#T](")C86QM(B`_(")#86QM(B`Z(")&<F]M('1H92`B+B1W
M96%T:&5R6R)W:6YD1&ER96-T:6]N(ETN(B`H(BXD=V5A=&AE<ELB=VEN9$1E
M9W)E97,B72XB)F1E9SLI(&%T("(N<F]U;F0H)'=E871H97);(G=I;F0B72P@
M,2DN)'5N:71S6R)W:6YD(ET_/B`*("`@("`@("`@("`@("`@(#P_/6ES<V5T
M*"1W96%T:&5R6R)W:6YD5F%R:6%B:6QI='DB72D@/R`B/&)R/G9A<FEA8FQE
M(&9R;VT@(BXD=V5A=&AE<ELB=VEN9%9A<FEA8FEL:71Y(EU;(F9R;VTB72XB
M)F1E9SL@=&\@(BXD=V5A=&AE<ELB=VEN9%9A<FEA8FEL:71Y(EU;(G1O(ETN
M(B9D96<[(B`Z("(B/SX@"B`@("`@("`@("`@("`@("`\/SUI<W-E="@D=V5A
M=&AE<ELB=VEN9$=U<W0B72D@/R`B/&)R/G=I=&@@9W5S=',@=7`@=&\@(BYR
M;W5N9"@D=V5A=&AE<ELB=VEN9$=U<W0B72P@,2DN)'5N:71S6R)W:6YD(ET@
M.B`B(C\^(`H@("`@("`@("`@("`\+W1D/@H@("`@("`@("`@("`\=&0@=F%L
M:6=N/2)T;W`B(&YO=W)A<#X\<W!A;B!C;&%S<STB8F]L9"(^5FES:6)I;&ET
M>3H\+W-P86X^(#P_/7-T<G1O;&]W97(H)'=E871H97);(G9I<U%U86QI9FEE
M<B)=*3\^(#P_/7)O=6YD*"1W96%T:&5R6R)V:7-I8FEL:71Y(ETL(#$I+B1U
M;FET<ULB=FES(ET_/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\='(^
M"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^0W5R<F5N="!C
M;VYD:71I;VXZ/"]S<&%N/CQB<CX\/SUI<W-E="@D=V5A=&AE<ELB8V]N9&ET
M:6]N(ETI(#\@=6-W;W)D<R@D=V5A=&AE<ELB8V]N9&ET:6]N(ETI(#H@(DYO
M(%-I9VYI9FEC86YT(%=E871H97(B/SX\+W1D/@H@("`@("`@("`@("`\=&0^
M/&EM9R!S='EL93TB:&5I9VAT.B`S,G!X.R!W:61T:#H@,S)P>"(@86QT/2(\
M/SUI<W-E="@D=V5A=&AE<ELB8V]N9&ET:6]N(ETI(#\@=6-W;W)D<R@D=V5A
M=&AE<ELB8V]N9&ET:6]N(ETI(#H@(DYO(%-I9VYI9FEC86YT(%=E871H97(B
M/SXB('-R8STB:6UA9V5S+S,R>#,R+SP_/21W96%T:&5R6R)C;VYD:71I;VY)
M8V]N(ET_/BYP;F<B/CPO=&0^"CP_<&AP"FEF("AI<W-E="@D=V5A=&AE<ELB
M<')E8VEP:71A=&EO;B)=*2`F)B!S:7IE;V8H)'=E871H97);(G!R96-I<&ET
M871I;VXB72DI('L*("`@("\O($]U='!U="!A(&QI;F4@9F]R(&5A8V@@='EP
M92!O9B!P<F5C:7!I=&%T:6]N+`H@("`@+R\@9&ES=&EN9W5I<V@@8F5T=V5E
M;B!S=')I;F<@86YD(&YU;65R:6,@=F%L=65S"C\^"B`@("`@("`@("`@("`@
M("`\8G(^/'-P86X@8VQA<W,](F)O;&0B/E!R96-I<&ET871I;VXZ/"]S<&%N
M/CQB<CX*/#]P:'`*("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=V5A
M=&AE<ELB<')E8VEP:71A=&EO;B)=*3L@)&DK*RD@>PH@("`@("`@("1P<F5C
M:7`@/2`B;&%S="`B+B1W96%T:&5R6R)P<F5C:7!I=&%T:6]N(EU;)&E=6R)H
M;W5R<R)=+B)H.B`B+B1W96%T:&5R6R)P<F5C:7!I=&%T:6]N(EU;)&E=6R)A
M;6]U;G0B73L*("`@("`@("`D<')E8VEP("X]("AC='EP95]A;'!H82@D=V5A
M=&AE<ELB<')E8VEP:71A=&EO;B)=6R1I75LB86UO=6YT(ETI*2`_("(B(#H@
M)'5N:71S6R)R86EN(ET["C\^"B`@("`@("`@("`@("`@("`\/STD<')E8VEP
M/SX\8G(^"CP_<&AP"B`@("!]"GT*/SX*("`@("`@("`@("`@/"]T9#X*("`@
M("`@("`@("`@/'1D('9A;&EG;CTB=&]P(CX*("`@("`@("`@("`@("`@(#QS
M<&%N(&-L87-S/2)B;VQD(CY#;&]U9',Z/"]S<&%N/CQB<CX*/#]P:'`*:68@
M*&ES<V5T*"1W96%T:&5R6R)C;&]U9',B72D@)B8@<VEZ96]F*"1W96%T:&5R
M6R)C;&]U9',B72DI('L*("`@("\O(%EE86@L(&-L;W5D<RXN+B!S86UE(&%S
M(&EN('1H92!T<F5N9"!H86YD;&EN9RXN+@H@("`@9F]R("@D:2`](#`[("1I
M(#P@<VEZ96]F*"1W96%T:&5R6R)C;&]U9',B72D[("1I*RLI('L*("`@("`@
M("`D8VQO=60@/2!U8W=O<F1S*"1W96%T:&5R6R)C;&]U9',B75LD:5U;(F%M
M;W5N=")=*3L*("`@("`@("!I9B`H:7-S970H)'=E871H97);(F-L;W5D<R)=
M6R1I75LB='EP92)=*2D@>PH@("`@("`@("`@("`D8VQO=60@+CT@(B`B+B1W
M96%T:&5R6R)C;&]U9',B75LD:5U;(G1Y<&4B73L*("`@("`@("!]"B`@("`@
M("`@:68@*&ES<V5T*"1W96%T:&5R6R)C;&]U9',B75LD:5U;(FAE:6=H=")=
M*2D@>PH@("`@("`@("`@("`D8VQO=60@+CT@(B!A="`B+B1W96%T:&5R6R)C
M;&]U9',B75LD:5U;(FAE:6=H=")=+B1U;FET<ULB:&5I9VAT(ET["B`@("`@
M("`@?0H_/@H@("`@("`@("`@("`@("`@/#\])&-L;W5D/SX\8G(^"CP_<&AP
M"B`@("!]"GT@96QS92!["C\^"B`@("`@("`@("`@("`@("!#;&5A<B!"96QO
M=R`\/STD;65T87(M/F-O;G9E<G1$:7-T86YC92@Q,C`P,"P@(F9T(BP@)'5N
M:71S6R)H96EG:'0B72DN)'5N:71S6R)H96EG:'0B73\^(`H\/W!H<`I]"C\^
M"B`@("`@("`@("`@(#PO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\+W1A
M8FQE/@H@("`@/"]T9#X*/"]T<CX*/'1R/@H@("`@/'1D/@H@("`@("`@(#QT
M86)L92!S='EL93TB8F]R9&5R+71O<#H@,G!X('-O;&ED(",U,C1B.3@[(&)O
M<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C93!E,V-E.R!B;W)D97(M;&5F=#H@
M,G!X('-O;&ED("-B.&(V8S$[(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X
M8C@W83`[('=I9'1H.B`Q,#`E(CX*("`@("`@("`\='(@8VQA<W,](F)G:VAA
M:VDB/@H@("`@("`@("`@("`\=&0@8V]L<W!A;CTB,R(@86QI9VX](F-E;G1E
M<B(@<W1Y;&4](F)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C86)A9&$R(CX\
M<W!A;B!C;&%S<STB8F]L9"(^1F]R96-A<W0@*%1!1BD\+W-P86X^/&)R/G9A
M;&ED(&9R;VT@/'-P86X@8VQA<W,](F)O;&0B/CP_/21F;W)E8V%S=%LB=F%L
M:61&<F]M(ET_/CPO<W!A;CX@=&\@/'-P86X@8VQA<W,](F)O;&0B/CP_/21F
M;W)E8V%S=%LB=F%L:614;R)=/SX\+W-P86X^/"]T9#X*("`@("`@("`\+W1R
M/@H@("`@("`@(#QT<B!V86QI9VX](G1O<"(^"B`@("`@("`@("`@(#QT9"!C
M;VQS<&%N/2(S(CX*("`@("`@("`@("`@("`@(#QT86)L92!S='EL93TB=VED
M=&@Z(#$P,"4B/@H@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@
M("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!C;&%S<STB8F=K:&%K:2(@<W1Y
M;&4](FAE:6=H=#H@,35P>#L@8F]R9&5R+71O<#H@,G!X('-O;&ED("-D.&0X
M8S`[(&)O<F1E<BUR:6=H=#H@,G!X('-O;&ED(",X8C@W83`[(&)O<F1E<BUL
M969T.B`R<'@@<V]L:60@(V0X9#AC,"(^)FYB<W`[/"]T9#X*("`@("`@("`@
M("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H.B`Q
M."4B/CQS<&%N(&-L87-S/2)B;VQD(CY-971E;W)O;&]G:6-A;"!#;VYD:71I
M;VYS/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N
M/2)C96YT97(B('-T>6QE/2)W:61T:#H@,3@E(B!C;&%S<STB8F=G<F5Y(CX\
M<W!A;B!C;&%S<STB8F]L9"(^5VEN9#PO<W!A;CX\+W1D/@H@("`@("`@("`@
M("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB=VED=&@Z(#$X
M)2(^/'-P86X@8VQA<W,](F)O;&0B/E9I<VEB:6QI='D\+W-P86X^/"]T9#X*
M("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4]
M(G=I9'1H.B`Q."4B(&-L87-S/2)B9V=R97DB/CQS<&%N(&-L87-S/2)B;VQD
M(CY#;&]U9',\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\=&0@
M86QI9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H.B`Q."4B/CQS<&%N(&-L87-S
M/2)B;VQD(CY#;VYD:71I;VX\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@
M(#PO='(^"CP_<&AP"B1T:6UE<R`](&%R<F%Y7VME>7,H)&9O<F5C87-T6R)T
M:6UE(ETI.PHD<')E("`@/2!A<G)A>2@B=VEN9"(@/3X@,"P@(G9I<R(@/3X@
M,"P@(F-L;W5D<R(@/3X@,"P@(F-O;F0B(#T^(#`I.PHO+R!/:RP@=&AE(&9O
M<F5C87-T(&ES(&$@8FET(&UO<F4@:6YT97)E<W1I;F<L(&%S($DG;2!T86MI
M;F<@82!F97<*+R\@<')E8V%U=&EO;G,@:&5R92!S;R!T:&%T('1H92!T86)L
M92!I<VXG="!F:6QL960@=7`@=&\@=&AE(&UA>"X*+R\@;R!)9B!A('9A;'5E
M(&ES(')E<&5A=&5D(&EN('1H92!N97AT(&UA:F]R('1I;65S;&]T("AN;W0@
M=VAE;@HO+R`@('-I9VYI9FEC86YT('=E871H97(@8VAA;F=E<R!A<F4@<')O
M8V5S<V5D*2P@:70G<R!N;W0@<')I;G1E9`HO+R!O(%-I9VYI9FEC86YT('=E
M871H97(@9V5T<R!I=',@;W=N(')O=W,L('=I=&@@=&EM97,@<')I;G1E9"!N
M;W)M86P*+R\@("!A<R!I;B!O<'!O<VET:6]N('1O(&)O;&0@<')I;G0@9F]R
M(&UA:F]R('1I;65S;&]T<PHO+R!O(%1H92!W:&EL92@D<F]W*2UC;VYS=')U
M8W0@8F5L;W<@:7,@9F]R(&AA;F1L:6YG('1H92!S:6=N:69I8V%N=`HO+R`@
M('=E871H97(L(&%S($D@<&]I;G0@)')O=R!T;R`D<F]W6R)F;6,B72!A9G1E
M<G=A<F1S+"!W:&5R92!T:&4*+R\@("!S;6%L;&5R(&-H86YG97,@87)E(&UE
M;G1I;VYE9`IF;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)&9O<F5C87-T6R)T
M:6UE(ETI.R`D:2LK*2!["B`@("`D<F]W(#T@)&9O<F5C87-T6R)T:6UE(EU;
M)'1I;65S6R1I75T["@H@("`@+R\@0W)E871E('1I;65S=&%M<`H@("`@)'-T
M87)T(#T@)'1I;65S6R1I73L*("`@(&EF("@D:2`K(#$@/"!S:7IE;V8H)&9O
M<F5C87-T6R)T:6UE(ETI*2!["B`@("`@("`@)&5N9"`]("1T:6UE<ULD:2`K
M(#%=.PH@("`@?2!E;'-E('L*("`@("`@("`D96YD(#T@<W5B<W1R*"1F;W)E
M8V%S=%LB=F%L:61287<B72P@+3(I+B(Z,#`B.PH@("`@("`@("1E;F0@/2`H
M)&5N9"`]/2`B,C0Z,#`B*2`_("(P,#HP,"(@.B`D96YD.PH@("`@?0H@("`@
M)'1I;64@("`@/2`D<W1A<G0N(B`M("(N)&5N9#L*("`@("1C;&%S<R`@(#T@
M)R!C;&%S<STB8F]L9"(G.PH@("`@+R\@5&AI<R!I<R!F;W(@;W5T<'5T=&EN
M9R`B0F5C;VUI;F<B+"`B5&5M<&]R87)Y(B!A;F0@<W5C:`H@("`@)&9M8R`@
M("`@/2!I<W-E="@D<F]W6R)F;6,B72D@/R`D<F]W6R)F;6,B72`Z(&9A;'-E
M.R`*("`@("1F;6-T>7!E(#T@(B(["B`@("`D9FUC8VYT("`](#`["@H@("`@
M=VAI;&4@*"1R;W<I('L*/SX*("`@("`@("`@("`@("`@(#QT<B!C;&%S<STB
M8F=K:&%K:2(^"B`@("`@("`@("`@("`@("`@("`@/'1D('-T>6QE/2)H96EG
M:'0Z(#%P>#L@96UP='DM8V5L;',Z('-H;W<[(&)O<F1E<BUR:6=H=#H@,G!X
M('-O;&ED(",X8C@W83`[(&)O<F1E<BUL969T.B`R<'@@<V]L:60@(V0X9#AC
M,"(^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\=&0@<W1Y;&4](FAE:6=H
M=#H@,7!X(B!C;VQS<&%N/2(U(CX\+W1D/@H@("`@("`@("`@("`@("`@/"]T
M<CX*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(@8VQA<W,](F)G:VAA:VDB('-T>6QE/2)B;W)D
M97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P.R!B;W)D97(M;&5F=#H@,G!X
M('-O;&ED("-D.&0X8S`B(&YO=W)A<#X\<W!A;CP_/21C;&%S<S\^/CP_/21T
M:6UE/SX\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@("`@("`\=&0@86QI
M9VX](F-E;G1E<B(^/#\])&9M8W1Y<&4_/CPO=&0^"CP_<&AP"B`@("`@("`@
M+R\@5&AI<R!L;V]P<R!T:')O=6=H('1H92!A=F%I;&%B;&4@9&%T82!A;F0@
M<')O8V5S<V5S(&ET"B`@("`@("`@+R\@9F]R(&]U='!U="P@=&AE(&1I9F9E
M<F5N="!M971H;V1S('=E<F4@86QR96%D>2!U<V5D(&%B;W9E"B`@("`@("`@
M+R\@*$]N;'D@9&EF9F5R96YC92!I<R!T:&4@8VAE8VMI;F<@9F]R('1H92!P
M<F4M=F%L=65S+BD*("`@("`@("!F;W)E86-H*&%R<F%Y*")W:6YD(BP@(G9I
M<R(L(")C;&]U9',B+"`B8V]N9"(I(&%S("1V86PI('L*("`@("`@("`@("`@
M<W=I=&-H("@D=F%L*2!["B`@("`@("`@("`@("`@("!C87-E(")W:6YD(CH*
M("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1R;W=;(G=I;F1$:7)E
M8W1I;VXB72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M("(F;F)S<#LB.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2!S=')T;VQO=V5R*"1R;W=;
M(G=I;F1$:7)E8W1I;VXB72D@/3T@(F-A;&TB(#\@(D-A;&TB(#H@(D9R;VT@
M=&AE("(N)')O=ULB=VEN9$1I<F5C=&EO;B)=+B(@*"(N)')O=ULB=VEN9$1E
M9W)E97,B72XB)F1E9SLI/&)R/F%T("(N<F]U;F0H)')O=ULB=VEN9")=+"`Q
M*2XD=6YI='-;(G=I;F0B73L*("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*&ES<V5T*"1R;W=;(G=I;F10<F]B(ETI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R:6YG("X]("(@*"(N)')O=ULB=VEN9%!R;V(B72XB
M)29N8G-P.U!R;V(N*2(["B`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*"1S=')I;F<@/3T]("1P<F5;(G=I
M;F0B72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M("(F;F)S<#LB.PH@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R95LB=VEN9")=(#T@)'-T
M<FEN9SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`G(&-L87-S
M/2)B9V=R97DB)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@(&-A<V4@(G9I<R(Z"B`@("`@("`@("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F]W6R)V:7-I8FEL:71Y(ETI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("1S=')I;F<@/2`B)FYB<W`[(CL*("`@("`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`D<W1R:6YG
M(#T@<W1R=&]L;W=E<B@D<F]W6R)V:7-1=6%L:69I97(B72DN(B`B+G)O=6YD
M*"1R;W=;(G9I<VEB:6QI='DB72P@,2DN)'5N:71S6R)V:7,B73L*("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R;W=;(G9I<U!R;V(B72DI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@+CT@(B`H
M(BXD<F]W6R)V:7-0<F]B(ETN(B4F;F)S<#M0<F]B+BDB.PH@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D
M<W1R:6YG(#T]/2`D<')E6R)V:7,B72D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'-T<FEN9R`]("(F;F)S<#LB.PH@("`@("`@("`@("`@("`@
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!R95LB=FES(ET@/2`D<W1R:6YG.PH@("`@("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@
M("1C;&%S<R`]("<G.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@8V%S92`B8VQO=61S(CH*("`@("`@("`@("`@("`@("`@
M("!I9B`H(6ES<V5T*"1R;W=;(F-L;W5D<R)=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`D<W1R:6YG(#T@(B9N8G-P.R(["B`@("`@("`@("`@("`@
M("`@("`@?2!E;'-E('L@"B`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U
M9',@(#T@(B(["B`@("`@("`@("`@("`@("`@("`@("`@(&9O<B`H)&H@/2`P
M.R`D:B`\('-I>F5O9B@D<F]W6R)C;&]U9',B72D[("1J*RLI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`]('5C=V]R9',H)')O=ULB
M8VQO=61S(EU;)&I=6R)A;6]U;G0B72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H:7-S970H)')O=ULB8VQO=61S(EU;)&I=6R)T>7!E(ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-L;W5D("X]
M("(@(BXD<F]W6R)C;&]U9',B75LD:EU;(G1Y<&4B73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AI<W-E="@D<F]W6R)C;&]U9',B75LD:EU;(FAE:6=H=")=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`N/2`B(&%T
M("(N)')O=ULB8VQO=61S(EU;)&I=6R)H96EG:'0B72XD=6YI='-;(FAE:6=H
M=")=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R;W=;(F-L;W5D<R)=6R1J
M75LB<')O8B)=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;&]U9"`N/2`B("@B+B1R;W=;(F-L;W5D<R)=6R1J75LB<')O8B)=+B(E
M)FYB<W`[4')O8BXI(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9',@+CT@)&-L;W5D
M+B(\8G(^(CL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H)&-L;W5D<R`]/3T@)'!R95LB8VQO=61S(ETI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2`B)FYB
M<W`[(CL*("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1S=')I;F<@("`@("`@(#T@)&-L;W5D
M<SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5;(F-L;W5D<R)=
M(#T@)&-L;W5D<SL*("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`D8VQA<W,@/2`G
M(&-L87-S/2)B9V=R97DB)SL*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*
M("`@("`@("`@("`@("`@(&-A<V4@(F-O;F0B.@H@("`@("`@("`@("`@("`@
M("`@(&EF("@A:7-S970H)')O=ULB8V]N9&ET:6]N(ETI('Q\("AI<W-E="@D
M<')E<F]W*2`F)B`D<')E<F]W6R)C;VYD:71I;VXB72`]/2`D<F]W6R)C;VYD
M:71I;VXB72DI('L*("`@("`@("`@("`@("`@("`@("`@("`@)'-T<FEN9R`]
M("(F;F)S<#LB.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1S=')I;F<@/2!U8W=O<F1S*"1R;W=;(F-O
M;F1I=&EO;B)=*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@)&-L87-S(#T@)R<["B`@("`@("`@("`@('T*/SX*("`@("`@
M("`@("`@("`@("`@("`\=&0@=F%L:6=N/2)T;W`B/#\])&-L87-S/SX^/#\]
M)'-T<FEN9S\^/"]T9#X*/#]P:'`*("`@("`@("!]"C\^("`@("`@("`@("`@
M("`@("`@("`*("`@("`@("`@("`@("`@(#PO='(^"CP_<&AP"B`@("`@("`@
M+R\@3F]W(&-H96-K(&9O<B!S:6=N:69I8V%N="!W96%T:&5R(&-H86YG97,@
M86YD(&UO=F4*("`@("`@("`O+R!T:&4@<F]W(&%C8V]R9&EN9VQY+BXN(&UA
M>6)E('5G;'D@8V]D:6YG+"!B=70@=&AI<PH@("`@("`@("\O(&ES(&9O<B!S
M:&]W:6YG(&1E<VEG;BP@;F]T(&9O<B!F86YY('!R;V=R86UM:6YG(#LM*0H@
M("`@("`@(&EF("@D9FUC("8F("1F;6-C;G0@/"!S:7IE;V8H)&9M8RDI('L*
M("`@("`@("`@("`@)')O=R`@("`@/2`D9FUC6R1F;6-C;G1=.PH@("`@("`@
M("`@("`D9FUC8VYT*RL["B`@("`@("`@("`@("1F;6-T>7!E(#T@)')O=ULB
M='EP92)=.PH@("`@("`@("`@("`O+R!#:&5C:R!I9B!W92!H879E(&$@=&EM
M97-T86UP+"!D;VXG="!O=71P=70@:68@:70G<PH@("`@("`@("`@("`O+R!T
M:&4@<V%M92!A<R!T:&4@;6%J;W(M=&EM97-L;W0*("`@("`@("`@("`@:68@
M*"%I<W-E="@D<F]W6R)F<F]M(ETI('Q\("1R;W=;(F9R;VTB72XB("T@(BXD
M<F]W6R)T;R)=(#T]("1T:6UE*2!["B`@("`@("`@("`@("`@("`D=&EM92`]
M("(F;F)S<#LB.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@)'1I;64@("`@/2`D<F]W6R)F<F]M(ETN(B`M("(N)')O=ULB=&\B73L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!S=VET8V@@*"1R;W=;(G1Y<&4B
M72D@>PH@("`@("`@("`@("`@("`@8V%S92`B4%)/0B(Z"B`@("`@("`@("`@
M("`@("`@("`@)&9M8W1Y<&4@/2`B(CL*("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@(&-A<V4@(E1%35!/(CH*("`@("`@("`@
M("`@("`@("`@("`D9FUC='EP92`](")496UP;W)A<GDB.PH@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B0D5#34<B
M.@H@("`@("`@("`@("`@("`@("`@("1F;6-T>7!E(#T@(D)E8V]M:6YG(CL*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!I9B`H:7-S970H)')O=ULB<')O8F%B:6QI='DB72DI('L*("`@
M("`@("`@("`@("`@("1F;6-T>7!E("X]("(@*"(N)')O=ULB<')O8F%B:6QI
M='DB72XB)29N8G-P.U!R;V(N*2(["B`@("`@("`@("`@('T*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("`D<F]W(#T@9F%L<V4["B`@("`@("`@?0H@
M("`@?0I]"C\^("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`@("`@/'1R
M/@H@("`@("`@("`@("`@("`@("`@(#QT9"!C;&%S<STB8F=K:&%K:2(@<W1Y
M;&4](FAE:6=H=#H@,7!X.R!E;7!T>2UC96QL<SH@<VAO=SL@8F]R9&5R+6)O
M='1O;3H@,G!X('-O;&ED("-D.&0X8S`[(&)O<F1E<BUL969T.B`R<'@@<V]L
M:60@(V0X9#AC,#L@8F]R9&5R+7)I9VAT.B`R<'@@<V]L:60@(SAB.#=A,"(^
M/"]T9#X*("`@("`@("`@("`@("`@("`@("`\=&0@<W1Y;&4](FAE:6=H=#H@
M,7!X(B!C;VQS<&%N/2(U(CX\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX*
M("`@("`@("`@("`@("`@(#PO=&%B;&4^"B`@("`@("`@("`@(#PO=&0^"B`@
M("`@("`@/"]T<CX*("`@("`@("`\='(@8VQA<W,](F)G:VAA:VDB/@H@("`@
M"2`@("`\=&0@<W1Y;&4](G=I9'1H.B`Y,W!X.R!B;W)D97(M=&]P.B`R<'@@
M<V]L:60@(V%B861A,B(^)FYB<W`[/"]T9#X*("`@("`@("`@("`@/'1D('-T
M>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(V%B861A,B(^57!D871E9#H@
M*#P_/7-U8G-T<B@D=V5A=&AE<ELB=7!D871E(ETL("TU*3\^)FYB<W`[+R9N
M8G-P.SP_/7-U8G-T<B@D9F]R96-A<W1;(G5P9&%T92)=+"`M-2D_/BD\+W1D
M/@H@("`@("`@("`@("`\=&0@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI
M9"`C86)A9&$R(B!A;&EG;CTB<FEG:'0B/D%L;"!T:6UE<R!55$,\+W1D/@H@
M("`@("`@(#PO='(^"B`@("`@("`@/"]T86)L93X*("`@(#PO=&0^"CPO='(^
M"CPO=&%B;&4^"CQA(&AR968](FIA=F%S8W)I<'0Z:&ES=&]R>2YB86-K*"DB
M/F)A8VL\+V$^"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O=V5A
M=&AE<BYC;VTM8F%S:6,N<&AP`````````````````````````#`P,#8T-"``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V-30V(#$P-3$U-#,T,3,R(#`S,#4P
M-P`@,```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````\
M/W!H<`HO*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED
M=&@]-"!S;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ
M"B`J($)A<VEC(&5X86UP;&4@9F]R('1H92!796%T:&5R+F-O;2US97)V:6-E
M"B`J"B`J(%!(4"!V97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@
M*B!#;W!Y<FEG:'0@*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@
M<FEG:'1S(')E<V5R=F5D+@H@*B`*("H@4F5D:7-T<FEB=71I;VX@86YD('5S
M92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T
M"B`J(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T
M('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E
M9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@
M86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E
M9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T
M:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@
M8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H
M92!D;V-U;65N=&%T:6]N"B`J("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P
M<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T
M:&4@;F%M92!O9B!T:&4@<V]F='=A<F4@;F]R('1H92!N86UE<R!O9B!I=',@
M8V]N=')I8G5T;W)S"B`J("`@;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P
M<F]M;W1E('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E"B`J
M("`@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN
M"B`J(`H@*B!42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!9
M4DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$
M($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'
M+"!"550@3D]4($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)
M15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)
M0U5,05(@4%524$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@
M4TA!3$P@5$A%($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*
M("H@3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!
M3"P@4U!%0TE!3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y424%,($1!
M34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%
M345.5"!/1@H@*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3
M($]&(%5312P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y4
M15)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/
M1B!,24%"24Q)5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,
M24%"24Q)5%DL($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]4
M2$525TE312D*("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%
M($]&(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@
M4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H@
M"B`J($!C871E9V]R>2`@("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@
M(%-E<G9I8V5S7U=E871H97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7
M:7)T>B`\86QE>$!P8S1P+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE
M>&%N9&5R(%=I<G1Z"B`J($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS
M;W5R8V4N;W)G+VQI8V5N<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N
M<V4*("H@0'9E<G-I;VX@("`@($-64SH@)$ED.B!W96%T:&5R+F-O;2UB87-I
M8RYP:'`L=B`Q+C<@,C`P-2\Q,2\P."`Q-SHU,CHT,B!E<G4@17AP("0*("H@
M0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V
M:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E
M(")397)V:6-E<R]796%T:&5R+G!H<"(["@HO+R!/8FIE8W0@:6YI=&EA;&EZ
M871I;VX@+2!E<G)O<B!C:&5C:VEN9R!I<R!I;7!O<G1A;G0L(&)E8V%U<V4@
M;V8*+R\@:&%N9&QI;F<@97AC97!T:6]N<R!S=6-H(&%S(&UI<W-I;F<@4$5!
M4B!M;V1U;&5S"B1W96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E871H97(Z
M.G-E<G9I8V4H(E=E871H97)$;W1#;VTB+"!A<G)A>2@B9&5B=6<B(#T^(#(L
M(")H='1P5&EM96]U="(@/3X@,S`I*3L*:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'=E871H97)$;W1#;VTI*2!["B`@("!D:64H(D5R<F]R.B`B
M+B1W96%T:&5R1&]T0V]M+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\O(%-E
M="!W96%T:&5R+F-O;2!P87)T;F5R(&1A=&$*)'=E871H97)$;W1#;VTM/G-E
M=$%C8V]U;G1$871A*"(\4&%R=&YE<DE$/B(L("(\3&EC96YS94ME>3XB*3L*
M"B\J($5R87-E(&-O;6UE;G1S('1O(&5N86)L92!C86-H:6YG"B1S=&%T=7,@
M/2`D=V5A=&AE<D1O=$-O;2T^<V5T0V%C:&4H(F9I;&4B+"!A<G)A>2@B8V%C
M:&5?9&ER(B`]/B`B+W1M<"]C86-H92\B*2D["FEF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("!E8VAO(")%<G)O<CH@(BXD
M<W1A='5S+3YG971-97-S86=E*"DN(EQN(CL*?0HJ+PH*)'=E871H97)$;W1#
M;VTM/G-E=%5N:71S1F]R;6%T*")M971R:6,B*3L*)'=E871H97)$;W1#;VTM
M/G-E=$1A=&54:6UE1F]R;6%T*")D+FTN62(L(")(.FDB*3L*"B\O($9I<G-T
M(&=E="!C;V1E(&9O<B!L;V-A=&EO;@HD<V5A<F-H(#T@)'=E871H97)$;W1#
M;VTM/G-E87)C:$QO8V%T:6]N*")";VYN+"!'97)M86YY(BD["FEF("A397)V
M:6-E<U]796%T:&5R.CII<T5R<F]R*"1S96%R8V@I*2!["B`@("!D:64H(D5R
M<F]R.B`B+B1S96%R8V@M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+R\@3F]W
M(&ET97)A=&4@=&AR;W5G:"!A=F%I;&%B;&4@9G5N8W1I;VYS(&9O<B!R971R
M:65V:6YG(&1A=&$*9F]R96%C:"`H87)R87DH(F=E=$QO8V%T:6]N(BP@(F=E
M=%=E871H97(B+"`B9V5T1F]R96-A<W0B*2!A<R`D9G5N8W1I;VXI('L*("`@
M("1D871A(#T@)'=E871H97)$;W1#;VTM/B1F=6YC=&EO;B@D<V5A<F-H*3L*
M("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1D871A*2D@>PH@
M("`@("`@(&5C:&\@(D5R<F]R.B`B+B1D871A+3YG971-97-S86=E*"DN(EQN
M(CL*("`@("`@("!C;VYT:6YU93L*("`@('T*"B`@("!V87)?9'5M<"@D9&%T
M82D["GT*/SX*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+W=E
M871H97(N8V]M+65X=&5N<VEV92YP:'`````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T-3,P,B`Q,#4Q-30S-#$S,B`P,S$T
M,S$`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I
M9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J
M*@H@*B!%;&%B;W)A=&4@97AA;7!L92!F;W(@=&AE($=L;V)A;%=E871H97(M
M<V5R=FEC90H@*@H@*B!796QL+"!T:&ES(&ES(&$@;6]R92!E;&%B;W)A=&4@
M97AA;7!L92!H;W<@=&\@8W)E871E(&$@;F5A="!L:71T;&4@<&%G90H@*B!W
M:71H(&9E=&-H:6YG(&1A=&$@9G)O;2!W96%T:&5R+F-O;2!A;F0@<'5T=&EN
M9R!I="!I;G1O(&$@9&5S:6=N+@H@*B!))VT@;F]T('1O;R!P<F]U9"!O9B!M
M>2!D97-I9VXM<VMI;&QS+"!M;W-T(&]F('1H92!S='5F9B!H97)E(&ES('1A
M:V5N"B`J(&9R;VT@=&AE('=E871H97(M8FQO8VL@=VAI8V@@8V%N(&)E(&9O
M=6YD('=I=&AI;B!T:&4@2&]R9&4@1G)A;65W;W)K+`H@*B!C;W5R=&5S>2!O
M9B!2:6-K($5M97)Y("T@8W)E871I=F4@<&EX96QS:&]V:6YG(&ES;B=T(&UY
M(&1O;6%I;B`Z+5`*("H@22=V92!U<V5D(&$@1FER969O>"!F;W(@8VAE8VMI
M;F<@=&AE(&1E<VEG;BP@<V\@9&]N)W0@8F4@=&]O"B`J(&1I<V%P<&]I;G1E
M9"P@:68@=&AE('!A9V4@;&]O:W,@<VAA8F)Y('=I=&@@=&AE($E%+"!N;W0@
M=&AA="!)(&-A<F4*("H@=F5R>2!M=6-H(&%N>7=A>2`[+2D*("H@268@>6]U
M('=A;G0@=&\@:VYO=R!W:&5R92!Y;W4@8V%N(&]B=&%I;B!T:&4@:6-O;G,L
M('!L96%S92!R96=I<W1E<B!A=`H@*B!H='1P.B\O=W=W+G=E871H97(N8V]M
M+W-E<G9I8V5S+WAM;&]A<"YH=&UL(&%N9"!Y;W4G;&P@<F5C96EV92!A;B!E
M36%I;`H@*B!C;VYT86EN:6YG('1H92!P87)T;F5R(&ED+"!T:&4@;&EC96YS
M92!K97D@86YD(&$@;&EN:R!P;VEN=&EN9R!T;R!T:&4*("H@4T1++B!0=70@
M=&AE(#,R>#,R(&%N9"!T:&4@;&]G;W,@9F]L9&5R<R!I;G1O('1H92!I;6%G
M97,O(&1I<F5C=&]R>2X*("H@5&AE(&1E<VEG;B!S:&]U;&0@861H97)E('1O
M('1H92!C;VYV96YT:6]N<R!D969I;F5D(&)Y('1H92!W96%T:&5R+F-O;0H@
M*B!31$LM9W5I9&4L('1H;W5G:"!)('=O;B=T(&=I=F4@86YY(&QE9V%L(&-E
M<G1A:6YT>2!F;W(@=&AI<R`H;V8@8V]U<G-E*2X*("H@2&%V92!F=6XA"B`J
M(`H@*B!02%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@
M0V]P>7)I9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I
M9VAT<R!R97-E<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@
M:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@
M*B!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T
M:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I
M<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B
M;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I
M<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE
M(&%B;W9E(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O
M;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@
M9&]C=6UE;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O
M=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE
M(&YA;64@;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O
M;G1R:6)U=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O
M;6]T92!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@
M('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@
M*B`*("H@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))
M1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!
M3ED@15A04D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@
M0E54($Y/5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453
M($]&($U%4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-5
M3$%2(%!54E!/4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(
M04Q,(%1(12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J
M($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL
M(%-014-)04PL($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!
M1T53("A)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%
M3E0@3T8*("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/
M1B!54T4L($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$52
M4E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@
M3$E!0DE,2519+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!
M0DE,2519+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%
M4E=)4T4I"B`J($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/
M1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/
M4U-)0DE,2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J(`H@
M*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!3
M97)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER
M='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA
M;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U
M<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E
M"B`J($!V97)S:6]N("`@("!#5E,Z("1)9#H@=V5A=&AE<BYC;VTM97AT96YS
M:79E+G!H<"QV(#$N,30@,C`P-2\Q,2\P."`Q-SHU,CHT,B!E<G4@17AP("0*
M("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]3
M97)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*+R\M+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM"B\O(%1H:7,@:7,@=&AE(&%R96$L('=H
M97)E('EO=2!C86X@8W5S=&]M:7IE('1H92!S8W)I<'0*+R\M+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"B1L;V-A=&EO;B`@("`@/2`B0F]N;BP@1V5R
M;6%N>2([("\O(%1H92!C:71Y('=E('=A;G0@=&\@9F5T8V@@=&AE(&1A=&$@
M9F]R+@HD9F]R96-A<W1$87ES(#T@-#L@("`@("`@("`@("`@("`O+R!4:&ES
M(')E9W5L871E<R!T:&4@86UO=6YT(&]F(&1I<W!L87EE9`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!D871E<R!I;B!T:&4@9F]R96-A
M<W0N("@Q(#P]('@@/#T@,3`I"B1P87)T;F5R240@("`@/2`B/%!A<G1N97))
M1#XB.R`@("\O($%S('!R;W9I9&5D(&)Y('=E871H97(N8V]M(&EN('1H90HD
M;&EC96YS94ME>2`@(#T@(CQ,:6-E;G-E2V5Y/B([("`O+R!R96=I<W1R871I
M;VX@94UA:6PN"B1C86-H951Y<&4@("`@/2`B(CL@("`@("`@("`@("`@("\O
M(%-E="!A('1Y<&4@*&9I;&4L(&1B+"!M9&(L("XN+BD@=&\*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@96YA8FQE(&-A8VAI;F<N"B1C
M86-H94]P="`@("`@/2!A<G)A>2@I.R`@("`@("`@("\O($-A8VAE(&YE961S
M('9A<FEO=7,@;W!T:6]N<RP@9&5P96YD:6YG"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(&]N('1H92!C;VYT86EN97(M='EP92`M('!L
M96%S92!C;VYS=6QT"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O('1H92!#86-H92!M86YU86P@+R!S;W5R8V5C;V1E(0HD=6YI='-&;W)M
M870@(#T@(FUE=')I8R([("`@("`@("`O+R!4:&4@9F]R;6%T('1H92!U;FET
M<R!A<F4@9&ES<&QA>65D(&EN("T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@;65T<FEC+"!S=&%N9&%R9"!O<B!S;VUE(&-U<W1O;6EZ
M871I;VXN"B1D871E1F]R;6%T("`@/2`B62UM+60B.R`@("`@("`@("\O(%-E
M="!T:&4@9F]R;6%T('1H92!D871E(&ES(&1I<W!L87EE9"!I;@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!#:&%N9VEN9R!I="!W:6QL
M(&)R96%K(&$@9F5W('1H:6YG<R!I;@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!T:&ES('-C<FEP="P@8G5T('5S=6%L;'D@>6]U(&-A
M;B!D969I;F4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M=&AI<R!T;R!Y;W5R(&QI:VEN9W,N"B1T:6UE1F]R;6%T("`@/2`B2#II(CL@
M("`@("`@("`@("\O(%-E="!T:&4@9F]R;6%T('1H92!T:6UE(&ES(&1I<W!L
M87EE9"!I;@HO+RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"B\O($QO
M860@=&AE(%=E871H97(@8VQA<W,*<F5Q=6ER95]O;F-E(")397)V:6-E<R]7
M96%T:&5R+G!H<"(["@HO+R!/8FIE8W0@:6YI=&EA;&EZ871I;VX@+2!E<G)O
M<B!C:&5C:VEN9R!I<R!I;7!O<G1A;G0L(&)E8V%U<V4@;V8*+R\@:&%N9&QI
M;F<@97AC97!T:6]N<R!S=6-H(&%S(&UI<W-I;F<@4$5!4B!M;V1U;&5S"B1W
M96%T:&5R1&]T0V]M(#T@)E-E<G9I8V5S7U=E871H97(Z.G-E<G9I8V4H(E=E
M871H97)$;W1#;VTB+"!A<G)A>2@B:'1T<%1I;65O=70B(#T^(#,P*2D["FEF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1W96%T:&5R1&]T0V]M*2D@
M>PH@("`@9&EE*")%<G)O<CH@(BXD=V5A=&AE<D1O=$-O;2T^9V5T365S<V%G
M92@I+B)<;B(I.PI]"@HO+R!3970@=V5A=&AE<BYC;VT@<&%R=&YE<B!D871A
M"B1W96%T:&5R1&]T0V]M+3YS971!8V-O=6YT1&%T82@D<&%R=&YE<DE$+"`D
M;&EC96YS94ME>2D["@HO+R!);FET:6%L:7IE(&-A8VAI;F<*:68@*'-T<FQE
M;B@D8V%C:&54>7!E*2D@>PH@("`@)'-T871U<R`]("1W96%T:&5R1&]T0V]M
M+3YS971#86-H92@D8V%C:&54>7!E+"`D8V%C:&5/<'0I.PH@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("!E
M8VAO(")%<G)O<CH@(BXD<W1A='5S+3YG971-97-S86=E*"DN(EQN(CL*("`@
M('T*?0H*+R\@1&5F:6YE('1H92!U;FET<R!F;W)M870L(&)R:6YG('1H92!R
M971R:65V960@9F]R;6%T(&EN=&\*+R\@<V]M971H:6YG(&UO<F4@8V]M;6]N
M+BXN"B1W96%T:&5R1&]T0V]M+3YS9715;FET<T9O<FUA="@D=6YI='-&;W)M
M870I.PHD=6YI=',@/2`D=V5A=&AE<D1O=$-O;2T^9V5T56YI='-&;W)M870H
M*3L*)'5N:71S6R)T96UP(ET@("`]("(F9&5G.R(N<W1R=&]U<'!E<B@D=6YI
M='-;(G1E;7`B72D["B1U;FET<ULB=VEN9")=("`@/2`B)FYB<W`[(BYS=')?
M<F5P;&%C92@B:VUH(BP@(FMM+V@B+"`D=6YI='-;(G=I;F0B72D["B1U;FET
M<ULB=FES(ET@("`@/2`B)FYB<W`[(BXD=6YI='-;(G9I<R)=.PHD=6YI='-;
M(FAE:6=H=")=(#T@(B9N8G-P.R(N)'5N:71S6R)H96EG:'0B73L*)'5N:71S
M6R)P<F5S(ET@("`]("(F;F)S<#LB+B1U;FET<ULB<')E<R)=.PHD=6YI='-;
M(G)A:6XB72`@(#T@(B9N8G-P.R(N)'5N:71S6R)R86EN(ET["@HO+R!3970@
M9&%T92TO=&EM92UF;W)M870*)'=E871H97)$;W1#;VTM/G-E=$1A=&54:6UE
M1F]R;6%T*"1D871E1F]R;6%T+"`D=&EM949O<FUA="D["@HO+R!396%R8V@@
M9F]R(&1E9FEN960@;&]C871I;VX@86YD(&9E=&-H('1H92!F:7)S="!I=&5M
M(&9O=6YD+@HO+R!"86EL(&]U="!I9B!S;VUE=&AI;F<@8F%D(&AA<'!E;G,N
M+BX*)'-E87)C:"`]("1W96%T:&5R1&]T0V]M+3YS96%R8VA,;V-A=&EO;B@D
M;&]C871I;VXL('1R=64I.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<V5A<F-H*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD<V5A<F-H+3YG971-
M97-S86=E*"DN(EQN(BD["GT*"B\O(%)E=')I979E(&1A=&$L('-T;W)E(&EN
M('9A<FEA8FQE<RP@8F%I;"!O=70@;VX@97)R;W(*)&9E=&-H(#T@87)R87DH
M"B`@("`B;&EN:W,B("`@(#T^(")G971,:6YK<R(L"B`@("`B;&]C871I;VXB
M(#T^(")G971,;V-A=&EO;B(L"B`@("`B=V5A=&AE<B(@(#T^(")G971796%T
M:&5R(BP*("`@(")F;W)E8V%S="(@/3X@(F=E=$9O<F5C87-T(@HI.PIF;W)E
M86-H("@D9F5T8V@@87,@)'9A<FEA8FQE(#T^("1F=6YC=&EO;BD@>PH@("`@
M)"1V87)I86)L92`]("1W96%T:&5R1&]T0V]M+3XD9G5N8W1I;VXH)'-E87)C
M:"P@)&9O<F5C87-T1&%Y<RD["B`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D)'9A<FEA8FQE*2D@>PH@("`@("`@(&5C:&\@(D5R<F]R.B`B
M+B0D=F%R:6%B;&4M/F=E=$UE<W-A9V4H*2XB7&XB.PH@("`@("`@(&-O;G1I
M;G5E.PH@("`@?0I]"@HO+R!792!N965D('1H:7,@9F]R('-O;64@=&EM92UC
M:&5C:W,@86YD(&1I<W!L87ES(&QA=&5R"B1W=7!D(#T@<W1R=&]T:6UE*"1W
M96%T:&5R6R)U<&1A=&4B72D@("L@9&%T92@B6B(I.PHD9G5P9"`]('-T<G1O
M=&EM92@D9F]R96-A<W1;(G5P9&%T92)=*2`K(&1A=&4H(EHB*3L*)&9U<"`@
M/2!S=')T;W1I;64H)&9O<F5C87-T6R)U<&1A=&4B72D@*R`D;&]C871I;VY;
M(G1I;65Z;VYE(ET@*B`S-C`P.PH*+R\@0VAE8VLL(&EF('=E)W)E(&EN('1H
M92!A9G1E<FYO;VX@86YD(&EF('1H92!F;W)E8V%S="!W87,@=7!D871E9"!Y
M970N+BX*+R\@5&AI<R!T<FEG9V5R<R!I9B!T:&4@9&%Y+69O<F5C87-T(&9O
M<B!T:&4@8W5R<F5N="!D87D@=VEL;"!G970@<VAO=VXN"B1A9G1E<FYO;VX@
M/2`H)&QO8V%T:6]N6R)T:6UE(ET@/B`B,3,Z-3DB('Q\(&1A=&4H(EEM9"(L
M("1F=7`I(#P@9&%T92@B66UD(BDI(#\@=')U92`Z(&9A;'-E.PH*+R\@5&AE
M('5S=6%L(&YO=&%T:6]N(&9O<B!C;VYD:71I;VX@:6-O;G,@:7,@;G5M97)I
M8RX@0VAE8VL@9F]R(&YU;65R:6,@:6-O;B!O<B`B;F$B(&%N9"!S970@=&\@
M(FYA(B!I9B!T:&%T)W,@;F]T('1H92!C87-E"FEF("@A*&-T>7!E7V1I9VET
M*"1W96%T:&5R6R)C;VYD:71I;VY)8V]N(ETI('Q\("1W96%T:&5R6R)C;VYD
M:71I;VY)8V]N(ET@/3T@(FYA(BDI('L*("`@("1W96%T:&5R6R)C;VYD:71I
M;VY)8V]N(ET@/2`B;F$B.PI]"@HO+R!.;W<@=V4@;W5T<'5T(&%L;"!T:&4@
M9&%T82P@<&QE87-E(&1O;B=T(&5X<&5C="!E>'1E;G-I=F4@8V]M;65N=',@
M:&5R92P@=&AI<R!I<R!B87-I8PHO+R!(5$U,+T-34R!S='5F9BX@06QS;R!T
M:&ES(&ES;B=T(&$@=F5R>2!F86YC>2!D97-I9VXL(&ET)W,@:G5S="!T;R!S
M:&]W('EO=2P@=VAA=`HO+R!T:&4@<V-R:7!T(&ES(&%B;&4@=&\@9&\@*&%N
M9"!M;W)E(#LM*2DN+BX*/SX*/&AT;6P^"CQH96%D/@H@("`@/'1I=&QE/E-E
M<G9I8V5S7U=E871H97(Z.E=E871H97)D;W1C;VT\+W1I=&QE/@H@("`@/'-T
M>6QE('1Y<&4](G1E>'0O8W-S(CX*("`@("`@("`N;F]R;6%L("`@("![(&9O
M;G0M9F%M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS+7-E<FEF.R!F;VYT
M+7-I>F4Z(#$Q<'0[(&9O;G0M=V5I9VAT.B!N;W)M86P[(&9O;G0M<W1Y;&4Z
M(&YO<FUA;"!]"B`@("`@("`@+FET86QI8R`@("`@>R!F;VYT+7=E:6=H=#H@
M;F]R;6%L.R!F;VYT+7-T>6QE.B!I=&%L:6,@?0H@("`@("`@("YB;VQD("`@
M("`@('L@9F]N="UW96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&YO<FUA;"!]
M"B`@("`@("`@+F)O;&1I=&%L:6,@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N
M="US='EL93H@:71A;&EC('T*("`@("`@("`N<F5D8F]L9"`@("![(&9O;G0M
M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE.B!N;W)M86P[(&-O;&]R.B`C9F8P
M,#`P('T*("`@("`@("`N8FQU96)O;&0@("![(&9O;G0M=V5I9VAT.B!B;VQD
M.R!F;VYT+7-T>6QE.B!N;W)M86P[(&-O;&]R.B`C,#`P,&9F('T*("`@("`@
M("`N8F=G<F5Y("`@("![(&)A8VMG<F]U;F0M8V]L;W(Z("-E.64Y93D@?0H@
M("`@("`@("YB9VMH86MI("`@('L@8F%C:V=R;W5N9"UC;VQO<CH@(V0X9#AC
M,"!]"B`@("`@("`@+G)E9R`@("`@("`@>R!F;VYT+7-I>F4Z(#=P=#L@=F5R
M=&EC86PM86QI9VXZ('-U<&5R('T*("`@("`@("!I;6<@("`@("`@("![('9E
M<G1I8V%L+6%L:6=N.B!M:61D;&4[(&)O<F1E<BUS='EL93H@;F]N93L@8F]R
M9&5R+7=I9'1H.B`P<'@@?0H@("`@("`@(&$@("`@("`@("`@('L@9F]N="UW
M96EG:'0Z(&)O;&0[(&9O;G0M<W1Y;&4Z(&ET86QI8SL@8V]L;W(Z(",Y.3,S
M,#`[('1E>'0M9&5C;W)A=&EO;CH@;F]N92!]"B`@("`@("`@83IV:7-I=&5D
M("`@>R!F;VYT+7=E:6=H=#H@8F]L9#L@9F]N="US='EL93H@:71A;&EC.R!C
M;VQO<CH@(SDY,S,P,#L@=&5X="UD96-O<F%T:6]N.B!N;VYE('T*("`@("`@
M("!A.FAO=F5R("`@("![(&9O;G0M=V5I9VAT.B!B;VQD.R!F;VYT+7-T>6QE
M.B!I=&%L:6,[(&-O;&]R.B`C8V,S,S`P.R!T97AT+61E8V]R871I;VXZ('5N
M9&5R;&EN92!]"B`@("`@("`@=&%B;&4@("`@("`@>R!B;W)D97(Z(#!P>"!N
M;VYE(&)L86-K.R!B;W)D97(M<W!A8VEN9SH@,'!X('T*("`@("`@("!T9"`@
M("`@("`@("![(&9O;G0M9F%M:6QY.B!!<FEA;"P@2&5L=F5T:6-A+"!S86YS
M+7-E<FEF.R!F;VYT+7-I>F4Z(#$Q<'0[(&9O;G0M=V5I9VAT.B!N;W)M86P[
M(&9O;G0M<W1Y;&4Z(&YO<FUA;"!]"B`@("`\+W-T>6QE/@H\+VAE860^"CQB
M;V1Y(&-L87-S/2)N;W)M86PB/@H\/W!H<`HO+R!$96)U9R!O=71P=71S('1H
M92!R87<@9&%T82!F971C:&5D(&)Y('1H92!F;W)E86-H+6QO;W`@86)O=F4L
M(&IU<W0@9F]R(&-H96-K:6YG+BXN"FEF("AI<W-E="@D7T=%5%LB9&5B=6<B
M72DI('L*("`@(&5C:&\@(CQP<F4^7&XB.PH@("`@=F%R7V1U;7`H)&QI;FMS
M+"`D;&]C871I;VXL("1W96%T:&5R+"`D9F]R96-A<W0I.PH@("`@96-H;R`B
M/"]P<F4^7&XB.PI](`H_/@H\<W!A;B!C;&%S<STB8FQU96)O;&0B('-T>6QE
M/2)F;VYT+7-I>F4Z(#$S<'0B/E=E871H97(@1F]R96-A<W0\+W-P86X^(&-R
M96%T960@=VET:"`\82!S='EL93TB9F]N="US:7IE.B`Q,W!T(B!H<F5F/2)H
M='1P.B\O<&5A<BYP:'`N;F5T+R(^4$5!4G,\+V$^(#QA('-T>6QE/2)F;VYT
M+7-I>F4Z(#$S<'0B(&AR968](FAT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G
M92]397)V:6-E<U]796%T:&5R+R(^4V5R=FEC97-?5V5A=&AE<CPO83X\8G(^
M"CQT86)L92!S='EL93TB=VED=&@Z(#$P,"4B/@H\='(^"B`@("`\=&0^"B`@
M("`@("`@/'1A8FQE('-T>6QE/2)B;W)D97(M=&]P.B`R<'@@<V]L:60@(S4R
M-&(Y.#L@8F]R9&5R+6)O='1O;3H@,G!X('-O;&ED("-E,&4S8V4[(&)O<F1E
M<BUL969T.B`R<'@@<V]L:60@(V(X8C9C,3L@8F]R9&5R+7)I9VAT.B`R<'@@
M<V]L:60@(SAB.#=A,#L@=VED=&@Z(#$P,"4B/@H@("`@("`@(#QT<B!C;&%S
M<STB8F=K:&%K:2(^"B`@("`@("`@("`@(#QT9"!S='EL93TB=VED=&@Z(#,Q
M,'!X.R!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V%B861A,B(@8V]L<W!A
M;CTB,B(^/'-P86X@8VQA<W,](F)O;&0B/CP_/21L;V-A=&EO;ELB;F%M92)=
M/SX\+W-P86X^/"]T9#X*("`@("`@("`@("`@/'1D('-T>6QE/2)W:61T:#H@
M,3DP<'@[(&)O<F1E<BUB;W1T;VTZ(#)P>"!S;VQI9"`C86)A9&$R(CX\<W!A
M;B!C;&%S<STB8F]L9"(^3&]C86P@=&EM93H\+W-P86X^(#P_/21L;V-A=&EO
M;ELB=&EM92)=/SX@*$=-5#P_/2@H)&QO8V%T:6]N6R)T:6UE>F]N92)=(#P@
M,"D@/R`B(B`Z("(K(BDN)&QO8V%T:6]N6R)T:6UE>F]N92)=/SXI/"]T9#X*
M("`@("`@("`@("`@/'1D('-T>6QE/2)B;W)D97(M8F]T=&]M.B`R<'@@<V]L
M:60@(V%B861A,B(^)FYB<W`[/"]T9#X*("`@("`@("`\+W1R/@H@("`@("`@
M(#QT<CX*("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY3=6YR
M:7-E.CPO<W!A;CX@/&EM9R!S='EL93TB=VED=&@Z(#(X<'@[(&AE:6=H=#H@
M,3-P>#L@=F5R=&EC86PM86QI9VXZ(&)A<V5L:6YE(B!A;'0](E-U;G)I<V4B
M('-R8STB:6UA9V5S+W-U;G)I<V4N9VEF(CX@/#\])&QO8V%T:6]N6R)S=6YR
M:7-E(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9"!C;VQS<&%N/2(R(CX\<W!A
M;B!C;&%S<STB8F]L9"(^4W5N<V5T.CPO<W!A;CX@/&EM9R!S='EL93TB=VED
M=&@Z(#,P<'@[(&AE:6=H=#H@,35P>#L@=F5R=&EC86PM86QI9VXZ(&)A<V5L
M:6YE(B!A;'0](E-U;G-E="(@<W)C/2)I;6%G97,O<W5N<V5T+F=I9B(^(#P_
M/21L;V-A=&EO;ELB<W5N<V5T(ET_/CPO=&0^"B`@("`@("`@("`@(#QT9"!R
M;W=S<&%N/2(U(B!V86QI9VX](FUI9&1L92(@86QI9VX](F-E;G1E<B(^"B`@
M("`@("`@("`@("`@("`\=&%B;&4@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S
M;VQI9"`C-3(T8CDX.R!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V4P93-C
M93L@8F]R9&5R+6QE9G0Z(#)P>"!S;VQI9"`C8CAB-F,Q.R!B;W)D97(M<FEG
M:'0Z(#)P>"!S;VQI9"`C.&(X-V$P(CX*("`@("`@("`@("`@("`@(#QT<B!C
M;&%S<STB8F=K:&%K:2(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N
M/2)C96YT97(B('-T>6QE/2)B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V%B
M861A,B(^/'-P86X@8VQA<W,](F)O;&0B/D9E871U<F5D(&]N(#QS<&%N(&-L
M87-S/2)B;VQD:71A;&EC(CYW96%T:&5R+F-O;3QS<&%N(&-L87-S/2)R96<B
M/B9R96<[/"]S<&%N/CPO<W!A;CX\+W-P86X^/"]T9#X*("`@("`@("`@("`@
M("`@(#PO='(^"CP_<&AP"B\O($QO;W`@=&AR;W5G:"!T:&4@;6%N9&%T;W)Y
M(&QI;FMS+"!N;W1H:6YG('-P96-T86-U;&%R"F9O<B`H)&D@/2`P.R`D:2`\
M('-I>F5O9B@D;&EN:W-;(G!R;VUO(ETI.R`D:2LK*2!["C\^"B`@("`@("`@
M("`@("`@("`\='(@8VQA<W,](F)G9W)E>2(^"B`@("`@("`@("`@("`@("`@
M("`@/'1D/CQA(&AR968](CP_/21L:6YK<ULB<')O;6\B75LD:5U;(FQI;FLB
M73\^(CX\/STD;&EN:W-;(G!R;VUO(EU;)&E=6R)T:71L92)=/SX\+V$^/"]T
M9#X*("`@("`@("`@("`@("`@(#PO='(^"CP_<&AP"GT*/SX*("`@("`@("`@
M("`@("`@(#PO=&%B;&4^"B`@("`@("`@("`@(#PO=&0^"B`@("`@("`@/"]T
M<CX*("`@("`@("`\='(^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB
M8F]L9"(^5&5M<&5R871U<F4Z/"]S<&%N/B`\/SUR;W5N9"@D=V5A=&AE<ELB
M=&5M<&5R871U<F4B72P@,2DN)'5N:71S6R)T96UP(ET_/CPO=&0^"B`@("`@
M("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^1&5W('!O:6YT.CPO<W!A
M;CX@/#\]<F]U;F0H)'=E871H97);(F1E=U!O:6YT(ETL(#$I+B1U;FET<ULB
M=&5M<")=/SX\+W1D/@H@("`@("`@("`@("`\=&0^/'-P86X@8VQA<W,](F)O
M;&0B/D9E;'0@=&5M<&5R871U<F4Z/"]S<&%N/B`\/SUR;W5N9"@D=V5A=&AE
M<ELB9F5L=%1E;7!E<F%T=7)E(ETL(#$I+B1U;FET<ULB=&5M<")=/SX\+W1D
M/@H@("`@("`@(#PO='(^"B`@("`@("`@/'1R/@H@("`@("`@("`@("`\=&0@
M8V]L<W!A;CTB,B(^/'-P86X@8VQA<W,](F)O;&0B/E!R97-S=7)E.CPO<W!A
M;CX@/#\]<F]U;F0H)'=E871H97);(G!R97-S=7)E(ETL(#$I+B1U;FET<ULB
M<')E<R)=/SX@86YD(#P_/21W96%T:&5R6R)P<F5S<W5R951R96YD(ET_/CPO
M=&0^"B`@("`@("`@("`@(#QT9#X\<W!A;B!C;&%S<STB8F]L9"(^2'5M:61I
M='DZ/"]S<&%N/B`\/STD=V5A=&AE<ELB:'5M:61I='DB73\^)3PO=&0^"B`@
M("`@("`@/"]T<CX*("`@("`@("`\='(^"B`@("`@("`@("`@(#QT9"!C;VQS
M<&%N/2(R(CX\<W!A;B!C;&%S<STB8F]L9"(^5VEN9#H\+W-P86X^(#P_/7-T
M<G1O;&]W97(H)'=E871H97);(G=I;F1$:7)E8W1I;VXB72D@/3T@(F-A;&TB
M(#\@(D-A;&TB(#H@(D9R;VT@=&AE("(N)'=E871H97);(G=I;F1$:7)E8W1I
M;VXB72XB("@B+B1W96%T:&5R6R)W:6YD1&5G<F5E<R)=+B(F9&5G.RD@870@
M(BYR;W5N9"@D=V5A=&AE<ELB=VEN9")=+"`Q*2XD=6YI='-;(G=I;F0B73\^
M/"]T9#X*("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY6:7-I
M8FEL:71Y.CPO<W!A;CX@/#\]<F]U;F0H)'=E871H97);(G9I<VEB:6QI='DB
M72P@,2DN)'5N:71S6R)V:7,B73\^/"]T9#X*("`@("`@("`\+W1R/@H@("`@
M("`@(#QT<CX*("`@("`@("`@("`@/'1D/CQS<&%N(&-L87-S/2)B;VQD(CY#
M=7)R96YT(&-O;F1I=&EO;CH\+W-P86X^/&)R/CP_/21W96%T:&5R6R)C;VYD
M:71I;VXB73\^/"]T9#X*("`@("`@("`@("`@/'1D/CQI;6<@<W1Y;&4](FAE
M:6=H=#H@,S)P>#L@=VED=&@Z(#,R<'@B(&%L=#TB/#\])'=E871H97);(F-O
M;F1I=&EO;B)=/SXB('-R8STB:6UA9V5S+S,R>#,R+SP_/21W96%T:&5R6R)C
M;VYD:71I;VY)8V]N(ET_/BYP;F<B/CPO=&0^"B`@("`@("`@("`@(#QT9"!V
M86QI9VX](G1O<"(^/'-P86X@8VQA<W,](F)O;&0B/E56+4EN9&5X.CPO<W!A
M;CX@/#\])'=E871H97);(G5V26YD97@B73\^("@\/STD=V5A=&AE<ELB=794
M97AT(ET_/BD\+W1D/@H@("`@("`@(#PO='(^"B`@("`@("`@/"]T86)L93X*
M("`@(#PO=&0^"CPO='(^"CQT<CX*("`@(#QT9#X*("`@("`@("`\=&%B;&4@
M<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C-3(T8CDX.R!B;W)D97(M
M8F]T=&]M.B`R<'@@<V]L:60@(V4P93-C93L@8F]R9&5R+6QE9G0Z(#)P>"!S
M;VQI9"`C8CAB-F,Q.R!B;W)D97(M<FEG:'0Z(#)P>"!S;VQI9"`C.&(X-V$P
M(CX*("`@("`@("`\='(@8VQA<W,](F)G:VAA:VDB/@H@("`@("`@("`@("`\
M=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](F)O<F1E<BUB;W1T;VTZ(#)P>"!S
M;VQI9"`C86)A9&$R(B!C;VQS<&%N/2(\/STH,2`K("1F;W)E8V%S=$1A>7,I
M/SXB/CQS<&%N(&-L87-S/2)B;VQD(CX\/STD9F]R96-A<W1$87ES/SXM9&%Y
M(&9O<F5C87-T/"]S<&%N/CPO=&0^"B`@("`@("`@/"]T<CX*("`@("`@("`\
M='(@=F%L:6=N/2)T;W`B/@H@("`@("`@("`@("`\=&0@<W1Y;&4](G=I9'1H
M.B`Q,"4B/@H@("`@("`@("`@("`@("`@/'1A8FQE(&-L87-S/2)B9VMH86MI
M(B!S='EL93TB=VED=&@Z(#$P,"4[(&)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C
M9#AD.&,P.R!B;W)D97(M8F]T=&]M.B`R<'@@<V]L:60@(V0X9#AC,#L@8F]R
M9&5R+6QE9G0Z(#)P>"!S;VQI9"`C9#AD.&,P.R!B;W)D97(M<FEG:'0Z(#)P
M>"!S;VQI9"`C.&(X-V$P(CX*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@
M("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H
M=#H@,35P>"(^)FYB<W`[/"]T9#X*("`@("`@("`@("`@("`@(#QT<CX*("`@
M("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE
M:6=H=#H@-#5P>"(^/'-P86X@8VQA<W,](F)O;&0B/E1E;7!E<F%T=7)E/"]S
M<&%N/B`\<W!A;B!C;&%S<STB<F5D8F]L9"(^2&EG:#PO<W!A;CX@+R`\<W!A
M;B!C;&%S<STB8FQU96)O;&0B/DQO=SPO<W!A;CX\+W1D/@H@("`@("`@("`@
M("`@("`@/"]T<CX*("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@
M("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@,35P
M>"(^)FYB<W`[/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@
M("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C
M96YT97(B('-T>6QE/2)H96EG:'0Z(#<U<'@B/CQS<&%N(&-L87-S/2)B;VQD
M(CY#;VYD:71I;VX\+W-P86X^/"]T9#X*("`@("`@("`@("`@("`@(#PO='(^
M"B`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@/'1D
M(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#0U<'@B/CQS<&%N(&-L
M87-S/2)B;VQD(CY0<F5C:7!I=&%T:6]N('!R;V)A8FEL:71Y/"]S<&%N/CPO
M=&0^"B`@("`@("`@("`@("`@("`\+W1R/B`@("`@("`@("`@(`H@("`@("`@
M("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB
M8V5N=&5R(B!S='EL93TB:&5I9VAT.B`T-7!X(CX\<W!A;B!C;&%S<STB8F]L
M9"(^5VEN9#PO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@/"]T<CX*("`@
M("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`\=&0@86QI
M9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@,35P>"(^/'-P86X@8VQA<W,]
M(F)O;&0B/DAU;6ED:71Y/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`\
M+W1R/@H@("`@("`@("`@("`@("`@/"]T86)L93X*("`@("`@("`@("`@/"]T
M9#X*/#]P:'`*9F]R("@D9&%Y(#T@,#L@)&1A>2`\("1F;W)E8V%S=$1A>7,[
M("1D87DK*RD@>PH@("`@+R\@4V5T(&YA;64@;V8@9&%Y"B`@("!I9B`H)&1A
M>2`]/2`P*2!["B`@("`@("`@)&1A>6YA;64@/2`B5&]D87DB.PH@("`@?2!E
M;'-E:68@*"1D87D@/3T@,2D@>PH@("`@("`@("1D87EN86UE(#T@(E1O;6]R
M<F]W(CL*("`@('T@96QS92!["B`@("`@("`@)&1A>6YA;64@/2!D871E*")L
M(BP@)&9U<"`K("1D87D@*B`X-C0P,"D["B`@("!]"B`@("`O+R!!9G1E<FYO
M;VX@:7,@;VYL>2!I;7!O<G1A;G0@9F]R('1O9&%Y"B`@("`D869T97)N;V]N
M(#T@*"1D87D@/3T@,"D@/R`D869T97)N;V]N(#H@9F%L<V4["@H@("`@+R\@
M5&AE('5S=6%L(&YO=&%T:6]N(&9O<B!C;VYD:71I;VX@:6-O;G,@:7,@;G5M
M97)I8RX@0VAE8VL@9F]R(&YU;65R:6,@:6-O;B!O<B`B;F$B(&%N9"!S970@
M=&\@(FYA(B!I9B!T:&%T)W,@;F]T('1H92!C87-E"B`@("!I9B`H(2AC='EP
M95]D:6=I="@D9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB9&%Y(EU;(F-O;F1I
M=&EO;DEC;VXB72D@?'P@)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(F1A>2)=
M6R)C;VYD:71I;VY)8V]N(ET@/3T@(FYA(BDI('L*("`@("`@("`D9F]R96-A
M<W1;(F1A>7,B75LD9&%Y75LB9&%Y(EU;(F-O;F1I=&EO;DEC;VXB72`](")N
M82(["B`@("!]"B`@("!I9B`H(2AC='EP95]D:6=I="@D9F]R96-A<W1;(F1A
M>7,B75LD9&%Y75LB;FEG:'0B75LB8V]N9&ET:6]N26-O;B)=*2!\?"`D9F]R
M96-A<W1;(F1A>7,B75LD9&%Y75LB;FEG:'0B75LB8V]N9&ET:6]N26-O;B)=
M(#T](")N82(I*2!["B`@("`@("`@)&9O<F5C87-T6R)D87ES(EU;)&1A>5U;
M(FYI9VAT(EU;(F-O;F1I=&EO;DEC;VXB72`](")N82(["B`@("!]"C\^"B`@
M("`@("`@("`@(#QT9"!S='EL93TB=VED=&@Z(#P_/2@Y,"`O("1F;W)E8V%S
M=$1A>7,I/SXE(CX*("`@("`@("`@("`@("`@(#QT86)L92!S='EL93TB=VED
M=&@Z(#$P,"4B/#\]*"1D87D@)2`R*2`_("<@8VQA<W,](F)G9W)E>2(G(#H@
M(B(_/CX*("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@
M("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!C;VQS<&%N/2(R(B!S='EL
M93TB:&5I9VAT.B`Q-7!X(CX\<W!A;B!C;&%S<STB8F]L9"(^/#\])&1A>6YA
M;64_/CPO<W!A;CX\+W1D/@H@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@
M("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@("`@("`@("`@("`@
M("`\=&0@86QI9VX](F-E;G1E<B(@8V]L<W!A;CTB,B(@<W1Y;&4](FAE:6=H
M=#H@-#5P>"(^/#\])&%F=&5R;F]O;B`_("(B(#H@)SQS<&%N(&-L87-S/2)R
M961B;VQD(CXG+G)O=6YD*"1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)T96UP
M97)A='5R94AI9V@B72P@,"DN)'5N:71S6R)T96UP(ETN)SPO<W!A;CX@+R`G
M/SX\<W!A;B!C;&%S<STB8FQU96)O;&0B/CP_/7)O=6YD*"1F;W)E8V%S=%LB
M9&%Y<R)=6R1D87E=6R)T96UP97)A='5R94QO=R)=+"`P*2XD=6YI='-;(G1E
M;7`B73\^/"]S<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/"]T<CX*
M("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@
M("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB=VED=&@Z(#4P)3L@:&5I
M9VAT.B`Q-7!X(CX\/STD869T97)N;V]N(#\@(B9N8G-P.R(@.B`G/'-P86X@
M8VQA<W,](F)O;&0B/D1A>3PO<W!A;CXG/SX\+W1D/@H@("`@("`@("`@("`@
M("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](G=I9'1H.B`U
M,"4[(&AE:6=H=#H@,35P>"(^/'-P86X@8VQA<W,](F)O;&0B/DYI9VAT/"]S
M<&%N/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/'1R/@H@("`@("`@("`@
M("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@("`@("`@/'1D(&%L
M:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#<U<'@B('9A;&ED;CTB=&]P
M(CX*("`@("`@("`@("`@("`@("`@("`@("`@("`@(#P_/21A9G1E<FYO;VX@
M/R`B)FYB<W`[(B`Z("<\:6UG('-T>6QE/2)H96EG:'0Z(#,R<'@[('=I9'1H
M.B`S,G!X(B!A;&EG;CTB=&]P(B!A;'0](B<N)&9O<F5C87-T6R)D87ES(EU;
M)&1A>5U;(F1A>2)=6R)C;VYD:71I;VXB72XG(B!S<F,](FEM86=E<R\S,G@S
M,B\G+B1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)D87DB75LB8V]N9&ET:6]N
M26-O;B)=+B<N<&YG(CXG/SX\8G(^"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`\/STD869T97)N;V]N(#\@(B9N8G-P.R(@.B`D9F]R96-A<W1;(F1A
M>7,B75LD9&%Y75LB9&%Y(EU;(F-O;F1I=&EO;B)=/SX@"B`@("`@("`@("`@
M("`@("`@("`@("`@(#PO=&0^"B`@("`@("`@("`@("`@("`@("`@("`@(#QT
M9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`W-7!X(B!V86QI9&X]
M(G1O<"(^"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\:6UG('-T>6QE
M/2)H96EG:'0Z(#,R<'@[('=I9'1H.B`S,G!X(B!A;&EG;CTB=&]P(B!A;'0]
M(CP_/21F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)C;VYD:71I
M;VXB73\^(B!S<F,](FEM86=E<R\S,G@S,B\\/STD9F]R96-A<W1;(F1A>7,B
M75LD9&%Y75LB;FEG:'0B75LB8V]N9&ET:6]N26-O;B)=/SXN<&YG(CX\8G(^
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`\/STD9F]R96-A<W1;(F1A
M>7,B75LD9&%Y75LB;FEG:'0B75LB8V]N9&ET:6]N(ET_/B`*("`@("`@("`@
M("`@("`@("`@("`@("`@/"]T9#X*("`@("`@("`@("`@("`@("`@("`\+W1R
M/@H@("`@("`@("`@("`@("`@("`@(#QT<CX*("`@("`@("`@("`@("`@("`@
M("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG:'0Z(#0U<'@B
M/CP_/21A9G1E<FYO;VX@/R`B)FYB<W`B(#H@)&9O<F5C87-T6R)D87ES(EU;
M)&1A>5U;(F1A>2)=6R)P<F5C:7!I=&%T:6]N(ETN(B4B/SX\+W1D/@H@("`@
M("`@("`@("`@("`@("`@("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4]
M(FAE:6=H=#H@-#5P>"(^/#\])&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI
M9VAT(EU;(G!R96-I<&ET871I;VXB73\^)3PO=&0^"B`@("`@("`@("`@("`@
M("`@("`@/"]T<CX*("`@("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@
M("`@("`@("`@("`@("`@(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I
M9VAT.B`T-7!X(CX\/STD869T97)N;V]N(#\@(B9N8G-P.R(@.B!R;W5N9"@D
M9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB9&%Y(EU;(G=I;F0B72P@,"DN)'5N
M:71S6R)W:6YD(ETN(B!F<F]M)FYB<W`[(BXD9F]R96-A<W1;(F1A>7,B75LD
M9&%Y75LB9&%Y(EU;(G=I;F1$:7)E8W1I;VXB73\^/"]T9#X*("`@("`@("`@
M("`@("`@("`@("`@("`@/'1D(&%L:6=N/2)C96YT97(B('-T>6QE/2)H96EG
M:'0Z(#0U<'@B/CP_/7)O=6YD*"1F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N
M:6=H=")=6R)W:6YD(ETL(#`I+B1U;FET<ULB=VEN9")=/SX@9G)O;29N8G-P
M.SP_/21F;W)E8V%S=%LB9&%Y<R)=6R1D87E=6R)N:6=H=")=6R)W:6YD1&ER
M96-T:6]N(ET_/CPO=&0^"B`@("`@("`@("`@("`@("`@("`@/"]T<CX*("`@
M("`@("`@("`@("`@("`@("`\='(^"B`@("`@("`@("`@("`@("`@("`@("`@
M(#QT9"!A;&EG;CTB8V5N=&5R(B!S='EL93TB:&5I9VAT.B`Q-7!X(CX\/STD
M869T97)N;V]N(#\@(B(@.B`D9F]R96-A<W1;(F1A>7,B75LD9&%Y75LB9&%Y
M(EU;(FAU;6ED:71Y(ETN(B4B/SX\+W1D/@H@("`@("`@("`@("`@("`@("`@
M("`@("`\=&0@86QI9VX](F-E;G1E<B(@<W1Y;&4](FAE:6=H=#H@,35P>"(^
M/#\])&9O<F5C87-T6R)D87ES(EU;)&1A>5U;(FYI9VAT(EU;(FAU;6ED:71Y
M(ET_/B4\+W1D/@H@("`@("`@("`@("`@("`@("`@(#PO='(^"B`@("`@("`@
M("`@("`@("`\+W1A8FQE/@H@("`@("`@("`@("`\+W1D/@H\/W!H<`I]"C\^
M"B`@("`@("`@/"]T<CX*("`@("`@("`\='(@8VQA<W,](F)G:VAA:VDB/@H@
M("`@"2`@("`\=&0@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C86)A
M9&$R(CXF;F)S<#L\+W1D/@H@("`@("`@("`@("`\=&0@<W1Y;&4](F)O<F1E
M<BUT;W`Z(#)P>"!S;VQI9"`C86)A9&$R(CY5<&1A=&5D.B`H/#\]9&%T92@D
M=&EM949O<FUA="P@)'=U<&0I/SXF;F)S<#LO)FYB<W`[/#\]9&%T92@D=&EM
M949O<FUA="P@)&9U<&0I/SXI/"]T9#X*("`@("`@("`@("`@/'1D(&%L:6=N
M/2)R:6=H="(@<W1Y;&4](F)O<F1E<BUT;W`Z(#)P>"!S;VQI9"`C86)A9&$R
M(B!C;VQS<&%N/2(\/STH)&9O<F5C87-T1&%Y<R`M(#$I/SXB/E=E871H97(@
M9&%T82!P<F]V:61E9"!B>2`\82!H<F5F/2)H='1P.B\O=W=W+G=E871H97(N
M8V]M+S]P<F]D/7AO87`F<&%R/3P_/21P87)T;F5R240_/B(^=V5A=&AE<BYC
M;VT\<W!A;B!C;&%S<STB<F5G(CXF<F5G.SPO<W!A;CX\+V$^/&$@:')E9CTB
M:'1T<#HO+W=W=RYW96%T:&5R+F-O;2\_<')O9#UX;V%P)G!A<CT\/STD<&%R
M=&YE<DE$/SXB/CQI;6<@<W1Y;&4](FAE:6=H=#H@,S)P>#L@=VED=&@Z(#0S
M<'@B(&%L=#TB=V5A=&AE<BYC;VTH4BD@;&]G;R(@<W)C/2)I;6%G97,O;&]G
M;W,O5%=#;&]G;U\S,G!X+G!N9R(^/"]A/CPO=&0^"B`@("`@("`@/"]T<CX*
M("`@("`@("`\+W1A8FQE/@H@("`@/"]T9#X*/"]T<CX*/"]T86)L93X*/&$@
M:')E9CTB:F%V87-C<FEP=#IH:7-T;W)Y+F)A8VLH*2(^8F%C:SPO83X*/"]B
M;V1Y/@H\+VAT;6P^"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+V5J<V4M8F%S:6,N<&AP
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P-C(T,R`Q,#4Q-30S-#$S,B`P,C<R,3,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!"87-I8R!E
M>&%M<&QE(&9O<B!T:&4@14I312US97)V:6-E"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P
M,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@
M*B`*("H@4F5D:7-T<FEB=71I;VX@86YD('5S92!I;B!S;W5R8V4@86YD(&)I
M;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H;W5T"B`J(&UO9&EF:6-A=&EO;BP@
M87)E('!E<FUI='1E9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N
M9&ET:6]N<PH@*B!A<F4@;65T.@H@*B!O(%)E9&ES=')I8G5T:6]N<R!O9B!S
M;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I9VAT(&YO
M=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O
M;&QO=VEN9R!D:7-C;&%I;65R+@H@*B!O(%)E9&ES=')I8G5T:6]N<R!I;B!B
M:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT
M(&YO=&EC92P*("H@("!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE
M(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!D;V-U;65N=&%T:6]N"B`J
M("`@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D
M:7-T<FEB=71I;VXN"B`J(&\@3F5I=&AE<B!T:&4@;F%M92!O9B!T:&4@<V]F
M='=A<F4@;F]R('1H92!N86UE<R!O9B!I=',@8V]N=')I8G5T;W)S"B`J("`@
M;6%Y(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E('!R;V1U8W1S(&1E
M<FEV960@9G)O;2!T:&ES('-O9G1W87)E"B`J("`@=VET:&]U="!S<&5C:69I
M8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I;VXN"B`J(`H@*B!42$E3(%-/1E17
M05)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@
M0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-
M4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@
M5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,
M2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!
M4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(
M5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@
M0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4
M551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52
M($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.
M1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H@"B`J($!C871E9V]R>2`@("!7
M96(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*
M("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE
M=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L
M:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S
M+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@
M($-64SH@)$ED.B!E:G-E+6)A<VEC+G!H<"QV(#$N-"`R,#`U+S$Q+S`X(#$W
M.C4R.C0R(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N
M<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&9I;&5S;W5R
M8V4*("HO"B`*<F5Q=6ER95]O;F-E(")397)V:6-E<R]796%T:&5R+G!H<"([
M"@HO+R!/8FIE8W0@:6YI=&EA;&EZ871I;VX@+2!E<G)O<B!C:&5C:VEN9R!I
M<R!I;7!O<G1A;G0L(&)E8V%U<V4@;V8*+R\@:&%N9&QI;F<@97AC97!T:6]N
M<R!S=6-H(&%S(&UI<W-I;F<@4$5!4B!M;V1U;&5S(&]R(&YO="!B96EN9R!O
M;FQI;F4*)&5J<V4@/2`F4V5R=FEC97-?5V5A=&AE<CHZ<V5R=FEC92@B16IS
M92(L(&%R<F%Y*")D96)U9R(@/3X@,BDI.PII9B`H4V5R=FEC97-?5V5A=&AE
M<CHZ:7-%<G)O<B@D96IS92DI('L*("`@(&1I92@B17)R;W(Z("(N)&5J<V4M
M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+RH@17)A<V4@8V]M;65N=',@=&\@
M96YA8FQE(&-A8VAI;F<*)'-T871U<R`]("1E:G-E+3YS971#86-H92@B9FEL
M92(L(&%R<F%Y*")C86-H95]D:7(B(#T^("(O=&UP+V-A8VAE+R(I*3L*:68@
M*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@(&5C
M:&\@(D5R<F]R.B`B+B1S=&%T=7,M/F=E=$UE<W-A9V4H*2XB7&XB.PI]"BHO
M"@HD96IS92T^<V5T56YI='-&;W)M870H(FUE=')I8R(I.PHD96IS92T^<V5T
M1&%T951I;65&;W)M870H(F0N;2Y9(BP@(D@Z:2(I.PH*)&QO8V%T:6]N(#T@
M(C@Q-C$Q(CL@+R\@07-P96XL($-/"B\O)&QO8V%T:6]N(#T@(C`R,3$U(CL@
M+R\@0F]S=&]N+"!-00HO+R1L;V-A=&EO;B`]("(Y-C<Y.2([("\O(%!A9V\@
M4&%G;RP@05,*+R\D;&]C871I;VX@/2`B,#DP,#DB.R`O+R!!<FUE9"!&;W)C
M97,@175R;W!E("T^($5R<F]R"@HO+R!.;W<@:71E<F%T92!T:')O=6=H(&%V
M86EL86)L92!F=6YC=&EO;G,@9F]R(')E=')I979I;F<@9&%T80IF;W)E86-H
M("AA<G)A>2@B9V5T3&]C871I;VXB+"`B9V5T5V5A=&AE<B(L(")G971&;W)E
M8V%S="(I(&%S("1F=6YC=&EO;BD@>PH@("`@)&1A=&$@/2`D96IS92T^)&9U
M;F-T:6]N*"1L;V-A=&EO;BD["B`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D9&%T82DI('L*("`@("`@("!E8VAO(")%<G)O<CH@(BXD9&%T
M82T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@8V]N=&EN=64["B`@("!]
M"@H@("`@=F%R7V1U;7`H)&1A=&$I.PI]"C\^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R
M+V1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]G;&]B86QW96%T:&5R
M+6)A<VEC+G!H<```````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#8T,3`@,3`U,34T,S0Q,S(@,#,Q,3`Q`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````#P_<&AP"B\J('9I
M;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O9G1T
M86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@0F%S:6,@
M97AA;7!L92!F;W(@=&AE($=L;V)A;%=E871H97(M<V5R=FEC90H@*@H@*B!0
M2%`@=F5R<VEO;G,@-"!A;F0@-0H@*@H@*B`\3$E#14Y313X*("H@0V]P>7)I
M9VAT("AC*2`R,#`U+"!!;&5X86YD97(@5VER='H*("H@06QL(')I9VAT<R!R
M97-E<G9E9"X*("H@"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I
M9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L
M;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE
M;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@
M;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U
M=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P
M<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*B`*("H@
M5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/
M3$1%4E,@04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A0
M4D534R!/4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/
M5"!,24U)5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%
M4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!5
M4E!/4T4*("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(
M12!#3U!94DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),
M12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)
M04PL($5814U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)
M3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*
M("H@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L
M($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/
M3BD@2$]7159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,
M2519+"!72$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519
M+"!/4B!43U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I
M"B`J($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3
M(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,
M2519($]&(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J(`H@*B!`8V%T
M96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E
M<U]796%T:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L
M97A`<&,T<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7
M:7)T>@H@*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R
M9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V
M97)S:6]N("`@("!#5E,Z("1)9#H@9VQO8F%L=V5A=&AE<BUB87-I8RYP:'`L
M=B`Q+C4@,C`P-2\Q,2\P."`Q-SHU,CHT,B!E<G4@17AP("0*("H@0&QI;FL@
M("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]7
M96%T:&5R"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E(")397)V
M:6-E<R]796%T:&5R+G!H<"(["@HO+R!/8FIE8W0@:6YI=&EA;&EZ871I;VX@
M+2!E<G)O<B!C:&5C:VEN9R!I<R!I;7!O<G1A;G0L(&)E8V%U<V4@;V8*+R\@
M:&%N9&QI;F<@97AC97!T:6]N<R!S=6-H(&%S(&UI<W-I;F<@4$5!4B!M;V1U
M;&5S(&]R(&YO="!B96EN9R!O;FQI;F4*)&=L;V)A;'=E871H97(@/2`F4V5R
M=FEC97-?5V5A=&AE<CHZ<V5R=FEC92@B1VQO8F%L5V5A=&AE<B(L(&%R<F%Y
M*")D96)U9R(@/3X@,BDI.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D9VQO8F%L=V5A=&AE<BDI('L*("`@(&1I92@B17)R;W(Z("(N)&=L;V)A
M;'=E871H97(M/F=E=$UE<W-A9V4H*2XB7&XB*3L*?0H*+RH@17)A<V4@8V]M
M;65N=',@=&\@96YA8FQE(&-A8VAI;F<*)'-T871U<R`]("1G;&]B86QW96%T
M:&5R+3YS971#86-H92@B9FEL92(L(&%R<F%Y*")C86-H95]D:7(B(#T^("(O
M=&UP+V-A8VAE+R(I*3L*:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H
M)'-T871U<RDI('L*("`@(&5C:&\@(D5R<F]R.B`B+B1S=&%T=7,M/F=E=$UE
M<W-A9V4H*2XB7&XB.PI]"BHO"@HD9VQO8F%L=V5A=&AE<BT^<V5T56YI='-&
M;W)M870H(FUE=')I8R(I.PHD9VQO8F%L=V5A=&AE<BT^<V5T1&%T951I;65&
M;W)M870H(F0N;2Y9(BP@(D@Z:2(I.PH*+R\@1FER<W0@9V5T(&-O9&4@9F]R
M(&QO8V%T:6]N"B1S96%R8V@@/2`D9VQO8F%L=V5A=&AE<BT^<V5A<F-H3&]C
M871I;VXH(DMO96QN("\@0F]N;B(I.PII9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D<V5A<F-H*2D@>PH@("`@9&EE*")%<G)O<CH@(BXD<V5A<F-H
M+3YG971-97-S86=E*"DN(EQN(BD["GT*"B\O($YO=R!I=&5R871E('1H<F]U
M9V@@879A:6QA8FQE(&9U;F-T:6]N<R!F;W(@<F5T<FEE=FEN9R!D871A"F9O
M<F5A8V@@*&%R<F%Y*")G971,;V-A=&EO;B(L(")G971796%T:&5R(BP@(F=E
M=$9O<F5C87-T(BD@87,@)&9U;F-T:6]N*2!["B`@("`D9&%T82`]("1G;&]B
M86QW96%T:&5R+3XD9G5N8W1I;VXH)'-E87)C:"D["B`@("!I9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D9&%T82DI('L*("`@("`@("!E8VAO(")%
M<G)O<CH@(BXD9&%T82T^9V5T365S<V%G92@I+B)<;B(["B`@("`@("`@8V]N
M=&EN=64["B`@("!]"@H@("`@=F%R7V1U;7`H)&1A=&$I.PI]"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A
M<B]D;V-S+T%R8VAI=F5?5&%R+V1O8W,`````````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,R(#`R,C0U,``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O07)C:&EV95]487(O9&]C<R]!<F-H
M:79E7U1A<BYT>'0`````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-#0V,3`@,3`U,34T,S0Q
M,S(@,#(U-#8T`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````$1O8W5M96YT871I;VX@9F]R(&-L87-S($%R8VAI=F5?5&%R#0H]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0T*3&%S="!U<&1A
M=&4@.B`R,#`Q+3`X+3$U#0H-"@T*#0I/=F5R=FEE=R`Z#0HM+2TM+2TM+2TM
M#0H-"B`@5&AE($%R8VAI=F5?5&%R(&-L87-S(&AE;'!S(&EN(&-R96%T:6YG
M(&%N9"!M86YA9VEN9R!'3E4@5$%2(&9O<FUA=`T*("!F:6QE<R!C;VUP<F5S
M<V5D(&)Y($=.52!:25`@;W(@;F]T+B`-"B`@5&AE(&-L87-S(&]F9F5R<R!B
M87-I8R!F=6YC=&EO;G,@;&EK92!C<F5A=&EN9R!A;B!A<F-H:79E+"!A9&1I
M;F<-"B`@9FEL97,@:6X@=&AE(&%R8VAI=F4L(&5X=')A8W1I;F<@9FEL97,@
M9G)O;2!T:&4@87)C:&EV92!A;F0@;&ES=&EN9PT*("!T:&4@87)C:&EV92!C
M;VYT96YT+B`-"B`@270@86QS;R!P<F]V:61E(&%D=F%N8V5D(&9U;F-T:6]N
M<R!T:&%T(&%L;&]W('1H92!A9&1I;F<@86YD#0H@(&5X=')A8W1I;VX@;V8@
M9FEL97,@=VET:"!P871H(&UA;FEP=6QA=&EO;BX@#0H-"@T*4V%M<&QE(#H-
M"BTM+2TM+2TM#0H-"B`@+R\@+2TM+2T@0W)E871I;F<@=&AE(&]B:F5C="`H
M=6YC;VUP<F5S<V5D(&%R8VAI=F4I#0H@("1T87)?;V)J96-T(#T@;F5W($%R
M8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B:F5C="T^<V5T
M17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-"@T*("`O+R`M+2TM
M+2!#<F5A=&EN9R!T:&4@87)C:&EV90T*("`D=E]L:7-T6S!=/2)F:6QE+G1X
M="([#0H@("1V7VQI<W1;,5T](F1A=&$O(CL-"B`@)'9?;&ES=%LR73TB9FEL
M92YL;V<B.PT*("`D=&%R7V]B:F5C="T^8W)E871E*"1V7VQI<W0I.PT*#0H@
M("\O("TM+2TM($%D9&EN9R!F:6QE<PT*("`D=E]L:7-T6S!=/2)D978O9FEL
M92YT>'0B.PT*("`D=E]L:7-T6S%=/2)D978O9&%T82\B.PT*("`D=E]L:7-T
M6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D*"1V7VQI
M<W0I.PT*#0H@("\O("TM+2TM($%D9&EN9R!M;W)E(&9I;&5S#0H@("1T87)?
M;V)J96-T+3YA9&0H(G)E;&5A<V4O;F5W9FEL92YL;V<@<F5L96%S92]R96%D
M;64N='AT(BD[#0H-"B`@+R\@+2TM+2T@3&ES=&EN9R!T:&4@8V]N=&5N=`T*
M("!I9B`H*"1V7VQI<W0@(#T@("1T87)?;V)J96-T+3YL:7-T0V]N=&5N="@I
M*2`A/2`P*0T*("`@(&9O<B`H)&D],#L@)&D\<VEZ96]F*"1V7VQI<W0I.R`D
M:2LK*0T*("`@('L-"B`@("`@(&5C:&\@(D9I;&5N86UE(#HG(BXD=E]L:7-T
M6R1I75MF:6QE;F%M95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N<VEZ92`Z
M)R(N)'9?;&ES=%LD:5U;<VEZ95TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N
M;71I;64@.B<B+B1V7VQI<W1;)&E=6VUT:6UE72XB)R`H(BYD871E*")L(&13
M(&]F($8@62!H.FDZ<R!!(BP@)'9?;&ES=%LD:5U;;71I;65=*2XB*3QB<CXB
M.PT*("`@("`@96-H;R`B("YM;V1E(#HG(BXD=E]L:7-T6R1I75MM;V1E72XB
M)SQB<CXB.PT*("`@("`@96-H;R`B("YU:60@.B<B+B1V7VQI<W1;)&E=6W5I
M9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@(B`N9VED(#HG(BXD=E]L:7-T6R1I
M75MG:61=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G1Y<&5F;&%G(#HG(BXD
M=E]L:7-T6R1I75MT>7!E9FQA9UTN(B<\8G(^(CL-"B`@("!]#0H-"B`@+R\@
M+2TM+2T@17AT<F%C=&EN9R!T:&4@87)C:&EV92!I;B!D:7)E8W1O<GD@(FEN
M<W1A;&PB#0H@("1T87)?;V)J96-T+3YE>'1R86-T*")I;G-T86QL(BD[#0H-
M"@T*4'5B;&EC(&%R9W5M96YT<R`Z#0HM+2TM+2TM+2TM+2TM+2TM+2T-"@T*
M3F]N90T*#0H-"E!U8FQI8R!-971H;V1S(#H-"BTM+2TM+2TM+2TM+2TM+2T-
M"@T*365T:&]D(#H@07)C:&EV95]487(H)'!?=&%R;F%M92P@)&-O;7!R97-S
M(#T@;G5L;"D-"D1E<V-R:7!T:6]N(#H-"B`@07)C:&EV95]487(@0VQA<W,@
M8V]N<W1R=6-T;W(N(%1H:7,@9FQA=F]U<B!O9B!T:&4@8V]N<W1R=6-T;W(@
M;VYL>0T*("!D96-L87)E(&$@;F5W($%R8VAI=F5?5&%R(&]B:F5C="P@:61E
M;G1I9GEI;F<@:70@8GD@=&AE(&YA;64@;V8@=&AE#0H@('1A<B!F:6QE+@T*
M("!)9B!T:&4@8V]M<')E<W,@87)G=6UE;G0@:7,@<V5T('1H92!T87(@=VEL
M;"!B92!R96%D(&]R(&-R96%T960@87,@80T*("!G>FEP(&]R(&)Z,B!C;VUP
M<F5S<V5D(%1!4B!F:6QE+B`-"D%R9W5M96YT<R`Z#0H@("1P7W1A<FYA;64@
M.B!!('9A;&ED(&9I;&5N86UE(&9O<B!T:&4@=&%R(&%R8VAI=F4@9FEL92X-
M"B`@)'!?8V]M<')E<W,@.B!C86X@8F4@;G5L;"P@)V=Z)R!O<B`G8GHR)RX@
M1F]R#0H@("`@("`@("`@("`@("`@8V]M<&%T:6)I;&ET>2!R96%S;VX@:70@
M8V%N(&%L<V\@8F4@=')U92X@5&AI<PT*("`@("`@("`@("`@("`@('!A<F%M
M971E<B!I;F1I8V%T97,@:68@9WII<"!O<B!B>C(@8V]M<')E<W-I;VX-"B`@
M("`@("`@("`@("`@("!I<R!R97%U:7)E9"X@#0I2971U<FX@=F%L=64@.@T*
M("!4:&4@07)C:&EV95]487(@;V)J96-T+@T*4V%M<&QE(#H-"B`@)'1A<E]O
M8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T
M87)?;V)J96-T7V-O;7!R97-S960@/2!N97<@07)C:&EV95]487(H(G1A<FYA
M;64N=&=Z(BP@=')U92D[#0I(;W<@:70@=V]R:W,@.@T*("!);FET:6%L:7IE
M('1H92!O8FIE8W0N#0H-"DUE=&AO9"`Z(&-R96%T92@D<%]F:6QE;&ES="D-
M"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@8W)E871E<R!T:&4@87)C
M:&EV92!F:6QE(&%N9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T;W)I97,-"B`@
M=&AA="!A<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+B`-"B`@268@=&AE(&9I
M;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71A8FQE+"!I="!I<R!R97!L
M86-E9"!B>2!T:&4-"B`@;F5W('1A<BX@270@:7,@82!C<F5A=&4@86YD(&YO
M="!A;B!A9&0N($EF('1H92!F:6QE(&5X:7-T<R!A;F0@:7,-"B`@<F5A9"UO
M;FQY(&]R(&ES(&$@9&ER96-T;W)Y(&ET(&ES(&YO="!R97!L86-E9"X@5&AE
M(&UE=&AO9"!R971U<FX-"B`@9F%L<V4@86YD(&$@4$5!4B!E<G)O<B!T97AT
M+B`-"B`@5&AE("1P7V9I;&5L:7-T('!A<F%M971E<B!C86X@8F4@86X@87)R
M87D@;V8@<W1R:6YG+"!E86-H('-T<FEN9PT*("!R97!R97-E;G1I;F<@82!F
M:6QE;F%M92!O<B!A(&1I<F5C=&]R>2!N86UE('=I=&@@=&AE:7(@<&%T:"!I
M9@T*("!N965D960N($ET(&-A;B!A;'-O(&)E(&$@<VEN9VQE('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@('-I;F=L92!B;&%N:RX@#0H@
M(%-E92!A;'-O(&-R96%T94UO9&EF>2@I(&UE=&AO9"!F;W(@;6]R92!D971A
M:6QS+@T*07)G=6UE;G1S(#H-"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O
M9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-
M"B`@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L
M86YK('-P86-E+B`-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S
M<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T87)?;V)J96-T
M(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D=&%R7V]B
M:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L@("\O
M($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;,%T](F9I;&4N
M='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.R`H3W!T:6]N86P@)R\G(&%T
M('1H92!E;F0I#0H@("1V7VQI<W1;,ET](F9I;&4N;&]G(CL-"B`@)'1A<E]O
M8FIE8W0M/F-R96%T92@D=E]L:7-T*3L-"E-A;7!L92`R(#H-"B`@)'1A<E]O
M8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T
M87)?;V)J96-T+3YS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?4%))3E0I
M.R`@+R\@3W!T:6]N86P@97)R;W(@:&%N9&QI;F<-"B`@)'1A<E]O8FIE8W0M
M/F-R96%T92@B9FEL92YT>'0@9&%T82\@9FEL92YL;V<B*3L-"DAO=R!I="!W
M;W)K<R`Z#0H@($IU<W0@8V%L;&EN9R!T:&4@8W)E871E36]D:69Y*"D@;65T
M:&]D('=I=&@@=&AE(')I9VAT('!A<F%M971E<G,N#0H-"DUE=&AO9"`Z(&-R
M96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E
M7V1I<B`]("(B*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!C<F5A
M=&5S('1H92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@9FEL97,@+R!D:7)E
M8W1O<FEE<PT*("!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0N(`T*
M("!)9B!T:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&%B;&4L
M(&ET(&ES(')E<&QA8V5D(&)Y('1H90T*("!N97<@=&%R+B!)="!I<R!A(&-R
M96%T92!A;F0@;F]T(&%N(&%D9"X@268@=&AE(&9I;&4@97AI<W1S(&%N9"!I
M<PT*("!R96%D+6]N;'D@;W(@:7,@82!D:7)E8W1O<GD@:70@:7,@;F]T(')E
M<&QA8V5D+B!4:&4@;65T:&]D(')E='5R;@T*("!F86QS92!A;F0@82!014%2
M(&5R<F]R('1E>'0N(`T*("!4:&4@)'!?9FEL96QI<W0@<&%R86UE=&5R(&-A
M;B!B92!A;B!A<G)A>2!O9B!S=')I;F<L(&5A8V@@<W1R:6YG#0H@(')E<')E
M<V5N=&EN9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@=VET:"!T
M:&5I<B!P871H(&EF#0H@(&YE961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG
M;&4@<W1R:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$-"B`@<VEN9VQE
M(&)L86YK+B`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7W)E;6]V95]D
M:7(@=VEL;"!B92!R96UO=F5D(&9R;VT@=&AE#0H@(&UE;6]R:7IE9"!P871H
M(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L:7-T960@=VAE;B!T:&ES('!A
M=&@-"B`@97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@<F5M;W9E9"`H
M96UP='D@<&%T:"`B(BD@#0H@(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]A
M9&1?9&ER('=I;&P@8F4@861D960@870@=&AE(&)E9VEN;FEN9R!O9@T*("!T
M:&4@;65M;W)I>F5D('!A=&@@;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI
M<W1E9"X@2&]W979E<B!I="!C86X-"B`@8F4@<V5T('1O(&5M<'1Y("(B+B!4
M:&4@861D:6YG(&]F(&$@<&%T:"!I<R!D;VYE(&%F=&5R('1H92!R96UO=FEN
M9PT*("!O9B!P871H+B`-"B`@5&AE('!A=&@@861D+W)E;6]V92!A8FEL:71Y
M(&5N86)L97,@=&AE('5S97(@=&\@<')E<&%R92!A;B!A<F-H:79E#0H@(&9O
M<B!E>'1R86-T:6]N(&EN(&$@9&EF9F5R96YT('!A=&@@=&AA;B!T:&4@;W)I
M9VEN(&9I;&5S(&%R92X@#0H@(%-E92!A;'-O(&%D9$UO9&EF>2@I(&UE=&AO
M9"!F;W(@9FEL92!A9&1I;F<@<')O<&5R=&EE<RX-"D%R9W5M96YT<R`Z#0H@
M("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E
M8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@("`@("`@("`@("`@("`@<W1R
M:6YG('=I=&@@;F%M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE(&)L86YK('-P
M86-E+@T*("`D<%]A9&1?9&ER(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I;G,@
M82!P871H('1O(&)E(&%D9&5D('1O('1H90T*("`@("`@("`@("`@("`@;65M
M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+B`-"B`@
M)'!?<F5M;W9E7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T
M:"!T;R!B92!R96UO=F5D(&9R;VT-"B`@("`@("`@("`@("`@("`@('1H92!M
M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0L('=H
M96X-"@D)("!R96QE=F%N="X-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@
M<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T87)?
M;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*("`D
M=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4
M*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;,%T]
M(F9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&%T82\B.R`H3W!T:6]N86P@
M)R\G(&%T('1H92!E;F0I#0H@("1V7VQI<W1;,ET](F9I;&4N;&]G(CL-"B`@
M)'1A<E]O8FIE8W0M/F-R96%T94UO9&EF>2@D=E]L:7-T+"`B:6YS=&%L;"(I
M.PT*("`O+R!F:6QE<R!A<F4@<W1O<F5D(&EN('1H92!A<F-H:79E(&%S(#H-
M"B`@+R\@("!I;G-T86QL+V9I;&4N='AT#0H@("\O("`@:6YS=&%L;"]D871A
M#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A
M;&PO9&%T82\N+BX@86QL('1H92!F:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T
M82\-"B`@+R\@("!I;G-T86QL+V9I;&4N;&]G#0I386UP;&4@,B`Z#0H@("1T
M87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*
M("`D=&%R7V]B:F5C="T^<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!2
M24Y4*3L@("\O($]P=&EO;F%L(&5R<F]R(&AA;F1L:6YG#0H@("1V7VQI<W1;
M,%T](F1E=B]F:6QE+G1X="([#0H@("1V7VQI<W1;,5T](F1E=B]D871A+R([
M("A/<'1I;VYA;"`G+R<@870@=&AE(&5N9"D-"B`@)'9?;&ES=%LR73TB;&]G
M+V9I;&4N;&]G(CL-"B`@)'1A<E]O8FIE8W0M/F-R96%T94UO9&EF>2@D=E]L
M:7-T+"`B:6YS=&%L;"(L(")D978B*3L-"B`@+R\@9FEL97,@87)E('-T;W)E
M9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O("`@:6YS=&%L;"]F:6QE+G1X
M=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O+R`@(&EN<W1A;&PO9&%T82]F
M:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$O+BXN(&%L;"!T:&4@9FEL
M97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@("\O("`@:6YS=&%L;"]L;V<O
M9FEL92YL;V<-"DAO=R!I="!W;W)K<R`Z#0H@($]P96X@=&AE(&9I;&4@:6X@
M=W)I=&4@;6]D92`H97)A<VEN9R!T:&4@97AI<W1I;F<@;VYE(&EF(&]N92DL
M#0H@(&-A;&P@=&AE(%]A9&1,:7-T*"D@;65T:&]D(&9O<B!A9&1I;F<@=&AE
M(&9I;&5S(&EN(&%N(&5M<'1Y(&%R8VAI=F4L#0H@(&%D9"!T:&4@=&%R(&9O
M;W1E<B`H-3$R(&)Y=&5S(&)L;V-K*2P@8VQO<V4@=&AE('1A<B!F:6QE+@T*
M#0H-"DUE=&AO9"`Z(&%D9$UO9&EF>2@D<%]F:6QE;&ES="P@)'!?861D7V1I
M<BP@)'!?<F5M;W9E7V1I<CTB(BD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M
M971H;V0@861D('1H92!F:6QE<R`O(&1I<F5C=&]R:65S(&QI<W1E9"!I;B`D
M<%]F:6QE;&ES="!A="!T:&4-"B`@96YD(&]F('1H92!E>&ES=&EN9R!A<F-H
M:79E+B!)9B!T:&4@87)C:&EV92!D;V5S(&YO="!Y970@97AI<W1S(&ET#0H@
M(&ES(&-R96%T960N#0H@(%1H92`D<%]F:6QE;&ES="!P87)A;65T97(@8V%N
M(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I;F<-"B`@<F5P<F5S
M96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@;F%M92!W:71H('1H
M96ER('!A=&@@:68-"B`@;F5E9&5D+B!)="!C86X@86QS;R!B92!A('-I;F=L
M92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@80T*("!S:6YG;&4@
M8FQA;FLN(`T*("!4:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?<F5M;W9E7V1I
M<B!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4-"B`@;65M;W)I>F5D('!A=&@@
M;V8@96%C:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N('1H:7,@<&%T
M:`T*("!E>&ES=',N($)Y(&1E9F%U;'0@;F]T:&EN9R!I<R!R96UO=F5D("AE
M;7!T>2!P871H("(B*2`-"B`@5&AE('!A=&@@:6YD:6-A=&5D(&EN("1P7V%D
M9%]D:7(@=VEL;"!B92!A9&1E9"!A="!T:&4@8F5G:6YN:6YG(&]F#0H@('1H
M92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES
M=&5D+B!(;W=E=F5R(&ET(&-A;@T*("!B92!S970@=&\@96UP='D@(B(N(%1H
M92!A9&1I;F<@;V8@82!P871H(&ES(&1O;F4@869T97(@=&AE(')E;6]V:6YG
M#0H@(&]F('!A=&@N(`T*("!4:&4@<&%T:"!A9&0O<F5M;W9E(&%B:6QI='D@
M96YA8FQE<R!T:&4@=7-E<B!T;R!P<F5P87)E(&%N(&%R8VAI=F4-"B`@9F]R
M(&5X=')A8W1I;VX@:6X@82!D:69F97)E;G0@<&%T:"!T:&%N('1H92!O<FEG
M:6X@9FEL97,@87)E+B`-"B`@268@82!F:6QE+V1I<B!I<R!A;')E861Y(&EN
M('1H92!A<F-H:79E(&ET('=I;&P@;VYL>2!B92!A9&1E9"!A="!T:&4-"B`@
M96YD(&]F('1H92!A<F-H:79E+B!4:&5R92!I<R!N;R!U<&1A=&4@;V8@=&AE
M(&5X:7-T:6YG(&%R8VAI=F5D#0H@(&9I;&4O9&ER+B!(;W=E=F5R('=H:6QE
M(&5X=')A8W1I;F<@=&AE(&%R8VAI=F4L('1H92!L87-T(&9I;&4@=VEL;`T*
M("!R97!L86-E('1H92!F:7)S="!O;F4N(%1H:7,@<F5S=6QT<R!I;B!A(&YO
M;F4@;W!T:6UI>F%T:6]N(&]F('1H90T*("!A<F-H:79E('-I>F4N(`T*("!)
M9B!A(&9I;&4O9&ER(&1O97,@;F]T(&5X:7-T('1H92!F:6QE+V1I<B!I<R!I
M9VYO<F5D+B!(;W=E=F5R(&%N#0H@(&5R<F]R('1E>'0@:7,@<V5N9"!T;R!0
M14%2(&5R<F]R+B`-"B`@268@82!F:6QE+V1I<B!I<R!N;W0@<F5A9&%B;&4@
M=&AE(&9I;&4O9&ER(&ES(&EG;F]R960N($AO=V5V97(@86X-"B`@97)R;W(@
M=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N(`T*("!)9B!T:&4@<F5S=6QT
M:6YG(&9I;&5N86UE+V1I<FYA;64@*&%F=&5R('1H92!A9&0O<F5M;W9E(&]P
M=&EO;B!O<@T*("!N;W0I('-T<FEN9R!I<R!G<F5A=&5R('1H86X@.3D@8VAA
M<BP@=&AE(&9I;&4O9&ER(&ES#0H@(&EG;F]R960N($AO=V5V97(@86X@97)R
M;W(@=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N(`T*07)G=6UE;G1S(#H-
M"B`@)'!?9FEL96QI<W0@.B!!;B!A<G)A>2!O9B!F:6QE;F%M97,@86YD(&1I
M<F5C=&]R>2!N86UE<RP@;W(@82!S:6YG;&4-"B`@("`@("`@("`@("`@("!S
M=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@82!S:6YG;&4@8FQA;FL@
M<W!A8V4N(`T*("`D<%]A9&1?9&ER(#H@02!S=')I;F<@=VAI8V@@8V]N=&%I
M;G,@82!P871H('1O(&)E(&%D9&5D('1O('1H90T*("`@("`@("`@("`@("`@
M;65M;W)I>F5D('!A=&@@;V8@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+B`-
M"B`@)'!?<F5M;W9E7V1I<B`Z($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@
M<&%T:"!T;R!B92!R96UO=F5D(&9R;VT-"B`@("`@("`@("`@("`@("`@('1H
M92!M96UO<FEZ960@<&%T:"!O9B!E86-H(&5L96UE;G0@:6X@=&AE(&QI<W0L
M('=H96X-"@D)("!R96QE=F%N="X-"E)E='5R;B!V86QU92`Z#0H@('1R=64@
M;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@,2`Z#0H@("1T
M87)?;V)J96-T(#T@;F5W($%R8VAI=F5?5&%R*")T87)N86UE+G1A<B(I.PT*
M("!;+BXN70T*("`D=E]L:7-T6S!=/2)D978O9FEL92YT>'0B.PT*("`D=E]L
M:7-T6S%=/2)D978O9&%T82\B.R`H3W!T:6]N86P@)R\G(&%T('1H92!E;F0I
M#0H@("1V7VQI<W1;,ET](FQO9R]F:6QE+FQO9R([#0H@("1T87)?;V)J96-T
M+3YA9&1-;V1I9GDH)'9?;&ES="P@(FEN<W1A;&PB*3L-"B`@+R\@9FEL97,@
M87)E('-T;W)E9"!I;B!T:&4@87)C:&EV92!A<R`Z#0H@("\O("`@:6YS=&%L
M;"]F:6QE+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T80T*("`O+R`@(&EN<W1A
M;&PO9&%T82]F:6QE,2YT>'0-"B`@+R\@("!I;G-T86QL+V1A=&$O+BXN(&%L
M;"!T:&4@9FEL97,@86YD('-U8BUD:7)S(&]F(&1A=&$O#0H@("\O("`@:6YS
M=&%L;"]F:6QE+FQO9PT*4V%M<&QE(#(@.@T*("`D=&%R7V]B:F5C="`](&YE
M=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B*3L-"B`@6RXN+ET-"B`@)'9?
M;&ES=%LP73TB9&5V+V9I;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A
M=&$O(CL@*$]P=&EO;F%L("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=
M/2)L;V<O9FEL92YL;V<B.PT*("`D=&%R7V]B:F5C="T^861D36]D:69Y*"1V
M7VQI<W0L(")I;G-T86QL(BP@(F1E=B(I.PT*("`O+R!F:6QE<R!A<F4@<W1O
M<F5D(&EN('1H92!A<F-H:79E(&%S(#H-"B`@+R\@("!I;G-T86QL+V9I;&4N
M='AT#0H@("\O("`@:6YS=&%L;"]D871A#0H@("\O("`@:6YS=&%L;"]D871A
M+V9I;&4Q+G1X=`T*("`O+R`@(&EN<W1A;&PO9&%T82\N+BX@86QL('1H92!F
M:6QE<R!A;F0@<W5B+61I<G,@;V8@9&%T82\-"B`@+R\@("!I;G-T86QL+VQO
M9R]F:6QE+FQO9PT*2&]W(&ET('=O<FMS(#H-"B`@268@=&AE(&%R8VAI=F4@
M9&]E<R!N;W0@97AI<W1S(&ET(&-R96%T92!I="!A;F0@861D('1H92!F:6QE
M<RX-"B`@268@=&AE(&%R8VAI=F4@9&]E<R!E>&ES=',@86YD(&ES(&YO="!C
M;VUP<F5S<V5D+"!I="!O<&5N(&ET+"!J=6UP#0H@(&)E9F]R92!T:&4@;&%S
M="!E;7!T>2`U,3(@8GET97,@8FQO8VL@*'1A<B!F;V]T97(I(&%N9"!A9&0@
M=&AE(&9I;&5S#0H@(&%T('1H:7,@<&]I;G0N#0H@($EF('1H92!A<F-H:79E
M(&1O97,@97AI<W1S(&%N9"!I<R!C;VUP<F5S<V5D+"!A('1E;7!O<F%R>2!C
M;W!Y(&9I;&4-"B`@:7,@8W)E871E9"X@5&AI<R!T96UP;W)A<GD@9FEL92!I
M<R!T:&5N("=G>FEP)R!R96%D(&)L;V-K(&)Y(&)L;V-K#0H@('5N=&EL('1H
M92!L87-T(&5M<'1Y(&)L;V-K+B!4:&4@;F5W(&9I;&5S(&%R92!T:&5N(&%D
M9&5D(&EN('1H90T*("!C;VUP<F5S<V5D(&9I;&4N#0H@(%1H92!A9&1I;F<@
M;V8@9FEL97,@:7,@9&]N92!B>2!G;VEN9R!T:')O=6=H('1H92!F:6QE+V1I
M<B!L:7-T+`T*("!A9&1I;F<@9FEL97,@<&5R(&9I;&5S+"!I;B!A(')E8W5R
M<VEV92!W87D@=&AR;W5G:"!T:&4-"B`@9&ER96-T;W)Y+B!%86-H('1I;64@
M82!P871H(&YE960@=&\@8F4@861D960O<F5M;W9E9"!I="!I<R!D;VYE#0H@
M(&)E9F]R92!W<FET:6YG('1H92!F:6QE(&AE861E<B!I;B!T:&4@87)C:&EV
M92X-"@T*365T:&]D(#H@861D*"1P7V9I;&5L:7-T*0T*1&5S8W)I<'1I;VX@
M.@T*("!4:&ES(&UE=&AO9"!A9&0@=&AE(&9I;&5S("\@9&ER96-T;W)I97,@
M;&ES=&5D(&EN("1P7V9I;&5L:7-T(&%T('1H90T*("!E;F0@;V8@=&AE(&5X
M:7-T:6YG(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@;F]T('EE="!E
M>&ES=',@:70-"B`@:7,@8W)E871E9"X@#0H@(%1H92`D<%]F:6QE;&ES="!P
M87)A;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I
M;F<-"B`@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@82!D:7)E8W1O<GD@
M;F%M92!W:71H('1H96ER('!A=&@@:68-"B`@;F5E9&5D+B!)="!C86X@86QS
M;R!B92!A('-I;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD@
M80T*("!S:6YG;&4@8FQA;FLN(`T*("!3964@861D36]D:69Y*"D@;65T:&]D
M(&9O<B!D971A:6QS(&%N9"!L:6UI=&%T:6]N<RX-"D%R9W5M96YT<R`Z#0H@
M("1P7V9I;&5L:7-T(#H@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E
M8W1O<GD@;F%M97,L(&]R(&$@<VEN9VQE#0H@('-T<FEN9R!W:71H(&YA;65S
M('-E<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X@#0I2971U<FX@
M=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*
M4V%M<&QE(#$@.@T*("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B
M=&%R;F%M92YT87(B*3L-"B`@6RXN+ET-"B`@)'9?;&ES=%LP73TB9&5V+V9I
M;&4N='AT(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL@*$]P=&EO;F%L
M("<O)R!A="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B
M.PT*("`D=&%R7V]B:F5C="T^861D*"1V7VQI<W0I.PT*4V%M<&QE(#(@.@T*
M("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT9WHB
M+"!T<G5E*3L-"B`@6RXN+ET-"B`@)'9?;&ES=%LP73TB9&5V+V9I;&4N='AT
M(CL-"B`@)'9?;&ES=%LQ73TB9&5V+V1A=&$O(CL@*$]P=&EO;F%L("<O)R!A
M="!T:&4@96YD*0T*("`D=E]L:7-T6S)=/2)L;V<O9FEL92YL;V<B.PT*("`D
M=&%R7V]B:F5C="T^861D*"1V7VQI<W0I.PT*2&]W(&ET('=O<FMS(#H-"B`@
M4VEM<&QY(&-A;&P@=&AE(&%D9$UO9&EF>2@I(&UE=&AO9"!W:71H('1H92!R
M:6=H="!P87)A;65T97)S+@T*#0I-971H;V0@.B!A9&13=')I;F<H)'!?9FEL
M96YA;64L("1P7W-T<FEN9RD-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H
M;V0@861D(&$@<VEN9VQE('-T<FEN9R!A<R!A(&9I;&4@870@=&AE#0H@(&5N
M9"!O9B!T:&4@97AI<W1I;F<@87)C:&EV92X@268@=&AE(&%R8VAI=F4@9&]E
M<R!N;W0@>65T(&5X:7-T<R!I=`T*("!I<R!C<F5A=&5D+@T*07)G=6UE;G1S
M(#H-"B`@)'!?9FEL96YA;64@.B!!('-T<FEN9R!W:&EC:"!C;VYT86EN<R!T
M:&4@9G5L;"!F:6QE;F%M92!P871H#0H@("`@("`@("`@("`@("`@=&AA="!W
M:6QL(&)E(&%S<V]C:6%T960@=VET:"!T:&4@<W1R:6YG+@T*("`D<%]S=')I
M;F<@.B`@(%1H92!C;VYT96YT(&]F('1H92!F:6QE(&%D9&5D(&EN('1H92!A
M<F-H:79E+@T*4F5T=7)N('9A;'5E(#H-"B`@=')U92!O;B!S=6-C97-S+"!F
M86QS92!O;B!E<G)O<BX-"E-A;7!L92`Q(#H-"B`@)'9?87)C:&EV92`]("8@
M;F5W($%R8VAI=F5?5&%R*"1P7V9I;&5N86UE*3L-"B`@)'9?87)C:&EV92T^
M<V5T17)R;W)(86YD;&EN9RA014%27T524D]27U!224Y4*3L-"B`@)'9?<F5S
M=6QT(#T@)'9?87)C:&EV92T^861D4W1R:6YG*"=D871A+W1E<W0N='AT)RP@
M)U1H:7,@:7,@=&AE('1E>'0@;V8@=&AE('-T<FEN9R<I.PT*#0H-"DUE=&AO
M9"`Z(&5X=')A8W0H)'!?<&%T:"`]("(B*0T*1&5S8W)I<'1I;VX@.@T*("!4
M:&ES(&UE=&AO9"!E>'1R86-T(&%L;"!T:&4@8V]N=&5N="!O9B!T:&4@87)C
M:&EV92!I;B!T:&4@9&ER96-T;W)Y#0H@(&EN9&EC871E9"!B>2`D<%]P871H
M+DEF("1P7W!A=&@@:7,@;W!T:6]N86PL(&EF(&YO="!S970@=&AE(&%R8VAI
M=F4-"B`@:7,@97AT<F%C=&5D(&EN('1H92!C=7)R96YT(&1I<F5C=&]R>2X@
M#0H@(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T:&4@9&ER96-T;W)Y
M('!A=&@@9&]E<R!N;W0@97AI<W1S(&ET(&ES#0H@(&-R96%T960N(`T*("!3
M964@97AT<F%C=$UO9&EF>2@I(&9O<B!D971A:6QS(&%N9"!L:6UI=&%T:6]N
M<RX-"D%R9W5M96YT<R`Z#0H@("1P7W!A=&@@.B!/<'1I;VYA;"!P871H('=H
M97)E('1H92!F:6QE<R]D:7(@;F5E9"!T;R!B>2!E>'1R86-T960N#0I2971U
M<FX@=F%L=64@.@T*("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R
M+@T*4V%M<&QE(#H-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H
M(G1A<FYA;64N=&%R(BD[#0H@("1T87)?;V)J96-T+3YE>'1R86-T*"D[#0I(
M;W<@:70@=V]R:W,@.@T*("!3:6UP;'D@8V%L;"!T:&4@97AT<F%C=$UO9&EF
M>2@I(&UE=&AO9"!W:71H(&%P<')O<')I871E('!A<F%M971E<G,N#0H-"DUE
M=&AO9"`Z(&5X=')A8W1-;V1I9GDH)'!?<&%T:"P@)'!?<F5M;W9E7W!A=&@I
M#0I$97-C<FEP=&EO;B`Z#0H@(%1H:7,@;65T:&]D(&5X=')A8W0@86QL('1H
M92!C;VYT96YT(&]F('1H92!A<F-H:79E(&EN('1H92!D:7)E8W1O<GD-"B`@
M:6YD:6-A=&5D(&)Y("1P7W!A=&@N(%=H96X@<F5L979A;G0@=&AE(&UE;6]R
M:7IE9"!P871H(&]F('1H90T*("!F:6QE<R]D:7(@8V%N(&)E(&UO9&EF:65D
M(&)Y(')E;6]V:6YG('1H92`D<%]R96UO=F5?<&%T:"!P871H(&%T('1H90T*
M("!B96=I;FYI;F<@;V8@=&AE(&9I;&4O9&ER('!A=&@N(`T*("!7:&EL92!E
M>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&1I<F5C=&]R>2!P871H(&1O97,@
M;F]T(&5X:7-T<R!I="!I<PT*("!C<F5A=&5D+B`-"B`@5VAI;&4@97AT<F%C
M=&EN9R!A(&9I;&4L(&EF('1H92!F:6QE(&%L<F5A9'D@97AI<W1S(&ET(&ES
M(')E<&QA8V5D#0H@('=I=&AO=70@;&]O:VEN9R!F;W(@;&%S="!M;V1I9FEC
M871I;VX@9&%T92X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T
M:&4@9FEL92!A;')E861Y(&5X:7-T<R!A;F0@:7,@=W)I=&4-"B`@<')O=&5C
M=&5D+"!T:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+B`-"B`@5VAI;&4@97AT
M<F%C=&EN9R!A(&9I;&4L(&EF(&$@9&ER96-T;W)Y('=I=&@@=&AE('-A;64@
M;F%M92!A;')E861Y#0H@(&5X:7-T<RP@=&AE(&5X=')A8W1I;VX@:7,@86)O
M<G1E9"X@#0H@(%=H:6QE(&5X=')A8W1I;F<@82!D:7)E8W1O<GDL(&EF(&$@
M9FEL92!W:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("!E>&ES=',L('1H
M92!E>'1R86-T:6]N(&ES(&%B;W)T960N(`T*("!7:&EL92!E>'1R86-T:6YG
M(&$@9FEL92]D:7)E8W1O<GD@:68@=&AE(&1E<W1I;F%T:6]N(&1I<F5C=&]R
M>2!E>&ES=`T*("!A;F0@:7,@=W)I=&4@<')O=&5C=&5D+"!O<B!D;V5S(&YO
M="!E>&ES="!B=70@8V%N(&YO="!B92!C<F5A=&5D+`T*("!T:&4@97AT<F%C
M=&EO;B!I<R!A8F]R=&5D+B`-"B`@268@869T97(@97AT<F%C=&EO;B!A;B!E
M>'1R86-T960@9FEL92!D;V5S(&YO="!S:&]W('1H92!C;W)R96-T#0H@('-T
M;W)E9"!F:6QE('-I>F4L('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960N(`T*
M("!7:&5N('1H92!E>'1R86-T:6]N(&ES(&%B;W)T960L(&$@4$5!4B!E<G)O
M<B!T97AT(&ES('-E="!A;F0@9F%L<V4-"B`@:7,@<F5T=7)N960N($AO=V5V
M97(@=&AE(')E<W5L="!C86X@8F4@82!P87)T:6%L(&5X=')A8W1I;VX@=&AA
M="!M87D-"B`@;F5E9"!T;R!B92!M86YU86QL>2!C;&5A;F5D+B`-"D%R9W5M
M96YT<R`Z#0H@("1P7W!A=&@@.B!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y
M('=H97)E('1H92!F:6QE<R]D:7(@;F5E9"!T;R!B>0T*("`@("`@("`@("`@
M97AT<F%C=&5D+B`-"B`@)'!?<F5M;W9E7W!A=&@@.B!087)T(&]F('1H92!M
M96UO<FEZ960@<&%T:"!T:&%T(&-A;B!B92!R96UO=F5D(&EF#0H@("`@("`@
M("`@("`@("`@("`@<')E<V5N="!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F
M:6QE+V1I<B!P871H+B`-"E)E='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C
M8V5S<RP@9F%L<V4@;VX@97)R;W(N#0I386UP;&4@.@T*("`O+R!);6%G:6YE
M('1A<FYA;64N=&%R('=I=&@@9FEL97,@.@T*("`O+R`@(&1E=B]D871A+V9I
M;&4N='AT#0H@("\O("`@9&5V+V1A=&$O;&]G+G1X=`T*("`O+R`@(')E861M
M92YT>'0-"B`@)'1A<E]O8FIE8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA
M;64N=&%R(BD[#0H@("1T87)?;V)J96-T+3YE>'1R86-T36]D:69Y*")I;G-T
M86QL(BP@(F1E=B(I.PT*("`O+R!&:6QE<R!W:6QL(&)E(&5X=')A8W1E9"!T
M:&5R92`Z#0H@("\O("`@:6YS=&%L;"]D871A+V9I;&4N='AT#0H@("\O("`@
M:6YS=&%L;"]D871A+VQO9RYT>'0-"B`@+R\@("!I;G-T86QL+W)E861M92YT
M>'0-"DAO=R!I="!W;W)K<R`Z#0H@($]P96X@=&AE(&%R8VAI=F4@86YD(&-A
M;&P@82!M;W)E(&=E;F5R:6,@9G5N8W1I;VX@=&AA="!C86X@97AT<F%C=`T*
M("!O;FQY(&$@<&%R="!O9B!T:&4@87)C:&EV92!O<B!A;&P@=&AE(&%R8VAI
M=F4N(`T*("!3964@97AT<F%C=$QI<W0H*2!M971H;V0@9F]R(&UO<F4@9&5T
M86EL<RX-"@T*365T:&]D(#H@97AT<F%C=$EN4W1R:6YG*"1P7V9I;&5N86UE
M*0T*1&5S8W)I<'1I;VX@.@T*("!4:&ES(&UE=&AO9"!E>'1R86-T(&9R;VT@
M=&AE(&%R8VAI=F4@;VYE(&9I;&4@:61E;G1I9FEE9"!B>2`D<%]F:6QE;F%M
M92X-"B`@5&AE(')E='5R;B!V86QU92!I<R!A('-T<FEN9R!W:71H('1H92!F
M:6QE(&-O;G1E;G0L(&]R($Y53$P@;VX@97)R;W(N(`T*07)G=6UE;G1S(#H-
M"B`@)'!?9FEL96YA;64@.B!4:&4@<&%T:"!O9B!T:&4@9FEL92!T;R!E>'1R
M86-T(&EN(&$@<W1R:6YG+B`-"E)E='5R;B!V86QU92`Z#0H@(&$@<W1R:6YG
M('=I=&@@=&AE(&9I;&4@8V]N=&5N="!O<B!.54Q,+@T*4V%M<&QE(#H-"B`@
M+R\@26UA9VEN92!T87)N86UE+G1A<B!W:71H(&9I;&5S(#H-"B`@+R\@("!D
M978O9&%T82]F:6QE+G1X=`T*("`O+R`@(&1E=B]D871A+VQO9RYT>'0-"B`@
M+R\@("!D978O<F5A9&UE+G1X=`T*("`D=E]A<F-H:79E(#T@)B!N97<@07)C
M:&EV95]487(H)W1A<FYA;64N=&%R)RD[#0H@("1V7V%R8VAI=F4M/G-E=$5R
M<F]R2&%N9&QI;F<H4$5!4E]%4E)/4E]04DE.5"D[#0H@("1V7W-T<FEN9R`]
M("1V7V%R8VAI=F4M/F5X=')A8W1);E-T<FEN9R@G9&5V+W)E861M92YT>'0G
M*3L-"B`@96-H;R`D=E]S=')I;F<[#0H-"DUE=&AO9"`Z(&QI<W1#;VYT96YT
M*"D-"D1E<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@<F5T=7)N<R!A;B!A
M<G)A>2!O9B!A<G)A>7,@=&AA="!D97-C<FEB92!E86-H#0H@(&9I;&4O9&ER
M96-T;W)Y('!R97-E;G0@:6X@=&AE(&%R8VAI=F4N(`T*("!4:&4@87)R87D@
M:7,@;F]T('-O<G1E9"P@<V\@:70@<VAO=R!T:&4@<&]S:71I;VX@;V8@=&AE
M(&9I;&4@:6X@=&AE#0H@(&%R8VAI=F4N(`T*("!4:&4@9FEL92!I;F9O<FUA
M=&EO;G,@87)E(#H-"B`@("`D9FEL95MF:6QE;F%M95T@.B!.86UE(&%N9"!P
M871H(&]F('1H92!F:6QE+V1I<BX-"B`@("`D9FEL95MM;V1E72`Z($9I;&4@
M<&5R;6ES<VEO;G,@*')E<W5L="!O9B!F:6QE<&5R;7,H*2D-"B`@("`D9FEL
M95MU:61=(#H@=7-E<B!I9`T*("`@("1F:6QE6V=I9%T@.B!G<F]U<"!I9`T*
M("`@("1F:6QE6W-I>F5=(#H@9FEL97-I>F4-"B`@("`D9FEL95MM=&EM95T@
M.B!,87-T(&UO9&EF:6-A=&EO;B!T:6UE("AR97-U;'0@;V8@9FEL96UT:6UE
M*"DI#0H@("`@)&9I;&5;='EP969L86==(#H@(B(@9F]R(&9I;&4L("(U(B!F
M;W(@9&ER96-T;W)Y#0I!<F=U;65N=',@.@T*4F5T=7)N('9A;'5E(#H-"B`@
M06X@87)R87D@;V8@87)R87ES(&]R(#`@;VX@97)R;W(N#0I386UP;&4@.@T*
M("`D=&%R7V]B:F5C="`](&YE=R!!<F-H:79E7U1A<B@B=&%R;F%M92YT87(B
M*3L-"B`@:68@*"@D=E]L:7-T("`]("`D=&%R7V]B:F5C="T^;&ES=$-O;G1E
M;G0H*2D@(3T@,"D-"B`@("!F;W(@*"1I/3`[("1I/'-I>F5O9B@D=E]L:7-T
M*3L@)&DK*RD-"B`@("![#0H@("`@("!E8VAO(")&:6QE;F%M92`Z)R(N)'9?
M;&ES=%LD:5U;9FEL96YA;65=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G-I
M>F4@.B<B+B1V7VQI<W1;)&E=6W-I>F5=+B(G/&)R/B([#0H@("`@("!E8VAO
M("(@+FUT:6UE(#HG(BXD=E]L:7-T6R1I75MM=&EM95TN(B<@*"(N#0H@("`@
M("`@("`@(&1A=&4H(FP@9%,@;V8@1B!9(&@Z:3IS($$B+"`D=E]L:7-T6R1I
M75MM=&EM95TI+B(I/&)R/B([#0H@("`@("!E8VAO("(@+FUO9&4@.B<B+B1V
M7VQI<W1;)&E=6VUO9&5=+B(G/&)R/B([#0H@("`@("!E8VAO("(@+G5I9"`Z
M)R(N)'9?;&ES=%LD:5U;=6ED72XB)SQB<CXB.PT*("`@("`@96-H;R`B("YG
M:60@.B<B+B1V7VQI<W1;)&E=6V=I9%TN(B<\8G(^(CL-"B`@("`@(&5C:&\@
M(B`N='EP969L86<@.B<B+B1V7VQI<W1;)&E=6W1Y<&5F;&%G72XB)SQB<CXB
M.PT*("`@('T-"DAO=R!I="!W;W)K<R`Z#0H@($-A;&P@=&AE('-A;64@9G5N
M8W1I;VX@87,@86X@97AT<F%C="!H;W=E=F5R('=I=&@@82!F;&%G('1O(&]N
M;'D@9V\-"B`@=&AR;W5G:"!T:&4@87)C:&EV92!W:71H;W5T(&5X=')A8W1I
M;F<@=&AE(&9I;&5S+B`-"@T*365T:&]D(#H@97AT<F%C=$QI<W0H)'!?9FEL
M96QI<W0L("1P7W!A=&@@/2`B(BP@)'!?<F5M;W9E7W!A=&@@/2`B(BD-"D1E
M<V-R:7!T:6]N(#H-"B`@5&AI<R!M971H;V0@97AT<F%C="!F<F]M('1H92!A
M<F-H:79E(&]N;'D@=&AE(&9I;&5S(&EN9&EC871E9"!I;B!T:&4-"B`@)'!?
M9FEL96QI<W0N(%1H97-E(&9I;&5S(&%R92!E>'1R86-T960@:6X@=&AE(&-U
M<G)E;G0@9&ER96-T;W)Y(&]R#0H@(&EN('1H92!D:7)E8W1O<GD@:6YD:6-A
M=&5D(&)Y('1H92!O<'1I;VYA;"`D<%]P871H('!A<F%M971E<BX@#0H@($EF
M(&EN9&EC871E9"!T:&4@)'!?<F5M;W9E7W!A=&@@8V%N(&)E('5S960@:6X@
M=&AE('-A;64@=V%Y(&%S(&ET(&ES#0H@('5S960@:6X@97AT<F%C=$UO9&EF
M>2@I(&UE=&AO9"X@#0I!<F=U;65N=',@.@T*("`D<%]F:6QE;&ES="`Z($%N
M(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@9&ER96-T;W)Y(&YA;65S+"!O<B!A
M('-I;F=L90T*("`@("`@("`@("`@("`@('-T<FEN9R!W:71H(&YA;65S('-E
M<&%R871E9"!B>2!A('-I;F=L92!B;&%N:R!S<&%C92X@#0H@("1P7W!A=&@@
M.B!4:&4@<&%T:"!O9B!T:&4@9&ER96-T;W)Y('=H97)E('1H92!F:6QE<R]D
M:7(@;F5E9"!T;R!B>0T*("`@("`@("`@("`@97AT<F%C=&5D+B`-"B`@)'!?
M<F5M;W9E7W!A=&@@.B!087)T(&]F('1H92!M96UO<FEZ960@<&%T:"!T:&%T
M(&-A;B!B92!R96UO=F5D(&EF#0H@("`@("`@("`@("`@("`@("`@<')E<V5N
M="!A="!T:&4@8F5G:6YN:6YG(&]F('1H92!F:6QE+V1I<B!P871H+B`-"E)E
M='5R;B!V86QU92`Z#0H@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R
M;W(N#0I386UP;&4@.@T*("`O+R!);6%G:6YE('1A<FYA;64N=&%R('=I=&@@
M9FEL97,@.@T*("`O+R`@(&1E=B]D871A+V9I;&4N='AT#0H@("\O("`@9&5V
M+V1A=&$O;&]G+G1X=`T*("`O+R`@(')E861M92YT>'0-"B`@)'1A<E]O8FIE
M8W0@/2!N97<@07)C:&EV95]487(H(G1A<FYA;64N=&%R(BD[#0H@("1T87)?
M;V)J96-T+3YE>'1R86-T3&ES="@B9&5V+V1A=&$O9FEL92YT>'0@<F5A9&UE
M+G1X="(L(")I;G-T86QL(BP-"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M(")D978B*3L-"B`@+R\@1FEL97,@=VEL;"!B92!E>'1R86-T960@=&AE<F4@
M.@T*("`O+R`@(&EN<W1A;&PO9&%T82]F:6QE+G1X=`T*("`O+R`@(&EN<W1A
M;&PO<F5A9&UE+G1X=`T*2&]W(&ET('=O<FMS(#H-"B`@1V\@=&AR;W5G:"!T
M:&4@87)C:&EV92!A;F0@97AT<F%C="!O;FQY('1H92!F:6QE<R!P<F5S96YT
M(&EN('1H90T*("!L:7-T+B`-"@T*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TYE=%]5
M4DPO9&]C<P``````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,R(#`R,34S,0`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D
M92]P96%R+V1O8W,O3F5T7U523"]D;V-S+V5X86UP;&4N<&AP````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#8S-C0@,3`U,34T,S0Q,S(@,#(S-S8U`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````#P_<&AP
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG
M:'0@*&,I(#(P,#(M,C`P,RP@4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@06QL(')I9VAT<R!R97-E
M<G9E9"X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA
M<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U="`@("!\"B\O('P@;6]D:69I8V%T
M:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN
M9R!C;VYD:71I;VYS("`@('P*+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@;R!2
M961I<W1R:6)U=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE
M(&%B;W9E(&-O<'ER:6=H="`@("`@('P*+R\@?"`@(&YO=&EC92P@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX@("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F
M;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\"B\O
M('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE('P*+R\@?"`@(&1O8W5M96YT
M871I;VX@86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H
M92!D:7-T<FEB=71I;VXN?"`*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T
M:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@
M("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A
M<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\"B\O('P@("!P
M97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@
M5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\"B\O
M('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y4
M2453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P*+R\@?"!,24U)5$5$(%1/
M+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E462!!
M3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%2
M12!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4
M("!\"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P*+R\@?"!34$5#
M24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@1$%-04=%4R`H24Y#
M3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\($Q)34E4140@5$\L(%!23T-5
M4D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@
M3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@
M24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P*+R\@
M?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52($E.($-/3E1204-4+"!3
M5%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`HO+R!\("A)3D-,541)3D<@
M3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/
M550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)
M1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@
M('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R.B!2:6-H87)D($AE
M>65S(#QR:6-H87)D(&%T('!H<"!N970^("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R`D
M260Z(&5X86UP;&4N<&AP+'8@,2XY(#(P,#0O,#4O,#@@,3<Z-#@Z,#@@<FEC
M:&%R9"!%>'`@)`HO*BH**B!4:&ES(&5X86UP;&4@=VEL;"!D96-O9&4@=&AE
M('5R;"!G:79E;B!A;F0@9&ES<&QA>2!I=',**B!C;VYS=&ET=65N="!P87)T
M<RX**B\*"B\O"6EN8VQU9&4H)RXN+U523"YP:'`G*3L*"6EN8VQU9&4H)TYE
M="]54DPN<&AP)RD["@H)+R\D=7)L(#T@)FYE=R!.971?55),*"=H='1P<SHO
M+W=W=RYE>&%M<&QE+F-O;2]F;V\O8F%R+VEN9&5X+G!H<#]F;V\]8F%R)RD[
M"@DD=7)L(#T@;F5W($YE=%]54DPH)VAT='!S.B\O97AA;7!L92YC;VTO<&QS
M+W!O<G1A;#,P+U!/4E1!3#,P+G=W<&]B7W!A9V4N8VAA;F=E=&%B<S]P7V)A
M8VM?=7)L/6AT='`E,T$E,D8E,D9E>&%M<&QE+F-O;24R1G-E<G9L970E,D9P
M86=E)3-&7W!A9V5I9"4S1#,V,"4R0S,V-B4R0S,V."4R0S,X,B4R-E]D860E
M,T1P;W)T86PS,"4R-E]S8VAE;6$E,T103U)404PS,"9F;V\]8F%R)RD["C\^
M"CQH=&UL/@H\8F]D>3X*"CQP<F4^"E!R;W1O8V]L+BXN.B`\/STD=7)L+3YP
M<F]T;V-O;#\^"@I5<V5R;F%M92XN+CH@/#\])'5R;"T^=7-E<C\^"@I087-S
M=V]R9"XN+CH@/#\])'5R;"T^<&%S<S\^"@I397)V97(N+BXN+CH@/#\])'5R
M;"T^:&]S=#\^"@I0;W)T+BXN+BXN+CH@/#\])'5R;"T^<&]R=#\^"@I&:6QE
M+W!A=&@N+CH@/#\])'5R;"T^<&%T:#\^"@I1=65R>7-T<FEN9SH@/#]P<FEN
M=%]R*"1U<FPM/G%U97)Y<W1R:6YG*3\^"@I!;F-H;W(N+BXN+CH@/#\])'5R
M;"T^86YC:&]R/SX*"@I&=6QL(%523"XN+CH@/#\])'5R;"T^9V5T57)L*"D_
M/@H\+W!R93X*"CPO8F]D>3X*/"]H=&UL/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R
M9&4O<&5A<B]D;V-S+T1A=&4O3$E#14Y310``````````````````````````
M`````````````````````````````````````````````#`P,#8T-"``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`R-3`W(#$P-3$U-#,T,3,R(#`R,3(W-@`@
M,```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!2961I
M<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS
M+"!W:71H(&]R('=I=&AO=70@;6]D:69I8V%T:6]N"BP@87)E('!E<FUI='1E
M9"!P<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R!A<F4@
M;65T.@H*,2X@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E(&UU<W0@
M<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T:6-E+"!T:`H@("!I<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<BX*"C(N(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E
M<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT(&YO=&EC92P*("`@=&AI<R!L
M:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE
M<B!I;B!T:&4@9&]C=6UE;G1A=&EO;B!A;F0O"B`@(&]R(&]T:&5R(&UA=&5R
M:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T<FEB=71I;VXN"@HS+B!4:&4@
M;F%M92!O9B!T:&4@875T:&]R(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E
M(&]R('!R;VUO=&4@<')O9'5C=',@9&5R:79E9`H@("!F<F]M('1H:7,@<V]F
M='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N('!E<FUI<W-I
M;VXN"@I42$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!!551(3U(@
M8&!!4R!)4R<G($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!"E)204Y4
M2453+"!)3D-,541)3D<L($)55"!.3U0@3$E-251%1"!43RP@5$A%($E-4$Q)
M140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24P*2519($%.1"!&251.15-3
M($9/4B!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@
M3D\@159%3E0@4TA!3$P@5$A%(`I!551(3U(@0D4@3$E!0DQ%($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4B!#"D].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)5
M5"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412`*
M1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@55-%+"!$051!+"!/4B!04D]&
M2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5PI%5D52($-!55-%
M1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@
M0T].5%)!0U0L(%-44DE#5"!,24%"24Q)"E19+"!/4B!43U)4("A)3D-,541)
M3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!
M62!/550@3T8@5$A%(%4*4T4@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!
M1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1&%T92]43T1/
M````````````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S
M-S(@,3`U,34T,S0Q,S(@,#(P-S4W`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"T@1FEX(&]N8V4@=&AE('1I;65Z;VYE('!R
M;V)L96T*"BT@3VYC92!46B!W;W)K<R!N:6-E;'DL('5P9&%T92!T:&4@=&5S
M='5N:71?9&%T92!A;F0@=7-E"B`@=&AE(')E86P@=&EM97IO;F4@86YD(&1C
M="!T;R!C:&5C:R!T:&4@97AP96-T960@=&EM92!O9F9S970*"BT@0VQE86X@
M=&AE('1E<W0@8V%S97,@86YD(&%T;VUI8R!D:7-P;&%Y(&EN<W1E860@;V8@
M82!G;&]B86P@;VL@;W(@9F%I;&5D"@HM('=R:71E('1H92!D;V-S+BXN+@H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,R(#`R,3`P,@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G
M+V1O8W,O97AA;7!L97,`````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S(@,#(R-C(P`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R],;V<O9&]C<R]G=6ED92YT>'0`````````````````
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#$R-#4P,"`Q,#4Q-30S-#$S,B`P,C(W,C$`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/3T]
M/3T]/3T]/3T]/3T]/3T*(%1H92!,;V<@4&%C:V%G90H]/3T]/3T]/3T]/3T]
M/3T]/0H*+2TM+2TM+2TM+2TM+2TM+2TM+2T*(%5S97(@1&]C=6UE;G1A=&EO
M;@HM+2TM+2TM+2TM+2TM+2TM+2TM+0H*.D%U=&AO<CH@("`@("`@($IO;B!0
M87)I<V4*.D-O;G1A8W0Z("`@("`@(&IO;D!P:'`N;F5T"CI$871E.B`@("`@
M("`@("`D1&%T93H@,C`P-B\P-"\R,2`P-3HR-3HP.2`D"CI2979I<VEO;CH@
M("`@("`D4F5V:7-I;VXZ(#$N,C4@)`H*+BX@8V]N=&5N=',Z.B!#;VYT96YT
M<PHN+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I5<VEN9R!,;V<@2&%N9&QE<G,*
M/3T]/3T]/3T]/3T]/3T]/3T]"@I4:&4@3&]G('!A8VMA9V4@:7,@:6UP;&5M
M96YT960@87,@82!F<F%M97=O<FL@=&AA="!S=7!P;W)T<R!T:&4@;F]T:6]N
M(&]F"F)A8VME;F0M<W!E8VEF:6,@;&]G(&AA;F1L97)S+B`@5&AE(&)A<V4@
M;&]G9VEN9R!O8FIE8W0@*&1E9FEN960@8GD@=&AE(&!,;V<*8VQA<W-@7RD@
M:7,@<')I;6%R:6QY(&%N(&%B<W1R86-T(&EN=&5R9F%C92!T;R!T:&4@8W5R
M<F5N=&QY(&-O;F9I9W5R960*:&%N9&QE<BX*"D$@=VED92!V87)I971Y(&]F
M(&AA;F1L97)S(&%R92!D:7-T<FEB=71E9"!W:71H('1H92!,;V<@<&%C:V%G
M92P@86YD+"!S:&]U;&0*;F]N92!O9B!T:&5M(&9I="!Y;W5R(&%P<&QI8V%T
M:6]N)W,@;F5E9',L(&ET)W,@96%S>2!T;R!@=W)I=&4@>6]U<B!O=VY@7U\N
M"@HN+B!?3&]G(&-L87-S.B!H='1P.B\O8W9S+G!H<"YN970O8V\N<&AP+W!E
M87(O3&]G+TQO9RYP:'`*7U\@8$-U<W1O;2!(86YD;&5R<V!?"@I#<F5A=&EN
M9R!A($QO9R!/8FIE8W0*+2TM+2TM+2TM+2TM+2TM+2TM+2TM"E1H97)E(&%R
M92!T:')E92!W87ES('1O(&-R96%T92!,;V<@;V)J96-T<SH*"B`@("`M(%5S
M:6YG('1H92!@8$QO9SHZ9F%C=&]R>2@I8&`@;65T:&]D"B`@("`M(%5S:6YG
M('1H92!@8$QO9SHZ<VEN9VQE=&]N*"E@8"!M971H;V0*("`@("T@1&ER96-T
M(&EN<W1A;G1I871I;VX*"E1H92!&86-T;W)Y($UE=&AO9`I^?GY^?GY^?GY^
M?GY^?GY^?GX*5&AE(&!@3&]G.CIF86-T;W)Y*"E@8"!M971H;V0@:6UP;&5M
M96YT<R!T:&4@8$9A8W1O<GD@4&%T=&5R;F!?+B`@270@86QL;W=S"F9O<B!T
M:&4@<&%R86UE=&5R:7IE9"!C;VYS=')U8W1I;VX@;V8@8V]N8W)E=&4@3&]G
M(&EN<W1A;F-E<R!A="!R=6YT:6UE+B`@5&AE"F9I<G-T('!A<F%M971E<B!T
M;R!T:&4@8&!,;V<Z.F9A8W1O<GDH*6!@(&UE=&AO9"!I;F1I8V%T97,@=&AE
M(&YA;64@;V8@=&AE"F-O;F-R971E(&AA;F1L97(@=&\@8W)E871E+B`@5&AE
M(')E<W0@;V8@=&AE('!A<F%M971E<G,@=VEL;"!B92!P87-S960@;VX@=&\*
M=&AE(&AA;F1L97(G<R!C;VYS=')U8W1O<B`H<V5E(&!#;VYF:6=U<FEN9R!A
M($AA;F1L97)@7R!B96QO=RDN"@I4:&4@;F5W(&!@3&]G8&`@:6YS=&%N8V4@
M:7,@<F5T=7)N960@8GD@<F5F97)E;F-E+@H*.CH*"B`@("!R97%U:7)E7V]N
M8V4@)TQO9RYP:'`G.PH*("`@("1C;VYS;VQE(#T@)DQO9SHZ9F%C=&]R>2@G
M8V]N<V]L92<L("<G+"`G5$535"<I.PH@("`@)&-O;G-O;&4M/FQO9R@G3&]G
M9VEN9R!T;R!T:&4@8V]N<V]L92XG*3L*"B`@("`D9FEL92`]("9,;V<Z.F9A
M8W1O<GDH)V9I;&4G+"`G;W5T+FQO9R<L("=415-4)RD["B`@("`D9FEL92T^
M;&]G*"=,;V=G:6YG('1O(&]U="YL;V<N)RD["@HN+B!?1F%C=&]R>2!0871T
M97)N.B!H='1P.B\O=W=W+G!H<'!A='1E<FYS+F-O;2]I;F1E>"YP:'`O87)T
M:6-L92]A<G1I8VQE=FEE=R\T.2\Q+S$O"@I4:&4@4VEN9VQE=&]N($UE=&AO
M9`I^?GY^?GY^?GY^?GY^?GY^?GY^?@I4:&4@8&!,;V<Z.G-I;F=L971O;B@I
M8&`@;65T:&]D(&EM<&QE;65N=',@=&AE(&!3:6YG;&5T;VX@4&%T=&5R;F!?
M+B`@5&AE"G-I;F=L971O;B!P871T97)N(&5N<W5R97,@=&AA="!O;FQY(&$@
M<VEN9VQE(&EN<W1A;F-E(&]F(&$@9VEV96X@;&]G('1Y<&4@86YD"F-O;F9I
M9W5R871I;VX@:7,@979E<B!C<F5A=&5D+B`@5&AI<R!H87,@='=O(&)E;F5F
M:71S.B!F:7)S="P@:70@<')E=F5N=',*9'5P;&EC871E(&!@3&]G8&`@:6YS
M=&%N8V5S(&9R;VT@8F5I;F<@8V]N<W1R=6-T960L(&%N9"P@<V5C;VYD+"!I
M="!G:79E<R!A;&P*;V8@>6]U<B!C;V1E(&%C8V5S<R!T;R!T:&4@<V%M92!@
M8$QO9V!@(&EN<W1A;F-E+B`@5&AE(&QA='1E<B!I<R!E<W!E8VEA;&QY"FEM
M<&]R=&%N="!W:&5N(&QO9V=I;F<@=&\@9FEL97,@8F5C875S92!O;FQY(&$@
M<VEN9VQE(&9I;&4@:&%N9&QE<B!W:6QL(&YE960*=&\@8F4@;6%N86=E9"X*
M"E1H92!@8$QO9SHZ<VEN9VQE=&]N*"E@8"!M971H;V0G<R!P87)A;65T97)S
M(&UA=&-H('1H92!@8$QO9SHZ9F%C=&]R>2@I8&`*;65T:&]D+B`@5&AE(&YE
M=R!@8$QO9V!@(&EN<W1A;F-E(&ES(')E='5R;F5D(&)Y(')E9F5R96YC92X*
M"CHZ"@H@("`@<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B`@("`O*B!386UE
M(&-O;G-T<G5C=&EO;B!P87)A;65T97)S("HO"B`@("`D82`]("9,;V<Z.G-I
M;F=L971O;B@G8V]N<V]L92<L("<G+"`G5$535"<I.PH@("`@)&(@/2`F3&]G
M.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0G*3L*"B`@("!I9B`H
M)&$@/3T]("1B*2!["B`@("`@("`@96-H;R`G)&$@86YD("1B('!O:6YT('1O
M('1H92!S86UE($QO9R!I;G-T86YC92XG("X@(EQN(CL*("`@('T*"B`@("`O
M*B!$:69F97)E;G0@8V]N<W1R=6-T:6]N('!A<F%M971E<G,@*B\*("`@("1C
M(#T@)DQO9SHZ<VEN9VQE=&]N*"=C;VYS;VQE)RP@)R<L("=415-4,2<I.PH@
M("`@)&0@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0R
M)RD["@H@("`@:68@*"1C("$]/2`D9"D@>PH@("`@("`@(&5C:&\@)R1C(&%N
M9"`D9"!P;VEN="!T;R!D:69F97)E;G0@3&]G(&EN<W1A;F-E<RXG("X@(EQN
M(CL*("`@('T*"BXN(%]3:6YG;&5T;VX@4&%T=&5R;CH@:'1T<#HO+W=W=RYP
M:'!P871T97)N<RYC;VTO:6YD97@N<&AP+V%R=&EC;&4O87)T:6-L979I97<O
M-B\Q+S$O"@I$:7)E8W0@26YS=&%N=&EA=&EO;@I^?GY^?GY^?GY^?GY^?GY^
M?GY^?@I)="!I<R!A;'-O('!O<W-I8FQE('1O(&1I<F5C=&QY(&EN<W1A;G1I
M871E(&-O;F-R971E(&!@3&]G8&`@:&%N9&QE<@II;G-T86YC97,N("!(;W=E
M=F5R+"!T:&ES(&UE=&AO9"!I<R`J*FYO="!R96-O;6UE;F1E9"HJ(&)E8V%U
M<V4@:70@8W)E871E<R!A"G1I9VAT97(@8V]U<&QI;F<@8F5T=V5E;B!Y;W5R
M(&%P<&QI8V%T:6]N(&-O9&4@86YD('1H92!,;V<@<&%C:V%G92!T:&%N(&ES
M"FYE8V5S<V%R>2X@(%5S92!O9B!@=&AE(&9A8W1O<GD@;65T:&]D8%\@;W(@
M8'1H92!S:6YG;&5T;VX@;65T:&]D8%\@:7,*<')E9F5R<F5D+@H*"D-O;F9I
M9W5R:6YG(&$@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*02!L;V<@
M:&%N9&QE<B=S(&-O;F9I9W5R871I;VX@:7,@9&5T97)M:6YE9"!B>2!T:&4@
M87)G=6UE;G1S('5S960@:6X@:71S"F-O;G-T<G5C=&EO;BX@($AE<F4G<R!A
M;B!O=F5R=FEE=R!O9B!T:&]S92!P87)A;65T97)S.CH*"B`@("`O*B!5<VEN
M9R!T:&4@9F%C=&]R>2!M971H;V0@+BXN("HO"B`@("`F3&]G.CIF86-T;W)Y
M*"1H86YD;&5R+"`D;F%M92P@)&ED96YT+"`D8V]N9BP@)&UA>$QE=F5L*3L*
M"B`@("`O*B!5<VEN9R!T:&4@<VEN9VQE=&]N(&UE=&AO9"`N+BX@*B\*("`@
M("9,;V<Z.G-I;F=L971O;B@D:&%N9&QE<BP@)&YA;64L("1I9&5N="P@)&-O
M;F8L("1M87A,979E;"D["@H@("`@+RH@57-I;F<@9&ER96-T(&EN<W1A;G1I
M871I;VX@+BXN("HO"B`@("!N97<@3&]G7VAA;F1L97(H)&YA;64L("1I9&5N
M="P@)&-O;F8L("1M87A,979E;"D["@HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@?"!4>7!E("`@("`@?"!$97-C
M<FEP=&EO;B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK
M/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@)&AA;F1L97)@
M8"`@?"!3=')I;F<@("`@?"!4:&4@='EP92!O9B!,;V<@:&%N9&QE<B!T;R!C
M;VYS=')U8W0N("!4:&ES("`@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@
M("`@?"!P87)A;65T97(@:7,@;VYL>2!A=F%I;&%B;&4@=VAE;B!@=&AE(&9A
M8W1O<GD@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!M971H;V1@
M7R!O<B!@=&AE('-I;F=L971O;B!M971H;V1@7R!A<F4@=7-E9"X@?`HK+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@)&YA;65@8"`@("`@
M?"!3=')I;F<@("`@?"!4:&4@;F%M92!O9B!T:&4@;&]G(')E<V]U<F-E('1O
M('=H:6-H('1H92`@("`@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"!E=F5N=',@=VEL;"!B92!L;V=G960N("!4:&4@=7-E(&]F('1H:7,@=F%L
M=64@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!I<R!D971E<FUI
M;F5D(&)Y('1H92!H86YD;&5R)W,@:6UP;&5M96YT871I;VXN?`I\("`@("`@
M("`@("`@("`@?"`@("`@("`@("`@?"!)="!D969A=6QT<R!T;R!A;B!E;7!T
M>2!S=')I;F<N("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@)&ED96YT8&`@("`@?"!3=')I;F<@("`@?"!!
M;B!I9&5N=&EF:6-A=&EO;B!S=')I;F<@=&AA="!W:6QL(&)E(&EN8VQU9&5D
M?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!I;B!A;&P@;&]G(&5V
M96YT<R!L;V=G960@8GD@=&AI<R!H86YD;&5R+B`@("`@?`I\("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"!4:&ES('9A;'5E(&1E9F%U;'1S('1O(&%N
M(&5M<'1Y('-T<FEN9R!A;F0@8V%N?`I\("`@("`@("`@("`@("`@?"`@("`@
M("`@("`@?"!B92!C:&%N9V5D(&%T(')U;G1I;64@=7-I;F<@=&AE(&!@<V5T
M261E;G0H*6!@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"!M971H
M;V0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@)&-O;F9@8"`@
M("`@?"!!<G)A>2`@("`@?"!!<W-O8VEA=&EV92!A<G)A>2!O9B!K97DM=F%L
M=64@<&%I<G,@=&AA="!A<F4@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@
M("`@?"!U<V5D('1O('-P96-I9GD@86YY(&AA;F1L97(M<W!E8VEF:6,@<V5T
M=&EN9W,N?`HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M)&QE=F5L8&`@("`@?"!);G1E9V5R("`@?"!,;V<@;65S<V%G97,@=7`@=&\@
M86YD(&EN8VQU9&EN9R!T:&ES(&QE=F5L+B`@?`I\("`@("`@("`@("`@("`@
M?"`@("`@("`@("`@?"!4:&ES('9A;'5E(&1E9F%U;'1S('1O(&!@4$5!4E],
M3T=?1$5"54=@8"X@("`@?`I\("`@("`@("`@("`@("`@?"`@("`@("`@("`@
M?"!3964@8$QO9R!,979E;'-@7R!A;F0@8$QO9R!,979E;"!-87-K<V!?+B`@
M("`@?`HK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*"DQO9V=I
M;F<@86X@179E;G0*+2TM+2TM+2TM+2TM+2TM+0I%=F5N=',@87)E(&QO9V=E
M9"!U<VEN9R!T:&4@8&!L;V<H*6!@(&UE=&AO9#HZ"@H@("`@)&QO9V=E<BT^
M;&]G*"=-97-S86=E)RP@4$5!4E],3T=?3D]424-%*3L*"E1H92!F:7)S="!A
M<F=U;65N="!C;VYT86EN<R!T:&4@;&]G(&5V96YT)W,@;65S<V%G92X@($5V
M96X@=&AO=6=H('1H92!E=F5N="!I<PIA;'=A>7,@;&]G9V5D(&%S(&$@<W1R
M:6YG+"!I="!I<R!P;W-S:6)L92!T;R!P87-S(&%N(&]B:F5C="!T;R!T:&4@
M8&!L;V<H*6!@"FUE=&AO9"X@($EF('1H92!O8FIE8W0@:6UP;&5M96YT<R!A
M(&!@9V5T4W1R:6YG*"E@8"!M971H;V0L(&$@8&!T;U-T<FEN9R@I8&`*;65T
M:&]D(&]R(%IE;F0@16YG:6YE(#(G<R!S<&5C:6%L(&!@7U]T;U-T<FEN9R@I
M8&`@8V%S=&EN9R!M971H;V0L(&ET('=I;&P@8F4*=7-E9"!T;R!D971E<FUI
M;F4@=&AE(&]B:F5C="=S('-T<FEN9R!R97!R97-E;G1A=&EO;BX@($]T:&5R
M=VES92P@=&AE"F!S97)I86QI>F5D8%\@9F]R;2!O9B!T:&4@;V)J96-T('=I
M;&P@8F4@;&]G9V5D+@H*5&AE('-E8V]N9"P@;W!T:6]N86P@87)G=6UE;G0@
M<W!E8VEF:65S('1H92!L;V<@979E;G0G<R!P<FEO<FET>2X@(%-E92!T:&4*
M8$QO9R!,979E;'-@7R!T86)L92!F;W(@=&AE(&-O;7!L971E(&QI<W0@;V8@
M<')I;W)I=&EE<RX@(%1H92!D969A=6QT('!R:6]R:71Y"FES(%!%05)?3$]'
M7TE.1D\N"@I4:&4@8&!L;V<H*6!@(&UE=&AO9"!W:6QL(')E='5R;B!@8'1R
M=65@8"!I9B!T:&4@979E;G0@=V%S('-U8V-E<W-F=6QL>0IL;V=G960N"@HB
M4VAO<G1C=70B(&UE=&AO9',@87)E(&%L<V\@879A:6QA8FQE(&9O<B!L;V=G
M:6YG(&%N(&5V96YT(&%T(&$@<W!E8VEF:6,@;&]G"FQE=F5L+B`@4V5E('1H
M92!@3&]G($QE=F5L<V!?('1A8FQE(&9O<B!T:&4@8V]M<&QE=&4@;&ES="X*
M"BXN(%]S97)I86QI>F5D.B!H='1P.B\O=W=W+G!H<"YN970O<V5R:6%L:7IE
M"@H*3&]G($QE=F5L<PHM+2TM+2TM+2TM"E1H:7,@=&%B;&4@:7,@;W)D97)E
M9"!B>2!H:6=H97-T('!R:6]R:71Y("A@8%!%05)?3$]'7T5-15)'8&`I('1O
M(&QO=V5S=`IP<FEO<FET>2`H8&!014%27TQ/1U]$14)51V!@*2X*"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@3&5V96P@("`@("`@("`@
M("`@("`@('P@4VAO<G1C=70@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@
M("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]
M/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3TK"GP@8&!014%27TQ/1U]%34521V!@("`@('P@8&!E;65R9R@I8&`@("!\
M(%-Y<W1E;2!I<R!U;G5S86)L92`@("`@("`@("`@("`@("!\"BLM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U]!3$525&!@
M("`@('P@8&!A;&5R="@I8&`@("!\($EM;65D:6%T92!A8W1I;VX@<F5Q=6ER
M960@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"GP@8&!014%27TQ/1U]#4DE48&`@("`@('P@8&!C<FET*"E@8"`@("!\($-R
M:71I8V%L(&-O;F1I=&EO;G,@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U]%4E)@8"`@("`@
M('P@8&!E<G(H*6!@("`@("!\($5R<F]R(&-O;F1I=&EO;G,@("`@("`@("`@
M("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@
M8&!014%27TQ/1U]705).24Y'8&`@('P@8&!W87)N:6YG*"E@8"!\(%=A<FYI
M;F<@8V]N9&ET:6]N<R`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U].3U1)0T5@8"`@('P@
M8&!N;W1I8V4H*6!@("!\($YO<FUA;"!B=70@<VEG;FEF:6-A;G0@("`@("`@
M("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!0
M14%27TQ/1U])3D9/8&`@("`@('P@8&!I;F9O*"E@8"`@("!\($EN9F]R;6%T
M:6]N86P@("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&!014%27TQ/1U]$14)51V!@("`@('P@8&!D
M96)U9R@I8&`@("!\($1E8G5G+6QE=F5L(&UE<W-A9V5S("`@("`@("`@("`@
M("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@H*3&]G($QE
M=F5L($UA<VMS"BTM+2TM+2TM+2TM+2TM+0I$969I;FEN9R!A(&QO9R!L979E
M;"!M87-K(&%L;&]W<R!Y;W4@=&\@:6YC;'5D92!A;F0O;W(@97AC;'5D92!S
M<&5C:69I8R!L979E;',*;V8@979E;G1S(&9R;VT@8F5I;F<@;&]G9V5D+B`@
M5&AE(&!@)&QE=F5L8&`@8V]N<W1R=6-T:6]N('!A<F%M971E<B`H<V5E"F!#
M;VYF:6=U<FEN9R!A($AA;F1L97)@7RD@=7-E<R!T:&ES(&UE8VAA;FES;2!T
M;R!E>&-L=61E(&QO9R!E=F5N=',@8F5L;W<@80IC97)T86EN('!R:6]R:71Y
M+"!A;F0@:70G<R!P;W-S:6)L92!T;R!D969I;F4@;6]R92!C;VUP;&5X(&UA
M<VMS(&]N8V4@=&AE($QO9PIO8FIE8W0@:&%S(&)E96X@8V]N<W1R=6-T960N
M"@I%86-H('!R:6]R:71Y(&AA<R!A('-P96-I9FEC(&UA<VL@87-S;V-I871E
M9"!W:71H(&ET+B`@5&\@8V]M<'5T92!A('!R:6]R:71Y)W,*;6%S:RP@=7-E
M('1H92!S=&%T:6,@8&!,;V<Z.DU!4TLH*6!@(&UE=&AO9#HZ"@H@("`@)&UA
M<VL@/2!,;V<Z.DU!4TLH4$5!4E],3T=?24Y&3RD["@I4;R!C;VUP=71E('1H
M92!M87-K(&9O<B!A;&P@<')I;W)I=&EE<R!U<"!T;RP@86YD(&EN8VQU9&EN
M9RP@82!C97)T86EN(&QE=F5L+`IU<V4@=&AE(&!@3&]G.CI-05@H*6!@('-T
M871I8R!M971H;V0Z.@H*("`@("1M87-K(#T@3&]G.CI-05@H4$5!4E],3T=?
M24Y&3RD["@I4;R!C;VUP=71E('1H92!M87-K(&9O<B!A;&P@<')I;W)I=&EE
M<R!G<F5A=&5R('1H86X@;W(@97%U86P@=&\@82!C97)T86EN"FQE=F5L+"!U
M<V4@=&AE(&!@3&]G.CI-24XH*6!@('-T871I8R!M971H;V0Z.@H*("`@("1M
M87-K(#T@3&]G.CI-24XH4$5!4E],3T=?24Y&3RD["@I4:&4@87!P;'D@=&AE
M(&UA<VLL('5S92!T:&4@8&!S971-87-K*"E@8"!M971H;V0Z.@H*("`@("1L
M;V=G97(M/G-E=$UA<VLH)&UA<VLI.PH*36%S:W,@8V%N(&)E(&)E(&-O;6)I
M;F5D('5S:6YG(&)I='=I<V4@;W!E<F%T:6]N<RX@(%1O(')E<W1R:6-T(&QO
M9V=I;F<@=&\*;VYL>2!T:&]S92!E=F5N=',@;6%R:V5D(&%S(&!@4$5!4E],
M3T=?3D]424-%8&`@;W(@8&!014%27TQ/1U]$14)51V!@.CH*"B`@("`D;6%S
M:R`]($QO9SHZ34%32RA014%27TQ/1U].3U1)0T4I('P@3&]G.CI-05-+*%!%
M05)?3$]'7T1%0E5'*3L*("`@("1L;V=G97(M/G-E=$UA<VLH)&UA<VLI.PH*
M1F]R(&-O;G9E;FEE;F-E+"!T=V\@<W!E8VEA;"!M87-K<R!A<F4@<')E9&5F
M:6YE9#H@8&!014%27TQ/1U].3TY%8&`@86YD"F!@4$5!4E],3T=?04Q,8&`N
M("!@8%!%05)?3$]'7T%,3&!@(&ES(&5S<&5C:6%L;'D@=7-E9G5L(&9O<B!E
M>&QU9&EN9R!O;FQY"G-P96-I9FEC('!R:6]R:71I97,Z.@H*("`@("1M87-K
M(#T@4$5!4E],3T=?04Q,(%X@3&]G.CI-05-+*%!%05)?3$]'7TY/5$E#12D[
M"B`@("`D;&]G9V5R+3YS971-87-K*"1M87-K*3L*"DET(&ES(&%L<V\@<&]S
M<VEB;&4@=&\@<F5T<FEE=F4@86YD(&UO9&EF>2!A($QO9R!O8FIE8W0G<R!E
M>&ES=&EN9R!M87-K.CH*"B`@("`D;6%S:R`]("1L;V=G97(M/F=E=$UA<VLH
M*2!\($QO9SHZ34%32RA014%27TQ/1U])3D9/*3L*("`@("1L;V=G97(M/G-E
M=$UA<VLH)&UA<VLI.PH*"D9L=7-H:6YG($QO9R!%=F5N=',*+2TM+2TM+2TM
M+2TM+2TM+2TM+0I3;VUE(&QO9R!H86YD;&5R<R`H<W5C:"!A<R!@=&AE(&-O
M;G-O;&4@:&%N9&QE<F!?*2!S=7!P;W)T(&5X<&QI8VET"B)B=69F97)I;F<B
M+B`@5VAE;B!B=69F97)I;F<@:7,@96YA8FQE9"P@;&]G(&5V96YT<R!W;VXG
M="!A8W1U86QL>2!B92!W<FET=&5N"G1O('1H92!O=71P=70@<W1R96%M('5N
M=&EL('1H92!H86YD;&5R(&ES(&-L;W-E9"X@($]T:&5R(&AA;F1L97)S("AS
M=6-H(&%S"F!T:&4@9FEL92!H86YD;&5R8%\I('-U<'!O<G0@:6UP;&EC:70@
M8G5F9F5R:6YG(&)E8V%U<V4@=&AE>2!U<V4@=&AE(&]P97)A=&EN9PIS>7-T
M96TG<R!)3R!R;W5T:6YE<RP@=VAI8V@@;6%Y(&)U9F9E<B!T:&4@;W5T<'5T
M+@H*270G<R!P;W-S:6)L92!T;R!F;W)C92!T:&5S92!H86YD;&5R<R!T;R!F
M;'5S:"!T:&5I<B!O=71P=70L(&AO=V5V97(L(&)Y"F-A;&QI;F<@=&AE:7(@
M8&!F;'5S:"@I8&`@;65T:&]D.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=B=69F
M97)I;F<G(#T^('1R=64I.PH@("`@)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O
M;B@G8V]N<V]L92<L("<G+"`G=&5S="<L("1C;VYF*3L*"B`@("!F;W(@*"1I
M(#T@,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@G
M5&AI<R!E=F5N="!W:6QL(&)E(&)U9F9E<F5D+B<I.PH@("`@?0H*("`@("\J
M($9L=7-H(&%L;"!O9B!T:&4@8G5F9F5R960@;&]G(&5V96YT<RX@*B\*("`@
M("1L;V=G97(M/F9L=7-H*"D["@H@("`@9F]R("@D:2`](#`[("1I(#P@,3`[
M("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H)U1H:7,@979E;G0@=VEL
M;"!B92!B=69F97)E9"XG*3L*("`@('T*"B`@("`O*B!);7!L:6-I=&QY(&9L
M=7-H('1H92!B=69F97)E9"!E=F5N=',@;VX@8VQO<V4N("HO"B`@("`D;&]G
M9V5R+3YC;&]S92@I.PH*070@=&AI<R!T:6UE+"!T:&4@8&!F;'5S:"@I8&`@
M;65T:&]D(&ES(&]N;'D@:6UP;&5M96YT960@8GD@8'1H92!C;VYS;VQE"FAA
M;F1L97)@7RP@8'1H92!F:6QE(&AA;F1L97)@7R!A;F0@8'1H92!M86EL(&AA
M;F1L97)@7RX*"@I3=&%N9&%R9"!,;V<@2&%N9&QE<G,*/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"@I4:&4@0V]N<V]L92!(86YD;&5R"BTM+2TM+2TM+2TM+2TM
M+2TM+2T*5&AE($-O;G-O;&4@:&%N9&QE<B!O=71P=71S(&QO9R!E=F5N=',@
M9&ER96-T;'D@=&\@=&AE(&-O;G-O;&4N("!)="!S=7!P;W)T<PIO=71P=70@
M8G5F9F5R:6YG(&%N9"!C;VYF:6=U<F%B;&4@<W1R:6YG(&9O<FUA=',N"@I#
M;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@("`@("!\(%1Y<&4@("`@
M("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO;B`@("`@("`@("`@("`@
M('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]
M/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8'-T<F5A
M;6!@("`@("`@("!\($9I;&4@("`@("!\(%-41$]55%\@("`@("`@?"!4:&4@
M;W5T<'5T('-T<F5A;2!T;R!U<V4N('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8&)U9F9E<FEN9V!@("`@("!\($)O;VQE86X@("!\
M($9A;'-E("`@("`@("`@?"!3:&]U;&0@=&AE(&]U='!U="!B92`@("`@('P*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@
M("`@?"!B=69F97)E9"!U;G1I;"!S:'5T9&]W;C\@('P**RTM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&QI;F5&;W)M871@8"`@("!\(%-T
M<FEN9R`@("!\(&!@)3$D<R`E,B1S("`@?"!,;V<@;&EN92!F;W)M870@("`@
M("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\(%LE
M,R1S72`E-"1S8&`@?"!S<&5C:69I8V%T:6]N+B`@("`@("`@("`@('P**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'1I;65&;W)M871@
M8"`@("!\(%-T<FEN9R`@("!\(&!@)6(@)60@("`@("`@?"!4:6UE('-T86UP
M(&9O<FUA="`@("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\("5(.B5-.B538&`@("`@?"`H9F]R('-T<F9T:6UE7RDN("`@("`@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]3
M5$1/550Z(&AT='`Z+R]W=W<N<&AP+FYE="]W<F%P<&5R<RYP:'`*+BX@7W-T
M<F9T:6UE.B!H='1P.B\O=W=W+G!H<"YN970O<W1R9G1I;64*"D5X86UP;&4*
M?GY^?GY^?@HZ.@H*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O
M;G-O;&4G+"`G)RP@)VED96YT)RD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q
M,#L@)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I
M(BD["B`@("!]"@H*5&AE($1I<W!L87D@2&%N9&QE<@HM+2TM+2TM+2TM+2TM
M+2TM+2TM"E1H92!$:7-P;&%Y(&AA;F1L97(@<VEM<&QY('!R:6YT<R!T:&4@
M;&]G(&5V96YT<R!B86-K('1O('1H92!B<F]W<V5R+B`@270*<F5S<&5C=',@
M=&AE(&!@97)R;W)?<')E<&5N9%]S=')I;F=@8"!A;F0@8&!E<G)O<E]A<'!E
M;F1?<W1R:6YG8&`@8&5R<F]R"FAA;F1L:6YG('9A;'5E<V!?(&%N9"!I<R!U
M<V5F=6P@=VAE;B!@;&]G9VEN9R!F<F]M('-T86YD87)D(&5R<F]R(&AA;F1L
M97)S8%\N"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@("`@("!\
M(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO;B`@("`@
M("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3TK
M/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*
M?"!@8&5R<F]R7W!R97!E;F1@8"!\(%-T<FEN9R`@("!\(%!(4"!)3DD@=F%L
M=64@?"!4:&ES('-T<FEN9R!W:6QL(&)E("`@("`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!P<F5P96YD
M960@=&\@=&AE(&QO9R`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!O=71P=70N("`@("`@("`@("`@
M("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@
M8&5R<F]R7V%P<&5N9&!@("!\(%-T<FEN9R`@("!\(%!(4"!)3DD@=F%L=64@
M?"!4:&ES('-T<FEN9R!W:6QL(&)E("`@("`@('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!A<'!E;F1E9"!T
M;R!T:&4@;&]G("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\("`@("`@("`@("`@("`@?"!O=71P=70N("`@("`@("`@("`@("`@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&QI
M;F5B<F5A:V!@("`@("!\(%-T<FEN9R`@("!\(&!@/&)R("\^7&Y@8"`@?"!4
M:&ES('-T<FEN9R!I<R!U<V5D('1O("`@('P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!R97!R97-E;G0@82!L
M:6YE(&)R96%K+B`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*"BXN(%]E<G)O<B!H86YD;&EN9R!V86QU97,Z(&AT='`Z+R]W=W<N<&AP
M+FYE="]E<G)O<F9U;F,*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1C;VYF
M(#T@87)R87DH)V5R<F]R7W!R97!E;F0G(#T^("<\9F]N="!C;VQO<CTB(V9F
M,#`P,"(^/'1T/B<L"B`@("`@("`@("`@("`@("`@("=E<G)O<E]A<'!E;F0G
M("`]/B`G/"]T=#X\+V9O;G0^)RD["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=D:7-P;&%Y)RP@)R<L("<G+"`D8V]N9BP@4$5!4E],3T=?1$5"
M54<I.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@
M("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*"E1H92!%
M<G)O<E],;V<@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2TM+2T*5&AE($5R
M<F]R7TQO9R!H86YD;&5R('-E;F1S(&QO9R!E=F5N=',@=&\@4$A0)W,@8&5R
M<F]R7VQO9R@I8%\@9G5N8W1I;VXN"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^
M?GY^?GX**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A
M;65T97(@("`@("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$
M97-C<FEP=&EO;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]
M/3TK/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/2L*?"!@8&1E<W1I;F%T:6]N8&`@("!\(%-T<FEN9R`@
M("!\("<G(&`H96UP='DI8"`@?"!/<'1I;VYA;"!D97-T:6YA=&EO;B!V86QU
M97P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!F;W(@8&5R<F]R7VQO9R@I8%\N("!3964@('P*?"`@("`@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!@17)R
M;W)?3&]G(%1Y<&5S8%\@9F]R("`@('P*?"`@("`@("`@("`@("`@("`@("!\
M("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!M;W)E(&1E=&%I;',N("`@
M("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8&5X=')A7VAE861E<G-@8"!\(%-T<FEN9R`@("!\("<G(&`H96UP='DI
M8"`@?"!!9&1I=&EO;F%L(&AE861E<G,@=&\@<&%S<WP*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!T;R!T:&4@
M8&UA:6PH*6!?(&9U;F-T:6]N('P*?"`@("`@("`@("`@("`@("`@("!\("`@
M("`@("`@("!\("`@("`@("`@("`@("`@?"!W:&5N('1H92`@("`@("`@("`@
M("`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!@8%!%05)?3$]'7U194$5?34%)3&!@("`@('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!T>7!E(&ES('-P96-I9FEE9"X@("`@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*"D5R<F]R7TQO9R!4>7!E<PI^?GY^?GY^?GY^
M?GY^?GX*06QL(&]F('1H92!A=F%I;&%B;&4@;&]G('1Y<&5S(&%R92!D971A
M:6QE9"!I;B!T:&4@8&5R<F]R7VQO9R@I8%\@<V5C=&EO;B!O9@IT:&4@4$A0
M(&UA;G5A;"X@($9O<B!Y;W5R(&-O;G9E;FEE;F-E+"!T:&4@3&]G('!A8VMA
M9V4@86QS;R!D969I;F5S('1H90IF;VQL;W=I;F<@8V]N<W1A;G1S('1H870@
M8V%N(&)E('5S960@9F]R('1H92!@8"1N86UE8&`@:&%N9&QE<B!C;VYS=')U
M8W1I;VX*<&%R86UE=&5R+@H**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2L*?"!#;VYS=&%N="`@("`@("`@("`@("`@("`@('P@1&5S8W)I<'1I
M;VX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P**ST]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/2L*?"!@8%!%05)?3$]'7U194$5?
M4UE35$5-8&`@('P@3&]G(&5V96YT<R!A<F4@<V5N="!T;R!02%`G<R!S>7-T
M96T@;&]G9V5R+"`@('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M=VAI8V@@=7-E<R!T:&4@;W!E<F%T:6YG('-Y<W1E;2=S(&QO9V=I;F<@("`@
M('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@;65C:&%N:7-M(&]R
M(&$@9FEL92`H9&5P96YD:6YG(&]N('1H92!V86QU92`@('P*?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@;V8@=&AE(&!E<G)O<E]L;V<@8V]N9FEG
M=7)A=&EO;B!D:7)E8W1I=F5@7RDN('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7U194$5?34%)3&!@("`@('P@3&]G
M(&5V96YT<R!A<F4@<V5N="!V:6$@96UA:6P@=&\@=&AE(&%D9')E<W,@('P*
M?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@<W!E8VEF:65D(&EN('1H
M92!@8&1E<W1I;F%T:6]N8&`@=F%L=64N("`@("`@('P**RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%05)?3$]'7U194$5?1$5"54=@
M8"`@('P@3&]G(&5V96YT<R!A<F4@<V5N="!T:')O=6=H(%!(4"=S(&1E8G5G
M9VEN9R`@('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@('P@8V]N;F5C
M=&EO;BX@(%1H:7,@=VEL;"!O;FQY('=O<FL@:68@("`@("`@("`@('P*?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@8')E;6]T92!D96)U9V=I;F=@
M7R!H87,@8F5E;B!E;F%B;&5D+B`@5&AE("`@('P*?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@8&!D97-T:6YA=&EO;F!@('9A;'5E(&ES('5S960@
M=&\@<W!E8VEF>2!T:&4@('P*?"`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@:&]S="!N86UE(&]R($E0(&%D9')E<W,@;V8@=&AE('1A<F=E="!S;V-K
M970N('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8%!%
M05)?3$]'7U194$5?1DE,16!@("`@('P@3&]G(&5V96YT<R!W:6QL(&)E(&%P
M<&5N9&5D('1O('1H92!F:6QE(&YA;65D('P*?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@8GD@=&AE(&!@9&5S=&EN871I;VY@8"!V86QU92X@("`@
M("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*"BXN(%]E<G)O<E]L;V<H*3H@:'1T<#HO+W=W=RYP:'`N;F5T+V5R<F]R
M7VQO9PHN+B!?;6%I;"@I.B!H='1P.B\O=W=W+G!H<"YN970O;6%I;`HN+B!?
M97)R;W)?;&]G(&-O;F9I9W5R871I;VX@9&ER96-T:79E.B!H='1P.B\O=W=W
M+G!H<"YN970O97)R;W)F=6YC(VEN:2YE<G)O<BUL;V<*+BX@7W)E;6]T92!D
M96)U9V=I;F<Z(&AT='`Z+R]W=W<N<&AP+FYE="]I;G-T86QL+F-O;F9I9W5R
M92-I;G-T86QL+F-O;F9I9W5R92YE;F%B;&4M9&5B=6=G97(*"D5X86UP;&4*
M?GY^?GY^?@HZ.@H*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V5R
M<F]R7VQO9R<L(%!%05)?3$]'7U194$5?4UE35$5-+"`G:61E;G0G*3L*("`@
M(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E
M<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@1FEL92!(86YD
M;&5R"BTM+2TM+2TM+2TM+2TM+2T*5&AE($9I;&4@:&%N9&QE<B!W<FET97,@
M;&]G(&5V96YT<R!T;R!A('1E>'0@9FEL92!U<VEN9R!C;VYF:6=U<F%B;&4@
M<W1R:6YG"F9O<FUA=',N"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX*
M*RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@
M("`@("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP
M=&EO;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]
M/3T]/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/3T]/2L*?"!@8&%P<&5N9&!@("`@("`@("!\($)O;VQE86X@("!\(%1R
M=64@("`@("`@("`@?"!3:&]U;&0@;F5W(&QO9R!E;G1R:65S(&)E('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!A<'!E;F0@=&\@86X@97AI<W1I;F<@;&]G('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!F:6QE+"!O<B!S
M:&]U;&0@=&AE(&$@;F5W('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\("`@("`@("`@("`@("`@?"!L;V<@9FEL92!O=F5R=W)I=&4@86X@
M("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@
M("`@("`@("`@?"!E>&ES=&EN9R!O;F4_("`@("`@("`@("`@('P**RTM+2TM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&QO8VMI;F=@8"`@("`@
M("!\($)O;VQE86X@("!\($9A;'-E("`@("`@("`@?"!3:&]U;&0@861V:7-O
M<GD@9FEL92`@("`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@
M("!\("`@("`@("`@("`@("`@?"!L;V-K:6YG("AU<VEN9R!F;&]C:U\I(&)E
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@
M("`@("`@?"!U<V5D/R`@("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&UO9&5@8"`@("`@("`@("!\
M($EN=&5G97(@("!\(#`V-#0@("`@("`@("`@?"!/8W1A;"!R97!R97-E;G1A
M=&EO;B!O9B`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\
M("`@("`@("`@("`@("`@?"!T:&4@;&]G(&9I;&4G<R!P97)M:7-S:6]N<WP*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@
M("`@?"!M;V1E+B`@("`@("`@("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&1I<FUO9&5@8"`@("`@("!\($EN
M=&5G97(@("!\(#`W-34@("`@("`@("`@?"!/8W1A;"!R97!R97-E;G1A=&EO
M;B!O9B`@('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@
M("`@("`@("`@("`@?"!T:&4@9FEL92!P97)M:7-S:6]N(&UO9&4@('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@
M?"!T:&%T('=I;&P@8F4@=7-E9"!W:&5N("`@('P*?"`@("`@("`@("`@("`@
M("`@("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!C<F5A=&EN9R!D
M:7)E8W1O<FEE<R!T:&%T('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@
M("`@("!\("`@("`@("`@("`@("`@?"!D;R!N;W0@86QR96%D>2!E>&ES="X@
M("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8&5O
M;&!@("`@("`@("`@("!\(%-T<FEN9R`@("!\($]3(&1E9F%U;'0@("`@?"!4
M:&4@96YD+6]N+6QI;F4@8VAA<F%C=&5R('P*?"`@("`@("`@("`@("`@("`@
M("!\("`@("`@("`@("!\("`@("`@("`@("`@("`@?"!S97%U96YC92X@("`@
M("`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*?"!@8&QI;F5&;W)M871@8"`@("!\(%-T<FEN9R`@("!\(&!@)3$D<R`E
M,B1S("`@?"!,;V<@;&EN92!F;W)M870@("`@("`@("`@('P*?"`@("`@("`@
M("`@("`@("`@("!\("`@("`@("`@("!\(%LE,R1S72`E-"1S8&`@?"!S<&5C
M:69I8V%T:6]N+B`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*?"!@8'1I;65&;W)M871@8"`@("!\(%-T<FEN9R`@("!\
M(&!@)6(@)60@("`@("`@?"!4:6UE('-T86UP(&9O<FUA="`@("`@("`@('P*
M?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("5(.B5-.B538&`@
M("`@?"`H9F]R('-T<F9T:6UE7RDN("`@("`@("`@('P**RTM+2TM+2TM+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]F;&]C:SH@:'1T<#HO+W=W=RYP
M:'`N;F5T+V9L;V-K"BXN(%]S=')F=&EM93H@:'1T<#HO+W=W=RYP:'`N;F5T
M+W-T<F9T:6UE"@I4:&4@9FEL92!H86YD;&5R('=I;&P@;VYL>2!A='1E;7!T
M('1O('-E="!T:&4@8&!M;V1E8&`@=F%L=64@:68@:70@=V%S"G)E<W!O;G-I
M8FQE(&9O<B!C<F5A=&EN9R!T:&4@9FEL92X*"D5X86UP;&4*?GY^?GY^?@HZ
M.@H*("`@("1C;VYF(#T@87)R87DH)VUO9&4G(#T^(#`V,#`L("=T:6UE1F]R
M;6%T)R`]/B`G)5@@)7@G*3L*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T
M;VXH)V9I;&4G+"`G;W5T+FQO9R<L("=I9&5N="<L("1C;VYF*3L*("`@(&9O
M<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@("`@)&QO9V=E<BT^
M;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@36%I;"!(86YD;&5R
M"BTM+2TM+2TM+2TM+2TM+2T*5&AE($UA:6P@:&%N9&QE<B!A9V=R96=A=&5S
M(&$@<V5S<VEO;B=S(&QO9R!E=F5N=',@86YD('-E;F1S('1H96T@:6X@=&AE
M(&)O9'D*;V8@86X@96UA:6P@;65S<V%G92!U<VEN9R!02%`G<R!@;6%I;"@I
M8%\@9G5N8W1I;VXN"@I#;VYF:6=U<F%T:6]N"GY^?GY^?GY^?GY^?GX**RTM
M+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!087)A;65T97(@("`@
M("`@("!\(%1Y<&4@("`@("!\($1E9F%U;'0@("`@("`@?"!$97-C<FEP=&EO
M;B`@("`@("`@("`@("`@('P**ST]/3T]/3T]/3T]/3T]/3T]/3TK/3T]/3T]
M/3T]/3TK/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3T]/2L*?"!@8&9R;VU@8"`@("`@("`@("!\(%-T<FEN9R`@("!\('-E;F1M
M86EL7V9R;VT@?"!686QU92!F;W(@=&AE(&UE<W-A9V4G<R`@('P*?"`@("`@
M("`@("`@("`@("`@("!\("`@("`@("`@("!\($E.22!V86QU92`@("`@?"!@
M8$9R;VTZ8&`@:&5A9&5R+B`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*?"!@8'-U8FIE8W1@8"`@("`@("!\(%-T<FEN9R`@
M("!\(&!@6TQO9U]M86EL72`@?"!686QU92!F;W(@=&AE(&UE<W-A9V4G<R`@
M('P*?"`@("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\($QO9R!M97-S
M86=E8&`@?"!@8%-U8FIE8W0Z8&`@:&5A9&5R+B`@("`@('P**RTM+2TM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*?"!@8'!R96%M8FQE8&`@("`@("!\
M(%-T<FEN9R`@("!\(&!@(&`H96UP='DI8"`@?"!0<F5A;6)L92!F;W(@=&AE
M(&UE<W-A9V4N('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M?"!@8&QI;F5&;W)M871@8"`@("!\(%-T<FEN9R`@("!\(&!@)3$D<R`E,B1S
M("`@?"!,;V<@;&EN92!F;W)M870@("`@("`@("`@('P*?"`@("`@("`@("`@
M("`@("`@("!\("`@("`@("`@("!\(%LE,R1S72`E-"1S8&`@?"!S<&5C:69I
M8V%T:6]N+B`@("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*?"!@8'1I;65&;W)M871@8"`@("!\(%-T<FEN9R`@("!\(&!@
M)6(@)60@("`@("`@?"!4:6UE('-T86UP(&9O<FUA="`@("`@("`@('P*?"`@
M("`@("`@("`@("`@("`@("!\("`@("`@("`@("!\("5(.B5-.B538&`@("`@
M?"`H9F]R('-T<F9T:6UE7RDN("`@("`@("`@('P**RTM+2TM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*"BXN(%]M86EL*"DZ(&AT='`Z+R]W=W<N<&AP
M+FYE="]M86EL"@I%>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D8V]N9B`](&%R
M<F%Y*"=S=6)J96-T)R`]/B`G26UP;W)T86YT($QO9R!%=F5N=',G*3L*("`@
M("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)VUA:6PG+"`G=V5B;6%S=&5R
M0&5X86UP;&4N8V]M)RP@)VED96YT)RP@)&-O;F8I.PH@("`@9F]R("@D:2`]
M(#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R+3YL;V<H(DQO
M9R!E;G1R>2`D:2(I.PH@("`@?0H*"E1H92!-1$(R($AA;F1L97(*+2TM+2TM
M+2TM+2TM+2TM+0I4:&4@341",B!H86YD;&5R(&ES('-I;6EL87(@=&\@8'1H
M92!344P@*$1"*2!H86YD;&5R8%\L(&)U="!I;G-T96%D(&]F('5S:6YG"G1H
M92!014%2($1"('!A8VMA9V4L(&ET('5S97,@=&AE(&!-1$(R(&1A=&%B87-E
M(&%B<W1R86-T:6]N('!A8VMA9V5@7RX*"D-O;F9I9W5R871I;VX*?GY^?GY^
M?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(%!A
M<F%M971E<B`@("`@("`@('P@5'EP92`@("`@('P@1&5F875L="`@("`@("!\
M($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@?`HK/3T]/3T]/3T]/3T]/3T]
M/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3TK/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]*PI\(&!@9'-N8&`@("`@("`@("`@('P@36EX960@
M("`@('P@)R<@8"AE;7!T>2E@("!\($$@8$1A=&$@4V]U<F-E($YA;65@7RX@
M("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\('QR97%U:7)E9'P@("`@("`@("`@("`@("`@?`HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@;W!T:6]N<V!@("`@("`@
M('P@07)R87D@("`@('P@8&!P97)S:7-T96YT8&!\($%N(&%R<F%Y(&]F(&!-
M1$(R8%\@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@("`@("`@("`@("`@("!\(&]P=&EO;G,N("`@("`@("`@("`@("`@("`@
M?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM
M+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@9&)@8"`@
M("`@("`@("`@('P@3V)J96-T("`@('P@3E5,3"`@("`@("`@("!\($%N(&5X
M:7-T:6YG(&!-1$(R8%\@("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\(&]B:F5C="X@($EF('-P96-I
M9FEE9"P@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\('1H:7,@;V)J96-T('=I;&P@8F4@=7-E9"P@?`I\
M("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@
M("!\(&%N9"!@8&1S;F!@('=I;&P@8F4@("`@("`@?`I\("`@("`@("`@("`@
M("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&EG;F]R960N
M("`@("`@("`@("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PI\(&!@<V5Q=65N8V5@8"`@("`@('P@4W1R:6YG("`@('P@8&!L
M;V=?:61@8"`@("!\(%1H92!N86UE(&]F('1H92!S97%U96YC92`@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M('1O('5S92!W:&5N(&=E;F5R871I;F<@("`@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('5N:7%U92!E=F5N
M="!)1',N("`@56YD97(@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\(&UA;GD@9&%T86)A<V5S+"!T:&ES('=I
M;&P@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\(&)E('5S960@87,@=&AE(&YA;64@;V8@("`@?`I\("`@("`@
M("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('1H
M92!S97%U96YC92!T86)L92X@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(&!@:61E;G1,:6UI=&!@("`@('P@26YT96=E<B`@
M('P@,38@("`@("`@("`@("!\(%1H92!M87AI;75M(&QE;F=T:"!O9B!T:&4@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\(&!@:61E;G1@8"!S=')I;F<N("`@("`@("`@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\("HJ0VAA
M;F=I;F<@=&AI<R!V86QU92!M87D@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\(')E<75I<F4@=7!D871E<R!T
M;R!T:&4@4U%,?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\('-C:&5M82P@87,@=V5L;"XJ*B`@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@<VEN9VQE=&]N
M8&`@("`@('P@0F]O;&5A;B`@('P@9F%L<V4@("`@("`@("!\($ES('1R=64L
M('5S92!A('-I;F=L971O;B`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\(&1A=&%B87-E(&]B:F5C="!U<VEN
M9R`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\(&!-1$(R.CIS:6YG;&5T;VXH*6!?+B`@("`@?`HK+2TM
M+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*+BX@7TU$0C(Z(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]-1$(R"BXN(%]-1$(R(&1A=&%B87-E
M(&%B<W1R86-T:6]N('!A8VMA9V4Z($U$0C)?"BXN(%]-1$(R.CIS:6YG;&5T
M;VXH*3H@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E+TU$0C(O9&]C<R]L
M871E<W0O341",B]-1$(R+FAT;6PC;65T:&]D<VEN9VQE=&]N"@I4:&4@3G5L
M;"!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2T*5&AE($YU;&P@:&%N9&QE<B!S
M:6UP;'D@8V]N<W5M97,@;&]G(&5V96YT<R`H86MI;B!T;R!S96YD:6YG('1H
M96T@=&\*8&`O9&5V+VYU;&Q@8"DN("!@3&]G(&QE=F5L(&UA<VMS8%\@87)E
M(')E<W!E8W1E9"P@86YD('1H92!E=F5N="!W:6QL('-T:6QL(&)E"G-E;G0@
M=&\@86YY(')E9VES=&5R960@8&QO9R!O8G-E<G9E<G-@7RX*"D5X86UP;&4*
M?GY^?GY^?@HZ.@H*("`@("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)VYU
M;&PG*3L*("`@(&9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`@
M("`@)&QO9V=E<BT^;&]G*"),;V<@96YT<GD@)&DB*3L*("`@('T*"@I4:&4@
M4U%,("A$0BD@2&%N9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5&AE(%-1
M3"!H86YD;&5R('-E;F1S(&QO9R!E=F5N=',@=&\@82!D871A8F%S92!U<VEN
M9R!@4$5!4B=S($1"(&%B<W1R86-T:6]N"FQA>65R8%\N"@HJ*DYO=&4Z*BH@
M1'5E('1O('1H92!C;VYS=')A:6YT<R!O9B!T:&4@9&5F875L="!D871A8F%S
M92!S8VAE;6$L('1H92!344P*:&%N9&QE<B!L:6UI=',@=&AE(&QE;F=T:"!O
M9B!T:&4@8&`D:61E;G1@8"!S=')I;F<@=&\@<VEX=&5E;B`H,38I(&-H87)A
M8W1E<G,N"E1H:7,@;&EM:70@8V%N(&)E(&%D:G5S=&5D('5S:6YG('1H92!@
M8&ED96YT3&EM:71@8"!C;VYF:6=U<F%T:6]N('!A<F%M971E<BX*"E1H92!,
M;V<@5&%B;&4*?GY^?GY^?GY^?GY^?@I4:&4@9&5F875L="!344P@=&%B;&4@
M=7-E9"!B>2!T:&ES(&AA;F1L97(@;&]O:W,@;&EK92!T:&ES.CH*"B`@("!#
M4D5!5$4@5$%"3$4@;&]G7W1A8FQE("@*("`@("`@("!I9"`@("`@("`@("!)
M3E0@3D]4($Y53$PL"B`@("`@("`@;&]G=&EM92`@("`@5$E-15-404U0($Y/
M5"!.54Q,+`H@("`@("`@(&ED96YT("`@("`@($-(05(H,38I($Y/5"!.54Q,
M+`H@("`@("`@('!R:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("`@("`@("!M
M97-S86=E("`@("!605)#2$%2*#(P,"DL"B`@("`@("`@4%))34%262!+15D@
M*&ED*0H@("`@*3L*"E1H:7,@:7,@=&AE(")L;W=E<W0@8V]M;6]N(&1E;F]M
M:6YA=&]R(B!T:&%T('-H;W5L9"!W;W)K(&%C<F]S<R!A;&P@4U%,"F-O;7!L
M:6%N="!D871A8F%S92X@(%EO=2!M87D@=V%N="!T;R!M86ME(&1A=&%B87-E
M+2!O<B!S:71E+7-P96-I9FEC(&-H86YG97,*=&\@=&AI<R!S8VAE;6$@=&\@
M<W5P<&]R="!Y;W5R('-P96-I9FEC(&YE961S+"!H;W=E=F5R+B`@1F]R(&5X
M86UP;&4L"F!0;W-T9W)E4U%,8%\@=7-E<G,@;6%Y('!R969E<B!T;R!U<V4@
M82!@8%1%6%1@8"!T>7!E(&9O<B!T:&4@8&!M97-S86=E8&`*9FEE;&0N"@HN
M+B!?4&]S=&=R95-13#H@:'1T<#HO+W=W=RYP;W-T9W)E<W%L+F]R9R\*"D-O
M;F9I9W5R871I;VX*?GY^?GY^?GY^?GY^?@HK+2TM+2TM+2TM+2TM+2TM+2TM
M+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PI\(%!A<F%M971E<B`@("`@("`@('P@5'EP92`@("`@
M('P@1&5F875L="`@("`@("!\($1E<V-R:7!T:6]N("`@("`@("`@("`@("`@
M?`HK/3T]/3T]/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/2L]/3T]/3T]/3T]
M/3T]/3TK/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]*PI\(&!@9'-N8&`@
M("`@("`@("`@('P@36EX960@("`@('P@)R<@8"AE;7!T>2E@("!\($$@8$1A
M=&$@4V]U<F-E($YA;65@7RX@("`@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\('QR97%U:7)E9'P@("`@("`@
M("`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM
M+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\
M(&!@<W%L8&`@("`@("`@("`@('P@4W1R:6YG("`@('P@?'-Q;"UD969A=6QT
M?"!\(%-13"!I;G-E<G1I;VX@<W1A=&5M96YT+B`@?`HK+2TM+2TM+2TM+2TM
M+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@;W!T:6]N<V!@("`@("`@('P@07)R
M87D@("`@('P@8&!P97)S:7-T96YT8&!\($%N(&%R<F%Y(&]F(&!$0F!?(&]P
M=&EO;G,N?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@
M9&)@8"`@("`@("`@("`@('P@3V)J96-T("`@('P@3E5,3"`@("`@("`@("!\
M($%N(&5X:7-T:6YG(&!$0F!?(&]B:F5C="X@?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\($EF('-P96-I9FEE
M9"P@=&AI<R!O8FIE8W0@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@
M("`@('P@("`@("`@("`@("`@("!\('=I;&P@8F4@=7-E9"P@86YD(&!@9'-N
M8&`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@
M("`@("`@("!\('=I;&P@8F4@:6=N;W)E9"X@("`@("`@("`@?`HK+2TM+2TM
M+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@<V5Q=65N8V5@8"`@("`@
M('P@4W1R:6YG("`@('P@8&!L;V=?:61@8"`@("!\(%1H92!N86UE(&]F('1H
M92!S97%U96YC92`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@
M('P@("`@("`@("`@("`@("!\('1O('5S92!W:&5N(&=E;F5R871I;F<@("`@
M?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@
M("`@("!\('5N:7%U92!E=F5N="!)1',N("`@56YD97(@?`I\("`@("`@("`@
M("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\(&UA;GD@
M9&%T86)A<V5S+"!T:&ES('=I;&P@?`I\("`@("`@("`@("`@("`@("`@('P@
M("`@("`@("`@('P@("`@("`@("`@("`@("!\(&)E('5S960@87,@=&AE(&YA
M;64@;V8@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@
M("`@("`@("`@("`@("!\('1H92!S97%U96YC92!T86)L92X@("`@("`@?`HK
M+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PI\(&!@:61E;G1,:6UI
M=&!@("`@('P@26YT96=E<B`@('P@,38@("`@("`@("`@("!\(%1H92!M87AI
M;75M(&QE;F=T:"!O9B!T:&4@?`I\("`@("`@("`@("`@("`@("`@('P@("`@
M("`@("`@('P@("`@("`@("`@("`@("!\(&!@:61E;G1@8"!S=')I;F<N("`@
M("`@("`@?`I\("`@("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@
M("`@("`@("`@("!\("HJ0VAA;F=I;F<@=&AI<R!V86QU92!M87D@?`I\("`@
M("`@("`@("`@("`@("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\
M(')E<75I<F4@=7!D871E<R!T;R!T:&4@4U%,?`I\("`@("`@("`@("`@("`@
M("`@('P@("`@("`@("`@('P@("`@("`@("`@("`@("!\('-C:&5M82P@87,@
M=V5L;"XJ*B`@("`@("`@?`HK+2TM+2TM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2LM+2TM+2TM+2TM+2TM+2TK+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*PH*5&AE(&YA;64@;V8@=&AE(&1A=&%B87-E('1A8FQE('1O('=H:6-H
M('1H92!L;V<@96YT<FEE<R!W:6QL(&)E('=R:71T96X@:7,*<W!E8VEF:65D
M('5S:6YG('1H92!@8"1N86UE8&`@8V]N<W1R=6-T:6]N('!A<F%M971E<B`H
M<V5E(&!#;VYF:6=U<FEN9R!A"DAA;F1L97)@7RDN"@HN+B!\<W%L+61E9F%U
M;'1\(')E<&QA8V4Z.B!@8$E.4T525"!)3E1/("1T86)L92`H:60L(&QO9W1I
M;64L(&ED96YT+"!P<FEO<FET>2P@;65S<V%G92D@5D%,5453*#\L($-54E)%
M3E1?5$E-15-404U0+"`_+"`_+"`_*6!@"@HN+B!?1$(Z(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]$0@HN+B!?4$5!4B=S($1"(&%B<W1R86-T:6]N
M(&QA>65R.B!$0E\*+BX@7T1A=&$@4V]U<F-E($YA;64Z(&AT='`Z+R]P96%R
M+G!H<"YN970O;6%N=6%L+V5N+W!A8VMA9V4N9&%T86)A<V4N9&(N:6YT<F\M
M9'-N+G!H<`H*17AA;7!L97,*?GY^?GY^?GX*57-I;F<@82!@1&%T82!3;W5R
M8V4@3F%M96!?('1O(&-R96%T92!A(&YE=R!D871A8F%S92!C;VYN96-T:6]N
M.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=D<VXG(#T^("=P9W-Q;#HO+VIO;D!L
M;V-A;&AO<W0K=6YI>"]L;V=S)RD["B`@("`D;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=S<6PG+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&-O;F8I.PH@
M("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G
M9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*57-I;F<@86X@97AI
M<W1I;F<@8$1"8%\@;V)J96-T.CH*"B`@("!R97%U:7)E7V]N8V4@)T1"+G!H
M<"<["B`@("`D9&(@/2`F1$(Z.F-O;FYE8W0H)W!G<W%L.B\O:F]N0&QO8V%L
M:&]S="MU;FEX+VQO9W,G*3L*"B`@("`D8V]N9ELG9&(G72`]("1D8CL*("`@
M("1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)W-Q;"<L("=L;V=?=&%B;&4G
M+"`G:61E;G0G+"`D8V]N9BD["B`@("!F;W(@*"1I(#T@,#L@)&D@/"`Q,#L@
M)&DK*RD@>PH@("`@("`@("1L;V=G97(M/FQO9R@B3&]G(&5N=')Y("1I(BD[
M"B`@("!]"@H*5&AE(%-Q;&ET92!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM
M+0HZ075T:&]R.B`@("`@("`@0F5R=')A;F0@36%N<VEO;@HZ0V]N=&%C=#H@
M("`@("`@8FUA;G-I;VY`;6%M87-A;2YC;VT*"E1H92!3<6QI=&4@:&%N9&QE
M<B!S96YD<R!L;V<@979E;G1S('1O(&%N(%-Q;&ET92!D871A8F%S92!U<VEN
M9R!T:&4@8&YA=&EV90I02%`@<W%L:71E(&9U;F-T:6]N<V!?+@H*270@:7,@
M9F%S=&5R('1H86X@8'1H92!344P@*$1"*2!H86YD;&5R8%\@8F5C875S92!R
M97%U97-T<R!A<F4@;6%D92!D:7)E8W1L>0IT;R!T:&4@9&%T86)A<V4@=VET
M:&]U="!U<VEN9R!A;B!A8G-T<F%C=&EO;B!L87EE<BX@($ET(&ES(&%L<V\@
M:6YT97)E<W1I;F<@=&\*;F]T92!T:&%T(%-Q;&ET92!D871A8F%S92!F:6QE
M<R!C86X@8F4@;6]V960L(&-O<&EE9"P@86YD(&1E;&5T960@;VX@>6]U<@IS
M>7-T96T@:G5S="!L:6ME(&%N>2!O=&AE<B!F:6QE<RP@=VAI8V@@;6%K97,@
M;&]G(&UA;F%G96UE;G0@96%S:65R+B`@3&%S="!B=70*;F]T(&QE87-T+"!U
M<VEN9R!A(&1A=&%B87-E('1O(&QO9R!Y;W5R(&5V96YT<R!A;&QO=W,@>6]U
M('1O('5S92!344P@<75E<FEE<PIT;R!C<F5A=&4@<F5P;W)T<R!A;F0@<W1A
M=&ES=&EC<RX*"E=H96X@=7-I;F<@82!D871A8F%S92!A;F0@;&]G9VEN9R!A
M(&QO="!O9B!E=F5N=',L(&ET(&ES(')E8V]M;65N9&5D('1O('-P;&ET"G1H
M92!D871A8F%S92!I;G1O('-M86QL97(@9&%T86)A<V5S+B`@5&AI<R!I<R!A
M;&QO=V5D(&)Y(%-Q;&ET92P@86YD('EO=2!C86X*;&%T97(@=7-E('1H92!3
M<6QI=&4@8$%45$%#2&!?('-T871E;65N="!T;R!Q=65R>2!Y;W5R(&QO9R!D
M871A8F%S92!F:6QE<PIG;&]B86QL>2X*"DEF('1H92!D871A8F%S92!D;V5S
M(&YO="!E>&ES="!W:&5N('1H92!L;V<@:7,@;W!E;F5D+"!S<6QI=&4@=VEL
M;"!T<GD@=&\*8W)E871E(&ET(&%U=&]M871I8V%L;'DN($EF('1H92!L;V<@
M=&%B;&4@9&]E<R!N;W0@97AI<W0L(&ET('=I;&P@86QS;R!B90IA=71O;6%T
M:6-A;&QY(&-R96%T960N("!4:&4@=&%B;&4@8W)E871I;VX@=7-E<R!T:&4@
M9F]L;&]W:6YG(%-13"!R97%U97-T.CH*"B`@("!#4D5!5$4@5$%"3$4@;&]G
M7W1A8FQE("@*("`@("`@("!I9"`@("`@("`@("!)3E1%1T52(%!224U!4ED@
M2T59($Y/5"!.54Q,+`H@("`@("`@(&QO9W1I;64@("`@($Y/5"!.54Q,+`H@
M("`@("`@(&ED96YT("`@("`@($-(05(H,38I($Y/5"!.54Q,+`H@("`@("`@
M('!R:6]R:71Y("`@($E.5"!.3U0@3E5,3"P*("`@("`@("!M97-S86=E"B`@
M("`I.PH*0V]N9FEG=7)A=&EO;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4
M>7!E("`@("`@?"!$969A=6QT("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@
M("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]
M/3T]/3T]/3T]/3T]/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@
M8&!F:6QE;F%M96!@("`@("`@?"!3=')I;F<@("`@?"`G)R!@*&5M<'1Y*6`@
M('P@4&%T:"!T;R!A;B!3<6QI=&4@("`@("`@("!\"GP@("`@("`@("`@("`@
M("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@9&%T86)A<V4N
M('QR97%U:7)E9'P@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@8&!M;V1E8&`@("`@("`@("`@?"!);G1E9V5R("`@?"`P-C8V
M("`@("`@("`@('P@3V-T86P@;6]D92!U<V5D('1O(&]P96X@("!\"GP@("`@
M("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@("`@("`@('P@
M=&AE(&1A=&%B87-E+B`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&!P97)S:7-T96YT8&`@("`@?"!";V]L96%N
M("`@?"!F86QS92`@("`@("`@('P@57-E(&$@<&5R<VES=&5N="`@("`@("`@
M("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@("`@("`@?"`@("`@("`@
M("`@("`@('P@8V]N;F5C=&EO;BX@("`@("`@("`@("`@("!\"BLM+2TM+2TM
M+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"@I!;B!A;')E861Y(&]P96YE9"!D
M871A8F%S92!C;VYN96-T:6]N(&-A;B!A;'-O(&)E('!A<W-E9"!A<R!P87)A
M;65T97(@:6YS=&5A9`IO9B!T:&4@86)O=F4@8V]N9FEG=7)A=&EO;BX@($EN
M('1H:7,@8V%S92P@8VQO<VEN9R!T:&4@9&%T86)A<V4@8V]N;F5C=&EO;B!I
M<PIU<"!T;R!T:&4@=7-E<BX*"BXN(%]N871I=F4@4$A0('-Q;&ET92!F=6YC
M=&EO;G,Z(&AT='`Z+R]W=W<N<&AP+FYE="]S<6QI=&4*+BX@7T%45$%#2#H@
M:'1T<#HO+W=W=RYS<6QI=&4N;W)G+VQA;F<N:'1M;"-A='1A8V@*"D5X86UP
M;&5S"GY^?GY^?GY^"E5S:6YG(&$@8V]N9FEG=7)A=&EO;B!T;R!C<F5A=&4@
M82!N97<@9&%T86)A<V4@8V]N;F5C=&EO;CHZ"@H@("`@)&-O;F8@/2!A<G)A
M>2@G9FEL96YA;64G(#T^("=L;V<N9&(G+"`G;6]D92<@/3X@,#8V-BP@)W!E
M<G-I<W1E;G0G(#T^('1R=64I.PH@("`@)&QO9V=E<B`])B!,;V<Z.F9A8W1O
M<GDH)W-Q;&ET92<L("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D8V]N9BD["B`@
M("`D;&]G9V5R+3YL;V<H)VQO9V=I;F<@86X@979E;G0G+"!014%27TQ/1U]7
M05).24Y'*3L*"E5S:6YG(&%N(&5X:7-T:6YG(&-O;FYE8W1I;VXZ.@H*("`@
M("1D8B`]('-Q;&ET95]O<&5N*"=L;V<N9&(G+"`P-C8V+"`D97)R;W(I.PH@
M("`@)&QO9V=E<B`])B!,;V<Z.F9A8W1O<GDH)W-Q;&ET92<L("=L;V=?=&%B
M;&4G+"`G:61E;G0G+"`D9&(I.PH@("`@)&QO9V=E<BT^;&]G*"=L;V=G:6YG
M(&%N(&5V96YT)RP@4$5!4E],3T=?5T%23DE.1RD["B`@("!S<6QI=&5?8VQO
M<V4H)&1B*3L*"@I4:&4@4WES;&]G($AA;F1L97(*+2TM+2TM+2TM+2TM+2TM
M+2TM"E1H92!3>7-L;V<@:&%N9&QE<B!S96YD<R!L;V<@979E;G1S('1O('1H
M92!S>7-T96T@;&]G9VEN9R!S97)V:6-E("AS>7-L;V<@;VX*56YI>"UL:6ME
M(&5N=FER;VYM96YT<R!O<B!T:&4@179E;G0@3&]G(&]N(%=I;F1O=W,@<WES
M=&5M<RDN("!4:&4@979E;G1S(&%R90IS96YT('5S:6YG(%!(4"=S(&!S>7-L
M;V<H*6!?(&9U;F-T:6]N+@H*1F%C:6QI=&EE<PI^?GY^?GY^?GY^"BLM+2TM
M+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@0V]N<W1A;G0@("`@("`@
M("`@?"!#871E9V]R>2!$97-C<FEP=&EO;B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"BL]/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]
M/3TK"GP@8&!,3T=?05542&!@("`@("`@?"!396-U<FET>2`O(&%U=&AO<FEZ
M871I;VX@;65S<V%G97,[(&!@3$]'7T%55$A04DE68&`@:7-\"GP@("`@("`@
M("`@("`@("`@("`@?"!P<F5F97)R960@;VX@<WES=&5M<R!W:&5R92!I="!I
M<R!D969I;F5D+B`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"GP@8&!,3T=?05542%!2259@8"`@?"!0<FEV871E('-E
M8W5R:71Y("\@875T:&]R:7IA=&EO;B!M97-S86=E<R`@("`@("`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?0U)/
M3F!@("`@("`@?"!#;&]C:R!D865M;VX@*&!@8W)O;F!@(&%N9"!@8&%T8&`I
M("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@8&!,3T=?1$%%34].8&`@("`@?"!3>7-T96T@9&%E;6]N
M('!R;V-E<W-E<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?2T523F!@
M("`@("`@?"!+97)N96P@;65S<V%G97,@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"GP@8&!,3T=?3$]#04PP8&`@+BX@?"!297-E<G9E9"!F;W(@;&]C
M86P@=7-E.R`J*FYO="HJ(&%V86EL86)L92!U;F1E<B`@("`@("!\"GP@8&!,
M3T=?3$]#04PW8&`@("`@?"!7:6YD;W=S+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?3%!28&`@("`@("`@?"!0<FEN=&5R
M('-U8G-Y<W1E;2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?
M34%)3&!@("`@("`@?"!-86EL('-U8G-Y<W1E;2`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"GP@8&!,3T=?3D574V!@("`@("`@?"!54T5.150@;F5W
M<R!S=6)S>7-T96T@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?4UE3
M3$]'8&`@("`@?"!);G1E<FYA;"!S>7-L;V<@;65S<V%G97,@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@8&!,3T=?55-%4F!@("`@("`@?"!'96YE<FEC('5S97(M
M;&5V96P@;65S<V%G97,@("`@("`@("`@("`@("`@("`@("`@("`@("!\"BLM
M+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!,3T=?555#4&!@
M("`@("`@?"!554-0('-U8G-Y<W1E;2`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"@HN+B!?<WES;&]G*"DZ(&AT='`Z+R]W=W<N<&AP+FYE="]S>7-L
M;V<*"D5X86UP;&4*?GY^?GY^?@HZ.@H*("`@("1L;V=G97(@/2`F3&]G.CIS
M:6YG;&5T;VXH)W-Y<VQO9R<L($Q/1U],3T-!3#`L("=I9&5N="<I.PH@("`@
M9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D;&]G9V5R
M+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*"E1H92!7:6YD;W<@2&%N
M9&QE<@HM+2TM+2TM+2TM+2TM+2TM+2T*5&AE(%=I;F1O=R!H86YD;&5R('-E
M;F1S(&QO9R!E=F5N=',@=&\@82!S97!A<F%T92!B<F]W<V5R('=I;F1O=RX@
M(%1H90IO<FEG:6YA;"!I9&5A(&9O<B!T:&ES(&AA;F1L97(@=V%S(&EN<W!I
M<F5D(&)Y($-R86EG($1A=FES)R!:96YD+F-O;2!A<G1I8VQE"F5N=&ET;&5D
M(&`B2F%V85-C<FEP="!0;W=E<B!02%`@1&5B=6=G:6YG(F!?+@H*0V]N9FEG
M=7)A=&EO;@I^?GY^?GY^?GY^?GY^"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM
M+2TM+2TM+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"GP@4&%R86UE=&5R("`@("`@("`@?"!4>7!E("`@("`@?"!$
M969A=6QT("`@("`@('P@1&5S8W)I<'1I;VX@("`@("`@("`@("`@("!\"BL]
M/3T]/3T]/3T]/3T]/3T]/3T]*ST]/3T]/3T]/3T]*ST]/3T]/3T]/3T]/3T]
M/2L]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3TK"GP@8&!T:71L96!@("`@
M("`@("`@?"!3=')I;F<@("`@?"!@8$QO9R!/=71P=70@('P@5&AE('1I=&QE
M(&]F('1H92!O=71P=70@("!\"GP@("`@("`@("`@("`@("`@("`@?"`@("`@
M("`@("`@?"!7:6YD;W=@8"`@("`@('P@=VEN9&]W+B`@("`@("`@("`@("`@
M("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM+2TM*RTM+2TM
M+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"GP@8&!C
M;VQO<G-@8"`@("`@("`@?"!!<G)A>2`@("`@?"!@4D]9($<@0DE68%\@('P@
M36%P<&EN9R!O9B!L;V<@<')I;W)I=&EE<R!\"GP@("`@("`@("`@("`@("`@
M("`@?"`@("`@("`@("`@?"`H:&EG:"!T;R!L;W<I('P@=&\@8V]L;W)S+B`@
M("`@("`@("`@("`@("!\"BLM+2TM+2TM+2TM+2TM+2TM+2TM*RTM+2TM+2TM
M+2TM*RTM+2TM+2TM+2TM+2TM+2LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"@HN+B!?(DIA=F%38W)I<'0@4&]W97(@4$A0($1E8G5G9VEN9R(Z(&AT
M='`Z+R]W=W<N>F5N9"YC;VTO>F5N9"]T=70O='5T;W)I86PM1&5B=6=,:6(N
M<&AP"BXN(%]23UD@1R!"258Z(&AT='`Z+R]W=W<N8VES+G)I="YE9'4O"@I%
M>&%M<&QE"GY^?GY^?GX*.CH*"B`@("`D8V]N9B`](&%R<F%Y*"=T:71L92<@
M/3X@)U-A;7!L92!,;V<@3W5T<'5T)RD["B`@("`D;&]G9V5R(#T@)DQO9SHZ
M<VEN9VQE=&]N*"=W:6XG+"`G3&]G5VEN9&]W)RP@)VED96YT)RP@)&-O;F8I
M.PH@("`@9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("`@("`D
M;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PH@("`@?0H*"D-O;7!O<VET
M92!(86YD;&5R<PH]/3T]/3T]/3T]/3T]/3T]/3T*270@:7,@;V9T96X@=7-E
M9G5L('1O(&QO9R!E=F5N=',@=&\@;75L=&EP;&4@:&%N9&QE<G,N("!4:&4@
M3&]G('!A8VMA9V4*<')O=FED97,@82!C;VUP;W-I=&EN9R!S>7-T96T@=&AA
M="!M87)K<R!T:&ES('1A<VL@=')I=FEA;"X*"E-T87)T(&)Y(&-R96%T:6YG
M('1H92!I;F1I=FED=6%L(&QO9R!H86YD;&5R<SHZ"@H@("`@)&-O;G-O;&4@
M/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)U1%4U0G*3L*("`@
M("1F:6QE(#T@)DQO9SHZ<VEN9VQE=&]N*"=F:6QE)RP@)V]U="YL;V<G+"`G
M5$535"<I.PH*5&AE;BP@8V]N<W1R=6-T(&$@8V]M<&]S:71E(&AA;F1L97(@
M86YD(&%D9"!T:&4@:6YD:79I9'5A;"!H86YD;&5R<R!A<PIC:&EL9')E;B!O
M9B!T:&4@8V]M<&]S:71E.CH*"B`@("`D8V]M<&]S:71E(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=C;VUP;W-I=&4G*3L*("`@("1C;VUP;W-I=&4M/F%D9$-H:6QD
M*"1C;VYS;VQE*3L*("`@("1C;VUP;W-I=&4M/F%D9$-H:6QD*"1F:6QE*3L*
M"E1H92!C;VUP;W-I=&4@:&%N9&QE<B!I;7!L96UE;G1S('1H92!S=&%N9&%R
M9"!@8$QO9V!@(&EN=&5R9F%C92!S;R!Y;W4@8V%N('5S90II="!J=7-T(&QI
M:V4@86YY(&]F('1H92!O=&AE<B!H86YD;&5R<SHZ"@H@("`@)&-O;7!O<VET
M92T^;&]G*"=4:&ES(&5V96YT('=I;&P@8F4@;&]G9V5D('1O(&)O=&@@:&%N
M9&QE<G,N)RD["@I#:&EL9')E;B!C86X@8F4@<F5M;W9E9"!F<F]M('1H92!C
M;VUP;W-I=&4@=VAE;B!T:&5Y)W)E(&YO="!L;VYG97(@;F5E9&5D.CH*"B`@
M("`D8V]M<&]S:71E+3YR96UO=F5#:&EL9"@D9FEL92D["@H*3&]G($]B<V5R
M=F5R<PH]/3T]/3T]/3T]/3T]"DQO9R!O8G-E<G9E<G,@<')O=FED92!A;B!I
M;7!L96UE;G1A=&EO;B!O9B!T:&4@8&]B<V5R=F5R('!A='1E<FY@7RX@($EN
M('1H90IC;VYT96YT(&]F('1H92!,;V<@<&%C:V%G92P@=&AE>2!P<F]V:61E
M(&$@;65C:&%N:7-M(&)Y('=H:6-H('EO=2!C86X@97AA;6EN90HH:2YE+B!O
M8G-E<G9E*2!E86-H(&5V96YT(&%S(&ET(&ES(&QO9V=E9"X@(%1H:7,@86QL
M;W=S('1H92!I;7!L96UE;G1A=&EO;B!O9@IS<&5C:6%L(&)E:&%V:6]R(&)A
M<V5D(&]N('1H92!C;VYT96YT<R!O9B!A(&QO9R!E=F5N="X@($9O<B!E>&%M
M<&QE+"!T:&4*;V)S97)V97(@8V]D92!C;W5L9"!S96YD(&%N(&%L97)T(&5M
M86EL(&EF(&$@;&]G(&5V96YT(&-O;G1A:6YE9"!T:&4@<W1R:6YG"F!@4$%.
M24-@8"X*"D-R96%T:6YG(&$@;&]G(&]B<V5R=F5R(&EN=F]L=F5S(&EM<&QE
M;65N=&EN9R!A('-U8F-L87-S(&]F('1H90I@8$QO9U]O8G-E<G9E<F!@(&-L
M87-S+B`@5&AE('-U8F-L87-S(&UU<W0@;W9E<G)I9&4@=&AE(&)A<V4@8VQA
M<W,G<PI@8&YO=&EF>2@I8&`@;65T:&]D+B`@5&AI<R!M971H;V0@:7,@<&%S
M<V5D(&$@:&%S:"!C;VYT86EN:6YG('1H92!E=F5N="=S"G!R:6]R:71Y(&%N
M9"!E=F5N="X@(%1H92!S=6)C;&%S<R=S(&EM<&QE;65N=&%T:6]N(&ES(&9R
M964@=&\@86-T('5P;VX@=&AI<PII;F9O<FUA=&EO;B!I;B!A;GD@=V%Y(&ET
M(&QI:V5S+@H*3&]G(&]B<V5R=F5R<R!A<F4@871T86-H960@=&\@8&!,;V=@
M8"!I;G-T86YC97,@=FEA('1H92!@8&%T=&%C:"@I8&`@;65T:&]D.CH*"B`@
M("`D;V)S97)V97(@/2`F3&]G7V]B<V5R=F5R.CIF86-T;W)Y*"=Y;W5R5'EP
M92<I.PH@("`@)&QO9V=E<BT^871T86-H*"1O8G-E<G9E<BD["@I/8G-E<G9E
M<G,@8V%N(&)E(&1E=&%C:&5D('5S:6YG('1H92!@8&1E=&%C:"@I8&`@;65T
M:&]D.CH*"B`@("`D;&]G9V5R+3YD971A8V@H)&]B<V5R=F5R*3L*"D%T('1H
M:7,@=&EM92P@;F\@8V]N8W)E=&4@8&!,;V=?;V)S97)V97)@8"!I;7!L96UE
M;G1A=&EO;G,@87)E(&1I<W1R:6)U=&5D"G=I=&@@=&AE($QO9R!P86-K86=E
M+@H*+BX@7V]B<V5R=F5R('!A='1E<FXZ(&AT='`Z+R]P:'!P871T97)N<RYC
M;VTO:6YD97@N<&AP+V%R=&EC;&4O87)T:6-L979I97<O,C<O,2\Q+PH*"DQO
M9V=I;F<@1G)O;2!3=&%N9&%R9"!%<G)O<B!(86YD;&5R<PH]/3T]/3T]/3T]
M/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T*"DQO9V=I;F<@4$A0($5R<F]R
M<PHM+2TM+2TM+2TM+2TM+2TM+2T*4$A0)W,@9&5F875L="!E<G)O<B!H86YD
M;&5R(&-A;B!B92!O=F5R<FED9&5N('5S:6YG('1H92!@<V5T7V5R<F]R7VAA
M;F1L97(H*6!?"F9U;F-T:6]N+B`@5&AE(&-U<W1O;2!E<G)O<B!H86YD;&EN
M9R!F=6YC=&EO;B!C86X@=7-E(&$@9VQO8F%L($QO9R!I;G-T86YC92!T;PIL
M;V<@=&AE(%!(4"!E<G)O<G,N"@HJ*DYO=&4Z*BH@1F%T86P@4$A0(&5R<F]R
M<R!C86YN;W0@8F4@:&%N9&QE9"!B>2!A(&-U<W1O;2!E<G)O<B!H86YD;&5R
M(&%T('1H:7,*=&EM92X*"CHZ"@H@("`@9G5N8W1I;VX@97)R;W)(86YD;&5R
M*"1C;V1E+"`D;65S<V%G92P@)&9I;&4L("1L:6YE*0H@("`@>PH@("`@("`@
M(&=L;V)A;"`D;&]G9V5R.PH*("`@("`@("`O*B!-87`@=&AE(%!(4"!E<G)O
M<B!T;R!A($QO9R!P<FEO<FET>2X@*B\*("`@("`@("!S=VET8V@@*"1C;V1E
M*2!["B`@("`@("`@8V%S92!%7U=!4DY)3D<Z"B`@("`@("`@8V%S92!%7U53
M15)?5T%23DE.1SH*("`@("`@("`@("`@)'!R:6]R:71Y(#T@4$5!4E],3T=?
M5T%23DE.1SL*("`@("`@("`@("`@8G)E86L["B`@("`@("`@8V%S92!%7TY/
M5$E#13H*("`@("`@("!C87-E($5?55-%4E].3U1)0T4Z"B`@("`@("`@("`@
M("1P<FEO<FET>2`](%!%05)?3$]'7TY/5$E#13L*("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@8V%S92!%7T524D]2.@H@("`@("`@(&-A<V4@15]54T52
M7T524D]2.@H@("`@("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U]%4E([
M"B`@("`@("`@("`@(&)R96%K.PH@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@
M("`@("1P<FEO=&ET>2`](%!%05)?3$]'7TE.1D\["B`@("`@("`@?0H*("`@
M("`@("`D;&]G9V5R+3YL;V<H)&UE<W-A9V4@+B`G(&EN("<@+B`D9FEL92`N
M("<@870@;&EN92`G("X@)&QI;F4L"B`@("`@("`@("`@("`@("`@("`@("1P
M<FEO<FET>2D["B`@("!]"@H@("`@<V5T7V5R<F]R7VAA;F1L97(H)V5R<F]R
M2&%N9&QE<B<I.PH@("`@=')I9V=E<E]E<G)O<B@G5&AI<R!I<R!A;B!I;F9O
M<FUA=&EO;B!L;V<@;65S<V%G92XG+"!%7U5315)?3D]424-%*3L*"BXN(%]S
M971?97)R;W)?:&%N9&QE<B@I.B!H='1P.B\O=W=W+G!H<"YN970O<V5T7V5R
M<F]R7VAA;F1L97(*"DQO9V=I;F<@4$5!4B!%<G)O<G,*+2TM+2TM+2TM+2TM
M+2TM+2TM+0I4:&4@3&]G('!A8VMA9V4@8V%N(&)E('5S960@=VET:"!@4$5!
M4CHZ<V5T17)R;W)(86YD;&EN9R@I8%\G<PI@8%!%05)?15)23U)?0T%,3$)!
M0TM@8"!M96-H86YI<VT@8GD@=W)I=&EN9R!A;B!E<G)O<B!H86YD;&EN9R!F
M=6YC=&EO;B!T:&%T"G5S97,@82!G;&]B86P@3&]G(&EN<W1A;F-E+B`@2&5R
M92=S(&%N(&5X86UP;&4Z.@H*("`@(&9U;F-T:6]N(&5R<F]R2&%N9&QE<B@D
M97)R;W(I"B`@("!["B`@("`@("`@9VQO8F%L("1L;V=G97(["@H@("`@("`@
M("1M97-S86=E(#T@)&5R<F]R+3YG971-97-S86=E*"D["@H@("`@("`@(&EF
M("@A96UP='DH)&5R<F]R+3YB86-K=')A8V5;,5U;)V9I;&4G72DI('L*("`@
M("`@("`@("`@)&UE<W-A9V4@+CT@)R`H)R`N("1E<G)O<BT^8F%C:W1R86-E
M6S%=6R=F:6QE)UT["B`@("`@("`@("`@(&EF("@A96UP='DH)&5R<F]R+3YB
M86-K=')A8V5;,5U;)VQI;F4G72DI('L*("`@("`@("`@("`@("`@("1M97-S
M86=E("X]("<@870@;&EN92`G("X@)&5R<F]R+3YB86-K=')A8V5;,5U;)VQI
M;F4G73L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D;65S<V%G92`N/2`G
M*2<["B`@("`@("`@?0H*("`@("`@("`D;&]G9V5R+3YL;V<H)&UE<W-A9V4L
M("1E<G)O<BT^8V]D92D["B`@("!]"@H@("`@4$5!4CHZ<V5T17)R;W)(86YD
M;&EN9RA014%27T524D]27T-!3$Q"04-++"`G97)R;W)(86YD;&5R)RD["B`@
M("!014%2.CIR86ES945R<F]R*"=4:&ES(&ES(&%N(&EN9F]R;6%T:6]N(&QO
M9R!M97-S86=E+B<L(%!%05)?3$]'7TE.1D\I.PH*+BX@7U!%05(Z.G-E=$5R
M<F]R2&%N9&QI;F<H*3H@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU86PO96XO
M8V]R92YP96%R+G!E87(N<V5T97)R;W)H86YD;&EN9RYP:'`*"@I#=7-T;VT@
M2&%N9&QE<G,*/3T]/3T]/3T]/3T]/3T]"E1H97)E(&%R92!T:6UE<R!W:&5N
M('1H92!S=&%N9&%R9"!H86YD;&5R<R!A<F5N)W0@82!P97)F96-T(&UA=&-H
M(&9O<B!Y;W5R"FYE961S+B`@26X@=&AO<V4@<VET=6%T:6]N<RP@=&AE('-O
M;'5T:6]N(&UI9VAT(&)E('1O('=R:71E(&$@8W5S=&]M(&AA;F1L97(N"@I5
M<VEN9R!A($-U<W1O;2!(86YD;&5R"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2T*
M57-I;F<@82!C=7-T;VT@3&]G(&AA;F1L97(@:7,@=F5R>2!S:6UP;&4N("!/
M;F-E('=R:71T96X@*'-E92!@5W)I=&EN9R!.97<*2&%N9&QE<G-@7R!A;F0@
M8$5X=&5N9&EN9R!%>&ES=&EN9R!(86YD;&5R<V!?(&)E;&]W*2P@>6]U(&AA
M=F4@=&AE(&-H;VEC92!O9@IP;&%C:6YG('1H92!F:6QE(&EN('EO=7(@4$5!
M4B!I;G-T86QL871I;VXG<R!M86EN(&!@3&]G+V!@(&1I<F5C=&]R>2`H=7-U
M86QL>0IS;VUE=&AI;F<@;&EK92!@8"]U<W(O;&]C86PO;&EB+W!H<"],;V=@
M8"!O<B!@8$,Z7'!H<%QP96%R7$QO9V!@*2P@=VAE<F4@:70*8V%N(&)E(&9O
M=6YD(&%N9"!U<V4@8GD@86YY(%!(4"!A<'!L:6-A=&EO;B!O;B!T:&4@<WES
M=&5M+"!O<B!P;&%C:6YG('1H92!F:6QE"G-O;65W:&5R92!I;B!Y;W5R(&%P
M<&QI8V%T:6]N)W,@;&]C86P@:&EE<F%R8VAY(&%N9"!I;F-L=61I;F<@:70@
M8F5F;W)E('1H90IT:&4@8W5S=&]M($QO9R!O8FIE8W0@:7,@8V]N<W1R=6-T
M960N"@I-971H;V0@,3H@2&%N9&QE<B!I;B!T:&4@4W1A;F1A<F0@3&]C871I
M;VX*?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M"D%F=&5R(&-O<'EI;F<@=&AE(&AA;F1L97(@9FEL92!T;R!Y;W5R(%!%05(@
M:6YS=&%L;&%T:6]N)W,@8&!,;V<O8&`@9&ER96-T;W)Y+`IS:6UP;'D@=')E
M870@=&AE(&AA;F1L97(@87,@:68@:70@=V5R92!P87)T(&]F('1H92!S=&%N
M9&%R9"!D:7-T<FEB=71E9"X@($EF"GEO=7(@:&%N9&QE<B!I<R!N86UE9"!@
M8&-U<W1O;6!@("AA;F0@=&AE<F5F;W)E(&EM<&QE;65N=&5D(&)Y(&$@8VQA
M<W,@;F%M960*8&!,;V=?8W5S=&]M8&`I.CH*"B`@("!R97%U:7)E7V]N8V4@
M)TQO9RYP:'`G.PH*("`@("1L;V=G97(@/2`F3&]G.CIF86-T;W)Y*"=C=7-T
M;VTG+"`G)RP@)T-54U1/32<I.PH*"DUE=&AO9"`R.B!(86YD;&5R(&EN(&$@
M0W5S=&]M($QO8V%T:6]N"GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^?GY^
M?GY^?GY^?GY^"DEF('EO=2!P<F5F97(@<W1O<FEN9R!Y;W5R(&AA;F1L97(@
M:6X@>6]U<B!A<'!L:6-A=&EO;B=S(&QO8V%L(&AI97)A<F-H>2P*>6]U)VQL
M(&YE960@=&\@:6YC;'5D92!T:&%T(&9I;&4@8F5F;W)E('EO=2!C86X@8W)E
M871E(&$@3&]G(&EN<W1A;F-E(&)A<V5D(&]N"FET+@H*.CH*"B`@("!R97%U
M:7)E7V]N8V4@)TQO9RYP:'`G.PH@("`@<F5Q=6ER95]O;F-E("=,;V-A;$AA
M;F1L97)S+V-U<W1O;2YP:'`G.PH*("`@("1L;V=G97(@/2`F3&]G.CIF86-T
M;W)Y*"=C=7-T;VTG+"`G)RP@)T-54U1/32<I.PH*"E=R:71I;F<@3F5W($AA
M;F1L97)S"BTM+2TM+2TM+2TM+2TM+2TM+2TM"@I43T1/"@I%>'1E;F1I;F<@
M17AI<W1I;F<@2&%N9&QE<G,*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"@I43T1/"@H*+BX@?')E<75I<F5D?"!R97!L86-E.CH@*BI;<F5Q=6ER961=
M*BH*"BXN('9I;3H@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S;V9T=&%B<W1O
M<#TT(&5X<&%N9'1A8B!T97AT=VED=&@]-S@@9G0]<G-T.@H`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O
M97AA;7!L97,O8V]M<&]S:71E+G!H<```````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`T
M-C$@,3`U,34T,S0Q,S(@,#(U-#$S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP
M:'`G.PH*)&-O;G-O;&4@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G
M)RP@)U1%4U0G*3L*)&9I;&4@/2`F3&]G.CIS:6YG;&5T;VXH)V9I;&4G+"`G
M;W5T+FQO9R<L("=415-4)RD["@HD8V]M<&]S:71E(#T@)DQO9SHZ<VEN9VQE
M=&]N*"=C;VUP;W-I=&4G*3L*)&-O;7!O<VET92T^861D0VAI;&0H)&-O;G-O
M;&4I.PHD8V]M<&]S:71E+3YA9&1#:&EL9"@D9FEL92D["@HD8V]M<&]S:71E
M+3YL;V<H)U1H:7,@979E;G0@=VEL;"!B92!L;V=G960@=&\@8F]T:"!H86YD
M;&5R<RXG*3L*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+V1I
M<W!L87DN<&AP````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-#,P(#$P-3$U-#,T
M,3,R(#`R-3`U,@`@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B1C;VYF
M(#T@87)R87DH)V5R<F]R7W!R97!E;F0G(#T^("<\9F]N="!C;VQO<CTB(V9F
M,#`P,"(^/'1T/B<L"B`@("`@("`@("`@("`@)V5R<F]R7V%P<&5N9"<@(#T^
M("<\+W1T/CPO9F]N=#XG*3L*)&QO9V=E<B`]("9,;V<Z.G-I;F=L971O;B@G
M9&ES<&QA>2<L("<G+"`G)RP@)&-O;F8L(%!%05)?3$]'7T1%0E5'*3L*9F]R
M("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO9R@B
M3&]G(&5N=')Y("1I(BD["GT*````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]E<G)O<E]L;V<N<&AP
M```````````````````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(U,2`Q,#4Q-30S-#$S,B`P,C4T,#``
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/#]P
M:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G9V5R(#T@)DQO9SHZ
M<VEN9VQE=&]N*"=E<G)O<E]L;V<G+"!014%27TQ/1U]465!%7U-94U1%32P@
M)VED96YT)RD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D
M;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O3&]G+V1O8W,O97AA;7!L97,O9FEL92YP:'``````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`S,S`@,3`U,34T,S0Q,S(@,#(T,S(S`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_<&AP"@IR97%U:7)E
M7V]N8V4@)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G;6]D92<@/3X@,#8P
M,"P@)W1I;65&;W)M870G(#T^("<E6"`E>"<I.PHD;&]G9V5R(#T@)DQO9SHZ
M<VEN9VQE=&]N*"=F:6QE)RP@)V]U="YL;V<G+"`G:61E;G0G+"`D8V]N9BD[
M"F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R+3YL
M;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S
M+V5X86UP;&5S+VUA:6PN<&AP````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,S0R(#$P-3$U-#,T,3,R(#`R-#,S,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N
M<&AP)SL*"B1C;VYF(#T@87)R87DH)W-U8FIE8W0G(#T^("=);7!O<G1A;G0@
M3&]G($5V96YT<R<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=M86EL
M)RP@)W=E8FUA<W1E<D!E>&%M<&QE+F-O;2<L("=I9&5N="<L("1C;VYF*3L*
M9F]R("@D:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO
M9R@B3&]G(&5N=')Y("1I(BD["GT*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]N
M=6QL+G!H<```````````````````````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(P-2`Q,#4Q-30S
M-#$S,B`P,C0S-3<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/#]P:'`*"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G
M9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=N=6QL)RD["F9O<B`H)&D@/2`P.R`D
M:2`\(#$P.R`D:2LK*2!["B`@("`D;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D
M:2(I.PI]"@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O;V)S97)V97)?;6%I
M;"YP:'``````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$R,3<@,3`U,34T,S0Q,S(@,#(V,C0R
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````#P_
M<&AP"@IR97%U:7)E7V]N8V4@)TQO9R]O8G-E<G9E<BYP:'`G.PH*8VQA<W,@
M3&]G7V]B<V5R=F5R7VUA:6P@97AT96YD<R!,;V=?;V)S97)V97(*>PH@("`@
M=F%R("1?=&\@/2`G)SL*("`@('9A<B`D7W-U8FIE8W0@/2`G)SL*("`@('9A
M<B`D7W!A='1E<FX@/2`G)SL*"B`@("!F=6YC=&EO;B!,;V=?;V)S97)V97)?
M;6%I;"@D<')I;W)I='DL("1C;VYF*0H@("`@>PH@("`@("`@("\J($-A;&P@
M=&AE(&)A<V4@8VQA<W,@8V]N<W1R=6-T;W(N("HO"B`@("`@("`@)'1H:7,M
M/DQO9U]O8G-E<G9E<B@D<')I;W)I='DI.PH*("`@("`@("`O*B!#;VYF:6=U
M<F4@=&AE(&]B<V5R=F5R+B`J+PH@("`@("`@("1T:&ES+3Y?=&\@/2`D8V]N
M9ELG=&\G73L*("`@("`@("`D=&AI<RT^7W-U8FIE8W0@/2`D8V]N9ELG<W5B
M:F5C="==.PH@("`@("`@("1T:&ES+3Y?<&%T=&5R;B`]("1C;VYF6R=P871T
M97)N)UT["B`@("!]"@H@("`@9G5N8W1I;VX@;F]T:69Y*"1E=F5N="D*("`@
M('L*("`@("`@("!I9B`H<')E9U]M871C:"@D=&AI<RT^7W!A='1E<FXL("1E
M=F5N=%LG;65S<V%G92==*2`A/2`P*2!["B`@("`@("`@("`@(&UA:6PH)'1H
M:7,M/E]T;RP@)'1H:7,M/E]S=6)J96-T+"`D979E;G1;)VUE<W-A9V4G72D[
M"B`@("`@("`@?0H@("`@?0I]"@H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O<&5A<E]E
M<G)O<E]H86YD;&5R+G!H<```````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q-30@,3`U,34T,S0Q,S(@
M,#(W,C0V`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*9G5N8W1I;VX@
M97)R;W)(86YD;&5R*"1E<G)O<BD*>PH@("`@9VQO8F%L("1L;V=G97(["@H@
M("`@)&UE<W-A9V4@/2`D97)R;W(M/F=E=$UE<W-A9V4H*3L*"B`@("!I9B`H
M(65M<'1Y*"1E<G)O<BT^8F%C:W1R86-E6S%=6R=F:6QE)UTI*2!["B`@("`@
M("`@)&UE<W-A9V4@+CT@)R`H)R`N("1E<G)O<BT^8F%C:W1R86-E6S%=6R=F
M:6QE)UT["B`@("`@("`@:68@*"%E;7!T>2@D97)R;W(M/F)A8VMT<F%C95LQ
M75LG;&EN92==*2D@>PH@("`@("`@("`@("`D;65S<V%G92`N/2`G(&%T(&QI
M;F4@)R`N("1E<G)O<BT^8F%C:W1R86-E6S%=6R=L:6YE)UT["B`@("`@("`@
M?0H@("`@("`@("1M97-S86=E("X]("<I)SL*("`@('T*"B`@("`D;&]G9V5R
M+3YL;V<H)&UE<W-A9V4L("1E<G)O<BT^8V]D92D["GT*"B1L;V=G97(@/2`F
M3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)VED96YT)RD["@I014%2
M.CIS971%<G)O<DAA;F1L:6YG*%!%05)?15)23U)?0T%,3$)!0TLL("=E<G)O
M<DAA;F1L97(G*3L*4$5!4CHZ<F%I<V5%<G)O<B@G5&AI<R!I<R!A;B!I;F9O
M<FUA=&EO;B!L;V<@;65S<V%G92XG+"!014%27TQ/1U])3D9/*3L*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA;7!L97,O
M<&AP7V5R<F]R7VAA;F1L97(N<&AP````````````````````````````````
M````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$T,#`@,3`U,34T
M,S0Q,S(@,#(W,3`P`"`P````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G.PH*9G5N
M8W1I;VX@97)R;W)(86YD;&5R*"1C;V1E+"`D;65S<V%G92P@)&9I;&4L("1L
M:6YE*0I["B`@("!G;&]B86P@)&QO9V=E<CL*"B`@("`O*B!-87`@=&AE(%!(
M4"!E<G)O<B!T;R!A($QO9R!P<FEO<FET>2X@*B\*("`@('-W:71C:"`H)&-O
M9&4I('L*("`@(&-A<V4@15]705).24Y'.@H@("`@8V%S92!%7U5315)?5T%2
M3DE.1SH*("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U]705).24Y'.PH@
M("`@("`@(&)R96%K.PH@("`@8V%S92!%7TY/5$E#13H*("`@(&-A<V4@15]5
M4T527TY/5$E#13H*("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U].3U1)
M0T4["B`@("`@("`@8G)E86L["B`@("!C87-E($5?15)23U(Z"B`@("!C87-E
M($5?55-%4E]%4E)/4CH*("`@("`@("`D<')I;W)I='D@/2!014%27TQ/1U]%
M4E(["B`@("`@("`@8G)E86L["B`@("!D969A=6QT.@H@("`@("`@("1P<FEO
M=&ET>2`](%!%05)?3$]'7TE.1D\["B`@("!]"@H@("`@)&QO9V=E<BT^;&]G
M*"1M97-S86=E("X@)R!I;B`G("X@)&9I;&4@+B`G(&%T(&QI;F4@)R`N("1L
M:6YE+`H@("`@("`@("`@("`@("`@("1P<FEO<FET>2D["GT*"B1L;V=G97(@
M/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@)VED96YT)RD["@IS
M971?97)R;W)?:&%N9&QE<B@G97)R;W)(86YD;&5R)RD["G1R:6=G97)?97)R
M;W(H)U1H:7,@:7,@86X@:6YF;W)M871I;VX@;&]G(&UE<W-A9V4N)RP@15]5
M4T527TY/5$E#12D["@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O3&]G+V1O8W,O97AA
M;7!L97,O<W%L+G!H<```````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S,S0@
M,3`U,34T,S0Q,S(@,#(T,C`W`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"@IR97%U:7)E7V]N8V4@)TQO9RYP:'`G
M.PH*)&-O;F8@/2!A<G)A>2@G9'-N)R`]/B`G<&=S<6PZ+R]J;VY`;&]C86QH
M;W-T*W5N:7@O;&]G<R<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=S
M<6PG+"`G;&]G7W1A8FQE)RP@)VED96YT)RP@)&-O;F8I.PIF;W(@*"1I(#T@
M,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT
M<GD@)&DB*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-R+VQO8V%L+W!S
M82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X86UP;&5S+W-Q;&ET
M92YP:'```````````````````````````````````````````````````#`P
M,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P-S4Q(#$P-3$U-#,T,3,R
M(#`R-#<Q-``@,```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W1A<@`P,&)U:6QD97(`````````````
M````````````````````8G(`````````````````````````````````````
M```P,#`P,#`@`#`P,#`P,"``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP)SL*"B\J($-R96%T
M:6YG(&$@;F5W(&1A=&%B87-E(&-O;FYE8W1I;VXN("HO"B1C;VYF(#T@87)R
M87DH)V9I;&5N86UE)R`]/B`G;&]G+F1B)RP@)VUO9&4G(#T^(#`V-C8L("=P
M97)S:7-T96YT)R`]/B!T<G5E*3L*)&QO9V=E<B`])B!,;V<Z.F9A8W1O<GDH
M)W-Q;&ET92<L("=L;V=?=&%B;&4G+"`G:61E;G0G+"`D8V]N9BD["B1L;V=G
M97(M/FQO9R@G;&]G9VEN9R!A;B!E=F5N="<L(%!%05)?3$]'7U=!4DY)3D<I
M.PH*+RH@57-I;F<@86X@97AI<W1I;F<@9&%T86)A<V4@8V]N;F5C=&EO;BX@
M*B\*)&1B(#T@<W%L:71E7V]P96XH)VQO9RYD8B<L(#`V-C8L("1E<G)O<BD[
M"B1L;V=G97(@/28@3&]G.CIF86-T;W)Y*"=S<6QI=&4G+"`G;&]G7W1A8FQE
M)RP@)VED96YT)RP@)&1B*3L*)&QO9V=E<BT^;&]G*"=L;V=G:6YG(&%N(&5V
M96YT)RP@4$5!4E],3T=?5T%23DE.1RD["G-Q;&ET95]C;&]S92@D9&(I.PH`
M`````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E
M+W!E87(O9&]C<R],;V<O9&]C<R]E>&%M<&QE<R]S>7-L;V<N<&AP````````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#(S-"`Q,#4Q-30S-#$S,B`P,C0W,C<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````/#]P:'`*
M"G)E<75I<F5?;VYC92`G3&]G+G!H<"<["@HD;&]G9V5R(#T@)DQO9SHZ<VEN
M9VQE=&]N*"=S>7-L;V<G+"!,3T=?3$]#04PP+"`G:61E;G0G*3L*9F]R("@D
M:2`](#`[("1I(#P@,3`[("1I*RLI('L*("`@("1L;V=G97(M/FQO9R@B3&]G
M(&5N=')Y("1I(BD["GT*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O
M3&]G+V1O8W,O97AA;7!L97,O=VEN+G!H<```````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`S,C`@,3`U,34T,S0Q,S(@,#(T,C`P`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"@IR97%U:7)E7V]N
M8V4@)TQO9RYP:'`G.PH*)&-O;F8@/2!A<G)A>2@G=&ET;&4G(#T^("=386UP
M;&4@3&]G($]U='!U="<I.PHD;&]G9V5R(#T@)DQO9SHZ<VEN9VQE=&]N*"=W
M:6XG+"`G3&]G5VEN9&]W)RP@)VED96YT)RP@)&-O;F8I.PIF;W(@*"1I(#T@
M,#L@)&D@/"`Q,#L@)&DK*RD@>PH@("`@)&QO9V=E<BT^;&]G*"),;V<@96YT
M<GD@)&DB*3L*?0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+TQO9R]D;V-S+V5X
M86UP;&5S+V-O;G-O;&4N<&AP````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,C(U
M(#$P-3$U-#,T,3,R(#`R-3`U,0`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`H*<F5Q=6ER95]O;F-E("=,;V<N<&AP
M)SL*"B1L;V=G97(@/2`F3&]G.CIS:6YG;&5T;VXH)V-O;G-O;&4G+"`G)RP@
M)VED96YT)RD["F9O<B`H)&D@/2`P.R`D:2`\(#$P.R`D:2LK*2!["B`@("`D
M;&]G9V5R+3YL;V<H(DQO9R!E;G1R>2`D:2(I.PI]"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M,B`P,C,Q,C,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+UA-3%]0
M87)S97(O97AA;7!L97,O>&UL7W!A<G-E<E]F:6QE+G!H<```````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`R,#,R(#$P-3$U-#,T,3,R(#`R-S`V,P`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````\/U!(4`HO*BH*("H@97AA;7!L92!F
M;W(@6$U,7U!A<G-E<E]3:6UP;&4*("H*("H@0&%U=&AO<B`@("`@(%-T97!H
M86X@4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("H@0'!A8VMA9V4@
M("`@(%A-3%]087)S97(*("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PH*
M+RHJ"B`J(')E<75I<F4@=&AE('!A<G-E<@H@*B\*<F5Q=6ER95]O;F-E("=8
M34PO4&%R<V5R+G!H<"<["@IC;&%S<R!M>5!A<G-E<B!E>'1E;F1S(%A-3%]0
M87)S97(*>PH*("`@(&9U;F-T:6]N(&UY4&%R<V5R*"D*("`@('L*("`@("`@
M("!P87)E;G0Z.EA-3%]087)S97(H*3L*("`@('T*"B`@("\J*@H@("`@*B!H
M86YD;&4@<W1A<G0@96QE;65N=`H@("`@*@H@("`@*B!`86-C97-S("`@<')I
M=F%T90H@("`@*B!`<&%R86T@("`@<F5S;W5R8V4@("`@>&UL('!A<G-E<B!R
M97-O=7)C90H@("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@;F%M92!O9B!T
M:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@87)R87D@("`@("`@871T<FEB
M=71E<PH@("`@*B\*("`@(&9U;F-T:6]N('-T87)T2&%N9&QE<B@D>'`L("1N
M86UE+"`D871T<FEB<RD*("`@('L*("`@("`@("!P<FEN=&8H)VAA;F1L92!S
M=&%R="!T86<Z("5S/&)R("\^)RP@)&YA;64I.PH@("`@?0H*("`@+RHJ"B`@
M("`J(&AA;F1L92!S=&%R="!E;&5M96YT"B`@("`J"B`@("`J($!A8V-E<W,@
M("!P<FEV871E"B`@("`J($!P87)A;2`@("!R97-O=7)C92`@("!X;6P@<&%R
M<V5R(')E<V]U<F-E"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!N86UE
M(&]F('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A
M='1R:6)U=&5S"B`@("`J+PH@("`@9G5N8W1I;VX@96YD2&%N9&QE<B@D>'`L
M("1N86UE*0H@("`@>PH@("`@("`@('!R:6YT9B@G:&%N9&QE(&5N9"!T86<Z
M("5S/&)R("\^)RP@)&YA;64I.PH@("`@?0I]"@HD<"`]("9N97<@;7E087)S
M97(H*3L*"B1R97-U;'0@/2`D<"T^<V5T26YP=71&:6QE*"=X;6Q?<&%R<V5R
M7V9I;&4N>&UL)RD["B1R97-U;'0@/2`D<"T^<&%R<V4H*3L*/SX`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+W!S
M82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R
M<V5R7VAA;F1L97(N<&AP````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$W-S8@,3`U,34T,S0Q,S(@,#(W
M-3<W`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I;7!L90H@
M*@H@*B!`875T:&]R("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M
M=&]O;',N;F5T/@H@*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`<W5B
M<&%C:V%G92`@17AA;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@<&%R
M<V5R"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]087)S97(N<&AP)SL*"F-L87-S
M(&UY2&%N9&QE<@I["B`@("\J*@H@("`@*B!H86YD;&4@<W1A<G0@96QE;65N
M=`H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@
M("`@<F5S;W5R8V4@("`@>&UL('!A<G-E<B!R97-O=7)C90H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`
M<&%R86T@("`@87)R87D@("`@("`@871T<FEB=71E<PH@("`@*B\*("`@(&9U
M;F-T:6]N('-T87)T2&%N9&QE<B@D>'`L("1N86UE+"`D871T<FEB<RD*("`@
M('L*("`@("`@("!P<FEN=&8H)VAA;F1L92!S=&%R="!T86<Z("5S/&)R("\^
M)RP@)&YA;64I.PH@("`@?0H*("`@+RHJ"B`@("`J(&AA;F1L92!S=&%R="!E
M;&5M96YT"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E"B`@("`J($!P
M87)A;2`@("!R97-O=7)C92`@("!X;6P@<&%R<V5R(')E<V]U<F-E"B`@("`J
M($!P87)A;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H92!E;&5M96YT"B`@
M("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S"B`@("`J+PH@
M("`@9G5N8W1I;VX@96YD2&%N9&QE<B@D>'`L("1N86UE*0H@("`@>PH@("`@
M("`@('!R:6YT9B@G:&%N9&QE(&5N9"!T86<Z("5S/&)R("\^)RP@)&YA;64I
M.PH@("`@?0I]"@HD<"`]("9N97<@6$U,7U!A<G-E<B@I.PHD:"`]("9N97<@
M;7E(86YD;&5R*"D["@HD<F5S=6QT(#T@)'`M/G-E=$EN<'5T1FEL92@G>&UL
M7W!A<G-E<E]F:6QE+GAM;"<I.PHD<F5S=6QT(#T@)'`M/G-E=$AA;F1L97)/
M8FHH)&@I.PHD<F5S=6QT(#T@)'`M/G!A<G-E*"D["C\^``!U<W(O;&]C86PO
M<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X
M;6Q?<&%R<V5R7W-I;7!L93$N<&AP````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(Q-C8@,3`U,34T,S0Q
M,S(@,#(W-3(V`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I
M;7!L90H@*@H@*B`D260Z('AM;%]P87)S97)?<VEM<&QE,2YP:'`L=B`Q+C,@
M,C`P-"\P-2\R."`Q-CHP.3HT."!S8VAS="!%>'`@)`H@*@H@*B!`875T:&]R
M("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M=&]O;',N;F5T/@H@
M*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`<W5B<&%C:V%G92`@17AA
M;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@<&%R<V5R"B`J+PIR97%U
M:7)E7V]N8V4@)UA-3"]087)S97(O4VEM<&QE+G!H<"<["@IC;&%S<R!M>5!A
M<G-E<B!E>'1E;F1S(%A-3%]087)S97)?4VEM<&QE"GL*("`@(&9U;F-T:6]N
M(&UY4&%R<V5R*"D*("`@('L*("`@("`@("`D=&AI<RT^6$U,7U!A<G-E<E]3
M:6UP;&4H*3L*("`@('T*"B`@("\J*@H@("`@*B!H86YD;&4@=&AE(&5L96UE
M;G0*("`@("H*("`@("H@5&AE(&5L96UE;G0@=VEL;"!B92!H86YD;&5D+"!O
M;F-E(&ET)W,@8VQO<V5D"B`@("`J"B`@("`J($!A8V-E<W,@("!P<FEV871E
M"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!N86UE(&]F('1H92!E;&5M
M96YT"B`@("`J($!P87)A;2`@("!A<G)A>2`@("`@("!A='1R:6)U=&5S(&]F
M('1H92!E;&5M96YT"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!C:&%R
M86-T97(@9&%T82!O9B!T:&4@96QE;65N=`H@("`@*B\*("`@(&9U;F-T:6]N
M(&AA;F1L945L96UE;G0H)&YA;64L("1A='1R:6)S+"`D9&%T82D*("`@('L*
M("`@("`@("!P<FEN=&8H)VAA;F1L:6YG("5S(&EN('1A9R!D97!T:"`E9#QB
M<B`O/B<L("1N86UE+"`D=&AI<RT^9V5T0W5R<F5N=$1E<'1H*"DI.PH@("`@
M("`@('!R:6YT9B@G8VAA<F%C=&5R(&1A=&$Z("5S/&)R("\^)RP@)&1A=&$@
M*3L*("`@("`@("!P<FEN="`G071T<FEB=71E<SH\8G(@+SXG.PH@("`@("`@
M('!R:6YT("<\<')E/B<["B`@("`@("`@<')I;G1?<B@@)&%T=')I8G,@*3L*
M("`@("`@("!P<FEN="`G/"]P<F4^)SL*("`@("`@("!P<FEN="`G/&)R("\^
M)SL*("`@('T*?0H*)'`@/2`F;F5W(&UY4&%R<V5R*"D["@HD<F5S=6QT(#T@
M)'`M/G-E=$EN<'5T1FEL92@G>&UL7W!A<G-E<E]S:6UP;&4Q+GAM;"<I.PHD
M<F5S=6QT(#T@)'`M/G!A<G-E*"D["C\^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C
M<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?<VEM<&QE,2YX;6P`
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`P,#,Q-R`Q,#4Q-30S-#$S,B`P,C<U,S,`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/"$M+2`D260Z('AM;%]P
M87)S97)?<VEM<&QE,2YX;6PL=B`Q+C(@,C`P-"\P-2\R-"`R,3HT,CHS,R!S
M8VAS="!%>'`@)"`M+3X*/&9O;SX*("`@(#QB87(^8V]N=&5N="!O9B!B87(\
M+V)A<CX*("`@(#QE;7!T>2\^"B`@("`\87)G:"!F;V\](F)A<B(^"B`@("`@
M("`@=&5S=`H@("`@("`@(#QT;VUA=&\^<&EZ>F$\+W1O;6%T;SX*("`@(#PO
M87)G:#X*/"]F;V\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O6$U,7U!A<G-E
M<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L93(N<&AP````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#(U
M,C0@,3`U,34T,S0Q,S(@,#(W-3(U`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_4$A0"B\J*@H@*B!E>&%M<&QE(&9O<B!8
M34Q?4&%R<V5R7U-I;7!L90H@*@H@*B`D260Z('AM;%]P87)S97)?<VEM<&QE
M,BYP:'`L=B`Q+C$@,C`P-"\P-2\R-"`R,3HT,CHS,R!S8VAS="!%>'`@)`H@
M*@H@*B!`875T:&]R("`@("`@4W1E<&AA;B!38VAM:61T(#QS8VAS=$!P:'`M
M=&]O;',N;F5T/@H@*B!`<&%C:V%G92`@("`@6$U,7U!A<G-E<@H@*B!`<W5B
M<&%C:V%G92`@17AA;7!L97,*("HO"@HO*BH*("H@<F5Q=6ER92!T:&4@<&%R
M<V5R"B`J+PIR97%U:7)E7V]N8V4@)UA-3"]087)S97(O4VEM<&QE+G!H<"<[
M"@IC;&%S<R!M>5!A<G-E<C(@97AT96YD<R!834Q?4&%R<V5R7U-I;7!L90I[
M"B`@("!F=6YC=&EO;B!M>5!A<G-E<B@I"B`@("!["B`@("`@("`@)'1H:7,M
M/EA-3%]087)S97)?4VEM<&QE*"D["B`@("!]"@H@("`O*BH*("`@("H@:&%N
M9&QE('1H92!C871E9V]R>2!E;&5M96YT"B`@("`J"B`@("`J(%1H92!E;&5M
M96YT('=I;&P@8F4@:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E9`H@("`@*@H@
M("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R86T@("`@87)R
M87D@("`@("`@871T<FEB=71E<R!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@=&AE(&5L96UE
M;G0*("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT7V-A=&5G;W)Y
M*"1N86UE+"`D871T<FEB<RP@)&1A=&$I"B`@("!["B`@("`@("`@<')I;G1F
M*"`G0V%T96=O<GD@:7,@)7,\8G(@+SXG+"`D9&%T82`I.PH@("`@?0H*("`@
M+RHJ"B`@("`J(&AA;F1L92!T:&4@;F%M92!E;&5M96YT"B`@("`J"B`@("`J
M(%1H92!E;&5M96YT('=I;&P@8F4@:&%N9&QE9"P@;VYC92!I="=S(&-L;W-E
M9`H@("`@*@H@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("`@("`@;F%M92!O9B!T:&4@96QE;65N=`H@("`@*B!`<&%R
M86T@("`@87)R87D@("`@("`@871T<FEB=71E<R!O9B!T:&4@96QE;65N=`H@
M("`@*B!`<&%R86T@("`@<W1R:6YG("`@("`@8VAA<F%C=&5R(&1A=&$@;V8@
M=&AE(&5L96UE;G0*("`@("HO"B`@("!F=6YC=&EO;B!H86YD;&5%;&5M96YT
M7VYA;64H)&YA;64L("1A='1R:6)S+"`D9&%T82D*("`@('L*("`@("`@("!P
M<FEN=&8H("=.86UE(&ES("5S/&)R("\^)RP@)&1A=&$@*3L*("`@('T*?0H*
M)'`@/2`F;F5W(&UY4&%R<V5R,B@I.PHD<F5S=6QT(#T@)'`M/G-E=$EN<'5T
M1FEL92@G>&UL7W!A<G-E<E]S:6UP;&4R+GAM;"<I.PHD<"T^<V5T36]D92@G
M9G5N8R<I.PHD<F5S=6QT(#T@)'`M/G!A<G-E*"D["C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO
M<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S+WAM;%]P87)S97)?
M<VEM<&QE,BYX;6P````````````````````````````````P,#`V-#0@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#(S,"`Q,#4Q-30S-#$S,B`P,C<U,C8`
M(#``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````/"$M
M+2`D260Z('AM;%]P87)S97)?<VEM<&QE,BYX;6PL=B`Q+C$@,C`P-"\P-2\R
M-"`R,3HT,CHS,R!S8VAS="!%>'`@)"`M+3X*/'!A8VMA9V4^"B`@("`\8V%T
M96=O<GD^6$U,/"]C871E9V]R>3X*("`@(#QN86UE/EA-3%]087)S97(\+VYA
M;64^"CPO<&%C:V%G93X`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O
M8W,O6$U,7U!A<G-E<B]E>&%M<&QE<R]X;6Q?<&%R<V5R7W-I;7!L95]H86YD
M;&5R+G!H<```````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#(T-S(@,3`U,34T,S0Q,S(@,#,Q,30R`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````#P_4$A0"B\J*@H@*B!E
M>&%M<&QE(&9O<B!834Q?4&%R<V5R7U-I;7!L90H@*@H@*B`D260Z('AM;%]P
M87)S97)?<VEM<&QE7VAA;F1L97(N<&AP+'8@,2XQ(#(P,#0O,#4O,C4@,3,Z
M,C8Z-#(@<V-H<W0@17AP("0*("H*("H@0&%U=&AO<B`@("`@(%-T97!H86X@
M4V-H;6ED="`\<V-H<W1`<&AP+71O;VQS+FYE=#X*("H@0'!A8VMA9V4@("`@
M(%A-3%]087)S97(*("H@0'-U8G!A8VMA9V4@($5X86UP;&5S"B`J+PH*+RHJ
M"B`J(')E<75I<F4@=&AE('!A<G-E<@H@*B\*<F5Q=6ER95]O;F-E("=834PO
M4&%R<V5R+U-I;7!L92YP:'`G.PH*8VQA<W,@;7E(86YD;&5R4VEM<&QE"GL*
M("`@+RHJ"B`@("`J(&AA;F1L92!T:&4@8V%T96=O<GD@96QE;65N=`H@("`@
M*@H@("`@*B!4:&4@96QE;65N="!W:6QL(&)E(&AA;F1L960L(&]N8V4@:70G
M<R!C;&]S960*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A=&4*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L96UE;G0*("`@
M("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I8G5T97,@;V8@=&AE(&5L
M96UE;G0*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&-H87)A8W1E<B!D
M871A(&]F('1H92!E;&5M96YT"B`@("`J+PH@("`@9G5N8W1I;VX@:&%N9&QE
M16QE;65N=%]C871E9V]R>2@D;F%M92P@)&%T=')I8G,L("1D871A*0H@("`@
M>PH@("`@("`@('!R:6YT9B@@)T-A=&5G;W)Y(&ES("5S/&)R("\^)RP@)&1A
M=&$@*3L*("`@('T*"B`@("\J*@H@("`@*B!H86YD;&4@=&AE(&YA;64@96QE
M;65N=`H@("`@*@H@("`@*B!4:&4@96QE;65N="!W:6QL(&)E(&AA;F1L960L
M(&]N8V4@:70G<R!C;&]S960*("`@("H*("`@("H@0&%C8V5S<R`@('!R:79A
M=&4*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&YA;64@;V8@=&AE(&5L
M96UE;G0*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@("`@(&%T=')I8G5T97,@
M;V8@=&AE(&5L96UE;G0*("`@("H@0'!A<F%M("`@('-T<FEN9R`@("`@(&-H
M87)A8W1E<B!D871A(&]F('1H92!E;&5M96YT"B`@("`J+PH@("`@9G5N8W1I
M;VX@:&%N9&QE16QE;65N=%]N86UE*"1N86UE+"`D871T<FEB<RP@)&1A=&$I
M"B`@("!["B`@("`@("`@<')I;G1F*"`G3F%M92!I<R`E<SQB<B`O/B<L("1D
M871A("D["B`@("!]"GT*"B1P(#T@)FYE=R!834Q?4&%R<V5R7U-I;7!L92@I
M.PHD:"`]("9N97<@;7E(86YD;&5R4VEM<&QE*"D["B1P+3YS971(86YD;&5R
M3V)J*"1H*3L*)')E<W5L="`]("1P+3YS971);G!U=$9I;&4H)WAM;%]P87)S
M97)?<VEM<&QE,BYX;6PG*3L*)'`M/G-E=$UO9&4H)V9U;F,G*3L*)')E<W5L
M="`]("1P+3YP87)S92@I.PH_/@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]834Q?4&%R<V5R+V5X86UP;&5S
M+WAM;%]P87)S97)?9FEL92YX;6P`````````````````````````````````
M```P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#$R-R`Q,#4Q-30S
M-#$S,B`P,C<P-S<`(#``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````/&9O;SX*("`@(#QB87(^8V]N=&5N="!O9B!B87(\+V)A<CX*
M("`@(#QE;7!T>2\^"B`@("`\87)G:"!F;V\](F)A<B(^=&5S=#PO87)G:#X*
M/"]F;V\^````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O3F5T7U--5%`O9&]C<P``````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S(@,#(Q-C4R
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O9&]C<R].971?4TU44"]D;V-S
M+V5X86UP;&5S````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$S,B`P,C,T-S``(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D
M;V-S+TYE=%]33510+V1O8W,O9W5I9&4N='AT````````````````````````
M`````````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#$T,S0R(#$P-3$U-#,T,3,R(#`R,S4W,P`@,```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"B!4:&4@3F5T7U--5%`@4&%C:V%G90H]/3T]/3T]/3T]/3T]
M/3T]/3T]/3T]"@HM+2TM+2TM+2TM+2TM+2TM+2TM+0H@57-E<B!$;V-U;65N
M=&%T:6]N"BTM+2TM+2TM+2TM+2TM+2TM+2TM"@HZ075T:&]R.B`@("!*;VX@
M4&%R:7-E"CI#;VYT86-T.B`@(&IO;D!P:'`N;F5T"CI$871E.B`@("`@("1$
M871E.B`R,#`U+S`S+S`T(#`S.C,U.C0U("0*.E)E=FES:6]N.B`@)%)E=FES
M:6]N.B`Q+C4@)`H*+BX@8V]N=&5N=',Z.B!486)L92!O9B!#;VYT96YT<PHN
M+B!S96-T:6]N+6YU;6)E<FEN9SHZ"@I$97!E;F1E;F-I97,*/3T]/3T]/3T]
M/3T]"@I4:&4@8%!%05)?17)R;W)@($-L87-S"BTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*"E1H92!.971?4TU44"!P86-K86=E('5S97,@=&AE(&!014%27T5R
M<F]R8%\@8VQA<W,@9F]R(&%L;"!O9B!I=',@8&5R<F]R"FAA;F1L:6YG8%\N
M"@I4:&4@8$YE=%]3;V-K971@(%!A8VMA9V4*+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM"@I4:&4@3F5T7U-O8VME=%\@<&%C:V%G92!I<R!U<V5D(&%S('1H
M92!B87-I<R!F;W(@86QL(&YE='=O<FL@8V]M;75N:6-A=&EO;G,N"@I4:&4@
M8$%U=&A?4T%33&`@4&%C:V%G90HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*
M5&AE(&!!=71H7U-!4TQ@7R!P86-K86=E(&ES(&%N(&]P=&EO;F%L(&1E<&5N
M9&5N8WDN("!)9B!I="!I<R!A=F%I;&%B;&4L('1H90I.971?4TU44"!P86-K
M86=E('=I;&P@8F4@86)L92!T;R!S=7!P;W)T('1H92!$24=%4U0M340U7R!A
M;F0@0U)!32U-1#5?(%--5%`*875T:&5N=&EC871I;VX@;65T:&]D<RX@($]T
M:&5R=VES92P@;VYL>2!T:&4@3$]'24Y?(&%N9"!03$%)3E\@;65T:&]D<R!W
M:6QL"F)E(&%V86EL86)L92X*"D5R<F]R($AA;F1L:6YG"CT]/3T]/3T]/3T]
M/3T]"@I!;&P@;V8@=&AE($YE=%]33510(&-L87-S)W,@<'5B;&EC(&UE=&AO
M9',@<F5T=7)N(&$@4$5!4E]%<G)O<E\@;V)J96-T(&EF(&%N"F5R<F]R(&]C
M8W5R<RX@(%1H92!S=&%N9&%R9"!W87D@=&\@8VAE8VL@9F]R(&$@4$5!4E]%
M<G)O<B!O8FIE8W0@:7,@8GD@=7-I;F<*8%!%05(Z.FES17)R;W(H*6!?.CH*
M"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D97)R;W(@/2`D<VUT<"T^8V]N;F5C
M="@I*2D@>PH@("`@("`@(&1I92@D97)R;W(M/F=E=$UE<W-A9V4H*2D["B`@
M("!]"@HN+B!?4$5!4CHZ:7-%<G)O<B@I.B!H='1P.B\O<&5A<BYP:'`N;F5T
M+VUA;G5A;"]E;B]C;W)E+G!E87(N<&5A<BYI<V5R<F]R+G!H<`H*4TU44"!!
M=71H96YT:6-A=&EO;@H]/3T]/3T]/3T]/3T]/3T]/3T]"@I4:&4@3F5T7U--
M5%`@<&%C:V%G92!S=7!P;W)T<R!T:&4@4TU44"!A=71H96YT:6-A=&EO;B!S
M=&%N9&%R9"`H87,@9&5F:6YE9`IB>2!21D,M,C4U-%\I+B`@5&AE($YE=%]3
M3510('!A8VMA9V4@<W5P<&]R=',@=&AE(&9O;&QO=VEN9R!A=71H96YT:6-A
M=&EO;@IM971H;V1S+"!I;B!O<F1E<B!O9B!P<F5F97)E;F-E.@H*+BX@7U)&
M0RTR-34T.B!H='1P.B\O=W=W+FEE=&8N;W)G+W)F8R]R9F,R-34T+G1X=`H*
M1$E'15-4+4U$-0HM+2TM+2TM+2TM"@I4:&4@1$E'15-4+4U$-2!A=71H96YT
M:6-A=&EO;B!M971H;V0@=7-E<R!@4E-!($1A=&$@4V5C=7)I='D@26YC+F!?
M)W,@340U"DUE<W-A9V4@1&EG97-T(&%L9V]R:71H;2X@($ET(&ES(&-O;G-I
M9&5R960@=&AE(&UO<W0@<V5C=7)E(&UE=&AO9"!O9B!33510"F%U=&AE;G1I
M8V%T:6]N+@H**BI.;W1E.BHJ(%1H92!$24=%4U0M340U(&%U=&AE;G1I8V%T
M:6]N(&UE=&AO9"!I<R!O;FQY('-U<'!O<G1E9"!I9B!T:&4*05542%]305-,
M7R!P86-K86=E(&ES(&%V86EL86)L92X*"BXN(%]24T$@1&%T82!396-U<FET
M>2!);F,N.B!H='1P.B\O=W=W+G)S87-E8W5R:71Y+F-O;2\*"D-204TM340U
M"BTM+2TM+2TM"@I4:&4@0U)!32U-1#4@875T:&5N=&EC871I;VX@;65T:&]D
M(&AA<R!B965N('-U<&5R<V5D960@8GD@=&AE($1)1T535"U-1#5?"FUE=&AO
M9"!I;B!T97)M<R!O9B!S96-U<FET>2X@($ET(&ES('!R;W9I9&5D(&AE<F4@
M9F]R(&-O;7!A=&EB:6QI='D@=VET:`IO;&1E<B!33510('-E<G9E<G,@=&AA
M="!M87D@;F]T('-U<'!O<G0@=&AE(&YE=V5R($1)1T535"U-1#4@86QG;W)I
M=&AM+@H**BI.;W1E.BHJ(%1H92!#4D%-+4U$-2!A=71H96YT:6-A=&EO;B!M
M971H;V0@:7,@;VYL>2!S=7!P;W)T960@:68@=&AE"D%55$A?4T%33%\@<&%C
M:V%G92!I<R!A=F%I;&%B;&4N"@I,3T=)3@HM+2TM+0H*5&AE($Q/1TE.(&%U
M=&AE;G1I8V%T:6]N(&UE=&AO9"!E;F-R>7!T<R!T:&4@=7-E<B=S('!A<W-W
M;W)D('5S:6YG('1H90I"87-E-C1?(&5N8V]D:6YG('-C:&5M92X@($)E8V%U
M<V4@9&5C<GEP=&EN9R!A($)A<V4V-"UE;F-O9&5D('-T<FEN9R!I<PIT<FEV
M:6%L+"!,3T=)3B!I<R!N;W0@8V]N<VED97)E9"!A('-E8W5R92!A=71H96YT
M:6-A=&EO;B!M971H;V0@86YD('-H;W5L9`IB92!A=F]I9&5D+@H*+BX@7T)A
M<V4V-#H@:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]F=6YC=&EO;BYB
M87-E-C0M96YC;V1E+G!H<`H*4$Q!24X*+2TM+2T*"E1H92!03$%)3B!A=71H
M96YT:6-A=&EO;B!M971H;V0@<V5N9',@=&AE('5S97(G<R!P87-S=V]R9"!I
M;B!P;&%I;B!T97AT+@I4:&ES(&UE=&AO9"!O9B!A=71H96YT:6-A=&EO;B!I
M<R!N;W0@<V5C=7)E(&%N9"!S:&]U;&0@8F4@879O:61E9"X*"E-E8W5R92!#
M;VYN96-T:6]N<PH]/3T]/3T]/3T]/3T]/3T]/3T*"DEF(&!S96-U<F4@<V]C
M:V5T('1R86YS<&]R='-@7R!H879E(&)E96X@96YA8FQE9"!I;B!02%`L(&ET
M(&ES('!O<W-I8FQE('1O"F5S=&%B;&ES:"!A('-E8W5R92!C;VYN96-T:6]N
M('1O('1H92!R96UO=&4@4TU44"!S97)V97(Z.@H*("`@("1S;71P(#T@;F5W
M($YE=%]33510*"=S<VPZ+R]M86EL+F5X86UP;&4N8V]M)RP@-#8U*3L*"E1H
M:7,@97AA;7!L92!C;VYN96-T<R!T;R!@;6%I;"YE>&%M<&QE+F-O;6`@;VX@
M<&]R="`T-C4@*&$@8V]M;6]N(%--5%!3"G!O<G0I('5S:6YG('1H92!@<W-L
M.B\O8"!T<F%N<W!O<G0N"@HN+B!?<V5C=7)E('-O8VME="!T<F%N<W!O<G1S
M.B!H='1P.B\O=W=W+G!H<"YN970O=')A;G-P;W)T<PH*1&%T82!1=6]T:6YG
M"CT]/3T]/3T]/3T]/0H*0GD@9&5F875L="P@86QL(&]U=&)O=6YD('-T<FEN
M9R!D871A(&ES('%U;W1E9"!I;B!A8V-O<F1A;F-E('=I=&@@4TU44`IS=&%N
M9&%R9',N("!4:&ES(&UE86YS('1H870@86QL(&YA=&EV92!5;FEX("A@7%QN
M8"D@86YD($UA8R`H8%Q<<F`I(&QI;F4*96YD:6YG<R!A<F4@8V]N=F5R=&5D
M('1O($EN=&5R;F5T+7-T86YD87)D($-23$8@*&!<7')<7&Y@*2!L:6YE(&5N
M9&EN9W,N"D%L<V\L(&)E8V%U<V4@=&AE(%--5%`@<')O=&]C;VP@=7-E<R!A
M('-I;F=L92!L96%D:6YG('!E<FEO9"`H8"Y@*2!T;R!S:6=N86P*86X@96YD
M('1O('1H92!M97-S86=E(&1A=&$L('-I;F=L92!L96%D:6YG('!E<FEO9',@
M:6X@=&AE(&]R:6=I;F%L(&1A=&$*<W1R:6YG(&%R92`B9&]U8FQE9"(@*&4N
M9RX@(F`N+F`B*2X*"E1H97-E('-T<FEN9R!T<F%N<V9O<FUA=&EO;B!C86X@
M8F4@97AP96YS:79E('=H96X@;&%R9V4@8FQO8VMS(&]F(&1A=&$@87)E"FEN
M=F]L=F5D+B`@1F]R(&5X86UP;&4L('1H92!.971?4TU44"!P86-K86=E(&ES
M(&YO="!A=V%R92!O9B!-24U%('!A<G1S("AI=`IJ=7-T('-E97,@=&AE($U)
M344@;65S<V%G92!A<R!O;F4@8FEG('-T<FEN9R!O9B!C:&%R86-T97)S*2P@
M<V\@:70@:7,@;F]T"F%B;&4@=&\@<VMI<"!N;VXM=&5X="!A='1A8VAM96YT
M<R!W:&5N('-E87)C:&EN9R!F;W(@8VAA<F%C=&5R<R!T:&%T(&UA>0IN965D
M('1O(&)E('%U;W1E9"X*"D)E8V%U<V4@;V8@=&AI<RP@:70@:7,@<&]S<VEB
M;&4@=&\@97AT96YD('1H92!.971?4TU44"!C;&%S<R!I;B!O<F1E<B!T;PII
M;7!L96UE;G0@>6]U<B!O=VX@8W5S=&]M('%U;W1I;F<@<F]U=&EN92X@($IU
M<W0@8W)E871E(&$@;F5W(&-L87-S(&)A<V5D(&]N"G1H92!.971?4TU44"!C
M;&%S<R!A;F0@<F5I;7!L96UE;G0@=&AE(&!Q=6]T961A=&$H*6`@;65T:&]D
M.CH*"B`@("!R97%U:7)E("=.971?4TU44"YP:'`G.PH*("`@(&-L87-S($YE
M=%]335107V-U<W1O;2!E>'1E;F1S($YE=%]33510"B`@("!["B`@("`@("`@
M9G5N8W1I;VX@<75O=&5D871A*"1D871A*0H@("`@("`@('L*("`@("`@("`@
M("`@+RH@4&5R9F]R;2!C=7-T;VT@9&%T82!Q=6]T:6YG("HO"B`@("`@("`@
M?0H@("`@?0H*3F]T92!T:&%T('1H92!@)&1A=&%@('!A<F%M971E<B!W:6QL
M(&)E('!A<W-E9"!T;R!T:&4@8'%U;W1E9&%T82@I8"!F=6YC=&EO;@I@8GD@
M<F5F97)E;F-E8%\N("!4:&ES(&UE86YS('1H870@>6]U(&-A;B!O<&5R871E
M(&1I<F5C=&QY(&]N(&`D9&%T86`N("!)=`IA;'-O('1H92!O=F5R:&5A9"!O
M9B!C;W!Y:6YG(&$@;&%R9V4@8"1D871A8"!S=')I;F<@=&\@86YD(&9R;VT@
M=&AE"F!Q=6]T961A=&$H*6`@;65T:&]D+@H*+BX@7V)Y(')E9F5R96YC93H@
M:'1T<#HO+W=W=RYP:'`N;F5T+VUA;G5A;"]E;B]L86YG=6%G92YR969E<F5N
M8V5S+G!A<W,N<&AP"@I$96)U9V=I;F<*/3T]/3T]/3T]"@I4:&4@3F5T7U--
M5%`@<&%C:V%G92!C;VYT86EN<R!B=6EL="UI;B!D96)U9V=I;F<@;W5T<'5T
M(')O=71I;F5S("AD:7-A8FQE9`IB>2!D969A=6QT*2X@($1E8G5G9VEN9R!O
M=71P=70@;75S="!B92!E>'!L:6-I=&QY(&5N86)L960@=FEA('1H92!S971$
M96)U9R@I"FUE=&AO9#HZ"@H@("`@)'-M='`M/G-E=$1E8G5G*'1R=64I.PH*
M5&AE(&1E8G5G9VEN9R!M97-S86=E<R!W:6QL(&)E('-E;G0@=&\@=&AE('-T
M86YD87)D(&]U='!U="!S=')E86TN"@I%>&%M<&QE<PH]/3T]/3T]/0H*0F%S
M:6,@57-E"BTM+2TM+2TM+0H*5&AE(&9O;&QO=VEN9R!S8W)I<'0@9&5M;VYS
M=')A=&5S(&AO=R!A('-I;7!L92!E;6%I;"!M97-S86=E(&-A;B!B92!S96YT
M"G5S:6YG('1H92!.971?4TU44"!P86-K86=E.CH*"B`@("!R97%U:7)E("=.
M970O4TU44"YP:'`G.PH*("`@("1H;W-T(#T@)VUA:6PN97AA;7!L92YC;VTG
M.PH@("`@)&9R;VT@/2`G=7-E<D!E>&%M<&QE+F-O;2<["B`@("`D<F-P="`]
M(&%R<F%Y*"=R96-I<&EE;G0Q0&5X86UP;&4N8V]M)RP@)W)E8VEP:65N=#)`
M97AA;7!L92YC;VTG*3L*("`@("1S=6)J(#T@(E-U8FIE8W0Z(%1E<W0@365S
M<V%G95QN(CL*("`@("1B;V1Y(#T@(D)O9'D@3&EN92`Q7&Y";V1Y($QI;F4@
M,B(["@H@("`@+RH@0W)E871E(&$@;F5W($YE=%]33510(&]B:F5C="X@*B\*
M("`@(&EF("@A("@D<VUT<"`](&YE=R!.971?4TU44"@D:&]S="DI*2!["B`@
M("`@("`@9&EE*")5;F%B;&4@=&\@:6YS=&%N=&EA=&4@3F5T7U--5%`@;V)J
M96-T7&XB*3L*("`@('T*"B`@("`O*B!#;VYN96-T('1O('1H92!33510('-E
M<G9E<BX@*B\*("`@(&EF("A014%2.CII<T5R<F]R*"1E(#T@)'-M='`M/F-O
M;FYE8W0H*2DI('L*("`@("`@("!D:64H)&4M/F=E=$UE<W-A9V4H*2`N(")<
M;B(I.PH@("`@?0H*("`@("\J(%-E;F0@=&AE("=-04E,($923TTZ)R!33510
M(&-O;6UA;F0N("HO"B`@("!I9B`H4$5!4CHZ:7-%<G)O<B@D<VUT<"T^;6%I
M;$9R;VTH)&9R;VTI*2D@>PH@("`@("`@(&1I92@B56YA8FQE('1O('-E="!S
M96YD97(@=&\@/"1F<F]M/EQN(BD["B`@("!]"@H@("`@+RH@061D<F5S<R!T
M:&4@;65S<V%G92!T;R!E86-H(&]F('1H92!R96-I<&EE;G1S+B`J+PH@("`@
M9F]R96%C:"`H)')C<'0@87,@)'1O*2!["B`@("`@("`@:68@*%!%05(Z.FES
M17)R;W(H)')E<R`]("1S;71P+3YR8W!T5&\H)'1O*2DI('L*("`@("`@("`@
M("`@9&EE*")5;F%B;&4@=&\@861D(')E8VEP:65N="`\)'1O/CH@(B`N("1R
M97,M/F=E=$UE<W-A9V4H*2`N(")<;B(I.PH@("`@("`@('T*("`@('T*"B`@
M("`O*B!3970@=&AE(&)O9'D@;V8@=&AE(&UE<W-A9V4N("HO"B`@("!I9B`H
M4$5!4CHZ:7-%<G)O<B@D<VUT<"T^9&%T82@D<W5B:B`N(")<<EQN(B`N("1B
M;V1Y*2DI('L*("`@("`@("!D:64H(E5N86)L92!T;R!S96YD(&1A=&%<;B(I
M.PH@("`@?0H*("`@("\J($1I<V-O;FYE8W0@9G)O;2!T:&4@4TU44"!S97)V
M97(N("HO"B`@("`D<VUT<"T^9&ES8V]N;F5C="@I.PH*+BX@7U!%05)?17)R
M;W(Z(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+V-O<F4N<&5A<BYP
M96%R+65R<F]R+G!H<`HN+B!?3F5T7U-O8VME=#H@:'1T<#HO+W!E87(N<&AP
M+FYE="]P86-K86=E+TYE=%]3;V-K970*+BX@7T%U=&A?4T%33#H@:'1T<#HO
M+W!E87(N<&AP+FYE="]P86-K86=E+T%U=&A?4T%33`H*+BX@=FEM.B!T86)S
M=&]P/30@<VAI9G1W:61T:#TT('-O9G1T86)S=&]P/30@97AP86YD=&%B('1E
M>'1W:61T:#TW-CH*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R].971?4TU44"]D;V-S+V5X86UP;&5S+V)A<VEC
M+G!H<``````````````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,3<V-2`Q,#4Q-30S-#$S,B`P,C4S
M-3(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*"G)E<75I<F4@)TYE="]33510+G!H<"<["@HD:&]S="`]("=M86EL
M+F5X86UP;&4N8V]M)SL*)&9R;VT@/2`G=7-E<D!E>&%M<&QE+F-O;2<["B1R
M8W!T(#T@87)R87DH)W)E8VEP:65N=#%`97AA;7!L92YC;VTG+"`G<F5C:7!I
M96YT,D!E>&%M<&QE+F-O;2<I.PHD<W5B:B`](")3=6)J96-T.B!497-T($UE
M<W-A9V5<;B(["B1B;V1Y(#T@(D)O9'D@3&EN92`Q7&Y";V1Y($QI;F4@,B([
M"@HO*B!#<F5A=&4@82!N97<@3F5T7U--5%`@;V)J96-T+B`J+PII9B`H(2`H
M)'-M='`@/2!N97<@3F5T7U--5%`H)&AO<W0I*2D@>PH@("`@9&EE*")5;F%B
M;&4@=&\@:6YS=&%N=&EA=&4@3F5T7U--5%`@;V)J96-T7&XB*3L*?0H*+RH@
M0V]N;F5C="!T;R!T:&4@4TU44"!S97)V97(N("HO"FEF("A014%2.CII<T5R
M<F]R*"1E(#T@)'-M='`M/F-O;FYE8W0H*2DI('L*("`@(&1I92@D92T^9V5T
M365S<V%G92@I("X@(EQN(BD["GT*"B\J(%-E;F0@=&AE("=-04E,($923TTZ
M)R!33510(&-O;6UA;F0N("HO"FEF("A014%2.CII<T5R<F]R*"1S;71P+3YM
M86EL1G)O;2@D9G)O;2DI*2!["B`@("!D:64H(E5N86)L92!T;R!S970@<V5N
M9&5R('1O(#PD9G)O;3Y<;B(I.PI]"@HO*B!!9&1R97-S('1H92!M97-S86=E
M('1O(&5A8V@@;V8@=&AE(')E8VEP:65N=',N("HO"F9O<F5A8V@@*"1R8W!T
M(&%S("1T;RD@>PH@("`@:68@*%!%05(Z.FES17)R;W(H)')E<R`]("1S;71P
M+3YR8W!T5&\H)'1O*2DI('L*("`@("`@("!D:64H(E5N86)L92!T;R!A9&0@
M<F5C:7!I96YT(#PD=&\^.B`B("X@)')E<RT^9V5T365S<V%G92@I("X@(EQN
M(BD["B`@("!]"GT*"B\J(%-E="!T:&4@8F]D>2!O9B!T:&4@;65S<V%G92X@
M*B\*:68@*%!%05(Z.FES17)R;W(H)'-M='`M/F1A=&$H)'-U8FH@+B`B7')<
M;B(@+B`D8F]D>2DI*2!["B`@("!D:64H(E5N86)L92!T;R!S96YD(&1A=&%<
M;B(I.PI]"@HO*B!$:7-C;VYN96-T(&9R;VT@=&AE(%--5%`@<V5R=F5R+B`J
M+PHD<VUT<"T^9&ES8V]N;F5C="@I.PH``````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O9&]C<R]$0B]D;V,`````````````````````
M```````````````````````````````````````````````````````````P
M,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S
M,B`P,C`S-C,`(#4`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S+T1"+V1O
M8R]-04E.5$%)3D524P``````````````````````````````````````````
M`````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`Q,C4P(#$P-3$U-#,T,3,R(#`R,C$S-0`@,```````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!-86EN=&%I;F5R<R!F;W(@1$(@9&%T
M86)A<V4@8F%C:V5N9',O9')I=F5R<SH*"F1B87-E("`@.B!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"F9B<W%L("`@.B!$86YI96P@0V]N
M=FES<V]R(#QD86YI96QC0'!H<"YN970^"B`@("`@("`@("!&<F%N:R!-+B!+
M<F]M86YN(#QF<F%N:T!K<F]M86YN+FEN9F\^"FEB87-E("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"FEF>"`@("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"FUS<6P@("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"FUS<W%L("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"FUY<W%L("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"FUY<W%L:2`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"F]C:3@@("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"F]D8F,@("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"G!G<W%L("`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"G-Q;&ET92`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"G-Y8F%S92`@.B!$86YI96P@
M0V]N=FES<V]R(#QD86YI96QC0'!H<"YN970^"@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]D;V-S
M+T1"+V1O8R]35$%455,`````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#$P-C0U(#$P-3$U-#,T,3,R(#`R,30Q-@`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!35$%455,@3T8@5$A%(%!%
M05(@1$(@4$%#2T%'10H]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/3T]/0H*
M)$ED.B!35$%455,L=B`Q+C,S(#(P,#4O,#(O,C(@,34Z-#4Z,S8@9&%N:65L
M8R!%>'`@)`HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*"D1"($1R:79E
M<B!&96%T=7)E($UA=')I>`HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*4WEM
M8F]L<SH*("!X("`]("!I;7!L96UE;G1E9"P@8G5T('=I=&AO=70@=&5S=',*
M("!T("`]("!I;7!L96UE;G1E9"P@8G5T(&]N92!O<B!M;W)E('1E<W1S(&9A
M:6P*("!4("`]("!I;7!L96UE;G1E9"P@<&%S<VEN9R!A;&P@=&5S=',*("!E
M("`]("!E;75L871E9"P@=VET:&]U="!T97-T<PH@(&P@(#T@(&5M=6QA=&5D
M+"!B=70@;VYE(&]R(&UO<F4@=&5S=',@9F%I;`H@($4@(#T@(&5M=6QA=&5D
M+"!P87-S:6YG(&%L;"!T97-T<PH@(&X@(#T@(')E='5R;G,@(FYO="!C87!A
M8FQE(@H@("T@(#T@(&YO(&EM<&QE;65N=&%T:6]N(&]F('1H:7,@9F5A='5R
M92!O<B!S=&%T=7,@=6YK;F]W;@H*("`@("`@("`@("`@("`@("`@("!F8G-Q
M;"`@("`@(&EF>"`@("`@(&US<W%L("`@("!M>7-Q;&D@("`@(&]D8F,@("`@
M('-Q;&ET90I&14%455)%("`@("`@("!D8F%S92`@?"`@:6)A<V4@('P@(&US
M<6P@("!\("!M>7-Q;"`@?"`@(&]C:3@@('P@('!G<W%L("!\("!S>6)A<V4*
M<VEM<&QE475E<GD@("`@("`M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@
M("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4"FYU;4-O;',@("`@
M("`@("`@>"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5`IN=6U2;W=S("`@("`@("`@('@@("`@
M5"`@("!%("`@($4@("`@5"`@("!4("`@(%0@("`@5"`@("!%("`@(%0@("`@
M5"`@("!4("`@(%0*97)R;W).871I=F4@("`@("!N("`@(%0@("`@5"`@("!4
M("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@12`@("!4
M"G!R97!A<F4O97AE8W5T92`@92`@("!%("`@(%0@("`@12`@("!%("`@($4@
M("`@12`@("!%("`@(%0@("`@12`@("!%("`@($4@("`@10IS97%U96YC97,@
M("`@("`@(&X@("`@5"`@("!4("`@(&X@("`@5"`@("!4("`@(%0@("`@5"`@
M("!4("`@($4@("`@5"`@("!%("`@(%0*869F96-T9612;W=S("`@("!N("`@
M(%0@("`@12`@("!%("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@
M($4@("`@5"`@("!4"F9E=&-H(&UO9&5S("`@("`@>"`@("!4("`@(%0@("`@
M5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@
M5`IF971C:"!R;W<@8GD@;F\@('@@("`@>"`@("!N("`@(&X@("`@>"`@("!X
M("`@('@@("`@>"`@("!N("`@('@@("`@>"`@("!X("`@('@*=')A;G-A8W1I
M;VYS("`@("`M("`@(%0@("`@5"`@("!4("`@(&X@("`@5"`@("!4("`@(%0@
M("`@5"`@("!4("`@(%0@("`@;B`@("!4"F%U=&\M8V]M;6ET("`@("`@;B`@
M("!4("`@($4@("`@12`@("!N("`@($4@("`@12`@("!%("`@($4@("`@5"`@
M("!%("`@(&X@("`@10IE<G)O<B!M87!P:6YG("`@("T@("`@5"`@("!4("`@
M(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@
M(%0*=&%B;&5);F9O("`@("`@("!X("`@(%0@("`@5"`@("!T("`@(%0@("`@
M5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4"@IG971,:7-T
M3V8H*2!465!%4PIT86)L97,@("`@("`@("`@("T@("`@5"`@("!4("`@(%0@
M("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0@("`@5"`@("!4("`@(%0*
M=FEE=W,@("`@("`@("`@("`M("`@(%0@("`@5"`@("`M("`@("T@("`@5"`@
M("`M("`@("T@("`@+2`@("!4("`@(%0@("`@+2`@("!4"G5S97)S("`@("`@
M("`@("`@+2`@("!4("`@(%0@("`@+2`@("`M("`@("T@("`@5"`@("!4("`@
M("T@("`@+2`@("!4("`@("T@("`@+0ID871A8F%S97,@("`@("`@("T@("`@
M+2`@("`M("`@("T@("`@5"`@("`M("`@(%0@("`@5"`@("`M("`@(%0@("`@
M5"`@("`M("`@("T*9G5N8W1I;VYS("`@("`@("`M("`@(%0@("`@+2`@("`M
M("`@("T@("`@+2`@("`M("`@("T@("`@+2`@("`M("`@(%0@("`@+2`@("`M
M"G-Y;F]N>6US("`@("`@("`@+2`@("`M("`@("T@("`@+2`@("`M("`@("T@
M("`@+2`@("`M("`@(%0@("`@+2`@("`M("`@("T@("`@+0H*"E1E<W0@0V]N
M9F]R;6%N8V4*+2TM+2TM+2TM+2TM+2TM+0I3>6UB;VQS.@H@("`@;R`@/2`@
M5&5S="!P87-S960*("`@(%@@(#T@(%1E<W0@9F%I;&5D"B`@("!,("`]("!3
M;VUE('!O<G1I;VYS(&]F('1H92!T97-T(&9A:6QE9"!D=64@=&\@;&EM:71A
M=&EO;G,@:6X@4$A0(&]R($1"35,*("`@(&X@(#T@(%1E<W0@<F5T=7)N<R`B
M;F]T(&-A<&%B;&4B"B`@("`M("`]("!.;W0@=&5S=&5D"@H@("`@("`@("`@
M("`@("`@("`@(&9B<W%L("`@("`@:69X("`@("`@;7-S<6P@("`@(&UY<W%L
M:2`@("`@;V1B8R`@("`@<W%L:71E"B`@("`@("`@("`@("`@(&1B87-E("!\
M("!I8F%S92`@?"`@;7-Q;"`@('P@(&UY<W%L("!\("`@;V-I."`@?"`@<&=S
M<6P@('P@('-Y8F%S90HP,6-O;FYE8W0@("`@("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\*,#)F971C:"`@("`@("`@("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C`S<VEM<&QE
M<75E<GD@("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHP-&YU;6-O;',@("`@("`@("T@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\*,#5S97%U96YC97,@("`@("`M("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O"C`V<')E<&5X96,@("`@("`@+2`@("!O("`@(&\@("`@;R`@("!,("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHP.&%F9F5C
M=&5D<F]W<R`@("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\*,#EN=6UR;W=S("`@("`@("`M
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O"C$P97)R;W)M87`@("`@("`@+2`@("!O("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@
M("`@;PHQ,71R86YS86-T:6]N<R`@("T@("`@;R`@("!O("`@(&\@("`@;B`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!N("`@(&\*,3-L:6UI
M="`@("`@("`@("`M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C$T9F5T8VAM;V1E7V]B:F4@
M+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;PHQ-7%U;W1E("`@("`@("`@("T@("`@;R`@("!O
M("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O
M("`@(&\*,39T86)L96EN9F\@("`@("`M("`@(&\@("`@;R`@("!,("`@(&\@
M("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O"C$W<75E
M<GD@("`@("`@("`@+2`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@
M("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;PHQ.&=E="`@("`@("`@("`@
M("T@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@
M(&\@("`@;R`@("!O("`@(&\*,3EG971L:7-T;V8@("`@("`M("`@(&\@("`@
M;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@;R`@("!O("`@(&\@("`@
M;R`@("!O"@H*1$)-4R!697)S:6]N<R!497-T960*+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*9&)A<V4@("!N+V$*9F)S<6P@("`T+C$N-@II8F%S92`@($9I<F5B
M:7)D(#$N-2XQ("`H4$A0(#4@;VYL>2D*:69X("`@("`W+C(@4W1A;F1A<F0@
M161T:71I;VX*;7-Q;"`@("`S+C8@("A02%`@<VYA<'-H;W1S(&1A=&5D(#(P
M,#4M,#(M,3@I"FUS<W%L("`@."XP+C<V,`IM>7-Q;"`@(#0N,"XR,0IM>7-Q
M;&D@(#0N,2XU("`H4$A0(#4@;VYL>2D*;V-I."`@("`Y+C(*;V1B8R`@("!$
M0C(@15-%(#@N,2!A;F0@35,@06-C97-S(#(P,#`*<&=S<6P@("`W+C0N,2!A
M;F0@."XP+C$*<W%L:71E("!02%`@-3H@97AT96YS:6]N+B`@4$A0(#0Z(%!%
M0TP@<VYA<'-H;W0N"G-Y8F%S92`@05-%(#$R+C4N,PH*5&5S=',@=V5R92!P
M97)F;W)M960@=6YD97(@8F]T:"!O9B!T:&4@9F]L;&]W:6YG(%!(4"!V97)S
M:6]N<PIU;FQE<R!O=&AE<G=I<V4@;F]T960Z"B`@("`T+C,N,3$M9&5V(&1A
M=&5D(#(P,#4M,#(M,C(*("`@(#4N,2XP+61E=B!D871E9"`R,#`U+3`R+3(R
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O1$(O9&]C+U1%
M4U1%4E,`````````````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,3(S
M,#`@,3`U,34T,S0Q,S(@,#(Q-3$R`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#T]/3T]/3T]/3T]/3T]/3T]/3T*2$]7(%1/
M(%1%4U0@4$5!4B!$0@H]/3T]/3T]/3T]/3T]/3T]/3T]"@HD260Z(%1%4U1%
M4E,L=B`Q+C(P(#(P,#4O,#(O,38@,#8Z,S,Z,3(@9&%N:65L8R!%>'`@)`H*
M"DE.5%)/1%5#5$E/3@H]/3T]/3T]/3T]/3T*"E1H97-E(&%R92!I;G-T<G5C
M=&EO;G,@9F]R('1E<W1I;F<@4$5!4B!$0B!O;B!A(%=I;F1O=W,@;6%C:&EN
M92!U<VEN9R!A"D-Y9W=I;B!"87-H('-H96QL+B`@061J=7-T('1H92!P871H
M<R!A;F0@8V]M;6%N9',@=&\@;6%T8V@@>6]U<B!S>7-T96TN"E1H:7,@8V]N
M9FEG=7)A=&EO;B!I<R!U<V5D(&)E8V%U<V4@=&AE<V4@<')E8VES92!S=&5P
M<R!A<F4@:VYO=VX@=&\@=V]R:RX*"DY/5$4Z("!9;W4@;75S="!L;V<@;VX@
M87,@82!U<V5R('=H:6-H(&AA<R!P97)M:7-S:6]N<R!T;R!M;V1I9GD@=&AE
M"F-O;G1E;G1S(&]F('EO=7(@4$A0(&5X96-U=&%B;&4G<R!D:7)E8W1O<GDN
M("!4:&ES(&ES(&YE8V5S<V%R>2!F;W(@8F]T:`IC;VYF:6=U<FEN9R!!3D0@
M<G5N;FEN9R!T:&4@=&5S="!S>7-T96TN"@H*24Y35$%,3$%424]."CT]/3T]
M/3T]/3T]/0H*3V)T86EN(%!(4"=S(%1E<W0@1G)A;65W;W)K"BTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0I)9B!Y;W4@9&]N)W0@:&%V92!02%`G<R!T
M97-T(&9R86UE=V]R:RP@>6]U(&YE960@=&\@;V)T86EN(&ET+B`@5&AE<V4*
M<W1E<',@:6YC;'5D92!C:&%N9VEN9R!T:&4@=V]R:VEN9R!D:7)E8W1O<GDL
M(&1O=VYL;V%D:6YG(')U;BUT97-T<RYP:'`*=FEA($-64R!A;F0@8V]P>6EN
M9R!T:&4@9FEL92!I;G1O('!L86-E+B`@0VAA;F=E('1H92!R979I<VEO;B!F
M;&%G(&EN('1H90I#5E,@8V]M;6%N9"!A<R!A<'!R;W!R:6%T92!F;W(@>6]U
M<B!P<F5S96YT('9E<G-I;VX@;V8@4$A0+@H*(&-D(&,Z+W!R;V=R87XQ+W!H
M<`H@8W9S("UD(#IP<V5R=F5R.F-V<W)E861`8W9S+G!H<"YN970Z+W)E<&]S
M:71O<GD@;&]G:6X@("`C('!A<W-W;W)D(&ES('!H<&9I"B!C=G,@+60@.G!S
M97)V97(Z8W9S<F5A9$!C=G,N<&AP+FYE=#HO<F5P;W-I=&]R>2!C;R`M<B!0
M2%!?-%\S(%P*("`@("`M9"!T97-T('!H<"US<F,O<G5N+71E<W1S+G!H<`H@
M8W`@=&5S="]R=6XM=&5S=',N<&AP("X*(')M("UR9B!T97-T"@H*3V)T86EN
M($1"(&%N9"!I=',@5&5S="!&<F%M97=O<FL*+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2T**B!)1B!014%2($1"($E3($%,4D5!1%D@24Y35$%,
M3$5$.@H*("!)9B!Y;W4@:&%V92!014%2($1"(&EN<W1A;&QE9"!A;')E861Y
M+"!G;V]D+B`@5&AE('1E<W0@<W5I=&4*("!I<R!I;B!P;&%C92X@($]P96X@
M=7`@82!C;VUM86YD+W-H96QL('!R;VUP="!A;F0@;6]V92!I;G1O"B`@=&AE
M('1E<W0@9&ER96-T;W)Y+@H*("`@8V0@/'!A=&@@=&\@<&5A<B!I;G-A;&P^
M+W1E<W1S+T1"+W1E<W1S"@HJ(%9)02!!($Y%5R!)3E-404Q,051)3TX@55-)
M3D<@5$A%(%!%05(@24Y35$%,3$52.@H*("!);G-T86QL:6YG(%!%05(@:&%S
M(&=O='1E;B!F86ER;'D@96%S>2X@($9O;&QO=R!T:&4@:6YS=')U8W1I;VYS
M"B`@9G)O;2!T:&4@;6%N=6%L.B`@:'1T<#HO+W!E87(N<&AP+FYE="]M86YU
M86PO96XO:6YS=&%L;&%T:6]N+G!H<`H@($]N8V4@4$5!4B!A;F0@1$(@87)E
M(&EN<W1A;&QE9"P@;6]V92!T;R!T:&4@=&5S="!D:7)E8W1O<GDN"@H@("!C
M9"!P96%R+W1E<W1S+T1"+W1E<W1S"@HJ(%9)02!#5E,Z"@H@($-R96%T92!A
M(&QO8V%T:6]N('1O('-T;W)E('1H92!T97-T(&EN<W1A;&QA=&EO;B!O9B!$
M0B!A;F0@:71S"B`@=&5S="!S8W)I<'1S+@H*("`@;6MD:7(@9#HO<&5A<G1E
M<W0*("`@8V0@9#HO<&5A<G1E<W0*("`@8W9S("UD(#IP<V5R=F5R.F-V<W)E
M861`8W9S+G!H<"YN970Z+W)E<&]S:71O<GD@8V\@+5`@<&5A<B]$0@H*("!7
M92!A<W-U;64@>6]U(&%L<F5A9'D@:&%V92!T:&4@4$5!4B!B87-E('!A8VMA
M9V4@:6YS=&%L;&5D+B`@268*("!Y;W4@9&]N)W0L('EO=2!W:6QL(&YE960@
M=&\@9&\@<V\L(&)U="!T:&4@:6YS=')U8W1I;VYS(&9O<@H@(&1O:6YG('1H
M870@87)E(&)E>6]N9"!T:&4@<V-O<&4@;V8@=&AI<R!D;V-U;65N="X@(%-E
M90H@(&AT='`Z+R]P96%R+G!H<"YN970O;6%N=6%L+V5N+VEN<W1A;&QA=&EO
M;BYP:'`@9F]R(&UO<F4@:6YF;RX*"B`@36]V92!T;R!T:&4@=&5S="!D:7)E
M8W1O<GDN"@H@("!C9"!P96%R+T1"+W1E<W1S"@H*0V]P>2!T:&4@4W1A<G1E
M<B!3:&5L;"!38W)I<'0@86YD($5D:70@=&AE(%!A=&AS"BTM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I4;R!M86ME
M('-T87)T:6YG('5P(&5A8V@@=&5S="!R=6X@96%S:65R+"!W92!H879E(&EN
M8VQU9&5D('1W;R!S:&5L;`IS8W)I<'1S+B`@5&AE(&]R:6=I;F%L(&9I;&5S
M(&%R92!N86UE9"`B<G5N+F-V<R(N("!4:&5Y(&YE960@=&\@8F4*<F5N86UE
M9"!T;R`B<G5N(B!S;R!#5E,@=V]N)W0@8F]T:&5R('EO=2!W:71H('1R86-K
M:6YG('1H96TN("!4:&5N+`IT:&4@<&%T:',@86YD(&9I;&4@;F%M97,@:6X@
M=&AE;2!N965D('1O(&)E('-E="!T;R!T:&]S92!U<V5D(&)Y"GEO=7(@<WES
M=&5M+@H*(&-P(')U;BYC=G,@<G5N"B!C:&UO9"`W-34@<G5N"B!V:2!R=6X*
M"B!C9"!D<FEV97(*(&-P(')U;BYC=G,@<G5N"B!C:&UO9"`W-34@<G5N"B!V
M:2!R=6X*"@I#;W!Y('1H92!3971U<"!&:6QE(&%N9"!%9&ET('1H92!$4TXG
M<PHM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I4:&4@
M=&5S="!S=6ET92!C;VYT86EN<R!A(&9I;&4@=&AA="!S=&]R97,@=&AE($13
M3B=S(&YE961E9"!T;PIC;VYN96-T('1O('EO=7(@9&%T86)A<V4N("!4:&4@
M;W)I9VEN86P@9FEL92!I<R`B<V5T=7`N:6YC+F-V<R(*86YD(&ET(&YE961S
M('1O(&)E(')E;F%M960@(G-E='5P+FEN8R(@<V\@0U93('=O;B=T('1R86-K
M(&ET+@I4:&5N('EO=2=L;"!N965D('1O(&5D:70@=&AE($133B=S(&EN(&ET
M+@H*(&-P('-E='5P+FEN8RYC=G,@<V5T=7`N:6YC"B!V:2!S971U<"YI;F,*
M"@I254X@5$A%(%1%4U13"CT]/3T]/3T]/3T]/3T*"E1O(')U;B!A;&P@=&5S
M=',Z("`N+W)U;@I4;R!R=6X@;VYE('1E<W0Z("`@+B]R=6X@/'1E<W0@9FEL
M92!N86UE/@I%>&%M<&QE.B`@("`@("`@("`@+B]R=6X@9&)?<&%R<V5D<VXN
M<&AP=`H*"E1E<W0@5'EP97,@86YD($QO8V%T:6]N<PHM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2T*=&5S=',@("`@("`@("`@("`@0V]M;6]N(%!%05(@1$(@
M=&5S=',*=&5S=',O9')I=F5R("`@("`@0V]M;6]N('1E<W1S(&9O<B!A;&P@
M=&AE(&1R:79E<G,*"@I297-U;'1S(&%N9"!7:&%T(%1O($1O(%=I=&@@5&AE
M;0HM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I%86-H('1E<W0@
M=&AA="!F86EL<R!G96YE<F%T97,@82`N<&AP("AW:&EC:"!Y;W4@8V%N(&5X
M96-U=&4I+"!A("YE>'`**'1H92!E>'!E8W1E9"!O=71P=70I+"!A("YO=70@
M*'1H92!T97-T(&]U='!U="D@86YD(&$@+F1I9F8@*&$@9&EF9B`M=0IF<F]M
M('1H92`N97AP(&%N9"`N;W5T(&9I;&5S*2X*"DEF('EO=2!R=6X@=&AE('1E
M<W1S+"!P;&5A<V4@<F5P;W)T(&]R(&9I;&P@=&AE(%1%4U0@0T].1D]234%.
M0T4@=&%B;&4*:6X@=&AE(%-405154R!D;V-U;65N="X@($)E9F]R92!A;GD@
M8V]M;6ET('1O($-64R!B92!S=7)E('1O(')U;B!T:&4*=&5S=',@86YD(&YO
M=&AI;F<@9V]T(&)R;VME;B!W:71H('1H92!C:&%N9V4N"@I)9B!Y;W4@9V5T
M('1H92!M97-S86=E(")32TE0(BP@;65A;G,@=&AA="!T:&4@=&5S="!I="=S
M(&YO="!E>&5C=71E9"X*3&]O:R!A="!T:&4@1$(O=&5S=',O9')I=F5R+W-K
M:7!I9BYI;F,@=&\@<V5E('=H870G<R!T:&4@<')O8FQE;0HH<')O8F%B;'D@
M82!C;VYN96-T:6]N('!R;V)L96TI+@H*"D1"(%1%4U1%4B!-051225@*/3T]
M/3T]/3T]/3T]/3T]/0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&9B<W%L("`@(&EF>"`@("!M<W-Q;"`@(&UY<W%L:2`@(&]D8F,@("!S<6QI
M=&4*5$535$52("`@("`@("`@("`@("`@("`@("`@(&1B87-E('P@:6)A<V4@
M?"`@;7-Q;"!\(&UY<W%L('P@(&]C:3@@?"!P9W-Q;"!\('-Y8F%S90I*;VAN
M($AO<G1O;B`@("`@("`@("`@("`@("`@("`M("`@+2`@("T@("!8("`@+2`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M"E1I;2!::6-K=7,@("`@
M("`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M
M("`@6"`@("T@("`M("`@+2`@("T*5&EM(%!A<FMI;B`@("`@("`@("`@("`@
M("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@
M("T@("`M("`@+0I0875L($=A<F1I;F5R("`@("`@("`@("`@("`@("`M("`@
M+2`@("T@("!8("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M
M"G!E=&5R=V)`:6%F<FEC82YC;VT@("`@("`@("`@("T@("`M("`@+2`@(%@@
M("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T*1&%N:65L+"!!
M9&%M("`@("`@("`@("`@("`@("`@+2`@("T@("`M("`@+2`@("T@("`M("`@
M+2`@("T@("!8("`@+2`@("T@("`M("`@+0IS>FEI0'-Z:6ES;V9T+F-O;2`@
M("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@
M("!8N2`@+2`@("T@("`M"FIM:#-`;&EN=7AF<F5A:RYC;VT@("`@("`@("`@
M("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@
M+2`@("T*2V5V:6X@2&5N<FEK<V]N("`@("`@("`@("`@("`@+2`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T@("!8("`@+2`@("T@("`M("`@+0I3=&EG
M($)A:VME;B`@("`@("`@("`@("`@("`@("`M("`@+2`@("T@("`M("`@+2`@
M("T@("!8("`@+2`@("T@("`M("`@6"`@("T@("`M"D-H=6-K($AA9V5N8G5C
M:"`@("`@("`@("`@("`@("T@("`M("`@+2`@("T@("`M("`@6"`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T*3'5D;W9I8V\@36%G;F]C879A;&QO("`@
M("`@("`@+2`@("T@("!8("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@
M("T@("`M("`@+0I$86YI96P@0V]N=FES<V]R("`@("`@("`@("`@("!8("`@
M6"`@(%@@("`M("`@6"`@(%@@("!8("`@6"`@(%@@("!8LB`@6"`@(%@@("!8
M"@I-25-324Y'(%1%4U1%4E,@("`@("`@("`@("`@("`M("`@+2`@("T@("`M
M("`@+2`@("T@("`M("`@+2`@("T@("`M("`@+2`@("T@("`M"@I#;VUM96YT
M<SH*"ELQ73H@3T1"0R!U<VEN9R!)0DT@1$(R"ELR73H@3T1"0R!U<VEN9R!)
M0DT@1$(R(&%N9"!-4R!!8V-E<W,*````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH
M;W)D92]P96%R+V1O8W,O1$(O9&]C+TE$14%3````````````````````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8U,S<@,3`U,34T,S0Q,S(@,#(Q,C(U
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````$%B
M<W1R86-T960@5'EP97,@*%-T:6<I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"@I$0B!N965D<R!A('-E="!O9B!T>7!E<R!R97!R97-E;G1I;F<@=&AE(&UO
M<W0@8V]M;6]N;'D@=7-E9"!T>7!E<R!I;@IA;&P@8F%C:V5N9',N("!4:&ES
M('1Y<&4@<V5T(&-O=6QD(&%L<V\@8F4@9V5A<F5D('1O=V%R9',@:6YT96=R
M871I;VX*=VET:"!T:&EN9W,@;&EK92!834PM4E!#+U-/05`@:6UP;&5M96YT
M871I;VYS+"!(5$U,(&9O<FT@8VQA<W-E<RP@971C+@H*4F5A;"!1=65R>2!0
M87)S97(@*%-T:6<I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0H*5VET:"!A
M(')E86P@<75E<GD@<&%R<V5R+"!$0B!C86X@:6UP;&5M96YT(&UO<F4@;V8@
M:71S('!O<G1A8FEL:71Y"F)A<V5D(&]N('1H92!Q=65R>2P@:6YS=&5A9"!O
M9B!H879I;F<@<W5P<&]R="!F=6YC=&EO;G,@9F]R"F5V97)Y=&AI;F<N("!/
M;F4@97AA;7!L92!W;W5L9"!B92!,24U)5"P@86YO=&AE<B`B24Y315)4"BXN
M+B!215154DY)3D<B+@H*4&]R=&%B;&4@=')A;G-A8W1I;VYS("A3=&EG*0HM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM"@I)9B!$0B!C86X@<&%R<V4@
M<75E<FEE<R!E;F]U9V@@=&\@9&5T97)M:6YE('=H870@=&%B;&5S(&%R92!A
M9F9E8W1E9`IB>2!Q=65R:65S+"!I="!S:&]U;&0@8F4@<&]S<VEB;&4@=&\@
M;6%K92!A(')E<&QA>6%B;&4@=')A;G-A8W1I;VX*;&]G+B`@1TY/344@=7-E
M<R!A;B!834P@9F]R;6%T(&9O<B!C;VYF:6=U<F%T:6]N(&1A=&$@=&AA="!L
M971S('EO=0IC:&5C:W!O:6YT('-T871E(&]N8V4@:6X@82!W:&EL92P@86YD
M(')E=F5R="!T;R!T:&%T('-T871E(&QA=&5R+@I7:71H(&$@<VEM:6QA<B!A
M<'!R;V%C:"!F;W(@=')A;G-A8W1I;VYS(&EN($1"('=E(&-A;B!I;7!L96UE
M;G0*<&]R=&%B;&4@=')A;G-A8W1I;VYS(&%N9"!C:&5C:W!O:6YT:6YG(&5V
M96X@9F]R('1H92!D871A8F%S97,@=&AA=`ID;VXG="!S=7!P;W)T('1H96TN
M"@H*17)R;W(@<F5P;W)T:6YG(&-L96%N+75P+V1E8G5G("A4;VUA<RD*+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0I.;W<@96%C:"!D
M<FEV97(@:&%S(&ET<R!O=VX@<F%I<V5%<G)O<B!M971H;V0L(&-O;6UO;B!H
M87,@82!R86ES945R<F]R(&%N9`I$0B!H87,@82!$0E]E<G)O<B!C;&%S<R!A
M;F0@:71S(&]W;B!I<T5R<F]R*"D@;65T:&]D+B!4:&ES(&5R<F]R('-T=69F
M(`IO=F5R:&5A9"!C;W5L9"!B92!S:6UP;&EF:65D('=I=&@@;VYL>2!O;F4@
M<F%I<V5%<G)O<BP@9')O<&EN9R!T:&4@1$(@17)R;W(*8VQA<W,@86YD(&%L
M<V\@=&AE($1".CII<T5R<F]R*"D@*'5S92!T:&4@4$5!4BYP:'`@;VYE<R!I
M;G-T96%D*2X*3W1H97(@:61E82!C;W5L9"!B92!T;R!A9&0@82!S>7-T96T@
M9F]R(&%L;&]W:6YG('!E;W!L92!A8V-E<W,@=&\@86QL('1H90IQ=65R:65S
M('-E;F1E9"!B>2!014%2($1"('1O('1H92!B86-K96YD+B!!;'-O(&$@;F5W
M(%!%05)?15)23U)?1$5"54<*9FQA9R!T:&%T(&%U=&]M871I8V%L;'D@*'-H
M;W=\=')I9V=E<G,I(&1E8G5G(&EN9F\L('!E<FAA<',*=VET:"!A(&YE=R!0
M14%27RA787)N:6YG?$1E8G5G*2!O8FIE8W0N"@I1=6]T92!C;&5A;BUU<"`H
M4W1I9RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM"C$N($ME97`@<75O=&4@86YD
M('%U;W1E4W1R:6YG+"!B=70@;6]V92!Q=6]T:6YG(&]F('-T<FEN9W,@8F%C
M:R!I;G1O"B`@('%U;W1E4W1R:6YG(&%N9"!M86ME('%U;W1E(&-A;&P@:70@
M9F]R('-T<FEN9W,N"@HR+B!!9&0@86X@;W!T:6]N86P@(F]P97)A=&]R(B!P
M87)A;65T97(@=&\@<75O=&4@=&AA="!I<R!O;F4@;V8@(CTB+`H@("`B/"(L
M("(^(B!O<B`B/#XB('1H870@=VEL;"!B92!I;G-E<G1E9"!I;B!F<F]N="!O
M9B!T:&4@<75O=&5D('9A;'5E"B`@('5N;&5S<R!I="!I<R!.54Q,+"!I;B!W
M:&EC:"!C87-E(&ET('=I;&P@8F4@8V]N=F5R=&5D('1O("))4R(@*&9O<@H@
M("`B/2(I(&]R("))4R!.3U0B("AF;W(@=&AE(&]T:&5R<RDN"@I!=71O(&9R
M964@<W1A=&5M96YT<R`H5&]M87,I"BTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*0GD@<V5T=&EN9R!A('!A<F%M(&EN('%U97)Y*"D@;W(@9F]R('1H
M92!H;VQE($1"(&EN<W1A;F-E+"!014%2($1""F-O=6QD(&%U=&\M9G)E92!R
M97-U;'1S(&EN($1"7W)E<W5L="T^9F5T8V@H26YT;WQ2;W<I('=H96X@=&AE
M(&1R:79E<@IR971U<FYS(&9A;'-E+@H*1&%T871Y<&5S(&EN('!R97!A<F4@
M<WEN=&%X("A4;VUA<RD*+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2T*17AT96YD('1H92!A8W1U86P@<')E<&%R92]E>&5C=71E('!L86-E
M:&]L9&5R<R!T;R!S=7!P;W)T(&1A=&$@='EP97,L(&)O=&@*=&\@8VAE8VL@
M=&AE(&1A=&$@:6YT<F]D=6-E9"!T;R!T:&4@<75E<GD@86YD('1O(")C87-T
M(B!T:&4@<F5S=6QT"G1O(&YA=&EV92!P:'`@9&%T82!T>7!E<RX@17@Z"@HD
M<W%L(#T@(DE.4T525"!)3E1/('1A8FQE(%9!3%5%4R`H>WMI;G0H-"E]?2P@
M>WMB;V]L?7TL('M[9&%T92@G62UM+60G*7U]*2(["B1R;W<@/2`D9&(M/G%U
M97)Y*"1S<6PL(&%R<F%Y*#@L("=T)RP@)S(P,#$M,#0M,2<I*3L*"D9O<FUA
M=#H@>WL\9&%T85]T>7!E/B@\<&%R86TQ/BP\<&%R86TR/BE]?0H*(G!A<F%M
M(B!C;W5L9"!B92!T:&4@;6%X(&QE;F=H="!O9B!T:&4@9&%T82P@9&%T92!F
M;W)M871S+"!N;W1?;G5L;`IC:&5C:W,@;W(@9&5F875L="!V86QU97,N"@I/
M=&AE<B!I9&5A<R!C;W5L9"!B93H*"C$I"B1S<6P@/2`B24Y315)4($E.5$\@
M=&%B;&4@5D%,5453("@_+"`_+"`_*2(["B1S=&@@/2`D9&(M/G!R97!A<F4H
M)'-Q;"P@87)R87DH)VEN="@T*2<L("=B;V]L)RP@)V1A=&4G*3L*)')E<R`]
M("1D8BT^97AE8W5T92@D<W1H+"!A<G)A>2@D82P@)&(L("1C*3L*"C(I"B1S
M<6P@/2`B24Y315)4($E.5$\@=&%B;&4@5D%,5453("@_+"`_+"`_*2(["B1P
M87)A;7,@/2!A<G)A>2@*"3`@/3X@87)R87DH)&$L("=I;G0H-"DG*2P*"3$@
M/3X@87)R87DH)&(L("=B;V]L)RD**3L*)')E<R`]("1D8BT^<75E<GDH)'-Q
M;"P@)'!A<F%M<RD["@I!=71O(&-O;FYE8W0@9F5A='5R92`H5&]M87,I"BTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*061D('1H92!A8FEL:71Y('1O
M(&-R96%T92!F;W(@97AA;7!L92!A(&QI9VAT(&%N9"!D=6UP($1"(&]B:F5C
M="!W:&EC:`IW:6QL(&]N;'D@<V5T('5P('1H92!C;VYN96-T:6]N('=H96X@
M;F5E9&5D+B!7:71H('1H870@<&5O<&QE(&-O=6QD"F-R96%T92!T:&4@1$(@
M;V)J96-T(&EN(&$@8V]M;6]N('!R97!E;F0@;W(@9&5F875L="!F:6QE('=I
M=&AO=70@=&AE"FYE960@=&\@=V%S=&4@<WES=&5M(')E<V]U<F-E<R!I9B!T
M:&4@=7-E(&]F('1H92!D871A8F%S92!I<R!F:6YA;&QY"FYO="!N965D960N
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M
M:&]R9&4O<&5A<B]D;V-S+TA45%!?4F5Q=65S="]D;V-S````````````````
M`````````````````````````````````````````````````#`P,#<U-2``
M,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,R(#`R,C4U
M,``@-0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W1A<@`P,&)U:6QD97(`````````````````````
M````````````8G(````````````````````````````````````````P,#`P
M,#`@`#`P,#`P,"``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+V1O8W,O2%144%]297%U97-T
M+V1O8W,O97AA;7!L92YP:'``````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#4V,#0@
M,3`U,34T,S0Q,S(@,#(U,#`P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(L(%)I8VAA<F0@2&5Y
M97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN
M('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70@("`@
M?`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P<F]V:61E9"!T
M:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\"B\O('P@87)E(&UE
M=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O=7)C92!C;V1E
M(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@("`@("!\"B\O('P@
M("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P*+R\@?"!O(%)E9&ES=')I8G5T
M:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E<')O9'5C92!T:&4@86)O=F4@
M8V]P>7)I9VAT("`@?`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N
M9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R(&EN('1H92!\
M"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@
M<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP*+R\@?"!O(%1H92!N
M86UE<R!O9B!T:&4@875T:&]R<R!M87D@;F]T(&)E('5S960@=&\@96YD;W)S
M92!O<B!P<F]M;W1E("`@("`@?`HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F
M<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET
M=&5N("!\"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\(%1(25,@4T]&5%=!4D4@
M25,@4%)/5DE$140@0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY4
M4DE"551/4E,@("!\"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@
M24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P*
M+R\@?"!,24U)5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%
M4D-(04Y404))3$E462!!3D0@1DE43D534R!&3U(@?`HO+R!\($$@4$%25$E#
M54Q!4B!055)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,
M3"!42$4@0T]065))1TA4("!\"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3
M($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y4
M04PL('P*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)
M04P@1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?`HO+R!\($Q)
M34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@
M4T525DE#15,[($Q/4U,@3T8@55-%+"!\"B\O('P@1$%402P@3U(@4%)/1DE4
M4SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!
M3D0@3TX@04Y9('P*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52
M($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@?`HO
M+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)
M3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\"B\O('P@3T8@5$A)4R!3
M3T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/
M1B!354-(($1!34%'12X@('P*+R\@?"`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PH*"B\J*@HJ(%1H:7,@=VEL;"!G<F%B(&$@=V5B<&%G92!A
M;F0@9&ES<&QA>2!I=`HJ+PH):6YC;'5D92@G2%144"]297%U97-T+G!H<"<I
M.PH*"21R97$@/2`F;F5W($A45%!?4F5Q=65S="@G:'1T<#HO+W=W=RYP:'`N
M;F5T)RD["@DD<F5Q+3YS971-971H;V0H2%144%]215%515-47TU%5$A/1%]0
M3U-4*3L*"21R97$M/F%D9%!O<W1$871A*"=&;V\G+"`G8F%R)RD["@DD<F5Q
M+3YS96YD4F5Q=65S="@I.PH))')E<W!O;G-E,2`]("1R97$M/F=E=%)E<W!O
M;G-E0F]D>2@I.PH)"@DD<F5Q+3YS971-971H;V0H2%144%]215%515-47TU%
M5$A/1%]'150I.PH))')E<2T^<V5T55),*"=H='1P.B\O<&5A<BYP:'`N;F5T
M)RD["@DD<F5Q+3YC;&5A<E!O<W1$871A*"D["@DD<F5Q+3YS96YD4F5Q=65S
M="@I.PH*"21R97-P;VYS93(@/2`D<F5Q+3YG971297-P;VYS94)O9'DH*3L*
M"@EE8VAO("1R97-P;VYS93$["@EE8VAO("1R97-P;VYS93(["C\^````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S<B]L;V-A;"]P<V$O<'-A
M+6AO<F1E+W!E87(O9&]C<R](5%107U)E<75E<W0O9&]C<R]D;W=N;&]A9"UP
M<F]G<F5S<RYP:'`````````````````````````````````````P,#`V-#0@
M`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-38T-"`Q,#4Q-30S-#$S,B`P,C<P
M,C(`(#``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-T87(`,#!B=6EL9&5R````````````````````
M`````````````&)R````````````````````````````````````````,#`P
M,#`P(``P,#`P,#`@````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M/#]P:'`*+RHJ"B`J($%N(&5X86UP;&4@;V8@3&ES=&5N97(@=7-A9V4@=VET
M:"!(5%107U)E<75E<W0N(%1H:7,@9&]W;FQO861S(&%N9"!S879E<R`*("H@
M=&AE(&9I;&4@9&ES<&QA>6EN9R!T:&4@<')O9W)E<W,@8F%R(&EN('1H92!P
M<F]C97-S+@H@*B`*("H@3F]T92!T=V\@=&AI;F=S.@H@*B`Q*2!4:&4@9FEL
M92!S:&]U;&0@8F4@<G5N(&EN(&-O;G-O;&4L(&YO="!I;B!B<F]W<V5R.PH@
M*B`R*2!9;W4@<VAO=6QD('1U<FX@;W5T<'5T(&)U9F9E<FEN9R!/1D8@9F]R
M('1H:7,@=&\@=V]R:R!P<F]P97)L>2X*("H@"B`J("1)9#H@9&]W;FQO860M
M<')O9W)E<W,N<&AP+'8@,2XQ(#(P,#,O,3`O,C<@,3`Z-#@Z-#D@879B($5X
M<"`D"B`J+PH*<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0N<&AP)SL*<F5Q
M=6ER95]O;F-E("=(5%10+U)E<75E<W0O3&ES=&5N97(N<&AP)SL*<F5Q=6ER
M95]O;F-E("=#;VYS;VQE+U!R;V=R97-S0F%R+G!H<"<["@I014%2.CIS971%
M<G)O<DAA;F1L:6YG*%!%05)?15)23U)?1$E%*3L*"G-E=%]T:6UE7VQI;6ET
M*#`I.PH*8VQA<W,@2%144%]297%U97-T7T1O=VYL;V%D3&ES=&5N97(@97AT
M96YD<R!(5%107U)E<75E<W1?3&ES=&5N97(*>PH@("`O*BH*("`@("H@2&%N
M9&QE(&9O<B!T:&4@=&%R9V5T(&9I;&4*("`@("H@0'9A<B!I;G0*("`@("HO
M"B`@("!V87(@)%]F<#L*"B`@("\J*@H@("`@*B!#;VYS;VQE7U!R;V=R97-S
M0F%R(&EN=&%N8V4@=7-E9"!T;R!D:7-P;&%Y('1H92!I;F1I8V%T;W(*("`@
M("H@0'9A<B!O8FIE8W0*("`@("HO"B`@("!V87(@)%]B87(["@H@("`O*BH*
M("`@("H@3F%M92!O9B!T:&4@=&%R9V5T(&9I;&4*("`@("H@0'9A<B!S=')I
M;F<*("`@("HO"B`@("!V87(@)%]T87)G970["@H@("`O*BH*("`@("H@3G5M
M8F5R(&]F(&)Y=&5S(')E8V5I=F5D('-O(&9A<@H@("`@*B!`=F%R(&EN=`H@
M("`@*B\*("`@('9A<B`D7W-I>F4@/2`P.PH*("`@(&9U;F-T:6]N($A45%!?
M4F5Q=65S=%]$;W=N;&]A9$QI<W1E;F5R*"D*("`@('L*("`@("`@("`D=&AI
M<RT^2%144%]297%U97-T7TQI<W1E;F5R*"D["B`@("!]"@H@("`O*BH*("`@
M("H@3W!E;G,@=&AE('1A<F=E="!F:6QE"B`@("`J($!P87)A;2!S=')I;F<@
M5&%R9V5T(&9I;&4@;F%M90H@("`@*B!`=&AR;W=S(%!%05)?17)R;W(*("`@
M("HO"B`@("!F=6YC=&EO;B!S971487)G970H)'1A<F=E="D*("`@('L*("`@
M("`@("`D=&AI<RT^7W1A<F=E="`]("1T87)G970["B`@("`@("`@)'1H:7,M
M/E]F<"`]($!F;W!E;B@D=&%R9V5T+"`G=V(G*3L*("`@("`@("!I9B`H(21T
M:&ES+3Y?9G`I('L*("`@("`@("`@("`@4$5!4CHZ<F%I<V5%<G)O<B@B0V%N
M;F]T(&]P96X@)WLD=&%R9V5T?2<B*3L*("`@("`@("!]"B`@("!]"@H@("`@
M9G5N8W1I;VX@=7!D871E*"8D<W5B:F5C="P@)&5V96YT+"`D9&%T82`](&YU
M;&PI"B`@("!["B`@("`@("`@<W=I=&-H("@D979E;G0I('L*("`@("`@("`@
M("`@8V%S92`G<V5N=%)E<75E<W0G.B`*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&%R9V5T(#T@8F%S96YA;64H)'-U8FIE8W0M/E]U<FPM/G!A=&@I.PH@
M("`@("`@("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!C87-E("=G;W1(
M96%D97)S)SH*("`@("`@("`@("`@("`@(&EF("AI<W-E="@D9&%T85LG8V]N
M=&5N="UD:7-P;W-I=&EO;B==*2`F)@H@("`@("`@("`@("`@("`@("`@('!R
M96=?;6%T8V@H)R]F:6QE;F%M93TB*%M>(ETK*2(O)RP@)&1A=&%;)V-O;G1E
M;G0M9&ES<&]S:71I;VXG72P@)&UA=&-H97,I*2!["@H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3YS971487)G970H8F%S96YA;64H)&UA=&-H97-;,5TI
M*3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G-E=%1A<F=E="@D=&AI<RT^7W1A<F=E="D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`D=&AI<RT^7V)A<B`])B!N97<@
M0V]N<V]L95]0<F]G<F5S<T)A<B@*("`@("`@("`@("`@("`@("`@("`G*B`G
M("X@)'1H:7,M/E]T87)G970@+B`G("5F<F%C=&EO;B4@2T(@6R5B87(E72`E
M<&5R8V5N="4G+"`G/3XG+"`G+2<L(`H@("`@("`@("`@("`@("`@("`@(#<Y
M+"`H:7-S970H)&1A=&%;)V-O;G1E;G0M;&5N9W1H)UTI/R!R;W5N9"@D9&%T
M85LG8V]N=&5N="UL96YG=&@G72`O(#$P,C0I.B`Q,#`I"B`@("`@("`@("`@
M("`@("`I.PH@("`@("`@("`@("`@("`@)'1H:7,M/E]S:7IE(#T@,#L*("`@
M("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`G=&EC:R<Z
M"B`@("`@("`@("`@("`@("`D=&AI<RT^7W-I>F4@*ST@<W1R;&5N*"1D871A
M*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8F%R+3YU<&1A=&4H<F]U;F0H
M)'1H:7,M/E]S:7IE("\@,3`R-"DI.PH@("`@("`@("`@("`@("`@9G=R:71E
M*"1T:&ES+3Y?9G`L("1D871A*3L*("`@("`@("`@("`@("`@(&)R96%K.PH*
M("`@("`@("`@("`@8V%S92`G9V]T0F]D>2<Z"B`@("`@("`@("`@("`@("!F
M8VQO<V4H)'1H:7,M/E]F<"D["B`@("`@("`@("`@("`@("!B<F5A:SL*"B`@
M("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!014%2.CIR86ES
M945R<F]R*")5;FAA;F1L960@979E;G0@)WLD979E;G1])R(I.PH@("`@("`@
M('T@+R\@<W=I=&-H"B`@("!]"GT*"B\O(%1R>2!U<VEN9R!A;GD@;W1H97(@
M<&%C:V%G92!I9B!Y;W4@;&EK92P@8G5T(&-H;V]S92!T:&4@8FEG9V5R(&]N
M97,*+R\@=&\@8F4@86)L92!T;R!S964@=&AE('!R;V=R97-S(&)A<@HD=7)L
M(#T@)VAT='`Z+R]P96%R+G!H<"YN970O9V5T+TA434Q?475I8VM&;W)M+7-T
M86)L92<["@HD<F5Q(#TF(&YE=R!(5%107U)E<75E<W0H)'5R;"D["@HD9&]W
M;FQO860@/28@;F5W($A45%!?4F5Q=65S=%]$;W=N;&]A9$QI<W1E;F5R*"D[
M"B1R97$M/F%T=&%C:"@D9&]W;FQO860I.PHD<F5Q+3YS96YD4F5Q=65S="AF
M86QS92D["C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#;VYS
M;VQE+T=E=&]P="YP:'``````````````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#(R-3`P(#$P-3$U-#,T,3,R(#`R,C`S-``@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO*B!V:6TZ('-E
M="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-#H@*B\*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$A0(%9E<G-I;VX@-"`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#,N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T('1H92!F;VQL;W=I;F<@
M=7)L.B`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S-?,"YT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R.B!!;F1R96D@6FUI979S:VD@/&%N9')E:4!P:'`N;F5T/B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!'971O<'0N<&AP+'8@,2XR,2XT+C<@,C`P
M,R\Q,B\P-2`R,3HU-SHP,2!A;F1R96D@17AP("0*"G)E<75I<F5?;VYC92`G
M4$5!4BYP:'`G.PH*+RHJ"B`J($-O;6UA;F0M;&EN92!O<'1I;VYS('!A<G-I
M;F<@8VQA<W,N"B`J"B`J($!A=71H;W(@06YD<F5I(%IM:65V<VMI(#QA;F1R
M96E`<&AP+FYE=#X*("H*("HO"F-L87-S($-O;G-O;&5?1V5T;W!T('L*("`@
M("\J*@H@("`@("H@4&%R<V5S('1H92!C;VUM86YD+6QI;F4@;W!T:6]N<RX*
M("`@("`J"B`@("`@*B!4:&4@9FER<W0@<&%R86UE=&5R('1O('1H:7,@9G5N
M8W1I;VX@<VAO=6QD(&)E('1H92!L:7-T(&]F(&-O;6UA;F0M;&EN90H@("`@
M("H@87)G=6UE;G1S('=I=&AO=70@=&AE(&QE861I;F<@<F5F97)E;F-E('1O
M('1H92!R=6YN:6YG('!R;V=R86TN"B`@("`@*@H@("`@("H@5&AE('-E8V]N
M9"!P87)A;65T97(@:7,@82!S=')I;F<@;V8@86QL;W=E9"!S:&]R="!O<'1I
M;VYS+B!%86-H(&]F('1H90H@("`@("H@;W!T:6]N(&QE='1E<G,@8V%N(&)E
M(&9O;&QO=V5D(&)Y(&$@8V]L;VX@)SHG('1O('-P96-I9GD@=&AA="!T:&4@
M;W!T:6]N"B`@("`@*B!R97%U:7)E<R!A;B!A<F=U;65N="P@;W(@82!D;W5B
M;&4@8V]L;VX@)SHZ)R!T;R!S<&5C:69Y('1H870@=&AE(&]P=&EO;@H@("`@
M("H@=&%K97,@86X@;W!T:6]N86P@87)G=6UE;G0N"B`@("`@*@H@("`@("H@
M5&AE('1H:7)D(&%R9W5M96YT(&ES(&%N(&]P=&EO;F%L(&%R<F%Y(&]F(&%L
M;&]W960@;&]N9R!O<'1I;VYS+B!4:&4*("`@("`J(&QE861I;F<@)RTM)R!S
M:&]U;&0@;F]T(&)E(&EN8VQU9&5D(&EN('1H92!O<'1I;VX@;F%M92X@3W!T
M:6]N<R!T:&%T"B`@("`@*B!R97%U:7)E(&%N(&%R9W5M96YT('-H;W5L9"!B
M92!F;VQL;W=E9"!B>2`G/2<L(&%N9"!O<'1I;VYS('1H870@=&%K92!A;@H@
M("`@("H@;W!T:6]N(&%R9W5M96YT('-H;W5L9"!B92!F;VQL;W=E9"!B>2`G
M/3TG+@H@("`@("H*("`@("`J(%1H92!R971U<FX@=F%L=64@:7,@86X@87)R
M87D@;V8@='=O(&5L96UE;G1S.B!T:&4@;&ES="!O9B!P87)S960*("`@("`J
M(&]P=&EO;G,@86YD('1H92!L:7-T(&]F(&YO;BUO<'1I;VX@8V]M;6%N9"UL
M:6YE(&%R9W5M96YT<RX@16%C:"!E;G1R>2!I;@H@("`@("H@=&AE(&QI<W0@
M;V8@<&%R<V5D(&]P=&EO;G,@:7,@82!P86ER(&]F(&5L96UE;G1S("T@=&AE
M(&9I<G-T(&]N90H@("`@("H@<W!E8VEF:65S('1H92!O<'1I;VXL(&%N9"!T
M:&4@<V5C;VYD(&]N92!S<&5C:69I97,@=&AE(&]P=&EO;B!A<F=U;65N="P*
M("`@("`J(&EF('1H97)E('=A<R!O;F4N"B`@("`@*@H@("`@("H@3&]N9R!A
M;F0@<VAO<G0@;W!T:6]N<R!C86X@8F4@;6EX960N"B`@("`@*@H@("`@("H@
M36]S="!O9B!T:&4@<V5M86YT:6-S(&]F('1H:7,@9G5N8W1I;VX@87)E(&)A
M<V5D(&]N($=.52!G971O<'1?;&]N9R@I+@H@("`@("H*("`@("`J($!P87)A
M;2!A<G)A>2`@)&%R9W,@("`@("`@("`@(&%N(&%R<F%Y(&]F(&-O;6UA;F0M
M;&EN92!A<F=U;65N=',*("`@("`J($!P87)A;2!S=')I;F<@)'-H;W)T7V]P
M=&EO;G,@('-P96-I9FEE<R!T:&4@;&ES="!O9B!A;&QO=V5D('-H;W)T(&]P
M=&EO;G,*("`@("`J($!P87)A;2!A<G)A>2`@)&QO;F=?;W!T:6]N<R`@('-P
M96-I9FEE<R!T:&4@;&ES="!O9B!A;&QO=V5D(&QO;F<@;W!T:6]N<PH@("`@
M("H*("`@("`J($!R971U<FX@87)R87D@='=O+65L96UE;G0@87)R87D@8V]N
M=&%I;FEN9R!T:&4@;&ES="!O9B!P87)S960@;W!T:6]N<R!A;F0*("`@("`J
M('1H92!N;VXM;W!T:6]N(&%R9W5M96YT<PH@("`@("H*("`@("`J($!A8V-E
M<W,@<'5B;&EC"B`@("`@*@H@("`@("HO"B`@("!F=6YC=&EO;B!G971O<'0R
M*"1A<F=S+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI
M"B`@("!["B`@("`@("`@<F5T=7)N($-O;G-O;&5?1V5T;W!T.CID;T=E=&]P
M="@R+"`D87)G<RP@)'-H;W)T7V]P=&EO;G,L("1L;VYG7V]P=&EO;G,I.PH@
M("`@?0H*("`@("\J*@H@("`@("H@5&AI<R!F=6YC=&EO;B!E>'!E8W1S("1A
M<F=S('1O('-T87)T('=I=&@@=&AE('-C<FEP="!N86UE("A03U-)6"US='EL
M92DN"B`@("`@*B!0<F5S97)V960@9F]R(&)A8VMW87)D<R!C;VUP871I8FEL
M:71Y+@H@("`@("H@0'-E92!G971O<'0R*"D*("`@("`J+R`@("`*("`@(&9U
M;F-T:6]N(&=E=&]P="@D87)G<RP@)'-H;W)T7V]P=&EO;G,L("1L;VYG7V]P
M=&EO;G,@/2!N=6QL*0H@("`@>PH@("`@("`@(')E='5R;B!#;VYS;VQE7T=E
M=&]P=#HZ9&]'971O<'0H,2P@)&%R9W,L("1S:&]R=%]O<'1I;VYS+"`D;&]N
M9U]O<'1I;VYS*3L*("`@('T*"B`@("`O*BH*("`@("`J(%1H92!A8W1U86P@
M:6UP;&5M96YT871I;VX@;V8@=&AE(&%R9W5M96YT('!A<G-I;F<@8V]D92X*
M("`@("`J+PH@("`@9G5N8W1I;VX@9&]'971O<'0H)'9E<G-I;VXL("1A<F=S
M+"`D<VAO<G1?;W!T:6]N<RP@)&QO;F=?;W!T:6]N<R`](&YU;&PI"B`@("![
M"B`@("`@("`@+R\@:6X@8V%S92!Y;W4@<&%S<R!D:7)E8W1L>2!R96%D4$A0
M07)G=B@I(&%S('1H92!F:7)S="!A<F<*("`@("`@("!I9B`H4$5!4CHZ:7-%
M<G)O<B@D87)G<RDI('L*("`@("`@("`@("`@<F5T=7)N("1A<F=S.PH@("`@
M("`@('T*("`@("`@("!I9B`H96UP='DH)&%R9W,I*2!["B`@("`@("`@("`@
M(')E='5R;B!A<G)A>2AA<G)A>2@I+"!A<G)A>2@I*3L*("`@("`@("!]"B`@
M("`@("`@)&]P=',@("`@(#T@87)R87DH*3L*("`@("`@("`D;F]N7V]P=',@
M/2!A<G)A>2@I.PH*("`@("`@("!S971T>7!E*"1A<F=S+"`G87)R87DG*3L*
M"B`@("`@("`@:68@*"1L;VYG7V]P=&EO;G,I('L*("`@("`@("`@("`@<V]R
M="@D;&]N9U]O<'1I;VYS*3L*("`@("`@("!]"@H@("`@("`@("\J"B`@("`@
M("`@("H@4')E<V5R=F4@8F%C:W=A<F1S(&-O;7!A=&EB:6QI='D@=VET:"!C
M86QL97)S('1H870@<F5L:65D(&]N"B`@("`@("`@("H@97)R;VYE;W5S(%!/
M4TE8(&9I>"X*("`@("`@("`@*B\*("`@("`@("!I9B`H)'9E<G-I;VX@/"`R
M*2!["B`@("`@("`@("`@(&EF("AI<W-E="@D87)G<ULP77LP?2D@)B8@)&%R
M9W-;,%U[,'T@(3T@)RTG*2!["B`@("`@("`@("`@("`@("!A<G)A>5]S:&EF
M="@D87)G<RD["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(')E
M<V5T*"1A<F=S*3L*("`@("`@("!W:&EL92`H;&ES="@D:2P@)&%R9RD@/2!E
M86-H*"1A<F=S*2D@>PH*("`@("`@("`@("`@+RH@5&AE('-P96-I86P@96QE
M;65N="`G+2TG(&UE86YS(&5X<&QI8VET(&5N9"!O9@H@("`@("`@("`@("`@
M("!O<'1I;VYS+B!4<F5A="!T:&4@<F5S="!O9B!T:&4@87)G=6UE;G1S(&%S
M(&YO;BUO<'1I;VYS"B`@("`@("`@("`@("`@(&%N9"!E;F0@=&AE(&QO;W`N
M("HO"B`@("`@("`@("`@(&EF("@D87)G(#T]("<M+2<I('L*("`@("`@("`@
M("`@("`@("1N;VY?;W!T<R`](&%R<F%Y7VUE<F=E*"1N;VY?;W!T<RP@87)R
M87E?<VQI8V4H)&%R9W,L("1I("L@,2DI.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("@D87)G>S!]("$]
M("<M)R!\?"`H<W1R;&5N*"1A<F<I(#X@,2`F)B`D87)G>S%](#T]("<M)R`F
M)B`A)&QO;F=?;W!T:6]N<RDI('L*("`@("`@("`@("`@("`@("1N;VY?;W!T
M<R`](&%R<F%Y7VUE<F=E*"1N;VY?;W!T<RP@87)R87E?<VQI8V4H)&%R9W,L
M("1I*2D["B`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?2!E
M;'-E:68@*'-T<FQE;B@D87)G*2`^(#$@)B8@)&%R9WLQ?2`]/2`G+2<I('L*
M("`@("`@("`@("`@("`@("1E<G)O<B`]($-O;G-O;&5?1V5T;W!T.CI?<&%R
M<V5,;VYG3W!T:6]N*'-U8G-T<B@D87)G+"`R*2P@)&QO;F=?;W!T:6]N<RP@
M)&]P=',L("1A<F=S*3L*("`@("`@("`@("`@("`@(&EF("A014%2.CII<T5R
M<F]R*"1E<G)O<BDI"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N("1E<G)O
M<CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("1E<G)O
M<B`]($-O;G-O;&5?1V5T;W!T.CI?<&%R<V53:&]R=$]P=&EO;BAS=6)S='(H
M)&%R9RP@,2DL("1S:&]R=%]O<'1I;VYS+"`D;W!T<RP@)&%R9W,I.PH@("`@
M("`@("`@("`@("`@:68@*%!%05(Z.FES17)R;W(H)&5R<F]R*2D*("`@("`@
M("`@("`@("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@87)R87DH)&]P=',L("1N;VY?;W!T
M<RD["B`@("!]"@H@("`@+RHJ"B`@("`@*B!`86-C97-S('!R:79A=&4*("`@
M("`J"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95-H;W)T3W!T:6]N*"1A
M<F<L("1S:&]R=%]O<'1I;VYS+"`F)&]P=',L("8D87)G<RD*("`@('L*("`@
M("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S=')L96XH)&%R9RD[("1I*RLI('L*
M("`@("`@("`@("`@)&]P="`]("1A<F=[)&E].PH@("`@("`@("`@("`D;W!T
M7V%R9R`](&YU;&P["@H@("`@("`@("`@("`O*B!4<GD@=&\@9FEN9"!T:&4@
M<VAO<G0@;W!T:6]N(&EN('1H92!S<&5C:69I97(@<W1R:6YG+B`J+PH@("`@
M("`@("`@("!I9B`H*"1S<&5C(#T@<W1R<W1R*"1S:&]R=%]O<'1I;VYS+"`D
M;W!T*2D@/3T](&9A;'-E('Q\("1A<F=[)&E](#T]("<Z)RD*("`@("`@("`@
M("`@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H
M(D-O;G-O;&5?1V5T;W!T.B!U;G)E8V]G;FEZ960@;W!T:6]N("TM("1O<'0B
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*'-T<FQE;B@D<W!E
M8RD@/B`Q("8F("1S<&5C>S%](#T]("<Z)RD@>PH@("`@("`@("`@("`@("`@
M:68@*'-T<FQE;B@D<W!E8RD@/B`R("8F("1S<&5C>S)](#T]("<Z)RD@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D:2`K(#$@/"!S=')L96XH)&%R9RDI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@+RH@3W!T:6]N('1A:V5S(&%N
M(&]P=&EO;F%L(&%R9W5M96YT+B!5<V4@=&AE(')E;6%I;F1E<B!O9@H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!T:&4@87)G('-T<FEN9R!I9B!T:&5R
M92!I<R!A;GET:&EN9R!L969T+B`J+PH@("`@("`@("`@("`@("`@("`@("`@
M("`D;W!T<UM=(#T@87)R87DH)&]P="P@<W5B<W1R*"1A<F<L("1I("L@,2DI
M.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@("`@("\J($]P=&EO;B!R97%U:7)E<R!A;B!A<F=U;65N="X@57-E
M('1H92!R96UA:6YD97(@;V8@=&AE(&%R9PH@("`@("`@("`@("`@("`@("`@
M("`@('-T<FEN9R!I9B!T:&5R92!I<R!A;GET:&EN9R!L969T+B`J+PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D:2`K(#$@/"!S=')L96XH)&%R9RDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@)&]P='-;72`](&%R<F%Y*"1O<'0L
M("!S=6)S='(H)&%R9RP@)&D@*R`Q*2D["B`@("`@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T@96QS92!I9B`H;&ES
M="@L("1O<'1?87)G*2`](&5A8V@H)&%R9W,I*0H@("`@("`@("`@("`@("`@
M("`@("`@("`O*B!%;'-E('5S92!T:&4@;F5X="!A<F=U;65N="X@*B\["B`@
M("`@("`@("`@("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@("`@("`@
M("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z(&]P
M=&EO;B!R97%U:7)E<R!A;B!A<F=U;65N="`M+2`D;W!T(BD["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1O<'1S6UT@
M/2!A<G)A>2@D;W!T+"`D;W!T7V%R9RD["B`@("`@("`@?0H@("`@?0H*("`@
M("\J*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*@H@("`@("HO"B`@
M("!F=6YC=&EO;B!?<&%R<V5,;VYG3W!T:6]N*"1A<F<L("1L;VYG7V]P=&EO
M;G,L("8D;W!T<RP@)B1A<F=S*0H@("`@>PH@("`@("`@($!L:7-T*"1O<'0L
M("1O<'1?87)G*2`](&5X<&QO9&4H)STG+"`D87)G*3L*("`@("`@("`D;W!T
M7VQE;B`]('-T<FQE;B@D;W!T*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I
M(#P@8V]U;G0H)&QO;F=?;W!T:6]N<RD[("1I*RLI('L*("`@("`@("`@("`@
M)&QO;F=?;W!T("`]("1L;VYG7V]P=&EO;G-;)&E=.PH@("`@("`@("`@("`D
M;W!T7W-T87)T(#T@<W5B<W1R*"1L;VYG7V]P="P@,"P@)&]P=%]L96XI.PH*
M("`@("`@("`@("`@+RH@3W!T:6]N(&1O97-N)W0@;6%T8V@N($=O(&]N('1O
M('1H92!N97AT(&]N92X@*B\*("`@("`@("`@("`@:68@*"1O<'1?<W1A<G0@
M(3T@)&]P="D*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH*("`@("`@("`@
M("`@)&]P=%]R97-T("`]('-U8G-T<B@D;&]N9U]O<'0L("1O<'1?;&5N*3L*
M"B`@("`@("`@("`@("\J($-H96-K('1H870@=&AE(&]P=&EO;G,@=6YI<75E
M;'D@;6%T8VAE<R!O;F4@;V8@=&AE(&%L;&]W960*("`@("`@("`@("`@("`@
M;W!T:6]N<RX@*B\*("`@("`@("`@("`@:68@*"1O<'1?<F5S="`A/2`G)R`F
M)B`D;W!T>S!]("$]("<])R`F)@H@("`@("`@("`@("`@("`@)&D@*R`Q(#P@
M8V]U;G0H)&QO;F=?;W!T:6]N<RD@)B8*("`@("`@("`@("`@("`@("1O<'0@
M/3T@<W5B<W1R*"1L;VYG7V]P=&EO;G-;)&DK,5TL(#`L("1O<'1?;&5N*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(%!%05(Z.G)A:7-E17)R;W(H(D-O
M;G-O;&5?1V5T;W!T.B!O<'1I;VX@+2TD;W!T(&ES(&%M8FEG=6]U<R(I.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<W5B<W1R*"1L;VYG7V]P
M="P@+3$I(#T]("<])RD@>PH@("`@("`@("`@("`@("`@:68@*'-U8G-T<B@D
M;&]N9U]O<'0L("TR*2`A/2`G/3TG*2!["B`@("`@("`@("`@("`@("`@("`@
M+RH@3&]N9R!O<'1I;VX@<F5Q=6ER97,@86X@87)G=6UE;G0N"B`@("`@("`@
M("`@("`@("`@("`@("`@5&%K92!T:&4@;F5X="!A<F=U;65N="!I9B!O;F4@
M=V%S;B=T('-P96-I9FEE9"X@*B\["B`@("`@("`@("`@("`@("`@("`@:68@
M*"%S=')L96XH)&]P=%]A<F<I("8F("$H;&ES="@L("1O<'1?87)G*2`](&5A
M8V@H)&%R9W,I*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z(&]P=&EO;B`M+21O
M<'0@<F5Q=6ER97,@86X@87)G=6UE;G0B*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T@96QS92!I9B`H
M)&]P=%]A<F<I('L*("`@("`@("`@("`@("`@(')E='5R;B!014%2.CIR86ES
M945R<F]R*")#;VYS;VQE7T=E=&]P=#H@;W!T:6]N("TM)&]P="!D;V5S;B=T
M(&%L;&]W(&%N(&%R9W5M96YT(BD["B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@("1O<'1S6UT@/2!A<G)A>2@G+2TG("X@)&]P="P@)&]P=%]A<F<I.PH@
M("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H*("`@("`@("!R971U<FX@
M4$5!4CHZ<F%I<V5%<G)O<B@B0V]N<V]L95]'971O<'0Z('5N<F5C;V=N:7IE
M9"!O<'1I;VX@+2TD;W!T(BD["B`@("!]"@H@("`@+RHJ"B`@("`J(%-A9F5L
M>2!R96%D('1H92`D87)G=B!02%`@87)R87D@86-R;W-S(&1I9F9E<F5N="!0
M2%`@8V]N9FEG=7)A=&EO;G,N"B`@("`J(%=I;&P@=&%K92!C87)E(&]N(')E
M9VES=&5R7V=L;V)A;',@86YD(')E9VES=&5R7V%R9V-?87)G=B!I;FD@9&ER
M96-T:79E<PH@("`@*@H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B!`<F5T
M=7)N(&UI>&5D('1H92`D87)G=B!02%`@87)R87D@;W(@4$5!4B!E<G)O<B!I
M9B!N;W0@<F5G:7-T97)E9`H@("`@*B\*("`@(&9U;F-T:6]N(')E86102%!!
M<F=V*"D*("`@('L*("`@("`@("!G;&]B86P@)&%R9W8["B`@("`@("`@:68@
M*"%I<U]A<G)A>2@D87)G=BDI('L*("`@("`@("`@("`@:68@*"%`:7-?87)R
M87DH)%]315)615);)V%R9W8G72DI('L*("`@("`@("`@("`@("`@(&EF("@A
M0&ES7V%R<F%Y*"1'3$]"04Q36R=(5%107U-%4E9%4E]605)3)UU;)V%R9W8G
M72DI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%
M<G)O<B@B0V]N<V]L95]'971O<'0Z($-O=6QD(&YO="!R96%D(&-M9"!A<F=S
M("AR96=I<W1E<E]A<F=C7V%R9W8]3V9F/RDB*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(')E='5R;B`D1TQ/0D%,4ULG2%144%]315)6
M15)?5D%24R==6R=A<F=V)UT["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N("1?4T525D526R=A<F=V)UT["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D87)G=CL*("`@('T*"GT*"C\^"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R````````````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$S,B`P,C$S,C8`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]%
M<G)O<BYP:'``````````````````````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`S-#4S(#$P-3$U-#,T,3,R(#`R,3(W,@`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5
M;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+PHO+R`D260Z($5R<F]R+G!H<"QV(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T
M.C0U(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)U!%05(N<&AP)SL*"B\J*@HJ
M($-A8VAE($5R<F]R(&-L87-S"BH@"BH@0'!A8VMA9V4@0V%C:&4**B\*8VQA
M<W,@0V%C:&5?17)R;W(@97AT96YD<R!014%27T5R<F]R('L*"@H@("\J*@H@
M("H@4')E9FEX(&]F(&%L;"!E<G)O<B!M97-S86=E<RX*("`J(`H@("H@0'9A
M<B`@<W1R:6YG"B`@*B\*("!V87(@)&5R<F]R7VUE<W-A9V5?<')E9FEX(#T@
M)T-A8VAE+45R<F]R.B`G.PH@(`H@("\J*@H@("H@0W)E871E<R!A;B!C86-H
M92!E<G)O<B!O8FIE8W0N"B`@*B`*("`J($!P87)A;2`@<W1R:6YG("!E<G)O
M<B!M97-S86=E"B`@*B!`<&%R86T@('-T<FEN9R`@9FEL92!W:&5R92!T:&4@
M97)R;W(@;V-C=7)E9`H@("H@0'!A<F%M("!S=')I;F<@(&QI;F5N=6UB97(@
M=VAE<F4@=&AE(&5R<F]R(&]C8W5R960*("`J+PH@(&9U;F-T:6]N($-A8VAE
M7T5R<F]R*"1M<V<L("1F:6QE(#T@7U]&24Q%7U\L("1L:6YE(#T@7U],24Y%
M7U\I('L*("`@(`H@("`@)'1H:7,M/E!%05)?17)R;W(H<W!R:6YT9B@B)7,@
M6R5S(&]N(&QI;F4@)61=+B(L("1M<V<L("1F:6QE+"`D;&EN92DI.PH@("`@
M"B`@?2`O+R!E;F0@9G5N8R!#86-H95]%<G)O<@H@(`I]("\O(&5N9"!C;&%S
M<R!#86-H95]%<G)O<@H_/@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O1G5N8W1I
M;VXN<&AP````````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`Q
M,3`W-2`Q,#4Q-30S-#$S,B`P,C$W-C4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@
M*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N
M(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES
M(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y3
M12P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y
M;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@
M86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@
M=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@
M("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y
M;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@4V5B87-T
M:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!&=6YC=&EO;BYP:'`L=B`Q+C8@,C`P,R\P,2\P-"`Q,3HU-#HT
M-2!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H92YP:'`G.PH*+RHJ"BH@
M1G5N8W1I;VY?0V%C:&4**@HJ(%!U<G!O<V4Z"BH**B`@($-A8VAI;F<@=&AE
M(')E<W5L="!A;F0@;W5T<'5T(&]F(&9U;F-T:6]N<RX**@HJ($5X86UP;&4Z
M"BH**B`@(')E<75I<F5?;VYC92`G0V%C:&4O1G5N8W1I;VXN<&AP)SL**@HJ
M("`@8VQA<W,@9F]O('L**B`@("`@9G5N8W1I;VX@8F%R*"1T97-T*2!["BH@
M("`@("`@96-H;R`B9F]O.CIB87(H)'1E<W0I/&)R/B(["BH@("`@('T**B`@
M('T**@HJ("`@8VQA<W,@8F%R('L**B`@("`@9G5N8W1I;VX@9F]O8F%R*"1O
M8FIE8W0I('L**B`@("`@("!E8VAO("<D)RXD;V)J96-T+B<M/F9O;V)A<B@G
M+B1O8FIE8W0N)RD\8G(^)SL**B`@("`@?0HJ("`@?0HJ"BH@("`D8F%R(#T@
M;F5W(&)A<CL**@HJ("`@9G5N8W1I;VX@9F]O8F%R*"D@>PHJ("`@("!E8VAO
M("=F;V]B87(H*2<["BH@("!]"BH**B`@("1C86-H92`](&YE=R!#86-H95]&
M=6YC=&EO;B@I.PHJ"BH@("`D8V%C:&4M/F-A;&PH)V9O;SHZ8F%R)RP@)W1E
M<W0G*3L**B`@("1C86-H92T^8V%L;"@G8F%R+3YF;V]B87(G+"`G8F%R)RD[
M"BH@("`D8V%C:&4M/F-A;&PH)V9O;V)A<B<I.PHJ"BH@3F]T93H**B`**B`@
M(%EO=2!C86YN;W0@8V%C:&4@979E<GD@9G5N8W1I;VXN(%EO=2!S:&]U;&0@
M;VYL>2!C86-H92`**B`@(&9U;F-T:6]N<R!T:&%T(&]N;'D@9&5P96YD(&]N
M('1H96ER(&%R9W5M96YT<R!A;F0@9&]N)W0@=7-E"BH@("!G;&]B86P@;W(@
M<W1A=&EC('9A<FEA8FQE<RP@9&]N)W0@<F5L>2!O;B!D871A8F%S92!Q=65R
M:65S(&]R(`HJ("`@9FEL97,L(&%N9"!S;R!O;BX**B`**B!`875T:&]R("`@
M("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@HJ($!M;V1U;&4@("`@("`@1G5N8W1I;VY?0V%C:&4**B!`;6]D=6QE
M9W)O=7`@($9U;F-T:6]N7T-A8VAE"BH@0'!A8VMA9V4@("`@("!#86-H90HJ
M($!V97)S:6]N("`@("`@)%)E=FES:6]N.B`Q+C8@)`HJ($!A8V-E<W,@("`@
M("`@<'5B;&EC"BHO"F-L87-S($-A8VAE7T9U;F-T:6]N(&5X=&5N9',@0V%C
M:&4@>PH@("`@=F%R("1E>'!I<F5S.PH*("`@("\J*@H@("`@*B!#;VYS=')U
M8W1O<@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!.86UE(&]F(&-O
M;G1A:6YE<B!C;&%S<PH@("`@*B!`<&%R86T@("`@87)R87D@("!!<G)A>2!W
M:71H(&-O;G1A:6YE<B!C;&%S<R!O<'1I;VYS"B`@("`J($!P87)A;2`@("!I
M;G1E9V5R($YU;6)E<B!O9B!S96-O;F1S(&9O<B!W:&EC:"!T;R!C86-H90H@
M("`@*B\*("`@(&9U;F-T:6]N($-A8VAE7T9U;F-T:6]N*"1C;VYT86EN97(@
M(#T@)V9I;&4G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&-O;G1A
M:6YE<E]O<'1I;VYS(#T@87)R87DH)V-A8VAE7V1I<B<@("`@("`@/3X@)RXG
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)V9I;&5N86UE7W!R969I>"<@/3X@)V-A8VAE7R<*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@*2P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1E>'!I<F5S
M(#T@,S8P,`H@("`@("`@("`@("`@("`@("`@("`@("`@("`I"B`@("!["B`@
M("`@("1T:&ES+3Y#86-H92@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R7V]P=&EO
M;G,I.PH@("`@("`D=&AI<RT^97AP:7)E<R`]("1E>'!I<F5S.R`@("`@(`H@
M("`@?0H*("`@("\J*@H@("`@*B!014%2+41E8V]N<W1R=6-T;W(*("`@("H@
M0V%L;"!D96-O;G-T<G5C=&]R(&]F('!A<F5N=`H@("`@*B\*("`@(&9U;F-T
M:6]N(%]#86-H95]&=6YC=&EO;B@I('L*("`@("`@("`D=&AI<RT^7T-A8VAE
M*"D["B`@("!]"@H@("`@+RHJ"B`@("`J($-A;&QS(&$@8V%C:&5A8FQE(&9U
M;F-T:6]N(&]R(&UE=&AO9"X*("`@("H*("`@("H@0')E='5R;B!M:7AE9"`D
M<F5S=6QT"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I
M;VX@8V%L;"@I('L*("`@("`@("`O+R!G970@87)G=6UE;G1S"B`@("`@("`@
M)&%R9W5M96YT<R`](&9U;F-?9V5T7V%R9W,H*3L*"B`@("`@("`@+R\@9V5N
M97)A=&4@8V%C:&4@:60*("`@("`@("`D:60@/2!M9#4H<V5R:6%L:7IE*"1A
M<F=U;65N=',I*3L*"B`@("`@("`@+R\@<75E<GD@8V%C:&4*("`@("`@("`D
M8V%C:&5D7V]B:F5C="`]("1T:&ES+3YG970H)&ED+"`G9G5N8W1I;VY?8V%C
M:&4G*3L*"B`@("`@("`@:68@*"1C86-H961?;V)J96-T("$]($Y53$PI('L*
M("`@("`@("`@("`@+R\@8V%C:&4@:&ET.B!R971U<FX@8V%C:&5D(&]U='!U
M="!A;F0@<F5S=6QT"@H@("`@("`@("`@("`D;W5T<'5T(#T@)&-A8VAE9%]O
M8FIE8W1;,%T["B`@("`@("`@("`@("1R97-U;'0@/2`D8V%C:&5D7V]B:F5C
M=%LQ73L*"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@8V%C:&4@
M;6ES<SH@8V%L;"!F=6YC=&EO;BP@<W1O<F4@;W5T<'5T(&%N9"!R97-U;'0@
M:6X@8V%C:&4*"B`@("`@("`@("`@(&]B7W-T87)T*"D["B`@("`@("`@("`@
M("1T87)G970@/2!A<G)A>5]S:&EF="@D87)G=6UE;G1S*3L*"B`@("`@("`@
M("`@("\O(&-L87-S;F%M93HZ<W1A=&EC365T:&]D"B`@("`@("`@("`@(&EF
M("AS=')S='(H)'1A<F=E="P@)SHZ)RDI('L*("`@("`@("`@("`@("`@(&QI
M<W0H)&-L87-S+"`D;65T:&]D*2`](&5X<&QO9&4H)SHZ)RP@)'1A<F=E="D[
M"@H@("`@("`@("`@("`@("`@)')E<W5L="`](&-A;&Q?=7-E<E]F=6YC7V%R
M<F%Y*&%R<F%Y*"1C;&%S<RP@)&UE=&AO9"DL("1A<F=U;65N=',I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`O+R!O8FIE8W0M/FUE=&AO9`H@("`@
M("`@("`@("!E;'-E:68@*'-T<G-T<B@D=&%R9V5T+"`G+3XG*2D@>PH@("`@
M("`@("`@("`@("`@;&ES="@D;V)J96-T+"`D;65T:&]D*2`](&5X<&QO9&4H
M)RT^)RP@)'1A<F=E="D["B`@("`@("`@("`@("`@("!G;&]B86P@)"1O8FIE
M8W0["@H@("`@("`@("`@("`@("`@)')E<W5L="`](&-A;&Q?=7-E<E]F=6YC
M7V%R<F%Y*&%R<F%Y*"0D;V)J96-T+"`D;65T:&]D*2P@)&%R9W5M96YT<RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(&9U;F-T:6]N"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@)')E<W5L="`](&-A;&Q?
M=7-E<E]F=6YC7V%R<F%Y*"1T87)G970L("1A<F=U;65N=',I.PH@("`@("`@
M("`@("!]"@H@("`@("`@("`@("`D;W5T<'5T(#T@;V)?9V5T7V-O;G1E;G1S
M*"D["B`@("`@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("`@("`@
M)'1H:7,M/G-A=F4H)&ED+"!A<G)A>2@D;W5T<'5T+"`D<F5S=6QT*2P@)'1H
M:7,M/F5X<&ER97,L("=F=6YC=&EO;E]C86-H92<I.PH@("`@("`@('T*"B`@
M("`@("`@96-H;R`D;W5T<'5T.PH@("`@("`@(')E='5R;B`D<F5S=6QT.PH@
M("`@?0I]"C\^"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE
M+T=R87!H:6-S+G!H<```````````````````````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,S`U-S`@,3`U,34T,S0Q,S(@,#(Q-S0Q`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````#P_<&AP"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P
M>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@
M=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@
M=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE
M($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R
M7S`R+G1X="X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M('P@268@>6]U(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L
M:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T
M:')O=6=H('1H92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E
M('1O("`@("`@("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N
M(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z
M(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@
M("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK"B\O"B\O("1)9#H@1W)A<&AI8W,N<&AP+'8@,2XU(#(P,#,O,#$O,#0@
M,3$Z-30Z-#4@;6H@17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4N<&AP)SL*
M"B\J*@HJ($=R87!H:6-S(&1I<VL@8V%C:&4N"BH@"BH@5&AE('5S=6%L('=A
M>2!T;R!C<F5A=&4@:6UA9V5S(&ES('1O('!A<W,@<V]M92!A<F=U;65N=',@
M=&AA="!D97-C<FEB92!T:&4@:6UA9V4@"BH@=&\@82!S8W)I<'0@=&AA="!D
M>6YA;6EC86QL>2!C<F5A=&5S(&%N(&EM86=E+B!&;W(@979E<GD@:6UA9V4@
M;V8@82!P86=E(`HJ(&$@;F5W(%!(4"!I;G1E<G!R971E<B!G971S('-T87)T
M960N(%1H:7,@:7,@82!G;V]D('=A>2!T;R!K:6QL('EO=7(@=V5B<V5R=F5R
M+@HJ(`HJ(%=H96X@9&5A;&EN9R!W:71H(&1Y;F%M:6-A;&QY(&=E;F5R871E
M9"!I;6%G97,@>6]U('-H;W5L9"!N;W0@8V%L;"!A;F]T:&5R('-C<FEP="`*
M*B!T;R!G96YE<F%T92!T:&4@:6UA9V5S(&)U="!G96YE<F%T92!T:&4@:6UA
M9V5S(&)Y('1H92!S8W)I<'0@=&AA="!P<F]D=6-E<R!T:&4@<&%G90HJ('1H
M870@8V]N=&%I;G,@=&AE(&EM86=E<RX@5&AI<R!I<R!A(&UA:F]R(&EM<')O
M=F5M96YT(&)U="!I="=S(&]N;'D@:&%L9B!T:&4@=V%Y+@HJ(`HJ(%1H97)E
M)W,@;F\@;F5E9"!T;R!R97)E;F1E<B!A;B!I;6%G92!O;B!E=F5R>2!R97%U
M97-T+B!!('-I;7!L92!D:7-K(&-A8VAE(&-A;B!R961U8V4**B!T:&4@8V]M
M<'5T871I;VX@=&EM92!D<F%M871I8V%L;'DN(%1H:7,@:7,@=VAA="!T:&4@
M8VQA<W,@9W)A<&AI8W-?8V%C:&4@:7,@9F]R+B`**B`**B!5<V%G93H**B`*
M*B`O+R!C<F5A=&4@86X@:6YS=&%N8V4@;V8@=&AE(&=R87!H:6-S(&-A8VAE
M"BH@)&-A8VAE(#T@;F5W(&=R87!H:6-S7V-A8VAE.PHJ"BH@)&EM9R`]($EM
M86=E0W)E871E*"XN+BD["BH**B`O+R!C;VUP=71E(&%N($E$(&9O<B!Y;W5R
M(&EM86=E(&)A<V5D(&]N('1Y<&EC86P@<&%R86UE=&5R<PHJ("1I9"`](&TU
M9"@@)'-I>F4L("1C;VQO<G,L("1L86)E;"D["BH@"BH@+R\@8VAE8VL@:68@
M:70G<R!C86-H960**B!I9B`H(2@D;&EN:R`]("1C86-H92T^9V5T26UA9V5,
M:6YK*"1I9"P@)V=I9B<I*2D@>PHJ("`**B`@("\O(&AM;6TL(&ET)W,@;F]T
M(&-A8VAE9"P@8W)E871E(&ET"BH@("`N+BX**B`@("\O(&-A8VAE26UA9V5,
M:6YK*"D@86YD(&-A8VAE26UA9V4H*2!M86ME('1H92!);6%G94=)1B@I(&-A
M;&PA"BH@("`O+R!C86-H94EM86=E*"D@<F5T=7)N<R!T:&4@=F%L=64@;V8@
M26UA9V5'248H*2!;971C+ETL(&-A8VAE26UA9V5,:6YK*"D@<F5T=7)N<R!A
M(%523`HJ("`@)&QI;FL@/2`D8V%C:&4M/F-A8VAE26UA9V5,:6YK*"1I9"P@
M)&EM9RP@)V=I9B<I.PHJ(`HJ('T**@HJ("\O($]K+"!L970G<R!B=6EL9"!T
M:&4@26UA9V5,:6YK"BH@)'-I>F4@/2!G971);6%G95-I>F4H)&QI;FM;,%TI
M.PHJ('!R:6YT9B@G/&EM9R!S<F,](B5S(B`E<SXG+"`D;&EN:ULQ72P@)'-I
M>F5;,UTI.PHJ"BH@+R\@9F]R(&-A8VAE26UA9V4H*3H**B`O+R!H96%D97(H
M)T-O;G1E;G0M='EP93H@:6UA9V4O9VEF)RD[('!R:6YT("1C86-H92T^8V%C
M:&5);6%G92@D:60L("1I;6<L("=G:68G*3L**B`**@HJ(%1H92!C;&%S<R!R
M97%U:7)E<R!02%`@-"XP+C(K(%M);6%G951Y<&4H*5TN($YO=&4@=&AA="!C
M86-H94EM86=E*"D@=V]R:W,@=VET:`HJ('1H92!O=71P=70@8G5F9F5R+B!-
M;V1I9GD@:70@:68@<F5Q=6ER960A"BH**B!`875T:&]R("`@56QF(%=E;F1E
M;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E<G-I;VX@("1)9#H@1W)A
M<&AI8W,N<&AP+'8@,2XU(#(P,#,O,#$O,#0@,3$Z-30Z-#4@;6H@17AP("0*
M*B!`<&%C:V%G92`@0V%C:&4**B\*8VQA<W,@0V%C:&5?1W)A<&AI8W,@97AT
M96YD<R!#86-H92!["@H*("`@("\J*@H@("`@*B!#86-H92!54DP@<')E9FEX
M+@H@("`@*B`*("`@("H@36%K92!S=7)E('1H870@=&AE(&-A8VAE(%523"!P
M<F5F:7@@<&]I;G1S('1O('1H92`D8V%C:&5?9&ER+"!O=&AE<G=I<V4*("`@
M("H@>6]U<B!L:6YK<R!W:6QL(&)E(&)R;VME;BX@57-E('-E=$-A8VAE55),
M('1O('-P96-I9GD@=&AE(&-A8VAE7W5R;"!A;F0@"B`@("`J('-E=$-A8VAE
M1&ER*"D@9F]R('1H92!C86-H95]D:7(N"B`@("`J(`H@("`@*B!`=F%R("!S
M=')I;F<*("`@("H@0'-E92`@<V5T0V%C:&554DPH*2P@<V5T0V%C:&5$:7(H
M*0H@("`@*B\*("`@('9A<B`D8V%C:&5?=7)L(#T@)R<["@H@("`@+RHJ"B`@
M("`J($1I<F5C=&]R>2!W:&5R92!C86-H960@9FEL97,@9V5T('-T;W)E9"X*
M("`@("H@<PH@("`@*B!-86ME('-U<F4@=&AA="!T:&4@8V%C:&5?9&ER(&ES
M('=R:71A8FQE(&%N9"!O9F9E<G,@96YO=6=H('-P86-E+B!#:&5C:R`*("`@
M("H@86QS;R!I9B!Y;W5R(&-A8VAE7W5R;"!P;VEN=',@=&\@=&AE(&1I<F5C
M=&]R>2X@57-E('-E=$-A8VAE1&ER*"D@=&\@<V5T"B`@("`J('1H92!V87)I
M86)L92X*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@("`@*B!`<V5E("!S
M971#86-H941I<B@I+"!S971#86-H95523"@I"B`@("`J+PH@("`@=F%R("1C
M86-H95]D:7(@/2`G)SL*"B`@("`O*BH*("`@("H@3F%M97!R969I>"!O9B!C
M86-H960@9FEL97,N"B`@("`J(`H@("`@*B!097(@9&5F875L="!T:&4@<')E
M9FEX(")G<F%P:&EC<U\B(&=E=',@=7-E9"X@66]U(&UI9VAT('5S92!T:&ES
M(`H@("`@*B!F;W(@=F5R<VEO;FEN9R!O<B!T;R!E87-E("AM86YU86PI(&-L
M96%N('5P<RX*("`@("H*("`@("H@0'9A<B`@("`@('-T<FEN9PH@("`@*B\*
M("`@('9A<B`D8V%C:&5?9FEL95]P<F5F:7@@/2`G9W)A<&AI8W-?)SL*("`@
M(`H@("`@"B`@("`O*BH*("`@("H@0V%C:&4@8V]N=&%I;F5R(&=R;W5P+@H@
M("`@*@H@("`@*B!`=F%R("`@("`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1C
M86-H95]G<F]U<"`]("=G<F%P:&EC<R<["@H@("`@"B`@("`O*BH*("`@("H@
M36%P<&EN9R!F<F]M('-U<'!O<G1E9"!I;6%G92!T>7!E('1O(&$@26UA9V54
M>7!E*"D@8V]N<W1A;G0N"B`@("`J(`H@("`@*B!2969E<G(@=&\@=&AE(%!(
M4"!M86YU86P@9F]R(&UO<F4@:6YF;W)M871I;VYS(&]N($EM86=E5'EP92@I
M"B`@("`J(`H@("`@*B!`=F%R("!A<G)A>0H@("`@*B!`;&EN:R!H='1P.B\O
M=W=W+G!H<"YN970O26UA9V54>7!E"B`@("`J+PH@("`@=F%R("1I;6%G971Y
M<&5S(#T@87)R87DH"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)V=I9B<@("`]/B!)34=?1TE&+"`*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`G:G!G)R`@(#T^($E-1U]*4$<L"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)W!N9R<@("`]/B!)34=?4$Y'+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("=W8FUP)R`@/3X@24U'7U="35`*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@"B`@("`O*BH*("`@("H@26YS=&%N=&EA=&5S(&$@8V%C
M:&4@9FEL92!C;VYT86EN97(N"B`@("`J"B`@("`J+PH@("`@9G5N8W1I;VX@
M0V%C:&5?1W)A<&AI8W,H*2!["B`@("`*("`@("`@("`D=&AI<RT^0V%C:&4H
M)V9I;&4G+"!A<G)A>2@G8V%C:&5?9&ER)R`]/B`D=&AI<RT^8V%C:&5?9&ER
M+"`G9FEL96YA;65?<')E9FEX)R`]/B`D=&AI<RT^8V%C:&5?9FEL95]P<F5F
M:7@I*3L*("`@("`@("`*("`@('T@+R\@96YD(&-O;G-T<G5C=&]R"@H@("`@
M"B`@("`O*BH*("`@("H@4F5T=7)N<R!T:&4@8V]N=&5N="!O9B!A(&-A8VAE
M9"!I;6%G92!F:6QE+@H@("`@*B`*("`@("H@5&AI<R!F=6YC=&EO;B!C86X@
M8F4@=7-E9"!T;R!S96YD('1H92!I;6%G92!D:7)E8W1L>2!T;R!T:&4@8G)O
M=W-E<BX*("`@("H@36%K92!S=7)E('1H870@>6]U('-E;F0@82!C;W)R97-P
M;VYD96YD:6YG(&AE861E<B!B969O<F4@<V5N9&EN9R!T:&4@:6UA9V4@:71S
M96QF+@H@("`@*@H@("`@*B!!;'=A>7,@=')Y('1O(&=E="!T:&4@:6UA9V4@
M9G)O;2!T:&4@8V%C:&4@8F5F;W)E('EO=2!C;VUP=71E(&ET+B!3964@"B`@
M("`J('1H92!C;&%S<R!D;V-S(&9O<B!A;B!E>&%M<&QE+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!);6%G92U)1`H@("`@*B!`<&%R86T@("`@
M<W1R:6YG("!);6%G92!T>7!E.B!G:68L(&IP9RP@<&YG+"!W8FUP"B`@("`J
M($!R971U<FX@("!S=')I;F<@($EM86=E(&9I;&4@8V]N=&5N=',@:68@82!C
M86-H960@9FEL92!E>&ES=',@;W1H97)W:7-E(&%N(&5M<'1Y('-T<FEN9PH@
M("`@*B!`<V5E("`@("`@8V%C:&5);6%G92@I"B`@("`J+R`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@9G5N8W1I;VX@9V5T26UA
M9V4H)&ED+"`D9F]R;6%T(#T@)W!N9R<I('L*("`@("`@("`D:60@/2`D=&AI
M<RT^9V5N97)A=&5)1"@D:60L("1F;W)M870I.PH@("`@("`@(`H@("`@("`@
M(')E='5R;B`D=&AI<RT^9V5T*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P*3L*
M("`@('T@+R\@96YD(&9U;F,@9V5T26UA9V4*"B`@("`*("`@("\J*@H@("`@
M*B!2971U<FYS(&%N(&%R<F%Y('=I=&@@82!L:6YK('1O('1H92!C86-H960@
M:6UA9V4@86YD('1H92!I;6%G92!F:6QE('!A=&@N"B`@("`J(`H@("`@*B!!
M;'=A>7,@=')Y('1O(&=E="!T:&4@:6UA9V4@9G)O;2!T:&4@8V%C:&4@8F5F
M;W)E('EO=2!C;VUP=71E(&ET+B!3964@"B`@("`J('1H92!C;&%S<R!D;V-S
M(&9O<B!A;B!E>&%M<&QE+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!);6%G92U)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!);6%G92!T>7!E
M.B!G:68L(&IP9RP@<&YG+"!W8FUP"B`@("`J($!R971U<FX@("!A<G)A>2`@
M(%L@9G5L;"!P871H('1O('1H92!I;6%G92!F:6QE+"!I;6%G92!U<FP@70H@
M("`@*B!`=&AR;W<@("`@0V%C:&5?17)R;W(*("`@("H@0'-E92`@("`@(&-A
M8VAE26UA9V5,:6YK*"D*("`@("HO"B`@("!F=6YC=&EO;B!G971);6%G94QI
M;FLH)&ED+"`D9F]R;6%T(#T@)W!N9R<I('L*("`@("`@("`D:60@/2`D=&AI
M<RT^9V5N97)A=&5)1"@D:60L("1F;W)M870I.PH@("`@("`@(&EF("@A)'1H
M:7,M/F-O;G1A:6YE<BT^:61%>&ES=',H)&ED+"`D=&AI<RT^8V%C:&5?9W)O
M=7`I*2`*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*"D["@H@("`@("`@("1F
M:6QE(#T@)'1H:7,M/F-A8VAE7W5R;"`N("1T:&ES+3YC86-H95]F:6QE7W!R
M969I>"`N("1I9#L*"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1T:&ES+3YC;VYT
M86EN97(M/F=E=$9I;&5N86UE*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P*2P@
M)&9I;&4I.PH@("`@?2`O+R!E;F0@9G5N8R!G971);6%G94QI;FL*("`@(`H*
M("`@("\J*@H@("`@*B!#<F5A=&4@86X@:6UA9V4@9G)O;2!T:&4@9VEV96X@
M:6UA9V4@:&%N9&QE<BP@8V%C:&4@:70@86YD(')E='5R;B!T:&4@9FEL92!C
M;VYT96YT+@H@("`@*@H@("`@*B!!;'=A>7,@=')Y('1O(')E=')I=F4@=&AE
M(&EM86=E(&9R;VT@=&AE(&-A8VAE(&)E9F]R92!Y;W4@8V]M<'5T92!I="X*
M("`@("H@"B`@("`J(%=A<FYI;F<Z('1H:7,@9G5N8W1I;VX@=7-E<R!T:&4@
M;W5T<'5T(&)U9F9E<BX@268@>6]U(&5X<&5C="!C;VQL:7-I;VYS(`H@("`@
M*B!M;V1I9GD@=&AE(&-O9&4N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I
M;F<@($EM86=E+4E$+B!5<V5D(&%S(&$@<&%R="!O9B!T:&4@8V%C:&4@9FEL
M96YA;64N"B`@("`J("`@("`@("`@("`@("`@("`@(%5S92!M9#4H*2!T;R!G
M96YE<F%T92!A(")U;FEQ=64B($E$(&9O<B!Y;W5R(&EM86=E"B`@("`J("`@
M("`@("`@("`@("`@("`@(&)A<V5D(&]N(&-H87)A8W1E<FES=&EC('9A;'5E
M<R!S=6-H(&%S('1H92!C;VQO<BP@<VEZ92!E=&,N"B`@("`J($!P87)A;2`@
M("!S=')I;F<@($EM86=E(&AA;F1L97(@=&\@8W)E871E('1H92!I;6%G92!F
M<F]M+@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!);6%G92!T>7!E.B!G:68L
M(&IP9RP@<&YG+"!W8FUP+B!!;'-O('5S960@87,@9FEL96YA;64@<W5F9FEX
M+@H@("`@*B`@("`@("`@("`@("`@("`@("!)9B!A;B!U;G-U<'!O<G1E9"!T
M>7!E(&ES(')E<75E<W1E9"!T:&4@9G5N8W1I;VYS('1R:65S('1O(`H@("`@
M*B`@("`@("`@("`@("`@("`@("!F86QL8F%C:R!T;R!A('-U<'!O<G1E9"!T
M>7!E(&)E9F]R92!T:')O=VEN9R!A;B!E>&5P=&EO;BX*("`@("H@0')E='5R
M;B`@('-T<FEN9R`@26UA9V4@8V]N=&5N="!R971U<FYE9"!B>2!);6%G94=)
M1B\N+BX@"B`@("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B!`86-C
M97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!G971);6%G92@I"B`@("`J
M+PH@("`@9G5N8W1I;VX@8V%C:&5);6%G92@D:60L("1I;6<L("1F;W)M870@
M/2`G<&YG)RD@>PH@("`@("`@(&EF("@A)&ED*0H@("`@("`@("`@("!R971U
M<FX@;F5W($-A8VAE7T5R<F]R*"=9;W4@;75S="!P<F]V:61E(&%N($E$(&9O
M<B!A;F0@:6UA9V4@=&\@8F4@8V%C:&5D(2<L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["@H@("`@("`@("1I9"`]("1T:&ES+3YG96YE<F%T94E$*"1I9"P@)&9O
M<FUA="D["B`@("`@("`@)'1Y<&5S(#T@26UA9V54>7!E<R@I.PH*("`@("`@
M("`O+R!#:&5C:R!I9B!T:&4@<F5Q=65S=&5D(&EM86=E('1Y<&4@:7,@<W5P
M<&]R=&5D(&)Y('1H92!'1"!L:6(N"B`@("`@("`@+R\@268@;F]T+"!T<GD@
M82!C86QL8F%C:R!T;R!T:&4@9FER<W0@879A:6QA8FQE(&EM86=E('1Y<&4N
M"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^:6UA9V5T>7!E<ULD9F]R;6%T
M72D@?'P@(2@D='EP97,@)B`D=&AI<RT^:6UA9V5T>7!E<ULD9F]R;6%T72DI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/FEM86=E='EP97,@87,@
M)'-U<'!O<G1E9"`]/B`D8FET;6%S:RD@>PH@("`@("`@("`@("`@("`@:68@
M*"1T>7!E<R`F("1B:71M87-K*2!["B`@("`@("`@("`@("`@("`@("`@;F5W
M($-A8VAE7T5R<F]R*")4:&4@8G5I;&0@:6X@1T0@;&EB(&1O97,@;F]T('-U
M<'!O<G0@=&AE(&EM86=E('1Y<&4@)&9O<FUA="X@1F%L;&)A8VL@=&\@)'-U
M<'!O<G1E9"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W($-A
M8VAE7T5R<F]R*")(;6TL(&ES('EO=7(@4$A0(&)U:6QD('=I=&@@1T0@<W5P
M<&]R=#\@0V%N)W0@9FEN9"!A;GD@<W5P<&]R=&5D('1Y<&5S+B(L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("@D:6UA9V4@/2`D=&AI<RT^9V5T
M*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P*2D*("`@("`@("`@("`@<F5T=7)N
M("1I;6%G93L*"B`@("`@("`@+R\@<V%V92!T:&4@:6UA9V4@=&\@=&AE(&]U
M='!U="!B=69F97(L('=R:71E(&ET('1O(&1I<VL@86YD(`H@("`@("`@("\O
M(')E='5R;B!T:&4@:6UA9V4N"B`@("`@("`@;V)?96YD7V-L96%N*"D["B`@
M("`@("`@;V)?<W1A<G0H*3L@"@H@("`@("`@(&EF("AS=')T;W5P<&5R*"1F
M;W)M870I(#T](")*4$<B*2!["B`@("`@("`@("`@("1G96Y&;W)M870@/2`B
M2E!%1R(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)&=E;D9O<FUA
M="`]('-T<G1O=7!P97(H)&9O<FUA="D["B`@("`@("`@?0H*("`@("`@("`O
M+R!G96YE<F%T92!T:&4@:6UA9V4*("`@("`@("`D9G5N8R`]("=);6%G92<@
M+B`D9V5N1F]R;6%T.PH@("`@("`@("1F=6YC*"1I;6<I.PH@("`@("`@($EM
M86=E1&5S=')O>2@D:6UG*3L*"B`@("`@("`@;V)?96YD*"D["B`@("`@("`@
M)&EM86=E(#T@;V)?9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?96YD7V-L
M96%N*"D["@H@("`@("`@("\O('-A=F4@=&AE(&=E;F5R871E9"!I;6%G92!T
M;R!D:7-K"B`@("`@("`@)'1H:7,M/G-A=F4H)&ED+"`D:6UA9V4L(#`L("1T
M:&ES+3YC86-H95]G<F]U<"D["@H@("`@("`@(')E='5R;B`D:6UA9V4["B`@
M("!]("\O(&5N9"!F=6YC(&-A8VAE26UA9V4*("`@(`H*("`@("\J*@H@("`@
M*B!#<F5A=&4@86X@:6UA9V4@9G)O;2!T:&4@9VEV96X@:6UA9V4@:&%N9&QE
M<BP@8V%C:&4@:70@86YD(')E='5R;B!A('5R;"!A;F0@=&AE(&9I;&4@<&%T
M:"!O9B!T:&4@:6UA9V4N"B`@("`J"B`@("`J($%L=V%Y<R!T<GD@=&\@<F5T
M<FEV92!T:&4@:6UA9V4@9G)O;2!T:&4@8V%C:&4@8F5F;W)E('EO=2!C;VUP
M=71E(&ET+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!);6%G92U)
M1"X@57-E9"!A<R!A('!A<G0@;V8@=&AE(&-A8VAE(&9I;&5N86UE+@H@("`@
M*B`@("`@("`@("`@("`@("`@("!5<V4@;60U*"D@=&\@9V5N97)A=&4@82`B
M=6YI<75E(B!)1"!F;W(@>6]U<B!I;6%G90H@("`@*B`@("`@("`@("`@("`@
M("`@("!B87-E9"!O;B!C:&%R86-T97)I<W1I8R!V86QU97,@<W5C:"!A<R!T
M:&4@8V]L;W(L('-I>F4@971C+@H@("`@*B!`<&%R86T@("`@<W1R:6YG("!)
M;6%G92!H86YD;&5R('1O(&-R96%T92!T:&4@:6UA9V4@9G)O;2X*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@26UA9V4@='EP93H@9VEF+"!J<&<L('!N9RP@
M=V)M<"X@06QS;R!U<V5D(&%S(&9I;&5N86UE('-U9F9I>"X*("`@("H@("`@
M("`@("`@("`@("`@("`@268@86X@=6YS=7!P;W)T960@='EP92!I<R!R97%U
M97-T960@=&AE(&9U;F-T:6]N<R!T<FEE<R!T;R`*("`@("H@("`@("`@("`@
M("`@("`@("`@9F%L;&)A8VL@=&\@82!S=7!P;W)T960@='EP92!B969O<F4@
M=&AR;W=I;F<@86X@97AE<'1I;VXN"B`@("`J($!R971U<FX@("!A<G)A>2`@
M6R!F=6QL('!A=&@@=&\@=&AE(&EM86=E(&9I;&4L(&EM86=E('5R;"!="B`@
M("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B!`86-C97-S("`@<'5B
M;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@8V%C:&5);6%G94QI;FLH)&ED+"`F
M)&EM9RP@)&9O<FUA="`]("=P;F<G*2!["B`@("`@("`@:68@*"$D:60I"B`@
M("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(@*"=9;W4@;75S="!P
M<F]V:61E(&%N($E$(&9O<B!A;F0@:6UA9V4@=&\@8F4@8V%C:&5D(2<L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("1I9"`]("1T:&ES+3YG96YE
M<F%T94E$*"1I9"P@)&9O<FUA="D["B`@("`@("`@)'1Y<&5S(#T@26UA9V54
M>7!E<R@I.PH*("`@("`@("`O+R!#:&5C:R!I9B!T:&4@<F5Q=65S=&5D(&EM
M86=E('1Y<&4@:7,@<W5P<&]R=&5D(&)Y('1H92!'1"!L:6(N"B`@("`@("`@
M+R\@268@;F]T+"!T<GD@82!C86QL8F%C:R!T;R!T:&4@9FER<W0@879A:6QA
M8FQE(&EM86=E('1Y<&4N"B`@("`@("`@:68@*"%I<W-E="@D=&AI<RT^:6UA
M9V5T>7!E<ULD9F]R;6%T72D@?'P@(2@D='EP97,@)B`D=&AI<RT^:6UA9V5T
M>7!E<ULD9F]R;6%T72DI('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M
M/FEM86=E='EP97,@87,@)'-U<'!O<G1E9"`]/B`D8FET;6%S:RD@"B`@("`@
M("`@("`@("`@("!I9B`H)'1Y<&5S("8@)&)I=&UA<VLI"B`@("`@("`@("`@
M("`@("`@("`@;F5W($-A8VAE7T5R<F]R*")4:&4@8G5I;&0@:6X@1T0@;&EB
M(&1O97,@;F]T('-U<'!O<G0@=&AE(&EM86=E('1Y<&4@)&9O<FUA="X@1F%L
M;&)A8VL@=&\@)'-U<'!O<G1E9"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@("`@("`@("`@96QS90H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!N97<@0V%C:&5?17)R;W(H(DAM;2P@:7,@>6]U<B!02%`@8G5I;&0@=VET
M:"!'1"!S=7!P;W)T/R!#86XG="!F:6YD(&%N>2!S=7!P;W)T960@='EP97,N
M(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("1U
M<FP@/2`D=&AI<RT^8V%C:&5?=7)L("X@)'1H:7,M/F-A8VAE7V9I;&5?<')E
M9FEX("X@)&ED.PH@("`@("`@("1F9FEL92`]("1T:&ES+3YC;VYT86EN97(M
M/F=E=$9I;&5N86UE*"1I9"P@)'1H:7,M/F-A8VAE7V=R;W5P*3L*"B`@("`@
M("`@:68@*"1T:&ES+3YI<T-A8VAE9"@D:60L("1T:&ES+3YC86-H95]G<F]U
M<"D@)B8@(6ES17AP:7)E9"@D:60L("1T:&ES+3YC86-H95]G<F]U<"DI"B`@
M("`@("`@("`@(')E='5R;B!A<G)A>2@D9F9I;&4L("1U<FPI.PH*("`@("`@
M("!I9B`H<W1R=&]U<'!E<B@D9F]R;6%T*2`]/2`B2E!'(BD@>PH@("`@("`@
M("`@("`D9V5N1F]R;6%T(#T@(DI014<B.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1G96Y&;W)M870@/2!S=')T;W5P<&5R*"1F;W)M870I.PH@
M("`@("`@('T*"B`@("`@("`@)&9U;F,@/2`G26UA9V4G("X@)&=E;D9O<FUA
M=#L*("`@("`@("`D9G5N8R@D:6UG+"`D9F9I;&4I.PH*("`@("`@("!);6%G
M941E<W1R;WDH)&EM9RD["@H@("`@("`@(')E='5R;B!A<G)A>2@D9F9I;&4L
M("1U<FPI.PH@("`@?2`O+R!E;F0@9G5N8R!C86-H94EM86=E3&EN:PH*("`@
M(`H@("`@+RHJ"B`@("`J(%-E=',@=&AE(%523"!P<F5F:7@@=7-E9"!W:&5N
M(')E;F1E<FEN9R!(5$U,(%1A9W,N(`H@("`@*B`*("`@("H@36%K92!S=7)E
M('1H870@=&AE(%523"!M871C:&5S('1H92!C86-H92!D:7)E8W1O<GDL(`H@
M("`@*B!O=&AE<G=I<V4@>6]U)VQL(&=E="!B<F]K96X@;&EN:W,N"B`@("`J
M(`H@("`@*B!`<&%R86T@("`@<W1R:6YG"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("H@0'-E92`@("`@('-E=$-A8VAE1&ER*"D*("`@("HO"B`@("!F
M=6YC=&EO;B!S971#86-H95523"@D8V%C:&5?=7)L*2!["B`@("`@("`@:68@
M*"1C86-H95]U<FP@)B8@)R\G("$]('-U8G-T<B@D8V%C:&5?=7)L+"`Q*2D@
M"B`@("`@("`@("`@("1C86-H95]U<FP@+CT@)R\G.PH@("`@("`@("`@("`*
M("`@("`@("`D=&AI<RT^8V%C:&5?=7)L(#T@)&-A8VAE7W5R;#L*("`@("`@
M("`*("`@('T@+R\@96YD(&9U;F,@<V5T0V%C:&554DP*"B`@("`*("`@("\J
M*@H@("`@*B!3971S('1H92!D:7)E8W1O<GD@=VAE<F4@=&\@8V%C:&4@9V5N
M97)A=&5D($EM86=E<PH@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9PH@
M("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!S971#86-H
M95523"@I"B`@("`J+PH@("`@9G5N8W1I;VX@<V5T0V%C:&5$:7(H)&-A8VAE
M7V1I<BD@>PH@("`@("`@(&EF("@D8V%C:&5?9&ER("8F("<O)R`A/2!S=6)S
M='(H)&-A8VAE7V1I<BP@,2DI"B`@("`@("`@("`@("1C86-H95]D:7(@+CT@
M)R\G.PH*("`@("`@("`D=&AI<RT^8V%C:&5?9&ER(#T@)&-A8VAE7V1I<CL*
M("`@("`@("`D=&AI<RT^8V]N=&%I;F5R+3YC86-H95]D:7(@/2`D8V%C:&5?
M9&ER.PH@("`@?2`O+R!E;F0@9G5N8R!S971#86-H941I<@H@("`@"B`@("`*
M("`@(&9U;F-T:6]N(&=E;F5R871E240H)'9A<FEA8FQE+"`D9F]R;6%T(#T@
M)W!N9R<I('L*("`@("`@<F5T=7)N(&UD-2AS97)I86QI>F4H)'9A<FEA8FQE
M*2D@+B`G+B<@+B`D9F]R;6%T.PH@("`@?2`O+R!E;F0@9G5N8R!G96YE<F%T
M94E$"B`@("`*("`@(`I]("\O(&5N9"!C;&%S<R!#86-H95]'<F%P:&EC<PH_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92](5%107U)E
M<75E<W0N<&AP````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#(S
M,C4T(#$P-3$U-#,T,3,R(#`R,C0W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H
M8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@
M,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@
M8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%
M+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO
M=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A
M;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T
M:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@
M("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO
M=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!&86)I96X@
M34%25%D@/&9A8FEE;BYM87)T>4!F<F5E+F9R/B!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($A45%!?4F5Q=65S="YP:'`L
M=B`Q+CD@,C`P,R\P-R\Q,R`P.#HR-SHQ."!F86(@17AP("0*"G)E<75I<F5?
M;VYC92`G0V%C:&4N<&AP)SL*<F5Q=6ER95]O;F-E("=(5%10+U)E<75E<W0N
M<&AP)SL*"F1E9FEN92@G0T%#2$5?2%144%]215%515-47T=23U507TY!344G
M+"`G8V%C:&5?:'1T<%]R97%U97-T)RD["F1E9FEN92@G0T%#2$5?2%144%]2
M15%515-47U-50T-%4U-?4D534$].4T5?0T]$12<L(#(P,"D["F1E9FEN92@G
M0T%#2$5?2%144%]215%515-47TM%15!?3$]#04Q?0T]062<L(#$I.PID969I
M;F4H)T-!0TA%7TA45%!?4D5154535%]215154DY?1D%,4T4G+"`R*3L*9&5F
M:6YE*"=#04-(15](5%107U)%455%4U1?4D5455).7U!%05)?15)23U(G+"`S
M*3L*"B\J*@HJ($A45%!?4F5Q=65S="!#86-H90HJ"BH@5&AE(&-L87-S:6-A
M;"!E>&%M<&QE(&ES(#H**@HJ(%EO=2!W86YT('1O(&=E="!N97=S(&9R;VT@
M86YO=&AE<B!S:71E('1H<F]U9V@@4E-3(')E;6]T92!F:6QE<RX@0G5T('EO
M=0HJ(&1O;B=T('=A;G0@=&\@86-C97-S('1O('1O('1H92!R96UO=&4@<VET
M92!A="!E=F5R>2!T:6UE('EO=2!D:7-P;&%Y"BH@:71S(&YE=W,@;VX@>6]U
M<B!S:71E+B!"96-A=7-E+"!I9B!T:&4@<F5M;W1E('-I=&4@:7,@9&]W;B!O
M<B!S;&]W+BXN"BH@4V\@>6]U('EO=2!N965D(&$@8VQA<W,@=VAI8V@@;6%K
M97,@82!L;V-A;"!C86-H92!C;W!Y(&]F('1H92!R96UO=&4@9FEL92X**B!%
M=F5R>2!X(&AO=7)S+"!T:&4@8V%C:&4@:7,@=7!D871E9"X@0G5T(&EF('1H
M92!R96UO=&4@<VET92!I<R!D;W=N+"!T:&4**B!L;V-A;"!C86-H92!C;W!Y
M(&ES(&ME97!E9"`H>6]U(&-A;B!A;'-O(&=E="!E<G)O<B!M97-S86=E<R!I
M9B!Y;W4@=V%N="DN"BH**B!3;R!Y;W4@;F5E9"!T:&ES(&-L87-S(0HJ"BH@
M0V%C:&5?2%144%]297%U97-T(&EN:&5R:71S(&9R;VT@0V%C:&4@86YD('5S
M92!(5%107U)E<75E<W0@=&\@86-C97-S('1O"BH@=&AE(')E;6]T92!F:6QE
M+@HJ"BH@57-A9V4@97AA;7!L92`Z"BH**B`\/W!H<`HJ(')E<75I<F5?;VYC
M92@G0V%C:&4O2%144%]297%U97-T+G!H<"<I.PHJ"BH@)&-A8VAE(#T@)FYE
M=R!#86-H95](5%107U)E<75E<W0H)VAT='`Z+R]W=W<N<&AP+FYE="<L($Y5
M3$PL("=F:6QE)RP@3E5,3"P@,S8P,"D["BH@)&-A8VAE+3YS96YD4F5Q=65S
M="@I.PHJ("1R96UO=&5&:6QE0F]D>2`]("1C86-H92T^9V5T4F5S<&]N<V5"
M;V1Y*"D["BH**B`H+BXN*0HJ(#\^"BH**B!`875T:&]R("`@1F%B:65N($U!
M4E19(#QF86)I96XN;6%R='E`9G)E92YF<CX**B!`=F5R<VEO;B`@)$ED.B!(
M5%107U)E<75E<W0N<&AP+'8@,2XY(#(P,#,O,#<O,3,@,#@Z,C<Z,3@@9F%B
M($5X<"`D"BH@0'!A8VMA9V4@($-A8VAE"BHO"@IC;&%S<R!#86-H95](5%10
M7U)E<75E<W0@97AT96YD<R!#86-H90I["@H@("`@+R\@+2TM(%!R:79A=&4@
M<')O<&5R=&EE<R`M+2T*"B`@("`O*BH*("`@("H@3&EF971I;64@:6X@<V5C
M;VYD<R`H,"!E;F1L97-S*0H@("`@*@H@("`@*B!`=F%R(&EN="`D7V5X<&ER
M97,*("`@("HO"B`@("!V87(@)%]E>'!I<F5S.PH*("`@("\J*@H@("`@*B!(
M5%10(%)E<75E<W0*("`@("H*("`@("H@0'9A<B!O8FIE8W0@)%]R97%U97-T
M"B`@("`J+PH@("`@=F%R("1?<F5Q=65S=#L*"B`@("`O*BH*("`@("H@0V%C
M:&4@:60@9F]R('1H92!C;&%S<VEC(&-A8VAE(&9I;&4*("`@("H*("`@("H@
M0'-E92!S96YD4F5Q=65S="@I"B`@("`J($!V87(@<W1R:6YG("1?:60*("`@
M("HO"B`@("!V87(@)%]I9#L*"B`@("`O*BH*("`@("H@0V%C:&4@:60@9F]R
M('1H92!E;F1L97-S(&-A8VAE(&9I;&4*("`@("H*("`@("H@0'-E92!S96YD
M4F5Q=65S="@I"B`@("`J($!V87(@<W1R:6YG("1?:60*("`@("HO"B`@("!V
M87(@)%]I9#(["@H@("`@+RHJ"B`@("`J($1A=&$@=&\@=7-E"B`@("`J"B`@
M("`J($!S964@9V5T4F5P;VYS94)O9'DH*2P@9V5T4F5P;VYS94AE861E<B@I
M+"!G971297!O;G-E0V]D92@I"B`@("`J($!V87(@87)R87D@)%]D871A"B`@
M("`J+PH@("`@=F%R("1?9&%T82`["@H@("`@+R\@+2TM(%!U8FQI8R!M971H
M;V1S("TM+0H*("`@("\J*@H@("`@*B!#;VYS=')U8W1O<@H@("`@*@H@("`@
M*B!`<&%R86T@)'5R;"!4:&4@=7)L('1O(&%C8V5S<PH@("`@*B!`<&%R86T@
M)'!A<F%M<R!!<W-O8VEA=&EV92!A<G)A>2!O9B!P87)A;65T97)S('=H:6-H
M(&-A;B!B93H*("`@("H@("`@("`@("`@("`@("`@("!M971H;V0@("`@("T@
M365T:&]D('1O('5S92P@1T54+"!03U-4(&5T8PH@("`@*B`@("`@("`@("`@
M("`@("`@(&AT='`@("`@("`@+2!(5%10(%9E<G-I;VX@=&\@=7-E+"`Q+C`@
M;W(@,2XQ"B`@("`J("`@("`@("`@("`@("`@("`@=7-E<B`@("`@("`M($)A
M<VEC($%U=&@@=7-E<FYA;64*("`@("H@("`@("`@("`@("`@("`@("!P87-S
M("`@("`@("T@0F%S:6,@075T:"!P87-S=V]R9`H@("`@*B`@("`@("`@("`@
M("`@("`@('!R;WAY7VAO<W0@+2!0<F]X>2!S97)V97(@:&]S=`H@("`@*B`@
M("`@("`@("`@("`@("`@('!R;WAY7W!O<G0@+2!0<F]X>2!S97)V97(@<&]R
M=`H@("`@*B`@("`@("`@("`@("`@("`@('!R;WAY7W5S97(@+2!0<F]X>2!A
M=71H('5S97)N86UE"B`@("`J("`@("`@("`@("`@("`@("`@<')O>'E?<&%S
M<R`M(%!R;WAY(&%U=&@@<&%S<W=O<F0*("`@("H@0'!A<F%M('-T<FEN9R`D
M8V]N=&%I;F5R($YA;64@;V8@8V]N=&%I;F5R(&-L87-S"B`@("`J($!P87)A
M;2!A<G)A>2`D8V]N=&%I;F5R3W!T:6]N<R!!<G)A>2!W:71H(&-O;G1A:6YE
M<B!C;&%S<R!O<'1I;VYS"B`@("`J($!P87)A;2!I;G0@)&UO9&4@5VAA="!T
M;R!D;R!W:&5N('1H92!R96UO=&4@<V5R=F5R(&ES(&1O=VX@.@H@("`@*B`@
M("`@("`@("`@("`@("`@("!#04-(15](5%107U)%455%4U1?2T5%4%],3T-!
M3%]#3U!9(&]R"B`@("`J("`@("`@("`@("`@("`@("`@($-!0TA%7TA45%!?
M4D5154535%]215154DY?1D%,4T4@;W(*("`@("H@("`@("`@("`@("`@("`@
M("`@0T%#2$5?2%144%]215%515-47U)%5%523E]014%27T524D]2"B`@("`J
M($!P87)A;2!I;G0@)&5X<&ER97,@;&EF971I;64@;V8@=&AE(&-A8VAE9"!D
M871A(&EN('-E8V]N9',@+2`P(&9O<B!E;F1L97-S"B`@("`J($!S964@0V%C
M:&4L($A45%!?4F5Q=65S=`H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*
M("`@(&9U;F-T:6]N($-A8VAE7TA45%!?4F5Q=65S="@D=7)L+"`D<&%R86US
M(#T@3E5,3"P@)&-O;G1A:6YE<B`@/2`G9FEL92<L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-O;G1A:6YE<D]P=&EO;G,@/2!.54Q,+"`D
M97AP:7)E<R`](#,V,#`L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)&UO9&4@/2!#04-(15](5%107U)%455%4U1?2T5%4%],3T-!3%]#3U!9
M*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H)'!A<F%M<RDI("1P87)A;7,@
M/2!A<G)A>2@I.PH@("`@("`@(&EF("@A:7-S970H)&-O;G1A:6YE<D]P=&EO
M;G,I*2!["B`@("`@("`@("`@("1C;VYT86EN97)/<'1I;VYS(#T@87)R87D@
M*`H@("`@("`@("`@("`@("`@)V-A8VAE7V1I<B<@/3X@)R]T;7`O)RP*("`@
M("`@("`@("`@("`@("=F:6QE;F%M95]P<F5F:7@G(#T^("=C86-H95\G"B`@
M("`@("`@("`@("D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3Y#86-H92@D
M8V]N=&%I;F5R+"`D8V]N=&%I;F5R3W!T:6]N<RD["B`@("`@("`@)'1H:7,M
M/E]R97%U97-T(#T@)FYE=R!(5%107U)E<75E<W0H)'5R;"P@)'!A<F%M<RD[
M"B`@("`@("`@)'1H:7,M/E]I9"`](&UD-2@D=7)L+G-E<FEA;&EZ92@D<&%R
M86US*2D["B`@("`@("`@)'1H:7,M/E]I9#(@/2!M9#4H)'1H:7,M/E]I9"D[
M("\O('=E(&YE960@='=O(&ME>7,*("`@("`@("`D=&AI<RT^7VUO9&4@/2`D
M;6]D93L*("`@("`@("`D=&AI<RT^7V5X<&ER97,@/2`D97AP:7)E<SL*("`@
M('T*"B`@("`O*BH*("`@("H@1&5C;VYS=')U8W1O<@H@("`@*@H@("`@*B!`
M86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(%]#86-H95](5%10
M7U)E<75E<W0H*0H@("`@>PH@("`@("`@("1T:&ES+3Y?0V%C:&4H*3L*("`@
M('T*"B`@("`O*BH*("`@("H@1V5T(&%N9"!R971U<FX@=&AE(')E<W!O;G-E
M(&)O9'D@*$Y53$P@:68@;F\@9&%T82!A=F%I;&%B;&4I"B`@("`J"B`@("`J
M($!S964@<V5N9%)E<75E<W0H*0H@("`@*B!`<F5T=7)N(&UI>&5D(')E<W!O
M;G-E(&)O9'D*("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC
M=&EO;B!G971297-P;VYS94)O9'DH*0H@("`@>PH@("`@("`@(')E='5R;B`D
M=&AI<RT^7V1A=&%;)V)O9'DG73L*("`@('T*"B`@("`O*BH*("`@("H@1V5T
M(&%N9"!R971U<FX@=&AE(')E<W!O;G-E(&-O9&4@*$Y53$P@:68@;F\@9&%T
M82!A=F%I;&%B;&4I"B`@("`J"B`@("`J($!S964@<V5N9%)E<75E<W0H*0H@
M("`@*B!`<F5T=7)N(&UI>&5D(')E<W!O;G-E(&-O9&4*("`@("H@0&%C8V5S
M<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!G971297-P;VYS94-O9&4H
M*0H@("`@>PH@("`@("`@(')E='5R;B`D=&AI<RT^7V1A=&%;)V-O9&4G73L*
M("`@('T*"B`@("`O*BH*("`@("H@1V5T(&%N9"!R971U<FX@=&AE(')E<W!O
M;G-E(&AE861E<B`H3E5,3"!I9B!N;R!D871A(&%V86EL86)L92D*("`@("H*
M("`@("H@0'-E92!S96YD4F5Q=65S="@I"B`@("`J($!R971U<FX@;6EX960@
M<F5S<&]N<V4@:&5A9&5R"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@
M("`@9G5N8W1I;VX@9V5T4F5S<&]N<V5(96%D97(H*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V1A=&%;)VAE861E<B==.PH@("`@?0H*"B`@("`O
M*BH*("`@("H@4V5T(&$@;F5W(&UO9&4@=VAE;B!T:&4@<V5R=F5R(&ES(&1O
M=VX*("`@("H*("`@("H@0'!A<F%M(&EN="`D;F5W36]D92!7:&%T('1O(&1O
M('=H96X@=&AE(')E;6]T92!S97)V97(@:7,@9&]W;B`Z"B`@("`J("`@("`@
M("`@("`@("`@("`@("`@($-!0TA%7TA45%!?4D5154535%]+14507TQ/0T%,
M7T-/4%D@;W(*("`@("H@("`@("`@("`@("`@("`@("`@("`@0T%#2$5?2%14
M4%]215%515-47U)%5%523E]&04Q312!O<@H@("`@*B`@("`@("`@("`@("`@
M("`@("`@("!#04-(15](5%107U)%455%4U1?4D5455).7U!%05)?15)23U(*
M("`@("H@0&%C8V5S<R!P=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!S971-
M;V1E*"1N97=-;V1E*0H@("`@>PH@("`@("`@("1T:&ES+3Y?;6]D92`]("1N
M97=-;V1E.PH@("`@?0H*("`@("\J*@H@("`@*B!396YD('1H92!(5%10(')E
M<75E<W0@;W(@=7-E('1H92!C86-H92!S>7-T96T*("`@("H*("`@("H@268@
M=&AE<F4@:7,@82!C86-H92!F:6QE(&9O<B!T:&ES($A45%`@<F5Q=65S="P@
M=&AE(')E<75E<W0@:7,@;F]T(')E+7-E;G0N"B`@("`J($-A8VAE9"!R97-P
M;VYS92!I<R!U<V5D+B!9970L(&EF('1H92!C86-H92!I<R!E>'!I<F5D+"!T
M:&4@2%144"!R97%U97-T"B`@("`J(&ES(')E+7-E;G0N(%1H96XL(&EF('1H
M92!R96UO=&4@<V5R=F5R(&ES(&1O=VXL('1H:7,@;65T:&]D('=I;&P@<F5T
M=7)N(#H*("`@("H@*&1E<&5N9&EN9R!O;B!T:&4@<V5L96-T960@;6]D92D*
M("`@("H@+2!F86QS92!O<@H@("`@*B`M(&$@4$5!4E]%<G)O<B!O<B`H8F5T
M=&5R*0H@("`@*B`M('1R=64@86YD('1H92!L;V-A;"!C;W!Y(&]F('1H92!L
M871E<W0@=F%L:60@<F5S<&]N<V4@=VEL;"!B92!U<V5D+@H@("`@*@H@("`@
M*B`H=&5C:&YI8V%L*0H@("`@*B!&;W(@=&AE(&QA<W0@8VAO:6-E+"!T:&5R
M92!I<R!A('1E8VAN:6-A;"!T:7!S+@H@("`@*B!);F1E960L('1H97)E(&%R
M92!T=V\@8V%C:&4@9FEL97,N(%1H92!F:7)S="!O;F4@*&ED(&ME>2D@:7,@
M82!C;&%S<VEC86P@;VYE"B`@("`J('=I=&@@=&AE(&=I=F5N(&QI9F5T:6UE
M+B!"=70@:70@8V%N(&)E(')E;6]V960@8GD@875T;VUA=&EC(&=A<F)A9V4@
M8V]L;&5C=&EO;@H@("`@*B!F;W(@97AA;7!L92X@4V\@=&\@8F4@86)L92!T
M;R!U<V4@=&AE(&QA=&5S="!V86QI9"!R97-P;VYS92`H=VAE;B!T:&4@<F5M
M;W1E"B`@("`J('-E<G9E<B!I<R!D96%D*2P@=V4@;6%K92!A('-E8V]N9"!C
M86-H92!F:6QE('=I=&@@;F\@;&EF971I;64@*&ED,B!K97DI+@H@("`@*@H@
M("`@*B!`<F5T=7)N(&UI>&5D('1R=64@;W(@9F%L<V4@;W(@82!014%27T52
M4D]2"B`@("`J($!A8V-E<W,@<'5B;&EC"B`@("`J+PH@("`@9G5N8W1I;VX@
M<V5N9%)E<75E<W0H*0H@("`@>PH@("`@("`@(&EF("@D9&%T82`]("1T:&ES
M+3YG970H)'1H:7,M/E]I9"P@0T%#2$5?2%144%]215%515-47T=23U507TY!
M344I*2!["B`@("`@("`@("`@("\O("TM+2!#86-H92!H:70@+2TM"B`@("`@
M("`@("`@("1T:&ES+3Y?9&%T82`]("1D871A.PH@("`@("`@("`@("!R971U
M<FX@=')U93L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R`M+2T@
M0V%C:&4@;6ES<R`M+2T*("`@("`@("`@("`@:68@*"1T:&ES+3Y?<V5N9%)E
M<75E<W1!;F1'971297-P;VYS92@I*2!["B`@("`@("`@("`@("`@("`O+R!3
M;R!T:&4@<F5M;W1E('-E<G9E<B!I<R!O:RXN+@H@("`@("`@("`@("`@("`@
M)'1H:7,M/G-A=F4H)'1H:7,M/E]I9"P@)'1H:7,M/E]D871A+"`D=&AI<RT^
M7V5X<&ER97,L($-!0TA%7TA45%!?4D5154535%]'4D]54%].04U%*3L*("`@
M("`@("`@("`@("`@("1T:&ES+3YS879E*"1T:&ES+3Y?:60R+"`D=&AI<RT^
M7V1A=&$L(#`L($-!0TA%7TA45%!?4D5154535%]'4D]54%].04U%*3L*("`@
M("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@:68@*"1D871A7W-A=B`]("1T:&ES+3YG970H
M)'1H:7,M/E]I9#(L($-!0TA%7TA45%!?4D5154535%]'4D]54%].04U%*2D@
M>PH@("`@("`@("`@("`@("`@("`@("\O($]K+"!T:&4@(G)E8V]V97(@8V%C
M:&4B(&ES(&%V86EL86)L92XN+@H@("`@("`@("`@("`@("`@("`@('-W:71C
M:"`H)'1H:7,M/E]M;V1E*2!["B`@("`@("`@("`@("`@("`@("`@8V%S92!#
M04-(15](5%107U)%455%4U1?2T5%4%],3T-!3%]#3U!9.@H@("`@("`@("`@
M("`@("`@("`@("`@("`O+R!792!M86ME(&$@;F5W(&QO8V%L(&-O<'D@86YD
M(&ME97`@:70@=6YT:6P@:70@97AP:7)E<RXN+@H@("`@("`@("`@("`@("`@
M("`@("`@("`D=&AI<RT^<V%V92@D=&AI<RT^7VED+"`D9&%T85]S878L("1T
M:&ES+3Y?97AP:7)E<RP@0T%#2$5?2%144%]215%515-47T=23U507TY!344I
M.PH@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^7V1A=&$@/2`D9&%T
M85]S878["B`@("`@("`@("`@("`@("`@("`@("`@(')E='5R;B!T<G5E.PH@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("!C87-E($-!0TA%7TA45%!?4D5154535%]215154DY?1D%,4T4Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("\O(%=E(')E='5R;B!F86QS90H@("`@
M("`@("`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@(&-A<V4@
M0T%#2$5?2%144%]215%515-47U)%5%523E]014%27T524D]2.@H@("`@("`@
M("`@("`@("`@("`@("`@("`O+R!792!R971U<FX@82!014%27T5R<F]R(0H@
M("`@("`@("`@("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=296UO=&4@9FEL92!I<R!N;W0@879A:6QA8FQE(2<I.PH@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("\O
M($ET)W,@=&5R<FEB;&4A(%1H92!R96UO=&4@<V5R=F5R(&ES(&1O=VX@86YD
M(&1E9FEN:71I=F5L>2!N;R!C86-H92!A=F%I;&%B;&4A"B`@("`@("`@("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G4F5M;W1E('-E<G9E
M<B!D;W=N(&%N9"!N;R!C86-H92!A=F%I;&%B;&4A)RD["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"@H@("`@+R\@
M+2TM(%!R:79A=&4@365T:&]D<R`M+2T*"B`@("`O*BH*("`@("H@4V5N9"!(
M5%10(')E<75E<W0@86YD(&=E="!T:&4@<F5S<&]N<V4*("`@("H*("`@("H@
M0')E='5R;B!B;V]L96%N('-U8V-E<W,@;W(@;F]T(#\*("`@("H@0'-E92!(
M5%107U)E<75E<W0*("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@
M9G5N8W1I;VX@7W-E;F1297%U97-T06YD1V5T4F5S<&]N<V4H*0H@("`@>PH@
M("`@("`@("1T:&ES+3Y?<F5Q=65S="T^<V5N9%)E<75E<W0H*3L*("`@("`@
M("`D8F]D>2`]("1T:&ES+3Y?<F5Q=65S="T^9V5T4F5S<&]N<V5";V1Y*"D[
M"B`@("`@("`@)&-O9&4@/2`D=&AI<RT^7W)E<75E<W0M/F=E=%)E<W!O;G-E
M0V]D92@I.PH@("`@("`@("1H96%D97(@/2`D=&AI<RT^7W)E<75E<W0M/F=E
M=%)E<W!O;G-E2&5A9&5R*"D["B`@("`@("`@)'1H:7,M/E]D871A(#T@87)R
M87DH"B`@("`@("`@("`@("=B;V1Y)R`]/B`D8F]D>2P*("`@("`@("`@("`@
M)V-O9&4G(#T^("1C;V1E+`H@("`@("`@("`@("`G:&5A9&5R)R`]/B`D:&5A
M9&5R"B`@("`@("`@*3L*("`@("`@("!R971U<FX@*"@D8V]D93T]0T%#2$5?
M2%144%]215%515-47U-50T-%4U-?4D534$].4T5?0T]$12D@/R!T<G5E(#H@
M9F%L<V4I.PH@("`@?0H*?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]/=71P=70N<&AP
M````````````````````````````````````````````````````````````
M`````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$V,34S
M(#$P-3$U-#,T,3,R(#`R,34P,@`@,```````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@
M,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O
M('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP
M(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H870@:7,@8G5N
M9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A
M;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D
M:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@
M87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@
M=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@
M("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A
M(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5;&8@5V5N9&5L
M(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O('P@("`@("`@("`@0VAR:7-T:6%N(%-T;V-K97(@/&-H<F5G
M=4!P:&%N="YC:#X@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\("`@
M("`@("`@(%9I;F%I($MO<'`@/&MO<'!`;F5T>F%R8F5I=&5R+F1E/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O"B\O("1)9#H@3W5T<'5T+G!H<"QV(#$N-B`R,#`S+S`Q
M+S`T(#$Q.C4T.C0U(&UJ($5X<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+G!H
M<"<["@HO*BH**B!#;&%S<R!T;R!C86-H92!T:&4@;W5T<'5T(&]F(&$@<V-R
M:7!T('5S:6YG('1H92!O=71P=70@8G5F9F5R:6YG(&9U;F-T:6]N<PHJ"BH@
M4VEM<&QE(&]U='!U="!C86-H92X@4V]M92!P86=E<R!R97%U:7)E(&QO=',@
M;V8@=&EM92!T;R!C;VUP=71E+B!#86-H:6YG('1H90HJ(&]U='!U="!C86X@
M:6YC<F5A<V4@=&AE(&]V97)A;&P@<W!E960@9')A;6%T:6-A;&QY+"!E<W!E
M8VEA;&QY(&EF('EO=2!U<V4**B!A(%-H87)E9"!-96UO<GD@<W1O<F%G92!C
M;VYT86EN97(N"BH**B!!<R!Y;W4@8V%N('-E92!I;B!T:&4@97AA;7!L92!T
M:&4@=7-A9V4@:7,@97AT96UE;'D@<VEM<&QE+B!4;R!C86-H92!A('-C<FEP
M=`HJ('-I;7!L92!P=70@<V]M92!F97<@;&EN97,@;V8@8V]D92!I;B!F<F]N
M="!O9B!Y;W5R('-C<FEP="!A;F0@<V]M92!A="!T:&4@96YD+@HJ($$@<')E
M9F5R<F%B;&4@<&QA8V4@9F]R('1H:7,@87)E('1H92!A=71O7W!R97!E;F0@
M86YD(&%U=&]?87!P96YD(&9I;&5S("@]/B!P:'`N:6YI*2X**@HJ(%5S86=E
M(&5X86UP;&4Z"BH**B`@+R\@<&QA8V4@=&AI<R!S;VUE=VAE<F4@:6X@82!C
M96YT<F%L(&-O;F9I9R!F:6QE"BH@(&1E9FEN92A#04-(15]35$]204=%7T-,
M05-3+"`G9FEL92<I.PHJ("`O+R!F:6QE('-T;W)A9V4@;F5E9',@82!D:7(@
M=&\@<'5T('1H92!C86-H92!F:6QE<PHJ("!D969I;F4H0T%#2$5?1$E2+"`G
M+W9A<B]T;7`O)RD["BH**B`@+R\@9V5T(&$@8V%C:&4@;V)J96-T"BH@("1C
M86-H92`](&YE=R!#86-H95]/=71P=70H0T%#2$5?4U1/4D%'15]#3$%34RP@
M87)R87DH)V-A8VAE7V1I<B<@/3X@0T%#2$5?1$E2*2D["BH**B`@+R\@8V]M
M<'5T92!T:&4@=6YI<75E(&AA;F1L92X**B`@+R\@:68@>6]U<B!S8W)I<'0@
M9&5P96YD<R!O;B!#;V]K:64@86YD($A45%`@4&]S="!D871A(&%S('=E;&P*
M*B`@+R\@>6]U('-H;W5L9"!U<V4Z"BH@("\O("1C86-H95]H86YD;&4@/2!A
M<G)A>2@**B`@+R\@("`@("`@("`@("`@("`@("`@("`@("=F:6QE)R`]/B`D
M4D5154535%]54DDL"BH@("\O("`@("`@("`@("`@("`@("`@("`@("`G<&]S
M="<@/3X@)$A45%!?4$]35%]605)3+`HJ("`O+R`@("`@("`@("`@("`@("`@
M("`@("`@)V-O;VMI92<@(#T^("1(5%107T-/3TM)15]605)3"BH@("\O("`@
M("`@("`@("`@("`@("`@("`I.PHJ("`O+R!"=70@8F4@=V%R;F5D+"!U<VEN
M9R!A;&P@1T54(&]R(%!/4U0@5F%R:6%B;&5S(&%S(&$@<V5E9`HJ("`O+R!C
M86X@8F4@=7-E9"!F;W(@82!$3U,@871T86-K+B!#86QL:6YG(&AT='`Z+R]W
M=W<N97AA;7!L92YC;VTO97AA;7!L92YP:'`_=VAA=&5V97(**B`@+R\@=VAE
M<F4@=VAA=&5V97(@:7,@82!R86YD;VT@=&5X="!M:6=H="!B92!U<V5D('1O
M(&9L;V]D('EO=7(@8V%C:&4N"BH@("1C86-H95]H86YD;&4@/2`D8V%C:&4M
M/F=E;F5R871E240H)%)%455%4U1?55))*3L**@HJ("`O+R!N;W<@=&AE(&UA
M9VEC(&AA<'!E;G,Z(&EF(&-A8VAE9"!C86QL(&1I92@I"BH@("\O('1O(&5N
M9"!T:&4@=&EM92!C;VYS=6UP=&EO;F<@<V-R:7!T('-C<FEP="!E>&5C=71I
M;VX@86YD('5S92!T:&4@8V%C:&5D('9A;'5E(0HJ("!I9B`H)&-O;G1E;G0@
M/2`D8V%C:&4M/G-T87)T*"1C86-H95]H86YD;&4I*2!["BH@("`@('!R:6YT
M("1C;VYT96YT.PHJ("`@("!P<FEN="`G/'`^0V%C:&4@:&ET/"]P/B<["BH@
M("`@(&1I92@I.PHJ("!]"BH**B`@+R\@=&EM92!C;VYS=6UP=&EO;B!S8W)I
M<'0@9V]E<R!H97)E+@HJ"BH@("\O('-T;W)E('1H92!O=71P=70@;V8@=&AE
M(&-A8VAE(&EN=&\@=&AE(&-A8VAE(&%N9"!P<FEN="!T:&4@;W5T<'5T+@HJ
M("!P<FEN="`D8V%C:&4M/F5N9"@I.PHJ("!P<FEN="`B/'`^0V%C:&4@;6ES
M<RP@<W1O<F5D('5S:6YG('1H92!)1"`G)&ED)RX\+W`^(CL**@HJ("!)9B!Y
M;W4@9&\@;F]T('=A;G0@=&\@8V%C:&4@82!W:&]L92!P86=E("T@;F\@<')O
M8FQE;3H**@HJ("!I9B`H(2@D8V]N=&5N="`]("1C86-H92T^<W1A<G0H)&-A
M8VAE7VAA;F1L92DI*2!["BH@("`@("\O(&1O('1H92!C;VUP=71A=&EO;B!H
M97)E"BH@("`@('!R:6YT("1C86-H92T^96YD*"D**B`@?2!E;'-E('L**B`@
M("`@<')I;G0@)&-O;G1E;G0["BH@('T**@HJ("!)9B!Y;W4@;F5E9"!A;B!E
M>&%M<&QE('-C<FEP="!C:&5C:R!T:&4@*&%U=&]?*7!R97!E;F0@86YD("AA
M=71O7REA<'!E;F0**B`@9FEL97,@;V8@;7D@:&]M97!A9V4Z"BH**B`@("!H
M='1P.B\O=W=W+G5L9BUW96YD96PN9&4O<&AP+W-H;W=?<V]U<F-E+G!H<#]F
M:6QE/7!R97!E;F0**B`@("!H='1P.B\O=W=W+G5L9BUW96YD96PN9&4O<&AP
M+W-H;W=?<V]U<F-E+G!H<#]F:6QE/6%P<&5N9`HJ"BH@($1O;B=T(&MN;W<@
M:&]W('1O('5S92!I="!O<B!Y;W4@;F5E9"!P<F]F:6QI;F<@:6YF;W)M871I
M;VYS/V`**B`@07-K($-H<FES=&EA;B!H92!W87,@<&%T:65N="!W:71H(&UE
M(&%N9"!H92=L;"!B92!S;R!W:71H('EO=7(@<75E<W1I;VYS(#LI+@HJ"BH@
M($AA=F4@9G5N(0HJ"BH@0&%U=&AO<G,@(%5L9B!796YD96P@/'5L9BYW96YD
M96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N("`D240Z("0**B!`<&%C:V%G92`@
M0V%C:&4**B!`86-C97-S("`@<'5B;&EC"BHO"F-L87-S($-A8VAE7T]U='!U
M="!E>'1E;F1S($-A8VAE('L*"B`@("`O*BH*("`@("H@240@<&%S<V5D('1O
M('-T87)T*"D*("`@("H*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J($!S964@
M('-T87)T*"DL(&5N9"@I"B`@("`J+PH@("`@=F%R("1O=71P=71?:60@/2`G
M)SL*"B`@("`O*BH*("`@("H@1W)O=7`@<&%S<V5D('1O('-T87)T*"D*("`@
M("H*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J($!S964@('-T87)T*"DL(&5N
M9"@I"B`@("`J+PH@("`@=F%R("1O=71P=71?9W)O=7`@/2`G)SL*"B`@("`O
M*BH*("`@("H@4$5!4BU$96-O;G-T<G5C=&]R"B`@("`J($-A;&P@9&5C;VYS
M=')U8W1O<B!O9B!P87)E;G0*("`@("HO"B`@("!F=6YC=&EO;B!?0V%C:&5?
M3W5T<'5T*"D*("`@('L*("`@("`@("`@("`@("`@("1T:&ES+3Y?0V%C:&4H
M*3L*("`@('T*"B`@("`O*BH*("`@("H@<W1A<G1S('1H92!O=71P=70@8G5F
M9F5R:6YG(&%N9"!R971U<FYS(&%N(&5M<'1Y('-T<FEN9R!O<B!R971U<FYS
M('1H92!C86-H960@;W5T<'5T(&9R;VT@=&AE(&-A8VAE+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!S=')I;F<*
M("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N('-T
M87)T*"1I9"P@)&=R;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@*"$D
M=&AI<RT^8V%C:&EN9RD*("`@("`@("`@("`@<F5T=7)N("<G.PH*("`@("`@
M("`O+R!T:&ES(&ES(&%L<F5A9'D@8V%C:&5D(')E='5R;B!I="!F<F]M('1H
M92!C86-H92!S;R!T:&%T('1H92!U<V5R"B`@("`@("`@+R\@8V%N('5S92!T
M:&4@8V%C:&4@8V]N=&5N="!A;F0@<W1O<"!S8W)I<'0@97AE8W5T:6]N"B`@
M("`@("`@:68@*"1C;VYT96YT(#T@)'1H:7,M/F=E="@D:60L("1G<F]U<"DI
M"B`@("`@("`@("`@(')E='5R;B`D8V]N=&5N=#L*"B`@("`@("`@+R\@<F5M
M96UB97(@<V]M92!D871A('1O(&)E(&%B;&4@=&\@9FEL;"!T:&4@8V%C:&4@
M;VX@8V%L;&EN9R!E;F0H*0H@("`@("`@("1T:&ES+3YO=71P=71?:60@/2`D
M:60["B`@("`@("`@)'1H:7,M/F]U='!U=%]G<F]U<"`]("1G<F]U<#L*"B`@
M("`@("`@+R\@5T%23DE.1SH@=V4@;F5E9"!T:&4@;W5T<'5T(&)U9F9E<B`M
M('!O<W-I8FQE(&-L87-H97,*("`@("`@("!O8E]S=&%R="@I.PH@("`@("`@
M(&]B7VEM<&QI8VET7V9L=7-H*&9A;'-E*3L*"B`@("`@("`@<F5T=7)N("<G
M.PH@("`@?2`O+R!E;F0@9G5N8R!S=&%R=`H*("`@("\J"B`@("`J(%-T;W)E
M<R!T:&4@8V]N=&5N="!O9B!T:&4@;W5T<'5T(&)U9F9E<B!I;G1O('1H92!C
M86-H92!A;F0@<F5T=7)N<R!T:&4@8V]N=&5N="X*("`@("H*("`@("H@0'!A
M<F%M("`@(&UI>&5D("`@;&EF971I;64@;V8@=&AE(&-A8VAE9"!D871A(&EN
M('-E8V]N9',@+2`P(&9O<B!E;F1L97-S+B!-;W)E(&9O<FUA=',@879A:6QA
M8FQE+B!S964@0V]N=&%I;F5R.CIG971%>'!I<F5S06)S;VQU=&4H*0H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!A9&1I=&EO;F%L('5S97)D969I;F5D(&1A
M=&$*("`@("H@0')E='5R;B`@('-T<FEN9R`@8V%C:&5D(&]U='!U=`H@("`@
M*B!`86-C97-S("`@<'5B;&EC"B`@("`J($!S964@("`@("!E;F10<FEN="@I
M+"!E;F1'970H*2P@0V]N=&%I;F5R.CIG971%>'!I<F5S06)S;VQU=&4H*0H@
M("`@*B\*("`@(&9U;F-T:6]N(&5N9"@D97AP:7)E(#T@,"P@)'5S97)D871A
M(#T@)R<I('L*("`@("`@("`D8V]N=&5N="`](&]B7V=E=%]C;VYT96YT<R@I
M.PH@("`@("`@(&]B7V5N9%]C;&5A;B@I.PH*("`@("`@("`O+R!S=&]R92!I
M;B!T:&4@8V%C:&4*("`@("`@("!I9B`H)'1H:7,M/F-A8VAI;F<I"B`@("`@
M("`@("`@("1T:&ES+3YC;VYT86EN97(M/G-A=F4H)'1H:7,M/F]U='!U=%]I
M9"P@)&-O;G1E;G0L("1E>'!I<F4L("1T:&ES+3YO=71P=71?9W)O=7`L("1U
M<V5R9&%T82D["@H@("`@("`@(')E='5R;B`D8V]N=&5N=#L*("`@('T@+R\@
M96YD(&9U;F,@96YD*"D*"B`@("`O*BH*("`@("H@4W1O<F5S('1H92!C;VYT
M96YT(&]F('1H92!O=71P=70@8G5F9F5R(&EN=&\@=&AE(&-A8VAE(&%N9"!P
M<FEN=',@=&AE(&-O;G1E;G0N"B`@("`J"B`@("`J($!B<F]T:&5R("!E;F0H
M*0H@("`@*B\*("`@(&9U;F-T:6]N(&5N9%!R:6YT*"1E>'!I<F4@/2`P+"`D
M=7-E<F1A=&$@/2`G)RD@>PH@("`@("`@("1T:&ES+3YP<FEN=$-O;G1E;G0H
M)'1H:7,M/F5N9"@D97AP:7)E+"`D=7-E<F1A=&$I*3L*("`@('T@+R\@96YD
M(&9U;F,@96YD4')I;G0*"B`@("`O*BH*("`@("H@4V5N9',@=&AE(&1A=&$@
M=&\@=&AE('5S97(N"B`@("`J(%1H:7,@:7,@9F]R(&-O;7!A=&EB:6QI='D@
M=VET:"!/=71P=71#;VUP<F5S<VEO;@H@("`@*B`*("`@("H@0'!A<F%M("`@
M('-T<FEN9PH@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+R`@("`*("`@
M(&9U;F-T:6]N('!R:6YT0V]N=&5N="@D8V]N=&5N="`]("<G*2!["B`@("`@
M("`@:68@*"<G(#T]("1C;VYT96YT*0H@("`@("`@("`@("`D8V]N=&5N="`]
M("8D=&AI<RT^8V]N=&%I;F5R+3YC86-H961A=&$["B`@("`@("`@("`@(`H@
M("`@("`@('!R:6YT("1C;VYT96YT.PH@("`@?0H@("`@+RHJ"B`@("`J(%)E
M='5R;G,@=&AE(&-O;G1E;G0@;V8@=&AE(&]U='!U="!B=69F97(@8G5T(&1O
M97,@;F]T('-T;W)E(&ET(&EN=&\@=&AE(&-A8VAE+@H@("`@*@H@("`@*B!5
M<V4@=&AI<R!M971H;V0@:68@=&AE(&-O;G1E;G0@;V8@>6]U<B!S8W)I<'0@
M:7,@;6%R:W5P("A834PI"B`@("`J('1H870@:&%S('1O(&)E('!A<G-E9"]C
M;VYV97)T960@*%A33%0I(&)E9F]R92!Y;W4@8V%N(&]U='!U=`H@("`@*B!A
M;F0@<W1O<F4@:70@:6YT;R!T:&4@8V%C:&4@=7-I;F<@<V%V92@I+@H@("`@
M*@H@("`@*B!`<F5T=7)N("`@<W1R:6YG"B`@("`J($!A8V-E<W,@("!P=6)L
M:6,*("`@("H@0'-E92`@("`@(&5N9%!R:6YT*"DL(&5N9"@I"B`@("`J+PH@
M("`@9G5N8W1I;VX@96YD1V5T*"D@>PH@("`@("`@("1C;VYT96YT(#T@;V)?
M9V5T7V-O;G1E;G1S*"D["B`@("`@("`@;V)?96YD7V-L96%N*"D["@H@("`@
M("`@("1T:&ES+3YO=71P=71?:60@/2`G)SL*("`@("`@("`D=&AI<RT^;W5T
M<'5T7V=R;W5P(#T@)R<["@H@("`@("`@(')E='5R;B`D8V]N=&5N=#L*("`@
M('T@+R\@96YD(&9U;F,@96YD1V5T"GT@+R\@96YD(&-L87-S(&]U='!U=`H_
M/@H`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T-A8VAE+T]U='!U=$-O
M;7!R97-S:6]N+G!H<```````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C$U
M,S0@,3`U,34T,S0Q,S(@,#(S-S(S`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*PHO+R!\(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC
M*2`Q.3DW+3(P,#,@5&AE(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!4:&ES('-O=7)C92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R
M+C`@;V8@=&AE(%!(4"!L:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B
M=6YD;&5D('=I=&@@=&AI<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L
M(&%N9"!I<R`@("`@("`@?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!H='1P.B\O=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U
M(&1I9"!N;W0@<F5C96EV92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N
M9"!A<F4@=6YA8FQE('1O("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H
M92!W;W)L9"UW:61E+7=E8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@
M("`@('P*+R\@?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U
M(&$@8V]P>2!I;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD
M96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P*+R\@?"`@("`@("`@("!#:')I<W1I86X@4W1O8VME<B`\8VAR
M96=U0'!H86YT+F-H/B`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PH*<F5Q=6ER95]O;F-E("=#86-H
M92]/=71P=70N<&AP)SL*"B\J*@HJ($-A8VAE('5S:6YG($]U='!U="!"=69F
M97)I;F<@86YD(&-O;G1N970@*&=Z*2!C;VUP<F5S<VEO;BX**BH@57-A9V4@
M97AA;7!L93H**@HJ("`O+R!P;&%C92!T:&ES('-O;65W:&5R92!I;B!A(&-E
M;G1R86P@8V]N9FEG(&9I;&4**B`@9&5F:6YE*$-!0TA%7U-43U)!1T5?0TQ!
M4U,L("=F:6QE)RD["BH@("\O(&9I;&4@<W1O<F%G92!N965D<R!A(&1I<B!T
M;R!P=70@=&AE(&-A8VAE(&9I;&5S"BH@(&1E9FEN92A#04-(15]$25(L("<O
M=F%R+W1M<"\G*3L**@HJ("`O+R!G970@82!C86-H92!O8FIE8W0**B`@)&-A
M8VAE(#T@;F5W($-A8VAE7T]U='!U="A#04-(15]35$]204=%7T-,05-3+"!A
M<G)A>2@G8V%C:&5?9&ER)R`]/B!#04-(15]$25(I*3L**@HJ("!I9B`H(2@D
M8V]N=&5N="`]("1C86-H92T^<W1A<G0H)&-A8VAE+3YG96YE<F%T94E$*"12
M15%515-47U5222DI*2D@>PHJ("`@('!R:6YT(")H96QL;R!W;W)L9"(["BH@
M("`@)&-A8VAE+3YE;F10<FEN="@K,3`P,"D["BH@('T**B`@96QS92!["BH@
M("`@)&-A8VAE+3YP<FEN=$-O;G1E;G0H*3L**B`@?0HJ"BH@("!/4@HJ"BH@
M(&EF("@H)&-O;G1E;G0@/2`D8V%C:&4M/G-T87)T*"1C86-H92T^9V5N97)A
M=&5)1"@D4D5154535%]54DDI*2DI('L**B`@("`D8V%C:&4M/G!R:6YT0V]N
M=&5N="@I.PHJ("`@(&1I92@I.PHJ("!]"BH@("`@<')I;G0@(FAE;&QO('=O
M<FQD(CL**B`@("`D8V%C:&4M/F5N9%!R:6YT*"LQ,#`P*3L**@HJ"BH@0F%S
M960@=7!O;B!A(&-A<V4@<W1U9'D@9G)O;2!#:')I<W1I86X@4W1O8VME<B!A
M;F0@:6YS<&ER960@8GD@:G!C86-H92X**@HJ($!V97)S:6]N("`D260Z($]U
M='!U=$-O;7!R97-S:6]N+G!H<"QV(#$N-R`R,#`S+S`Q+S`T(#$Q.C4T.C0U
M(&UJ($5X<"`D"BH@0&%U=&AO<B`@(%5L9B!796YD96P@/'5L9BYW96YD96Q`
M<&AP9&]C+F1E/BP@0VAR:7-T:6%N(%-T;V-K97(@/&-H<F5G=4!P:&%N="YC
M:#X**B!`86-C97-S("`@<'5B;&EC"BH@0'!A8VMA9V4@($-A8VAE"BHO"F-L
M87-S($-A8VAE7T]U='!U=$-O;7!R97-S:6]N(&5X=&5N9',@0V%C:&5?3W5T
M<'5T('L*("`@(`H@("`@+RHJ"B`@("`J($5N8V]D:6YG+"!W:&%T('1H92!U
M<V5R("AI=',@8G)O=W-E<BD@;V8@>6]U<B!W96)S:71E(&%C8V5P=',*("`@
M("H@"B`@("`J(")A=71O(B!S=&%N9',@9F]R('1E<W0@=7-I;F<@)%]315)6
M15);)TA45%!?04-#15!47T5.0T]$24Y')UTH)$A45%!?04-#15!47T5.0T]$
M24Y'*2X*("`@("H*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J($!S964@($-A
M8VAE7T]U='!U=$-O;7!R97-S:6]N*"DL('-E=$5N8V]D:6YG*"D*("`@("HO
M"B`@("!V87(@)&5N8V]D:6YG(#T@)V%U=&\G.PH@"B`@("`*("`@("\J*@H@
M("`@*B!-971H;V0@=7-E9"!F;W(@8V]M<')E<W-I;VX*("`@("H*("`@("H@
M0'9A<B`@<W1R:6YG"B`@("`J($!S964@(&ES0V]M<')E<W-E9"@I"B`@("`J
M+R`*("`@('9A<B`D8V]M<')E<W-I;VX@/2`G)SL*"B`@("`*("`@("\J*@H@
M("`@*B!3971S('1H92!S=&]R86=E(&1E=&%I;',@86YD('1H92!C;VYT96YT
M(&5N8V]D:6YG('5S960@*&EF(&YO="!A=71O9&5T96-T:6]N*0H@("`@*B`*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@3F%M92!O9B!C;VYT86EN97(@8VQA
M<W,*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@07)R87D@=VET:"!C;VYT86EN
M97(@8VQA<W,@;W!T:6]N<PH@("`@*B!`<&%R86T@("`@<W1R:6YG("!C;VYT
M96YT(&5N8V]D:6YG(&UO9&4@+2!A=71O(#T^('1E<W0@=VAI8V@@96YC;V1I
M;F<@=&AE('5S97(@86-C97!T<PH@("`@*B\@("`@"B`@("!F=6YC=&EO;B!#
M86-H95]/=71P=71#;VUP<F5S<VEO;B@D8V]N=&%I;F5R+"`D8V]N=&%I;F5R
M7V]P=&EO;G,@/2`G)RP@)&5N8V]D:6YG(#T@)V%U=&\G*2!["B`@("`*("`@
M("`@("`D=&AI<RT^<V5T16YC;V1I;F<H)&5N8V]D:6YG*3L*("`@("`@("`D
M=&AI<RT^0V%C:&4H)&-O;G1A:6YE<BP@)&-O;G1A:6YE<E]O<'1I;VYS*3L*
M("`@("`@("`*("`@('T@+R\@96YD(&-O;G-T<G5C=&]R"@H@("`@"B`@("`O
M*BH*("`@("H@0V%L;"!P87)E;G0@9&5C;VYS=')U8W1O<BX*("`@("HO"B`@
M("!F=6YC=&EO;B!?0V%C:&5?3W5T<'5T0V]M<')E<W-I;VXH*2!["B`@("`@
M("`@)'1H:7,M/E]#86-H92@I.PH@("`@?2`O+R!E;F0@9&5C;VYS=')U8W1O
M<@H@("`@"@H@("`@9G5N8W1I;VX@9V5N97)A=&5)1"@D=F%R:6%B;&4I('L*
M("`@("`@("`*("`@("`@("`D=&AI<RT^8V]M<')E<W-I;VX@/2`D=&AI<RT^
M9V5T16YC;V1I;F<H*3L*("`@("`@("`*("`@("`@("!R971U<FX@;60U*'-E
M<FEA;&EZ92@D=F%R:6%B;&4I("X@<V5R:6%L:7IE*"1T:&ES+3YC;VUP<F5S
M<VEO;BDI.PH@("`@?2`O+R!E;F0@9V5N97)A=&5)1`H*("`@(`H@("`@9G5N
M8W1I;VX@9V5T*"1I9"P@)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F-O;G1E
M;G0@/2`G)SL*("`@("`@("`*("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG
M*0H@("`@("`@("`@("!R971U<FX@)R<["B`@("`@("`@"B`@("`@("`@:68@
M*"1T:&ES+3YI<T-A8VAE9"@D:60L("1G<F]U<"D@)B8@(21T:&ES+3YI<T5X
M<&ER960H)&ED+"`D9W)O=7`I*0H@("`@("`@("`@("`D=&AI<RT^8V]N=&5N
M="`]("1T:&ES+3YL;V%D*"1I9"P@)&=R;W5P*3L*("`@("`@("`@("`@"B`@
M("`@("`@<F5T=7)N("1T:&ES+3YC;VYT96YT.PH@("`@?2`O+R!E;F0@9G5N
M8R!G970*("`@(`H@("`@"B`@("`O*BH*("`@("H@4W1O<',@=&AE(&]U='!U
M="!B=69F97)I;F<L('-A=F5S(&ET('1O('1H92!C86-H92!A;F0@<F5T=7)N
M<R!T:&4@7V-O;7!R97-S961?(&-O;G1E;G0N(`H@("`@*@H@("`@*B!)9B!Y
M;W4@;F5E9"!T:&4@=6YC;VUP<F5S<V5D(&-O;G1E;G0@9F]R(&9U<G1H97(@
M<')O8V5S<VEO;B!B969O<F4*("`@("H@:70G<R!S879E9"!I;B!T:&4@8V%C
M:&4@=7-E(&5N9$=E="@I+B!E;F1'970H*2!D;V5S(%]N;W0@8V]M<')E<W-?
M+@H@("`@*B\@("`@"B`@("!F=6YC=&EO;B!E;F0H)&5X<&ER92`](#`L("1U
M<V5R9&%T82`]("<G*2!["B`@("`@("`@)&-O;G1E;G0@/2!O8E]G971?8V]N
M=&5N=',H*3L*("`@("`@("!O8E]E;F1?8VQE86XH*3L*"B`@("`@("`@+R\@
M<W1O<F4@:6X@=&AE(&-A8VAE"B`@("`@("`@:68@*"1T:&ES+3YC86-H:6YG
M*2!["B`@("`@("`@("`@("1T:&ES+3YE>'13879E*"1T:&ES+3YO=71P=71?
M:60L("1C;VYT96YT+"`D=7-E<F1A=&$L("1E>'!I<F4L("1T:&ES+3YO=71P
M=71?9W)O=7`I.PH@("`@("`@("`@("!R971U<FX@)'1H:7,M/F-O;G1E;G0[
M("`@("`@("`@("`@("`@(`H@("`@("`@('T*("`@("`@("`@("`@"B`@("`@
M("`@<F5T=7)N("1C;VYT96YT.R`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC
M(&5N9"@I"B`@("`*("`@(`H@("`@9G5N8W1I;VX@96YD4')I;G0H)&5X<&ER
M92`](#`L("1U<V5R9&%T82`]("<G*2!["B`@("`@("`@)'1H:7,M/G!R:6YT
M0V]N=&5N="@D=&AI<RT^96YD*"1E>'!I<F4L("1U<V5R9&%T82DI.PH@("`@
M?2`O+R!E;F0@9G5N8R!E;F10<FEN=`H*("`@(`H@("`@+RHJ"B`@("`J(%-A
M=F5S('1H92!G:79E;B!D871A('1O('1H92!C86-H92X*("`@("H@"B`@("`J
M+R`@(`H@("`@9G5N8W1I;VX@97AT4V%V92@D:60L("1C86-H961A=&$L("1U
M<V5R9&%T82P@)&5X<&ER97,@/2`P+"`D9W)O=7`@/2`G9&5F875L="<I('L*
M("`@("`@("!I9B`H(21T:&ES+3YC86-H:6YG*0H@("`@("`@("`@("!R971U
M<FX@=')U93L*"B`@("`@("`@:68@*"1T:&ES+3YC;VUP<F5S<VEO;BD@>R`@
M("`@("`@("`@(`H@("`@("`@("`@("`*("`@("`@("`@("`@)&QE;B`]('-T
M<FQE;B@D8V%C:&5D871A*3L@("`@("`@("`@("`*("`@("`@("`@("`@)&-R
M8R`](&-R8S,R*"1C86-H961A=&$I.PH@("`@("`@("`@("`D8V%C:&5D871A
M(#T@9WIC;VUP<F5S<R@D8V%C:&5D871A+"`Y*3L*("`@("`@("`@("`@)'1H
M:7,M/F-O;G1E;G0@/2!S=6)S='(H)&-A8VAE9&%T82P@,"P@<W1R;&5N*"1C
M86-H961A=&$I("T@-"D@+B!P86-K*"=6)RP@)&-R8RD@+B!P86-K*"=6)RP@
M)&QE;BD["B`@("`@("`@("`@(`H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@(`H@("`@("`@("`@("`D=&AI<RT^8V]N=&5N="`]("1C86-H961A=&$[
M"B`@("`@("`@("`@(`H@("`@("`@('T*("`@("`@("!R971U<FX@)'1H:7,M
M/F-O;G1A:6YE<BT^<V%V92@D:60L("1T:&ES+3YC;VYT96YT+"`D97AP:7)E
M<RP@)&=R;W5P+"`D=7-E<F1A=&$I.PH@("`@?2`O+R!E;F0@9G5N8R!E>'13
M879E"B`@("`*("`@("\J*@H@("`@*B!396YD<R!T:&4@8V]M<')E<W-E9"!D
M871A('1O('1H92!U<V5R+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN
M9PH@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J+R`@("`*("`@(&9U;F-T
M:6]N('!R:6YT0V]N=&5N="@D8V]N=&5N="`]("<G*2!["B`@("`@("`@)'-E
M<G9E<B`]("8D=&AI<RT^7VEM<&]R=$=L;V)A;%9A<FEA8FQE*")S97)V97(B
M*3L*"B`@("`@("`@:68@*"<G(#T]("1C;VYT96YT*0H@("`@("`@("`@("`D
M8V]N=&5N="`]("8D=&AI<RT^8V]N=&%I;F5R+3YC86-H961A=&$["B`@("`@
M("`@("`@("`@("`@"B`@("`@("`@:68@*"1T:&ES+3YC;VUP<F5S<VEO;B`F
M)B`D=&AI<RT^8V%C:&EN9RD@>PH@("`*("`@("`@("`@("`@)&5T86<@/2`G
M4$5!4BU#86-H92TG("X@;60U*'-U8G-T<B@D8V]N=&5N="P@+30P*2D["B`@
M("`@("`@("`@(&AE861E<B@B151A9SH@)&5T86<B*3L*("`@("`@("`@("`@
M:68@*&ES<V5T*"1S97)V97);)TA45%!?249?3D].15]-051#2"==*2`F)B!S
M=')S='(H<W1R:7!S;&%S:&5S*"1S97)V97);)TA45%!?249?3D].15]-051#
M2"==*2P@)&5T86<I*2!["B`@("`@("`@("`@("`@("`O+R!N;W0@;6]D:69I
M960*("`@("`@("`@("`@("`@(&AE861E<B@G2%144"\Q+C`@,S`T)RD["B`@
M("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T@96QS92!["B`@
M(`H@("`@("`@("`@("`@("`@+R\@8VQI96YT(&%C8V5P<'1S('-O;64@96YC
M;V1I;F<@+2!S96YD(&AE861E<G,@)B!D871A"B`@("`@("`@("`@("`@("!H
M96%D97(H(D-O;G1E;G0M16YC;V1I;F<Z('LD=&AI<RT^8V]M<')E<W-I;VY]
M(BD["B`@("`@("`@("`@("`@("!H96%D97(H)U9A<GDZ($%C8V5P="U%;F-O
M9&EN9R<I.PH@("`@("`@("`@("`@("`@<')I;G0@(EQX,69<>#AB7'@P.%QX
M,#!<>#`P7'@P,%QX,#!<>#`P(CL*("`@("`@("`@("`@?0H@("`@("`@(`H@
M("`@("`@('T*("`@("`@("`*("`@("`@("!D:64H)&-O;G1E;G0I.PH@("`@
M?2`O+R!E;F0@9G5N8R!P<FEN=$-O;G1E;G0*("`@(`H@("`@"B`@("`O*BH*
M("`@("H@4F5T=7)N<R!T:&4@96YC;V1I;F<@;65T:&]D(&]F('1H92!C=7)R
M96YT(&1A=&%S970N(`H@("`@*@H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@
M("`J($!R971U<FX@("!S=')I;F<@($5M<'1Y('-T<FEN9R`H=VAI8V@@979A
M;'5A=&5S('1O(&9A;'-E*2!M96%N<R!N;R!C;VUP<F5S<VEO;@H@("`@*B\*
M("`@(&9U;F-T:6]N(&ES0V]M<')E<W-E9"@I('L*("`@("`@("!R971U<FX@
M)'1H:7,M/F-O;7!R97-S:6]N.PH@("`@?2`O+R!E;F0@9G5N8R!I<T-O;7!R
M97-S960*"B`@("`O*BH*("`@("H@4V5T<R!T:&4@96YC;V1I;F<@=&\@8F4@
M=7-E9"X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@(")A=71O(B!M
M96%N<R!A=71O9&5T96-T(&9O<B!E=F5R>2!C;&EE;G0*("`@("H@0&%C8V5S
M<R`@('!U8FQI8PH@("`@*B!`<V5E("`@("`@)&5N8V]D:6YG"B`@("`J+PH@
M("`@9G5N8W1I;VX@<V5T16YC;V1I;F<H)&5N8V]D:6YG(#T@)V%U=&\G*2![
M"B`@("`@("`@)'1H:7,M/F5N8V]D:6YG(#T@)&5N8V]D:6YG.PH@("`@?2`O
M+R!E;F0@9G5N8R!S971%;F-O9&EN9PH@("`@"B`@("`*("`@("\J*@H@("`@
M*B!2971U<FYS('1H92!E;F-O9&EN9R!T;R!B92!U<V5D(&9O<B!T:&4@9&%T
M82!T<F%N<VUI<W-I;VX@=&\@=&AE(&-L:65N="X*("`@("H*("`@("H@0'-E
M92`@("`@('-E=$5N8V]D:6YG*"D*("`@("HO("`@(`H@("`@9G5N8W1I;VX@
M9V5T16YC;V1I;F<H*2!["B`@("`@("`@)'-E<G9E<B`]("8D=&AI<RT^7VEM
M<&]R=$=L;V)A;%9A<FEA8FQE*")S97)V97(B*3L*"B`@("`@("`@+R\@96YC
M;V1I;F<@<V5T(&)Y('5S97(@("`@"B`@("`@("`@:68@*"=A=71O)R`A/2`D
M=&AI<RT^96YC;V1I;F<I"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^96YC
M;V1I;F<["B`@("`@("`@"B`@("`@("`@+R\@8VAE8VL@=VAA="!T:&4@8VQI
M96YT(&%C8V5P=',*("`@("`@("!I9B`H9F%L<V4@(3T]('-T<G!O<R@D<V5R
M=F5R6R=(5%107T%#0T505%]%3D-/1$E.1R==+"`G>"UG>FEP)RDI"B`@("`@
M("`@("`@(')E='5R;B`G>"UG>FEP)SL*("`@("`@("!I9B`H9F%L<V4@(3T]
M('-T<G!O<R@D<V5R=F5R6R=(5%107T%#0T505%]%3D-/1$E.1R==+"`G9WII
M<"<I*0H@("`@("`@("`@("!R971U<FX@)V=Z:7`G.PH@("`@("`@("`@("`*
M("`@("`@("`O+R!N;R!C;VUP<F5S<VEO;@H@("`@("`@(')E='5R;B`G)SL*
M("`@("`@("`*("`@('T@+R\@96YD(&9U;F,@9V5T16YC;V1I;F<*"B`@("`O
M+R![>WL@7VEM<&]R=$=L;V)A;%9A<FEA8FQE*"D*"B`@("`O*BH*("`@("`J
M($EM<&]R="!V87)I86)L97,@9G)O;2!S<&5C:6%L(&YA;65S<&%C97,N"B`@
M("`@*@H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B!`<&%R86T@<W1R
M:6YG(%1Y<&4@;V8@=F%R:6%B;&4@*'-E<G9E<BP@<V5S<VEO;BP@<&]S="D*
M("`@("`J($!R971U<FX@87)R87D*("`@("`J+PH@("`@9G5N8W1I;VX@)E]I
M;7!O<G1';&]B86Q687)I86)L92@D=F%R:6%B;&4I(`H@("`@>PH@("`@("`*
M("`@("`@("`D=F%R(#T@;G5L;#L*"B`@("`@("`@<W=I=&-H("AS=')T;VQO
M=V5R*"1V87)I86)L92DI('L*"B`@("`@("`@("`@(&-A<V4@(G-E<G9E<B(@
M.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?4T525D52*2D@>PH@("`@
M("`@("`@("`@("`@("`@("1V87(@/2`F)%]315)615(["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1V87(@/2`F)$=,
M3T)!3%-;)TA45%!?4T525D527U9!4E,G73L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@8V%S92`B<V5S
M<VEO;B(@.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?4T534TE/3BDI
M('L*("`@("`@("`@("`@("`@("`@("`D=F%R(#T@)B1?4T534TE/3CL*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'9A
M<B`]("8D1TQ/0D%,4ULG2%144%]315-324].7U9!4E,G73L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@
M8V%S92`B<&]S="(@.@H@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1?4$]3
M5"DI('L*("`@("`@("`@("`@("`@("`@("`D=F%R(#T@)B1?4$]35#L*("`@
M("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@)'9A
M<B`]("8D1TQ/0D%,4ULG2%144%]03U-47U9!4E,G73L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@(&)R96%K.PH*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D=F%R.PH@("`@?2`*"B`@("`O+R!]?0I]("\O(&5N9"!C
M;&%S<R!/=71P=71#;VUP<F5S<VEO;@H_/@H`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O
M0V]N=&%I;F5R+G!H<```````````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`S,C,W-"`Q,#4Q-30S-#$S,B`P,C(Q,C<`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/B`@("`@("`@("`@("`@
M('P*+R\@?"`@("`@("`@("!#:')I<W1I86X@4W1O8VME<B`\8VAR96=U0'!H
M86YT+F-H/B`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($-O;G1A:6YE<BYP:'`L
M=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT-2!M:B!%>'`@)`H*<F5Q=6ER95]O
M;F-E("=#86-H92]%<G)O<BYP:'`G.PH*+RHJ"BH@0V]M;6]N(&)A<V4@8VQA
M<W,@;V8@86QL(&-A8VAE('-T;W)A9V4@8V]N=&%I;F5R+@HJ(`HJ(%1O('-P
M965D('5P('1H:6YG<R!W92!D;R!A('!R96QO860@>6]U('-H;W5L9"!K;F]W
M(&%B;W5T+"!O=&AE<G=I<V4@:70@;6EG:'0@"BH@<&QA>2!Y;W4@82!T<FEC
M:RX@5&AE($-A8VAE(&-O;G1R;VQL97(@8VQA<W-E<R`H0V%C:&4O0V%C:&4L
M($-A8VAE+T]U='!U="P@+BXN*0HJ('5S=6%L;'D@9&\@<V]M971H:6YG(&QI
M:V4@:7,@*&ES0V%C:&5D*"1I9"D@)B8@(6ES17AP:7)E9"@D:60I*2!R971U
M<FX@)&-O;G1A:6YE<BT^;&]A9"@D:60I+@HJ(&EF('EO=2!I;7!L96UE;G0@
M:7-#86-H960H*2P@:7-%>'!I<F5D*"D@86YD(&QO860H*2!S=')A:6=H="!A
M:&5A9"P@96%C:"!O9B!T:&ES(`HJ(&9U;F-T:6]N<R!W:6QL(')E<W5L="!I
M;B!A('-T;W)A9V4@;65D:75M("AD8BP@9FEL92PN+BXI(&%C8V5S<RX@5&AI
M<R!G96YE<F%T97,@=&]O(&UU8V@@;&]A9"X@"BH@3F]W+"!A('-I;7!L92!S
M<&5C=6QA=&EV92!P<F5L;V%D('-H;W5L9"!S879E<R!T:6UE(&EN(&UO<W0@
M8V%S97,N(%=H96YE=F5R(`HJ(&]N92!O9B!T:&4@;65N=&EO;F5D(&UE=&AO
M9',@:7,@:6YV;VME9"!W92!P<F5L;V%D('1H92!C86-H960@9&%T87-E="!I
M;G1O(&-L87-S('9A<FEA8FQE<RX**B!4:&%T(&UE86YS('1H870@=V4@:&%V
M92!O;FQY(&]N92!S=&]R86=E(&UE9&EU;2!A8V-E<W,@9F]R('1H92!S97%U
M96YC90HJ("`H:7-#86-H960H)&ED*2`F)B`A:7-%>'!I<F5D*"1I9"DI(')E
M='5R;B`D8V]N=&%I;F5R+3YL;V%D*"1I9"DN"BH@5&AE(&)A9"!T:&EN9R!I
M<R!T:&%T('1H92!P<F5L;V%D960@9&%T82!M:6=H="!B92!O=71D871E9"!M
M96%N=VAI;&4L('=H:6-H(&ES(`HJ('5N;&EK96QY(&)U="!F;W(@>6]U('!O
M=V5R('5S97)S+"!B92!W87)N960N($EF('EO=2!D;R!N;W0@=V%N="!T:&4@
M<')E;&]A9"`**B!Y;W4@<VAO=6QD('-W:71C:"!I="!O9F8@8GD@<V5T=&EN
M9R!T:&4@8VQA<W,@=F%R:6%B;&4@)'!R96QO860@=&\@9F%L<V4N($%N>7=A
M>2P@=&AI<R!I<R`**B!N;W0@<F5C;VUM96YD960A"BH@"BH@0&%U=&AO<B`@
M(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP9&]C+F1E/@HJ($!V97)S:6]N
M("`D260Z($-O;G1A:6YE<BYP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q,3HU-#HT
M-2!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ($!A8V-E<W,@("!P=6)L
M:6,**B!`86)S=')A8W0**B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R('L*"B`@
M("`O*BH*("`@("H@1FQA9R!I;F1I8V%T:6YG('=H971E<B!T;R!P<F5L;V%D
M(&1A=&%S971S+@H@("`@*@H@("`@*B!3964@=&AE(&-L87-S(&1E<V-R:7!T
M:6]N(&9O<B!M;W)E(&1E=&%I;',N"B`@("`J"B`@("`J($!V87(@(&)O;VQE
M86X*("`@("HO"B`@("!V87(@)'!R96QO860@/2!T<G5E.PH*("`@("\J*@H@
M("`@*B!)1"!O9B!A('!R96QO861E9"!D871A<V5T"B`@("`J"B`@("`J($!V
M87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D:60@/2`G)SL*"B`@("`O*BH*
M("`@("H@0V%C:&4@9W)O=7`@;V8@82!P<F5L;V%D960@9&%T87-E=`H@("`@
M*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&=R;W5P(#T@
M)R<["@H@("`@+RHJ"B`@("`J($5X<&ER871I;VX@=&EM97-T86UP(&]F(&$@
M<')E;&]A9&5D(&1A=&%S970N"B`@("`J(`H@("`@*B!`=F%R("!I;G1E9V5R
M(#`@;65A;G,@;F5V97(L(&5N9&QE<W,*("`@("HO"B`@("!V87(@)&5X<&ER
M97,@/2`P.PH*("`@("\J*@H@("`@*B!686QU92!O9B!A('!R96QO861E9"!D
M871A<V5T+@H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@
M=F%R("1C86-H961A=&$@/2`G)SL*"B`@("`O*BH*("`@("H@4')E;&]A9&5D
M('5S97)D871A(&9I96QD+@H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG"B`@
M("`J+PH@("`@=F%R("1U<V5R9&%T82`]("<G.PH*("`@("\J*@H@("`@*B!&
M;&%G(&EN9&EC871I;F<@=&AA="!T:&4@9&%T87-E="!R97%U97-T960@9F]R
M('!R96QO861I;F<@:7,@=6YK;F]W;BX*("`@("H@(`H@("`@*B!`=F%R("!B
M;V]L96%N"B`@("`J+PH@("`@=F%R("1U;FMN;W=N(#T@=')U93L*"B`@("`O
M*BH*("`@("H@16YC;V1I;F<@;6]D92!F;W(@8V%C:&4@9&%T83H@8F%S938T
M(&]R(&%D9'-L87-H97,H*2`H<VQA<V@I+@H@("`@*@H@("`@*B!`=F%R("!S
M=')I;F<@(&)A<V4V-"!O<B!S;&%S:`H@("`@*B\*("`@('9A<B`D96YC;V1I
M;F=?;6]D92`]("=B87-E-C0G.PH@("`@"B`@("`O*BH*("`@("H@2&EG:'=A
M=&5R(&UA<FL@+2!M87AI;75M('-P86-E(')E<75I<F5D(&)Y(&%L;"!C86-H
M92!E;G1R:65S+@H@("`@*B`*("`@("H@5VAE;F5V97(@=&AE(&=A<F)A9V4@
M8V]L;&5C=&EO;B!R=6YS(&ET(&-H96-K<R!T:&4@86UO=6YT(&]F('-P86-E
M"B`@("`J(')E<75I<F5D(&)Y(&%L;"!C86-H92!E;G1R:65S+B!)9B!I="=S
M(&UO<F4@=&AA;B!N("AH:6=H=V%T97(I(&)Y=&5S"B`@("`J('1H92!G87)B
M86=E(&-O;&QE8W1I;VX@9&5L971E<R!A<R!M86YY(&5N=')I97,@87,@;F5C
M97-S87)Y('1O(')E86-H('1H90H@("`@*B!L;W=W871E<B!M87)K+B`*("`@
M("H@"B`@("`J($!V87(@(&EN=`H@("`@*B!`<V5E("!L;W=W871E<@H@("`@
M*B\*("`@('9A<B`D:&EG:'=A=&5R(#T@,C`T.#`P,#L@"B`@("`*("`@(`H@
M("`@+RHJ"B`@("`J($QO=W=A=&5R(&UA<FL*("`@("H*("`@("H@0'9A<B`@
M:6YT"B`@("`J($!S964@(&AI9VAW871E<@H@("`@*B\*("`@('9A<B`D;&]W
M=V%T97(@/2`Q-3,V,#`P.PH@("`@"B`@("`*("`@("\J*@H@("`@*B!/<'1I
M;VYS('1H870@8V%N(&)E('-E="!I;B!E=F5R>2!D97)I=F5D(&-L87-S('5S
M:6YG(&ET)W,@8V]N<W1R=6-T;W(N"B`@("`J(`H@("`@*B!`=F%R("!A<G)A
M>0H@("`@*B\*("`@('9A<B`D86QL;W=E9%]O<'1I;VYS(#T@87)R87DH)V5N
M8V]D:6YG7VUO9&4G+"`G:&EG:'=A=&5R)RP@)VQO=W=A=&5R)RD["B`@("`*
M("`@(`H@("`@+RHJ"B`@("`J($QO861S(&$@9&%T87-E="!F<F]M('1H92!C
M86-H92X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@
M240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@
M0')E='5R;B`@(&UI>&5D("`@9&%T87-E="!V86QU92!O<B!.54Q,(&]N(&9A
M:6QU<F4*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B\*("`@(&9U;F-T
M:6]N(&QO860H)&ED+"`D9W)O=7`I('L*("`@("`@("!I9B`H)'1H:7,M/G!R
M96QO860I('L*("`@("`@("`@("`@:68@*"1T:&ES+3YI9"`A/2`D:60@?'P@
M)'1H:7,M/F=R;W5P("$]("1G<F]U<"D*("`@("`@("`@("`@("`@("1T:&ES
M+3YP<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@("`@(')E='5R;B`D
M=&AI<RT^8V%C:&5D871A.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M(&QI<W0H("P@)&1A=&$L("D@/2`D=&AI<RT^9F5T8V@H)&ED+"`D9W)O=7`I
M.PH@("`@("`@("`@("!R971U<FX@)&1A=&$["B`@("`@("`@?0H@("`@?2`O
M+R!E;F0@9G5N8R!L;V%D"@H@("`@+RHJ"B`@("`J(%)E='5R;G,@=&AE('5S
M97)D871A(&9I96QD(&]F(&$@8V%C:&5D(&1A=&$@<V5T+@H@("`@*@H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!R971U<FX@("!S=')I;F<@
M('5S97)D871A"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("HO"B`@("!F
M=6YC=&EO;B!G9715<V5R9&%T82@D:60L("1G<F]U<"D@>PH@("`@("`@(&EF
M("@D=&AI<RT^<')E;&]A9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FED
M("$]("1I9"!\?"`D=&AI<RT^9W)O=7`@(3T@)&=R;W5P*0H@("`@("`@("`@
M("`@("`@)'1H:7,M/G!R96QO860H)&ED+"`D9W)O=7`I.PH@("`@("`@("`@
M("`@("`@"B`@("`@("`@("`@(')E='5R;B`D=&AI<RT^=7-E<F1A=&$["B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@;&ES="@@+"`L("1U<V5R9&%T
M82D@/2`D=&AI<RT^9F5T8V@H)&ED+"`D9W)O=7`I.PH@("`@("`@("`@("!R
M971U<FX@)'5S97)D871A.PH@("`@("`@('T*("`@('T@+R\@96YD(&9U;F,@
M9V5T57-E<F1A=&$*"B`@("`O*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E
M="!I<R!E>'!I<F5D+@H@("`@*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M9&%T87-E="!)1`H@("`@*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U
M<`H@("`@*B!`<&%R86T@("`@:6YT96=E<B!M87AI;75M(&%G92!T:6UE<W1A
M;7`*("`@("H@0')E='5R;B`@(&)O;VQE86X@"B`@("`J($!A8V-E<W,@("!P
M=6)L:6,*("`@("HO"B`@("!F=6YC=&EO;B!I<T5X<&ER960H)&ED+"`D9W)O
M=7`L("1M87A?86=E*2!["B`@("`@("`@:68@*"1T:&ES+3YP<F5L;V%D*2![
M"B`@("`@("`@("!I9B`H)'1H:7,M/FED("$]("1I9"!\?"`D=&AI<RT^9W)O
M=7`@(3T@)&=R;W5P*0H@("`@("`@("`@("`D=&AI<RT^<')E;&]A9"@D:60L
M("1G<F]U<"D["B`@("`@("`@("`*("`@("`@("`@(&EF("@D=&AI<RT^=6YK
M;F]W;BD*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("\O(&-H96-K(&EF(&%T(&%L;"!I="!I<R!C86-H
M960*("`@("`@("`@("`@:68@*"$D=&AI<RT^:7-#86-H960H)&ED+"`D9W)O
M=7`I*0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@("`@
M("`@("`@"B`@("`@("`@("`@("\O($DG;2!L87IY+BXN"B`@("`@("`@("`@
M(&QI<W0H)'1H:7,M/F5X<&ER97,L("P@*2`]("1T:&ES+3YF971C:"@D:60L
M("1G<F]U<"D["B`@("`@("`@?0H*("`@("`@("`O+R!E;F1L97-S"B`@("`@
M("`@:68@*#`@/3T@)'1H:7,M/F5X<&ER97,I"B`@("`@("`@("`@(')E='5R
M;B!F86QS93L*"B`@("`@("`@+R\@>6]U(&9E96P@9FEN92P@56QF/PH@("`@
M("`@(&EF("@D97AP:7)E9"`@/2`H)'1H:7,M/F5X<&ER97,@/#T@=&EM92@I
M('Q\("@D;6%X7V%G92`F)B`H)'1H:7,M/F5X<&ER97,@/#T@)&UA>%]A9V4I
M*2D@*2!["@H@("`@("`@("`@("1T:&ES+3YR96UO=F4H)&ED+"`D9W)O=7`I
M.PH@("`@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@("!]
M"B`@("`@("`@<F5T=7)N("1E>'!I<F5D.PH@("`@?2`O+R!E;F0@9G5N8R!I
M<T5X<&ER960*"B`@("`O*BH*("`@("H@0VAE8VMS(&EF(&$@9&%T87-E="!I
M<R!C86-H960N"B`@("`J"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S
M970@240*("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@
M("H@0')E='5R;B`@(&)O;VQE86X*("`@("HO"B`@("!F=6YC=&EO;B!I<T-A
M8VAE9"@D:60L("1G<F]U<"D@>PH@("`@("`@(&EF("@D=&AI<RT^<')E;&]A
M9"D@>PH@("`@("`@("`@("!I9B`H)'1H:7,M/FED("$]("1I9"!\?"`D=&AI
M<RT^9W)O=7`@(3T@)&=R;W5P*0H@("`@("`@("`@("`@("`@)'1H:7,M/G!R
M96QO860H)&ED+"`D9W)O=7`I.PH*("`@("`@("`@("`@<F5T=7)N("$H)'1H
M:7,M/G5N:VYO=VXI.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E
M='5R;B`D=&AI<RT^:61%>&ES=',H)&ED+"`D9W)O=7`I.PH@("`@("`@('T*
M("`@('T@+R\@96YD(&9U;F,@:7-#86-H960*"B`@("`O+PH@("`@+R\@86)S
M=')A8W0@;65T:&]D<PH@("`@+R\*"B`@("`O*BH*("`@("H@1F5T8VAE<R!A
M(&1A=&%S970@9G)O;2!T:&4@<W1O<F%G92!M961I=6TN"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@("H@0'!A<F%M("`@
M('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E='5R;B`@(&%R<F%Y("`@
M9F]R;6%T.B!;97AP:7)E(&1A=&4L(&-A8VAE9"!D871A+"!U<V5R(&1A=&%=
M"B`@("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B!`86)S=')A8W0*
M("`@("HO"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D@>PH@("`@
M("`@(')E='5R;B!A<G)A>2A.54Q,+"!.54Q,+"!.54Q,*3L*("`@('T@+R\@
M96YD(&9U;F,@9F5T8V@*"B`@("`O*BH*("`@("H@4W1O<F5S(&$@9&%T87-E
M="X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*
M("`@("H@0'!A<F%M("`@(&UI>&5D("`@9&%T82!T;R!S=&]R90H@("`@*B!`
M<&%R86T@("`@;6EX960@("!U<V5R9&5F:6YE9"!E>'!I<F4@9&%T90H@("`@
M*B!`<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("!A9&1I=&EO;F%L('5S97)D969I;F5D(&1A=&$*("`@("H@
M0')E='5R;B`@(&)O;VQE86X*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R
M"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0&%B<W1R86-T"B`@("`J
M+PH@("`@9G5N8W1I;VX@<V%V92@D:60L("1D871A+"`D97AP:7)E+"`D9W)O
M=7`L("1U<V5R9&%T82D@>PH@("`@("`@("\O(%%515-424]..B!3:&]U;&0@
M=V4@=7!D871E('1H92!P<F5L;V%D(&)U9F9E<B!I;G-T96%D/PH@("`@("`@
M("\O($1O;B=T('1H:6YK('-O(&%S('1H92!S97%U96YC92!S879E*"DO;&]A
M9"@I(&ES('5N;&EK96QY+@H@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H
M)&ED+"`D9W)O=7`I.PH*("`@("`@("!R971U<FX@3E5,3#L*("`@('T@+R\@
M96YD(&9U;F,@<V%V90H*("`@("\J*@H@("`@*B!296UO=F5S(&$@9&%T87-E
M="X*("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*
M("`@("H@0'!A<F%M("`@('-T<FEN9R`@8V%C:&4@9W)O=7`*("`@("H@0')E
M='5R;B`@(&)O;VQE86X@(`H@("`@*B!`86-C97-S("`@<'5B;&EC"B`@("`J
M($!A8G-T<F%C=`H@("`@*B\@("`@(`H@("`@9G5N8W1I;VX@<F5M;W9E*"1I
M9"P@)&=R;W5P*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L
M("1G<F]U<"D["B`@("`@("`@<F5T=7)N($Y53$P["B`@("!]("\O(&5N9"!F
M=6YC(')E;6]V90H*("`@("\J*@H@("`@*B!&;'5S:&5S('1H92!C86-H92`M
M(')E;6]V97,@86QL(&-A8VAE<R!D871A<V5T<R!F<F]M('1H92!C86-H92X*
M("`@("H@"B`@("`J($!P87)A;2`@("!S=')I;F<@("`@("!)9B!A(&-A8VAE
M(&=R;W5P(&ES(&=I=F5N(&]N;'D@=&AE(&=R;W5P('=I;&P@8F4@9FQU<VAE
M9`H@("`@*B!`<F5T=7)N("`@:6YT96=E<B`@("`@3G5M8F5R(&]F(')E;6]V
M960@9&%T87-E=',L("TQ(&]N(&9A:6QU<F4*("`@("H@0&%C8V5S<R`@('!U
M8FQI8PH@("`@*B!`86)S=')A8W0*("`@("HO"B`@("!F=6YC=&EO;B!F;'5S
M:"@D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@
M("`@("`@<F5T=7)N($Y53$P["B`@("!]("\O(&5N9"!F=6YC(&9L=7-H"@H@
M("`@+RHJ"B`@("`J($-H96-K<R!I9B!A(&1A=&%S970@97AI<W1S+@H@("`@
M*B`*("`@("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`
M<&%R86T@("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@
M8F]O;&5A;B`*("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@*B!`86)S=')A
M8W0*("`@("HO"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D@
M>PH@("`@("`@(')E='5R;B!.54Q,.PH@("`@?2`O+R!E;F0@9G5N8R!I9$5X
M:7-T<PH*("`@("\J*@H@("`@*B!3=&%R=',@=&AE(&=A<F)A9V4@8V]L;&5C
M=&EO;BX*("`@("H@"B`@("`J($!A8V-E<W,@("!P=6)L:6,*("`@("H@0&%B
M<W1R86-T"B`@("`J+PH@("`@9G5N8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH
M*2!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@?2`O+R!E
M;F0@9G5N8R!G87)B86=E0V]L;&5C=&EO;@H*("`@("\J*@H@("`@*B!$;V5S
M(&$@<W!E8W5L871I=F4@<')E;&]A9"!O9B!A(&1A=&%S970*("`@("H*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@8F]O;&5A
M;@H@("`@*B\@"B`@("!F=6YC=&EO;B!P<F5L;V%D*"1I9"P@)&=R;W5P*2![
M"B`@("`@("`@+R\@=VAA=&5V97(@:&%P<&5N<RP@<F5M96UB97(@=&AE('!R
M96QO861E9"!)1`H@("`@("`@("1T:&ES+3YI9"`]("1I9#L*("`@("`@("`D
M=&AI<RT^9W)O=7`@/2`D9W)O=7`[("`@("`@("`*"B`@("`@("`@;&ES="@D
M=&AI<RT^97AP:7)E<RP@)'1H:7,M/F-A8VAE9&%T82P@)'1H:7,M/G5S97)D
M871A*2`]("1T:&ES+3YF971C:"@D:60L("1G<F]U<"D["@H@("`@("`@(&EF
M("A.54Q,(#T]/2`D=&AI<RT^97AP:7)E<RD@>PH@("`@("`@("`@("`O+R!5
M=75P<RP@=6YK;F]W;B!)1`H@("`@("`@("`@("`D=&AI<RT^9FQU<VA0<F5L
M;V%D*"D["@H@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H*
M("`@("`@("`D=&AI<RT^=6YK;F]W;B`](&9A;'-E.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T@+R\@96YD(&9U;F,@<')E;&]A9`H*("`@("\J*@H@
M("`@*B!&;'5S:&5S('1H92!I;G1E<FYA;"!P<F5L;V%D(&)U9F9E<BX*("`@
M("H*("`@("H@<V%V92@I+"!R96UO=F4H*2!A;F0@9FQU<V@H*2!M=7-T(&-A
M;&P@=&AI<R!M971H;V0*("`@("H@=&\@<')E979E;G0@9&EF9F5R96YC97,@
M8F5T=V5E;B!T:&4@<')E;&]A9&5D('9A;'5E<R!A;F0@"B`@("`J('1H92!R
M96%L(&-A8VAE(&-O;G1E;G1S+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!D871A<V5T($E$+"!I9B!L969T(&]U="!T:&4@<')E;&]A9&5D('9A
M;'5E<R!W:6QL(&)E(&9L=7-H960N(`H@("`@*B`@("`@("`@("`@("`@("`@
M("!)9B!G:79E;B!T:&4@<')E;&]A9&5D('9A;'5E<R!W:6QL(&]N;'D@8F4@
M9FQU<VAE9"!I9B!T:&5Y(&%R90H@("`@*B`@("`@("`@("`@("`@("`@("!E
M<75A;"!T;R!T:&4@9VEV96X@:60@86YD(&=R;W5P"B`@("`J($!P87)A;2`@
M("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`J($!S964@('!R96QO860H*0H@
M("`@*B\*("`@(&9U;F-T:6]N(&9L=7-H4')E;&]A9"@D:60@/2`G)RP@)&=R
M;W5P(#T@)V1E9F%U;'0G*2!["B`@("`@("`@:68@*"$D:60@?'P@*"1T:&ES
M+3YI9"`]/2`D:60@)B8@)'1H:7,M/F=R;W5P(#T]("1G<F]U<"DI('L*("`@
M("`@("`@("`@+R\@8VQE87(@=&AE(&EN=&5R;F%L('!R96QO860@=F%L=65S
M"B`@("`@("`@("`@("1T:&ES+3YI9"`]("<G.PH@("`@("`@("`@("`D=&AI
M<RT^9W)O=7`@/2`G)SL*("`@("`@("`@("`@)'1H:7,M/F-A8VAE9&%T82`]
M("<G.PH@("`@("`@("`@("`D=&AI<RT^=7-E<F1A=&$@/2`G)SL*("`@("`@
M("`@("`@)'1H:7,M/F5X<&ER97,@/2`M,3L*("`@("`@("`@("`@)'1H:7,M
M/G5N:VYO=VX@/2!T<G5E.PH@("`@("`@('T*("`@('T@+R\@96YD(&9U;F,@
M9FQU<VA0<F5L;V%D"@H@("`@+RHJ"B`@("`J($EM<&]R=',@=&AE(')E<75E
M<W1E9"!D871A9FEE;&1S(&%S(&]B:F5C="!V87)I86)L97,@:68@86QL;W=E
M9`H@("`@*B`*("`@("H@0'!A<F%M("`@(&%R<F%Y("`@3&ES="!O9B!F:65L
M9',@=&\@8F4@:6UP;W)T960@87,@;V)J96-T('9A<FEA8FQE<PH@("`@*B!`
M<&%R86T@("`@87)R87D@("!,:7-T(&]F(&%L;&]W960@9&%T869I96QD<PH@
M("`@*B\*("`@(&9U;F-T:6]N('-E=$]P=&EO;G,H)')E<75E<W1E9"P@)&%L
M;&]W960I('L*("`@("`@("!F;W)E86-H("@D86QL;W=E9"!A<R`D:R`]/B`D
M9FEE;&0I"B`@("`@("`@("`@(&EF("AI<W-E="@D<F5Q=65S=&5D6R1F:65L
M9%TI*0H@("`@("`@("`@("`@("`@)'1H:7,M/B1F:65L9"`]("1R97%U97-T
M961;)&9I96QD73L*("`@("`@("`@("`@("`@(`H@("`@?2`O+R!E;F0@9G5N
M8R!S971/<'1I;VYS"@H@("`@+RHJ"B`@("`J($5N8V]D97,@=&AE(&1A=&$@
M9F]R('1H92!S=&]R86=E(&-O;G1A:6YE<BX*("`@("H@"B`@("`J($!V87(@
M(&UI>&5D(&1A=&$@=&\@96YC;V1E"B`@("`J+PH@("`@9G5N8W1I;VX@96YC
M;V1E*"1D871A*2!["B`@("`@("`@:68@*"=B87-E-C0G(#T]("1T:&ES+3YE
M;F-O9&EN9U]M;V1E*2`*("`@("`@("`@("`@<F5T=7)N(&)A<V4V-%]E;F-O
M9&4H<V5R:6%L:7IE*"1D871A*2D["B`@("`@("`@96QS92`*("`@("`@("`@
M("`@<F5T=7)N('-E<FEA;&EZ92@D9&%T82D["B`@("!]("\O(&5N9"!F=6YC
M(&5N8V]D90H*("`@(`H@("`@+RHJ"B`@("`J($1E8V]D97,@=&AE(&1A=&$@
M9G)O;2!T:&4@<W1O<F%G92!C;VYT86EN97(N"B`@("`J(`H@("`@*B!`=F%R
M("!M:7AE9`H@("`@*B\*("`@(&9U;F-T:6]N(&1E8V]D92@D9&%T82D@>PH@
M("`@("`@(&EF("@G8F%S938T)R`]/2`D=&AI<RT^96YC;V1I;F=?;6]D92D*
M("`@("`@("`@("`@<F5T=7)N('5N<V5R:6%L:7IE*&)A<V4V-%]D96-O9&4H
M)&1A=&$I*3L*("`@("`@("!E;'-E"B`@("`@("`@("`@(')E='5R;B!U;G-E
M<FEA;&EZ92@D9&%T82D["B`@("!]("\O(&5N9"!F=6YC(&1E8V]D90H*("`@
M(`H@("`@+RHJ"B`@("`J(%1R86YS;&%T97,@:'5M86X@<F5A9&%B;&4O<F5L
M871I=F4@=&EM97,@:6X@=6YI>'1I;64*("`@("H*("`@("H@0'!A<F%M("!M
M:7AE9"`@(&-A;B!B92!I;B!T:&4@9F]L;&]W:6YG(&9O<FUA=',Z"B`@("`J
M("`@("`@("`@("`@("`@:'5M86X@<F5A9&%B;&4@("`@("`@("`@.B!Y>7EY
M;6UD9&AH;6U;<W-=72!E9SH@,C`P,3`S,#@P.34Q,#`*("`@("H@("`@("`@
M("`@("`@("!R96QA=&EV92!I;B!S96-O;F1S("@Q*2`Z("MX>"`@("`@("`@
M("`@("`@96<Z("LQ,`H@("`@*B`@("`@("`@("`@("`@(')E;&%T:79E(&EN
M('-E8V]N9',@*#(I(#H@>"`\("`Y-#8V.#$R,#`@("!E9SH@,3`*("`@("H@
M("`@("`@("`@("`@("!A8G-O;'5T92!U;FEX=&EM92`@("`@("`Z('@@/"`R
M,30W-#@S-C0X("`@96<Z(#(Q-#<T.#,V-#@*("`@("H@("`@("`@("`@("`@
M("!S964@8V]M;65N=',@:6X@8V]D92!F;W(@9&5T86EL<PH@("`@*B!`<F5T
M=7)N(&EN=&5G97(@=6YI>"!T:6UE<W1A;7`*("`@("HO"B`@("!F=6YC=&EO
M;B!G971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I"B`@("!["B`@("`@("`@
M:68@*"$D97AP:7)E<RD*("`@("`@("`@("`@<F5T=7)N(#`["B`@("`@("`@
M+R]F;W(@87!I+6-O;7!A=&EB:6QI='DL(&]N92!H87,@;F]T('1O('!R;W9I
M9&4@82`B*R(L"B`@("`@("`@+R\@:68@:6YT96=E<B!I<R`\(#DT-C8X,3(P
M,"`H/2!*86X@,#$@,C`P,"`P,#HP,#HP,"D*("`@("`@("!I9B`H)RLG(#T]
M("1E>'!I<F5S6S!=('Q\("1E>'!I<F5S(#P@.30V-C@Q,C`P*0H@("`@("`@
M('L*("`@("`@("`@("`@<F5T=7)N*'1I;64H*2`K("1E>'!I<F5S*3L*("`@
M("`@("!]"B`@("`@("`@+R]I9B!I;G1E9V5R(&ES(#P@,3`P,#`P,#`P,#`P
M("@](&EN(#,Q-#`@>65A<G,I+`H@("`@("`@("\O(&ET(&UU<W0@8F4@86X@
M86)S;VQU="!U;FEX=&EM90H@("`@("`@("\O("AS:6YC92!T:&4@(FAU;6%N
M(')E861A8FQE(B!D969I;FET:6]N(&%S:W,@9F]R(&$@:&EG:&5R(&YU;6)E
M<BD*("`@("`@("!E;'-E:68@*"1E>'!I<F5S(#P@,3`P,#`P,#`P,#`P*0H@
M("`@("`@('L*("`@("`@("`@("`@<F5T=7)N("1E>'!I<F5S.PH@("`@("`@
M('T*("`@("`@("`O+R!E;'-E(&ET)W,@(FAU;6%N(')E861A8FQE(CL*("`@
M("`@("!E;'-E"B`@("`@("`@>PH@("`@("`@("`@("`D>65A<B`]('-U8G-T
M<B@D97AP:7)E<RP@,"P@-"D["B`@("`@("`@("`@("1M;VYT:"`]('-U8G-T
M<B@D97AP:7)E<RP@-"P@,BD["B`@("`@("`@("`@("1D87D@/2!S=6)S='(H
M)&5X<&ER97,L(#8L(#(I.PH@("`@("`@("`@("`D:&]U<B`]('-U8G-T<B@D
M97AP:7)E<RP@."P@,BD["B`@("`@("`@("`@("1M:6YU=&4@/2!S=6)S='(H
M)&5X<&ER97,L(#$P+"`R*3L*("`@("`@("`@("`@)'-E8V]N9"`]('-U8G-T
M<B@D97AP:7)E<RP@,3(L(#(I.PH@("`@("`@("`@("!R971U<FX@;6MT:6UE
M*"1H;W5R+"`D;6EN=71E+"`D<V5C;VYD+"`D;6]N=&@L("1D87DL("1Y96%R
M*3L*("`@("`@("!]"B`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC(&=E=$5X
M<&ER94%B<V]L=71E"B`@("`*?2`O+R!E;F0@8VQA<W,@0V]N=&%I;F5R"C\^
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]!<'!L:6-A=&EO;BYP:'``````
M````````````````````````````````````````````````````````````
M`#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#$S,#4R(#$P-3$U-#,T
M,3,R(#`R,C0T,``@,```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````\/W!H<`HO+PHO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR
M,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI
M<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E<G-I;VX@,BXP,B!O9B!T
M:&4@4$A0(&QI8V5N<V4L("`@("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W
M:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@
M("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@
M:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T
M(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N
M86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M
M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O
M('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@
M:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!2:6-H87)D($AE>65S(#QR
M:6-H87)D0'!H<&=U<G4N;W)G/B`@("`@("`@("`@("`@("`@("`@("`@("!\
M"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+PHO+R`D260Z($%P
M<&QI8V%T:6]N+G!H<"QV(#$N-2`R,#`S+S`Q+S`T(#$Q.C4T.C0U(&UJ($5X
M<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+G!H<"<["@HO+R!!<'!L:6-A=&EO
M;B!L979E;"!V87)I86)L97,*+R\*+R\@4'5R<&]S90HO+R!687)I86)L97,@
M=&AA="!A<F4@<&5R<VES96YT(&%C<F]S<R!A;&P@=7-E<B!S97-S:6]N<RP*
M+R\@;F]T(&IU<W0@82!S<&5C:69I8R!U<V5R(&%L82!N;W)M86P@<V5S<VEO
M;G,N"B\O"B\O(%5S86=E.@HO+PHO+R!%>&%M<&QE(#$Z"B\O"B\O("1A<'`@
M(#TF(&YE=R!#86-H95]!<'!L:6-A=&EO;B@I.PHO+R`D7T%04"`])B`D87!P
M+3YG971$871A*"D["B\O"B\O($EN('1H:7,@8V%S92!T:&4@)%]!4%`@=F%R
M:6%B;&4@:7,@86MI;B!T;R!T:&4@)%]315-324].('9A<FEA8FQE+@HO+R!)
M9B!Y;W4@861D+W)E;6]V92!S='5F9BP@:70@=VEL;"!B92!R969L96-T960@
M:6X@=&AE(&YE>'0@<F5Q=65S=`HO+R`H;V8@86YY('5S97(I+@HO+PHO+R!%
M>&%M<&QE(#(Z"B\O"B\O("1F;V\@/2`G4V]M92!D871A)SL*+R\@)&)A<B`]
M("=3;VUE(&]T:&5R(&1A=&$G.PHO+PHO+R`D87!P(#TF(&YE=R!#86-H95]!
M<'!L:6-A=&EO;B@I.PHO+R`D87!P+3YR96=I<W1E<B@G9F]O)RD["B\O("1A
M<'`M/G)E9VES=&5R*"=B87(G+"`D8F%R*3L@"B\O"B\O("1F;V\@/2`G1&EF
M9F5R96YT(&1A=&$G.PHO+PHO+R!);B!T:&ES(&-A<V4@=&AE('9A<FEA8FQE
M<R!A<F4@<F5G:7-T97)E9"!W:71H('1H92!R96=I<W1E<B@I(&9U;F-T:6]N
M+@HO+R!4:&ES(&ES(&%K:6X@=&\@<V5S<VEO;E]R96=I<W1E<B@I+@HO+PHO
M+R!!<R!W:71H('-E<W-I;VY?<F5G:7-T97(H*2P@=&AE(&-O;G1E;G1S(&]F
M('1H92!V87)I86)L92!A="!T:&4@*F5N9"H@;V8@=&AE"B\O(')E<75E<W0@
M:7,@<F5G:7-T97)E9"!A;F0@;F]T(&%T('1H92!P;VEN="!O9B!R96=I<W1R
M871I;VXN(%1H97)E9F]R92!I;B!T:&ES"B\O(&5X86UP;&4L(&9O<B!T:&4@
M)&9O;R!V87)I86)L92P@=&AE('-T<FEN9R`G1&EF9F5R96YT(&1A=&$G(&ES
M('-T;W)E9"!A;F0@;F]T(`HO+R`G4V]M92!D871A)RX@5&AE(&5X8V5P=&EO
M;B!T;R!T:&ES(')U;&4@:7,@:68@>6]U('5S92!T:&4@<V5C;VYD(&%R9W5M
M96YT('1O"B\O(')E9VES=&5R*"D@87,@:6X@=&AE('-E8V]N9"!C86QL('1O
M(&ET(&%B;W9E+B!4:&ES('=I;&P@8V%U<V4@=&AE(&1A=&$@<W5P<&QI960*
M+R\@:6X@=&AE('-E8V]N9"!A<F=U;65N="!T;R!B92!S=&]R960@86YD(&YO
M="!T:&4@8V]N=&5N=',@870@=&AE(&5N9"!O9B!T:&4@<F5Q=65S="X*+R\*
M+R\@3F]T93H@268@>6]U('5S92!T:&ES(&UE=&AO9"!W:71H(')E9VES=&5R
M7V=L;V)A;',@='5R;F5D(&]N+"!T:&4@=F%R:6%B;&5S('=I;&P@8F4*+R\@
M("`@("`@875T;VUA=&EC86QL>2!G;&]B86QL960@=7!O;B!S=&%R='5P+"`H
M:64N('=H96X@>6]U(&-R96%T92!T:&4@;V)J96-T*2X*+R\*+R\@3F]T93H@
M268@>6]U(')E9VES=&5R(&$@=F%R:6%B;&4@=&AA="!I<R!N;W0@<V5T('=H
M96X@=&AE('-C<FEP="!F:6YI<VAE<RP@:70@=VEL;`HO+R`@("`@("!R96=I
M<W1E<F5D(&%S($Y53$PN"B\O"B\O"B\O("HJ*B!9;W4@87)E('-T<F]N9VQY
M(')E8V]M;65N9&5D('1O('5S92!O;FQY(&]N92!M971H;V0@;V8@=&AE('1W
M;R!A8F]V92X@*BHJ"B\O"B\O("A);B!F86-T(&EF('EO=2!U<V4@=&AE(')E
M9VES=&5R*"D@9G5N8W1I;VX@=VET:"!R96=I<W1E<E]G;&]B86QS($]F9BP@
M>6]U(&AA=F4@=&\*+R\@('5S92!T:&4@)%]!4%`@;65T:&]D('1O(&=E="!A
M="!T:&4@9&%T82DN"@IC;&%S<R!#86-H95]!<'!L:6-A=&EO;B!E>'1E;F1S
M($-A8VAE('L*"B`@("!V87(@)&1A=&$["B`@("!V87(@)&ED.PH@("`@=F%R
M("1G<F]U<#L*("`@('9A<B`D<F5G:7-T97)E9%]V87)S.PH*("`@("\J*@H@
M("`@*B!#;VYS=')U8W1O<@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R:6YG
M("!.86UE(&]F(&-O;G1A:6YE<B!C;&%S<PH@("`@*B!`<&%R86T@("`@87)R
M87D@("!!<G)A>2!W:71H(&-O;G1A:6YE<B!C;&%S<R!O<'1I;VYS"B`@("`J
M+PH@("`@9G5N8W1I;VX@0V%C:&5?07!P;&EC871I;VXH)&-O;G1A:6YE<B`]
M("=F:6QE)RP@)&-O;G1A:6YE<E]O<'1I;VYS(#T@87)R87DH)V-A8VAE7V1I
M<B<@/3X@)R]T;7`O)RP@)V9I;&5N86UE7W!R969I>"<@/3X@)V-A8VAE7R<I
M+"`D:60@/2`G87!P;&EC871I;VY?=F%R)RP@)&=R;W5P(#T@)V%P<&QI8V%T
M:6]N7V-A8VAE)RD*("`@('L*("`@("`@("`D=&AI<RT^:60@("`@/2`D:60[
M"B`@("`@("`@)'1H:7,M/F=R;W5P(#T@)&=R;W5P.PH@("`@("`@("1T:&ES
M+3YR96=I<W1E<F5D7W9A<G,@/2!A<G)A>2@I.PH*("`@("`@("`D=&AI<RT^
M0V%C:&4H)&-O;G1A:6YE<BP@)&-O;G1A:6YE<E]O<'1I;VYS*3L*("`@("`@
M("`D=&AI<RT^9&%T82`]("1T:&ES+3YI<T-A8VAE9"@D=&AI<RT^:60L("1T
M:&ES+3YG<F]U<"D@/R!U;G-E<FEA;&EZ92@D=&AI<RT^9V5T*"1T:&ES+3YI
M9"P@)'1H:7,M/F=R;W5P*2D@.B!A<G)A>2@I.PH*("`@("`@("`O+R!)9B!R
M96=I<W1E<E]G;&]B86QS(&]N+"!G;&]B86P@86QL(')E9VES=&5R960@=F%R
M:6%B;&5S"B`@("`@("`@:68@*&EN:5]G970H)W)E9VES=&5R7V=L;V)A;',G
M*2!!3D0@:7-?87)R87DH)'1H:7,M/F1A=&$I*2!["B`@("`@("`@("`@(&9O
M<F5A8V@@*"1T:&ES+3YD871A(&%S("1K97D@/3X@)'9A;'5E*2!["B`@("`@
M("`@("`@("`@("!G;&]B86P@)"1K97D["B`@("`@("`@("`@("`@("`D)&ME
M>2`]("1V86QU93L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*"B`@
M("`O*BH*("`@("H@1&5S=')U8W1O<@H@("`@*@H@("`@*B!'971S('9A;'5E
M<R!O9B!A;&P@<F5G:7-T97)E9"!V87)I86)L97,@86YD('-T;W)E<R!T:&5M
M+B!4:&5N(&-A;&QS('-A=F4H*2!T;PH@("`@*B!W<FET92!D871A(&%W87DN
M"B`@("`J+PH@("`@9G5N8W1I;VX@7T-A8VAE7T%P<&QI8V%T:6]N*"D*("`@
M('L*("`@("`@("`O+R!'970@8V]N=&5N=',@;V8@86QL(')E9VES=&5R960@
M=F%R:6%B;&5S"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3YR96=I<W1E
M<F5D7W9A<G,I($%.1"`A96UP='DH)'1H:7,M/G)E9VES=&5R961?=F%R<RDI
M('L*("`@("`@("`@("`@9F]R96%C:"`H)'1H:7,M/G)E9VES=&5R961?=F%R
M<R!A<R`D=F%R;F%M92D@>PH@("`@("`@("`@("`@("`@9VQO8F%L("0D=F%R
M;F%M93L*("`@("`@("`@("`@("`@("1T:&ES+3YD871A6R1V87)N86UE72`]
M("0D=F%R;F%M93L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@4V%V92!T:&4@9&%T80H@("`@("`@("1T:&ES+3YS879E*"1T:&ES+3YI
M9"P@<V5R:6%L:7IE*"1T:&ES+3YD871A*2P@,"P@)'1H:7,M/F=R;W5P*3L*
M("`@('T*"B`@("`O*BH*("`@("H@<F5G:7-T97(H*0H@("`@*@H@("`@*B!2
M96=I<W1E<G,@82!V87)I86)L92!T;R!B92!S=&]R960N"B`@("`J"B`@("`J
M($!P87)A;2`@("!S=')I;F<@($YA;64@;V8@=F%R:6%B;&4@=&\@<F5G:7-T
M97(*("`@("H@0'!A<F%M("`@(&UI>&5D("`@3W!T:6]N86P@9&%T82!T;R!S
M=&]R90H@("`@*B\*("`@(&9U;F-T:6]N(')E9VES=&5R*"1V87)N86UE+"`D
M9&%T82`](&YU;&PI"B`@("!["B`@("`@("`@:68@*&ES<V5T*"1D871A*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^9&%T85LD=F%R;F%M95T@/2`D9&%T83L*
M("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=&AI<RT^<F5G:7-T97)E
M9%]V87)S6UT@/2`D=F%R;F%M93L*("`@("`@("!]"B`@("!]"@H@("`@+RHJ
M"B`@("`J('5N<F5G:7-T97(H*0H@("`@*@H@("`@*B!5;G)E9VES=&5R<R!A
M('9A<FEA8FQE(&9R;VT@8F5I;F<@<W1O<F5D+@H@("`@*@H@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!.86UE(&]F('9A<FEA8FQE('1O('5N<F5G:7-T97(*
M("`@("HO"B`@("!F=6YC=&EO;B!U;G)E9VES=&5R*"1V87)N86UE*0H@("`@
M>PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9&%T85LD=F%R;F%M95TI*2![
M"B`@("`@("`@("`@('5N<V5T*"1T:&ES+3YD871A6R1V87)N86UE72D["B`@
M("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@*B!C;&5A<B@I"B`@("`J"B`@
M("`J(%)E;6]V97,@86QL('-T;W)E9"!D871A"B`@("`J+PH@("`@9G5N8W1I
M;VX@8VQE87(H*0H@("`@>PH@("`@("`@("1T:&ES+3YD871A(#T@87)R87DH
M*3L*("`@('T*"B`@("`O*BH*("`@("H@9V5T1&%T82@I"B`@("`J"B`@("`J
M(%5S92!T:&ES('1O(&=E="!A(')E9F5R96YC92!T;R!T:&4@9&%T82!T;R!M
M86YI<'5L871E"B`@("`J(&EN(&-A;&QI;F<@<V-R:7!T+B!%9RX@)%]!4%`@
M/28@)&]B:BT^9V5T1&%T82@I.PH@("`@*@H@("`@*B!`<F5T=7)N(&UI>&5D
M("`@02!R969E<F5N8V4@=&\@=&AE(&1A=&$*("`@("HO"B`@("!F=6YC=&EO
M;B`F9V5T1&%T82@I"B`@("!["B`@("`@("`@<F5T=7)N("1T:&ES+3YD871A
M.PH@("`@?0I]"C\^````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+W!S82UH;W)D92]P96%R+T-A8VAE+T-O;G1A:6YE<B]D8BYP:'``````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,C(S,S`@,3`U,34T,S0Q,S(@
M,#(R-3`S`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\
M(%!%05(@.CH@0V%C:&4@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK"B\O('P@0V]P>7)I9VAT("AC*2`Q.3DW+3(P,#,@5&AE
M(%!(4"!'<F]U<"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`R+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\"B\O('P@=&AA="!I<R!B=6YD;&5D('=I=&@@=&AI
M<R!P86-K86=E(&EN('1H92!F:6QE($Q)0T5.4T4L(&%N9"!I<R`@("`@("`@
M?`HO+R!\(&%V86EL86)L92!A="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8B!A="`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!H='1P.B\O
M=W=W+G!H<"YN970O;&EC96YS92\R7S`R+G1X="X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\"B\O('P@268@>6]U(&1I9"!N;W0@<F5C96EV
M92!A(&-O<'D@;V8@=&AE(%!(4"!L:6-E;G-E(&%N9"!A<F4@=6YA8FQE('1O
M("`@?`HO+R!\(&]B=&%I;B!I="!T:')O=6=H('1H92!W;W)L9"UW:61E+7=E
M8BP@<&QE87-E('-E;F0@82!N;W1E('1O("`@("`@("`@('P*+R\@?"!L:6-E
M;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I;6UE9&EA
M=&5L>2X@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\($%U=&AO<G,Z(%5L9B!796YD96P@/'5L9BYW96YD96Q`
M<&AP9&]C+F1E/B`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"`@
M("`@("`@("!396)A<W1I86X@0F5R9VUA;FX@/'-B0'-E8F%S=&EA;BUB97)G
M;6%N;BYD93X@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@0VAU8VL@
M2&%G96YB=6-H(#QC:'5C:T!H;W)D92YO<F<^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\*
M+R\@)$ED.B!D8BYP:'`L=B`Q+C4@,C`P,R\P,2\P-"`Q,3HU-#HT-B!M:B!%
M>'`@)`H*<F5Q=6ER95]O;F-E("=$0BYP:'`G.PIR97%U:7)E7V]N8V4@)T-A
M8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@4$5!4B]$0B!#86-H92!#;VYT
M86EN97(N"BH**B!705).24Y'.B!/=&AE<B!S>7-T96US(&UI9VAT(&]R(&UI
M9VAT(&YO="!S=7!P;W)T(&-E<G1A:6X@9&%T871Y<&5S(&]F"BH@=&AE('1A
M8FQE<R!S:&]W;BX@07,@9F%R(&%S($D@:VYO=R!T:&5R92=S(&YO(&QA<F=E
M(&)I;F%R>0HJ('1Y<&4@:6X@4U%,+3DR(&]R(%-13"TY.2X@4&]S=&=R97,@
M<V5E;7,@=&\@;&%C:R!A;GD**B!"3$]"(&]R(%1%6%0@='EP92P@9F]R($U3
M+5-13"!Y;W4@8V]U;&0@=7-E($E-04=%+"!D;VXG="!K;F]W"BH@86)O=70@
M;W1H97(@9&%T86)A<V5S+B!0;&5A<V4@861D('-U9V5S=&EO;G,@9F]R(&]T
M:&5R(&1A=&%B87-E<R!T;PHJ('1H92!I;FQI;F4@9&]C<RX**@HJ(%1H92!F
M:65L9"`G8VAA;F=E9"<@:&%S(&YO(&UE86YI;F<@9F]R('1H92!#86-H92!I
M='-E;&8N($ET)W,@:G5S="!T:&5R90HJ(&)E8V%U<V4@:70G<R!A(&=O;V0@
M:61E82!T;R!H879E(&%N(&%U=&]M871I8V%L;'D@=7!D871E9"!T:6UE<W1A
M;7`**B!F:65L9"!F;W(@9&5B=6=G:6YG(&EN(&%L;"!O9B!Y;W5R('1A8FQE
M<RX**@HJ($9O<B!?37E344Q?('EO=2!N965D('1H:7,@1$(@=&%B;&4Z"BH*
M*B!#4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@:60@("`@("`@("`@0TA!4B@S
M,BD@3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A8VAE9W)O=7`@(%9!4D-(
M05(H,3(W*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@8V%C:&5D871A("`@
M0DQ/0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@=7-E<F1A=&$@("`@5D%2
M0TA!4B@R-34I($Y/5"!.54Q,($1%1D%53"`G)RP**B`@(&5X<&ER97,@("`@
M($E.5"@Y*2!.3U0@3E5,3"!$149!54Q4(#`L"BH**B`@(&-H86YG960@("`@
M(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"BH**B`@($E.1$58("AE>'!I<F5S
M*2P**B`@(%!224U!4ED@2T59("AI9"P@8V%C:&5G<F]U<"D**B`I"BH**B!`
M875T:&]R("`@4V5B87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R
M9VUA;FXN9&4^"BH@0'9E<G-I;VX@("1)9#H@9&(N<&AP+'8@,2XU(#(P,#,O
M,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0**B!`<&%C:V%G92`@0V%C:&4**B\*
M8VQA<W,@0V%C:&5?0V]N=&%I;F5R7V1B(&5X=&5N9',@0V%C:&5?0V]N=&%I
M;F5R('L*"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@1$(@=&%B;&4@=&\@
M<W1O<F4@8V%C:&EN9R!D871A"B`@("`J"B`@("`J($!S964@($-A8VAE7T-O
M;G1A:6YE<E]F:6QE.CHD9FEL96YA;65?<')E9FEX"B`@("`J+PH@("`@=F%R
M("1C86-H95]T86)L92`]("<G.PH*("`@("\J*@H@("`@*B!014%2($1"(&1S
M;B!T;R!U<V4N"B`@("`J"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@
M('9A<B`D9'-N(#T@)R<["@H@("`@+RHJ"B`@("`J(%!%05(@1$(@;V)J96-T
M"B`@("`J"B`@("`J($!V87(@(&]B:F5C="!014%27T1""B`@("`J+PH@("`@
M=F%R("1D8CL*"B`@("!F=6YC=&EO;B!#86-H95]#;VYT86EN97)?9&(H)&]P
M=&EO;G,I"B`@("!["B`@("`@("`@:68@*"%I<U]A<G)A>2@D;W!T:6]N<RD@
M?'P@(6ES<V5T*"1O<'1I;VYS6R=D<VXG72DI('L*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@G3F\@9'-N('-P96-I9FEE9"$G+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/G-E
M=$]P=&EO;G,H)&]P=&EO;G,L("!A<G)A>5]M97)G92@D=&AI<RT^86QL;W=E
M9%]O<'1I;VYS+"!A<G)A>2@G9'-N)RP@)V-A8VAE7W1A8FQE)RDI*3L*"B`@
M("`@("`@:68@*"$D=&AI<RT^9'-N*0H@("`@("`@("`@("!R971U<FX@;F5W
M($-A8VAE7T5R<F]R*"=.;R!D<VX@<W!E8VEF:65D(2<L(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["@H@("`@("`@("1T:&ES+3YD8B`]($1".CIC;VYN96-T*"1T
M:&ES+3YD<VXL('1R=64I.PH@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D=&AI
M<RT^9&(I*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H
M)T1".CIC;VYN96-T(&9A:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H)'1H
M:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^9&(M/G-E=$9E=&-H36]D92A$0E]&151#
M2$U/1$5?05-33T,I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!F
M971C:"@D:60L("1G<F]U<"D*("`@('L*("`@("`@("`D<75E<GD@/2!S<')I
M;G1F*")314Q%0U0@8V%C:&5D871A+"!U<V5R9&%T82P@97AP:7)E<R!&4D]-
M("5S(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@
M("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D:60I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D9W)O=7`I"B`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M
M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1"
M.CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D<F]W(#T@)')E<RT^9F5T
M8VA2;W<H*3L*("`@("`@("!I9B`H:7-?87)R87DH)')O=RDI"B`@("`@("`@
M("`@("1D871A(#T@87)R87DH)')O=ULG97AP:7)E<R==+"`D=&AI<RT^9&5C
M;V1E*"1R;W=;)V-A8VAE9&%T82==*2P@)')O=ULG=7-E<F1A=&$G72D["B`@
M("`@("`@96QS90H@("`@("`@("`@("`D9&%T82`](&%R<F%Y*$Y53$PL($Y5
M3$PL($Y53$PI.PH*("`@("`@("`O+R!L87-T('5S960@<F5Q=6ER960@8GD@
M=&AE(&=A<F)A9V4@8V]L;&5C=&EO;@H@("`@("`@("\O(%=!4DY)3D<Z(&UI
M9VAT(&)E($UY4U%,('-P96-I9FEC"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@B55!$051%("5S(%-%5"!C:&%N9V5D(#T@*$Y/5R@I("L@,"D@5TA%4D4@
M:60@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@
M("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M
M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1"
M.CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!R971U<FX@)&1A=&$["B`@
M("!]"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@("`J"B`@
M("`J(%=!4DY)3D<Z('=E('5S92!T:&4@4U%,(&-O;6UA;F0@4D503$%#12!)
M3E1/('1H:7,@;6EG:'0@8F4*("`@("H@37E344P@<W!E8VEF:6,N($%S($UY
M4U%,(&ES('9E<GD@<&]P=6QA<B!T:&4@;65T:&]D('-H;W5L9`H@("`@*B!W
M;W)K(&9I;F4@9F]R(#DU)2!O9B!Y;W4N"B`@("`J+PH@("`@9G5N8W1I;VX@
M<V%V92@D:60L("1D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I
M"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U
M<"D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E)%4$Q!0T4@24Y43R`E
M<R`H=7-E<F1A=&$L(&-A8VAE9&%T82P@97AP:7)E<RP@:60L(&-A8VAE9W)O
M=7`I(%9!3%5%4R`H)R5S)RP@)R5S)RP@)60L("<E<R<L("<E<R<I(BP*("`@
M("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@
M("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)'5S97)D871A*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@(&%D9'-L87-H97,H)'1H:7,M/F5N
M8V]D92@D9&%T82DI+`H@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YG971%>'!I<F5S06)S;VQU=&4H)&5X<&ER97,I("P*("`@("`@("`@("`@
M("`@("`@("`@("`@(&%D9'-L87-H97,H)&ED*2P*("`@("`@("`@("`@("`@
M("`@("`@("`@(&%D9'-L87-H97,H)&=R;W5P*0H@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D
M<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<RDI('L*("`@
M("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A
M:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H)')E<RD@+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!R96UO
M=F4H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E
M;&]A9"@D:60L("1G<F]U<"D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H
M(D1%3$5412!&4D]-("5S(%=(15)%(&ED(#T@)R5S)R!A;F0@8V%C:&5G<F]U
M<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A
M8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE
M<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D
M9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1R
M97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@(&EF("A$
M0CHZ:7-%<G)O<B@D<F5S*2D*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A
M9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@("`@9G5N
M8W1I;VX@9FQU<V@H)&=R;W5P(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M
M/F9L=7-H4')E;&]A9"@I.PH*("`@("`@("`@:68@*"1G<F]U<"D@>PH@("`@
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*")$14Q%5$4@1E)/32`E<R!72$52
M12!C86-H96=R;W5P(#T@)R5S)R(L("1T:&ES+3YC86-H95]T86)L92P@861D
M<VQA<VAE<R@D9W)O=7`I*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`D<75E<GD@/2!S<')I;G1F*")$14Q%5$4@1E)/32`E<R(L("1T:&ES+3YC
M86-H95]T86)L92D["B`@("`@("`@?0H*("`@("`@("`D<F5S(#T@)'1H:7,M
M/F1B+3YQ=65R>2@D<75E<GDI.PH*("`@("`@("!I9B`H1$(Z.FES17)R;W(H
M)')E<RDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1"
M.CIQ=65R>2!F86EL960Z("<@+B!$0CHZ97)R;W)-97-S86=E*"1R97,I+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@?0H*("`@(&9U;F-T:6]N(&ED17AI
M<W1S*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H(E-%3$5#5"!I9"!&4D]-("5S(%=(15)%($E$(#T@)R5S)R!!3D0@8V%C
M:&5G<F]U<"`]("<E<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H
M:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D
M<VQA<VAE<R@D:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA
M<VAE<R@D9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@
M("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@
M(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D*("`@("`@("`@("`@<F5T=7)N(&YE
M=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O
M<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@
M("1R;W<@/2`D<F5S+3YF971C:%)O=R@I.PH*("`@("`@("!I9B`H:7-?87)R
M87DH)')O=RDI('L*("`@("`@("`@("`@<F5T=7)N('1R=64["B`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@("`@('T*
M("`@('T*"B`@("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF
M971I;64I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH*
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=$14Q%5$4@1E)/32`E<R!72$52
M12`H97AP:7)E<R`\/2`E9"!!3D0@97AP:7)E<R`^(#`I($]2(&-H86YG960@
M/#T@)60G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@=&EM92@I+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@=&EM92@I("T@)&UA>&QI9F5T:6UE"B`@
M("`@("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<R`]("1T:&ES
M+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G<V5L96-T('-U;2AL96YG=&@H8V%C:&5D871A*2D@87,@0V%C:&53:7IE
M(&9R;VT@)7,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A
M8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`D
M8V%C:&5S:7IE(#T@)'1H:7,M/F1B+3Y'971/;F4H)'%U97)Y*3L*("`@("`@
M("!I9B`H1$(Z.FES17)R;W(H)&-A8VAE<VEZ92DI('L*("`@("`@("`@("`@
M<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z.G%U97)Y(&9A:6QE9#H@)R`N
M($1".CIE<G)O<DUE<W-A9V4H)&-A8VAE<VEZ92DL(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+VEF(&-A8VAE(&ES('1O(&)I
M9RX*("`@("`@("!I9B`H)&-A8VAE<VEZ92`^("1T:&ES+3YH:6=H=V%T97(I
M"B`@("`@("`@>PH@("`@("`@("`@("`O+V9I;F0@=&AE(&QO=W=A=&5R(&UA
M<FLN"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C="!L96YG
M=&@H8V%C:&5D871A*2!A<R!S:7IE+"!C:&%N9V5D(&9R;VT@)7,@;W)D97(@
M8GD@8VAA;F=E9"!$15-#)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@
M("`@("`@("D["B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^9&(M/G%U97)Y
M*"1Q=65R>2D["B`@("`@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@
M>PH@("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$(Z
M.G%U97)Y(&9A:6QE9#H@)R`N($1".CIE<G)O<DUE<W-A9V4H)')E<RDL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@
M("1N=6UR;W=S(#T@)'1H:7,M/F1B+3YN=6U2;W=S*"1R97,I.PH@("`@("`@
M("`@("`D:V5E<%]S:7IE(#T@,#L*("`@("`@("`@("`@=VAI;&4@*"1K965P
M7W-I>F4@/"`D=&AI<RT^;&]W=V%T97(@)B8@)&YU;7)O=W,M+2D@>PH@("`@
M("`@("`@("`@("`@)&5N=')Y(#T@)')E<RT^9F5T8VA2;W<H1$)?1D540TA-
M3T1%7T%34T]#*3L*("`@("`@("`@("`@("`@("1K965P7W-I>F4@*ST@)&5N
M=')Y6R=S:7IE)UT["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O9&5L
M971E(&%L;"!E;G1R:65S+"!W:&EC:"!W97)E(&-H86YG960@8F5F;W)E('1H
M92`B;&]W=W=A=&5R(&UA<FLB"B`@("`@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H)V1E;&5T92!F<F]M("5S('=H97)E(&-H86YG960@/#T@)RXH)&5N=')Y
M6R=C:&%N9V5D)UT@/R`D96YT<GE;)V-H86YG960G72`Z(#`I+`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@
M("`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@
M("`@("!]"@H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@("`@
M("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0CHZ<75E<GD@9F%I
M;&5D.B`G("X@1$(Z.F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"B`@("!]"@I]"C\^"@``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H
M92]#;VYT86EN97(O;61B+G!H<```````````````````````````````````
M`````````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#,S,C$T(#$P-3$U-#,T,3,R(#`R,C8V,P`@,```````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````\/W!H<`HO+R`K+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE(#HZ($U$
M0B!#;VYT86EN97(@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O
M<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O
M('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\
M('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL
M92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O
M,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO
M+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@
M;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@
M=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T
M92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A
M;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@
M?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!.;W1E.B!4
M:&ES(&ES(&$@341"+6]R:65N=&5D(')E=W)I=&4@;V8@0V%C:&4O0V]N=&%I
M;F5R+V1B+G!H<"X@("`@("!\"B\O('P@5&AA;FMS('1O($QU:V%S(%-M:71H
M(&9O<B!H:7,@<&%T:65N8V4@:6X@86YS=V5R:6YG(&UY('%U97-T:6]N<R`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H
M;W(Z($QO<F5N>F\@06QB97)T;VX@/&PN86QB97)T;VX@870@<75I<&\N:70^
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+PHO+R`D260Z(&UD8BYP:'`L=B`Q+C,@,C`P,R\P,2\P-"`Q
M,3HU-#HT-B!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=-1$(N<&AP)SL*<F5Q
M=6ER95]O;F-E("=#86-H92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ(%!%05(O
M341"($-A8VAE($-O;G1A:6YE<BX**@HJ($Y".B!4:&4@9FEE;&0@)V-H86YG
M960G(&AA<R!N;R!M96%N:6YG(&9O<B!T:&4@0V%C:&4@:71S96QF+B!)="=S
M(&IU<W0@=&AE<F4**B!B96-A=7-E(&ET)W,@82!G;V]D(&ED96$@=&\@:&%V
M92!A;B!A=71O;6%T:6-A;&QY('5P9&%T960@=&EM97-T86UP"BH@9FEE;&0@
M9F]R(&1E8G5G9VEN9R!I;B!A;&P@;V8@>6]U<B!T86)L97,N"BH**B!!(%A-
M3"!-1$(M8V]M<&QI86YT('-C:&5M82!E>&%M<&QE(&9O<B!T:&4@=&%B;&4@
M;F5E9&5D(&ES('!R;W9I9&5D+@HJ($QO;VL@870@=&AE(&9I;&4@(FUD8E]C
M86-H95]S8VAE;6$N>&UL(B!F;W(@=&AA="X**@HJ("TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+0HJ($$@8F%S:6,@=7-A9V4@
M97AA;7!L93H**B`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2T**@HJ("1D8FEN9F\@/2!A<G)A>2@**B`@("=D871A8F%S92<@
M("`@/3X@)V1B;F%M92<L"BH@("`G<&AP='EP92<@("`@(#T^("=M>7-Q;"<L
M"BH@("`G=7-E<FYA;64G("`@(#T^("=R;V]T)RP**B`@("=P87-S=V]R9"<@
M("`@/3X@)R<L"BH@("`G8V%C:&5?=&%B;&4G(#T^("=C86-H92<**B`I.PHJ
M"BH**B`D8V%C:&4@/2!N97<@0V%C:&4H)VUD8B<L("1D8FEN9F\I.PHJ("1I
M9"`]("1C86-H92T^9V5N97)A=&5)1"@G=&5S=&5N=')Y)RD["BH**B!I9B`H
M)&1A=&$@/2`D8V%C:&4M/F=E="@D:60I*2!["BH@("`@96-H;R`G0V%C:&4@
M:&ET+CQB<B`O/D1A=&$Z("<N)&1A=&$["BH**B!](&5L<V4@>PHJ("`@)&1A
M=&$@/2`G9&%T82!O9B!A;GD@:VEN9"<["BH@("`D8V%C:&4M/G-A=F4H)&ED
M+"`D9&%T82D["BH@("!E8VAO("=#86-H92!M:7-S+CQB<B`O/B<["BH@?0HJ
M"BH@+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M"BH**B!`875T:&]R("`@3&]R96YZ;R!!;&)E<G1O;B`\;"YA;&)E<G1O;B!A
M="!Q=6EP;RYI=#X**B!`=F5R<VEO;B`@)$ED.B!M9&(N<&AP+'8@,2XS(#(P
M,#,O,#$O,#0@,3$Z-30Z-#8@;6H@17AP("0**B!`<&%C:V%G92`@0V%C:&4*
M*B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R7VUD8B!E>'1E;F1S($-A8VAE7T-O
M;G1A:6YE<B!["@H@("`@+RHJ"B`@("`@*B!.86UE(&]F('1H92!-1$(@=&%B
M;&4@=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@("`@*@H@("`@("H@0'-E92`@
M0V%C:&5?0V]N=&%I;F5R7V9I;&4Z.B1F:6QE;F%M95]P<F5F:7@*("`@("`J
M+PH@("`@=F%R("1C86-H95]T86)L92`]("<G.PH*("`@("\J*@H@("`@("H@
M4$5!4B!-1$(@;V)J96-T"B`@("`@*@H@("`@("H@0'9A<B`@;V)J96-T(%!%
M05)?341""B`@("`@*B\*("`@('9A<B`D9&(["@H@("`@+RHJ"B`@("`@*B!#
M;VYS=')U8W1O<@H@("`@("H*("`@("`J($!P87)A;2!M:7AE9"!!<G)A>2!W
M:71H(&-O;FYE8W1I;VX@:6YF;R!O<B!D<VX@<W1R:6YG"B`@("`@*B\*("`@
M(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]M9&(H)&]P=&EO;G,I"B`@("![
M"B`@("`@("`@)'1H:7,M/F1B(#T@)DU$0CHZ0V]N;F5C="@D;W!T:6]N<RD[
M"B`@("`@("`@:68H341".CII<T5R<F]R*"1T:&ES+3YD8BDI('L*("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.F-O;FYE8W0@9F%I
M;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@+B`D=&AI<RT^9&(M/F=E=$UE
M<W-A9V4H*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`D=&AI<RT^9&(M/G-E=$9E=&-H36]D92A-1$)?1D54
M0TA-3T1%7T%34T]#*3L*("`@("`@("!]"B`@("`@("`@)'1H:7,M/G-E=$]P
M=&EO;G,H)&]P=&EO;G,L(&%R<F%Y7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P
M=&EO;G,L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@87)R87DH)V1S;B<L("=C86-H95]T86)L92<I*2D["B`@("!]"@H@("`@
M+RHJ"B`@("`@*B!&971C:"!I;B!T:&4@9&(@=&AE(&1A=&$@=&AA="!M871C
M:&5S(&EN<'5T('!A<F%M971E<G,*("`@("`J"B`@("`@*B!`<&%R86T@("`@
M<W1R:6YG("!D871A<V5T($E$"B`@("`@*B!`<&%R86T@("`@<W1R:6YG("!C
M86-H92!G<F]U<`H@("`@("H@0')E='5R;B`@(&UI>&5D("`@9&%T87-E="!V
M86QU92!O<B!.54Q,+T-A8VAE7T5R<F]R(&]N(&9A:6QU<F4*("`@("`J($!A
M8V-E<W,@("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8V@H)&ED
M+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'%U97)Y(#T@)U-%3$5#5"!C86-H
M961A=&$@1E)/32`G("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@
M("`@("`N)R!72$5212!I9#TG("`@("`@("X@)'1H:7,M/F1B+3YG971497AT
M5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@+B<@04Y$(&-A8VAE9W)O=7`]
M)R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1G<F]U<"D["B`@("`@("`@
M:68H)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*2D@>PH@("`@("`@
M("`@("!I9B@D=&AI<RT^9&(M/F5N9$]F4F5S=6QT*"1R97,I*2!["B`@("`@
M("`@("`@("`@("`O+VYO(')O=W,@<F5T=7)N960*("`@("`@("`@("`@("`@
M("1D871A(#T@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D8VQO8B`]("1T:&ES+3YD8BT^
M9F5T8VA#;&]B*"1R97,L,"PG8V%C:&5D871A)RD["B`@("`@("`@("`@("`@
M("!I9B@A341".CII<T5R<F]R*"1C;&]B*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1C86-H961?9&%T82`]("<G.PH@("`@("`@("`@("`@("`@("`@('=H
M:6QE*"$D=&AI<RT^9&(M/F5N9$]F3$]"*"1C;&]B*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("!I9BA-1$(Z.FES17)R;W(H)&5R<F]R(#T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1B+3YR96%D
M3&]B*"1C;&]B+"1D871A+#@P,#`I/#`I*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U97)Y
M(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`N("1E<G)O<BT^9V5T365S<V%G92@I+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("1C86-H961?9&%T82`N/2`D9&%T83L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@=6YS970H)&1A=&$I.PH@("`@
M("`@("`@("`@("`@("`@("1T:&ES+3YD8BT^9&5S=')O>4QO8B@D8VQO8BD[
M"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F1B+3YF<F5E4F5S=6QT*"1R
M97,I.PH*("`@("`@("`@("`@("`@("`@("`O+V9I;FES:&5D(&9E=&-H:6YG
M($Q/0BP@;F]W(&9E=&-H(&]T:&5R(&9I96QD<RXN+@H@("`@("`@("`@("`@
M("`@("`@("1Q=65R>2`]("=314Q%0U0@=7-E<F1A=&$L(&5X<&ER97,@1E)/
M32`G("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`N)R!72$5212!I9#TG("`@("`@("X@)'1H:7,M/F1B+3YG9714
M97AT5F%L=64H)&ED*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+B<@
M04Y$(&-A8VAE9W)O=7`])R`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E*"1G
M<F]U<"D["B`@("`@("`@("`@("`@("`@("`@:68H)')E<R`]("1T:&ES+3YD
M8BT^<75E<GDH)'%U97)Y*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`D
M<F]W(#T@)'1H:7,M/F1B+3YF971C:$EN=&\H)')E<RD["B`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]A<G)A>2@D<F]W*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2@*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R;W=;)V5X<&ER97,G72P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3YD96-O9&4H)&-A8VAE9%]D871A*2P*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R;W=;)W5S97)D871A)UT*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1D871A(#T@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`D9&%T82`](&%R<F%Y*$Y53$PL($Y5
M3$PL($Y53$PI.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#
M86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`N("1C;&]B+3YG971-97-S86=E*"DL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)'1H:7,M/F1B+3YF<F5E4F5S=6QT*"1R97,I.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@+R\@
M("`@("`@("`@+B`D<F5S=6QT+3YG971-97-S86=E*"DL(%]?1DE,15]?+"!?
M7TQ)3D5?7RD["B`@("`@("`@("`@("1D871A(#T@87)R87DH3E5,3"P@3E5,
M3"P@3E5,3"D["B`@("`@("`@?0H*("`@("`@("`O+R!L87-T('5S960@<F5Q
M=6ER960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;@H@("`@("`@("1Q=65R
M>2`]("=54$1!5$4@)R`@("`@("`@("`N("1T:&ES+3YC86-H95]T86)L90H@
M("`@("`@("`@("`@("`@+B<@4T54(&-H86YG960])R`@("`N('1I;64H*0H@
M("`@("`@("`@("`@("`@+B<@5TA%4D4@:60])R`@("`@("`N("1T:&ES+3YD
M8BT^9V5T5&5X=%9A;'5E*"1I9"D*("`@("`@("`@("`@("`@("XG($%.1"!C
M86-H96=R;W5P/2<@+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D9W)O=7`I
M.PH*("`@("`@("`D<F5S(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@
M("`@("`@(&EF("A-1$(Z.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@
M<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*
M("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B+3YE<G)O<DUE<W-A9V4H)')E
M<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@(')E
M='5R;B`D9&%T83L*("`@('T*"B`@("\J*@H@("`@("H@4W1O<F5S(&$@9&%T
M87-E="!I;B!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!)9B!D871A<V5T
M7TE$(&%L<F5A9'D@97AI<W1S+"!O=F5R=W)I=&4@:70@=VET:"!N97<@9&%T
M82P*("`@("`J(&5L<V4@:6YS97)T(&1A=&$@:6X@82!N97<@<F5C;W)D+@H@
M("`@("H*("`@("`J($!P87)A;2`@("!S=')I;F<@(&1A=&%S970@240*("`@
M("`J($!P87)A;2`@("!M:7AE9"`@(&1A=&$@=&\@8F4@8V%C:&5D"B`@("`@
M*B!`<&%R86T@("`@:6YT96=E<B!E>'!I<F%T:6]N('1I;64*("`@("`J($!P
M87)A;2`@("!S=')I;F<@(&-A8VAE(&=R;W5P"B`@("`@*B!`<&%R86T@("`@
M<W1R:6YG("!U<V5R9&%T80H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@
M("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F5S+"`D
M9W)O=7`L("1U<V5R9&%T82D*("`@('L*("`@("`@("!G;&]B86P@)&1B.PH@
M("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@
M("`@("`D9FEE;&1S(#T@87)R87DH"B`@("`@("`@("`@("=I9"<@("`@("`@
M(#T^(&%R<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1Y<&4G
M("`@/3X@)W1E>'0G+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U9A
M;'5E)R`@/3X@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)TME
M>2<@("`@/3X@=')U90H@("`@("`@("`@("`@("`@("`@("`@("`I+`H@("`@
M("`@("`@("`G=7-E<F1A=&$G("`]/B!A<G)A>2@*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("=4>7!E)R`@(#T^("=I;G1E9V5R)RP*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("=686QU92<@(#T^("1U<V5R9&%T82P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("=.=6QL)R`@(#T^("@D=7-E<F1A
M=&$@/R!F86QS92`Z('1R=64I"B`@("`@("`@("`@("`@("`@("`@("`@("DL
M"B`@("`@("`@("`@("=E>'!I<F5S)R`@(#T^(&%R<F%Y*`H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)U1Y<&4G("`@/3X@)VEN=&5G97(G+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)U9A;'5E)R`@/3X@)'1H:7,M/F=E
M=$5X<&ER97-!8G-O;'5T92@D97AP:7)E<RD*("`@("`@("`@("`@("`@("`@
M("`@("`@*2P*("`@("`@("`@("`@)V-A8VAE9W)O=7`G(#T^(&%R<F%Y*`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)U1Y<&4G("`@/3X@)W1E>'0G
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)U9A;'5E)R`@/3X@)&=R
M;W5P"B`@("`@("`@("`@("`@("`@("`@("`@("D*("`@("`@("`@("`@*3L*
M"B`@("`@("`@)')E<W5L="`]("1T:&ES+3YD8BT^<F5P;&%C92@D=&AI<RT^
M8V%C:&5?=&%B;&4L("1F:65L9',I.PH*("`@("`@("!I9BA-1$(Z.FES17)R
M;W(H)')E<W5L="DI('L*("`@("`@("`@("`@+R]687)?1'5M<#HZ9&ES<&QA
M>2@D<F5S=6QT*3L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("`N
M("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R97-U;'0I+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("!U;G-E="@D9FEE;&1S*3L@
M+R]E;F0@9FER<W0@<&%R="!O9B!Q=65R>0H@("`@("`@("1Q=65R>3(@/2`G
M55!$051%("<@("`N("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@
M("`@("XG(%-%5"!C86-H961A=&$]/R<*("`@("`@("`@("`@("`@("`N)R!7
M2$5212!I9#TG+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D:60I.PH*("`@
M("`@("!I9B@H)'!R97!A<F5D7W%U97)Y(#T@)'1H:7,M/F1B+3YP<F5P87)E
M475E<GDH)'%U97)Y,BDI*2!["B`@("`@("`@("`@("1C:&%R7VQO8B`](&%R
M<F%Y*`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)T5R<F]R)R`]/B`G
M)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("=4>7!E)R`]/B`G9&%T
M82<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`G1&%T82<@/3X@)'1H
M:7,M/F5N8V]D92@D9&%T82D*("`@("`@("`@("`@("`@("`@("`@("`@*3L*
M("`@("`@("`@("`@:68H(4U$0CHZ:7-%<G)O<B@D8VQO8B`]("1T:&ES+3YD
M8BT^8W)E871E3&]B*"1C:&%R7VQO8BDI*2!["B`@("`@("`@("`@("`@("`D
M=&AI<RT^9&(M/G-E=%!A<F%M0VQO8B@D<')E<&%R961?<75E<GDL,2PD8VQO
M8BPG8V%C:&5D871A)RD["B`@("`@("`@("`@("`@("!I9BA-1$(Z.FES17)R
M;W(H)&5R<F]R/21T:&ES+3YD8BT^97AE8W5T95%U97)Y*"1P<F5P87)E9%]Q
M=65R>2DI*2!["B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("X@)&5R<F]R+3YG971-97-S86=E*"D@+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@)'1H:7,M/F1B+3YD97-T<F]Y3&]B*"1C;&]B*3L*("`@("`@("`@("`@
M?2!E;'-E('L*("`@("`@("`@("`@("`@("\O(&-R96%T:6]N(&]F('1H92!H
M86YD;&5R(&]B:F5C="!F86EL960*("`@("`@("`@("`@("`@(')E='5R;B!N
M97<@0V%C:&5?17)R;W(H)TU$0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@
M("`@("`@("`@("`@("`@("X@)&-L;V(M/F=E=$UE<W-A9V4H*2`L(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@)'1H
M:7,M/F1B+3YF<F5E4')E<&%R9611=65R>2@D<')E<&%R961?<75E<GDI.PH@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O<')E<&%R960@<75E<GD@
M9F%I;&5D"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$
M0CHZ<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`@+B`D<')E
M<&%R961?<75E<GDM/F=E=$UE<W-A9V4H*2`L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?0H@("`@?0H*("`@("\J*@H@("`@("H@4F5M;W9E<R!A
M(&1A=&%S970@9G)O;2!T:&4@9&%T86)A<V4*("`@("`J"B`@("`@*B!`<&%R
M86T@("`@<W1R:6YG("!D871A<V5T($E$"B`@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!C86-H92!G<F]U<`H@("`@("HO"B`@("!F=6YC=&EO;B!R96UO=F4H
M)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A
M9"@D:60L("1G<F]U<"D["@H@("`@("`@("1Q=65R>2`]("=$14Q%5$4@1E)/
M32`G("`@("`N("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@
M+B<@5TA%4D4@:60])R`@("`@("`N("1T:&ES+3YD8BT^9V5T5&5X=%9A;'5E
M*"1I9"D*("`@("`@("`@("`@("`@("XG($%.1"!C86-H96=R;W5P/2<@+B`D
M=&AI<RT^9&(M/F=E=%1E>'1686QU92@D9W)O=7`I.PH*("`@("`@("`D<F5S
M(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("A-1$(Z
M.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@
M("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*"B`@("`O*BH*("`@("`J
M(%)E;6]V92!A;&P@8V%C:&5D(&1A=&$@9F]R(&$@8V5R=&%I;B!G<F]U<"P@
M;W(@96UP='D*("`@("`J('1H92!C86-H92!T86)L92!I9B!N;R!G<F]U<"!I
M<R!S<&5C:69I960N"B`@("`@*@H@("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M8V%C:&4@9W)O=7`*("`@("`J+PH@("`@9G5N8W1I;VX@9FQU<V@H)&=R;W5P
M(#T@)R<I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH*
M("`@("`@("!I9B`H)&=R;W5P*2!["B`@("`@("`@("`@("1Q=65R>2`]("=$
M14Q%5$4@1E)/32`G("`@("`@("X@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@
M("`@("`@("`@("`@("`@+B<@5TA%4D4@8V%C:&5G<F]U<#TG("X@)'1H:7,M
M/F1B+3YG971497AT5F%L=64H)&=R;W5P*3L*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N("1T:&ES+3YC
M86-H95]T86)L93L*("`@("`@("!]"@H@("`@("`@("1R97,@/2`D=&AI<RT^
M9&(M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D
M<F5S*2D@>PH@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-
M1$(Z.G%U97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@+B`D=&AI<RT^
M9&(M/F5R<F]R365S<V%G92@D<F5S*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"B`@("!]"@H@("`@+RHJ"B`@("`@*B!#:&5C:R!I9B!A(&1A
M=&%S970@240O9W)O=7`@97AI<W1S+@H@("`@("H*("`@("`J($!P87)A;2`@
M("!S=')I;F<@(&1A=&%S970@240*("`@("`J($!P87)A;2`@("!S=')I;F<@
M(&-A8VAE(&=R;W5P"B`@("`@*B!`<F5T=7)N("`@8F]O;&5A;@H@("`@("HO
M"B`@("!F=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D*("`@('L*("`@
M("`@("`D<75E<GD@/2`G4T5,14-4(&ED($923TT@)R`@+B`D=&AI<RT^8V%C
M:&5?=&%B;&4*("`@("`@("`@("`@("`@("XG(%=(15)%(&ED/2<@("`@("`@
M+B`D=&AI<RT^9&(M/F=E=%1E>'1686QU92@D:60I"B`@("`@("`@("`@("`@
M("`N)R!!3D0@8V%C:&5G<F]U<#TG("X@)'1H:7,M/F1B+3YG971497AT5F%L
M=64H)&=R;W5P*3L*("`@("`@("!E8VAO("1Q=65R>3L*("`@("`@("`D<F5S
M(#T@)'1H:7,M/F1B+3YQ=65R>2@D<75E<GDI.PH@("`@("`@(&EF("A-1$(Z
M.FES17)R;W(H)')E<RDI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@
M("`@("`N("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@("`@("`D<F]W(#T@)'1H:7,M
M/F1B+3YF971C:$EN=&\H)')E<RD["@H@("`@("`@(&EF("AI<U]A<G)A>2@D
M<F]W*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@("`@
M?0H*("`@("\J*@H@("`@("H@1V%R8F%G92!C;VQL96-T;W(N"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@(&EN="!M87AL:69E=&EM90H@("`@("HO"B`@("!F
M=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64I"B`@("![
M"B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@("`@("1Q=65R
M>2`]("=$14Q%5$4@1E)/32`G("`@("`@("`N("1T:&ES+3YC86-H95]T86)L
M90H@("`@("`@("`@("`@("`@+B<@5TA%4D4@*&5X<&ER97,@/#T@)R`N('1I
M;64H*0H@("`@("`@("`@("`@("`@+B<@04Y$(&5X<&ER97,@/B`P*2!/4B!C
M:&%N9V5D(#P]("<N('1I;64H*2`M("1M87AL:69E=&EM93L*"B`@("`@("`@
M)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*"B`@("`@("`@)'%U
M97)Y(#T@)U-%3$5#5"!S=6TH;&5N9W1H*&-A8VAE9&%T82DI(&%S($-A8VAE
M4VEZ92!&4D]-("<*("`@("`@("`@("`@("`@("X@)'1H:7,M/F-A8VAE7W1A
M8FQE.PH*("`@("`@("`D8V%C:&5S:7IE(#T@)'1H:7,M/F1B+3YG971/;F4H
M)'%U97)Y*3L*("`@("`@("!I9B`H341".CII<T5R<F]R*"1C86-H97-I>F4I
M*2!["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H)TU$0CHZ
M<75E<GD@9F%I;&5D.B`G"B`@("`@("`@("`@("`@("`@("`N("1T:&ES+3YD
M8BT^97)R;W)-97-S86=E*"1C86-H97-I>F4I+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@("`@("`O+VEF(&-A8VAE(&ES('1O(&)I9RX*
M("`@("`@("!I9B`H)&-A8VAE<VEZ92`^("1T:&ES+3YH:6=H=V%T97(I"B`@
M("`@("`@>PH@("`@("`@("`@("`O+V9I;F0@=&AE(&QO=W=A=&5R(&UA<FLN
M"B`@("`@("`@("`@("1Q=65R>2`]("=314Q%0U0@;&5N9W1H*&-A8VAE9&%T
M82D@87,@<VEZ92P@8VAA;F=E9"!&4D]-("<*("`@("`@("`@("`@("`@("`@
M("`N("1T:&ES+3YC86-H95]T86)L92`N)R!/4D1%4B!"62!C:&%N9V5D($1%
M4T,G.PH*("`@("`@("`@("`@)')E<R`]("1T:&ES+3YD8BT^<75E<GDH)'%U
M97)Y*3L*("`@("`@("`@("`@:68@*$U$0CHZ:7-%<G)O<B@D<F5S*2D@>PH@
M("`@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=-1$(Z.G%U
M97)Y(&9A:6QE9#H@)PH@("`@("`@("`@("`@("`@("`@("X@)'1H:7,M/F1B
M+3YE<G)O<DUE<W-A9V4H)')E<RDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@)&YU;7)O=W,@/2`D=&AI<RT^9&(M
M/FYU;5)O=W,H)')E<RD["B`@("`@("`@("`@("1K965P7W-I>F4@/2`P.PH@
M("`@("`@("`@("!W:&EL92`H)&ME97!?<VEZ92`\("1T:&ES+3YL;W=W871E
M<B`F)B`D;G5M<F]W<RTM*2!["B`@("`@("`@("`@("`@("`D96YT<GD@/2`D
M=&AI<RT^9&(M/F9E=&-H26YT;R@D<F5S+$U$0E]&151#2$U/1$5?05-33T,I
M.PH@("`@("`@("`@("`@("`@)&ME97!?<VEZ92`K/2`D96YT<GE;)W-I>F4G
M73L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@+R]D96QE=&4@86QL(&5N
M=')I97,L('=H:6-H('=E<F4@8VAA;F=E9"!B969O<F4@=&AE(")L;W=W871E
M<B!M87)K(@H@("`@("`@("`@("`D<75E<GD@/2`G1$5,151%($923TT@)R`N
M("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@("`@("XG(%=(
M15)%(&-H86YG960\/2<N*"1E;G1R>5LG8VAA;F=E9"==(#\@)&5N=')Y6R=C
M:&%N9V5D)UT@.B`P*3L*"B`@("`@("`@("`@("1R97,@/2`D=&AI<RT^9&(M
M/G%U97)Y*"1Q=65R>2D["B`@("`@("`@("`@(&EF("A-1$(Z.FES17)R;W(H
M)')E<RDI('L*("`@("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O
M<B@G341".CIQ=65R>2!F86EL960Z("<*("`@("`@("`@("`@("`@("`@("`N
M("1T:&ES+3YD8BT^97)R;W)-97-S86=E*"1R97,I+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H*?0H_/@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O
M0V]N=&%I;F5R+V9I;&4N<&AP````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`S,30P-2`Q,#4Q-30S-#$S,B`P,C,P-#``(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y
M<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V
M97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T
M:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@
M3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?
M,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@
M?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI
M8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H
M<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@
M=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@
M;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*
M+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@
M56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\("`@("`@("`@(%-E8F%S=&EA;B!"97)G
M;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN+F1E/B`@("`@("`@("`@("`@
M('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@
M9FEL92YP:'`L=B`Q+C$S(#(P,#,O,#,O,C<@,3`Z-#@Z-#(@8VAR96=U($5X
M<"`D"@IR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ
M"BH@4W1O<F5S(&-A8VAE(&-O;G1E;G1S(&EN(&$@9FEL92X**@HJ($!A=71H
M;W(@("!5;&8@5V5N9&5L("`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^"BH@0'9E
M<G-I;VX@("1)9#H@9FEL92YP:'`L=B`Q+C$S(#(P,#,O,#,O,C<@,3`Z-#@Z
M-#(@8VAR96=U($5X<"`D"BHO"F-L87-S($-A8VAE7T-O;G1A:6YE<E]F:6QE
M(&5X=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*"B`@("`O*BH*("`@("H@1FEL
M92!L;V-K:6YG"B`@("`J"B`@("`J(%=I=&@@9FEL92!C;VYT86EN97(L(&ET
M)W,@<&]S<VEB;&4L('1H870@>6]U(&=E="!C;W)R=7!T960*("`@("H@9&%T
M82UE;G1R:65S('5N9&5R(&)A9"!C:7)C=6US=&%N8V5S+B!4:&4@9FEL92!L
M;V-K:6YG(&UU<W0*("`@("H@:6UP<F]V92!T:&ES('!R;V)L96T@8G5T(&ET
M)W,@97AP97)I;65N=&%L('-T=69F+B!3;R!T:&4*("`@("H@9&5F875L="!V
M86QU92!I<R!F86QS92X@0G5T(&ET('-E96US('1O(&=I=F4@9V]O9"!R97-U
M;'1S"B`@("`J"B`@("`J($!V87(@8F]O;&5A;@H@("`@*B\*("`@('9A<B`D
M9FEL94QO8VMI;F<@/2!F86QS93L*"B`@("`O*BH*("`@("H@1&ER96-T;W)Y
M('=H97)E('1O('!U="!T:&4@8V%C:&4@9FEL97,N"B`@("`J"B`@("`J($!V
M87(@('-T<FEN9R`@36%K92!S=7)E('1O(&%D9"!A('1R86EL:6YG('-L87-H
M"B`@("`J+PH@("`@=F%R("1C86-H95]D:7(@/2`G)SL*"B`@("`O*BH*("`@
M("H@1FEL96YA;64@<')E9FEX(&9O<B!C86-H92!F:6QE<RX*("`@("H*("`@
M("H@66]U(&-A;B!U<V4@=&AE(&9I;&5N86UE('!R969I>"!T;R!I;7!L96UE
M;G0@82`B9&]M86EN(B!B87-E9"!C86-H92!O<B!J=7-T"B`@("`J('1O(&=I
M=F4@=&AE(&9I;&5S(&$@;6]R92!D97-C<FEP=&EV92!N86UE+B!4:&4@=V]R
M9"`B9&]M86EN(B!I<R!B;W)R;V5D(&9R;VT*("`@("H@82!U<V5R(&%U=&AE
M;G1I9FEC871I;VX@<WES=&5M+B!/;F4@=7-E<B!I9"`H8V%C:&5D(&1A=&%S
M970@=VET:"!T:&4@240@>"D*("`@("H@;6%Y(&5X:7-T<R!I;B!D:69F97)E
M;G0@9&]M86EN<R`H9&EF9F5R96YT(&9I;&5N86UE('!R969I>"DN(%EO=2!M
M:6=H="!W86YT"B`@("`J('1O('5S92!T:&ES('1O(&AA=F4@9&EF9F5R96YT
M(&-A8VAE('9A;'5E<R!F;W(@82!P<F]D=6-T:6]N+"!D979E;&]P;65N="!A
M;F0*("`@("H@<75A;&ET>2!A<W-U<F%N8V4@<WES=&5M+B!)9B!Y;W4@=V%N
M="!T:&4@<')O9'5C=&EO;B!C86-H92!N;W0@=&\@8F4@:6YF;'5E;F-E9`H@
M("`@*B!B>2!T:&4@<75A;&ET>2!A<W-U<F%N8V4@86-T:79I=&EE<RP@=7-E
M(&1I9F9E<F5N="!F:6QE;F%M92!P<F5F:7AE<R!F;W(@=&AE;2X*("`@("H*
M("`@("H@22!P97)S;VYA;&QY(&1O;B=T('1H:6YK('1H870@>6]U)VQL(&YE
M=F5R(&YE960@=&AI<RP@8G5T(#8T,&MB(&AA<'!E;F0@=&\@8F4*("`@("H@
M;F]T(&5N;W5G:"P@<V\N+BX@>6]U(&MN;W<@=VAA="!)(&UE86XN($EF('EO
M=2!F:6YD(&$@=7-E9G5L(&%P<&QI8V%T:6]N(&]F('1H90H@("`@*B!F96%T
M=7)E('!L96%S92!U<&1A=&4@=&AI<R!I;FQI;F4@9&]C+@H@("`@*@H@("`@
M*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&9I;&5N86UE7W!R969I
M>"`]("<G.PH@("`@"B`@("`*("`@("\J*@H@("`@*B!,:7-T(&]F(&-A8VAE
M(&5N=')I97,L('5S960@=VET:&EN(&$@9V,@<G5N"B`@("`J(`H@("`@*B!`
M=F%R(&%R<F%Y"B`@("`J+PH@("`@=F%R("1E;G1R:65S.PH@("`@"B`@("`O
M*BH*("`@("H@5&]T86P@;G5M8F5R(&]F(&)Y=&5S(')E<75I<F5D(&)Y(&%L
M;"!C86-H92!E;G1R:65S+"!U<V5D('=I=&AI;B!A(&=C(')U;BX*("`@("H@
M"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A<B`D=&]T86Q?<VEZ92`]
M(#`["@H*("`@("\J*@H@("`@*B!-87@@3&EN92!,96YG=&@@;V8@=7-E<F1A
M=&$*("`@("H*("`@("H@268@<V5T('1O(#`L(&ET('=I;&P@=&%K92!T:&4@
M9&5F875L="`*("`@("H@*"`Q,#(T(&EN('!H<"`T+C(L('5N;&EM:71E9"!I
M;B!P:'`@-"XS*0H@("`@*B!S964@:'1T<#HO+V-H+G!H<"YN970O;6%N=6%L
M+V5N+V9U;F-T:6]N+F9G971S+G!H<`H@("`@*B!F;W(@9&5T86EL<PH@("`@
M*@H@("`@*B!`=F%R(&EN=`H@("`@*B\*("`@('9A<B`D;6%X7W5S97)D871A
M7VQI;F5L96YG=&@@/2`R-3<["@H@("`@+RHJ"B`@("`J($-R96%T97,@=&AE
M(&-A8VAE(&1I<F5C=&]R>2!I9B!N96-C97-S87)Y"B`@("`J"B`@("`J($!P
M87)A;2`@("!A<G)A>2`@($-O;F9I9R!O<'1I;VYS.B!;(F-A8VAE7V1I<B(@
M/3X@+BXN+"`B9FEL96YA;65?<')E9FEX(B`]/B`N+BY="B`@("`J+PH@("`@
M(&9U;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]F:6QE*"1O<'1I;VYS(#T@)R<I
M('L*("`@("`@("!I9B`H:7-?87)R87DH)&]P=&EO;G,I*0H@("`@("`@("`@
M("`D=&AI<RT^<V5T3W!T:6]N<R@D;W!T:6]N<RP@87)R87E?;65R9V4H)'1H
M:7,M/F%L;&]W961?;W!T:6]N<RP@87)R87DH)V-A8VAE7V1I<B<L("=F:6QE
M;F%M95]P<F5F:7@G+"`G;6%X7W5S97)D871A7VQI;F5L96YG=&@G*2DI.PH@
M("`@("`@(`H@("`@("`@(&-L96%R<W1A=&-A8VAE*"D["B`@("`@("`@:68@
M*"1T:&ES+3YC86-H95]D:7(I"B`@("`@("`@>PH@("`@("`@("`@("`O+R!M
M86ME(')E;&%T:79E('!A=&AS(&%B<V]L=71E(&9O<B!U<V4@:6X@9&5C;VYS
M=')U8W1O<BX*("`@("`@("`@("`@+R\@:70@;&]O:W,@;&EK92!T:&4@9&5C
M;VYS=')U8W1O<B!H87,@<')O8FQE;7,@=VET:"!R96QA=&EV92!P871H<PH@
M("`@("`@("`@("!I9B`H3U-?54Y)6"`F)B`G+R<@(3T@)'1H:7,M/F-A8VAE
M7V1I<GLP?2`@*0H@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7V1I<B`]
M(')E86QP871H*"!G971C=V0H*2`N("<O)R`N("1T:&ES+3YC86-H95]D:7(I
M("X@)R\G.PH*("`@("`@("`@("`@+R\@8VAE8VL@:68@82!T<F%I;&EN9R!S
M;&%S:"!I<R!I;B!C86-H95]D:7(*("`@("`@("`@("`@:68@*"1T:&ES+3YC
M86-H95]D:7)[<W1R;&5N*"1T:&ES+3YC86-H95]D:7(I+3%]("$]($1)4D5#
M5$]265]315!!4D%43U(I"B`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7V1I<B`N/2`G+R<["@H@("`@("`@("`@("!I9B`@*"%F:6QE7V5X:7-T<R@D
M=&AI<RT^8V%C:&5?9&ER*2!\?"`A:7-?9&ER*"1T:&ES+3YC86-H95]D:7(I
M*0H@("`@("`@("`@("`@("`@;6MD:7(H)'1H:7,M/F-A8VAE7V1I<BP@,#<U
M-2D["B`@("`@("`@?0H@("`@("`@("1T:&ES+3YE;G1R:65S(#T@87)R87DH
M*3L*("`@("`@("`D=&AI<RT^9W)O=7!?9&ER<R`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC(&-O;G1R=6-T;W(*
M"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D@>PH@("`@("`@("1F
M:6QE(#T@)'1H:7,M/F=E=$9I;&5N86UE*"1I9"P@)&=R;W5P*3L*("`@("`@
M("!I9B`H(69I;&5?97AI<W1S*"1F:6QE*2D*("`@("`@("`@("`@<F5T=7)N
M(&%R<F%Y*$Y53$PL($Y53$PL($Y53$PI.PH*("`@("`@("`O+R!R971R:79E
M('1H92!C;VYT96YT"B`@("`@("`@:68@*"$H)&9H(#T@0&9O<&5N*"1F:6QE
M+"`G<F(G*2DI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H
M(D-A;B=T(&%C8V5S<R!C86-H92!F:6QE("<D9FEL92<N($-H96-K(&%C8V5S
M<R!R:6=H=',@86YD('!A=&@N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*"B`@
M("`@("`@+R\@1FEL92!L;V-K:6YG("AS:&%R960@;&]C:RD*("`@("`@("!I
M9B`H)'1H:7,M/F9I;&5,;V-K:6YG*0H@("`@("`@("`@("!F;&]C:R@D9F@L
M($Q/0TM?4T@I.PH*("`@("`@("`O+R!F:6QE(&9O<FUA=#H*("`@("`@("`O
M+R`Q<W0@;&EN93H@97AP:7)A=&EO;B!D871E"B`@("`@("`@+R\@,FYD(&QI
M;F4Z('5S97(@9&%T80H@("`@("`@("\O(#-R9"L@;&EN97,Z(&-A8VAE(&1A
M=&$*("`@("`@("`D97AP:7)E(#T@=')I;2AF9V5T<R@D9F@L(#$R*2D["B`@
M("`@("`@:68@*"1T:&ES+3YM87A?=7-E<F1A=&%?;&EN96QE;F=T:"`]/2`P
M("D@>PH@("`@("`@("`@("`D=7-E<F1A=&$@/2!T<FEM*&9G971S*"1F:"DI
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1U<V5R9&%T82`]('1R
M:6TH9F=E=',H)&9H+"`D=&AI<RT^;6%X7W5S97)D871A7VQI;F5L96YG=&@I
M*3L*("`@("`@("!]"B`@("`@("`@)&-A8VAE9&%T82`]("1T:&ES+3YD96-O
M9&4H9G)E860H)&9H+"!F:6QE<VEZ92@D9FEL92DI*3L*"B`@("`@("`@+R\@
M56YL;V-K:6YG"B`@("`@("`@:68@*"1T:&ES+3YF:6QE3&]C:VEN9RD*("`@
M("`@("`@("`@9FQO8VLH)&9H+"!,3T-+7U5.*3L*"B`@("`@("`@9F-L;W-E
M*"1F:"D["@H@("`@("`@("\O(&QA<W0@=7-A9V4@9&%T92!U<V5D(&)Y('1H
M92!G8R`M(&UA>&QI9F5T:6UE"B`@("`@("`@+R\@=&]U8V@@=VET:&]U="!S
M96-O;F0@<&%R86T@<')O9'5C960@<W1U<&ED(&5N=')I97,N+BX*("`@("`@
M("!T;W5C:"@D9FEL92QT:6UE*"DI.PH@("`@("`@(&-L96%R<W1A=&-A8VAE
M*"D["@H@("`@("`@(')E='5R;B!A<G)A>2@D97AP:7)E+"`D8V%C:&5D871A
M+"`D=7-E<F1A=&$I.PH@("`@?2`O+R!E;F0@9G5N8R!F971C:`H*("`@("\J
M*@H@("`@*B!3=&]R97,@82!D871A<V5T+@H@("`@*@H@("`@*B!705).24Y'
M.B!)9B!Y;W4@<W5P<&QY('5S97)D871A(&ET(&UU<W0@;F]T(&-O;G1A:6X@
M86YY(&QI;F5B<F5A:W,L"B`@("`J(&]T:&5R=VES92!I="!W:6QL(&)R96%K
M('1H92!F:6QE<W1R=6-T=7)E+@H@("`@*B\*("`@(&9U;F-T:6]N('-A=F4H
M)&ED+"`D8V%C:&5D871A+"`D97AP:7)E<RP@)&=R;W5P+"`D=7-E<F1A=&$I
M('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*
M"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T1FEL96YA;64H)&ED+"`D9W)O
M=7`I.PH@("`@("`@(&EF("@A*"1F:"`]($!F;W!E;B@D9FEL92P@)W=B)RDI
M*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#86XG="!A
M8V-E<W,@)R1F:6QE)R!T;R!S=&]R92!C86-H92!D871A+B!#:&5C:R!A8V-E
M<W,@<FEG:'1S(&%N9"!P871H+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@
M("`@("`@("\O($9I;&4@;&]C:VEN9R`H97AC;'5S:79E(&QO8VLI"B`@("`@
M("`@:68@*"1T:&ES+3YF:6QE3&]C:VEN9RD*("`@("`@("`@("`@9FQO8VLH
M)&9H+"!,3T-+7T58*3L*"B`@("`@("`@+R\@9FEL92!F;W)M870Z"B`@("`@
M("`@+R\@,7-T(&QI;F4Z(&5X<&ER871I;VX@9&%T90H@("`@("`@("\O(#)N
M9"!L:6YE.B!U<V5R(&1A=&$*("`@("`@("`O+R`S<F0K(&QI;F5S.B!C86-H
M92!D871A"B`@("`@("`@)&5X<&ER97,@/2`D=&AI<RT^9V5T17AP:7)E<T%B
M<V]L=71E*"1E>'!I<F5S*3L*("`@("`@("!F=W)I=&4H)&9H+"`D97AP:7)E
M<R`N(")<;B(I.PH@("`@("`@(&9W<FET92@D9F@L("1U<V5R9&%T82`N(")<
M;B(I.PH@("`@("`@(&9W<FET92@D9F@L("1T:&ES+3YE;F-O9&4H)&-A8VAE
M9&%T82DI.PH*("`@("`@("`O+R!&:6QE('5N;&]C:VEN9PH@("`@("`@(&EF
M("@D=&AI<RT^9FEL94QO8VMI;F<I"B`@("`@("`@("`@(&9L;V-K*"1F:"P@
M3$]#2U]53BD["@H@("`@("`@(&9C;&]S92@D9F@I.PH*("`@("`@("`O+R!)
M)VT@;F]T('-U<F4@:68@=V4@;F5E9"!T:&ES"@DO+R!I(&1O;B=T('1H:6YK
M('=E(&YE960@=&AI<R`H8VAR96=U*0H@("`@("`@("\O('1O=6-H*"1F:6QE
M*3L*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!F=6YC('-A
M=F4*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I('L*("`@("`@
M("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@
M)&9I;&4@/2`D=&AI<RT^9V5T1FEL96YA;64H)&ED+"`D9W)O=7`I.PH@("`@
M("`@(&EF("AF:6QE7V5X:7-T<R@D9FEL92DI('L*"B`@("`@("`@("`@("1O
M:R`]('5N;&EN:R@D9FEL92D["B`@("`@("`@("`@(&-L96%R<W1A=&-A8VAE
M*"D["@H@("`@("`@("`@("!R971U<FX@)&]K.PH@("`@("`@('T*"B`@("`@
M("`@<F5T=7)N(&9A;'-E.PH@("`@?2`O+R!E;F0@9G5N8R!R96UO=F4*"B`@
M("!F=6YC=&EO;B!F;'5S:"@D9W)O=7`I('L*("`@("`@("`D=&AI<RT^9FQU
M<VA0<F5L;V%D*"D["B`@("`@("`@)&1I<B`]("@D9W)O=7`I(#\@)'1H:7,M
M/F-A8VAE7V1I<B`N("1G<F]U<"`N("<O)R`Z("1T:&ES+3YC86-H95]D:7([
M"@H@("`@("`@("1N=6U?<F5M;W9E9"`]("1T:&ES+3YD96QE=&5$:7(H)&1I
M<BD["B`@("`@("`@=6YS970H)'1H:7,M/F=R;W5P7V1I<G-;)&=R;W5P72D[
M"B`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L*"B`@("`@("`@<F5T=7)N("1N
M=6U?<F5M;W9E9#L*("`@('T@+R\@96YD(&9U;F,@9FQU<V@*"B`@("!F=6YC
M=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D@>PH*("`@("`@("!R971U<FX@
M9FEL95]E>&ES=',H)'1H:7,M/F=E=$9I;&5N86UE*"1I9"P@)&=R;W5P*2D[
M"B`@("!]("\O(&5N9"!F=6YC(&ED17AI<W1S"@H@("`@+RHJ"B`@("`J($1E
M;&5T97,@86QL(&5X<&ER960@9FEL97,N"B`@("`J"B`@("`J($=A<F)A9V4@
M8V]L;&5C=&EO;B!F;W(@9FEL97,@:7,@82!R871H97(@(F5X<&5N<VEV92(L
M(")L;VYG('1I;64B"B`@("`J(&]P97)A=&EO;BX@06QL(&9I;&5S(&EN('1H
M92!C86-H92!D:7)E8W1O<GD@:&%V92!T;R!B92!E>&%M:6YE9"!W:&EC:`H@
M("`@*B!M96%N<R!T:&%T('1H97D@;75S="!B92!O<&5N960@9F]R(')E861I
M;F<L('1H92!E>'!I<F%T:6]N(&1A=&4@:&%S('1O(&)E"B`@("`J(')E860@
M9G)O;2!T:&5M(&%N9"!I9B!N96-C97-S87)Y('1H97D@:&%V92!T;R!B92!U
M;FQI;FME9"`H<F5M;W9E9"DN"B`@("`J($EF('EO=2!H879E(&$@=7-E<B!C
M;VUM96YT(&9O<B!A(&=O;V0@9&5F875L="!G8R!P<F]B86)I;&ET>2!P;&5A
M<V4@861D(&ET('1O"B`@("`J('1O('1H92!I;FQI;F4@9&]C<RX*("`@("H*
M("`@("H@0'!A<F%M("`@(&EN=&5G97(@36%X:6UU;2!L:69E=&EM92!I;B!S
M96-O;F1S(&]F(&%N(&YO(&QO;F=E<B!U<V5D+W1O=6-H960@96YT<GD*("`@
M("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J+PH@("`@9G5N8W1I;VX@
M9V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE*2!["@H@("`@("`@("1T
M:&ES+3YF;'5S:%!R96QO860H*3L*("`@("`@("!C;&5A<G-T871C86-H92@I
M.PH*("`@("`@("`D;VL@/2`D=&AI<RT^9&]'87)B86=E0V]L;&5C=&EO;B@D
M;6%X;&EF971I;64L("1T:&ES+3YC86-H95]D:7(I.PH*("`@("`@("`O+R!C
M:&5C:R!T:&4@<W!A8V4@=7-E9"!B>2!T:&4@8V%C:&4@96YT<FEE<R`@("`@
M("`@"B`@("`@("`@:68@*"1T:&ES+3YT;W1A;%]S:7IE(#X@)'1H:7,M/FAI
M9VAW871E<BD@>PH@("`@("`@(`H@("`@("`@("`@("!K<G-O<G0H)'1H:7,M
M/F5N=')I97,I.PH@("`@("`@("`@("!R97-E="@D=&AI<RT^96YT<FEE<RD[
M"B`@("`@("`@("`@(`H@("`@("`@("`@("!W:&EL92`H)'1H:7,M/G1O=&%L
M7W-I>F4@/B`D=&AI<RT^;&]W=V%T97(@)B8@;&ES="@D;&%S=&UO9"P@)&5N
M=')Y*2`](&5A8V@H)'1H:7,M/F5N=')I97,I*2!["B`@("`@("`@("`@("`@
M("!I9B`H0'5N;&EN:R@D96YT<GE;)V9I;&4G72DI"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/G1O=&%L7W-I>F4@+3T@)&5N=')Y6R=S:7IE)UT["B`@
M("`@("`@("`@("`@("!E;'-E"B`@("`@("`@("`@("`@("`@("`@;F5W($-A
M8VAE17)R;W(H(D-A;B=T(&1E;&5T92![)&5N=')Y6R)F:6QE(EU]+B!#:&5C
M:R!T:&4@<&5R;6ES<VEO;G,N(BD["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@"B`@("`@("`@?0H@("`@("`@(`H@("`@("`@("1T:&ES+3YE;G1R:65S
M(#T@87)R87DH*3L*("`@("`@("`D=&AI<RT^=&]T86Q?<VEZ92`](#`["B`@
M("`@("`@"B`@("`@("`@<F5T=7)N("1O:SL*("`@('T@+R\@96YD(&9U;F,@
M9V%R8F%G94-O;&QE8W1I;VX*("`@(`H@("`@+RHJ"B`@("`J($1O97,@=&AE
M(')E8W5R<VEV92!G8R!P<F]C961U<F4L('!R;W1E8W1E9"X*("`@("H*("`@
M("H@0'!A<F%M("`@(&EN=&5G97(@36%X:6UU;2!L:69E=&EM92!I;B!S96-O
M;F1S(&]F(&%N(&YO(&QO;F=E<B!U<V5D+W1O=6-H960@96YT<GD*("`@("H@
M0'!A<F%M("`@('-T<FEN9R`@9&ER96-T;W)Y('1O(&5X86UI;F4@+2!D;VXG
M="!S971S('1H:7,@<&%R86UE=&5R+"!I="=S('5S960@9F]R(&$*("`@("H@
M("`@("`@("`@("`@("`@("`@<F5C=7)S:79E(&9U;F-T:6]N(&-A;&PA"B`@
M("`J($!T:')O=W,@("!#86-H95]%<G)O<@H@("`@*B\*("`@(&9U;F-T:6]N
M(&1O1V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE+"`D9&ER*2!["B`@
M("`@("`@("`@"B`@("`@("`@:68@*"$H)&1H(#T@;W!E;F1I<B@D9&ER*2DI
M"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H(D-A;B=T(&%C
M8V5S<R!C86-H92!D:7)E8W1O<GD@)R1D:7(G+B!#:&5C:R!P97)M:7-S:6]N
M<R!A;F0@<&%T:"XB+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("!W
M:&EL92`H)&9I;&4@/2!R96%D9&ER*"1D:"DI('L*("`@("`@("`@("`@:68@
M*"<N)R`]/2`D9FEL92!\?"`G+BXG(#T]("1F:6QE*0H@("`@("`@("`@("`@
M("`@8V]N=&EN=64["@H@("`@("`@("`@("`D9FEL92`]("1D:7(@+B`D9FEL
M93L*("`@("`@("`@("`@:68@*&ES7V1I<B@D9FEL92DI('L*("`@("`@("`@
M("`@("`@("1T:&ES+3YD;T=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E=&EM
M92PD9FEL92`N("<O)RD["B`@("`@("`@("`@("`@("!C;VYT:6YU93L*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@<VMI<"!T<F]U8FQE(&UA:V5R
M<R!B=70@:6YF;W)M('1H92!U<V5R"B`@("`@("`@("`@(&EF("@A*"1F:"`]
M($!F;W!E;B@D9FEL92P@)W)B)RDI*2!["B`@("`@("`@("`@("`@("!N97<@
M0V%C:&5?17)R;W(H(D-A;B=T(&%C8V5S<R!C86-H92!F:6QE("<D9FEL92<L
M('-K:7!P:6YG(&ET+B!#:&5C:R!P97)M:7-S:6]N<R!A;F0@<&%T:"XB+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@8V]N=&EN=64[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1E>'!I<F4@/2!F9V5T<R@D
M9F@L(#$Q*3L*("`@("`@("`@("`@9F-L;W-E*"1F:"D["B`@("`@("`@("`@
M("1L87-T=7-E9"`](&9I;&5M=&EM92@D9FEL92D["B`@("`@("`@("`@(`H@
M("`@("`@("`@("`D=&AI<RT^96YT<FEE<ULD;&%S='5S961=(#T@87)R87DH
M)V9I;&4G(#T^("1F:6QE+"`G<VEZ92<@/3X@9FEL97-I>F4H)&9I;&4I*3L*
M("`@("`@("`@("`@)'1H:7,M/G1O=&%L7W-I>F4@*ST@9FEL97-I>F4H)&9I
M;&4I.PH@("`@("`@("`@("`*("`@("`@("`@("`@+R\@<F5M;W9E(&EF(&5X
M<&ER960*("`@("`@("`@("`@:68@*"@@*"1E>'!I<F4@)B8@)&5X<&ER92`\
M/2!T:6UE*"DI('Q\("@D;&%S='5S960@/#T@*'1I;64H*2`M("1M87AL:69E
M=&EM92DI("D@)B8@(75N;&EN:R@D9FEL92DI"B`@("`@("`@("`@("`@("!N
M97<@0V%C:&5?17)R;W(H(D-A;B=T('5N;&EN:R!C86-H92!F:6QE("<D9FEL
M92<L('-K:7!P:6YG+B!#:&5C:R!P97)M:7-S:6]N<R!A;F0@<&%T:"XB+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@8VQO<V5D
M:7(H)&1H*3L*"B`@("`@("`@+R\@9FQU<V@@=&AE(&1I<VL@<W1A=&4@8V%C
M:&4*("`@("`@("!C;&5A<G-T871C86-H92@I.PH*("`@('T@+R\@96YD(&9U
M;F,@9&]'87)B86=E0V]L;&5C=&EO;@H*("`@("\J*@H@("`@*B!2971U<FYS
M('1H92!F:6QE;F%M92!F;W(@=&AE('-P96-I9FEE9"!I9"X*("`@("H*("`@
M("H@0'!A<F%M("`@('-T<FEN9R`@9&%T87-E="!)1`H@("`@*B!`<&%R86T@
M("`@<W1R:6YG("!C86-H92!G<F]U<`H@("`@*B!`<F5T=7)N("`@<W1R:6YG
M("!F=6QL(&9I;&5N86UE('=I=&@@=&AE('!A=&@*("`@("H@0&%C8V5S<R`@
M('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9I;&5N86UE*"1I9"P@
M)&=R;W5P*2!["@H@("`@("`@(&EF("AI<W-E="@D=&AI<RT^9W)O=7!?9&ER
M<ULD9W)O=7!=*2D*("`@("`@("`@("`@<F5T=7)N("1T:&ES+3YG<F]U<%]D
M:7)S6R1G<F]U<%T@+B`D=&AI<RT^9FEL96YA;65?<')E9FEX("X@)&ED.PH*
M("`@("`@("`D9&ER(#T@)'1H:7,M/F-A8VAE7V1I<B`N("1G<F]U<"`N("<O
M)SL*("`@("`@("!I9B`H(69I;&5?97AI<W1S*"1D:7(I*2!["B`@("`@("`@
M("`@(&UK9&ER*"1D:7(L(#`W-34I.PH@("`@("`@("`@("!C;&5A<G-T871C
M86-H92@I.PH@("`@("`@('T*"B`@("`@("`@)'1H:7,M/F=R;W5P7V1I<G-;
M)&=R;W5P72`]("1D:7(["@H@("`@("`@(')E='5R;B`D9&ER("X@)'1H:7,M
M/F9I;&5N86UE7W!R969I>"`N("1I9#L*("`@('T@+R\@96YD(&9U;F,@9V5T
M1FEL96YA;64*"B`@("`O*BH*("`@("H@1&5L971E<R!A(&1I<F5C=&]R>2!A
M;F0@86QL(&9I;&5S(&EN(&ET+@H@("`@*@H@("`@*B!`<&%R86T@("`@<W1R
M:6YG("!D:7)E8W1O<GD*("`@("H@0')E='5R;B`@(&EN=&5G97(@;G5M8F5R
M(&]F(')E;6]V960@9FEL97,*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R
M"B`@("`J+PH@("`@9G5N8W1I;VX@9&5L971E1&ER*"1D:7(I('L*("`@("`@
M("!I9B`H(2@D9&@@/2!O<&5N9&ER*"1D:7(I*2D*("`@("`@("`@("`@<F5T
M=7)N(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@<F5M;W9E(&1I<F5C=&]R>2`G
M)&1I<B<N($-H96-K('!E<FUI<W-I;VYS(&%N9"!P871H+B(L(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["@H@("`@("`@("1N=6U?<F5M;W9E9"`](#`["@H@("`@
M("`@('=H:6QE("AF86QS92`A/3T@)&9I;&4@/2!R96%D9&ER*"1D:"DI('L*
M("`@("`@("`@("`@:68@*"<N)R`]/2`D9FEL92!\?"`G+BXG(#T]("1F:6QE
M*0H@("`@("`@("`@("`@("`@8V]N=&EN=64["@H@("`@("`@("`@("`D9FEL
M92`]("1D:7(@+B`D9FEL93L*("`@("`@("`@("`@:68@*&ES7V1I<B@D9FEL
M92DI('L*("`@("`@("`@("`@("`@("1F:6QE("X]("<O)SL*("`@("`@("`@
M("`@("`@("1N=6T@/2`D=&AI<RT^9&5L971E1&ER*"1F:6QE("X@)R\G*3L*
M("`@("`@("`@("`@("`@(&EF("AI<U]I;G0H)&YU;2DI"B`@("`@("`@("`@
M("`@("`@("`@)&YU;5]R96UO=F5D("L]("1N=6T["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!I9B`H=6YL:6YK*"1F:6QE*2D*("`@
M("`@("`@("`@("`@("`@("`D;G5M7W)E;6]V960K*SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("`O+R!A8V-O<F1I;F<@=&\@<&AP+6UA;G5A
M;"!T:&4@9F]L;&]W:6YG(&ES(&YE961E9"!F;W(@=VEN9&]W<R!I;G-T86QL
M871I;VYS+@H@("`@("`@(&-L;W-E9&ER*"1D:"D["B`@("`@("`@=6YS970H
M("1D:"D["B`@("`@("`@:68@*"1D:7(@(3T@)'1H:7,M/F-A8VAE7V1I<BD@
M>R`@+R]D96QE=&4@=&AE('-U8BUD:7(@96YT<FEE<R`@:71S96QF(&%L<V\L
M(&)U="!N;W0@=&AE(&-A8VAE+61I<BX*("`@("`@("`@("`@<FU$:7(H)&1I
M<BD["B`@("`@("`@("`@("1N=6U?<F5M;W9E9"LK.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1N=6U?<F5M;W9E9#L*("`@('T@+R\@96YD(&9U;F,@
M9&5L971E1&ER"B`@("`*?2`O+R!E;F0@8VQA<W,@9FEL90H_/@H`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E
M87(O0V%C:&4O0V]N=&%I;F5R+VUS97-S:6]N+G!H<```````````````````
M```````````````````````````````````````P,#`V-#0@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`Q-C8S,2`Q,#4Q-30S-#$S,B`P,C,W-C4`(#``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````/#]P:'`*+R\@
M*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H
M92`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\@?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B
M:F5C="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@
M('P*+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@
M=&AE(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA
M8FQE(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L
M:6-E;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T
M:&4@4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T
M86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N
M9"!A(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S
M;R!W92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@
M("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@
M075T:&]R<SH@56QF(%=E;F1E;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@
M("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2L*+R\*+R\@)$ED.B!M<V5S<VEO;BYP:'`L=B`Q+C0@,C`P
M,R\P,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`H*<F5Q=6ER95]O;F-E("=#86-H
M92]#;VYT86EN97(N<&AP)SL*"B\J*@HJ(%-T;W)E<R!C86-H92!C;VYT96YT
M<R!I;B!M<V5S<VEO;G,N"BH**B!705).24Y'.B!E>'!E<FEM96YT86PL('5N
M=&5S=&5D"BH**B!`875T:&]R("`@56QF(%=E;F1E;"`@/'5L9BYW96YD96Q`
M<&AP9&]C+F1E/@HJ($!V97)S:6]N("`D260Z(&US97-S:6]N+G!H<"QV(#$N
M-"`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"BHO"F-L87-S($-A8VAE
M7T-O;G1A:6YE<E]M<V5S<VEO;B!E>'1E;F1S($-A8VAE7T-O;G1A:6YE<B![
M"@H*("`@("\J*@H@("`@*B!,96YG=&@@;V8@=&AE($-A8VAE+4ED96YT:69I
M97(*("`@("H*("`@("H@3F]T92!T:&%T('1H92!014%2+4-A8VAE('!R969I
M>&5S('1H92!)1"!W:71H(&%N(&UD-2@I('9A;'5E"B`@("`J(&]F('1H92!C
M86-H92UG<F]U<"X@02!G;V]D('9A;'5E(&9O<B!T:&4@:61?;&5N9W1H"B`@
M("`J(&1E<&5N9',@;VX@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&5N=')I97,@
M<&5R(&-A8VAE(&=R;W5P+@H@("`@*@H@("`@*B!`=F%R("!I;G0*("`@("HO
M"B`@("!V87(@)&ED7VQE;F=T:"`](#,R.PH@("`@"B`@("`*("`@("\J*@H@
M("`@*B!5<V4@;7-E<W-I;VY?=6YI<2!T;R!C<F5A=&4@82!U;FEQ=64@4TE$
M+@H@("`@*B`*("`@("H@0'9A<B`@8F]O;&5A;@H@("`@*B\*("`@('9A<B`D
M=6YI<2`]('1R=64["B`@("`*("`@(`H@("`@+RHJ"B`@("`J($5S=&%B;&ES
M:"!A(&-O;FYE8W1I;VX@=&\@82!M<V5S<VEO;B!S97)V97(_"B`@("`J"B`@
M("`J($!V87(@(&)O;VQE86X*("`@("HO"B`@("!V87(@)&-O;FYE8W0@/2!T
M<G5E.PH@("`*("`@"B`@("`O*BH*("`@("H@;7-E<W-I;VX@:&]S=`H@("`@
M*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO("`*("`@('9A<B`D:&]S="`]
M($Y53$P["B`@("`*("`@"B`@("`O*BH*("`@("H@;7-E<W-I;VX@<&]R=`H@
M("`@*@H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)'!O<G0@
M/2!.54Q,.PH@("`@"B`@("`*("`@("\J*@H@("`@*B!M97-E<W-I;VX@<V5R
M=F5R(&-O;FYE8W1I;VX*("`@("H*("`@("H@0'9A<B`@<F5S;W5R8V4@;7-E
M<W-I;VX*("`@("HO"B`@("!V87(@)&US(#T@3E5,3#L*"B`@("`*("`@(&9U
M;F-T:6]N($-A8VAE7T-O;G1A:6YE<E]M<V5S<VEO;B@D;W!T:6]N<R`]("<G
M*2!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D*("`@("`@("`@
M("`@)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO;G,L(&%R<F%Y7VUE<F=E*"1T
M:&ES+3YA;&QO=V5D7V]P=&EO;G,L(&%R<F%Y*"=I9%]L96YG:'0G+"`G=6YI
M<2<L("=H;W-T)RP@)W!O<G0G+"`G8V]N;F5C="<I*2D["@H@("`@("`@(&EF
M("@D8V]N;F5C="D@>R`@("`@("`@("`@(`H@("`@("`@("`@("!I9B`H3E5,
M3"`]/2`D=&AI<RT^:&]S="D*("`@("`@("`@("`@("`@(&YE=R!#86-H95]%
M<G)O<B@G3F\@:&]S="!S<&5C:69I960N)RP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@:68@*$Y53$P@/3T@)'1H:7,M/G!O<G0I"B`@("`@
M("`@("`@("`@("!N97<@0V%C:&5?17)R;W(H)TYO('!O<G0@<W!E8VEF:65D
M+B<L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@"B`@("`@("`@("`@
M(&EF("@A*"1T:&ES+3YM<R`](&US97-S:6]N7V-O;FYE8W0H)'1H:7,M/FAO
M<W0L("1T:&ES+3YP;W)T*2DI"B`@("`@("`@("`@("`@("!N97<@0V%C:&5?
M17)R;W(H)T-A;B!N;W0@8V]N;F5C="!T;R!T:&4@<V5V97(@=7-I;F<@:&]S
M="`B)R`N("1T:&ES+3YH;W-T("X@)R(@;VX@<&]R="`B)R`N("1T:&ES+3YP
M;W)T("X@)R(G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@
M("`@("`*("`@('T@+R\@96YD(&9U;F,@8V]N=')U8W1O<@H*("`@(&9U;F-T
M:6]N(&9E=&-H*"1I9"P@)&=R;W5P*2!["B`@("`*("`@("`@("`D:60@/2!S
M=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I9#L*("`@("`@("`D9W)O=7`@
M/2!M<V5S<VEO;E]G970H)&ED+"`G7W!E87)?8V%C:&5?9&%T82<L($Y53$PI
M.PH@("`@("`@(`H@("`@("`@(&EF("A.54Q,(#T]("1D871A*0H@("`@("`@
M("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@("`@
M"B`@("`@("`@<F5T=7)N(&%R<F%Y*"1D871A6R=E>'!I<F5S)UTL("1D871A
M6R=C86-H961A=&$G72P@)&1A=&%;)W5S97)D871A)UTI.PH@("`@?2`O+R!E
M;F0@9G5N8R!F971C:`H*("`@("\J*@H@("`@*B!3=&]R97,@82!D871A<V5T
M+@H@("`@*@H@("`@*B!705).24Y'.B!)9B!Y;W4@<W5P<&QY('5S97)D871A
M(&ET(&UU<W0@;F]T(&-O;G1A:6X@86YY(&QI;F5B<F5A:W,L"B`@("`J(&]T
M:&5R=VES92!I="!W:6QL(&)R96%K('1H92!F:6QE<W1R=6-T=7)E+@H@("`@
M*B\*("`@(&9U;F-T:6]N('-A=F4H)&ED+"`D8V%C:&5D871A+"`D97AP:7)E
M<RP@)&=R;W5P+"`D=7-E<F1A=&$I('L*("`@("`@("`D=&AI<RT^9FQU<VA0
M<F5L;V%D*"1I9"P@)&=R;W5P*3L*("`@("`@("`*("`@("`@("`D8V%C:&5D
M871A("`@("`@/2`D=&AI<RT^96YC;V1E*"1C86-H961A=&$I.PH@("`@("`@
M("1E>'!I<F5S7V%B<R`@("`]("1T:&ES+3YG971%>'!I<F5S06)S;VQU=&4H
M)&5X<&ER97,I.PH*("`@("`@("`D<VEZ92`](#$@*R!S=')L96XH)&-A8VAE
M9&%T82D@*R!S=')L96XH)&5X<&ER97-?86)S*2`K('-T<FQE;B@D=7-E<F1A
M=&$I("L@<W1R;&5N*"1G<F]U<"D["B`@("`@("`@)'-I>F4@*ST@<W1R;&5N
M*"1S:7IE*3L*("`@("`@("`*("`@("`@("`D9&%T82`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@("`@("=C86-H961A=&$G(#T^("1C86-H961A=&$L(`H@
M("`@("`@("`@("`@("`@("`@("=E>'!I<F5S)R`@(#T^("1E>'!I<F5S7V%B
M<RP*("`@("`@("`@("`@("`@("`@("`G=7-E<F1A=&$G("`]/B`D=7-E<F1A
M=&$*("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`D:60@/2!S=')T;W5P
M<&5R*&UD-2@D9W)O=7`I*2`N("1I9#L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(`H@("`@("`@(&US97-S:6]N7VQO8VLH)&ED*3L*("`@("`@("`*
M("`@("`@("!I9B`H(6US97-S:6]N7W-E="@D:60L("=?<&5A<E]C86-H92<L
M('1R=64I*2!["B`@("`@("`@("`@(&US97-S:6]N7W5N;&]C:R@D:60I.PH@
M("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#86XG="!W<FET
M92!C86-H92!D871A+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@
M?0H@("`@("`@(`H@("`@("`@(&EF("@A;7-E<W-I;VY?<V5T*"1I9"P@)U]P
M96%R7V-A8VAE7V1A=&$G+"`D9&%T82DI('L*("`@("`@("`@("`@;7-E<W-I
M;VY?=6YL;V-K*"1I9"D["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?
M17)R;W(H(D-A;B=T('=R:71E(&-A8VAE(&1A=&$N(BP@7U]&24Q%7U\L(%]?
M3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@:68@*"%M<V5S
M<VEO;E]S970H)&ED+"`G7W!E87)?8V%C:&5?9W)O=7`G+"`D9W)O=7`I*2![
M"B`@("`@("`@("`@(&US97-S:6]N7W5N;&]C:R@D:60I.PH@("`@("`@("`@
M("!R971U<FX@;F5W($-A8VAE7T5R<F]R*")#86XG="!W<FET92!C86-H92!D
M871A+B(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@
M(`H@("`@("`@(&EF("@A;7-E<W-I;VY?<V5T*"1I9"P@)U]P96%R7V-A8VAE
M7W-I>F4G+"`D<VEZ92DI('L*("`@("`@("`@("`@;7-E<W-I;VY?=6YL;V-K
M*"1I9"D["B`@("`@("`@("`@(')E='5R;B!N97<@0V%C:&5?17)R;W(H(D-A
M;B=T('=R:71E(&-A8VAE(&1A=&$N(BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"B`@("`@("`@"B`@("`@("`@+R\@;&5T(&US97-S:6]N(&1O
M('-O;64@1T,@87,@=V5L;`H@("`@("`@("\O(&YO=&4@=&AA="!M<V5S<VEO
M;B!W;W)K<R!D:69F97)E;G0@9G)O;2!T:&4@4$5!4B!#86-H92X*("`@("`@
M("`O+R!M<V5S<VEO;B!D96QE=&5S(&%N(&5N=')Y(&EF(&ET(&AA<R!N;W0@
M8F5E;B!U<V5D(&9O<B!N+7-E8V]N9',N"B`@("`@("`@+R\@4$5!4B!#86-H
M92!D96QE=&5S(&%F=&5R(&XM<V5C;VYD<RX*("`@("`@("!I9B`H,"`A/2`D
M97AP:7)E<RD*("`@("`@("`@("`@;7-E<W-I;VY?=&EM96]U="@D:60L("1E
M>'!I<F5S*3L*("`@("`@("`@("`@"B`@("`@("`@;7-E<W-I;VY?=6YL;V-K
M*"1I9"D["@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2`O+R!E;F0@9G5N
M8R!S879E"@H@("`@9G5N8W1I;VX@<F5M;W9E*"1I9"P@)&=R;W5P*2!["B`@
M("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D:60L("1G<F]U<"D["B`@("`*
M("`@("`@("!R971U<FX@;7-E<W-I;VY?9&5S=')O>2AS=')T;W5P<&5R*&UD
M-2@D9W)O=7`I*2`N("1I9"D["B`@("!]("\O(&5N9"!F=6YC(')E;6]V90H*
M("`@(&9U;F-T:6]N(&9L=7-H*"1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF
M;'5S:%!R96QO860H*3L*("`@("`@"B`@("`@("`@)'-E<W-I;VYS(#T@;7-E
M<W-I;VY?9FEN9"@G7W!E87)?8V%C:&5?9W)O=7`G+"`D9W)O=7`I.PH@("`@
M("`@(&EF("AE;7!T>2@D<V5S<VEO;G,I*0H@("`@("`@("`@("!R971U<FX@
M,#L*("`@("`@("`*("`@("`@("!F;W)E86-H("@D<V5S<VEO;G,@87,@)&L@
M/3X@)&ED*0H@("`@("`@("`@("!M97-S<VEO;E]D97-T<F]Y*"1I9"D["@H@
M("`@("`@(')E='5R;B!C;W5N="@D<V5S<VEO;G,I.PH@("`@?2`O+R!E;F0@
M9G5N8R!F;'5S:`H*("`@(&9U;F-T:6]N(&ED17AI<W1S*"1I9"P@)&=R;W5P
M*2!["B`@("`@("`@"B`@("`@("`@<F5T=7)N("A.54Q,(#T](&US97-S:6]N
M7V=E="AS=')T;W5P<&5R*&UD-2@D9W)O=7`I*2`N("1I9"P@)U]P96%R7V-A
M8VAE7V=R;W5P)RP@3E5,3"DI(#\@9F%L<V4@.B!T<G5E.PH@("`@?2`O+R!E
M;F0@9G5N8R!I9$5X:7-T<PH*("`@("\J*@H@("`@*B!$96QE=&5S(&%L;"!E
M>'!I<F5D(&9I;&5S+@H@("`@*@H@("`@*B!.;W1E.B!G87)B86=E(&-O;&QE
M8W1I;VX@<VAO=6QD(&-A=7-E(&QO="=S(&]F(&YE='=O<FL@=')A9F9I8RX*
M("`@("H*("`@("H@0'!A<F%M("`@(&EN=&5G97(@36%X:6UU;2!L:69E=&EM
M92!I;B!S96-O;F1S(&]F(&%N(&YO(&QO;F=E<B!U<V5D+W1O=6-H960@96YT
M<GD*("`@("H@0'1H<F]W<R`@($-A8VAE7T5R<F]R"B`@("`J+PH@("`@9G5N
M8W1I;VX@9V%R8F%G94-O;&QE8W1I;VXH)&UA>&QI9F5T:6UE*2!["B`@("`@
M("`@)'1H:7,M/F9L=7-H4')E;&]A9"@I.PH@("`@("`@(`H@("`@("`@("1S
M97-S:6]N<R`](&US97-S:6]N7V9I;F0H)U]P96%R7V-A8VAE)RP@=')U92D[
M"B`@("`@("`@:68@*&5M<'1Y*"1S97-S:6]N<RDI"B`@("`@("`@("`@(')E
M='5R;B!T<G5E.PH@("`@("`@(`H@("`@("`@("1T;W1A;"`](#`["B`@("`@
M("`@)&5N=')I97,@/2!A<G)A>2@I.PH@("`@("`@(`H@("`@("`@(&9O<F5A
M8V@@*"1S97-S:6]N<R!A<R`D:R`]/B`D:60I('L*("`@("`@("`@("`@)&1A
M=&$@/2!M<V5S<VEO;E]G970H)&ED+"`G7W!E87)?8V%C:&5?9&%T82<L($Y5
M3$PI.PH@("`@("`@("`@("!I9B`H3E5,3"`]/2`D9&%T82D*("`@("`@("`@
M("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@("`@("`@"B`@("`@("`@("`@
M(&EF("@D9&%T85LG97AP:7)E<R==(#P]('1I;64H*2D@>PH@("`@("`@("`@
M("`@("`@;7-E<W-I;VY?9&5S=')O>2@D:60I.PH@("`@("`@("`@("`@("`@
M8V]N=&EN=64["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@("`@
M("`@("1S:7IE(#T@;7-E<W-I;VY?9V5T*"1I9"P@)U]P96%R7V-A8VAE7W-I
M>F4G+"!.54Q,*3L*("`@("`@("`@("`@)'1O=&%L("L]("1S:7IE.PH@("`@
M("`@("`@("`D96YT<FEE<ULD9&%T85LG97AP:7)E<R==72`](&%R<F%Y*"1I
M9"P@)'-I>F4I.PH@("`@("`@('T*("`@("`@("`*("`@("`@("!I9B`H)'1O
M=&%L(#X@)'1H:7,M/FAI9VAW871E<BD@>PH@("`@("`@("`@("`*("`@("`@
M("`@("`@:W)S;W)T*"1E;G1R:65S*3L*("`@("`@("`@("`@<F5S970H)&5N
M=')I97,I.PH@("`@("`@("`@("`*("`@("`@("`@("`@=VAI;&4@*"1T;W1A
M;"`^("1T:&ES+3YL;W=W871E<B`F)B!L:7-T*"1E>'!I<F5S+"`D96YT<GDI
M(#T@96%C:"@D96YT<FEE<RDI('L*("`@("`@("`@("`@("`@(&US97-S:6]N
M7V1E<W1R;WDH)&5N=')Y6S!=*3L*("`@("`@("`@("`@("`@("1T;W1A;"`M
M/2`D96YT<GE;,5T["B`@("`@("`@("`@('T*("`@("`@("`@("`@"B`@("`@
M("`@?0H@("`@("`@(`H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?2`O+R!E
M;F0@9G5N8R!G87)B86=E0V]L;&5C=&EO;@H@("`@"GT@+R\@96YD(&-L87-S
M(&9I;&4*/SX`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]#86-H92]#;VYT86EN97(O<&AP;&EB+G!H<```````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#(R-#8R(#$P-3$U-#,T,3,R(#`R,S0P,@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A
M8VAE("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M*PHO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!02%`@1W)O=7`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S
M=6)J96-T('1O('9E<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@
M("`@?`HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I
M;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I
M;&%B;&4@870@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T
M+VQI8V5N<V4O,E\P,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F
M('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O
M8G1A:6X@:70@=&AR;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S
M96YD(&$@;F]T92!T;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T
M('-O('=E(&-A;B!M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!!=71H;W)S.B!5;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B
M87-T:6%N($)E<F=M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@
M("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*
M+R\*+R\@)$ED.B!P:'!L:6(N<&AP+'8@,2XS(#(P,#,O,#$O,#0@,3$Z-30Z
M-#8@;6H@17AP("0*"G)E<75I<F5?;VYC92`G0V%C:&4O0V]N=&%I;F5R+G!H
M<"<["@HO*BH**B!3=&]R97,@8V%C:&4@9&%T82!I;G1O(&$@9&%T86)A<V4@
M=&%B;&4@=7-I;F<@4$A03&EB<R!$0B!A8G-T<F%C=&EO;BX**@HJ(%=!4DY)
M3D<Z($]T:&5R('-Y<W1E;7,@;6EG:'0@;W(@;6EG:'0@;F]T('-U<'!O<G0@
M8V5R=&%I;B!D871A='EP97,@;V8@"BH@=&AE('1A8FQE<R!S:&]W;BX@07,@
M9F%R(&%S($D@:VYO=R!T:&5R92=S(&YO(&QA<F=E(&)I;F%R>2`**B!T>7!E
M(&EN(%-13"TY,B!O<B!344PM.3DN(%!O<W1G<F5S('-E96US('1O(&QA8VL@
M86YY(`HJ($),3T(@;W(@5$585"!T>7!E+"!F;W(@35,M4U%,('EO=2!C;W5L
M9"!U<V4@24U!1T4L(&1O;B=T(&MN;W<@"BH@86)O=70@;W1H97(@9&%T86)A
M<V5S+B!0;&5A<V4@861D('-U9V5S=&EO;G,@9F]R(&]T:&5R(&1A=&%B87-E
M<R!T;R`**B!T:&4@:6YL:6YE(&1O8W,N"BH**B!4:&4@9FEE;&0@)V-H86YG
M960G(&ES('5S960@8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;BX@1&5P96YD
M:6YG(&]N(`HJ('EO=7(@9&%T86)A<V5S>7-T96T@>6]U(&UI9VAT(&AA=F4@
M=&\@<W5B8VQA<W,@9F5T8V@H*2!A;F0@9V%R8F%G94-O;&QE8W1I;VXH*2X*
M*@HJ($9O<B!?37E344Q?('EO=2!N965D('1H:7,@1$(@=&%B;&4Z"BH**B!#
M4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@:60@("`@("`@("`@0TA!4B@S,BD@
M3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A8VAE9W)O=7`@(%9!4D-(05(H
M,3(W*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@8V%C:&5D871A("`@0DQ/
M0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@=7-E<F1A=&$@("`@5D%20TA!
M4B@R-34I($Y/5"!.54Q,($1%1D%53"`G)RP**B`@(&5X<&ER97,@("`@($E.
M5"@Y*2!.3U0@3E5,3"!$149!54Q4(#`L"BH@(`HJ("`@8VAA;F=E9"`@("`@
M5$E-15-404U0*#$T*2!.3U0@3E5,3"P**B`@"BH@("!)3D1%6"`H97AP:7)E
M<RDL"BH@("!04DE-05)9($M%62`H:60L(&-A8VAE9W)O=7`I"BH@*0HJ"BH@
M"BH@0&%U=&AO<B`@(%5L9B!796YD96P@(#QU;&8N=V5N9&5L0'!H<&1O8RYD
M93XL(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`<V5B87-T:6%N+6)E<F=M86YN
M+F1E/@HJ($!V97)S:6]N("`D260Z('!H<&QI8BYP:'`L=B`Q+C,@,C`P,R\P
M,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ($!S
M964@("`@("!S879E*"D**B\*8VQA<W,@0V%C:&5?0V]N=&%I;F5R7W!H<&QI
M8B!E>'1E;F1S($-A8VAE7T-O;G1A:6YE<B!["B`@"B`@("`O*BH*("`@("H@
M3F%M92!O9B!T:&4@1$(@=&%B;&4@=&\@<W1O<F4@8V%C:&EN9R!D871A"B`@
M("`J(`H@("`@*B!`<V5E("!#86-H95]#;VYT86EN97)?9FEL93HZ)&9I;&5N
M86UE7W!R969I>`H@("`@*B\@(`H@("`@=F%R("1C86-H95]T86)L92`]("=C
M86-H92<["@H@("`@+RHJ"B`@("`J(%!(4$QI8B!O8FIE8W0*("`@("H@"B`@
M("`J($!V87(@(&]B:F5C="!014%27T1""B`@("`J+PH@("`@=F%R("1D8CL*
M"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@4$A03&EB($1"(&-L87-S('1O
M('5S90H@("`@*B`*("`@("H@0'9A<B`@<W1R:6YG("`*("`@("H@0'-E92`@
M)&1B7W!A=&@L("1L;V-A;%]P871H"B`@("`J+PH@("`@=F%R("1D8E]C;&%S
M<R`]("<G.PH*("`@("\J*@H@("`@*B!&:6QE;F%M92!O9B!Y;W5R(&QO8V%L
M+FEN8PH@("`@*B`*("`@("H@268@96UP='DL("=L;V-A;"YI;F,G(&ES(&%S
M<W5M960N"B`@("`J"B`@("`J($!V87(@("`@("`@<W1R:6YG"B`@("`J+PH@
M("`@=F%R("1L;V-A;%]F:6QE(#T@)R<["@H@("`@+RHJ"B`@("`J($EN8VQU
M9&4@<&%T:"!F;W(@>6]U(&QO8V%L+FEN8PH@("`@*@H@("`@*B!(24Y4.B!)
M9B!Y;W5R)W)E(&YO="!U<VEN9R!02%!,:6(G<R!P<F5P96YD+G!H<"!Y;W4@
M;75S="`*("`@("H@=&%K92!C87)E('1H870@86QL(&-L87-S97,@*&9I;&5S
M*2!R969E<F5N8V5S(&)Y('EO=2`*("`@("H@;&]C86PN:6YC(&%R92!I;F-L
M=61E9"!A=71O;6%T:6-A;&QY+B!3;R!Y;W4@;6EG:'0@"B`@("`J('=A;G0@
M=&\@=W)I=&4@82!N97<@;&]C86PR+FEN8R!T:&%T(&]N;'D@<F5F97)R<R!T
M;R`*("`@("H@=&AE(&1A=&%B87-E(&-L87-S("AF:6QE*2!Y;W4G<F4@=7-I
M;F<@86YD(&EN8VQU9&5S(&%L;"!R97%U:7)E9"!F:6QE<RX*("`@("H*("`@
M("H@0'9A<B`@<W1R:6YG("!P871H('1O('EO=7(@;&]C86PN:6YC("T@;6%K
M92!S=7)E('1O(&%D9"!A('1R86EL:6YG('-L87-H"B`@("`J($!S964@("1L
M;V-A;%]F:6QE"B`@("`J+PH@("`@=F%R("1L;V-A;%]P871H(#T@)R<["@H@
M("`@+RHJ"B`@("`J($-R96%T97,@86X@:6YS=&%N8V4@;V8@82!P:'!L:6(@
M9&(@8VQA<W,@=&\@=7-E(&ET(&9O<B!S=&]R86=E+@H@("`@*@H@("`@*B!`
M<&%R86T@("`@;6EX960@("!)9B!E;7!T>2!T:&4@;V)J96-T('1R:65S('1O
M('5S960@=&AE(`H@("`@*B`@("`@("`@("`@("`@("`@("!P<F5C;VYF:6=U
M<F5D(&-L87-S('9A<FEA8FQE<RX@268@9VEV96X@:70@"B`@("`J("`@("`@
M("`@("`@("`@("`@(&UU<W0@8F4@86X@87)R87D@=VET:#H*("`@("H@("`@
M("`@("`@("`@("`@("`@("!D8E]C;&%S<R`]/B!N86UE(&]F('1H92!$0B!C
M;&%S<R!T;R!U<V4*("`@("H@("`@("`@("`@("`@("`@("`@;W!T:6]N86PZ
M"B`@("`J("`@("`@("`@("`@("`@("`@("`@9&)?9FEL92`]/B!F:6QE;F%M
M92!O9B!T:&4@1$(@8VQA<W,*("`@("H@("`@("`@("`@("`@("`@("`@("!D
M8E]P871H(#T^('!A=&@@=&\@=&AE($1"(&-L87-S"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@;&]C86Q?9FEL92`]/B!K:6YD(&]F(&QO8V%L+FEN8PH@
M("`@*B`@("`@("`@("`@("`@("`@("`@(&QO8V%L7W!A=&L@/3X@<&%T:"!T
M;R!T:&4@;&]C86PN:6YC"B`@("`J("`@("`@("`@("`@("`@("`@('-E92`D
M;&]C86Q?<&%T:"!F;W(@<V]M92!H:6YT<RYS"B`@("`J($!S964@("1L;V-A
M;%]P871H"B`@("`J+PH@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7W!H
M<&QI8B@D;W!T:6]N<R`]("<G*2!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1O
M<'1I;VYS*2D*("`@("`@("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO
M;G,L("!A<G)A>5]M97)G92@D=&AI<RT^86QL;W=E9%]O<'1I;VYS+"!A<G)A
M>2@G9&)?8VQA<W,G+"`G9&)?9FEL92<L("=D8E]P871H)RP@)VQO8V%L7V9I
M;&4G+"`G;&]C86Q?<&%T:"<I*2D["@H@("`@("`@(&EF("@A)'1H:7,M/F1B
M7V-L87-S*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=.
M;R!D871A8F%S92!C;&%S<R!S<&5C:69I960N)RP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*"B`@("`@("`@+R\@:6YC;'5D92!T:&4@<F5Q=6ER960@9FEL97,*
M("`@("`@("!I9B`H)'1H:7,M/F1B7V9I;&4I"B`@("`@("`@("`@(&EN8VQU
M9&5?;VYC92@D=&AI<RT^9&)?<&%T:"`N("1T:&ES+3YD8E]F:6QE*3L*"B`@
M("`@("`@:68@*"1T:&ES+3YL;V-A;%]F:6QE*0H@("`@("`@("`@("!I;F-L
M=61E7V]N8V4H)'1H:7,M/FQO8V%L7W!A=&@@+B`D=&AI<RT^;&]C86Q?9FEL
M92D["@H@("`@("`@("\O(&-R96%T92!A(&1B(&]B:F5C="`*("`@("`@("`D
M=&AI<RT^9&(@/2!N97<@)'1H:7,M/F1B7V-L87-S.PH@("`@?2`O+R!E;F0@
M8V]N<W1R=6-T;W(*"B`@("!F=6YC=&EO;B!F971C:"@D:60L("1G<F]U<"D@
M>PH@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(E-%3$5#5"!E>'!I<F5S+"!C
M86-H961A=&$L('5S97)D871A($923TT@)7,@5TA%4D4@:60@/2`G)7,G($%.
M1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L(`H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&ED+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&=R
M;W5P"B`@("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("1T:&ES
M+3YD8BT^<75E<GDH)'%U97)Y*3L*("`@("`@("!I9B`H(21T:&ES+3YD8BT^
M3F5X=%]296-O<F0H*2D*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*$Y53$PL
M($Y53$PL($Y53$PI.PH*("`@("`@("`O+R!L87-T('5S960@<F5Q=6ER960@
M8GD@=&AE(&=A<F)A9V4@8V]L;&5C=&EO;B`@(`H@("`@("`@("\O(%=!4DY)
M3D<Z(&UI9VAT(&)E($UY4U%,('-P96-I9FEC("`@("`@("`@"B`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@B55!$051%("5S(%-%5"!C:&%N9V5D(#T@*$Y/
M5R@I("L@,"D@5TA%4D4@:60@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S
M)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?
M=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D:60L"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`*("`@("`@("`@("`@("`@
M("`@("`@("`@("`I.PH@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y
M*3L*("`@("`@("!R971U<FX@87)R87DH)'1H:7,M/F1B+3YF*"=E>'!I<F5S
M)RDL("1T:&ES+3YD96-O9&4H)'1H:7,M/F1B+3YF*"=C86-H961A=&$G*2DL
M("1T:&ES+3YD8BT^9B@G=7-E<F1A=&$G*2D["B`@("!]("\O(&5N9"!F=6YC
M(&9E=&-H"@H@("`@+RHJ"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@("`J
M(`H@("`@*B!705).24Y'.B!W92!U<V4@=&AE(%-13"!C;VUM86YD(%)%4$Q!
M0T4@24Y43R!T:&ES(&UI9VAT(&)E(`H@("`@*B!->5-13"!S<&5C:69I8RX@
M07,@37E344P@:7,@=F5R>2!P;W!U;&%R('1H92!M971H;V0@<VAO=6QD"B`@
M("`J('=O<FL@9FEN92!F;W(@.34E(&]F('EO=2X*("`@("HO"B`@("!F=6YC
M=&EO;B!S879E*"1I9"P@)&1A=&$L("1E>'!I<F5S+"`D9W)O=7`I('L*("`@
M("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@B4D503$%#12!)3E1/("5S("AC86-H961A
M=&$L(&5X<&ER97,L(&ED+"!C86-H96=R;W5P*2!604Q515,@*"<E<R<L("5D
M+"`G)7,G+"`G)7,G*2(L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!A9&1S;&%S:&5S*"1T:&ES+3YE;F-O9&4H)&1A=&$I*2P*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3YG971%>'!I<F5S06)S;VQU=&4H
M)&5X<&ER97,I("P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I9"P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<`H@("`@("`@("`@
M("`@("`@("`@("`@("`@*3L*("`@("`@("`D=&AI<RT^9&(M/G%U97)Y*"1Q
M=65R>2D["@H@("`@("`@(')E='5R;B`H8F]O;&5A;BDD=&AI<RT^9&(M/F%F
M9F5C=&5D7W)O=W,H*3L@"B`@("!]("\O(&5N9"!F=6YC('-A=F4*"B`@("!F
M=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I('L*("`@("`@("`D=&AI<RT^
M9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*("`@("`@("`D=&AI<RT^9&(M
M/G%U97)Y*`H@("`@("`@("`@("`@("`@("`@("`@("!S<')I;G1F*")$14Q%
M5$4@1E)/32`E<R!72$5212!I9"`]("<E<R<@04Y$(&-A8VAE9W)O=7`@/2`G
M)7,G(BP*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3YC86-H
M95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I9"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1G<F]U<`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@
M("!R971U<FX@*&)O;VQE86XI)'1H:7,M/F1B+3YA9F9E8W1E9%]R;W=S*"D[
M"B`@("!]("\O(&5N9"!F=6YC(')E;6]V90H*("`@(&9U;F-T:6]N(&9L=7-H
M*"1G<F]U<"D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@
M("`@("`@:68@*"1G<F]U<"D@>PH@("`@("`@("`@("`D=&AI<RT^9&(M/G%U
M97)Y*'-P<FEN=&8H(D1%3$5412!&4D]-("5S(%=(15)%(&-A8VAE9W)O=7`@
M/2`G)7,G(BP@)'1H:7,M/F-A8VAE7W1A8FQE+"`D9W)O=7`I*3L@("`@"B`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H:7,M/F1B+3YQ=65R>2AS
M<')I;G1F*")$14Q%5$4@1E)/32`E<R(L("1T:&ES+3YC86-H95]T86)L92DI
M.R`@("`*("`@("`@("!]"@H@("`@("`@(')E='5R;B`D=&AI<RT^9&(M/F%F
M9F5C=&5D7W)O=W,H*3L*("`@('T@+R\@96YD(&9U;F,@9FQU<V@*"B`@("!F
M=6YC=&EO;B!I9$5X:7-T<R@D:60L("1G<F]U<"D@>PH@("`@("`@("1T:&ES
M+3YD8BT^<75E<GDH"B`@("`@("`@("`@("`@("`@("`@("`@('-P<FEN=&8H
M(E-%3$5#5"!I9"!&4D]-("5S(%=(15)%($E$(#T@)R5S)R!!3D0@8V%C:&5G
M<F]U<"`]("<E<R<B+"`*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1I9"P@"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9W)O=7`*("`@
M("`@("`@("`@("`@("`@("`@("`@*2`@(`H@("`@("`@("`@("`@("`@("`@
M("D["@H@("`@("`@(')E='5R;B`H8F]O;&5A;BDD=&AI<RT^9&(M/FYF*"D[
M("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@?2`O+R!E;F0@9G5N8R!I
M<T5X:7-T<PH*("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL
M:69E=&EM92D@>PH@("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H*3L*"B`@
M("`@("`@)'1H:7,M/F1B+3YQ=65R>2@@"B`@("`@("`@("`@("`@("`@("`@
M("`@('-P<FEN=&8H(D1%3$5412!&4D]-("5S(%=(15)%("AE>'!I<F5S(#P]
M("5D($%.1"!E>'!I<F5S(#X@,"D@3U(@8VAA;F=E9"`\/2`H3D]7*"D@+2`E
M9"DB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE
M7W1A8FQE+"`*("`@("`@("`@("`@("`@("`@("`@("`@("`@('1I;64H*2P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1M87AL:69E=&EM90H@("`@
M("`@("`@("`@("`@("`@("`@("`I"B`@("`@("`@("`@("`@("`@("`@*3L*
M"B`@("`@("`@+R]C:&5C:R!F;W(@=&]T86P@<VEZ92!O9B!C86-H90H@("`@
M("`@("1Q=65R>2`]('-P<FEN=&8H)W-E;&5C="!S=6TH;&5N9W1H*&-A8VAE
M9&%T82DI(&%S($-A8VAE4VEZ92!F<F]M("5S)RP*("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YC86-H95]T86)L90H@("`@("`@("`@("`@("`@
M("`@("`@("D["@H@("`@("`@("1T:&ES+3YD8BT^<75E<GDH)'%U97)Y*3L*
M("`@("`@("`D=&AI<RT^9&(M/DYE>'1?4F5C;W)D*"D["B`@("`@("`@)&-A
M8VAE<VEZ92`]("1T:&ES+3YD8BT^9B@G0V%C:&53:7IE)RD["B`@("`@("`@
M+R]I9B!C86-H92!I<R!T;R!B:6<N"B`@("`@("`@:68@*"1C86-H97-I>F4@
M/B`D=&AI<RT^:&EG:'=A=&5R*0H@("`@("`@('L*("`@("`@("`@("`@+R]F
M:6YD('1H92!L;W=W871E<B!M87)K+@H@("`@("`@("`@("`D<75E<GD@/2!S
M<')I;G1F*"=S96QE8W0@;&5N9W1H*&-A8VAE9&%T82D@87,@<VEZ92P@8VAA
M;F=E9"!F<F]M("5S(&]R9&5R(&)Y(&-H86YG960@1$530R<L"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B
M;&4*("`@("`@("`@("`@("`@("`@("`@("`I.PH@("`@("`@("`@("`D=&AI
M<RT^9&(M/G%U97)Y*"1Q=65R>2D["@H@("`@("`@("`@("`D:V5E<%]S:7IE
M/3`["B`@("`@("`@("`@('=H:6QE("@D:V5E<%]S:7IE(#P@)'1H:7,M/FQO
M=W=A=&5R("8F("1T:&ES+3YD8BT^3F5X=%]296-O<F0H*2`I"B`@("`@("`@
M("`@('L*("`@("`@("`@("`@("`@("1K965P7W-I>F4@*ST@)'1H:7,M/F1B
M+3YF*"=S:7IE)RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@+R]D96QE
M=&4@86QL(&5N=')I97,L('=H:6-H('=E<F4@8VAA;F=E9"!B969O<F4@=&AE
M(")L;W=W=V%T97(@;6%R:R(*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT
M9B@G9&5L971E(&9R;VT@)7,@=VAE<F4@8VAA;F=E9"`\/2`G+B1T:&ES+3YD
M8BT^9B@G8VAA;F=E9"<I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("1T:&ES+3YD8BT^
M<75E<GDH)'%U97)Y*3L*("`@("`@("!]"B`@("!]("\O(&5N9"!F=6YC(&=A
M<F)A9V5#;VQL96-T:6]N"GT*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O0V%C:&4O0V]N=&%I;F5R
M+W-H;2YP:'``````````````````````````````````````````````````
M```````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R,3$S
M-2`Q,#4Q-30S-#$S,B`P,C(W,#<`(#``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````=7-T87(`,#!B=6EL
M9&5R`````````````````````````````````&)R````````````````````
M````````````````````,#`P,#`P(``P,#`P,#`@````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````/#]P:'`*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!#;W!Y<FEG:'0@*&,I
M(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO
M+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C="!T;R!V97)S:6]N(#(N
M,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*+R\@?"!T:&%T(&ES(&)U
M;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE(&9I;&4@3$E#14Y312P@
M86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE(&%T('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E;G-E+S)?,#(N='AT+B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@?"!)9B!Y;W4@
M9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@4$A0(&QI8V5N<V4@86YD
M(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE
M('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@
M("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W92!C86X@;6%I;"!Y;W4@
M82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@("`@('P*+R\@*RTM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T:&]R<SH@56QF(%=E;F1E
M;"`\=6QF+G=E;F1E;$!P:'!D;V,N9&4^("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?`HO+R!\("`@("`@("`@(%-E8F%S=&EA;B!"97)G;6%N;B`\<V)`
M<V5B87-T:6%N+6)E<F=M86YN+F1E/B`@("`@("`@("`@("`@('P*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@<VAM+G!H<"QV
M(#$N,R`R,#`S+S`Q+S`T(#$Q.C4T.C0V(&UJ($5X<"`D"@IR97%U:7)E7V]N
M8V4@)T-A8VAE+T-O;G1A:6YE<BYP:'`G.PH*+RHJ"BH@4W1O<F5S(&-A8VAE
M(&1A=&$@:6YT;R!S:&%R960@;65M;W)Y+@HJ"BH@5V5L;"P@=&AI<R!I<R!N
M;W0@82!V97)Y(&5F9FEC:65N="!I;7!L96UE;G1A=&EO;BX@26YD965D(&ET
M)W,@;75C:"`**B!S;&]W97(@=&AA;B!T:&4@9FEL92!C;VYT86EN97(@87,@
M9F%R(&%S(&UY('1E<W1S('-H;W=E9"X@1FEL97,@87)E(`HJ(&-A8VAE9"!B
M>2!M;W-T(&]P97)A=&EN9R!S>7-T96US(&%N9"!I="!W:6QL(&)E(&AA<F0@
M=&\@=W)I=&4@82!F87-T97(@"BH@8V%C:&EN9R!A;&=O<FET:&T@=7-I;F<@
M4$A0+@HJ"BH@0&%U=&AO<B`@(%5L9B!796YD96P@/'5L9BYW96YD96Q`<&AP
M9&]C+F1E/@HJ($!V97)S:6]N("`D260Z('-H;2YP:'`L=B`Q+C,@,C`P,R\P
M,2\P-"`Q,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ+PIC
M;&%S<R!#86-H95]#;VYT86EN97)?<VAM(&5X=&5N9',@0V%C:&5?0V]N=&%I
M;F5R('L*("`@("\J*@H@("`@*B!+97D@;V8@=&AE('-E;6%P:&]R92!U<V5D
M('1O('-Y;F,@=&AE(%-(32!A8V-E<W,*("`@("H@"B`@("`J($!V87(@(&EN
M=`H@("`@*B\*("`@('9A<B`D<V5M7VME>2`]($Y53$P["@H@("`@+RHJ"B`@
M("`J(%!E<FUI<W-I;VYS(&]F('1H92!S96UA<&AO<F4@=7-E9"!T;R!S>6YC
M('1H92!32$T@86-C97-S"B`@("`J(`H@("`@*B!`=F%R("!I;G0*("`@("HO
M"B`@("!V87(@)'-E;5]P97)M(#T@,#8T-#L*"B`@("`O*BH*("`@("H@4V5M
M87!H;W)E(&AA;F1L97(*("`@("H@"B`@("`J($!V87(@(')E<V]U<F-E"B`@
M("`J+PH@("`@=F%R("1S96U?:60@/2!.54Q,.PH*("`@("\J*@H@("`@*B!+
M97D@;V8@=&AE('-H87)E9"!M96UO<GD@8FQO8VL@=7-E9"!T;R!S=&]R92!C
M86-H92!D871A"B`@("`J"B`@("`J($!V87(@(&EN=`H@("`@*B\*("`@('9A
M<B`D<VAM7VME>2`]($Y53$P["@H@("`@+RHJ"B`@("`J(%-I>F4@;V8@=&AE
M('-H87)E9"!M96UO<GD@8FQO8VL@=7-E9`H@("`@*B`*("`@("H@3F]T93H@
M=&AE(&-O;G1A:6YE<B!D;V5S(&]N;'D@=7-E(%]O;F5?('-H;2!B;&]C:R!N
M;R!M;W)E(0H@("`@*B`*("`@("H@0'9A<B`@:6YT"B`@("`J+R`@("`@("`@
M"B`@("!V87(@)'-H;5]S:7IE(#T@,3,Q,#<R.PH*("`@("\J*@H@("`@*B!0
M97)M:7-S:6]N<R!O9B!T:&4@<VAA<F5D(&UE;6]R>2!B;&]C:PH@("`@*B`*
M("`@("H@0'9A<B`@:6YT"B`@("`J+PH@("`@=F%R("1S:&U?<&5R;2`](#`V
M-#0["@H@("`@+RHJ"B`@("`J(%-H87)E9"!M96UO<GD@:&%N9&QE<@H@("`@
M*B`*("`@("H@0'9A<B!R97-O=7)C90H@("`@*B\*("`@('9A<B`D<VAM7VED
M(#T@3E5,3#L*"B`@("`O*BH*("`@("H@2&%S:"!O9B!C86-H92!E;G1R:65S
M"B`@("`J(`H@("`@*B!5<V5D(&)Y('1H92!G87)B86=E(&-O;&QE8W1I;VX@
M=&\@9FEN9"!O;&0@96YT<FEE<RX*("`@("H*("`@("H@0'9A<B`@87)R87D*
M("`@("HO"B`@("!V87(@)&5N=')I97,@/2!A<G)A>2@I.PH*("`@("\J*@H@
M("`@*B!.=6UB97(@;V8@8GET97,@8V]N<W5M960@8GD@=&AE(&-A8VAE"B`@
M("`J(`H@("`@*B!`=F%R("!I;G0*("`@("HO"B`@("!V87(@)'1O=&%L7W-I
M>F4@/2`P.PH*("`@("\J*@H@("`@*B!#<F5A=&5S(&$@<VAA<F5D(&UE;6]R
M>2!C;VYT86EN97(*("`@("H*("`@("H@0'!A<F%M(&%R<F%Y("`@('-H;5]K
M97DL('-E;5]K97DL('-H;5]S:7IE+"!S96U?<&5R;2P@<VAM7W!E<FT*("`@
M("HO("`@(`H@("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7W-H;2@D;W!T
M:6]N<R`]("<G*2!["B`@("`@("`@:68@*&ES7V%R<F%Y*"1O<'1I;VYS*2D*
M("`@("`@("`@("`@)'1H:7,M/G-E=$]P=&EO;G,H)&]P=&EO;G,L(&%R<F%Y
M7VUE<F=E*"1T:&ES+3YA;&QO=V5D7V]P=&EO;G,L(`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87DH
M)W-H;5]K97DG+"`@)W-E;5]K97DG+"`*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=S:&U?<VEZ
M92<L("=S96U?<&5R;2<L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`G<VAM7W!E<FTG"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@
M("`@("\O($-A8VAE.CI#;VYT86EN97(@:&EG:"T@86YD(&QO=W=A=&5R(&1E
M9F%U;'1S('-H;W5L9"!B92!O=F5R<FED9&5N(&EF"B`@("`@("`@+R\@;F]T
M(&%L<F5A9'D@9&]N92!B>2!T:&4@=7-E<@H@("`@("`@(&EF("@A:7-S970H
M)&]P=&EO;G-;)VAI9VAW871E<B==*2D@"B`@("`@("`@("`@("1T:&ES+3YH
M:6=H=V%T97(@/2!R;W5N9"@P+C<U("H@,3,Q,#<R*3L*("`@("`@("!I9B`H
M(6ES<V5T*"1O<'1I;VYS6R=L;W=W871E<B==*2D*("`@("`@("`@("`@)'1H
M:7,M/FQO=W=A=&5R(#T@<F]U;F0H,"XU("H@,3,Q,#<R*3L*"B`@("`@("`@
M:68@*"%I<W-E="@D;W!T:6]N<ULG<VAM7W-I>F4G72DI"B`@("`@("`@("`@
M("1T:&ES+3YS:&U?<VEZ92`](#$S,3`W,CL*"B`@("`@("`@+R]G970@4TA-
M(&%N9"!396UA<&AO<F4@:&%N9&QE<PH@("`@("`@(&EF("@A*"1T:&ES+3YS
M:&U?:60@/2!S:&UO<%]O<&5N*"1T:&ES+3YS:&U?:V5Y+"`G8R<L("1T:&ES
M+3YS:&U?<&5R;2P@)'1H:7,M/G-H;5]S:7IE*2DI"B`@("`@("`@("`@(&YE
M=R!#86-H95]%<G)O<B@B0V%N)W0@;W!E;B!32$T@<V5G;65N="`G>R1T:&ES
M+3YS:&U?:V5Y?2<L('-I>F4@)WLD=&AI<RT^<VAM7W-I>F5])RXB+`H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%7U\L"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!?7TQ)3D5?7PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`I.PH*("`@("`@("!I9B`H(2@D=&AI<RT^<V5M7VED(#T@<V5M
M7V=E="@D=&AI<RT^<V5M7VME>2P@,2P@)'1H:7,M/G-E;5]P97)M*2DI"B`@
M("`@("`@("`@(&YE=R!#86-H95]%<G)O<B@B0V%N)W0@9V5T('-E;6%P:&]R
M92`G>R1T:&ES+3YS96U?:V5Y?2<@=7-I;F<@<&5R;7,@)WLD=&AI<RT^<V5M
M7W!E<FU])RXB+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@7U]&24Q%
M7U\L"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!?7TQ)3D5?7PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@('T@+R\@96YD(&-O;G-T
M<G5C=&]R"@H@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I('L*("`@
M("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@)&-A
M8VAE9&%T82`]('-H;6]P7W)E860H)'1H:7,M/G-H;5]I9"P@,"P@)'1H:7,M
M/G-H;5]S:7IE*3L*"B`@("`@("`@<V5M7W)E;&5A<V4H)'1H:7,M/G-E;5]I
M9"D["@H@("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^9&5C;V1E*"1C86-H
M961A=&$I.PH*("`@("`@("!I9B`H(6ES<V5T*"1C86-H961A=&%;)&=R;W5P
M75LD:61=*2D*("`@("`@("`@("`@<F5T=7)N(&%R<F%Y*$Y53$PL($Y53$PL
M($Y53$PI.PH@("`@("`@(&5L<V4@"B`@("`@("`@("`@("1C86-H961A=&$@
M/2`D8V%C:&5D871A6R1G<F]U<%U;)&ED73L*"B`@("`@("`@<F5T=7)N(&%R
M<F%Y*"1C86-H961A=&%;)V5X<&ER92==+`H@("`@("`@("`@("`@("`@("`@
M("`D8V%C:&5D871A6R=C86-H961A=&$G72P*("`@("`@("`@("`@("`@("`@
M("`@)&-A8VAE9&%T85LG=7-E<F1A=&$G70H@("`@("`@("`@("`@("`@("`@
M("D["B`@("!]("\O(&5N9"!F=6YC(&9E=&-H"@H@("`@9G5N8W1I;VX@<V%V
M92@D:60L("1D871A+"`D97AP:7)E+"`D9W)O=7`L("1U<V5R9&%T82D@>PH@
M("`@("`@("1T:&ES+3YF;'5S:%!R96QO860H)&ED+"`D9W)O=7`I.PH*("`@
M("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M7VED*3L*"B`@("`@("`@)&-A
M8VAE9&%T82`]("1T:&ES+3YD96-O9&4H<VAM;W!?<F5A9"@D=&AI<RT^<VAM
M7VED+"`P+"`D=&AI<RT^<VAM7W-I>F4I*3L*("`@("`@("`D8V%C:&5D871A
M6R1G<F]U<%U;)&ED72`](&%R<F%Y*"=E>'!I<F4G("`@(#T^("1T:&ES+3YG
M971%>'!I<F5S06)S;VQU=&4H)&5X<&ER92DL"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`G8V%C:&5D871A)R`]/B`D9&%T82P*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("=U<V5R
M9&%T82<@(#T^("1U<V5R9&%T82P*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("=C:&%N9V5D)R`@(#T^('1I;64H*0H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`I.PH*("`@("`@("!I
M9B`H<W1R;&5N*"1N97=D871A(#T@)'1H:7,M/F5N8V]D92@D8V%C:&5D871A
M*2D@/B`D=&AI<RT^<VAM7W-I>F4I"B`@("`@("`@("`@("1C86-H961A=&$@
M/2`D=&AI<RT^9V%R8F%G94-O;&QE8W1I;VXH=&EM92@I+"`D8V%C:&5D871A
M*3L*"B`@("`@("`@<VAM;W!?=W)I=&4H)'1H:7,M/G-H;5]I9"P@)&YE=V1A
M=&$L(#`I.PH*("`@("`@("!S96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*
M"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]("\O(&5N9"!F=6YC('-A=F4*
M"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED+"`D9W)O=7`I('L*("`@("`@("`D
M=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@("`@<V5M
M7V%C<75I<F4H)'1H:7,M/G-E;5]I9"D["@H@("`@("`@("1C86-H961A=&$@
M/2`D=&AI<RT^9&5C;V1E*'-H;6]P7W)E860H)'1H:7,M/G-H;5]I9"P@,"P@
M)'1H:7,M/G-H;5]S:7IE*2D["B`@("`@("`@=6YS970H)&-A8VAE9&%T85LD
M9W)O=7!=6R1I9%TI.PH@("`@("`@('-H;6]P7W=R:71E*"1T:&ES+3YS:&U?
M:60L("1T:&ES+3YE;F-O9&4H)&-A8VAE9&%T82DL(#`I.PH*("`@("`@("!S
M96U?<F5L96%S92@D=&AI<RT^<V5M7VED*3L*("`@('T@+R\@96YD(&9U;F,@
M<F5M;W9E"@H@("`@9G5N8W1I;VX@9FQU<V@H)&=R;W5P(#T@)R<I('L*("`@
M("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["@H@("`@("`@('-E;5]A8W%U
M:7)E*"1T:&ES+3YS96U?:60I.PH*("`@("`@("!S:&UO<%]W<FET92@D=&AI
M<RT^<VAM7VED+"`D=&AI<RT^96YC;V1E*&%R<F%Y*"DI+"`P*3L*"B`@("`@
M("`@<V5M7W)E;&5A<V4H)'1H:7,M/G-E;5]I9"D["B`@("!]("\O(&5N9"!F
M=6YC(&9L=7-H"@H@("`@9G5N8W1I;VX@:61%>&ES=',H)&ED+"`D9W)O=7`I
M('L*("`@("`@("!S96U?86-Q=6ER92@D=&AI<RT^<V5M7VED*3L*"B`@("`@
M("`@)&-A8VAE9&%T82`]('-H;5]R96%D*"1T:&ES+3YS:&U?:60L(#`L("1T
M:&ES+3YS:&U?<VEZ92D["@H@("`@("`@('-E;5]R96QE87-E*"1T:&ES+3YS
M96U?:60I.PH*("`@("`@("`D8V%C:&5D871A(#T@)'1H:7,M/F1E8V]D92@D
M8V%C:&5D871A*3L*"B`@("`@("`@<F5T=7)N(&ES<V5T*"1C86-H961A=&%;
M)&=R;W5P75LD:61=*3L*("`@('T@+R\@96YD(&9U;F,@:7-%>&ES=',*"B`@
M("!F=6YC=&EO;B!G87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF971I;64L("1C
M86-H961A=&$@/2!A<G)A>2@I*2!["B`@("`@("`@:68@*"1L;V-K(#T@96UP
M='DH)&-A8VAE9&%T82DI('L*("`@("`@("`@("`@<V5M7V%C<75I<F4H)'1H
M:7,M/G-E;5]I9"D["B`@("`@("`@("`@("1C86-H961A=&$@/2`D=&AI<RT^
M9&5C;V1E*'-H;6]P7W)E860H)'1H:7,M/G-H;5]I9"P@,"P@)'1H:7,M/G-H
M;5]S:7IE*2D["B`@("`@("`@?0H*("`@("`@("`D=&AI<RT^9&]'87)B86=E
M0V]L;&5C=&EO;B@D;6%X;&EF971I;64L("8D8V%C:&5D871A*3L*("`@("`@
M("!I9B`H)'1H:7,M/G1O=&%L7W-I>F4@/B`D=&AI<RT^:&EG:'=A=&5R*2![
M"B`@("`@("`@("`@(&MR<V]R="@D=&AI<RT^96YT<FEE<RD["B`@("`@("`@
M("`@(')E<V5T*"1T:&ES+3YE;G1R:65S*3L*"B`@("`@("`@("`@('=H:6QE
M("@D=&AI<RT^=&]T86Q?<VEZ92`^("1T:&ES+3YL;W=W871E<B`F)B!L:7-T
M*"1S:7IE+"`D96YT<FEE<RD@/2!E86-H*"1T:&ES+3YE;G1R:65S*2D@>PH@
M("`@("`@("`@("`@("`@<F5S970H)&5N=')I97,I.PH*("`@("`@("`@("`@
M("`@('=H:6QE("AL:7-T*"1K+"`D96YT<GDI(#T@96%C:"@D96YT<FEE<RDI
M('L*("`@("`@("`@("`@("`@("`@("!U;G-E="@D8V%C:&5D871A6R1E;G1R
M>5LG9W)O=7`G75U;)&5N=')Y6R=I9"==72D["B`@("`@("`@("`@("`@("`@
M("`@)'1H:7,M/G1O=&%L7W-I>F4@+3T@)'-I>F4["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@(&EF("@D;&]C
M:RD*("`@("`@("`@("`@<V5M7W)E;&5A<V4H)'1H:7,M/G-E;5]I9"D["@H@
M("`@("`@("1T:&ES+3YE;G1R:65S(#T@87)R87DH*3L*("`@("`@("`D=&AI
M<RT^=&]T86Q?<VEZ92`](#`["@H@("`@("`@(')E='5R;B`D8V%C:&5D871A
M.R`@("`@("`@("`@"B`@("!]("\O(&5N9"!F=6YC(&=A<F)A9V5#;VQL96-T
M:6]N"@H@("`@9G5N8W1I;VX@9&]'87)B86=E0V]L;&5C=&EO;B@D;6%X;&EF
M971I;64L("8D8V%C:&5D871A*2!["B`@("`@("`@)&-H86YG960@/2!T:6UE
M*"D@+2`D;6%X;&EF971I;64["B`@("`@("`@)')E;6]V960@/2`P.PH*("`@
M("`@("!R97-E="@D8V%C:&5D871A*3L*"B`@("`@("`@=VAI;&4@*&QI<W0H
M)&=R;W5P+"`D9W)O=7!D871A*2`](&5A8V@H)&-A8VAE9&%T82DI('L*("`@
M("`@("`@("`@<F5S970H)&=R;W5P9&%T82D["@H@("`@("`@("`@("!W:&EL
M92`H;&ES="@D:60L("1D871A*2`](&5A8V@H)&=R;W5P9&%T82DI('L*("`@
M("`@("`@("`@("`@(&EF("@D9&%T85LG97AP:7)E)UT@/"!T:6UE*"D@?'P@
M)&1A=&%;)V-H86YG960G72`\("1C:&%N9V5D*2!["B`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&-A8VAE9&%T85LD9W)O=7!=6R1I9%TI.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!U9VQY
M(&)U="!S:6UP;&4@=&\@:6UP;&5M96YT(#HO"B`@("`@("`@("`@("1S:7IE
M(#T@<W1R;&5N*"1T:&ES+3YE;F-O9&4H)&1A=&$I*3L*("`@("`@("`@("`@
M)'1H:7,M/F5N=')I97-;)'-I>F5=6UT@/2!A<G)A>2@G9W)O=7`G(#T^("1G
M<F]U<"P*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`G:60G("`@(#T^("1I9`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("1T:&ES+3YT;W1A
M;%]S:7IE("L]("1S:7IE.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1R
M96UO=F5D.PH@("`@?2`@+R\@96YD(&9U;F,@9&]'87)B86=E0V]L;&5C=&EO
M;@I]("\O(&5N9"!C;&%S<R!#86-H95]#;VYT86EN97)?<VAM"C\^"@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]#86-H92]#
M;VYT86EN97(O=')I9FEL92YP:'``````````````````````````````````
M`````````````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#$Q,C,T(#$P-3$U-#,T,3,R(#`R,S4U-0`@,```````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!014%2(#HZ($-A8VAE("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PHO+R!\($-O<'ER
M:6=H="`H8RD@,3DY-RTR,#`T(%1H92!02%`@1W)O=7`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK"B\O('P@5&AI<R!S;W5R8V4@9FEL92!I<R!S=6)J96-T('1O('9E
M<G-I;VX@,BXP(&]F('1H92!02%`@;&EC96YS92P@("`@("`@?`HO+R!\('1H
M870@:7,@8G5N9&QE9"!W:71H('1H:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,
M24-%3E-%+"!A;F0@:7,@("`@("`@('P*+R\@?"!A=F%I;&%B;&4@870@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(@870@("`@("`@("`@("`@("`@("`@
M("`@("`@("!\"B\O('P@:'1T<#HO+W=W=RYP:'`N;F5T+VQI8V5N<V4O,E\P
M,BYT>'0N("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?`HO+R!\
M($EF('EO=2!D:60@;F]T(')E8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC
M96YS92!A;F0@87)E('5N86)L92!T;R`@('P*+R\@?"!O8G1A:6X@:70@=&AR
M;W5G:"!T:&4@=V]R;&0M=VED92UW96(L('!L96%S92!S96YD(&$@;F]T92!T
M;R`@("`@("`@("!\"B\O('P@;&EC96YS94!P:'`N;F5T('-O('=E(&-A;B!M
M86EL('EO=2!A(&-O<'D@:6UM961I871E;'DN("`@("`@("`@("`@("`@?`HO
M+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@?"!!=71H;W)S.B!5
M;&8@5V5N9&5L(#QU;&8N=V5N9&5L0'!H<&1O8RYD93X@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\"B\O('P@("`@("`@("`@4V5B87-T:6%N($)E<F=M
M86YN(#QS8D!S96)A<W1I86XM8F5R9VUA;FXN9&4^("`@("`@("`@("`@("`@
M?`HO+R!\("`@("`@("`@($EA;B!%=7)E(#QI975R94!P:'`N;F5T/B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TK"B\O"B\O("1)9#H@=')I9FEL92YP:'`L=B`Q
M+C$@,C`P-"\P-"\P,2`P-SHU,#HP-R!C:')E9W4@17AP("0*"G)E<75I<F5?
M;VYC92`G0V%C:&4O0V]N=&%I;F5R+V9I;&4N<&AP)SL*"B\J*@H@*B!4<FDM
M9FEL92!C86-H92X*("H*("H@5&AI<R!C86-H92!C;VYT86EN97(@<W1O<F5S
M(&9I;&5S('=I=&@@;F\@<W!E8VEA;"!E;F-O9&EN9R!T;R!R961U8V4@;W9E
M<FAE860N"B`J($5X<&ER871I;VX@)B!U<V5R(&1A=&$@87)E('-T;W)E9"!I
M;B!S97!E<F%T92!F:6QE<RP@<')E9FEX960@=VET:"!A("<N)R!A;F0*("H@
M<W5F9FEX960@=VET:"`G+F5X<"<@)B`G+F1A="<@<F5S<&5C=&EV96QY+@H@
M*@H@*B!3964@:'1T<#HO+V%T;VUI>F5D+F]R9R]014%2+T-A8VAE7W1R:69I
M;&4N:'1M;"!F;W(@;6]R92!I;F9O<FUA=&EO;BX*("H*("H@0&%U=&AO<B!)
M86X@175R92`\:65U<F5`<&AP+FYE=#X*("H@0'9E<G-I;VX@,2XP"B`J+PIC
M;&%S<R!#86-H95]#;VYT86EN97)?=')I9FEL92!E>'1E;F1S($-A8VAE7T-O
M;G1A:6YE<E]F:6QE('L*("`@("\J*@H@("`@("H@1F5T8V@@8V%C:&5D(&9I
M;&4N"B`@("`@*@H@("`@("H@0'!A<F%M('-T<FEN9R`D:60@0V%C:&4@240@
M=&\@9F5T8V@*("`@("`J($!P87)A;2!S=')I;F<@)&=R;W5P($=R;W5P('1O
M(&9E=&-H(&9R;VT*("`@("`J($!R971U<FX@87)R87D@,2UD:6UE;G-I;VYA
M;"!A<G)A>2!I;B!T:&4@9F]R;6%T.B!E>'!I<F%T:6]N+&1A=&$L=7-E<F1A
M=&$*("`@("`J+PH@("`@9G5N8W1I;VX@9F5T8V@H)&ED+"`D9W)O=7`I"B`@
M("!["B`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T1FEL96YA;64H)&ED+"`D
M9W)O=7`I.PH@("`@("`@(&EF("@A9FEL95]E>&ES=',H)&9I;&4I*0H@("`@
M("`@("`@("!R971U<FX@87)R87DH3E5,3"P@3E5,3"P@3E5,3"D["B`@("`@
M("`@"B`@("`@("`@<F5T=7)N(&%R<F%Y*`H@("`@("`@("`@("`@("`@9FEL
M95]G971?8V]N=&5N=',H)'1H:7,M/E]G971%>'!&:6QE*"1F:6QE*2DL"B`@
M("`@("`@("`@("`@("!F:6QE7V=E=%]C;VYT96YT<R@D9FEL92DL"B`@("`@
M("`@("`@("`@("!F:6QE7V=E=%]C;VYT96YT<R@D=&AI<RT^7V=E=%5$1FEL
M92@D9FEL92DI"B`@("`@("`@*3L*("`@('T*("`@(`H@("`@+RHJ"B`@("`@
M*B!'970@=&AE(&9I;&4@=&\@<W1O<F4@8V%C:&4@9&%T82!I;BX*("`@("`J
M"B`@("`@*B!`<F5T=7)N('-T<FEN9R!#86-H92!D871A(&9I;&4@;F%M90H@
M("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]G
M971&:6QE*"1F:6QE*0H@("`@>PH@("`@("`@("1D:7(@/2!D:7)N86UE*"1F
M:6QE*3L*("`@("`@("`D9FEL92`](&)A<V5N86UE*"1F:6QE*3L*("`@("`@
M("!R971U<FX@)&1I<BXG+RXG+B1F:6QE.PH@("`@?0H@("`@"B`@("`O*BH*
M("`@("`J($=E="!T:&4@9FEL92!T;R!S=&]R92!E>'!I<F%T:6]N(&1A=&$@
M:6XN"B`@("`@*@H@("`@("H@0')E='5R;B!S=')I;F<@17AP:7)A=&EO;B!D
M871A(&9I;&4@;F%M90H@("`@("H@0&%C8V5S<R!P<FEV871E"B`@("`@*B\*
M("`@(&9U;F-T:6]N(%]G971%>'!&:6QE*"1F:6QE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V=E=$9I;&4H)&9I;&4I+B<N97AP)SL*("`@('T*
M("`@(`H@("`@+RHJ"B`@("`@*B!'970@=&AE(&9I;&4@=&\@<W1O<F4@=7-E
M<B!D871A(&EN+@H@("`@("H*("`@("`J($!R971U<FX@<W1R:6YG(%5S97(@
M9&%T82!F:6QE(&YA;64*("`@("`J($!A8V-E<W,@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?9V5T541&:6QE*"1F:6QE*0H@("`@>PH@("`@("`@
M(')E='5R;B`D=&AI<RT^7V=E=$9I;&4H)&9I;&4I+B<N9&%T)SL*("`@('T*
M("`@(`H@("`@+RHJ"B`@("`@*B!#86-H92!F:6QE"B`@("`@*@H@("`@("H@
M0'!A<F%M('-T<FEN9R`D:60@0V%C:&4@240*("`@("`J($!P87)A;2!M:7AE
M9"`D8V%C:&5D871A($1A=&$@=&\@8V%C:&4*("`@("`J($!P87)A;2!M:7AE
M9"`D97AP:7)E<R!7:&5N('1H92!D871A(&5X<&ER97,*("`@("`J($!P87)A
M;2!S=')I;F<@)&=R;W5P($-A8VAE(&=R;W5P('1O('-T;W)E(&1A=&$@:6X*
M("`@("`J($!P87)A;2!M:7AE9"`D=7-E<F1A=&$@061D:71I;VYA;"!D871A
M('1O('-T;W)E"B`@("`@*B!`<F5T=7)N(&)O;VQE86X@=')U92!O;B!S=6-C
M97-S+"!F86QS92!O=&AE<G=I<V4*("`@("`J+PH@("`@9G5N8W1I;VX@<V%V
M92@D:60L("1C86-H961A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T
M82D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R
M;W5P*3L*"B`@("`@("`@)&9I;&4@/2`D=&AI<RT^9V5T1FEL96YA;64H)&ED
M+"`D9W)O=7`I.PH@("`@("`@(&EF("A014%2.CII<T5R<F]R*"1R97,@/2`D
M=&AI<RT^7W-A=F5$871A*"1F:6QE+"`D8V%C:&5D871A*2DI('L*("`@("`@
M("`@("`@<F5T=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(&EF("A014%2
M.CII<T5R<F]R*"1R97,@/2`D=&AI<RT^7W-A=F5$871A*"1T:&ES+3Y?9V5T
M17AP1FEL92@D9FEL92DL("1E>'!I<F5S*2DI('L*("`@("`@("`@("`@<F5T
M=7)N("1R97,["B`@("`@("`@?0H@("`@("`@(&EF*%!%05(Z.FES17)R;W(H
M)')E<R`]("1T:&ES+3Y?<V%V941A=&$H)'1H:7,M/E]G97151$9I;&4H)&9I
M;&4I+"`D=7-E<D1A=&$I*2D@>PH@("`@("`@("`@("!R971U<FX@)')E<SL*
M("`@("`@("!]"@H@("`@("`@(')E='5R;B!T<G5E.PH@("`@?0H*("`@("\J
M*@H@("`@("H@4V%V92!D871A(&EN(&$@9FEL90H@("`@("H*("`@("`J($!P
M87)A;2!S=')I;F<@)&9I;&4@1FEL92!T;R!S879E(&1A=&$@:6X*("`@("`J
M($!P87)A;2!S=')I;F<@)&1A=&$@1&%T82!T;R!S879E"B`@("`@*B!`<F5T
M=7)N(&UI>&5D('1R=64@;VX@<W5C8V5S<RP@0V%C:&5?17)R;W(@;W1H97)W
M:7-E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]S879E1&%T82@D9FEL92P@)&1A
M=&$I('L*("`@("`@("`O+R!3879E(&1A=&$*("`@("`@("!I9B`H(2@D9F@@
M/2!`9F]P96XH)&9I;&4L("=W8B<I*2D*("`@("`@("`@("`@<F5T=7)N(&YE
M=R!#86-H95]%<G)O<B@B0V%N)W0@86-C97-S("<D9FEL92<@=&\@<W1O<F4@
M8V%C:&4@9&%T82X@0VAE8VL@86-C97-S(')I9VAT<R!A;F0@<&%T:"XB+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@(`H@("`@("`@(&EF("@D=&AI
M<RT^9FEL94QO8VMI;F<I('L*("`@("`@("`@("`@9FQO8VLH)&9H+"!,3T-+
M7T58*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@9G=R:71E*"1F:"P@
M)&1A=&$I.PH@("`@("`@(`H@("`@("`@(&EF*"1T:&ES+3YF:6QE3&]C:VEN
M9RD@>PH@("`@("`@("`@("!F;&]C:R@D9F@L($Q/0TM?54XI.PH@("`@("`@
M('T*("`@("`@("`*("`@("`@("!F8VQO<V4H)&9H*3L*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*?0H*/SX`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M0V%C:&4O0V]N=&%I;F5R+V1B>"YP:'``````````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`R,C<U,2`Q,#4Q-30S-#$S,B`P,C(W,#(`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@4$5!4B`Z.B!#86-H92`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L*+R\@
M?"!#;W!Y<FEG:'0@*&,I(#$Y.3<M,C`P,R!4:&4@4$A0($=R;W5P("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM*PHO+R!\(%1H:7,@<V]U<F-E(&9I;&4@:7,@<W5B:F5C
M="!T;R!V97)S:6]N(#(N,"!O9B!T:&4@4$A0(&QI8V5N<V4L("`@("`@('P*
M+R\@?"!T:&%T(&ES(&)U;F1L960@=VET:"!T:&ES('!A8VMA9V4@:6X@=&AE
M(&9I;&4@3$E#14Y312P@86YD(&ES("`@("`@("!\"B\O('P@879A:6QA8FQE
M(&%T('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B(&%T("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?`HO+R!\(&AT='`Z+R]W=W<N<&AP+FYE="]L:6-E
M;G-E+S)?,#(N='AT+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P*+R\@?"!)9B!Y;W4@9&ED(&YO="!R96-E:79E(&$@8V]P>2!O9B!T:&4@
M4$A0(&QI8V5N<V4@86YD(&%R92!U;F%B;&4@=&\@("!\"B\O('P@;V)T86EN
M(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B+"!P;&5A<V4@<V5N9"!A
M(&YO=&4@=&\@("`@("`@("`@?`HO+R!\(&QI8V5N<V5`<&AP+FYE="!S;R!W
M92!C86X@;6%I;"!Y;W4@82!C;W!Y(&EM;65D:6%T96QY+B`@("`@("`@("`@
M("`@('P*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK"B\O('P@075T
M:&]R<SH@0VAR:7-T:6%N(%-T;V-K97(@/&-H<F5G=4!P:&%N="YC:#X@("`@
M("`@("`@("`@("`@("`@("`@("`@?`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L*+R\*+R\@)$ED.B!D8G@N<&AP+'8@,2XT(#(P,#,O,#$O,#0@
M,3$Z-30Z-#8@;6H@17AP("0*"@IR97%U:7)E7V]N8V4@)T-A8VAE+T-O;G1A
M:6YE<BYP:'`G.PH*+RHJ"BH@97AT+V1B>"!#86-H92!#;VYT86EN97(N"BH*
M*B!705).24Y'.B!/=&AE<B!S>7-T96US(&UI9VAT(&]R(&UI9VAT(&YO="!S
M=7!P;W)T(&-E<G1A:6X@9&%T871Y<&5S(&]F(`HJ('1H92!T86)L97,@<VAO
M=VXN($%S(&9A<B!A<R!)(&MN;W<@=&AE<F4G<R!N;R!L87)G92!B:6YA<GD@
M"BH@='EP92!I;B!344PM.3(@;W(@4U%,+3DY+B!0;W-T9W)E<R!S965M<R!T
M;R!L86-K(&%N>2`**B!"3$]"(&]R(%1%6%0@='EP92P@9F]R($U3+5-13"!Y
M;W4@8V]U;&0@=7-E($E-04=%+"!D;VXG="!K;F]W(`HJ(&%B;W5T(&]T:&5R
M(&1A=&%B87-E<RX@4&QE87-E(&%D9"!S=6=E<W1I;VYS(&9O<B!O=&AE<B!D
M871A8F%S97,@=&\@"BH@=&AE(&EN;&EN92!D;V-S+@HJ"BH@5&AE(&9I96QD
M("=C:&%N9V5D)R!H87,@;F\@;65A;FEN9R!F;W(@=&AE($-A8VAE(&ET<V5L
M9BX@270G<R!J=7-T('1H97)E(`HJ(&)E8V%U<V4@:70G<R!A(&=O;V0@:61E
M82!T;R!H879E(&%N(&%U=&]M871I8V%L;'D@=7!D871E9"!T:6UE<W1A;7`*
M*B!F:65L9"!F;W(@9&5B=6=G:6YG(&EN(&%L;"!O9B!Y;W5R('1A8FQE<RX*
M*@HJ($9O<B!?37E344Q?('EO=2!N965D('1H:7,@1$(@=&%B;&4Z"BH**B!#
M4D5!5$4@5$%"3$4@8V%C:&4@*`HJ("`@:60@("`@("`@("`@0TA!4B@S,BD@
M3D]4($Y53$P@1$5&055,5"`G)RP**B`@(&-A8VAE9W)O=7`@(%9!4D-(05(H
M,3(W*2!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@8V%C:&5D871A("`@0DQ/
M0B!.3U0@3E5,3"!$149!54Q4("<G+`HJ("`@=7-E<F1A=&$@("`@5D%20TA!
M4B@R-34I($Y/5"!.54Q,($1%1D%53%0@)R<L"BH@("!E>'!I<F5S("`@("!)
M3E0H.2D@3D]4($Y53$P@1$5&055,5"`P+`HJ("`**B`@(&-H86YG960@("`@
M(%1)34535$%-4"@Q-"D@3D]4($Y53$PL"BH@(`HJ("`@24Y$15@@*&5X<&ER
M97,I+`HJ("`@4%))34%262!+15D@*&ED+"!C86-H96=R;W5P*0HJ("D**@HJ
M($!A=71H;W(@("!#:')I<W1I86X@4W1O8VME<B`\8VAR96=U0'!H86YT+F-H
M/@HJ($!V97)S:6]N("`D260Z(&1B>"YP:'`L=B`Q+C0@,C`P,R\P,2\P-"`Q
M,3HU-#HT-B!M:B!%>'`@)`HJ($!P86-K86=E("!#86-H90HJ+PIC;&%S<R!#
M86-H95]#;VYT86EN97)?9&)X(&5X=&5N9',@0V%C:&5?0V]N=&%I;F5R('L*
M"B`@("`O*BH*("`@("H@3F%M92!O9B!T:&4@1$(@=&%B;&4@=&\@<W1O<F4@
M8V%C:&EN9R!D871A"B`@("`J(`H@("`@*B!`<V5E("!#86-H95]#;VYT86EN
M97)?9FEL93HZ)&9I;&5N86UE7W!R969I>`H@("`@*B\@(`H@("`@=F%R("1C
M86-H95]T86)L92`]("<G.PH*("`@("\J*@H@("`@*B!$0G@@;6]D=6QE('1O
M('5S90H@("`@*@H@("`@*B`@870@=&AE(&UO;65N="!O;FQY(&UY<W%L(&]R
M(&]D8F,*("`@("H@"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A
M<B`D;6]D=6QE(#T@)R<["@H@("`@+RHJ"B`@("`J($1"(&AO<W0@=&\@=7-E
M"B`@("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&AO
M<W0@/2`G)SL*"B`@("`O*BH*("`@("H@1$(@9&%T86)A<V4@=&\@=7-E"B`@
M("`J(`H@("`@*B!`=F%R("!S=')I;F<*("`@("HO"B`@("!V87(@)&1B(#T@
M)R<["@H@("`@+RHJ"B`@("`J($1"('5S97)N86UE('1O('5S90H@("`@*B`*
M("`@("H@0'9A<B`@<W1R:6YG"B`@("`J+PH@("`@=F%R("1U<V5R;F%M92`]
M("<G.PH*("`@("\J*@H@("`@*B!$0B!P87-S=V]R9"!T;R!U<V4*("`@("H@
M"B`@("`J($!V87(@('-T<FEN9PH@("`@*B\*("`@('9A<B`D<&%S<W=O<F0@
M/2`G)SL*"B`@("`O*BH*("`@("H@1$)X(&AA;F1L92!O8FIE8W0*("`@("H@
M"B`@("`J($!V87(@(&]B:F5C="!$0G@@:&%N9&QE"B`@("`J+PH@("`@=F%R
M("1D8CL*("`@(`H@("`@"B`@("`O*BH*("`@("H@17-T86)L:7-H(&$@<&5R
M<VES=&5N="!C;VYN96-T:6]N/PH@("`@*B`*("`@("H@0'9A<B`@8F]O;&5A
M;B`*("`@("HO"B`@("!V87(@)'!E<G-I<W1E;G0@/2!T<G5E.PH@("`@"@H@
M("`@9G5N8W1I;VX@0V%C:&5?0V]N=&%I;F5R7V1B>"@D;W!T:6]N<RD*("`@
M('L*("`@("`@("!I9B`H(6ES7V%R<F%Y*"1O<'1I;VYS*2`I('L*("`@("`@
M("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G3F\@;W!T:6]N<R!S<&5C
M:69I960A)RP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@
M("`@("1T:&ES+3YS971/<'1I;VYS*"1O<'1I;VYS+"`@87)R87E?;65R9V4H
M)'1H:7,M/F%L;&]W961?;W!T:6]N<RP@87)R87DH)VUO9'5L92<L)VAO<W0G
M+"=D8B<L)W5S97)N86UE)RPG<&%S<W=O<F0G+"`G8V%C:&5?=&%B;&4G+"`G
M<&5R<VES=&5N="<I*2D["@H@("`@("`@(&EF("@A)'1H:7,M/FUO9'5L92D*
M("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G3F\@;6]D=6QE
M('-P96-I9FEE9"$G+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D
M=&AI<RT^9&(@/2!D8GA?8V]N;F5C="@D=&AI<RT^;6]D=6QE+"`D=&AI<RT^
M:&]S="P@)'1H:7,M/F1B+"`D=&AI<RT^=7-E<FYA;64L("1T:&ES+3YP87-S
M=V]R9"P@)'1H:7,M/G!E<G-I<W1E;G0I.PH*("`@("`@("!I9B`H9&)X7V5R
M<F]R*"1T:&ES+3YD8BDI('L*("`@("`@("`@("`@<F5T=7)N(&YE=R!#86-H
M95]%<G)O<B@G1$)X(&-O;FYE8W0@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T
M:&ES+3YD8BDL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@+R]N;W0@:6UP;&5M96YT960@>65T(&EN(&1B>`H@
M("`@("`@("`@("`O+R1T:&ES+3YD8BT^<V5T1F5T8VA-;V1E*$1"7T9%5$-(
M34]$15]!4U-/0RD["B`@("`@("`@?0H@("`@?0H*("`@(&9U;F-T:6]N(&9E
M=&-H*"1I9"P@)&=R;W5P*0H@("`@>PH@("`@("`@("1Q=65R>2`]('-P<FEN
M=&8H(E-%3$5#5"!C86-H961A=&$L('5S97)D871A+"!E>'!I<F5S($923TT@
M)7,@5TA%4D4@:60@/2`G)7,G($%.1"!C86-H96=R;W5P(#T@)R5S)R(L"B`@
M("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@
M("`@("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@
M("`@("`@("`@("`@("`@("`@("!A9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@
M("`@("`@("`@("`@("`@("`@*3L*"B`@("`@("`@)')E<R`](&1B>%]Q=65R
M>2@D=&AI<RT^9&(L("1Q=65R>2D["B`@("`@("`@:68@*&1B>%]E<G)O<B@D
M=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["@H@("`@("`@("1R;W<@/2`D<F5S+3YD
M871A6S!=.PH*("`@("`@("!I9B`H:7-?87)R87DH)')O=RDI"B`@("`@("`@
M("`@("1D871A(#T@87)R87DH)')O=ULG97AP:7)E<R==+"`D=&AI<RT^9&5C
M;V1E*"1R;W=;)V-A8VAE9&%T82==*2P@)')O=ULG=7-E<F1A=&$G72D["B`@
M("`@("`@96QS92`*("`@("`@("`@("`@)&1A=&$@/2!A<G)A>2A.54Q,+"!.
M54Q,+"!.54Q,*3L*"B`@("`@("`@+R\@;&%S="!U<V5D(')E<75I<F5D(&)Y
M('1H92!G87)B86=E(&-O;&QE8W1I;VX@("`*("`@("`@("`O+R!705).24Y'
M.B!M:6=H="!B92!->5-13"!S<&5C:69I8R`@("`@("`@(`H@("`@("`@("1Q
M=65R>2`]('-P<FEN=&8H(E501$%412`E<R!3150@8VAA;F=E9"`]("A.3U<H
M*2`K(#`I(%=(15)%(&ED(#T@)R5S)R!!3D0@8V%C:&5G<F]U<"`]("<E<R<B
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D
M:60I+`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D
M9W)O=7`I"B`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@("`*
M("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD8BP@)'%U97)Y*3L*
M("`@("`@("!I9B`H9&)X7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@("`@
M(')E='5R;B!N97<@0V%C:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@
M+B!D8GA?97)R;W(H)'1H:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(`H@("`@("`@("`@("`*("`@
M("`@("!R971U<FX@)&1A=&$[("`@("`@("`@("`@"B`@("!]"@H@("`@+RHJ
M"B`@("`J(%-T;W)E<R!A(&1A=&%S970N"B`@("`J(`H@("`@*B!705).24Y'
M.B!W92!U<V4@=&AE(%-13"!C;VUM86YD(%)%4$Q!0T4@24Y43R!T:&ES(&UI
M9VAT(&)E(`H@("`@*B!->5-13"!S<&5C:69I8RX@07,@37E344P@:7,@=F5R
M>2!P;W!U;&%R('1H92!M971H;V0@<VAO=6QD"B`@("`J('=O<FL@9FEN92!F
M;W(@.34E(&]F('EO=2X*("`@("HO"B`@("!F=6YC=&EO;B!S879E*"1I9"P@
M)&1A=&$L("1E>'!I<F5S+"`D9W)O=7`L("1U<V5R9&%T82D*("`@('L*("`@
M("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"1I9"P@)&=R;W5P*3L*"B`@("`@
M("`@)'%U97)Y(#T@<W!R:6YT9B@B4D503$%#12!)3E1/("5S("AU<V5R9&%T
M82P@8V%C:&5D871A+"!E>'!I<F5S+"!I9"P@8V%C:&5G<F]U<"D@5D%,5453
M("@G)7,G+"`G)7,G+"`E9"P@)R5S)RP@)R5S)RDB+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE+`H@("`@("`@("`@("`@
M("`@("`@("`@("`@861D<VQA<VAE<R@D=7-E<F1A=&$I+`H@("`@("`@("`@
M("`@("`@("`@("`@("`@861D<VQA<VAE<R@D=&AI<RT^96YC;V1E*"1D871A
M*2DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D=&AI<RT^9V5T17AP:7)E
M<T%B<V]L=71E*"1E>'!I<F5S*2`L"B`@("`@("`@("`@("`@("`@("`@("`@
M("!A9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A
M9&1S;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@*3L*
M"B`@("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D[
M"@H@("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D@>PH@("`@("`@
M("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R*"=$0G@@<75E<GD@9F%I;&5D
M.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BD@+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*("`@('T*"B`@("!F=6YC=&EO;B!R96UO=F4H)&ED
M+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'1H:7,M/F9L=7-H4')E;&]A9"@D
M:60L("1G<F]U<"D["@H@("`@("`@("1Q=65R>2`]('-P<FEN=&8H(D1%3$54
M12!&4D]-("5S(%=(15)%(&ED(#T@)R5S)R!A;F0@8V%C:&5G<F]U<"`]("<E
M<R<B+`H@("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A
M8FQE+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D:60I
M+`H@("`@("`@("`@("`@("`@("`@("`@("`@861D<VQA<VAE<R@D9W)O=7`I
M"B`@("`@("`@("`@("`@("`@("`@("`@("D["@H@("`@("`@("1R97,@/2!D
M8GA?<75E<GDH)'1H:7,M/F1B+"`D<75E<GDI.PH*("`@("`@("!I9B`H9&)X
M7V5R<F]R*"1T:&ES+3YD8BDI"B`@("`@("`@("`@(')E='5R;B!N97<@0V%C
M:&5?17)R;W(H)T1">"!Q=65R>2!F86EL960Z("<@+B!D8GA?97)R;W(H)'1H
M:7,M/F1B*2P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@('T*"B`@("!F=6YC
M=&EO;B!F;'5S:"@D9W)O=7`@/2`G)RD*("`@('L*("`@("`@("`D=&AI<RT^
M9FQU<VA0<F5L;V%D*"D["@H@("`@("`@(&EF("@D9W)O=7`I('L*("`@("`@
M("`@("`@)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($923TT@)7,@5TA%4D4@
M8V%C:&5G<F]U<"`]("<E<R<B+"`D=&AI<RT^8V%C:&5?=&%B;&4L(&%D9'-L
M87-H97,H)&=R;W5P*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'%U97)Y(#T@<W!R:6YT9B@B1$5,151%($923TT@)7,B+"`D=&AI<RT^8V%C
M:&5?=&%B;&4I.PH@("`@("`@('T*"B`@("`@("`@)')E<R`](&1B>%]Q=65R
M>2@D=&AI<RT^9&(L)'%U97)Y*3L*"B`@("`@("`@:68@*&1B>%]E<G)O<B@D
M=&AI<RT^9&(I*0H@("`@("`@("`@("!R971U<FX@;F5W($-A8VAE7T5R<F]R
M*"=$0G@@<75E<GD@9F%I;&5D.B`G("X@9&)X7V5R<F]R*"1T:&ES+3YD8BDL
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("!]"@H@("`@9G5N8W1I;VX@:61%
M>&ES=',H)&ED+"`D9W)O=7`I"B`@("!["B`@("`@("`@)'%U97)Y(#T@<W!R
M:6YT9B@B4T5,14-4(&ED($923TT@)7,@5TA%4D4@240@/2`G)7,G($%.1"!C
M86-H96=R;W5P(#T@)R5S)R(L"B`@("`@("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@("`@("!A
M9&1S;&%S:&5S*"1I9"DL"B`@("`@("`@("`@("`@("`@("`@("`@("!A9&1S
M;&%S:&5S*"1G<F]U<"D*("`@("`@("`@("`@("`@("`@("`@("`@*3L*"B`@
M("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D["@H@
M("`@("`@(&EF("AD8GA?97)R;W(H)'1H:7,M/F1B*2D*("`@("`@("`@("`@
M<F5T=7)N(&YE=R!#86-H95]%<G)O<B@G1$)X('%U97)Y(&9A:6QE9#H@)R`N
M(&1B>%]E<G)O<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*
M"B`@("`@("`@)')O=R`]("1R97-;,%T["@H@("`@("`@(&EF("AI<U]A<G)A
M>2@D<F]W*2D@>PH@("`@("`@("`@("!R971U<FX@=')U93L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@("`@?0H@
M("`@?0H*("`@(&9U;F-T:6]N(&=A<F)A9V5#;VQL96-T:6]N*"1M87AL:69E
M=&EM92D*("`@('L*("`@("`@("`D=&AI<RT^9FQU<VA0<F5L;V%D*"D["B`@
M("`@("`@"B`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G1$5,151%($923TT@
M)7,@5TA%4D4@*&5X<&ER97,@/#T@)60@04Y$(&5X<&ER97,@/B`P*2!/4B!C
M:&%N9V5D(#P]("A.3U<H*2`M("5D*2<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8V%C:&5?=&%B;&4L"B`@("`@("`@("`@("`@("`@("`@
M("`@("!T:6UE*"DL"B`@("`@("`@("`@("`@("`@("`@("`@("`D;6%X;&EF
M971I;64*("`@("`@("`@("`@("`@("`@("`@("`I.PH*"B`@("`@("`@)')E
M<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D["@H@("`@("`@(&EF
M("AD8GA?97)R;W(H)'1H:7,M/F1B*2D*("`@("`@("`@("`@<F5T=7)N(&YE
M=R!#86-H95]%<G)O<B@G1$)X('%U97)Y(&9A:6QE9#H@)R`N(&1B>%]E<G)O
M<B@D=&AI<RT^9&(I+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH*("`@("`@("`D
M<75E<GD@/2!S<')I;G1F*"=S96QE8W0@<W5M*&QE;F=T:"AC86-H961A=&$I
M*2!A<R!#86-H95-I>F4@9G)O;2`E<R<L"B`@("`@("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^8V%C:&5?=&%B;&4*("`@("`@("`@("`@("`@("`@("`@
M("`I.PH*("`@("`@("`D<F5S(#T@9&)X7W%U97)Y*"1T:&ES+3YD8BP@)'%U
M97)Y*3L*("`@("`@("`O+VEF(&-A8VAE(&ES('1O(&)I9RX*("`@("`@("!I
M9B`H)')E<RT^9&%T85LP75M#86-H95-I>F5=(#X@)'1H:7,M/FAI9VAW871E
M<BD*("`@("`@("!["B`@("`@("`@("`@("\O9FEN9"!T:&4@;&]W=V%T97(@
M;6%R:RX*("`@("`@("`@("`@)'%U97)Y(#T@<W!R:6YT9B@G<V5L96-T(&QE
M;F=T:"AC86-H961A=&$I(&%S('-I>F4L(&-H86YG960@9G)O;2`E<R!O<F1E
M<B!B>2!C:&%N9V5D($1%4T,G+`H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'1H:7,M/F-A8VAE7W1A8FQE"B`@("`@("`@("`@("`@
M("`@("`@("`@*3L*"B`@("`@("`@("`@("1R97,@/2!D8GA?<75E<GDH)'1H
M:7,M/F1B+"`D<75E<GDI.PH@("`@("`@("`@("`D:V5E<%]S:7IE/3`["B`@
M("`@("`@("`@("1I/3`["B`@("`@("`@("`@('=H:6QE("@D:V5E<%]S:7IE
M(#P@)'1H:7,M/FQO=W=A=&5R("8F("1I(#P@)')E<RT^<F]W<R`I"B`@("`@
M("`@("`@('L*"B`@("`@("`@("`@("`@("`D:V5E<%]S:7IE("L]("1R97,M
M/F1A=&%;)&E=6W-I>F5=.PH@("`@("`@("`@("`@("`@)&DK*SL*("`@('T*
M("`@(`H@("`@("`@("`@("`O+V1E;&5T92!A;&P@96YT<FEE<RP@=VAI8V@@
M=V5R92!C:&%N9V5D(&)E9F]R92!T:&4@(FQO=W=W871E<B!M87)K(@H@("`@
M("`@("`@("`D<75E<GD@/2!S<')I;G1F*"=D96QE=&4@9G)O;2`E<R!W:&5R
M92!C:&%N9V5D(#P]("5S)RP*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1T:&ES+3YC86-H95]T86)L92P*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1R97,M/F1A=&%;)&E=6V-H86YG961=
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@*3L*("`@("`@
M("`@("`@)')E<R`](&1B>%]Q=65R>2@D=&AI<RT^9&(L("1Q=65R>2D["B`@
M("`@("`@?0H@("`@?0I]"C\^``````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@O4T%33```````````````
M````````````````````````````````````````````````````````````
M````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U
M,34T,S0Q,S(@,#(P,#0T`"`U````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T
M:"]305-,+G!H<```````````````````````````````````````````````
M```````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q
M(``P,#`P,#`Q,#(P-"`Q,#4Q-30S-#$S,B`P,C`V,S$`(#``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R````
M````````````````````````````````````,#`P,#`P(``P,#`P,#`@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````/#]P:'`-"B\O("LM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R!\($-O<'ER:6=H="`H8RD@
M,C`P,BTR,#`S(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`T*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M?"`-"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(%)E
M9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R
M;7,L('=I=&@@;W(@=VET:&]U="`@("!\(`T*+R\@?"!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,@("`@?"`-"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@#0HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!O
M(%)E9&ES=')I8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T
M:&4@86)O=F4@8V]P>7)I9VAT("`@("`@?"`-"B\O('P@("!N;W1I8V4L('1H
M:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L
M86EM97(N("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@
M("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?"`-"B\O('P@
M("!D;V-U;65N=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED
M960@=VET:"!T:&4@9&ES=')I8G5T:6]N+GP@#0HO+R!\(&\@5&AE(&YA;65S
M(&]F('1H92!A=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R
M('!R;VUO=&4@("`@("!\(`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O
M;2!T:&ES('-O9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E
M;B`@?"`-"B\O('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!42$E3(%-/1E17
M05)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@
M0T].5%))0E543U)3("`@?"`-"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%
M4U,@3U(@24U03$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@
M("`@('P@#0HO+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)
M15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\(`T*+R\@
M?"!!(%!!4E1)0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@
M159%3E0@4TA!3$P@5$A%($-/4%E224=(5"`@?"`-"B\O('P@3U=.15(@3U(@
M0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%
M0U0L($E.0TE$14Y404PL('P@#0HO+R!\(%-014-)04PL($5814U03$%262P@
M3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@
M("`@("!\(`T*+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)3
M5$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?"`-"B\O
M('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].
M*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@#0HO+R!\(%1(14]262!/
M1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"
M24Q)5%DL($]2(%1/4E0@("!\(`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.
M0T4@3U(@3U1(15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(
M12!54T4@?"`-"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)
M4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@#0HO
M+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O('P@075T:&]R.B!2:6-H87)D($AE
M>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*
M+R\@#0HO+R`D260Z(%-!4TPN<&AP+'8@,2XT(#(P,#,O,#(O,C$@,38Z,#<Z
M,3<@;6H@17AP("0-"@T*+RHJ#0HJ($-L:65N="!I;7!L96UE;G1A=&EO;B!O
M9B!V87)I;W5S(%-!4TP@;65C:&%N:7-M<R`-"BH-"BH@0&%U=&AO<B`@4FEC
M:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/@T**B!`86-C97-S("!P=6)L
M:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K86=E($%U=&A?4T%33`T**B\-
M"@T*<F5Q=6ER95]O;F-E*"=014%2+G!H<"<I.PT*#0IC;&%S<R!!=71H7U-!
M4TP-"GL-"B`@("`O*BH-"B`@("`J($9A8W1O<GD@8VQA<W,N(%)E='5R;G,@
M86X@;V)J96-T(&]F('1H92!R97%U97-T#0H@("`@*B!T>7!E+@T*("`@("H-
M"B`@("`J($!P87)A;2!S=')I;F<@)'1Y<&4@3VYE(&]F.B!!;F]N>6UO=7,-
M"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@("!0;&%I;@T*("`@
M("H@("`@("`@("`@("`@("`@("`@("`@("`@("`@($-R86U-1#4-"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!$:6=E<W1-1#4-"B`@("`J
M("`@("`@("`@("`@("`@("`@("`@5'EP97,@87)E(&YO="!C87-E('-E;G-I
M=&EV90T*("`@("HO#0H@("`@9G5N8W1I;VX@)F9A8W1O<GDH)'1Y<&4I#0H@
M("`@>PT*("`@("`@("!S=VET8V@@*'-T<G1O;&]W97(H)'1Y<&4I*2![#0H@
M("`@("`@("`@("!C87-E("=A;F]N>6UO=7,G.@T*("`@("`@("`@("`@("`@
M("1F:6QE;F%M92`@/2`G075T:"]305-,+T%N;VYY;6]U<RYP:'`G.PT*("`@
M("`@("`@("`@("`@("1C;&%S<VYA;64@/2`G075T:%]305-,7T%N;VYY;6]U
M<R<[#0H@("`@("`@("`@("`@("`@8G)E86L[#0H-"B`@("`@("`@("`@(&-A
M<V4@)VQO9VEN)SH-"B`@("`@("`@("`@("`@("`D9FEL96YA;64@(#T@)T%U
M=&@O4T%33"],;V=I;BYP:'`G.PT*("`@("`@("`@("`@("`@("1C;&%S<VYA
M;64@/2`G075T:%]305-,7TQO9VEN)SL-"B`@("`@("`@("`@("`@("!B<F5A
M:SL-"@T*("`@("`@("`@("`@8V%S92`G<&QA:6XG.@T*("`@("`@("`@("`@
M("`@("1F:6QE;F%M92`@/2`G075T:"]305-,+U!L86EN+G!H<"<[#0H@("`@
M("`@("`@("`@("`@)&-L87-S;F%M92`]("=!=71H7U-!4TQ?4&QA:6XG.PT*
M("`@("`@("`@("`@("`@(&)R96%K.PT*#0H@("`@("`@("`@("!C87-E("=C
M<F%M;60U)SH-"B`@("`@("`@("`@("`@("`D9FEL96YA;64@(#T@)T%U=&@O
M4T%33"]#<F%M340U+G!H<"<[#0H@("`@("`@("`@("`@("`@)&-L87-S;F%M
M92`]("=!=71H7U-!4TQ?0W)A;4U$-2<[#0H@("`@("`@("`@("`@("`@8G)E
M86L[#0H-"B`@("`@("`@("`@(&-A<V4@)V1I9V5S=&UD-2<Z#0H@("`@("`@
M("`@("`@("`@)&9I;&5N86UE("`]("=!=71H+U-!4TPO1&EG97-T340U+G!H
M<"<[#0H@("`@("`@("`@("`@("`@)&-L87-S;F%M92`]("=!=71H7U-!4TQ?
M1&EG97-T340U)SL-"B`@("`@("`@("`@("`@("!B<F5A:SL-"@T*("`@("`@
M("`@("`@9&5F875L=#H-"B`@("`@("`@("`@("`@("!R971U<FX@4$5!4CHZ
M<F%I<V5%<G)O<B@G26YV86QI9"!305-,(&UE8VAA;FES;2!T>7!E)RD[#0H@
M("`@("`@("`@("`@("`@8G)E86L[#0H@("`@("`@('T-"@T*("`@("`@("!R
M97%U:7)E7V]N8V4H)&9I;&5N86UE*3L-"B`@("`@("`@<F5T=7)N(&YE=R`D
M8VQA<W-N86UE*"D[#0H@("`@?0T*?0T*#0H_/@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO0V]M
M;6]N+G!H<```````````````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V
M-30P(#$P-3$U-#,T,3,R(#`R,C`W,0`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`HO+R`K+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TK(`HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I
M8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`HO+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`HO+R!\(%)E9&ES=')I8G5T:6]N(&%N
M9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET
M:&]U="`@("!\(`HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P
M<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`HO
M+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R!\("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&]F
M('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@
M("`@("!\(`HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N
M<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`HO+R!\
M(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D
M=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\(`HO+R!\("`@;F]T:6-E+"!T
M:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C
M;&%I;65R(&EN('1H92!\(`HO+R!\("`@9&]C=6UE;G1A=&EO;B!A;F0O;W(@
M;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R:6)U=&EO
M;BY\(`HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S(&UA>2!N;W0@
M8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\(`HO+R!\("`@
M<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@=VET:&]U="!S
M<&5C:69I8R!P<FEO<B!W<FET=&5N("!\(`HO+R!\("`@<&5R;6ES<VEO;BX@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\
M(`HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@0ED@5$A%($-/4%E2
M24=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\(`HO+R!\(")!4R!)
M4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#
M3%5$24Y'+"!"550@3D]4("`@("!\(`HO+R!\($Q)34E4140@5$\L(%1(12!)
M35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519($%.1"!&251.
M15-3($9/4B!\(`HO+R!\($$@4$%25$E#54Q!4B!055)03U-%($%212!$25-#
M3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@0T]065))1TA4("!\(`HO
M+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,24%"3$4@1D]2($%.62!$
M25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\(`HO+R!\(%-014-)04PL
M($5814U03$%262P@3U(@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L($)55"!.3U0@("`@("!\(`HO+R!\($Q)34E4140@5$\L(%!23T-54D5-
M14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@4T525DE#15,[($Q/4U,@3T8@
M55-%+"!\(`HO+R!\($1!5$$L($]2(%!23T9)5%,[($]2($)54TE.15-3($E.
M5$524E505$E/3BD@2$]7159%4B!#0553140@04Y$($].($%.62!\(`HO+R!\
M(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-4
M4DE#5"!,24%"24Q)5%DL($]2(%1/4E0@("!\(`HO+R!\("A)3D-,541)3D<@
M3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I($%225-)3D<@24X@04Y9(%=!62!/
M550@3T8@5$A%(%5312!\(`HO+R!\($]&(%1(25,@4T]&5%=!4D4L($5614X@
M248@041625-%1"!/1B!42$4@4$]34TE"24Q)5%D@3T8@4U5#2"!$04U!1T4N
M("!\(`HO+R!\("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`HO+R`K+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`HO+R!\($%U=&AO<CH@4FEC:&%R
M9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T/B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK
M(`HO+R`*+R\@)$ED.B!#;VUM;VXN<&AP+'8@,2XV(#(P,#,O,#(O,C$@,38Z
M,#<Z,3<@;6H@17AP("0*"B\J*@HJ($-O;6UO;B!F=6YC=&EO;F%L:71Y('1O
M(%-!4TP@;65C:&%N:7-M<PHJ"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\
M<FEC:&%R9$!P:'`N;F5T/@HJ($!A8V-E<W,@('!U8FQI8PHJ($!V97)S:6]N
M(#$N,`HJ($!P86-K86=E($%U=&A?4T%33`HJ+PH*8VQA<W,@075T:%]305-,
M7T-O;6UO;@I["B`@("`O*BH*("`@("H@1G5N8W1I;VX@=VAI8V@@:6UP;&5M
M96YT<R!(34%#($U$-2!D:6=E<W0*("`@("H*("`@("H@0'!A<F%M("!S=')I
M;F<@)&ME>2`@5&AE('-E8W)E="!K97D*("`@("H@0'!A<F%M("!S=')I;F<@
M)&1A=&$@5&AE(&1A=&$@=&\@<')O=&5C=`H@("`@*B!`<F5T=7)N('-T<FEN
M9R`@("`@("!4:&4@2$U!0R!-1#4@9&EG97-T"B`@("`J+PH@("`@9G5N8W1I
M;VX@7TA-04-?340U*"1K97DL("1D871A*0H@("`@>PH@("`@("`@(&EF("AS
M=')L96XH)&ME>2D@/B`V-"D@>PH@("`@("`@("`@("`D:V5Y(#T@<&%C:R@G
M2#,R)RP@;60U*"1K97DI*3L*("`@("`@("!]"@H@("`@("`@(&EF("AS=')L
M96XH)&ME>2D@/"`V-"D@>PH@("`@("`@("`@("`D:V5Y(#T@<W1R7W!A9"@D
M:V5Y+"`V-"P@8VAR*#`I*3L*("`@("`@("!]"@H@("`@("`@("1K7VEP860@
M/2!S=6)S='(H)&ME>2P@,"P@-C0I(%X@<W1R7W)E<&5A="AC:'(H,'@S-BDL
M(#8T*3L*("`@("`@("`D:U]O<&%D(#T@<W5B<W1R*"1K97DL(#`L(#8T*2!>
M('-T<E]R97!E870H8VAR*#!X-4,I+"`V-"D["@H@("`@("`@("1I;FYE<B`@
M/2!P86-K*"=(,S(G+"!M9#4H)&M?:7!A9"`N("1D871A*2D["B`@("`@("`@
M)&1I9V5S="`](&UD-2@D:U]O<&%D("X@)&EN;F5R*3L*"B`@("`@("`@<F5T
M=7)N("1D:6=E<W0["B`@("!]"GT*/SX*````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T:"]305-,+T-R
M86U-1#4N<&AP````````````````````````````````````````````````
M```````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M-C<P-B`Q,#4Q-30S-#$S,B`P,C(P,S4`(#``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L@#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S
M(%)I8VAA<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!\(`T*+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(%)E9&ES=')I8G5T
M:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@
M;W(@=VET:&]U="`@("!\(`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M
M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@
M("`@?"`-"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I
M8G5T:6]N<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@
M8V]P>7)I9VAT("`@("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O
M9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@
M("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M
M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@
M?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@?"`-"B\O('P@("!D;V-U;65N
M=&%T:6]N(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T
M:&4@9&ES=')I8G5T:6]N+GP@#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A
M=71H;W)S(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@
M("`@("!\(`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O
M9G1W87)E('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O
M('P@("!P97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!2
M3U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E54
M3U)3("`@?"`-"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U0
M3$E%1"!705)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P@#0HO
M+R!\($Q)34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@3452
M0TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)
M0U5,05(@4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!
M3$P@5$A%($-/4%E224=(5"`@?"`-"B\O('P@3U=.15(@3U(@0T].5%))0E54
M3U)3($)%($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$
M14Y404PL('P@#0HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51
M545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\(`T*
M+R\@?"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/
M3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@?"`-"B\O('P@1$%402P@
M3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52
M($-!55-%1"!!3D0@3TX@04Y9('P@#0HO+R!\(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2
M(%1/4E0@("!\(`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(
M15)725-%*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?"`-
M"B\O('P@3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(
M12!03U-324))3$E462!/1B!354-(($1!34%'12X@('P@#0HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM*R`-"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H
M87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@
M#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D
M260Z($-R86U-1#4N<&AP+'8@,2XT(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@
M17AP("0-"@T*+RHJ#0HJ($EM<&QM96YT871I;VX@;V8@0U)!32U-1#4@4T%3
M3"!M96-H86YI<VT-"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC
M:&%R9$!P:'`N;F5T/@T**B!`86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@
M,2XP#0HJ($!P86-K86=E($%U=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E
M*"=!=71H+U-!4TPO0V]M;6]N+G!H<"<I.PT*#0IC;&%S<R!!=71H7U-!4TQ?
M0W)A;4U$-2!E>'1E;F1S($%U=&A?4T%33%]#;VUM;VX-"GL-"B`@("`O*BH-
M"B`@("`J($EM<&QE;65N=',@=&AE($-204TM340U(%-!4TP@;65C:&%N:7-M
M#0H@("`@*B!4:&ES($1/15,@3D]4(&)A<V4V-"!E;F-O9&4@=&AE(')E='5R
M;B!V86QU92P-"B`@("`J('EO=2!W:6QL(&YE960@=&\@9&\@=&AA="!Y;W5R
M<V5L9BX-"B`@("`J#0H@("`@*B!`<&%R86T@<W1R:6YG("1U<V5R("`@("`@
M57-E<FYA;64-"B`@("`J($!P87)A;2!S=')I;F<@)'!A<W,@("`@("!087-S
M=V]R9`T*("`@("H@0'!A<F%M('-T<FEN9R`D8VAA;&QE;F=E(%1H92!C:&%L
M;&5N9V4@<W5P<&QI960@8GD@=&AE('-E<G9E<BX-"B`@("`J("`@("`@("`@
M("`@("`@("`@("`@("`@("!T:&ES('-H;W5L9"!B92!A;')E861Y(&)A<V4V
M-%]D96-O9&5D+@T*("`@("H-"B`@("`J($!R971U<FX@<W1R:6YG(%1H92!S
M=')I;F<@=&\@<&%S<R!B86-K('1O('1H92!S97)V97(L(&]F('1H92!F;W)M
M#0H@("`@*B`@("`@("`@("`@("`@("`B/'5S97(^(#QD:6=E<W0^(BX@5&AI
M<R!I<R!.3U0@8F%S938T7V5N8V]D960N#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!G971297-P;VYS92@D=7-E<BP@)'!A<W,L("1C:&%L;&5N9V4I#0H@("`@
M>PT*("`@("`@("!R971U<FX@)'5S97(@+B`G("<@+B`D=&AI<RT^7TA-04-?
M340U*"1P87-S+"`D8VAA;&QE;F=E*3L-"B`@("!]#0I]#0H_/@``````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"]$
M:6=E<W1-1#4N<&AP````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,C`R-C`@,3`U,34T,S0Q,S(@,#(R,S8Q`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B\O("LM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L@"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@
M4FEC:&%R9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@"B\O('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@4F5D:7-T<FEB=71I;VX@
M86YD('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W
M:71H;W5T("`@('P@"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D
M('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@
M"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@"B\O('P@;R!2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M="`@("`@('P@"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD:71I
M;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@"B\O
M('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R
M;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P@"B\O('P@("!N;W1I8V4L
M('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I
M<V-L86EM97(@:6X@=&AE('P@"B\O('P@("!D;V-U;65N=&%T:6]N(&%N9"]O
M<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES=')I8G5T
M:6]N+GP@"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@;6%Y(&YO
M="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@"B\O('P@
M("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W:71H;W5T
M('-P96-I9FEC('!R:6]R('=R:71T96X@('P@"B\O('P@("!P97)M:7-S:6]N
M+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('P@"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"62!42$4@0T]0
M65))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@"B\O('P@(D%3
M($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!705)204Y42453+"!)
M3D-,541)3D<L($)55"!.3U0@("`@('P@"B\O('P@3$E-251%1"!43RP@5$A%
M($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"24Q)5%D@04Y$($9)
M5$Y%4U,@1D]2('P@"B\O('P@02!005)424-53$%2(%!54E!/4T4@05)%($1)
M4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@('P@
M"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%($Q)04),12!&3U(@04Y9
M($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL('P@"B\O('P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ5
M1$E.1RP@0E54($Y/5"`@("`@('P@"B\O('P@3$E-251%1"!43RP@4%)/0U52
M14U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/
M1B!54T4L('P@"B\O('P@1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,@
M24Y415)255!424].*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9('P@"B\O
M('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%5$A%4B!)3B!#3TY44D%#5"P@
M4U1224-4($Q)04))3$E462P@3U(@5$]25"`@('P@"B\O('P@*$E.0TQ51$E.
M1R!.14=,24=%3D-%($]2($]42$525TE312D@05))4TE.1R!)3B!!3ED@5T%9
M($]55"!/1B!42$4@55-%('P@"B\O('P@3T8@5$A)4R!33T945T%212P@159%
M3B!)1B!!1%9)4T5$($]&(%1(12!03U-324))3$E462!/1B!354-(($1!34%'
M12X@('P@"B\O('P@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@"B\O('P@075T:&]R.B!2:6-H
M87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L@"B\O(`HO+R`D260Z($1I9V5S=$U$-2YP:'`L=B`Q+C8@,C`P,R\P,B\R
M,2`Q-CHP-SHQ-R!M:B!%>'`@)`H*+RHJ"BH@26UP;&UE;G1A=&EO;B!O9B!$
M24=%4U0M340U(%-!4TP@;65C:&%N:7-M"BH**B!`875T:&]R("!2:6-H87)D
M($AE>65S(#QR:6-H87)D0'!H<"YN970^"BH@0&%C8V5S<R`@<'5B;&EC"BH@
M0'9E<G-I;VX@,2XP"BH@0'!A8VMA9V4@075T:%]305-,"BHO"@IR97%U:7)E
M7V]N8V4H)T%U=&@O4T%33"]#;VUM;VXN<&AP)RD["@IC;&%S<R!!=71H7U-!
M4TQ?1&EG97-T340U(&5X=&5N9',@075T:%]305-,7T-O;6UO;@I["B`@("`O
M*BH*("`@("H@4')O=FED97,@=&AE("AM86EN*2!C;&EE;G0@<F5S<&]N<V4@
M9F]R($1)1T535"U-1#4*("`@("H@<F5Q=6ER97,@82!F97<@97AT<F$@<&%R
M86UE=&5R<R!T:&%N('1H92!O=&AE<@H@("`@*B!M96-H86YI<VUS+"!W:&EC
M:"!A<F4@=6YA=F]I9&%B;&4N"B`@("`J(`H@("`@*B!`<&%R86T@('-T<FEN
M9R`D875T:&-I9"`@($%U=&AE;G1I8V%T:6]N(&ED("AU<V5R;F%M92D*("`@
M("H@0'!A<F%M("!S=')I;F<@)'!A<W,@("`@("!087-S=V]R9`H@("`@*B!`
M<&%R86T@('-T<FEN9R`D8VAA;&QE;F=E(%1H92!D:6=E<W0@8VAA;&QE;F=E
M('-E;G0@8GD@=&AE('-E<G9E<@H@("`@*B!`<&%R86T@('-T<FEN9R`D:&]S
M=&YA;64@(%1H92!H;W-T;F%M92!O9B!T:&4@;6%C:&EN92!Y;W4G<F4@8V]N
M;F5C=&EN9R!T;PH@("`@*B!`<&%R86T@('-T<FEN9R`D<V5R=FEC92`@(%1H
M92!S97)V:6-E;F%M92`H96<N(&EM87`L('!O<"P@86-A<"!E=&,I"B`@("`J
M($!P87)A;2`@<W1R:6YG("1A=71H>FED("`@075T:&]R:7IA=&EO;B!I9"`H
M=7-E<FYA;64@=&\@<')O>'D@87,I"B`@("`J($!R971U<FX@<W1R:6YG("`@
M("`@("`@("`@5&AE(&1I9V5S="!R97-P;VYS92`H3D]4(&)A<V4V-"!E;F-O
M9&5D*0H@("`@*B!`86-C97-S('!U8FQI8PH@("`@*B\*("`@(&9U;F-T:6]N
M(&=E=%)E<W!O;G-E*"1A=71H8VED+"`D<&%S<RP@)&-H86QL96YG92P@)&AO
M<W1N86UE+"`D<V5R=FEC92P@)&%U=&AZ:60@/2`G)RD*("`@('L*("`@("`@
M("`D8VAA;&QE;F=E(#T@)'1H:7,M/E]P87)S94-H86QL96YG92@D8VAA;&QE
M;F=E*3L*("`@("`@("`D875T:'II9%]S=')I;F<@/2`G)SL*("`@("`@("!I
M9B`H)&%U=&AZ:60@(3T@)R<I('L*("`@("`@("`@("`@)&%U=&AZ:61?<W1R
M:6YG(#T@)RQA=71H>FED/2(G("X@)&%U=&AZ:60@+B`G(B<[(`H@("`@("`@
M('T*"B`@("`@("`@:68@*"%E;7!T>2@D8VAA;&QE;F=E*2D@>PH@("`@("`@
M("`@("`D8VYO;F-E("`@("`@("`@/2`D=&AI<RT^7V=E=$-N;VYC92@I.PH@
M("`@("`@("`@("`D9&EG97-T7W5R:2`@("`@/2!S<')I;G1F*"<E<R\E<R<L
M("1S97)V:6-E+"`D:&]S=&YA;64I.PH@("`@("`@("`@("`D<F5S<&]N<V5?
M=F%L=64@/2`D=&AI<RT^7V=E=%)E<W!O;G-E5F%L=64H)&%U=&AC:60L("1P
M87-S+"`D8VAA;&QE;F=E6R=R96%L;2==+"`D8VAA;&QE;F=E6R=N;VYC92==
M+"`D8VYO;F-E+"`D9&EG97-T7W5R:2P@)&%U=&AZ:60I.PH*("`@("`@("`@
M("`@<F5T=7)N('-P<FEN=&8H)W5S97)N86UE/2(E<R(L<F5A;&T](B5S(B<@
M+B`D875T:'II9%]S=')I;F<@("X@)RQN;VYC93TB)7,B+&-N;VYC93TB)7,B
M+&YC/2(P,#`P,#`P,2(L<6]P/6%U=&@L9&EG97-T+75R:3TB)7,B+')E<W!O
M;G-E/25S+"5D)RP@)&%U=&AC:60L("1C:&%L;&5N9V5;)W)E86QM)UTL("1C
M:&%L;&5N9V5;)VYO;F-E)UTL("1C;F]N8V4L("1D:6=E<W1?=7)I+"`D<F5S
M<&]N<V5?=F%L=64L("1C:&%L;&5N9V5;)VUA>&)U9B==*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!R971U<FX@4$5!4CHZ<F%I<V5%<G)O<B@G
M26YV86QI9"!D:6=E<W0@8VAA;&QE;F=E)RD["B`@("`@("`@?0H@("`@?0H@
M("`@"B`@("`O*BH*("`@("H@4&%R<V5S(&%N9"!V97)I9FEE<R!T:&4@9&EG
M97-T(&-H86QL96YG92H*("`@("H*("`@("H@0'!A<F%M("!S=')I;F<@)&-H
M86QL96YG92!4:&4@9&EG97-T(&-H86QL96YG90H@("`@*B!`<F5T=7)N(&%R
M<F%Y("`@("`@("`@("`@(%1H92!P87)S960@8VAA;&QE;F=E(&%S(&%N(&%S
M<V]C"B`@("`J("`@("`@("`@("`@("`@("`@("`@("`@("`@87)R87D@:6X@
M=&AE(&9O<FT@(F1I<F5C=&EV92`]/B!V86QU92(N"B`@("`J($!A8V-E<W,@
M<')I=F%T90H@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S94-H86QL96YG92@D
M8VAA;&QE;F=E*0H@("`@>PH@("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@
M("`@("`@('=H:6QE("AP<F5G7VUA=&-H*"<O7BA;82UZ+5TK*3TH(EM>(ETK
M*#\\(5Q<7"DB?%M>+%TK*2]I)RP@)&-H86QL96YG92P@)&UA=&-H97,I*2![
M"@H@("`@("`@("`@("`O+R!)9VYO<F4@=&AE<V4@87,@<&5R(')F8S(X,S$*
M("`@("`@("`@("`@:68@*"1M871C:&5S6S%=(#T]("=O<&%Q=64G($]2("1M
M871C:&5S6S%=(#T]("=D;VUA:6XG*2!["B`@("`@("`@("`@("`@("`D8VAA
M;&QE;F=E(#T@<W5B<W1R*"1C:&%L;&5N9V4L('-T<FQE;B@D;6%T8VAE<ULP
M72D@*R`Q*3L*("`@("`@("`@("`@("`@(&-O;G1I;G5E.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!!;&QO=V5D(&UU;'1I<&QE(")R96%L;2(@
M86YD(")A=71H+7!A<F%M(@H@("`@("`@("`@("!I9B`H(65M<'1Y*"1T;VME
M;G-;)&UA=&-H97-;,5U=*2!!3D0@*"1M871C:&5S6S%=(#T]("=R96%L;2<@
M3U(@)&UA=&-H97-;,5T@/3T@)V%U=&@M<&%R86TG*2D@>PH@("`@("`@("`@
M("`@("`@:68@*&ES7V%R<F%Y*"1T;VME;G-;)&UA=&-H97-;,5U=*2D@>PH@
M("`@("`@("`@("`@("`@("`@("1T;VME;G-;)&UA=&-H97-;,5U=6UT@/2!P
M<F5G7W)E<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI
M.PH@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("`D=&]K96YS6R1M871C:&5S6S%=72`](&%R<F%Y*"1T;VME;G-;)&UA=&-H
M97-;,5U=+"!P<F5G7W)E<&QA8V4H)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA
M=&-H97-;,ETI*3L*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($%N>2!O=&AE<B!M=6QT:7!L92!I;G-T86YC92`](&9A:6QU<F4*("`@("`@
M("`@("`@?2!E;'-E:68@*"%E;7!T>2@D=&]K96YS6R1M871C:&5S6S%=72DI
M('L*("`@("`@("`@("`@("`@("1T;VME;G,@/2!A<G)A>2@I.PH@("`@("`@
M("`@("`@("`@8G)E86L["@H@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1O:V5N<ULD;6%T8VAE<ULQ75T@/2!P<F5G7W)E<&QA8V4H
M)R]>(B@N*BDB)"\G+"`G7%PQ)RP@)&UA=&-H97-;,ETI.PH@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`O+R!296UO=F4@=&AE(&IU<W0@<&%R<V5D(&1I
M<F5C=&EV92!F<F]M('1H92!C:&%L;&5N9V4*("`@("`@("`@("`@)&-H86QL
M96YG92`]('-U8G-T<B@D8VAA;&QE;F=E+"!S=')L96XH)&UA=&-H97-;,%TI
M("L@,2D["B`@("`@("`@?0H*("`@("`@("`O*BH*("`@("`@("`J($1E9F%U
M;'1S(&%N9"!R97%U:7)E9"!D:7)E8W1I=F5S"B`@("`@("`@*B\*("`@("`@
M("`O+R!296%L;0H@("`@("`@(&EF("AE;7!T>2@D=&]K96YS6R=R96%L;2==
M*2D@>PH@("`@("`@("`@("`D=6YA;64@/2!P;W-I>%]U;F%M92@I.PH@("`@
M("`@("`@("`D=&]K96YS6R=R96%L;2==(#T@)'5N86UE6R=N;V1E;F%M92==
M.PH@("`@("`@('T*("`@("`@("`*("`@("`@("`O+R!-87AB=68*("`@("`@
M("!I9B`H96UP='DH)'1O:V5N<ULG;6%X8G5F)UTI*2!["B`@("`@("`@("`@
M("1T;VME;G-;)VUA>&)U9B==(#T@-C4U,S8["B`@("`@("`@?0H@("`@("`@
M(`H@("`@("`@("\O(%)E<75I<F5D.B!N;VYC92P@86QG;W)I=&AM"B`@("`@
M("`@:68@*&5M<'1Y*"1T;VME;G-;)VYO;F-E)UTI($]2(&5M<'1Y*"1T;VME
M;G-;)V%L9V]R:71H;2==*2D@>PH@("`@("`@("`@("!R971U<FX@87)R87DH
M*3L*("`@("`@("!]"B`@("`@("`@"B`@("`@("`@<F5T=7)N("1T;VME;G,[
M"B`@("!]"@H@("`@+RHJ"B`@("`J($-R96%T97,@=&AE(')E<W!O;G-E/2!P
M87)T(&]F('1H92!D:6=E<W0@<F5S<&]N<V4*("`@("H*("`@("H@0'!A<F%M
M("!S=')I;F<@)&%U=&AC:60@("`@075T:&5N=&EC871I;VX@:60@*'5S97)N
M86UE*0H@("`@*B!`<&%R86T@('-T<FEN9R`D<&%S<R`@("`@("!087-S=V]R
M9`H@("`@*B!`<&%R86T@('-T<FEN9R`D<F5A;&T@("`@("!296%L;2!A<R!P
M<F]V:61E9"!B>2!T:&4@<V5R=F5R"B`@("`J($!P87)A;2`@<W1R:6YG("1N
M;VYC92`@("`@($YO;F-E(&%S('!R;W9I9&5D(&)Y('1H92!S97)V97(*("`@
M("H@0'!A<F%M("!S=')I;F<@)&-N;VYC92`@("`@0VQI96YT(&YO;F-E"B`@
M("`J($!P87)A;2`@<W1R:6YG("1D:6=E<W1?=7)I(%1H92!D:6=E<W0M=7)I
M/2!V86QU92!P87)T(&]F('1H92!R97-P;VYS90H@("`@*B!`<&%R86T@('-T
M<FEN9R`D875T:'II9"`@("!!=71H;W)I>F%T:6]N(&ED"B`@("`J($!R971U
M<FX@<W1R:6YG("`@("`@("`@("`@(%1H92!R97-P;VYS93T@<&%R="!O9B!T
M:&4@9&EG97-T(')E<W!O;G-E"B`@("`J($!A8V-E<W,@<')I=F%T90H@("`@
M*B\@("`@"B`@("!F=6YC=&EO;B!?9V5T4F5S<&]N<V5686QU92@D875T:&-I
M9"P@)'!A<W,L("1R96%L;2P@)&YO;F-E+"`D8VYO;F-E+"`D9&EG97-T7W5R
M:2P@)&%U=&AZ:60@/2`G)RD*("`@('L*("`@("`@("!I9B`H)&%U=&AZ:60@
M/3T@)R<I('L*("`@("`@("`@("`@)$$Q(#T@<W!R:6YT9B@G)7,Z)7,Z)7,G
M+"!P86-K*"=(,S(G+"!M9#4H<W!R:6YT9B@G)7,Z)7,Z)7,G+"`D875T:&-I
M9"P@)')E86QM+"`D<&%S<RDI*2P@)&YO;F-E+"`D8VYO;F-E*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`D03$@/2!S<')I;G1F*"<E<SHE<SHE
M<SHE<R<L('!A8VLH)T@S,B<L(&UD-2AS<')I;G1F*"<E<SHE<SHE<R<L("1A
M=71H8VED+"`D<F5A;&TL("1P87-S*2DI+"`D;F]N8V4L("1C;F]N8V4L("1A
M=71H>FED*3L*("`@("`@("!]"B`@("`@("`@)$$R(#T@)T%55$A%3E1)0T%4
M13HG("X@)&1I9V5S=%]U<FD["B`@("`@("`@<F5T=7)N(&UD-2AS<')I;G1F
M*"<E<SHE<SHP,#`P,#`P,3HE<SIA=71H.B5S)RP@;60U*"1!,2DL("1N;VYC
M92P@)&-N;VYC92P@;60U*"1!,BDI*3L*("`@('T*"B`@("`O*BH*("`@("H@
M0W)E871E<R!T:&4@8VQI96YT(&YO;F-E(&9O<B!T:&4@<F5S<&]N<V4*("`@
M("H*("`@("H@0')E='5R;B!S=')I;F<@(%1H92!C;F]N8V4@=F%L=64*("`@
M("H@0&%C8V5S<R!P<FEV871E"B`@("`J+PH@("`@9G5N8W1I;VX@7V=E=$-N
M;VYC92@I"B`@("!["B`@("`@("`@:68@*&9I;&5?97AI<W1S*"<O9&5V+W5R
M86YD;VTG*2D@>PH@("`@("`@("`@("!R971U<FX@8F%S938T7V5N8V]D92AF
M<F5A9"AF;W!E;B@G+V1E=B]U<F%N9&]M)RP@)W(G*2P@,S(I*3L*"B`@("`@
M("`@?2!E;'-E:68@*&9I;&5?97AI<W1S*"<O9&5V+W)A;F1O;2<I*2!["B`@
M("`@("`@("`@(')E='5R;B!B87-E-C1?96YC;V1E*&9R96%D*&9O<&5N*"<O
M9&5V+W)A;F1O;2<L("=R)RDL(#,R*2D["@H@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1S='(@/2`G)SL*("`@("`@("`@("`@;71?<W)A;F0H*&1O
M=6)L92EM:6-R;W1I;64H*2HQ,#`P,#`P,"D["B`@("`@("`@("`@(&9O<B`H
M)&D],#L@)&D\,S([("1I*RLI('L*("`@("`@("`@("`@("`@("1S='(@+CT@
M8VAR*&UT7W)A;F0H,"P@,C4U*2D["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@"B`@("`@("`@("`@(')E='5R;B!B87-E-C1?96YC;V1E*"1S='(I.PH@
M("`@("`@('T*("`@('T*?0H_/@H`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%U=&@O4T%33"],;V=I;BYP:'``
M````````````````````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#8R-S0@,3`U
M,34T,S0Q,S(@,#(Q-S$U`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````#P_<&AP#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TK(`T*+R\@?"!#;W!Y<FEG:'0@*&,I(#(P,#(M,C`P,R!2:6-H87)D
M($AE>65S("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O
M('P@06QL(')I9VAT<R!R97-E<G9E9"X@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!\(`T*+R\@?"!2961I<W1R:6)U=&EO;B!A;F0@
M=7-E(&EN('-O=7)C92!A;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO
M=70@("`@?"`-"B\O('P@;6]D:69I8V%T:6]N+"!A<F4@<&5R;6ET=&5D('!R
M;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD:71I;VYS("`@('P@#0HO
M+R!\(&%R92!M970Z("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O('P@;R!2961I<W1R:6)U=&EO;G,@
M;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H
M="`@("`@('P@#0HO+R!\("`@;F]T:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET
M:6]N<R!A;F0@=&AE(&9O;&QO=VEN9R!D:7-C;&%I;65R+B`@("`@("!\(`T*
M+R\@?"!O(%)E9&ES=')I8G5T:6]N<R!I;B!B:6YA<GD@9F]R;2!M=7-T(')E
M<')O9'5C92!T:&4@86)O=F4@8V]P>7)I9VAT("`@?"`-"B\O('P@("!N;W1I
M8V4L('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG
M(&1I<V-L86EM97(@:6X@=&AE('P@#0HO+R!\("`@9&]C=6UE;G1A=&EO;B!A
M;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I<W1R
M:6)U=&EO;BY\(`T*+R\@?"!O(%1H92!N86UE<R!O9B!T:&4@875T:&]R<R!M
M87D@;F]T(&)E('5S960@=&\@96YD;W)S92!O<B!P<F]M;W1E("`@("`@?"`-
M"B\O('P@("!P<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R92!W
M:71H;W5T('-P96-I9FEC('!R:6]R('=R:71T96X@('P@#0HO+R!\("`@<&5R
M;6ES<VEO;BX@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?"`-"B\O('P@5$A)4R!33T945T%212!)4R!04D]6241%1"!"
M62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/3E1224)55$]24R`@('P@
M#0HO+R!\(")!4R!)4R(@04Y$($%.62!%6%!215-3($]2($E-4$Q)140@5T%2
M4D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4("`@("!\(`T*+R\@?"!,24U)
M5$5$(%1/+"!42$4@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))
M3$E462!!3D0@1DE43D534R!&3U(@?"`-"B\O('P@02!005)424-53$%2(%!5
M4E!/4T4@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#
M3U!94DE'2%0@('P@#0HO+R!\($]73D52($]2($-/3E1224)55$]24R!"12!,
M24%"3$4@1D]2($%.62!$25)%0U0L($E.1$E214-4+"!)3D-)1$5.5$%,+"!\
M(`T*+R\@?"!34$5#24%,+"!%6$5-4$Q!4EDL($]2($-/3E-%455%3E1)04P@
M1$%-04=%4R`H24Y#3%5$24Y'+"!"550@3D]4("`@("`@?"`-"B\O('P@3$E-
M251%1"!43RP@4%)/0U5214U%3E0@3T8@4U5"4U1)5%5412!'3T]$4R!/4B!3
M15)624-%4SL@3$]34R!/1B!54T4L('P@#0HO+R!\($1!5$$L($]2(%!23T9)
M5%,[($]2($)54TE.15-3($E.5$524E505$E/3BD@2$]7159%4B!#0553140@
M04Y$($].($%.62!\(`T*+R\@?"!42$5/4ED@3T8@3$E!0DE,2519+"!72$54
M2$52($E.($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("`@
M?"`-"B\O('P@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D@
M05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%('P@#0HO+R!\($]&
M(%1(25,@4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4@4$]34TE"
M24Q)5%D@3T8@4U5#2"!$04U!1T4N("!\(`T*+R\@?"`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?"`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2L@#0HO+R!\($%U=&AO<CH@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N
M;F5T/B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@*RTM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*R`-"B\O(`T*+R\@)$ED.B!,;V=I
M;BYP:'`L=B`Q+C0@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@)`T*#0HO
M*BH-"BH@5&AI<R!I<R!T96-H;FEC86QL>2!N;W0@82!305-,(&UE8VAA;FES
M;2P@:&]W979E<@T**B!I="=S('5S960@8GD@3F5T7U-I979E+"!.971?0WER
M=7,@86YD('!O=&5N=&EA;&QY#0HJ(&]T:&5R('!R;W1O8V]L<R`L('-O(&AE
M<F4@:7,@82!G;V]D('!L86-E('1O(&%B<W1R86-T#0HJ(&ET+@T**@T**B!`
M875T:&]R("!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H<"YN970^#0HJ($!A
M8V-E<W,@('!U8FQI8PT**B!`=F5R<VEO;B`Q+C`-"BH@0'!A8VMA9V4@075T
M:%]305-,#0HJ+PT*#0IR97%U:7)E7V]N8V4H)T%U=&@O4T%33"]#;VUM;VXN
M<&AP)RD[#0H-"F-L87-S($%U=&A?4T%33%],;V=I;B!E>'1E;F1S($%U=&A?
M4T%33%]#;VUM;VX-"GL-"B`@("`O*BH-"B`@("`J(%!S975D;R!305-,($Q/
M1TE.(&UE8VAA;FES;0T*("`@("H-"B`@("`J($!P87)A;2`@<W1R:6YG("1U
M<V5R(%5S97)N86UE#0H@("`@*B!`<&%R86T@('-T<FEN9R`D<&%S<R!087-S
M=V]R9`T*("`@("H@0')E='5R;B!S=')I;F<@("`@("`@3$]'24X@<W1R:6YG
M#0H@("`@*B\-"B`@("!F=6YC=&EO;B!G971297-P;VYS92@D=7-E<BP@)'!A
M<W,I#0H@("`@>PT*("`@("`@("!R971U<FX@<W!R:6YT9B@G3$]'24X@)7,@
M)7,G+"`D=7-E<BP@)'!A<W,I.PT*("`@('T-"GT-"C\^````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]P<V$M:&]R9&4O<&5A<B]!=71H+U-!4TPO4&QA:6XN<&AP
M````````````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`V,C4Q(#$P
M-3$U-#,T,3,R(#`R,3<P,P`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM*R`-"B\O('P@0V]P>7)I9VAT("AC*2`R,#`R+3(P,#,@4FEC:&%R
M9"!(97EE<R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO
M+R!\($%L;"!R:6=H=',@<F5S97)V960N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@?"`-"B\O('P@4F5D:7-T<FEB=71I;VX@86YD
M('5S92!I;B!S;W5R8V4@86YD(&)I;F%R>2!F;W)M<RP@=VET:"!O<B!W:71H
M;W5T("`@('P@#0HO+R!\(&UO9&EF:6-A=&EO;BP@87)E('!E<FUI='1E9"!P
M<F]V:61E9"!T:&%T('1H92!F;VQL;W=I;F<@8V]N9&ET:6]N<R`@("!\(`T*
M+R\@?"!A<F4@;65T.B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS
M(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG
M:'0@("`@("!\(`T*+R\@?"`@(&YO=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I
M=&EO;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX@("`@("`@?"`-
M"B\O('P@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R
M97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="`@('P@#0HO+R!\("`@;F]T
M:6-E+"!T:&ES(&QI<W0@;V8@8V]N9&ET:6]N<R!A;F0@=&AE(&9O;&QO=VEN
M9R!D:7-C;&%I;65R(&EN('1H92!\(`T*+R\@?"`@(&1O8W5M96YT871I;VX@
M86YD+V]R(&]T:&5R(&UA=&5R:6%L<R!P<F]V:61E9"!W:71H('1H92!D:7-T
M<FEB=71I;VXN?"`-"B\O('P@;R!4:&4@;F%M97,@;V8@=&AE(&%U=&AO<G,@
M;6%Y(&YO="!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92`@("`@('P@
M#0HO+R!\("`@<')O9'5C=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4@
M=VET:&]U="!S<&5C:69I8R!P<FEO<B!W<FET=&5N("!\(`T*+R\@?"`@('!E
M<FUI<W-I;VXN("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('P@#0HO+R!\(%1(25,@4T]&5%=!4D4@25,@4%)/5DE$140@
M0ED@5$A%($-/4%E224=(5"!(3TQ$15)3($%.1"!#3TY44DE"551/4E,@("!\
M(`T*+R\@?"`B05,@25,B($%.1"!!3ED@15A04D534R!/4B!)35!,245$(%=!
M4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"`@("`@?"`-"B\O('P@3$E-
M251%1"!43RP@5$A%($E-4$Q)140@5T%24D%.5$E%4R!/1B!-15)#2$%.5$%"
M24Q)5%D@04Y$($9)5$Y%4U,@1D]2('P@#0HO+R!\($$@4$%25$E#54Q!4B!0
M55)03U-%($%212!$25-#3$%)345$+B!)3B!.3R!%5D5.5"!32$%,3"!42$4@
M0T]065))1TA4("!\(`T*+R\@?"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4@
M3$E!0DQ%($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@
M?"`-"B\O('P@4U!%0TE!3"P@15A%35!,05)9+"!/4B!#3TY315%514Y424%,
M($1!34%'15,@*$E.0TQ51$E.1RP@0E54($Y/5"`@("`@('P@#0HO+R!\($Q)
M34E4140@5$\L(%!23T-54D5-14Y4($]&(%-50E-425155$4@1T]/1%,@3U(@
M4T525DE#15,[($Q/4U,@3T8@55-%+"!\(`T*+R\@?"!$051!+"!/4B!04D]&
M2513.R!/4B!"55-)3D534R!)3E1%4E)54%1)3TXI($A/5T5615(@0T%54T5$
M($%.1"!/3B!!3ED@?"`-"B\O('P@5$A%3U)9($]&($Q)04))3$E462P@5TA%
M5$A%4B!)3B!#3TY44D%#5"P@4U1224-4($Q)04))3$E462P@3U(@5$]25"`@
M('P@#0HO+R!\("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I
M($%225-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!\(`T*+R\@?"!/
M1B!42$E3(%-/1E1705)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%(%!/4U-)
M0DE,2519($]&(%-50T@@1$%-04=%+B`@?"`-"B\O('P@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('P@#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TK(`T*+R\@?"!!=71H;W(Z(%)I8VAA<F0@2&5Y97,@/')I8VAA<F1`<&AP
M+FYE=#X@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O("LM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L@#0HO+R`-"B\O("1)9#H@4&QA
M:6XN<&AP+'8@,2XU(#(P,#,O,#(O,C$@,38Z,#<Z,3<@;6H@17AP("0-"@T*
M+RHJ#0HJ($EM<&QM96YT871I;VX@;V8@4$Q!24X@4T%33"!M96-H86YI<VT-
M"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R9$!P:'`N;F5T
M/@T**B!`86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP#0HJ($!P86-K
M86=E($%U=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=!=71H+U-!4TPO
M0V]M;6]N+G!H<"<I.PT*#0IC;&%S<R!!=71H7U-!4TQ?4&QA:6X@97AT96YD
M<R!!=71H7U-!4TQ?0V]M;6]N#0I[#0H@("`@+RHJ#0H@("`@*B!2971U<FYS
M(%!,04E.(')E<W!O;G-E#0H@("`@*@T*("`@("H@0'!A<F%M("!S=')I;F<@
M)&%U=&AC:60@("!!=71H96YT:6-A=&EO;B!I9"`H=7-E<FYA;64I#0H@("`@
M*B!`<&%R86T@('-T<FEN9R`D<&%S<R`@("`@(%!A<W-W;W)D#0H@("`@*B!`
M<&%R86T@('-T<FEN9R`D875T:'II9"`@($%U=&]R:7IA=&EO;B!I9`T*("`@
M("H@0')E='5R;B!S=')I;F<@("`@("`@("`@("!03$%)3B!297-P;VYS90T*
M("`@("HO#0H@("`@9G5N8W1I;VX@9V5T4F5S<&]N<V4H)&%U=&AC:60L("1P
M87-S+"`D875T:'II9"`]("<G*0T*("`@('L-"B`@("`@("`@<F5T=7)N("1A
M=71H>FED("X@8VAR*#`I("X@)&%U=&AC:60@+B!C:'(H,"D@+B`D<&%S<SL-
M"B`@("!]#0I]#0H_/@T*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O075T:"]305-,+T%N;VYY;6]U
M<RYP:'``````````````````````````````````````````````````````
M```````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P-C<V-"`Q
M,#4Q-30S-#$S,B`P,C(V-#$`(#``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````/#]P:'`-"B\O("LM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2L@#0HO+R!\($-O<'ER:6=H="`H8RD@,C`P,BTR,#`S(%)I8VAA
M<F0@2&5Y97,@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!\(`T*
M+R\@?"!!;&P@<FEG:'1S(')E<V5R=F5D+B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?"`-"B\O('P@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('P@#0HO+R!\(%)E9&ES=')I8G5T:6]N(&%N
M9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET
M:&]U="`@("!\(`T*+R\@?"!M;V1I9FEC871I;VXL(&%R92!P97)M:71T960@
M<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I=&EO;G,@("`@?"`-
M"B\O('P@87)E(&UE=#H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\(`T*+R\@?"!O(%)E9&ES=')I8G5T:6]N
M<R!O9B!S;W5R8V4@8V]D92!M=7-T(')E=&%I;B!T:&4@86)O=F4@8V]P>7)I
M9VAT("`@("`@?"`-"B\O('P@("!N;W1I8V4L('1H:7,@;&ES="!O9B!C;VYD
M:71I;VYS(&%N9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N("`@("`@('P@
M#0HO+R!\(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I;F%R>2!F;W)M(&UU<W0@
M<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@("!\(`T*+R\@?"`@(&YO
M=&EC92P@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL;W=I
M;F<@9&ES8VQA:6UE<B!I;B!T:&4@?"`-"B\O('P@("!D;V-U;65N=&%T:6]N
M(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES
M=')I8G5T:6]N+GP@#0HO+R!\(&\@5&AE(&YA;65S(&]F('1H92!A=71H;W)S
M(&UA>2!N;W0@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@("`@("!\
M(`T*+R\@?"`@('!R;V1U8W1S(&1E<FEV960@9G)O;2!T:&ES('-O9G1W87)E
M('=I=&AO=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B`@?"`-"B\O('P@("!P
M97)M:7-S:6]N+B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R!\("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!\(`T*+R\@?"!42$E3(%-/1E1705)%($E3(%!23U9)1$5$
M($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].5%))0E543U)3("`@
M?"`-"B\O('P@(D%3($E3(B!!3D0@04Y9($584%)%4U,@3U(@24U03$E%1"!7
M05)204Y42453+"!)3D-,541)3D<L($)55"!.3U0@("`@('P@#0HO+R!\($Q)
M34E4140@5$\L(%1(12!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!
M0DE,2519($%.1"!&251.15-3($9/4B!\(`T*+R\@?"!!(%!!4E1)0U5,05(@
M4%524$]312!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%
M($-/4%E224=(5"`@?"`-"B\O('P@3U=.15(@3U(@0T].5%))0E543U)3($)%
M($Q)04),12!&3U(@04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL
M('P@#0HO+R!\(%-014-)04PL($5814U03$%262P@3U(@0T].4T51545.5$E!
M3"!$04U!1T53("A)3D-,541)3D<L($)55"!.3U0@("`@("!\(`T*+R\@?"!,
M24U)5$5$(%1/+"!04D]#55)%345.5"!/1B!354)35$E4551%($=/3T13($]2
M(%-%4E9)0T53.R!,3U-3($]&(%5312P@?"`-"B\O('P@1$%402P@3U(@4%)/
M1DE44SL@3U(@0E5324Y%4U,@24Y415)255!424].*2!(3U=%5D52($-!55-%
M1"!!3D0@3TX@04Y9('P@#0HO+R!\(%1(14]262!/1B!,24%"24Q)5%DL(%=(
M151(15(@24X@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@
M("!\(`T*+R\@?"`H24Y#3%5$24Y'($Y%1TQ)1T5.0T4@3U(@3U1(15)725-%
M*2!!4DE324Y'($E.($%.62!705D@3U54($]&(%1(12!54T4@?"`-"B\O('P@
M3T8@5$A)4R!33T945T%212P@159%3B!)1B!!1%9)4T5$($]&(%1(12!03U-3
M24))3$E462!/1B!354-(($1!34%'12X@('P@#0HO+R!\("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!\(`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM*R`-"B\O('P@075T:&]R.B!2:6-H87)D($AE>65S(#QR:6-H87)D0'!H
M<"YN970^("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P@#0HO+R`K
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK(`T*+R\@#0HO+R`D260Z($%N
M;VYY;6]U<RYP:'`L=B`Q+C0@,C`P,R\P,B\R,2`Q-CHP-SHQ-R!M:B!%>'`@
M)`T*#0HO*BH-"BH@26UP;&UE;G1A=&EO;B!O9B!!3D].64U/55,@4T%33"!M
M96-H86YI<VT-"BH-"BH@0&%U=&AO<B`@4FEC:&%R9"!(97EE<R`\<FEC:&%R
M9$!P:'`N;F5T/@T**B!`86-C97-S("!P=6)L:6,-"BH@0'9E<G-I;VX@,2XP
M#0HJ($!P86-K86=E($%U=&A?4T%33`T**B\-"@T*<F5Q=6ER95]O;F-E*"=!
M=71H+U-!4TPO0V]M;6]N+G!H<"<I.PT*#0IC;&%S<R!!=71H7U-!4TQ?06YO
M;GEM;W5S(&5X=&5N9',@075T:%]305-,7T-O;6UO;@T*>PT*("`@("\J*@T*
M("`@("H@3F]T(&UU8V@@=&\@9&\@:&5R92!E>&-E<'0@<F5T=7)N('1H92!T
M;VME;B!S=7!P;&EE9"X-"B`@("`J($YO(&5N8V]D:6YG+"!H87-H:6YG(&]R
M(&5N8W)Y<'1I;VX@=&%K97,@<&QA8V4@9F]R('1H:7,-"B`@("`J(&UE8VAA
M;FES;2P@<VEM<&QY(&]N92!O9CH-"B`@("`J("!O($%N(&5M86EL(&%D9')E
M<W,-"B`@("`J("!O($%N(&]P87%U92!S=')I;F<@;F]T(&-O;G1A:6YI;F<@
M(D`B('1H870@8V%N(&)E(&EN=&5R<')E=&5D#0H@("`@*B`@("!B>2!T:&4@
M<WES861M:6X-"B`@("`J("!O($YO=&AI;F<-"B`@("`J#0H@("`@*B!792!C
M;W5L9"!H879E('-O;64@;&]G:6,@:&5R92!F;W(@=&AE('-E8V]N9"!O<'1I
M;VXL(&)U="!T:&ES#0H@("`@*B!W;W5L9"!B>2!N;R!M96%N<R!C<F5A=&4@
M<V]M971H:6YG(&EN=&5R<')E=&%B;&4N#0H@("`@*@T*("`@("H@0'!A<F%M
M("!S=')I;F<@)'1O:V5N($]P=&EO;F%L(&5M86EL(&%D9')E<W,@;W(@<W1R
M:6YG('1O('!R;W9I9&4-"B`@("`J("`@("`@("`@("`@("`@("`@("`@("!A
M<R!T<F%C92!I;F9O<FUA=&EO;BX-"B`@("`J($!R971U<FX@<W1R:6YG("`@
M("`@("!4:&4@=6YA;'1E<F5D(&EN<'5T('1O:V5N#0H@("`@*B\-"B`@("!F
M=6YC=&EO;B!G971297-P;VYS92@D=&]K96X@/2`G)RD-"B`@("![#0H@("`@
M("`@(')E='5R;B`D=&]K96X[#0H@("`@?0T*?0T*/SX```````````````!U
M<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+T%R8VAI=F4O5&%R+G!H<```
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q-C8W-S<@
M,3`U,34T,S0Q,S(@,#(Q,S,P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP#0HO*B!V:6TZ('-E="!T<STT('-W/30Z
M("HO#0HO+R`K+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2L-"B\O('P@4$A0
M(%9E<G-I;VX@-"`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TK#0HO+R!\($-O<'ER:6=H="`H8RD@,3DY-RTR,#`S(%1H92!0
M2%`@1W)O=7`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('P-"B\O
M("LM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM*PT*+R\@?"!4:&ES('-O=7)C
M92!F:6QE(&ES('-U8FIE8W0@=&\@=F5R<VEO;B`S+C`@;V8@=&AE(%!(4"!L
M:6-E;G-E+"`@("`@("!\#0HO+R!\('1H870@:7,@8G5N9&QE9"!W:71H('1H
M:7,@<&%C:V%G92!I;B!T:&4@9FEL92!,24-%3E-%+"!A;F0@:7,@("`@("`@
M('P-"B\O('P@879A:6QA8FQE('1H<F]U9V@@=&AE('=O<FQD+7=I9&4M=V5B
M(&%T('1H92!F;VQL;W=I;F<@=7)L.B`@("`@("`@("`@?`T*+R\@?"!H='1P
M.B\O=W=W+G!H<"YN970O;&EC96YS92\S7S`N='AT+B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!\#0HO+R!\($EF('EO=2!D:60@;F]T(')E
M8V5I=F4@82!C;W!Y(&]F('1H92!02%`@;&EC96YS92!A;F0@87)E('5N86)L
M92!T;R`@('P-"B\O('P@;V)T86EN(&ET('1H<F]U9V@@=&AE('=O<FQD+7=I
M9&4M=V5B+"!P;&5A<V4@<V5N9"!A(&YO=&4@=&\@("`@("`@("`@?`T*+R\@
M?"!L:6-E;G-E0'!H<"YN970@<V\@=V4@8V%N(&UA:6P@>6]U(&$@8V]P>2!I
M;6UE9&EA=&5L>2X@("`@("`@("`@("`@("!\#0HO+R`K+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2L-"B\O('P@075T:&]R.B!6:6YC96YT($)L879E="`\
M=FEN8V5N=$!P:'!C;VYC97!T+FYE=#X@("`@("`@("`@("`@("`@("`@("`@
M?`T*+R\@*RTM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TK#0HO+PT*+R\@)$ED
M.B!487(N<&AP+'8@,2XR.2`R,#`U+S`S+S$W(#(Q.C`R.C,Q('9B;&%V970@
M17AP("0-"@T*<F5Q=6ER95]O;F-E("=014%2+G!H<"<[#0H-"@T*9&5F:6YE
M("@G05)#2$E615]405)?05147U-%4$%2051/4B<L(#DP,#`Q*3L-"@T*+RHJ
M#0HJ($-R96%T97,@82`H8V]M<')E<W-E9"D@5&%R(&%R8VAI=F4-"BH-"BH@
M0&%U=&AO<B`@(%9I;F-E;G0@0FQA=F5T(#QV:6YC96YT0'!H<&-O;F-E<'0N
M;F5T/@T**B!`=F5R<VEO;B`@)%)E=FES:6]N.B`Q+C(Y("0-"BH@0'!A8VMA
M9V4@($%R8VAI=F4-"BHO#0IC;&%S<R!!<F-H:79E7U1A<B!E>'1E;F1S(%!%
M05(-"GL-"B`@("`O*BH-"B`@("`J($!V87(@<W1R:6YG($YA;64@;V8@=&AE
M(%1A<@T*("`@("HO#0H@("`@=F%R("1?=&%R;F%M93TG)SL-"@T*("`@("\J
M*@T*("`@("H@0'9A<B!B;V]L96%N(&EF('1R=64L('1H92!487(@9FEL92!W
M:6QL(&)E(&=Z:7!P960-"B`@("`J+PT*("`@('9A<B`D7V-O;7!R97-S/69A
M;'-E.PT*#0H@("`@+RHJ#0H@("`@*B!`=F%R('-T<FEN9R!4>7!E(&]F(&-O
M;7!R97-S:6]N(#H@)VYO;F4G+"`G9WHG(&]R("=B>C(G#0H@("`@*B\-"B`@
M("!V87(@)%]C;VUP<F5S<U]T>7!E/2=N;VYE)SL-"@T*("`@("\J*@T*("`@
M("H@0'9A<B!S=')I;F<@17AP;&]D92!S97!A<F%T;W(-"B`@("`J+PT*("`@
M('9A<B`D7W-E<&%R871O<CTG("<[#0H-"B`@("`O*BH-"B`@("`J($!V87(@
M9FEL92!D97-C<FEP=&]R#0H@("`@*B\-"B`@("!V87(@)%]F:6QE/3`[#0H-
M"B`@("`O*BH-"B`@("`J($!V87(@<W1R:6YG($QO8V%L(%1A<B!N86UE(&]F
M(&$@<F5M;W1E(%1A<B`H:'1T<#HO+R!O<B!F='`Z+R\I#0H@("`@*B\-"B`@
M("!V87(@)%]T96UP7W1A<FYA;64])R<[#0H-"B`@("`O+R![>WL@8V]N<W1R
M=6-T;W(-"B`@("`O*BH-"B`@("`J($%R8VAI=F5?5&%R($-L87-S(&-O;G-T
M<G5C=&]R+B!4:&ES(&9L879O=7(@;V8@=&AE(&-O;G-T<G5C=&]R(&]N;'D-
M"B`@("`J(&1E8VQA<F4@82!N97<@07)C:&EV95]487(@;V)J96-T+"!I9&5N
M=&EF>6EN9R!I="!B>2!T:&4@;F%M92!O9B!T:&4-"B`@("`J('1A<B!F:6QE
M+@T*("`@("H@268@=&AE(&-O;7!R97-S(&%R9W5M96YT(&ES('-E="!T:&4@
M=&%R('=I;&P@8F4@<F5A9"!O<B!C<F5A=&5D(&%S(&$-"B`@("`J(&=Z:7`@
M;W(@8GHR(&-O;7!R97-S960@5$%2(&9I;&4N#0H@("`@*@T*("`@("H@0'!A
M<F%M("`@('-T<FEN9R`@)'!?=&%R;F%M92`@5&AE(&YA;64@;V8@=&AE('1A
M<B!A<F-H:79E('1O(&-R96%T90T*("`@("H@0'!A<F%M("`@('-T<FEN9R`@
M)'!?8V]M<')E<W,@8V%N(&)E(&YU;&PL("=G>B<@;W(@)V)Z,B<N(%1H:7,-
M"B`@("`J("`@("`@("`@("`@("`@("`@('!A<F%M971E<B!I;F1I8V%T97,@
M:68@9WII<"!O<B!B>C(@8V]M<')E<W-I;VX-"B`@("`J("`@("`@("`@("`@
M("`@("`@(&ES(')E<75I<F5D+B`@1F]R(&-O;7!A=&EB:6QI='D@<F5A<V]N
M('1H90T*("`@("H@("`@("`@("`@("`@("`@("`@8F]O;&5A;B!V86QU92`G
M=')U92<@;65A;G,@)V=Z)RX-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!!<F-H:79E7U1A<B@D<%]T87)N86UE+"`D<%]C
M;VUP<F5S<R`](&YU;&PI#0H@("`@>PT*("`@("`@("`D=&AI<RT^4$5!4B@I
M.PT*("`@("`@("`D=&AI<RT^7V-O;7!R97-S(#T@9F%L<V4[#0H@("`@("`@
M("1T:&ES+3Y?8V]M<')E<W-?='EP92`]("=N;VYE)SL-"B`@("`@("`@:68@
M*"@D<%]C;VUP<F5S<R`]/3T@;G5L;"D@?'P@*"1P7V-O;7!R97-S(#T]("<G
M*2D@>PT*("`@("`@("`@("`@:68@*$!F:6QE7V5X:7-T<R@D<%]T87)N86UE
M*2D@>PT*("`@("`@("`@("`@("`@(&EF("@D9G`@/2!`9F]P96XH)'!?=&%R
M;F%M92P@(G)B(BDI('L-"B`@("`@("`@("`@("`@("`@("`@+R\@;&]O:R!F
M;W(@9WII<"!M86=I8R!C;V]K:64-"B`@("`@("`@("`@("`@("`@("`@)&1A
M=&$@/2!F<F5A9"@D9G`L(#(I.PT*("`@("`@("`@("`@("`@("`@("!F8VQO
M<V4H)&9P*3L-"B`@("`@("`@("`@("`@("`@("`@:68@*"1D871A(#T](")<
M,S=<,C$S(BD@>PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M;VUP<F5S<R`]('1R=64[#0H@("`@("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-O;7!R97-S7W1Y<&4@/2`G9WHG.PT*("`@("`@("`@("`@("`@("`@
M("`O+R!.;R!S=7)E(&ET)W,@96YO=6=H="!F;W(@82!M86=I8R!C;V1E("XN
M+BX-"B`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1D871A(#T](")"
M6B(I('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?8V]M<')E
M<W,@/2!T<G5E.PT*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T@)V)Z,B<[#0H@("`@("`@("`@("`@("`@("`@('T-
M"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("`@("\O('!R;V)A8FQY(&$@<F5M;W1E(&9I;&4@;W(@<V]M
M92!F:6QE(&%C8V5S<VEB;&4-"B`@("`@("`@("`@("`@("`O+R!T:')O=6=H
M(&$@<W1R96%M(&EN=&5R9F%C90T*("`@("`@("`@("`@("`@(&EF("AS=6)S
M='(H)'!?=&%R;F%M92P@+3(I(#T]("=G>B<I('L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VUP<F5S<R`]('1R=64[#0H@("`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?8V]M<')E<W-?='EP92`]("=G>B<[#0H@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"AS=6)S='(H)'!?=&%R;F%M92P@+3,I(#T]
M("=B>C(G*2!\?`T*("`@("`@("`@("`@("`@("`@("`@("`@("`H<W5B<W1R
M*"1P7W1A<FYA;64L("TR*2`]/2`G8GHG*2D@>PT*("`@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-O;7!R97-S(#T@=')U93L-"B`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T@)V)Z,B<[#0H@("`@("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@?0T*("`@("`@("!](&5L<V4@>PT*
M("`@("`@("`@("`@:68@*"@D<%]C;VUP<F5S<R`]/3T@=')U92D@?'P@*"1P
M7V-O;7!R97-S(#T]("=G>B<I*2![#0H@("`@("`@("`@("`@("`@)'1H:7,M
M/E]C;VUP<F5S<R`]('1R=64[#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M;VUP<F5S<U]T>7!E(#T@)V=Z)SL-"B`@("`@("`@("`@('T@96QS92!I9B`H
M)'!?8V]M<')E<W,@/3T@)V)Z,B<I('L-"B`@("`@("`@("`@("`@("`D=&AI
M<RT^7V-O;7!R97-S(#T@=')U93L-"B`@("`@("`@("`@("`@("`D=&AI<RT^
M7V-O;7!R97-S7W1Y<&4@/2`G8GHR)SL-"B`@("`@("`@("`@('T@96QS92![
M#0H@("`@("`@("`@("`@("`@9&EE*")5;G-U<'!O<G1E9"!C;VUP<F5S<VEO
M;B!T>7!E("<D<%]C;VUP<F5S<R=<;B(N#0H@("`@("`@("`@("`@("`@("`@
M(")3=7!P;W)T960@='EP97,@87)E("=G>B<@86YD("=B>C(G+EQN(BD[#0H@
M("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@?0T*
M("`@("`@("!]#0H@("`@("`@("1T:&ES+3Y?=&%R;F%M92`]("1P7W1A<FYA
M;64[#0H@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S*2![("\O(&%S<V5R
M="!Z;&EB(&]R(&)Z,B!E>'1E;G-I;VX@<W5P<&]R=`T*("`@("`@("`@("`@
M:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@
M("`@("`@("1E>'1N86UE(#T@)WIL:6(G.PT*("`@("`@("`@("`@96QS92!I
M9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@
M("`@("`@("1E>'1N86UE(#T@)V)Z,B<[#0H-"B`@("`@("`@("`@(&EF("@A
M97AT96YS:6]N7VQO861E9"@D97AT;F%M92DI('L-"B`@("`@("`@("`@("`@
M("!014%2.CIL;V%D17AT96YS:6]N*"1E>'1N86UE*3L-"B`@("`@("`@("`@
M('T-"B`@("`@("`@("`@(&EF("@A97AT96YS:6]N7VQO861E9"@D97AT;F%M
M92DI('L-"B`@("`@("`@("`@("`@("!D:64H(E1H92!E>'1E;G-I;VX@)R1E
M>'1N86UE)R!C;W5L9&XG="!B92!F;W5N9"Y<;B(N#0H@("`@("`@("`@("`@
M("`@("`@(")0;&5A<V4@;6%K92!S=7)E('EO=7(@=F5R<VEO;B!O9B!02%`@
M=V%S(&)U:6QT("(N#0H@("`@("`@("`@("`@("`@("`@(")W:71H("<D97AT
M;F%M92<@<W5P<&]R="Y<;B(I.PT*("`@("`@("`@("`@("`@(')E='5R;B!F
M86QS93L-"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*("`@('T-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!D97-T<G5C=&]R#0H@("`@9G5N8W1I;VX@
M7T%R8VAI=F5?5&%R*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8VQO<V4H
M*3L-"B`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@82!L;V-A;"!C;W!Y('1O
M(&1E;&5T90T*("`@("`@("!I9B`H)'1H:7,M/E]T96UP7W1A<FYA;64@(3T@
M)R<I#0H@("`@("`@("`@("!`=6YL:6YK*"1T:&ES+3Y?=&5M<%]T87)N86UE
M*3L-"B`@("`@("`@)'1H:7,M/E]014%2*"D[#0H@("`@?0T*("`@("\O('U]
M?0T*#0H@("`@+R\@>WM[(&-R96%T92@I#0H@("`@+RHJ#0H@("`@*B!4:&ES
M(&UE=&AO9"!C<F5A=&5S('1H92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@
M9FEL97,@+R!D:7)E8W1O<FEE<PT*("`@("H@=&AA="!A<F4@;&ES=&5D(&EN
M("1P7V9I;&5L:7-T+@T*("`@("H@268@82!F:6QE('=I=&@@=&AE('-A;64@
M;F%M92!E>&ES="!A;F0@:7,@=W)I=&%B;&4L(&ET(&ES(')E<&QA8V5D#0H@
M("`@*B!B>2!T:&4@;F5W('1A<BX-"B`@("`J(%1H92!M971H;V0@<F5T=7)N
M(&9A;'-E(&%N9"!A(%!%05(@97)R;W(@=&5X="X-"B`@("`J(%1H92`D<%]F
M:6QE;&ES="!P87)A;65T97(@8V%N(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@
M96%C:"!S=')I;F<-"B`@("`J(')E<')E<V5N=&EN9R!A(&9I;&5N86UE(&]R
M(&$@9&ER96-T;W)Y(&YA;64@=VET:"!T:&5I<B!P871H(&EF#0H@("`@*B!N
M965D960N($ET(&-A;B!A;'-O(&)E(&$@<VEN9VQE('-T<FEN9R!W:71H(&YA
M;65S('-E<&%R871E9"!B>2!A#0H@("`@*B!S:6YG;&4@8FQA;FLN#0H@("`@
M*B!&;W(@96%C:"!D:7)E8W1O<GD@861D960@:6X@=&AE(&%R8VAI=F4L('1H
M92!F:6QE<R!A;F0-"B`@("`J('-U8BUD:7)E8W1O<FEE<R!A<F4@86QS;R!A
M9&1E9"X-"B`@("`J(%-E92!A;'-O(&-R96%T94UO9&EF>2@I(&UE=&AO9"!F
M;W(@;6]R92!D971A:6QS+@T*("`@("H-"B`@("`J($!P87)A;2!A<G)A>2`@
M)'!?9FEL96QI<W0@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O
M<GD@;F%M97,L(&]R(&$-"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<VEN9VQE('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A('-I;F=L
M90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("!B;&%N:R!S<&%C92X-
M"B`@("`J($!R971U<FX@("`@("`@("`@("`@("`@("`@=')U92!O;B!S=6-C
M97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!S964@8W)E871E36]D:69Y
M*"D-"B`@("`J($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO
M;B!C<F5A=&4H)'!?9FEL96QI<W0I#0H@("`@>PT*("`@("`@("!R971U<FX@
M)'1H:7,M/F-R96%T94UO9&EF>2@D<%]F:6QE;&ES="P@)R<L("<G*3L-"B`@
M("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@861D*"D-"B`@("`O*BH-
M"B`@("`J(%1H:7,@;65T:&]D(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O<FEE
M<R!T:&%T(&%R92!L:7-T960@:6X@)'!?9FEL96QI<W0@:6X-"B`@("`J('1H
M92!A<F-H:79E+B!)9B!T:&4@87)C:&EV92!D;V5S(&YO="!E>&ES="!I="!I
M<R!C<F5A=&5D+@T*("`@("H@5&AE(&UE=&AO9"!R971U<FX@9F%L<V4@86YD
M(&$@4$5!4B!E<G)O<B!T97AT+@T*("`@("H@5&AE(&9I;&5S(&%N9"!D:7)E
M8W1O<FEE<R!L:7-T960@87)E(&]N;'D@861D960@870@=&AE(&5N9"!O9B!T
M:&4@87)C:&EV92P-"B`@("`J(&5V96X@:68@82!F:6QE('=I=&@@=&AE('-A
M;64@;F%M92!I<R!A;')E861Y(&%R8VAI=F5D+@T*("`@("H@4V5E(&%L<V\@
M8W)E871E36]D:69Y*"D@;65T:&]D(&9O<B!M;W)E(&1E=&%I;',N#0H@("`@
M*@T*("`@("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES="!!;B!A<G)A>2!O
M9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP@;W(@80T*"2H@("`@
M("`@("`@("`@("`@("`@("`@("`@("!S:6YG;&4@<W1R:6YG('=I=&@@;F%M
M97,@<V5P87)A=&5D(&)Y(&$@<VEN9VQE#0H)*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)L86YK('-P86-E+@T*("`@("H@0')E='5R;B`@("`@("`@
M("`@("`@("`@("!T<G5E(&]N('-U8V-E<W,L(&9A;'-E(&]N(&5R<F]R+@T*
M("`@("H@0'-E92!C<F5A=&5-;V1I9GDH*0T*("`@("H@0&%C8V5S<R!P=6)L
M:6,-"B`@("`J+PT*("`@(&9U;F-T:6]N(&%D9"@D<%]F:6QE;&ES="D-"B`@
M("![#0H@("`@("`@(')E='5R;B`D=&AI<RT^861D36]D:69Y*"1P7V9I;&5L
M:7-T+"`G)RP@)R<I.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!E>'1R86-T*"D-"B`@("!F=6YC=&EO;B!E>'1R86-T*"1P7W!A=&@])R<I
M#0H@("`@>PT*("`@("`@("!R971U<FX@)'1H:7,M/F5X=')A8W1-;V1I9GDH
M)'!?<&%T:"P@)R<I.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[
M>R!L:7-T0V]N=&5N="@I#0H@("`@9G5N8W1I;VX@;&ES=$-O;G1E;G0H*0T*
M("`@('L-"B`@("`@("`@)'9?;&ES=%]D971A:6P@/2!A<G)A>2@I.PT*#0H@
M("`@("`@(&EF("@D=&AI<RT^7V]P96Y296%D*"DI('L-"B`@("`@("`@("`@
M(&EF("@A)'1H:7,M/E]E>'1R86-T3&ES="@G)RP@)'9?;&ES=%]D971A:6PL
M(")L:7-T(BP@)R<L("<G*2D@>PT*("`@("`@("`@("`@("`@('5N<V5T*"1V
M7VQI<W1?9&5T86EL*3L-"B`@("`@("`@("`@("`@("`D=E]L:7-T7V1E=&%I
M;"`](#`[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7V-L
M;W-E*"D[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@)'9?;&ES=%]D
M971A:6P[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&-R96%T
M94UO9&EF>2@I#0H@("`@+RHJ#0H@("`@*B!4:&ES(&UE=&AO9"!C<F5A=&5S
M('1H92!A<F-H:79E(&9I;&4@86YD(&%D9"!T:&4@9FEL97,@+R!D:7)E8W1O
M<FEE<PT*("`@("H@=&AA="!A<F4@;&ES=&5D(&EN("1P7V9I;&5L:7-T+@T*
M("`@("H@268@=&AE(&9I;&4@86QR96%D>2!E>&ES=',@86YD(&ES('=R:71A
M8FQE+"!I="!I<R!R97!L86-E9"!B>2!T:&4-"B`@("`J(&YE=R!T87(N($ET
M(&ES(&$@8W)E871E(&%N9"!N;W0@86X@861D+B!)9B!T:&4@9FEL92!E>&ES
M=',@86YD(&ES#0H@("`@*B!R96%D+6]N;'D@;W(@:7,@82!D:7)E8W1O<GD@
M:70@:7,@;F]T(')E<&QA8V5D+B!4:&4@;65T:&]D(')E='5R;@T*("`@("H@
M9F%L<V4@86YD(&$@4$5!4B!E<G)O<B!T97AT+@T*("`@("H@5&AE("1P7V9I
M;&5L:7-T('!A<F%M971E<B!C86X@8F4@86X@87)R87D@;V8@<W1R:6YG+"!E
M86-H('-T<FEN9PT*("`@("H@<F5P<F5S96YT:6YG(&$@9FEL96YA;64@;W(@
M82!D:7)E8W1O<GD@;F%M92!W:71H('1H96ER('!A=&@@:68-"B`@("`J(&YE
M961E9"X@270@8V%N(&%L<V\@8F4@82!S:6YG;&4@<W1R:6YG('=I=&@@;F%M
M97,@<V5P87)A=&5D(&)Y(&$-"B`@("`J('-I;F=L92!B;&%N:RX-"B`@("`J
M(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]R96UO=F5?9&ER('=I;&P@8F4@
M<F5M;W9E9"!F<F]M('1H90T*("`@("H@;65M;W)I>F5D('!A=&@@;V8@96%C
M:"!F:6QE("\@9&ER96-T;W)Y(&QI<W1E9"!W:&5N('1H:7,@<&%T:`T*("`@
M("H@97AI<W1S+B!">2!D969A=6QT(&YO=&AI;F<@:7,@<F5M;W9E9"`H96UP
M='D@<&%T:"`G)RD-"B`@("`J(%1H92!P871H(&EN9&EC871E9"!I;B`D<%]A
M9&1?9&ER('=I;&P@8F4@861D960@870@=&AE(&)E9VEN;FEN9R!O9@T*("`@
M("H@=&AE(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R
M>2!L:7-T960N($AO=V5V97(@:70@8V%N#0H@("`@*B!B92!S970@=&\@96UP
M='D@)R<N(%1H92!A9&1I;F<@;V8@82!P871H(&ES(&1O;F4@869T97(@=&AE
M(')E;6]V:6YG#0H@("`@*B!O9B!P871H+@T*("`@("H@5&AE('!A=&@@861D
M+W)E;6]V92!A8FEL:71Y(&5N86)L97,@=&AE('5S97(@=&\@<')E<&%R92!A
M;B!A<F-H:79E#0H@("`@*B!F;W(@97AT<F%C=&EO;B!I;B!A(&1I9F9E<F5N
M="!P871H('1H86X@=&AE(&]R:6=I;B!F:6QE<R!A<F4N#0H@("`@*B!3964@
M86QS;R!A9&1-;V1I9GDH*2!M971H;V0@9F]R(&9I;&4@861D:6YG('!R;W!E
M<G1I97,N#0H@("`@*@T*("`@("H@0'!A<F%M(&%R<F%Y("`D<%]F:6QE;&ES
M="`@("`@06X@87)R87D@;V8@9FEL96YA;65S(&%N9"!D:7)E8W1O<GD@;F%M
M97,L#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!O<B!A('-I
M;F=L92!S=')I;F<@=VET:"!N86UE<R!S97!A<F%T960@8GD-"@DJ("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&$@<VEN9VQE(&)L86YK('-P86-E
M+@T*("`@("H@0'!A<F%M('-T<FEN9R`D<%]A9&1?9&ER("`@("`@02!S=')I
M;F<@=VAI8V@@8V]N=&%I;G,@82!P871H('1O(&)E(&%D9&5D#0H)*B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!T;R!T:&4@;65M;W)I>F5D('!A
M=&@@;V8@96%C:"!E;&5M96YT(&EN#0H)*B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!T:&4@;&ES="X-"B`@("`J($!P87)A;2!S=')I;F<@)'!?
M<F5M;W9E7V1I<B`@($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@<&%T:"!T
M;R!B90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<F5M;W9E
M9"!F<F]M('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H#0H)*B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!E;&5M96YT(&EN('1H92!L:7-T+"!W
M:&5N(')E;&5V86YT+@T*("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("`@
M("`@("`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@*B!`<V5E(&%D9$UO9&EF>2@I#0H@("`@
M*B\-"B`@("!F=6YC=&EO;B!C<F5A=&5-;V1I9GDH)'!?9FEL96QI<W0L("1P
M7V%D9%]D:7(L("1P7W)E;6]V95]D:7(])R<I#0H@("`@>PT*("`@("`@("`D
M=E]R97-U;'0@/2!T<G5E.PT*#0H@("`@("`@(&EF("@A)'1H:7,M/E]O<&5N
M5W)I=&4H*2D-"B`@("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@
M("!I9B`H)'!?9FEL96QI<W0@(3T@)R<I('L-"B`@("`@("`@("`@(&EF("AI
M<U]A<G)A>2@D<%]F:6QE;&ES="DI#0H@("`@("`@("`@("`@("`@)'9?;&ES
M="`]("1P7V9I;&5L:7-T.PT*("`@("`@("`@("`@96QS96EF("AI<U]S=')I
M;F<H)'!?9FEL96QI<W0I*0T*("`@("`@("`@("`@("`@("1V7VQI<W0@/2!E
M>'!L;V1E*"1T:&ES+3Y?<V5P87)A=&]R+"`D<%]F:6QE;&ES="D[#0H@("`@
M("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V-L96%N
M1FEL92@I.PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L
M:60@9FEL92!L:7-T)RD[#0H@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E
M.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`D=E]R97-U;'0@/2`D
M=&AI<RT^7V%D9$QI<W0H)'9?;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E
M7V1I<BD[#0H@("`@("`@('T-"@T*("`@("`@("!I9B`H)'9?<F5S=6QT*2![
M#0H@("`@("`@("`@("`D=&AI<RT^7W=R:71E1F]O=&5R*"D[#0H@("`@("`@
M("`@("`D=&AI<RT^7V-L;W-E*"D[#0H@("`@("`@('T@96QS90T*("`@("`@
M("`@("`@)'1H:7,M/E]C;&5A;D9I;&4H*3L-"@T*("`@("`@("!R971U<FX@
M)'9?<F5S=6QT.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!A
M9&1-;V1I9GDH*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@861D('1H
M92!F:6QE<R`O(&1I<F5C=&]R:65S(&QI<W1E9"!I;B`D<%]F:6QE;&ES="!A
M="!T:&4-"B`@("`J(&5N9"!O9B!T:&4@97AI<W1I;F<@87)C:&EV92X@268@
M=&AE(&%R8VAI=F4@9&]E<R!N;W0@>65T(&5X:7-T<R!I=`T*("`@("H@:7,@
M8W)E871E9"X-"B`@("`J(%1H92`D<%]F:6QE;&ES="!P87)A;65T97(@8V%N
M(&)E(&%N(&%R<F%Y(&]F('-T<FEN9RP@96%C:"!S=')I;F<-"B`@("`J(')E
M<')E<V5N=&EN9R!A(&9I;&5N86UE(&]R(&$@9&ER96-T;W)Y(&YA;64@=VET
M:"!T:&5I<B!P871H(&EF#0H@("`@*B!N965D960N($ET(&-A;B!A;'-O(&)E
M(&$@<VEN9VQE('-T<FEN9R!W:71H(&YA;65S('-E<&%R871E9"!B>2!A#0H@
M("`@*B!S:6YG;&4@8FQA;FLN#0H@("`@*B!4:&4@<&%T:"!I;F1I8V%T960@
M:6X@)'!?<F5M;W9E7V1I<B!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4-"B`@
M("`J(&UE;6]R:7IE9"!P871H(&]F(&5A8V@@9FEL92`O(&1I<F5C=&]R>2!L
M:7-T960@=VAE;B!T:&ES('!A=&@-"B`@("`J(&5X:7-T<RX@0GD@9&5F875L
M="!N;W1H:6YG(&ES(')E;6]V960@*&5M<'1Y('!A=&@@)R<I#0H@("`@*B!4
M:&4@<&%T:"!I;F1I8V%T960@:6X@)'!?861D7V1I<B!W:6QL(&)E(&%D9&5D
M(&%T('1H92!B96=I;FYI;F<@;V8-"B`@("`J('1H92!M96UO<FEZ960@<&%T
M:"!O9B!E86-H(&9I;&4@+R!D:7)E8W1O<GD@;&ES=&5D+B!(;W=E=F5R(&ET
M(&-A;@T*("`@("H@8F4@<V5T('1O(&5M<'1Y("<G+B!4:&4@861D:6YG(&]F
M(&$@<&%T:"!I<R!D;VYE(&%F=&5R('1H92!R96UO=FEN9PT*("`@("H@;V8@
M<&%T:"X-"B`@("`J(%1H92!P871H(&%D9"]R96UO=F4@86)I;&ET>2!E;F%B
M;&5S('1H92!U<V5R('1O('!R97!A<F4@86X@87)C:&EV90T*("`@("H@9F]R
M(&5X=')A8W1I;VX@:6X@82!D:69F97)E;G0@<&%T:"!T:&%N('1H92!O<FEG
M:6X@9FEL97,@87)E+@T*("`@("H@268@82!F:6QE+V1I<B!I<R!A;')E861Y
M(&EN('1H92!A<F-H:79E(&ET('=I;&P@;VYL>2!B92!A9&1E9"!A="!T:&4-
M"B`@("`J(&5N9"!O9B!T:&4@87)C:&EV92X@5&AE<F4@:7,@;F\@=7!D871E
M(&]F('1H92!E>&ES=&EN9R!A<F-H:79E9`T*("`@("H@9FEL92]D:7(N($AO
M=V5V97(@=VAI;&4@97AT<F%C=&EN9R!T:&4@87)C:&EV92P@=&AE(&QA<W0@
M9FEL92!W:6QL#0H@("`@*B!R97!L86-E('1H92!F:7)S="!O;F4N(%1H:7,@
M<F5S=6QT<R!I;B!A(&YO;F4@;W!T:6UI>F%T:6]N(&]F('1H90T*("`@("H@
M87)C:&EV92!S:7IE+@T*("`@("H@268@82!F:6QE+V1I<B!D;V5S(&YO="!E
M>&ES="!T:&4@9FEL92]D:7(@:7,@:6=N;W)E9"X@2&]W979E<B!A;@T*("`@
M("H@97)R;W(@=&5X="!I<R!S96YD('1O(%!%05(@97)R;W(N#0H@("`@*B!)
M9B!A(&9I;&4O9&ER(&ES(&YO="!R96%D86)L92!T:&4@9FEL92]D:7(@:7,@
M:6=N;W)E9"X@2&]W979E<B!A;@T*("`@("H@97)R;W(@=&5X="!I<R!S96YD
M('1O(%!%05(@97)R;W(N#0H@("`@*@T*("`@("H@0'!A<F%M(&%R<F%Y("`@
M("`@)'!?9FEL96QI<W0@("`@($%N(&%R<F%Y(&]F(&9I;&5N86UE<R!A;F0@
M9&ER96-T;W)Y#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@;F%M97,L(&]R(&$@<VEN9VQE('-T<FEN9R!W:71H(&YA;65S#0H)*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@<V5P87)A=&5D(&)Y
M(&$@<VEN9VQE(&)L86YK('-P86-E+@T*("`@("H@0'!A<F%M('-T<FEN9R`@
M("`@)'!?861D7V1I<B`@("`@($$@<W1R:6YG('=H:6-H(&-O;G1A:6YS(&$@
M<&%T:"!T;R!B90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&%D9&5D('1O('1H92!M96UO<FEZ960@<&%T:"!O9B!E86-H#0H)*B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96QE;65N="!I;B!T
M:&4@;&ES="X-"B`@("`J($!P87)A;2!S=')I;F<@("`@("1P7W)E;6]V95]D
M:7(@("!!('-T<FEN9R!W:&EC:"!C;VYT86EN<R!A('!A=&@@=&\@8F4-"@DJ
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!R96UO=F5D(&9R
M;VT@=&AE(&UE;6]R:7IE9"!P871H(&]F#0H)*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@96%C:"!E;&5M96YT(&EN('1H92!L:7-T+"!W
M:&5N#0H@("`@*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<F5L979A;G0N#0H@("`@*B!`<F5T=7)N("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J
M($!A8V-E<W,@<'5B;&EC#0H@("`@*B\-"B`@("!F=6YC=&EO;B!A9&1-;V1I
M9GDH)'!?9FEL96QI<W0L("1P7V%D9%]D:7(L("1P7W)E;6]V95]D:7(])R<I
M#0H@("`@>PT*("`@("`@("`D=E]R97-U;'0@/2!T<G5E.PT*#0H@("`@("`@
M(&EF("@A)'1H:7,M/E]I<T%R8VAI=F4H*2D-"B`@("`@("`@("`@("1V7W)E
M<W5L="`]("1T:&ES+3YC<F5A=&5-;V1I9GDH)'!?9FEL96QI<W0L("1P7V%D
M9%]D:7(L#0H)"0D@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P
M7W)E;6]V95]D:7(I.PT*("`@("`@("!E;'-E('L-"B`@("`@("`@("`@(&EF
M("AI<U]A<G)A>2@D<%]F:6QE;&ES="DI#0H@("`@("`@("`@("`@("`@)'9?
M;&ES="`]("1P7V9I;&5L:7-T.PT*("`@("`@("`@("`@96QS96EF("AI<U]S
M=')I;F<H)'!?9FEL96QI<W0I*0T*("`@("`@("`@("`@("`@("1V7VQI<W0@
M/2!E>'!L;V1E*"1T:&ES+3Y?<V5P87)A=&]R+"`D<%]F:6QE;&ES="D[#0H@
M("`@("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R
M<F]R*"=);G9A;&ED(&9I;&4@;&ES="<I.PT*("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@)'9?
M<F5S=6QT(#T@)'1H:7,M/E]A<'!E;F0H)'9?;&ES="P@)'!?861D7V1I<BP@
M)'!?<F5M;W9E7V1I<BD[#0H@("`@("`@('T-"@T*("`@("`@("!R971U<FX@
M)'9?<F5S=6QT.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!A
M9&13=')I;F<H*0T*("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@861D(&$@
M<VEN9VQE('-T<FEN9R!A<R!A(&9I;&4@870@=&AE#0H@("`@*B!E;F0@;V8@
M=&AE(&5X:7-T:6YG(&%R8VAI=F4N($EF('1H92!A<F-H:79E(&1O97,@;F]T
M('EE="!E>&ES=',@:70-"B`@("`J(&ES(&-R96%T960N#0H@("`@*@T*("`@
M("H@0'!A<F%M('-T<FEN9R`@("`@)'!?9FEL96YA;64@("`@($$@<W1R:6YG
M('=H:6-H(&-O;G1A:6YS('1H92!F=6QL#0H)*B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@9FEL96YA;64@<&%T:"!T:&%T('=I;&P@8F4@
M87-S;V-I871E9`T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('=I=&@@=&AE('-T<FEN9RX-"B`@("`J($!P87)A;2!S=')I;F<@("`@
M("1P7W-T<FEN9R`@("`@("!4:&4@8V]N=&5N="!O9B!T:&4@9FEL92!A9&1E
M9"!I;@T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H
M92!A<F-H:79E+@T*("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("`@
M("`@("`@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@861D4W1R
M:6YG*"1P7V9I;&5N86UE+"`D<%]S=')I;F<I#0H@("`@>PT*("`@("`@("`D
M=E]R97-U;'0@/2!T<G5E.PT*("`@("`@("`-"B`@("`@("`@:68@*"$D=&AI
M<RT^7VES07)C:&EV92@I*2![#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?
M;W!E;E=R:71E*"DI('L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L<V4[
M#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("`D=&AI<RT^7V-L;W-E*"D[
M#0H@("`@("`@('T-"B`@("`@("`@#0H@("`@("`@(&EF("@A)'1H:7,M/E]O
M<&5N07!P96YD*"DI#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H-"B`@
M("`@("`@+R\@3F5E9"!T;R!C:&5C:R!T:&4@9V5T(&)A8VL@=&\@=&AE('1E
M;7!O<F%R>2!F:6QE(#\@+BXN+@T*("`@("`@("`D=E]R97-U;'0@/2`D=&AI
M<RT^7V%D9%-T<FEN9R@D<%]F:6QE;F%M92P@)'!?<W1R:6YG*3L-"@T*("`@
M("`@("`D=&AI<RT^7W=R:71E1F]O=&5R*"D[#0H-"B`@("`@("`@)'1H:7,M
M/E]C;&]S92@I.PT*#0H@("`@("`@(')E='5R;B`D=E]R97-U;'0[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(&5X=')A8W1-;V1I9GDH*0T*
M("`@("\J*@T*("`@("H@5&AI<R!M971H;V0@97AT<F%C="!A;&P@=&AE(&-O
M;G1E;G0@;V8@=&AE(&%R8VAI=F4@:6X@=&AE(&1I<F5C=&]R>0T*("`@("H@
M:6YD:6-A=&5D(&)Y("1P7W!A=&@N(%=H96X@<F5L979A;G0@=&AE(&UE;6]R
M:7IE9"!P871H(&]F('1H90T*("`@("H@9FEL97,O9&ER(&-A;B!B92!M;V1I
M9FEE9"!B>2!R96UO=FEN9R!T:&4@)'!?<F5M;W9E7W!A=&@@<&%T:"!A="!T
M:&4-"B`@("`J(&)E9VEN;FEN9R!O9B!T:&4@9FEL92]D:7(@<&%T:"X-"B`@
M("`J(%=H:6QE(&5X=')A8W1I;F<@82!F:6QE+"!I9B!T:&4@9&ER96-T;W)Y
M('!A=&@@9&]E<R!N;W0@97AI<W1S(&ET(&ES#0H@("`@*B!C<F5A=&5D+@T*
M("`@("H@5VAI;&4@97AT<F%C=&EN9R!A(&9I;&4L(&EF('1H92!F:6QE(&%L
M<F5A9'D@97AI<W1S(&ET(&ES(')E<&QA8V5D#0H@("`@*B!W:71H;W5T(&QO
M;VMI;F<@9F]R(&QA<W0@;6]D:69I8V%T:6]N(&1A=&4N#0H@("`@*B!7:&EL
M92!E>'1R86-T:6YG(&$@9FEL92P@:68@=&AE(&9I;&4@86QR96%D>2!E>&ES
M=',@86YD(&ES('=R:71E#0H@("`@*B!P<F]T96-T960L('1H92!E>'1R86-T
M:6]N(&ES(&%B;W)T960N#0H@("`@*B!7:&EL92!E>'1R86-T:6YG(&$@9FEL
M92P@:68@82!D:7)E8W1O<GD@=VET:"!T:&4@<V%M92!N86UE(&%L<F5A9'D-
M"B`@("`J(&5X:7-T<RP@=&AE(&5X=')A8W1I;VX@:7,@86)O<G1E9"X-"B`@
M("`J(%=H:6QE(&5X=')A8W1I;F<@82!D:7)E8W1O<GDL(&EF(&$@9FEL92!W
M:71H('1H92!S86UE(&YA;64@86QR96%D>0T*("`@("H@97AI<W1S+"!T:&4@
M97AT<F%C=&EO;B!I<R!A8F]R=&5D+@T*("`@("H@5VAI;&4@97AT<F%C=&EN
M9R!A(&9I;&4O9&ER96-T;W)Y(&EF('1H92!D97-T:6YA=&EO;B!D:7)E8W1O
M<GD@97AI<W0-"B`@("`J(&%N9"!I<R!W<FET92!P<F]T96-T960L(&]R(&1O
M97,@;F]T(&5X:7-T(&)U="!C86X@;F]T(&)E(&-R96%T960L#0H@("`@*B!T
M:&4@97AT<F%C=&EO;B!I<R!A8F]R=&5D+@T*("`@("H@268@869T97(@97AT
M<F%C=&EO;B!A;B!E>'1R86-T960@9FEL92!D;V5S(&YO="!S:&]W('1H92!C
M;W)R96-T#0H@("`@*B!S=&]R960@9FEL92!S:7IE+"!T:&4@97AT<F%C=&EO
M;B!I<R!A8F]R=&5D+@T*("`@("H@5VAE;B!T:&4@97AT<F%C=&EO;B!I<R!A
M8F]R=&5D+"!A(%!%05(@97)R;W(@=&5X="!I<R!S970@86YD(&9A;'-E#0H@
M("`@*B!I<R!R971U<FYE9"X@2&]W979E<B!T:&4@<F5S=6QT(&-A;B!B92!A
M('!A<G1I86P@97AT<F%C=&EO;B!T:&%T(&UA>0T*("`@("H@;F5E9"!T;R!B
M92!M86YU86QL>2!C;&5A;F5D+@T*("`@("H-"B`@("`J($!P87)A;2!S=')I
M;F<@)'!?<&%T:"`@("`@("`@(%1H92!P871H(&]F('1H92!D:7)E8W1O<GD@
M=VAE<F4@=&AE#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!F
M:6QE<R]D:7(@;F5E9"!T;R!B>2!E>'1R86-T960N#0H@("`@*B!`<&%R86T@
M<W1R:6YG("1P7W)E;6]V95]P871H("!087)T(&]F('1H92!M96UO<FEZ960@
M<&%T:"!T:&%T(&-A;B!B90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@<F5M;W9E9"!I9B!P<F5S96YT(&%T('1H92!B96=I;FYI;F<@;V8-
M"@DJ("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('1H92!F:6QE+V1I
M<B!P871H+@T*("`@("H@0')E='5R;B!B;V]L96%N("`@("`@("`@("`@("`@
M=')U92!O;B!S=6-C97-S+"!F86QS92!O;B!E<G)O<BX-"B`@("`J($!A8V-E
M<W,@<'5B;&EC#0H@("`@*B!`<V5E(&5X=')A8W1,:7-T*"D-"B`@("`J+PT*
M("`@(&9U;F-T:6]N(&5X=')A8W1-;V1I9GDH)'!?<&%T:"P@)'!?<F5M;W9E
M7W!A=&@I#0H@("`@>PT*("`@("`@("`D=E]R97-U;'0@/2!T<G5E.PT*("`@
M("`@("`D=E]L:7-T7V1E=&%I;"`](&%R<F%Y*"D[#0H-"B`@("`@("`@:68@
M*"1V7W)E<W5L="`]("1T:&ES+3Y?;W!E;E)E860H*2D@>PT*("`@("`@("`@
M("`@)'9?<F5S=6QT(#T@)'1H:7,M/E]E>'1R86-T3&ES="@D<%]P871H+"`D
M=E]L:7-T7V1E=&%I;"P-"@D)"2`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(F-O;7!L971E(BP@,"P@)'!?<F5M;W9E7W!A=&@I.PT*("`@("`@
M("`@("`@)'1H:7,M/E]C;&]S92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O
M+R![>WL@97AT<F%C=$EN4W1R:6YG*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@
M;65T:&]D(&5X=')A8W0@9G)O;2!T:&4@87)C:&EV92!O;F4@9FEL92!I9&5N
M=&EF:65D(&)Y("1P7V9I;&5N86UE+@T*("`@("H@5&AE(')E='5R;B!V86QU
M92!I<R!A('-T<FEN9R!W:71H('1H92!F:6QE(&-O;G1E;G0L(&]R($Y53$P@
M;VX@97)R;W(N#0H@("`@*B!`<&%R86T@<W1R:6YG("1P7V9I;&5N86UE("`@
M("!4:&4@<&%T:"!O9B!T:&4@9FEL92!T;R!E>'1R86-T(&EN(&$@<W1R:6YG
M+@T*("`@("H@0')E='5R;B`@("`@("`@("`@("`@("`@("`@("`@82!S=')I
M;F<@=VET:"!T:&4@9FEL92!C;VYT96YT(&]R($Y53$PN#0H@("`@*B!`86-C
M97-S('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@97AT<F%C=$EN4W1R
M:6YG*"1P7V9I;&5N86UE*0T*("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?
M;W!E;E)E860H*2D@>PT*("`@("`@("`@("`@)'9?<F5S=6QT(#T@)'1H:7,M
M/E]E>'1R86-T26Y3=')I;F<H)'!?9FEL96YA;64I.PT*("`@("`@("`@("`@
M)'1H:7,M/E]C;&]S92@I.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@)'9?<F5S=6QT(#T@3E5,3#L-"B`@("`@("`@?0T*#0H@("`@("`@(')E
M='5R;B`D=E]R97-U;'0[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(&5X=')A8W1,:7-T*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D
M(&5X=')A8W0@9G)O;2!T:&4@87)C:&EV92!O;FQY('1H92!F:6QE<R!I;F1I
M8V%T960@:6X@=&AE#0H@("`@*B`D<%]F:6QE;&ES="X@5&AE<V4@9FEL97,@
M87)E(&5X=')A8W1E9"!I;B!T:&4@8W5R<F5N="!D:7)E8W1O<GD@;W(-"B`@
M("`J(&EN('1H92!D:7)E8W1O<GD@:6YD:6-A=&5D(&)Y('1H92!O<'1I;VYA
M;"`D<%]P871H('!A<F%M971E<BX-"B`@("`J($EF(&EN9&EC871E9"!T:&4@
M)'!?<F5M;W9E7W!A=&@@8V%N(&)E('5S960@:6X@=&AE('-A;64@=V%Y(&%S
M(&ET(&ES#0H@("`@*B!U<V5D(&EN(&5X=')A8W1-;V1I9GDH*2!M971H;V0N
M#0H@("`@*B!`<&%R86T@87)R87D@("1P7V9I;&5L:7-T("`@("!!;B!A<G)A
M>2!O9B!F:6QE;F%M97,@86YD(&1I<F5C=&]R>2!N86UE<RP-"@DJ("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&]R(&$@<VEN9VQE('-T<FEN9R!W
M:71H(&YA;65S('-E<&%R871E9`T*"2H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8GD@82!S:6YG;&4@8FQA;FL@<W!A8V4N#0H@("`@*B!`<&%R
M86T@<W1R:6YG("1P7W!A=&@@("`@("`@("!4:&4@<&%T:"!O9B!T:&4@9&ER
M96-T;W)Y('=H97)E('1H90T*"2H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@9FEL97,O9&ER(&YE960@=&\@8GD@97AT<F%C=&5D+@T*("`@("H@
M0'!A<F%M('-T<FEN9R`D<%]R96UO=F5?<&%T:"`@4&%R="!O9B!T:&4@;65M
M;W)I>F5D('!A=&@@=&AA="!C86X@8F4-"@DJ("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(')E;6]V960@:68@<')E<V5N="!A="!T:&4@8F5G:6YN
M:6YG(&]F#0H)*B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!T:&4@
M9FEL92]D:7(@<&%T:"X-"B`@("`J($!R971U<FX@("`@("`@("`@("`@("`@
M("`@("`@('1R=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@
M*B!`86-C97-S('!U8FQI8PT*("`@("H@0'-E92!E>'1R86-T36]D:69Y*"D-
M"B`@("`J+PT*("`@(&9U;F-T:6]N(&5X=')A8W1,:7-T*"1P7V9I;&5L:7-T
M+"`D<%]P871H/2<G+"`D<%]R96UO=F5?<&%T:#TG)RD-"B`@("![#0H@("`@
M("`@("1V7W)E<W5L="`]('1R=64[#0H@("`@("`@("1V7VQI<W1?9&5T86EL
M(#T@87)R87DH*3L-"@T*("`@("`@("!I9B`H:7-?87)R87DH)'!?9FEL96QI
M<W0I*0T*("`@("`@("`@("`@)'9?;&ES="`]("1P7V9I;&5L:7-T.PT*("`@
M("`@("!E;'-E:68@*&ES7W-T<FEN9R@D<%]F:6QE;&ES="DI#0H@("`@("`@
M("`@("`D=E]L:7-T(#T@97AP;&]D92@D=&AI<RT^7W-E<&%R871O<BP@)'!?
M9FEL96QI<W0I.PT*("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("1T:&ES
M+3Y?97)R;W(H)TEN=F%L:60@<W1R:6YG(&QI<W0G*3L-"B`@("`@("`@("`@
M(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@(&EF("@D=E]R
M97-U;'0@/2`D=&AI<RT^7V]P96Y296%D*"DI('L-"B`@("`@("`@("`@("1V
M7W)E<W5L="`]("1T:&ES+3Y?97AT<F%C=$QI<W0H)'!?<&%T:"P@)'9?;&ES
M=%]D971A:6PL(")P87)T:6%L(BP-"@D)"2`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'9?;&ES="P@)'!?<F5M;W9E7W!A=&@I.PT*("`@("`@
M("`@("`@)'1H:7,M/E]C;&]S92@I.PT*("`@("`@("!]#0H-"B`@("`@("`@
M<F5T=7)N("1V7W)E<W5L=#L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O
M+R![>WL@<V5T071T<FEB=71E*"D-"B`@("`O*BH-"B`@("`J(%1H:7,@;65T
M:&]D('-E="!S<&5C:69I8R!A='1R:6)U=&5S(&]F('1H92!A<F-H:79E+B!)
M="!U<V5S(&$@=F%R:6%B;&4-"B`@("`J(&QI<W0@;V8@<&%R86UE=&5R<RP@
M:6X@=&AE(&9O<FUA="!A='1R:6)U=&4@8V]D92`K(&%T=')I8G5T92!V86QU
M97,@.@T*("`@("H@)&%R8V@M/G-E=$%T=')I8G5T92A!4D-(259%7U1!4E]!
M5%1?4T5005)!5$]2+"`G+"<I.PT*("`@("H@0'!A<F%M(&UI>&5D("1A<F=V
M("`@("`@("`@("`@=F%R:6%B;&4@;&ES="!O9B!A='1R:6)U=&5S(&%N9"!V
M86QU97,-"B`@("`J($!R971U<FX@("`@("`@("`@("`@("`@("`@("`@('1R
M=64@;VX@<W5C8V5S<RP@9F%L<V4@;VX@97)R;W(N#0H@("`@*B!`86-C97-S
M('!U8FQI8PT*("`@("HO#0H@("`@9G5N8W1I;VX@<V5T071T<FEB=71E*"D-
M"B`@("![#0H@("`@("`@("1V7W)E<W5L="`]('1R=64[#0H@("`@("`@(`T*
M("`@("`@("`O+R`M+2TM+2!'970@=&AE(&YU;6)E<B!O9B!V87)I86)L92!L
M:7-T(&]F(&%R9W5M96YT<PT*("`@("`@("!I9B`H*"1V7W-I>F4@/2!F=6YC
M7VYU;5]A<F=S*"DI(#T](#`I('L-"B`@("`@("`@("`@(')E='5R;B!T<G5E
M.PT*("`@("`@("!]#0H@("`@("`@(`T*("`@("`@("`O+R`M+2TM+2!'970@
M=&AE(&%R9W5M96YT<PT*("`@("`@("`D=E]A='1?;&ES="`]("9F=6YC7V=E
M=%]A<F=S*"D[#0H-"B`@("`@("`@+R\@+2TM+2T@4F5A9"!T:&4@871T<FEB
M=71E<PT*("`@("`@("`D:3TP.PT*("`@("`@("!W:&EL92`H)&D\)'9?<VEZ
M92D@>PT*#0H@("`@("`@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!N97AT(&]P
M=&EO;@T*("`@("`@("`@("`@<W=I=&-H("@D=E]A='1?;&ES=%LD:5TI('L-
M"B`@("`@("`@("`@("`@("`O+R`M+2TM+2!,;V]K(&9O<B!O<'1I;VYS('1H
M870@<F5Q=65S="!A('-T<FEN9R!V86QU90T*("`@("`@("`@("`@("`@(&-A
M<V4@05)#2$E615]405)?05147U-%4$%2051/4B`Z#0H@("`@("`@("`@("`@
M("`@("`@("\O("TM+2TM($-H96-K('1H92!N=6UB97(@;V8@<&%R86UE=&5R
M<PT*("`@("`@("`@("`@("`@("`@("!I9B`H*"1I*S$I(#X]("1V7W-I>F4I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN
M=F%L:60@;G5M8F5R(&]F('!A<F%M971E<G,@9F]R("<-"@D)"0D)"2`@("`@
M("`@("`@("`@+B=A='1R:6)U=&4@05)#2$E615]405)?05147U-%4$%2051/
M4B<I.PT*("`@("`@("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*
M("`@("`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("`@("`@
M+R\@+2TM+2T@1V5T('1H92!V86QU90T*("`@("`@("`@("`@("`@("`@("`D
M=&AI<RT^7W-E<&%R871O<B`]("1V7V%T=%]L:7-T6R1I*S%=.PT*("`@("`@
M("`@("`@("`@("`@("`D:2LK.PT*("`@("`@("`@("`@("`@(&)R96%K.PT*
M#0H@("`@("`@("`@("`@("`@9&5F875L="`Z#0H@("`@("`@("`@("`@("`@
M("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=R!A='1R:6)U=&4@8V]D92`G+B1V
M7V%T=%]L:7-T6R1I72XG)RD[#0H@("`@("`@("`@("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@("`@("`@('T-"@T*("`@("`@("`@("`@+R\@+2TM
M+2T@3F5X="!A='1R:6)U=&4-"B`@("`@("`@("`@("1I*RL[#0H@("`@("`@
M('T-"@T*("`@("`@("!R971U<FX@)'9?<F5S=6QT.PT*("`@('T-"B`@("`O
M+R!]?7T-"@T*("`@("\O('M[>R!?97)R;W(H*0T*("`@(&9U;F-T:6]N(%]E
M<G)O<B@D<%]M97-S86=E*0T*("`@('L-"B`@("`@("`@+R\@+2TM+2T@5&\@
M8F4@8V]M<&QE=&5D#0H@("`@("`@("1T:&ES+3YR86ES945R<F]R*"1P7VUE
M<W-A9V4I.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?=V%R
M;FEN9R@I#0H@("`@9G5N8W1I;VX@7W=A<FYI;F<H)'!?;65S<V%G92D-"B`@
M("![#0H@("`@("`@("\O("TM+2TM(%1O(&)E(&-O;7!L971E9`T*("`@("`@
M("`D=&AI<RT^<F%I<V5%<G)O<B@D<%]M97-S86=E*3L-"B`@("!]#0H@("`@
M+R\@?7U]#0H-"B`@("`O+R![>WL@7VES07)C:&EV92@I#0H@("`@9G5N8W1I
M;VX@7VES07)C:&EV92@D<%]F:6QE;F%M93U.54Q,*0T*("`@('L-"B`@("`@
M("`@:68@*"1P7V9I;&5N86UE(#T]($Y53$PI('L-"B`@("`@("`@("`@("1P
M7V9I;&5N86UE(#T@)'1H:7,M/E]T87)N86UE.PT*("`@("`@("!]#0H@("`@
M("`@(&-L96%R<W1A=&-A8VAE*"D[#0H@("`@("`@(')E='5R;B!`:7-?9FEL
M92@D<%]F:6QE;F%M92D[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@
M>WM[(%]O<&5N5W)I=&4H*0T*("`@(&9U;F-T:6]N(%]O<&5N5W)I=&4H*0T*
M("`@('L-"B`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G
M9WHG*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&=Z;W!E;B@D=&AI
M<RT^7W1A<FYA;64L(")W8CDB*3L-"B`@("`@("`@96QS92!I9B`H)'1H:7,M
M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*0T*("`@("`@("`@("`@)'1H:7,M
M/E]F:6QE(#T@0&)Z;W!E;B@D=&AI<RT^7W1A<FYA;64L(")W8B(I.PT*("`@
M("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G
M*0T*("`@("`@("`@("`@)'1H:7,M/E]F:6QE(#T@0&9O<&5N*"1T:&ES+3Y?
M=&%R;F%M92P@(G=B(BD[#0H@("`@("`@(&5L<V4-"B`@("`@("`@("`@("1T
M:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP<F5S<VEO;B!T
M>7!E("@G#0H)"0D@("`@("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S7W1Y
M<&4N)RDG*3L-"@T*("`@("`@("!I9B`H)'1H:7,M/E]F:6QE(#T](#`I('L-
M"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L92!T;R!O<&5N(&EN
M('=R:71E(&UO9&4@7"<G#0H)"0D@("`@("`@("`@("`@("XD=&AI<RT^7W1A
M<FYA;64N)UPG)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("`@('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@
M?7U]#0H-"B`@("`O+R![>WL@7V]P96Y296%D*"D-"B`@("!F=6YC=&EO;B!?
M;W!E;E)E860H*0T*("`@('L-"B`@("`@("`@:68@*'-T<G1O;&]W97(H<W5B
M<W1R*"1T:&ES+3Y?=&%R;F%M92P@,"P@-RDI(#T]("=H='1P.B\O)RD@>PT*
M#0H@("`@("`@("`@+R\@+2TM+2T@3&]O:R!I9B!A(&QO8V%L(&-O<'D@;F5E
M9"!T;R!B92!D;VYE#0H@("`@("`@("`@:68@*"1T:&ES+3Y?=&5M<%]T87)N
M86UE(#T]("<G*2![#0H@("`@("`@("`@("`@("1T:&ES+3Y?=&5M<%]T87)N
M86UE(#T@=6YI<6ED*"=T87(G*2XG+G1M<"<[#0H@("`@("`@("`@("`@(&EF
M("@A)'9?9FEL95]F<F]M(#T@0&9O<&5N*"1T:&ES+3Y?=&%R;F%M92P@)W)B
M)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@
M=&\@;W!E;B!I;B!R96%D(&UO9&4@7"<G#0H)"0D)("`@("`@("`@("`@("`N
M)'1H:7,M/E]T87)N86UE+B=<)R<I.PT*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?=&5M<%]T87)N86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@<F5T=7)N
M(&9A;'-E.PT*("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@(&EF("@A
M)'9?9FEL95]T;R`]($!F;W!E;B@D=&AI<RT^7W1E;7!?=&%R;F%M92P@)W=B
M)RDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;F%B;&4@
M=&\@;W!E;B!I;B!W<FET92!M;V1E(%PG)PT*"0D)"2`@("`@("`@("`@("`@
M+B1T:&ES+3Y?=&5M<%]T87)N86UE+B=<)R<I.PT*("`@("`@("`@("`@("`@
M("1T:&ES+3Y?=&5M<%]T87)N86UE(#T@)R<[#0H@("`@("`@("`@("`@("`@
M<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@("!]#0H@("`@("`@("`@("`@
M('=H:6QE("@D=E]D871A(#T@0&9R96%D*"1V7V9I;&5?9G)O;2P@,3`R-"DI
M#0H@("`@("`@("`@("`@("`@("!`9G=R:71E*"1V7V9I;&5?=&\L("1V7V1A
M=&$I.PT*("`@("`@("`@("`@("!`9F-L;W-E*"1V7V9I;&5?9G)O;2D[#0H@
M("`@("`@("`@("`@($!F8VQO<V4H)'9?9FEL95]T;RD[#0H@("`@("`@("`@
M?0T*#0H@("`@("`@("`@+R\@+2TM+2T@1FEL92!T;R!O<&5N(&EF('1H92!L
M;V-A;"!C;W!Y#0H@("`@("`@("`@)'9?9FEL96YA;64@/2`D=&AI<RT^7W1E
M;7!?=&%R;F%M93L-"@T*("`@("`@("!](&5L<V4-"B`@("`@("`@("`O+R`M
M+2TM+2!&:6QE('1O(&]P96X@:68@=&AE(&YO<FUA;"!487(@9FEL90T*("`@
M("`@("`@("1V7V9I;&5N86UE(#T@)'1H:7,M/E]T87)N86UE.PT*#0H@("`@
M("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@
M("`@("`@("1T:&ES+3Y?9FEL92`]($!G>F]P96XH)'9?9FEL96YA;64L(")R
M8B(I.PT*("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@
M/3T@)V)Z,B<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I;&4@/2!`8GIO<&5N
M*"1V7V9I;&5N86UE+"`B<F(B*3L-"B`@("`@("`@96QS92!I9B`H)'1H:7,M
M/E]C;VUP<F5S<U]T>7!E(#T]("=N;VYE)RD-"B`@("`@("`@("`@("1T:&ES
M+3Y?9FEL92`]($!F;W!E;B@D=E]F:6QE;F%M92P@(G)B(BD[#0H@("`@("`@
M(&5L<V4-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@
M;6ES<VEN9R!C;VUP<F5S<VEO;B!T>7!E("@G#0H)"0D@("`@("`@("`@("`@
M("XD=&AI<RT^7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*("`@("`@("!I9B`H
M)'1H:7,M/E]F:6QE(#T](#`I('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R
M;W(H)U5N86)L92!T;R!O<&5N(&EN(')E860@;6]D92!<)R<N)'9?9FEL96YA
M;64N)UPG)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M('T-"@T*("`@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]
M#0H-"B`@("`O+R![>WL@7V]P96Y296%D5W)I=&4H*0T*("`@(&9U;F-T:6]N
M(%]O<&5N4F5A9%=R:71E*"D-"B`@("![#0H@("`@("`@(&EF("@D=&AI<RT^
M7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("1T:&ES+3Y?
M9FEL92`]($!G>F]P96XH)'1H:7,M/E]T87)N86UE+"`B<BMB(BD[#0H@("`@
M("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-
M"B`@("`@("`@("`@("1T:&ES+3Y?9FEL92`]($!B>F]P96XH)'1H:7,M/E]T
M87)N86UE+"`B<BMB(BD[#0H@("`@("`@(&5L<V4@:68@*"1T:&ES+3Y?8V]M
M<')E<W-?='EP92`]/2`G;F]N92<I#0H@("`@("`@("`@("`D=&AI<RT^7V9I
M;&4@/2!`9F]P96XH)'1H:7,M/E]T87)N86UE+"`B<BMB(BD[#0H@("`@("`@
M(&5L<V4-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@
M;6ES<VEN9R!C;VUP<F5S<VEO;B!T>7!E("@G#0H)"0D@("`@("`@("`@("`@
M("XD=&AI<RT^7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*("`@("`@("!I9B`H
M)'1H:7,M/E]F:6QE(#T](#`I('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R
M;W(H)U5N86)L92!T;R!O<&5N(&EN(')E860O=W)I=&4@;6]D92!<)R<-"@D)
M"2`@("`@("`@("`@("`@+B1T:&ES+3Y?=&%R;F%M92XG7"<G*3L-"B`@("`@
M("`@("`@(')E='5R;B!F86QS93L-"B`@("`@("`@?0T*#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?
M8VQO<V4H*0T*("`@(&9U;F-T:6]N(%]C;&]S92@I#0H@("`@>PT*("`@("`@
M("`O+VEF("AI<W-E="@D=&AI<RT^7V9I;&4I*2![#0H@("`@("`@(&EF("AI
M<U]R97-O=7)C92@D=&AI<RT^7V9I;&4I*2![#0H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=G>B<I#0H@("`@("`@("`@("`@
M("`@0&=Z8VQO<V4H)'1H:7,M/E]F:6QE*3L-"B`@("`@("`@("`@(&5L<V4@
M:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@
M("`@("`@("!`8GIC;&]S92@D=&AI<RT^7V9I;&4I.PT*("`@("`@("`@("`@
M96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=N;VYE)RD-"B`@
M("`@("`@("`@("`@("!`9F-L;W-E*"1T:&ES+3Y?9FEL92D[#0H@("`@("`@
M("`@("!E;'-E#0H@("`@("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK
M;F]W;B!O<B!M:7-S:6YG(&-O;7!R97-S:6]N('1Y<&4@*"<-"@D)"0D@("`@
M("`@("`@("`@("XD=&AI<RT^7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*("`@
M("`@("`@("`@)'1H:7,M/E]F:6QE(#T@,#L-"B`@("`@("`@?0T*#0H@("`@
M("`@("\O("TM+2TM($QO;VL@:68@82!L;V-A;"!C;W!Y(&YE960@=&\@8F4@
M97)A<V4-"B`@("`@("`@+R\@3F]T92!T:&%T(&ET(&UI9VAT(&)E(&EN=&5R
M97-T:6YG('1O(&ME97`@=&AE('5R;"!F;W(@82!T:6UE(#H@5&]$;PT*("`@
M("`@("!I9B`H)'1H:7,M/E]T96UP7W1A<FYA;64@(3T@)R<I('L-"B`@("`@
M("`@("`@($!U;FQI;FLH)'1H:7,M/E]T96UP7W1A<FYA;64I.PT*("`@("`@
M("`@("`@)'1H:7,M/E]T96UP7W1A<FYA;64@/2`G)SL-"B`@("`@("`@?0T*
M#0H@("`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*
M("`@("\O('M[>R!?8VQE86Y&:6QE*"D-"B`@("!F=6YC=&EO;B!?8VQE86Y&
M:6QE*"D-"B`@("![#0H@("`@("`@("1T:&ES+3Y?8VQO<V4H*3L-"@T*("`@
M("`@("`O+R`M+2TM+2!,;V]K(&9O<B!A(&QO8V%L(&-O<'D-"B`@("`@("`@
M:68@*"1T:&ES+3Y?=&5M<%]T87)N86UE("$]("<G*2![#0H@("`@("`@("`@
M("`O+R`M+2TM+2!296UO=F4@=&AE(&QO8V%L(&-O<'D@8G5T(&YO="!T:&4@
M<F5M;W1E('1A<FYA;64-"B`@("`@("`@("`@($!U;FQI;FLH)'1H:7,M/E]T
M96UP7W1A<FYA;64I.PT*("`@("`@("`@("`@)'1H:7,M/E]T96UP7W1A<FYA
M;64@/2`G)SL-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("\O("TM
M+2TM(%)E;6]V92!T:&4@;&]C86P@=&%R;F%M92!F:6QE#0H@("`@("`@("`@
M("!`=6YL:6YK*"1T:&ES+3Y?=&%R;F%M92D[#0H@("`@("`@('T-"B`@("`@
M("`@)'1H:7,M/E]T87)N86UE(#T@)R<[#0H-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]W<FET94)L
M;V-K*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5";&]C:R@D<%]B:6YA<GE?9&%T
M82P@)'!?;&5N/6YU;&PI#0H@("`@>PT*("`@("`@:68@*&ES7W)E<V]U<F-E
M*"1T:&ES+3Y?9FEL92DI('L-"B`@("`@("`@("!I9B`H)'!?;&5N(#T]/2!N
M=6QL*2![#0H@("`@("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y
M<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@("`@($!G>G!U=',H)'1H:7,M
M/E]F:6QE+"`D<%]B:6YA<GE?9&%T82D[#0H@("`@("`@("`@("`@(&5L<V4@
M:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@
M("`@("`@("`@($!B>G=R:71E*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A
M=&$I.PT*("`@("`@("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S
M7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@("`@("`@("`@("`@0&9P=71S*"1T
M:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A=&$I.PT*("`@("`@("`@("`@("!E
M;'-E#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=5;FMN;W=N
M(&]R(&UI<W-I;F<@8V]M<')E<W-I;VX@='EP92`H)PT*"0D)"2`@("`@("`@
M("`@("`@("`N)'1H:7,M/E]C;VUP<F5S<U]T>7!E+B<I)RD[#0H@("`@("`@
M("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G9WHG*0T*("`@("`@("`@("`@("`@("`@0&=Z<'5T<R@D
M=&AI<RT^7V9I;&4L("1P7V)I;F%R>5]D871A+"`D<%]L96XI.PT*("`@("`@
M("`@("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z
M,B<I#0H@("`@("`@("`@("`@("`@("!`8GIW<FET92@D=&AI<RT^7V9I;&4L
M("1P7V)I;F%R>5]D871A+"`D<%]L96XI.PT*("`@("`@("`@("`@("!E;'-E
M(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)VYO;F4G*0T*("`@("`@
M("`@("`@("`@("`@0&9P=71S*"1T:&ES+3Y?9FEL92P@)'!?8FEN87)Y7V1A
M=&$L("1P7VQE;BD[#0H@("`@("`@("`@("`@(&5L<V4-"B`@("`@("`@("`@
M("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@;W(@;6ES<VEN9R!C;VUP
M<F5S<VEO;B!T>7!E("@G#0H)"0D)("`@("`@("`@("`@("`@("XD=&AI<RT^
M7V-O;7!R97-S7W1Y<&4N)RDG*3L-"@T*("`@("`@("`@('T-"B`@("`@('T-
M"B`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@
M("\O('M[>R!?<F5A9$)L;V-K*"D-"B`@("!F=6YC=&EO;B!?<F5A9$)L;V-K
M*"D-"B`@("![#0H@("`@("`D=E]B;&]C:R`](&YU;&P[#0H@("`@("!I9B`H
M:7-?<F5S;W5R8V4H)'1H:7,M/E]F:6QE*2D@>PT*("`@("`@("`@(&EF("@D
M=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@
M)'9?8FQO8VL@/2!`9WIR96%D*"1T:&ES+3Y?9FEL92P@-3$R*3L-"B`@("`@
M("`@("!E;'-E(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V)Z,B<I
M#0H@("`@("`@("`@("`@("1V7V)L;V-K(#T@0&)Z<F5A9"@D=&AI<RT^7V9I
M;&4L(#4Q,BD[#0H@("`@("`@("`@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S
M<U]T>7!E(#T]("=N;VYE)RD-"B`@("`@("`@("`@("`@)'9?8FQO8VL@/2!`
M9G)E860H)'1H:7,M/E]F:6QE+"`U,3(I.PT*("`@("`@("`@(&5L<V4-"B`@
M("`@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G56YK;F]W;B!O<B!M:7-S:6YG
M(&-O;7!R97-S:6]N('1Y<&4@*"<-"@D)"2`@("`@("`@("`@("`@("`N)'1H
M:7,M/E]C;VUP<F5S<U]T>7!E+B<I)RD[#0H@("`@("!]#0H@("`@("!R971U
M<FX@)'9?8FQO8VL[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[
M(%]J=6UP0FQO8VLH*0T*("`@(&9U;F-T:6]N(%]J=6UP0FQO8VLH)'!?;&5N
M/6YU;&PI#0H@("`@>PT*("`@("`@:68@*&ES7W)E<V]U<F-E*"1T:&ES+3Y?
M9FEL92DI('L-"B`@("`@("`@("!I9B`H)'!?;&5N(#T]/2!N=6QL*0T*("`@
M("`@("`@("`@("`D<%]L96X@/2`Q.PT*#0H@("`@("`@("`@:68@*"1T:&ES
M+3Y?8V]M<')E<W-?='EP92`]/2`G9WHG*2![#0H@("`@("`@("`@("`@($!G
M>G-E96LH)'1H:7,M/E]F:6QE+"!`9WIT96QL*"1T:&ES+3Y?9FEL92DK*"1P
M7VQE;BHU,3(I*3L-"B`@("`@("`@("!]#0H@("`@("`@("`@96QS92!I9B`H
M)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]("=B>C(G*2![#0H@("`@("`@("`@
M("`@("\O("TM+2TM(%)E<&QA8V4@;6ES<VEN9R!B>G1E;&PH*2!A;F0@8GIS
M965K*"D-"B`@("`@("`@("`@("`@9F]R("@D:3TP.R`D:3PD<%]L96X[("1I
M*RLI#0H@("`@("`@("`@("`@("`@("`D=&AI<RT^7W)E861";&]C:R@I.PT*
M("`@("`@("`@('T@96QS92!I9B`H)'1H:7,M/E]C;VUP<F5S<U]T>7!E(#T]
M("=N;VYE)RD-"B`@("`@("`@("`@("`@0&9S965K*"1T:&ES+3Y?9FEL92P@
M0&9T96QL*"1T:&ES+3Y?9FEL92DK*"1P7VQE;BHU,3(I*3L-"B`@("`@("`@
M("!E;'-E#0H@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N:VYO=VX@
M;W(@;6ES<VEN9R!C;VUP<F5S<VEO;B!T>7!E("@G#0H)"0D@("`@("`@("`@
M("`@("`@+B1T:&ES+3Y?8V]M<')E<W-?='EP92XG*2<I.PT*#0H@("`@("!]
M#0H@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@7W=R:71E1F]O=&5R*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5&
M;V]T97(H*0T*("`@('L-"B`@("`@(&EF("AI<U]R97-O=7)C92@D=&AI<RT^
M7V9I;&4I*2![#0H@("`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&QA<W0@
M,"!F:6QL960@8FQO8VL@9F]R(&5N9"!O9B!A<F-H:79E#0H@("`@("`@("`@
M)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A-3$R(BP@)R<I.PT*("`@("`@("`@
M("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T82D[#0H@("`@("!]
M#0H@("`@("!R971U<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@
M("`O+R![>WL@7V%D9$QI<W0H*0T*("`@(&9U;F-T:6]N(%]A9&1,:7-T*"1P
M7VQI<W0L("1P7V%D9%]D:7(L("1P7W)E;6]V95]D:7(I#0H@("`@>PT*("`@
M("`@)'9?<F5S=6QT/71R=64[#0H@("`@("`D=E]H96%D97(@/2!A<G)A>2@I
M.PT*#0H@("`@("`O+R`M+2TM+2!296UO=F4@<&]T96YT:6%L('=I;F1O=W,@
M9&ER96-T;W)Y('-E<&%R871O<@T*("`@("`@)'!?861D7V1I<B`]("1T:&ES
M+3Y?=')A;G-L871E5VEN4&%T:"@D<%]A9&1?9&ER*3L-"B`@("`@("1P7W)E
M;6]V95]D:7(@/2`D=&AI<RT^7W1R86YS;&%T95=I;E!A=&@H)'!?<F5M;W9E
M7V1I<BP@9F%L<V4I.PT*#0H@("`@("!I9B`H(21T:&ES+3Y?9FEL92D@>PT*
M("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@9FEL92!D97-C<FEP
M=&]R)RD[#0H@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@?0T*#0H@
M("`@("!I9B`H<VEZ96]F*"1P7VQI<W0I(#T](#`I#0H@("`@("`@("`@<F5T
M=7)N('1R=64[#0H-"B`@("`@(&9O<F5A8V@@*"1P7VQI<W0@87,@)'9?9FEL
M96YA;64I('L-"B`@("`@("`@("!I9B`H(21V7W)E<W5L="D@>PT*("`@("`@
M("`@("`@("!B<F5A:SL-"B`@("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM
M+2T@4VMI<"!T:&4@8W5R<F5N="!T87(@;F%M90T*("`@("`@("!I9B`H)'9?
M9FEL96YA;64@/3T@)'1H:7,M/E]T87)N86UE*0T*("`@("`@("`@("`@8V]N
M=&EN=64[#0H-"B`@("`@("`@:68@*"1V7V9I;&5N86UE(#T]("<G*0T*("`@
M("`@("`@("`@8V]N=&EN=64[#0H-"B`@("`@("`@:68@*"%F:6QE7V5X:7-T
M<R@D=E]F:6QE;F%M92DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?=V%R;FEN
M9R@B1FEL92`G)'9?9FEL96YA;64G(&1O97,@;F]T(&5X:7-T(BD[#0H@("`@
M("`@("`@("!C;VYT:6YU93L-"B`@("`@("`@?0T*#0H@("`@("`@("\O("TM
M+2TM($%D9"!T:&4@9FEL92!O<B!D:7)E8W1O<GD@:&5A9&5R#0H@("`@("`@
M(&EF("@A)'1H:7,M/E]A9&1&:6QE*"1V7V9I;&5N86UE+"`D=E]H96%D97(L
M("1P7V%D9%]D:7(L("1P7W)E;6]V95]D:7(I*0T*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*#0H@("`@("`@(&EF("A`:7-?9&ER*"1V7V9I;&5N86UE
M*2D@>PT*("`@("`@("`@("`@:68@*"$H)'!?:&1I<B`](&]P96YD:7(H)'9?
M9FEL96YA;64I*2D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?=V%R;FEN
M9R@B1&ER96-T;W)Y("<D=E]F:6QE;F%M92<@8V%N(&YO="!B92!R96%D(BD[
M#0H@("`@("`@("`@("`@("`@8V]N=&EN=64[#0H@("`@("`@("`@("!]#0H@
M("`@("`@("`@("!W:&EL92`H9F%L<V4@(3T]("@D<%]H:71E;2`](')E861D
M:7(H)'!?:&1I<BDI*2![#0H@("`@("`@("`@("`@("`@:68@*"@D<%]H:71E
M;2`A/2`G+B<I("8F("@D<%]H:71E;2`A/2`G+BXG*2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H)'9?9FEL96YA;64@(3T@(BXB*0T*("`@("`@("`@
M("`@("`@("`@("`@("`@)'!?=&5M<%]L:7-T6S!=(#T@)'9?9FEL96YA;64N
M)R\G+B1P7VAI=&5M.PT*("`@("`@("`@("`@("`@("`@("!E;'-E#0H@("`@
M("`@("`@("`@("`@("`@("`@("`D<%]T96UP7VQI<W1;,%T@/2`D<%]H:71E
M;3L-"@T*("`@("`@("`@("`@("`@("`@("`D=E]R97-U;'0@/2`D=&AI<RT^
M7V%D9$QI<W0H)'!?=&5M<%]L:7-T+`T*"0D)"0D@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!?861D7V1I<BP-"@D)"0D)"0D)"0D)"21P7W)E;6]V
M95]D:7(I.PT*("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@('T-"@T*
M("`@("`@("`@("`@=6YS970H)'!?=&5M<%]L:7-T*3L-"B`@("`@("`@("`@
M('5N<V5T*"1P7VAD:7(I.PT*("`@("`@("`@("`@=6YS970H)'!?:&ET96TI
M.PT*("`@("`@("!]#0H@("`@("!]#0H-"B`@("`@(')E='5R;B`D=E]R97-U
M;'0[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]A9&1&:6QE
M*"D-"B`@("!F=6YC=&EO;B!?861D1FEL92@D<%]F:6QE;F%M92P@)B1P7VAE
M861E<BP@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I<BD-"B`@("![#0H@("`@
M("!I9B`H(21T:&ES+3Y?9FEL92D@>PT*("`@("`@("`@("1T:&ES+3Y?97)R
M;W(H)TEN=F%L:60@9FEL92!D97-C<FEP=&]R)RD[#0H@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@?0T*#0H@("`@("!I9B`H)'!?9FEL96YA;64@
M/3T@)R<I('L-"B`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=);G9A;&ED(&9I
M;&4@;F%M92<I.PT*("`@("`@("`@(')E='5R;B!F86QS93L-"B`@("`@('T-
M"@T*("`@("`@+R\@+2TM+2T@0V%L8W5L871E('1H92!S=&]R960@9FEL96YA
M;64-"B`@("`@("1P7V9I;&5N86UE(#T@)'1H:7,M/E]T<F%N<VQA=&57:6Y0
M871H*"1P7V9I;&5N86UE+"!F86QS92D[.PT*("`@("`@)'9?<W1O<F5D7V9I
M;&5N86UE(#T@)'!?9FEL96YA;64[#0H@("`@("!I9B`H<W1R8VUP*"1P7V9I
M;&5N86UE+"`D<%]R96UO=F5?9&ER*2`]/2`P*2![#0H@("`@("`@("`@<F5T
M=7)N('1R=64[#0H@("`@("!]#0H@("`@("!I9B`H)'!?<F5M;W9E7V1I<B`A
M/2`G)RD@>PT*("`@("`@("`@(&EF("AS=6)S='(H)'!?<F5M;W9E7V1I<BP@
M+3$I("$]("<O)RD-"B`@("`@("`@("`@("`@)'!?<F5M;W9E7V1I<B`N/2`G
M+R<[#0H-"B`@("`@("`@("!I9B`H<W5B<W1R*"1P7V9I;&5N86UE+"`P+"!S
M=')L96XH)'!?<F5M;W9E7V1I<BDI(#T]("1P7W)E;6]V95]D:7(I#0H@("`@
M("`@("`@("`@("1V7W-T;W)E9%]F:6QE;F%M92`]('-U8G-T<B@D<%]F:6QE
M;F%M92P@<W1R;&5N*"1P7W)E;6]V95]D:7(I*3L-"B`@("`@('T-"B`@("`@
M("1V7W-T;W)E9%]F:6QE;F%M92`]("1T:&ES+3Y?=')A;G-L871E5VEN4&%T
M:"@D=E]S=&]R961?9FEL96YA;64I.PT*("`@("`@:68@*"1P7V%D9%]D:7(@
M(3T@)R<I('L-"B`@("`@("`@("!I9B`H<W5B<W1R*"1P7V%D9%]D:7(L("TQ
M*2`]/2`G+R<I#0H@("`@("`@("`@("`@("1V7W-T;W)E9%]F:6QE;F%M92`]
M("1P7V%D9%]D:7(N)'9?<W1O<F5D7V9I;&5N86UE.PT*("`@("`@("`@(&5L
M<V4-"B`@("`@("`@("`@("`@)'9?<W1O<F5D7V9I;&5N86UE(#T@)'!?861D
M7V1I<BXG+R<N)'9?<W1O<F5D7V9I;&5N86UE.PT*("`@("`@?0T*#0H@("`@
M("`D=E]S=&]R961?9FEL96YA;64@/2`D=&AI<RT^7W!A=&A2961U8W1I;VXH
M)'9?<W1O<F5D7V9I;&5N86UE*3L-"@T*("`@("`@:68@*"1T:&ES+3Y?:7-!
M<F-H:79E*"1P7V9I;&5N86UE*2D@>PT*("`@("`@("`@(&EF("@H)'9?9FEL
M92`]($!F;W!E;B@D<%]F:6QE;F%M92P@(G)B(BDI(#T](#`I('L-"B`@("`@
M("`@("`@("`@)'1H:7,M/E]W87)N:6YG*")5;F%B;&4@=&\@;W!E;B!F:6QE
M("<B+B1P7V9I;&5N86UE#0H)"0D@("`@("`@("`@("`@("`@("`N(B<@:6X@
M8FEN87)Y(')E860@;6]D92(I.PT*("`@("`@("`@("`@("!R971U<FX@=')U
M93L-"B`@("`@("`@("!]#0H-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?=W)I
M=&5(96%D97(H)'!?9FEL96YA;64L("1V7W-T;W)E9%]F:6QE;F%M92DI#0H@
M("`@("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("`@('=H:6QE
M("@H)'9?8G5F9F5R(#T@9G)E860H)'9?9FEL92P@-3$R*2D@(3T@)R<I('L-
M"B`@("`@("`@("`@("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A-3$R(BP@
M(B1V7V)U9F9E<B(I.PT*("`@("`@("`@("`@("`D=&AI<RT^7W=R:71E0FQO
M8VLH)'9?8FEN87)Y7V1A=&$I.PT*("`@("`@("`@('T-"@T*("`@("`@("`@
M(&9C;&]S92@D=E]F:6QE*3L-"@T*("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`O+R`M+2TM+2!/;FQY(&AE861E<B!F;W(@9&ER#0H@("`@("`@("`@:68@
M*"$D=&AI<RT^7W=R:71E2&5A9&5R*"1P7V9I;&5N86UE+"`D=E]S=&]R961?
M9FEL96YA;64I*0T*("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@
M("!]#0H-"B`@("`@(')E='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-
M"@T*("`@("\O('M[>R!?861D4W1R:6YG*"D-"B`@("!F=6YC=&EO;B!?861D
M4W1R:6YG*"1P7V9I;&5N86UE+"`D<%]S=')I;F<I#0H@("`@>PT*("`@("`@
M:68@*"$D=&AI<RT^7V9I;&4I('L-"B`@("`@("`@("`D=&AI<RT^7V5R<F]R
M*"=);G9A;&ED(&9I;&4@9&5S8W)I<'1O<B<I.PT*("`@("`@("`@(')E='5R
M;B!F86QS93L-"B`@("`@('T-"@T*("`@("`@:68@*"1P7V9I;&5N86UE(#T]
M("<G*2![#0H@("`@("`@("`@)'1H:7,M/E]E<G)O<B@G26YV86QI9"!F:6QE
M(&YA;64G*3L-"B`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("!]#0H-
M"B`@("`@("\O("TM+2TM($-A;&-U;&%T92!T:&4@<W1O<F5D(&9I;&5N86UE
M#0H@("`@("`D<%]F:6QE;F%M92`]("1T:&ES+3Y?=')A;G-L871E5VEN4&%T
M:"@D<%]F:6QE;F%M92P@9F%L<V4I.SL-"@T*("`@("`@:68@*"$D=&AI<RT^
M7W=R:71E2&5A9&5R0FQO8VLH)'!?9FEL96YA;64L('-T<FQE;B@D<%]S=')I
M;F<I+`T*"2`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@,"P@,"P@
M(B(L(#`L(#`I*0T*("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@
M)&D],#L-"B`@("`@('=H:6QE("@H)'9?8G5F9F5R(#T@<W5B<W1R*"1P7W-T
M<FEN9RP@*"@D:2LK*2HU,3(I+"`U,3(I*2`A/2`G)RD@>PT*("`@("`@("`@
M("1V7V)I;F%R>5]D871A(#T@<&%C:R@B834Q,B(L("1V7V)U9F9E<BD[#0H@
M("`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A*3L-
M"B`@("`@('T-"@T*("`@("`@<F5T=7)N('1R=64[#0H@("`@?0T*("`@("\O
M('U]?0T*#0H@("`@+R\@>WM[(%]W<FET94AE861E<B@I#0H@("`@9G5N8W1I
M;VX@7W=R:71E2&5A9&5R*"1P7V9I;&5N86UE+"`D<%]S=&]R961?9FEL96YA
M;64I#0H@("`@>PT*("`@("`@("!I9B`H)'!?<W1O<F5D7V9I;&5N86UE(#T]
M("<G*0T*("`@("`@("`@("`@)'!?<W1O<F5D7V9I;&5N86UE(#T@)'!?9FEL
M96YA;64[#0H@("`@("`@("1V7W)E9'5C95]F:6QE;F%M92`]("1T:&ES+3Y?
M<&%T:%)E9'5C=&EO;B@D<%]S=&]R961?9FEL96YA;64I.PT*#0H@("`@("`@
M(&EF("AS=')L96XH)'9?<F5D=6-E7V9I;&5N86UE*2`^(#DY*2![#0H@("`@
M("`@("`@:68@*"$D=&AI<RT^7W=R:71E3&]N9TAE861E<B@D=E]R961U8V5?
M9FEL96YA;64I*0T*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@
M("!]#0H-"B`@("`@("`@)'9?:6YF;R`]('-T870H)'!?9FEL96YA;64I.PT*
M("`@("`@("`D=E]U:60@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V7VEN
M9F];-%TI*3L-"B`@("`@("`@)'9?9VED(#T@<W!R:6YT9B@B)39S("(L($1E
M8T]C="@D=E]I;F9O6S5=*2D[#0H@("`@("`@("1V7W!E<FUS(#T@<W!R:6YT
M9B@B)39S("(L($1E8T]C="AF:6QE<&5R;7,H)'!?9FEL96YA;64I*2D[#0H-
M"B`@("`@("`@)'9?;71I;64@/2!S<')I;G1F*"(E,3%S(BP@1&5C3V-T*&9I
M;&5M=&EM92@D<%]F:6QE;F%M92DI*3L-"@T*("`@("`@("!I9B`H0&ES7V1I
M<B@D<%]F:6QE;F%M92DI('L-"B`@("`@("`@("`D=E]T>7!E9FQA9R`]("(U
M(CL-"B`@("`@("`@("`D=E]S:7IE(#T@<W!R:6YT9B@B)3$Q<R`B+"!$96-/
M8W0H,"DI.PT*("`@("`@("!](&5L<V4@>PT*("`@("`@("`@("1V7W1Y<&5F
M;&%G(#T@)R<[#0H@("`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@
M("`@("`D=E]S:7IE(#T@<W!R:6YT9B@B)3$Q<R`B+"!$96-/8W0H9FEL97-I
M>F4H)'!?9FEL96YA;64I*2D[#0H@("`@("`@('T-"@T*("`@("`@("`D=E]L
M:6YK;F%M92`]("<G.PT*#0H@("`@("`@("1V7VUA9VEC(#T@)R<[#0H-"B`@
M("`@("`@)'9?=F5R<VEO;B`]("<G.PT*#0H@("`@("`@("1V7W5N86UE(#T@
M)R<[#0H-"B`@("`@("`@)'9?9VYA;64@/2`G)SL-"@T*("`@("`@("`D=E]D
M979M86IO<B`]("<G.PT*#0H@("`@("`@("1V7V1E=FUI;F]R(#T@)R<[#0H-
M"B`@("`@("`@)'9?<')E9FEX(#T@)R<[#0H-"B`@("`@("`@)'9?8FEN87)Y
M7V1A=&%?9FER<W0@/2!P86-K*")A,3`P83AA.&$X83$R03$R(BP-"@D)("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1V7W)E9'5C95]F:6QE;F%M92P@
M)'9?<&5R;7,L("1V7W5I9"P-"@D)"0D)"0D)"21V7V=I9"P@)'9?<VEZ92P@
M)'9?;71I;64I.PT*("`@("`@("`D=E]B:6YA<GE?9&%T85]L87-T(#T@<&%C
M:R@B83%A,3`P839A,F$S,F$S,F$X83AA,34U83$R(BP-"@D)("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'9?='EP969L86<L("1V7VQI;FMN86UE+"`D
M=E]M86=I8RP-"@D)"0D)"0D)("`@)'9?=F5R<VEO;BP@)'9?=6YA;64L("1V
M7V=N86UE+`T*"0D)"0D)"0D@("`D=E]D979M86IO<BP@)'9?9&5V;6EN;W(L
M("1V7W!R969I>"P@)R<I.PT*#0H@("`@("`@("\O("TM+2TM($-A;&-U;&%T
M92!T:&4@8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS=6T@/2`P.PT*("`@
M("`@("`O+R`N+BXN+B!&:7)S="!P87)T(&]F('1H92!H96%D97(-"B`@("`@
M("`@9F]R("@D:3TP.R`D:3PQ-#@[("1I*RLI#0H@("`@("`@("`@("`D=E]C
M:&5C:W-U;2`K/2!O<F0H<W5B<W1R*"1V7V)I;F%R>5]D871A7V9I<G-T+"1I
M+#$I*3L-"B`@("`@("`@+R\@+BXN+BX@26=N;W)E('1H92!C:&5C:W-U;2!V
M86QU92!A;F0@<F5P;&%C92!I="!B>2`G("<@*'-P86-E*0T*("`@("`@("!F
M;W(@*"1I/3$T.#L@)&D\,34V.R`D:2LK*0T*("`@("`@("`@("`@)'9?8VAE
M8VMS=6T@*ST@;W)D*"<@)RD[#0H@("`@("`@("\O("XN+BXN($QA<W0@<&%R
M="!O9B!T:&4@:&5A9&5R#0H@("`@("`@(&9O<B`H)&D],34V+"`D:CTP.R`D
M:3PU,3([("1I*RLL("1J*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U;2`K
M/2!O<F0H<W5B<W1R*"1V7V)I;F%R>5]D871A7VQA<W0L)&HL,2DI.PT*#0H@
M("`@("`@("\O("TM+2TM(%=R:71E('1H92!F:7)S="`Q-#@@8GET97,@;V8@
M=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*("`@("`@("`D=&AI<RT^7W=R
M:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?9FER<W0L(#$T."D[#0H-"B`@("`@
M("`@+R\@+2TM+2T@5W)I=&4@=&AE(&-A;&-U;&%T960@8VAE8VMS=6T-"B`@
M("`@("`@)'9?8VAE8VMS=6T@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1V
M7V-H96-K<W5M*2D[#0H@("`@("`@("1V7V)I;F%R>5]D871A(#T@<&%C:R@B
M83@B+"`D=E]C:&5C:W-U;2D[#0H@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C
M:R@D=E]B:6YA<GE?9&%T82P@."D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I
M=&4@=&AE(&QA<W0@,S4V(&)Y=&5S(&]F('1H92!H96%D97(@:6X@=&AE(&%R
M8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D
M871A7VQA<W0L(#,U-BD[#0H-"B`@("`@("`@<F5T=7)N('1R=64[#0H@("`@
M?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]W<FET94AE861E<D)L;V-K
M*"D-"B`@("!F=6YC=&EO;B!?=W)I=&5(96%D97)";&]C:R@D<%]F:6QE;F%M
M92P@)'!?<VEZ92P@)'!?;71I;64],"P@)'!?<&5R;7,],"P-"@D@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D<%]T>7!E/2<G+"`D<%]U:60],"P@)'!?
M9VED/3`I#0H@("`@>PT*("`@("`@("`D<%]F:6QE;F%M92`]("1T:&ES+3Y?
M<&%T:%)E9'5C=&EO;B@D<%]F:6QE;F%M92D[#0H-"B`@("`@("`@:68@*'-T
M<FQE;B@D<%]F:6QE;F%M92D@/B`Y.2D@>PT*("`@("`@("`@(&EF("@A)'1H
M:7,M/E]W<FET94QO;F=(96%D97(H)'!?9FEL96YA;64I*0T*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@:68@*"1P
M7W1Y<&4@/3T@(C4B*2![#0H@("`@("`@("`@)'9?<VEZ92`]('-P<FEN=&8H
M(B4Q,7,@(BP@1&5C3V-T*#`I*3L-"B`@("`@("`@?2!E;'-E('L-"B`@("`@
M("`@("`D=E]S:7IE(#T@<W!R:6YT9B@B)3$Q<R`B+"!$96-/8W0H)'!?<VEZ
M92DI.PT*("`@("`@("!]#0H-"B`@("`@("`@)'9?=6ED(#T@<W!R:6YT9B@B
M)39S("(L($1E8T]C="@D<%]U:60I*3L-"B`@("`@("`@)'9?9VED(#T@<W!R
M:6YT9B@B)39S("(L($1E8T]C="@D<%]G:60I*3L-"B`@("`@("`@)'9?<&5R
M;7,@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T*"1P7W!E<FUS*2D[#0H-"B`@
M("`@("`@)'9?;71I;64@/2!S<')I;G1F*"(E,3%S(BP@1&5C3V-T*"1P7VUT
M:6UE*2D[#0H-"B`@("`@("`@)'9?;&EN:VYA;64@/2`G)SL-"@T*("`@("`@
M("`D=E]M86=I8R`]("<G.PT*#0H@("`@("`@("1V7W9E<G-I;VX@/2`G)SL-
M"@T*("`@("`@("`D=E]U;F%M92`]("<G.PT*#0H@("`@("`@("1V7V=N86UE
M(#T@)R<[#0H-"B`@("`@("`@)'9?9&5V;6%J;W(@/2`G)SL-"@T*("`@("`@
M("`D=E]D979M:6YO<B`]("<G.PT*#0H@("`@("`@("1V7W!R969I>"`]("<G
M.PT*#0H@("`@("`@("1V7V)I;F%R>5]D871A7V9I<G-T(#T@<&%C:R@B83$P
M,&$X83AA.&$Q,D$Q,B(L#0H)"2`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<%]F:6QE;F%M92P@)'9?<&5R;7,L("1V7W5I9"P@)'9?9VED+`T*"0D)
M"0D)"0D))'9?<VEZ92P@)'9?;71I;64I.PT*("`@("`@("`D=E]B:6YA<GE?
M9&%T85]L87-T(#T@<&%C:R@B83%A,3`P839A,F$S,F$S,F$X83AA,34U83$R
M(BP-"@D)("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!?='EP92P@)'9?
M;&EN:VYA;64L("1V7VUA9VEC+`T*"0D)"0D)"0D@("`D=E]V97)S:6]N+"`D
M=E]U;F%M92P@)'9?9VYA;64L#0H)"0D)"0D)"2`@("1V7V1E=FUA:F]R+"`D
M=E]D979M:6YO<BP@)'9?<')E9FEX+"`G)RD[#0H-"B`@("`@("`@+R\@+2TM
M+2T@0V%L8W5L871E('1H92!C:&5C:W-U;0T*("`@("`@("`D=E]C:&5C:W-U
M;2`](#`[#0H@("`@("`@("\O("XN+BXN($9I<G-T('!A<G0@;V8@=&AE(&AE
M861E<@T*("`@("`@("!F;W(@*"1I/3`[("1I/#$T.#L@)&DK*RD-"B`@("`@
M("`@("`@("1V7V-H96-K<W5M("L](&]R9"AS=6)S='(H)'9?8FEN87)Y7V1A
M=&%?9FER<W0L)&DL,2DI.PT*("`@("`@("`O+R`N+BXN+B!)9VYO<F4@=&AE
M(&-H96-K<W5M('9A;'5E(&%N9"!R97!L86-E(&ET(&)Y("<@)R`H<W!A8V4I
M#0H@("`@("`@(&9O<B`H)&D],30X.R`D:3PQ-38[("1I*RLI#0H@("`@("`@
M("`@("`D=E]C:&5C:W-U;2`K/2!O<F0H)R`G*3L-"B`@("`@("`@+R\@+BXN
M+BX@3&%S="!P87)T(&]F('1H92!H96%D97(-"B`@("`@("`@9F]R("@D:3TQ
M-38L("1J/3`[("1I/#4Q,CL@)&DK*RP@)&HK*RD-"B`@("`@("`@("`@("1V
M7V-H96-K<W5M("L](&]R9"AS=6)S='(H)'9?8FEN87)Y7V1A=&%?;&%S="PD
M:BPQ*2D[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&9I<G-T(#$T
M."!B>71E<R!O9B!T:&4@:&5A9&5R(&EN('1H92!A<F-H:79E#0H@("`@("`@
M("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA<GE?9&%T85]F:7)S="P@,30X
M*3L-"@T*("`@("`@("`O+R`M+2TM+2!7<FET92!T:&4@8V%L8W5L871E9"!C
M:&5C:W-U;0T*("`@("`@("`D=E]C:&5C:W-U;2`]('-P<FEN=&8H(B4V<R`B
M+"!$96-/8W0H)'9?8VAE8VMS=6TI*3L-"B`@("`@("`@)'9?8FEN87)Y7V1A
M=&$@/2!P86-K*")A."(L("1V7V-H96-K<W5M*3L-"B`@("`@("`@)'1H:7,M
M/E]W<FET94)L;V-K*"1V7V)I;F%R>5]D871A+"`X*3L-"@T*("`@("`@("`O
M+R`M+2TM+2!7<FET92!T:&4@;&%S="`S-38@8GET97,@;V8@=&AE(&AE861E
M<B!I;B!T:&4@87)C:&EV90T*("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH
M)'9?8FEN87)Y7V1A=&%?;&%S="P@,S4V*3L-"@T*("`@("`@("!R971U<FX@
M=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7W=R:71E
M3&]N9TAE861E<B@I#0H@("`@9G5N8W1I;VX@7W=R:71E3&]N9TAE861E<B@D
M<%]F:6QE;F%M92D-"B`@("![#0H@("`@("`@("1V7W-I>F4@/2!S<')I;G1F
M*"(E,3%S("(L($1E8T]C="AS=')L96XH)'!?9FEL96YA;64I*2D[#0H-"B`@
M("`@("`@)'9?='EP969L86<@/2`G3"<[#0H-"B`@("`@("`@)'9?;&EN:VYA
M;64@/2`G)SL-"@T*("`@("`@("`D=E]M86=I8R`]("<G.PT*#0H@("`@("`@
M("1V7W9E<G-I;VX@/2`G)SL-"@T*("`@("`@("`D=E]U;F%M92`]("<G.PT*
M#0H@("`@("`@("1V7V=N86UE(#T@)R<[#0H-"B`@("`@("`@)'9?9&5V;6%J
M;W(@/2`G)SL-"@T*("`@("`@("`D=E]D979M:6YO<B`]("<G.PT*#0H@("`@
M("`@("1V7W!R969I>"`]("<G.PT*#0H@("`@("`@("1V7V)I;F%R>5]D871A
M7V9I<G-T(#T@<&%C:R@B83$P,&$X83AA.&$Q,D$Q,B(L#0H)"2`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`G+B\N+T!,;VYG3&EN:R<L(#`L(#`L(#`L
M("1V7W-I>F4L(#`I.PT*("`@("`@("`D=E]B:6YA<GE?9&%T85]L87-T(#T@
M<&%C:R@B83%A,3`P839A,F$S,F$S,F$X83AA,34U83$R(BP-"@D)("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'9?='EP969L86<L("1V7VQI;FMN86UE
M+"`D=E]M86=I8RP-"@D)"0D)"0D)("`@)'9?=F5R<VEO;BP@)'9?=6YA;64L
M("1V7V=N86UE+`T*"0D)"0D)"0D@("`D=E]D979M86IO<BP@)'9?9&5V;6EN
M;W(L("1V7W!R969I>"P@)R<I.PT*#0H@("`@("`@("\O("TM+2TM($-A;&-U
M;&%T92!T:&4@8VAE8VMS=6T-"B`@("`@("`@)'9?8VAE8VMS=6T@/2`P.PT*
M("`@("`@("`O+R`N+BXN+B!&:7)S="!P87)T(&]F('1H92!H96%D97(-"B`@
M("`@("`@9F]R("@D:3TP.R`D:3PQ-#@[("1I*RLI#0H@("`@("`@("`@("`D
M=E]C:&5C:W-U;2`K/2!O<F0H<W5B<W1R*"1V7V)I;F%R>5]D871A7V9I<G-T
M+"1I+#$I*3L-"B`@("`@("`@+R\@+BXN+BX@26=N;W)E('1H92!C:&5C:W-U
M;2!V86QU92!A;F0@<F5P;&%C92!I="!B>2`G("<@*'-P86-E*0T*("`@("`@
M("!F;W(@*"1I/3$T.#L@)&D\,34V.R`D:2LK*0T*("`@("`@("`@("`@)'9?
M8VAE8VMS=6T@*ST@;W)D*"<@)RD[#0H@("`@("`@("\O("XN+BXN($QA<W0@
M<&%R="!O9B!T:&4@:&5A9&5R#0H@("`@("`@(&9O<B`H)&D],34V+"`D:CTP
M.R`D:3PU,3([("1I*RLL("1J*RLI#0H@("`@("`@("`@("`D=E]C:&5C:W-U
M;2`K/2!O<F0H<W5B<W1R*"1V7V)I;F%R>5]D871A7VQA<W0L)&HL,2DI.PT*
M#0H@("`@("`@("\O("TM+2TM(%=R:71E('1H92!F:7)S="`Q-#@@8GET97,@
M;V8@=&AE(&AE861E<B!I;B!T:&4@87)C:&EV90T*("`@("`@("`D=&AI<RT^
M7W=R:71E0FQO8VLH)'9?8FEN87)Y7V1A=&%?9FER<W0L(#$T."D[#0H-"B`@
M("`@("`@+R\@+2TM+2T@5W)I=&4@=&AE(&-A;&-U;&%T960@8VAE8VMS=6T-
M"B`@("`@("`@)'9?8VAE8VMS=6T@/2!S<')I;G1F*"(E-G,@(BP@1&5C3V-T
M*"1V7V-H96-K<W5M*2D[#0H@("`@("`@("1V7V)I;F%R>5]D871A(#T@<&%C
M:R@B83@B+"`D=E]C:&5C:W-U;2D[#0H@("`@("`@("1T:&ES+3Y?=W)I=&5"
M;&]C:R@D=E]B:6YA<GE?9&%T82P@."D[#0H-"B`@("`@("`@+R\@+2TM+2T@
M5W)I=&4@=&AE(&QA<W0@,S4V(&)Y=&5S(&]F('1H92!H96%D97(@:6X@=&AE
M(&%R8VAI=F4-"B`@("`@("`@)'1H:7,M/E]W<FET94)L;V-K*"1V7V)I;F%R
M>5]D871A7VQA<W0L(#,U-BD[#0H-"B`@("`@("`@+R\@+2TM+2T@5W)I=&4@
M=&AE(&9I;&5N86UE(&%S(&-O;G1E;G0@;V8@=&AE(&)L;V-K#0H@("`@("`@
M("1I/3`[#0H@("`@("`@('=H:6QE("@H)'9?8G5F9F5R(#T@<W5B<W1R*"1P
M7V9I;&5N86UE+"`H*"1I*RLI*C4Q,BDL(#4Q,BDI("$]("<G*2![#0H@("`@
M("`@("`@("`D=E]B:6YA<GE?9&%T82`]('!A8VLH(F$U,3(B+"`B)'9?8G5F
M9F5R(BD[#0H@("`@("`@("`@("`D=&AI<RT^7W=R:71E0FQO8VLH)'9?8FEN
M87)Y7V1A=&$I.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]R96%D2&5A9&5R
M*"D-"B`@("!F=6YC=&EO;B!?<F5A9$AE861E<B@D=E]B:6YA<GE?9&%T82P@
M)B1V7VAE861E<BD-"B`@("![#0H@("`@("`@(&EF("AS=')L96XH)'9?8FEN
M87)Y7V1A=&$I/3TP*2![#0H@("`@("`@("`@("`D=E]H96%D97);)V9I;&5N
M86UE)UT@/2`G)SL-"B`@("`@("`@("`@(')E='5R;B!T<G5E.PT*("`@("`@
M("!]#0H-"B`@("`@("`@:68@*'-T<FQE;B@D=E]B:6YA<GE?9&%T82D@(3T@
M-3$R*2![#0H@("`@("`@("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@/2`G
M)SL-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)TEN=F%L:60@8FQO8VL@
M<VEZ92`Z("<N<W1R;&5N*"1V7V)I;F%R>5]D871A*2D[#0H@("`@("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM
M+2!#86QC=6QA=&4@=&AE(&-H96-K<W5M#0H@("`@("`@("1V7V-H96-K<W5M
M(#T@,#L-"B`@("`@("`@+R\@+BXN+BX@1FER<W0@<&%R="!O9B!T:&4@:&5A
M9&5R#0H@("`@("`@(&9O<B`H)&D],#L@)&D\,30X.R`D:2LK*0T*("`@("`@
M("`@("`@)'9?8VAE8VMS=6TK/6]R9"AS=6)S='(H)'9?8FEN87)Y7V1A=&$L
M)&DL,2DI.PT*("`@("`@("`O+R`N+BXN+B!)9VYO<F4@=&AE(&-H96-K<W5M
M('9A;'5E(&%N9"!R97!L86-E(&ET(&)Y("<@)R`H<W!A8V4I#0H@("`@("`@
M(&9O<B`H)&D],30X.R`D:3PQ-38[("1I*RLI#0H@("`@("`@("`@("`D=E]C
M:&5C:W-U;2`K/2!O<F0H)R`G*3L-"B`@("`@("`@+R\@+BXN+BX@3&%S="!P
M87)T(&]F('1H92!H96%D97(-"B`@("`@("`@9F]R("@D:3TQ-38[("1I/#4Q
M,CL@)&DK*RD-"B`@("`@("`@("`@)'9?8VAE8VMS=6TK/6]R9"AS=6)S='(H
M)'9?8FEN87)Y7V1A=&$L)&DL,2DI.PT*#0H@("`@("`@("1V7V1A=&$@/2!U
M;G!A8VLH(F$Q,#!F:6QE;F%M92]A.&UO9&4O83AU:60O83AG:60O83$R<VEZ
M92]A,3)M=&EM92\B#0H)"2`@("`@("`@("`@("`@("`@+B)A.&-H96-K<W5M
M+V$Q='EP969L86<O83$P,&QI;FLO839M86=I8R]A,G9E<G-I;VXO(@T*"0D)
M"0D)("XB83,R=6YA;64O83,R9VYA;64O83AD979M86IO<B]A.&1E=FUI;F]R
M(BP-"@D)"0D)"2`D=E]B:6YA<GE?9&%T82D[#0H-"B`@("`@("`@+R\@+2TM
M+2T@17AT<F%C="!T:&4@8VAE8VMS=6T-"B`@("`@("`@)'9?:&5A9&5R6R=C
M:&5C:W-U;2==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG8VAE8VMS=6TG72DI
M.PT*("`@("`@("!I9B`H)'9?:&5A9&5R6R=C:&5C:W-U;2==("$]("1V7V-H
M96-K<W5M*2![#0H@("`@("`@("`@("`D=E]H96%D97);)V9I;&5N86UE)UT@
M/2`G)SL-"@T*("`@("`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@;&%S="!B
M;&]C:R`H96UP='D@8FQO8VLI#0H@("`@("`@("`@("!I9B`H*"1V7V-H96-K
M<W5M(#T](#(U-BD@)B8@*"1V7VAE861E<ELG8VAE8VMS=6TG72`]/2`P*2D-
M"B`@("`@("`@("`@("`@("!R971U<FX@=')U93L-"@T*("`@("`@("`@("`@
M)'1H:7,M/E]E<G)O<B@G26YV86QI9"!C:&5C:W-U;2!F;W(@9FEL92`B)RXD
M=E]D871A6R=F:6QE;F%M92==#0H)"0D@("`@("`@("`@("`@("XG(B`Z("<N
M)'9?8VAE8VMS=6TN)R!C86QC=6QA=&5D+"`G#0H)"0D)"0D@("XD=E]H96%D
M97);)V-H96-K<W5M)UTN)R!E>'!E8W1E9"<I.PT*("`@("`@("`@("`@<F5T
M=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@+R\@+2TM+2T@17AT
M<F%C="!T:&4@<')O<&5R=&EE<PT*("`@("`@("`D=E]H96%D97);)V9I;&5N
M86UE)UT@/2!T<FEM*"1V7V1A=&%;)V9I;&5N86UE)UTI.PT*("`@("`@("`D
M=E]H96%D97);)VUO9&4G72`]($]C=$1E8RAT<FEM*"1V7V1A=&%;)VUO9&4G
M72DI.PT*("`@("`@("`D=E]H96%D97);)W5I9"==(#T@3V-T1&5C*'1R:6TH
M)'9?9&%T85LG=6ED)UTI*3L-"B`@("`@("`@)'9?:&5A9&5R6R=G:60G72`]
M($]C=$1E8RAT<FEM*"1V7V1A=&%;)V=I9"==*2D[#0H@("`@("`@("1V7VAE
M861E<ELG<VEZ92==(#T@3V-T1&5C*'1R:6TH)'9?9&%T85LG<VEZ92==*2D[
M#0H@("`@("`@("1V7VAE861E<ELG;71I;64G72`]($]C=$1E8RAT<FEM*"1V
M7V1A=&%;)VUT:6UE)UTI*3L-"B`@("`@("`@:68@*"@D=E]H96%D97);)W1Y
M<&5F;&%G)UT@/2`D=E]D871A6R=T>7!E9FQA9R==*2`]/2`B-2(I('L-"B`@
M("`@("`@("`D=E]H96%D97);)W-I>F4G72`](#`[#0H@("`@("`@('T-"B`@
M("`@("`@+RH@+2TM+2T@06QL('1H97-E(&9I96QD<R!A<F4@<F5M;W9E9"!F
M;W)M('1H92!H96%D97(@8F5C875S90T*"0ET:&5Y(&1O(&YO="!C87)R>2!I
M;G1E<F5S=&EN9R!I;F9O#0H@("`@("`@("1V7VAE861E<EML:6YK72`]('1R
M:6TH)'9?9&%T85ML:6YK72D[#0H@("`@("`@("1V7VAE861E<EMM86=I8UT@
M/2!T<FEM*"1V7V1A=&%;;6%G:6-=*3L-"B`@("`@("`@)'9?:&5A9&5R6W9E
M<G-I;VY=(#T@=')I;2@D=E]D871A6W9E<G-I;VY=*3L-"B`@("`@("`@)'9?
M:&5A9&5R6W5N86UE72`]('1R:6TH)'9?9&%T85MU;F%M95TI.PT*("`@("`@
M("`D=E]H96%D97);9VYA;65=(#T@=')I;2@D=E]D871A6V=N86UE72D[#0H@
M("`@("`@("1V7VAE861E<EMD979M86IO<ET@/2!T<FEM*"1V7V1A=&%;9&5V
M;6%J;W)=*3L-"B`@("`@("`@)'9?:&5A9&5R6V1E=FUI;F]R72`]('1R:6TH
M)'9?9&%T85MD979M:6YO<ETI.PT*("`@("`@("`J+PT*#0H@("`@("`@(')E
M='5R;B!T<G5E.PT*("`@('T-"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?
M<F5A9$QO;F=(96%D97(H*0T*("`@(&9U;F-T:6]N(%]R96%D3&]N9TAE861E
M<B@F)'9?:&5A9&5R*0T*("`@('L-"B`@("`@("1V7V9I;&5N86UE(#T@)R<[
M#0H@("`@("`D;B`](&9L;V]R*"1V7VAE861E<ELG<VEZ92==+S4Q,BD[#0H@
M("`@("!F;W(@*"1I/3`[("1I/"1N.R`D:2LK*2![#0H@("`@("`@("1V7V-O
M;G1E;G0@/2`D=&AI<RT^7W)E861";&]C:R@I.PT*("`@("`@("`D=E]F:6QE
M;F%M92`N/2`D=E]C;VYT96YT.PT*("`@("`@?0T*("`@("`@:68@*"@D=E]H
M96%D97);)W-I>F4G72`E(#4Q,BD@(3T@,"D@>PT*("`@("`@("`D=E]C;VYT
M96YT(#T@)'1H:7,M/E]R96%D0FQO8VLH*3L-"B`@("`@("`@)'9?9FEL96YA
M;64@+CT@)'9?8V]N=&5N=#L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@
M4F5A9"!T:&4@;F5X="!H96%D97(-"B`@("`@("1V7V)I;F%R>5]D871A(#T@
M)'1H:7,M/E]R96%D0FQO8VLH*3L-"@T*("`@("`@:68@*"$D=&AI<RT^7W)E
M861(96%D97(H)'9?8FEN87)Y7V1A=&$L("1V7VAE861E<BDI#0H@("`@("`@
M(')E='5R;B!F86QS93L-"@T*("`@("`@)'9?:&5A9&5R6R=F:6QE;F%M92==
M(#T@)'9?9FEL96YA;64[#0H-"B`@("`@(')E='5R;B!T<G5E.PT*("`@('T-
M"B`@("`O+R!]?7T-"@T*("`@("\O('M[>R!?97AT<F%C=$EN4W1R:6YG*"D-
M"B`@("`O*BH-"B`@("`J(%1H:7,@;65T:&]D(&5X=')A8W0@9G)O;2!T:&4@
M87)C:&EV92!O;F4@9FEL92!I9&5N=&EF:65D(&)Y("1P7V9I;&5N86UE+@T*
M("`@("H@5&AE(')E='5R;B!V86QU92!I<R!A('-T<FEN9R!W:71H('1H92!F
M:6QE(&-O;G1E;G0L(&]R($Y53$P@;VX@97)R;W(N#0H@("`@*B!`<&%R86T@
M<W1R:6YG("1P7V9I;&5N86UE("`@("!4:&4@<&%T:"!O9B!T:&4@9FEL92!T
M;R!E>'1R86-T(&EN(&$@<W1R:6YG+@T*("`@("H@0')E='5R;B`@("`@("`@
M("`@("`@("`@("`@("`@82!S=')I;F<@=VET:"!T:&4@9FEL92!C;VYT96YT
M(&]R($Y53$PN#0H@("`@*B!`86-C97-S('!R:79A=&4-"B`@("`J+PT*("`@
M(&9U;F-T:6]N(%]E>'1R86-T26Y3=')I;F<H)'!?9FEL96YA;64I#0H@("`@
M>PT*("`@("`@("`D=E]R97-U;'1?<W1R(#T@(B([#0H-"B`@("`@("`@5VAI
M;&4@*'-T<FQE;B@D=E]B:6YA<GE?9&%T82`]("1T:&ES+3Y?<F5A9$)L;V-K
M*"DI("$](#`I#0H@("`@("`@('L-"B`@("`@("`@("!I9B`H(21T:&ES+3Y?
M<F5A9$AE861E<B@D=E]B:6YA<GE?9&%T82P@)'9?:&5A9&5R*2D-"B`@("`@
M("`@("`@(')E='5R;B!.54Q,.PT*#0H@("`@("`@("`@:68@*"1V7VAE861E
M<ELG9FEL96YA;64G72`]/2`G)RD-"B`@("`@("`@("`@(&-O;G1I;G5E.PT*
M#0H@("`@("`@("`@+R\@+2TM+2T@3&]O:R!F;W(@;&]N9R!F:6QE;F%M90T*
M("`@("`@("`@(&EF("@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@)TPG*2![
M#0H@("`@("`@("`@("!I9B`H(21T:&ES+3Y?<F5A9$QO;F=(96%D97(H)'9?
M:&5A9&5R*2D-"B`@("`@("`@("`@("`@<F5T=7)N($Y53$P[#0H@("`@("`@
M("`@?0T*#0H@("`@("`@("`@:68@*"1V7VAE861E<ELG9FEL96YA;64G72`]
M/2`D<%]F:6QE;F%M92D@>PT*("`@("`@("`@("`@("!I9B`H)'9?:&5A9&5R
M6R=T>7!E9FQA9R==(#T]("(U(BD@>PT*("`@("`@("`@("`@("`@("`@)'1H
M:7,M/E]E<G)O<B@G56YA8FQE('1O(&5X=')A8W0@:6X@<W1R:6YG(&$@9&ER
M96-T;W)Y("<-"@D)"0D@("`@("`@("`@("`@("`@+B=E;G1R>2![)RXD=E]H
M96%D97);)V9I;&5N86UE)UTN)WTG*3L-"B`@("`@("`@("`@("`@("`@(')E
M='5R;B!.54Q,.PT*("`@("`@("`@("`@("!](&5L<V4@>PT*("`@("`@("`@
M("`@("`@("`@)&X@/2!F;&]O<B@D=E]H96%D97);)W-I>F4G72\U,3(I.PT*
M("`@("`@("`@("`@("`@("`@9F]R("@D:3TP.R`D:3PD;CL@)&DK*RD@>PT*
M("`@("`@("`@("`@("`@("`@("`@("1V7W)E<W5L=%]S='(@+CT@)'1H:7,M
M/E]R96%D0FQO8VLH*3L-"B`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@
M("`@("`@("`@(&EF("@H)'9?:&5A9&5R6R=S:7IE)UT@)2`U,3(I("$](#`I
M('L-"B`@("`@("`@("`@("`@("`@("`@("`D=E]C;VYT96YT(#T@)'1H:7,M
M/E]R96%D0FQO8VLH*3L-"B`@("`@("`@("`@("`@("`@("`@("`D=E]R97-U
M;'1?<W1R("X]('-U8G-T<B@D=E]C;VYT96YT+"`P+`T*"0D)"0D@("`@("`@
M("`@("`@("`@("`@("`@("`@("@D=E]H96%D97);)W-I>F4G72`E(#4Q,BDI
M.PT*("`@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@("`@<F5T
M=7)N("1V7W)E<W5L=%]S='([#0H@("`@("`@("`@("`@('T-"B`@("`@("`@
M("!](&5L<V4@>PT*("`@("`@("`@("`@("`D=&AI<RT^7VIU;7!";&]C:RAC
M96EL*"@D=E]H96%D97);)W-I>F4G72\U,3(I*2D[#0H@("`@("`@("`@?0T*
M("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N($Y53$P[#0H@("`@?0T*("`@
M("\O('U]?0T*#0H@("`@+R\@>WM[(%]E>'1R86-T3&ES="@I#0H@("`@9G5N
M8W1I;VX@7V5X=')A8W1,:7-T*"1P7W!A=&@L("8D<%]L:7-T7V1E=&%I;"P@
M)'!?;6]D92P-"@D@("`@("`@("`@("`@("`@("`@("`@)'!?9FEL95]L:7-T
M+"`D<%]R96UO=F5?<&%T:"D-"B`@("![#0H@("`@)'9?<F5S=6QT/71R=64[
M#0H@("`@)'9?;F(@/2`P.PT*("`@("1V7V5X=')A8W1?86QL(#T@=')U93L-
M"B`@("`D=E]L:7-T:6YG(#T@9F%L<V4[#0H-"B`@("`D<%]P871H(#T@)'1H
M:7,M/E]T<F%N<VQA=&57:6Y0871H*"1P7W!A=&@L(&9A;'-E*3L-"B`@("!I
M9B`H)'!?<&%T:"`]/2`G)R!\?"`H<W5B<W1R*"1P7W!A=&@L(#`L(#$I("$]
M("<O)PT*"2`@("`F)B!S=6)S='(H)'!?<&%T:"P@,"P@,RD@(3T@(BXN+R(@
M)B8@(7-T<G!O<R@D<%]P871H+"`G.B<I*2D@>PT*("`@("`@)'!?<&%T:"`]
M("(N+R(N)'!?<&%T:#L-"B`@("!]#0H@("`@)'!?<F5M;W9E7W!A=&@@/2`D
M=&AI<RT^7W1R86YS;&%T95=I;E!A=&@H)'!?<F5M;W9E7W!A=&@I.PT*#0H@
M("`@+R\@+2TM+2T@3&]O:R!F;W(@<&%T:"!T;R!R96UO=F4@9F]R;6%T("AS
M:&]U;&0@96YD(&)Y("\I#0H@("`@:68@*"@D<%]R96UO=F5?<&%T:"`A/2`G
M)RD@)B8@*'-U8G-T<B@D<%]R96UO=F5?<&%T:"P@+3$I("$]("<O)RDI#0H@
M("`@("`D<%]R96UO=F5?<&%T:"`N/2`G+R<[#0H@("`@)'!?<F5M;W9E7W!A
M=&A?<VEZ92`]('-T<FQE;B@D<%]R96UO=F5?<&%T:"D[#0H-"B`@("!S=VET
M8V@@*"1P7VUO9&4I('L-"B`@("`@(&-A<V4@(F-O;7!L971E(B`Z#0H@("`@
M("`@("1V7V5X=')A8W1?86QL(#T@5%)513L-"B`@("`@("`@)'9?;&ES=&EN
M9R`]($9!3%-%.PT*("`@("`@8G)E86L[#0H@("`@("!C87-E(")P87)T:6%L
M(B`Z#0H@("`@("`@("`@)'9?97AT<F%C=%]A;&P@/2!&04Q313L-"B`@("`@
M("`@("`D=E]L:7-T:6YG(#T@1D%,4T4[#0H@("`@("!B<F5A:SL-"B`@("`@
M(&-A<V4@(FQI<W0B(#H-"B`@("`@("`@("`D=E]E>'1R86-T7V%L;"`]($9!
M3%-%.PT*("`@("`@("`@("1V7VQI<W1I;F<@/2!44E5%.PT*("`@("`@8G)E
M86L[#0H@("`@("!D969A=6QT(#H-"B`@("`@("`@)'1H:7,M/E]E<G)O<B@G
M26YV86QI9"!E>'1R86-T(&UO9&4@*"<N)'!?;6]D92XG*2<I.PT*("`@("`@
M("!R971U<FX@9F%L<V4[#0H@("`@?0T*#0H@("`@8VQE87)S=&%T8V%C:&4H
M*3L-"@T*("`@('=H:6QE("AS=')L96XH)'9?8FEN87)Y7V1A=&$@/2`D=&AI
M<RT^7W)E861";&]C:R@I*2`A/2`P*0T*("`@('L-"B`@("`@("1V7V5X=')A
M8W1?9FEL92`]($9!3%-%.PT*("`@("`@)'9?97AT<F%C=&EO;E]S=&]P<&5D
M(#T@,#L-"@T*("`@("`@:68@*"$D=&AI<RT^7W)E861(96%D97(H)'9?8FEN
M87)Y7V1A=&$L("1V7VAE861E<BDI#0H@("`@("`@(')E='5R;B!F86QS93L-
M"@T*("`@("`@:68@*"1V7VAE861E<ELG9FEL96YA;64G72`]/2`G)RD@>PT*
M("`@("`@("!C;VYT:6YU93L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM+2T@
M3&]O:R!F;W(@;&]N9R!F:6QE;F%M90T*("`@("`@:68@*"1V7VAE861E<ELG
M='EP969L86<G72`]/2`G3"<I('L-"B`@("`@("`@:68@*"$D=&AI<RT^7W)E
M861,;VYG2&5A9&5R*"1V7VAE861E<BDI#0H@("`@("`@("`@<F5T=7)N(&9A
M;'-E.PT*("`@("`@?0T*#0H@("`@("!I9B`H*"$D=E]E>'1R86-T7V%L;"D@
M)B8@*&ES7V%R<F%Y*"1P7V9I;&5?;&ES="DI*2![#0H@("`@("`@("\O("TM
M+2TM($)Y(&1E9F%U;'0@;F\@=6YZ:7`@:68@=&AE(&9I;&4@:7,@;F]T(&9O
M=6YD#0H@("`@("`@("1V7V5X=')A8W1?9FEL92`](&9A;'-E.PT*#0H@("`@
M("`@(&9O<B`H)&D],#L@)&D\<VEZ96]F*"1P7V9I;&5?;&ES="D[("1I*RLI
M('L-"B`@("`@("`@("`O+R`M+2TM+2!,;V]K(&EF(&ET(&ES(&$@9&ER96-T
M;W)Y#0H@("`@("`@("`@:68@*'-U8G-T<B@D<%]F:6QE7VQI<W1;)&E=+"`M
M,2D@/3T@)R\G*2![#0H@("`@("`@("`@("`O+R`M+2TM+2!,;V]K(&EF('1H
M92!D:7)E8W1O<GD@:7,@:6X@=&AE(&9I;&5N86UE('!A=&@-"B`@("`@("`@
M("`@(&EF("@H<W1R;&5N*"1V7VAE861E<ELG9FEL96YA;64G72D@/B!S=')L
M96XH)'!?9FEL95]L:7-T6R1I72DI#0H)"0D@("`@)B8@*'-U8G-T<B@D=E]H
M96%D97);)V9I;&5N86UE)UTL(#`L('-T<FQE;B@D<%]F:6QE7VQI<W1;)&E=
M*2D-"@D)"0D@("`@/3T@)'!?9FEL95]L:7-T6R1I72DI('L-"B`@("`@("`@
M("`@("`@)'9?97AT<F%C=%]F:6QE(#T@5%)513L-"B`@("`@("`@("`@("`@
M8G)E86L[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@?0T*#0H@("`@("`@
M("`@+R\@+2TM+2T@270@:7,@82!F:6QE+"!S;R!C;VUP87)E('1H92!F:6QE
M(&YA;65S#0H@("`@("`@("`@96QS96EF("@D<%]F:6QE7VQI<W1;)&E=(#T]
M("1V7VAE861E<ELG9FEL96YA;64G72D@>PT*("`@("`@("`@("`@)'9?97AT
M<F%C=%]F:6QE(#T@5%)513L-"B`@("`@("`@("`@(&)R96%K.PT*("`@("`@
M("`@('T-"B`@("`@("`@?0T*("`@("`@?2!E;'-E('L-"B`@("`@("`@)'9?
M97AT<F%C=%]F:6QE(#T@5%)513L-"B`@("`@('T-"@T*("`@("`@+R\@+2TM
M+2T@3&]O:R!I9B!T:&ES(&9I;&4@;F5E9"!T;R!B92!E>'1R86-T960-"B`@
M("`@(&EF("@H)'9?97AT<F%C=%]F:6QE*2`F)B`H(21V7VQI<W1I;F<I*0T*
M("`@("`@>PT*("`@("`@("!I9B`H*"1P7W)E;6]V95]P871H("$]("<G*0T*
M("`@("`@("`@("`@)B8@*'-U8G-T<B@D=E]H96%D97);)V9I;&5N86UE)UTL
M(#`L("1P7W)E;6]V95]P871H7W-I>F4I#0H)"0D@("`@/3T@)'!?<F5M;W9E
M7W!A=&@I*0T*("`@("`@("`@("1V7VAE861E<ELG9FEL96YA;64G72`]('-U
M8G-T<B@D=E]H96%D97);)V9I;&5N86UE)UTL#0H)"2`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P7W)E;6]V95]P871H7W-I>F4I.PT*("`@
M("`@("!I9B`H*"1P7W!A=&@@(3T@)RXO)RD@)B8@*"1P7W!A=&@@(3T@)R\G
M*2D@>PT*("`@("`@("`@('=H:6QE("AS=6)S='(H)'!?<&%T:"P@+3$I(#T]
M("<O)RD-"B`@("`@("`@("`@("1P7W!A=&@@/2!S=6)S='(H)'!?<&%T:"P@
M,"P@<W1R;&5N*"1P7W!A=&@I+3$I.PT*#0H@("`@("`@("`@:68@*'-U8G-T
M<B@D=E]H96%D97);)V9I;&5N86UE)UTL(#`L(#$I(#T]("<O)RD-"B`@("`@
M("`@("`@("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@)'!?<&%T:"XD=E]H
M96%D97);)V9I;&5N86UE)UT[#0H@("`@("`@("`@96QS90T*("`@("`@("`@
M("`@)'9?:&5A9&5R6R=F:6QE;F%M92==(#T@)'!?<&%T:"XG+R<N)'9?:&5A
M9&5R6R=F:6QE;F%M92==.PT*("`@("`@("!]#0H@("`@("`@(&EF("AF:6QE
M7V5X:7-T<R@D=E]H96%D97);)V9I;&5N86UE)UTI*2![#0H@("`@("`@("`@
M:68@*"`@("A`:7-?9&ER*"1V7VAE861E<ELG9FEL96YA;64G72DI#0H)"2`@
M("`@("8F("@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@)R<I*2![#0H@("`@
M("`@("`@("`D=&AI<RT^7V5R<F]R*"=&:6QE("<N)'9?:&5A9&5R6R=F:6QE
M;F%M92==#0H)"0D@("`@("`@("`@("`@("XG(&%L<F5A9'D@97AI<W1S(&%S
M(&$@9&ER96-T;W)Y)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@
M("`@("`@("`@?0T*("`@("`@("`@(&EF("@@("`H)'1H:7,M/E]I<T%R8VAI
M=F4H)'9?:&5A9&5R6R=F:6QE;F%M92==*2D-"@D)("`@("`@)B8@*"1V7VAE
M861E<ELG='EP969L86<G72`]/2`B-2(I*2![#0H@("`@("`@("`@("`D=&AI
M<RT^7V5R<F]R*"=$:7)E8W1O<GD@)RXD=E]H96%D97);)V9I;&5N86UE)UT-
M"@D)"2`@("`@("`@("`@("`@+B<@86QR96%D>2!E>&ES=',@87,@82!F:6QE
M)RD[#0H@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@?0T*
M("`@("`@("`@(&EF("@A:7-?=W)I=&5A8FQE*"1V7VAE861E<ELG9FEL96YA
M;64G72DI('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T9I;&4@)RXD
M=E]H96%D97);)V9I;&5N86UE)UT-"@D)"2`@("`@("`@("`@("`@+B<@86QR
M96%D>2!E>&ES=',@86YD(&ES('=R:71E('!R;W1E8W1E9"<I.PT*("`@("`@
M("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@('T-"B`@("`@("`@("!I
M9B`H9FEL96UT:6UE*"1V7VAE861E<ELG9FEL96YA;64G72D@/B`D=E]H96%D
M97);)VUT:6UE)UTI('L-"B`@("`@("`@("`@("\O(%1O(&)E(&-O;7!L971E
M9"`Z($%N(&5R<F]R(&]R('-I;&5N="!N;R!R97!L86-E(#\-"B`@("`@("`@
M("!]#0H@("`@("`@('T-"@T*("`@("`@("`O+R`M+2TM+2!#:&5C:R!T:&4@
M9&ER96-T;W)Y(&%V86EL86)I;&ET>2!A;F0@8W)E871E(&ET(&EF(&YE8V5S
M<V%R>0T*("`@("`@("!E;'-E:68@*"@D=E]R97-U;'0-"@D)("`@("`@("`@
M/2`D=&AI<RT^7V1I<D-H96-K*"@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@
M(C4B#0H)"0D)("`@("`@("`@("`@("`@("`@("`_)'9?:&5A9&5R6R=F:6QE
M;F%M92==#0H)"0D)"0D)"0DZ9&ER;F%M92@D=E]H96%D97);)V9I;&5N86UE
M)UTI*2DI("$](#$I('L-"B`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N
M86)L92!T;R!C<F5A=&4@<&%T:"!F;W(@)RXD=E]H96%D97);)V9I;&5N86UE
M)UTI.PT*("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-
M"B`@("`@("`@:68@*"1V7V5X=')A8W1?9FEL92D@>PT*("`@("`@("`@(&EF
M("@D=E]H96%D97);)W1Y<&5F;&%G)UT@/3T@(C4B*2![#0H@("`@("`@("`@
M("!I9B`H(4!F:6QE7V5X:7-T<R@D=E]H96%D97);)V9I;&5N86UE)UTI*2![
M#0H@("`@("`@("`@("`@("`@:68@*"%`;6MD:7(H)'9?:&5A9&5R6R=F:6QE
M;F%M92==+"`P-S<W*2D@>PT*("`@("`@("`@("`@("`@("`@("`D=&AI<RT^
M7V5R<F]R*"=5;F%B;&4@=&\@8W)E871E(&1I<F5C=&]R>2![)PT*"0D)"0D@
M("`@("`@("`@("`@("XD=E]H96%D97);)V9I;&5N86UE)UTN)WTG*3L-"B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@('T-"B`@("`@("`@("!](&5L<V4@>PT*("`@
M("`@("`@("`@("!I9B`H*"1V7V1E<W1?9FEL92`]($!F;W!E;B@D=E]H96%D
M97);)V9I;&5N86UE)UTL(")W8B(I*2`]/2`P*2![#0H@("`@("`@("`@("`@
M("`@("`D=&AI<RT^7V5R<F]R*"=%<G)O<B!W:&EL92!O<&5N:6YG('LG+B1V
M7VAE861E<ELG9FEL96YA;64G70T*"0D)"2`@("`@("`@("`@("`@("`N)WT@
M:6X@=W)I=&4@8FEN87)Y(&UO9&4G*3L-"B`@("`@("`@("`@("`@("`@(')E
M='5R;B!F86QS93L-"B`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`@("`@("`@("1N(#T@9FQO;W(H)'9?:&5A9&5R6R=S:7IE)UTO-3$R*3L-
M"B`@("`@("`@("`@("`@("`@(&9O<B`H)&D],#L@)&D\)&X[("1I*RLI('L-
M"B`@("`@("`@("`@("`@("`@("`@("`D=E]C;VYT96YT(#T@)'1H:7,M/E]R
M96%D0FQO8VLH*3L-"B`@("`@("`@("`@("`@("`@("`@("!F=W)I=&4H)'9?
M9&5S=%]F:6QE+"`D=E]C;VYT96YT+"`U,3(I.PT*("`@("`@("`@("`@("`@
M("`@?0T*("`@("`@("`@("`@:68@*"@D=E]H96%D97);)W-I>F4G72`E(#4Q
M,BD@(3T@,"D@>PT*("`@("`@("`@("`@("`D=E]C;VYT96YT(#T@)'1H:7,M
M/E]R96%D0FQO8VLH*3L-"B`@("`@("`@("`@("`@9G=R:71E*"1V7V1E<W1?
M9FEL92P@)'9?8V]N=&5N="P@*"1V7VAE861E<ELG<VEZ92==("4@-3$R*2D[
M#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@($!F8VQO<V4H)'9?9&5S
M=%]F:6QE*3L-"@T*("`@("`@("`@("`@+R\@+2TM+2T@0VAA;F=E('1H92!F
M:6QE(&UO9&4L(&UT:6UE#0H@("`@("`@("`@("!`=&]U8V@H)'9?:&5A9&5R
M6R=F:6QE;F%M92==+"`D=E]H96%D97);)VUT:6UE)UTI.PT*("`@("`@("`@
M("`@+R\@5&\@8F4@8V]M<&QE=&5D#0H@("`@("`@("`@("`O+V-H;6]D*"1V
M7VAE861E<EMF:6QE;F%M95TL($1E8T]C="@D=E]H96%D97);;6]D95TI*3L-
M"B`@("`@("`@("!]#0H-"B`@("`@("`@("`O+R`M+2TM+2!#:&5C:R!T:&4@
M9FEL92!S:7IE#0H@("`@("`@("`@8VQE87)S=&%T8V%C:&4H*3L-"B`@("`@
M("`@("!I9B`H9FEL97-I>F4H)'9?:&5A9&5R6R=F:6QE;F%M92==*2`A/2`D
M=E]H96%D97);)W-I>F4G72D@>PT*("`@("`@("`@("`@("`D=&AI<RT^7V5R
M<F]R*"=%>'1R86-T960@9FEL92`G+B1V7VAE861E<ELG9FEL96YA;64G70T*
M"0D)("`@("`@("`@("`@("`@("XG(&1O97,@;F]T(&AA=F4@=&AE(&-O<G)E
M8W0@9FEL92!S:7IE(%PG)PT*"0D)"0D)"2YF:6QE<VEZ92@D=E]H96%D97);
M)V9I;&5N86UE)UTI#0H)"0D)"0D)+B=<)R`H)RXD=E]H96%D97);)W-I>F4G
M70T*"0D)"0D)"2XG(&5X<&5C=&5D*2X@07)C:&EV92!M87D@8F4@8V]R<G5P
M=&5D+B<I.PT*("`@("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@
M("`@?0T*("`@("`@("`@('T-"B`@("`@("`@?2!E;'-E('L-"B`@("`@("`@
M("`D=&AI<RT^7VIU;7!";&]C:RAC96EL*"@D=E]H96%D97);)W-I>F4G72\U
M,3(I*2D[#0H@("`@("`@('T-"B`@("`@('T@96QS92![#0H@("`@("`@("`@
M)'1H:7,M/E]J=6UP0FQO8VLH8V5I;"@H)'9?:&5A9&5R6R=S:7IE)UTO-3$R
M*2DI.PT*("`@("`@?0T*#0H@("`@("`O*B!40D,@.B!3965M<R!T;R!B92!U
M;G5S960@+BXN#0H@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<RD-"B`@("`@
M("`@)'9?96YD7V]F7V9I;&4@/2!`9WIE;V8H)'1H:7,M/E]F:6QE*3L-"B`@
M("`@(&5L<V4-"B`@("`@("`@)'9?96YD7V]F7V9I;&4@/2!`9F5O9B@D=&AI
M<RT^7V9I;&4I.PT*("`@("`@("`J+PT*#0H@("`@("!I9B`H)'9?;&ES=&EN
M9R!\?"`D=E]E>'1R86-T7V9I;&4@?'P@)'9?97AT<F%C=&EO;E]S=&]P<&5D
M*2![#0H@("`@("`@("\O("TM+2TM($QO9R!E>'1R86-T960@9FEL97,-"B`@
M("`@("`@:68@*"@D=E]F:6QE7V1I<B`](&1I<FYA;64H)'9?:&5A9&5R6R=F
M:6QE;F%M92==*2D-"@D)("`@(#T]("1V7VAE861E<ELG9FEL96YA;64G72D-
M"B`@("`@("`@("`D=E]F:6QE7V1I<B`]("<G.PT*("`@("`@("!I9B`H*'-U
M8G-T<B@D=E]H96%D97);)V9I;&5N86UE)UTL(#`L(#$I(#T]("<O)RD@)B8@
M*"1V7V9I;&5?9&ER(#T]("<G*2D-"B`@("`@("`@("`D=E]F:6QE7V1I<B`]
M("<O)SL-"@T*("`@("`@("`D<%]L:7-T7V1E=&%I;%LD=E]N8BLK72`]("1V
M7VAE861E<CL-"B`@("`@('T-"B`@("!]#0H-"B`@("`@("`@<F5T=7)N('1R
M=64[#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]O<&5N07!P
M96YD*"D-"B`@("!F=6YC=&EO;B!?;W!E;D%P<&5N9"@I#0H@("`@>PT*("`@
M("`@("!I9B`H9FEL97-I>F4H)'1H:7,M/E]T87)N86UE*2`]/2`P*0T*("`@
M("`@("`@(')E='5R;B`D=&AI<RT^7V]P96Y7<FET92@I.PT*("`@("`@("`@
M(`T*("`@("`@("!I9B`H)'1H:7,M/E]C;VUP<F5S<RD@>PT*("`@("`@("`@
M("`@)'1H:7,M/E]C;&]S92@I.PT*#0H@("`@("`@("`@("!I9B`H(4!R96YA
M;64H)'1H:7,M/E]T87)N86UE+"`D=&AI<RT^7W1A<FYA;64N(BYT;7`B*2D@
M>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)T5R<F]R('=H:6QE
M(')E;F%M:6YG(%PG)RXD=&AI<RT^7W1A<FYA;64-"@D)"0D@("`@("`@("`@
M("`@("XG7"<@=&\@=&5M<&]R87)Y(&9I;&4@7"<G+B1T:&ES+3Y?=&%R;F%M
M90T*"0D)"0D)"2`@+B<N=&UP7"<G*3L-"B`@("`@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@D
M=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD-"B`@("`@("`@("`@("`@
M("`D=E]T96UP7W1A<B`]($!G>F]P96XH)'1H:7,M/E]T87)N86UE+B(N=&UP
M(BP@(G)B(BD[#0H@("`@("`@("`@("!E;'-E:68@*"1T:&ES+3Y?8V]M<')E
M<W-?='EP92`]/2`G8GHR)RD-"B`@("`@("`@("`@("`@("`D=E]T96UP7W1A
M<B`]($!B>F]P96XH)'1H:7,M/E]T87)N86UE+B(N=&UP(BP@(G)B(BD[#0H@
M("`@("`@("`@("`@("`@#0H@("`@("`@("`@("!I9B`H)'9?=&5M<%]T87(@
M/3T@,"D@>PT*("`@("`@("`@("`@("`@("1T:&ES+3Y?97)R;W(H)U5N86)L
M92!T;R!O<&5N(&9I;&4@7"<G+B1T:&ES+3Y?=&%R;F%M90T*"0D)"2`@("`@
M("`@("`@("`@+B<N=&UP7"<@:6X@8FEN87)Y(')E860@;6]D92<I.PT*("`@
M("`@("`@("`@("`@($!R96YA;64H)'1H:7,M/E]T87)N86UE+B(N=&UP(BP@
M)'1H:7,M/E]T87)N86UE*3L-"B`@("`@("`@("`@("`@("!R971U<FX@9F%L
M<V4[#0H@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@(&EF("@A)'1H:7,M
M/E]O<&5N5W)I=&4H*2D@>PT*("`@("`@("`@("`@("`@($!R96YA;64H)'1H
M:7,M/E]T87)N86UE+B(N=&UP(BP@)'1H:7,M/E]T87)N86UE*3L-"B`@("`@
M("`@("`@("`@("!R971U<FX@9F%L<V4[#0H@("`@("`@("`@("!]#0H-"B`@
M("`@("`@("`@(&EF("@D=&AI<RT^7V-O;7!R97-S7W1Y<&4@/3T@)V=Z)RD@
M>PT*("`@("`@("`@("`@("`@("1V7V)U9F9E<B`]($!G>G)E860H)'9?=&5M
M<%]T87(L(#4Q,BD[#0H-"B`@("`@("`@("`@("`@("`O+R`M+2TM+2!296%D
M('1H92!F;VQL;W=I;F<@8FQO8VMS(&)U="!N;W0@=&AE(&QA<W0@;VYE#0H@
M("`@("`@("`@("`@("`@:68@*"%`9WIE;V8H)'9?=&5M<%]T87(I*2![#0H@
M("`@("`@("`@("`@("`@("`@(&1O>PT*("`@("`@("`@("`@("`@("`@("`@
M("`@)'9?8FEN87)Y7V1A=&$@/2!P86-K*")A-3$R(BP@)'9?8G5F9F5R*3L-
M"B`@("`@("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D
M=E]B:6YA<GE?9&%T82D[#0H@("`@("`@("`@("`@("`@("`@("`@("`D=E]B
M=69F97(@/2!`9WIR96%D*"1V7W1E;7!?=&%R+"`U,3(I.PT*#0H@("`@("`@
M("`@("`@("`@("`@('T@=VAI;&4@*"%`9WIE;V8H)'9?=&5M<%]T87(I*3L-
M"B`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("!`9WIC;&]S
M92@D=E]T96UP7W1A<BD[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!E
M;'-E:68@*"1T:&ES+3Y?8V]M<')E<W-?='EP92`]/2`G8GHR)RD@>PT*("`@
M("`@("`@("`@("`@("1V7V)U9F9E<F5D7VQI;F5S("`@/2!A<G)A>2@I.PT*
M("`@("`@("`@("`@("`@("1V7V)U9F9E<F5D7VQI;F5S6UT@/2!`8GIR96%D
M*"1V7W1E;7!?=&%R+"`U,3(I.PT*#0H@("`@("`@("`@("`@("`@+R\@+2TM
M+2T@4F5A9"!T:&4@9F]L;&]W:6YG(&)L;V-K<R!B=70@;F]T('1H92!L87-T
M(&]N90T*("`@("`@("`@("`@("`@('=H:6QE("AS=')L96XH)'9?8G5F9F5R
M961?;&EN97-;70T*"0D)"2`@("`@("`@("`@("`@/2!`8GIR96%D*"1V7W1E
M;7!?=&%R+"`U,3(I*2`^(#`I('L-"B`@("`@("`@("`@("`@("`@("`@)'9?
M8FEN87)Y7V1A=&$@/2!P86-K*")A-3$R(BP-"@D)"0D)("`@("`@("`@("`@
M("`@("`@("`@(&%R<F%Y7W-H:69T*"1V7V)U9F9E<F5D7VQI;F5S*2D[#0H@
M("`@("`@("`@("`@("`@("`@("1T:&ES+3Y?=W)I=&5";&]C:R@D=E]B:6YA
M<GE?9&%T82D[#0H@("`@("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("`@
M("`@0&)Z8VQO<V4H)'9?=&5M<%]T87(I.PT*("`@("`@("`@("`@?0T*#0H@
M("`@("`@("`@("!I9B`H(4!U;FQI;FLH)'1H:7,M/E]T87)N86UE+B(N=&UP
M(BDI('L-"B`@("`@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*"=%<G)O<B!W
M:&EL92!D96QE=&EN9R!T96UP;W)A<GD@9FEL92!<)R<-"@D)"0D@("`@("`@
M("`@("`@("XD=&AI<RT^7W1A<FYA;64N)RYT;7!<)R<I.PT*("`@("`@("`@
M("`@?0T*#0H@("`@("`@('T@96QS92![#0H@("`@("`@("`@("`O+R`M+2TM
M+2!&;W(@;F]T(&-O;7!R97-S960@=&%R+"!J=7-T(&%D9"!F:6QE<R!B969O
M<F4@=&AE(&QA<W0-"@D)"2\O("`@("`@(#4Q,B!B>71E<R!B;&]C:PT*("`@
M("`@("`@("`@:68@*"$D=&AI<RT^7V]P96Y296%D5W)I=&4H*2D-"B`@("`@
M("`@("`@("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("`@("`@8VQE87)S
M=&%T8V%C:&4H*3L-"B`@("`@("`@("`@("1V7W-I>F4@/2!F:6QE<VEZ92@D
M=&AI<RT^7W1A<FYA;64I.PT*("`@("`@("`@("`@9G-E96LH)'1H:7,M/E]F
M:6QE+"`D=E]S:7IE+34Q,BD[#0H@("`@("`@('T-"@T*("`@("`@("!R971U
M<FX@=')U93L-"B`@("!]#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7V%P
M<&5N9"@I#0H@("`@9G5N8W1I;VX@7V%P<&5N9"@D<%]F:6QE;&ES="P@)'!?
M861D7V1I<CTG)RP@)'!?<F5M;W9E7V1I<CTG)RD-"B`@("![#0H@("`@("`@
M(&EF("@A)'1H:7,M/E]O<&5N07!P96YD*"DI#0H@("`@("`@("`@("!R971U
M<FX@9F%L<V4[#0H@("`@("`@("`@("`-"B`@("`@("`@:68@*"1T:&ES+3Y?
M861D3&ES="@D<%]F:6QE;&ES="P@)'!?861D7V1I<BP@)'!?<F5M;W9E7V1I
M<BDI#0H@("`@("`@("`@("1T:&ES+3Y?=W)I=&5&;V]T97(H*3L-"@T*("`@
M("`@("`D=&AI<RT^7V-L;W-E*"D[#0H-"B`@("`@("`@<F5T=7)N('1R=64[
M#0H@("`@?0T*("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]D:7)#:&5C:R@I
M#0H-"B`@("`O*BH-"B`@("`@*B!#:&5C:R!I9B!A(&1I<F5C=&]R>2!E>&ES
M=',@86YD(&-R96%T92!I="`H:6YC;'5D:6YG('!A<F5N=`T*("`@("`J(&1I
M<G,I(&EF(&YO="X-"B`@("`@*@T*("`@("`J($!P87)A;2!S=')I;F<@)'!?
M9&ER(&1I<F5C=&]R>2!T;R!C:&5C:PT*("`@("`J#0H@("`@("H@0')E='5R
M;B!B;V]L(%12544@:68@=&AE(&1I<F5C=&]R>2!E>&ES=',@;W(@=V%S(&-R
M96%T960-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?9&ER0VAE8VLH)'!?9&ER
M*0T*("`@('L-"B`@("`@("`@:68@*"A`:7-?9&ER*"1P7V1I<BDI('Q\("@D
M<%]D:7(@/3T@)R<I*0T*("`@("`@("`@("`@<F5T=7)N('1R=64[#0H-"B`@
M("`@("`@)'!?<&%R96YT7V1I<B`](&1I<FYA;64H)'!?9&ER*3L-"@T*("`@
M("`@("!I9B`H*"1P7W!A<F5N=%]D:7(@(3T@)'!?9&ER*2`F)@T*("`@("`@
M("`@("`@*"1P7W!A<F5N=%]D:7(@(3T@)R<I("8F#0H@("`@("`@("`@("`H
M(21T:&ES+3Y?9&ER0VAE8VLH)'!?<&%R96YT7V1I<BDI*0T*("`@("`@("`@
M("`@(')E='5R;B!F86QS93L-"@T*("`@("`@("!I9B`H(4!M:V1I<B@D<%]D
M:7(L(#`W-S<I*2![#0H@("`@("`@("`@("`D=&AI<RT^7V5R<F]R*")5;F%B
M;&4@=&\@8W)E871E(&1I<F5C=&]R>2`G)'!?9&ER)R(I.PT*("`@("`@("`@
M("`@<F5T=7)N(&9A;'-E.PT*("`@("`@("!]#0H-"B`@("`@("`@<F5T=7)N
M('1R=64[#0H@("`@?0T*#0H@("`@+R\@?7U]#0H-"B`@("`O+R![>WL@7W!A
M=&A2961U8W1I;VXH*0T*#0H@("`@+RHJ#0H@("`@("H@0V]M<')E<W,@<&%T
M:"!B>2!C:&%N9VEN9R!F;W(@97AA;7!L92`B+V1I<B]F;V\O+BXO8F%R(B!T
M;R`B+V1I<B]B87(B+"`-"B`@("`@*B!R86YD(&5M;W9E(&1O=6)L92!S;&%S
M:&5S+@T*("`@("`J#0H@("`@("H@0'!A<F%M('-T<FEN9R`D<%]D:7(@<&%T
M:"!T;R!R961U8V4-"B`@("`@*@T*("`@("`J($!R971U<FX@<W1R:6YG(')E
M9'5C960@<&%T:`T*("`@("`J#0H@("`@("H@0&%C8V5S<R!P<FEV871E#0H@
M("`@("H-"B`@("`@*B\-"B`@("!F=6YC=&EO;B!?<&%T:%)E9'5C=&EO;B@D
M<%]D:7(I#0H@("`@>PT*("`@("`@("`D=E]R97-U;'0@/2`G)SL-"@T*("`@
M("`@("`O+R`M+2TM+2!,;V]K(&9O<B!N;W0@96UP='D@<&%T:`T*("`@("`@
M("!I9B`H)'!?9&ER("$]("<G*2![#0H@("`@("`@("`@("`O+R`M+2TM+2!%
M>'!L;V1E('!A=&@@8GD@9&ER96-T;W)Y(&YA;65S#0H@("`@("`@("`@("`D
M=E]L:7-T(#T@97AP;&]D92@G+R<L("1P7V1I<BD[#0H-"B`@("`@("`@("`@
M("\O("TM+2TM(%-T=61Y(&1I<F5C=&]R:65S(&9R;VT@;&%S="!T;R!F:7)S
M=`T*("`@("`@("`@("`@9F]R("@D:3US:7IE;V8H)'9?;&ES="DM,3L@)&D^
M/3`[("1I+2TI('L-"B`@("`@("`@("`@("`@("`O+R`M+2TM+2!,;V]K(&9O
M<B!C=7)R96YT('!A=&@-"B`@("`@("`@("`@("`@("!I9B`H)'9?;&ES=%LD
M:5T@/3T@(BXB*2![#0H@("`@("`@("`@("`@("`@("`@("\O("TM+2TM($EG
M;F]R92!T:&ES(&1I<F5C=&]R>0T*("`@("`@("`@("`@("`@("`@("`O+R!3
M:&]U;&0@8F4@=&AE(&9I<G-T("1I/3`L(&)U="!N;R!C:&5C:R!I<R!D;VYE
M#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&5L<V4@:68@
M*"1V7VQI<W1;)&E=(#T]("(N+B(I('L-"B`@("`@("`@("`@("`@("`@("`@
M+R\@+2TM+2T@26=N;W)E(&ET(&%N9"!I9VYO<F4@=&AE("1I+3$-"B`@("`@
M("`@("`@("`@("`@("`@)&DM+3L-"B`@("`@("`@("`@("`@("!]#0H@("`@
M("`@("`@("`@("`@96QS92!I9B`H("`@*"1V7VQI<W1;)&E=(#T]("<G*0T*
M"0D)"2`@("`@("`@("8F("@D:2$]*'-I>F5O9B@D=E]L:7-T*2TQ*2D-"@D)
M"0D)"2`F)B`H)&DA/3`I*2![#0H@("`@("`@("`@("`@("`@("`@("\O("TM
M+2TM($EG;F]R92!O;FQY('1H92!D;W5B;&4@)R\O)R!I;B!P871H+`T*("`@
M("`@("`@("`@("`@("`@("`O+R!B=70@;F]T('1H92!F:7)S="!A;F0@;&%S
M="`O#0H@("`@("`@("`@("`@("`@?2!E;'-E('L-"B`@("`@("`@("`@("`@
M("`@("`@)'9?<F5S=6QT(#T@)'9?;&ES=%LD:5TN*"1I(3TH<VEZ96]F*"1V
M7VQI<W0I+3$I/R<O)PT*"0D)"0D@("`@("`@("`@("`N)'9?<F5S=6QT.B<G
M*3L-"B`@("`@("`@("`@("`@("!]#0H@("`@("`@("`@("!]#0H@("`@("`@
M('T-"B`@("`@("`@)'9?<F5S=6QT(#T@<W1R='(H)'9?<F5S=6QT+"`G7%PG
M+"`G+R<I.PT*("`@("`@("!R971U<FX@)'9?<F5S=6QT.PT*("`@('T-"@T*
M("`@("\O('U]?0T*#0H@("`@+R\@>WM[(%]T<F%N<VQA=&57:6Y0871H*"D-
M"B`@("!F=6YC=&EO;B!?=')A;G-L871E5VEN4&%T:"@D<%]P871H+"`D<%]R
M96UO=F5?9&ES:U]L971T97(]=')U92D-"B`@("![#0H@("`@("!I9B`H3U-?
M5TE.1$]74RD@>PT*("`@("`@("`@("\O("TM+2TM($QO;VL@9F]R('!O=&5N
M=&EA;"!D:7-K(&QE='1E<@T*("`@("`@("`@(&EF("@@("`H)'!?<F5M;W9E
M7V1I<VM?;&5T=&5R*0T*"0D@("`@("`F)B`H*"1V7W!O<VET:6]N(#T@<W1R
M<&]S*"1P7W!A=&@L("<Z)RDI("$](&9A;'-E*2D@>PT*("`@("`@("`@("`@
M("`D<%]P871H(#T@<W5B<W1R*"1P7W!A=&@L("1V7W!O<VET:6]N*S$I.PT*
M("`@("`@("`@('T-"B`@("`@("`@("`O+R`M+2TM+2!#:&%N9V4@<&]T96YT
M:6%L('=I;F1O=W,@9&ER96-T;W)Y('-E<&%R871O<@T*("`@("`@("`@(&EF
M("@H<W1R<&]S*"1P7W!A=&@L("=<7"<I(#X@,"D@?'P@*'-U8G-T<B@D<%]P
M871H+"`P+#$I(#T]("=<7"<I*2![#0H@("`@("`@("`@("`@("1P7W!A=&@@
M/2!S=')T<B@D<%]P871H+"`G7%PG+"`G+R<I.PT*("`@("`@("`@('T-"B`@
M("`@('T-"B`@("`@(')E='5R;B`D<%]P871H.PT*("`@('T-"B`@("`O+R!]
M?7T-"@T*?0T*/SX-"@!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P96%R+U-E
M<G9I8V5S+U=E871H97(`````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S(@,#(Q-38S`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<BYP:'``````````````
M```````````````````````````````````````````````````````P,#`V
M-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`R-C`V,B`Q,#4Q-30S-#$S,B`P
M,C(S-C$`(#``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF
M='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*
M"B\J*@H@*B!014%2.CI397)V:6-E<U]796%T:&5R"B`J"B`J(%-E<G9I8V5S
M7U=E871H97(@<V5A<F-H97,@9F]R(&=I=F5N(&QO8V%T:6]N<R!A;F0@<F5T
M<FEE=F5S(&-U<G)E;G0*("H@=V5A=&AE<B!D871A(&%N9"P@9&5P96YD86YT
M(&]N('1H92!U<V5D('-E<G9I8V4L(&%L<V\@9F]R96-A<W1S+B!5<"!T;PH@
M*B!N;W<L(%-/05`@<V5R=FEC97,@9G)O;2!#87!E4V-I96YC92!A;F0@14I3
M12P@6$U,(&9R;VT@=V5A=&AE<BYC;VT@86YD"B`J($U%5$%2+U1!1B!F<F]M
M(&YO86$N9V]V(&%R92!S=7!P;W)T960L(&9U<G1H97(@<V5R=FEC97,@=VEL
M;"!G970*("H@:6YC;'5D960L(&EF('1H97D@8F5C;VUE(&%V86EL86)L92!A
M;F0@87)E('!R;W!E<FQY(&1O8W5M96YT960N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P
M,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@
M*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@
M;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@
M("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T
M=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M
M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R
M:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/
M+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%2
M62P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)5
M5"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!2
M3T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52
M($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@
M24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@
M1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@
M4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@
M0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*
M("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E
M;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-6
M4SH@)$ED.B!796%T:&5R+G!H<"QV(#$N-#,@,C`P-2\Q,2\Q-B`Q,CHT.#HS
M-"!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN
M970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!F:6QE<V]U<F-E"B`J
M+PH*+R\@>WM[(&-O;G-T86YT<PHO+R![>WL@8V%C:&4@=&EM97,*9&5F:6YE
M*")315)624-%4U]714%42$527T584$E215-?54Y)5%,B+"`@("`@("`@.3`P
M*3L@+R\@,35-"F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537TQ/
M0T%424].(BP@("`T,S(P,"D[("\O(#$R2`ID969I;F4H(E-%4E9)0T537U=%
M051(15)?15A025)%4U]714%42$52(BP@("`@(#$X,#`I.R`O+R`S,$T*9&5F
M:6YE*")315)624-%4U]714%42$527T584$E215-?1D]214-!4U0B+"`@("`W
M,C`P*3L@+R\@(#)("F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]%6%!)4D53
M7TQ)3DM3(BP@("`@("`T,S(P,"D[("\O(#$R2`ID969I;F4H(E-%4E9)0T53
M7U=%051(15)?15A025)%4U]314%20T@B+"`@(#(T,3DR,#`I.R`O+R`R.$0*
M+R\@?7U]"@HO+R![>WL@97)R;W(@8V]D97,*9&5F:6YE*")315)624-%4U]7
M14%42$527T524D]27U-%4E9)0T5?3D]47T9/54Y$(BP@("`@("`@(#$P*3L*
M9&5F:6YE*")315)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)
M3TXB+"`@("`@("`@(#$Q*3L*9&5F:6YE*")315)624-%4U]714%42$527T52
M4D]27U=23TY'7U-%4E9%4E]$051!(BP@("`@("`@(#$R*3L*9&5F:6YE*")3
M15)624-%4U]714%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$(BP@("`@
M("`@(#$S*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27T1"7TY/
M5%]#3TY.14-4140B+"`@("`@("`@(#$T*3L*9&5F:6YE*")315)624-%4U]7
M14%42$527T524D]27TA45%!?4%)/6%E?24Y604Q)1"(L("`@("`@(#$U*3L*
M9&5F:6YE*")315)624-%4U]714%42$527T524D]27U-53D953D-37T1!5$5?
M24Y604Q)1"(L("`@(#$V*3L*9&5F:6YE*")315)624-%4U]714%42$527T52
M4D]27U-53D953D-37U)%5$9/4DU?24Y604Q)1"(L(#$W*3L*9&5F:6YE*")3
M15)624-%4U]714%42$527T524D]27TU%5$%27U-/55)#15])3E9!3$E$(BP@
M("`@(#$X*3L*+R\@?7U]"@HO+R![>WL@97)R;W(@8V]D97,@9&5F:6YE9"!B
M>2!W96%T:&5R+F-O;0ID969I;F4H(E-%4E9)0T537U=%051(15)?15)23U)?
M54Y+3D]73E]%4E)/4B(L("`@("`@("`@("`@,"D["F1E9FEN92@B4T525DE#
M15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3B(L("`@("`@("`@("`@("`Q
M*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#
M051)3TXB+"`@("`@("`@(#(I.PID969I;F4H(E-%4E9)0T537U=%051(15)?
M15)23U)?24Y604Q)1%]005)43D527TE$(BP@("`@(#$P,"D["F1E9FEN92@B
M4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7U!23T150U1?0T]$12(L
M("`@,3`Q*3L*9&5F:6YE*")315)624-%4U]714%42$527T524D]27TE.5D%,
M241?3$E#14Y315]+15DB+"`@("`Q,#(I.PHO+R!]?7T*+R\@?7U]"@HO+R![
M>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE<@HO*BH*("H@5&AI<R!C;&%S<R!A
M8W1S(&%S(&%N(&EN=&5R9F%C92!T;R!V87)I;W5S(&]N;&EN92!W96%T:&5R
M+7-E<G9I8V5S+@H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S"B`J
M($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@("`@
M("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y<FEG
M:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@:'1T
M<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS92YP
M:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!296QE87-E.B`Q+C0N
M,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K86=E
M+U-E<G9I8V5S7U=E871H97(*("HO"F-L87-S(%-E<G9I8V5S7U=E871H97(@
M>PH*("`@("\O('M[>R`F<V5R=FEC92@I"B`@("`O*BH*("`@("`J($9A8W1O
M<GD@9F]R(&-R96%T:6YG('1H92!S97)V:6-E<RUO8FIE8W1S"B`@("`@*@H@
M("`@("H@57-A8FQE(&ME>7,@9F]R('1H92!O<'1I;VYS(&%R<F%Y(&%R93H*
M("`@("`J(&\@9&5B=6<@("`@("`@("`@("`@(&5N86)L97,@9&5B=6=G:6YG
M(&]U='!U=`H@("`@("H@+2TM($-O;6UO;B!/<'1I;VYS"B`@("`@*B!O(&-A
M8VAE5'EP92`@("`@("`@("!D969I;F5S('=H870@='EP92!O9B!C86-H92!T
M;R!U<V4*("`@("`J(&\@8V%C:&5/<'1I;VYS("`@("`@('!A<W-E<R!C86-H
M92!O<'1I;VYS"B`@("`@*B!O('5N:71S1F]R;6%T("`@("`@("!U<V4@*%53
M*2US=&%N9&%R9"P@;65T<FEC(&]R(&-U<W1O;2!U;FET<PH@("`@("H@;R!C
M=7-T;VU5;FET<T9O<FUA="`@9&5F:6YE<R!T:&4@8W5S=&]M:7IE9"!U;FET
M<R!F;W)M870*("`@("`J(&\@:'1T<%1I;65O=70@("`@("`@('-E=',@=&EM
M96]U="!F;W(@2%144"!R97%U97-T<PH@("`@("H@;R!H='1P4')O>'D@("`@
M("`@("`@<V5T<R!P<F]X>2!F;W(@2%144"!R97%U97-T<RP@<&QE87-E('5S
M92!T:&4*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&YO=&%T:6]N(&AT
M='`Z+R];=7-E<ELZ<&%S<UU`76AO<W1;.G!O<G1="B`@("`@*B!O(&1A=&5&
M;W)M870@("`@("`@("!S=')I;F<@=&\@=7-E(&9O<B!D871E(&]U='!U=`H@
M("`@("H@;R!T:6UE1F]R;6%T("`@("`@("`@<W1R:6YG('1O('5S92!F;W(@
M=&EM92!O=71P=70*("`@("`J("TM+2!%2E-%($]P=&EO;G,*("`@("`J(&\@
M;F]N90H@("`@("H@+2TM($=L;V)A;%=E871H97(@3W!T:6]N<PH@("`@("H@
M;R!N;VYE"B`@("`@*B`M+2T@345405(O5$%&($]P=&EO;G,*("`@("`J(&\@
M9'-N("`@("`@("`@("`@("`@(%-T<FEN9R!F;W(@9&5F:6YI;F<@=&AE($1"
M(&-O;FYE8W1I;VX*("`@("`J(&\@9&)/<'1I;VYS("`@("`@("`@('!A<W-E
M<R!$0B!O<'1I;VYS"B`@("`@*B!O('-O=7)C94UE=&%R("`@("`@("!H='1P
M+"!F='`@;W(@9FEL92`M('1Y<&4@;V8@9&%T82US;W5R8V4@9F]R($U%5$%2
M"B`@("`@*B!O('-O=7)C95!A=&A-971A<B`@("!W:&5R92!T;R!L;V]K(&9O
M<B!T:&4@<V]U<F-E+"!54DD@;W(@9FEL97!A=&@L"B`@("`@*B`@("`@("`@
M("`@("`@("`@("`@("!O9B!-151!4B!I;F9O<FUA=&EO;@H@("`@("H@;R!S
M;W5R8V54868@("`@("`@("`@:'1T<"P@9G1P(&]R(&9I;&4@+2!T>7!E(&]F
M(&1A=&$M<V]U<F-E(&9O<B!4048*("`@("`J(&\@<V]U<F-E4&%T:%1A9B`@
M("`@('=H97)E('1O(&QO;VL@9F]R('1H92!S;W5R8V4L(%5222!O<B!F:6QE
M<&%T:"P*("`@("`J("`@("`@("`@("`@("`@("`@("`@(&]F(%1!1B!I;F9O
M<FUA=&EO;@H@("`@("H@+2TM('=E871H97(N8V]M($]P=&EO;G,*("`@("`J
M(&\@<&%R=&YE<DE$("`@("`@("`@(%EO=2=L;"!R96-E:79E('1H97-E(&ME
M>7,@869T97(@<F5G:7-T97)I;F<*("`@("`J(&\@;&EC96YS94ME>2`@("`@
M("`@('=I=&@@=&AE('=E871H97(N8V]M(%A-3"US97)V:6-E"B`@("`@*B!O
M('!R949E=&-H("`@("`@("`@("!%;F%B;&5S('!R92UF971C:&EN9R!O9B!D
M871A(&EN(&]N92!S:6YG;&4@<F5Q=65S=`H@("`@("H*("`@("`J($!P87)A
M;2`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`D<V5R=FEC90H@("`@
M("H@0'!A<F%M("`@(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("1O<'1I
M;VYS"B`@("`@*B!`<F5T=7)N("`@4$5!4E]%<G)O<GQO8FIE8W0*("`@("`J
M($!T:')O=W,@("!014%27T5R<F]R"B`@("`@*B!`=&AR;W=S("`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.
M1`H@("`@("H@0&%C8V5S<R`@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO
M;B`F<V5R=FEC92@D<V5R=FEC92P@)&]P=&EO;G,@/2!N=6QL*0H@("`@>PH@
M("`@("`@("1S97)V:6-E(#T@=6-F:7)S="AS=')T;VQO=V5R*"1S97)V:6-E
M*2D["B`@("`@("`@)&-L87-S;F%M92`](")397)V:6-E<U]796%T:&5R7R(N
M)'-E<G9I8V4["@H@("`@("`@("\O($-H96-K(&9O<B!D96)U9V=I;F<M;6]D
M92!A;F0@<V5T('-T=69F(&%C8V]R9&EN9VQY"B`@("`@("`@:68@*&ES7V%R
M<F%Y*"1O<'1I;VYS*2`F)B!I<W-E="@D;W!T:6]N<ULB9&5B=6<B72D@)B8@
M)&]P=&EO;G-;(F1E8G5G(ET@/CT@,BD@>PH@("`@("`@("`@("!I9B`H(61E
M9FEN960H(E-%4E9)0T537U=%051(15)?1$5"54<B*2D@>PH@("`@("`@("`@
M("`@("`@9&5F:6YE*")315)624-%4U]714%42$527T1%0E5'(BP@=')U92D[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@:6YC;'5D95]O;F-E*")397)V
M:6-E<R]796%T:&5R+R(N)'-E<G9I8V4N(BYP:'`B*3L*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!I9B`H(61E9FEN960H(E-%4E9)0T537U=%051(
M15)?1$5"54<B*2D@>PH@("`@("`@("`@("`@("`@9&5F:6YE*")315)624-%
M4U]714%42$527T1%0E5'(BP@9F%L<V4I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@($!I;F-L=61E7V]N8V4H(E-E<G9I8V5S+U=E871H97(O(BXD<V5R
M=FEC92XB+G!H<"(I.PH@("`@("`@('T*"B`@("`@("`@+R\@3F\@<W5C:"!S
M97)V:6-E+BXN(&)A:6P@;W5T"B`@("`@("`@:68@*"%C;&%S<U]E>&ES=',H
M)&-L87-S;F%M92DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)6
M24-%7TY/5%]&3U5.1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]
M"@H@("`@("`@("\O($-R96%T92!S97)V:6-E(&%N9"!R971U<FX*("`@("`@
M("`D97)R;W(@/2!N=6QL.PH@("`@("`@($`D;V)J(#T@)FYE=R`D8VQA<W-N
M86UE*"1O<'1I;VYS+"`D97)R;W(I.PH*("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D97)R;W(I*2!["B`@("`@("`@("`@(')E='5R
M;B`D97)R;W(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@<F5T=7)N
M("1O8FH["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[
M(&%P:59E<G-I;VXH*0H@("`@+RHJ"B`@("`@*B!&;W(@>6]U<B!C;VYV96YI
M96YC92P@=VAE;B!)(&-O;64@=7`@=VET:"!C:&%N9V5S(&EN('1H92!!4$DN
M+BX*("`@("`J"B`@("`@*B!`<F5T=7)N("!S=')I;F<*("`@("`J($!A8V-E
M<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!A<&E697)S:6]N*"D*
M("`@('L*("`@("`@("!R971U<FX@(C$N-"(["B`@("!]"B`@("`O+R!]?7T*
M"B`@("`O+R![>WL@7V5R<F]R365S<V%G92@I"B`@("`O*BH*("`@("`J(%)E
M='5R;G,@=&AE(&UE<W-A9V4@9F]R(&$@8V5R=&%I;B!E<G)O<B!C;V1E"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@4$5!4E]%<G)O<GQI;G0@("`@("`@("`@
M("`@("1V86QU90H@("`@("H@0')E='5R;B`@<W1R:6YG"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]E<G)O<DUE<W-A
M9V4H)'9A;'5E*0H@("`@>PH@("`@("`@('-T871I8R`D97)R;W)-97-S86=E
M<SL*("`@("`@("!I9B`H(6ES<V5T*"1E<G)O<DUE<W-A9V5S*2D@>PH@("`@
M("`@("`@("`D97)R;W)-97-S86=E<R`](&%R<F%Y*`H@("`@("`@("`@("`@
M("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E]315)624-%7TY/5%]&3U5.1"`@
M("`@("`@(#T^(")297%U97-T960@<V5R=FEC92!C;W5L9"!N;W0@8F4@9F]U
M;F0N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?
M54Y+3D]73E],3T-!5$E/3B`@("`@("`@("`]/B`B56YK;F]W;B!L;V-A=&EO
M;B!P<F]V:61E9"XB+`H@("`@("`@("`@("`@("`@4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%402`@("`@("`@(#T^(")397)V97(@
M9&%T82!W<F]N9R!O<B!N;W0@879A:6QA8FQE+B(L"B`@("`@("`@("`@("`@
M("!315)624-%4U]714%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$("`@
M("`@("`@/3X@(D-A8VAE(&EN:70@=V%S(&YO="!C;VUP;&5T960N(BP*("`@
M("`@("`@("`@("`@(%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/
M3DY%0U1%1"`@("`@("`@("`]/B`B365T87)$0B!I<R!N;W0@8V]N;F5C=&5D
M+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]27TA4
M5%!?4%)/6%E?24Y604Q)1"`@("`@("`@/3X@(E1H92!G:79E;B!P<F]X>2!I
M<R!N;W0@=F%L:60L('!L96%S92!U<V4@=&AE(&YO=&%T:6]N(&AT='`Z+R];
M=7-E<ELZ<&%S<UU`76AO<W1;.G!O<G1=+B(L"B`@("`@("`@("`@("`@("!3
M15)624-%4U]714%42$527T524D]27U-53D953D-37T1!5$5?24Y604Q)1"`@
M("`@/3X@(E1H92!D871E('EO=2=V92!P<F]V:61E9"!F;W(@8V%L8W5L871I
M;VX@;V8@<W5N<FES92]S=6YS970@:7,@;F]T(&$@=&EM97-T86UP+B(L"B`@
M("`@("`@("`@("`@("!315)624-%4U]714%42$527T524D]27U-53D953D-3
M7U)%5$9/4DU?24Y604Q)1"`@/3X@(E1H92!R971U<FX@9F]R;6%T('EO=2=V
M92!P<F]V:61E9"!F;W(@8V%L8W5L871I;VX@;V8@<W5N<FES92]S=6YS970@
M:7,@;F]T('9A;&ED+B(L"B`@("`@("`@("`@("`@("!315)624-%4U]714%4
M2$527T524D]27TU%5$%27U-/55)#15])3E9!3$E$("`@("`@/3X@(E1H92!-
M151!4B]4048@<V]U<F-E('EO=2=V92!P<F]V:61E9"!H87,@86X@:6YV86QI
M9"!T>7!E(&]R('!A=&@N(BP*("`@("`@("`@("`@("`@(%-%4E9)0T537U=%
M051(15)?15)23U)?54Y+3D]73E]%4E)/4B`@("`@("`@("`@("`]/B`B06X@
M=6YK;F]W;B!E<G)O<B!H87,@;V-C=7)E9"XB+`H@("`@("`@("`@("`@("`@
M4T525DE#15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3B`@("`@("`@("`@
M("`@(#T^(").;R!L;V-A=&EO;B!P<F]V:61E9"XB+`H@("`@("`@("`@("`@
M("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].("`@
M("`@("`@(#T^("));G9A;&ED(&QO8V%T:6]N('!R;W9I9&5D+B(L"B`@("`@
M("`@("`@("`@("!315)624-%4U]714%42$527T524D]27TE.5D%,241?4$%2
M5$Y%4E])1"`@("`@("`@/3X@(DEN=F%L:60@<&%R=&YE<B!I9"XB+`H@("`@
M("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7U!2
M3T150U1?0T]$12`@("`@(#T^("));G9A;&ED('!R;V1U8W0@8V]D92XB+`H@
M("`@("`@("`@("`@("`@4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$
M7TQ)0T5.4T5?2T59("`@("`@(#T^("));G9A;&ED(&QI8V5N<V4@:V5Y+B(*
M("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1V86QU92DI('L*("`@("`@("`@("`@)'9A
M;'5E(#T@)'9A;'5E+3YG971#;V1E*"D["B`@("`@("`@?0H*("`@("`@("!R
M971U<FX@:7-S970H)&5R<F]R365S<V%G97-;)'9A;'5E72D@/R`D97)R;W)-
M97-S86=E<ULD=F%L=65=(#H@)&5R<F]R365S<V%G97-;4T525DE#15-?5T5!
M5$A%4E]%4E)/4E]53DM.3U=.7T524D]273L*("`@('T*("`@("\O('U]?0H*
M("`@("\O('M[>R!I<T5R<F]R*"D*("`@("\J*@H@("`@("H@0VAE8VMS(&9O
M<B!A;B!E<G)O<B!O8FIE8W0L('-A;64@87,@:6X@4$5!4@H@("`@("H*("`@
M("`J($!P87)A;2`@(%!%05)?17)R;W)\;6EX960@("`@("`@("`@("`D=F%L
M=64*("`@("`J($!R971U<FX@(&)O;VP*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!I<T5R<F]R*"1V86QU92D*("`@('L*
M("`@("`@("!R971U<FX@*&ES7V]B:F5C="@D=F%L=64I("8F("AS=')T;VQO
M=V5R*&=E=%]C;&%S<R@D=F%L=64I*2`]/2`B<&5A<E]E<G)O<B(@?'P@:7-?
M<W5B8VQA<W-?;V8H)'9A;'5E+"`B<&5A<E]E<G)O<B(I*2D["B`@("!]"B`@
M("`O+R!]?7T*"B`@("`O+R![>WL@)G)A:7-E17)R;W(H*0H@("`@+RHJ"B`@
M("`@*B!#<F5A=&5S(&5R<F]R+"!S86UE(&%S(&EN(%!%05(@=VET:"!A(&-U
M<W1O;6EZ960@9FQA=F]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@:6YT("`@
M("`@("`@("`@("`@("`@("`@("`@("1C;V1E"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&9I;&4*("`@("`J($!P87)A
M;2`@(&EN="`@("`@("`@("`@("`@("`@("`@("`@("`D;&EN90H@("`@("H@
M0')E='5R;B`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B`F<F%I<V5%<G)O<B@D8V]D92`](%-%4E9)
M0T537U=%051(15)?15)23U)?54Y+3D]73E]%4E)/4BP@)&9I;&4@/2`B(BP@
M)&QI;F4@/2`P*0H@("`@>PH@("`@("`@("\O(%1H:7,@<VAO=6QD(&EM<')O
M=F4@=&AE('!E<F9O<FUA;F-E(&]F('1H92!S8W)I<'0L(&%S(%!%05(@:7,@
M;VYL>2!I;F-L=61E9"P@=VAE;@H@("`@("`@("\O(')E86QL>2!N965D960N
M"B`@("`@("`@:6YC;'5D95]O;F-E(")014%2+G!H<"(["@H@("`@("`@("1M
M97-S86=E(#T@(E-E<G9I8V5S7U=E871H97(B.PH@("`@("`@(&EF("@D9FEL
M92`A/2`B(B`F)B`D;&EN92`^(#`I('L*("`@("`@("`@("`@)&UE<W-A9V4@
M+CT@(B`H(BYB87-E;F%M92@D9FEL92DN(CHB+B1L:6YE+B(I(CL*("`@("`@
M("!]"B`@("`@("`@)&UE<W-A9V4@+CT@(CH@(BY397)V:6-E<U]796%T:&5R
M.CI?97)R;W)-97-S86=E*"1C;V1E*3L*"B`@("`@("`@)&5R<F]R(#T@4$5!
M4CHZ<F%I<V5%<G)O<B@D;65S<V%G92P@)&-O9&4L(%!%05)?15)23U)?4D54
M55).+"!%7U5315)?3D]424-%+"`B4V5R=FEC97-?5V5A=&AE<E]%<G)O<B(L
M(&YU;&PL(&9A;'-E*3L*("`@("`@("!R971U<FX@)&5R<F]R.PH@("`@?0H@
M("`@+R\@?7U]"GT*+R\@?7U]"C\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O<'-A+6AO<F1E+W!E87(O4V5R=FEC97,O5V5A=&AE<B]%:G-E+G!H<```
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`T,C4Q,B`Q,#4Q-30S-#$S
M,B`P,C,R-#4`(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*+RH@=FEM.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S
M:&EF='=I9'1H/30@<V]F='1A8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@
M*B\*"B\J*@H@*B!014%2.CI397)V:6-E<U]796%T:&5R7T5J<V4*("H*("H@
M4$A0('9E<G-I;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER
M:6=H="`H8RD@,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@
M<F5S97)V960N"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U
M<F-E(&%N9"!B:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I
M9FEC871I;VXL(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L
M;&]W:6YG(&-O;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U
M=&EO;G,@;V8@<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O
M<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@
M86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U
M=&EO;G,@:6X@8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E
M(&-O<'ER:6=H="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO
M;G,@86YD('1H92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE
M;G1A=&EO;@H@*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@
M=VET:"!T:&4@9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@
M;V8@=&AE('-O9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U
M=&]R<PH@*B`@(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P
M<F]D=6-T<R!D97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO
M=70@<W!E8VEF:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!4
M2$E3(%-/1E1705)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],
M1$524R!!3D0@0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!2
M15-3($]2($E-4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4
M($Q)34E4140@5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@3452
M0TA!3E1!0DE,2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%52
M4$]310H@*B!!4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%
M($-/4%E224=(5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%
M($9/4B!!3ED@1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!
M3"P@15A%35!,05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.
M0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@
M*B!354)35$E4551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@
M1$%402P@3U(@4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].
M*2!(3U=%5D52($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)
M5%DL(%=(151(15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL
M($]2(%1/4E0@*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*
M("H@05))4TE.1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@
M4T]&5%=!4D4L($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)
M5%D@3T8@4U5#2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G
M;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?
M5V5A=&AE<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X
M0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER
M='H*("H@0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O
M;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R
M<VEO;B`@("`@0U93.B`D260Z($5J<V4N<&AP+'8@,2XR,R`R,#`U+S$Q+S$S
M(#(Q.C4V.C$V(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@
M("`@("`@(&AT='`Z+R]W=W<N96IS92YC;VTO<V5R=FEC97,O=V5A=&AE<E]X
M;6Q?=V5B7W-E<G9I8V5S+FAT;0H@*B!`97AA;7!L92`@("`@97AA;7!L97,O
M96IS92UB87-I8RYP:'`@("`@("`@("`@("`@96IS92UB87-I8RYP:'`*("H@
M0&9I;&5S;W5R8V4*("HO"@IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H
M97(O0V]M;6]N+G!H<"(["@HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE
M<E]%:G-E"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E
M('1O('1H92!S;V%P('-E<G9I8V4@;V8@14I312X@270@<F5T<FEE=F5S"B`J
M(&-U<G)E;G0@=V5A=&AE<B!D871A(&%N9"!F;W)E8V%S=',@8F%S960@;VX@
M<&]S=&%L(&-O9&5S("A:25`I+@H@*@H@*B!#=7)R96YT;'D@=&AI<R!S97)V
M:6-E(&ES(&]N;'D@879A:6QA8FQE(&9O<B!54R!T97)R:71O<GDN"B`J"B`J
M($9O<B!A('=O<FMI;F<@97AA;7!L92P@<&QE87-E('1A:V4@82!L;V]K(&%T
M"B`J("`@("!D;V-S+U-E<G9I8V5S7U=E871H97(O97AA;7!L97,O96IS92UB
M87-I8RYP:'`*("H*("H@0&-A=&5G;W)Y("`@(%=E8B!397)V:6-E<PH@*B!`
M<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`875T:&]R("`@("`@
M06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@*B!`8V]P>7)I9VAT
M("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N<V4@("`@(&AT='`Z
M+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D+6QI8V5N<V4N<&AP
M("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@4F5L96%S93H@,2XT+C`*
M("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O<&%C:V%G92]3
M97)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P.B\O=W=W+F5J
M<V4N8V]M+W-E<G9I8V5S+W=E871H97)?>&UL7W=E8E]S97)V:6-E<RYH=&T*
M("H@0&5X86UP;&4@("`@(&5X86UP;&5S+V5J<V4M8F%S:6,N<&AP("`@("`@
M("`@("`@(&5J<V4M8F%S:6,N<&AP"B`J+PIC;&%S<R!397)V:6-E<U]796%T
M:&5R7T5J<V4@97AT96YD<R!397)V:6-E<U]796%T:&5R7T-O;6UO;B!["@H@
M("`@+R\@>WM[('!R;W!E<G1I97,*("`@("\J*@H@("`@("H@5U-$3"!O8FIE
M8W0L('!R;W9I9&5D(&)Y($5*4T4*("`@("`J"B`@("`@*B!`=F%R("`@("!O
M8FIE8W0@("`@("`@("`@("`@("`@("`@("`@)%]W<V1L"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W=S9&P["@H@("`@+RHJ
M"B`@("`@*B!33T%0(&]B:F5C="!T;R!A8V-E<W,@=V5A=&AE<B!D871A+"!P
M<F]V:61E9"!B>2!%2E-%"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J96-T
M("`@("`@("`@("`@("`@("`@("`@("1?=V5A=&5R4V]A<`H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]W96%T:&5R4V]A<#L*
M("`@("\O('U]?0H*("`@("\O('M[>R!C;VYS=')U8W1O<@H@("`@+RHJ"B`@
M("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@("`J(%)E<75I<F5S(%-/05`@
M=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@("`@("H@0'!A<F%M("`@87)R87D@
M("`@("`@("`@("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`<&%R86T@
M("!M:7AE9"`@("`@("`@("`@("`@("`@("`@("`@)&5R<F]R"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?16IS92@D;W!T
M:6]N<RP@)B1E<G)O<BD*("`@('L*("`@("`@("`D<&5R<F]R(#T@;G5L;#L*
M("`@("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#;VUM;VXH)&]P=&EO
M;G,L("1P97)R;W(I.PH@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1P97)R;W(I*2!["B`@("`@("`@("`@("1E<G)O<B`]("1P97)R
M;W(["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(%]C
M;VYN96-T4V5R=F5R*"D*("`@("\J*@H@("`@("H@0V]N;F5C=',@=&\@=&AE
M(%-/05`@<V5R=F5R(&%N9"!R971R:65V97,@=&AE(%=31$P@9&%T80H@("`@
M("H*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\8F]O;`H@("`@("H@0'1H
M<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].
M1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8V]N;F5C=%-E<G9E<B@I"B`@("!["B`@("`@("`@
M:6YC;'5D95]O;F-E(")33T%0+T-L:65N="YP:'`B.PH@("`@("`@("1T:&ES
M+3Y?=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]W=W<N96IS92YC;VTO
M5V5A=&AE<E-E<G9I8V4O4V5R=FEC92YA<VUX/U=31$PB+"`D=&AI<RT^7VAT
M='!/<'1I;VYS*3L*("`@("`@("!I9B`H:7-S970H)'1H:7,M/E]W<V1L+3YF
M875L="D@)B8@4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=&AI<RT^7W=S
M9&PM/F9A=6QT*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A
M=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=23TY'
M7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*
M"B`@("`@("`@979A;"@D=&AI<RT^7W=S9&PM/F=E;F5R871E06QL4')O>&EE
M<R@I*3L*("`@("`@("!I9B`H(6-L87-S7V5X:7-T<R@B5V5B4V5R=FEC95]3
M97)V:6-E7U-E<G9I8V53;V%P(BDI('L*("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("!]"B`@("`@("`@)'1H:7,M/E]W96%T:&5R4V]A<"`]("9N97<@
M5V5B4V5R=FEC95]397)V:6-E7U-E<G9I8V53;V%P.PH*("`@("`@("!R971U
M<FX@=')U93L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?8VAE8VM,
M;V-A=&EO;DE$*"D*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!I9"!F;W(@
M=F%L:60@=F%L=65S(&%N9"!T:'5S('!R979E;G1S('-I;&QY(')E<75E<W1S
M('1O($5*4T4@<V5R=F5R"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG
M("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!
M4E]%<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)6
M24-%4U]714%42$527T524D]27TY/7TQ/0T%424]."B`@("`@*B!`=&AR;W=S
M("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27TE.5D%,241?
M3$]#051)3TX*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@
M9G5N8W1I;VX@7V-H96-K3&]C871I;VY)1"@D:60I"B`@("!["B`@("`@("`@
M:68@*&ES7V%R<F%Y*"1I9"D@?'P@:7-?;V)J96-T*"1I9"D@?'P@(7-T<FQE
M;B@D:60I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R
M.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#051)
M3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?2!E;'-E:68@*"%C
M='EP95]D:6=I="@D:60I('Q\("AS=')L96XH)&ED*2`A/2`U*2D@>PH@("`@
M("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA3
M15)624-%4U]714%42$527T524D]27TE.5D%,241?3$]#051)3TXL(%]?1DE,
M15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U
M93L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO
M;B@I"B`@("`O*BH*("`@("`J($5*4T4@;V9F97)S(&YO('-E87)C:"!F=6YC
M=&EO;B!T;R!D871E+"!S;R!T:&ES(&9U;F-T:6]N(&ES(&1I<V%B;&5D+@H@
M("`@("H@36%Y8F4@=&AI<R!I<R!T:&4@<&QA8V4@=&\@:6YT97)F86-E('1O
M('-O;64@;VYL:6YE('!O<W1C;V1E('-E<G9I8V4N+BX*("`@("`J"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&QO8V%T
M:6]N"B`@("`@*B!`<&%R86T@("!B;V]L("`@("`@("`@("`@("`@("`@("`@
M("`@)'5S949I<G-T"B`@("`@*B!`<F5T=7)N("!B;V]L"B`@("`@*B!`86-C
M97-S("!P=6)L:6,*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*("`@(&9U
M;F-T:6]N('-E87)C:$QO8V%T:6]N*"1L;V-A=&EO;B`](&YU;&PL("1U<V5&
M:7)S="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N0GE#;W5N
M=')Y*"D*("`@("\J*@H@("`@("H@14I312!O9F9E<G,@;F\@<V5A<F-H(&9U
M;F-T:6]N('1O(&1A=&4L('-O('1H:7,@9G5N8W1I;VX@:7,@9&ES86)L960N
M"B`@("`@*B!-87EB92!T:&ES(&ES('1H92!P;&%C92!T;R!I;G1E<F9A8V4@
M=&\@<V]M92!O;FQI;F4@<&]S=&-O9&4@<V5R=FEC92XN+@H@("`@("H*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D8V]U
M;G1R>0H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C8V5S<R`@<'5B
M;&EC"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC=&EO;B!S
M96%R8VA,;V-A=&EO;D)Y0V]U;G1R>2@D8V]U;G1R>2`](&YU;&PI"B`@("![
M"B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@+R\@?7U]"@H@("`@
M+R\@>WM[(&=E=$QO8V%T:6]N*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!T
M:&4@9&%T82!F;W(@=&AE(&QO8V%T:6]N(&)E;&]N9VEN9R!T;R!T:&4@240*
M("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]C871I;VXH)&ED(#T@(B(I
M"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO
M;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@
M("`@("`@('T*"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N(#T@87)R87DH*3L*
M"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D=V5A=&AE
M<B`]("1T:&ES+3Y?8V%C:&4M/F=E="@D:60L(")W96%T:&5R(BDI*2!["B`@
M("`@("`@("`@("\O($=E="!D871A(&9R;VT@8V%C:&4*("`@("`@("`@("`@
M)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97(["B`@("`@("`@("`@("1L;V-A
M=&EO;E)E='5R;ELB8V%C:&4B72`](")(250B.PH@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("\O($-H96-K+"!I9B!T:&4@=V5A=&AE<E-O87`M3V)J
M96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@4V5R=F5R
M(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@("`@(&EF("@A
M)'1H:7,M/E]W96%T:&5R4V]A<"D@>PH@("`@("`@("`@("`@("`@)'-T871U
M<R`]("1T:&ES+3Y?8V]N;F5C=%-E<G9E<B@I.PH@("`@("`@("`@("`@("`@
M:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@
M("`@("`@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@)'=E871H97(@/2`D
M=&AI<RT^7W=E871H97)3;V%P+3YG971796%T:&5R26YF;R@D:60I.PH*("`@
M("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E871H
M97(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H97(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE<B`]("1W96%T
M:&5R.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2![
M"B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:70*("`@("`@("`@
M("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?5T5!5$A%4E]%
M6%!)4D537U=%051(15(B*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?8V%C
M:&4M/F5X=%-A=F4H)&ED+"`D=&AI<RT^7W=E871H97(L("(B+"`D97AP:7)E
M+"`B=V5A=&AE<B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1L;V-A
M=&EO;E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"B`@("`@
M("`@)&QO8V%T:6]N4F5T=7)N6R)N86UE(ET@/2`D=&AI<RT^7W=E871H97(M
M/DQO8V%T:6]N.PH*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PH@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97(H*0H@("`@
M+RHJ"B`@("`@*B!2971U<FYS('1H92!W96%T:&5R+61A=&$@9F]R('1H92!S
M=7!P;&EE9"!L;V-A=&EO;@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J
M($!R971U<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%
M05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@/2`B
M(BD*("`@('L*("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C:&5C:TQO8V%T
M:6]N240H)&ED*3L*"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES
M17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,[
M"B`@("`@("`@?0H*("`@("`@("`O+R!'970@;W1H97(@9&%T80H@("`@("`@
M("1U;FET<R`@("`]("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&;W)M
M870I.PH*("`@("`@("`D=V5A=&AE<E)E='5R;B`](&%R<F%Y*"D["B`@("`@
M("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D=V5A=&AE<B`]("1T
M:&ES+3Y?8V%C:&4M/F=E="@D:60L(")W96%T:&5R(BDI*2!["B`@("`@("`@
M("`@("\O(%-A;64@<')O8V5D=7)E+BXN"B`@("`@("`@("`@("1T:&ES+3Y?
M=V5A=&AE<B`]("1W96%T:&5R.PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB8V%C:&4B72`](")(250B.PH@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("\O($-H96-K+"!I9B!T:&4@=V5A=&AE<E-O87`M3V)J96-T(&ES('!R
M97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@4V5R=F5R(&%N9"!R971R
M:65V92!T:&4@5T133"!D871A"B`@("`@("`@("`@(&EF("@A)'1H:7,M/E]W
M96%T:&5R4V]A<"D@>PH@("`@("`@("`@("`@("`@)'-T871U<R`]("1T:&ES
M+3Y?8V]N;F5C=%-E<G9E<B@I.PH@("`@("`@("`@("`@("`@:68@*%-E<G9I
M8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@
M("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@+R\@+BXN87,@;&%S="!F=6YC=&EO
M;@H@("`@("`@("`@("`D=V5A=&AE<B`]("1T:&ES+3Y?=V5A=&AE<E-O87`M
M/F=E=%=E871H97));F9O*"1I9"D["@H@("`@("`@("`@("!I9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D=V5A=&AE<BDI('L*("`@("`@("`@("`@
M("`@(')E='5R;B`D=V5A=&AE<CL*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97(["@H@("`@("`@("`@("!I
M9B`H)'1H:7,M/E]C86-H945N86)L960I('L*("`@("`@("`@("`@("`@("\O
M("XN+F%N9"!C86-H92!I=`H@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O
M;G-T86YT*")315)624-%4U]714%42$527T584$E215-?5T5!5$A%4B(I.PH@
M("`@("`@("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92@D:60L("1T
M:&ES+3Y?=V5A=&AE<BP@(B(L("1E>'!I<F4L(")W96%T:&5R(BD["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)'=E871H97)2971U<FY;(F-A8VAE(ET@
M/2`B34E34R(["B`@("`@("`@?0H*("`@("`@("!I9B`H(6ES<V5T*"1C;VUP
M87-S*2D@>PH@("`@("`@("`@("`O+R!997,L($Y.12!A;F0@=&AE(&QI:V5S
M(&%R92!M=6QT:7!L97,@;V8@,C(N-2P@8G5T(&%S('1H92!O=&AE<@H@("`@
M("`@("`@("`O+R!S97)V:6-E<R!R971U<FX@:6YT96=E<G,@9F]R('1H:7,@
M=F%L=64L('1H97-E(&1I<F5C=&EO;G,@87)E"B`@("`@("`@("`@("\O(')O
M=6YD960@=7`*("`@("`@("`@("`@)&-O;7!A<W,@/2!A<G)A>2@*("`@("`@
M("`@("`@("`@(")N;W)T:"(@("`@("`@("`@("`@/3X@87)R87DH(DXB+"`@
M("`@,"DL"B`@("`@("`@("`@("`@("`B;F]R=&@@;F]R=&AE87-T(B`@(#T^
M(&%R<F%Y*").3D4B+"`@,C,I+`H@("`@("`@("`@("`@("`@(FYO<G1H96%S
M="(@("`@("`@("`]/B!A<G)A>2@B3D4B+"`@(#0U*2P*("`@("`@("`@("`@
M("`@(")E87-T(&YO<G1H96%S="(@("`@/3X@87)R87DH(D5.12(L("`V."DL
M"B`@("`@("`@("`@("`@("`B96%S="(@("`@("`@("`@("`@(#T^(&%R<F%Y
M*")%(BP@("`@.3`I+`H@("`@("`@("`@("`@("`@(F5A<W0@<V]U=&AE87-T
M(B`@("`]/B!A<G)A>2@B15-%(BP@,3$S*2P*("`@("`@("`@("`@("`@(")S
M;W5T:&5A<W0B("`@("`@("`@/3X@87)R87DH(E-%(BP@(#$S-2DL"B`@("`@
M("`@("`@("`@("`B<V]U=&@@<V]U=&AE87-T(B`@(#T^(&%R<F%Y*")34T4B
M+"`Q-3@I+`H@("`@("`@("`@("`@("`@(G-O=71H(B`@("`@("`@("`@("`]
M/B!A<G)A>2@B4R(L("`@,3@P*2P*("`@("`@("`@("`@("`@(")S;W5T:"!S
M;W5T:'=E<W0B("`@/3X@87)R87DH(E-35R(L(#(P,RDL"B`@("`@("`@("`@
M("`@("`B<V]U=&AW97-T(B`@("`@("`@(#T^(&%R<F%Y*")35R(L("`R,C4I
M+`H@("`@("`@("`@("`@("`@(G=E<W0@<V]U=&AW97-T(B`@("`]/B!A<G)A
M>2@B5U-7(BP@,C0X*2P*("`@("`@("`@("`@("`@(")W97-T(B`@("`@("`@
M("`@("`@/3X@87)R87DH(E<B+"`@(#(W,"DL"B`@("`@("`@("`@("`@("`B
M=V5S="!N;W)T:'=E<W0B("`@(#T^(&%R<F%Y*")73E<B+"`R.3,I+`H@("`@
M("`@("`@("`@("`@(FYO<G1H=V5S="(@("`@("`@("`]/B!A<G)A>2@B3E<B
M+"`@,S$U*2P*("`@("`@("`@("`@("`@(")N;W)T:"!N;W)T:'=E<W0B("`@
M/3X@87)R87DH(DY.5R(L(#,S."D*("`@("`@("`@("`@*3L*("`@("`@("!]
M"@H@("`@("`@("\O($EN:71I86QI>F4@<V]M92!A<G)A>7,*("`@("`@("`D
M=7!D871E("`@("`@("`@("`@(#T@87)R87DH*3L*("`@("`@("`D=&5M<&5R
M871U<F4@("`@("`@(#T@87)R87DH*3L*("`@("`@("`D9F5L=%1E;7!E<F%T
M=7)E("`@(#T@87)R87DH*3L*("`@("`@("`D=FES:6)I;&ET>2`@("`@("`@
M(#T@87)R87DH*3L*("`@("`@("`D<')E<W-U<F4@("`@("`@("`@(#T@87)R
M87DH*3L*("`@("`@("`D9&5W4&]I;G0@("`@("`@("`@(#T@87)R87DH*3L*
M("`@("`@("`D=79);F1E>"`@("`@("`@("`@(#T@87)R87DH*3L*("`@("`@
M("`D=VEN9"`@("`@("`@("`@("`@(#T@87)R87DH*3L*"B`@("`@("`@:68@
M*'!R96=?;6%T8V@H(B\H7'<K*2`H7&0K*2P@*%QD*RDL(&%T("A<9"LZ7&0K
M(%QW32D@6UY<*%TK*%PH*%M>7"E=*RE<*2D_+R(L("1T:&ES+3Y?=V5A=&AE
M<BT^3&%S=%5P9&%T960L("1U<&1A=&4I*2!["B`@("`@("`@("`@(&EF("AI
M<W-E="@D=7!D871E6S5=*2D@>PH@("`@("`@("`@("`@("`@)'1I;65S=')I
M;F<@/2`D=7!D871E6S9=.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`@("`@)'1I;65S=')I;F<@/2`D=7!D871E6S)=+B(@(BXD=7!D871E
M6S%=+B(@(BXD=7!D871E6S-=+B(@(BXD=7!D871E6S1=+B(@15-4(CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D871E
M(ET@("`@("`@("`@("`](&=M9&%T92AT<FEM*"1T:&ES+3Y?9&%T949O<FUA
M="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T*2P@<W1R=&]T:6UE*"1T:6UE<W1R
M:6YG*2D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'=E871H97)2
M971U<FY;(G5P9&%T92)=("`@("`@("`@("`@/2`B(CL*("`@("`@("!]"B`@
M("`@("`@)'=E871H97)2971U<FY;(G5P9&%T95)A=R)=("`@("`@("`@/2`D
M=&AI<RT^7W=E871H97(M/DQA<W15<&1A=&5D.PH@("`@("`@("1W96%T:&5R
M4F5T=7)N6R)S=&%T:6]N(ET@("`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R
M+3Y297!O<G1E9$%T.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)C;VYD:71I
M;VY)8V]N(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R+3Y)8V]N26YD97@["B`@
M("`@("`@<')E9U]M871C:"@B+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]W96%T
M:&5R+3Y496UP<F%T=7)E+"`D=&5M<&5R871U<F4I.PH@("`@("`@("1W96%T
M:&5R4F5T=7)N6R)T96UP97)A='5R92)=("`@("`@(#T@)'1H:7,M/F-O;G9E
M<G1496UP97)A='5R92@D=&5M<&5R871U<F5;,5TL(")F(BP@)'5N:71S6R)T
M96UP(ETI.PH@("`@("`@('!R96=?;6%T8V@H(B\H+3]<9"LI7$0K+R(L("1T
M:&ES+3Y?=V5A=&AE<BT^1F5E;'-,:6ME+"`D9F5L=%1E;7!E<F%T=7)E*3L*
M("`@("`@("`D=V5A=&AE<E)E='5R;ELB9F5L=%1E;7!E<F%T=7)E(ET@("`]
M("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)&9E;'1496UP97)A='5R95LQ
M72P@(F8B+"`D=6YI='-;(G1E;7`B72D["B`@("`@("`@)'=E871H97)2971U
M<FY;(F-O;F1I=&EO;B)=("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/D9O
M<F5C87-T.PH@("`@("`@(&EF("AP<F5G7VUA=&-H*"(O*%M<9%PN72LI7$0K
M+R(L("1T:&ES+3Y?=V5A=&AE<BT^5FES:6)I;&ET>2P@)'9I<VEB:6QI='DI
M*2!["B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)V:7-I8FEL:71Y(ET@
M("`@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1V:7-I8FEL:71Y6S%=+"`B
M<VTB+"`D=6YI='-;(G9I<R)=*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB=FES:6)I;&ET>2)=("`@(#T@=')I;2@D
M=&AI<RT^7W=E871H97(M/E9I<VEB:6QI='DI.PH@("`@("`@('T*("`@("`@
M("!P<F5G7VUA=&-H*"(O*%M<9%PN72LI(&EN8VAE<R!A;F0@*%QW*RDO(BP@
M)'1H:7,M/E]W96%T:&5R+3Y0<F5S<W5R92P@)'!R97-S=7)E*3L*("`@("`@
M("`D=V5A=&AE<E)E='5R;ELB<')E<W-U<F4B72`@("`@("`@("`]("1T:&ES
M+3YC;VYV97)T4')E<W-U<F4H)'!R97-S=7)E6S%=+"`B:6XB+"`D=6YI='-;
M(G!R97,B72D["B`@("`@("`@)'=E871H97)2971U<FY;(G!R97-S=7)E5')E
M;F0B72`@("`@/2`D<')E<W-U<F5;,ET["B`@("`@("`@<')E9U]M871C:"@B
M+R@M/UQD*RE<1"LO(BP@)'1H:7,M/E]W96%T:&5R+3Y$97=0;VEN="P@)&1E
M=U!O:6YT*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB9&5W4&]I;G0B72`@
M("`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)&1E=U!O:6YT
M6S%=+"`B9B(L("1U;FET<ULB=&5M<")=*3L*("`@("`@("!P<F5G7VUA=&-H
M*"(O*%QD*RD@*%QW*RDO(BP@)'1H:7,M/E]W96%T:&5R+3Y55DEN9&5X+"`D
M=79);F1E>"D["B`@("`@("`@)'=E871H97)2971U<FY;(G5V26YD97@B72`@
M("`@("`@("`@/2`D=79);F1E>%LQ73L*("`@("`@("`D=V5A=&AE<E)E='5R
M;ELB=79497AT(ET@("`@("`@("`@("`]("1U=DEN9&5X6S)=.PH@("`@("`@
M("1W96%T:&5R4F5T=7)N6R)H=6UI9&ET>2)=("`@("`@("`@(#T@<W1R7W)E
M<&QA8V4H(B4B+"`B(BP@)'1H:7,M/E]W96%T:&5R+3Y(=6UI9&ET>2D["B`@
M("`@("`@:68@*'!R96=?;6%T8V@H(B]&<F]M('1H92`H6UQW7"!=*RD@870@
M*%M<9%PN72LI("AG=7-T:6YG('1O("A;7&1<+ETK*2`I/VUP:"\B+"`D=&AI
M<RT^7W=E871H97(M/E=I;F0L("1W:6YD*2D@>PH@("`@("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB=VEN9")=("`@("`@("`@("`@("`]("1T:&ES+3YC;VYV
M97)T4W!E960H)'=I;F1;,ETL(")M<&@B+"`D=6YI='-;(G=I;F0B72D["B`@
M("`@("`@("`@(&EF("AI<W-E="@D=VEN9%LT72DI('L*("`@("`@("`@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1W5S=")=("`@("`@/2`D=&AI<RT^
M8V]N=F5R=%-P965D*"1W:6YD6S1=+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)W
M:6YD1&5G<F5E<R)=("`@("`@(#T@)&-O;7!A<W-;<W1R=&]L;W=E<B@D=VEN
M9%LQ72E=6S%=.PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$1I
M<F5C=&EO;B)=("`@("`]("1C;VUP87-S6W-T<G1O;&]W97(H)'=I;F1;,5TI
M75LP73L*("`@("`@("!](&5L<V5I9B`H<W1R=&]L;W=E<B@D=&AI<RT^7W=E
M871H97(M/E=I;F0I(#T](")C86QM(BD@>PH@("`@("`@("`@("`D=V5A=&AE
M<E)E='5R;ELB=VEN9")=("`@("`@("`@(#T@,#L*("`@("`@("`@("`@)'=E
M871H97)2971U<FY;(G=I;F1$96=R965S(ET@("`](#`["B`@("`@("`@("`@
M("1W96%T:&5R4F5T=7)N6R)W:6YD1&ER96-T:6]N(ET@/2`B0T%,32(["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)'=E871H97)2971U<FX["B`@("!]
M"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R96-A<W0H*0H@("`@+RHJ
M"B`@("`@*B!'970@=&AE(&9O<F5C87-T(&9O<B!T:&4@;F5X="!D87ES"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1I;G0*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@("`@
M("`@("`@("`D9&%Y<R`@("`@("`@("`@5F%L=65S(&)E='=E96X@,2!A;F0@
M.0H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("1U;FET<T9O<FUA=`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A
M>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C8V5S<R`@
M<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$9O<F5C87-T*"1I9"`]
M("(B+"`D9&%Y<R`](#(L("1U;FET<T9O<FUA="`]("(B*0H@("`@>PH@("`@
M("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*
M("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S
M*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"B`@
M("`@("`@:68@*"%I;E]A<G)A>2@D9&%Y<RP@<F%N9V4H,2P@.2DI*2!["B`@
M("`@("`@("`@("1D87ES(#T@,CL*("`@("`@("!]"@H@("`@("`@("\O($=E
M="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E=%5N
M:71S1F]R;6%T*"1U;FET<T9O<FUA="D["@H@("`@("`@("1F;W)E8V%S=%)E
M='5R;B`](&%R<F%Y*"D["B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B
M;&5D("8F("@D9F]R96-A<W0@/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B
M9F]R96-A<W0B*2DI('L*("`@("`@("`@("`@+R\@4V%M92!P<F]C961U<F4N
M+BX*("`@("`@("`@("`@)'1H:7,M/E]F;W)E8V%S="`]("1F;W)E8V%S=#L*
M("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=(#T@(DA)5"([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@0VAE8VLL(&EF('1H
M92!W96%T:&5R4V]A<"U/8FIE8W0@:7,@<')E<V5N="X@268@;F]T+"!C;VYN
M96-T('1O('1H92!397)V97(@86YD(')E=')I979E('1H92!71%-,(&1A=&$*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^7W=E871H97)3;V%P*2!["B`@("`@
M("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C;VYN96-T4V5R=F5R*"D[
M"B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<W1A
M='5S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R`N+BYA<R!L87-T(&9U;F-T:6]N"B`@("`@("`@("`@("1F;W)E
M8V%S="`]("1T:&ES+3Y?=V5A=&AE<E-O87`M/D=E=$YI;F5$87E&;W)E8V%S
M=$EN9F\H)&ED*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1F;W)E8V%S="DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B`D9F]R96-A<W0["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES
M+3Y?9F]R96-A<W0@/2`D9F]R96-A<W0["@H@("`@("`@("`@("!I9B`H)'1H
M:7,M/E]C86-H945N86)L960I('L*("`@("`@("`@("`@("`@("\O("XN+F%N
M9"!C86-H92!I=`H@("`@("`@("`@("`@("`@)&5X<&ER92`](&-O;G-T86YT
M*")315)624-%4U]714%42$527T584$E215-?1D]214-!4U0B*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H)&ED+"`D=&AI<RT^
M7V9O<F5C87-T+"`B(BP@)&5X<&ER92P@(F9O<F5C87-T(BD["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=(#T@
M(DU)4U,B.PH@("`@("`@('T*"B`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)D
M87ES(ET@("`](&%R<F%Y*"D["@H@("`@("`@("\O($EN:71I86QI>F4@<V]M
M92!A<G)A>7,*("`@("`@("`D=&5M<&5R871U<F5(:6=H("`@(#T@87)R87DH
M*3L*("`@("`@("`D=&5M<&5R871U<F5,;W<@("`@(#T@87)R87DH*3L*"B`@
M("`@("`@9F]R("@D:2`](#$[("1I(#P]("1D87ES.R`D:2LK*2!["B`@("`@
M("`@("`@('!R96=?;6%T8V@H(B\H+3]<9"LI7$0K+R(L("1T:&ES+3Y?9F]R
M96-A<W0M/GLB1&%Y(BXD:7TM/DAI9V@L("1T96UP97)A='5R94AI9V@I.PH@
M("`@("`@("`@("!P<F5G7VUA=&-H*"(O*"T_7&0K*5Q$*R\B+"`D=&AI<RT^
M7V9O<F5C87-T+3Y[(D1A>2(N)&E]+3Y,;W<L("1T96UP97)A='5R94QO=RD[
M"B`@("`@("`@("`@("1D87D@/2!A<G)A>2@*("`@("`@("`@("`@("`@(")T
M96UP97)T=7)E2&EG:"(@/3X@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D
M=&5M<&5R871U<F5(:6=H6S%=+"`B9B(L("1U;FET<ULB=&5M<")=*2P*("`@
M("`@("`@("`@("`@(")T96UP97)A='5R94QO=R(@/3X@)'1H:7,M/F-O;G9E
M<G1496UP97)A='5R92@D=&5M<&5R871U<F5,;W=;,5TL(")F(BP@)'5N:71S
M6R)T96UP(ETI+`H@("`@("`@("`@("`@("`@(F1A>2(@/3X@87)R87DH"B`@
M("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;B(@("`@(#T^("1T:&ES+3Y?
M9F]R96-A<W0M/GLB1&%Y(BXD:7TM/D9O<F5C87-T+`H@("`@("`@("`@("`@
M("`@("`@(")C;VYD:71I;VY)8V]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3Y[
M(D1A>2(N)&E]+3Y)8V]N26YD97@L"B`@("`@("`@("`@("`@("`@("`@(G!R
M96-I<&ET871I;VXB(#T^('1R:6TH<W1R7W)E<&QA8V4H(B4B+"`B(BP@)'1H
M:7,M/E]F;W)E8V%S="T^>R)$87DB+B1I?2T^4')E8VEP0VAA;F-E*2D*("`@
M("`@("`@("`@("`@("D*("`@("`@("`@("`@*3L*"B`@("`@("`@("`@("1F
M;W)E8V%S=%)E='5R;ELB9&%Y<R)=6UT@/2`D9&%Y.PH@("`@("`@('T*"B`@
M("`@("`@<F5T=7)N("1F;W)E8V%S=%)E='5R;CL*("`@('T*("`@("\O('U]
M?0I]"B\O('U]?0H_/@H`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O<'-A+6AO<F1E+W!E87(O
M4V5R=FEC97,O5V5A=&AE<B]';&]B86QW96%T:&5R+G!H<```````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`T-C0T,"`Q,#4Q-30S-#$S,B`P,C4Q-#,`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````/#]P:'`*+RH@=FEM
M.B!S970@97AP86YD=&%B('1A8G-T;W`]-"!S:&EF='=I9'1H/30@<V]F='1A
M8G-T;W`]-"!F;VQD;65T:&]D/6UA<FME<CH@*B\*"B\J*@H@*B!014%2.CI3
M97)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(*("H*("H@4$A0('9E<G-I
M;VYS(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@
M,C`P-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N
M"B`J"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B
M:6YA<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL
M(&%R92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O
M;F1I=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@
M<V]U<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N
M;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@
M8FEN87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H
M="!N;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H
M92!F;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@
M*B`@(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@
M9&ES=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O
M9G1W87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@
M(&UA>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D
M97)I=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF
M:6,@<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E17
M05)%($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@
M0T].5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-
M4$Q)140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@
M5$\L(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,
M2519($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!
M4D4@1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(
M5"!/5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@
M1$E214-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,
M05)9+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@
M0E54($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4
M551%($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@
M4%)/1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52
M($-!55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(
M15(@24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@
M*$E.0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.
M1R!)3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L
M($5614X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#
M2"!$04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G;W)Y("`@(%=E
M8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@
M*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T
M/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI
M8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O
M8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@
M0U93.B`D260Z($=L;V)A;'=E871H97(N<&AP+'8@,2XS-"`R,#`U+S$Q+S$S
M(#(Q.C4V.C$V(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@
M("`@("`@(&AT='`Z+R]W=W<N8V%P97-C:65N8V4N8V]M+W=E8G-E<G9I8V5S
M+V=L;V)A;'=E871H97(O:6YD97@N<VAT;6P*("H@0&5X86UP;&4@("`@(&5X
M86UP;&5S+V=L;V)A;'=E871H97(M8F%S:6,N<&AP("`@(&=L;V)A;'=E871H
M97(M8F%S:6,N<&AP"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E
M(")397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PH*+R\@>WM[(&-L87-S
M(%-E<G9I8V5S7U=E871H97)?1VQO8F%L=V5A=&AE<@HO*BH*("H@5&AI<R!C
M;&%S<R!A8W1S(&%S(&%N(&EN=&5R9F%C92!T;R!T:&4@<V]A<"!S97)V:6-E
M(&]F(&-A<&5S8VEE;F-E+F-O;2X*("H@270@<V5A<F-H97,@9F]R(&=I=F5N
M(&QO8V%T:6]N<R!A;F0@<F5T<FEE=F5S(&-U<G)E;G0@=V5A=&AE<B!D871A
M+@H@*@H@*B!';&]B86Q796%T:&5R(&ES(&$@4T]!4"!F<F]N=&5N9"!F;W(@
M345405(@9&%T82P@<')O=FED960@8GD@0V%P95-C:65N8V4N"B`J($EF('EO
M=2!W86YT('1O('5S92!-151!4BP@>6]U('-H;W5L9"!T<GD@=&AI<R!C;&%S
M<R!F:7)S="P@87,@:70@:7,@;75C:`H@*B!M;W)E(&-O;69O<G1A8FQE("AA
M;F0@86QS;R!A(&)I="!F87-T97(I('1H86X@=&AE(&YA=&EV92!-151!4BUC
M;&%S<PH@*B!P<F]V:61E9"!B>2!T:&ES('!A8VMA9V4N($]N('1H92!O=&AE
M<B!H86YD+"!T:&ES('-E<G9I8V4@=V]N)W0@<W5P<&QY"B`J(%1!1G,L('1H
M92!F;W)E8V%S="!S>7-T96T@86-C;VUP86YY:6YG($U%5$%2+"!S;R!Y;W4@
M:&%V92!T;R!M86ME"B`J('1H92!C86QL(&AE<F4N+BX*("H*("H@1F]R(&$@
M=V]R:VEN9R!E>&%M<&QE+"!P;&5A<V4@=&%K92!A(&QO;VL@870*("H@("`@
M(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]G;&]B86QW96%T:&5R
M+6)A<VEC+G!H<`H@*@H@*@H@*B!`8V%T96=O<GD@("`@5V5B(%-E<G9I8V5S
M"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T:&5R"B`J($!A=71H;W(@
M("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T<"YN970^"B`J($!C;W!Y
M<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@*B!`;&EC96YS92`@("`@
M:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E;G-E<R]B<V0M;&EC96YS
M92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N("`@("!296QE87-E.B`Q
M+C0N,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE="]P86-K
M86=E+U-E<G9I8V5S7U=E871H97(*("H@0&QI;FL@("`@("`@(&AT='`Z+R]W
M=W<N8V%P97-C:65N8V4N8V]M+W=E8G-E<G9I8V5S+V=L;V)A;'=E871H97(O
M:6YD97@N<VAT;6P*("H@0&5X86UP;&4@("`@(&5X86UP;&5S+V=L;V)A;'=E
M871H97(M8F%S:6,N<&AP("`@(&=L;V)A;'=E871H97(M8F%S:6,N<&AP"B`J
M+PIC;&%S<R!397)V:6-E<U]796%T:&5R7T=L;V)A;'=E871H97(@97AT96YD
M<R!397)V:6-E<U]796%T:&5R7T-O;6UO;B!["@H@("`@+R\@>WM[('!R;W!E
M<G1I97,*("`@("\J*@H@("`@("H@5U-$3"!O8FIE8W0L('!R;W9I9&5D(&)Y
M($-A<&538VEE;F-E"B`@("`@*@H@("`@("H@0'9A<B`@("`@;V)J96-T("`@
M("`@("`@("`@("`@("`@("`@("1?=W-D;`H@("`@("H@0&%C8V5S<R`@<')I
M=F%T90H@("`@("HO"B`@("!V87(@)%]W<V1L.PH*("`@("\J*@H@("`@("H@
M4T]!4"!O8FIE8W0@=&\@86-C97-S('-T871I;VX@9&%T82P@<')O=FED960@
M8GD@0V%P95-C:65N8V4*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE8W0@
M("`@("`@("`@("`@("`@("`@("`@)%]S=&%T:6]N4V]A<`H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]S=&%T:6]N4V]A<#L*
M"B`@("`O*BH*("`@("`J(%-/05`@;V)J96-T('1O(&%C8V5S<R!W96%T:&5R
M(&1A=&$L('!R;W9I9&5D(&)Y($-A<&538VEE;F-E"B`@("`@*@H@("`@("H@
M0'9A<B`@("`@(&]B:F5C="`@("`@("`@("`@("`@("`@("`@("`D7W=E871H
M97)3;V%P"B`@("`@*B!`86-C97-S("`@<')I=F%T90H@("`@("HO"B`@("!V
M87(@)%]W96%T:&5R4V]A<#L*("`@("\O('U]?0H*("`@("\O('M[>R!C;VYS
M=')U8W1O<@H@("`@+RHJ"B`@("`@*B!#;VYS=')U8W1O<@H@("`@("H*("`@
M("`J(%)E<75I<F5S(%-/05`@=&\@8F4@:6YS=&%L;&5D"B`@("`@*@H@("`@
M("H@0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1O<'1I
M;VYS"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@("`@("`@("`@("`@("`@
M("`@)&5R<F]R"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`
M=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@
M*B\*("`@(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?1VQO8F%L=V5A=&AE
M<B@D;W!T:6]N<RP@)B1E<G)O<BD*("`@('L*("`@("`@("`D<&5R<F]R(#T@
M;G5L;#L*("`@("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#;VUM;VXH
M)&]P=&EO;G,L("1P97)R;W(I.PH@("`@("`@(&EF("A397)V:6-E<U]796%T
M:&5R.CII<T5R<F]R*"1P97)R;W(I*2!["B`@("`@("`@("`@("1E<G)O<B`]
M("1P97)R;W(["B`@("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@
M>WM[(%]C;VYN96-T4V5R=F5R*"D*("`@("\J*@H@("`@("H@0V]N;F5C=',@
M=&\@=&AE(%-/05`@<V5R=F5R(&%N9"!R971R:65V97,@=&AE(%=31$P@9&%T
M80H@("`@("H*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\8F]O;`H@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]74D].1U]315)615)?1$%400H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@
M("`@("HO"B`@("!F=6YC=&EO;B!?8V]N;F5C=%-E<G9E<B@I"B`@("!["B`@
M("`@("`@:6YC;'5D95]O;F-E(")33T%0+T-L:65N="YP:'`B.PH@("`@("`@
M("1T:&ES+3Y?=W-D;"`](&YE=R!33T%07U=31$PH(FAT='`Z+R]L:79E+F-A
M<&5S8VEE;F-E+F-O;2]W<V1L+T=L;V)A;%=E871H97(N=W-D;"(L("1T:&ES
M+3Y?:'1T<$]P=&EO;G,I.PH@("`@("`@(&EF("AI<W-E="@D=&AI<RT^7W=S
M9&PM/F9A=6QT*2`F)B!397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1T:&ES
M+3Y?=W-D;"T^9F%U;'0I*2!["B`@("`@("`@("`@("1E<G)O<B`](%-E<G9I
M8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*"B`@("`@("`@979A;"@D=&AI
M<RT^7W=S9&PM/F=E;F5R871E06QL4')O>&EE<R@I*3L*("`@("`@("!I9B`H
M(6-L87-S7V5X:7-T<R@B5V5B4V5R=FEC95]';&]B86Q796%T:&5R7U-T871I
M;VY);F9O(BD@?'P@(6-L87-S7V5X:7-T<R@B5V5B4V5R=FEC95]';&]B86Q7
M96%T:&5R7T=L;V)A;%=E871H97(B*2D@>PH@("`@("`@("`@("`D97)R;W(@
M/2!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(
M15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?<W1A=&EO;E-O87`@/2`F;F5W(%=E8E-E<G9I8V5?1VQO8F%L5V5A
M=&AE<E]3=&%T:6]N26YF;SL*("`@("`@("`D=&AI<RT^7W=E871H97)3;V%P
M(#T@)FYE=R!796)397)V:6-E7T=L;V)A;%=E871H97)?1VQO8F%L5V5A=&AE
M<CL*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@
M("`O+R![>WL@7V-H96-K3&]C871I;VY)1"@I"B`@("`O*BH*("`@("`J($-H
M96-K<R!T:&4@:60@9F]R('9A;&ED('9A;'5E<R!A;F0@=&AU<R!P<F5V96YT
M<R!S:6QL>2!R97%U97-T<R!T;PH@("`@("H@1VQO8F%L5V5A=&AE<B!S97)V
M97(*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?
M15)23U)?3D]?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3@H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE
M8VM,;V-A=&EO;DE$*"1I9"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH
M)&ED*2!\?"!I<U]O8FIE8W0H)&ED*2!\?"`A<W1R;&5N*"1I9"DI('L*("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3BP@7U]&24Q%7U\L
M(%]?3$E.15]?*3L*("`@("`@("!](&5L<V5I9B`H)'1H:7,M/E]S=&%T:6]N
M4V]A<"T^:7-686QI9$-O9&4H)&ED*2`]/3T@9F%L<V4I('L*("`@("`@("`@
M("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#
M15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH*0H@
M("`@+RHJ"B`@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO8V%T:6]N
M+"!R971U<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<PH@("`@("H@
M;W(@<VEN9VQE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0'!A<F%M("`@
M8F]O;"`@("`@("`@("`@("`@("`@("`@("`@("1U<V5&:7)S="`@("`@("!)
M9B!S970L(&9I<G-T($E$(&]F(')E<W5L="UA<G)A>2!I<R!R971U<FYE9`H@
M("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@
M("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E87)C
M:$QO8V%T:6]N*"1L;V-A=&EO;BP@)'5S949I<G-T(#T@9F%L<V4I"B`@("![
M"B`@("`@("`@+R\@0VAE8VLL(&EF('1H92!S=&%T:6]N4V]A<"U/8FIE8W0@
M:7,@<')E<V5N="X@268@;F]T+"!C;VYN96-T('1O('1H92!397)V97(@86YD
M(')E=')I979E('1H92!71%-,(&1A=&$*("`@("`@("!I9B`H(21T:&ES+3Y?
M<W1A=&EO;E-O87`I('L*("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?
M8V]N;F5C=%-E<G9E<B@I.PH@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@<F5T
M=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("\O($=E="!S96%R8V@@9&%T82!F<F]M('-E<G9E<B!A;F0@=6YS97)I86QI
M>F4*("`@("`@("`D<V5A<F-H(#T@)'1H:7,M/E]S=&%T:6]N4V]A<"T^<V5A
M<F-H0GE.86UE*"1L;V-A=&EO;BD["@H@("`@("`@(&EF("A397)V:6-E<U]7
M96%T:&5R.CII<T5R<F]R*"1S96%R8V@I*2!["B`@("`@("`@("`@(')E='5R
M;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(
M15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?
M7RD["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@:68@*"%I<U]A<G)A
M>2@D<V5A<F-H*2!\?"`A<VEZ96]F*"1S96%R8V@I*2!["B`@("`@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?
M+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("!I9B`H(21U<V5&:7)S="`F)B`H<VEZ96]F*"1S96%R8V@I(#X@,2DI
M('L*("`@("`@("`@("`@("`@("`@("`D<V5A<F-H4F5T=7)N(#T@87)R87DH
M*3L*("`@("`@("`@("`@("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE
M;V8H)'-E87)C:"D[("1I*RLI('L*("`@("`@("`@("`@("`@("`@("`@("`@
M)'-E87)C:%)E='5R;ELD<V5A<F-H6R1I72T^:6-A;UT@/2`D<V5A<F-H6R1I
M72T^;F%M92XB+"`B+B1S96%R8VA;)&E=+3YC;W5N=')Y.PH@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@('T@96QS96EF("@D=7-E1FER
M<W0@?'P@*'-I>F5O9B@D<V5A<F-H*2`]/2`Q*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1S96%R8VA2971U<FX@/2`D<V5A<F-H6S!=+3YI8V%O.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@
M("!R971U<FX@)'-E87)C:%)E='5R;CL*("`@('T*("`@("\O('U]?0H*("`@
M("\O('M[>R!S96%R8VA,;V-A=&EO;D)Y0V]U;G1R>2@I"B`@("`O*BH*("`@
M("`J(%)E='5R;G,@241S('=I=&@@;&]C871I;VXM;F%M92!F;W(@82!G:79E
M;B!C;W5N=')Y(&]R(&%L;"!A=F%I;&%B;&4*("`@("`J(&-O=6YT<FEE<RP@
M:68@;F\@=F%L=64@=V%S(&=I=F5N"B`@("`@*@H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1C;W5N=')Y"B`@("`@*B!`
M<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%2
M7T5R<F]R.CI315)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$
M051!"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%4
M2$527T524D]27U5.2TY/5TY?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!U
M8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA,;V-A=&EO;D)Y0V]U
M;G1R>2@D8V]U;G1R>2`]("(B*0H@("`@>PH@("`@("`@("\O(%)E='5R;B!T
M:&4@879A:6QA8FQE(&-O=6YT<FEE<R!A<R!N;R!C;W5N=')Y('=A<R!G:79E
M;@H@("`@("`@(&EF("@A<W1R;&5N*"1C;W5N=')Y*2D@>PH@("`@("`@("`@
M("`D8V]U;G1R:65S(#T@)'1H:7,M/E]S=&%T:6]N4V]A<"T^;&ES=$-O=6YT
M<FEE<R@I.PH@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D8V]U;G1R:65S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E
M<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%
M4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!R971U<FX@)&-O=6YT<FEE<SL*
M("`@("`@("!]"@H@("`@("`@("\O($-H96-K+"!I9B!T:&4@<W1A=&EO;E-O
M87`M3V)J96-T(&ES('!R97-E;G0N($EF(&YO="P@8V]N;F5C="!T;R!T:&4@
M4V5R=F5R(&%N9"!R971R:65V92!T:&4@5T133"!D871A"B`@("`@("`@:68@
M*"$D=&AI<RT^7W-T871I;VY3;V%P*2!["B`@("`@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@:68@*%-E
M<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@
M("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`O+R!.;W<@9F]R('1H92!R96%L('-E87)C:`H@("`@("`@
M("1C;W5N=')Y3&]C<R`]("1T:&ES+3Y?<W1A=&EO;E-O87`M/G-E87)C:$)Y
M0V]U;G1R>2@D8V]U;G1R>2D["B`@("`@("`@+R\@0VAE8VL@<F5S=6QT(&9O
M<B!V86QI9&ET>0H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1C;W5N=')Y3&]C<RDI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I
M8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1C;W5N=')Y3&]C<RDI('L*("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].+"!?7T9)
M3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@0V]N<W1R
M=6-T('1H92!R97-U;'0*("`@("`@("`D;&]C871I;VYS(#T@87)R87DH*3L*
M("`@("`@("!F;W)E86-H("@D8V]U;G1R>4QO8W,@87,@)&QO8V%T:6]N*2![
M"B`@("`@("`@("`@("1L;V-A=&EO;G-;)&QO8V%T:6]N+3YI8V%O72`]("1L
M;V-A=&EO;BT^;F%M92XB+"`B+B1L;V-A=&EO;BT^8V]U;G1R>3L*("`@("`@
M("!]"B`@("`@("`@87-O<G0H)&QO8V%T:6]N<RD["@H@("`@("`@(')E='5R
M;B`D;&]C871I;VYS.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E
M=$QO8V%T:6]N*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@9&%T82!F
M;W(@=&AE(&QO8V%T:6]N(&)E;&]N9VEN9R!T;R!T:&4@240*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED
M"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR
M;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@9V5T3&]C871I;VXH)&ED(#T@(B(I"B`@("!["B`@
M("`@("`@)'-T871U<R`]("1T:&ES+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D[
M"@H@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T
M=7,I*2!["B`@("`@("`@("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@('T*
M"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N(#T@87)R87DH*3L*"B`@("`@("`@
M:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("@D;&]C871I;VX@/2`D=&AI
M<RT^7V-A8VAE+3YG970H(D=7+2(N)&ED+"`B;&]C871I;VXB*2DI('L*("`@
M("`@("`@("`@+R\@1V5T(&1A=&$@9G)O;2!C86-H90H@("`@("`@("`@("`D
M=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T:6]N.PH@("`@("`@("`@("`D;&]C
M871I;VY2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!#:&5C:RP@:68@=&AE('-T871I;VY3;V%P+4]B
M:F5C="!I<R!P<F5S96YT+B!)9B!N;W0L(&-O;FYE8W0@=&\@=&AE(%-E<G9E
M<B!A;F0@<F5T<FEE=F4@=&AE(%=$4TP@9&%T80H@("`@("`@("`@("!I9B`H
M(21T:&ES+3Y?<W1A=&EO;E-O87`I('L*("`@("`@("`@("`@("`@("1S=&%T
M=7,@/2`D=&AI<RT^7V-O;FYE8W1397)V97(H*3L*("`@("`@("`@("`@("`@
M(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@
M("`@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1L;V-A=&EO;B`]
M("1T:&ES+3Y?<W1A=&EO;E-O87`M/F=E=%-T871I;VXH)&ED*3L*"B`@("`@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1L;V-A=&EO
M;BDI('L*("`@("`@("`@("`@("`@(')E='5R;B`D;&]C871I;VX["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D;&]C
M871I;VX["@H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L960I
M('L*("`@("`@("`@("`@("`@("\O("XN+F%N9"!C86-H92!I=`H@("`@("`@
M("`@("`@("`@)&5X<&ER92`](&-O;G-T86YT*")315)624-%4U]714%42$52
M7T584$E215-?3$]#051)3TXB*3L*("`@("`@("`@("`@("`@("1T:&ES+3Y?
M8V%C:&4M/F5X=%-A=F4H(D=7+2(N)&ED+"`D=&AI<RT^7VQO8V%T:6]N+"`B
M(BP@)&5X<&ER92P@(FQO8V%T:6]N(BD["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@("`@
M("`@('T*("`@("`@("!I9B`H<W1R;&5N*"1T:&ES+3Y?;&]C871I;VXM/G)E
M9VEO;BD@)B8@<W1R;&5N*"1T:&ES+3Y?;&]C871I;VXM/F-O=6YT<GDI*2![
M"B`@("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M/E]L;V-A=&EO;BT^;F%M
M92XB+"`B+B1T:&ES+3Y?;&]C871I;VXM/G)E9VEO;BXB+"`B+B1T:&ES+3Y?
M;&]C871I;VXM/F-O=6YT<GD["B`@("`@("`@?2!E;'-E:68@*'-T<FQE;B@D
M=&AI<RT^7VQO8V%T:6]N+3YC;W5N=')Y*2D@>PH@("`@("`@("`@("`D;&]C
M;F%M92`]("1T:&ES+3Y?;&]C871I;VXM/FYA;64N(BP@(BXD=&AI<RT^7VQO
M8V%T:6]N+3YC;W5N=')Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1L;V-N86UE(#T@)'1H:7,M/E]L;V-A=&EO;BT^;F%M93L*("`@("`@("!]
M"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)N86UE(ET@("`@("`]("1L;V-N
M86UE.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB;&%T:71U9&4B72`@/2`D
M=&AI<RT^7VQO8V%T:6]N+3YL871I='5D93L*("`@("`@("`D;&]C871I;VY2
M971U<FY;(FQO;F=I='5D92)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^;&]N9VET
M=61E.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<FES92)=("`@/2!D
M871E*"1T:&ES+3Y?=&EM949O<FUA="P@)'1H:7,M/F-A;&-U;&%T95-U;E)I
M<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)34535$%-4"P@)'1H
M:7,M/E]L;V-A=&EO;BT^;&%T:71U9&4L("1T:&ES+3Y?;&]C871I;VXM/FQO
M;F=I='5D92P@4T525DE#15-?5T5!5$A%4E]354Y&54Y#4U]354Y225-%7UI%
M3DE42"P@,"P@=')U92DI.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N
M<V5T(ET@("`@/2!D871E*"1T:&ES+3Y?=&EM949O<FUA="P@)'1H:7,M/F-A
M;&-U;&%T95-U;E)I<V53970H9VUM:W1I;64H*2P@4U5.1E5.0U-?4D547U1)
M34535$%-4"P@)'1H:7,M/E]L;V-A=&EO;BT^;&%T:71U9&4L("1T:&ES+3Y?
M;&]C871I;VXM/FQO;F=I='5D92P@4T525DE#15-?5T5!5$A%4E]354Y&54Y#
M4U]354Y3151?6D5.251(+"`@,"P@9F%L<V4I*3L*("`@("`@("`D;&]C871I
M;VY2971U<FY;(F5L979A=&EO;B)=(#T@)'1H:7,M/E]L;V-A=&EO;BT^96QE
M=F%T:6]N.PH*("`@("`@("!R971U<FX@)&QO8V%T:6]N4F5T=7)N.PH@("`@
M?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H97(H*0H@("`@+RHJ
M"B`@("`@*B!2971U<FYS('1H92!W96%T:&5R+61A=&$@9F]R('1H92!S=7!P
M;&EE9"!L;V-A=&EO;@H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D:60*("`@("`J($!P87)A;2`@('-T<FEN
M9R`@("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J($!R
M971U<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J($!T:')O=W,@(%!%05)?
M17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC
M=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@/2`B(BD*
M("`@('L*("`@("`@("!S=&%T:6,@)&-L;W5D<SL*("`@("`@("!I9B`H(6ES
M<V5T*"1C;&]U9',I*2!["B`@("`@("`@("`@("1C;&]U9',@("`@/2!A<G)A
M>2@*("`@("`@("`@("`@("`@(")S:WD@8VQE87(B+`H@("`@("`@("`@("`@
M("`@(F9E=R(L"B`@("`@("`@("`@("`@("`B<V-A='1E<F5D(BP*("`@("`@
M("`@("`@("`@(")B<F]K96XB+`H@("`@("`@("`@("`@("`@(F]V97)C87-T
M(BP*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("\O($=E
M="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E=%5N
M:71S1F]R;6%T*"1U;FET<T9O<FUA="D["@H@("`@("`@("1W96%T:&5R4F5T
M=7)N(#T@87)R87DH*3L*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L
M960@)B8@*"1W96%T:&5R(#T@)'1H:7,M/E]C86-H92T^9V5T*")'5RTB+B1I
M9"P@(G=E871H97(B*2DI('L*("`@("`@("`@("`@+R\@4V%M92!P<F]C961U
M<F4N+BX*("`@("`@("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97([
M"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@(DA)5"([
M"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@0VAE8VLL(&EF('1H
M92!W96%T:&5R4V]A<"U/8FIE8W0@:7,@<')E<V5N="X@268@;F]T+"!C;VYN
M96-T('1O('1H92!397)V97(@86YD(')E=')I979E('1H92!71%-,(&1A=&$*
M("`@("`@("`@("`@:68@*"$D=&AI<RT^7W=E871H97)3;V%P*2!["B`@("`@
M("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]C;VYN96-T4V5R=F5R*"D[
M"B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O
M<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B`D<W1A
M='5S.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`O+R`N+BYA<R!L87-T(&9U;F-T:6]N"B`@("`@("`@("`@("1W96%T
M:&5R(#T@)'1H:7,M/E]W96%T:&5R4V]A<"T^9V5T5V5A=&AE<E)E<&]R="@D
M:60I.PH*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'=E871H97(I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H
M97(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("1T:&ES+3Y?=V5A=&AE
M<B`]("1W96%T:&5R.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%
M;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@:70*
M("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?
M5T5!5$A%4E]%6%!)4D537U=%051(15(B*3L*("`@("`@("`@("`@("`@("1T
M:&ES+3Y?8V%C:&4M/F5X=%-A=F4H(D=7+2(N)&ED+"`D=&AI<RT^7W=E871H
M97(L("(B+"`D97AP:7)E+"`B=V5A=&AE<B(I.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@
M("`@("`@('T*"B`@("`@("`@)'5P9&%T92`]('1R:6TH<W1R7W)E<&QA8V4H
M87)R87DH(E0B+"`B6B(I+"`B("(L("1T:&ES+3Y?=V5A=&AE<BT^=&EM97-T
M86UP*2DN(B!'350B.PH*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D871E
M(ET@("`@("`@("`@("`](&=M9&%T92AT<FEM*"1T:&ES+3Y?9&%T949O<FUA
M="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T*2P@<W1R=&]T:6UE*"1U<&1A=&4I
M*3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=7!D871E4F%W(ET@("`@("`@
M("`]("1T:&ES+3Y?=V5A=&AE<BT^=&EM97-T86UP.PH@("`@("`@(&EF("AS
M=')L96XH)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YR96=I;VXI("8F('-T
M<FQE;B@D=&AI<RT^7W=E871H97(M/G-T871I;VXM/F-O=6YT<GDI*2!["B`@
M("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N
M+3YN86UE+B(L("(N)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YR96=I;VXN
M(BP@(BXD=&AI<RT^7W=E871H97(M/G-T871I;VXM/F-O=6YT<GD["B`@("`@
M("`@?2!E;'-E:68@*'-T<FQE;B@D=&AI<RT^7W=E871H97(M/G-T871I;VXM
M/F-O=6YT<GDI*2!["B`@("`@("`@("`@("1L;V-N86UE(#T@)'1H:7,M/E]W
M96%T:&5R+3YS=&%T:6]N+3YN86UE+B(L("(N)'1H:7,M/E]W96%T:&5R+3YS
M=&%T:6]N+3YC;W5N=')Y.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("1L;V-N86UE(#T@)'1H:7,M/E]W96%T:&5R+3YS=&%T:6]N+3YN86UE.PH@
M("`@("`@('T*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<W1A=&EO;B)=("`@
M("`@("`@("`]("1L;V-N86UE.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W
M:6YD(ET@("`@("`@("`@("`@(#T@)'1H:7,M/F-O;G9E<G13<&5E9"@D=&AI
M<RT^7W=E871H97(M/G=I;F0M/G!R979A:6QI;F=?<W!E960L(")M<',B+"`D
M=6YI='-;(G=I;F0B72D["B`@("`@("`@)'=E871H97)2971U<FY;(G=I;F1$
M96=R965S(ET@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G=I;F0M/G!R979A
M:6QI;F=?9&ER96-T:6]N+3YD96=R965S.PH@("`@("`@("1W96%T:&5R4F5T
M=7)N6R)W:6YD1&ER96-T:6]N(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YW
M:6YD+3YP<F5V86EL:6YG7V1I<F5C=&EO;BT^8V]M<&%S<SL*("`@("`@("!I
M9B`H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YP<F5V86EL:6YG7W-P965D("$]
M("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^9W5S=%]S<&5E9"D@>PH@("`@("`@
M("`@("`D=V5A=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@(#T@)'1H:7,M
M/F-O;G9E<G13<&5E9"@D=&AI<RT^7W=E871H97(M/G=I;F0M/F=U<W1?<W!E
M960L(")M<',B+"`D=6YI='-;(G=I;F0B72D["B`@("`@("`@?0H@("`@("`@
M(&EF("@D=&AI<RT^7W=E871H97(M/G=I;F0M/G9A<GEI;F=?9G)O;5]D:7)E
M8W1I;VX@(3T@(B(@)B8@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YV87)Y:6YG
M7W1O7V1I<F5C=&EO;B`A/2`B(BD@>PH@("`@("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB=VEN9%9A<B)=("`@("`@(#T@87)R87D@*`H@("`@("`@("`@("`@
M("`@(F9R;VTB(#T^("1T:&ES+3Y?=V5A=&AE<BT^=VEN9"T^=F%R>6EN9U]F
M<F]M7V1I<F5C=&EO;BP*("`@("`@("`@("`@("`@(")T;R(@("`]/B`D=&AI
M<RT^7W=E871H97(M/G=I;F0M/G9A<GEI;F=?=&]?9&ER96-T:6]N"B`@("`@
M("`@("`@("D["B`@("`@("`@?0H*("`@("`@("`D=V5A=&AE<E)E='5R;ELB
M=FES:6)I;&ET>2)=("`@("`@("`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H
M)'1H:7,M/E]W96%T:&5R+3YV:7-I8FEL:71Y+3YD:7-T86YC92`O(#$P,#`L
M(")K;2(L("1U;FET<ULB=FES(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N
M6R)V:7-1=6%L:69I97(B72`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YV:7-I
M8FEL:71Y+3YQ=6%L:69I97(["@H@("`@("`@("1C;VYD:71I;VX@/2!A<G)A
M>2@I.PH@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D=&AI<RT^
M7W=E871H97(M/G!H96YO;65N82D[("1I*RLI('L*("`@("`@("`@("`@)&-O
M;F1I=&EO;EM=(#T@)'1H:7,M/E]W96%T:&5R+3YP:&5N;VUE;F%;)&E=+3YS
M=')I;F<["B`@("`@("`@?0H@("`@("`@("1W96%T:&5R4F5T=7)N6R)C;VYD
M:71I;VXB72`@("`@("`@(#T@:6UP;&]D92@B+"`B+"`D8V]N9&ET:6]N*3L*
M"B`@("`@("`@:68@*&ES7V%R<F%Y*"1T:&ES+3Y?=V5A=&AE<BT^<VMY+3YL
M87EE<G,I*2!["B`@("`@("`@("`@("1L87EE<G,@/2!A<G)A>2@I.PH@("`@
M("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]W96%T
M:&5R+3YS:WDM/FQA>65R<RD[("1I*RLI('L*("`@("`@("`@("`@("`@(&EF
M("AS=')T;W5P<&5R*"1T:&ES+3Y?=V5A=&AE<BT^<VMY+3YL87EE<G-;)&E=
M+3YT>7!E*2`A/2`B0TQ%05(B*2!["B`@("`@("`@("`@("`@("`@("`@)&QA
M>65R<ULD:5T@("`@("`@("`@("`@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@("`@("1L87EE<G-;)&E=6R)A;6]U;G0B72`@(#T@)&-L;W5D<ULD=&AI
M<RT^7W=E871H97(M/G-K>2T^;&%Y97)S6R1I72T^97AT96YT73L*("`@("`@
M("`@("`@("`@("`@("`D;&%Y97)S6R1I75LB:&5I9VAT(ET@("`]("1T:&ES
M+3YC;VYV97)T1&ES=&%N8V4H)'1H:7,M/E]W96%T:&5R+3YS:WDM/FQA>65R
M<ULD:5TM/F%L=&ET=61E+"`B;2(L("1U;FET<ULB:&5I9VAT(ETI.PH@("`@
M("`@("`@("`@("`@("`@(&EF("AS=')T;W5P<&5R*"1T:&ES+3Y?=V5A=&AE
M<BT^<VMY+3YL87EE<G-;)&E=+3YT>7!E*2`A/2`B0TQ/540B*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("1L87EE<G-;)&E=6R)T>7!E(ET@/2!U8W=O
M<F1S*'-T<E]R97!L86-E*")?(BP@(B(L("1T:&ES+3Y?=V5A=&AE<BT^<VMY
M+3YL87EE<G-;)&E=+3YT>7!E*2D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF
M("AS:7IE;V8H)&QA>65R<RDI('L*("`@("`@("`@("`@("`@("1W96%T:&5R
M4F5T=7)N6R)C;&]U9',B72`@("`@("`@/2`D;&%Y97)S.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H*("`@("`@("`D=V5A=&AE<E)E='5R;ELB=&5M<&5R
M871U<F4B72`@("`@("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)'1H
M:7,M/E]W96%T:&5R+3YT96UP97)A='5R92T^86UB:65N="P@(F,B+"`D=6YI
M='-;(G1E;7`B72D["B`@("`@("`@)&9E;'1496UP97)A='5R92`]("1T:&ES
M+3YC86QC=6QA=&57:6YD0VAI;&PH)'1H:7,M/F-O;G9E<G1496UP97)A='5R
M92@D=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72P@)'5N:71S6R)T96UP
M(ETL(")F(BDL("1T:&ES+3YC;VYV97)T4W!E960H)'=E871H97)2971U<FY;
M(G=I;F0B72P@)'5N:71S6R)W:6YD(ETL(")M<&@B*2D["B`@("`@("`@)'=E
M871H97)2971U<FY;(F9E;'1496UP97)A='5R92)=("`@/2`D=&AI<RT^8V]N
M=F5R=%1E;7!E<F%T=7)E*"1F96QT5&5M<&5R871U<F4L(")F(BP@)'5N:71S
M6R)T96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)D97=0;VEN=")=
M("`@("`@("`@(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI<RT^
M7W=E871H97(M/G1E;7!E<F%T=7)E+3YD97=P;VEN="P@(F,B+"`D=6YI='-;
M(G1E;7`B72D["B`@("`@("`@)'=E871H97)2971U<FY;(FAU;6ED:71Y(ET@
M("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G1E;7!E<F%T=7)E+3YR96QA
M=&EV95]H=6UI9&ET>3L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<')E<W-U
M<F4B72`@("`@("`@("`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H)'1H:7,M
M/E]W96%T:&5R+3YP<F5S<W5R92T^86QT:6UE=&5R+"`B:'!A(BP@)'5N:71S
M6R)P<F5S(ETI.PH*("`@("`@("!R971U<FX@)'=E871H97)2971U<FX["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R96-A<W0H*0H@("`@
M+RHJ"B`@("`@*B!';&]B86Q796%T:&5R(&AA<R!N;R!F;W)E8V%S="!P97(@
M<V4L('-O('1H:7,@9G5N8W1I;VX@:7,@:G5S="!F;W(*("`@("`J(&-O;7!A
M=&EB:6QI='D@<'5R<&]S97,N"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1I;G0*("`@("`J($!P87)A;2`@
M(&EN="`@("`@("`@("`@("`@("`@("`@("`@("`D9&%Y<PH@("`@("H@0'!A
M<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA
M=`H@("`@("H@0')E='5R;B`@8F]O;`H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B!`9&5P<F5C871E9`H@("`@("HO"B`@("!F=6YC=&EO;B!G971&
M;W)E8V%S="@D:60@/2!N=6QL+"`D9&%Y<R`](&YU;&PL("1U;FET<T9O<FUA
M="`](&YU;&PI"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@
M("`@+R\@?7U]"GT*+R\@?7U]"C\^"@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]397)V:6-E<R]796%T:&5R+TUE=&%R+G!H<```````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,C4R,#(T(#$P-3$U-#,T,3,R(#`R,S0S,``@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J(%!%
M05(Z.E-E<G9I8V5S7U=E871H97)?365T87(*("H*("H@4$A0('9E<G-I;VYS
M(#0@86YD(#4*("H*("H@/$Q)0T5.4T4^"B`J($-O<'ER:6=H="`H8RD@,C`P
M-2P@06QE>&%N9&5R(%=I<G1Z"B`J($%L;"!R:6=H=',@<F5S97)V960N"B`J
M"B`J(%)E9&ES=')I8G5T:6]N(&%N9"!U<V4@:6X@<V]U<F-E(&%N9"!B:6YA
M<GD@9F]R;7,L('=I=&@@;W(@=VET:&]U=`H@*B!M;V1I9FEC871I;VXL(&%R
M92!P97)M:71T960@<')O=FED960@=&AA="!T:&4@9F]L;&]W:6YG(&-O;F1I
M=&EO;G,*("H@87)E(&UE=#H*("H@;R!2961I<W1R:6)U=&EO;G,@;V8@<V]U
M<F-E(&-O9&4@;75S="!R971A:6X@=&AE(&%B;W9E(&-O<'ER:6=H="!N;W1I
M8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F;VQL
M;W=I;F<@9&ES8VQA:6UE<BX*("H@;R!2961I<W1R:6)U=&EO;G,@:6X@8FEN
M87)Y(&9O<FT@;75S="!R97!R;V1U8V4@=&AE(&%B;W9E(&-O<'ER:6=H="!N
M;W1I8V4L"B`J("`@=&AI<R!L:7-T(&]F(&-O;F1I=&EO;G,@86YD('1H92!F
M;VQL;W=I;F<@9&ES8VQA:6UE<B!I;B!T:&4@9&]C=6UE;G1A=&EO;@H@*B`@
M(&%N9"]O<B!O=&AE<B!M871E<FEA;',@<')O=FED960@=VET:"!T:&4@9&ES
M=')I8G5T:6]N+@H@*B!O($YE:71H97(@=&AE(&YA;64@;V8@=&AE('-O9G1W
M87)E(&YO<B!T:&4@;F%M97,@;V8@:71S(&-O;G1R:6)U=&]R<PH@*B`@(&UA
M>2!B92!U<V5D('1O(&5N9&]R<V4@;W(@<')O;6]T92!P<F]D=6-T<R!D97)I
M=F5D(&9R;VT@=&AI<R!S;V9T=V%R90H@*B`@('=I=&AO=70@<W!E8VEF:6,@
M<')I;W(@=W)I='1E;B!P97)M:7-S:6]N+@H@*@H@*B!42$E3(%-/1E1705)%
M($E3(%!23U9)1$5$($)9(%1(12!#3U!94DE'2%0@2$],1$524R!!3D0@0T].
M5%))0E543U)3(")!4R!)4R(*("H@04Y$($%.62!%6%!215-3($]2($E-4$Q)
M140@5T%24D%.5$E%4RP@24Y#3%5$24Y'+"!"550@3D]4($Q)34E4140@5$\L
M(%1(10H@*B!)35!,245$(%=!4E)!3E1)15,@3T8@34520TA!3E1!0DE,2519
M($%.1"!&251.15-3($9/4B!!(%!!4E1)0U5,05(@4%524$]310H@*B!!4D4@
M1$E30TQ!24U%1"X@24X@3D\@159%3E0@4TA!3$P@5$A%($-/4%E224=(5"!/
M5TY%4B!/4B!#3TY44DE"551/4E,@0D4*("H@3$E!0DQ%($9/4B!!3ED@1$E2
M14-4+"!)3D1)4D5#5"P@24Y#241%3E1!3"P@4U!%0TE!3"P@15A%35!,05)9
M+"!/4@H@*B!#3TY315%514Y424%,($1!34%'15,@*$E.0TQ51$E.1RP@0E54
M($Y/5"!,24U)5$5$(%1/+"!04D]#55)%345.5"!/1@H@*B!354)35$E4551%
M($=/3T13($]2(%-%4E9)0T53.R!,3U-3($]&(%5312P@1$%402P@3U(@4%)/
M1DE44SL@3U(@0E5324Y%4U,*("H@24Y415)255!424].*2!(3U=%5D52($-!
M55-%1"!!3D0@3TX@04Y9(%1(14]262!/1B!,24%"24Q)5%DL(%=(151(15(@
M24X*("H@0T].5%)!0U0L(%-44DE#5"!,24%"24Q)5%DL($]2(%1/4E0@*$E.
M0TQ51$E.1R!.14=,24=%3D-%($]2($]42$525TE312D*("H@05))4TE.1R!)
M3B!!3ED@5T%9($]55"!/1B!42$4@55-%($]&(%1(25,@4T]&5%=!4D4L($56
M14X@248@041625-%1"!/1B!42$4*("H@4$]34TE"24Q)5%D@3T8@4U5#2"!$
M04U!1T4N"B`J(#PO3$E#14Y313X*("H*("H@0&-A=&5G;W)Y("`@(%=E8B!3
M97)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE<@H@*B!`
M875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N;F5T/@H@
M*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@0&QI8V5N
M<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS97,O8G-D
M+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@("`@0U93
M.B`D260Z($UE=&%R+G!H<"QV(#$N.#<@,C`P-B\P,R\P."`Q,CHS.3HQ."!E
M<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R+G!H<"YN970O
M<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@("`@("!H='1P
M.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R+VUE=&%R+G-H=&UL"B`J($!L
M:6YK("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R+W1A
M9BYS:'1M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O;65T87(M8F%S:6,N
M<&AP("`@("`@("`@("`@;65T87(M8F%S:6,N<&AP"B`J($!E>&%M<&QE("`@
M("!E>&%M<&QE<R]M971A<BUE>'1E;G-I=F4N<&AP("`@("`@("!M971A<BUE
M>'1E;G-I=F4N<&AP"B`J($!F:6QE<V]U<F-E"B`J+PH*<F5Q=6ER95]O;F-E
M(")397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'`B.PH*<F5Q=6ER95]O;F-E
M(")$0BYP:'`B.PH*+R\@>WM[(&-L87-S(%-E<G9I8V5S7U=E871H97)?365T
M87(*+RHJ"B`J(%1H:7,@8VQA<W,@86-T<R!A<R!A;B!I;G1E<F9A8V4@=&\@
M=&AE($U%5$%2+U1!1B!S97)V:6-E(&]F"B`J('=E871H97(N;F]A82YG;W8N
M($ET('-E87)C:&5S(&9O<B!L;V-A=&EO;G,@9VEV96X@:6X@24-!3R!N;W1A
M=&EO;B!A;F0*("H@<F5T<FEE=F5S('1H92!C=7)R96YT('=E871H97(@9&%T
M82X*("H*("H@3V8@8V]U<G-E('1H92!P87)S:6YG(&]F('1H92!-151!4BUD
M871A(&AA<R!I=',@;&EM:71A=&EO;G,L(&%S(&ET"B`J(&9O;&QO=W,@=&AE
M($9E9&5R86P@365T96]R;VQO9VEC86P@2&%N9&)O;VL@3F\N,2!W:71H(&UO
M9&EF:6-A=&EO;G,@=&\*("H@86-C;VUO9&%T92!F;W(@;F]N+553(')E<&]R
M=',L('-O(&EF('1H92!R97!O<G0@9&5V:6%T97,@9G)O;2!T:&5S90H@*B!S
M=&%N9&%R9',L('EO=2!W;VXG="!G970@:70@<&%R<V5D(&-O<G)E8W1L>2X*
M("H@06YY=&AI;F<@=&AA="!I<R!N;W0@<&%R<V5D+"!I<R!S879E9"!I;B!T
M:&4@(FYO<&%R<V4B(&%R<F%Y+65N=')Y+`H@*B!R971U<FYE9"!B>2!G9717
M96%T:&5R*"DL('-O('EO=2!C86X@9&\@>6]U<B!O=VX@<&%R<VEN9R!A9G1E
M<G=A<F1S+B!4:&ES"B`J(&QI;6ET871I;VX@:7,@<W!E8VEF:6-A;&QY(&=I
M=F5N(&9O<B!R96UA<FMS+"!A<R!T:&4@8VQA<W,@:7,@;F]T"B`J('!R;V-E
M<W-I;F<@979E<GET:&EN9R!M96YT:6]N960@=&AE<F4L(&)U="!Y;W4@=VEL
M;"!G970@=&AE(&UO<W0@8V]M;6]N"B`J(&9I96QD<R!L:6ME('!R96-I<&ET
M871I;VX@86YD('1E;7!E<F%T=7)E+6-H86YG97,N($%G86EN+"!E=F5R>71H
M:6YG(&YO=`H@*B!P87)S960L(&=O97,@:6YT;R`B;F]P87)S92(N"B`J"B`J
M($EF('EO=2!T:&EN:RP@<V]M92!I;7!O<G1A;G0@9FEE;&0@:7,@;6ES<VEN
M9R!O<B!N;W0@8V]R<F5C=&QY('!A<G-E9"P*("H@<&QE87-E(&9I;&4@82!F
M96%T=7)E+7)E<75E<W0O8G5G<F5P;W)T(&%T(&AT='`Z+R]P96%R+G!H<"YN
M970O(&%N9"!B90H@*B!S=7)E('1O('!R;W9I9&4@=&AE($U%5$%2("AO<B!4
M048I(')E<&]R="!W:71H(&$@7V1E=&%I;&5D7R!E>'!L86YA=&EO;B$*("H*
M("H@1F]R('=O<FMI;F<@97AA;7!L97,L('!L96%S92!T86ME(&$@;&]O:R!A
M=`H@*B`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP;&5S+VUE=&%R
M+6)A<VEC+G!H<`H@*B`@("`@9&]C<R]397)V:6-E<U]796%T:&5R+V5X86UP
M;&5S+VUE=&%R+65X=&5N<VEV92YP:'`*("H*("H*("H@0&-A=&5G;W)Y("`@
M(%=E8B!397)V:6-E<PH@*B!`<&%C:V%G92`@("`@4V5R=FEC97-?5V5A=&AE
M<@H@*B!`875T:&]R("`@("`@06QE>&%N9&5R(%=I<G1Z(#QA;&5X0'!C-'`N
M;F5T/@H@*B!`8V]P>7)I9VAT("`@,C`P-2!!;&5X86YD97(@5VER='H*("H@
M0&QI8V5N<V4@("`@(&AT='`Z+R]W=W<N;W!E;G-O=7)C92YO<F<O;&EC96YS
M97,O8G-D+6QI8V5N<V4N<&AP("!"4T0@3&EC96YS90H@*B!`=F5R<VEO;B`@
M("`@4F5L96%S93H@,2XT+C`*("H@0&QI;FL@("`@("`@(&AT='`Z+R]P96%R
M+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L:6YK("`@
M("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W96%T:&5R+VUE=&%R+G-H
M=&UL"B`J($!L:6YK("`@("`@("!H='1P.B\O=V5A=&AE<BYN;V%A+F=O=B]W
M96%T:&5R+W1A9BYS:'1M;`H@*B!`97AA;7!L92`@("`@97AA;7!L97,O;65T
M87(M8F%S:6,N<&AP("`@("`@("`@("`@;65T87(M8F%S:6,N<&AP"B`J($!E
M>&%M<&QE("`@("!E>&%M<&QE<R]M971A<BUE>'1E;G-I=F4N<&AP("`@("`@
M("!M971A<BUE>'1E;G-I=F4N<&AP"B`J+PIC;&%S<R!397)V:6-E<U]796%T
M:&5R7TUE=&%R(&5X=&5N9',@4V5R=FEC97-?5V5A=&AE<E]#;VUM;VX*>PH@
M("`@+R\@>WM[('!R;W!E<G1I97,*("`@("\J*@H@("`@("H@26YF;W)M871I
M;VX@=&\@86-C97-S('1H92!L;V-A=&EO;B!$0@H@("`@("H*("`@("`J($!V
M87(@("`@(&]B:F5C="`@1$(@("`@("`@("`@("`@("`@("`D7V1B"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V1B.PH*("`@
M("\J*@H@("`@("H@5&AE('-O=7)C92!-151!4B!U<V5S"B`@("`@*@H@("`@
M("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1?<V]U
M<F-E365T87(*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@
M=F%R("1?<V]U<F-E365T87(["@H@("`@+RHJ"B`@("`@*B!4:&4@<V]U<F-E
M(%1!1B!U<V5S"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1?<V]U<F-E5&%F"B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-O=7)C951A9CL*"B`@("`O*BH*
M("`@("`J(%1H:7,@<&%T:"!I<R!U<V5D('1O(&9I;F0@=&AE($U%5$%2(&1A
M=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)%]S;W5R8V50871H365T87(*("`@("`J($!A8V-E<W,@('!R
M:79A=&4*("`@("`J+PH@("`@=F%R("1?<V]U<F-E4&%T:$UE=&%R.PH*("`@
M("\J*@H@("`@("H@5&AI<R!P871H(&ES('5S960@=&\@9FEN9"!T:&4@5$%&
M(&1A=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!S=')I;F<@("`@("`@("`@
M("`@("`@("`@("`@)%]S;W5R8V50871H5&%F"B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7W-O=7)C95!A=&A4868["B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*("`@("\J*@H@("`@("H@
M0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@
M("`@("`@("`@("`@("`@("`@)&]P=&EO;G,*("`@("`J($!P87)A;2`@(&UI
M>&5D("`@("`@("`@("`@("`@("`@("`@("`D97)R;W(*("`@("`J($!T:')O
M=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J
M+PH@("`@9G5N8W1I;VX@4V5R=FEC97-?5V5A=&AE<E]-971A<B@D;W!T:6]N
M<RP@)B1E<G)O<BD*("`@('L*("`@("`@("`D<&5R<F]R(#T@;G5L;#L*("`@
M("`@("`D=&AI<RT^4V5R=FEC97-?5V5A=&AE<E]#;VUM;VXH)&]P=&EO;G,L
M("1P97)R;W(I.PH@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R
M<F]R*"1P97)R;W(I*2!["B`@("`@("`@("`@("1E<G)O<B`]("1P97)R;W([
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"@H@("`@("`@("\O(%-E
M="!O<'1I;VYS(&%C8V]R9&EN9VQY"B`@("`@("`@:68@*&ES<V5T*"1O<'1I
M;VYS6R)D<VXB72DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS
M6R)D8D]P=&EO;G,B72DI('L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D
M=&AI<RT^<V5T365T87)$0B@D;W!T:6]N<ULB9'-N(ETL("1O<'1I;VYS6R)D
M8D]P=&EO;G,B72D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`D<W1A='5S(#T@)'1H:7,M/G-E=$UE=&%R1$(H)&]P=&EO;G-;(F1S
M;B)=*3L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H4V5R
M=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@
M("`D97)R;W(@/2`D<W1A='5S.PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H*("`@("`@("`O+R!3971T:6YG('1H92!D871A('-O=7)C97,@9F]R
M($U%5$%2(&%N9"!4048@+2!H879E('1O('=A=&-H(&]U="!F;W(@;VQD97(@
M05!)('5S86=E"B`@("`@("`@:68@*"@D<V]U<F-E(#T@:7-S970H)&]P=&EO
M;G-;(G-O=7)C92)=*2D@?'P@:7-S970H)&]P=&EO;G-;(G-O=7)C94UE=&%R
M(ETI*2!["B`@("`@("`@("`@("1S;W5R8V5-971A<B`]("1S;W5R8V4@/R`D
M;W!T:6]N<ULB<V]U<F-E(ET@.B`D;W!T:6]N<ULB<V]U<F-E365T87(B73L*
M("`@("`@("`@("`@:68@*"@D<V]U<F-E4&%T:"`](&ES<V5T*"1O<'1I;VYS
M6R)S;W5R8V50871H(ETI*2!\?"!I<W-E="@D;W!T:6]N<ULB<V]U<F-E4&%T
M:$UE=&%R(ETI*2!["B`@("`@("`@("`@("`@("`D<V]U<F-E4&%T:$UE=&%R
M(#T@)'-O=7)C95!A=&@@/R`D;W!T:6]N<ULB<V]U<F-E4&%T:")=(#H@)&]P
M=&EO;G-;(G-O=7)C95!A=&A-971A<B)=.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@)'-O=7)C95!A=&A-971A<B`]("(B.PH@("`@
M("`@("`@("!]"B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'-O=7)C
M94UE=&%R(#T@(FAT='`B.PH@("`@("`@("`@("`D<V]U<F-E4&%T:$UE=&%R
M(#T@(B(["B`@("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB
M<V]U<F-E5&%F(ETI*2!["B`@("`@("`@("`@("1S;W5R8V54868@/2`D;W!T
M:6]N<ULB<V]U<F-E5&%F(ET["B`@("`@("`@("`@(&EF("AI<W-E="@D;W!T
M:6]N6R)S;W5R8V50871H5&%F(ETI*2!["B`@("`@("`@("`@("`@("`D<V]U
M<F-E4&%T:%1A9B`]("1O<'1I;VYS6R)S;W5R8V50871H5&%F(ET["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<V]U8V50871H5&%F
M(#T@(B(["B`@("`@("`@("`@('T*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D<V]U<F-E5&%F(#T@(FAT='`B.PH@("`@("`@("`@("`D<V]U<F-E
M4&%T:%1A9B`]("(B.PH@("`@("`@('T*("`@("`@("`D<W1A='5S(#T@)'1H
M:7,M/G-E=$UE=&%R4V]U<F-E*"1S;W5R8V5-971A<BP@)'-O=7)C95!A=&A-
M971A<BP@)'-O=7)C951A9BP@)'-O=7)C95!A=&A4868I.PH@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@
M("`@("`@("1E<G)O<B`]("1S=&%T=7,["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T365T
M87)$0B@I"B`@("`O*BH*("`@("`J(%-E=',@=&AE('!A<F%M971E<G,@;F5E
M9&5D(&9O<B!C;VYN96-T:6YG('1O('1H92!$0BP@=VAE<F4@=&AE"B`@("`@
M*B!L;V-A=&EO;BUS96%R8V@@:7,@9F5T8VAI;F<@:71S(&1A=&$@9G)O;2X@
M66]U(&YE960@=&\@8G5I;&0@82!$0@H@("`@("H@=VET:"!T:&4@97AT97)N
M86P@=&]O;"!B=6EL9$UE=&%R1$(@9FER<W0L(&ET(&9E=&-H97,@=&AE(&QO
M8V%T:6]N<PH@("`@("H@86YD(&%I<G!O<G1S(&9R;VT@82!.3T%!+7=E8G-I
M=&4N"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1D<VX*("`@("`J($!P87)A;2`@(&%R<F%Y("`@("`@("`@
M("`@("`@("`@("`@("`D9&)/<'1I;VYS"B`@("`@*B!`<F5T=7)N("!$0E]%
M<G)O<GQB;V]L"B`@("`@*B!`=&AR;W=S("!$0E]%<G)O<@H@("`@("H@0'-E
M92`@("`@1$(Z.G!A<G-E1%-."B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@
M("`J+PH@("`@9G5N8W1I;VX@<V5T365T87)$0B@D9'-N+"`D9&)/<'1I;VYS
M(#T@87)R87DH*2D*("`@('L*("`@("`@("`D9'-N:6YF;R`]($1".CIP87)S
M94133B@D9'-N*3L*("`@("`@("!I9B`H:7-?87)R87DH)&1S;FEN9F\I("8F
M("%I<W-E="@D9'-N:6YF;ULB;6]D92)=*2D@>PH@("`@("`@("`@("`D9'-N
M:6YF;ULB;6]D92)=/2`P-C0T.PH@("`@("`@('T*"B`@("`@("`@+R\@26YI
M=&EA;&EZ92!C;VYN96-T:6]N('1O($1"(&%N9"!S=&]R92!I;B!O8FIE8W0@
M:68@<W5C8V5S<V9U;`H@("`@("`@("1D8B`]("!$0CHZ8V]N;F5C="@D9'-N
M:6YF;RP@)&1B3W!T:6]N<RD["B`@("`@("`@:68@*$1".CII<T5R<F]R*"1D
M8BDI('L*("`@("`@("`@("`@<F5T=7)N("1D8CL*("`@("`@("!]"B`@("`@
M("`@)'1H:7,M/E]D8B`]("1D8CL*"B`@("`@("`@<F5T=7)N('1R=64["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T365T87)3;W5R8V4H*0H@
M("`@+RHJ"B`@("`@*B!3971S('1H92!S;W5R8V4L('=H97)E('1H92!C;&%S
M<R!T<FEE<R!T;R!L;V-A=&4@=&AE($U%5$%2+U1!1B!D871A"B`@("`@*@H@
M("`@("H@4V]U<F-E(&-A;B!B92!H='1P+"!F='`@;W(@9FEL92X*("`@("`J
M($%L=&5R;F%T92!S;W5R8V5P871H<R!C86X@8F4@<')O=FED960N"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("1S;W5R8V5-971A<@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@("1S;W5R8V50871H365T87(*("`@("`J($!P87)A;2`@
M('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D<V]U<F-E5&%F"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'-O=7)C
M95!A=&A4868*("`@("`J($!R971U<FX@(%!%05)?15)23U)\8F]O;`H@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]-151!4E]33U520T5?24Y604Q)1`H@("`@("H@0&%C8V5S<R`@<'5B;&EC
M"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$UE=&%R4V]U<F-E*"1S;W5R8V5-
M971A<BP@)'-O=7)C95!A=&A-971A<B`]("(B+"`D<V]U<F-E5&%F(#T@(B(L
M("1S;W5R8V50871H5&%F(#T@(B(I"B`@("!["B`@("`@("`@:68@*&EN7V%R
M<F%Y*"1S;W5R8V5-971A<BP@87)R87DH(FAT='`B+"`B9G1P(BP@(F9I;&4B
M*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V5-971A<B`]("1S;W5R
M8V5-971A<CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27TU%5$%27U-/55)#15])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&$@<')O<&5R
M($U%5$%2('-O=7)C92!I9B!P87)A;65T97(@:7,@<V5T+"!I9B!N;W0@<V5T
M('5S92!D969A=6QT<PH@("`@("`@(&-L96%R<W1A=&-A8VAE*"D["B`@("`@
M("`@:68@*'-T<FQE;B@D<V]U<F-E4&%T:$UE=&%R*2D@>PH@("`@("`@("`@
M("!I9B`H*"1T:&ES+3Y?<V]U<F-E365T87(@/3T@(F9I;&4B("8F(&ES7V1I
M<B@D<V]U<F-E4&%T:$UE=&%R*2D@?'P@*"1T:&ES+3Y?<V]U<F-E365T87(@
M(3T@(F9I;&4B("8F('!A<G-E7W5R;"@D<V]U<F-E4&%T:$UE=&%R*2DI('L*
M("`@("`@("`@("`@("`@("1T:&ES+3Y?<V]U<F-E4&%T:$UE=&%R(#T@)'-O
M=7)C95!A=&A-971A<CL*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%
M4E9)0T537U=%051(15)?15)23U)?345405)?4T]54D-%7TE.5D%,240L(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("!S=VET8V@@*"1S;W5R8V5-971A<BD@>PH@("`@
M("`@("`@("`@("`@8V%S92`B:'1T<"(Z"B`@("`@("`@("`@("`@("`@("`@
M)'1H:7,M/E]S;W5R8V50871H365T87(@/2`B:'1T<#HO+W=E871H97(N;F]A
M82YG;W8O<'5B+V1A=&$O;V)S97)V871I;VYS+VUE=&%R+W-T871I;VYS(CL*
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@(&-A
M<V4@(F9T<"(Z"B`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V50
M871H365T87(@/2`B9G1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D871A+V]B<V5R
M=F%T:6]N<R]M971A<B]S=&%T:6]N<R(["B`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("!C87-E(")F:6QE(CH*("`@("`@("`@
M("`@("`@("`@("`D=&AI<RT^7W-O=7)C95!A=&A-971A<B`]("(N(CL*("`@
M("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@:68@*&EN7V%R<F%Y*"1S;W5R8V54868L(&%R<F%Y*")H
M='1P(BP@(F9T<"(L(")F:6QE(BDI*2!["B`@("`@("`@("`@("1T:&ES+3Y?
M<V]U<F-E5&%F(#T@)'-O=7)C951A9CL*("`@("`@("!](&5L<V5I9B`H)'-O
M=7)C951A9B`A/2`B(BD@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?
M5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27TU%
M5$%27U-/55)#15])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@+R\@0VAE8VL@9F]R(&$@<')O<&5R(%1!1B!S;W5R
M8V4@:68@<&%R86UE=&5R(&ES('-E="P@:68@;F]T('-E="!U<V4@9&5F875L
M=',*("`@("`@("!C;&5A<G-T871C86-H92@I.PH@("`@("`@(&EF("AS=')L
M96XH)'-O=7)C95!A=&A4868I*2!["B`@("`@("`@("`@(&EF("@H)'1H:7,M
M/E]S;W5R8V54868@/3T@(F9I;&4B("8F(&ES7V1I<B@D<V]U<F-E4&%T:%1A
M9BDI('Q\("@D=&AI<RT^7W-O=7)C951A9B`A/2`B9FEL92(@)B8@<&%R<V5?
M=7)L*"1S;W5R8V50871H5&%F*2DI('L*("`@("`@("`@("`@("`@("1T:&ES
M+3Y?<V]U<F-E4&%T:%1A9B`]("1S;W5R8V50871H5&%F.PH@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]-151!
M4E]33U520T5?24Y604Q)1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@("`@('-W:71C:"`H
M)'-O=7)C951A9BD@>PH@("`@("`@("`@("`@("`@8V%S92`B:'1T<"(Z"B`@
M("`@("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H5&%F(#T@(FAT
M='`Z+R]W96%T:&5R+FYO86$N9V]V+W!U8B]D871A+V9O<F5C87-T<R]T868O
M<W1A=&EO;G,B.PH@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@8V%S92`B9G1P(CH*("`@("`@("`@("`@("`@("`@("`D=&AI
M<RT^7W-O=7)C95!A=&A4868@/2`B9G1P.B\O=V5A=&AE<BYN;V%A+F=O=B]D
M871A+V9O<F5C87-T<R]T868O<W1A=&EO;G,B.PH@("`@("`@("`@("`@("`@
M("`@(&)R96%K.PH@("`@("`@("`@("`@("`@8V%S92`B9FEL92(Z"B`@("`@
M("`@("`@("`@("`@("`@)'1H:7,M/E]S;W5R8V50871H5&%F(#T@(BXB.PH@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("!]"B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@=')U93L*("`@('T*("`@("\O('U]?0H*
M("`@("\O('M[>R!?8VAE8VM,;V-A=&EO;DE$*"D*("`@("\J*@H@("`@("H@
M0VAE8VMS('1H92!I9"!F;W(@=F%L:60@=F%L=65S(&%N9"!T:'5S('!R979E
M;G1S('-I;&QY(')E<75E<W1S('1O"B`@("`@*B!-151!4B!S97)V97(*("`@
M("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@
M("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M3D]?3$]#051)3TX*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)
M0T537U=%051(15)?15)23U)?24Y604Q)1%],3T-!5$E/3@H@("`@("H@0&%C
M8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?8VAE8VM,;V-A
M=&EO;DE$*"1I9"D*("`@('L*("`@("`@("!I9B`H:7-?87)R87DH)&ED*2!\
M?"!I<U]O8FIE8W0H)&ED*2!\?"`A<W1R;&5N*"1I9"DI('L*("`@("`@("`@
M("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#
M15-?5T5!5$A%4E]%4E)/4E].3U],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.
M15]?*3L*("`@("`@("!](&5L<V5I9B`H(6-T>7!E7V%L;G5M*"1I9"D@?'P@
M*'-T<FQE;B@D:60I(#X@-"DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I
M8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/
M4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@
M("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]"B`@("`O+R!]?7T*
M"B`@("`O*BH*("`@("`J($1O=VYL;V%D<R!T:&4@=V5A=&AE<BT@;W(@9F]R
M96-A<W0M9&%T82!F;W(@86X@:60@9G)O;2!T:&4@<V5R=F5R(&1E<&5N9&%N
M="!O;B!T:&4@9&%T871Y<&4@86YD(')E='5R;G,@:70*("`@("`J"B`@("`@
M*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&1A
M=&%4>7!E"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y"B`@("`@
M*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]2
M7U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@
M("`@*B\*("`@("\O('M[>R!?<F5T<FEE=F5397)V97)$871A*"D*("`@(&9U
M;F-T:6]N(%]R971R:65V95-E<G9E<D1A=&$H)&ED+"`D9&%T851Y<&4I('L*
M("`@("`@("!S=VET8V@H)'1H:7,M/GLB7W-O=7)C92(N=6-F:7)S="@D9&%T
M851Y<&4I?2D@>PH@("`@("`@("`@("!C87-E(")F:6QE(CH*("`@("`@("`@
M("`@("`@("\O($9I;&4@<V]U<F-E(&ES('5S960L(&=E="!F:6QE(&%N9"!R
M96%D(&%S+6ES(&EN=&\@82!S=')I;F<*("`@("`@("`@("`@("`@("1S;W5R
M8V4@/2!R96%L<&%T:"@D=&AI<RT^>R)?<V]U<F-E4&%T:"(N=6-F:7)S="@D
M9&%T851Y<&4I?2XB+R(N)&ED+B(N5%A4(BD["B`@("`@("`@("`@("`@("`D
M9&%T82`]($!F:6QE7V=E=%]C;VYT96YT<R@D<V]U<F-E*3L*("`@("`@("`@
M("`@("`@(&EF("@D9&%T82`]/3T@9F%L<V4I('L*("`@("`@("`@("`@("`@
M("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)6
M24-%4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@(&-A<V4@(FAT='`B.@H@("`@("`@("`@
M("`@("`@+R\@2%144"!U<V5D+"!A8W%U:7)E(')E<75E<W0@;V)J96-T(&%N
M9"!F971C:"!D871A(&9R;VT@=V5B<V5R=F5R+B!2971U<FX@8F]D>2!O9B!R
M97!L>0H@("`@("`@("`@("`@("`@:6YC;'5D95]O;F-E(")(5%10+U)E<75E
M<W0N<&AP(CL*"B`@("`@("`@("`@("`@("`D<F5Q=65S="`]("9N97<@2%14
M4%]297%U97-T*"1T:&ES+3Y[(E]S;W5R8V50871H(BYU8V9I<G-T*"1D871A
M5'EP92E]+B(O(BXD:60N(BY46%0B+"`D=&AI<RT^7VAT='!/<'1I;VYS*3L*
M("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D<F5Q=65S="T^<V5N9%)E<75E
M<W0H*3L*("`@("`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII
M<T5R<F]R*"1S=&%T=7,I('Q\("AI;G0I("1R97%U97-T+3YG971297-P;VYS
M94-O9&4H*2`\/B`R,#`I('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I
M.PH@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1D871A(#T@
M)')E<75E<W0M/F=E=%)E<W!O;G-E0F]D>2@I.PH@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@(&-A<V4@(F9T<"(Z"B`@("`@("`@("`@("`@
M("`O+R!&5%`@87,@<V]U<F-E+"!A8W%U:7)E(&YE8V-E<W-A<GD@;V)J96-T
M(&9I<G-T"B`@("`@("`@("`@("`@("!I;F-L=61E7V]N8V4@(DYE="]&5%`N
M<&AP(CL*"B`@("`@("`@("`@("`@("`O+R!087)S92!S;W5R8V4@=&\@9V5T
M('1H92!S97)V97(@9&%T80H@("`@("`@("`@("`@("`@)'-E<G9E<B`]('!A
M<G-E7W5R;"@D=&AI<RT^>R)?<V]U<F-E4&%T:"(N=6-F:7)S="@D9&%T851Y
M<&4I?2XB+R(N)&ED+B(N5%A4(BD["@H@("`@("`@("`@("`@("`@+R\@268@
M;F5C8V5S<V%R>2!O<'1I;VYS(&%R92!N;W0@<V5T+"!U<V4@9&5F875L=',*
M("`@("`@("`@("`@("`@(&EF("@A:7-S970H)'-E<G9E<ELB<&]R=")=*2!\
M?"`D<V5R=F5R6R)P;W)T(ET@/3T@(B(@?'P@)'-E<G9E<ELB<&]R=")=(#T]
M(#`I('L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R6R)P;W)T(ET@/2`R
M,3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'-E<G9E<ELB=7-E<B)=*2!\?"`D<V5R=F5R6R)U<V5R(ET@/3T@(B(I
M('L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R6R)U<V5R(ET@/2`B9G1P
M(CL*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A:7-S
M970H)'-E<G9E<ELB<&%S<R)=*2!\?"`D<V5R=F5R6R)P87-S(ET@/3T@(B(I
M('L*("`@("`@("`@("`@("`@("`@("`D<V5R=F5R6R)P87-S(ET@/2`B9G1P
M0"(["B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@26YS
M=&%N=&EA=&4@;V)J96-T(&%N9"!C;VYN96-T('1O('-E<G9E<@H@("`@("`@
M("`@("`@("`@)&9T<"`]("9N97<@3F5T7T944"@D<V5R=F5R6R)H;W-T(ETL
M("1S97)V97);(G!O<G0B72P@)'1H:7,M/E]H='1P3W!T:6]N<ULB=&EM96]U
M=")=*3L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D9G1P+3YC;VYN96-T
M*"D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!3
M97)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?
M15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@3&]G:6X@
M=&\@<V5R=F5R+BXN"B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)&9T<"T^
M;&]G:6XH)'-E<G9E<ELB=7-E<B)=+"`D<V5R=F5R6R)P87-S(ETI.PH@("`@
M("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-T
M871U<RDI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?
M5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=2
M3TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@("`@("\O("XN+F%N9"!R971R:65V
M92!T:&4@9&%T82!I;G1O(&$@=&5M<&]R87)Y(&9I;&4*("`@("`@("`@("`@
M("`@("1T96UP9FEL92`]('1E;7!N86TH(BXO(BP@(E-E<G9I8V5S7U=E871H
M97)?365T87(B*3L*("`@("`@("`@("`@("`@("1S=&%T=7,@/2`D9G1P+3YG
M970H)'-E<G9E<ELB<&%T:")=+"`D=&5M<&9I;&4L('1R=64L($944%]!4T-)
M22D["B`@("`@("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%
M<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@("`@('5N;&EN:R@D
M=&5M<&9I;&4I.PH@("`@("`@("`@("`@("`@("`@(')E='5R;B!397)V:6-E
M<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@
M("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@+R\@1&ES8V]N;F5C="!&
M5%`@<V5R=F5R+"!A;F0@<F5A9"!D871A(&9R;VT@=&5M<&]R87)Y(&9I;&4*
M("`@("`@("`@("`@("`@("1F='`M/F1I<V-O;FYE8W0H*3L*("`@("`@("`@
M("`@("`@("1D871A(#T@0&9I;&5?9V5T7V-O;G1E;G1S*"1T96UP9FEL92D[
M"B`@("`@("`@("`@("`@("!U;FQI;FLH)'1E;7!F:6QE*3L*("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@('T*"B`@("`@("`@+R\@4W!L:70@9&%T
M82!I;G1O(&%N(&%R<F%Y(&%N9"!R971U<FX*("`@("`@("!R971U<FX@<')E
M9U]S<&QI="@B+UQN?%QR7&Y\7&Y<<B\B+"`D9&%T82D["B`@("!]"B`@("`O
M+R!]?7T*"B`@("`O+R![>WL@7W!A<G-E5V5A=&AE<D1A=&$H*0H@("`@+RHJ
M"B`@("`@*B!087)S97,@=&AE(&1A=&$@86YD(&-A8VAE<R!I=`H@("`@("H*
M("`@("`J($U%5$%2($M0250@,#DQ.34U6B!#3U(@,C(P,35',C5+5"`S+S13
M32!2,CA,+S(V,#!&5"!44U)!($]60S`Q,$-""B`@("`@*B`Q."\Q-B!!,CDY
M,B!234L@4TQ0,#0U(%0P,3@R,#$U.0H@("`@("H*("`@("`J($!P87)A;2`@
M(&%R<F%Y("`@("`@("`@("`@("`@("`@("`@("`D9&%T80H@("`@("H@0')E
M='5R;B`@4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%
M<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%4
M00H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]53DM.3U=.7TQ/0T%424]."B`@("`@*B!`86-C97-S("!P<FEV
M871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]P87)S95=E871H97)$871A*"1D
M871A*0H@("`@>PH@("`@("`@('-T871I8R`D8V]M<&%S<SL*("`@("`@("!S
M=&%T:6,@)&-L;W5D<SL*("`@("`@("!S=&%T:6,@)&-O;F1I=&EO;G,["B`@
M("`@("`@<W1A=&EC("1S96YS;W)S.PH@("`@("`@(&EF("@A:7-S970H)&-O
M;7!A<W,I*2!["B`@("`@("`@("`@("1C;VUP87-S(#T@87)R87DH"B`@("`@
M("`@("`@("`@("`B3B(L(").3D4B+"`B3D4B+"`B14Y%(BP*("`@("`@("`@
M("`@("`@(")%(BP@(D5312(L(")312(L(")34T4B+`H@("`@("`@("`@("`@
M("`@(E,B+"`B4U-7(BP@(E-7(BP@(E=35R(L"B`@("`@("`@("`@("`@("`B
M5R(L(")73E<B+"`B3E<B+"`B3DY7(@H@("`@("`@("`@("`I.PH@("`@("`@
M("`@("`D8VQO=61S("`@(#T@87)R87DH"B`@("`@("`@("`@("`@("`B<VMC
M(B`@("`@("`@(#T^(")S:WD@8VQE87(B+`H@("`@("`@("`@("`@("`@(FYS
M8R(@("`@("`@("`]/B`B;F\@<VEG;FEF:6-A;G0@8VQO=60B+`H@("`@("`@
M("`@("`@("`@(F9E=R(@("`@("`@("`]/B`B9F5W(BP*("`@("`@("`@("`@
M("`@(")S8W0B("`@("`@("`@/3X@(G-C871T97)E9"(L"B`@("`@("`@("`@
M("`@("`B8FMN(B`@("`@("`@(#T^(")B<F]K96XB+`H@("`@("`@("`@("`@
M("`@(F]V8R(@("`@("`@("`]/B`B;W9E<F-A<W0B+`H@("`@("`@("`@("`@
M("`@(G9V(B`@("`@("`@("`]/B`B=F5R=&EC86P@=FES:6)I;&ET>2(L"B`@
M("`@("`@("`@("`@("`B=&-U(B`@("`@("`@(#T^(")4;W=E<FEN9R!#=6UU
M;'5S(BP*("`@("`@("`@("`@("`@(")C8B(@("`@("`@("`@/3X@(D-U;75L
M;VYI;6)U<R(L"B`@("`@("`@("`@("`@("`B8VQR(B`@("`@("`@(#T^(")C
M;&5A<B!B96QO=R`Q,BPP,#`@9G0B"B`@("`@("`@("`@("D["B`@("`@("`@
M("`@("1C;VYD:71I;VYS(#T@87)R87DH"B`@("`@("`@("`@("`@("`B*R(@
M("`@("`@("`@(#T^(")H96%V>2(L("`@("`@("`B+2(@("`@("`@("`@(#T^
M(")L:6=H="(L"@H@("`@("`@("`@("`@("`@(G9C(B`@("`@("`@("`]/B`B
M=FEC:6YI='DB+"`@("`@(G)E(B`@("`@("`@("`]/B`B<F5C96YT(BP*("`@
M("`@("`@("`@("`@(")N<W<B("`@("`@("`@/3X@(FYO('-I9VYI9FEC86YT
M('=E871H97(B+`H*("`@("`@("`@("`@("`@(")M:2(@("`@("`@("`@/3X@
M(G-H86QL;W<B+"`@("`@(")B8R(@("`@("`@("`@/3X@(G!A=&-H97,B+`H@
M("`@("`@("`@("`@("`@(G!R(B`@("`@("`@("`]/B`B<&%R=&EA;"(L("`@
M("`@(G1S(B`@("`@("`@("`]/B`B=&AU;F1E<G-T;W)M(BP*("`@("`@("`@
M("`@("`@(")B;"(@("`@("`@("`@/3X@(F)L;W=I;F<B+"`@("`@(")S:"(@
M("`@("`@("`@/3X@(G-H;W=E<G,B+`H@("`@("`@("`@("`@("`@(F1R(B`@
M("`@("`@("`]/B`B;&]W(&1R:69T:6YG(BP@(F9Z(B`@("`@("`@("`]/B`B
M9G)E97II;F<B+`H*("`@("`@("`@("`@("`@(")D>B(@("`@("`@("`@/3X@
M(F1R:7IZ;&4B+"`@("`@(")R82(@("`@("`@("`@/3X@(G)A:6XB+`H@("`@
M("`@("`@("`@("`@(G-N(B`@("`@("`@("`]/B`B<VYO=R(L("`@("`@("`@
M(G-G(B`@("`@("`@("`]/B`B<VYO=R!G<F%I;G,B+`H@("`@("`@("`@("`@
M("`@(FEC(B`@("`@("`@("`]/B`B:6-E(&-R>7-T86QS(BP@(G!E(B`@("`@
M("`@("`]/B`B:6-E('!E;&QE=',B+`H@("`@("`@("`@("`@("`@(F=R(B`@
M("`@("`@("`]/B`B:&%I;"(L("`@("`@("`@(F=S(B`@("`@("`@("`]/B`B
M<VUA;&P@:&%I;"]S;F]W('!E;&QE=',B+`H@("`@("`@("`@("`@("`@(G5P
M(B`@("`@("`@("`]/B`B=6YK;F]W;B!P<F5C:7!I=&%T:6]N(BP*"B`@("`@
M("`@("`@("`@("`B8G(B("`@("`@("`@(#T^(")M:7-T(BP@("`@("`@("`B
M9F<B("`@("`@("`@(#T^(")F;V<B+`H@("`@("`@("`@("`@("`@(F9U(B`@
M("`@("`@("`]/B`B<VUO:V4B+"`@("`@("`@(G9A(B`@("`@("`@("`]/B`B
M=F]L8V%N:6,@87-H(BP*("`@("`@("`@("`@("`@(")S82(@("`@("`@("`@
M/3X@(G-A;F0B+"`@("`@("`@(")H>B(@("`@("`@("`@/3X@(FAA>F4B+`H@
M("`@("`@("`@("`@("`@(G!Y(B`@("`@("`@("`]/B`B<W!R87DB+"`@("`@
M("`@(F1U(B`@("`@("`@("`]/B`B=VED97-P<F5A9"!D=7-T(BP*"B`@("`@
M("`@("`@("`@("`B<W$B("`@("`@("`@(#T^(")S<75A;&PB+"`@("`@("`B
M<W,B("`@("`@("`@(#T^(")S86YD<W1O<FTB+`H@("`@("`@("`@("`@("`@
M(F1S(B`@("`@("`@("`]/B`B9'5S='-T;W)M(BP@("`@(G!O(B`@("`@("`@
M("`]/B`B=V5L;"!D979E;&]P960@9'5S="]S86YD('=H:7)L<R(L"B`@("`@
M("`@("`@("`@("`B9F,B("`@("`@("`@(#T^(")F=6YN96P@8VQO=60B+`H*
M("`@("`@("`@("`@("`@("(K9F,B("`@("`@("`@/3X@(G1O<FYA9&\O=V%T
M97)S<&]U="(*("`@("`@("`@("`@*3L*("`@("`@("`@("`@)'-E;G-O<G,@
M/2!A<G)A>2@*("`@("`@("`@("`@("`@(")R=G)N;R(@(#T^(")2=6YW87D@
M5FES=6%L(%)A;F=E($1E=&5C=&]R(&]F9FQI;F4B+`H@("`@("`@("`@("`@
M("`@(G!W:6YO(B`@/3X@(E!R97-E;G0@5V5A=&AE<B!)9&5N=&EF:65R(&]F
M9FQI;F4B+`H@("`@("`@("`@("`@("`@(G!N;R(@("`@/3X@(E1I<'!I;F<@
M0G5C:V5T(%)A:6X@1V%U9V4@;V9F;&EN92(L"B`@("`@("`@("`@("`@("`B
M9GIR86YO(B`]/B`B1G)E97II;F<@4F%I;B!396YS;W(@;V9F;&EN92(L"B`@
M("`@("`@("`@("`@("`B='-N;R(@("`]/B`B3&EG:'1N:6YG($1E=&5C=&EO
M;B!3>7-T96T@;V9F;&EN92(L"B`@("`@("`@("`@("`@("`B=FES;F\B("`]
M/B`B,FYD(%9I<VEB:6QI='D@4V5N<V]R(&]F9FQI;F4B+`H@("`@("`@("`@
M("`@("`@(F-H:6YO(B`@/3X@(C)N9"!#96EL:6YG($AE:6=H="!);F1I8V%T
M;W(@;V9F;&EN92(*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@
M("1M971A<D-O9&4@/2!A<G)A>2@*("`@("`@("`@("`@(G)E<&]R="(@("`@
M("`]/B`B345405)\4U!%0TDB+`H@("`@("`@("`@("`B<W1A=&EO;B(@("`@
M(#T^(")<=WLT?2(L"B`@("`@("`@("`@(")U<&1A=&4B("`@("`@/3X@(BA<
M9'LR?2D_*%QD>S1]*5HB+`H@("`@("`@("`@("`B='EP92(@("`@("`@(#T^
M(")!551/?$-/4B(L"B`@("`@("`@("`@(")W:6YD(B`@("`@("`@/3X@(BA<
M9'LS?7Q605)\5E)"*2A<9'LR+#-]*2A'*%QD>S)]*2D_*%QW>S(L,WTI(BP*
M("`@("`@("`@("`@(G=I;F1687(B("`@("`]/B`B*%QD>S-]*58H7&1[,WTI
M(BP*("`@("`@("`@("`@(G9I<T9R86,B("`@("`]/B`B*%QD>S%]*2(L"B`@
M("`@("`@("`@(")V:7-I8FEL:71Y(B`@/3X@(BA<9'LT?2E\*"A-?%`I/R@H
M7&1[,2PR?7PH*%QD*2`I/RA<9"E<+RA<9"DI*%--?$M-*2DI?"A#059/2RDB
M+`H@("`@("`@("`@("`B<G5N=V%Y(B`@("`@(#T^(")2*%QD>S)]*2A<=RD_
M7"\H4'Q-*3\H7&1[-'TI*$94*3\H5BA0?$TI/RA<9'LT?2DH1E0I/RD_*%QW
M*3\B+`H@("`@("`@("`@("`B8V]N9&ET:6]N(B`@(#T^("(H+7Q<*WQ60WQ2
M17Q.4U<I/RA-27Q"0WQ04GQ44WQ"3'Q32'Q$4GQ&6BD_*"A$6BE\*%)!*7PH
M4TXI?"A31RE\*$E#*7PH4$PI?"A'4BE\*$=3*7PH55`I*2HH0E)\1D=\1E5\
M5D%\1%5\4T%\2%I\4%DI/RA03WQ347Q&0WQ34WQ$4RD_(BP*("`@("`@("`@
M("`@(F-L;W5D<R(@("`@("`]/B`B*%-+0WQ#3%)\3E-#?"@H1D57?%-#5'Q"
M2TY\3U9#?%96*2A<9'LS?2DH5$-5?$-"*3\I*2(L"B`@("`@("`@("`@(")T
M96UP97)A='5R92(@/3X@(BA-*3\H7&1[,GTI7"\H*$TI/RA<9'LR?2E\6%A\
M7"]<+RD_(BP*("`@("`@("`@("`@(G!R97-S=7)E(B`@("`]/B`B*$$I*%QD
M>S1]*7PH42DH7&1[-'TI(BP*("`@("`@("`@("`@(G1R96YD(B`@("`@("`]
M/B`B3D]324=\5$5-4$]\0D5#34<B+`H@("`@("`@("`@("`B<F5M87)K(B`@
M("`@(#T^(")234LB"B`@("`@("`@*3L*"B`@("`@("`@)')E;6%R:W,@/2!A
M<G)A>2@*("`@("`@("`@("`@(FYO<W!E8VDB("`@("`]/B`B3D]34$5#22(L
M"B`@("`@("`@("`@(")A=71O<W1A=&EO;B(@/3X@(D%/*#%\,BDB+`H@("`@
M("`@("`@("`B<')E<W-C:&<B("`@(#T^(")04D53*%)\1BE2(BP*("`@("`@
M("`@("`@(G-E87!R97-S=7)E(B`]/B`B4TQ0*%QD>S-]?$Y/*2(L"B`@("`@
M("`@("`@(")P<F5C:7`B("`@("`@/3X@(BA0?#9\-RDH7&1[-'U\7"][-'TI
M(BP*("`@("`@("`@("`@(G-N;W=D97!T:"(@("`]/B`B-%PO*%QD>S-]*2(L
M"B`@("`@("`@("`@(")S;F]W97%U:78B("`@/3X@(CDS,RA<9'LS?2DB+`H@
M("`@("`@("`@("`B8VQO=61T>7!E<R(@(#T^("(X7"\H7&1\7"\I*%QD?%PO
M*2A<9'Q<+RDB+`H@("`@("`@("`@("`B<W5N9'5R871I;VXB(#T^("(Y."A<
M9'LS?2DB+`H@("`@("`@("`@("`B,6AT96UP9&5W(B`@(#T^(")4*#!\,2DH
M7&1[,WTI*"@P?#$I*%QD>S-]*2D_(BP*("`@("`@("`@("`@(C9H;6%X=&5M
M<"(@("`]/B`B,2@P?#$I*%QD>S-]*2(L"B`@("`@("`@("`@("(V:&UI;G1E
M;7`B("`@/3X@(C(H,'PQ*2A<9'LS?2DB+`H@("`@("`@("`@("`B,C1H=&5M
M<"(@("`@(#T^("(T*#!\,2DH7&1[,WTI*#!\,2DH7&1[,WTI(BP*("`@("`@
M("`@("`@(C-H<')E<W-T96YD(B`]/B`B-2A;,"TX72DH7&1[,WTI(BP*("`@
M("`@("`@("`@(G-E;G-O<G,B("`@("`]/B`B4E923D]\4%=)3D]\4$Y/?$9:
M4D%.3WQ44TY/?%9)4TY/?$-(24Y/(BP*("`@("`@("`@("`@(FUA:6YT86EN
M(B`@("`]/B`B6UPD72(*("`@("`@("`I.PH*("`@("`@("!I9B`H4T525DE#
M15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@("`@("!F;W(@*"1I(#T@,#L@
M)&D@/"!S:7IE;V8H)&1A=&$I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!E
M8VAO("1D871A6R1I73L*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@
M("`O+R!3=&%R="!W:71H('!A<G-I;F<@=&AE(&9I<G-T(&QI;F4@9F]R('1H
M92!L87-T('5P9&%T90H@("`@("`@("1W96%T:&5R1&%T82`](&%R<F%Y*"D[
M"B`@("`@("`@)'=E871H97)$871A6R)S=&%T:6]N(ET@("`]("(B.PH@("`@
M("`@("1W96%T:&5R1&%T85LB9&%T85)A=R)=("`@/2!I;7!L;V1E*"(@(BP@
M)&1A=&$I.PH@("`@("`@("1W96%T:&5R1&%T85LB=7!D871E(ET@("`@/2!S
M=')T;W1I;64H=')I;2@D9&%T85LP72DN(B!'350B*3L*("`@("`@("`D=V5A
M=&AE<D1A=&%;(G5P9&%T95)A=R)=(#T@=')I;2@D9&%T85LP72D["B`@("`@
M("`@+R\@86YD('!R97!A<F4@=&AE(')E<W0@9F]R('-T97!P:6YG('1H<F]U
M9V@*("`@("`@("!A<G)A>5]S:&EF="@D9&%T82D["B`@("`@("`@)&UE=&%R
M(#T@97AP;&]D92@B("(L('!R96=?<F5P;&%C92@B+UQS>S(L?2\B+"`B("(L
M(&EM<&QO9&4H(B`B+"`D9&%T82DI*3L*"B`@("`@("`@+R\@061D(&$@9F5W
M(&QO8V%L('9A<FEA8FQE<R!F;W(@9&%T82!P<F]C97-S:6YG"B`@("`@("`@
M)'1R96YD0V]U;G0@/2`P.R`@("`@("`@("`@("`O+R!)9B!W92!H879E('1R
M96YD<RP@=V4@;F5E9"!T:&ES"B`@("`@("`@)'!O:6YT97(@("`@/28@)'=E
M871H97)$871A.R`O+R!0;VEN=&5R('1O('1H92!A<G)A>2!W92!A9&0@=&AE
M(&1A=&$@=&\*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)&UE
M=&%R*3L@)&DK*RD@>PH@("`@("`@("`@("`O+R!#:&5C:R!F;W(@=VAI=&5S
M<&%C92!A;F0@<W1E<"!L;V]P+"!I9B!N;W1H:6YG)W,@=&AE<F4*("`@("`@
M("`@("`@)&UE=&%R6R1I72`]('1R:6TH)&UE=&%R6R1I72D["B`@("`@("`@
M("`@(&EF("@A<W1R;&5N*"1M971A<ELD:5TI*2!["B`@("`@("`@("`@("`@
M("!C;VYT:6YU93L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*%-%
M4E9)0T537U=%051(15)?1$5"54<I('L*("`@("`@("`@("`@("`@("1T86(@
M/2!S=')?<F5P96%T*")<="(L(#(@+2!F;&]O<B@H<W1R;&5N*"1M971A<ELD
M:5TI("L@,BD@+R`X*2D["B`@("`@("`@("`@("`@("!E8VAO(")<(B(N)&UE
M=&%R6R1I72XB7"(B+B1T86(N(BT^("(["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("\O($EN:71I86QI>F4@<V]M92!A<G)A>7,*("`@("`@("`@("`@
M)')E<W5L="`@(#T@87)R87DH*3L*("`@("`@("`@("`@)')E<W5L=%9&(#T@
M87)R87DH*3L*("`@("`@("`@("`@)&QR97-U;'0@(#T@87)R87DH*3L*"B`@
M("`@("`@("`@("1F;W5N9"`](&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H
M("@D;65T87)#;V1E(&%S("1K97D@/3X@)')E9V5X<"D@>PH@("`@("`@("`@
M("`@("`@+R\@0VAE8VL@:68@8W5R<F5N="!C;V1E(&UA=&-H97,@8W5R<F5N
M="!M971A<B!S;FEP<&5T"B`@("`@("`@("`@("`@("!I9B`H*"1F;W5N9"`]
M('!R96=?;6%T8V@H(B]>(BXD<F5G97AP+B(D+VDB+"`D;65T87);)&E=+"`D
M<F5S=6QT*2D@/3T@=')U92D@>PH@("`@("`@("`@("`@("`@("`@('-W:71C
M:"`H)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S=&%T
M:6]N(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)S
M=&%T:6]N(ET@/2`D<F5S=6QT6S!=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@=6YS970H)&UE=&%R0V]D95LB<W1A=&EO;B)=*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")W:6YD(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%!A<G-E('=I;F0@9&%T82P@9FER<W0@=&AE('-P965D+"!C;VYV97)T
M(&9R;VT@:W0@=&\@8VAO<V5N('5N:70*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)W:6YD(ET@/2`D=&AI<RT^8V]N=F5R=%-P965D
M*"1R97-U;'1;,ETL('-T<G1O;&]W97(H)')E<W5L=%LU72DL(")M<&@B*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]
M(")605(B('Q\("1R97-U;'1;,5T@/3T@(E920B(I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!687)I86)L92!W:6YD<PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)W:6YD1&5G<F5E
M<R)=("`@/2`B5F%R:6%B;&4B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)W:6YD1&ER96-T:6]N(ET@/2`B5F%R:6%B;&4B
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!3879E('=I;F0@9&5G<F5E
M(&%N9"!C86QC(&1I<F5C=&EO;@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)W:6YD1&5G<F5E<R)=("`@/2!I;G1V86PH)')E
M<W5L=%LQ72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G=I;F1$:7)E8W1I;VXB72`]("1C;VUP87-S6W)O=6YD*"1R97-U
M;'1;,5T@+R`R,BXU*2`E(#$V73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE
M<FEC*"1R97-U;'1;-%TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5VEN9"!W:71H(&=U<W1S+BXN"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1'=7-T(ET@/2`D=&AI<RT^
M8V]N=F5R=%-P965D*"1R97-U;'1;-%TL('-T<G1O;&]W97(H)')E<W5L=%LU
M72DL(")M<&@B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E(")W:6YD5F%R(CH*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O($]N8V4@;6]R92!W:6YD+"!N;W<@=F%R:6%B:6QI='D@
M87)O=6YD('1H92!C=7)R96YT('=I;F0M9&ER96-T:6]N"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=VEN9%9A<FEA8FEL:71Y(ET@
M/2!A<G)A>2@B9G)O;2(@/3X@:6YT=F%L*"1R97-U;'1;,5TI+"`B=&\B(#T^
M(&EN='9A;"@D<F5S=6QT6S)=*2D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=FES
M1G)A8R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0;W-S:6)L
M92!F<F%C=&EO;F%L('9I<VEB:6QI='D@:&5R92X@0VAE8VL@:68@:70@;6%T
M8VAE<R!W:71H('1H92!N97AT($U%5$%2('!I96-E(&9O<B!V:7-I8FEL:71Y
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H(6ES<V5T*"1M971A
M<ELD:2`K(#%=*2!\?"`A<')E9U]M871C:"@B+UXB+B1M971A<D-O9&5;(G9I
M<VEB:6QI='DB72XB)"]I(BP@)')E<W5L=%LQ72XB("(N)&UE=&%R6R1I("L@
M,5TL("1R97-U;'161BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!.;R!N97AT($U%5$%2('!I96-E(&%V86EL86)L92!O<B!N;W0@
M;6%T8VAI;F<N($UA=&-H(&%G86EN<W0@;F5X="!-151!4B!C;V1E"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O=6YD(#T@9F%L<V4["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O($UA=&-H+B!(86YD(&]V97(@<F5S=6QT(&%N
M9"!A9'9A;F-E($U%5$%2"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@:68@*%-%4E9)0T537U=%051(15)?1$5"54<I('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`D:V5Y+B)<;B(["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@(EPB(BXD<F5S
M=6QT6S%=+B(@(BXD;65T87);)&D@*R`Q72XB7"(B+G-T<E]R97!E870H(EQT
M(BP@,B`M(&9L;V]R*"AS=')L96XH)')E<W5L=%LQ72XB("(N)&UE=&%R6R1I
M("L@,5TI("L@,BD@+R`X*2DN(BT^("(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1K97D@/2`B=FES:6)I;&ET>2(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)')E<W5L="`]("1R97-U;'161CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D:2LK.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V:7-I8FEL
M:71Y(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V
M:7-1=6%L:69I97(B72`](")!5"(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2`F)B`H)')E<W5L=%LQ
M72`]/2`Y.3DY*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("\O(%5P<&5R(&QI;6ET(&]F('9I<VEB:6QI='D@<F%N9V4*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES+3YC
M;VYV97)T1&ES=&%N8V4H,3`L(")K;2(L(")S;2(I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`]
M(")"15E/3D0B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M:68@*&ES7VYU;65R:6,H)')E<W5L=%LQ72DI('L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`O+R`T+61I9VET('9I<VEB:6QI='D@:6X@;0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@H)')E<W5L=%LQ72\Q,#`P*2P@(FMM
M(BP@(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V5I
M9B`H(6ES<V5T*"1R97-U;'1;,3%=*2!\?"`D<F5S=6QT6S$Q72`A/2`B0T%6
M3TLB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R
M97-U;'1;,UT@/3T@(DTB*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"14Q/5R([
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*"1R
M97-U;'1;,UT@/3T@(E`B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)V:7-1=6%L:69I97(B72`](")"15E/3D0B
M.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-?;G5M97)I8R@D<F5S=6QT
M6S5=*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!V:7-I8FEL:71Y(&%S(&]N92]T=V\M9&EG:70@;G5M8F5R"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@)'1H
M:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6S5=+"`D<F5S=6QT6S$P72P@
M(G-M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@=&AE
M('DO>B!P87)T+"!A9&0@:68@=V4@:&%D(&$@>"!P87)T("AS964@=FES:6)I
M;&ET>3$I"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]N=6UE<FEC*"1R97-U;'1;-UTI*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES+3YC
M;VYV97)T1&ES=&%N8V4H)')E<W5L=%LW72`K("1R97-U;'1;.%T@+R`D<F5S
M=6QT6SE=+"`D<F5S=6QT6S$P72P@(G-M(BD["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES+3YC
M;VYV97)T1&ES=&%N8V4H)')E<W5L=%LX72`O("1R97-U;'1;.5TL("1R97-U
M;'1;,3!=+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI9FEE<B)=
M(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'9I<VEB:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*#$P+"`B:VTB
M+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I
M;G1E<ELB8VQO=61S(ET@/2!A<G)A>2AA<G)A>2@B86UO=6YT(B`]/B`B0VQE
M87(@8F5L;W<B+"`B:&5I9VAT(B`]/B`U,#`P*2D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=(#T@(FYO
M('-I9VYI9FEC86YT('=E871H97(B.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);
M(G9I<VEB:6QI='DB72`]("1V:7-I8FEL:71Y.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A
M<V4@(F-O;F1I=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!&:7)S="!S;VUE(&)A<VEC('-E='5P<PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O
M;F1I=&EO;B)=(#T@(B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R;&5N*"1P;VEN=&5R6R)C;VYD:71I;VXB72D@/B`P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O
M;F1I=&EO;B)=("X]("(L(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:6Y?87)R87DH
M<W1R=&]L;W=E<B@D<F5S=6QT6S!=*2P@)&-O;F1I=&EO;G,I*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1FER<W0@=')Y(&UA=&-H
M:6YG('1H92!C;VUP;&5T92!S=')I;F<*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@+CT@(B`B+B1C;VYD
M:71I;VYS6W-T<G1O;&]W97(H)')E<W5L=%LP72E=.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!.;R!L=6-K+"!M871C:"!P87)T(&)Y('!A<G0*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!A<G)A>5]S:&EF="@D<F5S
M=6QT*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT
M(#T@87)R87E?=6YI<75E*"1R97-U;'0I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&9O<F5A8V@@*"1R97-U;'0@87,@)&-O;F1I=&EO;BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<W1R
M;&5N*"1C;VYD:71I;VXI(#X@,"D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-O;F1I=&EO;B)=("X]("(@
M(BXD8V]N9&ET:6]N<UMS=')T;VQO=V5R*"1C;VYD:71I;VXI73L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C
M;VYD:71I;VXB72`]('1R:6TH)'!O:6YT97);(F-O;F1I=&EO;B)=*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@
M("`@("`@("`@("!C87-E(")C;&]U9',B.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@:68@*"%I<W-E="@D<&]I;G1E<ELB8VQO=61S(ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F-L;W5D
M<R)=(#T@87)R87DH*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H<VEZ96]F*"1R97-U
M;'0I(#T](#4I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O
M+R!/;FQY(&%M;W5N="!A;F0@:&5I9VAT"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@/3X@)&-L;W5D
M<UMS=')T;VQO=V5R*"1R97-U;'1;,UTI72P@(FAE:6=H="(@/3X@*"1R97-U
M;'1;-%TJ,3`P*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!E;'-E:68@*'-I>F5O9B@D<F5S
M=6QT*2`]/2`V*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@06UO=6YT+"!H96EG:'0@86YD('1Y<&4*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D8VQO
M=61S6W-T<G1O;&]W97(H)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H)')E
M<W5L=%LT72HQ,#`I+"`B='EP92(@/3X@)&-L;W5D<UMS=')T;VQO=V5R*"1R
M97-U;'1;-5TI72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`O+R!32T,@;W(@0TQ2(&]R($Y30PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9"`](&%R<F%Y*")A
M;6]U;G0B(#T^("1C;&]U9'-;<W1R=&]L;W=E<B@D<F5S=6QT6S!=*5TI.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!O:6YT97);(F-L;W5D<R)=6UT@/2`D8VQO=60["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`B=&5M<&5R871U<F4B.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@;F]R;6%L('1E;7!E<F%T=7)E(&EN(&9I<G-T
M('!A<G0*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&YE9V%T:79E
M('9A;'5E"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L
M=%LQ72`]/2`B32(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<F5S=6QT6S)=("H]("TQ.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G1E
M;7!E<F%T=7)E(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U
M;'1;,ETL(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&EF("AS:7IE;V8H)')E<W5L="D@/B`T*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@+R\@<V%M92!F;W(@9&5W<&]I;G0*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LT72`]/2`B32(I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L
M=%LU72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F1E
M=U!O:6YT(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;
M-5TL(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB:'5M:61I='DB72`]("1T:&ES+3YC86QC=6QA=&5(=6UI
M9&ET>2@D<F5S=6QT6S)=+"`D<F5S=6QT6S5=*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<W-E="@D<&]I;G1E<ELB=VEN9")=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O($YO=R!C86QC=6QA=&4@=VEN9&-H:6QL(&9R
M;VT@=&5M<&5R871U<F4@86YD('=I;F1S<&5E9`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)F96QT5&5M<&5R871U<F4B72`]
M("1T:&ES+3YC86QC=6QA=&57:6YD0VAI;&PH)'!O:6YT97);(G1E;7!E<F%T
M=7)E(ETL("1P;VEN=&5R6R)W:6YD(ETI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G!R97-S=7)E(CH*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T](")!
M(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%!R97-S
M=7)E('!R;W9I9&5D(&EN(&EN8VAE<PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("1P;VEN=&5R6R)P<F5S<W5R92)=(#T@)')E<W5L=%LR72`O
M(#$P,#L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS96EF("@D
M<F5S=6QT6S-=(#T](")1(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O("XN+B!I;B!H96-T;W!A<V-A;`H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R6R)P<F5S<W5R92)=(#T@)'1H:7,M
M/F-O;G9E<G10<F5S<W5R92@D<F5S=6QT6S1=+"`B:'!A(BP@(FEN(BD["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B=')E;F0B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5V4@
M;6%Y(&AA=F4@82!T<F5N9"!H97)E+BXN(&5X=')A8W0@='EP92!A;F0@<V5T
M('!O:6YT97(@;VX*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(&-R
M96%T960@;F5W(&%R<F%Y"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H(6ES<V5T*"1W96%T:&5R1&%T85LB=')E;F0B72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G1R96YD(ET@
M/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M96%T:&5R1&%T85LB=')E;F0B75LD=')E;F1#;W5N=%T@/2!A<G)A>2@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!O:6YT97(@/28@)'=E871H97)$871A6R)T<F5N9")=
M6R1T<F5N9$-O=6YT73L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T
M<F5N9$-O=6YT*RL["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I
M;G1E<ELB='EP92)=(#T@)')E<W5L=%LP73L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('=H:6QE("AI<W-E="@D;65T87);)&D@*R`Q72D@)B8@<')E
M9U]M871C:"@B+UXH1DU\5$Q\050I*%QD>S)]*2A<9'LR?2DD+VDB+"`D;65T
M87);)&D@*R`Q72P@)&QR97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*"1L<F5S=6QT6S%=(#T](")&32(I('L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(F9R;VTB
M72`]("1L<F5S=6QT6S)=+B(Z(BXD;')E<W5L=%LS73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)&QR97-U;'1;,5T@/3T@
M(E1,(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M<&]I;G1E<ELB=&\B72`]("1L<F5S=6QT6S)=+B(Z(BXD;')E<W5L=%LS73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB870B
M72`]("1L<F5S=6QT6S)=+B(Z(BXD;')E<W5L=%LS73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@07,@=V4@:&%V92!J=7-T(&5X=')A8W1E9"!T:&4@=&EM
M92!F;W(@=&AI<R!T<F5N9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("\O(&9R;VT@;W5R($U%5$%2+"!I;F-R96%S92!F:65L9"UC;W5N=&5R
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&DK*SL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")R
M96UA<FLB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4F5M87)K
M('!A<G0@8F5G:6YS"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;65T
M87)#;V1E(#T@)')E;6%R:W,["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")A=71O<W1A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!7:&EC:"!A=71O<W1A=&EO;B!D;R!W92!H879E(&AE<F4_
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H)')E<W5L=%LQ72`]
M/2`P*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H
M97)$871A6R)R96UA<FLB75LB875T;W-T871I;VXB72`](")!=71O;6%T:6,@
M=V5A=&AE<G-T871I;VX@=R]O('!R96-I<&ET871I;VX@9&ES8W)I;6EN871O
M<B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M
M87)K(EU;(F%U=&]S=&%T:6]N(ET@/2`B075T;VUA=&EC('=E871H97)S=&%T
M:6]N('<O('!R96-I<&ET871I;VX@9&ES8W)I;6EN871O<B(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!U;G-E="@D;65T87)#;V1E6R)A=71O<W1A=&EO;B)=*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E(")P<F5S<V-H9R(Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!$96-O9&EN9R!F;W(@<F%P:60@<')E<W-U<F4@8VAA;F=E
M<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<G1O;&]W97(H
M)')E<W5L=%LQ72D@/3T@(G(B*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'=E871H97)$871A6R)R96UA<FLB75LB<')E<W-C:&<B72`]
M(")0<F5S<W5R92!R:7-I;F<@<F%P:61L>2(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G!R97-S8VAG(ET@/2`B
M4')E<W-U<F4@9F%L;&EN9R!R87!I9&QY(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1M971A<D-O9&5;(G!R97-S8VAG(ETI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G-E87!R97-S=7)E(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M(%!R97-S=7)E(&%T('-E82!L979E;"`H9&5L:79E<F5D(&EN(&AP82D*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($1E8V]D:6YG(&ES(&$@8FET
M(&]B<V-U<F4@87,@.3@R(&=E=',@.3DX+C(*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O('=H97)E87,@,3$S(&)E8V]M97,@,3$Q,R`M/B!N;R!R
M96%L(')U;&4@:&5R90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'-T<G1O;&]W97(H)')E<W5L=%LQ72D@(3T@(FYO(BD@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#X@-3`P*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F5S<R`]
M(#DP,"`K(')O=6YD*"1R97-U;'1;,5T@+R`Q,#`L(#$I.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P<F5S<R`](#$P,#`@*R`D<F5S=6QT
M6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R
M:R)=6R)S96%P<F5S<W5R92)=(#T@)'1H:7,M/F-O;G9E<G10<F5S<W5R92@D
M<')E<W,L(")H<&$B+"`B:6XB*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A
M<D-O9&5;(G-E87!R97-S=7)E(ETI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G!R
M96-I<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!0<F5C:7!I
M=&%T:6]N(&EN(&EN8VAE<PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M<W1A=&EC("1H;W5R<SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'=E871H97)$871A6R)P<F5C:7!I=&%T:6]N(ETI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$871A6R)P
M<F5C:7!I=&%T:6]N(ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1H;W5R<R`](&%R<F%Y*")0(B`]/B`B,2(L("(V(B`]
M/B`B,R\V(BP@(C<B(#T^("(R-"(I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"%I<U]N
M=6UE<FEC*"1R97-U;'1;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'!R96-I<"`](")I;F1E=&5R;6EN86)L92(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!](&5L<V5I9B`H)')E<W5L=%LR72`]/2`B
M,#`P,"(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<')E
M8VEP(#T@(G1R86-E86)L92(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!]96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!R
M96-I<"`]("1R97-U;'1;,ET@+R`Q,#`["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE
M<D1A=&%;(G!R96-I<&ET871I;VXB75M=(#T@87)R87DH"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(F%M;W5N="(@/3X@)'!R96-I<"P*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`B:&]U<G,B("`]/B`D:&]U
M<G-;)')E<W5L=%LQ75T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B<VYO=V1E<'1H(CH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%-N;W<@9&5P=&@@:6X@:6YC:&5S"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=
M6R)S;F]W9&5P=&@B72`]("1R97-U;'1;,5T["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)S;F]W9&5P=&@B72D["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@("`@("`@("`@8V%S92`B<VYO=V5Q=6EV(CH*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%-A;64@9F]R(&5Q=6EV86QE;G0@:6X@5V%T97(N
M+BX@*&EN8VAE<RD*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T
M:&5R1&%T85LB<F5M87)K(EU;(G-N;W=E<75I=B)=(#T@)')E<W5L=%LQ72`O
M(#$P.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R
M0V]D95LB<VYO=V5Q=6EV(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F-L;W5D
M='EP97,B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@0VQO=60@
M='EP97,L(&AA=F5N)W0@9F]U;F0@82!W87D@9F]R(&1E8V5N="!D96-O9&EN
M9R`H>65T*0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE
M=&%R0V]D95LB8VQO=61T>7!E<R)=*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")S
M=6YD=7)A=&EO;B(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!$
M=7)A=&EO;B!O9B!S=6YS:&EN92`H:6X@;6EN=71E<RD*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G-U;F1U
M<F%T:6]N(ET@/2`B5&]T86P@;6EN=71E<R!O9B!S=6YS:&EN93H@(BXD<F5S
M=6QT6S%=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE
M=&%R0V]D95LB<W5N9'5R871I;VXB72D["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B
M,6AT96UP9&5W(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%1E
M;7!E<F%T=7)E<R!I;B!T:&4@;&%S="!H;W5R(&EN($,*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S%=(#T]("(Q(BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@*CT@+3$[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R(Q:'1E;7`B
M72`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L=%LR72`O(#$P
M+"`B8R(L(")F(BD["@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@
M*'-I>F5O9B@D<F5S=6QT*2`^(#,I('L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!S86UE(&9O<B!D97=P;VEN=`H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@D<F5S=6QT6S1=(#T]("(Q(BD@>PH@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<F5S=6QT6S5=
M("H]("TQ.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(G)E
M;6%R:R)=6R(Q:&1E=R)=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D
M<F5S=6QT6S5=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1M971A<D-O9&5;(C%H=&5M<&1E=R)=*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("(V:&UA>'1E;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@
M36%X('1E;7!E<F%T=7)E(&EN('1H92!L87-T(#8@:&]U<G,@:6X@0PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@(C$B
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L=%LR
M72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;
M(C9H;6%X=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S
M=6QT6S)=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@('5N<V5T*"1M971A<D-O9&5;(C9H;6%X=&5M<")=*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E("(V:&UI;G1E;7`B.@H@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@36EN('1E;7!E<F%T=7)E(&EN('1H92!L87-T(#8@:&]U
M<G,@:6X@0PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U
M;'1;,5T@/3T@(C$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@)')E<W5L=%LR72`J/2`M,3L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T
M85LB<F5M87)K(EU;(C9H;6EN=&5M<")=(#T@)'1H:7,M/F-O;G9E<G1496UP
M97)A='5R92@D<F5S=6QT6S)=("\@,3`L(")C(BP@(F8B*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('5N<V5T*"1M971A<D-O9&5;(C9H;6EN=&5M
M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("(R-&AT96UP(CH*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O($UA>"]-:6X@=&5M<&5R871U<F5S(&EN
M('1H92!L87-T(#(T(&AO=7)S(&EN($,*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("@D<F5S=6QT6S%=(#T]("(Q(BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1R97-U;'1;,ET@*CT@+3$["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R(R-&AM87AT96UP(ET@/2`D
M=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1R97-U;'1;,ET@+R`Q,"P@(F,B
M+"`B9B(I.PH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("@D<F5S
M=6QT6S-=(#T]("(Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1R97-U;'1;-%T@*CT@+3$["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A
M=&%;(G)E;6%R:R)=6R(R-&AM:6YT96UP(ET@/2`D=&AI<RT^8V]N=F5R=%1E
M;7!E<F%T=7)E*"1R97-U;'1;-%T@+R`Q,"P@(F,B+"`B9B(I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB,C1H=&5M
M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E("(S:'!R97-S=&5N9"(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!792!D;VXG="!S879E('1H92!P
M<F5S<W5R92!D=7)I;F<@=&AE(&1A>2P@<V\@;F\@9&5C;V1I;F<*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O('!O<W-I8FQE+"!S;W)R>0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)&UE=&%R0V]D95LB,VAP
M<F5S<W1E;F0B72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A
M:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B;F]S<&5C:2(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!.;R!C:&%N9V4@9'5R:6YG
M('1H92!L87-T(&AO=7(*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1W
M96%T:&5R1&%T85LB<F5M87)K(EU;(FYO<W!E8VDB72`](").;R!C:&%N9V5S
M(&EN('=E871H97(@8V]N9&ET:6]N<R(["B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!U;G-E="@D;65T87)#;V1E6R)N;W-P96-I(ETI.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-A<V4@(G-E;G-O<G,B.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@5V4@;6%Y(&AA=F4@;75L=&EP;&4@8G)O:V5N('-E;G-O<G,L
M('-O(&1O(&YO="!U;G-E=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M:68@*"%I<W-E="@D=V5A=&AE<D1A=&%;(G)E;6%R:R)=6R)S96YS;W)S(ETI
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'=E871H97)$
M871A6R)R96UA<FLB75LB<V5N<V]R<R)=(#T@87)R87DH*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;(G-E;G-O<G,B75MS=')T;VQO
M=V5R*"1R97-U;'1;,%TI72`]("1S96YS;W)S6W-T<G1O;&]W97(H)')E<W5L
M=%LP72E=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FUA:6YT86EN(CH*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1W96%T:&5R1&%T85LB<F5M87)K(EU;
M(FUA:6YT86EN(ET@/2`B36%I;G1A:6YA;F-E(&YE961E9"(["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!U;G-E="@D;65T87)#;V1E6R)M86EN=&%I
M;B)=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@+R\@1&\@;F]T:&EN9RP@:G5S="!P<F5V96YT(&9U<G1H
M97(@;6%T8VAI;F<*("`@("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T
M*"1M971A<D-O9&5;)&ME>5TI.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@("`@(&EF("@D9F]U;F0@)B8@(5-%4E9)0T537U=%051(15)?1$5"54<I
M('L*("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E:68@*"1F;W5N9"`F)B!315)624-%4U]714%42$52
M7T1%0E5'*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&5C:&\@)&ME>2XB
M7&XB.PH@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*"$D9F]U;F0I('L*("`@("`@("`@("`@("`@(&EF
M("A315)624-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@("`@
M("`@96-H;R`B;B]A7&XB.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@:68@*"%I<W-E="@D=V5A=&AE<D1A=&%;(FYO<&%R<V4B72DI('L*
M("`@("`@("`@("`@("`@("`@("`D=V5A=&AE<D1A=&%;(FYO<&%R<V4B72`]
M(&%R<F%Y*"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D
M=V5A=&AE<D1A=&%;(FYO<&%R<V4B75M=(#T@)&UE=&%R6R1I73L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*&ES<V5T*"1W96%T:&5R
M1&%T85LB;F]P87)S92)=*2D@>PH@("`@("`@("`@("`D=V5A=&AE<D1A=&%;
M(FYO<&%R<V4B72`](&EM<&QO9&4H(B`B+"`@)'=E871H97)$871A6R)N;W!A
M<G-E(ETI.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1W96%T:&5R1&%T
M83L*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?<&%R<V5&;W)E8V%S
M=$1A=&$H*0H@("`@+RHJ"B`@("`@*B!087)S97,@=&AE(&1A=&$@86YD(&-A
M8VAE<R!I=`H@("`@("H*("`@("`J(%1!1B!+3$=!(#(W,3<S-%H@,C<Q.#$X
M(#$Q,#`W2U0@4#9332`M4D$@4T-4,#(P($)+3C(P,`H@("`@("H@("`@($9-
M,C,P,"`Q-#`P-TM4(%`V4TT@4T-4,#,P($)+3C$U,`H@("`@("H@("`@($9-
M,#0P,"!64D(P,TM4(%`V4TT@4T-4,#,U($]60S`X,"!04D]",S`@,#4P.2!0
M-E--("U202!"2TXP,S4*("`@("`J("`@("!&33`Y,#`@5E)",#-+5"`V4TT@
M+5)!($)2(%-#5#`Q-2!/5D,P,S4*("`@("`J("`@("`@("`@5$5-4$\@,3(Q
M-2`U4TT@+5)!($)2(%-#5#`P.2!"2TXP,34*("`@("`J("`@("`@("`@0D5#
M34<@,34Q-R`Q-C`P-TM4(%`V4TT@3E-7(%-#5#`Q-2!"2TXP-S`*("`@("`J
M"B`@("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@
M)&1A=&$*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!F=6YC=&EO;B!?<&%R
M<V5&;W)E8V%S=$1A=&$H)&1A=&$I"B`@("!["B`@("`@("`@<W1A=&EC("1C
M;VUP87-S.PH@("`@("`@('-T871I8R`D8VQO=61S.PH@("`@("`@('-T871I
M8R`D8V]N9&ET:6]N<SL*("`@("`@("!S=&%T:6,@)'-E;G-O<G,["B`@("`@
M("`@:68@*"%I<W-E="@D8V]M<&%S<RDI('L*("`@("`@("`@("`@)&-O;7!A
M<W,@/2!A<G)A>2@*("`@("`@("`@("`@("`@(").(BP@(DY.12(L(").12(L
M(")%3D4B+`H@("`@("`@("`@("`@("`@(D4B+"`B15-%(BP@(E-%(BP@(E-3
M12(L"B`@("`@("`@("`@("`@("`B4R(L(")34U<B+"`B4U<B+"`B5U-7(BP*
M("`@("`@("`@("`@("`@(")7(BP@(E=.5R(L(").5R(L(").3E<B"B`@("`@
M("`@("`@("D["B`@("`@("`@("`@("1C;&]U9',@("`@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@(")S:V,B("`@("`@("`@/3X@(G-K>2!C;&5A<B(L"B`@
M("`@("`@("`@("`@("`B;G-C(B`@("`@("`@(#T^(")N;R!S:6=N:69I8V%N
M="!C;&]U9"(L"B`@("`@("`@("`@("`@("`B9F5W(B`@("`@("`@(#T^(")F
M97<B+`H@("`@("`@("`@("`@("`@(G-C="(@("`@("`@("`]/B`B<V-A='1E
M<F5D(BP*("`@("`@("`@("`@("`@(")B:VXB("`@("`@("`@/3X@(F)R;VME
M;B(L"B`@("`@("`@("`@("`@("`B;W9C(B`@("`@("`@(#T^(")O=F5R8V%S
M="(L"B`@("`@("`@("`@("`@("`B=G8B("`@("`@("`@(#T^(")V97)T:6-A
M;"!V:7-I8FEL:71Y(BP*("`@("`@("`@("`@("`@(")T8W4B("`@("`@("`@
M/3X@(E1O=V5R:6YG($-U;75L=7,B+`H@("`@("`@("`@("`@("`@(F-B(B`@
M("`@("`@("`]/B`B0W5M=6QO;FEM8G5S(BP*("`@("`@("`@("`@("`@(")C
M;'(B("`@("`@("`@/3X@(F-L96%R(&)E;&]W(#$R+#`P,"!F="(*("`@("`@
M("`@("`@*3L*("`@("`@("`@("`@)&-O;F1I=&EO;G,@/2!A<G)A>2@*("`@
M("`@("`@("`@("`@("(K(B`@("`@("`@("`@/3X@(FAE879Y(BP@("`@("`@
M("(M(B`@("`@("`@("`@/3X@(FQI9VAT(BP*"B`@("`@("`@("`@("`@("`B
M=F,B("`@("`@("`@(#T^(")V:6-I;FET>2(L("`@("`B<F4B("`@("`@("`@
M(#T^(")R96-E;G0B+`H@("`@("`@("`@("`@("`@(FYS=R(@("`@("`@("`]
M/B`B;F\@<VEG;FEF:6-A;G0@=V5A=&AE<B(L"@H@("`@("`@("`@("`@("`@
M(FUI(B`@("`@("`@("`]/B`B<VAA;&QO=R(L("`@("`@(F)C(B`@("`@("`@
M("`]/B`B<&%T8VAE<R(L"B`@("`@("`@("`@("`@("`B<'(B("`@("`@("`@
M(#T^(")P87)T:6%L(BP@("`@("`B=',B("`@("`@("`@(#T^(")T:'5N9&5R
M<W1O<FTB+`H@("`@("`@("`@("`@("`@(F)L(B`@("`@("`@("`]/B`B8FQO
M=VEN9R(L("`@("`@(G-H(B`@("`@("`@("`]/B`B<VAO=V5R<R(L"B`@("`@
M("`@("`@("`@("`B9'(B("`@("`@("`@(#T^(")L;W<@9')I9G1I;F<B+"`B
M9GHB("`@("`@("`@(#T^(")F<F5E>FEN9R(L"@H@("`@("`@("`@("`@("`@
M(F1Z(B`@("`@("`@("`]/B`B9')I>GIL92(L("`@("`@(G)A(B`@("`@("`@
M("`]/B`B<F%I;B(L"B`@("`@("`@("`@("`@("`B<VXB("`@("`@("`@(#T^
M(")S;F]W(BP@("`@("`@("`B<V<B("`@("`@("`@(#T^(")S;F]W(&=R86EN
M<R(L"B`@("`@("`@("`@("`@("`B:6,B("`@("`@("`@(#T^(")I8V4@8W)Y
M<W1A;',B+"`B<&4B("`@("`@("`@(#T^(")I8V4@<&5L;&5T<R(L"B`@("`@
M("`@("`@("`@("`B9W(B("`@("`@("`@(#T^(")H86EL(BP@("`@("`@("`B
M9W,B("`@("`@("`@(#T^(")S;6%L;"!H86EL+W-N;W<@<&5L;&5T<R(L"B`@
M("`@("`@("`@("`@("`B=7`B("`@("`@("`@(#T^(")U;FMN;W=N('!R96-I
M<&ET871I;VXB+`H*("`@("`@("`@("`@("`@(")B<B(@("`@("`@("`@/3X@
M(FUI<W0B+"`@("`@("`@(")F9R(@("`@("`@("`@/3X@(F9O9R(L"B`@("`@
M("`@("`@("`@("`B9G4B("`@("`@("`@(#T^(")S;6]K92(L("`@("`@("`B
M=F$B("`@("`@("`@(#T^(")V;VQC86YI8R!A<V@B+`H@("`@("`@("`@("`@
M("`@(G-A(B`@("`@("`@("`]/B`B<V%N9"(L("`@("`@("`@(FAZ(B`@("`@
M("`@("`]/B`B:&%Z92(L"B`@("`@("`@("`@("`@("`B<'DB("`@("`@("`@
M(#T^(")S<')A>2(L("`@("`@("`B9'4B("`@("`@("`@(#T^(")W:61E<W!R
M96%D(&1U<W0B+`H*("`@("`@("`@("`@("`@(")S<2(@("`@("`@("`@/3X@
M(G-Q=6%L;"(L("`@("`@(")S<R(@("`@("`@("`@/3X@(G-A;F1S=&]R;2(L
M"B`@("`@("`@("`@("`@("`B9',B("`@("`@("`@(#T^(")D=7-T<W1O<FTB
M+"`@("`B<&\B("`@("`@("`@(#T^(")W96QL(&1E=F5L;W!E9"!D=7-T+W-A
M;F0@=VAI<FQS(BP*("`@("`@("`@("`@("`@(")F8R(@("`@("`@("`@/3X@
M(F9U;FYE;"!C;&]U9"(L"@H@("`@("`@("`@("`@("`@(BMF8R(@("`@("`@
M("`]/B`B=&]R;F%D;R]W871E<G-P;W5T(@H@("`@("`@("`@("`I.PH@("`@
M("`@('T*"B`@("`@("`@)'1A9D-O9&4@/2!A<G)A>2@*("`@("`@("`@("`@
M(G)E<&]R="(@("`@("`]/B`B5$%&?$%-1"(L"B`@("`@("`@("`@(")S=&%T
M:6]N(B`@("`@/3X@(EQW>S1](BP*("`@("`@("`@("`@(G5P9&%T92(@("`@
M("`]/B`B*%QD>S)]*3\H7&1[-'TI6B(L"B`@("`@("`@("`@(")V86QI9"(@
M("`@("`@/3X@(BA<9'LR?2DH7&1[,GTI*%QD>S)]*2(L"B`@("`@("`@("`@
M(")W:6YD(B`@("`@("`@/3X@(BA<9'LS?7Q605)\5E)"*2A<9'LR+#-]*2A'
M*%QD>S)]*2D_*%QW>S(L,WTI(BP*("`@("`@("`@("`@(G9I<T9R86,B("`@
M("`]/B`B*%QD>S%]*2(L"B`@("`@("`@("`@(")V:7-I8FEL:71Y(B`@/3X@
M(BA<9'LT?2E\*"A-?%`I/R@H7&1[,2PR?7PH*%QD*2`I/RA<9"E<+RA<9"DI
M*%--?$M-*2DI?"A#059/2RDB+`H@("`@("`@("`@("`B8V]N9&ET:6]N(B`@
M(#T^("(H+7Q<*WQ60WQ217Q.4U<I/RA-27Q"0WQ04GQ44WQ"3'Q32'Q$4GQ&
M6BD_*"A$6BE\*%)!*7PH4TXI?"A31RE\*$E#*7PH4$PI?"A'4BE\*$=3*7PH
M55`I*2HH0E)\1D=\1E5\5D%\1%5\4T%\2%I\4%DI/RA03WQ347Q&0WQ34WQ$
M4RD_(BP*("`@("`@("`@("`@(F-L;W5D<R(@("`@("`]/B`B*%-+0WQ#3%)\
M3E-#?"@H1D57?%-#5'Q"2TY\3U9#?%96*2A<9'LS?2DH5$-5?$-"*3\I*2(L
M"B`@("`@("`@("`@(")W:6YD<VAE87(B("`@/3X@(E=3*%QD>S-]*5PO*%QD
M>S-]*2A<9'LR+#-]*2A<=WLR+#-]*2(L"B`@("`@("`@("`@(")T96UP;6%X
M(B`@("`@/3X@(E18*%QD>S)]*5PO*%QD>S)]*2A<=RDB+`H@("`@("`@("`@
M("`B=&5M<&UI;B(@("`@(#T^(")43BA<9'LR?2E<+RA<9'LR?2DH7'<I(BP*
M("`@("`@("`@("`@(G1E;7!M87AM:6XB("`]/B`B5%@H7&1[,GTI7"\H7&1[
M,GTI*%QW*51.*%QD>S)]*5PO*%QD>S)]*2A<=RDB+`H@("`@("`@("`@("`B
M9G)O;2(@("`@("`@(#T^(")&32A<9'LR?2DH7&1[,GTI/R(L"B`@("`@("`@
M("`@(")F;6,B("`@("`@("`@/3X@(BA04D]"?$)%0TU'?%1%35!/*2A<9'LR
M?2D_(@H@("`@("`@("D["@H@("`@("`@(&EF("A315)624-%4U]714%42$52
M7T1%0E5'*2!["B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O
M9B@D9&%T82D[("1I*RLI('L*("`@("`@("`@("`@("`@(&5C:&\@)&1A=&%;
M)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@("\O($]K+"!W
M92!H879E(&-O<G)E8W0@9&%T82P@<W1A<G0@=VET:"!P87)S:6YG('1H92!F
M:7)S="!L:6YE(&9O<B!T:&4@;&%S="!U<&1A=&4*("`@("`@("`D9F]R96-A
M<W1$871A(#T@87)R87DH*3L*("`@("`@("`D9F]R96-A<W1$871A6R)S=&%T
M:6]N(ET@("`]("(B.PH@("`@("`@("1F;W)E8V%S=$1A=&%;(F1A=&%287<B
M72`@(#T@:6UP;&]D92@B("(L("1D871A*3L*("`@("`@("`D9F]R96-A<W1$
M871A6R)U<&1A=&4B72`@("`]('-T<G1O=&EM92AT<FEM*"1D871A6S!=*2XB
M($=-5"(I.PH@("`@("`@("1F;W)E8V%S=$1A=&%;(G5P9&%T95)A=R)=(#T@
M=')I;2@D9&%T85LP72D["B`@("`@("`@+R\@86YD('!R97!A<F4@=&AE(')E
M<W0@9F]R('-T97!P:6YG('1H<F]U9V@*("`@("`@("!A<G)A>5]S:&EF="@D
M9&%T82D["B`@("`@("`@)'1A9B`](&5X<&QO9&4H(B`B+"!P<F5G7W)E<&QA
M8V4H(B]<<WLR+'TO(BP@(B`B+"!I;7!L;V1E*"(@(BP@)&1A=&$I*2D["@H@
M("`@("`@("\O($%D9"!A(&9E=R!L;V-A;"!V87)I86)L97,@9F]R(&1A=&$@
M<')O8V5S<VEN9PH@("`@("`@("1F<F]M5&EM92`]("`B(CL@("`@("`@("`@
M("`O+R!4:&4@=&EM97!E<FEO9"!T:&4@9&%T82!G971S(&%D9&5D('1O"B`@
M("`@("`@)&9M8T-O=6YT(#T@(#`[("`@("`@("`@("`@("\O($EF('=E(&AA
M=F4@1DU#<R`H1F]R96-A<W0@365T96]R;VQO9VEC86P@0V]N9&ET:6]N<RDL
M('=E(&YE960@=&AI<PH@("`@("`@("1P;VEN=&5R("`])B`D9F]R96-A<W1$
M871A.R`O+R!0;VEN=&5R('1O('1H92!A<G)A>2!W92!A9&0@=&AE(&1A=&$@
M=&\*("`@("`@("!F;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1A9BD[("1I
M*RLI('L*("`@("`@("`@("`@+R\@0VAE8VL@9F]R('=H:71E<W!A8V4@86YD
M('-T97`@;&]O<"P@:68@;F]T:&EN9R=S('1H97)E"B`@("`@("`@("`@("1T
M869;)&E=(#T@=')I;2@D=&%F6R1I72D["B`@("`@("`@("`@(&EF("@A<W1R
M;&5N*"1T869;)&E=*2D@>PH@("`@("`@("`@("`@("`@8V]N=&EN=64["B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&EF("A315)624-%4U]714%42$52
M7T1%0E5'*2!["B`@("`@("`@("`@("`@("`D=&%B(#T@<W1R7W)E<&5A="@B
M7'0B+"`R("T@9FQO;W(H*'-T<FQE;B@D=&%F6R1I72D@*R`R*2`O(#@I*3L*
M("`@("`@("`@("`@("`@(&5C:&\@(EPB(BXD=&%F6R1I72XB7"(B+B1T86(N
M(BT^("(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($EN:71I86QI
M>F4@<V]M92!A<G)A>7,*("`@("`@("`@("`@)')E<W5L="`@(#T@87)R87DH
M*3L*("`@("`@("`@("`@)')E<W5L=%9&(#T@87)R87DH*3L*("`@("`@("`@
M("`@)&QR97-U;'0@(#T@87)R87DH*3L*"B`@("`@("`@("`@("1F;W5N9"`]
M(&9A;'-E.PH@("`@("`@("`@("!F;W)E86-H("@D=&%F0V]D92!A<R`D:V5Y
M(#T^("1R96=E>'`I('L*("`@("`@("`@("`@("`@("\O($-H96-K(&EF(&-U
M<G)E;G0@8V]D92!M871C:&5S(&-U<G)E;G0@=&%F('-N:7!P970*("`@("`@
M("`@("`@("`@(&EF("@H)&9O=6YD(#T@<')E9U]M871C:"@B+UXB+B1R96=E
M>'`N(B0O:2(L("1T869;)&E=+"`D<F5S=6QT*2D@/3T@=')U92D@>PH@("`@
M("`@("`@("`@("`@("`@("1I;G-E<G0@/2!A<G)A>2@I.PH@("`@("`@("`@
M("`@("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!C87-E(")S=&%T:6]N(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P;VEN=&5R6R)S=&%T:6]N(ET@/2`D<F5S=6QT6S!=.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@=6YS970H)'1A9D-O9&5;(G-T871I;VXB
M72D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@
M("`@("`@("`@("`@("`@("`@8V%S92`B=F%L:60B.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)'!O:6YT97);(G9A;&ED4F%W(ET@/2`D<F5S=6QT
M6S!=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1V5N97)A=&5S
M('1H92!T:6UE<&5R:6]D('1H92!R97!O<G0@:7,@=F%L:60@9F]R"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!L:7-T*"1Y96%R+"`D;6]N=&@L("1D
M87DI(#T@97AP;&]D92@B+2(L(&1A=&4H(EDM;2UD(BP@)&9O<F5C87-T1&%T
M85LB=7!D871E(ETI*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O
M($1A=&4@:7,@:6X@;F5X="!M;VYT:`H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*"1R97-U;'1;,5T@/"`D9&%Y*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&UO;G1H*RL["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I
M;G1E<ELB=F%L:61&<F]M(ET@/2!G;6UK=&EM92@D<F5S=6QT6S)=+"`P+"`P
M+"`D;6]N=&@L("1R97-U;'1;,5TL("1Y96%R*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%9A;&ED('1I;64@96YD<R!N97AT(&1A>0H@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,ET@/CT@)')E
M<W5L=%LS72D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1R
M97-U;'1;,5TK*SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V86QI9%1O(ET@
M("`](&=M;6MT:6UE*"1R97-U;'1;,UTL(#`L(#`L("1M;VYT:"P@)')E<W5L
M=%LQ72P@)'EE87(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'1A9D-O9&5;(G9A;&ED(ETI.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@3F]W('1H92!G<F]U<',@=VEL;"!S=&%R="P@<V\@:6YI=&EA
M;&EZ92!T:&4@=&EM92!G<F]U<',*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P;VEN=&5R6R)T:6UE(ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@)&9R;VU4:6UE(#T@)')E<W5L=%LR72XB.C`P(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)T:6UE(EU;
M)&9R;VU4:6UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`O+R!3970@<&]I;G1E<B!T;R!T:&4@9FER<W0@=&EM97!E<FEO9`H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97(@/28@)'!O:6YT
M97);(G1I;64B75LD9G)O;51I;65=.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I
M;F0B.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@4&%R<V4@=VEN
M9"!D871A+"!F:7)S="!T:&4@<W!E960L(&-O;G9E<G0@9G)O;2!K="!T;R!C
M:&]S96X@=6YI=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G=I;F0B72`]("1T:&ES+3YC;VYV97)T4W!E960H)')E<W5L=%LR72P@
M<W1R=&]L;W=E<B@D<F5S=6QT6S5=*2P@(FUP:"(I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*"1R97-U;'1;,5T@/3T@(E9!4B(@?'P@)')E
M<W5L=%LQ72`]/2`B5E)"(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O(%9A<FEA8FQE('=I;F1S"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@)'!O:6YT97);(G=I;F1$96=R965S(ET@("`](")687)I
M86)L92(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G=I;F1$:7)E8W1I;VXB72`](")687)I86)L92(["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%-A=F4@=VEN9"!D96=R964@86YD(&-A;&,@9&ER
M96-T:6]N"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G=I;F1$96=R965S(ET@("`]("1R97-U;'1;,5T["B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1$:7)E8W1I;VXB
M72`]("1C;VUP87-S6W)O=6YD*"1R97-U;'1;,5T@+R`R,BXU*2`E(#$V73L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;-%TI*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@5VEN9"!W:71H(&=U
M<W1S+BXN"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT
M97);(G=I;F1'=7-T(ET@/2`D=&AI<RT^8V]N=F5R=%-P965D*"1R97-U;'1;
M-%TL('-T<G1O;&]W97(H)')E<W5L=%LU72DL(")M<&@B*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(&EF("AI<W-E="@D<')O8F%B:6QI='DI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F10<F]B(ET@/2`D<')O
M8F%B:6QI='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS
M970H)'!R;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C87-E(")V:7-&<F%C(CH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%!O<W-I8FQE(&9R86-T:6]N86P@=FES:6)I
M;&ET>2!H97)E+B!#:&5C:R!I9B!I="!M871C:&5S('=I=&@@=&AE(&YE>'0@
M5$%&('!I96-E(&9O<B!V:7-I8FEL:71Y"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!I9B`H(6ES<V5T*"1T869;)&D@*R`Q72D@?'P@(7!R96=?;6%T
M8V@H(B]>(BXD=&%F0V]D95LB=FES:6)I;&ET>2)=+B(D+VDB+"`D<F5S=6QT
M6S%=+B(@(BXD=&%F6R1I("L@,5TL("1R97-U;'161BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!.;R!N97AT(%1!1B!P:65C92!A
M=F%I;&%B;&4@;W(@;F]T(&UA=&-H:6YG+B!-871C:"!A9V%I;G-T(&YE>'0@
M5$%&(&-O9&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D9F]U
M;F0@/2!F86QS93L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!B
M<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@36%T8V@N($AA;F0@
M;W9E<B!R97-U;'0@86YD(&%D=F%N8V4@5$%&"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@:68@*%-%4E9)0T537U=%051(15)?1$5"54<I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@96-H;R`D:V5Y
M+B)<;B(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&5C
M:&\@(EPB(BXD<F5S=6QT6S%=+B(@(BXD=&%F6R1I("L@,5TN(EPB(BYS=')?
M<F5P96%T*")<="(L(#(@+2!F;&]O<B@H<W1R;&5N*"1R97-U;'1;,5TN(B`B
M+B1T869;)&D@*R`Q72D@*R`R*2`O(#@I*2XB+3X@(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&ME>2`](")V:7-I8FEL:71Y(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`D<F5S=6QT(#T@)')E<W5L=%9&.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1I*RL["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@
M(G9I<VEB:6QI='DB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G9I<U%U86QI9FEE<B)=(#T@(D%4(CL*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC*"1R97-U;'1;,5TI("8F("@D
M<F5S=6QT6S%=(#T](#DY.3DI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@+R\@57!P97(@;&EM:70@;V8@=FES:6)I;&ET>2!R86YG90H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@Q,"P@(FMM(BP@(G-M(BD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI
M9FEE<B)=(#T@(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V5I9B`H:7-?;G5M97)I8R@D<F5S=6QT6S%=*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O(#0M9&EG:70@=FES:6)I;&ET
M>2!I;B!M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9I<VEB
M:6QI='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"@D<F5S=6QT6S%=+S$P
M,#`I+"`B:VTB+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M('T@96QS96EF("@A:7-S970H)')E<W5L=%LQ,5TI('Q\("1R97-U;'1;,3%=
M("$](")#059/2R(I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!I9B`H)')E<W5L=%LS72`]/2`B32(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI9FEE<B)=(#T@
M(D)%3$]7(CL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!](&5L
M<V5I9B`H)')E<W5L=%LS72`]/2`B4"(I('L*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G9I<U%U86QI9FEE<B)=(#T@
M(D)%64].1"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF("AI<U]N=6UE<FEC
M*"1R97-U;'1;-5TI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("\O('9I<VEB:6QI='D@87,@;VYE+W1W;RUD:6=I="!N=6UB97(*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'9I<VEB:6QI
M='D@/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1R97-U;'1;-5TL("1R97-U
M;'1;,3!=+"`B<VTB*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`O+R!T:&4@>2]Z('!A<G0L(&%D9"!I9B!W92!H860@82!X('!A<G0@*'-E
M92!V:7-I8FEL:71Y,2D*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@:68@*&ES7VYU;65R:6,H)')E<W5L=%LW72DI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6S==("L@)')E<W5L=%LX
M72`O("1R97-U;'1;.5TL("1R97-U;'1;,3!=+"`B<VTB*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1V:7-I8FEL:71Y(#T@
M)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D<F5S=6QT6SA=("\@)')E<W5L=%LY
M72P@)')E<W5L=%LQ,%TL(")S;2(I.PH@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=FES475A
M;&EF:65R(ET@/2`B0D593TY$(CL*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`D=FES:6)I;&ET>2`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H
M,3`L(")K;2(L(")S;2(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P;VEN=&5R6R)C;&]U9',B72`](&%R<F%Y*&%R<F%Y*")A;6]U;G0B
M(#T^(")#;&5A<B!B96QO=R(L(")H96EG:'0B(#T^(#4P,#`I*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N
M(ET@/2`B;F\@<VEG;FEF:6-A;G0@=V5A=&AE<B(["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-0<F]B(ET@/2`D<')O8F%B:6QI
M='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!R
M;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)V:7-I8FEL:71Y
M(ET@/2`D=FES:6)I;&ET>3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")C;VYD:71I
M;VXB.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@1FER<W0@<V]M
M92!B87-I8R!S971U<',*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'!O:6YT97);(F-O;F1I=&EO;B)=*2D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`]
M("(B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@?2!E;'-E:68@*'-T
M<FQE;B@D<&]I;G1E<ELB8V]N9&ET:6]N(ETI(#X@,"D@>PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`N
M/2`B+"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@:68@*&EN7V%R<F%Y*'-T<G1O;&]W97(H
M)')E<W5L=%LP72DL("1C;VYD:71I;VYS*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O($9I<G-T('1R>2!M871C:&EN9R!T:&4@8V]M
M<&QE=&4@<W1R:6YG"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97);(F-O;F1I=&EO;B)=("X]("(@(BXD8V]N9&ET:6]N<UMS=')T
M;VQO=V5R*"1R97-U;'1;,%TI73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@3F\@;'5C:RP@;6%T8V@@<&%R="!B>2!P87)T"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@87)R87E?<VAI9G0H)')E<W5L="D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)')E<W5L="`](&%R<F%Y7W5N
M:7%U92@D<F5S=6QT*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("!F;W)E86-H("@D<F5S=6QT(&%S("1C;VYD:71I;VXI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*'-T<FQE;B@D8V]N9&ET
M:6]N*2`^(#`I('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1P;VEN=&5R6R)C;VYD:71I;VXB72`N/2`B("(N)&-O;F1I=&EO
M;G-;<W1R=&]L;W=E<B@D8V]N9&ET:6]N*5T["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB8V]N9&ET:6]N(ET@
M/2!T<FEM*"1P;VEN=&5R6R)C;VYD:71I;VXB72D["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!I9B`H:7-S970H)'!R;V)A8FEL:71Y*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;VYD:71I
M;VXB72`N/2`B("@B+B1P<F]B86)I;&ET>2XB)2!P<F]B+BDB.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('5N<V5T*"1P<F]B86)I;&ET>2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B8VQO=61S(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)'!O:6YT97);(F-L;W5D<R)=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B72`](&%R<F%Y
M*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@:68@*'-I>F5O9B@D<F5S=6QT*2`]/2`U*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@3VYL>2!A;6]U
M;G0@86YD(&AE:6=H=`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1C;&]U9"`](&%R<F%Y*")A;6]U;G0B(#T^("1C;&]U9'-;<W1R=&]L;W=E
M<B@D<F5S=6QT6S-=*5TL(")H96EG:'0B(#T^("@D<F5S=6QT6S1=("H@,3`P
M*2D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("!E;'-E:68@*'-I>F5O9B@D<F5S=6QT*2`]/2`V
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@+R\@06UO=6YT
M+"!H96EG:'0@86YD('1Y<&4*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D8VQO=60@/2!A<G)A>2@B86UO=6YT(B`]/B`D8VQO=61S6W-T<G1O
M;&]W97(H)')E<W5L=%LS72E=+"`B:&5I9VAT(B`]/B`H)')E<W5L=%LT72`J
M(#$P,"DL(")T>7!E(B`]/B`D8VQO=61S6W-T<G1O;&]W97(H)')E<W5L=%LU
M72E=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("\O(%-+0R!O<B!#3%(@;W(@3E-#"B`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)&-L;W5D(#T@87)R87DH(F%M;W5N="(@
M/3X@)&-L;W5D<UMS=')T;VQO=V5R*"1R97-U;'1;,%TI72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!I9BAI<W-E="@D<')O8F%B:6QI='DI*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)&-L;W5D6R)P<F]B(ET@/2`D<')O8F%B:6QI
M='D["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!R
M;V)A8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R6R)C;&]U9',B75M=
M(#T@)&-L;W5D.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1S:&5A<B(Z"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!087)S92!W:6YD<VAE87(L
M(&EF(&%V86EL86)L90H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)'!O
M:6YT97);(G=I;F1S:&5A<B)=("`@("`@("`@(#T@)'1H:7,M/F-O;G9E<G13
M<&5E9"@D<F5S=6QT6S-=+"!S=')T;VQO=V5R*"1R97-U;'1;-%TI+"`B;7!H
M(BD["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D<&]I;G1E<ELB=VEN
M9'-H96%R2&5I9VAT(ET@("`@/2`D<F5S=6QT6S%=("H@,3`P.PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G=I;F1S:&5A<D1E9W)E
M97,B72`@(#T@)')E<W5L=%LR73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1P;VEN=&5R6R)W:6YD<VAE87)$:7)E8W1I;VXB72`]("1C;VUP87-S
M6W)O=6YD*"1R97-U;'1;,ET@+R`R,BXU*2`E(#$V73L*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")T96UP;6%X(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1F;W)E8V%S=$1A=&%;(G1E;7!E<F%T=7)E2&EG:")=(#T@)'1H:7,M/F-O
M;G9E<G1496UP97)A='5R92@D<F5S=6QT6S%=+"`B8R(L(")F(BD["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B=&5M<&UI;B(Z"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!087)S92!M87@O;6EN('1E;7!E<F%T=7)E"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)T96UP97)A='5R
M94QO=R)=("`]("1T:&ES+3YC;VYV97)T5&5M<&5R871U<F4H)')E<W5L=%LQ
M72P@(F,B+"`B9B(I.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!M87AM:6XB
M.@H@("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9O<F5C87-T1&%T85LB
M=&5M<&5R871U<F5(:6=H(ET@/2`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E
M*"1R97-U;'1;,5TL(")C(BP@(F8B*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("1F;W)E8V%S=$1A=&%;(G1E;7!E<F%T=7)E3&]W(ET@(#T@)'1H
M:7,M/F-O;G9E<G1496UP97)A='5R92@D<F5S=6QT6S1=+"`B8R(L(")F(BD[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B9G)O;2(Z"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`O+R!.97AT('1I;65P97)I;V0@:7,@8V]M:6YG('5P+"!P
M<F5P87)E(&%R<F%Y(&%N9`H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@<V5T('!O:6YT97(@86-C;W)D:6YG;'D*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(&EF("AS:7IE;V8H)')E<W5L="D@/B`R*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@+R\@5&AE($E#04\@=V%Y"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@)&9R;VU4:6UE(#T@)')E<W5L
M=%LQ72XB.B(N)')E<W5L=%LR73L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M+R\@5&AE($%U<W1R86QI86X@=V%Y("A(97D@;6%T97,A*0H@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F<F]M5&EM92`]("1R97-U;'1;,5TN
M(CHP,"(["B`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)T:6UE(EU;)&9R
M;VU4:6UE72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9FUC0V]U;G0@/2`P.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M)'!O:6YT97(@/28@)&9O<F5C87-T1&%T85LB=&EM92)=6R1F<F]M5&EM95T[
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@
M("`@("`@("`@("`@("`@8V%S92`B9FUC(CL*("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("\O(%1E<W0L(&EF('1H:7,@:7,@82!P<F]B86)I;&ET>2!F
M;W(@=&AE(&YE>'0@1DU#"B`@("`@("`@("`@("`@("`@("`@("`@("`@("!I
M9B`H<')E9U]M871C:"@B+UY"14--1WQ414U03R0O:2(L("1T869;)&D@*R`Q
M72P@)&QR97-U;'0I*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@4V5T('1Y<&4@=&\@0D5#34<@;W(@5$5-4$\*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D='EP92`]("1L<F5S=6QT6S!=.PH@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O(%-E="!P<F]B86)I;&ET
M>0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P<F]B86)I;&ET
M>2`]("1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@+R\@3F]W(&5X=')A8W0@=&EM92!F;W(@=&AI<R!G<F]U<`H@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@('!R96=?;6%T8V@H(B]>*%QD>S)]
M*2A<9'LR?2DD+VDB+"`D=&%F6R1I("L@,ETL("1L<F5S=6QT*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`D9G)O;2`]("1L<F5S=6QT6S%=
M+B(Z,#`B.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1T;R`@
M(#T@)&QR97-U;'1;,ETN(CHP,"(["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)'1O("`@/2`H)'1O(#T]("(R-#HP,"(I(#\@(C`P.C`P(B`Z
M("1T;SL*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!!<R!W
M92!N;W<@:&%V92!T>7!E+"!P<F]B86)I;&ET>2!A;F0@=&EM92!F;W(@=&AI
M<R!&34,*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`O+R!F<F]M
M(&]U<B!4048L(&EN8W)E87-E(&9I96QD+6-O=6YT97(*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D:2`K/2`R.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@?2!E;'-E:68@*'!R96=?;6%T8V@H(B]>*%QD>S)]*2A<
M9'LR?2DD+VDB+"`D=&%F6R1I("L@,5TL("1L<F5S=6QT*2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("\O($YO<FUA;"!G<F]U<"P@<V5T
M('1Y<&4@86YD('5S92!E>'1R86-T960@=&EM90H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1T>7!E(#T@)')E<W5L=%LQ73L*("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`O+R!#:&5C:R!F;W(@4%)/0F1D"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@:68@*&ES<V5T*"1R97-U
M;'1;,ETI*2!["B`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1P<F]B86)I;&ET>2`]("1R97-U;'1;,ET["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1F<F]M(#T@)&QR97-U;'1;,5TN(CHP,"(["B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@)'1O("`@/2`D;')E<W5L=%LR72XB.C`P(CL*
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=&\@("`]("@D=&\@
M/3T@(C(T.C`P(BD@/R`B,#`Z,#`B(#H@)'1O.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("\O(%-A;64@87,@86)O=F4L('=E(&AA=F4@82!T
M:6UE(&9O<B!T:&ES($9-0R!F<F]M(&]U<B!4048L"B`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@+R\@:6YC<F5A<V4@9FEE;&0M8V]U;G1E<@H@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1I("L](#$["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("\O(%1H:7,@:7,@96ET:&5R(&$@4%)/0F1D
M(&]R(&$@;6%L9F]R;65D(%1!1@H@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(&EF("AI<W-E="@D<F5S=6QT6S)=*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D<')O8F%B:6QI='D@/2`D<F5S=6QT
M6S)=.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`O+R!(86YD;&4@=&AE($9-0RP@9V5N97)A=&4@;F5C8V5S<V%R
M>2!A<G)A>2!I9B!I="=S('1H92!F:7)S="XN+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@:68@*&ES<V5T*"1T>7!E*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(&EF("@A:7-S970H)&9O<F5C87-T1&%T85LB
M=&EM92)=6R1F<F]M5&EM95U;(F9M8R)=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)T:6UE(EU;)&9R
M;VU4:6UE75LB9FUC(ET@/2!A<G)A>2@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D9F]R96-A<W1$871A6R)T:6UE(EU;)&9R;VU4:6UE75LB9FUC(EU;)&9M
M8T-O=6YT72`](&%R<F%Y*"D["B`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@+R\@+BXN86YD('-E="!P;VEN=&5R+@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1P;VEN=&5R(#TF("1F;W)E8V%S=$1A=&%;(G1I
M;64B75LD9G)O;51I;65=6R)F;6,B75LD9FUC0V]U;G1=.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("1F;6-#;W5N="LK.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("\O($EN<V5R="!D871A"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@)'!O:6YT97);(G1Y<&4B72`]("1T
M>7!E.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("1P;VEN=&5R
M6R)F<F]M(ET@/2`D9G)O;3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D<&]I;G1E<ELB=&\B72`@(#T@)'1O.PH@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@('5N<V5T*"1T>7!E+"`D9G)O;2P@)'1O*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("!I9B`H:7-S970H)'!R;V)A
M8FEL:71Y*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`D<&]I;G1E<ELB<')O8F%B:6QI='DB72`]("1P<F]B86)I;&ET>3L*("`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@=6YS970H)'!R;V)A
M8FEL:71Y*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@9&5F
M875L=#H*("`@("`@("`@("`@("`@("`@("`@("`@("`@("\O($1O(&YO=&AI
M;F<*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!I9B`H)&9O=6YD
M("8F("%315)624-%4U]714%42$527T1%0E5'*2!["B`@("`@("`@("`@("`@
M("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@('T@96QS96EF
M("@D9F]U;F0@)B8@4T525DE#15-?5T5!5$A%4E]$14)51RD@>PH@("`@("`@
M("`@("`@("`@("`@("`@("!E8VAO("1K97DN(EQN(CL*("`@("`@("`@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("!]"B`@("`@("`@("`@(&EF("@A
M)&9O=6YD*2!["B`@("`@("`@("`@("`@("!I9B`H4T525DE#15-?5T5!5$A%
M4E]$14)51RD@>PH@("`@("`@("`@("`@("`@("`@(&5C:&\@(FXO85QN(CL*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&EF("@A:7-S970H
M)&9O<F5C87-T1&%T85LB;F]P87)S92)=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("1F;W)E8V%S=$1A=&%;(FYO<&%R<V4B72`](&%R<F%Y*"D["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D9F]R96-A<W1$871A6R)N
M;W!A<G-E(EU;72`]("1T869;)&E=.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!I9B`H:7-S970H)&9O<F5C87-T1&%T85LB;F]P87)S92)=
M*2D@>PH@("`@("`@("`@("`D9F]R96-A<W1$871A6R)N;W!A<G-E(ET@/2!I
M;7!L;V1E*"(@(BP@("1F;W)E8V%S=$1A=&%;(FYO<&%R<V4B72D["B`@("`@
M("`@?0H*("`@("`@("!R971U<FX@)&9O<F5C87-T1&%T83L*("`@('T*("`@
M("\O('U]?0H*("`@("\O('M[>R!?8V]N=F5R=%)E='5R;B@I"B`@("`O*BH*
M("`@("`J($-O;G9E<G1S('1H92!D871A(&EN('1H92!R971U<FX@87)R87D@
M=&\@=&AE(&1E<VER960@=6YI=',@86YD+V]R"B`@("`@*B!O=71P=70@9F]R
M;6%T+@H@("`@("H*("`@("`J($!P87)A;2`@(&%R<F%Y("`@("`@("`@("`@
M("`@("`@("`@("`D=&%R9V5T"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@
M("`@("`@("`@("`@("`@("`@)'5N:71S"B`@("`@*B!`<&%R86T@("!S=')I
M;F<@("`@("`@("`@("`@("`@("`@("`@)&QO8V%T:6]N"B`@("`@*B!`86-C
M97-S("!P<FEV871E"B`@("`@*B\*("`@(&9U;F-T:6]N(%]C;VYV97)T4F5T
M=7)N*"8D=&%R9V5T+"`D=6YI=',L("1L;V-A=&EO;BD*("`@('L*("`@("`@
M("!I9B`H:7-?87)R87DH)'1A<F=E="DI('L*("`@("`@("`@("`@9F]R96%C
M:"`H)'1A<F=E="!A<R`D:V5Y(#T^("1V86PI('L*("`@("`@("`@("`@("`@
M(&EF("AI<U]A<G)A>2@D=F%L*2D@>PH@("`@("`@("`@("`@("`@("`@("\O
M($%N;W1H97(@87)R87D@9&5T96-T960L('-O(')E8W5R<V4@:6YT;R!I="!T
M;R!C;VYV97)T('1H92!U;FET<PH@("`@("`@("`@("`@("`@("`@("1T:&ES
M+3Y?8V]N=F5R=%)E='5R;B@D=&%R9V5T6R1K97E=+"`D=6YI=',L("1L;V-A
M=&EO;BD["B`@("`@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@
M("`@("`@('-W:71C:"`H)&ME>2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!C87-E(")S=&%T:6]N(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("1N97=686P@/2`D;&]C871I;VY;(FYA;64B73L*("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@("`@("`@("!C
M87-E(")U<&1A=&4B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V
M86QI9$9R;VTB.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")V86QI
M9%1O(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=686P@/2!G
M;61A=&4H=')I;2@D=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM
M949O<FUA="DL("1V86PI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F0B.@H@
M("`@("`@("`@("`@("`@("`@("`@("!C87-E(")W:6YD1W5S="(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@(&-A<V4@(G=I;F1S:&5A<B(Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E<G13
M<&5E9"@D=F%L+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI.PH@("`@("`@("`@
M("`@("`@("`@("`@("`@("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@
M("`@(&-A<V4@(G9I<VEB:6QI='DB.@H@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T1&ES=&%N8V4H)'9A;"P@
M(G-M(BP@)'5N:71S6R)V:7,B72D["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B:&5I
M9VAT(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=VEN9'-H96%R
M2&5I9VAT(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@("1N97=686P@
M/2`D=&AI<RT^8V]N=F5R=$1I<W1A;F-E*"1V86PL(")F="(L("1U;FET<ULB
M:&5I9VAT(ETI.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(G1E;7!E<F%T=7)E(CH*
M("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=&5M<&5R871U<F5(:6=H
M(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B=&5M<&5R871U<F5,
M;W<B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E(")D97=0;VEN="(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F9E;'1496UP97)A='5R
M92(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H
M:7,M/F-O;G9E<G1496UP97)A='5R92@D=F%L+"`B9B(L("1U;FET<ULB=&5M
M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")P<F5S<W5R92(Z"B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E<G10
M<F5S<W5R92@D=F%L+"`B:6XB+"`D=6YI='-;(G!R97,B72D["B`@("`@("`@
M("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@
M("`@("`@8V%S92`B86UO=6YT(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M8V%S92`B<VYO=V1E<'1H(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S
M92`B<VYO=V5Q=6EV(CH*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&EF
M("AI<U]N=6UE<FEC*"1V86PI*2!["B`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@)&YE=U9A;"`]("1T:&ES+3YC;VYV97)T4')E<W-U<F4H)'9A
M;"P@(FEN(BP@)'5N:71S6R)R86EN(ETI.PH@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`D;F5W5F%L(#T@)'9A;#L*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@
M("`@("`@("`@("`@("`@("`@("!C87-E(")S96%P<F5S<W5R92(Z"B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@)'1H:7,M/F-O;G9E
M<G10<F5S<W5R92@D=F%L+"`B:6XB+"`D=6YI='-;(G!R97,B72D["B`@("`@
M("`@("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@
M("`@("`@("`@8V%S92`B,6AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B,6AD97<B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E
M("(V:&UA>'1E;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("(V
M:&UI;G1E;7`B.@H@("`@("`@("`@("`@("`@("`@("`@("!C87-E("(R-&AM
M87AT96UP(CH*("`@("`@("`@("`@("`@("`@("`@("`@8V%S92`B,C1H;6EN
M=&5M<"(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D;F5W5F%L(#T@
M)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D=F%L+"`B9B(L("1U;FET<ULB
M=&5M<")=*3L*("`@("`@("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("`@("`@("`@("`@("!D969A=6QT.@H@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@)'1A<F=E=%LD:V5Y72`]("1N97=6
M86P["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!]
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5A<F-H3&]C871I;VXH
M*0H@("`@+RHJ"B`@("`@*B!396%R8VAE<R!)1',@9F]R(&=I=F5N(&QO8V%T
M:6]N+"!R971U<FYS(&%R<F%Y(&]F('!O<W-I8FQE(&QO8V%T:6]N<PH@("`@
M("H@;W(@<VEN9VQE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG
M?&%R<F%Y("`@("`@("`@("`@("`@("1L;V-A=&EO;@H@("`@("H@0'!A<F%M
M("`@8F]O;"`@("`@("`@("`@("`@("`@("`@("`@("1U<V5&:7)S="`@("`@
M("!)9B!S970L(&9I<G-T($E$(&]F(')E<W5L="UA<G)A>2!I<R!R971U<FYE
M9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O<GQA<G)A>7QS=')I;F<*("`@
M("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)2
M3U)?54Y+3D]73E],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O
M<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$"B`@
M("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T52
M4D]27TE.5D%,241?3$]#051)3TX*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S96%R8VA,;V-A=&EO;B@D;&]C871I;VXL
M("1U<V5&:7)S="`](&9A;'-E*0H@("`@>PH@("`@("`@(&EF("@A:7-S970H
M)'1H:7,M/E]D8BD@?'P@(41".CII<T-O;FYE8W1I;VXH)'1H:7,M/E]D8BDI
M('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E
M17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#5$5$
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@:68@
M*&ES7W-T<FEN9R@D;&]C871I;VXI*2!["B`@("`@("`@("`@("\O(%1R>2!T
M;R!P87)T('-E87)C:"!S=')I;F<@:6X@;F%M92P@<W1A=&4@86YD(&-O=6YT
M<GD@<&%R=`H@("`@("`@("`@("`O+R!A;F0@8G5I;&0@=VAE<F4@8VQA=7-E
M(&9R;VT@:70@9F]R('1H92!S96QE8W0*("`@("`@("`@("`@)&QO8V%T:6]N
M(#T@97AP;&]D92@B+"(L("1L;V-A=&EO;BD["@H@("`@("`@("`@("`O+R!4
M<FEM+"!C87!S+6QO=R!A;F0@<75O=&4@=&AE('-T<FEN9W,*("`@("`@("`@
M("`@9F]R("@D:2`](#`[("1I(#P@<VEZ96]F*"1L;V-A=&EO;BD[("1I*RLI
M('L*("`@("`@("`@("`@("`@("1L;V-A=&EO;ELD:5T@/2`D=&AI<RT^7V1B
M+3YQ=6]T92@B)2(N<W1R=&]L;W=E<BAT<FEM*"1L;V-A=&EO;ELD:5TI*2XB
M)2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!I9B`H<VEZ96]F*"1L
M;V-A=&EO;BD@/3T@,2D@>PH@("`@("`@("`@("`@("`@)'=H97)E("`]("),
M3U=%4BAN86UE*2!,24M%("(N)&QO8V%T:6]N6S!=.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<VEZ96]F*"1L;V-A=&EO;BD@/3T@,BD@>PH@("`@("`@("`@
M("`@("`@)'=H97)E("`]("),3U=%4BAN86UE*2!,24M%("(N)&QO8V%T:6]N
M6S!=.PH@("`@("`@("`@("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52*&-O
M=6YT<GDI($Q)2T4@(BXD;&]C871I;VY;,5T["B`@("`@("`@("`@('T@96QS
M96EF("AS:7IE;V8H)&QO8V%T:6]N*2`]/2`S*2!["B`@("`@("`@("`@("`@
M("`D=VAE<F4@(#T@(DQ/5T52*&YA;64I($Q)2T4@(BXD;&]C871I;VY;,%T[
M"B`@("`@("`@("`@("`@("`D=VAE<F4@+CT@(B!!3D0@3$]715(H<W1A=&4I
M($Q)2T4@(BXD;&]C871I;VY;,5T["B`@("`@("`@("`@("`@("`D=VAE<F4@
M+CT@(B!!3D0@3$]715(H8V]U;G1R>2D@3$E+12`B+B1L;V-A=&EO;ELR73L*
M("`@("`@("`@("`@?2!E;'-E:68@*'-I>F5O9B@D;&]C871I;VXI(#T](#0I
M('L*("`@("`@("`@("`@("`@("1W:&5R92`@/2`B3$]715(H;F%M92D@3$E+
M12`B+G-U8G-T<B@D;&]C871I;VY;,%TL(#`L("TR*2XB+"`B+G-U8G-T<B@D
M;&]C871I;VY;,5TL(#(I.PH@("`@("`@("`@("`@("`@)'=H97)E("X]("(@
M04Y$($Q/5T52*'-T871E*2!,24M%("(N)&QO8V%T:6]N6S)=.PH@("`@("`@
M("`@("`@("`@)'=H97)E("X]("(@04Y$($Q/5T52*&-O=6YT<GDI($Q)2T4@
M(BXD;&]C871I;VY;,UT["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O
M($-R96%T92!S96QE8W0L(&QO8V%T:6]N<R!W:71H($E#04\@9FER<W0*("`@
M("`@("`@("`@)'-E;&5C="`](")314Q%0U0@:6-A;RP@;F%M92P@<W1A=&4L
M(&-O=6YT<GDL(&QA=&ET=61E+"!L;VYG:71U9&4@(BX*("`@("`@("`@("`@
M("`@("`@("`@(")&4D]-(&UE=&%R3&]C871I;VYS("(N"B`@("`@("`@("`@
M("`@("`@("`@("`B5TA%4D4@(BXD=VAE<F4N(B`B+@H@("`@("`@("`@("`@
M("`@("`@("`@(D]21$52($)9(&EC86\@1$530R(["B`@("`@("`@("`@("1R
M97-U;'0@/2`D=&AI<RT^7V1B+3YQ=65R>2@D<V5L96-T*3L*("`@("`@("`@
M("`@+R\@0VAE8VL@<F5S=6QT(&9O<B!V86QI9&ET>0H@("`@("`@("`@("!I
M9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*("`@("`@("`@("`@("`@(')E
M='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!](&5L<V5I9B`H<W1R=&]L;W=E
M<BAG971?8VQA<W,H)')E<W5L="DI("$](")D8E]R97-U;'0B('Q\("1R97-U
M;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?1DE,15]?+"!?7TQ)3D5?7RD[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%)E<W5L="!I<R!V86QI
M9"P@<W1A<G0@<')E<&%R:6YG('1H92!R971U<FX*("`@("`@("`@("`@)&EC
M86\@/2!A<G)A>2@I.PH@("`@("`@("`@("!W:&EL92`H*"1R;W<@/2`D<F5S
M=6QT+3YF971C:%)O=RA$0E]&151#2$U/1$5?05-33T,I*2`A/2!N=6QL*2![
M"B`@("`@("`@("`@("`@("`D;&]C:6-A;R`]("1R;W=;(FEC86\B73L*("`@
M("`@("`@("`@("`@("\O($9I<G-T('1H92!N86UE(&]F('1H92!L;V-A=&EO
M;@H@("`@("`@("`@("`@("`@:68@*"%S=')L96XH)')O=ULB<W1A=&4B72DI
M('L*("`@("`@("`@("`@("`@("`@("`D;&]C;F%M92`]("1R;W=;(FYA;64B
M72XB+"`B+B1R;W=;(F-O=6YT<GDB73L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@)&QO8VYA;64@/2`D<F]W6R)N86UE
M(ETN(BP@(BXD<F]W6R)S=&%T92)=+B(L("(N)')O=ULB8V]U;G1R>2)=.PH@
M("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@:68@*"1L;V-I8V%O
M("$]("(M+2TM(BD@>PH@("`@("`@("`@("`@("`@("`@("\O(%=E(&AA=F4@
M82!L;V-A=&EO;B!W:71H($E#04\*("`@("`@("`@("`@("`@("`@("`D:6-A
M;ULD;&]C:6-A;UT@/2`D;&]C;F%M93L*("`@("`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("`@("`@+R\@3F\@24-!3RP@=')Y(&9I;F1I
M;F<@=&AE(&YE87)E<W0@86ER<&]R=`H@("`@("`@("`@("`@("`@("`@("1L
M;V-I8V%O(#T@)'1H:7,M/G-E87)C:$%I<G!O<G0H)')O=ULB;&%T:71U9&4B
M72P@)')O=ULB;&]N9VET=61E(ETI.PH@("`@("`@("`@("`@("`@("`@(&EF
M("@A:7-S970H)&EC86];)&QO8VEC86]=*2D@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`D:6-A;ULD;&]C:6-A;UT@/2`D;&]C;F%M93L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*
M("`@("`@("`@("`@+R\@3VYL>2!O;F4@<F5S=6QT/R!2971U<FX@87,@<W1R
M:6YG"B`@("`@("`@("`@(&EF("AS:7IE;V8H)&EC86\I(#T](#$@?'P@)'5S
M949I<G-T*2!["B`@("`@("`@("`@("`@("`D:6-A;R`](&ME>2@D:6-A;RD[
M"B`@("`@("`@("`@('T*("`@("`@("!](&5L<V5I9B`H:7-?87)R87DH)&QO
M8V%T:6]N*2D@>PH@("`@("`@("`@("`O+R!,;V-A=&EO;B!W87,@<')O=FED
M960@87,@8V]O<F1I;F%T97,L('-E87)C:"!N96%R97-T(&%I<G!O<G0*("`@
M("`@("`@("`@)&EC86\@/2`D=&AI<RT^<V5A<F-H06ER<&]R="@D;&]C871I
M;VY;,%TL("1L;V-A=&EO;ELQ72D["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?7T9)3$5?
M7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N("1I8V%O
M.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[('-E87)C:$QO8V%T:6]N
M0GE#;W5N=')Y*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!)1',@=VET:"!L
M;V-A=&EO;BUN86UE(&9O<B!A(&=I=F5N(&-O=6YT<GD@;W(@86QL(&%V86EL
M86)L90H@("`@("H@8V]U;G1R:65S+"!I9B!N;R!V86QU92!W87,@9VEV96X*
M("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@
M("`@("`@)&-O=6YT<GD*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R
M87D*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(
M15)?15)23U)?54Y+3D]73E],3T-!5$E/3@H@("`@("H@0'1H<F]W<R`@4$5!
M4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]$0E].3U1?0T].3D5#
M5$5$"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI315)624-%4U]714%4
M2$527T524D]27U=23TY'7U-%4E9%4E]$051!"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A<F-H3&]C871I;VY">4-O
M=6YT<GDH)&-O=6YT<GD@/2`B(BD*("`@('L*("`@("`@("!I9B`H(6ES<V5T
M*"1T:&ES+3Y?9&(I('Q\("%$0CHZ:7-#;VYN96-T:6]N*"1T:&ES+3Y?9&(I
M*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES
M945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?1$)?3D]47T-/3DY%0U1%
M1"P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@("`@("`@("\O
M(%)E='5R;B!T:&4@879A:6QA8FQE(&-O=6YT<FEE<R!A<R!N;R!C;W5N=')Y
M('=A<R!G:79E;@H@("`@("`@(&EF("@A<W1R;&5N*"1C;W5N=')Y*2D@>PH@
M("`@("`@("`@("`D<V5L96-T(#T@(E-%3$5#5"!$25-424Y#5"AC;W5N=')Y
M*2`B+@H@("`@("`@("`@("`@("`@("`@("`@(D923TT@;65T87)!:7)P;W)T
M<R`B+@H@("`@("`@("`@("`@("`@("`@("`@(D]21$52($)9(&-O=6YT<GD@
M05-#(CL*("`@("`@("`@("`@)&-O=6YT<FEE<R`]("1T:&ES+3Y?9&(M/F=E
M=$-O;"@D<V5L96-T*3L*"B`@("`@("`@("`@("\O($%S("1C;W5N=')I97,@
M:7,@96ET:&5R(&%N(&5R<F]R(&]R('1H92!T<G5E(')E<W5L="P*("`@("`@
M("`@("`@+R\@=V4@8V%N(&IU<W0@<F5T=7)N(&ET"B`@("`@("`@("`@(')E
M='5R;B`D8V]U;G1R:65S.PH@("`@("`@('T*"B`@("`@("`@+R\@3F]W(&9O
M<B!T:&4@<F5A;"!S96%R8V@*("`@("`@("`D<V5L96-T(#T@(E-%3$5#5"!I
M8V%O+"!N86UE+"!S=&%T92P@8V]U;G1R>2`B+@H@("`@("`@("`@("`@("`@
M("`B1E)/32!M971A<D%I<G!O<G1S("(N"B`@("`@("`@("`@("`@("`@(")7
M2$5212!,3U=%4BAC;W5N=')Y*2!,24M%("<E(BYS=')T;VQO=V5R*'1R:6TH
M)&-O=6YT<GDI*2XB)2<@(BX*("`@("`@("`@("`@("`@("`@(D]21$52($)9
M(&YA;64@05-#(CL*("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E
M<GDH)'-E;&5C="D["B`@("`@("`@+R\@0VAE8VL@<F5S=6QT(&9O<B!V86QI
M9&ET>0H@("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@
M("`@("`@("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V5I9B`H<W1R
M=&]L;W=E<BAG971?8VQA<W,H)')E<W5L="DI("$](")D8E]R97-U;'0B('Q\
M("1R97-U;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R
M;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(
M15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("!]"@H@("`@("`@("\O($-O;G-T<G5C="!T:&4@<F5S=6QT
M"B`@("`@("`@)&QO8V%T:6]N<R`](&%R<F%Y*"D["B`@("`@("`@=VAI;&4@
M*"@D<F]W(#T@)')E<W5L="T^9F5T8VA2;W<H1$)?1D540TA-3T1%7T%34T]#
M*2D@(3T@;G5L;"D@>PH@("`@("`@("`@("`D;&]C:6-A;R`]("1R;W=;(FEC
M86\B73L*("`@("`@("`@("`@:68@*"1L;V-I8V%O("$]("(M+2TM(BD@>PH@
M("`@("`@("`@("`@("`@+R\@1FER<W0@=&AE(&YA;64@;V8@=&AE(&QO8V%T
M:6]N"B`@("`@("`@("`@("`@("!I9B`H(7-T<FQE;B@D<F]W6R)S=&%T92)=
M*2D@>PH@("`@("`@("`@("`@("`@("`@("1L;V-N86UE(#T@)')O=ULB;F%M
M92)=+B(L("(N)')O=ULB8V]U;G1R>2)=.PH@("`@("`@("`@("`@("`@?2!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("`D;&]C;F%M92`]("1R;W=;(FYA
M;64B72XB+"`B+B1R;W=;(G-T871E(ETN(BP@(BXD<F]W6R)C;W5N=')Y(ET[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`D;&]C871I;VYS
M6R1L;V-I8V%O72`]("1L;V-N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@)&QO8V%T:6]N<SL*("`@('T*("`@("\O('U]
M?0H*("`@("\O('M[>R!S96%R8VA!:7)P;W)T*"D*("`@("\J*@H@("`@("H@
M4V5A<F-H97,@=&AE(&YE87)E<W0@86ER<&]R="AS*2!F;W(@9VEV96X@8V]O
M<F1I;F%T97,L(')E='5R;G,@87)R87D*("`@("`J(&]F($E$<R!O<B!S:6YG
M;&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@("`@
M("`@("`@("`@("`@)&QA=&ET=61E"B`@("`@*B!`<&%R86T@("!F;&]A="`@
M("`@("`@("`@("`@("`@("`@("`@)&QO;F=I='5D90H@("`@("H@0'!A<F%M
M("`@:6YT("`@("`@("`@("`@("`@("`@("`@("`@("1N=6U297-U;'1S"B`@
M("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y?'-T<FEN9PH@("`@("H@
M0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]5
M3DM.3U=.7TQ/0T%424]."B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R.CI3
M15)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.14-4140*("`@("`J
M($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?
M24Y604Q)1%],3T-!5$E/3@H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@
M*B\*("`@(&9U;F-T:6]N('-E87)C:$%I<G!O<G0H)&QA=&ET=61E+"`D;&]N
M9VET=61E+"`D;G5M4F5S=6QT<R`](#$I"B`@("!["B`@("`@("`@:68@*"%I
M<W-E="@D=&AI<RT^7V1B*2!\?"`A1$(Z.FES0V]N;F5C=&EO;B@D=&AI<RT^
M7V1B*2D@>PH@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ
M<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27T1"7TY/5%]#3TY.
M14-4140L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H@("`@("`@
M(&EF("@A:7-?;G5M97)I8R@D;&%T:71U9&4I('Q\("%I<U]N=6UE<FEC*"1L
M;VYG:71U9&4I*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T
M:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?24Y604Q)
M1%],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!]"@H@
M("`@("`@("\O($=E="!A;&P@86ER<&]R=',*("`@("`@("`D<V5L96-T(#T@
M(E-%3$5#5"!I8V%O+"!X+"!Y+"!Z($923TT@;65T87)!:7)P;W)T<R(["B`@
M("`@("`@)')E<W5L="`]("1T:&ES+3Y?9&(M/G%U97)Y*"1S96QE8W0I.PH@
M("`@("`@(&EF("A$0CHZ:7-%<G)O<B@D<F5S=6QT*2D@>PH@("`@("`@("`@
M("!R971U<FX@)')E<W5L=#L*("`@("`@("!](&5L<V5I9B`H<W1R=&]L;W=E
M<BAG971?8VQA<W,H)')E<W5L="DI("$](")D8E]R97-U;'0B('Q\("1R97-U
M;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("!]"@H@("`@("`@("\O(%)E<W5L="!I<R!V86QI9"P@<W1A<G0@<V5A
M<F-H"B`@("`@("`@+R\@26YI=&EA;&EZ92!V86QU97,*("`@("`@("`D;6EN
M7V1I<W0@/2!N=6QL.PH@("`@("`@("1Q=65R>2`@("`]("1T:&ES+3YP;VQA
M<C)C87)T97-I86XH)&QA=&ET=61E+"`D;&]N9VET=61E*3L*("`@("`@("`D
M<V5A<F-H("`@/2!A<G)A>2@B9&ES="(@/3X@87)R87DH*2P@(FEC86\B(#T^
M(&%R<F%Y*"DI.PH@("`@("`@('=H:6QE("@H)')O=R`]("1R97-U;'0M/F9E
M=&-H4F]W*$1"7T9%5$-(34]$15]!4U-/0RDI("$](&YU;&PI('L*("`@("`@
M("`@("`@)&EC86\@/2`D<F]W6R)I8V%O(ET["B`@("`@("`@("`@("1A:7(@
M(#T@87)R87DH)')O=ULB>")=+"`D<F]W6R)Y(ETL("1R;W=;(GHB72D["@H@
M("`@("`@("`@("`D9&ES="`](#`["B`@("`@("`@("`@("1D(#T@,#L*("`@
M("`@("`@("`@+R\@0V%L8W5L871E(&1I<W1A;F-E(&]F('%U97)Y(&%N9"!C
M=7)R96YT(&%I<G!O<G0*("`@("`@("`@("`@+R\@8G)E86L@;V9F+"!I9B!D
M:7-T86YC92!I<R!L87)G97(@=&AA;B!C=7)R96YT("1M:6Y?9&ES=`H@("`@
M("`@("`@("!F;W(H)&0[("1D(#P@<VEZ96]F*"1A:7(I.R`D9"LK*2!["B`@
M("`@("`@("`@("`@("`D="`]("1A:7);)&1=("T@)'%U97)Y6R1D73L*("`@
M("`@("`@("`@("`@("1D:7-T("L]('!O=R@D="P@,BD["B`@("`@("`@("`@
M("`@("!I9B`H)&UI;E]D:7-T("$](&YU;&P@)B8@)&1I<W0@/B`D;6EN7V1I
M<W0I('L*("`@("`@("`@("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1D(#X]('-I
M>F5O9B@D86ER*2D@>PH@("`@("`@("`@("`@("`@+R\@3VLL(&-U<G)E;G0@
M86ER<&]R="!I<R!O;F4@;V8@=&AE(&YE87)E<B!L;V-A=&EO;G,*("`@("`@
M("`@("`@("`@("\O(&%D9"!T;R!R97-U;'0M87)R87D*("`@("`@("`@("`@
M("`@("1S96%R8VA;(F1I<W0B75M=(#T@)&1I<W0["B`@("`@("`@("`@("`@
M("`D<V5A<F-H6R)I8V%O(EU;72`]("1I8V%O.PH@("`@("`@("`@("`@("`@
M+R\@4V]R="!A<G)A>2!F;W(@9&ES=&%N8V4*("`@("`@("`@("`@("`@(&%R
M<F%Y7VUU;'1I<V]R="@D<V5A<F-H6R)D:7-T(ETL(%-/4E1?3E5-15))0RP@
M4T]25%]!4T,L("1S96%R8VA;(FEC86\B72P@4T]25%]35%))3D<L(%-/4E1?
M05-#*3L*("`@("`@("`@("`@("`@("\O($EF(&%R<F%Y(&ES(&QA<F=E<B!T
M:&5N(&1E<VER960@<F5S=6QT<RP@8VAO<"!O9F8@;&%S="!O;F4*("`@("`@
M("`@("`@("`@(&EF("AS:7IE;V8H)'-E87)C:%LB9&ES=")=*2`^("1N=6U2
M97-U;'1S*2!["B`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S96%R
M8VA;(F1I<W0B72D["B`@("`@("`@("`@("`@("`@("`@87)R87E?<&]P*"1S
M96%R8VA;(FEC86\B72D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`D;6EN7V1I<W0@/2!M87@H)'-E87)C:%LB9&ES=")=*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@("`@("!I9B`H)&YU;5)E<W5L=',@/3T@
M,2D@>PH@("`@("`@("`@("`O+R!/;FQY(&]N92!R97-U;'0@=V%N=&5D+"!R
M971U<FX@87,@<W1R:6YG"B`@("`@("`@("`@(')E='5R;B`D<V5A<F-H6R)I
M8V%O(EU;,%T["B`@("`@("`@?2!E;'-E:68@*"1N=6U297-U;'1S(#X@,2D@
M>PH@("`@("`@("`@("`O+R!2971U<FX@9F]U;F0@;&]C871I;VYS"B`@("`@
M("`@("`@(')E='5R;B`D<V5A<F-H6R)I8V%O(ET["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E
M17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424].
M+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*("`@('T*("`@("\O
M('U]?0H*("`@("\O('M[>R!G971,;V-A=&EO;B@I"B`@("`O*BH*("`@("`J
M(%)E='5R;G,@=&AE(&1A=&$@9F]R('1H92!L;V-A=&EO;B!B96QO;F=I;F<@
M=&\@=&AE($E$"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1I9`H@("`@("H@0')E='5R;B`@4$5!4E]%<G)O
M<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@("`@("H@0&%C
M8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E=$QO8V%T:6]N
M*"1I9"`]("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H
M96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A
M=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@
M)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("1L;V-A=&EO;E)E='5R;B`]
M(&%R<F%Y*"D["@H@("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F
M)B`H)&QO8V%T:6]N(#T@)'1H:7,M/E]C86-H92T^9V5T*")-151!4BTB+B1I
M9"P@(FQO8V%T:6]N(BDI*2!["B`@("`@("`@("`@("\O($=R86(@<W1U9F8@
M9G)O;2!C86-H90H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO
M8V%T:6]N.PH@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A8VAE(ET@
M/2`B2$E4(CL*("`@("`@("!](&5L<V5I9B`H:7-S970H)'1H:7,M/E]D8BD@
M)B8@1$(Z.FES0V]N;F5C=&EO;B@D=&AI<RT^7V1B*2D@>PH@("`@("`@("`@
M("`O+R!'970@9&%T82!F<F]M($1""B`@("`@("`@("`@("1S96QE8W0@/2`B
M4T5,14-4(&EC86\L(&YA;64L('-T871E+"!C;W5N=')Y+"!L871I='5D92P@
M;&]N9VET=61E+"!E;&5V871I;VX@(BX*("`@("`@("`@("`@("`@("`@("`@
M(")&4D]-(&UE=&%R06ER<&]R=',@5TA%4D4@:6-A;STG(BXD:60N(B<B.PH@
M("`@("`@("`@("`D<F5S=6QT(#T@)'1H:7,M/E]D8BT^<75E<GDH)'-E;&5C
M="D["@H@("`@("`@("`@("!I9B`H1$(Z.FES17)R;W(H)')E<W5L="DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D<F5S=6QT.PH@("`@("`@("`@("!]
M(&5L<V5I9B`H<W1R=&]L;W=E<BAG971?8VQA<W,H)')E<W5L="DI("$](")D
M8E]R97-U;'0B('Q\("1R97-U;'0M/FYU;5)O=W,H*2`]/2`P*2!["B`@("`@
M("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O
M<BA315)624-%4U]714%42$527T524D]27U5.2TY/5TY?3$]#051)3TXL(%]?
M1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M+R\@4F5S=6QT(&ES(&]K+"!P=70@=&AI;F=S(&EN=&\@;V)J96-T"B`@("`@
M("`@("`@("1T:&ES+3Y?;&]C871I;VX@/2`D<F5S=6QT+3YF971C:%)O=RA$
M0E]&151#2$U/1$5?05-33T,I.PH*("`@("`@("`@("`@:68@*"1T:&ES+3Y?
M8V%C:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C
M:&4@:70*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T52
M5DE#15-?5T5!5$A%4E]%6%!)4D537TQ/0T%424].(BD["B`@("`@("`@("`@
M("`@("`D=&AI<RT^7V-A8VAE+3YE>'13879E*")-151!4BTB+B1I9"P@)'1H
M:7,M/E]L;V-A=&EO;BP@(B(L("1E>'!I<F4L(")L;V-A=&EO;B(I.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A8VAE
M(ET@/2`B34E34R(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@)'1H
M:7,M/E]L;V-A=&EO;B`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(FYA;64B
M("`@("`@/3X@)&ED+`H@("`@("`@("`@("`@("`@(G-T871E(B`@("`@/3X@
M(B(L"B`@("`@("`@("`@("`@("`B8V]U;G1R>2(@("`]/B`B(BP*("`@("`@
M("`@("`@("`@(")L871I='5D92(@(#T^("(B+`H@("`@("`@("`@("`@("`@
M(FQO;F=I='5D92(@/3X@(B(L"B`@("`@("`@("`@("`@("`B96QE=F%T:6]N
M(B`]/B`B(@H@("`@("`@("`@("`I.PH@("`@("`@('T*("`@("`@("`O+R!3
M='5F9B!N86UE+7-T<FEN9R!T;V=E=&AE<@H@("`@("`@(&EF("AS=')L96XH
M)'1H:7,M/E]L;V-A=&EO;ELB<W1A=&4B72D@)B8@<W1R;&5N*"1T:&ES+3Y?
M;&]C871I;VY;(F-O=6YT<GDB72DI('L*("`@("`@("`@("`@)&QO8VYA;64@
M/2`D=&AI<RT^7VQO8V%T:6]N6R)N86UE(ETN(BP@(BXD=&AI<RT^7VQO8V%T
M:6]N6R)S=&%T92)=+B(L("(N)'1H:7,M/E]L;V-A=&EO;ELB8V]U;G1R>2)=
M.PH@("`@("`@('T@96QS96EF("AS=')L96XH)'1H:7,M/E]L;V-A=&EO;ELB
M8V]U;G1R>2)=*2D@>PH@("`@("`@("`@("`D;&]C;F%M92`]("1T:&ES+3Y?
M;&]C871I;VY;(FYA;64B72XB+"`B+B1T:&ES+3Y?;&]C871I;VY;(F-O=6YT
M<GDB73L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D;&]C;F%M92`]
M("1T:&ES+3Y?;&]C871I;VY;(FYA;64B73L*("`@("`@("!]"B`@("`@("`@
M)&QO8V%T:6]N4F5T=7)N6R)N86UE(ET@("`@("`]("1L;V-N86UE.PH@("`@
M("`@("1L;V-A=&EO;E)E='5R;ELB;&%T:71U9&4B72`@/2`D=&AI<RT^7VQO
M8V%T:6]N6R)L871I='5D92)=.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB
M;&]N9VET=61E(ET@/2`D=&AI<RT^7VQO8V%T:6]N6R)L;VYG:71U9&4B73L*
M("`@("`@("`D;&]C871I;VY2971U<FY;(G-U;G)I<V4B72`@(#T@9&%T92@D
M=&AI<RT^7W1I;65&;W)M870L("1T:&ES+3YC86QC=6QA=&53=6Y2:7-E4V5T
M*&=M;6MT:6UE*"DL(%-53D953D-37U)%5%]424U%4U1!35`L("1T:&ES+3Y?
M;&]C871I;VY;(FQA=&ET=61E(ETL("1T:&ES+3Y?;&]C871I;VY;(FQO;F=I
M='5D92)=+"!315)624-%4U]714%42$527U-53D953D-37U-53E))4T5?6D5.
M251(+"`P+"!T<G5E*2D["B`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)S=6YS
M970B72`@("`](&1A=&4H)'1H:7,M/E]T:6UE1F]R;6%T+"`D=&AI<RT^8V%L
M8W5L871E4W5N4FES95-E="AG;6UK=&EM92@I+"!354Y&54Y#4U]2151?5$E-
M15-404U0+"`D=&AI<RT^7VQO8V%T:6]N6R)L871I='5D92)=+"`D=&AI<RT^
M7VQO8V%T:6]N6R)L;VYG:71U9&4B72P@4T525DE#15-?5T5!5$A%4E]354Y&
M54Y#4U]354Y3151?6D5.251(+"`@,"P@9F%L<V4I*3L*("`@("`@("`D;&]C
M871I;VY2971U<FY;(F5L979A=&EO;B)=(#T@)'1H:7,M/E]L;V-A=&EO;ELB
M96QE=F%T:6]N(ET["@H@("`@("`@(')E='5R;B`D;&]C871I;VY2971U<FX[
M"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T5V5A=&AE<B@I"B`@
M("`O*BH*("`@("`J(%)E='5R;G,@=&AE('=E871H97(M9&%T82!F;W(@=&AE
M('-U<'!L:65D(&QO8V%T:6]N"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R
M:6YG("`@("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1U;FET<T9O<FUA=`H@("`@
M("H@0')E='5R;B`@4$A07T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!0
M2%!?17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!G971796%T:&5R*"1I9"`]("(B+"`D=6YI='-&;W)M870@/2`B
M(BD*("`@('L*("`@("`@("`D:60@("`@(#T@<W1R=&]U<'!E<B@D:60I.PH@
M("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I
M.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A
M='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]
M"@H@("`@("`@("\O($=E="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@
M(#T@)'1H:7,M/F=E=%5N:71S1F]R;6%T*"1U;FET<T9O<FUA="D["B`@("`@
M("`@)&QO8V%T:6]N(#T@)'1H:7,M/F=E=$QO8V%T:6]N*"1I9"D["@H@("`@
M("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1L;V-A=&EO;BDI
M('L*("`@("`@("`@("`@<F5T=7)N("1L;V-A=&EO;CL*("`@("`@("!]"@H@
M("`@("`@(&EF("@D=&AI<RT^7V-A8VAE16YA8FQE9"`F)B`H)'=E871H97(@
M/2`D=&AI<RT^7V-A8VAE+3YG970H(DU%5$%2+2(N)&ED+"`B=V5A=&AE<B(I
M*2D@>PH@("`@("`@("`@("`O+R!7964N+BX@:70@=V%S(&-A8VAE9"P@;&5T
M)W,@:&%V92!I="XN+@H@("`@("`@("`@("`D=V5A=&AE<E)E='5R;B`@/2`D
M=V5A=&AE<CL*("`@("`@("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H
M97)2971U<FX["B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=
M(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@1&]W
M;FQO860@=V5A=&AE<@H@("`@("`@("`@("`D=V5A=&AE<D1A=&$@/2`D=&AI
M<RT^7W)E=')I979E4V5R=F5R1&%T82@D:60L(")M971A<B(I.PH@("`@("`@
M("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D=V5A=&AE<D1A
M=&$I*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H97)$871A.PH@
M("`@("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1W96%T:&5R1&%T82D@
M?'P@<VEZ96]F*"1W96%T:&5R1&%T82D@/"`R*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%
M4U]714%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@
M7U],24Y%7U\I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("`O+R!087)S
M92!W96%T:&5R"B`@("`@("`@("`@("1W96%T:&5R4F5T=7)N("`]("1T:&ES
M+3Y?<&%R<V5796%T:&5R1&%T82@D=V5A=&AE<D1A=&$I.PH*("`@("`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'=E871H97)2971U
M<FXI*2!["B`@("`@("`@("`@("`@("!R971U<FX@)'=E871H97)2971U<FX[
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O($%D9"!A;B!I8V]N(&9O
M<B!T:&4@8W5R<F5N="!C;VYD:71I;VYS"B`@("`@("`@("`@("\O($1E=&5R
M;6EN92!I9B!C97)T86EN('9A;'5E<R!A<F4@<V5T+"!I9B!N;W0@=7-E(&1E
M9F%U;'1S"B`@("`@("`@("`@("1C;VYD:71I;VX@("`](&ES<V5T*"1W96%T
M:&5R4F5T=7)N6R)C;VYD:71I;VXB72D@("`_("1W96%T:&5R4F5T=7)N6R)C
M;VYD:71I;VXB72`@(#H@(DYO(%-I9VYI9FEC86YT(%=E871H97(B.PH@("`@
M("`@("`@("`D8VQO=61S("`@("`@/2!I<W-E="@D=V5A=&AE<E)E='5R;ELB
M8VQO=61S(ETI("`@("`@/R`D=V5A=&AE<E)E='5R;ELB8VQO=61S(ET@("`@
M("`Z("`@("`@("`@("`@("`@("`@87)R87DH*3L*("`@("`@("`@("`@)'=I
M;F0@("`@("`@(#T@:7-S970H)'=E871H97)2971U<FY;(G=I;F0B72D@("`@
M("`@(#\@)'=E871H97)2971U<FY;(G=I;F0B72`@("`@("`@.B`@("`@("`@
M("`@("`@("`@("`@("`@(#4[(`H@("`@("`@("`@("`D=&5M<&5R871U<F4@
M/2!I<W-E="@D=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72D@/R`D=V5A
M=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72`Z("`@("`@("`@("`@("`@("`@
M("`@("`W,#L@"B`@("`@("`@("`@("1L871I='5D92`@("`](&ES<V5T*"1L
M;V-A=&EO;ELB;&%T:71U9&4B72D@("`@("`@("`_("1L;V-A=&EO;ELB;&%T
M:71U9&4B72`@("`@("`@(#H@("`@("`@("`@("`@("`@("`@("`M,S8P.PH@
M("`@("`@("`@("`D;&]N9VET=61E("`@/2!I<W-E="@D;&]C871I;VY;(FQO
M;F=I='5D92)=*2`@("`@("`@/R`D;&]C871I;VY;(FQO;F=I='5D92)=("`@
M("`@("`Z("`@("`@("`@("`@("`@("`@("`@+3,V,#L*("`@("`@("`@("`@
M"B`@("`@("`@("`@("\O($=E="!T:&4@:6-O;@H@("`@("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB8V]N9&ET:6]N26-O;B)=(#T@)'1H:7,M/F=E=%=E871H
M97))8V]N*"1C;VYD:71I;VXL("1C;&]U9',L("1W:6YD+"`D=&5M<&5R871U
M<F4L("1L871I='5D92P@)&QO;F=I='5D92D["@H@("`@("`@("`@("!I9B`H
M)'1H:7,M/E]C86-H945N86)L960I('L*("`@("`@("`@("`@("`@("\O($-A
M8VAE('=E871H97(*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N
M="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U=%051(15(B*3L*("`@("`@
M("`@("`@("`@("1T:&ES+3Y?8V%C:&4M/F5X=%-A=F4H(DU%5$%2+2(N)&ED
M+"`D=V5A=&AE<E)E='5R;BP@)'5N:71S1F]R;6%T+"`D97AP:7)E+"`B=V5A
M=&AE<B(I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?=V5A
M=&AE<B`]("1W96%T:&5R4F5T=7)N.PH@("`@("`@("`@("`D=V5A=&AE<E)E
M='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@("`@("`@("1T
M:&ES+3Y?8V]N=F5R=%)E='5R;B@D=V5A=&AE<E)E='5R;BP@)'5N:71S+"`D
M;&]C871I;VXI.PH*("`@("`@("!R971U<FX@)'=E871H97)2971U<FX["B`@
M("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R96-A<W0H*0H@("`@
M+RHJ"B`@("`@*B!-151!4B!P<F]V:61E<R!N;R!F;W)E8V%S="!P97(@<V4L
M('=E('5S92!T:&4@5$%&(')E<&]R=',@=&\@9V5N97)A=&4*("`@("`J(&$@
M9F]R96-A<W0@9F]R('1H92!A;FYO=6YC960@=&EM97!E<FEO9`H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M:60*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@("`@("`@("`@
M("`D9&%Y<R`@("`@("`@("`@26=N;W)E9"P@;F]T(&%P<&QI8V%B;&4*("`@
M("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=6YI
M='-&;W)M870*("`@("`J($!R971U<FX@(%!%05)?17)R;W)\87)R87D*("`@
M("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!G971&;W)E8V%S="@D:60@/2`B(BP@
M)&1A>7,@/2!N=6QL+"`D=6YI='-&;W)M870@/2`B(BD*("`@('L*("`@("`@
M("`D:60@("`@(#T@<W1R=&]U<'!E<B@D:60I.PH@("`@("`@("1S=&%T=7,@
M/2`D=&AI<RT^7V-H96-K3&]C871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H
M4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@
M("`@("!R971U<FX@)'-T871U<SL*("`@("`@("!]"@H@("`@("`@("\O($=E
M="!O=&AE<B!D871A"B`@("`@("`@)'5N:71S("`@(#T@)'1H:7,M/F=E=%5N
M:71S1F]R;6%T*"1U;FET<T9O<FUA="D["B`@("`@("`@)&QO8V%T:6]N(#T@
M)'1H:7,M/F=E=$QO8V%T:6]N*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1L;V-A=&EO;BDI('L*("`@("`@("`@("`@
M<F5T=7)N("1L;V-A=&EO;CL*("`@("`@("!]"@H@("`@("`@(&EF("@D=&AI
M<RT^7V-A8VAE16YA8FQE9"`F)B`H)&9O<F5C87-T(#T@)'1H:7,M/E]C86-H
M92T^9V5T*")-151!4BTB+B1I9"P@(F9O<F5C87-T(BDI*2!["B`@("`@("`@
M("`@("\O(%=E92XN+B!I="!W87,@8V%C:&5D+"!L970G<R!H879E(&ET+BXN
M"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;B`@/2`D9F]R96-A<W0["B`@
M("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D9F]R96-A<W12971U<FX[
M"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB8V%C:&4B72`](")(250B
M.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("\O($1O=VYL;V%D(&9O
M<F5C87-T"B`@("`@("`@("`@("1F;W)E8V%S=$1A=&$@/2`D=&AI<RT^7W)E
M=')I979E4V5R=F5R1&%T82@D:60L(")T868B*3L*("`@("`@("`@("`@:68@
M*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&9O<F5C87-T1&%T82DI('L*
M("`@("`@("`@("`@("`@(')E='5R;B`D9F]R96-A<W1$871A.PH@("`@("`@
M("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1F;W)E8V%S=$1A=&$I('Q\('-I
M>F5O9B@D9F]R96-A<W1$871A*2`\(#(I('L*("`@("`@("`@("`@("`@(')E
M='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%
M051(15)?15)23U)?5U)/3D=?4T525D527T1!5$$L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@("\O(%!A<G-E(&9O
M<F5C87-T"B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;B`@/2`D=&AI<RT^
M7W!A<G-E1F]R96-A<W1$871A*"1F;W)E8V%S=$1A=&$I.PH*("`@("`@("`@
M("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)&9O<F5C87-T4F5T
M=7)N*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1F;W)E8V%S=%)E='5R
M;CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!I9B`H)'1H:7,M/E]C86-H
M945N86)L960I('L*("`@("`@("`@("`@("`@("\O($-A8VAE('=E871H97(*
M("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N="@B4T525DE#15-?
M5T5!5$A%4E]%6%!)4D537T9/4D5#05-4(BD["B`@("`@("`@("`@("`@("`D
M=&AI<RT^7V-A8VAE+3YE>'13879E*")-151!4BTB+B1I9"P@)&9O<F5C87-T
M4F5T=7)N+"`D=6YI='-&;W)M870L("1E>'!I<F4L(")F;W)E8V%S="(I.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@("1T:&ES+3Y?9F]R96-A<W0@/2`D
M9F]R96-A<W12971U<FX["B`@("`@("`@("`@("1F;W)E8V%S=%)E='5R;ELB
M8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@("`@("`@("1T:&ES+3Y?
M8V]N=F5R=%)E='5R;B@D9F]R96-A<W12971U<FXL("1U;FET<RP@)&QO8V%T
M:6]N*3L*"B`@("`@("`@<F5T=7)N("1F;W)E8V%S=%)E='5R;CL*("`@('T*
M("`@("\O('U]?0I]"B\O('U]?0H_/@H`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+W!S82UH;W)D92]P
M96%R+U-E<G9I8V5S+U=E871H97(O5V5A=&AE<F1O=&-O;2YP:'``````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P-C,P,3`@,3`U,34T,S0Q,S(@,#(U,38P`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````#P_<&AP"B\J
M('9I;3H@<V5T(&5X<&%N9'1A8B!T86)S=&]P/30@<VAI9G1W:61T:#TT('-O
M9G1T86)S=&]P/30@9F]L9&UE=&AO9#UM87)K97(Z("HO"@HO*BH*("H@4$5!
M4CHZ4V5R=FEC97-?5V5A=&AE<E]796%T:&5R9&]T8V]M"B`J"B`J(%!(4"!V
M97)S:6]N<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@
M*&,I(#(P,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R
M=F5D+@H@*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A
M;F0@8FEN87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T
M:6]N+"!A<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN
M9R!C;VYD:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS
M(&]F('-O=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG
M:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T
M:&4@9F]L;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS
M(&EN(&)I;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y
M<FEG:'0@;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N
M9"!T:&4@9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I
M;VX*("H@("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@
M=&AE(&1I<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H
M92!S;V9T=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*
M("H@("!M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C
M=',@9&5R:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P
M96-I9FEC('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!3
M3T945T%212!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@
M04Y$($-/3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/
M4B!)35!,245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)
M5$5$(%1/+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y4
M04))3$E462!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*
M("H@05)%($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!9
M4DE'2%0@3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@
M04Y9($1)4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($58
M14U03$%262P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)
M3D<L($)55"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"
M4U1)5%5412!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L
M($]2(%!23T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7
M159%4B!#0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!7
M2$542$52($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!4
M3U)4("A)3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%2
M25-)3D<@24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E17
M05)%+"!%5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&
M(%-50T@@1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@
M("!796(@4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H
M97(*("H@0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P
M+FYE=#X*("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J
M($!L:6-E;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N
M<V5S+V)S9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@
M("`@($-64SH@)$ED.B!796%T:&5R9&]T8V]M+G!H<"QV(#$N-3@@,C`P-2\Q
M,2\Q-R`P.#HQ.3HT,B!E<G4@17AP("0*("H@0&QI;FL@("`@("`@(&AT='`Z
M+R]P96%R+G!H<"YN970O<&%C:V%G92]397)V:6-E<U]796%T:&5R"B`J($!L
M:6YK("`@("`@("!H='1P.B\O=W=W+G=E871H97(N8V]M+W-E<G9I8V5S+WAM
M;&]A<"YH=&UL"B`J($!E>&%M<&QE("`@("!E>&%M<&QE<R]W96%T:&5R+F-O
M;2UB87-I8RYP:'`@("`@("!W96%T:&5R+F-O;2UB87-I8RYP:'`*("H@0&5X
M86UP;&4@("`@(&5X86UP;&5S+W=E871H97(N8V]M+65X=&5N<VEV92YP:'`@
M('=E871H97(N8V]M+65X=&5N<VEV92YP:'`*("H@0&9I;&5S;W5R8V4*("HO
M"@IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H97(O0V]M;6]N+G!H<"([
M"@HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]796%T:&5R9&]T8V]M
M"B\J*@H@*B!4:&ES(&-L87-S(&%C=',@87,@86X@:6YT97)F86-E('1O('1H
M92!X;6P@<V5R=FEC92!O9B!W96%T:&5R+F-O;2X@270*("H@<V5A<F-H97,@
M9F]R(&=I=F5N(&QO8V%T:6]N<R!A;F0@<F5T<FEE=F5S(&-U<G)E;G0@=V5A
M=&AE<B!D871A(&%S('=E;&P*("H@87,@9F]R96-A<W0@9F]R('5P('1O(#$P
M(&1A>7,N"B`J"B`J($9O<B!U<VEN9R!T:&4@=V5A=&AE<BYC;VT@>&UL+7-E
M<G9I8V4@<&QE87-E('9I<VET"B`J("`@("!H='1P.B\O=W=W+G=E871H97(N
M8V]M+W-E<G9I8V5S+WAM;&]A<"YH=&UL"B`J(&%N9"!F;VQL;W<@=&AE(&QI
M;FL@=&\@<VEG;B!U<"P@:70G<R!F<F5E(2!9;W4@=VEL;"!R96-E:79E(&%N
M(&5M86EL"B`J('=H97)E('1O(&1O=VYL;V%D('1H92!31$L@=VET:"!T:&4@
M;F5E9&5D(&EM86=E<R!A;F0@9W5I9&5L:6YE<R!H;W<@=&\*("H@<'5B;&ES
M:"!L:79E(&1A=&$@9G)O;2!W96%T:&5R+F-O;2X@56YF;W)T=6YA=&5L>2!T
M:&4@9W5I9&5L:6YE<R!A<F4@80H@*B!B:70@:&%R<V@L('1H870G<R!W:'D@
M=&AE<F4G<R!N;R!A8W1U86P@9&%T82UR97!R97-E;G1A=&EO;B!I;B!T:&ES
M"B`J(&-L87-S+"!J=7-T('1H92!R87<@9&%T82X@06QS;R!W96%T:&5R+F-O
M;2!D96UA;F1S(&%C=&EV92!C86-H:6YG+"!S;R!))V0*("H@<W1R;VYG;'D@
M<F5C;VUM96YD(&5N86)L:6YG('1H92!C86-H:6YG(&EM<&QE;65N=&5D(&EN
M('1H:7,@8VQA<W,N($ET"B`J(&]B97ES('1O('1H92!T:6UE<R!A<R!W<FET
M=&5N(&1O=VX@:6X@=&AE(&=U:61E;&EN97,N"B`J"B`J($9O<B!W;W)K:6YG
M(&5X86UP;&5S+"!P;&5A<V4@=&%K92!A(&QO;VL@870*("H@("`@(&1O8W,O
M4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]W96%T:&5R+F-O;2UB87-I8RYP
M:'`*("H@("`@(&1O8W,O4V5R=FEC97-?5V5A=&AE<B]E>&%M<&QE<R]W96%T
M:&5R+F-O;2UE>'1E;G-I=F4N<&AP"B`J"B`J($!C871E9V]R>2`@("!796(@
M4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@
M0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*
M("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E
M;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@(%)E
M;&5A<V4Z(#$N-"XP"B`J($!L:6YK("`@("`@("!H='1P.B\O<&5A<BYP:'`N
M;F5T+W!A8VMA9V4O4V5R=FEC97-?5V5A=&AE<@H@*B!`;&EN:R`@("`@("`@
M:'1T<#HO+W=W=RYW96%T:&5R+F-O;2]S97)V:6-E<R]X;6QO87`N:'1M;`H@
M*B!`97AA;7!L92`@("`@97AA;7!L97,O=V5A=&AE<BYC;VTM8F%S:6,N<&AP
M("`@("`@=V5A=&AE<BYC;VTM8F%S:6,N<&AP"B`J($!E>&%M<&QE("`@("!E
M>&%M<&QE<R]W96%T:&5R+F-O;2UE>'1E;G-I=F4N<&AP("!W96%T:&5R+F-O
M;2UE>'1E;G-I=F4N<&AP"B`J+PIC;&%S<R!397)V:6-E<U]796%T:&5R7U=E
M871H97)D;W1C;VT@97AT96YD<R!397)V:6-E<U]796%T:&5R7T-O;6UO;B![
M"@H@("`@+R\@>WM[('!R;W!E<G1I97,*("`@("\J*@H@("`@("H@4&%R=&YE
M<BU)1"!A="!W96%T:&5R+F-O;0H@("`@("H*("`@("`J($!V87(@("`@('-T
M<FEN9R`@("`@("`@("`@("`@("`@("`@("`D7W!A<G1N97))1`H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]P87)T;F5R240@
M/2`B(CL*"B`@("`O*BH*("`@("`J($QI8V5N<V4@:V5Y(&%T('=E871H97(N
M8V]M"B`@("`@*@H@("`@("H@0'9A<B`@("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1?;&EC96YS94ME>0H@("`@("H@0&%C8V5S<R`@<')I=F%T
M90H@("`@("HO"B`@("!V87(@)%]L:6-E;G-E2V5Y(#T@(B(["@H@("`@+RHJ
M"B`@("`@*B!3=VET8V@@=&\@=&]G9VQE('!R92UF971C:&EN9R!O9B!D871A
M(&EN(&]N92!S:6YG;&4@<F5Q=65S=`H@("`@("H*("`@("`J($!V87(@("`@
M(&)O;VP@("`@("`@("`@("`@("`@("`@("`@("`D7W!R949E=&-H"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@("!V87(@)%]P<F5&971C
M:"`](&9A;'-E.PH*("`@("\J*@H@("`@("H@3V)J96-T(&-O;G1A:6YI;F<@
M=&AE('!R;VUO=&EO;F%L(&QI;FMS+61A=&$*("`@("`J"B`@("`@*B!`=F%R
M("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@("`@("`@)%]L:6YK<PH@("`@
M("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L:6YK<SL*
M"B`@("`O*BH*("`@("`J(%A-3%]5;G-E<FEA;&EZ97(L('5S960@9F]R('!R
M;V-E<W-I;F<@=&AE('AM;`H@("`@("H*("`@("`J($!V87(@("`@(&]B:F5C
M="!834Q?56YS97)I86QI>F5R("`@("`D7W5N<V5R:6%L:7IE<@H@("`@("H@
M0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]U;G-E<FEA;&EZ
M97(["B`@("`O+R!]?7T*"B`@("`O+R![>WL@8V]N<W1R=6-T;W(*("`@("\J
M*@H@("`@("H@0V]N<W1R=6-T;W(*("`@("`J"B`@("`@*B!297%U:7)E<R!8
M34Q?4V5R:6%L:7IE<B!T;R!B92!I;G-T86QL960*("`@("`J"B`@("`@*B!`
M<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&]P=&EO;G,*
M("`@("`J($!P87)A;2`@(&UI>&5D("`@("`@("`@("`@("`@("`@("`@("`D
M97)R;W(*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(*("`@("`J($!A8V-E
M<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N8W1I;VX@4V5R=FEC97-?5V5A
M=&AE<E]796%T:&5R9&]T8V]M*"1O<'1I;VYS+"`F)&5R<F]R*0H@("`@>PH@
M("`@("`@("1P97)R;W(@/2!N=6QL.PH@("`@("`@("1T:&ES+3Y397)V:6-E
M<U]796%T:&5R7T-O;6UO;B@D;W!T:6]N<RP@)'!E<G)O<BD["B`@("`@("`@
M:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'!E<G)O<BDI('L*("`@
M("`@("`@("`@)&5R<F]R(#T@)'!E<G)O<CL*("`@("`@("`@("`@<F5T=7)N
M.PH@("`@("`@('T*"B`@("`@("`@+R\@4V5T(&]P=&EO;G,@86-C;W)D:6YG
M;'D*("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G!A<G1N97))1")=*2D@
M>PH@("`@("`@("`@("`D=&AI<RT^<V5T06-C;W5N=$1A=&$H)&]P=&EO;G-;
M(G!A<G1N97))1")=*3L*("`@("`@("!]"B`@("`@("`@:68@*&ES<V5T*"1O
M<'1I;VYS6R)L:6-E;G-E2V5Y(ETI*2!["B`@("`@("`@("`@("1T:&ES+3YS
M971!8V-O=6YT1&%T82@B(BP@)&]P=&EO;G-;(FQI8V5N<V5+97DB72D["B`@
M("`@("`@?0H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB<')E1F5T8V@B
M72DI('L*("`@("`@("`@("`@)'1H:7,M/F5N86)L95!R949E=&-H*"1O<'1I
M;VYS6R)P<F5&971C:")=*3L*("`@("`@("!]"@H@("`@("`@(&EN8VQU9&5?
M;VYC92`B6$U,+U5N<V5R:6%L:7IE<BYP:'`B.PH@("`@("`@("1U;G-E<FEA
M;&EZ97(@/2`F;F5W(%A-3%]5;G-E<FEA;&EZ97(H87)R87DH(F-O;7!L97A4
M>7!E(B`]/B`B;V)J96-T(BP@(FME>4%T=')I8G5T92(@/3X@(G1Y<&4B*2D[
M"B`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'5N<V5R
M:6%L:7IE<BDI('L*("`@("`@("`@("`@)&5R<F]R(#T@)'5N<V5R:6%L:7IE
M<CL*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T@96QS92!["B`@("`@
M("`@("`@("1T:&ES+3Y?=6YS97)I86QI>F5R(#T@)'5N<V5R:6%L:7IE<CL*
M("`@("`@("!]"@H@("`@("`@("\O($-A;B=T(&%C<75I<F4@86X@;V)J96-T
M(&AE<F4L(&AA<R!T;R!B92!C;&5A;B!O;B!E=F5R>2!R97%U97-T"B`@("`@
M("`@:6YC;'5D95]O;F-E(")(5%10+U)E<75E<W0N<&AP(CL*("`@('T*("`@
M("\O('U]?0H*("`@("\O('M[>R!S971!8V-O=6YT1&%T82@I"B`@("`O*BH*
M("`@("`J(%-E=',@=&AE(&YE8V-E<W-A<GD@86-C;W5N="UI;F9O<FUA=&EO
M;B!F;W(@=V5A=&AE<BYC;VTL('EO=2=L;`H@("`@("H@<F5C96EV92!T:&5M
M(&%F=&5R(')E9VES=&5R:6YG(&9O<B!T:&4@6$U,+7-T<F5A;0H@("`@("H*
M("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M<&%R=&YE<DE$"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@
M("`@("`@("`@)&QI8V5N<V5+97D*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("HO"B`@("!F=6YC=&EO;B!S971!8V-O=6YT1&%T82@D<&%R=&YE<DE$
M+"`D;&EC96YS94ME>2D*("`@('L*("`@("`@("!I9B`H<W1R;&5N*"1P87)T
M;F5R240I("8F(&-T>7!E7V1I9VET*"1P87)T;F5R240I*2!["B`@("`@("`@
M("`@("1T:&ES+3Y?<&%R=&YE<DE$("`]("1P87)T;F5R240["B`@("`@("`@
M?0H@("`@("`@(&EF("AS=')L96XH)&QI8V5N<V5+97DI("8F(&-T>7!E7V%L
M;G5M*"1L:6-E;G-E2V5Y*2D@>PH@("`@("`@("`@("`D=&AI<RT^7VQI8V5N
M<V5+97D@/2`D;&EC96YS94ME>3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]
M?7T*"B`@("`O+R![>WL@96YA8FQE4')E1F5T8V@H*0H@("`@+RHJ"B`@("`@
M*B!%;F%B;&5S('!R92UF971C:&EN9R!O9B!D871A(&EN(&]N92!S:6YG;&4@
M<F5Q=65S=`H@("`@("H*("`@("`J($!P87)A;2`@(&)O;VP@("`@("`@("`@
M("`@("`@("`@("`@("`D<')E1F5T8V@*("`@("`J($!A8V-E<W,@('!U8FQI
M8PH@("`@("HO"B`@("!F=6YC=&EO;B!E;F%B;&50<F5&971C:"@D<')E1F5T
M8V@I"B`@("!["B`@("`@("`@:68@*"1P<F5&971C:"`]/2!T<G5E*2!["B`@
M("`@("`@("`@("1T:&ES+3Y?<')E1F5T8V@@/2!T<G5E.PH@("`@("`@('T*
M("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!?8VAE8VM,;V-A=&EO;DE$
M*"D*("`@("\J*@H@("`@("H@0VAE8VMS('1H92!I9"!F;W(@=F%L:60@=F%L
M=65S(&%N9"!T:'5S('!R979E;G1S('-I;&QY(')E<75E<W1S('1O"B`@("`@
M*B!W96%T:&5R+F-O;2!S97)V97(*("`@("`J"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N
M("!014%27T5R<F]R?&)O;VP*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z
M.E-%4E9)0T537U=%051(15)?15)23U)?3D]?3$]#051)3TX*("`@("`J($!T
M:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?24Y6
M04Q)1%],3T-!5$E/3@H@("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO
M"B`@("!F=6YC=&EO;B!?8VAE8VM,;V-A=&EO;DE$*"1I9"D*("`@('L*("`@
M("`@("!I9B`H:7-?87)R87DH)&ED*2!\?"!I<U]O8FIE8W0H)&ED*2!\?"`A
M<W1R;&5N*"1I9"DI('L*("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E
M871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E].3U],
M3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@("`@("!](&5L<V5I
M9B`H(6-T>7!E7V%L;G5M*"1I9"D@?'P@*'-T<FQE;B@D:60I(#X@."DI('L*
M("`@("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R
M;W(H4T525DE#15-?5T5!5$A%4E]%4E)/4E])3E9!3$E$7TQ/0T%424].+"!?
M7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N
M('1R=64["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@7W!A<G-E5V5A
M=&AE<D1A=&$H*0H@("`@+RHJ"B`@("`@*B!&971C:&5S('1H92!D871A(&)A
M<V5D(&]N('1H92!R97%U97-T960@='EP92!A;F0@8V%C:&5S(&ET"B`@("`@
M*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@("`@
M("1I9`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@("`@
M("`@("1R97%4>7!E"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&)O;VP*
M("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(15)?
M15)23U)?5U)/3D=?4T525D527T1!5$$*("`@("`J($!T:')O=W,@(%!%05)?
M17)R;W(*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@("`@9G5N
M8W1I;VX@7W!A<G-E5V5A=&AE<D1A=&$H)&ED+"`D<F5Q5'EP92D*("`@('L*
M("`@("`@("!I9B`H)'1H:7,M/E]P<F5&971C:"D@>PH@("`@("`@("`@("`D
M<F5Q5'EP92`](")A;&PB.PH@("`@("`@('T*"B`@("`@("`@)'5R;"`](")H
M='1P.B\O>&]A<"YW96%T:&5R+F-O;2]W96%T:&5R+VQO8V%L+R(N)&ED+B(_
M<')O9#UX;V%P)G!A<CTB+B1T:&ES+3Y?<&%R=&YE<DE$+B(F:V5Y/2(N)'1H
M:7,M/E]L:6-E;G-E2V5Y.PH*("`@("`@("!S=VET8V@@*"1R97%4>7!E*2![
M"B`@("`@("`@("`@(&-A<V4@(FQI;FMS(CH*("`@("`@("`@("`@("`@("1U
M<FP@+CT@(B9L:6YK/7AO87`B.PH@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@(&-A<V4@(G=E871H97(B.@H@("`@("`@("`@("`@("`@)'5R
M;"`N/2`B)F-C/2HF=6YI=#US(CL*("`@("`@("`@("`@("`@(&)R96%K.PH@
M("`@("`@("`@("!C87-E(")F;W)E8V%S="(Z"B`@("`@("`@("`@("`@("`D
M=7)L("X]("(F9&%Y9CTQ,"9U;FET/7,B.PH@("`@("`@("`@("`@("`@8G)E
M86L["B`@("`@("`@("`@(&-A<V4@(F%L;"(Z"B`@("`@("`@("`@("`@("`D
M=7)L("X]("(F;&EN:SUX;V%P)F-C/2HF9&%Y9CTQ,"9U;FET/7,B.PH@("`@
M("`@("`@("`@("`@8G)E86L["B`@("`@("`@?0H*("`@("`@("`O+R!'970@
M9&%T82!F<F]M(%523"XN+@H@("`@("`@("1R97%U97-T(#T@)FYE=R!(5%10
M7U)E<75E<W0H)'5R;"P@)'1H:7,M/E]H='1P3W!T:6]N<RD["B`@("`@("`@
M)'-T871U<R`]("1R97%U97-T+3YS96YD4F5Q=65S="@I.PH@("`@("`@(&EF
M("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I('Q\("AI;G0I
M("1R97%U97-T+3YG971297-P;VYS94-O9&4H*2`\/B`R,#`I('L*("`@("`@
M("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T52
M5DE#15-?5T5!5$A%4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%
M7U\L(%]?3$E.15]?*3L*("`@("`@("!]"B`@("`@("`@)&1A=&$@/2`D<F5Q
M=65S="T^9V5T4F5S<&]N<V5";V1Y*"D["@H@("`@("`@("\O("XN+F%N9"!U
M;G-E<FEA;&EZ90H@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7W5N<V5R:6%L
M:7IE<BT^=6YS97)I86QI>F4H)&1A=&$I.PH*("`@("`@("!I9B`H4V5R=FEC
M97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R
M971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]7
M14%42$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@("1R;V]T(#T@
M)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E=%)O;W1.86UE*"D["B`@("`@("`@
M("`@("1D871A(#T@)'1H:7,M/E]U;G-E<FEA;&EZ97(M/F=E=%5N<V5R:6%L
M:7IE9$1A=&$H*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E<U]796%T:&5R
M.CII<T5R<F]R*"1R;V]T*2!\?"`D<F]O="`]/2`B2%1-3"(I('L*("`@("`@
M("`@("`@("`@("\O(%-O;65T:&EN9R!W<F]N9R!H97)E+"!M87EB92!N;W0@
M6$U,(')E=')I979E9"XN+@H@("`@("`@("`@("`@("`@<F5T=7)N(%-E<G9I
M8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?*3L*("`@
M("`@("`@("`@?2!E;'-E:68@*"1R;V]T(#T](")E<G)O<B(I('L*("`@("`@
M("`@("`@("`@("\O(%=E(&=O="!A;B!E<G)O<B!B86-K(&9R;VT@=V5A=&AE
M<BYC;VT*("`@("`@("`@("`@("`@("1E<G)N;R`@/2!K97DH9V5T7V]B:F5C
M=%]V87)S*"1D871A*2D["B`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC
M97-?5V5A=&AE<CHZ<F%I<V5%<G)O<B@D97)R;F\L(%]?1DE,15]?+"!?7TQ)
M3D5?7RD["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`O
M+R!686QI9"!D871A+"!L971S(&=E="!S=&%R=&5D"B`@("`@("`@("`@("`@
M("`O+R!,;V]P('1H<F]U9V@@=&AE(&1I9F9E<F5N="!S=6(M<&%R=',@;V8@
M=&AE(&1A=&$@9G)O('!R;V-E<W-I;F<*("`@("`@("`@("`@("`@(&9O<F5A
M8V@@*&=E=%]O8FIE8W1?=F%R<R@D9&%T82D@87,@)&ME>2`]/B`D=F%L*2![
M"B`@("`@("`@("`@("`@("`@("`@<W=I=&-H("@D:V5Y*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-A<V4@(FAE860B.@H@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@8V]N=&EN=64@,CL*("`@("`@("`@("`@("`@("`@("`@
M("`@8V%S92`B<')M;R(Z"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D
M=F%R;F%M92`@/2`B;&EN:W,B.PH@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@8G)E86L["B`@("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(FQO8R(Z
M"B`@("`@("`@("`@("`@("`@("`@("`@("`@("`D=F%R;F%M92`@/2`B;&]C
M871I;VXB.PH@("`@("`@("`@("`@("`@("`@("`@("`@("`@8G)E86L["B`@
M("`@("`@("`@("`@("`@("`@("`@(&-A<V4@(F-C(CH*("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("1V87)N86UE("`](")W96%T:&5R(CL*("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(&)R96%K.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C87-E(")D87EF(CH*("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("1V87)N86UE("`](")F;W)E8V%S="(["B`@("`@("`@("`@("`@("`@
M("`@("`@("`@("!B<F5A:SL*("`@("`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("`@("`@+R\@4V%V92!D871A(&EN(&]B:F5C=`H@("`@("`@
M("`@("`@("`@("`@("1T:&ES+3Y[(E\B+B1V87)N86UE?2`]("1V86P["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("\O("XN+F%N9"!C86-H92!I9B!P
M;W-S:6)L90H@("`@("`@("`@("`@("`@("`@("`@("`D97AP:7)E(#T@8V]N
M<W1A;G0H(E-%4E9)0T537U=%051(15)?15A025)%4U\B+G-T<G1O=7!P97(H
M)'9A<FYA;64I*3L*("`@("`@("`@("`@("`@("`@("`@("`@)'1H:7,M/E]C
M86-H92T^97AT4V%V92@D:60L("1V86PL("(B+"`D97AP:7)E+"`D=F%R;F%M
M92D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!R971U<FX@=')U93L*
M("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!S96%R8VA,;V-A=&EO;B@I
M"B`@("`O*BH*("`@("`J(%-E87)C:&5S($E$<R!F;W(@9VEV96X@;&]C871I
M;VXL(')E='5R;G,@87)R87D@;V8@<&]S<VEB;&4@;&]C871I;VYS"B`@("`@
M*B!O<B!S:6YG;&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)&QO8V%T:6]N"B`@("`@*B!`<&%R86T@
M("!B;V]L("`@("`@("`@("`@("`@("`@("`@("`@)'5S949I<G-T("`@("`@
M($EF('-E="P@9FER<W0@240@;V8@<F5S=6QT+6%R<F%Y(&ES(')E='5R;F5D
M"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y?'-T<FEN9PH@("`@
M("H@0'1H<F]W<R`@4$5!4E]%<G)O<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/
M4E]74D].1U]315)615)?1$%400H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O
M<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]53DM.3U=.7TQ/0T%424]."B`@
M("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5A
M<F-H3&]C871I;VXH)&QO8V%T:6]N+"`D=7-E1FER<W0@/2!F86QS92D*("`@
M('L*("`@("`@("`D;&]C871I;VX@/2!T<FEM*"1L;V-A=&EO;BD["B`@("`@
M("`@)&QO8TQO=R`@(#T@<W1R=&]L;W=E<B@D;&]C871I;VXI.PH@("`@("`@
M(`H@("`@("`@("\O($-H96-K(&]N(&-A8VAE9"!D871A.B!-1#4M:&%S:"!O
M9B!L;V-A=&EO;B!H87,@=&\@8F4@8V]R<F5C="!A;F0@=&AE('5S97)D871A
M(&AA<R!T;R!B92!T:&4@<V%M92!A<R!T:&4@9VEV96X@;&]C871I;VX@"B`@
M("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F("1L;V-,;W<@/3T@
M)'1H:7,M/E]C86-H92T^9V5T57-E<D1A=&$H;60U*"1L;V-,;W<I+"`B<V5A
M<F-H(BDI('L*("`@("`@("`@("`@)'-E87)C:"`]("1T:&ES+3Y?8V%C:&4M
M/F=E="AM9#4H)&QO8TQO=RDL(")S96%R8V@B*3L*("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`O+R!'970@<V5A<F-H(&1A=&$@9G)O;2!S97)V97(@
M86YD('5N<V5R:6%L:7IE"B`@("`@("`@("`@("1R97%U97-T(#T@)FYE=R!(
M5%107U)E<75E<W0H(FAT='`Z+R]X;V%P+G=E871H97(N8V]M+W-E87)C:"]S
M96%R8V@_=VAE<F4](BYU<FQE;F-O9&4H)&QO8V%T:6]N*2P@)'1H:7,M/E]H
M='1P3W!T:6]N<RD["B`@("`@("`@("`@("1S=&%T=7,@/2`D<F5Q=65S="T^
M<V5N9%)E<75E<W0H*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H
M97(Z.FES17)R;W(H)'-T871U<RD@?'P@*&EN="D@)')E<75E<W0M/F=E=%)E
M<W!O;G-E0V]D92@I(#P^(#(P,"D@>PH@("`@("`@("`@("`@("`@<F5T=7)N
M(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H4T525DE#15-?5T5!5$A%
M4E]%4E)/4E]74D].1U]315)615)?1$%402P@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D9&%T82`]("1R97%U97-T
M+3YG971297-P;VYS94)O9'DH*3L*("`@(`H@("`@("`@("`@("`O+R`N+BYA
M;F0@=6YS97)I86QI>F4*("`@("`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?
M=6YS97)I86QI>F5R+3YU;G-E<FEA;&EZ92@D9&%T82P@9F%L<V4L(&%R<F%Y
M*")O=F5R<FED94]P=&EO;G,B(#T^('1R=64L(")C;VUP;&5X5'EP92(@/3X@
M(F%R<F%Y(BP@(FME>4%T=')I8G5T92(@/3X@(FED(BDI.PH@("`@"B`@("`@
M("`@("`@(&EF("A397)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I
M*2!["B`@("`@("`@("`@("`@("!R971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ
M<F%I<V5%<G)O<BA315)624-%4U]714%42$527T524D]27U=23TY'7U-%4E9%
M4E]$051!+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@("`@("!]"B`@
M("`*("`@("`@("`@("`@)')O;W0@/2`D=&AI<RT^7W5N<V5R:6%L:7IE<BT^
M9V5T4F]O=$YA;64H*3L*("`@("`@("`@("`@)'-E87)C:"`]("1T:&ES+3Y?
M=6YS97)I86QI>F5R+3YG9715;G-E<FEA;&EZ961$871A*"D["B`@("`*("`@
M("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R;W(H)'-E87)C
M:"D@?'P@)')O;W0@/3T@(DA434PB*2!["B`@("`@("`@("`@("`@("!R971U
M<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%4
M2$527T524D]27U=23TY'7U-%4E9%4E]$051!+"!?7T9)3$5?7RP@7U],24Y%
M7U\I.PH@("`@("`@("`@("!](&5L<V5I9B`H(6ES7V%R<F%Y*"1S96%R8V@I
M('Q\("%S:7IE;V8H)'-E87)C:"DI('L*("`@("`@("`@("`@("`@(')E='5R
M;B!397)V:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(
M15)?15)23U)?54Y+3D]73E],3T-!5$E/3BP@7U]&24Q%7U\L(%]?3$E.15]?
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@:68@*"1T:&ES+3Y?8V%C
M:&5%;F%B;&5D*2!["B`@("`@("`@("`@("`@("`O+R`N+BYA;F0@8V%C:&4@
M:68@<&]S<VEB;&4*("`@("`@("`@("`@("`@("1E>'!I<F4@/2!C;VYS=&%N
M="@B4T525DE#15-?5T5!5$A%4E]%6%!)4D537U-%05)#2"(I.PH@("`@("`@
M("`@("`@("`@)'1H:7,M/E]C86-H92T^97AT4V%V92AM9#4H)&QO8TQO=RDL
M("1S96%R8V@L("1L;V-,;W<L("1E>'!I<F4L(")S96%R8V@B*3L*("`@("`@
M("`@("`@?0H@("`@("`@('T*"B`@("`@("`@:68@*"$D=7-E1FER<W0@)B8@
M*'-I>F5O9B@D<V5A<F-H*2`^(#$I*2!["B`@("`@("`@("`@("1S96%R8VA2
M971U<FX@/2`D<V5A<F-H.PH@("`@("`@('T@96QS96EF("@D=7-E1FER<W0@
M?'P@*'-I>F5O9B@D<V5A<F-H*2`]/2`Q*2D@>PH@("`@("`@("`@("`D<V5A
M<F-H4F5T=7)N(#T@:V5Y*"1S96%R8V@I.PH@("`@("`@('T*"B`@("`@("`@
M<F5T=7)N("1S96%R8VA2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@<V5A<F-H3&]C871I;VY">4-O=6YT<GDH*0H@("`@+RHJ"B`@("`@
M*B!2971U<FYS(&]N;'D@9F%L<V4L(&%S('=E871H97(N8V]M(&]F9F5R<R!N
M;R!C;W5N=')Y(&QI<W1I;F<@=FEA"B`@("`@*B!I=',@6$U,('-E<G9I8V5S
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1C;W5N=')Y"B`@("`@*B!`<F5T=7)N("!B;V]L"B`@("`@*B!`
M86-C97-S("!P=6)L:6,*("`@("`J($!D97!R96-A=&5D"B`@("`@*B\*("`@
M(&9U;F-T:6]N('-E87)C:$QO8V%T:6]N0GE#;W5N=')Y*"1C;W5N=')Y(#T@
M(B(I"B`@("!["B`@("`@("`@<F5T=7)N(&9A;'-E.PH@("`@?0H@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(&=E=$QI;FMS*"D*("`@("\J*@H@("`@("H@4F5T
M=7)N<R!T:&4@9&%T82!F;W(@=&AE('!R;VUO=&EO;F%L(&QI;FMS(&)E;&]N
M9VEN9R!T;R!T:&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%2
M7T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&EN
M:W,H)&ED(#T@(B(I"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES+3Y?
M8VAE8VM,;V-A=&EO;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E<U]7
M96%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E='5R
M;B`D<W1A='5S.PH@("`@("`@('T*"B`@("`@("`@)&QI;FMS4F5T=7)N(#T@
M87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B;&5D("8F
M("@D;&EN:W,@/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B;&EN:W,B*2DI
M('L*("`@("`@("`@("`@+R\@1V5T(&1A=&$@9G)O;2!C86-H90H@("`@("`@
M("`@("`D=&AI<RT^7VQI;FMS(#T@)&QI;FMS.PH@("`@("`@("`@("`D;&EN
M:W-2971U<FY;(F-A8VAE(ET@/2`B2$E4(CL*("`@("`@("!](&5L<V4@>PH@
M("`@("`@("`@("`O+R!386UE(&%S(&EN('1H92!F=6YC=&EO;B!A8F]V92XN
M+@H@("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]P87)S95=E871H97)$
M871A*"1I9"P@(FQI;FMS(BD["@H@("`@("`@("`@("!I9B`H4V5R=FEC97-?
M5V5A=&AE<CHZ:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("`@("`@
M<F5T=7)N("1S=&%T=7,["B`@("`@("`@("`@('T*("`@("`@("`@("`@)&QI
M;FMS4F5T=7)N6R)C86-H92)=(#T@(DU)4U,B.PH@("`@("`@('T*"B`@("`@
M("`@)&QI;FMS4F5T=7)N6R)P<F]M;R)=(#T@87)R87DH*3L*("`@("`@("!F
M;W(@*"1I(#T@,#L@)&D@/"!S:7IE;V8H)'1H:7,M/E]L:6YK<RT^;&EN:RD[
M("1I*RLI('L*("`@("`@("`@("`@)&QI;FMS4F5T=7)N6R)P<F]M;R)=6R1I
M72`](&%R<F%Y*"D["B`@("`@("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B
M75LD:5U;(G1I=&QE(ET@/2`D=&AI<RT^7VQI;FMS+3YL:6YK6R1I72T^=#L*
M("`@("`@("`@("`@+R\@0C!R:V5D(')E<W!O;G-E("AR971U<FYE9"!I<R`F
M<&%R/7AO87`L('-H;W5L9"!B92`F<')O9#UX;V%P*2P@9FEX(&ET"B`@("`@
M("`@("`@("1L:6YK<U)E='5R;ELB<')O;6\B75LD:5U;(FQI;FLB72`@/2!S
M=')?<F5P;&%C92@B<&%R/2(L(")P<F]D/2(L("1T:&ES+3Y?;&EN:W,M/FQI
M;FM;)&E=+3YL*3L*("`@("`@("`@("`@)&QI;FMS4F5T=7)N6R)P<F]M;R)=
M6R1I75LB;&EN:R)=("X]("(F<&%R/2(N)'1H:7,M/E]P87)T;F5R240["B`@
M("`@("`@?0H*("`@("`@("!R971U<FX@)&QI;FMS4F5T=7)N.PH@("`@?0H@
M("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=$QO8V%T:6]N*"D*("`@("\J*@H@
M("`@("H@4F5T=7)N<R!T:&4@9&%T82!F;W(@=&AE(&QO8V%T:6]N(&)E;&]N
M9VEN9R!T;R!T:&4@240*("`@("`J"B`@("`@*B!`<&%R86T@("!S=')I;F<@
M("`@("`@("`@("`@("`@("`@("`@)&ED"B`@("`@*B!`<F5T=7)N("!014%2
M7T5R<F]R?&%R<F%Y"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@
M*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T3&]C
M871I;VXH)&ED(#T@(B(I"B`@("!["B`@("`@("`@)'-T871U<R`]("1T:&ES
M+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D["@H@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@(')E
M='5R;B`D<W1A='5S.PH@("`@("`@('T*"B`@("`@("`@)&QO8V%T:6]N4F5T
M=7)N(#T@87)R87DH*3L*"B`@("`@("`@:68@*"1T:&ES+3Y?8V%C:&5%;F%B
M;&5D("8F("@D;&]C871I;VX@/2`D=&AI<RT^7V-A8VAE+3YG970H)&ED+"`B
M;&]C871I;VXB*2DI('L*("`@("`@("`@("`@+R\@1V5T(&1A=&$@9G)O;2!C
M86-H90H@("`@("`@("`@("`D=&AI<RT^7VQO8V%T:6]N(#T@)&QO8V%T:6]N
M.PH@("`@("`@("`@("`D;&]C871I;VY2971U<FY;(F-A8VAE(ET@/2`B2$E4
M(CL*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`O+R!386UE(&%S(&EN
M('1H92!F=6YC=&EO;B!A8F]V92XN+@H@("`@("`@("`@("`D<W1A='5S(#T@
M)'1H:7,M/E]P87)S95=E871H97)$871A*"1I9"P@(FQO8V%T:6]N(BD["@H@
M("`@("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ:7-%<G)O<B@D<W1A
M='5S*2D@>PH@("`@("`@("`@("`@("`@<F5T=7)N("1S=&%T=7,["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)&QO8V%T:6]N4F5T=7)N6R)C86-H92)=
M(#T@(DU)4U,B.PH@("`@("`@('T*"B`@("`@("`@)&QO8V%T:6]N4F5T=7)N
M6R)N86UE(ET@("`@("`]("1T:&ES+3Y?;&]C871I;VXM/F1N86T["B`@("`@
M("`@)&QO8V%T:6]N4F5T=7)N6R)T:6UE(ET@("`@("`](&1A=&4H)'1H:7,M
M/E]T:6UE1F]R;6%T+"!S=')T;W1I;64H)'1H:7,M/E]L;V-A=&EO;BT^=&TI
M*3L*("`@("`@("`D;&]C871I;VY2971U<FY;(FQA=&ET=61E(ET@(#T@)'1H
M:7,M/E]L;V-A=&EO;BT^;&%T.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB
M;&]N9VET=61E(ET@/2`D=&AI<RT^7VQO8V%T:6]N+3YL;VX["B`@("`@("`@
M)&QO8V%T:6]N4F5T=7)N6R)S=6YR:7-E(ET@("`](&1A=&4H)'1H:7,M/E]T
M:6UE1F]R;6%T+"!S=')T;W1I;64H)'1H:7,M/E]L;V-A=&EO;BT^<W5N<BDI
M.PH@("`@("`@("1L;V-A=&EO;E)E='5R;ELB<W5N<V5T(ET@("`@/2!D871E
M*"1T:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?;&]C871I
M;VXM/G-U;G,I*3L*("`@("`@("`D;&]C871I;VY2971U<FY;(G1I;65Z;VYE
M(ET@(#T@)'1H:7,M/E]L;V-A=&EO;BT^>F]N93L*"B`@("`@("`@<F5T=7)N
M("1L;V-A=&EO;E)E='5R;CL*("`@('T*("`@("\O('U]?0H*("`@("\O('M[
M>R!G971796%T:&5R*"D*("`@("\J*@H@("`@("H@4F5T=7)N<R!T:&4@=V5A
M=&AE<BUD871A(&9O<B!T:&4@<W5P<&QI960@;&]C871I;VX*("`@("`J"B`@
M("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&ED
M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@
M)'5N:71S1F]R;6%T"B`@("`@*B!`<F5T=7)N("!014%27T5R<F]R?&%R<F%Y
M"B`@("`@*B!`=&AR;W=S("!014%27T5R<F]R"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@9V5T5V5A=&AE<B@D:60@/2`B
M(BP@)'5N:71S1F]R;6%T(#T@(B(I"B`@("!["B`@("`@("`@)'-T871U<R`]
M("1T:&ES+3Y?8VAE8VM,;V-A=&EO;DE$*"1I9"D["@H@("`@("`@(&EF("A3
M97)V:6-E<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@
M("`@(')E='5R;B`D<W1A='5S.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5T
M(&]T:&5R(&1A=&$*("`@("`@("`D=6YI=',@("`@/2`D=&AI<RT^9V5T56YI
M='-&;W)M870H)'5N:71S1F]R;6%T*3L*"B`@("`@("`@)'=E871H97)2971U
M<FX@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H)'1H:7,M/E]C86-H945N86)L
M960@)B8@*"1W96%T:&5R(#T@)'1H:7,M/E]C86-H92T^9V5T*"1I9"P@(G=E
M871H97(B*2DI('L*("`@("`@("`@("`@+R\@4V%M92!P<F]C961U<F4N+BX*
M("`@("`@("`@("`@)'1H:7,M/E]W96%T:&5R(#T@)'=E871H97(["B`@("`@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)C86-H92)=(#T@(DA)5"(["B`@("`@
M("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@+BXN87,@;&%S="!F=6YC=&EO
M;@H@("`@("`@("`@("`D<W1A='5S(#T@)'1H:7,M/E]P87)S95=E871H97)$
M871A*"1I9"P@(G=E871H97(B*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB8V%C:&4B72`](")-25-3(CL*("`@("`@("!]"@H@
M("`@("`@("\O(%-O;64@97AP;&%N871I;VX@9F]R('1H92!N97AT('1W;R!L
M:6YE<SH*("`@("`@("`O+R!W96%T:&5R+F-O;2!I<VXG="!A;'=A>7,@<W5P
M<&QY:6YG('1H92!T:6UE>F]N92!I;B!T:&4@=7!D871E('-T<FEN9RP@8G5T
M"B`@("`@("`@+R\@=7-E<R`B3&]C86P@5&EM92(@87,@<F5F97)E;F-E+"!W
M:&EC:"!I<R!I;6AO('5T=&5R;'D@<W1U<&ED+"!B96-A=7-E(&ET)W,*("`@
M("`@("`O+R!I;F-O;G-I<W1E;G0N(%=E;&PL('=H870@22!D;R!H97)E(&ES
M(&-H96-K(&9O<B!T:&ES('-T<FEN9R!A;F0@:68@22!C86X*("`@("`@("`O
M+R!F:6YD(&ET+"!)(&-A;&-U;&%T92!T:&4@9&EF9F5R96YC92!B971W965N
M('1H92!T:6UE>F]N92!A="!T:&4@;&]C871I;VX*("`@("`@("`O+R!A;F0@
M=&AI<R!C;VUP=71E<G,@=&EM97IO;F4N(%1H:7,@86UO=6YT(&]F('-E8V]N
M9',@:7,@=&AE;B!S=6)T<F%C=&5D(&9R;VT*("`@("`@("`O+R!T:&4@=&EM
M92!T:&4@=7!D871E+7-T<FEN9R!H87,@9&5L:79E<F5D+@H@("`@("`@("1U
M<&1A=&4@("`]('-T<E]R97!L86-E*"),;V-A;"!4:6UE(BP@(B(L("1T:&ES
M+3Y?=V5A=&AE<BT^;'-U<"D["B`@("`@("`@)&%D:G5S=%1:(#T@*"1U<&1A
M=&4@/3T@)'1H:7,M/E]W96%T:&5R+3YL<W5P*2`_(#`@.B`D=&AI<RT^7VQO
M8V%T:6]N+3YZ;VYE("H@,S8P,"`M(&1A=&4H(EHB*3L*("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB=7!D871E(ET@("`@("`@("`@("`](&=M9&%T92AT<FEM
M*"1T:&ES+3Y?9&%T949O<FUA="XB("(N)'1H:7,M/E]T:6UE1F]R;6%T*2P@
M<W1R=&]T:6UE*"1U<&1A=&4I("T@)&%D:G5S=%1:*3L*("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB=7!D871E4F%W(ET@("`@("`@("`]("1T:&ES+3Y?=V5A
M=&AE<BT^;'-U<#L*("`@("`@("`D=V5A=&AE<E)E='5R;ELB<W1A=&EO;B)=
M("`@("`@("`@("`]("1T:&ES+3Y?=V5A=&AE<BT^;V)S=#L*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=&5M<&5R871U<F4B72`@("`@("`]("1T:&ES+3YC
M;VYV97)T5&5M<&5R871U<F4H)'1H:7,M/E]W96%T:&5R+3YT;7`L(")F(BP@
M)'5N:71S6R)T96UP(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)F96QT
M5&5M<&5R871U<F4B72`@(#T@)'1H:7,M/F-O;G9E<G1496UP97)A='5R92@D
M=&AI<RT^7W=E871H97(M/F9L:6LL(")F(BP@)'5N:71S6R)T96UP(ETI.PH@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)C;VYD:71I;VXB72`@("`@("`@(#T@
M)'1H:7,M/E]W96%T:&5R+3YT.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)C
M;VYD:71I;VY)8V]N(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YI8V]N.PH@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)P<F5S<W5R92)=("`@("`@("`@(#T@
M)'1H:7,M/F-O;G9E<G10<F5S<W5R92@D=&AI<RT^7W=E871H97(M/F)A<BT^
M<BP@(FEN(BP@)'5N:71S6R)P<F5S(ETI.PH@("`@("`@("1W96%T:&5R4F5T
M=7)N6R)P<F5S<W5R951R96YD(ET@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YB
M87(M/F0["B`@("`@("`@)'=E871H97)2971U<FY;(G=I;F0B72`@("`@("`@
M("`@("`@/2`D=&AI<RT^8V]N=F5R=%-P965D*"1T:&ES+3Y?=V5A=&AE<BT^
M=VEN9"T^<RP@(FUP:"(L("1U;FET<ULB=VEN9")=*3L*("`@("`@("`D=V5A
M=&AE<E)E='5R;ELB=VEN9$=U<W0B72`@("`@("`@("`]("1T:&ES+3YC;VYV
M97)T4W!E960H)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YG=7-T+"`B;7!H(BP@
M)'5N:71S6R)W:6YD(ETI.PH@("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD
M1&5G<F5E<R)=("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YD.PH@
M("`@("`@("1W96%T:&5R4F5T=7)N6R)W:6YD1&ER96-T:6]N(ET@("`@(#T@
M)'1H:7,M/E]W96%T:&5R+3YW:6YD+3YT.PH@("`@("`@("1W96%T:&5R4F5T
M=7)N6R)H=6UI9&ET>2)=("`@("`@("`@(#T@)'1H:7,M/E]W96%T:&5R+3YH
M;6ED.PH@("`@("`@(&EF("AI<U]N=6UE<FEC*"1T:&ES+3Y?=V5A=&AE<BT^
M=FES*2D@>PH@("`@("`@("`@("`D=V5A=&AE<E)E='5R;ELB=FES:6)I;&ET
M>2)=("`@(#T@)'1H:7,M/F-O;G9E<G1$:7-T86YC92@D=&AI<RT^7W=E871H
M97(M/G9I<RP@(G-M(BP@)'5N:71S6R)V:7,B72D["B`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@)'=E871H97)2971U<FY;(G9I<VEB:6QI='DB72`@
M("`]("1T:&ES+3Y?=V5A=&AE<BT^=FES.PH@("`@("`@('T*("`@("`@("`D
M=V5A=&AE<E)E='5R;ELB=79);F1E>")=("`@("`@("`@("`]("1T:&ES+3Y?
M=V5A=&AE<BT^=78M/FD["B`@("`@("`@)'=E871H97)2971U<FY;(G5V5&5X
M=")=("`@("`@("`@("`@/2`D=&AI<RT^7W=E871H97(M/G5V+3YT.PH@("`@
M("`@("1W96%T:&5R4F5T=7)N6R)D97=0;VEN=")=("`@("`@("`@(#T@)'1H
M:7,M/F-O;G9E<G1496UP97)A='5R92@D=&AI<RT^7W=E871H97(M/F1E=W`L
M(")F(BP@)'5N:71S6R)T96UP(ETI.PH*("`@("`@("!R971U<FX@)'=E871H
M97)2971U<FX["B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![>WL@9V5T1F]R
M96-A<W0H*0H@("`@+RHJ"B`@("`@*B!'970@=&AE(&9O<F5C87-T(&9O<B!T
M:&4@;F5X="!D87ES"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@
M("`@("`@("`@("`@("`@("`@("1I9`H@("`@("H@0'!A<F%M("`@:6YT("`@
M("`@("`@("`@("`@("`@("`@("`@("1D87ES("`@("`@("`@("!686QU97,@
M8F5T=V5E;B`Q(&%N9"`Q,`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1U;FET<T9O<FUA=`H@("`@("H@0')E='5R;B`@
M4$5!4E]%<G)O<GQA<G)A>0H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O<@H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&=E
M=$9O<F5C87-T*"1I9"`]("(B+"`D9&%Y<R`](#(L("1U;FET<T9O<FUA="`]
M("(B*0H@("`@>PH@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7V-H96-K3&]C
M871I;VY)1"@D:60I.PH*("`@("`@("!I9B`H4V5R=FEC97-?5V5A=&AE<CHZ
M:7-%<G)O<B@D<W1A='5S*2D@>PH@("`@("`@("`@("!R971U<FX@)'-T871U
M<SL*("`@("`@("!]"B`@("`@("`@:68@*"%I;E]A<G)A>2@D9&%Y<RP@<F%N
M9V4H,2P@,3`I*2D@>PH@("`@("`@("`@("`D9&%Y<R`](#(["B`@("`@("`@
M?0H*("`@("`@("`O+R!'970@;W1H97(@9&%T80H@("`@("`@("1U;FET<R`@
M("`]("1T:&ES+3YG9715;FET<T9O<FUA="@D=6YI='-&;W)M870I.PH*("`@
M("`@("`D9F]R96-A<W12971U<FX@/2!A<G)A>2@I.PH*("`@("`@("!I9B`H
M)'1H:7,M/E]C86-H945N86)L960@)B8@*"1F;W)E8V%S="`]("1T:&ES+3Y?
M8V%C:&4M/F=E="@D:60L(")F;W)E8V%S="(I*2D@>PH@("`@("`@("`@("`O
M+R!%;F-O<F4N+BX*("`@("`@("`@("`@)'1H:7,M/E]F;W)E8V%S="`]("1F
M;W)E8V%S=#L*("`@("`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)C86-H92)=
M(#T@(DA)5"(["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@+BXN
M"B`@("`@("`@("`@("1S=&%T=7,@/2`D=&AI<RT^7W!A<G-E5V5A=&AE<D1A
M=&$H)&ED+"`B9F]R96-A<W0B*3L*"B`@("`@("`@("`@(&EF("A397)V:6-E
M<U]796%T:&5R.CII<T5R<F]R*"1S=&%T=7,I*2!["B`@("`@("`@("`@("`@
M("!R971U<FX@)'-T871U<SL*("`@("`@("`@("`@?0H@("`@("`@("`@("`D
M9F]R96-A<W12971U<FY;(F-A8VAE(ET@/2`B34E34R(["B`@("`@("`@?0H*
M("`@("`@("`O+R!3;VUE(&5X<&QA;F%T:6]N(&9O<B!T:&4@;F5X="!T=V\@
M;&EN97,Z("AS86UE(&%S(&%B;W9E*0H@("`@("`@("\O('=E871H97(N8V]M
M(&ES;B=T(&%L=V%Y<R!S=7!P;'EI;F<@=&AE('1I;65Z;VYE(&EN('1H92!U
M<&1A=&4@<W1R:6YG+"!B=70*("`@("`@("`O+R!U<V5S("),;V-A;"!4:6UE
M(B!A<R!R969E<F5N8V4L('=H:6-H(&ES(&EM:&\@=71T97)L>2!S='5P:60L
M(&)E8V%U<V4@:70G<PH@("`@("`@("\O(&EN8V]N<VES=&5N="X@5V5L;"P@
M=VAA="!)(&1O(&AE<F4@:7,@8VAE8VL@9F]R('1H:7,@<W1R:6YG(&%N9"!I
M9B!)(&-A;@H@("`@("`@("\O(&9I;F0@:70L($D@8V%L8W5L871E('1H92!D
M:69F97)E;F-E(&)E='=E96X@=&AE('1I;65Z;VYE(&%T('1H92!L;V-A=&EO
M;@H@("`@("`@("\O(&%N9"!T:&ES(&-O;7!U=&5R<R!T:6UE>F]N92X@5&AI
M<R!A;6]U;G0@;V8@<V5C;VYD<R!I<R!T:&5N('-U8G1R86-T960@9G)O;0H@
M("`@("`@("\O('1H92!T:6UE('1H92!U<&1A=&4M<W1R:6YG(&AA<R!D96QI
M=F5R960N"B`@("`@("`@)'5P9&%T92`@(#T@<W1R7W)E<&QA8V4H(DQO8V%L
M(%1I;64B+"`B(BP@)'1H:7,M/E]F;W)E8V%S="T^;'-U<"D["B`@("`@("`@
M)&%D:G5S=%1:(#T@*"1U<&1A=&4@/3T@)'1H:7,M/E]F;W)E8V%S="T^;'-U
M<"D@/R`P(#H@)'1H:7,M/E]L;V-A=&EO;BT^>F]N92`J(#,V,#`@+2!D871E
M*"):(BD["B`@("`@("`@)&9O<F5C87-T4F5T=7)N6R)U<&1A=&4B72`@("`]
M(&=M9&%T92@D=&AI<RT^7V1A=&5&;W)M870N(B`B+B1T:&ES+3Y?=&EM949O
M<FUA="P@<W1R=&]T:6UE*"1U<&1A=&4I("T@)&%D:G5S=%1:*3L*("`@("`@
M("`D9F]R96-A<W12971U<FY;(G5P9&%T95)A=R)=(#T@)'1H:7,M/E]F;W)E
M8V%S="T^;'-U<#L*("`@("`@("`D9F]R96-A<W12971U<FY;(F1A>7,B72`@
M("`@(#T@87)R87DH*3L*"B`@("`@("`@9F]R("@D:2`](#`[("1I(#P@)&1A
M>7,[("1I*RLI('L*("`@("`@("`@("`@)&1A>2`](&%R<F%Y*`H@("`@("`@
M("`@("`@("`@(G1E;7!E<F%T=7)E2&EG:"(@/3X@)'1H:7,M/F-O;G9E<G14
M96UP97)A='5R92@D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YH:2P@(F8B
M+"`D=6YI='-;(G1E;7`B72DL"B`@("`@("`@("`@("`@("`B=&5M<&5R871U
M<F5,;W<B("`]/B`D=&AI<RT^8V]N=F5R=%1E;7!E<F%T=7)E*"1T:&ES+3Y?
M9F]R96-A<W0M/F1A>5LD:5TM/FQO=RP@(F8B+"`D=6YI='-;(G1E;7`B72DL
M"B`@("`@("`@("`@("`@("`B<W5N<FES92(@("`@("`@("`]/B!D871E*"1T
M:&ES+3Y?=&EM949O<FUA="P@<W1R=&]T:6UE*"1T:&ES+3Y?9F]R96-A<W0M
M/F1A>5LD:5TM/G-U;G(I*2P*("`@("`@("`@("`@("`@(")S=6YS970B("`@
M("`@("`@(#T^(&1A=&4H)'1H:7,M/E]T:6UE1F]R;6%T+"!S=')T;W1I;64H
M)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<W5N<RDI+`H@("`@("`@("`@
M("`@("`@(F1A>2(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(F-O
M;F1I=&EO;B(@("`@(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A
M<G1;,%TM/G0L"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;DEC;VXB
M(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,%TM/FEC;VXL
M"B`@("`@("`@("`@("`@("`@("`@(G=I;F0B("`@("`@("`@(#T^("1T:&ES
M+3YC;VYV97)T4W!E960H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R
M=%LP72T^=VEN9"T^<RP@(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@
M("`@("`@("`@("`@("`B=VEN9$=U<W0B("`@("`@/3X@)'1H:7,M/F-O;G9E
M<G13<&5E9"@D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=+3YW
M:6YD+3YG=7-T+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI+`H@("`@("`@("`@
M("`@("`@("`@(")W:6YD1&5G<F5E<R(@("`]/B`D=&AI<RT^7V9O<F5C87-T
M+3YD87E;)&E=+3YP87)T6S!=+3YW:6YD+3YD+`H@("`@("`@("`@("`@("`@
M("`@(")W:6YD1&ER96-T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;
M)&E=+3YP87)T6S!=+3YW:6YD+3YT+`H@("`@("`@("`@("`@("`@("`@(")P
M<F5C:7!I=&%T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP
M87)T6S!=+3YP<&-P+`H@("`@("`@("`@("`@("`@("`@(")H=6UI9&ET>2(@
M("`@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S!=+3YH
M;6ED"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@(FYI9VAT
M(B`]/B!A<G)A>2`H"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;B(@
M("`@(#T^("1T:&ES+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/G0L
M"B`@("`@("`@("`@("`@("`@("`@(F-O;F1I=&EO;DEC;VXB(#T^("1T:&ES
M+3Y?9F]R96-A<W0M/F1A>5LD:5TM/G!A<G1;,5TM/FEC;VXL"B`@("`@("`@
M("`@("`@("`@("`@(G=I;F0B("`@("`@("`@(#T^("1T:&ES+3YC;VYV97)T
M4W!E960H)'1H:7,M/E]F;W)E8V%S="T^9&%Y6R1I72T^<&%R=%LQ72T^=VEN
M9"T^<RP@(FUP:"(L("1U;FET<ULB=VEN9")=*2P*("`@("`@("`@("`@("`@
M("`@("`B=VEN9$=U<W0B("`@("`@/3X@)'1H:7,M/F-O;G9E<G13<&5E9"@D
M=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YW:6YD+3YG=7-T
M+"`B;7!H(BP@)'5N:71S6R)W:6YD(ETI+`H@("`@("`@("`@("`@("`@("`@
M(")W:6YD1&5G<F5E<R(@("`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=
M+3YP87)T6S%=+3YW:6YD+3YD+`H@("`@("`@("`@("`@("`@("`@(")W:6YD
M1&ER96-T:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T
M6S%=+3YW:6YD+3YT+`H@("`@("`@("`@("`@("`@("`@(")P<F5C:7!I=&%T
M:6]N(B`]/B`D=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YP
M<&-P+`H@("`@("`@("`@("`@("`@("`@(")H=6UI9&ET>2(@("`@("`]/B`D
M=&AI<RT^7V9O<F5C87-T+3YD87E;)&E=+3YP87)T6S%=+3YH;6ED"B`@("`@
M("`@("`@("`@("`I"B`@("`@("`@("`@("D["@H@("`@("`@("`@("`D9F]R
M96-A<W12971U<FY;(F1A>7,B75M=(#T@)&1A>3L*("`@("`@("!]"@H@("`@
M("`@(')E='5R;B`D9F]R96-A<W12971U<FX["B`@("!]"B`@("`O+R!]?7T*
M?0HO+R!]?7T*/SX*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]P<V$M:&]R9&4O
M<&5A<B]397)V:6-E<R]796%T:&5R+T-O;6UO;BYP:'``````````````````
M`````````````````````````````````````````#`P,#8T-"``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,3$S,#`P(#$P-3$U-#,T,3,R(#`R,S4W-@`@,```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````\/W!H<`HO
M*B!V:6TZ('-E="!E>'!A;F1T86(@=&%B<W1O<#TT('-H:69T=VED=&@]-"!S
M;V9T=&%B<W1O<#TT(&9O;&1M971H;V0];6%R:V5R.B`J+PH*+RHJ"B`J(%!%
M05(Z.E-E<G9I8V5S7U=E871H97)?0V]M;6]N"B`J"B`J(%!(4"!V97)S:6]N
M<R`T(&%N9"`U"B`J"B`J(#Q,24-%3E-%/@H@*B!#;W!Y<FEG:'0@*&,I(#(P
M,#4L($%L97AA;F1E<B!7:7)T>@H@*B!!;&P@<FEG:'1S(')E<V5R=F5D+@H@
M*@H@*B!2961I<W1R:6)U=&EO;B!A;F0@=7-E(&EN('-O=7)C92!A;F0@8FEN
M87)Y(&9O<FUS+"!W:71H(&]R('=I=&AO=70*("H@;6]D:69I8V%T:6]N+"!A
M<F4@<&5R;6ET=&5D('!R;W9I9&5D('1H870@=&AE(&9O;&QO=VEN9R!C;VYD
M:71I;VYS"B`J(&%R92!M970Z"B`J(&\@4F5D:7-T<FEB=71I;VYS(&]F('-O
M=7)C92!C;V1E(&UU<W0@<F5T86EN('1H92!A8F]V92!C;W!Y<FEG:'0@;F]T
M:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@9F]L
M;&]W:6YG(&1I<V-L86EM97(N"B`J(&\@4F5D:7-T<FEB=71I;VYS(&EN(&)I
M;F%R>2!F;W)M(&UU<W0@<F5P<F]D=6-E('1H92!A8F]V92!C;W!Y<FEG:'0@
M;F]T:6-E+`H@*B`@('1H:7,@;&ES="!O9B!C;VYD:71I;VYS(&%N9"!T:&4@
M9F]L;&]W:6YG(&1I<V-L86EM97(@:6X@=&AE(&1O8W5M96YT871I;VX*("H@
M("!A;F0O;W(@;W1H97(@;6%T97)I86QS('!R;W9I9&5D('=I=&@@=&AE(&1I
M<W1R:6)U=&EO;BX*("H@;R!.96ET:&5R('1H92!N86UE(&]F('1H92!S;V9T
M=V%R92!N;W(@=&AE(&YA;65S(&]F(&ET<R!C;VYT<FEB=71O<G,*("H@("!M
M87D@8F4@=7-E9"!T;R!E;F1O<G-E(&]R('!R;VUO=&4@<')O9'5C=',@9&5R
M:79E9"!F<F]M('1H:7,@<V]F='=A<F4*("H@("!W:71H;W5T('-P96-I9FEC
M('!R:6]R('=R:71T96X@<&5R;6ES<VEO;BX*("H*("H@5$A)4R!33T945T%2
M12!)4R!04D]6241%1"!"62!42$4@0T]065))1TA4($A/3$1%4E,@04Y$($-/
M3E1224)55$]24R`B05,@25,B"B`J($%.1"!!3ED@15A04D534R!/4B!)35!,
M245$(%=!4E)!3E1)15,L($E.0TQ51$E.1RP@0E54($Y/5"!,24U)5$5$(%1/
M+"!42$4*("H@24U03$E%1"!705)204Y42453($]&($U%4D-(04Y404))3$E4
M62!!3D0@1DE43D534R!&3U(@02!005)424-53$%2(%!54E!/4T4*("H@05)%
M($1)4T-,04E-140N($E.($Y/($5614Y4(%-(04Q,(%1(12!#3U!94DE'2%0@
M3U=.15(@3U(@0T].5%))0E543U)3($)%"B`J($Q)04),12!&3U(@04Y9($1)
M4D5#5"P@24Y$25)%0U0L($E.0TE$14Y404PL(%-014-)04PL($5814U03$%2
M62P@3U(*("H@0T].4T51545.5$E!3"!$04U!1T53("A)3D-,541)3D<L($)5
M5"!.3U0@3$E-251%1"!43RP@4%)/0U5214U%3E0@3T8*("H@4U5"4U1)5%54
M12!'3T]$4R!/4B!315)624-%4SL@3$]34R!/1B!54T4L($1!5$$L($]2(%!2
M3T9)5%,[($]2($)54TE.15-3"B`J($E.5$524E505$E/3BD@2$]7159%4B!#
M0553140@04Y$($].($%.62!42$5/4ED@3T8@3$E!0DE,2519+"!72$542$52
M($E."B`J($-/3E1204-4+"!35%))0U0@3$E!0DE,2519+"!/4B!43U)4("A)
M3D-,541)3D<@3D5'3$E'14Y#12!/4B!/5$A%4E=)4T4I"B`J($%225-)3D<@
M24X@04Y9(%=!62!/550@3T8@5$A%(%5312!/1B!42$E3(%-/1E1705)%+"!%
M5D5.($E&($%$5DE3140@3T8@5$A%"B`J(%!/4U-)0DE,2519($]&(%-50T@@
M1$%-04=%+@H@*B`\+TQ)0T5.4T4^"B`J"B`J($!C871E9V]R>2`@("!796(@
M4V5R=FEC97,*("H@0'!A8VMA9V4@("`@(%-E<G9I8V5S7U=E871H97(*("H@
M0&%U=&AO<B`@("`@($%L97AA;F1E<B!7:7)T>B`\86QE>$!P8S1P+FYE=#X*
M("H@0&-O<'ER:6=H="`@(#(P,#4@06QE>&%N9&5R(%=I<G1Z"B`J($!L:6-E
M;G-E("`@("!H='1P.B\O=W=W+F]P96YS;W5R8V4N;W)G+VQI8V5N<V5S+V)S
M9"UL:6-E;G-E+G!H<"`@0E-$($QI8V5N<V4*("H@0'9E<G-I;VX@("`@($-6
M4SH@)$ED.B!#;VUM;VXN<&AP+'8@,2XU,2`R,#`U+S$Q+S$S(#(R.C(W.C,R
M(&5R=2!%>'`@)`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E87(N<&AP+FYE
M="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("H@0&9I;&5S;W5R8V4*("HO
M"@IR97%U:7)E7V]N8V4@(E-E<G9I8V5S+U=E871H97(N<&AP(CL*"B\O('M[
M>R!C;VYS=&%N=',*+R\@>WM[(&YA='5R86P@8V]N<W1A;G1S(&%N9"!M96%S
M=7)E<PID969I;F4H(E-%4E9)0T537U=%051(15)?4D%$25537T5!4E1((BP@
M-C,W."XQ-2D["B\O('U]?0H*+R\@>WM[(&1E9F%U;'0@=F%L=65S(&9O<B!T
M:&4@<W5N+69U;F-T:6]N<PID969I;F4H(E-%4E9)0T537U=%051(15)?4U5.
M1E5.0U-?1$5&055,5%],051)5%5$12(L("`S,2XW-C8W*3L*9&5F:6YE*")3
M15)624-%4U]714%42$527U-53D953D-37T1%1D%53%1?3$].1TE4541%(BP@
M,S4N,C,S,RD["F1E9FEN92@B4T525DE#15-?5T5!5$A%4E]354Y&54Y#4U]3
M54Y225-%7UI%3DE42"(L("`@(#DP+C@S*3L*9&5F:6YE*")315)624-%4U]7
M14%42$527U-53D953D-37U-53E-%5%]:14Y)5$@B+"`@("`@.3`N.#,I.PHO
M+R!]?7T*+R\@?7U]"@HO+R![>WL@8VQA<W,@4V5R=FEC97-?5V5A=&AE<E]#
M;VUM;VX*+RHJ"B`J(%!A<F5N="!C;&%S<R!F;W(@=V5A=&AE<BUS97)V:6-E
M<RX@1&5F:6YE<R!C;VUM;VX@9G5N8W1I;VYS(&9O<B!U;FET"B`J(&-O;G9E
M<G-I;VYS+"!C:&5C:W,@9F]R(&-A8VAE(&5N86)L:6YG(&%N9"!D;V5S(&]T
M:&5R(&UI<V-E;&QA;F5O=7,*("H@=&AI;F=S+@H@*@H@*B!`8V%T96=O<GD@
M("`@5V5B(%-E<G9I8V5S"B`J($!P86-K86=E("`@("!397)V:6-E<U]796%T
M:&5R"B`J($!A=71H;W(@("`@("!!;&5X86YD97(@5VER='H@/&%L97A`<&,T
M<"YN970^"B`J($!C;W!Y<FEG:'0@("`R,#`U($%L97AA;F1E<B!7:7)T>@H@
M*B!`;&EC96YS92`@("`@:'1T<#HO+W=W=RYO<&5N<V]U<F-E+F]R9R]L:6-E
M;G-E<R]B<V0M;&EC96YS92YP:'`@($)31"!,:6-E;G-E"B`J($!V97)S:6]N
M("`@("!296QE87-E.B`Q+C0N,`H@*B!`;&EN:R`@("`@("`@:'1T<#HO+W!E
M87(N<&AP+FYE="]P86-K86=E+U-E<G9I8V5S7U=E871H97(*("HO"F-L87-S
M(%-E<G9I8V5S7U=E871H97)?0V]M;6]N('L*"B`@("`O+R![>WL@<')O<&5R
M=&EE<PH@("`@+RHJ"B`@("`@*B!&;W)M870@;V8@=&AE('5N:71S('!R;W9I
M9&5D("AS=&%N9&%R9"]M971R:6,O8W5S=&]M*0H@("`@("H*("`@("`J($!V
M87(@("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D7W5N:71S1F]R
M;6%T"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D
M7W5N:71S1F]R;6%T(#T@(G,B.PH*("`@("\J*@H@("`@("H@0W5S=&]M(&9O
M<FUA="!O9B!T:&4@=6YI=',*("`@("`J"B`@("`@*B!`=F%R("`@("!A<G)A
M>2`@("`@("`@("`@("`@("`@("`@("`@)%]C=7-T;VU5;FET<T9O<FUA=`H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]C=7-T
M;VU5;FET<T9O<FUA="`](&%R<F%Y*`H@("`@("`@(")T96UP(B`@(#T^(")F
M(BP*("`@("`@("`B=FES(B`@("`]/B`B<VTB+`H@("`@("`@(")H96EG:'0B
M(#T^(")F="(L"B`@("`@("`@(G=I;F0B("`@/3X@(FUP:"(L"B`@("`@("`@
M(G!R97,B("`@/3X@(FEN(BP*("`@("`@("`B<F%I;B(@("`]/B`B:6XB"B`@
M("`I.PH*("`@("\J*@H@("`@("H@3W!T:6]N<R!F;W(@2%144"!R97%U97-T
M<PH@("`@("H*("`@("`J($!V87(@("`@(&%R<F%Y("`@("`@("`@("`@("`@
M("`@("`@("`D7VAT='!/<'1I;VYS"B`@("`@*B!`86-C97-S("!P<FEV871E
M"B`@("`@*B\*("`@('9A<B`D7VAT='!/<'1I;VYS(#T@87)R87DH*3L*"B`@
M("`O*BH*("`@("`J($9O<FUA="!O9B!T:&4@=7-E9"!D871E<PH@("`@("H*
M("`@("`J($!V87(@("`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D
M7V1A=&5&;W)M870*("`@("`J($!A8V-E<W,@('!R:79A=&4*("`@("`J+PH@
M("`@=F%R("1?9&%T949O<FUA="`](")M+V0O>2(["@H@("`@+RHJ"B`@("`@
M*B!&;W)M870@;V8@=&AE('5S960@=&EM97,*("`@("`J"B`@("`@*B!`=F%R
M("`@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)%]T:6UE1F]R;6%T
M"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7W1I
M;65&;W)M870@/2`B1SII($$B.PH*("`@("\J*@H@("`@("H@3V)J96-T(&-O
M;G1A:6YI;F<@=&AE(&QO8V%T:6]N+61A=&$*("`@("`J"B`@("`@*B!`=F%R
M("`@("!O8FIE8W0@<W1D0VQA<W,@("`@("`@("`@("`@)%]L;V-A=&EO;@H@
M("`@("H@0&%C8V5S<R`@<')I=F%T90H@("`@("HO"B`@("!V87(@)%]L;V-A
M=&EO;CL*"B`@("`O*BH*("`@("`J($]B:F5C="!C;VYT86EN:6YG('1H92!W
M96%T:&5R+61A=&$*("`@("`J"B`@("`@*B!`=F%R("`@("!O8FIE8W0@<W1D
M0VQA<W,@("`@("`@("`@("`@)%]W96%T:&5R"B`@("`@*B!`86-C97-S("!P
M<FEV871E"B`@("`@*B\*("`@('9A<B`D7W=E871H97(["@H@("`@+RHJ"B`@
M("`@*B!/8FIE8W0@8V]N=&%I;FEN9R!T:&4@9F]R96-A<W0M9&%T80H@("`@
M("H*("`@("`J($!V87(@("`@(&]B:F5C="!S=&1#;&%S<R`@("`@("`@("`@
M("`D7V9O<F5C87-T"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*
M("`@('9A<B`D7V9O<F5C87-T.PH*("`@("\J*@H@("`@("H@0V%C:&4L(&-O
M;G1A:6YI;F<@=&AE(&1A=&$M;V)J96-T<PH@("`@("H*("`@("`J($!V87(@
M("`@(&]B:F5C="!#86-H92`@("`@("`@("`@("`@("`D7V-A8VAE"B`@("`@
M*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@('9A<B`D7V-A8VAE.PH*
M("`@("\J*@H@("`@("H@4')O=FED97,@8VAE8VL@9F]R($-A8VAE"B`@("`@
M*@H@("`@("H@0'9A<B`@("`@8F]O;"`@("`@("`@("`@("`@("`@("`@("`@
M("1?8V%C:&5%;F%B;&5D"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@
M*B\*("`@('9A<B`D7V-A8VAE16YA8FQE9"`](&9A;'-E.PH@("`@+R\@?7U]
M"@H@("`@+R\@>WM[(&-O;G-T<G5C=&]R"B`@("`O*BH*("`@("`J($-O;G-T
M<G5C=&]R"B`@("`@*@H@("`@("H@0'!A<F%M("`@87)R87D@("`@("`@("`@
M("`@("`@("`@("`@("1O<'1I;VYS"B`@("`@*B!`<&%R86T@("!M:7AE9"`@
M("`@("`@("`@("`@("`@("`@("`@)&5R<F]R"B`@("`@*B!`=&AR;W=S("!0
M14%27T5R<F]R"B`@("`@*B!`86-C97-S("!P<FEV871E"B`@("`@*B\*("`@
M(&9U;F-T:6]N(%-E<G9I8V5S7U=E871H97)?0V]M;6]N*"1O<'1I;VYS+"`F
M)&5R<F]R*0H@("`@>PH@("`@("`@("\O(%-E="!S;VUE(&-O;G-T86YT<R!F
M;W(@=&AE(&-A<V4@=VAE;B!02%`T(&ES('5S960L(&%S('1H90H@("`@("`@
M("\O(&1A=&5?<W5N<V5T+W-U;G)I<V4@9G5N8W1I;VYS(&%R92!N;W0@:6UP
M;&5M96YT960@=&AE<F4*("`@("`@("!I9B`H(61E9FEN960H(E-53D953D-3
M7U)%5%]424U%4U1!35`B*2D@>PH@("`@("`@("`@("!D969I;F4H(E-53D95
M3D-37U)%5%]424U%4U1!35`B+"`P*3L*("`@("`@("`@("`@9&5F:6YE*")3
M54Y&54Y#4U]2151?4U1224Y'(BP@("`@,2D["B`@("`@("`@("`@(&1E9FEN
M92@B4U5.1E5.0U-?4D547T1/54),12(L("`@(#(I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4V5T(&]P=&EO;G,@86-C;W)D:6YG;'D*("`@("`@("!I9B`H
M:7-S970H)&]P=&EO;G-;(F-A8VAE5'EP92)=*2D@>PH@("`@("`@("`@("!I
M9B`H:7-S970H)&]P=&EO;G-;(F-A8VAE3W!T:6]N<R)=*2D@>PH@("`@("`@
M("`@("`@("`@)'-T871U<R`]("1T:&ES+3YS971#86-H92@D;W!T:6]N<ULB
M8V%C:&54>7!E(ETL("1O<'1I;VYS6R)C86-H94]P=&EO;G,B72D["B`@("`@
M("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("`D<W1A='5S(#T@)'1H
M:7,M/G-E=$-A8VAE*"1O<'1I;VYS6R)C86-H951Y<&4B72D["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z.FES17)R
M;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]("1S=&%T
M=7,["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB=6YI='-&;W)M
M870B72DI('L*("`@("`@("`@("`@:68@*&ES<V5T*"1O<'1I;VYS6R)C=7-T
M;VU5;FET<T9O<FUA=")=*2D@>PH@("`@("`@("`@("`@("`@)'1H:7,M/G-E
M=%5N:71S1F]R;6%T*"1O<'1I;VYS6R)U;FET<T9O<FUA=")=+"`D;W!T:6]N
M<ULB8W5S=&]M56YI='-&;W)M870B72D["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D=&AI<RT^<V5T56YI='-&;W)M870H)&]P=&EO
M;G-;(G5N:71S1F]R;6%T(ETI.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(FAT='!4:6UE;W5T(ETI*2![
M"B`@("`@("`@("`@("1T:&ES+3YS971(='1P5&EM96]U="@D;W!T:6]N<ULB
M:'1T<%1I;65O=70B72D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@
M)'1H:7,M/G-E=$AT='!4:6UE;W5T*#8P*3L*("`@("`@("!]"B`@("`@("`@
M:68@*&ES<V5T*"1O<'1I;VYS6R)H='1P4')O>'DB72DI('L*("`@("`@("`@
M("`@)'-T871U<R`]("1T:&ES+3YS971(='1P4')O>'DH)&]P=&EO;G-;(FAT
M='!0<F]X>2)=*3L*("`@("`@("`@("`@:68@*%-E<G9I8V5S7U=E871H97(Z
M.FES17)R;W(H)'-T871U<RDI('L*("`@("`@("`@("`@("`@("1E<G)O<B`]
M("1S=&%T=7,["B`@("`@("`@("`@("`@("!R971U<FX["B`@("`@("`@("`@
M('T*("`@("`@("!]"@H@("`@("`@(&EF("AI<W-E="@D;W!T:6]N<ULB9&%T
M949O<FUA=")=*2D@>PH@("`@("`@("`@("`D=&AI<RT^<V5T1&%T951I;65&
M;W)M870H)&]P=&EO;G-;(F1A=&5&;W)M870B72P@(B(I.PH@("`@("`@('T*
M("`@("`@("!I9B`H:7-S970H)&]P=&EO;G-;(G1I;65&;W)M870B72DI('L*
M("`@("`@("`@("`@)'1H:7,M/G-E=$1A=&54:6UE1F]R;6%T*"(B+"`D;W!T
M:6]N<ULB=&EM949O<FUA=")=*3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]
M?7T*"B`@("`O+R![>WL@<V5T0V%C:&4H*0H@("`@+RHJ"B`@("`@*B!%;F%B
M;&5S(&-A8VAI;F<@=&AE(&1A=&$L('5S86=E('-T<F]N9VQY(')E8V]M;65N
M9&5D"B`@("`@*@H@("`@("H@4F5Q=6ER97,@0V%C:&4@=&\@8F4@:6YS=&%L
M;&5D"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@
M("`@("`@("`@("1C86-H951Y<&4*("`@("`J($!P87)A;2`@(&%R<F%Y("`@
M("`@("`@("`@("`@("`@("`@("`D8V%C:&5/<'1I;VYS"B`@("`@*B!`<F5T
M=7)N("!014%27T5R<F]R?&)O;VP*("`@("`J($!T:')O=W,@(%!%05)?17)R
M;W(Z.E-%4E9)0T537U=%051(15)?15)23U)?0T%#2$5?24Y)5%]&04E,140*
M("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!S
M971#86-H92@D8V%C:&54>7!E(#T@(F9I;&4B+"`D8V%C:&5/<'1I;VYS(#T@
M87)R87DH*2D*("`@('L*("`@("`@("`O+R!4:&4@97)R;W(@:&%N9&QI;F<@
M:6X@0V%C:&4@:7,@82!B:70@8W)U;6UY("AR96%D.B!N;W0@97AI<W1E;G0I
M"B`@("`@("`@+R\@<V\@=V4@:&%V92!T;R!D;R!T:&%T(&]N(&]U<B!O=VXN
M+BX*("`@("`@("!`:6YC;'5D95]O;F-E(")#86-H92YP:'`B.PH@("`@("`@
M($`D8V%C:&4@/2!N97<@0V%C:&4H)&-A8VAE5'EP92P@)&-A8VAE3W!T:6]N
M<RD["B`@("`@("`@:68@*&ES7V]B:F5C="@D8V%C:&4I("8F("AS=')T;VQO
M=V5R*&=E=%]C;&%S<R@D8V%C:&4I*2`]/2`B8V%C:&4B('Q\(&ES7W-U8F-L
M87-S7V]F*"1C86-H92P@(F-A8VAE(BDI*2!["B`@("`@("`@("`@("1T:&ES
M+3Y?8V%C:&4@("`@("`@(#T@)&-A8VAE.PH@("`@("`@("`@("`D=&AI<RT^
M7V-A8VAE16YA8FQE9"`]('1R=64["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)'1H:7,M/E]C86-H92`@("`@("`@/2!N=6QL.PH@("`@("`@("`@
M("`D=&AI<RT^7V-A8VAE16YA8FQE9"`](&9A;'-E.PH@("`@("`@("`@("!R
M971U<FX@4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]7
M14%42$527T524D]27T-!0TA%7TE.251?1D%)3$5$+"!?7T9)3$5?7RP@7U],
M24Y%7U\I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N('1R=64["B`@("!]
M"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T56YI='-&;W)M870H*0H@("`@
M+RHJ"B`@("`@*B!#:&%N9V5S('1H92!R97!R97-E;G1A=&EO;B!O9B!T:&4@
M=6YI=',@*'-T86YD87)D+VUE=')I8RD*("`@("`J"B`@("`@*B!`<&%R86T@
M("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'5N:71S1F]R;6%T"B`@
M("`@*B!`<&%R86T@("!A<G)A>2`@("`@("`@("`@("`@("`@("`@("`@)&-U
M<W1O;55N:71S1F]R;6%T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J
M+PH@("`@9G5N8W1I;VX@<V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T+"`D
M8W5S=&]M56YI='-&;W)M870@/2!A<G)A>2@I*0H@("`@>PH@("`@("`@('-T
M871I8R`D86-C97!T961&;W)M871S.PH@("`@("`@(&EF("@A:7-S970H)&%C
M8V5P=&5D1F]R;6%T<RDI('L*("`@("`@("`@("`@)&%C8V5P=&5D1F]R;6%T
M<R`](&%R<F%Y*`H@("`@("`@("`@("`@("`@(G1E;7`B("`@/3X@87)R87DH
M(F,B+"`B9B(I+`H@("`@("`@("`@("`@("`@(G9I<R(@("`@/3X@87)R87DH
M(FTB+"`B:VTB+"`B9G0B+"`B<VTB*2P*("`@("`@("`@("`@("`@(")H96EG
M:'0B(#T^(&%R<F%Y*")M(BP@(F9T(BDL"B`@("`@("`@("`@("`@("`B=VEN
M9"(@("`]/B!A<G)A>2@B;7!H(BP@(FMM:"(L(")K="(L(")M<',B+"`B9G!S
M(BP@(F)F="(I+`H@("`@("`@("`@("`@("`@(G!R97,B("`@/3X@87)R87DH
M(FEN(BP@(FAP82(L(")M8B(L(")M;2(L(")A=&TB*2P*("`@("`@("`@("`@
M("`@(")R86EN(B`@(#T^(&%R<F%Y*")I;B(L(")M;2(I"B`@("`@("`@("`@
M("D["B`@("`@("`@?0H*("`@("`@("!I9B`H<W1R;&5N*"1U;FET<T9O<FUA
M="D@)B8@:6Y?87)R87DH<W1R=&]L;W=E<B@D=6YI='-&;W)M871[,'TI+"!A
M<G)A>2@B8R(L(")M(BP@(G,B*2DI('L*("`@("`@("`@("`@)'1H:7,M/E]U
M;FET<T9O<FUA="`]('-T<G1O;&]W97(H)'5N:71S1F]R;6%T>S!]*3L*("`@
M("`@("`@("`@:68@*"1T:&ES+3Y?=6YI='-&;W)M870@/3T@(F,B("8F(&ES
M7V%R<F%Y*"1C=7-T;VU5;FET<T9O<FUA="DI('L*("`@("`@("`@("`@("`@
M(&9O<F5A8V@@*"1C=7-T;VU5;FET<T9O<FUA="!A<R`D:V5Y(#T^("1V86QU
M92D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AA<G)A>5]K97E?97AI<W1S
M*"1K97DL("1A8V-E<'1E9$9O<FUA=',I("8F(&EN7V%R<F%Y*"1V86QU92P@
M)&%C8V5P=&5D1F]R;6%T<ULD:V5Y72DI('L*("`@("`@("`@("`@("`@("`@
M("`@("`@)'1H:7,M/E]C=7-T;VU5;FET<T9O<FUA=%LD:V5Y72`]("1V86QU
M93L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T@96QS96EF("@D=&AI<RT^7W5N:71S1F]R;6%T(#T](")C
M(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]U;FET<T9O<FUA="`](")S
M(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@("\O('U]?0H*
M("`@("\O('M[>R!S971(='1P3W!T:6]N*"D*("`@("\J*@H@("`@("H@4V5T
M<R!A;B!O<'1I;VX@9F]R('5S86=E(&EN($A45%!?4F5Q=65S="!O8FIE8W1S
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1V87).86UE"B`@("`@*B!`<&%R86T@("!M:7AE9"`@("`@("`@
M("`@("`@("`@("`@("`@)'9A<E9A;'5E"B`@("`@*B!`86-C97-S("!P=6)L
M:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T2'1T<$]P=&EO;B@D=F%R3F%M
M92P@)'9A<E9A;'5E*0H@("`@>PH@("`@("`@(&EF("AI<U]S=')I;F<H)'9A
M<DYA;64I("8F("1V87).86UE("$]("(B("8F("%E;7!T>2@D=F%R5F%L=64I
M*2!["B`@("`@("`@("`@("1T:&ES+3Y?:'1T<$]P=&EO;G-;)'9A<DYA;65=
M(#T@)'9A<E9A;'5E.PH@("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@
M("\O('M[>R!S971(='1P5&EM96]U="@I"B`@("`O*BH*("`@("`J(%-E=',@
M=&AE('1I;65O=70@:6X@<V5C;VYD<R!F;W(@2%144"!R97%U97-T<PH@("`@
M("H*("`@("`J($!P87)A;2`@(&EN="`@("`@("`@("`@("`@("`@("`@("`@
M("`D:'1T<%1I;65O=70*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO
M"B`@("!F=6YC=&EO;B!S971(='1P5&EM96]U="@D:'1T<%1I;65O=70I"B`@
M("!["B`@("`@("`@:68@*&ES7VEN="@D:'1T<%1I;65O=70I*2!["B`@("`@
M("`@("`@("1T:&ES+3Y?:'1T<$]P=&EO;G-;(G1I;65O=70B72`]("1H='1P
M5&EM96]U=#L*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O+R![
M>WL@<V5T2'1T<%!R;WAY*"D*("`@("\J*@H@("`@("H@4V5T<R!T:&4@<')O
M>'D@9F]R($A45%`@<F5Q=65S=',*("`@("`J"B`@("`@*B!`<&%R86T@("!S
M=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&AT='!0<F]X>0H@("`@("H@
M0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N('-E=$AT='!0
M<F]X>2@D:'1T<%!R;WAY*0H@("`@>PH@("`@("`@(&EF("@H)'!R;WAY(#T@
M<&%R<V5?=7)L*"1H='1P4')O>'DI*2`A/3T@9F%L<V4@)B8@)'!R;WAY6R)S
M8VAE;64B72`]/2`B:'1T<"(I('L*("`@("`@("`@("`@:68@*&ES<V5T*"1P
M<F]X>5LB=7-E<B)=*2`F)B`D<')O>'E;(G5S97(B72`A/2`B(BD@>PH@("`@
M("`@("`@("`@("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB<')O>'E?=7-E<B)=
M(#T@)'!R;WAY6R)U<V5R(ET["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M:68@*&ES<V5T*"1P<F]X>5LB<&%S<R)=*2`F)B`D<')O>'E;(G!A<W,B72`A
M/2`B(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB
M<')O>'E?<&%S<R)=(#T@)'!R;WAY6R)P87-S(ET["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LB:&]S=")=*2`F)B`D<')O
M>'E;(FAO<W0B72`A/2`B(BD@>PH@("`@("`@("`@("`@("`@)'1H:7,M/E]H
M='1P3W!T:6]N<ULB<')O>'E?:&]S=")=(#T@)'!R;WAY6R)H;W-T(ET["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@:68@*&ES<V5T*"1P<F]X>5LB<&]R
M=")=*2`F)B`D<')O>'E;(G!O<G0B72`A/2`B(BD@>PH@("`@("`@("`@("`@
M("`@)'1H:7,M/E]H='1P3W!T:6]N<ULB<')O>'E?<&]R=")=(#T@)'!R;WAY
M6R)P;W)T(ET["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(')E='5R;B!T
M<G5E.PH@("`@("`@('T@96QS92!["B`@("`@("`@("`@(')E='5R;B!397)V
M:6-E<U]796%T:&5R.CIR86ES945R<F]R*%-%4E9)0T537U=%051(15)?15)2
M3U)?2%144%]04D]865])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@
M("`@("`@('T*("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!G9715;FET
M<T9O<FUA="@I"B`@("`O*BH*("`@("`J(%)E='5R;G,@=&AE('-E;&5C=&5D
M('5N:71S(&9O<FUA=`H@("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@
M("`@("`@("`@("`@("`@("`@("`D=6YI='-&;W)M870*("`@("`J($!R971U
M<FX@(&%R<F%Y"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J+PH@("`@
M9G5N8W1I;VX@9V5T56YI='-&;W)M870H)'5N:71S1F]R;6%T(#T@(B(I"B`@
M("!["B`@("`@("`@+R\@5&AI<R!I<R!C:&5A<"=O('-T=69F"B`@("`@("`@
M:68@*'-T<FQE;B@D=6YI='-&;W)M870I("8F(&EN7V%R<F%Y*'-T<G1O;&]W
M97(H)'5N:71S1F]R;6%T>S!]*2P@87)R87DH(F,B+"`B;2(L(")S(BDI*2![
M"B`@("`@("`@("`@("1U;FET<T9O<FUA="`]('-T<G1O;&]W97(H)'5N:71S
M1F]R;6%T>S!]*3L*("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`D=6YI
M='-&;W)M870@/2`D=&AI<RT^7W5N:71S1F]R;6%T.PH@("`@("`@('T*"B`@
M("`@("`@)&,@/2`D=&AI<RT^7V-U<W1O;55N:71S1F]R;6%T.PH@("`@("`@
M("1M(#T@87)R87DH"B`@("`@("`@("`@(")T96UP(B`@(#T^(")C(BP*("`@
M("`@("`@("`@(G9I<R(@("`@/3X@(FMM(BP*("`@("`@("`@("`@(FAE:6=H
M="(@/3X@(FTB+`H@("`@("`@("`@("`B=VEN9"(@("`]/B`B:VUH(BP*("`@
M("`@("`@("`@(G!R97,B("`@/3X@(FUB(BP*("`@("`@("`@("`@(G)A:6XB
M("`@/3X@(FUM(@H@("`@("`@("D["B`@("`@("`@)',@/2!A<G)A>2@*("`@
M("`@("`@("`@(G1E;7`B("`@/3X@(F8B+`H@("`@("`@("`@("`B=FES(B`@
M("`]/B`B<VTB+`H@("`@("`@("`@("`B:&5I9VAT(B`]/B`B9G0B+`H@("`@
M("`@("`@("`B=VEN9"(@("`]/B`B;7!H(BP*("`@("`@("`@("`@(G!R97,B
M("`@/3X@(FEN(BP*("`@("`@("`@("`@(G)A:6XB("`@/3X@(FEN(@H@("`@
M("`@("D["@H@("`@("`@(')E='5R;B`D>R1U;FET<T9O<FUA='T["B`@("!]
M"B`@("`O+R!]?7T*"B`@("`O+R![>WL@<V5T1&%T951I;65&;W)M870H*0H@
M("`@+RHJ"B`@("`@*B!#:&%N9V5S('1H92!R97!R97-E;G1A=&EO;B!O9B!T
M:6UE(&%N9"!D871E<R`H<V5E(&AT='`Z+R]W=W<N<&AP+FYE="]D871E*0H@
M("`@("H*("`@("`J($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@
M("`@("`D9&%T949O<FUA=`H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@
M("`@("`@("`@("`@("`@("1T:6UE1F]R;6%T"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J+PH@("`@9G5N8W1I;VX@<V5T1&%T951I;65&;W)M870H
M)&1A=&5&;W)M870@/2`B(BP@)'1I;65&;W)M870@/2`B(BD*("`@('L*("`@
M("`@("!I9B`H<W1R;&5N*"1D871E1F]R;6%T*2D@>PH@("`@("`@("`@("`D
M=&AI<RT^7V1A=&5&;W)M870@/2`D9&%T949O<FUA=#L*("`@("`@("!]"B`@
M("`@("`@:68@*'-T<FQE;B@D=&EM949O<FUA="DI('L*("`@("`@("`@("`@
M)'1H:7,M/E]T:6UE1F]R;6%T(#T@)'1I;65&;W)M870["B`@("`@("`@?0H@
M("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G9E<G1496UP97)A='5R
M92@I"B`@("`O*BH*("`@("`J($-O;G9E<G0@=&5M<&5R871U<F4@8F5T=V5E
M;B!F(&%N9"!C"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@
M("`@("`@("`@("`@("`@("1T96UP97)A='5R90H@("`@("H@0'!A<F%M("`@
M<W1R:6YG("`@("`@("`@("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)'1O"B`@("`@*B!`
M<F5T=7)N("!F;&]A=`H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*
M("`@(&9U;F-T:6]N(&-O;G9E<G1496UP97)A='5R92@D=&5M<&5R871U<F4L
M("1F<F]M+"`D=&\I"B`@("!["B`@("`@("`@)&9R;VT@/2!S=')T;VQO=V5R
M*"1F<F]M>S!]*3L*("`@("`@("`D=&\@("`]('-T<G1O;&]W97(H)'1O>S!]
M*3L*"B`@("`@("`@)')E<W5L="`](&%R<F%Y*`H@("`@("`@("`@("`B9B(@
M/3X@87)R87DH"B`@("`@("`@("`@("`@("`B9B(@/3X@)'1E;7!E<F%T=7)E
M+"`@("`@("`@("`@(")C(B`]/B`H)'1E;7!E<F%T=7)E("T@,S(I("\@,2XX
M"B`@("`@("`@("`@("DL"B`@("`@("`@("`@(")C(B`]/B!A<G)A>2@*("`@
M("`@("`@("`@("`@(")F(B`]/B`Q+C@@*B`D=&5M<&5R871U<F4@*R`S,BP@
M(F,B(#T^("1T96UP97)A='5R90H@("`@("`@("`@("`I"B`@("`@("`@*3L*
M"B`@("`@("`@<F5T=7)N(')O=6YD*"1R97-U;'1;)&9R;VU=6R1T;UTL(#(I
M.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-O;G9E<G13<&5E9"@I
M"B`@("`O*BH*("`@("`J($-O;G9E<G0@<W!E960@8F5T=V5E;B!M<&@L(&MM
M:"P@:W0L(&UP<RP@9G!S(&%N9"!B9G0*("`@("`J"B`@("`@*B!&=6YC=&EO
M;B!W:6QL(')E='5R;B`B9F%L<V4B('=H96X@=')Y:6YG('1O(&-O;G9E<G0@
M9G)O;0H@("`@("H@0F5A=69O<G0L(&%S(&ET(&ES(&$@<V-A;&4@86YD(&YO
M="!A('1R=64@;65A<W5R96UE;G0*("`@("`J"B`@("`@*B!`<&%R86T@("!F
M;&]A="`@("`@("`@("`@("`@("`@("`@("`@)'-P965D"B`@("`@*B!`<&%R
M86T@("!S=')I;F<@("`@("`@("`@("`@("`@("`@("`@)&9R;VT*("`@("`J
M($!P87)A;2`@('-T<FEN9R`@("`@("`@("`@("`@("`@("`@("`D=&\*("`@
M("`J($!R971U<FX@(&9L;V%T?&EN='QB;V]L"B`@("`@*B!`86-C97-S("!P
M=6)L:6,*("`@("`J($!L:6YK("`@(&AT='`Z+R]W=W<N<W!C+FYO86$N9V]V
M+V9A<2]T;W)N861O+V)E875F;W)T+FAT;6P*("`@("`J+PH@("`@9G5N8W1I
M;VX@8V]N=F5R=%-P965D*"1S<&5E9"P@)&9R;VTL("1T;RD*("`@('L*("`@
M("`@("`D9G)O;2`]('-T<G1O;&]W97(H)&9R;VTI.PH@("`@("`@("1T;R`@
M(#T@<W1R=&]L;W=E<B@D=&\I.PH*("`@("`@("!S=&%T:6,@)&9A8W1O<CL*
M("`@("`@("!S=&%T:6,@)&)E875F;W)T.PH@("`@("`@(&EF("@A:7-S970H
M)&9A8W1O<BDI('L*("`@("`@("`@("`@)&9A8W1O<B`](&%R<F%Y*`H@("`@
M("`@("`@("`@("`@(FUP:"(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@
M("`@(FUP:"(@/3X@,2P@("`@("`@("`B:VUH(B`]/B`Q+C8P.3,T-"P@(FMT
M(B`]/B`P+C@V.#DW-C(L(")M<',B(#T^(#`N-#0W,#0L("`@(F9P<R(@/3X@
M,2XT-C8V-C8W"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@
M(FMM:"(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@/3X@
M,"XV,C$S-S$R+"`B:VUH(B`]/B`Q+"`@("`@("`@(FMT(B`]/B`P+C4S.3DU
M-C@L(")M<',B(#T^(#`N,C<W-S<W."P@(F9P<R(@/3X@,"XY,3$S-#0T"B`@
M("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@("`@(FMT(B`@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FUP:"(@/3X@,2XQ-3`W-SDT+"`B
M:VUH(B`]/B`Q+C@U,BP@("`@(FMT(B`]/B`Q+"`@("`@("`@(")M<',B(#T^
M(#`N-3$T-#0T-"P@(F9P<R(@/3X@,2XV.#<X,#DY"B`@("`@("`@("`@("`@
M("`I+`H@("`@("`@("`@("`@("`@(FUP<R(@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@(FUP:"(@/3X@,BXR,S8Y,S8S+"`B:VUH(B`]/B`S+C8L
M("`@("`@(FMT(B`]/B`Q+CDT,S@T-#4L(")M<',B(#T^(#$L("`@("`@("`@
M(F9P<R(@/3X@,RXR.#`X,SDY"B`@("`@("`@("`@("`@("`I+`H@("`@("`@
M("`@("`@("`@(F9P<R(@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(FUP:"(@/3X@,"XV.#$X,3@R+"`B:VUH(B`]/B`Q+C`Y-S(X+"`@(FMT(B`]
M/B`P+C4Y,C0X,S@L(")M<',B(#T^(#`N,S`T."P@("`@(F9P<R(@/3X@,0H@
M("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@
M+R\@0F5A=69O<G0@<V-A;&4L(&UE87-U<F5M96YT<R!A<F4@:6X@:VYO=',*
M("`@("`@("`@("`@)&)E875F;W)T(#T@87)R87DH"B`@("`@("`@("`@("`@
M("`@(#$L("`@,RP@("`V+"`@,3`L"B`@("`@("`@("`@("`@("`@,38L("`R
M,2P@(#(W+"`@,S,L"B`@("`@("`@("`@("`@("`@-#`L("`T-RP@(#4U+"`@
M-C,*("`@("`@("`@("`@*3L*("`@("`@("!]"@H@("`@("`@(&EF("@D9G)O
M;2`]/2`B8F9T(BD@>PH@("`@("`@("`@("!R971U<FX@9F%L<V4["B`@("`@
M("`@?2!E;'-E:68@*"1T;R`]/2`B8F9T(BD@>PH@("`@("`@("`@("`D<W!E
M960@/2!R;W5N9"@D<W!E960@*B`D9F%C=&]R6R1F<F]M75LB:W0B72P@,"D[
M"B`@("`@("`@("`@(&9O<B`H)&D@/2`P.R`D:2`\('-I>F5O9B@D8F5A=69O
M<G0I.R`D:2LK*2!["B`@("`@("`@("`@("`@("!I9B`H)'-P965D(#P]("1B
M96%U9F]R=%LD:5TI('L*("`@("`@("`@("`@("`@("`@("!R971U<FX@)&D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("`@("`@
M<F5T=7)N('-I>F5O9B@D8F5A=69O<G0I.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@(')E='5R;B!R;W5N9"@D<W!E960@*B`D9F%C=&]R6R1F<F]M
M75LD=&]=+"`R*3L*("`@("`@("!]"B`@("!]"B`@("`O+R!]?7T*"B`@("`O
M+R![>WL@8V]N=F5R=%!R97-S=7)E*"D*("`@("\J*@H@("`@("H@0V]N=F5R
M="!P<F5S<W5R92!B971W965N(&EN+"!H<&$L(&UB+"!M;2!A;F0@871M"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@
M("`@("1P<F5S<W5R90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@
M("`@("`@("`@("`@("`@("`@)'1O"B`@("`@*B!`<F5T=7)N("!F;&]A=`H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;G9E<G10<F5S<W5R92@D<')E<W-U<F4L("1F<F]M+"`D=&\I"B`@("!["B`@
M("`@("`@)&9R;VT@/2!S=')T;VQO=V5R*"1F<F]M*3L*("`@("`@("`D=&\@
M("`]('-T<G1O;&]W97(H)'1O*3L*"B`@("`@("`@<W1A=&EC("1F86-T;W([
M"B`@("`@("`@:68@*"%I<W-E="@D9F%C=&]R*2D@>PH@("`@("`@("`@("`D
M9F%C=&]R(#T@87)R87DH"B`@("`@("`@("`@("`@("`B:6XB("`@/3X@87)R
M87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`Q+"`@("`@("`@(")H
M<&$B(#T^(#,S+C@V,S@X-RP@(FUB(B`]/B`S,RXX-C,X.#<L(")M;2(@/3X@
M,C4N-"P@("`@("`B871M(B`]/B`P+C`S,S0R,3,*("`@("`@("`@("`@("`@
M("DL"B`@("`@("`@("`@("`@("`B:'!A(B`@/3X@87)R87DH"B`@("`@("`@
M("`@("`@("`@("`@(FEN(B`]/B`P+C`R.34S+"`@(")H<&$B(#T^(#$L("`@
M("`@("`@(FUB(B`]/B`Q+"`@("`@("`@(")M;2(@/3X@,"XW-3`P-C$V+"`B
M871M(B`]/B`P+C`P,#DX-CD*("`@("`@("`@("`@("`@("DL"B`@("`@("`@
M("`@("`@("`B;6(B("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@
M(FEN(B`]/B`P+C`R.34S+"`@(")H<&$B(#T^(#$L("`@("`@("`@(FUB(B`]
M/B`Q+"`@("`@("`@(")M;2(@/3X@,"XW-3`P-C$V+"`B871M(B`]/B`P+C`P
M,#DX-CD*("`@("`@("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B;6TB
M("`@/3X@87)R87DH"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`P+C`S
M.3,W,#$L(")H<&$B(#T^(#$N,S,S,C(S.2P@(FUB(B`]/B`Q+C,S,S(R,SDL
M(")M;2(@/3X@,2P@("`@("`@("`B871M(B`]/B`P+C`P,3,Q-3@*("`@("`@
M("`@("`@("`@("DL"B`@("`@("`@("`@("`@("`B871M(B`@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@(FEN(B`]/B`R.2PY,C$R-3@L(")H<&$B
M(#T^(#$P,3,N,C4P,2P@(FUB(B`]/B`Q,#$S+C(U,#$L(")M;2(@/3X@-S4Y
M+CDY.3DU,BP@(F%T;2(@/3X@,0H@("`@("`@("`@("`@("`@*0H@("`@("`@
M("`@("`I.PH@("`@("`@('T*"B`@("`@("`@<F5T=7)N(')O=6YD*"1P<F5S
M<W5R92`J("1F86-T;W);)&9R;VU=6R1T;UTL(#(I.PH@("`@?0H@("`@+R\@
M?7U]"@H@("`@+R\@>WM[(&-O;G9E<G1$:7-T86YC92@I"B`@("`O*BH*("`@
M("`J($-O;G9E<G0@9&ES=&%N8V4@8F5T=V5E;B!K;2P@9G0@86YD('-M"B`@
M("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@
M("`@("1D:7-T86YC90H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@
M("`@("`@("`@("`@("1F<F]M"B`@("`@*B!`<&%R86T@("!S=')I;F<@("`@
M("`@("`@("`@("`@("`@("`@)'1O"B`@("`@*B!`<F5T=7)N("!F;&]A=`H@
M("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@("`@*B\*("`@(&9U;F-T:6]N(&-O
M;G9E<G1$:7-T86YC92@D9&ES=&%N8V4L("1F<F]M+"`D=&\I"B`@("!["B`@
M("`@("`@)'1O("`@/2!S=')T;VQO=V5R*"1T;RD["B`@("`@("`@)&9R;VT@
M/2!S=')T;VQO=V5R*"1F<F]M*3L*"B`@("`@("`@<W1A=&EC("1F86-T;W([
M"B`@("`@("`@:68@*"%I<W-E="@D9F%C=&]R*2D@>PH@("`@("`@("`@("`D
M9F%C=&]R(#T@87)R87DH"B`@("`@("`@("`@("`@("`B;2(@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@(FTB(#T^(#$L("`@("`@("`@("`@(FMM
M(B`]/B`Q,#`P+"`@("`@(")F="(@/3X@,RXR.#`X,SDX.34L(")S;2(@/3X@
M,"XP,#`V,C$S-CDY"B`@("`@("`@("`@("`@("`I+`H@("`@("`@("`@("`@
M("`@(FMM(B`]/B!A<G)A>2@*("`@("`@("`@("`@("`@("`@("`B;2(@/3X@
M,"XP,#$L("`@("`@("`B:VTB(#T^(#$L("`@("`@("`@(F9T(B`]/B`S,C@P
M+C@S.3@Y-2P@(G-M(B`]/B`P+C8R,3,V.3D*("`@("`@("`@("`@("`@("DL
M"B`@("`@("`@("`@("`@("`B9G0B(#T^(&%R<F%Y*`H@("`@("`@("`@("`@
M("`@("`@(")M(B`]/B`P+C,P-#@L("`@("`@(")K;2(@/3X@,"XP,#`S,#0X
M+"`B9G0B(#T^(#$L("`@("`@("`@("`B<VTB(#T^(#`N,#`P,3@Y-`H@("`@
M("`@("`@("`@("`@*2P*("`@("`@("`@("`@("`@(")S;2(@/3X@87)R87DH
M"B`@("`@("`@("`@("`@("`@("`@(FTB(#T^(#`N,#`Q-C`Y,S0W,BP@(FMM
M(B`]/B`Q+C8P.3,T-S(L(")F="(@/3X@-3(X,"XP,3`V+"`@(")S;2(@/3X@
M,0H@("`@("`@("`@("`@("`@*0H@("`@("`@("`@("`I.PH@("`@("`@('T*
M"B`@("`@("`@<F5T=7)N(')O=6YD*"1D:7-T86YC92`J("1F86-T;W);)&9R
M;VU=6R1T;UTL(#(I.PH@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&-A
M;&-U;&%T95=I;F1#:&EL;"@I"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!W
M:6YD8VAI;&P@9G)O;2!T96UP97)A='5R92!A;F0@=VEN9'-P965D("AE;FAA
M;F-E9"!F;W)M=6QA*0H@("`@("H*("`@("`J(%1E;7!E<F%T=7)E(&AA<R!T
M;R!B92!E;G1E<F5D(&EN(&1E9R!&+"!S<&5E9"!I;B!M<&@A"B`@("`@*@H@
M("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1T
M96UP97)A='5R90H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@
M("`@("`@("`@("1S<&5E9`H@("`@("H@0')E='5R;B`@9FQO870*("`@("`J
M($!A8V-E<W,@('!U8FQI8PH@("`@("H@0&QI;FL@("`@:'1T<#HO+W=W=RYN
M=W,N;F]A82YG;W8O;VTO=VEN9&-H:6QL+PH@("`@("HO"B`@("!F=6YC=&EO
M;B!C86QC=6QA=&57:6YD0VAI;&PH)'1E;7!E<F%T=7)E+"`D<W!E960I"B`@
M("!["B`@("`@("`@<F5T=7)N(')O=6YD*#,U+C<T("L@,"XV,C$U("H@)'1E
M;7!E<F%T=7)E("T@,S4N-S4@*B!P;W<H)'-P965D+"`P+C$V*2`K(#`N-#(W
M-2`J("1T96UP97)A='5R92`J('!O=R@D<W!E960L(#`N,38I*3L*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!C86QC=6QA=&5(=6UI9&ET>2@I"B`@
M("`O*BH*("`@("`J($-A;&-U;&%T92!H=6UI9&ET>2!F<F]M('1E;7!E<F%T
M=7)E(&%N9"!D97=P;VEN=`H@("`@("H@5&AI<R!I<R!O;FQY(&%N(&%P<')O
M>&EM871I;VXL('1H97)E(&ES(&YO(&5X86-T(&9O<FUU;&$L('1H:7,*("`@
M("`J(&]N92!H97)E(&ES(&-A;&QE9"!-86=N=7,M1F]R;75L80H@("`@("H*
M("`@("`J(%1E;7!E<F%T=7)E(&%N9"!D97=P;VEN="!H879E('1O(&)E(&5N
M=&5R960@:6X@9&5G($,A"B`@("`@*@H@("`@("H@0'!A<F%M("`@9FQO870@
M("`@("`@("`@("`@("`@("`@("`@("1T96UP97)A='5R90H@("`@("H@0'!A
M<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1D97=0;VEN=`H@
M("`@("H@0')E='5R;B`@9FQO870*("`@("`J($!A8V-E<W,@('!U8FQI8PH@
M("`@("H@0&QI;FL@("`@:'1T<#HO+W=W=RYF87%S+F]R9R]F87%S+VUE=&5O
M<F]L;V=Y+W1E;7`M9&5W<&]I;G0O"B`@("`@*B\*("`@(&9U;F-T:6]N(&-A
M;&-U;&%T94AU;6ED:71Y*"1T96UP97)A='5R92P@)&1E=U!O:6YT*0H@("`@
M>PH@("`@("`@("\O($9I<G-T(&-A;&-U;&%T92!S871U<F%T:6]N('-T96%M
M('!R97-S=7)E(&9O<B!B;W1H('1E;7!E<F%T=7)E<PH@("`@("`@(&EF("@D
M=&5M<&5R871U<F4@/CT@,"D@>PH@("`@("`@("`@("`D82`](#<N-3L*("`@
M("`@("`@("`@)&(@/2`R,S<N,SL*("`@("`@("!](&5L<V4@>PH@("`@("`@
M("`@("`D82`](#<N-CL*("`@("`@("`@("`@)&(@/2`R-#`N-SL*("`@("`@
M("!]"B`@("`@("`@)'1E;7!34U`@/2`V+C$P-S@@*B!P;W<H,3`L("@D82`J
M("1T96UP97)A='5R92D@+R`H)&(@*R`D=&5M<&5R871U<F4I*3L*"B`@("`@
M("`@:68@*"1D97=0;VEN="`^/2`P*2!["B`@("`@("`@("`@("1A(#T@-RXU
M.PH@("`@("`@("`@("`D8B`](#(S-RXS.PH@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("1A(#T@-RXV.PH@("`@("`@("`@("`D8B`](#(T,"XW.PH@
M("`@("`@('T*("`@("`@("`D9&5W4U-0("`](#8N,3`W."`J('!O=R@Q,"P@
M*"1A("H@)&1E=U!O:6YT*2`O("@D8B`K("1D97=0;VEN="DI.PH*("`@("`@
M("!R971U<FX@<F]U;F0H,3`P("H@)&1E=U-34"`O("1T96UP4U-0+"`Q*3L*
M("`@('T*("`@("\O('U]?0H*("`@("\O('M[>R!C86QC=6QA=&5$97=0;VEN
M="@I"B`@("`O*BH*("`@("`J($-A;&-U;&%T92!D97=P;VEN="!F<F]M('1E
M;7!E<F%T=7)E(&%N9"!H=6UI9&ET>0H@("`@("H@5&AI<R!I<R!O;FQY(&%N
M(&%P<')O>&EM871I;VXL('1H97)E(&ES(&YO(&5X86-T(&9O<FUU;&$L('1H
M:7,*("`@("`J(&]N92!H97)E(&ES(&-A;&QE9"!-86=N=7,M1F]R;75L80H@
M("`@("H*("`@("`J(%1E;7!E<F%T=7)E(&AA<R!T;R!B92!E;G1E<F5D(&EN
M(&1E9R!#(0H@("`@("H*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@
M("`@("`@("`@("`@("`D=&5M<&5R871U<F4*("`@("`J($!P87)A;2`@(&9L
M;V%T("`@("`@("`@("`@("`@("`@("`@("`D:'5M:61I='D*("`@("`J($!R
M971U<FX@(&9L;V%T"B`@("`@*B!`86-C97-S("!P=6)L:6,*("`@("`J($!L
M:6YK("`@(&AT='`Z+R]W=W<N9F%Q<RYO<F<O9F%Q<R]M971E;W)O;&]G>2]T
M96UP+61E=W!O:6YT+PH@("`@("HO"B`@("!F=6YC=&EO;B!C86QC=6QA=&5$
M97=0;VEN="@D=&5M<&5R871U<F4L("1H=6UI9&ET>2D*("`@('L*("`@("`@
M("!I9B`H)'1E;7!E<F%T=7)E(#X](#`I('L*("`@("`@("`@("`@)&$@/2`W
M+C4["B`@("`@("`@("`@("1B(#T@,C,W+C,["B`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@)&$@/2`W+C8["B`@("`@("`@("`@("1B(#T@,C0P+C<[
M"B`@("`@("`@?0H*("`@("`@("`O+R!&:7)S="!C86QC=6QA=&4@<V%T=7)A
M=&EO;B!S=&5A;2!P<F5S<W5R92!F;W(@=&5M<&5R871U<F4*("`@("`@("`D
M4U-0(#T@-BXQ,#<X("H@<&]W*#$P+"`H)&$@*B`D=&5M<&5R871U<F4I("\@
M*"1B("L@)'1E;7!E<F%T=7)E*2D["@H@("`@("`@("\O(%-T96%M('!R97-S
M=7)E"B`@("`@("`@)%-0("`]("1H=6UI9&ET>2`O(#$P,"`J("134U`["@H@
M("`@("`@("1V("`@/2!L;V<H)%-0("\@-BXQ,#<X+"`Q,"D["@H@("`@("`@
M(')E='5R;B!R;W5N9"@D8B`J("1V("\@*"1A("T@)'8I+"`Q*3L*("`@('T*
M("`@("\O('U]?0H*("`@("\O('M[>R!P;VQA<C)C87)T97-I86XH*0H@("`@
M+RHJ"B`@("`@*B!#;VYV97)T('!O;&%R(&-O;W)D:6YA=&5S('1O(&-A<G1E
M<VEA;B!C;V]R9&EN871E<PH@("`@("H*("`@("`J($!P87)A;2`@(&9L;V%T
M("`@("`@("`@("`@("`@("`@("`@("`D;&%T:71U9&4*("`@("`J($!P87)A
M;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@("`@("`D;&]N9VET=61E"B`@
M("`@*B!`<F5T=7)N("!A<G)A>0H@("`@("H@0&%C8V5S<R`@<'5B;&EC"B`@
M("`@*B\*("`@(&9U;F-T:6]N('!O;&%R,F-A<G1E<VEA;B@D;&%T:71U9&4L
M("1L;VYG:71U9&4I"B`@("!["B`@("`@("`@)'1H971A(#T@9&5G,G)A9"@D
M;&%T:71U9&4I.PH@("`@("`@("1P:&D@("`](&1E9S)R860H)&QO;F=I='5D
M92D["@H@("`@("`@("1X(#T@4T525DE#15-?5T5!5$A%4E]2041)55-?14%2
M5$@@*B!C;W,H)'!H:2D@*B!C;W,H)'1H971A*3L*("`@("`@("`D>2`](%-%
M4E9)0T537U=%051(15)?4D%$25537T5!4E1(("H@<VEN*"1P:&DI("H@8V]S
M*"1T:&5T82D["B`@("`@("`@)'H@/2!315)624-%4U]714%42$527U)!1$E5
M4U]%05)42"`@("`@("`@("`@("`J('-I;B@D=&AE=&$I.PH*("`@("`@("!R
M971U<FX@87)R87DH)'@L("1Y+"`D>BD["B`@("!]"B`@("`O+R!]?7T*"@H@
M("`@+R\@>WM[(&-A;&-U;&%T95-U;E)I<V53970H*0H@("`@+RHJ"B`@("`@
M*B!#86QC=6QA=&5S('-U;G)I<V4@86YD('-U;G-E="!F;W(@82!L;V-A=&EO
M;@H@("`@("H*("`@("`J(%1H92!S=6X@<&]S:71I;VX@86QG;W)I=&AM('1A
M:V5N(&9R;VT@=&AE("=54R!.879A;"!/8G-E<G9A=&]R>2=S"B`@("`@*B!!
M;&UA;F%C(&9O<B!#;VUP=71E<G,G+"!I;7!L96UE;G1E9"!B>2!+96X@0FQO
M;VT@/&ME:V%B;&]O;5MA=%UU8V1A=FES6V1O=%UE9'4^"B`@("`@*B!F;W(@
M=&AE('IM86YI;2!P<F]J96-T+"!C;VYV97)T960@=&\@0R!B>2!-;W-H92!$
M;W)O;B`\;6]S9&]R;VY;871=;F5T=FES:6]N6V1O=%UN971;9&]T76EL/@H@
M("`@("H@86YD(&9I;F%L;'D@=&%K96X@9G)O;2!T:&4@4$A0-2!S;W5R8V5S
M(&%N9"!C;VYV97)T960@=&\@;F%T:79E(%!(4"!A<R!A('=R87!P97(N"B`@
M("`@*@H@("`@("H@5&AE(&1A=&4@:&%S('1O(&)E(&5N=&5R960@87,@82!T
M:6UE<W1A;7`A"B`@("`@*@H@("`@("H@0'!A<F%M("`@:6YT("`@("`@("`@
M("`@("`@("`@("`@("`@("1D871E"B`@("`@*B!`<&%R86T@("!I;G0@("`@
M("`@("`@("`@("`@("`@("`@("`@)')E=&9O<FUA=`H@("`@("H@0'!A<F%M
M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1L871I='5D90H@("`@
M("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1L;VYG
M:71U9&4*("`@("`J($!P87)A;2`@(&9L;V%T("`@("`@("`@("`@("`@("`@
M("`@("`D>F5N:71H"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@("`@("`@
M("`@("`@("`@("`@)&=M=%]O9F9S970*("`@("`J($!P87)A;2`@(&)O;VP@
M("`@("`@("`@("`@("`@("`@("`@("`D<W5N<FES90H@("`@("H@0')E='5R
M;B`@4$5!4E]%<G)O<GQM:7AE9`H@("`@("H@0'1H<F]W<R`@4$5!4E]%<G)O
M<CHZ4T525DE#15-?5T5!5$A%4E]%4E)/4E]354Y&54Y#4U]$051%7TE.5D%,
M240*("`@("`J($!T:')O=W,@(%!%05)?17)R;W(Z.E-%4E9)0T537U=%051(
M15)?15)23U)?4U5.1E5.0U-?4D541D]235])3E9!3$E$"B`@("`@*B!`=&AR
M;W=S("!014%27T5R<F]R.CI315)624-%4U]714%42$527T524D]27U5.2TY/
M5TY?15)23U(*("`@("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F
M=6YC=&EO;B!C86QC=6QA=&53=6Y2:7-E4V5T*"1D871E+"`D<F5T9F]R;6%T
M(#T@;G5L;"P@)&QA=&ET=61E(#T@;G5L;"P@)&QO;F=I='5D92`](&YU;&PL
M("1Z96YI=&@@/2!N=6QL+"`D9VUT7V]F9G-E="`](&YU;&PL("1S=6YR:7-E
M(#T@=')U92D*("`@('L*("`@("`@("`O+R!$871E(&UU<W0@8F4@=&EM97-T
M86UP(&9O<B!N;W<*("`@("`@("!I9B`H(6ES7VEN="@D9&%T92DI('L*("`@
M("`@("`@("`@<F5T=7)N(%-E<G9I8V5S7U=E871H97(Z.G)A:7-E17)R;W(H
M4T525DE#15-?5T5!5$A%4E]%4E)/4E]354Y&54Y#4U]$051%7TE.5D%,240L
M(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@("`@("`@?0H*("`@("`@("`O+R!#
M:&5C:R!F;W(@<')O<&5R(')E='5R;B!F;W)M870*("`@("`@("!I9B`H)')E
M=&9O<FUA="`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D<F5T9F]R;6%T("`]
M(%-53D953D-37U)%5%]35%))3D<["B`@("`@("`@?2!E;'-E:68@*"%I;E]A
M<G)A>2@D<F5T9F]R;6%T+"!A<G)A>2A354Y&54Y#4U]2151?5$E-15-404U0
M+"!354Y&54Y#4U]2151?4U1224Y'+"!354Y&54Y#4U]2151?1$]50DQ%*2D@
M*2!["B`@("`@("`@("`@(')E='5R;B!397)V:6-E<U]796%T:&5R.CIR86ES
M945R<F]R*%-%4E9)0T537U=%051(15)?15)23U)?4U5.1E5.0U-?4D541D]2
M35])3E9!3$E$+"!?7T9)3$5?7RP@7U],24Y%7U\I.PH@("`@("`@('T*"B`@
M("`@("`@+R\@4V5T(&1E9F%U;'0@=F%L=65S(&9O<B!C;V]R9&EN871E<PH@
M("`@("`@(&EF("@D;&%T:71U9&4@/3T](&YU;&PI('L*("`@("`@("`@("`@
M)&QA=&ET=61E("`@/2!354Y&54Y#4U]$149!54Q47TQ!5$E4541%.PH@("`@
M("`@('T@96QS92!["B`@("`@("`@("`@("1L871I='5D92`@(#T@*&9L;V%T
M*2`D;&%T:71U9&4["B`@("`@("`@?0H@("`@("`@(&EF("@D;&]N9VET=61E
M(#T]/2!N=6QL*2!["B`@("`@("`@("`@("1L;VYG:71U9&4@(#T@4U5.1E5.
M0U-?1$5&055,5%],3TY'25151$4["B`@("`@("`@?2!E;'-E('L*("`@("`@
M("`@("`@)&QO;F=I='5D92`@/2`H9FQO870I("1L;VYG:71U9&4["B`@("`@
M("`@?0H@("`@("`@(&EF("@D>F5N:71H(#T]/2!N=6QL*2!["B`@("`@("`@
M("`@(&EF*"1S=6YR:7-E*2!["B`@("`@("`@("`@("`@("`D>F5N:71H(#T@
M4U5.1E5.0U-?4U5.4DE315]:14Y)5$@["B`@("`@("`@("`@('T@96QS92![
M"B`@("`@("`@("`@("`@("`D>F5N:71H(#T@4U5.1E5.0U-?4U5.4T547UI%
M3DE42#L*("`@("`@("`@("`@?0H@("`@("`@('T@96QS92!["B`@("`@("`@
M("`@("1Z96YI=&@@("`@(#T@*&9L;V%T*2`D>F5N:71H.PH@("`@("`@('T*
M"B`@("`@("`@+R\@1&5F875L="!V86QU92!F;W(@1TU4(&]F9G-E=`H@("`@
M("`@(&EF("@D9VUT7V]F9G-E="`]/3T@;G5L;"D@>PH@("`@("`@("`@("`D
M9VUT7V]F9G-E="`](&1A=&4H(EHB+"`D9&%T92D@+R`S-C`P.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("1G;71?;V9F<V5T(#T@*&9L;V%T*2`D
M9VUT7V]F9G-E=#L*("`@("`@("!]"@H@("`@("`@("\O($EF('=E(&AA=F4@
M4$A0-2P@=&AE;B!A8W0@87,@=W)A<'!E<B!F;W(@=&AE(&%P<')O<')I871E
M(&9U;F-T:6]N<PH@("`@("`@(&EF("@D<W5N<FES92`F)B!F=6YC=&EO;E]E
M>&ES=',H(F1A=&5?<W5N<FES92(I*2!["B`@("`@("`@("`@(')E='5R;B!D
M871E7W-U;G)I<V4H)&1A=&4L("1R971F;W)M870L("1L871I='5D92P@)&QO
M;F=I='5D92P@)'IE;FET:"P@)&=M=%]O9F9S970I.PH@("`@("`@('T*("`@
M("`@("!I9B`H(21S=6YR:7-E("8F(&9U;F-T:6]N7V5X:7-T<R@B9&%T95]S
M=6YS970B*2D@>PH@("`@("`@("`@("!R971U<FX@9&%T95]S=6YS970H)&1A
M=&4L("1R971F;W)M870L("1L871I='5D92P@)&QO;F=I='5D92P@)'IE;FET
M:"P@)&=M=%]O9F9S970I.PH@("`@("`@('T*"B`@("`@("`@+R\@07!P87)E
M;G1L>2!W92!H879E(%!(4#0L('-O(&-A;&-U;&%T92!T:&4@;F5C8V5S<V%R
M>2!S=&5P<R!I;B!N871I=F4@4$A0"B`@("`@("`@+R\@4W1E<"`Q.B!&:7)S
M="!C86QC=6QA=&4@=&AE(&1A>2!O9B!T:&4@>65A<@H@("`@("`@("1.(#T@
M9&%T92@B>B(L("1D871E*2`K(#$["@H@("`@("`@("\O(%-T97`@,CH@0V]N
M=F5R="!T:&4@;&]N9VET=61E('1O(&AO=7(@=F%L=64@86YD(&-A;&-U;&%T
M92!A;B!A<'!R;WAI;6%T92!T:6UE"B`@("`@("`@)&QN9TAO=7(@/2`D;&]N
M9VET=61E("\@,34["@H@("`@("`@("\O(%5S92`Q."!F;W(@<W5N<V5T(&EN
M<W1E860@;V8@-@H@("`@("`@(&EF("@D<W5N<FES92D@>PH@("`@("`@("`@
M("`O+R!3=6YR:7-E"B`@("`@("`@("`@("1T(#T@)$X@*R`H*#8@+2`D;&YG
M2&]U<BD@+R`R-"D["B`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@+R\@
M4W5N<V5T"B`@("`@("`@("`@("1T(#T@)$X@*R`H*#$X("T@)&QN9TAO=7(I
M("\@,C0I.PH@("`@("`@('T*"B`@("`@("`@+R\@4W1E<"`S.B!#86QC=6QA
M=&4@=&AE('-U;B=S(&UE86X@86YO;6%L>0H@("`@("`@("1-(#T@*#`N.3@U
M-B`J("1T*2`M(#,N,C@Y.PH*("`@("`@("`O+R!3=&5P(#0Z($-A;&-U;&%T
M92!T:&4@<W5N)W,@=')U92!L;VYG:71U9&4*("`@("`@("`D3"`]("1-("L@
M*#$N.3$V("H@<VEN*&1E9S)R860H)$TI*2D@*R`H,"XP,C`@*B!S:6XH9&5G
M,G)A9"@R("H@)$TI*2D@*R`R.#(N-C,T.PH*("`@("`@("!W:&EL92`H)$P@
M/"`P*2!["B`@("`@("`@("`@("1,>"`]("1,("L@,S8P.PH@("`@("`@("`@
M("!A<W-E<G0H)$QX("$]("1,*3L@+R\@87-K:6YG=&AE9W5R=3H@<F5A;&QY
M(&YE961E9#\*("`@("`@("`@("`@)$P@/2`D3'@["B`@("`@("`@?0H*("`@
M("`@("!W:&EL92`H)$P@/CT@,S8P*2!["B`@("`@("`@("`@("1,>"`]("1,
M("T@,S8P.PH@("`@("`@("`@("!A<W-E<G0H)$QX("$]("1,*3L@+R\@87-K
M:6YG=&AE9W5R=3H@<F5A;&QY(&YE961E9#\*("`@("`@("`@("`@)$P@/2`D
M3'@["B`@("`@("`@?0H*("`@("`@("`O+R!3=&5P(#5A.B!#86QC=6QA=&4@
M=&AE('-U;B=S(')I9VAT(&%S8V5N<VEO;@H@("`@("`@("1202`](')A9#)D
M96<H871A;B@P+CDQ-S8T("H@=&%N*&1E9S)R860H)$PI*2DI.PH*("`@("`@
M("!W:&EL92`H)%)!(#P@,"D@>PH@("`@("`@("`@("`D4D%X(#T@)%)!("L@
M,S8P.PH@("`@("`@("`@("!A<W-E<G0H)%)!>"`A/2`D4D$I.R`O+R!A<VMI
M;F=T:&5G=7)U.B!R96%L;'D@;F5E9&5D/PH@("`@("`@("`@("`D4D$@/2`D
M4D%X.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*"1202`^/2`S-C`I('L*
M("`@("`@("`@("`@)%)!>"`]("1202`M(#,V,#L*("`@("`@("`@("`@87-S
M97)T*"1207@@(3T@)%)!*3L@+R\@87-K:6YG=&AE9W5R=3H@<F5A;&QY(&YE
M961E9#\*("`@("`@("`@("`@)%)!(#T@)%)!>#L*("`@("`@("!]"@H@("`@
M("`@("\O(%-T97`@-6(Z(%)I9VAT(&%S8V5N<VEO;B!V86QU92!N965D<R!T
M;R!B92!I;B!T:&4@<V%M92!Q=6%D<F%N="!A<R!,"B`@("`@("`@)$QQ=6%D
M<F%N="`@/2!F;&]O<B@D3"`O(#DP*2`J(#DP.PH@("`@("`@("1207%U861R
M86YT(#T@9FQO;W(H)%)!("\@.3`I("H@.3`["@H@("`@("`@("1202`]("12
M02`K("@D3'%U861R86YT("T@)%)!<75A9')A;G0I.PH*("`@("`@("`O+R!3
M=&5P(#5C.B!2:6=H="!A<V-E;G-I;VX@=F%L=64@;F5E9',@=&\@8F4@8V]N
M=F5R=&5D(&EN=&\@:&]U<G,*("`@("`@("`D4D$@+ST@,34["@H@("`@("`@
M("\O(%-T97`@-CH@0V%L8W5L871E('1H92!S=6XG<R!D96-L:6YA=&EO;@H@
M("`@("`@("1S:6Y$96,@/2`P+C,Y-S@R("H@<VEN*&1E9S)R860H)$PI*3L*
M("`@("`@("`D8V]S1&5C(#T@8V]S*&%S:6XH)'-I;D1E8RDI.PH*("`@("`@
M("`O+R!3=&5P(#=A.B!#86QC=6QA=&4@=&AE('-U;B=S(&QO8V%L(&AO=7(@
M86YG;&4*("`@("`@("`D8V]S2"`]("AC;W,H9&5G,G)A9"@D>F5N:71H*2D@
M+2`H)'-I;D1E8R`J('-I;BAD96<R<F%D*"1L871I='5D92DI*2D@+R`H)&-O
M<T1E8R`J(&-O<RAD96<R<F%D*"1L871I='5D92DI*3L*"B`@("`@("`@+R\@
M6%A8.B!7:&%T)W,@=&AE('5S92!O9B!T:&ES(&)L;V-K+BX@/PH@("`@("`@
M("\O(&EF("AS=6YR:7-E("8F(&-O<T@@/B`Q('Q\("%S=6YR:7-E("8F(&-O
M<T@@/"`M,2D@>PH@("`@("`@("\O("`@("!T:')O=R!D;V5S;G1H87!P96XH
M*3L*("`@("`@("`O+R!]"@H@("`@("`@("\O(%-T97`@-V(Z($9I;FES:"!C
M86QC=6QA=&EN9R!((&%N9"!C;VYV97)T(&EN=&\@:&]U<G,*("`@("`@("!I
M9B`H)'-U;G)I<V4I('L*("`@("`@("`@("`@+R\@4W5N<FES90H@("`@("`@
M("`@("`D2"`](#,V,"`M(')A9#)D96<H86-O<R@D8V]S2"DI.PH@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("\O(%-U;G-E=`H@("`@("`@("`@("`D
M2"`](')A9#)D96<H86-O<R@D8V]S2"DI.PH@("`@("`@('T*("`@("`@("`D
M2"`]("1(("\@,34["@H@("`@("`@("\O(%-T97`@.#H@0V%L8W5L871E(&QO
M8V%L(&UE86X@=&EM90H@("`@("`@("14(#T@)$@@*R`D4D$@+2`H,"XP-C4W
M,2`J("1T*2`M(#8N-C(R.PH*("`@("`@("`O+R!3=&5P(#DZ($-O;G9E<G0@
M=&\@551#"B`@("`@("`@)%54(#T@)%0@+2`D;&YG2&]U<CL*"B`@("`@("`@
M=VAI;&4@*"155"`\(#`I('L*("`@("`@("`@("`@)%54>"`]("155"`K(#(T
M.PH@("`@("`@("`@("!A<W-E<G0H)%54>"`A/2`D550I.R`O+R!A<VMI;F=T
M:&5G=7)U.B!R96%L;'D@;F5E9&5D/PH@("`@("`@("`@("`D550@/2`D551X
M.PH@("`@("`@('T*"B`@("`@("`@=VAI;&4@*"155"`^/2`R-"D@>PH@("`@
M("`@("`@("`D551X(#T@)%54("T@,C0["B`@("`@("`@("`@(&%S<V5R="@D
M551X("$]("155"D[("\O(&%S:VEN9W1H96=U<G4Z(')E86QL>2!N965D960_
M"B`@("`@("`@("`@("155"`]("155'@["B`@("`@("`@?0H*("`@("`@("`D
M550@/2`D550@*R`D9VUT7V]F9G-E=#L*"B`@("`@("`@+R\@3F]W(&)R:6YG
M('1H92!R97-U;'0@:6YT;R!T:&4@8VAO<V5N(&9O<FUA="!A;F0@<F5T=7)N
M"B`@("`@("`@<W=I=&-H("@D<F5T9F]R;6%T*2!["B`@("`@("`@("`@(&-A
M<V4@4U5.1E5.0U-?4D547U1)34535$%-4#H*("`@("`@("`@("`@("`@(')E
M='5R;B!F;&]O<B@D9&%T92`M("@D9&%T92`E("@R-"`J(#,V,#`I*2D@*R!F
M;&]O<B@V,"`J("155"D["B`@("`@("`@("`@(&-A<V4@4U5.1E5.0U-?4D54
M7U-44DE.1SH*("`@("`@("`@("`@("`@("1.(#T@9FQO;W(H)%54*3L*("`@
M("`@("`@("`@("`@(')E='5R;B!S<')I;G1F*"(E,#)D.B4P,F0B+"`D3BP@
M9FQO;W(H-C`@*B`H)%54("T@)$XI*2D["B`@("`@("`@("`@(&-A<V4@4U5.
M1E5.0U-?4D547T1/54),13H*("`@("`@("`@("`@("`@(')E='5R;B`D550[
M"B`@("`@("`@("`@(&1E9F%U;'0Z"B`@("`@("`@("`@("`@("!R971U<FX@
M4V5R=FEC97-?5V5A=&AE<CHZ<F%I<V5%<G)O<BA315)624-%4U]714%42$52
M7T524D]27U5.2TY/5TY?15)23U(L(%]?1DE,15]?+"!?7TQ)3D5?7RD["B`@
M("`@("`@?0H@("`@?0H@("`@+R\@?7U]"@H@("`@+R\@>WM[(&=E=%=E871H
M97))8V]N*"D*("`@("\J*@H@("`@("H@1V5T<R!A(&YU;6)E<B!C;W)R97-P
M;VYD:6YG('1O(&$@=V5A=&AE<B!I8V]N+@H@("`@("H*("`@("`J(%1H97-E
M(&YU;6)E<G,@:G5S="!H87!P96X@=&\@8V]R<F5S<&]N9"!W:71H('1H92!I
M8V]N<R!T:&%T('EO=2!G970@=VET:`H@("`@("H@=&AE('=E871H97(N8V]M
M(%-$2RP@8G5T(&]P96X@=F5R<VEO;G,@;V8@=&AE;2!H879E(&)E96X@8W)E
M871E9"X@26YP=70*("`@("`J(&UU<W0@8F4@:6X@<W1A;F1A<F0@=6YI=',N
M($9O<B!T:&4@:6-O;G,@=&AA="!I;F-L=61E(&1A>2]N:6=H="P@=V4@=7-E
M"B`@("`@*B!T:&4@<')E<V5N="!T:6UE(&%N9"!T:&4@<')O=FED960@;&%T
M+VQO;B!T;R!D971E<FUI;F4@:68@=&AE('-U;B!I<R!U<"X*("`@("`J($$@
M8V]M<&QE=&4@<V5T(&]F(&EC;VX@9&5S8W)I<'1I;VYS(&-A;B!B92!F;W5N
M9"!H97)E.@H@("`@("H@:'1T<#HO+W-R86YS:&%F="YW:6YC=7-T;VUI>F4N
M8V]M+T%R=&EC;&5S+F%S<'@_04E$/38P,38U)G4],`H@("`@("H*("`@("`J
M(%1H97)E(&%R92!A(&YU;6)E<B!O9B!I8V]N('-E=',@:&5R93H*("`@("`J
M(&AT='`Z+R]W=W<N9&5S:W1O<'-I9&5B87(N8V]M+V9O<G5M<R]I;F1E>"YP
M:'`_<VAO=W1O<&EC/3(T-#$F<W0],`H@("`@("H@:'1T<#HO+W=W=RYD97-K
M=&]P<VED96)A<BYC;VTO9F]R=6US+VEN9&5X+G!H<#]S:&]W=&]P:6,].#$Y
M"B`@("`@*@H@("`@("H@0'!A<F%M("`@<W1R:6YG("`@("`@("`@("`@("`@
M("`@("`@("1C;VYD:71I;VX@("`@("!4:&4@8V]N9&ET:6]N+@H@("`@("H@
M0'!A<F%M("`@87)R87D@("`@("`@("`@("`@("`@("`@("`@("1C;&]U9',@
M("`@("`@("!4:&4@8VQO=61S(&%T('9A<FEO=7,@;&5V96QS+@H@("`@("H@
M0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@("`@("1W:6YD("`@
M("`@("`@("!7:6YD('-P965D(&EN(&UP:"X*("`@("`J($!P87)A;2`@(&9L
M;V%T("`@("`@("`@("`@("`@("`@("`@("`D=&5M<&5R871U<F4@("`@5&5M
M<&5R871U<F4@:6X@9&5G($8N"B`@("`@*B!`<&%R86T@("!F;&]A="`@("`@
M("`@("`@("`@("`@("`@("`@)&QA=&ET=61E("`@("`@(%!O:6YT(&QA=&ET
M=61E+@H@("`@("H@0'!A<F%M("`@9FQO870@("`@("`@("`@("`@("`@("`@
M("`@("1L;VYG:71U9&4@("`@("!0;VEN="!L;VYG:71U9&4N"B`@("`@*B!`
M875T:&]R("!3971H(%!R:6-E("`\<V5T:$!P<FEC97!A9V5S+F]R9SX*("`@
M("`J($!A8V-E<W,@('!U8FQI8PH@("`@("HO"B`@("!F=6YC=&EO;B!G9717
M96%T:&5R26-O;B@D8V]N9&ET:6]N+"`D8VQO=61S(#T@87)R87DH*2P@)'=I
M;F0@/2`U+"`D=&5M<&5R871U<F4@/2`W,"P@)&QA=&ET=61E(#T@+3,V,"P@
M)&QO;F=I='5D92`]("TS-C`I"B`@("!["B`@("`@("`@+R\@4V5A<F-H(&9O
M<B!M871C:&5S('1H870@9&]N)W0@=7-E('1H92!T:6UE(&]F(&1A>0H@("`@
M("`@("1H86EL("`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL(")H
M86EL(BD["B`@("`@("`@)&1U<W0@("`@(#T@*&)O;VPI('-T<FES='(H)&-O
M;F1I=&EO;BP@(F1U<W0B*2`@("`@?'P@*&)O;VPI('-T<FES='(H)&-O;F1I
M=&EO;BP@(G-A;F0B*3L*("`@("`@("`D<VUO:V4@("`@/2`H8F]O;"D@<W1R
M:7-T<B@D8V]N9&ET:6]N+"`B<VUO:V4B*2`@("!\?"`H8F]O;"D@<W1R:7-T
M<B@D8V]N9&ET:6]N+"`B=F]L8V%N:6,@87-H(BD["@H@("`@("`@("\O(%-L
M:6=H=&QY(&UO<F4@8V]M<&QE>"!M871C:&5S('1H870@;6EG:'0@;W(@;6EG
M:'0@;F]T('5S92!T:&4@=&EM92!O9B!D87D*("`@("`@("`D;F5A<B`@("`@
M/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B=FEC:6YI='DB*2!\?"`H
M8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B<F5C96YT(BD["B`@("`@("`@
M)&QI9VAT("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@(FQI9VAT
M(BD["B`@("`@("`@)&AE879Y("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I
M=&EO;BP@(FAE879Y(BD["B`@("`@("`@)&EC92`@("`@(#T@*&)O;VPI('-T
M<FES='(H)&-O;F1I=&EO;BP@(FEC92(I("`@("`@?'P@*&)O;VPI('-T<FES
M='(H)&-O;F1I=&EO;BP@(G!E;&QE=',B*3L*("`@("`@("`D<F%I;B`@("`@
M/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B<F%I;B(I.PH@("`@("`@
M("1S;F]W("`@("`]("AB;V]L*2!S=')I<W1R*"1C;VYD:71I;VXL(")S;F]W
M(BD["B`@("`@("`@)&9O9R`@("`@(#T@*&)O;VPI('-T<FES='(H)&-O;F1I
M=&EO;BP@(F9O9R(I("`@("`@?'P@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO
M;BP@(G-P<F%Y(BD@("`@("`@('Q\("AB;V]L*2!S=')I<W1R*"1C;VYD:71I
M;VXL(")M:7-T(BD["B`@("`@("`@)&AA>F4@("`@(#T@*&)O;VPI('-T<FES
M='(H)&-O;F1I=&EO;BP@(FAA>F4B*3L*("`@("`@("`D=',@("`@("`@/2`H
M8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B=&AU;F1E<G-T;W)M(BD["B`@
M("`@("`@)&9R965Z:6YG(#T@*&)O;VPI('-T<FES='(H)&-O;F1I=&EO;BP@
M(F9R965Z:6YG(BD["B`@("`@("`@)'=I;F0@("`@(#T@*&)O;VPI('-T<FES
M='(H)&-O;F1I=&EO;BP@(G-Q=6%L;"(I("`@?'P@)'=I;F0@/B`R-3L*("`@
M("`@("`D;G-W("`@("`@/2`H8F]O;"D@<W1R:7-T<B@D8V]N9&ET:6]N+"`B
M;F\@<VEG;FEF:6-A;G0@=V5A=&AE<B(I.PH@("`@("`@("1H;W0@("`@("`]
M("1T96UP97)A='5R92`^(#DU.PH@("`@("`@("1F<FEG:60@("`]("1T96UP
M97)A='5R92`\(#4["@H*("`@("`@("!I9B`H)&AA:6PI('L*("`@("`@("`@
M("`@<F5T=7)N(#8[("`O+R!(86EL"B`@("`@("`@?0H@("`@("`@(&EF("@D
M9'5S="D@>PH@("`@("`@("`@("!R971U<FX@,3D[("\O($1U<W0*("`@("`@
M("!]"B`@("`@("`@:68@*"1S;6]K92D@>PH@("`@("`@("`@("!R971U<FX@
M,C([("\O(%-M;VME"B`@("`@("`@?0H*("`@("`@("`O+R!'970@<V]M92!O
M9B!T:&4@9&%N9V5R;W5S(&-O;F1I=&EO;G,@9FES=`H@("`@("`@(&EF("@D
M<F%I;B`F)B`D<VYO=R`F)B`H)&EC92!\?"`D9G)E97II;F<I*2!["B`@("`@
M("`@("`@(')E='5R;B`W.R`@+R\@26-Y+T-L;W5D<R!286EN+5-N;W<*("`@
M("`@("!]"B`@("`@("`@:68@*"@D=',@?'P@)')A:6XI("8F("@D:6-E('Q\
M("1F<F5E>FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N(#$P.R`O+R!)8WDO
M4F%I;@H@("`@("`@('T*("`@("`@("!I9B`H*"1F;V<@?'P@)&AA>F4I("8F
M("@D:6-E('Q\("1F<F5E>FEN9RDI('L*("`@("`@("`@("`@<F5T=7)N(#@[
M("`O+R!)8WDO2&%Z92!286EN"B`@("`@("`@?0H@("`@("`@(&EF("@D<F%I
M;B`F)B`D<VYO=RD@>PH@("`@("`@("`@("!R971U<FX@-3L@("\O($-L;W5D
M>2]3;F]W+5)A:6X@36EX"B`@("`@("`@?0H@("`@("`@(&EF("@D9F]G("8F
M("1R86EN*2!["B`@("`@("`@("`@(')E='5R;B`Y.R`@+R\@2&%Z92]286EN
M"B`@("`@("`@?0H@("`@("`@(&EF("@D=VEN9"`F)B`D<F%I;BD@>PH@("`@
M("`@("`@("!R971U<FX@,3L@("\O(%=I;F0O4F%I;@H@("`@("`@('T*("`@
M("`@("!I9B`H)'=I;F0@)B8@)'-N;W<I('L*("`@("`@("`@("`@<F5T=7)N
M(#0S.R`O+R!7:6YD>2]3;F]W"B`@("`@("`@?0H@("`@("`@(&EF("@D<VYO
M=R`F)B`D;&EG:'0I('L*("`@("`@("`@("`@<F5T=7)N(#$S.R`O+R!&;'5R
M<FEE<PH@("`@("`@('T*("`@("`@("!I9B`H)&QI9VAT("8F("1R86EN*2![
M"B`@("`@("`@("`@(')E='5R;B`Q,3L@+R\@3&EG:'0@4F%I;@H@("`@("`@
M('T*"B`@("`@("`@+R\@1V5T('1H92!M87AI;75M(&-O=F5R86=E(&]F('1H
M92!C;&]U9',@870@86YY(&AE:6=H="X@1F]R(&UO<W0*("`@("`@("`O+R!P
M96]P;&4L(&]V97)C87-T(&%T(#$P,#!F="!I<R!T:&4@<V%M92!A<R!O=F5R
M8V%S="!A="`Q,#`P,&9T+@H@("`@("`@("\O"B`@("`@("`@+R\@,"`]/2!C
M;&5A<BP@,2`]/2!H87IE>2P@,B`]/2!P87)T;'D@8VQO=61Y+"`S(#T](&UO
M<W1L>2!C;&]U9'DL(#0@/3T@;W9E<F-A<W0*("`@("`@("`D8V]V97)A9V4@
M/2`P.PH@("`@("`@(&9O<F5A8V@@*"1C;&]U9',@87,@)&QA>65R*2!["B`@
M("`@("`@("`@(&EF("@D8V]V97)A9V4@/"`Q("8F('-T<FES='(H)&QA>65R
M6R)A;6]U;G0B72P@(F9E=R(I*2!["B`@("`@("`@("`@("`@("`D8V]V97)A
M9V4@/2`Q.PH@("`@("`@("`@("!](&5L<V5I9B`H)&-O=F5R86=E(#P@,B`F
M)B!S=')I<W1R*"1L87EE<ELB86UO=6YT(ETL(")S8V%T=&5R960B*2D@>PH@
M("`@("`@("`@("`@("`@)&-O=F5R86=E(#T@,CL*("`@("`@("`@("`@?2!E
M;'-E:68@*"1C;W9E<F%G92`\(#,@)B8@*'-T<FES='(H)&QA>65R6R)A;6]U
M;G0B72P@(F)R;VME;B(I('Q\('-T<FES='(H)&QA>65R6R)A;6]U;G0B72P@
M(F-U;75L=7,B*2DI('L*("`@("`@("`@("`@("`@("1C;W9E<F%G92`](#,[
M"B`@("`@("`@("`@('T@96QS96EF("@D8V]V97)A9V4@/"`T("8F('-T<FES
M='(H)&QA>65R6R)A;6]U;G0B72P@(F]V97)C87-T(BDI('L*("`@("`@("`@
M("`@("`@("1C;W9E<F%G92`](#0["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("\O($-H96-K(&EF(&ET(&ES(&1A>2!O<B!N;W0N(#`@:7,@
M;FEG:'0L(#(@:7,@9&%Y+"!A;F0@,2!I<R!U;FMN;W=N"B`@("`@("`@+R\@
M;W(@='=I;&EG:'0@*'XH*WPM*3$@:&]U<B!O9B!S=6YR:7-E+W-U;G-E="DN
M($YO=&4@=&AA="!T=VEL:6=H="!I<VXG=`H@("`@("`@("\O(&%L=V%Y<R!A
M8V-U<F%T92!B96-A=7-E(&]F(&ES<W5E<R!W<F%P<&EN9R!A<F]U;F0@=&AE
M(#(T:'(@8VQO8VLN($]H('=E;&PN+BX*("`@("`@("!I9B`H)&QA=&ET=61E
M(#P@.3`@)B8@)&QA=&ET=61E(#X@+3DP("8F("1L;VYG:71U9&4@/"`Q.#`@
M)B8@)&QO;F=I='5D92`^("TQ.#`I('L*("`@("`@("`@("`@+R\@0V%L8W5L
M871E('-U;G)I<V4O<W5N<V5T(&%N9"!C=7)R96YT('1I;64@:6X@1TU4"B`@
M("`@("`@("`@("1S=6YR:7-E("`@/2`D=&AI<RT^8V%L8W5L871E4W5N4FES
M95-E="AG;6UK=&EM92@I+"!354Y&54Y#4U]2151?5$E-15-404U0+"`D;&%T
M:71U9&4L("1L;VYG:71U9&4L(%-%4E9)0T537U=%051(15)?4U5.1E5.0U-?
M4U5.4DE315]:14Y)5$@L(#`L('1R=64I.PH@("`@("`@("`@("`D<W5N<V5T
M("`@(#T@)'1H:7,M/F-A;&-U;&%T95-U;E)I<V53970H9VUM:W1I;64H*2P@
M4U5.1E5.0U-?4D547U1)34535$%-4"P@)&QA=&ET=61E+"`D;&]N9VET=61E
M+"!315)624-%4U]714%42$527U-53D953D-37U-53E))4T5?6D5.251(+"`P
M+"!F86QS92D["B`@("`@("`@("`@("1T:6UE3V9$87D@/2!G;6UK=&EM92@I
M.PH*("`@("`@("`@("`@+R\@3F]W('1H870@=V4@:&%V92!T:&4@<W5N<FES
M92]S=6YS970@=&EM97,@86YD('1H92!C=7)R96YT('1I;64L"B`@("`@("`@
M("`@("\O('=E(&YE960@=&\@9FEG=7)E(&]U="!I9B!I="!I<R!D87DL(&YI
M9VAT+"!O<B!T=VEL:6=H="X@5W)A<'!I;F<*("`@("`@("`@("`@+R\@=&AE
M<V4@=&EM97,@87)O=6YD('1H92`R-&AR(&-L;V-K(&ES(&$@<&%I;BX*("`@
M("`@("`@("`@:68@*"1S=6YR:7-E(#P@)'-U;G-E="D@>PH@("`@("`@("`@
M("`@("`@:68@*"1T:6UE3V9$87D@/B`H)'-U;G)I<V4@*R`S-C`P*2`F)B`D
M=&EM94]F1&%Y(#P@*"1S=6YS970@+2`S-C`P*2D@>PH@("`@("`@("`@("`@
M("`@("`@("1I<T1A>2`](#(["B`@("`@("`@("`@("`@("!](&5L<V5I9B`H
M)'1I;65/9D1A>2`^("@D<W5N<FES92`M(#,V,#`I("8F("1T:6UE3V9$87D@
M/"`H)'-U;G-E="`K(#,V,#`I*2!["B`@("`@("`@("`@("`@("`@("`@)&ES
M1&%Y(#T@,3L*("`@("`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@
M("`@("`@("`@)&ES1&%Y(#T@,#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&EF("@D=&EM94]F1&%Y
M(#P@*"1S=6YR:7-E("T@,S8P,"D@)B8@)'1I;65/9D1A>2`^("@D<W5N<V5T
M("L@,S8P,"DI('L*("`@("`@("`@("`@("`@("`@("`D:7-$87D@/2`P.PH@
M("`@("`@("`@("`@("`@?2!E;'-E:68@*"1T:6UE3V9$87D@/"`H)'-U;G)I
M<V4@*R`S-C`P*2`F)B`D=&EM94]F1&%Y(#X@*"1S=6YS970@+2`S-C`P*2D@
M>PH@("`@("`@("`@("`@("`@("`@("1I<T1A>2`](#$["B`@("`@("`@("`@
M("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@("`@("1I<T1A>2`](#([
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`O+R!$969A=6QT('1O('1W:6QI9VAT(&)E8V%U
M<V4@:70@=&5N9',@=&\@:&%V92!N975T<F%L(&EC;VYS+@H@("`@("`@("`@
M("`D:7-$87D@/2`Q.PH@("`@("`@('T*"B`@("`@("`@+R\@1V5N97)A;"!P
M<F5C:7!I=&%T:6]N"B`@("`@("`@:68@*"1T<R`F)B`D;F5A<BD@>PH@("`@
M("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S
M92`P.@H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@
M("`@(')E='5R;B`S.#L@+R\@3&EG:'1N:6YG"B`@("`@("`@("`@("`@("!C
M87-E(#(Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#,W.R`O+R!,:6=H
M=&YI;F<O1&%Y"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@
M*"1T<RD@>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@
M("`@("`@("`@8V%S92`P.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`T
M-SL@+R\@5&AU;F1E<G-T;W)M+TYI9VAT"B`@("`@("`@("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@("`@
M("`@<F5T=7)N(#`[("`O+R!286EN+TQI9VAT;FEN9PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@("`@(&EF("@D<VYO=RD@>PH@("`@("`@("`@("!S
M=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P.@H@("`@
M("`@("`@("`@("`@("`@(')E='5R;B`T-CL@+R\@4VYO=R].:6=H=`H@("`@
M("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@8V%S92`R.@H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`T,3L@+R\@4VYO=PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D<F%I;BD@>PH@("`@("`@
M("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@8V%S92`P
M.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`T-3L@+R\@4F%I;B].:6=H
M=`H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@("`@("`@
M(')E='5R;B`T,#L@+R\@4F%I;@H@("`@("`@("`@("`@("`@8V%S92`R.@H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`S.3L@+R\@4F%I;B]$87D*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@+R\@0VQO=60@8V]N9&ET
M:6]N<R!N96%R('1H92!G<F]U;F0*("`@("`@("!I9B`H)&9O9RD@>PH@("`@
M("`@("`@("!R971U<FX@,C`[("\O($9O9PH@("`@("`@('T*("`@("`@("!I
M9B`H)&AA>F4I('L*("`@("`@("`@("`@<F5T=7)N(#(Q.R`O+R!(87IE"B`@
M("`@("`@?0H*("`@("`@("`O+R!#;&]U9"!C;VYD:71I;VYS"B`@("`@("`@
M:68@*"1C;W9E<F%G92`]/2`T*2!["B`@("`@("`@("`@(')E='5R;B`R-CL@
M+R\@36]S=&QY($-L;W5D>0H@("`@("`@('T*("`@("`@("!I9B`H)&-O=F5R
M86=E(#T](#,I('L*("`@("`@("`@("`@<W=I=&-H("@D:7-$87DI('L*("`@
M("`@("`@("`@("`@(&-A<V4@,#H*("`@("`@("`@("`@("`@("`@("!R971U
M<FX@,C<[("\O($UO<W1L>2!#;&]U9'DO3FEG:'0*("`@("`@("`@("`@("`@
M(&-A<V4@,3H*("`@("`@("`@("`@("`@("`@("!R971U<FX@,C8[("\O($UO
M<W1L>2!#;&]U9'D*("`@("`@("`@("`@("`@(&-A<V4@,CH*("`@("`@("`@
M("`@("`@("`@("!R971U<FX@,C@[("\O($UO<W1L>2!#;&]U9'DO1&%Y"B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@:68@*"1C;W9E<F%G92`]
M/2`R*2!["B`@("`@("`@("`@('-W:71C:"`H)&ES1&%Y*2!["B`@("`@("`@
M("`@("`@("!C87-E(#`Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#(Y
M.R`O+R!087)T;'D@0VQO=61Y+TYI9VAT"B`@("`@("`@("`@("`@("!C87-E
M(#$Z"B`@("`@("`@("`@("`@("`@("`@<F5T=7)N(#(V.R`O+R!-;W-T;'D@
M0VQO=61Y"B`@("`@("`@("`@("`@("!C87-E(#(Z"B`@("`@("`@("`@("`@
M("`@("`@<F5T=7)N(#,P.R`O+R!087)T;'D@0VQO=61Y+T1A>0H@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&EF("@D8V]V97)A9V4@/3T@,2D@
M>PH@("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@
M("`@8V%S92`P.@H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@
M("`@("`@("`@(')E='5R;B`S,SL@+R\@2&%Z>2].:6=H=`H@("`@("`@("`@
M("`@("`@8V%S92`R.@H@("`@("`@("`@("`@("`@("`@(')E='5R;B`S-#L@
M+R\@2&%Z>2]$87D*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M+R\@0V%T8V@M86QL<PH@("`@("`@(&EF("@D=VEN9"D@>PH@("`@("`@("`@
M("!R971U<FX@,C,[("\O(%=I;F0*("`@("`@("!]"B`@("`@("`@:68@*"1H
M;W0I('L*("`@("`@("`@("`@<F5T=7)N(#,V.R`O+R!(;W0A"B`@("`@("`@
M?0H@("`@("`@(&EF("@D9G)I9VED*2!["B`@("`@("`@("`@(')E='5R;B`R
M-3L@+R\@1G)I9VED"B`@("`@("`@?0H*("`@("`@("!I9B`H)&YS=RD@>PH@
M("`@("`@("`@("!S=VET8V@@*"1I<T1A>2D@>PH@("`@("`@("`@("`@("`@
M8V%S92`P.@H@("`@("`@("`@("`@("`@8V%S92`Q.@H@("`@("`@("`@("`@
M("`@("`@("\O(%5S92!N:6=H="!F;W(@='=I;&EG:'0@8F5C875S92!T:&4@
M;6]O;B!I<R!G96YE<F%L;'D*("`@("`@("`@("`@("`@("`@("`O+R!O=70@
M=&AE;BP@<V\@:70@=VEL;"!M871C:"!W:71H(&UO<W0@:6-O;B!S971S+@H@
M("`@("`@("`@("`@("`@("`@(')E='5R;B`S,3L@+R\@0VQE87(@3FEG:'0*
M("`@("`@("`@("`@("`@(&-A<V4@,CH*("`@("`@("`@("`@("`@("`@("!R
M971U<FX@,S([("\O($-L96%R($1A>0H@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("!R971U<FX@(FYA(CL*("`@('T*("`@("\O('U]?0I]"B\O
M('U]?0H_/@IU<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<P``````````````
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S(@,#$V,30T`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO
M<&QI8@``````````````````````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,2`P,34V,#4`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]A9&UI;B]S8FEN````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,Q(#`Q-38Q,@`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+W-B:6XO9FEL96UN
M9P``````````````````````````````````````````````````````````
M````````````````````````````````,#`P-34P(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`Q-C$R,#0@,3`U,34T,S0Q,S$@,#$W,C,U`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````']%3$8!`0$)````````
M```"``,``0```&R8!`@T````%-\````````T`"``!0`H`!8`%0`&````-```
M`#2`!`@T@`0(H````*`````%````!`````,```#4````U(`$"-2`!`@5````
M%0````0````!`````0``````````@`0(`(`$"&K8``!JV```!0`````0```!
M````;-@``&QH!0AL:`4(D`(```A````&`````!````(```"0V```D&@%")!H
M!0C(````R`````8````$````+VQI8F5X96,O;&0M96QF+G-O+C$`````80``
M`'0``````````````%,```!#``````````0`````````;P```$D`````````
M`````!````!C````5P```"T```!N````$0````H`````````6````&````!9
M````<```````````````.````$4```!B````7P`````````U`````````%4`
M``!1````;```````````````*0```%H```!D````2P```%X```!Q````00``
M`!P`````````:P```%T```!A````.@````\```!H````+````&T```!G````
M,P````````!,````'P`````````^````1`````P```!I````-P````````!E
M`````````',```!R`````````#T`````````,@`````````E`````````&H`
M``!<````5@```"(```!*````,````"@```!F````````````````````````
M`%`````&```````````````K````5````#L```!(````````````````````
M```````````````````````````````````````````(````````````````
M`````````````````````````!(```````````````T`````````````````
M````````"P`````````#````&@`````````````````````````.````````
M```````@```````````````6````(0```````````````````!<````'````
M`````"\`````````&`````D``````````````````````````````!L````Q
M`````````````````````````#D````!````$P```"H````F````````````
M````````!0```````````````````$8````````````````````"````/```
M`"X````_`````````!T``````````````#0````>````-@```%(`````````
M`````$(`````````(P````````!'````0````!0```!.````%0```"<`````
M````&0```$T````D````````````````````6P```````````````````$\`
M````````````````````````T@$```````"N````$@````L`````````````
M`!(```#:`0```&L%"`0````1`!,`Y`$````````F````$@```.P!````````
M"0,``!(````Z`````````"P````2````0@$```````!<````$@```/(!````
M`````````!(```!&`0```````$P````2``````(`````````````$@```$\!
M```$:P4(!````!$`$P`(`@````````<!```2````(P````````#.````$@``
M`!(```"0:`4(`````!$`\?\/`@```````!X````2````6`$```````"P````
M$@```!@"`````````````!(````?`@```````#T````2````)P(```````!0
M````$@```"X"`````````````!(````U`@`````````````2````7P$`````
M``"(`0``$@```#P"````````F@```!(```!!`@`````````````2````2`(`
M``````!,`0``$@```&4!```(:P4(!````!$`$P"]`0```````-,````2````
M3P(`````````````$@```&\!`````````````!(```!4`@```````)$!```2
M````&P`````````C````$@```"(`````````Y@```!(```!;`@```````"``
M```2````8@(`````````````$@```'8!`````````````!(```!H`@``````
M`&@````2````+`````````"?````$@```'`"````````>`0``!(````V`@``
M```````````2````&0(`````````````$@```#,````XD@0(`````!(`!P!Y
M`@`````````````2````?0$``!!K!0A4#```$0`3`'X"`````````````!(`
M``"0`0`````````````2````A0(```````#_````$@```)@!````````9P``
M`!(```".`@`````````````2````G```````````````$@```)4"``!HJ`4(
M!````!$`$P"=`@`````````````2````.0`````````G````$@```*,"````
M`````````!(```!!```````````````2````2```````````````(````$("
M`````````````!(```"H`@```````$`````2````LP(````````D````$@``
M`+@"``!L:`4(!````!$`#`##`@`````````````2````R0(```````!O````
M$@```&``````````%P```!(```#0`@`````````````2````U@(`````````
M````$@```&D``````````````!(```#U`````````'X````2`````0$`````
M````````$@````D!````````-0```!(```#=`@`````````````2````GP$`
M```````F````$@```!$!``!D=P4(!````!$`$P#D`@`````````````2````
MIP$```````#?````$@```.D"````````,````!(````D`0```````#H````2
M````:``````````O`0``$@```(\"`````````````!(```!T````:'<%"`0`
M```1`!,`;@````````"K````$@```&8#``#\:@4(`````!``\?^!````````
M```````2````[P(````````%````$@```(@`````````0@$``!(```#Y`@``
M`````"(````2````+`$`````````````$@````$#````````'@```!(````*
M`P```````',%```2````$0,````````>````$@```(\```!$&`4(`````!(`
M"@!*`P```````*4````2````&@,````````K````$@```"$#````````*```
M`!(```"5`````````*H````2````G@(`````````````$@```)L`````````
MMP```!(```!?`P``_&H%"``````0`/'_H@```&QI!0@`````$0#Q_W(#``!T
MJ`4(`````!``\?\S`P```````$0````2````*0,````````>````$@```*X!
M````````9@```!(````R`P`````````````2````;P``````````````$@``
M`+4!`````````````!(```"\`0```````*H````2````.`,`````````````
M$@```#\#````````O0```!(```"X```````````````@````2`,```````#P
M````$@```,(!`````````````!(```!2`P`````````````2````60,`````
M````````$@```,P``````````````"````")```````````````2````X@``
M```````C````$@````!L:6)Z+G-O+C,`<W1R8W!Y`%]$64Y!34E#`&UA;&QO
M8P!V<VYP<FEN=&8`9F9L=7-H`%]I;FET`&9P<FEN=&8`<W1R8V%T`%]?9&5R
M96=I<W1E<E]F<F%M95]I;F9O`%]?97)R;W(`9G)E860`9F]P96X`7U]I<W1H
M<F5A9&5D`&UE;7-E=`!F8VQO<V4`7V9I;FD`9G!U=&,`9G=R:71E`%]'3$]"
M04Q?3T9&4T547U1!0DQ%7P!?2G9?4F5G:7-T97)#;&%S<V5S`%]?<F5G:7-T
M97)?9G)A;65?:6YF;P!F<F5E`&QI8F-R>7!T+G-O+C,`7U]?<G5N971Y<&4`
M<W1R;F-M<`!S=')N8W!Y`%]#=7)R96YT4G5N94QO8V%L90!S=')N8V%T`'-T
M<F-M<`!L:6)C<GEP=&\N<V\N-`!-1#4`<W1R97)R;W(`7U]S=&1I;G``9V5T
M96YV`&9G971S`%]?<W1D97)R<`!G971U:60`<V5L96-T`%]$969A=6QT4G5N
M94QO8V%L90!S=')R8VAR`&-A;&QO8P!R96%L;&]C`'-S8V%N9@!F:6QE;F\`
M<W1R8VAR`&9P=71S`&9C;G1L`&QI8F,N<V\N-@!P=71C:&%R`%]?<W1D;W5T
M<`!W86ET<&ED`'!O<&5N`&=E=&1T86)L97-I>F4`9V5T975I9`!P8VQO<V4`
M9V5T9W)G:60`9F-H;6]D`%]?<W)G970`=7-L965P`&5X96-V90!F8VAO=VX`
M9V5T8P!F8VAD:7(`<&5R<F]R`&1U<#(`<WES=&5M`&UK=&5M<`!R;61I<@!R
M96%D9&ER`')E86QP871H`'!I<&4`<F5N86UE`&)A<V5N86UE`')I;F1E>`!E
M;G9I<F]N`&9S=&%T`&MI;&P`:6YI=&=R;W5P<P!W86ET`%]?<')O9VYA;64`
M;'-T870`<W1R<W1R`&9L;V-K`'-E=&=I9`!U;FQI;FL`9F]R:P!E>&5C=@!?
M:6YI=%]T;',`;W!E;F1I<@!G971P=W5I9`!G971C=V0`9V5T<'=N86T`871E
M>&ET`&UK<W1E;7``9V5T9W)N86T`7V5X:70`<V5T<VED`&-L;W-E9&ER`'9A
M<W!R:6YT9@!S971U:60`;6MD:7(`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M``!K!0@%`P``!&L%"`4+```(:P4(!1H``!!K!0@%*P``9'<%"`5'``!H=P4(
M!4X``'AI!0@'`0``?&D%"`<"``"`:04(!P0``(1I!0@'!0``B&D%"`<&``",
M:04(!P<``)!I!0@'"```E&D%"`<)``"8:04(!PH``)QI!0@'#```H&D%"`<-
M``"D:04(!P\``*AI!0@'$```K&D%"`<1``"P:04(!Q(``+1I!0@'$P``N&D%
M"`<4``"\:04(!Q4``,!I!0@'%@``Q&D%"`<7``#(:04(!Q@``,QI!0@'&0``
MT&D%"`<;``#4:04(!QP``-AI!0@''0``W&D%"`<>``#@:04(!Q\``.1I!0@'
M(```Z&D%"`<A``#L:04(!R(``/!I!0@'(P``]&D%"`<D``#X:04(!R4``/QI
M!0@')@```&H%"`<G```$:@4(!R@```AJ!0@'*@``#&H%"`<L```0:@4(!RT`
M`!1J!0@'+@``&&H%"`<O```<:@4(!S```"!J!0@',0``)&H%"`<S```H:@4(
M!S0``"QJ!0@'-0``,&H%"`<V```T:@4(!S@``#AJ!0@'.0``/&H%"`<Z``!`
M:@4(!SP``$1J!0@'/0``2&H%"`<^``!,:@4(!S\``%!J!0@'0```5&H%"`=!
M``!8:@4(!T(``%QJ!0@'0P``8&H%"`=$``!D:@4(!T4``&AJ!0@'1@``;&H%
M"`=(``!P:@4(!TD``'1J!0@'2@``>&H%"`=+``!\:@4(!TP``(!J!0@'30``
MA&H%"`=/``"(:@4(!U$``(QJ!0@'4@``D&H%"`=3``"4:@4(!U0``)AJ!0@'
M50``G&H%"`=6``"@:@4(!U<``*1J!0@'6```J&H%"`=:``"L:@4(!UL``+!J
M!0@'7```M&H%"`==``"X:@4(!UX``+QJ!0@'7P``P&H%"`=C``#$:@4(!V0`
M`,AJ!0@'90``S&H%"`=F``#0:@4(!V<``-1J!0@':```V&H%"`=I``#<:@4(
M!VH``.!J!0@':P``Y&H%"`=M``#H:@4(!VX``.QJ!0@';P``\&H%"`=P``#T
M:@4(!W(``/AJ!0@'<P``@^P,Z`P'``#HVX4``(/$#,,```#_-7!I!0C_)71I
M!0@`````_R5X:04(:`````#IX/____\E?&D%"&@(````Z=#_____)8!I!0AH
M$````.G`_____R6$:04(:!@```#IL/____\EB&D%"&@@````Z:#_____)8QI
M!0AH*````.F0_____R60:04(:#````#I@/____\EE&D%"&@X````Z7#_____
M)9AI!0AH0````.E@_____R6<:04(:$@```#I4/____\EH&D%"&A0````Z4#_
M____):1I!0AH6````.DP_____R6H:04(:&````#I(/____\EK&D%"&AH````
MZ1#_____);!I!0AH<````.D`_____R6T:04(:'@```#I\/[___\EN&D%"&B`
M````Z>#^____);QI!0AHB````.G0_O___R7`:04(:)````#IP/[___\EQ&D%
M"&B8````Z;#^____)<AI!0AHH````.F@_O___R7,:04(:*@```#ID/[___\E
MT&D%"&BP````Z8#^____)=1I!0AHN````.EP_O___R78:04(:,````#I8/[_
M__\EW&D%"&C(````Z5#^____)>!I!0AHT````.E`_O___R7D:04(:-@```#I
M,/[___\EZ&D%"&C@````Z2#^____)>QI!0AHZ````.D0_O___R7P:04(:/``
M``#I`/[___\E]&D%"&CX````Z?#]____)?AI!0AH``$``.G@_?___R7\:04(
M:`@!``#IT/W___\E`&H%"&@0`0``Z<#]____)01J!0AH&`$``.FP_?___R4(
M:@4(:"`!``#IH/W___\E#&H%"&@H`0``Z9#]____)1!J!0AH,`$``.F`_?__
M_R44:@4(:#@!``#I</W___\E&&H%"&A``0``Z6#]____)1QJ!0AH2`$``.E0
M_?___R4@:@4(:%`!``#I0/W___\E)&H%"&A8`0``Z3#]____)2AJ!0AH8`$`
M`.D@_?___R4L:@4(:&@!``#I$/W___\E,&H%"&AP`0``Z0#]____)31J!0AH
M>`$``.GP_/___R4X:@4(:(`!``#IX/S___\E/&H%"&B(`0``Z=#\____)4!J
M!0AHD`$``.G`_/___R5$:@4(:)@!``#IL/S___\E2&H%"&B@`0``Z:#\____
M)4QJ!0AHJ`$``.F0_/___R50:@4(:+`!``#I@/S___\E5&H%"&BX`0``Z7#\
M____)5AJ!0AHP`$``.E@_/___R5<:@4(:,@!``#I4/S___\E8&H%"&C0`0``
MZ4#\____)61J!0AHV`$``.DP_/___R5H:@4(:.`!``#I(/S___\E;&H%"&CH
M`0``Z1#\____)7!J!0AH\`$``.D`_/___R5T:@4(:/@!``#I\/O___\E>&H%
M"&@``@``Z>#[____)7QJ!0AH"`(``.G0^____R6`:@4(:!`"``#IP/O___\E
MA&H%"&@8`@``Z;#[____)8AJ!0AH(`(``.F@^____R6,:@4(:"@"``#ID/O_
M__\ED&H%"&@P`@``Z8#[____)91J!0AH.`(``.EP^____R68:@4(:$`"``#I
M8/O___\EG&H%"&A(`@``Z5#[____):!J!0AH4`(``.E`^____R6D:@4(:%@"
M``#I,/O___\EJ&H%"&A@`@``Z2#[____):QJ!0AH:`(``.D0^____R6P:@4(
M:'`"``#I`/O___\EM&H%"&AX`@``Z?#Z____);AJ!0AH@`(``.G@^O___R6\
M:@4(:(@"``#IT/K___\EP&H%"&B0`@``Z<#Z____)<1J!0AHF`(``.FP^O__
M_R7(:@4(:*`"``#IH/K___\ES&H%"&BH`@``Z9#Z____)=!J!0AHL`(``.F`
M^O___R74:@4(:+@"``#I</K___\EV&H%"&C``@``Z6#Z____)=QJ!0AHR`(`
M`.E0^O___R7@:@4(:-`"``#I0/K___\EY&H%"&C8`@``Z3#Z____)>AJ!0AH
MX`(``.D@^O___R7L:@4(:.@"``#I$/K___\E\&H%"&CP`@``Z0#Z____)?1J
M!0AH^`(``.GP^?___R7X:@4(:``#``#IX/G__U6)Y5=64X/L#(/D\(M=!(G7
MC72=#(7;B35HJ`4(?B2+10B%P'0=HVQH!0B)P8H!A,!T$)`\+XU1`71%B=&*
M`83`=?&XD&@%"(7`=#Z#[`Q7Z&O^__^#Q!"#[`QH1!@%".A;_O__Z&+Y__]0
M5HU%"%!3Z"X&``"#Q!10Z)'^__^0B=&)%6QH!0CKL^BQ_?__Z\>0D)!5B>6#
M[`B`/6QW!0@`=`_K.(UV`(/`!*-T:`4(_]*A=&@%"(L0A=)UZ[@`````A<!T
M$(/L#&B,:`4(Z,%F^_>#Q!#&!6QW!0@!R<.05;@`````B>6#[`B%P'05@^P(
M:'!W!0AHC&@%".B39OOW@\00H6AI!0B%P'0;N`````"%P'02@^P,:&AI!0CH
M<6;[]X/$$(GVR<.0D%6)Y8U5F(/L<%+_=0CHLOW__X/$$$`/E,`/ML#)PXGV
M58GE5U93@>R`$```BU4,9HF5AN____PQP+^:&`4(N?_____RKO?1N`$0```I
MR%#_=0B-M>CO__]6Z`;\__];7XV]B.___U=6Z%?]__^#Q!"#^/^)PP^$H0``
M`(L=;*@%"(7;='2#[`QF@[V&[___`'5RBX6X[___BY6\[___4E#_M:CO__]6
M:*P8!0CH4_C__X/$%/^UF.___^@]0```@\0,4%;_M93O___HR3\``%E;4&BY
M&`4(Z"CX__]8#[>UD.___UJ!YO\!``!6:,`8!0CH#OC__X/$$(UE]%M>,<!?
MR<.0BX7`[___BY7$[___#Z3""<'@">N%C78`@^P(5U;HOOK__X/$$(7`=14/
MMXV0[___@>$`\```@?D`H```="J#[!#HNOK__UK_,.CB]___@\004&C&&`4(
M:@%J`>B@>P``@\00Z0_____\43'`B=F_FA@%"/*N]]%)46B:&`4(5N@\^___
M@\00Z>O^__]5B>575E.#['B+70A3BWT,Z(_[__^#Q!"%P(G&#X1"`0``@^P,
M4^CY^?__D(/$$(/L#%;H[/C__X/$$(7`#X0.`0``@^P(C56(4HU8"%/HX?O_
M_X/$$$`/A)\```"+59")T"4`\```/0!```!U<HL5<*@%"(72=+>#[`QFA?]T
M=(M%P(M5Q`^DP@G!X`E24/]UJ%-HK!@%".C7]O__@\04_W68Z,0^``"#Q`Q0
M4/]UE.A3/@``65M0:+D8!0CHLO;__P^W79!86H'C_P$``%-HP!@%".B;]O__
MZ4[___^)]H/L"`^_SU%3Z*/]___I.O___XGVBT6XBU6\ZY&#[`B-18A04^A+
M^?__@\00A<!U%XM5D(G1@>$`\```@?D`H```#X0Y____@^P0Z$7Y__]:_S#H
M;?;__X/$$%!HQA@%"&H!:@'H*WH``(/$$.D,____@^P,5NAZ^___C67T6UXQ
MP%_)PX/L$.@(^?__6?\PZ##V__^#Q!!0:-<8!0AJ`6H!Z.YY``"#Q!#IE/[_
M_XGV58GE5U93@>R,````BT409HE%AL<%;*@%"`````#'!7"H!0@`````_(MU
M"+_K&`4(N08```#SIG5;QP5LJ`4(`0```(/L"(U5B%+_=0SH4OK__X/$$$!T
M<P^W79"!XP#P``"!^P!````/A)H```"#[`@/OWV&5_]U#.B"_/__@\00A<`/
MA9L```"-9?1;7C'`7\G#D+L%````_(MU"+_Q&`4(B=GSI@^%D````,<%<*@%
M"`$```"#[`B-58A2_W4,Z-_Y__^#Q!!`=8V#[!#H$?C__UO_,.@Y]?__@\00
M4&C&&`4(:@%J`>CW>```#[==D('C`/```(/$$('[`$````^%:/___XGV@^P(
M#[]%AE#_=0SH6/W__X/$$(7`#X1F____D(/L#&H!Z(YW``"#Q!"-9?1;7C'`
M7\G#D/R+=0B_]A@%"(G9\Z9U&<<%;*@%"`$```#'!7"H!0@!````Z5+___]6
M:``:!0AJ`6H!Z'%X``"#Q!#IR/[__Y!5B>575E.-G>CO__^![!`0``#\ON(;
M!0BY!P```(G?\Z5FI6CB#P``:@"-A0;P__]0Z#+X__]8BT40A<!T8E#_=0QH
M^Q@%"&@`$```4^AV]/__@\044^BM^/__@\00@_C_=&"#[`Q0Z*SY__]?6%/_
M=0CH]20``(/$$(7`=2F#[`AHI`$``%/HS/7__XD<).CT]/__,<"-9?1;7E_)
MPXGVN`@9!0CKEX/L#%/_=0AH)!H%"&H!:@#HK'<``+C_____Z]-0:$@:!0AJ
M`6H`Z)9W``"X_____^N]C78`58GE5U93@>SL!```BU4,@^3P@^P0BP+'A7S[
M__\`````QX5X^___`````&;'A7;[__\``*-DJ`4(Z&X(``#HB?3__X/L"&H`
M:!89!0B)P^A4.```@\00.<-T#>AL]/__A<`/A8<"``#H7_/__X7`#X2P`0``
M@WT(`@^.C0$``(M5#(M:!(M""(F%@/O___RY!0```+X=&04(B=_SI@^%3@$`
M`(-]"`1^%+D*````OB(9!0B+O8#[___SIG024&@M&04(:@%J`>C`=@``@\00
MNP,```#\B[6`^___OTL9!0B)V?.F#X6A````QX5\^___1AD%"+H"````ZPR0
MBW4,BPR6B4R6^$([50A\\(M%"(M=#,=$@_@`````Z/WU__^%P(G&#X0:`0``
M4&H"C96$^___4E;H,_+__X/$$$`/A&`!``"+E83[__^)T(/@?W1C@_A_=`B%
MP`^%O`$``(G7@^=_@_]_#X34`0``@^P,:@KHU_'__\<$)`````#HXW0``(UE
M]%M>,<!?R</\N00```"+M8#[__^_4QD%"/.F#X41`0``QX5\^___3AD%".E!
M____P?H(A=)TL?^U?/O__VAL&@4(:@!J`>B^=0``@\00@^P,:@KH<?'__\<$
M)`````#H?70``(UE]%M>,<!?R</HUO'__X7`#X71_O__@^P,4^B5%0``Z<#^
M____=0AHD!H%"&H!:@'H;W4``(/$$.E:_O__@^P,:@#H[?;__\<$)`````#H
M<?3__X/$$.DR_O__@^P(:@)J`>AM\O__Z%CQ__^#Q!"#^`.-6/]^%9"#[`Q3
MZ-/V__^)V(/$$$N#^`-_[%#_=1#_=0S_M7S[___HQO'__X/$$%!J`HV5A/O_
M_U)6Z-/P__^#Q!!`#X6@_O__@^P,:@'HMW,``(/$$.F._O___(NU@/O__[]G
M&04(B=GSIG1#_(NU@/O__[]<&04(N08```#SI@^%@@```,>%?/O__U<9!0CI
M!?[__V@6&04(:-`:!0AJ`6H!Z(IT``"#Q!#I7OW__\>%?/O__V(9!0CIV_W_
M_X/L#%#_M7S[__]H&!L%"&H`:@'H6W0``(/$((N5A/O__^D>_O__@^P,P?H(
M4O^U?/O__VA4&P4(:@!J`>@R=```@\0@Z0G^___\B[6`^___OWX9!0B)V?.F
M="3\B[6`^___OW,9!0BY!@```/.F=1['A7S[__]J&04(Z5S]___'A7S[__]Y
M&04(Z4W]___\B[6`^___OX89!0B)V?.F=0_'A7S[__^!&04(Z2S]___\B[6`
M^___OXX9!0BY!@```/.F=0_'A7S[__^)&04(Z0C]___\B[6`^___OYD9!0BY
M!@```/.F=0_'A7S[__^4&04(Z>3\__^[!0```/R+M8#[__^_$1D%"(G9\Z9U
M#\>%?/O__Y\9!0CIOOS___R+M8#[__^_K1D%"(G9\Z9U4(-]"`1^2HM=#(MS
M%+D,````O[(9!0CSIG4)9L>%=OO__P$`5P^_E7;[__]2BT4,_W`0_W`,Z";Y
M___'!"0`````Z-9Q``"#Q!#I7OS__XGV_+D,````B[6`^___O[X9!0CSIG4*
M@WT(!`^$GP```/RY"P```(NU@/O__[\B&04(\Z9U-(-]"`1^+HM=#(-]"`:+
M0PR+4Q!U"8M[%(F]>/O__U'_M7C[__]24.@L^O__B00DZXR-=@#\N0D```"+
MM8#[__^_RAD%"/.F=0:#?0@$='/\N04```"+M8#[__^_TQD%"/.F=0J#?0@%
M#X2#````_[6`^___:)`;!0AJ`6H!Z#YR``"#Q!#IGOO__X/L"(V]B/O__\<%
M;*@%"`````!7BU4,_W(,Z-?R__]`6P^4P%X/MMA3:-@9!0CH`^[__^GT_O__
M@^P(BU4,C87H^___BW(,4%;HN.___XD$)(G#Z#9,``"#Q!"%P'135FB\&P4(
MZXB+70R+<PRY#````+^R&04(\Z9U"6;'A7;[__\!`(/L"(M]#`^_E7;[__^+
M7Q!24^A/`0``B=&)PB'(@\000'494VC<&04(Z3W___^#[`Q3Z)ON___I;/[_
M_U!14FCY&04(Z6'___^058GE5U93@>R(````BT4(:.,K!0AFB46&Z'OQ__^)
M18"+38`Q]C'_@\00,<`QTH7)#X2A````B?:#[`S_=8#HU>[__X/$$(7`#X2Z
M````@'@(+HU8"'41BD,!A,!TVCPN#X2"````B?:#[`B-58A24^C3[___@\00
MA<!XO&:#?88`=%T#=<`3?<0/MTV0@>$`\```@?D`0```=9V#[`Q3Z'3O__^#
MQ!"%P'B-@^P,#[]=AE/H2/___P'&$=?'!"3B*P4(Z%#O__^#Q!"%P`^)9?__
M_XGPB?J-9?1;7E_)PY`#=;@3?;SKH8![`@`/A7;___^#[`S_=8#H&^[__X/$
M$(7`#X5&____@^P,_W6`Z+7Q__^)\(GZZ[Z-=@!5B>575E.![)0```"-18A0
MBU4,_W4(9HE5AL=%@``0``#H!N___X/$$(7`NO____^Y_____W@U9H-]A@!U
M.@^W39"!X0#P``"!^0!```"+=;B+?;QT.HGPB?IF@WV&`'0'#Z3""<'@"8G1
MB<*-9?1;7HG07XG*R<,/MTV0@>$`\```@?D`0```BW7`BWW$=<:#[`QH`!``
M`.@/[?__@\00A<")P[K_____N?____]TO(/L"/]U@%/H\.___X/$$(7`=3^#
M[`B!18``$```_W6`4XF=?/___^CP[O__@\00A<")PW7+@^P,_[5\____Z!GQ
M__^Z_____[G_____Z6K___^#[`S_=0CH[^W__X/$$(7`>%&#[`P/OT6&4.C#
M_?__B85P____`;5P____B95T____$;UT____B1PDZ+OM__^#Q!"%P'@=@^P,
M4^B[\/__@\00BX5P____BY5T____Z?7^__^#[`Q3ZX.058GE5U93@^QLH1QX
M!0B%P'0*C67T6UY?R<.)]H/L#&CE*P4(Z`,B``"#Q!"%P(G##X2B"```@#@`
M#X29"```@^P,B1T<>`4(:/0K!0CHVB$``(/$$(7`B<-T!8`X`'425VBH+@4(
M:@%J`>AQ;@``@\00@^P,B1T4>`4(:`,L!0CHIR$``(/$$(7`B<-T!8`X`'42
M5FC,+@4(:@%J`>@^;@``@\00@^P,B1T0>`4(:!`L!0CH="$``(/$$(7`B<-T
M!8`X`'4246CP+@4(:@%J`>@+;@``@\00@^P,B1T,>`4(:"`L!0CH02$``(/$
M$(7`B<-T!8`X`'424F@4+P4(:@%J`>C8;0``@\00@^P,B1T(>`4(:"PL!0CH
M#B$``(/$$(7`B<-T!8`X`'424&@T+P4(:@%J`>BE;0``@\00@^P,B1T$>`4(
M:#DL!0CHVR```(/$$(7`B<-T!8`X`'424&A8+P4(:@%J`>AR;0``@\00@^P,
MB1T`>`4(:$LL!0CHJ"```(/$$(7`B<-T!8`X`'424&A5+`4(:@%J`>@_;0``
M@\00@^P,B1W\=P4(:',L!0CH=2```(/$$(7`B<-T!8`X`'424&B`+P4(:@%J
M`>@,;0``@\00@^P,B1WX=P4(:($L!0CH0B```(/$$(7`B<-T!8`X`'46:($L
M!0AHI"\%"&H!:@'HU6P``(/$$(/L#(D=]'<%"&B,+`4(Z`L@``"#Q!"%P(G#
M=`6`.`!U$E!HU"\%"&H!:@'HHFP``(/$$(/L#(D=\'<%"&B=+`4(Z-@?``"#
MQ!"%P(G#=`6`.`!U$E!HIBP%"&H!:@'H;VP``(/$$(/L#(D=Z'<%"&C#+`4(
MZ*4?``"#Q!"%P(G#=`6`.`!U$E=HS2P%"&H!:@'H/&P``(/$$(/L#(D=Y'<%
M"&CK+`4(Z'(?``"#Q!"%P(G#=`6`.`!U$E9H_"\%"&H!:@'H"6P``(/$$(/L
M#(D=X'<%"&CW+`4(Z#\?``"#Q!"%P(G#=`6`.`!U$E%H'#`%"&H!:@'HUFL`
M`(/$$(/L#(D=W'<%"&@#+04(Z`P?``"#Q!"%P(G#=`6`.`!U$E)H/#`%"&H!
M:@'HHVL``(/$$(/L#(D=V'<%"&@/+04(Z-D>``"#Q!"%P(G#=`6`.`!U$E!H
M7#`%"&H!:@'H<&L``(/$$(/L#(D=U'<%"&@<+04(Z*8>``"#Q!"%P(G#=`6`
M.`!U$E!H@#`%"&H!:@'H/6L``(/$$(/L#(D=T'<%"&@K+04(Z',>``"#Q!"%
MP(G#=`6`.`!U$E!HI#`%"&H!:@'H"FL``(/$$(/L#(D=S'<%"&@Y+04(Z$`>
M``"#Q!"%P(G#=`6`.`!U$E!HR#`%"&H!:@'HUVH``(/$$(/L#(D=R'<%"&A&
M+04(Z`T>``"#Q!"%P(G#=`6`.`!U$E!H32T%"&H!:@'HI&H``(/$$(/L#(D=
M['<%"&AH+04(Z-H=``"#Q!"%P(G#=`6`.`!U$E!H[#`%"&H!:@'H<6H``(/$
M$(/L#(D=Q'<%"&AV+04(Z*<=``"#Q!"%P(G#=`6`.`!U$E=H$#$%"&H!:@'H
M/FH``(/$$(/L#(D=P'<%"&B#+04(Z'0=``"#Q!"%P(G#=`6`.`!U$E9H-#$%
M"&H!:@'H"VH``(/$$(/L#(D=O'<%"&B/+04(Z!$@``"CN'<%"%E;:``0``!J
M`>@BZ/__,=N^_____XL5''@%"(E%C(E5\*.T=P4(_(G7B-B)\?*N]]&#Q`Q)
M4?]U\/]UC.@/Z?__6%IHHRT%"/\UM'<%".@]Z/__65]H`!```&H!Z,_G__^+
M%1QX!0B)18R)5>BCL'<%"/R)UXC8B?'RKO?1@\0,25%2_W6,Z,7H__]86FBX
M+04(_S6P=P4(Z//G__]97V@`$```:@'HA>?__XL5''@%"(E%C(E5X*.L=P4(
M_(G7B-B)\?*N]]&#Q`Q)4?]UX/]UC.AYZ/__6%IHRBT%"/\UK'<%".BGY___
M65]H`!```&H!Z#GG__^+%1QX!0B)18R)5=BCJ'<%"/R)UXC8B?'RKO?1@\0,
M25'_==C_=8SH+>C__UA::-TM!0C_-:AW!0CH6^?__UE?:``0``!J`>CMYO__
MBQ4<>`4(B46,B570HZ1W!0C\B=>(V(GQ\J[WT8/$#$E1_W70_W6,Z.'G__]8
M6FCP+04(_S6D=P4(Z`_G__]97V@`$```:@'HH>;__XL5''@%"(E%C(E5R*.@
M=P4(_(G7B-B)\?*N]]&#Q`Q)4?]UR/]UC.B5Y___6%IH!BX%"/\UH'<%".C#
MYO__65]H`!```&H!Z%7F__^+%1QX!0B)18R)5<"CG'<%"/R)UXC8B?'RKO?1
M@\0,25'_=<#_=8SH2>?__UA::!LN!0C_-9QW!0CH=^;__UE?:``0``!J`>@)
MYO__BQ4<>`4(B46,B56XHYAW!0C\B=>(V(GQ\J[WT8/$#$E1_W6X_W6,Z/WF
M__]86F@O+@4(_S68=P4(Z"OF__]97V@`$```:@'HO>7__XL5''@%"(E%C(E5
ML*.4=P4(_(G7B-B)\?*N]]&#Q`Q)4?]UL/]UC.BQYO__6%IH1"X%"/\UE'<%
M".C?Y?__65]H`!```&H!Z''E__^+%1QX!0B)18R)5:BCD'<%"/R)UXC8B?'R
MKO?1@\0,25'_=:C_=8SH9>;__UA::%8N!0C_-9!W!0CHD^7__UE?:``0``!J
M`>@EY?__BQ4<>`4(B46,B56@HXQW!0C\B=>(V(GQ\J[WT8/$#$E1_W6@_W6,
MZ!GF__]86FAK+@4(_S6,=P4(Z$?E__]?6&@`$```:@'HV>3__X/$#*.(=P4(
M:``0``#_-1QX!0A0Z.#E__^+%8AW!0B)59B)U_R(V(GQ\J[WT;\`$```@\0,
M*<]7:(`N!0C_=9CH%.;__XL5''@%"(E5D(G7_(C8B?'RKO?1@\$1B0PDZ)7C
M__]97O\U''@%"%")P^CUX?__6%IHE2X%"%/HN.3__XD=&'@%"(UE]%M>7\G#
MB?90:%0Q!0AJ`6H!Z/EE``"#Q!#I4/?__Y!5B>575E.![`P0``"+70B%V[X0
M)P``=!T/OA.!^O\```!W6J%D=P4(BT20-"4`!0``A<!U$U!H=S$%"&H!:@'H
MK&4``(/$$)"#[`Q&5NCNY?__@\00A<!U[X'^_/\``'8J4&B),04(:@!J`.B`
M90``C67T6UZX`0```%_)PX/L#%+HJN3__X/$$.NA:)DQ!0AHJ#$%"/]U#%93
M:&0T!0AH`!```(V=Z.___U/HH.'__X/$%%/HA^+__X/$$(7`B<=T"HGXC67T
M6UY?R<.#[`QHKS$%".B#)P``68G#6&CH`0``_W4,Z*;F__^#Q`Q35O]U#.C9
MXO__6%IHZ`$``/]U#.C:XO__@\00B?CKMXUV`%6)Y5=64X'L("```/R^$C@%
M"+D&````C;WH[___QX7DW___`0```/.EI&CG#P``:@"-A0'P__]0Z*/D__^#
M[`C_=0S_=0CHU>3__X/$(#'2A<`/A.0!``"+50B%TG15BUT(#[X3@?K_````
M#X;5`0``@^P,4NBFX___@\00)0`%``"%P'0NBWT,A?]T)XMU#`^^%H'Z_P``
M``^&Z@$``(/L#%+H>./__X/$$"4`!0``A<!U$E!HMS$%"&H!:@'H'60``(/$
M$/]U"&C4,04(:``0``"-M>C?__]6Z&'@__];7V@$+@4(5NCDW___@\00A<")
MPP^$GP$``(/L#(V5Z.___U+H>.3__X/$$(7`B87@W___=3'I20$``(GVQX7D
MW___`````/PQP+G_____4HGW\J[WT4E15O^UX-___^C]X?__@\004%-H`!``
M`%;H;>#__X/$$(7`=#F+O>3?__^%_W3"@+WHW___(W6O@+WIW___('30@+WJ
MW___"G6=4%-H`!```%;H-.#__X/$$(7`=<?_=0AHYS$%"&@`$```5NB:W___
MB30DZ(+@__]8_W4,_W4(:)PT!0AH`!```%;H>]___X/$%%;H8N#__X/$#&C`
M-`4(:``0``!6B<?H7=___XDT).A%X/__@\00A?]U8H/L#(V5Z.___U+_=0QH
M!3(%"&@`$```5N@QW___@\045N@8X/__B1PDZ!#?__]8_[7@W___C9WH[___
MZ%[D__^)'"3H%N+__XGZC67T6UZ)T%_)PZ%D=P4(BT20-.DI_O__@^P,C8WH
M[___4?]U".N<@^P,4^C$WO__C87H[___4&CH-`4(:@%J`>A?8@``@\0@Z;W^
M__^+#61W!0B+1)$TZ1/^____=0AH+#4%"&H!:@'H-V(``(/$$.E(_O__C78`
M58GE5U93@>Q\$```BUT(A=MT30^^$X'Z_P````^'W@```*%D=P4(BT20-"4`
M!0``A<!T+(M]#(7_="6+30P/OA&!^O\````/A_L```"+-61W!0B+1)8T)0`(
M``"%P'425F@:,@4(:@%J`>B]80``@\00@^P(C46(4/]U#.AKXO__@\00A<`/
ME,(/MO*%]G0<BU64BTV8BWV0B96$[___B8V`[___9HF]?N___X/L#/]U#%-H
M6#4%"(V=B.___V@`$```4^C#W?__@\044^BJWO__@\0,:,`T!0AH`!```%.)
MQ^BEW?__B1PDZ(W>__^#Q!"%]G4>C67T6UZ)^%_)PX/L#%+H8^#__X/$$.D:
M____C78`4?^U@.____^UA.____]U#.CCWO__6`^WM7[O__]:5O]U#.CAWO__
M@\00C67T6UZ)^%_)PX/L#%+H&^#__X/$$.G^_O__C78`58GE5E.![``0``"+
M70B%VXMU#'1'#[X3@?K_````#X>4````H61W!0B+1)`T)0`%``"%P'0FA?9T
M(@^^%H'Z_P````^'@P```(L-9'<%"(M$D30E``@``(7`=1)0:#<R!0AJ`6H!
MZ&5@``"#Q!"#[`Q64VB`-04(C9WX[___:``0``!3Z*?<__^#Q!13Z([=__^#
MQ`QHP#0%"&@`$```4XG&Z(G<__^)'"3H<=W__XUE^%N)\%[)PX/L#%+H3]__
M_X/$$.ED____C78`@^P,4N@[W___@\00Z7;___^-=@!5B>53@^P4C4WXBUT(
MQT7P_____\=%]/____^-5?114HU%\%!3Z'X@``"#Q!!`#X0$`0``@^P,_W7X
MZ&'>__^#Q!!`#X07`0``BT7P/?,!``!V08/L"/]U]%/H4=[__X/$$$!T4X/L
M#/]U].B@WO__@\00A<!U>8/L#/]U\.C^X/__@\00A<`/A8\````QP(M=_,G#
M4&BD-04(:@%J`>A-7P``@\00@^P(_W7T4^C^W?__@\000'6M@^P0Z##>__]:
M_S#H6-O__XD$)%-HR#4%"&H!:@'H%E\``(/$((/L#/]U].@HWO__@\00A<!T
MB)#_=?1H4C(%"&H!:@'H[UX``(/$$(/L#/]U\.AQX/__@\00A<`/A'/___^)
M]O]U\&AH,@4(:@%J`>C#7@``@\00,<"+7?S)PY!3:'XR!0AJ`6H!Z*E>``"#
MQ!"#[`S_=?CH2]W__X/$$$`/A>K^__^0@^P,_W7X4VB0,@4(:@%J`>A[7@``
M@\0@Z<S^__^-=@!5B>564X/L$(MU".CPW?__A<")PG4BZ*7?__]`=7^#[`QH
MKC(%".A5V___QP0D`P```.A)W___D%-J`HU%]%!2Z`O:__^#Q!!`#X3?````
MBU7TB="#X']T)X/X?W0(A<`/A0,!``")T8/A?X/Y?P^$Y@```#'`C67X6U[)
MPXUV`,'Z"(72=.U6:/0U!0AJ`&H`Z-I=``"X_____^O9@^P(:@)HOC(%".CD
MWO__B</'!"0`````Z&;?___'!"0!````Z%K?___'!"0"````Z$[?__]96&H`
M4^C$VO__6%IJ`5/HNMK__UE8:@)3Z+#:__^)'"3H*-___XDT).B`_?__6%IJ
M#VK_Z/7;___'!"00)P``Z`G:__]>6&H):O_HWMO__\<$)`````#H4M[__X/L
M$.@ZW/__6?\PZ&+9__^)!"16:!0V!0AJ`&H`Z"!=``"X_____^D<____@^P,
MP?H(4E9H2#8%".O>@^P,4%9HB#8%".O2C78`58GE5U93@>P,$```BW4(A?:+
M?0QT'0^^%H'Z_P```'=#H61W!0B+1)`T)0`%``"%P'424&C(,@4(:@%J`>BV
M7```@\00@^P,5N@:W?__@\00,=*%P'4=C67T6UZ)T%_)PXUV`(/L#%+HR]O_
M_X/$$.NXB?9J`6H!5FC:,@4(Z`4=``"#Q!"%P'5L@^P,5NCU_?__5FCH,@4(
MC9WH[___:``0``!3Z*[8__^#Q!13Z)79__^)-"1H!C,%"&@;,P4(:``0``!3
MZ(W8__^#Q!13Z'39__^#Q!"%P(G"#X5V____A?]T!8`_`'4@,=*-9?1;7HG0
M7\G#4&@C,P4(:@!J`.CS6P``@\00ZX"#[`C_-11X!0A7Z"\U``"#Q!"%P'3*
MZ"\@``"%P'00@^P,5^@.+@``@\00,=+KLX/L"&H!5^AX)P``@\00Z^R-=@!5
MB>575E.#['R+?0B-7=B-M7C____'1=A`,P4(QT7<2C,%",=%X`````#K%(/#
M!.AXVO__BQ.%TL<``````'0\4/\S5VA2,P4(Z.)9``!:6590Z!7<__^#Q!"%
MP'7.#[=5@(G0)0#P```]`(```'6\@^)`=+>+`^L%C78`,<"-9?1;7E_)PXGV
M58GE5U93@>P(`0``_W4(BWT,Z'W;__^#Q!"%P(G##X3<`0``@^P,_W,<Z*79
M__^#Q!!`=#.#[`B-18A0:%<S!0CHGMO__X/$$$!T$@^W59"!X@#P``"!^@!`
M``!T(HUE]%M>7\G#B?;_<QQHR#8%"&H!:@'HJUH``(/$$.NWB?:#[`B-M7C_
M__^+0PR-C03___]648F%`/___\>%>/___W,S!0C'A7S___];,P4(QT6`:3,%
M",=%A`````#H3S,``(/$$(7`#X55`0``_S4(:P4(:C)J`6CH-@4(Z!3;__^#
MQ!"%_P^$)0(``(/L#&A],P4(Z)S9__^#Q!!`#X3K`@``@^P,:(\S!0CHA=G_
M_X/$$$`/A"8#``"#[`QHFC,%".ANV?__@\000`^$Y@(``(/L#&BF,P4(Z%?9
M__^#Q!!`#X1]`@``@^P(:%`T!0AH?3,%".B[V?__@\00A<")Q@^$:@$``(/L
M"&BQ,P4(4.@PV/__@\00A<`/B%$!``"#[`A7_W,,_W,(_W4(:,\S!0A6Z`W8
M__^#Q""%P`^(+@$``(/L#%;HF=G__X/$$$`/A!L!``"-=@!0:@!H?3,%"&A7
M,P4(:.4S!0AHZ#,%"&CK,P4(:.LS!0CH6E$``(/$((7`#X1U_O__4&@<-P4(
M:@%J`>@L60``@\00Z5[^__^#[`S_=0AH$D@%"&C^,P4(:@%J`>@+60``@\0@
MZ0/^__^#[`QH%S0%".AFV/__@\000`^$KP```%!HI`$``&@!!@``:!<T!0CH
M]]G__X/$$(/X_XG&#X0D`@``4/]U"/^U`/___VA(-P4(Z#E7``#'!"0`````
M:!8T!0A0:"$T!0C_M03_____M03___]J`E9J_XF%_/[__^@[50``@\0P0`^$
MP0$``(/L#/^U_/[__^@OVO__B30DZ!?:__^#Q!#H7]?__\<``````.D3_O__
M4&AX-P4(:@%J`>A%6```@\00Z='^___H.-?__X,X`@^$0____V@7-`4(:"0T
M!0AJ`6H!Z!Q8``"#Q!#I*/___XM['(VU:/___\>%:/___T`S!0C'A6S___]*
M,P4(QX5P____`````.L7C78`Z./6__^#Q@3'``````"+!H7`='!0_S97:%(S
M!0CH2E8``%I9C94(____4E#H=]C__X/$$(7`=<@/MY40____B=&!X0#P``"!
M^0"```!UL8/B0'2LBP:%P(G'#X5/_?__@^P,_W4(:!)(!0AHJ#<%"&H!:@'H
M;U<``(/$(.DN_?__C78`,<#KSNA;UO__@S@"#X1U_?__:*8S!0AH)#0%"&H!
M:@'H/U<``(/$$.E:_?__Z#+6__^#.`(/A`?]__]H?3,%"&@D-`4(:@%J`>@6
M5P``@\00Z>S\___H"=;__X,X`@^$#/W__VB:,P4(:"0T!0AJ`6H!Z.U6``"#
MQ!#I\?S__^C@U?__@S@"#X3,_/__:(\S!0AH)#0%"&H!:@'HQ%8``(/$$.FQ
M_/__4&C0-P4(:@%J`>BM5@``@\00Z2C^__]0:/`W!0AJ`6H!Z)96``"#Q!#I
MQ?W__XGV58GE4X/L)(M%",=%Z!](!0C'1>PV-`4(B47PQT7T`````.CUU?__
M@_C_C5WHB<)T0X7`=%A0:@"-3>114N@JTO__BU7D@\00,<"%TG09B=#!^`B#
MXG]U"H/X0W0/@_A!=`JX_____XM=_,G#,<"+7?S)PY!2:#TT!0AJ`6H!Z`E6
M``"#Q!"Z_____^O!@^P(4V@?2`4(Z*'5___'!"3_____Z,76__^058GE4X/L
M)(M%",=%Z"Q(!0C'1>PX-`4(B47PQT7T`````.A-U?__@_C_C5WH=$6%P'1:
M46H`C4WD45#HA-'__XM5Y(/$$#'`A=)T&8G0P?@(@^)_=0J#^$-T$8/X070,
MN/____^+7?S)PXGV,<"+7?S)PY!3:#TT!0AJ`6H!Z&%5``"#Q!"Z_____^N_
M@^P(4V@L2`4(Z/G4___'!"3_____Z!W6__^058GE5E.![#P0``"+70B+=0Q3
MZ'TO``"#Q!"%P+K_____#X6O````A?:X3#0%"`^$K````&H`4U!H4C0%".BZ
M2P``B1PDZ(+V__^#Q!"%]@^$L0```(F=\.___\>%Z.___Q](!0C'A>SO__\V
M-`4(QX7T[___`````.A.U/__@_C_C9WH[___B<(/A-D```"%P`^$!P$``%!J
M`(V%U.___U!2Z'70__^#Q!"+A=3O__\QTH7`="")PL'Z"*A_=1*#^D,/A)0`
M``"#^D$/A(L```"Z_____XUE^%N)T%[)PY!J`%.X730%"%!H4C0%".@)2P``
MB1PDZ-'U__^#Q!"%]@^%3____XF=X.___\>%V.___RQ(!0C'A=SO__\X-`4(
MQX7D[___`````.B=T___@_C_C9W8[___="Z%P'1&5FH`C8W0[___45#HSL__
M_X/$$(N%T.___^E4____C67X6S'2B=!>R<.04&@]-`4(:@%J`>C%4P``@\00
MN/_____I,O___X/L"%-H+$@%".A:T___QP0D_____^A^U/__@^P(4V@?2`4(
MZ^2-=@!5B>53@^PTBT4(QT78.4@%",=%W.@S!0C'1>!B-`4(B47DQT7H````
M`.CRTO__@_C_C5W8="J%P'0_46H`C4W445#H*<___XM5U(/$$#'`A=)T!;C_
M____BUW\R<.-=@!3:#TT!0AJ`6H!Z"%3``"#Q!"X_____^O?@^P(4V@Y2`4(
MZ+G2___'!"3_____Z-W3__^058GE5U93@>PD$```_W4,_W4(Z"73__^#Q!`Q
MTH7`=0J-9?1;7HG07\G#@^P(:@'_=0SHB3$``(/$$(7`B87@[___=#>#[`Q0
MZ`LO``"#Q!"%P'0GBT4(@#@M=4N`>`$`=46+/6AW!0B%_P^%4P(``*$$:P4(
M#[]`#NL\_W4,:$Q(!0AJ`&H`Z'!2``!8_[7@[___Z'0O``"Z`0```(UE]%M>
MB=!?R<.#[`AJ`/]U".AHT___@\00B87D[___B[7D[___A?8/B(4!``"+10R`
M."UU((!X`0!U&HL-:'<%"(7)#X7O`0``BQ4`:P4(#[]R#NL5@^P(:`$&``#_
M=0SH&=/__X/$$(G&A?:-O>CO__\/B'8!``")]E!H`!```%?_M>3O___H`M'_
M_X/$$(7`B<-_$.MUC78`Z+_0___'``0```!04U=6Z!#0__^#Q!"%P'3E.=AT
MP8/L$.B=T/__6_\PZ,7-__]:65#_=0S_=0AH>$@%"&H`:@#H?E$``(/$%/^U
MX.___^@`+@``B30DZ!C3__]8_[7D[___Z`S3__^Z`0```.GS_O__0P^$J0$`
M`(L=:'<%"(7;#X4J`0``H0!K!0@/OW@..?=T(H/L#%;HU]+__X/$$(7`#X4G
M`0``BS5H=P4(A?8/A38!``"+#01K!0@/OT$..X7D[___=!F#[`S_M>3O___H
MGM+__X/$$(7`#X4A`0``@^P,_[7@[___Z&4M``"#Q!"%P'4',=+IZ_W___]U
M#&B<2`4(:@!J`.BV4```@\00,=+IT/W__X/L$.BDS___6_\PZ,S,__^)!"3_
M=0AH'TH%"&H`:@#HB%```(/$%/^UX.___^@*+0``N@$```#I$?[__X/L$.AH
MS___6O\PZ)#,__^)!"3_=0QH'TH%"&H`:@#H3%```(/$%/^UX.___^C.+```
MZ='^__^#[`S_-01K!0CH*]'__^G>_?__@^P,_S4`:P4(Z!C1___I&O[__X/L
M#/\U`&L%".@%T?__@\00.?`/A<K^___IV?[__X/L$.CMSO__7_\PZ!7,__^)
M!"3_=0QH.DH%".N#@^P,_S4$:P4(Z,K0__^#Q!#IOO[__X/L$.BZSO__7O\P
MZ.++__^)!"3_=0AH.DH%".D1____@^P0Z)K.__];_S#HPLO__UI94/]U#/]U
M"&C(2`4(Z?C]__^-=@!5B>575E.!["00``"+11AFB87F[___:@#_=0CH?-#_
M_XF%V.___X/$$$`/A$("```QP(M]#/RY______*N]]&#[`R-6?^#P0=1Z([,
M__^#Q!"%P(F%X.___P^$40(``%!3_W4,_[7@[___Z&W.__^+E>#O___'!!HN
M6%A8QT0:!%A86`")%"3HD,___XF%W.___X/$$$`/A/4!``!3:``0``"-M>CO
M__]6_[78[___Z/C-__^#Q!"%P(G'=$DQ]I`Y_G/84%>-G>CO__]3_[7<[___
MZ`3-__^#Q!"#^/^)PW0&*=_KVHGV@^P,_W4,_W4(:/!(!0AJ`6H!Z'U.```I
MWX/$(.NZ4?]U%/]U$/^UW.___^@TR___@\000'1V@^P(#[>-YN___U'_M=SO
M___HV,K__X/$$$`/A)````"#[`S_M=SO___HX,___X/$$$`/A*H```"#[`S_
MM=CO___HR,___UA:_W4,_[7@[___Z!C,__^#Q!!`#X3$````@^P,_[7@[___
MZ+#/__^-9?1;7E_)PX/L#/]U#/]U"&@<204(:@%J`>C130``@\0@@^P(#[>-
MYN___U'_M=SO___H2,K__X/$$$`/A7#___^#[`S_=0S_=0AH2$D%"&H!:@'H
METT``(/$((/L#/^UW.___^@VS___@\000`^%5O___X/L#/]U#/]U"&AT204(
M:@%J`>AE30``@\0@@^P,_[78[___Z`3/__]86O]U#/^UX.___^A4R___@\00
M0`^%//___X/L#/]U#/]U"&B@204(:@%J`>@C30``@\0@@^P,_[7@[___Z-+.
M__^-9?1;7E_)PX/L#/]U#/]U"&C,204(:@%J`>CS3```@\0@Z9_]__^#[`S_
M=0S_=0AH]$D%"&H!:@'HU$P``(/$(.GL_?__4&A72@4(:@%J`>B]3```@\00
MZ9C]__^058GE5U93@>R,````,<#\N?____^+?0CRKO?1BQT@>`4(287;B4V$
M#X3V````BSTD>`4(QX5X____`````#F]>/___XF]?/___P^#/0$``(LU('@%
M"(L59'<%"(FU=/___XE5@(N==/___P.=>/___^L8B?:#[`Q0Z'?+__\E`$``
M`(/$$(7`=!M##[8#/?\```!WX(M-@(M$@30E`$```(7`=>6+183\.<")WHM]
M"(G!\Z8/A?L```"+580/M@03/?\````/A_D```"+?8"+1(<T)0!```"%P`^$
MU0````-=A.L:@^P,4.@'R___@\00)0!```"%P`^$MP$``$.*`X3`#X2L`0``
M/`H/A*0!```/ML`]_P```'?*BW6`BT2&-.O-@^P(:`0N!0AH:4H%".AOR___
MB<>#Q!`QP(7_=$Z+%6AW!0B#[`B-=8B%TE8/A34!```/OT<.4.C%R?__@\00
MA<!U&XM=N(/L#(/#`E/HG\C__X/$$(7`HR!X!0AU5(/L#%?H2LO__XGV,<"-
M9?1;7E_)PXGVBX5X____BXUT_____X5X____@#P(``^$OP```(N=?/___SF=
M>/___W+6Z\B#[`Q0Z"?*__^#Q!#I_?[__U=J`?]UN%#HH\K__X/$$$@/A:L`
M``"+1;B+#2!X!0BC)'@%",8$"``Q]HL5)'@%"#G6<Q>-=@"+#2!X!0B`/#$*
MC1PQ=#)&.=9R[(/L#%?HJ\K__X/$$.G\_?__C78`@^P,4NBWR?__)0!```"#
MQ!"%P'0AQ@,`2P^^$X'Z_P```'?<H61W!0B+1)`T)0!```"%P'7?BQ4D>`4(
M1NNIBY5\____.95X____#X+?_?__Z0+___]7Z"3+__]:Z</^__^#[`S_-2!X
M!0CHT,O__UC'!2!X!0@`````Z=#^__^+O7S___\YO7C___^)V`^"QO[__^F_
M_O__C78`58GE5E.#[`R+=0A6Z!_]__^#Q!"%P(G#=`6`.`!U$E9H>TH%"&H!
M:@'HMDD``(/$$(UE^(G86U[)PY"058GE5U93@>RD$```:@'_=0B+71#'A7SO
M__\`````Z$DH``"#Q!"%P(F%>.___W00@^P,4.C+)0``@\00A<!U1(/L$.A@
MR/__6?\PZ(C%__^)!"3_=0AHE$H%"&H`:@#H1$D``(/$%/^U>.___^A&)@``
MN@$```"-9?1;7HG07\G#C78`@^P(C86([___4/]U".C2R?__@\00A<`/A9@`
M``"#^P$/A,8````/CCH"``"#^P(/A%L#``"+A7SO__^%P'4^5_^UF.____^U
ME.____]U".BPQO__@\00A<`/B-T$``"#[`@/MXV0[___4?]U".BBQO__@\00
MA<`/B*<!``"#[`S_M7CO___H*24``(/$$#'2A<`/A%O___^#[!#HA,?__UG_
M,.BLQ/__B00D_W4(:,1*!0CK*>AJQ___@S@"#X12`0``@^P0Z%G'__]:_S#H
M@<3__XD$)/]U"&CT2@4(:@!J`.@]2```Z0+___^+A7SO__^%P`^%40$``(/L
M"&@$+@4(_W4(Z`K(__^#Q!"%P(F%:.___P^$_P0``/]U"&C32P4(:``0``"-
MM>CO__]6Z%#$__];7VA0-`4(5NC3Q___@\00A<")A63O__\/A*@&``")]E?_
MM6CO__]H_P\``%;HGL3__X/$$(7`#X3#`0``,<")]_RY______*N]]&->?_'
MA73O__\`````@+P]Y^___PH/A,0```"+70R+$X72=$"04%=6_S/HQL;__X/$
M$(7`=1>+"XH$.3P*=`2$P'4*QX5T[___`0```(/#!(L#A<!USXN==.___X7;
M#X5Q____@^P(_[5D[___5NARR/__@\000`^%6/____]U"&B\2P4(:@%J`>@7
M1P``@\00Z3_____'A7SO__\!````Z?G]__^#[!#H^,7__UO_,.@@P___B00D
M_W4(:!Q+!0AJ`&H`Z-Q&``"#Q""#[`S_M7CO___H6R,``.F0_?__C7G^Z33_
M__^%VP^%Q_W__XM5%(72#X1,!```@WT4`0^%LOW__X/L"&C:2P4(_W4(Z('&
M__^#Q!"%P(F%A.___P^$=@,``(MU#(L^A?]T3HGZ,<#\B=>Y______*NB<OW
MT_^UA.___TM3:@%2Z"7'__^+#H/$$(!\&?\*=!?_M83O__]J`6H!:/<9!0CH
M!<?__X/$$(/&!(L6A=)UM(/L#/^UA.___^@[QO__@\00A<`/A"']__^#[!#H
M",7__U__,.@PPO__B00D_W4(:#I*!0CI"____X/L#/^U:.___^@"QO__@\00
MA<`/A&L"``"#[!#HS\3__UO_,.CWP?__B00D_W4(:#I*!0AJ`&H`Z+-%``"#
MQ!3_M7CO___H-2(``%G_M63O___HN<7__^E>_/__@^P(:`0N!0C_=0CH=,7_
M_X/$$(7`B85@[___#X1I`@``_W4(:--+!0AH`!```(V]Z.___U?HNL'__UE;
M:%`T!0B-M>CO__]6Z#?%__^#Q!"%P(F%7.___P^$6@0``(GV4/^U8.___VC_
M#P``C;7H[___5NC\P?__@\00A<`/A$D!```QP/RY_____XV]Z.____*N]]&-
M0?^)A7#O___'A6SO__\`````@+P%Y^___PH/A.@```"+=0R+/H7_=*&)^^LH
MD`^.K````(-]%`(/A(8```"+A6SO__^%P'1B@\8$BQZ%VP^$=?___S'`_+G_
M____B=_RKO?1C5'_@'P3_P!U`XU1_H-]%`%UN#N5<.___W?`C;WH[___45(I
MUP.]<.___U-7Z+G#__^#Q!"%P'6BQX5L[___`0```.N@B?:#[`C_M5SO__^-
MC>CO__]1Z'_%__^#Q!#KA(/L"%.-G>CO__]3Z!K#__^#Q!"%P'7!Z5[___^+
M312%R0^%4____SN5<.___P^'1____U=24XV5Z.___U+H2,/__^N-@^D"B8UP
M[___Z0K___^#[!#HX,+__U[_,.@(P/__B00D_W4(:$Q+!0CIX_S__X/L#/^U
M8.___^C:P___@\00A<`/A,4```"#[!#HI\+__U__,.C/O___B00D_W4(:#I*
M!0AJ`&H`Z(M#``"#Q!3_M7CO___H#2```%[_M5SO___HD</__^DV^O__@^P,
M_[5D[___Z'[#__^#Q!"%P`^%0_W___]U"&C32P4(:``0``!6Z*"___]86O]U
M"%;H1<'__X/$$(7`#X1%^O__@^P0Z"+"__]?_S#H2K___XD$)/]U"&A\2P4(
MZ27\__^#[!#H`L+__U[_,.@JO___B00D_W4(:-Q+!0CI!?S__X/L#/^U7.__
M_^C\PO__@\00A<`/A<'\____=0AHTTL%"&@`$```C97H[___4N@8O___65O_
M=0B-G>CO__]3Z+?`__^#Q!"%P`^$K?G__X/L$.B4P?__6O\PZ+R^__^#Q!!0
MC;WH[___5VA\2P4(_S4(:P4(Z/'`__]8_S4(:P4(Z"7`__]8Z8G[____=0AH
MTTL%"&@`$```C97H[___4NBFOO__6UYH4#0%"(VUZ.___U;H(\+__X/$$(7`
MB86`[___#X2,`@``BW4,BSZ%_W1.B?J)US'`_+G_____\JZ)S_?7_[6`[___
M3U=J`5+HQ\+__XL.@\00@'PY_PIT%_^U@.___VH!:@%H]QD%".BGPO__@\00
M@\8$BQ:%TG6T@^P(:`0N!0C_=0CHJ\'__X/$$(7`B<,/A&T!``!74V@`$```
MC97H[___4NA[OO__@\00A<`/A`@!``"#[`C_M8#O__^-M>CO__]6Z+O"__^#
MQ!!`=<>#[!#H;<#__UK_,.B5O?__B00D_W4(:)Q+!0AJ`&H`Z%%!``"#Q!3_
MM7CO___HTQT``(D<).A;P?__6/^U@.___^A/P?__Z?3W__^#[!#H(L#__UG_
M,.A*O?__@\004%9HW$L%"/\U"&L%".B%O___6O\U"&L%".BYOO__6/^U>.__
M_^A]'0``6/^U:.___^@!P?__Z:;W__^#[!#HU+___UK_,.C\O/__@\004(V5
MZ.___U)HW$L%"/\U"&L%".@QO___6/\U"&L%".AEOO__6/^U>.___^@I'0``
M6/^U8.___^BMP/__Z5+W__^#[`Q3Z)_`__^#Q!"%P'1O@^P0Z'"___]>_S#H
MF+S__XD$)/]U"&@Z2@4(:@!J`.A40```@\04_[5X[___Z-8<``#I!O___X/L
M$.@YO___6O\PZ&&\__^)!"3_=0AHW$L%"&H`:@#H'4```(/$%/^U@.___^@O
MP/__6.DS^?__@^P,_[6`[___Z!O`__^#Q!"%P`^%X/G___]U"&C32P4(:``0
M``"-C>CO__]1Z#>\__]96_]U"(V=Z.___U/HUKW__X/$$(7`#X3,]O__@^P0
MZ+.^__]:_S#HV[O__X/$$%"-O>CO__]7:/A+!0CI&OW__X/L$.B.OO__6?\P
MZ+:[__^#Q!!0C9WH[___4VC<2P4(Z?7\__^058GE@^P(_W44_W40C47X4(M5
M#/]U"(E5^,=%_`````#HH_7__\G#D%6)Y5=64X/L&(MU"%:+70R+?1#HH+__
M_X/$$(7`B<)T*X7;=`6+0`B)`X7_=`6+2@R)#XM=%(7;=`B+<AR+512),C'`
MC67T6UY?R<-6:!A,!0AJ`&H`Z.T^``"X_____^OBB?95B>5348M5#(72BUT(
M="6#[`Q3Z#R___^#Q!"%P'0\BT`,B47X,<!`="*+1?B+7?S)PXGV@^P,4^@7
MO___@\00A<!T%XM`".O9C78`QT7X`````(M%^(M=_,G#4V@83`4(:@!J`.AZ
M/@``@\00N/_____KLU6)Y8M5"(H"A,!T&P^^P#W_````=QCV!(5%:P4(!'0.
M0HH"A,!UY;@!````R<,QP,G#B?95B>5348M=".@OO?__@^P,QP``````4^@0
MO___@\00A<!T"(M`"(M=_,G#@^P0Z`F]__]:_S#H,;K__XD$)%-H6TP%"&H`
M:@#H[ST``#'`BUW\R<-5B>5348M=".C;O/__@^P,QP``````4^@\NO__@\00
MA<")VG0'B="+7?S)PX/L$.BTO/__6O\PZ-RY__^)!"13:&Q,!0AJ`&H`Z)H]
M```QTNO3B?95B>534(M="(G:B@/K&8GV#[[`/?\```!W2_8$A45K!0@$=$%"
MB@*$P'7E4(U%^%!H?4P%"%/H^;S__X/$$(M=^.A.O/__@^P,QP``````4^BO
MN?__@\00A<")VG0JB="+7?S)P^@JO/__@^P,QP``````4^@+OO__@\00A<!T
M,XM`"(M=_,G#@^P0Z`2\__]9_S#H++G__XD$)%-H;$P%"&H`:@#HZCP``#'2
M@\0@B=#KK8/L$.C9N___6O\PZ`&Y__^)!"13:%M,!0AJ`&H`Z+\\``"#Q"`Q
MP(M=_,G#D%6)Y5.#[!"+70A3Z!2]__^#Q!"%P'0(BT`(BUW\R<.#[!#HC;O_
M_UK_,.BUN/__B00D4V@X3`4(:@!J`.AS/```,<"+7?S)PU6)Y5.#[!"+70A3
MZ*R\__^#Q!"%P'0I46C_#P``_S!H0'@%".BCN___Q@4_B`4(`(/$$+A`>`4(
MBUW\R<.-=@!3:(!,!0AH`!```&A`>`4(Z'>X__^#Q!"X0'@%"(M=_,G#B?95
MB>53@^P0BUT(4^AHN/__@\00A<!T*5-H_P\``/\P:$"(!0CH/[O__\8%/Y@%
M"`"#Q!"X0(@%"(M=_,G#C78`4VB`3`4(:``0``!H0(@%".@3N/__@\00N$"(
M!0B+7?S)PY"058GE@^QHH7AH!0B#^/]T!,G#B?:#[`B-19A0:(-,!0CH/[S_
M_X/$$(7`=1(/MU6@@>(`\```@?H`@```=!''!7AH!0@`````H7AH!0C)PXM5
MS(M%R(G1"<%UX\<%>&@%"`$```#KX9!5B>575E.![(0```"-18A0_W4(Z`2Z
M__^#Q!!`#X1P`@``#[=%D"4`\```/0"@```/A$8!```]`(````^$@@$``(/L
M"&H$:.,K!0CH#+S__XE%@(/$$$`/A*<!``"#[`S_=0CH!+O__X/$$(7`B46$
M#X3"`@``@^P,_W4(Z&NY__^#Q!!`#X1M`@``D(/L#/]UA.A5N/__@\00A<!T
M?X/L"(U5B%*-6`A3Z&ZY__^#Q!!`#X1X`0``#[=%D"4`\```/0!````/A+@`
M```]`(```'6Y4?]U$/]U#%/H/+C__X/$$$!UIH/L$.A.N?__6O\PZ':V__^)
M!"13:(Q-!0AJ`6H!Z#0Z``"#Q""#[`S_=83HUK?__X/$$(7`=8&#[`S_=8#H
M%+?__X/$$$`/A#8!``"#[`S_=8#HK[O__X/$$$`/A"$!``"#[`S_=83H2KO_
M_X/$$$`/A'`!``"+712%VW094?]U$/]U#/]U".BJM___@\000`^$G`$``(UE
M]%M>7\G#_(G>O^,K!0BY`@```/.F#X3S_O__B=Z_XBL%"+D#````\Z8/A-_^
M__]J`?]U$/]U#%/H1?[__X/$$.G)_O__5O]U$/]U#/]U".A*M___@\000'6D
M@^P0Z%RX__];_S#HA+7__XD$)/]U"&B,304(:@%J`>A`.0``@\0@Z7C___^#
M[!#H,+C__UG_,.A8M?__@\004&BT304(:@%J`>@6.0``@\00Z2_^__^)]N@'
MN/__@S@"#X1._O__@^P0Z/:W__]>_S#H'K7__XD$)%-HZ$T%"&H!:@'HW#@`
M`(/$(.E0_O__@^P0Z,RW__]?_S#H]+3__X/$$%!H$$X%"&H!:@'HLC@``(/$
M$.FU_O__Z*6W__^#.`(/A8+]__^#[!#HE+?__U__,.B\M/__B00D_W4(:)=,
M!0AJ`6H!Z'@X``"#Q"#I5OW__X/L$.AHM___7O\PZ)"T__^)!"3_=0AHLTP%
M"&H!:@'H3#@``(/$(.ED_O__@^P0Z#RW__]?_S#H9+3__XD$)/]U"&C/3`4(
MZ>?]__^#[!#H'+?__UK_,.A$M/__B00D_W4(:.Q,!0CIN_[__X/L$.C\MO__
M6O\PZ"2T__^)!"3_=0AH"$T%"&H!:@'HX#<``(/$(.D2_?__58GE5U93@>R$
M````C46(4/]U".B@MO__@\000`^$>`(```^W19`E`/```#T`H```#X1.`0``
M/0"````/A(H!``"#[`AJ!&CC*P4(Z*BX__^)18"#Q!!`#X2P`0``@^P,_W4(
MZ*"W__^#Q!"%P(E%A`^$R@(``(/L#/]U".@'MO__@\000`^$=0(``)"#[`S_
M=83H\;3__X/$$(7`#X2`````@^P(C4V(48U8"%/H!K;__X/$$$`/A'P!```/
MMT60)0#P```]`$````^$O````#T`@```=;6#[`@/MT4,4%/HX[3__X/$$$!U
MH8/L$.CEM?__7_\PZ`VS__^)!"13:#Q.!0AJ`6H!Z,LV``"#Q""#[`S_=83H
M;;3__X/$$(7`=8"#[`S_=8#HJ[/__X/$$$`/A#D!``"#[`S_=8#H1KC__X/$
M$$`/A"0!``"#[`S_=83HX;?__X/$$$`/A',!``"+712%VW0<@^P(#[=5$%+_
M=0CH4+3__X/$$$`/A)X!``")]HUE]%M>7\G#_(G>O^,K!0BY`@```/.F#X3K
M_O__B=Z_XBL%"+D#````\Z8/A-?^__]J`?]U$/]U#%/H/?[__X/$$.G!_O__
M@^P(#[=5#%+_=0CH[;/__X/$$$!UHX/L$.COM/__7_\PZ!>R__^)!"3_=0AH
M(TT%"&H!:@'HTS4``(/$(.EW____@^P0Z,.T__]>_S#HZ['__X/$$%!HM$T%
M"&H!:@'HJ34``(/$$.DF_O__D.B;M/__@S@"#X1&_O__@^P0Z(JT__]:_S#H
MLK'__XD$)%-HZ$T%"&H!:@'H<#4``(/$(.E,_O__@^P0Z&"T__]>_S#HB+'_
M_X/$$%!H$$X%"&H!:@'H1C4``(/$$.FR_O__Z#FT__^#.`(/A7K]__^#[!#H
M*+3__UK_,.A0L?__B00D_W4(:)=,!0AJ`6H!Z`PU``"#Q"#I3OW__X/L$.C\
ML___6_\PZ"2Q__^)!"3_=0AHLTP%"&H!:@'HX#0``(/$(.EA_O__@^P0Z-"S
M__]9_S#H^+#__XD$)/]U"&C/3`4(Z>3]__^#[!#HL+/__UK_,.C8L/__B00D
M_W4(:$%-!0CIO/[__X/L$.B0L___6_\PZ+BP__^)!"3_=0AH"$T%"&H!:@'H
M=#0``(/$(.D*_?__58GE5E.+71Q3_W40_W4,BW4(5N@8^?__4_]U&/]U%%;H
M;_S__XUE^%LQP%[)PXGV58GE5U93@>R$````C46(4/]U".@$L___@\000`^$
M0`(```^W19`E`/```#T`H```#X1>`0``/0"````/A%,!``"#[`AJ!&CC*P4(
MZ`RU__^)18"#Q!!`#X12`@``@^P,_W4(Z`2T__^#Q!"%P(E%A`^$KP(``(/L
M#/]U".AKLO__@\000`^$>@(``)"#[`S_=83H5;'__X/$$(7`='*#[`B-58A2
MC5@(4^ANLO__@\000`^$2`$```^W39"!X0#P``"!^0!````/A>8```#\B=Z_
MXRL%"+D"````\Z9TK8G>O^(K!0BY`P```/.F=)V#[`AJ`5/H!O___X/$$(/L
M#/]UA.CDL/__@\00A<!UCY"#[`S_=8#H(;#__X/$$$`/A!,!``"#[`S_=8#H
MO+3__X/$$$`/A/X```"#[`S_=83H5[3__X/$$$`/A(H!``"+70R%VW13@^P,
M_W4(Z&NP__^#Q!!`=4+HT+'__X,X`G0X@^P0Z,.Q__]9_S#HZZ[__XD$)/]U
M"&A=304(Z0T!``"-=@"#[`S_=0CH#;+__X/$$$`/A,P```"-9?1;7E_)PXUV
M`(/L#%/H[['__X/$$$`/A<7^___H<+'__X,X`@^$M_[__X/L$.A?L?__6O\P
MZ(>N__^)!"13:&1.!0AJ`6H!Z$4R``"#Q"#IC?[__Y#H-['__X,X`@^$?O[_
M_X/L$.@FL?__6?\PZ$ZN__^)!"13:.A-!0AJ`6H!Z`PR``"#Q"#I@/[__X/L
M$.C\L/__7_\PZ"2N__^#Q!!0:!!.!0AJ`6H!Z.(Q``"#Q!#IV/[__^C5L/__
M@S@"#X6R_?__Z33____HPK#__X,X`@^$)O___X/L$.BQL/__6O\PZ-FM__^)
M!"3_=0AHD$X%"&H!:@'HE3$``(/$(.GZ_O__@^P0Z(6P__]?_S#HK:W__X/$
M$%!HM$T%"&H!:@'H:S$``(/$$.F$_?__@^P0Z%NP__]>_S#H@ZW__XD$)/]U
M"&BS3`4(:@%J`>@_,0``@\0@Z4K^__^#[!#H+[#__UO_,.A7K?__B00D_W4(
M:,],!0CIR?[__X/L$.@/L/__7O\PZ#>M__^)!"3_=0AH"$T%"&H!:@'H\S``
M`(/$(.DE_?__C78`58GE5U93@>R4````C46(4/]U".BPK___@\000`^$?`(`
M``^W19`E`/```#T`H```#X2Z`0``/0"````/A+<!``"#[`AJ!&CC*P4(Z+BQ
M__^)18"#Q!!`#X2T`0``@^P,_W4(Z+"P__^#Q!"%P(E%A`^$C@(``(/L#/]U
M".@7K___@\000`^$30(``)"#[`S_=83H`:[__X/$$(7`#X3J````@^P(C56(
M4HU8"%/H%J___X/$$$`/A(`!```/MT60)0#P```]`$```'1P/0"```!UN8M%
M%(7`=+*+?0PQP/RY______*NB8U\____]]%64?]U#%/H/J___X/$$(7`=8N#
M[`C_=1#_=0SHZ:W__X/$$$`/A7/___^#[!#HQZ[__UK_,.COJ___7E]0_W40
M_W4,:+!.!0CIMP$``/R)WK_C*P4(N0(```#SI@^$.____XG>O^(K!0BY`P``
M`/.F#X0G____:@'_=1#_=0Q3Z(W^__^#Q!"#[`S_=83H%ZW__X/$$(7`#X46
M____@^P,_W6`Z%&L__^#Q!!`#X33````@^P,_W6`Z.RP__^#Q!!`#X2^````
M@^P,_W6$Z(>P__^#Q!!`=2F#[!#H&:[__UG_,.A!J___B00D_W4(:+-,!0AJ
M`6H!Z/TN``"#Q"")]HUE]%M>7\G#_W4(:.!.!0AJ`6H`Z-\N``"-9?1;7E_)
MPX/L$.C/K?__7O\PZ/>J__^#Q!!0:+1-!0AJ`6H!Z+4N``"#Q!#I(O[__Y#H
MIZW__X,X`@^$0O[__X/L$.B6K?__6O\PZ+ZJ__^)!"13:.A-!0AJ`6H!Z'PN
M``"#Q"#I2/[__X/L$.ALK?__6_\PZ)2J__^#Q!!0:!!.!0AJ`6H!Z%(N``"#
MQ!#I&/___^A%K?__@S@"#X5V_?__@^P0Z#2M__]?_S#H7*K__XD$)/]U"&B7
M3`4(:@%J`>@8+@``@\0@Z4K]__^#[!#H"*W__UG_,.@PJO__B00D_W4(:,],
M!0AJ`6H!Z.PM``"#Q"#IB/W__X/L$.C<K/__6_\PZ`2J__^)!"3_=0AH"$T%
M"&H!:@'HP"T``(/$(.E&_?__58GE5E.![&`0``"A@&@%"(7`BW4(NX!H!0@/
MA-````"#[`C_,%;HW08``(/$$(7`#X7,````@\,$BP.%P'7A5F@,3P4(:@%J
M`>AJ+0``@\00@^P(C868[___4%;H%Z[__X/$$(7`=!A0:%!/!0AJ`6H!Z$$M
M``"-9?A;7LG#B?:#[`S_-7QH!0B+$_\R:'I-!0AH`!```(V=^.___U/H=:G_
M_X/$%%/HC*K__X/$$(7`=%.#[`Q35FB$3P4(:@%J`.CR+```@\084U;H5`0`
M`(/$$(7`=*!0:*Q/!0AJ`6H!Z-(L``"#Q!"-9?A;7LG#H8!H!0B%P`^%5/__
M_^D]____BP/K[U!HW$\%"&H!:@'HHRP``(/$$.N9B?95B>575E.#['RA@&@%
M"(7`QT6$@&@%"`^$[````(/L#/\PZ*6L__^#Q!"%P(G&#X3=````BUV$@^P,
MBPO_,>@)J___@\00B?:#[`Q6Z/NI__^#Q!"%P(G"#X2*````@^P(C7V(5XU:
M"%/H[JS__X/$$$!T;`^W19`E`/```#T`0```=<2+%7QH!0B)58`QP(M]@/RY
M______*N]]%)4%'_=8!3Z$2K__^#Q!"%P'69:@!3:(9-!0AH@1D%".A;%```
M@\00A<!T@%-H'%`%"(GV:@%J`.C#*P``Z67___^)]E-H4%`%".OH@^P,:(I-
M!0CH5ZK__X-%A`2+=82#Q!"+!H7`#X44____C67T6UY?R<.#[!#H@ZK__UK_
M,.BKI___B00DBU6$BP+_,&@(304(:@%J`.AC*P``C67T6UY?R<.0D)!5B>53
M@^P,BUT(:`$&``!3Z&.L__^#Q!"%P'@0@^P,4.CCK/__,<"+7?S)PX/L$.@D
MJO__6O\PZ$RG__^)!"13:'10!0AJ`&H`Z`HK``"X_____XM=_,G#58GE4X/L
M#(M="&@!`@``4^@+K/__@\00A<!X$(/L#%#HBZS__S'`BUW\R<.#[!#HS*G_
M_UG_,.CTIO__B00D4VB?404(:@!J`.BR*@``N/____^+7?S)PU6)Y5=64X/L
M%(M]#(E%\(E5[&HO4.C>J/__@\00A<")PP^W]W0G.T7P="+&``")\(/L""7_
M`0``4/]U"(M5[(M%\.BY____Q@,O@\00@^P(5O]U\.COJ___@\000'0=5O]U
M"/]U[/]U\.@:J/__@\000'10C67T6UY?R</H)ZG__X,X$73N@^P0Z!JI__]?
M_S#H0J;__XD$)/]U\&B@4`4(:@%J`>C^*0``@\0@5O]U"/]U[/]U\.C,I___
M@\000'6RB?:#[!#HW*C__UO_,.@$IO__B00D_W7P:+Q1!0AJ`6H`Z,`I``"#
MQ""-9?1;7E_)PY!5B>575E.#[!2+10R+?1`/MUT4B47P_W4(:`53!0CH%2@`
M`(G&6%I35XM5\(GPZ-G^__^)=0B#Q!"-9?1;7E_)Z2^K__^-=@!5B>564XMU
M"`^W713H6ZC__X/L",<``````%-6Z.NJ__^#Q!"%P'0*Z#^H__^#.!%U7U#_
M=1#_=0Q6Z`VG__^#Q!"%P'0*Z"&H__^#.`)U:H/L"%-6Z`*G__^#Q!"%P'4+
M,<"-9?A;7LG#B?;H^Z?__X,X`G3K@^P0Z.ZG__]9_S#H%J7__XD$)%9HP%`%
M".L9@^P0Z-.G__]:_S#H^Z3__XD$)%9HX%`%"&H`:@#HN2@``+C_____ZZF#
M[!#HJJ?__UO_,.C2I/__B00D5F@`404(Z]6-=@!5B>575E.#['2-78A3BW4(
M5HM]#.@[J?__@\00A<!T##'`C67T6UY?R<.)]H/L"%-7Z!ZI__^#Q!"%P'0[
M@^P(5U;H7:;__X/$$(7`=-*#[!#H/J?__UK_,.AFI/__65M05U9HT%$%"&H`
M:@#H(R@``+C_____ZZI7:"!1!0AJ`&H`Z`TH``"X_____^N4B?95B>564X/L
M8(MU"(M=%.CQIO__QP``````@^P(C4684%;HGJC__X/$$(7`=`LQP(UE^%M>
MR<.)]E#_=1#_=0Q6Z)^E__^#Q!"%P'4]@^P(#[?34E;HFZ7__X/$$(7`=,V#
M[!#HG*;__UG_,.C$H___B00D5FA@404(:@!J`.B")P``N/_____KIH/L$.AS
MIO__6_\PZ)NC__^)!"16:(!1!0CKU56)Y5.#[!#_=0CH<:?__X/$$(7`B<-U
M"(G8BUW\R<.0@^P0Z#BF__]:_S#H8*/__X/$$%!H[E$%"&H`:@#H'B<``(G8
M@\00BUW\R<-5B>575E.#[&R+?0C'!P````"+70R+,X7V="N-=8B)]H/L"%;_
M,^BII___@\00A<!T'H/#!.C:I?__BPN%R<<``````'7:C67T6UXQP%_)PXL#
MB0>-9?1;7K@!````7\G#D)"058GE5U93@>R$,```C5V(4XMU"%:+?0SH=*7_
M_X/$$(7`=1`/MT60)0#P```]`$```'0*,<"-9?1;7E_)PX/L"%-7Z$FE__^#
MQ!"%P'7E#[=5D('B`/```('Z`$```'73@^P(:``0``"-G8C/__]3Z)RF__^)
M-"3HY*3__UY8:``0``"-M8CO__]6Z(&F__^)/"3HR:3__UI9:``0``"-E8C?
M__]2Z&:F__^-O8C?__^)'"3HJ*3__S'`_+G_____\J[WT8U9_U!35HV-B-__
M_U''A8#/__\`````Z""E__^#Q""%P'4*@+P=B.___R]T"XN%@,___^DY____
MQX6`S___`0```.OI58GEBU4(,<"%TG0%@#H`=06X`0```,G#58GE5U93@>R`
M,```BUT(:``0``!J`(V%B-___U#H;J7__X/$#&@`$```:@!H0)@%".A:I?__
M7E]H`!```(VUB,___U;HIZ7__X/$$(7`#X15`0``@^P(C56(4E/H[Z7__X/$
M$(7`#X5(`0``46@`$```4XV=B.___U/H<:3__P^W39"!X0#P``"#Q!"!^0!`
M``!T+(/L"&HO4^@1H___@\00A<!T?L8``%)H`!```$!0C;V(W___5^@SI/__
M@\00@^P,4^AWH___@\00A<!U&8/L"&@`$```:$"8!0CH#J7__X/$$(7`=1M0
M:`Q2!0AJ`&H`Z)@D``"-9?1;7C'`7\G#B?:`O8C?__\`=3^#[`Q6Z"JC__^-
M9?1;7KA`F`4(7\G#D%!H`!```%.-A8C?__]0Z+FC__^#Q`QH`!```&CC*P4(
M4^EN____B?;\OT"8!0A0N?____\QP/*NNP`0``#WT4F)VBG*4FA34@4(:$"8
M!0CHV*/__[]`F`4(_#'`N?_____RKO?128/$#"G+4XV=B-___U-H0)@%".BO
MH___@\00Z63___]3:%52!0CI.____U-H-%(%".DP____D%6)Y8/L$/]U"&B_
M&`4(Z-T"``"#Q`Q0_S4<>`4(:')2!0CH+2(``,G#C78`58GEBU4(,<"%TG0(
M,<"#.@`/G\#)PXGV58GEBU4(A=*X`0```'0(,<"#.@`/E,#)PXUV`%6)Y593
MBUT(,?:%V[C_____="B+`X7`?A"#[`Q0Z/ZD__^#Q!"%P'@IBT,$A<!U%(/L
M#%/H]Z3__XGPC67X6U[)PXGV@^P,4.CCI/__@\00Z]Z#[!#H%J+__UK_,.@^
MG___B00D_W,$:*A2!0AJ`6H`Z/HB``"^_____X/$(.NI58GE5E.+70@Q]H7;
MN/____]T*XL#A<!^$(/L#%#H?J3__X/$$(7`>"V+0P2%P'48@^P,4^AWI/__
M@\00B?"-9?A;7LG#C78`@^P,4.A?I/__@\00Z]J#[!#HDJ'__UG_,.BZGO__
MB00D_W,$:*A2!0AJ`6H`Z'8B``"^_____X/$(.NE58GE5U93@^P8BWT(BW44
M:@CHMI___X/$$#'2A<")PW129H7VQP``````QT`$`````'5-@^P(5V@%4P4(
MZ*\@``"#Q`R)0P1HI`$``/]U#%#H-Z/__X/$$(7`B0-X88/L"/]U$%#H$J'_
M_X/$$(7`B=IU?8UE]%M>B=!?R<.-=@"#[`A7:+\8!0CH_@```(/$#%#_-1QX
M!0AH<E(%".A.(```@\0,B4,$:*0!``#_=0Q0Z-:B__^#Q!"%P(D#>9^#[!#H
MI:#__U[_,.C-G?__B00D_W,$:(=2!0AJ`&H`Z(DA``")VHUE]%M>B=!?R<.0
M@^P,_S/H(J/__X/$$.AJH/__@S@C#Y3"#[;"2(G:B0/KTXGV58GE@^P(#[]%
M#%!J!F@"!@``_W4(Z-+^___)PU6)Y8/L"`^_10Q0:@)H`@8``/]U".BV_O__
MR<-5B>575E.#[`R+?0B^0*@%"#';D%`/M@0?4&C74@4(5D/H>J'__X/&`H/$
M$(/[#W[CC67T6UZX0*@%"%_)PXGV58GE5U93@>PH$```_W4,_W4(:%(S!0B-
MG>CO__]H`!```%/H&)W__X/$'&H`B=_\,<"Y______*N]]%)45/HK9S__XG&
M@\00NT"H!0@Q_Y!2#[84/E)HUU(%"%-'Z/Z@__^#PP*#Q!"#_P]^XXUE]%M>
MN$"H!0A?R<.0D%6)Y5=64X'L'!```*%H=P4(A<"+70B+?0P/A2$!``"+#01K
M!0@/OU$..=H/A/,```"A`&L%"`^_0`XY^`^$X@```(/L#(V5X.___U+H$Y[_
M_^B>G___@\00A<")Q@^,#@(```^$$`$``(/L#/^UY.___^B=H?__C9WH[___
M@\00ZRB)]L:$!>?O__\`4V@%4P4(:@!J`.C)'P``7_\U"&L%".A]G?__@\00
M46C_#P``4_^UX.___^C8GO__@\00A<!_P8/L#/^UX.___^A#H?__@\0,:@*-
MG=SO__]35NAAF___@\000`^$K@$``(N5W.___XG0@^!_=!N#^']T"(7`#X6O
M`0``B=>#YW^#_W\/A$$!``"-9?1;7HG0P?@(7\G#B?90:-!3!0AJ`&H`Z#$?
M``"-9?1;7KC_____7\G#@^P,_S4$:P4(Z!:@__^#Q!`YV'3/BS5H=P4(A?8/
MA,[^__^#[`S_-0!K!0CH\Y___X/$$.G!_O__@^P,:@#HD:#__\<$)`$```#H
MA:#__\<$)`(```#H>:#__UC_M>#O___H;:#__UY8:@!3Z..;__]96VH!5^C9
MF___6%IJ`O^UY.___^C*F___7UC_=13_=1#H/9[__XF%W.___^B"G?__7O\P
MZ*J:__^#Q`Q0:`A4!0C_-0AK!0CHYIS__^AAG?__@\00@S@.=#K_-0AK!0AJ
M`FH!:-Q2!0CH%9___UO_-0AK!0CH^9O__UG_M>3O___HW9___XN%W.___XUE
M]%M>7\G#_S4(:P4(:EAJ`6@L5`4(Z\2#[`S!^@A25FB(5`4(:@!J`.CX'0``
MZ<+^__^#[!#HZYS__UK_,.@3FO__@\004&B\5`4(:@%J`>C1'0``@\00Z9C^
M__^#[!#HP9S__UK_,.CIF?__B00D5FC<5`4(ZZV#[`Q05F@@504(ZZ&)]E6)
MY5=64X/L#(MU"(E%\(M]#(U&_#GXB=-V*5&+%XG0]]`#!E`#$U*+3?#_,>B>
MG/__@\00A<!^/P$'C67T6UY?R<.0BQ:#[`B!P@`0``")%E+_,^C'G/__@\00
MA<")`W6Y4&C?4@4(:@%J`>@O'0``@\00ZZ6)]H/L#(MU\/\VZ,N>__^+7?#'
M`______H#9S__UK_,.@UF?__@\0,4&A4504(_S4(:P4(Z'&;___H[)O__\<`
M`````(/$$(UE]%M>7\G#C78`58GE5U93@>P\`0``,<F-71"-512#?1``ZPJ)
MT(LX08/"!(7_=?2#[`R-%(T(````4N@"FO__@\00A<")A=#^__\/A&T#``"+
MC=#^__^+=0R),8U3!+D!````BP/K$8G3B[W0_O__B02/@\($08L#A<!UZXN5
MT/[__X/L#(V%X/[__\<$B@````#'A<C^__\`````4.@_FO__@\00Z,>;__^%
MP(F%S/[__P^,Q@(```^.SP,``(/L#,>%Q/[__P`0``#_M>3^___HNYW__\>%
MP/[__P````#'!"0`$```Z%69__]:68M-"(D!:@/_M>#^___H89W__X/(!(/$
M#%!J!/^UX/[__^A-G?__C;5H____@\00N"````!(A<#'!(8`````=?2-G>C^
M__^P($B%P,<$@P````!U](N-X/[__XG/L`&#X1_3X,'O!0F$O6C____H@9K_
M_XV]V/[__X/L#,<``````,>%V/[__P$```#'A=S^__\`````5U-35HN5X/[_
M_T)2Z.V8__^#Q"#H19K__XL`A<`/A>X```"+E>#^__^)T,'H!8G1@^$?BX2%
M:/___]/HJ`$/A/@```!0BX7$_O__*X7`_O__2%"+A<#^__^+30@#`5!2Z"F:
M__^#Q!"#^/\/A$8"``"%P`^.\0```(N5Q/[__P&%P/[__TH[E<#^__\/CM0!
M``"X(````(UV`$B%P,<$A@````!U]+`@B?9(A<#'!(,`````=?2+C>#^__^)
MRK`!@^$?T^#!Z@4)A)5H____Z(J9__^#[`S'``````#'A=C^__\!````QT<$
M`````%=34U:+E>#^__]"4NC_E___@\0@Z%>9__^+`(7`#X02____Z$B9__^#
M.`1U3XN5X/[__XG0P>@%B=&#X1^+A(5H____T^BH`0^%"/___U!J`8V5U/[_
M_U+_M<S^___H[97__X/$$#N%S/[__P^%,O___\>%R/[__P$```"+30B+.8N=
MP/[__\8$'P"+M<C^__^%]@^$"0$``(N%U/[__ZA_N_____]U%XG#P?L(#X2!
M````@?O_````#X1"`0``@^P(BW4(_S93_W4,:'A5!0AJ`6H`Z)<9``"#Q""+
M30B#[`S_,>A'F___@\00BWT(@^P,QP<`````_[70_O__Z"V;__^-9?2)V%M>
M7\G#@^P0Z%N8__]:_S#H@Y7__X/$$%!H]E(%"&H!:@'H01D``#';@\00@^P,
M_[70_O__Z.Z:__^-9?2)V%M>7\G#@^P0Z!R8__]>_S#H1)7__X/$$%!H"%,%
M"&H!:@'H`AD``(/$$.EI_/__B?:#[`B!A<3^__\`$```_[7$_O__BT4(_S#H
M6YC__XM-"(/$$(D!Z0+^___'A=3^__\`````4VH`C874_O__4/^US/[__^B/
ME/__@\00Z=#^___HHI?__X,X!`^$I?[__X/L$.B1E___6?\PZ+F4__^#Q!!0
M:"-3!0AJ`6H`Z'<8``"#Q!#I>_[__XM5"/\R:$!3!0AJ`6H`Z%P8``"#Q!#I
MP/[__X/L#/^UX/[__^CVF?__QP0D`0```.CJF?__QP0D`@```.C>F?__6%IJ
M`?^UY/[__^A/E?__7UAJ`O^UY/[__^A`E?__6U[_M=#^____=0SHL)?__^C[
MEO__6?\PZ".4__^#Q`Q0_W4,:$I3!0CHXI/__\<$)/_____HMIC__XGV58GE
M5E.+=0B+70PYWHGP=!N#_O]T'H/L"%-6Z.24__^)PXDT).A:F?__B=B-9?A;
M7LG#D(/L"&H":+XR!0CHL9C__XG&@\00@_[_N/____]UQ.O858GE5E.![+`!
M``"+=0B-30R)M5C^__^Z`0```(/Z8W\3B<N+`X/!!(F$E5C^__]"A<!UZ,=%
MZ`````#HT);__X7`="6#[`R-C53^__]1Z/V5__^#Q!`QP/:%5/[__W\/E<"-
M9?A;7LG#@^P,:@#HO9C__\<$)`$```#HL9C__\<$)`(```#HI9C__UA::@)H
MOC(%".@'F/__68G#6&H`4^@+E/__6%IJ`5/H`93__UE8:@)3Z/>3__]86HV5
M6/[__U)6Z&B6__^)!"3HD)?__U6)Y5=64X/L%&@$+@4(_W4,QT7P`````.B#
MDO__@\00A<")Q@^$)`$``(/L#&@!$```QT7L`!```,=%Z`````#HRY/__X/$
M$(7`B<</A!H!``#&``#K+Y"+5@1*A=*)5@0/B-0```"+#@^V&4&#^_^)#G0O
MBT7L.47H=%B+1>B('#A`B47HBQUH=P4(A=MTR(/L#%;H!Y/__XG#@\00@_O_
M==&#[`R+1>C&!`<`5NA-DO__@\00@_C_='?!^`AT`XE%\(MU"(D^BT7PC67T
M6UY?R<.0BU7H@^P(@<(!$```4HM-Z('!`!```%>)3>SH/97__X/$$(7`B<=U
M@/\U"&L%"&I):@%HG%4%".APEO__QT7H`````(/$$(/L#(M%Z,8$!P!6Z-:1
M__^#Q!"#^/]UB<=%\/_____KB(/L#%;H#)+__XG#@\00Z5#_____-0AK!0AJ
M7&H!:.A5!0CH'I;__[C_____Z5______-0AK!0AJ)FH!:$A6!0CKX(UV`%6)
MY5.#[`R-1?C'1?@`````_W4(4.AF_O__@\00@_C_B<-T/(7`=".+1?B#[`R`
M.`!U!;A=4P4(4%-H<%8%"&H!:@#HZ!0``(/$((/L#/]U^.B:EO__B=B+7?S)
MPXUV`(/L$.C(D___6O\PZ/"0__^#Q!!0:)Q6!0AJ`6H`Z*X4``"#Q!"#[`S_
M=?CH8);__XG8BUW\R<.058GE5E/HKI#__XG&NP,````Y\WT4C78`@^P,4^@G
MEO__0X/$$#GS?._H:I/__\<``````(UE^%M>R<.058GE5U93@^P,BWT4Z-N3
M__^#^/^)PP^$P````(7`#X7,````BW4(A?9T)(/^_P^$Q@```(/L"&H`5NA-
MD?__B<.)-"3HPY7__X/$$$-T8(MU#(/^`70D@_[_#X2Y````@^P(:@%6Z"&1
M__^)PXDT).B7E?__@\000W0TBW40@_X"#X2T````@_[_#X3_````@^P(:@)6
MZ/&0__^)PXDT).AGE?__@\000P^%C````(/L$.BEDO__7O\PZ,V/__^#Q`Q0
M:&E3!0C_-0AK!0CH"9+__UMJ_^AAE/__D%=HR%8%"&H!:@'H<1,``(/$$(GV
MC67TB=A;7E_)PX/L"&H":+XR!0CH<Y3__X/$$(/X_XG&#X4=____ZY:#[`AJ
M`FB^,@4(Z%24__^#Q!"#^/^)Q@^%*O___^ET____Z#R/__^[`P```#G#B<9\
M:>@,DO__@^P(QP``````_W485^BJDO__@^P0Z/*1__]9_S#H&H___X/$$%!7
M:.A6!0C_-0AK!0CH59'__X/$%.E%____@^P(:@)HOC(%".C>D___@\00@_C_
MB<8/A>3^___I_O[__XUV`(/L#%-#Z$Z4__^#Q!`Y\WV&@^P,4T/H/93__X/$
M$#GS?-[I</___Y!5B>575E.![-@```"+10B+30R-M6#____'``````#'`0``
M``!6QX5(____`````,>%3/___P````#'A4#___\`````QX5$____`````,>%
M-/___P````#'A3#___\`````Z!J0__^#Q!!`#X7O`0``C9U8____4&@,5P4(
M:@%J`>C[$0``@\00BY5@____BX58____.=!]`HG0C7@!4&H$:@12Z%B3__^#
MQ!!`#X0B`@``46H$:@3_M5C____H/I/__X/$$$`/A`@"``"#[`S_=13_=1#_
M<P3_=@1J`.A"_?__BXU@____@\0@@_G_B84X____#X3Q`0``BYU8____C;5H
M____N"````"02(7`QP2&`````'7T@_G_=!.)RK`!@^$?P>H%T^`)A)5H____
M@_O_=!B)VH/C'[@!````B-G!Z@73X`F$E6C____'A5#___\!````QX54____
M`````(V=4/___^@4D/__@^P,QP``````4VH`:@!65^B?CO__@\0@A<`/CG0!
M``"+C6#___^%R7X9B<K!Z@6#X1^+A)5H____T^BH`0^%T0```(N=6/___X7;
M?AN)VL'J!8G9@^$?BX25:/___]/HJ`$/A=,```"+C6#___^#^?\/A2/___^#
M^_\/A1K___^+M3#___^%]G4UZ(6/___'``````!0:@&-O3S___]7_[4X____
MZ$J,__^#Q!"%P,>%-/________\/A6,!``"+10B+$(72=`J+C4S____&!`H`
MBW4,BQ:%TG0*B[U$____Q@0Z`(N%-/___XUE]%M>7\G#@^P,C9U8____4^@2
MCO__@\000`^%$/[__^GY_?__C78`@^P(C9U,____4XV-2/___U&+50B-A6#_
M___H0?+__X/$$.D(____@^P(C85$____4(V=0/___U.+50R-A5C____H&O+_
M_X/$$(N=6/___^D`____4F@P5P4(:@%J`>B=#P``@\00Z>']__^+G5C___^#
M^_\/A0;^___I]_[__Y#H>X[__\<``````%!J`8V-//___U'_M3C____H0(O_
M_X/$$(7`=*+H5([__XL0A=)U4(N%//___ZA_=4;!^`B)A33___^#[`S_M5C_
M___HW9#__UC_M6#____'A5C_________Z,>0___'A6#_________QX4P____
M`0```.E$____QX4T_________^NWZ.V-__^+&(7;=1N+A3S___^H?W41P?@(
MB84T____Z7K^__^-=@#'A33_________Z6C^__^058GE5E,QR8U=%(U5&(-]
M%`#K"Y")T(LP08/"!(7V=?2#[`R-%(T$````4NCLB___@\00A<")QG1'BP,Q
MR87`C5,$B09U!>L/B02.B=.+`T&#P@2%P'7QQP2.`````%;_=1#_=0S_=0CH
MS_O__XG#B30DZ`60__^-9?B)V%M>R<.#[!#H-(W__UK_,.A<BO__@\004&B'
M4P4(:@%J`>@:#@``@\00ZY*058GE5E.#[!"+=0C_=0Q6C57T4HU%\%#H>/O_
M_X/$$(7`B<-T*XM-$(7)=22+1?"%P'4ZBT7TA<!T2H/L#%!6:)M3!0AJ`6H`
MZ,<-``"#Q""#[`S_=?#H>8___UC_=?3H<(___XUE^(G86U[)PX/L"%#_-0AK
M!0CH&(S__X/$$.NRC78`5FA@5P4(:@%J`.B!#0``@\00@^P,_W7PZ#./__]8
M_W7TZ"J/__^-9?B)V%M>R<.058GE5U93@^P,,<F+?0B-=0R-51"#?0P`ZPR)
M]HG0BQA!@\($A=MU](/L#(T4C00```!2Z(B*__^#Q!"%P(G##X36````BP8Q
MR87`C58$B0-U!>L/B02+B=:+!D&#P@2%P'7QQP2+`````%-7C57P4HU-[%'H
M9_K__X/$$(7`B<9T)(M%[(7`=7N+1?"%P'0\@^P,4%=HFU,%"&H!:@#HO0P`
M`(/$((/L#/]U[.AOCO__6/]U\.AFCO__B1PDZ%Z.__^-9?1;B?!>7\G#5VA@
M5P4(:@%J`.B%#```@\00@^P,_W7LZ#>.__]8_W7PZ"Z.__^)'"3H)H[__XUE
M]%N)\%Y?R<.#[`A0_S4(:P4(Z,V*__^#Q!#I;O___X/L$.@]B___6O\PZ&6(
M__^#Q!!0:(=3!0AJ`6H!Z",,``"#Q!#I`/___XUV`%6)Y593@^P0BUT(_W4,
M4XU5]%*-1?!0Z'SY__^#Q!"%P(G&="2+1?"%P'5TBT7TA<!T.8/L#%!3:)M3
M!0AJ`6H`Z-(+``"#Q""#[`S_=?#HA(W__UC_=?3H>XW__X/$$(UE^%N)\%[)
MPXUV`%-H8%<%"&H!:@#HG0L``(/$$(/L#/]U\.A/C?__6/]U].A&C?__@\00
MC67X6XGP7LG#B?:#[`A0_S4(:P4(Z.F)__^#Q!#I=?___Y!5B>564X'L&!``
M`(M="&HO4^AZC/__@\00A<`/A:L```"#[`Q3_S4<>`4(:+-3!0AH`!```(V=
M^.___U/H?X?__X/$(/]U#%.-E?3O__]2C87P[___4.B%^/__@\00A<")QG0L
MBX7P[___A<!U>HN%].___X7`=$"#[`Q04VB;4P4(:@%J`.C5"@``@\0@B?:#
M[`S_M?#O___H@HS__UC_M?3O___H=HS__X/$$(UE^%N)\%[)PXGV4VA@5P4(
M:@%J`.B9"@``@\00Z\13:(!7!0AJ`&H`Z(4*``"-9?A;N/____]>R<.0@^P(
M4/\U"&L%".CIB/__@\00Z6____^058GE5E.![+`!``"+=0B-30R)M5C^__^Z
M`0```(/Z8P^/GP```(G+BP.#P02)A)58_O__0H7`=>2#^F,/CX,```#'A)58
M_O__`````(V%6/[__U!6C8U4_O__48V54/[__U+H>??__X/$$(7`B<-T+HN%
M4/[__X7`#X6*````BX54_O__A<!T2(/L#%!6:)M3!0AJ`6H`Z,4)``"#Q""#
M[`S_M5#^___H=(O__UC_M53^___H:(O__X/$$(UE^(G86U[)P\=%Z`````#I
M?/___U9H8%<%"&H!:@#H@0D``(/$$(/L#/^U4/[__^@PB___6/^U5/[__^@D
MB___@\00C67XB=A;7LG#@^P(4/\U"&L%".C)A___@\00Z5____^058GE5E.!
M[+@1``"+=0AJ+U;H6HK__X/$$(7`#X4``0``@^P,5O\U''@%"&BS4P4(:``0
M``"-M?CO__]6Z%^%__^-70R)M5CN__^Z`0```(/$((GV@_IC#X^A````B=F+
M`8/#!(F$E5CN__]"A<!UY(/Z8P^/A0```,>$E5CN__\`````C858[O__4%:-
MG53N__]3C950[O__4N@A]O__@\00A<")PW0PBX50[O__A<`/A88```"+A53N
M__^%P'1-@^P,4%9HFU,%"&H!:@#H;0@``(/$((GV@^P,_[50[O__Z!J*__]8
M_[54[O__Z`Z*__^#Q!"-9?B)V%M>R</'A>CO__\`````Z7?___]6:&!7!0AJ
M`6H`Z"0(``"#Q!#KMU9H@%<%"&H`:@#H$`@``(UE^%NX_____U[)PX/L"%#_
M-0AK!0CH=8;__X/$$.EC____D%6)Y5=64X/L##')BWT(C74,C540@WT,`.L,
MB?:)T(L808/"!(7;=?2#[`R-%(T$````4N@4A?__@\00A<")PP^$U@```(L&
M,<F%P(U6!(D#=07K#XD$BXG6BP9!@\($A<!U\<<$BP````!35XU5\%*-3>Q1
MZ//T__^#Q!"%P(G&="2+1>R%P'5[BT7PA<!T/(/L#%!7:)M3!0AJ`6H`Z$D'
M``"#Q""#[`S_=>SH^XC__UC_=?#H\HC__XD<).CJB/__C67T6XGP7E_)PU=H
M8%<%"&H!:@#H$0<``(/$$(/L#/]U[.C#B/__6/]U\.BZB/__B1PDZ+*(__^-
M9?1;B?!>7\G#@^P(4/\U"&L%".A9A?__@\00Z6[___^#[!#HR87__UK_,.CQ
M@O__@\004&B'4P4(:@%J`>BO!@``@\00Z0#___^-=@!5B>575E.![,@```"+
M50B-A6#____'`@````!0QX50____`````,>%5/___P````#'A43___\`````
MZ&6$__^#Q!!`#X0,`@``4FH$BXU@____:@2-60%1B9U`____Z,&'__^#Q!!`
M#X0>`@``@^P,_W40_W4,:@+_M63___]J`.C#\?__BYU@____@\0@@_O_B85(
M____#X2D````C;5H____C;U8____N"````")]DB%P,<$A@````!U](/[_W05
MB=J#XQ^P`8C9P>H%T^`)A)5H____QT<$`````,>%6/___P$```#HN(3__X/L
M#,<``````%=J`&H`5O^U0/___^@^@___@\0@A<`/CML```"+G6#___^%VWX7
MB=K!Z@6)V8/A'XN$E6C____3Z*@!=6&#^_\/A6[___\Q_X7_=3'H7H3__\<`
M`````%=J`8V53/___U+_M4C____H(X'__X/$$(7`QX5$_________W5.BT4(
MBQ"%TG0*BXU4____Q@0*`(N%1/___XUE]%M>7\G#@^P(C854____4(V=4/__
M_U.+50B-A6#____H4N?__X/$$(N=8/___^ER____Z-^#__^+&(7;=16+A4S_
M__^H?W4+P?@(B85$____ZY+'A43_________ZX;HLX/__\<``````%!J`8V-
M3/___U'_M4C____H>(#__X/$$(7`=*+HC(/__XLPA?8/A8````"+A4S___^H
M?W5VP?@(B85$____@^P,_[5@____Z!&&__^#Q!#'A6#_________Z1W___]1
M:`Q7!0AJ`6H!Z$`$``"#Q!!2:@2+C6#___]J!(U9`5&)G4#____HHX7__X/$
M$$`/A>+]__]0:#!7!0AJ`6H!Z`H$``"#Q!#IR_W__\>%1/_________KAXGV
M58GE5E,QR8U=$(U5%(-]$`#K"Y")T(LP08/"!(7V=?2#[`R-%(T$````4N@D
M@?__@\00A<")QG1%BP,QR87`C5,$B09U!>L/B02.B=.+`T&#P@2%P'7QQP2.
M`````%-6_W4,_W4(Z.7\__^)PXDT).@_A?__C67XB=A;7LG#@^P0Z&Z"__]:
M_S#HEG___X/$$%!HAU,%"&H!:@'H5`,``(/$$.N4C78`58GE5E,QR8U=&(U5
M'(-]&`#K"Y")T(LP08/"!(7V=?2#[`R-%(T$````4NA\@/__@\00A<")QG1.
MBP,QR87`C5,$B09U!>L/B02.B=.+`T&#P@2%P'7Q@^P,QP2.`````%;_=13_
M=1#_=0S_=0CH?>[__X/$%%:)P^B.A/__C67XB=A;7LG#@^P0Z+V!__]:_S#H
MY7[__X/$$%!HAU,%"&H!:@'HHP(``(/$$.N+B?95B>575E.#[&R+?0R%_P^$
MF0```(7_B?YT:X`_`'1FD(/L"&HZ5NA1@O__@\00A<")PW1<*?!#_W4(5E!H
MPU,%".C:````B<986HU5B%)6Z`B#__^#Q!"%P'43BTT0A<ET00^W?9"#YTF#
M_TET-8/L#%;HY8/__X/$$(7;B=YT!8`[`'6;,<"-9?1;7E_)PY`QP/RY____
M_XGW\J[WT8U!_^N4C67T6XGP7E_)PX/L#&C+4P4(Z&)^__^)QX/$$#'`A?\/
MA4O____KO)!5B>6#[`S'1?P`````_W4,_W4(C47\4.@D@___@\000'0&BT7\
MR<.0@^P0Z*"`__]:_S#HR'W__X/$$%!HPE<%"&H!:@'HA@$``(M%_(/$$,G#
MB?95B>6-50R#[`S'1?P`````4O]U"(U%_%#HSX+__X/$$$!T!8M%_,G#@^P0
MZ$R`__]9_S#H='W__X/$$%!HPE<%"&H!:@'H,@$``(M%_(/$$,G#D)!5B>6#
M[!3_=0CH^H'__XGV58GE5U93@^P,H62H!0@Q]H7`BUT(#X7!````@^P(_S4(
M:P4(4^@N@O__B=\QP/RY______*N]]&#Q!"`?!G^"G03@^P(_S4(:P4(:@KH
M=H'__X/$$(/L#/\U"&L%".AU?O__@\00A?9T%5)6:-U7!0C_-0!K!0CH''__
M_X/$$(/L"/\U`&L%"%/HRH'__XG?,<#\N?_____RKO?1@\00@'P9_@IT$X/L
M"/\U`&L%"&H*Z!*!__^#Q!"#[`S_-0!K!0CH$7[__XM5#(/$$(72=3N-9?1;
M7C'`7\G#D(/L#%#H8W[__X/$$(7`B<8/A"G___]14&C=5P4(_S4(:P4(Z)1^
M__^#Q!#I#____X/L#/]U#.CA@/__D%6)Y5=64X/L'(M-"(M5#(E-\(E5[.CF
M?O__BP"#[`R)1>3'1>@`$```:``0``#H+7W__X/$$(7`B<,/A"@!``"-=116
M_W40:``0``!0Z!Y]__^#Q!`]`!```(G&#XW2````Z)E^__^+5>2)$.B/?O__
MBSB%_W4I5O]U[/]U\%/H9/[__X/$$(7;=`R#[`Q3Z"R!__^#Q!"-9?1;7E_)
MPY"+3>@Q_RGQB4W@=#N#[!#H3'[__UG_,.AT>___B00DZ#Q^____,&CB5P4(
M_W7@C3PS5^B)>___@\0@.T7@#YW`#[;XA?]TD(/L"(U4-P%24^B+?O__@\00
MA<`/A'?___^#[!")P^CV??__6O\PZ!Y[__^)!"3HYGW___\P:.)7!0A7C0PS
M4>@U>___@\0@Z43___^0@^P(C7@!5U/H/W[__X/$$(7`#X06____B<.-112)
M?>A0_W405U/H$7S__X/$$.G[_O__D%#_=>S_=?!H^%<%".AO_?__C67T6UY?
MR<.0D)!5B>534KM8:04(H5AI!0CK"HUV`(/K!/_0BP.#^/]U]%A;R<.#[`SH
MM(#__X/$#,,D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O8W)T:2Y3
M+'8@,2XW(#(P,#4O,#4O,3D@,#<Z,S$Z,#8@9&9R($5X<"`D`"`H8G)O:V5N
M('-Y;6QI;FLI`"5S"25L=0DE;&QU"0`E<PDE<PD`)3`S;PH`<W1A="!F86EL
M960Z("5S"@!O<&5N9&ER(&9A:6QE9#H@)7,*`&9I;&5S`&1I<G,`8F]T:``E
M<R\E<RU86%A86%@`<'-A+71E;7`M9FEL90!P<V%A9&T`<F]O=`!C<#)T96UP
M;F%M`$YO="!A;&QO=V5D('5S97(@)W)O;W0G"@`O8FEN+VQS`"]B:6XO8V%T
M`"]B:6XO8VAM;V0`+V)I;B]C<``O=7-R+V)I;B]T;W5C:``O8FEN+VUV`"]B
M:6XO<FT`+V)I;B]M:V1I<@`O8FEN+W)M9&ER`"]U<W(O8FEN+V9I;&4`;&ES
M=``M+6EN+6)L;V-K<P!F:6QE7V5X:7-T<P!R96%L<&%T:`!S:7IE`"5I"@!5
M;F%B;&4@=&\@9V5T('-I>F4@9F]R("<E<R<*`"5L;&0*``!7<F]N9R!C;VUM
M86YD(&]P=&EO;B!T;R!L:7-T(&9I;&5S"@!5;F%B;&4@=&\@8V]P>2!T:&4@
M9FEL92`E<R!T;R`E<PH```!%<G)O<B!D=7)I;F<@=&5M<&]R87)Y(&YA;64@
M8W)E871E"@!%<G)O<B!O8V-U<F5D(&1U<FEN9R`E<R!C;VUM86YD+@H```!3
M>7-T96T@17)R;W(Z(&EN=F%L:60@87)G=6UE;G0@;G5M8F5R("5D+"!M=7-T
M(&)E(#,@;W(@;6]R90H`````075T:&5N=&EC871I;VX@9F%I;&5D+"!Y;W4@
M87)E(&YO="`E<R!O<B!R;V]T("T@8V%N;F]T('-T87)T('!R;V=R86UM+@H`
M56YA8FQE('1O(&5X96-U=&4@)7,@8V]M;6%N9#H@9&%E;6]N(&MI;&QE9"!B
M>2!S:6=N86P@)6D*````56YA8FQE('1O(&5X96-U=&4@)7,@8V]M;6%N9#H@
M9&%E;6]N('-T;W!P960@8GD@<VEG;F%L("5I"@``5W)O;F<@8V]M;6%N9"!N
M86UE(&]R('!A<F%M971E<B!N=6UB97(Z("5S"@!5;F%B;&4@=&\@<F5C:65V
M92!R96%L('!A=&@@9F]R("<E<R<*`"]T;7`O<'-A+6%U=&]R97-P;VYD97(M
M6%A86%A8````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````N+@!04D]$54-47U)/3U1?1`!(5%10
M1%]62$]35%-?1`!(5%101%]#3TY&7T0`2%144$1?24Y#3%5$15]$`$A45%!$
M7T))3E]$`%%-04E,7U)/3U1?1`!134%)3%]-04E,3D%-15-?1`!&5%!$7T-/
M3D8`17)R;W(Z($944$1?0T].1B!N;W0@9&5F:6YE9`H`1E101%]#3TY&7TE.
M0P!&5%!$7T))3E]$`$Y!345$7U)53E]23T]47T0`5T5"7U-4050`17)R;W(Z
M(%=%0E]35$%4(&YO="!D969I;F5D"@!,3T=23U1!5$4`17)R;W(Z($Q/1U)/
M5$%412!N;W0@9&5F:6YE9`H`35E344Q?5D%27T0`35E344Q?0DE.7T0`4$=3
M44Q?0DE.7T0`4$=344Q?1$%405]$`$U!24Q-04Y?4D]/5%]$`$U!24Q-04Y?
M5D%27T0`4%)/1%5#5%]20U]$`$1535!?1`!%<G)O<CH@1%5-4%]$(&YO="!D
M969I;F5D"@!#051!3$E.05](3TU%`$125T5"7U)/3U1?1`!$4E=%0E]%5$-?
M1`!#55),7T-!7T)53D1,15]&24Q%`"]A9&UI;B]C;VYF+W-E='1I;F=S`"]A
M9&UI;B]B:6XO9&YS;6YG`"]A9&UI;B]B:6XO;6%I;&UN9P`O861M:6XO8FEN
M+W5S97)M;F<`+V%D;6EN+V)I;B]F<%]W<F%P<&5R`"]A9&UI;B]B:6XO<FU?
M<&1?=7-R`"]A9&UI;B]B:6XO;6%K95]V<G0`+V%D;6EN+V)I;B]W96)S<G9M
M;F<`+V%D;6EN+V)I;B]R;5]F<FT`+V%D;6EN+V)I;B]I;G1E<F9A8V4`+V%D
M;6EN+V)I;B]D;VUA:6YM;F<`+V%D;6EN+V)I;B]C:&MC;VYF:6<`+W9A<B]C
M97)T:69I8V%T97,``$5R<F]R.B!(5%101%]62$]35%-?1"!N;W0@9&5F:6YE
M9`H``$5R<F]R.B!(5%101%]#3TY&7T0@;F]T(&1E9FEN960*`````$5R<F]R
M.B!(5%101%])3D-,541%7T0@;F]T(&1E9FEN960*`$5R<F]R.B!(5%101%]"
M24Y?1"!N;W0@9&5F:6YE9`H`17)R;W(Z(%%-04E,7U)/3U1?1"!N;W0@9&5F
M:6YE9`H`````17)R;W(Z(%%-04E,7TU!24Q.04U%4U]$(&YO="!D969I;F5D
M"@```$5R<F]R.B!&5%!$7T-/3D9?24Y#(&YO="!D969I;F5D"@```$5R<F]R
M.B`E<R!N;W0@9&5F:6YE9"!I;B!P<F]D=6-T(&-O;F9I9R!F:6QE`````$5R
M<F]R.B!.04U%1%]254Y?4D]/5%]$(&YO="!D969I;F5D"@````!%<G)O<CH@
M35E344Q?5D%27T0@;F]T(&1E9FEN960*`$5R<F]R.B!-65-13%]"24Y?1"!N
M;W0@9&5F:6YE9`H`17)R;W(Z(%!'4U%,7T))3E]$(&YO="!D969I;F5D"@!%
M<G)O<CH@4$=344Q?1$%405]$(&YO="!D969I;F5D"@````!%<G)O<CH@34%)
M3$U!3E]23T]47T0@;F]T(&1E9FEN960*``!%<G)O<CH@34%)3$U!3E]605)?
M1"!N;W0@9&5F:6YE9`H```!%<G)O<CH@4%)/1%5#5%]20U]$(&YO="!D969I
M;F5D"@````!%<G)O<CH@0T%404Q)3D%?2$]-12!N;W0@9&5F:6YE9`H```!%
M<G)O<CH@1%)714)?4D]/5%]$(&YO="!D969I;F5D"@````!%<G)O<CH@1%)7
M14)?151#7T0@;F]T(&1E9FEN960*`$5R<F]R.B!04D]$54-47U)/3U1?1"!N
M;W0@9&5F:6YE9`H`17)R;W(Z(&5M<'1Y(%5S97(`34%854E$(')E86-H960*
M`"]U<W(O8FEN+V9A;'-E`'!S86-L;@!P<V%S97)V`$5R<F]R.B!E;7!T>2!5
M<V5R(&]R($YE=U5S97(`8W)O;G1A8B`M;"`M=2`G)7,G`&5C:&\@)WDG('P@
M8W)O;G1A8B`M<B`M=2`G)7,G`&-R;VYT86(@+74@)R5S)R`G)7,G`$5R<F]R
M.B!E;7!T>2!5<V5R(&]R($AO;65$:7(`17)R;W(Z(&5M<'1Y(%5S97(@;W(@
M4VAE;&P`1F%I;&5D('1O('-E=&=I9#H@)60*`$9A:6QE9"!T;R!S971U:60Z
M("5D"@!5<V5R("5S(&YO="!F;W5N9`!#86YN;W0@8VAD:7(@=&\@)7,@:&]M
M961I<B`E<P!S971S:60H*2!F86EL960`+V1E=B]N=6QL`$5R<F]R.B!E;7!T
M>2!U<V5R`"]E=&,O9G1P=7-E<G,`96-H;R`G>65S)WQC<F]N=&%B("UR("UU
M("<E<R<`+W5S<B]S8FEN+W!W('5S97)D96P`)7,@)R5S)P!5;F%B;&4@=&\@
M96YA8FQE(&9T<"!A8V-E<W,*`"]B:6XO8F%S:``O8FEN+W-H`"5S)7,`971C
M`"]U<W(O8FEN+V=R97``+W5S<B]L;V-A;"]B:6XO9W)E<`!E=&,O;6%S=&5R
M+G!A<W-W9`!E=&,O<'=D+F1B`&5T8R]S<'=D+F1B`&5T8R]P87-S=V0`<F]O
M=#HJ.C`Z,#HZ.CHF.B\Z+V)I;B]F86QS90H`)7,Z*CHE9#HE9#HZ.CHF.B\Z
M)7,*`"UD`"UP`"]U<W(O<V)I;B]P=V1?;6MD8@`E<R@I.B!U<V5R("5S(&YO
M="!F;W5N9``O971C+V=R;W5P`"U%`'5N;&EN:R@E<RD@9F%I;&5D`'5N;&]C
M:P!5;F%B;&4@=&\@9F]R:P!A;&QO=P!C<F]N=&%B;6YG`&1E;GD`(0`O=7-R
M+W-B:6XO<'<@=7-E<F%D9"`G)7,G("UU("5U("UD("<E<R<@+6<@)R5S)R`M
M<R`G)7,G`"]U<W(O<V)I;B]P=R!U<V5R;6]D("<E<R<@+6P@)R5S)P```"]U
M<W(O<V)I;B]P=V1?;6MD8B`O971C+VUA<W1E<BYP87-S=V0```!%4E)/4CH@
M56YA8FQE('1O(&-R96%T92!T96UP(&9I;&4@)R5S)R!N86UE('1O('-T;W)E
M('5S97(@8W)O;G1A8@H``$524D]2.B!5;F%B;&4@=&\@;W!E;B!C<F]N=&%B
M(&]F('5S97(@)R5S)PH`+W5S<B]S8FEN+W!W('5S97)M;V0@)R5S)R`M;2`M
M9"`G)7,G`````"]U<W(O<V)I;B]P=R!U<V5R;6]D("<E<R<@+7,@)R5S)P``
M`$-A;FYO="!R=6X@87,@9F]R8FED9&5N('5I9#H@)60*`````%5N86)L92!T
M;R!I;FET(&YE=R!G<F]U<',@9F]R('5S97(@)7,Z("5S````0VQO<V4@=7-E
M<B`G)7,G('-E<W-I;VX@9F%I;&5D"@!%<G)O<B!O8V-U<F5D(&1U<FEN9R!C
M;&]S92!U<V5R("<E<R<@<V5S<VEO;CH@)7,*````56YA8FQE('1O(&-L;W-E
M('5S97(@)R5S)R!S97-S:6]N.B!D865M;VX@<W1O<'!E9"!B>2!S:6=N86P@
M)6D*`%5N86)L92!T;R!C;&]S92!U<V5R("<E<R<@<V5S<VEO;CH@9&%E;6]N
M(&MI;&QE9"!B>2!S:6=N86P@)6D*``!S971U<%]C:')O;W0Z(&-H9&ER*"5S
M*2!F86EL960``&UK7V=R;W5P.B!G<F5P(&YO="!F;W5N9"P@;F]T('=R:71I
M;F<@9W)O=7!S(&9I;&4*``!S971U<%]C:')O;W0Z('!A<W-W9"!D871A8F%S
M92!U<&1A=&4@9F%I;&5D`%YP<V%S97)V.GQ>6UXZ72HZ6UXZ72HZ*#!\)60I
M.GQ;+#I=)7,H+%M>.ETJ?"DD`'-E='5P7V-H<F]O=#H@=W)I=&4@=&\@>W)O
M;W1]+V5T8R]P87-S=V0@9F%I;&5D`"5S*"DZ($YO(&-H<F]O=&5D('-H96QL
M(&9O<B`E<R!F;W5N9`````!M:U]G<F]U<#H@9W)E<"!E>&5C=71I;VX@9F%I
M;&5D`&UK7V=R;W5P.B!O<&5N*"]E=&,O9W)O=7`I(&9A:6QE9``O=&UP+V-R
M;VYT86(M=&UP+5A86%A86%@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````<V5T=7!?
M8VAR;V]T`"]U<W(O<V)I;B]P=P`O=7-R+W-B:6XO<'<`+W5S<B]B:6XO8VAP
M87-S`````$5R<F]R(&]C8W5R<F5D('=H:6QE(&QO8VMI;F<@=&AE(&9I;&4@
M)7,*````56YA8FQE('1O(&-O<'D@9FEL92`E<R!T;R`E<SH@)7,*````17)R
M;W(@;V-C=7)R960@=VAI;&4@=6YL;V-K:6YG('1H92!F:6QE("5S"@!%<G)O
M<B!W:&EL92!C;W!Y:6YG(&9I;&4@)7,@=&\@)7,Z("5S````8V]P>5]F:6QE
M7V%T;VUI8R@E<R`M/B`E<RDZ('=R:71E(&9A:6QE9`````!C;W!Y7V9I;&5?
M871O;6EC*"5S("T^("5S*3H@8VAO=VX@9F%I;&5D`````&-O<'E?9FEL95]A
M=&]M:6,H)7,@+3X@)7,I.B!C:&UO9"!F86EL960`````8V]P>5]F:6QE7V%T
M;VUI8R@E<R`M/B`E<RDZ(&9L=7-H(&9A:6QE9`````!C;W!Y7V9I;&5?871O
M;6EC*"5S("T^("5S*3H@<F5N86UE(&9A:6QE9````&-O<'E?9FEL95]A=&]M
M:6,H)7,@+3X@)7,I.B!O<&5N(&9A:6QE9`!C;W!Y7V9I;&5?871O;6EC*"5S
M("T^("5S*3H@;6MS=&5M<"!F86EL960`56YA8FQE('1O(&]P96X@9FEL92`E
M<SH@)7,`56YA8FQE('1O(&-L;W-E(&9I;&4@)7,Z("5S"@!!;&QO8V%T:6]N
M(&9A:6QE9``O971C+W!S82]P<V$N8V]N9@!%<G)O<CH@)7,@;F]T(&1E9FEN
M960`````17)R;W(@;V-C=7)R960@=VAI;&4@;&]C:VEN9R!T:&4@9FEL92`E
M<SH@)7,*````17)R;W(@;V-C=7)R960@=VAI;&4@=6YL;V-K:6YG('1H92!F
M:6QE("5S.B`E<PH`9FEL95]S='(Z(%5N86)L92!T;R!S=&%T(&9I;&4@)7,Z
M("5S"@```&9I;&5?<W1R.B!%4E)/4CH@56YA8FQE('1O(&-H;6]D(&9I;&4@
M)7,Z("5S`````&9I;&5?<W1R.B!%4E)/4CH@56YA8FQE('1O(&-H;W=N(&9I
M;&4@)7,Z("5S`````$5R<F]R('=H:6QE(')E;F%M92!F:6QE("5S.B`E<PH`
M56YA8FQE('1O(&9P=71S('1O(&9I;&4@)7,Z("5S"@!C86YN;W0@=W)I=&4@
M82!L:6YE('1O("5S+G1M<`!A`%5N86)L92!T;R!O<&5N(&9I;&4@)7,Z("5S
M"@!5;F%B;&4@=&\@<F5N86UE(&9I;&4@)7,Z("5S"@```%5N86)L92!T;R!G
M971P=VYA;2!F;W(@=7-E<B`E<P``56YA8FQE('1O(&9I;F0@=6ED(&9O<B!U
M<V5R("5S.B`E<P!G971G<FYA;2@E<RDZ("5S`&=E=&=R9VED*"5D*3H@)7,`
M)60`)74`+V1E=B]H9'8Q`%]?9&5L971E9`!5;F%B;&4@=&\@9V5T(&5N=')Y
M("5S.B`E<PH`56YA8FQE('1O(&-L;W-E(&1I<B`E<SH@)7,*`%5N86)L92!T
M;R!C:&%N9V4@9&ER("5S.B`E<PH`56YA8FQE('1O(&-H;W=N(&1I<B`E<SH@
M)7,*`%5N86)L92!T;R!O<&5N(&1I<B`E<SH@)7,*`%5N86)L92!T;R!C:&UO
M9"!E;G1R>2`E<SH@)7,*`%5N86)L92!T;R!C:&UO9"!D:7(@)7,Z("5S"@!5
M;F%B;&4@=&\@<F5M;W9E(&1I<B`E<SH@)7,*`"5S+R5S6%A86%A8`"UR9@`M
M`%5N86)L92!T;R!C:&]W;B!D:7)E8W1O<GD@96YT<GD@)7,Z("5S"@!5;F%B
M;&4@=&\@9V5T(&9I;&4@9&5S8W)I<'1O<B!O9B!C=7)R96YT(&1I<CH@)7,*
M````56YA8FQE('1O(&-H96-K(&1I<F5C=&]R>2!E;G1R>2`E<SH@)7,*`%5N
M86)L92!T;R!R97-T;W)E("8@8VQO<V4@8W5R<F5N="!D:7(Z("5S"@``56YA
M8FQE('1O(&-H;6]D(&1I<F5C=&]R>2!E;G1R>2`E<SH@)7,*`%5N86)L92!T
M;R!U;FQI;FL@9&ER96-T;W)Y(&5N=')Y("5S.B`E<PH`````56YA8FQE('1O
M('5N;&EN:R!E;G1R>2`E<SH@)7,*``!5;F%B;&4@=&\@<F5N86UE(&1I<F5C
M=&]R>2!E;G1R>2`E<R!T;R`E<SH@)7,*``!)="=S(&$@<F5G=6QA="!E;G1R
M>2AN;W0@9&ER96-T;W)Y*3H@)7,*`````&1E9F5R<F5D7W)E;6]V92@I.B!N
M;W0@<W5P<&]R=&5D(&1I<F5C=&]R>2!F;W(@9&5F97)R960@<F5M;W9E.B`E
M<PH`9&5F97)R961?<F5M;W9E*"DZ(&-A;B=T('-T870@9&ER96-T;W)Y+"!S
M:VEP(&ET+@H``&1E9F5R<F5D7W)E;6]V92@I.B!R96YA;64@9&ER("5S('1O
M("5S"@!D969E<G)E9%]R96UO=F4H*3H@56YA8FQE('1O(')E;F%M92!D:7)E
M8W1O<GD*``!D969E<G)E9%]R96UO=F4H*3H@56YA8FQE(&-R96%T92!F:6QE
M;F%M92!F;W(@9&5L971E(&1I<F5C=&]R>0H`0V%N)W0@<F5M;W9E(&1I<F5C
M=&]R>2`E<R`H=VEL;"!T<GD@:6X@;F5X="!T:6UE*0H``%5N86)L92!T;R!S
M=&%T(&9I;&4@)7,L('-K:7!P960*`````%5N86)L92!T;R!T<G5N8V%T92!O
M<B!C<F5A=&4@9FEL92`E<SH@)7,`````0V%N;F]T(&-R96%T92!D:7)E8W1O
M<GD@)7,Z("5S``!%4E)/4CH@56YA8FQE('1O(&-H;6]D("5S.B`E<PH``$52
M4D]2.B!5;F%B;&4@=&\@;6MD:7(@)7,Z("5S"@``15)23U(Z(%5N86)L92!T
M;R!C:&]W;B`E<SH@)7,*``!$:7)E8W1O<GD@<F5N86UE(&5R<F]R.B!T87)G
M970@9&ER96-T;W)Y("5S(&%L<F5A9'D@97AI<W1S+@H`````15)23U(Z('5N
M86)L92!T;R!C:&UO9"`E<SH@)7,*``!%4E)/4CH@=6YA8FQE('1O(&-H;W=N
M("5S.B`E<PH`56YA8FQE('1O(&-R96%T92!F:6QE("5S.B`E<P!#86YN;W0@
M8VAO=VX@)7,Z("5S`%)E;6%M:6YG("5S('1O("5S(&9A:6QE9#H@)7,*`%5N
M86)L92!T;R!C;&]S92!T:&4@9FEL93H@)7,*`%5N86)L92!T;R!G970@<F5A
M;"!P871H(&EN9F]R;6%T:6]N"@````!3=6-H('!A=&@@)R5S)R!D;V5S(&YO
M="!E>&ES=`H`+P!5;F%B;&4@=&\@<V%V92!C=7)R96YT('!A=&@*`"5S+W9A
M<B]L;V-K+V9I;&5S+R5S`%5N86)L92!T;R!O<&5N(&9I;&4@(B5S(CH@)7,N
M`````$%N(&5R<F]R(&]C8W5R960@9'5R:6YG(&-L;W-I;F<@)R5S)R!F:6QE
M.B`E<PH`)3`R>``N"@!#86YN;W0@86QL;V-A=&4@;65M;W)Y`$-A;FYO="!F
M;W)K*"DZ"B5S`$-A;FYO="!A;&QO8V%T92!B=69F97(Z"B5S`$-A;FYO="!R
M96%D(&-H:6QD(&]U='!U=#H*)7,`97)R;W(Z"B5S`$-A;FYO="!E>&5C("5S
M.@HE<P!E<G)O<CH@;F]N90!F;W)K7V5X96-V.B!D=7`H*2!F86EL960Z("5S
M"@!M86QL;V,H*2!F86EL960Z("5S`"5S(&5X96-U=&EO;B!F86EL960Z"B5S
M`"5S+V%D;6EN+V)I;B\E<P`E+BIS+R5S`%!!5$@`=F%L=65S(#`L,2PR(&YO
M="!A;&QO=V5D(&9O<B!V87)I86)L97,@9F1?:6X@)B!F9%]O=70*``!%<G)O
M<B!O8V-U<F5D(&1U<FEN9R!E>&5C=B@I.@HE<P`````L('!O<W-I8FQE(')E
M87-O;B`M($Y53$P@<&%R86UE=&5R(&ES(&%B<V5N="!I;B!U=&EL7V5X96,H
M<&%T:"P@87)G,2P@87)G,BP@3E5,3"D@8V%L;"X*`````%1H92!C:&EL9"!P
M<F]C97-S('=I=&@@<&ED("5D('-T;W!P960@8GD@<VEG;F%L("5I"@!%<G)O
M<B!O8V-U<F5D(&1U<FEN9R!F;W)K*"DZ"B5S`$5R<F]R(&]C8W5R960@9'5R
M:6YG('=A:71I;F<@=&AE(&-H:6QD('!R;V-E<W,@=VET:"!P:60Z("5D.B`E
M<PH`````5&AE(&-H:6QD('!R;V-E<W,@=VET:"!P:60@)60@:VEL;&5D(&)Y
M('-I9VYA;"`E:0H``&9O<FM?97AE8RHZ(')E860H<&EP92D@9F%I;&5D.B`E
M<PH``'5T:6QI='D@)7,@9F%I;&5D("AR97-U;'0])60I.@HE<P```'!O<&5N
M7V5X96,Z('=A<FYI;F<Z(&9A:6QE9"!T;R!A;&QO8V%T92!M96UO<GD@9F]R
M(&-O;6UA;F0@;W5T<'5T(&)U9F9E<@H```!P;W!E;E]E>&5C.B!F86EL960@
M=&\@97AE8W5T92!C;VUM86YD.B!F;W)K(&]R('!I<&4@8V%L;',@9F%I;&5D
M+"!O<B!C86YN;VX@86QL;V-A=&4@;65M;W)Y"@````!P;W!E;E]E>&5C.B!F
M86EL960@=&\@86QL;V-A=&4@;65M;W)Y"@``<&]P96Y?97AE8SH@8V]M;6%N
M9"!F86EL960@8V]D93H@)60@+"`E<PH```!P;W!E;E]E>&5C.B!F86EL960@
M=&\@97AE8W5T92!C;VUM86YD.B`E<PH``&9O<FM?97AE8W9?<&EP97,Z(&9O
M<FLH*2!F86EL960`9F]R:U]E>&5C=CH@97AE8W8H(B5S(BD@9F%I;&5D.B`E
M<PH`9F]R:U]E>&5C=E]G971O=71E<G(Z('!I<&4H*2!F86EL960`9F]R:U]E
M>&5C=E]G971O=71E<G(Z(&9C;G1L*$]?3D].0DQ/0TLI(&9A:6QE9```)7,@
M97AE8W5T:6]N(&9A:6QE9"`H;F\@;W5T<'5T*0!5=&EL:71Y(&YA;64@)R5S
M)R!I<R!I;G9A;&ED+B!5<V4@;VYL>2!U=&EL:71Y(&YA;64@=VET:&]U="!P
M871H+@!#86YN;W0@86QL;V-A=&4@;65M;W)Y.B`E<P`E<SH@``I3>7-T96T@
M97)R;W(@)60Z("5S``!#86XG="!A;&QO8V%T92!M96UO<GD@9F]R(&5R<F]R
M(&UE<W-A9V4`)$9R965"4T0Z('-R8R]L:6(O8W-U+VDS.#8M96QF+V-R=&XN
M4RQV(#$N-B`R,#`U+S`U+S$Y(#`W.C,Q.C`V(&1F<B!%>'`@)````+\8!0@`
M````9&D%"/____^-3`4(%'@%"`!X!0@```````````$````!`````0```.<`
M```!````,P$```$```#(`0``#````#B2!`@-````1!@%"`0```#L@`0(!0``
M`(B+!`@&````2(0$"`H```!W`P``"P```!`````5``````````,```!L:04(
M`@````@#```4````$0```!<````PCP0($0````"/!`@2````,````!,````(
M````````````````````````````````````````````````````````````
M````````_____P````#_____``````````"0:`4(``````````!BD@0(<I($
M"(*2!`B2D@0(HI($"+*2!`C"D@0(TI($".*2!`CRD@0(`I,$"!*3!`@BDP0(
M,I,$"$*3!`A2DP0(8I,$"'*3!`B"DP0(DI,$"**3!`BRDP0(PI,$"-*3!`CB
MDP0(\I,$"`*4!`@2E`0((I0$"#*4!`A"E`0(4I0$"&*4!`ARE`0(@I0$")*4
M!`BBE`0(LI0$",*4!`C2E`0(XI0$"/*4!`@"E00($I4$""*5!`@RE00(0I4$
M"%*5!`ABE00(<I4$"(*5!`B2E00(HI4$"+*5!`C"E00(TI4$".*5!`CRE00(
M`I8$"!*6!`@BE@0(,I8$"$*6!`A2E@0(8I8$"'*6!`B"E@0(DI8$"**6!`BR
ME@0(PI8$"-*6!`CBE@0(\I8$"`*7!`@2EP0((I<$"#*7!`A"EP0(4I<$"&*7
M!`AREP0(@I<$")*7!`BBEP0(LI<$",*7!`C2EP0(XI<$"/*7!`@"F`0($I@$
M""*8!`@RF`0(0I@$"%*8!`ABF`0(```````D1G)E94)31#H@<W)C+VQI8B]C
M<W4O8V]M;6]N+V-R=&)R86YD+F,L=B`Q+C0@,C`P,R\Q,"\Q-R`Q-3HT,SHQ
M,R!P971E<B!%>'`@)``D1G)E94)31#H@<W)C+VQI8B]C<W4O:3,X-BUE;&8O
M8W)T,2YC+'8@,2XQ-"`R,#`U+S`U+S$Y(#`W.C,V.C`W(&1F<B!%>'`@)`!'
M0T,Z("A'3E4I(#,N-"XT(%M&<F5E0E-$72`R,#`U,#4Q.```1T-#.B`H1TY5
M*2`S+C0N-"!;1G)E94)31%T@,C`P-3`U,3@``$=#0SH@*$=.52D@,RXT+C0@
M6T9R965"4T1=(#(P,#4P-3$X``!'0T,Z("A'3E4I(#,N-"XT(%M&<F5E0E-$
M72`R,#`U,#4Q.```1T-#.B`H1TY5*2`S+C0N-"!;1G)E94)31%T@,C`P-3`U
M,3@``$=#0SH@*$=.52D@,RXT+C0@6T9R965"4T1=(#(P,#4P-3$X``!'0T,Z
M("A'3E4I(#,N-"XT(%M&<F5E0E-$72`R,#`U,#4Q.```1T-#.B`H1TY5*2`S
M+C0N-"!;1G)E94)31%T@,C`P-3`U,3@``$=#0SH@*$=.52D@,RXT+C0@6T9R
M965"4T1=(#(P,#4P-3$X``!'0T,Z("A'3E4I(#,N-"XT(%M&<F5E0E-$72`R
M,#`U,#4Q.```1T-#.B`H1TY5*2`S+C0N-"!;1G)E94)31%T@,C`P-3`U,3@`
M`$=#0SH@*$=.52D@,RXT+C0@6T9R965"4T1=(#(P,#4P-3$X``!'0T,Z("A'
M3E4I(#,N-"XT(%M&<F5E0E-$72`R,#`U,#4Q.```1T-#.B`H1TY5*2`S+C0N
M-"!;1G)E94)31%T@,C`P-3`U,3@``$=#0SH@*$=.52D@,RXT+C0@6T9R965"
M4T1=(#(P,#4P-3$X``!'0T,Z("A'3E4I(#,N-"XT(%M&<F5E0E-$72`R,#`U
M,#4Q.```1T-#.B`H1TY5*2`S+C0N-"!;1G)E94)31%T@,C`P-3`U,3@``$=#
M0SH@*$=.52D@,RXT+C0@6T9R965"4T1=(#(P,#4P-3$X``!'0T,Z("A'3E4I
M(#,N-"XT(%M&<F5E0E-$72`R,#`U,#4Q.```1T-#.B`H1TY5*2`S+C0N-"!;
M1G)E94)31%T@,C`P-3`U,3@``"YS:'-T<G1A8@`N:6YT97)P`"YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YD871A`"YE:%]F<F%M90`N9'EN86UI8P`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F=O=``N8G-S`"YC;VUM96YT````````````````````
M```````````````````````````````````````+`````0````(```#4@`0(
MU````!4```````````````$`````````$P````4````"````[(`$".P```!<
M`P```P`````````$````!````!D````+`````@```$B$!`A(!```0`<```0`
M```!````!````!`````A`````P````(```"(BP0(B`L``'<#````````````
M``$`````````*0````D````"`````(\$"``/```P`````P`````````$````
M"````#(````)`````@```#"/!`@P#P``"`,```,````(````!`````@````[
M`````0````8````XD@0(.!(``!$```````````````0`````````-@````$`
M```&````3)($"$P2```@!@`````````````$````!````$$````!````!@``
M`&R8!`AL&```V'\`````````````!`````````!'`````0````8```!$&`4(
M1)@```P```````````````0`````````30````$````"````4!@%"%"8```:
M0``````````````$`````````%4````!`````P```&QH!0ALV```(```````
M````````!`````````!;`````0````(```",:`4(C-@```0`````````````
M``0`````````90````8````#````D&@%")#8``#(````!``````````$````
M"````&X````!`````P```%AI!0A8V0``"```````````````!`````````!U
M`````0````,```!@:04(8-D```@```````````````0`````````?`````$`
M```#````:&D%"&C9```$```````````````$`````````($````!`````P``
M`&QI!0ALV0``D`$`````````````!`````0```"&````"`````,`````:P4(
M`-L``'0]`````````````"``````````BP````$```````````````#;``!]
M`P`````````````!``````````$````#``````````````!]W@``E```````
M`````````0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S<B]L;V-A;"]P
M<V$O861M:6XO<&QI8B]C;VUM;VY?9G5N8RYP:'`S````````````````````
M```````````````````````````````````````````````````````````P
M,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#,R-38Q-B`Q,#4Q-30S-#$S
M,2`P,C$P,#``(#``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-T87(`,#!B=6EL9&5R````````````
M`````````````````````&)R````````````````````````````````````
M````,#`P,#`P(``P,#`P,#`@````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````/#]P:'`*("`@(&1I92@B5&AE(&9I;&4@8V]M;6]N7V9U;F,N<&AP
M,R!I<R!P87)T(&]F(%!L97-K(&1I<W1R:6)U=&EO;BX@270@8V%N;F]T(&)E
M(')U;B!O=71S:61E(&]F(%!L97-K(&5N=FER;VYM96YT+EQN(BD["B`@("!?
M7W!L97-K7VQO861E<E]P<F%G;6%?7R@G0B<I.PH_/@I2[O-R\-/80T1FZ%)W
MI+U01@C0Y'>_/GS):5H@DMA'8"-9UH.I<4D,`N:MWODBCYVPU#?BB6(M1W/H
M-EAJ)&_1+`_=2E(D-[8[/S\W1R5#64>2-+<A)!EQ9$T/*/&!PB`X#R?JN*UU
M@H6<CEI>)R7;?$U95`56X:I?),AO%MU[OPA5F6N'">L)\,S:DHCE`"")C01@
M?=O<3?IUT@Q0/U-PVG;-\YO6QN=]`5[?IEC$<2F@U-K5K:$29/\24A6>Z-7_
M_46[[NU\+0F&$%E4T%0I*0\3M61-DF"BMLY25[&:8]A"4*>K8S7+^N((L6-O
M$\K)I8\MJI-6!#I-9L?2P.+7=7G)3)+N?UFI:M_B2GC/E4U%K'^HA8&<II1-
M_Q4JI?'+3A.VC7I_'PJG>\&77^OO89H<*Z&[,@#(^O8(37AN#/!<GK.OSNA"
MKC6#<;B_V$D)<QSI=I"4I+K3%H4-A?0.&(I;H8F?/5=RS5FQ5:2BST>8_-Y=
M<9^._&WWVX$VNOZLQU&7%6$VY@W93?M)S4P+XD!"[!MF/&ZH21.,\U#I(;Z?
M;:GVJ^6F:(/XIN_W80%/?KH^*'^]AN/1+LA5JGY:X'"(<OM*Z1,A[#F3LLSK
M[ER\^N]P\W3)*XX,6&&+P&OV2*F*=0!WURQW.4>YBC_N(TYV)J,0?#D#_"ZJ
M@VTEQA'Q\#"WU#M@P/.)J#7P\(]U.)]6^G#'"QA*TI6'["P9=W/3=9MW_E30
M-US$L\A'KF2HC-W!*W4KFAK7E^!P/K\S=(B:_%&\Z^0#FLBQ?GX?N3&8D?@:
M9GF#P)FI)X3.JSUF#MEJTNJ%/2`S^4!'K+)-/8T#TC,%Z*^@#^4"\!B=>K8A
M"_DU'<"Q)K7(5G4P!@<=Q?>2/7RS@^[LGJ%[4S'+][J7+7"-WHU]#YJ;_UN'
MBR4A^%KFLL'JX!AB&*B$JD-(Z?X2.T0DMNV.26,U>3HWX+'QBDA&#3*NK8IR
M6#YDD=];'SUYCGS&;X-]'5&?;-D`=B@1,D,7]@Q6AN%.RDP]JAW@^WKH=$1R
M`S26%V416]S^D6"SS5G5=K6EXIUL,).4-RIW#&J+G`43M-)'Q-!2FFRCZ<36
M=\&"&P",#X#=C+B+=9A?W[72Y=>W7.*B'7!>6MR[>1D'97A/KW(Y-O\.Y\HJ
M$9VT[K$4^RT@];/Y$]D^JN-U'K"D/G/GT4)$^_6-#=26UQ3\>(DH9YH7J*+2
M$YR(V3O,2;+PNU/^_\S#?:1YD;S?ID1PM@"I0!L\!:8OUE+638)(3A1I`HV4
M_K5_*P-L""V$FX.@7E!?%B'95F6X+J.F_18)M5R^\1$\FUM#*(-KJM&F(S+-
MLJ=G*X+D117<$E=#V'\PI/5;]9V4\ZD(F*9(ZO@'_H3EP/AK/KW%C![EE)#;
MTG2##Z@C+%W;6XADD,DYP55C:<@52$J)F%OX=!XV+ZZA."W#I4$<W&AF."T'
MVH?+RJ\:P@8ZB-Z^4?,I_H8!UC1AIU(B_DZWIVQJ>?(_%S4+NF+0CZR)2%,M
MV,U+.CA*1$&&S?"DDH!$!=`W9>*=Y4#^EW4_0S=5!R/V++::@M->=4.SF7+-
M!.AFOV=#;5(G:>#TW(K<(7#IC@V<M>5436^>(E&=X!&,OUW6^]2W41KN\Y)!
M.T]"VKKP[U<VG(CR6\*X`4(;@7V3Q#LZ3\;96.+U(7"1H88!)%]*_Q?,.AOU
M=#KL8EG)6(4H+H[DV-@/_7JKR8=N^NUX3*+R<+]5\#$<=8Z4%I"P>*-O@I`J
M>!1(9K$"UU_)=XT/S/-%;REP1)<^0!]'UHG%+Q0443GT@VL'VM-M203Z8Q.Z
MH0K*A]+U(0?D!X.103=2T'M%W43>^*:XY4B==\VKTV^F,"0"=87FVM#Q/(YP
M7L)=&AJA\`#@&#1"C_,%CV"*+/JLR,03NJ:5FI.<@K;FI![F-#K52^7X(34@
M`C)G_>T=B-4R*:LAXA,;@2915A69J>'*PU!';F&]M757L^N?@)&+`=:55@K)
MN@).#O+FYSHZ+T8ERU2=V/NF\?JM(KXWXN>Y,]_,J3A2G^,)4#1^"B':78^C
M`O4AS/K25FZ4EL/O,%5AICMVS<4DFY]F;7PU<>"WV14`9B_:,@(!;58IK-.-
M,VE;0!(S5#OR5ZJ#"OL]*?_WVL(&#--#DX?R;BO"Y7GG]A<]$CYN7+S,TA[O
MQXZ/IOSC3S5F,D-O!,]?X,J>"WHCFZ@Y4SPGQ[8')?*TZ:3,O)TGAN`D2@LR
MBNVL64)(SEL%D?7`DVK+X./+@ED(-&%;ETD(@C2F$&]ODO5[(-4C:N'`LLLS
M]PBAGNY[6=]-XW,2+Y@53\=GJ<64,"#8",GQU*=#SV0-IW"CL">-TP[E"2<J
M(PA&_%A5OI/ZV"4?`[S^V\G,*E_K/YC*-&[4@FFNZL:$,*Z2/9RBMD0KC&1@
MTFSW!PS]32IQ.L+R<%9'R/NFP]S5B@OQU*J+_9X]LE14)*EY8QO.&1L[3RX-
M@V)'44>79WYAAN&,V!C/*ZUK5*Y[PC=PG'KLKZ9-`<@"LK66:<BRPCN4BF3V
M^.>/=(4C]ARF/>1/X]7-K[%1%F1F`-PQ4,[G1X:NW_!$?U`!G9BGTZ&4<4$Z
MF5T'NQ-M1T#6"^)I!UV]M`FR82^0$"\@.%;9;2;)\O!N=AHR7N]SYV8O=_!#
MOQZ!!)W$/?>`_'6AW._HXXMS9`^C!`N1SJGBWZ$MAZ&GU6I7/NV_DREMAE"R
M5,6<\1TTR%&^RV8-E;"]18U?1Z<Y>5OBI></6K)2/T)>SN!EP]6\7H[`OY68
MM@U0;SLQT[`=?/*):N4!4_2R4#)\7%2^AP+M''C/]GAD.HXG+CT07009M.FZ
M#8HK?XF64VXP2J7OJ9`>6VC$E>P`BXG_)C7`RG/!0T8V.7[&*`4%DP%H6*1\
ML9'O]4@I(<C!P;=J@>Q3%XN,.@S?S0@D4\=G$N?WS@RDKHE@H@08@!8VE!?Z
M/Q9E!;"US/&74#RDL`U-.S;QP&:+^ANX-P'?EZZS(B.<L=@X#`9O<CJ!+3=J
MEG+GFO8$^1]A"[;;OX&IT"%<*$%$\S/\V#%+"2_;RN_9=3,A%%;QX*`!R&PM
M!HA)[4K75N7W*XTGN;?^$&H`J0N/YHZ/P]N$>G'1XDV70DX)L]"..TE:ZV(-
M.]Z2)C[<ZW%>:S6W9,UXG1`RM,T)E$;H;<?2%;JV&?M(PL/E,@5Y0*A08'%Q
M1??C,$K+J!6(K@))&6=7H9O\<XE#W\;J8:@X_[D\VX85;1$$.X'*(%@.)<VE
MVH=6:]NI1U><0T=$A)^*#!+:B_YC&G789C0#9-(P=*EG7ITKTL')OHAX]N@:
M<BX)'YG8G\BBV/^.]'MYGME^2@#&$(*)U8JB1@3SXW8]C%D4)V!="V8":>D$
MO6:"8F]AJV24W3J1\^>)%!B>>+'Q"S^WQ"270.,/XRS5(+C,_=`N7.`(ZU.[
MOU]O'"M4AX^%_X<;%EA7<88!06RU*$+)YXE,5E0>Z66DEJU<BY.-D34KKVAJ
MS:4O)P<M"4*L8=J&#\<P`I$T[XJ+I[D?^X;D8&``FA1#+0R02;=9^3-:-/VE
MFOAZ9MJ-<_>?2*XS]36=LR+>A%@P-6/G+CMDZT309F9EC-FB<S+H9@W<R>K/
M](/7MFQ$HA2-TRAHT2U;JZEJ-K5A'1+40]=_5!BX=E)P*$.+;#1O_OBMG/9/
ML1,Q_[8R00X9U2REGJ,H2?C:);-+S"PQT!1T\_1:X9,F-DUWVYW9`Q*7*MQR
M^&TCE_?]8&1T[E2!3*N:D2&')Y;@'U-"L#X%T@%QQL=Z^FDT&FT74283DS!?
M>HH>>VTQZ#C5!9WJ^\9TO)F`PW:W*)4Y#NEU[1,=CSG[8V$M,#="AD=MT_M!
M0TCY;B<ZCGPGU*93#\(%A/.]F2_3B@1OE6N/QR68N'V#^BK$!UAK25Q3=<C5
MJ*H@'7F&*W8G?:NJL!91K?OL`G3\K7GX7#3F>NE-""XVHRR'[9+*^,=NU@CB
M8L!MW<W]*B:)\@/3(7`=,T`CR&CT*&MWI?8B&>P4,)API5+1=<`0^>LZ?$F)
M9XF&1/E_?VWG(&S<`F*<VXMR2)UYIP1"T0)K,7^+``/@68C?'/6XGI<Q9?O%
ME21W>CMUR@66-2&-=]=E8(C=/5;$6':/!-#7'$EY&3[?_K!NM+,_JB4VBQNG
MT7:#]XF/3_S58PB24QFCC4=B_J>7^+6?C*:I^2NJ:[OM_K',-I#*%PU#0S5`
MEU_WUU,A$0Z7!F%W<Z.-K`EDO3T[S9M[7/X/#EG5U&NU0WID,`WH9DE%UN@S
M:1)AF5>QB;O2U-N=W^TLQ%(,.41TW7(K\VX!:GF/IZ'>CWN8-V6%%TD>8Q,_
M'JH<2YI'.:/(9N"U#X@Y;D<696F):-)\3YMW`PF6;E8P7!J&0.=:^K-Z9A3N
M;83Y;\4+IZ_)P:M90_,F\_[(BXU80[\\9&4`'/9$B=2*N*7><@,>SZV>'31=
M_^WA;W_7J(C@LF!B!1RE3^Z?![G_QMU[@Y_K0A<`K*I[I23.`B!=>W#^V:Y(
MAT'P7Z4'BK!B3%K92+G<0CTLZ"$*GU/1WS,-@$0F?Q+.Y*T(8B<9`VROR[V]
M(V'7?.A#<*OD]_=&:/\(^>UW2.E?J]6OIP>6G^N[UF-6L.X6*X@`_$\A*)D^
M?*H,J49,0-5LMM;]8TWB.L'Z&B,<HCR>=X)E-335BS4KUZ^S;\RF1)<X@]B2
ML9B(R-/=4S/18HR!W]M?Q4Z["P6<M>X$ZIM@W=@CI`L(]/+CHZ=1A0\96R=O
M(^F6@54RO%2G"R+'"OK214<?NSN9OX7GO"X7JLKV93>$7P[/[9N8HSOY2ALV
MY+]N*N3GU4+6@*/JFJ9A0R,53M%_9P=LCZ]TU=$UO1]MWP=M9W;MP95YN.8+
M*74=W#^$PU\L@WH'=;$!`=$\MOKAR!50CC1MI.I@";^=51A+96M#H[1%\T]H
M(0(C&Q6_O!0TGZ/!9^_6,5T>G4"(BQF1SM:)[AX4]`RFSM$E1F&%NG"H_";*
MEDTL%(3VU(M[.[9<TU;-L9JB'")=#;C8SGR&6U,DFP?4E-I-9U;QO2*49<EM
M@P%=)4!H]A!;F'[.6\]%UK3XHZ7QM\(XJ_MZG";*_K1+-G2%SL5X\I=`&3!G
M3%$'".LIY/FX@,(4BH;3$8R<.;!PKH/^MTJ_<&'Z]LXE3O+,0.>M)(HDB=R(
M8'HU!#\^S]67;JB2,J&D4%8$VGWC+DX)`&JW^Z)!0_-QJ<W_<`E3VA`T#XEV
MLV3>6DA?%"U[6(V*G(V'[P,AMR_#F[U>FI+**A^2]#%R.<%*O$3_G?RUUOPC
MWM6V/XY:NX%Y=EV$GI9$=_U5/HO26I(H(K`GM\=)WR8+$96?"08K'?MFQI4T
MO7+)(OQ@J.ZILT&F\%;U\D*C..?]Q_UPP"=[Y]_]<%GBK?2P!J&G)G#WQ*]Q
M[)M,-:\TG*"#X0597$?+FI%O9E4DV).XQHU+OJGY'AAPC*-F;PM8=00%[C1;
M4[M^FG[`5\(-R!1$;#!L8Z_7ZB/8"+*>:>_OU.M"2#8].HLEJ+#U=S)3.\%^
MHMW:F>#SD.CQ:^,4EGP457LWO]&<^.MX$T>9[M>`B?B9'MEXFRR'BAF6SE(W
MG?D.%*L>86OY/<IY6_!58S.@MLU4L425.C4!./R&DT1@%EXFJ-_)E&(T;3@"
MOK$9JF4X0[I5YBFKKI$&8'$N+/:Q)7?^?GA@I2;J"X:^&F!S-K7*EYB$?+WX
MKRY-<NT^65(Z,*<A0C0\%FXG;+L-O[N&!J$:UR(P00@^%(02A>S9\;HDXU+1
M<`?3**W'UX%&,[V*8I405&O?"J8"/7JL@O)>6K!,E?;!1Y-#OEI!XI$*L@-\
MV=Z;>-B)I)M06]25_B`"MG3E?I4UTGP8H0RQ!F`"QH>JLV)#:*P0/T/=P&0J
M%NK-DN/EL8_*408M'K&Z>`5;3G2H;$P^DV#$SJ/T<2J)Q"^K)Q16U`8NY%"M
MN_S6^BN&4<VZLB@_;KRD&Z'O;^Y2[&S1.2-V4!K(O`6N<9C]78)TU@6OSHNF
M6]#:*1CKJV^X"?6P<%H>O2O9G&!;B7@E(-P+9><URK=91>CK`AL[*F;J']*1
M-J+JIS`:,]@K,#F?:E#5.\Z\45\K#7'9C]40X$ON=5E1/1G;Z+N%T8?FG`A2
M)<_()O*%6A5HA?_\-@I"!0T-=#J'GAQTXU2DCOW4XHM8!`6\<=[QI#@=XPL)
M-1DWM*,M-#C74)!U)E>COYI3EGG+<P#GKQ_\MU<I[(8)2=I2RY(IZC-S8#-[
M_2X+T-6*=%GSFR`H>2#</RQ'":V%W?BK1UN49O@+*)!Y`Y<1WJ3\P86_^&-*
M%L0VQO:ITC/=@&<J0FXR1/'<`L4LECU2V'0Y17'FWH6A];S%$87QD"4+A4<R
M\B]TNHM[6\4@UP[\&N(8E)E&1>)6<&6E%T#C;+MY&\(_0=@(G[\@_(,9:!L4
M+HGEW.*'PW1JSN-I:-<3!(J;P2XUP82O]S\Q1!5"4V]W!$\>[!3+@<V/>^U5
M**0\>_,!"J)Q(1?#VTW]:'<SX*X:6:,=)G?]#^K,G=BXXTK]$UK!9#S"_F-U
M`UC2`IKUZR9.:@/YHUD3>>5]_X]CC4!?G.*#,\F6S:^$.:LE;^DG0W;F"M-\
M?\/(CHFM)W'*4VW5_,4[RO#`\,/^K#5P$I`'B8?X7Q.%&4PK?-V%II4-EY7%
MBQ^)5_#MX-R%>Z"N"EU`LQD&O#7$CW/0]BU(G8M"5J^6O`M%M)&/XB05U8^6
MM(:I[TRT<[@`%;8O;C]!*W;Y5OZB'%Q%<1;,B2!OHS3_ZO/)BCRF`)%#[U!O
M<)#*#-U3=BK5&95WEFXJK,L+0-\K7`3[/J0EO5R4;WVIGP.G$_8"(W]'*;C?
MEPO?U?6T"+#A((*/@E\6Z;D8V)<\J!;QT>60CDP*8X.!?DG>-YJ_5%I2'(P8
MDRZ:4:\QM8-PTT%W]F`AK<R*!-Y^Q2*;/L:/%4\ZGC=B!,Z[9$EO8C9>3B'\
M;OVXVGA5"KF5C[00OBU$#!X&B&H7P6*YQE%88%L\J:)PJ@KN+C:65@%9O/[S
M7*OM+3Z],*[KJEHP_>N4Q1R"!2PQY[.P0Q?[H(\MYW]$M@D2_>T[I5S=<7^`
MF>`I!5KOF-;M#CH3"3-YM3KH"N+H[J$9!;=KAVU$!XCMNSF.\0%.HA3*1,1O
MM"G:%^\MC-9'>C_2`B<GQA?<M^"&WFL%.WF#?+LYMJ%HUK7A23-3$;(QW,8&
MER'YNF;@YY2/S$"1D8\K7I/AT\UGJWR540!;_\3#0^;G$([>QFVK66@.3TJ[
M??[;[E,F."*:3J?G5#F"9S&F?&;J.Q6]Q6-[/X=QQQE@U2/QA;=(@Y(&]OBM
MKC[G@5S\>3%=V[;!^:6:>J=RE^6:&8RK/:&CDC*\0HD``#$N]XY=]RK>\"$6
M^BG[MB(2I0:DIX]GWOU\3Z1<C&<(_;_+G`Z%&?4JD03/4E9-<2H(`$]F)C74
M[2Q^911;YBCJ&1D57*[..4!8=F!_Y%"WSX32&ZNEGF!;_1.O^RE';&F=H#:=
M_I9\\X`BK^H%#$PN?<7')\*ONR^66\K',3_?KA490V.T.%8CQ]YP"LJUUD.6
M]_F`UFQMG[0Q6]+9W3<D-S.WIJ;)9*3&0$CV(MD8PU&H\("`=Z&IH$5CTK]:
MV^Y,!818S[=H_I],@X?!L3##>:79+1^L"6?[K_EJC6-X(]HJC8K""?/^QVHZ
M[NP9HBD-OW_Q%5Z^7P!$33O<3UE&Z9`%S%X/`>8G7\=VR.N@Q[,L!C"7>;64
M((0O\:YJT=P$[N,KP1?\X?T@L+]#$<YT:?F-3?#V7Z)G!A^`YS<+D#$QF["C
M:$6@W,=A&A:[VN4+FTYG_LM>]GH-PJ*6E@D;8=O\+?Y\=Q$PK!9IT2`R$]K6
M]&;8?9[^<-9,?"_DO6DJ"N%D%\FF$4\%^P&3IJ("G^H:^MA?P00`AQJU.00=
M&RPNZY4>72][W-*&Z]=F'8>]2UED([3Z<NVQSN[7+MQ*@JWHS?$+:S2H:[F2
M,A/#'W#Q4.:['_Q/8"QAKMU@0*J_C^(42+T63S+%O__!/<;R'JFY_#%5?@#2
MC=T$%^XU%!"FL^3%\N3_<&@YL2Z@R;Y"]"V+G>!X1$C#TBO\3YDHO)C7//3Y
MBY@?6E\0,'"B)NV`N8W8)%X]&9RQCP5CS!I#CV<S#=#"2PV.W(,#%Y2/R6D'
MP-1O5#).IUG5ZJZ)JJYX&\X4CSU``6FNP-RTD"=^F31W@S9[[6BV&GR_<CJ\
MGHXF/VY66(3*)[S6CSL_D,WVSQQD<6924*)RX,EB$FK1OW>(&W4=,05]"7:X
MUW'=?KOYFEP(Y>5"DW,]Z:(7<OG;FH/"#"8O<UY&H72P0TAUQ+W)K=R4<H7)
M+Y"H`Z)#EO3LJL8A^E:\!B2.9^]F`>>4X0<DP*SE;:YX5AJ.7&0TZ_$H??>A
M%9"C*@N1AUK?R8"!.Q)6'9%XSJ?TFPK*A"D%8\^`Q.!@*\U_`DO/QAWV]?O1
M0]P=_Y4NU$@'TD<))KA4SZIJ3<#:4XXR5"LZ>UB#AG/X+UX:A^6+JPU"Q_1A
M>JURNS^@8G::8`<'/U/`*5ACZO.0(#_UH8C"6<FSQY#HNO&K7=0NTZW2E@:&
M5QA3\-.A\WKVBX4T;T6DD3_2Q>>=8G0QD@BTY4.?BUA;%D7?^V[S."`]R]>@
MDS^K4.&(EO]`RQ%\+O8DXQ4F89JW(6@R%BH'%-\)<ZW!]O&[9KG?9GK<_3#A
MB/]BL0SR+!BHP;\:D_U^QR=M6X$WP[@B>OB@YR`L[VO42JTH'N/GH%+)PQP@
MI!K#*F>L[G(9%Q;4E-F[.A&@\R;=-[]XMV:\Y%C@Q+Q*Z7,QSOV6Y&R38[GD
M7X0G8I*&3@/H;IW($SGS#4C^=FZ=5<A;K!7L9VF<X>FMFNCA5V+J^5PUX5B7
M/`R!&5XG(G5M"ZDH038&H`S4DC?M<(L1[X0=>!P9V5XT@VB`F%3]`ECJ&S`!
M2H<^`D5@H.[`;KI6=')V00:^J/'IZJ/0!P;V^8J#7M=\PUQC^.X$=$5SN$(1
MA54VF844^UL0U#R/$QV<I4E*3':HJ80ST&`SE<.%C_/OB`PGB7"I5>EP6(*Y
MUK'(.!%+C`N6UD%1K.H#PB+ZWSFE!K18P5@3[+2UA<0"86[P'V0138Z(-4(T
MZI]K5UU"4\>.V?F&6/G@<7V5I`XB-+X%4*4$*3J2P!C4/'>)5!/N//08L\UN
MO$M"[NB?\=UP;KX?%"KDX,3%68DGG`"W?"^).R,$OMIY18T0Z?TVK92DE_Q@
M.`'M/ZOCGBD\Y?6`?CSCZ3@F#]Q3-9,IZ*O7+7+.#<$)+?,%J##77MW?!RS=
M)EU%GS8'HYK'%U5'[]K8%#3"(C09W,\!AYV`^XYQS7[W'S;^<X(E`:FG;4""
MR6R34XC1\WS"'@L#Y2RSDTC[:;/`$C<'+`S;C*A3$.N:#BXTLL1WG]2#HNB2
MO"\%IQ__`\1!?!\Q=^2IM![%>@<WUG0C_ITKP8(\2S/@P4T,_/XVX1@>55"Z
M=^\7$I(`-E[F@NXU6:5E$HRX-*6==2QDG4P#HG.&O=`D(HA'_$=C5/]2=RE/
M_9+?^$D8BL[X6[OU9%_%M6WN6Z@0=C$IDO0\.)``N4BWKF"53DCD:U<0A8ER
MN4*:)$^*-VC_-84YENPP&32T2N:E)`/?:=Z!.0!BZ]'-?)4]GK7;OA1E&C15
M:0P<OG4W:O4M_\'KA9KK;.6HJH/AU5=\/9B,QU:0>^W*#V7U%K)N([[=1LG0
M3C7MIZ:?BS1?JK"<TJV`*C376MN$%ENA]#*&?G)%O=\OT8/Z,$GZK2[OPBF4
M<U0"[1['+Y=.4R.VF@J[)>'R20([0J<(('-30=05,`PO7,AW"H9`95H<SX*4
M71%;)&!4^IJH;',48\KL%LH6%@N@S5)!F]D<)"#1KE!L:<ITO[_NF:30S&4M
MQX.-+3RHWFX-,D^;`2$79HU*`B0JXM2C0,I&/D^V0D8!W/*KC?ERK`[`IAUU
M!*(JX[-8NFL=:>L'17]'Z_#"\7K.1J1O>?=!O,!_6I)S\?H513`BD??<@6%&
MY@W=6IK'1M&#N%T,7?=9__7$L-]@[%"Z4A\WV?R!B1.6-3WN].7Z[W9VWL0U
M@W)3J->2]KUV.+=W&R$9Q$_PGI^?6>/,Z]I.JZ^92LEB!A)V8L!OK>WNZ>I9
M(7*5M$W6<)HH\<HKK8?*!$_&,93C^-+BY"C%?D"LC+H7TKA9`;L4\5#!4TO!
M7A@B&+MU(1T]F8"2CEK`E&W+8SZ[G'LF"89]4Y9-O9HUD4`V'U_O!PBC4,G,
MI_J[9#/[$\.2:^22=U3>S;NS9UL<J0H`I#<SZ02K&9&M8*V9B<"K_+W*D%QY
MM4M^^-I^1)#0D8R8/Z6%CEYR;R&W13172D%#6S8E,5R"@.-TG?UE2]W9<9Y3
MMU[@.61NQBN([:'.V`+HBH.#[B4''+09ANXA`=!&$_`3857<82,`Y,@0W=W1
M[9<"*PSN3?OZFN!NHH*Q+FF)PH%8*PO)!9AE(.WO63`+*GG@.2HI*F1J9(`C
MA;@VX5\ZN-'H2?.I/;(I(^*`60RT&>+;"'ST7W@:@,.\[BJH!#M+IXTD_`2Y
MTL2%ML:]O`"QR<(L-/V]?V=#H9UXH_IJ),[L1%30<$-+4=#VT&!1XT7",-]&
M=+;H921UR=W%U26945_L#*/Q5Q\!-L[Y-\#Q__=0VU2;P&X4C#Z%8U%TI3>Z
M0X!!4',O="LLN*FX7&?=UE8(=GL>>3VLT.E;(3B+T6J3>]DLYR8L9JX;Q61A
M.<4W.G`$52DAL,VLIZD(H\J9^5?'9MT;&39+**$@>U?4]&R^]51'E3A#7<!5
MKI$&,E=)7%!H!K?ZM1^TL7P4OL@!;T"+3#]<^7)(.XQZLNCY4]??M'!S'G5P
M"PN*S)UFXV+KFUEBZ9UE@I;0G-H8DJ+?-96;(9-LJ:CI_='BS/-NSE^3@[XX
M<!0Z&K?IB@Z[GSNO,SAQM55'LM10X/`GPK]#L<\DI'M,EW\\Q@I39N]4&3:5
M,12RVB.ZS^J)#:#2//WF0V9G@CPX7RY)Q(**[VS7]E\*)R4`-L$I8-GD$%I>
M;+1S^N-I#"J<8`1\YW2%72*<"CHL%!]5@>\_`XBB%0M/$TF3GR":=<:W6YX<
M&WNUCE5B3*\#IRI.7<5>\MK>LE>\FWGO0XH"?^V!QO%/LWF),$;-AEU8\\R,
MP!DIX4X]B9,R+?8V/RN.NC8YR3%\H\BV0ZS^._H)_*2/%Q8(;0O!H"<C`=GZ
MV)N%)]%C'[TWP9VIC/8;S&(-W-)DKN?`-<LGT]>`_#(1X+#ZR!Y5:)):C$A^
MV`FRN&NL(R><]*G::EPH<TZ+0G&Y)+#>P\`)2.TIP%K#9W*#\3&1<]I'=VJ0
M3OI/_**7]>PB8.'K(_@.?,#NM\OE1WS\*CCX1WG0T)LM-.J\0TP)I[B9!,W<
M:ISFKMOTO/<AZI+SGOQ[L!.R78Y2R<LRTQC\X#^`I9-=:(/<ENNH)RH9;I]W
MIX@N2R"=UKT]]#%,YG8^",TA!$9=OH8`OA9,&/,ISI;]U(GASQAC#=34/DH5
M"<.;MIT#7*),ACZL'RJG0JV,85*'BQ$RCFUCG<A($BL@?K5MT2^2F*HQ5@*%
M7#\2&G<`&AON_'%@\XD7DAZ(@@A=C!Y;"(XVY,Q'G&5#U-AB(()12!4"0\#P
M;KR='G(<!(E)^1/EI)W3SINFF;%$!9X;#L$\O@]&I+X-_1=J5I=)#W,3Y199
MJ+@C:$\Q7WZX4+ATG4#;CVSX'VX5T60NHT>-[)66*>K(>^W/30)_E@8=;@?"
MM>B_QNC[)-7`Y9(,G@J6UG`&F[KAG-3\SG%LZ)F=Y9(&R=>\`NJ,;:+:E&02
MZ0:WGZDI!="IF""_91.V"G0Q!)EIEPX?=4`45#EPJO"?Z<@+[;M$_:TG_$WU
M$B%R>=C5='SNKIQ![6K"B*"P,&L_K\F"174LV!4*P'W`-5RAOI4/PK`!Y#&P
M]FONN[+-M\:]^CD;8L0P/\3N8L(4!L8S]LN:WX!"#BIL_P>>>4SC*"D=>WSY
M'C<NQ<K4`)@_[:09`<ZBO2KQ"!HAC[3%R%WFT+T^BN.JV$MQ_CI;<MMDOL!-
MST]"2/;1_:+8^A$+O0%8M0:_N'3`5&QEU>5"I=D0&!KZ;F)>"1A$<>&TN]J"
MK_G.S;_C@-J[38V*S5H-.;**CG!N*U=1SB"%$-BRVK2BB*2_"".#G-]_AHZG
M2/QTEL.RM-4:*VA545A5BD1%(O?.+])FP\OG<M?D7TB4#V=H2@BM'WLU$!#8
M&.-3CV.]Y9#`*ME`$^%PE-X?TZ%SD86A/ZO)OP"\F'^2%0D!_5?$W*.SI'*O
MK3>^"^<-36-G`5(=4SOP;1>0L!!=^*=!_DS8^<OSK(SAFS.`&?!6FB#)XP_V
MNRFJ*3I2MIQ1GSPJ45&#T'&\HU9*KS1K6]5DCC&[C9I$H?E-&]*OUF(G$I\F
M8^/A,E9@A(MD.>2XL!A`]WO&H7])7^TUU-)P-.0"UQ2X>B*OV[T(XTJ2ZM[]
MQC5.O0N(WTO4`PB0ND>J;87D2+6>M[M-H<S8K2<7FYA^QGI(8Q?2]()M_>8E
M3=LZ9K7K\/4+8(./$;7>5HI%Z:!?>>"%'H%!U\QUQ%*O*4?,03!4<0Y_--Y6
MP`*!=ACZLO9LU]ZI%D$J7T]U6D+X9S`5;:N$;\J7$EBH@5@VVBK'NW]JL$$E
M-V4@`V^YT_C1."'3ZG'D4'.Q>P2D+&ZO_Z[K<O@0ZFGG8A5G'?D_WZQX<*XC
M(]\IE'!<OAK<0LRLVJY$RX1"*[H]2.*+T4QM=61_1A.`X"5#67;!`U)ZP1YH
ML2]JN+)IWIGE<_]ID87Z7SSL8Q1U;^RGWPK`37YSX$5>9UI9;><+K7<^QOC9
M%X;[O!$:/OZ_<0HH=,;__Z>M&*QCR<C\:'LTZIN&<BF#[:MJ^>KD(D'9;K7(
MVLO!X>B=2^)CA$"JP_TD>Z3%CXGWL@IB7#!SM>E58')#8:A\?L)1?RO"=NN4
MIH^/?H-IP'MO#^W@H;L`X?!^UH\A:=.&:1$2<3NZY1Y-A(3>)WL>V`IH],3O
M:Y/8=<TXC%+_+OG*&<)%4VJ\#&1BMTL"@E+$E*SV\@'J('GQOCD?`_?O._$^
M'():(QW2<TG@#/_P<PII-;0,>*BDBFNBM;BO^]+):P^W7F"EO%/#U5.+(N`N
MKPK_Q3AQ/&@5L4"AD7LN`42\Z43#$Q@BR/H$?I*8DX"HHPM5CBSA8H?8K-6D
MCTC$'GB7+_B.F43QGR<;G@E#U.K#MF^&Q9_R:%#@;CW+'>Q'@1R"RTCM_C[8
MNH>[32<"]C;+SFCW"`+V8R(4JSAU<.[#\JR930."$>N%*\$MSP)@=9+]_;__
MUG<&_Y<M<S_Q%5\K#J5IGRJJ.4:5(7QFX(3+AFLR&S5)0T`S7_F>HU/'0]AS
M/,[+>JJ24.0/(;O\5A4WY+I4O9.K']0SF58,:\#Z%]I*XM4;1J:3QWZ-H>%<
MN;W`A*)R'>YH2M=.:[!8JPY3:XYS(K&<7,6&&!$VI:"L'$)+T01179&(7LN;
MY-#5=1Y7:?`]0400XZBHS>9O7^&@N7P]5+K6L01B?K^R*J(].@^%3CL'A?!W
MP("\/J^<*B=T_L]ZC*#IJS7S/<Y!M*W97\X0>FA6=6C[^YGDAM66X$1S!9*O
M3`I+V6A23X&),BC^FI],$E(S`RH80,#"3Z6V'4W31GK$8;$(L0\HY(V-IY5M
M#=[`YI5.`43HD2Z5(NHUT16KEA4LS]%&=Z+@-@13:)-6@U+^J8J'?9/G+G)H
M>_AM^:`S+]-\#JW;M^JJ\4I$3XZ$CUE?9R=CN^B3];Y0/G:#MVL8Q3N(:B\,
MC)2!2XW.L;WF0<UQM6'-LFRI0Z/:WB,GLSG=!)L:"K@#=)65K.4N/]&XF']"
MS<0[E>--^>?[@`&^:TE@3=255NWS=_EJVTWWY(D)KH"UAP8#8Z?J"<@M';&6
M<*"Q1$LDO8<5G;74<`YS1)ME)CI-1`\YE".[D?9#T^IK<3O1"6)N>55RK)8N
M"1ZKP?(I8&_"C*$I%5[_2BL%I,Y=LDI]TYZXY5'BB(L`.NR/QJHANE(IL)Y!
MJZM6P=C3M/G@JB<V%,*5=B2DS^O`7)V"&0$P.R"?C#^,W&<H2?*W.U"TH/=]
M8M:@^[1GE&.#\[HR36N2Q:F2X#@I<A9?C;$Y$5"(B$U/?^.S5B78MD!W5,B!
MV3,I4HJU`)J?&G54AO`#Z<OST](LX]4$<!;W.+F>#P!=E_*!O<835W_'5)]_
M84@JJDZ';:\(_<GP64&_@Y$\^UDY17">@BG`O=HOVHX?^=V61)>+<4]OITP&
MK[>:%MY*ZRDJ5'XV[P%8)<!IL,6M#MSTWD@.[[EO,[#KN94M9TV`19O;Q)(W
MQ+.@^#8D(>.<!#81[\4PB&+''@#R^R.M9(]V1*;AE<8];V]S+R)[^U1+C3/Z
MR6!0@?6A.IFM,?2$X*_1]8I-BJ>$ZYA1<;2M2@G(NYV/3K^C^?=,3GS_T0LK
MA`_F0-16,E7J_@[)Q/N73J;1P"N:6)/!^E_/K#YR>&14'X#V^30UFSUG4!KO
M\ACP7'(PB.Y+1A8FA\%SN!Y"XA*\%@G!@(,=XXN)(J*79,44GV'W`+>[RI)J
M>-NU@D'O%0*L69M-O4.([\<3V2C``X.G.U;W""'3EQ]TQL."J%'OZ2!:YWZO
M3!^K$P"GX#)K^FLLNQ0.J8,E[)QXM3/Y!RMW2'+96XZX9LW%#S+&Y[@ECX^]
M4CZ&MJ6N^?ZCZJ%F:25:D\U7L'N6FGU-J>)Y'(UAV7N2,6G^_Y78UC1W;G\S
M7&[TCOVH"??T8ZWF,&999G&`VU3SP?++HR`8>!9(D?\Q0F/MBB%+^R`7F+$!
M3DV**'1/9CS.`IC=HA/`Z<N*-/^BR=(_<#_RF9KT7&(1$6QUT*/S/)1)NV=M
M[CYB-K#NONHV(PP(0RE`A1&#E8P3F:`2@\7Z)YYQ"T"C<_;63T8.S83$FHM@
MZH[IV*2V6>KU[+AQ^OC')OOP:74=\O>^T:-(#.?R`WBL59I.F.3^E!'PJMR&
M#VO$DVUU/3'[>F80[VE=LH;6]#@*^Q*?F0"`$$`KVF1F>`/(+^J#P("D)TY-
M9MA@*HX]5M2'U)]-O__&O_\HZPR"3KH#=&I4A'XO<7W\/7K^2]4[2S8?@`=V
M^&W\OZ[.O38E80E5TEW'=L\IPL2M'>A^7)R2<032#WJBPW.A;9D"!)J&U3QZ
MV?5!G+(\H#O+%7#4?K"$R6DC*!EA[J,A>9@@K=:9\W^5>:0F-UV.[\,'9<%4
MU-R+DIT/.0(-,T7B3%/I["L^:,OB=,9\3%67A]F\<9A4I59L[W,?7-Y>)-J"
M>_6_5G3_#>8*"NF1@$Z$]"#R!*3\T.U=[]D6=@1D,T@%9]P;3:RHB[P!\N8:
M!G.FL-J;[%N%\RZJ=Z/A*J'.9$L\@LX5^MQ9Z'%3C.'/>N<2Y/9H(U[#=+RC
M1)?/`(J]0?!"M`TYB#OP`C+!OK/=_$NR;"1)ZY?O^@SBIJ6NP1[3DHN_:6?`
M6DK"'2'8@"4;H4.VGKAOM(S6Q=B43'=3'OI6K9<!K7&*IGT--;B`>9ZQ:O':
M798,W+11I7)&*`N2>S.6#RWS!,2!&F]Y]KKT*W_G9F(F]#S_)0GN:ER88-T%
M((O(#\EGY<:'//HLJA.P5];,H7HFO:7X-Z=REHM-L0NMKZ--IAZ]@7W35MFM
M=K4J08E>&?@.]SP0H^#(2TD=AYX]_HAZ)#UIX<,=N.$'\]Z-M';,91]-IC)$
M$O^L;W52AS#R'A[O\>(*?A!DCR.<[(])*IQ+`4'H?``GJU$/HP?/=:#<S_48
M7%[X@1,:,:^GBSJN06PEJ+7/N5]7MQ<*"5''Y"^]W^5^QA:%37W7+#LUY=!F
MR_*4`?YZG[4*LYP4(?=./EI9"8VX^:_]/H>R]N8X%5B0V>0>>D>Y1G\BH56P
ML>C:QD.NZL$<AV8[I<R.8*GKH>C<EQ=#?9%FK2B=4)D[!$6=/YK<3\L!`F>^
M#B'1SSRM%6I'*H4=K*(5,,+:"+:,(Q@%$)4>+R*LQO_"P)<M<RMK5G<`;;-*
M2H,O#YQT(J.&P8AF5XFP='9A[$#2D%?-8G&K0$R<T'H"C/R*#'P<4#B9W1;J
M?]?XZ6$IF'-K,9A.?=Z_3H0[\7PL8L#I=I.R5WLI+Z*25R8;`LU;]@D,;>K-
M+,+Q>3M_GZT3\9$;_I8W@RH%1QVN<+^OU@J0W]6<CK)V"9_$;G__J&CY;F<'
M+I*81B+EB+<T5':U3`K#%XV>`::`\XU$,H?!"B-+B(CH8O*!W:\FJ@PN1_L;
M:H+PK@C-3])Z?\E`X4>9_9QGO7B#LZMD]^TMV:BOH_*YD\D=!RVPBV^BOG_7
M!7_(S^6(0U)ET&,55FT<KN]HTXF!P<OK,&,-TO)'\_H-)>;L"%F4ZAN&<NMR
M6PRQ3&A-/F[P.[K5SV\TP1F%-<MCM'\'8@V/XHYSC[0\%(WLMO\/K,3?OCB>
M^2U]RH$8*U5/ANSJM!Y+M7EKP-=O"'PB<-CQT6UV,8:5-7O#-Q3CTJSL:7H-
M<8X-5L'*-O0=AD=7$/A?_7$,A%0_Y]*WI`R7A<VJ_VJOL!H3Z=NQC^I74=(.
MD$6].90.YCH\-1D@D]>*FB)O]?$,)96"NHM+O`T(<M_(K:OAAT-X1[Q:I;+I
MH`3V68(B2*);XB=8S]L#!E8XI4VOUP+]\[UCZS^F40=#3)18BPPC1#1"]WA^
MV=$\(2M0V9O>7D:>C)9;]9VP!IRI&!U^!K5!`L\&L#\]WMVN)N=)BXA`!)22
MWA2@,!@Z/*&L`5L>B/%A@*;S0:<=I<NG;L7^P>TS%\3<I54[MK-G<:QN-5+;
M>=5>L3]BCNFKZ!F?QJP[30,$T../GF@LD&;M.DATWX$<(RL1YJ=3)O]$)KYW
MI`7G0:_#>4W%CQ'I9^:A`8;A7O$=V:6)#ZG?$=]&8VY%M(GN&3I/M<$@.P])
M\*IL]L<>4^7]6]UG)\,1A0I5*?7'',2V4$(.U%O6A:HQ4D)]X,?8'589YFR!
M48V;_TX+8B@<FV)+!?OK32YN:@S@_1_7&[`6Y58>U\YDTUR%YX=+,Q!=MPD2
M=?4*1F@)+[06(EB"?<G!P(\KE)#.6U2I"/@)W`W0RL^:/C5KX(Z/(?^,`&;_
M3N0`+FV^_#4RM=0XI[P*3K>](8V8L<GWL2*J$?09-RX0&B`1UI(9>:4M9NF%
M#PO(M*WI;6HID^U?=RI=G2&<F'-A<9&-.Q5A?LEO5O2!=&0)(U^]DU')SWL;
MU1HF&"AXY&8&2MOJ^(6?*JC^;'."0R2,C_1G@+&7JOHL\B12Y:M0]*YL+\W5
MH]OMJ_Z?!BXK>'=J#`ZF"JS#OC\7DR72*JSL0VB:5K'N-JQQ:$3H@>U\7W6*
MRW5V;LKZZ6*\D=9[XT0O(0Z=6,!,-0?:`)-SJ+U2O:V0NT[L%^3F.-B/LKSE
MHJ3V[+#\J?P_1G0,!JTRC5I*TGR4'C)RJ5\MS;I^A-TLVJ7,FOI[\YI[0NI.
MQ6A(^,Q5TMZW4?5NM`S+#ZW^=^)ORU@/]W?.PR\!]69P4X\:#_BNHWZDYV61
MHHPTFRH"ZN2-H?3#VZ[Y7.7C3?J@'/GQCW!#5=B)FARI;G8<F\)W)2*EN=<3
M;YSVOV3"S)*C<TL:#4W/`(./2:)0H\ER:WM=R`KD9+;&X5Y,_;N4[R;UG;OF
MA"F_9,67(#(W$0OKCCA>E6$'A`D$R[/)`A_A.IV$]V@@/7E^D[-!^G#XV']Y
M!K:N/4HJS9NC?#&34_`K8YU6B6*&M3XY"$J<CKA?&93QC4/MAOSB=\<W<Z8@
M*%^`78R(67T_-1%Z@/<BC;*R:HSL%;!@(\;01<T+J[D4?"/R@!?;G4BO&H9<
MVW&MU'>=UZE*HPI,9R6R%4Z5:8"61R!V*[2'7Z(!S,KV?&"89LZS@O2S>I!M
M,!LF?'*Q$@\+TT&EP[BPEU(\-SDPSC_ZT_=WN=_\HI9M$1JQ6GF(&0')>\E-
M'^Z/(O*^!GUWWN-'#FOR^B?QVIK5S]?\M$*>+W50:^)C)NKS$UEHR5-0M&0(
MK'A=Q`-^^&DS"2\,V%H*]-@'@Y!Q:UL+4XD&&E^(SW8JJCJC+*N&;CNP6_K0
M>#88-B,G(BZRGCP/PMD[H@UP2%%$D,TDE^9)Z2!2?FB>(GHG<-BPI5%YWNG'
M+]*VZT0K$-'U.S:]_4!;Y3C^23N;Y1]^E#+O#+1I6DHYS@1;19&FO`FFO,(_
M)>Y7Z`@9,]4!X$"@<!I()^W+.C/Y-Z#@!U6@6A6E6U7>3C`DD[V7)21C8G\K
M2=_+D#F&P4IEE0_%GOQ$^7U[`GG9P#"2H:ORTM%`W8GE6*,%P')=RA"#'AL0
M;\T7I%G\.VS>0ES<4-YP/T5:>='K]@X0/#@E]F,=W=7CY:9>V=7SRHFF0KJ:
MQ(R;NYBSR9/2?3S.S'=4GSN7BG"O*A5A?:+[7IG7<A"`MDAWE*>NPC3*Y[8%
MZ=71`6^GMNUP+4"0!(;^O,95:ETT+V?]LR.\SG=*&3'.)2:NV2,D\]!<&'O6
MAZ[RK&O,WU9[_XW/Q][(6^TW3RX6D3,<UH58.".6NKJ,-S#4<:<SHT>CPQC'
MVV3[LOKOJ#X0:D!<BZG&4"S*;%TW=$0^/AQ8P&0DRU\"KH^PY%Q:4TGJ!.)2
M*73,,[K/9RUNY*G-T^L)33P.R@LZ`K9L*^J'L-;N.*QUQ$C]I(DY.W&\6=`)
M(-DO?2PO#='/-%OF1CC+OB<;K-K'K-)/P;"1<RW!1HDU5?Y/Y)3KS_&?LC_F
M8IPQ6!5F80:>NII^<N>M%F$FW=$<6"$E)-2[DV=O%41%&_^7&SW]5;4SLAL(
M&508?7%6V;).7[1F*E$8P*&O$'8')!FY?.^_\^2JM<L#N=>L(S&SJ+(G[)T]
MN/F]W":7I0RF'8EY+ZO[-8`TR&WTJK)*KIQX%,0T;;6K`GW<S7>V.P;[JR2L
MW(DVZ/\7ULIEN"=,_EQRLG3,QX%$U`NM4^:QRA!EMP$7M+%;BAUHX':JGTA4
M^T<1FNJG\5#X]J5]F/PJ&]^IFTJ:-!%7,B!PA%7K%.K_72A_VM[?:6T1>02!
M[QH$0%0GC96)XB"`Z"#)**!.W]]-:)Z:[6I4](LF+C*ZM#=IW"!8*Z#K+=!L
MT<U.,],#+51XG`/[6;85(,_7&%<^A#N)+W,QRI/96[XACTI+'SJO2N2L[$><
M6/[X-.SV(G)L^&+:CCK4)U^.4;XM[.!7]&_<Q%>O'.%R2#6_29:&^'#IR].S
M-[L<>,^+<J4$4ZD\_>:;QU/6*&WCUQPT:8/,!^>2/QU0'NP/.$1!6ZU;]AH9
M]=&]J?$O_10)BO=EPD^<$):0#SU!J9^44]G:DO)%"UY$8JQ,:,@TM9BQ/XM7
M*L<T2&B9!_U]=EM[S_7$V4AN+@<^D.[B\%P4:/8'/M/F/[7)@RP+19Z#N=K&
MG\\`U`+!YO8[_7'/Z4:2&;;BI^$#G+)]`IVKIO'YI!5@B,1FH`^EM%^/B*P@
MXVC/$//>6FA<05+Y*W[!8#`LZ%'D#:^U.V'8WZFM=.&PV.8C_JVDJI=\V@:D
M<<\VB;BL@?B\TJ%6DK`/4<@GOW"P[5I1U=".H2`'N-=!"[+##'FA8*%N&L#;
M*(7E0<KQH]AP[%,V994L14R\Y8L9/<!'2K5==A_LGT!F6)%>`)<DI3BS;*%8
MMR$J)IK.);F]Q,\^"U$GK0_:]A#BE'_;\TWF$'"-S=QTDD1VZ2&J.;24TIDF
M'59R1!J2I;MBK(`9X!@,IRRD%S;<-]KW)A]V,HL(`F6N:GX7B!5E!G,FZ'F`
MUCJW4TW=W;%V19_<Z;07-PBK9J!OAC-7Z.^L1;:6L884J^K-TZ6MC1SRPP/$
M/'Z?2[4*[&T0`IBNX;H)OGZS.,<7B$0#8<JM)\5<\QCCXW]5QD#O3$50*0PO
M-^'J+DU\;Q>\PW)99J\O'A(Z-$QAWZ5I3OTELX&;A`L7IKTH"JF)C&`@?006
M`]GT.$>L4_;6.+VZ*P@H'0LB%8"S+_N4[5Q+4\=7)V5.>=WX`K@%B,RN9YM&
M=;2C45$8JN(-KU3Y^__>Z,,'O8RX23:962'Z,VE5?:N(1\D4=NX:!'6XOO.O
M';>OQJ$QCTU[0=:*FVU"UJ(8D$I#U(XE^W&#VB#(!+*!)M@P\S&4DZ#%/PV_
M`TU$>B:<8DSF&5TYD[59QD:_&+MZ=I-=U4?L"Q4P-EEXX_$#]0/7CV#:0/-$
M_U>4D"NX"L\,-!>B\<M)#,&A@HU7%B&(V3N=T,>1Z0LE+_BJ`<(H+9;`UF8G
M]I`*K]2FE\?UK2JAD>VF^ON-2$!_N%];PA?[CC3I3I^/05F4@(PJI;;N;6Q!
MBKV!.+MVUNE2W?:_ZCB$`2Z=,V268C/>"AS&_`O[_-]41,D1&<-=&#L-A$JY
M59[<T%!XRTKAAD"\G-+NKS4R1?4AXNRDN"&T&VV>TF>7H[7Z`4P^YYFA-5'<
M8LE:-W31=:DF^AIPA.UNF"A,YX31U>0-#B>ESZX5X>TA9FVH&K>;.>*X_<_>
M4%$3-B,:;1//>V5^%G*+V4@WTYB5.$)(8I8<TKW1>L$8Z%.6NZI?I)K`+$(W
M,U=K@!R[">I:TR*1\E+Y:HA6LX7?L)>TPU.USCY.LC_<R>RN"R?,E2H*Q:04
MFW(\=+YZ>")6-0?UI%11UM=JA%=0UO[BCDO)L48-SWJ]J,TT3+@M)#"SIP#S
M;K`WQ+C!3Q,YKKO.^PJ+Y29>8#A'>(`N?6J0!A54&'ON:PYI#<)!NE9\XAU(
M8\=<R%87VP3D'`5Q@(M^39^[Q`94]9/=8MQ_THQ]\:2@WX&AN8$E)1<@Y2$;
M2"1-&%%;95$6.O9R<#`HX;@3Z#WVASKR:'#]:59)II[(LBHHPOR^>:K9..B>
MFW)>%1\>!_/7O%63'#?6$U]76AM22<@=^I+'KW`>%>Z7#6M\*,5:GD=8"/B%
MK&2]1MZX_75QEXTD"K!0+C<Z=QE9_JZ+"KG*;+QRS\&']EQ+<Y-2_DLCS2C7
MW+(("KS0P/'7JHZA8]R\-`U(A.0J7]Y@QK_-KR9'(+4HD-UXWO:-QO3D[`JK
M&&'G9P$4/E0#>/MF<:4/+P:AUM^32%]$)DBU%@ZG@O`F24G>8<*0O"CK$A@5
MQK:*]6V;X9]8]1E\-\Z[CZ.7,M@EYRPN)%OGV4?MHU7PO_J$/ST.^.HF;.AU
M6@//,H;36`N9DLK4UQC$K84K'//D&Z^W;N&QN=SWQF+FA18EN;1@8/=/^L_S
M9RLH%7RRF/#9`+XXOO3"ZB:ST9V?2>I89+F,C8MQM-SJEYZ?[I0WX<+(OS/$
M>VJ[&^B66@-;F)0BDF[;8\F$;E0KJX,Q:FL55,5%;5-U\42W#?^*VK.26XW3
M_Q1&V'I*/'%.0?U7VKIF">EB+4L_CI3(N(Y[TT5QM-Q3U</7XK)_];$($-)O
M3:+T<5;6]+_`6^],:WA`@AF6CN8'2AY.#=F6J)=0NH^BQJ\;G\%44H3_B2J)
M'$H6VN[T*4':8`2ORW$ZSU6`'=$/K1MPMTUK8LI*=YN$0TUM!8)U+UR;R&'=
MRE&*#/V"C^]F#F0+C;UH&W!:YTIB1%C:3(Y1VB&H7OKHI>IZ,P%J<?*HMUPH
M9&V7@P9>LD3$;W_SW0=Y^D7!]+UK;\R'M/KDZ4H4@'&,IZ7CP(QB:(?PO-.R
MDB;6]Y%81S>O36[^UJ]*8SQ/@LE;H^0>KHAP+09&[7&#(JL]4JN5J(O_7'D;
MO9LDTV=B>VRF=!<$=Y1)XI?DY#[-<I!PE,'E@H!428;IO:PTZ4!0.WQ4\A<)
MHD<(\2D18U#&Y^Z$$;/]#SWZPQ(UROT@V@7J+H16`#$.**;T+J4A,ET\?#[+
M!T'%,<W6B'#]$0`;,'4;]"W;D&O%"%@4!&POLOEQ7085FB-=O./_IT/UBUG?
MZ4RK"SE#,E!Q"25U>/C:I-UU4Q5]_WF[0%'>%M1G,.Y\N.TU3O%-ACFA@>=L
M<G9`"@%69*ML_R424@9GA<E18S!UHR.,`E6@LR[[^2;T^26P;S=.TG;"M"KF
M?!LIO89U\Y*\NNW=W%;'Q5VJGUL$3WS]#FSP0W,D^%5@)^<E[H;>?$71-MK+
M;>5>PK.T'A<X,ABO#**\^WJ\3;#0R;8ZY$`HJ]4$)5H+\(#/B^UF`9QNNPJ.
M/0N]T(=N^@3T+4O-I.C56\K`#P//*JH=>00Q+F-!ASKG!_!!?&9*\P5(RG4$
M`J9D+>%;+>B?C`WM*1UL4/]$OXBR./X[I5H0FBDQO5@/5,-OWO=@EAXB?"\6
M4U;%U:^IYOZ;1FM]^CTM"M#]D]=88'HRW-)K@Q7B)'9?E!Q/>LEQ*F?=DZB,
M+P2:5+Q$9ZIGB#<C"_,5341CFS9L,,$BSHP[VM_%X26@(,.#X>*Y/44F.M_W
M(>6XO#SZR#PC\X<-^KG9DLU1L!(]/$(CFG@+#D//G29TK0S\!UR(3)N*23&2
M_/F0\(J[)-";,/%=R*E"M'\OLA5IF%\%-C9@&UERL5B!PU#U;E_=6YQM1FDJ
ME3'`N8<X[F^B-)8/\4)E<QQMXBUT'N\#<NLP>IQ2"7381KL#*O-0/FR1W./5
MC1M:#!DF$XRN6<<=00&8V:41`YYD#>ZH+I2YMG;_D<P+1;Q3ZP2YCWXD+'V9
MQZP-R:`#2U0G[L3HJ/26_OZBHF]">L]U@8@W/18S_[C[5_#@0(-\8$BDOSS5
M@_#RB!X2;+_IMEWO-:!"%_E93P?A'L4CD7,N46OLN;RO$=)5MH$2+'17F,74
M)P_W99XJ<YY;9!&TP_U.5?^J$?"`%Y)_4%NM38613VF[\A"+;T&2F/]3TJ-9
MKRN.LGPIU8EP$M:Q[2X`UW1/",;98[+G!J9;SBG1NS=<RM/%Y`KWC!\-;66D
M^(TKDDZ`>VDR(8%L$'Z0]9EAY[8`3,(SN"=[0V']*0SSH2S*+K81_2_!G@>I
MPI''J6D'[@MSXV](:6D<WTB_L@"]^&&-BRM!E+0YOK_)KW0./`O/*5S8QJ<K
MRE/#O$QUW`K'<2.YX;R&>_A_EA66<+%PA\R1`2!`"4E]$J<8C[];HB#LA9RS
M&S8+MIJ6%%VXX/AU43>L"0QJ:`?<_P`PFNWK5K4'&A98G&+F]_3NSPSY?&DJ
MXP2"?QF8>4.$;:DO1C"S@W#H.)H%3Z7EJ@H*>Z'9]W^TH+>*C5-;JESXA,ZB
MEV$K88K8=VDRRO^W"JI/4:21[(%DMYLYDA=7T-.I42&8@+D3%"I)?647^.#V
MR2&!WDZVBP$$J;V75B\'I!PD].CLNX*Z*<C!WD\J9-D4SAZC;(#)_;KX%[#K
ML1?7G>D8Y?#8.@-WX7&&WY`YV?WR$$?ID8&35W\%K!W.9A:SEZ2[HJT[8!9*
M,)GOIV`V!36[A$PQ*ID6IJV8(-P$Q5-""K8TT9J,\E&X_5U3;<^F:'_2/^.%
MMY1V]<?$`,*'S<YMO%AQC7O)?."/%?;+J&9`KE7^/9GZW6^#OWIM9T^9#+"]
M7<_-K\6EM\BW#?/_#6YV]]GLCQP1\VBKW7'4(<QZHMR_&*N(9*IB8Z-JFXTM
M6<G>]'$CX5=X;]O.GY,@-T3DEMK)R,$!3#^F#E:7[O5?H^[4>);&B@[!\)?>
M`V]=_\N3EM\_X[.H6M'^U.>R\?399YK&?-">`:#7E'%[Z,?&1#@F<+GU;_A&
MDL\-);$";."7U_:E+Z7^WC6QSR3(@"F:0&(1-A-JA!WV4/,J>H44KN?KS+V:
MD@NZ]*D,R4^2_8]D"'4N180=DTY0F"VM024W]\,0_A@QI9#,AC!)BEWP3JOP
M+Y;0:L.$DT;[YWGT-XR(/FZ/?0E5_(UX`'R%*!E"$JOL,L:+ENP6\R+M><_6
ML%RJP5IC7=IB2`QN385625[]E<X)[3;R$$_M&!/#:;YN:LD]_1_K[0ONQ*Y+
M87(35QY+SI*6^C``=>I(NA!5N=?`QGLH+G8SJ:0+=RZ!:&EU^2S\A)N15'P(
M&>!:,>'.143H*L;.89RKMDZ$KI3)([3Z:X^%?;=&2$+P=U)W,>W?2N@3&T3H
MQF1:_J?VS2`@P?LZZ)'Q!5!+'>51=RN'%D=4$4E:3WYC^^,4GK1@(4B`(;A1
M6+TN7`:!VY#<R,F+T-E$Z&*0Q#/KEP<JQMIAS5UAS=\7?WTL5<A0&>0MD>XF
M0X&6;L9)G(U8181_"%])H9/?,24A@$95QI\E7(FX]9I[24S-/3YX>*Q_CC/X
MU6=-,Z*@!!0Z4GD(,ZQCA2EE#U,L:*2?F&C]<VW@&PK=I6R7UU;7I$LN[?K&
MMRC"]3(@X3?(Q;A<L6B()/VVG;/?`RA6,SC`DD00%R_@V"46/_%U1O\]8Q%8
MV-M=!D<."9OF>&AH1VD]>3G2P@?6&,(Q8FW9,'KW;!R(91PWW41P1R:@(B4B
M1SRW3>9@78Q.":OO%5X2`5D&R)3K:O`YNC.OSFL92&:&&)BIZ9!ZS4O!;5$!
M^(KA/D(S&&FCHV1R]<>T<&HY-(BGJY^W-AJ^.9QXX^S;[W`C,@A*51W-V/%0
MTA0LZ\HF-;$PXKTD,U_C0>]A[/^$/1/HJ_8T-[?#8BBW#S7B#'+?+M03W<:J
M.W;$@]KO$`LG&XW#E+5*RB>CI8ZU3HJ]1*DJN?ZK\1.?MKW'@#?A$^X&"P;_
M_ZLOC,"1>(CY&Y[9O#]3JS=""N\<F0$K>^2;S@PAGNF*/%NU=2*5;D'<8K#"
M*QG,>66C7ED`#'ZU/$*!*M[_T^`IP-3:%`!YIN/&75-&K:4/_N.QP-DEYX7\
MRY"'1ZA0@I$+HIZ3\N6'@L^T-7VXM8X0E)N<\`5EBTL:[&%:>RBQ=)2<5>O3
MXUD>%[P3LPI!@HYY((LN&_!2K83'RR[RN!"9*'J03PE/0+`TMUH5CV&%*I2B
ME0S?WXJ"``O",2>B96IU\J&V))SP7B.#A%T5B)>`QECG@2F,SBQ7*=>O6'4(
M7,LS^`\!-)A7VH-WZVC/:XH7#/X@%UP)XA'PCXTJ@@WBUFA6H8I;X^GI61]5
M=AA1/*3[5^SGRKSWE_.SLXHRZV4!<_;MR,;.H[">Y+WAO%\&FZ*@5G.<\X)S
MII:V'GI27/`[',OSP'*P:``4-_]/8]`V)D;ROLZ&(&YAR[2N]G/Y+S%Y2/^;
MY$BZ*=/!]T&LF>Z.'M`85<.EO@/?S!#1Z",8ZPN`JJFJNAA-_ZW@X'1.S_J\
M!4-Y'LB+GEN]0VA?F=LV8A80BU0:*?R0#\GS'9XX>$HXAJ>\0XMI=U>PMX^,
MGE)Y,`H+NJ/<&9I+Z0^=0I(5!0UA30T;^Z_E":F6"D1G5W*S4W$TZZJ61O<4
M&(S$XY?@"ZF@(*^80RL1X";(L(931K8^S>C^^E&C!7CP$/U?&C?9?OP$XE*L
MX;32W,],_GRGB8%KL5=&%`K13+`L^K8/VM:@]A0K]>%>%BQ"_N8:G+(]Y!>Q
MTK`_<9D!/U'Z\!7(CG)@UM>K%//3PN15&)4T.'$*U\Y$TEUK)+WX+=YG&<T?
M#@TCG7J/6$40T87_Z[<AR/W`5],VOL:+%]I>3]'V\\S(U3^$_2VX#]8G_-F[
M*S08T_SF8E(X)SY$ZK]O"X)F=[VD+!$S$*%?>`*DP0$&#[>IT9*6B)9&T8[G
M32%W-'QB$R!DY0S)^)7.SB,._])^^U:U,.W7E\:Y.$Z3RR#94I[95-)P=B6Q
MK?QN"5(+R\8F>V2U;Z+O\2:7E86<!?*)%5A/1KG]A*P0[S)BG.4OFE<0W<=%
M_(^;>SV\]2($DJ';<!QO#6K$E)0BLC?P"/^-3B^.CX3^D5T4$]HYL]J<.EQH
M?N)*?0^N/Q!RS>GEY9/P%-:NE8$0=5A_?V6(N]K/0+'?/IY/'82U15382MD-
M)B5'/OR/F%=L^1Q5\F#VN,YK??_DP.?DV+Y@;$(4#]>S)V+&W;9#%O$`<A&0
MD]XDU?5QB,B&[0+VUO]`(YJ&2Z%UWJ$\8RGJT\V62FJ^H'WRMG3Y`I"W0.=G
M$J(CW\5'W*?N)4QZUR6'8Z24]X==XQ6W&&U!@$2@'Z\M([&%Z(VD%N*YIDS1
MN?#C0[HZ`RP9[MXON1`FKTIVBF7E/@8Y0@4R).L<!XMP1[L[[X-9W'F,16=2
ME.ICA[-;]O^U*YIW)RJI\'EIY.C8KW)]KSH*NQQ[7B[`AY.+I-/O7?.C;"";
MT/YXW,H0]CG/9:Z;1:>W>W\M0?G$29L,9?^27O87L>P7K*H>]D,UR#QN27IH
MB]JPD/2,@2=4M*3HG$\L^E]X)F70Q!)Y/95T]=8TY?7W+?Z?(S/;19YFJD]5
M>SD!EF\YP^[O\Q\I$-@4=5^M#50=SW$S*GJBZ+"VD:C0=+$_G6O!-'66BYS#
ML14R"8@,<'7NY'5OJO9VR9K97T'EG*#K].MNQZE?Z_""^*W\G**3SM-#G_@U
M+[Y]-EGIP^O"+KGBYK`[G`AE%,%IIKPVC)U&Z1"_[Y0:*SO<4ES:'Q>9&+;"
M6Y2=H-$S.$KPY%Z]:F7X\+K>D^%MPO2]=5=$R6?MY#C9`DYL$GL\-DN%=RP:
M1QWM&WW]YVA^Y/`V$$3+%H)%EU.:)>SW]F^@;Y^YYJ+@^B8NF.`).W`#K5'[
M9M^A:\9AM]C?FL`1H"D'+"6Q-D*0UP0DN"C+8XT3EQ>$A?3QG:SH2EU"]+S8
MZ1T,S9,U/51]P5"%U:JQK2B<VE%S-H16QN3H9V#,42PMX.9RI[BB$:DS2H`F
M$QX]:CHRNWY;H=*KF?4J)`?Z?[RNA*'Z4%.\.L!0@K#27#5C2`*F6:=ZN.:/
M6@#]#<1.]7!-G563UA'`'A'M+0.&_'3I\BX7@/>SN?)=544],4"%Q5["C]3,
M`/Z#N?\:]@>.SVJ[*Z=[9A+$^!Y;`C3H6[]4,$L7,@4A`SBF:K"WH=J#8%VA
M_7IKCB1Q^/3DW=$TTKZIHH48:0@30#\^PS["+/U?^#5,_LMFUJVR39&OX>K'
MWR-.BTWX"6_[V`K)S'L#5'1.F1\>NLSR#0@70V>)FUQ0%SR5`\Q-K(-ZWF>[
MDQQ&UYN1,.-`(:&I%<EH*;3OJM[A,UD.QT,-(TU;%,V%\#[#,4$]%GKE>`\Y
MHI`+B0H5T6M62JC_WXNS^$;I^O^7$;^&7^"&KICNFG7W*F=CI`?3'$36,<7-
MO2FDGAAJV(O[%)<+KTP-GCG5I0%)\2'%&*'8*;+F-F_:3N6L`E]#"8K.X>G.
M[L&-/]]=(RB$],#L\H2$\3F.$!EDYOX4TQL!:%]\D:7^K+BFY"<NL0X]NN<X
MD52UN#=NV2S?I+?]GEDS9(EN\;@1KRR^#**V:<I:%#CF?L0?8)$[KBAZQ/8.
M/6..C/79^H$C=2=)RK0XX1!9DJ4*99=:VAAJ`$/VA7,$4O3S.2DH:F"]E@J`
M^%:$P2'JNA.I]L`N?H-C:5-S3&+&R.(--+2`Y-)-:[_7`T,LD=I/+"85QV)/
M[!MD80ISI!L"^"V8T`?VE,%INI2(%H#F9F&!=_KX#L>UT[ZSG4HB7>%/3-9B
M=\EW;.;[#K>$HRW."7'4^8:S8KUM.%_3-889:S(S-2?9?;`.\)@=`2X$B%N[
M@$:)[:EQM'5_#2(]XNJ\H&3%"L%$YT+6<8X54:GX],LC7^*0!8WF8?B0F=AT
M;2B`I`F2H)[C1-L`+N>6EOKY4-OXS/^CGO[^$@Q>PT=[.70-L3J^%,8MA<V0
MVD7F6LO/5XOGPUUD0L]SX,_<LS6!TXO:./.,)CH[9TE347"%]*_Y;G1H@0Y_
M7T0V)P_F1Q4$VS!$?AV0])=-$RQ=UE?BE3D`)[6Y5,S!6@*E.H/#^C7]W.AB
MIQODQB*8EZ,(@%F$]L`'Q!T..NBJ)CU8G1VQD3S_5$M0FQ)J2LAW6-#^9R2T
MD&S+M[8BRMS+Z\;+T/9A@NV=4]FX%EZ%ZV.3$*W.:-V%;OJ#,%D-)HAL[>U5
MT*?;]5.*_#<_DS@>O:"MKX1-FZ,PF*)Z7#59V]9_L>Q1"XZT.^ONI/`K:%^*
MT8NH%LCO:,*^S1%<9,=$,W78P3@+:*PG.\4N,P)JA2@7Y5_70QVJ%ZTKG_3;
M1$"+%-"D/;T2/W4;)PZ\Y?;JX*A97+-:@F*D?@NX>)8FOPF"85.!RY[(Z&RE
MV`^U>G7<GHA*4P:J5RVS0HETWK&JJ[^I1/EA8<;#"[<:;*^#Q3\1A]N_2++,
M`(I$BO!J&ST.9\<(><D$#&*NSQ`KX3\.<V$C/?BWS<UKV=1XFAGZ/^9U%`8F
M8ZD6LB71M&$AU&MR5\0/FD`^M>2%UIFW^@]-DWCRF)H?3%2'N:<76$X%.!%'
M30>DB2I^I^X%3ZW@*C!G"5>YU<T2#BC>_K8VW`DWUIGJ9!6LK:F,;&D,9+0G
MI?5,"?KI'F!&[[:_=[<_7S`#>.EUU,/).RJD$J)K+0%=6]+5@7)L:UD?D!AL
M>^83$?Y2(.FQ%E:703+?3LT!(-I2L:^:OS&*0,-^'_+63_FDK2G/*)7/W7,^
M=\!%OW-=B6'!IER(F;5RW=X$.@#@O3&^+42IQ)C%8YO4DT$,P9G_FH-*BPCD
M9C2@)6W(H:,GTCM^"L8,?(?;#J_=^QR5!VNH*5WQ)C@*IU4?*^PHCE$J=@1,
M'PEZRM%KAD0'%*!M<E/"J.\A_5`V'7IPI4U1.CV1.QTA.%@J?SR1"5GZE(/>
MO),D9ROI5'>-HH^VTV?H8$M.`U%F:1KN=N/&UKYG+E"CVGQY]_7G,?YV??^.
M<D[3;QO%DBTNGT.@(93U"9H75#4O;?6<),;Y47.@=Z4A_J6T0Q*O[308ZCU<
M:X0GL"4RFHQHM@4D,!2[2?Y"=8Z<2)\X#U&%NJ%`8S)"2FH5_=A_980T/XM:
M@0P9K:8773!.R!T0&-779[+-`KXYH.?3,A$X&%4.T[@O$"TPMC5A%T;/!9;H
M8;-D9)A7@$@1LZ\JBU<S):"RE+*J^H(/XK8XTLLVS0?E7CG/I3W!4;8VXB1]
M>:<>G^.]_3%ZSOGK'!;V2[H&42!00*FR7(V,3T0@B^F<-X?BAF?3Y0@G81/S
MHS:(I]7^G-E<07;8&AEE>&9ILR-WX*14JU)&#3MY6TX[@XCVU5GO%Y@*%M'S
M=$L#;]E>W\-I9G:K&!<?-`,2I>8"1Q(V\PJG3]+$\@OJB>;AF$J+UT8MD)C1
M%WA#OW%BR[#WV04'(PUJ&3[DZQO4V$4,;L%S'P6G(33W;]WJN8[5`T*/=-WV
M(IQ*H4E38;ZL5.HR*?U,*Z#.Q[;-$:KE#[Q3G")$#(DF&![S/24`!,G?VEUQ
MWDP97-G`FI(]\):+_(R</4IA/R3W%^FP3H%D'<$>3FC4[MF:@_$U=H;/PSP8
M*+\T#'?"=AZG$)D>VKP&'30U5.+0&/>V5U&1G1/D'KWLGC;C?MA6C;8Z8'O?
M7%&2`17QQKJ:CZ$&?$!$AF177\O7`<HSQ+O&*QAT3FN\L;W8GV`F#QU-<=L=
M99?0Q3`DCJV+0:R6DR$[UE)=.UXN`&==-3U[$Z7,39V%]]B$N.P_KI'5QY.8
M(\8&P_%2IB\&Z<Z[H3OUFQ^KZG/N4D=)1]#G(?,&=VK.GU>\@/,]%P\!A8(Z
M&R)E12Q993Q6=[HI1T2-,?NEWAFGRTL6DM(&A0)9^!<\*+"0XV2Z,JM=B8##
M!PU-B%&M0Q`83&"T#\\+*VI.5NT9GQ$*R($Q-I8G"1>E@M)6".G+$:#X3RG]
M5:7YD@W9A=M,!5A5=01P<N?IVU>WSY[IH2HB`"PKS7\?X^GB?/?&(26O"S?#
MFP=X_(CX/66][9-7;&2]O&8VF84[I=#]BU!!C?$[YF.?//-D8<[)1L\D6R6?
M5MY?=M868?3ZD1L`OY>H-U!A#D;1<,&L&G;09VW)@`,.Q,W%GA7'6.2V5:N-
MX`[N!&M?!F_P$<'([A1B"',+TK*H!!`5\9*-+A3_2"HT_,KEC>\%HRMPC4:R
MBV72Z1!U/Z+#UJ1SUKE-B_)$;1U<N>1+2+Z,UTI*4.9RCV<V?"'1X_LA9N#,
M^2F2Z9:UG-FST/E:`[_Y]G;%@#9`YUT!@'YV+#1)MI<L^0IMJH(M-%IF2[0G
M]1]X)-/U-3USE-L5]QAINOS5W*:Z__LH3;4]KYY5`5C@4KO2I'ZWG,R3^-L?
MX#821H3/O)1`?"_M`%!)LZ*-#JU;$CR:*SQ/SKC1G<#E.4R$)6CE"[]:#>Q(
M[#_#,2].TSBG[SY1<N`T"4)KCU#/ML5'3=!44RD#%^`^.^_-)\C,R]1#\T!;
M,KK$EF+S50:+JX5OW'W"G6:\[4%N8"+^0O(VIJ!R'EU6^V/%69LJ>&PW2[P9
MY8B]`?F1&AGOU9;L@\%93>N<*Y-M>;3'EN$2`,%%MAH#RG&"3M8<8Y2@O/4,
MK4\\T,@@DM]+2:1FC%=0LX/+3.N1+(22I:[4O[9*PTC(*VM$_&4)S1%HT]50
M2,,0]EX>A9;R$34-IU&Q,6[2/_#T,;QNA@9LNE,2MA`!U#HMB^S@@.W[WA24
M^*H*O"?T4NEBV\#&<":Y3!CQ5G<`)C1=FXS<-J>N'+>FIEV[KC:>)F6<ZM4]
M9N_L&U"/HGP/57NCS\/7>&H_+]EF3QH'#2U'^LP0V&D[WSTA;@UF"SD8L'<&
M27ID_>#[&>H6%=DIKBCU4,'\0+3X%>1JTM]HIX]+$0UW5UKXTQM-7OY6+QX^
M?]\(DZ<0,ANWW1J:N[S0A/FZ!_L&TQWULOS,M8_3H$U44Y&`;WM;^Z.K^9&&
MY+8OKJWM8[>S%+XX<(?17YG<MG`5AS#.21NC8VF8>L]J0$V@5`7<*.\,_T(#
M)(MC.K:[;8/YKM0U)<R:FS)=OG:X5AC9?S`/4X*_VN)=5N:[7`U.+79[&_+&
MUUK*P?+7'L1QM'-D`D"D]&*H"<UA+X<P@+]0J3X(XG):0?"D8)Q\ZV5:4+=R
M+R$*+_3_J-2P=0+-X2S0\P4Q0LKE2#9(;^RIC3]$6%RX1GZIHXXL4(=%N3RQ
MD[&Z.$1N%X70J;5HE'_6"J816+Q^RS$Q#[4=<)L=[,2XJFA/5?QC&H>>CX2]
MFJ1)A)5N_5XK-;E+)ZVSQ^FFZQ_&4^(/2[S^\<RB%DC2VKO.7WCW[^$G37Q5
MR)+7%G1?GGT=[1WQS/B@1"OG..&_BT42/QMX7@Q(*DY@-/AS(J6!PG1];>P^
M0=CAW2_3!-CU**DG4@6\*#D,%S<MU,F'TRP/=_QZE0PX*`(SRU?50@3:BF=O
M:M.5ERW3V0L;4Q`=O]0(6F)3JKR0"*OV6+7"LY<3IV8-;;3'JI\[O7&,1"Y9
M7**6@DF%WS%*SFV*G$;!Y4ZI05Q]%@OO==XM[=]G]OIQN$+1'N0*%75U_E7Y
ME^WT_)W1?_5$B@'TE)\)2Q^82'P$PX[66B:*IY>9<12B14'F%)&$)'1QT%N\
M="V4,S$D6/84?^^)#$7Z<A\^2ISXB0SP*P+OP,D:Y0603WHH).G[4X(W$:X2
M5Z.9I>G.(&/2`;J$EDT2BC191IUAAYN<@M+`4"4R"B`N(\T/M"_J25ZA*P7K
M4-:E1GIY_&H-JVSQ<W0UCV==PP`5F)G0$20:\;W=$TZ+96#QPT0GXI&[^W(C
M)'<*(IN%;(,ZF9-!AVJ+$$)'\$&7DOT9[*T3_O#TW7GB%%U'=6EWH.67MWC7
M<NT`R'_>AV=1?N18B$N9B:VH"`6/Y)_L)Q#6WBK!VL9#<@]ZB-OK+BK@Q^@E
MAE8""`AZEC]A4])/HFFA@0#]=KS,P8:*B1/.TC4-6C,?N<P:=!P\*_R^6LHH
M(%Y%I'8,+,3(Q#E?X-07X6I[QR<,;LE)LR`L[C<<M[F\HA#3\8.?`OYM`-_P
MB&SX6MBZB>US3.UR;&ZZ6'4YG(@6G)%OZKA2+V!G6@T3+_H(<&^XG!\^G-G+
MY$=;6'8E(2T<YIC*@+T1^XRHT;]K(4,=W*)C>PU(*QX"%H(LKXO3YED40\K,
MV"H@J!K;_:2^89;/_>L&:UTHN!-15[\]G*.R^37JZ];/?-FTV@2^6,V2YRL)
M"$/K<3C6QS^4PG^)U9&:."JR,P8?8T:.5RL*$+Z8:O:0@D`?%ZH0-$FNI236
MRWNG^].TLPSUY;+=37D641J]I80OAVG&8]A[0IH2]K,^Z$[(300&`.,'0;I@
MD!HR@SMLOAUCJDB^<ZE$'*QMW=T5:FOGH6UK*S=$I%\L"L=E8:Q#L&S<*4T[
ML;9(+*<1(.4K%FG2*EH7RT-$WYF'QYOT!__0CU!3MBW,FF*WN<FA&:"*'RTQ
MI/7G0V%<R][*[E;C$8V>Y5JDK7MST!H)7&?7[5].C"=5,QNPW\36>`6DX5<]
MA`_:[B:383B8$F8*TGK5YVOJ8GG8ZZ@2X,)H#Q]"2(0%^,R2^;@&%#ERZ7BH
M?NI]&X#3JYQ?ET%"AO7/`OBE:.SCM+YANAVT0X?\'[+G44Q/Z-=N_I!+)C7E
MYA>/<CJTS+LIXVDS?Z94A=BR$,K,U$6MEZ%X]O:$Y7Z]HI*`Q*H<>-P%-T\2
M9):(`Y#&"7OB`5&DIV<2%=D+[7P,GTU(D(H/?H")H[KTMG@J^*#R"AM&0G^D
M5WM5<)C56L5B0!3#(VBJLX\6I9A<G,13!*E`J16(+XI-XV%2.0"TTL?%-R`[
ML21"L8Y`J4.(%_K/OPLZ0_X@;2:IRX1@_9]^YWHHEHH6=V,3*2I&&1;.L9",
MJX?NID&S\_IOPC?%1G!/\\*-9-EX+40&5+@J<@3"^NA3BPY%__$*/VOA2$<G
MP9JCHF]C::I++W3\)4<*WER3XC,(K)@B4U7(,7`;1%2P.$?`N`V`Y_4\7PQ`
M!-N2^4"%;11O'JF@E)_YVDS4P9ZS>$XNU"L4@^!`.U<?L[[UBEI/+@8__ZLT
M25]YA`C9]O*4;84EZ@\ET.:9,2`SZ`E]!-CW8QT6L)NPFE?A<HT-JN/1RQ*8
M<H(9&XG';WPP,%6NW#O_09+NE1++<ED,0A;+]XI37(M`$B9R('-:>)7:;S6X
M.4C!$.FL&"#$15K$-YY_F/P>BD_!`L&>1;Y:HJB+;Y)8'%OX2^:W9WT,8M;[
M7ZG#!)I-Z291ISYJK>L4'X@&T(*ZFOPJ"0K6>B*KEC%>S#RGD[K%:`K+U=%%
MJ>BSN[>5^&&<<]R?DU8++(Y:/]TAO?0T"="7((>XW#%,-<`+[EQ[)P?V&U=9
MY-75-OB`TI8M']`F)9]^YVWGA<YKY\$\>LSJV9]EF-O+R`C^@S$SA/WC*%T7
MU6N8WDZ!MHN1E_.>@'Y#(N5)"$8$*VPB&%M5&^2!\>GZNA$K.N\)$(3E.<D1
M]QGB\^R&V-9>7E\GMNUJ-REH:]D`IN[]<`M)!M8&";9JP6H?'#J&Q`UI:W_`
M23L:`*5M(7T2V<;T%%!BF_X18`8D-(=R`2M$7,1W,3">^KR$[(PUP1J<1]DI
MGTH.^@W?C.V47!SA6&_BIT"IY)F]%/Z.J^H(/;@,&5^<4"&7;Y'R3D=B2?+/
M%L_<F47$@)`^IC0.\E=[""VZ8'_:Y*];L7D-F!ASKCLV;1.64ZDSU]1@K//(
M4O@L[%*N`7X@K'BL2Z]F7?9^?_+NLZ*TBAL^HK!M-YE5S$^6IO(1![:%,X)&
M3/)C$'>X+>&#4FY<37DBM"?8>+)2##7,.HKSE>5T(;;0_?PQK]-PLURB+"]*
M8N\G@:?^*V;Q:SFM)Z_+TC_V;#JE`N7MOLL?BJ.:83=:#_%&]DE4:1#__EOZ
M]N1318Y><)>"<W6?BIY'&)E#IA5O%&-#V;QXD&&$7++#<K^=IGWV'^]X$#58
M44=5HCS4#2#B+6,#MFNX)UY1JE;;[#X-RD)`1T!!%\/OOD-?BQO3H'D51LV*
M,;U+H$C1R.ET.R%G=$RKU4>65(60[JY94LL88=BQO<`-P42XO@X=W6QSL;^3
M2]SH?6A==%81^5N2JQ:9,XUT76I-WN%5>+Y@+FAYEVK(PL!==E'%=)]N\U1D
M2+6LP$0`91JK^>V7$^\20\N"`T/H*=>8KO/Y`/SYO$>'E+$XCM7VL<"FD)\.
M+3T0,I3N-6QF+V"_6C+!#7D*_ST\%"Z.57]F?,(_[/D;ZB8?J0<2<(=E*%J.
M5@W(#%`$>NTKEU'KCSXEJ>+[@">8/H<JK$G)&L2O<X5%90[JND@.?^EH^#ZZ
MN!F+U,`^B/@(>/;B^R1$B6:I$H=JC2O=F:K5=12`L<[)K2HTNC0B/UP;PIX=
M$M%!WYZ0-B^XZ+PMAJ<-MQ6/M?,MM#$L0.174=VPDNI7N+.6K"EZ,_.IP,@:
M?N4-P9/0>E$A+8(RT&>;FB.,W:B.X*1V$3O7+ZF:_]KY(:L"3'R#\_`!A.)D
M4.88H*3@A=+0GL&>-IRR4@-6.>&L9O2%#=/,=IWKDY:`Y#*E0@@V:-4;$OP^
M,[Q(GJ@D/&'_L!)3UM<<DX11&"B"O^85L58=*PB"P)3;21=,<IN[\D<BP58?
MU,_Y#F%R"96_.,>K)L+E?>":/L3#JTFJSFS5G&"V6<_0N(Y2R.$CI_3,ZC9C
M5HQ[`8P3#1F:ST/O0Z'+B2-"7CFE&=91?2'7UYSEJWO.M\#?7G^2*YX$2#J9
MVOT?;P(1]1M?B"Y\B+X`6!RG8A)-GHED:B<;K.RQ`13CW;0G"T8X.MF:B`70
MB*XT\U*42>V;HPA'&R6QU79=<AI";V&4%2JQ0.$&AG02F;IT6F%.H#05X)E]
M;U,\CX0`$G=<'S0-NESX]C)K;H58&\3E;#KN^,%-:-=ZI\SW(>7M';[>JVM1
MX/-TH]+T$IR,`@IS,H0P3I@$O5D</PK:#*XU,FF=:`<S8%GQ0"-@1:\Z`LL!
M]GKK95)SL(3'N;H@__&)OQV0P9&"(LKFB@7<1LOSA%+Q/LEM*9(@&B7P'/`D
MT/MZI`ZAA1\,F5/<T*OIT4_W+`>>^!OL\N_(]+O:3WG%@CDA&6S)9@4^8`UM
MVNWJ=_!7>)(9":UX^./6"I#*[Z2MPZ*G@.^!QA&;07AV3QV&0@@FHY84GNL(
M#$EPR:WWG!=+M#BI6^-%J2R711#C;:]2-D#K,GY#QO6NS@,_437LC"OEF7A6
MZHC#0#)"0C<<>>W9S-`L-;+>G8QO4E,5K2,KDJG8,D/-(2B6K1E9LQ<>6OC-
M;>X,&TOYM90'B2V#=_%YRZ!&1%_&YUN7EH&[K\(Y%@AN"K2MV<,=,90&P_;H
MOB,=\#I-PR10O2UZ876KLL3ZK$M/)$NXG1ZC<@O>_WF&W5SEVA"7.;:>Z1=C
MME$.+8_RO+%,Y&9G"Z%U@5Z'IG4":Q7)_/V-RM<;^@Y:XFX"&\_I(!B78GIJ
M'!N_A[\>@B=T.%$I$DXUJ*PC+:HC<!H-0SF^KY2$U3&X'!'@L`"/9?VAWF9+
M,)7'<M=N!V?^'L/>(&B>54K=Z:;9P`*7>1=NZH;UK>NL/L1YSU=4C6M%/JNH
MX#,R!BV%#]2U72R?S<Q?5ZUV)8BE?I8L7=%RW024[!HU)2-O!&'MCC!KTJN[
M-\`B=:,MC&D\(KA_(XI9Z;WN%$4H+!#P2S\PQ\X@#BYEQ(B`7,46/I(N[R6;
MRB>[&@_"ID3*3^-QX.)+<I!E41KK0FC<2G'TKW736HI_[4E?)%$R[02Y+C=.
M\[2YQBK0*"C#OWOM=#^IS2):BXX!YIT@R.._.OG;R`-2@)P8F@+[0E@8J392
MGMFLO1,`'UJ"]#KG"NAJ]2+F[@,3.<GF8O^&Y4O7&<U;M7ZM=%]7EZ(^A7>#
MDIBKBYW00$CFX2:PD1RA[\A`0+M5[L.FJ\ZCA(446VGNJZW0-+EUN1<;U6A-
M1S2F6]<$#*8YS<P/[+('NQ3"4'(,1LD+,8=:$#XLW,2JZZGB&F]%!C18337)
M:XDV;IG*E,-5?0SG?\%:1GF5O9N6MG%5O'+$V(KU*0+0)QDB6T$-+C(0]XM$
M)[C6ERN&]NR"O\\0J.82HRQ8Z/ONK&T/%+Y;<JS2&!Q^5E=*AVRP/6IHH9RT
M]Q(?@9:2./AXL!QW_7[:.QQPCX'=S7>FB16R_YRI:?#T?C_-C(#/$;R7-0)3
M:Z`<B%%X/9A>[=%']E`'GT]&ZWF7O5',R@X*C@KQ6E?NM1T#,&I^/=<F#]2Y
M`L((R]8"N<;Y-A"IZ?K!"H!K5N@?3MK_5-R(^'GHGAX1J,I@P$M*6_/7ABB7
M#Z?$ZR<&+[ASBT^C1EH[^GC"`M*9]4]I(>3?FP"U(%!(^E=>>TY8%^>BYW.$
M*G+"YR1-FJC!RKY4X%=F;K=\[)[>R@1I*58D93[\44%$6BI4(!1:W1&+9.K\
MF:@L!&P#S@!5-I7WYH-_+C-73@">>AG\R!(:)#8B&+/)^H]5C^.EXT9D4\G8
MW$@?5@TL")<5!?4#UJ/:,%9VZGM^63^1*8^VN,52D2K:"+6'!*.Y\H6%CSMZ
MMC,0Y!(.V!CJ[H?;\[1T6F:A;?[[CEJ-2TB,_V<]C:9%1MF+4KK+*A]B--[(
MQM*IES'9>@H$/!$+.6#.W'D?XKII6G3=1"TW5ZI77`O9A7@V9-^M!WK!7&6U
M9=^+.#ZI:;5_U\Y:.<9D1A/>7?K+5PHE7<RL@ANBG;NHOM":N*&(38YR/SRC
MN+0F1LN77PJ^+\P<<O!7L"^<MSAF&'9M,48T?IZT+P=L7K)-#JG!/B(G!0WN
MIG7UNH@*](BML/V&E1HGID9JM,"Z3+C6#+LI8&:'31;95;25[9Z307WWUJ>9
M''`E0SE.Z]#'P'!L=ZFZ7J<*8/84_X5A%=MHEFF-FG+'`6MRH=ZB8:<<]_$1
M/.K)]WU+B9<5B.!C7A+S"8.'Z<#$$*'E1_-`[]]&;"R0A<72J5=`$.)O[<`*
MD=E(B^/2-Y#X@_&;RS*8/ZD4==]K:=Q:IUO/\_M:\_>+O>&I4A;-11@7^F.N
M87(G<S*N6S)[GQ0L;S#(Q7_07W/_$Z7KK3C[\AI^]["J"\6O'@4#1(BG%"><
MM<[&_ZG?.BQV&WTC=-<K\SE44OKG42`PQ15W#)[1UI&[A;&RXM*+0#;Q&[&;
ML`H311AVH#X>$DV>X[.NT\=T$]S+)C6TI']7!`=1):]]3E5Z"(MLE65ID[&;
M>!=G304)SL^_CW4[A5!7=^^W[TF!KOPU?ZWRR<:C<X*E:E-75''5,O7(IO[\
M^PDGEUHTFQX[6"F#0),#9K[W'6S=XZGW+"#M(_Q;%3ADAY7//-W<&;\K*I;<
M5-4).`<J.'OGT?6\&).IO:K6KL<JZ>5)]04=*GD!ROG[8]NV:<:DK&Z2*.Y&
MOYDTA9LLSCS,6P3-,;**1F(0N9(ELO6]AD:J]JP1EM)_GVDSP&D9H<$,`#.Z
MIQ]]?G>)+P'V"W<Y):"26(LGO>(3IOY\<?AO'X`1?<WI_);#1B1%,HX7/5=%
MY?9A,',UB=0OT2'&J)!D!:77_7>A(.-)[XX'>S`31KZ[FJ+'H%=VY:&5K?G_
MT"#GA6PJ>T\2P[RWI-8:@IES&62^>L3X$CB?1AANFV.>8J6%G6L7@F=:0?8%
M(,\N5Q'`)&VSWCV5N7\6-:PWY'\,@[>GGF&,='V+YPB\6(##5E-1'>M#Q33G
MRK=G<]]04H3A5M:`YK^-MQM^#@Y'HTVVA;^@>S1%OK?&OZFOM,(!@2JY$,3:
MI4`OJY"]ZIXV.#EJF)F5_W:5?LRH9Y>#B40#2[S_1G;#R1J(*N'GEI^R*_,B
M:_JS%]J(1:I\>Z:G?%?OJK.ZG?DTAZ/W$YCH)",39^E\X&P,CJX6'/JV,FSV
MR`;$!*6]3F'NF+`0``4CH;?3`KT$5CU6<M"!+B!_#,-%(0"T:KN:/-@D^5P?
MQGJ?>!6-DE2"Q!+%\:=!J'HG8%Y9RBI_HK13%UE/!<$L6U-*T!0-3@D0''VD
MQR(2-=ISKSR)Q$'[1(64%$#[KW>;Z,E6%I8!VC>%N;(2AV=#ZFB=)'IDS;&&
MT"P'F'>R0%3`[_:,::O5BU,CSDK[`P-T0;-MC#-.HW).`WB\KK6QJJ-M::58
MV!ZE6%U^`)O.(/6SHVT.O(NGB*IW9>;:8<X,4Z`@MRCUI#(Z4D"(WPQ-ZJ(1
M9$'":G.5'7"7:(M?62F@*#]X+&B81-PARP=0U4CILS"#ZXPCOUC%G"NXP-B%
M<OPUEBR]1Z4$[^[WR1J\OPW<'?H$P$#1)[YK>A^?6C(!W5@89H&@_%QUB)WE
MBYD:.OZ#;F<KC(=BLD`,2(;M)<&K?*EA,CF8EQ$Z*Y.:]QGN&$`!O-0>5DH,
M.&]96JBT>-'#PX_"*T1T32**1HUUDXR?)A%A!2JL.=W^9YPR4>]6#=F>8U!:
M9M5:X.Q,JBE@:7@QSI^3"?IZL2N#50S@TTKAHRPX:`TJ2^Q<[/G/T)?4OOMP
MBNI*BM7U/>\A1F]-I5@4C7:3H@HT+W3Y0*7!"P$$&]EA9O8\/W!H<"!E8VAO
M)SP_)SL_/L2AT)ED=CHZUKOBB<)J<XQ#7Z;-E'64]\+2=OM$%G/O-BB>!2U;
MPIU65QMOSQOM/[A;TUCEWV#9]Z<?[\+%TUMZKW]&';SO43_SXR%V21RE%`JN
M>/9ON+:'"@NZ,8("M51ND8D/+[F25'P-X`P?.[)G&I]UJ"CJCM5EZ-`@%](W
M'A@<U:?.FJ'.O<,N'E=QV38XFDIR<L5#KRBSWQ@[$E]=P+>R(_ASG@IVM6Q'
MOY3>UU[-8[N+'_=#RYL"Z!:>1F$)DP;!EBY<`[H&3B7)90+9W5%RG?7C(%P.
M;A<W='A5HCI^[C%[;0>S!F01.$DQK`$;7)#:1#%0(U]5W>+E]$C12;KBMDMO
MFU$V^WT^Y;M,(?8B[&'/\8"L5QFZD6$0G3<4^+_5$,GD2YH=4']V0&T;?X\A
M=9>ZUC-F1OU:KIM/G>0#(`5S<`4;-F"T>]>>B\DZJ2`)/.(Y]M7HG%_XZJQ^
MR3_7W";5\R[)VFLS=7RR'1Q"3>J9@OQT(7Q/3^#?=*QV[V`&LDUZ3HCTXA$U
M'0M0&ZFUM`OU!<WWA43Z:*LG@FEG]R"5!.[8:PVF(I''HH<"09VDJT0@1_)9
M!C?@7"J0ZY/2ZH4<C(MV[\%QW;EII^R]S>--7B:-_.1$33_S2*\]BTB7&KM/
M0>O3[G8S`L*%Z[N#H*JB1;4H!:=_718@?C+/P0&BUO6?HT19A7<W1H/X['K+
ML4@R*4Q0?I08?4&""X+"/ZG2G3=2:@]>!F)=YX<?MHQYRK*&&X,C@OM&E!\6
MO@^SZ''4'=V27NB\8A;]C!?[K%ED:W\<68RF%Z#(]APFYL.+/8O:C<YY2[EN
MB<=G$Y(@J3T\[2%C-6O/!;'/#]0YH54SJAGDB5P)(`0LKY9L5/ZX9<_]/&@2
M6H>6&LN+K!-)#E8N+@2E>]]:.7)1DC<EN34:U<',F'=36*;G+.)R\8//YY72
M^*FO?^]?1AK<8A6OHM8ICHI+_GOV[(<SH@I7"RJ0^#KO^WLQB#@\>AQ*VQW9
MO$6]YUE-"N^EK/V(9,YMF!LYMT")RR3IT^>UTWT%$UP!Q)&MI+HIQ6]GB\-4
M3UC!ZTL$KP4/T!VH/-Z^0_T1$,;T6*9\L!L&H=*ENLJ)ZOLC"^3H78BN<TLT
M$IQLJ"`83+?XNF5HH7^P"+_2I2KG6%L(#RES57@/_N>*!/VV=HV/`_][T/@=
M`)#Z`L62))J&'60E.8-YM6U9^?A-K$A\9];,#VO<F$&^`AW;T<UL\ST6F7XY
MD@D0/XC8E`;T#`NV/(`-Y(8)(H5M`"D6$"*^@":U!7&\$OG]8DYY_MZM<ZE?
M^?AN$G=?.*OO,LD8CR!6XOGY-\=!SWU<\\#!PF$YI2>^H\BHP0I)XGXT0+(P
M7?6NNQ)/DV7FOX!Z/BD`T8T_CP"AQ_T4-LABZ?;PL+T]!E_R762H/S59C-<.
M_8#O,=Y#A->X;UDSWNQD^>\"FJ+ORGLS@TLU=0.&2@\O.:BKH=&H^/.'^*/^
MX<,UBK$."8GL\_VO$]2E%G5C,X#X8E0?[+I62@N8=FW<RAZ_.`'S+2<.Y6&6
MCM>!]!CD=7N/.EZ%`"6&G5F[>S7AR23/%[$XC!D89/HG0`(]4([1#V'#CA(W
MT7%"?W-JF@BQJ:66\`E-HNA&'XD][HO4!+(/&W^\JB$!%AYXV#6]S$:-*`D4
M.:,4#FS9W(!4B7/S?9=*-YK4KB^YV_'_3PR`=8]+R^.=+^96#4!?Z,/Q:DM;
MD/Y#<..(3+8S&S2P:(LZH\(#66?RH`]OMA)&BKRFKY?48.!=08O8=T9-.AJ!
MY3UNKH44/2G&M;?K77BFP!,U:BS'\(:]V]>7M<$*4LE1@K+$E?G>270:-X0'
M%&`F3)JK(2+53#D7IB2;$MJ(FF@]B3A7Y6X6/T6PL(QMEI44N77LY;0`?9UF
M&JQ=2BF]1X#\PIU=5XE(V0'D$1)O1(E0=&2N$6Y:G66C8TM&^)K/)G$TL]7T
MOTE:R."<C]D:.C0,`KX"BL8VFZG%5[X^(X>U":17S%M\KQO$'8>V/RV4I`?X
M8,3:X=W2H43RF"PFM@$9%8^+#A^N.\OM_I=[QZR__ZI@"H;A/3S9L(`691&,
M(':(LZO2:7+]>%NFE%(YF>WDTQ,65SF*BQQA.\K[-A$7O[[P2MGKW)MS=:2;
M8J2&M45BP'^J!2*;J&1,O"K?AV$%^X.\5[7=I]O.RWA+/9C?BM)U%/_8Y:R/
M)'MA0`2?0CE)&G$"KD.H29`5TD._-X6?KC/\S6BP?84*U\X665]^NC]NBO>T
M$=?("^EI.-Q0U/"2!!2FCNKI?7*XC="KCR\1J)F9'<(_\N#V.7DMG&.S'!KI
MM6H)X:1F$XS)7L8+9L="D3I-JVZF"&>7(,&UI'V`X=WDY"C[BW9[TMC$DJJ\
MX?7#PZY0B/I0SV&=00,=A-:R1:^9MA](XUO3S*,>?4HPI$R<(D[8F/'APZ]\
M7KCF&E57#$0,8;MQ&@$9H+JRT9[)/*@^#&J#3N,B;72L+`M/A.J^'JAYG&X$
M1W%`I-81,J#BP:$R/D3X+^@H+R$<,O?5%C236I3;;*=9!?0SG[<QK:`06$;#
M<NL,,:[#R6%EL]\M%HVABV_C,;A<A5#C2N\K:0FV@-+XY`174%78IUS71$NA
MV3?NU%-&X+$=+1!]C[PL\T(DD,&$@N2^UX4`_,7"0JH53\8ORQ,>`L53`VHA
M\']<'19?CM<?W&2<#%=F1KI-<5!=\K!C[P^BQ5,2D?<LI96G1`BD2DB3*HNW
M)/>5@"3JFH:,-,5Y=VNJ$V$DNSJ?RPGD3AI,)8S,1@711[N26<*YR_K6Z,4Q
M"F0DHP!V^F4J`M`<D9C98-*^?U,VL1\ZILHQR#?I])K*65V%I*G0]>I@0H5&
MUXPT;M2?\F/;Q9!KJG[.X[VG10L=FI=@K_CRY1!`F/F795?1'*1,*B5^[&7;
M0,J:Y&.5VX[A$LDT]_@0:[9_,"!7&WWT^AO).(;-A,1&%%_+Q&DWA>37?@!N
M2B-GN%;,@Y56_L['?;+8Z!==!:)5+1]]<37/`:BUG`?IB&_QV[0Z"'^<L`X[
M)#8QM]CNHL_M]Z)^@>56:\,WOCX4/&HKL"*8-Q]MD)&P5D%8*?,D8ACY_[((
M14_83A8RP2KZ\F9M.9KLN=R^*D=,9QC1E8LZ#]*R@BF%2?Z%^I8GUU4G==A*
M6H3<C-LG9NWVBV]JWL(!E-#5YR&_9@-$+Q_P95HHOW@0?>$!Q'8E\F0Q_B'@
M6%K&RB%?:O9(X9,+<QQ'2%`(-<N4Q4U/&_R2H(S>32%D!T14?A.;2W?G)]-0
M)??D8@KY2ON7@L"[Q+#_K%+"'75946K%Z0N%?DH`;5U*R<+S)DID>Y'FYUJD
M'*U!>#:P42`);ZD!43)2Z\2JMVD^;[="`*B5]UI=KULH<T[!I#O;I!?B"!\R
M*(6;YTIA:X]3(1+6[DT'AO[?>^!O36W>,YF/^$.^PG75SV%R",)/\SN@SL.K
MHH%"Y38`L^<%`8%D&.#$3F:AIU;]6GW@44\?QI[_7<<+94_@E$UR>,".<WD0
M[1UIKZQK=B.09UKQX^M?,[TR$],@E^W:LU?1X)L40E2=^_@B&Q\Q;]Z!(`3+
MG["LS[=V\7;/5$Y5,*/$G/"(#W+I.8">P5IRF[VWJ0_KD0!`.>2I,TMWC#R$
M61(^,$<I4NX.8_:7B3CO8AJA\_YR@'M^H4[7_L017#@S%"E`+.?[,UL2(8%F
M5=<,L#ZW+?5-MF"G])P5T<RWF,^LX]*/P<E5#%CF7KP@A9</?01#^&).>5++
M'F/HI6(#;?FB7%5*4RLLW$+Q3UI,?GV!<I3@V?H$3U0&$W1863I0R8<M?-[+
M7%=\))NS,I]C0)`14-<K<X[XZ-4N#()G6;(P4])_C(E.9>JG_?+VM4'9>!T]
M%YTE!//<TF]?.*NGG;S5<A,P\7H]2D]A^>VBM06S7=)</9=3GP:MN>D&H#VT
M>?([10+C8_-H('-7Z#.0^\L&\5WF)@,%/)+"Y>A;NPH6S]N$O^ICD1MC=Z).
M#*K4;"LYS=^^<^%+JGT2J#<9@>@IU'Y\UP'P&,$ZWS?-A?+X&Y?ATVO@:'JY
M#]I]5SI?'.26V'%*?U5DU#1`]S4ACQ!1L]@JZ]^07Q2?*R`UDC%E:?M-WCCC
M/\0L!$%'>EU=@PQO-/JN=?TMD/.L?4F)N-=+P*Q89S"><[I.'-FCATW;N>$D
MQH7BMNJTE^!S"8>V&#?X`OQ3NO"8JNK&=?>\11FS4B7FKJQ>NG];4&G8\/ZJ
MUT2[780*F6@Y%Y>^O_O0HEPCJ_\479X0+SE<?6>I`U@M]\5GYV+WK/U,+9D:
MB$PI1[@EF!\,@+(0B9O<S\86=9^^WPAH?A*!=S[M!<5AZ>>>]G$)5H1R^>O)
M)LAZS:D6YAM&Y2^V[`;(5OG_RHJ+%>WW7Z-Y+P=5,/!'SLF9+BD)4%7;>H.4
M$O6M]0=1S4@O_442\C-=%BWQ4&/19X2=H!)-M*&92!J">Z2DL,/=I@S=4,O\
MC!\LM`AC1[W<`!%DXV2@/D6\/`6P'F.],B+S7HR$;3=T[/NF%N]]I>M[)$D7
M3QP2BU*UNE9:6:&=2UP@JT]MQ!]`XT'@\IP!$4#<QJT#I;R5CJ[)8;N[YM5"
MSL:$O\@6&71KO_5IIDS$]\^MI2P"8"C3H>"T&R*V"2Y2)0`\*BS_Z(P]$`YW
M.^:L#)\D&!"1`MT-J78&45>TM=Q/@3#8WI_S7#;+,QFP<$!>2RM857'CU23?
MDI,*;Z4],G4`UM9EA8\,HYS;*]^0LYU?%CWME6<0LS?*<ZS1\J[L.RGKRHQ`
M\HWF!;+.\<^JI&25D<DA[77W27DG[3^>H;A#F<.B+(N\4X=,FF=C(W'468SL
MJ(I_#4MN-/'&:^T_]L=(@@D#D_59)"(S"^M"FR2LU\<FZ>M_4/LD"&:YBU?I
M@)5D+`.!YC&@6'G.!K"-*K+`H7<I=O<L>RP<L+GT:G'180.7>;@G3S<.YR."
MUZE'%42DAQPA;VVRL-?,/X*Q*/1F<%K^K*Z+V[U)%K%"1PC).KS"J)?&V3D=
M@^ID;%AJY1[1H64I@/1B+<#)V<D\L%,^;@0VS;+OF8UM@WT/@Y4.*JVM:,'#
M8`80H))>+:6@?<BA@-K81+J.E'0E]$S31Y6Z[V!B2B9KK75D]M.JJ,MM@,DR
M1>/UDI;0`I&QQ.-ZHA0V2BV9X6G%OP:SQI##?C7+,(Z+IP.8I+.#3(M#4P-V
MB@EGGYVE5(2_EH<]M3C&FFY)]#BI%^?+6"3<E-%3,/6.E0CZ97JH?A)[^N&M
M!;"A]@IMD&S<"T4%QH/IJ['+&#9PJ$6*(4]R**A$(^%5V#T?E!TK5H$'7&3B
M%M_\&'"YHK#A@9UY#@I"2!F1VI#J\*G^]6VH`^VJDON8Q[:Q>EZ/*(8N8I*R
M"6-("UL?MU1/F,SB.C+6'7]:W-G])`M_7;Y>7NQ\8,JPT,Q>.ECT>50<!>XT
M''\9=Y;^01DL>RIF;+J02X(02K(I2,NVK.?E^>8.P0#V>6Q]1:U4]\$$<F:+
MW,#=HP^&];YEU9K?%JFC/!.5WX-7C5IHH`_GUKT`C=Z-??'CUI9.[%D/AH)$
MSI5IOK;`V16TMJ8;6/V_L<4UZ39+]^UWI@]U]=KEIT0*TB-T!]_LU+*'T0`'
MM25'KL\U3.D@3['O6[E2ULYMOT.K#X(@).OH=(RF&E4I9LE2F32/="UH:+"`
MF.4&^W_[99>'5KLWPW)O)UPBUJ#_06C_=L2*U[3@-0:U*%+5[\S/NK;L[L@I
M.J+,8>0Y_^=(LN;<,,B+)]J2L:R+5$A1*?U`1RMOR,V`HFTC$2NJYT9M`+%D
M8O##W0"]Z^/-TP'$+='M6"2RF<!#L+SIE@Z7(3[+*;TM[8R@Z5A[-(7_;;Y2
M0E@@1BID)?>88_D^_@H1^1,>.HJ;>[1.5Q\R&TBZJF02LGPR_"5(-8!ZR&"?
MKLQ-.(C>M.3ISZL$S$8?&\LR*2\&7YC-^^5.I:%\QGY.0;U,M<O5EIY/21F%
ML]/6"HLI9J:H[!>F=33F"WIN+NI0/>X<;#X,NYC'J[!O*)^S,>]$C(WUV)Y#
M-3;X]RF0ER.P">XVZ^#YO<#G(4QVHB]1`F;#7FEK5MB*141TL6PJXG!X0.MT
MZ[V<B!WARV=M4L\\S'DG186I**,I!K+"&_(C#G]8/XA09M=BPJ9-+_?Q0QDF
M,),64K;5)?VY;K)TUTH'`B+:ZUXO3KXBK%+*2NM6:OPZ.T'(LDB+TOQGS0K_
MB0_'$5QH91?3AR1T6WI4/(27$[)INZ@2110WXFX<[\(_/1!ZK@I3.#'[[Z^+
M208&JP7SHEJ[.)O=D8XC(I1L9%3G21%K?6?-,.)?0]*_DFQHQ9(@G:G(HP-]
M09K@T&Z&+CQJ!]?,S;SLA?,A:H++G!7:^M(71FGL-4!2C%I<Q-A.GUED24E0
M@,L'?\W^*R3\53GAXL/2@9DLPO+,9X<(ZO-!0<QO#P)WHL>TDXTY,A[W3EMV
M.&#H8:R3'-TP,M[L12E-'(;]G"[<D$+QF?DE:.P4RGPGB';LIG(X,^/M#PRF
MI.@+S):7"EMPMQ[91F]&DPX5!!Q"&16\]8(90QEU6HVJBX#M9<6.K!N*,?%I
M>\!]$Q8MND!,OI(%\W3W2DM1%\.KT<C@@_;*9>5&X+S/YHLB.:E16C+G?^1?
M.,_(.6F0Z\T9!?15[U[,O:4K#(I.SG\8'3;0L?*!H7!?1`<"E*J=C&<W6*BC
ME,.*IDX2QA>,92G1#A_,Z!F[L,F#]/3(D%*2;.AFM0=@-KI([\':$&PQ&VJ=
MO&UZ_991R).,?EMWU^OGR/=`96!/53$&?@:5V@V!K8F(*[+95:MC<X'`MWI@
MF6+12FW)]2R&93:Z/-</40KT_>W8>QO95?1+>'?TQ+65C=7$*TH98X`6N`=7
M6E#.`'MD%/(`O&5A\.+9<YT>[4R!QY?/5PB/>69C^O>0M`7G*U;:"F'2,=!+
ME@0,O#RSQ:,'L6QJ8E/@[O?%Y-H4^%*QJ%]DA^")^59Q,+?$]BA.AWCGO-[]
M$RWU?U7?'8YWS!;IB']R<AR#<`,+Y"B]L%`;0\813K!5V\;_:!Y3,+D!.X!1
M@AF`LLGA3YR'9//]8K4G5R]OA`Y&=R!/O^R6;K'H]T0-%$E^,=*'VU<#E2.A
M+P\ZX)$:J;D&*&3!5O,J<2\\^J,#T;5\W'()TGOG7>6N#=M#/?H0]8O]H=:I
MQND9O`VN7`OE@+OVTT#[K.-;`Z"]M)&O\)U:F>L8$?F)QJ6Y#GT!&#K0L9B*
MO?.DW!F]-O@O3JWXS_9M=)$V4X0!2*W.&KS%;:U(5Y&T4**C0:Q88E%#^X8O
M^;3.1M01"S0NS<1(4_^(8TE^46[ZORDSGHLM;>;NTARL9^4[4D+84:*8<E,1
M5>`QT>NS?%;%4V;WFVMPX#"GEH^_%%0"/F@5Y)&Z6JK[ZB<(J!H%D46BUGS.
M@^*X\<@+,&C#1/D,D*6^:8:I0/W88.)5$Z*2__/UD23_V<KF%C4M@,)F56#8
M`^NO]_2<+@0,0LP+UVI,P0;IF<Y5WZ`X:H3]EA''$:/'_W_#K*10X"]-TNKT
M25@9H6\3"C:Y$=$1EW=9VNEX<<Y04J?3I4WG5L\%,A>+3(NCDF4?4]]=8U-6
M[V@1U]/L9F:'G$57)*!6WNZ^$N#H[;+;IL8^NRS"?PZK..%U_2!I'FFUL/"N
MHP\5HWIQ>WJ%E\$X>YGX_,J9C^SI9./IG$H`1%-60,Y!R"&6(PUY-+XAU[]K
MF]FA:#SLB*C.;.1,$/'J3:]MG?V[U5Z!Q+J<^;`["R\?"[+QQ%::H#[6R>\*
MAY'N(9\^NAVNE#I*'1D\'0327XJ/>&V-N>%.E.O!+H]1%YM(K:VY1J7J,J2C
M84H'KXY?\#"O_=@X/T1FAL0U<KW25M`&9KL-#B1S'II_C3YQ:>BS9_A`MS/`
MAO/3X4JCYCI%9DLS=PBM\K9%IJY`ES%,(4C.:G<O(AYXNM14TL5:T8XH$Z&/
M!F&G3(IKJ9HU?C90^KFB?VB-:U[NJ*26G\.CB)V2X'+#<O0P6R<UIJ03.>LI
M<\*YRX<Z.?J%4+7;B5,'<A_L,:8#NFCXDZ2?37>E+,OUSP8+8G2'[RV`=Q;G
M-+[RN$XB(!Y1-=Q<U![7ANBKYY[>UM8!_Z>O=N#A>2RQ#R4J_,$F>Q)IJ@>*
M$NQ[WY`L5T(CJ7HBE9G-DEJY#6&](^`Y4S+RZ:FX<\8`UX8J/Z5<).&LF=VV
MHP-+(9MP"P7`>+.3%\*'">I1=#*W8`H0KR@LP(Y.2FF4GO(`_L]U*4?]C1NN
M=RB\:GYY`U%<WLXA)2HI[K`;:%+7J`2A2Y,\6B5FGO<NCS-8-9"N%!G5RL@.
M8614Q\BFA=2)VBHJ;?AAEN+!J6?`OX("9F^-#74'W0@.",/=+_HM4XW(:7ML
M'(@R=-?RJLUY;SPI"'M_,$EZBP_7DGBE1T>_*:QO$/+.V06G<">0\)I5?@GZ
MI%7H(8\#9`*A-\>E'6U0<G4[[@VB^$5<P\31<RHUZZ7BZRA^8[`EH>K(S6UW
MTC0R_(OS_;`,<:K]]80'!K>N>(*N/1W2M\;[$TT3_V8#WTT5?)JGY[Z)@TST
MO#'1JI.6D7<N[!@8;F$:Q`;1YR;MQ="=4*HM`#MT493R2!_O3X42<%S:_*[G
M(.YN+P@8KF0'^BA[C?@&<]"B,"$@EC4!#*YK9"TYQY84JACA@V+C!>CM>R=F
M_>'Z6%$5AH:9?NI\#LO-,)SUSH3QJ\?G2>3J.-G+6[]]1O<R+E05+=SNM?#G
M!@9VEY@=3%(,OE_20J0#87W&1=+SG__MP4IP57R=]TJ*`.&:;HD-`U(\P(Z?
MQS?^/<@B1*E.R\4(>L\7!9Y=A)P&?!CX+`-VT;RS3.1:#R<\7I9:&J7(10$H
MUJFJ[+'6FV6:Z(G0JBO0J0_S:"7;>X@D"O";6.OVOFYJEIP:CCX\<_1AY[7&
MT?ITXV'1A:J!<V1;KW@B?DH+L]4:Z2PRT#O:MI,,)6EMU%/)G&SR\8Z&\?D2
M+)44/LR10C@GL>6#I;VB0N!9=3P4ASJHC\(1NT89!"HT)&ZA'K/*L'DALEZ#
M*>1I3_6CKA3+:UTPRR7+*\!2:KT0IF#F;;^)8H/T0Y69XY#"9R(^%V=@>ZPC
M_"H(8CD8-^*7%KWW6E%@E?4[!:J@:+YVLQQ#/"X]][Z2DX^^J3^YQ,:,\EKM
M`AL.:2`)1!V.=NN4V&68YS"V;/*&03J(=A6GPK[?>;PO`#\(N*GJ$O.#$W*]
M%_N_@EY590<`N@K5/VLO_K(0:F;)K?0!PE#7YH6-<=OI9^[UBRA*:[1ADM-V
M3U<.YP3^C.<&X>Q0O/19RMVC-=_MI\E2]C`TJ,_'<6RE$Q-1YP>Y:8$\T2A#
MM/".MQ90&NEC2ZRH+-4DFRL-;.%UG;Z^JE;J&8'IZ4K_7%Z:VJ>0HCD'TL/&
MM'@55_;Y2.Z<CQA3XH%#!(#N-`DTQD\ZA^$2$9ZH@Q/.WRDH90SGL0(D0F@3
M5,N)CCGU!D;&^@M]=RN4-7F0-_N<BPH95]RWC.9VAM]3AV@Y-P7B[+,-#]BZ
M&;K&F)K"J'QJ10V&IE*)(@T;A4V)"X`D<BB][H8PH$#L=TI8KS%T_!23/;KU
MQL?;IU$$']L``>:+=NBUA6QPI'F&M^4@9:.Y#0K!S(RJ;YOR.)L&X>?S(%RP
M!F6J]AWDIX`XW<>T?>S:B<01-W9)@FO0(,VN!3K2KM\*QA>?@KQ3\FS@M,X3
M@8O?ZE[Q$LP9&MU9'K!-KUZ7I%DI$A-N\K`N$@I=`O01-)[F[=RQ+6O=.IEZ
M.W9FPCS.FZMV2Y*E.TMM7MVS.FA^DT_@??4T_E308R$\V3^#PFB,C1S'IP_*
M&)6:Z`[XG3Z=]%/==V4@9AJTLNA*YZ&3+_(3.5OE/YBQ,X@V:,,-]+XBKTK0
MU@S]>EGZ7,_I^>H!%OX"J6Q[Z*)W9CTBG;W>ZNH`"*ORA+JR566ZG.^FI_A.
M<)%TLY_7WG(.^<D=C(6@(*+W2]=:"%[UJ0DT<XY4YSTN"0`)7GRFG`F/_,W'
MY@=1.9S![:LN>>!!+&)=[Y.NT(MK%ZUMVO0+=>(Z$]H1*ZT-"27MHHU4Z54X
MGKEJUPFENU>NBH".)C5+[U!HU7X8'_PW5Q]Z2;#?4,!-=/?YX4V\-4'\)OZ^
MFH(G5WN_MQB;EL2(1[Z3C[]DO-,A,\L(_D-(N^GLR)?(!()L*>00J>V:HA4,
M0SBV8H@:5':BEVI,?NK_J5$-\>.N]5'!??TMSAB\Y!BI9KX5)[GP')0$H'TR
M#/$FXO6<@-7'>^5')B'O8$_AW_"EUF:?T8!`86@=:./+,Q+>YG;S6O)!2N-2
M**=C1I''WY0ITE13%>UJ4'LC62NH&8<K]"TJ:M9`&"W_+2<=<=)1O\%L7)B9
M8H,)5N1)'SNZWM>Q'57$S^0A&E8T&19I>8U]"V(8RRC]]\01U%WZ+E02PZV]
M)<7.^WES,/FG?Z$`4,"N:JGW*(+@A=D,+"/_S<Y?A>W;_=!3TW>)^N4]F=9B
M_O2N0]FTYJ46&CHXVRRQ_11+NZCFPZB,)&V+>>MKR)#/`5)L1P\WJ:#KEG)-
M*EE*"#$SK61"SA9NF7PV&<^9C_WG!N;CY/X6"T];AT7,]-W+`$H9UL:JV=9`
MO)F!AU3$I>A?Y/!B*L*,)\RB*^5L!XB]S'F1(^7WH16U"'R4B(+`;T17B6.7
M)=A:RB^9%7]IY>C&:&NI%Y.J+AQ%X5FLS=-.FJ4<SE*)(NX"4?6F_`5"9TNJ
MPD8VE$Q<.PL88?L:G>K)0[JS5+%%FX'ZWQ-QT+/->J'X9LK@(48IOEV)`0BY
M(/YTN04BYYL3)*%-S?"1?QI"81V1_`B<-)6%=L2J&0L83D8W.N>NT^N%7PO^
MKCVY=T%H^?9K#6]OQBU1;G<JCHE`6KMM_1PXYJ[:S-4DL#,,L-';E,O_L':C
MJFZ+AX770"UR?VS)_'MW#YK+9&$W6R=TVW6+A^1\%X266L!<-L1"F)PGS]@:
M(JDNNE19M>-.;(%T"0O#-LP4D^0N7H=&N22BNP`2Q:9KC]9XXHF;<=%Z?M;-
MIXC/B'>3G`$F=`B/^+O!>^.+K12`V)`Y/'6T>[#-S<;0]A#JTA0Y)"Y)1IWC
MN5(M*]=0(A#>M[Q$A"/P#T;IN'1B:B5/3':-Q&WO%[1+,G?@T2XHCQ`@0#9<
M!XKO^\Q-+*>07?15Z4.V\\UY7*&`;CZ#!7<4FH'UL5VI36WZ:XK=MC&'*6^)
M50<M=HD*O8_%OO$U3Y]1X:@S/Q-7"7><*9Q+<H=F('6C=P%9V900=>,%?6_R
MB-Z%SE4U!A-&LA:R+VI\8'@HQH&&"ZF]#J/4U0&BC'I'TPMRD?&U$DUC,G(\
MY'[G<%LQJIJ4<N56>WJL"&!ERJ,I3HO(,;%_JUJ1#%!8ZW9];\Y703#-&T%(
M=;WY6Q\EZ:+*97W(C,K\7^=>_,!=Y=%=:YU;7^,/"$IF\7_J&KBK,IY9+D3Q
M`6/;90N;<+]O9=$!C5(3.UDU_3QFEWOOAM]Q,4^F.^>9LL*$XF<NS7Y=S]@/
MMX@-)K;$**$<(7Y)(ZN[`(CR.WD9F8(-9&?)4_4>`6OD)$>&@[_W'O3NERK>
M+T,/S6^B%.2[3.M%>Y)BXKHB:@36XS\KPG_ZU&N@7'5\"2T@'X@L&\3&2['_
MOCY&]-0_-.6%`*9C&&JU\4UOCR>$RYQ7B)`SP),U=2D]!39LB$>3G#>R:;N"
MC1`,(P&\WA9@`"]P3_0<]<X"'Y1GCMR3EBL>TYZ(K!J$\9O]_N4;J#)Q!>K,
M48!E&MP3KT=S@Q-:U2@Z7EAU.P";=3[@UFC#^U)CJ\PQ8'11TSHV<(TH'IS;
M0%\J-;"]TR[@Z-'TYC#*YIKQM@ZS/,?_-R7`,&'='DG#.9%PIB95Q166S,DE
M/A1+IT$%\W'Y/W<A,#TRO4BVG:./HFX,.,V($Y[UM@I@V$48ES61]?'-?BD'
M7)<6#H5$UUE;Y"3!U/\1B(J"J<TTM%+P`XR2"9-+)S&64TG!#'O+H51WQ05X
MJ##IV?T(6\,^\ML$<;3)+Q6QO.$^7Q\R9U6MW&U+E0.$MFFWYAN'<O"HV5M6
MCM-.*$9A0FYY*49VH>X@#E"A:47NK[SC9Z<&Q'8_$9+0`&_``Q>(RQV;&"5N
MQT.1+SRC/%#J?[CESBUR1"O&'E_:\2&;&_EXHN$&V.+FG5DY@^P>5LUR?C/*
M\BYPZSWPUKNE=I(]5(BA`)'P2?=(.MIVPQ("0B:W'64@!8?`?BG$(,#\(*O\
M\(+9CG:Q@Y1&/YO$9KJ,1.H5-%DXKE4X&5I?GM7EQ/(9B*:CPP^R#*1[4(K%
M>W0Y)8$1'P)Y$HTVTV7WB;N8R5(@\ZL:3QQVB<1#W5EUWKN0S5WD9O"^(_I_
MNU$,'@*9^+Z/7Z"+]G'=4!>\QSPQ*+4S@D^#!X5]5,,@9N'1XP4,SX.0QSWP
M>D);X=/4Z==(0.F+EBWU?03BG,E8J%[K+5*D1Z^!V<1],>CKA;PL$.D*X[,T
M*JBWK?1)6\!!Z(F54SA[.KOE)R<9345)V4!I1L>98^@5<S8#:@4^/#N2]W@H
M&UF5;T[J9@>]&5OTBH`7HX!I:<(&^$?_@((7"]_Q*.'$@4L.2:T4B-[KM>/N
MF6\0\==L]2"_IEO_@']W,"QI"I3\F&K`A^+MT'*HB$5]:?3!66BB)N!9PJ&^
M49R!IK'JQ,)D*54U?-;Z\XM#GDZIN,0NH<HZV[2"#,L;G5^"(,$*UKQ6XE9C
MADX7L`OO_AV;_3`_]*-1P>G<PEO,Y$GSDXX06T:5ZT>Y/$_-3IQ`Z4%BP310
M%IH%!1/\!(]K4L@0;(POOG%14O1:WG<@67#45M%/H-O50D34__$"BN@0HDG,
M^85:MDV\6YEK[-^\W@)(V;>I:7,]\XV[63P9L$N#33`_`5CO009V?.E^-[L2
M-+60B.H,H\1([8N54.#PHYF)M57F9IF]G<1)5J7<37H'.<%7:"GCX;0M%UJ>
MJ*-U$=;IP\"P(:EZT!ELI+J<HGR@MA.$X&M<*V^2Q2@)R^H1%JX;6)OZDSHS
M6)VF+9;3><H!V3+_EVE<"J]RVI^%<&_4GN3V.JZ+-<R06?*!VBAVC*VQ0E'V
MNW7`J.(946I,IQ67B^2!9,^A"B?J@M4A4GUH_Q83A59_0/OH9`EPKZJ4S\"=
MZ::E7DRC,5U[0LS:TQ_JH77^_*O<EIS`LCW,7<^](\B0;_M*-/$D*?C*?^R7
MC]CDLO/WHG@4#W[F3/A@J_.E'K-.H^N,C_/*71`VKVU'65OH^85C0>B%MC*0
MDMA(D$+$B(F/`4UP4?KB?8Z_%=@-"=[Q00`#-?\"A:3TP%[?`$=S?3?8.5B4
M&\.F'?:`)`+NP9`*DTF64Q+I)K+R9XP]S+^=+SN&Y!AON#W/G;_1_B9:V0;\
M#6,&[F`MCG_2-#]J-R\S*Q&=BH@6N1=S)J16@_;L?RN<6_Y"<Z4H<FC!>U\X
MH/K(P.4LU"T%1#AB?MWWYL1I'*%NA3.3`Y/SER">_:S(:)51`$]7\1@;B`!,
MGHM#[(GOF%H[7Z;*HB+5XF"$P>M!,/[/6(OH51)];)2D^#.7O;"1K554LT(A
M#BYWTX#ILYN7/L2$'9$(]"$N_4+W`OWZUDJ`*`$U#,BN\8,1.)8+-L.R(L]T
M@'`<C;^;S^%)C7_!0EMV@=_RHEZ?DU"9]5K"K?1+]E/:YQ3TL%X8.E,S25B;
MKH$UC1,J!FK=+@0HEI>T=)$'$DRP>=YR1C$Y48^/LO(SGUDVR634U?%Y]NA-
MRP<0SIB_$O9-_?^```?W)5"02Q1F3Q"&U\*BU*=W=$:-3J4BDD]K&]$,.(N)
MWKY;(\R_UP&Y.03KFQ!M%4>9GBF_W!=@^5F;JVG/%^Y7WZQ&[ZE=Y9'==)>3
M<FQ6Q2&(&O,>0PCZ&XZ3YZNFP$(\EG3&^_')""B?6L<0HS9R4O>"B/PLJ)0W
MP(IYO_&O&CN'^(MERN,"/B#:HM)2F-RV7`>RY:C.ZM/$$I!U4J7^;13KXZC=
M28P_[.R?K>+W=&*HA"B=._F3;<8=45L<MO12.$@JQ0YR)\,$TBL@V<V8/N0Q
M4-TZ<3P>\(=C%[*@]"(?)-,-DE![0O0-DE`\_4`F6<G0L!]E=]:$?7`P'5A?
ML)L$*AGD"JEU$!SZ\%%,GL.&+)H[[^#"=3LWU<`A^G20B%V*_`Z&M[57-K2`
MM#N]S:]3<I@N&31EX??5P)E]0$C+[GE$#`3\WF.AV<J(QX^&ZHCZ@)=>6"<&
MAUC1N^TQ/V(.*6RSU/]=C#*T!%'$*("QLBB:N);)AM="=X&,FWD\:`PG)!;W
MD%R0P9G[B1+X?>[W_V-#A:WBO)EEK@"QS9TWJ!!\B3$.I7"'%Q^/'.9N1--.
MPC3J9:,+3'O*HAH1E,,3`)'HJ8:42\S85Z3^ZR<9GR6R>>_.52$:XX_4_N[S
M$/\&U9D#!]"W=TL6/Y>:C#B3_$%H[IZNC$5.A]B_U^IABT?M8`C`B(.M2<TX
MT\*^TJBXQ%7@B=,%JIPT8J.Q&F5,(K]GS>"QQJKL;J:9Z@#^T.6R0;&^KG2>
M@T0.GX,/9E^1M2^@;4;C;V+DRD8PW'OO31DGHH&'ZJQQ92/;-TND=),J^EH1
M[*W5KV3/F9JH'5IB?S&4R5OH(@-D/N@6=8^Q"A[ESY$QBT#=Y=NL,F8BL<2/
M'9;(I`11##P^2.^5BBUSX!Q'_XNEF:\;_V0"_R[A$EJ@(B1SU:L`Y&4V"RON
M+I$UG[B%;\O'E'?G04=3I.#'[.?A5<!!1#`>9GLS4`?V3<HV&V]H,XP&FVZU
MJM(>!RD"@FIS+K4Q]M3%?HVL;#,D2Q!/K\*+`"!3%09C;@I.Q+PK@D?XZ'O_
M_?#W&8*/+6@(CH*D?PCGMSOR4KFD95!=2&,<$<J!9M?M6K=6$6`<9<$B;JNQ
M!+JE&"_!,7,?"-.K,5\.RM)`P%00*]MN2X0##K"A"?37.I\5$7T,TF?=:F(@
M#2O!JC!YQD*/:[D`]+XX'R/[-,`A04#4WT$!O#&&X?T:;1;HR6(^[;R"_:7H
M?>@:2ICN_>"D])$X6G@/&_UG36I7\;X'/M#CQ'&-EH<1VSPP+''5PJ_B:N`#
MHECNL$V)EYK4.5%E8*AW^QX\*GT((K4L"W,=.3#\,@-\$K_O-)MUH[P-6@L4
M7]%43@>@+RS5%]SUC4[5[1:P0#$_44K9M-74W?Y)->F"YV>`_/%^@X9OF%<!
MQ:PE.^J-WWCK32J>^!JB58!THAGT2Z?G?>M53/>J8!CDE#+7[-;Z=[()HO<]
M^GD%$[-QZ;/XHDGP<9Y:R*XH"[?E7+AEJAB.8:M7#LO,6]U"B]\RM1/+41/;
M_O%1RP5@8`#-3<!51186WV@:ARDW&:W(6^ZH<!@!AO5>8L_-*_WB7M>$J5[W
M,I!%82RJ4*!,*Z$/TN3[\<N]#)>*42!$WFRP^WW2^^V5@@]>HQXH3C<#&?X+
M5[0O34C?0<H6T2O"T\`$`%<38>:!ZQ,GWW,4(&%':RX-^^B1^-H1[7=:Q:J6
M[=P!I\`)OOZIWC,A]-&H1H:?H.X\0C(TT8GD*E@KW0-O16C;!?\'"?K54[I^
M@,OW829"=I:W78]*I+0=9478E&!<"CMTGJ**!TB#;=B`>#(7QH*D+IL90LR2
MB&`"$UA!,YCJ>=V5KVPKUPE<6NFE><B7)XF^^^(#ZNN_-U,C(D9GR%O"%10;
MOX8LZ\]V2*1546!PT[G[\H&<GPIWLG>&,=WF%VDA-82E/S&>2J-!KKWR!#9F
M,^+KK;(&@])EWX!`(=>?MF*Z71$I)=A2+Y3AC>=ZPLK;I>LUE:'[&NOCP3QB
MX4WWM26O2@DS)`!WK(]N0\==D.HEBX9KQ8__E;FA[RD\=*!`3RYK[@NG3;OC
M</0/64VNRMJ!).EW"#CGEGPT!V[R6;ERGN6?HH0/!3G(4BC617EQ25(:I7KH
M6<9Q2K?B?SF#AF:,AME"")T6<FW/'3=XA?;XORF%0S@L>5AB3/TX?Z1EW]&W
M+E>T2O`;+_Z<$7T$$\A%!,:FM_8$CAW+R\+;2+ZU&KN6;K2NC!D@.TKK(>'\
M+S!H2V*.-#BIM[/D$0SRR&EGXL;F";_5^C0PVT.X@%2VGPQ?M.D6#1JSJ;F5
MEB(V7_66V>12NU8@@\<DW!RR"K2#$PLB9:*[Q]+XI%V,VS2N@*Q1R5(?`0F;
M?2K'/GTG,VBYTZ>U+$0N40K*5M532P-;Y;^$*9&:OGT'OA%:5V1OHB`:9)**
M&BW>TS7%)MWX;!@+S#J6IXM*H1@+P!)I%^&FLINOUDYYXM9LV)&!8CFP?"PL
MDU6W)N2Q<CO2U#1:DHUOP-E\-D\?X@,*;9I*JD#P!"FV"8/^"PFD5WXK30RQ
M2!S.$Z#^23P>W.VA90HY7K+4G@^$J]K?MOH'`5\:-8QR/1\8-4&9_AYL$^][
M3U34P##1HY[V<^J!+*]'SI0]YM@RE03`C8G_-7N'>K6*=VVG5:MX9'FK-*%"
M4$3M]XK"(NV3#(^>&`(5G(/`N.P162I@@=PO<_V&LR>;>2<@V4>5?L&[61Q%
M&:$TV,T;AK8,ZQ3H^!J]==="5.0SA%IR3P][Y`77&)S=_";,^5Z=^)S0CA[2
M2.&Z]"-:EF8&&]7WY42VZ;.B,B0>4ERED.CUJ_&S*4U],0@!"<Z<4(=6Q5]6
MH&^#*039W"`XU>VH9QYFXZ3E@!K<!A/7S!:WWI^:I8;'(\*4"]PI5^:!0T=-
MW1]-'J@_ZE-*FY8#*S_;77?^-=+'OPDY(2N0*J)W(#OME=J-J*TU^4=$@6?L
MA?XXJ\QMK.GR>M3-C5#UK0B"%.9!`Z=CEX[%GG5EEE9TAU*(56T!78+CT]YB
M,6&/IXP&-)\\B%V>K]X-?"R9ZJ[#0PE4I*"4]).:4A9<(CBKVD:4PU=DSRWS
MT]%_HL$>0HHGL7J#O!Z&TE`N6X)XWH"(\AOOWBD^!;<?3J'T5B\./<Y<E5Q]
MDJ.U\U[20\OT[JJ:6!(3R;&7^@HAL&9R>6H$%C-]RR>.TUM.LXA0B$8Z,AQP
M/O[Y"\]%@":)>$0N%&!7@!@)4.++_E1O`8,!=4SNADI]15D9U'^E)",5=]4E
M"O*-\9)F>#AU@;WS34IDI++@&NX3&(1\;3(9&?DM(X#O[*V\#RSB`7^S>+(B
MJSO;K\Q.^-O(E"KCF>396\NXZ>T$,=1R"6[*/@[VJZ@XX),'R0LESB"GZKZ2
M[7D:U','R)QB^-P&/54(JIC]9-QC+R;D]QI$(@IG$3>5_*=U;PCMD&PDXV8+
MK$2>`KKDA%<Y=;G%%ZH2AOXLZHQ60=8\OLSEC@!U3G!!V_%&A2/6'HO:^75O
MS),DONXJ<TLF=8UV90%^GQ/H0:7P%P*&)E2(1Q!IM8?QXFW;QTB-/3A<4HUE
M+.*5R]PQ.,LD<`3>J(H,TQD1Y&:3V(7N/3PU8$3_6Q=9CBSZ@!8O"'X/]Y:1
M1?:V:31IH)_^K^JA1T[7>).1IC6Q^TP.FT8Z&&@NS=H+#0_/#*_$G<V-=Q\T
M`"#:C.F2`Q.]T5'7(KN3$FG1H\LS)\SU_0_MXQQ!PWAD58Y:O%S,FE_65:TL
M!RWN)EK#.A`NT*![B@RR%2/`_RUJ>;:0Z"F12_N?#6D9;24.-!.$#*4>I.N-
MF>\_0QKV/#;U*@.(.\LF4313R;996FW>E$/P`;'W(<+(W;]T-4HEXICT#&E"
M-0@P3ZKQ/\9N),K49>E4,0V-OBF2B0RCKLE=HZBT.'X*K[+Y:GB.V/S_4`JW
MM8,RNG*\VU!=[5,VFB,TKX3S,QK-61P84++B,Z:*,1Z:,QJ"(Y;6_F,Q;\G)
MU-%7B'YEX*E8S8WOGR8Z(A=\BZ0V97R=X7_CH1LUHVZ@@>\&?G:B^9SOF=YC
MU+)'T.NO.8S3AF52(7LBAS._-"B/"3S>X?N0^LZ3#S50#L2*DUDZ-FQ3ZMG=
M5A28+1QI_754./+<9D!\[4R:B7IO6:GABAW0*?22U\-HZ)@Y.!?B+NF`,WV3
M0>8*+ID%UXOOR%MWZ=P\_%5--COP!XEPWJNF5D@U"$42+"VHW2(PO-K,BDP\
MQR-FYDJ@4`BWK#\[N8/A<.QK@1W0Q1F.,1:=4X9-B>4!22'\UJB%LA@O5)Y`
M26`3KI90;X1BK&8`B%#R5X&A[6HJ"?!0/Z=Z#[EK2O7Q`?WUJ[R[<A+&S-3I
M$"^S:*X0'^NKI)=AXS@FF/2FA)9AG!W7@=JI$ZI*Y%0^G6*23&X(N'VS;N>-
MCAY+8971?8&%&"TH[K3R21KQEL9WA#,S&U?.JYJ9F"@H$VW90'@RJT5<%0FB
M7;>SPF8SG>!]C0H3=W0^Q4:#2BH[6JUW//L=:[Z\=1Z='E'1BN$!))IA\E61
M1_VCBAEH!]T->R*O$F',-22"HEU.ZMB+,8`:P?/,BW$*5%ZEZ-KJ0/J=<%PW
M`^?E8OB1LCF?Z0(DG),`1/CNON]U=0>9H1*:$*[JK\S&=#5#:?]/!*H@99@6
M(0F8MP%9LK/(#?J%"$<IH!<5$.M*0M?QLQ8RZ[H^D7;_HRG(1\,A03'F_[,'
M@5)U?*S(=+K#/SIMYNG).FJ84;!>#A]D.'VXB]#HL;.)ZZ&3\?OJ#!_`N@BN
M<D$//K(C6V-R3C3/)!-W7=G23VH1[LW848BZ#!8\R"?)2;D#U)O+R;00:#\"
M80A`@=<*KBTS]&@]DQSYC=D$\2HM1`,YPZS56<Q^C;IBC`-R*Z6M6_8>,.*9
M)?@LB.VW6=<T*#*_1_;<KVT<9Z'Y#X>@W.(_Q6R<KE6A90JA_/J"B75\U3_\
MYGH5IE\A@ZYQ$KU5,KG&%P"T2`898>'[9'[%R.'_P[C/7OYL8@9MRC95%;!!
M`C%`=A(L`K4>M\'B(V2;-ST7#Z*@B%.\+P0WQ)8L#:ZB]*G4/P27$"#="X;K
MHR$>+5"<<MIE>!XH,<L2V-0"":YC]A.@C2$*AC__'-/`I%';=2BU?+Q;?1LL
MUP%2TPBR$CX`1GR0NGO,D%*QLND140GG7[K%XA@RG#FMTQE6@3TD36"G\ZF%
M&`8">Z#I!@LU6/VB`2[[YR_!3]#SG_4#=%_.U:YY0X\X-8T'0CQ@`Q/HL9L>
M;]Q>>(JDIUY^E^G(K?ETUFC.)KXAE-Z%"=F(Y:.T\/CT;$IN(J;)Q4D0\!G0
MF39TWK8_+CO@JLE!94Z/J1I7J$`N1;K71R^$??EY3"`@?E2+T-S8W8?G%AYL
MS(6E_^EFU%?7X-16^D?$@S.;Z@4LB.I;3=_PD&Q86(@W19)=Z+.EY3#LKD-J
M@-HWZ!`I<=U0R[)@W4;LUN:`B`8M+W!0J^Q&")A"".^AK[7LHL/3H3MG6,8+
MQ:7-S*ZV4.P$MP^'JG]!P=M2HR\4#O*`#8UO64L#D?.9&3>*K=:=+G@ETT4J
M_)=JI7D3U$<1E_$)+G$?<Y&5\SH0Z(U1"'JASUXII=`8J<)S,XS_#BPH01$(
M9JNWB\_M"BL"1*""+#$"5KG,>4<&5\NP4KAOYPZHJ;9%Z'*<)PM1/F`[4PTL
M!:R,0Z*1J/153[*E*Z2XDE_P1*:$!*+9P<%4FBL2SC3C\3CILDT_@0-V'@2'
M&WBD+%"QIT=^-K$++XZ,J,;TW2NG2<>N&:LQ16+>/8`D(?@I//2=MOZU$WNJ
M\]F/,G92LZE_G>=@N\@PD^)4'Z'`S#4?=RT`GO.#\M4I0BA9WUC.Q5LA\E:P
M49Z=R$2S'^#.E,/<T)#3WJFF8&&/:0.G1L!@\"R-1$9R$ZCMRHY!JNG2$`V+
M?@9\G-'JF5PI0+:6*Z%R?>044VU2?O2UR7N-SNMZWB5++?!K&4P\4O[X1V22
M[=(QZ;50JQ!>)XB*#=]#ZCA1MA-FS\J]YTZU7S@%50=K+JR5`G(`B)@B_-F\
M[*,-;>XI]\5_!(\\\:IR+X>K27/*M)>^:WQONGN.OXXNX&E8W:7T[JB\W!Z3
MTMQ3A*Y2)UJT;``K3<"(APWAO=^JV,CMCIIM4XBYI*T^I'?,(8#7++#VOSH5
M9)7Z#/XS(JKPS?-U?/=[(4!%/<C7-%A$#P?,)59UB)@]&O5%@R?UTC_N?+D(
M'#)\,9QQ-KA1ZK)T(JOI`OZIE`N=>,R-G>MA+`S^DI:0[>E6)L![R^/"3LO3
M8-U#]#/"AQ=XKU"GJJ]N:XOM8W[?0VS>"LS&JE,94EE^)*1V]%(D6,6N`Z_4
MM\=AL$&;[&_!J_V3^E@3GM=WNG.:KS8KAS])H&1T&VDOE)$,N?0?3J7*@-]O
MC#0"RYV-4F4%;33S5GUC2-_(8F_=@*:D:"O3B?A9B("?#X"PCYSP=RZ<A[YF
M?6L6&A)0'2@=,I)8U1H_2%V)BR&=9KD,,KWV]S@RRX2$F8`]9`$$&RS.7%!7
M=Q(*8)6F2`J(;_*`FYT`->C3]FJJK)5DKS=`L<<T\D1>"EEY7;*&AQZKX+_>
MY0[DUY2F2@$+D6F][UC]@SZ.F8O`&5#$DE+?C<EY?]4S@GWR5\[Z=3YH`2L1
M+(`["Z5+])^8X1_*+'/H3QA.H#+G'W-D.=-*<:")YORPM89X&.V^XQJL;]"R
ML_7N^^P>EQG?V0\7H(SX+&`H,I4&RC]*+&8<WVQ^YT&P`&7N:E0*3PQ%T+CL
MTC51YS+:K.X]O/(!L.?>B*FLOC?-BW-K4;C%D-O[+Y#.WF@"CLSTZ8QIXX7O
MMN"Z?;51`!PO>(B?E=,)5V`$"DL[3BD:)QI/QSZBA?BGP]Q23"+":`I+;]!%
M]5)?(L3%-$'AJA[J-PG9L^-BAU>=I>/-T9Q)/:_6J<U.GV[797Q3(<W-N0W;
M(G`?S:@P]P1\X-N28)",J^.O(@5E6+'+7\MEG.^>4<T[6-:LO>C$B@-)'1=$
MC:ZKV1&AX<X]/0`7W8U.C##G+=#N>YIWC%QN#)+M-"^J4LJ)[(/2:S=,]P+H
M/1E`V\MC;%SF[Q$:75_UKQ^^ER179QYT+%#N41E([R("M_EV:<FL78>[.]+^
MSRBWJ$3X)R'F)S8N<_H34KV#16L;0T?V4>1+@6](H#&GQT&A*7R4F63>8YTP
MV7*^G.BX;1E@9&A9P!O[?H^!1K!,=A0)VT+`B@#RCR=@H:.-[C$D8LU_$M$!
MN35N=>S>#A7.@@IYS63%!$;^[@[E8M'Y\,!F]J)1XVOR1$/BLOA,;]-"B)XY
M"/I;-K0J*S[BH7*27_K$[YO.3,!+:;.Z?!ZKO0#>!)U?,@N!`(-;^_-[JE6$
M'.:"_HK2&\L<P_#!HM5-3E9)N&ACWF+94MN8/Y<5*W34A!,_;4B01.!G<EOL
M)@G,0?6S*YX,`J4Q&TV_/&Z]IYX]])8H/$XBD3/AQ\5$`91YLUY`?7AY6X_[
M*3^WIU4^2J;:^RNVY)J;]H8AW9D8JM6_3#[KLD?*!D_"FJ/+4%YI"4ZTAX%:
M,JTLW!.28M>[?A/W*@'XF>"U]Z?7='WG07;2Y>IS'NA5-5<IQC?(=Q6^A*E(
MGR&;\3>>DIH8FG=!_<GX19G1J6+M[/LP&I4V?ZYO)=32@4F*-^D-)P>/>V*G
M3SJP@J1^7XF7O%Q`0@0]>`+1SI)X&II.'I#H)9.8.&Z60X#*[K7WV\HPR>[@
M:7%)),1N^^03ZR=`T?RQ/C$W4<L4^/$+N_@0<\8(",(MO63Y%("4[:>O\C[Y
M8`76OA)!Z6C*?=``W61S'B@1QQT=LU@!`O^=XH4")S'Z-H.THJA_<P=<D79X
M&JTBXZU-`O0"U*:0R],$[-NVP+\8DPHSBA<3\/25HAZ-JTA(_=\OK+#)4C6]
M3V1+Q-C\SA\L;CIM<EP4/23%C^D?[?(FS8?ZGASS8?"[I!DI1KH*]46$^3&?
M4$X,(3`5^%#+I9A:M\1R&'TZXKD]+7ETKRE%0D8C0GD%`E]6M\AYT*)E(?>H
MKJY1_TEH^43(WY)M$0X*(1P`EM\WYJ"GCV&F'$W3%SDQ%5&JX3;)677`ERX)
M39(I?=4Z[B@<9]RS+HX#^R(;U+"@7/TMFMK8V`!1X'7/Z/$:RPL4JV*LXB41
MT$'G8WW"LEP5*++8*@*:`<TF@K1N.AL;J5Y'-K*/=;JU1@6](.0%'&>?.F=&
MX0;ZJ91;#M)8GDOOP?J45U#>A9]APQ,@Y56E:,AM@6T_"XT3CV^,]_L8_P9>
M;X[QJ94L`0[GQK?<N&\#1&C'BL7AO/59L:3XT?N*DI/0KLCEYBC=^76=3&/<
MTQ.M]Z['W!E>-VHB,_CY8Y#HJ7M'_-T9/$-_^YV1_9@D+%#W*KT#1@7!_JG\
MQ?*7/C+E32DAP2>-YOKF@UG++E-CA,U(FQWR+I_YSADT2,TFW2IL`&PQA1DW
M1"/HI,('D2`Z=K?:RQ$JWA3+OI>KC8^N9BC:V-%;NF(K2G,-`'S#Z+VF\@/L
MDHR!`8PQ4U2P'+ZL@7U("K9JZ-C<E*>NC.4QO,7L$(<=YFA2#8YJ_;>F!IO0
MO:[+;^B4`Z>GNXP2_P'3&J=\6\@*%<]^[VLX(+U^$:@YGXE3:P-B^8I?IQCP
M<WEY<#,%&TF956DBJ5@[:2FF=.VOM06<4%&0JXFF<6;4[!*PK0[FN"\\V#D/
MQ)1TVUV.'.%]&:ZH?YB1*KAB%"V,Z0)^_FE07707,5URO7)MS?C:]UFK/)9*
MP])F!3HK\_4PE9_1$;U#:J-7+IN$IM(RQ?A@Y-9\K`QKG5,[(U#>7LFRIV5O
M0CZL9/<$(@$0?RLJO9_9,IA%PN:-,F)(I#$PT=6!8(]9A,C]XLM$+5[LF9)F
M_8I,8YLZ$P6HQW+,^62<8*C'.W?[O)]MT1\JI$/.C]/E>BARN1[@)G^O]D"(
M\N:0N;4W6DQ>CL[`N)%O\U`O;SDG=AK-.0;H%;J$,-BTTT^/,FU_12LHT`8[
M0#OS/5[T1'%6@:+#>G7EN#NS>V@CY?QUGR-88&PH20C6J53R_-M:YDG"."9\
M_KU@Y6LF@T!5!#\/(1PH=?"2=+SP_/J/;IOO#O3U7V,AVVN!5'B*S1[_U"F*
M/G\-P6[0X:$<NZM"_@98/8D_P-\E/&XTY5D<A2:I:8-W;7(X()YT=]W/J=Q&
MV<9D6D@U[R"&ZL*T8VC:G.%#K;@X]N%F?"-&5=[/D[\X'O)(M?IO&J4J"_:4
MBX=\J>>,8[_,TV>ZB8ELN#=2[<$.V\&>^:"^OAL2R@T2D9?7%16*MB7JE,1R
M;-#V\7F\#9OF6]Q-TE]@9S>=!UV-<D@S?*J*34AB[]C/X+YK*8H-_`KQKC%/
M^.[FS-NI=C2$"M*'SM0@;CR^UU_(4,2K2Z(=TA#$(CM(1X1%1;7:!H*XT.X<
M/;U&G@NAP\,AK(*.5A^&%K+%5@E!Z^8BENBV?E81U@)@21W'Y)A+RN55_`%D
M;W3L*P4%F!G:$G?'D.^6Q*BTIW>A9$$O8N=D1F@EC0B79^Z'PO;.A2QVK[*=
M/JYD5Z3<L.8L5G^WE@^%R+6&F`VK?V`X;#[K74:W+;%)=WP"*^`#PN?AERY[
M5'./LG,)3K+PYI/[^*D#2$.7@R-WIQI3VFM5@O2[A]J<SOR[3P<U>E_7U6_6
M5B_*#A)+X2$@B!8RSGE`L:7$U[4T.`,Z&N+TG.1Q.1LX`YC=U8/73OXT!D#\
M"!/GRZ.5(W)!37T1W7B8./&V#4N*9!N,+LD_O%OVRUIKEOO?C8^<L(5V!IN@
MKZB_L#XX%_Y9^>E0]/Q1F9[F=6Q/L.1-"+7/3HN92/3@-[IE87ZQLEWXS*@`
M_^Z5XT3OU,]'DS8TVT[3$7NHVD_>IKC1728P_0OQ%RKA%82>`B$SL7TG`Y"2
M6OH:U)/=A16ABV+F]9$%CE<)+?@!&=,4S'<$2QB?LZJ]R+"7Y=QVM!(S0)96
MJG+^?SN)P'&/XS;<+OGG281P<U5/7)F0*?"C0&-U?.M?7(^J9-F^;6>;;<,T
M,U8QV-0XQR:!X(`!\MCG9-1HOXO\M22KS&P,U`5'M0!@F(Y]I#*8'Y0"U8`W
M-;WM;Z#`1UAQU0,*AAIF"BRLD/-A'D3B>QS5\$6AY5%7EJVO-@7PB+0&.A[\
M<A2C"VI5C9)R;QO;:'8H+"DC8TY-&!(/AL>D%"`7$Z=+&YC_E[0.9VU708T^
MV.="2O.>W4I6R^:.[B]&+H7`P#0`!1PO,\B,GW9CTC?+]CVUB1S;L(Y`2NEN
MB9/^"AT>V4>;17!]0[/S,HNP&8H@^VGV2@DAW,^IYKN9E%+K?(/.U%:0UMFS
M6,FQ\V[`E,@,9[$USM"YCT']V120/H*,&5J.1H#F%_`&**W$KLBY<P<&PZ4>
MW?)+V<9/$N&'1/T7[Z"?]F)`D]UY'S@!@!4^UIR2$+.]1N2S[,13W`):PC<`
M5+\,)+FDJVY>J*>Y6SOIOK/!UCQFE)T:*,R7['^`\&S9D]0=T+DJ*?$?:JC]
M&4O$SGWNO*\$:0^Z"%F]SPO1'.)KN(&HH@ZL[E].%^T6#Z`]UW^&T:PP!!CU
MJ&3HFW8\>^.^_GUP&:2A^O28\-*5N\^I:AWV&U?8"9^2E%R^1]Q02;]:(4HU
MO&,%ZKU28/RX0`!7M>04'Z0<!?0DRQ?5!3)]UR/?;/#0K/Z9Q/T1KU3`+U5Q
M>I]"#8J'4#E0#QQ)LKJH3X.EGGL6Y>3KM%:?AH_]69+*,N,(5(\$ZJ?7;O-^
MM"/A[PR^Y^=B82_%(D^V,6!Q\G_M&+G<>KIPN'@,L)U;>`!0USA]8]Y20AK*
MK-B[3L,@PSQ\BL\=Y#D#PGBS+<#-[O&5":%C@/QJP]HN(<%EGV4Z$<;/HL`0
M[EC-#@:[I-/X$[8W7)0S.W&3>4,[;<B&NT=5KB?FA!<1)H]/99GXD5)[KU/D
M#]7ME4E'<3IX0F1HL_J1ZFKD\X[,>KZ*ML&=9K(N#R'HH0-TI"$;*EB0(;/?
MJ_YN#MP>K-`RC6-`5>A]$JIFHY1&HYKE>X=7,4(=9.]QP(RBN.\F<IH<(L:6
M*X0(3],67&4AL08;S&/>4@0@6"$*,O8#RBLO`NS;KW6`)8#=62''>T/FP\;R
M-B`KNE,8Z!I,&R&*H<MO'`+<=_2V'`2S_.V7OQ05Y0Y4+M#(_\>8Q9[SCYA%
M*1U-L';*"AS/B@9Z0(1P,E*F(V4%5=),Y2K'`!\_X/-`:[VS7+^YI"38MB,3
M$$\*-JP4467_9;K+#0MC+1@+H1#H+'DSQ[#+ZPN>((5-0[XX>>8#_MX_@HIR
M06IJ&FS,UAFY+6DKD\&E.`G8*\MN_+;J_J@E(AHX&]]$;01W[3J.GDVU=MUU
MAD4(7ZIB2Q%_NP`P]]HLAW#(;!CF`D$!2=07(;#FW4%=X"=)=[D+N6A"1UYP
M4+SPZUK,UERT6+R3`5YZ(VV0^QT8_6J,$5JZZ0$==]TTE2/"X@<SY3/]L+)Q
M.`!5A;:X+6C!_X0Z8()8:G'TFQ8LX(0:7AK\7`!;#;Y9QK'OD?OH[#8^2!]Y
M>T`V,\+1R,H91T^D42#^*8E+53<,]ISUX?FK$7,\-*=YT4&#^3I]W`J``UYS
M((5R()9&;Y^K%H4C$@]"EZY\^THEZ'>4(MWJ2W+L84TL6&H8Q%+#M>_B$IBC
M1(T9`DCGM\+OK_JIA'#'6W5'_BWPJD;G[.J\ONX!,6C\8QL0U-<[+3IUF7Y.
M"DOE%&\,U5ID$`>8G`Z,YUUE>'SFVLW%FI2>E&(4E1MG*LGR0/T:'QY$C!N;
M60V[+!_94,?Z`:(!RFS*2#S,?EI]+4?EI,E>90'JN+O^WO84&OM%(#/*\24F
M\J+!O10*PT,+T9^6VU"!8&SP7]\)\_6`'B0W(BTN?BO(]R`F&8HQ2)I!`CI%
MHVCD^-3<,;^,YH9,[SI0Q[AG!:31;W@$1C7V=!F(0/KY8\_W"J7T48#,U6Y1
M0.!/7/:&AW\,TG\R+\7%F'JLJGIA\DH+D>83^N6L[=AP=7>1V4=TEX($93FM
M+I\[#^6?#SBK3\\\QQ$Y3^3/;:79"8+SBG;G]_?-?M;[;AD%=>5-XP+^J)=S
MZ)S$;;*#$2)WX3FA"-Z3XS0NN`-;HMI>#3O-RK9FS!S1>GGB>U0C3%_MD897
MYW[Z='CB$`OW(C$D=W9))1H,M2XM!85`:`@-<IWH<9+X_'4]:56=1P[]06X;
MW0;,JT:251]A&W$Q%L0`U)Z4K/LRDB:-%R/97;6^',0$2L<3*&5T;$0W.@QP
M5.T3G*X?R?E;+J['=9^V,!?2]ZX4<+^+(R+L%6EA/I6R^FZ>@=]H82\SF<$(
MY#KQ?/P,N.L)(:@S*CO#]WD/5;-EW08$P\V#S12>3\KOF)7]Y.DE.!8IL=XM
MIWEY4TE64]ZY:-YYM`.,'"A8#8O\YOG'%.*>.-PW#Z.Y90/;>E[LC&\H:R'=
MNFWZCLKP&!S#!6&#MO]W>/7H:(D`%#F?*W1Z*5Q!,L6W9M_;$I;B.N[,M)II
M3M.UP<@"\<4P?2EL28KNT+?)N(YNR8*J;]3JIP[S7D.0)?H1F2J@2*APQ:<"
MN/7\E@BO;Z`D*Q!]YX5YR%>@EFHL$D_@3D'J&57VI4=8N*I.2@\74"_9R7:2
M%=EH>69,2>LC(:\+4*P3O./9B3,YT48L/4.[\#^=4:X,/TUL"TAYEPKOY8MX
MQ\R*[9;:EU9BK:7ZTDB'.U/X4XL1A*!Y<@K<1<GHL*3JQ#HZ.68IBZ"W-#$\
MO:<8@#2S+P0>Y&Y(H>8$1%8&JN219S>:R?=4$WP;%7O,1YR17R(W+SW_BD)C
MA?^=^_@30"P"]-:B*;&*%=R_KM`.6*D7D;*2+*TC\5>/NFD&2]*M!QAW`:FR
M"/C@2)2?RQF+CV2,YP9J<Z3FUU':!<Z7>JZ3(A]#E8F&QA(Z:-BG*'K2A%/P
M!N>"L/DJ[=!KS>N$K'K""'93#O%SJS+\)Q4%IAP9)=N9PQHA[H?R]'6$R=$%
ML*>BD]/]%7'&CW7T`%'<IO#GJ9*#"X7+M4Z:IVW%H=>&=&BAU9V[";;U!,*&
M!I,-\,=A(MKV[G;&N#P%/!%660(N`JVOM!43%5-U?\]ABM2A:SYR&ICF;/]3
MM4]3B_Q6F)F?!P?;0X,#O^[N+9J;Z7>F$Y!9-(<,UOS;&.3^"#,1`5[54Q:`
M$C4(&3QME/%4']38^<(,4Z3#E_].(4;UOKJ&2>I`&R;1G";182SR+[071F])
ML#H,Y+9(2-R%T,3L]D#+]AULJFMF=V0W(SD(6%C,!F3JEQWV,1Y=\3>OT%:6
M3`DU\VGA0R!US^&H&AQW,,R6-=,;$/:/:A<\]?IQYN`[B/95N:NN+W6OW^2U
M(HWFM;,KA$8`A6W0P(5__<8XW:=9BN2C(4Y>43@<,8W!3TF+3(FH$(0,);F[
M8;%'W*JKES8K=7PLG.=;7&J(Y+_*B:[SDVNU#=S")]E^>X<88,B!'9DS).-\
M='SY^QYWM5KFR0,DNPW=6\WT%O/`69,J_!W>$"VEQ6,:AT,?J\52UY.N2IJO
M@!$K+8I:HA&>8"^<SQP@8!/2=L.8%E7F141"0MW75#BZ\!;R+RY4V\Y1WXT5
MUNPD52GJ36&JO**1LM0<(2G(:KD=J8T$W6NS\3TT9HH!K[Q?FAXO9YLZVSS)
M0FTRZ1OICQP%,TQ&T$&LFXV,P-"=B&J6DVB-UOD%/!0Q)N_%I7,;G>G>J?4T
M]PS<"W"NU/7TI0JL"@L%I7]KTG:!EB2'>7I?G?>9\(]W4`7_+4"`,;$_$0NM
MG^728+QZC-<_;83^L33D*@T.(M1'QYN?EX&5)8L(KCI[USBOBAS'F."G(X2/
MD3J1#A!DWLV6;;4MX;^+5TH-T>E#:17F8*Z*1&ZQA]SZ,%`ZAO'1L>J99LD6
M/.`Y>;[CT5$4"P<T8ZCHR>6HN<:7##>MN5/FUG@SJ*,(_;VTOFM2$LLH(DJ/
M^Y?BDIY"Z#[H.OA_`]%47L*]U>;T"UA216/$"XPTC`WX\AZ0$!$J#.RFK`?T
MA3>35%GN8#3"(XI/G4;SJ+-_^&#LYKLX0'(+8F6]7\B%]>/,+PS=6B]JOH7U
MMSI)/L6&\D6ANF^`0:#FM8R<'F0NQI)O2V7E9^2B_<ZLG:/KBAD`PE'V/(]$
M51^>D)?\:!S@+RC[\*VWIV7!X6LRL@"VH0CDNHM@\$GY?D@.N=A85HP7%^E$
MCF.K=WAC0EO60+`CYZ6"+KIQA"@^H'%BS/C4X=<V(I\R`IA)L6K4)<OVR5"F
MMVRA@NU`6EI,KDYO7#81\2BY%PZWHT+TQH:<$D.WE"J;F37\QE/9_YAF9.05
M+(=GTE[R-18%D'E)/$(8UN0=&%M+V-14*4UW;92?:4:RD?T@LA?GSI9M6Q_S
M=+BO0F5NN!5=#VO!.<LK"S9ZO*Z*&X.[$(8Z;18>UV_:@HEF)R":(<9V_NUB
MS$`JVTMB)E;2*WSNK2#,+:B8-JO'EVL4SY]WUN$R.R@02*P<'O<J$?&3+TKD
MU23CX^=3F"5CMW.N2W/-,/#15,?AG!3BKVG+I=R>M+5^/]*[QM+57/9B7=YR
M'44PH6'[P&U_[S8"4$G%$+7]WA\#*K$T]P#DH<&0P%FXOR'@_J;9L.-*R3K?
M<'LI56C1:"KT05UV7_NP/R@3*)-^F@%//AI,,<*.RR\&/CP`8#NJ*>5,V#A)
MV%+'>0?U;UO<4YLLZM\Z.4#Y21BXZE7`DQ5-P.""?HG*V6_HFA*S3:ZADH``
M_A_PLD:8=/;J.37>AN&BX,#,11%&ZQ(7\!-R]'#+3TZ7@*,$;(BFABEOSY9.
MRRP52.L/0#N%[2$$XD:13&\EF"5%1@V9!B$'-YV^\X[L01.,SP"E]ZDC-\K?
MG:WSAO"''5;)M%BBIHV54?_[!$O6-V7<;?8?$6U(R%D$=CDCVEZ_`@OWX%P.
M#Z6C\:F?#T5_S&)%KL11S('B\6A2,S\4/Y8BZ\$%QL$F,A#2S3CAI&UR)1C3
MRNN"=EOF=FLKF8Z#;9GV)OD?G23GGX$ZC1B%P6#4L4N&^<0ZDS5.0HX!2$XU
M-"*+?[:E9`WL,GQB0^0)<12,=GTI)U.H/J06K>&)5Y_%*)XG4('O?"O_%]RM
MQR47UKX@CRV,]2WFC9AXR+_?K>X`QEW3&'IN@67[\7[4*4A__[9@S0%SQ.<H
M"?BTUL67UDK+33?34)E_1^1(QWFUX(F'+HTJ^D0.(G/=_F``)[HS^!'U6G9D
MNMLO<-W%P_//TG.1S'L`)`QDE1,DIO^DUOSH]O)?8[\:^DDMZ]!>6+:2=VC;
M1'^"XTOQ;'%K7],[!,Y7RK/$RI3P1T!;VXLQL7,)NP!RP$?<J[HU,JD=[>5<
M*COUGEBX_]G^C^\9R4K@8<N]!#9LM[%X##-E],Y_BZJLR"N'1]3^*1OCHC1>
M*I(Z-\K2@:$ADGX.56)+9B<N37D2?R#,LPVT%REXR9VYF;DH"GS'1DXDR:FO
M3-VO<UE38FC5+!#])`/"SQQZ$\AY"3.1H8\6$O_G0FC:8;MX##J<97IO=\2/
MU7EZ.1\]9WO'&++S).L8IUN&OM/>>5C?^*Z`[`RVUG?J`X`RJ%"U*U=W$XR+
M/L7QW-ZU[ID<#/:#YD4W2M=.]CJG9"D9-R*2MMVSK>XS&/Z=][J0I)[.['5[
MFT9*_-,GH@9\D2:;:W"$`?'96R-KI<I/E5))E=_$=>+D:M7E,UW\_$IRKMBM
MG2+!12]8=;B<%O\]VB=.;C]L@T,];2(UY[3"APD9/R3=A-'&O-CZN[AWJ]UY
M?4A7I1]:'>@BS5;B$C,F&(=#>9U)=Z,L3B,_'I/^_F)4IO:.R2OHCU\B(-S>
M`^:-M(^Z.L")NX]%7>8X:IM^Z/6?W<.5C[$S_%W(A]!WVZ\?*?E_]U9EEZU1
M)/HM8]I`]3DQ=]A/G'IBC=1"]U.&QZU@Q=)E@PG.`P,\TGYS/K&S>HC_TWA3
MWV])/SH@_XP0FL\&F/1U5)C2<2KR18IF6\T5K91P/U.KT2Q7_C:!+$OI5"MR
MG..D`EM-/F]0(D>2\<+;1!*GHI%W^@J#=:]'/JA4<*ELH9>IJ#C<L2E/^&UX
M<)O:>'JK@^LW"_(GHR.#P$VUI+&AP`97?\.S--^-W6P5)Z/<-KR2260W8%4&
MZPZ*AJJH9>UQXZ]HK;4PQ]V(A6.W/Z;/9>KV2./=F;P=$K?&+P5E3_>Q['R<
MZ/25>I('!X-TCCD3JTL=1X[?<-3U@7P_1AA\.L,Z<`+SJ\YY<P<%@YC#P$AZ
MH#^>7/+=>_K8:K@-JO]PQPP:OT5\5Q->F:S'-N?#-9'1=4>B'9Q1S/4B>-0@
M*`Y9T0?(#VOK3$@R;KT>DRX9>18GQ<8,"F7ZRAX(I"8TBZXRF;/,<3+:8-"8
M#UW5[XGH[7.S(@9K$J.2^%"^>$]TT]TK(J`8LD.T(H"]?'45">7]HM*+<_3;
MALF*9(W059DKRJX\/9K2]!P4\<*E4:S[=,2U+D03/;?_GGYF".":HAS#5*G3
MPV+DL?["E[9]W-.K3R:/N+IX?.%1[KU=GRTY,_[&]=\6*A^?>4<G/>;F8+1]
M>IJ7CI&5XOK<C3(_G7BWM[!?/8_H;#*VE,#TJ:/3^#<`4?--Y&P6V=Z2>?AO
M`"`VYN@XM_^'%'#I#_QO(5JJ0HK,XRU!JH2I$`IJY6>%[M*_HQ?J['N**Z#E
M3%@M;TOERCY$#)?1\R_;A07_VY-6]P?0VRH,G0X5H9L`K6`,5-Z*3RZ^9)DN
M@_TB"(UCCV/9A>.F<,1L_>F"T)PDR%_H(?$]&?R.*4UP0A"6HN9+__%#B'G-
M8+;1[2`27O>NRPD+3?,4]T*`JX-0)X8_7WA>;-$?ZQ=D;@`&9XI^(VD$2:W4
MR_F1WJ,1+\#&S(?-L:?4T,/K&BAA&B#W>U^^S7\O/KER/QX^+GK2_\SMW4L9
M&J8_3]-5!!1B;GI`(?WZ3;7+X.<IZ,S/PED4'6HB>3Z*8;+HM>\2R=6$M#?-
MN1'.&/5)!#4WOX&"<@]C#?MY;]Z&W=86]"D_Y(TBW>_J3PU%,5*T"*5+I$R"
M-^]VI;#&Q7JV<(2F0!G-.-6[`Z'5/99;(^N5_QJ.,0;\#="&]\!#\N!A)-+?
M>NGA=:F5L?QL?V=SR:+)4,[G5J+HM$#O5WLO-_7#;4(TSPC'0E1#N_`*87(Z
MU1#W>66AA,?F8L_\]A1=.[P!!JL>ZIK5&^AXH@^FQ@64WHY(^K.FG$6]`*NO
M$N88Q5\>X&WHLN<LAEXGE*X$08EY@S@.LS!X=,.(2"KMRQ[%R8]0C4HPO^+P
M2O*+/MJ!\K#9W,?QESSG[34E/(Q*<H7_C'F6>45V>_*3>*V=IZK6ED>TM/`Y
M7W,I$2N]VB4YZW,+<<4>]*,XNQ6!1#0XNJB03GI9/].L1%&4"6,(XC0>J1V%
M?#J9_7,O>`J>^CZ6^.!OR@]4WYB5FC]`7:Z2=J^,DD;5^9V!LJL`C39"JO2]
M8#T+^(%>DC=M-Q%$OIV<`"G'7]6:!EH,@DTC(VXVT<ODQ(DAZD&N^AS4KO-.
M-*;XT;A>;B%S-OXT]Z&K+T+=NF(12',]69,+,+THQIU=);Z&K2$5)G5KOF/F
M3J>Z(L)VX^EQFB=#IU=%`>YSE`&LGN>3D!+I5\I9!OE:R@K;.!I=87V<H&L\
MX\5S;Q:&&/C>U@BD=/G'=E6I!T,7L13^DP"B?#L*,NQP1IV['\N<`1A[*QJ/
M)S6H@0NHPWTU&&K[#>%*E6'/:(+<X:BCGY>)/+&03D42W3+7NE!J^,]WS,B:
M#-#+,#/KB;E+01+P:-^&,TD]6L(6)4N"Y4L3_T8T?J20/<Y?)I(YDL'#+_07
MBRS9C:Y=D`=0ZD``R3Z-8#PC>',2K[R@WDZ3$!V">#MX7D!4#1_;<?\C5'^3
MQ>QC1I+@[EGX+X7RAWV*B*I&%%23\JM->QI?4"=)9:&(77(#+"HR4*)/\C,'
M`KC+FW9XN%ZGB+:1#`X--?G2(,!V:=72[94?>KXVBTS#N"1%HZF<;Q$4WMX<
MNJW<?X=@#D0[Z$,"?^;O@YIU`]PK1;.RA)ZC2Y/VA%7O=T2F]F<CH14?60XU
MDCQ_+UB:59$&@3>WW&W4'@;Z.F*K'785(D,Y$/4$(.L-*&V^H;"ZL=L1D2)I
M,LN*ND$KS!/-,5?>LF9/Y+%_4JL_'11S.M5.B(]:[0GP_&9IPY+E-Y!)C=A0
M4B/GHF-YD[K+X1+DBZPW%!=]*",Z#OGO2ULR^(23K6FI#"70F(\%!H9ZDOMD
MIK#S,"BQ[!7YN=,%VI7(.TE(R'1PYM?QV$"/_U&+W^I4-#ZI)975Q7X7!'@'
M%YSOX6DH8?FC@/[^13;R84B6O5X87$-GN4-(`9Q@-%Z.GW(V(`HJXT4[-;:M
MH3F[K3U10C`%D_GJ7#3KR;:UQ],/*?[+Q/*XAQPU<C&]0``KN\>^MVF"Z9IE
M/%0-=?R0Z%O!;D!S8/(-N`\!CR<2C$;IO<'&!C/.(=1BY.U&NJF";-?!W#<P
MM+S9&LCOO))[IM$=--CR+VM_\S5_*?A"%'`T@H5)N0)@4H*VG=RU[P`W#Q:T
M+ZF-#1U';X/J$E?7OI<KN"<GY"-ID+8_0!?&@0]TL4MK)<O-]6JSF+S_87*B
MB,19Y(0).CD#$>`G_UZG,61##&1THZQF0_CI/J/B)=GET!<TYG+I#94$[U(?
MIIT?YD>>;7@+^'JC(%5L_]Q+GYZ-%PA:0AO(ZNS#AG'%Y7:!1R2!NW.L9TL3
MPK&J*5I$K9-S/S)B0/8>30)BQ$8NUT%P57N9ZTHF4RUFOFP$-4RP<G'X5MWS
MOI`HI!%,IHJ_?.2%V>$W;])I(^3LVR9V9!?TA=)I%.`4&]7=JNN9/09+C674
M)HSM8']604P*(T2GDGO]8(5I:0'BFP6='FQR\US[9F(?D>0G3(R:IJ+;BN)C
MO'B1=4KIZ8J,"$VW!A+`4U%G^7C,LD1&['S[I8O@#T&+!"9>-196UC+&G%N'
M(RX@44?`'_=RDML[4I76(*(,13HM[)0IY\6W+"$WQSQYH/0F'!<4T\T+A8#%
M0*OEG4N-?.)55WT@W\)V'#[K,5^W6QWYAS>/J4M^%D"#2%H=O?OU:+DC:=+<
M5'T#U>=UFK`0R=A05@T&QFKCDN9$CD^;O-;ZV$!?QD0M&6K6%BU-^\>OQ0\'
M%:S2-H6^*)FA.%F6-KEA:12']'_>/-NI5#M8<$B9M,S>5G3O*'XG9/.7[^(,
MW<HAGV)6D[@RCEQ<61.NZTM[Q1U"Z.[:^"ILWFMIL0.]$T@58K*AI=YG/*;5
M)FGM"P>E_;CS>:L">:X[]Z*3OG6/L@AXC'+G&MA^V*:&XYNW+)XW8+/+(MBL
MIIPGWC7_`&(4;?"06?F"(9#K))>VITJ^`*U</7AT607MD%<L1%'6HX($?XN;
M[9*IPR9#/>5%7+)83H:W@<]L&8+H"&G1M:$[)+.#4?W:E-))]0"S9G?\H*J*
M!^ZKH,5N;ZZ^;1K<9U$*[SOVN^,3`+:/[9I(^I9ANIBS$19Q&4M+134F;PD>
M'<,"0A^^L(+I^(NE>0\P)\-MQNY;5GX(4I!4Z%TQVT-IX5NN.)>6*V*M?6G"
M%`N-F>"WECM(?FD)9=6\8GYEOO==DFN%'5N"`XZC024D@]_0848ITO:*V!I9
M]CEP#^WT$(5,2=\+BZ`=:>SU/DP"R-33+?>_)<E#]B;F[>(;,R((=#Z5H?Y*
MX@R9>/^8V,F"I_4F%:FBH-CJ;BC%H!K[Q<4I7MPJP$:G3<=E&-#__F3=RIFZ
M9?XA)1.O`@;ZR:78FF6F%1Z%N&!@Z^P8G/#,`BYXT(C69S2ULO!;L0FHN+I6
MC>2#X;;]X+_3$2</'I^1%F&4<5A`EG==P]B(0^GQ$]QK_$U0,$%7ZA4OT`K,
M1,V[O/U$!4O2%0][#CKR-WX97+[0D/][^31-W\M,4/T`T2RBS5PW-SXZW-KC
MQ2DLZM6J1#F1]`R-;2H:,&-9]IR9JA,4[L;@O1Y7BP>T9$`N*/@<]CY;G+`]
M[S.;G*+_)YKX\!%J=VYL;G4"?4>7A-\XU<0"->F'9QVZGD">]Y-%_@?9I\<R
MAT+6O[82!4S*S;T7)E3/AK*I$%L[4]UJ+Z@EG8]$7Q^IR@/NE?3<^_S#<;12
MT'ZX,^OCB?+N#S!&V4*XT5CV+;Z/2O.Q?QJ9!^'N:^!4'-,*Y[Q'F8:+*M8!
M37+\>,ZL_G>O(%BOET(L8S,^L6FN,P]:N;Q9S4(+%=@$[%B!LA9ZQ8Q/`FG@
MTV"=#8Y]/(3B,<"E/"#=N0!Z!JBW!J^(=G+'?J`M&1]Y7GGQ/]JJ76K7P?NG
MUXAD%1+/<YV_1<.Y4X]>Q8H:_L44'#KB=X9+_J)Q9)RQ=)5M-=RMW;==<Y$<
M64:4]7_5T`N.M.+!-';KEJ.XKK1X?5O)VQ&R-@F&BDWYV'6VXH8^[MFE>&/\
MG"1@?(Y23-'/?$Z),6\568\H=U^35&[VU`7_2GOZ6`>CK:;D=6NI>(\Q9A69
ML.PU9\C`W1#"_/0ND8KO>(A)0(-V<)8'6X3]Z`P.%:K@GP:[``M@V^969P>:
M9>5I^W!16:`'O9GMIX4]$MC"(U.D)#*6<4G@FKD,WKA.Y<D<?JZ+B>T.=3Q,
MNUCS3F85)5_Z-J%.RUN3+04HL/V[5>9PTFJX%)P\(QQ;7W/'8B97@G:GZ?RF
M&EM,*Y(<.4,=R"\)L[8.R)B\5!@R)WY=@^CN&]8=KIWBEGFD%TGT4>F8TD1]
M,+#?E_YP&G\8A/(DN%*FL/`,X%29^(IFL2JD8(S%)N_WJDABW^=8-/B9^/[L
M4EX/;/T'D><_TA>(;*'<LE?;1ITL_1B:]EMG)UU?2HF6@V;J)&:`:3CP"PPB
M'AX$I6Y=.)E'_.7Y?\W:(A?VX1I)@XTX46]6D%H6N6-RH?1+T()X5H-"HU($
M*AHGE2@GMJ][7$,[2@3BZ1#VYOZ?&GTP3QJAP[9][D\R<X!35.23'=F%QCEN
M?JM7*4%R"\7:W=C(U-+GI_LYQY4KC[;F$'R)-6&G%M10:3F'Z-8'6I6I4B]/
M)`Z2&+0VL<XST^>P0H(DXUZC:-L)?=2L'\!=:WL+<[2,DN/Z2?@7_`"8V5IS
M;M-=MA2Y`K=]8WB@7_T%LX_EKG%@'^KNR/;>%:A&_-P%*=E61L]-L[1GR!!I
M>GLB)[DRC%#5]S0RE8_1VUG3D_LJ<40Q7#0QYX)`BN.F@+^TLJP=',648&8!
MC*]B3V]Z6SDILB+791%N4_A=5NU$*!.$[5K!(4`/1!$*2Z[639ICB0"F.XI1
M=R!8<:,$O&9T%G`#Q)MTVN?2WCH%$I:%>)%H[1D7=:@OD8>,*L`.`54^R`G;
MYN['[I%@_OJ((*PE=&&;\".<#1?^U*XT`#8BX)[MB3/!,L)_D)F=%^K<::$@
MK`JUDZAT-8>=(TWMHY[667'7?I6`+W+5=ZR6(>857#]NOYCZM]NP7>!E([,T
M`2>NUUA]@X>;,ZY0-A*@5DYWAYV^IU("MQJAF`XJQ&:'*@>[C>&HRU7']A4I
MT\C.YQLJ6/T4BN1K*'G-D$;0XS)IVPD8+T^JL=''SKJ0W<G+Q5V!4%GAA6'U
M19&9E\E!1DZ_?<L%AKL3\7M>+:W_\=.[X+%-''YV5`A*^;F)!5)@C8MG&C=4
M7:\?V^$J1M*P<PD:6H"&EJX04%B$'%1K'U57[%QU7/%1EK(+,UTI!#;Z%&_H
M)N4;YJ&_KF,(.$&^.:%E!B=%/%.YRZ<R`T"[L:JNB";)`OT]$D\2`GJ4X=J5
MW"(/;1)_5>DZ2VU[GW=W8E%[[,X`\Z87SIHE<EKV4?>_</E:_*L9&(:Q#C;'
MH+T?<>G-<CTB_DZK!@4ZKSXK'A+YCS%13Z;BDT\R$.R@;T>#.]MPWS,'ALK]
M8AEI2=F2'`IE<AJV>H(_6>JZ,M6\,??C("!]XA`IP2L$*[>HV;B*=5U@AX@I
M>>G9N7O$Y\.R?E2NU4E?B&?6(6##BO#B>Y?=*0R30N8SKXAZ-?P;PGAU7@/\
MC)\RE/!YT/5?0>7I6*%TS]&HM,\YX3;[R)ZY)LY#2EW%<-URGM)`?CS8D@RF
MQ=D)3SQ*U)Y<&Z)A&ZX?A!1V42U:>M7W2Y,PX4X5/Y[HE9^825)B5'<O^R^U
M26.=2?G)W:P%\\8NCR19O0$^5QS)OD/88H="!LR>SV+Q)I^;B^WU'/V?O&H_
M'9Y#T-6>I#2AS8G17S2[=OTL5#DM.)_N07-NQ/@<?P:_.V8QZ13:&"^C5H?.
MYY"`\@71Y517*Y"C%O,)AWNAQ(!_R?$A.%\ZFKP+T;?.`_;PEK)R5/3-M%PY
M@)EV*K*8S[LRUW*OZ8NR5RKSL'$GFY*?'P;'IUV#`X39U!ITP8,Z7=*[N`00
MFPN,O8FXN]F\8MVTV9RXO3_#=G^H'LH@3O?%G)0QJU_BS+)J4VY0%/*EC6I=
M!%)84$N_^5&6T`QDN[1XDWM8N"29U=M]__=MIZBS<#\:"R`>Y/[*&APC:\;4
M*Q`O<3$Y1"3V2;;#Z%5NW0\<`+M;@Y?RJ?"#94J.TMQY7-E4Y")@#)C%XV>3
M%@Z+N&H>>#\$K=>_@_C*:"<T%NIG3GH"I32L=;Y;(QF=/]D@07A@(!,[M90`
MIII@+(YW8N3&,Q-?Q(,Z!7RS-_)$1B8B>2<3CFGN6S2JU@`9TPS03)H&P#70
MC3%4CCK"*/N<8RAFF0C90V"9:EOL*%N6T'JFCGP^M$NN5AOI=U^1'9,5X.(_
M;QF'J>`DH6+$$79^8%:_+N/%(Q7+!S#F&0W=EWJIGBLA/6?`/1$R0O#?V"WZ
M0XY:,1"G+/B8$GST\+1R6!>.[CAN?DG6M#3:J14FRQ--X$FJ,OI$8V^]N=0M
M?HQ&=$4>3DH'UG+I(SO>`=Z1B;9A:D0[JBVIVBO\=GN[8F[]'R?;E.TD8*`,
MXFS48R9E3HG22G9K78L-!T,Z14QPJCO5'.N99)[#.Y(ZO6<UJ^LZR!Y+5O];
M$5!W-TW$`M!/*]<_7YQG_$`*>@88O#&Y6>8BW=Z?^=I-K0@GY2M:C<I92R:4
M"7/W?5&=7)U8'?'`/B59SA7&H,BYGT'Z[Y-2LVZ3[XFIK:7_9PP=HFZ/WL^(
M,:7'>C?Z#U:M#<M(;.@R-+^3&&4OB_)F[R%)'JM_A<BJAYU0]?KL^`.2Y!HD
M*Y/TN^RG_-T[F3K]]DS,W[4NQ"YR)$HJ*N?:J[N@&`0\U"OXBC5J-QX-AI_2
M!43)F8*Z"+$G^,$/KB[@/A<F[-^_,:>Q%F^'#I;)Y_\[RQ_B-S6*<W?%4^IJ
MYM\=$(XQ:<1F3MC];I/)O46'^M>W4FL;]MBRI<XO9"%>5F_+/PY_5Y-1K5HA
MF(;AZ14.J#:\I!K3H`]UR=))Y7^&7Z9Q`C9?4M@9J/+_3-9GX&!*P6YH*2(9
M?%,B`F``CU\&J=P#OQ/C2`CO\%9T>L&H6ZFL7FUUL^@U_;S1(;;K^".-&4=&
ML7B.2"=<1^4,M\9]!Z@4/A)JZBGK1'9>E%XQ;>1KB:MD_1!251T;!G_V1,;"
MXNH[-NL.A33C>E^4M[$[^!`^-0X&]<L.U.?T=_FV[YTU6C\=@-&I4D]2#=.F
MK<=NT7HC.Y7\1M'-/?M/Q>T&;K[3+PV)`5NPB/L.2IOQ6;K`+MQM`49$."F$
MW)SN($,[-XZGAMRDC;5&9U(NJ@=O#$;-W).-F<%I+D-F:'3=,&[R\QG-$$Q;
M9'!&MR*]5C6U&%MVEP&[-[%%:!SUMHV6.BI_`XO=.@C!V$WM\K@^LK:[3;MN
M0_/-=1]-O4EB)FD.$ZCP1$(]XE)"&QAC=UYBE]NC#\)]&3"7^0,K>)>&N?-7
M&7ABUP*X=M^I?`"4]OIQK(II6Y2@%_BY%!CE<XSF]XYVMU/`]X'&5PWS+@8T
MMT8>^4>5_AK-!<#9KNJB\56IT#]*SGO/1<PDGPPCZ]Z%XQ^HD=BH?!'CU.&5
MF^GQ>X""B<ZC(A6O;R63MZMB,EI5.4F<FTO&)>%",1'8KW_3V"5I^J3$TV14
M:9XI;"]H3'B0MJ1.3EMYU#W_#KSR2)5@R8L741?-8B^'[&XLJW`(L3A(\/S"
M0B@HB:!6!%P<K$&4KH*_H2]>3_$UDBR>';34IL$X[/&FT([^;&5WJH1;R/.O
MR7'9`SU*\T3*V0C12;6G(VE#8T$>_7,SU>MRDNF!`<Z%LO8I`,Y(3D.E%-0;
MM8!S;$,7-*%)SLH%E@@7_Y0WL[D.MBT%6_+TUP95PN1`A3F";SK_O,N;(F5+
M],9F+[6K4!6F=P83?P#]!1V+Q\U&FEY8:W\NW8#3UUDN2N8S<366'%.*:[:_
M>6S7A+$R@S-$![0J(_%=R(\ZR5TTQE/(J=<(RZ4/KF79RIZG8UO`4AL$R+!`
M8.EW=]YCM^-<?RHCNV/J$PCKA*N\*4\RG!M_Z7>)-`89-CM18>/A\,KSZQ@0
MF[CCVF34?@V@XMX=N.X?S]1$8)#3?XPJHT6"4YY1O]E,OMIA_4B$Y,ZI%55A
M5XIH9JIFT0X.:<DOD4935)FJ<=L0A:R7UZLG##HMJ^5UFLH:3K[O-58MT#.>
M/^[K!W!%_('V*`-A."G=T@K.@3$[IC]H2)YA<@,I>.U"TO>&W:::#PL]0QIV
MFK@"(!PV2;UT']G*I>5'\*E5GZRY?5K"RP^P:.WAC+U(9KS?E;K^O*38"C@?
MV83/U/,;;,&U(AEH]O&.@FCJ%,W"N[YL_J]$D\\MSP7DDTHR_ONB+/78JGF8
MLM'H(H-ALBT07>*W_;6^C1?Q8R*,^<`[NDS$T=C)N/^;K0?.RK3RV+YST/.*
MG6>=]<%'WXQW#\I(C<MLF52]V`%A_7@B8FUP`EH:3XV^W(U\$=6S,Q_X-XT]
M)52=S>C(R9CS5%8L0KC";)'*(((3GG<&]D"[8Y99=I)%/DDB1&QD#0%02ZR"
ME6''@9W#V>IBE+`+Q"*56#=`%%DG$/9G>E'ZYE/3KL*C7(F=[LQ*ZMX_C\.`
ME(.%IM]^O,OR,E4:>SFY/_>_QQ-?$ZK47IJM?;_'89*;UU8VCYR?.QBS%FHT
M[RKDT%@&IS^/-VV4Y3C(&]G,D_,S$Q2`-Y!PF;4*QVRFR9Z<U8Q&E!YRFE%N
MM(I1R!-Z,(&,``*0K6T:Z_0$;.9-*M7F0MZD&F76!R>43Y):Y7S\3%2W,::;
M5FN.!>Y0"AX+R6/1MW>,M%F\V&>TBJ$3DHF9Q]".+E0T:4QW3!:]/YIZ\(<+
MJ#6QO+ZPH*C\1]MQ$W(@=6:A081N7,+D,Y4^F8),NP1XFIN..;4Q);524ZXD
M8VF7>+>2V;D,H`ARE++RP+C!UG4AIEAH#4N\Y!53VOH<F\0JS&#F2U]<L.(:
MPN'W+:N&AI4BA3K-.XFFVD26/M6>E33ZZ^8^Q^Y1N3%W4Z2)291`'D+I5(E=
M5&AL:00F"5^5;8#WIO.XWCI9/E4'GYV5W-C!4-O*A0W[4(1KPK<\P29/'H-Z
M*2M%>EE@4T@R)9HE*SF>F+POZZ*FU.8D]L+(Y$7!>,!3>Q:$X/,GMS-P<&/(
M/$"ZA#EQ;&$<'JN_=T%7792HM08:;6^$?2B6XJN/;0=%R*_'7$&BA>`R7?@X
M\9`MJ],SSL_&KV53+,*^.;_!XY\-ZLKR?IYCAI,/QFK]BPBF;/50N,D-"MWF
MZT$?*YHHXP.A43A;5!AL!1M9>UR<B]V;W:"(IYO+0;=_6X)#G@%Z,U78`7J5
MH=JX,@V4HJF%*^-`D6&*N,:;/65J6E1&1('\W6&JES@(C8-XCI31^I0B\.[R
M<6`JPK>\)-PHGM7V#?3S)3_^5UC4#=>\+%+8M0`JKNSLU8PJX=D-0WC_.ZQW
MLEUDO0AV`H09?N3Z"M5)D^[#.*&5!$>B[]%*VS(;DF;A;!#J=CS?Q%M0W+Y/
M:UC3VL>,:&878&P(O[Z/RZ0[<07]`VZ1')"Q\E-^@:]IPSSNC]\*BOJFPLL"
M5]\J*7M]-L5)"\>X6XG5@C#$)(%'6)M.8(0'>-76Z'X]Z2A,Z]DXIIU@XFSP
MD7$<994@C.@SBO*RH14K#RFFY_9R6%+(G4S+WPZ_36JY:NT<KR?^Y5DP\7E&
M#+RIZM\L%Y]%01P/$WRLW;-OR?GN2:@S+5WU2(Z?ZRO'$R'.`*AF0BH.LZUN
M#^*3=]@W=\ICJD%0HBSB]]W&%_`:SK2NV(^7C=JBNBRK7C1V=7#EU%"6?579
MFT9W:U;3&6FHK)/=P2+0>3*+0!\(-%*959HJZ[GAN2E+,4?WR'KB,-@V1S*B
M.F05H1B=D7CO?)KG!JZI1V5SH+.LJ#]EA1H3-"#>=CN47RB"!=]>X\_7%K57
M23RKTM?JS5)[>^NCKD/BZF7^YI`A&DO>84I[@%@O5X3)ARPWT3JB-1P@3!6%
MXFCP%(1O+9-]DD[=YL;YWGJO`O\>P+"-DE@\=()4H$:I^*H'_A,3I"M7VZ;)
MSYX@K8CE;S<M&WQ!B[Q^'T&EPOP-4Y"$IA6]7($;:Q!VC./Z6N0-MWQ^UD7-
MPE^H2><BA?KE9`K1QG!A.B+S%^ZC%'RO,Y$!3<8.Q!(FOF"+S[,[3L`G5R+]
M@V61`B5?33ZDOD((CK]^MUXJ-!J)Y`IO4EQFP9@A>Q06DHE\"09-'8SO3^]&
MK:_%B+.V[$%&TV#$:CI'^;]'H7Z=\OG^[I@#9#XP\CX&8W09%3WHI\M'JG5P
M]C_V!]&U0(G339<O-.T>9;R^U>*Z73\>8@;5*(.N$$$V%DOL7IY/[=[%D75>
M1O6PWD_Q;)3XW(G]CM)M82#@V<0]?E;*<TL6[8\\>WB92%E2P:O%9GUAP>.&
M[J4#D,13Y>-ZQ)],*:W"/:&-*`+Q[#G.S+#KC%T,(;<FIR1L&YR\VPX4-Y)2
M)(QN>`JJ%RN%*VD3\O>AQ)U/U$\-!_AHWD?9S^E4%![:Z_BT_!5@,C$;?A2)
M,DSE%A"4$_[IOHS\D;R@.D>W8(.F?";YY336;[WAT`F/^P=\N=JL[TA25,"[
MT*!G(VVU5MJ'E.CLVC.#'A\C&$=%JF>%D5<PB/,;]5,%?["D+ADEEW"X`\#(
M^`2%IF*>TAT5%^UYI^.'EENGV'A2)39L[$[<DQPG*D+\:D(M#XS-+3I:1\R?
MBE?0'G1.\R?&^=<^)BW(+[9(6,[D$;K[+SM<+&.TT$&Z?'@K]#2\/NB%DCH8
M_TNF07IKSB5(`1*Z!J6AD[<'-$QG+AAVPN%,W86/M0+^GRKT?XMMJ[4$5./%
M61A_F['-[8-`YE`+5`%-_:3N5H.4^Y&[K(M8TU87Z*$B*KTC^Q\/.%HJ=G-;
M$(4GT&U!&X+'^EAIS!R.EYPS7DU<M<4-_97"GC0>W23/-<<PB1ZV_I7,Q-89
M"WA\$4VFO5XC_0UOZ/H4M[2&:EB/&^_<N:3M+JX-KKV<L?SC_68E1#F.>`!X
MI0Q*7<6I95%.8?+0%)3IDR5DNZ--$(N?M1Z1EA%DT+2J&Y7NB/HAU":C.KFW
M>LQUMTFU:?_`=Z(^:!A-V*D0H--H=<ZSTDCA$+]*"^P%S/]^&?$C:U1%$O9_
MIZ232BM3[C6$!G%>@@A/4D58X6`VOHE^R:CJOVG59:E5&)1)L?"UJFU5)%(4
M;1'VLDB\9SB]%Z^27T!*(9/]4ME&5IO$4!>[!_//_N1;M];O;#<=I3QILG7F
M9];;93NAN<@;*"%8=XJP,?Q=ZP^E:\D%7.?W`UL[3,ZS/-V>&JFMAKG5176Y
M3<.4:OJ,:G.&7_<U<@$K.@RVLFODN$NPG!/Y3".6".\=24K^=9V"?.^53,#$
MMD5C53`&4`"*KL6#)KR#XMDG6Q![:Q4M48='\9AI$UG;O@ID3WFG>VZ`QF[P
M23*3`;#'W"QY^7GC<1.$LYQ<EZ-9`G'\<>+2ZO<_RTZOYA=H!1^?#,9?D!OO
M:+#/2_#,T7@.$;[QMA$4#;K04$7H"SF`14GDO^/@BY1_Z97<.9SK!GL%-/E-
MKI>C#$3!\+7K87U94]CZGI2[=7Y1^(.FG.&6DUA2.(4A**U!0(7([W:=`=W,
M+Z+_Q>KGQVW9-`>$MJR0@&*;4FW(\(Q@F-+(5;<KIS^N;@+.G;');S7Q'I49
MC-:<^/5XVIC]_(JM>)!^>I#)O9O">9PE`!>I\E1B4BEHL3,.%//[C%X-:WLB
M=P5O:"=S/;5,B)&SRE444"(BZ,F40LIB91_$M^%Y7Q7E>Q"0\N^Z66[+">MG
MCK5VM>"JS3Z9]E%NN)7>X%>^:9=>46-8%<>K>O<:U'3'X'NSU[6<BU]7\@@%
M5RBG/E<X!&$6TC#$UCBMU6:1#^$\]\WH$B4H?_!A:2Z.VC(B'^G81US&PF5[
M9EW1F+#];ZK:\.IWW'`Q^$_JHEB.@*L482)_EAW,"9]ILC6H);EEU2.A\L"/
M))S\R!RV67WS\9+/]#A:\1&W/7M,N1F*"XI..C8"&JE]'0@%#1L85:BQ0EM'
M7SC[#>UX4=*`A,DM&X%BGA.\-U+LB[E-C=L2I\OR$XR7^XN60U-XK@X\B69B
MN92I67#:R5KH8E2_9CSD$\BRZW+'AUCRMP&EF$D[965`V%!L!\JF&+?LS^H3
MR!42=K3H<A$#H3-DG4QF4N*A6ND^R<*3Y.06/;^TGD'>70EO1DMIM#\ORW-G
MC)<22]3E2<3Z(`@,"4;3P<E2".;*[7I@R53^FL%RC`KK]YX_A9JDG*B?[,I<
MDB6-D&A4=:RIITFMV!<N@*13:5=W\*,,6&0,;%IW5;.GZ4:.?,^_,0'>`1[H
M"Z/>$HAK_TBB:^*40I3ZHXF"-"(F6>U/G$S"FG.QQ^OX.GE)(+^,F&<HVG"5
MJ=UYL;48LJL?[CD['P=1/D6V/%2E!-?$2T=I)]D*WP5'IQT2V\'\5FC``;24
M/ETLB*=$+8G%"$@B[I^QR$@;R6M'W;FPP:MMXO`RV$KY3[$\D':80CAQ1TB-
MGO1S9F);;3N=7&CDQKL!&`N?5-=VTXO5P;=VK7WBF^%"E>@:?<'SC!?^07@Y
MNM2.C^F0=P4B:T]E9C2GQ/0C=QIO6E4M,-!!//YSW`9PX'0*IMG-Z1CPO[N;
MP#"22:4PPD@_<=,X^[F>+`7;Z`52>WM>$9X<G%HUH`>Z(\4>+@;!M252XZKI
MA7'\D=P=^'K=:N&IX8)U1@YQFN\2XGK%W%7"*?)'+^E9S:TB4/W1R:%-K5]W
MPQ6![VV+^&AKP&9=](T^RUKPC6Z8A/[W3/[VO$9QL>:TJB((&\B@9WGYKCNI
M^_RD:3._1CN$MMTJ%TNDO(A@U8E":[:"10(!QJ/WD)HB__[(6UHXJC!VG0C0
M):&O%TF4;5@6&4,&K"-MU0D?,Y$DZ*\)Q$>FJ!!Y)Q6D\:2*:6``PBW!%MI:
MC69K71+O=GK0F\Z;YFE4X./-L`4O[QZDQ`\[V1'KR(6-Z]CTQS*5]S&%%,10
MT:@9UTE@Y9Z35+?B\6]6@Z[/WZ2+.FALUA>1I"Z4KN)L,W@F^R!0FT!<.!5*
MQS[2F/=`ABJ&GQ8M4C:+[4"K'"GTY(A^`3)7F>1Z<#>L.;0?/RC^X]$_%YBG
M<:+:6K>UX?H)D16I4:WDLA^;?W6LT+Q0?M>-+BNK*DN\Q5UE34/IZ6WF)G7U
MYS?8'9^[F)9X0Z^E$!IF]6&=9%/)/<W36Q5^";RRV'Q26=P?-Q.OZ+NYQ1HI
M&BN7@Y"M_6L_#-1P^2L[F;XY14!Y)/U`BY>N6\'CE]QACC//&'YW[FKW06$%
M4;3W1$CV$$NP.OW"(.5VU1(AV^3,OXXWQ_E5*<*.#XO.W62/S&/+`D@8T76'
MSKP&2Q@\^I*.-7Q%:P+L@]QN.6LPGH45&AB2]Y/-6G[WX>66-T8<8_B&2JLZ
MK/1;W<8(W3T%$/ES$<9UG)@AQVI8)%6G`&*7)'\P_9AB6-5Q_0?+BV7,K$]R
MX?+X,[!:;<W00#A4]1%'><:[*]\!2JE=.J-X`<>7Z#!;_*NX#=Z*U%("^6);
M<8I,N>7A@4%1R>)VL\&(>6^>=5]UM%,>_P]:^;-TVPBB:NNI`W,3C>XH/+AY
MSYL,"T?E.^#:GI6G42A"64'R=TTI+`/P4HHSE3[!Q6VQS_>,GC2065&#!Q'A
M:OBK+Q))1M$!O'2$84KP(O),DO%TV=8,&=:+%BE9#RFQ6PZKHHV<-;WERTG1
MP(S9_'I;?4BW-"$/)+(DW2`G5VUG&M^`P+'C)K>%$YY,!Q$/IT?.=<2C-A\Z
M*WD$CBVAMF"O4LRJE^XRB*UZNJSLS78YX7A:`^L2692\:G;D#OM_N$R^[EVO
M*HH:$/7>F(839M4%R/</:;EFMNYS/6W,&C`QQ'<?,>W>-0W?I>+T8KOD`,)I
M/WFR23LV^,?0@9$6,!2CRH_3_#Y?:[.]M:U^7^50PZUDZICKK1+W#S*)3*J3
M&('(*PX,7JK5'9A1]H&AH"YXA'EOW2G)_@?N@O2CD.I?[7IK4,:NG0#L](RV
M%57I^I?+@)`J/(.<LF-^8:QU=<0LPQD[1!AB'Y+J7;Y;QTI#8E,JNTR8R1V0
M&+G,?NF'">XO]5DV+<4KCC\%H0C`Z&-,RA[.@*NF81A6$!`C;,KJ^(4=1K:*
M%=W#_()<::7KRHC(<(,BVX_K33/NA:T9AO>-391GY5P%>SS7H.Z7PU[/A;AT
MI+%/UBL1FD=1S.WVC_B?E0VR&Z<\U.YL,'0,OI`12JK[/&4&5+N70`<-?IMD
M'EG2-Q3$L;`F"5F1*,";8SA3#(V+IV;O[J:X]>#],!\UOAA7A]GJBOB;X!ZD
MS3<NKVC`T^EDH6',S3QD;R"8)234G'O"0XG^Y+'."$A8\UIB;#)SC=:[;DCH
M%H&?7$8Z.LAI/0LB,$13WG,!MM<FB;]3'-TLHK,.&DU>Z\5IY7:N)XU#Q;/G
M*KK_+ZYK)]7,#3*B.$]&I.->XB.6=V]%\G=7P)M?O=U8<)9GI][;(-R5:A"E
M\%W7%@$NF%&5E/@NI=]8:SU&RLAV&]&\`&C]R'#25U-6Y*6%*&)/6/P.R@4)
MK)3)ZY$5L&PGZIBBDY9W3!M%;2]V\].+O^AR!'89)5DQ[W6OHKN@?P_ZN#$8
MC``;HJ6*\%;;2=ED1%Z0"%<M9@4-+\TYF9P%;;SE2<;1K%,R?"^Q!(&05CO9
M4!P/S="[AB#B7B?BE9.XHXL5Z:0ZE@/Y75:1^6UT1<=\KUWQ1.3_I9AQ-AKI
M*QU3W7G6?Z?4<UGEYA6RBP+[6'XOW443LW6A[%]9V<\R:/,II0]QIID;0C3[
M*[G+@YH+]BWP_K]=XV"F\]J;]K^X(=!AF4N1`<COFS'<UR;7`7<+?BJ<D5SI
MO9NV\\U&V9W&"[JG,5!,KFGWO9(24<^50'4`<C:F=XO?'"-!Y*GG")GFF3P)
M:*A&EAY,7L.S4V9!V(@A#V/0%4/(-^R1BM:79UO+W%+2H:G!9_>,J<OO=^),
MB2;0'XL90&#%PJ(W0$`5+!%5@T7F2;8XK3G<5B03Y4IX2$C@8W[920.&,NMW
MI_`'(43)_.,OK*-OB.X%N4LWW^)79/J$=HZZ)&_QO3H)_I1.I2D.F0Z$Z$SI
M@$!(0JG<K)3(]8$`^\/FOQ>GCG]#1.'E#V`C>B#ON]G-%M]37+$J&F>ES2BH
ME_LYFW9/!@@Y[RTS'125PWMB<J[.S'<G:[S*QVGW'99>OMU$B4.3E6S6(86$
MYF_'M7)^U*0JU%<3]G":Y*Q[,EBK&^FQPS=Q7X0'+L."[LNV&_J(Y1,;R"M.
MM<15%%_$T6I>CLP`>]IPKAHQO9J+6'9Z."%!1?!7A_&NA]6-216=QV4G%C>V
ML1%`Z\>(REE`)?;L'K)E^&RT!VY.*LXCVK"ZJR,GI/K]EW^1->Z_&G_QA0-.
MMQ)P\K0F$@:OZH+I/E`9F$F,J4YH1A$K/K,877?PJP4`EWJ`4#XI^O/+DT)H
MF;S`F"')'+IISY>Y.E"2[>?;G9*DWW556'G)-N,7DX^E.7FB-E$G+;7=LN<R
MD.9R?C:1-:&KP$'V`]M;TP%='\I^\C(,L'BTWM2H&JSYK!C9+#]!03P^OD0D
MT%?0E.H-Z9OG0^W-G9O9W619MYYP-[I65U)_A@UP5/?P$AD^(R10O"`^:#R[
M%BI@%Z"'IF,)IE$HJMK.@DN';43!*TE!TP>%?42+8"=5A'\6]P$A>ER2/ECA
M@F8A,)QE3Z:*P5(Q`45_D"3LSIS[$$K00-T=U>:=\'QA`FLD41/937,$'-Z:
MMZ]]9@J8OLH#[,?_32JPW1'AC"SM"U:B8L2">E0W`W95:=GZWZT:H]^WLT]>
MY7]6WIH,<WP'VY2S_]XI8RI-@]\7W/R0HQ`?YB[G/BXW^O?"FM7H!41<2;I+
MY-^H.5?(+%O9,0X8.PGQC6A%YDM,HJ(?-P.WN&8<I&54L5M<ID+?E<F8T/^/
M:^=PR)7QPL@2.C=4H$";B-*-?B#-OO+[H'P`W9]-][U[!DU>LG^%SOV])_BG
MW=!3?M@I&:ZN$UV/#C0'RCUY0.PE#(L>AI]/*M8H\W,LW@C!^)4&-"/1CCX>
M$$J_@H90N&\^B5/IR`)]9ATX`12F1?K\@HC-%6-)=8/>'*8^XX7(^8@:-W,*
MMJ)1\LZB,"SROV;";R[5TL$BJ')]8VZWKL\GBR"1IBQ3UR9:MM)1FNT1N<<,
M-KJ6^5(&H8I!U2E8`S#>=APS^*E:3NWAT2;X._V7;65K:0P0\DH#?;5=2<-8
M+M+$J,A"C-C<@,&;+<6Q/:^(DF+2@7W%@^>\DE#ZOO_->>47@[=DH0"4[%J(
M6;>KB<+/G(I;`+M.FZWDB#QF=%EG*[.HW7C"+0C3U"F[2+?5OE4L=TEX0)"H
M9+<T22Y<QU=/^>T[I*V?N4;I5)&5;U0L*6%A()W=,C\A=$L37UU#H(LQXO0=
M68&-HK\.;O#VX5F^#6))Z>R7(UP7BPKY#247I6#F:.K&\L/A`%%T`QPF4%@=
MCBF&8AX]'PU2YU]"F>55M1'!"D+ARMYQ;A6ZN/'Y@?Y??B^1NO.L-2ATZ3A!
MMU5@#VAP$,;!/.JJ=G!H/S#D]*N6/U.MS+P=F&J+`@I5=#T]IXQGR&S2M!=4
MM_+43E5I*.GL]:Q]'LBV$_W$/!)+8+AJV][SJ6Z3<PU`<E+<$?B1SVT#\4)F
M+2%'ZYLM"VCKL5Q#V1!:2#7O_'R"*FZ6Z`?^_3]?\N!8Z5[42XY*9\)XHE;=
MG:]JIQ<B_^ZC=0P5%238C=#IP/8!8,"AS)%U12#]DWL.'IN*D5VR=PU#D:@V
M8**/@I.*]_NU%U[)61?64ZA7UD%3`7>F8<%-VFHU&#3&5J?8CI6F@,-W:ENG
M8+A+5PE83BWJ1U'^RC/*T-(G^$634/_>!R>3W$\[5/44[?JX4DB;W.V_+""S
M96U1:NRGW&@U;=.R/?)Y[+5$U)-NK%KA.=2F00^"SH5%KO#I;`RQP5/IF9A\
MB&9(?YHF<HZD2LLH1A-\#Q3!\:B"98!VS0Q\#^83[6]@4R'>'=BP$.#G;\[N
MJ<YF9^+7FU00>UE-@Z<9O@-A@I>AGL%N53Q<XP<+&!Q_I-^`P[%OH$RLY[YA
MR@P$Q/0JUB(%K=6-34[&7T;[>T`=J>A+$+:*P)`8G"P+R5.EK?V(CU8-9!%L
ME)_\+3):A[O)%(Q^I-4-_.$*9J.)A)1.18CQ)E/-^Z,<=;W;*J8`K+@`I<?,
M'KH-]8$-.U?][-L@_L.PR%Z1HEI$\$1]&9<D*TDA*D._PGBW":3N'"TH>N6^
MDHA,G]X?D@9/-+E/,\I$5R.3-X@C!4Q1'G$:.ZNE"I>(BE&UT:A1TV8DIY8\
M?T\Y`XH@J,;+CI76R-K[,Z"H8@3TLQJZ^&8$*)R3S%^H`)#[+)G]V"U+AKI0
M9ZU,:[?#F/]8*/81`][37_;Z)Z)^?_55@.W4D$HEY_1\'?!35.F<90N]7^W.
ME\=R5F!J@T*Q"C:\>T$Y>RZC#9<Q&`65ST%=K4(`O\0K^G=HI&GEP1>*+Q#=
MRBLOA%NVS+;*O&P,W33[),:S7$N*CV(*O`.7NO/JK,VYG3<TK1"JN['I/+3[
M73OF;1S43CILIB`;@.+S)F8TV1/\'*;-F'O-<(U7_RW+Q7P]X"Z2^+M0]IA<
M6]LT6R>B?+U`UWFB6G[=#9]W;2!;N]4@'5^J5UO2VQ>>QK1^S_SN1J3"PQ]@
M+X]W\+:PL*J&P0ZD>@S/J;4#)@#FC%J0JWWFT@7:*'GPB4J-42WO!"ET.?T)
M$)8U<6I%ZXOY5KJ&9:4MM06M>G3$*&1K',0#]TQ1$*Q^Y0K3FO*61QWB"%=Y
MQ)_TXL.8,F\V^/#P<Y)TJ$'\1>8-"F2NJ8K.5`&/XW45]N0?DTB`;[9PPREW
M1\-[KJ^CA'>!6Q=U;+O$Q4ES!2R&CPD+^^4@``5\7F):1E-HA"E?`-UG0E.'
MIC\4=VWN43.FL0C&I)VPV8_HF.XJB0[I&H2DG#>:Y8):0,OM*>893'$FTY1Q
M)$/N#3>-]-!C_[^ET4!S%<&])RQWJ]]S[GR5\8/KQ+H9^C";V.6<)5?L/J2N
M[#=)<'9B?6Z7$C_)IJ&`5V"&O>]=.TR,'4PIT5CJ9_"V$;47V1ZIC6S&Q19T
M:EN##EWQ=&O'_>;/P#Q1IXY2&3GR&.(S:KY;N\XV+W\X44EQJUX32`DCNH4)
M8S@N7WAY2EV/#)=1/_S\3AI[99!_8D3L1QRA<>_IA5=A$#A4W.!\?@\!)!H"
M*=?Y5$9J7G)@[#_8)/TU`N1%!D@.#AMM#J?FH-?[W%FN'?/D)-:!G4O-L9@F
MO?;)-:'!2D@DSFJX=.$IB>'1D)F?Y!/(BED)+>/I)/NV*WA%I?JA;J^QDZ<!
M7'^VO;GV3$`8#D/<YMG@_MT2^^8%U9R].-.<QO]Z2+`"#T;+OI*,L`[J$B^2
M*LRU'.AT(K=M+[\_7SOUHS/CZ=*+H#BA/,GTPQYVX9Y!Z'\&VI/<9$B4'-3:
M5*W8MO/UC8HEO&-FNZ21](XSL*2<E:?`K+GY"^62[./ET$!7W0;.5RM!?/3Y
MWE&'!MS_L]4:/]\`F%UM8F_G8P<._<+WV1C`[R6)`;T*QS3FLW)UG")/*>)O
M/$\3/"S-HT<SWD0EOV6(@U%TG'@X][AIS(2-C?)ZM]N?O3DLG;\;P(MD1WJ6
M/F*MW5N^$B1'5O`M2Q]R[4X2SLKFG40OHG1@`SJ*CN-SG*Y(I84`BFW/)%U\
MZ>U@LGS)MLJ&.WQRZO4C5H]-_VMUR4,U[TU]A/(6,IT:R$/!:_R/P:V/0OQ[
MZ&_BHVYKV85UP"@))DQBG,!+U)9616C[1,P#'BL_$X2JW6<*,!,DO)_<EFI@
M;KA),-A&H(2Q8O@[6>,W=U)2),T(.$S7"'\S*]8#!?4[DS2:@?'#=)T*UWNN
MY\0]GDQ5^`V".`.501*@S.H_",F3F*V@R6X3$AYX!/[_GKB!Y8,X0$D`QX+`
M.4@SB)$X)=Y?1[B"FSF0?$5RPF.ESP]$$;`4Z"WUH1%SQ[]4]RUIXR^\3S.@
M,*6#^7T-3WFBTJ&\U9<[_?/C7O<OTE2*7(HN.ITS@1@<%1'[-6S+6;"`O"QN
M6@;?G7N42N4;P9QI[_G"2Q=BB'6'_?K]O@E@W(O4,G59PVXV>-"?+`TEZ2Y\
M@S.G8`)_IRU8&JD96)#`K\:;SR)!Z;7V(/,X01.6,Z;=&H2>V/"T;P:4,S!<
MXAP3G[!S2.N-'_V*:V]U;>%9]!-YKTHU%"9$.&0,IB;XP8DT+UM'V8NB.=IE
M]PL?%_MD18ZL'4V=GF-^&G>G*AP)\:CSV._6I*[]:PA>A]K$J:&[EK*]QI[G
M7H?//0*(70V="7S5SA;2]-]BY$/_[^!AT]:H)06Y(D`=LM*OWB^R,YZ%+7R\
MH%K6)+^`-PBY3V[;X96#0+=.@R\EWA$S,7/MY@>2JK<MY5DV[%_EU1+,N")F
ML&_*H`P$4;WL_-XE@<<T3X\/3%!N^(G9YM5G=+K^VRMVR5#)J+HK@H\?XEE#
M="RR"/V?#FI53[?GUU<!2`*7>3<<!\X"W^YMY\W85P4=D>SWO`F65Z(C5Z$0
M6A=HH?RP&'\_[D.V$$(`FZJ;9;`SU*F)U6[QR/-/]R7/:')($$'ZN#>+U[3(
MK-[_+/^^BK>)87"O@DY?8H!>YK@&\<=K,65JEG8R&H_-E5_]9C5(^'1YC7L>
MB^C+_L<RX@$M-SV!-K2@!'KA79>RC$.W30&<0"_['"*I$4XS7FAM!1BI%,G@
M']"JD<'L@NVI<UO%CV^A^7N?I_MJAE[EG4DDIED2;Y%DK`B:#V+T785&HQLR
MK9S28(=@*9&G";5GY*(DE(9[O0A&ANW0[ZA/RN.'3W=_FJ>O[NV`_":\EGS-
MO3YL4$B#V0RHOM4,H(_U*5Q,QU$L\3IE9E"*=53A*KT>QOQL:;^"U,U&[5K0
M-0Y'OI+5G`,I<'EL^!-K.6SXUN6,QE"R&PFH>TW("#PKS=),81S\Y@(@&HSA
MD!I#F,XNK;+KU&G,-2T<60<U__%"%\)9'R8=/NF*->;TYL<,1@>Y*)5O)RHF
ML4*=AXTL9G`I@GM?9928._+KW#5(>A=[?@+,II)22#`NAU2EO]QOFEWZ'W06
MKZJ%(F2N''^>#Z2V32;D],01FKQ9^6"TY77@DV2Z-KI6P!_$:^:,R%K,[)BS
MWUPY*O)GZ5#V5A^X1&-(/_>%$K]N14R\>&<+QT>61K$Z+.;@2RVQ''T0;UT9
MM(BM%T884>)K>0C"2`@X48*^KG?/=,/,"M<:[GJE7V%R!TG`,P;_$4,UZO#-
MJ4LRQ%\*TL;H8XA$8V")^LE=&;95U6'$E<"0/&]-S";4(_`Z9CH_=-*M#JD1
M#E0PX3)/8467-DBJQW.#Z%YE2/4GH8UE:]/O2Z-;#NR0</A!%E#'2P6TFPZ%
MAR^:LJU\[GFJJ;FK>LT>)@RA)@5K&KB/K7M^BZBFBJ*T':<)S[UO%6LPHD3>
M123&O4&FF9!O"+PM-21H0!)!J0F87F:3#!7?7R20/UBTYH_K=]EY(9+,0P7S
MZ!:8]&4^7E^$T*><`&UPT")RVW_.=B6Q/LB<-U^S)IIF$1!-SN-@'>HW'(ET
M&0M/,-?=?;PA,%5@>1-0>;XI?LG`>REA3SW_F)UJPNF3;VO'*_\9B=[OETS'
MRUH),YA\>UT;DXO9=T2&M<$VN*E>7FJ')X"[(H2TMF3Y7D?=`)J%SQ#:[2T%
MB9O-A6_9],*?YUA;3%8S-F#N.,$J3R(2\AK'#!P?%!=Y&%E=N3C4H,>!V=>"
M/XB_`QYRMGU[*XS09YJ%]3ZD7LP[TN176X4%,0,5*G<#A^I5H&L^<[_)ARS-
M$6M9AF'#XP;GUMNI#?&D*29%_]LN[0B`Y!UN4M>E9/ZJ1106MF)T,>?(]2`R
MZ9LH\<AI.B8!W.<OPF8"04.+*6+.F-Y=`U?W%)GG<N9E62V@M+V7QR>+.#*.
M/>/3N,WB7'^E5+@<Y!:1CR6U6(9YL<2=G$L<6_]C9=P,BV*@,6@QCAM`:)7.
M?2S#_U0HIA@,RD'`)KG)HVY/KC8E#FOLJ/0X&BC*B#9EZW:1%W;:.W>WW)ZT
M,]8L^%JBY"M._/UC"CSA=N77M-L0D_P'1[5QG-WC\N,DP!;3-R090R<NYRL+
MZR4U0O^[K`&<J`(Y%4M[3O:J+L^9%IFQBM-'T^#:O8^72)1Z%U=2.LYRU4WQ
M_7;4"_^(!C-I/]0[^1-A'="]<7XESU[F.M]['RSG\9D<UQRB",F]MK%-"*5P
MU#-3\>FY?VZ0H#\T+!XM^;%GCSGI#@?5&/U&38``@BICKY4.<BW_^2M8_^VF
M:K+&J4E1;*S]!.0]H;V)%7<)0^&'<CU@Y7IJ5LPY9(M%A^Z/HEF:=Q*Q%?"L
M3]OQ>=:R_S4N#%RQ0<"NQ7#<W$8.I^ZH`)U"-RFJE8R2-`O>4(('>ABQ-RL`
MU2[51SN\9CJF\>H^9D8QH@'92AHMX,\2,]<B`CE8K;OD=9;S3S5.7&X9.6!%
M%='3B?U7-]D-U]A+V`-GRG9<W<:43&SOIJ%S,Q1.^(*"62H`7MHZ98VY@ESR
M@2>^OGDRC<`VI0!,PC<&&RQ;9&_,:DRD*!4E#[TI=JT8J?M]S$W9^R_BT0?(
M=4O1NH;'$OD^+<W-N0\7R*N)QZV6P3Z9A[H7QW?BW'?R&C/YQ'PZJ!)/L23D
MW=E!':ZC0ZO/%P03$]-PHNJ7,_/?H%#(C,P+I;^"_]Y>\^;D3[=.WT2<@A;!
MFWC-54MHL0!:U#&@E^&P?L#G&*A8O-FF$Y:WDNH[(5`T1I+"N_GC4C,3B1B?
M&#Z)5+PS6/\@MR1KSP]4RX125MS]<7;TILHK\O&WCHA7/5XP9OOY%&-$6H8>
M.U%L=R]6N;&27V/OO].#9#\3D/[TLIR&H76Y.GU_26HRY,(V^U%,XG>J04#T
MO!5EED.)O)O>,#:QECF7N(,]+ODQ-:@4&PG5[F9WHG;$>$OJ+,`C\[L$Q`?C
MWPZ)C'>L"3OB#7Y>RG2JI>1XS7.FU<(F_3\>YD7TE7,57>EA1857AP1/4*BJ
MA(_T:-H"I-.AP6AYSQ"7Q,HOW$[?XUH36EF_]HX1-KAF,;O5Q5+1_9N1JK;-
M"@Q3H*38?<<:<"2ALY4<8C+VDLFER>A/5=I!AJ/T$\2[-I-N%1DOBX^(3/P$
MMW/%S4\)G*/QRB7,MNA-F2U\)*/:/]8^V!GJ8%7V"N^7,HT;RAULIJ;[:>`&
MY*6=XK4M5ILFG,4L5S-`)7;/G$G%\,4,*3LH-!H`.?H(NLZM%T[:G.*D?_*?
M-E'1HS\-M8?5QV);P`/)M8U0;B_7R\R=Q,ULC^7_9`K-^D+Q&`7`_Z)<E[4L
M1<N;:SE@Y.F30\B_8"Y4!S76G(*1)VAJI&*-S1'[]/7QRRGRT8Y$_J&J1'_/
MH"X/3Z$)/H(IHG'_3B,#%KU^R`FC=+T`]'I%Y%>'G=08BC70EM>":R\0E19/
M1A]Y":*E36VS*"\<^K^C=5*E%`4,4`,<(@XZ"BL7!YFIOK*BM$NELM'Z6OYP
MGAD-Z4N&O0J+)G4']34UG"<B$=@1-%M#@IWH$U@>.%B"@GB$R`R1WA-%U1<F
MB%P@%?8'51C`6&S*_>`%:`L0$B([XPE'UUKG](?_4KJ48R>WX;.D\;EX4P,2
M5/8EPP)^O#[J(B,J=S>@)LOY2J9]*72Y*OLW`RYOG?&?UT("W@/Q!]0RUH@-
M7LD+BMQB94)1[$S'&J\)/$-OI4I?6"1K19)4R[$E9]]%CBY)2DBQ$]DSGT<[
M$RLNY;SB8$0-5H)T)C2H=$^?5C=8,NIE5[\'?K#LW(+.A!$U;P2UO.5TC^W<
MEIUDO.PO>5T2[0K&GENUQ!)Y3,`ZQ8-)X^.69+[^/8?X<>P#V_L,\%7+=P76
MM>A**`V31@P.3<,X*]A[B!*2M%!>X$TK0S`2\'D#QCK(_SFNS!IC?U"+$"3+
M&6I1!UL:JOD\+P^;F;*6012<6H7U5$#\P42[>CH_SQ:47HW0(M$[_FP*]K!*
M';QB3"X#^\6[RRJAO1A=C6NSV<U4K$B3/=6>WJ<GV5RJA,A"%HW+/IQ>@=@^
M!1KNSVPLI/[#M,`9SER0<V0M9#<X#9@_UN,8TQ[P(659"=T,1;T-V&T<P2]V
MI[2/GIE-9$[U\JE)3-;YK#5%8_JXF(*1H""3W&*=T526T2)7W#'OL#-"H!D>
MQRWH''!P)P-+<V;Y."H^IY*\0`SW?F5."B0S=_-MK)`75@VA6*B430I#H:Y?
MJ:<3=EZ=+?VH&EF<JAA5O7V$V%9W*RLPZZS0WN=@'11["G,]+;NZ?PY:L!QJ
MU\CP*(2,@85)^[)G=@&.#_1'LE)E%`;V68MP<`!SYG?[W%:68U$95LOO6K11
M)*AN1))?P'#VG#'*#;#K`0>*1FFFB>PQM_$;5]=5PQ,/]9^P<:^"4U:9*IOJ
MZ/7#B%\,-*"J7Y'L'H&/2`63Y/?;XE7Y,&K<2W7"DQD$?M$,LB+_7U26C621
MMI-FO^FBU^ZY*L&\[.;'#]E[!GLZ;LK:CG1Z<QAI!=(+_^+P6U5L<T0M,4R<
ML]]U10>S+D2\QB2#R>^32OXKUG.03G74,!SK!O/P\OKZD\D4:L".HAQ#CR*S
M!"K3;?L(J-UU&QE"98-<NZO096WWKIB9.&17H^=(LK5XH^J[52353S@Y^C:2
M9+5,M(B:&LF)L*`KAKVN[S6EX)JGX/(@=9Q?'#ZMZC&H8"2(QAHM=]@7]+-K
M<TD]+CJ[_8S8P\=#^-U](',-3=MVXF;P>(-0J_M0/5[)W.2QN]J#OPS#7VAQ
M/H)1J^*V\E__4/S_4FH>?H/N(?E+:_N[S_HU9J6F>LV%G=`+3N8,RQWOO0"%
MKE0$;ID?LF1$@2&*I*QFCSG]I6L2&I72VOJWM%EQ8Y;'!-A)C_)@]Q"DD\V`
MI:,39%@,5;$Q941:*>>?XB-WD;A)7*&L?J4KUX:LJ\-W'"%SGTST'.3:F@A6
MYB!<WPU'2:=)S=.-XE)!:MC9.(3T$:[ZUUIS&+#0S[/LVB[4D:35*`)]T<GA
MG?.'?M8F&^_@";E#_6=^B1RQ,+K2_T%:.,J"`ZL(D\6N'3^LFSV%^U4PU^6C
M7+/LJK^X[8MZ/CY[XGA@T79U'LV6MZ<VCT9ZJ#,K/E++UTO9%_'+AT3`<V-U
MPK0C+QM/_XZ;#)/*F/N9G2UVP4ZJT2;.=C%5_RX/E&6!`R)J-:[E',$/%0P?
ML?:'_]`%CO,$A;W<]<#A(>WG>ARFI:TYV(C:&HVCOX:+>`1M"(IJ6-1;*<NO
M<VSKAC[1)FEA%^!4!\DPL\6H20@U1Y$!#4,_G*X%V]P(!G.SKLSLPYT"ZR'>
M-+(.R(:'L7D6##YR!.FW])L+LW(;6HKQ'>L8O/_6E(UK_?"\ZI)Z75"F($>L
M1VR1ZY+ENTN++G*`1N%(1(@-<C/!R$QR9$9-'$<B#2A:==DQ4EVVE*-(H-MZ
M"HQ/95@BZ]=)G,+?9K9RO6[#\Q0QS`#AE`L(UDR-)_21S-IF7YO#\"6EUZ\Q
M:\`D+A-AF3M%-B4X/V)_7?1A)':354BW]FHUTP_Q_QKO]R;E5$F*O/^,JV_O
MG5$]5Q(Y9A]!3W2>:M&FG0Y'DL2WMUBS#'97.$C@>3B<WKX!S%E@.8Q56LY9
MO#R&UZ'1L<W30_3TT@!4-``9;4AT-,P%[245'GNLMPLR5>."0P\0CEX78W[;
M&I_3S_2D#UYN`Q`\NRJU;77>KS6^LW[]8*]X*,1]4]V.>F5A9X1!6"39#T=L
M??,DIBLF^&C:"A]\>CB(VRR$7EE5&>:;QWMBNQE#B&\1?`E.,C.8^+'-IU)D
ML2&KSDX+L];G]C04RR)<27;KK`Z8U`C:G@DN.:[@`*R`:XL)>Z7,&LXO[L[6
M#.P_6N?C4B.3TCGMK-4\M"`%@F\5&Z&.>O&[[9>ZQ*:!5L1GS&4[T8;UT7NG
M=!S[XE?(;T\AR^:[9\;0%-@QJJ,\=D1]3*GT*<>PMF[*2``+Y2]D1CW*8`NT
M.O?C+<"S3KT)&W?^-3*]D=&_;U"\Y><UZ<9I6WFX!HBI<%/6M!"D&1]NEX?Y
M_4-__HU1M#7$`K3SY8V(+E[DS1[S:=F$Q[5K>[!Z*VY@:I,9_4YAU.$[NI_8
M\FC\SZ+9&[O'Z]]OL-+-]>B7XWB@$$YO92WVGU'6ROZ;?6HBQ9,/,:=5SOTR
M8;A_L8M7S;^2`^6QIOI*<%B`8<="OZ*J@N)!LIE[%D3#_DL^%KXB!G*9CIBV
M'!1-?2=1518,V`<9,)@F@7-/C]_NL&!>&H;S5G\8ML$.(B$=T,M^YI=;K-TR
M4[?&E%RQ[^E9YY=,D5(UD-G;EU"RKUQ[W5PR:;(("<\2NCQ?J+Z86L?'H.I-
M+Z";OL!HON<A6[P;K/^RJRQ5VYB+NU)@^IW1C6:X@.*XH!HT0'G4`8&WQ&.0
M+.,VC!'Q(\[U>)N\KB04?@YO$=X!$.I1E@$!FFRS?7UO"LRJG.A9B+,-$O=8
M%4?MHBO#T,0HY?#HF#HHP=;<Q*)X_8$P!&XY<I7<+:.V+^5!IEC$F?4H2YCU
M:H((]/"K,D>"FH0UZE12]%/Z5Z<9V<P:MYOT@6$_LF3Y2"\)-YB@,)30Q?S0
MN8!Z?(_:09*664793AYHG@P53E>U=M,-SAGZZQ>#ZW>C;?!YOT"Q?KYZ.:K*
MR6ENB533*L2B@[J=3;<RGN6!IKZCK)J=YKIHE4V&OVRCO4L9`"2!:98NZWDM
MIS*-SE()5*9G4[UN!D**]6/[(@9(7T&N`J3#:?JED5<\?[_""]H)"G]3V.XC
M<;^["_,'C'K982LVV_%M"#V:G3EW4V(#R72@3:^;?QH8&(S(1WM9^#^:U'"T
MWYGOU&#.9A<TCP*5(PVO^[:P(,3D(S$EYT7;^FI?$6-;UJYLFSU+!W[V:VLJ
MV@AIQ-"E[0%:5GAU<^RN0]:E^/F;[/Z'6)9WD,C]>@3KGIYF6<!Q:Q[3H;/0
MW)/:.9O5J$VQ7XSA</2ZZ^=\]BPU5V"<XX?<GL.[$K7;&F@F^(,`]9%;:P47
MC=GPDH;8MI"2N,?\;J+L5A]-PEM1,AUAQ:`U;_&&%2''+T'['$!LX[.$]=>O
M`?]$7HOHD[W$%)\F,22Z9=?,36IY,)SH\\EV=%8U"AA"T9$A;B335#/-^?6_
M,LMP5B&06":>A[1GK,_":"5:9/YTWNH[\L$P-5:;_@_DR@?FK]\&KETV1Q*L
M.&69N.,P';9[,.C`/A2&X#-^88<5<)5;7[F'7Q=\O6>4`((X0YF$;XO#CSJN
M*$A(9^^C`K<-0+TB^,/'A1BSW]HQ]1E%0+7`F^Q#(_SR80K&`!Z1H+NU(5Z3
M>=1#IP;[<Z17E69KA2HR,_UHV!;V0]BOM.M&BP^:ZES%+B@8]HGL?!?T+-9K
MOR?[7DE[ZA=0RX5SQX)S8^:>9M*J;NH-=,E(^A#?FLD*N9T0*B5K-CA.MD-#
MRX0LE(!=>VNTX.,6JW&9O,K+N6$R1:R0?B]D\GOU!%2,]-\Z0Q$KHOTSIV&J
M@W)?0^SZ-@N',;*!@$.3\7)%?AF5<$VM&]D:<KG"X8-`%PXD25_BCL-C;X%^
M=K#`7IFG<&@`[EK_'2$E)M49,HG8=?1@*O`SN=8<H4NKUJ(3:]6ME\C'8%MJ
M@HZ"EX3+^KV*G4V5O-$:(N-T*R+]R6F>8[%BX044#=^Y570#%#5\_=;I<H,?
M\KB_8Q_=.;<\R+V@S],YPT4A^OS&YAY>QH8YI'>I0:VV.<!N"T2+5NRF"1R3
M54CZ3H_L+=R^P"T5`M;OVM=]!H-T7.S($Q,GT`KBVP3=`PMO,/86:&AT&.F!
MO80\D)<Q,5U_O9E';Q7K%WJT2/-/P.#D[G.<N[`*80YK$CRKU=^.G=MU66%+
M+T&H@3>U]H\=G#C)G^2*L^X.]"'NHB>)\BID`DI%/VV)00),8I@LHK&=$T3>
M!YG%_>:&R).%Z^&N\XMQ/U!<20.$Z41]=0%H)I_ZY$IF%%P[I(L1*A?I*`#,
MH^\%6<GA>ZCUREJ8[^(8ZPZJE$1G$_^WK3Y%H7O^?BHUPQ=#8K*$Z'^V#502
M2/.=<DQ?L4FVB3E@.%%V'P/0!T?-3HM^?">S%X/G7CI$&6%"IR<^[TW6`4Y]
MC1L:D&2HB+=E6,MAFE2#Y5-=OG)0D?GS<0.782<V0U85R<:%.8\2DIHO"?'J
M,>ZV&N`HM8`I*E3N$#RA?HH,&5_N)A4RVME<N&.RU]@'FKX3[X'R]J!`MSJP
M_>DT&FE>'0*'I##'G'18CMX>0^N9[`"J<,>RA&^>C)R26.U8HP/_\A2FI?]!
M1#TPQ<YH<(W""2#="_31CK\'G#WZ!:LEZ[KF0,(',FU]O;:[6&$0#06RKSL;
M@6=P3Z:8XP]D24-QMR'*PZ%Z.J;U:?1IR$3_"$_2`R62I/_V^G-8OQDDX\FM
M3%#`F7J?;H.QA+";;M4Q4@R=-R-JM"VGH0&2Q(H>NBOK''=LKL;@OW._$`BU
M=?+28P0=+%=#&.'CYZ]<,BS#&6I8;*,CGPEOG=8_,I20$9T!#T3[S2![&H.Q
M<.*2:X^$8LG-)<KQ&I)P:2%M2LGN=`]<]%)L5]8;,MX>S[P?)?`+I6)>3W-#
M+E!8)F/G<[]9<`L6S*_/N@H1I4%Y+AE8R\+X!4(`.Y0>'0IEU%5(`);W[?O.
M%@G)]`^GQ:\!\SCU$R'["GP8!DB8/Z&F`>@>>9^?!]O5@1Y"77NWXE3\(?/@
MDJ3>?`ZK&+AQ\N!]/J":.-:AD!Y-@F-4=#^'4K00^8_(MY60=FPF`J3C:M.7
MZ?A.C,=9!IGOIWJN]_D"UJ\F0DA8%309Y41F.I5/P.?Z;X^*S/F;.[-\6QR>
M'6SU]>S8KB9SDMN*KH_=&U#!7<*79:+'FR-D1A^4(W*$8LU>HVX"><6_9%\,
MCJH59&FB>+W:?`$RZ^!7*8SYSOE4=+HS/#]P:'`@96-H;R<\/PHG.S\^\!0M
MFI\#0YYC)OR;XRP&`S0WM;-4D<'85=7HO&7.@Y;K0&30L%]X.F27.,V>>I#S
MQR3['`-G`A;2\!(@P&L;@NCPO()#YQY0/T"P&O<]S.-)OHCGO<('8(N&U%9H
MI[UDF<5]TEW-.T98<&]2>6,/KO/+:YP9/"9BGD]T@</?J:"6$;98SU3]@D'H
M$%&<BS4DNW3KM)K;<2DW+$%&IUEXZX$3PM>14=,9MVR1]_9B!'A5AS:*+\A?
M[JO[9M:NH?QJC+$KATVG#`S#A2(M[T2('8`/0\1\?)R+7YZZ8#E#;>1D^S&!
MM:N[*$W7;;>8\>O*]CLU@GEY0X"&0H`9*M%'NL*F%VX^R$:-D8/N'0C5U%96
M?4)P-UMHK?HD[(>%'T4`%'R1:*85YZ9GX).H1,=)93EA3Z&W(H?N.QG(#;\\
M@S+QVDE$,YOPYN!T#Y0J4%2K@,B..%$MWM5*@/.TXZ4RUL8*ZLYE.'@[Y],@
M!R-)$:F?><'*#YZZ?"345V)\FQ-#O83K_#M!U*]QW[&<C>[0OTW4,ZD,K;/5
M`YD)=L/8[N?^PD\I`0(*@O\T$>+PWY1RE`+:AX=KIJS#$9GL`.R@&`(T!?;G
M)`CH,$8-HDLS4PZ:ZG=-O%NT!N?5O1*H"@K\+OD+(*"3(<N;/%"1$5]2UWM8
M$Y.2K%6"1-*<J!-ST<'7]+R._Z]&[6"QN4`_]$.PI!1L6'QLF_9<KJ@$U@"!
M;IDD.6_G%U1H9'UW:9GL[O*5$M:0ZP1C2F:0]&0E-V1+S>IZI@7%VZ'#\8P'
M[]ZD`*-2^'@M]055DZX,=*WAIK?>&N]T>IJ]CVVSE>;[DV(M+F6@;0+M`_.:
M#M#D$1,/=7ON_5T351UP$3^FBC"K&RPM_<);@1ZWE#6KG&BZ#A%1&#Z\"4IY
M,UHN6]Q%"E\_*ML$L8X](+F/@L%'D>MECRM@E^1XS@_*V\X,L$0HLIHK8.2P
M+:6FJA&>:,["2[_!SOS:F+/]\O@VI;J2Q9N<F[KVXB"'CIX`W+<H9E;W`UC:
ML4C#SB'+3E,!@"MTHQ8@B>E"3\<L4,E-A[ZVB?\;A9>W`01W6DC_%A9?J=V1
MD]=^P^DQF;F`)E_3N2(=D@_GN@!2BG8JU,P$,*"]Q(-^@M-?6K0XSUD'AN1F
MG;J)NX3V,#YQ&KR!_`S=,F>!,XNC;F#2ME=][,\N'>QX5$M^HD,#P7TWM^#"
M"Z^$^"*<ERY''`6,.2[KS?.;4_YL>N(=BP-A`ZKAO9W+^;+D*T'V#X\S)-NY
MK+)V_5<.KB?^./33VMB`UHRTM#FL5<W'*M6;&[98:-6C;>6RZ(KL(%TOFEA;
M]4L6_%JTYT0#3@F^9)3U\*0W>F%*\_R($GL#GOG>=<*]/LQ;S&-SUXT96EL7
MUYQ,KIC!SQ#;$"@@(Q]::;(!'AF@W[:\K])-L439"J?\SBE8N0JW^LG.$(?;
MO7"8UE`]5412ZO'2:X^/8Q7GB'3XY'O>R2#%7\704O85HV\]!;64J:"X=,'L
M,X;;SJ%UY&I^2-JV$*A!4IAQVBE&^0#/SUJU:=:N.86-O.CD<&G?GFK;!$B%
M'TG:[0"5^1LLLE<`]0FO3*RYLG&`PY]'6+SOL&^4(%WZ0P$]Q$MI@/@QID+P
M8/#?QA"JR\LIRB>UG.D/*EL!YP@IX6#97?D.KKA+T!FPZ_5QNK0%>YI/)Q^#
M^=7;$2-S&I[Y.9TJ.-'EW.T21R%I1$#G;B;_:>Q,EO%^+]LKGD/"VEN$A4*A
M[0\*&S]:&-]6"MFG@=79C?KET@)^,:*';G(H,<.R:LOT.MRW$A2J/]$0?P>0
MTA_5**F%H=T>JU(MN.R;L+B4_-O`Q5YS$4`&#5_DR[#["G1B8AH29@0"FHMA
M1VY8`?X?J+7Y#.J4SL1&X`U^$JA/J]S6@-XJ57[Y3[9,2QA=M4S;RT2ELM>Z
M$A4'BI%[7UPH<:RE$"VZ8WMJ2S'T#`N4`</^-846.7('KF[Y6OA]N?,FO=]6
M15?T/,DO_88GY1Q_G^K*\@EDE(78Z59Z=U*GGRI3T?J:7?'H-O6R%93T'`=(
M`_*@H0SNSP_O6S+D%DQG^WK#-MC3!U)R2[V2`KM[9=CF2&U%$F<;XV=R1K3O
M$;MXF$)04?U_*=*HN-Q)FI)>H<#&>)+4XD(\"FYQ;^%2=)#46UYT"XXRR1W$
M1(>YR[>DS%$9[\*CL7ZN^95B9/680",VT5.1Q:A/$,$\E@,K32!H%<5[2R^\
M<:RN\N\JZ!S<Z'6&E.E<NW:J6(*V3T$Z6,\P@RS[J,AH-EUK/>P5+-RKPV2%
MR;1&8,.6'90K@-3BU&5J1LSSL\*$O>9ZN<5FKV]%.AT3G^PS)N?(/8VJ@G4%
M\SA]`R`_WNUS!L\=<!4?>"M<VH4$4YDO+XV(.<,[L>C8F@CD%=Q*(@!FS49?
M07'P&^?`NLC4+E7'-1WK2B'H2/TL_SU<,?(M+Z7V$FID7+50JX;^P<8?(E_C
M5A;AOG!6RZ*Y9:+^R?*Q*U5T3TN^_!,C=E^PXSF/:.F?3=U4$UKS=J[:I9.N
MT&]PA(B?=DXIXF@,:Z@[M@=CYLA*W)<IG`>I_GN'+VEGEJ<NGOMWL>MLNWZV
MJ98;L[V35/`(_,:YR))C63=:!N<FSG)B42M19<YSNR$A)K9'\*VLC."4:<NV
M1).-FZ9SBK#M>ZK*]D)0O'^>FKL=FS^$_XATOZ,D[V+5_'4;B!NHD;W?VIH0
MYI,9T`25:ND@L=6;7L`]A'L,I4U4CAJ(0MH<^CRWW_2!S/"C;H#DQCRGJI(`
M--,HO*^<QQAUX^Z$]B&T^G&D5R*F?R]%E%Q<A5&XD7^Z[*4S9;-.T[@+]OD=
M%BMVKI+XYAZ\;!/0&0,_9.(N]5O1@HO`8MOOZ%'7E&RKN.COWV)0^\:V$I7$
M6?-BN,'J*7F0!*_C0K2:[$I5"SOI0+;EVZ+@IRMVCI+Z67WC@V)R,97SFHGH
M?^C9+GNN/12AMOA.=[!/'TP3?@\@BW5><?RZMX?$Q7W3;`UA#"./6=DQKB0^
M_$G;"C\#L-&=WUM(CU"V%?KOETMW7Z#5UNQZ%*:]?*>4;,2Z)9LN,B<V[-7,
MM*"0V6.9W,)TLLR]`Y""SR'G]81QZ-%B/`T-N7YU]U"ZUUMOSQ-E3:7OT>22
M'WX@XD0CXVYWKYWMV?P:=R`MLSXE6:)#<[89$/5Z9Y>(#./[T@A?,@;P"TEZ
M)"K[U)I/H7T1+Y1GDZ.5^B5'\]V`F;0SP&8#0M2T)\-2%6KWEW]*6?ABV0Z#
M76I&]K<395(?RR7$*IO2ITL,>1E)NCD@!9=Y_O13E>$F8I-%?>'#4G[^[=[$
MTQ8%6T]K1S,2U$[M11ZUSLE^3LL*+8.PI9V2H?_!B7D0@%R#S@'@7;<#';T0
M:"";G:VZ0'>)_","]G.6U<I(M."9=2ZPMY7*$Z6&5DMY<BQ@"B(02X^777S9
MA8R!"-WGG!QC;80,:]&\NN4YK=)=8XA?^56L/B![U"H+F[QH^12QSG3AZN5V
MPALP(IOWGGQ2;F7H]:4@T]ZAP]-38XO_@DQ:A%7![>68H!&7:.4.8*`3O`9`
MDE.]^N.BBX.GAGS$72YR&&6MS9^,#F_TX!OS5LN.7^%HF:.S!>5*-.<8E'/T
MUY;!$V.C%S&RG*<@I6!GC?FQ^7SK3J;*]1X>@9'CJ.G/>@CE2:$>E]$D^^M4
M)4(G!ACPSG76$^'I*!/'P*]QV5'4W<)'`%IVI4J>;^(9XCFD(4@R/;\3.AMT
M]M`L',,F]&4XN<4&Z":RN+X(@9N179ZO=L)Q\*[5X=;)N?J($L=9J?3.P.9G
MU3;>).GP'TH*KI3<VPJT:N1G#`825,>D']8_MTF7G.-H3.BSV"2)KCKL4#V%
MP_[*7LEKY2(??8AJR>-IBU*?%D5ZM@S<#Z"Q:Q[7J9XHC2\KWNIKP3"RH17[
MSZPQ7@!'5+AFW]0BP^/WE\7S=9I[SZX?<)EU4X_I=!8]`#.*\-^G%',`-_>>
M`B5SZM+>#?_.CN95JXMWTL+'T3M)>5<)P'T+8\0MD?]$-`)0]7GG-*UC6ZH*
MO0/C@#1KI1Y+2L8]+W]*.GVB0>ODEB`6+P[N$1K*9HQMQY4*G[%B%Y+NJ`33
M3M'^@I^K'EU5*DEVQ,_"E]!PN)WU9NNPLB:5WJ7RJ+2]2V#90CYLYL\S0CEH
M(L'NA<X`G/)X.F34=/)\N01@JHG0Y8QFP>,P&=JA?LIPK+*@Q`$UG^P@.O]<
M8:S_CFT_*_-[4I&=!X-WV^(Z#G^R4PT%E;?Q[T!&;#.;SNWWX@Z^O3=CE!31
MWYZ9QI0DCB#D$O=-QE;38],XARA:!^#)C,*P*6?1.*\.T>R%$X\NZ8&G&ZIX
MKG?F8!1[I%N<\71N>&M(MP*>"_LWOIUJ5$]9J];/KXM(E_MF*_V)3+9(@T8(
MHCR3#)56R2")>B`(L;N:9P#W]&L3K/:7V;N)MT()*<P5^@.*S53CV1:.ZK+!
M^YU3)*_/^OA.5>/N!::'\`+@#T@B3><9.EZ_.DFJAR8N_<U%Y4\WW[IJ):GI
MC_R.N8$.H7D*J^@C()8#XY'@+"2B5T>E"')U?.,*CF7`WTJ$,".XR*F]/#"1
M9/'`,$>YQ34+\FR_?P&5,B<T<*_?>)21%P0OK]OB6&?Q-_[XCH8TE2GAOVC4
M=DK)*?-5%^I2H%CO!#=)?LKYHM"X^^)PG'Q:V<X"*^'."NDJ'LWH&K;C`15C
MZZ;^^*5BM<L@/DR9+/"%JFFKX-EC>U@-)^@R#=&N`-__3A><$B)VN6I+YK]R
M/E^[J\E``<,*#4^D2I*G:$2;Q5;+NY7A5%C<8K586%'6`H9PVE8Q&I2*`%`^
MF*J"LC,W-YN"^QTE!4^/<QR,_*1MM9*=[!K@9%BJ0Y)W,2XDV]=Q9Q)['IND
M*"=X]EI6VB0LFAM5='6J^A;RIM9"UZ,Y%JHS+D#-T%OS%C+S&8LZ)-2U=8PI
M??L,,^D_.G7UN`F4>20.#82K)H&E=BEI)"B%$1?H4E^/#^?,XZL[F#?8%"I:
M9-DQS0R,(2E1\D0-9W[^<G4%GBEG"MI#S^J`Q6V^)!<A2@@3OW/(QPM%K&KH
M<D[T>DLC.L;L"SX0X]-4L.9+[Y`9S#+__H?G1*!KA@03LZV>#&#G,92$-$;V
MV/KT\L92'\J57LPZOWQ?7/IP+*4\A>Q#N`ASC#[F_$5<#*@L>LCOI5#2'X[>
M<NP=J,GA"T^%931MP1\6^S(KSDY2F\1Q835C[4>J,"E->%U,Z?MA5QVD+J'S
MJ\71X5A9/HXAR\412-^0M!<1^38S?4>^[2OK63SJ]/,`1B'+1[X\?!Z1D9".
M%+5RL`'&7:SR./;E/6Z%)"QFJ>>"LJ?[0&-B'GK1:I[>]5"46D3H8=&N[;N5
MXF+1,B\;Q&6TTD;JG'86.];S_*<U(D-!_%'/N3A76_TMZ:+;LZ@^TW=X:NN'
MMN'.\(<]UOUW\*+>HG\3]_K<`>/C7F7#6%85M.`:^B6!'+]%'V;O@-6GSLE&
M+&V-\&F8<&K/:S8U,M[&5R&T)D_F:YPOC\!6O,-LLHN4;,G/'KYH\^-?&3-+
MM6J;@^KK7?Q3:3^K'19>.A,.9;,OF%6A1EPKVLU#WHH?U?!PK)I":(L5C26H
M2/L3[2#1D]29"%CL$/<%\W-DA-KF>9]_1&P<S>5OQ5.8@W5D<"!3&"[&JNON
M/'-([:)<+NT!^$5WL,)R/=;23'2+>)"Y$9RDF`)/\02>]<<()5!B$.ULH5Y?
M8BDW`DO'XVV'G?D$-V2!)U)WAYJT-E$($**.OC(=C!9TECLQ6RAH79+FU5@#
M1L&].6U;Z9\A@6L])3H`=Y>778(\25[J+SRI9L@$^S3'#L6'6>%6B0:%C4+X
M&T[/KD_8D+#!6%7"YCVP??,A_LNP-1E]VHE!`K#I[E<%&DHO^+5DO@=;B3>%
M^J<2)_?(-H@HB$D'N2-).2@G[Y&$UG<+S&SEYH.%J]A;8K3+6G&'9K&%Z1DU
M.J.KK_SG@TN7V&8@UM,'5I]HL1B*#5A#Q?PVU6R`]"`)K`':"5NM9YE<Y;_*
M8U><2@U,"(5\KMRJ_'D(,9'BM6@61,9$<)<J`0EH?A._A,9G2N]AO@ZH*:,!
MY\CY!O)22]51Z\$F@:)=^0[E_6W.F6V=P4,A8ZLKT_%,'#I=&U&AOP!,1`6?
M8%NFJ^X-TVILP@[6F@W125O16MX^7P?&R''S;GKEHG0M*!X.`;2B<>Q(U;#@
MUEX(>X=FU(.703./A`7.J;=LS0.4OUM;7T#[P+QM_'%X\Y/8!Q;D95OPN04^
M(S&GX!%^%Y-(`-?)RX=<7+XA4=]O]XM;+"VN$65P=8CGWJC7*92V2ZK-O=.Y
MIE9Y:;Y6?QJ;\.I%D]X%RYCS)X?0O;M?/]E26]6%$+05A2+1>&<UKQ,I#2-8
ML8K"588D3PKB'70C^3EYSPU,F._+ZQ1P"DHQE]$GNPA2F512LUQ[<=BV"+>Q
MI+3""8^K=D24G^[ZP%Z30V"7V5D*RJ2))[.=)E(P7TO;?62GMCQH^6>506]Q
MHKKFH123/?T$3W-'C)44G.(R@`LGL%O`<#H*6!DYCGUCDVF96FMT1SJ.6Q)P
M&VP[A-%%>G)EBS%KY4#=<Y^MI#T?Z9\41':^"`#+W\E9!/UFTBP][TD8?5ON
M_K9[A:=[/5K-:!;QO$A?ZGVI>C]"$['>9(1B)>%'R,HE'3%$RLZ/LU(9:!$\
M!BLF-DP\X=WR6$RP8:D\]#["-)>$JN\5Z9T+*-$(*L8E1E_*;O=JJY?X;B^M
M8W+&(P]<]7>M3D<G#)$'LOQLO^ZA]D7@R8WO4X^^+D("(0.WK"SLYHP'E5/X
M.XMQ!,2=(U3J%4#OIDE>%P2\P8UPT0[&P\_[@QO8H8<G;;_*T:.$+GP(Z@7$
M&&P3=K+4;)*7A:^%9`RQ__>64ZS_Z50PH,?Q?[W,+,`"`%(_IF('@_X_LWLC
M;9T4\DZPPM`%F.P2AC*Z`M"5=^I=LJ7H"!IOZA`+*P:ZT6557KS_6%4XDW0H
M<3B&RXJ@P@O;OPN9<JS*)^/>!QX"2[7G?1?EQ6_"1=_49#*DX!Y(JTJV^*WJ
MAD,7]$AUY<:81*,3,T]]RGLP'%E@\%L5QS==>\$FTD<3@/FIXTC&($;#L04V
M1-&NNGV54MI:+(0@,1)8Q0)()>`#6*XK9)XQ1BE@E,%'';G87V/0H^DXYHGN
MUP\E"S5$HWLO3GQ'BGI^#2VNZ1=M6L,.F,8B4>JU0]$JI/Y%JW?_"SG&O0C@
M"Y&[!5MB[C%RSF5.>>/+$"P&TI+M%]*-NPTK>17$/-GV-?6I4<C8T55E+>D5
MXC7"^G4?,PL66K#54CAS!<Y!.TW<(<%AEHX?(&>-ZP<$D5Y!&G-@=7EU\T+Y
MI"<G"[@K81#26J46]TS+>YZ/!R#TG/3%_=P8_I6<D2GKDC+&+YSI`=YI-!AF
MH\V9C?3K`N:-L#F]:4@F=D96TLZ(HT7%099#LA<+6FXU&[OUO](!R3#Z)Q70
MWEL0,O(.(!AA^^#BK-RTU:RY"3'<\3?\4?3P-[WB9;!<-/0QD^Y7OB&Y=Q:&
M70CMC9Y=2$#&1!PIH>"?BM5OH=V57H\68<5KHB@'%8)74K).7;+-]9*M(APK
MQ3S>EDO739Z8.B/<A+I7,]6@/]2Y+OS7M[XG!4,;$7V,>6H=RB28N9?$PF;P
M7G7\6M`=8=):QWW"`SW2<WM<.9;Y'V&)4GUOE"3X*6M3Y?'NT6N[8_X)^\&J
MH1D&S$C88WX-I0RZ/-1,(L1+U&GP=5R?T*'B1#@::O8ZUTJU#LHE-4'DA^S?
M2D*%)7[B6J"@7+M'4B?M>5G#D,B[+>D+<S"ART975;.E+9*3;Z_")6H]CXNM
MMD]'UM?@K:>3<(\M$)GK)#%3RY-YRK!*8%5?*Y&A+@>DE/9;!)O"[Q+M]#MF
M26+[Q![&[/.8(<!RV?.[E.>3'W5HOJ'N7CR)'WJ#Y],XR$5'LRA3PE^'LX9T
M8679U9M,'?;6&%!EP$WF6@HE.F*U5**5``TLA82YGP380$4[$N/T<J>X$3G>
M81%N%LM);"WIK&H!&<.8KQ-$FL,V(HG\-_2Y16"20FP2&WT!@0MA^A'_009;
MD6CNNSCI3+STJF`H+X4XJ@)RL":1<1![;<Q@S_\S#E.A;64$1ML&6;4W,]61
MB+;OIN#^P<55N8@Q`XN<9CA/L9\7+>E!/*6'^,L5T(/"I4:!!NZ_\A]IQ53$
M7QC:5$!KJ^^:0HN0L*8,;CNRZ,W(IPY8Y/T2`5JK)[BVS]H34O"O7Q+DA=ET
M?S_3R[5#>*W`MZ![?+0%9=P33]9G?8^0->%&&?Z34?8E"NY_#!K)\)Q<'#^*
M98&.RT-X6\;DCH/">8T==7-493)`>W4,!GO&M)AY31K<X6@%L"G'Y3=.KM36
M93&$@<1K'&;?Y&=$<<^"&:#IM`E\$*0U#>)\M8:J<0]`;@$<4ZG#WP_.!W?:
M'CR)=,4$J)ZA$FV96HZX-S%7@B//9O`YEYB`NKTH5ZG7602`]ZSJ"3>,#$T'
M4TD(SFOR(E`LPX]E>`3B!%U5.F0<"'74AN)5SKE',Z>_*;889-6J?LL[G5N^
M>,#E2SK[WFI@Q>O`?N$Y<8/$X&O4PG80WT8X3)\+11:/K_V03'T#\_R[%\"=
M]2Z5S[S5[G9F(0S1X>0+#!I+D9X=6G[P:934CEN;I74%IX!\%M@O`X-M(Y@N
M=S66:/?#4TE2,XH'DBA9(!"Q5;+DF@'[(43TN-X2/P`*"TC[+5`GSZ>@@\Y_
M)@WF+IL=$KG\GSZJH:S'$BRB11M=XUKJI,OB/>\.$57CD-,1!J>=CPDEB=-C
MK.&!5%(RA#1!*<QT\\"(1M19RN5!P;F/?R-+X'@:X9+*RY_XA.`XA$1Q^1IC
MG^Y,;AQ@91)_DUMS)#V%J=`WA1@6D'=R@TC+.R<^_-WO`A7MDU?C0O_^MXWF
M8H28Z[BNW(>F_7.FB'Y,B<FZ4Z->D@(47,2W"+<*0)""5DVXZ&_Z<+@6_._;
MR9@3?%^R^,I90/1\/OM^6:RKXW^6$H=Q6K.QYXSLX8TL$`U_+T)GYMU6Z]?@
M"0\4>:&I.T+\&PJBQ=6[W190<%;.(,Y+Q7K1[.N_SCM3E.IM$6^RYPF'Q'9`
MCTV@/YBN1$9]NTQNF(CQJQ!I5L%CZMB`G5XXP#-MFD8K&_1=Z;)Y8F[(.V"6
MUS03H]:'&[>=N6_-3*YPM9VQU;-;R<7E-YX*3$3D%YNG0_D%\^DJ;OTZ3)V<
M*NT.]C)(5O8?@`]-T=8='7-$%6KOOE$NC[!Y=][@_2+P]\314O_NT\Q,WB?R
MI#APPSL(%66RPBU'*WCA+5K=:VD)G#NT"A]W?J'M?FWO@)(^4\/"'K0KJ.:^
MPK%CHP03C`[(ZEE/6+(*M4%ZB2(R`3_^7GO3+4G9#>CC'U/*-F[8TSC-JH.3
M*S/"G-2Q.F)OIVG\F>R<B[4?1/TKK=::W0;*1Z1T/:O::2X.@96>5C=11LZJ
MEVMXPL!)$W=;D4Q94DX1[-CSOO3K^2A;%UD%%T%?)',_#_C9\9)-6%P(9:8N
M6*<.W3GW4E]//8P$ZIW*:]$,\X`X:H'<B&5C']/^?0^4Z41@I4>SW4)=J,$5
M)WI&:0CUS_<*`3,?ZG`.X@A5K%_6>\:\&W;A?!*ABOBLT98<#[7^W),H[`I8
M4_MP252XM$R<OZ/J><#X%M#/0L0DR6$!^=F*QALJR]FI!6HM?K@?#G72R:G8
M/H)7-QH>Z_DZ4>ZE2,<V-TLZ@@J-?CTQ0&'Q/'DQT7Y@4X!VB"303)N,V8;=
M?L=2@1W?$_H^*Y46'2V'JUE?D\U0":LFW$)P6R$9$.UA?"[0%]WN>WF$.U;K
MX.74DR!A?F;^!YP,I_AK\:PW&*Q#"ZYI$197]HFV/PXE2:46[(:!,?A%E$(Z
M4*$.CIK8V[=YT>YGB(FKZ>5QX-W+Y;`;(*`#M@=J-W@T<<1]C4^VO?0G((GQ
MAMS9(2G['39E*D_\\Z8M+S*XG^#H1*D9GHU=T3&Q+TU.DO$.=^B:O543M'/&
MP_1ZDY\BIA*TF;%IM00%7X(`FN"HMNH[#P*<P('G>+!.-<D(#B_,=JR9KTD)
M[`8B]1N6.F:*6&@_ZD6(Y8?>51N$?7V7FG5$GKH:#G4&6]4=5[D1N@!<K&<D
M<<^Z(2=L9T?\C74R6("?`&5>Y`>^B\:%>,\,ACH^<AUDFD%8]6WW1+X,]K2*
MH8FP,TF55)4VW0MI=8C%L0,+O)V9F\*]ECHJ`&L^]'VAK2B>K/,Y2D,L,`1E
M%74'N`DQGBHTG0E]EXQGQ3.["NTAB08KN-04#6*'>9BH2-?3XU^**WTBUA^=
MA;Z8<$%1J=!6/)3J;8>WZ'7Y][4$Q<<<464QTF*C*/E@)N>82<U5)*PE<U&X
MO9DR1..4?SHX($OX+V?7%C295O)S.7WC:(\[Q5GA,JV@)AQL'KE[O*4S:&9&
MH<'PZYV"F8,=D#]2XD9#85A.[N($-A@8F7,!^JCIB@/ZT[C;5/,9[J">B749
M*3F-9ZQ@R^4U9[BL3MFH5'L4(F9K=\6Q#?CC$C);35RB!&[2ROK_"K%VCF8_
MY\P9HX2G#L02U)7:/GD?JY%?"=&#[W)%;Q[$)S)#PZ-XC>@P1@G14)&T(J0\
M/:ZK]V[MN]J`-N4=LAYQYV%^6>O+.@O=%]:<M=U/E,_86)N1E`4KEX;)`_ZF
M5'#'&-D$(^`>LL@76,VS&D]NBIB2+-'$`;IQUTL79C?T4?K<A!(;U/>9:-R2
MOVWMV3S>F/JA+4_I]@LA)$C$:4Z*?=9AN(HOLE!1]AVROH<:^_X'P$:BO78T
M\X_&I^N=\?AK^%X%:I_\'Z`?XP&;(BL??Z54[^[D\NRF/+_BV%;!GE*OP8&H
MTUI+U./O,H#L`M4,S"9PYP[7?;\J)GDK#TK("$+B,;.`_\P__;-P<R%MT[5;
M/>3>+.'(.V,;PZD6;H&*;<I>`"N05METHG_9K(2PMC_?U<B4YKX*:O,]*+G_
M$(';-A4U-XA!8TAUL]]_T]8J)%@^OG7*$5E='B],G=PO)<7X"99G/S5XO<43
M1HY7KR"?ZU`7#7+4M%VUYB4A,U-Z]4N=!\98^UV8[@TH;1?"1P_\5:<<B1(M
M8Y2Q#+78'15UKT59H/(IF`A!P*OOT7=1SFENR5FH^*5/R_HGZWIL]$J*DK07
MD\Q_?+[$T*SV%<_B&UJ4$93XX3<2.J@RO)C>A!>,<RX?,]?`?%#6("4XV::I
M7'024Z/XOC1P3/);L<50#V@9ELPT\8Q7_<V.`.KW:M441.9(T]R2-'OW%'=K
MM,QVQ691[Q9:+IJ:C`FL0+`Y/WZ%Z*P)EZ&7>JF\(XG%Z&TT@2E$N=:9D0+*
M`8P+IB\>YU21$L%Y3S5TL%VSD/OZW(-]]9(&)]%[U$Z;/*KRZB4'55CU:HL+
MY6\LT55?UA-PCEW%$RLWFE321>/?3Z<ON'"1>N]SOS.@6QR-LBQ./?)]>[/5
M(!`IJ/BBADKV("%'WR!QC9ZQX!QSUAL4Z[JWUKDQ/:4^F?D?K6RKIP4<"O,R
M_+4*DJ9.[$>(K_`<@OL5IM8A5OYT\:IBTE"S'6,'2F892'HNYQ!Q(0=1A_\K
M#7('',WASMY;LMO,(HB)+9%XDX/R]">V(K+U=A>)HO%6'C0#JWK/$:^3+`VM
M\+E$#^-SDP)WP$I3U+Y73E%P%%6.%WV+;LQW.K+I,]&!"J&B[KT$2&5Q:*<"
MKZ%WOZM&ZU(E>G]V%F&7F5F7IK?DU$H&1_^D*\"H$6^5B0?5R\+2PL$LE5]8
M@3?RGG'T2EB?Z8D<RJR^PQ=;DU&8:[W9_38F5M97(4)BAL!NWX6Z`U6Y$E%^
MS@PED8I5RS)LE8-!+OR1`SXP\6[!P-2Z_\L*YS)5:<-6K]I$&_9KK"!Z5W(X
M22Q!<W(@:?36$%YG"ULKE,=M7++3'NVNBKC1*-(]YAFXS7]CA/!LE_?Q@CH:
M&X\*@'$WBD()D1(L*='FPD<!#L@Z*D3(A)`6XT!!$.R`3+CP:>PY-E\ML#ZR
M'1[J%9HB]*!!$GE'5>=!(_O=+!2)2&/+=7L*,631W%<NIW8R+T7+7P#*,;-9
M6J*9DO`T12NXLLP21\A1DAQ5$HMWG$XKJ,O$PD9^Q784"Z(H7VI*;S+JH56I
MA^K`G"3N%SZP&,_8B'+MZ;XQU;?!.8-O!J.0_=%/*,)-.@*NU^T=<AD;GLB7
M$GM3]5J?L=ICVS^[)XL>+$'8S;`<&KJ74)G<6T=&R3:!3A^S),/R?Z-%L6L4
MF]TD4^(`\ZS#_-F<*SMX%E^A9OEZQ<FH]5\BD]J)7YI?3+["&@6'`C"H=,!E
MB+[IKUEU&I8$D%%F0O+[SK3X=-1@$_(R+RQBZ^^;-":D'ZG,88:,]'GC+*[I
M(6,M8@*NYZTE&0>P&*`M,ZPOHF]2XN4C-BA8Q)E0E;FM[1(#@/G*GM\.&^@#
M`4`^NX;]_?4)FN0+7&;8U3V8.%&'4NF*I'/O"WFX8_25J^IT1AV5%]P+[,4\
M[$/U=O5,N`S,E[8`R3LDU^YD]XZGP#!W;G*B?`?H"0<SA#=$+X@RW+W8NSXL
M/(5DLW9(IMY;0)=(M<]]YFD:=!"B_RN%)[-#K<&Z$G@<Q!9^#[:DZ\-L*JZ"
M?M7'RK9OY'CVU.<_REML[7ZCF['\A<5=ZN+>2IT6A'`PVHL$&5EE]@/^)\<)
M3LO2FQ'^P*JTL\L-N-H2RO0Z!"2<:'&0KWX.^A<!YAL&\M7O&C^_^@8_0/;?
M2=U&HT[/;G6]''2"&/3N[O3IQPW]/K<<>5&G\OL@7$;('#M1="D4"HGMI`C<
M0-C_@:3S'M%&^A#U(]CY%T=*WK81#GBQUS>;<O:YF<U+D#8<`,FP>PUT'OXR
MOU(;`BG_3.1Q1_5C5VXKYAOED7(<84IUC,8':,&7Q7+N$H+B5:DCBT-QCF>V
M;D;:O1V)B$*04'4?0\S\[GL!&0.?3?!'V/Z%`\K,H0RC=N^)GT0=&T/!3W?N
MRHMQ`6?2X0#N[A*7499H(R'NX,9\[Y"YH:F4H$^@VG>/UPP0E$'8=ZV$%12,
M!?D$Y*TB<IMWJ4E#B6^94L?`V5GR9_FK)_P)#$M:_4"=DRL<>H?$$$G_$AJF
MOTT>NQ0Z:1P8BJVR3'$`7B`(B;M9_-4VQ%J_KAP7.,"9;]01`DDFRMJ_3)"1
M!RTL]HU8[J`Z,")[7^`A\,X;M]V`9$8*U<Z$YN//YI[P<=&4L,J]4HE2E'%"
M/9GSC8@*]:87<U-:67]X"$,1=]X_#$B*(Y*><"=)&M)0^Y>:_,UC@U2.YC-X
M.*9SE=;_'78_"E&5U5E.^#=]X\VR@^(_P22QC.*#'=D1)<^]4`Q>?<6E\F.2
MQUYQ+#T&XO49DX:;0Y$P$"U!N>\[&V,2$TX>WZ=6D*>F"@];0[XD7N</[W/.
MG7<&*_9(G%<W3*9@(\PW1$-Y`7T%Z><E,0<FRPLD=PB+.#L%KM-6HY0C1#_%
M*Y%K)@NRW;H5'3;L8_17L@,74?L<5$!*\MU#TKIVN3+='//^:\\C"KT57`@^
MD0_M[+EIXK9`52<84BRMM5F5<HCS#T92D\/Y*50MLR_=L%KW;%^R(FQYCWCM
MZ!FVEI%1TUT[Z&!MX`&QB,9[W.U$(46I?$6T/<:(C7HY#[%J21S4KZ!Z[R!*
M>][OH":JM&P=8IS2=I[4'YG%%38RG(7R<"9B,@*26>B<+J,9*0/D",^:+*0(
MVDPFSO)URA_/.&&/K=^NG:(9+PVGX1HJ\C@I&@+TA/LX<PLA:H?YJ3$6F0"<
M55))`#/UMV/(&8Q"/$V&O83.H=&`0Z2^+"A.`LD\,/$DB7]U@";?#^A]*QJJ
MXX7X"5+]JLM!D$>J&0TZ9,)C*BSM'H-*!DA/PX)T$^6D)C.GT*)Q;NKM3O?R
M1/GDL2RR!ANF._+*03`_3<M45WGM>O.GX:M*MB8GT"`IH1VC/Z.#9!5W.^L2
M=DMI)JD`2WWV_+,%LK,=[1+CI#HU+@K\D%U)TE]MW,NI)GF;R04>Z5S1@,I+
M1S/0@X?Y_,\4H>X%)HT`^PY]'C8XS_/$*JU3^50S2[\RXG0MX#$Z,79_O$`T
MSM!]$XKS<JCY#G&@JV1E4O^I[WHPJ)"\(.CPCPE>Q4*/I#2L"O(A&*M"?*J2
MH6FAO*6RUW2"[C>V^2_[^:$\&?70?XN8*O]EC%2QX)W@D4<"5-R87H,N:B_\
MHR/)_VZU@_=<-^SI"_3V7C7&9Z)QX;Z"P4[OL-\1*@"]P&H[TGNJ7IAN*I/]
M`<K/BD7(M@;0(0JC77>KJY_2CL)8/+A5[[K_EL1KM05F.G)XYY03+SSEX#\S
M^E%JU]:)2GE6L2,_">2VC(<NDRRSP%)UA,#>V;YW*VW7K9\E32T@7EM[7\\<
M!5_A>=Z+B/6X[06[ZU0:2,9%7YXIFKG:IY6M-%<R:F"2'@;!"2?]SJHND1VA
MD,[KNB$U2?Y927K;$6^`_+!P56V'BT9*F7#0M+>+-2=C\SI'$CI/JQM2WHC?
MM>MR9KLMW<"D#]IDKE*[Z\U$)T6Z7YL,8`^B!J6H*+T6VH`PGNN%I71$H?[6
MI6!Q\(8GNLKRM4'R<NB3K6UCP'MS"?!YX)X*WG>N&&7:&W>#L&I_\\?;-[R9
MLR+:&DL&[O0LNJ>V>X'-M1(F"1"X]KWI<B1K=*<E%D7I9MG"58NA/MY(+`Z\
MG\:Q]HMJ"+DD0Q6DI+%,F"[>E9A\+$W>L'4YQC6Y3<2RM)6<%5'_H1M\V?'5
M;I'W'`WS9=Z^]$4;,&*G?)`24*F*-7?AUZ(@@:^!)[22'?7;>;01H-HZ0;NO
M[6MXVX).TK8+9/A3='!J4&3KFM#]V5ZHUSWZ[2;[O]EI54/._9S?'Q>A,D\2
MH*5-4WWHR2AW5K,?AZ>FFN"GPD\]"),UGT1\`+R+WUP)O1,;0ZB8G7:#QJ=[
MH"?'+7E$QU;L16Z/Y_JQE;%O2*&4N1^`,?F3@YV"9[?"!CDN,[%XR4L^B:@F
MUZ39H[/Q/R70#+(?9IJ[2Y022BT=V2QKU3X6ISF$8-%Q;_<V\GE=S(5;+O8&
MODRNI<<#SWOH'F0QZ!B6U(=0^SRRD^-F)!Q0=,0JZ#X-WUGNJO/61(`0Z$^H
MZ-ORF'@8M2]=E/^0'15B@GG[>XOK0*%>+1SM85P^JL,7LC64,P+9[!9B)_H?
M_2B5K_-@"1#ZUXU5\K4E""!CA*N^5LN2U!8Z-#1#O]#V3ZZ,5304UQ%F+7Z\
M2;1E7TM@-EHS>:D2OJ2:2+VA;Z5X#R4>Q,1,2]_R$J-R5\%VS'],Q(]L2VYL
MK8-2`$/4!]&N2V3N(V]]&:UA:I>*!2/A(7\"+RVM[GMMY">3L-HE$[-F[*+)
MG!KP[9I=YT/87Q?"F,2ALPS(T\/Y_IO16E*@7UD%/#HN4R&MYA"!<ABE(E7.
M"XJ(@SE!X$PK35'ZY?.&K%R2:S*G@\CXA?ZK!43,LQ.F@E_.8)S>\9M!RI*V
M3I2?W8DMS5VE[`5W%R'1H,%Q$A_0OYQW<%4UY>?QB!II/.X'MZWQI-:66XF%
M!F@D-Z3X=T@?&BUY79D-TE9^1VM9$:FEURU%]41C-KIOS<41E*))E\)`<'!E
M56[G\[39`(_+05?V4&%*L4&P?P5^OA^ZP=OVIQ#JPYJA%BCV&J&\''M)0BXK
M]#.(*=,RF\2L#-Y1:[ME0D2@[Q![TA<VZ`GF4N/&@W6Y_[JCM+@B<IN=D-:\
M@J!X5F=RDY@HE;/%BC^&K'GO@+Y>SL5H?L6BWZX4+2LH>:NKIRI^A*>`](E1
M64;U9H#7B(0O/P8/Q0RU!!3R]]^-'895#Q?*D1RPX(70O^"]B[8U;:TC$\34
MP=YCJC"E.E=>7751<V/N?O<]_<`S:%BGT@5)81%^I/;Y.@<CZR8[!\%$"J>[
MU)?L;W9,L(J+@UHU'$$KC56TIAFKH?OO^`=YQ'E-"2=)I?6)C2M8_A_Z:4IN
M#)X27V7]7+I+7R'C5*PW5]S98)+;.J5GJ\^R#M&D3%PN0\0&U=*&MS-AU%<V
M5>$)Y'9TGC'`D<5&QV$A$EKDP9U97,+K`F+V.#RJLR-2!M_P.+CF$*(9]W?;
M#]*2"]\B%A7G$@FFV4<$Q-_<I>NZO)T%#CI2?1,7HD_\?V-G`G.+OOT[&)\,
MT]`8E/I-Y.8.WD7,XIB%)O'<G?Z7.EA%4_0U7MK4._N`K2;@KL_B01?SV>M\
ML:I_<^`!<U`#')9DULJ`R7..R#4'Y_Q;RM-8D0<E=4OK6_#!.BXOMNJFC:.D
M_`3-2TR%+UN[G#NXZ05\RTSSB5+X:I/'33K!I<!CU%F#E30^"C_'V=HV%X/+
M?^2IX["YX`V!XIFOGVE>Y0_VE["Q!W]"@<IM\DS=5^:)EP!HO9X`SO'55^^`
M(K^RP.A2J<;TM&O`*:RMBY8U9*60T2:(^KLJ<;O<=.5MUL`VR[')7$<173W9
MCQ).CP/%'K9[E--&&(D_%;8S6RVM0QW+8R$>6-,1:3\')=:M?-TTZT<.%BV.
MB&'5W\CN+.5X6@X7^"CGN?A#_M$ZH7N_3NCZ^30`Q7M.[(N)6/\A3K7^_Z;A
M0U%$ST1?L`9?$KN07WO2!VLZ8[5G<.#IJU:VSUL(!A/;GK[Q1"IY-Z`+8HR4
M(+-]I\"MHL`]W#M8)1?CTB&\7!0"PJ/;A39B48R*H9.JI2_`J%_A\O3+5?C'
M<Y>B="A/G)Q]1=9.?IR&<:7.UFQRGWGR`NI8IH8:^J!OD?3WNRIH&&*/VI-4
MJ[(.A4-MU7&9/X:=?^E>Y),E2%$:O;H/PJ<`43CN!)8OLE4RI>Y5K1RDM#XA
M%_!=4(H`D%WK5F3O9M,*TOLN4=YYVA+6(<%!V(3>0/H>.LE>DN:\R'U7#X[K
M5T4`C1.P!<MCX&;'EJ>C]];J0<$1N*/8\&_\%9$;H+<AO%HC[Z)6_WS_X!S6
MMI(>0^Y?:>\6D!^WJM#L!0LON=)W,ND?H9G^0=NRVB7E@F6R?+T(EQ]K?$!2
M*%L4<"0TV(V9?)6D4$A?'.UVP('Z7H6;>T`OL.A4[5=NU@[)7%HHBE)19?M6
M:^JU56B-7Y,'U<;M".R^9\#8=M00RR^TYE5];9M-`9BH.Z?I)\7>DXHF)!["
MB.D8`XZ=6TIG]<F1S]3NILW0>>#0#-!5#S5""#;^9[N'H876"FW?NR&GI(VW
MRSQ"&C_4Z0Z?U"T"4M/DPL'52V[L@6\_^=]LR>%+2X<(:S@ZJPK:-,'),RN;
MOV/4^\K>+06E:RLG,<[+6B<]26RM&V2[`;!BO5Q8H.Q?MF6JO<>/(GD+89L;
M3T?[,FPB%_B0IHTQMWU>/9L?&&S\,)(B8]08)H[FC+7><X6BX[M[:?JKDG^%
MF45LOL`^J@/-S^'UC6LS,6M(:G:1\G-]^W:A8&DE1A4TX0^J))T^U;S(HL-4
MW.DVJU-RM*BXK329G,^CIW5'56*5ITFUJ<R]*HECZ5IA+D)L0[.'EAMX+KYY
M$(SEP<8=Q(0=Q3F_]8W.PY8:&?>SK(&D>Q>K7^/@!I]ZJ1'[$U0"C#)V@$AW
M(F<.^>+RP^C&X]@WD13$)A@I7:AH$.5YZX?'N=>\;==X$-0F#EA72<L>YB*X
MSK$"VG*B+\R,V0-D.?C$(8C1:&#-ER>BK9XG&]TLCE<=?U'M:0Z\8`C*:A8>
M&QV&YH_BJ+FL`J)T5Z^2?/HEC1$.E0GYK@O<,(.4#<OEO845<&1$'$%;*9;_
M&3QIG[OM2F#UMLMRGDH5TB)*@+81NKY"[CU^A^%IKIWIXWO*KAGK=Z0&FU]B
M/MDD=9:')`<V!`W<7!J+DIOO)Z"6,+RBMAMSE9;TI<P<'DGJ:$4P!9^B%_JK
MH'U@#>\F'`B(9B%&7^OT,9N4WE)N_=03C?Z?YWOP_ZC=KO:P=:^)MD49!06H
ME-HU750].@3^"G\5UUY$(?^L+X%VQ\+7QE+61XZVKC$7#@1N/D[1?+?U`<VY
MGI[1&];0@8[@5+G<X1Y+N)40/(;[P-3O1!>_+%W?O*Z!WM9QKF9B.##(0N(O
M^&T@A&-_%1HV8`:5;V'A,*]Z:\]G#%O15D.O*0,+:=R7-6'/T@601.4.;[>7
M:E5,S_EY%1]4@%BLG936.(\P[7\D"3+SCF!+$Z_P:"N'.V[-'M2`%IOR[BKT
MQOES9:'7BK8T5$@6/29)^9I$ZB(O(>O7R/")A0C,S!VE#WD*(EXLTD2-X:YK
M^/0T(`>KRZ*Q2(=@FQ4#@3MC!Y34G)@`M<._+C/W(=C5E;03XDI%C9#V7E"R
M7_=STBYYPL<WBTE("PX.EFJ:+N2Q3F-A\[B[ZO8\LD24,,T(_^X"-5LHR5M)
MDX#VK"NK#WL\A<KF8'^&J<D/(89F^6CT&R=RU_ZE+0Z;)!WF$.;P&'?(`!N]
M,V"Y0+:8&OI[RS#SJ8V[@$;!)VZ3H&*TQ52+@G0CW"-WY`&G>59/>K&,Z65^
MUD'?R(GUQ,&K'2B8BY.=X?S0V_;4+H6S:M159!X`CO_V<L4KF./\07\*45*K
M"[(G!%Z2)/7G<GYW!]\VOY7+,^XXC!0*TZGZ)0@+:GZ6QK_;@E@'K-KEUKSH
M(/MV9#\<0CWF,SE2C/SA5:N_'#]*A^OCT!=->IX6NTT3+=9WU'<$[3`^BC#Y
MXYG\A.A2M_JA@YW_^<#ZQWS4ET9!3)JE:;CU;JEHMU`+7IMT_FD+F=T;G\)@
M.M*_1UT$0"(2@ABF:=WY5=-\GV,QG2U@&EE'Q?")8'B%(`:>05'[V(OS.FU-
M49=V`)(78*DI/NXKD7[4.1:FIUK>DP&^6$U+R*`-#O9'Z8I32\/V\@!<<6%:
M;\>B.-QYL+",)F1!E5W6:4PG0^X&.D'M5(:`@2YW=3-DR!VG+;(9>:ZDO(F?
M@RH^O4[1*+6)Z^&[1FQUDBOCR`(#TCJ-]&',:).(7?WB;4O%I3-CPA#DPB?Y
MRZ,U]NZT=_9%Q;P_\"F(H'VOEH=)GS@AI9<$+L*[2@10>:'N@Y6KW:V3H:@W
M[Q@J:@O,LU9[KPP:RP_80!.2VTWC9]XSPJH\GT&A;H/KDCX.DL:I,ON/_LZ[
MPG":Y&3.UB/AKUFE1D8CA2U(I`X!,`./7]:EKB.^8QS>H%<(-O3($"^3\'.U
M)OWY."/2M?@]2Q829__X!9'3-G@<EV/TFQ%1*SYJNU/HCGBN\^]-62TA2DST
M5(!_)*F>)K`(;<G*?$@U%3Q+?IJ-2,#U:B^MN.[M#X+`"#OO#9X;0%\7WDWR
M)FEW3[0I#K_4F2O3!!">;B'0<R=4VE-$CI900D#O\I(3?%U8A>+#,$ZH>Y;5
MUH]7TVT2@@"/B7A%[:7_IPLXLH5<0S"4,)I*!@4H7CHVZV%&XG(N&3QL]_2C
MMWJ$^`35K=<#U-D?NX+ZD?B.VIV<,$DM%ZQZIPC`D,N\1J,TN0921>5"N?Y\
MY]V!U(9C_[WIBF_$AR'TH[DTK[:`PH?.66=3H"Z9+/'PD[6I>W37,O!AQ6J+
M#"O8AHPM5>/>_QNYVKV7P+3==DXBT6FDD?A/7,C<QD":G2<+#./P#'NK,C'.
ML*![GQT%RKI=8&T>M&W*,`[,?QX"<L.U#/C6P\>2W=-+YX'N>.)=D]N'T,JN
M1J%TP&(]HR,LP<E+HBX,HNF6Z\\W3G0_I/L^Z/Y\*7AP+#BU(-2N6OW%][C/
MX^:.)SVB!5]UGX0@$C*!5.^'M:R4904RE!7=Q(*"AG[BPA>AYD6O=O%'T9KK
M%WAPC$*Z(L#H^Z="\VLJW9#)/'>#F"T*`K_OAA*YS*<FIM2RC'E\\X^3XM?P
M:$^7V?@L$WD6H@7N,`_\S.P>?Y6SQ*@DMM*N$5=[-S9W4!\7$[U>4'W4P^FO
M!P5!^]2I`^6'A#(JH*VH2;0>27S/EMA#%$J\X2U$AX:Y<1A?LMU#^O&+")<X
M5Y\SP3=W\*D`;+;Y0#+FZ;OQ9G7H.AUAI6YKW5.NYTZ?_G$F:RKCWM%'2]EK
M?`KGQ+7'SH##7'4N5+S$O*%*@GH'1EA''`T-Z63:W0CX*KH/Y5<>:2W^-'@"
MOCF;\&;.@*=HSLW>=9(0.+V9;*+&(N+'.;'W?T(MJ3V4R+0GL"'N2G(Z-5R<
MJM`>3HF_ZLHAR2#L,31A[J0+AJ7409GG_\C9!W7D#M>&&RS8<,+,OEQ^S'97
MY(&"VL=Z$LB3&6`_.4M2MR?-@7BA-1;(%&%FRZPY+AF];C.#I>I(VQ-S*#H-
M\Z"C4ET4V<8*YB.+1_@M#332HAJ(,?=Y3Y?TN`1#<]=:0Y_>#MWJ4=W_K6(.
MB6VJ<`O6$)^A8VKY^*!X6C;$[7D,<Z%D[.[WQ5E.0/40YW2/PI51,K@X<GV#
M@,O<'N9WG@_!J6$J/O.C'3\\&+NQK2:+SWJUDDH-D)@+]/M`&G\+>[JG$^0C
M.]JK"A7'I>K#N&5/-Y=EUHTZ(7(\2[BVC,THVFA7]N6<+".RD.3_IW$,F2:(
M#./RHCORD;Z"5`.@5T#L"YCX>OU:=:B=TD-U'&+Y^L6<C4^BMP-(EM$LN_P"
M3\Y]Y(.1D5VE8^G;?)1D%<"([)";5PQ2IM<CP>L,]ZZ9+[&.`[<VAB!D`667
M98,7VO`I5D!7_N]0/K%C@?*>+$35'-@;4R5FW.@-U=HV$V2E`I\$K9L,QS)2
MB#1PL6?6"=,BE)BPN;L8;)G)QK,A`\C=:MH(SY$)V':[AWD3'"6A!HY4(F@K
MQ#'E>ML57;?<@XJD-.1VAP4=V+CVQQ*[JSU:U[\KL-!+1BI>ANC)A+N09T*@
M[4:-F9#@5\U[.M4J<0.X;V&^`$.CT72E-)*JE'>T+6SHN8B*_<GOR"D!!3;7
M\V!T$85/IJ.;<`Y(ABT!*S.T5PMD>5))S0`JVK3"O?E59J`]Z2QI89.Y\WY;
MJ$0Q&+XAXF6G0,7^\YUS*;@'+7\%Z\HW)`Y[0HC\P#D[5*@E^;\T;YI7R3M7
MU\4X(,9XI70R0>,VL2$LHJ`"DU_&1F,4)O+M796X^*%B6#@#/#(I`\,KJ8HK
M2QHO#=\`W2B+9:#$IS07B$3S:<#)B7>DAJCQ092@Y$QKH/A3W^[CD7.B,5_9
M"DRB]']/B.AB`,3]-H+2]`9$1C,Z.C*AK[F^P?KAD\?PHRUPD&RZBC:XD>?+
M*JA:KL2<8_L162J">JV3J)NJS!1KFG.SKI>RT&6X.=*.,=K/72O%B54'UL"(
MNKQ3A1:W`E.-[#O4]U:SJ=E*B5L,QX776%]^UD#P=C;75/R,+6W0/2NSDI.<
M=T3EXP0E1BJ3\/I?GK5`J;RMBY?A3#GSUC76ZW/(1.MXLS5H9N]M;9"-FR++
M05,KDR"N)T'3!7_=AC(VDE?28Q%Y;KC)T!FB)Y[\3:/;?<!*--VP;:D-$">I
M!1MA1-&_Z$:>,:%P;B>/JL]T,[`=#*_D3K[9J*$T%"]V"TUC[O#_*P#OW?$5
M$,^@E#O*J.`IG)W_S,6=1<[MTFHP`91"+XRG_MT&HFL?K%GGI3IS,*CJPZZ,
M5*A2\:MW++(:1^)HN-OVCK!=<RD+Z)_6"RW!1`PSL0*JJG;,$29I5:3Y=/VC
M`KT+2=9PC852VC!I.*#!=HF90,B?R[/GC9X"#5RH&+6U']QRA'>_?.^`-W(?
M$%W)*)VQ;&#QO$O0=W=Y*;&4G0M4/HIT%\DYY1N7*PE!4U<Q_OT=7B^05BI?
M7MA9/Y$!Z2.%+SVY!T^G,E_=FU7@+]N'-SOQ6+^MF%7FB("ZO1EDQX,EX)73
M>0V:'F9@G?99N$_+V9?!L@KD+"T-$FY@&]EK[4QG29C]LH%H*0A?Z5'P:PUE
MI\E.IK>_"]^!I#O/-G[*E-.:2E#2X,7S_"S(F:(UCK/:YTJV^I&JL/,1A"(#
MIO)-1QS\ST;`A^^[DEUXY#SURJTBX/W"6BZQ#!_[Y(W1KLIR+Z%Q]QQ7[&#\
M*RR=@:E:%_\D).%<>R5#HPYRAS+:RH\&,;4PEROD&G*_\C>2#X,GMK1BRT"=
M!A$1W\[=$K[RID:1H@$/.I1RC$RWY/,8<>\36BE+7;C=Q)V9LX<X#W-+!Z*H
MAT&OX&%[$;P.*GQP&_.Y10^C(-*3E<!-7A]8N7O,T@[F8<.A&]1B*ZQ_,Y+'
M$X&8C$LXF[X*8_'\(Y-#Y=!6L.06I'P]0X\^!718$@Y@=G$]VC$2GD)P[XPR
MC"[Z6D]O]'D_9]'G?^/I'S0H6`U%=B[:.$Z.XGY<GUX\V3S+$T7$KF1C3*%M
M$]UA>Z&!'LO/&7`O<#%S_V['\I"Y,+!^_AJDWK<VXJ'B+41\#<X'UA4F1+=M
M8"3D`U3V:<8WR$1!U#38A*]W$J73:28J%GAC?G_QBT2$'*IZ.;C4DX:3*/#<
MX)VSMA-<7SN*TOO!/_9@G(^I)_#JTA.C`IE#ZX`E!`5$K45!@<(H<P1.E1/5
M=#K:D"[@4IZ@@PF@5`X'P@G&:'025.CZH%'MEV]Q_<C+6^`%+@]Z+#Q5\]MU
MCZDJ'A;"VZE4P$<6EM!*`5X4`PL(/BG*%XR]-OGF4=`6X%<F7B9Y)CF1?)_`
M^6@ZI!\N>(QVS*4,?^XPT90A-@<KM(0IS@CI2'<HT7!D0O(\]W-*(`X'-<(,
M?XG)U,30^;U9R_RK]S_]PJ\R+3A^+A)6MP+D%`)&!,J!U^%UI9&G;SH"&AW3
MWGE]QNJD_S%$2?R-V)\D8UW:1,,`+PMVK+S&W4N3HPUYFKN<<?`&8]+4ZX@-
MFF:P<AIY<\B]&I\J;M`G-C8IEXT]'%E;:*CE,ZTT`1K4)D.&2IL0&!+H;J_L
M-QVJT_7Q*</]8]<DP_<!C@6VTR$:6JE?LS[?(]"F8N_8S9)T:7,'JTMIO*QO
M%66ENGD#SY.%SZ7WG#IQ[?X&HMHR!C7&Q+(65GO8>Y3W4(GL#8'^3@Y=Z+/H
M#ZQ*$AYGE8>\X^:K4).QV\E>1AJFX#IB?5SI#)1I?*GJ?Q$.H&"'A&.U(&Y[
MUX,83#K&&7X`3E-G`YH?HQ*>D[^20>N`EAM6@EW=(/3:L4ETS5!$L\*Q:$8+
M\V[/0;A04V43;?'[P]5:HLDV_'72.O)'0(=)&#9*,2>$VF!.*SJZ!HF'A"HT
M%5IN1*!SU(/0-X)>EI7\P,\'#%(('UX_(A";S/4CUPPQ%@4/QQ1$&#`S"^[+
MN.PL"@9&GYZR9]7J1,40G;G#J=US]K7WFRNB-<57))IGLN<&O4GMA#\(<]\]
MK"[1?4A?3/&BQ(<#:$M)S:C94S>18.ORXW0=[#BS'#-AC^X-D6\4`253O+2[
M.VXMY:!>4Y=8UUY#$==IG8D[%2A"^Y;0!5#J'^$?4`A$%%$S888!^5ZP`Z@'
M:@YU[GGG*P:PGL8B**O\2`9V*NSI'KTD\YN+U8\TDTL=R=9XC?1%T3TS]($,
M]I-O&CN"6G@=QQNPQ#A6"#,<4IH\B.*&K6C(K8CGUBK$KX7P$)F03AOL9V'0
MDL+QMO57PL<U\OYX1@L!Q9AX[G/R+K.T>AC.M&C]VDHA0?J%*:H`EFVH!OO>
MW*01Y,+V\<CM5E$G:SA=1*!$Y[=_`C+38BO;2QCBIFJP`D)2TL9?T/_3%K,'
MD0C!I'H8HXE!6I28(N::%28,Q*^Y+]LG5?&1#36U5$+>DS%%?U$-;7:8QYUK
ME\>4W1**O6YC/TV5`G[.3FET0DZ)BE491G(3_J5]NFJ'*+G@5-A=XIVR_?R+
MY2NQ9TG0SNRSL(XIZ8$<TXH?)"H:JM9CU(O).6N"M]JOLR7_M*J%YJ<!<3_$
MA]G%F65P[222M7\A:$;C.CI&0Z8Z)2PLW+%*)D^BXK/W<<WB-@3VER"\L-H)
M-7.H1=:P[^L"[9"5X;G/@9D=Z\,L#%ZEC!`A?ZJ/TV:$>V7G&G;X`NI$ZMX,
M[951YH[NLM(+).@CQ42_3E'U$,MJ9CMV\>=J%`IL:I#9)/GWN5/H'E_5RSL?
MDH!=>>==->L58TD/N%-];\BHU[W04[;'Z$.1<(N#X$FU@@:[Z52R\ALCNN8L
MY+_Q5>&/K"M*!.%7OXJ@3NO'*';USL5]M;)Z&;W1$="\U1L[\):#SZ?+2!D@
M7'F6I\K8`>D-3+7$!W^X9_0X><L"M@9).R\($]':IQM6^.3\Z;RZGA-0NV=!
M+/<?\U%?E*9OE=PBR*<+K(YZ#'HBNWG9PEYI[32$MA.:P9<@(,ZM,TPR-,71
M<&Y*A1`-#!1XX?25J[5[HT,`=NML$L+!6%"/`=+;A,U&#E_3G;SY#D(@^>\-
M""%4;@KG3FW/2@?H:Z=X&VE!*6V]%P\(Z?58_IP7.KF<,?O^K",EWU+%I,1X
MMC5G(3*D_)^-_R:`BI=@W37%2]_R"50*\%#ZF]3H",C7CKD8M2UC>E'^-MWA
M/VJ@*[BSR=%\K8$Z4O!E;'/KCS7PAH%*J$9''_0,0B;D)BH+YY881Y\*>A"F
MU-6;^G_+>66V(,6[M8S<Z,11AP]#%//?L-@OBZ0$;^W^LM!.C!LS(27R;$E0
MH+V+0(XJ6@R2MMQ(4'HQ&TG@$9##IZNO0^ET!["DC5'0AS3`K6*BOR7BCHF$
MDPPYS-"MG^\14_B,Q/UE7Q@O0RZ+SVWK,_?D]S(QJDS('/\.9H>7WH!%8Q)0
MF1MM;VCQF;!>PD4`:D3X00/E?KRZOY5(O,[_N;I(7U_%_Y@:%_A*"-:?[1-3
M:-`_RJ!T@2?;<1TX/A$`DYOA;4>LGKR#01IIWF_"^*2#PDV^6/V?8DQC[-II
MBJ-^`XS$CIY?]`?@S7Q1/7YHY6?/)7H)H*_!G@CX4_MG7S?$L3<N^\[H8&"6
MW")-ZD_<)_V'TZV.26QRJ]24=(BR575)@1;6>K!=*G\R1!%YT).7,!^4I)7A
M013TQN;.=E1[.W->283ML4%9$L9R"E&\.@94S)LJG>%+/1F#2W<?:CDT0>BZ
MOXQNNK';7)7%+?%X;BZ6LI)0?%L/Z+1J=S[R4-#58((@ZI3VA?KO$VU"S8%6
M#+025978B9X1AW@]@<&G\M$#@9=#]HD;T+-TD%F8B<`"2CW+MXS-CO'EYB0$
MP6*&:G,V[H!+"!_C:IS+#MV,5KD?YV'CO7>(81/?1!^40+VN-`!A-O&-%T,`
MP@$<50ZH:U^9%%X,(>*RL[RLHF@^;`LBG!5"$?,ZLE+@0Y;6UJ77E;?"T'">
MJE(G^[<^^YED!S[MT"HEM"4@L*[#(3Q!4!B>)!!"S=!]"(BP4D$[MV#9A4@7
M'_[Z4/N%`U2Z(U0P8E8=D*K\"!@N;(A,C=%YS/!N-6J=*T42J>O$IHHX=DXN
MV@+Y=7^`_,A69V]I0(7O54C$/%1(,^32B/M$FA'I*0-GV:(<V#9HP%1ER_51
MZ&^L6Q*RN!$?W&=Y_TQ/WB\M,QN?L#5Y':KW=@0\1DT$R9F`ITO1@3E349EA
MTDU^BV6@%M-Z=0'^>B%.6A[.O'T"?O#\P>:,UA.3KS$'S]O-O#!^(=P1N84X
MW@C/\X>`76^X73W;.,]TSKC!5AF-E3566]5@IE:9-GA(+<1=42CD$0X=@S0^
M9T&(6!KI&GG$`LK&&QV>HO@&S_+.1+UR@]8E!W$E=^>8DI*Y_.IUISFU7R:H
M[&O8O!'`$IU$..TS6.O"@#*R#.`/ZAD`PG,F:\;O-K6Q'Y>WOK\&OT$50\][
M$'-9UG__;U,N.G79=HCL?%8ZT>T.EC&?O>#*T)H]RK7?Q9*9M1+D@VVOKWL0
M]6H-:=T=*GP]'H0MIYL30$MF$6WP42)==_<GUM:LG.CT'6%!.D".?E&$-5(_
M;!>DQ$?H<Q^\)%0VR`(4D"8),(CF/9:3N5\AD=(WY;Y54859"K/,JOR*,A2]
MIT2,LB4P-)V*HDANE63.S9E!EA"2DDB\!ZL?VQD<<0[_F>C"SE@?]8]*@Q&+
M(P'N;S2FS952W*YR<'\\M=Z&'!"H$:XZ:FLZ/AAA-V8B;=-9#@$QDI)YOQIR
M;K#^,,M9AG3"1?R-5829E?*`:!&'JJ:7^7VEUI"5%VV1XP-<G%'0_\HJE/.>
M>;X^FRF!2CE!!8SP+17%@#C,+EJ*$''-]H)14C1MY^DC;S2.28GCX4PKJ..O
ME?@+M!]J;Y0RQJ0S#2E+.P#L7M4NL&?TJ;70.?`#JZ&AF%NFA9-1XQ%$-56F
MC+,O5YW&H)DP7GP]MBK+GOXC!P./YM[T8--(BAER':H2<$!3E[2!27!N;SAX
M:$Q(?B00E81P+R4#_ZR/<<0R8,E.:A\TR4YS9G1)"%`,H!$EG`O*TP>)TI]V
M7F?4)4$69/P;8&6WM$7A?,8<;2]>?]$85P%[7!3[Z_LZU+OC3]-DM)W"2V_Q
M.3EV%DZJ8-QDT^!XV<-#ZO-I!:>KTF&@V:UKQ9>'I5QG`L[:ZN2+ND;Z0B%:
MF#1-"(X\\G&$L\^PUK]/](?/WDCD!U`U>"&_<<D]769*4X=`&N!>.OFC0M0-
M>Q(>NOWPZ;37+`M3J-T?+`JC1"]!DIEL_M;<>N:%LA6?%<`V[*(@M>VRFVA_
MDU@B<];-]_([.`R!%:Y[L<!8J%E27?G$Y1[D3WJF_%[$6G=%H[3F6ODD(B-)
M7Q-NWM8-PT-+NA=`)&]!20_:&80()@<[!)Y&_\FLV\_3W2E&X6O?K-Z:$>#V
M8/;2'^R*+8'J=0\O14RL+<(`Q%AP,^.(:%T>XG*I!EK_U>/<"K-C@>K+^1QK
M`<+J)C[I[)-ZI8HUZ]V5-8)FIOS"#515JW5U7+8P031;F]#*6]I6'.N8I6&W
MI+3F87ZWC/7/A2"Z@_H^H1?B-A6C[A)1C#@T]Z=W7QM1;5*/VJWLHU'#<P)8
M;Q[.T\A>"%P`R;**UG/J%'@^EQ^98I]+#\0SE4`ZW0(+226)58+(3&Q[T`;X
M\7.\KA1>O^$F((2J!J,8=+*U9<$QK9_:R$AV(GSDCE]RE)LVEQU3]B9KDFLL
MOZ5&70(TA#'>A.IW97/D[#7\D!DZ.(6*O[ON!HYV(:SLUS?N0Z6,5--!Z&%.
M5*P-PL;X+QN-91R;V]QJJ7FI2<@+VR2DF8-G9-LJ?9IR%S62'\@DTFU6HU6I
M.Q;1"E'<!KD5FW-+[3!"#[?PF&-[<Z]4C?Q[+N?"1MS^SB)9KEZ2M+,H*[R6
M%F6>2)#=8ZRH*,(Z1]65;JZ@J1M[/_S)8BS\ELD<*>=71*&#Z*U%L-[[9)R:
M<:;D\9*%5(S7JV.J_#S$2<8JL/.S<#>:8C(YQR"^262VV994^KD-*88X$%U-
M."*:XSJ3K>'@J[K_7`L51Y4!_.0Z.FDHC,+*25<ST4V$=>H,\C>,"+1V?0P8
MIVO6-N[HUI/?EO:DZ7R>(\+1UIWJETM-OP<8%_0L_M"`,)C?/9D$SAF%OD]K
M)?MXX8[Y;]+T-YI.W$*_'5P4*_A&'Z@MYF*]PJM6SK=2F)@H^KC-DW<`,`OL
M?W(GA>*\[7>:GD6H^,80:OO"/A+.0@3;]GCYNK&]RC@XSJ#;+(H2>BAR4&7N
MMP'OQXU<@SV7^4@;)6HDR!7X\[4X0K:U"%$N;MM<)OU?2.J.(DR;<<"C"1P3
M].(12!0+/8'?9.-R.'^K^0!3\PV!WZK#^^B5_1\.Q=+6;FB1_0%;=0,<37K9
M6(7`Q1/'L+L1'7$YY$AZ27NT#U+&)[G,.16?M&[PWS(C2.?(07'HPVRZR;-<
MTH>9.@N!>?YL[T,'@"F#6K>;3IC,BN86GND`Z,TZ:38I$#FEDQGB(2EWRCBG
M?3?$+MQ$+;C,-J))>Q[[S+FUA2OA/!PE:9*^.DG>]&G4+97*@!HL"GEB]B]K
M[KI.=W)'CKTOF>RE"3=LT%<)VPKQ1*L66:)N]Z\)9YL$+&ML,VEZ6ZY9F\@`
M=A\V\@C6M;KJJ!I>-ET+?+K4!NB:XE"[']6GW;HY/<XV'OV<^V-D?=&?(6U8
MKN'T>53&IZNZ*D/J^5[>3YAOE.,^KEUPAD?MZ-.?5XRE_#ZNT`($AV[+9L&5
M2/B,_^$^``8?_CIJGG#K*1/QQ'<R0>)X!JW\B';S%M3ZN4[3!P8BU1L2)*3<
MU_'A()\:>;:E?<K#:>FMIJTH<J9;BQH;CMU?KIU)Z8FU\@8_):WFD(#&\Y?H
M%@*0GH)9Q13(K5I%I&O.'7*TD73&"Y:]H<R[3T_#S;F>%%X7N%DH*G/_UVQB
M3/R/BPX4DXQ:0BG?8<&VW`[/\K;WJE:;.I];``?]PV)$[AQH`G747[QW5[N0
M3R">3L<#WAG\UH8&[H9K<@?U_K,[MB"J=JFC@];NZKCRG2WJR[QY++G)3`*%
M'4J#"99C[\6Z:4=43@JG4K`E!)+'Z,?U5]JV9E"3FN>K8PG9FM;N4P/W?495
M9S01U2O3D2(F[L&6$4`0S$KLG5W#!YED:TV>!\A-E[K(F7PO5!;`B$&G@L,%
M]*<0C,O"$ZY330TJ1D-:$TT-Y`[D3[\!3S#EVY&N9H7[9RXKC%*P&6*]AA7V
M!Y5$$(XDD8VMXCBRB^]4HX['RVX^"KP0@S*XSD2\2R<VI>9+8_6&7>_70T#H
M$9528*U\FQ!R@.2[KYV/)Z0P3ZF_YS@DBA_0/X1S@T'1*@XT-Z14;XP],4G@
M/9FOB=,G%?<3UNW++V0TJ9<"1MOG3^;_N&+<L0EOJY1-*$^53W#B)'"7#'\4
MLV]'QYJ-Q-\JH6Q'Y36;5T+P]P60A_P#ZT`>9H\"&)IAHI_+2OIC6!($NJQY
M@Z`=:+J-_4.*$V8R*7TDXSE"$!_PDXW+Q;,0?0MIC+]LH!OF$9?5?EF[27@:
MTC<1*$9I0(=TVN>8(JLEY%G#WF[9QHFO(DV].T8KKQO&4BHA'(W+'UC,-PV$
MK`P%M\(2F7RNIX.7$RP]91SX2O7!:+!R6KV',*";IRN#)E7W-^DK0U'+8%HU
MSM%12CY-NSNC!AOM(9=C74`71A'_-<(!>F4S++O`G44EN;1'*PH<'^W\K5NM
M8"(X%(4TSZ%NCO<7#ABNG*6\7DI$%?]\8LKES\]V(7E[4C!0;I)B87I[S!NT
MN6K=R6`7-8B=,A-QP&1%X0ZH%YW_F'[%BL1&F.CTTC`F6DGMP71_Y9`\)Z$7
M.>HE]_MM:KN\UHLAMF#34S4U">D\TAO64KJ)R9@0T-L[/ZE^I&>4L)=<?PR]
M4R;PGDPD=`@+X7:!>2HU)P6#=M\0@$!R<L60%;GXS[GRB&2EW0W/7:E\FA!N
M'P;%206%"02,;.5[J^N.M)V`*:[EW'D@_5U]-<<]VES.TW_RO-J6ZA.B+NET
MW!2Z5DE9QB#55%`;YE;.%EX@#^[-1;RJ7/W8K5@;\BSQ5>QR5$!4WFZ&+9CE
M$![E6,X%LGORC73+NX9?8O;F2*_C+D,D.>&>34O*V;J:O09__:3:1JV80P[5
M,:E-7&95GG/T:P67`.U*7*B*O&63\Q1`I&/ZW(Q=5#IIR<H"+S?]>%Y3SS9-
MNI;KH%A/DT[5?2/&]SSCUN95')^_^^K+\#TF2Q<C.;7K7ME[F+5(H<S**SPY
M.`XB\S99:))84CL]3#&YQ_E&L%%@EH<9>[@ITNB]Z,+R+-7>;L6W8%VFI%$"
M/B\>S#,7?V\3<V?,"XED#U!9PU:V>L(UIT*[<PL$$5%R/J(/4:`LK1EW;)\J
M^"%9P4S.#LE@BL6'C?`Y-5:<W0+:CZ4JI<+H"^Y(T);#L_(G)"W`^LJY)S@U
M'>]=?SB-`&-2LB;;>W5;=OP/,+?6\+P4)W^06QL!NHW"^7/]`16,J93]?@W:
MSUGQ0&7]'RH$$1#9V8;WM$</(GQYYCHJ7"!/4C$W8OGJ*=ML!,=@[?3UF:!L
M/YVX!8/M'D$I(:!I"@(A)/;CV7"FHQOGT$9L7_>*!K:DEM8ZDM["2'S/5W>X
MN1A_$OIL\-YY#C?%1_=D)L*=P!$3N^8(-?*<NAQ9VK]=Z]M%UOJT<2#G:^L!
MH+3WWN@9JGLV_]W;+0.1S]OVL;/XPSAPH`S"&DH^HR,9:T6Y:O"L+\F]>RF,
M`/[46037ZZF_M(ZR#K!A$#,6A#/0E3.'-9JR\5M:@Q6DJKE`[:EX%;>^)>OT
MEFV$N[SS!#*XF/E1L0#O0<;Z%^5UHM+D(\\VM4"KMU^L2QUKT/O?.IC/?\JU
MI]&V3)9\D<TS:='=:M^>KPQ4`.]?H&J:E?^ZA";_*`["0P78S>4":@]D.@7S
MTY9QZM(Y#0A7-U=$*XM7<_#*_&"`(_=L8C56*Z[Z#S9DE.")/^A2RDFO9MO(
M$F]\[#/L4SIA,:[IXP]4,SGT=]R\W-#!-4K22JVSJ,!KW@54B3^8N:#:'-KB
M@Y@4>,\=S*V0Z`[#]C+]\`9*O"6>K+RO@%9L&]ST==>UNPKT%_9B(ZQ]XHG@
M[$*I]S!R2+/QC2.B,;?9/P/P62U])+26YNJ=23LM?`]1)F-B]V3&\N_`B,_8
M#J6K2?/W&::F"XD5$&J[@N(R>Z8WBX;5S<8HOPR6%=Q<2K!<_YN"TB\ROX7=
MPGHV?+M-H&&!`:T>`PQH^8C'\.F587<GZ4BBM.DPO,M6`9C.JEY\FW^63.6>
M-(0$%+3+SBGATWCO'9^D/7I8-%\5#L*MCI<ABT6S>BP,C[CI.D\M3H7`^I"B
M,-`._B-81)]W%<'('9!"@"3GK'XS]TUN%<UF7?ED+`&L-1UX9`]`T1!VVP0(
MYXS'F?.D6F.4*#+Y:O_"2(![G6\\.^G(B$(I:2IXTA4"63)';NTQ?1@?PNTY
M'%C+CV](>P]#`*,C4X*AS8H3M<FW]Z[?T7E8V;J!:;06.ND/(IZEKN=._R:C
M\>*?3I<4+>G;8!R0B!41U)D=4V]XAV9D_T5XYE<HZE*9&_5Y%D_P?\$YX=<H
M7`%Z7<7N87+V*3S9:K$Y*1IS`2#JQH9<;5`=WH-W+W]DA7N$1(<Q67J8`_J`
M<O<"BD1]7]7M+U;O'/-$9]IZ-J[[R#FKS@X%&YJH-K1^R$W#SM`C^[TJ;]J2
M3U83+,,)?+)4`Y32;25D].E9AG3^NS*CU5WA<Y`!GI+ITG9R'ALI_:&9"QMF
M_?:E92QY5Y)4W?,'O@,`%S<Z.CGBXSVZ@<YMC"#@\ER]Y$M4E)F\L):$$/=P
MW=#4+:[\"HKQR!%Z(168Z0-6;ST-M1P>.OA9MMLY11>/=*.'NCYZ^/YI_^YH
MX2*,1QBE)68W`H["71=0KI/49HP1$COD$^D?!8FJ:-B54@ZA-^_I">.Z/;V+
M73MM;R[.FU>S3P$)^MG\S:*>2=1\]9:<Q14Y9Z5=AV0D7!S7^CCC6V6,=[LU
M_&_]0S2`W#8N.E8DQ;-FO^>O*!CU?7(:9]DI6*)ZX!K8XC[Z"FV"^Y?FSM@+
MYU&H@A=I4+\D!*E8+%C%U'E5&0<,,[0_#)A&XS#3E\VNVY4BX6]?`Q?P#R$$
MD26SC5'(_D@C$NG"]E,HDK#Y(*K[A.:4]KZ;>^VS@_//;F5D!=A]YRKX^!H=
M@O3F^,9B7A/;M+FXI>MR]',,HW?>9]#9A$:8@*._5F1LHE'8F5&*3Q1KXQL@
MHARW%),Q18`4"QP15"?4-RG.=-!&=.R(W5"".-0C^(O?&KAZ1#B([+B'=:U2
MKKL_?-<B8;K;8<(CQRF,D8$GZ#CW))<5M0)Y+?NG1X_NY,)&E&5<&+!1@BAG
M."[L"9,;JD8^SM^I&<N/D7L2BU(:V/P'V]T)F,A._&(MD#J;`/%8,:VW1)'3
MAMI*6^=+Y^9,@I'18@Q>L9<,K8S+UI5S[I'#J%@E?^@_T.(;#<UDTX_YJ,Y+
MSR@>_Q137JB#%&:1=#UF*:$S1E#OLT_@+1]`$+BKC7J-C^730>]T<5L!6ER?
MT]A[FT23T4)!_!'%N@PMR*LK]#_OK$ES?B4=_&=[\7"U`2AS0<DKM`@V8)XF
MF6=Z=HEV0FXK+2S#"RNA_>Y]#V(?@949B[)I*KVG&M=PLJ2-G$_O^]9T$S7L
MK%*3DVW`OQ4XK?,R.?J^:.%ISYQD]&>NIBYVFV#F8?;'O3!TH:"*567+%L,H
M0-2^ZTL';;N-'W.O9L4OM(QA60<T@T_>^`!?BU&&M2'S'^#KUV/_%M`VFH2^
M<MN.W9K`UN?0/7F*H6!!EB#)R]KQ&C:(8P]8&=&`D9U6_UY:+`U!1.`IXQ)[
MJFE[;-W-+Y<%]Q5S<Q2)7/+,6!H>6&H29<'GS]!?__3/%`+J\NA!9'G%^5(:
M.;+<(Z"6T5NCYT,8B<$?%^%G]1FO)J.THC)2*(BXQ:-5NS7^R5_IAK_,/=,:
M0N-Z73P"*6H;)]3SO()^0K_I->XCW"K@[7AHELR[T=N;3V8*V4<'[JD!ZI4T
M.H6QL?QAR55Y<IR%)N;A@-8R4+SI626#7^#^96G4\D'U'.K?/,XRKG!4;A$Z
M[HC"]2_R#5&UIZC./P38K[G1./8;W8,2K:7QE#FOB2HWL9V:,5\`W,0M[]^2
M(RX_8)[O#:8#!\<I*%;\%-;@Q&J`TM-MO2"!1",Q9)USR.ARZ..:[G[L,5R=
M=[Y\S./%B9PW5[4D^]>=YG@Q/)-\?8TZ/XWJM(,9*!6Q=]LTK$TK1?CS&K=%
MKWIQ<%E!2[L*OX7RT#T2.Y$Z$?1:)T',0?;,&>P;G0N.0AW,%;[\*"5F2[+V
M(FA01U<OW9S`WT($KZ*(W.KJ5K=%*0+@]UNDD![^\]>@?8MT?3@_'%T04G.(
M5$X(P:^,]['P?]'^J4);(6@8%`RJA+_8UY:[XD;7-33R_BGU45IP/94XS!'!
M4!9E.R;R<!@G]<WPO#\GWQ1''HP1^&1>`Y9@)RVJQ"Z%Z/BM!3"9@,[!?\R$
MQ\Y9^WA4B0]BJO035-F9\)/95Q2Q)`#O_+0!50^AS%RL9C5H]#D6,M.>S]YU
M7N=N4W$54#P<)V,#95D#9*N2H?@1H?N46^5DP'*]U)!#T+]!3$?M'0A=,CHC
M"FF%DW@B9<2EE,[*V)U;HD*Q,;\N`T3"1G;E9(#'+':@^VY_F#6]E+D=/!JR
M=<2>]<?%V&H"9/%^?1/ZT,^1EHO6F.JA5X0I3XQ/A^QY/)@`E8K!-QF/*QBE
M>K25J@TM4?[=P^T&4SX'(%EL"F-)'CLJ?3]#'JV3EGX)MKY*D<?_&\>M/QAP
MF1@B0^2?1%%^3WJ`[43M#/9(QO<L#9/3RY`E<_SBB__KX=]Y9D(1V2`<9PUS
M`!:?R4&2=S@2*Q+YUA'!'>S*"/J+`ER:]WC1<4$>Q]3MQTKH:'RR,#"J6@\[
M[WK;0E3?G7H^-\Q^FU?:9]4.AQW)TJ#1()/BW.O?WV:8'@QOQX'U!4JI\W#4
M7NI(LH67E<KCS1X1?Y+5X?FKI;"/WP[&O0W"8BR?0R7N)21WD$X5H/N;<DW"
M&LTT<7YE*#=\/T_,=JL"H-<UN?4`NVG8S*6FRCY7C'`B\#Y/!KHJ%/.H)[:/
M-*)Y]?SOI2+=CKW,UZ\KOP!OB!R99-(.L:/_\QR?)R,P4]ETL5&[W::JW[E<
MEH%^L<M55YDQSB#+6FWAO4X)3EAJH>@@U3RV$\B<HLJ6Y\DLH-[Z1$;^<\=`
M="?*'+%S7<_\KX;D[4/SD#FPS,.1(`1Y3V/`T.=371H+_48X^R<L:51^\KO(
M4^OF>J7Z</"-_#/ZP'GF^,^O;-NX2T-H&4<B$E^,AM2%[++IGNE_3WP!WE/X
MSC>H52S40IPR6OPP119?>33<:TOTBL0PT`JDHFD5H>43^F.AJJ8H3O,YDT:K
M%=;OJ"5)C6N:W['JFN?.?YE=`%V/D%]*ZLAF(A%P3V,&;+6Q([:C$FT6/;R[
M^=BP('>1&H/='(#*E?I5DI1,?I#%ZBXQMLO6.D/>/'H35N`X!$C90:A")0S)
MDV\(1LCT0<+H7LN_4R\5SG&^G8:OG1%DYKD&M`(W"MO<Y?`-=XT-JUT)-D88
M=GKM*W1-$R`P$D8],3VRT\T?P(&^<__^XV/6[Q>.JO?+G3@*T4EKY4[B2[._
MM<6>W>]2(OEG(-*9K]<?-J)&R_8CHDA84R2O<6H,\Y6_<V::]TGBHMD'M+AS
M#JUE*S.-O*ZPX\1*CY#9%,K0S'K[O<W/>)#R9N.>G33K?,VW16GA!K)'4/#@
MCIJ6.5LUSS-PH;3V5//`"D"^6MP-/\@Q%=!8W*T@,L?BOETPN?P"W>.<F<BR
M@6;+N@ZSX>G5UO=H$WO"-ZP=7<=*8_>;1.;/L-%,BK5[J1D_0[3;H^UVKOEJ
M`KK7CL(+7\[$$")E9(HS97\Q=!T<F3Y?$6+G@J#[]_5+#>X94P?JMX_Z#4_5
MYOB#Y\]R#Y9M.`LHQ'L;\ZW$.CZZ'WC'$*GJ(:*.M'WA(\5+DF9?>T:\YDH6
M6*7,9HV=POYR&/VZCDN'X#XK_Y/#O.:>\[^,^8VDS]$[[(_L5>_^_HT)O?Z8
MKJ:[0;35WAVCCS#R</HMSG+N,U;YW_W2^QF(H9S9'9NB:@R=!7VW@K'!1)=,
M.BK!PI=!2-4/<RY*N'BP\U).+!XS1@9`K6S-["%RF+4[_9MZD-;FQM9H\7!>
M)49RFW\Q.5<`*P':4.*HQ1D<?$"SMFBU$52&04*7L_IX3]JJPNWQ=T4MZ+N7
M'DP]IAU'\IYF:@AA:P5TCK#`X"!X+""<)>380,=^ZR1I_&:]#:+R=A-B:MOF
MD#L90I];U7[%\Q\CVW`*3-\$M_T.2`R@JN^LT`J#3F$9PZE#R<'_DLF8K;$(
M7*':NV##`UMH2JKPAL%L-4VYZ>VU5C3#T7@-@Y3)!OZHHY!X3:/]A78YMD:F
M`=E)=6IWABX:D)*WY>5(]&[>)9T2D(N`S=T9*"'3,LN5T`HXYVA8LW)F"W&>
M17.:0U&@OIA#T_&7K!]A,0UCZ=T4(G2N@]YH'!EX%WGMVUQ?XE(7%V[JX07Z
M?P3&@6338:]AX#?,YQ""0#I#U*5B5B=67+3)?):)QGXB+!1BAKO]^E:]S@]9
MEWD1/",=%^^ZNQ"L?C%`AI8YI7_6"-^QBS`;?E;BLU!R<-17)T/;_[V:QHTA
ML;B!0")$'%MSA5$)RKJ\O*.;A\G3LB_*(AT"S?WK&7U*T65#+&/NU^S]J@K"
MMH)I-$KKHE(R,/U0=AS@:8,KG`FU,W-!HKM7&Z*KF3^@969O^"T9+AUTQ%8B
MDS$Y!X6_>IMFS2V)9>)*1PV>VKKCU=A]5VA:1'2L<U^JZ[D3),R+L"&<3HTL
MSCB!)OQ,:8GA"A301;9M*B0`18SDAWUU*L;[%;I2^ZLT)*9N(TAO&L)Z3WQ@
MQ/73MD6Z0::K+92M36E`79NQ[-&FC4KAI-PNK]YQKS]3M%\W?RK59-#:(_2Q
M.;A2U<*UQP^__/Y71LS6SN^AA5>@8AE0Q2_]7(@DAX&H`SX(F3#+S\R(W5R_
M;SV]5K%+R:UH<`]*@$P?>F0#H1IARH&O8^!I#^33/I.0+A=U+-U*0:0UX>#;
M?\<4M5H'BA<7&&$;&@4(ML3\1B_YZE8#;C;4;$`PFE`&LRY4HWWSQ%#,F*KX
M7S6!B2>H2C/GR--3B-^0N0L#S$YU2TE_\\3])"46WX6-(.$4>B<;URXRU=JJ
MJN1FOHIL2&&-H@5DI%'D+!KQD8Y.M4N^O<.<)5BRPTR'U$JE*$E?U-^&S/W^
MB0,(*!OW,15?]V7P8Z1U^BW;%XLE>F"6=5B'Y1+7'*U/D%)]G/1#+TDR(]_"
MWAO<.9VR?(8-K#<E9W0]7IAGMG$H-^(P`+4L-_JL92A[;!Z/1?7U&4V4L*06
M712$UIG3@[DX<3"K>R`N#A-\MK4:&-ZD<51'X'[@\HC2Z42O=01;K`/J,U&V
MR+]F&N8B\J<N":QXUV@B,Z=2T,?%%R*56%(\#>Q.A+R@=':QDN!NM=@=0B%1
MY#:;;BXSN@'3TT90ZDZSNV6=)*-XRH0\DL#F^`N:,&JC:4TF:=/UXQY-=!<]
MSI1Y^Q!P\6'#CBI`H,@(?%A&R!YS]2@_/6EFT!',*H(BHM(_TJH#:R`GEV1`
M3."9('6FA;TRMWMFC@Y@)L^23(?T=*LU/'K!TNTEG++KF*1-M`5LKNR_7*6F
MX$6@0N=4>Z#FQUXSH!19U(*A3S'$(N+[6:#Y6WX<UD6CJR/&'>A\1P.]JW"N
M6%&&K%\FQ1]YR<J'.>)\]O'NCC,N5Z?[],C[*W.L(QZ$]-5>&$^?6<*J#4_G
MX?LZ77^<`$U&F6@S0G-&&KSOU0`)=V0%&2I]%2IXGJ.Q`]?(FC,7#`1M1H1?
M2J(B?Y-%C:/EYOK@FW@HS.R@AX*JAW1BQ)LBE;6=\/E-L$*>#N$M7QP73R/P
MYXY71;-JJ&<(SKGBZ;CI,$&O]N=IV,_*W6ZLH)3Y`"68DO870=E'JXD"$<82
M5&/C6*2P3C;G)/B1RQ6RO;G;M27H/,Z+JVL]%D8XP4O=T%YL\%M>B]N-DVQL
ML?D9DT3=D[XS0=+92)LSFN5'$"X3?.;VCXJ]/@@#58MH+"#'XR`)4V2H,J>6
MV)KU>HV5&/<_'ND]@HA:''*YZWZ<V!9);`LM>^JG*XJWOP@$QM>B;R/KPMWO
M@3-6MLJ12?C([.HRX9-V,@">,KA7MM&0[&W76-7)5%7'.3/PFWSZSFY`AE)D
MC9@-=)G$2A(2!&Q+V=NH21NNF*P0\5V.BB$I1E%P63[*[V&^?SE"?W?[&:\B
M/W^/N]'4M1&.K?PP>PP>Y*%F[LZN#NZ9TNW>&@SAVI@T0OUY7U'=B[V^7;R"
MV?AE/?-$M.5`^=![][/(308W//+]0OE>#BGHEQFA[R$*'R_,^Y$`[/2Z8CE6
MS@P!Y:HG3PUDJTD2SS0O+52W\%.3FNF)EBZHU63>9:4_!KCAVD_A(;[J7(U!
MD!OH%QTV4XPSET?4X#'<>AAY'V&F_=$1:ZP$Z#)L^KL[;2/+4@?"\K%!4BPS
M+G*+GB?SRSX:<^2+<Y-ZZA[#VN&K?KI<&&!T@GX&0]F99<G.87?^W_E.X($K
M]XYI0<Q_Z)MJLUB+P\8"[S$/M+/J!%-G<13\\;`')VN^VY7&.S8+,SKK"3/R
MUI7'NDQH@0KGYJI0BL>Z\"?VSJJ<I)G1*\RJC2KL(DP9AS'1NA[_Z,8A+G`)
MZC=U_@JN]JNAU@?7UGZ<@+H7"$9@H:[EB:Z!U>]QD^@9LD/&<-V>O#0JAGL2
M'=T!;D?_P`A=:8W^@>(<Z^D;1X#8X\AO1+"&#V\QQ!-'3W2=JX7Q[D2+&(71
MU(^J;Z3%?T"TZ4#(+TRS>IK;$NPZ[2KP-"D/GB5LIDC@\"BPL2O,*@:PYO*%
M'BUE[IJS8?7CE,LCEQ=;P+X.%':C[";>TT=_O^[,SA.G5;4-D/B+K40[^<G/
MKS<X"+WR#%0>6T[XEOKQ@WGF$T-0.A/!L;2O6',$U%-FL6#W3Z-#UTT-K-^+
M5X9?OU:?A1AIB8Z![+GQ`>IWT.1MI)38J=0$=:U+_-'!V1K4=GFK&38^\F+E
M,*H@C^`[O%6/N5C7ETR!QJV&&`T*P[_9%]E2VQM8IRY!<Y`G181K-`G8EGXA
M<UF593!!+<U&?N7)"+(E@DW<,%P3GAUIP\S-.9V/RXQTN-]!6Q;CNZZE%I<6
MBT98U9BR3N@2!RUWW$F=,&EU9RZ`_KT)NUI=L>Z*`0]F^K7*F4L5WN<P/JE!
M4-T12O<?YK`8PK+L1DSY1=<8N[BP[KA$H6WCUC_`N*X*?L%T=XGA51[^-(9/
M.HIF2"B**_)0;.QZ.*]3K#)6*O9N8,6&;6!7&3.LV,WEBY-:AM:^9-HRD]F>
M@*XBO2]]Q3\5W/M??(T2]+DU[M&.$!@LB;RQGP0ZW^/L<6S87##_1SCBY:*<
MDT1M2(E.<2@PS7WF":KOS./TW+)H7?:R<5VFX1RBX46_%85RW-06IT]=Z(\\
M5@4Z4KH81''8O!77,MY$(B>%K\DEVY/'[R2E\0EN^1M]L';P0J2HVZS*Y3%$
MI/H)7O<:6+,7UAP1^8E.*RJ(44<^+TM&:8[`(X!\?`+'8$=;-R;,?(=<IE[/
MJ(7!YA9T0!H0K"`A0T7602]&S/!P=Z&;D)ZSSRM5`/LV,-63</S//`$[1IR#
M!!;<ZB)O<T%5:"W(:V\]^-KG]@:#M83T86I%)^QK36A3Y\>O`(X59ESW3!"9
M%V_T;9.^FH5D;"E[FJEF_B>^\$0/ODK?'#N13`<<!<*KH]+S:.E^^.78X=MQ
MR%PT\>K[BMUO116.WFC%*<9X/L"&5AD,G]JVY@[9GK04OD[^+M'JJF!!<T)<
M+]8?YNNQ-=%"B54C,IB,(//%JK'SZ!>3X0P;L1YU7X3)[J&26?YXPVMG!4,0
M/7%SUE@(7_4>'&,$<2)+8P!9WVG-20FEH(_-;IVD\FRNCA=<C_![6JW(6HKN
M9=3@L%4%T'!9*F$4:FY8FS^P6X1PV1C9EB`8^GZ9^4&O@I4G3PTL[2$?M_2$
M:A>BY^(*I,.6YE4*Y=]WTFQ4!,'`7BC"*^#(D,#63Q"3/1%U8I9H#!\P:N].
M$D`%)%[S;:8:6E4@U<RBF%?SD(4+I'(7QJCQN`_.K$(:CT'/>!729AFO</E3
M1_96X-37KK5(>TN8:*VI#S.R'!R^C9G6Y[Z,>0_3<+]RX<A'Z",H&!ULO1?_
MGBZG!J&IZ?[OA^^(PCMQ5:5MXU$YL:4$Z)F5_0R[F#0;H8`6X!C3,]1[C>C>
M4I6M:/7#-CJ5ZOG9JI<"ZZWF&#I1'GWS.K3/Z*2+!WG0L,@6CE`1)Q&.XD$$
M_R%G,H)9;.SCRQ75MJ?@BS54:R=1R=KOH_I3V,^AY4577W,S^ONC>!G0?^/C
MO1S/:KPB'<H,*:`[I"DS'M]29]->T%3&?31#Q'U^FW?7=#IB*PP`"V=(:K^)
M_I,+]FIL^(K)TN7E,=SPN0HX>E7;^+1WG47E<M$NA;8VTC.L%"6<7H6_Y93>
M0&;/&+L"M!RY$(`[?)?F@8")^/D-#'H,K9[ASY@9EZY>;DW75(>G2W-,>_O8
M^B!AQDYCY(?\SS?0F#V/Y:5B`U2R.2ECIFI5(;>+\HYE(L91XHG.LG0^G6K-
M_XUSP%'J%_T-8:PYG-54-N(1M1T8L<7^>Z*@WJ#.$$I+%Y^R+HI]`0J>5?.&
M/T0%'_3V)HD&9X'6-=]EG`5@&&+<W0[;8VXG`*G47L1ZJ/-@!53ZH7D1"*R1
M>%2C0MZ7<XIQSX;7<'W"(_;X7EL6GTC'G5,XWWXBJKNE<JY)(KY*T1:9+))N
MV?O0?5O@0HP_9IW0=_#O**O\[((\DT]U%8MOD-8M-2/I3,5"F,W&2\AN1SR!
M<=M+?S3RZ0?043U[XP6JNTZZ[;#Z,[GWHE#3)5REAT8:07,MJQ)%DFV>2W1N
MW,QAWV5NB)NW3F'Q=;J.?S;8Z6<&N.0=>;T^(NU;G.EYXZ+<8N-#RWTL"#WK
MO`=>=YLZQ&UD;\9XSW^(,V208BY5J=2>-:"^*`_!M457CE\3/1[<41V\QH9C
M)7QD_WQ+SV0ER8_E70_JW;4L44NS4)BU9E!*-:'V]#3Y@4)3WCNNNTR21Z>Q
MG4`_0G.DB\(RN?.;M3N2OE(MT@,3_/[5H-UW"4/'7/SQG5)\CLC\8QHELO7@
MQD>VAGC>U3YK0K=),>G?5>MLN92L.I%",:R82*J#OJ1PU"4E%H%FX=:]2<)P
M0F^E[0K'M,(^0"@K<1"UG<6#$1<HVC:3>&&/:-#[91?E\LVPTEHS>8LJK_>-
M./$HCW5O#_G)8*/RN/T#70CY"G+2->:EZ2Z+!GYD:)8_\''!DD?[@)S<G1I)
M,)#F7_7TS:=^KJ5WC?PM$\<)6;-^:\F?*/-G+(.Y)M3$$83S*E_Q&MR)E(U%
M1>48X@K8E%<\Q8>;(FLLT%L$7&L:X*!>RL.XI]^FL^W?6F>N(Y#VC%<MCQ`:
M,2828[\Q1$$/+GX=]8]/<&K4CJX67IO"HT1TM7RP1F&*I0K>;(@J^9[K"6'1
MVQNYA@*TRFUD1GS^3A>2G/^+A%:]$NC,.*-K@2W](1FQ//&V5R/X4/R7(S*I
M9_-WS,/N?#&PM*DA&`/F(LUK(#OE$#OO1=4(A`=BF>)]&B$\!9*MBGIET+@\
M`9W&6IIL,4#],9JT]#!`9IB=[(),5/1%MAPPT6@(PAD;("7-0F?,LZO.?P@L
MLXX-9@1DXK'MJ>QZ/,:/$\Z/46=,O#'/BT:4#T6VQLA3%>^9&-J^Y+T+`G!-
M/KNO%$05S,94?1D&&/@)I9VG]-G2)EP6?$)Q),@Y?HRH;J4`B%%#K%2=EN\,
MF`&!$"2+LU&+W+'LUJIP+3N7MTA$H<7NJE3Y>.(#6X=J+M7M(0OK'O4<@_':
M!`B1;77"EP^,'4ZQT7G^6Q":BYI8SI-Z=[\TB02NBVM&"0.RW^.P+06]:D"7
MF/D:RW1&;C[`'34KSJWK:RVCK%P+80^`@)JG6=.AY)J6Z)B4RC[/WI)_DZ";
MJID_T2&_S)7.7O*U;';IEB+IWNX"8')'_\N/E-Y[L":N[KE+EH1)-DHFV&ZZ
MFGR$44]EF3Y2?\4"IUD`(KN#8KB0^,\+`USP?M,3)JV"D+0U,HVTQCH9E2]S
M#>6<CLZH[/>#*]P>CP*^'"@F:U()E!ZTA(PI`,`5'\N>`:`=L*J'A;WW_V6U
MJ;@GR&.W/L-B8D)>58-AF@HP0N8^J.Y__U'N:>EA57;&X(2'`41^4T)LM81%
M=ELKM&%\7KY$=YO,)MT5I20S'TUCM7*]<P39^VL,^4Z>1F&V;\B@M;/:^[-6
MUIS$`F;!+_!OWX_R2=9D$T!QY[\O[4VX`+9E4@/95#AD?'W%(%7E>)J-Z@SC
M1)2[R>E5ARA*Z*1#V5#;,7ZO9R?]:VOI3-5,`NE.^((G9JZ@ZJV.86<IYM*N
MA0ZZQH-P#9V7'BY-M3.!]!?B=(Z8O:A;-S07IC@'^DA'?AK"B8M<:-<$F@G%
MG,>8U*EB6$P/_*WB/))-*4@FU-7?N8X*XX"Y-E83+1'\6!X9&#&]3-RKA77:
M1NE9TE5GTT$$7:0Z/MH'-MW$[2M#":9TT$ZG7B*FEBBI2UE;V<A9R/#H^;M(
M=/)KY1S%\42_.S!A-)P?<2,:OS3^60`LH-2'T].Q)\%5:^[EK^%#3RR8L%7M
MC>+&?+]K00OBN0@KAF^TSA>@@08(NI,^XO0#:A7\C97(E-]A+V^232HC\L$&
MO,#RTPU&*9=/F&Q0S,&IR:+FS)E/4=^"DY#R;P%[UZ<L)8&;O:GZ6(QC(.S_
M@IS<6!-:"4FHRF$*3/_%#"W5KY/@*T*=.V.M3J,<<YI#,J,WJ]$76\[`RP7G
M9W_C4]>((A!WR?";,J+$"9JK+.WTOA<'D\X5+6$^E_[AU)J"FP$+Y(^F4")G
M=#:+5"?!RW+!A.[-R)8!A(K[*EPJ9!:8-`S=P\^*0')-=?!]K?W,2,]_6F\/
M\B@K1K6ZD*]NUAQ"Q1#R&9X8G4/-*+91FNQE2EP#BKD;0\][I![X?Q`_N'YZ
M(,,"HR\4X&$)&,QVA>>-'FQ3(1@=I6O[GPI#.&@$T-D!1DJ^M9^E*RYW^:]F
M:H]F0:=A')L#DJ7>W_0STT\`G%Z+A.':H4RY&_"U2^I1S>NU.@^D#Z=<WG)[
MFLQ)&Y77856KVY87I-H#NPC#T%:XV4_E'>LYU6Q,VG\#8H(QKJ&.5@(&ONMQ
M=I-8!T+;G?GJ`*7\*XQP9DI'O'.\DM",Z_OSTCKV_9[J"0DL(6U]^=4CY96L
MD$GCSY%5P%3_23-?XL6%*24*FS%E3\=^``P'3&FK3:],(J-0;*4Q,QP'H(O7
M72WV(<I+)`@"]B(^\S90E4@=KXXUV48:5B%@"@YQ4!J$Z^IW1OIH?+5NL5@M
MB#LKO`/V5?F(=G-,Y`^H32JV,I:J52?(>OH['@:6DI!VE3__I9X2R!^1S?-V
MO5@IIV:N,^^=5)Z*&F_:K)_`1[\<833!22[UH7FI)]J2.4&"#ZFA?'[%1TX]
MRILP3`@NE;+;T#\>.=0T7\WN0PC3!>;NK;CBLTYT,(8[ZJZZRMMYP!P^O/;+
M^-TA^3-4CG?]JS(1LGNG>5L#$6DMTPOSPS\FS+_VJ)A579;L'9M-+<)":4KD
MW'S>@5V4\\2_O^OL2<%YB>]YXIJ?(#[;.Y698+7+]B'1:!XNQ=[?]?AYKZI@
MJAC._X*ZQ.7#F4-S?_/'=UQ9^-X:!V0@8,K%7&<M_!&<U6S1!8S>/=>7(JM0
M4=$>=!A1?'?@*0=-SAW@G-WLT`IUB02N2Y^-)F9&U.C9Z6VKV)P'9_>1VYS?
M"B+&@MMZ1KR[;Y-X(2%7MA@[VR`?L,27:!(`(.G$$E0)0TKWC>X,_NP7:RR#
M+SE&0:_N/E86&;K+_?#%/IQED&$??1%[&^4OH'?Q-VW2L!%*>D33QK`RG^38
M`_W-S(8"O(6]F'_3`'S&6B%?KA)>??T<K@"*7>=Y&"_XU8S2_E_][(=%-_B"
M4(AWC]926,]B_;=1J!%E642;!F*33/76G445Z7DUB&2#R'FIA)YD^>/E+ZWR
M>*V1;MN9IO`HE^I,XTEL_S->(OL)I`Q]6CP;YE_PU39H.O4UJU$N]U;5$HX$
MI?;R+8:S7([NIQVFV1+0?;@=#`!%UY=5;AF"$L1S287#CN3P:!CH4@_U&N]O
MP:;,^0I&[Y^PT_CS8J7$L2*&'8/!<R%/MG$C#B%SLVO,PGK^]'.DH6,YNY4-
M!G_%6FL<V4/.C*6\?5;0N?J+PU%M<T1;!I+#S`TW<5=F8*:?D(\X!$Y2/C"<
M3J,&FWV;^Q@@)"QU4JQ:0=R80$51$BX8?`T4EM%H+V%DE!I@%O</DWQZ)6(D
MN^WYM/<>51(\O;1^<#44-2'IFC8W`JZ,YVA[5\:8=C;Q,2XF8J'$)N]K6L1F
M+$+W4:3"8:7,N/31)GVRAX7N5_3T(3%GO`#A;3W\`4W5"%T+-PCS!)*256P*
M&2X_$B`<Y>,OR>]Q&)&\[Z\Q\DA<]=GDGCZ$++7M*8R-Q"*]/W^B\N2[ZPH2
M(>-;@<,33IH&5VL>HV1J7J?H0;56UH?`!:7DI%_H#=65Z5I*+HVXL=M3"%`[
MR\RIV::T$LM-Y?7,YZ4&V68VK@L`&1;M+X2]Y5@Z3Y!]4HM1<"M.?8`7@FU8
M\LY]RQVIZ-884_]M2<-'.*N3FPM$R#[`U?WD*X],U*>8AC)+V:/0DO"A<HT3
M^[\3]L6M]R$7=#9*\^UOCSWI'I^4]BH?[#@]E^:0\'=L7\0(831VH69&%/>;
MW2N']?<`9D#^FG#0D`M_\,^='/=^S-V!G'L9:`X&E2C9RM-.R3C\[.0D=X92
M'V)5/X'%E%MKSF(R_A@U32[6NT#8@`4AE%1OHBPQB7T%C%_2E>UJ_JF%[@=E
M]@S.?NM.4Q6OC_7$'0*7G0`G.4)PJ<W2T<YA:ULAA))!H&KB-/:T;O!@^HSV
MQ4ZKCF\)3AJ[D;RM$RP0L7.%!T!NL@=42A%7U5FY@USS;EBLIO%^2LO'J5[4
M=3X<O3ZTJ3&V\X=-8_OAYBMF_%/"THL1\V[/.X!1=B<7U<&O2BDBE;::,)BP
M3H',U-/AS]ML,C586#ML-@56O/IWR1VIG5GD!`AZ^S!B,-D*/>I_LT*TSOLA
M9`C9LE&11'</F3EG,D7<,>/:Z@`@,4M`5>&P37"WG,T<D+!.,9)8.YU5R#@U
M7^R8DXG7L^-/EH40+CB[W3;U`%7<\'*I\+M^8/1H]@]&<0D]TL8F>A:2V>.L
M((VEW3C^\$EBY#43Q!:<';"-%<$WP'WH[9R;O+_,](?IY*M\T.DSQ8^IKA#[
MH/G/!"<I\)BW&,GV(+C$<YUD4-2$$E._Z\@MZ]"E/^-UW:?6[@$G#PB?/L8&
M]X1CGBZ[_!XCF6%V:;3&D\V9WNST\@=0A(OG,W2F\\T(4SV5JM=78F8.,/%+
MMK`M[B)EY&B@)5;T9SA1'E?0+0$E7D"BH)0"!5,WI/7YJIE*4P:<RR:*PK3#
M)0%^5G9(T#1DB/?&J&@DS@>]I9SJ)(\U>P?^]<S*TTC,,]HJ;_L"?CCHIV^(
M:G*N*3TIP[B[FB]AH@`@7+R&[:?P.1+^[-R`S)NHK?KY#\9@=KX&/3F?%B<.
MPX]&4*'+?NR\P@9CQHMG(3+.H>W=?8=@ZA]Z\^:,817^\&@4>CA+.=H@"7^N
M$F_N8."G=@+-W+*LL"#)*VNDTD#W_JMN<9_=5@P).FM5FU:ZR0^9J(SH*(S2
M`TIBHI<Q[563Z+GWA+3YDI[&O']&.&=^[$G!.W^"A!>;)&G5T/PIC4Y5G0OQ
MSM69F2$8?\-=4$7(&1?YR>G[ECRZ4F(^M+59`7*(2;<+O1[XD%_^\7OX/K_P
M?82R0W0SO^7_5EW\.!8/*#$8!H%7)X8STNXQ*AMZ*5,4Y=PA^]X0)K]I<**A
M4=BY$6%!BVQ1GVB;.0I$13JNNPTZTDN>6I!D[!VV*7!9P>JW[7=)DJ&QZT/+
M';XB4AC?XFQ4:SL,U*)9:(5VWG2]GWY9$7-O4=K82BK.V6]5>_HI[,C$V0H?
ME,Y2#?"VJN3/9.=9,TAR8?_9(%A,7.?AVXT(\B(8W>=/,*><JPB5Q^5EF1=S
M]I1G(;YU>'_Z&>RK%U`EN-C3"3CXQ5_MHMY1U8RKDJB]YH8K,EO%U"1<\9PZ
MXYOCI&F49^X)_G?5[$0?@$:,<J&5T;.<+.KSA+?BQ'ABFI@@ZAO'%`KQ)\J%
MNHRXY^>T78?:P_X>'YRCPP@$(6,$'/&^L>)=!1IT6/JG2?F%#/[`^T3?Y7QN
MB0@FYKUV;ZDNA8.^'"?-,T1:A;@N-&;MQ_6W;!5[C\^$@3#B./QPY_(_!]R>
MNI2W*JLRIS3W/6M:[*NRE,4W++(R)BIIG9R2+[9GDH?&LS7UG"PF#SZVFE5&
MR,.(;D)7WLH_&YRIYN('&]X.*MA>8NXC*=;X>++!\CTR1CL_*DP\EHU$!8&3
M+Y#>#(4S+,.:A)4%V;@'"MSF)!4K=P3DZ?XUX+9+*T?M#BW$HYN9')7=);I`
MH:1?(.HRHIS*LZQ=&3\(@I5Z.OYR\*5IHGI4=#=I$W4I7:'46V7(_8*(7GHB
M@.KG"#^@;;3`T.@2Y$1$RF+@H#SALYZ%.@149>D*U%X)A8%(=88(OK&X5WCS
MC$9#^"?^T^4'1T8I\ZA-4HW_EE2.L7\Y?%AGP)'T.2MS^?+<7:&TU4H=)MK!
M+>WCT;<OF0>1@^X(,T[WS/E'F\4I&/KX[$M)=#'GL&CV_*,%H=[[&R'\/Q8Z
M;3\##1WX;>D87H\,H8,M=2(:1R_5.=>S1^:=V.>X(HF73BF)6LZH[",,_VW1
M[HOW10@AEH;TK/;9/ZI>92T&AN(H<2CHQ(UNIE=G,LD##CI,TG6>3,EMXA:/
M!0%ZF#%TQ@JEB1UBUM)>L3>BC!"Q_IL+^&TLO/I?X^QDQI*GAH7$H91_3!:Q
M'$/F%8;\54`:4.ZRIR]."T>YF<)%<Y.FKD&KSX%*I,QK2"V;SY/9>015MY'M
M!^FC3':]9K(SK_]%H;7,B'!>W]/N-6F:44#Y*MM23:F@M-K\<I)?OK%#)*F,
MPQH/#,DUIG_3,AW4JSD;3-[`"$@M,;+E"JDA/JW.)K/&;6..6IA\#*PYQOF$
MQ[+Y&]+W%.;"\%$I;,407!)T:6EC`K[%LFD"I^P*[],*&SD)T&T77,Y#XA#)
MX[#4\+:O&?YUL]LM<INT9$H>:](_+Z[0=SX*6,.H>]G@E:5BZ&/Q_9D79HJG
M(WM)2<=U]4]M)SV*7'G248[GWG%AWQ$FX"(^B9.J0X#27S(@_9(T$4_-KHX!
MSVD$5K0WP%:L$C>_Z-MW\PH+2>QJ*'HWG'#SI"6R3.I4;H]P_"#^%6.6\.X[
M?\S:T493`&P!^HLA=.?=[<>U:8M/-CC8X/AR;_L.B"&L'^J`O2-,+4R21VXE
MS)$'$V:H>R5K0'QNQUTZ_.LIN2ZS!/4OQH\C]_-<(X5;76CPT==_43'&HVH]
MT!):,1S=[@7;DW)\2>1_JN+)/]5]/*G@^P70P8ZD65"SJ@?O!+TUHD@1JN]S
MBIQ-7(WVB'0_F##3!E/*0)AD"1440-T\H?^G.TC(!84Q2*ISE+_</11,;YAM
MCI>`LTYGFK067'9T2[PI40R;D[$`G/R^J<8`(7`?'W.'&-6&$I'F#A4V7QY-
MBB)RZ?/KN)_(A@NXNR[-$!S%R'W\@,:,2S$%E7W&1Z@;'[<.XY"_`4,/#IN>
MUK=.G^/\(H5V-#X6?B0M71T+9CE,RP+4UTM%'M$\/W!H<"!E8VAO)SP_)SL_
M/BYIS6II<10%>,O,QWOL$3/M*82FJJ)TZVAA^P@D5"T7I$UW`OLR.A$-[':N
MJ'XX:;-LH*WO&XX"^+B%AEI\E4"33WG,>FKI66EK&(S%B]\X>G%7;=O?TF.4
MH)EIZG/WSTC]G:]T!=)6BAV0FTP?AP%PF;&+U%5]+6?'V:%PK1Z@=`YR$^H9
MS2.TE^R%AO@/OM&(XI5S5KC(U9RJ_A,N5,7N%'52S--?>/.%[(<8O-F_LA:T
M2V,4##-74X6)HJVA\!8@TTDFS"17*K5WC1+^R2?$.55&_J@H#QB]\1T>>7@@
M3#F6*7I$*1XGZ+K6(]@TIP;:BIRY9K70TM03-P\A0`S<H6TJ.I@&II.FF$06
M:6IL`]2[<$JZ>E-QO<;Y^F>)XRP6GE`-*?CUA1@R5<9*?(;:#X:W-D!"TK_)
M1;PR<_3AN/EB3B9&LW>;$"6AA`=/X\='XRZLM;>4S@J;:97C%]\QNL8<#O9`
MYH=BSU3(VW#3)44%M5T_K?]"S*Y;JCLQG9MP[$20\8Z\^L91,^I,[$L!5]++
M!,\&FK&2P.>XOQK]>3SXU3R3;NO!@8/3O)@'U+HI@]5L@_"1[S*/(Z'VL0(F
M1?U_-&>-V6@HATQB$.DE9Y&2^+PZ"[F!H#R;G,K@CM,H8P"HI/9NHD\$[]'N
MXXU6\A\R_U:T]DXB"",.5:#<^54_@QZ<<JG(^I<E)`<ZCB`VNBGDQ4WM`M[9
MP'K?\W<Q:RT$_N>]4?#M<\,$00*`[L[PD!J4N#`'424S=X?1*V67&"C](*>3
M<X;J=;>0+9-X?OO09,0:I2HM2B"!(X]YPCDZFKH[V<SSV-C9FG2\3>=3"0<`
M@)*PE.QXO6Q))WAH.AVS\Q?NG;1KV#D]-@23,@F?-!)X/N`WI:,Z%Q7+*1N7
M/<!1-"QF>B=$Y>&=!)+34WP`M;8[KUJ5YJ9GX$;9?5D]]PG-LP*"_ZMC35HE
M^(,G+US[FO;U-U0`SU.25W5[GN#*\CLB`?$U_P;(":;;=#!19S]AN(__#TAP
M`_!J+844<S#I46<5@*BZI6?Q$HIC*-'*8R]^SPT4(CD`7-.FK-KKYSH=M<$\
MW+WX0'V&8@=91F[<*4\W62WC1<)UURP(T(FZBY@D2D"]V(4O.;^Y-;^"793Z
M4%2N?P?*GY&4#O;E>2SB\Z'VY+XQ@NPILCRMAWWBVS6(.Z9V>N[>>%#OO/5Q
M2R&\"T:?9KHTJ%'O>D@*N&J0>M,8EI*=;-;>"MA0(D\ZX5YF-7M@<-(F#,EZ
MRDC3I"+2YM-DTPS8B90(9F>8<PT=*#GIOM;75.`[-B#-O;$G^YPE;XZV"M=X
M-N3BUG8GW<]V9%WZEL1>(SV]^S][&0\:5S<2I"A2D>"&T)&#3R$CN@,;#-T/
MF+1.SN=A[E9^WK`/I@3-!%ECH1OA_7&)[;X.@G2D?@#-I%F5IYL.XP>=`O0K
M$OW6I=V)JP_9V\8O:?-(+B3:-!EVAUR+@Z[LRS_PH%%/1AA<DQZ@>^,N,<EX
MDTF2+2>PQWJ,3M_P<;0N/0=CO'D"?BQ-$ZYO\:&%(%SP*CJ'6P@"/P)@/EXJ
M5TMIIDF\/-$$WB$53&<.D#GGB=QHCN6G?WN#SDNW/R\\HH1F`$PD#J?!N+&/
M2QSH]G*',"9"$)DZBE&'KP]OD1/2:TXZ%FZJ`T9-EC$G>W6,NN#YL'6L1.4Q
MWIP3J`MBM/_%8A!1.2"<'$L;?BE5^#V2^<^U`I/`GD.\OH30FQPO[\!.QTC[
MS>7*".NH%?>XS$&EVM7?7/B.S][WFLOG0SI_=/8'(T^)DX7G7U5#O*LY3VWP
MY$;"YDI:L[.-V>X']"]%DG\BD\?N#2HVREPD1":"[]U0A194VU>_498=S/MA
MQ44?97PK%%FCM:+B\W=0[T+EWVE_V#56A^X`.<R[>$)Q>WJQ>$*:#@PB#'?,
MXB`^=Q0B'%NTHZXBUGQIOX%NY91ES8NQ:,;:W5B'A11#H6.51JFRKBE3P[F]
MO1MCG]DX-`>LGXRX`<&(>3_1\1P_%,+RQ<C_4"L1O0A8546`/X1+2LMGMQ3N
MQ1<19X4FAVC9!LTRCI(\T^HZ'7*N!H\2D(#);"M"L"F*]#^3Y,^A!)-2;>9B
MGOEZ&KV"<:@M#`R#IA'7=](A,*!VB_"5Q;W:/VN^^9M.@?##7<S$)E8K!H9$
M6JD\!LH$K8&&4+1),18#;8]A,K:_D8X%@:_>S`C(X98)00QC2+%P3+`N_Q/Z
M8&-P"N/7%=;74=(XJD(R@`Z^)@HEUQ]\DJ?_;19&DK\?C3Z9QKIN;.95L'V7
M0)IB=B3-.)>.1Y<T,BI=Z`@`U!M<7RQQM@1)D''G)5^/X2QJE2\\TX4\&>P8
MAXLFI>6LU<%Q:1NRAWLD>XF+9*NMB0J#:OH@-M'&5K4^[A3@;\AP]^++W4?5
M(KBRA#92J/J&HQB#N/F0%".)R5KHM3L]\/@+I)*4NYRHMY*.#&W.V!!Y9>F=
M'PFY@]1D>N"PY%+Q.R#$:-OXU&##=%`E^;E/8(QH;PQ6*1S$FMD((`(T2>R!
M#?_7_PGMMTA:PXQ<H;IIJ&8&8\^(+&EN9=5C-E?Q(K91!Y$*A+KRZHIS=+77
MI/-N,$'J4X<&GW3FBFZU(->]A#HF1OECK4M/`>H*0>O0@#N*RL]3]2@;L1CT
MY$#+)[2_LO]!D=)X,LH\_.EVI^BE8G?F^0?'75QAP%?$F<'878XTHPXK!)K2
M-K\H*M+#.RI0D1BG64-3**@TE10^UXZC'W^Y%3"Z/MR;UMV=GTD3ZWO%1HPD
M[B-L6##@(0LL'!02_7LG^D+Q@?*H)$-Q^BN?OO:NL!1*!/N;JZX)^+8C]`WF
M@*(`8RBLD.O*V,N\[=,9?RO])]K"+#U4*]$=E[4@PUD)6\@&I-<U,(R@6.PI
MJ',`N0HO4WSFB?2!VY,YEWKAYM,_G]0I:+H_Q!AZ?A.G`[<Z!-2^0T6%)20.
MLQ?'(GLDPCK2\H.<1E+O>!5F'F3H]3>U7)P3VQEK%7U!`C0<1)9+Z87I3]O`
MB;J&674M7#ZGSL.`%C?E9TW>?B9_1+<+-RB1[SW0R(D#2#-J(!Z.SX4TTLIV
MW$#S>*9=[HUB\#`0T3)R#]M5+"B*&5C(8=SS@8=[)T+YP0QR`"IY"+!EUW#+
M:?G.D*1N.>=#>.=2,I!K*Z=84DCK/*%TKDP)[6).>EDUFC$G)(/?\BL)QQ#/
M!HOO=DI9\,QA$3K)IX!_#OV/F-7*]DC^D[L*>9_[B/79W;!!$:<Y,YY1D",Q
MCK,`>-OSJ>JU0>\%!+]KJ.4%CLQ=!VE:]9J,4:B46@58A/\[GG+?62%]FW)O
MJ3VM2:??YC8Q36=&/9:"`<(\R31FM`5`JZ:OII1%JL9S@4DK%P^.LED8<?^F
M*@LS;YJBZS'B$HX5CBXPWMITEZ+F3K8V\$CMNZ\V-Y^6=6T1_S5H22J@)<M%
ME(HT5`2J&]K9$RNGV:0`G9QU[+1N#9)DF,\^5M^7F"A>^/];8,=JS&6])UQE
MC(A&3`W$&S/HTPM4+Y%U=.CH_X'&Q(R>#Q0M53-1_^A@F-&(9X$Q9H3)QKUJ
M,Z*M:&%<DD@CDH*S&:R1"S3"-6=FAQ0@J-A'+A9X[D'[BO[,PO+5QVG:R;LY
M8RCI(>^EK%<2=IDGWIC'-A#MVA@_)8V+/(-LRO2EXD]8G"%5XRUB=*DBXI7P
ME,'4TX'?$!L8/?@T%^%STIII+>%)$S2RWISF(#E37`X31CIHP9X4JH7O9;M.
M0M0U3+B!%D(X!I'H3S[^'A+NY,_=I&@XEQ^>,<,A%H7)*^UINP&_#0#XN"?6
M`BM)R4!*++HPXMH.KKTRYQ/_L(%VYHEEK!/OZ?Q"R7/$I%&G]-JOP7$\P$19
M6YN=O7AX]X:L[(>5I2)LM/B&!K?GZT3QURGPM2]XM0CR'3X#**<A?B&B('V/
M<2<9+)&\JI%O<*B*)CMT'1^7H2XG>8C(WCP:O"V5=C)LAL"`(EQ6&2I:;:^5
M;L<31@+:3R055<XX)[++[0#@C/=2RQ5Z:8H8.C\E\.4'YK8$ZE\(@O2,OB0&
MJ7-&NVQT$W4H^%`WY7Q]+S:3TT!`_-D1#`ZD]NA$[`*6:!*-\_F'1-E/#.)E
MPM)/*IC=&A2='!23<,0WY'HW^G@`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O8VQA<W,N0VAE8VME<BYP:'``````
M````````````````````````````````````````````````````````````
M````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P-38R-C(@
M,3`U,34T,S0Q,S$@,#(Q,#8P`"`P````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````#P_<&AP"B`@("!D:64H(E1H92!F:6QE(&-L87-S
M+D-H96-K97(N<&AP(&ES('!A<G0@;V8@4&QE<VL@9&ES=')I8G5T:6]N+B!)
M="!C86YN;W0@8F4@<G5N(&]U='-I9&4@;V8@4&QE<VL@96YV:7)O;FUE;G0N
M7&XB*3L*("`@(%]?<&QE<VM?;&]A9&5R7W!R86=M85]?*"=")RD["C\^"HS-
M#D`7_PQ`*UR=MTBUK4Z"67\OPY?1,;1V6=`(G82Q8"T;YY!0+SSZJ/7@K0!T
M=+LR;\/ZYS*`<'U?%6(N4O@(P(AJ=`B+Z29^U/J!H=)][#*%2IA!8?;W@#/$
M'+R-Z0%L_!RA+RTY/Z6-=OFOA3O`5_8;6FHG;M9^'I;K<@SU>`*K=R4IF,@(
M5Y-LAQGU47,JE&0R%T:58TK,AOH\@^QLJEF_.>MOL7]%?)#%-FL9Y23N%*Z8
M2HW=BC9:Q0K]AK*OH;X'J!\#R;-`[-'W&Y(9GMY)O0N#WWVZ.A?/P4?VK"R'
M[#`)U%:-.6Q^Q#]<&>AP@2L$\=64IVZD91!LRW(P74T"14-4:W\M#1N]#2&&
M6S/`:#SQOD<JI6WY)=9.-4JM9(]$4OF<M!%,-N43TD">U.A3U\LZW?K=3:Y-
MA.E'%@7&X3?[;<%FR)CF?F*`BTCW$GQ3+D`E2YAO<.7*5??X\@8E9(=^>VPH
M)YIXY(7+9A/_P8?&[^%LY0K,]NIL7@2C6VB3)IY")!U.@MQ)O/?(V#@D*&C<
MWX4GXZM^Z41'J6,2Z3LPK-RQYB`(&7"6D9Q:EHU"P)(V(3?A,WO82)OB7AS=
MN>Q:Y.0CBJ[1GUY8]@J0Q!V<2="(S.@F7!ZG/O*5%+8HB9YT8IGB\=!1UL'I
M[$/0C).6.='V)#:^WUP6V\C'E@9.'<C3O/R@<&-<<K`GU8)Y5,*'LL^*C5<I
M?0F_\8:B)K&L3@1835%*O;,IIW)@DC@\UC(FC.S(X:8BP^(Z#JP^_=F(9BT[
MG3/@:K?".AN@$S#D32.X!`8,\?AMB#!XT`!TO3G`A^:AHE2Y0/8^?Q.P'X<:
M.:&#KY/@AK)Q.>V2@#^CT%:'G->O#$]2^T,"D1!-%`]*O`Q_R9FL!-KV'$<*
MQ]V?3M[V_NA@H$N4&A,0%I\M1&0>>5HQ]_>:H;%+/PM;C[7OL+5B$WCT]&,?
M6MS25=E06=<9[K2W=E+EXVZ*3H^RXX!<->#J,-JF>.C^:S17&TH>.?QHP)'.
M5(L&#G':ZH<3JO9Z)R>E5AM8@KA8,]1^,,V3P26/ETX%SK:K*&3)OD*VQD^)
MVT&IHL[CHW[Y<#"=/"S@;*T_2FH43(.6<2+Z)8#!Y4N:^*$>K+]WEI9,W@ID
MYSH/!P,#%.H"(,\T&3PV0*FJ#4;\)4=S,%VU>`L2,&];IZ[ZV->-17V;^S2X
MBUA-*XH++17,M#:5`)+.'/K2MI;$MJ!SE?;)267G1F76O'KT#+SSB!P(G$;W
M^V`*L585"O;(0\?R/VUD%;L$UR[;]GB^MD^,95CD&]]5_1X3E&+6"Z*\HBJJ
M!W$%*(;J_<0>3H1;1O57OW9@E$4C^EGX"\OP`=O'P-[WW#B@`GSI4H4H"?-3
M>=ECR?5EDD=5A)1R,`C*+.YHMOQPU;)BK2S7\OL$S9_3U;<VDW8#;CW\$K8T
M!P-DOO0W627.`#V/(#";=B.O0%9B+4IM*5X4)0E_NR!TU/^%+0-Z."[0+'6(
MT('[P]5EE\M9%PNLS,%/%ZCBQ&L?X6`0D#:5MK@3^MP,XEJ8(<Q0S:YS`=HY
MI;OX>#,$T^\@[O%<_V3ZWOX)^]67O"&"^899HH#5@"V,2F!3\X$1W==W^ET)
M4,O#LXOX$RXA8SOYOAYYGFYL79*XRO=3SO[4!1BQA>7K)+E!1FG,NPZZC\BK
M^4>*Q7#_B4+7Z-_*(3@I\]4:;7C0H^4PW*P\?"MRD5]R6^J)!W'@OG'=#$SL
MV3X!9`\&YEQ*6W[R>^SNR/O=9B#)NXOF*15W@&/Y19&\<Z$S88!_QWQ:7Q][
MIYMMNQ\BZJ$(&E^E7M4X3=$QZ$F-#@EV%!D.@5#OW$3NDUCJXJ0;S%E/%P$L
M.\WIWB8U%%SGJ0RFG!UQB#Z3D.H"=)HNL'^?HDA7*S$X_'%SXD-`EJ]3&]?!
M@!WX\%2!_9(!(=@I5`N3;D(63J3]I:9AI%[VLAV\<]HW+5:SSN=']N?D,."X
MX$@14K1_-_/,:<\#"I*O5M%^&XV7]B?0U(-)DN+)8+1@+GO5[$UX1R1<`0C8
M0%9%(J-B1#%U?[?YF5C7Z7'ZAR_$4=1VUGC8*/!$D/4Q362\6,WU"-8^&"H*
M!MI=;8/I_^:!:-B!5;5)I`(/0,NQHF2EN4$!S2F3K#RYO!Q9@W(V2%`2Q-'-
MW1^2'!CY/N>,86^?9`MP.X>X?'R9AP7#ATNJS?4Q)GIA^=)X,X#`CTW^9***
M#\E=\:O%9KI>YS3J$WGEM)T?K6-@J(>3L'SPO^"+4D`Z,RB9N@E"VL,UFZ<<
M'N;50X4L[7T_1.<R;B?JMY96;-WG0.-U7\O[^FI1RMD66_M+@*!27S!AZBP>
M?D4=)W(-W:]XT`NTJJ8G4O?F@:^B_R8+\%HO6Z0J.P6U-M6'Y7CPB6I/O#7D
M7T2<^1PX[L\['E>9,NI3M8[PA+_G*L`UO6^?-33V8C`3Z:P/I'B]&.U[QF65
ME2S:?*NE7BX%22(]62#>.^N'.W7Q8FJ-0H*9,,*@<%P!LF_L/I2RV:!^/R@N
MMMG?'30R'.@(10A(WEV?("O93HJS]$&8")>YYDR@C>-*T&-X,J$,'Q_3)7S\
M65[<.V_67/C!^E@Y%&S\?WAN9RCGI?1;*BT10XLFIM!/\5K76MEK)^@A8-]W
M?*406,'7M^1D<DZSJ;ASZ-19G&]&:5G(/$N;GN2:_$XYO5)"KO$5DXM$S33Y
M^6^CF`*.4"8&#L9A*5)H?Z'BB(CE22)4-?K@DJ0+%5<STI$)4F6EB)NL`Y]U
MJJ&=M@8;%7@>/56+*NC\VR.>*$B8?8=#&GE55=O7([9$^4^%89M3-C>37/JG
M@OXMMB<HQ;PLCK_:\74T1*PT@`7L9=J+,+8AP+*P@99'E=5I)X!1?Y@$M6UV
MD(^=<5^747QPLA].74&I"HM>6M\,N`2(=_/^/M(5;HEK$[BVND!S\@YB(Z#I
M!83W^TT>@:E4GL=K@)\7'*W<AB4@G@@?^96K#PG@S!OZG(-K2')VK($M)!!N
MN"A:>@T7F5%-H+AC)0A?XS<_?(1X<D=<S@"*3[P&<QQKL@8\P#W3P9/Y"H+V
M0L$95:[89H%N5O0+A&\M=#$(X^RI?XS?:CW/<PYHB9,"2AX=E="(F[#P5SK5
ML;Y?]M"8J'[GO:6HE3P1NSYE3V!X.$@F#?(L6=OEN.)):69$MWBGKU=G5<.Q
M3V"J$!&O6R?OHWS(WMI<=YQA76$9'8C0ZF7#[GC#_O+0UJ!7SY[MPH4MP>Y"
M3#"(&S`8MN2:X73=A!>:H4)D%3:JT.559AN1ZM0(U7W7X8*)ZNK$OGX)21Q7
M<3`W+'ET6)3_0RFJKQMWE#4A..BD8#?4NU9]W4']Y2H(Q$!4SY.9T`XV=%YL
MIX5\-+"L9PUGUV'"P:4X]CRW#!Q*O,Q0`#%]W]PH)`JR0#V'\!D"H,W.$Q,.
MY'$J+6,SP6MD#%V0$U&%LZ+HY.SHDT5P:+1KK4!:D'>LH(ZLZ7D0=WF8WH+H
MSO0G_^9I6LTJ54RK7W16/G`65\#5)7/X_`B`BRH*'7+;?[-91(S%6S_CI]4C
MDX@'1'S[PUY!O@)CHGE'BM-O9+EH@'JM3LC9`>&LSOXDZ=XGI*Y'O,`HTHA'
M4<H^W^I-V/S0"#/Y'[.G]]C#3C)(\;4T->0M.WZA70_-CPL)Y@0MDTTQQ\.6
M!C1FFX\486L)7D5-K02/R1?M;_RX:UY.71UUKKN^CCRD8B;#%?;6%I&EL?>7
MQ[L-)J1D"-'/V[3HNWOY^P$%O&9%2\-S^Y[WOA*YI29I]@F8C@8EW!RY/[L5
MP^EA6;-?)5=!Y3?OS4^,"E1M]VD<I%.+CKA;$17ZOIH/@'X"3F55MJJLND5^
MX(KJ$(:/'6!$MKWCC0>AC=WVV0R2^K-8$X?PWC&:%-)HDL[7NN_HX:?$NOFT
M:K#+"`SWWP'P>V#BZ@HB(DL&#V6_X-ZN2>>V0^SG-/.9AD1_5DJ+?NK>!>'1
MB#]W13&P1$%2?^^`,J'\V'-^0'@-63HHOE1[W?/T?OWB]M5TE((GQ4S/[?3O
M7EWT'5QVH9\;W(J-H"LIQN]M#1K0986?IXQC,C)54<RPZS2LX$I"LRG8;;Q/
M$/%@P2EXFR+:-@JW_1?-9<O7G;P@)/EO`XQY`@G#,#9887QJVX@-QB()_`-H
M<BHC;9R1+K?Q"EWMK?M<`?W47&[T93A6C-5V9L7$_$%&N.^<L-Y,LN(?G3PC
MY,W$8<.OD%4-,VQ7T]A.F9NG$)A_M:593B0;&-%FHY;=$^ALI$2;U8',-Z4)
M506I4\0ED!/=(]B\/?PWG^^**I>^'+AI1-8R,?O-1_>F0HF"U?3O]4.4=2(I
M+Q.F4$,&]<OK&JAQG28[<89S>X+)R\2/H(=KKJ=]+A`:`L[9[[[F[X:,RN2K
M9)K*WPY00QK[1#YU2XO='=BE;!U3`#S?%\:.@9!XRA("'@_("$>'_EL`N_+3
M;AHHVI&`Q[1XBCGJ$'Y[>FMO-9<IS]K+DP`0V9ON=ZT*X-.@$C=AM)_SL-"<
MEC,!EV8.["8>T45>&:U,UZ..%7Q$O2!LNLD,-5QKI79^O2MV?NV%,3>V-K78
M^ZJTEI30<M*W6Z)]Q42:4H>MYBUMN7NEF'"0WV':XVEUUKOPIT0]90LI,A:A
M?$]#)B+=&@\//ST:2G0Y<HOQ>DG>K=>D"BJ6PI]DFS\DS*&,HO-/L`0)]5:$
M$4@D;VVUI&1?XR8E>G4V*#UMM,B)<(-1GK.I]7MW7(9>#VG!S7(@6E`&I@/M
M`7$&*(N#[T6)A_Y(TOV)M?,B!:07S1)RHG';UP`!.7D`QVZ%$)7>-ST+D(Z6
M(8@%-6*K#R[,.,ECJ.1Z0!:35!M<&@%>XRX6W!\^;R+)*X[/AE$`,+$[UJD%
M0Q!>+WAO%,(S9UKVK3Y0%Z?OG,:LU5H1%8-.Z]>%\X?7$=64LT9A2;,O,/8R
M/QUKA\:IBO&3A8"?9'/HTPT/+GSIB1ZHY'TUZHJF^_6[3<*Q@R-(-%^TQG-N
M7T**I[O`7[%YQRQ62(TR4+M=[([5:(8YZ"U37\LG-/%SJNN#U',@^3)OX4Y-
MKPKC<?31<_PK!#[Y2)UX[L"F!_>/^".($R0>3-:^3H#>@1ZP68EPK<BW^VQ>
M9,CH9>3^FDFE,QOHU_A`X"].)`L74)WB&;0<\)WQ.V4,-.9J'7FOV*BJ,H00
M="$M!_$YM@)B]Q+2Q9)P%!RMF#)K)U0N*:0VO*6H-NR5T-R2"U49@:0E]NPI
M]A[&\"HUEHHY!-T/QA.?C6M<C["V"!W*C/V45<0W`PR9A<O)SGY4K'PGVCK,
MZA`LQI9G[JE-T1\7!^:)L=:,\9@$&"RQH'&8*M+V^*$9?9']<].,ANG\M-Z5
M`(6_6S;'9,B?4\5Y(XW$SNOW'U8H@79TJ7#*\1&[02+3@:%?WRHU__E">']^
MM?K$*E?H,2R'<+N=%&79T^4`V*]/)0OUV*UOX8H8QW,=>;(#X16L"<K_6,5[
M(3?/9R_##HBL[%WX-DX\8[CZ1'.(1@:<)Q`>BG,#VW_E<F*ENS<QD::+;`%&
M8*VV38)QN+]6C#2,.9LJ*54XCAC:/;8`'(XN_DKE:'8Z[:!@P.]:]A9?PFWP
M+U\XPY']8.G^8,3,KC;;L^JOP)DDO`QH2ZN"$&BP6>T%T@"AQNH$<;I0=^VR
MR$`B,,X^X2*03$"E.%WS50@9N>HQG8[X<G?%R>IM?]'NV1=F+``[S@^$34XH
MKRI'^#U]@J4A^W`>GKA4`/V&(U/4^HZ+OXVK]%98S"XY1[$02K]XT7!&+PA\
MC>/148F!XC6:X$Z[T_^N:/22!R`83K,T(XYH;OM>,.RIA.*NN^Z_;U\5*0S!
M].8-=[.FR=S0`%GF_\8Z>0H9KE)FD@*?V0LLA6@F\3+S9,[V4@C`^'92PW".
M^.*#XN1:G(2@!K)Q*C5DIK$F6`U($)8-?(#_0?-3K6,"R$`I%I4BD3IHLVWE
MVZ.9KR0O"(6#]=?BL;[;`@=$/@WSF#S`!,VA^\-JH4(Q"IFE!+:KU$B*DSJ?
M:L$?K\5@R3/*=V<'Z,H$H0>"TGL/\M\;XD_NQ6^>Q+W300\Z0_I>D?9TRGL!
M!INTUYU`C<['VN'?/Y>8J6,S+:P/($6]1?WKP*#IPO,"7.;SJUN>M*AMZ0!"
MTO<QI6AN7._:[(BI#>+]@ZGE?YB5*3_=F'V?HM,"MY:Z`J#U=,7Q_M#,NVA2
M^/#ICPR(7R1L.U*&`/A+PP^8=$\T-J40_]?:'?(1Q?XK/%;PF`=DYJ=IEGH4
MGD"F8'254.Y84U8S,;DZ^S>6"'N'/5VDGG/R1/#@_1,OVT:\9*6>V6SU\9,M
M[E$^Y-FZV`&S#BAF-#O?TU=RUD=K/G+%J!*O$)-RV8Z'-TVP>!+R<\W.F20F
MR8PG*0>/@&EP70:#,F<-DQS6NJN]WL6*0P$1?$]<%\V*E-FW4[U"`!V(75?]
M*ZD-`E9161K7-YKY3],I(IHQ,05E&=7`SC5M^&C`'9=2EVK4*G4*^5$[+?2=
MUU(^D)JX#$KNJJKA`>)F5\K"'4HL[@!*"T]AO(6?<M?9CV.'7T![`6IZC=0U
M#7V,5W359G&[IBX>.'I^.^LQ<IE7_@G]:<ETGA5QM<`;9PJB$9V?45W3C.C:
M#WJ0,K7X<L&%Q\(W\KT-.[;=LW0X@$[0*H'&@CYW<LN#-;-+0M5(<9E=>RMO
MWP[D</B(8M_%Y2KVL`=<]XU*19@XD!M-2FG.\T4QN!L!Z$L4P9!?N9TUFO/]
M3]&"HB+2;^`']'X:@Y<*K*(73WYR8&^_+`#V'B>`'JN%#RU[A1`:-_ZJP66:
M7H`N^):3M2,UUK@Z/6'<&7@E"WN<LVM/C;(=AJ[W:Y'HG9Y(W/V,3>:Y..XO
MY4:P0)$HQ'8F\'M_HUOIDX.I9R(]EE9GD=P9]A1/_#Q],[&[+?UW/%+1R*["
M%U%#]SS(J$0B14_5&:BMB<$692Y.#N-VJH7;3X_50QN`!8(%+#>1D0+*&O(S
MK[R`60XN+^>(VA#*!@6"]5\F&,WP=PQY1W/^Z*6<&&B8YER_$?WO\6`-7DJ1
MQF!#)D=GAHTJJZ.NCN1S0ZWM6!],=D]]6A!='Y@_\#PDA7ZI8)YV61"S)19K
M$H<ES,J_C=2Z9]:"52ZIB*1:`N^/_QAY#__BA:"%<.=Q^=5W1-/A4]$N^.\7
M,URTSQAPQ>=DSMV+*`P_!/D#H[,@"J9C<.L6^_P8^QOE)`>/M!5`/_6KC7Z,
M9_I-#2/=09_HK?;`K"URA#JM=$3P8ZB!FJ8WM,S0J4Y>Q*=FK!3,LUS52:RW
M!LB2EM9/D(</<NX4J>B^]-XR5"N8^<`S`]SKH+;X&=G"CE;N:H89_#QF<!X-
MQ`&?9L0=ICK56K&<^"]0);/ZX_Y[$38H!XZE&;04DWZU8MR^_INGP1]QV>)'
MZE?9*A'LX18*`.!-]I&WOA7\7NF]TE[?1;KP>[%^OOD-L[]%+TJ*<+[PLBRJ
M?0PJ-PVO:$,=@0H/PXPE2.Z3UC6%A+2*\@+^*[+=S=C[9[8V#?KK*-^ANP,S
M.6I_>2UP%?,T[%EVTER(9V$,'<SB-[OO-0;#-FB5FE(OWJU4TX7B&VG8X[6C
M$"$",I"$CY]-_-(>,#CA;%-!J!7;&(;>2A)YG&!2K\^#;/;`I[K\Y3*&/[^`
M!0W,E#"J.*MUM-Z[RG`>'9.@^H3I`OGW#']EISC3MQ5-@;D>\3`[2+F_B%AB
MHU5B:I,6:7<.'Q+,1RE<AJCAO&4#I]C5+-W"`HN8EOE)[YQ:E^WQK,QOEH),
M_)_*$=YNJEQKNY;G%L"<%UAB<?<;*DQX)?QVSK(IV,!OZIUF!#:Y;W*O6U3K
M'`*RYY7CKCORM2:RRW4+73"R!B'#49Y7.@]5@/J&OO_:>^*H"&<DG*7)R5LO
MW@)YI/U^DF."?>V'TDO?1,N*.S0*<\C>PSL9*-M4R`#-4:`!GFHM5@]\].N8
M:(Y0D/!FF.J(:L&T.;X(HAY;[_-)"1G[<GPOH[8YYC%4W+]TWAW$-S)=D;BG
M.MT8W4<FL].GY`X,C7FG6K?LNC:J..7YK\?@#Q56-L^)$G'/7;C];!<899TR
M2@*@B][O;0!&'[X*=$9"<@0&V!TE\S1"1:2MWPUI-0'?:#F]H%VB!>AY`K#W
M%B#M#4@'7@QQ>33/3V\3K%E&T'$CNQIU*OGKC+V#VL%LR;U_LB^T2'!OAN5M
M1'?(2BY9)"+//5NRCW6)E.#T6;JBUM7Q[.)N.5%MMV1\_YH-#3V=2@B*R9-W
M%_XL.6Y-%0"$B5*JK3$)WRD?5FWP"(IL83'CRK@B=>VC)*)L&WN?,HW"Z#HQ
MX`<U`.NVAXL/;FH!<L0CEOED<3;P&)4&0+4!"[RI4KH3H0D.L,*N(D#,<26>
MRYZIKL]5P=]V^EB0P!<WXYYWF7SOEBQOZ$&J19"6'$F[;>)X2IQ+!K*?B\[5
M>Z9JSK!_HYK72^"4MW!,+5`7B7FL)+"+("(#U_O95\-U&CDYZ%!9`E3W#()&
MRX#U7RXQ4O-\%BD6YBO:J&L+S0B3%U"[=%.$1(["3FP,UO6I[_\&[9#2Q=4A
MW]GKB,?#4OS?"8<U*X^L=:27G1&/B&LLU.VFC+*<JLLH%^(NI,)^*+1^:NO<
M#XHT_+'"#77-;&@G4F?+P=9DX08J;$D8HJO1S)_I-MN/Q:NWFP-%8P&0BWLV
MS@7X7OAR>;`U(6*N$.%`7P*KT!Q,6A"B?0M-L^UAH`5',KX8#<U>"D2_XU'^
M^5+-Y<[EVX)8$P1)T=+1SQ3JM3K@)`[XN%JCWLFR5HCJD,;FE>X&EWKWX6?:
MI6+4FD;[8.]904Z2!2$K-(X341T^56^@MS.WD7S>Z(KB562+G^[%:EJACRHS
M]]"2.=\H/QJ=XA@&N]9-H`N5T0`!V@W&TK63\48\B:!>:'E!-P:_)';XZ=#=
M\&#:=B%Y["?6EW%^&F_'2PHAS%K)SD#&6+YWXWT-8]2)3-H05'S^,^7:GD3W
MB?R;Z:]L%>4J(V2E7(_'_:77[#9.\8+XGB!)#5NH"Z&Z_.H<1A^I<YHXJCDK
MA8E$0(,>$[O3LL-I_GJSWI[]!C*$VS]R/"IZ^WH7`T_%TZW$V2LLG.N@54XM
M4K`Y<.(`RGRZ[K&/=NXM=XV,6LS!0*(,\!%<AZ>ZFM\++4U?5VXR>`O^3]5@
MA`\<;4)"A?!;4,A0XM)1:)&'6')P5"/DLDJ8Z-&\">RE5*.(<(Q/WB+O#JB`
M!3:_K>4X?.HAU4>5>@\2:U1C"R2(O6:"=J*LO9O/!-J4*AW$:KB^>8R"G]>5
M,AWX"W/^7!O1'%_D.YQ;!-(2M3"%T(:F<55)IEMY9M#LP+*6F7/JD6'<6;"E
M`K<,E,CU_.#.)"L/,V#UF>N>L(LQOE)8BPNPRH+Q];<RML`]>#X+`=O>"$^4
M"J<NBDL,[R8^\`4AI]0[X0<+,U$.FUVY%GQ'3:=^<ZT#,)WB9Y\]\HIF]A_+
M?)G+'S*#3U@732+Z@;#$:*J`>R+>KGX)**\B1MZ&W_EOGIA0A=Z`V$[9ML1[
ME3N#%QG!&>`5N)ZN+Q^Y"-'W(?8R-P.S$K,X?+KDAX/6F"=)Q=LK\:F-90*9
M]SI@7`.(QH:F1<`ST%\.7*A4+1DB+T`CL=F&*,R[+FD0#V!1(XUV_UO.XQ-R
MRX]R.3EZR_L8Q@Q]&;=(G"AKMJA#B0*A_L'N,VS6CM_847W/5Q_5]K76M=(Z
MC4C")9WHW`WR,@*C_*N7Z^20PZ-I%T5-Z!T$371`?-3V>/ZS&WA&8M\C3ZU*
M:Z]E.*-+_Z%(GO#O6"$X)*+D_EVBW-W#-F*V'<D4MNLL1*#9%QM\ZK\D#B->
MVK1IBGIRE,*!,^H6GZCK(!4NQ*_#FH(V.NF.I'P%##FMA4P-;\H,$97H!OGB
M4%8)+Q`VU=Y(1T'\NA=><5CR4*8`054+R[<M75N',%J\[G@<`20SDP&*(!>K
M5-PWKG]X99Z.ZC;%GK_45'Y.0S9_6M,H]C'L&E+O%C0YU!'06JM3+*EYFO8K
MY!!#0.EEQNPB,F9)K"B<ZS]3OVB:;.([H1[4^\+T`,Z'\!'3Z39.`<`;7?D!
M3S(#L(J1'_!<2OF*/^8IO_<P@`C3IABWW*_,N\:4GV<;CPVOKCRU="2";&V!
MRO3G,4O(BFVI#;U9-=P4"3(]SXMY+7MB+@#VR=APD-SY:W)!M]/)=2-7E&-?
MTU+H4+,W[LD9:P%FZ<5NM$,[&/H$N"!+!&IM"[-RF2K"$[SV'_T1K!`FV4:D
M\#9_A[,=S;Y5&V<X'Z2$1S#"`3B8N5M!0$YDT`\$95YI%XXQD()$G]FI/^[4
M(DPP#.-B6<!KLF2S"B<4Q,=V,\HR@@N5U,$2@_Y%VHN@MU'$(19ZBA\8Q>+M
M.?&&E>F*B3N<QS43)WW'FR)/9B)1[KX4-$O%-3`$V:<3#0!'!BN:@JZ*NS[%
M);-)!\8/EHNHBEAKDPDC/6/JP]Q!A1M+X>9'D!?.%/2D+FYC1*'HX%7!T3>/
M.^<PKJE&?;(U2)GXVB4N`=SX,7SP\[A8J%H(X>>SY9'M.WL3OH-A,[Y\7]"Z
M_&'WY"^5`E2=/^V&Z5+G`BB]MVJ7*'Y6S6SH-=":X?T@W5#U?LQ==?0L6E#$
MXTC!%44-K9H@I8S`6SC]C/D3]1&%Q]"9Y70?O!\HL1C\*&#6RAAM!JBOI54<
M<R`W4&!]@1V-+,1T%MP>ZK<8#IP<L.G8;LIFX'U+"M9*(A/XZ#NY_IQT<H@_
MCT3:R%?P935($-A9(6)!'X7KR*`<\X".<'I[-K-$,)6]%$EW6*+Q]B)3L%5B
MF?\=9[#X1/_S-/'"O)X%R0UCN!!'O+(O/5"9040@/N4O23K:Q1PI*,E<HG$*
ML=LC9JLTL?+K`?=+%51NRC)Z^LB0H%.\^[K:5%(?GD;7Q?S+;)@EMV_6DFVN
MH'VHQ+3XD[6%F@9T<UL98]B1:#[LU[5F/_IDI6\57B$70'GL^FOA_-'D#5OD
MN8PM4U8%@)>XGT(S,,TC;#O/:?"`:PW@D9_SN*@#64WXHWHF]AS6P>J!@#Q7
M*B"8$+>;NDT`=-70(9>?7.H7L]2C)\2ZB-!H@%5Q8@+?G]^BCBUU]=MV%!E8
M&27S\8CK!KO))FQ]Y"1SS3[K/IR1_2-EJUB;SO;C_Y%$8L6UFE&N0.*^M,1&
MYA-_J%5C>75P,<22`)_OHVE_9H.]NHUG<-1W`"T+COV+RL>JKC.3NSX44C0G
M&&!=Q:YP\_QS#?M3NT"+6A1B\]+O"N4SE%T4:=0PLRQW<)%<:>AJY2,4H9X4
M'L=M$41N3=2#JNM4?06TLE3%KQT,(R[J6/+GRBMWBRE#'W8>4CN;,`T0F@:S
M/*<(HNNL9ERZU]#%NW'11@Y!L2)WBG^?XN;[=X=`PUJXDV"QL!DR1#+%]J?P
MP$EJK$@X+3&,4!O6Y!6MJY+NH"&C-">;T,3EDKN<TN?NCJ#(X;MC2E0*'6>8
MA%GRJN,NOC-4"Y+/=KE*]9NK4G%MQ'JH>S%W>AU=I#GVU\H.!\H">WD&`TB4
M;*+<6NX,#/V,ES'49BQ/5MD%H-FVDQN,&E5*)TL#@WSZS[V61'KT;43?'SLX
M9ZXJ/W,N/3CX6C_MIHN)1'H\'^F6#&?R;=MZOHAD6!HZ//7=W;A&WC![*AG)
MJ$>L^T!)FKDY3BW&I>%6)L9QH=!.X5-%YF`60GI>#Z9"#X>=8B?NE)#Q^0Q@
MCL+B(N.(CLJ_W-SU,UVES"%NRR`L$W+,R/#MF6?TF)8FSN*'SL#H7AU8PI@6
M`I?67@,D\"#GXN/FK6,&-)E'-HX=:CDGGQ$1)_#7Q.<9-:J,V[O+L=I%V'LM
M;AXUX!3CS1-BSIG/<9!$<2N.-C8!$^&9=)/<QG3=0;;%\VVQ20\<P@PC0<+^
M%<#J/T$"AFK/$\Z6C=R)S3Y4THEN/\+$./AR9!&6]UHN</,*TV7P@LA7:77\
M^BQJJ9^VS'.*X.>&!P?-VH?$&6E!TPT="6[4Y^=>#N%U0IUT41=0M[$7UXIH
M63&*-FV)KZF]F]AG9YIKZQ^`&DN[/="@%N,_8Z!<\"!:I\O7?'#MUR.OFCDL
MYOH+CD%)0Q!IG^#8/1)YJ@WU4B%&SF850-DU.3#KF<W#RDJR(7NQ'A%&&>)N
MO/@R])A^?E@"@Z$:7-%-4,4?V$QXR=&/-FAOZ/6J;\HH:S6ML,1E/`2=8S5Q
MBR96LQ/L\,T=6MR@0>5P))4Z*R2*>FU$,+HUW'>S]U?$0@=P"B5%FE;1XUA/
M./ZA7%4/7(W]5IG+G!F^X3S9"]EU#[.Z\_`2T1RYY66"QV^,WGVMCM]<XUR[
MO<)4,@;2?$LRL/@Z]1,A`SXR2-Q3K<")U.@7NV+2]V(<]Q_'CV%N2^AI092#
MV,D3RZ=C/`FJZM(358F!Y^TK4A09N*SMYP//(V?"27]0?P'5\&TAO6\?-L!#
M-$6VQ`7,?HM&&?0>C''8J_3;8WI;B`(:->HJ,K+!20DZ(47_YLWD(8WIF2-A
M8TV!E";B(^HA<5.WF;,2@?TCMEE7W*P4CQNZ243Y^O-FB6S"FCG*=&X6$O(O
MFS)I!SF2J?@1A;*"+''P.)S<=L]A9\F/MPADV<;ZU$PDG4J[?O\"ARIZ@U2K
M`]T>LK]3>9=/"R*_KZJ]QKF:!@GKV-Q(=?]64(Z]F.V+"#2ZXU*.7;)%('JC
M3;62[K.6H5E#(YGT*EB\\>?0<`$_\=0XT=2M\`C(./9F`)""<NX67XI0R(^F
MFX<`_-S;?\(VQ"\Y5BMP<)%/UO9J$^PF":J-6NAOC:R@/I_<AJN%(C5-R=IS
M=G$92T;K.BO-2Z=Q8S;))MD4Y5EGI7^H,1;),X*4)!K(.=?561+-.:%7%,%(
M3D?TK^6;F"%67V'N3W(WZ:<EG>[C;<'0D&D/6!J.#L^Q3E-S^/<\=)]VU9^`
MK[QW3:@QOS-1_3)PG/CE_`Q86LNI@6K:G/;BCI=Q.Y]=#N03&_Z+B=RJO&QR
M7&6OKE?A(-(1X"_1OYN'G3761U=B0B?3*O&>VT_D:E4<A[]E2M%IC*H(D&1^
M!V-L'&R*`=>4?H?,(DT%4:$-7O!VD%FCA9^'E<[@;J/MH@F*LT0&NN8U>";W
MDF'0Y$$8U6*=M<$LN00#;S;D1*,[C%WK5]\C/1/G@2!NB1ER8[:%23Q+''OE
M4><463:;0BP,K^IMJKEM%;N+]YZBE>\@B74=VHJYSA"Y":3(\`RF_*QRS9X`
M3FANT/>KQ4S10$#D#PN9R[^68M3`MV(=&ASWOHW30EN18PID#&XQ?3]T0#2/
M`C2;;+769N>-T"*$A$;,+^YRD1DJ#JTH\[I"A;:=W%_I;-H*.^<>I95/>2+T
M83)LEE^P15W"RR%2X!P\9,$]YG5[K*R1TN2$\XZFHMRJ\X]N8THR:GA!*+&(
M`:],>L>IPUC]3CS%";L,"<>8,';,?=]:R.)F"7_SQ-K$K0YB0>`Q&.EB58.4
M4^Z(67W\A'/2/;&'W!G-(V@O>>%I#3&6BELBSC0UOVM=?0$JVK^)%_V=F^,?
M`9L4B1*B\T!GM&.S((/>79)L'[DJV]=)LYH#4<P+(7)G%&.Z!.,:'O+YTV;Z
M^`#EHO&;W7G0>3'O-(*U12VQ+;R]C>2N@].N6W1L:;-=),EG\$Z(VDSYGKZ@
M7(/C\N(.V&G-'56'4@PM;#!<=+%J/J"7%U=VFCE?L4$'<A,7CW[A>W./%,[>
M,Z$)"O@+2H6JVY2%D$_U)*M+6^,?)G3O!+X\E-=1^A46`NRP15PQ,`D%N(\/
M:VL4E1-!R@&[:1)Q2/W9S@[.L$WC$9AX>HJCHTC9\>HU61KHTOB>AYZ%E/Y,
M(3O05;@IET(N8M/0^,2>'X+!KM1U-SK#RC)VS1%;5H`["=-&EJ37]V[/_!95
M>QBO`G>E_C&T$X+(C%I,2GQ,F/")=,,).K@9V7:)OD,R2,@=ZW\/M?NB*U#C
M,9$QG`/<[G09'6V74;^-B-3:4@Y\"(*@VY7%R[\AX@XUAYX+]TABJOUH]F.5
M)[=Q/RF[I^>U:946,I\;J]RK24?34>YW_X;?S.E*;>Z><!OF@'*Y`8IH-$GP
M@HVCW/F8%O+=+U+Y!7^X[,CU!!-?RO$,V^HY#3LD8YKXHQEW@0%JRX]FQ^X$
M^9J;VSX.'RA0-?(-\S2N1`OFUM,_^4PIT_R[OLS?S?#Q&\Z+AY9H!(O4@L96
M>.!A^]=B2/AC>C%2M%&JF5>BH'2PJU6_[6P=W!"&:**./Z?,[35W\3U6\4*M
M>?1(J;?5K9A1$/[OX3#7CY'W/P'**XMLF2;6&D(+EF@?&Z3:'8%/,:F4E#I.
MK5<'LL`0C8X2!?J3Q^-QMIX-:<F`XZ*CC30S$B\MIC?V0!9"033U6(]W%ON<
MM6G:BIF1O]!0:IMVO*?W!YJRO9G_F&D8?Z-NK:H0BX$?QZ346=$H%A;.>)U4
MJ+P'.Q76?8>"B9(_FX[S]>,6M.SR74#T$,]]D]XF^9K#9[D\TJOA"3QCR4E2
MF/)[-7%\S==,9M8J$[<=DS/<X44V!,.JZY#^?99I>L#]M6B9CTZ?Y=>]B1N8
M)56M=="W*DXMU.4;+(KT0'H`!4S0879W4%Q(R74,C=7K37F&6VC%T\ZUF:I:
MI6"0,V?^4573\FT!"30U(:YO2L#V$HY".#5``!C2JX<$A[7X@_>=X_9O=_]U
M6-"-`+M?^./I)Z:9PK*U"MJY<=N'I7R7\<KBE#>X-JT*%`_@':IR[]RUW5)A
M(B4ZB\$T5J!.ATO^XA9?_RBTMR.<%,1O2O97>AGO*=5'TT</[[,>`_A5XP?G
MV_-2-`@Z]6*^6SZN@X\9*+L)X3B[HA%A(5.L/D?ZUI_Z$;7$5[L*/A@92#FT
MC@MWO.>/*IRU.0D%J^_'H;09F7]G+T2:]>J,R",%YU,&+<X=#;8.FA@\E8OM
MLMM>K+9S5*9)_?BU)RV>AR`I_A5^^!7N"G]0`J80)C^,^ID#`;36V*;$L&>+
MGM0+R13ZR<R7"M2IWSV"]'\O$P$8NP?;H(.,;M:^MG'A,FM"'M$]U:(3`F@%
MBT=_JZT<BW"/I@*TB0ZSLKUFL=-_<SL4](>0[4UL=O6COR5[_';NXT1*,%!/
M6?#M"`%Y"A9M2PAO%@RMVKPG4^1[QL*R.DN`P#8V!5"P\=U&,/=U,F7[?BY#
M-`'N?X3>-C4;DXK3.@BB*#?B&1TF*$;O\+-^.?DKL`'F;[NXHF:?K1M+WY?!
M=J/*#]V'+\<AL!4>;2EC1_E/OWZ^!+69PVWK!2_&LVL'-9WP/G>X#F:Y.8CB
M_))B#3//0/>OKPYDQ!BBOKE1NNFI$5B8\J_AOL_^67$&/#$Y8?L^S9OTP]3D
MBNR$A>[MLQ7(2N1>.04S;FX*T;;Z9LZ5V1)6^)"%028!8%:+L#7=DE%`HE[S
MWH&;N1N^/.Y,I)MRP]>@K68<VK3\J4A15S,^PPQQS[]FEK*&H0YS-7[?H0P2
MTDUFW$"D_B3F*15?;;<A9"DR"NH?_=77C0"?][T'"L]T@CNDF>8F[CH)&;9L
MN\)NB^[?L)!THK7`.#=#X*XUWQ()5B&4+$2+'^7EP6ED)JNVLROBYK96/CZJ
M1US91(OY7!FR`'"/$M28U#F)F6\'^G\UF`'P)]8:*,:>3C'H'X9;*U@2YB9F
MC`XWUPGJ3-]<RK.:1[6MD]L=6#06@[7[(]NY94\/FR?4T08C2WU+P,Q5(P/E
M#;Z7+SI%@5F]B>0P`Z@+#IN"+U56@#AZ&3QW*O6,.J"W/_/`FB`Q35VF11N_
M4+&J82:[T1_Z;_B]KL#--;X#T1B)5VR.CB`;Y.9"+&C-$\/W\=!3(,S[$74&
M/5Z_WZQR.2KDB04O$0XC]Y2`P;13'WU8PC>T>0!;4*#`.&[-MO/"6"'EP_I1
M&(P]?`'N5)(M\2"8"/8$Z$G2AM(R$5<I;#7-B]=^(K/6#&0"EK:!SYS:36)W
M`91?Y$BH46UVTOE]H<)Z8IFZ"D.1YN5M)R764OY(OHBUEL*TFPIJL5_Z9%BI
M4Z4O!FQ7#)5!@_QS@.WW=FA(^-H1^6XK++A<*5,%JB6`><BE^]_S4+Z7M!&N
MB,<*XJ;2\LA+58X)9TJW".KB\4EG1=X.3_O6EKT&D<JUL+TG5U+?E[4Z'WV0
MI)53%)V^#$&="4_T)HQ`Q<,#(G9Y).)I3Y.LXU42<X""-']1:=T/1P,4A?W?
MII2%_ETMJ<(+0L^E'#;=QY;J[63@8.!D$?2B-07TF*ECD4=K3SQ]Y'9?(_IA
MW*_?M7,2G:Z8,JFK^\.Y6-&%^WD^M'2ZUQ52F!@(0;<+G;%+3.7>A$KA!YQ-
M1*-:G&<<S*^DC9T?#AT?LB]A7/B[S4]*#N+905?,Z\8RDPONARK)37!K6CDP
M5;]*X-N,__19,](-MLU1S8VVCPGW70:N)-GH;W0<$)MU:8V_.>NK7,.4`PH6
M^3XV4>QHC';\W[F%8W?]S%1#0.5J=F`(9`52I8V6I:HO<;1$``BA4.=VXAH,
M"D!T;FO*^M`JFRI$D8I3(#3;^?V=S4FUC?;3_K*>-C)%0:S3)W(*VC4J?T3G
MOC8$?$-,^#+]1/QQ(;:[^VG=D4:28@0+_^$"YBV:C=4Q'H!B..-A!\N%?5O`
MB1-\,`$],&P.H*:LJ>;*-P\^@:[V]&CZC(ML%`_RZ&K$\0M0\F>!ER%`DOZ6
MG:]=0W#_ZQXTG2CE`*:P`%'P'4$>2G.:4=`;-:C8.R[NF65`XD!LHO#=E'$&
MH&DTC+;&=GMG!W1=WIR9^`M6_Q]%LF5LMGPE3?7#8TIMGF"(Z!"B=;'WE`K\
M,Z+4,[2<;`-_O<(.:6)W*>>GB.)IH5.SFEKFIL@Z2)'X^O6L!IZFG9`F[5$^
M9TQ?/>7#CS2%9A=<!E\R4XH.W'0K,NJIKF3DV>ZDMW#'I]G++Z)J]F9=XUY#
M125P\KJ!3_+,5TW*A#?L7>1',GT_._"?3+Z^2(XBH5M6&(VN-%N%@3%M0GYR
M/04\<'?FO(=@2NFXDDQ2D?1A$GDX']IV4MCR;.V%!!O.2K0ZZP)-BN@IS\O"
MGFW2/?V':ZD)3*IV_I^"8.E3[462IGQ/K=W<Z,X<N[ZW1O_G:OUZR90,',V/
M!*0-9WZXW1=_1-UWQ&]FV,C38R'B4_\6Q\Y=;,%KZWG7L['C&$L0B"(#C,FQ
MME?I)YILX?AW16AY08&Y8"_-Z8HSI>6EZTOT339VU@Z,7,Z/'VY7!`ODB&FJ
M4#0"EUE_A&Z;%`ND@\"E[TZW"->F).Z#D27\3E3^#$QJ`+U9K:Y87BKP1;8)
M)26S:Y>X3!.!=&)"Y;<LERGKO(S=1P<B1E+8Z1N4"61$/M-KTOD7"KK=M0*%
MBA!0SHUH_*K'Z(M!+V,B,6T?5^2Z5&/;!R[CC%5'_)-=6:_"W(\4V@UOVS9'
M9#S5QSUA'64CN>):NP$VL5%N$8>SZ6K^=T0\I.JLIC.T<%WQ4CID61>]0L&R
MKLUT"O<7`'[EM)`*%DMRGJXT(TV&;T_S]OH!ZGL]V)=4UVP8O-8)=);F*_.4
MX;;AL`:(9`(1FQ=%<&[=*;<;)NVS=WI@L`N._P[2VR)\4EWDEJ:<'M_H7_+;
ML?F4$X'FD4H"1WFZPJ;50UZ&J[!S0"#V%(@YW_GMXTYH`K6TI&;#@-I,$M)@
M"+6_QE2A`8A_8($_]%[M4`TS+[VOVG^7><^('(A9=^M"HO%1N+Z5]7,Z3*X;
MGP4L!BG(HKD<P_E3*"GD"\>/9+%>P)NB^?9("A4J7X!_7J$H3K^]?)(*O8K:
M69PGE@_CO-G.1;7B7AT['QV,PP8>)GF^ZG+>4E9[;IHW>(+&-$__)GGHG%4<
M':0=42S\UHN>,TM<&1!?EV=0(KPYDQ78%V^ASFY$`0UZBS>5];+)6LI52:9D
MER8AE7'QT+W5,X79/&^^3.AK0@&:I0O70-["6YA2HUJ*]PA%AE(<1I7ZP\@'
M(\=@SB#Z;!(^GA/55\E5%,I1?LC")/V?8J^]N1ZO=8;Q<="D$4Z3JQ.J_NFI
M&:<WWDS\:4,25>C;EI'<6"W'I*3^2@`]S8ND(4W6"9A"S03ES_FNB%.5:)?]
M.G=69@<KO990%1R)Z01`W!N1`8=HY1PEA,3R97J+6_AVR)I4@Z+<WFOY`J+N
M5K?_SV9K9@#4#(T;`$1?BN3*?GEN4A#J75U0[;/4-I<\%YZ=`%X+SN"S*:OP
M:\(1E<%6DLHFFPJ><*+Y]&.[QROWL'I('$R""`ELH?-XHI2%YV_)?<PA"1.Z
MY/DPWL'^S*?:Q"C4\GXS$E9Y*)'A1VF5@":IH2;<E2^(0%VOR_HN'("Q7RNW
M@Q=W<$M3OZ3988W$-3&Q/3D?'-@`E6%W,(,/@MTO+:@G:ID?0E%D,\*PY+L'
MV%[Z#E#!SZS33YIX:HRPFFJU(8%PP+/\65QEG@1A!_>Z;CC_+E:GABO-^GD-
MC>7HWE_V05D4\$04_&@II*$'U5*4C2XR4LMU+>C(AK,05*'BH(5,'@03M9H6
MY8+_M$RAMLEHN,^^VB^FV>&"Z_LD4N&$3;/!^EH-49?B]7J:M=:#*B""&^@\
MZ22;!*VA:'Y.=]0"6'QD+U6TA@U*>&;U$E^["0.YELH)W!L5#QZ8S`+$(W+(
M[?P.LM'=#I]M2Q_3Z/<&IMN5T/1*PLT<!O;?+0U_W]=V?+HH(D"Q)>[:@CQ>
M:!M>=PV8SF64:%C\B>="G#L:%!@=T,T`<S`O[A%:/`<U_TWO<J!X1F!JL:F%
MF+@?40`5SZU\CNO_TFHPG7\<PQ^3FFUO^PAAS"6_9ABJJUW70_CETH%I&>'O
M)C(HRX#!Y;3O89,[<J@,I01%=]JC<V1OX_K$VJLG$-!LAMN8"5:D?2HP:4TO
M";+5%A_-:JQYOA.0>4]K]>:R9$BNM^<Q:LC3+^V97457M(MU,#EB=Y!<8:_'
M2MZD=I1;NLM4:>)]#G^!C=M]O0FSPB9,7`8DX]3-RJ[WTUPF8VQ$[H<)Q<N%
M`Y&Q&\)Q[KEX'&UI(&QS$THTA!OP&]]Y4\3AMX'?\D1BN9&+W?_S>!J*,QY1
M/87NDY7'U5R2L^9`/E"%U)P0;#0@)0K_RQ]HK)3S*Q&+<6T]AC/4\@:EO\*2
M^SPY","=?ZA@G5]5/1=V*GB'^DG#/2YE`6V*WC+S`,/O>,CAW+>YDC#/#)UB
MRV&9T&#<&V<HRUBKXC#5;DS1HF?@0F*C8TRU0M8H1A3)FP^.R/7JM"(,SN[=
M%F@.X%O0FXJIRH?X.YI['YH`C^]XK6)7PC]LS]NT]#'\1&?DA6>3Z,(4LEFD
M?=?Y6[/5:71R2AY6SAQ:X0#+!Z;G`DM[M>A$[<Q,"P&_9U(H)HK,_$:F)E`?
M\_EX!U02###7(R%A0[:>*_,0Q'@BGFB>#VQU6:,.[I!WEG1M'@=8@`M[@4WH
MNE8N?+<.%IVVAG75@Q>&X,G&K`[C+[2-9N</NGN34E[P*_X<QVF/P>7-.9H"
MZ4I.W)G_%R-N,`JW?O<_&/ZG;4(Z"%H`FJ&MZX5</C!1)7$J':(!%!%TD'W#
M\=X<057$`6DPH122I+F_XJQQ)=$/FRY)()#>>'([UYIC(=(JA^8?>-#SJ5??
MC3OF6+"35V5'<6M3GF-U([4ANVEK>CR^8</"KX?*>*JFVB>XTD&'K**/+S8,
MUM"AX"/M?B*7X%B)(R,OT,RAHU7T?_[!XZ89MTUCV<2*4E/N)1<0/PQ775JS
M@GA\>)_"^Z(B`N&`9`;(=A48\C^,9_BS"N-YRJ!5@MODOPKBOI@,+,QPE]7?
M\2ZT*-)$/#C]5K%7.8T$QGE:/>_)*WF\X-&+6?`#7>;NLRN]<346DP?4>56U
MB*//.6,II)8J;/Q1>#:EN&E;$@SVEU%#N/,)GRV2'["^%E>;A>9#.SVJ`NT-
M8'?082XK4`);#AP`44\U#?*2<WE!1U)V]UR<7W'#IDBB.L;>G[%,YC&LCGA=
MT/BB-;?L_%3_HO/]D>_T'(9P8@436W_'ZW)$4"#&=3^(LZ5?</9D#_[/^ROP
MSHQ0Q3W"@BAS.`PJH!0T[%-U^$#&-9%T4Z__P@J7RFX_MSA34X8#.),L40A]
M].AP-<5@MX8UD^L!D-'80RB0?K?(51%<L%`5:SDT%4"52CM*UK)_H/6X1"EN
M\^V:&]"7)8T:LU^UUU=.AX4=VT&I?&4W&#_HJM^:N`@`%$O_9'>/(H/::92;
M'9FMO552["Q'J(U3[42=R-10W'ZA'%Z"S/$BI>Z7Q\^P+86AV=X]HDC>W7[5
M#OW?UE2P&7"2N^0K;$`7O"OI-$,/S=-DC^U9CZ)BQ94!H5";F++0JD?!E+J;
M4[4(X^IK:XCIA6Y-V<4$&RKLJGC#//K73)GT_"UW635,*)@J2-5X'%*^J_)4
MX]0U=++I5?&OZ7+Z;JE#0C5Z]HE;J0O@Y._Z+0@+=]^5B`(2R>;<,2FYZ+MZ
MRB$4E,$/-!&;U#+X?C:WYF$]I0*8C%=HKG``\>)%Y2G#3CO=E^75"`+5*G_Z
MB2Z+!#3&R"NUP+FS)NMYEQ?YO%!-2?JX#KT[*+)Q">K;%EFH-7AI;'4`'CQ'
M<-<:)F$:3FNS*8W3<=[J:WF'L6'RN-A\0$@M<M%N&/*J6U+USDD#N%Y2SKR(
MTC\=U+@,0TUM2.#9++R_./&W4/K#7%[`51^H2F]:&QMF3F)%(5HCX1*;(612
MH3WGLY_P3M%I#SJE19$>`6'T[>>`RLGK\7.47B!L.6DA'F7W-N$^PAUHA[&C
M]4Y-[/JCW+O&\TZIBY<S=/S#P%?E0S(8,8!@9&\GOOVONOA83T^@0G7@J3\G
MW5+5&C\=??0O3S9\JWM@]4UA#Z.SOG`.DV$51"/LQ!&>\SXH]NBR'F!,"(!>
MPB!TCL^>ZG'^;^"BR-@.DK@:%IVXX)WZ1%GQH%3:^U_)0J9LV@I)7V:NUM[Y
MGV%?OT]HR&\YGTEZ*63WCMBD:/.9K"77WH@VI]F&@0/I:J00(Y8RI,\\SDM<
M-"%Y)UZ<RQ7IR:-TH>!!/0LM^+401\I:92ZV#RYT.$8KIY4::1:J\83D.3OA
M'35?8FE,"NQOX>:[CIF/9<"K![+=JP]\=Y_X82P(<T:,WY4_3DTY>,28K32S
MF22X0F2_LU:BP-?"2-H%^B+RA5\?FH,VAZ[&'2X$\,]/WM&C;ZE#Q82:)0-F
M7/;Q'G'N&U@*S'2-?>I6^:K^QTZE`*ZG*A.Q>T-,"&)WTF<:]ZXM'2%!=5OH
M&X&/X],51#L`WS;'>Q+M)\I+T.IK;^/U,7V$9@N#0T*#XN,3NSU@,4F];5TP
M*KC\./0`O7`P7T";E5M,1(I+<E419`D)=M'[0=L3.F&\2OYU-VY'4XE9M4/Z
MC/;GI$SK4^"E?2)7Q(EHAA;].ZT7)]\Q$K*@#"G>G*6_N"+P_^[ECHM"M<[P
M,F`L50QXJ4BB+^*U<Y;J;>QJ&<Z0T(0SSSBB=5DT[1#4U#$&SP[!]CLM/M9D
M'COX$VB/+R,LP3MRD+N%6<(B%J/PC?@6R-\B_>>)H_8]V</8LO4GO9V.OU5C
M%(8RIJ/+JR*(YIFDQB_DHK*OM/"W'8=+6=D>V4".W9PO%8WJOMR.1+4$!2^9
MBM3FRD/;>#(I(]4>=.-;?.]V21TOV-IV[IRFDH$!-%8?>E4NLN<(A(2>,OW!
M6^LWU=@YHLT1/(YN&O2Z<4<2LBGN"9AP=)0@Z3GC9U`[Y99-/="S3<V^:WF,
M<U*2I@'AO`9]M^M#.CVWAAR'*^460P8(FJ,`J?[PY/II!8S8<4:Z[Z4-C17/
M!MPU/#7/*"C`=/3W<`O.HEY?1"HNO7$B,W"F5#I!:H8JKKB"F#1HX4XWC[RJ
M@![0J;'B&KO]"<^%E]_ZHQ8]U<!'0W8&6=](_IKQ%S5MK-E0B%)P$GOTDTQ"
MC;#)"9`)HZ?>.$+:QJ*-W%/]2M&%$6P<-5HXQEGM+[X"GXE>O8[-UNA8F?_,
MX_N5#125-P=6PZIW"16T%G__-X574YEKE''WV(FMTC^6#.,_PK$50:-\7TUO
M723:BBQ&K'DB/+9GHC!JKEOZ)0GZ,SV8>2*=#"5>+4S*:UGJ,8]_A"U1DOW%
M!'4--2:3<\<0AK8[:M*X-+311E$&/$S(_NCX-*>M9R%">$U#6#3Y`/Q;FQQ8
M*&S3.TVBOY2G6,>'N\W6"56I//TFGQ.4-]J.ZB/EH+N9D7NE1:Q(_?K#->FS
MG*[%6@U1X-8:,L**3]C)NJJM-#^J^CU66(Z?F<L3UIQBV5Q5'YQ7#7FTSX1V
M[LH@4;M3OBK%#I^1W5'FED,@9X?F>6-=7L[IG0BD9Q`$O&9J4;[NRQ\766&Y
MTAO(_NBV+-RS)JV-!8)^%3Y),!G([1;W^T3W'8L%ML`_C7K5`LC,IGWV=96&
MI##MU![[Z[/CQWW2SNK\A&,PKMI<X'C834(W4;O@(]UE0^:*Q`&2)UH'&2(S
M6/^5/^T)&Z4W&WVZA*+^>"]5]Y;L952>\E97SANC&I*FEK5:O%@#G)K;14MQ
MXY=!S>9F>P$8+08D/W,HRV#^.*:)+U)-$N_P)`4)LX890%!S*`^NJN1WKL44
MB(DLI\`_4/FZ;6TP4U]*:77]]WF#*"5^E$YZ&66QZ<:+(&$K4GMJ#!ZA&L=3
MI0!$0"UEPC"V:\RN'D>[WM(/6H+[NMG=[&^8HV5]3[+L34K\1[(A'3E,U'5%
M2@QA#:JE%;W6`&[[]=\OMG.&&F=",@U[`76;5K`4OWLE-5Z[)LY3P5M5E""5
M.*W\:MXGA71E][3F;HR#H!5J\L!4^TT^H="FHC,&N'TZO,)=IFD]06;U?8HM
M4B;R,M84?R..5(K6::@";3))[M(MN%0F28U4,G@33IO+A@M,W^P=7/QG%"F<
M-0H<P-W[\Y:[@MY!<4]AIV,)$AT%[JZB2\:^-`.#$N'!W,BDY:U?M).`CELL
M]9LKGW:L:4>B(V+RP@S^MLOT*QV$?[7ZY!T'@ZHJ>C^XY?<[BMS#,#B<48),
MF/_7@.$?$LPM3J$@//4/C,TX3/]F6Y,P#M9VO9X`(MG;']B7(DGAQGC8@!BM
M6-#%)."NK4*R6Y%;Y3T+B_'G/*QKS"EDU(@NB%>^\SJ"#RE$F,AR0\M)>I=J
M5,!F=WN;O-N0P5S$I5%\3E59[B[#Y]7L/H5S4NOS^TM+/\_=Q;6GV%SP94NS
MITG`*5M9P)[@Z4DC.75^E%82.YMW58JJ-`X,Y93O0FA4D!D\P1;#/'@PV!%G
MH36A9"I(%OD"H615&2(H2XU[Z)GO:W0E5Y;RNBI4IX\TFWVE(Z&AMPA"5.<9
MJ"-%TY/^F)U.*@D806#HWMH)&4G1[/=ZEV7IL;97AJ8Q6H=YM;8$-.I10[DC
MVST$'^HJ4D9.5SK@$D""L^AQ5F%I;#7T<G!IUY/R!70JVC6Y`A`F!!Z$(0Y0
M.H;'V]@$.ZS"YN<-;>'\NE+UHRWQE'VYG$,#5?AW*FBHVZLHJ!O*55'?MJWJ
M_J.,P?OVFR_@+]CA,V*7Q'BIQB`_O:/#UG.WIB@'HF/!6]&"+(QYF.(^0&<R
M#KIG6E&#`R-G;H<G?_N5O^AMMZDQ1OX=$*(1*?8-Q:NJ#1=9ITV*4T0B&&&>
M?05VI\I.E4W,A7YHB1\/G^K?N-#<]%'46^$,E,AZ:?7]40[<B966QEF$_.QM
MT3BSAP`E8/DBH`;3^3&VQ_(-KKAL+GEX1]!$.A]1#>.,!8B![?`N:46$DQ1U
M&#Q`L%5M`>A#@]+*%0DMZSQXNLFOK%->C8]=**63BD4+K@=DOQSN98[T*`?E
MIICTY9]XY5M?]Z9B#U]#LH1L6+^"V4A)]GSE1LDZ)J?B\$;R]>QVR;A6UH-?
MFR\')"CO.(1C+5V7YN")EFC=O'!@;Y$S"(,!O_^2G([C"L3Q-_5$VM(0_?2_
MEFGJ"P+9"1>\X*/KJD,U6/X!6NQ)Z[Y$(CHIPHS&,"JLQSU9MZ:,,^FM"ID=
M/*_7'R%G26%O00259`R2QDL_?/%,Q]I8F:*CUH\=0$NK$PL--F?KGCE`#^CJ
M2M.PH9<$;MHBR$S9G-%`G@>^Y8A"H(AS\@'E$^M%S/"W'^:3.^Q(P`E.\+R*
MZC_S\Y`4+;]SI>WC?]]V0E3\<9(>HB"9-#W*SF$)#4.B!RF3H]]`)5<HUEL_
M[#D5DKD+8EVJ9=T(>4WA'3PK,7UI<L[T'J`K$_$8B;B`C5=L)KC-XWQE`8LX
MG+"84+4/OM:"J*:\C<`5-;'<<FE5:^@;7FJY61`Z8GNYKV&,7_Q_75$364.9
MHV](@SR>8IQ+&&'79SN"_W9NV:VT;76OX!0L,R=K@U:8,_=Q$<^,,O""UH[-
MF:+TB=MPZ,0@%$=]TXF<4/$.PV:]J*2N>G>KA11Y#O78N"6L/KZT*AM>_F9R
M`1-),Z",VB[I8!88._'4ABTT29J,AHL;#$,_G'3/V.J=.T!--[%:'<=?0JQV
M!R?Z9\\Y6V[<(SD2Y3+;&*5Z'D2R`ZQ.0M]K^8I`'L0#]*V)QBP*DC5E9);1
MC!HT6>HXEA`^;BW2,J2(;0KARL'*1"#&#4:K[K;CYJ.\8BH^3Z7%59SB'&8;
MF0VYD->7*:2R*4D7<BIZ>8Y32LL0'"8Y5<'*8"1BXRNE`T5:_C3&H[;TG<"Q
MPQ2,)<-%V&SCQ2B+T.]O2.MDT!B(G#1F@J`R!+,DTS-DKZ`U\N+>_3D^9X+6
M^M%:#@1OB$O/#!GHY[CTH]C,(DWN6D+=>S;)"B;SS>\.WZG$NL+2]G3HZ9K:
MO;=DV=1V,IUH&4+=Q=FQ;*P)[:PIH,,X2%47)S64[?05OKLD/H=WH.\]7Z%&
MF6HQ?K'X*\-JU&<[-%'5LSY69*RPZC@NY9$6D"8JDHH6\;>I.X!M+IP2,PQ]
M8Y./<E%O9)$ONW0'QT$2*I4\DQVP+%YO=#F^#QT%A6R<<TEUN\=FXF'T=-Y5
MC$#O!1V35W#%U3J29O'KA"1TN_?G6D=1C3AK#"MC9!57)ZJ%A6,&_1<*E-</
M[85Z%J.1)ZZT`<,ET:$'-2LW2%N2)B[N-`8@^_B6DN77)OT_?UL@\=:\+<*I
M^;ETV0ZU_WVI753B5'^<CK.?X'S^LX]+,;[(;Z/<QI(M0.R7$@6VN!4'O]G5
M?TY2(%6T1LJALL*1FX$'M8\LY#!?[F)?S3RJ$VW5%GM[UX%2Q.[A;U[OTSOD
M8$E>OU)PE5B:/&=11:FR5M$4QY=*978)?:[?<R2#D^#U%3CW<M>'K'.?#P*7
MG>(VO`J=J/N+A#O@W?9KDU0GY`]/V](?D!824P"SAH.W$S65*S?'/@Y`CA4!
MSKCG->2]/_PM.3=JXH[3+LD;(LL7=+H#,0])O,M;4VGE&9IT+;'!V(84,?!:
M%*^4QJ@3B="PZT=,Q&XOR4M8-^ISO75X)S#_]-([V'JP!\5&RX^4H5D+U[X6
M=K+_?4B@;F;K7%NJK.);H"AS\'RT!":$@P@>K1EF"#:6])`XCT+,%)I983J+
M:HT^E['Y>=R#2'R+GIY@=X>)$%$E$WR3PVH@@MR,UPN#D$F#WX%V3FI'%.U:
MGSP\SMA=RIVWT_FT<8>&46Z!.0O<XW-D+)Y/:T[Y1D[FK-ACM3".SYU(6Z4G
MP[]+TNS$:K/O9(=48Q0M)?*$L*0URB*V(:OD*RT+YK5F#J9Q9RIK.@;UH>3=
MZ7OQ`O=G(I%2O3<'M>F*BR\\A4''*58P=8];1;1X.$'Z:<61N8A=K0A?PQAN
M)4=T?&$+&5#O:TF,5.&$PFDI"JZ5HJRP(9.CDRX(0.^]*RS$IYC41.U[.I?4
M&VWKQ09TXCH[TTQCAZ^"31;+ZU1IABRC8AV62S8DV@!?Z"&CRN7Y)()[Y!^<
MBP'?[P`O=-(C$D@9W]884]'MDGGQJ?N7I!QH_HNLA:#ST'A/!Y?PI0-F4_(_
M]L:)ASP`()CEKPXK)2&5"(ZW"3F^:[[RG[[SS;9-=+/R9>ADFVVOUGS;K.8)
MQL"2A42\H&ID^30)(*_((LV[R>]C>^U&_ZWBY)[O$S)4T^I[8N)*??^4F=^T
M95@/R=XF(?E:YU>-!S.&E,NTUK!=5I7PSNK)>=QAS]@N"3I?=;LI.Q2*G`<$
M=/+P8='@V(?0@NE*(#[D)57*@-#)XH(M;:&TT;+,@A,$T=9HF]_@V"\?4$!?
MZC$-@,AVE/W6DXD.R]O82<N6O5W6\RY2DM.ZMV0?@6CO($8#(AGSW)+"+(-9
MWA&<8QH(^%09P`C$C(2LY?<G/)'?0!EZSL)T8RN`T6PS%&H$7-[LA3=7D\Z!
M(B!([BN4X>\/M[%H@I]FF#FZ*IMFK^+D)+HOF(]MDL9,(_JH8T>6H-]D9_BC
M8;E%/0;^R=LB<QK'.WP5VHV82?@JRF[VX9[B8HJS;TXVQ"HAK/Y6&I+=?]%-
M(Q/^+0%8++:_O.YHAM$3*9$1!A5PP[/>S(D@4GV1F6WIE$4_@*Q-8Y>8\PVE
MO<=1\!`6KY(`@)FK\"'N`)[('7V)`4Z"GUUE=C(IIOBCV8B#2!U3M;)K;`)<
M'X[HLU:@MYE<@\%80.^^,[YHX<M]S)/D).8A_=7H6<#$#RM8B6[D-,QTE$()
M?NY<K+D_`/%:K!@C&6BDPG8^WWEP`WQ1G]TJ&?5?F(F2L89\`)D!;T6!*(O6
MD*?#PR]<`]O:5$BJ6HK=+)AR6%]YM(!^0@2+$"0"%1&N]5KIC>Q=Z0T%.^.B
MRE8+$,\$30CL4T[0QP,7H[7^"<#502UA;\;TX).IO/F#5E\'P`>)`]^\_=8<
MI)&P_JDQ)YG0^\.4P;0<CJ.Y4I\L;8V[73RG;<SH-IP5!U?E%6/?%YZ`:[%I
MX:^N,CF8?Q(LIKA[$Z>Z$!2"VDXWJHT"FV*<\KU'0GIT$-%"A39.V#)5EV%V
M^BNK47K4C6WCN_#0?^(/+^9C%J1B&EFK^P":1>O+0"R],*)G0IPC1$XD^:B+
MRI]>'CTK#!4;>2)_CC!-^9M<4L9)(QN%"C@!]D6Q]?#8[LTVY;_TUNT5C_\[
M#:*9V5&XD/Z,.F[S3-C8@,;)?(O@C6$(!0>MFZRON=IR53]WOOX!#./*D`U_
MHT`O@BR;5$DSCC%=AOM1F'L?T9]&)_C.Z_!+;1#<_S?;AE.-#KKY`(>&$,<G
MQUYX-[MS\^7(#SD?C"GEU2+K;)*H.A]T<<H_XX;(0U,)AE#;)W>!;+9)&(F-
M7]S)&&9KRLPF07':&:#P(C0@I%+W?9I`89\]G\D1T]VX<,!/G(<20J!@P$ME
M6W-`H.%@Z,4F0+2:0=!PMJZ?7?%I]NS4P[F<9JD$CU4YA!_HM$DT#I9`O5:X
MQVD:P_<H7(7"_&]I$]9.*L&75OU4<8<J2NB,#5_=0HUZX#\6!XGCF%6C(_%C
M(]8`R<.Y2..K0.V(SVD1G"^G/=PE((8<"T:*[5Y&`4M/\B7P.[6R?_@!90$H
MLT@F_OIEY173.<B>JE@=R,W!+_&_3&G=DE!_IIDV09,<M26M):Q-._7V.%&-
M-)[+#<+$;-^'BUTR_WVY?MPXH>8'[?!G$&-"KG:IYFV;+$HG9M47&AP,B*W\
M2]PN+G-N4^.;!.V1YDR3QH.+^[%$3#TT;VC:!'8@C%7]0#&/-U>,IA]BY\,?
MCF2[H34+>=)M&S."&KNV]#`KX#WRVF81Q\+)(T::N-%IMMM#O?U"\R[*,&Z*
M6$:$S$7@FD=&XMK=ZW4+JC;XK-3`[PQ>ZF^7OW[`A0K8[L:`59['F@G>S-FU
M\/2?*V$'I\=ZXK\[GC7[='T^_%!93'*-U@NMWI["40NHS"$;;DOAB_!TM_TE
ME^_?%E#("0U@\J1GB$-;Q_C'W5!F'99T7/%?3QI>1X#(.A^BJB2=2H;?-=/)
M?L0YTLK:C477;6AVDB4N-0ZO/!KM=YJ467>W3%.+2_6>!X+++@K@!]M_=6AM
MR5[XF)X!?/-J'8&`F?:TRN,#J9LP@>RIU)-EV>6WE@B.\8U)65KD"AEJEY,M
MDJH2%1$M^[ME[+M73]LTH1P21\[9/=28&\[4.LW5^[[BH'XHT(BTQ7X4^U;/
MX%VILD,0!/]_4H?\4T5G%2\/5E@&ICJ8!6M#:M,P`M/90Q.7C*I/5AFE3KU)
ME"#=0T!F'8+:C.(5&MMJKEF4]2U70JN(_]7]WNC3:&4Q+%SWZ(R.76$JFZ?.
MQY+*)(\B7@9R)-'2Y"QJW-G1=^%^_XQC19U=&^+0F.UI-@P:9+IR_5*)\$M;
M266_3+GHIWB8OE1H'SH%:X*N-$]!!A6Q\T(REC-6&W_HUVASIS0&,AIO%L;/
M31WT.9:;9<58$=2BS?%IMZJGU:L0:1:O4R_1FT4E.*QQ'NT7?>1G0.R[=A4J
M-Q)=7K:M;8VZ["WRZG3%`S!70(3_B1FM;QNG(C$_''O32>`LL5''`I%1$SNR
M+T8E&8Y;L:B<);K7D9M@B^B3`@8B0OK!T?NJC?1<_M=&\DZ]^<FW!#6L]0J;
MNGHNGO3X.#8^F#Y0V3R95#=3<_Y?`%#9IUVP0:R*V(^#C"]-RRFN>@ZH%PH,
M#JO;F\'"-5*7],9.K/+IL(*-]>MW3/C:08(32O?R-AE"J`[!,?[5S4F\+Q0L
MNV<1X3=^`7S#V_-,-YMP)\;]3RR$B:%\W"P0V131:S]E4-3$)C)K"=LLFZ=O
MN\1#;I\;+QWKU"KQKE^A'Z$V_S/#?B+#,?\H6D&H&C&\`::E=B^L$O*&SM'R
M@&&*[T.+QZK"]/-$9O9!D-L/Y8=`/(`\$/(_Y,*.'=L+#F<1Q":*^-W5R:Q<
MZ]=S0"J)@T*8>X;BO+V52C':9&KZ8EF6M9=A5F.Q*R'PY:"\G)#MZIE"!%QK
M4))G@^H>'7>M9*]W^$GXJ)P,$L&'5G_-3ZD[`'2=<T.TGC8[71XRU]P;%Z;0
ML#6=2-('8-976A4G7RF=>A&ZNV&('4>ARDJ1IIPO;E'G=YA]9:W:3SN6I59?
M,DGT'J0S_8ZKI6>>@_2\7"QO&(Z20*L[WVHFV7;"#A^AQ[VSTC$4^WC^SIPD
MYES<O>.2E;U_WG=;O8I)4HIM"+*5-I2D1D"ACM4U4O52E30VCG3F'7H3!4FX
M)"`&C[.>S^]Q,A+9D@*I"JTW">JR+3%4_O9T5P2#_P(E5^_IG$6VF:/<TZPT
M88+G;-"(Y!6)4VTPT9ZP#.N.&>"[-MU*GUBTL#:,UNFS'YB7./D%F.O0H'P[
M["ZWZS#5EZB+?&C&4G:WGHAY;`\G[2OJ3KW1QBFSBM>')I7BH!@.DZ>;7EM;
M^6U[/7S"*VVP+\\,K:T00G,L5"PYURUF^,$L'6%I[-#P70)WOV9%:!,(@O/@
MVX8I2)$:AYD'!L%<BB%-0Q^QJ?Q#8RN\95LY)])]G7"/*&JS(9W$'#\G2FKR
MY`18&!,;)B9ZF(]#]I&7F(R[('38.FI,6CTRVX<N"E]U\.SO!8X3)2GXH*C-
M`U0A\43`D8T!^2:#,](*^<DQVFQ+T/_/X#GKT@Q$A/]W8=7Q;O0LS^SO_LZA
MVZSOI,!96O)>;232?A?=VY;E4&$\$EQ[U45_X+_V%O?W%O5)MA>#75(8!U'P
MKYF)1@#X2H#!!44:`]NWY6+,_1H$`6K>:W].QSE]/N`Z"3VR;S`OTFE_?IOL
MJZ'&WX;ROT8/H>7U#Z.#"6`*^L\2$PYJO;.2K+2WJSM81!04Z<;W2K';LZ(/
MI0IG0QK($4_[09D_^\ZL8+V5V`77MA_3F\IWX\J@;*WO32E]Y8-O<!C!9VVC
M*O?;^S/%=X]V#^QA9`8['#17B?,*:2\OXM\^SPCQS2[<U\_MXLN:;[RT-&7O
M&!:Y)``XR=M1QDJZZZ*FL_!".I1K1E"`7B%6F5I[H%+A.ZMH)V?/+24VPSZE
M22SP]Y$/"O:#Z)",#USS2,R:;_@<S3F%$;"'%"ZY`T@B*F@CPDCGC#X<%EV[
M5D*[&EKWTZ3^^AL,.CX!4`F36:X9\#0*#A'G+F9>I7KRA/QV34'DSUS9RDU]
M#D*6W6I*'L;-6$@<S?4=GHXR^,OP<?,%[RJ]?1UC=)OW;[9<_;,6\S'RZWQ3
M\S';'[EY]4BX!LOD%P^M(C`HL]8OE87Q[Z04U"A.1NG6YGD@V7Z9->Q!LWUI
MWUK/>V1U9XL`#A8X?/@(Q/=BE;K<:)FHBO=AHH1IR9XX5ND7ZQG=J---VTST
MOLL#;\=FU:!\J/97J9X($J@1JBAQ\>E7@/P7K3'>Z2&18*JHRQBX.Z5K'5QQ
M_WBW2=2T].>Y$<&^@'1B!J4$;W\LG-*4R1*>BA,IYZ<-8A8E/!%,;*C;BQUC
M#[[?DKM"HNEDB$_L#'D64+'G,G<)Y]4D$FY,<*%=:\]>>2(+@;@+Z^CB=L.O
M]A0*PP)G2I[1>+-'WQNG&'WJOV4E+Q7A3$JKD1,;J'MRJ3GV*^"9SX^X=1@Z
M2A8"HAM7G%%09@D4.4L@+78X,CO%?)YSM.[\CN*='H0*-#LUL4HU]3?I7WK0
M;Q63%*@F-?;H=AQ"=.=RE:!B00N6T025.$JG,97;JBVDJSD>A7TEIA8V_2R$
MJ<HTR:_<_C'[[1%L"_!=[`?%S/]@EII3,RI0!M'V#8^1=V#G9V3@&"(`4`&Y
M58D=U`0PU]#5ZIRAJK`+W,G("Z42A1BW5BN9.Z!&U1C(F?UEY._ZPM-`/Y8<
MAMZ8(V8QD@3;70;689?C3$K?NG1F_)3N5OG&W_/`*$TNL/;IM%9*>9>)8^AV
M6<PC$6966Q`3KC/W7-Q]?/ZPLOBD08`U7Q5GNX+A._IH+U.>>&9D_C76OG$2
M=?<=74+%;&4LVFS,T<\A2!DI"@2I78F*?U_9OKCOU/:.HUW^\5@1_K*?@TT%
M_,@ASJ+4UMI]>2'UQ6:B,X(SZ##EYLE/*([9$%MU<A5.:AY[(NH@897MBD2!
M?3W\-BU+.'S<KK5)U+:!T)+9*&[[4X\:7.&!&7MCXY,0C2Z+<%_@F8J,ZSY`
M*HEII;'85</10I"HV!E&3:Y?-"G5%*/`:<$(]X&,_NBX:::Y%K@28@S]0A?K
M<W"AJ&6>4UM\\3>_/)!=;%A+NJ7F&C&6VLK/#/R[?A!\)3C_O?F$4/#D`VXH
M3KB9?FPKWPM1#Z[";/^MVG1:KR0\RQ<ZV(_)VL1GBER<!MXZ,=JU<)FG,7WN
M/NBNZ@03?J/*L^@=`6Q^?Y++UMV?0(=UU761KI0RHM@!AO9!_ITQ?O\-QS50
M]\[DJS=D=VL.1XLQ\<B0?GV^#8VZRFR#G\F+HBU*K24@P\`._EA0XFRJ:+Q:
MZHJ@,6U&LH7+@)X"GY3P7]:,A,VI>//I,J[X7;YGVB\2HP#X/F8S/3#C%(8W
MPR_QE>T*FJ[^6@"L_='"`SAE'J"BDF[@M$-8A?JC_,)U(_6#AFPZ6[Q]\GI%
M'6NH2'=VH9E7D:@EU'#<8B42D!!:#`CS%G4'^S:!?%N+E]C(684B-?YL9>_/
M)*E*".N>,D&8?;4#2+O3U`F`^=>5J*F%FU2@9(EIGE?TVU)X\M9=."L5A=18
M<I0@!A591^/Y!=%6K"8I!)(_A.N'I$,G5TNA(2>J_,GNV"1Y`*T/1Y&2?%*N
MRC2,`L[\K&'!'^0"B'PB7VNJ5@JL/#CPF>RZ'8IG-F)<ZU-J'PF#NU:#VZ5$
M4!]<!)K'36=8N6U,1&TV<S;`UA,8A]MV-:O>Z9C#OKE!_*.<QFMO#,,\;T,3
MH<</#11^X'L2.TP@)MQUYI\^?R1$IF8O!7ZY.:/Z]0``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O8VQA<W,N1FEL94UA;F%G
M97(N<&AP````````````````````````````````````````````````````
M````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`Q
M-C,R,30@,3`U,34T,S0Q,S$@,#(Q-C8R`"`P````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````#P_<&AP"B`@("!D:64H(E1H92!F:6QE
M(&-L87-S+D9I;&5-86YA9V5R+G!H<"!I<R!P87)T(&]F(%!L97-K(&1I<W1R
M:6)U=&EO;BX@270@8V%N;F]T(&)E(')U;B!O=71S:61E(&]F(%!L97-K(&5N
M=FER;VYM96YT+EQN(BD["B`@("!?7W!L97-K7VQO861E<E]P<F%G;6%?7R@G
M0B<I.PH_/@I!READI4$=8O0?"PO)3-;[1<OW%RR1#=WOH<Q;H-*+,U>-)DF_
M69<6AGHHY8^--_U2%Z\^->12]X(PAI`8WJ@<R;FS3LCMR95O,YP>U9*KX92F
MB)V(14AD!B>CJ!SH=,L+-EA@?2^Z?P*E1B@FZ,?TNH;T'X3.&<_]G)0$:WWA
M*!G4!MD$5Q`1)S'G/:',77'+L#\_GLW>.E9L14+7:YZ&8&FJ#L"'Z`K`6U\(
M_*+;'R<2ODC^Q*[A"$B>C][WASG>2[<@1\F5G<(J;FX$/Y@QJ2V18%,TN,O\
MPG^K_Q,4M2^[S[36$>^.A:8,KQA7B./<;(58*X8AG)O%F6MH'C'+F>NJL$(0
M9Z_>):Z^>:4"UFM7)#5B?G=WM6NK`G(5671`+^T29;ET]U,?6U&!<"6#"((T
MAJ0WT^+)9140O(F\:1&.94H5LPZ#3?Y$P>MH*79RJ+!#A2Q"USC.TI>$30#'
MD4?6L\-.-UN5BU*OZ!JX*.>G6W'>LI7=_+G[+-%L5Z8Q[,;1F^?#U`JMA=P=
MB;HW\&GZ%%.0M3AB63Y2#>S',>WL\6PX3-.&2N9X+1+N%C78`$#>^1ZMSU*Z
MB2^6Q'QE9D_"Z'90W97!@'5;6PTW7"=*+?F>1UGY=^4%(+/2P4].]FPA'593
MGU1JC)#8L+[E>"[SCY.H&P7V3DV$8IL17_H?EA!FLB%D^-1RJS^[:X*+N8QE
M[=#ZHHE7PZ.A'V<'L:4J!^JD`=`H)S&'E0+.,&57+;&;M)$WQ4`8\+=23S;A
MUDB8-1I`C4,B[2+)!SW1+`I!:AK%<OSYE%A=@,>J$?"O+1%._71D1'/ZL1_4
MS";/+"<T=H*-WGCM6M*'PUP>H3M0/"N25P4`G:51G[1+<KQ>J-Y6PPJG:!1D
ML">\=\14$3MIH!Y81KE$QNV3@VA@D.8L@;YDX)&Y_7YLUSD[+ND"T@'F48/B
M//=UE^M-=\,4T/9R,^1B`*9(N?.WGVL$E[5I)FB"4G;+&5AJ=(C0>M.J&)X*
MK]J[%##1F,ZPFVLF3$%0;T]YT5/*`(&$+N)KXWH5_7I`U]MSXN/>K6KR5+%R
MYSB^*#--7QW^$+$V84Z9.B".R1+G.E#O*1(9Z>BC92;B)&=&!J(;Q[C#Q17M
M&4RQ6LROK.EU@>%C`[UJ7-]XZ`X';OE52^L%GAJ@2W8;(D%U:`&8JX<:&O4!
MZ9':XUTUER,@]0RW*LJ[`#+?.!J[A>BJA53P#I]`R[-SVSR4V4UYIO;+[3M=
MH>(3"UT^EU%XLD/V-SV']:B%GLS.?^TUB4`H^GL$AM)X?Z)`-F^?6=1YOE>V
M98_C#=ER#(U*Z>FW#*(F+C4@-O0BE6R2?[KEO=9GO@SQ.S!Q:LBW%UX"AJ'/
MKD/`52$`@&XHZ^+<</ZBAZ`-WUOVQK!]J(F<2!3)B[NDM1]?DTA@+0=B`]9%
MY>OVR1W)@SZ5T:8DM,*8D:2`@3"`Z-.)N5GUP$&D5!]OJ8LD;).O8&D&V9?5
M])I?N;!D^Q[+/MX!E9<,U*:^S=1SXP8/#R5H'>/,=6N+@/R#?XA&--1'I/+J
MPR-;TT(Q<*7IPW^?K;8M*[7ZZ=*L@/+"6_F2'<&#XC\;5OG7+?UHYO_740.V
M>'O2E?AF[M[@#)N>4ROT"!8E,Y#$;!T<C:S_%J)#L4%5OJ@<CME>`3:H0R]/
M4L4%(A^='MH$0JPY_9/TBYH17OFI?U@D\#[EU2%=4P1ES;;W\F8$D.PQ$3=M
MGXWR:EBG9O@J$61DHV1)\9PO^24'FYU2":;'PAQ$O>&"_*(/]N-RGL^J=5*B
M;X';8/#CHQ_<U6P7\O[((O:G>`WABB,%@929$:&<(+?,"<&EMZ.FEFY/&IA[
M,119]\#F,B*Q2/WD+9!ZB:S^WSR'"T/"V`TH2".W(),Z3GP+R$%>)LUPFHB%
M\W#@H@IUQBT8U8TX\MSIF;CL((^'VY:?C5"":"IQ28CZC&R#_?PJ*#7ZKPB5
MH7>S4"+`#,;C*2[]KC7A,+$6"^[Y6(2($7,S_9+(W9QT06@FGT"U2.+C&KG>
M5.=CS`:R[06VGK90NP#%RA[`@?/$`":T[,2-5[=*$&)GP.H@65'(UXBZ\HE,
M5UXD9)U`?9S9^*&\4C8/<'/ZC_1(]]@KT,?AQ&`U,9'3M.[OL":$2Z2OD>3A
MY/#'UK=8J]$X4T("Q^'O?"U=?=OP@>#H/G+3OPZYX410_5'P#.H"]S2UP1N'
MI/DB]\<5`UX+1CMNK[/+?"F1M$%CM.;1QCC#6(OY0%^'I&&#70L_?HO,:'!L
MSQ/-EK]I"N-RR*`+YLV%#H+L]5$7:>UK]2Y6ZA#YRJ2SD5;";IZ1>5)QPH;R
MLZ7NN-$OP"R*L3;-'*4#BMK[U=/!.MML"K4<2`?*B*_[DU80F8#>^1I%S(FG
MCLHSFK*:1F%+D-FOH(X!!^&N9/N)P4=@A[G0H.X^;U%*<I>\]D4[KU6<%24$
MFJN4<?!G-YLA\?0W5?Y\KP*.>H!HQE#W/N8!IRI^G^8HR>,#.`"5ON(G[.S\
M[>/H`:^,^7:/Z=//[TW!8DA=NAF4U\/TZV+M`M2<\DSL=L^;WW;R]?3,1P?A
M4T267]4$XN(UL%*G)6XYCK7<!?L/.;DZK+E[TK7E>BHM[[%LZ+#A-,?&`$U`
M^>O-0ECO><AV'`#[YD&<9E(AD(<>EE+>/'2\DG34;H#+VHQYT=1+02?K#YLD
M"^RSG](9?-'+TJ.@<X7`BA,<=31T5*-K?*1STXR\7?"Z<A6,!L)T+0)H?R.*
MZ.7%-P*ULX=:4MT4OGQC`<)"@PW1,@R[?DU'0?\DBW8$Z)PW-NI*T2<5X)Z&
MZ)*635=T;\1"?,A:I9!0'\>JAG75%L!D`PN>M1V116&CBLF3N>D-.IJR[..H
M^*PTN^X5=0^BEISSAEA1EC]5RD^^.:CT!AR:7PLGTL$\CU\-:\[0?%G#2-,-
MRBGDXOX4#_)O%_#:01CIN@?X.E@MSLE+AH^['21-3SXFJ-K,['5+0>KU:F_8
M11\-KO9^_JKF$L3H%5_+4H"+%#M%82S/VV-$%%1#U'.;S&%\\^JO1L@Y4;&D
M`H5WPFFUSG083)7=L7N?<E*IN:F_[--"?A[LN?2F<F)BY]2&.;8":-U3]$@-
MNF[>MG:_LQ2[9S0%K,LEE89XX4O&\X"K2%/Z?@$]1E419"1`S5`],(\WQK#[
M$K9.FKR.MK>"'Y"RJ!M^2,PZ$E"B=D`XT.W*UAO!29DSK-2`Q02W$"A)L2RQ
M(J_I>-]FA\>ZL-#_+Y@R^XW@L8VHPHX@68A6/&*\%.<&`F_F0<9AVGYA-73$
M<7Z%([W$_6:[*'=?U3)\4,Z!!`I_HP'-H!PAI77)LO>MEH)OB676];N#!W$0
M$>AGZ-^-&I0";#['7[Z1/FO6R5Q9-X>:6Z!T\63#A'(VP1)D#)]X`0<J?C;=
MDYRB-[_44KA\J4J.O]83NFW5QJ<>@5]DT@K"NC[<R:FK(@[)A,5F`7+>GM\H
M'N"`8(?UQA)'(EDS3E&$Z21]ZAD6]W@6:M^&<EI#UB.E_Z2/&7A,^<@<6DOX
MZFFB)LF'^SV,8RYN@E8?J#)\/<XGJ9];KU/1?Z6&X05DK]QJ/W]=G9%'<"5?
MJQYT?,.7OC'?3<O5U3U*C0@D5@9G,_S0!U]U4WFX%G).AL/$$#RV*V3*FBO@
MF2=LG<]"OC[1Q/M@EL2'7MC-\]MMHZQ1LB#CO<.58JX?@2,FLD#374X^8M/[
MJ^7?_8OGQK3*)Y&A&N[P4$3P_6!AF.>.,<.E[!R@Z%@T2+O<TVR*DIAE%!:_
ME?08,I'@SAK>1EY#+*+PC<N^A<HZ-"R9C*IBD(9#BG[WV&ZHXL7RE`;[U+WC
M5@YOTHXHXQVW(RRL`7A[FW2R%]]O;R5Q1B.2VZ%.=S';(`^QG&+C?^9T#J5?
M^"506/[-O1LVN6G@AU;?>]]+>TNH?O;"<6P5@PJ8%3I#YG%C0?0-'X+[%`Q2
MH_I-H99M]^H6@G![8>]3%;_;$)JHB=@26B@R?S-&&>O"67:Q]=2+!_/<(UV;
M.&\,#!77C(Z7SY[$-^R[Z`(_B737W+.H8[KFZ=*2\JW1%&D(G>!+>/[#@`WY
MK4D<Z,AN=(!CR`!UILSO^@G;[\;K,C%-04:SFD?C#5^?Y[,1-R3"J_@:>5Q$
MK'"=0%O8CU+.R6@`>&K\$(E3XP][XT-;GNI+R^Z*,T:HH':[5,$]O2U](9"Z
MO<;`!?X(</QA@78NKM?%B<&=G=E^]12?*RSF*9`^0IQF)!%.PE#&<(/_.NW?
M?;0_#Q'+Y4B9W72'\FO^YJ9%WDLW#1;9&0O!>"(0V!W(YJ)IA1?$:X;P1E!H
MA/8L*+;0P1Q&FY/\3[?]E_P5<+PC=X)$2-`#OH'?2^!B$'T'E9268_EPEM%M
MAQY.Q6^;-X!PT`QW?'?V/]]S)[OO!(<EP:TF4(VMQL[T!)49./-`/S^;RH/3
M`%NR19E?@0(]R(98*I-XC!233.QNU`FRYIU-_W?H"#[)'YQE)L8NVT5<@?K2
MBYIF]^U7NK\G7Z6Z-A[*X$0)^_=!',&SM),K:LJ9]LV+?CCP7C'MM.;K]S1N
M4L279_..V.B'">RVV&$A&96.,#UU-\4?28Q`3<5#(DV-#0!@R+8Q3AYQ@68I
MU=+PZ;>>C&BT1=5<Q&XP[6T.#DAD?&,N8G;YF3*22L/K8A(?G-PRSS0/1IBA
MQQ2Z^O+]!=0\"*34;_Y0C"F:`/+@"UZ"#(D<U"KY4C@S%<!!QK[8'"XQC7WS
M_XSURDU&XT`X[6F4YA\('"^.HI8)LD`-RI:8V6!DO6>]/-0K]'9Y)$L)W[1A
MAT+$.DC$=M3&-+\M0NK%)1&+6SS)6GTP`(+^A>G$U.UR)]A**QJP16-^]C@T
M[!$`H4[I>$I:UKHS8[S(DQON*B2V:QGUGD6H^DDVJ-AH(,(/@;$%,D[,9!O$
M=B]^@^^U#UPF/9V*Q`_+H;=5Y#X\`).,<0J1::ORVHFU%+I4[[%FQ;#Q&Q1V
M'_HC+<R&5U))]L$U,:QW:M,JN,V$BM([IWSFLOC#;2U/=]`VRE?J6O'K'"Q*
M6=GI(F89'?VZ8Z^<C/KWWL+/>\,6I`?_XH5,(!@F8QD4@E-_7_W<$C0[!Z1J
M?BK(O>2VII0]I%X\16?.&3X@Q/MZG.@6\MFM=H24#[@;Z^*M3&'$8:ON92_K
M+I;`0CVWR#G?2XHM^4@*2"_NN&P+G#D@%(:Z-9RFWO0SQ?H37_K(*"A?QDYN
MJ,J;G;#6^%)+R$F4L!1$0-3@#7ABO$K>N2"M69&1UTH#R-K:C1M1]JH1NFB5
M4*^PK!Y[XS>V`_%PY86[!/A722_SD`,-#PJ3U!S/S=E?<%!DON_WB=8!PZSH
M3;@2VV*]&-33AA;DO35WB7$W=C7<<\:8DZQ7L2Z&_LN6&>&*WK+?''J63:'&
MI)2SC109HH".U,YXTTNF'!>/4>WQ6Q.-Z9=M78;W9*);HO<IM9IG%*=##C<T
M_!I1>EGU$Z4X@?0:S'/EFH)"]P0?!GB0S?I(+<-O%O3Y2*,UM$&T*<-?/6<"
M.\`0L.355K24*AIB(+JD::7OR;@C[%\/2;$5J]8(,ZE]9\5>=MRJJ34HUU^'
MEPK(T-@[LWI]`F.28#D\Z=DL&%9_3=C1+LH!B1`![<BCJ-18FX(J^%M8;@:S
M(@?UT`.UNH*A6#@OZQ5F1D&,.8`:!+XO?P`<I9#S=E*J\*(-E+W&`W2N$G'[
MK_XD3PX18XLP:H]FV+2*F2"HB8SV5%?1E#=G-H_GAC&-1RT8$Q)),N]$:&^U
MJK%S`U<KX'=9O7<Z-_+\7--Y%(E]/0=(88(M59:_=O#N&3^)%65C[(!P+B1Q
M'OEUWS+D0+P2K.+$MD5,?0^6L")*KW97H,4F\8N.4_YQX%@6:\#'>.\FOPRE
M!Z6]L486$MNH:P:O=]9?22`!?7\;V+:>9N2B&C@CI*W4G&M&XR3($FSB2/+$
M`6\_XE]8;OIR'?6%NU-9V_P/\>,@+W96=O9APN",6?\*!-$`_=EEMK)TEV[8
M;)$8RL2X?ZX<UL+#@],J*S<TRAN^>+[T\BQ8WIF2!-X,('A&JT5_[O;_.6%3
MKO&BHH^BN?VV>/UOCB@L6.V'EK,6YM0TS8-YAAQ7D']O9X;0(C>#9R06:D@O
MIV!@B6+3V`CTA@T`S#F,RLF6D;PHE$@H6IUW\?VU!??:`#5>6"6\FS'(<2HR
MEWK<N_^<_D(`K?VUZ+']/VOI=K*88PQDMHGM+YGE-[3YT(4FJI84?.(CQ]<M
M&M.@SNF"`5K**!H!N#\V4=EN/,;O.#=)^]EYN0&\O<)+C<T'L^9\1[;+(F]@
M`WW9A\FK>E^96=T#%[,&;IMY$T]R-AF#ZC]$FP/UF3(PP2S-WWGL]-]#B\L%
M1RAP,(5Z%L,.V#/(8>''LYN[J\3_40YUOB)#?(ZOH13#73AL'"\C+1:%*UXG
M\%WW]Q=R&]-</#MD:*1I,%<:AB,;.7XW4QE/O&PK//=G7NJ<$%#O?X8+^<+!
M!9.%8Q3N?0=.H^!8VKI-H-WELG"ZG7,(##>.Y00)N=X5=[J=#U,27XD*\E.6
M(=01_S>M(>SZ@0GZK89LLX=X.8DB*5[%%)31'`Q-O=8P$D'&0@]5_^]DC7%:
MJ/:N[\>_+@P_MOB%S(W'0DBP3J33=<C7_)!H0;*P("JNIK]SD[\;E&\"]DLI
M\NCUO^=0?X+!"Z2QALF0[["*E0A14H_'[[SO6(&=D^D6"OGCH?&]I]5HFEPW
M1XXQ,(A;.)-\139B^:,+K.^T.\`U<Q3?*K,&MW$9D8V,G1R.<N/*A/?%BL]%
M*$6!7TLJO/9,X`=]V+B;Y=!U[45O$P053!L.1*:38W\:UV"5280`MLR@\E1G
M^$'U70$PJD9<[]0E]2U/G_]XK!?N(O'E=']Z[Y\B+5@#553.`]*8N/P?'1=+
M\1>HSNP21&!%9_T;6@Y'4H.R_WYIUS_J*/E?D\N1J2-.BI0_LZPV%5:FK[#*
MV2^!EF,/2U;%(@;SKJZ;ILUOFM4Y?O*:MFT[^5^PS/&I/.,R>Y_V,:@J"4KA
MQ\\::54%WDHZ$2:C74>..@+?F;<?*-*&`I_4NE"!?'?&E&>I'&XSZ_E"S1IK
MH'59)#)\`3I+>W&+I#ZO_HRPB:DGOLCFU4VHR%[T8MG.57:BZH=#,!EQ8!?.
M<N,S`'^^[=`JLPJ]:5<Q?Z*1[\1+2@+%_^E+3EE9?@4CXPKJ=J_WR"M&AR"X
MFK%VPC:MG3JH.0.@,?WO=V-2N1<_%G:GMN><*[BNVH:$)R8LIAC2%30VV@1?
M+F,@>7(,"YDHBT-C&3"LD*>P%&[>B]SI4.*+=*)?YW\F9%@0M0&U>V3_/0M\
M97ZDP-HV3*'B+N\YX%5P,'&>D_=?SG>O9>^P;&2/CDF(SFLVYE=SU\)Q2,($
M<DZ$@,KO+"D$Z),,0PC#!5AE[[XT7S<*"OF?&#U*GQPS!F5J=.:9]-WLFK;%
M?V[K;;]QKCD]Y%UOD#&>YXO4];=?7L$$U&E1+CPC#=QB?J--J.%#L5_#\7QF
M%M]-H,OEP3@6M+XKDK8Q\#%9/X(5'T*UK%6#WOXBA<'5RD#4:'&-6^1N;?>*
M91./."@3E1($1_:I^0?08^@;$7M[>@G1_STF\_O%O(<"$J,9ASF9R/&_62+Q
M)#!!O`:X.]?T\"%&P]<HS\1H=^3/O9J,`G8*!@%%/P#@**U!+_6!3,BQUV%]
M?!N)7[A^EY5E%PFT"OA*:%A""W3%Z1@_U(UW^R=2%68W7CT9%)P-ZP%ERG()
MQG!:MPG9Y_1PJ8-V?;5CO#&M<JIE&!F^<_PC6.XW(Z]^8\J3?@:0!G\FY]D;
M$V9'WJ/IVL%D+:P=F(FN$(SNF-7*#)31Z3ZCFT@FV;&@R5:K)`?%X6R[;?5D
MOPK,CJ27^:SP?6[797_E1@OXF]L[J5`6F0@+`FXL3I-D`N%"V'7$[0`@LG'Z
M0S.QQ59,(L_4*9[KY8^?^K4/NX=T(T?QFB@@,N0X%04&[!4E^94[0S_+76S'
M#9%L'\SQS1S#SAF*'U1Z<OPP%,7P%)ELS`LG'G&@<89/8<X5/PUT[:2FBN&K
M`76;`]7Y+X25(ML]-=]Q0`CSG/]>-46PZO`O)B`:7M'K8<>)@NQ'.Q^>\3U4
M-_RY".`(PD%8/CDD'@HCU#2GJ1!LW"F)6``UI(:9?]0%HJK5PZU8N(H_6<VH
M4YIR$YPI97Y1-7[IA8AK):"`*J,J#[V]6*1/24:58%"3:#I<!AQ\8?@X$FI%
ML+'19Q6TFYJ#GYT\0JNA)\+2AEO[;G":@:&.)KJ*[C,(O%ZYS76T"GTE.>RJ
M[9H)$^QCX913:ABS:8$A1+9)Q=N";RU`EGXL+N=7TF.;<)#LACH;PA%'%9<R
M'3\X:S#K^<_)I[T@RE7=F+C,1U$`%!"9;.TD:,Y4[Q!5?C#S.G[Z%S[(4?CT
M7$2Q<WI@F-,EV%:/D\X59_EWA</F5LDSD5.DQ=G@6#T+6BAL/ZK6\;#5`YZI
M($+Q'SPG5WF3?)5M52"I"/F)7-D:X2'DI(X46W*?F%0W^NL6T8YE.E=D^WI/
MHFI?9I>_2N!<N"BS7Q'`6-),E\D#'7JW`8L*QD0^")[7TASP$>)T^[98+F?_
MK::YRKKOST9.M.F:J=)M4^Y,"1K_7ME[;<ZS"8$^/B%M=]W1+F4+?#Y-P+*2
MC;(XEDYRH?*#>N\+YN)]^<]WU(1J_"+6SK=5]YSJ_F.(_A^IC0VM7Z;$2:1T
M@*)*8R@_XY43351@W(,&!^[D3F-$D72J*XR8JW=V/E^;L:*-&'V-/%0BG-R/
M3R&C<B#5T>DG?+2`QC^'(7'"&%8LEJMG)<U`038,!;1Z2A<(<3D-``QH>^*F
MJ781XH&J=1I7U1)+KL>2`SQ(`'SW\!W/%N)PJLOH;NG)U$_"SL).6IY01:DF
M%KRAVDU!_)%)42W*4H.&6]HRQ-HS&FO,NQ*-1JZZA3R0V%EE[MU891'SUX5.
MAL/,!F:\=;'NQ]9B$DA>@6L(N.`="`TD]2-$PWWYL9"0>=^S<O!8+AP2*5KN
MJQ%;A$1](V/?Q'*R7BY#W51R:[+9I%3-%7I-H3,H&MHTB<3"-`8R"/*U6A[?
M72A.J?=.IM_G+RVMP6=\<6Y_HH*9,9Y)_?8R]"N=3?DAEEV_BBH0@@!NRMG,
MHUL/DD'2K,E<(>L3?(</E)--3(+!PJ;3E\CD!PST2#-)_T@?T_:L=:J)R=E/
MA8NG"-"@]7V-6^6F%@HLT<;KS^;5GG5@4)>6A_"%&%AH#*W:S6B4OM'I8=ET
MGYR1S>03J9ODPU6(<B7>M\3(@"IO2[4KWY75D53#KI[B((#=ZX5I)1<S6XX;
M3IE"HHAS#0W,95:[H&JH.MW?2.CR$>BUWY07W%BYA/ITZ..R4E_S$7:Q7ZD_
M%GS'+B,=U3R)[@26\=V#K"Y6B5/,O&R5</3W4&8IUP.V`!5^#EJRJ4G_,%];
M@\A-@NZPV2-906C$7YTXY=V(D&E_8_=$J))&(`R0I:SM_,-HR0+Y_EB',`VB
MV/?IAW)RD#MWUK(IU$)D]?`K!-<_$8^-KKTO%D@$@\Q:%"--)/MNK]$,X$K1
M&GIM(3'%9__OTF'FIK5&@%<+G-,+^0!*,:4Z+%A$0+=LALJ%C_+-M_?:,:+D
M1=[+"\"ZDC'[0[5>X<J:=6CX5.JY\;K2?`Y\'\2^P&QU=;]9M'S%F'<^@N8F
M79`I%4JX14=%\@EWIF9NG]PCE70<OTGJN@[YDEE$BE5:+1:W%_#BFUQ9EO#8
MJ/8L-"V6A0N-M)B:9QG:.2VKBU<@@+B`QFF@V"/HJ>^=/5NZKO\BU2,7*8FZ
MNT<:/@KR8A5"0?V']4`<-]G^&TQJF_W)[^M,R@,-ECOHO1)YZ'M%7>ZYM6MR
M^D7]\2\N+>/N57/,`!V:M$#KYMJX)X]\#TE?"S6)!6]]Y=9H988O"RWO7B]Y
M`.+30BJ>N0095B"VG)ZP#,N4;TK$3P+-XWV=:;GJ*YE9TK2K!%-Z,N0Q*]3Q
M^U$WN,&<6R.5(#Y=-K%X6-V5C^ML]Z[26K@XT:TJ7(9=_=+S?%MCL3J(RNAY
MX'F@FPS?OJEI*&?"E\Q=F?74J,'7Z:]2I[-,092+A^X,QI30LO\=6TB?3'0[
MSD=>A*YJP%B@Q$SW1CHM2VV;`,XS6@8V/0VW7B&J.CCJO>%2.MWFTP_?JLE!
MGZ?VS)41R95+Y0#[0MJGMH)T&<Y&]B^?!]+'W8-<@6-K%K;!P^*U<Z:-WFZ`
MPWKGC<947:F=SVFKQFU4,Y(,Y]=+ZCO1C"_(S*ELA]88:N3:@R+L-O`XA2G>
MR265T$FR`.+!*DQQPM&72W4=09'TP1=V,OD=QQ<(>?S`S&`*JOUV=/A4%ZB0
MH7+AGWZUVM:1A@NLNPW<ND^C*JF>ILZ$V,FGK/IB4_Y`87<3"Q%14[(O*L8)
MR>BHP==A&]A!F=QK%O:Y8H/(P?-&NY);M#W\T]^5/_R:I\`X$8$O;8(P_UOR
M?;ZTP3FI[0E+K3)4E2;8Y9#Z;[':MR?PQ$V1[D&OX/,J-R+=V'+6^E5:^'S1
MR#_Q1'@;`*XRZ=V!Y->E?<#S5<]!\L%55Z\MR.:7GT13M3&C%(S4=##W!3;+
MQ:Q"TEPB46''3C=NFCP2@*X\,HV%H^UX4N?1JM/IH?;<SD58_=%,UZV!02=(
MC`[!Q4J'[X4:$TYG0>3H)GNQ5Z#0WO_+6:Q'IIZ_9=O]]VF5L5%U6/,#*[:X
M>C%.E"GSJZZQD%YX$S3=3$R7RK;)D`,`A[.9JBU,$>UI(+%*F5_6^1(8ZX2U
M=)"-=F=;=;"OOOZ''W"B_*S9YSMPZ0[5.3\WM\&3IV0HXY<!71M0Q7L@V=C.
M5;"1DONPL.#5(&$*QSA2#.863YIEUE`\A+A$3W\QE/@G+W$[5HBE:1$.:T!B
M.Q\!648,!=4;I<RPVZ<ZBH[_H%&>[T22;$+>N).\"\MY"9;C&RR>I2':M3D3
M:"6KK#A+&@/SGQ9TJ`_'&-E`XL3H.8/;_3=1A%#2*LZ54UI"(//?I^=\MP-!
M[6@!KB_<YG9>18KOJ3A8MA`XTVN\NV&0!X_DXB8]]G-N_32W*YU-5_.LD@5:
M)8!]79UHN(-<(,M8\B_4I^-T_;<Z=NBJEVFM)`!JU%Y8INLT6^M?B"8<DQ[M
M&C3(!""61]^ZS/"+;3LI=GTS']_#4,U\Q<ZL<N2<S"R\Q09OFJ"D#Z._02V;
MJL+:=!GKFEKW??_+H>,]C*_`6Q!,CS0='QA$\-7F5C:IID`Q-KK0X'7PU^2`
M'(WFCG1V.*^A.S7A?,>X0Z%_9=P,KQ*D#H,`.6I\).3-$9U&`=`:[*II4#AV
MM)E@!:!P\X&R>)NB!0;(82-$$&,\,?1M,(QSKSYO7QKLE(*8DOM15;\5)5'8
M\KK?=O$FH-%,ZT@&04@]NPBQ/KV4P=8MG:8FX6AJK5EC!G$C]^&GM_\Z0C]H
M%RO>79Z&2'1AKS;?BISQ:7$69+HC%?6A6>P<6:#/\NU]]+N\[H/_)!NZ&Q4;
M^_'C^20$O_K%<[TRX\J'1PU>X%$!H_W\G\0I4;OY0=%YV^-^$-&Y42P,0PY4
MI.TW=YF7ZD_QA<'WC/_<91-_NGV]U\<SSJ+5-X4A:FH,EUA;[O$.:T]-<:_7
M,C9!&(X>`OGVO:3\ZT/;C`TJX$)E$B0K5J6;0;5(2[P*83AUVELDG#5^@V<%
MO.<;IA,;<#8F1LBN];E)8KRT2!'#]QJ4V:)1QX0JK)/DI_<X?NE'DP?[RJCX
MWI^7A-;D/)<&Y?`ZL3B&I1,&&RJN&$;N$*J6.JUEJ,CWU5&!C=)43?FVRV!<
MO_%"T9'MI\]D/<Z[S_C4Q1!:LZOX^"E"5_Z+I,$!*+3H#&0O;;Y3HN1^^/'4
M)8AA\$4"T_QG7),'))Y*1?W/]6THG>"%RG(3.Q2Q(=[SO>LG(FBYQ;SILA[U
MSMT':#+-1/"M&\<"-H_V<R$8<DX:!5I84631D*%R/EX1HK'I.)S"VGRR%;>H
M$DJ:."\51]?;U?^)OMF,]E/0*609_'?&$+\.%CX4E_Q;-D&#R4QZ%X>9`+=&
M]2-*7LYE&>+<^?&],^3^&B+M\C`"?T+CUF!7E;=!VRUV6G+@$R4[]P@95>4G
MD$W7[9N&\K%L]WJ-FLJD&]+\:+D6[586N<O631'0M:6=T".$`8$;(/G)8AMU
MLU.(@'543HE\%6_73]IZO9?-V`V$)IQU-)NK#THP=Q'[]3^*<L3_[>_/^52F
M/?]/8DR\:EUPXOR0$YD(L.VEN[Y'L%R'(7GWPLD@1(5W`EF.">],+Z;'-44;
M+\EPT[EL#_/]5,4;Q]H'ZOH+O_]9W+<WB;&>E-;%#OAETV%.\&!;U+7U]"45
MV"&,UE0"<DJ>>0I0/`A'ND3<(_SB&YT!I$J\4CB5LJL7'V893/67XU+(#UQ[
M_HW+XEJ'S`)S-*SDCP?5A@%=;Z8GR4:<?@S'A8O0VG'+I`<CAS^,9LM3,8'T
MN0]'-C]W`FC[R!1SHVKAY1ISP\ZHZO4U>X^V0K/*V1?9\2_OTP\9,1!.C4%D
M709WU8Y$T7JJDGU^D6KA"[M\F9N<Q-X[CL).*OX519T]$Z4SR"0K#:,3)&5%
M.O#&+FB+RI"A]GK<^)(U.8CJ/S[+4Y%*G1N$BI6K%4@@NKVP8J_..@XW&EN3
MY.E-#.]QT'K"@!V:$X22`%OB@@<ANH/-M,V@)@J$^ETU!USS3J"ZL'Z2$,W"
MR`CM30O::EY]GCWF.0-8;U*L[/]!;7*7]=OJL1?U@DOKME9S$;EH:I2Y=\.D
M8799/NNNL^B&%0'A`V^%#\%AWXM8QZ;>5=1-]6?SR?(/Y*XSMC)\A2WHED:F
M/,4"?T9@K+$(;%VD![8]['_*?D+:G:(43W5I%HR7;7TCG4$(3L&O*?02\*YO
M2Z"XEEP*T5@+*A+F9I!G2#QXEFO+9<P;1XOPIT/B8NWARQP@KA"Z_3)"VZBW
M7&*[?;#<#W"9<LA9J2P?+2LASG!B>M%MER"9U`93I;YTXFEV6.8)U`U(Q7*:
ML[%^/,KH^KVW;*ISP)RC/E6YQB4\H?6?(/EWBHJP3"0O^+^K@B2FPTTDP0L5
M.)8D@EZ4Z;FRH(/=F#-()UM':\K,34*0\=;W.RR'3^\+58*]P:/&O!G(+*Q-
MU8WJ?N1^ICJ]HT+9ZHDAE)';,D4<5T]X:V:(E\:`[(F*<0)(K,L>Y`@WK8W8
M'SM?NQ*D7&&<(/ZHT4%L0C*$T6Q-&E5PX52B:@0ZDVM/C%@<:0GE-,:3>M`S
MBSR7<.M:]@A^"^0AV#:?.XB2G"*$.H@1!LU<I`U)(Y"[$*3-4'O[)V>"#>@&
MG]]HCFZ.F(?!D':B5+>TC"U5'@V=2AWGD&G12U(..PL?LD#6G7Q-K=&&(FC+
M8Q>HLL$^B,DU)!GLRNN;TI326742&#YUL`Q$Q9MH@\A$Z84'MZ4`6.N$E%A?
MJ]?3!2CE/G\FW/^SZ-+5_<0RO.E,2J+;2#O@@=KLR1J\^;3VRR2*(5-*^'F@
M7YD)Y$V]_=U`LY,:*:DL4DECTJV@TT$Y%JUXMO")S8[SIZRF%,$Z+)<PIO@^
M$6@5V6$$(/=UOZX;!&V]J$S98B9PJ?WV$ZU=$*@2DU68,;$Y\R+S@TMVH9QO
M%I'%@WARSJ=OK)E@B"KJFAZIKGFGFR4<A1+FD"S^</H#C?\)9``%X_Y.4?%5
M#(X&/O7\&9Q%8-)/9!()BU7(ENIQ)Q\W^2V=AT*#15S&U,`]Z2D!A]3B^\27
MQ.R=G,E[6]S22)TO$1$!1:4*_/B/*_P9FAQ^9PR?(^@<"BU<MLSTBS/@8ZT&
MF"L<<8)GF-K(E1O^5'\_*!C(^,"@<(Y]7C'0E#8Z-R*['R%-TH=9AZ\P%9QI
M:.P/&6("=PG>F)O#-]1=>G3]L75<+-S>*&8R&J2PW_&?]1LZ$'[T,BM?/(=4
M98!QX^])*;BTHBSA%YMD7Q62*PHIL-7FCG\!%RE,6I*8&LJ:-.!/9,$?U8:6
M:(%XT>L3#:F;].U4=T^X%.(<$%?FO-9(=K'/#!3#[L5I@6TPY=..L<T9E1G\
MJD]D?6ET[93T]7N!6=0DG;J?6!_$DA7!G=LPB"82V>9T5907@/63K:5$O8$8
M=#$?(X\Y*ET2)&#883O=_)(H6^&H@/FVZFQG`77O^>CKYH->G/ASFLU'D1SO
M#G/\Q"E?XE>5"_C"+76YO9(,,'C$`$YXKR,HO:9GJ(X,Q^^5B+6/$T/TZWMB
M7!YN-D?GO])T&O[9#RGMP;%F;@1)5Z1(Z?[WE-D[M4W&X5B!SY\UU&A&5.@3
M"SO:I"B?+S[@X6%*5.^+WP*(`2[U+J)R9&%ZBM%/?CNSK(G)]#Z7.(J51TS1
M<X4=,K*^J=HNX[N-FC$$$27R6-3U!*&-L3L=@/^199KU#?&+1P<D1G:%,MP@
MM'0QKWDG#5L8N^N4XVTBWP\4(NC8;RGJB(4_*(F&31X#/=$69J(>?JJJ<'E!
M#+HQ4_QWQ.`T1ET.(%'W2%8A6V-]H=P4;#*B>!I+\P7&FZ_K:^G5Z$`C^Y1M
MGQV("2`#7Z;-BCW(+G>6*L5=>356?87=J(31E_:O%-7$)T7CZ8]-Y%,*)0;N
MY%UKL:2&P3K&3-A#-(U=S.JO-.'0P'D0I[)SFE*;XKKZL]J*;#I:OGJ3R=>V
MPGV<S@^`HB/"Z8WJ:;1WZ_$6-T)UL&H+?</R6U<:@6&!R)<"7(2B%GA9N+3F
M*Z_&D6YJ@`(%&6<Y`4R;0FH-^]U)`K*3BQ&`.HAH7CCE@H#8(-F22(H2)`4[
M?YW&^.Y^0L87FO%M,V#'*`.<-'SM$<;C(`M_M[>7D)U@2+$71H,"EU_Z\D>X
M8X>GQP9FFQ,Y/JZ2I'%\Q&AYNOYV/Q733]?[1M10!1W9)6:.2C1YJXSUPJ'M
M00;'.XOY<VT\NXG=IZM!54#C70MJJ/8MY=[JJ-LFY./EIJG:>K<>'(]_[V_9
MHD!CQV?.G&:H-;T.%+77M22^]M!46I^/61EQ80W"R%BQ(6_J"9&A0V-6S5>]
M[1V;@*$(57'4JX-9XJ`5NJ.6]5#%?4V\73U\$*7^(UNQ(^!)KOC(?UI<;UYR
MGX(\Y*?>1Y78;Z!LMDMIMWZS'_?:(+H#;X8%F^AF8;<GN:K$]&B$2I;*09EE
M@O/,A*[+Y)"C\)V\54P=J:Q#68XS?*=2:-WKR1.=YJ8=8$Z*^*7Z*\JCC)D/
MO'M\EO4I?SDZA^13ZO(5UF]_5NA@GC30#,B:4[V)>C-&N?D$/!CHT._JWX+6
M4SB3X=3<LU)GR'S&V85GPJKK8LC09?2TW/X79`(B9@+4J5O0R@+G1R,K'<X3
MO5L%#@(E'ZRLG.6^X<#QSLE/GAK6/(9FR_6_H<L^#`\BE/DI$<%'$S)>0\J7
M-F,*N!2.PPE_0<5QGS-;61[/6G+&<4R5QT*Q`GSK$Z,"!KDX+P/@:B]_&BPF
MSC440,GD*C_4Q1OH3W;?ONQ.CM&S($9*P3W1;P3XI6-)C3ES@C<B%6-H@A%#
M555_^"+SYQ\%&#4/8NI*$LB>9)EO!**A)2A&P_9Z?"`TW.LF"EXDX;(4:(N8
M>*5DXW3T\I@14#KE<G!:O;$A0@=VQ?-R12T`R3_3LGE'<9/Z3C..5\*-[Y80
M#PGPCLX3YE\Y`R;+G,Z:F4@UL.E>?&4`[SMX1?94J;U*AM<&`I^$KOKD:6/S
MT6I4P@;#]C['*=_>],'50#^-2KNQ^-&0*PXV[/!'9,_(5:MG\)RV3HXL4]F-
MMZQ]UW]2CX!G4;DWOO"\M8?DJAO4B$K`2`ZV`*2+)PCR.?+NMX<!W\F.XSQ$
M8QJ2X&R)ALFA.6V[..L;A;_>)6)\<9\"3%)\[%E77K$=NG58[=G3?"R&-2,`
M]SG:"?RFL<D%12VELJR+O`^LXB.#M"%583VGB8^9HB4<S,@1_!AK:;E`6H9O
M?Y0FG@@:7/'?\MF.O&&;ZH&F'E:,28#<F93H:>;9`&,\-&TGR%5=8%5P9S35
MB,79U=*$1[R9A/[7AZ?*_.),9>INH/QH<,QLZ(_^M`U]%5IKZWS6(R*Z`D@.
MFHU#2`ABG;<*L^#L0;M'6O72>S4,#J%-&_&/.XJ0XAV$\_K_0T\Y2!PB%4_!
M>+`=]"^6"J(+A^2VU),WB9?UA#(E=*L;G<I3CL)TC(:L)XO^:2,"55#M!R3N
M@[J^?7M7VW_9C)]F`BM$BI!HW>:XM/B"CL(#SX9W'U#W6J'"PC?`JRCA&PJK
MYH2VGRVR-.FHLL7VB'B52V3(:_XZ3'$^,&L62G9*)TUJ?Q$&N[$UUZAQ0C\Q
MC69Z"1I$1V")G2;?*'SSV)Q&5F4F<S9M/;W",ZBZ"KPZP)Z!I]EXA4``D"55
M^'>J?/'R%N:I[+;HR7LEA8!#LYEU'TXI5YNP\8%"U3+4T.9$KU>7?:P\SLR@
M.CEL$THXO#W/ZNL6^LFY:=`N_UQ/)M",R;ST4M**J2%V0.5LS3VDIF0,YF->
M71VL[4PD^G;H1H2AC:U!O/^<K"!J1XW$CA=$@!LG8(SUZK)G'D.F,@JQ-+G[
MOAU>O(@)LY6&&'88A<N(#66^V.#(7L2CO675B%SLF4%8V1H#/()T$RV$2/'&
M%=@[JLA\#WK8HX5OD?-GT[0Y2$TJ!NQ!&U\H@4#/*YS+P'7L'DU9_T2.?`NK
M@4+$FT9N\%#=*Y=.SO7:FPY?.^-J;M:0]=GNWV'S\>[@X<T*+D.?@XBXC<)/
M&FB@$.E[Y,+.!B3R&6]?K''#_+-$_Q_+GJ!E9ECO!W=ND4JX8TGNFP\,,I(X
M,W1<6[.9_JX849LS1L]+G`9(>O:D(,4-TJ=R9Y8O<=-'Z;#7WO<]64[J/RU#
M,S!BC]^1=T:5$\.3*^UY?>ZQXKCWO1-YX"4@2T;J&\!RSG)J*'9<"K-'RI<I
MU`_L$\+XPUY]0^<1,V-#3T9B+@)1O15Z_,CB`?2BK0C=1375]?_/(#8P=W]9
M,=!O*XK7.1^1ID\KH"6B^\\7*AC%9S@%VI)A>1:SPK"<)Y=\8_F#`VI0.O#S
MJ+1<_>L*/MC(QWM]J.&"<'\I=?BW6KR`U6MSBG/'>!(M#,-S-EB&0G9PQ)XC
MSC21IMRJ&\Q*C?M_S?B+M&[=X5*:O9)<`O/8&(:,?DH=QXW]@XQG]$!&AYF;
M2)I<\N<,XH4%]6P!$BH[Q!AKUT0K<M#2P>W76*W7@"H5E=\%F->0EM=04KP"
M1O@G.Y4EH$M*S`)ONA@6*S^DEV"17J9O+SJXFF$(`!ENDW._S^8CZQ4T2Y6/
M6(UK@RS&S_SWV90Y-"WRD1!A$0V4U2#2+X_&/<$#6\SL$SM#RV%W"]Q``8A;
MO=V3+_LCY%VDCB)KL-<'#R('?\R]61?](("1W'EFVV`)@2BIP0(:]L'EFP:_
M4[GLRN:T@8E7K%-TX14(KE-(FK_J7GX/QT#='.%"\5O:2NRO)%GPVE;U]$K^
MFT34NLBT^@0NG,-%X]2X)>"V]<JU89##(I1C'6=UA00I*GZTMPB-):"=1MR7
M#Y!`,N%%Q7F)D4EM^UVIWEB=;FW('`(6A=(?N<`+#'J5T`3\K65/#NP*@+1N
MN=LRV)Q,\FJ//@6<,X$S`8+=U!#!*>M"#4O&VR>O]I2"[6ORS\^NMJW7;H-E
MT&PY+5IF1\;)-$9Y7!)QRD_35W8>58PO0</BK"`/+)1=.R@O52P<$2Z(3."&
MK**7F7\+"<H:&#\FP\73P]>5_:`QM%2X-4KEB6"GL.,9C[5H8A]YY[:6.*DZ
M[+O45A]OX6WD!H:S6HF"D]@TVSZ_"ZM$B0=2(6)3&'@BJV^J?LHX@W8&0`72
M8@'H*4]G:">-%XX]D<!OCV>K*-\=X\B^+E,A1^P52K*A$$2E;O];I_[)+,7J
M=156$K/+P=6+S/%"8OHIS#*LMWDQ;:#I7K>F6*1PBT_$J#6X:6N=AD:3GU-@
MA2=B,O(\\,)-NZL9!$9R:^VI!V$,:>Q"-*TZLP=MM_3S*^2?);G\&?.;Y<,R
M`>C*A`'BIC3(ZKK7PHS'XA?J5%UFIWZ-,R&0-3H2%LY/>)AW&`_A<B)O"TFD
M?7[C>"&LB^#F?*AG6QIT&IRM">[Z$">@YC?*JFF@2_3A?(DN2_&=SN=I5B>A
MZ^XU3@$E))O3W(53W(^DR&H1_3.(=LG(5C7.E<E@R(BMA4CUO6A=WVG/&6D=
MB([Z`L/R,T7[WJ65^\X/J@80?;?I]Z"9QT[FL]76(UYPB3."FYR3["!,<JO3
MZ>%B='JOZ@S=!%34;"`Y8B1<VN]HW14_P"Z(2BW\8KEZL(+KJ*%$>EWL%GR#
MS0;Y)$;_1EXY5?.*H5;4E.;+HZ$`91ZB&'SR-#(KOWS$ZI),,Z]^;!I`P@8%
M8K\*;ZI$M/&E=:;>7&7`KRF!SYHF30B@3S1]+DWK`PZH\?0C=%Y[2'?T3N'\
MAC`ASN&THFD')+J1<N83)L4/)94H3:P\/#&)K>(RC4!6#![WN0@6Z_4YT\MV
M-I71.B#1V9#@(WDSA$2I#D9(J0F4G>%GJ*X"PCBO/J=RZ@M]XG5VF@*NWH#>
M8RA9KXF*H,+UN`J[@=)CR(!!K8W5`FC-+X#)UP6,>4S*?Q"QM$1#ET8&&]*U
M\\7'?Y1,S07L-=)T[DE,(MKHC#8N`@]*51(67.$CAA#::3[BL?CQ1NN-8SP/
ME!\9_]MW6[FD*O1N%H<+6XN!$T(XD1FR+R0(.HN2(%B4M16V9_<1YE03_QSA
M)$Y64+T'NAD;H)`??09\SF8.`\MH$/@321PUVOUP>"C@6S`9#BFW"X5<]-$=
M[B('!ZWXY[EP[L-'/V]M"O=%7-644#BOD,V;UPY0^U0R-Q?GGS[B74`LA'/7
M:H(+A1C+R\.?VZVK4K28=[$/=.SKGT82#2-K"G@B0`82.U#VKR,3#@#YT8/'
MNA\RA3T(8;ZWOAAC3X27,D99-LK1F+%2Q4T\"'7^@P#SI7Y4Y+S7GV1$>2YD
M>4V0LGQ>:H_CN0VZ_UFH1M=B=K16)7RLW)*-GJ24Y#QH!67W.#L+\K*&V:6U
M\ML;-4#P72;9_YT6'LG!S39PRW&>SW.<S_NP"DX?`^*;APC^5W%TA(M>CLQB
M'9<(IX@[*OMK`S'LM?ZNF;OYIJ>80AYQ(V92Z)V#O,B&A^1ST$[:?5#<U?P(
M*:%$KGL3P#,?M&MF=EIZ8ACD8=\J?.)8X4C6"?PXTX*YE$%]HC>U!GI@,-E*
M^18#>F:4;SB(1<3]BW!E,7OP;]+K>:$&R@[[":9>=)&T`%X\?&%SEBI*,$69
MWP03=(.$3:TDO)2,QUQAZCR7ST4%A$*N8+P:E9>Z47S*9N#%50'I_&?V8Z5L
M1BQ^#F)E%H_&\N&ZY&/.6TK#6:ZE!P7!@AZQ8'K&,'RJI79(946\)QH">W7R
M1W3Q_&PE(^+MA.&A7<-]R/[!<!9?XJX'I]G<+G@LI^G?G.PI><+!+R=:N&I8
MXRJ\XNNC/,`]%SLU+JQJS"43LX*?T7<#$9M-EWR8[8=#^7<$5E$K.T+1P=?3
M(1SDHYD!)I_LPW)#O2Y"FX1EK419:'T%BFO<[85%W$M4J'S7)C^K2\NI>3>K
MX,^4E02(C2@QE[>)R,#?\E>7W1[Q];YMU:AL-[:O)#:+8%R"N+8>[\HV@R>!
MHAW^0,NDS5O'7/UXY!=PZEX\\*$EU0T+WQ^)`O!;&]IDWT'ZV;F((]'!RJ?Y
MI-4RB#8AMJGQU@>X2(H'U[_X"?>\QZSKTNJKHZB.2=\GT,XP]6=VQT9-'[9K
M>XM_"U&W_9YL\/L2N<#T4N)`K)C=+!'Y/FI/:](^84-3)2099",)^XGV_5\,
M!=G%1&$;2T2+><83,>I1">$[[S]RX8FLZ.1LIB&3N0=%/V%V/DKU*B1L4.3\
M:'6ZVBKD55!F=$Y(0/E%FZ.=@^W?_K5S`*FC2;<($')UH:_U`Q-8[*HBD"_7
M<$X7?K,&9+I2YXRH)Z%W.Z+4S@Z>*G<\>;M-KQ8DF-Q+^[!EX&2BL""@]*$`
MDUQ((#!Q`C?@PE\=6#-;'*5+.OD:$4U*0(J(.\OWG:N=FF4P%,#;),C>M4Y9
M.L9;-Q!)<,@S8?VV)DWHX](TICA.*3S>0R'Q0R.Y%?OI'SIAE5F"G(JL`-#^
M)E(UJ!E[]4Q5F""*9O$@Q<VD\Q]MW)Q6\QY=BOP2R@57P>;8Y?JJCRZQ%SD6
M7290/QIH$-\*1`ZQ:1FU##GJ3)VTX@'9AE._`(("=+V>3F7Y#0E)FMQ&7&0Z
M=R!C!Y$X+A=*X4DUV3V2!_HM.(!,@`?[%<Y)RP(UYW>#$X]6%/AM_I>EX#%:
MPG5Z`0Y9ZX-^Q.W5<=-1=IK!1;4`^1F*X+.*^3,@0+I1&N$#D&J$0[AAJ(@=
MH?.+<$6(.KG0"_%>(QW1F?&YDEML'ZF3P5Q^>TVO,D._$]6MC%"ETWQ(1ZAI
M7.R_UVPV3<K8,.#P0#$M">$<O1(L=Z#'4!A2D7<]Q%,^S8Y\Q7/JD,?;A5=+
MZ9'R?>D]CHP$$ZF;11SBN2$^Q/$*4]VWYW;+-DE?1:,MQ.U,/B^!0W)!RMO2
M%N$,P17&E+V5#D+)(B$C40]G0PPXYRD+L4)C8=D4BLG/@'\J.J,:O'KH!]">
M3G]D3O=@$3)ZXQ@?8.T/;Z(OK'C1@@Q/@[";'&J)J(7C7EB7"6`AB>I5)K>:
MG,*5_D^O5%I&=\=K>)1K3U`UW;T/&=6`8<SKML%%(FKOP];J)B#-Q,3';H+U
MO/[I'=I!"5*J+,+X(C:RE_E'9]?2\\I//&'?_]@^J81$//9V+)53PF`E0LG<
MD'F,N9Z#&C,KZ]WQ5+?'ER?T:'&LPPV@_)?X\A_Q_1[/U%`7K=6/N((W./^'
M3#KLK<XD%JH]>V9O$NR2:RRT7+M".!AD5?R#VU5/]UXG!G".M9R8I"@(=RR5
MA0]3H]&]Z2;^26&)$A9-N#-F\7NTN<^:M$@0H*(F_TX21^19'I-DW*:?#J6W
M(E)Y<`E>ECXBT5/$%#B*;:U?&G"QS=*:PUB2!H<HSX[N9W]6R2NJ/D(S'IP_
M%INB4,RD5%./1BU_4?]FTYZ6E!PU-)8(I#%4P!:AQQI3HB8!7R_H39]M/JE:
MJ>_JA<%,2V_*\8"^.\1C5:2AN9,76.9`;6X0>Y[,2*@,+:W5O86XUKN0^M%3
M2Q\G!^KK!Y&C#4J$[(A792^`_D6`BF@`_<E?9Q.)X/]#0?;'7`@4045Q`M#\
M;$&ZNS'+AZQF`#QA?*]-=VX,&NSKR[),.$GVW7I!D<W7_,+ZDE0+=V__&#1=
M3!!L=.=A)>PTSGL=)O9KTS>J#&O^S3@.LK'XUZ(2*MIV]8MEN=1#21\8?:P^
MR+WJ6M<4K&,*^/,K[F1!]]D5'\D`B$]\;=QIP(D4QIO`K_"W"KOCW8Z"O0LV
MI/HE_-(/$2/JJL`N1Z6O+3PBU!J@EC;,V`;*G#;V8R3S-TV[U5N.Z;-1%X<5
ML7RT*%O[C/P?:W1ITP3XWHM>4#RE%,?<8(7?JT8=VGW(2KIWP!6"1MCZ='.#
M8D(B/'I%CP.YO>!-DAF\(X*)\)X@E#6"GLZF.HVY+O5Y_\K,2,[#;RG2E`B*
MM2]V\[(63SIWE$23[2.B.7<X!3KBG9:EP08JYH5D7;DBG)U8+E`GEQ$41%'T
M#(DRP!.>%"2W:."'C0B>YPLHG>$04!!`AF?!GFC,`[%RF3==D[$P0PH)AN5)
MUGJ0B1ZO7`>"2K'\C&#-):[G9OEK[8.9IB"&"Q8S!11]_#D)$:*S`L-#`=;U
M_?(^0A01)2=<#XZ]^&_$VD**AU7LWABL%ZGG*@>]Y_QNY]&<>:K3UTWA(@-!
M(L'7EQ:/T+7KFZ^3SI+,0[[N>-N,!W-KS.5+AGJ%H)HOUFP&&'?KZ,K*D.3-
M+;;E;M-^I>@QH8/5,2B/^#5BI%UZC*K]?P"D&:=Q>[Q=\?3$VPJFY7M!DCL^
M$!--'H)ZQKQ8(>D>;@'TPP6JQIY,IG-7_0A*]:4J^CQB9L\95$0<*!UAW;L#
M:N2RFJ+>TY/,.;01]AX`O(I5VFR%1(QH^V!X.0HP]-.T`Y[,=P-Q_:`W!R`7
M7`=&Q+>D&T@1[WX7[&$!21Y4!P#HD*)?W*C;_K]+#+<4%\+L'KHO9+_?-5``
MIU,=&"_84J=5,>R#?).2MV@;,V;_Z.^Q8RVG&CRF?#Z89HT^.S"OF3IU#M#C
MGN5_^GE83LM[GM6K"W5,"87IYK)6_-J8LWKD(P_+H`OSX0)@S8&06^F_CTR1
M(TQ\G@N=Z%<5[;$U-499*.3>#N1QGH9#R1DCK[1@D8(D<UTHG]SEY8-D':[)
MV57D05LJ)_=&Q7YS:TG)(K&?OB"EWP!]DA55\<MX2*=]0.>S6K2Y=SV'ET]&
MS)X]<VSH]3^L'NNE4YDA2Q^H=>/XHL),A6'LU;_:Y^S@UW>21!`^R^BPR[NW
MG$K4!K*3M<)H-+-`H8#+)R1"=V_CMV<#'CO!&=EC*F$.D*"\$=B(_,$]OD"!
M6D2RAJ4@SM/L5U+9Q!)%N0*2>KE)^+<[-DP0`B\V8-W]SC":\Y)/@05"3:OP
MZ5@VNF`M^2^)&F([L[K]^`0_DM:B>/Q9#V<.B4%8?SBCK5'`WIF-W`^S(E6Q
MS:KIPH3`%7!@EV0*Y%R'G(8Y676`0(&D!IT%^,#//,<(_I:7E[/[AUG*(\3F
M^I>ZZG_B;0*['DNT#$O`E]H70NH\;I=7CX,>Q4M2!2I/"1LD9IZ^%=YYO2A:
M:RA\_")G`)U1;+=6MM)?]8&BYKB8&-KP*L!^4NU;HJ'I2B-=)#[3TVH+S*PG
M#`U]V/$<J%G>E$AJ).KL,5<)2ABWQ722+6R\I\O*CVWO\`!#](7)?B+KD_Z(
MNPA)ODWB<35(G,/0&3IMA.M&8-8\/&%[X8J$D,/4`]6_+'.,[O`%QSADA-,0
M'95:'YWA;7]'\\QLGO$[^/$.$VS[Z8PR$T/"+$:MD#Z&G_'6+7/VU"IDO'Q.
MKI-]-ULX&53/7>@%6NO3BUF*.%#L^5@$]7'FM1X.B^<OV!-[>=/ZV39'SRVQ
MAU%FVYFM#MP/S9\1=$CXR[3V)W)L$76)A3**E*9>V,=1L"E944PJ`E.K`@";
M^"1]CB!+/O@V2+AG,C[I`4Q.C.Y.6'2F^Z?C[U?P3R^3=Q4X/B:Z'P,GQX^5
M=XZ_=\4+ND']1YBJI(++.BM"&A,6DEB,1YLK*[:<9(:F64*.1V2^?N"!_:LJ
M:])@'11D8Q;_SASR1SN)DG]`\D8`/<WU;>\`QP5P'^KE)J=E;8@U"78E(<C"
MV7SXX6>Z6:9B5T>-4C<DB4W'GO,-V"%\Z6;'?BP+GQ<?F_[\3#:&O`"M#X(W
M+X/$W,`18%MB`72JCN$9GE]+%_R#L[*+,-3T)QO*9_%,]V[6%O[+HOA\H.GM
M)H)2OS:H-YJ7)_"T*F1KK1L`F'P`^=EMLSCBTL#<D[D0ID'/45SF"&5[LD=U
M"36U=N5>UQ:O-EL;DM!\C7HJJN\+UHC=$0)=,PI03(IWB78,3A#%S+8V,1?6
MRHJ]:*FK'/6R734RW,G?B#IN*8PD$2GS]!SET?&T7*E'&\6HD0,)1I/_'X(*
M+:G@WF->M&C7R[KC;9A@$/Z_J]'5DKPR0>3],P\Q8Z[S*EUO3SIHQ[%+0]).
M,F'_=2(P&PP2`JY5:^,I*PEFD*QQZ^5%&#>MEP2@W2+);_I0:8,YIP6$NU7U
MK'5(\^1\2M>MZI<U<24C28&DV]F;8I.]?)966>:?MJ5=]:UD!E>.B$<95U*P
M+XYQ[S>]NF8T-'/QM@*LU<EBUZI,0L^W?#[G:3A/.D@J95M!FA/$-F!U^J-]
M3XE\UP_8C/(@FZV$4W0I+]Q?EP"1+?=H"<.(.!20DD!,0&BC#]31::8MI8AJ
M+T4N.L4YF`=+//7TPUX'-T+2KTKQVE)GU&O%-!H)@#F9A.2/('%0\:S&(.Y*
MN*4`.[RP]5XON:":V";\K.^VYE)P6&*I;T64RO,@SBDR%#&3W<VF>>IT3:\0
M0$NSY5LQAZU&A:MSMSVQHW+T+G8GAF=L@:X?:WJ-5/KY?45MH@*N&@JVSVD2
MM`/Y1V(F$;[/86>:>8Q/8F,=3P^G<NP!08%G_VJWETA"0M$2MC[RO-\>,$Y2
M(76C<_OIN-7`ZD_K-&#S`<\\QP)JLFY[`;FDOVC!?U]^KH8Y%"7#).9HRLI8
ML76`YR7AX]DX0!G^(152_`$<X-CH$Z+>]-M1GGDPV@6E9T$2QW9KU/"OY>-1
M">(JHS0&6:W-?K.'\1$@*/-C#T[IV5Q@,CR7@Z%!<%2I]JW8)EA`LX2MJB0Y
M>T78G,;";HW\;)`Y&*&8\A+\E8]$@!/=0=!/E^KA?LW#L![T*OPU'!@(\?[>
M7\+0>7(20P^O>]ENST_SZMBWR6!B.DB^(*2W54WEC864^?(3;E"1\'A$5[O$
MD?FE%&L>"SX@5QK3ZA,<_N/=NYW-NC0Y'H(2IIF)%`7R6`'7!#_&B)R*YO(Q
M%-M3"Q.ZKXDV2UT[^=F:E.M1I`4'P8X%7R`<50H"`G!0P#2<)A87P:T:^B\N
MDO[@1S-=@EV>\3LHA`V\4`^!4P,=:.F7!<J$]2(@<H#">F3.(UJ=4617J,^1
M8:`OW@H&,?EK8,*6;PS#89>M6ZMXX?NSNK((^!-"FY-XL:Z*<"FG/B&$#]WN
MCO-S,IKQ4YKQ":V,`2/&?3YK([H4C'C[,@HY7\KM3(C2`-!GZ]8`-N=6722&
MS3G^-10E'V+C=7T;THQS.AG*D]R2E@U:SJA*Z+5I1`D*A&RSIH5`'JKB4X4>
MB6)F<[I1&:<4GN0&Y42Y<#LOJ".F4R09Y`:S7,A"4X&GCF!@X#)1!]8)`]7/
MAC+:MP&1#?(4A^_WMTG8SWS:$M\Y56ELV(A#YC733_<;N=?8\*Z3'[Q6S@!.
MTNL*\VP6A;1UCK#W9&(Y8BNTM[->4]:BZ(I\S[3HC$;:[I'6;LU=<878,ZTH
MGY3I^?]>@;2N<ZP,7`K5,2):)V[+B>_=]LV"8A0-UO]W1DC13ST1%[XH$!CM
MKI/3]LRG>R(=X@Y&20ZR!$!F23OMT3?Z\Z-OY0Q*@,-OX188^L45H2Y/T'!C
MFV[RDG?1:)WZ#L>N'QTQRX+79_\\C>3!)02;PJ(N@`TG?XJ*\-7`K5EH]"^[
M^\.R%21O@W+3,0)`[(?U]Z[=X-]X_24.5':CJYA$B-R":)$-/>!8/FJ+#;KP
MG>`Y.$;&-Q,.)\HM.LHY)J+;@NSR_VF^RC`RC)@$$LILAP4&KP=,.`X^]WV!
MW,EH?'K[&<&=WZ(&Q_9?:@ZXY41,T6\Z3+W=H'72&8,HPQSC*IQ*I1X4A"*%
ML=>WPJ*K!!37IPK;_LJF),9#M=C7_+61J-H8#%G;2"1(S:9M"5'<8Z\_"O*/
MK>A'G]D5\/[TJ.!Q",QNFI&9S,W?3C+-6GS_W1KY[1A*S"IPTP,%8WT92$<H
MM8>R4T"CBZN-6#:GIKN)/6IOU7CTUJIVBA_/<DGAEC2[Q2/Z.(X4`!T!I.",
MX<::U\$B&CZ`83L;I1OYQPCULN!Z-0QP94]3/Q`L8P0=[>^C3^+R8N>[!C%>
MH-!6*X'26`O35IY#+C]`Q57IN.DMD8[5_QR'V-IXDW+:_>[@<ZH*,*4>X?ON
M<#H=I;B:*/U[]G-^X6?D1TPD]UMNO'=1WWV:GM51,T?[D7PF:>:`*>GF)G29
M32\"POH$U=ZQ=`YZ(0?76K_!WZ--3WQG])X_*CO64B)TCS$(M*L9V%JO\80E
M&Q]H6G24>+&!HQI-75,U-[E'3+IW3BYUDNT/QV2?M695,Y%,O_JEY=T*`K."
M`Y\1],3(,?#^8;ZJF*L833=[[N@4S$83ZM:ENI#5N\G;206XBN/-DPN,<G!0
ME*('1E`,UOR=3"):IQM4CBMRSD.81][MX&.@U!LM:$MHB%Y/A\1.R-.6$M:0
MT#XWOCK02)WRKWG;\X*@+TU!W(CN5(BXT61:%[@Y`!X&_D.;K&*9IIMC7R?R
MH./`""#U9TWT.A%^(8%5"+>QE,U,UCM`NJ@[=0HW%\>%\5,''!VNFSG`V4@0
M'7Z/:UB@=/(?(MRJ_9L;@?S0#+Q5O?8Z-)0$/7K?DMWQ&Y;-%5326F[C""`2
M0H(DOY.]L+_[^Y;=5@=UQ<ZY>898K:,X1\$3PB@T*XDGY'1L99W&$G58];Y/
MJA")[Q)H>9VM)02V-+8KC&WFV)_`#FFC35S7UV7*M:G&S\,T+$R&=^"Z,@E+
MH)*^KF6-*.J;A%B5$P+.6?9:@FRS8+;5J6Q/W.G24R'N"%/=I;I!T(]Z6CZ=
M%<NY/F';)*V=OUOD8"8HZ]-#M4/"L/8=BR<;++@XDUB#"*L_@HOJ1Y;/^X05
M1^!`XV<B7<3TG\OITUUDYM*(:@A<"3;W>`9\"@')-2#2X&%4BI?;RFHKH+L:
M_U<H:UNS$<*3WP2+9'V41W(CA#/GTS8R*,JX,LFE9,;NX_A]-CE=CG!),^[K
M9P/:FK_-&G\(K,S;2UT?U!PIJ3FTF(7;&3+]9Z_CA]7CI")=129XM`8KYCCC
M3ISAN9$#*<MW#4:O;TL_*4;?C)GH_!6?-9,U89*.^LI_>43/\;,QQLXK&CFS
M<C77O7#$SK_4M=H]IO.87UDLSSO99V;BB1]:]K1=N"7CU5'!;%A;HL$!1DG`
M8RAWA!8OX=Y(GRQ&:6]A#B_QK@8'AL&Y.FUA''F*+"NC6#ZY4>J^&_;!.D>4
M%3C4![Z#^;/`N0*[MXP.'4;2"`?CA!.G50PC,3^"1Q.!`,L#-#-1*IOWL842
MLE)UF"\RTZ?>]_0?/Z08F89+]<?'L_8L]U\IHL9>BP%X0Y#7"[.*EG/0E:I"
M?%CTHW>O;*O)"H9I5*::#F/$AO/^^$[C3[+V2,G5W,8VTX[*.K9:0],(CDC?
M4/G_4X;E/J`5EU<_SE>'_W+"Z\_MO_T!`MZHUFGWN<B'>4>;/V8.F=#3=6S4
MY9RV<Y[U]5,J(T(DA7/6:NZ-I&)@RDPR%CVGMM'0K^8W6H=]O7FBX4PL1BIY
M+>M"2%R<,?]J2WW@)GFI@AINA@XEM4:DG^19B":N!ML.R827JI/,R"^(4113
MW*F#7N@W5>L`.UFZ,$FQ?3")"^,$GK#O)B.K%CAT.^E\9UU2-EVK0GDW-:0Q
M;R$#]65/',,8-P*G?TS9UBWD5KWBM*K*86XIN`<^$R;@UMF"*KW(R<X4&7^[
M`%X5N?PN'M!D9_TD".,($PG6#4;#.V2"#,DO?TAT(_R0V^_<9";JP^E0C,X\
MEN$PP5A0J];&.5V=A>%S4`*/;AU>MB!'5%S?HSP!$=54\8*?!?+`2<,&>L$B
MD-5WH'V;^E*I9A!=5G5RH%%Y@;W],^8=.?\I,?NS)^L9JJF:P%E>$B5XZSS,
M>LID$'KHQ!)TTT5#U#JSTL.+J%7>.['YI@WG"\[OQQGV1?RPM"7D$^8Q5MVB
M%P`UZC4'E%@RO=A[S>GTB)CN_T'&8,5!HG41A5<"F9L@7;?K+*5!Y2T0T5YC
ME4=N;U^<VK(RKYBFE2BZS*<BI:P["//FI9[09;!OZ<HUS=F%B="0J5X1)B9>
M@XM\$A-NB!4!O]\%QSQY9!:Y@`420<7ZRX59,["W>>*[QF>KEU4WBF2VNIC*
M/5GMQ1?&4#+<+H\^5_T%&LDN^UM/#S&8!XET*<*IL3P\5EKL>44A$N=F85RQ
MNU#[8-5RG37>T<O@\1^6+J#J%3@2UHN]GC0[@FT2Q=D5L2]Y:S[SO>1)UC@%
MB2[T_]C9<9?`P(;*+&`-*$E#B(L\SG^N.1KQ<J'.9Z(8NZ._@"F.ZX]7W.7P
M1M(A]4B<OUZR6D;LQHB9C+!]"TB6$HM*1IX2]8^W>&!*0H0+BEP^A=R:_$2W
M([#+I6QC.UW$<D$")U()MX-XU6]P)H`KZN\4!?C)$I=BV_'^4C)[-J5C\N[Z
M2;!&H:P^:,!2S89GS'JBA/2Q(W<J)P'"P'FB5U670MO%BBP*5WJ5+A[/8WW(
M\YXWC9_Y(-WS^D:J*!<0>S]XMRV2O;PQ^F@J4?NT3MB.PHPS=7>$_<1^/S2Y
MS:NUJ_U)CC/-T84&3+N]B?[)8(G'C1Q(_(QR6^%#"HR`>W,`EAT?S^6E.@:8
M=C$D=8AJ],WG=9[$+EU?N?4,SRAH4'KY5N\>^5(G9;4)F.GPO=*+)U7CEGH7
M"V1=1P_\KLWW8*2Z_)]T]3HHOC-P^U=(ABLZ%P/+]49HM6WHRQV$.D8;>3<%
MR^LM:I)/KO6FDHQG_#]-BP8N>T7[X*Q"(&']4H"&R=IY_#&IPUEVFF!YBBG]
M"95]>BN-GW8S?=4$:Q[1L:%^`G0!4%PYKJR]I-WLQZS8'Q0)O=Y+E="G3\A9
ML-BT',MIR0)A8!W4%BC>+=I#KO"G'8?Q]?*-UM$8;=5>8.2OM'_C)<CVH:K9
MFQPC/'Q>N/\+?O[MZ=J/QD?[*-&<3SPH"3L+)PW!LG_9_4\(@7.MRK"$1CK,
M=?XD&G%P&(/=`X#X*=7?1VY?>>-Z,)$X0FFTZB;-B]7GO(,]LHO,#Q6N37/D
MGJ3;Q6GE&KC:9AH:]E]Z;_XEBO]GT#V$4HG%<AN3L6W[Y;MJC__[4!U;+=E^
M=:AM<:%QW5B$==6HZ72!_]MJ72JBO>6FX:'HQN"AM6K%OS@/LR,8V@KU'H0M
MG9E(EIFL7&X[>CP">(DOA2$AF+%F&16;06+]`'7;G`GS'XR!VK([@.N\UU;U
M&#8G">QSY]C3+UU6R&J*AEC<:I^&'O3@V:I[7QI]05OW:P!OHXX?3"7`3^(I
M+PHX4>:M"3E1,X\00DT_E:Y0Y8I*&IF2P#]F!3&;N!8Z.8FMTMX62#Q\ZI/^
M)7W7U)&`ZZ7/8[O8#WMA*N]UNO:]>03`@;?HNN%A.;J%QELH1)=1NWEPPHSW
MN=(A*3P@KGBLA?&>C0=P(F!Z*K:>U>;%P(PR:O8=7S2Q:B3Z2Y_1V"I9D'56
M$-_U4I"HGV/BH,R8KOH+TS"ZRF05J.YE,KT]X>'()#<*$R85[N_&J[S8`=X:
MQVG'IJAA-QV&BO#[.6:JN,FRR+SEHPGYK;P7!JI;;!:E05'1V@M2PA9$86WP
M(#APNO,8.2DX&-T+K84I5]G+$=4+X8AH/2#JW7PU>A'UE;\80"-"P.#MTH#B
MW'E./P<@X8J1#363*LC)E/Z^VJ.3`]2.>:RG;$&I0(,/`YX$B/ZT$^[K)J7R
MJ^"5#E6PE$PESJU^HR87]_<\+VTI-*F/Y7CG9;LJZM5(PR/J#[--3!Q0)>KG
M6%]]-*4WYW&!0(@)NU:^=QPH,=/)TV!66S9^[RQGJ#[6:>$$0*0[-$82P[GG
MB7Q"0.3B230L8U$6GYWCF`W`V*K70DR&53RLUZ]V^&U8E*SY>"&U_B.#V"[\
MP`X>LUF=+^5537E_7?FTDU`D[+-&TH[\,LEVVQ[TO[N9J,G.HX215&P+)O7X
M7!,&Z35.\`:G_551>C/0R/NZOY2Q^J4M\IUM*RHN/N(\9.`Y>\THWE@'/^SM
M"A&/2V26OZSAE."?9;=U6"4A=CAD^NT'W;F"9";2N0AUWI'OC/17>J;\"C+6
M']?.V5O1O=VHNSY(%A;(4^K,#/L^\P8SC=C@X+**L5!100HQ.3WP)[%AXS_N
M`*A76FMQ8/?`\[AM%>I+GOIAV;/J](E2%&@TIY]+:JBWE/`P`&<ML+`8MC:^
MD:%0L7-ICT>-T9Y+,(9SY%2@H[G7!)5*D-3*2-%6+*\<:RD3O*U*AT^=XB5.
MDJV*'-U[;W.ROK3U-;QY,`1*T/:^G/)U`SYW!8&XZY^%S>Y_0.L.2@#U!Z.W
MTUFQ/UJ@-87M;"8-T0B>]*O3HQ*=""#W?*NC"/U5!U\1)%;N&`"HSE(.X@.7
M9R5S_\V*P*$/_O5[H.AU\D7S`Z0I+2@E4[,7_9\C&[@D<L.J!<;%HHB,&SS^
M@"IDFJ&YIG^^N:Z?]4(!E$C8#)T&UVNI0%2VX7:Z,SBH+H1?-P)$[?WZ_^8N
M!ST1DHRM=@"7QQ_HF&-EN'QP.O5JX#[J"S?<!\BAP9&[1&9PTNI1,;^5A"(_
M`T(CYL5.&XO87,-0@#C9X568?R7N>+O&/AF:&);7L:#VA[-S%E5/*]@D]FXS
MDN3P+_(64VT0YD#\1A#92\?/(4@\S2SRBZ$U9&!@:B&F'VAUP`US-!MV<JUF
MGE,<M<`L5VIW-L<@T;>^KTW^$NKFD2%+7VQJ`/:AI//BK2GHW`T!5-VX&N7V
M(TXN)3#6JTI_APZG#X=TX0W#2JO"&\G*H+>Y*S1<H#N413AHB6W]W;OY<?E'
M%ZAVF6O8OK_Z=K^'N.Y%`UJU1I#'4[`1#.]HQFDU'2#^!T@JW[CQVV2`MS%%
MMVY7B2,49.>'E"HH,>,FRL&:3&ING4T==?,]0-02R<IU7M'P7,%-`XO_:,4)
M@NW;NT,A)*5]0OD@^(5__;FEC-*B`-(>H6'-5$K\SLF=B0*48$WT:HMPQ_()
MDD"9#^8V?6755FO-EGFK1*19=V'/,9:F-V+-.MIV9VO<41YIP+[>WE/J8_E-
M1T8/P/6`5C1`63=XKQ'J/#'TK$;[UO:^$D&@!52G\H9!/995@O2^ACVI7ITI
M%@E)X=[E7]-Y/U8<\=&7#RW4;_P[[H%90QFJ"P](K@I*`_P#F]9%).VB88<X
MA<U,AJ)72+C*%P8C:UDTRU"OD.G%MGS5Q2H8_?&8%/R1#`9J'"RN`&K4LS2,
M`1W18\C9R(&IV[S+%K<VR=PKCIW];38J;,H*$K4D%$P"!PL0\46.:V]X[3`V
M`GE]JP^#GI4!TC<,-V;L3S1VC,POKG>'-WC#G1=$'\W>8K]U/QDV)N6/4*![
M9HH-:.1P5EI9+TE^"Y)J[LK.91#*-&I($LV3C-=%P3;SJ]T`\PCROTU7T8Z?
M$:NH'F7G*Z6]"A_$M\==8PS92?EZJ>?"EACG1)ZFAC%50=X1'D5G+O(.XQ0*
MJO4>*Q#BS#_S'.D(Z`J/PMV[4-X(>Q"1N;6(A+9&H:^)X>[7FWXGIJG&<YCS
MHL%M=EJ=6WBH%V4G*W:M<EZXKF$AFRB&O"OYAZB`!^EIDD*]',>U*R3",V-?
M]/.<B-Q4MYYO\B\HV)]W,QD<Z"]P]/?FQOQ;NV.PYK[.;Z7=>&^7JR!2'K\E
MKJA=<HQ6.,JYQ=O2VU$V2#<'C9ILSSYQN(Y\6S4&049!+`IBUZQ,/*<\^,TO
M<TU/MT,SC5T%N<N\#M*8Y_<?1^RA=*?RY<M/$8[9E-N&"2Q:US0J"WZ,F%,$
M%T,5/R\U*K,L%I*G(+ZB)5W@."_[='HGS6M$7RO]-!^B(PB'O_*Z1>;OSFW5
M0:#('E^%@-W%R#UH@(_=!F*N/-R0;LW^U\4R@>[^."_G1DY&,89)'*B>%'"[
M=PG9)*;YT/8.AN\S8O72;)-18<MN4=D$I].LQH[IDK(_OA<W##1#P4G#)!IF
M^XD`BBY\ACK$,=",I8*QDH.B9L:K*@WRKXL\3`I"\Y>`"IEBQN8@.?DW"ML(
M"6JXHRLU7/1B\1,"*H7KO<FV.CP:(]<JY(+4(WGK1:=,Z)[+O@$'=70P:'H8
M*1ATG:9+2G*&>=I-7OR92>R?L\#T0['KQ4!_+I::?,Y==%1QN?O0G/E(XI^E
M%1)IN4H:RT1W$N(D?EM=H2C.,IH-&]!U=F@<0&UH8?N1!KB>[-N#`EJNTET9
ME_D=5`J8RY4OX_`L=8D"`@39K+S"J(;\8@4,K"N4R-3G`O^@FDJ^^4R&/\39
M*85LCK`N-U1.T6;$8D68M7Y5UNI93)@40H)37X.?8BJ/)K2TY3>O1/3Q!%#:
M,*J0VH&8O0H0MG8%)85!2U$&#O/QHEQ;Q[[I;*_NO6Z7*Q7X%Q#;4:?BCA6A
MP5,E]Y%(T,JZ\E#Y.Y/)1U\AN`/_GV5J:'6QP0TYZ"98\59*D42DI/S&2^M-
M'1;PR@BHH@/P5<,\^7;_T<[U3PX&Z`06Y=-MA=X:%ES8%O`(`?%;7=VL@X_8
M3&GSYN>AQO#4Q(1^R5LN5=1)1E2S]]J"$AM\EV=?--(X@]=9<V-!V3#T$SP$
MP[HW0V<V2G'UF<)&O#?W<R!?@4L_H:\*S??.F2!.8*LHX;&>_BOU$AO?=X`?
M)7P8*^J4RN'>X?(;XX.U"BE22BHG>=IET18L1<J/1M[#QK\N7!(RQIF$+,49
MD_0ZYEY&YIJ^S6P.=.W=CGF`%#)^(LT5)PP+)I>`'&.`$9Q68&3;K`%:YK0B
MQC>/0C5S/(*Y:([OF0CR,)0J=9YS?/U=#F:AA#ZLS(=&GNZJ19!&/C@GQVD<
M@\!#6PP)DG.ED"J`ZO('E"5`]]\<('C7(ZHC2I//AR"_)^KYL26%46=S>4*N
MEKXN3NY#UKXF^SPYV@O%\V9V)IN:N`2%^)ILX9VT1+V-GT=8%/D!6?"NQ*>4
M$%YC&6\$P_RJT3N%FZRWJOC%J_PRIRE#J#7:)D(I'=<N8\*+\T,=,*$G2&^S
M#F?#N5SA).947L(N]3O9LZZ!M@[YR?GQ&3]^;*L4+T>+`PP;M8HD2^T^YT,.
M(`<D#N35C[4-GF)*I(CAZ=ME\EHZT$XBG_)+".=:"$`\N$0XO#=*8D/.EJR1
MBYZJ(M=U;E>T56GC?LR"#R:;*^/1'MI'.9PCYL!5S\OAP-=Q"W6@>*=V`WQ9
MD#HT.0"!7U%3?LE6/CW`L+5K.\Y@!4H:X!3REEFBF\_H6`&MTHF*=R9(V4E1
MJ9A5]ITL*Z8;6,H72G+-Z>]3!^'2CMCS00<EA+P`-OT(!8&SEM4PJ8CA%AD-
M-=.MFII(H!H)N[2>"47*>G\(URP`4EEOW9P''?I],>:QQV!ZB*]#.FA(ZR+@
M2.%?%W4?K7!3A"&L2FD=Q,=/FHCOU@``^KDEYH5F43BR'U6.Z^TVY',6T;1^
MZ[A#=OW\R:R31)KYC-11#<J*);FQ<R/2YINH-'$[_-;'+-%.&&T8+,@O#.+Z
M^-601Q&WR=4O2Y[7"[!P76!T=LX$'+H[YIO:7LZ<9+C`0"+?XKK.@LG05':H
M2T_([7E35*LWL=/WFPF3J1Z6K?M_\#F0-4\1)RG=)FE$NZGA;CPP5@6<%H#Z
M]OZ=#QK-+]O*$_R&3[E"-@`J=@B+\M5O;50!&"6,JB\L+P"I_/H_0@])59C(
MU2CNM8C#H;(Q8W;@.I$1-0ZD[%[3&Z'N\)-H(*Q@]ESSIQ"9KZ[#Y^=T;<AK
MY'.C-D?<'1S$OGOTA^XW(@R6>?PK6UE"JB=%FQ7(YA:R,Y@G5<&@Z1&8X82E
MNB'S+U%H59454RO]*%0857"4+**KQ0;4.!&9,D.QNI`_SI9E6Y*'`<19T563
MD#;1+;#A_3UA=M.J.(M2,=BZTG;T;;P;*+@^BAP6P41NV&93&>Y,=T@GX*)5
M.!AAV0:O7L?=UG?GJ1LEA-<)!GV_>^*56^#\B#*R$T8\J2BBY,O\!74Z[<">
M1OQE"09MO=OXBBS)^(9[)QQ'+B*%<:*3L$24_;,U('(@Y7Q"Q1K>-:RBLB&=
MNM=E*Z'0!97BL)J$]N;66,+?[PU=@U4'9'?+E-?"39#_!7@0`_IHGPY'^8D8
M9>::D/ELHHRE<:V(+YZFP/7]<%>@X?1\GQ4Y\W<L-+.E^[[.`\>X?,<:7ZBB
M6@\5OA(@&\^7[>O:-\>W`&=Q&*0%8:7G+*1%`>)4=3VOL=>^]+;$JC;SQ?ZO
MJ)%XGA<^$Z4W_,E)Y.7JX/MHI=$'ZX^KY$R35Z)'K:Q=^50QV08/GR^,K2FI
MZBR]/GUN[@)AH33]08A%K.4]G;E1C#ZCKE8;]Z20_A9MVYVOAJ\/G6P+!OL@
MEU\WZD5RP2?TPH/)9D'(*!<?Z_<N14^*Q$MNCSF5KY:("#IC-)IR*JGCOY//
M\T8K#\Q%"@F'<JZJ0(QB:IY6SZ=?EF5B.T*U;MH*TP?,K9>H)U`6P'U?0_FU
M=O\K[D<_H,II7:=\YW9L3QI94M3Q]H0A5^4?9\#\;#RN&P^?2(?9+>\'`<U1
MFJE#,EZCE2@4_@B[$CPE)N<+RIRMHVV?:]WD\D?$LPO4_7(GB"2?U[TH(I@9
MY;B/(1F]BQE;+6XS[L/^J9297FS9`>1$_QQW.\0::;/S*Y`36]=?)#O>]-HK
M?Z\M52CB]&@6//)90+"ACVH%.G).P"Y":^P4[TZO)?#N%8L,GY,ZV"D%0I"=
MCMKO13%K^>^]<.AM6N])=3OJ#C1JI&$BYZ@<VW).>-(';2_Z3&V)#9B;#,Q8
MW,\0KL9.5_S90BL<<=XU]7YA(GG6W3Z9GB-JZI^16F23MZL?N%_\T15%,J+9
MRQ-7MRNP;T$8%$N<9G,+"\/UJ#ZY`PT,RB0K.%"X)-'D[J6G0HT,;^:?7]S_
MC`%)M.VDE]ZF1*FU^JX<-DVS1R6[@^]JM?N[N,1>-2J]`49GO`AB6"N<.@&;
MFO@&C52G5O`Q58CJ)JBXC*N?E(VPOW#V,]VRL$VC9+\A,.G#+![I2TMP)\BO
M^'0AEUA!A;1D4ZS8/P*JF&.GL07^*-9BC"+(22J9`]M1W#M'ED%*A^#Y&+)R
MO)MVU^<NSM\MKZU3B,'*]#N8XV7WKK$GBI`T#<?^VH?O]M<]-EN0$MR:&E(;
M9465]\D:="^+*]!,CL,CZE,*7Q]=2JJW!Q<<1,-N>L4W3R&G,)Y5_14,T`-`
M*](.V'7<O([8[,F+5YC-P?Z38(-0:>*(>D&=#8C&G&@1`JD7QV792G[3N"T!
MUQ\I=D^,N\%S=WQ]U8[N<JH)Z0`HN=-?7!+N,%<$_"*Q\<6]4-']2[X2=!@F
MO9=XIY"V:KWA@J_4BF+=Y+[5*E<I8,])VS]Y!?"]`!*6WRAC3[K$CQ'G+@ZB
M6+(H@48]"Y`M-3F\<VAQ$L8%$B\CF%Y'RXK9'`UV0#/M`A$H>-:G-$(<>T4@
MFVEY[^YB0W3H99S"+@:$3(8N'$75`'GB-/3CNL*9TAC&9&6M[UW>:SDKXE\A
M25_[I2>^_M?%E1:=TG4>X7$)K,*T5G;0&(#E:'DG?0M4ZY:%?=<W>G4LVM"2
M&.I:QI'Y0I6@<]X`)U$/<.=,)11=L\0AA&\OO@&P7-_=8!Q!Z$>H1,F@ZR/O
MK0/J/8`1$FPKNY&H,&A[TO"Q0Q7Q"N,]&=ZIH*8=<ILB@&OU)"71-T=67_WM
MXR+^%C0RV^#'PA."92UR+PM9V`LJT%-%K+:+.?B,'U`W`-3Z`EM-(4MWG6/L
M:9[@Q_F&U)V<=:8'8_A9\2WZ2^WT`J?+Y4:IA8Y?')2R`2%N?E*QIN#FT85A
M9"[($W`(ZDL1R;U^5"43D4.#I^P_#%E_$/<RXUF`Q)N1;V(EJ>1B\CHTCEX:
MDB',77PJ"_;OHKIPK:^Y:!!;\<VU_%]T<W#G<=.?MTE="A2T&HFQ64E(4XS?
MMZK*]/U$+@F)E-+%NWFB\FV#.NNG?7^)-M6+*P`1@Q*+EA>1("B$)>!(G\+\
MKK_$(+%@YP(CK<4DP;!QG0T5A>YL//I/5FER=O#(0O;/6@`F%D31)`0+H3)Z
M/CY56:CL9T\*_F\@GM*ZV0?=JZ5R3FA9B@%]].]L)01,>S_^Q1%K$()1'9<`
M_#'#02['#LAHY,+92/X$"Z]??N&_O7+VY]F40QP5"+:+L'9)`8M-,-I;*9I>
MLRY`.9=@FB)H3_O5`8`+?#3<K^P=#M3'\X@21`(1QZ5"0Y,X]O<T."-(N+8;
MODG-1*]N@M2`/G.8KG!@B$E-3?Z=GJW;ITL+`Q?!O05T34T;V.HKX2G4!N//
M%#KX[$(`D]/QB4N_N!2]`SY0$0Z/Q^.THLVGKOT&S%/UV_+J)=ZPI<"NKI<A
M]JM(+)TG@6L7R.#K6PJA[VM&.DS[6/)=X3P>3U'$>7G-9A&BCG6=R$-^4Z;U
M[L\ZP<8<KYBT:<@7J#F=[91;[C\1"%-.\]T8D,QZF:ZON@:Y^(D)!<#;DS&-
M9-/"CB65S?I0NRVRX@2CW.3V=[T&S#+?E^"QY94\O+^"L$83/A@1"HP0LS?6
M^R'X:B5BIH0(-EA)ER)DWB4VCQ6N_7D2V%;\4E66B+@-9C+R@C-8U8+XKO!@
ML&<&<&K:2JIF+^Z^K1D8_%9/4?_72XM?XLR093W=`T);6@*6QW&O%/6)(<<2
M%3IGAP9&N1LI70F&C@*3*@&4I$@T,@\UN[44<4:^6C4\33I:7\C[H\M"NXF-
M&ZO<%HTZRL3"":V`JOMIQ.8-#^K,IBER@:,I'O/DO<Y(^T!NYAARQ\[J-8%O
MB#WCL"-6#/+)"9^AG<M7TWS`_#5\%]YFTMKL9N2^CHDU@T88#RS9M/,-[`RA
MQ=[5OUUWV&_SJ],]V:('5%#OML2!F?D3)6#;MZ)(_6M5>6+E@^5RUCV1^`P7
M]CI02_.BEV1W54_&;H[";O].8,-`[X9@.0:,.9!Z"Z)1/:X/KKD?"HMRFPL=
MUHS[_Z/5$";C/^3K/J/.`-_K=INL&.!R`:&*)&*VM)25'5;V3GF\"0#59ZIM
MB;:DOEH,,Y1[-\=Z.*1V@&O=<X<RTHTC5B!:W)070VQ^[T;/@9>0MA)X;$\`
M23E#+F^%SW6-VB!W;)RKH5,3]?``K/&`P_UF0O.X!,E8>4R92^G]OXF(YU?=
M`B\TW6KGW!18W?-1#T.SD3D,799E1`&]2,4MYSFF;6/@#'[G+E".%A%)LZE.
ME=BH)NS?;9?%+)2MW<CO23FV2U+T3+#1<T74)`NFL,II;3)^9VX_:6HF)88S
M6N(J8KHW1;"2X^N8`QQ15\1ZB65H,H'9C%D?'Q/A+2*089C"+TVZD:3Q9IE(
M6>W>7[/BLVB@[AWD8R\EGV>%HIQS0_,$=\&M^+EGCMU)_8,QH@B'<8LF/:S;
M8^Q],=_@3,B&JJ3>XRK^JOSQU:0..;"@BX*\,G2LT4-=8=Y;#L,2`8YLTY`-
M,`+%4P`VMRQ7.0JFZH8:RG3-+FUILU@/R.J<RL,3ICU<[FP+6[CEU"8YZ>$[
MQ2ZU0XEQF+7DF..$K"72M]XV'>=,<I5?.X-:<Y9:L@ML:#(S,:W5D'^>LVI^
M=N!*9%*L\\@_*6VX&"O1+"#>$!2;SONWB0>"2Z-UU*B]$:I[&R]S2MKES-*V
MND_Z,JG5+U]6CQ*A0DB]6?0#"4FA<5]"%.9$_9[UKK4N"H>^;9@WZ>GZ&W9C
M72$EOCH^7)*RP/#]YD\N_Y>(]:I;"8`?B3SD3Y8[\DG$'A#`0^14Y5^`"7Z)
M+4MLQ;"+#"K#7_4JJCO]O)`C%/2\`768*J8HZ'`6RJ]G_9PN-@;,U@QH;#0(
M3`.Y(T.$](Y-[UTQO/'SM_Z=`=JH];S$P26C7M9/H0I%E(V.JUSAL?867L@$
MZDH1?\',XF>MR4;W6[.;H5EU;N(P75$#\,8(E,\+[ZKWBL$`]NL%11N&:00#
M>Y_L_5SUS`;M=*ASUX]9M,`8BB'(CV(M%W?E*_W&_IE5,)AG;WQ&8X=3J8)&
M&(U*F#-&19&,B2@8X-!#H*[O)@"A`T?QZ!]"!N0N<RM`9:21YP8JSU1Q<L[[
MAU*SC>!T"")&7.W24#`P`TDK0!ZQ[!WVD"OW1#MP!>9A!..+K%G>AZ"),,);
MAIG4X1<;;Z'Z#POJEO0\O[GE1+]Y^U<P.1I741B@T2YS\,U!.YJ-[XH_AMET
M#Q542<X>O[I9OL*`Y`5WG`OUB,L2,BZKL?<*8JLWG8[Q)ZH96>-4Q=*P$5(K
MRC;IW1]^`453+BCS,RZ,B?0J;944;/H5M:Q$;G?2Q42$="67?5N'_7S)/+^!
MP<F<(:2VR]:#S^;^R`@*4>@4H5YL(;V8;K<65.,-WJ'7:M,Q6.E.8.Z&'J3-
MC8``_D\CU[7<%4MY,:P:+'["W\B/+S5-1@_*H4YB+B*3&[UA#!GBY3EC,5[5
MOA[[-?<QC,5!(=`2<LG#2^K]J@=*ZSP_<&AP(&5C:&\G/#\G.S\^"5LI'5J.
M^/R1XTN1+$4R;U)YU<%SG/F9D`;E[2U=(C!E8F*R&.$&&#;[Z+\_C6XI#>I'
MV?H*>H-*R(ST]J=8^5O4P!3(E!M$?]O"+S^).-P;;5C]MO+!Z#A3']E9M"61
M4*&3N84?SZV=;:[#ZK(L0;;"SB/#@$K@TF;%B7H.D"=D!+Y:#+&<O;K;\HCE
MCO@Q`]LP/'F'F-5*&/FFT1\WP-@<_#C4-.7'V6SW.^9LIE2X&GRBQ?"@LTWG
M[S4<E??H.<Y7G#[,A_?8!.=;6QE,(]BU&!9#LL2R_UA,?A4:EK">$TC$AO?Z
M`",`TS%I;+'N"83[N^Z`('+F-@2I*((T\(Q2J%T?I@6:QWRA\+R@!A+<=N^)
MTH[?P281H"^1)W6_;,5(AFP`W]\J;S1$68%W)V1TB.BT_*5H[>IB#E,;@5B3
M3'=,A#9Z?&U1X_12[%`=4*V%:D1QH-;3L7!P_N0/PO]23W@2V@,<&&U-=2O&
MMG_W2X$OWJIUZ=^#0QE6S0&*`G;6%3C*M&R0;K_'Y()8%GKM8IDTW.]L[#;'
M_-\J&/6?9->AD#>91@FSENI%8"9FS?#I8;(VZ--^2:-P#$FB^]!,.[N1*H&$
M!+@,4&PAG=)!LV9=W(2M..X4TV95\`@8IR[3]"F\Y$C<W8U-E5,!#X!+ET@@
MC+J6HE/9=W]7(R@$ZA(*6?;BP!V^.=PE),LK)+7N6G&>W3YXF;Z=E/;^4^N-
MA+XM79WF-Y6$G1:W8N(^S\N2V(!A+,[[WNKTX*EL0C>%P_C*Y-'R0`RO;-B!
M^;H?1R$]B=!-GV^$#'@!;%12;RW5B=L=0EGLE8$$;4:YH1M%21ZWPZ7HJ9[U
MM<EZ61<-)2BE.R^BKIZ"];MO7K:)^ME!HD>1JL"7$M'K_,"6O#=/2`4$2\DG
MO_#TO&EZJ>=*%Q1O]P=,X+/8%3<"D04(*E6-C$O)@5$K6,FP%:`O%2X-H,"_
M2NNV\F\6V/@=[N1P-/)'_%=JX^S#W#A!1#W]0E]<1EEC9<&5YQWYPL`9^TW6
M_\P&,-C1Q;9.30#(*;7G>T]J31M@-!0`UE,@&>239,;B>O<0VTMZ&DG43*3M
M^'W$+[/YO@[8B""\!#NF?\'!YVHNHNNQD%3%***_\AZ\;B$]_0S(Z;7VJ,EC
M(`YDO0G9.6NXM0%U&C=!U@M]GC.BWM*S<2LG#4_.N6.B8@=%OIJ;]&=\U52`
MR_)/+PDU_['[;"5\TOE("3XTA5P8-M@"$91,C(.M9]E-$3A<+#J0SN5.CE@%
M8FEUWG41T#T5:,Z<\=K4TP9Y-('9H\R"?EBFTMQ#&_QB1O/K2[!(F91-HBG?
MG'I"5Y@VD\XFW?BRG`L2MH-,.@\DBAW$'XAD[#WEF:1DJ.B0`.$73?\2)FHI
MN#'JR,MR114ETVJ(IA6A*B,6*X1_W^XD#E2P_-YN"(DZ+G*X7*O%=\V61H_Y
ME-,Y4T%GF:$X^5L37:QOWDR_SES$\Z^&_Z7(Q,>=HK;@LA>.O+G?$G++].=0
MTD-R9XBNGDIE2(D5*:(&E!WUG[!.39-4'U'91(SC`MBFC]@C)K64F/)2N;AO
M^&/J@^@>NXD=S6<7'TG<L`$AT/X\E#BG?2HJS5G+;RRC?(42!*V*^]/+!A4_
M_5*1*ZY[@8UNKM#_KZHIVAG.7$@ENSQ/U=?9RF9ECQ"!27>ZJB)./@P)RFAQ
M;3H"%:PSPD0+4/'-5&4A%Q0`'WSI:3V6R??UB4!<)3N\->OS>D<)TE(&0&@=
M)ASJTQ++.M"PHJ$6<ZDYR=FLB."R:7.);\XSJ5.,!UWV0@2BFK@Q6JI>\/"$
M?*G!7C%T.8U,[#O)?=]N#.=>%34^^2(QXYP>-/,CL[QEH5]0@?;^:/L.)]@Z
M6C_<+=QA-R)F`5`\KB9*16]2]HR<57D3+@C$?3&%UY/)=.(:>53]81S:B)PC
M)_D:X/\W)Y8O&3$7B%.@!;)ZT_N[4@(=$).8IG5?NZ6!4*<'1FSG":+5]7AG
MASO.^XJ6M6AV>J#3SME5W_G'SA;H^TP@T?`@35WV:_4?-LIK3534MS)]*U[J
M0_JVQJ<!(V\EM-VOI(6E/"%]03"/39F5QD#,!\>G(EJVSX]+O%>1V<\PNA72
M2F!2E!?FFGKK\?)2]+.6VW\R\8D;$FTW&U>+0QM0;GT)9H#("G</9WWHF7:$
ML:/Y(VR.."DC4>)BM,YCX*YIZ$Q*8;SB?,A3<:"TJ*PRBQU_&"G=QE<%U)5S
MTDBI4K`Z:`>DD70$*)8CT\`AZOZ0\[9LB(<;QKIIP1DX+W6T4YFC2BXJ)O?%
MTDPFCG?4'T``+A"XY"5C<(.A->'GB]=ATN<W8E_*\W?L/&Y=?=!-#M$;!U`I
MO#-INWN'Y;3>NWN6:8)53QY:?4UJ">LA7N;8W>5#O)"5`I^=[`UQ6WF;.,'%
M#:/MZ@4CS!@N,PQRV7M;S24[::T_K9ELK9[K<5N`DNJ_O5[0":,OPC[34']4
MN.^H>50(^&X'V"*[<TE'\_&+H++!1P'F5ITIR1]N>,1&KK]K-"BY[#="&0='
M":'J@L/>YUQBHX<QQ6?L@H=6>=\=\3OE)IA*EDLCAI0T4VJH3)W+Z.`>]CQ4
MN:*FX?\>_S-]L3[(F<@\A&I#51"%>!0:4(KF!)/'/3&K/0;@V)G;S4B;#D\N
ME(]=AF]YNAH:5OQ:Q@TBX2)&?[X/^%:'4[!266:I8C72?^LYP!P;7`\)%HF]
M@&WF:-%G%61SZZO-G7D5U.G_#C4:D?1F2W`SSHSB[U9P07*T\_FYZ601-3R9
M67G.$:P;H@"2R,'JR:*TJ,\JSIB!,&%V$3M+8*.&F<NL)8]TP_6KJKBQ9D6W
MUHBY9YL<L'!KM>M%MZ;1RI7&\+Y,#CA?AI_E*JRK,B5X?3'"2<<9HD'FZ&YR
M`6EM@[C<'0:%HG,UG>C!RT(,J0DH`=MP=H!7D70.XO1:#[K)M[[//$HT%2F$
MNFI(7*=2;T^V0A7EVY<^,U'A@)0Y)6GH0WDQZ.^</W-$8*0)\Y^ME:H.JYC?
MIKA$]CG-?9"YTQQH@TE3K!,[C5875,12/NB?%R;>UUAK;04B+D3-](+A%O&5
MDG)JF3:K7:C+LM*BR::#N(;OF)V9(,-SQYSQWH^4^*!*KG'G0QVC7=<N(`=Z
M;&Z8EU,*MR/N7^Y!F[E0'6^U9.YO#3:A^7_,8%`&C#I)3)#4J0-E<L@L>CE,
MFW$V8S(^"VV"CMS/A45HX>&4D*-U'PJ;GJ)!.W%XAZG*UI'-#W$JORT79M5\
MF.K9!F-.TF1+0:1!UPL)IOW6=`R=)B;^R:BW+P0L*.L<3KW#M)#,4&>Z-3WX
M1#RMRYC57/\H$J(K#XT(8I5B6:T56A,)LJR>&Z6^%XN'S^*6#92^HK+EJD?&
M45XCV[MZ$%OHB9%V(`5--_@KBTW(<+YO`D-7%?2#<.KYDWASTD[-(,<X_!'1
M>$`TXJ9CN/L>4/)0O(H=R86G8?,D75GU2QB&U1[P9K:-T:,5D\1C8@"9GR$E
M5\/'@)>"5CU@HE7*[W:RBQR/HM5\A+FP_X`.>GU15`^53)V8!6>#NLE-'C9:
MZ6OZ\2[NG&T5/!MY:*E+O<4J-ZW(7EUA!,.=>"%_:(P'NNOL'AQ&('\*GV6"
MR5>@WN]]?\L,*<`V<],M#:+3T7U9&X4!T'TWX/OJCZ0DO'N?&&RU=15)D5?]
MCH<PEAX=V#:CPR,W4C'N;NJY<M0P`L7WTFB53O9U<$3N];Z$U"*=E*K8A^4:
MP_EX]I,+SU/>V&J3AO1D9VZXSH63`(C1'V.R4[9D`NA;,86#V7[(RIJ4U6U9
MB\ZS<=?*@D++!&X^^^FF$/0*D$-!#KC*&/MG8J;6$@#IU4BDG>;E(E7P4U(2
MITR_1.Q)-6H3DY46\":C>N^(GF"K$TG.5`Q5\``ZJ_4EP;#:"#QA.2053C'?
MK,<"JS@?[<OOQ`SJWR^>GL3MFFZ"^]9;Q<5T&F1.Q*Z?KH5W)>WAMV56(Z-+
M_$"=!]EH-M42L)_ZJGFM^^15\^#:P=;OT1'Z@!83N\J(*<2$&F)80_Y0D)^F
M?_OCJ7V:1,$SXTE=^@24=&=OUN+E0_;G9A]I@6^^=XV)TMUJ]R=\,,)07;8K
MTP>&!Z^@OC7Q+3TV>%#Z69PV<CMPB_5O-1R]6BPDAV3\A:\1F6?_$%\_J6$P
M&\T__!$WIA!]I1.8FW4]N:`\8FV-^4^UD[>.:<S:_SU)GJ,BDS_[Y]R=ZJ6J
M;O*YF4E1['&Q^G]0%&MB8:Q)#W6?6ML=>W&\W*%+N$KKXDB.!D]_-6.8*NS+
MU]M[]8@S@K/A`?`?O5>%67:>RN/T9]G'.%O"&'0.^K`BQC>>(^4_7I>RN(U-
MI.K\\,6G*3$X%:B2GCEYB1/-QC'QH,LJSB,JP\85=O!R?(/Y(=.>#]J&A37P
M"B8J=_JUTH`'/E:W?"P=U!9'@"JG:3T,N0J-P>91XHLJ!<@I,#!<S/R.0]OR
M)SL!1LW!KD:C4+--M]LU_=DL+<GHXVI>A8WUKZ>+QV50;XL>OP*O&.5FV!0M
MO/??[(W;%"AJ&_*?(6P0^X3^XC]X$,+:#L0J7)6K)V?)?:0FI]>73I3)OE)6
MP<_YOMF^UDV7OP)T_T#1^<UBPW/3-J4QJDC2;N$0M(RS6@",<%YOK3$:#-^=
M&:0^^5BS#Q5`!!&JQG"0Q^:7&ZM/^0D`=;#IK\^0`?)X:H5H%K1FP>*!0SM.
M]=(X#,\EV\;+HN.2ZA2%Y$<-I+9#\V%#VDBE#T%3&O6J3@9]`$(I$OUJ2[W.
ML)'>\F'[LKU#7CFPME7[F3PE0F8W5)"F29FX@M&8='MWBTU]2$#7!*;6#82^
M./39)OM!%MDTWF&D`[XSDC/_"JH,M-26Q](+ZN7YC+'*U"%TIL\7/N6'!*"Y
M!4B.#<B3O2B;BD29%3K;'.Q6GK-+2(RDJ(_PF2O)&`[_C`LWGTGQT3=]U`RK
MH7$-:.4G3Q(%>0ENP/G8Y&)9M59M`9.)<*SD:H`EAPS=O/\+-4'2M\9SF(%F
M09IYLDCZS2I2<J0#47P1/=^8#^@S%33=<G+54!BY&\L+[5@@K)K_88,H4&Y]
M+V,F0D$;`G]5)6.F:<'1([7>`HO2EQ=J8UBP[BR\1V`,>-I#W/SC`IF,.J5H
MY+$HPSHDXI>.>IG.)`(R+#9+YZV\P`&!37M.A_&/X`_VZK`V9)T(ZHD$C.0_
MJ3:!57MF:?/Z80%GO>UQ3?C8>%D5$J=^I"0001Z#DT%*4M&G<B+81^"WP<-'
ML?!/GW(&1`#4A[U]8'TBU*JGD=#%GI:#X++WPT5'41;_CJ.?9"\PLOP(OI//
M_NFG-<X?GZ_H9"1C4W5DSFN>>,+SFYMWJSV*:PLM-<SO_)`FL,ZE'JOV$G"V
M5R0F7/;G4021/O3]G!F!93C;QKA9R3*S#\''G>RK:>#LQP@MHGR0*W,IX4':
MP?]##W5`Y%;ZH9&O1^&6/Y6K?D:HVN/76U&0.Z5V\"C9Y^,>&+FQ8711?!M<
MA9EAMX*KBOZ'\8<<_']L.Y)95/+0"Q#XBW?0M7M(**GK/V+NT4?\,5X>>)*?
M72XK$4G)O!'Q60YE]7Q=<@!H+C,0[,,.`5)9,A^9\G(BG&<16@BZRBHYR;%8
MMQC8ZCD_2M@/U:YFD!]Q>83B+HPZC:56H):M=VABX*&/X'E_@#P\ED2W&?S<
M@NU/9!\K%O)8-QX(RRXL'B*00ZNLQUM&T2T^XY[72%;"7M'.C/(YBHPL&WB$
M>;LFKH=CZ:08(Y(=;L!%BW;VX:QFI])'645?,J,Z29-D$"UOFF#XU;\WQ+_(
M=V8]9#I#+HT.7)!S]/S\`K2$*5P0^X'M<E'*%SV6<R78GM^8D?P"!XW)WO6E
M.285Q+IDGD?BBOM^J"H]A)7]P4^M0&-_PRP!DV>6S-7[:(.O0%Z0(_I5`<B%
ME0P4B*R?`>!,[V+@)X1X.=R<?SFC=X2!'Q02,O3LS1<>U:(&B7L)M4[&)#*9
MY8I8GZWQ![RR&>1$V)D;G5:"4F1D&JF-0/=04&KYA#(*\4KWZ#<_EPHE+3@8
M.%<QF6M&'J3LV07<;;Y0#^V;7G*^(9^;2=;M(6@O3%Q\"AO''2-BW6,OB@AF
M;`Z8=;)LP%?6%::JPX@N`R)B/N2U4NL2!]U/8TY@WUP0T!3-LHA/?2,1C^[Z
M_#L^X+F'5#)56`SMTF;8+.N)4-'ZBBL7""=!AN#ATDNY6PM449GA4%=[+*O@
M)0GO/&!Q)U@Z;`O]QML.G-"0-LEYZ\3O]I4;+$%<ES11)1?4AO79/6S6]%A)
MK1!1//Y3"F>(;^LQ",-4=9[438TL[3B`Q*;O;D>$!5!G_J<YP1VBU[_(N#*W
MUL(<:B+@Q(E/?`;E&8YW(<&@!$@OU/R[=<63A0N\FWKAM2P;Z>QRUUO")$WN
MX!59N#I?Z\.+PU';F0@6&=VFN;E"]L;$9,;QS0#J"O_T/WR)JM<<*T!*H-FK
MQQ(SW!U+(G%PO8HRXI5HID:U!R+^9=.E!G+)3'?2"%6.=B.:4K=W_AX4;I%%
MR^1UE'R?OM9K?7,*,PU_,7(T"L8-;(_G:P%>H7?\3S^)4-@"`T=-G<;<V3&Y
ME+MQ]/X%L)OQF1=]>%@[--TQ_J6(=W>/KL<882!)S6F4]A=`&P\8Z$A1&O6:
MJTHZ0(`U6Y13'6#"X??ABFSNGQ(/P6F^F1UY9FF69.B`@32_)4$)C/Z?*LM@
MYP5+QMYB;AVG\G,@BFCZ@;2/'=UP]ZH<VDBXG6ZCG\U"(5HP:T;)@Z'FVBP.
M79U)+E1>_$J8?/O)PNCL%PR_%UQ.(W(6<?R_N31%/A7`:*9WY9LTL$,R;>@S
M=,5+A\IMI?PIYE?0D,O7:P(;<.Q34I$6G^4B^!=@:TY;9BW8!@F#S6=O_%,P
M]Q'468M=FHJ;L4&]REQ$ED<D6]C.?0[%\7U8T()<W0KS5R9/>LYZ-[$H;&ZR
MIJ_\#;H;#5'0EIF4+OYB!,(IJ+!7EE)0AJ%[6IX#8//)0YA(T48[9*`$&JO#
MV"P7SW$P3&?`I+7E1RZ\-2Q3>1UT$,:#%H9K`#C3B&I(4<YZ@B1M3-_L]B(8
MIP#"K,BO3-@'U:&TUX:L'LY?B.M-T)VK=;[:7J3]Q$M2[GE,[%[P7N`7K*)+
M@"+W6['F'\O&</[)WD)T#5?"87`P!*H3Z[FC5^=\>06^NL"%8KT1%1BGL*DL
M0PEF]5+S(DT35`06#5/V79'1VW=L$6+<Q3FO^GFM##31%38B5Y9ED!Q'G3`J
M?4HFZ5[IF05?!A(:0BCX,*MEX+#OI4GA4-+*0:MZ+^;Q3SHE`6OB8TB5-HG;
MVQB/27&XU$9]7E="9K./`M`9]Y4>(E#P@G^MB&O##]2[5/TZ>R#)3K-8Y?;Z
MTY+\OOVD"AC,)C)?L+&%@SDR;^`@8G,=LY*\T']XF.QA0A4CB#P6K\\ZT[]/
MZ\#]I:`$?JL/NH]BC,;C))79ZLY!.).UQ9X)V0<:\?@>@Q#^BWGQ!,X4>M+,
M&I"O;TL"1@_WTFH\0W,KAJ/J0!/XVL2PYI7G!-17>EBXN(.2`)/4B14=:&@^
M$<`=?1!&9@,7E^K-(O@%ITC\N[_2!<7&2?EJ0[Z1)CJUCHRF'>CLK'0`=[-/
MX5-94ZB[%>:GA6(O$NJ/KZ-'=JX]D'H`'I/??K:_["N(^L(C3H;X#?]F"\!0
MGWX*D#+MSB5+4.B:^R'G'CPO#?RZ0W2`[+O/'&!ET.V`@"0?Y[9S[X)501U-
M1YH;JG&R^E]YZ3"77@R4SNHHQ0^2,)K2U<./1"8-.WW55RD/X\J()?T&KT_1
MMY.TGQ0\DL<H[B.;Z7W0QY;=?3&U`=(3)->YAN,T)\^H]AH*$6@7+X@`B9B0
M`L:5^O+'X8U93^$S2G="^DF-OR'\7X/OJ2L.MO;,W&QC*\WJ<3"V3!2D4^P"
MD3>P6G4#&2-<V12_ZFX",-[\Y.CNR,K^@JSP,.-`+1JYC(80I!(5Q4$_.Z_K
M$@$VP.NT5*9^_>+@\OA9R:;]C^P`?R/#E0E4#'+[S-F.W%].T?!$7F4*;B!=
M?/<GG>[8'\Y0B6'$P@SAR`&,8,#,?#BI>2?\?3$@2_C3B08F'SS8M_IC0!2I
MCI4&<!QB23S`"ROQMG`X2$-I0.Y'`V7S635O@CC2R.W2LVZBK)][I8GL.T@A
M^BB2X@1+:+I$9D2#*YE>[=9X7^1#-$\EB@@+-EPUC/MG',S'P\UTP1Y$_,"#
M*&5_;N$%(1^A5:6M$5=WLDEO*5#82A"?XU:S"Z6B^UF5NLL"++M'!8T%,>.#
MBZ2SBD%6`F:A]IF2JW>JUPXCC'[_/BRJF9108[-F">I)D@J7;F.=P(B4FU'S
MD]*;DLK3)SAUNR)E+!AW6*+]+Z6@7)M`M[ZZ_X3'.F'3AO/?W^2VN*`M.AG[
M3X.L.>=`=^2RUMF+PM?V@3AJQNT\GLATOAH*=[,ABH^DG0;'-R:#%_MZAY=Q
MV@HUUVV2](H8\'$DGR`ZB2P?8++V3,WJFK=)>X>X^(V<;@U0.B$SD,I6OPLP
MN.&8#L:@#^:`AZ8\[OE(RTT#`?8=(!;T4\##'U].U19/8C*>Y8B)$>=TW53-
MJY8N4[/MWE$;DL:\`02B.![RAKIV-C(W93_Q&"D:$9<(8H"=='U\D(7FR0G#
M42*8V.AV<S>P1]%6]"R<1_1W?2T>PP&OP-"PA]L:0R;.H:[$1!Q_8U1QS()U
M7P;#%AO5J!$<A+M5P+\%OK>IP7EC8O)%6Q_V)[NG@/=3:HA2F!+158;CP[13
M%X[W)VFIP2_&F-="U6[_U$S]"A[BDTH)+."7IST=D[5DH]^KN%<*X,"[YPV"
M]S;/]7-+Q/]O#C!89&ZIPIU[P5BA7R)JF\I9DXQ1#\M=Q'2"?7X1`"6V1*EF
M'RV)5[TPJ_3#7YR@"WVC2`-!=N!DPSQ#&(S2!A_\;J`@U;L-[Z;LL@S`D=<2
M*L-REI4^O.GVF,/J[XFB"'/X1,6>156\I)"_BW[+X?<CW3N2^\\WI9]E2HR3
M;-::#:PU^R<,/;R1FA*08.34-4LV4D4)X!O?@/%2KA9=;42RT$2E+0+,@R,&
MBQ&)QF3R.^,PVF@_"%#KU5XFC/M!BMIF(]UH5MVRY1NC!?)3S5(7<JQ:=PUH
M1&@F+3H-KVXL$T8Z3PD19_SR)W$.T[1J'6U9()W)_F'J,7DD9H-U3ARWZ/V/
M*")A/G1HB<$S/V2*2FLQ<V.9/\**>%WR[+0I>6GOC`T$4NB`T@PG#\*P+_1+
M"0IO]\829HB/?5D%7.DH(IH50JQNN9;@O[ZG!,8TUC5K!&=L>\H*4MYB0M[P
M5&#DH1?>._^$A&%O">^Z(F-WK`+3#Y)MUMB1;,(H36<@6[Q+G<0I6>*@;1,5
MPKT=[M9^:3<K+W!C:0Z-]<UTAD1F6OIR8NPL`B8E@U`]SHTRU.`,Y#!U24':
M<]$J5P]RD119J`0!,Y(5/>5[Q;/=D!@QS[$#A'1'`WF'=87"9K9B&RM!C21%
M.08-'>I6PTV#A!R$BUY9MB2])/DD9TL`HA4>P![PE\M*=;/=_Y,A@L$<W#Q5
M"<ICA1[E.#)+T3\<K\MZ_\O)AUSSL(7I^+"M`AD:#VU7,[*^@ALY'K%7W*UA
M>U!]T-ZK`OV:SM0YC+@5Q99=9A%S(W#ID0MH<I'FSF"#<^=Q$_?[]1Q!2-K3
MLVGZ1?_K%\/($)JW0W9`9A:-+,Z]X/SIJ5=E&%ZD3$NL2<([5"SKAA=6?%@Y
M+.=#G0F7Q0$ALVUA7]C!6),;R5I'H`&H^<?%VK>:HU$+S4NZ0Q#Q^CJBLCK%
M:SMV\;*+P2XKT=]!<E.JAP!."EKGB\M]=-IEII0D:34`A0/TLGYGH>DVO)-I
MK&\4RIYF%:5A*\YQ;__ECVYH!7*<<B'"M&.QN]C4-NJ=DALJ+-CGG7K!67\L
MX5+=[H]?"9U[&45&HLK5Q+JC.V\B$.JQH2&S0I2NAR?Z>2U:^SJ.A;!)^0R[
M35JWN6ZEQ$YUW-J6--7IIQ-^_6;&+R\4ZPSL"&:<*J)1_=B'Q9&<YP[,8N-&
M`^G4'RD.'#118'*6PG\!K/D,Y+F$<&X(KM=BWN-$-^*W]+RO5M.JM*>\+=PR
MG\P5R?H[&2$*`ITEW^DL:$"_OVHX&1"$Q?RB+9"NK>TWXH/:5L]],-%F<B`=
M3#28?GI^.5I$XMVJW%>AG:YP63;9N[N/F9@N#@D_-GOQC](TF&-_$).8^VX^
M>TIJ&3H(6;(%P&M1EDQT=G%R563G?G))]6&,Y;_)`+&&#[)`?!OJ;R2N%*-O
M@S3)4'$J;\YL3=1FA\/>T?V9.^=-O@G@IFM<%'/>\8G>M5!T,2U6K\/E[;O'
MOF9U]4UV20*.5?(FU?5],3S->E`49?X]C&7S"O[K3-0,ASA9Q^AUN>J-I%AT
M.>>[*?,43+8<I5!K\R-VQN#!C_;*PE8CM3?_K1)1?6`PL8`K`!</X`K9R_2.
M`,)<VL;F]\;Z>Z'#%U!KY/876[5,YC?F4GG0QU_ELA5;<L98Y#`\`<K/56L"
MZYZ.,$@KF&M2V7AH%"BO&P%4)0^CF)]"M]$=??5.??N.V(-!1*1<XW&C+6SH
M7%TAZD;$T)SDTDQM&5.V_ML+F.@YGD^C([;:+O`O4&2)?;_&6_76IKAD6:&<
MN"AR@ENQ%Y#2/IGY'+QJL^:5STHR[$&B>5$J9$A?F[)$>RO4D[Z7(T@U@BNH
M*\ROS4YU@6L-M/;R*5:JW:VN%UUSQ"Q;_!?>[`</NQLF<IS70IC]49*:Q]*O
M'"+^SM#4T:R'^=$5!G<\E)06F#TQ,;LPS"9]E"6^A_A10LZ?_<ZCL/>9$Q4]
MF_="-06*M$UE#Z<M_$KUE)BH]TSZHQ3*.SV**J;K]Q[GHD>6!EG^(&%*3*)L
M:YEC=]HIX$5L?\(;>)25%D,?B^T5<,5,H56Y\U\S+_8MXIZ($>.[6?6$'1C8
M>'4GK$:#'=H'!(%0QC4LJ*.*6CL$O/]DW.G&6;`0&E^/@,=IL'1CJ>4T!;I;
M=F>+85`W2?\FQLX`YX--U2)6@E&SI$'KS`Y!:`F3J5#]_NR[F'S0D)E-3\V*
MF]!R=ZKC13=_7,#3C)E&84UH@PC3=C*O9J(35,Y/G<#2L;9>J0/)Z@44^.J0
M22U712VSU$[!Y!E#],&IXQ9S:)_$9=T87QB[G;&8[QRYTSECT[C%X+V0H1JZ
M<%`1,&W%VU&(2.C42-/8:2>/_N.7ZJ#WBE7JP$NBOZ<$P:??!S#K-SL62*?_
M7XI(K@FX_I?S?LI2;LUG!T,<:#D5?.%P"]@X-S?Y22_%C12EU(ZKR#X)\/;Q
M]4O2_-IRV*P+QY.68R&Y[(UR>?O!-U<]6T4D_)/G6^(G>430BT_`5]:ZNW8:
M*<'):RA@`[Q6"QCOR8?HY:BGKYB%0*Y[:-4)\@>/\DK7'AH/T5WSQ$1LDNAP
M&-47&TFOLFKG+<S4,;]5O&IU[>N=YR97"FYXIV)E4#^]GZ!:11XP.Q?M1"!L
MSP@68:&N\QG\O4<]Z>"1+V'?[2UG"G?NV&[IZ'.JC+TD,>2\6;;KA4HI?&,3
M%%X[M"X%RYZLAY+SJ7\^7L/>I+=K8A[;:$1*.8BA86[0[7#3;ZJQ[T/I1+JX
M!M"'"*JMV\`P*.F79BR_:V3L`*`Y!&.%CX'M\VI!ZNGB'8!IPZ1/L&)MOA$/
M;V_35=EIU?J!D+@@LYL92G5K!M3['HQV`[$!J@T4$[2#U5QFQ'<($;QQA;.G
M[:Q8S[!=`F:&U,$42^X*S+1`#^''/B\(<.N#\"'_M56/0DP`-1(=6#8JI2UG
M>IPCDSM0R.<A'NHA^=.M#=N%MO^T9DAEI37K_).^8PXC%ZY>9G6X`Q7SLD/!
MQU[?T=Y`%"Y@CU'`_9BH#AJC$*,_?8DN0;5RWP!`_^(_6>*B#+%PE01D,G^P
M2%S7M@K[Y\:,37-*AZ7Q1[*J=\7)>:T&/^M4=N[#7"*=ET'.,O!>!NYK0RPG
M6PW6Q3>7R::=9,I9&\!B%'=W,;'+-:%'VAM&YS1SXRO>,U^@3`I>SB)P2:_4
MTH@$_@POZ:%!J3O6NR\S56UGDWE68077B);?(_B*B"CA7H,<(S&RV\4%)#7$
M]Z/-615*95T('MFE;>MH`(2HZ$8&#I'@(I>T@)XIOHOC2X;%"=)[S'"IH[#I
M?"O&"[]5XFTFE0X_H'TD:8PS<Y"1XL>ALJR]K*+7JYQD+Y1);*K%LZ+<BK\1
M,>M]J-"),>Y.T!E^Q!:II#2:\,G0G&SI91\J^Z[>Q@QUWW/TF`RQ7$:WU=\X
M\;[3N-ZO*U>AA"V%CEOR+4F1*\"7[A'.M)=>$1_O@B44EOS7R1<\X$U:49"%
M:;7=[7R2OF0LNKU>!4#[*Q+^@Z2CVHO==`U]>TJ3=K1IQ?HSHC_8W2[,"[KC
M13QI4<,V2!L7WH141L_RZ`VD93=L'6-@7=:*5<@M25UG-J^C17+H5V!&7;QZ
MQGA34<6C,0>/J!K<FTG#<Y[5$B4)RB=1)_D3JIC.'I;=BE#X#IFWW.I2>3.:
M9F=Y/,`NR-0A3QDVH6FF?*,4I=6+X10S0WN<(`+-HTU;3WG)Q9V>L_$P#1+H
MM)G=]!HJ-O6J7:[U>IXK_N?U&SX1<"Y=!4D2]-E@TO3!JS$$U8Y54&J/ZBWU
MM<"X79)(DI0")L&+N5M@6O")+KQ#(\6%O)@BZP><^G/C#'L7&H\`RH,M0QK1
M@/`I0@7!R7G@,?Z[I)AN7#98*+<Q:1H7%%8JI_;.'!UF>BTB<;6@"\F[`-8=
M].>[U5&O;>[DZP/UYS,D<B*'%O3I8`J`5Y\09'^?G0UO0"HGU/?S.\UD;4TV
MU^.#PUYPTH554R6X1#.5@,-W3\RNC[L&_T*KSA1S3=>8W[LZV_%PGHS3>7%"
MG++.0)WJ%OM'5"Q4-08<AT27&GR"VXV(HO3ZWWVA*A0J'()G/5=`,">+KX`,
M&<*VJ&WF&^97R7[+[P/@#B3\8F',2Y!BA@*]2@"@WR@%.#\Q1;%<AN32D/7>
M]_AX=?3"A#`[X)CG>^Z5%]Q9?UK]A'8[&?/C\_2^8H3L`>BJ"1V+DQ*ENCS"
M6178V4/#<L5UU4US]<^;A8-Q#?ZQD7PMY[FM_5DNQUGD4P0@#\V'JY9`IL8[
MLY$82QK"*;+,VWN;@U,/MJI^2@8H28CM<^#2?=&AM$<,^1^GP/7YJXK2W+9J
M6+1O`9Q:4[/G=ETQ[6[VI+5BBS"^%XTD@+NZJ05BMIE;A`PME2M[M2&4=$D1
M*]$3R\,?;IR6@G&12KY+48MIY#9]F$V&BFSIE7Z.LDMQ:0N]S1Q<R'MT!F@\
M?'JBN9-1V'5U7R*7B(,^V0Y_I:LKGY))UT9L2><44XL\G`?SSG$3\E&&P&<1
MC,UWDI[B])+5$-*E-MK:%]KK`@*,1-.VOH$>K_UH;^E'*!I-D$'+0E*73F,H
M)_^6?\UZ@A*XB4\](J(465.L3'E[F6?+8)A.S.98EX:.=;1T*L^JD"[\=Q*#
M-*C9IZ.-CJN0A0XSI44[0$`LLB/26CW$C$JN;&VT)'V@<_"%($CH2)/_!:V-
MY_*%M.N9+'#7L)&'<[<G3Y]&>/S*F-I_66U^"V.;D1\H+7^4WT;P0`O>V0F+
M8MVP13T*6$^J"L5`*@L7><Y5M":(8M5L-E2QQQ`T/8U7KXW=6`MY$@B7>5EL
M<>)$4'O4::MAWGCJB37J!O.P7O_'+KB)XTKMV)D5AR%'BE\HLV?WLGJTMK_.
M#8J9[*[L7Y`LQ_&9%2+;!.O/.BQ]%G4:!PZVK[U@90N5H/!,CU+&4^R4%@_D
MU?=V6\#[PNDM6VI@GO3?CQ4+Q>.I_/J3=<C1UT[<H2P<C^T[$+^I7%+6UV1"
M"NZQ5G^"_!`Q?T:QY0EV&3:C<O&/4VBGB*.L4[&O"%2.^*.><+[&#3-C0_S.
MLGU.ALGE?GVDRGKN!/LE4$W1;Q0>/.X]D!J1+E"U#+)U2N)]07B0@6.L2D-!
M/YD%Y/+U./+)G'"*U=A8?F^;B!W:<<NG<W?Q*\!GN!46"?#4ZL%`+1N%4&X&
MM+II5AO!I`03Z$*A;=Z6;O[2*),7"GWM^#FIT(:NU=%:^*]I&/?3-(+QR<?1
MH7]<=<UZ28.Q@E0J^PK6_^.#V4YO'5$]Y?8Z#_*'+5[]!S0V?5LOZPJ/7*R^
MK?^-UU:T'-'0XEUE8]&>;!6#N0082$*S`+IYUG@T3Z+%A`PQ&BL:+^A4R:S_
MY<[@G=-NX1"<'),&%L]TWZ"-('7*E_`^5X2#&ZG)36UH-Z)>NX'--8UZU2?%
MO>MQU_W>D-N=A*'`Z!1KW6>J6G2WW0<_^^3RD+N$4T\72Y72RDL%'KVR3MHI
M36;41BM\B<1RDS2@0;UVE6:4:.OE@WT!K9!/9C0M&'P?8WKMU>*#0%`>5&6U
M'RG&:S<2=Z-R$3^)^;F=$[L+.C:JFC:A32WP\<@`2%[GSGP1>ARD?A\V(C@O
M'TTV]>=_U8C/X/*Q"1(094!HTHQ`OOR2W;C3#=$HN#Q5A_\GQ"7C.=E,QX!F
M*"SQSQ,CPH..LPW6+6V>E?$R2?`O7]T3"MM/$LK^OQM+.I&\N]7G*E+PVQ=M
M*C/>21V8A^A&(EZ3D@@&'Y=VZ*]DW_Y`))*T;WS3=X-2:;4!3BNQMM(YM"D^
MVFD1:8W]X;C]-MQR6YSSW:+Y\K-3OZDLW9GY@`WV\4W2=HM*#W-88W"R].K<
M#.`[NW*>?'W,YBW["MC>^5C2%;!M+61O1538$UOGER3%5X;"H*JI(/RS:H7Z
M&#H=B0K?AF/87I4EKRJ'EG&K)K3A658R6NN'R(\IM*;5ZC-4KD@'Q[=S+:,;
M/@('<4N:3"N9UM`Q6S+0BM%W",J\B7E82D^DT>HI"PK>?B6+KC+.+TKM8^9>
M!2.D8V,W\I]09EN4X-M3#3Y96Q..QSJNZ#>J?>::.2USEH34AI_@6_ZQGQET
MT5V#ZL)N<?%S*LG;7+D3<U>7OFSQ/E`+$Q1$M_`?CKX=W]F<%M\4=1R@'U1P
MY(!"\FK1T2]B43UCE864$RMUP!#*]CZ:3#E>9P%0E:==\;Q>#,WS+DP?105X
M(1^@HMEDC*A(3BA(4,?^()V$\,&T#OB-G+B:L:4A,HW@3Z9:52M>%R6G;KUV
M:](SP-]0XMMSY!9'U<^K&XQ),)WTTI?];]Y.LPG6D?)S#E?;.S@I%974K8B'
MGL#P'ET+A]YU5!,??.V4LTR*#T#55S?2]GXCJ4G!#"2(48`RUJ]/P#_^K=0!
M&5[CUH^G\4\J1(6KMDX<V/Q63\M^V<(9'"'R52%4`,77Q=-,.7FM0&MDLTIE
MTU31S;2?GB8$.0C'`5P3!@VU3>`0K$>RH3DULZ"GHZG&SA$_KZ3L7"]'?FX(
M?K>FW-ZE:K!D<:3RS.>Q,;!H:E%ZN5ONQ=)BK)';]0@-2QILQ-#V_SJ6L;)G
M$U,V>4$8G($W:P%D]_]JX/C^$G@:;9%?+V)-]O*-^3NYYAHLMOU9>4B>6D#.
M4I%3^.E%>J%-R@'NK(KZ(F!\/20W9E]]=7\-_L:"R"EK:D01CF4ZD52C1Q)8
MT\(@4F9Q%!TMQ].FN+&?FO=R?>O2>:Q!Q<]P-&I]PA`@OB&\EBA,,L(,S$!=
M]V#X7O9OC)8-(B67YD`5^JV1D^E=SX=8,:]U`(6"^?.1I`NAZ8>2+_.#B@9K
MK_DYTYHCGG=>""/KRRZA`2-Z$2_?UCEI;-W3F!S6T;M.<,'#=A;6QEQ[OO[=
MWU_JY'UVVKH!V][SC"HD65=+;W_B6JC2-\/38KF>)IG-L)5<$`0@13CN%LS[
MOA91_[C_EKIR5E4)]<\B#U!1VF''2YX'JCX<ZMI9(;@S^)_%>I#R/;]RPT3C
M.TZ`U9X]>KS?'<V*&*-[@-5@*M"&2V6>N<J3$KRGTP`X:(2@+=1I>G?C^)`(
M[[$H\1JS<TJ;^^HE7.N[H("-7Z.+K=O(!/]YE_8>^CF.+^X;S$`0V)S9!%Q1
MCTW6K0[/V(I?-.7T>\&IM7N-9Y8!(:DV`@?5,%F8SOR"B*Z*M_O++]_Q\>65
ML%44%M`[CT,)QXW;FGPW+K/7OD8N3<`E(O%&-KT;)..QW8NKV@2JF/4=0Q[7
MPC?D)H%+.Z^H\2$E<U>"4VC6+7_$D2<MM1W3I-N5LN\QDD#ZM0IE9,/.(\8*
M0X,\_6ZUV*!7,CBZD25^_`4^1F@&-@0\L<G<-.,X%Q$??``>33_D83;+?X#C
M8/,#@V?+X]3P;CKU[MM<L,OH:D/PV7&*TN7M)4M.8)809#/9'2K`3V%^>/!.
M,V9LS,,?``[N.-EMM`$J[#R-*-AG_2Z@4?8AI2KS,VS`\RM:`V%=VEOHRN4J
ME+P9$JEF?96_"8,O5_1;P*+23D%2^C3_"/$E^,(`$4`]BF:UI0'`FBCH6XIF
MB&%\"6J3M,_SJ5Q9I%30<FB$;KV%C3V$RUNU^\49=QCH_W^$TG',X';VL"YB
M*GUP@[6E\Z+C&BA*5:BZW9KWE^R=0_#ZCU9BSA)P1O\<9CQL#QD0<2%_L57B
MD\J4Q9FGQ(QN>H8+(")5CD@S50M?&?-/V=TN09*;5NHD^D1[ZME#@D8!BE&E
M"N^%@J!MXC=B%,`?!S&$P*HVP-7*:K\Y'<N$Q>8;%1S'X$!%!M%*7\=WGULO
M_+"8CQ_[R+1^^9I?A%Z]V$[E-K.L7J"*KI&CNA3&JQXLON[6S48(T;:<*6"O
MP4@6S#7?O``.9W^2/A0>92NTT59\<UL>04_R-P!$^13_EFEYE1,O0+0A=!P&
M75Z!I^-QA_"AYR:T,;UDDC?DRB9^GZ%^"F:M%HCT3<E1\RTK?P>9`E2;T-S`
MWU?#XT%-3'IR_C_S;S$N]AS$-7"!1%CSR3D'B/TOGLN>^M[DO%$BC@Q#?B.P
MLUCEW&0^!I$-V_&9&SU5A&$6R`"9>WC3&9!]K261@Y:8]3SDKWN-AT0+RRGW
MA$K[4A4V06)GR:ZN`2ME6+I4UWF1>9(*FU56)/M0'Y12%[)['^CY486U:?G4
MX9>KZCG5">!]=Y9K`!2OT.3W$\NF(MI/I?JGYT-BMSCC,\N?F%P91N"FC#[6
MT%<;KZJN4V1/N4"\GU$96P1HQ<I(VC<O`L:>Z0#@R7S.]G]<XXNZM.BT1AKC
M\#JS8&'R]+F5"48Y+CX#Z>LV#!+5WB4K7=`C>Q3U9AR*[$(4H//D8;1.!"9U
MS>7@2_48Z3HM>_*7&X?(2/'`F6/F>9B20%8//;=237I_R7BUNL<@1CY.*-UT
M3H%3HBP%F))L/G$[HU@I;W7"<Z_6\N@->;ELUB&I)Z4.V7V/>*K%*ZR!2,A[
M;G;[Y,,QM`\H-8HZ@\26Z@BC@6#0!'Z;#J)=;H<+QW&W<A7`/^X3ABMJ'TA<
MX+VF@&?LO==!0`"3%2!XXM^X(EF):U\ZY,Z3*PTF-1TH>OF01[WIC0TT"3H@
MC?)C%20,F1^0^7[2_?9=0+$ZM:;(F@,FK'AW%*$3(3-*0640?YVJXFUXSH%=
M`VZH`C9K\,U7PC_;<Y*;D?KP.I&&%GU7O,-R:>G$+6N@(_(?\6U0B"QI:I],
MK@Q%@33"HIX9O3,8@O'/=C?>DU>OP4!2/\OO-K7&X_&ZT!L4X);1=P+WFN?)
M')@[?*+,=M$N;ZR$XQ4KSR0WB>QW6D`,.&<>M_R`=UJ:/M5:K5PTWQ);!<X`
M*U(P<_,&TX>D&)A>%)3^*0TDH+V7[J%<8DKQF2!XO*WR]6)8Q8S\.!VJ8=8^
MC1LKMU<-8LW:R4>*?TD4,Z2<>6'U_N$`!ZV\=OYEU&OGSD(8R+V>#P8`2ODP
M,Y0[XGWF8E0^)O5`G$G-\Q@Q8]>UWG94%6E3V`5`5V"2P[LQKD>OXJ\2>DUM
M6L4>U'2.5W2&WFVO/JU#WF3=%U#N_G^#LA)Z:9<S%JJ<GR;L'<,1/<E;1`72
M_D:7>]<K!($>XHVUY-<2'JW]X$MP5!-\\QAN0\A5)\3!=/@Y$U<9FV+?7+'9
M7)-3Y_I/Z5='PSK!DBB"G>IN&AV?<GF5%R#DA?C&+4=U;'EI1E_$'??7Q&02
M$+[KZ@I1Y)'6JC!^C&[6`///(!#EB!U%>I%;1)<Z2+KG-D9GHTRM$K?84"3Z
M2)T?]6%+8+@[M5D:)'<8.CK(X(2\DQ?:9G5FL%'(HPJ$:%]5Q4KACW_254D`
M]-)AUCA6OJ]^9Y.`4EY/O8P?0=AIQMQ0*X(H?C\M]$4H5DY;(!P\_`^FB(83
M'%'UK)4:WEEK?*]*'G`RH*J#L<Q;%0&HM274Z$&_A@CQ%#D^<,GC0Z'3Y/#$
M@NSGGU`M=T+9=:1`*UV)J#_FICX)_\&D1ZXS@E.-OLDBHK?\GS$HI@#(_&-&
MO4@6=+RT-;W+"@W):)[)%5815[H&@Z+Y4'[EPO.N@S/X98(;(.K=ZWWU@D$O
MA<+0_>8-]"U>OY_MPR*63E0+@*C3G^51VG.2YL>?@WMTI7_/]LSZ*/JP>M:J
MHAFP`W1]T:)#OLLN;F_7A)Z,1C5`&.CY?EL*W"J]C6IZ(\$P`#T9ECA&$\*&
M<=^;9[CARP?%S299R.R<L'33FX<NBQ"^N]]4TN%;1&W1/&(2&$JKQP+5+P-4
M6L=;:EV=KY`@&M593::*;OS9O=>0J#0G\D:7&[9,3'Q*'&EEDOGJ\T?UQX8$
MHG\Q[^GK6>T3`=(G+*M`Z$UEA5;[?P,USIL4O40;]WDXKL:[W7<*)S!K_9CH
MLD2Y+_-.1FPD7P[4<!R1!U`?JMF4XS.:*Y1)EH1$W"-0<%O(""IZ5G8A`1_;
MH[@FZ@K<=#/2O7*R.4=M_%066)T9W<2MPBH[(%MNO:\=B>8EMN8E5E7(#VDE
MM)KHDG,V\/0?UH)E8N4/&5U&NQ;.#_CN0?QTU-!^N\UN'ZE;FO/FE@>J@9H"
MPZ4S@C_U6'U5A$_MK<;MATQ&5F=ZHD838S0Z`1"\5A<E!R?*#(D#Q\AI=K.+
M^%CP?.@J&#%'`>7234@#T3,2DP"+R-5Y?_?D+@U:NDVZWVNN6"Z,!.;^&?00
MR,Y87^)ZDZK%DQ4$.N??%?W1ENA;+<?OI"-AH7#,N"]_!RBY&&)(DY,CFR'0
M/5%B]X<A5YY-`XO@+^63HGOB<CSN\898][4W`Z+,O>D3=BNHS$Y@D#-%)8I#
M+#\V/(T4QS3JM(Z>U__8RSDC"*507/@*Q7VSHXSZ?3Y<VDB.Q;(OKE'^%CN=
M`P:FNWY\>JG`N^]SN[&Y]=)7Z63,3`E3=J3CCJHM?\LQGV`:)V%T@&!6A/8(
M4B4<E":`"X)([*J8Q!95EZT&(?UDN3U"1;0^ZG9&#$CI);7[$((WF'[0*2\Q
ME]"T:]+W`CV7L`.K9^QP7(<;K3`4S&%$29`R0[\++(4KQIRZ%Z+?+!^(YGT!
M=B?%5-I":F!B5S?CSI(&)10Y(4#*0R>%"!8T!FN)O(0[/KX2UK7Q98\E:1:<
MVO#*TW:N])X)AY73DUA5?'S^+(<,=W1U\Z@M>`I4U\R;8+_2XPY7';@K(C]-
M=1_\<TC5M%*AJ.9;TQ`P0G1U3[2:/C^6V\,/]B[CA\2S([*GXKV95^_P3X^)
M%2:'(7N,?,:"SX_CW_8?(*?0I;'ZT-[BECKQD41!JXT:V*=2RP_=Q+R]2;\I
M`E<A-IEK3DC&]B17DD1`M:##Y+MC17LBR`X':*%3;A8J/>8WK?ZOV6NQ_^2U
M,@.;&HR4-&F=`.J?^&QN/VR^<%'2MYL&\XU*(UZ'GY?X^K_@8S,9@OP&>]P_
M^5WC[9#2;+&K>C-1_\'&O_*^R%SNJ>F(,C(L8@4.O@9.V,_->&L(^.OH7P.:
M)]W9Y8;?8ULCLODY]6J(3CO+=VY&R(RQ-`/^1DL?K*2NDFJ+/"AT+B6AH8[R
M!BA;U'&*X*-<1<[4XD^@!9$WX`9IF-]-O0FZTB,#G!\*7R1R[^[9Z!/W<GX,
MAI_KHONGL"G(?'A5G8+=,S1]=?,1=&H_+0UYPT^>]8Y;:$32I+R4J?ESQ"O'
MMZ')(D77\@3^R>^*I#O[MGXF[N.(QZB@DRF@D!N7@6$RA-^#U7!4\^W,B1H[
MWG\V:N)#W7OV[+[((6XIT@^%^P-KAJ-B(F>H,GKUT(PNP@<T?]VWFRI;;EM?
M3_L?_,P7^#A!P2#.$79GBE:6(@PT($41(&!D]NGPKMM<DYJDS3ZQS3,>8[?K
M9YED_&9/,HNJ@ID=V@XC5/5/9Q%3X9>_:SB>\\Q^&8J[[E?\"-]R#8;!OUT2
MJ_T>D?B;^AQ9?!&B#O3/V18TT?2PS;?5%T;7J34DDC[3V8#!1(]_3[XH'Z8O
MU%CH:`.KOW[OWS]_O/SN_*4,V\"4<,')T\<DAGX$)(]NM9[&!Q'U#;N_0!MJ
MPA:E^O-9HD7+2CSQDT2&6+-"H)9RM/7826[7A,1_M\GY67#LW%+B6YU]',;$
M?Q)K#$MW-<%.!JN7%./3>1V5R%!\C3<>/C/M*67FA&O'F>9_$60A@0#<L6I\
M_!"-*U9%T=BMWD\,E:Z]\?IB1MQ7-L3Y9^OO"=%-L`^Y5W4,3^=>#>G0<+M`
MA16G?4`=`3O._UR,R2LTT7;6.D#G,#=.1>S.W%@1EBB!JB7=M'X#[J]+&W*C
MLJJKU:B*+SP=,VBH=>.D%*S\NY!@`GSTF4%O?>'J6A9ZCBV#2E7#+WOX*'J,
MV/8.JU?/)KU$TL.<"$D;5PMT=I5J`;TD<CG2C4CF51"'`A9C7]0R`<NY'&1Z
M6GY!_IW"$!IP>F^(NOCO;@KK:%[L:0JIJI`<C$:LRXJAAX"I\)47)\0":)%"
M"\VG]@BV5=]7:D`7.`&+:SFL@KU^;OT1AB7JX;Y<"C'#06[%U@5W*UKXOPIN
MJV(A`'X"=7(*R)#GJB^(]OWG/TT+J`D!D[$!Q5Z-DG;3`'1:W%2HF$7I.-OT
M!7)+-9PNW5%.BR\ZGDJ@?UH1^Y)*W.N_@<"!-TMP=Q\Y"4GV-.NLL-#`+6..
M:8E0\BGC%%[_GM9E%J1Z_R@+2O!K"'9IDBV@!\@7LL;L^1U@I3C@58P;%@N!
M!'8F:HG0L8,56XS9;RNJ4F5!HMZE?Q0_V$,POV;;@_B0]6X5L_7$+I(X7H^)
M]T7/3CG2#_*<6^>K0]<;FINKN3T\$6I,:9Q@.3S<3/SZ_.<.B-D:E"?=^]Q+
M*T8-77T"^<_GG;\N_I=]536Q-.ZAEHB8)\:=(S4Q)AV]<D^(YM'K[+F/U/78
MORLY3S(I:"^&6Z\_,S(^M$!V4%5O3\6B:>`$BZ*D8LUQ;SWH7Y;N#$[MN[!S
M%D:CV_>;)1A*(GW45'B;=$W=(__K3_^.1M>1X52X@@NB8.<!VC*Z+UG^D7<1
M7(X<'$<EUO!\6X;>.@JX<XSX7)XV_V^L\?P=6,5/OAC-=<`6WEQ&R8<:90Y!
M)=\.EY9F&75GCT^GI%@9H?PZ9(56B*F6ZJS%+[B&JRA"CJFX0_-WAT:V:[9E
MA&D0M*=1+<S?;^QF6GB`:Y52`V&PO\XP,U(_I"\."_YU?TJD&Y093,V]R@2-
ML`P*,[J]>V%8!GTX?F'?=CU&T^7\D$L535BZ9E?FO+&^)SC0B2_9:=8;Q7`^
MJ44[H+P7O15<1J;L#51L/.!G\P2OD57W>_:>TP:=]JH-]^>>WX0,-+.<P^80
MANI0F*@6X-&&KO@#3V214^_/\!^A'BADT,38MZ*3J2\X)`U')-+L47,<&GAP
M4"IBZJO9Z$`3XEXUQ+SF(C+876C]Z1RS2P^5\4YQ:2O!3IP9]8-5\ZS,*@5F
M"[Q#.NO;Q@7K:![7E^:J=:BA_DE=B%,#<K`<[(,%E1(.YBV)"TUY="B?B%IE
MY!U,4B<>I,#HZ!%0BT;2`),.X;I=I]/"@7'KN8(LCNHT>`.5J.79:/ZA:VBJ
M^FUED<_9R!D^4,2H$V1TFMLA#HPI1?WT'ZB!8%K;^OF8_Z=3J/M_ZK%M*:*X
M!%SZ[>+*J"GU[%YC\712&OWC9<H(,MS9EB"IP[_PX&P.6TFOL5=DXRBG@=-G
M6&\[_%BZQK:]T*^@(X.H9O]'HXZJ`>#VT/.9.Y`0C@!<!3[HU$R4>@!@>Z5N
M)X?S>YTN/?;.`*287&T-G-E?"LT>-K%26`LM<%Y&0'/>I%%.UYI]![20C$SL
MMP"^[D7Y3_;#ZIP9O!T;W2.XX+-[$P(4,DI9G'IRL#`U02K[)UU.AVJ-+6J)
M<D7*'6+5_+1.%%`Y4=7EJABF-1K>/#6XG*W"K.UJ&O7</%GF0G3"[^Y?L7X,
MKXR;6AQ@S,.17L"V$9`>G(@.KD_Z&-2R`['7;!+,2WXR2.4U`$0:.N8$(!1-
M+TT9U!J5`#(2"<J@%]S4]QXJQYWDNV&5<(Y>S=#*A8=?70362M]L%OK7SD'S
MA"C/TP5,GUVD4W\-1ZU#6]A4:+R14S,ME/K),(QKX`$KD-]</2D^%(S3:="#
M^+RJM#KB!5%_IT%D/L8)D3B%+(9<</@)DLKQ)K%C3$]!1"]ZON/YVPIL=-JW
MB`<ET0MW'Y"\7S:R6.W.&I'H$\^5JMR][]!:#DRD`]M\6IB81+*UYG=BQRHU
M!P,&':U5L`>9](`//9HC\H.HP3.:96652K$\=("L'4Y?W58K@G0.DM6'"-<C
M'3J!1ZA2RB(,"0L.O\$=NTJM1%XOY<2^&@5'=KW<OHY9$7*A6</IMIREH_5:
M%`!P)U&PI4<578;WK3&7B:3_HTORETIAPRYH@SZX=KV5O>(023'[GRQD"=P<
MXJ`V.1SG/N/-LS^D]@3<V[UK,-$+[&_GB($ONXB>.P)5OL7'V\M=$L;+S];S
M017=(2LGT[\%"C;Z2CV`PYO$O(X5@JWJODE7J*^!4-LOAX!V8H%S]R:AB:;F
MNV4>"1"6I,#,4B1^Y'T0LS+QZSP4N8W/B'7K;*$D..2/7`C!;XW^/X1DZ$3Q
MU5\%%01F#<B^V":KA$#IV]VFO7H'77Z=(5ZN]MDY;$2[]R.^KZ&Q,B\N>8'S
M/,M&'N@K9;`WP02S)U;K&D7I[L\>-^")^BASL2KZS%(WN8RO/SDF2JP$_@7J
MA+@#I0;*G9(CXC)M04K\2`LD,6'P5MZJZMAD2SE#9O5,T!<CA*JS<U;]$$TO
MO[*==!,\Y2+R,B,%H:QI;O3XO$:+M>3Z?%3#K"THC_D*(2BMCQFE3NIC:U+:
M/C1F%U_#9\"9H'K"P$HK*QGE^W8O!>;PD/"&\8UJ>];$KS*)`0CN4\X@BR"0
MFT-2:]LZ692PVW/G_*F9\8Q]"3=_.1<6ARVJBH7TJ,V-'QQ(!TY2@%`KQP3T
MO^N>)!_#-W86JLII@60%#[O6])8%)5E$#T>"9RRQ7O%HR7?CV3^L'_7V0A9`
M[L_ZAGB%6<OVM'M7XBT>(<CE0^NUL1XU47+)S^=2<[*G06VV!)N8ULS[*2*U
M*_=P(\.U.;\;[.'6,("];C4$V2P>D%X+&Q]#[+8F$%ST<$L!@J"\"*U.ESW^
MHP>*V6>:6)XIG"?>?H]>Y6/V<@V0G+I\4+!'!@&@34UAMLZ2J2RU8O4H*[78
M+X)(T3`&L_'YOU="7N?M'"3'))1FP?)`UAOQ9(`NI\RUHZL^<$][N]PN#WK]
M6`/XNTYXC"0AC>>GWRM(IL.YW4HDNUP@T8=X<D3KIP)\G7\V2QD^SWUR;0T7
M:<C\RHUE]MMF"OOWA[&G"/QUW'6K,8"^0W(2%Z^RC31#ET<[TYD\Q*,_L<EY
M$V!^<>I/"M6<>L8(I/"?3)@4.+W%V,K@D_Y%M^,S2<]>QN'S+>E<R8A*`/*'
M\.#QH:<7YXO2;2`7Z%0-\XQ*/L-AZZ$`G:O:GV0^)JW"%H=FHW*&U,?"MS,G
MZM#5\_4>R[OA/I:,%>==B==HO?OA"YZMF2-:7KS1AR.U+D.`\CW)D!IQUO,E
M<K*@,BO=N+5IE\]--@/?V!8[36NA%R`(&[>DVR_VGX`]M'9B^GXV\4#4AD*`
MIZ53V8`V]*^?K\%:Z1*!04,.,!^K!/)(Z`A8.4[THN6!_CL<^`K=7%59K#'%
MJ31$#?#Y"7U?W,#:P+;\Q>&B+SV*N,%-AV&CC/EQX"'[7`3M(K>0>/Z(5C`V
M2S/(&8I57?>XC`V2'QO/['T:@#I9MGKPK]+^+.VV1B)FS-``RC,(V*9R)05-
M7,IPO;A8'T:'BL9QOWD-@!R-EJ2,:]'HR;PC(F"#4W^7WP2*:\:[T#S&9`2U
M-G0H+0Y7!B1ZF+*0IV,PX3+J(-O.#J>](NMI)L!G%=MUSXB5'P@)/8Q5^P\N
M<TU9"@Q%*_6;WL8K#^$Z^QM1&WO84;J"<1GRIPS:#1,Q8G+@M4M/#)R.TGIK
MCXGFV326E8OFNC+9MT`+/][R%M+SZKW[H(BV:1@/G61_+V5@BITD70?JCT?N
M]W`3C0PCN@&Y#]O56Z7V`C?P12?RT6)9%GYU*_8.4)'&]"H\Z^T>_POH]G#I
M4B;O5X'+3#(C^!`=21^3W]Y,,$I$'D6^]%NV@.`#T;8"^*>4"+=Z<&R"DKV;
M<B6N@?<JPYX[S`B.F);9`E>#/[3KL#6'Y2\P\'R@W(W\9:V\FOI"V8YP0H<K
M@`:=<Y_^<,7/9'U<18"BW!*)`WBGEQC(SNW?O],HAIE:YL6T\N>>IVO=(8^>
MQP?LCTLE-XZDWDM2^4]KX=ND*X:-"?'BNJ1($L#)I`"U%TI(<:-`)(2R"Z.U
MN-"T=%^OE4)H%B*=A,9RK-`J'S-LEN_B-8#YFR#>AY'X*#3T_CS.G\M_DOHV
M7%#HM3EYM?#@?]9"SZ31%TS*@,9R;E\$F=4I.,\Y)*0E>OIG4I-S>5AC?Z5(
MPG/*_?`O&\)I4Y)%6X7/JN11??57$M\P_=OD:K>$^7BW;4TNIWTU1?#8W9AW
M9T&UY*OY4YI=_5%\MDKD;JE^Z(EHS#BXCP=`YVWU[]2+00P5OJ;S/^5#ABH8
M(H@^%8=WO<:[+-@4<!(@!)<#ST!NO62X0M9'`;ZDK##ASAU(NDFE/T#"+D"%
M@JP.XQ5:#/-HZLOM4::='D>+)P\J1)UT9#DL=I2)&_%.IP1X3]4V@-K@N]\,
MN_%D:Z56ZE(#WIE5+*@A:\S2!MB[BDQ!XP5R6_*:R9X//1V7V+IORM)6*>79
M\4O=E!'UU).YVHSFN=UNM2^Y>K&Q`UM5T(G'*2E@/GY^$,>#Y$=MPSH/3@%@
MTF^;N$2%$A\*,K/4:*DL7IF.0GY>'?!`P[`-?2*(<]^_9"+%8.N^(B3\;T!?
M37?L*;O,WMIN.M5,,L:6_^>V`FGZ1X96X*4J%#1HV>O+]0_5RUYF/#]P:'`@
M96-H;R<\/R<[/SZ`RUPGW?!(!:9E_V(T.18NZ![J7O9C]DXK)E&(>U:EEB<_
M*T@:IC>H*<9L,81M5JAO(/;YO*^3E5>M$XI\L5@#`RG9O+)<KEU&%SSKA?ZR
MA(S9X0,9`.W#VE?@1JT`*Q(Z?"=MX4UE01*#<5ZM5`,)3T/F%(H4ZWI.>TKP
M//&*"UQ(XV;S><+:;*0[&NO%ZT_;;.MK/^^(\WG>>C?Q6`!..UP>A*CO3#S<
M,G*<X2IV#EY$:$6?P?L%>T^E[ZWD+/3)KU_;V[S8+!Q&+.:1$>`VZ)09QX75
MCMA.+T]X;A"%DN4@")[HLZ7MWTX;J%*4\,$=L7<>S7YN@2I=<4Q[\]E:GEK;
M^!WA+5%<I>(_N3ZFL\\I!TQUL!3HF<ZX%W)2IU$\/(OFD4#5@1_!;H.6HDK'
M^5BVNI5S/P19P)WL'[CE_N]RO$<S+(U_%3O^:5749Q=21]UW1WLPN',!;3OQ
M?MX?.S%"T-Y,6]4?^*87B_[28_8S<XY''F@!IN6=4-TK"@#O(_584[GC<]#Z
M3U^X9,6OL/_Z)[E$%X_F(T,NR0A7K.O'\JKV6(;IJ9M^U@PR4)$:GGP!B,&4
M4->/E&>/MCCUKLCLU6,:ET:6J0QK@4/YDFS^:6@'Q/BGS?T#T*9,-*9TH<DO
MJ)L9Y?=V"MW&EDS2!-YY)5=^RPP^-.).6N#8`%`_N&OW9![<N]$0H*[8N)Y<
M$'&0?01[4-XQ*1@WH@V>;?M>WF_[M4]<SM&6T@WK_J9N$(JN8YF&S2KGC2MD
M]I;*2'>^6_N_);<2,Y#9K=_Y0;_U5EEN/5>A)E36;$:WRA3W"R+*B#4[X`E6
MUY:@78<-$==_DK?M2#\NE8\5+"O5^GTH]:J^O"T@1#),J3+`=;)%87Z[RD=/
MQ^H@=L,#MNW5%YW?(ZAQ+JH2=_5;44A^#<]"WX"'M8F=&E'W3$3=P=%(-ZTS
MJ8\>CDO_*VM9V.D1>``0:2Q'.5R:+:K,`9)!0J*=S:D7)FI33Z,0O@C]8NXU
MT7`'="JC>V*"''MWPR=;`FC=9Q27V[=?O1T'K-@64HO\5P%]:F-"K-.\P5Z9
MDQ/(3C`L&ZRVZ].-!Z:9[3"D;+!3`QVQ"S;=(=$JD"*#O7BX;NMUNGQV1FNT
M0G%0\:9(+OL&Q1`+%1\>*E5`N(;IH$H8_3P;3JT$(P`"FAF/:0(#D5Z$"I^T
MDSS_@W8Q6+2N-A$O$YC[ZU>/'W`VY=;K7:B"%&:<3J.`AF/!`3Y/0&N<\G3=
M73#_OCFK]OS3F7'4&HDY%3HK`2GH<.4';CG11VYI^,S#)B6#`JV4-AQ4([N=
M_3]"B<`<`#OY*7S0_W0_'FR<R3_]G'SOGJC*A\73>S<KD%9G\`@L#I<C"<3*
M^F+6FD(W]*>IK_NOL:!GUPM:_L^3T$T*CI>`9#@'0`A3EE>/\6RGN/JRYO^`
MT*M$0!=RYL'LA-TO7V9JF%RYH\FH.W;=.`=/JY^$M9*\'N8!6Y=B2OTR&3^_
M0T/NFWN>:?^M6`A!74-M3I&NN%.30]VNN8*9C!1_,I^WR*A2R+]]>TD*>A+1
M-P@L$Z;Y^H=LQK5M2[=J:'G4(Z@2CY@;F_GO=3!?!^!+"/)L7G5)S[B03%BL
M24*YMMQ:,Z_F<UX;]%^VOY;5J*GZ(L@:2T;Q2KC?Z74@EI,`20,)/W>4#IWF
M$;2:3V_66"Q1#%"SX&XI8\];/]>"\6X(5ZR>[3"$4%CM?*U]NS9SQ9I*+38`
MLBY>%]9!E@DT+>27@&X>J`CW>E;SI1%."G'1!,^L(<AFO^_8U$15@9&2'I7M
MR*_=%8&>U?JA&"J@Z6V$-W^L!8P(K23VM-8F]9O3)IE$[<RY#GFD)%=O'6*>
M."TD,#>G,!6A<V[#B<:4"5;&F2C<__'B:9T/QH>Z@U!/5`Q\4/M(E_`NJ%I%
ML/P@;YAJC*I0>N\P0&MOC;NM@[4:A0V:GSAF?MPL$.^A0;3I&924IUPD/2O!
MV2>8K^FR"J*H(RF3&@N;^)ZOFNR1QCF>[@=041_(>P.:F;S)$Z'>S:Q#30DL
M7EL_V''G+JD4]6"#I<(CB2R"UU5L&JH\G0`^K"<\T5+SD/I9Q+K;OCJ3TY$^
MB=^8V..!O^:?2F?*Z<]]D,20!ZO:N!T_&3)W7J\<@"4OCSY.TX<3D39PEJ,3
MN)]OVX:L0T39;M$G439(U5#:3>PORXJ:8Q<4L.I)0R0U>8-G==?*QSCG,FRT
MF^Y6PXDUL@Q1`5M2<M%A0JIV!+NE_=#LNIIN4^#B.9<ER*/!1(>[?(('K3:R
M\5,QH[S,"%4GFR92W!E(:-G6D'^QE0K&KB&_N,!8X>["1:^Q;U!8($#TUNPM
M?0+TM='(^G,A<DKO#94&_<U52W=_6`@_UW=\J>E7K+`U6$E@"0HIMMY#O.*F
M8CU8U/3??UXW!)NUBUQT_WV9=S8##1*#\L%HF])\KO\7C"]YR8D_*T3-_F#!
M$FP#L"+@H"'FB=$UC;U8=OF42=,.]V*J?-TP",#0)Q3D8\9I50?U)2>]G<NM
MKXW$HF1>,>,B&!#(AJ7;<EK_H3.GEVEZOLAL#"2_O\+:3S"=JGVNR4=M6=Q1
MFZ/FP*86<^T!>KI')R1XGG7!)U9(=B&A<9/UF];S=RML962I>S"OZ18$Q,J*
MVQAI/DUQ%F=)AZ384D!8@K+"6$VFE5JHD4='`X;XG0&=HB/?,!+!A-.[ITGI
MR7^PG'5@IF2:"N5J<6W`SK"6KF2K$>]?#O-[2,7$?5$>C%Z=H+&W;(?JZS,C
MNDJG1.%[2PV6^^N4/X1ZXDNW0B^6`/T?.N!NU_'/,@&>0:#P:F;F2)*I7P&^
MCRDO0$US"^EF*V[LH#:?+V"JO3>5'D@[UQACIS/B@W#S,&(#XNP5;`/20#W)
MWT4T!SI%%Z]\9^S2IKN5>'VAV0]89-//!P>CR&W]Q;GUSQNX3;BG.^M)]P10
M!U"_]XZB8A_N;FFEQFBL*<Q?MJP,NOA-LQ+M+0OZ,N%1&!G1S30':.,^]2=@
MM.H+AB/T4)@"+,O!'AJ%Q_KGC$@9X=2NR.#D]YCU-^PS\6[,I"4R=KVMQK2<
M)D.""%]31B+9G_$/F_SXUAX%Q0O*[^!2O#I1W4#.=`'ZEEZ2<,!O=63_4.0T
M>GHNEL/#-U+*:HI=,L-H_D.QGU>KT02T:H$Z;+[[36=MU8AM?7GF5)_KI^%_
M'K)@=\;[L-HJEF:O:Y2!;L5P1&Y@N0TB,CC%+F3%C9([-S'][R%$>0;YQNH8
M#Q/N;574#1[Q608C8I,;%<)\P5-`'/X#9Y89M^^YQG-?F+QB7C*L[79F^W]3
M0PZWFK[)!&WRX1+E:9Y.ODGF:L.H!4KQ"C=?JC[7%*XC&\)F(W62G1G;3F3/
MJDG/><S<*GO(,;5ZF\2:'86U/71'4XZT/TON#5F8E#+E9?AOSDH`*K(J6;34
MH3<SO$*=]>X:5W':NY,]:VMPIY8\8LJ"JV<[.;N76ZPSV:,L!>T9<.%8DM3!
M^?KIXIPP8`]G$-KPG&1'!O_B98W&QO[TT)!V6'Q"9+3M/.LN>4[H![#'`P4/
M/>\1;=RA&\.8*KQ$_Z>-0F]S.-5X@'N?[SFZKG'ATZ;EP*AG;FJ\V+%R28BD
MGV8Z[!,BII,QG#4D0DZ]MWN.+D1P5%(1!WH(O0M%-:]VKF1$YHZ7?*Q?(H#>
M5B<TFPKH3(-?#>;M.0M;F-CT'F.4\+8C=1`P1()UG+]LL!6*@T1OL74U,1VS
MK^4PPA?*5UYLM<T4;<>F\SA&O$3F8=/!=S16BOB_RSISSLZ4MO[XKC\[:'@*
M_<A4LM`'7#X)KPMH4"8IVK[9U1(+ULEA:MIO,KH/\@^!1S#2YUE=]&,M/+'Y
M/5X_Q"45)Q6IH*:TR$UG"4E=:B#2[&Z5+8(':YAUE>D0\3&>7_J#L&&X_?42
M#6P::-:;)FQC,+6A\W&EF8Y<&B'+WH9M`^2QPJB]2MN-DJM8]Q(X@T=V<^K(
ML>];/4+F)5=%V1-T!4GO^+LME#4V&4";M%PS"`.>]#S^O7*"?PR2_.@IR6ID
M/K)AKZ\R,MUQ;:.'42(2)5G_G?$*@ZZ-AX2JC:6(0LQJ'S0[G_6HG'''\/5=
M<"R%R[#Y1ME:(]Y8OJ+V^;6D%(@2U=-IIS]I79'_]C],?I>EZ[Z\88F>*$/I
M>-B5BA197>]YCN%:!.;"*:-)K`X0';W8GT!:*0,YT6(D.91J^I,TXW*.F5QB
MM:(%YZ"HWGW?.WV)GDHBH[#,VWMV1@M=B7)4Z2:N2=7<@`':,G9@(T$>NU$<
M^\4A'$,H"E%EW5D(SP$_6]%Q4*XGBY:!?!`/#&H%XV%ZSU%$@@-:KUXRM[F(
MK9KYQU4L*^E)TB%56'Q5MQE+!<,\;Y]OUQ-Y\)9<VM[%XG7;>.5G6-$DX!?M
MWLRG34\HK8_E<91]#UUX\UEA^VO^&FE%T!`)<QE54PA_G*4\W8.9?O6*U'7>
M["3)O"ITNUL\PS3#TD9;8P70\EFL'(QJAYU,D["O2=^!=#NZR2I-$2FV3</4
M6_YY]TA*I,QFD['_C@:`E4(EP0:89B)$?RJ;_H%,ZI!S)8K4>.?H[GQ^H]E5
MCR8VCJ&^S&7!3FEML;YE%4I0\_EDS%]F*O9+K#3V757&5,M$622ZLN4@&S$O
MO0Q%!?>%.ZZ,HTDDW8\K1`D$I4&KFT?D;BT,XZ8^77P6Z@"/M*)FBY_IJK\4
M)ZWQJ>.GHDPF1PNZ>!%A#I4NW,U2@$KEV)#?F722CY%S.50FAY&DX1C09!4#
M_Z&:8$<>%:C5W^4Y#9E12H"I06'Y[F?H@+%/3TYW0F8/`59`W+N=90*2\K1H
MWXDA&V)^93:/ZJY4VZ^TK7F=Y`Z#"Q1]0;<<'H=V"-38`?M%CF6^49W#E]#3
MX)-*YQ_$4(\0C4U/0[\'2$@Y/"QH3-D[$9M:51=M)GMJ#EL,T9)P";O=3EX7
M5S'X-_1FV:Z)V<$J4W8!HN>+<D5ZT+I3&8U;'"Q^4KPKZI!OEQ<PH&.NDS$(
M6I!UIM[?AI1<W,M]0_!''(ZBEV,&-UHA9GO^P>(38YT"`8CX#=LZG%;/*22A
M%$Q&F%[?S'='U>6+C`4RJ\73]^4G@2Q/)U2B@G,JDB<%'5MS8&;`O,S^AJ/[
M1Q(('D\4R%&=*PQ]H(V2#OO5\/.=TO:QIZ*3G^$C9<JED$/^_PLUV4U7G=[[
MVEC+WM$1K\M)A&^?\CZL(O55]5IW]9W;L>'YOX_<^3Q(^([R6Y$+_:*1>O_(
MQ').2:^090-`U_T7UV";-?B)9Q4U$2!I9\/RZ=$,7<5CK)8VK/5*)P0@%A6\
MQ"9DSS>US_V.&#`SDTL8JA]I:<-`]^:X]XK+YQGESAO1`.HUV53MO1R]*S>]
MQGKR2`3U@E'Y;S;S.$7-\L;$3>B.7;G,\H2941_->/H[LS+CQ:J#M8"U/%OP
M!=E@Z57*V0Z+4OC,FDY:O6!TE1EV%M-N`3Z#0:<9M\F7>O((Q"&F:L41:"#&
M79S;8)2;+SLQ7'\H@)ADJ?G0HQ4J#J/CBR]((_+[O+GB^K&Q7F]GB`R-G0G)
M?Z9UNK(3@280DV`=6!EDP^F/+X]"IZ<$-&YYSN.B>P9+S"C:`RU]5KIF<#['
M2R^QX=]WAI+U%8#T:"FR::,2(U>5UK$`C'+SG&A.^8-Q36$S&9.XJ+T4`$9N
M]$"$4NPG4[!W.2O-=0:\751]C?-;$P>D*+]-=30'#C?:($MSZUS(@S)",G>&
MQ'1#8NDBH'5TRJL3O=GNOE"4;G:\`BX>41H.K%'K*QH[6KF&DK$J>TIA4!7Y
M)9HDL&]V+N+4;)57/RZ^?4FLW1K`S3,<A\M73(;9.,9`[)`W(</[K:62<4(K
M8FF"XH1_;/XI9[&2D!J$R9/?;MSS<0N6=1+J6'KIR'*Y04NZ>`&JR?W`UK8X
MNG=`E,`/'GBRRFCVR.IOF"5##!Y0_:7=,=?0?H*_]CO'YHAOEQVZ-VH"@IFF
M7\02]R!&BCHDAA*E!5Y-KD!F!%_=:M"5O8=!3F@TOB7HZRF31?KE/+H%RI3E
M<,FRA\6.W8Z?+E\98P?U!]H1KRPMR6OK='N/1?,!KHQHMS8N%4*-G[!;N%Z/
M+TL91(7GK$SSVNVJ\]!X]^2]`4*+Y*5=Z!QX)*$*5#C,QJRT#&&"STK0:2E+
MA+MG#1[Z*DF0*WF/!V\I<?+R`+3UH&:*=0(.6]P?@&,-)/A&&D#_$`&59Q)`
MF!'^TOJ=RUT!C&-[CH,'AI^&2O[VGQ3A`'ESA]H-S]<9+WB[H-LY7&S&W58L
MW9H/=:I?A4G7C%QUA99+H&9J6R`!>Z6:7V3W4$6$_`FO`P]*`MUA4^H8QL]6
M;VB<08/,_8Z*Y96Z_F2DTF8%LVT!6>5B@`(I^+@FH*O,@=/8X",7'\,:>Q=]
MM'EL`*NYIIUQ^C>4FI]%*&Z=[;ZO$`Z$1G_AQ6:M>@DY@5:4-)[5(SK),#G\
M.;7.K`V\0F>@@5)I*Z%`RYO=!0<$Q[':-])D"/^75\M5JQ)GJ2S?E]6/\K12
ME7$EQ+Y^N^#RCU7H#%S5W;#N*EU0S`=T&T2SG(%%X@@]9GJFIW:RD)(2STZ4
MC;R(Q^^@22HAA*@0\_=JWX_7*4N]^4L#4)/61(@[>4[R'7(]^+=?+Q25O$$F
M,7=%KG0VR?A/`QX[.\%6T9Z\;.VTKZUG(55/W::B^=0[G.27-L69JW>\F^76
M^PQ\0_QE[@%VS_BG6-SV1?\LZ_&OE==A/'^5^V$[%-.KW_BC2(SB?KX.P(!1
M("#/M<7#&]9A9>W*+;=YC"BK$J.*M(0Y*N2Q`%]D4?CFLA,XGZ#*QQ-=)=VO
M:07C073#)4$?+7#$G7?3,9,&P2/YT=8;C3>]O`?=Z"I8`_;3]D(F'U]P$2AJ
MQ'Z^;:`PB<WC`3-%2YX(5KY2<#QHLJIX.A=UJ\_S2>2%/"5<J=VM:&<;(>*"
M"$WS_B(HUGM8U?BC#M*1&@UH'2DC0/YTAMIOK(S&HKC)J^2CO>*6+%6P2:9R
M-6<6Y/?JGV<ZM$_SZ2&L._XQ5I"F-AMWSO1I'U&%_+'BCN-.,0!$"[V\DB]'
M'\G9LE`;A:\T0RE7WO[6!1Y"F2%W-E4N.$'R'^3*<!@R@0<'%0$A$>?+I=$K
M!^99'IF]X&OYOFIPX=WI)GI<\Z1G^.>LURSU$C;>!/;K_O3>'/YPB60[6ZQK
M>:0N*PR,7Y`H>W?PKHZ21/^;EHM\_'9]>_EP:0I#`K?Q%EMP[+83RV\0*>09
MZ4Z33J\3!NII!*HNT[/(;I5)K271*;X<M_4<+-P9_2[^<.BJBF=A=L!SV_KU
M+@5!6F(S2`"%5M:WL^G=CJ?0[L=,_HT=O%F"KAOEA!A4QDL4ZE3\`-[W#;RW
MZUC`Y`:DMN6]*M@['!2J^9W<U!W#6LH$=5257-\:S_<&=P+PM9F*D?GH9])Z
M?B"K)QF0C%8(>V]+MN:^\P<0XA2Q+;B@M%V]4`J<789D'NDO0"IBGM8K1'OH
MW@QPP>S?61PB^/J&@\8V>V.N7??;.M%D>K:3'=^5\VJB8@U7I#\C*_Q0AGGC
MA)#>7-G+)%8DQ_+^(+.CC]C+<L&EGS&;D"A7Z;I@A?#S*7T.&6-;!^>9*"GA
MT=Y@Z/CP'ZTYZIA'_$NOP/,76Y?/)-!?!LB,LH/W_I-E38YJ"X=ALVIR)L,D
M*Z<HXYC%_AL,7+L^6"GHMAM$.Z54/==Q]05I3EQVQ(.O09F2[@]38L^\C`/_
MRP!,(RM^W2PO.=`NHE)SSQ]S:Z(S.>"K'<V7T5V];N^UE^?GP>+$#)++\!:F
M=Z52A;MM!^!8KQ",T,/./D55OPQ,,0^VE8ID3.;3_`'`+^4F\F\DG[.HG_E;
M2%8N%Y\]2!MQ"\@!_:XWM$^:$H;GI4,`76Z&A&ACU_^>^P.FXP4*1E4M,B+"
M.M_BKLI(LNY"PGMK'P@&Y:ARQJZ[!'LEX._?L,!LAY.H)M?0<Q34.T=2.,Y#
M#ATG]:R;$EU-IBANQ(:M^=C!.8HIG6)P9D^%MMQQ8;15)0F;[VF02K5VS:VU
M3>;FO&$5)\XA=K:%<U79,%6Y;B`FIC9Q>DM^/<[A7/SA_2_$7,T19S[SF-)N
M%B7C?_J+V\1"<:>YVT8?@/(3^XGU`>9]VO-'*0E)'*>K0=`C$0>;3?@NWP+O
M7ID:B6YO<-J&#YVA<W)VNYZ`C`!GZ/Y>/:$0$YSZ0RPJ#X*HI;=X$?1,E)#I
M\L$T!YH\7UD\B[NJSAA%'("3MMF,Z;"DC-2$G-MKIOXZ=*@.`C^R%9&%3&`_
MT5#'&5]:Q);9VB>7'?FS%B@40=_J!#_I`<Y0_,('(;+V$TI1F=M1>O5`=`@W
M-V3"_OR'L`E41MP#9%V8-,MWZ)H^WJ"L#T$7!>*T52=G5^P9&92A)23TD3,O
M]AD<^HZ]]6`L<S^-_R'."Q^V'!ZLP63^OJA7=(SWXP!;(LMZDHV$B8T3</J:
M2;P;N&C6&X"PY+GCCS.'#L#Q1I_*%#'8#5(H.4SZS;QJ$4#B.#)A];Q-W%_-
MO?DEA*X7#<`"O$%[VH:'7RU^?QL;6,3'V2W#;#B]\/X1F"2K6M97J>W3:24,
MDC,I_OD)MQI3F=#QODV'CKITI&`X4L+Q)OA_D/)[<:Y;[&MH(ELH:!M(G2.7
M_$)FS)XGK^7=DZZ<F3O&9-J]:/%2,WUO(@L@1@J_$/)#7`L)D9Q4)Y)2G1A@
M"#Q?./CU)1H&NBOW+I1OFI#,*0*V(I(DB'2G+=.D[D)*9P#($'*74@C&HMU'
M:*88[F-[@N:::?S1J-&^$VE`L_J[`0H>;U^V3KIC00LCZY7XV!P(#F[QUSN'
M<&5`YU6.;"_E_Y4/2[<WP21H9O(Q;5(F>GLF%H'I)28K7U)'OLB-W=+#Z91L
ME8VHS(.7#5;5N$Q`/!\C<V@(VUJ-@F1EDP_=M_!5&TV78<8TW4A\LZJ`H=-F
M^GN/90O-`5DJ:CEULAE6V]I3;MW.[T+`1-?('#K,]9Y/)F(82(Z0>Q:VG#4&
M'G;R\+FLU`*W';0LU;B(H[MVN6'K<P)\42ZKP+VJZFT5?Z%I]ZH&81@]7MZ:
MIN(_:_H2C)D:?IG?ER5W5X-6@F!R:KM7(E+P^G\ZM6$]667R=E^9,R*._-)S
M9N"%%HN12>"*B#<;K]HB_"RR,3])"@QQ$MHN]:8H3A(?$0Y7WJKV"]2&V1P7
M#.P'Q?*MAE8AM4B47KPR^JO$QF6>,"NQF3NCURI`/X+(>.C?]G`T2=P#-/I+
M1AQM['B9KVH`&VSUVGTD(=KI#!G05[_AZ3V]9F6>AQ2)*[>"9N,%VZ./Q2B,
MA]2A82WPEQJUHW#HTI8(?21XLJ00@N<)R*OIG9D134,B,OWQ:+(U;I#UT\/\
MFN%'(3O!^"UP:]';MD+.J7/4M\0%+F3:%;X@^W>3ST:?>;/UWI'T)@/F;-RX
MT%6!YA-R^UX,H>XKNZPHZV>BUHB'[,<V'9RW)1`HB"0DY_:^,#(TO^L4VUB\
M269DDX<[).'7:;>^4H?;$(!$3+(\799N<-(7UMH!M%*.1#AY_],+T^J=]H[!
MS%E\[-Y(7^LP$JY19CROA_!4FL\I!BR\^8*CXT:)X;.%EWYI.ZI14V9))FM7
M@>CME0/0U!E6!2:8=U.J?Q(1^`K%)15>J>)UK#?LBX='OXE^P#A+<AX$.'M#
M?"1D4OHE!0:O9U!23XJ^C?T%GQNO\K><R<?P;*D'B?`!/K-%0VR.J\0I.=VQ
M`4;0JXB8('^"VFU.F:9_=EJIESFT;H`^ADV+]$2,CA*M```9,3T\;*E.EQ[+
M=ZN9Y8%.U:#5,Z4S@?-*-W1!TUL/\3T"JE;O%$-7E7?8>/AX[].^#X-`H(A6
M9Z*J?+EEJ]%>Q4I)6KQS@>*V#)HF"_<ZDQ@=E842R6/PG8HC9':VZ1X7H.LO
M4P>ZP3`N/'#\"!-)4/P'HO#OMR:*'.$#C<EYL]72"T"45"%#1+XTA$$9??>=
M#GQM!>*`#>S]5'O@'5ME[Y^FHQ+MVM$:)R!BVP7P='I5=9X/LO4/DN"@]JHC
M9OEWY^VC!]X$8+@=PI?^V!L\FN,D?EXX%,T/4.!.\$=:.9588O,\]VO!"8FR
MJ2BVT5UTF<"PU(>->CO[+6&O=B-\5!U-"NNQ\6D1Q2C8B<IZTV^D%*@SYO:T
MM\XY"Y]1=53[5>1?-MK+HU?49Z7>,+=;\2`JP0:>`_'KD51Q$V+WU2HH/*!(
M8#M']1=W+*7&M.TG*U10*8_".C."AV48C"6,E__-0/U^[#-\^F*'!$Q^I0K(
M>J'FX4<;RX>O=<?%.Q@FL4FL<2X+G9A)LE5PA^(>Z#DP^8/!W@R7KD@6H%BP
M&C#=Q<R>E:F*Z@QN1A.:L>GBD>YAYL"%@T8Y4+/Y-1DT+&<@<K-J4+*2[O+#
MACX.!=%O@Q<*=5)6]ADK0=8-$!(+/O*SO'A"[)=G39[DZ-TG_;*^0[UYY[/K
M6O+Z,>0Q&9;/IYH9<BZ8(R"K%QF<Y,3Q-P0>@]'MD[)G$P9(/NUA#F6D`ZV7
M<Z!A]8$?&,1;L:@R#3=B]C'VE1:BY%4M!:HK&?C!<S#%V.T^N$\\17S:FO8.
M&NCSB=&+2.EW6=<8YH.*Q_"N]),#%FSB!4A2](:8G^EQ4^?4BAB<#?(ID@J7
M?:U:'ETZX]?30^9-(5MMR3)I$]GYX'V??PGI.'?ZD]1,0A!K>T_278+ZT@KE
M.BX(S.-Z;=69]^(8<822[K7918WA3T\4K?C9%I17G^0(4LJ/Z7GLYJP1%CA`
MZAU:>>L*#_H2TUHH[TF.9RU50T64US/8>7>-GN<Y!X[22B@E&MQG(A0[L,`>
MH-JM('`:<NNV&D-!-%VS31MB<9@YU-$J?KJ(LT_@4?V-#>O/1^W<Y$?>CA^?
MP@JPAC%N\KPF.;6S&:QN&-![-_OFYGS*32?I(P+QV#Z9F%1X2[B&5+LN94#[
M&Q_AVZ!77M-1<N,=&T6FBJ)JV<IK_I7;&W5"`A^Y\^;]#9!$H5DV$1C9(+BQ
M*\>6GYK_*ZK:+KGM6G".XS*2B@)/)&L%1`7FM@9!E,7-LFE8V2;*PA.Y:\90
M::@Z%O3??K9PS12?[7+S%[Y0;?LP'Y(Q46;J';G28UECTV(]Z>''(GDY[9?P
M9,J*>,T#-8M9>RH7T.UZU'/'>7TE<7CZM]'QJ%<N9]Y@@MH83OSN,2]0V998
MM/(U*[`0YP?2KFS21&DN4013N-KN_!'-F>X0PQ&BZKUW!3=6QQ+^ZXW8#=+6
M6J<G+^>E&E7CM4]!::*2U=,3B%UHR<6EG6I1\7;P?WV,B,6#*7#5O_G8L3T1
MJE2Q#*RW@3D;VY(8*0)P($V^2#@LCN8=JQ(V[@KHA!XJJL'M9DG!J4-NWUDR
M?W"?\P^4%WS*LTN*IU#B`CP"Z!,KJOGMA(MBF!37Z;P/@)KJ!C/P>2AU+YA0
M@2\<EW1BZ?-?Q_/*=*P21]N)0!/%-?KIZ]PK_/I9/=R5+^$H/!>R/HZ2A0T6
M]*W"4NLDG[-+U!,Y0UWV.BI2FCVLBRM/PHV*N4`Q7T2L)0$`C!.A%$7==U`N
M<K:@)FUY',S-KFQ<EN.!/7W%-*-60>2,8-3U$*R/413>9U.O1'/&*]XDQS%Q
M/X=6KFNO^71QX5#0OES<FO+]2Z9_*S$S!D8@AV'N)-6D7A-J*]?`6[PEU*""
M'FXXQ@!P[]`>@:0=5JN+_?NM788UN'=-+,IHE4@,D,ESEI\C25@I[*G.Q&):
M.'4R$4(4D_ZS,=L4J@\RGK4$:MJ7AKP!?*(WV5C7]V?N>?N"W;*+]O%;N6F+
M`MX\#366)V%CJ9'EHRC,I*D]I34*"N"K"0N[HX`BX)W/V>>M:DD4_]&*PYNN
M3177(]]W_YU[THIF%Q.9ZI!UE90SVR"LD=?N@"T:P=*\3F-V7+X&];;'IW\N
MAUA*.[J`ZU?_.9I6U['EOMK2_4`'SUSV0?+-MZ#:K&:2M\=39`X;[F5=G=E0
M:%D0F"#&E,EAD<!(-H`,9U'RT@J.!.J.3'+$9+2`AC.@GMH??C0TWZ5I2P";
M<6;QO'L/\;<,*3,_T.#T'7B\Y\YL_1X?+-^?S'E?+H$'26CEA697$E9S/QUV
MROQA)>)1_5'W5T`[S*>`M\%9+IF34*WFREL"@![+UIP(Y)GL(US,,)*_UC2-
M)`E/V`"!3I/E[+88/:R^,5=V56,`B,PDT[K&_EU^K3I<T275OND\ZCP,@<7+
M178JV@`^0""!RFP.\D2T2N(MPI*O(LTP(ME?%E!2\IT?[4`PU6FB#>*=^)FK
M,^IT7?N6U(SQ8+4.E!R'8+L37;F;Z>+,/Y,+:6,<[;3,0%[FA?B0#3N^H9H^
M3#6SF1'%_!0\(X%,2%(()W?'*@W'4EWPU/\LZB/<`9!)2\4'##++&)WP*3+3
M4X`='F3Y4S3*H;XO<W\8]/Z;.,-PS;=C10B>Z[;R-0P3>H2AG9T?A15`IQP@
MCB0_!B-P@G'0E,)*]+(MXN)Q"D4-_@G*N@!@\\H"68;L4/_GR%I.#LI!J_5!
M'\Q%S/%0RF8Z=CUJCGT(@0[7K!J!B`".D)W-_:A"@6O5^5+`4NS/O93]YR$C
M7S;)DR2(7-LMH'C9V-:T8(EL</_7T'C8&X=VE7`7/0B9^RGL$HHA5Q]2-L`#
M0!>#?K"_Y-6$P=K&M`K<<6'1J$);QC&QI3XI[T?OF0QO(._*YN#5N`Q%+*5D
MQ35X@_<':S,'D,</<Q$AL0H=RE+()T<,C'UF30@QR4$41$@X]TD\NT3.#UR?
MV(UMQ^J12,%?JYK0I"ZA<98P`%L[-J(PWE>.7/E<ZX0?$(.ZA(F5;U9(3]]-
M"&Y*W/@1OU:)4*OCJH,%K*3#H@`X%?*?LT;<C$<E,9&&-UJ#K9N[U#S8CUB1
M`3)"9!C+>>&#RW?[7VF;]50&,-97\W7"X&<ZDM%/"FO+D6F+6"Q5,<<SK9-Y
M[M9YSXA?@41RR4$9ALUJJB-NMD"FXZ=8>,MKM$T0?><+DXC1@C*GH8-HY.F3
M?.N7,?]X]F_X]LR^<_!)-)R*VC*WCO4K./32-J,(S_%U6YS[_@+$_>!O*U!V
ML$J^R)B8%E44Y9"VD.5]BLH0=-3_B[>N_C_`K1-9$4H8P'??]'@<$#.<>:-A
M\=H;1[7(]Z2-F'Z]K$QB*,D9A5$`Z3V]I`NV1T/M4LSWHG\$\C@YOK057\I7
ME=-PXQ7S$BI8>_ANH#SWYB=(4!!IU2Z!L*=5,&7R<G;#E8=VRLT79Y`RI);:
MB[JW%BL51T+2(8`1OLT0N&[16%N]Z!JF!AR2.7-)JD2I8<N_`B86)V/EFW#+
ME/-(PL*4IHS5FIIRKFYRE@TR=9O6\'G0ZNESJP%1,22/:?BD@-I[^*+O+'S%
M2XNGFU3S'U+S<]O2SS_*MG<D!AKOK0.\R)-.>.K4@[4#_SMPFI"F4==,53C?
M92QDV1?``&[7BW?Z3,$ZAGN6]G84(+W+6-!U4T%AO(I6+9ETKB52SX#7+",F
M^T++ZGZ]]YD8Y.,T?>FWE=#"?=)_)[@&@OTOU5C(@>SN`,_U-2SUU?XB861T
M(]2%R;']LC"BYJGR&A"A79.FG'U2:="G^5V>+,LXSB]XO=N%;1:0WG@H=!'Q
M<!]\R"2GVM1->^@3\N)+AAFP?()+NAPHFL9N2-]BS2>.<LGDAY#N#3T=B8@6
M.L!PHYN+RF_SU?DR\19&4B;AFH01N=VS@)VZW70YRJA3R*):T@)_=;?16&`7
MD>>\+;5A=13BY"&3,M(X/A7&N4D^EU2;7E6X9Y5Z(_*46]W3C*MT1&KNW)3N
M?Z"+;QD_^$]4)+R]`:IVB`P@<L:2/4VBYK&U"5#&Z+Z[)HA80C5"Q*@,F.QV
MU'0QXI9]?X-F.,<M&8;9=@``O(XL[HMP<<N_B0]K&N63D$2OS!R^H?^SNGFV
M$E.&&\7-T!,)>162T>K"!IT&Q6K8O1"'(T?K!'(K!*"N1L[4,?PK6\P4OC6Y
MQ>QEW/"C03W+1XD",Q%7)WU4N.^DH9'LY[^[B)-HI1`H@Q;'EOBLLYW)?5A`
MGF.+`3U#J^X%5\TPM;J&5._X&@]ERA8KV%%@CTPPD;Q%1;!9OEHM.V7KCZ,O
MAUO=1%!D0ZT2M[`]SL-#$=&Y#0U+D^O#B0^I:5-DP($H(ZKOL<XX7O+=VX!F
ML'$9X/?C(6,^AY+$&DCT0*:#RIY$X(T"/C[W$$\J1'\@5E(BXB*9HE8QA9]U
M&)2`S8H=MU;2'0(^]%;GU`Y(N1NSP+6RW+X`(A(^*$0V<6T`/QI-7REL1BM_
M'C0E4RI/4B9@J)<!@1ZX>K%K)D2P7_I$:P[O0,-(DX\7/.WW^/Q];6""3(/@
MW?0>Y@B_\',;9'`7=PD32%G?XKL=-8`WN-1RAQ\Z1Y`!\T9O.T&I8F/>%N%:
M9$'%[\D/P;BE2`RQ?514I-FI)_\/,4_WPF)2J,VV-JIG081:X::/QGA_-[AK
ME__1+Z#J^/M`TWATI*FZ.>_3/\7/-,:WP\#G.>!%<$A;N[[@J_0"%T^]:P0/
M@FA<;HS;`T+A;Z4S6F0,9&T#?O5,"VZ\&_!IIVD<HG#'7\WTPSPE[S8/"ED?
M@WD(OW%5G@T,&SR*;R+GAZI,3)$WCPK\[9[_VJ^YKC7^$`$5.P4>\(2]J,3B
M&DB[F^\1'&21P5YAWP3A<A3XDK^H(TK\$^%?,IW&?Q!SI$^(>!W622Y1_:9;
M`75J\KJ<G-=)*KU4;YR)3$*+W]0=X)3IX#QTR:'OOBOQS?4QY7JN(S!N;!(3
M>^16D5'`P+B4/4)R(,?2&MPV9+C*3&1`7)G<TO*53K9,"'H^$UMDFA8^^VN]
ML":"=H:5(NFJ,9]HNVE`_J)PQ+2_@F:E!@2,WGJ)]^B)3=(9(`"[RU<,[+/8
MG`!Q4U>4_5-MHS3*/A3=50:.6&D9HN#J,QCE55\*3)W(_[W5/=>K$N+!\+T`
MC2>CO(?]LY-6.6YEBO6?4N-;%';`QLQ,?]']D0&B?,`0FJ]@7#\;II>O,X(`
MTC+S(3Q@)IT>MISX7C[WIIAC+(&.AQ#M'PN`5'?:?1#O'IT2,#6B=EPO`[(:
M7WQ2:?X/7A@=4R@.+2L<:?RIC%48B"G<GR>!?G1[=\<PWP+%)Q43*SO_/-4+
MU!/(A'_K`7X&?N0-+.8X=!I-_/K(A`0M[LC;_A-:9(%HFPE3![H!!2LS(B0F
M35&'C^?%N$+A+7R^0M^#,X'7J;(!>!3INHT=5J<S*X31M,X(=L38RQ;3F+[`
MJD4&X6"X[,*ZEUE-J=L/IO`,E=U2*E5`%H=CQMA*+TS)L921(#<6_^,<^R:\
MB4,&J.<=+W=)S],SZP#H@Y5115CB2+405,&(7;CQ8#PUITGF<)?E+ZE8FJY3
M@$"`[`FK%<_Z]X2TS4EP7UU.C4<=.?NQ3"#W**Z]:)?*H[F]SG3*Y$@;U7FV
M7L`!=M%B%1YN"@\S>B^NURX<725.`,V)LQD\M3K<S/>N(IK;OM48L%KLWF,)
MP5NP]T;(*3.S+77SZ=*``8L2OX/=A[_/'-:?A1%L=-`KG.N]$*&&`=01'/`5
M,UN[+DTH?J&R>TB_GI](=E8I]XE=.!\__[W%3*$QSYY_(2*42&[!TSNDG'5I
M>*4S`G3O/<X@1),?=UE&`<FLDPU*A446A!OJ4Q*(/1B*T^-@T9$AG$L:V5F/
M.XJY29?.L5S9(=J-:<5A_C,;@`D>=)'>N=07""H0QRHK-?!<AS&]$9^HCTDK
MYSXU_42E^HQ)M=E[T[5CB_L;)N>TH*R&DHPBA07W\.JUPLS=0]Q:+4X+-HK*
M+O@ZS2%52I-27D+MZ]4Z3!/[7AI?O`F*$\S%&(#0O(K+SQK_VY2E^M0/)GFZ
MX)M&YM5Q`_"#/H')BS\5&C4!^O-'@6::BF=JSRIL=0[5M9>731JP8=H3XIK.
M'+D@ONE,AOJ9,],HOY)#VG_26EG<M4QG;$-TFJMNQ#,<S7>G)W\+3$.+JHU(
MWPH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+W!L:6(O;&]C86QE
M<P``````````````````````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#$W,C(W`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M861M:6XO<&QI8B]L;V-A;&5S+V5N+553````````````````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,2`P
M,C`Q-38`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]A9&UI;B]P;&EB+VQO8V%L97,O96XM55,O;65S
M<V%G97-?96XM55,N<&AP````````````````````````````````````````
M`````````````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`Q-#0S
M,C<R(#$P-3$U-#,T,3,R(#`R,S8P,@`@,```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````\/W!H<`IG;&]B86P@)%!23T1?3D%-12P@
M)&QM<V=?87)R.PIG;&]B86P@)&1E9E]D871E7V9O<FUA="P@)&1E9E]T:6UE
M7V9O<FUA="P@)&1E9E]D871E=&EM95]F;W)M870["@HO*BH*("H@1F]R(&UO
M<F4@:6YF;R!A8F]U="!T:6UE(&%N9"!D871E(&9O<FUA="!S964Z"B`J(&AT
M='`Z+R]W=W<N<&AP+FYE="]M86YU86PO96XO9G5N8W1I;VXN9&%T92YP:'`*
M("HO"B1D969?9&%T95]F;W)M870)/2`G32!J+"!9)SL*)&1E9E]T:6UE7V9O
M<FUA=`D]("=H.FDZ<R!!)SL*)&1E9E]D871E=&EM95]F;W)M870]("=-(&HL
M(%D@:#II($$G.PH*)&QM<V=?87)R(#T@87)R87D@*`H*("`@("`@("`O+R`J
M*BH@5&AE('-T<FEN9W,@8F5L;W<@:&%V92!B965N(&=E;F5R871E9"!A=71O
M;6%T:6-A;&QY(&9R;VT@0$!#05!424].(&1I<F5C=&EV97,N"@H@("`@("`@
M("=U:5]?861M:6XM:6YF;U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET($-0(&%D
M;6EN:7-T<F%T;W(@<&5R<V]N86P@:6YF;W)M871I;VXN)RP*("`@("`@("`G
M=6E?7V%D;6EN+6EN9F]?7V1O;F4G(#T^("=!9&UI;FES=')A=&]R('!E<G-O
M;F%L(&EN9F]R;6%T:6]N(&AA<R!B965N('5P9&%T960N)RP*("`@("`@("`G
M=6E?7V%D;6EN+6EN9F]?7W-H;W)T+71I=&QE)R`]/B`G061M:6X@:6YF;R<L
M"B`@("`@("`@)W5I7U]A9&UI;BUI;F9O7U]T:71L92<@/3X@)T-H86YG92!P
M97)S;VYA;"!I;F9O)RP*"B`@("`@("`@)W5I7U]A9&UI;BUP87-S=V]R9%]?
M9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@4&QE<VL@061M:6YI<W1R871O<B!P
M87-S=V]R9"XG+`H@("`@("`@("=U:5]?861M:6XM<&%S<W=O<F1?7V1O;F4G
M(#T^("=0;&5S:R!!9&UI;FES=')A=&]R('!A<W-W;W)D(&AA<R!B965N(&-H
M86YG960N)RP*("`@("`@("`G=6E?7V%D;6EN+7!A<W-W;W)D7U]S:&]R="UT
M:71L92<@/3X@)U!A<W-W;W)D)RP*("`@("`@("`G=6E?7V%D;6EN+7!A<W-W
M;W)D7U]T:71L92<@/3X@)T-H86YG92!P87-S=V]R9"<L"@H@("`@("`@("=U
M:5]?8VQI96YT7U]D97-C<FEP=&EO;B<@/3X@)T-L:65N="`E,5PG<R!A8V-O
M=6YT(&%N9"!D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE;G1?7V1I<V%B
M;&5D+7=A<FYI;F<G(#T^("=#;&EE;G0@)3$@:7,@9&ES86)L960N)RP*("`@
M("`@("`G=6E?7V-L:65N=%]?;F]N92UA=F%I;&%B;&4G(#T^("=4:&5R92!A
M<F4@;F\@8VQI96YT(&%C8V]U;G1S(&-O;F9I9W5R960N)RP*("`@("`@("`G
M=6E?7V-L:65N=%]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G1?7W1I=&QE)R`]/B`G0VQI96YT("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N=%]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@;7D@9&]M
M86EN<RXG+`H@("`@("`@("=U:5]?8VQI96YT7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G37D@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G1?<V5L9E]?
M=&ET;&4G(#T^("=->2!D;VUA:6YS)RP*("`@("`@("`G=6E?7V-L:65N=%]U
M;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=#;&EE;G1S)RP*"B`@("`@("`@
M)W5I7U]C;&EE;G0O8F%C:W5P7U]D97-C<FEP=&EO;B<@/3X@)T)A8VL@=7`O
M4F5S=&]R92!C;&EE;G0@<&5R<V]N86P@:6YF;R!A;F0@86-C;W5N="!S971T
M:6YG<R!A;F0O;W(@8VQI96YT(&1O;6%I;G,L('-C:&5D=6QE(&)A8VMU<',@
M=FEA(%!L97-K($)A8VMU<"!-86YA9V5R+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O8F%C:W5P7U]D;VYE)R`]/B`G)RP*("`@("`@("`G=6E?7V-L:65N="]B
M86-K=7!?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@("`G=6E?
M7V-L:65N="]B86-K=7!?7W1I=&QE)R`]/B`G0VQI96YT("4Q(&)A8VMU<"<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W-E;&9?7V1E<V-R:7!T:6]N
M)R`]/B`G0F%C:R!U<"]297-T;W)E('EO=7(@9&]M86EN<R!A;F0O;W(@86-C
M;W5N="!S971T:6YG<RP@<V-H961U;&4@8F%C:W5P<R!V:6$@4&QE<VL@0F%C
M:W5P($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?<V5L
M9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@("`G=6E?7V-L
M:65N="]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("="86-K=7`@36%N86=E<B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O8F%C:W5P7W5N:VYO=VY?7V1E<V-R:7!T
M:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E(&-L:65N="!P97)S;VYA;"!I;F9O
M(&%N9"!A8V-O=6YT('-E='1I;F=S(&%N9"]O<B!C;&EE;G0@9&]M86EN<RP@
M<V-H961U;&4@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA;F%G97(N)RP*
M("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W;E]?<VAO<G0M=&ET
M;&4G(#T^("="86-K=7`G+`H@("`@("`@("=U:5]?8VQI96YT+V)A8VMU<%]U
M;FMN;W=N7U]T:71L92<@/3X@)T-L:65N="!"86-K=7`G+`H@("`@("`@("=U
M:5]?8VQI96YT+V)A8VMU<%]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#
M;&EE;G0@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK
M;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@82!C;&EE;G0@
M=VAO<V4@86-C;W5N="!A;F0@9&]M86EN('EO=2!W86YT('1O(&)A8VL@=7`N
M)RP*("`@("`@("`G=6E?7V-L:65N="]B86-K=7!?=6YK;F]W;E]?=VEZ87)D
M7U\R)R`]/B`G5&\@8F%C:R!U<"!T:&4@86-C;W5N="!S971T:6YG<R!A;F0O
M;W(@9&]M86EN<RP@8VQI8VL@0F%C:W5P($YO=RX@5&\@<F5S=&]R92!T:&4@
M97AI<W1I;F<@8F%C:W5P(&9I;&4L(&-L:6-K(&ET<R!N86UE+B!4;R!S8VAE
M9'5L92!B86-K=7!S+"!C;&EC:R!38VAE9'5L960@0F%C:W5P+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]D97-C<FEP=&EO;B<@
M/3X@)TQI<W0@;V8@8W5S=&]M(&)U='1O;G,@9F]R(&-L:65N="`E,2XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7U]S:&]R="UT:71L
M92<@/3X@)T-U<W1O;2!B=71T;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]C
M=7-T;VTM8G5T=&]N<U]?=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R!O9B!C
M;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS
M7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!M>2!C=7-T;VT@8G5T
M=&]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W-E
M;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O;G,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS7W-E;&9?7W1I=&QE)R`]
M/B`G37D@8W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V-U
M<W1O;2UB=71T;VYS7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O
M9B!A(&-L:65N="!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V-U<W1O;2UB=71T;VYS7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M0W5S=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB
M=71T;VYS7W5N:VYO=VY?7W1I=&QE)R`]/B`G0VQI96YT(&-U<W1O;2!B=71T
M;VYS)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S
M=&]M+6)U='1O;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA
M=F4@86YY(&-L:65N="UL979E;"!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VY?7VYO
M;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@
M86YY(&-U<W1O;2!B=71T;VYS+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V-U
M<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]D97-C<FEP=&EO
M;B<@/3X@)U)E;6]V92!C;&EE;G0M;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB
M=71T;VXO9&5L971E7U]D;VYE)R`]/B`G0VQI96YT+6QE=F5L(&-U<W1O;2!B
M=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7U]S:&]R
M="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I=&QE)R`]/B`G
M4F5M;W9E(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&$@8VQI96YT+6QE=F5L(&-U<W1O
M;2!B=71T;VXN)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N
M<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@
M/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=2
M96UO=F4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D+71I=&QE)R`]/B`G0W5S=&]M($)U='1O;B!296UO=F%L)RP*("`@("`@
M("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M(&-L:65N="!W:&]S92!C=7-T;VT@8G5T=&]N('EO=2!W86YT('1O(')E;6]V
M92!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U
M<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I
M>F%R9%]?,U]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M(&)U='1O;B!Y
M;W4@=V%N="!T;R!R96UO=F4@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=#;VYF:7)M(')E;6]V:6YG
M('1H92!C=7-T;VT@8G5T=&]N(&)Y('-E;&5C=&EN9R!T:&4@8VAE8VL@8F]X
M(&]N('1H:7,@<V-R965N(&%N9"!C;&EC:R!&:6YI<V@N)RP*"B`@("`@("`@
M)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P
M97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O9B!C
M;&EE;G0M;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE
M<U]?9&]N92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@<')O<&5R=&EE<R!H879E
M(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G
M(#T^("=0<F5F97)E;F-E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M
M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7U]T:71L92<@/3X@
M)TUO9&EF>2!C;&EE;G0@8W5S=&]M(&)U='1O;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W(&-L:65N="UL
M979E;"!C=7-T;VT@8G5T=&]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&]N
M92<@/3X@)T-U<W1O;2!B=71T;VX@)3$@:&%S(&)E96X@8W)E871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T
M;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G0W)E871E)RP*
M("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T
M=&]N+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!C;&EE;G0@
M8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U
M='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I
M=&QE)R`]/B`G0W5S=&]M($)U='1O;B!#<F5A=&EO;B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7VYE=U]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@82!C;&EE
M;G0@9F]R('=H;VT@>6]U('=A;GD@=&\@8W)E871E(&$@8W5S=&]M(&)U='1O
M;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U
M<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7W=I
M>F%R9%]?,U]N97<G(#T^("=#;&EC:R!&:6YI<V@@=&\@8W)E871E(&-U<W1O
M;2!B=71T;VX@=VET:"!T:&4@9&5F:6YE9"!P<F]P97)T:65S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P
M<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G161I="!P<F]P
M97)T:65S(&]F(&$@8VQI96YT+6QE=F5L(&-U<W1O;2!B=71T;VXN)RP*("`@
M("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=0<F]P97)T
M:65S)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=-;V1I
M9GD@8VQI96YT(&-U<W1O;2!B=71T;VXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=-;V1I9GEI;F<@0VQI96YT+6QE=F5L
M($-U<W1O;2!"=71T;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA
M<F1?7S-?=6YK;F]W;B<@/3X@)U-E;&5C="!W:&EC:"!C=7-T;VT@8G5T=&]N
M('EO=2!W86YT('1O(&UO9&EF>2!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO
M<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7:&5N(&1O;F4@
M=VET:"!E9&ET:6YG('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O;2!B=71T;VXL
M(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]C=7-T;VTM8G5T=&]N<R]C
M=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;VYO=VY?7W=I>F%R9%]?,5]U
M;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT('=H;W-E(&-U<W1O;2!B=71T
M;VX@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.97AT(#X^+B<L"@H@
M("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-C=7-T;VTM8G5T=&]N<U]?
M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D(V1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@9F%V
M;W)I=&4@9&]M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D
M(V1O;6%I;G-?7W1I=&QE)R`]/B`G1&]M86EN<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D(V9A=F]R:71E<R]T86)S7U]D97-C<FEP=&EO;B<@
M/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!T86)S(&EN($9A=F]R:71E<SHG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-F879O<FET97-?7W1I=&QE
M)R`]/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A
M<F0C:6YF;R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L
M;&]W:6YG(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@
M=&AE(&9O;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1A<VAB;V%R9"-I;F9O7U]T:71L92<@/3X@)TEN9F]R;6%T:6]N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C;6%I;&YA;65S7U]D97-C
M<FEP=&EO;B<@/3X@)TYO(&9A=F]R:71E(&UA:6QN86UE<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(VUA:6QN86UE<U]?=&ET;&4G(#T^("=-
M86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"-Q=6EC
M:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*("`@("`@("`G
M=6E?7V-L:65N="]D87-H8F]A<F0C<F5C96YT7U]D97-C<FEP=&EO;B<@/3X@
M)TYO(')E8V5N="!P86=E<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D(W)E8V5N=%]?=&ET;&4G(#T^("=296-E;G0G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T:6]N)R`]/B`G
M3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0C
M<VAO<G1C=71S7U]T:71L92<@/3X@)U-H;W)T8W5T<R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7V1E<V-R:7!T:6]N)R`]
M/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N.B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D(W-T871I<W1I8W-?7W1I=&QE)R`]/B`G
M4W1A=&ES=&EC<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D(W1O
M;VQS+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H92!F;VQL;W=I
M;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D(W1O;VQS7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE
M(&9O;&QO=VEN9R!B=71T;VYS.B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S
M:&)O87)D(W1O;VQS7U]T:71L92<@/3X@)U1O;VQS)RP*("`@("`@("`G=6E?
M7V-L:65N="]D87-H8F]A<F1?7V1E<V-R:7!T:6]N)R`]/B`G1&5S:W1O<"!O
M9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?
M7W-H;W)T+71I=&QE)R`]/B`G)3%<)W,@1&5S:W1O<"<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&%S:&)O87)D7U]T:71L92<@/3X@)T1E<VMT;W`@;V8@8VQI
M96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?<V5L9E]?
M9&5S8W)I<'1I;VXG(#T^("=->2!$97-K=&]P+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&%S:&)O87)D7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G1&5S:W1O
M<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D7W-E;&9?7W1I=&QE
M)R`]/B`G37D@1&5S:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VQI96YT($1E<VMT;W`N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F1?=6YK;F]W;E]?<VAO
M<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D
M87-H8F]A<F1?=6YK;F]W;E]?=&ET;&4G(#T^("=#;&EE;G0@1&5S:W1O<"<L
M"@H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T;VUI>F5?7V1E
M<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`@;V8@8VQI96YT("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+V-U<W1O;6EZ95]?
M9&]N92<@/3X@)U-E='1I;F<@;V8@1&5S:W1O<"!F;W(@8VQI96YT("4Q(&AA
M=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D+V-U<W1O;6EZ95]?<VAO<G0M=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S
M:W1O<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+V-U<W1O;6EZ
M95]?=&ET;&4G(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@8VQI96YT("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O8W5S=&]M:7IE7W-E
M;&9?7V1E<V-R:7!T:6]N)R`]/B`G0W5S=&]M:7IE('EO=7(@1&5S:W1O<"!C
M;VYT96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+V-U<W1O
M;6EZ95]S96QF7U]D;VYE)R`]/B`G66]U<B!$97-K=&]P('-E='1I;F=S(&AA
M=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O
M87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ
M92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O8W5S
M=&]M:7IE7W-E;&9?7W1I=&QE)R`]/B`G0W5S=&]M:7IE(&UY($1E<VMT;W`G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T;VUI>F5?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@
M82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D87-H8F]A<F0O8W5S
M=&]M:7IE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E
M<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T;VUI
M>F5?=6YK;F]W;E]?=&ET;&4G(#T^("=#=7-T;VUI>F4@8VQI96YT($1E<VMT
M;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T;VUI>F5?
M=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M:7II;F<@0VQI96YT
M($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT+V1A<VAB;V%R9"]C=7-T
M;VUI>F5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@
M82!C;&EE;G0@=VAO<V4@1&5S:W1O<"!Y;W4@=V%N="!T;R!C=7-T;VUI>F4@
M86YD(&-L:6-K($YE>'0@/CXN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S
M:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G
M161I="!P<F]P97)T:65S(&]F('-H;W)T8W5T("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7V1O;F4G
M(#T^("=0<F]P97)T:65S(&]F('-H;W)T8W5T("4Q(&AA=F4@8F5E;B!U<&1A
M=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T
M+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I="<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W1I
M=&QE)R`]/B`G161I="!S:&]R=&-U="`E,2<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?;F5W7U]D97-C<FEP
M=&EO;B<@/3X@)T-R96%T92!N97<@<VAO<G1C=70N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7V1O
M;F4G(#T^("=3:&]R=&-U="`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?
M;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!S:&]R=&-U="<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?
M;F5W7U]T:71L92<@/3X@)T-R96%T92!S:&]R=&-U="<L"@H@("`@("`@("=U
M:5]?8VQI96YT+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^("=296UO=F4@86-C
M;W5N="!O9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D96QE
M=&5?7V1O;F4G(#T^("=#;&EE;G0@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=2
M96UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]?=&ET;&4G(#T^
M("=296UO=F4@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D96QE
M=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=296UO=F4@82!C;&EE;G0@
M86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&5L971E7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&-L:65N="<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&5L971E7W5N:VYO=VY?7W=I>F%R9"UT
M:71L92<@/3X@)T-L:65N="!296UO=F%L)RP*("`@("`@("`G=6E?7V-L:65N
M="]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE
M8W0@=VAI8V@@8VQI96YT('EO=2!W86YT('1O(')E;6]V92!A;F0@8VQI8VL@
M3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1E;&5T95]U;FMN;W=N
M7U]W:7IA<F1?7S(G(#T^("=#;VYF:7)M(&-L:65N="!R96UO=F%L(&)Y('-E
M;&5C=&EN9R!T:&4@8VAE8VL@8F]X(&%N9"!C;&EC:R!&:6YI<V@@=&\@8V]M
M<&QE=&4@=&AE(')E;6]C86P@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6Y?7V1E<V-R:7!T:6]N)R`]/B`G36%N
M86=E(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?
M9&ES86)L960M=V%R;FEN9R<@/3X@)T1O;6%I;B`E,2!I<R!D:7-A8FQE9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]?;F]N92UA=F%I;&%B;&4G
M(#T^("=9;W4@9&]N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6Y?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI
M96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1O;6%I;G,N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6Y?7W-H;W)T+71I=&QE)R`]/B`G)3$G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;E]?=&ET;&4G(#T^("=$;VUA:6X@)3$G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;E]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)TUA;F%G92!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;E]S96QF7U]D:7-A8FQE9"UW87)N:6YG)R`]/B`G66]U<B!D
M;VUA:6X@:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6Y?<V5L9E]?<75I8VLM<V5A<F-H)R`]/B`G37D@9&]M86EN<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G
M37D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6Y?<V5L9E]?
M=&ET;&4G(#T^("=->2!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;E]U;FMN;W=N7U]Q=6EC:RUS96%R8V@G(#T^("=$;VUA:6YS)RP*"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V)A8VMU<%]?9&5S8W)I<'1I;VXG
M(#T^("="86-K('5P+U)E<W1O<F4@=&AE(&1O;6%I;BP@<V-H961U;&4@=&AE
M(&1O;6%I;B!B86-K=7!S('9I82!0;&5S:R!"86-K=7`@36%N86=E<BXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?7V1O;F4G(#T^("<G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?7W-H;W)T+71I
M=&QE)R`]/B`G0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M8F%C:W5P7U]T:71L92<@/3X@)T1O;6%I;B`E,2!B86-K=7`G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("="86-K('5P+U)E<W1O<F4@>6]U<B!D;VUA:6XL('-C:&5D=6QE('1H
M92!D;VUA:6X@8F%C:W5P<R!V:6$@4&QE<VL@0F%C:W5P($UA;F%G97(N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C:W5P7W-E;&9?7V1O;F4G
M(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?<V5L
M9E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]B86-K=7!?<V5L9E]?=&ET;&4G(#T^("=$;VUA:6X@8F%C
M:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C:W5P7W5N:VYO
M=VY?7V1E<V-R:7!T:6]N)R`]/B`G0F%C:R!U<"]297-T;W)E(&$@9&]M86EN
M+"!S8VAE9'5L92!A(&1O;6%I;B!B86-K=7!S('9I82!0;&5S:R!"86-K=7`@
M36%N86=E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("="86-K=7`G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=&ET;&4G(#T^("=$
M;VUA:6X@0F%C:W5P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8F%C
M:W5P7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T1O;6%I;B!"86-K=7`G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?
M=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@>6]U('=A
M;G0@=&\@8F%C:R!U<"!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]B86-K=7!?=6YK;F]W;E]?=VEZ87)D7U\S)R`]
M/B`G5&\@8F%C:R!U<"!T:&4@9&]M86EN+"!C;&EC:R!"86-K=7`@3F]W+B!4
M;R!R97-T;W)E('1H92!E>&ES=&EN9R!B86-K=7`@9FEL92P@8VQI8VL@:71S
M(&YA;64N(%1O('-C:&5D=6QE(&)A8VMU<',L(&-L:6-K(%-C:&5D=6QE9"!"
M86-K=7`N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@9&]M86EN("4Q(&-U
M<W1O;2!B=71T;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U
M<W1O;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?
M7W1I=&QE)R`]/B`G0W5S=&]M(&)U='1O;G,@9F]R(&1O;6%I;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS7W-E;&9?
M7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!Y;W5R(&-U<W1O;2!B=71T;VYS
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS
M7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@8W5S=&]M(&)U='1O;G,G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<U]S96QF
M7U]T:71L92<@/3X@)TUY(&-U<W1O;2!B=71T;VYS)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?=6YK;F]W;E]?9&5S8W)I
M<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!C=7-T;VT@8G5T=&]N<RXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<U]U;FMN
M;W=N7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G-?=6YK;F]W;E]?
M=&ET;&4G(#T^("=$;VUA:6X@8W5S=&]M(&)U='1O;G,G+`H*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;E]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T(&AA=F4@86YY(&1O
M;6%I;BUL979E;"!C=7-T;VT@8G5T=&]N<RXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N7U]N;VYE
M+6%V86EL86)L95]?,2<@/3X@)T-L:65N="`E,2!D;V5S;EPG="!H879E(&%N
M>2!D;VUA:6XM;&5V96P@8W5S=&]M(&)U='1O;G,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;E]?
M;F]N92UA=F%I;&%B;&5?7S(G(#T^("=4:&5R92!A<F4@;F\@8W5S=&]M(&)U
M='1O;G,@9F]R(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7V1E
M<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&1O;6%I;B!C=7-T;VT@8G5T=&]N("4Q
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G1&]M86EN(&-U<W1O
M;2!B=71T;VX@)3$@:&%S(&)E96X@<F5M;W9E9"XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E
M;&5T95]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5M
M;W9E(&$@9&]M86EN+6QE=F5L(&-U<W1O;2!B=71T;VXN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T
M;VTM8G5T=&]N+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!D
M;VUA:6X@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO
M=VY?7W=I>F%R9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@4F5M;W9A;"<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U
M<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N
M)R`]/B`G4V5L96-T(&$@8VQI96YT(&9R;VT@=VAO<V4@9&]M86EN('EO=2!W
M86YT('1O(')E;6]V92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@
M/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9G)O;2!W:&EC:"!Y;W4@=V%N
M="!T;R!R96UO=F4@82!C=7-T;VT@8G5T=&]N(&%N9"!C;&EC:R!.97AT(#X^
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN
M;W=N)R`]/B`G4V5L96-T(&$@8W5S=&]M(&)U='1O;B!Y;W4@=V%N="!T;R!R
M96UO=F4@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?
M=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO=FEN9R!T:&4@
M8W5S=&]M(&)U='1O;B!B>2!S96QE8W1I;F<@=&AE(&-H96-K(&)O>"!A;F0@
M8VQI8VL@1FEN:7-H('1O(&-O;7!L971E;'D@<F5M;W9E('1H92!B=71T;VX@
M86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S
M7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O9B!D;VUA:6XM
M;&5V96P@8W5S=&]M(&)U='1O;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q('!R;W!E<G1I97,@:&%V
M92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7U]S:&]R
M="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I
M97-?7W1I=&QE)R`]/B`G36]D:69Y(&1O;6%I;B!C=7-T;VT@8G5T=&]N("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O
M8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^
M("=#<F5A=&4@;F5W(&1O;6%I;BUL979E;"!C=7-T;VT@8G5T=&]N+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U<W1O
M;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=#=7-T;VT@8G5T
M=&]N("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!D;VUA:6X@8W5S
M=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O
M;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R
M9"UT:71L92<@/3X@)T-U<W1O;2!"=71T;VX@0W)E871I;VXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T
M=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E
M;&5C="!A(&-L:65N="!F;W(@=VAO<V4@9&]M86EN('EO=2!W86YT('1O(&-R
M96%T92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^
M("=396QE8W0@82!D;VUA:6X@9F]R('=H:6-H('EO=2!W86YT('1O(&-R96%T
M92!A(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@;6]D:69Y(&$@
M8W5S=&]M(&)U='1O;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?;F5W)R`]/B`G0VQI8VL@1FEN
M:7-H('1O(&-R96%T92!T:&4@8W5S=&]M(&)U='1O;B!A;F0@97AI="!T:&4@
M=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB
M=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C
M<FEP=&EO;B<@/3X@)T5D:70@9&]M86EN+6QE=F5L(&-U<W1O;2!B=71T;VX@
M<')O<&5R=&EE<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=0<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P
M97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36]D:69Y(&1O;6%I;B!C=7-T
M;VT@8G5T=&]N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO8W5S=&]M
M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S7W5N:VYO=VY?7W=I
M>F%R9"UT:71L92<@/3X@)TUO9&EF>6EN9R!$;VUA:6X@0W5S=&]M($)U='1O
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?
M=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-U<W1O;2!B=71T;VX@=VAI8V@@<V5T
M=&EN9W,@>6]U('=A;G0@=&\@;6]D:69Y(&%N9"!C;&EC:R!.97AT(#X^+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V-U<W1O;2UB=71T;VYS+V-U
M<W1O;2UB=71T;VXO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S4G(#T^
M("=7:&5N(&1O;F4@=VET:"!C:&%N9VEN9R!P<F]P97)T:65S(&]F('1H92!C
M=7-T;VT@8G5T=&]N+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A
M;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D87-H8F]A<F0C8W5S=&]M+6)U='1O;G-?7W1I=&QE)R`]/B`G0W5S
M=&]M(&)U='1O;G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H
M8F]A<F0C9F%V;W)I=&5S+W1A8G-?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T
M:&4@9F]L;&]W:6YG('1A8G,@:6X@1F%V;W)I=&5S.B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-F879O<FET97-?7W1I=&QE)R`]
M/B`G1F%V;W)I=&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S
M:&)O87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE
M(&9O;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D(VEN9F]?7V1E<V-R:7!T:6]N
M)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&EN9F]R;6%T:6]N.B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-I;F9O7U]T:71L92<@
M/3X@)TEN9F]R;6%T:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M9&%S:&)O87)D(VUA:6QN86UE<U]?9&5S8W)I<'1I;VXG(#T^("=.;R!F879O
M<FET92!M86EL;F%M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M87-H8F]A<F0C;6%I;&YA;65S7U]T:71L92<@/3X@)TUA:6QN86UE<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-Q=6EC:RUS96%R
M8VA?7W1I=&QE)R`]/B`G475I8VL@<V5A<F-H)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D(W)E8V5N=%]?9&5S8W)I<'1I;VXG(#T^
M("=.;R!R96-E;G0@<&%G97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]D87-H8F]A<F0C<F5C96YT7U]T:71L92<@/3X@)U)E8V5N="<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E
M<V-R:7!T:6]N)R`]/B`G3F\@<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%S:&)O87)D(W-H;W)T8W5T<U]?=&ET;&4G(#T^("=3
M:&]R=&-U=',G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A
M<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H92!F;VQL
M;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%S:&)O87)D(W-T871I<W1I8W-?7W1I=&QE)R`]/B`G4W1A=&ES=&EC
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"-T;V]L
M<R]F;V]T97)?7V1E<V-R:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG
M(&)U='1O;G,@:6X@=&AE(&9O;W1E<CHG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F0C=&]O;'-?7V1E<V-R:7!T:6]N)R`]/B`G4VAO
M=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,Z)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%S:&)O87)D(W1O;VQS7U]T:71L92<@/3X@)U1O;VQS)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7U]D97-C<FEP
M=&EO;B<@/3X@)T1E<VMT;W`@;V8@9&]M86EN(&%D;6EN:7-T<F%T;W(@)3$N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7U]S:&]R
M="UT:71L92<@/3X@)R4Q7"=S($1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]D87-H8F]A<F1?7W1I=&QE)R`]/B`G1&5S:W1O<"!O9B!D
M;VUA:6X@861M:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M87-H8F]A<F1?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=->2!$97-K=&]P+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9%]S96QF7U]S
M:&]R="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F1?<V5L9E]?=&ET;&4G(#T^("=->2!$97-K=&]P
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7W5N:VYO
M=VY?7V1E<V-R:7!T:6]N)R`]/B`G1&]M86EN(&%D;6EN:7-T<F%T;W(@9&5S
M:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F1?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=$97-K=&]P)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D7W5N:VYO=VY?7W1I=&QE)R`]
M/B`G1&]M86EN(&%D;6EN(&1E<VMT;W`G+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^
M("=#=7-T;VUI>F4@1&5S:W1O<"!F;W(@1&]M86EN($%D;6EN:7-T<F%T;W(@
M)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U
M<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@1&]M86EN($%D
M;6EN:7-T<F%T;W(@1&5S:W1O<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D87-H8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G1&5S:W1O<"!O
M9B!$;VUA:6X@061M:6YI<W1R871O<B`E,2!H87,@8F5E;B!U<&1A=&5D+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"]C=7-T;VUI
M>F5?7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S=&]M:7IE7U]S
M:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]?=&ET;&4G
M(#T^("=#=7-T;VUI>F4@1&5S:W1O<"!O9B!$;VUA:6X@061M:6X@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S=&]M:7IE
M7U]T:71L92<@/3X@)T-U<W1O;6EZ92!$;VUA:6X@061M:6X@1&5S:W1O<"<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"]C=7-T;VUI
M>F5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI>F4@;7D@1&5S:W1O
M<"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O8W5S
M=&]M:7IE7W-E;&9?7V1O;F4G(#T^("=9;W5R($1E<VMT;W`@<V5T=&EN9W,@
M:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]S:&]R="UT:71L92<@/3X@
M)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L92<@/3X@)T-U<W1O
M;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@
M/3X@)T5D:70@<')O<&5R=&EE<R!O9B!S:&]R=&-U="`E,2XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R
M=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA<R!B965N('5P9&%T960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%S:&)O87)D+W-H;W)T
M8W5T+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G161I="<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P
M97)T:65S7U]T:71L92<@/3X@)T5D:70@<VAO<G1C=70@)3$G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R
M=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE=R!S:&]R=&-U
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D87-H8F]A<F0O<VAO
M<G1C=70O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:&]R=&-U="`E,2!H
M87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET
M;&4G(#T^("=#<F5A=&4@<VAO<G1C=70G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R=&EE<U]N97=?7W1I
M=&QE)R`]/B`G0W)E871E('-H;W)T8W5T)RP*"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+V1A=&%B87-E<U]?9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F
M(&1O;6%I;B`E,2!D871A8F%S97,N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO9&%T86)A<V5S7U]S:&]R="UT:71L92<@/3X@)T1A=&%B87-E<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<U]?=&ET;&4G
M(#T^("=$871A8F%S97,@;V8@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%T86)A<V5S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G
M3&ES="!O9B!Y;W5R(&1A=&%B87-E<RXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D871A8F%S97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=$871A
M8F%S97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97-?
M<V5L9E]?=&ET;&4G(#T^("=->2!D871A8F%S97,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]D871A8F%S97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=,:7-T(&]F(&1O;6%I;B!D871A8F%S97,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO9&%T86)A<V5S7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G1&%T86)A<V5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M9&%T86)A<V5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&]M86EN(&1A=&%B87-E
M<R<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T
M86)A<V5?7V1E<V-R:7!T:6]N)R`]/B`G1&%T86)A<V4@)3$@=7-E<G,@86YD
M(%=E8D%D;6EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S95]?;F]N92UA=F%I;&%B;&4G(#T^("=9;W4@9&]N7"=T
M(&AA=F4@86YY(&1A=&%B87-E<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]D871A8F%S97,O9&%T86)A<V5?7VYO;F4M879A:6QA8FQE7U\Q)R`]
M/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY(&1A=&%B87-E<RXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V5?
M7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO(&1A=&%B87-E
M<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M9&%T86)A<V5S+V1A=&%B87-E7U]S:&]R="UT:71L92<@/3X@)R4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7U]T
M:71L92<@/3X@)T1A=&%B87-E("4Q('5S97)S)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E7W5N:VYO=VY?7V1E<V-R
M:7!T:6]N)R`]/B`G36%N86=E(&1A=&%B87-E('5S97)S(&%N9"!A8V-E<W,@
M5V5B061M:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A
M<V5S+V1A=&%B87-E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G1&%T86)A
M<V4@=7-E<G,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S
M97,O9&%T86)A<V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86YA9V4@9&%T86)A
M<V4@=7-E<G,G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A
M<V5S+V1A=&%B87-E+V1E;&5T95]?9&5S8W)I<'1I;VXG(#T^("=296UO=F4@
M9&%T86)A<V4@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T
M86)A<V5S+V1A=&%B87-E+V1E;&5T95]?9&]N92<@/3X@)T1A=&%B87-E("4Q
M(&AA<R!B965N(')E;6]V960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO9&%T86)A<V5S+V1A=&%B87-E+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^
M("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S
M97,O9&%T86)A<V4O9&5L971E7U]T:71L92<@/3X@)U)E;6]V92!D871A8F%S
M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D
M871A8F%S92]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=296UO
M=F4@82!D871A8F%S92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M871A8F%S97,O9&%T86)A<V4O9&5L971E7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T
M86)A<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E
M;6]V92!D871A8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE
M)R`]/B`G1&%T86)A<V4@4F5M;W9A;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9G)O;2!W:&EC
M:"!W86YT('1O(')E;6]V92!A(&1A=&%B87-E(&%N9"!C;&EC:R!.97AT(#X^
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A
M8F%S92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!D871A8F%S92!Y;W4@=V%N="!T;R!R96UO=F4@86YD(&-L:6-K
M($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A
M<V5S+V1A=&%B87-E+V1E;&5T95]U;FMN;W=N7U]W:7IA<F1?7S4G(#T^("=#
M;VYF:7)M(')E;6]V:6YG('1H92!D871A8F%S92!B>2!S96QE8W1I;F<@=&AE
M(&-H96-K(&)O>"!A;F0@8VQI8VL@1FEN:7-H('1O(&-O;7!L971E;'D@<F5M
M;W9E('1H92!D871A8F%S92!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O<')O
M<&5R=&EE<U]N97<M861H;V-?7W=I>F%R9%]?-%]N97<G(#T^("=4:&4@9&%T
M86)A<V4@=VEL;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C
M;&EC:R!.97AT(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A
M=&%B87-E<R]D871A8F%S92]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG
M(#T^("=#<F5A=&4@82!N97<@9&%T86)A<V4N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&%T86)A<V5S+V1A=&%B87-E+W!R;W!E<G1I97-?;F5W
M7U]D;VYE)R`]/B`G1&%T86)A<V4@)3$@:&%S(&)E96X@8W)E871E9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O
M<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G0W)E871E(&1A=&%B
M87-E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&%T86)A<V5S+V1A
M=&%B87-E+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!D871A
M8F%S92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D
M871A8F%S92]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]/B`G1&%T
M86)A<V4@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D
M871A8F%S97,O9&%T86)A<V4O<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,E]U
M;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&]N('=H:6-H('EO=2!W86YT
M('1O(&-R96%T92!A(&1A=&%B87-E(&%N9"!C;&EC:R!.97AT(#X^+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]P
M<F]P97)T:65S7VYE=U]?=VEZ87)D7U\T7VYE=R<@/3X@)T-L:6-K($9I;FES
M:"!T;R!C<F5A=&4@=&AE(&1A=&%B87-E(&%N9"!E>&ET('1H92!W:7IA<F0N
M)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A
M8F%S92]W96)A9&UI;E]?9&5S8W)I<'1I;VXG(#T^("=!8V-E<W,@5V5B061M
M:6X@9F]R(&UA;F%G:6YG(&1A=&%B87-E("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A8F%S92]W96)A9&UI;E]?9&]N
M92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E
M<R]D871A8F%S92]W96)A9&UI;E]?<VAO<G0M=&ET;&4G(#T^("=796)!9&UI
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A
M8F%S92]W96)A9&UI;E]?=&ET;&4G(#T^("=/<&5N(%=E8D%D;6EN(&9O<B!D
M871A8F%S92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B
M87-E<R]D871A8F%S92]W96)A9&UI;E]U;FMN;W=N7U]D97-C<FEP=&EO;B<@
M/3X@)T%C8V5S<R!796)!9&UI;B!F;W(@;6%N86=I;F<@82!D871A8F%S92XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A
M<V4O=V5B861M:6Y?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796)!9&UI
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1A=&%B87-E<R]D871A
M8F%S92]W96)A9&UI;E]U;FMN;W=N7U]T:71L92<@/3X@)T]P96X@5V5B061M
M:6X@9F]R(&1A=&%B87-E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?7W=I>F%R9"UT
M:71L92<@/3X@)U=E8D%D;6EN(%-T87)T=7`G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]D871A8F%S97,O9&%T86)A<V4O=V5B861M:6Y?=6YK;F]W
M;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9F]R
M('=H;W-E(&1A=&%B87-E('EO=2!W86YT('1O(&]P96X@5V5B061M:6X@86YD
M(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M9&%T86)A<V5S+V1A=&%B87-E+W=E8F%D;6EN7W5N:VYO=VY?7W=I>F%R9%]?
M-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&%T86)A<V4@=VAI8V@@>6]U('=A
M;G0@=&\@;6%N86=E('9I82!796)!9&UI;BXG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO9&5L971E7U]D97-C<FEP=&EO;B<@/3X@)U)E;6]V92!D
M;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E
M7U]D;VYE)R`]/B`G1&]M86EN("4Q(&AA<R!B965N(')E;6]V960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO9&5L971E7U]S:&]R="UT:71L92<@
M/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T
M95]?=&ET;&4G(#T^("=296UO=F4@9&]M86EN("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G4F5M;W9E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U;FMN;W=N7U]T
M:71L92<@/3X@)U)E;6]V92!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G1&]M
M86EN(%)E;6]V86PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]D96QE
M=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D
M;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E(&%N9"!C;&EC:R!.97AT(#X^+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+V1E;&5T95]U;FMN;W=N7U]W
M:7IA<F1?7S,G(#T^("=#;VYF:7)M(')E;6]V:6YG('1H92!D;VUA:6X@8GD@
M<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K($9I;FES:"!T;R!C
M;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG7U]N;VYE+6%V86EL
M86)L92<@/3X@)TAO<W1I;F<@:7,@;F]T(&-O;F9I9W5R960@;VX@>6]U<B!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9U]?
M;F]N92UA=F%I;&%B;&5?7S(G(#T^("=(;W-T:6YG(&ES(&YO="!C;VYF:6=U
M<F5D(&]N(&1O;6%I;B`E,2XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1E<V-R:7!T:6]N)R`]/B`G06-C
M97-S(&1O;6%I;B`E,2!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?7V1O;F4G(#T^("<G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N
M86=E<E]?<VAO<G0M=&ET;&4G(#T^("=&:6QE(&UA;F%G97(G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]?=&ET
M;&4G(#T^("=-86YA9V4@9FEL97,@;VX@9&]M86EN("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?<V5L9E]?
M9&5S8W)I<'1I;VXG(#T^("=/<F=A;FEZ92!Y;W5R('=E8G-I=&4@9FEL97,@
M86YD(&1I<F5C=&]R:65S('9I82!0;&5S:R!&:6QE($UA;F%G97(N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?
M<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O9FEL92UM86YA9V5R7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G
M1FEL92!M86YA9V5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]F:6QE+6UA;F%G97)?<V5L9E]?=&ET;&4G(#T^("=-86YA9V4@9FEL
M97,@;VX@;7D@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^
M("=/<F=A;FEZ92!A('=E8G-I=&4@9FEL97,@86YD(&1I<F5C=&]R:65S('9I
M82!0;&5S:R!&:6QE($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?<VAO<G0M=&ET
M;&4G(#T^("=&:6QE(&UA;F%G97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]T:71L92<@/3X@
M)TUA;F%G92!F:6QE<R!O;B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]W:7IA<F0M
M=&ET;&4G(#T^("=-86YA9VEN9R!&:6QE<R<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O9FEL92UM86YA9V5R7W5N:VYO=VY?7W=I>F%R
M9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN('=H:6-H(&9I;&5S
M(&%N9"!D:7)E8W1O<FEE<R!Y;W4@=V%N="!T;R!M86YA9V4@=VET:"!&:6QE
M($UA;F%G97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]F:6QE+6UA;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O
M;B!T:&4@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L(&AO<W1I;F<@
M86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE($UA;F%G97(N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA
M;F%G97)?=6YK;F]W;E]?=VEZ87)D7U\S+W!R;W!E<G1I97-?<V5L9BUP:&]S
M=&EN9R<@/3X@)TAO<W1I;F<@:7,@;F]T('EE="!C;VYF:6=U<F5D(&]N('EO
M=7(@9&]M86EN+B!0;&5A<V4@<V5T('5P('!H>7-I8V%L(&AO<W1I;F<@86YD
M(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!&:6QE($UA;F%G97(N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]F:6QE+6UA;F%G
M97)?=6YK;F]W;E]?=VEZ87)D7U\T)R`]/B`G5VAE;B!D;VYE('=I=&@@;6%N
M86=I;F<@9FEL97,@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN:7-H('1O(&5X
M:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+V9I;&4M;6%N86=E<E]U;FMN;W=N7U]W:7IA<F1?7S1?<V5L9B<@
M/3X@)U=H96X@9&]N92!W:71H(&UA;F%G:6YG(&9I;&5S(&]N('EO=7(@9&]M
M86EN+"!C;&EC:R!&:6YI<V@@=&\@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?7V1E
M<V-R:7!T:6]N)R`]/B`G4V5T('5P(&AO<W1I;F<@<V5R=FEC97,@9F]R(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4V5T('5P(&AO<W1I;F<G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I
M97-?7W1I=&QE)R`]/B`G4V5T('5P(&AO<W1I;F<@;VX@9&]M86EN("4Q)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S
M7V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&9O<G=A
M<F1I;F<@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]D;VYE)R`]/B`G
M1F]R=V%R9&EN9R!P<F]P97)T:65S(&]N(&1O;6%I;B`E,2!H879E(&)E96X@
M=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W!R;W!E<G1I97-?9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G(#T^("=#;VYF
M:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG7U]T:71L92<@/3X@)T-O
M;F9I9W5R92!F;W)W87)D:6YG(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]P:&]S=&EN9U]?
M9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@=FER='5A;"!H;W-T(&9O<B!D
M;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]P<F]P97)T:65S7W!H;W-T:6YG7U]D;VYE)R`]/B`G4&AY<VEC86P@:&]S
M=&EN9R!S971T:6YG<R!O;B!D;VUA:6X@)3$@:&%V92!B965N('5P9&%T960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T
M:65S7W!H;W-T:6YG7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!P:'ES
M:6-A;"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]P<F]P97)T:65S7W!H;W-T:6YG7U]T:71L92<@/3X@)T-O;F9I9W5R
M92!P:'ES:6-A;"!H;W-T:6YG(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+69O<G=A
M<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&9O<G=A<F1I;F<@
M;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?9&]N92<@/3X@
M)T9O<G=A<F1I;F<@;VX@>6]U<B!D;VUA:6X@:&%S(&)E96X@8V]N9FEG=7)E
M9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E
M<G1I97-?<V5L9BUF;W)W87)D:6YG7U]S:&]R="UT:71L92<@/3X@)T-O;F9I
M9W5R92!F;W)W87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]P<F]P97)T:65S7W-E;&8M9F]R=V%R9&EN9U]?=&ET;&4G(#T^
M("=#;VYF:6=U<F4@9F]R=V%R9&EN9R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG7U]D97-C
M<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!V:7)T=6%L(&AO<W0@9F]R('EO=7(@
M9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG7U]D;VYE)R`]/B`G4&AY<VEC86P@
M:&]S=&EN9R!S971T:6YG<R!O;B!Y;W5R(&1O;6%I;B!H879E(&)E96X@=7!D
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R
M;W!E<G1I97-?<V5L9BUP:&]S=&EN9U]?<VAO<G0M=&ET;&4G(#T^("=#;VYF
M:6=U<F4@<&AY<VEC86P@:&]S=&EN9R<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF+7!H;W-T:6YG7U]T:71L
M92<@/3X@)T-O;F9I9W5R92!P:'ES:6-A;"!H;W-T:6YG)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W-E;&9?7V1E
M<V-R:7!T:6]N)R`]/B`G0VQI8VL@=&\@<V5T('5P(&AO<W1I;F<@<V5R=FEC
M97,@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]S96QF7U]S:&]R="UT:71L92<@/3X@
M)U-E="!U<"!H;W-T:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G4V5T('5P(&AO
M<W1I;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R
M;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@
M:&]S=&EN9R!S97)V:6-E<R!F;W(@82!D;VUA:6XN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&AO<W1I;F<G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=&ET;&4G(#T^("=#;VYF:6=U<F4@:&]S=&EN9R!O;B!A(&1O;6%I;B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#;VYF:6=U<FEN9R!(;W-T:6YG
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T
M:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@
M9&]M86EN(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U<F4@:&]S=&EN
M9R!S97)V:6-E<R!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D7U\T)R`]/B`G4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@<V5R=FEC
M97,@>6]U('=A;G0@=&\@8V]N9FEG=7)E(&]N('1H92!D;VUA:6X@86YD(&-L
M:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]F;W)W87)D:6YG
M)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!O
M;B!T:&4@9&]M86EN+"!C;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-%]P:&]S=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG
M('!H>7-I8V%L(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN:7-H
M('1O(&%P<&QY('1H92!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET('1H92!W:7IA
M<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P
M97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF)R`]/B`G4V5L96-T('1H
M92!T>7!E(&]F(&AO<W1I;F<@<V5R=FEC97,@>6]U('=A;G0@=&\@8V]N9FEG
M=7)E(&]N('1H92!D;VUA:6X@86YD(&-L:6-K($YE>'0@/CXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-%]S96QF+69O<G=A<F1I;F<G(#T^("=7:&5N(&1O;F4@
M=VET:"!C;VYF:6=U<FEN9R!F;W)W87)D:6YG(&]N('EO=7(@9&]M86EN+"!C
M;&EC:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]S96QF+7!H;W-T
M:6YG)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@<&AY<VEC86P@
M:&]S=&EN9R!O;B!Y;W5R(&1O;6%I;BP@8VQI8VL@1FEN:7-H+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I
M;VYS7U]D97-C<FEP=&EO;B<@/3X@)TUA;F%G92!S:71E(&%P<&QI8V%T:6]N
M<R!O;B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]?<VAO<G0M=&ET;&4G(#T^("=3
M:71E(&%P<&QI8V%T:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G-?7W1I=&QE)R`]/B`G36%N86=E
M('-I=&4@87!P;&EC871I;VYS(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G-?<V5L
M9E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A<'!L:6-A=&EO;G,@
M;VX@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF7U]S:&]R="UT:71L92<@
M/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]S96QF7U]T:71L92<@
M/3X@)TUA;F%G92!M>2!S:71E(&%P<&QI8V%T:6]N<R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G-?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@<VET92!A<'!L:6-A=&EO
M;G,@;VX@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<U]U;FMN;W=N7U]T
M:71L92<@/3X@)TUA;F%G92!D;VUA:6X@<VET92!A<'!L:6-A=&EO;G,G+`H*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI
M8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N7U]D97-C<FEP=&EO;B<@/3X@)U)E
M8V]N9FEG=7)E('-I=&4@87!P;&EC871I;VX@)3$N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E
M+6%P<&QI8V%T:6]N7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<)W0@
M:&%V92!A;GD@:6YS=&%L;&5D('-I=&4@87!P;&EC871I;VYS+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;E]?;F]N92UA=F%I;&%B;&5?7S$G(#T^("=#
M;&EE;G0@)3$@9&]E<VY<)W0@:&%V92!A;GD@(&EN<W1A;&QE9"!S:71E(&%P
M<&QI8V%T:6]N<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VY?7VYO;F4M
M879A:6QA8FQE7U\R)R`]/B`G3F\@<VET92!A<'!L:6-A=&EO;G,@87)E(&-U
M<G)E;G1L>2!I;G-T86QL960@;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET
M92UA<'!L:6-A=&EO;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O
M<VET92UA<'!L:6-A=&EO;E]?=&ET;&4G(#T^("=3:71E(&%P<&QI8V%T:6]N
M("4Q)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET
M92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE=&5?7V1E<V-R
M:7!T:6]N)R`]/B`G56YI;G-T86QL('-I=&4@87!P;&EC871I;VX@)3$N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI
M8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?9&]N92<@/3X@)U-I
M=&4@87!P;&EC871I;VX@)3$@:&%S(&)E96X@=6YI;G-T86QL960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T
M:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^
M("=296UO=F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO9&5L971E7U]T
M:71L92<@/3X@)U)E;6]V92!S:71E(&%P<&QI8V%T:6]N("4Q)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]D97-C<FEP=&EO
M;B<@/3X@)U5N:6YS=&%L;"!A('-I=&4@87!P;&EC871I;VXN)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N
M<R]S:71E+6%P<&QI8V%T:6]N+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE
M=&5?=6YK;F]W;E]?=&ET;&4G(#T^("=296UO=F4@<VET92!A<'!L:6-A=&EO
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA
M<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]D96QE=&5?=6YK;F]W;E]?
M=VEZ87)D+71I=&QE)R`]/B`G4VET92!!<'!L:6-A=&EO;B!5;FEN<W1A;&PG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P
M;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO9&5L971E7W5N:VYO=VY?7W=I
M>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&]N('=H:6-H
M('EO=2!W86YT('1O('5N:6YS=&%L;"!A('-I=&4@87!P;&EC871I;VX@86YD
M(&-L:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+V1E
M;&5T95]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@=6YI;G-T86QL("!A;F0@
M8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO9&5L
M971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@=6YI;G-T86QL
M:6YG('1H92!S:71E(&%P<&QI8V%T:6]N(&)Y('-E;&5C=&EN9R!T:&4@8VAE
M8VL@8F]X(&%N9"!C;&EC:R!&:6YI<V@@=&\@8V]M<&QE=&5L>2!U;FEN<W1A
M;&P@:70@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P
M<&QI8V%T:6]N+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G4F5C;VYF
M:6=U<F4@<VET92!A<'!L:6-A=&EO;B`E,2XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P
M;&EC871I;VXO<')O<&5R=&EE<U]?9&]N92<@/3X@)U-I=&4@87!P;&EC871I
M;VX@)3$@8V]N9FEG=7)A=&EO;B!H87,@8F5E;B!U<&1A=&5D+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7U]S:&]R="UT:71L92<@
M/3X@)U)E8V]N9FEG=7)E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R
M;W!E<G1I97-?7W1I=&QE)R`]/B`G4F5C;VYF:6=U<F4@<VET92!A<'!L:6-A
M=&EO;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S
M7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=);G-T86QL(&$@<VET92!A<'!L:6-A
M=&EO;B!O;B!A(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO
M<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=3:71E(&%P<&QI8V%T:6]N("4Q
M(&AA<R!B965N(&EN<W1A;&QE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VXO<')O<&5R=&EE<U]N97=?7W-H;W)T+71I=&QE)R`]/B`G26YS=&%L;"<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L
M:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=&ET
M;&4G(#T^("=);G-T86QL('-I=&4@87!P;&EC871I;VXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I
M=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R9"UT:71L92<@
M/3X@)U-I=&4@07!P;&EC871I;VX@26YS=&%L;&%T:6]N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S
M:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S$O8W5S
M=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T:65S)R`]/B`G4V5T
M('5P('!R;W!E<G1I97,@;V8@=&AE(&-U<W1O;2!B=71T;VX@86YD(&-L:6-K
M($9I;FES:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG
M+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE
M<U]N97=?7W=I>F%R9%]?,B]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N
M+W!R;W!E<G1I97,G(#T^("=3970@=7`@<')O<&5R=&EE<R!O9B!T:&4@8W5S
M=&]M(&)U='1O;B!A;F0@8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA
M<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R7W5N:VYO=VXG
M(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@:6YS
M=&%L;"!S:71E(&%P<&QI8V%T:6]N(&%N9"!C;&EC:R!.97AT(#X^+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A
M=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D
M7U\S+W!R;W!E<G1I97-?<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y
M970@8V]N9FEG=7)E9"!O;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@
M:&]S=&EN9R!A;F0@8VQI8VL@3F5X="`^/B!T;R!P<F]C965D('1O(&EN<W1A
M;&QI;F<@=&AE('-I=&4@87!P;&EC871I;VXN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P
M<&QI8V%T:6]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O<')O<&5R=&EE
M<U]S96QF+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@>65T(&-O;F9I
M9W5R960@;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A;"!H;W-T:6YG
M(&%N9"!C;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@:6YS=&%L;&EN9R!T
M:&4@<VET92!A<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]H;W-T:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I
M;VXO<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-5]N97<G(#T^("=396QE8W0@
M82!S:71E(&%P<&QI8V%T:6]N('EO=2!W86YT('1O(&EN<W1A;&P@86YD(&-L
M:6-K($YE>'0@/CXN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]S:71E+6%P<&QI8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E
M<G1I97-?;F5W7U]W:7IA<F1?7S5?;F5W+65X=')A)R`]/B`G1&5F:6YE('=H
M870@<VAO=6QD(&)E(&1O;F4@=&\@=&AE(&5X=')A(&9I;&5S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\U
M7VYE=RUI;F9O)R`]/B`G0VQI8VL@3F5X="`^/B!T;R!I;G-T86QL('1H92!S
M:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7VYE=U]?=VEZ87)D7U\U7VYE=RUI;G-T86QL)R`]/B`G4W!E
M8VEF>2!T:&4@<VET92!A<'!L:6-A=&EO;B!P87)A;65T97)S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO
M;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U]C
M=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97,G(#T^("=3
M970@=7`@<')O<&5R=&EE<R!O9B!T:&4@8W5S=&]M(&)U='1O;B!A;F0@8VQI
M8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T
M:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5C;VYF:6=U<F4@82!S
M:71E(&%P<&QI8V%T:6]N+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4F5C;VYF:6=U
M<F4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M
M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]U;FMN
M;W=N7U]T:71L92<@/3X@)U)E8V]N9FEG=7)E('-I=&4@87!P;&EC871I;VXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-I=&4M87!P
M;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R=&EE<U]U;FMN;W=N
M7U]W:7IA<F0M=&ET;&4G(#T^("=3:71E($%P<&QI8V%T:6]N(%)E8V]N9FEG
M=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M<VET92UA<'!L:6-A=&EO;G,O<VET92UA<'!L:6-A=&EO;B]P<F]P97)T:65S
M7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M
M86EN(&]N('=H:6-H('EO=2!W86YT('1O(')E8V]N9FEG=7)E(&$@<VET92!A
M<'!L:6-A=&EO;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-I=&4M87!P;&EC871I;VYS+W-I=&4M87!P;&EC871I;VXO<')O<&5R
M=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M('-I=&4@87!P;&EC871I;VX@>6]U('=A;G0@=&\@<F5C;VYF:6=U<F4N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S:71E+6%P<&QI
M8V%T:6]N<R]S:71E+6%P<&QI8V%T:6]N+W!R;W!E<G1I97-?=6YK;F]W;E]?
M=VEZ87)D7U\V)R`]/B`G4W!E8VEF>2!T:&4@<VET92!A<'!L:6-A=&EO;B!P
M87)A;65T97)S+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G-?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!D;VUA
M:6X@)3$@<W5B9&]M86EN<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-U8F1O;6%I;G-?7W-H;W)T+71I=&QE)R`]/B`G4W5B9&]M
M86EN<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B
M9&]M86EN<U]?=&ET;&4G(#T^("=3=6)D;VUA:6YS(&]F(&1O;6%I;B`E,2<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN
M<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TQI<W0@;V8@>6]U<B!S=6)D;VUA
M:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B
M9&]M86EN<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-U8F1O;6%I;G,G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?
M<V5L9E]?=&ET;&4G(#T^("=->2!S=6)D;VUA:6YS)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS7W5N:VYO=VY?7V1E
M<V-R:7!T:6]N)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I;BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G-?=6YK
M;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=6)D;VUA:6YS)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!O9B!A(&1O;6%I;B<L"@H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M
M86EN7U]D97-C<FEP=&EO;B<@/3X@)U!R;W!E<G1I97,@;V8@<W5B9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B
M9&]M86EN<R]S=6)D;VUA:6Y?7VYO;F4M879A:6QA8FQE)R`]/B`G66]U(&1O
M;EPG="!H879E(&%N>2!S=6)D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6Y?7VYO;F4M
M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q(&1O97-N7"=T(&AA=F4@86YY
M('-U8F1O;6%I;G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]?;F]N92UA=F%I;&%B;&5?7S(G
M(#T^("=4:&5R92!A<F4@;F\@<W5B9&]M86EN<R!O;B!D;VUA:6X@)3$N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M+W-U8F1O;6%I;E]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6Y?
M7W1I=&QE)R`]/B`G4W5B9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6X@:&]S=&EN
M9R!S971T:6YG<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G4W5B9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;E]U;FMN;W=N7U]T:71L92<@
M/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]D96QE=&5?
M7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-U8F1O;6%I;B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B
M9&]M86EN+V1E;&5T95]?9&]N92<@/3X@)U-U8F1O;6%I;B`E,2!H87,@8F5E
M;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]S:&]R="UT:71L92<@
M/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E7U]T:71L92<@/3X@)U)E
M;6]V92!S=6)D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T95]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T1E;&5T92!S=6)D;VUA:6X@8V]N9FEG=7)A
M=&EO;B!A;F0@8V]N=&5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+V1E;&5T95]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO9&5L971E
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G4F5M;W9E('-U8F1O;6%I;B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D
M;VUA:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U-U8F1O
M;6%I;B!296UO=F%L)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]D96QE=&5?=6YK;F]W;E]?=VEZ
M87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@9G)O;2!W:&EC
M:"!Y;W4@=V%N="!T;R!R96UO=F4@82!S=6)D;VUA:6XN)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I
M;B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\U7W5N:VYO=VXG(#T^("=396QE
M8W0@82!S=6)D;VUA:6X@>6]U('=A;G0@=&\@<F5M;W9E+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA
M:6XO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@)T-O;F9I<FT@<F5M
M;W9I;F<@=&AE('-U8F1O;6%I;B!B>2!S96QE8W1I;F<@=&AE(&-H96-K(&)O
M>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@<F5M;W9E(&ET(&%N
M9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]?
M9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@<W5B9&]M86EN("4Q(&AO<W1I
M;F<@<V5T=&EN9W,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S
M=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]P<F]P97)T:65S7U]D;VYE)R`]
M/B`G4W5B9&]M86EN("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E96X@=7!D871E
M9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G0V]N9FEG
M=7)E('-U8F1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]N97<M
M861H;V-?7W=I>F%R9%]?-5]N97<G(#T^("=.97<@<W5B9&]M86EN('=I;&P@
M8F4@8W)E871E9"!I;6UE9&EA=&5L>2!A9G1E<B!Y;W4@8VQI8VL@3F5X="`^
M/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]D97-C<FEP=&EO;B<@
M/3X@)T-R96%T92!N97<@<W5B9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R
M=&EE<U]N97=?7V1O;F4G(#T^("=3=6)D;VUA:6X@)3$@:&%S(&)E96X@8W)E
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U
M8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L
M92<@/3X@)T-R96%T92!S=6)D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I
M97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!S=6)D;VUA:6XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M
M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^("=3=6)D;VUA
M:6X@0W)E871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y
M;W4@=V%N="!T;R!C<F5A=&4@82!S=6)D;VUA:6XN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS+W-U8F1O;6%I;B]P
M<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?<&AO<W1I;F<G
M(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O;B!T:&4@9&]M
M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI8VL@3F5X="`^
M/B!T;R!P<F]C965D('1O('-U8F1O;6%I;B!C<F5A=&EO;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M
M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S,O<')O<&5R=&EE<U]S96QF
M+7!H;W-T:6YG)R`]/B`G2&]S=&EN9R!I<R!N;W0@>65T(&-O;F9I9W5R960@
M;VX@>6]U<B!D;VUA:6XN(%-E="!U<"!P:'ES:6-A;"!H;W-T:6YG(&%N9"!C
M;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@<W5B9&]M86EN(&-R96%T:6]N
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M
M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-5]N97<G
M(#T^("=3<&5C:69Y('1H92!S=6)D;VUA:6X@:&]S=&EN9R!P87)A;65T97)S
M(&%N9"!C;&EC:R!&:6YI<V@@=&\@8W)E871E('1H92!S=6)D;VUA:6XN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]S=6)D;VUA:6YS
M+W-U8F1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G0V]N9FEG=7)E('-U8F1O;6%I;B!H;W-T:6YG('-E='1I;F=S+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S
M=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@
M)U-U8F1O;6%I;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O<W5B9&]M86EN<R]S=6)D;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]T
M:71L92<@/3X@)T-O;F9I9W5R92!S=6)D;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R
M;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G4W5B9&]M86EN
M($-O;F9I9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H
M;W-T:6YG+W-U8F1O;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W
M;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@=VAO
M<V4@<W5B9&]M86EN('EO=2!W86YT('1O(')E8V]N9FEG=7)E+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O<W5B9&]M86EN<R]S=6)D
M;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S5?=6YK;F]W;B<@
M/3X@)U-E;&5C="!A('-U8F1O;6%I;B!Y;W4@=V%N="!T;R!R96-O;F9I9W5R
M92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W-U8F1O
M;6%I;G,O<W5B9&]M86EN+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V
M)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@=&AE('-U8F1O;6%I
M;B!H;W-T:6YG('-E='1I;F=S+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA
M;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]?9&5S8W)I<'1I;VXG(#T^
M("=,:7-T(&]F(&1O;6%I;B`E,2!W96(@=7-E<G,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?7W-H;W)T+71I=&QE
M)R`]/B`G5V5B('5S97)S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:&]S=&EN9R]W96(M=7-E<G-?7W1I=&QE)R`]/B`G5V5B('5S97)S(&]F(&1O
M;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G3&ES="!O9B!Y;W5R
M('=E8B!U<V5R<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T
M:6YG+W=E8BUU<V5R<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U=E8B!U<V5R
M<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?=6YK;F]W;E]?
M9&5S8W)I<'1I;VXG(#T^("=,:7-T(&]F(&1O;6%I;B!W96(@=7-E<G,N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G-?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<U]U;FMN;W=N
M7U]T:71L92<@/3X@)T1O;6%I;B!W96(@=7-E<G,G+`H*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O<')O<&5R=&EE<U]?
M9&5S8W)I<'1I;VXG(#T^("=796(@=7-E<G,@<')E9F5R96YC97,@;VX@9&]M
M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W!R;W!E<G1I97-?7V1O;F4G(#T^("=796(@=7-E<G,@<')E
M9F5R96YC97,@:&%V92!B965N('5P9&%T960@;VX@9&]M86EN("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R
M;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC97,@9F]R('=E
M8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G5V5B('5S97)S('!R
M969E<F5N8V5S(&]N(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("=9;W5R('=E8B!U<V5R<R!P<F5F97)E;F-E<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R
M;W!E<G1I97-?<V5L9E]?9&]N92<@/3X@)UEO=7(@=V5B('5S97)S('!R969E
M<F5N8V5S(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?<V5L9E]?
M<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<G,@<')E9F5R96YC97,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P<F]P
M97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G37D@=V5B('5S97)S('!R969E<F5N
M8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M
M=7-E<G,O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U=E
M8B!U<V5R<R!P<F5F97)E;F-E<R!O9B!A(&1O;6%I;BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P<F]P97)T:65S
M7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC97,@9F]R('=E
M8B!U<V5R<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=796(@
M=7-E<G,@<')E9F5R96YC97,@;V8@82!D;VUA:6XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]P<F]P97)T:65S7W5N
M:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN
M(&9O<B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U<F4@=V5B('5S97)S('!R
M969E<F5N8V5S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U)R`]
M/B`G5VAE;B!D;VYE('=I=&@@961I=&EN9R!T:&4@=V5B('5S97)S('!R969E
M<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI
M="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U
M7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('EO=7(@=V5B('5S
M97)S('!R969E<F5N8V5S+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E
M<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?9&5S8W)I<'1I
M;VXG(#T^("=796(@=7-E<B`E,2!P<F]P97)T:65S+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R7U]N
M;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<)W0@:&%V92!A;GD@=V5B('5S
M97)S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W=E8BUU<V5R7U]N;VYE+6%V86EL86)L95]?,2<@/3X@)T-L:65N
M="`E,2!D;V5S;EPG="!H879E(&%N>2!W96(@=7-E<G,N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97)?
M7VYO;F4M879A:6QA8FQE7U\R)R`]/B`G5&AE<F4@87)E(&YO('=E8B!U<V5R
M(&%C8V]U;G1S(&]N(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<E]?<VAO<G0M=&ET
M;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I
M;F<O=V5B+75S97)S+W=E8BUU<V5R7U]T:71L92<@/3X@)U=E8B!U<V5R("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E
M<G,O=V5B+75S97)?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#:&%N9V4@
M<&%S<W=O<F0@9F]R('=E8B!U<V5R(&%C8V]U;G0L(&QI;6ET(&1I<VL@<W!A
M8V4@=7-A9V4@86YD('-E="!U<"!S8W)I<'1S('-U<'!O<G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S
M97)?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU
M<V5R7W5N:VYO=VY?7W1I=&QE)R`]/B`G0V]N9FEG=7)E('=E8B!U<V5R(&%C
M8V]U;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W
M96(M=7-E<G,O=V5B+75S97(O9&5L971E7U]D97-C<FEP=&EO;B<@/3X@)T1E
M;&5T92!W96(@=7-E<B!A8V-O=6YT(&%N9"!C;VYT96YT+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R
M+V1E;&5T95]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&AA<R!B965N(')E;6]V
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M
M=7-E<G,O=V5B+75S97(O9&5L971E7U]S:&]R="UT:71L92<@/3X@)U)E;6]V
M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@=V5B('5S
M97(@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E
M8BUU<V5R<R]W96(M=7-E<B]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=$96QE=&4@82!W96(@=7-E<B!A8V-O=6YT(&%N9"!C;VYT96YT+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S
M+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E
M;6]V92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E
M;6]V92!W96(@=7-E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO
M<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+V1E;&5T95]U;FMN;W=N7U]W:7IA
M<F0M=&ET;&4G(#T^("=796(@57-E<B!296UO=F%L)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O9&5L
M971E7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@
M9&]M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E(&$@=V5B('5S
M97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M
M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?-5]U;FMN
M;W=N)R`]/B`G4V5L96-T(&$@=V5B('5S97(@86-C;W5N="!Y;W4@=V%N="!T
M;R!R96UO=F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?
M-B<@/3X@)T-O;F9I<FT@<F5M;W9I;F<@=&AE('=E8B!U<V5R(&%C8V]U;G0@
M8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K(&9I;FES:"!T
M;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ87)D+BXG
M+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E
M<G,O=V5B+75S97(O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET
M('!R;W!E<G1I97,@;V8@=V5B('5S97(@)3$N)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R
M=&EE<U]?9&]N92<@/3X@)U=E8B!U<V5R("4Q(&%C8V]U;G0@:&%V92!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN
M9R]W96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G
M(#T^("<E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O
M=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G0V]N
M9FEG=7)E('=E8B!U<V5R(&%C8V]U;G0@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T
M:65S7VYE=RUA9&AO8U]?=VEZ87)D7U\U7VYE=R<@/3X@)TYE=R!W96(@=7-E
M<B!A8V-O=6YT('=I;&P@8F4@8W)E871E9"!I;6UE9&EA=&5L>2!A9G1E<B!Y
M;W4@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T:65S7VYE=U]?
M9&5S8W)I<'1I;VXG(#T^("=#<F5A=&4@;F5W('=E8B!U<V5R(&%C8V]U;G0N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M=7-E
M<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7V1O;F4G(#T^("=796(@=7-E
M<B`E,2!H87,@8F5E;B!C<F5A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?
M;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!W96(@=7-E<B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU
M<V5R+W!R;W!E<G1I97-?;F5W7U]T:71L92<@/3X@)T-R96%T92!W96(@=7-E
M<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S
M97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W7U]W:7IA<F0M=&ET;&4G(#T^
M("=796(@=7-E<B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?;F5W
M7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!O;B!W
M:&EC:"!Y;W4@=V%N="!T;R!C<F5A=&4@=V5B('5S97(@86-C;W5N="XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W
M96(M=7-E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\S+W!R;W!E<G1I97-?
M<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y970@8V]N9FEG=7)E9"!O
M;B!T:&4@9&]M86EN+B!3970@=7`@<&AY<VEC86P@:&]S=&EN9R!A;F0@8VQI
M8VL@3F5X="`^/B!T;R!P<F]C965D('1O(&-R96%T:6YG('=E8B!U<V5R(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W
M96(M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,R]P
M<F]P97)T:65S7W-E;&8M<&AO<W1I;F<G(#T^("=(;W-T:6YG(&ES(&YO="!Y
M970@8V]N9FEG=7)E9"!O;B!Y;W5R(&1O;6%I;BX@4V5T('5P('!H>7-I8V%L
M(&AO<W1I;F<@86YD(&-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!C<F5A
M=&EN9R!W96(@=7-E<B!A8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?
M;F5W7U]W:7IA<F1?7S5?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T
M92!T:&4@=V5B('5S97(@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E<B]P<F]P97)T:65S
M7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('!A<W-W;W)D(&9O
M<B!W96(@=7-E<B!A8V-O=6YT+"!L:6UI="!D:7-K('-P86-E('5S86=E(&%N
M9"!S970@=7`@<V-R:7!T<R!S=7!P;W)T+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I
M97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=796(@=7-E<B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU
M<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U<F4@
M=V5B('5S97(@86-C;W5N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VAO<W1I;F<O=V5B+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W
M;E]?=VEZ87)D+71I=&QE)R`]/B`G0V]N9FEG=7)I;F<@5V5B(%5S97(@06-C
M;W5N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VAO<W1I;F<O=V5B
M+75S97)S+W=E8BUU<V5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R
M7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A
M;G0@=&\@<F5C;VYF:6=U<F4@=V5B('5S97(@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]H;W-T:6YG+W=E8BUU<V5R<R]W96(M=7-E
M<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-5]U;FMN;W=N)R`]/B`G
M4V5L96-T('=E8B!U<V5R(&%C8V]U;G0@>6]U('=A;G0@=&\@<F5C;VYF:6=U
M<F4N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:&]S=&EN9R]W96(M
M=7-E<G,O=V5B+75S97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S8G
M(#T^("=7:&5N(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!T:&4@=V5B('5S97(@
M86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD(&5X
M:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?7V1E<V-R:7!T:6]N
M)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="!F;W(@9&]M86EN("4Q+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P
M86-E+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@
M=7-A9V4@;&EM:70G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I
M8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G95]?=&ET;&4G(#T^("=$:7-K
M('-P86-E('5S86=E(&QI;6ET(&9O<B!D;VUA:6X@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU
M<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A9V4@
M;&EM:70@9F]R('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W-E;&9?
M7W-H;W)T+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E
M+6QI;6ET+75S86=E7W-E;&9?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G
M92!L:6UI="!F;W(@>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G95]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A9V4@;&EM:70@
M9F]R(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L:6UI="<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET
M+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92!L
M:6UI="!F;W(@82!D;VUA:6XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7V1E<V-R:7!T:6]N)R`]/B`G1&]M
M86EN("4Q(&5X<&ER871I;VX@9&%T92`N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W-H;W)T+71I=&QE)R`]
M/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+65X<&ER871I;VY?7W1I=&QE)R`]/B`G1&]M86EN("4Q
M(&5X<&ER871I;VX@9&%T92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G
M66]U<B!D;VUA:6X@97AP:7)A=&EO;B!D871E+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T:6]N7W-E;&9?7W-H;W)T
M+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?<V5L9E]?=&ET;&4G
M(#T^("=9;W5R(&1O;6%I;B!E>'!I<F%T:6]N(&1A=&4N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER871I;VY?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=$;VUA:6X@97AP:7)A=&EO;B!D871E+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUE>'!I<F%T
M:6]N7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G17AP:7)A=&EO;B!D871E
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+65X<&ER
M871I;VY?=6YK;F]W;E]?=&ET;&4G(#T^("=$;VUA:6X@97AP:7)A=&EO;B!D
M871E)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUF
M=6QL+7-T871U<U]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T=7,@
M;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUF=6QL+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T
M92!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M9G5L;"US=&%T=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S(&]F
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUF=6QL+7-T871U<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-O;7!L
M971E('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L9E]?<VAO<G0M
M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L9E]?=&ET;&4G
M(#T^("=#;VUP;&5T92!S=&%T=7,@;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK
M;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VUP;&5T92!S=&%T=7,@;V8@82!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+69U;&PM<W1A='5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&QE
M=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?7W1I=&QE)R`]/B`G0V]M<&QE=&4@
M<W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUI<%]?9&5S8W)I<'1I;VXG(#T^("=)4"!A9&1R97-S
M(&]F(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I
M;F1I8V%T;W(M:7!?7W-H;W)T+71I=&QE)R`]/B`G25`@861D<F5S<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]?=&ET;&4G
M(#T^("=)4"!A9&1R97-S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUI<%]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)TE0(&%D9')E<W,@;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6EP7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G25`@861D<F5S<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VEN9&EC871O<BUI<%]S96QF7U]T:71L92<@/3X@)TE0(&%D9')E<W,@;V8@
M>6]U<B!D;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I
M8V%T;W(M:7!?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=)4"!A9&1R97-S
M(&]F(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUI<%]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)TE0(&%D9')E
M<W,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M:7!?
M=6YK;F]W;E]?=&ET;&4G(#T^("=)4"!A9&1R97-S(&]F(&$@9&]M86EN)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M;6%I
M;&)O>&5S+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)TUA:6QB;WAE
M<R!L:6UI="!U<V%G92!F;W(@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S
M86=E7U]S:&]R="UT:71L92<@/3X@)TUA:6QB;WAE<R!L:6UI="!U<V%G92<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUM87@M;6%I
M;&)O>&5S+6QI;6ET+75S86=E7U]T:71L92<@/3X@)TUA:6QB;WAE<R!L:6UI
M="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?<V5L
M9E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@=7-A9V4@9F]R
M('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T
M+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM
M:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=-86EL8F]X97,@;&EM:70@=7-A
M9V4@9F]R('EO=7(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W
M;E]?9&5S8W)I<'1I;VXG(#T^("=-86EL8F]X97,@;&EM:70@=7-A9V4@9F]R
M(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC
M871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T
M+71I=&QE)R`]/B`G36%I;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"UM86EL8F]X97,M;&EM
M:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=-86EL8F]X97,@;&EM:70@
M=7-A9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU<V%G95]?9&5S
M8W)I<'1I;VXG(#T^("=3=6)D;VUA:6YS(&QI;6ET('5S86=E(&9O<B!D;VUA
M:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@/3X@
M)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]I;F1I8V%T;W(M;6%X+7-U8F1O;6%I;G,M;&EM:70M=7-A9V5?
M7W1I=&QE)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@9&]M86EN
M("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA
M>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7V1E<V-R:7!T:6]N)R`]
M/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@>6]U<B!D;VUA:6XN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"US=6)D
M;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G4W5B
M9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU<V%G95]S96QF
M7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4@9F]R('EO=7(@
M9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+6UA>"US=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7V1E<V-R:7!T
M:6]N)R`]/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92!F;W(@82!D;VUA:6XN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6UA>"US
M=6)D;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G4W5B9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VEN9&EC871O<BUM87@M<W5B9&]M86EN<RUL:6UI="UU<V%G
M95]U;FMN;W=N7U]T:71L92<@/3X@)U-U8F1O;6%I;G,@;&EM:70@=7-A9V4@
M9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUN86UE7U]D97-C<FEP=&EO;B<@/3X@)TYA;64@;V8@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUN
M86UE7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?7W1I=&QE)R`]/B`G
M3F%M92!O9B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M;F%M95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TYA;64@
M;V8@>6]U<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M:6YD:6-A=&]R+6YA;65?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=$;VUA:6X@
M;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUN
M86UE7W-E;&9?7W1I=&QE)R`]/B`G3F%M92!O9B!Y;W5R(&1O;6%I;B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUN86UE7W5N:VYO
M=VY?7V1E<V-R:7!T:6]N)R`]/B`G3F%M92!O9B!A(&1O;6%I;BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M;F%M95]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!N86UE)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+6YA;65?=6YK;F]W;E]?=&ET;&4G
M(#T^("=.86UE(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUS=&%T95]?9&5S8W)I<'1I;VXG(#T^("=(96%L
M=&@@<W1A=&4@;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUS=&%T95]?<VAO<G0M=&ET;&4G(#T^("=(96%L
M=&@@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F(&1O;6%I;B`E
M,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T
M95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TAE86QT:"!S=&%T92!O9B!Y;W5R
M(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T
M;W(M<W1A=&5?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=(96%L=&@@<W1A=&4G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A=&5?
M<V5L9E]?=&ET;&4G(#T^("=(96%L=&@@<W1A=&4@;V8@>6]U<B!D;VUA:6XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A=&5?
M=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=(96%L=&@@<W1A=&4@;V8@82!D
M;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+7-T871E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G2&5A;'1H('-T871E
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871E
M7W5N:VYO=VY?7W1I=&QE)R`]/B`G2&5A;'1H('-T871E(&]F(&$@9&]M86EN
M)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T
M=7,M9&5T86EL<U]?9&5S8W)I<'1I;VXG(#T^("=$971A:6QE9"!S=&%T=7,@
M;V8@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN
M9&EC871O<BUS=&%T=7,M9&5T86EL<U]?<VAO<G0M=&ET;&4G(#T^("=$971A
M:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I
M8V%T;W(M<W1A='5S+61E=&%I;'-?7W1I=&QE)R`]/B`G1&5T86EL960@<W1A
M='5S(&]F(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T1E=&%I;&5D('-T871U<R!O9B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?
M<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S+61E=&%I
M;'-?<V5L9E]?=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,@;V8@>6]U<B!D
M;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M
M<W1A='5S+61E=&%I;'-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$971A
M:6QE9"!S=&%T=7,@;V8@82!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W5N:VYO=VY?7W-H
M;W)T+71I=&QE)R`]/B`G1&5T86EL960@<W1A='5S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W5N:VYO
M=VY?7W1I=&QE)R`]/B`G1&5T86EL960@<W1A='5S(&]F(&$@9&]M86EN)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7-?
M7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&1O;6%I;B`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S7U]S:&]R
M="UT:71L92<@/3X@)U-T871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VEN9&EC871O<BUS=&%T=7-?7W1I=&QE)R`]/B`G4W1A='5S(&]F(&1O
M;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O
M<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=3=&%T=7,@;V8@>6]U
M<B!D;VUA:6XN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A
M=&]R+7-T871U<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7-?<V5L
M9E]?=&ET;&4G(#T^("=3=&%T=7,@;V8@>6]U<B!D;VUA:6XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&]F(&$@9&]M86EN+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VEN9&EC871O<BUS=&%T=7-?=6YK;F]W
M;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]I;F1I8V%T;W(M<W1A='5S7W5N:VYO=VY?7W1I=&QE)R`]
M/B`G4W1A='5S(&]F(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VEN9&EC871O<BUT<F%F9FEC+6QI;6ET+75S86=E7U]D97-C<FEP
M=&EO;B<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R(&1O;6%I;B`E,2XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I
M8RUL:6UI="UU<V%G95]?<VAO<G0M=&ET;&4G(#T^("=4<F%F9FEC(&QI;6ET
M('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R
M+71R869F:6,M;&EM:70M=7-A9V5?7W1I=&QE)R`]/B`G5')A9F9I8R!L:6UI
M="!U<V%G92!F;W(@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O<B!Y;W5R(&1O
M;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M
M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]S:&]R="UT:71L92<@/3X@)U1R
M869F:6,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]T:71L92<@
M/3X@)U1R869F:6,@;&EM:70@=7-A9V4@9F]R('EO=7(@9&]M86EN)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO:6YD:6-A=&]R+71R869F:6,M;&EM
M:70M=7-A9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=4<F%F9FEC(&QI
M;6ET('5S86=E(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI="UU<V%G95]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A9V4G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]I;F1I8V%T;W(M=')A9F9I8RUL:6UI
M="UU<V%G95]U;FMN;W=N7U]T:71L92<@/3X@)U1R869F:6,@;&EM:70@=7-A
M9V4@9F]R(&$@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W(&]R(&5D:70@<F5S;W5R
M8V4@=7-A9V4@;&EM:71S(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;&EM:71S7U]D;VYE)R`]/B`G3&EM:71S(&]F(&1O
M;6%I;B`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]L:6UI='-?7W-H;W)T+71I=&QE)R`]/B`G3&EM:71S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7U]T:71L92<@/3X@
M)U9I97<O161I="!D;VUA:6X@)3$@;&EM:71S)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;&EM:71S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G5FEE
M=R!M>2!L:6UI=',N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM
M:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]L:6UI='-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=,:6UI=',G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]L:6UI='-?<V5L9E]?=&ET;&4G
M(#T^("=6:65W(&UY(&QI;6ET<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VQI;6ET<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@
M961I="!R97-O=7)C92!U<V%G92!L:6UI=',@9F]R(&$@9&]M86EN+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VQI;6ET<U]U;FMN;W=N7U]S:&]R
M="UT:71L92<@/3X@)TQI;6ET<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O161I="!D;VUA
M:6X@;&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S
M7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O161I=&EN9R!$
M;VUA:6X@3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM
M:71S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@
M9&]M86EN('=H;W-E(&QI;6ET<R!Y;W4@=V%N="!T;R!V:65W(&]R(&5D:70N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;&EM:71S7W5N:VYO=VY?
M7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W:71H(&5D:71I;F<@=&AE(&1O
M;6%I;B!L:6UI=',L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N
M9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;&EM:71S7W5N:VYO=VY?7W=I>F%R9%]?,U]S96QF)R`]/B`G5VAE;B!D
M;VYE('=I=&@@=FEE=VEN9R!Y;W5R(&QI;6ET<RP@8VQI8VL@1FEN:7-H+B<L
M"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7U]D97-C<FEP=&EO
M;B<@/3X@)TUA;F%G92!M86EL('-Y<W1E;2!O9B!D;VUA:6X@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]?9&ES86)L960M=V%R;FEN
M9R<@/3X@)TUA:6P@<V5R=FEC92!O;B!D;VUA:6X@)3$@:7,@9&ES86)L960@
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6Q?7W-H;W)T+71I
M=&QE)R`]/B`G36%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6Q?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@;VX@9&]M86EN("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]S96QF7U]D97-C<FEP=&EO
M;B<@/3X@)T-O;F9I9W5R92!M86EL('-Y<W1E;2!O;B!Y;W5R(&1O;6%I;BXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W-E;&9?7V1I<V%B
M;&5D+7=A<FYI;F<G(#T^("=-86EL('-E<G9I8V4@;VX@>6]U<B!D;VUA:6X@
M:7,@9&ES86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;%]S96QF7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL7W-E;&9?7W1I=&QE)R`]/B`G36%N86=E(&UA
M:6PG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL7W5N:VYO=VY?
M7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES=&5M(&]N(&$@
M9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;%]U;FMN
M;W=N7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL7W5N:VYO=VY?7W1I=&QE)R`]/B`G36%N86=E(&UA
M:6P@;VX@9&]M86EN)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;65?7V1E<V-R:7!T:6]N)R`]/B`G36%N86=E(&UA:6P@86-C
M;W5N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE7U]N;VYE+6%V86EL86)L92<@/3X@)UEO=2!D;VY<)W0@:&%V92!A
M;GD@;6%I;&YA;65S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;65?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT("4Q
M(&1O97-N7"=T(&-H879E(&%N>2!M86EL;F%M97,N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]?;F]N92UA=F%I;&%B;&5?
M7S(G(#T^("=4:&5R92!A<F4@;F\@;6%I;&YA;65S(&]N(&1O;6%I;B`E,2XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7U]S
M:&]R="UT:71L92<@/3X@)R4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M95]?=&ET;&4G(#T^("=-86EL;F%M92`E,2<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;65?<V5L9E]?
M9&5S8W)I<'1I;VXG(#T^("=-86YA9V4@>6]U<B!M86EL(&%C8V]U;G0N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M95]S96QF
M7U]Q=6EC:RUS96%R8V@G(#T^("=->2!M86EL;F%M97,G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?7W-H;W)T+71I
M=&QE)R`]/B`G37D@;6%I;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE7W-E;&9?7W1I=&QE)R`]/B`G37D@;6%I;&YA
M;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M7W5N:VYO=VY?7W%U:6-K+7-E87)C:"<@/3X@)TUA:6QN86UE<R<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U
M<R]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!A;G1I
M=FER=7,@<V5R=FEC92!F;W(@;6%I;"!A8V-O=6YT("4Q+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S+W!R
M;W!E<G1I97-?7V1O;F4G(#T^("=!;G1I=FER=7,@<V5T=&EN9W,@9F]R(&UA
M:6QN86UE("4Q(&AA=F4@8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I
M97-?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R
M=&EE<U]?=&ET;&4G(#T^("=3970@=7`@86YT:79I<G5S(&9O<B!M86EL;F%M
M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^
M("=#;VYF:6=U<F4@86YT:79I<G5S('-E<G9I8V4@9F]R('EO=7(@;6%I;"!A
M8V-O=6YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O86YT:79I<G5S+W!R;W!E<G1I97-?<V5L9E]?9&]N92<@/3X@)T%N
M=&EV:7)U<R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H879E(&)E96X@
M=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G06YT:79I<G5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]S96QF7U]T:71L
M92<@/3X@)U-E="!U<"!A;G1I=FER=7,G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N
M:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&%N=&EV:7)U<R!S
M97)V:6-E(&9O<B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S
M7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G06YT:79I<G5S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A;G1I=FER=7,O
M<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U-E="!U<"!A;G1I=FER
M=7,@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A;G1I=FER=7,O<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F0M=&ET;&4G(#T^("=!;G1I=FER=7,@0V]N9FEG=7)A=&EO;B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I
M<G5S+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^
M("=396QE8W0@82!D;VUA:6X@;VX@9F]R('=H:6-H(&UA:6P@86-C;W5N="!Y
M;W4@=V%N="!T;R!S970@=7`@86YT:79I<G5S+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O86YT:79I<G5S+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M
M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P(&%N=&EV:7)U
M<RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-B<@/3X@
M)U-E;&5C="!W:&5T:&5R(&EN8V]M:6YG(&]R(&]U=&-O;6EN9R!M86EL+"!O
M<B!B;W1H('-H;W5L9"!B92!C:&5C:V5D(&9O<B!V:7)U<V5S+B!7:&5N(&1O
M;F4@=VET:"!C;VYF:6=U<FEN9R!A;G1I=FER=7,@9F]R('1H92!M86EL;F%M
M92P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD(&5X:70@=&AE
M('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V%N=&EV:7)U<R]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?
M-E]S96QF)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@86YT:79I
M<G5S(&9O<B!Y;W5R(&UA:6P@86-C;W5N="P@8VQI8VL@=&\@87!P;'D@8VAA
M;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S7U]D97-C
M<FEP=&EO;B<@/3X@)TQI<W0@;V8@875T;W)E<W!O;F1E<G,@;VX@;6%I;&YA
M;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<U]?9&ES86)L960M=V%R;FEN9R<@/3X@)U1H
M92!A=71O<F5S<&]N9&5R<R!S97)V:6-E(&]N(&UA:6QN86UE("4Q(&ES(&1I
M<V%B;&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G-?7W-H;W)T+71I=&QE)R`]/B`G)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S7U]T:71L92<@/3X@)T%U=&]R97-P;VYD97)S(&]N(&UA:6QN
M86UE("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TUA
M;F%G92!Y;W5R(&%U=&]R97-P;VYD97)S+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G-?<V5L9E]?
M<VAO<G0M=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G-?<V5L9E]?=&ET;&4G(#T^("=->2!A=71O<F5S<&]N9&5R<R<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE)R`]/B`G66]U
M(&1O;EPG="!H879E(&%N>2!A=71O<F5S<&]N9&5R<RXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97)?7VYO;F4M879A:6QA8FQE7U\Q)R`]/B`G0VQI96YT
M("4Q(&1O97-N7"=T(&AA=F4@86YY(&%U=&]R97-P;VYD97)S+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O
M;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B;&5?7S(G(#T^("=4
M:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@;VX@9&]M86EN("4Q+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E
M<W!O;F1E<G,O875T;W)E<W!O;F1E<E]?;F]N92UA=F%I;&%B;&5?7S0G(#T^
M("=4:&5R92!A<F4@;F\@875T;W)E<W!O;F1E<G,@8V]N9FEG=7)E9"!O;B!M
M86EL;F%M92`E,2XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C
M:"UD96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&%T=&%C:&UE;G1S
M(&9R;VT@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P
M;VYD97(O871T86-H+61E;&5T95]?9&]N92<@/3X@)T%T=&%C:&UE;G1S(&AA
M=F4@8F5E;B!R96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E<BXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]?<VAO<G0M=&ET
M;&4G(#T^("=296UO=F4@871T86-H;65N=',G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R
M97-P;VYD97(O871T86-H+61E;&5T95]?=&ET;&4G(#T^("=296UO=F4@871T
M86-H;65N=',@9G)O;2!A=71O<F5S<&]N9&5R("4Q)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A
M=71O<F5S<&]N9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]D97-C<FEP=&EO;B<@
M/3X@)T-L:6-K('1O(')E;6]V92!A='1A8VAM96YT<R!F<F]M(&YE=R!A=71O
M<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]A='1A8V@M
M9&5L971E7VYE=U]?9&]N92<@/3X@)T%T=&%C:&UE;G1S(&AA=F4@8F5E;B!R
M96UO=F5D(&9R;VT@)3$@875T;W)E<W!O;F1E<BXG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U
M=&]R97-P;VYD97(O871T86-H+61E;&5T95]N97=?7W-H;W)T+71I=&QE)R`]
M/B`G4F5M;W9E(&%T=&%C:&UE;G1S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+V%T=&%C:"UD96QE=&5?;F5W7U]T:71L92<@/3X@)U)E;6]V92!A='1A
M8VAM96YT<R!F<F]M(&$@;F5W(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]U;FMN;W=N7U]D97-C<FEP
M=&EO;B<@/3X@)T1E;&5T92!A;B!A=71O<F5S<&]N9&5R(&%T=&%C:&UE;G1S
M("XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H+61E;&5T95]U
M;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92!A='1A8VAM96YT<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]A='1A8V@M9&5L971E7W5N:VYO
M=VY?7W1I=&QE)R`]/B`G4F5M;W9E(&%N(&%U=&]R97-P;VYD97(@871T86-H
M;65N=',G+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]?9&5S
M8W)I<'1I;VXG(#T^("=!='1A8V@@9FEL97,@=&\@875T;W)E<W!O;F1E<B`E
M,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H7U]D;VYE)R`]
M/B`G071T86-H;65N=',@:&%V92!B965N(&%D9&5D('1O(&%U=&]R97-P;VYD
M97(@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]?<VAO
M<G0M=&ET;&4G(#T^("=!='1A8V@@9FEL97,G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R
M97-P;VYD97(O871T86-H7U]T:71L92<@/3X@)T%T=&%C:"!F:6QE<R!T;R!A
M=71O<F5S<&]N9&5R("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T
M=&%C:%]N97=?7V1E<V-R:7!T:6]N)R`]/B`G061D(&%T=&%C:&UE;G0@9FEL
M97,@9F]R(&YE=R!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E
M<W!O;F1E<B]A='1A8VA?;F5W7U]D;VYE)R`]/B`G071T86-H;65N=',@:&%V
M92!B965N(&%D9&5D('1O(&%U=&]R97-P;VYD97(@)3$N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]N97=?7W-H;W)T+71I=&QE)R`]/B`G
M071T86-H(&9I;&5S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C
M:%]N97=?7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&YE=R!A=71O<F5S
M<&]N9&5R)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V%T=&%C:%]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)T%D9"!A='1A8VAM96YT(&9I;&5S(&9O
M<B!A;B!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E
M<B]A='1A8VA?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=!='1A8V@@9FEL
M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O871T86-H7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G071T86-H(&9I;&5S('1O(&%U=&]R97-P;VYD97(G+`H*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?9&5S8W)I<'1I;VXG
M(#T^("=296UO=F4@875T;W)E<W!O;F1E<B`E,2XG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U
M=&]R97-P;VYD97(O9&5L971E7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E
M,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E
M<B]D96QE=&5?7W-H;W)T+71I=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@875T
M;W)E<W!O;F1E<B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE
M=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=$96QE=&4@875T;W)E<W!O
M;F1E<B!C;VYF:6=U<F%T:6]N(&9O<B!A(&UA:6P@86-C;W5N="XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?7W-H;W)T+71I
M=&QE)R`]/B`G4F5M;W9E)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E
M;&5T95]U;FMN;W=N7U]T:71L92<@/3X@)U)E;6]V92!A=71O<F5S<&]N9&5R
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]U;FMN;W=N7U]W
M:7IA<F0M=&ET;&4G(#T^("=!=71O<F5S<&]N9&5R(%)E;6]V86PG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?
M,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&]W;FEN9R!T:&4@9&]M
M86EN(&9R;VT@=VAI8V@@>6]U('=A;G0@=&\@<F5M;W9E(&%U=&]R97-P;VYD
M97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+V1E;&5T95]U;FMN;W=N
M7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F<F]M
M('=H:6-H('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N9&5R+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E
M<W!O;F1E<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D
M7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!F<F]M('=H:6-H
M('EO=2!W86YT('1O(')E;6]V92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\V7W5N
M:VYO=VXG(#T^("=0;&5A<V4@<V5L96-T('=H:6-H(&%U=&]R97-P;VYD97(@
M>6]U('=A;G0@=&\@<F5M;W9E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E
M<B]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\W)R`]/B`G0V]N9FER;2!R96UO
M=FEN9R!T:&4@875T;W)E<W!O;F1E<B!B>2!S96QE8W1I;F<@=&AE(&-H96-K
M(&)O>"!A;F0@8VQI8VL@9FEN:7-H('1O(&-O;7!L971E;'D@<F5M;W9E(&ET
M(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O
M;F1E<B]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!A
M=71O<F5S<&]N9&5R("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P
M<F]P97)T:65S7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E,2!C;VYF:6=U
M<F%T:6]N(&AA<R!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]?=&ET
M;&4G(#T^("=!=71O<F5S<&]N9&5R("4Q('!R969E<F5N8V5S)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N
M9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]D97-C<FEP=&EO
M;B<@/3X@)T-R96%T92!N97<@875T;W)E<W!O;F1E<B!F;W(@82!M86EL(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?
M;F5W7U]D;VYE)R`]/B`G075T;W)E<W!O;F1E<B`E,2!H87,@8F5E;B!C<F5A
M=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7VYE
M=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R
M97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E871E(&%U
M=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R
M=&EE<U]N97=?7W=I>F%R9"UT:71L92<@/3X@)T%U=&]R97-P;VYD97(@0W)E
M871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N
M97=?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&9O
M<B!W:&EC:"!M86EL(&%C8V]U;G0@>6]U('=A;G0@=&\@8W)E871E(&%U=&]R
M97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I
M97-?;F5W7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U!L96%S92!S96QE8W0@
M82!M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@8W)E871E(&%U=&]R
M97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I
M97-?;F5W7U]W:7IA<F1?7S8O871T86-H)R`]/B`G4V5L96-T(&%T=&%C:&UE
M;G1S(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@961I=&EN9R!T:&4@875T
M;W)E<W!O;F1E<B!P<F]P97)T:65S+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O
M;F1E<B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\V+V%T=&%C:"<@/3X@)U-E
M;&5C="!A='1A8VAM96YT<R!A;F0@8VQI8VL@3TL@=&\@<F5T=7)N('1O(&5D
M:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R=&EE<RXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD
M97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?-B]A
M='1A8V@M9&5L971E)R`]/B`G0V]N9FER;2!A='1A8VAM96YT(')E;6]V86P@
M86YD(&-L:6-K($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H92!A=71O<F5S
M<&]N9&5R('!R;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R
M+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S8O9FEL97,O9&5L971E)R`]/B`G
M0V]N9FER;2!F:6QE<R!R96UO=F%L(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@
M=&\@;6%N86=I;F<@=&AE(&%U=&]R97-P;VYD97(@871T86-H;65N=',N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O
M<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?;F5W7U]W:7IA
M<F1?7S9?;F5W)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@875T
M;W)E<W!O;F1E<BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R
M=&EE<U]N97=?7W=I>F%R9%]?-R<@/3X@)U=H96X@9&]N92!W:71H(&-H86YG
M:6YG('1H92!A=71O<F5S<&]N9&5R('!R;W!E<G1I97,L(&-L:6-K($9I;FES
M:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=#:&%N9V4@875T;W)E<W!O;F1E<B!S971T:6YG<RXG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U
M=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)U!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U
M=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]T:71L92<@/3X@)U)E
M8V]N9FEG=7)E(&%U=&]R97-P;VYD97(G+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P
M;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=!
M=71O<F5S<&]N9&5R(%)E8V]N9FEG=7)I;F<G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R
M97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W
M;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI8V@@;6%I;"!A8V-O=6YT
M('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O
M;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@9F]R('=H:6-H
M('EO=2!W86YT('1O(&-O;F9I9W5R92!A=71O<F5S<&]N9&5R+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O
M;F1E<G,O875T;W)E<W!O;F1E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-B]A='1A8V@G(#T^("=396QE8W0@871T86-H;65N=',@86YD(&-L:6-K
M($]+('1O(')E='5R;B!T;R!E9&ET:6YG('1H92!A=71O<F5S<&]N9&5R('!R
M;W!E<G1I97,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\V+V%T=&%C:"UD96QE=&4G(#T^("=#;VYF
M:7)M(&%T=&%C:&UE;G0@<F5M;W9A;"!A;F0@8VQI8VL@3TL@=&\@<F5T=7)N
M('1O(&5D:71I;F<@=&AE(&%U=&]R97-P;VYD97(@<')O<&5R=&EE<RXG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W
M:7IA<F1?7S8O9FEL97,O9&5L971E)R`]/B`G0V]N9FER;2!F:6QE<R!R96UO
M=F%L(&%N9"!C;&EC:R!/2R!T;R!R971U<FX@=&\@;6%N86=I;F<@=&AE(&%U
M=&]R97-P;VYD97(@871T86-H;65N=',N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S
M<&]N9&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V7W5N:VYO=VXG
M(#T^("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@=V%N('1O(&UA
M;F%G92XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F1?7S<G(#T^("=7:&5N(&1O;F4@=VET:"!C:&%N9VEN
M9R!T:&4@875T;W)E<W!O;F1E<B!P<F]P97)T:65S+"!C;&EC:R!&:6YI<V@@
M=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P
M;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7V1I<V%B;&5?7V1E<V-R:7!T
M:6]N)R`]/B`G1&ES86)L92!A=71O<F5S<&]N9&5R("4Q+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?9&ES86)L95]?9&]N92<@/3X@)T%U
M=&]R97-P;VYD97(@)3$@:&%S(&)E96X@9&ES86)L960N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R
M<R]A=71O<F5S<&]N9&5R+W1O9V=L95]D:7-A8FQE7U]S:&]R="UT:71L92<@
M/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE
M7V1I<V%B;&5?7W1I=&QE)R`]/B`G1&ES86)L92!A=71O<F5S<&]N9&5R("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A
M=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?7V1E
M<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD97(@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?7V1O;F4G(#T^
M("=!=71O<F5S<&]N9&5R("4Q(&AA<R!B965N(&5N86)L960N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N
M9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L95]E;F%B;&5?7W-H;W)T+71I=&QE
M)R`]/B`G16YA8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N9&5R+W1O9V=L
M95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE(&%U=&]R97-P;VYD97(@)3$G
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U
M=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7W5N:VYO=VY?7V1E
M<V-R:7!T:6]N)R`]/B`G16YA8FQE(&]R(&1I<V%B;&4@875T;W)E<W!O;F1E
M<B!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD
M97(O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G16YA8FQE+V1I
M<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7W5N:VYO
M=VY?7W1I=&QE)R`]/B`G16YA8FQE+T1I<V%B;&4@875T;W)E<W!O;F1E<B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O875T;W)E<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ
M87)D+71I=&QE)R`]/B`G16YA8FQI;F<O1&ES86)L:6YG($%U=&]R97-P;VYD
M97(G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+V%U=&]R97-P;VYD97(O=&]G9VQE7W5N:VYO=VY?
M7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L96-T(&$@8VQI96YT(&]W;FEN
M9R!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(&5N86)L92!O<B!D
M:7-A8FQE(&%U=&]R97-P;VYD97(N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]A=71O<F5S<&]N
M9&5R+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E
M;&5C="!A(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E;F%B;&4@;W(@
M9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E<W!O
M;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=3
M96QE8W0@82!M86EL;F%M92!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E;F%B;&4@
M;W(@9&ES86)L92!A=71O<F5S<&]N9&5R+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E<G,O875T;W)E
M<W!O;F1E<B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\V7W5N:VYO=VXG(#T^
M("=396QE8W0@=VAI8V@@875T;W)E<W!O;F1E<B!Y;W4@=V%N="!T;R!E;F%B
M;&4@;W(@9&ES86)L92XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?
M9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I
M8V4@;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?9&]N92<@
M/3X@)T%U=&]R97-P;VYD:6YG('-E<G9I8V4@:&%S(&)E96X@9&ES86)L960@
M;VX@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?<VAO<G0M=&ET
M;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]M86EL;F%M92]A=71O<F5S<&]N9&5R<R]T;V=G;&5?9&ES86)L95]?
M=&ET;&4G(#T^("=$:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@;VX@
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V%U=&]R97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7V1E<V-R:7!T:6]N)R`]
M/B`G16YA8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@;VX@)3$N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]T;V=G;&5?96YA8FQE7U]D;VYE)R`]/B`G075T;W)E<W!O;F1I
M;F<@<V5R=FEC92!H87,@8F5E;B!E;F%B;&5D(&]N("4Q+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T;W)E<W!O;F1E
M<G,O=&]G9VQE7V5N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%;F%B;&4G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R
M97-P;VYD97)S+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE(&%U
M=&]R97-P;VYD97)S('-E<G9I8V4@;VX@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L
M95]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE
M(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@9F]R(&$@;6%I;"!A8V-O=6YT+B<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O875T
M;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G
M16YA8FQE+V1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]T
M:71L92<@/3X@)T5N86)L92]$:7-A8FQE(&%U=&]R97-P;VYD97)S)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]A=71O<F5S
M<&]N9&5R<R]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA
M8FQI;F<O1&ES86)L:6YG($%U=&]R97-P;VYD:6YG(%-E<G9I8V4@;VX@36%I
M;&YA;64G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V%U=&]R97-P;VYD97)S+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S%?
M=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-L:65N="!O=VYI;F<@=&AE(&1O;6%I
M;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!E;F%B;&4@;W(@9&ES86)L92!A=71O
M<F5S<&]N9&EN9R!S97)V:6-E(&9O<B!M86EL;F%M92XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V%U=&]R97-P;VYD97)S
M+W1O9V=L95]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C
M="!A(&1O;6%I;B!T:&4@9&]M86EN(&]N('=H:6-H('EO=2!W86YT('1O(&5N
M86)L92!O<B!D:7-A8FQE(&%U=&]R97-P;VYD:6YG('-E<G9I8V4@9F]R(&UA
M:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O875T;W)E<W!O;F1E<G,O=&]G9VQE7W5N:VYO=VY?7W=I>F%R9%]?
M-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I;&YA;64@;VX@=VAI8V@@>6]U
M('=A;G0@=&\@96YA8FQE(&]R(&1I<V%B;&4@875T;W)E<W!O;F1I;F<@<V5R
M=FEC92XG+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]D96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&UA:6QN86UE
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O9&5L971E7U]D;VYE)R`]/B`G36%I;&YA;64@)3$@:&%S(&)E96X@<F5M
M;W9E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V1E;&5T95]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E;&5T95]?=&ET
M;&4G(#T^("=296UO=F4@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E;&5T95]U;FMN;W=N7U]D97-C
M<FEP=&EO;B<@/3X@)T1E;&5T92!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V1E;&5T95]U;FMN
M;W=N7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N:VYO=VY?7W1I
M=&QE)R`]/B`G4F5M;W9E(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D
M+71I=&QE)R`]/B`G36%I;&YA;64@4F5M;W9A;"<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9&5L971E7W5N:VYO=VY?7W=I
M>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN('1O(')E;6]V
M92!A(&UA:6QN86UE(&9R;VTN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]D96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\T7W5N
M:VYO=VXG(#T^("=396QE8W0@82!M86EL;F%M92!T;R!R96UO=F4N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]D96QE=&5?
M=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G0V]N9FER;2!R96UO=FEN9R!T:&4@
M;6%I;&YA;64@8GD@<V5L96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K
M(&9I;FES:"!T;R!C;VUP;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@
M=VEZ87)D+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V9O<G=A<F1I;F=?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E
M(&UA:6P@9F]R=V%R9&EN9R!O;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I;F=?7V1O;F4G(#T^("=-
M86EL(&9O<G=A<F1I;F<@<V5T=&EN9W,@9F]R(&UA:6QN86UE("4Q(&AA=F4@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]?<VAO<G0M=&ET;&4G(#T^("=&;W)W
M87)D:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL
M;F%M92]F;W)W87)D:6YG7U]T:71L92<@/3X@)U-E="!U<"!F;W)W87)D:6YG
M(&9O<B!M86EL;F%M92`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]S96QF7U]D97-C<FEP=&EO;B<@
M/3X@)T-O;F9I9W5R92`@;6%I;"!F;W)W87)D:6YG(&9O<B!Y;W5R(&UA:6P@
M86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V9O<G=A<F1I;F=?<V5L9E]?9&]N92<@/3X@)TUA:6P@9F]R=V%R
M9&EN9R!S971T:6YG<R!F;W(@>6]U<B!M86EL;F%M92!H879E(&)E96X@=7!D
M871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN
M86UE+V9O<G=A<F1I;F=?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=&;W)W87)D
M:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]F;W)W87)D:6YG7W-E;&9?7W1I=&QE)R`]/B`G4V5T('5P(&9O<G=A<F1I
M;F<G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+V9O<G=A<F1I;F=?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U
M<F4@9F]R=V%R9&EN9R!S97)V:6-E(&]N(&$@;6%I;"!A8V-O=6YT+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R
M9&EN9U]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T9O<G=A<F1I;F<G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V9O<G=A
M<F1I;F=?=6YK;F]W;E]?=&ET;&4G(#T^("=3970@=7`@;6%I;"!F;W)W87)D
M:6YG)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]F;W)W87)D:6YG7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUA:6P@
M1F]R=V%R9&EN9R!3971U<"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]W:7IA<F1?7S)?
M=6YK;F]W;B<@/3X@)U-E;&5C="!A(&1O;6%I;B!F;W(@=VAI8V@@;6%I;&YA
M;64@>6]U('=A;G0@=&\@<V5T('5P(&UA:6P@9F]R=V%R9&EN9RXG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+V9O<G=A<F1I
M;F=?=6YK;F]W;E]?=VEZ87)D7U\T7W5N:VYO=VXG(#T^("=396QE8W0@82!M
M86EL;F%M92!F;W(@=VAI8V@@>6]U('=A;G0@=&\@<V5T('5P(&UA:6P@9F]R
M=V%R9&EN9RXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA
M:6QN86UE+V9O<G=A<F1I;F=?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G5VAE
M;B!D;VYE('=I=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!F;W(@=&AE(&UA
M:6QN86UE+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8V]N9FEG=7)A=&EO;B!A
M;F0@97AI="!T:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+VUA:6PO;6%I;&YA;64O9F]R=V%R9&EN9U]U;FMN;W=N7U]W:7IA<F1?
M7S5?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG(&UA:6P@
M9F]R=V%R9&EN9R!F;W(@>6]U<B!M86EL;F%M92P@8VQI8VL@1FEN:7-H('1O
M(&%P<&QY(&-O;F9I9W5R871I;VX@86YD(&5X:70@=&AE('=I>F%R9"XG+`H*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL
M8F]X+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA
M:6QB;W@@;VX@;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R;W!E<G1I97-?7V1O;F4G
M(#T^("=-86EL8F]X("4Q(&-O;F9I9W5R871I;VX@:&%S(&)E96X@=7!D871E
M9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+VUA:6QB;W@O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("=#;VYF:6=U
M<F4@;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7U]T:71L92<@/3X@)TUA:6QB
M;W@@)3$@<')O<&5R=&EE<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN
M+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W-E;&9?7V1E<V-R
M:7!T:6]N)R`]/B`G0V]N9FEG=7)E('EO=7(@;6%I;&)O>"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O
M<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G66]U<B!M86EL8F]X(&-O;F9I9W5R
M871I;VX@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R=&EE<U]S96QF
M7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M86EL8F]X)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R
M;W!E<G1I97-?<V5L9E]?=&ET;&4G(#T^("=->2!M86EL8F]X)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R
M;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=#;VYF:6=U<F4@
M;6%I;&)O>"!O;B!A(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+VUA:6QB;W@O<')O<&5R=&EE<U]U
M;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-O;F9I9W5R92!M86EL8F]X)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL
M8F]X+W!R;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U<F4@
M;6%I;&)O>"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O;6%I;&)O>"]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9"UT:71L
M92<@/3X@)TUA:6QB;W@@0V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S
M7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M
M86EN('1O(&-O;F9I9W5R92!M86EL8F]X(&]N+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O;6%I;&)O>"]P<F]P97)T:65S
M7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G4V5L96-T(&$@;6%I
M;&YA;64@=&\@8V]N9FEG=7)E(&UA:6QB;W@@;VXN)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\V)R`]/B`G5VAE;B!D;VYE('=I=&@@8V]N
M9FEG=7)I;F<@;6%I;&)O>"!O;B!T:&4@;6%I;&YA;64L(&-L:6-K($9I;FES
M:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]M86EL8F]X
M+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\V7W-E;&8G(#T^("=7:&5N
M(&1O;F4@=VET:"!C;VYF:6=U<FEN9R!Y;W5R(&UA:6QB;W@L(&-L:6-K($9I
M;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*
M"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O
M<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('!R;W!E<G1I97,@;V8@
M;6%I;&YA;64@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]P<F]P97)T:65S7U]D;VYE)R`]/B`G4')O<&5R=&EE<R!O
M9B!M86EL;F%M92`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?7W-H
M;W)T+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]?
M=&ET;&4G(#T^("=-86EL;F%M92`E,2!P<F]P97)T:65S)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE
M=RUA9&AO8U]?=VEZ87)D7U\T7VYE=R<@/3X@)TYN97<@;6%I;&YA;64@=VEL
M;"!B92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC:R!.97AT
M(#X^+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA
M;64O<')O<&5R=&EE<U]N97<M8F5F;W)E+6%N=&EV:7)U<U]?=VEZ87)D7U\T
M7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E871E('1H92!M86EL;F%M
M92!A;F0@<')O8V5E9"!T;R!C;VYF:6=U<FEN9R!A;G1I+79I<G5S('-E='1I
M;F=S+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C<F5A=&4@=&AE(&UA:6QN86UE
M(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=RUB969O<F4M<W!A
M;2UF:6QT97)?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R=&EE<R<@/3X@
M)U-P96-I9GD@<&%R86UE=&5R<R!O9B!$<BY796(@86YT:79I<G5S(&-O;F9I
M9W5R871I;VXN($-L:6-K($YE>'0@/CX@=&\@<')O8V5E9"!T;R!A;G1I+7-P
M86T@9FEL=&5R(&-O;F9I9W5R871I;VXN($-L:6-K($9I;FES:"!T;R!S879E
M($1R+E=E8B!C;VYF:6=U<F%T:6]N(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7VYE=RUB969O<F4M<W!A;2UF:6QT97)?7W=I>F%R9%]?-%]N97<G
M(#T^("=#;&EC:R!.97AT(#X^('1O(&-R96%T92!T:&4@;6%I;&YA;64@86YD
M('!R;V-E960@=&\@8V]N9FEG=7)I;F<@86YT:2US<&%M(&9I;'1E<B!F;W(@
M=&AE(&UA:6QN86UE+B!#;&EC:R!&:6YI<V@@=&\@:G5S="!C<F5A=&4@=&AE
M(&UA:6QN86UE+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M;6%I;&YA;64O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E
M871E(&YE=R!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=U]?9&]N92<@/3X@
M)TUA:6QN86UE("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE=U]?
M<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@;6%I;&YA;64G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W
M7U]T:71L92<@/3X@)T-R96%T92!M86EL;F%M92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N97=?7W=I
M>F%R9"UT:71L92<@/3X@)T-R96%T:6YG($UA:6QN86UE)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7VYE
M=U]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@
M=VAI8V@@>6]U('=A;G0@=&\@8W)E871E(&UA:6QN86UE+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]N
M97=?7W=I>F%R9%]?-"]A;G1I=FER=7,O<')O<&5R=&EE<R<@/3X@)T-L:6-K
M($9I;FES:"!T;R!S879E($1R+E=E8B!C;VYF:6=U<F%T:6]N(&%N9"!F:6YI
M<V@@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S0O<W!A;2UF
M:6QT97(O<')O<&5R=&EE<R<@/3X@)T-O;F9I9W5R92!T:&4@86YT:2US<&%M
M(&9I;'1E<B!A;F0@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@86YD
M(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S1?;F5W
M)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@;6%I;&YA;64@86YD
M(&5X:70@=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I97-?<V5L9E]?9&5S8W)I<'1I;VXG
M(#T^("=%9&ET('!R;W!E<G1I97,@;V8@>6]U<B!M86EL(&%C8V]U;G0N)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P
M97)T:65S7W-E;&9?7V1O;F4G(#T^("=0<F]P97)T:65S(&]F('EO=7(@;6%I
M;&YA;64@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W-E;&9?7W-H;W)T
M+71I=&QE)R`]/B`G36%I;&YA;64@<')O<&5R=&EE<R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]S96QF
M7U]T:71L92<@/3X@)T5D:70@;7D@86-C;W5N="<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R=&EE<U]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T-H86YG92!P87-S=V]R9"!A;F0@:6YT97)F
M86-E(&%N9"!S97-S:6]N('!R969E<F5N8V5S(&9O<B!A(&UA:6P@86-C;W5N
M="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W!R;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=-86EL;F%M
M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G161I
M="!M86EL;F%M92!P<F]P97)T:65S)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO;6%I;"]M86EL;F%M92]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9"UT:71L92<@/3X@)T5D:71I;F<@36%I;&YA;64@4')O<&5R=&EE<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<')O<&5R
M=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S)?=6YK;F]W;B<@/3X@)U-E;&5C="!A
M(&1O;6%I;B!O;B!W:&EC:"!Y;W4@=V%N="!T;R!C;VYF:6=U<F4@;6%I;&YA
M;64N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M
M92]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-%]U;FMN;W=N)R`]/B`G
M4V5L96-T('=H:6-H(&UA:6QN86UE('EO=2!W86YT('1O(&-O;F9I9W5R92XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R
M;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\U)R`]/B`G5VAE;B!D;VYE('=I
M=&@@8VAA;F=I;F<@;6%I;&YA;64@<')O<&5R=&EE<RP@8VQI8VL@1FEN:7-H
M('1O(&%P<&QY(&-H86YG97,@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\U7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET
M:"!C:&%N9VEN9R!M86EL;F%M92!P<F]P97)T:65S+"!C;&EC:R!&:6YI<V@@
M=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL
M=&5R+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E('-P
M86T@9FEL=&5R(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I
M97-?7V1O;F4G(#T^("=3<&%M(&9I;'1E<B!S971T:6YG<R!F;W(@;6%I;&YA
M;64@)3$@:&%V92!B965N('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S
M7U]S:&]R="UT:71L92<@/3X@)U-P86T@9FEL=&5R)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P
M97)T:65S7U]T:71L92<@/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<B!F;W(@
M;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?96YA8FQE7U]D97-C
M<FEP=&EO;B<@/3X@)T5N86)L92!A;F0@8V]N9FEG=7)E('-P86T@9FEL=&5R
M(&9O<B!M86EL;F%M92`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?96YA8FQE
M7U]D;VYE)R`]/B`G4W!A;2!F:6QT97(@9F]R(&UA:6QN86UE("4Q(&AA<R!B
M965N(&5N86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7V5N86)L95]?<VAO
M<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE
M<U]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE+T-O;F9I9W5R92!S<&%M(&9I
M;'1E<B!F;W(@;6%I;&YA;64@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?<V5L
M9BUE;F%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G16YA8FQE(&%N9"!C;VYF:6=U
M<F4@9FEL=&5R(&9O<B!Y;W5R(&UA:6P@86-C;W5N="XG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R
M;W!E<G1I97-?<V5L9BUE;F%B;&5?7V1O;F4G(#T^("=3<&%M(&9I;'1E<B!F
M;W(@>6]U<B!M86EL;F%M92!H87,@8F5E;B!E;F%B;&5D+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O
M<')O<&5R=&EE<U]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G(#T^("=3<&%M
M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]S96QF+65N86)L95]?=&ET
M;&4G(#T^("=%;F%B;&4@86YD(&-O;F9I9W5R92!S<&%M(&9I;'1E<B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF
M:6QT97(O<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I
M9W5R92!S<&%M(&9I;'1E<B!F;W(@>6]U<B!M86EL(&%C8V]U;G0N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I
M;'1E<B]P<F]P97)T:65S7W-E;&9?7V1O;F4G(#T^("=3<&%M(&9I;'1E<B!S
M971T:6YG<R!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R;W!E<G1I
M97-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=3<&%M(&9I;'1E<B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT
M97(O<')O<&5R=&EE<U]S96QF7U]T:71L92<@/3X@)T-O;F9I9W5R92!S<&%M
M(&9I;'1E<B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I
M;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP
M=&EO;B<@/3X@)T-O;F9I9W5R92!S<&%M(&9I;'1E<FEN9R!S971T:6YG<R!F
M;W(@82!M86EL(&%C8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W-H;W)T+71I=&QE)R`]/B`G4W!A;2!F:6QT97(G+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE+W-P86TM9FEL=&5R+W!R
M;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=#;VYF:6=U<F4@<W!A;2!F
M:6QT97(@9F]R(&UA:6QN86UE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9"UT:71L92<@/3X@)U-P86T@9FEL=&5R(&-O;F9I9W5R871I
M;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+VUA:6QN86UE
M+W-P86TM9FEL=&5R+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@82!D;VUA:6X@;VX@=VAI8V@@;6%I;&YA;64@
M>6]U('=A;G0@=&\@8V]N9FEG=7)E('-P86T@9FEL=&5R:6YG+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT
M97(O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@
M)U-E;&5C="!O;B!W:&EC:"!M86EL;F%M92!Y;W4@=V%N="!T;R!C;VYF:6=U
M<F4@<W!A;2!F:6QT97)I;F<N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO
M=VY?7W=I>F%R9%]?-B<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG
M('-P86T@9FEL=&5R(&9O<B!T:&4@;6%I;&YA;64L(&-L:6-K($9I;FES:"!T
M;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M86EL;F%M92]S<&%M+69I;'1E
M<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?-E]E;F%B;&4G(#T^("=7
M:&5N('EO=2!C;&EC:R!&:6YI<V@L('-P86T@9FEL=&5R(&9O<B!T:&4@;6%I
M;&YA;64@=VEL;"!B92!E;F%B;&5D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO;6%I;&YA;64O<W!A;2UF:6QT97(O<')O<&5R=&EE<U]U
M;FMN;W=N7U]W:7IA<F1?7S9?<V5L9B<@/3X@)U=H96X@9&]N92!W:71H(&-O
M;F9I9W5R:6YG('-P86T@9FEL=&5R(&9O<B!Y;W5R(&UA:6QN86UE+"!C;&EC
M:R!&:6YI<V@N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]M
M86EL;F%M92]S<&%M+69I;'1E<B]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R
M9%]?-E]S96QF+65N86)L92<@/3X@)U=H96X@>6]U(&-L:6-K($9I;FES:"P@
M<W!A;2!F:6QT97(@9F]R('EO=7(@;6%I;&YA;64@=VEL;"!B92!E;F%B;&5D
M+B<L"@H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I
M97-?7V1E<V-R:7!T:6]N)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES=&5M(&]N
M(&1O;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL
M+W!R;W!E<G1I97-?7V1O;F4G(#T^("=-86EL('-Y<W1E;2!O;B!D;VUA:6X@
M)3$@:&%S(&)E96X@8V]N9FEG=7)E9"XG+`H@("`@("`@("=U:5]?8VQI96YT
M+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?7W-H;W)T+71I=&QE)R`]/B`G0V]N
M9FEG=7)E(&UA:6P@<WES=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA
M:6XO;6%I;"]P<F]P97)T:65S7U]T:71L92<@/3X@)TUA;F%G92!M86EL(&]N
M(&1O;6%I;B`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M<')O<&5R=&EE<U]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-O;F9I9W5R92!M
M86EL('-Y<W1E;2!O;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?<V5L9E]?9&]N92<@/3X@)TUA
M:6P@<WES=&5M(&]N('EO=7(@9&]M86EN(&AA<R!B965N(&-O;F9I9W5R960N
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S
M7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES=&5M
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S
M7W-E;&9?7W1I=&QE)R`]/B`G36%N86=E(&UA:6PG+`H@("`@("`@("=U:5]?
M8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I97-?=6YK;F]W;E]?9&5S8W)I
M<'1I;VXG(#T^("=#;VYF:6=U<F4@;6%I;"!S>7-T96T@;VX@82!D;VUA:6XN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S
M7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G0V]N9FEG=7)E(&UA:6P@<WES
M=&5M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P<F]P97)T
M:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G36%N86=E(&UA:6P@;VX@9&]M86EN
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]P<F]P97)T:65S
M7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)TUA:6P@<WES=&5M(&-O;F9I
M9W5R871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R
M;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE
M8W0@82!D;VUA:6X@;VX@=VAI8V@@>6]U('=A;G0@=&\@8V]N9FEG=7)E(&UA
M:6P@<WES=&5M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO
M<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S0G(#T^("=7:&5N(&1O;F4@
M=VET:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L:6-K($9I;FES
M:"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D7U\T7W-E;&8G(#T^("=7:&5N(&1O;F4@=VET
M:"!C;VYF:6=U<FEN9R!T:&4@;6%I;"!S>7-T96TL(&-L:6-K($9I;FES:"XG
M+`H*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES
M86)L95]?9&5S8W)I<'1I;VXG(#T^("=$:7-A8FQE(&UA:6P@<V5R=FEC97,@
M;VX@9&]M86EN("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO=&]G9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=-86EL('-E<G9I8V5S(&]N
M(&1O;6%I;B`E,2!H879E(&)E96X@9&ES86)L960N)RP*("`@("`@("`G=6E?
M7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?9&ES86)L95]?<VAO<G0M=&ET
M;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]T;V=G;&5?9&ES86)L95]?=&ET;&4G(#T^("=$:7-A8FQE(&UA:6P@
M;VX@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I
M;"]T;V=G;&5?96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!M86EL
M('-E<G9I8V5S(&9O<B!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N
M="]D;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]D;VYE)R`]/B`G36%I;"!S
M97)V:6-E<R!O;B!D;VUA:6X@)3$@:&%V92!B965N(&5N86)L960N)RP*("`@
M("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?96YA8FQE7U]S
M:&]R="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+VUA:6PO=&]G9VQE7V5N86)L95]?=&ET;&4G(#T^("=%;F%B;&4@
M;6%I;"!O;B!D;VUA:6X@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]M86EL+W1O9V=L95]S96QF+61I<V%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G
M0VQI8VL@=&\@9&ES86)L92!M86EL('-E<G9I8V5S(&]N('EO=7(@9&]M86EN
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E
M;&8M9&ES86)L95]?9&]N92<@/3X@)TUA:6P@<V5R=FEC97,@;VX@>6]U<B!D
M;VUA:6X@:&%V92!B965N(&1I<V%B;&5D+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M9&ES86)L95]?<VAO<G0M=&ET
M;&4G(#T^("=$:7-A8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M;6%I;"]T;V=G;&5?<V5L9BUD:7-A8FQE7U]T:71L92<@/3X@)T1I<V%B;&4@
M;6%I;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE
M7W-E;&8M96YA8FQE7U]D97-C<FEP=&EO;B<@/3X@)T-L:6-K('1O(&5N86)L
M92!M86EL('-E<G9I8V5S(&]N('EO=7(@9&]M86EN+B<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&8M96YA8FQE7U]D;VYE
M)R`]/B`G36%I;"!S97)V:6-E<R!O;B!Y;W5R(&1O;6%I;B!H879E(&)E96X@
M96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W1O
M9V=L95]S96QF+65N86)L95]?<VAO<G0M=&ET;&4G(#T^("=%;F%B;&4G+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W1O9V=L95]S96QF+65N
M86)L95]?=&ET;&4G(#T^("=%;F%B;&4@;6%I;"<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O9&]M86EN+VUA:6PO=&]G9VQE7W-E;&9?7V1E<V-R:7!T:6]N)R`]
M/B`G0VQI8VL@=&\@96YA8FQE(&]R(&1I<V%B;&4@;6%I;"!S97)V:6-E<R!O
M;B!Y;W5R(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M
M86EL+W1O9V=L95]S96QF7U]S:&]R="UT:71L92<@/3X@)T5N86)L92]D:7-A
M8FQE)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?
M<V5L9E]?=&ET;&4G(#T^("=%;F%B;&4O1&ES86)L92!M86EL)RP*("`@("`@
M("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK;F]W;E]?9&5S
M8W)I<'1I;VXG(#T^("=%;F%B;&4@;W(@9&ES86)L92!M86EL('-E<G9I8V5S
M(&]N(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+VUA
M:6PO=&]G9VQE7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G16YA8FQE+V1I
M<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]M86EL+W1O9V=L
M95]U;FMN;W=N7U]T:71L92<@/3X@)T5N86)L92]$:7-A8FQE(&UA:6P@;VX@
M9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO;6%I;"]T;V=G
M;&5?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G16YA8FQI;F<O1&ES86)L
M:6YG($UA:6P@4V5R=FEC97,@;VX@1&]M86EN)RP*("`@("`@("`G=6E?7V-L
M:65N="]D;VUA:6XO;6%I;"]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N
M:VYO=VXG(#T^("=396QE8W0@;VX@=VAI8V@@9&]M86EN('EO=2!W86YT('1O
M(&5N86)L92!O<B!D:7-A8FQE(&UA:6P@<V5R=FEC97,N)RP*"B`@("`@("`@
M)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?7V1E<V-R:7!T:6]N)R`]
M/B`G4V5T('5P(&1O;6%I;B!A9&UI;FES=')A=&]R(&%C8V]U;G0@9F]R(&1O
M;6%I;B`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T
M:65S7U]D;VYE)R`]/B`G1&]M86EN(&%D;6EN(&%C8V]U;G0@)3$@:&%S(&)E
M96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P
M97)T:65S7U]S:&]R="UT:71L92<@/3X@)T1O;6%I;B!P<F]P97)T:65S)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]?=&ET;&4G
M(#T^("=3970@=7`@9&]M86EN(&%D;6EN(&9O<B!D;VUA:6X@)3$G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=RUA9&AO8U]?
M=VEZ87)D7U\R7VYE=R<@/3X@)TYE=R!D;VUA:6X@=VEL;"!B92!C<F5A=&5D
M(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC:R!.97AT(#X^+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W7U]D97-C<FEP
M=&EO;B<@/3X@)T-R96%T92!A;F0@8V]N9FEG=7)E(&YE=R!D;VUA:6XN)RP*
M("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7V1O
M;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@8W)E871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET
M;&4G(#T^("=#<F5A=&4@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E871E(&1O;6%I
M;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E<G1I97-?;F5W
M7U]W:7IA<F0M=&ET;&4G(#T^("=$;VUA:6X@0W)E871I;VXG+`H@("`@("`@
M("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\Q
M7W5N:VYO=VXG(#T^("=396QE8W0@82!C;&EE;G0@9F]R('=H;VT@>6]U('=A
M;G0@=&\@8W)E871E(&$@9&]M86EN+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M9&]M86EN+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S(O:&]S=&EN9R]P<F]P
M97)T:65S)R`]/B`G4V5L96-T('1H92!D97-I<F5D(&AO<W1I;F<@='EP92!F
M;W(@=&AE(&1O;6%I;B!A;F0@8VQI8VL@3F5X="`^/BXG+`H@("`@("`@("=U
M:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D7U\R+VAO
M<W1I;F<O<')O<&5R=&EE<U]F;W)W87)D:6YG)R`]/B`G5VAE;B!D;VYE('=I
M=&@@8V]N9FEG=7)I;F<@9F]R=V%R9&EN9R!O;B!T:&4@9&]M86EN+"!C;&EC
M:R!&:6YI<V@@=&\@87!P;'D@=&AE(&-O;F9I9W5R871I;VX@86YD(&5X:70@
M=&AE('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P
M97)T:65S7VYE=U]?=VEZ87)D7U\R+VAO<W1I;F<O<')O<&5R=&EE<U]P:&]S
M=&EN9R<@/3X@)U=H96X@9&]N92!W:71H(&-O;F9I9W5R:6YG('!H>7-I8V%L
M(&AO<W1I;F<@;VX@=&AE(&1O;6%I;BP@8VQI8VL@1FEN:7-H('1O(&%P<&QY
M(&%L;"!C:&%N9V5S(&%N9"!E>&ET('1H92!W:7IA<F0N)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]N97=?7W=I>F%R9%]?,B]L
M:6UI=',G(#T^("=#;&EC:R!.97AT(#X^('1O('!R;V-E960@=&\@8V]N9FEG
M=7)I;F<@:&]S=&EN9R!F;W(@=&AE(&1O;6%I;BX@0VQI8VL@1FEN:7-H('1O
M(&%P<&QY(&1O;6%I;B!L:6UI=',@86YD(&5X:70@=&AE('=I>F%R9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7VYE=U]?=VEZ
M87)D7U\R7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E871E('1H92!D
M;VUA:6X@86YD('!R;V-E960@=&\@8V]N9FEG=7)I;F<@9&]M86EN(&QI;6ET
M<RX@0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@9&]M86EN('=I=&AO=70@
M:71S(&9U<G1H97(@8V]N9FEG=7)I;F<@86YD(&5X:70@=&AE('=I>F%R9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?
M7V1E<V-R:7!T:6]N)R`]/B`G0VAA;F=E('EO=7(@<&%S<W=O<F0@86YD('!E
M<G-O;F%L(&EN9F\L('-E="!U<"!#4"!A<'!E87)A;F-E(&%N9"!V:65W('EO
M=7(@<&5R;6ES<VEO;G,N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M<')O<&5R=&EE<U]S96QF7U]D;VYE)R`]/B`G4')O<&5R=&EE<R!O9B!Y;W5R
M(&1O;6%I;B!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]P<F]P97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G
M1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I
M;B]P<F]P97)T:65S7W-E;&9?7W1I=&QE)R`]/B`G161I="!M>2!A8V-O=6YT
M)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO<')O<&5R=&EE<U]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!D;VUA:6X@861M:6YI<W1R
M871O<B!A8V-O=6YT(&9O<B!A(&1O;6%I;BXG+`H@("`@("`@("=U:5]?8VQI
M96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]
M/B`G1&]M86EN('!R;W!E<G1I97,G+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G4V5T('5P(&1O
M;6%I;B!A9&UI;B!F;W(@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=3
M971T:6YG(%5P($1O;6%I;B!!9&UI;FES=')A=&]R($%C8V]U;G0G+`H@("`@
M("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S7W5N:VYO=VY?7W=I
M>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L96-T(&$@9&]M86EN(&9O<B!W:&EC
M:"!Y;W4@=V%N="!T;R!S970@=7`@9&]M86EN(&%D;6EN:7-T<F%T;W(@86-C
M;W5N="XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]P<F]P97)T:65S
M7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W:71H('-P96-I
M9GEI;F<@<')O<&5R=&EE<R!O9B!D;VUA:6X@861M:6YI<W1R871O<B!A8V-O
M=6YT+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T
M:&4@=VEZ87)D+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W!R;W!E
M<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S7W-E;&8G(#T^("=7:&5N(&1O;F4@
M=VET:"!S<&5C:69Y:6YG('!R;W!E<G1I97,@;V8@9&]M86EN(&%D;6EN:7-T
M<F%T;W(@86-C;W5N="P@8VQI8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,@
M86YD(&5X:70@=&AE('=I>F%R9"XG+`H*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO=&]G9VQE7V1I<V%B;&5?7V1E<V-R:7!T:6]N)R`]/B`G1&ES86)L
M92!D;VUA:6X@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO=&]G
M9VQE7V1I<V%B;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@9&ES
M86)L960N)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO=&]G9VQE7V1I
M<V%B;&5?7W-H;W)T+71I=&QE)R`]/B`G1&ES86)L92<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O9&]M86EN+W1O9V=L95]D:7-A8FQE7U]T:71L92<@/3X@)T1I
M<V%B;&4@9&]M86EN("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]D;VUA:6XO
M=&]G9VQE7V5N86)L95]?9&5S8W)I<'1I;VXG(#T^("=%;F%B;&4@9&]M86EN
M("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L95]E;F%B
M;&5?7V1O;F4G(#T^("=$;VUA:6X@)3$@:&%S(&)E96X@96YA8FQE9"XG+`H@
M("`@("`@("=U:5]?8VQI96YT+V1O;6%I;B]T;V=G;&5?96YA8FQE7U]S:&]R
M="UT:71L92<@/3X@)T5N86)L92<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M
M86EN+W1O9V=L95]E;F%B;&5?7W1I=&QE)R`]/B`G16YA8FQE(&1O;6%I;B`E
M,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L95]U;FMN;W=N
M7U]D97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE(&$@9&]M86EN
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O9&]M86EN+W1O9V=L95]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)T5N86)L92]D:7-A8FQE)RP*("`@("`@("`G
M=6E?7V-L:65N="]D;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G
M16YA8FQE+T1I<V%B;&4@9&]M86EN)RP*("`@("`@("`G=6E?7V-L:65N="]D
M;VUA:6XO=&]G9VQE7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)T5N86)L
M:6YG+T1I<V%B;&EN9R!$;VUA:6XG+`H@("`@("`@("=U:5]?8VQI96YT+V1O
M;6%I;B]T;V=G;&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=3
M96QE8W0@=VAI8V@@9&]M86EN('EO=2!W86YT('1O(&5N86)L92!O<B!D:7-A
M8FQE+B<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VUP86YY
M+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&%N>2!N86UE(&]F(&-L:65N
M="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VUP86YY
M+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&%N>2!N86UE)RP*("`@("`@
M("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]M<&%N>2UN86UE7U]T:71L92<@
M/3X@)T-O;7!A;GD@;F%M92!O9B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?
M8VQI96YT+VEN9&EC871O<BUC;VUP86YY+6YA;65?<V5L9E]?9&5S8W)I<'1I
M;VXG(#T^("=9;W5R(&-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O:6YD:6-A=&]R+6-O;7!A;GDM;F%M95]S96QF7U]S:&]R="UT:71L92<@
M/3X@)T-O;7!A;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6-O;7!A;GDM;F%M95]S96QF7U]T:71L92<@/3X@)UEO=7(@8V]M<&%N
M>2!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]M<&%N
M>2UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&%N>2!N86UE
M(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R
M+6-O;7!A;GDM;F%M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-O;7!A
M;GD@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O;7!A
M;GDM;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;7!A;GD@;F%M92!O9B!A
M(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VYT
M86-T+6YA;65?7V1E<V-R:7!T:6]N)R`]/B`G0V]N=&%C="!N86UE(&]F(&-L
M:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUC;VYT
M86-T+6YA;65?7W-H;W)T+71I=&QE)R`]/B`G0V]N=&%C="!N86UE)RP*("`@
M("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]N=&%C="UN86UE7U]T:71L
M92<@/3X@)T-O;G1A8W0@;F%M92!O9B!C;&EE;G0@)3$G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUC;VYT86-T+6YA;65?<V5L9E]?9&5S8W)I
M<'1I;VXG(#T^("=9;W5R(&-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]S:&]R="UT:71L
M92<@/3X@)T-O;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6-O;G1A8W0M;F%M95]S96QF7U]T:71L92<@/3X@)UEO=7(@8V]N
M=&%C="!N86UE)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M8V]N
M=&%C="UN86UE7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G0V]N=&%C="!N
M86UE(&]F(&$@8VQI96YT+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6-O;G1A8W0M;F%M95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)T-O
M;G1A8W0@;F%M92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6-O
M;G1A8W0M;F%M95]U;FMN;W=N7U]T:71L92<@/3X@)T-O;G1A8W0@;F%M92!O
M9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD
M:7-K+7-P86-E+6QI;6ET+75S86=E7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@
M<W!A8V4@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7U]S
M:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A9V4G+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S
M86=E7U]T:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A9V4@9F]R(&-L
M:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+61I<VLM
M<W!A8V4M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R
M(&1I<VL@<W!A8V4@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T
M+71I=&QE)R`]/B`G1&ES:R!S<&%C92!L:6UI="!U<V%G92<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O:6YD:6-A=&]R+61I<VLM<W!A8V4M;&EM:70M=7-A9V5?
M<V5L9E]?=&ET;&4G(#T^("=9;W5R(&1I<VL@<W!A8V4@;&EM:70@=7-A9V4G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI
M;6ET+75S86=E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G1&ES:R!S<&%C
M92!L:6UI="!U<V%G92!F;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M9&ES:RUS<&%C92UL:6UI="UU<V%G95]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)T1I<VL@<W!A8V4@;&EM:70@=7-A9V4G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUD:7-K+7-P86-E+6QI;6ET
M+75S86=E7W5N:VYO=VY?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!L:6UI="!U
M<V%G92!F;W(@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]I;F1I
M8V%T;W(M96UA:6Q?7V1E<V-R:7!T:6]N)R`]/B`G16UA:6P@861D<F5S<R!O
M9B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M96UA:6Q?7W-H;W)T+71I=&QE)R`]/B`G16UA:6P@861D<F5S<R<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+65M86EL7U]T:71L92<@/3X@)T5M
M86EL(&%D9')E<W,@;V8@8VQI96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M96UA:6Q?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R
M(&5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUE;6%I;%]S96QF7U]S:&]R="UT:71L92<@/3X@)T5M86EL(&%D9')E<W,G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUE;6%I;%]S96QF7U]T
M:71L92<@/3X@)UEO=7(@96UA:6P@861D<F5S<R<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+65M86EL7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]
M/B`G16UA:6P@861D<F5S<R!O9B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?
M8VQI96YT+VEN9&EC871O<BUE;6%I;%]U;FMN;W=N7U]S:&]R="UT:71L92<@
M/3X@)T5M86EL(&%D9')E<W,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUE;6%I;%]U;FMN;W=N7U]T:71L92<@/3X@)T5M86EL(&%D9')E<W,@
M;V8@82!C;&EE;G0G+`H*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M
M9G5L;"US=&%T=7-?7V1E<V-R:7!T:6]N)R`]/B`G0V]M<&QE=&4@<W1A='5S
M(&9O<B!C;&EE;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M9G5L;"US=&%T=7-?7W-H;W)T+71I=&QE)R`]/B`G0V]M<&QE=&4@<W1A
M='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T
M=7-?7W1I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S(&9O<B!C;&EE;G0@)3$G
M+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL+7-T871U<U]S
M96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@8V]M<&QE=&4@<W1A='5S)RP*
M("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?<V5L
M9E]?<VAO<G0M=&ET;&4G(#T^("=#;VUP;&5T92!S=&%T=7,G+`H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUF=6QL+7-T871U<U]S96QF7U]T:71L
M92<@/3X@)UEO=7(@8V]M<&QE=&4@<W1A='5S)RP*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK;F]W;E]?9&5S8W)I<'1I
M;VXG(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+69U;&PM<W1A='5S7W5N:VYO=VY?
M7W-H;W)T+71I=&QE)R`]/B`G0V]M<&QE=&4@<W1A='5S)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M9G5L;"US=&%T=7-?=6YK;F]W;E]?=&ET
M;&4G(#T^("=#;VUP;&5T92!S=&%T=7,@9F]R(&$@8VQI96YT)RP*"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S
M86=E7U]D97-C<FEP=&EO;B<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U
M<V%G92!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7U]S:&]R="UT:71L92<@
M/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7U]T
M:71L92<@/3X@)TUA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92!F;W(@8VQI
M96YT("4Q)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+61O
M;6%I;G,M;&EM:70M=7-A9V5?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R
M(&UA>&EM=6T@9&]M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W-E;&9?
M7W-H;W)T+71I=&QE)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+61O;6%I;G,M
M;&EM:70M=7-A9V5?<V5L9E]?=&ET;&4G(#T^("=9;W5R(&UA>&EM=6T@9&]M
M86EN<R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A
M=&]R+6UA>"UD;VUA:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7V1E<V-R:7!T
M:6]N)R`]/B`G36%X:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E(&9O<B!A(&-L
M:65N="<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UD;VUA
M:6YS+6QI;6ET+75S86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G36%X
M:6UU;2!D;VUA:6YS(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N
M="]I;F1I8V%T;W(M;6%X+61O;6%I;G,M;&EM:70M=7-A9V5?=6YK;F]W;E]?
M=&ET;&4G(#T^("=-87AI;75M(&1O;6%I;G,@;&EM:70@=7-A9V4@9F]R(&$@
M8VQI96YT)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA>"UM
M86EL8F]X97,M;&EM:70M=7-A9V5?7V1E<V-R:7!T:6]N)R`]/B`G36%X:6UU
M;2!M86EL8F]X97,@;&EM:70@=7-A9V4@9F]R(&-L:65N="`E,2XG+`H@("`@
M("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET
M+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI
M;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X
M+6UA:6QB;WAE<RUL:6UI="UU<V%G95]?=&ET;&4G(#T^("=-87AI;75M(&UA
M:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q)RP*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G
M95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@;6%X:6UU;2!M86EL8F]X
M97,@;&EM:70@=7-A9V4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S86=E7W-E;&9?7W-H;W)T+71I=&QE
M)R`]/B`G36%X:6UU;2!M86EL8F]X97,@;&EM:70@=7-A9V4G+`H@("`@("`@
M("=U:5]?8VQI96YT+VEN9&EC871O<BUM87@M;6%I;&)O>&5S+6QI;6ET+75S
M86=E7W-E;&9?7W1I=&QE)R`]/B`G66]U<B!M87AI;75M(&UA:6QB;WAE<R!L
M:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+6UA
M>"UM86EL8F]X97,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=-87AI;75M(&UA:6QB;WAE<R!L:6UI="!U<V%G92!F;W(@82!C;&EE
M;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB
M;WAE<RUL:6UI="UU<V%G95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)TUA
M>&EM=6T@;6%I;&)O>&5S(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M;6%X+6UA:6QB;WAE<RUL:6UI="UU<V%G95]U;FMN
M;W=N7U]T:71L92<@/3X@)TUA>&EM=6T@;6%I;&)O>&5S(&QI;6ET('5S86=E
M(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUS=&%T95]?9&5S8W)I<'1I;VXG(#T^("=3=&%T92!O9B!C;&EE;G0@)3$N
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?7W-H;W)T
M+71I=&QE)R`]/B`G4W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC
M871O<BUS=&%T95]?=&ET;&4G(#T^("=3=&%T92!O9B!C;&EE;G0@)3$G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T95]S96QF7U]D97-C
M<FEP=&EO;B<@/3X@)UEO=7(@<W1A=&4G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T95]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T871E
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?<V5L9E]?
M=&ET;&4G(#T^("=9;W5R('-T871E)RP*("`@("`@("`G=6E?7V-L:65N="]I
M;F1I8V%T;W(M<W1A=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=3=&%T
M92!O9B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUS=&%T95]U;FMN;W=N7U]S:&]R="UT:71L92<@/3X@)U-T871E)RP*("`@
M("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A=&5?=6YK;F]W;E]?=&ET
M;&4G(#T^("=3=&%T92!O9B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?9&5S8W)I<'1I;VXG(#T^
M("=$971A:6QE9"!S=&%T=7,@9F]R(&-L:65N="`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?<VAO<G0M=&ET
M;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]?=&ET;&4G(#T^("=$971A:6QE
M9"!S=&%T=7,@9F]R(&-L:65N="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:6YD:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7V1E<V-R:7!T:6]N)R`]
M/B`G66]U<B!D971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]S96QF7U]S:&]R="UT:71L92<@
M/3X@)T1E=&%I;&5D('-T871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+7-T871U<RUD971A:6QS7W-E;&9?7W1I=&QE)R`]/B`G66]U<B!D
M971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O
M<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T1E
M=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L
M:65N="]I;F1I8V%T;W(M<W1A='5S+61E=&%I;'-?=6YK;F]W;E]?<VAO<G0M
M=&ET;&4G(#T^("=$971A:6QE9"!S=&%T=7,G+`H@("`@("`@("=U:5]?8VQI
M96YT+VEN9&EC871O<BUS=&%T=7,M9&5T86EL<U]U;FMN;W=N7U]T:71L92<@
M/3X@)T1E=&%I;&5D('-T871U<R!F;W(@82!C;&EE;G0G+`H*("`@("`@("`G
M=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A='5S7U]D97-C<FEP=&EO;B<@/3X@
M)U-T871U<R!F;W(@8VQI96YT("4Q+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M:6YD:6-A=&]R+7-T871U<U]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?7W1I=&QE)R`]
M/B`G4W1A='5S(&9O<B!C;&EE;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT
M+VEN9&EC871O<BUS=&%T=7-?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=9;W5R
M('-T871U<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U
M<U]S96QF7U]S:&]R="UT:71L92<@/3X@)U-T871U<R<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O:6YD:6-A=&]R+7-T871U<U]S96QF7U]T:71L92<@/3X@)UEO
M=7(@<W1A='5S)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M<W1A
M='5S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4W1A='5S(&9O<B!A(&-L
M:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=3=&%T=7,G+`H@("`@("`@("=U
M:5]?8VQI96YT+VEN9&EC871O<BUS=&%T=7-?=6YK;F]W;E]?=&ET;&4G(#T^
M("=3=&%T=7,@9F]R(&$@8VQI96YT)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O
M:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?7V1E<V-R:7!T:6]N)R`]
M/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?
M7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?
M7W1I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U<V%G92!F;W(@8VQI96YT("4Q
M)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T;W(M=')A9F9I8RUL:6UI
M="UU<V%G95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)UEO=7(@=')A9F9I8R!L
M:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R
M869F:6,M;&EM:70M=7-A9V5?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=4<F%F
M9FEC(&QI;6ET('5S86=E)RP*("`@("`@("`G=6E?7V-L:65N="]I;F1I8V%T
M;W(M=')A9F9I8RUL:6UI="UU<V%G95]S96QF7U]T:71L92<@/3X@)UEO=7(@
M=')A9F9I8R!L:6UI="!U<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD
M:6-A=&]R+71R869F:6,M;&EM:70M=7-A9V5?=6YK;F]W;E]?9&5S8W)I<'1I
M;VXG(#T^("=4<F%F9FEC(&QI;6ET('5S86=E(&9O<B!A(&-L:65N="XG+`H@
M("`@("`@("=U:5]?8VQI96YT+VEN9&EC871O<BUT<F%F9FEC+6QI;6ET+75S
M86=E7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G5')A9F9I8R!L:6UI="!U
M<V%G92<L"B`@("`@("`@)W5I7U]C;&EE;G0O:6YD:6-A=&]R+71R869F:6,M
M;&EM:70M=7-A9V5?=6YK;F]W;E]?=&ET;&4G(#T^("=4<F%F9FEC(&QI;6ET
M('5S86=E(&9O<B!A(&-L:65N="<L"@H@("`@("`@("=U:5]?8VQI96YT+VEP
M+7!O;VQ?7V1E<V-R:7!T:6]N)R`]/B`G061D+U)E;6]V92!)4"!A9&1R97-S
M97,@86YD(&%S<VEG;B!34TP@8V5R=&EF:6-A=&5S(&9O<B!C;&EE;G0@)3$N
M)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L7U]S:&]R="UT:71L92<@
M/3X@)TE0('!O;VPG+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VQ?7W1I
M=&QE)R`]/B`G0VQI96YT("4Q($E0('!O;VPG+`H@("`@("`@("=U:5]?8VQI
M96YT+VEP+7!O;VQ?<V5L9E]?9&5S8W)I<'1I;VXG(#T^("=6:65W('EO=7(@
M25`@<&]O;"XG+`H@("`@("`@("=U:5]?8VQI96YT+VEP+7!O;VQ?<V5L9E]?
M<VAO<G0M=&ET;&4G(#T^("=)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N
M="]I<"UP;V]L7W-E;&9?7W1I=&QE)R`]/B`G37D@25`@<&]O;"<L"@H@("`@
M("`@("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?9&5S8W)I<'1I
M;VXG(#T^("=3970@=7`@25`@<&]O;"!F;W(@8VQI96YT("4Q+B<L"B`@("`@
M("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7U]D;VYE)R`]/B`G
M0VQI96YT("4Q($E0('!O;VP@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@
M("=U:5]?8VQI96YT+VEP+7!O;VPO<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G
M(#T^("=)4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L+W!R
M;W!E<G1I97-?7W1I=&QE)R`]/B`G4V5T('5P($E0('!O;VP@9F]R(&-L:65N
M="`E,2<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S
M7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G5FEE=R!Y;W5R($E0('!O;VPN)RP*
M("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L+W!R;W!E<G1I97-?<V5L9E]?
M9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P
M97)T:65S7W-E;&9?7W-H;W)T+71I=&QE)R`]/B`G37D@25`@<&]O;"<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W-E;&9?7W1I
M=&QE)R`]/B`G37D@25`@<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M
M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G061D
M+U)E;6]V92!)4"!A9&1R97-S97,@=&\O9G)O;2!C;&EE;G0@25`@<&]O;"P@
M86YD(&UA;F%G92!34TP@8V5R=&EF:6-A=&5S+B<L"B`@("`@("`@)W5I7U]C
M;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE
M)R`]/B`G25`@<&]O;"<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W1I=&QE)R`]/B`G4V5T('5P(&-L:65N="!)
M4"!P;V]L)RP*("`@("`@("`G=6E?7V-L:65N="]I<"UP;V]L+W!R;W!E<G1I
M97-?=6YK;F]W;E]?=VEZ87)D+71I=&QE)R`]/B`G0VQI96YT($E0(%!O;VP@
M0V]N9FEG=7)A=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,5]U;FMN;W=N)R`]/B`G4V5L
M96-T(&$@8VQI96YT('=H;W-E($E0('!O;VP@>6]U('=A;G0@=&\@8V]N9FEG
M=7)E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O:7`M<&]O;"]P<F]P97)T:65S
M7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)U=H96X@9&]N92!W:71H(&5D:71I
M;F<@=&AE(&-L:65N="!)4"!P;V]L+"!C;&EC:R!&:6YI<V@@=&\@87!P;'D@
M8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@("`@("=U:5]?
M8VQI96YT+VQI;6ET<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W(&]R(&5D:70@
M;&EM:71S(&]F(&-L:65N="`E,2XG+`H@("`@("`@("=U:5]?8VQI96YT+VQI
M;6ET<U]?9&]N92<@/3X@)TQI;6ET<R!O9B!C;&EE;G0@)3$@:&%V92!B965N
M('5P9&%T960N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI='-?7W-H;W)T
M+71I=&QE)R`]/B`G3&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?7W1I=&QE)R`]/B`G5FEE=R!O<B!E9&ET(&QI;6ET<R!O9B!C;&EE;G0@
M)3$G+`H@("`@("`@("=U:5]?8VQI96YT+VQI;6ET<U]S96QF7U]D97-C<FEP
M=&EO;B<@/3X@)U9I97<@;7D@;&EM:71S+B<L"B`@("`@("`@)W5I7U]C;&EE
M;G0O;&EM:71S7W-E;&9?7V1O;F4G(#T^("<G+`H@("`@("`@("=U:5]?8VQI
M96YT+VQI;6ET<U]S96QF7U]S:&]R="UT:71L92<@/3X@)TQI;6ET<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O;&EM:71S7W-E;&9?7W1I=&QE)R`]/B`G5FEE
M=R!M>2!L:6UI=',G+`H@("`@("`@("=U:5]?8VQI96YT+VQI;6ET<U]U;FMN
M;W=N7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I="!L:6UI=',@;V8@
M82!C;&EE;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI='-?=6YK;F]W
M;E]?<VAO<G0M=&ET;&4G(#T^("=,:6UI=',G+`H@("`@("`@("=U:5]?8VQI
M96YT+VQI;6ET<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<@;W(@961I="!L
M:6UI=',@;V8@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI96YT+VQI;6ET
M<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=6:65W:6YG(&]R(&5D:71I
M;F<@82!C;&EE;G0@;&EM:71S)RP*("`@("`@("`G=6E?7V-L:65N="]L:6UI
M='-?=6YK;F]W;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=0;&5A<V4@<V5L
M96-T(&$@8VQI96YT('=H;W-E(&QI;6ET<R!T;R!V:65W(&]R(&5D:70N)RP*
M("`@("`@("`G=6E?7V-L:65N="]L:6UI='-?=6YK;F]W;E]?=VEZ87)D7U\R
M)R`]/B`G069T97(@961I=&EN9R!T:&4@8VQI96YT(&QI;6ET<RP@8VQI8VL@
M1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O;&EM:71S7W5N:VYO=VY?
M7W=I>F%R9%]?,E]S96QF)R`]/B`G069T97(@=FEE=VEN9R!Y;W5R(&QI;6ET
M<RP@8VQI8VL@1FEN:7-H+B<L"@H@("`@("`@("=U:5]?8VQI96YT+W!E<FUI
M<W-I;VYS7U]D97-C<FEP=&EO;B<@/3X@)U9I97<@;W(@961I="!P97)M:7-S
M:6]N<R!F;W(@8VQI96YT(&%C8V]U;G0@)3$N)RP*("`@("`@("`G=6E?7V-L
M:65N="]P97)M:7-S:6]N<U]?9&]N92<@/3X@)U!E<FUI<W-I;VYS(&]F(&-L
M:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?8VQI
M96YT+W!E<FUI<W-I;VYS7U]S:&]R="UT:71L92<@/3X@)U!E<FUI<W-I;VYS
M)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]?=&ET;&4G(#T^
M("=#;&EE;G0@)3$@<&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI96YT
M+W!E<FUI<W-I;VYS7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G5FEE=R!Y;W5R
M('!E<FUI<W-I;VYS+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R;6ES<VEO
M;G-?<V5L9E]?9&]N92<@/3X@)R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R
M;6ES<VEO;G-?<V5L9E]?<VAO<G0M=&ET;&4G(#T^("=097)M:7-S:6]N<R<L
M"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R;6ES<VEO;G-?<V5L9E]?=&ET;&4G
M(#T^("=->2!P97)M:7-S:6]N<R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<&5R
M;6ES<VEO;G-?=6YK;F]W;E]?9&5S8W)I<'1I;VXG(#T^("=6:65W(&]R(&5D
M:70@<&5R;6ES<VEO;G,@9F]R(&$@8VQI96YT(&%C8V]U;G0N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]S:&]R="UT:71L
M92<@/3X@)U!E<FUI<W-I;VYS)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M
M:7-S:6]N<U]U;FMN;W=N7U]T:71L92<@/3X@)U9I97<O161I="!C;&EE;G0@
M<&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI96YT+W!E<FUI<W-I;VYS
M7W5N:VYO=VY?7W=I>F%R9"UT:71L92<@/3X@)U9I97=I;F<O161I=&EN9R!#
M;&EE;G0@4&5R;6ES<VEO;G,G+`H@("`@("`@("=U:5]?8VQI96YT+W!E<FUI
M<W-I;VYS7W5N:VYO=VY?7W=I>F%R9%]?,2]P<F]P97)T:65S7W-E;&8G(#T^
M("=7:&5N(&1O;F4@=VET:"!V:65W:6YG('EO=7(@<&5R;6ES<VEO;G,L(&-L
M:6-K($9I;FES:"!T;R!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E>&ET('1H92!W
M:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN
M;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-L:65N="!W
M:&]S92!P97)M:7-S:6]N<R!Y;W4@=V%N="!T;R!V:65W+V5D:70N)RP*("`@
M("`@("`G=6E?7V-L:65N="]P97)M:7-S:6]N<U]U;FMN;W=N7U]W:7IA<F1?
M7S(G(#T^("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C;&EE;G0@<&5R
M;6ES<VEO;G,L(&-L:6-K($9I;FES:"!T;R!A<'!L>2!C:&%N9V5S(&%N9"!E
M>&ET('1H92!W:7IA<F0N)RP*"B`@("`@("`@)W5I7U]C;&EE;G0O<')E9F5R
M96YC97-?7V1E<V-R:7!T:6]N)R`]/B`G161I="!S97-S:6]N(&%N9"!I;G1E
M<F9A8V4@<')E9F5R96YC97,@9F]R(&-L:65N="`E,2XG+`H@("`@("`@("=U
M:5]?8VQI96YT+W!R969E<F5N8V5S7U]D;VYE)R`]/B`G4')E9F5R96YC97,@
M9F]R(&-L:65N="`E,2!H879E(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U
M:5]?8VQI96YT+W!R969E<F5N8V5S7U]S:&]R="UT:71L92<@/3X@)U!R969E
M<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]?=&ET
M;&4G(#T^("=#;&EE;G0@)3$@<')E9F5R96YC97,G+`H@("`@("`@("=U:5]?
M8VQI96YT+W!R969E<F5N8V5S7W-E;&9?7V1E<V-R:7!T:6]N)R`]/B`G161I
M="!Y;W5R('-E<W-I;VX@86YD(&EN=&5R9F%C92!P<F5F97)E;F-E<R<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O<')E9F5R96YC97-?<V5L9E]?9&]N92<@/3X@
M)UEO=7(@<')E9F5R96YC97,@:&%V92!B965N('5P9&%T960N)RP*("`@("`@
M("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]S96QF7U]S:&]R="UT:71L92<@
M/3X@)TUY('!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7V-L:65N="]P<F5F
M97)E;F-E<U]S96QF7U]T:71L92<@/3X@)TUY('!R969E<F5N8V5S)RP*("`@
M("`@("`G=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N7U]D97-C<FEP
M=&EO;B<@/3X@)T5D:70@0U`@<V5S<VEO;B!A;F0@:6YT97)F86-E('!R969E
M<F5N8V5S(&9O<B!A(&-L:65N="XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R
M969E<F5N8V5S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')E9F5R96YC
M97,G+`H@("`@("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?
M7W1I=&QE)R`]/B`G161I="!C;&EE;G0@<')E9F5R96YC97,G+`H@("`@("`@
M("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W=I>F%R9"UT:71L
M92<@/3X@)T5D:71I;F<@0VQI96YT(%!R969E<F5N8V5S)RP*("`@("`@("`G
M=6E?7V-L:65N="]P<F5F97)E;F-E<U]U;FMN;W=N7U]W:7IA<F1?7S%?=6YK
M;F]W;B<@/3X@)U-E;&5C="!C;&EE;G0@=VAO<V4@<V5S<VEO;B!A;F0@:6YT
M97)F86-E('!R969E<F5N8V5S('EO=2!W86YT('1O(&UA;F%G92XG+`H@("`@
M("`@("=U:5]?8VQI96YT+W!R969E<F5N8V5S7W5N:VYO=VY?7W=I>F%R9%]?
M,B<@/3X@)T%F=&5R(&5D:71I;F<@=&AE(&-L:65N="!P<F5F97)E;F-E<RP@
M8VQI8VL@1FEN:7-H+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')E9F5R96YC
M97-?=6YK;F]W;E]?=VEZ87)D7U\R7W-E;&8G(#T^("=!9G1E<B!E9&ET:6YG
M('EO=7(@<')E9F5R96YC97,L(&-L:6-K($9I;FES:"XG+`H*("`@("`@("`G
M=6E?7V-L:65N="]P<F]P97)T:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@
M<&5R<V]N86P@:6YF;W)M871I;VX@;V8@8VQI96YT("4Q+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?9&]N92<@/3X@)U!E<G-O;F%L(&EN
M9F]R;6%T:6]N(&]F(&-L:65N="`E,2!H87,@8F5E;B!U<&1A=&5D+B<L"B`@
M("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^
M("=097)S;VYA;"!I;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O
M<')O<&5R=&EE<U]?=&ET;&4G(#T^("=#;&EE;G0@)3$@<&5R<V]N86P@:6YF
M;R<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N97<M861H;V-?
M7W=I>F%R9%]?,5]N97<G(#T^("=4:&4@8VQI96YT(&%C8V]U;G0@=VEL;"!B
M92!C<F5A=&5D(&EM;65D:6%T96QY(&%F=&5R('EO=2!C;&EC:R!.97AT(#X^
M+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]N97=?7V1E<V-R
M:7!T:6]N)R`]/B`G0W)E871E(&YE=R!C;&EE;G0@86-C;W5N="XG+`H@("`@
M("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G0VQI
M96YT("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G=6E?7V-L:65N
M="]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4@8VQI
M96YT)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7VYE=U]?=&ET
M;&4G(#T^("=#<F5A=&4@8VQI96YT)RP*("`@("`@("`G=6E?7V-L:65N="]P
M<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]/B`G0VQI96YT($-R96%T
M:6]N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7VYE=U]?=VEZ
M87)D7U\Q+VEP+7!O;VPO<')O<&5R=&EE<R<@/3X@)U=H96X@9&]N92!W:71H
M(&-O;F9I9W5R:6YG('1H92!C;&EE;G0@25`@<&]O;"P@8VQI8VL@1FEN:7-H
M('1O(&-O;7!L971E+B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE
M<U]N97=?7W=I>F%R9%]?,2]L:6UI=',G(#T^("=#;&EC:R!.97AT(#X^('1O
M('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT('!E<FUI<W-I;VYS+B!#
M;&EC:R!&:6YI<V@@=&\@87!P;'D@=&AE(&QI;6ET<R!A;F0@97AI="!T:&ES
M('=I>F%R9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?;F5W
M7U]W:7IA<F1?7S$O<&5R;6ES<VEO;G,G(#T^("=#;&EC:R!.97AT(#X^('1O
M('!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT($E0('!O;VPN($-L:6-K
M($9I;FES:"!T;R!A<'!L>2!T:&4@<&5R;6ES<VEO;G,@86YD(&5X:70@=&AI
M<R!W:7IA<F0N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7VYE
M=U]?=VEZ87)D7U\Q7VYE=R<@/3X@)T-L:6-K($YE>'0@/CX@=&\@8W)E871E
M('1H92!C;&EE;G0@86-C;W5N="!A;F0@<')O8V5E9"!T;R!C;VYF:6=U<FEN
M9R!R97-O=7)C92!U<V%G92!L:6UI=',N($-L:6-K($9I;FES:"!T;R!C<F5A
M=&4@=&AE(&%C8V]U;G0@=VET:&]U="!I=',@9G5R=&AE<B!C;VYF:6=U<FEN
M9RXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?<V5L9E]?9&5S
M8W)I<'1I;VXG(#T^("=%9&ET('EO=7(@<&5R<V]N86P@:6YF;W)M871I;VXN
M)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7W-E;&9?7V1O;F4G
M(#T^("=9;W5R('!E<G-O;F%L(&EN9F]R;6%T:6]N(&AA<R!B965N('5P9&%T
M960N)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T:65S7W-E;&9?7W-H
M;W)T+71I=&QE)R`]/B`G37D@<&5R<V]N86P@:6YF;W)M871I;VXG+`H@("`@
M("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?<V5L9E]?=&ET;&4G(#T^("=-
M>2!P97)S;VYA;"!I;F9O)RP*("`@("`@("`G=6E?7V-L:65N="]P<F]P97)T
M:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G161I="!A(&-L:65N="!P
M97)S;VYA;"!I;F9O<FUA=&EO;BXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R
M;W!E<G1I97-?=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=097)S;VYA;"!I
M;F9O<FUA=&EO;B<L"B`@("`@("`@)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]U
M;FMN;W=N7U]T:71L92<@/3X@)T5D:70@8VQI96YT('!E<G-O;F%L(&EN9F\G
M+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ
M87)D+71I=&QE)R`]/B`G161I=&EN9R!#;&EE;G0@4&5R<V]N86P@26YF;W)M
M871I;VXG+`H@("`@("`@("=U:5]?8VQI96YT+W!R;W!E<G1I97-?=6YK;F]W
M;E]?=VEZ87)D7U\Q7W5N:VYO=VXG(#T^("=396QE8W0@8VQI96YT('=H;W-E
M('!E<G-O;F%L(&EN9F\@>6]U('=A;G0@=&\@8VAA;F=E+B<L"B`@("`@("`@
M)W5I7U]C;&EE;G0O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S(G(#T^
M("=7:&5N(&1O;F4@=VET:"!E9&ET:6YG('1H92!C;&EE;G0@:6YF;RP@8VQI
M8VL@1FEN:7-H('1O(&%P<&QY(&-H86YG97,N)RP*("`@("`@("`G=6E?7V-L
M:65N="]P<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]S96QF)R`]/B`G
M5VAE;B!D;VYE('=I=&@@961I=&EN9R!Y;W5R(&EN9F\L(&-L:6-K($9I;FES
M:"!T;R!A<'!L>2!C:&%N9V5S+B<L"@H@("`@("`@("=U:5]?8VQI96YT+W1O
M9V=L95]D:7-A8FQE7U]D97-C<FEP=&EO;B<@/3X@)T1I<V%B;&4@8VQI96YT
M(&%C8V]U;G0@)3$N)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?9&ES
M86)L95]?9&]N92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!D:7-A8FQE9"XG
M+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]D:7-A8FQE7U]S:&]R="UT
M:71L92<@/3X@)T1I<V%B;&4G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L
M95]D:7-A8FQE7U]T:71L92<@/3X@)T1I<V%B;&4@8VQI96YT("4Q)RP*("`@
M("`@("`G=6E?7V-L:65N="]T;V=G;&5?96YA8FQE7U]D97-C<FEP=&EO;B<@
M/3X@)T5N86)L92!C;&EE;G0@86-C;W5N="`E,2XG+`H@("`@("`@("=U:5]?
M8VQI96YT+W1O9V=L95]E;F%B;&5?7V1O;F4G(#T^("=#;&EE;G0@)3$@:&%S
M(&)E96X@96YA8FQE9"XG+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]E
M;F%B;&5?7W-H;W)T+71I=&QE)R`]/B`G16YA8FQE)RP*("`@("`@("`G=6E?
M7V-L:65N="]T;V=G;&5?96YA8FQE7U]T:71L92<@/3X@)T5N86)L92!C;&EE
M;G0@)3$G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]U;FMN;W=N7U]D
M97-C<FEP=&EO;B<@/3X@)T5N86)L92!O<B!D:7-A8FQE(&$@8VQI96YT(&%C
M8V]U;G0N)RP*("`@("`@("`G=6E?7V-L:65N="]T;V=G;&5?=6YK;F]W;E]?
M<VAO<G0M=&ET;&4G(#T^("=%;F%B;&4O9&ES86)L92<L"B`@("`@("`@)W5I
M7U]C;&EE;G0O=&]G9VQE7W5N:VYO=VY?7W1I=&QE)R`]/B`G16YA8FQE+T1I
M<V%B;&4@82!C;&EE;G0G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]U
M;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=%;F%B;&EN9R]$:7-A8FQI;F<@
M0VQI96YT($%C8V]U;G0G+`H@("`@("`@("=U:5]?8VQI96YT+W1O9V=L95]U
M;FMN;W=N7U]W:7IA<F1?7S%?=6YK;F]W;B<@/3X@)U-E;&5C="!A(&-L:65N
M="!A8V-O=6YT('EO=2!W86YT('1O(&5N86)L92]D:7-A8FQE+B<L"@H@("`@
M("`@("=U:5]?8W5S=&]M+6)U='1O;G-?7V1E<V-R:7!T:6]N)R`]/B`G4V5R
M=F5R+7=I9&4@8W5S=&]M(&)U='1O;G,N)RP*("`@("`@("`G=6E?7V-U<W1O
M;2UB=71T;VYS7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;2!B=71T;VYS)RP*
M("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS7U]T:71L92<@/3X@)U-E<G9E
M<BUW:61E(&-U<W1O;2!B=71T;VYS)RP*"B`@("`@("`@)W5I7U]C=7-T;VTM
M8G5T=&]N<R]C=7-T;VTM8G5T=&]N7U]N;VYE+6%V86EL86)L92<@/3X@)UEO
M=2!D;VY<)W0@8W5R<F5N=&QY(&AA=F4@86YY(&-U<W1O;2!B=71T;VYS+B<L
M"@H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D
M96QE=&5?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E('-E<G9E<BUW:61E(&-U
M<W1O;2!B=71T;VX@)3$N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS
M+V-U<W1O;2UB=71T;VXO9&5L971E7U]D;VYE)R`]/B`G4V5R=F5R+7=I9&4@
M8W5S=&]M(&)U='1O;B`E,2!H87,@8F5E;B!R96UO=F5D+B<L"B`@("`@("`@
M)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]?<VAO
M<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U
M='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?7W1I=&QE)R`]/B`G4F5M;W9E
M(&-U<W1O;2!B=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O
M;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W;E]?9&5S8W)I<'1I;VXG
M(#T^("=296UO=F4@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;BXG+`H@("`@
M("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?
M=6YK;F]W;E]?<VAO<G0M=&ET;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U
M:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D96QE=&5?=6YK;F]W
M;E]?=&ET;&4G(#T^("=296UO=F4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@
M)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+V1E;&5T95]U;FMN
M;W=N7U]W:7IA<F0M=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N(')E;6]V86PG
M+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]D
M96QE=&5?=6YK;F]W;E]?=VEZ87)D7U\R7W5N:VYO=VXG(#T^("=396QE8W0@
M=VAI8V@@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;B!Y;W4@=V%N="!T;R!R
M96UO=F4N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB
M=71T;VXO9&5L971E7W5N:VYO=VY?7W=I>F%R9%]?,R<@/3X@)T-O;F9I<FT@
M<F5M;W9I;F<@=&AE('-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VX@8GD@<V5L
M96-T:6YG('1H92!C:&5C:R!B;W@@86YD(&-L:6-K(&9I;FES:"!T;R!C;VUP
M;&5T96QY(')E;6]V92!I="!A;F0@97AI="!T:&4@=VEZ87)D+B<L"@H@("`@
M("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P97)T
M:65S7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@<')O<&5R=&EE<R!O9B!S97)V
M97(M=VED92!C=7-T;VT@8G5T=&]N("4Q+B<L"B`@("`@("`@)W5I7U]C=7-T
M;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?7V1O;F4G(#T^
M("=0<F]P97)T:65S(&]F(&-U<W1O;2!B=71T;VX@)3$@:&%V92!B965N('5P
M9&%T960N)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB
M=71T;VXO<')O<&5R=&EE<U]?<VAO<G0M=&ET;&4G(#T^("=0<F]P97)T:65S
M)RP*("`@("`@("`G=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO
M<')O<&5R=&EE<U]?=&ET;&4G(#T^("=-;V1I9GD@<V5R=F5R(&-U<W1O;2!B
M=71T;VX@)3$G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M
M+6)U='1O;B]P<F]P97)T:65S7VYE=U]?9&5S8W)I<'1I;VXG(#T^("=#<F5A
M=&4@;F5W('-E<G9E<BUW:61E(&-U<W1O;2!B=71T;VXN)RP*("`@("`@("`G
M=6E?7V-U<W1O;2UB=71T;VYS+V-U<W1O;2UB=71T;VXO<')O<&5R=&EE<U]N
M97=?7V1O;F4G(#T^("=#=7-T;VT@8G5T=&]N("4Q(&AA<R!B965N(&-R96%T
M960G+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7VYE=U]?<VAO<G0M=&ET;&4G(#T^("=#<F5A=&4G+`H@
M("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P
M97)T:65S7VYE=U]?=&ET;&4G(#T^("=#<F5A=&4@<V5R=F5R(&-U<W1O;2!B
M=71T;VXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U
M='1O;B]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I=&QE)R`]/B`G0W5S=&]M
M(&)U='1O;B!C<F5A=&EO;B<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N
M<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?;F5W7U]W:7IA<F1?7S)?;F5W
M)R`]/B`G0VQI8VL@1FEN:7-H('1O(&-R96%T92!T:&4@8W5S=&]M(&)U='1O
M;BXG+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O
M;B]P<F]P97)T:65S7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G161I="!P
M<F]P97)T:65S(&]F(&$@<V5R=F5R+7=I9&4@8W5S=&]M(&)U='1O;BXG+`H@
M("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P<F]P
M97)T:65S7W5N:VYO=VY?7W-H;W)T+71I=&QE)R`]/B`G4')O<&5R=&EE<R<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R
M;W!E<G1I97-?=6YK;F]W;E]?=&ET;&4G(#T^("=-;V1I9GD@<V5R=F5R+7=I
M9&4@8W5S=&]M(&)U='1O;B<L"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N
M<R]C=7-T;VTM8G5T=&]N+W!R;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D+71I
M=&QE)R`]/B`G36]D:69Y:6YG(%-E<G9E<BUW:61E($-U<W1O;2!"=71T;VXG
M+`H@("`@("`@("=U:5]?8W5S=&]M+6)U='1O;G,O8W5S=&]M+6)U='1O;B]P
M<F]P97)T:65S7W5N:VYO=VY?7W=I>F%R9%]?,E]U;FMN;W=N)R`]/B`G4V5L
M96-T('=H:6-H(&-U<W1O;2!B=71T;VX@>6]U('=A;G0@=&\@;6]D:69Y+B<L
M"B`@("`@("`@)W5I7U]C=7-T;VTM8G5T=&]N<R]C=7-T;VTM8G5T=&]N+W!R
M;W!E<G1I97-?=6YK;F]W;E]?=VEZ87)D7U\S)R`]/B`G5VAE;B!D;VYE('=I
M=&@@;6]D:69Y:6YG('1H92!S97)V97(M=VED92!C=7-T;VT@8G5T=&]N+"!C
M;&EC:R!&:6YI<V@@=&\@87!P;'D@8VAA;F=E<R!A;F0@97AI="!T:&4@=VEZ
M87)D+B<L"@H@("`@("`@("=U:5]?9&%S:&)O87)D(V-L:65N='-?7V1E<V-R
M:7!T:6]N)R`]/B`G3F\@9F%V;W)I=&4@8VQI96YT<R<L"B`@("`@("`@)W5I
M7U]D87-H8F]A<F0C8VQI96YT<U]?=&ET;&4G(#T^("=#;&EE;G1S)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-C=7-T;VTM8G5T=&]N<U]?=&ET;&4G(#T^
M("=#=7-T;VT@8G5T=&]N<R<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0C9&]M
M86EN<U]?9&5S8W)I<'1I;VXG(#T^("=.;R!F879O<FET92!D;VUA:6YS)RP*
M("`@("`@("`G=6E?7V1A<VAB;V%R9"-D;VUA:6YS7U]T:71L92<@/3X@)T1O
M;6%I;G,G+`H@("`@("`@("=U:5]?9&%S:&)O87)D(V9A=F]R:71E<R]T86)S
M7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O;&QO=VEN9R!T86)S(&EN
M($9A=F]R:71E<SHG+`H@("`@("`@("=U:5]?9&%S:&)O87)D(V9A=F]R:71E
M<U]?=&ET;&4G(#T^("=&879O<FET97,G+`H@("`@("`@("=U:5]?9&%S:&)O
M87)D(VEN9F\O9F]O=&5R7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O
M;&QO=VEN9R!B=71T;VYS(&EN('1H92!F;V]T97(Z)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-I;F9O7U]D97-C<FEP=&EO;B<@/3X@)U-H;W<@=&AE(&9O
M;&QO=VEN9R!I;F9O<FUA=&EO;CHG+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M(VEN9F]?7W1I=&QE)R`]/B`G4V5R=F5R($EN9F]R;6%T:6]N)RP*("`@("`@
M("`G=6E?7V1A<VAB;V%R9"-M86EL;F%M97-?7V1E<V-R:7!T:6]N)R`]/B`G
M3F\@9F%V;W)I=&4@;6%I;&YA;65S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R
M9"-M86EL;F%M97-?7W1I=&QE)R`]/B`G36%I;&YA;65S)RP*("`@("`@("`G
M=6E?7V1A<VAB;V%R9"-Q=6EC:RUS96%R8VA?7W1I=&QE)R`]/B`G475I8VL@
M<V5A<F-H)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-R96-E;G1?7V1E<V-R
M:7!T:6]N)R`]/B`G3F\@<F5C96YT('!A9V5S)RP*("`@("`@("`G=6E?7V1A
M<VAB;V%R9"-R96-E;G1?7W1I=&QE)R`]/B`G4F5C96YT)RP*("`@("`@("`G
M=6E?7V1A<VAB;V%R9"-S:&]R=&-U='-?7V1E<V-R:7!T:6]N)R`]/B`G3F\@
M<VAO<G1C=71S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"-S:&]R=&-U='-?
M7W1I=&QE)R`]/B`G4VAO<G1C=71S)RP*("`@("`@("`G=6E?7V1A<VAB;V%R
M9"-S=&%T:7-T:6-S+V9O;W1E<E]?9&5S8W)I<'1I;VXG(#T^("=3:&]W('1H
M92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@9F]O=&5R.B<L"B`@("`@("`@
M)W5I7U]D87-H8F]A<F0C<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=3
M:&]W('1H92!F;VQL;W=I;F<@:6YF;W)M871I;VXZ)RP*("`@("`@("`G=6E?
M7V1A<VAB;V%R9"-S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-T871I<W1I8W,G
M+`H@("`@("`@("=U:5]?9&%S:&)O87)D(W1O;VQS+V9O;W1E<E]?9&5S8W)I
M<'1I;VXG(#T^("=3:&]W('1H92!F;VQL;W=I;F<@8G5T=&]N<R!I;B!T:&4@
M9F]O=&5R.B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0C=&]O;'-?7V1E<V-R
M:7!T:6]N)R`]/B`G4VAO=R!T:&4@9F]L;&]W:6YG(&)U='1O;G,Z)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"-T;V]L<U]?=&ET;&4G(#T^("=4;V]L<R<L
M"B`@("`@("`@)W5I7U]D87-H8F]A<F1?7V1E<V-R:7!T:6]N)R`]/B`G061M
M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F1?
M7W-H;W)T+71I=&QE)R`]/B`G1&5S:W1O<"<L"B`@("`@("`@)W5I7U]D87-H
M8F]A<F1?7W1I=&QE)R`]/B`G061M:6YI<W1R871O<B!$97-K=&]P)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9%]S96QF7U]D97-C<FEP=&EO;B<@/3X@)TUY
M($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9%]S96QF7U]S:&]R
M="UT:71L92<@/3X@)T1E<VMT;W`G+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M7W-E;&9?7W1I=&QE)R`]/B`G37D@1&5S:W1O<"<L"@H@("`@("`@("=U:5]?
M9&%S:&)O87)D+V-U<W1O;6EZ95]?9&5S8W)I<'1I;VXG(#T^("=#=7-T;VUI
M>F4@061M:6YI<W1R871O<B!$97-K=&]P+B<L"B`@("`@("`@)W5I7U]D87-H
M8F]A<F0O8W5S=&]M:7IE7U]D;VYE)R`]/B`G061M:6X@1&5S:W1O<"!H87,@
M8F5E;B!U<&1A=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O8W5S=&]M
M:7IE7U]S:&]R="UT:71L92<@/3X@)T-U<W1O;6EZ92!$97-K=&]P)RP*("`@
M("`@("`G=6E?7V1A<VAB;V%R9"]C=7-T;VUI>F5?7W1I=&QE)R`]/B`G0W5S
M=&]M:7IE($%D;6EN($1E<VMT;W`G+`H@("`@("`@("=U:5]?9&%S:&)O87)D
M+V-U<W1O;6EZ95]S96QF7U]D97-C<FEP=&EO;B<@/3X@)T-U<W1O;6EZ92!Y
M;W5R($1E<VMT;W`N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]C=7-T;VUI
M>F5?<V5L9E]?9&]N92<@/3X@)UEO=7(@1&5S:W1O<"!H87,@8F5E;B!U<&1A
M=&5D+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O8W5S=&]M:7IE7W-E;&9?
M7W-H;W)T+71I=&QE)R`]/B`G0W5S=&]M:7IE($1E<VMT;W`G+`H@("`@("`@
M("=U:5]?9&%S:&)O87)D+V-U<W1O;6EZ95]S96QF7U]T:71L92<@/3X@)T-U
M<W1O;6EZ92!M>2!$97-K=&]P)RP*"B`@("`@("`@)W5I7U]D87-H8F]A<F0O
M<VAO<G1C=70O<')O<&5R=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET('-H
M;W)T8W5T("4Q+B<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O<VAO<G1C=70O
M<')O<&5R=&EE<U]?9&]N92<@/3X@)U-H;W)T8W5T("4Q(&AA<R!B965N('5P
M9&%T960N)RP*("`@("`@("`G=6E?7V1A<VAB;V%R9"]S:&]R=&-U="]P<F]P
M97)T:65S7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@("`@("=U:5]?
M9&%S:&)O87)D+W-H;W)T8W5T+W!R;W!E<G1I97-?7W1I=&QE)R`]/B`G161I
M="!S:&]R=&-U="`E,2<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O<VAO<G1C
M=70O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E(&YE
M=R!S:&]R=&-U="XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D+W-H;W)T8W5T
M+W!R;W!E<G1I97-?;F5W7U]D;VYE)R`]/B`G4VAO<G1C=70@)3$@:&%S(&)E
M96X@8W)E871E9"XG+`H@("`@("`@("=U:5]?9&%S:&)O87)D+W-H;W)T8W5T
M+W!R;W!E<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-R96%T92!S:&]R
M=&-U="<L"B`@("`@("`@)W5I7U]D87-H8F]A<F0O<VAO<G1C=70O<')O<&5R
M=&EE<U]N97=?7W1I=&QE)R`]/B`G0W)E871E(&YE=R!S:&]R=&-U="<L"@H@
M("`@("`@("=U:5]?:6YD:6-A=&]R+6-L:65N=',M;G5M8F5R7U]D97-C<FEP
M=&EO;B<@/3X@)TYU;6)E<B!O9B!C;&EE;G1S+B<L"B`@("`@("`@)W5I7U]I
M;F1I8V%T;W(M8VQI96YT<RUN=6UB97)?7W-H;W)T+71I=&QE)R`]/B`G3G5M
M8F5R(&]F(&-L:65N=',G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-L:65N
M=',M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!C;&EE;G1S)RP*"B`@
M("`@("`@)W5I7U]I;F1I8V%T;W(M8W!U7U]D97-C<FEP=&EO;B<@/3X@)T-0
M52XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P=5]?<VAO<G0M=&ET;&4G
M(#T^("=#4%4G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6-P=5]?=&ET;&4G
M(#T^("=#4%4G+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUD:7-K+75S86=E
M7U]D97-C<FEP=&EO;B<@/3X@)T1I<VL@<W!A8V4@=7-A9V4N)RP*("`@("`@
M("`G=6E?7VEN9&EC871O<BUD:7-K+75S86=E7U]S:&]R="UT:71L92<@/3X@
M)T1I<VL@<W!A8V4@=7-A9V4G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+61I
M<VLM=7-A9V5?7W1I=&QE)R`]/B`G1&ES:R!S<&%C92!U<V%G92<L"@H@("`@
M("`@("=U:5]?:6YD:6-A=&]R+61O;6%I;G,M;G5M8F5R7U]D97-C<FEP=&EO
M;B<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS+B<L"B`@("`@("`@)W5I7U]I;F1I
M8V%T;W(M9&]M86EN<RUN=6UB97)?7W-H;W)T+71I=&QE)R`]/B`G3G5M8F5R
M(&]F(&1O;6%I;G,G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+61O;6%I;G,M
M;G5M8F5R7U]T:71L92<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"B`@("`@
M("`@)W5I7U]I;F1I8V%T;W(M:&]S=&YA;65?7V1E<V-R:7!T:6]N)R`]/B`G
M2&]S=&YA;64N)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUH;W-T;F%M95]?
M<VAO<G0M=&ET;&4G(#T^("=(;W-T;F%M92<L"B`@("`@("`@)W5I7U]I;F1I
M8V%T;W(M:&]S=&YA;65?7W1I=&QE)R`]/B`G2&]S=&YA;64G+`H*("`@("`@
M("`G=6E?7VEN9&EC871O<BUL:6-E;G-E+65X<&ER871I;VY?7V1E<V-R:7!T
M:6]N)R`]/B`G3&EC96YS92!K97D@97AP:7)A=&EO;B!D871E+B<L"B`@("`@
M("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N7U]S:&]R="UT
M:71L92<@/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T92<L"B`@("`@
M("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UE>'!I<F%T:6]N7U]T:71L92<@
M/3X@)TQI8V5N<V4@:V5Y(&5X<&ER871I;VX@9&%T92<L"@H@("`@("`@("=U
M:5]?:6YD:6-A=&]R+6QI8V5N<V4M:V5Y+6ED7U]D97-C<FEP=&EO;B<@/3X@
M)TQI8V5N<V4@:V5Y(&YU;6)E<BXG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R
M+6QI8V5N<V4M:V5Y+6ED7U]S:&]R="UT:71L92<@/3X@)TQI8V5N<V4@:V5Y
M(&YU;6)E<B<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;&EC96YS92UK97DM
M:61?7W1I=&QE)R`]/B`G3&EC96YS92!K97D@;G5M8F5R)RP*"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M;&]A9"UA=F%R86=E7U]D97-C<FEP=&EO;B<@/3X@
M)T%V97)A9V4@;&]A9"XG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+6QO860M
M879A<F%G95]?<VAO<G0M=&ET;&4G(#T^("=!=F5R86=E(&QO860G+`H@("`@
M("`@("=U:5]?:6YD:6-A=&]R+6QO860M879A<F%G95]?=&ET;&4G(#T^("=!
M=F5R86=E(&QO860G+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUM96TM=7-A
M9V5?7V1E<V-R:7!T:6]N)R`]/B`G365M;W)Y('5S86=E+B<L"B`@("`@("`@
M)W5I7U]I;F1I8V%T;W(M;65M+75S86=E7U]S:&]R="UT:71L92<@/3X@)TUE
M;6]R>2!U<V%G92<L"B`@("`@("`@)W5I7U]I;F1I8V%T;W(M;65M+75S86=E
M7U]T:71L92<@/3X@)TUE;6]R>2!U<V%G92<L"@H@("`@("`@("=U:5]?:6YD
M:6-A=&]R+6]S7U]D97-C<FEP=&EO;B<@/3X@)T]P97)A=&EN9R!S>7-T96TN
M)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUO<U]?<VAO<G0M=&ET;&4G(#T^
M("=/<&5R871I;F<@<WES=&5M)RP*("`@("`@("`G=6E?7VEN9&EC871O<BUO
M<U]?=&ET;&4G(#T^("=/<&5R871I;F<@<WES=&5M)RP*"B`@("`@("`@)W5I
M7U]I;F1I8V%T;W(M=7!T:6UE7U]D97-C<FEP=&EO;B<@/3X@)U5P=&EM92XG
M+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+75P=&EM95]?<VAO<G0M=&ET;&4G
M(#T^("=5<'1I;64G+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+75P=&EM95]?
M=&ET;&4G(#T^("=5<'1I;64G+`H*("`@("`@("`G=6E?7VEN9&EC871O<BUV
M97)S:6]N7U]D97-C<FEP=&EO;B<@/3X@)U!L97-K('9E<G-I;VXN)RP*("`@
M("`@("`G=6E?7VEN9&EC871O<BUV97)S:6]N7U]S:&]R="UT:71L92<@/3X@
M)U!L97-K('9E<G-I;VXG+`H@("`@("`@("=U:5]?:6YD:6-A=&]R+79E<G-I
M;VY?7W1I=&QE)R`]/B`G4&QE<VL@=F5R<VEO;B<L"@H@("`@("`@("=U:5]?
M;&EC96YS95]?9&5S8W)I<'1I;VXG(#T^("=6:65W('EO=7(@;&EC96YS92!I
M;F9O+"!O<F1E<B!N97<@;&EC96YS92!K97DL(')E=')I979E(&%N9"!U<&QO
M860@8V]M;6]N(&%N9"!A9&1I=&EO;F%L(&QI8V5N<V4@:V5Y<RXG+`H@("`@
M("`@("=U:5]?;&EC96YS95]?<VAO<G0M=&ET;&4G(#T^("=,:6-E;G-E)RP*
M("`@("`@("`G=6E?7VQI8V5N<V5?7W1I=&QE)R`]/B`G36%N86=E(%!L97-K
M(&QI8V5N<V4G+`H*("`@("`@("`G=6E?7VYE=W,O9&ES;6ES<U]?9&5S8W)I
M<'1I;VXG(#T^("=#;&EC:R!T;R!C;VUP;&5T96QY(&-L;W-E('1H92!.97=S
M(&9R86UE+B!0;&5S:R!W:6QL(&YO="!S:&]W('1H:7,@9G)A;64@=6YT:6P@
M3F5W<R!A<G1I8VQE<R!A<F4@=7!D871E9"XG+`H@("`@("`@("=U:5]?;F5W
M<R]D:7-M:7-S7U]D;VYE)R`]/B`G4&QE<VL@3F5W<R!H879E(&)E96X@8VQO
M<V5D+B<L"B`@("`@("`@)W5I7U]N97=S+V1I<VUI<W-?7W1I=&QE)R`]/B`G
M0VQO<V4@;F5W<R<L"@H@("`@("`@("=U:5]?<V5R=F5R7U]D97-C<FEP=&EO
M;B<@/3X@)U-E<G9E<B!M86YA9V5M96YT+B<L"B`@("`@("`@)W5I7U]S97)V
M97)?7W-H;W)T+71I=&QE)R`]/B`G4V5R=F5R)RP*("`@("`@("`G=6E?7W-E
M<G9E<E]?=&ET;&4G(#T^("=397)V97(@;6%N86=E;65N="<L"@H@("`@("`@
M("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?7V1E<V-R:7!T:6]N)R`]/B`G
M57!D871E('EO=7(@8V]N=')O;"!P86YE;"!O<B!I=',@8V]M<&]N96YT<RXG
M+`H@("`@("`@("=U:5]?<V5R=F5R+V%U=&]I;G-T86QL97)?7W-H;W)T+71I
M=&QE)R`]/B`G57!D871E<B<L"B`@("`@("`@)W5I7U]S97)V97(O875T;VEN
M<W1A;&QE<E]?=&ET;&4G(#T^("=5<&1A=&5R)RP*"B`@("`@("`@)W5I7U]S
M97)V97(O:6YT97)F86-E7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!$97-K
M=&]P('!R97-E=',L(&EN=&5R9F%C92!T96UP;&%T97,L('-K:6YS(&%N9"!L
M;V-A;&5S+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E7U]S:&]R
M="UT:71L92<@/3X@)TEN=&5R9F%C92!P<F5F97)E;F-E<R<L"B`@("`@("`@
M)W5I7U]S97)V97(O:6YT97)F86-E7U]T:71L92<@/3X@)U-E="!U<"!S97)V
M97(@:6YT97)F86-E('!R969E<F5N8V5S)RP*"B`@("`@("`@)W5I7U]S97)V
M97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S7U]D97-C<FEP=&EO;B<@
M/3X@)TUA;F%G92!$97-K=&]P('!R97-E=',N)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W-H;W)T+71I=&QE
M)R`]/B`G1&5S:W1O<"!P<F5S971S)RP*("`@("`@("`G=6E?7W-E<G9E<B]I
M;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E='-?7W1I=&QE)R`]/B`G36%N86=E
M($1E<VMT;W`@<')E<V5T<R<L"@H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R
M9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?7V1E<V-R:7!T:6]N)R`]
M/B`G4F5M;W9E($1E<VMT;W`@<')E<V5T<RXG+`H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?7V1O;F4G
M(#T^("=396QE8W1E9"!D97-K=&]P('!R97-E=',@:&%V92!B965N(')E;6]V
M960N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D
M+7!R97-E=',O9&5L971E7U]S:&]R="UT:71L92<@/3X@)U)E;6]V92<L"B`@
M("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S
M+V1E;&5T95]?=&ET;&4G(#T^("=296UO=F4@1&5S:W1O<"!P<F5S971S)RP*
M("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E
M=',O9&5L971E7W5N:VYO=VY?7V1E<V-R:7!T:6]N)R`]/B`G4F5M;W9E(&$@
M1&5S:W1O<"!P<F5S970G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C
M92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?<VAO<G0M=&ET
M;&4G(#T^("=296UO=F4G+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C
M92]D87-H8F]A<F0M<')E<V5T<R]D96QE=&5?=6YK;F]W;E]?=&ET;&4G(#T^
M("=296UO=F4@82!$97-K=&]P('!R97-E="<L"@H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R
M=&EE<U]?9&5S8W)I<'1I;VXG(#T^("=%9&ET($1E<VMT;W`@<')E<V5T("4Q
M+B<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP
M<F5S971S+W!R97-E="]P<F]P97)T:65S7U]D;VYE)R`]/B`G1&5S:W1O<"!P
M<F5S970@)3$@:&%S(&)E96X@=7!D871E9"XG+`H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R
M=&EE<U]?<VAO<G0M=&ET;&4G(#T^("<E,2<L"B`@("`@("`@)W5I7U]S97)V
M97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T
M:65S7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P<F5S970@)3$G+`H@("`@
M("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P
M<F5S970O<')O<&5R=&EE<U]N97=?7V1E<V-R:7!T:6]N)R`]/B`G0W)E871E
M(&YE=R!$97-K=&]P('!R97-E="!B87-E9"!O;B!T:&4@<')E<V5T("4Q+B<L
M"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB;V%R9"UP<F5S
M971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?9&]N92<@/3X@)T1E<VMT;W`@
M<')E<V5T("4Q(&AA<R!B965N(&-R96%T960N)RP*("`@("`@("`G=6E?7W-E
M<G9E<B]I;G1E<F9A8V4O9&%S:&)O87)D+7!R97-E=',O<')E<V5T+W!R;W!E
M<G1I97-?;F5W7U]S:&]R="UT:71L92<@/3X@)T-O<'D@)3$G+`H@("`@("`@
M("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S
M970O<')O<&5R=&EE<U]N97=?7W1I=&QE)R`]/B`G0V]P>2!$97-K=&]P('!R
M97-E="`E,2<L"B`@("`@("`@)W5I7U]S97)V97(O:6YT97)F86-E+V1A<VAB
M;V%R9"UP<F5S971S+W!R97-E="]P<F]P97)T:65S7VYE=U]?=VEZ87)D+71I
M=&QE)R`]/B`G1&5S:W1O<"!0<F5S970@0W)E871I;VXG+`H@("`@("`@("=U
M:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O
M<')O<&5R=&EE<U]U;FMN;W=N7U]D97-C<FEP=&EO;B<@/3X@)T5D:70@82!$
M97-K=&]P('!R97-E="XG+`H@("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C
M92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N
M7U]S:&]R="UT:71L92<@/3X@)T5D:70G+`H@("`@("`@("=U:5]?<V5R=F5R
M+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R=&EE
M<U]U;FMN;W=N7U]T:71L92<@/3X@)T5D:70@1&5S:W1O<"!P<F5S970G+`H@
M("`@("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T
M<R]P<F5S970O<')O<&5R=&EE<U]U;FMN;W=N7U]W:7IA<F0M=&ET;&4G(#T^
M("=%9&ET:6YG(&$@1&5S:W1O<"!P<F5S970G+`H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]P<F5S970O<')O<&5R
M=&EE<U]U;FMN;W=N7U]W:7IA<F1?7S1?=6YK;F]W;B<@/3X@)U-E;&5C="!W
M:&EC:"!$97-K=&]P('!R97-E="!Y;W4@=V%N="!T;R!E9&ET+B<L"@H@("`@
M("`@("=U:5]?<V5R=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]U
M<&QO861?7V1E<V-R:7!T:6]N)R`]/B`G57!L;V%D($1E<VMT;W`@<')E<V5T
M<R!T;R!S97)V97(N)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E<F9A8V4O
M9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]D;VYE)R`]/B`G1&5S:W1O<"!P
M<F5S971S(&AA=F4@8F5E;B!U<&QO861E9"XG+`H@("`@("`@("=U:5]?<V5R
M=F5R+VEN=&5R9F%C92]D87-H8F]A<F0M<')E<V5T<R]U<&QO861?7W-H;W)T
M+71I=&QE)R`]/B`G57!L;V%D)RP*("`@("`@("`G=6E?7W-E<G9E<B]I;G1E
M<F9A8V4O9&%S:&)O87)D+7!R97-E=',O=7!L;V%D7U]T:71L92<@/3X@)U5P
M;&]A9"!$97-K=&]P('!R97-E=',G+`H*("`@("`@("`G=6E?7W-E<G9E<B]I
M<"UA9&1R97-S97-?7V1E<V-R:7!T:6]N)R`]/B`G061D($E0(&%D9')E<W-E
M<R!T;R!A;F0@<F5M;W9E(&9R;VT@=&AE(&YE='=O<FL@:6YT97)F86-E<RXG
M+`H@("`@("`@("=U:5]?<V5R=F5R+VEP+6%D9')E<W-E<U]?<VAO<G0M=&ET
M;&4G(#T^("=)4"!A9&1R97-S97,G+`H@("`@("`@("=U:5]?<V5R=F5R+VEP
M+6%D9')E<W-E<U]?=&ET;&4G(#T^("=-86YA9V4@25`@861D<F5S<V5S)RP*
M"B`@("`@("`@)W5I7U]S97)V97(O;6%I;%]?9&5S8W)I<'1I;VXG(#T^("=#
M;VYF:6=U<F4@<V5R=F5R+7=I9&4@;6%I;"!S>7-T96TN)RP*("`@("`@("`G
M=6E?7W-E<G9E<B]M86EL7U]S:&]R="UT:71L92<@/3X@)TUA:6PG+`H@("`@
M("`@("=U:5]?<V5R=F5R+VUA:6Q?7W1I=&QE)R`]/B`G4V5R=F5R+7=I9&4@
M;6%I;"!P<F5F97)E;F-E<R<L"@H@("`@("`@("=U:5]?<V5R=F5R+W!R969E
M<F5N8V5S7U]D97-C<FEP=&EO;B<@/3X@)U-E="!U<"!S97)V97(@<')E9F5R
M96YC97,N)RP*("`@("`@("`G=6E?7W-E<G9E<B]P<F5F97)E;F-E<U]?9&]N
M92<@/3X@)U-E<G9E<B!P<F5F97)E;F-E<R!H879E(&)E96X@=7!D871E9"XG
M+`H@("`@("`@("=U:5]?<V5R=F5R+W!R969E<F5N8V5S7U]S:&]R="UT:71L
M92<@/3X@)U!R969E<F5N8V5S)RP*("`@("`@("`G=6E?7W-E<G9E<B]P<F5F
M97)E;F-E<U]?=&ET;&4G(#T^("=397)V97(@<')E9F5R96YC97,G+`H*("`@
M("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?9&5S8W)I<'1I;VXG(#T^("=3
M=&%R="P@<W1O<"!O<B!R97-T87)T(&-O;G1R;VP@<&%N96P@<V5R=FEC97,N
M)RP*("`@("`@("`G=6E?7W-E<G9E<B]S97)V:6-E<U]?<VAO<G0M=&ET;&4G
M(#T^("=397)V:6-E<R<L"B`@("`@("`@)W5I7U]S97)V97(O<V5R=FEC97-?
M7W1I=&QE)R`]/B`G36%N86=E('-E<G9I8V5S)RP*"B`@("`@("`@)W5I7U]S
M97)V97(O<W1A=&ES=&EC<U]?9&5S8W)I<'1I;VXG(#T^("=6:65W('-Y<W1E
M;2!S=&%T:7-T:6-S+B<L"B`@("`@("`@)W5I7U]S97)V97(O<W1A=&ES=&EC
M<U]?<VAO<G0M=&ET;&4G(#T^("=S=&%T:7-T:6-S)RP*("`@("`@("`G=6E?
M7W-E<G9E<B]S=&%T:7-T:6-S7U]T:71L92<@/3X@)U-Y<W1E;2!S=&%T:7-T
M:6-S)RP*"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D97-C<FEP=&EO;B<@/3X@
M)U-U8FUI="!A(')E<75E<W0@9F]R(%!L97-K('1E8VAN:6-A;"!S=7!P;W)T
M+B<L"B`@("`@("`@)W5I7U]S=7!P;W)T7U]D;VYE)R`]/B`G5&5C:&YI8V%L
M('-U<'!O<G0@<&%G92!H87,@8F5E;B!O<&5N960N)RP*("`@("`@("`G=6E?
M7W-U<'!O<G1?7W-H;W)T+71I=&QE)R`]/B`G4W5P<&]R="<L"B`@("`@("`@
M)W5I7U]S=7!P;W)T7U]T:71L92<@/3X@)U1E8VAN:6-A;"!S=7!P;W)T)RP*
M"B`@("`@("`@+R\@*BHJ(%1H92!S=')I;F=S(&%B;W9E(&AA=F4@8F5E;B!G
M96YE<F%T960@875T;VUA=&EC86QL>2!F<F]M($!`0T%05$E/3B!D:7)E8W1I
M=F5S+@H*"2\O(&%K<W,@<&%R=`H*"2=?7U]?9&5T86EL<R<@/3X@)R@E,2DG
M+`H))U]?7U]L:7-T7V5M<'1Y)R`]/B`G)RP*"2=?7U]?;&ES=%]F:7)S=%]I
M=&5M)R`]/B`G)3$G+`H))U]?7U]L:7-T7VET96TG(#T^("<L("4Q)RP*"2=?
M7U]?;&ES=%]L87-T7VET96TG(#T^("<L("4Q)RP*"@DG7U]S:&]W7VAI9&5?
M=&ET;&4G(#T^("=-:6YI;6EZ92]297-T;W)E)RP*"2=?7U503$]!1%]%4E)?
M1D]235]325I%)R`]/B`B57!L;V%D960@9FEL92!E>&-E961S('1H92!A;&QO
M=V5D('-I>F4@;V8@)3$B+`H))U]?55!,3T%$7T524E])3DE?4TE:12<@/3X@
M(E5P;&]A9&5D(&9I;&4@97AC965D<R!T:&4@86QL;W=E9"!S:7IE(BP*"2=?
M7U503$]!1%]%4E)?3D]?1DE,12<@/3X@(DYO(&9I;&4@<F5C96EV960B+`H)
M)U]?55!,3T%$7T524E]/2R<@/3X@(D9I;&4@<W5C8V5S<V9U;&QY('5P;&]A
M9&5D(BP*"2=?7U503$]!1%]%4E)?4$%25$E!3"<@/3X@(D9I;&4@=V%S('!A
M<G1I86QL>2!U<&QO861E9"P@<&QE87-E('1R>2!A9V%I;B(L"@DG7U]A9&UI
M;E]S97)V97)?;F]T7W)E<W!O;F0G(#T^("))9B`E,2!D;V5S(&YO="!R97-P
M;VYD+"!P;&5A<V4@86-C97-S('1H92!S97)V97(@86YD(')E<W1A<G0@=&AE
M(&%D;6EN:7-T<F%T:79E('=E8B!S97)V97(@96YG:6YE(&UA;G5A;&QY+B(L
M"@DG7U]A8V-O=6YT<R<@/3X@(D%C8V]U;G1S(BP*"2=?7V%D9')E<W,G(#T^
M(")!9&1R97-S(BP*"2=?7V%D9')E<W-E<R<@/3X@(D%D9')E<W-E<R(L"@DG
M7U]A8VQ?<F5C;W)D<R<)/3X@)T%#3"!296-O<F1S)RP*"2=?7V%D;6EN7W)E
M<&]S:71O<GDG(#T^(")!9&UI;FES=')A=&]R)W,@<F5P;W-I=&]R>2(L"@DG
M7U]A;&PG(#T^(")!3$PB+`H))U]?86QL;W=?;75L=&EP;'E?;&]G:6XG(#T^
M(")!;&QO=R!M=6QT:7!L92!S97-S:6]N<R(L"@DG7U]A;&QO=V5D)R`]/B`B
M06QL;W=E9"(L"@DG7U]A;F]N9G1P7W-T871U<R<@/3X@(D%N;VYY;6]U<R!&
M5%`B+`H))U]?87!A8VAE7V5R<F1O8W,G(#T^(")#=7-T;VT@17)R;W(@1&]C
M=6UE;G1S(BP*"2=?7V%P86-H95]R97-T87)T)R`]/B`B+BXN)3$@=V5B+7-E
M<G9E<B!I<R!B96EN9R!R97-T87)T960L('!L96%S92!W86ET+BXN(BP*"2=?
M7V%S<"<@/3X@(DUI8W)O<V]F="!!4U`B+`H))U]?87-P7V1O=%]N970G(#T^
M(")-:6-R;W-O9G0@05-0+DY%5"(L"@DG7U]A<W!?9&]T7VYE=%]S=7!P;W)T
M)R`]/B`B36EC<F]S;V9T($%34"Y.150@<W5P<&]R="(L"@DG7U]A<W!?=6YI
M>%]S=7!P;W)T)R`]/B`B07!A8VAE($%34"!S=7!P;W)T(BP*"2=?7V%S<%]W
M:6Y?<W5P<&]R="<@/3X@(DUI8W)O<V]F="!!4U`@<W5P<&]R="(L"@DG7U]A
M='1A8VAM96YT<R<@/3X@(D%T=&%C:&UE;G1S(BP*"2=?7V%T=&%C:&UE;G1S
M7VQI<W0G(#T^(")!='1A8VAM96YT<R(L"@DG7U]A=71H;W(G(#T^("=!=71H
M;W(G+`H))U]?875T;W)E<W!?;F%M95]A;')E861Y7V5X:7-T<R<@/3X@(D%U
M=&]R97-P;VYD97(@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI<W1S+B(L"@DG
M7U]A=71O<F5S<&]N9&5R)R`]/B`B075T;W)E<W!O;F1E<B`@(BP*"2=?7V%U
M=&]R97-P;VYD97)S)R`]/B`B075T;W)E<W!O;F1E<G,B+`H))U]?875T;W)E
M<W!O;F1E<G-?;&ES="<@/3X@(D%U=&]R97-P;VYD97)S(BP*"2=?7V%U=&]R
M97-P;VYD97)?871T86-H;65N=%]F:6QE<R<@/3X@(D%U=&]R97-P;VYD97(@
M071T86-H;65N="!&:6QE<R(L"@DG7U]A=71O7W5P9&%T97-?;&ES="<@/3X@
M)T%V86EL86)L92!5<&1A=&5S)RP*"2=?7V%V86EL)R`]/B`B079A:6QA8FQE
M(BP*"2=?7V)I;F1?<W1A='5S)R`]/B`B1$Y3(%-E<G9E<B!S=&%T=7,B+`H)
M)U]?8G5?:7-?;F]T7VEN<W1A;&QE9"<@/3X@(E1H:7,@<V5R=FEC92!I<R!N
M;W0@8W5R<F5N=&QY(&%V86EL86)L92P@8F5C875S92!T:&4@8F%C:W5P('5T
M:6QI=&EE<R!W97)E(&YO="!I;G-T86QL960N(BP*"2=?7V)U7VYO=%]S=7!P
M;W)T7VEN7VME>2<@/3X@(D)A8VMU<"!C87!A8FEL:71Y(&ES(&YO="!S=7!P
M;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y+B(L"@DG7U]B>71E<R<@/3X@(F)Y
M=&5S(BP*"2=?7V-A;E]N;W1?=7-E7W)E<V5R=F5D7W=O<F1S)R`]/B`B66]U
M(&-A;FYO="!U<V4@=&AE(')E<V5R=F5D('=O<F1S+B(L"@DG7U]C97)T:69I
M8V%T92<@/3X@(D-E<G1I9FEC871E(BP*"2=?7V-E<G1I9FEC871E<R<@/3X@
M(D-E<G1I9FEC871E<R(L"@DG7U]C97)T:69I8V%T97-?;&ES="<@/3X@(D-E
M<G1I9FEC871E<R(L"@DG7U]C9VE?<W5P<&]R="<@/3X@(D-'22!S=7!P;W)T
M(BP*"2=?7V-H86YG95]D871E)R`]/B`B36]D:69I8V%T:6]N(&1A=&4B+`H)
M)U]?8VAO;W-E7VQO9V\G(#T^(")#:&]O<V4@;F5W(&QO9V\@9FEL92(L"@DG
M7U]C:71Y)R`]/B`B0VET>2(L"@DG7U]C;%]N;W1?97AI<W0G(#T^(")#;&EE
M;G0@86-C;W5N="!D;V5S(&YO="!E>&ES="XB+`H))U]?8VQI96YT)R`]/B`B
M0VQI96YT(BP*"2=?7V-L:65N=%]C87)D)R`]/B`B0VQI96YT(&-A<F0B+`H)
M)U]?8VQI96YT7V-O;G1A8W1?;F%M92<@/3X@(D-L:65N="!C;VYT86-T(&YA
M;64B+`H))U]?8VQI96YT7V9O<FTG(#T^(")#;&EE;G0@9F]R;2(L"@DG7U]C
M;&EE;G1?:7!?<&]O;"<@/3X@(D-L:65N="=S($E0('!O;VPB+`H))U]?8VQI
M96YT7VQI;6ET<R<@/3X@(D-L:65N="!A8V-O=6YT(&QI;6ET<R(L"@DG7U]C
M;&EE;G1?<&5R;6ES<VEO;G,G(#T^(")#;&EE;G0@<&5R;6ES<VEO;G,B+`H)
M)U]?8VQI96YT7W!R969E<F5N8V5S)R`]/B`B0VQI96YT('!R969E<F5N8V5S
M(BP*"2=?7V-L:65N=%]S=&%T=7,G(#T^(")#;&EE;G0@<W1A='5S(BP*"2=?
M7V-L:65N=%]N86UE)R`]/B`B0VQI96YT)W,@;F%M92(L"@DG7U]C;&EE;G1?
M=&]T86PG(#T^(")#;&EE;G0@5&]T86PB+`H))U]?8VQI96YT7W=I=&A?;&]G
M:6Y?;F%M95]A;')E861Y7V5X:7-T<R<@/3X@(D-L:65N="!W:71H(&QO9VEN
M(&YA;64@7"(E,5PB(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]C;&EE;G1?9&]M
M=7-E<E]W:71H7VQO9VEN7V%L<F5A9'E?97AI<W1S)R`]/B`B3&]G:6X@;F%M
M92`G)3$G(&ES(&%L<F5A9'D@:6X@=7-E(&)Y('1H92!A9&UI;FES=')A=&]R
M(&]F(&1O;6%I;B`G)3$G+B(L"@DG7U]C;&EE;G1S)R`]/B`B0VQI96YT<R(L
M"@DG7U]C;&EE;G1S7V=L;V)A;%]C:&%N9V5S)R`]/B`B1W)O=7`@3W!E<F%T
M:6]N<R!O;B!#;&EE;G0@06-C;W5N=',B+`H))U]?8VQI96YT<U]L:7-T)R`]
M/B`B0VQI96YT<R(L"@DG7U]C;61?;F]T7V9O=6YD)R`]/B`B56YK;F]W;B!C
M;VUM86YD.B`E,2(L"@DG7U]C;VQD9G5S:6]N7VYO=%]S=7!P;W)T7VEN7VME
M>2<@/3X@(D-O;&1&=7-I;VX@:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC
M96YS92!K97DB+`H))U]?8V]L9&9U<VEO;E]S=&%T=7,G(#T^("=#;VQD1G5S
M:6]N('-T871U<R<L"@DG7U]C;VQD9G5S:6]N7W-U<'!O<G0G(#T^(")#;VQD
M1G5S:6]N('-U<'!O<G0B+`H))U]?8V]M;6%N9"<@/3X@)T-O;6UA;F0G+`H)
M)U]?8V]M;65N=',G(#T^(")#;VUM96YT<R(L"@DG7U]C;VUP86YY7VYA;64G
M(#T^(")#;VUP86YY(&YA;64B+`H))U]?8V]M<&]N96YT7W9E<G-I;VXG(#T^
M(")#;VUP;VYE;G0@=F5R<VEO;B(L"@DG7U]A;&QO=U]Z;VYE7W1R86YS9F5R
M7VQI<W0G(#T^("=#;VUM;VX@06QL;W<@6F]N92!4<F%N<V9E<B!!0TPG+`H)
M)U]?8V]M<&]N96YT7VYO=%]I;G-T86QL960G(#T^(")#;VUP;VYE;G0@)3$@
M=V%S(&YO="!I;G-T86QL960B+`H))U]?8V]N9FER;5]D96PG(#T^(")9;W4@
M;75S="!C;VYF:7)M(&1E;&5T:6]N+B(L"@DG7U]C;VYF:7)M7W-T;W`G(#T^
M(")9;W4@;75S="!C;VYF:7)M('!R;V-E<W,@<W1O<'!I;F<N(BP*"2=?7V-O
M;F9I<FU?<&%S<W=D)R`]/B`B0V]N9FER;2`E,2!087-S=V]R9"(L"@DG7U]C
M;VYF:7)M7W!A<W-W9%]S:6YG;&4G(#T^(")#;VYF:7)M(%!A<W-W;W)D(BP*
M"2=?7V-O;F9I<FU?<F5M;W9A;"<@/3X@(D-O;F9I<FT@<F5M;W9A;"(L"@DG
M7U]C;VYH96QP)R`]/B`B0V]N=&5X="!H96QP('1I<"(L"@DG7U]C;VYT86-T
M7VYA;64G(#T^(")#;VYT86-T(&YA;64B+`H))U]?8V]U;G1R>2<@/3X@(D-O
M=6YT<GDB+`H))U]?8V]U;G1R:65S)R`]/B`G0V]U;G1R>2<L"@DG7U]C;W5N
M=')Y7W5N:VYO=VXG(#T^("=5;F%B;&4@=&\@<F5C;V=N:7IE('1H92!C;W5N
M=')Y('-U8F-O9&4N)RP*"2=?7V-R96%T95]D;VUA:6XG(#T^("=#<F5A=&4@
M;F5W(&1O;6%I;B<L"@DG7U]C<GEP=&5D)R`]/B`G96YC<GEP=&5D)RP*"2=?
M7V-P7V%C8V5S<R<@/3X@(D-O;G1R;VP@<&%N96P@86-C97-S(BP*"2=?7V-P
M7W5S97(G(#T^(")#;VYT<F]L(%!A;F5L(%5S97(B+`H))U]?8W)E871E)R`]
M/B`B0W)E871E(BP*"2=?7V-R96%T95]C;&EE;G1?=&5M<&QA=&5?=VET:&]U
M=%]T96UP;&%T92<@/3X@(D-R96%T92!C;&EE;G0@=VET:&]U="!T96UP;&%T
M92(L"@DG7U]C<F5A=&5?9&]M86EN7V9O<B<@/3X@(D-R96%T92!N97<@9&]M
M86EN(&9O<B`\8CXE,3PO8CXB+`H))U]?8W)E871E7V1O;6%I;E]T96UP;&%T
M95]W:71H;W5T7W1E;7!L871E)R`]/B`B0W)E871E(&1O;6%I;B!W:71H;W5T
M('1E;7!L871E(BP*"2=?7V-R96%T:6]N7V1A=&4G(#T^(")#<F5A=&EO;B!D
M871E(BP*"2=?7V-R;VYT86)?=6YI>"<@/3X@(D-R;VYT86(B+`H))U]?8W)O
M;G1A8E]W:6XG(#T^(")38VAE9'5L97(B+`H))U]?8W1?8VUD)R`]/B`B0V]M
M;6%N9"(L"@DG7U]C=%]D;VTG(#T^(")$87D@;V8@=&AE($UO;G1H(BP*"2=?
M7V-T7V1O;5\G(#T^(")$32(L"@DG7U]C=%]D;W<G(#T^(")$87D@;V8@=&AE
M(%=E96LB+`H))U]?8W1?9&]W7R<@/3X@(D17(BP*"2=?7V-T7V5N86)L960G
M(#T^(")3=&%T=7,B+`H))U]?8W1?96YA8FQE9%\G(#T^(")3(BP*"2=?7V-T
M7VAO=7(G(#T^(")(;W5R(BP*"2=?7V-T7VAO=7)?)R`]/B`B2"(L"@DG7U]C
M=%]M:6YU=&4G(#T^(")-:6YU=&4B+`H))U]?8W1?;6EN=71E7R<@/3X@(DUI
M;B(L"@DG7U]C=%]M;VYT:"<@/3X@(DUO;G1H(BP*"2=?7V-T7VUO;G1H7R<@
M/3X@(DTB+`H))U]?8W1?;6]N=&A?96YT97)?861V)R`]/B`B16YT97(@=&AE
M('9A;'5E(BP*"2=?7V-T7VAI;G1?=6YI>%]F;W)M870G(#T^(")I;B!53DE8
M(&-R;VYT86(@9F]R;6%T(&4N9RXB+`H))U]?8W1?;6]N=&A?96YT97(G(#T^
M(")396QE8W0@=&AE(&UO;G1H(BP*"2=?7V-T7V1O=U]E;G1E<E]A9'8G(#T^
M(")%;G1E<B!T:&4@=F%L=64B+`H))U]?8W1?9&]W7V5N=&5R)R`]/B`B4V5L
M96-T('1H92!D87D@;V8@=V5E:R(L"@DG7U]C=%]M;VYT:%]J86XG(#T^("=*
M86YU87)Y)RP*"2=?7V-T7VUO;G1H7V9E8B<@/3X@)T9E8G)U87)Y)RP*"2=?
M7V-T7VUO;G1H7VUA<B<@/3X@)TUA<F-H)RP*"2=?7V-T7VUO;G1H7V%P<B<@
M/3X@)T%P<FEL)RP*"2=?7V-T7VUO;G1H7VUA>2<@/3X@)TUA>2<L"@DG7U]C
M=%]M;VYT:%]J=6XG(#T^("=*=6YE)RP*"2=?7V-T7VUO;G1H7VIU;"<@/3X@
M)TIU;'DG+`H))U]?8W1?;6]N=&A?875G)R`]/B`G075G=7-T)RP*"2=?7V-T
M7VUO;G1H7W-E<"<@/3X@)U-E<'1E;6)E<B<L"@DG7U]C=%]M;VYT:%]O8W0G
M(#T^("=/8W1O8F5R)RP*"2=?7V-T7VUO;G1H7VYO=B<@/3X@)TYO=F5M8F5R
M)RP*"2=?7V-T7VUO;G1H7V1E8R<@/3X@)T1E8V5M8F5R)RP*"2=?7V-T7V1O
M=U]S=6XG(#T^("=3=6YD87DG+`H))U]?8W1?9&]W7VUO;B<@/3X@)TUO;F1A
M>2<L"@DG7U]C=%]D;W=?='5E)R`]/B`G5'5E<V1A>2<L"@DG7U]C=%]D;W=?
M=V5D)R`]/B`G5V5D;F5S9&%Y)RP*"2=?7V-T7V1O=U]T:'4G(#T^("=4:'5R
M<V1A>2<L"@DG7U]C=%]D;W=?9G)I)R`]/B`G1G)I9&%Y)RP*"2=?7V-T7V1O
M=U]S870G(#T^("=3871U<F1A>2<L"@DG7U]C=7-T;VU?8G5T=&]N)R`]/B`B
M0W5S=&]M(&)U='1O;B(L"@DG7U]C=7-T;VU?8G5T=&]N<R<@/3X@(D-U<W1O
M;2!B=71T;VYS(BP*"2=?7V-U<W1O;5]B=71T;VYS7VQI<W0G(#T^(")#=7-T
M;VT@8G5T=&]N<R(L"@DG7U]D86EL>2<@/3X@(D1A:6QY(BP*"2=?7V1A;&EA
M<U]N;W1?97AI<W0G(#T^("=$;VUA:6X@86QI87,@9&]E<R!N;W0@97AI<W0N
M)RP*"2=?7V1A=&%B87-E7VYO=%]A8W1I=F%T960G(#T^("(E,2!W87,@;F]T
M(&%C=&EV871E9"!I;B!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T:6]N('-E8W1I
M;VXN(BP*"2=?7V1A=&%B87-E7VYO=%]I;G-T86QL960G(#T^(")$871A8F%S
M92`E,2!I<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]D871A8F%S95]N;W1?<G5N
M)R`]/B`B1&%T86)A<V4@)3$@:7,@;F]T(')U;FYI;F<N(BP*"2=?7V1A=&%B
M87-E<R<@/3X@(D1A=&%B87-E<R(L"@DG7U]D871A8F%S97-?;&ES="<@/3X@
M(D1A=&%B87-E<R(L"@DG7U]D871A8F%S95]T>7!E7VYO=%]S=7!P;W)T961?
M8GE?:V5Y)R`]/B`G5&AI<R!T>7!E(&]F(&1A=&%B87-E(&ES(&YO="!S=7!P
M;W)T960@8GD@>6]U<B!L:6-E;G-E(&ME>2<L"@DG7U]D871E7VEM;65D:6%T
M96QY)R`]/B`B=&]D87DB+`H))U]?9&%T95]N979E<B<@/3X@(FYE=F5R(BP*
M"2=?7V1A>2AS*2<@/3X@(D1A>2AS*2(L"@DG7U]D87DP)R`]/B`B4W5N(BP*
M"2=?7V1A>3$G(#T^(")-;VXB+`H))U]?9&%Y,B<@/3X@(E1U97,B+`H))U]?
M9&%Y,R<@/3X@(E=E9"(L"@DG7U]D87DT)R`]/B`B5&AU<G,B+`H))U]?9&%Y
M-2<@/3X@(D9R:2(L"@DG7U]D87DV)R`]/B`B4V%T(BP*"2=?7V1A>7,G(#T^
M("(E,2!D87DH<RDB+`H))U]?1&%Y<R<@/3X@(D1A>7,B+`H))U]?9&)?861M
M:6Y?;&]G:6Y?96UP='DG(#T^(")9;W4@:&%V92!E;G1E<F5D(&%N(&5M<'1Y
M(&QO9VEN+"!D:7-A8FQI;F<@8V]N=')O;"!O=F5R("4Q(&EN('1H92!I;G1E
M<F9A8V4N($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=?7V1B7V%L<F5A
M9'E?97AI<W0G(#T^(")$871A8F%S92`E,2!A;')E861Y(&5X:7-T<RXB+`H)
M)U]?9&)?96YG:6YE)R`]/B`B1&%T86)A<V4@16YG:6YE(BP)+R\@:6YD:7)E
M8W0*"2=?7V1B7W1Y<&4G(#T^(")$871A8F%S92!T>7!E(BP*"2=?7V1B7W5S
M97(G(#T^(")$871A8F%S92!U<V5R(BP*"2=?7V1B7W5S97)S)R`]/B`B1&%T
M86)A<V4@=7-E<G,B+`H))U]?9&)?<V5R=F5R)R`]/B`G1&%T86)A<V4@<V5R
M=F5R)RP*"2=?7V1E8W)E;65N="<@/3X@(D1E8W)E87-E("@M*2(L"2\O(&EN
M9&ER96-T"@DG7U]D969?9&]M86EN)R`]/B`B1&5F875L="!D;VUA:6XB+`H)
M)U]?9&5F875L=%]F;W)?;7ES<6PG(#T^("=D969A=6QT(&9O<B!->5-13"<L
M"@DG7U]D969A=6QT7V9O<E]P;W-T9W)E<W%L)R`]/B`G9&5F875L="!F;W(@
M4&]S=&=R95-13"<L"@DG7U]D96QE=&4G(#T^(")$96QE=&4B+`H))U]?9&5M
M;R<@/3X@(E1H:7,@9G5N8W1I;VX@:7,@9&ES86)L960@:6X@9&5M;R!V97)S
M:6]N+B(L"@DG7U]D:7)E8W1O<GDG(#T^(")$:7)E8W1O<GDB+`H))U]?9&ES
M86)L95]L;V-K7W-C<F5E;B<@/3X@)U!R979E;G0@=7-E<G,@9G)O;2!W;W)K
M:6YG('=I=&@@=&AE(&-O;G1R;VP@<&%N96P@=6YT:6P@:6YT97)F86-E('-C
M<F5E;G,@87)E(&-O;7!L971E;'D@;&]A9&5D+B<L"@DG7U]D:7-M:7-S7VYE
M=W,_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(&-O;7!L971E;'D@
M:&ED92!T:&4@;F5W<R!B;&]C:S]<;EQN5&AE(&YE=W,@=VEL;"!N;W0@8F4@
M<VAO=VX@86YY;6]R92!U;G1I;"!T:&5R92!I<R!S;VUE(&UO<F4@;F5W<R!S
M;VUE9&%Y+B!)9B!Y;W4@=V]U;&0@<F%T:&5R(&QI:V4@=&\@<V5E('1H97-E
M(&YE=W,@86=A:6X@<V]M971I;64L('EO=2!C86X@;6EN:6UI>F4@=&AE(&)L
M;V-K(&EN<W1E860@8GD@8VQI8VMI;F<@;VX@:71S('1I=&QE(&)A<BXB+`H)
M)U]?9&5F875L=%]B86-K=7!?8V]M;65N="<@/3X@(B4Q(&)A8VMU<"Y<;D-R
M96%T:6]N(&1A=&4Z("4R(BP*"2=?7V1E<V-R:7!T:6]N)R`]/B`B1&5S8W)I
M<'1I;VXB+`H))U]?9&ES86)L960G(#T^(")D:7-A8FQE9"(L"@DG7U]D:7-K
M7W-P86-E7VQI;6ET)R`]/B`B1&ES:R!S<&%C92!L:6UI="(L"@DG7U]D:7-K
M7W5S86=E7V)Y)R`]/B`B1&ES:R!S<&%C92!U<V5D(&)Y("4Q(BP*"2=?7V1N
M<R<@/3X@(D1.4R(L"@DG7U]D;G-?<F5C;W)D7V%L<F5A9'E?97AI<W0G(#T^
M(")$3E,@<F5C;W)D(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]D;G-?;6%S=&5R
M7W-H;W5L9%]B95]R96UO=&4G(#T^(")9;W4@<VAO=6QD(&AA=F4@='=O(&1I
M9F9E<F5N="!A=71H;W)I=&%T:79E(&YA;64@<V5R=F5R<R!O;B!S97!A<F%T
M92!H;W-T<RXB+`H))U]?9&YS7W)E8V]R9%]N;W1?97AI<W0G(#T^(")$3E,@
M<F5C;W)D(&1O97,@;F]T(&5X:7-T+B(L"@DG7U]D;G-?<V5R=F5R)R`]/B`B
M1$Y3('-E<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]D;VU?:61?:7-?=6YD969I
M;F5D)R`]/B`B1&]M86EN(&ED(&ES('5N9&5F:6YE9"XB+`H))U]?9&]M7VYA
M;64G(#T^(")$;VUA:6X@;F%M92(L"@DG7U]D;VU?;F%M95]I<U]I;G9A;&ED
M)R`]/B`B1&]M86EN(&YA;64@:7,@:6YV86QI9"X@4&QE87-E(&UA:V4@<W5R
M92!Y;W5R(&1O;6%I;B!N86UE(&-O;7!R:7-E<R!O;FQY(&%L<&AA;G5M97)I
M8RP@9&]T(&%N9"!H>7!H96X@<WEM8F]L<RP@86YD(&ES(&YO="!G<F5A=&5R
M('1H86X@,C4U('-Y;6)O;',@:6X@;&5N9W1H+B!%86-H('!A<G0@;V8@=&AE
M(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U;&0@;F]T(&5X8V5E9"`V
M,R!S>6UB;VQS+B(L"@DG7U]D;VU?;F]T7V5X:7-T)R`]/B`B1&]M86EN(&1O
M97,@;F]T(&5X:7-T+B(L"@DG7U]D;VUA:6XG(#T^(")$;VUA:6X@)3$B+`H)
M)U]?9&]M86EN7V9O<FTG(#T^(")$;VUA:6X@9F]R;2(L"@DG7U]D;VUA:6Y?
M:7-?='5R;F5D7V]F9E]F;W)?8F%C:W5P)R`]/B`B1&]M86EN("4Q(&ES('1E
M;7!O<F%R:6QY('1U<FYE9"!O9F8@9F]R(&)A8VMU<"]R97-T;W)I;F<@86YD
M(&ES(&YO="!C=7)R96YT;'D@879A:6QA8FQE+B(L"@DG7U]D;VUA:6Y?;&EM
M:71S)R`]/B`B1&]M86EN(&QI;6ET<R(L"@DG7U]D;VUA:6Y?;F%M92<@/3X@
M(D1O;6%I;B!N86UE(BP*"2=?7VUA:6Q?;F%M95]I;E]!4T-)25]F;W)M)R`]
M/B`B36%I;"!N86UE(&EN($%30TE)(&9O<FUA="(L"@DG7U]M97-S86=E7V5R
M<F]R)R`]/B`G17)R;W(G+`H))U]?;65S<V%G95]W87)N:6YG)R`]/B`G5V%R
M;FEN9R<L"@DG7U]M97-S86=E7VEN9F\G(#T^("=);F9O<FUA=&EO;B<L"@DG
M7U]D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]/B`B1&]M86EN(&YA;64@
M:6X@05-#24D@9F]R;6%T(BP*"2=?7V1O;6%I;E]R97!O<VET;W)Y)R`]/B`B
M4F5P;W-I=&]R>2!O9B!D;VUA:6X@)3$B+`H))U]?9&]M86EN7W-T871U<R<@
M/3X@(D1O;6%I;B!S=&%T=7,B+`H))U]?9&]M86EN7V1N<R<@/3X@)T1O;6%I
M;B!$3E,@>F]N92<L"@DG7U]D;VUA:6Y?=&]T86PG(#T^(")$;VUA:6X@5&]T
M86PB+`H))U]?9&]M86EN7W5S97(G(#T^(")$;VUA:6X@861M:6YI<W1R871O
M<B(L"@DG7U]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG7U]D;VUA:6YS7V=L
M;V)A;%]C:&%N9V5S)R`]/B`B1W)O=7`@3W!E<F%T:6]N<R!O;B!$;VUA:6YS
M(BP*"2=?7VUA:6QN86UE<U]G;&]B86Q?8VAA;F=E<R<@/3X@(D=R;W5P($]P
M97)A=&EO;G,@;VX@36%I;"!.86UE<R(L"@DG7U]M:6=R871I;VY?;6%N86=E
M<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R)RP*"2=?7V)A8VMU<%]M86YA9V5R
M)R`]/B`G0F%C:W5P($UA;F%G97(G+`H))U]?9&]M86EN<U]L:7-T)R`]/B`B
M1&]M86EN<R(L"@DG7U]D;VUA:6Y?<F5S;VQV97-?=&]?86YO=&AE<E]I<"<@
M/3X@(E1H92!D;VUA:6X@<F5S;VQV97,@=&\@86YO=&AE<B!)4"!A9&1R97-S
M("@E,2DN(%!L96%S92!C;W)R96-T($1.4R!S971T:6YG<RXB+`H))U]?9&]U
M8FQE7W=W=U]W87)N:6YG)R`]/B`B5&AE(&1O;6%I;B!N86UE(&)E9VEN<R!W
M:71H('=W=RP@86QT:&]U9V@@=&AE(%=75R!P<F5F:7@@:7,@96YA8FQE9"Y<
M;E!R;V-E960@86YY=V%Y/R(L"@DG7U]D<VUA:6PG(#T^(")-86EL('-E<G9I
M8V4B+`H))U]?9'-M86EL;&ES="<@/3X@(DUA:6QI;F<@;&ES="!S97)V:6-E
M(BP*"2=?7V1S<E]D8B<@/3X@(D1"(BP*"2=?7V1S<E]D;F%M92<@/3X@(D1O
M;6%I;B!N86UE(BP*"2=?7V1S<E]D=2<@/3X@(D15(BP*"2=?7V1S<E]M82<@
M/3X@(DU!(BP*"2=?7V1S<E]M9R<@/3X@(DU'(BP*"2=?7V1S<E]M;"<@/3X@
M(DU,(BP*"2=?7V1S<E]M;B<@/3X@(DU";W@B+`H))U]?9'-R7VUR)R`]/B`B
M35(B+`H))U]?9'-R7W!N86UE)R`]/B`B0VQI96YT)W,@;F%M92(L"@DG7U]D
M<W)?<V0G(#T^(")31"(L"@DG7U]D<W)?='(G(#T^(")44B(L"@DG7U]D<W)?
M=W4G(#T^(")752(L"@DG7U]D<W1O;6-A="<@/3X@(E1O;6-A="!S97)V:6-E
M(BP*"2=?7V1U;7!?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA;64B+`H))U]?
M9'5M<'-?=&]T7W-I>F4G(#T^(")4;W1A;"!S:7IE(&]F(&)A8VMU<"!F:6QE
M<R(L"@DG7U]E;6%I;"<@/3X@(D4M;6%I;"(L"@DG7U]E;6%I;%]A9&1R7VES
M7VEN=F%L:60G(#T^(")%+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG
M7U]E;F%B;&5D)R`]/B`B96YA8FQE9"(L"@DG7U]E;G1E<E]C97)T7W1E>'0G
M(#T^(")%;G1E<B!C97)T:69I8V%T92!T97AT(BP*"2=?7V5N=&5R7VQO9V]?
M=7)L)R`]/B`B16YT97(@;F5W(%523"!F;W(@;&]G;R(L"@DG7U]E;G1E<E]S
M:7IE)R`]/B`B16YT97(@<VEZ92(L"@DG7U]E=F5N="<@/3X@)T5V96YT)RP*
M"2=?7V5V96YT7VAA;F1L97(G(#T^("=%=F5N="!H86YD;&5R)RP*"2=?7V5V
M96YT7VAA;F1L97)S)R`]/B`G179E;G0@:&%N9&QE<G,G+`H))U]?97AC;'5S
M:79E)R`]/B`B17AC;'5S:79E(BP*"2=?7V5X<&ER871I;VY?9&%T92<@/3X@
M(D5X<&ER871I;VX@9&%T92(L"@DG7U]F87@G(#T^(")&87@B+`H))U]?9FEL
M92<@/3X@(D9I;&4B+`H))U]?9FEL95]I<U]E;7!T>2<@/3X@(D9I;&4@:7,@
M96UP='DN(BP*"2=?7V9I;&5?;F%M92<@/3X@(D9I;&4@;F%M92(L"@DG7U]F
M:6QE7W1Y<&4G(#T^("=&:6QE('1Y<&4G+`H))U]?9FEL96UA;F%G97(G(#T^
M(")&:6QE($UA;F%G97(B+`H))U]?9FEL97!A=&A?:7-?96UP='DG(#T^(")0
M871H('1O(&9I;&4@:7,@96UP='DB+`H))U]?9FEL97-?;&ES="<@/3X@(D9I
M;&5S(BP*"2=?7V9P7W-S;%]U;FEX7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@
M;W9E<B!34TP@<W5P<&]R="(L"@DG7U]F<%]S<VQ?=VEN7W-U<'!O<G0G(#T^
M(")-:6-R;W-O9G0@1G)O;G1086=E(&]V97(@4U-,('-U<'!O<G0B+`H))U]?
M9G!?=6YI>%]A=71H)R`]/B`B1G)O;G1086=E(&%U=&AO<FEN9R(L"@DG7U]F
M<%]U;FEX7W-U<'!O<G0G(#T^(")&<F]N=%!A9V4@<W5P<&]R="(L"@DG7U]F
M<%]W:6Y?875T:"<@/3X@(DUI8W)O<V]F="!&<F]N=%!A9V4@875T:&]R:6YG
M(BP*"2=?7V9P7W=I;E]S=7!P;W)T)R`]/B`B36EC<F]S;V9T($9R;VYT4&%G
M92!S=7!P;W)T(BP*"2=?7V9R;VYT<&%G92<@/3X@(DUI8W)O<V]F="!&<F]N
M=%!A9V4B+`H))U]?9G1P)R`]/B`B1E10(BP)+R\@*VEN9&ER96-T"@DG7U]F
M='!?<V5T=&EN9W,G(#T^(")&5%`@<V5T=&EN9W,B+`H))U]?9G1P7W-E<G8G
M(#T^(")&5%`@<V5R=F5R(BP)+R\@:6YD:7)E8W0*"2=?7V9T<%]S97)V97)?
M<&%R86UE=&5R<U]A<F5?96UP='DG(#T^(")9;W4@<VAO=6QD('-E="!T:&4@
M1E10(&%C8V]U;G0@<')O<&5R=&EE<R!F:7)S="$B+`H))U]?9G1P7W-T871U
M<R<@/3X@(D944"!S97)V97(@<W1A='5S(BP*"2=?7V9U;&Q?9&%Y,"<@/3X@
M(E-U;F1A>2(L"@DG7U]F=6QL7V1A>3$G(#T^(")-;VYD87DB+`H))U]?9G5L
M;%]D87DR)R`]/B`B5'5E<V1A>2(L"@DG7U]F=6QL7V1A>3,G(#T^(")7961N
M97-D87DB+`H))U]?9G5L;%]D87DT)R`]/B`B5&AU<G-D87DB+`H))U]?9G5L
M;%]D87DU)R`]/B`B1G)I9&%Y(BP*"2=?7V9U;&Q?9&%Y-B<@/3X@(E-A='5R
M9&%Y(BP*"2=?7V9U;&Q?;6]N=&@Q)R`]/B`B2F%N=6%R>2(L"@DG7U]F=6QL
M7VUO;G1H,3`G(#T^(")/8W1O8F5R(BP*"2=?7V9U;&Q?;6]N=&@Q,2<@/3X@
M(DYO=F5M8F5R(BP*"2=?7V9U;&Q?;6]N=&@Q,B<@/3X@(D1E8V5M8F5R(BP*
M"2=?7V9U;&Q?;6]N=&@R)R`]/B`B1F5B<G5A<GDB+`H))U]?9G5L;%]M;VYT
M:#,G(#T^(")-87)C:"(L"@DG7U]F=6QL7VUO;G1H-"<@/3X@(D%P<FEL(BP*
M"2=?7V9U;&Q?;6]N=&@U)R`]/B`B36%Y(BP*"2=?7V9U;&Q?;6]N=&@V)R`]
M/B`B2G5N92(L"@DG7U]F=6QL7VUO;G1H-R<@/3X@(DIU;'DB+`H))U]?9G5L
M;%]M;VYT:#@G(#T^(")!=6=U<W0B+`H))U]?9G5L;%]M;VYT:#DG(#T^(")3
M97!T96UB97(B+`H))U]?9V5N97)A;"<@/3X@(D=E;F5R86PB+`H))U]?9VEG
M82<@/3X@(D<B+`H))U]?9W)O=7`G(#T^(")'<F]U<"(L"@DG7U]H)R`]/B`B
M2"(L"@DG7U]H87)D7V1I<VM?<75O=&$G(#T^(")(87)D(&1I<VL@<75O=&$B
M+`H))U]?:&%R9%]D:7-K7W%U;W1A7VYO=%]S=7!P;W)T960G(#T^(")H87)D
M(&1I<VL@<75O=&$@:7,@;F]T('-U<'!O<G1E9"(L"@DG7U]H96%D97)?=&5X
M=%]I<U]I;G9A;&ED)R`]/B`B2&5A9&5R('1E>'0@:7,@:6YV86QI9"XB+`H)
M)U]?:&5L<"<@/3X@(DAE;'`B+`H))U]?:&5L<%]T;W!I8U]N;W1?9F]U;F0G
M(#T^("=4:&4@:&5L<"!T;W!I8R!Y;W4@<F5Q=65S=&5D("@E,2D@9&]E<R!N
M;W0@97AI<W0N)RP*"2=?7VAO;64G(#T^(")(;VUE(BP*"2=?7VAO<W1I;F<G
M(#T^(")(;W-T:6YG(BP*"2=?7VAO<W1I;F=?:7!?9&YS7VEP7VYO=%]E<75I
M=B<@/3X@(DYO;F4@;V8@25`@861D<F5S<V5S('-P96-I9FEE9"!I;B!!($1.
M4R!R96-O<F1S(&UA=&-H('1H92!)4"!A9&1R97-S('5S960@9F]R(&AO<W1I
M;F<B+`H))U]?:&]S=&EN9U]S8W)I<'1I;F<G(#T^(")(;W-T:6YG('-C<FEP
M=&EN9R!S=7!P;W)T(BP*"2=?7VAO<W1I;F=?<V5T=7!?<&%G95]T:71L92<@
M/3X@(E!H>7-I8V%L(&AO<W1I;F<@<V5T=7`@<&%G92!F;W(@9&]M86EN("4Q
M(BP*"2=?7VAO<W1I;F=?=&ET;&4G(#T^(")(;W-T:6YG("@E,2DB+`H))U]?
M:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R!T>7!E(BP*"2=?7VAO<W1N86UE
M)R`]/B`B2&]S=&YA;64B+`H))U]?:&]S=&YA;65?:7-?96UP='DG(#T^(")(
M;W-T;F%M92!I<R!E;7!T>2XB+`H))U]?2&]U<G,G(#T^("=(;W5R<R<L"@DG
M7U]H<W1?='EP95]I;F-O<G)E8W0G(#T^(")(;W-T:6YG('1Y<&4@:7,@:6YC
M;W)R96-T+B(L"@DG7U]H='1P)R`]/B`B2%144"(L"2\O:6YD:7)E8W0*"2=?
M7VAT>7!E)R`]/B`B2"(L"@DG7U]I9&QE7W1I;64G(#T^("))9&QE('1I;64B
M+`H))U]?:69A8V4G(#T^("));G1E<F9A8V4B+`H))U]?:6UA9V4G(#T^("))
M;6%G92(L"@DG7U]I;6%P7W-T871U<R<@/3X@(DE-05`@4V5R=F5R('-T871U
M<R(L"@DG7U]I;B<@/3X@(DEN(BP*"2=?7VEN7R4G(#T^(")I;B`E(BP*"2=?
M7VEN8V]R<F5C=%]D871A8F%S97-?;&]G:6Y?<&%S<R<@/3X@(EEO=2!S<&5C
M:69I960@:6YC;W)R96-T(&-R961E;G1I86QS(&9O<B!A8V-E<W,@=&\@4&]S
M=&=R95-13"XB+`H))U]?:6YC;W)R96-T7VEP7V]R7VYE='=O<FM?861D<F5S
M<R<@/3X@)TEN8V]R<F5C="!)4"!A9&1R97-S(&]R(&YE='=O<FLN)RP*"2=?
M7VEN8W)E;65N="<@/3X@(DEN8W)E87-E("@K*2(L"2\O(&EN9&ER96-T"@DG
M7U]I;F9O)R`]/B`G26YF;R<L"@DG7U]I;G-T86QL)R`]/B`B26YS=&%L;"(L
M"@DG7U]I;G-T86QL7W!R969I>"<@/3X@(DEN<W1A;&P@<')E9FEX(BP*"2=?
M7VEN=&5R9F%C95]S:VEN)R`]/B`B26YT97)F86-E('-K:6XB+`H))U]?:6YV
M86QI9%]C97)T7VED)R`]/B`B26YV86QI9"!C97)T:69I8V%T92!I9"(L"@DG
M7U]I;G9A;&ED7V-O;G1E>'0G(#T^("));G9A;&ED(&-O;G1E>'0Z("4Q(BP*
M"2=?7VEN=F%L:61?9&)?=7-R7VYA;64G(#T^(")$871A8F%S92!U<V5R(&YA
M;64@:7,@:6YV86QI9"XB+`H))U]?:6YV86QI9%]D:7)?;F%M92<@/3X@(D1I
M<F5C=&]R>2!N86UE(&ES(&EN=F%L:60B+`H))U]?:6YV86QI9%]D;VU?;F%M
M92<@/3X@(D1O;6%I;B!N86UE(&ES(&EN=F%L:60N(BP*"2=?7VEN=F%L:61?
M9FEL96YA;64G(#T^("));G9A;&ED(&9I;&5N86UE+B!$;R!N;W0@=7-E('-I
M;F=L92!Q=6]T97,@86YD+V]R(%PB+BXO7"(@8V]M8FEN871I;VXN(BP*"2=?
M7VEN=F%L:61?:60G(#T^("));G9A;&ED(&ED96YT:69I97(N(BP*"2=?7VEN
M=F%L:61?;6%X7V)U='1O;E]L96XG(#T^("));F%P<')O<')I871E('9A;'5E
M(&9O<B!N=6UB97(@;V8@8VAA<F%C=&5R<RX@66]U('-H;W5L9"!U<V4@;VYL
M>2!D:6=I=',N(BP*"2=?7VEN=F%L:61?;6%X7VQE='1E<E]S:7IE)R`]/B`B
M36%X:6UU;2!L971T97(@<VEZ92!I<R!I;G9A;&ED+B(L"@DG7U]I;G9A;&ED
M7W!D:7)?;F%M92<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<GD@;F%M92!I<R!I
M;G9A;&ED+B(L"@DG7U]I;G9A;&ED7W)E<W1A<G1?87!A8VAE7VEN=&5R=F%L
M)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86P@:7,@:6YV86QI9"(L"@DG
M7U]I;G9A;&ED7W1M<&Q?;F%M92<@/3X@(E1E;7!L871E(&YA;64@:7,@:6YV
M86QI9"XB+`H))U]?:6YV86QI9%]V86QU92<@/3X@(DEM<')O<&5R('9A;'5E
M+B(L"@DG7U]I<%]A9&1R)R`]/B`B25`@061D<F5S<R(L"@DG7U]I<%]A9&1R
M97-S7V%N9%]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B;F5T($UA<VLB
M+`H))U]?:7!?;6%S:R<@/3X@(E-U8FYE="!-87-K(BP*"2=?7VEP7V%L:6%S
M7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B;F5T($UA<VLB+`H))VEP
M7V%L:6%S7U]M87-K)R`]/B`B25`@061D<F5S<R!A;F0@4W5B;F5T($UA<VLB
M+`H))U]?:7!?861D<E]F;W)M)R`]/B`B25`@061D<F5S<R!F;W)M(BP*"2=?
M7VEP7V%D9')?:7-?:6YV86QI9"<@/3X@(DE0(&%D9')E<W,@:7,@:6YV86QI
M9"XB+`H))U]?:7!?861D<E]L:7-T)R`]/B`B25`@061D<F5S<V5S(BP*"2=?
M7VEP7V%D9')E<W-?9&]E<U]N;W1?97AI<W0G(#T^("))4"!A9&1R97-S(&1O
M97,@;F]T(&5X:7-T+B(L"@DG7U]I<%]A9&1R97-S97,G(#T^("))4"!!9&1R
M97-S97,B+`H))U]?:7!?861D<F5S<U]A;F1?;6%S:U]H:6YT)R`]/B`G12YG
M+B`E,2<L"@DG7U]I<U]O=VYE<B<@/3X@(D\B+`H))U]?:F%V85]E;F=I;F4G
M(#T^(")*879A(BP)+R\@:6YD:7)E8W0*"2=?7VID:R<@/3X@(DI$2R(L"@DG
M7U]K8B<@/3X@(DM"(BP*"2=?7VMB<',G(#T^(")+0B]S(BP*"2=?7VMB>71E
M<R<@/3X@(FMI;&]B>71E<R(L"@DG7U]K97E?;&EM:71S7V5X8V5E9&EN9R<@
M/3X@(E1H:7,@86-T:6]N(&5X8V5E9',@=&AE(&QI;6ET<R!D969I;F5D(&)Y
M('EO=7(@<V]F='=A<F4@;&EC96YS92X@268@>6]U(')E8V5I=F5D('1H:7,@
M;65S<V%G92!Y;W4@;6%Y(&-O;G1A8W0@>6]U<B!P<F]V:61E<B!O<B!T:&4@
M;6%N=69A8W1U<F5R('1O(&-L87)I9GD@;W(@97AT96YD('1H92!L:6UI=',@
M;V8@=&AI<R!L:6-E;G-E+B(L"@DG7U]K:6QO)R`]/B`B2R(L"@DG7U]K97EW
M;W)D<R<@/3X@)TME>7=O<F1S)RP*"2=?7VQA;F=?=6YK;F]W;B<@/3X@)U5N
M86)L92!T;R!R96-O9VYI>F4@=&AE(&QA;F=U86=E+B<L"@DG7U]L86YG=6%G
M97,G(#T^("=,86YG=6%G92<L"@DG7U]L96%R;E]M;W)E)R`]/B`G3&5A<FX@
M;6]R92<L"@DG7U]L;V-A;&5S)R`]/B`B3&%N9W5A9V4@<&%C:W,B+`H))U]?
M;&EM:70G(#T^("),:6UI="(L"@DG7U]L:6UI=',G(#T^("),:6UI=',B+`H)
M)U]?;&EN:U]U<FQ?:7-?:6YV86QI9"<@/3X@(DQO9V\@55),(&ES(&EN=F%L
M:60N(BP*"2=?7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG7U]L:71E
M<F%L7V)Y=&5S)R`]/B`B0B(L"@DG7U]P<F]C97-S:6YG)R`]/B`B4&QE87-E
M('=A:70N/&)R/DQO861I;F<@+BXN(BP*"2=?7VQO8V%L92<@/3X@(DEN=&5R
M9F%C92!L86YG=6%G92(L"@DG7U]L;V-A;&5?:7-?;F]T7V1E9FEN960G(#T^
M("));G1E<F9A8V4@;&%N9W5A9V4@:7,@;F]T(&1E9FEN960N(BP*"2=?7VQO
M8V%L7W-E<G9E<E]M>7-Q;"<@/3X@)TQO8V%L($UY4U%,('-E<G9E<B<L"@DG
M7U]L;V-A;%]S97)V97)?<&]S=&=R97-Q;"<@/3X@)TQO8V%L(%!O<W1G<F53
M44P@<V5R=F5R)RP*"2=?7VQO9U]F:6QE<R<@/3X@(DQO9R!F:6QE<R(L"@DG
M7U]C;VYF:6=?9FEL97,G(#T^("=#;VYF:6<@9FEL97,G+`H))U]?8VAR;V]T
M7V9I;&5S)R`]/B`G0VAR;V]T960@96YV:7)O;FUE;G0G+`H))U]?;&]G:6XG
M(#T^("(E,2!,;V=I;B(L"@DG7U]L;V=I;C$G(#T^("),;V=I;B(L"@DG7U]L
M;V=I;E]D:7-A8FQE9"<@/3X@(DQO9VEN(&1I<V%B;&5D(BP*"2=?7VQO9VEN
M7V5N86)L960G(#T^("),;V=I;B!E;F%B;&5D(BP*"2=?7VQO9VEN7VEN8V]R
M<F5C="<@/3X@(DQO9VEN(&ES(&EN8V]R<F5C="XB+`H))U]?;&]G:6Y?;F%M
M92<@/3X@(B4Q(&QO9VEN(&YA;64B+`H))U]?;&]G:6Y?;F%M95]I<U]I;G9A
M;&ED)R`]/B`B)3$@;&]G:6X@;F%M92!I<R!I;G9A;&ED+B(L"@DG7U]L;V=O
M;E]T:6UE)R`]/B`B3&]G;VX@=&EM92(L"@DG7U]L;V=O=70G(#T^("),;V<@
M;W5T(BP*"2=?7VUA)R`]/B`B36%I;"!A;&EA<V5S(BP*"2=?7VUA:6PG(#T^
M(")-86EL(BP*"2=?7VUA:6Q?86QI87-?;F%M92<@/3X@(DUA:6P@86QI87,@
M;F%M92(L"@DG7U]M86EL7V5X8VAA;F=E<E]N86UE7VES7VEN=F%L:60G(#T^
M(")-86EL(&5X8VAA;F=E<B!N86UE(&ES(&EN=F%L:60N(BP*"2=?7VUA:6Q?
M9W)O=7!S)R`]/B`B36%I;"!G<F]U<',B+`H))U]?;6%I;%]L:7-T7V5N9VEN
M92<@/3X@(DUA:6QI;F<@;&ES="!S;V9T=V%R92(L"@DG7U]M86EL7VYA;64G
M(#T^(")-86EL(&YA;64B+`H))U]?;6%I;%]N86UE7V9O<FTG(#T^(")-86EL
M(&YA;64@9F]R;2(L"@DG7U]M86EL7VYA;65S)R`]/B`B36%I;"!N86UE<R(L
M"@DG7U]M86EL7VYA;65S7VQI<W0G(#T^(")-86EL(&YA;65S(BP*"2=?7VUA
M:6Q?<V5R=B<@/3X@(DUA:6P@<V5R=F5R(BP*"2=?7VUA:6Q?=7-E<B<@/3X@
M)TUA:6P@=7-E<B<L"@DG7U]M86EL9W)O=7`G(#T^(")-86EL(&=R;W5P(BP*
M"2=?7VUA:6QL:7-T)R`]/B`B36%I;&EN9R!L:7-T(BP*"2=?7VUA:6QL:7-T
M<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))U]?;6%I;&QI<W1?;65M8F5R<R<@
M/3X@)TUA:6QI;F<@;&ES="!M96UB97)S)RP*"2=?7VUA:6QL:7-T7VUE;6)E
M<B<@/3X@)TUA:6QI;F<@;&ES="!M96UB97(G+`H))U]?;6%I;&YA;64G(#T^
M(")-86EL(&YA;64B+`H))U]?;6%I;&YA;65?<F5D:7)?<V5L9B<@/3X@(DUA
M:6P@;F%M92!C86YN;W0@8F4@<F5D:7)E8W1E9"!T;R!I='-E;&8N(BP*"2=?
M7VUA<W1E<B<@/3X@(DUA<W1E<B(L"@DG7U]M87A?9&]M7VYU;5]R96%C:&5D
M7V9O<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@9&]M86EN<R!H
M87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O=6YT+B(L"@DG
M7U]M87A?9FEL95]S:7IE7V%V86EL86)L92<@/3X@(DUA>&EM=6T@9FEL97-I
M>F4@86QL;W=E9"`E,2(L"@DG7U]M87A?<W5B9&]M7VYU;5]R96%C:&5D7V9O
M<E]C;"<@/3X@(E1H92!L:6UI="!O;B!N=6UB97(@;V8@<W5B9&]M86EN<R!H
M87,@8F5E;B!R96%C:&5D(&9O<B!T:&ES(&-L:65N="!A8V-O=6YT+B(L"@DG
M7U]M87A?<W5B9&]M7VYU;5]R96%C:&5D7V9O<E]D;VTG(#T^(")4:&4@;&EM
M:70@;VX@;G5M8F5R(&]F('-U8F1O;6%I;G,@:&%S(&)E96X@<F5A8VAE9"!F
M;W(@=&AE(&1O;6%I;BXB+`H))U]?;6%X7W-U8F1O;5]N=6U?<F5A8VAE9%]F
M;W)?:V5Y)R`]/B`B5&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS
M(&%L;&]W960@8GD@=&AE(&QI8V5N<V4@:V5Y(&AA<R!B965N(')E86-H960N
M(BP*"2=?7VUA>%]T<F%F9FEC7VQI;6ET)R`]/B`B5')A9F9I8R!L:6UI="(L
M"@DG7U]M87AI;75M7V5X8VQ?:7!?;G5M)R`]/B`B36%I;"!N86UE<R(L"@DG
M7U]M8B<@/3X@(DU"(BP*"2=?7VUB>71E<R<@/3X@(FUE9V%B>71E<R(L"@DG
M7U]M8E]M;VYT:"<@/3X@(DU"+VUO;G1H(BP*"2=?7VUE9V$G(#T^(")-(BP*
M"2=?7TUI;G5T97,G(#T^("=-:6YU=&5S)RP*"2=?7VUL<U]N;W1?:6Y?:V5Y
M)R`]/B`B66]U<B!P<F]D=6-T(&ME>2!D;V5S(&YO="!S=7!P;W)T(&UU;'1I
M;&EN9W5A;"!I;G1E<F9A8V4N(BP*"2=?7VUO9&EF:6-A=&EO;E]D871E)R`]
M/B`B36]D:69I8V%T:6]N(&1A=&4B+`H))U]?;6]D=6QE)R`]/B`B36]D=6QE
M(BP*"2=?7VUO9'5L97,G(#T^(")-;V1U;&5S(BP*"2=?7VUO;G1H)R`]/B`B
M36]N=&@B+`H))U]?;6]N=&@H<RDG(#T^(")-;VYT:"AS*2(L"@DG7U]M;VYT
M:#$G(#T^(")*86XB+`H))U]?;6]N=&@Q,"<@/3X@(D]C="(L"@DG7U]M;VYT
M:#$Q)R`]/B`B3F]V(BP*"2=?7VUO;G1H,3(G(#T^(")$96,B+`H))U]?;6]N
M=&@R)R`]/B`B1F5B(BP*"2=?7VUO;G1H,R<@/3X@(DUA<B(L"@DG7U]M;VYT
M:#0G(#T^(")!<')I;"(L"@DG7U]M;VYT:#4G(#T^(")-87DB+`H))U]?;6]N
M=&@V)R`]/B`B2G5N92(L"@DG7U]M;VYT:#<G(#T^(")*=6QY(BP*"2=?7VUO
M;G1H."<@/3X@(D%U9R(L"@DG7U]M;VYT:#DG(#T^(")397!T(BP*"2=?7VUO
M;G1H;'DG(#T^(")-;VYT:&QY(BP*"2=?7VUO;G1H<R<@/3X@(DUO;G1H<R(L
M"@DG7U]M;W9E9%]P97)M86YE;G1L>2<@/3X@)TUO=F5D(%!E<FUA;F5N=&QY
M)RP*"2=?7VUS<W%L)R`]/B`B36EC<F]S;V9T(%-13"!S97)V97(B+`H))U]?
M;7-S<6Q?<W1A='5S)R`]/B`B36EC<F]S;V9T(%-13"!S97)V97(@<W1A='5S
M(BP*"2=?7VUU;'1I<&QY7VQO9VEN7V1E;GDG(#T^(")5;F%B;&4@=&\@;&]G
M('EO=2!O;BX@06YO=&AE<B!U<V5R('=I=&@@=&AE('-A;64@;&]G:6X@;F%M
M92`H)3$I(&ES(&%L<F5A9'D@;&]G9V5D(&EN('1O('1H92!C;VYT<F]L('!A
M;F5L+B(L"@DG7U]M>7-Q;"<@/3X@(DUY4U%,(BP*"2=?7VUY<W%L7W-T871U
M<R<@/3X@(E-13"!S97)V97(@<W1A='5S(BP*"2=?7VUY<W%L7W9E<G-I;VXG
M(#T^(")->7-Q;"!V97)S:6]N(BP*"2=?7VYA;64G(#T^(").86UE(BP*"2=?
M7VYA;65?:6YV86QI9"<@/3X@(DYA;64@:7,@:6YV86QI9"XB+`H))U]?;F%M
M97-E<G9E<B<@/3X@(FYA;65S97)V97(B+`H))U]?;F5T=V]R:R<@/3X@(DYE
M='=O<FLB+`H))U]?;F5T=V]R:W,G(#T^(").971W;W)K<R(L"@DG7U]N971W
M;W)K<U]L:7-T)R`]/B`B3F5T=V]R:W,B+`H))U]?;F5W7W!A<W-W9"<@/3X@
M(DYE=R`E,2!P87-S=V]R9"(L"@DG7U]N97=?<&%S<W=D7W-I;F=L92<@/3X@
M(DYE=R!P87-S=V]R9"(L"@DG7U]N;R<@/3X@(DYO(BP*"2=?7VYO7VEP7V%D
M9')E<W-?=VET:%]P<F]P97)L>5]T>7!E7V%V86EL86)L92<@/3X@(E5N86)L
M92!T;R!R97-T;W)E('1H92!B86-K960@=7`@9&%T82!B96-A=7-E('1H97)E
M(&%R92!N;R!S=6ET86)L92!)4"!A9&1R97-S97,@<F5Q=6ER960@9F]R(')E
M<W1O<FEN9RXB+`H))U]?;F]?8VQI96YT<U]S<&5C:69I960G(#T^(").;R!C
M;&EE;G0@86-C;W5N=',@<W!E8VEF:65D+B(L"@DG7U]N;U]C;VUM96YT<R<@
M/3X@(DYO(&-O;6UE;G1S+B(L"@DG7U]N;U]I<%]S<&5C:69I960G(#T^(").
M;R!I<"!S<&5C:69I960N(BP*"2=?7VYO7W-I=&5?87!P<U]S<&5C:69I960G
M(#T^(").;R!S:71E(&%P<&QI8V%T:6]N<R!S96QE8W1E9"XB+`H))U]?;F]C
M:&%N9V4G(#T^(")$;R!N;W0@8VAA;F=E(BP*"2=?7VYO;&]G:6XG(#T^(")&
M;W)B:61D96XB+`H))U]?;F]N92<@/3X@(DYO;F4B+`H))U]?;F]T7V-O;F9I
M9W5R960G(#T^(").;W0@8V]N9FEG=7)E9"(L"@DG7U]N;W1?<W5P<&]R=&5D
M7V)Y7V9T<"<@/3X@(BAN;W0@<W5P<&]R=&5D(&)Y($944"!S97)V97(I(BP*
M"2=?7VYO=%]S=7!P;W)T961?8GE?;6%I;&UN9R<@/3X@(FYO="!S=7!P;W)T
M960@8GD@=&AE(&UA:6P@<V5R=F5R(BP*"2=?7VYO=&EF:6-A=&EO;B<@/3X@
M(DYO=&EF:6-A=&EO;B(L"@DG7U]N;W1I9FEC871I;VYS)R`]/B`B3F]T:69I
M8V%T:6]N<R(L"@DG7U]N=6U?9&ES<&QA>65D)R`]/B`B)3$@;V8@)3(@9&ES
M<&QA>65D(BP*"2=?7VYU;5]I<U]I;G9A;&ED)R`]/B`B3G5M8F5R(&ES(&EN
M=F%L:60N(BP*"2=?7V]B:F5C=%]N;W1?9F]U;F0G(#T^("=/8FIE8W0@;F]T
M(&9O=6YD.B`E,2<L"@DG7U]O9E]A;&PG(#T^("(E(&]F($%L;"(L"@DG7U]O
M9F8G(#T^(")/9F8B+`H))U]?;VLG(#T^(")/2R(L"@DG7U]O;&1?<&%S<W=D
M)R`]/B`B3VQD("4Q('!A<W-W;W)D(BP*"2=?7V]L9%]P87-S=V1?<VEN9VQE
M)R`]/B`B3VQD('!A<W-W;W)D(BP*"2=?7V]N)R`]/B`B3VXB+`H))U]?;W1H
M97)S)R`]/B`B3W1H97)S(BP*"2=?7V]T:&5R7VEP7U]W:6QL7V)E7V%D9&5D
M)R`]/B`G3W1H97(@879A:6QA8FQE($E0(&%D9')E<W-E<R`H=VEL;"!B92!A
M9&1E9"!T;R!T:&4@8VQI96YT7"=S($E0('!O;VPI)RP*"2=?7V]U="<@/3X@
M(D]U="(L"@DG7U]O=VYE<B<@/3X@(D]W;F5R(BP*"2=?7W`G(#T^(")0(BP*
M"2=?7W!A<W-W9"<@/3X@(B4Q(%!A<W-W;W)D(BP*"2=?7W!A<W-W9%]S:6YG
M;&4G(#T^(")087-S=V]R9"(L"@DG7U]P87-S=V1?:&EN="<@/3X@(D%T(&QE
M87-T(#4@8VAA<F%C=&5R<RP@;F\@;F%T:6]N86P@8VAA<F%C=&5R<R(L"@DG
M7U]P87-S=V1?:7-?:6YV86QI9"<@/3X@(B4Q(%!A<W-W;W)D(&ES(&EN=F%L
M:60N(BP*"2=?7W!A<W-W9%]N;W1?;6%T8V@G(#T^(")087-S=V]R9',@9&\@
M;F]T(&UA=&-H(2(L"@DG7U]P871H)R`]/B`B4&%T:"(L"@DG7U]P97)L7W5N
M:7A?<W5P<&]R="<@/3X@(FUO9%]P97)L('-U<'!O<G0B+`H))U]?<&5R;%]W
M:6Y?<W5P<&]R="<@/3X@(E!E<FP@<W5P<&]R="(L"@DG7U]P97)M7V1E;FEE
M9"<@/3X@(E!E<FUI<W-I;VX@9&5N:65D+B(L"@DG7U]P97)M:7-S:6]N<R<@
M/3X@(E!E<FUI<W-I;VYS(BP*"2=?7W!E<G-O;F%L7VYA;64G(#T^(")097)S
M;VYA;"!N86UE(BP*"2=?7W!G7V%D;6EN7VYO=%]A8W1I=F%T960G(#T^(")0
M;W-T9W)E4U%,('=A<R!N;W0@86-T:79A=&5D(&EN('1H92!S97)V97(@861M
M:6YI<W1R871I;VX@<V5C=&EO;BXB+`H))U]?<&=?;F]T7VEN<W0G(#T^(")0
M;W-T9W)E4U%,('=A<R!N;W0@:6YS=&%L;&5D+B(L"@DG7U]P9U]N;W1?<G5N
M7V]R7VEN<W0G(#T^(")0;W-T9W)E4U%,('=A<R!N;W0@:6YS=&%L;&5D(&]R
M(&ES(&YO="!R=6YN:6YG+B(L"@DG7U]P:&]N92<@/3X@(E!H;VYE(BP*"2=?
M7W!H;W-T:6YG)R`]/B`B4&AY<VEC86P@:&]S=&EN9R(L"@DG7U]P:'!?<W5P
M<&]R="<@/3X@(E!(4"!S=7!P;W)T(BP*"2=?7W!H<%]S869E7VUO9&4G(#T^
M(")02%`@)W-A9F5?;6]D92<@;VXB+`H))U]?<&AP7W9E<G-I;VXG(#T^(")0
M2%`@=F5R<VEO;B(L"@DG7U]P:'ES:6-A;"<@/3X@(E!H>7-I8V%L(&AO<W1I
M;F<B+`H))U]?<&QE<VM?<W1A=%]P9&ER)R`]/B`B4')O=&5C="!D:7)E8W1O
M<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A=%]D:7)?;F%M92<@
M/3X@(D1O;6%I;B!S=&%T:7-T:6-S(BP*"2=?7W!L97-K7W-T871?<')O=&5C
M="<@/3X@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D('!R;W1E8W1E9"!D:7)E
M8W1O<GD@)R]P;&5S:RUS=&%T+R<B+`H))U]?<&QE<VM?<W1A=%]P<F]T96-T
M7VEN<W1A;&PG(#T^(")A8V-E<W-I8FQE('9I82!P87-S=V]R9"!P<F]T96-T
M960@9&ER96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=?7W!L97-K7W-T871?
M=V5B<W1A=%]N;W1?86-T:79A=&4G(#T^(")796(@<W1A=&ES=&EC<R!A<F4@
M;F]T(&5N86)L960N(BP*"2=?7W!O<#-?:6UA<"<@/3X@(E!/4#,O24U!4"(L
M"2\O(&EN9&ER96-T"@DG7U]P;W`S7W-T871U<R<@/3X@(E!/4#,@<V5R=F5R
M('-T871U<R(L"@DG7U]P;W!E;E]E<G)O<B<@/3X@(D%N(&5R<F]R(&]C8W5R
M<F5D('=H:6QE(&-A;&QI;F<@=&AE('!O<&5N(&9U;F-T:6]N+B(L"@DG7U]P
M;W)T)R`]/B`G4&]R="<L"@DG7U]P;W-T9W)E<R<@/3X@(E!O<W1G<F5344PB
M+`H))U]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F5344PB+`H))U]?<&]S=&=R
M97-Q;%]S=&%T=7,G(#T^(")0;W-T9W)E4U%,('-T871U<R(L"@DG7U]P<F5F
M97)E;F-E<R<@/3X@(E!R969E<F5N8V5S(BP*"2=?7V%D;6EN:7-T<F%T;W)?
M<')E9F5R96YC97,G(#T^(")!9&UI;FES=')A=&]R)W,@4')E9F5R96YC97,B
M+`H))U]?86-C;W5N=%]P<F5F97)E;F-E<R<@/3X@(D%C8V]U;G0@4')E9F5R
M96YC97,B+`H))U]?:6YT97)F86-E7W!R969E<F5N8V5S7V=E;F5R86PG(#T^
M("='96YE<F%L)RP*"2=?7VEN=&5R9F%C95]P<F5F97)E;F-E<U]D969A=6QT
M)R`]/B`G1&5F875L="!);G1E<F9A8V4@4')E9F5R96YC97,G+`H))U]?:6YT
M97)F86-E7W!R969E<F5N8V5S7V%D;6EN)R`]/B`B061M:6YI<W1R871O<B=S
M($EN=&5R9F%C92!0<F5F97)E;F-E<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S
M7U]D969A=6QT7VET;7!L)R`]/B`G1&5F875L="!I;G1E<F9A8V4@8W5S=&]M
M:7IA=&EO;B!T96UP;&%T92<L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]A9&UI
M;E]I=&UP;"<@/3X@(D%D;6EN:7-T<F%T;W(G<R!I;G1E<F9A8V4@8W5S=&]M
M:7IA=&EO;B!T96UP;&%T92(L"@DG7U]I;G1E<F9A8V5?=&5M<&QA=&4G(#T^
M("=);G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T92<L"@DG7U]S>7-T
M96U?<')E9F5R96YC97,G(#T^(")3>7-T96T@<')E9F5R96YC97,B+`H))U]?
M:6YT97)F86-E7W!R969E<F5N8V5S)R`]/B`B26YT97)F86-E('!R969E<F5N
M8V5S(BP*"2=?7W!R:6]R:71Y)R`]/B`G4')I;W)I='DG+`H))U]?<')I;W)I
M='E?:&EG:&5S="<@/3X@)VAI9VAE<W0G+`H))U]?<')I;W)I='E?:&EG:"<@
M/3X@)VAI9V@G+`H))U]?<')I;W)I='E?;F]R;6%L)R`]/B`G;F]R;6%L)RP*
M"2=?7W!R:6]R:71Y7VQO=R<@/3X@)VQO=R<L"@DG7U]P<FEO<FET>5]L;W=E
M<W0G(#T^("=L;W=E<W0G+`H))U]?<')I;W)I='E?;W1H97(G(#T^("=C=7-T
M;VTG+`H))U]?<')O8V5E9#\G(#T^(")$;R!Y;W4@=V%N="!T;R!P<F]C965D
M/R(L"@DG7U]P<F]C96YT)R`]/B`B)2(L"@DG7U]P<F]T96-T7V1I<E]U<V5R
M)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U<V5R(BP*"2=?7W!R;W1E8W1?
M9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U<V5R<R(L"@DG
M7U]P<F]T96-T7V1I<G,G(#T^(")0<F]T96-T960@9&ER96-T;W)I97,B+`H)
M)U]?<')O=FED97)?8V]N=&%C=%]N86UE)R`]/B`B4')O=FED97(G<R!C;VYT
M86-T(&YA;64B+`H))U]?<'0G(#T^(")U;FET<R(L"@DG7U]P>71H;VY?=6YI
M>%]S=7!P;W)T)R`]/B`B;6]D7W!Y=&AO;B!S=7!P;W)T(BP*"2=?7W!Y=&AO
M;E]W:6Y?<W5P<&]R="<@/3X@(E!Y=&AO;B!S=7!P;W)T(BP*"2=?7W%U;W1A
M)R`]/B`B475O=&$B+`H))U]?<B<@/3X@(E(B+`H))U]?<F5C;VYF:6=U<F4G
M(#T^(")296-O;F9I9W5R92(L"@DG7U]R96-O<F1?='EP92<@/3X@(E)E8V]R
M9"!T>7!E(BP*"2=?7W)E;&5A<V4G(#T^(")296QE87-E(BP*"2=?7W)E;6]T
M95]D8E]N;W1?<W5P<&]R=&5D7V)Y7VME>2<@/3X@)U)E;6]T92!D871A8F%S
M92!H;W-T:6YG(&ES(&YO="!S=7!P;W)T960@8GD@>6]U<B!L:6-E;G-E(&ME
M>2XG+`H))U]?<F5M;W9E)R`]/B`B4F5M;W9E(BP*"2=?7W)E;6]V95]C;VYF
M:7)M871I;VXG(#T^(")296UO=F%L(&-O;F9I<FUA=&EO;B(L"@DG7U]R97!O
M<G0G(#T^(")297!O<G0B+`H))U]?<F5P;W)T7V%U=&\G(#T^("=$96QI=F5R
M>2!S8VAE9'5L92<L"@DG7U]R97!O<G1?9F]R;2<@/3X@(E)E<&]R="!F;W)M
M(BP*"2=?7W)E<&]R=%]S:7IE7VYA)R`]/B`B4V5R=FEC92!I<R!U;F%V86EL
M86)L92(L"@DG7U]R97!O<G1S7VQI<W0G(#T^(")297!O<G1S(BP*"2=?7W)E
M<75E<W1E9"<@/3X@(E)E<75E<W1E9"(L"@DG7U]R97%U:7)E9%]F:65L9',G
M(#T^(")297%U:7)E9"!F:65L9',B+`H))U]?<F5S<%]N86UE7VEN=F%L:60G
M(#T^(")!=71O<F5S<&]N9&5R(&YA;64@:7,@:6YV86QI9"X@57-E(&]N;'D@
M86QP:&%N=6UE<FEC+"!D;W1S+"!U;F1E<G-C;W)E(&%N9"!W:&ET92!S<&%C
M97,@<WEM8F]L<RXB+`H))U]?8R<@/3X@(D$B+"`O+R!!8V-E<W,@=&\@8V]N
M=')O;"!P86YE;`H))U]?<R<@/3X@(E,B+`H))U]?<V5R=F5R7VYA;65?:7-?
M:6YV86QI9"<@/3X@(E-E<G9E<B!N86UE(&ES(&EN=F%L:60N(BP*"2=?7W-C
M<F5E;G-H;W1S)R`]/B`G4V-R965N<VAO=',G+`H))U]?<V-R:7!T7W=A<FYI
M;F<G(#T^(")">2!R96UO=FEN9R!T:&4@<V-R:7!T:6YG(&-A<&%B:6QI='D@
M9G)O;2!T:&ES(&1O;6%I;B!A;&P@:6YF;'5E;F-E9"!S8W)I<'1S('=I;&P@
M8F4@9&ES<&QA>65D(&EN('!L86EN('1E>'0@=VAE;B!C86QL960@8GD@82!B
M<F]W<V5R+B`@270@:7,@861V:7-A8FQE(&9O<B!T:&4@861M:6YI<W1R871O
M<B!T;R!R96UO=F4@86QL(&1E<&5N9&5N="!S8W)I<'1S(&9R;VT@=&AE(&=I
M=F5N(&1O;6%I;BXB+`H))U]?<V5C)R`]/B`B4V5C;VYD<R(L"@DG7U]S965?
M;&ES=%]O9E]L;V=G961?:6XG(#T^(")3964@=&AE(&QI<W0@;V8@8W5R<F5N
M=&QY(&QO9V=E9"!O;B!U<V5R<RXB+`H))U]?<V5L96-T7V-E<G1S7W1O7W)E
M;6]V92<@/3X@(E-E;&5C="!C97)T:69I8V%T97,@=&\@8F4@<F5M;W9E9"XB
M+`H))U]?<V5L96-T7V-L:65N='-?=&]?<F5M;W9E)R`]/B`B4V5L96-T(&-L
M:65N="!A8V-O=6YT<R!T;R!B92!R96UO=F5D+B(L"@DG7U]S96QE8W1?9&]M
M86EN<U]T;U]D969A=6QT7VAO<W0G(#T^(")396QE8W0@82!D;VUA:6X@=&\@
M<V5T(&%S(&1E9F%U;'0N(BP*"2=?7W-E;&5C=%]D;VUA:6YS7W1O7W)E;6]V
M92<@/3X@(E-E;&5C="!D;VUA:6YS('1O(&)E(')E;6]V960N(BP*"2=?7W-E
M;&5C=%]F:6QE<U]T;U]R96UO=F4G(#T^(")396QE8W0@9FEL97,@=&\@8F4@
M<F5M;W9E9"XB+`H))U]?<V5L96-T7VEP)R`]/B`B4V5L96-T(&%N($E0(&%D
M9')E<W,B+`H))U]?<V5L96-T7VEP7W1O7W)E;6]V92<@/3X@(E-E;&5C="!A
M;B!)4"!A9&1R97-S('1O(&)E(')E;6]V960N(BP*"2=?7W-E;&5C=%]T96UP
M;&%T92<@/3X@(E-E;&5C="!T96UP;&%T92(L"@DG7U]S96QE8W1?=&5M<&QA
M=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!T96UP;&%T97,@=&\@8F4@<F5M
M;W9E9"XB+`H))U]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*"2=?7W-E<G9E<G-?
M;&ES="<@/3X@(E-L879E(%-E<G9E<G,B+`H))U]?<V5R=F5R7W1O=&%L)R`]
M/B`B4V5R=F5R(%1O=&%L(BP*"2=?7W-E<G9I8V4G(#T^(")397)V:6-E(BP*
M"2=?7W-E<G9I8V5S)R`]/B`B4V5R=FEC97,B+`H))U]?<V5S<VEO;G,G(#T^
M(")397-S:6]N<R(L"@DG7U]S97-S:6]N<U]L:7-T)R`]/B`B4V5S<VEO;G,B
M+`H))U]?<V5T)R`]/B`B16YA8FQE(BP*"2=?7W-E='5P7VQO9V]?<')E9B<@
M/3X@(E-E="!U<"!L;V=O('!R;W!E<G1I97,B+`H))U]?<VAA<F5D)R`]/B`B
M4VAA<F5D(BP*"2=?7W-H961U;&5D7V)A8VMU<"<@/3X@(E-H961U;&5D($)A
M8VMU<"(L"@DG7U]S:&5L;%]A8V-E<W-?=V%R;FEN9R<@/3X@(D%L;&]W:6YG
M('-H96QL(&%C8V5S<R!T;R!T:&4@<WES=&5M(&ES(&AI9VAL>2!D86YG97)O
M=7,@9F]R('1H92!S>7-T96T@<V5C=7)I='DN($%L;&]W(&%C8V5S<R!T;R!T
M:&4@<WES=&5M(&]N;'D@:68@>6]U(&-L96%R;'D@=6YD97)S=&%N9"!W:&%T
M('EO=2!A<F4@9&]I;F<L(&%N9"!O;FQY('1O('1R=7-T960@=7-E<G,N($1O
M('EO=2!R96%L;'D@=V%N="!T;R!A;&QO=R!A8V-E<W,_(BP*"2=?7W-I=&5A
M<'!?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B4VET92!A<'!L:6-A=&EO;G,@
M87)E(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y(BP*"2=?7W-I
M=&5A<'!?8V%N;F]T7W)E8V]N9FEG=7)E7W=I=&A?<F5M;W1E7V1A=&%B87-E
M)R`]/B`G5&AE(&-O;F9I9W5R871I;VX@;V8@=&AI<R!S:71E(&%P<&QI8V%T
M:6]N(&AA<R!B965N(&-H86YG960@;6%N=6%L;'DN($EN(&]R9&5R('1O('!R
M;W1E8W0@=&AE(&UA;G5A;"!M;V1I9FEC871I;VYS+"!R96-O;F9I9W5R871I
M;VX@=&AR;W5G:"!0;&5S:R!I<R!D:7-A;&QO=V5D+B<L"@DG7U]S:71E87!P
M7VQO8V%L7V1B7V1I<V%L;&]W960G(#T^("=!(')E;6]T92!D871A8F%S92!S
M97)V97(@:&%S(&)E96X@<V5L96-T960@87,@=&AE(&1E9F%U;'0@9&%T86)A
M<V4@;&]C871I;VXL(&)U="!T:&ES('-I=&4@87!P;&EC871I;VX@:7,@=6YA
M8FQE('1O('5S92!A(')E;6]T92!D871A8F%S92X@5&AE('-I=&4@87!P;&EC
M871I;VX@8V%N;F]T(&)E(&EN<W1A;&QE9"X@06X@=7!G<F%D92!O9B!T:&4@
M<VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(')E8V]M;65N9&5D+B<L"@DG
M7U]S:71E87!P7W)E;6]T95]D871A8F%S92<@/3X@)U1H92!D871A8F%S92!C
M86X@8F4@:&]S=&5D(&]N(&$@<F5M;W1E('-E<G9E<BXG+`H))U]?<VET95]A
M<'!L:6-A=&EO;B<@/3X@(E-I=&4@07!P;&EC871I;VXB+`H))U]?<VET95]A
M<'!L:6-A=&EO;E]P86-K86=E)R`]/B`B4VET92!!<'!L:6-A=&EO;B!086-K
M86=E(BP*"2=?7W-I=&5?87!P;&EC871I;VY?<&%C:V%G97,G(#T^(")3:71E
M($%P<&QI8V%T:6]N(%!A8VMA9V5S(BP*"2=?7W-I=&5?87!P;&EC871I;VYS
M)R`]/B`B4VET92!!<'!L:6-A=&EO;G,B+`H))U]?<VET95]M86YA9V5M96YT
M)R`]/B`B5V5B(%!U8FQI<VAI;F<B+`DO+R!I;F1I<F5C=`H))U]?<VEZ92<@
M/3X@(E-I>F4B+`H))U]?<VME;&5T;VXG(#T^(")3:V5L971O;B(L"@DG7U]S
M:VEN<R<@/3X@)U-K:6YS)RP*"2=?7W-M='`G(#T^(")33510(BP)+R\@:6YD
M:7)E8W0*"2=?7W-M='!?<W1A='5S)R`]/B`B4TU44"!S97)V97(@<W1A='5S
M(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O<E]I;G9A;&ED)R`]/B`B
M4V]M92!F:65L9',@87)E(&5M<'1Y(&]R(&-O;G1A:6X@86X@:6UP<F]P97(@
M=F%L=64N(BP*"2=?7W-O;65?9FEE;&1S7V%R95]E;7!T>5]O<E]I;G9A;&ED
M7V]R7VQO;F<G(#T^(")3;VUE(&9I96QD<R!A<F4@96UP='D@;W(@8V]N=&%I
M;B!A;B!I;7!R;W!E<B!V86QU92X@5&AE('9A;'5E<R!S:&]U;&0@8F4@;&EM
M:71E9"!T;R`V-"!C:&%R86-T97)S+B!)9B!Y;W4@87)E('5S:6YG(&%N(&EN
M=&5R;F%T:6]N86QI>F5D(&1O;6%I;B!N86UE+"!M86ME('-U<F4@96%C:"!P
M87)T(&]F('1H92!D;VUA:6X@;F%M92!B971W965N(&1O=',@9&]E<R!N;W0@
M97AC965D(#8S('-Y;6)O;',@=VAE;B!T<F%N<V9O<FUE9"!T;R!!4T-)22!F
M;W)M870N(BP*"2=?7W-P86UA<W-A<W-I;B<@/3X@(E-P86U!<W-A<W-I;B(L
M"@DG7U]S<&%M87-S87-S:6Y?<W1A='5S)R`]/B`B4W!A;4%S<V%S<VEN('-T
M871U<R(L"@DG7U]S<&QI=&5D7V)A8VMU<"<@/3X@(BAM=6QT:79O;'5M92!B
M86-K=7`I(BP*"2=?7W-P;&ET7V)A8VMU<%]F:6QE)R`]/B`B0W)E871E(&$@
M;75L=&EV;VQU;64@8F%C:W5P(BP*"2=?7W-P;&ET7V)A8VMU<%]S:7IE)R`]
M/B`B5F]L=6UE('-I>F4B+`H))U]?<W!L:71?8F%C:W5P7VQE<W-?=&AA;E\U
M,#`G(#T^(")6;VQU;64@<VEZ97,@;&5S<R!T:&%N(#4P,"!M96=A8GET97,@
M87)E(&YO="!S=7!P;W)T960B+`H))U]?<W-I)R`]/B`B4U-)(BP*"2=?7W-S
M:5]S=7!P;W)T)R`]/B`B4U-)('-U<'!O<G0B+`H))U]?<W-L)R`]/B`G4U-,
M)RP*"2=?7W-S;%]S=7!P;W)T)R`]/B`B4U-,('-U<'!O<G0B+`H))U]?<V%M
M95]S<VPG(#T^(")5<V4@82!S:6YG;&4@9&ER96-T;W)Y(&9O<B!H;W5S:6YG
M(%-33"!A;F0@;F]N+5-33"!C;VYT96YT(BP*"2=?7W-A;65?<W-L7V-U)R`]
M/B`B0V]M;6]N(%-33"].;VXM4U-,(&-O;G1E;G0B+`H))U]?<W1A=&4G(#T^
M(")3=&%T92]0<F]V:6YC92(L"@H))U]?<W1A='5S7U]!8W1I=F4G(#T^("=!
M8W1I=F4G+`H))U]?<W1A='5S7U]A8W1I=F4G(#T^("=A8W1I=F4G+`H))U]?
M<W1A='5S7U]087-S:79E)R`]/B`G1&ES86)L960G+`H))U]?<W1A='5S7U]P
M87-S:79E)R`]/B`G9&ES86)L960G+`H))U]?<W1A='5S7U]O9F8G(#T^("=D
M:7-A8FQE9"<L"@DG7U]S=&%T=7-?7W=I=&A?<&%R96YT)R`]/B`G9&ES86)L
M960G+`H))U]?<W1A='5S7U]B86-K=7!?<F5S=&]R92<@/3X@)W1E;7!O<F%R
M:6QY('-U<W!E;F1E9"!F;W(@8F%C:VEN9R!U<"!O<B!R97-T;W)I;F<G+`H)
M)U]?<W1A='5S7U]A9&UI;B<@/3X@)V1I<V%B;&5D(&)Y(&%D;6EN)RP*"2=?
M7W-T871U<U]?<F5S<V5L97(G(#T^("=D:7-A8FQE9"!B>2!R97-E;&QE<B<L
M"@DG7U]S=&%T=7-?7V-L:65N="<@/3X@)V1I<V%B;&5D(&)Y(&-L:65N="<L
M"@DG7U]S=&%T=7-?7W5N:VYO=VXG(#T^("=S=&%T=7,@:7,@=6YK;F]W;B<L
M"@H))U]?<W1A='5S7V]F)R`]/B`B)3$@<W1A='5S(BP*"@DO+R!E;F0@;V8@
M86MS<R!P87)T"@H)+R\@<VAR86UK;R!P87)T"@H))U]?<W1U;FYE;"<@/3X@
M(E-T=6YN96PB+`H))U]?<W1U;FYE;%]S97)V97(G(#T^(")3='5N;F5L('-E
M<G9E<B(L"2\O(&EN9&ER96-T"@DG7U]S=6)D;VUA:6XG(#T^(")3=6)D;VUA
M:6XB+`H))U]?<W5B9&]M86EN7VYA;64G(#T^(")3=6)D;VUA:6X@;F%M92(L
M"@DG7U]S=6)D;VUA:6Y?;F%M95]I;E]!4T-)25]F;W)M)R`]/B`B26X@05-#
M24D@9F]R;6%T(BP*"2=?7W-U8F1O;6%I;G,G(#T^(")3=6)D;VUA:6YS(BP*
M"2=?7W-U8F1O;6%I;G-?;&ES="<@/3X@(E-U8F1O;6%I;G,B+`H))U]?<W5B
M9&]M86EN<U]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3=6)D;VUA:6X@;W!E
M<F%T:6]N<R!A<F4@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DB
M+`H))U]?<WES7W5S97)?='EP92<@/3X@(D944"!U<V5R(BP*"2=?7W-Y<U]U
M<V5R7W1Y<&5?;6%I;B<@/3X@(E5S92!T:&4@1E10('5S97(@86-C;W5N="!O
M9B!T:&4@;6%I;B!D;VUA:6XB+`H))U]?<WES7W5S97)?='EP95]N871I=F4G
M(#T^(")#<F5A=&4@82!S97!A<F%T92!&5%`@=7-E<B!A8V-O=6YT(&9O<B!T
M:&ES('-U8F1O;6%I;B(L"@DG7U]T)R`]/B`B5"(L"@DG7U]T87)G971?9&]M
M86EN)R`]/B`B5&%R9V5T(&1O;6%I;B(L"@DG7U]T87-K)R`]/B`G5&%S:R<L
M"@DG7U]T87-K<U]L:7-T)R`]/B`G5&%S:W,G+`H))U]?=&5M<&QA=&4G(#T^
M(")496UP;&%T92(L"@DG7U]T96UP;&%T95]N;W1?86-C97!T960G(#T^(")5
M;F%B;&4@=&\@86-C97!T('1H92!T96UP;&%T93H@=&AE(&9O;&QO=VEN9R!L
M:6UI=&%T:6]N<R!A<F4@97AC965D960N(BP*"2=?7W1E;7!L871E<R<@/3X@
M(E1E;7!L871E<R(L"@DG7U]T96UP;&%T97-?;&ES="<@/3X@(E1E;7!L871E
M<R(L"@DG7U]T97)A)R`]/B`B5"(L"@DG7U]T97AT)R`]/B`B5&5X="(L"@DG
M7U]T:71L92<@/3X@(E1I=&QE(BP*"2=?7W1O;6-A="<@/3X@(E1O;6-A="(L
M"@DG7U]T;VUC871?;F]T7W-U<'!O<G1?:6Y?:V5Y)R`]/B`B5&]M8V%T(&ES
M(&YO="!S=7!P;W)T960@8GD@=&AE(&QI8V5N<V4@:V5Y(BP*"2=?7W-P86UA
M<W-A<W-I;E]N;W1?<W5P<&]R=%]I;E]K97DG(#T^(")3<&%M07-S87-S:6X@
M:7,@;F]T('-U<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DB+`H))U]?=&]M
M8V%T7W-T871U<R<@/3X@(E1O;6-A="!S=&%T=7,B+`H))U]?=&]O;',G(#T^
M(")4;V]L<R(L"@DG7U]T;W1A;"<@/3X@(E1O=&%L("4Q(BP*"2=?7W1O=&%L
M7W-I>F4G(#T^(")4;W1A;"!S:7IE(BP*"2=?7W1O=&%L7W5S960G(#T^(")4
M;W1A;"!5<V5D(BP*"2=?7W1T<R<@/3X@(DAE;'`@1&5S:R(L"@DG7U]T<F%F
M9FEC)R`]/B`B5')A9F9I8R(L"@DG7U]T<F%F9FEC7V)Y7V-L:65N="<@/3X@
M(E1R869F:6,@8GD@8VQI96YT(BP*"2=?7W1R869F:6-?8GE?9&]M86EN)R`]
M/B`B5')A9F9I8R!B>2!D;VUA:6XB+`H))U]?=')A9F9I8U]B>5]S97)V:6-E
M)R`]/B`B5')A9F9I8R!B>2!S97)V:6-E(BP*"2=?7W1R869F:6-?:&ES=&]R
M>2<@/3X@(E1R869F:6,@:&ES=&]R>2(L"@DG7U]U;F%B;&5?8VAA;F=E7VQO
M8V%L92<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&EN=&5R9F%C92!L86YG
M=6%G93H@)3$B+`H))U]?=6YA8FQE7V-R96%T95]N97=?9&]M)R`]/B`B56YA
M8FQE('1O(&-R96%T92!N97<@9&]M86EN.B`E,2(L"@DG7U]U;F%B;&5?9&5F
M:6YE7V1O;5]N86UE)R`]/B`B56YA8FQE('1O(&1E9FEN92!D;VUA:6X@;F%M
M93H@)3$B+`H))U]?=6YA8FQE7V1E9FEN95]N96-E<W-A<GE?<')O<&5R=&EE
M<R<@/3X@(E5N86)L92!T;R!D969I;F4@86QL(')E<75I<F5D('!R;W!E<G1I
M97,N(BP*"2=?7W5N86)L95]D969I;F5?<')O<&5R=&EE<R<@/3X@(E5N86)L
M92!T;R!D969I;F4@<')O<&5R=&EE<SH@)3$B+`H))U]?=6YA8FQE7V5X96-?
M=71I;"<@/3X@(E5N86)L92!T;R!E>&5C=71E('5T:6QI='DZ("4Q(BP*"2=?
M7W5N86)L95]G96YE<F%T95]C97)T)R`]/B`B56YA8FQE('1O(&=E;F5R871E
M(&-E<G1I9FEC871E.B`E,2(L"@DG7U]U;F%B;&5?9V5N97)A=&5?8W-R)R`]
M/B`B56YA8FQE('1O(&=E;F5R871E($-34CH@)3$B+`H))U]?=6YA8FQE7V=E
M=%]D;G-?85]R96-S)R`]/B`B56YA8FQE('1O(')E=')I979E(&EP(&%D9')E
M<W-E<R!F;W(@02!$3E,@<F5C;W)D<R!F;W(@=&AI<R!H;W-T:6YG(&%C8V]U
M;G0Z("4Q(BP*"2=?7W5N86)L95]G971?;6)O>%]Q=6]T82<@/3X@(E5N86)L
M92!T;R!R971R:65V92!T:&4@:6YF;W)M871I;VX@;VX@=&AE(&UA:6QB;W@@
M<VEZ92!L:6UI="XB+`H))U]?=6YA8FQE7W)E9&ER96-T7W1O7VUY<V5L9B<@
M/3X@(E5N86)L92!T;R!R961I<F5C="!T;R!O;F5S96QF+B(L"@DG7U]U;F%B
M;&5?<F5M;W9E7V-L:65N="<@/3X@(E5N86)L92!T;R!R96UO=F4@8VQI96YT
M.B`E,2(L"@DG7U]U;F%B;&5?<V5T7W5P7VUB;WA?<75O=&$G(#T^(")5;F%B
M;&4@=&\@<V5T('1H92!M86EL8F]X('-I>F4@;&EM:70@9F]R('1H92!D;VUA
M:6XZ("4Q(BP*"2=?7W5N86)L95]S971U<%]P87-S)R`]/B`B56YA8FQE('1O
M('-E="!P87-S=V]R9#H@)3$B+`H))U]?=6YA8FQE7W1O7V-R96%T95]N97=?
M86-C;W5N="<@/3X@(E5N86)L92!T;R!C<F5A=&4@;F5W(&%C8V]U;G0Z("4Q
M(BP*"2=?7W5N86)L95]T;U]D969I;F5?9&)?<VEZ92<@/3X@(E5N86)L92!T
M;R!D969I;F4@=&AE(&1A=&%B87-E('-I>F4B+`H))U]?=6YA8FQE7W1O7V5N
M86)L95]S:&]R=%]N86UE<R<@/3X@(E5N86)L92!T;R!A;&QO=R!T:&4@=7-E
M(&]F('-H;W)T(&UA:6P@;F%M97,@9F]R(%!/4#,O24U!4"!A8V-O=6YT<RXB
M+`H))U]?=6YA8FQE7W1O7V9E=&-H7V1A=&%?9G)O;5]S=6)M:70G(#T^(")5
M;F%B;&4@=&\@9F5T8V@@=&AE('-U8FUI='1E9"!D871A.B`E,2(L"@DG7U]U
M;F%B;&5?=&]?;W!E;E]F:6QE)R`]/B`B56YA8FQE('1O(&]P96X@=&AE(&9I
M;&4@)3$Z("4R+B(L"@DG7U]U;F%B;&5?=&]?=7!D871E7W-U8F1O;6%I;B<@
M/3X@(E5N86)L92!T;R!M86ME(&-H86YG97,@=&\@=&AE('-U8F1O;6%I;CH@
M)3$B+`H))U]?=6YA8FQE7W5P9&%T95]C;%]D871A)R`]/B`B56YA8FQE('1O
M('5P9&%T92!C;&EE;G0@9&%T83H@)3$B+`H))U]?=6YA8FQE7W5P9&%T95]D
M8E]P87)A;7,G(#T^(")5;F%B;&4@=&\@=7!D871E(&1A=&%B87-E('!A<F%M
M971E<G,Z("4Q(BP*"2=?7W5N86)L95]U<&1A=&5?9&]M7V1A=&$G(#T^(")5
M;F%B;&4@=&\@=7!D871E(&1O;6%I;B!D871A.B`E,2(L"@DG7U]U;F1E9FEN
M960G(#T^(")U;F1E9FEN960B+`H))U]?=6YI;G-T86QL)R`]/B`B56YI;G-T
M86QL(BP*"2=?7W5N:VYO=VY?97)R;W(G(#T^(")5;FMN;W=N(&5R<F]R(BP*
M"2=?7W5N;&EM:71E9"<@/3X@(E5N;&EM:71E9"(L"@DG7U]U;FQI;6ET961?
M;&]W97(G(#T^(")5;FQI;6ET960B+`H))U]?=6YS970G(#T^(")$:7-A8FQE
M(BP*"2=?7W5P9&%T92<@/3X@(E5P9&%T92(L"@DG7U]U<&QO861?8V5R=%]F
M:6QE)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&9I;&4@(BP*"2=?7W5P;&]A
M9&5D7V9I;&5?:7-?:6YV86QI9"<@/3X@(E5P;&]A9&5D(&9I;&4@:7,@:6YV
M86QI9#H@)3$B+`H))U]?=7)L)R`]/B`B55),(BP*"2=?7W5S86=E)R`]/B`B
M1&ES:R!U<V%G92(L"@DG7U]U<V5D)R`]/B`B57-E9"(L"@DG7U]U<V5R)R`]
M/B`B57-E<B(L"@DG7U]U<V5R7V%L<F5A9'E?97AI<W0G(#T^(")5<V5R("4Q
M(&%L<F5A9'D@97AI<W1S+B(L"@DG7U]U<V5R7V%L<F5A9'E?97AI<W1S)R`]
M/B`B57-E<B`E,2!A;')E861Y(&5X:7-T<RXB+`H))U]?=7-E<E]A;')E861Y
M7VQO9V=E9"<@/3X@(D%N;W1H97(@=7-E<B!W:71H('1H92!S86UE(&QO9VEN
M("@E,2D@:7,@86QR96%D>2!L;V=G960@;VX@=&\@=&AE("!C;VYT<F]L('!A
M;F5L+B(L"@DG7U]V86QU92<@/3X@(E9A;'5E(BP*"2=?7W9E<G-I;VXG(#T^
M(")697)S:6]N(BP*"2=?7W9H7W1Y<&4G(#T^(")6:7)T=6%L(&AO<W0@='EP
M92(L"@DG7U]V:&]S='-?87!A8VAE7W-T871U<R<@/3X@(E=E8B!S97)V97(@
M<W1A='5S(BP*"2=?7W=R;VYG7V-H87)S971?8V]N=F5R<VEO;B<@/3X@)U=R
M;VYG(&-H87)S970L(&-O;G9E<G-I;VX@9G)O;2`B)3$B('1O("(E,B(@:7,@
M;F]T(&%L;&]W960G+`H))U]?=V%R;FEN9U\G(#T^(")787)N:6YG(2(L"@DG
M7U]W87)N:6YG7V5X8VQ?:7!?;G5M)R`]/B`B17AC;'5S:79E($E0(&%D9')E
M<W,B+`H))U]?=V%R;FEN9U]E>'!I<F%T:6]N)R`]/B`B17AP:7)A=&EO;B!D
M871E(BP*"2=?7W=E8E]A<'!S)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H)
M)U]?=V5B7W-C<FEP=&EN9R<@/3X@(E=E8B!S8W)I<'1I;F<B+`DO+R!I;F1I
M<F5C=`H))U]?=V5B7W-E<G8G(#T^(")796(@<V5R=F5R(BP)+R\@:6YD:7)E
M8W0*"2=?7W=E8E]S=&%T:7-T:6,G(#T^(")796(@<W1A=&ES=&EC<R(L"2\O
M(&EN9&ER96-T"@DG7U]W96)M86EL)R`]/B`B5V5B36%I;"(L"2\O("MI;F1I
M<F5C=`H))U]?=V5B<W1A=%]N;W1?:6YS=&%L;&5D)R`]/B`B5V5B86QI>F5R
M(&ES(&YO="!C=7)R96YT;'D@:6YS=&%L;&5D(&]N('1H92!S97)V97(N($-O
M;G1A8W0@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R('1O(&AA=F4@=&AE(%=E
M8F%L:7IE<B!I;G-T86QL960N(BP*"2=?7W=E8G-T871?<W5P<&]R="<@/3X@
M(E=E8B!S=&%T:7-T:6-S(BP*"2=?7W=E8G5S97(G(#T^(")796(@=7-E<B(L
M"@DG7U]W96)U<V5R<U]L:7-T)R`]/B`B5V5B('5S97)S(BP*"2=?7W=E96ML
M>2<@/3X@(E=E96ML>2(L"@DG7U]W:&%T<U]N97=?:6Y?=F5R<VEO;B<@/3X@
M(E=H870G<R!N97<@:6X@4&QE<VL@)3$_(BP*"2=?7W=R;VYG7VAO<W1I;F=?
M='EP95]?;F]N92<@/3X@)U1H97)E(&ES(&YO('!H>7-I8V%L(&AO<W1I;F<@
M8V]N9FEG=7)E9"!O;B!T:&ES(&1O;6%I;BXG+`H))U]?=W)O;F=?:&]S=&EN
M9U]T>7!E7U]S=&1?9G=D)R`]/B`G5&AI<R!D;VUA:6X@:&%S('-T86YD87)D
M(&9O<G=A<F1I;F<@8V]N9FEG=7)E9"X@5&AI<R!O<&5R871I;VX@:7,@879A
M:6QA8FQE(&]N;'D@9F]R(&1O;6%I;G,@=VET:"!P:'ES:6-A;"!H;W-T:6YG
M+B<L"@DG7U]W<F]N9U]H;W-T:6YG7W1Y<&5?7V9R;5]F=V0G(#T^("=4:&ES
M(&1O;6%I;B!H87,@9G)A;64@9F]R=V%R9&EN9R!C;VYF:6=U<F5D+B!4:&ES
M(&]P97)A=&EO;B!I<R!A=F%I;&%B;&4@;VYL>2!F;W(@9&]M86EN<R!W:71H
M('!H>7-I8V%L(&AO<W1I;F<N)RP*"2=?7W=U)R`]/B`B5V5B('5S97)S(BP*
M"2=?7W=W=R<@/3X@(E=75R(L"@DG7U]W=W=?<')E9FEX)R`]/B`B5U=7('!R
M969I>"(L"@DG7U]W=W=?<')E9FEX7W=A<U]C:&%N9V5D)R`]/B`B5U=7('!R
M969I>"!W87,@8VAA;F=E9"X@0F4@<W5R92!T;R!M;V1I9GD@=&AE(%-33"!C
M97)T:69I8V%T92!A8V-O<F1I;F=L>2XB+`H))U]?>65A<B<@/3X@(EEE87(B
M+`H))U]?>65A<BAS*2<@/3X@(EEE87(H<RDB+`H))U]?>65S)R`]/B`B665S
M(BP*"2=?7WEO=2<@/3X@(EEO=2(L"@DG7U]Z:7!?8V]D92<@/3X@(E!O<W1A
M;"]:25`@8V]D92(L"@DG7U]F;W)M7VYO<FUA;"<@/3X@(DYO<FUA;"(L"@DG
M7U]F;W)M7V%D=F%N8V5D)R`]/B`B061V86YC960B+`H*"2=?7VUA>%]D;VUA
M:6YS7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@)3(@9&]M86EN*',I('5S960[
M("4S(&%V86EL86)L92<L"@DG7U]M87A?9&]M86EN<U]N;U]L:6UI=%]U<V%G
M92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D;VUA:6YS('5S960G+`H))U]?;6%X
M7VUA:6QB;WAE<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R(&UA:6QB;W@H
M97,I('5S960[("4S(&%V86EL86)L92<L"@DG7U]M87A?;6%I;&)O>&5S7VYO
M7VQI;6ET7W5S86=E)R`]/B`G)3$@;V8@=6YL:6UI=&5D(&UA:6QB;WAE<R!U
M<V5D)RP*"2=?7V1I<VM?<W!A8V5?;&EM:71?=7-A9V4G(#T^("<E,2!O9B`E
M,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?9&ES:U]S<&%C95]N;U]L:6UI
M=%]U<V%G92<@/3X@)R4Q(&]F('5N;&EM:71E9"!D:7-K('-P86-E('5S960G
M+`H))U]?=')A9F9I8U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R('5S960[
M("4S(&%V86EL86)L92<L"@DG7U]T<F%F9FEC7VYO7VQI;6ET7W5S86=E)R`]
M/B`G)3$@;V8@=6YL:6UI=&5D('1R869F:6,@=7-E9"<L"@DG7U]M87A?<W5B
M9&]M86EN<U]L:6UI=%]U<V%G92<@/3X@)R4Q(&]F("4R('-U8F1O;6%I;BAS
M*2!U<V5D.R`E,R!A=F%I;&%B;&4G+`H))U]?;6%X7W-U8F1O;6%I;G-?;F]?
M;&EM:71?=7-A9V4G(#T^("<E,2!O9B!U;FQI;6ET960@<W5B9&]M86EN<R!U
M<V5D)RP*"@DG7U]M96U?=7-A9V5?:6YF;R<@/3X@)R4Q(&]F("4R('5S960[
M("4S(&%V86EL86)L92<L"@DG7U]D:7-K7W5S86=E7VEN9F\G(#T^("<E,2!O
M9B`E,B!U<V5D.R`E,R!A=F%I;&%B;&4G+`H*"2=A8W1I;VYL;V=?7V-O;F9I
M<FU?8VQE86Y?;&]G)R`]/B`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(&1E
M;&5T92!T:&4@<V5L96-T960@86-T:6]N(&QO9R!R96-O<F1S/R(L"@DG86-T
M:6]N;&]G7U]D:6=I=%]E>'!E8W1E9"<@/3X@(D$@;G5M8F5R(&5X<&5C=&5D
M.B`E,2(L"@DG86-T:6]N;&]G7U]D;VYT7W)E;6]V95]R96-S)R`]/B`B9&\@
M;F]T(')E;6]V92!R96-O<F1S(BP*"2=A8W1I;VYL;V=?7V9R;VU?9&%T92<@
M/3X@(F9R;VTZ(BP*"2=A8W1I;VYL;V=?7VEN8V]R<F5C=%]R;W1A=&EO;B<@
M/3X@(DEN=F%L:60@;&]G(')O=&%T:6]N('!A<F%M971E<G,@<W!E8VEF:65D
M.B`E,2(L"@DG86-T:6]N;&]G7U]J<U]I;F-O<G)E8W1?9&%T92<@/3X@(DEN
M=F%L:60@9&%T92!S<&5C:69I960B+`H))V%C=&EO;FQO9U]?:G-?:6YC;W)R
M96-T7VYU;5]P97)I;V1S)R`]/B`B26YV86QI9"!R;W1A=&EO;B!P97)I;V0@
M<W!E8VEF:65D(BP*"2=A8W1I;VYL;V=?7VIS7VEN8V]R<F5C=%]N=6U?<F5C
M;W)D<R<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(')E8V]R9',@<W!E8VEF:65D
M(BP*"2=A8W1I;VYL;V=?7VQO9V=E9%]A8W1I;VYS)R`]/B`B3&]G9V5D(&%C
M=&EO;G,B+`H))V%C=&EO;FQO9U]?<&5R:6]D7V1A>2<@/3X@(F1A>7,B+`H)
M)V%C=&EO;FQO9U]?<&5R:6]D7VUO;G1H)R`]/B`B;6]N=&AS(BP*"2=A8W1I
M;VYL;V=?7W!E<FEO9%]W965K)R`]/B`B=V5E:W,B+`H))V%C=&EO;FQO9U]?
M<V5T=&EN9W,G(#T^(")!8W1I;VX@;&]G('-E='1I;F=S(BP*"2=A8W1I;VYL
M;V=?7W-T;W)E7VQO9W-?:6Y?9&(G(#T^(")3=&]R92!R96-O<F1S(&EN('1H
M92!D871A8F%S92(L"@DG86-T:6]N;&]G7U]S=&]R95]N=6UB97(G(#T^(")E
M;G1R:65S(BP*"2=A8W1I;VYL;V=?7W1O7V1A=&4G(#T^(")T;SHB+`H))V%C
M=&EO;FQO9U]?=6YK;F]W;E]R;W1?<&5R:6]D)R`]/B`B56YK;F]W;B!R;W1A
M=&EO;B!P97)I;V0Z("4Q(BP*"2=A8W1I;VYL;V=?7W5N:VYO=VY?<F]T7W1Y
M<&4G(#T^(")5;FMN;W=N(')O=&%T:6]N('1Y<&4Z("4Q(BP*"2=A8W1I;VYL
M;V=?7W=R;VYG7V1A=&5?<&5R:6]D)R`]/B`B26YV86QI9"!D871E(BP*"2=A
M8W1I;VYL;V=?7W-E<W-I;VY?<')E9F5R96YC97,G(#T^("=,;V=I;B!S971T
M:6YG<R<L"@H))V%C=&EO;FQO9U]?861M:6Y?:6YF;R<@/3X@)T%D;6EN:7-T
M<F%T;W(@:6YF;W)M871I;VXG+`H))V%C=&EO;FQO9U]?<V5R=FEC92<@/3X@
M)U-E<G9I8V4G+`H))V%C=&EO;FQO9U]?:7!?861D<B<@/3X@)TE0(&%D9')E
M<W,G+`H))V%C=&EO;FQO9U]?8VQI96YT)R`]/B`G0VQI96YT(&%C8V]U;G0G
M+`H))V%C=&EO;FQO9U]?8VQI96YT7W-T871U<R<@/3X@)T-L:65N="!A8V-O
M=6YT('-T871U<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?<')E9F5R96YC97,G
M(#T^(")#;&EE;G0G<R!I;G1E<F9A8V4@<')E9F5R96YC97,B+`H))V%C=&EO
M;FQO9U]?8VQI96YT7VQI;6ET<R<@/3X@)T-L:65N="!A8V-O=6YT(&QI;6ET
M<R<L"@DG86-T:6]N;&]G7U]C;&EE;G1?;&EM:71?<VEZ92<@/3X@(D1I<VL@
M<W!A8V4@;&EM:70@9F]R(&-L:65N="!A8V-O=6YT(BP*"2=A8W1I;VYL;V=?
M7V-L:65N=%]L:6UI=%]T<F%F9FEC)R`]/B`B5')A9F9I8R!L:6UI="!F;W(@
M8VQI96YT(&%C8V]U;G0B+`H))V%C=&EO;FQO9U]?8VQI96YT7W!E<FUI<W-I
M;VYS)R`]/B`B0VQI96YT)W,@<&5R;6ES<VEO;G,B+`H))V%C=&EO;FQO9U]?
M8VQI96YT7VEP7W!O;VPG(#T^(")#;&EE;G0G<R!)4"!P;V]L(BP*"2=A8W1I
M;VYL;V=?7V-L:65N=%]S:71E87!P)R`]/B`B0VQI96YT)W,@<VET92!A<'!L
M:6-A=&EO;B!P;V]L(BP*"2=A8W1I;VYL;V=?7V1O;6%I;E]U<V5R)R`]/B`G
M1&]M86EN(&%D;6EN:7-T<F%T;W(@86-C;W5N="<L"@DG86-T:6]N;&]G7U]D
M;VUA:6XG(#T^("=$;VUA:6XG+`H))V%C=&EO;FQO9U]?9&]M86EN7V]W;F5R
M)R`]/B`G1&]M86EN(&]W;F5R)RP*"2=A8W1I;VYL;V=?7V1O;6%I;E]S=&%T
M=7,G(#T^("=$;VUA:6X@<W1A='5S)RP*"2=A8W1I;VYL;V=?7V1O;6%I;E]D
M;G,G(#T^("=$;VUA:6X@1$Y3('IO;F4G+`H))V%C=&EO;FQO9U]?<W5B9&]M
M86EN)R`]/B`G4W5B9&]M86EN)RP*"2=A8W1I;VYL;V=?7V1A<VAB;V%R9%]P
M<F5S970G(#T^("=$97-K=&]P('!R97-E="<L"@DG86-T:6]N;&]G7U]D;VUA
M:6Y?86QI87,G(#T^("=$;VUA:6X@86QI87,G+`H))V%C=&EO;FQO9U]?9&]M
M86EN7V%L:6%S7V1N<R<@/3X@)T1O;6%I;B!A;&EA<R!$3E,@>F]N92<L"@DG
M86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71S)R`]/B`G1&]M86EN(&QI;6ET<R<L
M"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM:71?<VEZ92<@/3X@)T1I<VL@<W!A
M8V4@;&EM:70@9F]R(&1O;6%I;B<L"@DG86-T:6]N;&]G7U]D;VUA:6Y?;&EM
M:71?=')A9F9I8R<@/3X@)U1R869F:6,@;&EM:70@9F]R(&1O;6%I;B<L"@DG
M86-T:6]N;&]G7U]C<%]U<V5R)R`]/B`G0V]N=')O;"!P86YE;"!U<V5R)RP*
M"2=A8W1I;VYL;V=?7VUA:6QN86UE)R`]/B`G36%I;"!N86UE)RP*"2=A8W1I
M;VYL;V=?7VUA:6QL:7-T)R`]/B`G36%I;&EN9R!L:7-T)RP*"2=A8W1I;VYL
M;V=?7W!H;W-T:6YG)R`]/B`G4&AY<VEC86P@:&]S=&EN9R<L"@DG86-T:6]N
M;&]G7U]F;W)W87)D:6YG)R`]/B`G4W1A;F1A<F0@;W(@9G)A;64@9F]R=V%R
M9&EN9R!H;W-T:6YG)RP*"2=A8W1I;VYL;V=?7W=E8G5S97(G(#T^("=796(@
M=7-E<B!A8V-O=6YT)RP*"2=A8W1I;VYL;V=?7W-I=&5?87!P;&EC871I;VXG
M(#T^("=3:71E(&%P<&QI8V%T:6]N)RP*"2=A8W1I;VYL;V=?7W-I=&5?87!P
M;&EC871I;VY?<&%C:V%G92<@/3X@)U-I=&4@87!P;&EC871I;VX@<&%C:V%G
M92<L"@DG86-T:6]N;&]G7U]L:6-E;G-E)R`]/B`G3&EC96YS92!K97DG+`H*
M"2=A8W1I;VYL;V=?7VQI;6ET7W)E86-H960G(#T^("=R96%C:&5D)RP*"2=A
M8W1I;VYL;V=?7V%D9&5D)R`]/B`G861D960G+`H))V%C=&EO;FQO9U]?<F5M
M;W9E9"<@/3X@)W)E;6]V960G+`H))V%C=&EO;FQO9U]?8VAA;F=E)R`]/B`G
M8VAA;F=E9"<L"@DG86-T:6]N;&]G7U]U<&1A=&4G(#T^("=U<&1A=&5D)RP*
M"2=A8W1I;VYL;V=?7V5X<&ER960G(#T^("=E>'!I<F5D)RP*"2=A8W1I;VYL
M;V=?7V-R96%T92<@/3X@)V-R96%T960G+`H))V%C=&EO;FQO9U]?9&5L971E
M)R`]/B`G9&5L971E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E7W-T;W`G(#T^
M("=S=&]P<&5D)RP*"2=A8W1I;VYL;V=?7W-E<G9I8V5?<F5S=&%R="<@/3X@
M)W)E<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]S97)V:6-E7W-T87)T)R`]/B`G
M<W1A<G1E9"<L"@DG86-T:6]N;&]G7U]L;V=I;B<@/3X@)VQO9V=E9"!I;B<L
M"@DG86-T:6]N;&]G7U]L;V=O=70G(#T^("=L;V=G960@;W5T)RP*"2=A8W1I
M;VYL;V=?7VEN<W1A;&PG(#T^("=I;G-T86QL960G+`H))V%C=&EO;FQO9U]?
M=6YI;G-T86QL)R`]/B`G=6YI;G-T86QL960G+`H))V%C=&EO;FQO9U]?<F5C
M;VYF:6=U<F4G(#T^("=R96-O;F9I9W5R960G+`H*"2=A9&UI;E]E9%]?961I
M=%]A9&UI;FES=')A=&]R7VEN9F\G(#T^(")%9&ET(&%D;6EN:7-T<F%T;W(@
M:6YF;W)M871I;VXB+`H))V%D;6EN7V5D7U]I7W=O=6QD7VQI:V5?<F5C:65V
M95]A;FYO=6YC92<@/3X@(DD@=V]U;&0@;&EK92!T;R!R96-E:79E('!E<FEO
M9&EC(&4M;6%I;',@9G)O;2!35W-O9G0L($EN8RX@86YN;W5N8VEN9R!N97<@
M<')O9'5C=',L(&1I<V-O=6YT<R!A;F0@;6]R92XB+`H))V%D;6EN7V5D7U]C
M<F5A=&5?9&5F875L=%]C;&EE;G0G(#T^("))('=O=6QD(&QI:V4@=&\@8W)E
M871E(&$@9&5F875L="!C;&EE;G0@86-C;W5N="XB+`H))V%D;6EN7V5D7U]U
M;F%B;&5?=7!D871E)R`]/B`B56YA8FQE('1O('5P9&%T92!A9&UI;FES=')A
M=&]R(&EN9F]R;6%T:6]N.B`E,2(L"@DG86YO;F9T<%]?86QL;W=?=7!L;V%D
M7VEN8V]M:6YG)R`]/B`B06QL;W<@=7!L;V%D:6YG('1O(&EN8V]M:6YG(&1I
M<F5C=&]R>2(L"@DG86YO;F9T<%]?86QL;W=?8W)E871E7V1I<G,G(#T^("=!
M;&QO=R!C<F5A=&EO;B!O9B!D:7)E8W1O<FEE<R!I;B!T:&4@:6YC;VUI;F<@
M9&ER96-T;W)Y)RP*"2=A;F]N9G1P7U]A;&QO=U]D;W=N;&]A9%]I;F-O;6EN
M9R<@/3X@)T%L;&]W(&1O=VYL;V%D:6YG(&9R;VT@=&AE(&EN8V]M:6YG(&1I
M<F5C=&]R>2<L"@DG86YO;F9T<%]?86YO;F9T<%]F;W)?9&]M86EN)R`]/B`B
M06YO;GEM;W5S($944"!A8V-O=6YT(&9O<B!T:&4@9&]M86EN(BP*"2=A;F]N
M9G1P7U]D:7-P;&%Y7VQO9VEN)R`]/B`G1&ES<&QA>2!L;V=I;B!M97-S86=E
M)RP*"2=A;F]N9G1P7U]L;V=I;E]T97AT)R`]/B`G365S<V%G92!T97AT)RP*
M"2=A;F]N9G1P7U]L;V=I;E]T97AT7VQI;6ET)R`]/B`B26YV86QI9"!M97-S
M86=E('1E>'0@;&5N9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O(#8U-3,S(&-H
M87)A8W1E<G,N(BP*"2=A;F]N9G1P7U]L;V=I;E]T97AT7V%S8VEI)R`]/B`B
M02!M97-S86=E('1E>'0@8V%N(&-O;G1A:6X@;VYL>2!!4T-)22!C:&%R86-T
M97)S+B(L"@DG86YO;F9T<%]?96YA8FQE9%]O;E]O=&AE<E]I<"<@/3X@(FES
M('5S960@;VX@86YO=&AE<B!)4"!A9&1R97-S(BP*"2=A;F]N9G1P7U]I;G9A
M;&ED7V)A;F1W:61T:"<@/3X@(DEN=F%L:60@9&]W;FQO860@8F%N9'=I9'1H
M('9A;'5E+"!O;FQY(&1I9VET<R!A<F4@86QL;W=E9"XB+`H))V%N;VYF='!?
M7VEN=F%L:61?;6%X7V-O;FXG(#T^("));G9A;&ED(&YU;6)E<B!O9B!M87AI
M;75M('-I;75L=&%N96]U<R!C;VYN96-T:6]N<RP@;VYL>2!D:6=I=',@87)E
M(&%L;&]W960B+`H))V%N;VYF='!?7VEN=F%L:61?<75O=&$G(#T^("));G9A
M;&ED(&1I<VL@<W!A8V4@=F%L=64L(&]N;'D@9&EG:71S(&%R92!A;&QO=V5D
M+B(L"@DG86YO;F9T<%]?:7!?861D<F5S7W1Y<&5?<VAA<F5D)R`]/B`B2&]S
M=&EN9R!I<R!B87-E9"!O;B!T:&4@<VAA<F5D(&EP(&%D9')E<W,N(BP*"2=A
M;F]N9G1P7U]L:6UI=%]I;F-O;6EN9U]D:7-K7W-P86-E)R`]/B`B3&EM:70@
M9&ES:R!S<&%C92!I;B!T:&4@:6YC;VUI;F<@9&ER96-T;W)Y(BP*"2=A;F]N
M9G1P7U]L:6UI=%]M87AI;75M7V)A;F1W:61T:"<@/3X@(DQI;6ET(&1O=VYL
M;V%D(&)A;F1W:61T:"!F;W(@=&AI<R!V:7)T=6%L($944"!D;VUA:6XB+`H)
M)V%N;VYF='!?7VQI;6ET7VUA>&EM=6U?8V]N;F5C=&EO;G,G(#T^("),:6UI
M="!N=6UB97(@;V8@<VEM=6QT86YE;W5S(&-O;FYE8W1I;VYS(BP*"2=A;F]N
M9G1P7U]U;F%B;&5?8W)E871E)R`]/B`B56YA8FQE('1O(&-R96%T92!A;F]N
M>6UO=7,@1E10(&%C8V]U;G0Z("4Q(BP*"2=A;F]N9G1P7U]U;F%B;&5?96YA
M8FQE)R`]/B`B1F%I;&5D('1O(&5N86)L92!A;F]N>6UO=7,@1E10(&%C8V]U
M;G0Z("4Q(BP*"2=A;F]N9G1P7U]U;F%B;&5?:6YI="<@/3X@(E5N86)L92!T
M;R!I;FET:6%L:7IE(&%N;VYY;6]U<R!&5%`@86-C;W5N=#H@)3$B+`H))V%N
M;VYF='!?7W5N86)L95]P=71?8V]N9B<@/3X@(E5N86)L92!T;R!P=70@8V]N
M9FEG=7)A=&EO;B!F:6QE.B`E,2(L"@DG86YO;F9T<%]?=6YA8FQE7W-E=%]Q
M=6]T82<@/3X@(E5N86)L92!T;R!S970@=&AE(&EN8V]M:6YG(&1I<F5C=&]R
M>2!D:7-K('-P86-E(&QI;6ET.B`E,2(L"@DG86YO;F9T<%]?=6YA8FQE7W5P
M9&%T92<@/3X@(E5N86)L92!T;R!U<&1A=&4@86YO;GEM;W5S($944"!A8V-O
M=6YT('!R;W!E<G1I97,Z("4Q(BP*"2=A=71H7U]U<&1A=&5?861M:6Y?:6YF
M;R<@/3X@(E!L96%S92!E;G1E<B!A9&UI;FES=')A=&]R)W,@:6YF;W)M871I
M;VXN(%1H:7,@:6YF;W)M871I;VX@:7,@<F5Q=6ER960@=&\@;W!E<F%T92`E
M,2XB+`H))V%U=&A?7W5P9&%T95]C;%]E;6%I;%]A;F1?<&AO;F4G(#T^(")0
M;&5A<V4@96YT97(@>6]U<B!E+6UA:6P@86YD('!H;VYE(&YU;6)E<BX@5&AE
M>2!W:6QL(&)E('5S960@=&\@;F]T:69Y('EO=2!O9B!P;W-S:6)L92!P<F]B
M;&5M<RXB+`H))V%U=&A?7WEO=5]N;W1?:&%V95]P97)M)R`]/B`B66]U(&1O
M(&YO="!H879E('!E<FUI<W-I;VYS('1O(&UA;F%G92!T:&ES(&1O;6%I;BXB
M+`H))V%U=&A?7VME>5]E>'!I<F5D7V%D;6EN)R`]/B`G66]U<B!L:6-E;G-E
M(&ME>2!H87,@97AP:7)E9"X@5&\@8V]N=&EN=64@=7-I;F<@>6]U<B!#;VYT
M<F]L(%!A;F5L('EO=2!M=7-T('!U<F-H87-E(&$@;F]N+65X<&ER:6YG(&-O
M;6UE<F-I86P@;&EC96YS92XG+`H))V%U=&A?7VME>5]E>'!I<F5D7V-L:65N
M="<@/3X@)U1H92!L:6-E;G-E(&ME>2!H87,@97AP:7)E9"X@4&QE87-E(&-O
M;G1A8W0@>6]U<B!S97)V:6-E('!R;W9I9&5R+B<L"@DG875T;VEN<W1A;&QE
M<E]?;F]T7VEN<W1A;&QE9"<@/3X@)T%U=&]I;G-T86QL97(@8V]M<&]N96YT
M(&ES(&YO="!I;G-T86QL960N)RP*"2=A=71O:6YS=&%L;&5R7U]R96QE87-E
M7V%C=&EO;B<@/3X@)T%V86EL86)L92!O<&5R871I;VYS)RP*"2=A=71O:6YS
M=&%L;&5R7U]R96QE87-E7V%C=&EO;E]I8V]N)R`]/B`G4R<L"@DG875T;VEN
M<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!G<F%D92<@/3X@)U5P9W)A9&EN
M9R!T;R!T:&4@;F5W(&-O;G1R;VP@<&%N96P@=F5R<VEO;B<L"@DG875T;VEN
M<W1A;&QE<E]?<F5L96%S95]A8W1I;VY?=7!D871E)R`]/B`G57!D871I;F<@
M;W(@861D:6YG(&YE=R!C;VUP;VYE;G1S)RP*"2=A=71O:6YS=&%L;&5R7U]R
M96QE87-E7V%C=&EO;E]U<#)D871E)R`]/B`G66]U(&AA=F4@86X@=7`@=&\@
M9&%T92!V97)S:6]N)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G1?86-T
M:6]N)R`]/B`G4W1A='5S)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G1?
M86-T:6]N7VEC;VXG(#T^("=3)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE
M;G1?86-T:6]N7VEN<W1A;&PG(#T^("=.;W0@:6YS=&%L;&5D)RP*"2=A=71O
M:6YS=&%L;&5R7U]C;VUP;VYE;G1?86-T:6]N7W5P9&%T92<@/3X@)T%N('5P
M9&%T92!I<R!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N
M=%]A8W1I;VY?=7!G<F%D92<@/3X@)T%N('5P9&%T92!I<R!A=F%I;&%B;&4G
M+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N=%]A8W1I;VY?=7`R9&%T92<@
M/3X@)UEO=2!H879E(&%N('5P('1O(&1A=&4@=F5R<VEO;B<L"@DG875T;VEN
M<W1A;&QE<E]?8V]M<&]N96YT7V%C=&EO;E]E<G)O<B<@/3X@)U5P9&%T97,@
M87)E(&YO="!A=F%I;&%B;&4G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N
M=%]S97)V97)B=6EL9'1I;64G(#T^("=,871E<W0@<F5L96%S92<L"@DG875T
M;VEN<W1A;&QE<E]?8V]M<&]N96YT7VQO8V%L8G5I;&1T:6UE)R`]/B`G66]U
M<B!R96QE87-E)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G0G(#T^("=#
M;VUP;VYE;G0G+`H))V%U=&]I;G-T86QL97)?7V-O;7!O;F5N=',G(#T^("=#
M;VUP;VYE;G1S)RP*"2=A=71O:6YS=&%L;&5R7U]C;VUP;VYE;G1S7W1I=&QE
M)R`]/B`G)3$@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE<E]?8V]M<&]N
M96YT7V1E<&5N9&5N8WE?;F]T92<@/3X@)W)E<75I<F5D(&9O<B!I;G-T86QL
M871I;VX@;V8@=&AE(&-O;7!O;F5N=',@>6]U('-E;&5C=&5D)RP*"2=A=71O
M:6YS=&%L;&5R7U]I;G-T86QL7V-O;F9I<FTG(#T^("=997,L($D@=VES:"!T
M;R!I;G-T86QL('1H97-E(&-O;7!O;F5N=',G+`H))V%U=&]I;G-T86QL97)?
M7VEN<W1A;&Q?8V]N9FER;5]R97%U97-T)R`]/B`G4&QE87-E('-E;&5C="!T
M:&4@8VAE8VMB;W@@=&\@8V]N9FER;2XG+`H))V%U=&]I;G-T86QL97)?7VEN
M<W1A;&Q?=&ET;&4G(#T^("=#;VYF:7)M($EN<W1A;&QA=&EO;B!O9B!T:&4@
M4V5L96-T960@0V]M<&]N96YT<R<L"@DG875T;VEN<W1A;&QE<E]?:V5R;F5L
M7W5P9&%T95]C;VYF:7)M)R`]/B`G0V]N9FER;2!T:&4@:V5R;F5L('5P9&%T
M92<L"@DG875T;VEN<W1A;&QE<E]?:V5Y7W5P9&%T95]C;VYF:7)M)R`]/B`G
M0V]N9FER;2!S:VEP<&EN9R!K97D@=7!D871E(&%N9"!I;G-T86QL:6YG('1H
M92!D969A=6QT(&ME>2<L"@DG875T;VEN<W1A;&QE<E]?:V5Y7W5P9&%T95]C
M;VYF:7)M7W)E<75E<W0G(#T^("=0;&5A<V4@8VAE8VL@=&AE(&-H96-K8F]X
M('1O(&-O;F9I<FTN)RP*"2=A=71O:6YS=&%L;&5R7U]K97E?=7!D871E7V9A
M:6QE9"<@/3XG/'`^4&QE<VL@:7,@=6YA8FQE('1O('5P9&%T92!Y;W5R('!R
M;V1U8W0@;&EC96YS92X\+W`^)PH)"2X@)SQP/B4Q/"]P/B<*"0DN("<\<#Y#
M;VYT:6YU:6YG('=I=&@@=&AE('5P9W)A9&4@=VET:&]U="!H879I;F<@86X@
M87!P<F]P<FEA=&4@<')O9'5C="!L:6-E;G-E('=I;&P@<F5S=6QT(&EN('1H
M92!I;G-T86QL871I;VX@;V8@82!D969A=6QT(&QI8V5N<V4@=VET:"!L:6UI
M=&5D(&9U;F-T:6]N86QI='DN($%D;6EN:7-T<F%T;W)S(&%R92!A9'9I<V5D
M('1O(&9I<G-T(&%C<75I<F4@=&AE(&%P<')O<')I871E(&QI8V5N<V4@8F5F
M;W)E(&-O;G1I;G5I;F<@=VET:"!T:&4@<')O9'5C="!U<&=R861E+CPO<#XG
M+`H))V%U=&]I;G-T86QL97)?7V5M86EL)R`]/B`G4V5N9"!N;W1I8V4@=&\G
M+`H))V%U=&]I;G-T86QL97)?7V5M86EL7V%D;6EN)R`]/B`B061M:6YI<W1R
M871O<B=S(&4M;6%I;"(L"@DG875T;VEN<W1A;&QE<E]?96UA:6Q?96UA:6PG
M(#T^("=#=7-T;VT@92UM86EL(&%D9')E<W,N+BXG+`H))V%U=&]I;G-T86QL
M97)?7W)E;&5A<V4G(#T^("=296QE87-E(&YA;64G+`H))V%U=&]I;G-T86QL
M97)?7W)E;&5A<V5S)R`]/B`G079A:6QA8FQE(')E;&5A<V5S)RP*"2=A=71O
M:6YS=&%L;&5R7U]R96QE87-E<U]T:71L92<@/3X@)U!L97-K(%5P9&%T97(G
M+`H))V%U=&]I;G-T86QL97)?7W-E;&5C=%]C;VUP;VYE;G1S7W1O7VEN<W1A
M;&PG(#T^("=396QE8W0@=&AE(&-O;7!O;F5N=',@=&\@8F4@:6YS=&%L;&5D
M)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?97)R;W(G(#T^("=%<G)O<CH@
M)3$N)RP*"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]E<G)O<B<@
M/3X@)TEN<W1A;&QA=&EO;B!C;W5L9"!N;W0@8F4@<W1A<G1E9#H@)3$N)RP*
M"2=A=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]B=7-Y)R`]/B`G26YS
M=&%L;&%T:6]N(&-O=6QD(&YO="!B92!S=&%R=&5D.B!A;F]T:&5R(&EN<W1A
M;&QA=&EO;B!P<F]C961U<F4@:7,@8W5R<F5N=&QY(')U;FYI;F<N)RP*"2=A
M=71O:6YS=&%L;&5R7U]S=&%T=7-?:6YS=&%L;%]O:R<@/3X@)TEN<W1A;&QA
M=&EO;B!S=&%R=&5D+B!9;W4@=VEL;"!B92!N;W1I9FEE9"!O9B!I;G-T86QL
M871I;VX@<')O9W)E<W,@8GD@92UM86EL("@E,2DN)RP*"2=A=71O:6YS=&%L
M;&5R7U]S=&%T=7-?<75E<GE?8G5S>2<@/3X@)TEN<W1A;&QA=&EO;B!I<R!I
M;B!P<F]G<F5S<RXG+`H))V%U=&]I;G-T86QL97)?7W-T871U<U]Q=65R>5]E
M<G)O<B<@/3X@)U5N86)L92!T;R!R971R:65V92!I;G-T86QL871I;VX@<W1A
M='5S.B`E,2<L"@DG875T;VEN<W1A;&QE<E]?8V]N9FEG=7)E7W1I=&QE)R`]
M/B`G57!D871E<B!3971T:6YG<R<L"@DG875T;VEN<W1A;&QE<E]?<')E9F5R
M96YC97-?;&5G96YD)R`]/B`G4V5T=&EN9W,G+`H))V%U=&]I;G-T86QL97)?
M7W-O=7)C95]T>7!E)R`]/B`G4V]U<F-E('1Y<&4G+`H))V%U=&]I;G-T86QL
M97)?7W-O=7)C95]T>7!E7VEN=F%L:60G(#T^("=);G9A;&ED('-O=7)C92!T
M>7!E)RP*"2=A=71O:6YS=&%L;&5R7U]S;W5R8V5?='EP95]P;&5S:R<@/3X@
M)U!L97-K('5P9&%T92!S97)V97(G+`H))V%U=&]I;G-T86QL97)?7W-O=7)C
M95]T>7!E7VYE='=O<FLG(#T^("=.971W;W)K('-T;W)A9V4G+`H))V%U=&]I
M;G-T86QL97)?7W-O=7)C95]I;G9A;&ED)R`]/B`G26YV86QI9"!S;W5R8V4G
M+`H))V%U=&]I;G-T86QL97)?7W-O=7)C95]I;G9A;&ED7VYE='=O<FLG(#T^
M("=);G9A;&ED('-O=7)C92!54DP@*'-A;7!L93H@:'1T<#HO+W-O=7)C92P@
M9G1P.B\O<V]U<F-E*2<L"@DG875T;VEN<W1A;&QE<E]?<V]U<F-E)R`]/B`G
M4V]U<F-E(%523"<L"@DG875T;VEN<W1A;&QE<E]?=&%R9V5T)R`]/B`G5&5M
M<&]R87)Y(&1O=VYL;V%D(&1I<F5C=&]R>2<L"@DG875T;VEN<W1A;&QE<E]?
M=&%R9V5T7VEN=F%L:60G(#T^(")3<&5C:69Y(&%B<V]L=71E('!A=&@B+`H)
M)V%U=&]I;G-T86QL97)?7V-H96-K7W5P9&%T97,G(#T^("=#:&5C:R!F;W(@
M=7!D871E<R!U<&]N(&%D;6EN:7-T<F%T;W)<)W,@;&]G:6X@=&\@8V]N=')O
M;"!P86YE;"XG+`H))V%U=&]I;G-T86QL97)?7V-H96-K7W5P9&%T97-?=V%R
M;FEN9R<@/3X@)TYE=R`\82!H<F5F/2(E,2(^=7!D871E<SPO83X@87)E(&%V
M86EL86)L92!F;W(@)3(@)RP*"2=B86-K=7!?7W!E<FEO9"<)/3X@)T)A8VMU
M<"!P97)I;V0G+`H))V)A8VMU<%]?<F5P;W-I=&]R>2<]/B`G0F%C:W5P(&9I
M;&5S(')E<&]S:71O<GD@;&]C871I;VXG+`H))V)A8VMU<%]?;6%X7V1U;7!?
M9FEL97,G"3T^("=.=6UB97(@;V8@8F%C:W5P(&9I;&5S('-T;W)E9"!I;B!R
M97!O<VET;W)Y)RP*"2=B86-K=7!?7V9I;&5N86UE7W!R969I>"<]/B`G061D
M('!R969I>"!T;R!B86-K=7`@9FEL92!N86UE<R<L"@DG8F%C:W5P7U]E<G)O
M<E]N;W1I9GE?96UA:6PG(#T^("=396YD(&YO=&EF:6-A=&EO;B!O;B!E<G)O
M<G,@:68@86YY(&]C8W5R(&1U<FEN9R!B86-K=7`@=&\@96UA:6PG+`H))V)A
M8VMU<%]?9'5M<%]I;F9O)R`]/B`B0F%C:W5P(&EN9F]R;6%T:6]N(BP*"2=B
M86-K=7!?7V1U;7!?9FEL95]N86UE7VYO=%]D969I;F5D)R`]/B`B0F%C:W5P
M(&9I;&4@;F%M92!I<R!N;W0@<W!E8VEF:65D(BP*"2=B86-K=7!?7V9T<%]A
M8V-O=6YT)R`]/B`B1E10(&%C8V]U;G0@9F]R(')E;6]T92!R97!O<VET;W)Y
M(BP*"2=B86-K=7!?7V-R;VY?8F%C:W5P7W1A<VM?<')E9G,G(#T^(")38VAE
M9'5L960@0F%C:W5P(BP*"2=B86-K=7!?7V9T<%]A8V-O=6YT7V9O<E]B86-K
M=7`G(#T^(")&5%`@86-C;W5N="!P<F5F97)E;F-E<R(L"@DG8F%C:W5P7U]L
M;V-A;%]F:6QE)R`]/B`G3&]C86P@8F%C:W5P(&9I;&4G+`H))V)A8VMU<%]?
M9&]M86EN7V1U;7!S)R`]/B`G;&]C86P@<F5P;W-I=&]R>2<L"@DG8F%C:W5P
M7U]D;VUA:6Y?9G1P)R`]/B`G<F5M;W1E($944"!S97)V97(G+`H))V)A8VMU
M<%]?=W)O;F=?<&%T:"<@/3X@(DEN8V]R<F5C="!P871H('1O('1H92!B86-K
M=7`@9FEL97,@<F5P;W-I=&]R>3H@1&\@;F]T('5S92!T:&4@<V5Q=65N8V4@
M;V8@8VAA<F%C=&5R<R`N+B\N+B\B+`H))V)A8VMU<%]?=6YA8FQE7W1O7V-O
M;FYE8W1?=&]?9G1P7W-E<G9E<B<]/B`B56YA8FQE('1O(&-O;FYE8W0@=&\@
M1E10('-E<G9E<CH@)3$B+`H))V)A8VMU<%]?8F%C:W5P7W1A<VM?9&]E<U]N
M;W1?97AI<W0G(#T^(")"86-K=7`@=&%S:R!D;V5S(&YO="!E>&ES="P@>6]U
M('-H;W5L9"!C<F5A=&4@:70@8F5F;W)E('1U<FYI;F<@;VXN(BP*"2=B86-K
M=7!?7W)E<W1O<F5?<&%R86US)R`]/B`B4F5S=&]R92!P87)A;65T97)S(BP*
M"2=B86-K=7!?7V-O;F9I<FUA=&EO;B<@/3X@(E=A<FYI;F<Z('1H92!D;VUA
M:6X@=VEL;"!N;W0@8F4@879A:6QA8FQE(&1U<FEN9R!B86-K=7`O<F5S=&]R
M:6YG+B(L"@DG8F%C:W5P7U]D=6UP9FEL95]I<U]N;W1?97AI<W0G(#T^(")"
M86-K=7`@9FEL92!D;V5S(&YO="!E>&ES="XB+`H))V)A8VMU<%]?8F%C:W5P
M7VUE=&AO9"<)/3X@)T)A8VMU<"!M971H;V0G+`H))V)A8VMU<%]?9'5M<&9I
M;&5?;F%M92<@/3X@(D)A8VMU<"!F:6QE(&YA;64B+`H))V)A8VMU<%]?9'5M
M<&9I;&5?;F%M95]I<U]I;G9A;&ED)R`]/B`B0F%C:W5P(&9I;&4@;F%M92!I
M<R!I;G9A;&ED.B!5<V4@;VYL>2!A;'!H86YU;65R:6,L(&1A<V@L(&1O="!A
M;F0@=6YD97)S8V]R92!S>6UB;VQS+"!D;R!N;W0@=7-E(&YA;64@;&EK92!D
M97-C<FEP=&EO;BXJ(&%S(&)A8VMU<"!F:6QE(&YA;64N(BP*"2=B86-K=7!?
M7V1U;7!F:6QE7VYA;65?:7-?;F]T7V1E9FEN960G(#T^(")"86-K=7`@9FEL
M92!N86UE(&ES('5N9&5F:6YE9"XB+`H))V)A8VMU<%]?96UA:6Q?<F5Q=6ER
M960G(#T^(")9;W5R(&4M;6%I;"!A9&1R97-S(&ES(')E<75I<F5D('1O(&ME
M97`@>6]U(&EN9F]R;65D(&]F('1H92!B86-K=7`O<F5S=&]R:6YG('!R;V-E
M9'5R92!P<F]G<F5S<RX@4&QE87-E('-P96-I9GD@>6]U<B!E+6UA:6P@:6X@
M=&AE(&%C8V]U;G0@9&5T86EL<RXB+`H))V)A8VMU<%]?97)R;W)?9'5R:6YG
M7V)A8VMU<"<@/3X@(E5N86)L92!T;R!C<F5A=&4@=&AE(&)A8VMU<"!F:6QE
M.B`E,2(L"@DG8F%C:W5P7U]I;G!U=%]E;6%I;%]W87)N:6YG)R`]/B`B66]U
M('-H;W5L9"!E:71H97(@<W!E8VEF>2!E+6UA:6P@9F]R(&YO=&EF:6-A=&EO
M;B!O<B!D97-E;&5C="!T:&4@8VAE8VMB;W@N(BP*"2=B86-K=7!?7VUA:V5?
M9&]W;FQO860G(#T^(")D;R!N;W0@<W1O<F4@=&AE(&)A8VMU<"!F:6QE(&EN
M(')E<&]S:71O<GDL(&]N;'D@9&]W;FQO860@:70B+`H))V)A8VMU<%]?;6%K
M95]D=6UP)R`]/B`G8W)E871E(&)A8VMU<"!F:6QE(&%N9"!S=&]R92!I;B!L
M;V-A;"!R97!O<VET;W)Y)RP*"2=B86-K=7!?7VUA:V5D=6UP7W1O7V9T<"<@
M/3X@)V-R96%T92!B86-K=7`@9FEL92!A;F0@<W1O<F4@;VX@<F5M;W1E($94
M4"!S97)V97(G+`H))V)A8VMU<%]?9G1P7W-E<G9E<B<@/3X@(D944"!S97)V
M97(B+`H))V)A8VMU<%]?9G1P7V)A<V5D:7(G(#T^(")0871H('1O(&)A8VMU
M<"!F:6QE<R!R97!O<VET;W)Y(&]N($944"!S97)V97(B+`H))V)A8VMU<%]?
M;F]T:69I8V%T:6]N7V5M86EL)R`]/B`B3F]T:69Y(&)Y(&4M;6%I;"(L"@DG
M8F%C:W5P7U]N;W1I9GE?96UA:6Q?:7-?:6YV86QI9"<@/3X@(DEN8V]R<F5C
M="!E+6UA:6P@861D<F5S<R!F;W(@8F%C:W5P+W)E<W1O<FEN9R!P<F]G<F5S
M<R!N;W1I9FEC871I;VX@:7,@<W!E8VEF:65D+B(L"@DG8F%C:W5P7U]R97-T
M;W)E7VEP)R`]/B`B25`@861D<F5S<R!F;W(@<F5S=&]R871I;VXB+`H))V)A
M8VMU<%]?<V5L96-T7V1U;7!F:6QE)R`]/B`B4V5L96-T(&$@8F%C:W5P(&9I
M;&4N(BP*"2=B86-K=7!?7W1I;64G(#T^(")"86-K=7`@=&EM92(L"@DG8F%C
M:W5P7U]V:65W7V1U;7!?:6YF;R<@/3X@(E9I97<@=&AE(&)A8VMU<"!I;F9O
M<FUA=&EO;B!F;W(@9&]M86EN("4Q(BP*"2=B86-K=7!?7W=R;VYG7V1O;6%I
M;E]N86UE)R`]/B`B5&AE(&)A8VMU<"!F:6QE(&-O;G1A:6YS('1H92!D871A
M(&]F(&1O;6%I;B`E,2!A;F0@=&AE<F5F;W)E(&-A;FYO="!B92!R97-T;W)E
M9"!O;B!D;VUA:6X@)3(B+`H))V)A8VMU<%]?:6YC;W)R96-T7V9T<%]U<V5R
M7V]R7W!A<W-W9"<@/3X@(DEN8V]R<F5C="!&5%`@=7-E<B!O<B!P87-S=V]R
M9"X@4&QE87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R=&EE<R(L"@DG
M8F%C:W5P7U]A8V-E<W-?9&5N:65D)R`]/B`B06-C97-S(&1E;FEE9"X@4&QE
M87-E(&-O<G)E8W0@1E10($%C8V]U;G0@4')O<&5R=&EE<R(L"@DG8F%C:W5P
M7U]C;W5L9&YO=%]R97-O;'9E7VAO<W0G(#T^(")#;W5L9&XG="!R97-O;'9E
M(&AO<W0@)3$B+`H))V)A8VMU<%]?<F5S=&]R95]F<F]M)R`]/B`B4F5S=&]R
M92`E,2(L"@DG8F%C:W5P7U]D;VUA:6Y?<V5S<VEO;E]F86EL960G(#T^("=$
M;VUA:6X@)3$@=V%S(&YO="!B86-K960@=7`G+`H))V)A8VMU<%]?8VQI96YT
M7W-E<W-I;VY?9F%I;&5D)R`]/B`G0VQI96YT("4Q('=A<R!N;W0@8F%C:V5D
M('5P)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7W)E<W1O<F5?9F%I;&5D
M)R`]/B`G1&]M86EN("4Q('=A<R!N;W0@<F5S=&]R960G+`H))V)A8VMU<%]?
M8VQI96YT7W-E<W-I;VY?<F5S=&]R95]F86EL960G(#T^("=#;&EE;G0@)3$@
M=V%S(&YO="!R97-T;W)E9"<L"@DG8F%C:W5P7U]D;VUA:6Y?<V5S<VEO;E]C
M;VUP;&5T92<@/3X@)T1O;6%I;B`E,2!W87,@8F%C:V5D('5P)RP*"2=B86-K
M=7!?7V1O;6%I;E]S97-S:6]N7V)A8VMU<"<@/3X@)T)A8VMU<"!O9B!D;VUA
M:6X@)3$G+`H))V)A8VMU<%]?8VQI96YT7W-E<W-I;VY?8F%C:W5P)R`]/B`G
M0F%C:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?<W1O<%]T
M:71L92<@/3X@)T-A;F-E;&QI;F<@8F%C:W5P(&]F(&1O;6%I;B`E,2<L"@DG
M8F%C:W5P7U]C;&EE;G1?<W1O<%]T:71L92<@/3X@)T-A;F-E;&QI;F<@8F%C
M:W5P(&]F(&-L:65N="`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]S
M=&]P7W1I=&QE)R`]/B`G0V%N8V5L;&QI;F<@<F5S=&]R92!O9B!D;VUA:6X@
M)3$G+`H))V)A8VMU<%]?8VQI96YT7W)E<W1O<F5?<W1O<%]T:71L92<@/3X@
M)T-A;F-E;&QI;F<@<F5S=&]R92!O9B!C;&EE;G0@)3$G+`H))V)A8VMU<%]?
M9&]M86EN7W-E<W-I;VY?8F%C:W5P7W-T;W`G(#T^("=9;W4@87)E(&%B;W5T
M('1O(&-A;F-E;"!T:&4@86-T:79E(&)A8VMU<"!P<F]C97-S(2!"86-K=7`@
M9FEL92!W:6QL(&YO="!B92!C<F5A=&5D+B<L"@DG8F%C:W5P7U]B86-K=7!?
M<W1O<%]C;VYF:7)M)R`]/B`G665S+"!)('=A;G0@=&\@<W1O<"!T:&4@8F%C
M:W5P('!R;V-E<W,G+`H))V)A8VMU<%]?<F5S=&]R95]S=&]P7V-O;F9I<FTG
M(#T^("=997,L($D@=V%N="!T;R!S=&]P('1H92!R97-T;W)E('!R;V-E<W,G
M+`H))V)A8VMU<%]?9&]M86EN7W-E<W-I;VY?<F5S=&]R92<@/3X@)U)E<W1O
M<F4@;V8@9&]M86EN("4Q)RP*"2=B86-K=7!?7V1O;6%I;E]S97-S:6]N7W)E
M<W1O<F5?<W1O<"<@/3X@)UEO=2!A<F4@86)O=70@=&\@8V%N8V5L('1H92!A
M8W1I=F4@<F5S=&]R92!P<F]C97-S(2<L"@DG8F%C:W5P7U]D;VUA:6Y?8F%C
M:W5P7V9I;&5?:6YF;R<@/3X@)T1O;6%I;B!"86-K=7`@1FEL92!);F9O<FUA
M=&EO;B<L"@DG8F%C:W5P7U]D;VUA:6Y?8F%C:W5P7V9I;&5?;&ES="<@/3X@
M)V5X:7-T:6YG(&)A8VMU<"!F:6QE<R<L"@DG8F%C:W5P7U]D;VUA:6Y?8F%C
M:W5P7W!R;V=R97-S)R`]/B`G4')O9W)E<W,@;V8@9&]M86EN("4Q(&)A8VMU
M<"<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P<F]G<F5S<R<@/3X@)U!R
M;V=R97-S(&]F(&1O;6%I;B`E,2!R97-T;W)E)RP*"2=B86-K=7!?7V1O;6%I
M;E]B86-K=7!?<')O9W)E<W-?96QA<'-E9%]T:6UE)R`]/B`G16QA<'-E9"!T
M:6UE.B`E,2<L"@DG8F%C:W5P7U]D;VUA:6Y?<F5S=&]R95]P<F]G<F5S<U]E
M;&%P<V5D7W1I;64G(#T^("=%;&%P<V5D('1I;64Z("4Q)RP*"2=B86-K=7!?
M7VEP7VUA<%]L96=E;F0G(#T^("=)4"!-87!P:6YG)RP*"2=B86-K=7!?7VEP
M7VUA<%]L:7-T7V-O=6YT)R`]/B`G25`@061D<F5S<V5S)RP*"2=B86-K=7!?
M7V1O;6%I;E]R97-T;W)E7W-E<W-I;VY?8V]M<&QE=&4G(#T^("=$;VUA:6X@
M)3$@:7,@<F5S=&]R960G+`H))V)A8VMU<%]?9&]M86EN7W)E<W1O<F5?<V5S
M<VEO;E]C;VUP;&5T95]M97-S86=E)R`]/B`G1&]M86EN("4Q(&AA<R!B965N
M(')E<W1O<F5D)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?9FEL95]D96QE
M=&4G(#T^("=4:&4@9F]L;&]W:6YG(&)A8VMU<"!F:6QE<R!W:6QL(&)E(')E
M;6]V960Z)RP*"2=B86-K=7!?7V1O;6%I;E]B86-K=7!?9FEL95]F;W)?<F5M
M;W9E)R`]/B`G4V5L96-T(&)A8VMU<"!F:6QE<R!Y;W4@=VES:"!T;R!R96UO
M=F4G+`H))V)A8VMU<%]?8F%C:W5P7V]V97)W<FET95]F:6QE7V-O;F9I<FTG
M(#T^("=297!L86-E;65N="!C;VYF:7)M871I;VXG+`H))V)A8VMU<%]?8F%C
M:W5P7V]V97)W<FET95]F:6QE7V-O;F9I<FU?=&5X="<@/3X@)T)A8VMU<"!F
M:6QE('=I=&@@=&AE(&YA;64@(B4Q(B!A;')E861Y(&5X:7-T<RX@1&\@>6]U
M('=A;G0@=&\@<F5P;&%C92!I=#\G+`H))V)A8VMU<%]?8F%C:W5P7V-O;F9I
M<FU?;W9E<G=R:71E)R`]/B`G0V]N9FER;2!F:6QE(')E<&QA8V5M96YT)RP*
M"2=B86-K=7!?7V)A8VMU<%]O=F5R=W)I=&5?;&5G96YG)R`]/B`G4F5P;&%C
M92<L"@DG8F%C:W5P7U]B86-K=7!?;F]T7V-O;G1A:6Y?9&]M86EN)R`]/B`G
M0F%C:W5P(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!I;F9O<FUA=&EO;B!A8F]U
M="!D;VUA:6X@)3$G+`H))V)A8VMU<%]?8F%C:W5P7VYO=%]C;VYT86EN7V-L
M:65N="<@/3X@)T)A8VMU<"!F:6QE(&1O97,@;F]T(&-O;G1A:6X@:6YF;W)M
M871I;VX@86)O=70@8VQI96YT("4Q)RP*"2=B86-K=7!?7V)A8VMU<%]C;&EE
M;G1?:6YF;R<@/3X@(D)A8VMU<"!C;&EE;G0G<R!P<F5F97)E;F-E<R!A;F0@
M86-C;W5N="!D971A:6QS(BP*"2=B86-K=7!?7V-L:65N=%]B86-K=7!?<')O
M9W)E<W,G(#T^("=0<F]G<F5S<R!O9B!#;&EE;G0@)3$@0F%C:W5P)RP*"2=B
M86-K=7!?7V-L:65N=%]S97-S:6]N7V-O;7!L971E)R`]/B`G0VQI96YT("4Q
M(&ES(&)A8VME9"!U<"<L"@DG8F%C:W5P7U]C;&EE;G1?8F%C:W5P7V9I;&5?
M:6YF;R<@/3X@)T-L:65N="!"86-K=7`@1FEL92!);F9O<FUA=&EO;B<L"@DG
M8F%C:W5P7U]R97-T;W)E7V-L:65N=%]I;F9O)R`]/B`B4F5S=&]R92!C;&EE
M;G0G<R!P<F5F97)E;F-E<R!A;F0@86-C;W5N="!D971A:6QS(BP*"2=B86-K
M=7!?7V-L:65N=%]S97-S:6]N7W)E<W1O<F4G(#T^("=297-T;W)I;F<@0VQI
M96YT("4Q)RP*"2=B86-K=7!?7V-L:65N=%]D8E]S97)V97)?;6%P)R`]/B`G
M1&%T86)A<V4@4V5R=F5R<R!-87!P:6YG)RP*"2=B86-K=7!?7V1O;6%I;E]D
M8E]S97)V97)?;6%P)R`]/B`G1&%T86)A<V4@4V5R=F5R<R!-87!P:6YG)RP*
M"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W-E<W-I;VY?8V]M<&QE=&5?;65S
M<V%G92<@/3X@)T-L:65N="`E,2!H87,@8F5E;B!R97-T;W)E9"XG+`H))V)A
M8VMU<%]?8VQI96YT7W)E<W1O<F5?<V5S<VEO;E]C;VUP;&5T92<@/3X@)T-L
M:65N="`E,2!R97-T;W)E9"<L"@DG8F%C:W5P7U]R97-T;W)E7W-E;&5C=%]S
M;VUE)R`]/B`G4&QE87-E('-E;&5C="!O8FIE8W1S('EO=2!W:7-H('1O(')E
M<W1O<F4N)RP*"2=B86-K=7!?7V-L:65N=%]R97-T;W)E7W!R;V=R97-S)R`]
M/B`G4')O9W)E<W,@;V8@0VQI96YT("4Q(%)E<W1O<F4G+`H))V)A8VMU<%]?
M;F5W7V)A8VMU<"<@/3X@)T-R96%T:6YG($YE=R!"86-K=7`G+`H))V)A8VMU
M<%]?9&]N92<@/3X@)T1O;F4Z)RP*"2=B86-K=7!?7V1O;F5?9&]M86EN<R<@
M/3X@)R4Q(&1O;6%I;BAS*2!O=70@;V8@)3(G+`H))V)A8VMU<%]?9&]N95]C
M;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I(&]U="!O9B`E,B<L"@DG8F%C:W5P
M7U]R96UA:6YI;F<G(#T^("=296UA:6YI;F<Z)RP*"2=B86-K=7!?7W)E;6%I
M;FEN9U]D;VUA:6YS)R`]/B`G)3$@9&]M86EN*',I)RP*"2=B86-K=7!?7W)E
M;6%I;FEN9U]C;&EE;G1S)R`]/B`G)3$@8VQI96YT*',I)RP*"2=B86-K=7!?
M7V]V97)A;&Q?8F%C:W5P7W!R;V=R97-S)R`]/B`G3W9E<F%L;"!B86-K=7`@
M<')O9W)E<W,G+`H))V)A8VMU<%]?8V]M;65N=%]N7V$G(#T^("=N+V$G+`H)
M)V)A8VMU<%]?8V]M;6%N9%]I9VYO<F4G(#T^("=#;VUM86YD("(E,2(@:7,@
M:6=N;W)E9"<L"@DG8F%C:W5P7U]N;W1?8F%C:W5P7V9I;&4G(#T^("=.;W0@
M82!B86-K=7`@9FEL92<L"@DG8F%C:W5P7U]D8E]S97)V97)?;6%P<&EN9R<@
M/3X@)U-E;&5C="!T:&4@9&%T86)A<V4@<V5R=F5R(&-O;F9I9W5R960@:6X@
M4&QE<VL@=&\@=VAI8V@@>6]U('=I<V@@=&\@;6%P('1H92!D871A8F%S92!S
M97)V97(@9G)O;2!B86-K=7`N)RP*"2=B86-K=7!?7W5N86)L95]U<&1A=&4G
M(#T^("=5;F%B;&4@=&\@=7!D871E('-C:&5D=6QE9"!B86-K=7`@:6YF;W)M
M871I;VXZ("4Q)RP*"2=B86-K=7!?7VYO7V]B:F5C=',G(#T^("=T:&5R92!A
M<F4@;F\@;V)J96-T<R!F;W(@8F%C:W5P)RP*"2=B86-K=7!?7V-L:5]W87)N
M:6YG7VYO=%]E;F]U9VA?:7`G(#T^("=705).24Y'.B!N;W0@96YO=6=H($E0
M(&%D9')E<W-E<R!T;R!P97)F;W)M(&1E9F%U;'0@25`@;6%P<&EN9SH@)RP*
M"2=B=%]B86-K=7!?;F]W)R`]/B`B0F%C:W5P($YO=R(L"@DG8G1?;F5W7W)E
M<W1O<F4G(#T^(")297-T;W)E(BP*"2=B=%]B86-K=7!?<V-H961U;&4G(#T^
M(")38VAE9'5L960@0F%C:W5P(BP*"2=B86-K=7!?97AI<W1?8F%C:W5P<R<@
M/3X@(D5X:7-T:6YG(&)A8VMU<"!F:6QE<R(L"@DG8F%C:W5P7V1I86QO9U]?
M<&%G95]T:71L92<@/3X@(D)A8VMU<"!&:6QE($-R96%T:6]N(BP*"2=B86-K
M=7!?9&EA;&]G7U]P;&5A<V5?=V%I="<@/3X@(E1H92!B86-K=7`@<')O8V5S
M<R!I<R!A8F]U="!T;R!B96=I;BX@)3$@5&AI<R!O<&5R871I;VX@;6EG:'0@
M=&%K92!S;VUE('1I;64N("4R(%!L96%S92!W86ET+BXN("4S(BP*"2=D=6UP
M7V9I;&5?7VEN8V]R<F5C=%]F:6QE;F%M92<@/3X@(E1H92!F:6QE<R!Y;W4@
M<W!E8VEF:65D(&%R92!N;W0@<&%R=',@;V8@=&AE('-A;64@;75L=&DM=F]L
M=6UE(&)A8VMU<"XB+`H))V1U;7!?9FEL95]?:6YC;W)R96-T7W-E<75E;F-E
M)R`]/B`B5W)O;F<@<V5Q=65N8V4@;V8@=F]L=6UE<R!S<&5C:69I960A(BP*
M"2=B=%]A8V-E<'0G(#T^(")!8V-E<'0B+`H))V)T7V%C8V5S<R<@/3X@(D%C
M8V5S<R(L"@DG8G1?86-T:6]N7VQO9R<@/3X@(D%C=&EO;B!,;V<B+`H))V)T
M7V%D9"<@/3X@(D%D9"(L"@DG8G1?861D7V-L:65N="<@/3X@(D%D9"!.97<@
M0VQI96YT(BP*"2=B=%]D871A8F%S95]S97)V97)?861D)R`]/B`G061D($1A
M=&%B87-E(%-E<G9E<B<L"@DG8G1?861D7VYE=U]C871E9V]R>2<@/3X@(D%D
M9"!.97<@0V%T96=O<GDB+`H))V)T7V%D9%]N97=?<')I;W)I='DG(#T^(")!
M9&0@3F5W(%!R:6]R:71Y(BP*"2=B=%]A9&1?;F5W7W%U975E)R`]/B`B061D
M($YE=R!1=65U92(L"@DG8G1?861D7VYE=U]T:6-K970G(#T^(")!9&0@3F5W
M(%1I8VME="(L"@DG8G1?861D7W-E<G9I8V5S)R`]/B`B061D(%-E<G9I8V5S
M(BP*"2=B=%]A9&1?861D<F5S<U]T;U]A8VPG(#T^("=!9&0@3F5W($%D9')E
M<W,G+`H))V)T7V%D9%]T;R<@/3X@(CP\($%D9"(L"@DG8G1?=&]?861D)R`]
M/B`B061D(#X^(BP*"2=B=%]T;U]E>&-L=7-I=F4G(#T^("(\/"!%>&-L=7-I
M=F4B+`H))V)T7W1O7W-H87)E9"<@/3X@(E-H87)E9"`^/B(L"@DG8G1?86YO
M;F9T<%]S=&%T<R<@/3X@(D%N;VXN1E10(%-T871S(BP*"2=B=%]A;F]N>6UO
M=7-?9G1P)R`]/B`B06YO;GEM;W5S($944"(L"@DG8G1?871T86-H)R`]/B`B
M071T86-H(BP*"2=B=%]A=71O:6YS=&%L;&5R)R`]/B`G57!D871E<B<L"@DG
M8G1?8F%C:R<@/3X@(CP\($)A8VLB+`H))V)T7V)A8VMU<"<@/3X@(D)A8VL@
M=7`B+`H))V)T7V)U>5]C97)T<R<@/3X@(D)U>2!#97)T<R(L"@DG8G1?8FQO
M8VME9%]D;VUA:6YS)R`]/B`G0FQA8VL@3&ES="<L"@DG8G1?8FQO8VME9%]D
M;VUA:6Y?861D)R`]/B`G061D($1O;6%I;B<L"@DG8G1?8V%N8V5L)R`]/B`B
M0V%N8V5L(BP*"2=B=%]C87)D)R`]/B`B0V%R9"(L"@DG8G1?8V5R="<@/3X@
M(D-E<G1I9FEC871E(BP*"2=B=%]C97)T7V%D9"<@/3X@(D%D9"!.97<@0V5R
M=&EF:6-A=&4B+`H))V)T7V-E<G1?8G5Y)R`]/B`B0G5Y($-E<G0B+`H))V)T
M7V-E<G1?<F5Q=65S="<@/3X@(E)E<75E<W0B+`H))V)T7V-E<G1?<V5L9E]S
M:6=N)R`]/B`B4V5L9BU3:6=N960B+`H))V)T7V-E<G1?=FEE=R<@/3X@(E9I
M97<@0V5R=',B+`H))V)T7V-E<G1I9FEC871E<R<@/3X@(D-E<G1I9FEC871E
M<R(L"@DG8G1?8V9?8V]N9FEG=7)E)R`]/B`B0V]L9$9U<VEO;B!3971T:6YG
M<R(L"@DG8G1?8VAA;F=E7W!A<W-W9"<@/3X@(D-H86YG92!087-S=V]R9"(L
M"@DG8G1?8VQE86Y?;&]G)R`]/B`B0VQE87(@3&]G(BP*"2=B=%]C;&5A<B<@
M/3X@(D-L96%R(BP*"2=B=%]C;&EE;G1?=&5M<&QA=&5S)R`]/B`B0VQI96YT
M(%1E;7!L871E<R(L"@DG8G1?8VQI96YT<R<@/3X@(D-L:65N=',B+`H))V)T
M7V-O9&5P86=E7V-H86YG92<@/3X@)T-H86YG92!%;F-O9&EN9R<L"@DG8G1?
M8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT($EN9F\B+`H))V)T7V-O;6UO;E]A
M8VPG(#T^("=#;VUM;VX@04-,)RP*"2=B=%]C;VYF:6=U<F5?;6%I;&QI<W1S
M)R`]/B`B4V5T(%5P($UA:6QM86XB+`H))V)T7V-O;F9I9W5R95]O9&)C)R`]
M/B`B3T1"0R!3971T:6YG<R(L"@DG8G1?8V]P>2<@/3X@(D-O<'DB+`H))V)T
M7V-O<'E?;6]V92<@/3X@(D-O<'DO36]V92(L"@DG8G1?8W)E871E)R`]/B`B
M0W)E871E(BP*"2=B=%]C<F5A=&5?86-C;W5N="<@/3X@(D-R96%T92!.97<@
M06-C;W5N="(L"@DG8G1?8W)E871E7V1I<B<@/3X@(D%D9"!.97<@1&ER96-T
M;W)Y(BP*"2=B=%]C<F5A=&5?9FEL92<@/3X@(D%D9"!.97<@1FEL92(L"@DG
M8G1?8V]U;G1?<VEZ92<@/3X@(D-A;&-U;&%T92!3:7IE(BP*"2=B=%]C<F]N
M=&%B7W5N:7@G(#T^(")#<F]N=&%B(BP*"2=B=%]C<F]N=&%B7W=I;B<@/3X@
M(E-C:&5D=6QE<B(L"@DG8G1?8W5S=&]M7V)U='1O;E]N97<G(#T^(")!9&0@
M3F5W($)U='1O;B(L"@DG8G1?8W5S=&]M7V)U='1O;G,G(#T^(")#=7-T;VT@
M0G5T=&]N<R(L"@DG8G1?8W5S=&]M:7IE)R`]/B`B0W5S=&]M:7IE(BP*"2=B
M=%]D871A8F%S97,G(#T^(")$871A8F%S97,B+`H))V)T7V1A=&%B87-E7W-E
M<G9E<G,G(#T^("=$871A8F%S92!397)V97)S)RP*"2=B=%]D8E]U<W)?;F5W
M)R`]/B`B061D($YE=R!$871A8F%S92!5<V5R(BP*"2=B=%]D8E]N97<G(#T^
M(")!9&0@3F5W($1A=&%B87-E(BP*"2=B=%]D8E]P:'!M>6%D;6EN)R`]/B`B
M37E344P@061M:6XB+`H))V)T7V1B7W!H<'!G861M:6XG(#T^(")0;W-T9W)E
M4U%,($%D;6EN(BP*"2=B=%]D8G5S97)?9&5F875L="<@/3X@(D1E9F%U;'0@
M9F]R($1"(%=E8D%D;6EN(BP*"2=B=%]D96-L:6YE)R`]/B`B1&5C;&EN92(L
M"@DG8G1?9&5F875L="<@/3X@(D1E9F%U;'0B+`H))V)T7V1E9F%U;'1S)R`]
M/B`B1&5F875L=',B+`H))V)T7V1E;&5T92<@/3X@(D1E;&5T92(L"@DG8G1?
M9&ER96-T;W)I97,G(#T^(")$:7)E8W1O<FEE<R(L"@DG8G1?9&ES86)L92<@
M/3X@(D1I<V%B;&4B+`H))V)T7V1N<R<@/3X@(D1.4R(L"@DG8G1?9&YS7V%D
M9"<@/3X@(D%D9"!.97<@4F5C;W)D(BP*"2=B=%]D;G-R96-O<F1?861D)R`]
M/B`B061D($YE=R!296-O<F0B+`H))V)T7V1N<U]S;V$G(#T^(")33T$@4')E
M9F5R96YC97,B+`H))V)T7V1N<U]P<F5F97)E;F-E<R<@/3X@(D1.4R!0<F5F
M97)E;F-E<R(L"@DG8G1?9&]?8F%C:W5P)R`]/B`B0F%C:R!5<"(L"@DG8G1?
M9&]?<F5S=&]R92<@/3X@(E)E<W1O<F4B+`H))V)T7V1O7W5P;&]A9"<@/3X@
M(E5P;&]A9"(L"@DG8G1?9&]M86EN7W1E;7!L871E<R<@/3X@(D1O;6%I;B!4
M96UP;&%T97,B+`H))V)T7V1O;6%I;E]U<V5R)R`]/B`B1&]M86EN($%D;6EN
M:7-T<F%T;W(B+`H))V)T7V1O;6%I;E]U<V5R7W!A<W-W9"<@/3X@(D1O;6%I
M;B!!9&UI;FES=')A=&]R(%!A<W-W;W)D(BP*"2=B=%]D;VUA:6YS)R`]/B`B
M1&]M86EN<R(L"@DG8G1?9&]W;FQO860G(#T^(")$;W=N;&]A9"(L"@DG8G1?
M9&]W;FQO861?;&]G)R`]/B`B1&]W;FQO860B+`H))V)T7V5D:70G(#T^(")%
M9&ET(BP*"2=B=%]E;F%B;&4G(#T^(")%;F%B;&4B+`H))V)T7V5V96YT;6=R
M)R`]/B`G179E;G0@36%N86=E<B<L"@DG8G1?979E;G1?:&%N9&QE<E]A9&0G
M(#T^("=!9&0@3F5W($5V96YT($AA;F1L97(G+`H))V)T7V5X<&]R="<@/3X@
M)T5X<&]R="<L"@DG8G1?97AT<F%S)R`]/B`B17AT<F%S(BP*"2=B=%]F:6QE
M7VUA;F%G97(G(#T^(")&:6QE($UA;F%G97(B+`H))V)T7V9I;FES:"<@/3X@
M(D9I;FES:"(L"@DG8G1?9G1P7V%C8V]U;G0G(#T^(")&5%`@06-C;W5N="!0
M<F]P97)T:65S(BP*"2=B=%]F;W)G971?<&%S<W=O<F0G(#T^(")&;W)G;W0@
M4&%S<W=O<F0_(BP*"2=B=%]F<%]S<VQ?=V5B861M:6XG(#T^(")&4"U34TP@
M5V5B861M:6XB+`H))V)T7V9P7W=E8F%D;6EN)R`]/B`B1E`@5V5B861M:6XB
M+`H))V)T7V9T<%]S=&%T<R<@/3X@(D944"!3=&%T<R(L"@DG8G1?9V5T7W!A
M<W-W;W)D)R`]/B`B1V5T(%!A<W-W;W)D(BP*"2=B=%]G;&]B86Q?8VAA;F=E
M<R<@/3X@(D=R;W5P($]P97)A=&EO;G,B+`H))V)T7VAE;'`G(#T^(")(96QP
M(BP*"2=B=%]H:61E7V%L:6%S97,G(#T^(")(:61E($%L:6%S97,B+`H))V)T
M7VAI9&5?=&]O;&)A<B<@/3X@)TAI9&4@=&]O;&)A<B<L"@DG8G1?:&ED95]S
M=6)D;VUA:6YS)R`]/B`B2&ED92!3=6)D;VUA:6YS(BP*"2=B=%]H;VUE)R`]
M/B`B2&]M92(L"@DG8G1?:&]S=&EN9R<@/3X@(DAO<W1I;F<B+`H))V)T7VEN
M<W1A;&PG(#T^("));G-T86QL(BP*"2=B=%]I;G1E<F9A8V5?;6%N86=E;65N
M="<@/3X@(DEN=&5R9F%C92!-86YA9V5M96YT(BP*"2=B=%]I<%]A;&EA<VEN
M9R<@/3X@(DE0($%D9')E<W-E<R(L"@DG8G1?:7!?861D)R`]/B`B061D($YE
M=R!)4"!!9&1R97-S(BP*"2=B=%]I<%]P;V]L)R`]/B`B25`@4&]O;"(L"@DG
M8G1?:V5Y7VEN9F\G(#T^("),:6-E;G-E($UA;F%G96UE;G0B+`H))V)T7VME
M>5]B=7EO;FQI;F5?861D;VYS)R`]/B`G3W)D97(@0V]N=')O;"!086YE;"!!
M9&0M3VYS)RP*"2=B=%]K97E?8G5Y;VYL:6YE7W5P9W)A9&5S)R`]/B`G3W)D
M97(@0V]N=')O;"!086YE;"!5<&=R861E<R<L"@DG8G1?:V5Y7V)U>6]N;&EN
M95]N97<G(#T^("=/<F1E<B!.97<@2V5Y)RP*"2=B=%]K97E?=7!D871E)R`]
M/B`G4F5T<FEE=F4@2V5Y<R<L"@DG8G1?:V5Y7W5P;&]A9"<@/3X@)U5P;&]A
M9"!+97DG+`H))V)T7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL;V%D($ME>2<L
M"@DG8G1?:V5Y7W)E=F5R="<@/3X@)U)O;&P@0F%C:R!+97DG+`H))V)T7VQI
M;6ET<R<@/3X@(DQI;6ET<R(L"@DG8G1?;&]C86QE7V%D9"<@/3X@)T%D9"!,
M;V-A;&4G+`H))V)T7VQO8V%L97,G(#T^("=,;V-A;&5S)RP*"2=B=%]L;V=?
M;6%N86=E<B<@/3X@(DQO9R!-86YA9V5R(BP*"2=B=%]L;V=I;B<@/3X@(DQO
M9VEN(BP*"2=B=%]L;V=O)R`]/B`B3&]G;R!3971U<"(L"@DG8G1?;&]G;U]D
M969A=6QT)R`]/B`B1&5F875L="!,;V=O(BP*"2=B=%]L;V=O7W-E;F1?;&EN
M:R<@/3X@(D%T=&%C:"!,:6YK(BP*"2=B=%]L;V=O7W-E;F1?;&]G;R<@/3X@
M(D%T=&%C:"!,;V=O(BP*"2=B=%]L;V=O=70G(#T^("),;V<@3W5T(BP*"2=B
M=%]L;V=R;W1A=&EO;B<@/3X@(DQO9R!2;W1A=&EO;B(L"@DG8G1?;6%I;"<@
M/3X@(DUA:6PB+`H))V)T7VUA:6Q?86QI87-?861D)R`]/B`B061D($YE=R!-
M86EL($%L:6%S(BP*"2=B=%]M86EL7V%L:6%S97,G(#T^(")-86EL($%L:6%S
M97,B+`H))V)T7VUA:6Q?9W)O=7!?861D)R`]/B`B061D($YE=R!-96UB97(B
M+`H))V)T7VUA:6Q?9W)O=7!S)R`]/B`B1W)O=7!S(BP*"2=B=%]M86EL7V1R
M=V5B)R`]/B`G1'(N5V5B)RP*"2=B=%]M86EL7VYA;65?861D)R`]/B`B061D
M($YE=R!-86EL($YA;64B+`H))V)T7VUA:6Q?<')E9F5R96YC97,G(#T^(")0
M<F5F97)E;F-E<R(L"@DG8G1?;6%I;%]G<F]U<"<@/3X@(DUA:6P@1W)O=7`B
M+`H))V)T7VUA:6Q?;6%I;&)O>"<@/3X@(DUA:6QB;W@B+`H))V)T7VUA:6Q?
M<F5D:7)E8W0G(#T^(")2961I<F5C="(L"@DG8G1?;6%I;%]R97-P7V%D9"<@
M/3X@(D%D9"!.97<@075T;W)E<W!O;F1E<B(L"@DG8G1?;6%I;%]R97-P7V%T
M=&%C:%]A9&0G(#T^(")!9&0@3F5W($%T=&%C:&UE;G0B+`H))V)T7VUA:6Q?
M<F5S<%]F:6QE<R<@/3X@(D%T=&%C:&UE;G0@1FEL97,B+`H))V)T7VUA:6Q?
M<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*"2=B=%]M86EL7W-P
M86UF:6QT97(G(#T^(")3<&%M($9I;'1E<B(L"@DG8G1?;6%I;%]W96)M86EL
M)R`]/B`B5V5B36%I;"(L"@DG8G1?;6%I;&QI<W1?;F5W)R`]/B`B061D($YE
M=R!-86EL:6YG($QI<W0B+`H))V)T7VUA:6QL:7-T7VUE;6)E<E]N97<G(#T^
M(")!9&0@3F5W($UE;6)E<B(L"@DG8G1?;6%I;&QI<W1S)R`]/B`B36%I;&EN
M9R!,:7-T<R(L"@DG8G1?;6%I;&UA;B<@/3X@(DUA:6QM86XB+`H))V)T7VUA
M:V5?9'5M<"<@/3X@(D-R96%T92!"86-K=7`B+`H))V)T7VUA;F%G92<@/3X@
M(DUA;F%G92(L"@DG8G1?;6%S=&5R)R`]/B`B36%S=&5R(BP*"2=B=%]M:6=R
M871I;VY?;6%N86=E<B<@/3X@)TUI9W)A=&EO;B!-86YA9V5R)RP*"2=B=%]M
M:6=R871E)R`]/B`G36EG<F%T92<L"@DG8G1?;6]D=6QE<U]A9&0G(#T^("=!
M9&0@36]D=6QE)RP*"2=B=%]M;V1U;&5S7VUA;F%G92<@/3X@)TUA;F%G92!-
M;V1U;&5S)RP*"2=B=%]M;W9E)R`]/B`B36]V92(L"@DG8G1?;7!C)R`]/B`B
M37E0;&5S:RYC;VTB+`H))V)T7VYE=U]C;&EE;G0G(#T^(")!9&0@3F5W($-L
M:65N="!!8V-O=6YT(BP*"2=B=%]N97=?9&]M86EN)R`]/B`B061D($YE=R!$
M;VUA:6XB+`H))V)T7VYE>'0G(#T^(").97AT(#X^(BP*"2=B=%]N97AT7W!A
M9V4G(#T^(").97AT(BP*"2=B=%]N971W;W)K7V%D9"<@/3X@(D%D9"!.97<@
M3F5T=V]R:R(L"@DG8G1?;F]T:69I8V%T:6]N<R<@/3X@(DYO=&EF:6-A=&EO
M;G,B+`H))V)T7V]D8F-?9'-N7V%D9"<@/3X@(D%D9"!.97<@3T1"0R!$4TXB
M+`H))V)T7V]F9B<@/3X@(D]F9B(L"@DG8G1?;VLG(#T^(")/2R(L"@DG8G1?
M;VXG(#T^(")/;B(L"@DG8G1?;VY?;V9F)R`]/B`B3VXO3V9F(BP*"2=B=%]P
M9%]N97<G(#T^(")!9&0@3F5W($1I<F5C=&]R>2(L"@DG8G1?<&1?=7-E<E]N
M97<G(#T^(")!9&0@3F5W(%5S97(B+`H))V)T7W!E<FUI<W-I;VYS)R`]/B`B
M4&5R;6ES<VEO;G,B+`H))V)T7W!H<&UY861M:6XG(#T^(")0:'!->4%D;6EN
M(BP*"2=B=%]P:'!P9V%D;6EN)R`]/B`B4&AP4&=!9&UI;B(L"@DG8G1?<&]S
M=&=R95]S<6PG(#T^(")0;W-T9W)E4U%,(BP*"2=B=%]P<F5F97)E;F-E<R<@
M/3X@(E!R969E<F5N8V5S(BP*"2=B=%]P<F5V7W!A9V4G(#T^(")0<F5V(BP*
M"2=B=%]P<F5V:65W)R`]/B`G4VET92!0<F5V:65W)RP*"2=B=%]P<FEN="<@
M/3X@(E!R:6YT(BP*"2=B=%]R96)O;W0G(#T^(")296)O;W0B+`H))V)T7W)E
M9G)E<V@G(#T^(")2969R97-H(BP*"2=B=%]R96=I<W1E<B<@/3X@(E)E9VES
M=&5R(BP*"2=B=%]R96UO=F4G(#T^(")296UO=F4B+`H))V)T7W)E;6]V95]F
M<F]M)R`]/B`B4F5M;W9E(#X^(BP*"2=B=%]F<F]M7W)E;6]V92<@/3X@(CP\
M(%)E;6]V92(L"@DG8G1?<F5M;W9E7W-E;&5C=&5D)R`]/B`B4F5M;W9E(%-E
M;&5C=&5D(BP*"2=B=%]R97!A:7)?:7`G(#T^(")297!A:7(@25`B+`H))V)T
M7W)E<&]R="<@/3X@(E)E<&]R="(L"@DG8G1?<F5P;W)T7V%U=&\G(#T^("=2
M97!O<G0@1&5L:79E<GDG+`H))V)T7W)E<&]R=%]A=71O7VYE=R<@/3X@)T%D
M9"!$96QI=F5R>2!38VAE9'5L92<L"@DG8G1?<F5P;W)T7VYE=R<@/3X@(D%D
M9"!.97<@3&%Y;W5T(BP*"2=B=%]R97)E861?:7`G(#T^(")297)E860@25`B
M+`H))V)T7W)E<V5T)R`]/B`B4F5S970B+`H))V)T7W)E<W1A<G1?<V5R=FEC
M97,G(#T^(")397)V:6-E($UA;F%G96UE;G0B+`H))V)T7W-A=F4G(#T^(")3
M879E(BP*"2=B=%]S96%R8V@G(#T^(")396%R8V@B+`H))V)T7W-E;F1?8GE?
M96UA:6PG(#T^(")396YD($)Y($4M36%I;"(L"@DG8G1?<V5N9%]F:6QE)R`]
M/B`B4V5N9"!&:6QE(BP*"2=B=%]S96YD7VUA:6PG(#T^(")396YD($UA:6PB
M+`H))V)T7W-E;F1?<&%S<W=D)R`]/B`B4V5N9"!087-S=V]R9"(L"@DG8G1?
M<V5N9%]T97AT)R`]/B`B4V5N9"!497AT(BP*"2=B=%]S97)V97(G(#T^(")3
M97)V97(B+`H))V)T7W-E<G9E<E]A9&0G(#T^(")!9&0@3F5W(%-E<G9E<B(L
M"@DG8G1?<V5R=F5R7W!R969E<F5N8V5S)R`]/B`B4V5R=F5R(%!R969E<F5N
M8V5S(BP*"2=B=%]S97)V97)S7VQI<W0G(#T^(")397)V97)S(BP*"2=B=%]S
M97-S:6]N7W-E='5P)R`]/B`B3&]G:6X@4V5T=&EN9W,B+`H))V)T7W-E<W-I
M;VYS)R`]/B`B4V5S<VEO;G,B+`H))V)T7W-E="<@/3X@(E-E="(L"@DG8G1?
M<V5T7V%S7V1E9F%U;'0G(#T^(")3970@07,@1&5F875L="(L"@DG8G1?<V5T
M=7`G(#T^(")3971U<"(L"@DG8G1?<VAO=U]A;&EA<V5S)R`]/B`B4VAO=R!!
M;&EA<V5S(BP*"2=B=%]S:&]W7V%L;"<@/3X@(E-H;W<@06QL(BP*"2=B=%]S
M:&]W7W-U8F1O;6%I;G,G(#T^(")3:&]W(%-U8F1O;6%I;G,B+`H))V)T7W-H
M=71D;W=N)R`]/B`B4VAU="!$;W=N(BP*"2=B=%]S:71E7V%P<'!K9W,G(#T^
M(")!<'!L:6-A=&EO;B!6875L="(L"@DG8G1?<VET95]A<'!P;V]L)R`]/B`B
M07!P;&EC871I;VX@4&]O;"(L"@DG8G1?<VET95]A<'!S)R`]/B`B07!P;&EC
M871I;VX@5F%U;'0B+`H))V)T7W-I=&5?87!P7V%D9"<@/3X@(D%D9"!.97<@
M07!P;&EC871I;VXB+`H))V)T7W-I=&5?87!P7W!K9U]N97<G(#T^(")!9&0@
M3F5W($%P<&QI8V%T:6]N(%!A8VMA9V4B+`H))V)T7V%D9&ET:6]N86Q?:V5Y
M7W5P;&]A9"<@/3X@)U5P;&]A9"!.97<@2V5Y)RP*"2=B=%]A9&1I=&EO;F%L
M7VME>5]D;W=N;&]A9"<@/3X@)T1O=VYL;V%D($ME>2<L"@DG8G1?861D:71I
M;VYA;%]K97E?<F5M;W9E)R`]/B`G4F5M;W9E($ME>2<L"@DG8G1?861D:71I
M;VYA;%]K97E?86-T:79A=&4G(#T^("=!8W1I=F%T92<L"@DG8G1?<VET95]B
M=6EL9&5R)R`]/B`B36%M8F\@0TU3(BP*"2=B=%]S:V5L971O;B<@/3X@(E-K
M96QE=&]N(BP*"2=B=%]S:VEN<R<@/3X@)U-K:6YS)RP*"2=B=%]S:VEN7V%D
M9"<@/3X@)T%D9"!.97<@4VMI;B<L"@DG8G1?<VMI;E]M86YU86PG(#T^("=3
M:VEN<R!2969E<F5N8V4G+`H))V)T7W-K:6Y?9&]W;FQO860G(#T^("=$;W=N
M;&]A9"!3:VEN)RP*"2=B=%]S:VEN7W)E<&QA8V4G(#T^("=5<&1A=&4@4VMI
M;B<L"@DG8G1?<W!A;6%S<V%S<VEN)R`]/B`B4W!A;4%S<V%S<VEN(BP*"2=B
M=%]S<&%M87-S87-S:6Y?=')A:6XG(#T^(")4<F%I;FEN9R(L"@DG8G1?<W!A
M;69I;'1E<B<@/3X@(E-P86T@1FEL=&5R(BP*"2=B=%]S<VAT97)M)R`]/B`G
M4U-((%1E<FUI;F%L)RP*"2=B=%]S=&%T:7-T:6-S)R`]/B`B4W1A=&ES=&EC
M<R(L"@DG8G1?<W5B9&]M86EN7VYE=R<@/3X@(D%D9"!.97<@4W5B9&]M86EN
M(BP*"2=B=%]S=6)D;VUA:6YS)R`]/B`B4W5B9&]M86EN<R(L"@DG8G1?<W5B
M;6ET)R`]/B`B4W5B;6ET(BP*"2=B=%]S=6UM87)Y7W)E<&]R="<@/3X@(E-U
M;6UA<GD@4F5P;W)T(BP*"2=B=%]S=7!P;W)T)R`]/B`B4W5P<&]R="(L"@DG
M8G1?<W=I=&-H)R`]/B`B4W=I=&-H(BP*"2=B=%]S>7-T96U?=&EM92<@/3X@
M(E-Y<W1E;2!4:6UE(BP*"2=B=%]T87-K7VYE=R<@/3X@(D%D9"!.97<@5&%S
M:R(L"@DG8G1?9&]M7W1M<&Q?861D)R`]/B`G061D($YE=R!$;VUA:6X@5&5M
M<&QA=&4G+`H))V)T7V-L7W1M<&Q?861D)R`]/B`G061D($YE=R!#;&EE;G0@
M5&5M<&QA=&4G+`H))V)T7V-R;VY?8F%C:W5P)R`]/B`G4V-H961U;&5D($)A
M8VMU<"!3971T:6YG<R<L"@DG8G1?=&5S="<@/3X@(E1E<W0@0V]N;F5C=&EO
M;B(L"@DG8G1?=&5X="<@/3X@(E1E>'0B+`H))V)T7W1O=6-H)R`]/B`B5&]U
M8V@B+`H))V)T7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=B=%]T<F%F9FEC
M7VAI<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))V)T7W1T<U]G;&]B
M86Q?;&ES="<@/3X@(E-E<G9E<G,B+`H))V)T7W1T<U]T:6-K971S7V%L;"<@
M/3X@(D%L;"(L"@DG8G1?='1S7W1I8VME='-?86QL;W!E;F5D)R`]/B`B06QL
M($]P96YE9"(L"@DG8G1?='1S7W1I8VME='-?8VQO<V5D)R`]/B`B0VQO<V5D
M(BP*"2=B=%]T='-?=&EC:V5T<U]N97<G(#T^(").97<B+`H))V)T7W1T<U]T
M:6-K971S7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B+`H))V)T7W1T<U]C871S
M)R`]/B`B0V%T96=O<FEE<R(L"@DG8G1?='1S7V=E;F5R86Q?8V]N9FEG)R`]
M/B`B1V5N97)A;"!3971T:6YG<R(L"@DG8G1?='1S7VUA:6Q?9V%T92<@/3X@
M(DUA:6P@1V%T92!3971T:6YG<R(L"@DG8G1?='1S7W!R:6]R:71I97,G(#T^
M(")0<FEO<FET:65S(BP*"2=B=%]T='-?<75E=65S)R`]/B`B475E=65S(BP*
M"2=B=%]U<%]L979E;"<@/3X@(E5P($QE=F5L(BP*"2=B=%]U<&1A=&4G(#T^
M(")5<&1A=&4B+`H))V)T7W5P;&]A9"<@/3X@(E5P;&]A9"(L"@DG8G1?=7!L
M;V%D7V9R;VU?9G1P)R`]/B`B1E10(%5P;&]A9"(L"@DG8G1?=V5B7V%P<%]N
M97<G(#T^(")!9&0@3F5W($IA=F$@07!P;&EC871I;VXB+`H))V)T7W=E8E]A
M<'!S)R`]/B`B5&]M8V%T(BP*"2=B=%]W96)?<W1A=',G(#T^(")796(@4W1A
M=',B+`H))V)T7W=E8E]S=&%T<U]S<VPG(#T^(")796(@4W1A=',@4U-,(BP*
M"2=B=%]W96)?=7-E<E]A9&0G(#T^(")!9&0@3F5W(%=E8B!5<V5R(BP*"2=B
M=%]W96)?=7-E<G,G(#T^(")796(@57-E<G,B+`H))V)T7W=E8F%D;6EN)R`]
M/B`B1$(@5V5B061M:6XB+`H))V)T7W=E8F%L:7IE<B<@/3X@(E=E8F%L:7IE
M<B(L"@DG8G1?=V5B86QI>F5R7W!R969E<F5N8V5S)R`]/B`B5V5B(%-T871I
M<W1I8W,@4')E9F5R96YC97,B+`H))V)T7VAI9&1E;BUR969E<G)E<BUA9&0G
M(#T^("=(:61E($5N=')I97,G+`H))V)T7V=R;W5P+7)E9F5R<F5R+6%D9"<@
M/3X@)T=R;W5P(%)E9F5R<F5R<R<L"@DG8G1?=VAA='-?;F5W7V9U;&PG(#T^
M(")3964@=&AE(&9U;&P@;&ES="!O9B!C:&%N9V5S(BP*"2=B=%]W:&ET95]L
M:7-T)R`]/B`B5VAI=&4@3&ES="(L"@DG8G1?=VAI=&5?;&ES=%]A9&0G(#T^
M(")!9&0@3F5T=V]R:R(L"@DG8V5R=%]?861D7VYE=U]C97)T)R`]/B`B061D
M($YE=R!#97)T:69I8V%T92(L"@DG8V5R=%]?861M:6Y?<V5R=F5R7VYO=%]R
M97-P;VYD)R`]/B`B268@)3$@9&]E<R!N;W0@<F5S<&]N9"P@<&QE87-E(&%C
M8V5S<R!T:&4@<V5R=F5R(&%N9"!R97-T87)T('1H92!A9&UI;FES=')A=&EV
M92!W96(@<V5R=F5R(&5N9VEN92!M86YU86QL>2XB+`H))V-E<G1?7V-E<G1S
M7W1R86YS9F5R<F5D7W1O7V%D;6EN7W)E<"<@/3X@(E1H92!F;VQL;W=I;F<@
M8V5R=&EF:6-A=&5S(&%R92!S=&EL;"!I;B!U<V4@86YD('1H97)E9F]R92!C
M86YN;W0@8F4@<F5M;W9E9"`Z("4Q.R!!;&P@;V8@=&AE;2!W:6QL(&)E('!L
M86-E9"!T;R!T:&4@861M:6YI<W1R871O<B=S(&-E<G1I9FEC871E(')E<&]S
M:71O<GDN(BP*"2=C97)T7U]C:&]O<V5?8V5R="<@/3X@(E-E;&5C="!A(&-E
M<G1I9FEC871E(&9I;&4N(BP*"2=C97)T7U]I;G9A;&ED7W5P;%]C97)T)R`]
M/B`B57!L;V%D960@8V5R=&EF:6-A=&4@:7,@:6YV86QI9"XB+`H))V-E<G1?
M7VYO7V-E<G1?;W)?<'9T:V5Y)R`]/B`B56YA8FQE('1O(&EN<W1A;&P@=&AE
M(&1E9F%U;'0@8V5R=&EF:6-A=&4Z(&YO(&-E<G1I9FEC871E('=I=&@@<')I
M=F%T92!K97D@<V5L96-T960N(BP*"2=C97)T7U]O;FQY7V]N95]C97)T7V-A
M;E]B95]D969A=6QT)R`]/B`B3VYL>2!O;F4@8V5R=&EF:6-A=&4@8V%N(&)E
M('-E="!A<R!D969A=6QT+B(L"@DG8V5R=%]?;VYL>5]O;F5?8V5R=%]C86Y?
M<V5T=7!?;VY?8W`G(#T^(")/;FQY(&]N92!C97)T:69I8V%T92!C86X@8F4@
M:6YS=&%L;&5D(&EN=&\@=&AE($-O;G1R;VP@4&%N96PN(BP*"2=C97)T7U]P
M<FEV871E7VME>5]F;W5N9"<@/3X@(E1H92!P<FEV871E(&ME>2!F;W(@=&AE
M('5P;&]A9&5D(&-E<G1I9FEC871E('=A<R!F;W5N9"!U;F1E<B!N86UE("4Q
M+B!#97)T:69I8V%T92!W87,@<W5C8V5S<V9U;&QY(&%D9&5D+B(L"@DG8V5R
M=%]?<V5L96-T7V-E<G1?9F]R7VEN<W1A;&Q?;VY?8W`G(#T^(")396QE8W0@
M=&AE(&-E<G1I9FEC871E('1O(&EN<W1A;&P@:6YT;R!T:&4@0V]N=')O;"!0
M86YE;"XB+`H))V-E<G1?7W-E;&5C=%]C97)T7V9O<E]S971?9&5F875L="<@
M/3X@(E-E;&5C="!A(&-E<G1I9FEC871E('1O('-E="!A<R!D969A=6QT+B(L
M"@DG8V5R=%]?<W-L7V-E<G1?<F5L;V%D)R`]/B`B+BXN4U-,(&-E<G1I9FEC
M871E(&ES(&)E:6YG(')E;&]A9&5D+"!P;&5A<V4@=V%I="XN+B(L"@DG8V5R
M=%]?=&ET;&5?8W`G(#T^(")#97)T:69I8V%T92!R97!O<VET;W)Y(BP*"2=C
M97)T7U]T:71L95]D;VUA:6XG(#T^(")#97)T:69I8V%T92!R97!O<VET;W)Y
M(&9O<B!D;VUA:6X@/&(^)3$\+V(^(BP*"2=C97)T7U]U;F%B;&5?9FEN9%]A
M<'!R7W!V=%]K97DG(#T^(")5;F%B;&4@=&\@9FEN9"!T:&4@87!P<F]P<FEA
M=&4@<')I=F%T92!K97D@9F]R('1H92!C97)T:69I8V%T92XB+`H))V-E<G1?
M7W5N86)L95]I;G-T86QL7V-E<G1?;VY?8W`G(#T^(")5;F%B;&4@=&\@:6YS
M=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T:&4@0V]N=')O;"!086YE;#H@
M=&AE('!R:79A=&4@:V5Y(&%N9"!C97)T:69I8V%T92!C;VYT96YT<R!A<F4@
M;6ES<VEN9RXB+`H))V-E<G1?7W5N86)L95]T;U]U<&QO860G(#T^("=5;F%B
M;&4@=&\@:6YS=&%L;"!T:&4@8V5R=&EF:6-A=&4@:6YT;R!T:&4@0V]N=')O
M;"!086YE;#H@)3$G+`H))V-E<G1?7W5N86)L95]T;U]D96QE=&5?8V5R=&EF
M:6-A=&5S)R`]/B`B56YA8FQE('1O(')E;6]V92!C97)T:69I8V%T97,Z("(L
M"@DG8V5R=%]?=7!L;V%D7V-E<G0G(#T^(")5<&QO860@8V5R=&EF:6-A=&4@
M9FEL92!A;F0@9FEN9"!M871C:&EN9R!P<FEV871E(&ME>2!I;B!T:&4@<F5P
M;W-I=&]R>2XB+`H))V-E<G1?7W5P;&]A9%]C97)T7V)Y7W!V=%]K97DG(#T^
M(")&:6YD('1H92!A<'!R;W!R:6%T92!P<FEV871E(&ME>2!T;R!T:&4@8V5R
M=&EF:6-A=&4B+`H))V-E<G1?861D7U]B:71S)R`]/B`B0FET<R(L"@DG8V5R
M=%]A9&1?7V-A7V-E<G0G(#T^(")#02!C97)T:69I8V%T92(L"@DG8V5R=%]A
M9&1?7V-E<G0G(#T^(")#97)T:69I8V%T92(L"@DG8V5R=%]A9&1?7V-E<G1?
M;F%M92<@/3X@(D-E<G1I9FEC871E(&YA;64B+`H))V-E<G1?861D7U]C:71Y
M)R`]/B`B3&]C871I;VX@*$-I='DI(BP*"2=C97)T7V%D9%]?96YT97)?8V5R
M=%]N86UE)R`]/B`B16YT97(@8V5R=&EF:6-A=&4@;F%M92XB+`H))V-E<G1?
M861D7U]E;G1E<E]P=G1?:V5Y7V-E<G1?9FEL92<@/3X@(D5N=&5R('!R:79A
M=&4@:V5Y(&%N9"!C97)T:69I8V%T92!F:6QE+B(L"@DG8V5R=%]A9&1?7V5N
M=&5R7W!V=%]K97E?8V5R=%]T97AT)R`]/B`B16YT97(@<')I=F%T92!K97D@
M86YD(&-E<G1I9FEC871E('1E>'0N(BP*"2=C97)T7V%D9%]?;W)G86YI>F%T
M:6]N7VYA;64G(#T^(")/<F=A;FEZ871I;VX@;F%M92`H8V]M<&%N>2DB+`H)
M)V-E<G1?861D7U]O<F=A;FEZ871I;VY?=6YI=%]N86UE)R`]/B`B3W)G86YI
M>F%T:6]N(&1E<&%R=&UE;G0O9&EV:7-I;VX@;F%M92(L"@DG8V5R=%]A9&1?
M7W!R:79A=&5?:V5Y7V%N9%]C<W)?<V5N=%]E;6%I;"<@/3X@(E1H92!G96YE
M<F%T960@<')I=F%T92!K97D@86YD($-34B!H879E(&)E96X@<V5N="!T;R!E
M+6UA:6PZ("4Q(BP*"2=C97)T7V%D9%]?<'9T7VME>2<@/3X@(E!R:79A=&4@
M:V5Y(BP*"2=C97)T7V%D9%]?<W1A=&4G(#T^(")3=&%T92!O<B!P<F]V:6YC
M92(L"@DG8V5R=%]A9&1?7W1I=&QE7V-P)R`]/B`B0W)E871E(&$@;F5W(%-3
M3"!C97)T:69I8V%T92(L"@DG8V5R=%]A9&1?7W1I=&QE7V1O;6%I;B<@/3X@
M(D-R96%T92!A(&YE=R!34TP@8V5R=&EF:6-A=&4@9F]R(&1O;6%I;B`\8CXE
M,3PO8CXB+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7V-A7V-E<G0G(#T^(")5
M;F%B;&4@=&\@<V5T('1H92!#02!C97)T:69I8V%T93H@)3$B+`H))V-E<G1?
M861D7U]U;F%B;&5?<V5T7V-E<G0G(#T^(")5;F%B;&4@=&\@<V5T('1H92!C
M97)T:69I8V%T93H@)3$B+`H))V-E<G1?861D7U]U;F%B;&5?<V5T7W!R:79A
M=&5?:V5Y)R`]/B`B56YA8FQE('1O('-E="!T:&4@<')I=F%T92!K97DZ("4Q
M(BP*"2=C97)T7V%D9%]?=7!L;V%D7V-E<G1?9FEL97,G(#T^(")5<&QO860@
M8V5R=&EF:6-A=&4@9FEL97,B+`H))V-E<G1?861D7U]U<&QO861?8V5R=%]T
M97AT)R`]/B`B57!L;V%D(&-E<G1I9FEC871E(&%S('1E>'0B+`H))V-E<G1?
M961I=%]?8V]M<&]N96YT7V%B<V5N="<@/3X@(D-O;7!O;F5N="!I<R!M:7-S
M:6YG(BP*"2=C97)T7V5D:71?7V-S<B<@/3X@(D-34B(L"@DG8V5R=%]E9&ET
M7U]O=F5R;&]A9%]C85]C97)T7V-O;F9I<FT_)R`]/B`B3W9E<G=R:71E('1H
M92!E>&ES=&EN9R!#02!C97)T:69I8V%T93\B+`H))V-E<G1?961I=%]?;W9E
M<FQO861?8V5R=%]C;VYF:7)M/R<@/3X@(D]V97)W<FET92!T:&4@97AI<W1I
M;F<@0V5R=&EF:6-A=&4_(BP*"2=C97)T7V5D:71?7W)E;6]V95]C85]C;VYF
M:7)M/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@=VES:"!T;R!R96UO=F4@=&AE
M($-!(&-E<G1I9FEC871E/R(L"@DG8V5R=%]E9&ET7U]T:71L95]C<"<@/3X@
M(E-33"!C97)T:69I8V%T92(L"@DG8V5R=%]E9&ET7U]T:71L95]D;VUA:6XG
M(#T^(")34TP@8V5R=&EF:6-A=&4@9F]R(&1O;6%I;B`\8CXE,3PO8CXB+`H)
M)V-E<G1I9FEC871E<U]L:7-T7U]C97)T:69I8V%T95]U<V5D7V%S7V1E9F%U
M;'0G(#T^(")O;F4@;V8@=&AE(&-E<G1I9FEC871E('EO=2!A<F4@9V]I;F<@
M=&\@9&5L971E(&ES('5S960@87,@=&AE($1E9F%U;'0@0V5R=&EF:6-A=&4N
M(BP*"2=C97)T:69I8V%T97-?;&ES=%]?8V5R=&EF:6-A=&5S)R`]/B`B4U-,
M(&-E<G1I9FEC871E<R(L"@DG8V5R=&EF:6-A=&5S7VQI<W1?7V-E<G1I9FEC
M871E<U]A<W-I9VYE9%]O;E]I<"<@/3X@(F]N92!O<B!S979E<F%L(&-E<G1I
M9FEC871E<R!A<F4@87-S:6=N960@=&\@=&AE($E0(&%D9')E<W-E<RXB+`H)
M)V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V%?8V5R="<@/3X@(D$B
M+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8V5R="<@/3X@(D,B
M+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?8W-R)R`]/B`B4B(L
M"@DG8V5R=&EF:6-A=&5S7VQI<W1?7W1A8E]T:71L95]I<%]U<V%G92<@/3X@
M(E5S960B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T86)?=&ET;&5?;F%M92<@
M/3X@(D-E<G1I9FEC871E($YA;64B+`H))V-E<G1I9FEC871E<U]L:7-T7U]T
M86)?=&ET;&5?<'9T7VME>2<@/3X@(DLB+`H))V-F7V-O;F9?7W!A9V5?=&ET
M;&4G(#T^(")#;VQD1G5S:6]N(%-E='1I;F=S(BP*"2=C9E]C;VYF7U]P871H
M)R`]/B`B0V]L9$9U<VEO;B!I;G-T86QL871I;VX@<&%T:"(L"@DG8V9?8V]N
M9E]?=W)O;F=?<&%T:%]E;G1E<F5D)R`]/B`B26YC;W)R96-T(&EN<W1A;&QA
M=&EO;B!P871H+B(L"@DG8VA?<&%S<U]?861M:6Y?<&%S<R<@/3X@(D%D;6EN
M:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG8VA?<&%S<U]?;VQD7W!A<W,G(#T^
M(")/;&0@<&%S<W=O<F0B+`H))V-H7W!A<W-?7W!A<W-?8V]N9FER;2<@/3X@
M(D-O;F9I<FTB+`H))V-H7W!A<W-?7W5N86)L95]C:&%N9V5?861M:6Y?<&%S
M<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&%D;6EN:7-T<F%T;W(G<R!P
M87-S=V]R9#H@)3$B+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]E;6%I;%]S=6)J
M96-T)R`]/B`G4&QE<VL@<&%S<W=O<F0@<F5M:6YD97(G+`H*"@DG8VA?<&%S
M<U]B>5]S96-R971?7V5M86EL7V)O9'DG(#T^(")$96%R("4R+%QN("4S7&Y<
M;B!4;R!S970@=7`@82!N97<@<&%S<W=O<F0L('!L96%S92!F;VQL;W<@=&AE
M(&QI;FLZ("4Q(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S<V%G95]S96YD
M)R`]/B`G)3$G+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]M97-S86=E7W-E;F1?
M97)R;W(G(#T^("=5;F%B;&4@=&\@<V5N9"!T:&4@<V5C<F5T(&-O9&4Z("4Q
M)RP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?;65S<V%G95]S96-R971?<F5Q=65S
M=%]A9&UI;B<@/3X@)U1H92!I;G-T<G5C=&EO;G,@;VX@8VAA;F=I;F<@>6]U
M<B!P87-S=V]R9"!H879E(&)E96X@<V5N="!T;R!Y;W5R(&4M;6%I;"XG+`H)
M)V-H7W!A<W-?8GE?<V5C<F5T7U]E;6%I;%]S96-R971?<F5Q=65S=%]A9&UI
M;B<@/3X@(EEO=2!R97%U97-T960@=&AE(&-O;G1R;VP@<&%N96P@=&\@<V5N
M9"!Y;W4@>6]U<B!P87-S=V]R9"!B>2!E+6UA:6PN($9O<B!S96-U<FET>2!R
M96%S;VYS+"!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0@8V%N;F]T(&)E('-E
M;G0@8GD@92UM86EL+B!(;W=E=F5R+"!Y;W4@8V%N('-E="!U<"!A(&YE=R!P
M87-S=V]R9"!U<VEN9R!T:&4@<V5C<F5T(&-O9&4@>6]U('=I;&P@9FEN9"!I
M;B!T:&ES(&QE='1E<BXB+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]M97-S86=E
M7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W4@<F5Q=65S=&5D('1H
M92!C;VYT<F]L('!A;F5L('1O('-E;F0@>6]U('EO=7(@<&%S<W=O<F0@8GD@
M92UM86EL+B!!<R!Y;W4@<&%S<W=O<F0@=V%S('-T;W)E9"!I;B!T:&4@<WES
M=&5M(&EN('1H92!E;F-R>7!T960@9F]R;2P@:70@;6%D92!N;R!S96YS92!T
M;R!S96YD(&ET(&)Y(&4M;6%I;#H@>6]U('=O=6QD('-I;7!L>2!N;W0@8F4@
M86)L92!T;R!U<V4@:70N($AO=V5V97(L('EO=2!C86X@<V5T('5P(&$@;F5W
M('!A<W-W;W)D('5S:6YG('1H92!S96-R970@8V]D92!Y;W4@=VEL;"!F:6YD
M(&EN('1H:7,@;&5T=&5R+B(L"@DG8VA?<&%S<U]B>5]S96-R971?7V5M86EL
M7W-E8W)E=%]R97%U97-T7V-R>7!T960G(#T^(")9;W5R('!A<W-W;W)D(&-O
M=6QD(&YO="!B92!S96YT(&)E8V%U<V4@:70@:7,@<W1O<F5D(&EN('1H92!E
M;F-R>7!T960@9F]R;2XB+`H))V-H7W!A<W-?8GE?<V5C<F5T7U]M97-S86=E
M7W=R;VYG7VQO9VEN)R`]/B`B5&AE(&QO9VEN(&YA;64@>6]U('-P96-I9FEE
M9"!D;V5S(&YO="!M871C:"!T:&4@<V5C<F5T(&-O9&4N($$@;F5W('-E8W)E
M="!C;V1E('=A<R!G96YE<F%T960@86YD('-E;G0@=&\@>6]U<B!E+6UA:6PN
M(BP*"2=C:%]P87-S7V)Y7W-E8W)E=%]?96UA:6Q?=W)O;F=?;&]G:6XG(#T^
M("=9;W4@=')I960@=&\@<V5T('5P(&$@;F5W('!A<W-W;W)D('5S:6YG('1H
M92!S96-R970@8V]D92!B=70@96YT97)E9"!T:&4@=W)O;F<@;&]G:6X@;F%M
M92X@66]U('=I;&P@9FEN9"!A(&YE=R!S96-R970@8V]D92!I;B!T:&ES(&QE
M='1E<BXG+`H*"2=C:%]P87-S7V)Y7W-E8W)E=%]?:6YV86QI9%]S96-R970G
M(#T^("=);G9A;&ED('-E8W)E="!C;V1E(2<L"@DG8VA?<&%S<U]B>5]S96-R
M971?7W1I=&QE)R`]/B`G0VAA;F=E(%EO=7(@4&%S<W=O<F0G+`H))V-H7W!A
M<W-?8GE?<V5C<F5T7U]S96-R970G(#T^("=396-R970@8V]D92<L"@H))V-H
M96-K7VUA:6Q?8WEC;&5?7V%L:6%S97,G(#T^(")-86EL(&-Y8VQI;F<@:7,@
M9&5T96-T960L('1H92!A9&1R97-S(%PB)3%<(B!I<R!C;VYT86EN960@:6X@
M=&AE(&%L:6%S97,@;V8@=&AI<R!M86EL(&YA;64N(BP*"2=C:&5C:U]M86EL
M7V-Y8VQE7U]A=71O<F5S<&]N9&5R<R<@/3X@(DUA:6P@8WEC;&EN9R!I<R!D
M971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O;G1A:6YE9"!I;B!T
M:&4@875T;W)E<W!O;F1E<G,@;V8@=&AI<R!M86EL(&YA;64N(BP*"2=C:&5C
M:U]M86EL7V-Y8VQE7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@8WEC;&EN9R!I
M<R!D971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&ES(&-O;G1A:6YE9"!I
M;B!T:&4@;6%I;"!G<F]U<"!O9B!T:&ES(&UA:6P@;F%M92XB+`H))V-H96-K
M7VUA:6Q?8WEC;&5?7VUA:6Q?;F%M92<@/3X@(DUA:6P@8WEC;&EN9R!I<R!D
M971E8W1E9"P@=&AE(&%D9')E<W,@7"(E,5PB(&-O:6YC:61E<R!W:71H('1H
M:7,@;6%I;"!N86UE+B(L"@DG8VAE8VM?;6%I;%]C>6-L95]?<F5D:7)E8W0G
M(#T^(")-86EL(&-Y8VQI;F<@:7,@9&5T96-T960L('1H92!A9&1R97-S(%PB
M)3%<(B!C;VEN8VED97,@=VET:"!T:&4@<F5D:7)E8W0@;V8@=&AI<R!M86EL
M(&YA;64N(BP*"2=C:&M?:G-?7V5N=&5R7VQO9VEN7V%N9%]P87-S=V0G(#T^
M(")%;G1E<B!L;V=I;B!N86UE(&%N9"!P87-S=V]R9"XB+`H))V-H:U]J<U]?
M96YT97)?;&]G:6Y?;F%M92<@/3X@(D5N=&5R(&QO9VEN(&YA;64N(BP*"2=C
M:&M?:G-?7V5N=&5R7W!A<W-W9"<@/3X@(D5N=&5R('!A<W-W;W)D+B(L"@H)
M)V)T7V-H86YG95]O=VYE<B<@/3X@(D-H86YG92!/=VYE<B(L"@DG8VAO=VY?
M7W-E;&5C=%]T:71L92<@/3X@(E-E;&5C="!T:&4@;F5W(&]W;F5R(BP*"2=C
M:&]W;E]?8VAE8VM?=&ET;&4G(#T^(")#:&%N9V4@9&]M86EN(&]W;F5R(BP*
M"2=C:&]W;E]?;F5W7V]W;F5R)R`]/B`B3F5W(&]W;F5R(BP*"2=C:&]W;E]?
M<V5L96-T961?9&]M86EN<R<@/3X@(E-E;&5C=&5D(&1O;6%I;G,B+`H))V-H
M;W=N7U]L:6UI='-?;&5G96YD)R`]/B`B4F5S;W5R8V5S(BP*"2=C:&]W;E]?
M;&EM:71?;F%M92<@/3X@(E)E<V]U<F-E(&YA;64B+`H))V-H;W=N7U]L:6UI
M=%]V86QU92<@/3X@(D%L;&]C871E9"!R97-O=7)C97,B+`H))V-H;W=N7U]L
M:6UI=%]A<W-I9VYE9%]B969O<F4G(#T^(")"969O<F4@=')A;G-F97(B+`H)
M)V-H;W=N7U]L:6UI=%]A<W-I9VYE9%]A9G1E<B<@/3X@(D%F=&5R('1R86YS
M9F5R(BP*"2=C:&]W;E]?97)R;W)?9&]M86EN<U]E>&-L=61E)R`]/B`B4V]M
M92!P<F]B;&5M<R!W97)E(&5N8V]U;G1E<F5D(&1U<FEN9R!A='1E;7!T('1O
M('1R86YS9F5R('-O;64@;V8@=&AE(&1O;6%I;G,@=&\@82!N97<@;W=N97(N
M(%1H97-E(&1O;6%I;G,@;F%M97,@87)E(&AI9VAL:6=H=&5D+B(L"@DG8VAO
M=VY?7V5R<F]R7VQI;6ET<R<@/3X@(D1O;6%I;B!T<F%N<V9E<B!I<R!I;7!O
M<W-I8FQE+B!4:&ES(&1O;6%I;B!R97%U:7)E<R!M;W)E(')E<V]U<F-E<R!T
M:&%N(&1E<W1I;F%T:6]N('5S97(@86-C;W5N="!C86X@<')O=FED92XB+`H)
M)V-H;W=N7U]E<G)O<E]N;U]D;VUA:6YS)R`]/B`B56YA8FQE('1O(&-O;G1I
M;G5E(&1O;6%I;B!T<F%N<V9E<CH@;F\@9&]M86EN<R!S96QE8W1E9"XB+`H)
M)V-H;W=N7U]E<G)O<E]E;7!T>5]I<%]P;V]L)R`]/B`B56YA8FQE('1O(&-O
M;G1I;G5E(&1O;6%I;B!T<F%N<V9E<CH@25`@<&]O;"!O9B!T:&4@8VQI96YT
M(&ES(&5M<'1Y+B!0;&5A<V4@87-S:6=N(&%N($E0(&%D9')E<W,@=&\@=&AE
M(&-L:65N="!F:7)S="XB+`H))V-H;W=N7U]I<%]N;W1?:6Y?8VQI96YT7W!O
M;VPG(#T^(")4:&4@25`@861D<F5S<R!A<W-O8VEA=&5D('=I=&@@=&AI<R!D
M;VUA:6X@=V%S(&YO="!A<W-I9VYE9"!T;R!)4"!P;V]L(&]F('1H92!N97<@
M9&]M86EN(&]W;F5R+B(L"@DG8VAO=VY?7V%L<F5A9'E?;W=N961?8GE?8VQI
M96YT)R`]/B`B5&AI<R!D;VUA:6X@;F%M92!A;')E861Y(&)E;&]N9W,@=&\@
M=&AI<R!U<V5R+B(L"@DG8VAO=VY?7W!L96%S95]S96QE8W1?;F5W7V1O;6%I
M;E]O=VYE<B<@/3X@)U!L96%S92!S96QE8W0@=&AE(&YE=R!O=VYE<B!F;W(@
M=&AI<R!D;VUA:6XN)RP*"2=C:&]W;E]?;VQD7VEP7V%D9')E<W,G(#T^("=4
M:&4@8W5R<F5N="!)4"!A9&1R97-S)RP*"2=C:&]W;E]?;F5W7VEP7V%D9')E
M<W,G(#T^("=4:&4@;F5W($E0(&%D9')E<W,G+`H))V-H;W=N7U]I<%]A9&1R
M97-S7W=A<FXG(#T^("=4:&4@25`@861D<F5S<R!A<W-O8VEA=&5D('=I=&@@
M=&AI<R!D;VUA:6X@9&]E<R!N;W0@8F5L;VYG('1O('1H92!P;V]L(&]F('1H
M92!N97<@9&]M86EN(&]W;F5R.B!P;&5A<V4@8VAE8VL@=&AE('9A;'5E<R!S
M96QE8W1E9"!F;W(@25`@;6%P<&EN9R<L"@H)+R\@96YD(&]F('-H<F%M:V\@
M<&%R=`H*"@DO+R!S97)G92!P87)T"@H))V-H:U]J<U]?=V%R;FEN9U]A8F]U
M=%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E<F-A<V4@86QP
M:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O;',@:6X@=&AE
M(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B96=I;B!W:71H
M(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B!4:&4@<&%S<W=O<F0@<VAO=6QD(&YO
M="!C;VYT86EN('1H92!L;V=I;B!N86UE+B(L"@DG8VAK7VIS7U]W87)N:6YG
M7V%B;W5T7V9T<%]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!A;'!H
M86YU;65R:6,L(&1A<V@@86YD('5N9&5R<V-O<F4@<WEM8F]L<R!I;B!T:&4@
M;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A8F]U=%]L;V=I;E]S
M>6YT87A?=VEN)R`]/B`B66]U(&-A;B!U<V4@;&]W97)C87-E(&%L<&AA;G5M
M97)I8RP@9&%S:"!A;F0@=6YD97)S8V]R92!S>6UB;VQS(&EN('1H92!L;V=I
M;B!N86UE+B!4:&4@;&]G:6X@;F%M92!S:&]U;&0@8F5G:6X@=VET:"!A;B!A
M;'!H86)E=&EC('-Y;6)O;"XB+`H))V-H:U]J<U]?=V%R;FEN9U]A8F]U=%]P
M87-S=V1?<WEN=&%X)R`]/B`B1&\@;F]T('5S92!Q=6]T97,L('-P86-E(&%N
M9"!N871I;VYA;"!A;'!H86)E="!C:&%R86-T97)S(&EN(&$@<&%S<W=O<F0N
M7&Y4:&4@<&%S<W=O<F0@;&5N9W1H('-H;W5L9"!B92!F<F]M(#4@=&\@,30@
M8VAA<F%C=&5R<RX@5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@8V]N=&%I;B!T
M:&4@;&]G:6X@;F%M92XB+`H))V-H:U]J<U]?=V%R;FEN9U]A8F]U=%]P;&5S
M:U]L;V=I;E]S>6YT87@G(#T^(")9;W4@8V%N('5S92!L;W=E<F-A<V4@86QP
M:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y;6)O;',@:6X@=&AE
M(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L9"!B96=I;B!W:71H
M(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L"@DG8VAK7VIS7U]W87)N:6YG7V%B
M;W5T7W!L97-K7VQO9VEN7W-Y;G1A>%]W:6XG(#T^(")9;W4@8V%N('5S92!L
M;W=E<F-A<V4@86QP:&%N=6UE<FEC+"!D87-H(&%N9"!U;F1E<G-C;W)E('-Y
M;6)O;',@:6X@=&AE(&QO9VEN(&YA;64N(%1H92!L;V=I;B!N86UE('-H;W5L
M9"!B96=I;B!W:71H(&%N(&%L<&AA8F5T:6,@<WEM8F]L+B(L"@DG8VAK7VIS
M7U]W87)N:6YG7V%B;W5T7W!L97-K7W!A<W-W9%]S>6YT87@G(#T^(")$;R!N
M;W0@=7-E('%U;W1E<RP@<W!A8V4@86YD(&YA=&EO;F%L(&%L<&AA8F5T(&-H
M87)A8W1E<G,@:6X@82!P87-S=V]R9"Y<;E1H92!P87-S=V]R9"!S:&]U;&0@
M8F4@8F5T=V5E;B`U(&%N9"`Q-"!C:&%R86-T97)S(&%N9"!S:&]U;&0@;F]T
M(&-O;G1A:6X@=&AE(&QO9VEN(&YA;64N(BP*"2=C:&M?:G-?7W=A<FYI;F=?
M86)O=71?<&%M7W!A<W-W9%]E<G)O<B<@/3X@(E=R;VYG('-Y<W1E;2!U<V5R
M(&%C8V]U;G0@<W!E8VEF:6-A=&EO;CH@)3$B+`H))V-L7V5D7U]E9&ET7V-L
M)R`]/B`B)3$G<R!A8V-O=6YT(&1E=&%I;',B+`H))V-L7VQI;6ET<U]?8VPG
M(#T^(")#;&EE;G0@)3$G<R!L:6UI=',B+`H))V-L7VQO9V]?7W-E='5P7VQO
M9V]?<')E9B<@/3X@(E-E="!L;V=O('!R;W!E<G1I97,@9F]R(&-L:65N="`E
M,2(L"@DG8VQ?;F5W7U]E;G1E<E]N97=?8VQ?9&%T82<@/3X@(D5N=&5R('1H
M92!I;F9O<FUA=&EO;B!O;B!N97<@8VQI96YT(BP*"2=C;%]P97)M7U]A;&Q?
M:7`G(#T^(")!;&P@879A:6QA8FQE($E0<R(L"@DG8VQ?<&5R;5]?86QL7VEP
M7V)A<V5D7VAS=%]W:6QL7V)E7VYB)R`]/B`B06QL(&EP+6)A<V5D(&AO<W1I
M;F<@86-C;W5N=',@9F]R(&-L:65N="!W:6QL(&)E('1R86YS9F5R<F5D('1O
M($YA;64M8F%S960N(BP*"2=C;%]P97)M7U]A;&QO=U]C;&EE;G1?8W)E871E
M7V1O;6%I;B<@/3X@(E1H92!F:65L9',@>6]U(&%R92!T<GEI;F<@=&\@<V5L
M96-T(&%R92!O;FQY(&%P<&QI8V%B;&4@=&\@0VQI96YT<R!W:&\@87)E(&%L
M;&]W960@=&\@8W)E871E(&1O;6%I;G,N(BP*"2=C;%]P97)M7U]A;&QO=U]C
M<F5A=&5?;F)?=U]I<"<@/3X@(D-L:65N="!C86X@8W)E871E($YA;64M8F%S
M960@:&]S=&EN9R!U<VEN9R`E,2(L"@DG8VQ?<&5R;5]?86QL;W=?8W)E871I
M;VY?:7!?8F%S961?:&]S=&EN9R<@/3X@(D%L;&]W($E0+6)A<V5D(&AO<W1I
M;F<@86-C;W5N=',@8W)E871I;VXB+`H))V-L7W!E<FU?7V%V86EL86)L95]I
M<',G(#T^(")!=F%I;&%B;&4@25!S(BP*"2=C;%]P97)M7U]C:&%N9V5?;&EM
M:71S)R`]/B`B1&]M86EN(&QI;6ET<R!A9&IU<W1M96YT(BP*"2=C;%]P97)M
M7U]C;%]D:7-K7W-P86-E)R`]/B`B5&]T86P@9&ES:R!S<&%C92!A=F%I;&%B
M;&4B+`H))V-L7W!E<FU?7V-L7V5X<&ER871I;VXG(#T^(")#;&EE;G0@86-C
M;W5N="!V86QI9&ET>2!P97)I;V0B+`H))V-L7W!E<FU?7V-L7VUA>%]B;W@G
M(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL8F]X97,B+`H))V-L7W!E<FU?
M7V-L7VUA>%]D8B<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&1A=&%B87-E<R(L
M"@DG8VQ?<&5R;5]?8VQ?;6%X7V1O;2<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F
M(&1O;6%I;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]M86EL;&ES=',G(#T^(")-
M87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=C;%]P97)M7U]C
M;%]M87A?;6<G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL(&=R;W5P<R(L
M"@DG8VQ?<&5R;5]?8VQ?;6%X7W)E9&ER)R`]/B`B36%X:6UU;2!N=6UB97(@
M;V8@<F5D:7)E8W1S(BP*"2=C;%]P97)M7U]C;%]M87A?<F5S<"<@/3X@(DUA
M>&EM=6T@;G5M8F5R(&]F(&%U=&]R97-P;VYD97)S(BP*"2=C;%]P97)M7U]C
M;%]M87A?<W5B9&]M)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@<W5B9&]M86EN
M<R(L"@DG8VQ?<&5R;5]?8VQ?;6%X7W1R869F:6,G(#T^(")4;W1A;"!A;6]U
M;G0@;V8@=')A9F9I8R!A=F%I;&%B;&4B+`H))V-L7W!E<FU?7V-L7VUA>%]W
M96)A<'!S)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@2F%V82!A<'!L:6-A=&EO
M;G,B+`H))V-L7W!E<FU?7V-L7VUA>%]W=2<@/3X@(DUA>&EM=6T@;G5M8F5R
M(&]F('=E8B!U<V5R<R(L"@DG8VQ?<&5R;5]?8VQ?;6)O>%]Q=6]T82<@/3X@
M(E1H92!M86EL8F]X('-I>F4@;&EM:70@<V5T(&9O<B!T:&ES('5S97(@86-C
M;W5N="(L"@DG8VQ?<&5R;5]?8W)E871E7V1O;6%I;G,G(#T^(")$;VUA:6X@
M8W)E871I;VXB+`H))V-L7W!E<FU?7V-U<G)E;G1?;6%X:6UU;5]E>'!?9&%T
M92<@/3X@(E1H92!C=7)R96YT(&UA>&EM=6T@=F%L=64@;V8@9&]M86EN('9A
M;&ED:71Y('!E<FEO9"!I<R`E,3L@<F5Q=65S=&5D("4R7&XB+`H))V-L7W!E
M<FU?7V-U<G)E;G1?;6%X:6UU;5]M86EL8F]X7W%U;W1A)R`]/B`B5&AE(&-U
M<G)E;G1L>2!D969I;F5D(&QI;6ET(&]N(&%M;W5N="!O9B!D:7-K('-P86-E
M(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X97,@=6YD97(@=&AI<R!U
M<V5R(&%C8V]U;G0@:7,@)3$[(')E<75E<W1E9"`E,EQN(BP*"2=C;%]P97)M
M7U]C=7)R96YT7W1O=&%L7W)E<75E<W1E9"<@/3X@(E1H92!C=7)R96YT('1O
M=&%L('9A;'5E(&]F(&1O;6%I;B!L:6UI=',@9F]R("4Q(&ES("4R.R!R97%U
M97-T960@)3-<;B(L"@DG8VQ?<&5R;5]?8W5R<F5N=%]T;W1A;%]R97%U97-T
M961?9&]M)R`]/B`B0W5R<F5N="!N=6UB97(@;V8@)3$@8F5L;VYG:6YG('1O
M('1H:7,@8VQI96YT(&ES("4R.R!R97%U97-T960@)3-<;B(L"@DG8VQ?<&5R
M;5]?9&ES:U]S<&%C92<@/3X@(FUA>&EM=6T@86UO=6YT(&]F(&1I<VL@<W!A
M8V4B+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]S=&1G=6DG(#T^("=5<V5R(&EN
M=&5R9F%C92<L"@DG8VQ?<&5R;5]?;6%N86=E7V1A<VAB;V%R9"<@/3X@)T1E
M<VMT;W`@;6%N86=E;65N="<L"@DG8VQ?<&5R;5]?9&%S:&)O87)D7V%N9%]S
M=&1G=6DG(#T^("=$97-K=&]P(&%N9"!S=&%N9&%R9"!I;G1E<F9A8V4@87)E
M(&%L;&]W960G+`H))V-L7W!E<FU?7V1A<VAB;V%R9%]O;FQY)R`]/B`G3VYL
M>2!$97-K=&]P(&EN=&5R9F%C92!I<R!A;&QO=V5D)RP*"2=C;%]P97)M7U]S
M=&1G=6E?;VYL>2<@/3X@)T]N;'D@<W1A;F1A<F0@:6YT97)F86-E(&ES(&%L
M;&]W960G+`H))V-L7W!E<FU?7V5D:71?8VPG(#T^(")#;&EE;G0@)3$G<R!P
M97)M:7-S:6]N<R(L"@DG8VQ?<&5R;5]?97AP7V1A=&5?97AC965D960G(#T^
M(")4:&4@=F%L:61I='D@<&5R:6]D('EO=2!A<F4@=')Y:6YG('1O('-E="!E
M>&-E961S('1H92!L:6UI="!S<&5C:69I960@=VET:&EN(&EN9&EV:61U86P@
M9&]M86EN<R!R96QA=&5D('1O('1H:7,@8VQI96YT+EQN(BP*"2=C;%]P97)M
M7U]I;G9A;&ED7W9A;'5E)R`]/B`B26YV86QI9"!V86QU92P@;VYL>2!D:6=I
M=',@87)E(&%L;&]W960N(BP*"2=C;%]P97)M7U]L:6UI=%]D:7-K7W-P86-E
M)R`]/B`B)3$@3&EM:70@=&AE('1O=&%L(&%M;W5N="!O9B!D:7-K('-P86-E
M(BP*"2=C;%]P97)M7U]L:6UI=%]E>'!I<F%T:6]N)R`]/B`B)3$@3&EM:70@
M=&AE('9A;&ED:71Y('!E<FEO9"!F;W(@=&AE(&-L:65N="!A8V-O=6YT(BP*
M"2=C;%]P97)M7U]L:6UI=%]M87A?8F]X)R`]/B`B)3$@3&EM:70@=&AE(&UA
M>&EM=6T@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG8VQ?<&5R;5]?;&EM:71?
M;6%X7V1B)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&1A
M=&%B87-E<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7V1O;2<@/3X@(B4Q($QI
M;6ET('1H92!M87AI;75M(&YU;6)E<B!O9B!D;VUA:6YS(BP*"2=C;%]P97)M
M7U]L:6UI=%]M87A?;6%I;&QI<W1S)R`]/B`B)3$@3&EM:70@=&AE(&UA>&EM
M=6T@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V-L7W!E<FU?7VQI;6ET
M7VUA>%]M9R<@/3X@(B4Q($QI;6ET('1H92!M87AI;75M(&YU;6)E<B!O9B!M
M86EL(&=R;W5P<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W)E9&ER)R`]/B`B
M)3$@3&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(')E9&ER96-T<R(L"@DG
M8VQ?<&5R;5]?;&EM:71?;6%X7W)E<W`G(#T^("(E,2!,:6UI="!T:&4@;6%X
M:6UU;2!N=6UB97(@;V8@875T;W)E<W!O;F1E<G,B+`H))V-L7W!E<FU?7VQI
M;6ET7VUA>%]S=6)D;VTG(#T^("(E,2!,:6UI="!T:&4@;6%X:6UU;2!N=6UB
M97(@;V8@<W5B9&]M86EN<R(L"@DG8VQ?<&5R;5]?;&EM:71?;6%X7W1R869F
M:6,G(#T^("(E,2!,:6UI="!T:&4@=&]T86P@86UO=6YT(&]F('1R869F:6,B
M+`H))V-L7W!E<FU?7VQI;6ET7VUA>%]W96)A<'!S)R`]/B`B)3$@3&EM:70@
M=&AE(&UA>&EM=6T@;G5M8F5R(&]F($IA=F$@87!P;&EC871I;VYS(BP*"2=C
M;%]P97)M7U]L:6UI=%]M87A?=W4G(#T^("(E,2!,:6UI="!T:&4@;6%X:6UU
M;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C;%]P97)M7U]L:6UI=%]M8F]X
M7W%U;W1A)R`]/B`B)3$@4V5T('1H92!M86EL8F]X('%U;W1A(BP*"2=C;%]P
M97)M7U]L:6UI='-?97AC965D960G(#T^(")/;F4@;W(@<V5V97)A;"!L:6UI
M=',@>6]U(&%R92!T<GEI;F<@=&\@<V5T(&%R92!A;')E861Y(&5X8V5E9&5D
M(&)Y('1H92!L:6UI=',@9&5F:6YE9"!W:71H:6X@:6YD:79I9'5A;"!D;VUA
M:6YS(&)E;&]N9VEN9R!T;R!T:&ES(&-L:65N="Y<;E1H92!T;W1A;"!L:6UI
M="!F;W(@=&AE(&-L:65N="!M=7-T(&)E(&UO<F4@;W(@97%U86P@=&\@=&AE
M('1O=&%L('-U;2!O9B!T:&4@9&]M86EN(&QI;6ET<R!D969I;F5D(&9O<B!T
M:&ES(&-L:65N="!A8V-O=6YT+EQN(BP*"2=C;%]P97)M7U]M86EL8F]X7W%U
M;W1A7V5X8V5E9&5D)R`]/B`B5&AE(&QI;6ET(&]N(&%M;W5N="!O9B!D:7-K
M('-P86-E(&%L;&]C871E9"!F;W(@:&]U<VEN9R!M86EL8F]X97,@>6]U(&%R
M92!T<GEI;F<@=&\@<V5T(&5X8V5E9',@=&AE(&QI;6ET(&1E9FEN960@=VET
M:&EN(&EN9&EV:61U86P@9&]M86EN<R!R96QA=&5D('1O('1H:7,@8VQI96YT
M(&%C8V]U;G0N7&XB+`H))V-L7W!E<FU?7VUA:6QB;WA?<75O=&%?97AC965D
M<U]S97)V97)?;&EM:70G(#T^(")4:&4@;&EM:70@;VX@86UO=6YT(&]F(&1I
M<VL@<W!A8V4@86QL;V-A=&5D(&9O<B!H;W5S:6YG(&UA:6QB;WAE<R!Y;W4@
M87)E('1R>6EN9R!T;R!S970@97AC965D<R!T:&4@;&EM:71A=&EO;B!I;7!O
M<V5D(&%T('1H92!S97)V97(@;&5V96PN(BP*"2=C;%]P97)M7U]M86ME7V1U
M;7!S)R`]/B`B0F%C:W5P+W)E<W1O<F4@9G5N8W1I;VYS(BP*"2=C;%]P97)M
M7U]M86YA9V5?86YO;F9T<"<@/3X@(D%N;VYY;6]U<R!&5%`@;6%N86=E;65N
M="(L"@DG8VQ?<&5R;5]R96UO=&5?86-C97-S7VEN=&5R9F%C92<@/3X@(D%B
M:6QI='D@=&\@=7-E(')E;6]T92!834P@:6YT97)F86-E(BP*"2=C;%]P97)M
M7U]M86YA9V5?8W)O;G1A8E]W:6XG(#T^(")38VAE9'5L97(@;6%N86=E;65N
M="(L"@DG8VQ?<&5R;5]?;6%N86=E7V-R;VYT86)?=6YI>"<@/3X@(D-R;VYT
M86(@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7V1N<R<@/3X@(D1.
M4R!Z;VYE(&UA;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G95]F='!?<&%S
M<W=O<F0G(#T^(")-86YA9V4@1E10('!A<W-W;W)D(BP*"2=C;%]P97)M7U]M
M86YA9V5?;&]G)R`]/B`B3&]G(')O=&%T:6]N(&UA;F%G96UE;G0B+`H))V-L
M7W!E<FU?7VUA;F%G95]M86EL;&ES=',G(#T^(")-86EL:6YG(&QI<W1S(&UA
M;F%G96UE;G0B+`H))V-L7W!E<FU?7VUA;F%G95]N;W1?8VAR;V]T7W-H96QL
M)R`]/B`G3F]N+6-H<F]O=&5D('-H96QL(&UA;F%G96UE;G0G+`H))V-L7W!E
M<FU?7VUA;F%G95]D<G=E8B<@/3X@)T1R+E=E8B!A;G1I=FER=7,@;6%N86=E
M;65N="<L"@DG8VQ?<&5R;5]?;6%N86=E7W!H;W-T:6YG)R`]/B`B4&AY<VEC
M86P@:&]S=&EN9R!M86YA9V5M96YT(BP*"2=C;%]P97)M7U]M86YA9V5?<75O
M=&$G(#T^(")(87)D(&1I<VL@<75O=&$@87-S:6=N;65N="(L"@DG8VQ?<&5R
M;5]?;6%N86=E7W-H7V%C8V5S<R<@/3X@(DUA;F%G96UE;G0@;V8@<VAE;&P@
M86-C97-S('1O('-E<G9E<B(L"@DG8VQ?<&5R;5]?;6%N86=E7W-H7V%C8V5S
M<U]D:7-A8FQE9"<@/3X@)T-L:65N="!C86YN;W0@86QL;W<@;W(@9&ES86QL
M;W<@<VAE;&P@86-C97-S)RP*"2=C;%]P97)M7U]M86YA9V5?<VA?86-C97-S
M7V-H<F]O=&5D)R`]/B`G0VQI96YT(&-A;B!A;&QO=R!A8V-E<W,@;VYL>2!T
M;R!A(&-H<F]O=&5D(&5N=FER;VYM96YT)RP*"2=C;%]P97)M7U]M86YA9V5?
M<VA?86-C97-S7V%N>2<@/3X@)T-L:65N="!C86X@86QL;W<@86-C97-S('1O
M(&%N>2!T>7!E(&]F('-H96QL)RP*"2=C;%]P97)M7U]M86YA9V5?<W5B9&]M
M86EN<R<@/3X@(E-U8F1O;6%I;G,@;6%N86=E;65N="(L"@DG8VQ?<&5R;5]?
M;6%N86=E7V1O;6%I;E]A;&EA<V5S)R`]/B`B1&]M86EN(&%L:6%S97,@;6%N
M86=E;65N="(L"@DG8VQ?<&5R;5]?;6%N86=E7W=E8F%P<',G(#T^(")*879A
M(&%P<&QI8V%T:6]N<R!M86YA9V5M96YT(BP*"2=C;%]P97)M7U]M87A?8F]X
M)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;&)O>&5S(BP*"2=C;%]P97)M
M7U]M87A?9&(G(#T^(")M87AI;75M(&YU;6)E<B!O9B!D871A8F%S97,B+`H)
M)V-L7W!E<FU?7VUA>%]D;VTG(#T^(")D;VUA:6YS(BP*"2=C;%]P97)M7U]M
M87A?;6%I;&QI<W1S)R`]/B`B;6%X:6UU;2!N=6UB97(@;V8@;6%I;&EN9R!L
M:7-T<R(L"@DG8VQ?<&5R;5]?;6%X7VUG)R`]/B`B;6%X:6UU;2!N=6UB97(@
M;V8@;6%I;"!G<F]U<',B+`H))V-L7W!E<FU?7VUA>%]R961I<B<@/3X@(FUA
M>&EM=6T@;G5M8F5R(&]F(')E9&ER96-T<R(L"@DG8VQ?<&5R;5]?;6%X7W)E
M<W`G(#T^(")M87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N9&5R<R(L"@DG
M8VQ?<&5R;5]?;6%X7W-U8F1O;2<@/3X@(G-U8F1O;6%I;G,B+`H))V-L7W!E
M<FU?7VUA>%]T<F%F9FEC)R`]/B`B;6%X:6UU;2!A;6]U;G0@;V8@=')A9F9I
M8R(L"@DG8VQ?<&5R;5]?;6%X7W=E8F%P<',G(#T^(")M87AI;75M(&YU;6)E
M<B!O9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQ?<&5R;5]?;6%X7W=U)R`]
M/B`B;6%X:6UU;2!N=6UB97(@;V8@=V5B('5S97)S(BP*"2=C;%]P97)M7U]M
M8F]X7W%U;W1A)R`]/B`B;6%I;&)O>"!Q=6]T82(L"@DG8VQ?<&5R;5]?;F]T
M7V%L;&]W7V-R96%T95]N8E]H<W0G(#T^(")#;&EE;G0@8V%N;F]T(&-R96%T
M92!.86UE+6)A<V5D(&AO<W1I;F<N(BP*"2=C;%]P97)M7U]C<%]A8V-E<W,G
M(#T^("=!8V-E<W,@=&\@8V]N=')O;"!P86YE;"<L"@DG8VQ?<&5R;5]?<V5L
M96-T7VEP7V%D9')S)R`]/B`B4V5L96-T(&EP(&%D9')E<W-E<R(L"@DG8VQ?
M<&5R;5]?<VET95]B=6EL9&5R)PD]/B`G57-E(&]F($UA;6)O(&-O;G1E;G0@
M;6%N86=E;65N="!S>7-T96TG+`H))V-L7W!E<FU?7W1H:7-?:7!?=7-E9%]V
M<G1?:'-T)R`]/B`B5&AI<R!I<"!A9&1R97-S(&ES('5S960@8GD@=FER='5A
M;"!H;W-T:6YG+EQN5&\@9&5L971E('1H:7,@:7`@861D<F5S<RP@<F5M;W9E
M(&AO<W1I;F<@<V5R=FEC92!O<B!C:&%N9V4@:71S('1Y<&4@=&\@3F%M92UB
M87-E9"XB+`H))V-L7W!E<FU?7W5N86)L95]O9F9?:7!B7V-R96%T:6YG)R`]
M/B`B0VQI96YT(&%L<F5A9'D@:&%S($E0+6)A<V5D(&AO<W1I;F<@<V5R=FEC
M92!S970M=7`N(%1O(&1E86-T:79A=&4@=&AI<R!F96%T=7)E(&9O<B!T:&4@
M0VQI96YT+"!D97-E;&5C="!T:&4@7")$;VUA:6X@8W)E871I;VY<(B!C:&5C
M:V)O>"!O<B!R96UO=F4@86QL($E0+6)A<V5D(&AO<W1I;F<@86-C;W5N=',N
M(BP*"2=C;%]P97)M7U]U;F%B;&5?;V9F7VYB7V-R96%T:6YG)R`]/B`B0VQI
M96YT(&%L<F5A9'D@:&%S($YA;64M8F%S960@:&]S=&EN9R!S97)V:6-E('-E
M="UU<"X@5&\@9&5A8W1I=F%T92!T:&ES(&9E871U<F4@9F]R('1H92!#;&EE
M;G0L(&1E<V5L96-T('1H92!<(D1O;6%I;B!C<F5A=&EO;EPB(&-H96-K8F]X
M(&]R(')E;6]V92!A;&P@3F%M92UB87-E9"!H;W-T:6YG(&%C8V]U;G1S+B(L
M"@DG8VQ?<&5R;5]?=6YA8FQE7W-E=%]D;VUA:6Y?;&EM:70G(#T^(")5;F%B
M;&4@=&\@;&EM:70@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&1O;6%I;G,Z(&-L
M:65N="!A;')E861Y(&AA<R`E,2!D;VUA:6YS(BP*"2=C;%]P97)M7U]U;F%B
M;&5?=7!D871E7V-L:65N=%]L:6UI=&%T:6]N<R<@/3X@(E5N86)L92!T;R!M
M;V1I9GD@=&AE(&QI;6ET<R!O9B!C;&EE;G0@86-C;W5N=#H@)3$B+`H))V-L
M7W!R969?7V5D:71?8VPG(#T^(")#;&EE;G0@)3$G<R!P<F5F97)E;F-E<R(L
M"@DG8VQ?=')A9F9I8U]H:7-T;W)Y7U]T:71L92<@/3X@(D-L:65N="`\8CXE
M,3PO8CXG<R!T<F%F9FEC(&AI<W1O<GDB+`H))V-L87-S7V%N;VYF='!?7V-R
M96%T95]F='!?9&]M86EN)R`]/B`B3F\@=FER='5A;"!&5%`@9&]M86EN(&9O
M<B!T:&ES(&1O;5]I9"P@=')Y(&-R96%T:6YG(&ET(&9I<G-T+B(L"@DG8VQA
M<W-?86YO;F9T<%]?:6YC;VUI;F=?9&ES:U]S<&%C95]S:&]U;&1?8F5?;&]W
M97(G(#T^(")4:&4@9&ES:R!S<&%C92!L:6UI="!Y;W4@87)E('1R>6EN9R!T
M;R!S970@*"4Q*2!S:&]U;&0@;F]T(&5X8V5E9"!T:&4@=&]T86P@9&ES:R!S
M<&%C92!L:6UI="!D969I;F5D(&%T('1H92!D;VUA:6X@;&5V96P@*"4R*2(L
M"@DG8VQA<W-?86YO;F9T<%]?:6YV86QI9%]I;G!U=%]O;FQY7V1I9VET<R<@
M/3X@(DEN=F%L:60@=F%L=64@<W!E8VEF:65D+"!O;FQY(&1I9VET<R!A<F4@
M86QL;W=E9"(L"@DG8VQA<W-?86YO;F9T<%]?=6YA8FQE7V-H86YG95]O=VYE
M<G-H:7!S)R`]/B`B56YA8FQE('1O(&-H86YG92!O=VYE<G-H:7`@;W(@<&5R
M;6ES<VEO;G,@9F]R('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG8VQA<W-?86YO
M;F9T<%]?=6YA8FQE7V-O<'E?<75O=&%?9FEL92<@/3X@(E5N86)L92!T;R!C
M;W!Y('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG8VQA<W-?86YO;F9T<%]?=6YA
M8FQE7V=E=%]D:7-K7W5S86=E)R`]/B`B56YA8FQE('1O(')E=')I979E(&1I
M<VL@=7-A9V4@:6YF;W)M871I;VX@;VX@=&AE(&EN8V]M:6YG(&1I<F5C=&]R
M>3H@)3$B+`H))V-L87-S7V%N;VYF='!?7W5N86)L95]P87)S95]Q=6]T85]F
M:6QE)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!Q=6]T82!F:6QE+B(L"@DG
M8VQA<W-?86YO;F9T<%]?=6YA8FQE7W)E861?<75O=&%?9FEL92<@/3X@(E5N
M86)L92!T;R!R96%D('1H92!Q=6]T82!F:6QE.B`E,2(L"@DG8VQA<W-?86YO
M;F9T<%]?=6YA8FQE7W5P9&%T95]Q=6]T82<@/3X@(E5N86)L92!T;R!U<&1A
M=&4@<75O=&$Z('1H92!F:6QE<R!I;B!T:&4@:6YC;VUI;F<@9&ER96-T;W)Y
M('5S92`E,2!+0G,@;V8@9&ES:R!S<&%C92P@=VAI8V@@97AC965D<R!T:&4@
M;F5W('%U;W1A('9A;'5E(BP*"2=C;&%S<U]A;F]N9G1P7U]U;F%B;&5?=W)I
M=&5?=&5M<%]F:6QE)R`]/B`B56YA8FQE('1O('=R:71E('1O('1H92!T96UP
M;W)A<GD@9FEL93H@)3$B+`H))V-L87-S7V)S9&]M86EN7U]W87)N7VUA>%]D
M871E7U\G(#T^(")4:&4@=F%L:61I='D@<&5R:6]D('=A<R!S970@=&\@)3$B
M+`H))V-L87-S7V-L:65N=%]?8VQI96YT7V-R96%T:6]N7VYO=&EF:6-A=&EO
M;B<@/3X@(D-L:65N="!C<F5A=&EO;B!N;W1I8V4N(BP*"2=C;&%S<U]C;&EE
M;G1?7V-L:65N=%]W:71H7V-O;G1A8W1?;F%M95]A;')E861Y7V5X:7-T<R<@
M/3X@(D-L:65N="!W:71H(&YA;64@)3$@86QR96%D>2!E>&ES=',N(BP*"2=C
M;&%S<U]C;&EE;G1?7V-L:65N=%]W:71H7VQO9VEN7VYA;65?861M:6Y?86QR
M96%D>5]E>&ES=',G(#T^(")4:&4@=7-E<B!W:71H(&QO9VEN(&YA;64@861M
M:6X@86QR96%D>2!E>&ES=',N(BP*"2=C;&%S<U]C;&EE;G1?7V1I<VM?<W!A
M8V4G(#T^(")$:7-K('-P86-E(BP*"2=C;&%S<U]C;&EE;G1?7VEN=F%L:61?
M;6%X7V1O;2<@/3X@(DEN=F%L:60@;G5M8F5R(&]F(&1O;6%I;G,@=F%L=64L
M(&]N;'D@9&EG:71S(&%R92!A;&QO=V5D+B(L"@DG8VQA<W-?8VQI96YT7U]L
M:6UI=%]E>&-E960G(#T^("(E,3H@<F5Q=65S=&5D("T@)3(L(&UA>&EM=6T@
M879A:6QA8FQE("T@)3,B+`H))V-L87-S7V-L:65N=%]?;&EM:71?97AC965D
M7W5N;&EM:71E9"<@/3X@(B4Q.B!R97%U97-T960@+2!U;FQI;6ET960L(&UA
M>&EM=6T@879A:6QA8FQE("T@)3(B+`H))V-L87-S7V-L:65N=%]?;6%X7V)O
M>"<@/3X@(DUA:6QB;WAE<R(L"@DG8VQA<W-?8VQI96YT7U]M87A?9&(G(#T^
M(")$871A8F%S97,B+`H))V-L87-S7V-L:65N=%]?;6%X7VUA:6QL:7-T<R<@
M/3X@(DUA:6QI;F<@;&ES=',B+`H))V-L87-S7V-L:65N=%]?;6%X7VUG)R`]
M/B`B36%I;"!G<F]U<',B+`H))V-L87-S7V-L:65N=%]?;6%X7W)E9&ER)R`]
M/B`B4F5D:7)E8W1S(BP*"2=C;&%S<U]C;&EE;G1?7VUA>%]R97-P)R`]/B`B
M075T;W)E<W!O;F1E<G,B+`H))V-L87-S7V-L:65N=%]?;6%X7W-U8F1O;2<@
M/3X@(E-U8F1O;6%I;G,B+`H))V-L87-S7V-L:65N=%]?;6%X7W1R869F:6,G
M(#T^(")-87AI;75M('1R869F:6,B+`H))V-L87-S7V-L:65N=%]?;6%X7W=E
M8F%P<',G(#T^(")*879A(&%P<&QI8V%T:6]N<R(L"@DG8VQA<W-?8VQI96YT
M7U]M87A?=W4G(#T^(")796(@=7-E<G,B+`H))V-L87-S7V-L:65N=%]?;6)O
M>%]Q=6]T82<@/3X@(DUA:6QB;W@@<75O=&$B+`H))V-L87-S7V-L:65N=%]?
M=6YA8FQE7V1E9FEN95]C;%]S=&%T=7,G(#T^(")5;F%B;&4@=&\@9&5F:6YE
M('-T871U<R!O9B!C;&EE;G0@86-C;W5N=#H@)3$B+`H))V-L87-S7V-L:65N
M=%]?=6YA8FQE7V1E9FEN95]I;F%C=&EV95]D;VTG(#T^(")5;F%B;&4@=&\@
M9&5F:6YE(&EN86-T:79E(&1O;6%I;G,@)3$B+`H))V-L87-S7V-L:65N=%]?
M=6YA8FQE7V1E;%]I<"<@/3X@(E5N86)L92!T;R!R96UO=F4@25!S.B`E,2(L
M"@DG8VQA<W-?9&)?7V1B7VYA;65?;F]T7W-E="<@/3X@(D1A=&%B87-E(&YA
M;64@:7,@;F]T(&1E9FEN960N(BP*"2=C;&%S<U]D8E]?9&)?;F]T7V5X:7-T
M7V9O<E]C=7)R7V1O;2<@/3X@(E1H92!D871A8F%S92!D;V5S(&YO="!E>&ES
M="!F;W(@=&AI<R!D;VUA:6XN(BP*"2=C;&%S<U]D8E]?:6YV86QI9%]D8E]O
M<E]D;VU?;F%M92<@/3X@(E1H92!D;VUA:6X@;W(@9&%T86)A<V4@:60@:7,@
M:6YV86QI9"!O<B!D871A8F%S92!N86UE(&ES(&YO="!D969I;F5D+B(L"@DG
M8VQA<W-?9&)?7VEN=F%L:61?<&%S<R<@/3X@(E1H92!P87-S=V]R9"!I<R!I
M;G9A;&ED+B(L"@DG8VQA<W-?9&)?7VUA:6QG<G!?;65M8F5R7V5X:7-T)R`]
M/B`B5&AE(&UA:6P@9W)O=7`@;65M8F5R(&%L<F5A9'D@97AI<W1S+B(L"@DG
M8VQA<W-?9&)?7V%C8V5S<U]H;W-T<U]N;W1S=7!P;W)T)R`]/B`G06-C97-S
M(&AO<W1S('-E='1I;F<@:7,@;F]T('-U<'!O<G1E9"!F;W(@=&AI<R!D871A
M8F%S92!T>7!E)RP*"2=C;&%S<U]D8E]?=6YA8FQE7V%D9"<@/3X@)U5N86)L
M92!T;R!A9&0@86-C97-S(&AO<W0@<F5C;W)D.B`E,2<L"@DG8VQA<W-?9&)?
M7W5N86)L95]D96PG(#T^("=5;F%B;&4@=&\@9&5L971E(&%C8V5S<R!H;W-T
M(')E8V]R9#H@)3$G+`H))V-L87-S7V1B7U]I;F-?=7-E<E]N;W1?97AI<W0G
M(#T^("=$871A8F%S92!U<V5R("(E,2(@9&]E<R!N;W0@97AI<W0G+`H))V-L
M87-S7V1B7U]I;F-?86-C97-S7W)E8V]R9%]E>&ES="<@/3X@)U1H:7,@86-C
M97-S(')E8V]R9"!A;')E861Y(&5X:7-T<R<L"@DG8VQA<W-?9&)?7VEN8U]A
M8V-E<W-?<F5C;W)D7VYO=%]E>&ES="<@/3X@)T=I=F5N(&%C8V5S<R!R96-O
M<F0@9&]E<R!N;W0@97AI<W0G+`H))V-L87-S7V1B7U]I;F-?=6YA8FQE7V1E
M;%]L87-T7W)E8V]R9"<@/3X@)U5N86)L92!T;R!D96QE=&4@=&AE(&QA<W0@
M86-C97-S(&AO<W0@<F5C;W)D)RP*"2=C;&%S<U]D;VUT;7!L961I=&9O<FU?
M7V1N<U]M87-T97(G(#T^(")-87-T97(B+`H))V-L87-S7V1O;71M<&QE9&ET
M9F]R;5]?9&YS7W-L879E)R`]/B`B4VQA=F4B+`H))V-L87-S7V1O;71M<&QE
M9&ET9F]R;5]?9&YS7W1Y<&4G(#T^(")4>7!E(&]F(&1O;6%I;B!$3E,@>F]N
M92(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?861M:6XG(#T^(")A9&UI
M;B(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT)R`]/B`B8VQI
M96YT(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE;G1?8W)E871I
M;VY?=&5X="<@/3X@(D-L:65N="!!8V-O=6YT($-R96%T:6]N(BP*"2=C;&%S
M<U]N;W1I9FEC871I;VYF;W)M7U]C;&EE;G1?97AP7W=A<FYI;F=?=&5X="<@
M/3X@(D-L:65N="!!8V-O=6YT($5X<&ER871I;VX@5V%R;FEN9R(L"@DG8VQA
M<W-?;F]T:69I8V%T:6]N9F]R;5]?8VQI96YT7V5X<&ER871I;VY?=&5X="<@
M/3X@(D-L:65N="!!8V-O=6YT($5X<&ER960B+`H))V-L87-S7VYO=&EF:6-A
M=&EO;F9O<FU?7V1A>7,G(#T^("(@9&%Y<R!I;B!A9'9A;F-E(BP*"2=C;&%S
M<U]N;W1I9FEC871I;VYF;W)M7U]D;VUA:6Y?8W)E871I;VY?=&5X="<@/3X@
M(D1O;6%I;B!#<F5A=&EO;B(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?
M9&]M86EN7V5X<%]W87)N:6YG7W1E>'0G(#T^(")$;VUA:6X@17AP:7)A=&EO
M;B!787)N:6YG(BP*"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]D;VUA:6Y?
M97AP:7)A=&EO;E]T97AT)R`]/B`B1&]M86EN($5X<&ER960B+`H))V-L87-S
M7VYO=&EF:6-A=&EO;F9O<FU?7V1O;6%I;E]L:6UI='-?97AC965D7W1E>'0G
M(#T^(")!8V-O=6YT($QI;6ET($YO=&EC97,B+`H))V-L87-S7VYO=&EF:6-A
M=&EO;F9O<FU?7V1O;6%I;E]U<V5R)R`]/B`B9&]M86EN(&%D;6EN:7-T<F%T
M;W(B+`H))V-L87-S7VYO=&EF:6-A=&EO;F9O<FU?7V5M86EL7V%D9')E<W,G
M(#T^(")E+6UA:6P@861D<F5S<R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R
M;5]?979E;G0G(#T^(")%=F5N="(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R
M;5]?97AP:7)A=&EO;E]T:6UE)R`]/B`B4V5N9"!%>'!I<F%T:6]N(%=A<FYI
M;F=S("(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?:6YV86QI9%]E;6%I
M;"<@/3X@(DEN8V]R<F5C="!E+6UA:6P@861D<F5S<R!S<&5C:69I960N(BP*
M"2=C;&%S<U]N;W1I9FEC871I;VYF;W)M7U]I;G9A;&ED7V5X<%]T:6UE)R`]
M/B`B3G5M8F5R(&]F(&1A>7,@:7,@:6YV86QI9"XB+`H))V-L87-S7VYO=&EF
M:6-A=&EO;F9O<FU?7W-E;F1?;F]T:69?=&\G(#T^(")396YD(&YO=&EC92!T
M;R(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC:V5T7V-L;W-E9%]T
M97AT)R`]/B`B5&EC:V5T($-L;W-E9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N
M9F]R;5]?=&EC:V5T7V-O;6UE;G1E9%]T97AT)R`]/B`B5&EC:V5T($-O;6UE
M;G1E9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&EC:V5T7V-R96%T
M961?=&5X="<@/3X@(E1I8VME="!#<F5A=&5D(BP*"2=C;&%S<U]N;W1I9FEC
M871I;VYF;W)M7U]T:6-K971?<F5O<&5N961?=&5X="<@/3X@(E1I8VME="!2
M96]P96YE9"(L"@DG8VQA<W-?;F]T:69I8V%T:6]N9F]R;5]?=&ET;&4G(#T^
M(").;W1I9FEC871I;VX@<W5B<V-R:7!T:6]N(BP*"2=C;&%S<U]S<VQC97)T
M:69I8V%T95]?8V%?;F]T7W-I9VYS)R`]/B`B(%1H92!#02!C97)T:69I8V%T
M92!D;V5S(&YO="!S:6=N('1H92!C97)T:69I8V%T92XB+`H))V-L87-S7W-S
M;&-E<G1I9FEC871E7U]C85]N;W1?<VEG;G-?=V%R;B<@/3X@(E=A<FYI;F<Z
M('1H92!#02!C97)T:69I8V%T92!D;V5S(&YO="!S:6=N('1H92!C97)T:69I
M8V%T92XB+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]I;F-O;7!A=&EB;&5?
M<'9T7VME>5]C97)T)R`]/B`B26YC;VUP871I8FQE('!R:79A=&4@:V5Y+V-E
M<G1I9FEC871E('!A:7(B+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]I;G9A
M;&ED7V-E<G1?9F]R;6%T)R`]/B`B26YV86QI9"!C97)T:69I8V%T92!F;W)M
M870N(BP*"2=C;&%S<U]S<VQC97)T:69I8V%T95]?:6YV86QI9%]P<FEV871E
M7VME>5]F;W)M870G(#T^("));G9A;&ED('!R:79A=&4@:V5Y(&9O<FUA="XB
M+`H))V-L87-S7W-S;&-E<G1I9FEC871E7U]P<F]B7VEN=F%L:61?<')I=E]K
M97DG(#T^(")0<F]B86)L>2P@=&AE('!R:79A=&4@:V5Y(&9O<FUA="!I<R!I
M;G9A;&ED+B(L"@DG8VQA<W-?=')A9F9I8VAI<W1O<GE?7VYO7V1A=&%?879A
M:6QA8FQE)R`]/B`B3F\@9&%T82!A=F%I;&%B;&4N(BP*"2=C;&%S<U]T<F%F
M9FEC:&ES=&]R>5]?<F5T96Y?<')E9B<@/3X@)U1R869F:6,@<W1A=&ES=&EC
M<R!R971E;G1I;VX@<')E9F5R96YC97,G+`H))V-L87-S7W1R869F:6-H:7-T
M;W)Y7U]T<F%F9FEC7W5S86=E)R`]/B`B5')A9F9I8R!U<V%G92(L"@DG8VQI
M96YT=')A9F9I8VQI<W1?:&5A9&5R)R`]/B`B5')A9F9I8R!A="!D;VUA:6YS
M(BP*"2=C;&EE;G1T<F%F9FEC;&ES=%]H96%D97)?;V9?8VQI96YT7U\G(#T^
M(")4<F%F9FEC(&%T('1H92!D;VUA:6YS(&]F(&-L:65N="`E,2(L"@H))V-L
M:7-T7U]F:7)S="<@/3X@)T9I<G-T)RP*"2=C;&ES=%]?;&%S="<@/3X@)TQA
M<W0G+`H))V-L:7-T7U]P<F5V)R`]/B`G)FQT.R9L=#LG+`H))V-L:7-T7U]N
M97AT)R`]/B`G)F=T.R9G=#LG+`H))V-L:7-T7U]P86=E)R`]/B`G4&%G97,G
M+`H))V-L:7-T7U]P86=E7W-I>F4G(#T^("=.=6UB97(@;V8@96YT<FEE<R!P
M97(@<&%G92<L"@DG8VQI<W1?7VEN9F\G(#T^("<E-"`E,2!T;W1A;"<L"@DG
M8VQI<W1?7VEN9F]?96UP='DG(#T^("=.;R`E,2<L"@DG8VQI<W1?7VEN9F]?
M9FEL=&5R)R`]/B`G)34@)3$@9F]U;F0G+`H))V-L:7-T7U]I;F9O7W!A9VEN
M9R<@/3X@)R4R+24S("4Q(&]F("4T('1O=&%L)RP*"2=C;&ES=%]?:6YF;U]P
M86=I;F=?9FEL=&5R)R`]/B`G)3(M)3,@)3$@;V8@)34@9F]U;F0G+`H))V-L
M:7-T7U]S96%R8VA?<VAO=R<@/3X@)U-H;W<@4V5A<F-H)RP*"2=C;&ES=%]?
M<V5A<F-H7VAI9&4G(#T^("=(:61E(%-E87)C:"<L"@H))V-M9%]D;G-?7V%?
M9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T)R`]/B`B4W5C:"!!(')E8V]R9"!A
M;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;G-?7V-A;F]N:6-A;%]D;VU?;F%M
M95]I<U]I;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N86UE(&ES(&EN
M=F%L:60N(BP*"2=C;61?9&YS7U]C;F%M95]D;G-?<F5C;W)D7V%L<F5A9'E?
M97AI<W0G(#T^(")3=6-H($-.04U%(')E8V]R9"!A;')E861Y(&5X:7-T<RXB
M+`H))V-M9%]D;G-?7V-N86UE7VEN7W)R7V-O;6)I;F%T:6]N)R`]/B`G5&AE
M<F4@:7,@:6YC;W)R96-T(&-O;6)I;F%T:6]N(&]F(')E<V]U<F-E(')E8V]R
M9',@:6X@=&AE('IO;F4G+`H))V-M9%]D;G-?7V-N86UE7V-O97AI<W1?=VET
M:%]D871A)R`]/B`G02!#3D%-12!R96-O<F0@8V%N;F]T(&-O97AI<W0@=VET
M:"!O=&AE<B!R97-O=7)C92!R96-O<F1S(&EN('1H92!S86UE('IO;F4N)RP*
M"2=C;61?9&YS7U]D;G-?<F5C;W)D7W1Y<&5?:7-?:6YV86QI9"<@/3X@(E)E
M<V]U<F-E(')E8V]R9"!T>7!E(&ES(&EN=F%L:60N(BP*"2=C;61?9&YS7U]E
M>'1?:&]S=%]I<U]N;W1?<F5S;VQV960G(#T^(")5;F%B;&4@=&\@<F5S;VQV
M92!T:&4@8V%N;VYI8V%L(&YA;64@)3$N(BP*"2=C;61?9&YS7U]D;VUA:6Y?
M<F5S=&]R95]D;G-?>F]N95]F86EL961?861D7W)E8V]R9"<@/3X@)U5N86)L
M92!T;R!R97-T;W)E('1H92!$3E,@>F]N93H@86X@97)R;W(@;V-C=7)E9"!W
M:&EL92!A9&1I;F<@=&AE("4Q(')E8V]R9"<L"@DG8VUD7V1N<U]?;6%I;%]D
M;VU?;F%M95]I<U]I;G9A;&ED)R`]/B`B36%I;"!E>&-H86YG97(@;F%M92!I
M<R!I;G9A;&ED+B(L"@DG8VUD7V1N<U]?;7A?<')I;W)I='E?:7-?:6YV86QI
M9"<@/3X@(DU8('!R:6]R:71Y(&ES(&EN=F%L:60N(BP*"2=C;61?9&YS7U]N
M86UE7W-E<G9E<E]I<U]I;G9A;&ED)R`]/B`B3F%M92!S97)V97(@:7,@:6YV
M86QI9"XB+`H))V-M9%]D;G-?7VYE='=O<FM?;6%S:U]S:&]U;&1?8F5?,C1?
M,39?;W)?."<@/3X@(DYE='=O<FL@;6%S:R!V86QU92!S:&]U;&0@8F4@,C0L
M(#$V(&]R(#@N(BP*"2=C;61?9&YS7U]T:&ES7V1N<U]R96-O<F1?86QR96%D
M>5]E>&ES=',G(#T^(")3=6-H(')E<V]U<F-E(')E8V]R9"!A;')E861Y(&5X
M:7-T<RXB+`H))V-M9%]D;G-?7W5N86)L95]A9&1?<F5C;W)D)R`]/B`B56YA
M8FQE('1O(&%D9"`G)3$G(')E8V]R9#H@)3(B+`H))V-M9%]D;G-?7W5N86)L
M95]A9&1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@861D($$@<F5C;W)D.B`E
M,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]C;F%M95]R96-O<F0G(#T^(")5
M;F%B;&4@=&\@861D($-.04U%(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N
M86)L95]A9&1?9&YS7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A9&0@<F5S;W5R
M8V4@<F5C;W)D.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]E>'1?;G-?
M<F5C;W)D)R`]/B`B56YA8FQE('1O(&%D9"!%6%1?3E,@<F5C;W)D.B`E,2(L
M"@DG8VUD7V1N<U]?=6YA8FQE7V%D9%]N<U]R96-O<F0G(#T^(")5;F%B;&4@
M=&\@861D($Y3(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N86)L95]A9&1?
M<'1R7W)E8V]R9"<@/3X@(E5N86)L92!T;R!A9&0@4%12(')E8V]R9#H@)3$B
M+`H))V-M9%]D;G-?7W5N86)L95]A9&1?='AT7W)E8V]R9"<@/3X@(E5N86)L
M92!T;R!A9&0@5%A4(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?7W5N86)L95]C
M<F5A=&5?9&YS7WIO;F4G(#T^(")5;F%B;&4@=&\@8W)E871E('1H92!$3E,@
M>F]N92`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7V1E9FEN95]D;G-?<F5C;W)D
M)R`]/B`B56YA8FQE('1O(&1E9FEN92!T:&4@<F5S;W5R8V4@<F5C;W)D("4Q
M(BP*"2=C;61?9&YS7U]U;F%B;&5?9V5T7V1E9F%U;'1?9&YS7WIO;F5?<W1A
M='5S7W-E=%]T<G5E)R`]/B`B56YA8FQE('1O(')E=')I979E('1H92!D969A
M=6QT($1.4R!Z;VYE('-T871U<SH@)3$B+`H))V-M9%]D;G-?7W5N86)L95]I
M;G-E<G1?85]R96-O<F0G(#T^(")5;F%B;&4@=&\@:6YS97)T($$@<F5C;W)D
M.B`E,2(L"@DG8VUD7V1N<U]?=6YA8FQE7VEN<V5R=%]M>%]R96-O<F0G(#T^
M(")5;F%B;&4@=&\@:6YS97)T($U8(')E8V]R9#H@)3$B+`H))V-M9%]D;G-?
M7W5N86)L95]I;G-E<G1?;G-?<F5C;W)D)R`]/B`B56YA8FQE('1O(&EN<V5R
M="!.4R!R96-O<F0Z("4Q(BP*"2=C;61?9&YS7U]U;F%B;&5?<V5T7V1N<U]Z
M;VYE7W-T871U<R<@/3X@(E5N86)L92!T;R!S970@=&AE($1.4R!Z;VYE('-T
M871U<SH@)3$B+`H))V-M9%]D;VUA:6YS7U]D;VU?86QR96%D>5]E>&ES=',G
M(#T^(")$;VUA:6X@)3$@86QR96%D>2!E>&ES=',N(BP*"2=C;61?9&]M86EN
M<U]?9&YS7W)E8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@(E-U8V@@1$Y3(')E
M8V]R9"!F;W(@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD7V1O
M;6%I;G-?7V1O;5]A;')E861Y7V5X:7-T<S$G(#T^(")4:&5R92!A<F4@)3(@
M<W5B9&]M86EN<R!I;B!T:&ES(&1O;6%I;BX@1&]M86EN("4Q(&%L<F5A9'D@
M97AI<W1S+B(L"@DG8VUD7V1O;6%I;G-?7V1O;5]A;')E861Y7V5X:7-T<S(G
M(#T^(")T:&4@<W5B9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD
M7V1O;6%I;G-?7W-U8F1O;5]A;')E861Y7V5X:7-T<R<@/3X@(E1H92!S=6)D
M;VUA:6X@=VET:"!S=6-H(&YA;64@86QR96%D>2!E>&ES=',N(BP*"2=C;61?
M9&]M86EN<U]?9&%L:6%S7V%L<F5A9'E?97AI<W1S)R`]/B`B5&AI<R!A;&EA
M<R!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]D;VUA:6YS7U]U;F%B;&5?9&5L
M7VUA:6Q?9F]R7V1O;2<@/3X@(E5N86)L92!T;R!D96QE=&4@=&AE(&UA:6P@
M<V5R=FEC97,@9F]R(&1O;6%I;CH@)3$B+`H))V-M9%]D;VUA:6YS7U]U;F%B
M;&5?9&5L971E7V%N;VYY;6]U<U]F='`G(#T^(")5;F%B;&4@=&\@9&5L971E
M(&%N;VYY;6]U<R!&5%`@86-C;W5N="!F;W(@9&]M86EN.B`E,2(L"@DG8VUD
M7V1O;6%I;G-?7W5N86)L95]U<&1A=&5?9&]M7W!A<F%M)R`]/B`B56YA8FQE
M('1O('5P9&%T92!T:&4@9&]M86EN('!A<F%M971E<G,Z("4Q+B(L"@DG8VUD
M7V1O;6%I;G-?7W5N86)L95]R96YA;65?8VQI96YT7V5X:7-T)R`]/B`B9&]M
M86EN(&%D;6EN:7-T<F%T;W(G<R!L;V=I;B!N86UE(&ES(&%L<F5A9'D@:6X@
M=7-E+B(L"@DG8VUD7VAO<W1I;F=?7VAS=%]T>7!E7VES7VYO=%]P:'ES:6-A
M;%]H<W0G(#T^(")(;W-T:6YG('1Y<&4@:7,@;F]T('!H>7-I8V%L+B(L"@DG
M8VUD7VAO<W1I;F=?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@(E5N86)L92!T
M;R!C<F5A=&4@=7-E<B`E,CH@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?
M9&5F:6YE7VEP7V%D9')?9F]R7VYA;65?8F%S961?=FER='5A;%]H;W-T<R<@
M/3X@(E5N86)L92!T;R!D969I;F4@25`@861D<F5S<R!F;W(@=&AE(&YA;64M
M8F%S960@=FER='5A;"!H;W-T<SH@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B
M;&5?9&5L7V]L9%]H<W0G(#T^(")5;F%B;&4@=&\@9&5L971E('1H92!P<F5V
M:6]U<VQY('-E="!U<"!H;W-T:6YG.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N
M86)L95]D96Q?<')O=&5C=&5D7V1I<F5C=&]R>2<@/3X@(E5N86)L92!T;R!D
M96QE=&4@<')O=&5C=&5D(&1I<F5C=&]R>3H@)3$B+`H))V-M9%]H;W-T:6YG
M7U]U;F%B;&5?9&5L7W=E8E]U<V5R)R`]/B`B56YA8FQE('1O(&1E;&5T92!W
M96(@=7-E<CH@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?;6%K92]U<&1A
M=&5?=FER='5A;%]H;W-T)R`]/B`B56YA8FQE('1O(&-R96%T92!O<B!U<&1A
M=&4@=&AE(%9I<G1U86P@2&]S=#H@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B
M;&5?;6%K95]F<F%M95]F;W)W87)D7VAS="<@/3X@(E5N86)L92!T;R!S970@
M=7`@=&AE(&9R86UE(&9O<G=A<F1I;F<@:&]S=&EN9RXB+`H))V-M9%]H;W-T
M:6YG7U]U;F%B;&5?<F5B=6EL9%]F='!?8V]N9FEG)R`]/B`B56YA8FQE('1O
M(')E8G5I;&0@=&AE('!R;V9T<&0@8V]N9FEG=7)A=&EO;B!F:6QE.B`E,2(L
M"@DG8VUD7VAO<W1I;F=?7W5N86)L95]S971?=7!?<W-L)R`]/B`B56YA8FQE
M('1O('-E="!U<"!34TP@)3$B+`H))V-M9%]H;W-T:6YG7U]U;F%B;&5?=6YP
M<F]T96-T7W-S;%]D:7)E8W1O<GDG(#T^(")5;F%B;&4@=&\@<F5M;W9E('!R
M;W1E8W1I;VX@9G)O;2!T:&4@4U-,(&1I<F5C=&]R>3H@)3$B+`H))V-M9%]H
M;W-T:6YG7U]U;F%B;&5?=7!D871E7V1E<W1?=7)L)R`]/B`B56YA8FQE('1O
M('5P9&%T92!T:&4@9&5S=&EN871I;VX@55),("4Q(BP*"2=C;61?:&]S=&EN
M9U]?=6YA8FQE7W5P9&%T95]D;G-?>F]N95]F;W)?9&]M7W5N86)L95]E>&5C
M7W5T:6PG(#T^(")5;F%B;&4@=&\@=7!D871E('1H92!$3E,@>F]N92!F;W(@
M=&AE(&1O;6%I;CH@=71I;&ET>2!E>&5C=71I;VX@9F%I;&5D+B(L"@DG8VUD
M7VAO<W1I;F=?7W5N86)L95]U<&1A=&5?9G1P7W!A<W-W9"<@/3X@(E5N86)L
M92!T;R!U<&1A=&4@1E10('!A<W-W;W)D("4Q(BP*"2=C;61?:&]S=&EN9U]?
M=6YA8FQE7W5P9&%T95]U<V5R)R`]/B`B56YA8FQE('1O('5P9&%T92!U<V5R
M("4R.B`E,2(L"@DG8VUD7VAO<W1I;F=?7W5N:VYO=VY?:'-T7W1Y<&4G(#T^
M(")5;FMN;W=N(&AO<W1I;F<@='EP92XB+`H))V-M9%]H;W-T:6YG7U]Y;W5?
M;F]T7VAA=F5?<&5R;6ES<VEO;E]D96Q?:'-T)R`]/B`B66]U(&1O(&YO="!H
M879E('1H92!P97)M:7-S:6]N('1O('1E<FUI;F%T92!H;W-T:6YG('-E<G9I
M8V4N(BP*"2=C;61?;6%I;%]?861D<E]A;')E861Y7W5S961?:6Y?;6%I;%]R
M961I<F5C="<@/3X@(D%D9')E<W,@)3$@:7,@86QR96%D>2!B96EN9R!U<V5D
M(&EN(&$@;6%I;"!R961I<F5C="XB+`H))V-M9%]M86EL7U]A;&EA<U]A;')E
M861Y7V5X:7-T<R<@/3X@(F%L:6%S(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD
M7VUA:6Q?7V%U=&]R97-P7VED7V%N9%]M86EL;F%M95]I9%]N;W1?;6%T8V@G
M(#T^(")!=71O<F5S<&]N9&5R(&ED(&%N9"!M86EL(&YA;64@:60@9&\@;F]T
M(&UA=&-H(2(L"@DG8VUD7VUA:6Q?7V%U=&]R97-P7VED7VES7W5N9&5F:6YE
M9"<@/3X@(D%U=&]R97-P;VYD97(@:60@:7,@=6YD969I;F5D+B(L"@DG8VUD
M7VUA:6Q?7VUA:6Q?86QI87-?86QR96%D>5]E>&ES='-?:6Y?;6%I;%]N86UE
M)R`]/B`B5&AE(&UA:6P@86QI87,@=VET:"!S=6-H(&YA;64@86QR96%D>2!E
M>&ES=',@9F]R('1H92!M86EL(&YA;64@)3$B+`H))V-M9%]M86EL7U]M86EL
M7VYA;65?86QR96%D>5]E>&ES='-?:6Y?;6%I;&QI<W1S)R`]/B`B36%I;"!N
M86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL:6YG(&QI<W0B+`H))V-M9%]M
M86EL7U]M86EL7VYA;65?86QR961Y7V5X:7-T7VEN7V1O;2<@/3X@(E1H92!M
M86EL(&YA;64@)3$@:7,@86QR96%D>2!I;B!T:&4@9&]M86EN(BP*"2=C;61?
M;6%I;%]?;6%I;%]N86UE7VYO=%]E>&ES="<@/3X@(E1H92!M86EL(&YA;64@
M9&]E<R!N;W0@97AI<W0N(BP*"2=C;61?;6%I;%]?;6%I;%]N86UE7W!A<W-W
M9%]P87)T)R`]/B`B5&AE('!A<W-W;W)D('-H;W5L9"!N;W0@8V]N=&%I;B!M
M86EL(&YA;64@87,@:71S('!A<G0N(BP*"2=C;61?;6%I;%]?;6%I;%]P87-S
M=V1?:6YC;W)R96-T)R`]/B`B7&Y4:&4@<&%S<W=O<F0@:7,@:6YC;W)R96-T
M+"!U<V4@870@;&5A<W0@-2!C:&%R86-T97)S+B!4:&4@<&%S<W=O<F0@<VAO
M=6QD(&YO="!C;VYT86EN(&UA:6P@;F%M92!A<R!I=',@<&%R="Y<;D]N;'D@
M3&%T:6X@8VAA<F%C=&5R<RP@;F\@9&EC=&EO;F%R>2!W;W)D<R`H;W!T:6]N
M86PI+B(L"@DG8VUD7VUA:6Q?7VUA:6Q?<F5D:7)E8W1?861D<E]I<U]I;G9A
M;&ED)R`]/B`B36%I;"!R961I<F5C="!A9&1R97-S(&ES(&EN=F%L:60N(BP*
M"2=C;61?;6%I;%]?;6%I;&QI<W1?86QR96%D>5]E>&ES=%]I;E]T:&ES7V1O
M;2<@/3X@(DUA:6QI;F<@;&ES="`E,2!A;')E861Y(&5X:7-T<R!O;B!T:&ES
M(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M86EL;&ES=%]A;')E861Y7V5X:7-T
M<R<@/3X@(FUA:6QI;F<@;&ES="!A;')E861Y(&5X:7-T<RXB+`H))V-M9%]M
M86EL7U]M86EL;F%M95]A;')E861Y7V5X:7-T7VEN7VUG)R`]/B`B36%I;"!N
M86UE("4Q(&ES(&%L<F5A9'D@:6X@82!M86EL(&=R;W5P+B(L"@DG8VUD7VUA
M:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?<F5D:7(G(#T^(")-86EL
M(&YA;64@)3$@:7,@86QR96%D>2!I;B!A(')E9&ER96-T+B(L"@DG8VUD7VUA
M:6Q?7VUA:6QN86UE7V%L<F5A9'E?97AI<W1?:6Y?=&AI<U]D;VTG(#T^(")-
M86EL(&YA;64@)3$@86QR96%D>2!E>&ES=',@:6X@=&AI<R!D;VUA:6XN(BP*
M"2=C;61?;6%I;%]?;6%I;&YA;65?86QR96%D>5]E>&ES=',G(#T^(")M86EL
M(&YA;64@86QR96%D>2!E>&ES=',N(BP*"2=C;61?;6%I;%]?;6%I;&YA;65?
M:7-?:6YV86QI9"<@/3X@(DUA:6P@;F%M92`E,2!I<R!I;G9A;&ED+B(L"@DG
M8VUD7VUA:6Q?7VUA:6QN86UE7W5N86)L95]U<&1A=&4G(#T^(")5;F%B;&4@
M=&\@=7!D871E('1H92!M86EL(&YA;64@<')O<&5R=&EE<SHB+`H))V-M9%]M
M86EL7U]M87A?875T;W)E<W!?<F5A8VAE9%]F;W)?=&AI<U]D;VTG(#T^(")-
M87AI;75M(&YU;6)E<B!O9B!A=71O<F5S<&]N9&5R<R!I<R!R96%C:&5D(&9O
M<B!T:&ES(&1O;6%I;BXB+`H))V-M9%]M86EL7U]M87A?;6%I;%]G<F]U<'-?
M;G5M7VAA<U]B965N7W)E86-H961?9F]R7W1H:7-?9&]M)R`]/B`B;6%X:6UU
M;2!N=6UB97(@;V8@;6%I;"!G<F]U<',@:&%S(&)E96X@<F5A8VAE9"!F;W(@
M=&AI<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7VYU;5]O9E]R961I<F5C
M='-?:&%S7V)E96Y?<F5A8VAE9%]F;W)?=&AI<U]D;VTG(#T^(")M87AI;75M
M(&YU;6)E<B!O9B!R961I<F5C=',@:&%S(&)E96X@<F5A8VAE9"!F;W(@=&AI
M<R!D;VUA:6XN(BP*"2=C;61?;6%I;%]?;6%X7W!O<W1B;WAE<U]N=6U?:&%S
M7V)E96Y?<F5A8VAE9"<@/3X@(FUA>&EM=6T@;G5M8F5R(&]F(&UA:6QB;WAE
M<R!H87,@8F5E;B!R96%C:&5D+B(L"@DG8VUD7VUA:6Q?7VYO7VUE;6)E<G-?
M<W!E8VEF:65D)R`]/B`B;F\@;65M8F5R<R!S<&5C:69I960N(BP*"2=C;61?
M;6%I;%]?=&AE7W!A<W-W9%]I<U]T;V]?<VEM<&QE7V-H;V]S95]A;F]T:&5R
M)R`]/B`B5&AE('!A<W-W;W)D(&ES('1O;R!S:6UP;&4L('!L96%S92!C:&]O
M<V4@86YO=&AE<BXB+`H))V-M9%]M86EL7U]T:&ES7V%D9')?86QR96%D>5]E
M>&ES=%]I;E]M9U]O<E]M;B<@/3X@(E1H:7,@861D<F5S<R!I<R!A;')E861Y
M(&EN(&$@;6%I;"!G<F]U<"!O<B!M86EL(&YA;64N(BP*"2=C;61?;6%I;%]?
M=6YA8FQE7V1E9FEN95]A=71O<F5S<%]I9"<@/3X@(E5N86)L92!T;R!D969I
M;F4@875T;W)E<W!O;F1E<B!I9"`E,2(L"@DG8VUD7VUA:6Q?7W5N86)L95]D
M96Q?;6%I;%]F;W)?9&]M)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@;6%I
M;"!S97)V:6-E(&9R;VT@9&]M86EN("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE
M7V1E;%]M86EL7W)E9&ER96-T:6]N)R`]/B`B56YA8FQE('1O(')E;6]V92!M
M86EL(')E9&ER96-T:6]N("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E;6]V
M95]A=71O<F5S<"<@/3X@(E5N86)L92!T;R!R96UO=F4@875T;W)E<W!O;F1E
M<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E;6]V95]M86EL7V=R;W5P
M7VUE;6)E<G,G(#T^(")5;F%B;&4@=&\@<F5M;W9E('1H92!M86EL(&=R;W5P
M(&UE;6)E<G,Z("4Q(BP*"2=C;61?;6%I;%]?=6YA8FQE7W)E;6]V95]R961I
M<F5C="<@/3X@(E5N86)L92!T;R!R96UO=F4@<F5D:7)E8W0Z("4Q(BP*"2=C
M;61?;6%I;%]?=6YA8FQE7W1U<FY?;V9F7VUA:6Q?9W)O=7`G(#T^(")&86EL
M960@=&\@9&ES86)L92!T:&4@;6%I;"!G<F]U<#H@)3$B+`H))V-M9%]M86EL
M7U]U;F%B;&5?=7!D871E7VUA:6Q?<F5D:7)E8W0G(#T^(")5;F%B;&4@=&\@
M=7!D871E('1H92!M86EL(')E9&ER96-T("4Q(BP*"2=C;61?;6%I;%]?=6YA
M8FQE7W5P9&%T95]M8F]X7W%U;W1A)R`]/B`B56YA8FQE('1O('5P9&%T92!T
M:&4@;6%I;&)O>"!Q=6]T82XB+`H))V-M9%]M86EL7U]U<&QO861E9%]F:6QE
M7VES7W1O;U]B:6<G(#T^(")5<&QO861E9"!F:6QE('-I>F4@:7,@=&]O(&QA
M<F=E+B(L"@DG8VUD7VUA:6Q?7V%D9&ET:6]N86QL>2<@/3X@(D%D9&ET:6]N
M86QL>3H@(BP*"2=C;61?<&1?7VEN=F%L:61?;&]G:6XG(#T^("));F-O<G)E
M8W0@;&]G:6XN(BP*"2=C;61?<&1?7W1H:7-?=7-E<E]A;')E861Y7V5X:7-T
M)R`]/B`B4W5C:"!U<V5R(&%L<F5A9'D@97AI<W1S+B(L"@DG8VUD7W!D7U]U
M;F%B;&5?9&5F:6YE7VAS=%]T>7!E)R`]/B`B56YA8FQE('1O(&1E9FEN92!H
M;W-T:6YG('1Y<&4N(BP*"2=C;61?<&1?7W5N86)L95]U<&1?<&1?=7-R)R`]
M/B`B56YA8FQE('1O('5P9&%T92!P<F]T96-T960@9&ER96-T;W)Y('5S97(@
M<')O<&5R=&EE<SH@)3$B+`H))V-M9%]P9%]?=7-E<E]I<U]U;F1E9FEN960G
M(#T^(")5<V5R(&ES('5N9&5F:6YE9"XB+`H))V-M9%]S97)V97)?7VYO7V5N
M;W5G:%]F<F5E7V1I<VM?<W!A8V4G(#T^(").;W0@96YO=6=H(&1I<VL@<W!A
M8V4N(BP*"2=C;61?<V5R=F5R7U]O;&1?<&%S<W=D7VES7VEN8V]R<F5C=%]P
M;&5A<V5?=')Y7V%G86EN)R`]/B`B;VQD('!A<W-W;W)D(&ES(&EN8V]R<F5C
M="X@4&QE87-E+"!T<GD@86=A:6XN(BP*"2=C;61?=V5B7W5S<E]?;6%X7W=E
M8E]U<V5R<U]R96%C:&5D7V9O<E]T:&ES7V1O;2<@/3X@(FUA>&EM=6T@=V5B
M('5S97)S(&QI;6ET(&ES(')E86-H960@9F]R('1H:7,@9&]M86EN+B(L"@DG
M8VUD7W=E8E]U<W)?7W5N86)L95]C<F5A=&5?=7-E<B<@/3X@(G5N86)L92!T
M;R!C<F5A=&4@<WES=&5M('5S97(Z("4Q(BP*"2=C;61?=V5B7W5S<E]?=6YA
M8FQE7V1E9FEN95]M87A?=V5B7W5S97)S7VQI;6ET)R`]/B`B=6YA8FQE('1O
M(&1E9FEN92!M87AI;75M('=E8B!U<V5R<R!L:6UI=#H@)3$B+`H))V-M9%]W
M96)?=7-R7U]U<V5R7V%L<F5A9'E?97AI<W1S)R`]/B`B=7-E<B!A;')E861Y
M(&5X:7-T<RXB+`H))V-M9%]W96)?=7-R7U]W96)?=7-E<E]N86UE7VES7VEN
M=F%L:60G(#T^(")W96(@=7-E<B!N86UE("4Q(&ES(&EN=F%L:60N(BP*"2=C
M;61?=V5B7W5S<E]?=V5B7W5S97)?;F]T7V5X:7-T)R`]/B`B=V5B('5S97(@
M9&]E<R!N;W0@97AI<W0N(BP*"2=C;VUM;VY?9G5N8U]?97AE8U]B861?87)G
M=6UE;G0G(#T^(")E>&5C(&%R9W5M96YT('-H;W5L9"!N;W0@8V]N=&%I;B!S
M:6YG;&4@<75O=&4@<WEM8F]L+B(L"@DG8V]M;6]N7V%C;%]?861D7V%D9')E
M<W,G(#T^("=!9&0@=&\@0V]M;6]N($%L;&]W(%IO;F4@5')A;G-F97(@04-,
M)RP*"2=C;VUM;VY?86-L7V%D9%]R96-O<F0G(#T^("=!9&0@82!!0TP@<F5C
M;W)D)RP*"2=E;G1E<E]I<%]O<E]N971W;W)K7V%D9')E<W,G(#T^("=%;G1E
M<B!)4"!O<B!N971W;W)K(&%D9')E<W,G+`H))U]?96]L)R`]/B`G3&EN92!B
M<F5A:W,G+`H))V5O;%]?;F]N92<@/3X@)V1O(&YO="!M;V1I9GDG+`H))V5O
M;%]?;&8G(#T^("=I;B!5;FEX('-T>6QE)RP*"2=E;VQ?7V-R)R`]/B`G:6X@
M36%C3U,@<W1Y;&4G+`H))V5O;%]?8W)L9B<@/3X@)VEN(%=I;F1O=W,@<W1Y
M;&4G+`H))V5O;%]?8FEN87)Y7V9I;&4G(#T^("=5;F%B;&4@=&\@8VAA;F=E
M(&QI;F4@8G)E86L@<W1Y;&4@:6X@8FEN87)Y(&9I;&4N)RP*"2=C;VUP7VEN
M9F]?7VAE861E<B<@/3X@)T-O;7!O;F5N=',G+`H))V-O;7!?:6YF;U]?8V]M
M<%]N86UE)R`]/B`B0V]M<&]N96YT(&YA;64B+`H))V-O;7!?:6YF;U]?8V]M
M<%]V97)S:6]N)R`]/B`B0V]M<&]N96YT('9E<G-I;VXB+`H))V-O;7!?:6YF
M;U]?=&ET;&4G(#T^("));F9O<FUA=&EO;B!O;B`E,2!C;VUP;VYE;G1S(BP*
M"2=C;VYF:6=U<F5?7V9U;&Q?:&]S=&YA;65?:&EN="<@/3X@)U-P96-I9GD@
M=&AE(&9U;&QY('%U86QI9FEE9"!D;VUA:6X@;F%M92!F;W(@=&AI<R!S97)V
M97(N($5X86UP;&4Z(&AO<W1N86UE+F1O;6%I;BYC;VTG+`H))V-O;F9I9W5R
M95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G0G(#T^("=3<&5C:69Y('1H92!)
M4"!A9&1R97-S('1H870@=VEL;"!B92!U<V5D(&%S('1H92!M86EN('-E<G9E
M<B!)4"!A9&1R97-S+B!396QE8W0@86X@97AI<W1I;F<@25`@861D<F5S<R!O
M<B!C;&EC:R!!9&0@25`@061D<F5S<R!T;R!A9&0@82!N97<@25`@861D<F5S
M<R!T;R!T:&4@<WES=&5M+B!)9B!Y;W4@=V%N="!T:&4@;F5W($E0(&%D9')E
M<W,@=&\@8F4@<VAA<F5D(&)E='=E96X@<V5V97)A;"!C;&EE;G0@86-C;W5N
M=',L('-E;&5C="!T:&4@4VAA<F5D(&-H96-K(&)O>"XG+`H))V-O;F9I9W5R
M95]?9&5F875L=%]I<%]A9&1R97-S7VAI;G1?<V5L96-T7V]N;'DG(#T^("=3
M<&5C:69Y('1H92!)4"!A9&1R97-S('1H870@=VEL;"!B92!U<V5D(&%S('1H
M92!M86EN($E0(&%D9')E<W,@9F]R('1H:7,@<V5R=F5R+B<L"@DG8V]N9FEG
M=7)E7U]S:&%R961?:7!?861D<F5S<U]H:6YT)R`]/B`G66]U(&-A;B!C:&%N
M9V4@=&AE('1Y<&4@;V8@97AI<W1I;F<@25`@861D<F5S<V5S(&9R;VT@97AC
M;'5S:79E('1O('-H87)E9"X@4VAA<F5D($E0(&%D9')E<W-E<R!C86X@8F4@
M87-S:6=N960@=&\@;75L=&EP;&4@8VQI96YT(&%C8V]U;G1S+B!4;R!C:&%N
M9V4@=&AE($E0(&%D9')E<W,@='EP92!F<F]M(&5X8VQU<VEV92!T;R!S:&%R
M960L('-E;&5C="!)4"!A9&1R97-S97,@:6X@=&AE(&QI<W0@;V8@97AC;'5S
M:79E($E0(&%D9')E<W-E<RP@86YD(&-L:6-K(%-H87)E9"XG+`H))U]?9&5F
M875L=%]I<%]A9&1R97-S)R`]/B`G1&5F875L="!)4"!!9&1R97-S)RP*"2=C
M;VYF:6=U<F5?7V1E9F%U;'1?:7!?<V5L96-T)R`]/B`G4V5L96-T(&%N(&%D
M9')E<W,G+`H))V-O;F9I9W5R95]?9&5F875L=%]I<%]N97<G(#T^("=!9&0@
M25`@061D<F5S<R<L"@DG8V]N9FEG=7)E7U]I<%]I;G1E<F9A8V4G(#T^("=)
M;G1E<F9A8V4G+`H))V-O;F9I9W5R95]?:7!?861D<F5S<R<@/3X@)TE0($%D
M9')E<W,G+`H))V-O;F9I9W5R95]?:7!?<VAA<F5D)R`]/B`G4VAA<F5D)RP*
M"2=C;VYF:6=U<F5?7W-E;&5C=%]E>&QU<VEV95]I<',G(#T^("=%>&-L=7-I
M=F4@25`@861D<F5S<V5S)RP*"2=C;VYF:6=U<F5?7W-E;&5C=%]S:&%R961?
M:7!S)R`]/B`G4VAA<F5D($E0(&%D9')E<W-E<R<L"@DG8V]N9FEG=7)E7U]A
M9&UI;E]P87-S=V]R9%]C:&%N9V4G(#T^(")0;&5A<V4@8VAA;F=E('1H92!D
M969A=6QT(&%D;6EN:7-T<F%T;W(@<&%S<W=O<F0N(BP*"2=C;VYF:6=U<F5?
M7V5R<F]R7VYA;65D7W)E<W1A<G0G(#T^(").86UE9"!R97-T87)T(&5R<F]R
M+B!&;W(@<')O<&5R(&YA;65D('=O<FL@>6]U('-H;W5L9"!R97-T87)T(&ET
M+B(L"@DG8V]N9FEG=7)E7U]F:6QL7V9O;&QO=VEN9U]F:65L9',G(#T^(")&
M:6QL('1H92!R97%U97-T960@:6YF;W)M871I;VX@:6YT;R!T:&4@87!P<F]P
M<FEA=&4@9FEE;&1S+B!4:&ES(&EN9F]R;6%T:6]N(&ES(')E<75I<F5D(&9O
M<B`E,2!T;R!W;W)K+B(L"@DG8V]N9FEG=7)E7U]F=6QL7VAO<W1N86UE)R`]
M/B`B1G5L;"!H;W-T;F%M92(L"@DG8V]N9FEG=7)E7U]U;F%B;&5?8V]N9FEG
M=7)E)R`]/B`B56YA8FQE('1O(&-O;F9I9W5R93H@)3$B+`H))V-P7V%C8V5S
M<U]A9&UI;E]D96YY)R`]/B`B06-C97-S(&9O<B!A9&UI;FES=')A=&]R(&9R
M;VT@861D<F5S<R`G)3$G(&ES(')E<W1R:6-T960@:6X@86-C;W)D86YC92!W
M:71H($E0($%C8V5S<R!R97-T<FEC=&EO;B!P;VQI8WD@8W5R<F5N=&QY(&%P
M<&QI960N(BP*"2=C<%]A8V-E<W-?8W5R<E]I<%]A8V-E<W-?9&5N>2<@/3X@
M(E=A<FYI;F<A(2$@5&AE(&%C8V5S<R!R97-T<FEC=&EO;B!P;VQI8WD@86YD
M('1H92!L:7-T(&]F(&YE='=O<FMS(&%R92!C=7)R96YT;'D@8V]N9FEG=7)E
M9"!T:&4@=V%Y('EO=2!W:6QL(&YO="!B92!A8FQE('1O(&QO9VEN('=I=&@@
M861M:6YI<W1R871O<B=S(')I9VAT<R!F<F]M('EO=7(@25`@861D<F5S<R`G
M)3$G+B(L"@DG8W!?86-C97-S7V5D:71?:&5A9&5R)R`]/B`B3F5T=V]R:R!E
M9&ET:6YG(BP*"2=C<%]A8V-E<W-?97AI<W1S)R`]/B`B5&AE(&YE='=O<FL@
M:7,@86QR96%D>2!I;B!T:&4@25`@86-C97-S(')E<W1R:6-T:6]N(&QI<W0N
M(BP*"2=C<%]A8V-E<W-?:&5A9&5R)R`]/B`B25`@86-C97-S(')E<W1R:6-T
M:6]N(&UA;F%G96UE;G0B+`H))V-P7V%C8V5S<U]P;VQI8WDG(#T^(")#;VYT
M<F]L('!A;F5L(&%C8V5S<R!W:71H(&%D;6EN:7-T<F%T;W(G<R!P<FEV:6QE
M9V5S(BP*"2=C<%]A8V-E<W-?<&]L:6-Y7V%L;&]W)R`]/B`B06QL;W=E9"P@
M97AC;'5D:6YG('1H92!N971W;W)K<R!I;B!T:&4@;&ES="XB+`H))V-P7V%C
M8V5S<U]P;VQI8WE?9&5N>2<@/3X@(D1E;FEE9"!F<F]M('1H92!N971W;W)K
M<R!T:&%T(&%R92!N;W0@;&ES=&5D+B(L"@DG8W!?86-C97-S7W)E;6]V95]H
M96%D97(G(#T^(").971W;W)K(')E;6]V86PB+`H))V-P7V%C8V5S<U]S96QE
M8W1?:7`G(#T^(")396QE8W0@;VYE(&]R('-E=F5R86P@;F5T=V]R:W,@9G)O
M;2!T:&4@25`@86-C97-S(')E<W1R:6-T:6]N(&QI<W0N(BP*"2=C<%]A8V-E
M<W-?<W=I=&-H7V-O;F9I<FUA=&EO;B<@/3X@(D-H86YG92!T:&4@86-C97-S
M('!O;&EC>3\B+`H))V-P7V%C8V5S<U]S=VET8VA?9&5N>5]E<G)O<B<@/3X@
M(E5N86)L92!T;R!C:&%N9V4@=&AE(&%C8V5S<R!P;VQI8WDZ(&YO(&YE='=O
M<FMS('-P96-I9FEE9"(L"@DG8W!?86-C97-S7W-W:71C:%]D96YY7VYO=R<@
M/3X@(E1H92!A8V-E<W,@<&]L:6-Y('=A<R!C:&%N9V5D(&)E8V%U<V4@=&AE
M<F4@87)E(&YO(&YE='=O<FMS('-P96-I9FEE9"XB+`H))V-P7V%C8V5S<U]?
M;F5T=V]R:U]A9&1R97-S)R`]/B`G4W5B;F5T(&]R($E0(&%D9')E<W,G+`H)
M)V-P7V%C8V5S<U]?;F5T=V]R:U]M87-K)R`]/B`G4W5B;F5T(&UA<VLG+`H)
M)V-R96%T95]D;VUA:6Y?=V%R;E]?)R`]/B`B5&AE(&9O;&QO=VEN9R!E>&-E
M<'1I;VYS('=E<F4@;6%D92!D=7)I;F<@9&]M86EN(&-R96%T:6]N.B(L"@DG
M8W)E871E7V1O;6%I;E]?8VQI96YT7W-E;&5C="<@/3X@)U-E;&5C="!T:&4@
M8VQI96YT('1O(&-R96%T92!T:&4@9&]M86EN(&9O<B<L"@DG8W)O;G1A8E]?
M8W)O;G1A8E]E;G1R>5]E>&ES=',G(#T^(")4:&4@)3$@=&%S:R!A;')E861Y
M(&5X:7-T<R(L"@DG8W)O;G1A8E]?8W)O;G1A8E]E;G1R>5]N;W1?97AI<W1S
M)R`]/B`B5&AE("4Q('1A<VL@9&]E<R!N;W0@97AI<W0B+`H))V-R;VYT86)?
M7VEN=F%L:61?=F%L=65S7V9O=6YD)R`]/B`B5&AE<F4@87)E(&EN8V]R<F5C
M="!P87)A;65T97(@=F%L=65S(BP*"2=C<F]N=&%B7V5D:71?7V-R;VYT86)?
M;V9?7R<@/3X@(D5D:71I;F<@=&AE("4Q('1A<VL@;V8@)3(B+`H))V-R;VYT
M86)?961I=%]?8VUD7VUA>%]L96XG(#T^(")4:&4@8V]M;6%N9"!Y;W4@<W!E
M8VEF:65D(&5X8V5E9',@=&AE(&%L;&]W960@;&5N9W1H("@E,2!S>6UB;VQS
M*2XB+`H))V-R;VYT86)?;&ES=%]?;6%I;%]T;U]?)R`]/B`B4V5N9"`E,2!M
M97-S86=E<R!T;R!A9&1R97-S("4R(BP*"2=C<F]N=&%B7VQI<W1?7VUA:6Q?
M=&]?:7-?:6YV86QI9"<@/3X@(E1H92!A9&1R97-S(&9O<B`E,2!M97-S86=E
M<R!D96QI=F5R>2!I<R!I;F-O<G)E8W0B+`H))V-R;VYT86)?;&ES=%]?<F5M
M;W9E7V]N7W5S97)?7R<@/3X@(E)E;6]V92!T:&4@<V-H961U;&5D('1A<VMS
M(&]F("4R(BP*"2=C<F]N=&%B7VQI<W1?7W-E;&5C=%]T;U]R96UO=F4G(#T^
M(")396QE8W0@=&AE("4Q('1A<VMS('1O(&)E(')E;6]V960N(BP*"2=C<F]N
M=&%B7VQI<W1?7W-H;W=?8W)O;G1A8E]O9E]?)R`]/B`B4VAO=R`E,2!O9B`E
M,B(L"@DG8W)O;G1A8E]L:7-T7U]S>7-U<V5R7VQI<W1?96UP='DG(#T^(")4
M:&5R92!A<F4@;F\@)3$@=&%S:W,@879A:6QA8FQE(BP*"2=C<F]N=&%B7VQI
M<W1?7W1A<VMS)R`]/B`B)3$@=&%S:W,B+`H*"2=C=7-T;VU?8G5T=&]N7U]S
M;W)T7VME>2<)"3T^("=0<FEO<FET>2<L"@DG8W5S=&]M7V)U='1O;E]?<&QA
M8V4G"0D)/3X@)TQO8V%T:6]N)RP*"2=C=7-T;VU?8G5T=&]N7U]P;&%C95]N
M879I9V%T:6]N)PD]/B`G3F%V:6=A=&EO;B!P86YE;"<L"@DG8W5S=&]M7V)U
M='1O;E]?<&QA8V5?861M:6XG"0D]/B`G061M:6YI<W1R871O<EPG<R!$97-K
M=&]P)RP*"2=C=7-T;VU?8G5T=&]N7U]P;&%C95]C;&EE;G0G"0D]/B`G0VQI
M96YT7"=S($1E<VMT;W`@+R!(;VUE('!A9V4G+`H))V-U<W1O;5]B=71T;VY?
M7W!L86-E7V1O;6%I;B<)"3T^("=$;VUA:6X@3W=N97)<)W,@1&5S:W1O<"`O
M($AO;64@<&%G92<L"@DG8W5S=&]M7V)U='1O;E]?<'5B;&EC)PD)"3T^("=6
M:7-I8FQE('1O(&%L;"!S=6(M;&]G:6YS)RP*"2=C=7-T;VU?8G5T=&]N7U]I
M;6%G92<)"0D]/B`G0F%C:V=R;W5N9"!I;6%G92<L"@DG8W5S=&]M7V)U='1O
M;E]?8V]N:&5L<"<)"3T^(")#;VYT97AT(&AE;'`@=&EP(&-O;G1E;G1S(BP*
M"2=C=7-T;VU?8G5T=&]N7U]E9&ET)PD)"3T^(")#=7-T;VT@0G5T=&]N(%!R
M;W!E<G1I97,B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7V-N
M86UE)PD]/B`B26YC;'5D92!C;&EE;G0G<R!C;VUP86YY(&YA;64B+`H))V-U
M<W1O;5]B=71T;VY?7VEN8VQU9&5?8VQI96YT7V5M86EL)R`]/B`B26YC;'5D
M92!C;&EE;G0G<R!E+6UA:6PB+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?
M8VQI96YT7VED)R`]/B`B26YC;'5D92!C;&EE;G0@:60B+`H))V-U<W1O;5]B
M=71T;VY?7VEN8VQU9&5?8VQI96YT7W!N86UE)R`]/B`B26YC;'5D92!C;&EE
M;G0G<R!C;VYT86-T(&YA;64B+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU9&5?
M9&]M86EN7VED)R`]/B`B26YC;'5D92!D;VUA:6X@:60B+`H))V-U<W1O;5]B
M=71T;VY?7VEN8VQU9&5?9&]M86EN7VYA;64G(#T^("));F-L=61E(&1O;6%I
M;B!N86UE(BP*"2=C=7-T;VU?8G5T=&]N7U]I;F-L=61E7V9T<%]U<V5R)R`]
M/B`B26YC;'5D92!&5%`@3&]G:6XB+`H))V-U<W1O;5]B=71T;VY?7VEN8VQU
M9&5?9G1P7W!A<W,G(#T^("));F-L=61E($944"!P87-S=V]R9"(L"@DG8W5S
M=&]M7V)U='1O;E]?:6YT97)N86Q?;W!E;B<@/3X@(D]P96X@55),(&EN('1H
M92!#;VYT<F]L(%!A;F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]T97AT)R`]/B`B
M0G5T=&]N(&QA8F5L(BP*"2=C=7-T;VU?8G5T=&]N7U]U<FPG(#T^(")54DPB
M+`H*"2=C=7-T;VU?8G5T=&]N<U]?96UP='E?<V5L96-T:6]N)R`]/B`B4V5L
M96-T('1H92!B=71T;VYS('1O(&)E(')E;6]V960N(BP*"2=C=7-T;VU?8G5T
M=&]N<U]?;F%M92<@/3X@(DQA8F5L(BP*"2=C=7-T;VU?8G5T=&]N<U]?<'5B
M;&EC)R`]/B`G02<L+R]"=71T;VX@86-C97-S:6)I;&ET>2!P<F]P97)T>0H)
M)V-U<W1O;5]B=71T;VYS7U]S;W)T7VME>2<@/3X@)U!R:6]R:71Y)RP@+R]4
M:&ES(&ES('1H92!L:7-T('1I=&QE('=H:6-H(&EN9&EC871E<R!T:&4@;W)D
M97(@;V8@=&AE(&-U<G)E;G0@8G5T=&]N"@DG8W5S=&]M7V)U='1O;G-?7W!L
M86-E)R`]/B`G3"<L+R],;V-A=&EO;@H))V-U<W1O;5]B=71T;VYS7U]R96UO
M=F4G(#T^(")4:&4@9F]L;&]W:6YG(&)U='1O;G,@=VEL;"!B92!R96UO=F5D
M.B(L"@DG8G1?9&]M86EN7V%L:6%S97,G(#T^("=$;VUA:6X@06QI87-E<R<L
M"@DG8G1?9&]M86EN7V%L:6%S7V%D9"<@/3X@)T%D9"!$;VUA:6X@06QI87,G
M+`H))W!B7U]D;VUA:6Y?86QI87-E<R<@/3X@)T1O;6%I;B!A;&EA<V5S)RP*
M"2=D87-H8F]A<F1?7VYA=E]B=71T;VY?;F%M92<@/3X@(D1E<VMT;W`B+`H)
M)V1A;&EA<U]?;&ES=%]T:71L92<@/3X@)T1O;6%I;B!A;&EA<V5S(&]F('1H
M92!D;VUA:6X@)3$G+`H))V1A;&EA<U]?;&ES=%]L96=E;F0G(#T^("=$;VUA
M:6X@86QI87-E<R<L"@DG9&%L:6%S7U]L:7-T7VAE861E<B<@/3X@)T1O;6%I
M;B!A;&EA<V5S)RP*"2=D86QI87-?7VQI<W1?<W1A='5S)R`]/B`G4R<L"@DG
M9&%L:6%S7U]L:7-T7VYA;64G(#T^("=$;VUA:6X@86QI87,@;F%M92<L"@DG
M9&%L:6%S7U]L:7-T7V%S8VEI7VYA;64G(#T^("=);B!!4T-)22!F;W)M870G
M+`H))V1A;&EA<U]?<F5M;W9E7W1I=&QE)R`]/B`G5&AE(&9O;&QO=VEN9R!D
M;VUA:6X@86QI87-E<R!O9B!T:&4@9&]M86EN("4Q('=I;&P@8F4@<F5M;W9E
M9#HG+`H))V1A;&EA<U]?<V5L96-T7V1O;6%I;E]A;&EA<V5S7W1O7W)E;6]V
M92<@/3X@)U-E;&5C="!T:&4@9&]M86EN(&%L:6%S97,@=&\@8F4@<F5M;W9E
M9"XG+`H))V1A;&EA<U]?8V]N=')O;%]T:71L92<@/3X@)T1O;6%I;B!A;&EA
M<R`E,2<L"@DG9&%L:6%S7U]C;VYT<F]L7VEN9F]?;&5G96YD)R`]/B`G26YF
M;R<L"@DG9&%L:6%S7U]C;VYT<F]L7W-T871U<U]T:71L92<@/3X@)U,G+`H)
M)V1A;&EA<U]?8V]N=')O;%]N86UE7W1I=&QE)R`]/B`G4V5R=FEC92!N86UE
M)RP*"2=D86QI87-?7V-O;G1R;VQ?9&5T86EL<U]T:71L92<@/3X@)T1E=&%I
M;',G+`H))V1A;&EA<U]?<V5R=FEC95]M86EL)R`]/B`G36%I;"<L"@DG9&%L
M:6%S7U]S97)V:6-E7W=E8B<@/3X@)U=E8B<L"@DG9&%L:6%S7U]D;VUA:6Y?
M<V5R=FEC95]M86EL7V5N86)L960G(#T^("=-86EL('-E<G9I8V4@:7,@96YA
M8FQE9"!O;B!T:&4@9&]M86EN+B<L"@DG9&%L:6%S7U]D;VUA:6Y?<V5R=FEC
M95]M86EL7V1I<V%B;&5D)R`]/B`G36%I;"!S97)V:6-E(&ES(&1I<V%B;&5D
M(&]N('1H92!D;VUA:6XN)RP*"2=D86QI87-?7V1O;6%I;E]S97)V:6-E7VUA
M:6Q?;7@G(#T^("<E,2!U<V5D(&%S(&UA:6P@97AC:&%N9V5R+B<L"@DG9&%L
M:6%S7U]E9&ET7W1I=&QE)R`]/B`G1&]M86EN(&%L:6%S('!R969E<F5N8V5S
M)RP*"2=D86QI87-?7V%D9%]T:71L92<@/3X@)T%D9"!D;VUA:6X@86QI87,G
M+`H))V1A;&EA<U]?961I=%]L96=E;F0G(#T^("=0<F5F97)E;F-E<R<L"@DG
M9&%L:6%S7U]E9&ET7VYA;64G(#T^("=$;VUA:6X@86QI87,@;F%M92<L"@DG
M9&%L:6%S7U]I;G9A;&ED7W9A;'5E<R<@/3X@)U1H92!D;VUA:6X@;F%M92!Y
M;W4@<W!E8VEF:65D(&ES(&EN=F%L:60N($1O;6%I;B!N86UE<R!C86X@8V]M
M<')I<V4@;&5T=&5R<RP*9&EG:71S(&%N9"!H>7!H96YS+B!%86-H('!A<G0@
M;V8@=&AE(&1O;6%I;B!N86UE(&)E='=E96X@9&]T<R!S:&]U;&0@;F]T(&)E
M"FQO;F=E<B!T:&%N(#8S('-Y;6)O;',N)RP*"2=D86QI87-?7V1O;6%I;E]A
M;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!N86UE(&]F(&1O;6%I;B!A
M;&EA<R`E,2P@9&]M86EN("4Q(&%L<F5A9'D@97AI<W1S+B<L"@DG9&%L:6%S
M7U]W=W=?<')E9FEX7V1O;6%I;E]A;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R
M<F5C="!N86UE(&]F(&1O;6%I;B!A;&EA<R!W=W<N)3$L('1H:7,@86QI87,@
M:7,@86QR96%D>2!C<F5A=&5D(&9O<B!T:&4@9&]M86EN("4Q+B<L"@DG9&%L
M:6%S7U]W96)M86EL7V5N86)L961?9&]M86EN7V%L<F5A9'E?97AI<W1S)R`]
M/B`G26YC;W)R96-T(&1O;6%I;B!A;&EA<R!N86UE.B!4:&5R92!I<R!A;')E
M861Y("!T:&4@9&]M86EN(&YA;64@=V5B;6%I;"XE,2XG+`H))V1A;&EA<U]?
M;&ES='-?96YA8FQE9%]D;VUA:6Y?86QR96%D>5]E>&ES=',G(#T^("=);F-O
M<G)E8W0@9&]M86EN(&%L:6%S(&YA;64Z($$@9&]M86EN('=I=&@@;F%M92`@
M;&ES=',N)3$@86QR96%D>2!E>&ES=',N)RP*"2=D86QI87-?7W-U8F1O;5]A
M;')E861Y7V5X:7-T<R<@/3X@)TEN8V]R<F5C="!D;VUA:6X@86QI87,@;F%M
M93H@02!D;VUA:6X@=VET:"!N86UE("4Q(&%L<F5A9'D@97AI<W1S+B<L"@DG
M9&%L:6%S7U]D;G-?<F5C;W)D7V%L<F5A9'E?97AI<W1S)R`]/B`G4W5C:"!R
M97-O=7)C92!R96-O<F0@:7,@86QR96%D>2!I;B!T:&4@>F]N92!O9B!T:&4@
M9&]M86EN("`E,2XG+`H))V1A;&EA<U]?9&%L:6%S7V%L<F5A9'E?97AI<W1S
M)R`]/B`G1&]M86EN(&%L:6%S("4Q(&%L<F5A9'D@97AI<W1S+B<L"@DG9&%L
M:6%S7U]M86EL7W1U<FY?;VY?9F%I;&5D)R`]/B`G56YA8FQE('1O('1U<FX@
M;VX@;6%I;"!S97)V:6-E.B`E,2<L"@DG9&%L:6%S7U]W96)?='5R;E]O;E]F
M86EL960G(#T^("=5;F%B;&4@=&\@='5R;B!O;B!796(@<V5R=FEC93H@)3$G
M+`H))V1A=&%B87-E<U]?9&)?861M:6Y?;&]G:6XG(#T^("(E,2!A9&UI;FES
M=')A=&]R)W,@;&]G:6XB+`H))V1A=&%B87-E<U]?;F]T7VEN<W1A;&QE9"<@
M/3X@(BAN;W0@:6YS=&%L;&5D*2(L"@DG9&%T86)A<V5S7U]N;W1?<W5P<&]R
M=&5D7VQI8V5N<V4G(#T^("(H;F]T('-U<'!O<G1E9"!B>2!Y;W5R(&QI8V5N
M<V4@:V5Y*2(L"@DG9&%T86)A<V5S7U]T:71L92<@/3X@(D1A=&%B87-E($UA
M;F%G96UE;G0@86YD($%D;6EN:7-T<F%T;W(G<R!#<F5D96YT:6%L<R(L"@DG
M9&%T86)A<V5S7U]U;F%B;&5?8V]N;F5C="<@/3X@(E5N86)L92!T;R!A8V-E
M<W,@9&%T86)A<V4N($EN8V]R<F5C="!P87)A;65T97)S+B(L"@DG9&%T86)A
M<V5S7U]I;F-O<G)E8W1?9&)?861M:6Y?;&]G:6XG(#T^("=4:&4@;&]G:6X@
M;F%M92!C86X@8V]N=&%I;B!O;FQY(&%L<&AA;G5M97)I8RP@9&%S:"!A;F0@
M=6YD97)S8V]R92!S>6UB;VQS+"!A;F0@<VAO=6QD(&)E9VEN('=I=&@@86X@
M86QP:&%B971I8R!S>6UB;VPN)RP*"2=D871A8F%S97-?7VEN8V]R<F5C=%]D
M8E]A9&UI;E]P87-S=V0G(#T^("=4:&4@<&%S<W=O<F0@<VAO=6QD(&YO="!C
M;VYT86EN('1H92!L;V=I;B!N86UE+B<L"@DG9&%T86)A<V5?:&]S=&EN9U]P
M<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO8V%L7V1B7W1E>'0G
M(#T^("=);G-T86QL871I;VX@;V8@<VET92!A<'!L:6-A=&EO;G,@=&AA="!D
M;R!N;W0@<W5P<&]R="!R96UO=&4@9&%T86)A<V5S)RP*"2=D871A8F%S95]H
M;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I=&5A<'!?;&]C86Q?
M9&)?=')U95]T97AT)R`]/B`G06QL;W<@;&]C86P@:&]S=&EN9R!O9B!D871A
M8F%S97,@9F]R('1H97-E('-I=&4@87!P;&EC871I;VYS)RP*"2=D871A8F%S
M95]H;W-T:6YG7W!R969E<F5N8V5S7V9O<FU?7V%L;&]W7W-I=&5A<'!?;&]C
M86Q?9&)?9F%L<V5?=&5X="<@/3X@)T1I<V%L;&]W(&EN<W1A;&QA=&EO;B!O
M9B!T:&5S92!S:71E(&%P<&QI8V%T:6]N<R<L"@DG9&%T86)A<V5?:&]S=&EN
M9U]P<F5F97)E;F-E<U]F;W)M7U]A;&QO=U]S:71E87!P7VQO8V%L7V1B7VAI
M;G0G(#T^("=4:&ES('!R969E<F5N8V4@:7,@;VYL>2!I;B!E9F9E8W0@=VAE
M;B!A(')E;6]T92!D871A8F%S92!S97)V97(@:7,@<V5L96-T960@87,@9&5F
M875L="XG+`H))V1A=&%B87-E7VAO<W1I;F=?<')E9F5R96YC97-?9F]R;5]?
M=&ET;&4G(#T^("=$871A8F%S92!H;W-T:6YG('!R969E<F5N8V5S)RP*"2=D
M871A8F%S95]S97)V97)S7V9O<FU?7W1I=&QE)R`]/B`G1&%T86)A<V4@<V5R
M=F5R<R<L"@DG9&%T86)A<V5?<V5R=F5R<U]F;W)M7U]S97)V97)?;&ES=%]L
M96=E;F0G(#T^("=$871A8F%S92!S97)V97)S)RP))V1A=&%B87-E7W-E<G9E
M<G-?9F]R;5]?<F5M;W9E7V5M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(&1A=&%B
M87-E('-E<G9E<G,@<V5L96-T960N)RP*"2=D871A8F%S95]S97)V97)S7V9O
M<FU?7W)E;6]V95]T:71L92<@/3X@)U1H92!F;VQL;W=I;F<@9&%T86)A<V4@
M<V5R=F5R<R!W:6QL(&)E(')E;6]V960Z)RP*"2=D871A8F%S95]S97)V97)?
M9&%T86)A<V5?;&ES=%]?8VQI96YT)R`]/B`G0VQI96YT)RP*"2=D871A8F%S
M95]S97)V97)?9&%T86)A<V5?;&ES=%]?9&]M86EN)R`]/B`G1&]M86EN)RP*
M"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?:&5A9&5R)R`]/B`G
M1&%T86)A<V5S)RP*"2=D871A8F%S95]S97)V97)?9&%T86)A<V5?;&ES=%]?
M;F%M92<@/3X@)TYA;64G+`H))V1A=&%B87-E7W-E<G9E<E]D871A8F%S97-?
M9F]R;5]?9&%T86)A<V5S7VQI<W1?;&5G96YD)R`]/B`G1&%T86)A<V5S)RP*
M"2=D871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E;6]V95]E;7!T
M>5]S96QE8W1I;VXG(#T^("=.;R!D871A8F%S97,@<V5L96-T960N)RP*"2=D
M871A8F%S95]S97)V97)?9&%T86)A<V5S7V9O<FU?7W)E;6]V95]T:71L92<@
M/3X@)U1H92!F;VQL;W=I;F<@9&%T86)A<V5S('=I;&P@8F4@<F5M;W9E9#HG
M+`H))V1A=&%B87-E7W-E<G9E<E]D871A8F%S97-?9F]R;5]?=&%B)R`]/B`G
M1&%T86)A<V5S("@E,2DG+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?
M7V%D;6EN7VQO9VEN)R`]/B`B061M:6YI<W1R871O<B=S(&QO9VEN(&YA;64B
M+`H))V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN7W!A<W-W;W)D
M7V]L9"<@/3X@(D-U<G)E;G0@861M:6YI<W1R871O<B=S('!A<W-W;W)D(BP*
M"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]A9&UI;E]P87-S=V]R9"<@
M/3X@(DYE=R!A9&UI;FES=')A=&]R)W,@<&%S<W=O<F0B+`H))V1A=&%B87-E
M7W-E<G9E<E]E9&ET7V9O<FU?7V%D;6EN7W!A<W-W;W)D,B<@/3X@(D-O;F9I
M<FT@;F5W(&%D;6EN:7-T<F%T;W(G<R!P87-S=V]R9"(L"@DG9&%T86)A<V5?
M<V5R=F5R7V5D:71?9F]R;5]?9&5F875L="<@/3X@)U5S92!T:&ES('-E<G9E
M<B!A<R!D969A=6QT(&9O<B`E,2<L"@DG9&%T86)A<V5?<V5R=F5R7V5D:71?
M9F]R;5]?9'5P;&EC871E)R`]/B`G02!D871A8F%S92!S97)V97(@=VET:"!T
M:&ES(&-O;6)I;F%T:6]N(&]F(&AO<W0@861D<F5S<R!A;F0@<&]R="!N=6UB
M97(@:7,@86QR96%D>2!R96=I<W1E<F5D+B<L"@DG9&%T86)A<V5?<V5R=F5R
M7V5D:71?9F]R;5]?:&]S="<@/3X@)TAO<W0@;F%M92!O<B!)4"!A9&1R97-S
M)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]L96=E;F1?875T:&5N
M=&EC871I;VXG(#T^("=!=71H96YT:6-A=&EO;B<L"@DG9&%T86)A<V5?<V5R
M=F5R7V5D:71?9F]R;5]?;&5G96YD7V=E;F5R86PG(#T^("='96YE<F%L)RP*
M"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]P87-S=V]R9%]W87)N:6YG
M7W!O<W1G<F5S<6PG(#T^("=)9B!Y;W4@8VAA;F=E('1H92!L;V=I;B!O<B!P
M87-S=V]R9"!B96QO=RP@=&AE(%!O<W1G<F5344P@=7-E<B!A8V-O=6YT('=I
M=&@@861M:6YI<W1R871I=F4@<FEG:'1S('=I;&P@8F4@=7!D871E9"XG+`H)
M)V1A=&%B87-E7W-E<G9E<E]E9&ET7V9O<FU?7W!O<G0G(#T^("=0;W)T(&YU
M;6)E<B<L"@DG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?<&]R=%]H:6YT
M)R`]/B`G3&5A=F4@8FQA;FL@9F]R('1H92!D969A=6QT('!O<G0@;G5M8F5R
M)RPG9&%T86)A<V5?<V5R=F5R7V5D:71?9F]R;5]?=&%B)R`]/B`G1&%T86)A
M<V4@<V5R=F5R)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]T:71L
M95]N97<G(#T^("=.97<@9&%T86)A<V4@<V5R=F5R)RP*"2=D871A8F%S95]S
M97)V97)?961I=%]F;W)M7U]T:71L95]E9&ET)R`]/B`G1&%T86)A<V4@<V5R
M=F5R("4Q)RP*"2=D871A8F%S95]S97)V97)?961I=%]F;W)M7U]T>7!E)R`]
M/B`G1&%T86)A<V4@<V5R=F5R('1Y<&4G+`H))V1A=&%B87-E7W-E<G9E<E]E
M9&ET7V9O<FU?7W5N:7A?<V]C:V5T)R`]/B`G*&QO8V%L(&-O;FYE8W1I;VXI
M)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7V-O;G-U;'1?861M:6XG(#T^
M("=0;&5A<V4@8V]N=&%C="!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T;W(N)RP*
M"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?7V-O;FYE8W1I;VY?9F%I
M;&5D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C;VYT<F]L('1H:7,@9&%T
M86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E(&]F(&YE='=O<FL@<')O8FQE
M;7,N)RP*"2=D871A8F%S95]S97)V97)?97)R;W)?7VQA<W1?7W!E<FUI<W-I
M;VY?9&5N:65D)R`]/B`G5&AE(&QA<W0@871T96UP="!T;R!C;VYT<F]L('1H
M:7,@9&%T86)A<V4@<V5R=F5R(&9A:6QE9"!B96-A=7-E('1H92!S=7!P;&EE
M9"!A8V-O=6YT(&1O97,@;F]T('!O<W-E<W,@861M:6YI<W1R871I=F4@<')I
M=FEL96=E<RXG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?;&%S=%]?8W)E
M9&5N=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U<'!L>2!V86QI
M9"!A9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D(&)E9F]R92!0
M;&5S:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H))V1A=&%B87-E
M7W-E<G9E<E]E<G)O<E]?;&%S=%]?;W1H97)?97)R;W(G(#T^("=4:&4@;&%S
M="!A='1E;7!T('1O(&-O;G1R;VP@=&AI<R!D871A8F%S92!S97)V97(@9F%I
M;&5D+B<L"@DG9&%T86)A<V5?<V5R=F5R7V5R<F]R7U]R96%L7U]C;VYN96-T
M:6]N7V9A:6QE9"<@/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E
M<G9E<B!H87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P<F]B;&5M<SHG
M+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?<&5R;6ES<VEO;E]D
M96YI960G(#T^("=#;VYN96-T:6]N('1O('1H92!D871A8F%S92!S97)V97(@
M:&%S(&9A:6QE9"!B96-A=7-E('1H92!S=7!P;&EE9"!A8V-O=6YT(&1O97,@
M;F]T('!O<W-E<W,@861M:6YI<W1R871I=F4@<')I=FEL96=E<SHG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?<F5A;%]?9'5P;&EC871E7V]B:F5C="<@
M/3X@)T-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D(&)E8V%U<V4@;V8@82!N86UE(&-L87-H.B<L"@DG9&%T86)A<V5?<V5R
M=F5R7V5R<F]R7U]R96%L7U]U;F%C8V5P=&%B;&5?;F%M92<@/3X@)T-O;FYE
M8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I;&5D(&)E8V%U
M<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M93HG+`H))V1A=&%B87-E7W-E
M<G9E<E]E<G)O<E]?<F5A;%]?=6YA8V-E<'1A8FQE7W!A<W-W;W)D)R`]/B`G
M0V]N;F5C=&EO;B!T;R!T:&4@9&%T86)A<V4@<V5R=F5R(&AA<R!F86EL960@
M8F5C875S92!O9B!A;B!U;F%C8V5P=&%B;&4@<&%S<W=O<F0Z)RP*"2=D871A
M8F%S95]S97)V97)?97)R;W)?7W)E86Q?7V-R961E;G1I86QS7VYO=%]S970G
M(#T^(")0;&5S:R!C86YN;W0@8V]N;F5C="!T;R!T:&4@9&%T86)A<V4@<V5R
M=F5R(&)E8V%U<V4@=F%L:60@861M:6YI<W1R871O<B=S(&QO9VEN(&%N9"!P
M87-S=V]R9"!H879E(&YO="!B965N('-P96-I9FEE9"XB+`H))V1A=&%B87-E
M7W-E<G9E<E]E<G)O<E]?<F5A;%]?;W1H97)?97)R;W(G(#T^("=#;VYN96-T
M:6]N('1O('1H92!D871A8F%S92!S97)V97(@:&%S(&9A:6QE9#HG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?8V]N;F5C=&EO;E]F86EL960G
M(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H
M87,@9F%I;&5D(&)E8V%U<V4@;V8@;F5T=V]R:R!P<F]B;&5M<SHG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?<&5R;6ES<VEO;E]D96YI960G
M(#T^("=497-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H
M87,@9F%I;&5D(&)E8V%U<V4@=&AE('-U<'!L:65D(&%C8V]U;G0@9&]E<R!N
M;W0@<&]S<V5S<R!A9&UI;FES=')A=&EV92!P<FEV:6QE9V5S.B<L"@DG9&%T
M86)A<V5?<V5R=F5R7V5R<F]R7U]T97-T7U]D=7!L:6-A=&5?;V)J96-T)R`]
M/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A8F%S92!S97)V97(@:&%S
M(&9A:6QE9"!B96-A=7-E(&]F(&$@;F%M92!C;&%S:#HG+`H))V1A=&%B87-E
M7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A8FQE7VYA;64G(#T^("=4
M97-T(&-O;FYE8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I
M;&5D(&)E8V%U<V4@;V8@86X@:6YV86QI9"!O8FIE8W0@;F%M93HG+`H))V1A
M=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?=6YA8V-E<'1A8FQE7W!A<W-W
M;W)D)R`]/B`G5&5S="!C;VYN96-T:6]N('1O('1H92!D871A8F%S92!S97)V
M97(@:&%S(&9A:6QE9"!B96-A=7-E(&]F(&%N('5N86-C97!T86)L92!P87-S
M=V]R9#HG+`H))V1A=&%B87-E7W-E<G9E<E]E<G)O<E]?=&5S=%]?8W)E9&5N
M=&EA;'-?;F]T7W-E="<@/3X@(EEO=2!N965D('1O('-U<'!L>2!V86QI9"!A
M9&UI;FES=')A=&]R)W,@;&]G:6X@86YD('!A<W-W;W)D(&)E9F]R92!0;&5S
M:R!C86X@8V]N;F5C="!T;R!T:&ES('-E<G9E<BXB+`H))V1A=&%B87-E7W-E
M<G9E<E]E<G)O<E]?=&5S=%]?;W1H97)?97)R;W(G(#T^("=497-T(&-O;FYE
M8W1I;VX@=&\@=&AE(&1A=&%B87-E('-E<G9E<B!H87,@9F%I;&5D.B<L"@DG
M9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAE861E<B<@/3X@)T1A=&%B87-E('-E
M<G9E<G,G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]L87-T7V5R<F]R)R`]
M/B`G4R<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7W1Y<&4G(#T^("=397)V
M97(@='EP92<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7VAO<W0G(#T^("=(
M;W-T(&YA;64G+`H))V1A=&%B87-E7W-E<G9E<E]L:7-T7U]P;W)T)R`]/B`G
M4&]R="<L"@DG9&%T86)A<V5?<V5R=F5R7VQI<W1?7V1B8V]U;G0G(#T^("=$
M871A8F%S97,G+`H))V1B7U]C<F5A=&5?;F5W7V1B)R`]/B`B061D(&YE=R!D
M871A8F%S92(L"@DG9&)?7V1B7V%D9"<@/3X@(D%D9"!.97<@1&%T86)A<V4B
M+`H))V1B7U]D8E]F;W)?9&]M)R`]/B`B1&%T86)A<V5S(&9O<B!D;VUA:6X@
M)3$B+`H))V1B7U]D8E]I9%]U;F1E9FEN960G(#T^(")$871A8F%S92!I9"!I
M<R!U;F1E9FEN960N(BP*"2=D8E]?9&)?;F%M92<@/3X@(D1A=&%B87-E(&YA
M;64B+`H))V1B7U]D8E]N;W1?97AI<W0G(#T^(")$871A8F%S92!D;V5S(&YO
M="!E>&ES="XB+`H))V1B7U]D8E]T>7!E)R`]/B`B5'EP92(L"@DG9&)?7V1B
M7W-E<G9E<B<@/3X@(D1A=&%B87-E('-E<G9E<B(L"@DG9&)?<V5R=F5R7VYO
M=%]E>&ES="<@/3X@(D1A=&%B87-E('-E<G9E<B!D;V5S(&YO="!E>&ES="XB
M+`H))V1B7U]D8E]U<V5R7VYO=%]E>&ES="<@/3X@(D1A=&%B87-E('5S97(@
M9&]E<R!N;W0@97AI<W0N(BP*"2=D8E]?9&]M86EN7VYO=%]E>&ES="<@/3X@
M(D1O;6%I;B!D;V5S(&YO="!E>&ES="XB+`H))V1B7U]E;G1E<E]D8E]N86UE
M)R`]/B`B16YT97(@;F5W(&1A=&%B87-E(&YA;64N(BP*"2=D8E]?:6YV86QI
M9%]D8E]I9"<@/3X@(D1A=&%B87-E(&ED96YT:69I97(@:7,@:6YV86QI9"XB
M+`H))V1B7U]I;G9A;&ED7V1B7VYA;64G(#T^(")$871A8F%S92!N86UE(&ES
M(&EN=F%L:60N(%1H92!D871A8F%S92!N86UE('-H;W5L9"!C;VYT86EN(&]N
M;'D@3&%T:6X@86QP:&%B970@<WEM8F]L<RP@9&EG:71S(&]R(&1A<V@N($ET
M(&-A;FYO="!B92!L;VYG97(@=&AA;B`V,R!S>6UB;VQS+B(L"@DG9&)?7VUA
M>%]D8E]R96%C:&5D7V9O<E]D;VTG(#T^(")4:&4@;&EM:70@;VX@;G5M8F5R
M(&]F(&1A=&%B87-E<R!I<R!R96%C:&5D(&9O<B!T:&ES(&1O;6%I;BXB+`H)
M)V1B7U]N;VYD969A=6QT7W-E<G9E<E]N;W1?86QL;W=E9"<@/3X@)T]N;'D@
M=&AE(&%D;6EN:7-T<F%T;W(@8V%N(&-H;V]S92!S97)V97)S(&9O<B!D871A
M8F%S92!H;W-T:6YG+B<L"@DG9&)?7W!O<W1G<F5S7VYO=%]C;VYN96-T7V9O
M<E]A9&UI;B<@/3X@(E5N86)L92!T;R!C;VYN96-T('1O(%!O<W1G<F5344PN
M($5N86)L92!0;W-T9W)E4U%,('-U<'!O<G0@;VX@=&AE('-E<G9E<B!A9&UI
M;FES=')A=&EO;B!P86=E+B(L"@DG9&)?7W!O<W1G<F5S7VYO=%]C;VYN96-T
M7V9O<E]C;&EE;G0G(#T^(")5;F%B;&4@=&\@8V]N;F5C="!T;R!0;W-T9W)E
M4U%,+B!2969E<B!T;R!Y;W5R('-Y<W1E;2!A9&UI;FES=')A=&]R(&9O<B!H
M96QP+B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6XG(#T^(")4:&4@9F]L
M;&]W:6YG(&1A=&%B87-E<R!W:6QL(&)E(')E;6]V960@9G)O;2!T:&4@9&]M
M86EN("4Q.B(L"@DG9&)?7W)E;6]V95]D8E]O;E]D;VUA:6Y?;V9?8VPG(#T^
M(")4:&4@9F]L;&]W:6YG(&1A=&%B87-E<R!F;W(@9&]M86EN("4R(&]W;F5D
M(&)Y(&-L:65N="`E,2!W:6QL(&)E(')E;6]V960Z(BP*"2=D8E]?<F5M;W9E
M7V1B7VQI;FME9%]R97-O=7)C92<@/3X@)U1H:7,@9&%T86)A<V4@:7,@:6X@
M=7-E(&)Y(&$@<VET92!A<'!L:6-A=&EO;BX@270@8V%N(&)E(')E;6]V960@
M;VYL>2!A9G1E<B!U;FEN<W1A;&QI;F<@=&AI<R!S:71E(&%P<&QI8V%T:6]N
M+B<L"@DG9&)?7W)E;6]V95]D8E]U<V5R<R<@/3X@(E1H92!F;VQL;W=I;F<@
M=7-E<G,@;V8@9&%T86)A<V4@)3(@:6X@9&]M86EN("4Q('=I;&P@8F4@<F5M
M;W9E9#HB+`H))V1B7U]R96UO=F5?9&)?=7-E<G-?;V9?8VPG(#T^(")4:&4@
M9F]L;&]W:6YG('5S97)S(&]F(&1A=&%B87-E("4S(&EN(&1O;6%I;B`E,B!O
M=VYE9"!B>2!T:&4@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB+`H))V1B
M7U]S96QE8W1?9&)?9F]R7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@9&%T86)A
M<V5S('1O(&)E(')E;6]V960N(BP*"2=D8E]?<V5L96-T7V1B7W5S97)S7V9O
M<E]R96UO=F4G(#T^(")396QE8W0@=&AE(&1A=&%B87-E('5S97)S('1O(&)E
M(')E;6]V960N(BP*"2=D8E]?=6YA8FQE7V-R96%T95]D8E]U<V5R)R`]/B`B
M56YA8FQE('1O(&-R96%T92!T:&4@9&%T86)A<V4@=7-E<CH@)3$B+`H))V1B
M7U]U;F%B;&5?9&5F:6YE7V1B7VYA;64G(#T^(")5;F%B;&4@=&\@9&5F:6YE
M('1H92!D871A8F%S92!N86UE.B`E,2(L"@DG9&)?7W5N86)L95]D969I;F5?
M9&)?=7-E<B<@/3X@(E5N86)L92!T;R!D969I;F4@=&AE(&1A=&%B87-E('5S
M97(Z("4Q(BP*"2=D8E]?=6YA8FQE7V1E9FEN95]D8E]U<V5R<R<@/3X@(E5N
M86)L92!T;R!D969I;F4@9&%T86)A<V4@=7-E<G,Z("4Q(BP*"2=D8E]?=6YA
M8FQE7W-E;&5C=%]D;VU?;F%M92<@/3X@(E5N86)L92!T;R!S96QE8W0@9&]M
M86EN(&YA;64Z("4Q(BP*"2=D8E]E9&ET7U]D8E]F;W)?9&]M)R`]/B`B57-E
M<G,@9F]R(&1A=&%B87-E("4Q(&]N(&1O;6%I;B`E,B(L"@DG9&)?961I=%]?
M:6YV86QI9%]D8E]N86UE)R`]/B`B5&AE(&1A=&%B87-E(&YA;64@:7,@:6YV
M86QI9"XB+`H))V1B7V5D:71?7VYO7W5S97)S)R`]/B`B5&AE<F4@87)E(&YO
M('5S97)S('=I=&@@8W)E9&5N=&EA;',@9F]R('1H:7,@9&%T86)A<V4N(BP*
M"2=D8E]E9&ET7U]U;F%B;&5?9&5F:6YE7V1B7W5S<G,G(#T^(")5;F%B;&4@
M=&\@9&5F:6YE('1H92!D871A8F%S92!U<V5R<SH@)3$B+`H))V1B7V5D:71?
M7W5N86)L95]S96QE8W1?9&)?=7-R)R`]/B`B56YA8FQE('1O('-E;&5C="!T
M:&4@9&%T86)A<V4@=7-E<BXB+`H))V1B7V5D:71?7V1B7W5S97)?<&%S<W=O
M<F1?9F]R7R<@/3X@(E!L96%S92!T>7!E(&EN('1H92!P87-S=V]R9"!T;R!L
M;V<@:6X@87,@=&AE(&1A=&%B87-E('5S97(@)3$@(BP*"2=D8E]L:7-T7U]T
M86)?=&ET;&5?9&)?='EP92<@/3X@(E0B+`H))V1B7W5S<E]E9&ET7U]A9&1?
M9&)?=7-R)R`]/B`B5&AE(&1A=&%B87-E('5S97(@861D:71I;VXB+`H))V1B
M7W5S<E]E9&ET7U]D8E]U<W)?;F%M92<@/3X@(D1A=&%B87-E('5S97(@;F%M
M92(L"@DG9&)?=7-R7V5D:71?7V5D:71?9&)?=7-R)R`]/B`B4V5T('5P(&-R
M961E;G1I86QS(&9O<B!D871A8F%S92!U<V5R(&%C8V]U;G0B+`H))V1B7W5S
M<E]E9&ET7U]F;W)?9&(G(#T^("(@:6X@)3$@9&%T86)A<V4B+`H))V1B7W5S
M<E]E9&ET7U]N;W1?8W)E871E7W!A<W,G(#T^(")4:&ES(&]P97)A=&EO;B!W
M:6QL(')E<W5L="!I;B!C<F5A=&EN9R!A(&1A=&%B87-E('5S97(@86-C;W5N
M="!W:71H;W5T('!A<W-W;W)D+EQN1&\@>6]U('=I<V@@=&\@8W)E871E(&$@
M=7-E<B!W:71H;W5T(&%S<VEG;FEN9R!A('!A<W-W;W)D/R(L"@DG9&)U<V5R
M7U]O;FQY7V]N95]U<V5R7V-A;E]B95]D969A=6QT)R`]/B`B3VYL>2!O;F4@
M=7-E<B!C86X@8F4@<V5T(&%S(&1E9F%U;'0N(BP*"2=D8E]S97)V97)?7V-A
M;FYO=%]D96QE=&5?9&5F875L="<@/3X@(E1H92!D969A=6QT(&1A=&%B87-E
M('-E<G9E<B!C86YN;W0@8F4@9&5L971E9"XB+`H))V1B7W-E<G9E<E]?8V%N
M;F]T7V1E;&5T95]L;V-A;"<@/3X@(E1H92!L;V-A;"!D871A8F%S92!S97)V
M97(@8V%N;F]T(&)E(&1E;&5T960N(BP*"2=D8E]S97)V97)?7V-A;FYO=%]D
M96QE=&5?=7-E9"<@/3X@)T$@9&%T86)A<V4@<V5R=F5R(&-A;FYO="!B92!D
M96QE=&5D('=H:6QE('1H97)E(&%R92!D871A8F%S97,@:&]S=&5D(&]N(&ET
M+B<L"@DG9&5M;U]?9&ES86)L961?:6Y?9&5M;R<@/3X@(E1H:7,@;W!E<F%T
M:6]N(&ES(&YO="!S=7!P;W)T960@:6X@=&AE(&1E;6\@=F5R<VEO;BXB+`H)
M)V1N<U]?861D7V1N<U]M87-T97)?<V5R=F5R)R`]/B`B061D($1.4R!M87-T
M97(@<V5R=F5R(BP*"2=D;G-?7V%D9%]D;G-?<F5C;W)D)R`]/B`B061D(')E
M<V]U<F-E(')E8V]R9"(L"@DG9&YS7U]A9&1?;F%M97-E<G9E<B<@/3X@(D%D
M9"!N86UE<V5R=F5R(BP*"2=D;G-?7V1N<U]R96-O<F1?;F]T7V5X:7-T)R`]
M/B`B5&AE<F4@:7,@;F\@<W5C:"!R97-O=7)C92!R96-O<F0@:6X@=&AE('IO
M;F4N(BP*"2=D;G-?7V1N<U]Z;VYE7V9O<E]D;VUA:6XG(#T^(")$3E,@>F]N
M92!F;W(@=&AE(&1O;6%I;B(L"@DG9&YS7U]D;G-?>F]N95]L96=E;F0G(#T^
M("=297-O=7)C92!R96-O<F1S)RP*"2=D;G-?7V1N<U]Z;VYE7VUA<W1E<E]T
M:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@82!P<FEM87)Y(&YA;65S
M97)V97(@9F]R('1H92!$3E,@>F]N92`E,2<L"@DG9&YS7U]D;G-?>F]N95]S
M;&%V95]T:71L92<@/3X@)U1H:7,@<V5R=F5R(&%C=',@87,@82!S96-O;F1A
M<GD@;F%M97-E<G9E<B!F;W(@=&AE($1.4R!Z;VYE("4Q)RP*"2=D;G-?7V1N
M<U]Z;VYE7V]F9E]T:71L92<@/3X@)TYA;65S97)V97)S(&9O<B!T:&4@1$Y3
M('IO;F4@)3$G+`H))V1N<U]?861D7V1N<U]R96-O<F1?;6%S=&5R7W1I=&QE
M)R`]/B`G061D(')E<V]U<F-E(')E8V]R9"!T;R!T:&4@>F]N92<L"@DG9&YS
M7U]A9&1?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@)T%D9"!P<FEM87)Y
M($1.4R!S97)V97(G+`H))V1N<U]?861D7V1N<U]R96-O<F1?;V9F7W1I=&QE
M)R`]/B`G061D(&YA;65S97)V97(G+`H))V1N<U]?961I=%]D;G-?<F5C;W)D
M7VUA<W1E<E]T:71L92<@/3X@)T5D:70@<F5S;W5R8V4@<F5C;W)D)RP*"2=D
M;G-?7V5D:71?9&YS7W)E8V]R9%]S;&%V95]T:71L92<@/3X@)T5D:70@<V5R
M=F5R(')E8V]R9"<L"@DG9&YS7U]E9&ET7V1N<U]R96-O<F1?;V9F7W1I=&QE
M)R`]/B`G161I="!N86UE<V5R=F5R)RP*"2=D;G-?7V1N<U]R96-O<F1?:6YV
M86QI9%]V86QU97,G(#T^("=4:&5R92!A<F4@:6YC;W)R96-T('!A<F%M971E
M<B!V86QU97,N)RP*"2=D;G-?7V1N<U]Z;VYE7VEN=F%L:61?=F%L=65S)R`]
M/B`G5&AE<F4@87)E(&EN8V]R<F5C="!P87)A;65T97(@=F%L=65S+B<L"@DG
M9&YS7U]D;G-?<V]A7W1I=&QE)R`]/B`G4T]!(%!R969E<F5N8V5S)RP*"2=D
M;G-?7V1N<U]S;V%?;&5G96YD)R`]/B`G4T]!(%!R969E<F5N8V5S)RP*"2=D
M;G-?7V1N<U]S;V%?='1L)R`]/B`G5%1,)RP*"2=D;G-?7V1N<U]S;V%?<F5F
M<F5S:"<@/3X@)U)E9G)E<V@G+`H))V1N<U]?9&YS7W-O85]R971R>2<@/3X@
M)U)E=')Y)RP*"2=D;G-?7V1N<U]S;V%?97AP:7)E)R`]/B`G17AP:7)E)RP*
M"2=D;G-?7V1N<U]S;V%?;6EN:6UU;2<@/3X@)TUI;FEM=6TG+`H))V1N<U]?
M9&YS7W-O85]T=&Q?97)R;W(G(#T^("=45$P@=F%L=64@:7,@:6YV86QI9"X@
M270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?
M7V1N<U]S;V%?<F5F<F5S:%]E<G)O<B<@/3X@)U)E9G)E<V@@=F%L=64@:7,@
M:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@=&\@-C@@>65A<G,N
M)RP*"2=D;G-?7V1N<U]S;V%?<F5T<GE?97)R;W(G(#T^("=2971R>2!V86QU
M92!I<R!I;G9A;&ED+B!)="!C86X@8F4@9G)O;2`Q('-E8V]N9"!T;R`V."!Y
M96%R<RXG+`H))V1N<U]?9&YS7W-O85]E>'!I<F5?97)R;W(G(#T^("=%>'!I
M<F4@=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@,2!S96-O;F0@
M=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]S;V%?;6EN:6UU;5]E<G)O<B<@
M/3X@)TUI;FEM=6T@=F%L=64@:7,@:6YV86QI9"X@270@8V%N(&)E(&9R;VT@
M,2!S96-O;F0@=&\@-C@@>65A<G,N)RP*"2=D;G-?7V1N<U]D969A=6QT7W1I
M=&QE)R`]/B`G4F5S=&]R92!T:&4@1$Y3('IO;F4N)RP*"2=D;G-?7V1N<U]D
M969A=6QT7VQE9V5N9"<@/3X@)UIO;F4@<F5S=&]R:6YG(&]P=&EO;G,N)RP*
M"2=D;G-?7V1N<U]D969A=6QT7W1E>'0G(#T^("=#:&]O<V4@=&AE('-E='1I
M;F=S(&9O<B!R97-T;W)I;F<@=&AE($1.4R!Z;VYE+"!C;VYF:7)M('1H96T@
M86YD(&-L:6-K($]++B<L"@DG9&YS7U]D;G-?9&5F875L=%]C;VYF:7)M)R`]
M/B`G0V]N9FER;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*"2=D;G-?7V1N
M<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A<V4@8V]N9FER
M;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4N)RP*"@DG9&YS7W1?7V1N<U]D969A
M=6QT7W1I=&QE)R`]/B`G4F5S=&]R92!T:&4@;W)I9VEN86P@1$Y3('IO;F4@
M=&5M<&QA=&4N)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?;&5G96YD)R`]/B`G
M4F5S=&]R:6YG(&]P=&EO;G,N)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?=&5X
M="<@/3X@)T-H;V]S92!T:&4@<V5T=&EN9W,@9F]R(')E<W1O<FEN9R!T:&4@
M1$Y3('IO;F4@=&5M<&QA=&4L(&-O;F9I<FT@=&AE;2!A;F0@8VQI8VL@3TLN
M)RP*"2=D;G-?=%]?9&YS7V1E9F%U;'1?8V]N9FER;2<@/3X@)T-O;F9I<FT@
M<F5S=&]R:6YG(&]F($1.4R!Z;VYE('1E;7!L871E+B<L"@DG9&YS7W1?7V1N
M<U]D969A=6QT7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A<V4@8V]N9FER
M;2!R97-T;W)I;F<@;V8@1$Y3('IO;F4@=&5M<&QA=&4N)RP*"2=D;G-?=%]?
M9&YS7WIO;F5?;V9F7W)E;6]V95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@
M<F5S;W5R8V4@<F5C;W)D<R!F;W(@1$Y3('IO;F4@=&5M<&QA=&4@=VEL;"!B
M92!R96UO=F5D.B(L"@DG9&YS7W1?7V1N<U]Z;VYE7VUA<W1E<E]R96UO=F5?
M=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E8V]R9',@=VEL
M;"!B92!R96UO=F5D(&9R;VT@1$Y3('IO;F4@=&5M<&QA=&4Z(BP*"2=D;G-?
M=%]?861D7V1N<U]R96-O<F1?;6%S=&5R7W1I=&QE)R`]/B`G061D(')E<V]U
M<F-E(')E8V]R9"!T;R!T:&4@>F]N92!T96UP;&%T92<L"@DG9&YS7W1?7V%D
M9%]D;G-?<F5C;W)D7V]F9E]T:71L92<@/3X@)T%D9"!N86UE<V5R=F5R)RP*
M"2=D;G-?=%]?961I=%]D;G-?<F5C;W)D7VUA<W1E<E]T:71L92<@/3X@)T5D
M:70@<F5S;W5R8V4@<F5C;W)D)RP*"2=D;G-?=%]?961I=%]D;G-?<F5C;W)D
M7V]F9E]T:71L92<@/3X@)T5D:70@;F%M97-E<G9E<B<L"@DG9&YS7W1?7W-E
M;&5C=%]R96-O<F1?=&]?<F5M;W9E)R`]/B`G4V5L96-T(')E8V]R9',@=&\@
M8F4@<F5M;W9E9"!F<F]M('1H92!$3E,@=&5M<&QA=&4N)RP*"@DG9&YS7U]U
M;FET7W-E8V]N9',G(#T^("=S96-O;F1S)RP*"2=D;G-?7W5N:71?;6EN=71E
M<R<@/3X@)VUI;G5T97,G+`H))V1N<U]?=6YI=%]H;W5R<R<@/3X@)VAO=7)S
M)RP*"2=D;G-?7W5N:71?9&%Y<R<@/3X@)V1A>7,G+`H))V1N<U]?=6YI=%]W
M965K<R<@/3X@)W=E96MS)RP*"2=D;G-?7V1N<U]Z;VYE7V]F9E]R96UO=F5?
M=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E<V]U<F-E(')E8V]R9',@=VEL
M;"!B92!R96UO=F5D(&9R;VT@=&AE('IO;F4@)3$Z(BP*"2=D;G-?7V1N<U]Z
M;VYE7VUA<W1E<E]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG(')E
M<V]U<F-E(')E8V]R9',@9F]R($1.4R!Z;VYE("4Q('=I;&P@8F4@<F5M;W9E
M9#HB+`H))V1N<U]?9&YS7WIO;F5?<VQA=F5?<F5M;W9E7W1I=&QE)R`]/B`B
M5&AE(&9O;&QO=VEN9R!P<FEM87)Y(&YA;65S97)V97(@<F5C;W)D<R!F;W(@
M)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&YS7U]D;G-?>F]N95]S=&%T=7,G
M(#T^(")$3E,@>F]N92!S=&%T=7,N(BP*"2=D;G-?7V1N<U]Z;VYE7W1E;7!L
M871E)R`]/B`B1$Y3('IO;F4@=&5M<&QA=&4B+`H))V1N<U]?9&YS7WIO;F5?
M=&5M<&QA=&5?<F5S=&]R95]D969A=6QT)R`]/B`B4F5S=&]R92!T:&4@9&5F
M875L="!$3E,@>F]N92!T96UP;&%T92(L"@DG9&YS7U]D;G-?>F]N95]T96UP
M;&%T95]R97-T;W)E7V1E9F%U;'1?8V]N9FER;2<@/3X@(E)E<W1O<FEN9R!T
M:&4@<W1A;F1A<F0@1$Y3('IO;F4@=&5M<&QA=&4@=VEL;"!D:7-C87)D('1H
M92!C=7)R96YT;'D@=7-E9"!T96UP;&%T92P@<')O8V5E9"!A;GEW87D_(BP*
M"2=D;G-?7V1N<U]Z;VYE7W1E;7!L871E7W)E<W1O<F5?9&5F875L=%]E<G)O
M<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!T:&4@1$Y3('IO;F4@=&5M<&QA=&4Z
M(BP*"2=D;G-?7VAO<W0G(#T^(")(;W-T(BP*"2=D;G-?7VEN=F%L:61?:7!?
M861D<F5S<R<@/3X@(DE0(&%D9')E<W,@;V8@;F5W(&UA<W1E<B!$3E,@<V5R
M=F5R(&ES(&EN=F%L:60@;W(@96UP='DN(BP*"2=D;G-?7VEP7V%D9')E<W,G
M(#T^("))4"!!9&1R97-S(BP*"2=D;G-?7VUA<W1E<E]D;G-?='EP92<@/3X@
M(FES(&$@;6%S=&5R($1.4R!S97)V97(B+`H))V1N<U]?;6%S=&5R<R<@/3X@
M(D1.4R!M87-T97(@<V5R=F5R<R(L"@DG9&YS7U]S;V%?;6EN:6UU;5]T;V]?
M;&%R9V4G(#T^("=#86-H:6YG(&YE9V%T:79E(')E<W!O;G-E<R!F;W(@;6]R
M92!T:&%N('1H<F5E(&AO=7)S(&ES(&YO="!R96-O;6UE;F1E9"XG+`H))V1N
M<U]?<V5L96-T7VUA<W1E<G-?=&]?<F5M;W9E)R`]/B`B4V5L96-T(')E8V]R
M9',@=&\@8F4@<F5M;W9E9"XB+`H))V1N<U]?<V5L96-T7W1E;7!L871E7W)E
M8V]R9%]T;U]R96UO=F4G(#T^("=396QE8W0@<F5C;W)D<R!T;R!B92!R96UO
M=F5D+B<L"@DG9&YS7U]S96QE8W1?8V]M;6]N7V%C;%]R96-O<F1?=&]?<F5M
M;W9E)R`]/B`G4V5L96-T($%#3"!R96-O<F1S(&9O<B!R96UO=FEN9RXG+`H)
M)V1N<U]?<V5L96-T7W)E8V]R9%]T;U]R96UO=F4G(#T^("=396QE8W0@<F5S
M;W5R8V4@<F5C;W)D<R!T;R!B92!R96UO=F5D+B<L"@DG9&YS7U]N86UE<V5R
M=F5R<U]F;W)?9&]M86EN)R`]/B`B3F%M97-E<G9E<G,@9F]R('1H92!D;VUA
M:6XB+`H))V1N<U]?;G,G(#T^(").86UE('-E<G9E<B(L"@DG9&YS7U]N<U]R
M96-O<F0G(#T^(").86UE('-E<G9E<G,B+`H))V1N<U]?<F5M;W9E7V1N<U]M
M87-T97)S7V]N7V1O;6%I;B<@/3X@(E1H92!F;VQL;W=I;F<@1$Y3(&UA<W1E
M<B!S97)V97)S(&9O<B!D;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q('=I
M;&P@8F4@<F5M;W9E9#HB+`H))V1N<U]?<F5M;W9E7V1N<U]Z;VYE7V]F7V1O
M;6%I;E]?)R`]/B`B1$Y3(')E8V]R9',@<F5M;W9A;"!F<F]M(&1O;6%I;B`E
M,2(L"@DG9&YS7U]R96UO=F5?9&YS7WIO;F5?=&5M<&QA=&5?7R<@/3X@(E1H
M92!F;VQL;W=I;F<@<F5S;W5R8V4@<F5C;W)D<R!W:6QL(&)E(')E;6]V960@
M9G)O;2!T:&4@=&5M<&QA=&4Z(BP*"2=D;G-?7W)E;6]V95]C;VUM;VY?86-L
M7W)E8V]R9"<@/3X@(E1H92!F;VQL;W=I;F<@04-,(')E8V]R9',@=VEL;"!B
M92!R96UO=F5D(BP*"2=D;G-?7W)E;6]V95]T:&ES7V1N<U]R96-O<F0_)R`]
M/B`B07)E('EO=2!S=7)E('EO=2!W:7-H('1O(')E;6]V92!T:&ES($1.4R!R
M96-O<F0_(BP*"2=D;G-?7W)E<W1O<F5?9&5F875L="<@/3X@(E)E<W1O<FEN
M9R!T:&4@1$Y3('IO;F4@8GD@=&AE('1E;7!L871E(BP*"2=D;G-?7W)E<W1O
M<F5?9&5F875L=%]C;VYF:7)M)R`]/B`B4F5S=&]R:6YG('1H92!$3E,@>F]N
M92!W:6QL(&1I<V-A<F0@=&AE(&-U<G)E;G0@1$Y3('IO;F4@8V]N9FEG=7)A
M=&EO;BP@<')O8V5E9"!A;GEW87D_(BP*"2=D;G-?7W)E<W1O<F5?9&5F875L
M=%]E<G)O<B<@/3X@(D5R<F]R(')E<W1O<FEN9R!$3E,@>F]N93HB+`H))V1N
M<U]?<VQA=F5?9&YS7W1Y<&4G(#T^(")I<R!A('-E8V]N9&%R>2!N86UE('-E
M<G9E<B(L"@DG9&YS7U]S=6)D;VUA:6Y?9&YS7W)E8U]R96UO=F5D)R`]/B`B
M5&AE($$@<F5C;W)D(&AA<R!B965N(')E;6]V960@9G)O;2!T:&4@<W5B9&]M
M86EN('IO;F4@)3$B+`H))V1N<U]?='EP92<@/3X@(E)E8V]R9"!T>7!E(BP*
M"2=D;G-?7W5N86)L95]A8W1I=F%T92]D96%C=&EV871E7V1N<R<@/3X@(E5N
M86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E($1.4SH@)3$B+`H))V1N<U]?
M=6YA8FQE7V%D9%]D;G-?;6%S=&5R7V1U<&QI8V%T95]E;G1R>2<@/3X@(E5N
M86)L92!T;R!A9&0@1$Y3(&UA<W1E<B!S97)V97(Z(&1U<&QI8V%T92!E;G1R
M>2XB+`H))V1N<U]?=6YA8FQE7V1E9FEN95]D;G-?<F5C;W)D)R`]/B`B56YA
M8FQE('1O(&1E9FEN92!T:&4@1$Y3(')E8V]R9#H@)3$B+`H))V1N<U]?=6YA
M8FQE7V=E=%]D;G-?=&5M<&QA=&5?<W1A='5S)R`]/B`B56YA8FQE('1O(')E
M=')I979E('1H92!$3E,@=&5M<&QA=&4@<W1A='5S+B(L"@DG9&YS7U]U;F%B
M;&5?<F5M;W9E7V1N<U]R96,G(#T^(")5;F%B;&4@=&\@<F5M;W9E('1H92!$
M3E,@<F5C;W)D.B`E,2(L"@DG9&YS7U]V86PG(#T^(")686QU92(L"@DG9&YS
M7U]W87)N:6YG<U]?)R`]/B`B5&AE(')E<W5L="!O9B!$3E,@>F]N92!M;V1I
M9FEC871I;VXZ(BP*"2=D;G-?7WEO=5]N;W1?:&%V95]P97)M7VUA;F%G95]D
M;G,G(#T^(")9;W4@9&\@;F]T(&AA=F4@<&5R;6ES<VEO;B!T;R!M86YA9V4@
M=&AE($1.4R!Z;VYE(&9O<B!T:&ES(&1O;6%I;BXB+`H))V1N<U]?>F]N95]R
M96-O<F0G(#T^(")$3E,@<F5C;W)D<R(L"@DG9&YS7U]D;G-?<')E9F5R96YC
M97-?9F]R;2<@/3X@)T1.4R!P<F5F97)E;F-E<R<L"@DG9&YS7U]D;G-?<F5C
M=7)S:6]N7W-E='1I;F=S)R`]/B`G1$Y3(')E8W5R<VEO;B!S971T:6YG<R<L
M"@DG9&YS7U]A;&QO=U]R96-U<G-I;VXG(#T^("=!;&QO=R!R96-U<G-I;VXG
M+`H))V1N<U]A9&1?7V%D9%]R96-?9F]R7WIO;F4G(#T^(")!9&0@)3$@9F]R
M('IO;F4@)3(B+`H))V1N<U]A9&1?7V-A;F]N:6-A;%]D;VU?;F%M95]I<U]I
M;G9A;&ED)R`]/B`B0V%N;VYI8V%L(&1O;6%I;B!N86UE(&ES(&EN=F%L:60N
M(BP*"2=D;G-?861D7U]E;G1E<E]C86YO;FEC86Q?;F%M92<@/3X@(D5N=&5R
M(&$@8V%N;VYI8V%L(&YA;64B+`H))V1N<U]A9&1?7V5N=&5R7V1O;5]N86UE
M)R`]/B`B16YT97(@9&]M86EN(&YA;64B+`H))V1N<U]A9&1?7V5N=&5R7VEP
M7V%D9')E<W,G(#T^(")%;G1E<B!)4"!A9&1R97-S(BP*"2=D;G-?861D7U]E
M;G1E<E]I<%]M87-K)R`]/B`B16YT97(@25`O;6%S:R(L"@DG9&YS7V%D9%]?
M96YT97)?;6%I;%]D;VUA:6XG(#T^(")%;G1E<B!M86EL(&1O;6%I;B(L"@DG
M9&YS7V%D9%]?96YT97)?;6%I;%]E>&-H86YG97(G(#T^(")%;G1E<B!M86EL
M(&5X8VAA;F=E<B(L"@DG9&YS7V%D9%]?96YT97)?;F%M97-E<G9E<B<@/3X@
M(D5N=&5R(&YA;65S97)V97(B+`H))V1N<U]A9&1?7V5N=&5R7W1X=%]R96-O
M<F0G(#T^(")%;G1E<B!46%0@<F5C;W)D(BP*"2=D;G-?861D7U]I;G9A;&ED
M7VEP)R`]/B`B25`@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG9&YS7V%D9%]?
M;&]W)R`]/B`B;&]W(BP*"2=D;G-?861D7U]M86EL7V1O;5]N86UE7VES7VEN
M=F%L:60G(#T^(")-86EL(&1O;6%I;B!N86UE(&ES(&EN=F%L:60N(BP*"2=D
M;G-?861D7U]N86UE<V5R=F5R7VES7VEN=F%L:60G(#T^(").86UE<V5R=F5R
M(&ES(&EN=F%L:60N(BP*"2=D;G-?861D7U]R96-O<F0G(#T^("(E,2!R96-O
M<F0B+`H))V1N<U]A9&1?7W-E;&5C=%]P<F5F97)?9F]R7VUA:6Q?97AC:&%N
M9V5?<V5R=F5R)R`]/B`B4W!E8VEF>2!P<FEO<FET>2!O9B!M86EL(&5X8VAA
M;F=E('-E<G9E<B(L"@DG9&YS7V%D9%]?=6YA8FQE7VEN<V5R=%]N97=?9&YS
M7W)E8R<@/3X@(E5N86)L92!T;R!I;G-E<G0@;F5W($1.4R!R96-O<F0Z("4Q
M(BP*"2=D;G-?861D7U]V97)Y7VAI9V@G(#T^(")V97)Y(&AI9V@B+`H))V1N
M<U]C:&5C:U]?=&5S=%]D;G-?>F]N92<@/3X@(E1E<W0@1$Y3('IO;F4@)3$@
M;VX@)3(B+`H))V1N<U]C:&5C:U]?=6YA8FQE7V=E=%]D;VU?<')O<&5R=&EE
M<R<@/3X@(E5N86)L92!T;R!R971R:65V92!D;VUA:6X@<')O<&5R=&EE<SH@
M)3$B+`H))V1O;5]C=')L7U]A;&QO=V5D)R`]/B`B06QL;W=E9"(L"@DG9&]M
M7V-T<FQ?7V1B)R`]/B`B1&%T86)A<V5S(BP*"2=D;VU?8W1R;%]?9&5L7VAS
M=%]O;E]D;VTG(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E
M(&AO<W1I;F<@8V]N9FEG=7)A=&EO;B!F<F]M(&1O;6%I;B`E,3\B+`H))V1O
M;5]C=')L7U]D:7-K7W-P86-E)R`]/B`B1&ES:R!S<&%C92(L"@DG9&]M7V-T
M<FQ?7V1O;5]A9&TG(#T^(")$;VUA:6X@)3$@;V8@)3(B+`H))V1O;5]C=')L
M7U]D;VU?8VPG(#T^(")$;VUA:6X@)3$B+`H))V1O;5]C=')L7U]D;VUA:6Y?
M:&%S7V9O<G=A<F1I;F=?=VET:%]U;F1E9FEN961?9G=D7W5R;"<@/3X@(D1O
M;6%I;B!H87,@9F]R=V%R9&EN9R!S970@=7`@=VET:"!U;F1E9FEN960@9F]R
M=V%R9&EN9R!54DPB+`H))V1O;5]C=')L7U]D;VUA:6Y?:&%S7V9R86UE7V9O
M<G=A<F1I;F<G(#T^(")$;VUA:6X@:&%S(&9R86UE(&9O<G=A<F1I;F<@=&\@
M=&AE(%523"`E,2(L"@DG9&]M7V-T<FQ?7V1O;6%I;E]H87-?;F]?:&]S=&EN
M9R<@/3X@(D1O;6%I;B!H87,@;F\@:&]S=&EN9R!C;VYF:6=U<F5D(BP*"2=D
M;VU?8W1R;%]?9&]M86EN7VAA<U]P:'ES:6-A;%]H;W-T:6YG)R`]/B`B1&]M
M86EN(&AA<R!P:'ES:6-A;"!H;W-T:6YG(&]N($E0("4Q(BP*"2=D;VU?8W1R
M;%]?9&]M86EN7VAA<U]S=&%N9&%R9%]F;W)W87)D:6YG)R`]/B`B1&]M86EN
M(&AA<R!S=&%N9&%R9"!F;W)W87)D:6YG('1O('1H92!54DP@)3$B+`H))V1O
M;5]C=')L7U]M86EL;&ES=',G(#T^(")-86EL:6YG(&QI<W1S(BP*"2=D;VU?
M8W1R;%]?;6)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=D;VU?8W1R;%]?;6<G
M(#T^(")-86EL(&=R;W5P<R(L"@DG9&]M7V-T<FQ?7W)E9&ER)R`]/B`B4F5D
M:7)E8W1S(BP*"2=D;VU?8W1R;%]?<F5S;W5R8V5?;F%M92<@/3X@(E)E<V]U
M<F-E(BP*"2=D;VU?8W1R;%]?<F5S<"<@/3X@(D%U=&]R97-P;VYD97)S(BP*
M"2=D;VU?8W1R;%]?<W5B9&]M)R`]/B`B4W5B9&]M86EN<R(L"@DG9&]M7V-T
M<FQ?7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=D;VU?8W1R;%]?=6YA8FQE
M7V%C=&EV871E+V1E86-T:79A=&5?9&]M)R`]/B`B56YA8FQE('1O(&%C=&EV
M871E+V1E86-T:79A=&4@9&]M86EN.B`E,2(L"@DG9&]M7V-T<FQ?7W5S960G
M(#T^(")5<V5D(BP*"2=D;VU?8W1R;%]?=V5B87!P<R<@/3X@(DIA=F$@87!P
M;&EC871I;VYS(BP*"2=D;VU?8W1R;%]?>6]U7W=A;G1?8VAA;F=E7W1H95]S
M=&%T=7-?;V9?=&AE7V1O;6%I;C\_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@9&]M86EN/R(L"@DO+R!E;F0@
M;V8@<V5R9V4@<&%R=`H*"2\O(&UA=F5R:6-K('!A<G0*"@DG9&]M7V-T<FQ?
M7W=U)R`]/B`B5V5B('5S97)S(BP*"2=D;VU?<')E9E]?8F]U;F-E7W=I=&A?
M<&AR87-E)R`]/B`B0F]U;F-E('=I=&@@;65S<V%G92(L"@DG9&]M7W!R969?
M7V-A=&-H7V%D9'(G(#T^(")&;W)W87)D('1O(&%D9')E<W,B+`H))V1O;5]P
M<F5F7U]R96IE8W0G(#T^("=296IE8W0G+`H))V1O;5]P<F5F7U]C;VYF:7)M
M7V1O;6%I;E]R96UO=FEN9R<@/3X@(E!L96%S92P@9&\@;F]T(&9O<F=E="!T
M;R!I;F9O<FT@=&AE(&1O;6%I;B!V:7-I=&]R<R!O9B!T:&4@9&]M86EN(&YA
M;64@8VAA;F=E+B!!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5N86UE('1H
M92!D;VUA:6X_(BP*"2=D;VU?<')E9E]?9&)?:6YC;VYS>7-T96YC>2<@/3X@
M(F1A=&%B87-E(&EN8V]N<VES=&5N8WDN(BP*"2=D;VU?<')E9E]?9&)S)R`]
M/B`B9&%T86)A<V5S(BP*"2=D;VU?<')E9E]?9&5L971E7W1R869F:6-?<W1A
M="<@/3X@(E)E=&%I;B!T<F%F9FEC('-T871I<W1I8W,B+`H))V1O;5]P<F5F
M7U]D96QE=&5?=')A9F9I8U]S=&%T7V]L9&5R)R`]/B`B4F5T86EN('1R869F
M:6,@<W1A=&ES=&EC<R(L"@DG9&]M7W!R969?7V1O7VYO=%]U<V5?<WEM8F]L
M7V%P;W-T<F]F)R`]/B`B1&\@;F]T('5S92!A<&]S=')O<&AE+"!R979E<G-E
M(&%P;W-T<F]P:&4L('-E;6EC;VQO;B!O<B!E;7!T>2!V86QU92!I;B!T:&4@
M8F]U;F-E(&UE<W-A9V4@9FEE;&0N(BP*"2=D;VU?<')E9E]?9&]M7VQE=F5L
M7VYA;65?8V]N9FQI8W0G(#T^(")4:&4@9&]M86EN(&%D;6EN:7-T<F%T;W(G
M<R!L;V=I;B!N86UE(&-O;F9L:6-T<R!W:71H(&QO9VEN(&YA;64@;V8@;VYE
M(&]F('1H92!C;&EE;G1S+B(L"@DG9&]M7W!R969?7VEN=F%L:61?9&ES:U]S
M<&%C95]L:6UI="<@/3X@(DEN=F%L:60@9&ES:R!S<&%C92!L:6UI="XB+`H)
M)V1O;5]P<F5F7U]I;G9A;&ED7V5X<&ER871I;VY?9&%T95]L:6UI="<@/3X@
M(DEN=F%L:60@=F%L:61I='D@<&5R:6]D+B(L"@DG9&]M7W!R969?7VEN=F%L
M:61?;6%X7W1R869F:6-?;&EM:70G(#T^("));G9A;&ED('1R869F:6,@;&EM
M:70N(BP*"2=D;VU?<')E9E]?;&EM:71S7V]F7V1O;2<@/3X@(DQI;6ET<R!F
M;W(@9&]M86EN("4Q(BP*"2=D;VU?<')E9E]?;6%I;%]G<G!S)R`]/B`B;6%I
M;"!G<F]U<',B+`H))V1O;5]P<F5F7U]M86EL7VYO;F5X:7-T96YT7W5S97(G
M(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V1O;5]P<F5F7U]M
M86EL7W)E9&ER<R<@/3X@(FUA:6P@<F5D:7)E8W1S(BP*"2=D;VU?<')E9E]?
M;6%I;%]R97-P<R<@/3X@(FUA:6P@875T;W)E<W!O;F1E<G,B+`H))V1O;5]P
M<F5F7U]M87A?;&EM:71?:7-?:6YV86QI9"<@/3X@(B4Q(&ES(&EN=F%L:60N
M(BP*"2=D;VU?<')E9E]?;6%X7VYU;5]O9E\E;V)J96-T<U]I<U]I;G9A;&ED
M)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@)3$@:7,@:6YV86QI9"XB+`H))V1O
M;5]P<F5F7U]N97=?;&EM:71?;&5S<U]C=7)R96YT;'E?=7-E9"<@/3X@(B4Q
M.B!R97%U97-T960@+2`E,BP@8W5R<F5N=&QY('5S960@+2`E,R(L"@DG9&]M
M7W!R969?7V]L9&5R7W1H870G(#T^("(@9F]R("(L"@DG9&]M7W!R969?7W!O
M<W1B;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG9&]M7W!R969?7W!R969E<F5N
M8V5S7V]F7V1O;2<@/3X@(E!R969E<F5N8V5S(&9O<B!D;VUA:6X@)3$B+`H)
M)V1O;5]P<F5F7U]R961I<F5C=%]T;U]I='-E;&8G(#T^(")4:&4@9&]M86EN
M('=I;&P@:&%V92!T:&4@9F]R=V%R9&EN9R!S970@=&\@:71S96QF(BP*"2=D
M;VU?<')E9E]?=')A9E]S=&%T7W=I;&Q?;F]T7V1E;&5T92<@/3X@(E1R869F
M:6,@<W1A=&ES=&EC<R!W:6QL(&YO="!B92!D96QE=&5D+B(L"@DG9&]M7W!R
M969?7W1R869F:6-?;&]G9VEN9U]P97)I;V1?8V]U;&1N=%]B95]L;W=E<B<@
M/3X@(EEO=2!S<&5C:69I960@=&AE(&1O;6%I;B!T<F%F9FEC('-T871I<W1I
M8W,@<F5T96YT:6]N('1I;64@=&\@8F4@;&5S<R!T:&%N('1H92!T;W1A;"!V
M86QU92!D969I;F5D(&9O<B!T:&4@<V5R=F5R("@E,2!M;VYT:"AS*2DN(%1H
M92!S=&%T:7-T:6-S(')E=&5N=&EO;B!P97)I;V0@:7,@<V5T(&5Q=6%L('1O
M('1H92!D969A=6QT('9A;'5E(&9O<B!T:&4@<V5R=F5R("@E,2!M;VYT:"AS
M*2DN(BP*"2=D;VU?<')E9E]?=6YA8FQE7V%D9%]W=W=?<')E9FEX7VEN7V1O
M;2<@/3X@(E5N86)L92!T;R!A9&0@82!W=W<@<')E9FEX('1O(&1O;6%I;CH@
M)3$B+`H))V1O;5]P<F5F7U]U;F%B;&5?9&5F:6YE7W!H>7-I8V%L7VAS=%]P
M87)A;2<@/3X@(E5N86)L92!T;R!D969I;F4@<&AY<VEC86P@:&]S=&EN9R!P
M87)A;65T97)S.B`E,2(L"@DG9&]M7W!R969?7W5N86)L95]R96YA;65?9&]M
M86EN)R`]/B`B56YA8FQE('1O(')E;F%M92!T:&4@9&]M86EN(BP*"2=D;VU?
M<')E9E]?=6YA8FQE7W-E=%]U<%]M8F]X7W%U;W1A)R`]/B`B56YA8FQE('1O
M('-E="!T:&4@;6%I;&)O>"!Q=6]T82!F;W(@=&AI<R!D;VUA:6XZ("4Q(BP*
M"2=D;VU?<')E9E]?=6YA8FQE7W-E=%]U<%]W96)?=7-E<E]S8W)I<'0G(#T^
M(")5;F%B;&4@=&\@<V5T('5P('-C<FEP=&EN9R!F;W(@=V5B('5S97)S.B`E
M,2(L"@DG9&]M7W!R969?7W5N;&EM:71E9"<@/3X@(E5N;&EM:71E9"(L"@DG
M9&]M7W!R969?7W=E8E]U<W)S)R`]/B`B=V5B('5S97)S(BP*"2=D;VU?<')E
M9E]?=V5B=7-E<G-?<V-R:7!T)R`]/B`B06QL;W<@=&AE('=E8B!U<V5R<R!S
M8W)I<'1I;F<B+`H))V1O;5]P<F5F7U]Y;W5?86QR96%D>5]H879E7R5O8FIE
M8W0G(#T^(")9;W4@86QR96%D>2!H879E("4Q(BP*"2=D;VU?8VQI7U]W87)N
M:6YG7VEG;F]R95]Q=6]T82<@/3X@)U=!4DY)3D<Z($]P=&EO;B`B+6AA<F1?
M<75O=&$B(&ES(&EG;F]R960Z(&AA<F0@9&ES:R!Q=6]T82!I<R!N;W0@<W5P
M<&]R=&5D)RP*"2=D;VU?=7-E<E]C;&EE;G1?;&]G:6Y?97AI<W0G(#T^(")5
M;F%B;&4@=&\@86QL;W<@9&]M86EN(&%D;6EN:7-T<F%T;W(G<R!A8V-E<W,@
M=&\@8V]N=')O;"!P86YE;"!O;B!T:&4@9&]M86EN("4Q.B!L;V=I;B!N86UE
M(&ES(&%L<F5A9'D@:6X@=7-E+B(L"@DG9&]M7W1R869F:6-?:&ES=&]R>5]?
M=&ET;&4G(#T^(")$;VUA:6X@/'-P86X@8VQA<W,]7")N86UE7"(^)3$\+W-P
M86X^('1R869F:6,@:&ES=&]R>2XB+`H))V1O;6%I;E]?<W5B9&]M86EN7V5X
M:7-T<R<@/3X@(E1H97)E(&ES(&$@<W5B9&]M86EN('=I=&@@;F%M92`E,2XE
M,BXB+`H))V1O;6%I;E]?9&%L:6%S7V5X:7-T<R<@/3X@(E1H97)E(&ES(&$@
M9&]M86EN(&%L:6%S('=I=&@@;F%M92`E,2XE,BXB+`H))V1O;6%I;E]?=6YA
M8FQE7W1O7W1U<FY?;VY?<V5R=FEC92<@/3X@(D9A:6QE9"!T;R!E;F%B;&4@
M=&AE("4Q('-E<G9I8V4B+`H))V1O;6%I;G-?7V-H86YG95]T:&5?<W1A='5S
M7V]F7V1O;6%I;C\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@8VAA
M;F=E('1H92!S=&%T=7,@;V8@9&]M86EN("4Q/R(L"@DG9&]M86EN<U]?8VQI
M96YT7VEN9F\G(#T^("(E,2!D;VUA:6YS+"`E,B!A8W1I=F4@9&]M86EN<RP@
M)3,@9&ES:R!S<&%C92!U<V5D+"`E-"!T<F%F9FEC('5S960B+`H))V1O;6%I
M;G-?7V-L:65N=%]I;F9O7VAI9&EN9U]T<F%F9FEC)R`]/B`B)3$@9&]M86EN
M<RP@)3(@86-T:79E(&1O;6%I;G,L("4S(&1I<VL@<W!A8V4@=7-E9"(L"@DG
M9&]M86EN<U]?<F5M;W9E7V1O;2<@/3X@(E1H92!F;VQL;W=I;F<@9&]M86EN
M<R!W:6QL(&)E(')E;6]V960Z(BP*"2=D;VUA:6YS7U]R96UO=F5?9&]M7V9O
M<E]C;"<@/3X@(E1H92!F;VQL;W=I;F<@9&]M86EN<R!O=VYE9"!B>2!C;&EE
M;G0@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG9&]M86EN<U]?<V5L96-T7V1O
M;5]F;W)?<F5M;W9E)R`]/B`B4V5L96-T(&1O;6%I;G,@=&\@8F4@<F5M;W9E
M9"XB+`H))V1O;6%I;G-?7W5N86)L95]T;U]C:&%N9V5?8VQI96YT7W-T871U
M<R<@/3X@(E5N86)L92!T;R!C:&%N9V4@=&AE(&-L:65N="!A8V-O=6YT('-T
M871U<SH@)3$B+`H))V1O;6%I;G-?7W5N86)L95]U<&1A=&5?87!A8VAE7W-E
M='1I;F=S)R`]/B`B56YA8FQE('1O('5P9&%T92!!<&%C:&4@<V5T=&EN9W,B
M+`H))V1O;6%I;G-?7WEO=5]D;U]N;W1?:&%V95]P97)M:7-S:6]N<U]T;U]D
M96QE=&5?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!P97)M:7-S:6]N
M<R!T;R!D96QE=&4@9&]M86EN<RXB+`H))V1O;6%I;G-?7WEO=5]W86YT7V-H
M86YG95]T:&5?<W1A='5S7V]F7W1H95]C;#\_)R`]/B`B07)E('EO=2!S=7)E
M('EO=2!W86YT('1O(&-H86YG92!T:&4@<W1A=&4@;V8@8VQI96YT(&%C8V]U
M;G0_(BP*"2=D;VUA:6YS7U]Y;W5?=V%N=%]C:&%N9V5?=&AE7V-P7V%C8V5S
M<U]O9E]T:&5?8VP_/R<@/3X@(D%R92!Y;W4@<W5R92!Y;W4@=V%N="!T;R!P
M97)F;W)M('1H:7,@;W!E<F%T:6]N/R(L"@DG9&]M86EN<U]L:7-T7U]U;F%B
M;&5?<F5M;W9E7V1O;7,G(#T^(")5;F%B;&4@=&\@<F5M;W9E(&1O;6%I;G,Z
M("4Q(BP*"2=D;VUA:6YT<F%F9FEC;&ES=%]H96%D97)?;V9?9&]M86EN7U\G
M(#T^(")4<F%F9FEC(&%T(&1O;6%I;B`E,2(L"@DG9'-?7V%N;VYY;6]U<U]F
M='`G(#T^(")!;F]N>6UO=7,@1E10(BP*"2=D<G=E8E]?<&%G971I=&QE)R`]
M/B`G1'(N5V5B($%N=&EV:7)U<R!0<F5F97)E;F-E<R<L"@DG9')W96)?7V1R
M=V5B)R`]/B`G06YT:79I<G5S(&UA:6P@8VAE8VMI;F<G+`H))V1R=V5B7U]D
M<G=E8E]D:7)E8W1I;VXG(#T^("=#:&5C:VEN9R!M86EL(&9O<B!V:7)U<V5S
M)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V]F9B<@/3X@)T1I<V%B;&5D
M)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N7V%N>2<@/3X@)TEN8V]M:6YG
M(&%N9"!O=71G;VEN9R!M86EL)RP*"2=D<G=E8E]?9')W96)?9&ER96-T:6]N
M7V9R;VTG(#T^("=/=71G;VEN9R!M86EL(&]N;'DG+`H))V1R=V5B7U]D<G=E
M8E]D:7)E8W1I;VY?=&\G(#T^("=);F-O;6EN9R!M86EL(&]N;'DG+`H))V1R
M=V5B7U]D:7-A8FQE7W)E87-O;E]K97DG(#T^("=$<BY796(@:7,@;F]T('-U
M<'!O<G1E9"!B>2!T:&4@;&EC96YS92!K97DN)RP*"2=D<G=E8E]?9&ES86)L
M95]R96%S;VY?<&5R;2<@/3X@)UEO=2!H879E(&YO('!E<FUI<W-I;VX@=&\@
M;6%N86=E($1R+E=E8B!A;G1I=FER=7,N)RP*"2=D<G=E8E]?9&ES86)L95]R
M96%S;VY?:6YS=&%L;"<@/3X@)T1R+E=E8B!A;G1I=FER=7,@:7,@;F]T(&EN
M<W1A;&QE9"XG+`H))V1S7U]D;G,G(#T^(")$3E,@6F]N92(L"@DG9'-?7VUA
M:6PG(#T^(")-86EL(BP*"2=D<U]?=&]M8V%T)R`]/B`B5&]M8V%T(BP*"2=D
M<W)?7V]F7V-L:65N=%]T:71L92<@/3X@(D1O;6%I;B!3=6UM87)Y(%)E<&]R
M="!O9B`E,2(L"@DG9'-R7U]R97!O<G1?:&%S7V)E96Y?<V5N=%]E;6%I;"<@
M/3X@(D1O;6%I;B!3=6UM87)Y(%)E<&]R="!H87,@8F5E;B!S96YT('1O(&4M
M;6%I;#H@)3$B+`H))V1S<E]?=&ET;&4G(#T^(")$;VUA:6X@4W5M;6%R>2!2
M97!O<G0B+`H))V1U;7!?9FEL95]?<F5M;W9E)PD]/B`B4F5M;W9E(BP*"2=D
M=6UP7V9I;&5?7V%D9"<)/3X@(E-P96-I9GD@=&AE(&YE>'0@=F]L=6UE(BP*
M"2=D=6UP<U]L:7-T7U]D96QE=&EO;E]P86=E7W1I=&QE)R`]/B`B5&AE(&9O
M;&QO=VEN9R!B86-K=7`@9FEL97,@;V8@9&]M86EN("4Q('=I;&P@8F4@<F5M
M;W9E9#HB+`H))V1U;7!S7VQI<W1?7W5P;&%D7V1U;7!?9FEL97,G(#T^(")5
M<&QO860@8F%C:W5P(&9I;&4B+`H))V1U;7!S7VQI<W1?7V1U;7!?9FEL97,G
M(#T^(")"86-K=7`@9FEL97,B+`H))V1U;7!S7VQI<W1?7V1U;7!F:6QE7V%L
M<F5A9'E?97AI<W1S)R`]/B`B5&AE(&9I;&4@)3$@86QR96%D>2!E>&ES=',N
M(BP*"2=D=6UP<U]L:7-T7U]D=6UP9FEL95]I<U]I;G9A;&ED)R`]/B`B5&AE
M(&9I;&4@)3$@:7,@;F]T(&$@=F%L:60@9&]M86EN(&)A8VMU<"!F:6QE+B(L
M"@DG9'5M<'-?;&ES=%]?<&%G95]T:71L92<@/3X@(D)A8VMU<"!F:6QE<R!R
M97!O<VET;W)Y(BP*"2=D=6UP<U]U<&QO861?7W!A9V5?=&ET;&4G(#T^(")5
M<&QO861I;F<@0F%C:W5P($9I;&5S('1O(%)E<&]S:71O<GDB+`H))V1U;7!S
M7VQI<W1?7W)E<&]S:71O<GE?:7-?;F]T7V5X:7-T)R`]/B`B0F%C:W5P(&9I
M;&5S(')E<&]S:71O<GD@9&]E<R!N;W0@97AI<W0B+`H))V1U;7!S7VQI<W1?
M7W1O=&%L7W-I>F4G(#T^(")4;W1A;"!S:7IE.B`E,2(L"@DG9'5M<'-?;&ES
M=%]?=6YA8FQE7W1O7W)E;6]V92<@/3X@(E5N86)L92!T;R!R96UO=F4@=&AE
M(&)A8VMU<"!F:6QE.B`E,2(L"@DG9'5M<'-?;&ES=%]?9'5M<&9I;&5?8V%N
M7V-O;F9L:6-T)R`]/B`B5&AE(&9I;&4@;F%M92!Y;W4@<W!E8VEF:65D(&-O
M;F9L:6-T<R!W:71H(&9I;&4@)3'"H%!L96%S92P@<W!E8VEF>2!A;F]T:&5R
M(&9I;&4@;F%M92XB+`H))V1U<W)?961?7V%L;&]W7V1L7W5S<E]A8V-E<W,G
M(#T^(")!;&QO=R!D;VUA:6X@861M:6YI<W1R871O<B=S(&%C8V5S<R(L"@DG
M9'5S<E]E9%]?:6YF;W)M871I;VXG(#T^(")%9&ET('1H92!P<F]P97)T:65S
M(&]F(&1O;6%I;B!A9&UI;FES=')A=&]R)W,@86-C;W5N="(L"@DG9'5S<E]E
M9%]?;&]C86QE)R`]/B`B1&]M86EN(&%D;6EN:7-T<F%T;W(G<R!L86YG=6%G
M92(L"@DG9'5S<E]E9%]?<VMI;B<@/3X@(D1O;6%I;B!A9&UI;FES=')A=&]R
M)W,@:6YT97)F86-E('-K:6XB+`H))V5S<U]?97)R;W(G(#T^(")%<G)O<B(L
M"@DG979E;G1?:&%N9&QE<E]E9&ET7U]T:71L92<@/3X@)T5V96YT($AA;F1L
M97(@4')O<&5R=&EE<R<L"@DG979E;G1?:&%N9&QE<G-?<F5M;W9E7U]T:71L
M92<@/3X@)U)E;6]V92!T:&4@<V5L96-T960@979E;G0@:&%N9&QE<G,G+`H)
M)V5V96YT7VAA;F1L97)S7W)E;6]V95]?<V5L96-T7V5V96YT7VAA;F1L97)S
M7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&5V96YT(&AA;F1L97)S('1O
M(&)E(')E;6]V960N)RP*"2=E=F5N=%]H86YD;&5R<U]L:7-T7U]T:71L92<@
M/3X@)T5V96YT($UA;F%G97(G+`H))V5X86UP;&5?7R<@/3X@(D5X86UP;&4Z
M("4Q(BP*"2=E>'1R87-?7V)U>5]N97=?:V5Y)R`]/B`B66]U<B!C=7)R96YT
M(&QI8V5N<V4@:V5Y(&1O97,@;F]T(&%L;&]W('EO=2!T;R!M;V1I9GD@=&AE
M<V4@;V)J96-T<RX@268@>6]U('=I<V@@=&\@8F4@86)L92!T;R!D;R!T:&%T
M+"!Y;W4@<VAO=6QD('!U<F-H87-E(&$@;F5W(&QI8V5N<V4@:V5Y(BP*"@DG
M9F5A='5R95]?9&5S:W1O<%]?:&5A9&5R)R`]/B`G1&5S:W1O<"<L"@DG9F5A
M='5R95]?9&5S:W1O<%]?861M:6XG(#T^("=4:&4@<&%G92!Y;W4@87)E(&-U
M<G)E;G1L>2!O;B!I<R!T:&4@;F5W('1A<VLM;W)I96YT960@1&5S:W1O<"P@
M=VAI8V@@9VEV97,@>6]U('%U:6-K(&%C8V5S<R!T;R!Y;W5R(&1A:6QY('1A
M<VMS+"!R97-O=7)C97,@=7-A9V4@<W1A=&ES=&EC<RP@86YD(&]F9F5R<R!A
M(&AA;F1Y('-T;W)A9V4@9F]R('EO=7(@9F%V;W)I=&4@<&QA8V5S(&EN(%!L
M97-K+B!$97-K=&]P(&ES(&%C8V5S<VEB;&4@9G)O;2!T:&4@;&5F="!M96YU
M(&%T(&%N>2!T:6UE+B<L"@DG9F5A='5R95]?9&5S:W1O<%]?8VQI96YT)R`]
M/B`G5&AE('!A9V4@>6]U(&%R92!C=7)R96YT;'D@;VX@:7,@=&AE(&YE=R!T
M87-K+6]R:65N=&5D($1E<VMT;W`L('=H:6-H(&=I=F5S('EO=2!Q=6EC:R!A
M8V-E<W,@=&\@>6]U<B!D86EL>2!T87-K<RP@<F5S;W5R8V5S('5S86=E('-T
M871I<W1I8W,L(&%N9"!O9F9E<G,@82!H86YD>2!S=&]R86=E(&9O<B!Y;W5R
M(&9A=F]R:71E('!L86-E<R!I;B!0;&5S:RX@1&5S:W1O<"!I<R!A8V-E<W-I
M8FQE(&9R;VT@=&AE(&QE9G0@;65N=2!A="!A;GD@=&EM92XG+`H))V9E871U
M<F5?7V1E<VMT;W!?7V1O;6%I;B<@/3X@)U1H92!P86=E('EO=2!A<F4@8W5R
M<F5N=&QY(&]N(&ES('1H92!N97<@=&%S:RUO<FEE;G1E9"!$97-K=&]P+"!W
M:&EC:"!G:79E<R!Y;W4@<75I8VL@86-C97-S('1O('EO=7(@9&%I;'D@=&%S
M:W,L(')E<V]U<F-E<R!U<V%G92!S=&%T:7-T:6-S+"!A;F0@;V9F97)S(&$@
M:&%N9'D@<W1O<F%G92!F;W(@>6]U<B!F879O<FET92!P;&%C97,@:6X@4&QE
M<VLN($1E<VMT;W`@:7,@86-C97-S:6)L92!F<F]M('1H92!L969T(&UE;G4@
M870@86YY('1I;64N)RP*"2=F96%T=7)E7U]D;VUA:6Y?86QI87-E<U]?:&5A
M9&5R)R`]/B`G1&]M86EN($%L:6%S97,G+`H))V9E871U<F5?7V1O;6%I;E]A
M;&EA<V5S7U]C;&EE;G0G(#T^("=4:&ES(&YE=R!F96%T=7)E(&%L;&]W<R!Y
M;W4@=&\@<V5T('5P(&%L=&5R;F%T:79E(&YA;65S(&9O<B!Y;W5R(&1O;6%I
M;G,@=VET:"!N;R!A9&1I=&EO;F%L(&-O<W0N($1O;6%I;B!A;&EA<V5S(&%C
M="!A<R!N:6-K;F%M97,@9F]R('EO=7(@=V5B<VET97,@86YD(&4M;6%I;"!A
M9&1R97-S97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE(&)Y('-E;&5C
M=&EN9R!A(&1O;6%I;B!O;B!Y;W5R($AO;64@4&%G92!A;F0@8VQI8VMI;F<@
M7"=$;VUA:6X@06QI87-E<UPG+B<L"@DG9F5A='5R95]?9&]M86EN7V%L:6%S
M97-?7V1O;6%I;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL;W=S('EO=2!T
M;R!S970@=7`@86QT97)N871I=F4@;F%M97,@9F]R('EO=7(@9&]M86EN('=I
M=&@@;F\@861D:71I;VYA;"!C;W-T+B!$;VUA:6X@86QI87-E<R!A8W0@87,@
M;FEC:VYA;65S(&9O<B!Y;W5R('=E8G-I=&4@86YD(&4M;6%I;"!A9&1R97-S
M97,N(%1H:7,@9F5A='5R92!I<R!A8V-E<W-I8FQE(&)Y(&-L:6-K:6YG(%PG
M1&]M86EN($%L:6%S97-<)R!O;B!Y;W5R($AO;64@<&%G92XG+`H))V9E871U
M<F5?7V1O;6%I;E]A;&EA<V5S7U]Q=6EC:U]L:6YK)R`]/B`G1V\@=&\@1&]M
M86EN($%L:6%S97,@;6%N86=E;65N="<L"@DG9F5A='5R95]?=V%T8VAD;V<R
M7U]H96%D97(G(#T^("=7871C:&1O9R`R+C`G+`H))V9E871U<F5?7W=A=&-H
M9&]G,E]?861M:6XG(#T^("=4:&4@<V5C;VYD(&5D:71O;B!O9B!7871C:&1O
M9R!M;V1U;&4@(&UO;FET;W)S('9I=&%L(%!L97-K('-E<G9I8V5S(&QI:V4@
M07!A8VAE(%=E8B!397)V97(L(&YO=&EF>6EN9R!Y;W4@=FEA(&4M;6%I;"!I
M;B!C87-E(&]F('-E<G9I8V4@:7-S=65S+B!7871C:&1O9R`R+C`@;F]W(&%L
M<V\@;6]N:71O<G,@>6]U<B!H87)D(&1I<VMS('1O(&5N<W5R92!Y;W4@=V]N
M7"=T(')U;B!O=70@;V8@<W1O<F%G92!U;F5X<&5C=&5D;'DL('-C86YS('EO
M=7(@<V5R=F5R(&9O<B!S96-U<FET>2!V=6QN97)A8FEL:71I97,@<W5C:"!A
M<R!R;V]T:VET<RP@8F%C:V1O;W)S(&%N9"!L;V-A;"!E>'!L;VET<RP@86YD
M(&1I<W!L87ES($-052!A;F0@4D%-('5S86=E('-T871I<W1I8W,N(%1O(&%C
M8V5S<R!7871C:&1O9R`R+C`L(&-L:6-K($UO9'5L97,@:6X@=&AE(&QE9G0@
M;65N=2P@=&AE;B!C;&EC:R!7871C:&1O9R!O;B!T:&4@($UO9'5L97,@<&%G
M92XG+`H))V9E871U<F5?7W=A=&-H9&]G,E]?<75I8VM?;&EN:R<@/3X@)T=O
M('1O(%=A=&-H9&]G(#(N,"<L"@DG9F5A='5R95]?<F5M;W1E7V1B7U]H96%D
M97(G(#T^("=296UO=&4@1&%T86)A<V4@2&]S=&EN9R<L"@DG9F5A='5R95]?
M<F5M;W1E7V1B7U]A9&UI;B<@/3X@)TEN(&%D9&ET:6]N('1O(&AO<W1I;F<@
M;&]C86P@9&%T86)A<V5S+"!0;&5S:R`X(&-A;B!H;W-T('5S97)S7"<@9&%T
M82!O;B!R96UO=&4@9&%T86)A<V4@<V5R=F5R<RX@66]U(&-A;B!E=F5N(&AA
M=F4@<V5V97)A;"!0;&5S:R!S97)V97)S(&AO<W1I;F<@=&AE:7(@=7-E<G-<
M)R!D871A8F%S97,@;VX@82!S:6YG;&4@9&5D:6-A=&5D(&UA8VAI;F4N($)O
M=&@@37E344P@*&EN8VQU9&EN9R!->5-13"`T+C$I(&%N9"!0;W-T9W)E4U%,
M(&%R92!S=7!P;W)T960N(%1O(&%C8V5S<R!$871A8F%S92!397)V97)S(&UA
M;F%G96UE;G0@<&%G92P@8VQI8VL@1&%T86)A<V4@4V5R=F5R<R!O;B!397)V
M97(@061M:6YI<W1R871I;VX@<&%G92XG+`H))V9E871U<F5?7W)E;6]T95]D
M8E]?<75I8VM?;&EN:R<@/3X@)T=O('1O($1A=&%B87-E(%-E<G9E<G,@;6%N
M86=E;65N="<L"@DG9F5A='5R95]?;6%I;%]Q=65U95]?:&5A9&5R)R`]/B`G
M36%I;"!1=65U92!-86YA9V5M96YT)RP*"2=F96%T=7)E7U]M86EL7W%U975E
M7U]A9&UI;B<@/3X@)U1H:7,@;F5W(&9E871U<F4@86QL;W=S(&%D;6EN:7-T
M<F%T;W)S('1O(&UA;F%G92!T:&4@46UA:6P@;65S<V%G92!Q=65U92!D:7)E
M8W1L>2!F<F]M(%!L97-K+B!7:71H('1H:7,@9F5A='5R92P@>6]U(&-A;B!M
M86YU86QL>2!D96QE=&4@<W!A;2!A;F0@;W1H97(@=6YW86YT960@;6%I;"!F
M<F]M('1H92!Q=65U92P@=7-I;F<@<75I8VL@86YD(&EN='5I=&EV92!S;W)T
M:6YG(&]P=&EO;G,N(%1O(&%C8V5S<R!-86EL('%U975E(&UA;F%G96UE;G0@
M<&%G92P@8VQI8VL@36%I;"!O;B!T:&4@4V5R=F5R($%D;6EN:7-T<F%T:6]N
M('!A9V4@86YD('-E;&5C="!T:&4@36%I;"!1=65U92!T86(N)RP*"2=F96%T
M=7)E7U]M86EL7W%U975E7U]Q=6EC:U]L:6YK)R`]/B`G1V\@=&\@36%I;"!1
M=65U92!M86YA9V5M96YT)RP*"2=F96%T=7)E7U]S;V%?7VAE861E<B<@/3X@
M)T1.4R!33T$@4F5C;W)D<R!-86YA9V5M96YT)RP*"2=F96%T=7)E7U]S;V%?
M7V-L:65N="<@/3X@)U-T87)T($]F($%U=&AO<FET>2`H4T]!*2!R96-O<F1S
M(&%R92!S<&5C:6%L('1Y<&4@;V8@1$Y3(')E8V]R9',@=&AA="!D969I;F4@
M=&AE('!A<F%M971E<G,@;V8@1$Y3(')E8V]R9',@8V%C:&EN9RX@4W1A<G1I
M;F<@=VET:"!0;&5S:R`X+"!Y;W4@:&%V92!F=6QL(&-O;G1R;VP@;W9E<B!$
M3E,@4T]!(')E8V]R9',L('=H:6-H(&QE=',@>6]U('-P96-I9GD@=F%R:6]U
M<R!T:6UE;W5T<R!T;R!F:6YE+71U;F4@=&AE(&1O;6%I;B!N86UE('-E<G9I
M8V4N(%1O(&%C8V5S<R!33T$@<F5C;W)D<R!M86YA9V5M96YT+"!S96QE8W0@
M82!D;VUA:6X@;VX@>6]U<B!(;VUE('!A9V4L(&-L:6-K($1.4R!A;F0@8VQI
M8VL@4T]!(%!R969E<F5N8V5S+B<L"@DG9F5A='5R95]?<V]A7U]D;VUA:6XG
M(#T^("=3=&%R="!/9B!!=71H;W)I='D@*%-/02D@<F5C;W)D<R!A<F4@<W!E
M8VEA;"!T>7!E(&]F($1.4R!R96-O<F1S('1H870@9&5F:6YE('1H92!P87)A
M;65T97)S(&]F($1.4R!R96-O<F1S(&-A8VAI;F<N(%-T87)T:6YG('=I=&@@
M4&QE<VL@."P@>6]U(&AA=F4@9G5L;"!C;VYT<F]L(&]V97(@1$Y3(%-/02!R
M96-O<F1S+"!W:&EC:"!L971S('EO=2!S<&5C:69Y('9A<FEO=7,@=&EM96]U
M=',@=&\@9FEN92UT=6YE('1H92!D;VUA:6X@;F%M92!S97)V:6-E+B!4;R!A
M8V-E<W,@4T]!(')E8V]R9',@;6%N86=E;65N="P@8VQI8VL@1$Y3(&]N('EO
M=7(@2&]M92!P86=E(&%N9"!C;&EC:R!33T$@4')E9F5R96YC97,N)RP*"2=F
M96%T=7)E7U]S;V%?7W%U:6-K7VQI;FLG(#T^("=';R!T;R!33T$@4F5C;W)D
M<R!M86YA9V5M96YT('!A9V4G+`H*"2=F:6QE;6%N86=E<E]?:71E;7,G(#T^
M("=F:6QE<R!A;F0@9&ER96-T;W)I97,@:6X@)3$G+`H))V9I;&5M86YA9V5R
M7U]C:&1I<E]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-H86YG92!D:7)E8W1O
M<GD@=&\@)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?8VAM;V1?9&ER)R`]/B`B
M0VAA;F=E('!E<FUI<W-I;VYS(&9O<B!D:7)E8W1O<GD@)3$B+`H))V9I;&5M
M86YA9V5R7U]C:&UO9%]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-H86YG92!P
M97)M:7-S:6]N<R!F;W(@9FEL92`E,3H@)3(B+`H))V9I;&5M86YA9V5R7U]C
M:&UO9%]F:6QE)R`]/B`B0VAA;F=E('!E<FUI<W-I;VYS(&9O<B!F:6QE("4Q
M(BP*"2=F:6QE;6%N86=E<E]?8V]P>5]E<G)O<E]?)R`]/B`B56YA8FQE('1O
M(&-O<'D@)3$@=&\@)3(Z("4S(BP*"2=F:6QE;6%N86=E<E]?8V]P>5]M;W9E
M)R`]/B`B0V]P>2`H;6]V92D@9FEL97,@9G)O;2`E,2(L"@DG9FEL96UA;F%G
M97)?7V-O=6YT7W-I>F5?7R<@/3X@)U-E;&5C=&EO;B!S:7IE.B`E,2<L"@DG
M9FEL96UA;F%G97)?7V-O=6YT7W-I>F5?97)R;W)?7R<@/3X@)U5N86)L92!T
M;R!C86QC=6QA=&4@<VEZ92!F;W(@)3$Z("4R)RP*"2=F:6QE;6%N86=E<E]?
M8V]U;G1?<VEZ95]N;W1E)R`]/B`G5&AE('1O=&%L('-I>F4@;V8@9FEL97,@
M86YD('-U8F1I<F5C=&]R:65S+B<L"@DG9FEL96UA;F%G97)?7V-R96%T95]D
M:7(G(#T^(")$:7)E8W1O<GD@8W)E871I;VXB+`H))V9I;&5M86YA9V5R7U]C
M<F5A=&5?9&ER7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@8W)E871E(&1I<F5C
M=&]R>2`E,3H@)3(B+`H))V9I;&5M86YA9V5R7U]C<F5A=&5?9FEL92<@/3X@
M(D9I;&4@8W)E871I;VXB+`H))V9I;&5M86YA9V5R7U]C<F5A=&5?9FEL95]?
M)R`]/B`B0W)E871E(&9I;&4@)3$B+`H))V9I;&5M86YA9V5R7U]C<F5A=&5?
M9FEL95]E<G)O<E]?)R`]/B`B56YA8FQE('1O(&-R96%T92!F:6QE("4Q.B`E
M,B(L"@DG9FEL96UA;F%G97)?7V-R96%T95]F:6QE7VAT;6PG(#T^(")5<V4@
M:'1M;"!T96UP;&%T92(L"@DG9FEL96UA;F%G97)?7V1E;6\G(#T^(")4:&ES
M(&]P97)A=&EO;B!I<R!N;W0@879A:6QA8FQE(&EN('1H92!D96UO('9E<G-I
M;VXN(BP*"2=F:6QE;6%N86=E<E]?9&5S=&EN871I;VXG(#T^(")$97-T:6YA
M=&EO;B(L"@DG9FEL96UA;F%G97)?7V1I<E]N;W1?97AI<W1S)R`]/B`B1&ER
M96-T;W)Y("4Q(&1O97,@;F]T(&5X:7-T+B(L"@DG9FEL96UA;F%G97)?7V1I
M<FYA;64G(#T^(")$:7)E8W1O<GD@;F%M92(L"@DG9FEL96UA;F%G97)?7V9I
M;&5N86UE)R`]/B`B1FEL92!N86UE(BP*"2=F:6QE;6%N86=E<E]?:7-?;F]?
M<W5C:"<@/3X@(E1H97)E(&ES(&YO(&9I;&4@;W(@9&ER96-T;W)Y('=I=&@@
M;F%M92`E,2(L"@DG9FEL96UA;F%G97)?7V)I;F%R>5]D871A7V%C8V5S<R<@
M/3X@)U1H:7,@9FEL92!M87D@8F4@82!B:6YA<GD@9FEL92X@1&\@>6]U('=A
M;G0@=&\@;W!E;B!I=#\G+`H))V9I;&5M86YA9V5R7U]E9&ET)R`]/B`B161I
M="!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?961I=%]E<G)O<E]?)R`]/B`B
M56YA8FQE('1O(&5D:70@9FEL92`E,3H@)3(B+`H))V9I;&5M86YA9V5R7U]E
M;7!T>5]S96QE8W1I;VXG(#T^(").;R!F:6QE*',I('-E;&5C=&5D+B(L"@DG
M9FEL96UA;F%G97)?7V9I;&5?97AI<W1S)R`]/B`B1FEL92`E,2!A;')E861Y
M(&5X:7-T<RXB+`H))V9I;&5M86YA9V5R7U]M;W9E7V5R<F]R7U\G(#T^(")5
M;F%B;&4@=&\@;6]V92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M86YA9V5R7U]N
M97=?9&ER)R`]/B`B1&ER96-T;W)Y(&YA;64B+`H))V9I;&5M86YA9V5R7U]N
M97=?9&ER7W1I=&QE)R`]/B`B0W)E871E(&YE=R!D:7)E8W1O<GD@:6X@)3$B
M+`H))V9I;&5M86YA9V5R7U]N97=?9FEL95]T:71L92<@/3X@(D-R96%T92!N
M97<@9FEL92!I;B`E,2(L"@DG9FEL96UA;F%G97)?7VYO=%]A;&QO=V5D)R`]
M/B`B66]U(&%R92!N;W0@86QL;W=E9"!T;R!C:&%N9V4@<&5R;6ES<VEO;G,@
M9F]R('1H92!F:6QE+B(L"@DG9FEL96UA;F%G97)?7W)?;6]D92<@/3X@(E)E
M860@;6]D92(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]D:7(G(#T^("),:7-T
M(&1I<F5C=&]R>2(L"@DG9FEL96UA;F%G97)?7W)?<&5R;5]F:6QE)R`]/B`B
M4F5A9"!D871A(BP*"2=F:6QE;6%N86=E<E]?<F5M;W9E)R`]/B`B4F5M;W9E
M(&9I;&5S(&9R;VT@)3$B+`H))V9I;&5M86YA9V5R7U]R96UO=F5?97)R;W)?
M7R<@/3X@(E5N86)L92!T;R!R96UO=F4@9FEL92`E,3H@)3(B+`H))V9I;&5M
M86YA9V5R7U]R96YA;65?9&ER)R`]/B`B4F5N86UE(&1I<F5C=&]R>2`E,2(L
M"@DG9FEL96UA;F%G97)?7W)E;F%M95]E<G)O<E]?)R`]/B`B56YA8FQE('1O
M(')E;F%M92`E,2!T;R`E,CH@)3,B+`H))V9I;&5M86YA9V5R7U]R96YA;65?
M9FEL92<@/3X@(E)E;F%M92!F:6QE("4Q(BP*"2=F:6QE;6%N86=E<E]?<V5T
M7W=I;E]P97)M:7-S:6]N<U]D:7(G(#T^(")3970@<&5R;6ES<VEO;G,@9F]R
M("4Q(&9O;&1E<B(L"@DG9FEL96UA;F%G97)?7W-E=%]W:6Y?<&5R;6ES<VEO
M;G-?9FEL92<@/3X@(E-E="!P97)M:7-S:6]N<R!F;W(@)3$@9FEL92(L"@DG
M9FEL96UA;F%G97)?7W-H;W<G(#T^(")3:&]W(&9I;&4@)3$B+`H))V9I;&5M
M86YA9V5R7U]S:&]W7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@<VAO=R!F:6QE
M("4Q.B`E,B(L"@DG9FEL96UA;F%G97)?7W-O=7)C92<@/3X@(E-O=7)C92(L
M"@DG9FEL96UA;F%G97)?7W1O=6-H7V-O;F9I<FTG(#T^(")!<F4@>6]U('-U
M<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@;V8@=&AE('-E
M;&5C=&5D(&9I;&5S/R(L"@DG9FEL96UA;F%G97)?7W1O=6-H7V5R<F]R7U\G
M(#T^(")5;F%B;&4@=&\@8VAA;F=E('1H92!T:6UE<W1A;7`@9F]R(&9I;&4@
M)3$Z("4R(BP*"2=F:6QE;6%N86=E<E]?;F]?<&5R;7-?;W)?=6YS=7!P;W)T
M961?9FEL95]T>7!E)R`]/B`G56YA8FQE('1O(')E860@=&AE(&9I;&4@;W(@
M=&AE(&9I;&4@9F]R;6%T(&ES(&YO="!S=7!P;W)T960N)RP*"2=F:6QE;6%N
M86=E<E]?=7!L;V%D7V5R<F]R7U\G(#T^(")5;F%B;&4@=&\@=7!L;V%D("4Q
M('1O("4R.B`E,R(L"@DG9FEL96UA;F%G97)?7W5P;&]A9%]F:6QE)R`]/B`B
M57!L;V%D(&9I;&4B+`H))V9I;&5M86YA9V5R7U]U<&QO861?9FEL95]S<F,G
M(#T^(")&:6QE('-O=7)C92(L"@DG9FEL96UA;F%G97)?7W5S97)N86UE)R`]
M/B`B57-E<B(L"@DG9FEL96UA;F%G97)?7W=?;6]D92<@/3X@(E=R:71E(&UO
M9&4B+`H))V9I;&5M86YA9V5R7U]W7W!E<FU?9&ER)R`]/B`B0W)E871E(&9I
M;&5S(BP*"2=F:6QE;6%N86=E<E]?=U]P97)M7V9I;&4G(#T^(")7<FET92!D
M871A(BP*"2=F:6QE;6%N86=E<E]?>%]M;V1E)R`]/B`B17AE8W5T92]S96%R
M8V@@;6]D92(L"@DG9FEL96UA;F%G97)?7WA?<&5R;5]D:7(G(#T^(")4<F%V
M97)S92!D:7)E8W1O<GDB+`H))V9I;&5M86YA9V5R7U]X7W!E<FU?9FEL92<@
M/3X@(D5X96-U=&4@9FEL92(L"@DG9FEL96UA;F%G97)?7W5N86)L95]T;U]R
M97-O;'9E7W)E86QP871H)R`]/B`B56YA8FQE('1O(')E<V]L=F4@<&%T:"!T
M;R!F:6QE("4Q(BP@+R]T;R!C:&5C:PH))V9I;&5M86YA9V5R7U]A8V-E<W-?
M=&]?<F5A;'!A=&A?9&5N:65D)R`]/B`B4&5R;6ES<VEO;B!D96YI960@=&\@
M)3$@+3X@)3(B+"`O+W1O(&-H96-K"@DG9V-H7U]A8W1I;VXG(#T^(")!8W1I
M;VXB+`H))V=C:%]?869T97)?9&5C<F5A<VEN9U]F;W)?=&AE7W9A;'5E7VYU
M;6)E<E]W:6QL7V)E8V%M95]N96=A=&EV92<@/3X@(D%F=&5R(&1E8W)E87-I
M;F<@=&AE('-P96-I9FEE9"!V86QU92P@:70@=VEL;"!B96-O;64@;F5G871I
M=F4N(BP*"2=G8VA?7V-A=&AE9V]R>2<@/3X@(D-A=&5G;W)Y(BP*"2=G8VA?
M7V-L:65N=%]P86=E7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T:6]N<R!O;B!C
M;&EE;G0@86-C;W5N=',B+`H))V=C:%]?8VQI96YT<U]S96QE8W1I;VXG(#T^
M(")-;V1I9FEE9"!A8V-O=6YT<R`H)3$I(BP*"2=G8VA?7V1O;6%I;E]P86=E
M7W1I=&QE)R`]/B`B1W)O=7`@;W!E<F%T:6]N<R!O;B!D;VUA:6YS(BP*"2=G
M8VA?7V1O;6%I;G-?<V5L96-T:6]N)R`]/B`B36]D:69I960@9&]M86EN<R`H
M)3$I(BP*"2=G8VA?7VUA:6QN86UE<U]S96QE8W1I;VXG(#T^(")-;V1I9FEE
M9"!M86EL(&YA;65S("@E,2DB+`H))V=C:%]?:&]S=&EN9R<@/3X@(DAO<W1I
M;F<B+`H))V=C:%]?:&]S=&EN9U]A<&%C:&5?97)R;W)?9&]C<R<@/3X@(D-U
M<W1O;2!E<G)O<B!D;V-U;65N=',B+`H))V=C:%]?:&]S=&EN9U]C9VDG(#T^
M(")#1TD@<W5P<&]R="(L"@DG9V-H7U]H;W-T:6YG7VQO9U]R;W1A=&EO;B<@
M/3X@(DQO9R!R;W1A=&EO;B!S=&%T=7,B+`H))V=C:%]?:&]S=&EN9U]L;V=?
M<F]T871I;VY?8V]M<')E<W,G(#T^("),;V<@9FEL97,@8V]M<')E<W-I;VXB
M+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T871I;VY?;6%I;'1O)R`]/B`B1&5L
M:79E<B!P<F]C97-S960@;&]G(&9I;&5S('1O(BP*"2=G8VA?7VAO<W1I;F=?
M;&]G7W)O=&%T:6]N7VUA>%]F:6QE<R<@/3X@(DYU;6)E<B!O9B!L;V<@9FEL
M92!I;G-T86YC97,B+`H))V=C:%]?:&]S=&EN9U]L;V=?<F]T871I;VY?<&5R
M:6]D)R`]/B`B3&]G(')O=&%T:6]N(&-O;F1I=&EO;B(L"@DG9V-H7U]H;W-T
M:6YG7VQO9U]R;W1A=&EO;E]T:71L92<@/3X@(DQO9R!R;W1A=&EO;B(L"@DG
M9V-H7U]H;W-T:6YG7W!D:7)?<&QE<VM?<W1A="<@/3X@(E!R;W1E8W0@9&ER
M96-T;W)Y("<O<&QE<VLM<W1A="\G(BP*"2=G8VA?7VAO<W1I;F=?<&AP)R`]
M/B`B4$A0('-U<'!O<G0B+`H))V=C:%]?:&]S=&EN9U]S:&5L;"<@/3X@(E-H
M96QL(&%C8V5S<R(L"@DG9V-H7U]H;W-T:6YG7W-S:2<@/3X@(E-322!S=7!P
M;W)T(BP*"2=G8VA?7VAO<W1I;F=?<W-L)R`]/B`B4U-,('-U<'!O<G0B+`H)
M)V=C:%]?:&]S=&EN9U]T>7!E)R`]/B`B2&]S=&EN9R(L"@DG9V-H7U]H;W-T
M:6YG7W=E8G-T870G(#T^(")796(@<W1A=&ES=&EC<R(L"@DG9V-H7U]I;G9A
M;&ED7V1A=&5?=F%L=64G(#T^("));F-O<G)E8W0@9&%T92!V86QU92XB+`H)
M)V=C:%]?:6YV86QI9%]L;V=R;W1A=&5?<&%R86US)R`]/B`B3&]G(')O=&%T
M:6]N(&-O;F9I9R!I<R!N;W0@>65T(&-R96%T960@9F]R('1H:7,@9&]M86EN
M+"!T;R!C<F5A=&4@:70@>6]U(&YE960@=&\@9FEL;"!O=70@86QL('1H92!F
M:65L9',@97AC97!T(&9O<B`E,2XB+`H))V=C:%]?:71?:7-?:6UP;W-S:6)L
M95]T;U]D96-R96%S95]N=6UB97)?;6]R95]T:&%N7S$P,%]P97)C96YT<R<@
M/3X@(E5N86)L92!T;R!D96-R96%S92!T:&4@;G5M8F5R(&)Y(&UO<F4@=&AA
M;B`Q,#`E+B(L"@DG9V-H7U]I=%]I<U]I;7!O<W-I8FQE7W1O7VEN8W)E87-E
M7V]R7V1E8W)E87-E7W5N;&EM:71E9%]V86QU92<@/3X@(E5N86)L92!T;R!I
M;F-R96%S92!O<B!D96-R96%S92!T:&4@=F%L=64@+2!I="!I<R!U;FQI;6ET
M960N(BP*"2=G8VA?7VQI;5]D:7-K7W-P86-E)R`]/B`B3&EM:70@=&]T86P@
M9&ES:R!S<&%C92(L"@DG9V-H7U]L:6U?97AP:7)A=&EO;B<@/3X@(DQI;6ET
M('1H92!V86QI9&ET>2!P97)I;V0B+`H))V=C:%]?;&EM7VUA>%]B;W@G(#T^
M("),:6UI="!T:&4@;G5M8F5R(&]F(&UA:6QB;WAE<R(L"@DG9V-H7U]L:6U?
M;6%X7V1B)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!D871A8F%S97,B+`H)
M)V=C:%]?;&EM7VUA>%]D;VTG(#T^("),:6UI="!T:&4@;G5M8F5R(&]F(&1O
M;6%I;G,B+`H))V=C:%]?;&EM7VUA>%]M86EL;&ES=',G(#T^("),:6UI="!T
M:&4@;G5M8F5R(&]F(&UA:6QI;F<@;&ES=',B+`H))V=C:%]?;&EM7VUA>%]M
M9R<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@;6%I;"!G<F]U<',B+`H))V=C
M:%]?;&EM7VUA>%]R961I<B<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@;6%I
M;"!R961I<F5C=',B+`H))V=C:%]?;&EM7VUA>%]R97-P)R`]/B`B3&EM:70@
M=&AE(&YU;6)E<B!O9B!M86EL(&%U=&]R97-P;VYD97)S(BP*"2=G8VA?7VQI
M;5]M87A?<W5B9&]M)R`]/B`B3&EM:70@=&AE(&YU;6)E<B!O9B!S=6)D;VUA
M:6YS(BP*"2=G8VA?7VQI;5]M87A?=')A9F9I8R<@/3X@(DQI;6ET('1O=&%L
M(&%M;W5N="!O9B!T<F%F9FEC(BP*"2=G8VA?7VQI;5]M87A?=V5B87!P<R<@
M/3X@(DQI;6ET('1H92!N=6UB97(@;V8@2F%V82!A<'!L:6-A=&EO;G,B+`H)
M)V=C:%]?;&EM7VUA>%]W=2<@/3X@(DQI;6ET('1H92!N=6UB97(@;V8@=V5B
M('5S97)S(BP*"2=G8VA?7VQI;5]M8F]X7W%U;W1A)R`]/B`B4V5T('1H92!M
M86EL8F]X('%U;W1A(BP*"2=G8VA?7VQI;5]T>7!E)R`]/B`B3&EM:70B+`H)
M)V=C:%]?;&EM:71?;75S=%]B95]I;G1E9V5R7W!O<VET:79E7VYU;6)E<B<@
M/3X@(E1H92!L:6UI="!V86QU92!M=7-T(&)E(&$@<&]S:71I=F4@:6YT96=E
M<BXB+`H))V=C:%]?;F5W7VQI;6ET7W9A;'5E7V)E='=E96Y?>F5R;U]A;F1?
M:V)Y=&4G(#T^(")4:&4@;F5W(&QI;6ET('9A;'5E(&-A;B!B92!E:71H97(@
M,"P@,2!+:6QO8GET92!O<B!G<F5A=&5R+B(L"@DG9V-H7U]N97=?;&EM:71?
M=F%L=65?8F5T=V5E;E]Z97)O7V%N9%]M8GET92<@/3X@(E1H92!N97<@;&EM
M:70@=F%L=64@8V%N(&)E(&5I=&AE<B`P+"`Q($UE9V%B>71E(&]R(&=R96%T
M97(N(BP*"2=G8VA?7VQI;6ET7W9A;'5E7VES7V]U=%]O9E]R86YG92<@/3X@
M(E1H92!L:6UI="!V86QU92!S<&5C:69I960@97AC965D<R!T:&4@<F%N9V4@
M;V8@86QL;W=A8FQE('9A;'5E<RXB+`H))V=C:%]?;&EM:71S)R`]/B`B3&EM
M:71S(BP*"2=G8VA?7VUA:6QN86UE7W!A9V5?=&ET;&4G(#T^("='<F]U<"!O
M<&5R871I;VYS(&]N(&UA:6P@;F%M97,G+`H))V=C:%]?;6Y?;F]?875T;W)E
M<W!O;F1E<B<@/3X@)U1H97)E(&%R92!N;R!A=71O<F5S<&]N9&5R<R!S970M
M=7`@9F]R('1H92!M86EL(&YA;64N)RP*"2=G8VA?7VYE=U]C;&EE;G1?;&EM
M:71?:7-?;&5S<U]T:&%N7V1O;6%I;E]L:6UI=',G(#T^(")4:&4@<W!E8VEF
M:65D(&QI;6ET('9A;'5E(&ES(&QE<W,@=&AA;B!T:&4@=&]T86P@;V8@86QL
M(&QI;6ET<R!D969I;F5D(&9O<B!T:&ES(&-L:65N="=S(&1O;6%I;G,B+`H)
M)V=C:%]?;F5W7VQI;6ET7W9A;'5E7W=I;&Q?8F5C86UE7V]U=%]O9E]R86YG
M92<@/3X@(D-H86YG:6YG('1H92!V86QU92!T;R!T:&4@;&5V96P@<W!E8VEF
M:65D('=I;&P@<F5S=6QT(&EN(&5X8V5E9&EN9R!T:&4@;6%X:6UU;2!A;&QO
M=V%B;&4@9&EG:70@=F%L=64N(BP*"2=G8VA?7VYO7V-L:65N='-?<V5L96-T
M960G(#T^(").;R!C;&EE;G0@86-C;W5N=',@<V5L96-T960B+`H))V=C:%]?
M;F]?9&]M86EN<U]S96QE8W1E9"<@/3X@(DYO(&1O;6%I;G,@<V5L96-T960B
M+`H))V=C:%]?;F]?;6%I;&YA;65S7W-E;&5C=&5D)R`]/B`G3F\@;6%I;"!N
M86UE<R!S96QE8W1E9"<L"@DG9V-H7U]P87)A;65T<B<@/3X@(E!A<F%M971E
M<B(L"@DG9V-H7U]P97)M7V-H86YG95]L:6UI=',G(#T^(")!8FEL:71Y('1O
M(&UO9&EF>2!D;VUA:6X@;&EM:71S(BP*"2=G8VA?7W!E<FU?8W)E871E7V1O
M;6%I;G,G(#T^(")!8FEL:71Y('1O(&-R96%T92!D;VUA:6YS(BP*"2=G8VA?
M7W!E<FU?='EP92<@/3X@(E!E<FUI<W-I;VXB+`H))V=C:%]?<&5R;6ES<VEO
M;G,G(#T^(")097)M:7-S:6]N<R(L"@DG9V-H7U]P<F5F7V%L;&]W7W-C<FEP
M=&EN9R<@/3X@(D%L;&]W('1H92!W96(@=7-E<G,@<V-R:7!T:6YG(BP*"2=G
M8VA?7W!R969?9&5L971E7W-T871I<W1I8R<@/3X@(E)E=&%I;B!T<F%F9FEC
M('-T871I<W1I8W,@9F]R(BP*"2=G8VA?7W!R969?;6%I;&UA;E]N;W1?:6YS
M=&%L;&5D7V]R7V-O;F8G(#T^(")-86EL;6%N(%-E<G9E<B!%>'1E;G-I;VYS
M(&%R92!N;W0@8W5R<F5N=&QY(&EN<W1A;&QE9"!O<B!P<F]P97)L>2!C;VYF
M:6=U<F5D(&]N('1H92!S97)V97(N(BP*"2=G8VA?7W!R969?;F]N97AI<W0G
M(#T^(")-86EL('1O(&YO;F5X:7-T96YT('5S97(B+`H))V=C:%]?<')E9E]T
M>7!E)R`]/B`B4')E9F5R96YC92(L"@DG9V-H7U]P<F5F7W=E8E]M86EL)R`]
M/B`B5V5B36%I;"(L"@DG9V-H7U]P<F5F7W=W=U]P<F5F:7@G(#T^(")75U<@
M<')E9FEX(BP*"2=G8VA?7W!R969E<F5N8V5S)R`]/B`B4')E9F5R96YC97,B
M+`H))V=C:%]?<F5J96-T:6]N)R`]/B`B4F5J96-T:6]N(')E87-O;B(L"@DG
M9V-H7U]S97)V7V%N;VYY;6]U<U]F='`G(#T^(")!;F]N>6UO=7,@1E10(BP*
M"2=G8VA?7W-E<G9?9&YS)R`]/B`B1$Y3('IO;F4B+`H))V=C:%]?<V5R=E]M
M86EL)R`]/B`B36%I;"(L"@DG9V-H7U]S97)V7VUA:6QL:7-T<R<@/3X@(DUA
M:6QI;F<@;&ES=',B+`H))V=C:%]?<V5R=E]T;VUC870G(#T^(")4;VUC870B
M+`H))V=C:%]?<V5R=E]T>7!E)R`]/B`B4V5R=FEC92(L"@DG9V-H7U]S97)V
M:6-E<R<@/3X@(E-E<G9I8V5S(BP*"2=G8VA?7W)E:F5C=%]L96=E;F0G(#T^
M(")4:&4@9W)O=7`@;W!E<F%T:6]N<R!H879E(&)E96X@<W5C8V5S<V9U;&QY
M('!E<F9O<FUE9"P@97AC97!T(&9O<B!T:&4@9F]L;&]W:6YG(&]B:F5C=',Z
M(BP*"2=G8VA?7W9A;'5E)R`]/B`B5F%L=64B+`H))V=C:%]?=F%L=65?;75S
M=%]B95]I;G1E9V5R7W!O<VET:79E7VYU;6)E<B<@/3X@(E1H92!V86QU92!M
M=7-T(&)E(&$@<&]S:71I=F4@:6YT96=E<BXB+`H))V=E=%]P87-S=V]R9%]?
M861M:6Y?<&%S<W=O<F0G(#T^(")4:&4@861M:6YI<W1R871O<B=S('!A<W-W
M;W)D(&-A;FYO="!B92!S96YT(&)Y(&4M;6%I;"!F;W(@<V5C=7)I='D@<F5A
M<V]N<RX@66]U(&-A;B!L;V]K(&ET('5P(&EN('1H92`O971C+W!S82\N<'-A
M+G-H861O=R!F:6QE(&QO8V%T960@;VX@>6]U<B!0;&5S:R!H;W-T+"!O;F-E
M('EO=2!A<F4@;&]G9V5D(&]N(&%S('5S97(@<F]O="XB+`H))V=E=%]P87-S
M=V]R9%]?96YC<GEP=&5D7W!A<W-W;W)D)R`]/B`B56YA8FQE('1O('-E;F0@
M=&AE('!A<W-W;W)D(&EN9F]R;6%T:6]N.B!T:&4@<&%S<W=O<F0@:7,@<W1O
M<F5D(&5N8W)Y<'1E9"XB+`H))V=E=%]P87-S=V]R9%]?:6YV86QI9%]L;V=I
M;E]O<E]E;6%I;"<@/3X@(DED96YT:69I8V%T:6]N(&9A:6QE9#H@:6YV86QI
M9"!L;V=I;B!O<B!E+6UA:6P@861D<F5S<R!S<&5C:69I960N(%!L96%S92P@
M=')Y(&%G86EN+B(L"@DG9V5T7W!A<W-W;W)D7U]L86)E;"<@/3X@(D=E="!P
M87-S=V]R9"(L"@DG9V5T7W!A<W-W;W)D7U]M86EL7V5R<F]R)R`]/B`B06X@
M97)R;W(@;V-C=7)E9"!W:&EL92!A='1E;7!T:6YG('1O('-E;F0@=&AE('!A
M<W-W;W)D('1O(&4M;6%I;"`E,3H@)3(B+`H))V=E=%]P87-S=V]R9%]?;6%I
M;%]O:R<@/3X@(E1H92!P87-S=V]R9"!H87,@8F5E;B!S=6-C97-S9G5L;'D@
M<V5N="!T;R!E+6UA:6PZ("4Q+B(L"@DG9V5T7W!A<W-W;W)D7U]M97-S86=E
M)R`]/B`B66]U<B!L;V=I;B!N86UE(&9O<B!A8V-E<W-I;F<@=&AE('-Y<W1E
M;3H@)3%<;EEO=7(@<&%S<W=O<F0@:7,@)3(B+`H))V=E=%]P87-S=V]R9%]?
M<W5B:F5C="<@/3X@(E!A<W-W;W)D(&9O<B!A8V-E<W,@=&\@<WES=&5M(BP*
M"2=G971?<&%S<W=O<F1?7W=A<FYI;F<G(#T^("(\8CY!='1E;G1I;VXA(2$\
M+V(^/&)R/EQN4V5N9&EN9R!P87-S=V]R9"!B>2!E+6UA:6P@:7,@:6YS96-U
M<F4A/&)R/EQN16YT97(@>6]U<B!L;V=I;B!N86UE(&%N9"!E+6UA:6P@<F5G
M:7-T97)E9"!I;B!T:&4@<WES=&5M(&9O<B!P87-S=V]R9"!D96QI=F5R>2XB
M+`H))V=R;W5P<U]?879A:6QA8FQE)R`]/B`B079A:6QA8FQE(&UA:6P@9W)O
M=7!S(BP*"2=G<F]U<'-?7V=R;W5P<U]F;W)?;6%I;&YA;64G(#T^(")-86EL
M(&=R;W5P<R!F;W(@=&AE(&UA:6P@;F%M92`E,2(L"@DG9W)O=7!S7U]M96UB
M97)?;V8G(#T^(")-96UB97(@;V8@=&AE(&9O;&QO=VEN9R!M86EL(&=R;W5P
M<R(L"@DG:&5L<%]?:&5L<%]A<F5A)R`]/B`B2&5L<"!A<F5A+B(L"@DG:'-T
M7V1E9E]?875T:%]D:7-A8FQE9"<@/3X@(F1I<V%B;&5D(BP*"2=H<W1?9&5F
M7U]A=71H7V5N86)L960G(#T^(")E;F%B;&5D(BP*"2=H<W1?9&5F7U]C:&%N
M9V5?8W5R<E]D;G-?:7`G(#T^(")4:&4@8W5R<F5N="!)4"!A9&1R97-S(&]F
M('1H92!!($1.4R!R96-O<F0@=VEL;"!B92!C:&%N9V5D(BP*"2=H<W1?9&5F
M7U]C<E]H;W-T:6YG7VEP7V1N<U]I<%]N;W1?97%U:78G(#T^(").;VYE(&]F
M('1H92!)4"!A9&1R97-S97,@;V8@=&AE($$@1$Y3(')E8V]R9"!M871C:"!W
M:71H($E0(&%D9')E<W,@87-S:6=N960@=&\@=&AE(&AO<W1I;F<@86-C;W5N
M="!B96EN9R!C<F5A=&5D(BP*"2=H<W1?9&5F7U]D97-T7W5R;"<@/3X@(D1E
M<W1I;F%T:6]N(%523"(L"@DG:'-T7V1E9E]?9&ES:U]Q=6]T82<@/3X@(D1I
M<VL@<75O=&$B+`H))VAS=%]D969?7V1I<VM?<W!A8V5?;&EM:71?97AC965D
M7VEN8V]M:6YG7W%U;W1A)R`]/B`B5&AE(&1I<VL@<W!A8V4@;&EM:70@>6]U
M(&%R92!T<GEI;F<@=&\@<V5T(&ES(&5X8V5E9&5D(&)Y('1H92!D:7-K('-P
M86-E(&QI;6ET(&EN('1H92!A;F]N>6UO=7,@1E10(&EN8V]M:6YG(&1I<F5C
M=&]R>2X@5&AE(&1I<VL@<W!A8V4@;&EM:70@:6X@=&AE(&%N;VYY;6]U<R!&
M5%`@:6YC;VUI;F<@9&ER96-T;W)Y(&UU<W0@;F]T(&5X8V5E9"!T:&4@9&]M
M86EN(&1I<VL@<W!A8V4@;&EM:70N(BP*"2=H<W1?9&5F7U]F<%]A9&UI;E]L
M;V=I;B<@/3X@(D9R;VYT4&%G92!!9&UI;FES=')A=&]R)W,@3&]G:6XB+`H)
M)VAS=%]D969?7V9P7V%D;6EN7VQO9VEN7VES7VEN=F%L:60G(#T^(")&<F]N
M=%!A9V4@061M:6YI<W1R871O<B=S($QO9VEN(&ES(&EN=F%L:60N(BP*"2=H
M<W1?9&5F7U]F<%]A9&UI;E]P87-S=V0G(#T^(")&<F]N=%!A9V4@061M:6XG
M<R!087-S=V]R9"(L"@DG:'-T7V1E9E]?9G!?97AT96YT:6]N7W-U<'!O<G0G
M(#T^(")&<F]N=%!A9V4@97AT96YS:6]N<R!S=7!P;W)T+B(L"@DG:'-T7V1E
M9E]?9G)A;65?9F]R=V%R9&EN9U]D969I;FET:6]N)R`]/B`B1G)A;64@9F]R
M=V%R9&EN9R!A<W-I9VYM96YT(&9O<B!D;VUA:6X@)3$B+`H))VAS=%]D969?
M7V9T<'5S97)?9F]R7VAS=%]N;W1?97AI<W1?:6Y?<WES=&5M)R`]/B`B5T%2
M3DE.1RX@1E10('5S97(@)3$@:7,@=7-E9"!I;B!A(&AO<W1I;F<@86-C;W5N
M="!B=70@9&]E<R!N;W0@97AI<W0@:6X@=&AE('-Y<W1E;2XB+`H))VAS=%]D
M969?7VAS=%]T>7!E7VES7VYO=%]D969I;F5D)R`]/B`B2&]S=&EN9R!T>7!E
M(&ES(&YO="!D969I;F5D(BP*"2=H<W1?9&5F7U]I<%]B87-E9"<@/3X@(DE0
M+6)A<V5D(BP*"2=H<W1?9&5F7U]N86UE7V)A<V5D7W!O=V5R7V%N;VYY;6]U
M<U]F='!?9&]W;B<@/3X@(E1R86YS9F5R<FEN9R!Y;W5R(&AO<W1I;F<@86-C
M;W5N="!T;R!S:&%R960@:7`@861D<F5S<R!W:6QL(&1I<V%B;&4@>6]U<B!A
M;F]N>6UO=7,@1E10(&1O;6%I;BX@4')O8V5E9"!A;GEW87D_(BP*"2=H<W1?
M9&5F7U]P87-S=V]R9%]I<U]I;G9A;&ED7W!A<W-W;W)D7W-Y;G1A>"<@/3X@
M(E!A<W-W;W)D(&ES(&EN=F%L:60N7&Y$;R!N;W0@=7-E('-I;F=L92!Q=6]T
M92!A;F0@;F%T:6]N86P@86QP:&%B970@8VAA<F%C=&5R<R!I;B!A('!A<W-W
M;W)D+EQN5&AE('!A<W-W;W)D(&QE;F=T:"!S:&]U;&0@8F4@9G)O;2`U('1O
M(#$T(&-H87)A8W1E<G,N(%1H92!P87-S=V]R9"!S:&]U;&0@;F]T(&-O;G1A
M:6X@=&AE('5S97(@;F%M92XB+`H))VAS=%]D969?7W-H96QL)R`]/B`B4VAE
M;&P@86-C97-S('1O('-E<G9E<B!W:71H($944"!U<V5R)W,@8W)E9&5N=&EA
M;',B+`H))VAS=%]D969?7W-T86YD87)D7V9O<G=A<F1I;F=?9&5F:6YI=&EO
M;B<@/3X@(E-T86YD87)D(&9O<G=A<F1I;F<@87-S:6=N;65N="!F;W(@9&]M
M86EN("4Q(BP*"2=H<W1?9&5F7U]T:71L95]N86UE7V)A<V5D)R`]/B`B3F%M
M92UB87-E9"(L"@DG:'-T7V1E9E]?=6YA8FQE7V-R96%T92]U<&1A=&5?<&AY
M<VEC7VAS="<@/3X@(E5N86)L92!T;R!C<F5A=&4O=7!D871E('!H>7-I8V%L
M(&AO<W1I;F<Z("4Q(BP*"2=H<W1?9&5F7U]U;F%B;&5?8W)E871E+W5P9&%T
M95]S=&1?9G=D)R`]/B`B56YA8FQE('1O(&-R96%T92]U<&1A=&4@<W1A;F1A
M<F0@9F]R=V%R9&EN9SH@)3$B+`H))VAS=%]D969?7W5N86)L95]C<F5A=&5?
M9F]R=V%R9&EN9U]M>7-E;&8G(#T^(")5;F%B;&4@=&\@8W)E871E(&9O<G=A
M<F1I;F<@=&\@=&AE(&1O;6%I;B!I='-E;&8N(BP*"2=H<W1?9&5F7U]U;F%B
M;&5?='5R;E]S<VQ?;V9F7W=H:6QE7V9P7W-S;%]O;B<@/3X@(E5N86)L92!T
M;R!T=7)N(&]F9B!34TP@<W5P<&]R=#H@1G)O;G1086=E(&]V97(@4U-,('-U
M<'!O<G0@:7,@96YA8FQE9"XB+`H))VAS=%]D969?7W5N86)L95]T=7)N7V9P
M7W-S;"<@/3X@(E5N86)L92!T;R!T=7)N(&]N($9R;VYT4&%G92!O=F5R(%-3
M3"!S=7!P;W)T.B!34TP@<W5P<&]R="!I<R!D:7-A8FQE9"XB+`H))VAS=%]D
M969?7W5N86)L95]T=7)N7V]N7W-S;%]C97)T7VYO=%]D969I;F5D)R`]/B`B
M56YA8FQE('1O('1U<FX@;VX@4U-,('-U<'!O<G0Z(&YO(%-33"!C97)T:69I
M8V%T92!I;G-T86QL960B+`H))VAS=%]D969?7W5R;%]I<U]I;G9A;&ED)R`]
M/B`B55),(&ES(&EN=F%L:60N(BP*"2=H<W1?9&5F7U]V:7)T=6%L7VAO<W1?
M86-C97-S)R`]/B`B5FER='5A;"!H;W-T(&%C8V5S<R!F;W(@9&]M86EN("4Q
M(BP*"2=H<W1?9&5F7U]V:7)T=6%L7VAO<W1?=7-E<U]N;VY?97AI<W1E9%]I
M<%]A9&1R97-S)R`]/B`B5T%23DE.1RX@5&AI<R!V:7)T=6%L(&AO<W0@:7,@
M=7-I;F<@82!N;VYE>&ES=&5N="!)4"!A9&1R97-S(&9O<B!H;W-T:6YG+B(L
M"@DG:'-T7V1E9E]?>6]U7VAA=F5?;F]?:7!S)R`]/B`B66]U(&AA=F4@;F\@
M:7`@861D<F5S<V5S(&%V86EL86)L92!A;F0@>6]U(&%R92!N;W0@86QL;W=E
M9"!T;R!C<F5A=&4@3F%M92UB87-E9"!H;W-T:6YG+B(L"@DG:'-T7V1E9E]?
M>6]U7W1U<FYE9%]O9F9?9G!?<W-L7W-U<'!O<G1?86QL7V9P7W-E='1I;F=S
M7W=I;&Q?8F5?9&5S=')O>65D7V]K/R<@/3X@(EEO=2!H879E('1U<FYE9"!O
M9F8@=&AE($9R;VYT4&%G92!O=F5R(%-33"!S=7!P;W)T+B!!;&P@1G)O;G10
M86=E('-E='1I;F=S('=I;&P@8F4@9&ES8V%R9&5D+B!$;R!Y;W4@=V%N="!T
M;R!P<F]C965D/R(L"@DG:'-T7V1E9E]?>6]U7W1U<FYE9%]O9F9?9G!?<W5P
M<&]R=%]A;&Q?9G!?<V5T=&EN9W-?=VEL;%]B95]D97-T<F]Y961?;VL_)R`]
M/B`B66]U(&AA=F4@='5R;F5D(&]F9B!T:&4@1G)O;G1086=E('-U<'!O<G0N
M($%L;"!&<F]N=%!A9V4@<V5T=&EN9W,@=VEL;"!B92!D:7-C87)D960N($1O
M('EO=2!W86YT('1O('!R;V-E960_(BP*"2=H<W1?<V5L7U]H96%D97(G(#T^
M("`@(E1O(&AO<W0@82!W96(@<VET92!O;B!T:&ES(&UA8VAI;F4L('-E;&5C
M="!T:&4@4&AY<VEC86P@:&]S=&EN9R!O<'1I;VXN(%5P;VX@8V]M<&QE=&EO
M;B!O9B!T:&ES('!R;V-E9'5R92P@>6]U<B!C;VYT<F]L('!A;F5L('=I;&P@
M<V5T('5P('1H92!D;VUA:6X@;F%M92!S97)V97(@;VX@=&AI<R!M86-H:6YE
M('1O('-E<G9E('1H92!N97<@9&]M86EN(&YA;64@86YD('!R97!A<F4@=&AE
M('=E8B!S97)V97(@=&\@<V5R=F4@=&AE(&YE=R!W96(@<VET93H@82!N97<@
M>F]N92!F:6QE('=I=&@@87!P<F]P<FEA=&4@<F5S;W5R8V4@<F5C;W)D<R!W
M:6QL(&)E(&%D9&5D('1O('1H92!D;VUA:6X@;F%M92!S97)V97(G<R!C;VYF
M:6=U<F%T:6]N(&9I;&5S+"!A('=E8B!S<&%C92!W:6QL(&)E(&-R96%T960@
M:6YS:61E('1H92!W96(@<V5R=F5R)W,@9&ER96-T;W)Y+"!A;F0@;F5C97-S
M87)Y('5S97(@86-C;W5N=',@=VEL;"!B92!C<F5A=&5D(&]N('1H92!S97)V
M97(N7&Y.;W1E.B!)9B!T:&4@<VET92!I<R!H;W-T960@;VX@86YO=&AE<B!M
M86-H:6YE+"!A;F0@>6]U('=I<V@@=&\@<V5T('5P('EO=7(@8V]N=')O;"!P
M86YE;"=S($1.4R!S97)V97(@;VYL>2!T;R!S97)V92!T:&4@1$Y3('IO;F4@
M9F]R('1H870@<VET92P@<V5L96-T(&5I=&AE<B!&<F%M92!F;W)W87)D:6YG
M(&]R(%-T86YD87)D(&9O<G=A<F1I;F<@;W!T:6]N+B!7:71H('-T86YD87)D
M(&9O<G=A<F1I;F<L(&$@=7-E<B!I<R!R961I<F5C=&5D('1O('1H92!S:71E
M(&%N9"!T:&4@86-T=6%L('-I=&4G<R!54DP@:7,@<VAO=VX@:6X@=&AE('5S
M97(G<R!B<F]W<V5R+"!S;R!T:&4@=7-E<B!A;'=A>7,@:VYO=W,@=&AA="!H
M92!O<B!S:&4@:7,@<F5D:7)E8W1E9"!T;R!A;F]T:&5R(%523"X@5VET:"!F
M<F%M92!F;W)W87)D:6YG+"!A('5S97(@:7,@<F5D:7)E8W1E9"!T;R!T:&4@
M<VET92!W:71H;W5T(&MN;W=I;F<@=&AA="!T:&4@<VET92!A8W1U86QL>2!R
M97-I9&5S(&%T(&%N;W1H97(@;&]C871I;VXN(BP*"2=H<W1?<V5L7U]P:'ES
M:6-A;%]H<W0G"3T^(")0:'ES:6-A;"!H;W-T:6YG(BP*"2=H<W1?<V5L7U]S
M96QE8W1?:'-T7W1Y<&4G(#T^(")396QE8W0@=&AE('1Y<&4@;V8@:&]S=&EN
M9R!F;W(@=&AE(&1O;6%I;B(L"@DG:'-T7W-E;%]?<V5L96-T7VAS=%]T>7!E
M7W=A<FYI;F<G(#T^(")396QE8W0@=&AE('1Y<&4@;V8@:&]S=&EN9R!F;W(@
M=&AE(&1O;6%I;B$B+`H))VAS=%]S96Q?7W-T86YD87)D7V9R=R<)/3X@(E-T
M86YD87)D(&9O<G=A<F1I;F<B+`H))VAS=%]S96Q?7V9R86UE7V9R=R<)/3X@
M(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?8VAO;W-E7VAS=%]T>7!E)R`]/B`B
M4V5L96-T('1H92!R97%U:7)E9"!H;W-T:6YG('1Y<&4N(BP*"2=?7V9R86UE
M7V9R=R<@/3X@(D9R86UE(&9O<G=A<F1I;F<B+`H))U]?:&]S=&EN9U]E>&ES
M=',G(#T^(")5;F%B;&4@=&\@8W)E871E(&AO<W1I;F<L(&%S(&ET(&ES(&%L
M<F5A9'D@8V]N9FEG=7)E9"!F;W(@=&AI<R!D;VUA:6XN(%EO=2!W:6QL(&)E
M(')E9&ER96-T960@=&\@=&AE(&AO<W1I;F<@;6%N86=E;65N="!P86=E+B(L
M"@DG7U]N;U]H<W1?8V]N9B<@/3X@(E1H97)E(&ES(&YO(&AO<W1I;F<@8V]N
M9FEG=7)E9"!F;W(@>6]U<B!D;VUA:6XN(BP*"2=?7W!H>7-I8V%L7VAS="<@
M/3X@(E!H>7-I8V%L(&AO<W1I;F<B+`H))U]?<V5L96-T7VAS=%]T>7!E)R`]
M/B`B4V5L96-T('1H92!T>7!E(&]F(&AO<W1I;F<@9F]R('1H92!D;VUA:6XB
M+`H))U]?<W1A;F1A<F1?9G)W)R`]/B`B4W1A;F1A<F0@9F]R=V%R9&EN9R(L
M"@DG7U]W87)N:6YG)R`]/B`B5V%R;FEN9R$@06QL(&]F('1H92!P<F5V:6]U
M<VQY('-E="!P87)A;65T97)S('=I;&P@8F4@9&ES8V%R9&5D+B!!<F4@>6]U
M('-U<F4@>6]U('=A;G0@=&\@8VAA;F=E('1H92!H;W-T:6YG('1Y<&4_(BP*
M"2=I7V-L7R$G(#T^(")297-O=7)C92!U<V%G92!O9B!T:&4@8VQI96YT(&ES
M(&5X8V5E9&EN9R!L:6UI=',N(BP*"2=I7V-L7V]F9B<@/3X@(D-L:65N="!I
M<R!I;F%C=&EV92XB+`H))VE?8VQ?;V9F7V)Y7V%D;6EN)R`]/B`B0VQI96YT
M(&%C8V]U;G0@:7,@9&ES86)L960@8GD@861M:6YI<W1R871O<BXB+`H))VE?
M8VQ?;V9F7V5X<&ER960G(#T^(")#;&EE;G0@86-C;W5N="!I<R!E>'!I<F5D
M+B(L"@DG:5]C;%]O:R<@/3X@(E)E<V]U<F-E('5S86=E(&]F('1H92!C;&EE
M;G0@:7,@=VET:&EN(&QI;6ET<RXB+`H))VE?8VQ?;VXG(#T^(")#;&EE;G0@
M:7,@86-T:79E+B(L"@DG:5]D;VU?(2<@/3X@(D1I<VL@<W!A8V4@86YD+V]R
M('1R869F:6,@;&EM:71S(&%R92!E>&-E961E9"!I;B!T:&4@9&]M86EN+B(L
M"@DG:5]D;VU?;V9F)R`]/B`B1&]M86EN(&ES(&EN86-T:79E+B(L"@DG:5]D
M;VU?;V9F7V)A8VMU<%]R97-T;W)E)R`]/B`B1&]M86EN(&ES('1E;7!O<F%R
M:6QY(&1I<V%B;&5D(&9O<B!B86-K=7`O<F5S=&]R:6YG+B(L"@DG:5]D;VU?
M;V9F7V)Y7V%D;6EN)R`]/B`B1&]M86EN(&ES(&1I<V%B;&5D(&)Y(&%D;6EN
M:7-T<F%T;W(B+`H))VE?9&]M7V]F9E]B>5]C;&EE;G0G(#T^(")$;VUA:6X@
M:7,@9&ES86)L960@8GD@8VQI96YT(BP*"2=I7V1O;5]O9F9?8GE?<F5S96QL
M97(G(#T^(")$;VUA:6X@:7,@9&ES86)L960@8GD@<F5S96QL97(B+`H))VE?
M9&]M7V]F9E]E>'!I<F5D)R`]/B`B1&]M86EN(&ES(&5X<&ER960B+`H))VE?
M9&]M7V]F9E]W:71H7W!A<F5N="<@/3X@(D-L:65N="!I<R!D:7-A8FQE9"!A
M;&]N9R!W:71H(&AI<R]H97(@9&]M86EN(BP*"2=I7V1O;5]O:R<@/3X@(D1O
M;6%I;B!I<R!A;&P@<FEG:'0N(BP*"2=I7V1O;5]O;B<@/3X@(D1O;6%I;B!I
M<R!A8W1I=F4N(BP*"2=I<%]A9&1R7U]A;')E861Y7V5X:7-T<R<@/3X@(DE0
M(&%D9')E<W,@)3$@86QR96%D>2!E>&ES=',N(BP*"2=I<%]A9&1R7U]C86YT
M7V%D9"<@/3X@(DE0("4Q(&1O97,@;F]T(&5X:7-T(&]R(&)E;&]N9W,@=&\@
M25`@<&]O;"!O9B!A;F]T:&5R(&-L:65N="(L"@DG:7!?861D<E]?8VQ?9&]M
M86EN<U]L:7-T7V9O<E]I<"<@/3X@(E1H92!D;VUA:6YS(&]F(&-L:65N="`E
M,2!T:&%T('5S92`E,B!I<"!A9&1R97-S("4S(BP*"2=I<%]A9&1R7U]C;%]L
M:7-T7V9O<E]I<"<@/3X@(D-L:65N=',@=7-I;F<@)3$@25`@861D<F5S<R`E
M,B(L"@DG:7!?861D<E]?8VQ?;&ES=%]F;W)?:7!?861D)R`]/B`B061D($E0
M(&%D9')E<W,@=&\@8VQI96YT<R!P;V]L(BP*"2=I<%]A9&1R7U]D;VUA:6YS
M7VQI<W1?9F]R7VEP)R`]/B`B1&]M86EN<R!U<VEN9R`E,2!)4"!A9&1R97-S
M("4R(BP*"2=I<%]A9&1R7U]I<%]U<V5D7V)Y7VAS=%]O<E]F<G<G(#T^("))
M4"!A9&1R97-S("4Q(&ES('5S960@9F]R(&AO<W1I;F<@;W(@9F]R=V%R9&EN
M9RXB+`H))VEP7V%D9')?7W)E;6]V95]I<%]A9&1R)R`]/B`B5&AE<V4@:7`@
M861D<F5S<V5S('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!S>7-T96TZ(BP*
M"2=I<%]A9&1R7U]S96QE8W1?8VQI96YT<R<@/3X@(E-E;&5C="!C;&EE;G1S
M(BP*"2=I<%]A9&1R7U]S96QE8W1?:7!?861D<E]T;U]R96UO=F4G(#T^(")3
M96QE8W0@=&AE($E0(&%D9')E<W,@=&\@8F4@<F5M;W9E9"XB+`H))VEP7V%D
M9')?7W5N86QL;W=E9%]B>5]L:6-E;G-E)R`]/B`B4&QE<VL@:7,@;F]T(&QI
M8V5N<V5D('1O('=O<FL@;VX@25`@861D<F5S<R`E,2Y<;D%L;&]W960@25`@
M<F%N9V5S(&%R93H@)3(N(BP*"2=I<%]A;&EA<U]?861D7VEP)R`]/B`B061D
M($E0(&%D9')E<W,B+`H))VEP7V%L:6%S7U]A9&1R7V%L<F5A9'E?97AI<W0G
M(#T^(")A9&1R97-S(&%L<F5A9'D@97AI<W1S+B(L"@DG:7!?86QI87-?7V%L
M:6%S7VUA;F%G92<@/3X@(DE0(&%D9')E<W-E<R!M86YA9V5M96YT(BP*"2=I
M<%]A;&EA<U]?86QI87-E<R<@/3X@(DE0($%D9')E<W-E<R`B+`H))VEP7V%L
M:6%S7U]I;G1E<F9A8V4G(#T^("));G1E<F9A8V4@(BP*"2=I<%]A;&EA<U]?
M:6YV86QI9%]I<%]N;5]B<V1?=G)T7VAS=',G(#T^("(E,2!)4"!A9&1R97-S
M(&9O<B!N86UE+6)A<V5D('9I<G1U86P@:&]S=&EN9R!I<R!I;G9A;&ED+B(L
M"@DG:7!?86QI87-?7VEN=F%L:61?:7!?;W)?;F5T;6%S:R<@/3X@(DEN=F%L
M:60@25`@861D<F5S<R]N971M87-K('!A:7(N(BP*"2=I<%]A;&EA<U]?:7!?
M8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!I<R!T:&4@;6%I;B!S97)V
M97(@25`L('=H:6-H(&-A;FYO="!B92!R96UO=F5D+B(L"@DG:7!?86QI87-?
M7VEP7VYO=%]E>&ES="<@/3X@(FEP(&%D9')E<W,@)3$@9&]E<R!N;W0@97AI
M<W0N(BP*"2=I<%]A;&EA<U]?:7!?861D<F5S<U]A;F1?;6%S:R<@/3X@)TE0
M(&%D9')E<W,@86YD('-U8FYE="!M87-K)RP*"2=I<%]A;&EA<U]?<F5M;W9E
M7W-E;&5C=&5D7VEP7V%L:6%S97,_)R`]/B`B07)E('EO=2!S=7)E('EO=2!W
M86YT('1O(')E;6]V92!T:&4@<V5L96-T960@25`@861D<F5S<V5S/R(L"@DG
M:7!?86QI87-?7W-E;&5C=%]I<"<@/3X@(E-E;&5C="!A="!L96%S="!O;F4@
M25`@861D<F5S<R!F<F]M('1H92!L:7-T('1O(')E;6]V92!I="XB+`H))VEP
M7V%L:6%S7U]T:&ES7VEP7W5S961?9F]R7V1O;6%I;B<@/3X@(B@E,2D@=&AI
M<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&1O;6%I;B`E,BXB+`H))VEP7V%L
M:6%S7U]T:&ES7VEP7W5S961?9F]R7VYM7V)S9%]V<G1?:'-T<R<@/3X@(B@E
M,2D@=&AI<R!)4"!A9&1R97-S(&ES('5S960@9F]R(&YA;64M8F%S960@=FER
M='5A;"!H;W-T<RXB+`H))VEP7V%L:6%S7U]T>7!E)R`]/B`B25`@='EP92(L
M"@DG:7!?86QI87-?7W5N86)L95]A9&1?:7`G(#T^(")5;F%B;&4@=&\@861D
M($E0.B`E,2(L"@DG:7!?86QI87-?7W5N86)L95]R96UO=F5?:7`G(#T^(")5
M;F%B;&4@=&\@<F5M;W9E($E0.B`E,2(L"@DG:7!?8W1R;%]?86YO;GEM;W5S
M7V9T<%]E>&ES='-?:6Y?9&]M86EN)R`]/B`B66]U(&-A;FYO="!C:&%N9V4@
M=&AE($E0(&%D9')E<W,@='EP92!T;R!S:&%R960L(&%S(&ET('=I;&P@;6%K
M92!!;F]N>6UO=7,@1E10(&9O<B!D;VUA:6X@)R4Q)R!U;F%V86EL86)L92XB
M+`H))VEP7V-T<FQ?7VEP7V%D9'(G(#T^("))4"!A9&1R97-S("4R(&]N('1H
M92!I;G1E<F9A8V4@)3$B+`H))VEP7V-T<FQ?7VEP7V5X:7-T<U]M86YY7W!O
M;VQS)R`]/B`B66]U(&-A;FYO="!C:&%N9V4@25`@='EP92X@25`@861D<F5S
M<R!B96QO;F=S('1O('1H92!P;V]L<R!O9B!S979E<F%L(&-L:65N=',@870@
M=&AE('-A;64@=&EM92XB+`H))VEP7V-T<FQ?7W-S;%]C97)T)R`]/B`B4U-,
M($-E<G1I9FEC871E(BP*"2=I<%]P;V]L7U]I<%]A9&1R97-S7VES7V%B<V5N
M9%]I;E]P;V]L)R`]/B`B25`@861D<F5S<R!I<R!M:7-S:6YG+B(L"@DG:7!?
M<&]O;%]?:7!?<&]O;%]F;W)?8VQI96YT)R`]/B`B25`@<&]O;"!O9B!C;&EE
M;G0@)3$B+`H))VEP7W!O;VQ?7VYO7V-L:65N<U]A=F%I;"<@/3X@(E1H97)E
M(&%R92!N;R!C;&EE;G1S(&%V86EL86)L92(L"@DG:7!?<&]O;%]?;F]?=F%C
M86YT7VEP<R<@/3X@(E1H97)E(&%R92!N;R!V86-A;G0@25!S(BP*"2=I<%]P
M;V]L7U]P;V]L7VES7V5M<'1Y)R`]/B`B0VQI96YT)W,@25`@<&]O;"!I<R!E
M;7!T>2X@5&\@861D(&%N($E0(&%D9')E<W,L('EO=2!S:&]U;&0@=7-E('1H
M92!#;&EE;G0G<R!)4"!P;V]L(&UA;F%G96UE;G0@9G5N8W1I;VYS(&%V86EL
M86)L92!F<F]M('1H92!#;&EE;G0G<R!(;VUE(%!A9V4N(BP*"2=I<%]P;V]L
M7U]R96UO=F5?:7!?861D<B<@/3X@(E1H97-E(&EP(&%D9')E<W-E<R!W:6QL
M(&)E(')E;6]V960@9G)O;2!T:&4@<&]O;"`E,3HB+`H))VEP7W!O;VQ?7W-E
M;&5C=%]F<F5E7VEP<R<@/3X@(E9A8V%N="!)4',B+`H))VEP7W!O;VQ?7W5S
M961?:7!S)R`]/B`B0VQI96YT)W,@25`@<&]O;"(L"@DG;&EC96YS95]?:5]A
M9W)E92<@/3X@(DD@86=R964@=&\@=&AE('1E<FUS(&]F('1H:7,@;&EC96YS
M92!A9W)E96UE;G0N(BP*"2=L:6-E;G-E7U]N;W1?<VAO=R<@/3X@(D1O(&YO
M="!S:&]W(&ET(&%G86EN+B(L"@DG;&EC96YS95]?=6YA8FQE7V]P96Y?;&EC
M96YS95]F:6QE)R`]/B`B56YA8FQE('1O(&]P96X@=&AE(&QI8V5N<V4@9FEL
M93H@)3$B+`H))VQI8V5N<V5?7WEO=5]S:&]U;&1?86-C97!T)R`]/B`B26X@
M;W)D97(@=&\@=7-E("104D]$7TY!344@>6]U('-H;W5L9"!A9W)E92!T;R!T
M:&4@=&5R;7,@;V8@=&AI<R!L:6-E;G-E+B(L"@DG;&EM:71?7V1A=&5?:6Y?
M<&%S="<@/3X@(E9A;&ED:71Y('!E<FEO9"!I<R!I;G9A;&ED+B`E,2!I<R!I
M;B!T:&4@<&%S="XB+`H))VQI;6ET7U]D:7-K7W-P86-E)R`]/B`B1&ES:R!S
M<&%C92(L"@DG;&EM:71?7V5N=&5R7V1A=&4G(#T^(")%;G1E<B!D871E(BP*
M"2=L:6UI=%]?97AP:7)A=&EO;B<@/3X@(E9A;&ED:71Y('!E<FEO9"(L"@DG
M;&EM:71?7VUA>%]B;W@G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL8F]X
M97,B+`H))VQI;6ET7U]M87A?9&(G(#T^(")-87AI;75M(&YU;6)E<B!O9B!D
M871A8F%S97,B+`H))VQI;6ET7U]M87A?9&]M)R`]/B`B36%X:6UU;2!N=6UB
M97(@;V8@9&]M86EN<R(L"@DG;&EM:71?7VUA>%]M86EL;&ES=',G(#T^(")-
M87AI;75M(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S(BP*"2=L:6UI=%]?;6%X
M7VUG)R`]/B`B36%X:6UU;2!N=6UB97(@;V8@;6%I;"!G<F]U<',B+`H))VQI
M;6ET7U]M87A?<F5D:7(G(#T^(")-87AI;75M(&YU;6)E<B!O9B!M86EL(')E
M9&ER96-T<R(L"@DG;&EM:71?7VUA>%]R97-P)R`]/B`B36%X:6UU;2!N=6UB
M97(@;V8@;6%I;"!A=71O<F5S<&]N9&5R<R(L"@DG;&EM:71?7VUA>%]S=6)D
M;VTG(#T^(")-87AI;75M(&YU;6)E<B!O9B!S=6)D;VUA:6YS(BP*"2=L:6UI
M=%]?;6%X7W1R869F:6,G(#T^(")-87AI;75M(&%M;W5N="!O9B!T<F%F9FEC
M(BP*"2=L:6UI=%]?;6%X7W=E8F%P<',G(#T^(")-87AI;75M(&YU;6)E<B!O
M9B!*879A(&%P<&QI8V%T:6]N<R(L"@DG;&EM:71?7VUA>%]W=2<@/3X@(DUA
M>&EM=6T@;G5M8F5R(&]F('=E8B!U<V5R<R(L"@DG;&EM:71?7VUB;WA?<75O
M=&$G(#T^(")3970@=&AE(&UA:6QB;W@@<75O=&$B+`H))VQI;6ET7U]U;FET
M<U]D:7-K7W-P86-E)R`]/B`B34(B+`H))VQI;6ET7U]U;FET<U]M87A?8F]X
M)R`]/B`B;6%I;&)O>&5S(BP*"2=L:6UI=%]?=6YI='-?;6%X7VUN)R`]/B`B
M;F%M97,B+`H))VQI;6ET7U]U;FET<U]M87A?9&(G(#T^(")D871A8F%S97,B
M+`H))VQI;6ET7U]U;FET<U]M87A?8VPG(#T^(")C;&EE;G1S(BP*"2=L:6UI
M=%]?=6YI='-?;6%X7V1O;2<@/3X@(F1O;6%I;G,B+`H))VQI;6ET7U]U;FET
M<U]M87A?;6%I;&QI<W1S)R`]/B`B;6%I;&EN9R!L:7-T<R(L"@DG;&EM:71?
M7W5N:71S7VUA>%]M9R<@/3X@(FUA:6P@9W)O=7!S(BP*"2=L:6UI=%]?=6YI
M='-?;6%X7W)E9&ER)R`]/B`B<F5D:7)E8W1S(BP*"2=L:6UI=%]?=6YI='-?
M;6%X7W)E<W`G(#T^(")A=71O<F5S<&]N9&5R<R(L"@DG;&EM:71?7W5N:71S
M7VUA>%]S=6)D;VTG(#T^(")S=6)D;VUA:6YS(BP*"2=L:6UI=%]?=6YI='-?
M;6%X7W1R869F:6,G(#T^(")-0B]M;VYT:"(L"@DG;&EM:71?7W5N:71S7VUA
M>%]W96)A<'!S)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H))VQI;6ET7U]U
M;FET<U]M87A?=W4G(#T^(")W96(@=7-E<G,B+`H))VQI;6ET7U]U;FET<U]M
M8F]X7W%U;W1A)R`]/B`B2T(B+`H*"2=L;V-A;&5?=7!L;V%D7U]T:71L92<@
M/3X@)T%D9"!,;V-A;&4G+`H))VQO8V%L95]U<&QO861?7V9I;&5?;F%M92<@
M(#T^("=0871H('1O('1H92!L86YG=6%G92!P86-K(&9I;&4@;&]C871I;VXG
M+`H))VQO8V%L95]U<&QO861?7W5N86)L95]T;U]I;G-T86QL)R`@/3X@)U5N
M86)L92!T;R!I;G-T86QL('1H92!L86YG=6%G92!P86-K(&9I;&4G+`H))VQO
M8V%L97-?;&ES=%]?=&ET;&4G("`@("`@(#T^("=,86YG=6%G92!P86-K<R!R
M97!O<VET;W)Y)RP*"2=L;V-A;&5S7VQI<W1?7VQE9V5N9"<@("`@("`@/3X@
M)T%V86EL86)L92!L86YG=6%G97,G+`H))VQO8V%L97-?;&ES=%]?86-T:79E
M7W1I=&QE)PD]/B`G4R<L"@DG;&]C86QE<U]L:7-T7U]L;V-A;&5?=&ET;&4G
M"3T^("=,86YG=6%G92!P86-K)RP*"2=L;V-A;&5S7VQI<W1?7VQA;F=?=&ET
M;&4G"0D]/B`G3&%N9W5A9V4G+`H))VQO8V%L97-?;&ES=%]?8V]U;G1R>5]T
M:71L92<)/3X@)T-O=6YT<GDG+`H))VQO8V%L97-?;&ES=%]?=7-E9%]T:71L
M92<)"3T^("=5<V5D)RP*"@DG;&]C86QE<U]R96UO=F5?7W1I=&QE)R`@("`@
M/3X@)TQO8V%L97,@4F5M;W9A;"<L"@DG;&]C86QE<U]R96UO=F5?7W-E;&5C
M=%]L;V-A;&5S7V9O<E]R96UO=F4G(#T^("=396QE8W0@=&AE(&QO8V%L97,@
M=&\@8F4@<F5M;W9E9"XG+`H))VQO8V%L97-?7V-A;E]N;W1?<F5M;W9E)R`@
M(#T^("=5;F%B;&4@=&\@<F5M;W9E('1H92!L86YG=6%G92!P86-K(&9O<B!L
M;V-A;&4@)3$Z("4R)RP*"@DG;&]G7V9I;&5?=FEE=V5R7U]F:6QE7VYA;65?
M:7-?=6YD969I;F5D)R`]/B`B4W!E8VEF>2!T:&4@;&]G(&9I;&5N86UE(&9O
M<B!V:65W:6YG+B(L"@DG;&]G7V9I;&5S7U]D96QE=&EO;E]P86=E7W1I=&QE
M)R`]/B`B5&AE(&9O;&QO=VEN9R!L;V<@9FEL97,@9F]R(&1O;6%I;B`E,2!W
M:6QL(&)E(')E;6]V960Z(BP*"2=L;V=?9FEL97-?7VEN=F%L:61?=F%L=65?
M;&EN97-?9F]R7W9I97<G(#T^("));G9A;&ED(&YU;6)E<B!O9B!L:6YE<R!S
M<&5C:69I960N(BP*"2=L;V=?9FEL97-?7VQI;F5S7V]F7VQO9V9I;&5?9F]R
M7W9I97<G(#T^("),:6YE<R!O9B!L;V<@9FEL92!T;R!B92!D:7-P;&%Y960@
M*&9R;VT@=&AE(&5N9"!O9B!T:&4@9FEL92DB+`H))VQO9U]F:6QE<U]?;&]G
M7V9I;&5?8V%N7VYO=%]B95]D96QE=&5D)R`]/B`B5&AI<R!L;V<@9FEL92!I
M<R!A8W1I=F4@86YD('1H97)E9F]R92!C86YN;W0@8F4@9&5L971E9"XB+`H)
M)VQO9U]F:6QE<U]?;&]G7V9I;&5S)R`]/B`B3&]G(&9I;&5S(BP*"2=L;V=?
M9FEL97-?7W!A9V5?=&ET;&4G(#T^("),;V<@9FEL97,@;6%N86=E;65N="!F
M;W(@9&]M86EN("4Q(BP*"2=L;V=?9FEL97-?7W-E;&5C=%]F:6QE<U]F;W)?
M<F5M;W9E)R`]/B`B3F\@;&]G(&9I;&5S('-E;&5C=&5D(&9O<B!R96UO=F%L
M+B(L"@DG;&]G7V9I;&5S7U]T;W1A;%]L;V=F:6QE<U]S:7IE)R`]/B`B3&]G
M(&9I;&5S('1O=&%L('-I>F4Z("4Q(BP*"2=L;V=?<F]T7U]C;VUP<F5S<R<@
M/3X@(D-O;7!R97-S(&QO9R!F:6QE<R(L"@DG;&]G7W)O=%]?;&]G7W)O=%]P
M97)I;V0G(#T^("),;V<@<F]T871I;VX@8V]N9&ET:6]N(BP*"2=L;V=?<F]T
M7U]L;V=?<F]T7W-I>F4G(#T^(")B>2!S:7IE(BP*"2=L;V=?<F]T7U]L;V=?
M<F]T7W1I;64G(#T^(")B>2!T:6UE(BP*"2=L;V=?<F]T7U]L;V=R;W1A=&EO
M;E]E;F%B;&4G(#T^(")%;F%B;&4@;&]G(')O=&%T:6]N(BP*"2=L;V=?<F]T
M7U]M86EL)R`]/B`B4V5N9"!P<F]C97-S960@;&]G(&9I;&5S('1O(&4M;6%I
M;"(L"@DG;&]G7W)O=%]?;6%X7VYU;6)E<E]O9E]L;V=F:6QE<R<@/3X@(DUA
M>&EM=6T@;G5M8F5R(&]F(&QO9R!F:6QE<R(L"@DG;&]G7W)O=%]?<&%G95]T
M:71L92<@/3X@(DQO9R!R;W1A=&EO;B!P<F5F97)E;F-E<R!F;W(@9&]M86EN
M("4Q(BP*"2=L;V=?<F]T7U]T:6UE7W!E<FEO9"<@/3X@(G!E<FEO9"(L"@DG
M;&]G:6Y?=7!?7V%C8V5S<U]D96YI961?86-C;W5N=%]D:7-A8FQE9"<@/3X@
M(D%C8V5S<R!D96YI960N(%EO=7(@86-C;W5N="!H87,@8F5E;B!D:7-A8FQE
M9"XB+`H))VQO9VEN7W5P7U]D969A=6QT7VQO8V%L92<@/3X@)U5S97(@9&5F
M875L="<L"@DG;&]G:6Y?=7!?7V5N=&5R7VQO9VEN7V%N9%]P87-S=V0G(#T^
M(")%;G1E<B!Y;W5R(&QO9VEN(&YA;64@86YD('!A<W-W;W)D+B(L"@DG;&]G
M:6Y?=7!?7V9O<F=O=%]P87-S=V]R9%]L86)E;"<@/3X@(D9O<F=O="!Y;W5R
M('!A<W-W;W)D/R(L"@DG;&]G:6Y?=7!?7V9O<F=O=%]P87-S=V]R9%]T97AT
M)R`]/B`B268@>6]U(&9O<F=O="!Y;W5R('!A<W-W;W)D('=E('=I;&P@=')Y
M('1O(&AE;'`@>6]U(&)Y('-E;F1I;F<@:70@;W5T('1O('EO=7(@92UM86EL
M+B(L"@DG;&]G:6Y?=7!?7VQO9VEN7VAA<U]B965N7VQO8VME9"<@/3X@(D%C
M8V5S<R!D96YI960N(BP*"2=L;V=I;E]U<%]?;&]G:6Y?;&%B96Q?<&QE<VLG
M(#T^("),;V=I;B!4;R`E,2(L"@DG;&]G:6Y?=7!?7VQO9VEN7W1E>'0G(#T^
M(")%;G1E<B!T:&4@;&]G:6X@;F%M92!I;G1O(%PB3&]G:6Y<(B!A;F0@<&%S
M<W=O<F0@:6YT;R!T:&4@7")087-S=V]R9%PB(&9I96QD<R!R97-P96-T:79E
M;'DN(%1H96X@8VQI8VL@7"),;V=I;EPB+B(L"@DG;&]G:6Y?=7!?7W5N86)L
M95]T;U]C:&5C:U]P87-S)R`]/B`B56YA8FQE('1O(&-H96-K('!A<W-W;W)D
M.B`E,2(L"@DG;&]C86QE<U]L:7-T7U]M;'-?;&EM:70G(#T^(")4:&4@;&EM
M:70@;VX@=&AE(&UA>&EM=6T@;G5M8F5R(&]F(&QA;F=U86=E('!A8VMS(&ES
M(&5X8V5E9&5D+B!!8W1I=F4@;&%N9W5A9V5S("4Q+B!!;&QO=V5D(&QA;F=U
M86=E<R`E,BXB+`H))VQO9VEN7W5P7U]S:&]R=%]W87)N:6YG7VQI;6ET<U]L
M:6-E;F-E7VME>2<@/3X@(D%C8V5S<R!T;R!T:&4@8V]N=')O;"!P86YE;"!I
M<R!T96UP;W)A<FEL>2!U;F%V86EL86)L92X@4&QE87-E(&-O;G1A8W0@>6]U
M<B!P<F]V:61E<B!F;W(@9&5T86EL<RXB+`H))VQO9VEN7W5P7U]G<F%C95]P
M97)I;V0G(#T^("=9;W4@87)E(&-U<G)E;G1L>2!O<&5R871I;F<@=VET:&EN
M('1H92!G<F%C92!P97)I;V0@;V8@>6]U<B!P<F]D=6-T(&QI8V5N<V4@*"4S
M*2X@5&\@=7!D871E('EO=7(@<')O9'5C="!L:6-E;G-E('5S92!T:&4@4F5T
M<FEE=F4@2V5Y<R!F=6YC=&EO;B!O9B`E,4QI8V5N<V4@36%N86=E<B4R+B<L
M"@DG;&]G:6Y?=7!?7W!A<G1N97)?;&EC96YS95]M97-S86=E)R`]/B`G66]U
M(&%R92!C=7)R96YT;'D@;W!E<F%T:6YG('=I=&@@82!L:6UI=&5D('!R;V1U
M8W0@;&EC96YS92!T:&%T(')E<75I<F5S(')E9VES=')A=&EO;B!P<FEO<B!T
M;R!A8W1I=F%T:6YG('1H92!F=6QL(&9E871U<F4@<V5T+B`@5&\@=7!D871E
M('EO=7(@<')O9'5C="!L:6-E;G-E('-E;&5C="!T:&4@4F5T<FEE=F4@2V5Y
M<R!O<'1I;VX@9G)O;2!W:71H:6X@)3%,:6-E;G-E($UA;F%G97(E,BXG+`H)
M)VUA7U]C<F5A=&5?=&ET;&4G(#T^("=#<F5A=&EN9R!M86EL(&%L:6%S(&9O
M<B`E,2<L"@DG;6%?7V5D:71?=&ET;&4G(#T^(")%9&ET(&UA:6P@86QI87,@
M)3$B+`H))VUA7U]E;G1E<E]N97=?86QI87,G(#T^(")%;G1E<B!N97<@86QI
M87,N(BP*"2=M85]?:6YV86QI9%]A;&EA<R<@/3X@(DEN=F%L:60@;6%I;"!A
M;&EA<RXB+`H))VUA7U]M86EL7V%L:6%S97-?;6%I;&YA;64G(#T^(")-86EL
M(&%L:6%S97,@9F]R(&UA:6P@;F%M92`E,2(L"@DG;6%?7VUA:6QN86UE7V1O
M97-?;F]T7V5X:7-T)R`]/B`B36%I;"!N86UE(&1O97,@;F]T(&5X:7-T+B(L
M"@DG;6%?7W-E;&5C=%]M85]F;W)?<F5M;W9E)R`]/B`B4V5L96-T(&UA:6P@
M86QI87-E<R!T;R!B92!R96UO=F5D+B(L"@DG;6%?7W5N86)L95]T;U]A9&1?
M;F5W7VUA)R`]/B`B56YA8FQE('1O(&%D9"!N97<@;6%I;"!A;&EA<SH@)3$B
M+`H))VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97,G(#T^(").86UE<R!F
M;W(@4$]0,R])34%0(&UA:6P@86-C;W5N=',B+`H))VUA:6Q?7V%L;&]W7W-H
M;W)T7W!O<#-?;F%M97-?9&ES86)L960G(#T^(")/;FQY('5S92!O9B!F=6QL
M(%!/4#,O24U!4"!M86EL(&%C8V]U;G1S(&YA;65S(&ES(&%L;&]W960B+`H)
M)VUA:6Q?7V%L;&]W7W-H;W)T7W!O<#-?;F%M97-?96YA8FQE9"<@/3X@(E5S
M92!O9B!S:&]R="`H=V5B;6%S=&5R*2!A;F0@9G5L;"`H=V5B;6%S=&5R0&1O
M;6%I;BYC;VTI(%!/4#,O24U!4"!M86EL(&%C8V]U;G0@;F%M97,@:7,@86QL
M;W=E9"(L"@DG;6%I;%]?8F%D9&]M86EN7V5X:7-T<R<@/3X@(E5N86)L92!T
M;R!A9&0@9&]M86EN('1O('1H92!B;&%C:R!L:7-T.B!S=6-H(&1O;6%I;B!A
M;')E861Y(&5X:7-T<R(L"@DG;6%I;%]?8FQO8VM?;6%I;%]F<F]M7V1O;7,G
M(#T^(")";&%C:R!,:7-T(BP*"2=M86EL7U]B;&]C:V5R<R<@/3X@(D)L;V-K
M960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME<G-?<F5M;W9E)R`]/B`B4F5M
M;W9E(&)L;V-K960@9&]M86EN<R(L"@DG;6%I;%]?8FQO8VME<E]A9&0G(#T^
M(")!9&0@9&]M86EN<R!T;R!B;&%C:R!L:7-T(BP*"2=M86EL7U]C;&]S960G
M(#T^(")C;&]S960B+`H))VUA:6Q?7V-R>7!T961?<&%S<W=D7VUA=&-H)R`]
M/B`B5&AE<F4@87)E(&UA:6P@;F%M97,@;6%T8VAI;F<@=&AE(&5N8W)Y<'1E
M9"!P87-S=V]R9',N(BP*"2=M86EL7U]D;VU?:6Y?;&ES="<@/3X@(D1O;6%I
M;B!I<R!A;')E861Y(&EN('1H92!B;&%C:R!L:7-T+B(L"@DG;6%I;%]?96YA
M8FQE7W)B;"<@/3X@(D5N86)L92!-05!3('-P86T@<')O=&5C=&EO;B(L"@DG
M;6%I;%]?96YT97)?<F)L7W-E<G9E<B<@/3X@(E1Y<&4@:6X@=&AE($U!4%,@
M>F]N92XB+`H))VUA:6Q?7V5N=&5R7W)I9VAT7VEP7VUA<VLG(#T^(")%;G1E
M<B!T:&4@:7`@;6%S:R!B971W965N(#$@86YD(#,R(BP*"2=M86EL7U]E;G1E
M<E]R:6=H=%]I<%]M87-K7S(T)R`]/B`B16YT97(@=&AE(&EP(&UA<VL@8F5T
M=V5E;B`R-"!A;F0@,S(B+`H))VUA:6Q?7VEN<W1A;&Q?<F)L<VUT<&1?<')O
M9W)A;2<@/3X@(DEN<W1A;&P@=&AE(')B;'-M='`@<V]F='=A<F4N(BP*"2=M
M86EL7U]I;G9A;&ED7V1O;5]N86UE)R`]/B`B1&]M86EN(&YA;64@)3$@:7,@
M:6YV86QI9"XB+`H))VUA:6Q?7VEN=F%L:61?<&]P7VQO8VM?=&EM92<@/3X@
M(E!/4#,@;&]C:R!T:6UE(&ES(&EN=F%L:60N(BP*"2=M86EL7U]I;G9A;&ED
M7W)B;%]S97)V97(G(#T^(")-05!3('IO;F4@;F%M92!I<R!I;G9A;&ED+B(L
M"@DG;6%I;%]?:7!?86YD7VUA<VLG(#T^("))4"!A9&1R97-S+VUA<VLB+`H)
M)VUA:6Q?7VEP7V%N9%]M87-K7V5X:7-T<R<@/3X@(E-U8V@@:7`@861D<F5S
M<R]N971M87-K('!A:7(@86QR96%D>2!E>&ES=',N(BP*"2=M86EL7U]I<%]O
M<E]M87-K7VES7VEN=F%L:60G(#T^("))4"!A9&1R97-S+VYE="!M87-K('!A
M:7(@:7,@:6YV86QI9"XB+`H))VUA:6Q?7VQO8VM?=&EM92<@/3X@(FQO8VL@
M=&EM92(L"@DG;6%I;%]?;6%I;%]O<'1I;VYS)R`]/B`B36%X:6UU;2!L971T
M97(@<VEZ92!A;F0@<F5L87D@;6]D92!P87)A;65T97)S(BP*"2=M86EL7U]M
M86EL;F%M97-?<&%S<W=D7VUA=&-H)R`]/B`B5&AE<F4@87)E(&UA:6P@;F%M
M92!A;F0@<&%S<W=O<F0@<&%I<G,@;6%T8VAI;F<N(BP*"2=M86EL7U]S96QE
M8W1?9&]M86EN<U]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H92!D;VUA:6YS
M('1O(&)E(')E;6]V960N(BP*"@DO+R!E;F0@;V8@;6%V97)I8VL@<&%R=`H*
M"@DO+R!K;V]P97(@<&%R=`H*"2=M86EL7U]M87A?<VEZ92<@/3X@(DUA>&EM
M=6T@;&5T=&5R('-I>F4B+`H))VUA:6Q?7VUB;WA?<75O=&$G(#T^(")-86EL
M8F]X('%U;W1A(BP*"2=M86EL7U]M:6XG(#T^(")-:6XB+`H))VUA:6Q?7W1O
M=&%L7V9I;&5S7W-I>F4G(#T^(")4;W1A;"!R97!O<VET;W)Y('-I>F4Z("4Q
M(BP*"2=M86EL7U]F:6QE;F%M95]A;')E861Y7VEN7W)E<&]S:71O<GDG(#T^
M(")&:6QE('=I=&@@<W5C:"!N86UE(&ES(&%L<F5A9'D@:6X@<F5P;W-I=&]R
M>2(L"@DG;6%I;%]?;F]?=VAI=&5?;&ES=%]M87-K7V9E871U<F5?,C0G(#T^
M(")0;&5A<V4L('5S92`R-"!O<B!H:6=H97(@87,@;6%S:R!V86QU92Y<;EEO
M=7(@;6%I;"!S97)V97(@9&]E<R!N;W0@<W5P<&]R="!S971T:6YG(&UA<VMS
M+B!792!C86X@;VYL>2!E;75L871E('-E='1I;F<@;6%S:R!F;W(@=F%L=65S
M(&YO="!L97-S('1H86X@,C0N(BP*"2=M86EL7U]O<&5N)R`]/B`B;W!E;B(L
M"@DG;6%I;%]?;W!E;E]R96QA>5]W87)N:6YG)R`]/B`B4V5T=&EN9R!Y;W5R
M(&UA:6P@<F5L87D@=&\@;W!E;B!E>'!O<V5S('EO=7(@;6%I;"!S97)V97(@
M=&\@<W!A;6UI;F<@86)U<V4N7&Y<;DET('-H;W5L9"!O;FQY(&)E('5S960@
M9F]R('1E;7!O<F%R>2!T97-T:6YG(&]F('EO=7(@;6%I;"!S97)V97(@;W(@
M:6X@:6YS=&%N8V5S('=H97)E('EO=2!A<F4@;W!E<F%T:6YG(%!L97-K(&9R
M;VT@:6YT97)N86P@;F5T=V]R:R!N;W0@86-C97-S:6)L92!V:6$@=&AE($EN
M=&5R;F5T+EQN7&Y!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@:V5E<"!T:&ES
M('-E='1I;F<_(BP*"2=M86EL7U]P;W`S)R`]/B`B4$]0,R(L"@DG;6%I;%]?
M<')E9F5R96YC97,G(#T^(")-86EL('!R969E<F5N8V5S(BP*"2=M86EL7U]R
M8FQ?>F]N97,G(#T^(")-05!3('IO;F5S(BP*"2=M86EL7U]R96QA>5]F<F]M
M7VEP)R`]/B`B5VAI=&4@3&ES="(L"@DG;6%I;%]?<F5L87EI;F<G(#T^(")2
M96QA>6EN9R(L"@DG;6%I;%]?<F5Q<E]A=71H)R`]/B`B875T:&]R:7IA=&EO
M;B!I<R!R97%U:7)E9#H@(BP*"2=M86EL7U]S;71P)R`]/B`B4TU44"(L"@DG
M;6%I;%]?=6YA8FQE7V%D9%]N97=?;6%I;%]N86UE)R`]/B`B56YA8FQE('1O
M(&%D9"!N97<@;6%I;"!N86UE.B`E,2(L"@DG;6%I;%]?=VAI=&5?;&ES="<@
M/3X@(E=H:71E($QI<W0B+`H))VUA:6Q?7W=H:71E7VQI<W1?861D)R`]/B`G
M061D($YE=R!.971W;W)K)RP*"2=M86EL7U]W:&ET95]L:7-T7W)E;6]V92<@
M/3X@)U1H92!F;VQL;W=I;F<@;F5T=V]R:W,@=VEL;"!B92!R96UO=F5D.B<L
M"@DG;6%I;%]?=VAI=&5?;&ES=%]M96UB97(G(#T^("=!;&QO=V5D(&YE='=O
M<FMS)RP*"2=M86EL7U]W:&ET95]L:7-T7V5M<'1Y7W-E;&5C=&EO;E]F;W)?
M<F5M;W9E)R`]/B`G4V5L96-T('1H92!E;G1R:65S('1O(&)E(')E;6]V960N
M)RP*"2=M86EL7W%U975E7U]T;V]L<U]L96=E;F0G(#T^("=4;V]L<R<L"@DG
M;6%I;%]Q=65U95]?:6YF;U]L96=E;F0G(#T^("=);F9O)RP*"2=M86EL7W%U
M975E7U]M97-S86=E<U]L:7-T7VQE9V5N9"<@/3X@)TUE<W-A9V5S(&EN(&UA
M:6P@<75E=64G+`H))VUA:6Q?<75E=65?7W$G(#T^("=1)RP*"2=M86EL7W%U
M975E7U]S=6)J96-T)R`]/B`G4W5B:F5C="<L"@DG;6%I;%]Q=65U95]?96YV
M96QO<&5?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U975E7U]E;G9E
M;&]P95]R96-I<&EE;G1S)R`]/B`G4F5C:7!I96YT<R<L"@DG;6%I;%]Q=65U
M95]?9&%T92<@/3X@)T1A=&4G+`H))VUA:6Q?<75E=65?7V%G92<@/3X@)T%G
M92<L"@DG;6%I;%]Q=65U95]?<VEZ92<@/3X@)U-I>F4G+`H))VUA:6Q?<75E
M=65?7VUE<W-A9V5S)R`]/B`G;65S<V%G97,G+`H))VUA:6Q?<75E=65?7VEN
M9F]?=&5X="<@/3X@)TUE<W-A9V5S(&EN('%U975E.B`E,2!N;W0@<')E<')O
M8V5S<V5D+"`E,B!L;V-A;"P@)3,@<F5M;W1E+"`E-"!T;W1A;"XG+`H))VUA
M:6Q?<75E=65?7W-E;&5C=%]?86QL)R`]/B`G06QL)RP*"2=M86EL7W%U975E
M7U]S96QE8W1?7W1O9&\G(#T^("=.;W0@4')E<')O8V5S<V5D)RP*"2=M86EL
M7W%U975E7U]S96QE8W1?7W)E;6]T92<@/3X@)U)E;6]T92<L"@DG;6%I;%]Q
M=65U95]?<V5L96-T7U]L;V-A;"<@/3X@)TQO8V%L)RP*"2=M86EL7W%U975E
M7U]S96QE8W1?7VQO8V%L7V%N9%]R96UO=&4G(#T^("=,;V-A;"!A;F0@4F5M
M;W1E)RP*"2=M86EL7W%U975E7U]Q=65U92<@/3X@)U%U975E<R<L"@DG;6%I
M;%]Q=65U95]?96YV96QO<&4G(#T^("=%;G9E;&]P92<L"@DG;6%I;%]Q=65U
M95]?<V5N9&5R)R`]/B`G4V5N9&5R)RP*"2=M86EL7W%U975E7U]R96-I<&EE
M;G0G(#T^("=296-I<&EE;G0G+`H))VUA:6Q?<75E=65?7W-T87)T7V1A=&4G
M(#T^("=3=&%R="<L"@DG;6%I;%]Q=65U95]?96YD7V1A=&4G(#T^("=%;F0G
M+`H))VUA:6Q?<75E=65?7VUI;E]A9V4G(#T^("=-:6YI;75M)RP*"2=M86EL
M7W%U975E7U]M87A?86=E)R`]/B`G36%X:6UU;2<L"@DG;6%I;%]Q=65U95]?
M;6EN7W-I>F4G(#T^("=-:6YI;75M)RP*"2=M86EL7W%U975E7U]M87A?<VEZ
M92<@/3X@)TUA>&EM=6TG+`H))VUA:6Q?<75E=65?7V5M<'1Y7W-E;&5C=&EO
M;B<@/3X@)TYO(&UE<W-A9V5S('-E;&5C=&5D+B<L"@DG;6%I;%]Q=65U95]?
M<F5M;W9E7VUE<W-A9V5S7V-O;F9I<FTG(#T^("=$;R!Y;W4@<F5A;&QY('=A
M;G0@=&\@<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F<F]M('1H92!Q
M=65U93\G+`H))VUA:6Q?<75E=65?7VYO=%]A;&QO=V5D7V)Y7VQI8V5N<V5?
M:V5Y)R`]/B`G36%I;"!Q=65U92!M86YA9V5M96YT(&ES(&YO="!A;&QO=V5D
M(&)Y('1H92!L:6-E;G-E(&ME>2XG+`H))V)T7W-H;W=?861V86YC961?<V5A
M<F-H)R`]/B`G4VAO=R!!9'9A;F-E9"!396%R8V@G+`H))V)T7VAI9&5?861V
M86YC961?<V5A<F-H)R`]/B`G2&ED92!!9'9A;F-E9"!396%R8V@G+`H))VUA
M:6QL:7-T7U\G(#T^(")-86EL:6YG(&QI<W0@)3$B+`H))VUA:6QL:7-T7U]A
M;')E861Y7V5X:7-T<R<@/3X@(DUA:6QI;F<@;&ES="!A;')E861Y(&5X:7-T
M<RXB+`H))VUA:6QL:7-T7U]C<F5A=&5?;6%I;&QI<W1?9F]R)R`]/B`B0W)E
M871E(&$@;6%I;&EN9R!L:7-T(&9O<B!D;VUA:6X@)3$B+`H))VUA:6QL:7-T
M7U]E;6%I;%]?)R`]/B`B36%I;&EN9R!L:7-T(&%D;6EN:7-T<F%T;W(G<R!E
M;6%I;"`E,2(L"@DG;6%I;&QI<W1?7VEN=F%L:61?96UA:6PG(#T^(")!9&UI
M;FES=')A=&]R)W,@96UA:6P@:7,@:6YV86QI9"(L"@DG;6%I;&QI<W1?7VEN
M=F%L:61?;F%M92<@/3X@(E1H92!M86EL:6YG(&QI<W0@;F%M92!I<R!I;G9A
M;&ED(BP*"2=M86EL;&ES=%]?:6YV97)T7V]N7V]F9C\G(#T^(")#:&%N9V4@
M=&AE('-T871E(&]F('-E;&5C=&5D(&UA:6QI;F<@;&ES=',_(BP*"2=M86EL
M;&ES=%]?:6YV97)T7V]N7V]F9E]O;F4_)R`]/B`B0VAA;F=E('1H92!S=&%T
M92!O9B!T:&4@;6%I;&EN9R!L:7-T/R(L"@DG;6%I;&QI<W1?7VUA:6Q?86QI
M87-?86QR96%D>5]E>&ES='-?:6Y?=&AI<U]D;VUA:6XG(#T^(")4:&4@;6%I
M;"!A;&EA<R`E,2!A;')E861Y(&5X:7-T<R!I;B!T:&ES(&1O;6%I;B(L"@DG
M;6%I;&QI<W1?7VYA;65?7R<@/3X@(DUA:6QI;F<@;&ES="!N86UE("4Q(BP*
M"2=M86EL;&ES=%]?;F5W7U\G(#T^(")#<F5A=&4@;F5W(&UA:6QI;F<@;&ES
M="`E,2(L"@DG;6%I;&QI<W1?7VYO=&EF>5]?)R`]/B`B3F]T:69Y(&%D;6EN
M:7-T<F%T;W(@;V8@=&AE(&UA:6QI;F<@;&ES="!C<F5A=&EO;B(L"@DG;6%I
M;&QI<W1S7U\G(#T^(")-86EL:6YG(&QI<W1S("4Q(BP*"2=M86EL;&ES='-?
M7VQI;6ET7V-L7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM:70@;VX@;G5M
M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE9"!F;W(@=&AE
M(&-L:65N="`H;&EM:70Z("4Q+"!U<V5D.B`E,BDB+`H))VUA:6QL:7-T<U]?
M;&EM:71?9&]M7VUA>%]M86EL;&ES=',G(#T^(")4:&4@;&EM:70@;VX@;G5M
M8F5R(&]F(&UA:6QI;F<@;&ES=',@:&%S(&)E96X@<F5A8VAE9"!F;W(@=&AE
M(&1O;6%I;BXB+`H))VUA:6QL:7-T<U]?;&ES="<@/3X@(DUA:6QI;F<@;&ES
M=',B+`H))VUA:6QL:7-T<U]?;&ES='-?;V9?9&]M86EN7U\G(#T^(")-86EL
M:6YG(&QI<W1S(&EN(&1O;6%I;B`E,2(L"@DG;6%I;&QI<W1S7U]M86EL;6%N
M7VYO=%]I;G-T86QL961?;W)?8V]N9B<@/3X@(EQN36%I;&UA;B!397)V97(@
M17AT96YS:6]N<R!A<F4@;F]T(&-U<G)E;G1L>2!I;G-T86QL960@;W(@8V]N
M9FEG=7)E9%QN;VX@=&AE('-E<G9E<BX@0V]N=&%C="!T:&4@<V5R=F5R(&%D
M;6EN:7-T<F%T;W(@=&\@:&%V92!T:&4@36%I;&UA;B!397)V97(@17AT96YS
M:6]N<R!I;G-T86QL960@;W(@<')O<&5R;'D@8V]N9FEG=7)E9"XB+`H))VUA
M:6QL:7-T<U]?<F5M;W9E7VUA:6QL:7-T<U]O;E]D;VUA:6XG(#T^(")296UO
M=FEN9R!M86EL:6YG(&QI<W1S(&9R;VT@9&]M86EN("4Q+B(L"@DG;6%I;&QI
M<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7VEN=F5R=%]O;E]O9F8G(#T^(")9
M;W4@<VAO=6QD('-E;&5C="!A="!L96%S="!O;F4@;6%I;&EN9R!L:7-T+B(L
M"@DG;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1?9F]R7W)E;6]V92<@/3X@
M(E-E;&5C="!T:&4@;6%I;&EN9R!L:7-T<R!T;R!B92!R96UO=F5D+B(L"@DG
M;6%I;&QI<W1S7U]S96QE8W1?;6%I;&QI<W1S7W1O7W)E;6]V92<@/3X@(E-E
M;&5C="!O;F4@;W(@<V5V97)A;"!M86EL:6YG(&QI<W1S('1O(&)E(')E;6]V
M960N(BP*"2=M86EL;&ES='-?7W-T871U<R<@/3X@(DUA:6QI;F<@;&ES="!S
M97)V:6-E(&ES(&5N86)L960B+`H))VUA:6QL:7-T<U]?=6YA8FQE7W1O7V1E
M;&5T95]?)R`]/B`B56YA8FQE('1O(&1E;&5T92!T:&4@;6%I;&EN9R!L:7-T
M.B`E,2(L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT)R`]/B`G66]U(&-A
M;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C875S92!T:&4@36%I
M;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O<B!C;VYF:6=U<F5D
M+B<L"@DG;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7V%D;6EN)R`]/B`G66]U
M(&-A;FYO="!M86YA9V4@=&AE(&UA:6QI;F<@;&ES=',@8F5C875S92!T:&4@
M36%I;&UA;B!C;VUP;VYE;G0@:7,@;F]T(&EN<W1A;&QE9"!O<B!C;VYF:6=U
M<F5D+B!0;&5A<V4@=7-E('1H92!-86EL;6%N(&-O;F9I9W5R871I;VX@9G5N
M8W1I;VX@870@=&AE(%-E<G9E<B!!9&UI;FES=')A=&EO;B!086=E+B<L"@DG
M;6%I;&QI<W1S7U]D:7-A8FQE9%]T97AT7W5S97(G(#T^("=9;W4@8V%N;F]T
M(&UA;F%G92!T:&4@;6%I;&EN9R!L:7-T<R!B96-A=7-E('1H92!-86EL;6%N
M(&-O;7!O;F5N="!I<R!N;W0@:6YS=&%L;&5D(&]R(&-O;F9I9W5R960N(%!L
M96%S92!C;VYT86-T('EO=7(@<V5R=F5R(&%D;6EN:7-T<F%T;W(@=&\@:&%V
M92!T:&4@36%I;&UA;B!I;G-T86QL960N)RP*"2=M86EL;&ES='-?8V]N9E]?
M<&%G95]T:71L92<@/3X@(D-O;F9I9W5R:6YG($UA:6QI;F<@3&ES=',@36%N
M86=E<B(L"@DG;6%I;&QI<W1S7V-O;F9?7W-U8V-E<W-F=6PG(#T^("=4:&4@
M36%I;&UA;B!S;V9T=V%R92!H87,@8F5E;B!S=6-C97-S9G5L;'D@8V]N9FEG
M=7)E9"P@<V\@=&AE(%-E="!5<"!-86EL;6%N(&)U='1O;B!W:6QL(&YO(&QO
M;F=E<B!B92!A8V-E<W-I8FQE(&9R;VT@=&AE(%-E<G9E<B!!9&UI;FES=')A
M=&EO;B!S8W)E96XN)RP*"2=M86EL;&ES=%]M96UB97)?961I=%]?=&ET;&4G
M(#T^(")!9&0@3F5W(%-U8G-C<FEB97(B+`H))VUA:6QL:7-T7VUE;6)E<G-?
M7W1I=&QE)R`]/B`G)3$@4W5B<V-R:6)E<G,G+`H))VUA:6QL:7-T7VUE;6)E
M<G-?7W-E;&5C=%]F;W)?<F5M;W9E)R`]/B`B4V5L96-T('1H92!S=6)S8W)I
M8F5R<R!T;R!B92!R96UO=F5D+B(L"@DG;6%I;&QI<W1?;65M8F5R<U]R96UO
M=F5?7W1I=&QE)R`]/B`G4F5M;W9E(&UA:6QI;F<@;&ES="!S=6)S8W)I8F5R
M<R<L"@DG;6%I;&QI<W1?;65M8F5R7U]A;')E861Y7V5X:7-T<R<@/3X@)TUA
M:6QI;F<@;&ES="!S=6)S8W)I8F5R(&%L<F5A9'D@97AI<W1S+B<L"@DG;6%I
M;&QI<W1?;65M8F5R7U]N;W1?97AI<W1S)R`]/B`G5&AE<F4@:7,@;F\@<W5C
M:"!U<V5R(&]N('1H92!M86EL:6YG(&QI<W0N)RP*"2=M86YA9V5R7U]A8V-E
M<W-?9&5N:65D)R`]/B`B06-C97-S(&1E;FEE9#H@)3$B+`H))VUA;F%G97)?
M7V%D;6EN)R`]/B`B061M:6YI<W1R871O<B(L"@DG;6%N86=E<E]?8VQI96YT
M)R`]/B`B0VQI96YT(BP*"2=M86YA9V5R7U]D;VUA:6XG(#T^(")$;VUA:6XB
M+`H))VUA;F%G97)?7V1O;6%I;E]C;%]L:6UI=%]E>&-E961I;F<G(#T^(")4
M:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1O;6%I;G,@:7,@<F5A8VAE9"!F;W(@
M=&AI<R!C;&EE;G0@86-C;W5N="(L"@DG;6%N86=E<E]?9&]M86EN7VES7VYO
M=%]Y;W5R<R<@/3X@(D1O;6%I;B`E,2!D;V5S(&YO="!B96QO;F<@=&\@>6]U
M(BP*"2=M86YA9V5R7U]D;VUA:6Y?:V5Y7VQI;6ET7V5X8V5E9&EN9R<@/3X@
M(E1H92!L:6UI="!O;B!D;VUA:6X@8W)E871I;VX@9&5F:6YE9"!B>2!Y;W5R
M(&QI8V5N<V4@:V5Y(&ES(')E86-H960B+`H))VUA;F%G97)?7VYO7W!E<FU?
M=&]?8V%L;"<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@<&5R;6ES<VEO;B!T
M;R!C86QL("4Q(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O7V-R96%T95]D;VUA
M:6YS)R`]/B`B66]U(&1O(&YO="!H879E('1H92!P97)M:7-S:6]N('1O(&-R
M96%T92!D;VUA:6YS(BP*"2=M86YA9V5R7U]N;U]P97)M7W1O7VUO9&EF>5]D
M;VUA:6XG(#T^(")9;W4@9&\@;F]T(&AA=F4@=&AE('!E<FUI<W-I;VX@=&\@
M;6]D:69Y(&1O;6%I;B`E,2(L"@DG;6%N86=E<E]?;F]?<&5R;5]T;U]M;V1I
M9GE?9&]M86EN<R<@/3X@(EEO=2!D;R!N;W0@:&%V92!T:&4@<&5R;6ES<VEO
M;B!T;R!M;V1I9GD@9&]M86EN<R(L"@DG;6%N86=E<E]?;F]?<&5R;5]T;U]R
M96UO=F5?9&]M86EN)R`]/B`B66]U(&1O(&YO="!H879E('1H92!P97)M:7-S
M:6]N('1O(')E;6]V92!D;VUA:6X@)3$B+`H))VUA;F%G97)?7VYO7W!E<FU?
M=&]?<F5M;W9E7V1O;6%I;G,G(#T^(")9;W4@9&\@;F]T(&AA=F4@=&AE('!E
M<FUI<W-I;VX@=&\@<F5M;W9E(&1O;6%I;G,B+`H))VUA;F%G97)?7VYO9&5?
M9&]E<VYT7V5X:7-T)R`]/B`B)3$@9&]E<R!N;W0@97AI<W0B+`H))VUA;F%G
M97)?7W5S97)?9&ES86)L960G(#T^(")9;W5R(&%C8V]U;G0@:7,@9&ES86)L
M960N(%EO=2!C86YN;W0@;W!E<F%T92!T:&4@<WES=&5M+B(L"@DG;6)O>%]Q
M=6]T85]U;G-U<'!O<G1E9"<@/3X@(FYO="!S=7!P;W)T960@8GD@=&AE(&UA
M:6P@<V5R=F5R(BP*"2=M;E]?871T86-H7W)E;6]V92<@/3X@(E)E;6]V92!A
M='1A8VAM96YT<R(L"@DG;6Y?7V%T=&%C:%]S96QE8W1?9F]R7W)E;6]V92<@
M/3X@(E-E;&5C="!A='1A8VAM96YT<R!T;R!B92!R96UO=F5D+B(L"@DG;6Y?
M7V-R96%T95]T:71L92<@/3X@(D-R96%T92!M86EL(&YA;64B+`H))VUN7U]E
M9&ET7W1I=&QE)R`]/B`B4')E9F5R96YC97,B+`H))VUN7U]F:6QE<U]L:7-T
M7W1I=&QE)R`]/B`B071T86-H;65N="!&:6QE<R(L"@DG;6Y?7V9I;&5S7W)E
M;6]V92<@/3X@(E)E;6]V92!F:6QE<R!F<F]M(&%T=&%C:&UE;G1S(')E<&]S
M:71O<GDN(%1H:7,@9FEL97,@87)E('!O<W-I8FQY('5S960@8GD@875T;W)E
M<W!O;F1E<G,N(%1H97D@=VEL;"!B92!R96UO=F5D(&9R;VT@8F]T:#H@=&AE
M(')E<&]S:71O<GD@86YD(&%U=&]R97-P;VYD97)S('5S:6YG('1H96TN(BP*
M"2=M;E]?9FEL97-?<V5L96-T7V9O<E]R96UO=F4G(#T^(")396QE8W0@9FEL
M97,@=&\@8F4@<F5M;W9E9"XB+`H))VUN7U]M86EL7V%L:6%S7V9O<FTG(#T^
M(")-86EL(&%L:6%S(&9O<FTB+`H))VUN7U]M86EL7V%L:6%S97-?;&ES="<@
M/3X@(DUA:6P@86QI87-E<R(L"@DG;6Y?7VUA:6QB;W@G(#T^(")-86EL8F]X
M(&UA;F%G96UE;G0B+`H))VUN7U]R961I<E]R96UO=F4G(#T^(")296UO=F4@
M;65M8F5R<R(L"@DG;6Y?7W)E9&ER7W-E;&5C=%]F;W)?<F5M;W9E)R`]/B`B
M4V5L96-T('1H92!M96UB97)S('1O(&)E(')E;6]V960N(BP*"2=M;E]?<F5S
M<%]R96UO=F4G(#T^(")296UO=F4@;6%I;"!A=71O<F5S<&]N9&5R<R(L"@DG
M;6Y?7W)E<W!?<V5L96-T7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE(&%U
M=&]R97-P;VYD97)S('1O(&)E(')E;6]V960N(BP*"2=M;E]?<V5L96-T7V9I
M;&5S7V9O<E]A='1A8V@G(#T^(")396QE8W0@=&AE(&9I;&5S('1O(&)E(&%T
M=&%C:&5D+B(L"@DG;6Y?7W-E;&5C=%]M;E]F;W)?<F5M;W9E)R`]/B`B4V5L
M96-T('1H92!M86EL(&YA;65S('1O(&)E(')E;6]V960N(BP*"2=M;E]?=6YA
M8FQE7V1E9FEN95]M;B<@/3X@(E5N86)L92!T;R!D969I;F4@;6%I;"!N86UE
M<SH@)3$B+`H))VUN7U]U;F%B;&5?<F5M;W9E7VUB;WA?<75O=&$G(#T^(")5
M;F%B;&4@=&\@<F5S970@=&AE(&QI;6ET(&]N(&UA:6QB;W@@<VEZ93H@)3$B
M+`H))VUN7U]U<&QO861?9FEL92<@/3X@(E5P;&]A9"!F:6QE(BP*"2=M;E]E
M9&ET7U]A9&1?;6%I;%]G<F]U<%]M96UB97)S7V]R7W1U<FY?;V9F7V)O>"<@
M/3X@(EEO=2!S:&]U;&0@861D(&$@;6%I;"!G<F]U<"!M96UB97(@8F5F;W)E
M(&5N86)L:6YG('1H92!M86EL(&=R;W5P+B(L"@DG;6Y?961I=%]?861D7W)E
M<W!?;W)?='5R;E]O9F9?8F]X)R`]/B`B66]U('-H;W5L9"!A9&0@875T;W)E
M<W!O;F1E<B!O<B!D97-E;&5C="!T:&4@875T;W)E<W!O;F1E<B!C:&5C:V)O
M>"XB+`H))VUN7V5D:71?7V%T=&%C:&UE;G1S)R`]/B`B071T86-H;65N=',B
M+`H))VUN7V5D:71?7V1O;5]Q=6]T85]L97-S7W1H96Y?<75O=&$G(#T^(")4
M:&4@<VEZ92!O9B!T:&ES(&UA:6QB;W@@;75S="!N;W0@97AC965D('1H92!L
M:6UI="!O;B!A;6]U;G0@;V8@9&ES:R!S<&%C92!A;&QO8V%T960@9F]R(&AO
M=7-I;F<@;6%I;&)O>&5S(&EN('1H:7,@9&]M86EN+B(L"@DG;6Y?961I=%]?
M96YT97)?97AT97)N86Q?<F-P;G1?96UA:6PG(#T^(")%;G1E<B!E>'1E<FYA
M;"!M86EL(&=R;W5P(&UE;6)E<B=S(&4M;6%I;"(L"@DG;6Y?961I=%]?96YT
M97)?;6%I;%]R961I<E]O<E]T=7)N7V]F9E]B;W@G(#T^(")9;W4@<VAO=6QD
M(&5N=&5R(&$@;6%I;"!R961I<F5C="!O<B!D97-E;&5C="!T:&4@<F5D:7)E
M8W0@8VAE8VMB;W@N(BP*"2=M;E]E9&ET7U]E>'1?<F-P;G1?96UA:6Q?:6YV
M86QI9"<@/3X@(D5X=&5R;F%L(')E8VEP:65N="!E+6UA:6P@861D<F5S<R!I
M<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?9FEL95]E>&ES=',G(#T^(")&:6QE
M(&5X:7-T<RX@3W9E<G=R:71E/R(L"@DG;6Y?961I=%]?9FEL97-?9&5L9%]F
M<F]M7W)E<&]S:71O<GDG(#T^(")4:&5S92!F:6QE<R!W:6QL(&)E(&1E;&5T
M960@9G)O;2!R97!O<VET;W)Y(&%N9"!A=71O<F5S<&]N9&5R<R!C;VYT86EN
M:6YG('1H96TN($1O('EO=2!W86YT('1O('!R;V-E960_(BP*"2=M;E]E9&ET
M7U]M86EL7VYA;64G(#T^(")-86EL(&YA;64B+`H))VUN7V5D:71?7VUA:6Q?
M;F%M95]I;G9A;&ED)R`]/B`B36%I;"!N86UE(&ES(&EN=F%L:60N(BP*"2=M
M;E]E9&ET7U]M86EL7W)E9&ER)R`]/B`B36%I;"!R961I<F5C=',B+`H))VUN
M7V5D:71?7VUA:6Q?<F5D:7)?861D)R`]/B`B061D($UA:6P@1W)O=7`@365M
M8F5R(BP*"2=M;E]E9&ET7U]M86EL7W)E<W!S)R`]/B`B36%I;"!A=71O<F5S
M<&]N9&5R<R(L"@DG;6Y?961I=%]?;6%I;&)O>"<@/3X@(DUA:6QB;W@B+`H)
M)VUN7V5D:71?7VUA:6QG<F]U<"<@/3X@(DUA:6P@9W)O=7`B+`H))VUN7V5D
M:71?7VUA:6QG<F]U<%]A9&1R97-S97,G(#T^(")-86EL(&=R;W5P(&UE;6)E
M<G,B+`H))VUN7V5D:71?7VUA:6QG<F]U<%]D:7-A8FQE9"<@/3X@(D%V86EL
M86)L92!O;FQY('=H96X@;6%I;"!N86UE(&ES(&%L<F5A9'D@861D960B+`H)
M)VUN7V5D:71?7VUA>%]D;VU?<75O=&$G(#T^(")$969A=6QT(&9O<B!T:&4@
M9&]M86EN("@E,2DB+`H))VUN7V5D:71?7VUB;WA?<75O=&%?:6YV86QI9"<@
M/3X@(DEC;W)R96-T(&UA:6QB;W@@<VEZ92!S<&5C:69I960N(BP*"2=M;E]E
M9&ET7U]N97=?<F5S<%]N86UE)R`]/B`B3F5W(&%U=&]R97-P;VYD97(@;F%M
M92(L"@DG;6Y?961I=%]?;F]?875T;W)E<W!O;F1E<G,G(#T^(")9;W4@<VAO
M=6QD(&%D9"!A="!L96%S="!O;F4@875T;W)E<W!O;F1E<B!B969O<F4@='5R
M;FEN9R!T:&4@875T;W)E<W!O;F1E<B!S97)V:6-E(&]N+V]F9BXB+`H))VUN
M7V5D:71?7VYO7V9I;&5?<V5L)R`]/B`B3F\@9FEL97,@<V5L96-T960N(BP*
M"2=M;E]E9&ET7U]N;U]M86EL7V%D9')E<W-E<R<@/3X@(DYO(&4M;6%I;"!A
M9&1R97-S97,@:&%V92!B965N(&5N=&5R960@;W(@<V5L96-T960N(BP*"2=M
M;E]E9&ET7U]N;VYE)R`]/B`B3F]N92(L"@DG;6Y?961I=%]?;F]T7V-R96%T
M95]P87-S)R`]/B`B5&AI<R!W:6QL(&YO="!C<F5A=&4@82!P87-S=V]R9"!F
M;W(@=&AI<R!A8V-O=6YT+EQN5VET:&]U="!P87-S=V]R9"P@=7-E<B!W:6QL
M(&YO="!B92!A8FQE('1O('9I97<@86YD+V]R('-E;F0@;6%I;"XB+`H))VUN
M7V5D:71?7W)E9&ER7V5M86EL7VEN=F%L:60G(#T^(")2961I<F5C="!E+6UA
M:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG;6Y?961I=%]?<F5D:7)E8W0G
M(#T^(")2961I<F5C="(L"@DG;6Y?961I=%]?<F5D:7)E8W1?861D<B<@/3X@
M(E)E9&ER96-T(&%D9')E<W,B+`H))VUN7V5D:71?7W)E;6]V95]A=71O<F5S
M<#\G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H92!A
M=71O<F5S<&]N9&5R/R(L"@DG;6Y?961I=%]?<F5M;W9E7W)C<&YT<S\G(#T^
M(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@<F5M;W9E('1H97-E(')E8VEP
M:65N=',_(BP*"2=M;E]E9&ET7U]R97!O<VET;W)Y)R`]/B`B4F5P;W-I=&]R
M>2(L"@DG;6Y?961I=%]?<F5S<'-?871T86-H)R`]/B`B075T;W)E<W!O;F1E
M<B!A='1A8VAM96YT(&9I;&5S(BP*"2=M;E]E9&ET7U]S96QE8W1?<F-P;G1?
M9G)O;5]L:7-T)R`]/B`B4V5L96-T(&%T(&QE87-T(&]N92!R96-I<&EE;G0@
M9G)O;2!T:&4@;&ES="!T;R!R96UO=F4@:70N(BP*"2=M;E]E9&ET7U]S96QE
M8W1?<F5G:7-T97)E9%]U<V5R<R<@/3X@(E-E;&5C="!R96=I<W1E<F5D('5S
M97)S(BP*"2=M;E]E9&ET7U]S96QE8W1E9%]P;W-T8F]X7VAA=F5?;F]T7W-E
M='5P7W!A<W-W9"<@/3X@(EEO=2!H879E(&-H;W-E;B!T;R!H879E(&$@;6%I
M;&)O>"!B=70@:&%V92!N;W0@<V5T('5P('1H92!P87-S=V]R9"!F;W(@:70N
M(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7VUA:6Q?9W)O=7`G(#T^
M(")5;F%B;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!M86EL(&=R;W5P.B`E
M,2(L"@DG;6Y?961I=%]?=6YA8FQE7V%C=%]D96%C=%]M86EL7W)E9&ER)R`]
M/B`B56YA8FQE('1O(&%C=&EV871E+V1E86-T:79A=&4@;6%I;"!R961I<F5C
M=#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]A8W1?9&5A8W1?<&]S=&)O>"<@
M/3X@(E5N86)L92!T;R!A8W1I=F%T92]D96%C=&EV871E(&UA:6QB;W@Z("4Q
M(BP*"2=M;E]E9&ET7U]U;F%B;&5?86-T7V1E86-T7W)E<W`G(#T^(")5;F%B
M;&4@=&\@86-T:79A=&4O9&5A8W1I=F%T92!A=71O<F5S<&]N9&5R<SH@)3$B
M+`H))VUN7V5D:71?7W5N86)L95]A9&1?871T86-H)R`]/B`B56YA8FQE('1O
M(&%D9"!A='1A8VAM96YT(&9I;&4Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?
M861D7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O(&%D9"!M86EL
M(&=R;W5P(&UE;6)E<CH@)3$B+`H))VUN7V5D:71?7W5N86)L95]A9&1?<F5S
M<"<@/3X@(E5N86)L92!T;R!A9&0@875T;W)E<W!O;F1E<CH@)3$B+`H))VUN
M7V5D:71?7W5N86)L95]C:&%N9V5?;6%I;%]N86UE)R`]/B`B56YA8FQE('1O
M(&-H86YG92!M86EL(&YA;64Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?9&5A
M8W1I=F%T95]M86EL7V=R;W5P)R`]/B`B56YA8FQE('1O(&1E86-T:79A=&4@
M;6%I;"!G<F]U<#H@)3$B+`H))VUN7V5D:71?7W5N86)L95]D96%C=&EV871E
M7W)E<W`G(#T^(")5;F%B;&4@=&\@9&5A8W1I=F%T92!M86EL(&%U=&]R97-P
M;VYD97)S.B`E,2(L"@DG;6Y?961I=%]?=6YA8FQE7V1E9FEN95]R97-P7VED
M)R`]/B`B56YA8FQE('1O(&1E9FEN92!A=71O<F5S<&]N9&5R(&ED.B`E,2(L
M"@DG;6Y?961I=%]?=6YA8FQE7W)E;6]V95]A='1A8V@G(#T^(")5;F%B;&4@
M=&\@<F5M;W9E(&%T=&%C:&UE;G0@9FEL92AS*3H@)3$B+`H))VUN7V5D:71?
M7W5N86)L95]R96UO=F5?875T;W)E<W`G(#T^(")5;F%B;&4@=&\@<F5M;W9E
M(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?<F5M;W9E
M7VUA:6Q?9W)O=7!?;65M8F5R)R`]/B`B56YA8FQE('1O(')E;6]V92!M86EL
M(&=R;W5P(&UE;6)E<G,Z("4Q(BP*"2=M;E]E9&ET7U]U;F%B;&5?<V5T=7!?
M;6%I;%]R961I<B<@/3X@(E5N86)L92!T;R!S970@=7`@;6%I;"!R961I<F5C
M="!A9&1R97-S.B`E,2(L"@DG;6Y?961I=%]?=W)O;F=?=V%Y)PD)"3T^("=4
M:&4@;65S<V%G97,@861D<F5S<V5D('1O("4Q('=I;&P@;F]T(&)E(&1E;&EV
M97)E9"P@87,@=&AE(&UA:6P@;F%M92!I<R!N96ET:&5R(&$@;6%I;&)O>"P@
M;F]R(')E9&ER96-T+"!M86EL(&=R;W5P+"!O<B!A=71O<F5S<&]N9&5R+B<L
M"@DG;6Y?;&ES=%]?;6%I;%]N86UE<U]F;W)?9&]M86EN)R`]/B`B36%I;"!N
M86UE<R!F;W(@9&]M86EN("4Q(BP*"2=M;E]L:7-T7U]S85]C86YN;W1?=6YA
M8FQE)R`]/B`B0V%N;F]T(&5N86)L92!S<&%M(&9I;'1E<FEN9R(L"@DG;6Y?
M;&ES=%]?=&%B7V-P7V%C8V5S<R<@/3X@(DPB+`H))VUN7VQI<W1?7W1A8E]T
M:71L95]C;&EE;G0G(#T^("=#;&EE;G0G+`H))VUN7VQI<W1?7W1A8E]T:71L
M95]D;VUA:6XG(#T^("=$;VUA:6XG+`H))VUN7VQI<W1?7W1A8E]T:71L95]A
M=71O<F5S<"<@/3X@(D$B+`H))VUN7VQI<W1?7W1A8E]T:71L95]B;W@G(#T^
M(")"(BP*"2=M;E]L:7-T7U]T86)?=&ET;&5?9W)O=7`G(#T^(")'(BP*"2=M
M;E]L:7-T7U]T86)?=&ET;&5?;F%M92<@/3X@(DYA;64B+`H))VUN7VQI<W1?
M7W1A8E]T:71L95]R961I<F5C="<@/3X@(E(B+`H))VUN7VQI<W1?7W1A8E]T
M:71L95]S<&%M9FEL=&5R)R`]/B`B4R(L"@DG;6Y?;&ES=%]?=&%B7W1I=&QE
M7V1R=V5B)R`]/B`G058G+`H))VUN7VQI<W1?7W5N86)L95]R96UO=F5?;6YS
M)R`]/B`B56YA8FQE('1O(')E;6]V92!T:&4@;6%I;"!N86UE<SH@)3$B+`H*
M"2=M;V1S7VUA;F%G7U]T:71L92<)"0D)/3X@)TUO9'5L97,@;6%N86=E;65N
M="<L"@DG;6]D<U]M86YA9U]?96UP='E?<V5L96-T:6]N7V9O<E]R96UO=F4G
M(#T^("=396QE8W0@=&AE(&UO9'5L97,@=&\@8F4@<F5M;W9E9"XG+`H))VUO
M9'-?;6%N86=?7V-A;E]N;W1?<F5M;W9E)PD]/B`G56YA8FQE('1O(')E;6]V
M92!M;V1U;&4@)3$Z("4R)RP*"2=M;V1S7W)E;6]V95]?=&ET;&4G"0D)/3X@
M)TUO9'5L92!R96UO=F%L)RP*"2=M;V1U;&5?=7!L;V%D7U]T:71L92<@/3X@
M)U5P;&]A9"!.97<@36]D=6QE)RP*"2=M;V1U;&5?=7!L;V%D7U]F:6QE7VYA
M;64G"3T^("=0871H('1O('1H92!M;V1U;&4@<&%C:V%G92!F:6QE)RP*"2=M
M;V1U;&5?=7!L;V%D7U]M;V1U;&5?=V%S7VEN<W1A;&QE9"<@/3X@)U1H:7,@
M;6]D=6QE(&ES(&%L<F5A9'D@:6YS=&%L;&5D+B!)9B!Y;W4@=VES:"!T;R!I
M;G-T86QL(&$@;F5W97(@=F5R<VEO;B!O9B!T:&ES(&UO9'5L92P@<&QE87-E
M(&1E:6YS=&%L;"!T:&4@;6]D=6QE('1H<F]U9V@@=&AE(&-O;G1R;VP@<&%N
M96PL(&%N9"!T:&5N('1R>2!I;G-T86QL:6YG+B<L"@DG;6]D=6QE7W5P;&]A
M9%]?=6YA8FQE7W1O7VEN<W1A;&PG"3T^("=5;F%B;&4@=&\@:6YS=&%L;"!T
M:&4@;6]D=6QE('!A8VMA9V4@9FEL92<L"@H))VUP8U]?=6YA8FQE7V)U>5]C
M97)T7W5N86)L95]G96YE<F%T95]C<W(G(#T^(")5;F%B;&4@=&\@<'5R8VAA
M<V4@82!C97)T:69I8V%T93H@=6YA8FQE('1O(&=E;F5R871E('1H92!#4U(Z
M("4Q(BP*"2=M<&-?7W5N86)L95]B=7E?8V5R=%]U;F%B;&5?<W1O<F5?<')I
M=F%T95]K97DG(#T^(")5;F%B;&4@=&\@<'5R8VAA<V4@82!C97)T:69I8V%T
M93H@=6YA8FQE('1O('-T;W)E('1H92!P<FEV871E(&ME>3H@)3$B+`H))VYE
M=W-?87)T:6-L97-?=&ET;&4G(#T^("=0;&5S:R!.97=S)RP*"2=N879?7V-U
M<W1O;5]B=71T;VYS)R`]/B`G0W5S=&]M)RP*"2=N879?7V=E;F5R86PG(#T^
M("='96YE<F%L)RP*"2=N879?7W-Y<W1E;2<@/3X@)U-Y<W1E;2<L"@DG;F%V
M7U]H96QP7V%N9%]S=7!P;W)T)R`]/B`G2&5L<"`F(%-U<'!O<G0G+`H))VYO
M7W!S85]M86EL<U]M871C:&5D)R`]/B`B3F\@;6%I;"!A8V-O=6YT<R!M871C
M:&EN9R!Y;W5R(&-R:71E<FEA(BP*"2=N;W1I9FEC871I;VY?=&5X=%]?:6YV
M86QI9%]T97AT7VQE;F=T:"<@/3X@(DEN=F%L:60@;F]T:6-E('1E>'0@;&5N
M9W1H+B!3:&]U;&0@8F4@9G)O;2`Q('1O(#8U-3,S(&-H87)A8W1E<G,N(BP*
M"2=N;W1I9FEC871I;VY?=&5X=%]?=&5X="<@/3X@(DYO=&EC92!T97AT(BP*
M"2=N;W1I9FEC871I;VY?=&5X=%]?=&ET;&4G(#T^(")%9&ET(&YO=&EC92(L
M"@DG;F]T:69I8V%T:6]N7W1E>'1?7W5N86)L95]S971?=&5X="<@/3X@(E5N
M86)L92!T;R!M;V1I9GD@;F]T:6-E('1E>'0Z("(L"@DG;F]T:69I8V%T:6]N
M<U]?=6YA8FQE7W1O7W5P9&%T92<@/3X@(E5N86)L92!T;R!U<&1A=&4@;F]T
M:69I8V%T:6]N.B`E,2(L"@DG;V1B8U]?8V%N=%]A9&1?9'-N)R`]/B`B56YA
M8FQE('1O(&%D9"!$4TX@)3$Z("4R(BP*"2=O9&)C7U]C86YT7V)U:6QD7V-O
M;FYE8W1I;VY?<W1R:6YG)R`]/B`B56YA8FQE('1O(&-O;FYE8W0@=7-I;F<@
M=&AE('!A<F%M971E<G,@<W!E8VEF:65D+"!P;&5A<V4@=')Y(&%G86EN('5S
M:6YG(&1I9F9E<F5N="!P87)A;65T97)S+B!5=&EL:71Y(&AA<R!R971U<FYE
M9#H@)3$B+`H))V]D8F-?7V-A;G1?8V]N;F5C="<@/3X@(E5N86)L92!T;R!C
M;VYN96-T('1O('1H92!D871A('-O=7)C92!U<VEN9R!T:&4@9&5F:6YE9"!S
M971T:6YG<RX@4V5R=F5R(&AA<R!R971U<FYE9#H@)3$B+`H))V]D8F-?7V-A
M;G1?9&5L971E7V1S;B<@/3X@(E5N86)L92!T;R!D96QE=&4@1%-.("4Q.B`E
M,B(L"@DG;V1B8U]?8V%N=%]G971?9')I=F5R<R<@/3X@(E5N86)L92!T;R!R
M971R:65V92!A(&QI<W0@;V8@3T1"0R!D<FEV97)S.B`E,2(L"@DG;V1B8U]?
M8V%N=%]G971?;&ES="<@/3X@(E5N86)L92!T;R!R971R:65V92!A(&QI<W0@
M;V8@97AI<W1I;F<@1%-.<SH@)3$B+`H))V]D8F-?7V-A;G1?<&%R<V5?<W1R
M:6YG)R`]/B`B56YA8FQE('1O('!A<G-E('1H92!C;VYN96-T:6]N('-T<FEN
M9R(L"@DG;V1B8U]?8V]N;F5C=%]S=6-C97-S)R`]/B`B0V]N;F5C=&EO;B!S
M=6-C97-S9G5L(BP*"2=O9&)C7U]D<FEV97)?;F]T7W-E="<@/3X@(D1R:79E
M<B!I<R!N;W0@<V5T(BP*"2=O9&)C7U]D<FEV97)?;W)?;F%M95]N;W1?<V5T
M)R`]/B`B1')I=F5R(&]R(&YA;64@;V8@=&AE($]$0D,@8V]N;F5C=&EO;B!W
M97)E(&YO="!S970B+`H))V]D8F-?7V1S;E]A;')E861Y7V5X:7-T<R<@/3X@
M(D133B!W:71H('1H:7,@;F%M92`H)3$I(&%L<F5A9'D@97AI<W1S(&EN('1H
M92!S>7-T96TB+`H))V]D8F-?7V1S;E]N;W1?97AI<W1S)R`]/B`B5&AI<R!$
M4TX@9&]E<R!N;W0@97AI<W0B+`H))V]D8F-?7V5N=&5R7V-O;FYE8W1I;VY?
M<&%R86US)R`]/B`B66]U('-H;W5L9"!S<&5C:69Y('1H92!O<'1I;VYS('1O
M(&)E('5S960@8GD@=&AE(&1R:79E<BX@069T97(@>6]U(&AA=F4@<W5P<&QI
M960@86QL('1H92!R97%U:7)E9"!D871A+"!Y;W4@=VEL;"!N965D('1O(&-L
M:6-K($9I;FES:"!I;B!O<F1E<B!T;R!C;VUP;&5T92!T:&4@3T1"0R!$4TX@
M8V]N9FEG=7)A=&EO;BXB+`H))V]D8F-?7V5N=&5R7V1S;E]N86UE)R`]/B`B
M16YT97(@1%-.(&YA;64B+`H))V]D8F-?7VEN=F%L:61?9'-N7VYA;64G(#T^
M(")7<F]N9R!S>6YT87@@9F]R($]$0D,@8V]N;F5C=&EO;B!N86UE("@E,2DZ
M('!L96%S92!U<V4@;VYL>2!A;'!H86YU;65R:6,@<WEM8F]L<RXB+`H))V]D
M8F-?7VYO7W-U8VA?9')I=F5R)R`]/B`B3T1"0R!D<FEV97(@=VET:"!S=6-H
M(&YA;64@*"4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*"2=O9&)C7U]R96UO=F5?
M<&%G95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@3T1"0R!$4TX@8V]N;F5C
M=&EO;G,@=VEL;"!B92!R96UO=F5D.B(L"@DG;V1B8U]?<V5L96-T7V1S;E]T
M;U]R96UO=F4G(#T^(")396QE8W0@1%-.<R!T;R!B92!R96UO=F5D+B(L"@DG
M;V1B8U]A9&1?;F5W)R`]/B`B061D(&YE=R!$4TX@8V]N;F5C=&EO;B(L"@DG
M;V1B8U]D<FEV97(G(#T^(")$<FEV97(B+`H))V]D8F-?9'-N7V1E<V-R:7!T
M:6]N)R`]/B`B0V]N;F5C=&EO;B!D97-C<FEP=&EO;B(L"@DG;V1B8U]D<VY?
M;&ES="<@/3X@(D]$0D,@1%-.(&-O;FYE8W1I;VYS(BP*"2=O9&)C7V1S;E]N
M86UE)R`]/B`B0V]N;F5C=&EO;B!N86UE(BP*"2=O9&)C7V1S;E]S>7-T96TG
M(#T^(")3>7-T96T@1%-.(BP*"2=O9&)C7V1S;E]T97AT)R`]/B`B3T1"0R!$
M4TXB+`H))V]D8F-?<F5Q7V9I96QD7VYO=%]S970G(#T^(")297%U:7)E9"!P
M87)A;65T97)S(&%R92!N;W0@<W5P<&QI960N(BP*"2=P8E]?86QI87-E<R<@
M/3X@(D%L:6%S97,B+`H))W!B7U]A;F]N9G1P)R`]/B`B06YO;GEM;W5S($94
M4"(L"@DG<&)?7V%U=&]I;G-T86QL97)?<F5L96%S97,G(#T^("=5<&1A=&5R
M)RP*"2=P8E]?8V5R="<@/3X@(D-E<G1I9FEC871E<R(L"@DG<&)?7V-L7W!O
M;VPG(#T^("))4"!A9&1R97-S97,B+`H))W!B7U]C;%]P;V]L7V-T<FPG(#T^
M("(E,2(L"@DG<&)?7V-L7W!R968G(#T^(")0<F5F97)E;F-E<R(L"@DG<&)?
M7V-L7W)P="<@/3X@(E)E<&]R="(L"@DG<&)?7V-L7W)P=%]L:7-T)R`]/B`B
M0W5S=&]M:7IE(BP*"2=P8E]?8VQ?=&5M<&QA=&5S)R`]/B`B0VQI96YT('1E
M;7!L871E<R(L"@DG<&)?7V-L7W1R869F:6,G(#T^(")4<F%F9FEC(BP*"2=P
M8E]?8VQ?=')A9F9I8U]H:7-T;W)Y)R`]/B`B5')A9F9I8R!H:7-T;W)Y(BP*
M"2=P8E]?8VQ?=')A9F9I8U]O9B<@/3X@(E1R869F:6,@;V8@)3$B+`H))W!B
M7U]C;&EE;G0G(#T^("(E,2(L"@DG<&)?7V-L:65N=',G(#T^(")#;&EE;G1S
M(BP*"2=P8E]?8V]M<%]I;F9O)R`]/B`B0V]M<&]N96YT(&EN9F\B+`H))W!B
M7U]C;VUM;VY?86-L)R`]/B`G06QL;W<@5')A;G-F97(@04-,)RP*"2=P8E]?
M8W!?86-C97-S)R`]/B`B06-C97-S(BP*"2=P8E]?8W)O;G1A8B<@/3X@(E-C
M:&5D=6QE<B(L"@DG<&)?7V-U<W1O;5]B=71T;VYS)R`]/B`B0W5S=&]M($)U
M='1O;G,B+`H))W!B7U]D8B<@/3X@(D1A=&%B87-E<R(L"@DG<&)?7V1B7V5D
M:70G(#T^("(E,2(L"@DG<&)?7V1B7W-E<G9E<E]E9&ET)R`]/B`G)3$G+`H)
M)W!B7U]D8E]S97)V97)S)R`]/B`G1&%T86)A<V4@<V5R=F5R<R<L"@DG<&)?
M7V1L7W5S<E]E9"<@/3X@(D1O;6%I;B!A9&UI;FES=')A=&]R(BP*"2=P8E]?
M9&YS)R`]/B`B1$Y3(BP*"2=P8E]?9&YS7W1E;7!L871E)R`]/B`B1$Y3(BP*
M"2=P8E]?9&YS7W0G(#T^(")$3E,B+`H))W!B7U]D;VU?8W1R;"<@/3X@(B4Q
M(BP*"2=P8E]?9&]M7VQI;2<@/3X@(D1O;6%I;B!L:6UI=',B+`H))W!B7U]D
M;VU?<')E9B<@/3X@(E!R969E<F5N8V5S(BP*"2=P8E]?9&]M7W-U;5]R97!O
M<G0G(#T^(")$;VUA:6X@4W5M;6%R>2!297!O<G0B+`H))W!B7U]D;VU?=&5M
M<&QA=&5S)R`]/B`B1&]M86EN(%1E;7!L871E<R(L"@DG<&)?7V1O;5]T<F%F
M9FEC)R`]/B`B5')A9F9I8R!O9B`E,2(L"@DG<&)?7V1O;5]T<F%F9FEC7VAI
M<W1O<GDG(#T^(")4<F%F9FEC($AI<W1O<GDB+`H))W!B7U]D;VUA:6YS)R`]
M/B`B1&]M86EN<R(L"@DG<&)?7V1U;7!S7VQI<W0G(#T^(")"86-K=7`@1FEL
M97,@4F5P;W-I=&]R>2(L"@DG<&)?7V5V96YT7VAA;F1L97)S)R`]/B`G179E
M;G0@;6%N86=E<B<L"@DG<&)?7V9O<G=A<F1I;F=?<V5T=7`G(#T^(")&;W)W
M87)D:6YG(%-E='5P(BP*"2=P8E]?9FEL96UA;F%G97(G(#T^(")&:6QE($UA
M;F%G97(B+`H))W!B7U]G;&]B86QC:&%N9V5S)R`]/B`B1W)O=7`@3W!E<F%T
M:6]N<R(L"@DG<&)?7VEP7V%L:6%S:6YG)R`]/B`B25`@061D<F5S<V5S(BP*
M"2=P8E]?:7!?9&]M86EN<R<@/3X@(D1O;6%I;G,B+`H))W!B7U]I<%]C;&EE
M;G1S)R`]/B`B25`@061D<F5S<V5S(')E;6]V86PB+`H))W!B7U]L:6-E;G-E
M7VUA;F%G96UE;G0G(#T^("=,:6-E;G-E($UA;F%G96UE;G0G+`H))W!B7U]L
M;V-A;&5S)R`]/B`G3&]C86QE<R<L"@DG<&)?7VQO9U]F:6QE<R<@/3X@(DQO
M9R!F:6QE<R(L"@DG<&)?7VUA:6PG(#T^("=-86EL)RP*"2=P8E]?;6%I;%]B
M;&]C:V5D7V1O;6%I;G,G(#T^("=";&%C:R!L:7-T)RP*"2=P8E]?;6%I;%]N
M86UE7V9I;&5S)R`]/B`B071T86-H;65N="!F:6QE<R(L"@DG<&)?7VUA:6Q?
M;F%M95]E9&ET)R`]/B`B)3$B+`H))W!B7U]M86EL7VYA;65?;6%I;%]G<F]U
M<"<@/3X@(DUA:6P@9W)O=7`B+`H))W!B7U]M86EL7VYA;65?<F5D:7)E8W1S
M)R`]/B`B4F5D:7)E8W1S(BP*"2=P8E]?;6%I;%]N86UE7W)E<W!?871T86-H
M7V%D9"<@/3X@(DYE=R!A='1A8VAM96YT(BP*"2=P8E]?;6%I;%]N86UE7W)E
M<W!?961I="<@/3X@(B4Q(BP*"2=P8E]?;6%I;%]N86UE7W)E<W!O;F1E<G,G
M(#T^(")!=71O<F5S<&]N9&5R<R(L"@DG<&)?7VUA:6Q?;F%M97,G(#T^(")-
M86EL(BP*"2=P8E]?;6%I;%]W:&ET95]L:7-T)R`]/B`G5VAI=&4@;&ES="<L
M"@DG<&)?7VUA:6QL:7-T<R<@/3X@(DUA:6QI;F<@;&ES=',B+`H))W!B7U]M
M;V1U;&5S)R`]/B`G36]D=6QE<R<L"@DG<&)?7VUO9'5L97-?;6%N86=E;65N
M="<@/3X@)TUA;F%G92!-;V1U;&5S)RP*"2=P8E]?;F]T:69I8V%T:6]N<R<@
M/3X@(DYO=&EF:6-A=&EO;G,B+`H))W!B7U]O9&)C)R`]/B`B3T1"0R(L"@DG
M<&)?7W!H;W-T:6YG7W-E='5P)R`]/B`B4&AY<VEC86P@:&]S=&EN9R!S971U
M<"(L"@DG<&)?7W!R=&1?9&ER<R<@/3X@(E!R;W1E8W1E9"!D:7)E8W1O<FEE
M<R(L"@DG<&)?7W!R=&1I<E]E9&ET)R`]/B`B)3$B+`H))W!B7U]R97!O<G0G
M(#T^(")297!O<G0B+`H))W!B7U]R97!O<G1?875T;R<@/3X@(D1E;&EV97)Y
M('-C:&5D=6QE(&9O<B`E,2(L"@DG<&)?7W)E<&]R=%]L:7-T)R`]/B`B0W5S
M=&]M:7IE(BP*"2=P8E]?<V5R=F5R)R`]/B`B4V5R=F5R(BP*"2=P8E]?<V5R
M=F5R7VEN9F\G(#T^(")3;&%V92!S97)V97(@:6YF;W)M871I;VXB+`H))W!B
M7U]S97)V97)?=')A9F9I8R<@/3X@(E-E<G9E<B!T<F%F9FEC(BP*"2=P8E]?
M<V5R=F5R<U]L:7-T)R`]/B`B4VQA=F4@<V5R=F5R(&%C8V]U;G1S(BP*"2=P
M8E]?<V5S<VEO;G,G(#T^(")397-S:6]N<R(L"@DG<&)?7W-A<'!?<&]O;"<@
M/3X@(D%P<&QI8V%T:6]N(%!O;VPB+`H))W!B7U]S:71E87!P7VEN<W1A;&PG
M(#T^(")3:71E($%P<&QI8V%T:6]N($EN<W1A;&QA=&EO;B(L"@DG<&)?7W-I
M=&5?87!P7W!K9W,G(#T^(")3:71E($%P<&QI8V%T:6]N(%!A8VMA9V5S(BP*
M"2=P8E]?<VET95]A<'!S)R`]/B`B4VET92!!<'!L:6-A=&EO;G,B+`H))W!B
M7U]A9&1I=&EO;F%L7VME>5]I;F9O)R`]/B`G2V5Y(%!R;W!E<G1I97,G+`H)
M)W!B7U]A9&1I=&EO;F%L7VME>5]P<F]P97)T:65S)R`]/B`G2V5Y(%!R;W!E
M<G1I97,G+`H))W!B7U]S:V5L971O;B<@/3X@(E-K96QE=&]N($UA;F%G96UE
M;G0B+`H))W!B7U]S:VEN<R<@/3X@)U-K:6YS)RP*"2=P8E]?<VMI;E]I;F9O
M)R`]/B`G)3$G+`H))W!B7U]S<&%M87-S87-S:6XG(#T^(")3<&%M07-S87-S
M:6XB+`H))W!B7U]S=&%T:7-T:6-S)R`]/B`B4W1A=&ES=&EC<R(L"@DG<&)?
M7W-U8F1O;6%I;G,G(#T^(")3=6)D;VUA:6YS(BP*"2=P8E]?=&5M<&QA=&5S
M)R`]/B`B5&5M<&QA=&5S(BP*"2=P8E]?=&EC:V5T<R<@/3X@(E1I8VME=',B
M+`H))W!B7U]T=',G(#T^(")4:6-K971S(BP*"2=P8E]?=V5B7V%P<',G(#T^
M(")4;VUC870B+`H))W!B7U]W96)?=7-E<G,G(#T^(")796(@=7-E<G,B+`H)
M)W!B7U]W96)A;&EZ97)?<')E9F5R96YC97,G(#T^("=796(@4W1A=&ES=&EC
M<R!0<F5F97)E;F-E<R<L"@DG<&1I<E]?96YT97)?9&ER7VYA;64G(#T^(")%
M;G1E<B!D:7)E8W1O<GD@;F%M92XB+`H))W!D:7)?7VEN=F%L:61?:'-T)R`]
M/B`B2&]S=&EN9R!T>7!E(&ES(&EN=F%L:60N($UU<W0@8F4@<&AY<VEC86PN
M(BP*"2=P9&ER7U]P9%]I9%]I<U]U;F1E9FEN960G(#T^(")0<F]T96-T960@
M9&ER96-T;W)Y(&ED(&ES('5N9&5F:6YE9"XB+`H))W!D:7)?7W!D:7)?97AI
M<W0G(#T^(")$:7)E8W1O<GD@=VET:"!T:&ES(&YA;64@:7,@86QR96%D>2!P
M<F]T96-T960N(BP*"2=P9&ER7U]P9&ER7VYO=%]E>&ES="<@/3X@(E!R;W1E
M8W1E9"!D:7)E8W1O<GD@9&]E<R!N;W0@97AI<W0N(BP*"2=P9&ER7U]P9&ER
M7W5S<E]N;W1?97AI<W0G(#T^(")0<F]T96-T960@9&ER96-T;W)Y('5S97(@
M9&]E<R!N;W0@97AI<W0N(BP*"2=P9&ER7U]P<F1I<G-?9F]R7V1O;6%I;B<@
M/3X@(E!R;W1E8W1E9"!D:7)E8W1O<FEE<R!F;W(@9&]M86EN("4Q(BP*"2=P
M9&ER7U]R96UO=F5?<&1I<E]U<W)S)R`]/B`B5&AE(&9O;&QO=VEN9R!U<V5R
M<R!O9B!P<F]T96-T960@9&ER96-T;W)Y("4R(&EN(&1O;6%I;B`E,2!W:6QL
M(&)E(')E;6]V960Z(BP*"2=P9&ER7U]R96UO=F5?<&1I<G-?;VY?9&]M)R`]
M/B`B5&AI<R!O<&5R871I;VX@=VEL;"!R97-U;'0@:6X@<F5M;W9I;F<@<')O
M=&5C=&EO;B!F<F]M('1H92!D:7)E8W1O<FEE<R!O9B!D;VUA:6X@)3(@;W=N
M960@8GD@8VQI96YT("4Q+"!T:&4@9&ER96-T;W)I97,@=&AE;7-E;'9E<R!W
M:6QL(&YO="!B92!E<F%S960N(BP*"2=P9&ER7U]S96QE8W1?<&1I<E]U<W)S
M7V9O<E]R96UO=F4G(#T^(")396QE8W0@=&AE('!R;W1E8W1E9"!D:7)E8W1O
M<GD@=7-E<G,@=&\@8F4@<F5M;W9E9"XB+`H))W!D:7)?7W-E;&5C=%]P9&ER
M<U]T;U]R96UO=F4G(#T^(")396QE8W0@=&AE(&1I<F5C=&]R:65S('1O(')E
M;6]V92!P<F]T96-T:6]N(&9R;VTN(BP*"2=P9&ER7U]U;F%B;&5?9&5F:6YE
M7W!D:7)?=7-E<G,G(#T^(")5;F%B;&4@=&\@9&5F:6YE('1H92!P<F]T96-T
M960@9&ER96-T;W)Y('5S97)S+B(L"@DG<&1I<E]?=6YA8FQE7V1E9FEN95]P
M9&ER<U]P<F]P97)T:65S)R`]/B`B56YA8FQE('1O('-E="!T:&4@<')O=&5C
M=&5D(&1I<F5C=&]R:65S)R!P<F]P97)T:65S.B`E,2(L"@DG<&1I<E]?=6YA
M8FQE7W-E;&5C=%]D;VU?<&%R86TG(#T^(")5;F%B;&4@=&\@<V5L96-T(&1O
M;6%I;B!P87)A;65T97)S.B`E,2(L"@DG<&1I<E]E9%]?8W)E871E7W!D:7)?
M9F]R7V1O;6%I;B<@/3X@(D-R96%T92!N97<@<')O=&5C=&5D(&1I<F5C=&]R
M>2!O;B!D;VUA:6X@)3$B+`H))W!D:7)?961?7V1I<E]A;')E861Y7W!R;W1E
M8W0G(#T^(")4:&ES(&1I<F5C=&]R>2!I<R!A;')E861Y('!R;W1E8W1E9"XB
M+`H))W!D:7)?961?7VAE861?='AT)R`]/B`B2&5A9&5R(%1E>'0B+`H))W!D
M:7)?961?7VEN=F%L:61?;&]G:6XG(#T^(")5<V5R(&YA;64@:7,@:6YV86QI
M9"XB+`H))W!D:7)?961?7VQO9VEN7V5X:7-T<R<@/3X@(E-U8V@@=7-E<B!A
M;')E861Y(&5X:7-T<RX@5')Y(&%N;W1H97(@;&]G:6X@;F%M92XB+`H))W!D
M:7)?961?7VYE=U]U<W(G(#T^(").97<@=7-E<B(L"@DG<&1I<E]E9%]?;F]N
M7W-S;"<@/3X@(DYO;BU34TPB+`H))W!D:7)?961?7V-G:5]B:6XG(#T^(")C
M9VDM8FEN(BP*"2=P9&ER7V5D7U]P871H)R`]/B`B1&ER96-T;W)Y(&YA;64B
M+`H))W!D:7)?961?7W!D:7)?9F]R7V1O;6%I;B<@/3X@(E!R;W1E8W1E9"!D
M:7)E8W1O<GD@)3$@;VX@9&]M86EN("4R(BP*"2=P9&ER7V5D7U]P9&ER7VQO
M8V%T:6]N)R`]/B`B1&ER96-T;W)Y(&QO8V%T:6]N(BP*"2=P9&ER7V5D7U]P
M9&ER7W5S97)S)R`]/B`B4')O=&5C=&5D(&1I<F5C=&]R>2!U<V5R<R(L"@DG
M<&1I<E]E9%]?<W-L)R`]/B`B4U-,(BP*"2=P9&ER7V5D7U]S<VQ?;F]T7W-U
M<'!O<G1E9%]D;VUA:6XG(#T^(")34TP@:7,@;F]T('-U<'!O<G1E9"!I;B!T
M:&ES(&1O;6%I;BXB+`H))W!D:7)?961?7W-S;%]O<E]N;VYS<VQ?<VAO=6QD
M7V)E7V-H96-K960G(#T^(")!="!L96%S="!O;F4@8VAE8VMB;W@@<VAO=6QD
M(&)E('-E;&5C=&5D(&9R;VT@4U-,(&%N9"!.;VXM4U-,(&-H96-K8F]X97,N
M(BP*"2=P9&ER7V5D7U]U;F%B;&5?8W)?<&1I<E]U<W(G(#T^(")5;F%B;&4@
M=&\@8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S97(Z("4Q(BP*
M"2=P9&ER7V5D7U]U;F%B;&5?8W)E871E7W!D:7(G(#T^(")5;F%B;&4@=&\@
M8W)E871E('1H92!P<F]T96-T960@9&ER96-T;W)Y.B`E,2(L"@DG<&1I<E]E
M9%]?=6YA8FQE7V1E9FEN95]H<W1?='EP92<@/3X@(E5N86)L92!T;R!D969I
M;F4@=&AE(&AO<W1I;F<@='EP92XB+`H))W!D:7)?961?7W5N86)L95]U<&1A
M=&5?<&1I<B<@/3X@(E5N86)L92!T;R!U<&1A=&4@=&AE('!R;W1E8W1E9"!D
M:7)E8W1O<GDZ("4Q(BP*"2=P9&ER7V5D7U]W<F]N9U]S>6UB;VQ?:6Y?:&5A
M9&5R)R`]/B`B4&QE87-E+"!D;R!N;W0@=7-E('-Y;6)O;"`E,2!I;B!T:&4@
M9&ER96-T;W)Y(&AE861E<B(L"@DG<&1I<E]U<W)?961?7V-R96%T95]P9&ER
M7W5S<E]F;W)?<&0G(#T^(")#<F5A=&4@=7-E<B!F;W(@=&AE('!R;W1E8W1E
M9"!D:7)E8W1O<GD@)3$B+`H))W!D:7)?=7-R7V5D7U]N;W1?8W)E871E7W!A
M<W,G(#T^(")4:&ES('=I;&P@;F]T(&-R96%T92!A('!A<W-W;W)D(&9O<B!T
M:&4@;F5W('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<BY<;E=I=&AO=70@<&%S
M<W=O<F0@=&AE('5S97(@=VEL;"!N;W0@8F4@86)L92!T;R!L;V<@:6XN(BP*
M"2=P9&ER7W5S<E]E9%]?<&%S<U]F;W)?<&1I<E]U<W(G(#T^(")087-S=V]R
M9"!F;W(@=&AE('!R;W1E8W1E9"!D:7)E8W1O<GD@=7-E<B`E,2(L"@DG<&1I
M<E]U<W)?961?7W5N86)L95]S96QE8W1?<&1I<E]U<W(G(#T^(")5;F%B;&4@
M=&\@<V5L96-T('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S97(Z("4Q(BP*
M"2=P9&ER7W5S<G-?;&ES=%]?=6YA8FQE7V1E9FEN95]P9&ER7W5S<G,G(#T^
M(")5;F%B;&4@=&\@9&5F:6YE('1H92!P<F]T96-T960@9&ER96-T;W)Y('5S
M97)S.B`E,2(L"@DG<&1I<E]U<W)S7VQI<W1?7W5N86)L95]R96UO=F5?<&1?
M=7-R<R<@/3X@(E5N86)L92!T;R!R96UO=F4@=&AE('!R;W1E8W1E9"!D:7)E
M8W1O<GD@=7-E<G,Z("4Q(BP*"2=P9&ER<U]L:7-T7U]N86UE)R`]/B`B3F%M
M92(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7VYO;E]S96-U<F5?9&ER)R`]
M/B`B3B(L"@DG<&1I<G-?;&ES=%]?=&%B7W1I=&QE7W-E8W5R95]D:7(G(#T^
M(")3(BP*"2=P9&ER<U]L:7-T7U]T86)?=&ET;&5?8V=I7V)I;E]D:7(G(#T^
M(")#(BP*"2=P9&ER<U]L:7-T7U]U;F%B;&5?<F5M;W9E7W!D:7)S)R`]/B`B
M56YA8FQE('1O(')E;6]V92!T:&4@<')O=&5C=&5D(&1I<F5C=&]R:65S.B`E
M,2(L"@DG<&AO<W1I;F=?7V%N;VYF='!?9&ES86)L960G(#T^(")!;F]N>6UO
M=7,@1E10('-E<G9I8V4@:7,@9&ES86)L960@;VX@=&AI<R!D;VUA:6X@87,@
M=&AI<R!)4"!A9&1R97-S(&ES(&%L<F5A9'D@8F5I;F<@=7-E9"!F;W(@86YO
M;GEM;W5S($944"!S97)V:6-E(&]N(&%N;W1H97(@9&]M86EN+B(L"@DG<&AO
M<W1I;F=?7V%N;VYF='!?96YC<GEP="<)/3X@)U1H92!P87-S=V]R9"!O9B!&
M5%`@=7-E<B!I<R!E;F-R>7!T960L(&%N9"!T:&5R969O<F4@8V%N;F]T(&)E
M('5S960@9F]R('!R;W1E8W1I;F<@9&ER96-T;W)Y("]P;&5S:RUS=&%T+RX@
M4&QE87-E(')E96YT97(@>6]U<B!&5%`@<&%S<W=O<F0L(&]R(&1E<V5L96-T
M('1H92!O<'1I;VX@(F%C8V5S<VEB;&4@=FEA('!A<W-W;W)D('!R;W1E8W1E
M9"!D:7)E8W1O<GD@7"<O<&QE<VLM<W1A="]<)R(G+`H))W!H;W-T:6YG7U]I
M<%]C:&%N9V5?=V%R;FEN9R<@/3X@(DE0(&%D9')E<W,@8VAA;F=E9"X@5&AE
M(&-O<G)E<W!O;F1I;F<@8VAA;F=E<R!W97)E(&%L<V\@;6%D92!I;B!T:&4@
M9&]M86EN)W,@1$Y3('IO;F4N(BP*"2=P:&]S=&EN9U]?;W1H97)?:&]S=&EN
M9U]E>&ES='-?;VY?:7`G(#T^(")5;F%B;&4@=&\@8VAA;F=E('1H92!C97)T
M:69I8V%T92!B96-A=7-E('1H:7,@:7`@861D<F5S<R!I<R!B96EN9R!U<V5D
M(&EN(&]N92!O<B!S979E<F%L(&AO<W1I;F<@86-C;W5N=',N(BP*"2=P:&]S
M=&EN9U]?=6YA8FQE7W1O7V-H86YG95]C97)T:69I8V%T92<@/3X@(E5N86)L
M92!T;R!I;G-T86QL('1H92!C97)T:69I8V%T93H@)3$B+`H))W!H;W-T:6YG
M7U]U;F%B;&5?=&]?8VAA;F=E7VEP7V%D9')E<W,G(#T^(")5;F%B;&4@=&\@
M8VAA;F=E('1H92!I<"!A9&1R97-S.B`E,2(L"@DG<&AO<W1I;F=?7W5N86)L
M95]T;U]S971?8V5R="<@/3X@(E5N86)L92!T;R!S970@=&AE('-S;"!C97)T
M:69I8V%T93H@)3$B+`H))W!H;W-T:6YG7U]U;F%B;&5?=7!D871E)R`]/B`B
M56YA8FQE('1O('5P9&%T92!H;W-T:6YG('!R969E<F5N8V5S.B`E,2(L"@DG
M<&AO<W1I;F=?7W5N86)L95]M86YA9V4G(#T^(")5;F%B;&4@=&\@;6%N86=E
M(&AO<W1I;F<Z("4Q(BP*"@DG<&EC:V5R7V%U=&]R97-P;VYD97)?7W1I=&QE
M)R`]/B`G075T;W)E<W!O;F1E<B!S96QE8W1I;VXG+`H))W!I8VME<E]C;&EE
M;G1?7W1I=&QE)R`]/B`G0VQI96YT('-E;&5C=&EO;B<L"@DG<&EC:V5R7V1A
M=&%B87-E7U]T:71L92<@/3X@)T1A=&%B87-E('-E;&5C=&EO;B<L"@DG<&EC
M:V5R7V1O;6%I;E]?=&ET;&4G(#T^("=$;VUA:6X@<V5L96-T:6]N)RP*"2=P
M:6-K97)?;6%I;&YA;65?7W1I=&QE)R`]/B`G36%I;&YA;64@<V5L96-T:6]N
M)RP*"2=P:6-K97)?<VET95]A<'!L:6-A=&EO;E]?=&ET;&4G(#T^("=3:71E
M(&%P<&QI8V%T:6]N('-E;&5C=&EO;B<L"@DG<&EC:V5R7W-U8F1O;6%I;E]?
M=&ET;&4G(#T^("=3=6)D;VUA:6X@<V5L96-T:6]N)RP*"2=P:6-K97)?=V5B
M7W5S97)?7W1I=&QE)R`]/B`G5V5B('5S97(@<V5L96-T:6]N)RP*"2=P:6-K
M97)?8W5S=&]M7V)U='1O;E]?=&ET;&4G(#T^("=#=7-T;VT@8G5T=&]N('-E
M;&5C=&EO;B<L"@H))W!L97-K7V=U:61E)R`]/B`B4&QE<VL@57-E<B=S($=U
M:61E(BP*"2=P;&5S:U]K97E?7V%C=&EO;E]L;V=S)R`]/B`B06)I;&ET>2!T
M;R!U<V4@86-T:6]N(&QO9V=I;F<B+`H))W!L97-K7VME>5]?87!P7W9A=6QT
M)R`]/B`B06)I;&ET>2!T;R!U<V4@87!P;&EC871I;VX@=F%U;'0B+`H))W!L
M97-K7VME>5]?8F%C:W5P)R`]/B`B06)I;&ET>2!T;R!U<V4@=&AE(&)A8VMU
M<"!F=6YC=&EO;G,B+`H))W!L97-K7VME>5]?8VQI96YT7W1E;7!L<R<@/3X@
M(D%B:6QI='D@=&\@;6%N86=E(&-L:65N="!T96UP;&%T97,B+`H))W!L97-K
M7VME>5]?8VQI96YT<R<@/3X@(DUA>&EM=6T@;G5M8F5R(&]F(&-L:65N="!A
M8V-O=6YT<R(L"@DG<&QE<VM?:V5Y7U]C;VQD9G5S:6]N)R`]/B`B06)I;&ET
M>2!T;R!U<V4@0V]L9$9U<VEO;B(L"@DG<&QE<VM?:V5Y7U]D;VUA:6YS)R`]
M/B`B36%X:6UU;2!N=6UB97(@;V8@9&]M86EN<R(L"@DG<&QE<VM?:V5Y7U]D
M87-H8F]A<F0G(#T^("=!8FEL:71Y('1O('5S92!$97-K=&]P(&EN=&5R9F%C
M92<L"@DG<&QE<VM?:V5Y7U]S=&1G=6DG(#T^("=!8FEL:71Y('1O('5S92!S
M=&%N9&%R9"!I;G1E<F9A8V4G+`H))W!L97-K7VME>5]?;6%N86=E7V1A<VAB
M;V%R9"<@/3X@)T%B:6QI='D@=&\@;6%N86=E($1E<VMT;W`G+`H))W!L97-K
M7VME>5]?:V5Y7VEP7W)A;F=E<R<@/3X@)UEO=2!C86X@=7-E(%!L97-K(&]N
M;'D@=VET:"!T:&4@9F]L;&]W:6YG($E0(&%D9')E<W-E<SHG+`H))W!L97-K
M7VME>5]?9')W96(G(#T^(")!8FEL:71Y('1O('5S92!$<BY796(@86YT:79I
M<G5S(BP*"2=P;&5S:U]K97E?7V5V96YT7VUA;F%G97(G(#T^(")!8FEL:71Y
M('1O('5S92!E=F5N="!M86YA9V5R(BP*"2=P;&5S:U]K97E?7V5X<&ER871I
M;VYS)R`]/B`B06)I;&ET>2!T;R!M86YA9V4@9&]M86EN(&%N9"!C;&EE;G0@
M86-C;W5N="!E>'!I<F%T:6]N(&1A=&5S(BP*"2=P;&5S:U]K97E?7V=R;W5P
M7V]P<R<@/3X@(D%B:6QI='D@=&\@<&5R9F]R;2!G;&]B86P@;W!E<F%T:6]N
M<R!O;B!O8FIE8W1S("AG<F]U<"!O<&5R871I;VYS*2(L"@DG<&QE<VM?:V5Y
M7U]E>'!I<F%T:6]N)R`]/B`B2V5Y(&5X<&ER871I;VX@9&%T92(L"@DG<&QE
M<VM?:V5Y7U]K97E?;G5M8F5R)R`]/B`B2V5Y(&YU;6)E<B(L"@DG<&QE<VM?
M:V5Y7U]L86YG=6%G97,G(#T^(")-87AI;75M(&YU;6)E<B!O9B!L86YG=6%G
M92!P86-K<R(L"@DG<&QE<VM?:V5Y7U]M86EL;F%M97,G(#T^(")-87AI;75M
M(&YU;6)E<B!O9B!M86EL(&%C8V]U;G1S(BP*"2=P;&5S:U]K97E?7VUI9W)A
M=&EO;E]M86YA9V5R)R`]/B`B06)I;&ET>2!T;R!U<V4@36EG<F%T:6]N($UA
M;F%G97(B+`H))W!L97-K7VME>5]?;7-S<6PG(#T^(")!8FEL:71Y('1O('5S
M92!-:6-R;W-O9G0@4U%,(%-E<G9E<B(L"@DG<&QE<VM?:V5Y7U]M>7!L97-K
M7V9U;F,G(#T^(")-4$,@9G5N8W1I;VYA;&ET>2(L"@DG<&QE<VM?:V5Y7U]M
M>7!L97-K7VUA;F%G92<@/3X@(D%D;6EN:7-T<F%T;W(@8V%N(&UA;F%G92!-
M4$,@<V5R=FEC92!A8V-E<W-I8FEL:71Y(BP*"2=P;&5S:U]K97E?7VUY<&QE
M<VM?<V5R=F5R7VED)R`]/B`B35!#('-L879E('-E<G9E<B!I9&5N=&EF:65R
M(BP*"2=P;&5S:U]K97E?7VYO=&EF:6-A=&EO;G,G(#T^(")!8FEL:71Y('1O
M(&UA;F%G92!N;W1I9FEC871I;VYS(BP*"2=P;&5S:U]K97E?7W!O<W1G<F5S
M<6PG(#T^(")!8FEL:71Y('1O('5S92!0;W-T9W)E4U%,(BP*"2=P;&5S:U]K
M97E?7W%M86EL7W%U975E)R`]/B`G06)I;&ET>2!T;R!M86YA9V4@;6%I;"!Q
M=65U92<L"@DG<&QE<VM?:V5Y7U]R96UO=&5?9&(G(#T^("=!8FEL:71Y('1O
M('5S92!R96UO=&4@9&%T86)A<V4@:&]S=&EN9R<L"@DG<&QE<VM?:V5Y7U]S
M:71E8G5I;&1E<B<@/3X@(D%B:6QI='D@=&\@=7-E($UA;6)O($--4R(L"@DG
M<&QE<VM?:V5Y7U]S;&%V95]S97)V97)S)R`]/B`B4VQA=F4@<V5R=F5R<R!L
M:6UI="(L"@DG<&QE<VM?:V5Y7U]S<&%M87-S87-S:6XG(#T^(")!8FEL:71Y
M('1O('5S92!3<&%M07-S87-S:6XB+`H))W!L97-K7VME>5]?<W5B9&]M86EN
M<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E('-U8F1O;6%I;G,B+`H))W!L97-K
M7VME>5]?<WES7V%C8V5S<R<@/3X@(D%B:6QI='D@=&\@;6%N86=E('-H96QL
M(&%C8V5S<R(L"@DG<&QE<VM?:V5Y7U]T;VUC870G(#T^(")!8FEL:71Y('1O
M('5S92!4;VUC870B+`H))W!L97-K7VME>5]?=')A9F9I8U]R97!O<G1S)R`]
M/B`B06)I;&ET>2!T;R!U<V4@=')A9F9I8R!R97!O<G1I;F<B+`H))W!L97-K
M7VME>5]?='1S)R`]/B`B06)I;&ET>2!T;R!U<V4@2&5L<"!$97-K(BP*"2=P
M;&5S:U]K97E?7W9I<G1U;WIZ;R<@/3X@(E9A;&ED(&9O<B!6:7)T=6]Z>F\@
M;VYL>2(L"@DG<&QE<VM?:V5Y7U]W96)U<V5R<R<@/3X@(DUA>&EM=6T@;G5M
M8F5R(&]F('=E8B!U<V5R<R(L"@DG<&QE<VM?:V5Y7U]L:6-E;G-E7W5P9&%T
M95]D871E)R`]/B`G3F5X="!L:6-E;G-E(&ME>2!U<&1A=&4G+`H))W!L97-K
M7VME>5]?875T;VEN<W1A;&QE<E]C;VYF:6<G(#T^("=!8FEL:71Y('1O(&UA
M;F%G92!U<&1A=&5R('!R969E<F5N8V5S)RP*"2=P;&5S:U]K97E?=7!D871E
M7U]T:71L92<@/3X@)TME>2!5<&1A=&4@4W1A='5S)RP*"2=P;&5S:U]K97E?
M=7!D871E7U]L96=E;F0G(#T^("=+97D@57!D871E(%-T871U<R<L"@DG<&QE
M<VM?:V5Y7W5P9&%T95]?;F5W7V%D9&ET:6]N86Q?:V5Y)R`]/B`G3F5W(&%D
M9&ET:6]N86P@:V5Y(')E8V5I=F5D)RP*"@DG<&QE<VM?:V5Y7U]C:&5C:U]W
M<F]N9R<@"0D)"3T^("=4:&4@;&EC96YS92!K97D@:7,@;F]T('9A;&ED+B!4
M;R!U<V4@=&AE(&-O;G1R;VP@<&%N96PL(&]B=&%I;B!A;F0@:6YS=&%L;"!A
M(&YE=R!F=6QL>2!F96%T=7)E9"!L:6-E;G-E(&ME>2XG+`H))W!L97-K7VME
M>5]?=7!L;V%D7V-H96-K7W=R;VYG)PD)"3T^("=4:&4@=7!L;V%D960@;&EC
M96YS92!K97D@:7,@;F]T('9A;&ED+B<L"@DG<&QE<VM?:V5Y7U]R979E<G1?
M8VAE8VM?=W)O;F<G"0D)/3X@)U1H92!P<F5V:6]U<VQY(&EN<W1A;&QE9"!L
M:6-E;G-E(&ME>2!I<R!N;W0@=F%L:60N)RP*"2=P;&5S:U]K97E?7W5P9&%T
M95]C:&5C:U]W<F]N9R<)"0D]/B`G5&AE('5P9&%T960@;&EC96YS92!K97D@
M:7,@;F]T('9A;&ED+B<L"@H))W!L97-K7VME>5]?:V5Y7V5X<&ER960G"0D)
M"3T^("=9;W5R(&QI8V5N<V4@:V5Y(&AA<R!E>'!I<F5D+B!4;R!C;VYT:6YU
M92!U<VEN9R!Y;W5R(&-O;G1R;VP@<&%N96PL('EO=2!M=7-T('!U<F-H87-E
M(&$@;F]N+65X<&ER:6YG(&-O;6UE<F-I86P@;&EC96YS92XG+`H))W!L97-K
M7VME>5]?=FER=6]Z>F]?;VYL>5]K97DG"0D)/3X@)U1H92!L:6-E;G-E(&ME
M>2!I<R!I;G1E;F1E9"!O;FQY(&9O<B!U<V4@=VET:"!0;&5S:R!I;G-I9&4@
M5FER='5O>GIO('9I<G1U86P@<')I=F%T92!S97)V97)S+B<L"@DG<&QE<VM?
M:V5Y7U]E87-Y7VUI<W5S960G"0D)"3T^("=4:&4@;&EC96YS92!K97D@9F]R
M(%!L97-K($5A<WD@86QL;W=S('-E<G9I;F<@;VYL>2!O;F4@8VQI96YT(&%C
M8V]U;G0N(%EO=2!H879E("4Q(&-L:65N=',N)RP*"2=P;&5S:U]K97E?7VEP
M7W)A;F=E<U]E>&-E961E9"<)"0D]/B`G66]U(&-A;B!U<V4@=&AI<R!L:6-E
M;G-E9"!0;&5S:R!C;W!Y(&]N;'D@=VET:"!T:&4@9F]L;&]W:6YG($E0(&%D
M9')E<W-E<SH@)3(N(%1H92!F;VQL;W=I;F<@25`@861D<F5S<V5S(&%R92!N
M;W0@8V]V97)E9"!B>2!Y;W5R(&QI8V5N<V4Z("4Q+B<L("\O)3$@=6YA;&QO
M=V5D(&%D9')E<W-E<R!L:7-T('-E<&%R871E9"!B>2!C;VUM82P@)3(@86QL
M;W=E9"!I<"!A9&1R97-S97,@;&ES="!S97!A<F%T960@8GD@8V]M;6$*"2=P
M;&5S:U]K97E?7VQI;6ET<U]E>&-E961E9"<)"0D]/B`G5&AE(&%M;W5N="!O
M9B!C=7)R96YT;'D@=7-E9"!R97-O=7)C97,@;W9E<G)I9&5S('1H92!L:6UI
M=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4N)RP*"2=P;&5S:U]K97E?7VQI
M;6ET<U]E>&-E961E9%]L:6U?9&]M)PD]/B`G5&AE(&YU;6)E<B!O9B!W96(@
M<VET97,@:&]S=&5D(&]N('1H92!S97)V97(@97AC965D<R!T:&4@;&EM:71S
M(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!9;W4@:&%V92`E,B!S:71E<R!H
M;W-T960[('EO=7(@;&EC96YS92!A;&QO=W,@:&]S=&EN9R!O;FQY("4Q('-I
M=&5S+B<L("\O("4Q(&QI;6ET('9A;'5E+"`E,B!U<V5D('9A;'5E+"`E,R!D
M96QT82!V86QU90H))W!L97-K7VME>5]?;&EM:71S7V5X8V5E9&5D7VQI;5]C
M;"<)"3T^("=4:&4@;G5M8F5R(&]F('-E<G9E9"!C;&EE;G0@86-C;W5N=',@
M97AC965D<R!T:&4@;&EM:71S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E+B!9
M;W4@:&%V92`E,B!C;&EE;G0@86-C;W5N=',@8W5R<F5N=&QY('-E<G9E9#L@
M>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG(&]N;'D@)3$@8VQI96YT(&%C
M8V]U;G1S+B<L("\O)3$@;&EM:70@=F%L=64L("4R('5S960@=F%L=64L("4S
M(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?97AC965D961?;&EM
M7VUN)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D(&4M;6%I;"!A8V-O=6YT
M<R!E>&-E961S('1H92!L:6UI=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4N
M(%EO=2!H879E("4R(&4M;6%I;"!A8V-O=6YT<R!C=7)R96YT;'D@<V5R=F5D
M.R!Y;W5R(&QI8V5N<V4@86QL;W=S('-E<G9I;F<@;VYL>2`E,2!E+6UA:6P@
M86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L=64L("4R('5S960@=F%L=64L
M("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?97AC965D961?
M;&EM7W=U)PD)/3X@)U1H92!N=6UB97(@;V8@<V5R=F5D('=E8B!U<V5R(&%C
M8V]U;G1S(&5X8V5E9',@=&AE(&QI;6ET<R!D969I;F5D(&)Y('EO=7(@;&EC
M96YS92X@66]U(&AA=F4@)3(@=V5B('5S97(@86-C;W5N=',@8W5R<F5N=&QY
M('-E<G9E9#L@>6]U<B!L:6-E;G-E(&%L;&]W<R!S97)V:6YG(&]N;'D@)3$@
M=V5B('5S97(@86-C;W5N=',N)RP@+R\@)3$@;&EM:70@=F%L=64L("4R('5S
M960@=F%L=64L("4S(&1E;'1A('9A;'5E"@DG<&QE<VM?:V5Y7U]L:6UI='-?
M97AC965D961?34Q3)PD)/3X@)U1H92!N=6UB97(@;V8@8W5R<F5N=&QY('5S
M960@;&%N9W5A9V4@<&%C:W,@97AC965D<R!T:&4@;&EM:71S(&1E9FEN960@
M8GD@>6]U<B!L:6-E;G-E+B!4:&5R92!A<F4@)3(@;&%N9W5A9V4@<&%C:W,@
M:6YS=&%L;&5D.R!Y;W5R(&QI8V5N<V4@86QL;W=S(&EN<W1A;&QI;F<@;VYL
M>2`E,2!L86YG=6%G92!P86-K<RXG+"`O+R`E,2!L:6UI="!V86QU92P@)3(@
M=7-E9"!V86QU92P@)3,@9&5L=&$@=F%L=64*"@DG<&QE<VM?:V5Y7U]K97E?
M9FEL95]I;G9A;&ED)R`]/B`G5&AE('5P;&]A9&5D(&ME>2!F:6QE(&ES(&YO
M="!V86QI9"!O<B!D;V5S(&YO="!C;VYT86EN(&$@;&EC96YS92!K97DN)RP*
M"2=K97E?7W1I=&QE)R`]/B`G3&EC96YS92!-86YA9V5M96YT)RP*"2=K97E?
M7W5P;&]A9%]T:71L92<@/3X@)TQI8V5N<V4@2V5Y(%5P;&]A9"<L"@DG:V5Y
M7U]U<&QO861?;&5G96YD)R`]/B`G3&EC96YS92!K97D@=7!L;V%D)RP*"2=K
M97E?7V9I;&4G(#T^("=0871H('1O('1H92!L:6-E;G-E(&ME>2!F:6QE(&QO
M8V%T:6]N)RP*"2=K97E?7VYO7VME>5]F:6QE7VEN7WII<"<@/3X@)U1H92!U
M<&QO861E9"`N>FEP(&9I;&4@9&]E<R!N;W0@8V]N=&%I;B!K97D@9FEL92<L
M"@DG:V5Y7U]K97E?=7!L;V%D)R`]/B`G3&EC96YS92!+97D@26YS=&%L;&%T
M:6]N)RP*"2=K97E?7V]V97)W<FET95]C;VYF:7)M871I;VXG(#T^("=297!L
M86-E('1H92!C=7)R96YT;'D@:6YS=&%L;&5D(&QI8V5N<V4@:V5Y('=I=&@@
M=&AE('-E;&5C=&5D(&]N92<L"@DG:V5Y7U]O=F5R=W)I=&5?8V]N9FER;6%T
M:6]N7W)E<75I<F5D)R`]/B`G4&QE87-E(&-O;F9I<FT@=&AE(&QI8V5N<V4@
M:V5Y(')E<&QA8V5M96YT+B<L"@DG:V5Y7U]L:6UI='-?97AC965D961?8V]N
M9FER;6%T:6]N)R`]/B`G1&\@;F]T(&-H96-K('1H92!L:6UI=',@;VX@<F5S
M;W5R8V4@=7-A9V4@9&5F:6YE9"!B>2!T:&4@:V5Y)RP*"2=K97E?7W1A8G-?
M<&QE<VLG(#T^("=0;&5S:R!,:6-E;G-E($ME>2<L"@DG:V5Y7U]T86)S7V%D
M9&ET:6]N86PG(#T^("=!9&1I=&EO;F%L($QI8V5N<V4@2V5Y<R<L"@DG:V5Y
M7W)E=F5R=%]?=&ET;&4G(#T^("=,:6-E;G-E($ME>2!2;VQL8F%C:R<L"@DG
M:V5Y7W)E=F5R=%]?;&5G96YD)R`]/B`G2V5Y(')O;&QB86-K(&-O;F9I<FUA
M=&EO;B<L"@DG:V5Y7W)E=F5R=%]?=&5X="<@/3X@)U1H92!L:6-E;G-E(&ME
M>2!W:71H('1H92!F;VQL;W=I;F<@<')O<&5R=&EE<R!W:6QL(&)E(')E<W1O
M<F5D.B<L"@DG861D:71I;VYA;%]K97E?7VEN9F\G(#T^("=!9&1I=&EO;F%L
M($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]?<')O<%]N86UE
M)R`]/B`G4')O<&5R='DG+`H))V%D9&ET:6]N86Q?:V5Y7U]P<F]P7W9A;'5E
M)R`]/B`G5F%L=64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C<E]N86UE)R`]
M/B`G2V5Y(&YA;64G+`H))V%D9&ET:6]N86Q?:V5Y7U]D97-C<E]K97E?;G5M
M8F5R)R`]/B`G2V5Y(&YU;6)E<B<L"@DG861D:71I;VYA;%]K97E?7V1E<V-R
M7VQI;5]D871E)R`]/B`G17AP:7)A=&EO;B!D871E)RP*"2=A9&1I=&EO;F%L
M7VME>5]?9&5S8W)?;&EC96YS95]U<&1A=&5?9&%T92<@/3X@)TYE>'0@;&EC
M96YS92!K97D@=7!D871E)RP*"2=A9&1I=&EO;F%L7VME>5]?<F5M;W9E7W1I
M=&QE)R`]/B`B5&AE('-I=&4@87!P;&EC871I;VX@:V5Y('=I=&@@=&AE(&9O
M;&QO=VEN9R!P<F]P97)T:65S('=I;&P@8F4@<F5M;W9E9#HB+`H))V%D9&ET
M:6]N86Q?:V5Y<U]?<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!A
M9&1I=&EO;F%L(&ME>7,@=VEL;"!B92!R96UO=F5D.B(L"@DG861D:71I;VYA
M;%]K97ES7U]S96QE8W1?=&]?<F5M;W9E)R`]/B`G4V5L96-T('1H92!A9&1I
M=&EO;F%L(&ME>7,@=&\@8F4@<F5M;W9E9"XG+`H))V%D9&ET:6]N86Q?:V5Y
M7U]F:6QE7VEN=F%L:60G(#T^("=4:&4@=7!L;V%D960@:V5Y(&9I;&4@:7,@
M;F]T('9A;&ED(&]R(&1O97,@;F]T(&-O;G1A:6X@82!L:6-E;G-E(&ME>2XG
M+`H))V%D9&ET:6]N86Q?:V5Y7U]F:6QE7VEN8V]M<&%T:6)L92<@/3X@)U1H
M92!U<&QO861E9"!K97D@9FEL92!I<R!N;W0@=F%L:60@9F]R('1H:7,@87!P
M;&EC871I;VXN)RP*"2=A9&1I=&EO;F%L7VME>5]?;F]T7V5X:7-T<R<@/3X@
M)TYO(&QI8V5N<V4@:V5Y(&EN<W1A;&QE9"XG+`H))V%D9&ET:6]N86Q?:V5Y
M<U]?;&5G96YD)R`]/B`G061D:71I;VYA;"!K97ES)RP*"2=A9&1I=&EO;F%L
M7VME>7-?7VQI<W1?:&5A9&5R)R`]/B`G061D:71I;VYA;"!K97ES)RP*"2=A
M9&1I=&EO;F%L7VME>5]U<&1A=&5?7W1I=&QE)R`]/B`G57!D871I;F<@061D
M:71I;VYA;"!+97DN)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7VQE9V5N
M9"<@/3X@)U-T871U<R!O9B!A9&1I=&EO;F%L(&ME>2!U<&1A=&4N)RP*"2=A
M9&1I=&EO;F%L7VME>5]U<&1A=&5?7VYE=U]K97DG(#T^("=!9&1I=&EO;F%L
M($ME>2!0<F]P97)T:65S)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W)E
M<W5L=%]R97-P;VYS92<@/3X@)TQI8V5N<VEN9R!S97)V97(@<F5S<&]N<V4Z
M("4Q)RP*"2=A9&1I=&EO;F%L7VME>5]U<&1A=&5?7W)E<W5L=%]N971W;W)K
M)R`]/B`G56YA8FQE('1O(&-O;FYE8W0@=&\@=&AE(&QI8V5N<VEN9R!S97)V
M97(N(%!L96%S92!M86ME('-U<F4@=&AA="!Y;W5R(&YE='=O<FL@86QL;W=S
M(&-O;6UU;FEC871I;VX@=&\@)3$Z("4R+B<L"@DG861D:71I;VYA;%]K97E?
M=7!D871E7U]R97-U;'1?;&]C:R<@/3X@)TME>2!U<&1A=&4@:7,@86QR96%D
M>2!I;B!P<F]G<F5S<R<L"@DG861D:71I;VYA;%]K97E?=7!D871E7U]R97-U
M;'1?:6YT97)N86Q?97)R;W(G(#T^("=%<G)O<B!O8V-U<G)E9"!W:&EL92!U
M<&1A=&EN9R!T:&4@;&EC96YS92!K97DZ("4Q)RP*"@DG8G1?861D:71I;VYA
M;%]K97E?<F5V97)T)R`]/B`G4F]L;"!"86-K($ME>2<L"@DG8G1?861D:71I
M;VYA;%]K97E?=7!D871E)R`]/B`G4F5T<FEE=F4@061D:71I;VYA;"!+97DG
M+`H))V%D9&ET:6]N86Q?:V5Y7W)E=F5R=%]?=&ET;&4G(#T^("=0;&5A<V4@
M8V]N9FER;2!T:&4@;W!E<F%T:6]N)RP*"2=A9&1I=&EO;F%L7VME>5]R979E
M<G1?7VQE9V5N9"<@/3X@)U!R;W!E<G1I97,@;V8@=&AE('!R979I;W5S;'D@
M=7-E9"!A9&1I=&EO;F%L(&ME>2<L"@DG861D:71I;VYA;%]K97E?<F5V97)T
M7U]C;VYF:7)M7W1E>'0G(#T^("=2;VQL(&)A8VL@:V5Y)RP*"2=A9&1I=&EO
M;F%L7VME>5]R979E<G1?7V-O;F9I<FU?<F5Q=6ER960G(#T^("=0;&5A<V4@
M8V]N9FER;2!T:&4@;W!E<F%T:6]N+B<L"@H))W!R;V-E961?=&]?8VQ?<&]O
M;"<@/3X@(E!R;V-E960@=&\@8V]N9FEG=7)I;F<@8VQI96YT)W,@25`@<&]O
M;"(L"@DG<')O8V5E9%]T;U]H;W-T:6YG7W-E='5P)R`]/B`B4')O8V5E9"!T
M;R!H;W-T:6YG('-E='5P(BP*"2=R96UO=F5#97)T<U]?<F5M;W9E7V-E<G1I
M9FEC871E<U]C<"<@/3X@(E1H92!F;VQL;W=I;F<@8V5R=&EF:6-A=&5S('=I
M;&P@8F4@<F5M;W9E9#H@(BP*"2=R96UO=F5#97)T<U]?<F5M;W9E7V-E<G1I
M9FEC871E<U]D;VUA:6XG(#T^(")4:&4@9F]L;&]W:6YG(&-E<G1I9FEC871E
M<R!O=VYE9"!B>2`E,2!W:6QL(&)E(')E;6]V960Z("(L"@DG<F5M;W9E0VQI
M96YT<TE07W)E;6]V95]C;&EE;G1S7VEP)R`]/B`B5&AI<R!)4"!A9&1R97-S
M('=I;&P@8F4@<F5M;W9E9"!F<F]M('1H92!P;V]L<R!O9B!T:&4@9F]L;&]W
M:6YG(&-L:65N=',Z(BP*"2=R96UO=F5#;&EE;G1S4VET94%P<%]R96UO=F5?
M8VQI96YT<R<@/3X@(E1H:7,@<VET92!A<'!L:6-A=&EO;B!W:6QL(&)E(')E
M;6]V960@9G)O;2!T:&4@<&]O;',@;V8@=&AE(&9O;&QO=VEN9R!C;&EE;G1S
M.B(L"@DG<F5M;W9E0VQI96YT<U]?<F5M;W9E7V-L:65N='-?9&]M86EN<R<@
M/3X@(E1H92!F;VQL;W=I;F<@8VQI96YT(&%C8V]U;G1S(&%N9"!T:&5I<B!D
M;VUA:6YS('=I;&P@8F4@<F5M;W9E9#HB+`H))W)E;6]V94UA:6Q!;&EA<V5S
M7U]R96UO=F5?;6%I;%]A;&EA<V5S)R`]/B`B5&AE(&9O;&QO=VEN9R!M86EL
M(&%L:6%S97,@9F]R('1H92!M86EL(&YA;64@)3$@=VEL;"!B92!R96UO=F5D
M.B(L"@DG<F5M;W9E36%I;$YA;65S7U]R96UO=F5?;6%I;&YA;65S)R`]/B`B
M5&AE(&9O;&QO=VEN9R!M86EL(&YA;65S(&%N9"!A;&EA<V5S('=I;&P@8F4@
M<F5M;W9E9"!F<F]M('1H92!D;VUA:6X@)3$Z(BP*"2=R96UO=F5-86EL3F%M
M97-?7W)E;6]V95]M86EL;F%M97-?;V9?8VPG(#T^(")4:&4@9F]L;&]W:6YG
M(&UA:6P@;F%M97,@86YD(&%L:6%S97,@=VEL;"!B92!R96UO=F5D(&9R;VT@
M9&]M86EN("4R(&]W;F5D(&)Y(&-L:65N="`E,3HB+`H))W)E;6]V94UA:6Q.
M86UE<U]?=&AE<V5?;6%I;&YA;65S7W=I;&Q?;F]T7V1E;&5T92<@/3X@(E1H
M97-E(&UA:6P@;F%M97,@=VEL;"!N;W0@8F4@9&5L971E9"XB+`H))W)E;6]V
M95-E<W-I;VYS7U]R96UO=F5?=&ET;&4G(#T^(")4:&4@9F]L;&]W:6YG('-E
M<W-I;VYS('=I;&P@8F4@96YD960Z(BP*"2=R96UO=F5&='!397-S:6]N<U]?
M<F5M;W9E7W1I=&QE)R`]/B`B5&AE(&9O;&QO=VEN9R!&5%`@<V5S<VEO;G,@
M=VEL;"!B92!E;F1E9#HB+`H))W)E;6]V951E;7!L871E<U]?<F5M;W9E7W1E
M;7!L871E<R<@/3X@(E1H92!F;VQL;W=I;F<@=&5M<&QA=&5S('=I;&P@8F4@
M<F5M;W9E9#HB+`H))W)E<&]R=%]A=71O7U]L:7-T7W1I=&QE)R`]/B`G1"<L
M"@DG<F5P;W)T7V%U=&]?7VQI<W1?875T;R<@/3X@)T9R97%U96YC>2<L"@DG
M<F5P;W)T7V%U=&]?7VQI<W1?;&%S="<@/3X@)TQA<W0@9&5L:79E<GD@9&%T
M92<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<F5C:7!I96YT)R`]/B`G1&5L:79E
M<B!T;R<L"@DG<F5P;W)T7V%U=&]?7VQI<W1?<V5L96-T)R`]/B`G4F5P;W)T
M(&]N)RP*"2=R97!O<G1?875T;U]?=&ET;&4G(#T^("=$96QI=F5R>2!38VAE
M9'5L97,@9F]R("4Q)RP*"2=R97!O<G1?875T;U]?<F5C:7!I96YT7V5M86EL
M)R`]/B`G=&AE(&4M;6%I;"!A9&1R97-S($D@<W!E8VEF>2<L"@DG<F5P;W)T
M7V%U=&]?7W)E8VEP:65N=%]A9&UI;B<@/3X@)W1H92!S97)V97(@861M:6YI
M<W1R871O<B<L"@DG<F5P;W)T7V%U=&]?7W)E8VEP:65N=%]C;&EE;G0G(#T^
M("=T:&4@8VQI96YT)RP*"2=R97!O<G1?875T;U]?<F5C:7!I96YT7V1O;6%I
M;B<@/3X@)W1H92!D;VUA:6X@861M:6YI<W1R871O<B<L"@DG<F5P;W)T7V%U
M=&]?961I=%]?<V5L96-T)R`]/B`G4F5P;W)T(&]N)RP*"2=R97!O<G1?875T
M;U]?<V5L96-T7V-L:65N=%]R97!O<G1?86QL)R`]/B`G86QL(&-L:65N=',G
M+`H))W)E<&]R=%]A=71O7U]S96QE8W1?8VQI96YT7W)E<&]R=%]C=7)R96YT
M)R`]/B`G=&AI<R!C;&EE;G0G+`H))W)E<&]R=%]A=71O7U]S96QE8W1?8VQI
M96YT7W)E<&]R=%]O=&AE<E]C;&EE;G0G(#T^("<E,2<L"@DG<F5P;W)T7V%U
M=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V%L;"<@/3X@)V%L;"!D;VUA:6YS
M)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V1O;6%I;E]R97!O<G1?;W1H97)?
M8VQI96YT)R`]/B`G86QL(&1O;6%I;G,@;V8@)3$G+`H))W)E<&]R=%]A=71O
M7U]S96QE8W1?9&]M86EN7W)E<&]R=%]C;&EE;G0G(#T^("=A;&P@9&]M86EN
M<R!O9B!T:&ES(&-L:65N="<L"@DG<F5P;W)T7V%U=&]?7W-E;&5C=%]D;VUA
M:6Y?<F5P;W)T7V-U<G)E;G0G(#T^("=T:&ES(&1O;6%I;B<L"@DG<F5P;W)T
M7V%U=&]?7W-E;&5C=%]D;VUA:6Y?<F5P;W)T7V]T:&5R7V1O;6%I;B<@/3X@
M)R4Q)RP*"2=R97!O<G1?875T;U]?;&5G96YD)R`]/B`G1&5L:79E<GD@<V-H
M961U;&5S)RP*"2=R97!O<G1?875T;U]?<V5L96-T7V9O<E]R96UO=F4G(#T^
M(")396QE8W0@=&AE(&1E;&EV97)Y('-C:&5D=6QE<R!T;R!B92!R96UO=F5D
M+B(L"@DG<F5P;W)T7V%U=&]?<F5M;W9E7U]T:71L92<@/3X@(E1H92!F;VQL
M;W=I;F<@<F5P;W)T(&1E;&EV97)Y('-C:&5D=6QE<R!W:6QL(&)E(')E;6]V
M960Z(BP*"2=R97!O<G1?875T;U]E9&ET7U]T:71L92<@/3X@)T1E;&EV97)Y
M(%-C:&5D=6QE(%!R;W!E<G1I97,G+`H))W)E<&]R=%]A=71O7V5D:71?7W)E
M8VEP:65N="<@/3X@)T1E;&EV97(@=&\G+`H))W)E<&]R=%]A=71O7V5D:71?
M7W1A<F=E="<@/3X@)U)E<&]R="!O;B<L"@DG<F5P;W)T7V%U=&]?961I=%]?
M875T;R<@/3X@)T1E;&EV97)Y(&9R97%U96YC>2<L"@DG<F5S<%]E9&ET7U]A
M;'=A>7-?<F5S<&]N9"<@/3X@(F%L=V%Y<R!R97-P;VYD(BP*"2=R97-P7V5D
M:71?7W)E<&QY7W-U8FIE8W0G(#T^(")297!L>2!S=6)J96-T(BP*"2=R97-P
M7V5D:71?7V%N<W=E<E]T>'0G(#T^(")297!L>2!W:71H('1E>'0B+`H))W)E
M<W!?961I=%]?871T86-H)R`]/B`B071T86-H(&9I;&5S(BP*"2=R97-P7V5D
M:71?7V1E9F%U;'1?<W5B:F5C="<@/3X@(E)E.B`E,2(L"@DG<F5S<%]E9&ET
M7U]F;W(G(#T^(")F;W(@(BP*"2=R97-P7V5D:71?7V9R=U]R<7-T7V5M86EL
M)R`]/B`B57!O;B!A=71O;6%T:6,@<F5S<&]N<V4L(&9O<G=A<F0@=&AE(&]R
M:6=I;F%L(&UE<W-A9V4@=&\@=&AE('-P96-I9FEE9"!E+6UA:6PB+`H))W)E
M<W!?961I=%]?9G=D7V5M86EL7VEN=F%L:60G(#T^(")$97-T:6YA=&EO;B!E
M+6UA:6P@861D<F5S<R!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E9&ET7U]I;E]B
M;V1Y)R`]/B`B=VAE;B!S<&5C:69I960@=V]R9',@87)E(&9O=6YD(&EN('1H
M92!M97-S86=E(&)O9'DB+`H))W)E<W!?961I=%]?:6Y?<W5B:F5C="<@/3X@
M(G=H96X@<W!E8VEF:65D('=O<F1S(&%R92!F;W5N9"!I;B!M97-S86=E('-U
M8FIE8W0B+`H))W)E<W!?961I=%]?:6YV86QI9%]R97-P7V9R97$G(#T^(")2
M97-P;VYS92!F<F5Q=65N8WD@:7,@:6YV86QI9"XB+`H))W)E<W!?961I=%]?
M:6YV86QI9%]R<7-T7W1X="<@/3X@(DEN=F%L:60@<F5Q=65S="!T97AT+B(L
M"@DG<F5S<%]E9&ET7U]I;G9A;&ED7W-T;W)E7VQI;5]N=6TG(#T^("),:6UI
M="!V86QU92!I<R!I;G9A;&ED+B(L"@DG<F5S<%]E9&ET7U]L:6UI='-?=&ET
M;&4G(#T^("),:6UI=',B+`H))W)E<W!?961I=%]?;6%X:6UU;5]A;&QO=V5D
M7W)E<W!?9G)E<5]R96%C:&5D)R`]/B`B3G5M8F5R(&]F(&UA>&EM=6T@<F5S
M<&]N<V5S('!E<B!D87D@97AC965D<R!T:&4@9&5F:6YE9"!R871E+B!!;&QO
M=V5D.B`E,2P@<F5Q=65S=&5D.B`E,B(L"@DG<F5S<%]E9&ET7U]N;U]F:6QE
M<U]S96PG(#T^(").;R!F:6QE<R!S96QE8W1E9"XB+`H))W)E<W!?961I=%]?
M;F]?='AT7W-U<'!L:65D)R`]/B`B3F\@=&5X="!S=7!P;&EE9"XB+`H))W)E
M<W!?961I=%]?<F5P;'E?=&ET;&4G(#T^(")297!L>2(L"@DG<F5S<%]E9&ET
M7U]R97!L>5]T;U]A9&1R97-S)R`]/B`B4F5T=7)N(&%D9')E<W,B+`H))W)E
M<W!?961I=%]?<F5P;'E?=&]?:6YV86QI9"<@/3X@(E)E='5R;B!A9&1R97-S
M(&ES(&EN=F%L:60N(BP*"2=R97-P7V5D:71?7W)E<&QY7W5N:7%?96UA:6PG
M(#T^(")297!L>2!T;R!T:&4@=6YI<75E(&4M;6%I;"!A9&1R97-S(&YO="!M
M;W)E('1H86XB+`H))W)E<W!?961I=%]?8V]N9&ET:6]N<U]T:71L92<@/3X@
M(D-O;F1I=&EO;G,B+`H))W)E<W!?961I=%]?<F5S<"<@/3X@(D%U=&]R97-P
M;VYD97(@("(L"@DG<F5S<%]E9&ET7U]R97-P7VYA;64G(#T^(")!=71O<F5S
M<&]N9&5R(&YA;64B+`H))W)E<W!?961I=%]?<F5S<%]N;W1?97AI<W0G(#T^
M(")!=71O<F5S<&]N9&5R(&1O97,@;F]T(&5X:7-T+B(L"@DG<F5S<%]E9&ET
M7U]R97-P7W-T871U<R<@/3X@(D%U=&]R97-P;VYD97(@<W1A='5S(BP*"2=R
M97-P7V5D:71?7W)Q<W1?='AT)R`]/B`G4W!E8VEF>2!T:&4@8V]N9&ET:6]N
M(&9O<B!T:&ES(&%U=&]M871I8R!R97!L>2<L"@DG<F5S<%]E9&ET7U]S96QE
M8W1?9FEL97-?;VY?<V5R=F5R7V9O<E]A='1A8V@G(#T^(")396QE8W0@=&AE
M(&9I;&5S('EO=2!W86YT('1O(&%T=&%C:"(L"@DG<F5S<%]E9&ET7U]S=&]R
M95]U<%]T;R<@/3X@(E-T;W)E('5P('1O(BP*"2=R97-P7V5D:71?7W-U8FI?
M;&EN95]I;G9A;&ED)R`]/B`B4W5B:F5C="!L:6YE(&ES(&EN8V]R<F5C="XB
M+`H))W)E<W!?961I=%]?=&5X=%]T;V]?8FEG)R`]/B`B5&AE(')E<&QY(&UE
M<W-A9V4@=&5X="!I<R!T;V\@;&%R9V4N(BP*"2=R97-P7V5D:71?7W1I;65S
M7VEN7V%?9&%Y)R`]/B`B=&EM97,@82!D87DN(BP*"2=R97-P7V5D:71?7W5N
M86)L95]D969I;F5?<F5S<%]C;VYD)R`]/B`B56YA8FQE('1O(&1E9FEN92!T
M:&4@875T;W)E<W!O;F1E<B!C;VYD:71I;VXZ("4Q(BP*"2=R97-P7V5D:71?
M7W5N86)L95]D969I;F5?<F5S<%]S=&%T=7,G(#T^(")5;F%B;&4@=&\@9&5F
M:6YE(&%U=&]R97-P;VYD97(@<W1A='5S.B`E,2(L"@DG<F5S<%]E9&ET7U]U
M;F%B;&5?='5R;E]O;E]R97-P)R`]/B`B56YA8FQE('1O('1U<FX@;VX@=&AE
M(&%U=&]R97-P;VYD97(Z("4Q(BP*"2=R97-P7V5D:71?7W5N:7%?96UA:6PG
M(#T^(")U;FEQ=64@92UM86EL(&%D9')E<W-E<R(L"@DG<F5S<%]E9&ET7U]C
M;VYT96YT7W1Y<&4G(#T^("=-86EL('-E;F1I;F<@9F]R;6%T)RP*"2=R97-P
M7V5D:71?7V-O;G1E;G1?='EP95]T97AT)R`]/B`G4&QA:6X@=&5X="<L"@DG
M<F5S<%]E9&ET7U]C;VYT96YT7W1Y<&5?:'1M;"<@/3X@)TA434PG+`H))W)E
M<W!?961I=%]?8VAA<G-E="<@/3X@)T5N8V]D:6YG)RP*"2=R97-T87)T7U]C
M;VQD9G5S:6]N)R`]/B`B0V]L9$9U<VEO;B`H)3$I(BP*"2=R97-T87)T7U]C
M;VQD9G5S:6]N7VEN<W1A;&QA=&EO;E]T>7!E)R`]/B`B26YS=&%L;&%T:6]N
M('1Y<&4Z("4Q(BP*"2=R97-T87)T7U]D;G,G(#T^("=$3E,@4V5R=F5R("@E
M,2DG+`H))W)E<W1A<G1?7V1R=V5B)R`]/B`G1'(N5V5B(&%N=&EV:7)U<R<L
M"@DG<F5S=&%R=%]?;6%I;"<@/3X@(DE-05`O4$]0,R!397)V97(@*"4Q*2(L
M"@DG<F5S=&%R=%]?;7-S<6PG(#T^(")-:6-R;W-O9G0@4U%,('-E<G9E<B(L
M"@DG<F5S=&%R=%]?<&]S=&=R97-Q;"<@/3X@(E!O<W1G<F5344PB+`H))W)E
M<W1A<G1?7W!S82<@/3X@(E-E<G9I8V5S(&UA;F%G96UE;G0B+`H))W)E<W1A
M<G1?7W-M='`G(#T^(")33510(%-E<G9E<B`H)3$I(BP*"2=R97-T87)T7U]S
M<&%M87-S87-S:6XG(#T^(")3<&%M07-S87-S:6XB+`H))W)E<W1A<G1?7W-T
M=6YN96PG(#T^(")3='5N;F5L(BP*"2=R97-T87)T7U]T;VUC870G(#T^(")4
M;VUC870B+`H))W)E<W1A<G1?7W=E8B<@/3X@(E=E8B!397)V97(@*"4Q*2(L
M"@DG<FU?9&]M86EN<U]?<V]M95]D;VUA:6YS7V%R95]N;W1?97AI<W0G(#T^
M(")3;VUE(&]F('1H92!S<&5C:69I960@9&]M86EN<R!D;R!N;W0@97AI<W0N
M(%1H97D@:&%V92!B965N('!O<W-I8FQY(')E;6]V960@8GD@86YO=&AE<B!U
M<V5R+B(L"@DG<G!T7V-L7V1O;5]D871A7V)A<V5S)R`]/B`B1$)A<V5S(BP*
M"2=R<'1?8VQ?9&]M7VUA:6Q?9W)O=7!S)R`]/B`B34=R;W5P<R(L"@DG<G!T
M7V-L7V1O;5]M86EL7VQI<W1S)R`]/B`B34QI<W1S(BP*"2=R<'1?8VQ?9&]M
M7VUA:6Q?<F5S<',G(#T^(")!4F5S<"XB+`H))W)P=%]C;%]D;VU?<&]S=&)O
M>&5S)R`]/B`B34)O>&5S(BP*"2=R<'1?8VQ?9&]M7W)E9&ER96-T<R<@/3X@
M(E)E9&ER+B(L"@DG<G!T7V-L7V1O;5]S=6)D;VUA:6YS)R`]/B`B4W5B9&]M
M(BP*"2=R<'1?8VQ?9&]M7W=E8E]U<V5R<R<@/3X@(E=5<V5R<R(L"@DG<G!T
M7V-L7V1O;5]W96)A<'!S)R`]/B`B5T%P<',B+`H))W)P=%]C;%]R97!O<G1?
M9F]R7V-L7U\G(#T^(")297!O<G0@;VX@8VQI96YT("4Q(BP*"2=R<'1?8VQ?
M<V5C=&EO;E]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T7V-L7W-E8W1I
M;VY?9G5L;%]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG<G!T7V-L7W-E8W1I
M;VY?9V5N97)A;"<@/3X@(D=E;F5R86PB+`H))W)P=%]C<F5A=&4G(#T^(")#
M<F5A=&4@<F5P;W)T(BP*"2=R<'1?96UP='DG(#T^(")4:&4@<F5P;W)T('-H
M;W5L9"!C;VYT86EN(&%T(&QE87-T(&]N92!S96-T:6]N(BP*"2=R<'1?9&5F
M875L=%]R97!O<G0G(#T^(")5<V4@87,@9&5F875L="!R97!O<G0B+`H))W)P
M=%]D;VU?<F5P;W)T7V9O<E]D;VU?7R<@/3X@(D1O;6%I;B!R97!O<G0@9F]R
M("4Q(BP*"2=R<'1?9&]M7W-E8W1I;VY?9&%T86)A<V5S)R`]/B`B1&%T86)A
M<V5S(BP*"2=R<'1?9&]M7W-E8W1I;VY?9G5L;%]D871A8F%S97,G(#T^(")$
M871A8F%S97,B+`H))W)P=%]D;VU?<V5C=&EO;E]F=6QL7VUA:6QL:7-T<R<@
M/3X@(DUA:6QI;F<@;&ES=',B+`H))W)P=%]D;VU?<V5C=&EO;E]F=6QL7VUA
M:6QN86UE<R<@/3X@(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?<V5C=&EO;E]F
M=6QL7W=E8G5S97)S)R`]/B`B5V5B('5S97)S(BP*"2=R<'1?9&]M7W-E8W1I
M;VY?9G5L;%]S:71E87!P<R<@/3X@)U-I=&4@87!P;&EC871I;VYS)RP*"2=R
M<'1?9&]M7W-E8W1I;VY?9G5L;%]T;VUC870G(#T^(")*879A(&%P<&QI8V%T
M:6]N<R(L"@DG<G!T7V1O;5]S96-T:6]N7V=E;F5R86PG(#T^(")'96YE<F%L
M(BP*"2=R<'1?9&]M7W-E8W1I;VY?:&]S=&EN9R<@/3X@(DAO<W1I;F<B+`H)
M)W)P=%]D;VU?<V5C=&EO;E]L:7-T7W1O;6-A="<@/3X@(DIA=F$@87!P;&EC
M871I;VYS(BP*"2=R<'1?9&]M7W-E8W1I;VY?;6%I;&QI<W1S)R`]/B`B36%I
M;&EN9R!L:7-T<R(L"@DG<G!T7V1O;5]S96-T:6]N7VUA:6QN86UE<R<@/3X@
M(DUA:6P@;F%M97,B+`H))W)P=%]D;VU?<V5C=&EO;E]S:71E87!P<R<@/3X@
M)U-I=&4@87!P;&EC871I;VYS)RP*"2=R<'1?9&]M7W-E8W1I;VY?=&]M8V%T
M)R`]/B`B2F%V82!A<'!L:6-A=&EO;G,B+`H))W)P=%]D;VU?<V5C=&EO;E]W
M96)U<V5R<R<@/3X@(E=E8B!U<V5R<R(L"@DG<G!T7V1O;5]T:71L95]W85]S
M=&%T=7,G(#T^(")3(BP*"2=R<'1?961I=%]?)R`]/B`B161I="!R97!O<G0@
M)3$B+`H))W)P=%]E;G1E<E]E;6%I;%]A9&1R97-S)R`]/B`B16YT97(@=&AE
M(&4M;6%I;"!A9&1R97-S('1H92!R97!O<G0@=VEL;"!B92!D96QI=F5R960@
M=&\N(BP*"2=R<'1?;&ES="<@/3X@(D-U<W1O;2!R97!O<G0@;&%Y;W5T<R(L
M"@DG<G!T7VYA;64G(#T^(")297!O<G0@;F%M92(L"@DG<G!T7W)E;6]V95]R
M97!O<G1S)R`]/B`B5&AE(&9O;&QO=VEN9R!R97!O<G0@;&%Y;W5T<R!W:6QL
M(&)E(')E;6]V960Z(BP*"2=R<'1?<F5P;W)T<R<@/3X@(E)E<&]R=',B+`H)
M)W)P=%]S96-T:6]N7V9U;&PG(#T^(")&=6QL(BP*"2=R<'1?<V5C=&EO;E]N
M;VYE)R`]/B`B3F]N92(L"@DG<G!T7W-E8W1I;VY?<W5M;6%R>2<@/3X@(E-U
M;6UA<GDB+`H))W)P=%]S96QE8W1?<F5P;W)T<U]F;W)?<F5M;W9E)R`]/B`B
M4V5L96-T('1H92!R97!O<G0@;&%Y;W5T<R!T;R!B92!R96UO=F5D+B(L"@DG
M<G!T7V1E9F%U;'1?9G5L;"<@/3X@)T9U;&P@4F5P;W)T)RP*"2=R<'1?9&5F
M875L=%]S=6UM87)Y)R`]/B`G4W5M;6%R>2!297!O<G0G+`H*"2\O(&5N9"!O
M9B!K;V]P97(@<&%R=`H*"2\O(&=R97D@<&%R="`H<G-E<W-I;VX@<W5P<&]R
M="D*"2=R<V5S<VEO;E]N;U]A<&E?<G!C7V5R<FUS9R<@/3X@(E!L97-K($%0
M22!24$,@:7,@;F]T(&EN<W1A;&QE9"!O;B!T:&4@<F5M;W1E(&AO<W0N($-O
M;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R871O<B!F;W(@<W5P<&]R="XB
M+`H))W)S97-S:6]N7VYO7V%C8V]U;G1?97)R;7-G)R`]/B`B56YA8FQE('1O
M(&%C8V5S<R!T:&4@<F5M;W1E('-E<G9I8V4@=6YD97(@>6]U<B!A8V-O=6YT
M+B!4:&4@;6]S="!C;VUM;VX@<F5A<V]N(&ES('1H870@=&AE('-E<G9I8V4@
M9F]R('EO=7(@86-C;W5N="!I<R!N;W0@86-T:79A=&5D('EE="X@4&QE87-E
M+"!W86ET(&9O<B!S979E<F%L(&UI;G5T97,L(&%N9"!T:&5N('1R>2!A9V%I
M;BX@268@>6]U(&5N8V]U;G1E<B!T:&ES(&5R<F]R(&%G86EN+"!C;VYT86-T
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(N(BP*"2=R<V5S<VEO;E]N;U]D
M;VUA:6Y?97)R;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E
M('-E<G9I8V4@9F]R('1H:7,@9&]M86EN+B!4:&4@;6]S="!C;VUM;VX@<F5A
M<V]N(&ES('1H870@=&AE('-E<G9I8V4@9F]R('1H:7,@9&]M86EN(&ES(&YO
M="!A8W1I=F%T960@>65T+B!0;&5A<V4L('=A:70@9F]R('-E=F5R86P@;6EN
M=71E<RP@86YD('1H96X@=')Y(&%G86EN+B!)9B!Y;W4@96YC;W5N=&5R('1H
M:7,@97)R;W(@86=A:6XL(&-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<BXB+`H))W)S97-S:6]N7W5N:VYO=VY?97)R;7-G)R`]/B`B5&AE(')E
M;6]T92!S97)V97(@:&%S(')E:F5C=&5D('1H92!A='1E;7!T('1O(&5S=&%B
M;&ES:"!A('-E<W-I;VXN($-O;G1A8W0@>6]U<B!S>7-T96T@861M:6YI<W1R
M871O<B!F;W(@<W5P<&]R="X@5&AE(&5R<F]R('=A<SH@)3$B+`H))W)S97-S
M:6]N7W5N:VYO=VXR7V5R<FUS9R<@/3X@(E5N:VYO=VX@97)R;W(@=VAI;&4@
M97-T86)L:7-H:6YG(&$@<F5M;W1E('-E<W-I;VXN($UO<W0@<')O8F%B;'D@
M=&AE(')E;6]T92!S97)V97(@9&]E<R!N;W0@<F5S<&]N9"!P<F]P97)L>2!O
M<B!D;V5S(&YO="!A;G-W97(@870@86QL+B!!<VL@>6]U<B!S>7-T96T@861M
M:6YI<W1R871O<B!T;R!C:&5C:R!F;W(@97)R;W(@9&5T86EL<R!I;B!T:&4@
M07!A8VAE(&5R<F]R(&QO9RXB+`H))W)S97-S:6]N7VYO7V-O;FYE8W1?97)R
M;7-G)R`]/B`B56YA8FQE('1O(&%C8V5S<R!T:&4@<F5M;W1E('-E<G9I8V4Z
M(&-O;FYE8W1I;F<@=&\@<F5M;W1E('-E<W-I;VX@9F%I;&5D+B!#;VYT86-T
M('EO=7(@<WES=&5M(&%D;6EN:7-T<F%T;W(@9F]R('-U<'!O<G0N(BP*"2\O
M(&5N9"!O9B!G<F5Y('!A<G0*"@DO+R!P:70@<&%R=`H*"2=R<'1?<V5N9%]R
M97!O<G1?8GE?96UA:6Q?97)R;W)?7R<@/3X@(D5R<F]R('-E;F1I;F<@=&AE
M(')E<&]R=#H@)3$B+`H))W)P=%]S96YD7W)E<&]R=%]B>5]E;6%I;%]O:U]?
M)R`]/B`B5&AE(')E<&]R="!H87,@8F5E;B!S96YT('1O("4Q+B(L"@DG<V%?
M86-T:6]N7V1E;"<@/3X@(D1E;&5T92(L"@DG<V%?86-T:6]N7V1E<V,G(#T^
M(")7:&%T('1O(&1O('=I=&@@<W!A;2!M86EL(BP*"2=S85]A8W1I;VY?<V%V
M92<@/3X@(DUA<FL@87,@<W!A;2!A;F0@<W1O<F4@:6X@;6%I;&)O>"(L"@DG
M<V%?861M:6Y?8FQA8VML:7-T)R`]/B`B061M:6YI<W1R871O<B=S(&)L86-K
M(&QI<W0B+`H))W-A7V%D;6EN7W=H:71E;&ES="<@/3X@(D%D;6EN:7-T<F%T
M;W(G<R!W:&ET92!L:7-T(BP*"2=S85]B;&%C:VQI<W0G(#T^(")";&%C:R!L
M:7-T(BP*"2=S85]B;&%C:VQI<W1?9&5S8R<@/3X@(D%L=V%Y<R!M87)K(&%S
M('-P86T@;6%I;"!F<F]M(&%D9')E<W,B+`H))W-A7V)Y7W1A9R<@/3X@(F)Y
M('1A9R(L"@DG<V%?8V9G7W5S95]P;VQI8WDG(#T^(")5<V%G92!P;VQI8WD@
M<V5T=&EN9W,B+`H))W-A7V-O;F9?;&ES=%]B;&%C:R<@/3X@(D%R92!Y;W4@
M<W5R92!Y;W4@=V%N="!T;R!R96UO=F4@=&AE('-E;&5C=&5D('!A='1E<FYS
M(&9R;VT@=&AE(&)L86-K(&QI<W0_(BP*"2=S85]C;VYF7VQI<W1?:6=N;W)E
M)R`]/B`B07)E('EO=2!S=7)E('EO=2!W86YT('1O(')E;6]V92!T:&4@<V5L
M96-T960@<&%T=&5R;G,@9G)O;2!T:&4@:6=N;W)E(&QI<W0_(BP*"2=S85]C
M;VYF7VQI<W1?=VAI=&4G(#T^(")!<F4@>6]U('-U<F4@>6]U('=A;G0@=&\@
M<F5M;W9E('1H92!S96QE8W1E9"!P871T97)N<R!F<F]M('1H92!W:&ET92!L
M:7-T/R(L"@DG<V%?9&)?9&5L7V-O;F9I<FTG(#T^(")!<F4@>6]U('-U<F4@
M>6]U('=A;G0@=&\@8VQE87(@=&AE(%-P86U!<W-A<W-I;B=S(&1A=&%B87-E
M/R(L"@DG<V%?96UL7VEN7VEG;F]R96QI<W0G(#T^(")%+6UA:6P@:7,@:6X@
M=&AE(&EG;F]R92!L:7-T(BP*"2=S85]E;6Q?<&%T=&5R;B<@/3X@(D4M;6%I
M;"!P871T97)N(BP*"2=S85]E;7!T>5]E;6%I;"<@/3X@(D-A;FYO="!A9&0@
M96UP='D@92UM86EL('!A='1E<FXN(BP*"2=S85]E>&ES='-?96UA:6PG(#T^
M(")3=6-H(&4M;6%I;"!P871T97)N(&%L<F5A9'D@97AI<W1S+B(L"@DG<V%?
M9&ES86)L961?7VUA:6QN86UE7VYO=%]F:6QT97)I;F<G(#T^(")4:&4@8W5R
M<F5N="!S97)V97(@<V5T=&EN9W,@9&\@;F]T(&%L;&]W('1O('5S92!M86EL
M(&9I;'1E<FEN9R!F;W(@=&AI<R!M86EL(&YA;64B+`H))W-A7V1I<V%B;&5D
M7U]F:6QT97)I;F=?:7-?9&ES86)L960G(#T^("=3<&%M(&9I;'1E<FEN9R!W
M87,@9&ES86)L960@8GD@=&AE('-E<G9E<B!A9&UI;FES=')A=&]R)RP*"2=S
M85]E;F%B;&5?9FEL=&5R)R`]/B`B16YA8FQE('-P86T@9FEL=&5R:6YG(BP*
M"2=S85]H:71S7W)E<2<@/3X@(DAI=',@<F5Q=6ER960@9F]R('-P86TB+`H)
M)W-A7VAI='-?;F]T7VYU;6)E<B<@/3X@)U1H92!N=6UB97(@>6]U('-P96-I
M9FEE9"!I<R!I;G9A;&ED+B!9;W4@<VAO=6QD('5S92!A('!O<VET:79E(&EN
M=&5G97(N)RP*"2=S85]I9VYO<F5L:7-T)R`]/B`B4V5R=F5R+7=I9&4@:6=N
M;W)E(&QI<W0B+`H))W-A7VEG;F]R96QI<W1?9&5S8R<@/3X@(D1O(&YO="!F
M:6QT97(@;6%I;"!F;W(@=&AE<V4@86-C;W5N=',B+`H))W-A7VUO9&EF>5]S
M=6)J)R`]/B`B36]D:69Y('-P86T@;6%I;"!S=6)J96-T(BP*"2=S85]P871T
M97)N7VEN7V)L86-K;&ES="<@/3X@(E!A='1E<FX@86QR96%D>2!E>&ES=',@
M:6X@8FQA8VL@;&ES="(L"@DG<V%?<&%T=&5R;E]I;E]I9VYO<F5L:7-T)R`]
M/B`B4&%T=&5R;B!A;')E861Y(&5X:7-T<R!I;B!I9VYO<F4@;&ES="(L"@DG
M<V%?<&%T=&5R;E]I;E]W:&ET96QI<W0G(#T^(")0871T97)N(&%L<F5A9'D@
M97AI<W1S(&EN('=H:71E(&QI<W0B+`H))W-A7W!A='1E<FY?:7-?:6YV86QI
M9"<@/3X@(E!A='1E<FX@:7,@:6YV86QI9"XB+`H))V)T7W-A7V-L96%R7V1B
M)R`]/B`G0VQE87(@4W!A;2!&:6QT97(@1&%T86)A<V4G+`H))V)T7W-A7V9O
M<F=E="<@/3X@)T9O<F=E="!)="<L"@DG8G1?<V%?;&5A<FY?87-?<W!A;2<@
M/3X@(DET)W,@4W!A;2$B+`H))V)T7W-A7VQE87)N7V%S7VYO;G-P86TG(#T^
M("))="=S($YO="!3<&%M(BP*"2=S85]T<F%I;F5R7U]P86=E7W1I=&QE)R`]
M/B`G4W!A;2!F:6QT97(@=')A:6YI;F<G+`H))W-A7W1R86EN97)?7W1O;VQS
M7VQE9V5N9"<@/3X@)U1O;VQS)RP*"2=S85]T<F%I;F5R7U]I;F9O7VQE9V5N
M9"<@/3X@)TEN9F\G+`H))W-A7W1R86EN97)?7VUE<W-A9V5S7VQI<W1?;&5G
M96YD)R`]/B`G365S<V%G97,@:6X@>6]U<B!M86EL8F]X)RP*"2=S85]T<F%I
M;F5R7U]C)R`]/B`G5"<L"@DG<V%?=')A:6YE<E]?;"<@/3X@)TPG+`H))W-A
M7W1R86EN97)?7W-U8FIE8W0G(#T^("=3=6)J96-T)RP*"2=S85]T<F%I;F5R
M7U]F<F]M)R`]/B`G1G)O;2<L"@DG<V%?=')A:6YE<E]?9&%T92<@/3X@)T1A
M=&4G+`H))W-A7W1R86EN97)?7VEN9F]?=&5X="<@/3X@)TUE<W-A9V5S(&QE
M87)N960Z("4Q(&%S('-P86TL("4R(&%S(&YO;BUS<&%M+"`E,R!T;W1A;"XG
M+`H))W-A7W1R86EN97)?7VUE<W-A9V5S)R`]/B`G;65S<V%G92AS*2<L"@DG
M<V%?=')A:6YE<E]?<V5L96-T7U]A;&PG(#T^("=!;&PG+`H))W-A7W1R86EN
M97)?7W-E;&5C=%]?<W!A;5]O;FQY)R`]/B`G4W!A;2<L"@DG<V%?=')A:6YE
M<E]?<V5L96-T7U]H86U?;VYL>2<@/3X@)TYO;BU3<&%M)RP*"2=S85]T<F%I
M;F5R7U]S96QE8W1?7W5N:VYO=VY?;VYL>2<@/3X@)U5N:VYO=VXG+`H))W-A
M7W1R86EN97)?7V-A;FYO=%]R96UO=F5?;65S<V%G97,G(#T^("=#86YN;W0@
M<F5M;W9E('1H92!S96QE8W1E9"!M97-S86=E<R!F<F]M('1H92!M86EL8F]X
M+B<L"@DG<V%?=')A:6YE<E]?<F5M;W9E7VUE<W-A9V5S7V-O;F9I<FTG(#T^
M("=!<F4@>6]U('-U<F4@=&AA="!Y;W4@=VES:"!T;R!R96UO=F4@=&AE('-E
M;&5C=&5D(&UE<W-A9V5S(&9R;VT@=&AE(&UA:6QB;W@_)RP*"2=S85]S96QE
M8W1?96UA:6PG(#T^(")396QE8W0@870@;&5A<W0@;VYE(&4M;6%I;"!P871T
M97)N(&9R;VT@=&AE(&QI<W0@=&\@<F5M;W9E(&ET+B(L"@DG<V%?<W)V7V)L
M86-K;&ES="<@/3X@(E-E<G9E<BUW:61E(&)L86-K(&QI<W0B+`H))W-A7W-R
M=E]C9F<G(#T^(")397)V97(@=VED92!S971T:6YG<R(L"@DG<V%?<W)V7W-E
M='1I;F=S)R`]/B`B4V5R=F5R('-E='1I;F=S(BP*"2=S85]S<G9?=VAI=&5L
M:7-T)R`]/B`B4V5R=F5R+7=I9&4@=VAI=&4@;&ES="(L"@DG<V%?=7-E7W-R
M=E]S971T:6YG<R<@/3X@(E5S92!S97)V97(@=VED92!S971T:6YG<R(L"@DG
M<V%?=7-E<E]B;&%C:VQI<W0G(#T^(")5<V5R)W,@8FQA8VL@;&ES="(L"@DG
M<V%?=7-E<E]W:&ET96QI<W0G(#T^(")5<V5R)W,@=VAI=&4@;&ES="(L"@DG
M<V%?=7-R7V1I<V%B;&5D7V)Y7W-R=B<@/3X@(D%D;6EN:7-T<F%T;W(@:&%S
M(&1I<V%B;&5D('5S97(M8V]N9FEG=7)E9"!S<&%M(&9I;'1E<FEN9R(L"@DG
M<V%?=7-R7VYO7W!O<W1B;W@G(#T^(")5<V5R(&AA<R!N;R!M86EL8F]X(&5N
M86)L960B+`H))W-A7W5S<E]S971T:6YG<R<@/3X@(E!E<G-O;F%L('-E='1I
M;F=S(BP*"2=S85]W:&ET96QI<W0G(#T^(")7:&ET92!L:7-T(BP*"2=S85]W
M:&ET96QI<W1?9&5S8R<@/3X@(DYE=F5R(&UA<FL@87,@<W!A;2!M86EL(&9R
M;VT@861D<F5S<R(L"@DG<V5R=F5R7U]A9&UI;E]I;F9O)R`]/B`B061M:6YI
M<W1R871O<B!I;F9O<FUA=&EO;B(L"@DG<V5R=F5R7U]C=')L7W!A;F5L)R`]
M/B`B0V]N=')O;"!086YE;"(L"@DG<V5R=F5R7U]E;G1E<E]B=6=?97-S96YC
M95]B96QO=R<@/3X@(D5N=&5R('1H92!B=6<@9&5S8W)I<'1I;VX@8F5L;W<B
M+`H))W-E<G9E<E]?<&]W97)?;6%N86=E;65N="<@/3X@(E!O=V5R(&UA;F%G
M96UE;G0B+`H))W-E<G9E<E]?<V5R=FEC97,G(#T^(")397)V:6-E<R(L"@DG
M<V5R=F5R7U]S>7-T96TG(#T^(")3>7-T96TB+`H))W-E<G9E<E]?=&ET;&4G
M(#T^(")397)V97(@061M:6YI<W1R871I;VXB+`H))W-E<G9E<E]?=V%R;FEN
M9U]R96)O;W0G(#T^(")787)N:6YG(2!4:&4@<WES=&5M('=I;&P@;F]W(&)E
M(')E8F]O=&5D+B!0<F]C965D/R(L"@DG<V5R=F5R7U]W87)N:6YG7W-H=71D
M;W=N)R`]/B`B5T%23DE.1SH@5&AI<R!O<&5R871I;VX@=VEL;"!S:'5T('1H
M92!S97)V97(@9&]W;BX@(%1H92!S97)V97(@8V%N;F]T7&YB92!R97-T87)T
M960@<F5M;W1E;'D@8GD@;65A;G,@;V8@=&AI<R!S;V9T=V%R92X@07)E('EO
M=2!S=7)E('EO=2!W86YT('1O('!R;V-E960_(BP*"2=S97)V97)?7W=I;&Q?
M<F5B;V]T)R`]/B`B5&AE('-Y<W1E;2!W:6QL(&YO=R!B92!R96)O;W1E9"XB
M+`H))W-E<G9E<E]?=VEL;%]S:'5T9&]W;B<@/3X@(E1H92!S>7-T96T@:7,@
M<VAU='1I;F<@9&]W;BXB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?861M:6Y?
M;&%N9W5A9V4G(#T^(")!9&UI;FES=')A=&]R)W,@:6YT97)F86-E(&QA;F=U
M86=E(BP*"2=S97)V97)?<')E9F5R96YC97-?7V%D;6EN7W-K:6XG(#T^(")!
M9&UI;FES=')A=&]R)W,@:6YT97)F86-E('-K:6XB+`H))W-E<G9E<E]P<F5F
M97)E;F-E<U]?86QL;W=?861M:6Y?;75L=&EP;'E?;&]G:6XG(#T^(")!;&QO
M=R!M=6QT:7!L92!S97-S:6]N<R!U;F1E<B!A9&UI;FES=')A=&]R)W,@;&]G
M:6XB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?9&ES:U]S<&%C92<@
M/3X@(DEN8VQU9&4@:6X@=&AE(&1I<VL@<W!A8V4@=7-A9V4@8V%L8W5L871I
M;VXB+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?8V]U;G1?=')A9F9I8R<@/3X@
M(DEN8VQU9&4@:6X@=&AE('1R869F:6,@8V%L8W5L871I;VXB+`H))W-E<G9E
M<E]P<F5F97)E;F-E<U]?8V]U;G1?='EP92<@/3X@)U=H96X@8V%L8W5L871I
M;F<@9&ES:R!S<&%C92!U<V%G92P@8V]U;G0G+`H))W-E<G9E<E]P<F5F97)E
M;F-E<U]?8V]U;G1?='EP95]?8GET92<@/3X@)V9I;&4@<VEZ92<L"@DG<V5R
M=F5R7W!R969E<F5N8V5S7U]C;W5N=%]T>7!E7U]B;&]C:R<@/3X@)V%M;W5N
M="!O9B!D:7-K('-P86-E('5S960G+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?
M9&5F875L=%]L86YG=6%G92<@/3X@(D1E9F%U;'0@;&]C86QE(BP*"2=S97)V
M97)?<')E9F5R96YC97-?7V1E9F%U;'1?<VMI;B<@/3X@(D1E9F%U;'0@<VMI
M;B(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]D:7-P;&%Y)R`]/B`B1&ES<&QA
M>2(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7V1A=&%B87-E<R<@
M/3X@(F1A=&%B87-E<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I;F-L=61E
M7V1O;6%I;F1U;7!S)R`]/B`B9&]M86EN(&)A8VMU<"!F:6QE<R(L"@DG<V5R
M=F5R7W!R969E<F5N8V5S7U]I;F-L=61E7VEN8V]M:6YG)R`]/B`B;VYL>2!I
M;F)O=6YD('1R869F:6,B+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?:6YC;'5D
M95]I;F-O;6EN9U]A;F1?;W5T9V]I;F<G(#T^(")I;F)O=6YD(&%N9"!O=71B
M;W5N9"!T<F%F9FEC(BP*"2=S97)V97)?<')E9F5R96YC97-?7VEN8VQU9&5?
M;&]G<R<@/3X@(FQO9R!F:6QE<R(L"@DG<V5R=F5R7W!R969E<F5N8V5S7U]I
M;F-L=61E7VUA:6QB;WAE<R<@/3X@(FUA:6QB;WAE<R(L"@DG<V5R=F5R7W!R
M969E<F5N8V5S7U]I;F-L=61E7VUA:6QL:7-T<R<@/3X@(FUA:6QI;F<@;&ES
M=',B+`H))W-E<G9E<E]P<F5F97)E;F-E<U]?:6YC;'5D95]O=71G;VEN9R<@
M/3X@(F]N;'D@;W5T8F]U;F0@=')A9F9I8R(L"@DG<V5R=F5R7W!R969E<F5N
M8V5S7U]I;F-L=61E7W=E8F%P<',G(#T^(")*879A(&%P<&QI8V%T:6]N<R(L
M"@DG<V5R=F5R7W!R969E<F5N8V5S7U]K965P7W-T871S)R`]/B`B4F5T86EN
M('1R869F:6,@<W1A=&ES=&EC<R!F;W(B+`H))W-E<G9E<E]P<F5F97)E;F-E
M<U]?;6%X7V)U='1O;E]L96YG=&@G(#T^(")"=71T;VX@;&%B96P@;&5N9W1H
M(BP*"2=S97)V97)?<')E9F5R96YC97-?7W)E<W1A<G1?87!A8VAE7VEN=&5R
M=F%L)R`]/B`B07!A8VAE(')E<W1A<G0@:6YT97)V86PB+`H))W-E<G9E<E]P
M<F5F97)E;F-E<U]?<W1A=%]W87)N:6YG)R`]/B`B5&AE(&-H86YG97,@;6%D
M92!T;R!T:&4@9&ES:R!S<&%C92!U<V%G92!C86QC=6QA=&EO;B!S8VAE;64@
M=VEL;"!T86ME(&5F9F5C="!O;FQY(&1U<FEN9R!N97AT('-T871I<W1I8W,@
M8V%L8W5L871I;VXN(BP*"2=S97)V97)?<')E9F5R96YC97-?7W1I=&QE)R`]
M/B`B4V5R=F5R('!R969E<F5N8V5S(BP*"2=S97)V97)?;6%I;%]?=&ET;&4G
M(#T^(")397)V97(M=VED92!M86EL('!R969E<F5N8V5S(BP*"2=M86EL7U]T
M86)S7W!R969E<F5N8V5S)R`]/B`B4')E9F5R96YC97,B+`H))VUA:6Q?7W1A
M8G-?=VAI=&5?;&ES="<@/3X@(E=H:71E($QI<W0B+`H))VUA:6Q?7W1A8G-?
M8FQO8VME9%]D;VUA:6YS)R`]/B`B0FQA8VL@3&ES="(L"@DG;6%I;%]?=&%B
M<U]M86EL7W%U975E)R`]/B`B36%I;"!1=65U92(L"@DG<V5R=F5R7W!R969E
M<F5N8V5S7U]U<V5?=F]C86)U;&%R>2<@/3X@(D-H96-K('1H92!P87-S=V]R
M9',@9F]R(&UA:6QB;WAE<R!I;B!T:&4@9&EC=&EO;F%R>2(L"@DG<V5R=F5R
M<U]L:7-T7U]A8V-O=6YT7V1I<V%B;&5D)R`]/B`B26YF;W)M871I;VX@<75E
M<GD@:7,@9&ES86)L960@9F]R('1H:7,@<V5R=F5R+B(L"@DG<V5R=F5R<U]L
M:7-T7U]P;&5A<V5?=V%I="<@/3X@(E%U97)Y:6YG('-L879E('-E<G9E<G,N
M("4Q(%1H:7,@;W!E<F%T:6]N(&UI9VAT('1A:V4@<V]M92!T:6UE+B`E,B!0
M;&5A<V4@=V%I="XN+B(L"@DG<V5R=F5R<U]L:7-T7U]R96UO=F5?<&%G95]T
M:71L92<@/3X@(E1H92!F;VQL;W=I;F<@<VQA=F4@<V5R=F5R(&%C8V]U;G1S
M('=I;&P@8F4@<F5M;W9E9#HB+`H))W-E<G9E<G-?;&ES=%]?<V5L96-T7W-L
M879E7W-E<G9E<G-?=&]?<F5M;W9E)R`]/B`B4V5L96-T('1H92!S;&%V92!S
M97)V97)S('1O(&)E(')E;6]V960N(BP*"2=S97)V97)S7VQI<W1?7W1O=&%L
M7V9I;&5S)R`]/B`B4VQA=F4@<V5R=F5R<R(L"@DG<V5R=F5R<U]L:7-T7U]U
M;F%B;&5?=&]?9V5T7W-L879E<U]N=6UB97(G(#T^(")5;F%B;&4@=&\@9&5T
M97)M:6YE('1H92!N=6UB97(@;V8@<VQA=F4@<V5R=F5R<R(L"@DG<V5R=F5R
M<U]L:7-T7U]U;F%B;&5?=&]?<F5M;W9E)R`]/B`B56YA8FQE('1O(')E;6]V
M92!T:&4@<VQA=F4@<V5R=F5R(&%C8V]U;G0Z("4Q(BP*"2=S97)V97)S7VQI
M<W1?7WEO=5]H879E7W1O;U]M86YY7W-L879E<R<@/3X@(EEO=2!H879E(&UO
M<F4@<VQA=F4@<V5R=F5R<R!A8V-O=6YT<R!S970@=7`@=&AA;B!I="!I<R!A
M;&QO=V5D(&)Y('EO=7(@;&EC96YS92!K97DN(BP*"2=S97)V97)T<F%F9FEC
M;&ES=%]H96%D97(G(#T^(")397)V97(@=')A9F9I8R(L"@DG<V5S<VEO;E]?
M:6YV86QI9%]I9&QE7W1I;64G(#T^(")397-S:6]N(&ED;&4@=&EM92!I<R!I
M;G9A;&ED+B(L"@DG<V5S<VEO;E]?:6YV86QI9%]L;V=I;E]A='1E;7!T<R<@
M/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',@=F%L=64@<VAO=6QD(&)E(&$@
M<&]S:71I=F4@:6YT96=E<BXB+`H))W-E<W-I;VY?7VEN=F%L:61?;&]G:6Y?
M:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN(&EN=&5R=F%L('9A;'5E('-H
M;W5L9"!B92!A('!O<VET:79E(&EN=&5G97(N(BP*"2=S97-S:6]N7U]I;G9A
M;&ED7VQO9VEN7VQO8VM?=&EM92<@/3X@(DEN=F%L:60@;&]G:6X@;&]C:R!T
M:6UE('9A;'5E('-H;W5L9"!B92!A('!O<VET:79E(&EN=&5G97(N(BP*"2=S
M97-S:6]N<U]?86=R965M96YT)R`]/B`B665S+"!)('=I<V@@=&\@96YD('1H
M97-E('-E<W-I;VYS+B(L"@DG<V5S<VEO;G-?7VEN=E]L;V=I;E]A='1E;7!T
M<R<@/3X@(DEN=F%L:60@;&]G:6X@871T96UP=',B+`H))W-E<W-I;VYS7U]I
M;G9?;&]G:6Y?:6YT97)V86PG(#T^("));G9A;&ED(&QO9VEN(&EN=&5R=F%L
M(BP*"2=S97-S:6]N<U]?:6YV7VQO9VEN7VQO8VM?=&EM92<@/3X@(DEN=F%L
M:60@;&]G:6X@;&]C:R!T:6UE(BP*"2=S97-S:6]N<U]?;6EN)R`]/B`B36EN
M=71E<R(L"@DG<V5S<VEO;G-?7W)E<75I<F5D7V9I96QD<R<@/3X@(E)E<75I
M<F5D(&9I96QD<RXB+`H))W-E<W-I;VYS7U]S96QE8W1?<V5S<VEO;G-?9F]R
M7W)E;6]V92<@/3X@(E-E;&5C="!T:&4@<V5S<VEO;G,@=&\@8F4@96YD960N
M(BP*"2=S97-S:6]N<U]?<V5S<VEO;E]I9&QE7W1I;64G(#T^(")397-S:6]N
M(&ED;&4@=&EM92(L"@DG<V5S<VEO;G-?7W-E<W-I;VY?<V5T=7`G(#T^("),
M;V=I;B!3971T:6YG<R(L"@DG<V5S<VEO;G-?7W-E<W-I;VYS7VUA;F%G96UE
M;G0G(#T^(")397-S:6]N<R!-86YA9V5M96YT(BP*"2=S97-S:6]N<U]?=6YA
M8FQE7W-E='5P7VEN=F%L:61?;&]G:6Y?871T96UP=',G(#T^(")5;F%B;&4@
M=&\@<V5T('5P('1H92!N=6UB97(@;V8@:6YV86QI9"!L;V=I;B!A='1E;7!T
M<SH@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?<V5T=7!?:6YV86QI9%]L;V=I
M;E]I;G1E<G9A;"<@/3X@(E5N86)L92!T;R!S970@=7`@:6YV86QI9"!L;V=I
M;B!I;G1E<G9A;#H@)3$B+`H))W-E<W-I;VYS7U]U;F%B;&5?<V5T=7!?:6YV
M86QI9%]L;V=I;E]L;V-K7W1I;64G(#T^(")5;F%B;&4@=&\@<V5T('5P(&EN
M=F%L:60@;&]G:6X@;&]C:R!T:6UE.B`E,2(L"@DG<V5S<VEO;G-?7W5N86)L
M95]S971U<%]S97-S:6]N7VED;&4G(#T^(")5;F%B;&4@=&\@<V5T('5P('-E
M<W-I;VX@:61L92!T:6UE.B`E,2(L"@DG<V5S<VEO;G-?7W1A8G-?8W!?<V5S
M<VEO;G,G(#T^("=#4"!397-S:6]N<R<L"@DG<V5S<VEO;G-?7W1A8G-?9G1P
M7W-E<W-I;VYS)R`]/B`G1E10(%-E<W-I;VYS)RP*"2=S97-S:6]N<U]?9G1P
M7W-E<W-I;VYS7VQO9VEN)R`]/B`G1E10('5S97(@;&]G:6XG+`H))W-E<W-I
M;VYS7U]F='!?<V5S<VEO;G-?9&]M86EN)R`]/B`G1&]M86EN(&YA;64G+`H)
M)W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?<&%T:"<@/3X@)T-U<G)E;G0@;&]C
M871I;VXG+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?9FEL92<@/3X@)T9I
M;&4@;F%M92<L"@DG<V5S<VEO;G-?7V9T<%]S97-S:6]N<U]A8W1I;VXG(#T^
M("=3=&%T=7,G+`H))W-E<W-I;VYS7U]F='!?<V5S<VEO;G-?<W!E960G(#T^
M("=3<&5E9"P@2T(O4R<L"@DG<V5S<VEO;G-?7V9T<%]S97-S:6]N<U]C;VUP
M)R`]/B`G4')O9W)E<W,L("4G+`H*"@DG<VET95]A<'!S7U]A8V-E<W-?;&5V
M96PG(#T^("=!8V-E<W,@;&5V96PG+`H))W-I=&5?87!P<U]?86-C97-S7VQE
M=F5L7V-O;6UE<F-I86PG(#T^("=#;VUM97)C:6%L)RP*"2=S:71E7V%P<'-?
M7V%C8V5S<U]L979E;%]F<F5E)R`]/B`G1G)E92<L"@DG<VET95]A<'!S7U]A
M8W1I;VY?:6YS=&%L;&5R)R`]/B`B4VET92!A<'!L:6-A=&EO;B!I;G-T86QL
M871I;VXB+`H))W-I=&5?87!P<U]?86-T:6]N7W)E8V]N9FEG=7)E)R`]/B`B
M4VET92!A<'!L:6-A=&EO;B!R96-O;F9I9W5R:6YG(BP*"2=S:71E7V%P<'-?
M7V5X=')A7V9I;&5S7W1I=&QE)R`]/B`G5VAA="!T;R!D;R!W:71H('1H92!F
M:6QE<S\G+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R;FEN9R<@/3X@
M)U1H92!C;VYT96YT<R!O9B!T:&4@9&ER96-T;W)Y("4Q('=I;&P@8F4@<F5W
M<FET=&5N('1O(&5N<W5R92!T:&4@8VQE86X@:6YS=&%L;&%T:6]N(&%N9"!P
M<F]P97(@=V]R:R!O9B!T:&4@87!P;&EC871I;VXN(%-O+"!I9B!Y;W4@:&%V
M92!A;GD@=F%L=6%B;&4@9&%T82!S=&]R960@=VET:&EN('1H92!D;VUA:6XL
M('EO=2!S:&]U;&0@8F%C:R!T:&5M('5P(&]R(&UO=F4@=&\@86YO=&AE<B!L
M;V-A=&EO;B!B969O<F4@>6]U('!R;V-E960@=VET:"!T:&4@:6YS=&%L;&%T
M:6]N+B!9;W4@8V%N(&)R;W=S92!T:&4@9&]M86EN(&-O;G1E;G0@=VET:"`E
M,BXG+`H))W-I=&5?87!P<U]?97AT<F%?9FEL97-?=V%R;FEN9U]B<F]W<V4G
M(#T^("=B<F]W<V4@=&AE(&1O;6%I;B!C;VYT96YT('=I=&@@1FEL92!-86YA
M9V5R)RP*"2=S:71E7V%P<'-?7V5X=')A7V9I;&5S7VQE9V5N9"<@/3X@)U=H
M870@=&\@9&\@=VET:"!T:&4@9FEL97,_)RP*"2=S:71E7V%P<'-?7V5X=')A
M7V9I;&5S7V1E;&5T92<@/3X@)U)E;6]V92!A;&P@9FEL97,@:6X@=&AE(&1O
M8W5M96YT(')O;W0@9&ER96-T;W)Y+B<L"@DG<VET95]A<'!S7U]E>'1R85]F
M:6QE<U]K965P)R`]/B`G2V5E<"!E>&ES=&EN9R!F:6QE<RP@=VAE;B!P;W-S
M:6)L92X@3F]T92!T:&%T(&%P<&QI8V%T:6]N(&9I;&5S('=I;&P@;W9E<G=R
M:71E('1H92!E>&ES=&EN9R!F:6QE<R!A;GEW87DL(&%N9"!T:&4@97AT<F$@
M9FEL97,@;6%Y(&-A=7-E(&%P<&QI8V%T:6]N('1O(&)E:&%V92!I;F-O<G)E
M8W1L>2XG+`H))W-I=&5?87!P<U]?;F]?=F%C86YT7W-I=&5?87!P<R<@/3X@
M(EEO=2!H879E(&YO(&-O;6UE<F-I86P@<VET92!A<'!L:6-A=&EO;G,@=&\@
M861D+B(L"@DG<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'`G(#T^(")#;&EE
M;G1S('5S:6YG(&-O;6UE<F-I86P@<VET92!A<'!L:6-A=&EO;B`E,2(L"@DG
M<VET95]A<'!S7U]C;%]L:7-T7V9O<E]A<'!?861D)R`]/B`B4V5L96-T('1H
M92!C;&EE;G1S('=H;R!S:&]U;&0@=7-E('1H:7,@87!P;&EC871I;VXB+`H)
M)W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;"<@/3X@)U=O=6QD('EO
M=2!L:6ME('1O(&-R96%T92!A(&YE=R!C=7-T;VT@8G5T=&]N(&9O<B!A8V-E
M<W-I;F<@=&AI<R!A<'!L:6-A=&EO;C\G+`H))W-I=&5?87!P<U]?8W5S=&]M
M7V)U='1O;E]L979E;%]F86QS95]D;VUA:6Y?=7-E<E]O;FQY)R`]/B`G3F\G
M+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]D;VUA:6Y?=7-E
M<E]O;FQY)R`]/B`G665S)RP*"2=S:71E7V%P<'-?7V-U<W1O;5]B=71T;VY?
M;&5V96Q?9F%L<V4G(#T^("=.;R<L"@DG<VET95]A<'!S7U]C=7-T;VU?8G5T
M=&]N7VQE=F5L7V1O;6%I;B<@/3X@)UEE<RP@86YD(&UA:V4@:70@879A:6QA
M8FQE(&9O<B!T:&4@8W5R<F5N="!D;VUA:6X@;VYL>2XG+`H))W-I=&5?87!P
M<U]?8W5S=&]M7V)U='1O;E]L979E;%]C;&EE;G0G(#T^("=997,L(&%N9"!M
M86ME(&ET(&%V86EL86)L92!F;W(@86QL(&1O;6%I;G,@;V8@=&AE(&-L:65N
M="XG+`H))W-I=&5?87!P<U]?8W5S=&]M7V)U='1O;E]L979E;%]A9&UI;B<@
M/3X@)UEE<RP@86YD(&UA:V4@:70@879A:6QA8FQE(&9O<B!A;&P@9&]M86EN
M<RXG+`H))W-I=&5?87!P<U]?9&5S8W)I<'1I;VXG(#T^(")$97-C<FEP=&EO
M;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]S87!P7U\G(#T^(")4:&4@
M9&ER96-T;W)Y(%PB)3%<(B!I<R!U<V5D(&)Y(&%N;W1H97(@<VET92!A<'!L
M:6-A=&EO;B(L"@DG<VET95]A<'!S7U]D:7)?=7-E9%]B>5]F<%]?)R`]/B`B
M5&AE(&1I<F5C=&]R>2!<(B4Q7"(@:7,@=7-E9"!B>2!T:&4@1G)O;G1086=E
M(&%P<&QI8V%T:6]N(BP*"2=S:71E7V%P<'-?7V1I<E]U<V5D7V)Y7W5N:VYO
M=VY?7R<@/3X@(E1H92!D:7)E8W1O<GD@7"(E,5PB(&%L<F5A9'D@97AI<W1S
M(BP*"2=S:71E7V%P<'-?7V9I;&5?;F%M92<@/3X@(E-I=&4@87!P;&EC871I
M;VX@<&%C:V%G92!F:6QE;F%M92(L"@DG<VET95]A<'!S7U]I;G-T86QL871I
M;VY?;G5M8F5R)R`]/B`B26YS=&%N8V5S(BP*"2=S:71E7V%P<'-?7VEN<W1A
M;&QE9%]I;E]?)R`]/B`B:6YS=&%L;&5D(&EN("4Q(BP*"2=S:71E7V%P<'-?
M7VEN=F%L:61?:6YS=&%L;%]P<F5F:7@G(#T^("));G9A;&ED(&EN<W1A;&QA
M=&EO;B!P<F5F:7@B+`H))W-I=&5?87!P<U]?:6YV86QI9%]P86-K86=E)R`]
M/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E(&ES(&EN=F%L:60N(BP*"2=S
M:71E7V%P<'-?7V5R<F]R7W1E<W1?<&%C:V%G92<@/3X@(E1H:7,@<&%C:V%G
M92!F:6QE(&ES(&EN=F%L:60N7&XE,2(L"@DG<VET95]A<'!S7U]E<G)O<E]T
M97-T7W!A8VMA9V5?=F%U;'0G(#T^(")4:&ES(&9I;&4@:7,@;F]T(&$@=F%L
M:60@<VET92!A<'!L:6-A=&EO;B!P86-K86=E+EQN)3$B+`H))W-I=&5?87!P
M<U]?97)R;W)?861D7W!A8VMA9V5?7R<@/3X@(E5N86)L92!T;R!I;G-T86QL
M('1H92!S:71E(&%P<&QI8V%T:6]N('!A8VMA9V4N7&XE,2(L"@DG<VET95]A
M<'!S7U]K97E?<W1A='5S)R`]/B`G3&EC96YS:6YG)RP*"2=S:71E7V%P<'-?
M7VME>5]S=&%T=7-?9G)E92<@/3X@)T1I<W1R:6)U=&5D(&9R965L>2X@3F\@
M;&EC96YS92!K97D@<F5Q=6ER960G+`H))W-I=&5?87!P<U]?:V5Y7W-T871U
M<U]O:R<@/3X@)U1H92!R97%U:7)E9"!L:6-E;G-E(&ME>2!I<R!I;G-T86QL
M960G+`H))W-I=&5?87!P<U]?:V5Y7W-T871U<U]P<F]B;&5M)R`]/B`G5&AE
M(')E<75I<F5D(&QI8V5N<V4@:V5Y(&ES(&YO="!I;G-T86QL960G+`H))W-I
M=&5?87!P<U]?;F%M92<@/3X@(DYA;64B+`H))W-I=&5?87!P<U]?;F]?9&]M
M86EN<R<@/3X@)U1H92!S:71E(&%P<&QI8V%T:6]N(&-A;FYO="!B92!I;G-T
M86QL960N(%1H97)E(&ES(&%L<F5A9'D@86YO=&AE<B!S:71E(&%P<&QI8V%T
M:6]N(&EN<W1A;&QE9"!I;B!T:&4@<F]O="!D:7)E8W1O<GD@;V8@=&AI<R!D
M;VUA:6XN($-O;G-I9&5R(&-R96%T:6YG(&$@<W5B9&]M86EN(&9O<B!T:&4@
M<VET92!A<'!L:6-A=&EO;BXG+`H))W-I=&5?87!P<U]?<&%C:V%G95]I;F9O
M7R<@/3X@(E-I=&4@07!P;&EC871I;VX@4&%C:V%G92!);F9O<FUA=&EO;B(L
M"@DG<VET95]A<'!S7U]P86-K86=E7VEN=&5G<F%T960G(#T^(")B=6EL="UI
M;B!P86-K86=E+"!C86YN;W0@8F4@<F5M;W9E9"(L"@DG<VET95]A<'!S7U]P
M;V]L7W1I=&QE)R`]/B`G07!P;&EC871I;VX@<&]O;"!O9B`E,2<L"@DG<VET
M95]A<'!S7U]P;V]L7W)E;6]V95]T:71L92<@/3X@(E1H92!F;VQL;W=I;F<@
M<VET92!A<'!L:6-A=&EO;B!P86-K86=E<R!W:6QL(&)E(')E;6]V960@9G)O
M;2!T:&4@<&]O;#HB+`H))W-I=&5?87!P<U]?<&]O;%]S96QE8W1?<&%C:V%G
M97-?=&]?<F5M;W9E)R`]/B`G4V5L96-T('1H92!S:71E(&%P<&QI8V%T:6]N
M('!A8VMA9V5S('1O(&)E(')E;6]V960N)RP*"2=S:71E7V%P<'-?7W!O;VQ?
M<V5L96-T7W!A8VMA9V5S7W1O7V%D9"<@/3X@)U-E;&5C="!T:&4@<VET92!A
M<'!L:6-A=&EO;B!P86-K86=E<R!T;R!A9&0@=&\@=&AE('!O;VPN)RP*"2=S
M:71E7V%P<'-?7W!O;VQ?861D7W1I=&QE)R`]/B`G061D('-I=&4@87!P;&EC
M871I;VX@<&%C:V%G97,@=&\@=&AE('!O;VPG+`H))W-I=&5?87!P<U]?<F5L
M96%S92<@/3X@(E)E;&5A<V4B+`H))W-I=&5?87!P<U]?<F5Q=6ER97-?879A
M:6)L95]T:71L92<@/3X@(D%V86EL86)L92(L"@DG<VET95]A<'!S7U]R97%U
M:7)E<U]E<G)O<B<@/3X@(E1H92!S:71E(&%P<&QI8V%T:6]N(')E<75I<F5S
M('1H92!R97-O=7)C97,L('=H:6-H(&%R92!N;W0@8W5R<F5N=&QY(&%V86EL
M86)L92(L"@DG<VET95]A<'!S7U]R97%U:7)E<U]E<G)O<E]?)R`]/B`B5&AE
M('-I=&4@87!P;&EC871I;VX@<F5Q=6ER97,@=&AE(')E<V]U<F-E<RP@=VAI
M8V@@87)E(&YO="!C=7)R96YT;'D@879A:6QA8FQE.EQN)3$B+`H))W-I=&5?
M87!P<U]?<F5Q=6ER97-?97)R;W)?9&5S8W)I<'1I;VY?7R<@/3X@(B4Q+"`E
M,BX@<F5Q=6ER960Z("4S+B!A=F%I;&%B;&4Z("4T+B(L"@DG<VET95]A<'!S
M7U]R97%U:7)E<U]E<G)O<E]H;W-T:6YG7U\G(#T^(")4:&4@<F5Q=6ER960@
M<F5S;W5R8V4@:7,@;F]T(&5N86)L960@:6X@9&]M86EN(&AO<W1I;F<@9F5A
M='5R97,N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S7V5R<F]R7VQI;6ET<U]?
M)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E(&ES(&YO="!A=F%I;&%B;&4@
M9'5E('1O(&1O;6%I;B!L:6UI=',@9&5F:6YE9"XB+`H))W-I=&5?87!P<U]?
M<F5Q=6ER97-?97)R;W)?<WES=&5M7V1I<VM?<W!A8V5?7R<@/3X@(DYO="!E
M;F]U9V@@9G)E92!D:7-K('-P86-E(&]N("4Q+B!0;&5A<V4@9G)E92!U<"!S
M;VUE(&1I<VL@<W!A8V4@86YD('1R>2!I;G-T86QL:6YG('1H:7,@87!P;&EC
M871I;VX@86=A:6XN(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S7V5R<F]R7W9E
M<G-I;VY?7R<@/3X@(E1H92!C;VUP;VYE;G0@=F5R<VEO;B!O;B!T:&4@<V5R
M=F5R(&1O97,@;F]T('-A=&ES9GD@=&AE('-I=&4@87!P;&EC871I;VXG<R!R
M97%U:7)E;65N=',N(BP*"2=S:71E7V%P<'-?7W)E<75I<F5S7V5R<F]R7W-U
M8F1O;6%I;E]?)R`]/B`B5&AE(')E<75I<F5D(')E<V]U<F-E(&ES(&YO="!E
M;F%B;&5D(&EN('-U8F1O;6%I;B!F96%T=7)E<RXB+`H))W-I=&5?87!P<U]?
M<F5Q=6ER97-?97)R;W)?=&ET;&4G(#T^(")$97-C<FEP=&EO;B(L"@DG<VET
M95]A<'!S7U]R97%U:7)E<U]N86UE7W1I=&QE)R`]/B`B4F5Q=6ER960B+`H)
M)W-I=&5?87!P<U]?<F5Q=6ER97-?='EP95]T:71L92<@/3X@(E1Y<&4B+`H)
M)W-I=&5?87!P<U]?<F5Q=6ER97-?=F%L=65?=&ET;&4G(#T^(")686QU92(L
M"@DG<VET95]A<'!S7U]R97-O=7)C95]U<V5D7V)Y7W-A<'`G(#T^(")4:&ES
M(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D('-I=&4@87!P;&EC
M871I;VXB+`H))W-I=&5?87!P<U]?<F]O=%]U<V5D7V)Y7W-A<'`G(#T^(")4
M:&ES(')E<V]U<F-E(&ES('5S960@8GD@86X@:6YS=&%L;&5D('-I=&4@87!P
M;&EC871I;VXB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P<%]P:V=?=&]?:6YS
M=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L:6-A=&EO;B!P86-K86=E
M('1O(&EN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P<%]P:V=S7W1O
M7W5N:6YS=&%L;"<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L:6-A=&EO;B!P
M86-K86=E<R!T;R!U;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V%P
M<%]T;U]A<'!L:6-A=&EO;B<@/3X@(E-E;&5C="!T:&4@<VET92!A<'!L:6-A
M=&EO;B!T;R!O<&5N(BP*"2=S:71E7V%P<'-?7W-E;&5C=%]A<'!?=&]?<F5C
M;VYF:6=U<F4G(#T^(")396QE8W0@=&AE('-I=&4@87!P;&EC871I;VX@=&\@
M<F5C;VYF:6=U<F4B+`H))W-I=&5?87!P<U]?<V5L96-T7V%P<'-?=&]?=6YI
M;G-T86QL)R`]/B`B4V5L96-T('1H92!S:71E(&%P<&QI8V%T:6]N<R!T;R!U
M;FEN<W1A;&PB+`H))W-I=&5?87!P<U]?<V5L96-T7V-L:65N=',G(#T^(")3
M96QE8W0@8VQI96YT<R(L"@DG<VET95]A<'!S7U]S:71E7V%P<%]P:V=S)R`]
M/B`B4VET92!A<'!L:6-A=&EO;B!P86-K86=E<R(L"@DG<VET95]A<'!S7U]S
M:71E7V%P<%]P:V=S7V%D9"<@/3X@(D%D9"!N97<@<VET92!A<'!L:6-A=&EO
M;B!P86-K86=E(BP*"2=S:71E7V%P<'-?7W-I=&5?87!P7W!K9W-?;6%N86=E
M;65N="<@/3X@(D%P<&QI8V%T:6]N(%9A=6QT(BP*"2=S:71E7V%P<'-?7W-I
M=&5?87!P<R<@/3X@(E-I=&4@07!P;&EC871I;VYS(BP*"2=S:71E7V%P<'-?
M7W-I=&5?87!P<U]M86YA9V5M96YT)R`]/B`B26YS=&%L;&5D($%P<&QI8V%T
M:6]N<R(L"@DG<VET95]A<'!S7U]S:71E7V%P<%]P:V=S7VEN<W1A;&QA=&EO
M;B<@/3X@)TEN<W1A;&QA=&EO;CH@<V5L96-T('1H92!A<'!L:6-A=&EO;B!T
M;R!B92!I;G-T86QL960G+`H))W-I=&5?87!P<U]?<VET95]A<'!?<&MG<U]I
M;G-T86YC97,G(#T^("=);G-T86QL871I;VYS(&]F('1H92`E,2!!<'!L:6-A
M=&EO;B<L"@DG<VET95]A<'!S7U]U;FEN<W1A;&Q?<V%P<"<@/3X@(E5N:6YS
M=&%L;"!A<'!L:6-A=&EO;G,@9G)O;2!D;VUA:6X@)3$B+`H))W-I=&5?87!P
M<U]?=6YI;G-T86QL7W-A<'!P:V<G(#T^(")5;FEN<W1A;&P@87!P;&EC871I
M;VX@<&%C:V%G97,B+`H))W-I=&5?87!P<U]?=7!L;V%D7W-I=&5?87!P7W!K
M9U]T:71L92<@/3X@(E5P;&]A9"!N97<@<VET92!A<'!L:6-A=&EO;B!P86-K
M86=E(BP*"2=S:71E7V%P<'-?7W9E<G-I;VXG(#T^(")697)S:6]N(BP*"2=S
M:71E7V)U:6QD97)?<F5Q=6ER97,G(#T^("<E,2`M("4S)RP*"2=S:V5L971O
M;E]?861M:6Y?;&%B96PG(#T^(")!9&UI;FES=')A=&]R(&1E9FEN960@<VME
M;&5T;VXB+`H))W-K96QE=&]N7U]C;&EE;G1?;&%B96PG(#T^("(E,2!D969I
M;F5D('-K96QE=&]N(BP*"2=S:V5L971O;E]?861M:6Y?<&%G92<@/3X@(E-K
M96QE=&]N(&UA;F%G96UE;G0B+`H))W-K96QE=&]N7U]F:6QE<U]L:7-T)R`]
M/B`B4VME;&5T;VX@8V]N=&5N=',B+`H))W-K96QE=&]N7U]A<F-H:79E<E]N
M;W1?:6YS=&%L;&5D)R`]/B`B56YA8FQE('1O('5N<&%C:R!T:&4@<VME;&5T
M;VXN($%R8VAI=F5R(&ES('!O<W-I8FQY(&YO="!I;G-T86QL960@;VX@=&AE
M('-E<G9E<BX@0V]N=&%C="!T:&4@)%!23T1?3D%-12!A9&UI;FES=')A=&]R
M('1O(&AA=F4@=&AE(&%R8VAI=F5R('-O9G1W87)E(&EN<W1A;&QE9"XB+`H)
M)W-K96QE=&]N7U]C;&EE;G1?<&%G92<@/3X@(E9I<G1U86P@:&]S="!S:V5L
M971O;B!M86YA9V5M96YT(BP*"2=S:V5L971O;E]?87)C:&EV95]C;W)R=7!T
M960G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R960@=&AA="!T:&4@87)C
M:&EV92!F:6QE(&ES(&5I=&AE<B!C;W)R=7!T(&]R('1H:7,@87)C:&EV92!T
M>7!E(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:V5L971O;E]?87)C:&EV95]T
M;V]?;&%R9V4G(#T^(")!<F-H:79E(&-H96-K(&1I<V-O=F5R960@=&AA="!T
M:&4@87)C:&EV92!F:6QE(&ES('1O;R!L87)G92XB+`H))W-K96QE=&]N7U]N
M;W1?<W5P<&]R=&5D7V%R8VAI=F5?='EP92<@/3X@(E1H:7,@='EP92!O9B!A
M<F-H:79E("AF:6QE("4Q*2!I<R!N;W0@<W5P<&]R=&5D(BP*"2=S:V5L971O
M;E]?=7!L;V%D7V%R8VAI=F5?9FEL92<@/3X@(E5P;&]A9"!S:V5L971O;B!A
M<F-H:79E(&9I;&4B+`H))W-K:6Y?9&]W;FQO861?7W1I=&QE)R`]/B`G1&]W
M;FQO860@4VMI;B<L"@DG<VMI;E]D;W=N;&]A9%]N;W=?7W1I=&QE)R`]/B`G
M4VMI;B!D;W=N;&]A9"!I;B!P<F]G<F5S<R<L"@DG<VMI;E]D;W=N;&]A9%]N
M;W=?7W1E>'0G(#T^("=4:&4@<VMI;B!P86-K86=E(&-R96%T:6]N(&ES(&EN
M('!R;V=R97-S+CQB<CY4:&ES('!R;V-E9'5R92!M87D@=&%K92!S;VUE('1I
M;64N/&)R/B!/;F-E('1H92!D:6%L;V<*=VEN9&]W(&%P<&5A<G,L('EO=2!C
M86X@8V]N=&EN=64@;W!E<F%T:6YG('1H92!C;VYT<F]L('!A;F5L+B<L"@DG
M<VMI;E]F:6QE7U]H96QP7V9O<E]U<VEN9U]T>7!E<R<@/3X@(E!L96%S92P@
M=7-E('1H92!S:VEN(&%R8VAI=F5S(&EN(&]N92!O9B!T:&4@9F]L;&]W:6YG
M(&9O<FUA=',B+`H))W-K:6Y?:6YF;U]?=&ET;&4G(#T^("=3:VEN(%!R;W!E
M<G1I97,G+`H))W-K:6Y?;6YG7V5R<E]?<G!M7VYO=%]S:VEN)PD]/B`G5&AI
M<R!24$T@:7,@;F]T(&$@8V]N=')O;"!P86YE;"!S:VEN('!A8VMA9V4G+`H)
M)W-K:6Y?;6YG7V5R<E]?<'-A7VEN<W1A;&Q?;F]R96QO8R<@/3X@)T9A:6QE
M9"!T;R!I;G-T86QL(')P;2UB87-E9"!S:VEN(&EN('1H92!S<&5C:69I960@
M;&]C871I;VXN)RP*"2=S:VEN7VUN9U]E<G)?7V%L<F5A9'E?97AI<W1S)R`]
M/B`G5&AE('-K:6X@:6YS=&%L;&%T:6]N(&1I<F5C=&]R>2!A;')E861Y(&5X
M:7-T<RP@86YD('1H97)E(&ES(&$@<VMI;B!P86-K86=E(&1E<&QO>65D+B<L
M"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;VYR<&TG(#T^("=4:&4@
M=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!24$T@<VMI;B!P86-K86=E
M+B<L"@DG<VMI;E]M;F=?97)R7U]R<&U?=7!G<F%D95]N;W-K:6XG(#T^("=4
M:&4@=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"!S:VEN('!A8VMA9V4N
M)RP*"2=S:VEN7VUN9U]E<G)?7W)P;5]U<&=R861E7V)A<V4G(#T^(")4:&4@
M=7!L;V%D960@9FEL92!I<R!N;W0@82!V86QI9"`D4%)/1%].04U%('-K:6X@
M<&%C:V%G92XB+`H))W-K:6Y?;6YG7V5R<E]?<G!M7W5P9W)A9&5?;W1H97(G
M(#T^("=5;F%B;&4@=&\@:6YS=&%L;"!T:&4@<VMI;CH@:6YV86QI9"!S:VEN
M(&9O<FUA="XG+`H))W-K:6Y?;6YG7V5R<E]?;F]?85]S:VEN)R`]/B`B5&AE
M('5P;&]A9&5D(&9I;&4@:7,@;F]T(&$@=F%L:60@)%!23T1?3D%-12!S:VEN
M('!A8VMA9V4N(BP*"2=S:VEN7W5P;&]A9%]?=&ET;&4G(#T^("=5<&QO860@
M3F5W(%-K:6XG+`H))W-K:6Y?=7!L;V%D7U]A;')E861Y7V5X:7-T<R<@/3X@
M(E1H92!S:VEN("<E,2<@86QR96%D>2!E>&ES=',B+`H))W-K:6Y?=7!L;V%D
M7U]U;F%B;&5?=&]?87!P;'DG(#T^(")4:&4@=7!L;V%D960@9FEL92!D;V5S
M(&YO="!C;VYT86EN(&$@4&QE<VL@<VMI;BP@;W(@=&AE(&%R8VAI=F4@9F]R
M;6%T(&ES(&YO="!S=7!P;W)T960N(BP*"2=S:VEN7W5P;&]A9%]?9FEL95]N
M86UE)R`]/B`G4&%T:"!T;R!T:&4@<VMI;B!P86-K86=E(&9I;&4G+`H))W-K
M:6YS7VQI<W1?7W1I=&QE)R`]/B`G4VMI;G,@4F5P;W-I=&]R>2<L"@DG<VMI
M;G-?<F5M;W9E7U]T:71L92<@/3X@)U-K:6X@4F5M;W9A;"<L"@DG<VMI;G-?
M<F5M;W9E7U]S96QE8W1?<VMI;G-?9F]R7W)E;6]V92<@/3X@)U-E;&5C="!T
M:&4@<VMI;G,@=&\@8F4@<F5M;W9E9"XG+`H))W-L879E7V-E<G1?7W!A9V5?
M=&ET;&4G(#T^(")3;&%V92!S97)V97(@)3$@8V5R=&EF:6-A=&4@<V5T=7`N
M(BP*"2=S;&%V95]S97)V97)?7V%D;6EN7V%P86-H95]I<U]N;W1?=V]R:R<@
M/3X@(D%D;6EN(&%P86-H92!S97)V97(@9&]E<R!N;W0@9G5N8W1I;VXZ('1H
M92!P;W)T(')E:F5C=',@8V]N;F5C=&EO;G,N(BP*"2=S;&%V95]S97)V97)?
M7V%L;%]O:R<@/3X@(D%L;"!S97)V:6-E<R!F=6YC=&EO;B!P<F]P97)L>2!A
M;F0@=&AE<F4@87)E(&YO('!R;V)L96T@9&]M86EN<R!O<B!C;&EE;G1S(&]N
M('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?7V)A9%]C;&EE
M;G1S)R`]/B`B5&AE<F4@87)E('!R;V)L96T@8VQI96YT<R!O;B!T:&4@<VQA
M=F4@<V5R=F5R+B(L"@DG<VQA=F5?<V5R=F5R7U]B861?9&]M86EN<R<@/3X@
M(E1H97)E(&%R92!P<F]B;&5M(&1O;6%I;G,@;VX@=&AE('-L879E('-E<G9E
M<BXB+`H))W-L879E7W-E<G9E<E]?8F%D7V1O;6%I;G-?86YD7V-L:65N=',G
M(#T^(")4:&5R92!A<F4@<')O8FQE;2!C;&EE;G1S(&%N9"!D;VUA:6YS(&]N
M('1H92!S;&%V92!S97)V97(N(BP*"2=S;&%V95]S97)V97)?7V-E<G1?9FEL
M96YA;65?:7-?96UP='DG(#T^(")5<&QO861E9"!S;&%V92!S97)V97(@8V5R
M=&EF:6-A=&4@9FEL96YA;64@:7,@96UP='DN(BP*"2=S;&%V95]S97)V97)?
M7V-E<G1?:7-?:6YV86QI9"<@/3X@(E1H92!C97)T:69I8V%T92!U<V5D(&9O
M<B!T:&ES('-E<W-I;VX@9&ED(&YO="!P87-S('1H92!V97)I9FEC871I;VXN
M(BP*"2=S;&%V95]S97)V97)?7V-E<G1?:7-?;F]T7W-E="<@/3X@(E-33"!C
M97)T:69I8V%T92!F;W(@=&AI<R!S;&%V92!S97)V97(@=V%S(&YO="!I;G-T
M86QL960N(BP*"2=S;&%V95]S97)V97)?7V-E<G1?=&5X=&9I96QD7VES7V5M
M<'1Y)R`]/B`B57!L;V%D960@<VQA=F4@<V5R=F5R(&-E<G1I9FEC871E(&ES
M(&5M<'1Y+B(L"@DG<VQA=F5?<V5R=F5R7U]C;W5L9&YT7V-O;FYE8W0G(#T^
M(")&86EL960@=&\@8V]N;F5C="!T;R!H;W-T+B(L"@DG<VQA=F5?<V5R=F5R
M7U]D97-C<FEP=&EO;B<@/3X@(D1E<V-R:7!T:6]N(BP*"2=S;&%V95]S97)V
M97)?7V1O7VYO=%]R97%U97-T)R`]/B`B1&\@;F]T(')E<75E<W0@:6YF;W)M
M871I;VX@9G)O;2!T:&4@<V5R=F5R(BP*"2=S;&%V95]S97)V97)?7V5N=&5R
M<')I<V5?:7-?;F]T7W-U<'!O<G1E9"<@/3X@(E1H92`D4%)/1%].04U%('9E
M<G-I;VX@<G5N;FEN9R!O;B!T:&ES('-E<G9E<B!D;V5S(&YO="!S=7!P;W)T
M('1H92!-87-T97(@9F5A='5R92XB+`H))W-L879E7W-E<G9E<E]?9F]L;&]W
M:6YG7W-E<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B5&AE(&9O;&QO=VEN9R!S
M97)V:6-E<R!D;R!N;W0@9G5N8W1I;VX@;VX@=&AE('-L879E('-E<G9E<CH@
M)3$N(BP*"2=S;&%V95]S97)V97)?7VEN=F%L:61?;&]G:6Y?;W)?<&%S<W=O
M<F0G(#T^("));F-O<G)E8W0@;&]G:6X@86YD('!A<W-W;W)D+B(L"@DG<VQA
M=F5?<V5R=F5R7U]K97E?;&EM:71S)R`]/B`B66]U<B!K97D@86QL;W=S(&-R
M96%T:6YG("4Q('-L879E('-E<G9E<G,@86-C;W5N=',@;VYL>2XB+`H))W-L
M879E7W-E<G9E<E]?<&%G95]T:71L92<@/3X@(E-L879E('-E<G9E<B!A8V-O
M=6YT(BP*"2=S;&%V95]S97)V97)?7W)E<75E<W1?=&EM96]U="<@/3X@(E-E
M<G9E<B!D871A(')E=')I979A;"!T:6UE;W5T+B(L"@DG<VQA=F5?<V5R=F5R
M7U]S96QE8W1?<VQA=F5?<V5R=F5R<U]F;W)?<F5M;W9E)R`]/B`B4V5L96-T
M('-L879E('-E<G9E<B!A8V-O=6YT<R!T;R!B92!R96UO=F5D+B(L"@DG<VQA
M=F5?<V5R=F5R7U]S97)V97)?86-C;W5N=%]A;')E861Y7V5X:7-T)R`]/B`B
M<V5R=F5R(&%C8V]U;G0@=VET:"!S=6-H(&AO<W1N86UE(&%L<F5A9'D@97AI
M<W1S+B(L"@DG<VQA=F5?<V5R=F5R7U]S97)V97)?:6YF;U]I<U]N;W1?879A
M:6QA8FQE)R`]/B`B4VQA=F4@<V5R=F5R(&EN9F]R;6%T:6]N(&ES(&YO="!C
M=7)R96YT;'D@879A:6QA8FQE+B(L"@DG<VQA=F5?<V5R=F5R7U]S;VUE7W-E
M<G9I8V5S7VES7VYO=%]W;W)K)R`]/B`B4V]M92!S97)V:6-E<R!D;R!N;W0@
M9G5N8W1I;VX@;VX@=&AE('-L879E('-E<G9E<BXB+`H))W-L879E7W-E<G9E
M<E]?=6YA8FQE7V1E9FEN95]H;W-T;F%M92<@/3X@(E5N86)L92!T;R!D969I
M;F4@=&AE('-L879E('-E<G9E<B!H;W-T;F%M93H@)3$B+`H))W-L879E7W-E
M<G9E<E]?=6YA8FQE7W1O7W)E<V]L=F5?:&]S=&YA;64G(#T^(")5;F%B;&4@
M=&\@<F5S;VQV92!T:&4@:&]S=&YA;64N(BP*"2=S;&%V95]S97)V97)?7W5N
M86)L95]T;U]S971?8V5R=&EF:6-A=&4G(#T^(")5;F%B;&4@=&\@:6YS=&%L
M;"!T:&4@8V5R=&EF:6-A=&4@=&\@=&AE('-L879E('-E<G9E<CH@)3$B+`H)
M)W-L879E7W-E<G9E<E]?=6YA8FQE7W1O7W5P9&%T92<@/3X@(E5N86)L92!T
M;R!U<&1A=&4@=&AE('-L879E('-E<G9E<B!P<F5F97)E;F-E<SH@)3$B+`H)
M)W-L879E7W-E<G9E<E]?=6YK;F]W;E]E<G)O<B<@/3X@(E-E<G9E<B!R971U
M<FYE9"!U;FMN;W=N(&5R<F]R+B(L"@DG<W!A;6%S<V%S<VEN7U]T:71L92<@
M/3X@(E-P86T@9FEL=&5R(&-O;F9I9W5R871I;VXB+`H))W-P87=?7V5D:71?
M9FEL95]?)R`]/B`G5UE325=91R!E9&ET;W(Z("4Q)RP*"2=S<&%W;E]?=6YA
M8FQE7W1O7V5D:71?;F]?8F]D>2<@/3X@)U5N86)L92!T;R!E9&ET('1H:7,@
M9FEL92!B96-A=7-E(&ET(&1O97,@;F]T(&-O;G1A:6X@=&AE(#QB;V1Y/B!T
M86<N)RP*"2=S<&9?<&%R86UE=&5R<R<@/3X@)T5N86)L92!34$8@<W!A;2!P
M<F]T96-T:6]N)RP*"2=S<&9?8F5H879I;W(G(#T^("=34$8@8VAE8VMI;F<@
M;6]D92<L"@DG<W!F7W)U;&5S)R`]/B`G4U!&(&QO8V%L(')U;&5S)RP*"2=S
M<&9?9W5E<W,G(#T^("=34$8@9W5E<W,G+`H))W-P9E]E>'`G(#T^("=34$8@
M97AP;&%N871I;VX@=&5X="<L"@DG<W!F7U]U;F%B;&5?=7!D871E)R`]/B`G
M56YA8FQE('1O('5P9&%T92!34$8@<&%R86UE=&5R<R<L"@DG<W!F7V)H=E]?
M8W)E871E7VAE861E<G-?;F]?8FQO8VLG(#T^("=/;FQY(&-R96%T92!296-E
M:79E9"U34$8@:&5A9&5R<RP@;F5V97(@8FQO8VLG+`H))W-P9E]B:'9?7W5S
M95]T;7!?97)R;W)S)R`]/B`G57-E('1E;7!O<F%R>2!E<G)O<B!N;W1I8V5S
M('=H96X@>6]U(&AA=F4@1$Y3(&QO;VMU<"!P<F]B;&5M<R<L"@DG<W!F7V)H
M=E]?<F5J96-T7VEF7V9A:6PG(#T^("=296IE8W0@;6%I;',@=VAE;B!34$8@
M<F5S;VQV97,@=&\@(F9A:6PB("AD96YY*2<L"@DG<W!F7V)H=E]?<F5J96-T
M7VEF7W-O9G1F86EL)R`]/B`G4F5J96-T(&UA:6QS('=H96X@4U!&(')E<V]L
M=F5S('1O(")S;V9T9F%I;"(G+`H))W-P9E]B:'9?7W)E:F5C=%]I9E]N975T
M<F%L)R`]/B`G4F5J96-T(&UA:6QS('=H96X@4U!&(')E<V]L=F5S('1O(")N
M975T<F%L(B<L"@DG<W!F7V)H=E]?<F5J96-T7VEF7VYO7W!A<W,G(#T^("=2
M96IE8W0@;6%I;',@=VAE;B!34$8@9&]E<R!N;W0@<F5S;VQV92!T;R`B<&%S
M<R(G+`H))W-S:'1E<FU?7W1I=&QE)R`]/B`G4V5C=7)E(%-H96QL(%1E<FUI
M;F%L)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H96YT:6-A=&EO;E]W87)N
M:6YG)R`]/B`G3F]T93H@4&%S<W=O<F0@875T:&5N=&EC871I;VX@:7,@9&ES
M86)L960@:6X@=&AE(&QO8V%L(%-32"!S97)V97(@8V]N9FEG=7)A=&EO;BX@
M268@>6]U(&%R92!U;F%B;&4@=&\@8V]N;F5C="!U<VEN9R!T:&4@4U-((%1E
M<FUI;F%L+"!A<VL@=&AE(&%D;6EN:7-T<F%T;W(@=&\@<V5T(")087-S=V]R
M9$%U=&AE;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H+W-S:&1?8V]N
M9FEG(&9I;&4N)RP*"2=S<VAT97)M7U]P87-S=V]R9%]A=71H96YT:6-A=&EO
M;E]W87)N:6YG7V%D;6EN)R`]/B`G3F]T93H@4&%S<W=O<F0@875T:&5N=&EC
M871I;VX@:7,@9&ES86)L960@:6X@=&AE(&QO8V%L(%-32"!S97)V97(@8V]N
M9FEG=7)A=&EO;BX@268@>6]U(&%R92!U;F%B;&4@=&\@8V]N;F5C="!U<VEN
M9R!T:&4@4U-((%1E<FUI;F%L+"!P;&5A<V4@<V5T(")087-S=V]R9$%U=&AE
M;G1I8V%T:6]N('EE<R(@:6X@=&AE("]E=&,O<W-H+W-S:&1?8V]N9FEG(&9I
M;&4N)RP*"2=S=&%T:7-T:6-S7U]A8W1I=F5?9&]M86EN<R<@/3X@(D%C=&EV
M92!D;VUA:6YS(BP*"2=S=&%T:7-T:6-S7U]C;&EE;G1S)R`]/B`B0VQI96YT
M<R(L"@DG<W1A=&ES=&EC<U]?<W5B9&]M86EN<R<@/3X@(E-U8F1O;6%I;G,B
M+`H))W-T871I<W1I8W-?7V-P=2<@/3X@(D-052(L"@DG<W1A=&ES=&EC<U]?
M9&%T86)A<V5S)R`]/B`B1&%T86)A<V5S(BP*"2=S=&%T:7-T:6-S7U]D8E]U
M<V5R<R<@/3X@(D1A=&%B87-E('5S97)S(BP*"2=S=&%T:7-T:6-S7U]D:7)S
M)R`]/B`B1&ER96-T;W)I97,B+`H))W-T871I<W1I8W-?7V1O;5]A8W1I=F4G
M(#T^(")!8W1I=F4B+`H))W-T871I<W1I8W-?7V1O;5]P87-S:79E)R`]/B`B
M4&%S<VEV92(L"@DG<W1A=&ES=&EC<U]?9&]M7W!R;V)L96TG(#T^(")0<F]B
M;&5M(BP*"2=S=&%T:7-T:6-S7U]D;VUA:6YS)R`]/B`B1&]M86EN<R(L"@DG
M<W1A=&ES=&EC<U]?9&]M86EN<U]W:71H7VAO<W0G(#T^(")$;VUA:6YS('=I
M=&@@:&]S=&EN9R(L"@DG<W1A=&ES=&EC<U]?9&]M<R<@/3X@(D1O;6%I;G,@
M(BP*"2=S=&%T:7-T:6-S7U]F:6QE<WES=&5M)R`]/B`B1FEL97-Y<W1E;2(L
M"@DG<W1A=&ES=&EC<U]?9V5N97)A;"<@/3X@(D=E;F5R86PB+`H))W-T871I
M<W1I8W-?7VAD9%]A=F%I;&%B;&4G(#T^(")!=F%I;&%B;&4B+`H))W-T871I
M<W1I8W-?7VAD9%]C87!A8VET>2<@/3X@(D-A<&%C:71Y(BP*"2=S=&%T:7-T
M:6-S7U]H9&1?=&]T86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?:&1D
M7W5S86=E)R`]/B`B2&%R9"!$:7-K(%5S86=E(BP*"2=S=&%T:7-T:6-S7U]H
M9&1?=7-E9"<@/3X@(E5S960B+`H))W-T871I<W1I8W-?7VEP)R`]/B`B25`@
M861D<F5S<R(L"@DG<W1A=&ES=&EC<U]?:V5Y7VYU;6)E<B<@/3X@(DME>2!N
M=6UB97(B+`H))W-T871I<W1I8W-?7VPQ)R`]/B`B3&%S="`Q(&UI;G5T92(L
M"@DG<W1A=&ES=&EC<U]?;#$U)R`]/B`B3&%S="`Q-2!M:6YU=&5S(BP*"2=S
M=&%T:7-T:6-S7U]L-2<@/3X@(DQA<W0@-2!M:6YU=&5S(BP*"2=S=&%T:7-T
M:6-S7U]L82<@/3X@(D-052!U<V%G92(L"@DG<W1A=&ES=&EC<U]?;6%I;%]A
M=71O<F5S<&]N9&5R<R<@/3X@(D%U=&]R97-P;VYD97)S(BP*"2=S=&%T:7-T
M:6-S7U]M86EL7V)O>&5S)R`]/B`B36%I;&)O>&5S(BP*"2=S=&%T:7-T:6-S
M7U]M86EL7V=R;W5P<R<@/3X@(DUA:6P@9W)O=7!S(BP*"2=S=&%T:7-T:6-S
M7U]M86EL7VQI<W1S)R`]/B`B36%I;&EN9R!L:7-T<R(L"@DG<W1A=&ES=&EC
M<U]?;6%I;%]R961I<F5C=',G(#T^(")-86EL(')E9&ER96-T<R(L"@DG<W1A
M=&ES=&EC<U]?;65M)R`]/B`B365M;W)Y(%5S86=E(BP*"2=S=&%T:7-T:6-S
M7U]M96U?=7-A9V4G(#T^(")5<V%G92(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y
M7V)U9F9E<B<@/3X@(D)U9F9E<B(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y7V-A
M8VAE9"<@/3X@(D-A8VAE9"(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y7V9R964G
M(#T^(")&<F5E(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?<VAA<F5D)R`]/B`B
M4VAA<F5D(BP*"2=S=&%T:7-T:6-S7U]M96UO<GE?=&]T86PG(#T^(")4;W1A
M;"(L"@DG<W1A=&ES=&EC<U]?;65M;W)Y7W5S960G(#T^(")5<V5D(BP*"2=S
M=&%T:7-T:6-S7U]O<R<@/3X@(D]3(BP*"2=S=&%T:7-T:6-S7U]P<F]B;&5M
M7V-L:65N=',G(#T^(")0<F]B;&5M(&-L:65N=',B+`H))W-T871I<W1I8W-?
M7W!R;V)L96U?9&]M86EN<R<@/3X@(E!R;V)L96T@9&]M86EN<R(L"@DG<W1A
M=&ES=&EC<U]?<W=A<"<@/3X@(E-W87`@=7-A9V4B+`H))W-T871I<W1I8W-?
M7W-W87!?9G)E92<@/3X@(D9R964B+`H))W-T871I<W1I8W-?7W-W87!?=&]T
M86PG(#T^(")4;W1A;"(L"@DG<W1A=&ES=&EC<U]?<W=A<%]U<V%G92<@/3X@
M(E5S86=E(BP*"2=S=&%T:7-T:6-S7U]S=V%P7W5S960G(#T^(")5<V5D(BP*
M"2=S=&%T:7-T:6-S7U]S>7-T96U?<W1A="<@/3X@(E-Y<W1E;2!S=&%T:7-T
M:6-S(BP*"2=S=&%T:7-T:6-S7U]U;F%B;&5?9&5F:6YE7V%C=&EV95]D;VUS
M)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN92!T:&4@;G5M8F5R(&]F(&%C=&EV
M92!D;VUA:6YS.B`E,2(L"@DG<W1A=&ES=&EC<U]?=6YA8FQE7V1E9FEN95]I
M;F%C=&EV95]D;VUS)R`]/B`B56YA8FQE('1O(&1E=&5R;6EN92!T:&4@;G5M
M8F5R(&]F(&EN86-T:79E(&1O;6%I;G,Z("4Q(BP*"2=S=&%T:7-T:6-S7U]U
M<%]T:6UE)R`]/B`B4WES=&5M(%5P=&EM93H@(BP*"2=S=&%T:7-T:6-S7U]V
M97(G(#T^(")697)S:6]N(BP*"2=S=&%T:7-T:6-S7U]W96)?87!P<R<@/3X@
M(DIA=F$@87!P;&EC871I;VYS(BP*"2=S=&%T:7-T:6-S7U]W96)?=7-E<G,G
M(#T^(")796(@=7-E<G,B+`H))W-T871U<U]?8VQI96YT7VAA<U]R96%S;VYS
M7W1O7V)E7V]F9B<@/3X@(E1H92!C;&EE;G0@86-C;W5N="!I<R!S=&EL;"!D
M:7-A8FQE9"X@5&AE(')E87-O;CH@)3$B+`H))W-T871U<U]?9&]M86EN7VAA
M<U]R96%S;VYS7W1O7V)E7V]F9B<@/3X@(E1H92!D;VUA:6X@:7,@<W1I;&P@
M9&ES86)L960N(%1H92!R96%S;VXZ("4Q(BP*"2=S=6)D;VUA:6Y?7V-R96%T
M95]?)R`]/B`B0W)E871E(&$@<W5B9&]M86EN(&EN('1H92!D;VUA:6X@)3$B
M+`H))W-U8F1O;6%I;E]?961I=%]?)R`]/B`B36%N86=E('-U8F1O;6%I;B`E
M,2(L"@DG<W5B9&]M86EN7U]I;G9A;&ED7VYA;64G(#T^("));G9A;&ED('-U
M8F1O;6%I;B!N86UE.B!U<V4@;VYL>2!A;'!H86YU;65R:6,@86YD(&1A<V@@
M<WEM8F]L<RXB+`H))W-U8F1O;6%I;G-?7V9U;&Q?;F%M95]L;VYG)R`]/B`B
M5&AE(&9U;&P@;F%M92!O9B!S=6)D;VUA:6X@:7,@=&]O(&QO;F<N(BP*"2=S
M=6)D;VUA:6YS7U]L:7-T7V]F7V1O;6%I;B<@/3X@(E-U8F1O;6%I;G,@:6X@
M=&AE(&1O;6%I;B`E,2(L"@DG<W5B9&]M86EN<U]?;6%I;&QI<W1S7V5N86)L
M961?:6Y?9&]M86EN)R`]/B`B26YC;W)R96-T('-U8F1O;6%I;B!N86UE(&QI
M<W1S+B4Q+"!O;B!D;VUA:6X@)3$@=&AE($UA:6QI;F<@;&ES=',@87)E(&5N
M86)L960N(BP*"2=S=6)D;VUA:6YS7U]D86QI87-?97AI<W1S)R`]/B`G5&AE
M(&1O;6%I;B!A;&EA<R!W:71H('-U8V@@;F%M92!A;')E9'D@97AI<W1S+B<L
M"@DG<W5B9&]M86EN<U]?;F%M95]E>&ES=',G(#T^(")4:&4@<W5B9&]M86EN
M('=I=&@@<W5C:"!N86UE(&%L<F5A9'D@97AI<W1S+B(L"@DG<W5B9&]M86EN
M<U]?<F5G=6QA<E]D;VUA:6Y?97AI<W1S)R`]/B`B5&AE(&1O;6%I;B!W:71H
M('-U8V@@;F%M92!A;')E9'D@97AI<W1S+B(L"@DG<W5B9&]M86EN<U]?<F5M
M;W9E7W-U8F1O;6%I;G-?;VY?9&]M86EN)R`]/B`B5&AE(&9O;&QO=VEN9R!S
M=6)D;VUA:6YS(&9O<B!D;VUA:6X@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG
M<W5B9&]M86EN<U]?<V5L96-T7W-U8F1O;6%I;G-?9F]R7W)E;6]V92<@/3X@
M(E-E;&5C="!T:&4@<W5B9&]M86EN<R!T;R!B92!R96UO=F5D+B(L"@DG<W5B
M9&]M86EN<U]?=&%R9V5T7V9O;&1E<E]E>&ES=',G(#T^(")4:&4@9&ER96-T
M;W)Y("4Q(&9O<B!S=6)D;VUA:6X@86QR96%D>2!E>&ES=',N(BP*"2=S=6)D
M;VUA:6YS7U]W96)M86EL7V5N86)L961?:6Y?9&]M86EN)R`]/B`B26YC;W)R
M96-T('-U8F1O;6%I;B!N86UE('=E8FUA:6PN)3$L(&]N(&1O;6%I;B`E,2!T
M:&4@5V5B;6%I;"!I<R!E;F%B;&5D+B(L"@DG<W5B9&]M86EN<U]?9&YS7W)E
M8V]R9%]A;')E861Y7V5X:7-T<R<@/3X@)U-U8V@@<F5S;W5R8V4@<F5C;W)D
M(&ES(&%L<F5A9'D@:6X@=&AE('IO;F4@)3$N)RP*"2=S=6)D;VUA:6YS7U]W
M=W=?<')E9FEX7VEN7V1O;6%I;B<@/3X@(DEN8V]R<F5C="!S=6)D;VUA:6X@
M;F%M93H@=&AE(&1O;6%I;B`E,2!A;')E861Y(&AA<R!T:&4@5U=7(&%L:6%S
M+B(L"@DG<W5B9&]M86EN<U]?8W)E871I;VY?:6Y?9&YS7W-L879E)R`]/B`B
M4&QE<VLG<R!N86UE('-E<G9E<B!I<R!A8W1I;F<@87,@82!S96-O;F1A<GD@
M*'-L879E*2!N86UE('-E<G9E<B!F;W(@=&AI<R!D;VUA:6XN($9O<B!Y;W5R
M('-U8F1O;6%I;B!T;R!R97-O;'9E('!R;W!E<FQY+"!M86ME('-U<F4@=&AA
M="!T:&4@>F]N92!F:6QE(&]N('1H92!P<FEM87)Y("AM87-T97(I('-E<G9E
M<B!C;VYT86EN<R!T:&4@<F5C;W)D("4Q(BP*"2=S>7-?=7-E<E]?871T<FEB
M=71E<U]N;W1?8VAA;F=E9"<@/3X@(EQN5&AE(&9O;&QO=VEN9R!S>7-T96T@
M=7-E<B!A='1R:6)U=&5S('=E<F4@;F]T(&-H86YG960Z("4Q(BP*"2=S>7-?
M=7-E<E]?;F]?86-C97-S7W=I=&AO=71?<&%S<W=O<F0G(#T^(")9;W4@9&ED
M(&YO="!S970@82!P87-S=V]R9"X@5&AE('-Y<W1E;2!U<V5R('=I;&P@8F4@
M8W)E871E9"P@8G5T('=I;&P@;F]T(&)E(&%B;&4@=&\@;&]G(&EN('1O('1H
M92!S>7-T96TL('5N=&EL(&AE+W-H92!I<R!G:79E;B!A('!A<W-W;W)D+B!7
M;W5L9"!Y;W4@;&EK92!T;R!P<F]C965D/R(L"@DG<WES7W5S97)?7VYO7VAA
M<F1?<75O=&$G(#T^(")N;W0@<W5P<&]R=&5D(BP*"2=S>7-U<V5R7U]Z97)O
M7W%U;W1A7VES7W5N;&EM:71E9"<@/3X@(C`@9F]R('5N;&EM:71E9"(L"@DG
M=&5M<&QA=&5?7VYU;5]E>&-L7VEP<R<@/3X@(D%L;&]C871E(&5X8VQU<VEV
M92!I<"!A9&1R97-S97,@=&\@=&AE(&-L:65N="(L"@DG=&5M<&QA=&5?7W-E
M;%]S:%]I<',G(#T^(")396QE8W0@<VAA<F5D(&EP(&%D9')E<W-E<R(L"@DG
M=&5M<&QA=&5?7V%V7W-H7VEP<R<@/3X@(D%V86EL86)L92!S:&%R960@:7`@
M861D<F5S<V5S(BP*"2=T96UP;&%T95]?=7!?=&]?97AC;%]I<"<@/3X@(E5P
M('1O("4Q(&EP(&%D9')E<W-E<R(L"@DG=&5M<&QA=&5S7U]A;&Q?8VQI96YT
M<R<@/3X@(F%L;"!C;&EE;G1S(BP*"2=T96UP;&%T97-?7V-L7V1O;6%I;E]T
M96UP;&%T97,G(#T^(")496UP;&%T97,@9F]R("4Q(BP*"2=T96UP;&%T97-?
M7V-L7W1E;7!L871E<R<@/3X@(D-L:65N="!T96UP;&%T97,B+`H))W1I;65?
M7V1A>2<@/3X@(D1A>2(L"@DG=&EM95]?9&]M7VYA;65?:7`G(#T^(")$;VUA
M:6X@;F%M92!O<B!)4"(L"@DG=&EM95]?:&]U<G,G(#T^(")(;W5R<R(L"@DG
M=&EM95]?:6YV86QI9%]I<"<@/3X@(DEN=F%L:60@25`@861D<F5S<R!O<B!D
M;VUA:6X@;F%M92XB+`H))W1I;65?7VEN=F%L:61?>65A<B<@/3X@(EEE87(@
M:7,@:6YV86QI9"X@4VAO=6QD(&)E(&)E='=E96X@,3DW,2!A;F0@,C`S-BXB
M+`H))W1I;65?7VEN=F%L:61?;6]N=&@G(#T^(")-;VYT:"!I<R!I;G9A;&ED
M+B!3:&]U;&0@8F4@8F5T=V5E;B`Q(&%N9"`Q,BXB+`H))W1I;65?7VEN=F%L
M:61?9&%Y)R`]/B`B1&%Y(&ES(&EN=F%L:60N(%-H;W5L9"!B92!B971W965N
M(#$@86YD(#,Q+B(L"@DG=&EM95]?:6YV86QI9%]H;W5R<R<@/3X@(DAO=7)S
M(&ES(&EN=F%L:60N(%-H;W5L9"!B92!B971W965N(#`@86YD(#(T+B(L"@DG
M=&EM95]?:6YV86QI9%]M:6YU=&5S)R`]/B`B36EN=71E<R!I<R!I;G9A;&ED
M+B!3:&]U;&0@8F4@8F5T=V5E;B`P(&%N9"`U.2XB+`H))W1I;65?7VEN=F%L
M:61?<V5C;VYD<R<@/3X@(E-E8V]N9',@:7,@:6YV86QI9"X@4VAO=6QD(&)E
M(&)E='=E96X@,"!A;F0@-3DN(BP*"2=T:6UE7U]M:6YU=&5S)R`]/B`B36EN
M=71E<R(L"@DG=&EM95]?;6]N=&@G(#T^(")-;VYT:"(L"@DG=&EM95]?<V5C
M)R`]/B`B4V5C;VYD<R(L"@DG=&EM95]?<WEN7W-Y<U]T:6UE)R`]/B`B4WEN
M8VAR;VYI>F4@<WES=&5M('1I;64B+`H))W1I;65?7W-Y<W1E;5]D871E)R`]
M/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H))W1I;65?7W-Y<W1E;5]D871E
M7W1I=&QE)R`]/B`B4WES=&5M($1A=&4@86YD(%1I;64B+`H))W1I;65?7W1I
M;65Z;VYE7W1I=&QE)R`]/B`G5&EM92!Z;VYE)RP*"2=T:6UE7U]T:6UE>F]N
M92<@/3X@)UEO=7(@=&EM92!Z;VYE)RP*"2=T:6UE7U]P;&5A<V5?<V5L96-T
M7W1I;65Z;VYE)R`]/B`G4&QE87-E+"!S96QE8W0@82!T:6UE('IO;F4G+`H)
M)U]?<&QE87-E7W-E;&5C=%]C;W5N=')Y)R`]/B`G4&QE87-E+"!S96QE8W0@
M>6]U<B!C;W5N=')Y)RP*"2=T:6UE7U]U;F%B;&5?<V5T7W1I;64G(#T^(")5
M;F%B;&4@=&\@<V5T('1H92!S>7-T96T@=&EM93H@)3$B+`H))W1I;65?7WEE
M87(G(#T^(")996%R(BP*"2=T;7!L7U]C<F5A=&4G(#T^(")#<F5A=&4@=&5M
M<&QA=&4B+`H))W1M<&Q?7V5D:71?7R<@/3X@(D5D:70@=&5M<&QA=&4@)3$B
M+`H))W1M<&Q?7VQO9W)O=&%T:6]N7W=A<FXG(#T^("),;V<@<F]T871I;VX@
M;VX@=&AE(&1O;6%I;B!C<F5A=&5D(&)Y('1H:7,@=&5M<&QA=&4@=VEL;"!B
M92!P97)F;W)M960@;VYL>2!I;B!C87-E(&]F('-U8G-E<75E;G0@<&AY<VEC
M86P@:&]S=&EN9R!A8V-O=6YT(&-R96%T:6]N(&9O<B!I="XB+`H))W1M<&Q?
M7VYA;64G(#T^(")496UP;&%T92!N86UE(BP*"2=T;7!L7U]N86UE7VEN=F%L
M:60G(#T^(")496UP;&%T92!N86UE(&ES(&EN=F%L:60@;W(@96UP='DN(BP*
M"2=T;7!L7U]D;VU?97AI<W0G(#T^(")$;VUA:6X@=&5M<&QA=&4@=VET:"!S
M=6-H(&YA;64@86QR96%D>2!E>&ES=',@:6X@861M:6YI<W1R871O<B=S(&]R
M(&-L:65N="=S('1E;7!L871E<R!P;V]L+B(L"@DG=&UP;%]?=7-E7VYE>'1?
M:7!?861D<B<@/3X@(DYE>'0@=F%C86YT(&EP(&%D9')E<W,@=VEL;"!B92!U
M<V5D(BP*"2=T;V]L<V)A<E]?;&]G;W5T/R<@/3X@(D%R92!Y;W4@<W5R92!Y
M;W4@=VES:"!T;R!L;V<@;W5T/R(L"@DG=')A9F9I8U]?;F]?<&5R:6]D<U]F
M;W5N9"<@/3X@(E5N86)L92!T;R!D:7-P;&%Y('1H92!T<F%F9FEC('-T871I
M<W1I8W,N(%1H:7,@9G5N8W1I;VX@=VEL;"!B92!A=F%I;&%B;&4@;VYL>2!A
M9G1E<B!T:&4@;F5X="!S=&%T:7-T:6-S(&-A;&-U;&%T:6]N+B(L"@DG='1S
M)R`]/B`B2&5L<"!$97-K(BP*"2=T='-?7V-A;G1?8VQO<V5?8VQO<V5D)R`]
M/B`B66]U(&-A;FYO="!C;&]S92!A;B!A;')E861Y(&-L;W-E9"!T:6-K970B
M+`H))W1T<U]?8V%N=%]D96Q?8V%T7W1I8VME=',G(#T^(")5;F%B;&4@=&\@
M9&5L971E('1H92!C871E9V]R>3H@:70@:7,@=7-E9"!B>2!C97)T86EN('1I
M8VME=',@;W(@87-S:6=N960@87,@9&5F875L="!C871E9V]R>2XB+`H))W1T
M<U]?8V%N=%]D96Q?<')I;W)I='E?=&EC:V5T<R<@/3X@(E5N86)L92!T;R!D
M96QE=&4@=&AE('!R:6]R:71Y.B!I="!I<R!U<V5D(&)Y(&-E<G1A:6X@=&EC
M:V5T<R!O<B!A<W-I9VYE9"!A<R!D969A=6QT('!R:6]R:71Y+B(L"@DG='1S
M7U]C86YT7V1E;%]Q=65U95]T:6-K971S)R`]/B`B56YA8FQE('1O(&1E;&5T
M92!T:&4@<75E=64Z(&ET(&ES('5S960@8GD@8V5R=&%I;B!T:6-K971S(&]R
M(&%S<VEG;F5D(&%S(&1E9F%U;'0@<75E=64N(BP*"2=T='-?7V-A;G1?;W!E
M;E]N;W1?8VQO<V5D)R`]/B`B66]U(&-A;FYO="!R96]P96X@82!N;VXM8VQO
M<V5D('1I8VME="(L"@DG='1S7U]C871E9V]R>2<@/3X@(D-A=&5G;W)Y(BP*
M"2=T='-?7V-A=&5G;W)Y7V%L<F5A9'E?97AI<W1S7U\G(#T^("=#871E9V]R
M>2`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?8V%T<R<@/3X@(D-A=&5G
M;W)I97,B+`H))W1T<U]?8V]N9E]C86Y?<&]S="<@/3X@(D%L;&]W(&-U<W1O
M;65R<R!T;R!S=6)M:70@=&EC:V5T<R(L"@DG='1S7U]C;VYF7V1E9E]C871E
M9V]R>2<@/3X@(D1E9F%U;'0@0V%T96=O<GDB+`H))W1T<U]?96YA8FQE9"<@
M/3X@(D5N86)L960B+`H))W1T<U]?9V5N97)A;%]C;VYF:6<G(#T^(")(96QP
M($1E<VL@4V5T=&EN9W,B+`H))W1T<U]?<')I;W)I=&EE<U]L:7-T)R`]/B`B
M4')I;W)I=&EE<R(L"@DG='1S7U]P=6)L:6-?;F%M92<@/3X@(DYO=&EF:6-A
M=&EO;B!396YD97(G<R!.86UE(BP*"2=T='-?7W!U8FQI8U]E;6%I;"<@/3X@
M(DYO=&EF:6-A=&EO;B!396YD97(G<R!2971U<FX@061D<F5S<R(L"@DG='1S
M7U]C;VYF7V1E9E]P<FEO<FET>2<@/3X@(D1E9F%U;'0@4')I;W)I='DB+`H)
M)W1T<U]?8V]N9E]D969?<75E=64G(#T^(")$969A=6QT(%%U975E(BP*"2=T
M='-?7V-O;F9?96YA8FQE9"<@/3X@(D5N86)L960B+`H))W1T<U]?8V]N9FEG
M=7)A=&EO;B<@/3X@(DAE;'`@1&5S:R!3971T:6YG<R(L"@DG='1S7U]E9&ET
M7V-A="<@/3X@(D5D:70@8V%T96=O<GDB+`H))W1T<U]?961I=%]P<FEO<FET
M>2<@/3X@(D5D:70@<')I;W)I='DB+`H))W1T<U]?961I=%]Q=65U92<@/3X@
M(D5D:70@<75E=64B+`H))W1T<U]?97)R7W-E;%]Q<&,G(#T^(")9;W4@<VAO
M=6QD('-E;&5C="!T:&4@9&5F875L="!Q=65U92P@<')I;W)I='D@86YD(&-A
M=&5G;W)Y('1O(&%L;&]W('1I8VME="!S=6)M:7-S:6]N+B(L"@DG='1S7U]G
M;%]C;G1?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?7V=L7V-N=%]N97<G
M(#T^(").97<B+`H))W1T<U]?9VQ?8VYT7V]P96YE9"<@/3X@(D]P96XB+`H)
M)W1T<U]?9VQ?8VYT7W)E;W!E;F5D)R`]/B`B4F5O<&5N960B+`H))W1T<U]?
M9VQ?<V5R=F5R7VYA;64G(#T^(")397)V97(@2&]S=&YA;64B+`H))W1T<U]?
M9VQ?<V5R=F5R<R<@/3X@(E-E<G9E<G,B+`H))W1T<U]?9VQ?='1S7V-A;E]P
M;W-T)R`]/B`B5&EC:V5T(%-U8FUI<W-I;VXB+`H))W1T<U]?9VQ?='1S7V5N
M86)L960G(#T^(")(96QP($1E<VL@:7,@86-T:79A=&5D(BP*"2=T='-?7V=L
M7W5N:VYO=VXG(#T^(")5;FMN;W=N(BP*"2=T='-?7V=L7W5P9&%T960G(#T^
M(")5<&1A=&5D(BP*"2=T='-?7V=L;V)A;%]T=',G(#T^(")';&]B86P@2&5L
M<"!$97-K(BP*"2=T='-?7VQO8U]C;VYF7W1I=&QE)R`]/B`B3&]C86P@2&5L
M<"!$97-K(%-E='1I;F=S(BP*"2=T='-?7VQO8U]I;F9O)R`]/B`B5&]T86P@
M)3$L('1O=&%L(&]P96X@)3(@*"!N97<@)3,L(')E;W!E;F5D("4T*2P@=&]T
M86P@8VQO<V5D("4U('1I8VME=',N(BP*"2=T='-?7VQO8U]T:6-K971S7W1I
M=&QE)R`]/B`B3&]C86P@5&EC:V5T<R(L"@DG='1S7U]M86EL9V%T95]C;VYF
M:6<G(#T^(")(96QP($1E<VL@36%I;"!'871E(%-E='1I;F=S(BP*"2=T='-?
M7VYE=R<@/3X@(DYE=R!4:6-K970B+`H))W1T<U]?<&]P7W-E<G9E<B<@/3X@
M(E!/4#,@4V5R=F5R(BP*"2=T='-?7W!O<%]U<V5R;F%M92<@/3X@(E!/4#,@
M3&]G:6XB+`H))W1T<U]?<')I;W)I=&EE<R<@/3X@(E!R:6]R:71I97,B+`H)
M)W1T<U]?<')I;W)I='DG(#T^(")0<FEO<FET>2(L"@DG='1S7U]P<FEO<FET
M>5]A;')E861Y7V5X:7-T<U]?)R`]/B`B4')I;W)I='D@)3$@86QR96%D>2!E
M>&ES=',N(BP*"2=T='-?7W%U97)Y7W!E<FEO9"<@/3X@(E%U97)Y(&UA:6P@
M;VYC92!I;B(L"@DG='1S7U]Q=65R>5]P97)I;V1?;6EN=71E<R<@/3X@(FUI
M;B(L"@DG='1S7U]Q=65U97,G(#T^(")1=65U97,B+`H))W1T<U]?<75E=65S
M7VQI<W0G(#T^(")1=65U97,@;&ES="(L"@DG='1S7U]Q=65U92<@/3X@(E%U
M975E(BP*"2=T='-?7W%U975E7V%L<F5A9'E?97AI<W1S7U\G(#T^("=1=65U
M92`E,2!A;')E861Y(&5X:7-T<RXG+`H))W1T<U]?<F5M;W9E7V-A=',G(#T^
M(")296UO=F4@8V%T96=O<FEE<R(L"@DG='1S7U]R96UO=F5?<')I;W)I=&5S
M)R`]/B`B4F5M;W9E('!R:6]R:71I97,B+`H))W1T<U]?<F5M;W9E7W%U975E
M<R<@/3X@(E)E;6]V92!Q=65U97,B+`H))W1T<U]?<F5P;W)T97)?='EP95]A
M9&UI;B<@/3X@(D%D;6EN:7-T<F%T;W(B+`H))W1T<U]?<F5P;W)T97)?='EP
M95]C;&EE;G0G(#T^(")#;&EE;G0B+`H))W1T<U]?<F5P;W)T97)?='EP95]D
M;VUA:6XG(#T^(")$;VUA:6XB+`H))W1T<U]?<F5P;W)T97)?='EP95]E;6%I
M;"<@/3X@(D4M;6%I;"(L"@DG='1S7U]R97!O<G1E<E]T>7!E7VUA:6QN86UE
M)R`]/B`B36%I;"!N86UE(BP*"2=T='-?7W-E;&5C=%]C871S7W1O7W)E;6]V
M92<@/3X@(E-E;&5C="!C871E9V]R:65S('1O(&)E(')E;6]V960N(BP*"2=T
M='-?7W-E;&5C=%]E=F5N=%]T>7!E)R`]/B`B4V5L96-T(&5V96YT('1Y<&4@
M9F]R(&-O;6UE;G0@<W5B;6ES<VEO;B(L"@DG='1S7U]S96QE8W1?<')I;W)I
M=&5S7W1O7W)E;6]V92<@/3X@(E-E;&5C="!P<FEO<FET:65S('1O(&)E(')E
M;6]V960N(BP*"2=T='-?7W-E;&5C=%]Q=65U97-?=&]?<F5M;W9E)R`]/B`B
M4V5L96-T('%U975E<R!T;R!B92!R96UO=F5D+B(L"@DG='1S7U]S=&%R=%]T
M:6-K971?<W5B:B<@/3X@(E1I8VME="!S=6)J96-T(&UU<W0@<W1A<G0@=VET
M:"(L"@DG='1S7U]T979?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?7W1E
M=E]C;VUM96YT960G(#T^(")#;VUM96YT960B+`H))W1T<U]?=&5V7V-R96%T
M960G(#T^(")#<F5A=&5D(BP*"2=T='-?7W1E=E]R96]P96YE9"<@/3X@(E)E
M;W!E;F5D(BP*"2=T='-?7W1I8VME="<@/3X@(E1I8VME="(L"@DG='1S7U]T
M:6-K971?8F]D>2<@/3X@(E1I8VME="!";V1Y(BP*"2=T='-?7W1I8VME=%]C
M871E9V]R>2<@/3X@(D-A=&5G;W)Y(BP*"2=T='-?7W1I8VME=%]I9"<@/3X@
M(DED(BP*"2=T='-?7W1I8VME=%]M86EL8VQ?;F%M92<@/3X@(E)E<&]R=&5R
M($YA;64B+`H))W1T<U]?=&EC:V5T7VUO9&EF:65D)R`]/B`B36]D:69I960B
M+`H))W1T<U]?=&EC:V5T7W%U975E)R`]/B`B475E=64B+`H))W1T<U]?=&EC
M:V5T7W)E<&]R=&5R7W1Y<&4G(#T^(")297!O<G1E<B!4>7!E(BP*"2=T='-?
M7W1I8VME=%]S=&%T=7,G(#T^(")4:6-K970@4W1A='5S(BP*"2=T='-?7W1I
M8VME=%]S=6)J96-T)R`]/B`B5&EC:V5T(%-U8FIE8W0B+`H))W1T<U]?=&EC
M:V5T7W1I=&QE:60G(#T^(")4:6-K970@)3$B+`H))W1T<U]?=&EC:V5T<R<@
M/3X@(E1I8VME=',B+`H))W1T<U]?=&EC:V5T<U]L:7-T)R`]/B`B5&EC:V5T
M<R(L"@DG='1S7U]T:6-K971S7W-U;6UA<GDG(#T^(")4:6-K971S(%-U;6UA
M<GDB+`H))W1T<U]?=&YE=E]C;&]S92<@/3X@(D-L;W-E('1I8VME="(L"@DG
M='1S7U]T;F5V7V-O;6UE;G0G(#T^(")#;VUM96YT('1I8VME="(L"@DG='1S
M7U]T;F5V7W)E;W!E;B<@/3X@(E)E;W!E;B(L"@DG='1S7U]T<U]A;&PG(#T^
M(")!;&PB+`H))W1T<U]?='-?86QL;W!E;F5D)R`]/B`B06QL(&]P96XB+`H)
M)W1T<U]?='-?8VQO<V5D)R`]/B`B0VQO<V5D(BP*"2=T='-?7W1S7VYE=R<@
M/3X@(DYE=R(L"@DG='1S7U]T<U]R96]P96YE9"<@/3X@(E)E;W!E;F5D(BP*
M"2=T='-?7W1T<R<@/3X@(DAE;'`@1&5S:R(L"@DG='1S7V-A;G1?<&]S="<@
M/3X@(E1I8VME="!S=6)M:7-S:6]N(&ES(&1I<V%B;&5D(BP*"2=T='-?979?
M7VAI<W1O<GDG(#T^(")4:6-K970@2&ES=&]R>2(L"@DG='1S7VYO=%]A8W1I
M=F%T960G(#T^(")(96QP($1E<VL@:7,@;F]T(&%C=&EV871E9"XB+`H))W1T
M<U]T:6-K971?7V1O)R`]/B`B5&EC:V5T($5V96YT(BP*"2=T='-?=&EC:V5T
M7U]N97=?8V]M;65N="<@/3X@(DYE=R!#;VUM96YT(BP*"2=T='-?=&EC:V5T
M7U]P=6)L:6,G(#T^(")6:7-I8FQE('1O(&-L:65N="(L"@DG='1S7W1I8VME
M=%]?<')I=F%T92<@/3X@(DEN=FES:6)L92!T;R!C;&EE;G0B+`H))W1T<U]T
M:6-K971?9&]?<V5C=&EO;B<@/3X@(DYE=R!%=F5N="(L"@DG=FA?8F%S961?
M7VYO7V9R965?:7!?9F]R7W9H)R`]/B`B5&AE<F4@87)E(&YO('9A8V%N="!)
M4"!A9&1R97-S97,@9F]R('1H92!)4"UB87-E9"!V:7)T=6%L(&AO<W1I;F<N
M(%!L96%S92P@861D(&%N($E0(&%D9')E<W,N(BP*"@DG=FES:6)I;&ET>5]?
M861M:6YO;FQY)R`]/B`G061M:6X@3VYL>2<L"@DG=FES:6)I;&ET>5]?8G5T
M=&]N7W-E=',G(#T^("="=71T;VX@<V5T<R<L"@DG=FES:6)I;&ET>5]?8V]N
M=')O;"<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!T:&ES(&-O;G1R;VPN)RP*
M"2=V:7-I8FEL:71Y7U]C=7)R96YT7V-U<W1O;6EZ871I;VYS)R`]/B`G0W5R
M<F5N="!C=7-T;VUI>F%T:6]N<R<L"@DG=FES:6)I;&ET>5]?8W5R<F5N=%]C
M=7-T;VUI>F%T:6]N<U]B96QO=R<@/3X@)U1H92!F;VQL;W=I;F<@8G5T=&]N
M<R!H879E(&-U<W1O;2!S971T:6YG<RX@0VQI8VL@=&AE;2!T;R!C:&%N9V4@
M=&AE<V4@<V5T=&EN9W,N)RP*"2=V:7-I8FEL:71Y7U]C=7)R96YT7V-U<W1O
M;6EZ871I;VYS7V9O<FUS)R`]/B`G4V]M92!C;VYT<F]L<R!O;B!F;W)M<R!H
M879E(&-U<W1O;2!S971T:6YG<RXG+`H))W9I<VEB:6QI='E?7V-U<W1O;6EZ
M871I;VY?9F]O=&YO=&4G(#T^("=#;&EC:R!/2R!T;R!F:6YI<V@@8W5S=&]M
M:7IA=&EO;B!O9B!T:&ES('-C<F5E;BXG+`H))W9I<VEB:6QI='E?7V1E9F%U
M;'0G(#T^("=$969A=6QT)RP*"2=V:7-I8FEL:71Y7U]E>'!O<G1?;F]T92<@
M/3X@(E1H92!C=7-T;VUI>F%T:6]N('-E='1I;F=S('EO=2!M861E(&%R92!A
M8F]U="!T;R!B92!E>'!O<G1E9"X@02!S:&5L;"!S8W)I<'0@=VEL;"!N;W<@
M8F4@9&]W;FQO861E9"!T;R!Y;W5R(&-O;7!U=&5R+B!4;R!A<'!L>2!T:&5S
M92!S971T:6YG<R!T;R!A;F]T:&5R(%!L97-K('-E<G9E<BP@;W9E<G=R:71I
M;F<@86YY(&5X:7-T:6YG(&EN=&5R9F%C92!M86YA9V5M96YT('-E='1I;F=S
M+"!P;&5A<V4@=7!L;V%D(&%N9"!E>&5C=71E('1H92!S8W)I<'0@=&AE<F4N
M7&Y<;E!L96%S92!N;W1E('1H870L(&EF('EO=2!H879E(&UA9&4@86YY(&-H
M86YG97,@;VX@=&AI<R!S8W)E96X@8G5T(&AA=F5N)W0@>65T(&-L:6-K960@
M3TLL('1H92!D871A(&5X<&]R=&5D('=I;&P@;F]T(&EN8VQU9&4@>6]U<B!L
M871E<W0@8VAA;F=E<RXB+`H))W9I<VEB:6QI='E?7V9O<FU?8V]N=')O;'-?
M<F5S970G(#T^("=!;&P@8V]N=')O;',@;VX@9F]R;7,@=VEL;"!B92!R97-E
M="!T;R!D969A=6QT('-E='1I;F=S)RP*"2=V:7-I8FEL:71Y7U]H:61E)R`]
M/B`G2&ED92<L"@DG=FES:6)I;&ET>5]?:&ED95]D:7-A8FQE9"<@/3X@)TAI
M9&4@86QL(&=R87EE9"!O=70@8G5T=&]N<R!B>2!D969A=6QT)RP*"2=V:7-I
M8FEL:71Y7U]H:61E7W5N879A:6QA8FQE7VQI;6ET<R<@/3X@)TAI9&4@9G)O
M;2!U<V5R<R!T:&4@;&EM:70@;6%N86=E;65N=`IC;VYT<F]L<R!T:&5Y(&%R
M92!N;W0@86QL;W=E9"!T;R!O<&5R871E)RP*"2=V:7-I8FEL:71Y7U]H:61E
M7W5N879A:6QA8FQE7W!E<FUI<W-I;VYS)R`]/B`G2&ED92!F<F]M('5S97)S
M('1H92!P97)M:7-S:6]N"FUA;F%G96UE;G0@8V]N=')O;',@=&AE>2!A<F4@
M;F]T(&%L;&]W960@=&\@;W!E<F%T92<L"@DG=FES:6)I;&ET>5]?;F]?8W5R
M<F5N=%]C=7-T;VUI>F%T:6]N<R<@/3X@)T%L;"!B=71T;VYS(&]N(%!L97-K
M('-C<F5E;G,@:&%V92!D969A=6QT('-E='1I;F=S+B<L"@DG=FES:6)I;&ET
M>5]?<F5S971?86QL)R`]/B`G4F5S970@86QL('1O(&1E9F%U;'0G+`H))W9I
M<VEB:6QI='E?7W)E<V5T7W-C<F5E;B<@/3X@)U)E<W1O<F4@;W)I9VEN86P@
M;&%Y;W5T(&]F('1H:7,@<V-R965N)RP*"2=V:7-I8FEL:71Y7U]R;V]T7V]V
M97)R:61E7W!A<G-E7V5R<F]R)R`]/B`G5&AE<F4@:7,@82!S>6YT87@@97)R
M;W(@:6X@9FEL92`E,2!I;B!L:6YE("4R(2<L"@DG=FES:6)I;&ET>5]?<V-R
M965N7W1I=&QE)R`]/B`G26YT97)F86-E(&UA;F%G96UE;G0G+`H))W9I<VEB
M:6QI='E?7W-E=%]C97)T7W!U8VAA<VEN9R<@/3X@)TAI9&4@8G5T=&]N<R!F
M;W(@8V5R=&EF:6-A=&4@<'5R8VAA<VEN9R<L"@DG=FES:6)I;&ET>5]?<V5T
M7V1O;6%I;E]R96=I<W1R871I;VXG(#T^("=(:61E(&)U='1O;G,@9F]R(&1O
M;6%I;B!R96=I<W1R871I;VXG+`H))W9I<VEB:6QI='E?7W-E=%]E>'1R87,G
M(#T^("=(:61E(&)U='1O;G,@9F]R(&5X=')A('-E<G9I8V5S)RP*"2=V:7-I
M8FEL:71Y7U]S971?;6%I;%]B;W5N8V4G(#T^("=(:61E(&-O;G1R;VQS(&9O
M<B!B;W5N8V4@;65S<V%G97,@9F]R(&YO;BUE>&ES=&5N="!M86EL(&%D9')E
M<W-E<R<L"@DG=FES:6)I;&ET>5]?<VAO=R<@/3X@)U-H;W<G+`H))W9I<VEB
M:6QI='E?7W-H;W=?=&]O;&)A<B<@/3X@)U-H;W<@26YT97)F86-E(&UA;F%G
M96UE;G0@=&]O;&)A<B<L"@DG=FES:6)I;&ET>5]?<W1A;F1B>5]F;V]T;F]T
M92<@/3X@)T-L:6-K('1O(&-U<W1O;6EZ92!C;VYT<F]L<R!O;B!T:&ES('-C
M<F5E;BXG+`H))W9I<VEB:6QI='E?7W-T86YD8GE?9F]O=&YO=&5?;F]C;VYT
M<F]L<R<@/3X@)U1H97)E(&%R92!N;R!C=7-T;VUI>F%B;&4@8V]N=')O;',@
M;VX@=&AI<R!S8W)E96XN)RP*"2=I;G1E<F9A8V5?<')E9F5R96YC97,G(#T^
M("=);G1E<F9A8V4@<')E9F5R96YC97,G+`H))VET;7!L7U]L:7-T7W1I=&QE
M)R`]/B`G26YT97)F86-E('1E;7!L871E<R!M86YA9V5M96YT)RP*"2=P8E]?
M:6YT97)F86-E7W1E;7!L871E<R<@/3X@)TEN=&5R9F%C92!M86YA9V5M96YT
M)RP*"2=B=%]I;G1E<F9A8V5?=&5M<&QA=&5?861D)R`]/B`G061D($EN=&5R
M9F%C92!496UP;&%T92<L"@DG:71M<&Q?7VQI<W1?;&5G96YD)R`]/B`G26YT
M97)F86-E('1E;7!L871E<R<L"@DG:71M<&Q?7VQI<W1?;F%M92<@/3X@)TEN
M=&5R9F%C92!T96UP;&%T92!N86UE)RP*"2=I=&UP;%]?;&ES=%]U<V%G92<@
M/3X@)U5S86=E)RP*"2=I=&UP;%]?;&ES=%]H96%D97(G(#T^("=);G1E<F9A
M8V4@=&5M<&QA=&5S)RP*"2=I=&UP;%]?<V5L96-T7W1E;7!L871E<U]T;U]R
M96UO=F4G(#T^("=396QE8W0@=&AE(&EN=&5R9F%C92!T96UP;&%T97,@=&\@
M8F4@<F5M;W9E9"XG+`H))VET;7!L7U]S96QE8W1?=&5M<&QA=&5?=&]?;6%K
M95]D969A=6QT)R`]/B`G4V5L96-T(&%N(&EN=&5R9F%C92!T96UP;&%T92!T
M;R!M86ME(&ET(&1E9F%U;'0N)RP*"2=I=&UP;%]?;F%M92<@/3X@)TEN=&5R
M9F%C92!T96UP;&%T92!N86UE)RP*"2=B=%]S:&]W7VET;7!L7W1O;VQB87(G
M(#T^("=3:&]W(%1O;VQB87(G+`H))VET;7!L7U]U<&QO861?=&ET;&4G(#T^
M("=5<&QO860@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP;%]?=7!L;V%D
M7VQE9V5N9"<@/3X@)U5P;&]A9"!I;G1E<F9A8V4@=&5M<&QA=&4G+`H))VET
M;7!L7U]F:6QE7VYA;64G(#T^("=0871H('1O(&EN=&5R9F%C92!T96UP;&%T
M92!F:6QE)RP*"2=I=&UP;%]?:6YV86QI9%]V86QU97,G(#T^("=);G9A;&ED
M('9A;'5E<R<L"@DG:71M<&Q?7V%L<F5A9'E?97AI<W0G(#T^("=);G1E<F9A
M8V4@=&5M<&QA=&4@=VET:"!N86UE("(E,2(@86QR96%D>2!E>&ES=',N)RP*
M"2=I=&UP;%]?=7!L;V%D7VEN=F%L:61?='EP92<@/3X@)TYO="!S=7!P;W)T
M960@9FEL92!T>7!E+B<L"@DG:71M<&Q?7WAM;%]L;V%D7V9A:6QE9"<@/3X@
M)UA-3"!F:6QE(&ES(&EN('1H92!W<F]N9R!F;W)M870N)RP*"2=I=&UP;%]?
M961I=%]T:71L92<@/3X@)T5D:70@:6YT97)F86-E('1E;7!L871E("4Q)RP*
M"2=I=&UP;%]?861D7W1I=&QE)R`]/B`G061D(&YE=R!I;G1E<F9A8V4@=&5M
M<&QA=&4G+`H))VET;7!L7U]C;%]L:7-T7V9O<E\G(#T^("=#;&EE;G1S('5S
M:6YG("4Q(&EN=&5R9F%C92!T96UP;&%T92<L"@DG:71M<&Q?7V-L7VQI<W1?
M861D)R`]/B`G4V5L96-T('1H92!C;&EE;G1S('=H;R!S:&]U;&0@=7-E('1H
M:7,@:6YT97)F86-E('1E;7!L871E)RP*"2=I=&UP;%]?<F5M;W9E7W1I=&QE
M)R`]/B`G5&AE(&9O;&QO=VEN9R!I;G1E<F9A8V4@=&5M<&QA=&5S('=I;&P@
M8F4@<F5M;W9E9#HG+`H))VET;7!L7U]R96UO=F5?8VQI96YT<R<@/3X@)U1H
M92!F;VQL;W=I;F<@8VQI96YT<R!W:6QL(&YO(&QO;F=E<B!U<V4@=&AI<R!I
M;G1E<F9A8V4@8W5S=&]M:7IA=&EO;B!T96UP;&%T93HG+`H))W!B7U]I;G1E
M<F9A8V5?8VQI96YT<R<@/3X@)T-L:65N=',@=7-I;F<@)3$G+`H*"2=W96)A
M;&EZ97)?<')E9F5R96YC97-?7W1I=&QE)R`]/B`G5V5B(%-T871I<W1I8W,@
M4')E9F5R96YC97,G+`H))W=E8F%L:7IE<E]P<F5F97)E;F-E<U]?=&%B7VAI
M9&1E;E]R969E<G)E<G,G(#T^("=(:61D96X@4F5F97)R97)S)RP*"2=W96)A
M;&EZ97)?<')E9F5R96YC97-?7W1A8E]G<F]U<%]R969E<G)E<G,G(#T^("='
M<F]U<&5D(%)E9F5R<F5R<R<L"@H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R
M97)?7V5D:71?=&ET;&4G(#T^("=(:61D96X@16YT<GD@4')O<&5R=&EE<R<L
M"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?961I=%]L96=E;F0G(#T^
M("=(:61D96X@16YT<FEE<R<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E
M<E]?<F5F97)R97)?='EP92<@/3X@)T5N=')Y('1Y<&4G+`H))W=E8F%L:7IE
M<E]H:61D96Y?<F5F97)R97)?7W)E9F5R<F5R)R`]/B`G4F5F97)R97(G+`H)
M)W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7VQI<W1?:&5A9&5R)R`]/B`G
M2&ED9&5N(%)E9F5R<F5R<R<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E
M<E]?;&ES=%]L96=E;F0G(#T^("=(:61D96X@4F5F97)R97)S)RP*"2=W96)A
M;&EZ97)?:&ED9&5N7W)E9F5R<F5R7U]R969E<G)E<E]D:7)E8W1?<F5Q=65S
M="<@/3X@)T1I<F5C="!R97%U97-T)RP*"2=W96)A;&EZ97)?:&ED9&5N7W)E
M9F5R<F5R7U]R969E<G)E<E]C=7-T;VU?<F5F97)R97(G(#T^("=2969E<G)E
M<B<L"@DG=V5B86QI>F5R7VAI9&1E;E]R969E<G)E<E]?<F5M;W9E7V5M<'1Y
M7W-E;&5C=&EO;B<@/3X@)TYO(&5N=')I97,@<V5L96-T960G+`H))W=E8F%L
M:7IE<E]H:61D96Y?<F5F97)R97)?7W)E;6]V95]T:71L92<@/3X@)U1H92!F
M;VQL;W=I;F<@<F5F97)R97)S('=I;&P@;F\@;&]N9V5R(&)E(&AI9&1E;CHG
M+`H))W=E8F%L:7IE<E]H:61D96Y?<F5F97)R97)?7V%L<F5A9'E?97AI<W0G
M(#T^("=3=6-H(&5N=')Y(&%L<F5A9'D@97AI<W1S+B<L"@H))W=E8F%L:7IE
M<E]G<F]U<%]R969E<G)E<E]?;&ES=%]H96%D97(G(#T^("='<F]U<"!2969E
M<G)E<G,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?;&ES=%]L96=E
M;F0G(#T^("='<F]U<"!2969E<G)E<G,G+`H))W=E8F%L:7IE<E]G<F]U<%]R
M969E<G)E<E]?961I=%]T:71L92<@/3X@)U)E9F5R<F5R($=R;W5P(%!R;W!E
M<G1I97,G+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?961I=%]L96=E
M;F0G(#T^("=2969E<G)E<B!'<F]U<"!0<F]P97)T:65S)RP*"2=W96)A;&EZ
M97)?9W)O=7!?<F5F97)R97)?7V=R;W5P)R`]/B`G1W)O=7`G+`H))W=E8F%L
M:7IE<E]G<F]U<%]R969E<G)E<E]?<F5F97)R97(G(#T^("=2969E<G)E<B<L
M"@DG=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]A;')E861Y7V5X:7-T)R`]
M/B`G02!G<F]U<"!R969E<G)E<B!W:71H('-U8V@@;F%M92!A;')E861Y(&5X
M:7-T<RXG+`H))W=E8F%L:7IE<E]G<F]U<%]R969E<G)E<E]?<F5M;W9E7V5M
M<'1Y7W-E;&5C=&EO;B<@/3X@)TYO(')E9F5R<F5R<R!S96QE8W1E9"<L"@DG
M=V5B86QI>F5R7V=R;W5P7W)E9F5R<F5R7U]R96UO=F5?=&ET;&4G(#T^("=4
M:&4@9F]L;&]W:6YG(')E9F5R<F5R('-I=&5S('=I;&P@8F4@=6YG<F]U<&5D
M.B<L"@H))W=E8E]A<'!S7U]D;VUA:6Y?;&EM:71?97AC965D960G(#T^(")5
M;F%B;&4@=&\@861D(&YE=R!*879A(&%P<&QI8V%T:6]N.B!D;VUA:6X@;&EM
M:70@:7,@97AC965D960B+`H))W=E8E]A<'!S7U]H879E7VYO7W!E<FUI<W-I
M;VYS)R`]/B`B56YA8FQE('1O(&UA;F%G92!*879A(&%P<&QI8V%T:6]N<SH@
M8VQI96YT(&]R(&1O;6%I;B!L979E;"!U<V5R(&1O97,@;F]T(&AA=F4@=&AE
M(&%P<')O<')I871E('!E<FUI<W-I;VX@;W(@9&]M86EN(&ES(&YO="!A8W1I
M=F4N(BP*"2=W96)?87!P<U]?;VYL>5]W87)?9FEL92<@/3X@(D]N;'D@+G=A
M<B!F:6QE<R!C86X@8F4@:6YS=&%L;&5D(&%S(&$@2F%V82!A<'!L:6-A=&EO
M;BXB+`H))W=E8E]A<'!S7U]R96UO=F5?=V5B87!P<U]O;E]D;VTG(#T^(")4
M:&4@9F]L;&]W:6YG($IA=F$@87!P;&EC871I;VYS(&9O<B!D;VUA:6X@)3(@
M;W=N960@8GD@8VQI96YT("4Q('=I;&P@8F4@<F5M;W9E9#HB+`H))W=E8E]A
M<'!S7U]S96QE8W1?=V%R7V9I;&4G(#T^(")396QE8W0@2F%V82!A<'!L:6-A
M=&EO;B!F:6QE+B(L"@DG=V5B7V%P<'-?7W-E;&5C=%]W96)A<'!S7W1O7W)E
M;6]V92<@/3X@(E-E;&5C="!T:&4@2F%V82!A<'!L:6-A=&EO;G,@=&\@8F4@
M<F5M;W9E9"XB+`H))W=E8E]A<'!S7U]T:71L92<@/3X@(DIA=F$@87!P;&EC
M871I;VYS(&9O<B!D;VUA:6X@)3$B+`H))W=E8E]A<'!S7U]A9&1?=&ET;&4G
M(#T^(")!9&1I;F<@3F5W($IA=F$@07!P;&EC871I;VXB+`H))W=E8E]A<'!S
M7U]T;VUC871?;6%Y7V)E7VYO=%]W;W)K)R`]/B`B4&]S<VEB;&4@<F5A<V]N
M("T@5&]M8V%T('-E<G9I8V4@:7,@;F]T(&-U<G)E;G1L>2!R=6YN:6YG(&]N
M('1H92!S97)V97(N(BP*"2=W96)?87!P<U]?=&]M8V%T7W-T871U<R<@/3X@
M(E1O;6-A="!S=&%T=7,B+`H))W=E8E]A<'!S7U]U;F%B;&5?=&]?<W1A<G1?
M=V5B87!P)R`]/B`B56YA8FQE('1O('-T87)T('5P($IA=F$@87!P;&EC871I
M;VXZ("4Q(BP*"2=W96)?87!P<U]?=6YA8FQE7W1O7V1O=VY?=V5B87!P)R`]
M/B`B56YA8FQE('1O('-H=70@9&]W;B!*879A(&%P<&QI8V%T:6]N.B`E,2(L
M"@DG=V5B7V%P<'-?7W5P;&]A9%]W87)?9FEL92<@/3X@(E5P;&]A9"!705(@
M9FEL92(L"@DG=V5B7V%P<'-?7W=A<E]F:6QE)R`]/B`B5T%2(&9I;&4B+`H)
M)W=E8E]A<'!S7U]W96)?87!P7V-O=6QD;G1?;F%M961?;6%N86=E<B<@/3X@
M(D%N(&%P<&QI8V%T:6]N(&-A;FYO="!B92!N86UE9"!A<R!M86YA9V5R(BP*
M"2=W96)?87!P<U]?=V5B7V%P<%]F:6QE;F%M95]I;G9A;&ED)R`]/B`B07!P
M;&EC871I;VX@9FEL96YA;64@:7,@:6YV86QI9"X@57-E(&]N;'D@86QP:&%N
M=6UE<FEC(&-H87)A8W1E<G,L(&1O="!A;F0@:'EP:&5N('-Y;6)O;',N(BP*
M"2=W96)?87!P<U]?=V5B87!P7V5X:7-T<R<@/3X@(D$@2F%V82!A<'!L:6-A
M=&EO;B!W:71H('-U8V@@;F%M92!A;')E861Y(&5X:7-T<RXB+`H*"2=W=5]?
M861D:71I;VYA;%]F96%T=7)E<R<@/3X@(D%D9&ET:6]N86P@9F5A='5R97,B
M+`H))W=U7U]A=%]D;VUA:6YS7W1E>'0G(#T^(")%;F%B;&4@=V5B=7-E<D`E
M,2!A8V-E<W,@9F]R;6%T(BP*"2=W=5]?96YT97)?=V5B7W5S97)?;F%M92<@
M/3X@(D5N=&5R(&YE=R!W96(@=7-E<B!N86UE+B(L"@DG=W5?7VYE=U]W=2<@
M/3X@(D%D9"!N97<@=V5B('5S97(@;V8@9&]M86EN(#QB/B4Q/"]B/B(L"@DG
M=W5?7W)E;6]V95]W=5]O;E]D;VTG(#T^(")4:&4@9F]L;&]W:6YG('=E8B!U
M<V5R<R!O9B!D;VUA:6X@)3$@=VEL;"!B92!R96UO=F5D.B(L"@DG=W5?7W)E
M;6]V95]W=5]O;E]D;VU?;V9?8VPG(#T^(")4:&4@9F]L;&]W:6YG('=E8B!U
M<V5R<R!O9B!D;VUA:6X@)3(@;W=N960@8GD@8VQI96YT("4Q('=I;&P@8F4@
M<F5M;W9E9#HB+`H))W=U7U]S96QE8W1?=W5?9F]R7W)E;6]V92<@/3X@(E-E
M;&5C="!T:&4@=V5B('5S97)S('1O(&)E(')E;6]V960N(BP*"2=W=5]?=6YA
M8FQE7V-R96%T92<@/3X@(E5N86)L92!T;R!C<F5A=&4@=V5B('5S97(Z("4Q
M(BP*"2=W=5]?=6YA8FQE7W)E;6]V95]W=2<@/3X@(E5N86)L92!T;R!R96UO
M=F4@=V5B('5S97)S.B`E,2(L"@DG=W5?7W=E8E]U<V5R<U]D;VUA:6XG(#T^
M(")796(@=7-E<G,@;V8@9&]M86EN("4Q(BP*"2=W=5]?=W5?:61?=6YD969I
M;F5D)R`]/B`B5V5B('5S97(@:60@:7,@=6YD969I;F5D+B(L"@DG=W5?7W=U
M7VYA;64G(#T^(")796(@=7-E<B!N86UE(BP*"2=W=5]E9&ET7U]D:7-K7W%U
M;W1A)R`]/B`B1&ES:R!Q=6]T82(L"@DG=W5?961I=%]?:6YV86QI9%]P87-S
M)R`]/B`B4&%S<W=O<F0@:7,@:6YV86QI9"XB+`H))W=U7V5D:71?7VEN=F%L
M:61?<75O=&$G(#T^(")4:&4@<W!E8VEF:65D(&1I<VL@<W!A8V4@<75O=&$@
M=F%L=64@:7,@:6YV86QI9"X@4&QE87-E+"!E;G1E<B!A('!O<VET:79E(&EN
M=&5G97(N(BP*"2=W=5]E9&ET7U]N;W1?8W)E871E7W!A<W,G(#T^(")4:&ES
M(&%C=&EO;B!W:6QL(&YO="!C<F5A=&4@82!P87-S=V]R9"!F;W(@=&AE(&YE
M=R!W96(@=7-E<BY<;E=I=&AO=70@<&%S<W=O<F0@=&AE('5S97(@=VEL;"!N
M;W0@8F4@86)L92!T;R!L;V<@:6XN(BP*"2=W=5]E9&ET7U]P87-S=V1?9F]R
M7W=U)R`]/B`B4')O<&5R=&EE<R!O9B!W96(@=7-E<B`@)3$B+`H))W=U7V5D
M:71?7W5N86)L95]U<&1A=&4G(#T^(")5;F%B;&4@=&\@=7!D871E('1H92!W
M96(@=7-E<B!P<F]P97)T>3H@)3$B+`H*"2=D87-H8F]A<F1?7V)O;VMM87)K
M7V)U='1O;E]T:71L95]F879O<FET95]E9&ET)PD)/3X@)T5D:70@1F%V;W)I
M=&4G+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7W1I=&QE7V9A=F]R
M:71E7V%D9"<)"0D]/B`G061D('1O(&9A=F]R:71E<R<L"@DG9&%S:&)O87)D
M7U]B;V]K;6%R:U]B=71T;VY?=&ET;&5?<VAO<G1C=71?961I="<)"3T^("=%
M9&ET(%-H;W)T8W5T)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K7V)U='1O;E]T
M:71L95]S:&]R=&-U=%]A9&0G"0D)/3X@)T-R96%T92!S:&]R=&-U="<L"@H)
M)V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R:7!T:6]N7V9A=F]R
M:71E7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@<VAO<G1C=70@=&\@
M(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R:7!T
M:6]N7V9A=F]R:71E7V%D9"<)/3X@)T%D9"`B)3$B('1O(&9A=F]R:71E<RXG
M+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R:7!T:6]N7W-H
M;W)T8W5T7V5D:70G"3T^("=%9&ET('!R;W!E<G1I97,@;V8@<VAO<G1C=70@
M=&\@(B4Q(BXG+`H))V1A<VAB;V%R9%]?8F]O:VUA<FM?8G5T=&]N7V1E<V-R
M:7!T:6]N7W-H;W)T8W5T7V%D9"<)/3X@)T-R96%T92!S:&]R=&-U="!T;R`B
M)3$B+B<L"@H))V1A<VAB;V%R9%]?8F]O:VUA<FM?=&ET;&5?9F%V;W)I=&5?
M961I="<)/3X@)T5D:71I;F<@4')O<&5R=&EE<R!O9B!3:&]R=&-U="!T;R`B
M)3$B)RP*"2=D87-H8F]A<F1?7V)O;VMM87)K7W1I=&QE7V9A=F]R:71E7V%D
M9"<)/3X@)T%D9&EN9R`B)3$B('1O($9A=F]R:71E<R<L"@DG9&%S:&)O87)D
M7U]B;V]K;6%R:U]T:71L95]S:&]R=&-U=%]E9&ET)PD]/B`G161I=&EN9R!0
M<F]P97)T:65S(&]F(%-H;W)T8W5T('1O("(E,2(G+`H))V1A<VAB;V%R9%]?
M8F]O:VUA<FM?=&ET;&5?<VAO<G1C=71?861D)PD]/B`G0W)E871I;F<@<VAO
M<G1C=70@=&\@(B4Q(B<L"@H))V1A<VAB;V%R9%]?<V5C=&EO;E]S:&]W7W1I
M=&QE)PD)"0D]/B`G4F5S=&]R92<L"@DG9&%S:&)O87)D7U]S96-T:6]N7VAI
M9&5?=&ET;&4G"0D)"3T^("=-:6YI;6EZ92<L"@DG9&%S:&)O87)D7U]S:&]R
M=&-U=%]P<F]P97)T:65S7W1I=&QE)PD)/3X@)U-H;W)T8W5T(%!R;W!E<G1I
M97,G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&4G"0D)"0D]/B`G5&ET
M;&4G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?=&ET;&5?9&5F875L="<)"0D]
M/B`G57-E(&1E9F%U;'0G+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?9&5S8W)I
M<'1I;VXG"0D)/3X@)T1E<V-R:7!T:6]N)RP*"2=D87-H8F]A<F1?7W-H;W)T
M8W5T7V1E<V-R:7!T:6]N7V1E9F%U;'0G"3T^("=5<V4@9&5F875L="<L"@DG
M9&%S:&)O87)D7U]S:&]R=&-U=%]T:71L95]I;G9A;&ED7W9A;'5E)PD]/B`G
M5&AE('1I=&QE('-H;W5L9"!C;VYT86EN(&9R;VT@,2!T;R`R-34@8VAA<F%C
M=&5R<RXG+`H))V1A<VAB;V%R9%]?<VAO<G1C=71?9&5S8W)I<'1I;VY?:6YV
M86QI9%]V86QU92<)/3X@)U1H92!D97-C<FEP=&EO;B!S:&]U;&0@8V]N=&%I
M;B!F<F]M(#$@=&\@,C4U(&-H87)A8W1E<G,N)RP*"@DG9&%S:&)O87)D7U]P
M<F5S971S7V5X<&]R=%]F86EL960G"3T^("=%<G)O<B!O8V-U<G)E9"!D=7)I
M;F<@97AP;W)T:6YG('-E;&5C=&5D($1E<VMT;W`@<')E<V5T<SH@)3$G+`H)
M)V1A<VAB;V%R9%]?<')E<V5T7V5R<F]R)PD)/3X@)T5R<F]R(&]C8W5R<F5D
M(&EN($1E<VMT;W`@<')E<V5T("(E,2(G+`H))V1A<VAB;V%R9%]?<')E<V5T
M7V5R<F]R7U\G"0D]/B`G17)R;W(@;V-C=7)R960@:6X@1&5S:W1O<"!P<F5S
M970@(B4Q(CH@)3(G+`H*"2=D87-H8F]A<F1?7W!R97-E=%]U<&QO861?9F%I
M;&5D)PD]/B`G17)R;W(@;V-C=7)R960@9'5R:6YG(&EM<&]R=&EN9R!$97-K
M=&]P('!R97-E=',@9G)O;2!F:6QE.B`E,2<L"@DG9&%S:&)O87)D7U]P<F5S
M971?<F5P;&%C95]N86UE7V-O;F9L:6-T)PD]/B`G4')E<V5T<R!W:71H('1H
M92!N86UE<R!C;VYT86EN960@:6X@=&AE(&9I;&4@86QR96%D>2!E>&ES="!I
M;B!0;&5S:RX@5&\@<F5P;&%C92!E>&ES=&EN9R!P<F5S971S('=I=&@@=&AE
M('5P;&]A9&5D(&]N97,L('-E;&5C="!T:&4@;W9E<G=R:71I;F<@8V]N9FER
M;6%T:6]N(&-H96-K8F]X+B<L"@DG9&%S:&)O87)D7U]P<F5S971?=7!L;V%D
M7W)E<&QA8V5?8V]N9FER;6%T:6]N)R`]/B`G3W9E<G=R:71E('!R97-E=',@
M=VET:"!T:&4@<V%M92!N86UE(&%N9"!T>7!E+B<L"@H))V1A<VAB;V%R9%]?
M<')E<V5T7W5P;&]A9%]T:71L92<)/3X@)U5P;&]A9&EN9R!$97-K=&]P(%!R
M97-E=',G+`H))V1A<VAB;V%R9%]?<')E<V5T7W5P;&]A9%]L96=E;F0G"3T^
M("=5<&QO860@1&5S:W1O<"!P<F5S971S)RP*"2=D87-H8F]A<F1?7W!R97-E
M=%]U<&QO861?9FEL96YA;64G"3T^("=$97-K=&]P('!R97-E=',@9FEL92!L
M;V-A=&EO;B<L"@H))V1A<VAB;V%R9%]?<')E<V5T7VYA;65?97AI<W1S)PD)
M/3X@)T1E<VMT;W`@4')E<V5T("!W:71H(&YA;64@)3$@86QR96%D>2!E>&ES
M=',N)RP*"2=?7V1A<VAB;V%R9%]P<F5S970G"0D)"3T^("=$97-K=&]P('!R
M97-E="<L"@DG9&%S:&)O87)D7U]P<F5S971S7W!R:79A=&4G"0D]/B`G0W5S
M=&]M:7IE9"!$97-K=&]P)RP*"@DG9&%S:&)O87)D7U]P<F5S971S7VQI<W1?
M;&5G96YD)PD]/B`G1&5S:W1O<"!P<F5S971S)RP*"2=D87-H8F]A<F1?7W!R
M97-E='-?;&ES=%]I=&5M)PD)/3X@)T1E<VMT;W`@<')E<V5T<R<L"@DG9&%S
M:&)O87)D7U]P<F5S971S7VQI<W1?8V]P>2<)"3T^("=#;W!Y($1E<VMT;W`@
M<')E<V5T)RP*"2=D87-H8F]A<F1?7W!R97-E='-?='EP92<)"3T^("=4)RP*
M"2=D87-H8F]A<F1?7W!R97-E=%]T>7!E)PD)/3X@)U1Y<&4G+`H))V1A<VAB
M;V%R9%]?<')E<V5T7W1Y<&5?861M:6XG"0D]/B`G061M:6YI<W1R871O<EPG
M<R!D97-K=&]P('!R97-E="<L"@DG9&%S:&)O87)D7U]P<F5S971?='EP95]C
M;&EE;G0G"0D]/B`G0VQI96YT7"=S(&1E<VMT;W`@<')E<V5T)RP*"2=D87-H
M8F]A<F1?7W!R97-E=%]T>7!E7V1O;6%I;B<)"3T^("=$;VUA:6X@;W=N97)<
M)W,@9&5S:W1O<"!P<F5S970G+`H))V1A<VAB;V%R9%]?<')E<V5T<U]N86UE
M)PD)/3X@)T1E<VMT;W`@<')E<V5T(&YA;64G+`H))V1A<VAB;V%R9%]?<')E
M<V5T7VYA;64G("`)"3T^("=.86UE)RP*"2=D87-H8F]A<F1?7W!R97-E=%]D
M969A=6QT)PD)/3X@)T1E9F%U;'0G+`H))V1A<VAB;V%R9%]?<')E<V5T7V1I
M<V%B;&5D7W1A<VMS)PD]/B`G079A:6QA8FQE('1A<VMS)RP*"2=D87-H8F]A
M<F1?7W!R97-E=%]E;F%B;&5D7W1A<VMS)PD]/B`G4V5L96-T960@=&%S:W,G
M+`H*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?8W5S=&]M7W!R97-E="<@
M/3X@)T-U<W1O;2!$97-K=&]P('!R97-E="!C86YN;W0@8F4@<F5M;W9E9"XG
M+`H))V1A<VAB;V%R9%]?9&5L971E7W!R97-E=%]P<FEV871E7W!R97-E="<@
M/3X@)U!R:79A=&4@1&5S:W1O<"!P<F5S970@8V%N;F]T(&)E(')E;6]V960N
M)RP*"2=D87-H8F]A<F1?7V1E;&5T95]P<F5S971?9&5F875L=%]P<F5S970G
M(#T^("=$969A=6QT($1E<VMT;W`@<')E<V5T(&-A;FYO="!B92!R96UO=F5D
M+B<L"@H))V1A<VAB;V%R9%]?=W)O;F=?<')E<V5T7W1Y<&4G"0D]/B`G26YC
M;VUP871I8FQE($1E<VMT;W`@<')E<V5T('1Y<&4N)RP*"@DG<&)?7V1A<VAB
M;V%R9"<)"0D)/3X@)T1E<VMT;W`G+`H*"2=D87-H8F]A<F1?7W!R97-E='-?
M>&UL7VQO861?97)R;W(G"3T^("=5;F%B;&4@=&\@:6UP;W)T(&1E<VMT;W`@
M<')E<V5T<SH@5&AE('5P;&]A9&5D(%A-3"!F:6QE(&-O;G1A:6YS(&$@<WEN
M=&%X(&5R<F]R+B<L"@DG9&%S:&)O87)D7U]P<F5S971S7WAM;%]V86QI9&%T
M:6]N7V5R<F]R)PD]/B`G56YA8FQE('1O(&EM<&]R="!D97-K=&]P('!R97-E
M=',Z(%1H92!U<&QO861E9"!834P@9FEL92!C;VYT86EN<R!A('-Y;G1A>"!E
M<G)O<BXG+`H))V1A<VAB;V%R9%]?<')E<V5T<U]X;6Q?=F5R<VEO;E]E<G)O
M<B<)"3T^("=5;F%B;&4@=&\@:6UP;W)T(&1E<VMT;W`@<')E<V5T<SH@5&AE
M('5P;&]A9&5D(%A-3"!F:6QE('=A<R!C<F5A=&5D(&)Y(%!L97-K('9E<G-I
M;VX@)3(@=VAI8V@@:7,@96%R;&EE<B!T:&%N('1H92!C=7)R96YT('9E<G-I
M;VX@*"4Q*2XG+`H*"2=D87-H8F]A<F1?7W!R97-E=%]R96UO=F5?96UP='E?
M<V5L96-T:6]N)PD]/B`G3F\@<')E<V5T<R!S96QE8W1E9"X@4V5L96-T(&1E
M<VMT;W`@<')E<V5T<R!Y;W4@=V%N="!T;R!R96UO=F4N)RP*"2=D87-H8F]A
M<F1?7W!R97-E=%]R96UO=F5?=&ET;&4G"0D)/3X@)U1H92!F;VQL;W=I;F<@
M1&5S:W1O<"!P<F5S971S('=I;&P@8F4@<F5M;W9E9#HG+`H*"2=D87-H8F]A
M<F1?7W!R97-E=%]E9&ET7W1I=&QE)PD)"0D]/B`G161I=&EN9R!$97-K=&]P
M(%!R97-E="<L"@DG9&%S:&)O87)D7U]D87-H8F]A<F1?8W5S=&]M:7IE7W1I
M=&QE)PD)/3X@)T-U<W1O;6EZ:6YG($1E<VMT;W`G+`H*"2=S97)V97)?:6YT
M97)F86-E7U]P86=E7W1I=&QE)PD]/B`G4V5R=F5R($EN=&5R9F%C92!0<F5F
M97)E;F-E<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]L;V-A;&5S)R`]
M/B`G3&]C86QE<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]S:VEN<R<)
M(#T^("=3:VEN<R<L"@DG<V5R=F5R7VEN=&5R9F%C95]?=&%B<U]D87-H8F]A
M<F1?<')E<V5T<R<@/3X@)T1E<VMT;W`@4')E<V5T<R<L"@DG<V5R=F5R7VEN
M=&5R9F%C95]?=&%B<U]I;G1E<F9A8V5?=&5M<&QA=&5S)R`]/B`G26YT97)F
M86-E(%1E;7!L871E<R<L"@DG8G1?<V5R=F5R7VEN=&5R9F%C92<)/3X@)TEN
M=&5R9F%C92!0<F5F97)E;F-E<R<L"@DG<&)?7W-E<G9E<E]I;G1E<F9A8V4G
M"3T^("=);G1E<F9A8V4@4')E9F5R96YC97,G+`H*"2=B=%]W:7IA<F1?;F5X
M="<@/3X@)TYE>'0@/CXG+`H))V)T7W=I>F%R9%]P<F5V)R`]/B`G/#P@0F%C
M:R<L"@H))U]?;&EM:71?97AC965D961?;6%X7V1O;5]S97)V97(G"0D)"3T^
M("=397)V97(@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1O;6%I
M;G,N(%!L96%S92!C;VYT86-T('1O('1H92!S97)V97(@861M:6YI<W1R871O
M<BXG+`H))U]?;&EM:71?97AC965D961?;6%X7W-U8F1O;5]S97)V97(G"0D)
M/3X@)U-E<G9E<B!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@<W5B
M9&]M86EN<RX@4&QE87-E(&-O;G1A8W0@=&\@=&AE('-E<G9E<B!A9&UI;FES
M=')A=&]R+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?9&]M86EN7V%L:6%S
M97-?<V5R=F5R)PD]/B`G4V5R=F5R(')E86-H960@=&AE(&QI;6ET(&]N(&YU
M;6)E<B!O9B!D;VUA:6X@86QI87-E<RX@4&QE87-E(&-O;G1A8W0@=&\@=&AE
M('-E<G9E<B!A9&UI;FES=')A=&]R+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M
M87A?=W5?<V5R=F5R)PD)"0D]/B`G4V5R=F5R(')E86-H960@=&AE(&QI;6ET
M(&]N(&YU;6)E<B!O9B!W96(@=7-E<B`@86-C;W5N=',N(%!L96%S92!C;VYT
M86-T('1O('1H92!S97)V97(@861M:6YI<W1R871O<BXG+`H))U]?;&EM:71?
M97AC965D961?;6%X7VUN7W-E<G9E<B<)"0D)/3X@)U-E<G9E<B!R96%C:&5D
M('1H92!L:6UI="!O;B!N=6UB97(@;V8@92UM86EL(&YA;65S+B!0;&5A<V4@
M8V]N=&%C="!T;R!T:&4@<V5R=F5R(&%D;6EN:7-T<F%T;W(N)RP*"@DG7U]L
M:6UI=%]E>&-E961E9%]M87A?8VQ?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E
M(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!C;&EE;G0@86-C;W5N
M=',@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@
M57-E9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E961E9%]M
M87A?9&]M7W5S97)A9&UI;B<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L
M:6UI="!O;B!N=6UB97(@;V8@9&]M86EN<R!D969I;F5D(&)Y('EO=7(@;&EC
M96YS92!K97DN($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U
M+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<W5B9&]M7W5S97)A9&UI;B<)
M"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@
M<W5B9&]M86EN<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L;&]W
M960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E
M>&-E961E9%]D:7-K7W-P86-E7W5S97)A9&UI;B<)"3T^("=9;W4@:&%V92!N
M;R!F<F5E(&1I<VL@<W!A8V4@;&5F="X@5&]T86P@86UO=6YT(&]F(&%V86EL
M86)L92!D:7-K('-P86-E.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG
M+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S97)A9&UI;B<)"0D]/B`G
M66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F('=E8B!U
M<V5R("!A8V-O=6YT<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L
M;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI
M=%]E>&-E961E9%]M87A?9&)?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R
M96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@9&%T86)A<V5S(&1E9FEN
M960@8GD@>6]U<B!L:6-E;G-E(&ME>2X@06QL;W=E9#H@)3(N(%5S960Z("4S
M+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]B;WA?
M=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O
M;B!N=6UB97(@;V8@;6%I;&)O>&5S(&1E9FEN960@8GD@>6]U<B!L:6-E;G-E
M(&ME>2X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*
M"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M;E]U<V5R861M:6XG"0D]/B`G66]U
M(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&4M;6%I;"!N
M86UE<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L;&]W960Z("4R
M+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E
M9%]M87A?<F5D:7)?=7-E<F%D;6EN)PD)/3X@)UEO=2!H879E(')E86-H960@
M=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL(&9O=V%R9&5R<R`H<F5D:7)E
M8W1S*2!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L;&]W960Z("4R
M+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E
M9%]M87A?;6=?=7-E<F%D;6EN)PD)"3T^("=9;W4@:&%V92!R96%C:&5D('1H
M92!L:6UI="!O;B!N=6UB97(@;V8@;6%I;"!G<F]U<',@*&4M;6%I;"!F;W)W
M87)D97)S('=I=&@@;75L=&EP;&4@<F5C:7!I96YT<RD@9&5F:6YE9"!B>2!Y
M;W5R(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I
M<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W)E<W!?=7-E<F%D
M;6EN)PD)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E
M<B!O9B`@875T;W)E<W!O;F1E<G,@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@
M:V5Y+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H)
M)U]?;&EM:71?97AC965D961?;6%X7VUA:6QL:7-T<U]U<V5R861M:6XG"3T^
M("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I
M;&EN9R!L:7-T<R!D969I;F5D(&)Y('EO=7(@;&EC96YS92!K97DN($%L;&]W
M960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E
M>&-E961E9%]M87A?=V5B87!P<U]U<V5R861M:6XG"3T^("=9;W4@:&%V92!R
M96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@2F%V82!A<'!L:6-A=&EO
M;G,@9&5F:6YE9"!B>2!Y;W5R(&QI8V5N<V4@:V5Y+B!!;&QO=V5D.B`E,BX@
M26YS=&%L;&5D.B`E,RX@4F5Q=6ER960Z("4U+B<L"@H))U]?;&EM:71?97AC
M965D961?;6%X7V1O;5]U<V5R8VQI96YT)PD)/3X@)UEO=2!H879E(')E86-H
M960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!D;VUA:6YS+B`@06QL;W=E9#H@
M)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E
M9&5D7VUA>%]S=6)D;VU?=7-E<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H
M960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!S=6)D;VUA:6YS("X@06QL;W=E
M9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X
M8V5E9&5D7V1I<VM?<W!A8V5?=7-E<F-L:65N="<)/3X@)UEO=2!H879E(')E
M86-H960@=&AE(&1I<VL@<W!A8V4@=7-A9V4@;&EM:70N("!!;&QO=V5D.B`E
M,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D
M961?;6%X7W1R869F:6-?=7-E<F-L:65N="<)/3X@)UEO=2!H879E(')E86-H
M960@=&AE(&QI;6ET(&]N(&%M;W5N="!O9B!B86YD=VED=&@N($%L;&]W960Z
M("4R+B!5<V5D.B`E,RXG+`H))U]?;&EM:71?97AC965D961?;6%X7W=U7W5S
M97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@
M;G5M8F5R(&]F('=E8B!U<V5R(&%C8V]U;G1S+B!!;&QO=V5D.B`E,BX@57-E
M9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X
M7V1B7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&1A=&%B87-E<R`N($%L;&]W960Z("4R+B!5<V5D
M.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?
M8F]X7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM
M:70@;VX@;G5M8F5R(&]F(&UA:6QB;WAE<R`N($%L;&]W960Z("4R+B!5<V5D
M.B`E,RX@4F5Q=6ER960Z("4U+B<L"@DG7U]L:6UI=%]E>&-E961E9%]M87A?
M<F5D:7)?=7-E<F-L:65N="<)"3T^("=9;W4@:&%V92!R96%C:&5D('1H92!L
M:6UI="!O;B!N=6UB97(@;V8@;6%I;"!F;W)W87)D97)S("AR961I<F5C=',I
M+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?
M;&EM:71?97AC965D961?;6%X7VUG7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA
M=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6P@9F]R=V%R
M9&5R<R!W:71H(&UU;'1I<&QE(')E8VEP:65N=',@*&UA:6P@9W)O=7!S*2X@
M06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI
M;6ET7V5X8V5E9&5D7VUA>%]R97-P7W5S97)C;&EE;G0G"0D]/B`G66]U(&AA
M=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("!A=71O<F5S<&]N
M9&5R<RX@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U:7)E9#H@)34N)RP*
M"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]M86EL;&ES='-?=7-E<F-L:65N="<)
M/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M
M86EL:6YG(&QI<W1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D
M.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W=E8F%P<'-?=7-E<F-L
M:65N="<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E
M<B!O9B!*879A(&%P<&QI8V%T:6]N<RX@06QL;W=E9#H@)3(N($EN<W1A;&QE
M9#H@)3,N(%)E<75I<F5D.B`E-2<L"@DG7U]L:6UI=%]E>&-E961E9%]E>'!I
M<F%T:6]N7W5S97)C;&EE;G0G"3T^("=9;W5R(&%C8V]U;G0@97AP:7)E9"!O
M;B`E,BXG+`H*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]S=6)D;VU?=7-E<F1O
M;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&YU;6)E
M<B!O9B!S=6)D;VUA:6YS("X@06QL;W=E9#H@)3(N(%5S960Z("4S+B!297%U
M:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7V1I<VM?<W!A8V5?=7-E
M<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&1I<VL@<W!A8V4@
M=7-A9V4@;&EM:70N("!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D
M.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7W1R869F:6-?=7-E<F1O
M;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@=&AE(&QI;6ET(&]N(&%M;W5N
M="!O9B!B86YD=VED=&@N($%L;&]W960Z("4R+B!5<V5D.B`E,RXG+`H))U]?
M;&EM:71?97AC965D961?;6%X7W=U7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA
M=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F('=E8B!U<V5R(&%C
M8V]U;G1S+B!!;&QO=V5D.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG
M+`H))U]?;&EM:71?97AC965D961?;6%X7V1B7W5S97)D;VUA:6XG"0D]/B`G
M66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&1A=&%B
M87-E<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L
M"@DG7U]L:6UI=%]E>&-E961E9%]M87A?8F]X7W5S97)D;VUA:6XG"0D]/B`G
M66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F(&UA:6QB
M;WAE<R`N($%L;&]W960Z("4R+B!5<V5D.B`E,RX@4F5Q=6ER960Z("4U+B<L
M"@DG7U]L:6UI=%]E>&-E961E9%]M87A?<F5D:7)?=7-E<F1O;6%I;B<)"3T^
M("=9;W4@:&%V92!R96%C:&5D('1H92!L:6UI="!O;B!N=6UB97(@;V8@;6%I
M;"!F;W)W87)D97)S("AR961I<F5C=',I+B!!;&QO=V5D.B`E,BX@57-E9#H@
M)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC965D961?;6%X7VUG
M7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@
M;VX@;G5M8F5R(&]F(&UA:6P@9F]R=V%R9&5R<R!W:71H(&UU;'1I<&QE(')E
M8VEP:65N=',@*&UA:6P@9W)O=7!S*2X@06QL;W=E9#H@)3(N(%5S960Z("4S
M+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA>%]R97-P
M7W5S97)D;VUA:6XG"0D]/B`G66]U(&AA=F4@<F5A8VAE9"!T:&4@;&EM:70@
M;VX@;G5M8F5R(&]F("!A=71O<F5S<&]N9&5R<RX@06QL;W=E9#H@)3(N(%5S
M960Z("4S+B!297%U:7)E9#H@)34N)RP*"2=?7VQI;6ET7V5X8V5E9&5D7VUA
M>%]M86EL;&ES='-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E86-H960@
M=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!M86EL:6YG(&QI<W1S+B!!;&QO=V5D
M.B`E,BX@57-E9#H@)3,N(%)E<75I<F5D.B`E-2XG+`H))U]?;&EM:71?97AC
M965D961?;6%X7W=E8F%P<'-?=7-E<F1O;6%I;B<)/3X@)UEO=2!H879E(')E
M86-H960@=&AE(&QI;6ET(&]N(&YU;6)E<B!O9B!*879A(&%P<&QI8V%T:6]N
M<RX@06QL;W=E9#H@)3(N($EN<W1A;&QE9#H@)3,N(%)E<75I<F5D.B`E-2<L
M"@DG7U]L:6UI=%]E>&-E961E9%]E>'!I<F%T:6]N7W5S97)D;VUA:6XG"3T^
M("=9;W5R(&%C8V]U;G0@97AP:7)E9"!O;B`E,BXG+`H*"@DG86-T:6]N;&]G
M7U]D8E]S97)V97(G(#T^("=$871A8F%S92!S97)V97(G+`H))V1A<VAB;V%R
M9%]?<')E<V5T<U]S96QE8W1?=&]?9&]W;FQO860G(#T^("=.;R!D97-K=&]P
M('!R97-E=',@<V5L96-T960N(%!L96%S92!S96QE8W0@=&AE('!R97-E=',@
M>6]U('=A;G0@=&\@9&]W;FQO860N)RP*"2=M:6=R871I;VY?=7!L;V%D7V9O
M<FU?;65S)R`]/B`G57!L;V%D:6YG(&UI9W)A=&EO;B!A9V5N="!T;R!H;W-T
M("4Q+B<L"@DG;6EG<F%T:6]N7W5P;&]A9%]A9V5N=%]F86QS92<@/3X@)T9A
M:6QE9"!T;R!U<&QO860@=&AE(&UI9W)A=&EO;B!A9V5N="<L"@DG;6EG<F%T
M:6]N7W5P;&]A9%]A9V5N="<@/3X@)TUI9W)A=&EO;B!!9V5N="!5<&QO860G
M+`H))VUI9W)A=&EO;E]U<&QO861?86=E;G1?;VXG(#T^("=5<&QO861I;F<@
M36EG<F%T:6]N($%G96YT('1O("4Q)RP*"2=M:6=R871I;VY?:&]S=%]I;F9O
M)R`]/B`G26YF;W)M871I;VX@;VX@4V]U<F-E($AO<W0@)3$G+`H))VUI9W)A
M=&EO;E]G971?86-C;W5N=%]A;F1?9&]M86EN<R<@/3X@)U-E;&5C="!O8FIE
M8W1S('1H870@>6]U('=I<V@@=&\@;6EG<F%T92!F<F]M(&AO<W0@)3$G+`H)
M)VUI9W)A=&EO;E]M97-S86=E7VQE9V5N9"<@/3X@)TEN9F]R;6%T:6]N)RP*
M"2=M:6=R871I;VY?:&]S=%]D971A:6QS)R`]/B`G2&]S="!D971A:6QS)RP*
M"2=M:6=R871I;VY?:&]S=%]I;F9O7V]S)R`]/B`G3W!E<F%T:6YG('-Y<W1E
M;2<L"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]L;V%D879G)R`]/B`G3&]A9"!A
M=F5R86=E(&]N('1H92!H;W-T)RP*"2=M:6=R871I;VY?:&]S=%]I;F9O7VAO
M<W1I;F=P;&%T9F]R;2<@/3X@)TAO<W1I;F<@<&QA=&9O<FTO=F5R<VEO;B<L
M"@DG;6EG<F%T:6]N7VAO<W1?:6YF;U]C;&EE;G1S)R`]/B`G3G5M8F5R(&]F
M(&-L:65N=',G+`H))VUI9W)A=&EO;E]H;W-T7VEN9F]?9&]M86EN<R<@/3X@
M)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I;VY?:&]S=%]I;F9O7VAO
M<W0G(#T^("=397)V97(G+`H))VUI9W)A=&EO;E]G971?86-C;W5N=%]D;VUA
M:6Y?;65S)R`]/B`G1&]W;FQO861I;F<@82!L:7-T(&]F(&%C8V]U;G1S(&%N
M9"!D;VUA:6YS(&9R;VT@=&AE('-O=7)C92!H;W-T("4Q+B<L"@DG;6EG<F%T
M:6]N7VUA:6Y?9&]W;FQO860Q)R`]/B`B5')A;G-F97)R:6YG(&9I;&4Z("4Q
M7&Y3:7IE.B`E,EQN3&5F="!T;R!T<F%N<V9E<CH@)3,B+`H))VUI9W)A=&EO
M;E]M86EN7V1O=VYL;V%D,B<@/3X@(DAO<W0Z("4Q7&Y4<F%N<V9E<G)E9#H@
M)3(@9FEL97,L("4S7&Y,969T.B`E-"!F:6QE<RP@)35<;E1R86YS9F5R('-P
M965D.B`E-B(L"@DG;6EG<F%T:6]N7W-E;&5C=%]A8V-O=6YT)R`]/B`G4V5L
M96-T('1H92!C;&EE;G0@86-C;W5N="<L"@DG;6EG<F%T:6]N7VEP7VUA<%]P
M86=E)R`]/B`G25`@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A=&$@9G)O;2`E
M,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?<&%G92<@/3X@)T1A=&%B
M87-E('-E<G9E<G,@;6%P<&EN9R!F;W(@;6EG<F%T:6YG(&1A=&$@9G)O;2`E
M,2<L"@DG;6EG<F%T:6]N7V1B7W-E<G9R95]M87!?;&5G96YD)R`]/B`G1$(@
M<V5R=F5R<R!M87!P:6YG)RP*"2=M:6=R871I;VY?:7!?;6%P)R`]/B`G25`@
M36%P<&EN9R<L"@DG;6EG<F%T:6]N7VEP7VUA<%]A;&5R="<@/3X@)U!L96%S
M92!S<&5C:69Y(&UA<'!I;F<@9F]R(&%L;"!)4"!A9&1R97-S97,G+`H))VUI
M9W)A=&EO;E]S=&]P7W!A9V4G(#T^("=3=&]P(&UI9W)A=&EN9R!D871A(&9R
M;VT@:&]S="`E,2<L"@DG;6EG<F%T:6]N7W-T;W!?;65S<V%G92<@/3X@)U-T
M;W`@=&AE(&UI9W)A=&EO;B!P<F]C97-S)RP*"2=M:6=R871I;VY?9&5P;&]Y
M7VEN9F\Q)R`]/B`G1&5P;&]Y:6YG("4Q("4R)RP*"2=M:6=R871I;VY?9&5P
M;&]Y7VEN9F\R)R`]/B`B5&]T86P@86-C;W5N=',O;&5F="`E,2\E,EQN5&]T
M86P@9&]M86EN<R]L969T("4S+R4T7&XB+`H))VUI9W)A=&EO;E]N;W1I9GDG
M(#T^("=.;W1I9GD@=7-E<G,@=7!O;B!C<F5A=&EO;B!O9B!E86-H('-Y<W1E
M;2!O8FIE8W0G+`H))VUI9W)A=&EO;E]K965P7V%R8VAI=F5S)R`]/B`G2V5E
M<"!T:&4@=&5M<&]R87)Y(&9I;&5S)RP*"2=M:6=R871I;VY?<V5T=&EN9R<@
M/3X@)T1E<&QO>6UE;G0@4V5T=&EN9W,G+`H))VUI9W)A=&EO;E]S971T:6YG
M7VQE9R<@/3X@)T1E<&QO>6UE;G0@<V5T=&EN9W,G+`H))VUI9W)A=&EO;E]D
M97!L;WE?<')O9W)E<W,G(#T^("=$97!L;WEM96YT('!R;V=R97-S)RP*"2=M
M:6=R871I;VY?9&5P;&]Y7VEN9F\G(#T^("=$97!L;WEM96YT('!R;V=R97-S
M(&9O<B!H;W-T("4Q)RP*"2=M:6=R871I;VY?:&]S="<@/3X@)U-O=7)C92!H
M;W-T)RP*"2=M:6=R871I;VY?<&%S<W=O<F0G(#T^("=,;V=I;B!P87-S=V]R
M9"<L"@DG;6EG<F%T:6]N7W!L871F;W)M)R`]/B`G4V]U<F-E('!L871F;W)M
M)RP*"2=M:6=R871I;VY?=')A;G-L971E)R`]/B`G0V]N=F5R=&EN9R!D=6UP
M('1O(%!L97-K(&9O<FUA="<L"@DG;6EG<F%T:6]N7V%G96YT7W=A:70G(#T^
M("=786ET:6YG('1H92!R97-P;VYS92!F<F]M(&%G96YT)RP*"2=M:6=R871I
M;VY?96YD7V1E<&QO>5]I;F9O)R`]/B`G1&%T82!M:6=R871I;VX@9G)O;2!H
M;W-T("4Q(&AA<R!B965N(&-O;7!L971E9"XG+`H))VUI9W)A=&EO;E]D97!L
M;WE?9&5T86EL<R<@/3X@)T1E=&%I;',G+`H))VUI9W)A=&EO;E]W<F]N9U]A
M9V5N="<@/3X@)T%G96YT(&ES(&YO="!S=6ET86)L92!F;W(@=&AE(&=I=F5N
M(&AO<W0N)RP*"2=M:6=R871I;VY?<V5L96-T7W-O;64G(#T^("=396QE8W0@
M=&AE(&]B:F5C=',@=&\@;6EG<F%T92XG+`H))VUI9W)A=&EO;E]D;W=L;V%D
M)R`]/B`G1&]W;FQO861I;F<@8V]N=&5N="!F<F]M(&AO<W0@)3$G+`H))VUI
M9W)A=&EO;E]D;W=L;V%D7W!R;V=R97-S)R`]/B`G1&]W;FQO860@<')O9W)E
M<W,G+`H))VUI9W)A=&EO;E]D;W=L;V%D7V-U<G)E;G0G(#T^("=$;W=N;&]A
M9&EN9R!C=7)R96YT(&9I;&4G+`H))VUI9W)A=&EO;E]X;6Q?9&5S8R<@/3X@
M)T1O=VYL;V%D:6YG('1H92!D=6UP(&1E<V-R:7!T:6]N+B<L"@DG;6EG<F%T
M:6]N7VYO7V5R<F]R<R<@/3X@)U1H92!M:6=R871I;VX@:&%S(&)E96X@8V]M
M<&QE=&5D+B<L"@DG;6EG<F%T:6]N7W5N86)L95]G971?86-C;W5N=%]A;F1?
M9&]M86EN<R<@/3X@)U5N86)L92!T;R!R971R:65V92!A(&QI<W0@;V8@86-C
M;W5N=',@86YD(&1O;6%I;G,Z("<L"@DG;6EG<F%T:6]N7W5N86)L95]T<F%N
M<VQA=&4G(#T^("=5;F%B;&4@=&\@8V]N=F5R="!T:&4@9&%T82!T;R!0;&5S
M:R!F;W)M870Z("<L"@DG;6EG<F%T:6]N7W5N86)L95]D=6UP7W)E=')I979E
M)R`]/B`G1F%I;&5D('1O(')E=')I979E('1H92!D871A.B`G+`H))VUI9W)A
M=&EO;E]U;F%B;&5?87)C:&EV95]H;W-T)R`]/B`G56YA8FQE('1O(&-R96%T
M92!A(&1E<V-R:7!T:6]N(&9O<B!T:&4@;6EG<F%T960@;V)J96-T<SH@)RP*
M"2=M:6=R871I;VY?<V5L96-T7V%C8V]U;G1?<&%G92<@/3X@)U-E;&5C="!T
M:&4@8VQI96YT(&%C8V]U;G0@=&\@=VAI8V@@>6]U('=I<V@@=&\@;6EG<F%T
M92!T:&4@9&]M86EN<R<L"@DG;6EG<F%T:6]N7W5N86)L95]D97!L;WDG(#T^
M("=5;F%B;&4@=&\@9&5P;&]Y('1H92!M:6=R871E9"!O8FIE8W1S.B`G+`H)
M)V)T7VUI9W)A=&EO;E]M;W)E)R`]/B`G36EG<F%T92!M;W)E)RP*"2=B=%]M
M:6=R871I;VY?8F5G:6XG(#T^("=&:6YI<V@G+`H))VUI9W)A=&EO;E]S96QE
M8W1?97AI<W1?:7`G(#T^("=396QE8W0@9&5S=&EN871I;VX@25`G+`H))VUI
M9W)A=&EO;E]S96QE8W1?97AI<W1?9&)?<V5R=F5R)R`]/B`G4V5L96-T(&1E
M<W1I;F%T:6]N($1"('-E<G9E<B<L"@DG;6EG<F%T:6]N7V1O;6%I;E]C;W5N
M="<@/3X@)TYU;6)E<B!O9B!D;VUA:6YS)RP*"2=M:6=R871I;VY?86-C;W5N
M="<@/3X@)T%C8V]U;G0G+`H))VUI9W)A=&EO;E]D96UO7W=A<B<@/3X@(E=A
M<FYI;F<A(%1H:7,@:7,@=&AE($UI9W)A=&EO;B!-86YA9V5R(&1E;6\N($YO
M(&%C8V]U;G1S(&%N9"!D;VUA:6YS('=I;&P@8F4@86-T=6%L;'D@;6EG<F%T
M960N(%QN4&QE87-E('-P96-I9GD@=&AE(&1E<VER960@=F%L=65S+B(L"@DG
M;6EG<F%T:6]N7V1O=VYL;V%D7VYO=%]S<&%C92<@/3X@)TYO="!E;F]U9V@@
M9&ES:R!S<&%C92$G+`H))V)T7VUI9W)A=&EO;E]I9VYO<F4G(#T^("=)9VYO
M<F4G+`H))V)T7VUI9W)A=&EO;E]R971R>2<@/3X@)U)E=')Y)RP*"2=M:6=R
M871I;VY?9'5M<%]A;&PG(#T^("=-:6=R871E(&%L;"!C;&EE;G1S(&%N9"!D
M;VUA:6YS)RP*"2=M:6=R871I;VY?9&5T86EL<R<@/3X@)TUI9W)A=&EO;B!D
M971A:6QS)RP*"2=M:6=R871I;VY?;&EM:71?97)R;W(G(#T^(")4:&4@;G5M
M8F5R(&]F('MT>7!E?2!Y;W4@87)E('1R>6EN9R!T;R!C<F5A=&4@=V]U;&0@
M;W9E<G)I9&4@=&AE(&QI;6ET<R!D969I;F5D(&)Y('1H92!L:6-E;G-E(&ME
M>2`M("4Q+EQN66]U(&-A;B!C<F5A=&4@;VYL>2`E,B![='EP97T@;6]R92XB
M+`H))VUI9W)A=&EO;E]I9&QE)R`]/B`G4')E<&%R:6YG(&9O<B!E>&5C=71I
M;VXG+`H))VUI9W)A=&EO;E]R96UO=F5?86=E;G0G(#T^("=296UO=F4@86=E
M;G0G+`H))VUI9W)A=&EO;E]S=&]P7VQA8FQE)R`]/B`G4W1O<'!I;F<G+`H)
M)VUI9W)A=&EO;E]R96UO=F5?87)C:&EV92<@/3X@)U)E;6]V92!T96UP;W)A
M<GD@9FEL97,G+`H))VUI9W)A=&EO;E]N;U]O8FIE8W0G(#T^("=4:&5R92!A
M<F4@;F\@;V)J96-T<R!F;W(@;6EG<F%T:6]N(&]N('1H92!R96UO=&4@:&]S
M="XG+`H))VUI9W)A=&EO;E]N;U]D;VUA:6XG(#T^("=.;R!D;VUA:6YS('=E
M<F4@9F]U;F0G+`H))V)T7VUI9W)A=&5?<VEN9VQE)R`]/B`G4VEN9VQE+4AO
M<W0@36EG<F%T:6]N)RP*"2=M:6=R871I;VY?8V]M<')E<W,G(#T^("=$871A
M(&-O;7!R97-S:6]N)RP*"2=M:6=R871I;VY?;6]D92<@/3X@)TUI9W)A=&EO
M;B!M;V1E)RP*"2=M:6=R871I;VY?9'5M<%]M97-S86=E,2<@/3X@(D-U<G)E
M;G1L>2!D=6UP:6YG('1H92!A8V-O=6YT.B`E,5QN0W5R<F5N="!D;VUA:6XZ
M("4R7&Y!8V-O=6YT<R!L969T('1O(&1U;7`Z("4S7&Y$;VUA:6YS(&QE9G0@
M=&\@9'5M<#H@)30B+`H))VUI9W)A=&EO;E]D=6UP7W!R;V=R97-S)R`]/B`G
M1'5M<&EN9R!P<F]G<F5S<R<L"@DG;6EG<F%T:6]N7V1U;7!?8W5R<F5N="<@
M/3X@)T1U;7!I;F<@9&%T82<L"@DG;6EG<F%T:6]N7V%G96YT7W!A=&@G(#T^
M("=$:7)E8W1O<GD@;VX@=&AE('-O=7)C92!H;W-T('=H97)E($UI9W)A=&EO
M;B!-86YA9V5R('=I;&P@<&QA8V4@86QL(&1A=&$@8F5F;W)E('1R86YS9F5R
M<FEN9R!T:&5M)RP*"2=M:6=R871I;VY?9'5M<%]N;V5X:7-T)R`]/B`G1F]R
M('1H92!S:6YG;&4M:&]S="!M:6=R871I;VXL('EO=2!S:&]U;&0@<&QA8V4@
M=&AE(&1U;7`@=&\@(B4Q(BXG+`H))VUI9W)A=&EO;E]S=61O7W!A<W-W;W)D
M)R`]/B`G4W5D;R!P87-S=V]R9"<L"@DG;6EG<F%T:6]N7W-U9&]?<F]O="<@
M/3X@)W)O;W0G+`H))VUI9W)A=&EO;E]S=61O7V]T:&5R<R<@/3X@)V]T:&5R
M)RP*"2=M:6=R871I;VY?8F%C:V5N9%]C<F%S:%]O9F9?;65S<R<@/3X@)TUI
M9W)A=&EO;B!-86YA9V5R(&)A8VL@96YD('1E<FUI;F%T960@8F5C875S92!O
M9B!U;F5X<&5C=&5D(&5R<F]R+B!0;&5A<V4@8V]N=&%C="!S=7!P;W)T+B<L
M"@DG;6EG<F%T:6]N7W-I;F=L95]N;W1E7VUE<W,G(#T^("=5<V4@=&AI<R!F
M96%T=7)E('1O(&EM<&]R="!T:&4@9&%T82!C<F5A=&5D(&)Y('1H92!M:6=R
M871I;VX@86=E;G0N)RP*"2=M:6=R871I;VY?<VEN9VQE7VUO9&4G(#T^("=$
M871A(&EM<&]R="<L"@DG;6EG<F%T:6]N7VYO<FUA;%]M;V1E)R`]/B`G36EG
M<F%T:6]N)RP*"2=M:6=R871I;VY?<V5L96-T7V-L:65N="<@/3X@)U-E;&5C
M="!C;&EE;G0G+`H))VUI9W)A=&EO;E]F<F]M)R`]/B`G("AM:6=R871I;VX@
M9G)O;2!H;W-T("4Q*2<L"@DG;6EG<F%T:6]N7W-E;&5C=%]M;V1E)R`]/B`G
M4V5L96-T(&UI9W)A=&EO;B!M;V1E)RP*"2=M:6=R871I;VY?<V5L96-T7V-L
M:65N=%]I;E]L:7-T)R`]/B`G5&\@<V5L96-T(&$@8VQI96YT+"!C;&EC:R!O
M;B!T:&4@8VQI96YT(&YA;64G+`H))VUI9W)A=&EO;E]S:6YG;&5?:6YF;R<@
M/3X@)TEM<&]R=&EN9R!D871A(&9R;VT@)3$G+`H))VUI9W)A=&EO;E]D=6UP
M7VEN9F\G(#T^("=$=6UP(&1E=&%I;',G+`H))VUI9W)A=&EO;E]S96QE8W1?
M<VEN9VQE7VUO9&4G(#T^("=396QE8W0@:6UP;W)T(&UO9&4G+`H))VUI9W)A
M=&EO;E]S96QE8W1?<VEN9VQE7VET96TG(#T^("=396QE8W0@;V)J96-T<R!F
M;W(@:6UP;W)T)RP*"2=M:6=R871I;VY?<VEN9VQE7V%L;"<@/3X@)TEM<&]R
M="!A;&PG+`H))VUI9W)A=&EO;E]A9&1?9G)E95]I<"<@/3X@)SQB/DYO=&4Z
M/"]B/B!">2!S96QE8W1I;F<@82!V86-A;G0@25`@861D<F5S<R!Y;W4@=VEL
M;"!A9&0@:70@=&\@8VQI96YT7"=S($E0('!O;VPN)RP*"2=M:6=R871I;VY?
M:7!?=F%C86YT)R`]/B`G5F%C86YT)RP*"2=M:6=R871I;VY?<VEN9VQE7W1R
M86YS)R`]/B`G0V]N=F5R=&EN9R!D871A('1O(&YA=&EV92!0;&5S:R!F;W)M
M870G+`H))VUI9W)A=&EO;E]S96QE8W1?:7`G(#T^("=396QE8W0@25`G+`H)
M)VUI9W)A=&EO;E]N;U]C:&5C:U]S<&%C92<@/3X@)T1O(&YO="!C:&5C:R!F
M;W(@86UO=6YT(&]F(&9R964@9&ES:R!S<&%C92!D=7)I;F<@;6EG<F%T:6]N
M)RP*"2=M:6=R871I;VY?9G-?:6YF;U]M;W5N='!O:6YT)R`]/B`G36]U;G0@
M<&]I;G0G+`H))VUI9W)A=&EO;E]F<U]I;F9O7W1Y<&4G(#T^("=4>7!E)RP*
M"2=M:6=R871I;VY?9G-?:6YF;U]T;W1A;"<@/3X@)U1O=&%L)RP*"2=M:6=R
M871I;VY?9G-?:6YF;U]F<F5E)R`]/B`G1G)E92<L"@DG;6EG<F%T:6]N7V9S
M7VQE9V5N="<@/3X@)U-O=7)C92!H;W-T('!A<G1I=&EO;B<L"@DG;6EG<F%T
M:6]N7V9S7W5S86=E)R`]/B`G57-A9V4G+`H))VUI9W)A=&EO;E]L;V-A;%]F
M<U]L96=E;G0G(#T^("=7;W)K:6YG(&1I<F5C=&]R>2<L"@DG;6EG<F%T:6]N
M7W-T;W)A9V5?9&ER)R`]/B`G1&ER96-T;W)Y(&]N('1H:7,@<V5R=F5R('1O
M('=H:6-H(&%L;"!D871A('=I;&P@8F4@=')A;G-F97)R960G+`H))VUI9W)A
M=&EO;E]U<&QO861?<V-O=6YT)R`]/B`G4F5T<FEE=FEN9R!I;F9O<FUA=&EO
M;B!O;B!T:&4@:&]S="`E,2!I<R!I;B!P<F]C97-S)RP*"2=M:6=R871I;VY?
M=7!L;V%D7W-C;W5N=%]O;B<@/3X@)U)E=')I979I;F<@:6YF;W)M871I;VX@
M;VX@=&AE(&AO<W0@)3$G+`H))VUI9W)A=&EO;E]S;W5R8V5?<&QA=&9O<FTG
M(#T^("=-:6=R871I;VX@<&QA=&9O<FTG+`H))VUI9W)A=&EO;E]P;&%T9F]R
M;5]D971E8U]F86EL)R`]/B`G075T;VUA=&EC(&1E=&5C=&EO;B!O9B!H;W-T
M:6YG('!L871F;W)M(&9A:6QE9"X@4&QE87-E('-E;&5C="!P;&%T9F]R;2!M
M86YU86QL>2!F<F]M('1H92!C;VUB;R!B;W@@8F5L;W<N)RP*"2=M:6=R871I
M;VY?<V5L96-T7W!L871F;W)M)R`]/B`G+2T@4V5L96-T('!L871F;W)M("TM
M)RP*"2=M:6=R871I;VY?;F]?8VQI96YT)R`]/B`G66]U(&AA=F4@;F\@8VQI
M96YT(&%C8V]U;G1S(&]N('1H92!D97-T:6YA=&EO;B!H;W-T('1O(&UI9W)A
M=&4@9&]M86EN<R!T;R<L"@DG;6EG<F%T:6]N7W1E;7!L871E7VQE9V5N9"<@
M/3X@)T-R96%T:6]N(&]F(&1O;6%I;G,@8GD@=&5M<&QA=&4G+`H))VUI9W)A
M=&EO;E]C;&EE;G1?=&5M<&QA=&4G(#T^("=5<V4@82!T96UP;&%T92!F;W(@
M8W)E871I;F<@8VQI96YT(&%C8V]U;G1S)RP*"2=M:6=R871I;VY?9&]M86EN
M7W1E;7!L871E)R`]/B`G57-E(&$@=&5M<&QA=&4@9F]R(&-R96%T:6YG(&1O
M;6%I;G,G+`H))VUI9W)A=&EO;E]R96%C:&5D7VQI;6ET)R`]/B`G66]U(&AA
M=F4@<F5A8VAE9"!T:&4@;&EM:70@;VX@;G5M8F5R(&]F("4Q+B<L"@DG;6EG
M<F%T:6]N7W)E86-H961?;&EM:71?8VQI96YT)R`]/B`G8VQI96YT(&%C8V]U
M;G1S)RP*"2=M:6=R871I;VY?<F5A8VAE9%]L:6UI=%]D;VUA:6XG(#T^("=D
M;VUA:6YS)RP*"2=M:6=R871I;VY?<V5S<VEO;E]L:7-T)R`]/B`G4&QE<VL@
M36EG<F%T:6]N($UA;F%G97(G+`H))VUI9W)A=&EO;E]C=7)R96YT7VUI9W)A
M=&EO;G-?;&ES="<@/3X@)T-U<G)E;G0@;6EG<F%T:6]N<R<L"@DG;6EG<F%T
M:6]N7V-U<G)E;G1?;6EG<F%T:6]N)R`]/B`G0W5R<F5N="!M:6=R871I;VYS
M)RP*"2=B=%]M:6=R871I;VY?<V5S<VEO;E]A9&0G(#T^("=3=&%R="!A(&YE
M=R!M:6=R871I;VXG+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7V]B:F5C
M=',G(#T^("=-:6=R871I;F<@;V)J96-T<R<L"@DG;6EG<F%T:6]N7W-E<W-I
M;VY?;&ES=%]?<W1A<G1?9&%T92<@/3X@)U-T87)T(&1A=&4G+`H))VUI9W)A
M=&EO;E]S97-S:6]N7VQI<W1?7V5L87!S960G(#T^("=%;&%P<V5D('1I;64G
M+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7W!R;V=R97-S)R`]/B`G4')O
M9W)E<W,G+`H))VUI9W)A=&EO;E]S97-S:6]N7VQI<W1?7VYO=%]S96QE8W1E
M9"<@/3X@)TYO="!Y970@<V5L96-T960G+`H))VUI9W)A=&EO;E]S=&%T95]D
M97-C7V9A:6QE9"<@/3X@)T9A:6QE9"!M:6=R871I;VXG+`H))VUI9W)A=&EO
M;E]S=&%T95]D97-C7V%W86ET:6YG7W-T87)T)R`]/B`G5V%I=&EN9R!F;W(@
M82!S=&%R="<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?87=A:71I;F=?86=E
M;G1?<&%R86TG(#T^("=0;&5A<V4@<W!E8VEF>2!M:6=R871I;VX@<&%R86UE
M=&5R<R<L"@DG;6EG<F%T:6]N7W-T871E7V1E<V-?<V5L96-T7V]B:F5C="<@
M/3X@)U-E;&5C="!T:&4@8G5S:6YE<W,@;V)J96-T<R!T;R!M:6=R871E)RP*
M"2=M:6=R871I;VY?<W1A=&5?9&5S8U]S96QE8W1?8VQI96YT)R`]/B`G4V5L
M96-T('1H92!C;&EE;G0@9F]R(&UI9W)A=&EO;B<L"@DG;6EG<F%T:6]N7W-T
M871E7V1E<V-?:7!?;6%P)R`]/B`G25`@;6%P<&EN9R<L"@DG;6EG<F%T:6]N
M7W-T871E7V1E<V-?9&)?<V5R=F5R7VUA<"<@/3X@)T1"('-E<G9E<B!M87!P
M:6YG)RP*"2=M:6=R871I;VY?<W1A=&5?9&5S8U]A<&E?;6EG<F%T:6]N)R`]
M/B`G36EG<F%T:6]N(&UA9&4@8GD@;65A;G,@;V8@4E!#)RP*"2=M:6=R871I
M;VY?<W1A=&5?9&5S8U]D=6UP:6YG)R`]/B`G4F5T<FEE=FEN9R!D871A(&9R
M;VT@<F5M;W1E(&AO<W0G+`H))VUI9W)A=&EO;E]S97-S:6]N7V9A:6QE9"<@
M/3X@)TUI9W)A=&EO;B!F<F]M(&AO<W0@)3$@9F%I;&5D)RP*"2=M:6=R871I
M;VY?8V]M<&QE=&5D)R`]/B`G5&AE(&UI9W)A=&EO;B!H87,@8F5E;B!C;VUP
M;&5T960N)RP*"2=M:6=R871I;VY?;F]?861M:6Y?9&]M7W1E;7!L871E)R`]
M/B`G5&AE<F4@87)E(&YO(&%D;6EN:7-T<F%T;W)<)W,@9&]M86EN('1E;7!L
M871E<R<L"@DG;6EG<F%T:6]N7V5R<F]R7V9I;&4G(#T^("=&:6QE)RP*"2=M
M:6=R871I;VY?97)R;W)?;&EN92<@/3X@)TQI;F4G+`H))VUI9W)A=&EO;E]E
M<G)O<E]C;VYT97AT)R`]/B`G0V]N=&5X="<L"@DG;6EG<F%T:6]N7V5R<F]R
M7W1E>'0G(#T^("=497AT)RP*"2=M:6=R871I;VY?97)R;W)?='EP92<@/3X@
M)U1Y<&4G+`H))VUI9W)A=&EO;E]E<G)O<E]N86UE)R`]/B`G3F%M92<L"@DG
M;6EG<F%T:6]N7VYO7VEP7V%V86EL86)L92<@/3X@)TYO($E0(&%D9')E<W-E
M<R!A=F%I;&%B;&4G+`H))VUI9W)A=&EO;E]A;FYO;E]F='!?;&]S="<@/3X@
M)T%F=&5R($E0(&UA<'!I;F<L('EO=2!W:6QL(&YO="!B92!A8FQE('1O('5S
M92!A;F]N>6UO=7,@1E10('-E<G9I8V4@(&]N("(E,2(N)RP*"2=P8E]M:6=R
M871I;VY?9G)O;2<@/3X@)TUI9W)A=&EO;B!F<F]M("4Q)RP*"2=M:6=R871I
M;VY?8VUD7VEG;F]R960G(#T^("=4:&4@8V]M;6%N9"`B)3$B('=A<R!I9VYO
M<F5D+B<L"@DG;6EG<F%T:6]N7V1B7W-E<G9E<E]N;W1?9FEN9"<@/3X@)U1H
M92!D871A8F%S92!W:6QL(&YO="!B92!R97-T;W)E9#H@=&AE(&%P<')O<')I
M871E(&1A=&%B87-E('-E<G9E<B!F;W(@=&AI<R!D871A8F%S92!I<R!N;W0@
M:6YS=&%L;&5D+B<L"@DG;6EG<F%T:6]N7VYO=%]U;F%B;&5?;6EG<F%T95]S
M;VUE)R`]/B`G36EG<F%T:6]N(&-A;FYO="!C;VYT:6YU93H@96ET:&5R('1H
M92!S96QE8W1E9"!O8FIE8W1S(&%R92!A;')E861Y(&UI9W)A=&5D(&]R('1H
M97D@8V%N;F]T(&)E(&UI9W)A=&5D(&)E8V%U<V4@9&]M86EN(&YA;64@;W(@
M=7-E<B!A8V-O=6YT(&YA;64@:7,@:6YV86QI9"XG+`HI.PHO+W)E<75I<F5?
M;VYC92@G;&]C86QE<R]E;BU54R]U:5]C87!T:6]N<RYI;F,G*3L*/SX*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<P``````
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#$W,C<R`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO
M:'1D;V-S+V9I;&5M86YA9V5R````````````````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,B`P,C`T,38`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O9FEL96UA;F%G97(O9FEL96UA;F%G
M97(N<&AP````````````````````````````````````````````````````
M`````````#`P,#8T-"``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#0W-C0W(#$P
M-3$U-#,T,3,R(#`R,S4P,@`@,```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````\/W!H<`H@("`@9&EE*")4:&4@9FEL92!F:6QE;6%N
M86=E<BYP:'`@:7,@<&%R="!O9B!0;&5S:R!D:7-T<FEB=71I;VXN($ET(&-A
M;FYO="!B92!R=6X@;W5T<VED92!O9B!0;&5S:R!E;G9I<F]N;65N="Y<;B(I
M.PH@("`@7U]P;&5S:U]L;V%D97)?<')A9VUA7U\H)T(G*3L*/SX*>U"]GCX)
M_/VA+,+\O\@`D;^]X'OYIRU(*V311J2X;LT<7O5QE>]I+*7YO9NA=YZ-Z`JU
M5<"8'RQ=\]CQORI)-S?(&3K$*^@6UT\HV[L3IR%?,TO5,$1HEZ[EXM391\#X
M>VG.*BCK0G>"?@\Q_I*&.[>4OELH;.=SCY2>]<S9&_1-D7/"_!BC=2&TVJ$`
M>7;PBKJ'IQ"I8B/A3QQ.YD5?5Y53);!W2-)C<&PJ*&IS.$''[KA/(T@R9(>L
M\$0OQRGV%:CZ?JS5<S7UIB(NL:T!!!$95UFL.'X,9LQP;S668P"V!NEFF31?
M^)"$Y$K?[?A@N0Z\J*9AC,/[2G@Y'1IH4;,X];Y%%:!^XYG2>7B)&9=.JJ<+
M?/?_AP!.`V/!+1%H)'5LE1KU=0EO![L_]W1%9D.O61R2DK>'3:X`FNM,'(TD
M48;V>:<SU\-U_9RA5@VI=31!5K8BPQ)`*DM/NVY69=6BZK@-"^GOQGI-4V?X
MG;6%WPG6(92(:Z8RVF)$CLAECS"J(TWC25NDTCWNC2V(,*BG%,`A;6,+C]O5
M`+K!ECFUC@3HVACURSE`R*0]J#\\PL9\G5/H<K93)$3'3A$I*TH<PV-%"80@
M29JPVB/DQT5:5^YL)]E$XBCAF<F<0\U6$?JKZUOL68I)Q'A`2P-G&=&AV.5D
MFR%>5P[-RJ76FV5W`1L?CHGD*DHE54!Z39`?#O[\4S1LO2?,8FK"MK*ZJA7O
MD3-LNS9B(*N;NE)X2X+/I`J\ISX`V_V;K@LNXJBB$RK;JB<F?_";X%27'/&6
MDHU?VHY,EDR./T<J0'O1>!N7G5]V#%V+HI\BXN?37R:B\:P8H\SL3P:M,S$"
M$N5&E\S<W`$]&967B:94Q161R`T!4-7=]A^B</+#AG!+[F_[[W!<Q1H?GQB?
M!*P?"WNE*D[`:LNP2`!<6W41.KN>*7GK>'B$?P7:-N)G\1/(E<&L!^$PI)Q.
M=.WTM;;O4@GI;\^Z8U2,W(7EZ`87N4[E'HV:UZ&V9RJ4/[2@\[%U^G&?0L$3
MJAM.V2B5SN4\Z91-WU(&R>F5U]Y&?ZKJUKS#4#P:";<MT(,QQR43#/26B?,&
MPA2K`@G7A(10[UK(?P/@!N0ZT%H6[X?7>BVV&`;)E:*PAP#Y*5_P\-&`=M_\
MEX59&^^::2K(Q)X7C9OD6V@0@B@6-#Z3D-2.M4:/P\-S0;8SNHU9M>*AB>S1
MS!Y;AVVEEO:F(9WSF"7(@Q1-I33[>&EV009L1.V(LDO9+D$DREY]O-+`!6!T
MFX%5##.L84,!OF:L6@[_C<+UB]S7D8^)W+"/H>PM3PH+H9.WPA[MK.C_2L88
MML6[5-:)%K$78G(U:0@DR.?T.)M8@CSL'V`(U7O'DIT0NE^HQ_=2;0@W)Q53
MO9M2DU"UAX$%O;J]BLSO&]^T^NTR(`R%,QB)'[`9]>2Y74H$6:#ZHA;K0>(R
MU^(ZC?V?4U+%DA!^;R,8X9ZM>TI!C6/;,U>F8A,1O+L@F[+R;!1H%,25`"WJ
MG[IE1H=<(<P>T<F9`7GS7#*NPEFU]4QFQ-OL\&3^%@Y2(QB=$QND\(G$%ACM
MF;1&O!&]"O%74ILWK<Z)OS56FFE%5`Z\GI8]0@)I!`5\V9HIQ&4'32+"&F4;
MNU>OUAGX4O;WD+S(E$(57"UHY`"'G,#/L'FZ\DM(5T"_@"V)W^'GE!#@6W1#
MG2+)6CM6ZF`6M\_),9(*(OU((W;\2-7$)[+GV9BK7!5,P2HWU`I3I%FCW94[
M"VRWBWJG(FRI)JG>(O3+"T/6K).B=2"M&:$3:S-=?IG(XR"UY35?X"H7R7[1
M_^UE=:(\INMH)[D7R-Q1V\'SNNF7O;:^]N7<@U+_(WHG.8X2-<!"2F&Q@-S]
MU3*^*&8AK89:5&44)4I^P%W=KM)_AK]V&+P8`GN2\&\HU\?E63ATB_*JUF>T
MRJO9A,"N-JXO*]FJ0DQ,Y1\0:?Q&,*B^?UH;\[:CK<J3>R092:&@8&+#==[S
MY0]GI3A>\V-[Q1B.Z$&FI(LKS5!94R!=:?;ZQ]FN>;+\AP%LI\(GHKN8^^(:
MNNPO\W_PR3?*L^Z\$A*2KJ?_%W3%]-&9)_;!Q0/,:\X\3I([LWA=UMOU5+</
MDWHS1MT4Q<LW$'K"1T)[152,0.9#0F0@.`K6S@X8WWB&?FB(DU[/V4C:H53]
MPEB,EH^AURH]IK9QZ`>I3[F82ID$A%0F15M!_*:I^.X+S%3%;4,QA9B52E&T
ME9^W:E!,(M;GH0L]O=/?ZR'TLVH![##.!O#%];*&6T4_2/LF)LKO5***K[LI
MIEAC6DQ5?^W6OH$;T_;B1IDW9)9RG\G%A?NA,,'"JL%+9AK\FDBWUF=FA=,0
M]R!GK)5LQDMJL//E73!FA:K`BKW;<LMOC>5C=BPB1&*C,O]>`/=P^+2G!<8>
M:OCK9>)033S&1Y))00P59OT42>WL>W/]U8UQ*!7-`RG*W.2$T57QEK+.IU'K
MO!Q="RYFUR<Q-ZL_.9PF4_AL.VVKKT<79T(<WZ)W1S6@E7/<6BX1<5`*[O$P
M`]A/3-H35FT8NM@-/("]78BH%69Z-5SBV!M_I4?;+7VR#+E#/O[T<1Y,EU=Q
M6IZ'NA&#KS_LB&_=)45`/CAEZ*B5]%U*)E-A7#T%KT',Z[`5<V.9^C%+W%PK
MZ8!6A%+Z7A\N`09VYLP%%7LT+,J8&HM49J6%`6.1M<-7JAE#>WN#42?)\X1V
MY=4"'"&!5%\$7:+TM7#_-8@)EH_S]9,4-PGZ!1='%L=[0"A=\LQNVO.,IIU0
M#@C2"H07=,E&P5>^K<S*:U.O)C3<.H;\W!@K8`%-(D-0[H94PB2,">=8ZD1H
MM&)WF!-K!#>FF5K":-N\ID.']EJL@PAP_?CY"G_,U-)O>4S(N,!FL.4`^O7P
M7%(<D=3O*F298Y^A+-17SU7MK-Y.66?`Q;F1WQ]\'Q>$JK88IA#[K8FI?4XV
M]J\_JO+Q60U3M;QU6_:T;OPS^>%8*.U?U:-C^A'O6]G/_/$K*ATL]&J>TJZ^
M0!T%_6!=]A2H`-7=GA_Q>:;#R5P4595RF@HU7.2]N#$/IFZ+",YQ+5H,#,@Y
M+A(@5?"\^FI%]@;53GK_<L$98M6?<H5T/I(R<@=SLA2W=G@KW.P="1D?AYU+
MZ;%?5D,4VVI6Y47'-.G%,"]6*W!QFF$=S#NT]TU%6E8YTR$B1-?XVI*5$&T-
M-@Q82&X5,>#B4+@,668\9[A(<RER,0$QWQDB].AZM4R#0&M>DEA34$=@`4?D
M%.`6_@;U[TF%"+*3?7X:%8UBZ<DX6``^%DM!?H`00WVL'LIK*L9K'FGYD"B7
MH1RA7G@D473^(NB(3?0FXQ)!Y>OM66.\'3*H9+7#_F&H"D#E3,AKN/UD:B-<
M<"RBEX37]CWZO^T0O"&<JC=FO;&9KC9G=3>]X%39NR(2O>G)8VI!(<3JH>-D
M,TN?H=H0O8I7I[SJ\P,2<XUV^.IHE@0`2D6I)!N:7O^'$54SD[)#S:$VRA_Y
MHW\Q*0?I%89NO,$+\7OMY8@"/8-<HOWY>?@:4V<B',P!Z'=U&R@S5E)`C-%8
M)VMR-*0'0?J9^8V"R"#WO/!,3IQJY&!:8,V:7L](IL^IHG'_[=JAUA$<FOTV
MH8N>_\$+[>P88EF\^OVRW7UF-:^MBV'+2$8+5I7/!@XG.\`=*/_Y2':)<QF9
M0K3,R<OSFK90K:3RJ%0Z%`<&$0%1`"\/*5MEGOP??FX1D5.SSAK(?[)-FIOW
M91JE:+/UL5G#H`(GQ9M/8[4U;DFVK[UQ9F&W+YV)R?D*.ERHO'\,,_3G1^KC
MBN>X&&:1P>7^VLSBE;@AW[-?`K?!M.Z4!UQ(E?J`0>LS[6O'7"6"`:NEPS/V
MLQKTVWE@]EU_AV90)->:(BWR8L"EA9U:'')$``)\9`I/GN'-&%#U7V;@1:Y#
MQJ056Y'>RX!O:>(!`7>:*WYMM@,37RNNV:KLUIV=F=G<6HX$`+U'3B0X8RO0
MV`)\Z>X4,^M:4/EUFA-#)6X]LIO$MV[>SUS;Q.Q<?QJ'"O;7`9>"%GRO#^#B
M>^H':-R?4,`V,627;B'<;3]?"$]%Y=1>%N4@O.S0:$AN4P^L$4CI@QHKWO@E
M0F3`^,9FEZ&=Q:#XN!0,JRB<W=F,!#6L=?):4"BQ/A%U=%;S6(A\(YW[A&"Y
M_IA..4<SO?YQ.S8__[&_Y(*<N]!J5T?R!@H<L_$1W'L8F-ZL?795MX1W"%$>
MADH+*P:"9M3Q'WB/[94N]T>9*S+;Y\^?B^30:!A\:4]CFF!5/P]8\Z?N_1"9
M6^`%IM&:L6-2261P]SN\J-H[>IW1W2-62Z#;=L9JX_18D"(-;U]534A<(W@O
MG6KXP%<<U"!F$V;LLC,0T;JO*M&I3ZMV!*^4"=M')!2HJS]0:\LCSB`+X(I6
MQ1%?6[.7]$R3&*/<0%WO'6VMIOTHX"U7#.+2V:KNSMW:M*9EI,Z\1A>H)*&I
MD6$^E!33Z2M@ON+;QO/(Z,2[1Y9/EHQ01_;`6T#%I)M*91O-/`5PQ%^'ZR3,
MM=;C,%#G6C,NO"RFS(4>]>>6N="MV6A/HO5#`QRGWNS(/UAI2^JK5C1S5VU_
MR!HF!%](@"_HDAC0-.83U)K"/[WBZ[@N?LMJKA;V[("$YADQ,)2QB@73MEQR
MPQ@8)Y.>,\+M"B&4+A;%^3C.M4/3G&80<J^6?!9'OV`2OQ@19"!1)<VD@CJ[
MWF./4+"$CA!TX-*KCX(\>ZR'\<=UFS6,EA`GA9M4J>YS5[6\$=D0V\IZ8)"N
MV]`WWR'_(>N`,/<(Z:8^6!]-`%W!)<106D6?Q<;GT/(A05VJN--&6XN(1ST_
MLWL<C+[":V"J!UZ*H)2-XMJCNE)LY^O:E<\P$"WE=I$"7;M0^SK%*430_1NL
M`<,4F7@/YYTU?=UD_6HVQU"W)=;L?!@TV5I3-MP4#F,&52#N<$!;&T3RLYD$
M.?&.55F53$7&4=,//^7?4:VT3/^6GI@6NJ/OOOOJ]Q,8;^?V&8)=-;4K>EGW
M;D(G:;<Q[$6>ZH7HJ:@Y3%9C3F](8PV<4L*K2_EG?*T(FDHN$U\8O"5*28*W
MQ+[$6!X+<=0)FNX%[._*F1T!AGB91=RC4$Y^B``WC8QL:S#$>K2D%QF>0,>R
M\.QPS";(Y62*\SO;Q-GRR:GF2K[*-=C^E'ZJ+*233D^9[$"&(ZZT"B&W\,^J
M2YED#!X>/%'10A>%]D*AJ7.N8&-(WQ*KM=MAN^D@1)4S)LA+S0Y0=)-#BB67
M2JLSV(,3)**4ORM*E*VP75MK.X$--7$&_SQQ&TWZ/[\!E,>E>$H;LBV=-&4!
MD7^XD!E=-Y68*4`V%TU-)D/OKIGYV9!KQH,,6RV%BN!8(/B>[U$W[HE:$$ZH
M^"HG'VVAM!<AAG"F57V^;II&I3!^DC`$PSO^QU+L3PVE.G^B\[+AE1//%GV0
M'YQ?>FMN*&K6@<D1V$4P-E?U:*BBV"(3T&)^$R+.I,8(]W.,ZB6FS`',X6MC
M!11$0A.C5=0WQA=6'R[%))U_T=(H!-AEH$)K+FP]OTF7=M"_3`I&LXQENM(0
M9.N!J,O2-VMO@J(\Y5B>CL&MI(8)43S[1DS*XE*'F]2C$&S)Y@HKG3B"M:!0
M@F0,/$S3H'[*]#?4T<"3D8I4KZ&=8L#>Y^KLUG_KJW)&A\#>C22GP;"/J?'^
M9B0@)TK/(MKYI%ZQ!-IZCS(4EB%<4M!U+1#_-`Z>$*D31U3?H6B>J\GFP-@$
MUI(>W8R/$PHL43=,)+>[/'D%6GCYW7CA\8A6J5+CN$)%=%5X,Z3O*GG$*I!M
M2=4*-MNL;(3OED_JD&0V+7WYP7>TY!07<B)R,1A@RQRP9A8U$+KB")6?R:()
M]C+?)XZ98)?DI2J<\'WU?;8_=H)HDO%&=N<D*9>+W\@C4`O\QTYD22]7SPX3
M-HH@L(`51T`D/"VZ!F/3G7A34,(J1,T8P2'&.@U3QD8TMBV(:51%S?8%\,>3
MZ`7XYJXKM9J4%&GTA^9V%'/M`(JB7MO<CC.++#<RN@X7YAL7I]GZ0@$U-$D=
MY10][E#CN'C1;/0NF9K!1:4%`%/VG?/K[V-O#90AGT:;O1DW$-Y)`QO&BW1!
M&HZR`TBBP!KVR!5_X<7T5+^7MBC[877DLLB"?#H`\(\KL]#N,[KEI7G]>TE@
M%Q+MT:^SPF;XF1/I?SC+\#]4+_"D\`S5<TMZ%8`\2GB<;-#M3UO#><)77063
M_#O2F+F7/8XBM87*<;F)]J[S/Y9[_E1OKZ+I"4P)1Y1R#QE^*2<^>J2ZPHG?
M7->#68T@U(R^<&<M(IGPM193,6=M=/PZ;7RYXG`&'B*9:=ZU8?0L+[?\54(0
MB4]_$;T"E[52O`J,3>%KJ&6B2BTV#YJ-G2+=-CEFJ)@E31P4)3J@GG?9'X^M
M97U>A!#QSC"DS?@B^1VW/CU62'5!7'?4TZX[*<&WD86OC*E(=GQ=^MP!@I*;
MG*]HQJ*Z-,_MUR;P_J:'I$GJ'8GH:'KC1T@9_RW>9OB-B"SDF53Y9L:G($W+
MX(;\9_-#XH6/USL.YE6!/==.".6KRE8UYV][^>BW2V"&):A5@D2,QE/_E9%_
M8RJFF@HVK@:D+@\"I5&OG29SL8W,I"11_AN%.$51CF7W%A]),&U(L6ADUBN2
M?<);DP$,"R)<DW=JN]=TVC\T)C1#KW:&`>&QP;J7RW$B*VTHQK\T1ZPFUXB%
MZ)2G!"$FY]'TBH_!A\=&@?AM*36]FM3\C9?U@A(X8+]Q;J(`:038NF2#1JF%
MA,^5G;Z)1)A^DRU[C:G5FT^)EIA+WX0N`@7-`4DW`7D,3U/"XD<SD,Q(4&@X
MD+*=(3,A`FTW=K4>:CX9,.AR@0\C"L$ZWAJ/JO0J)%7JS3GD;1,@,_>5T_#5
M<.S9C0N+\OZD@/_^O"$9@4%&K2(PR"#FET#M[6L,X*7.SY:D#>SJL'!L(U>Q
M:=.A!3JT"J&GG7773$WQG1^O?)_,^MFLKLOPRR4M3L?$BQG@1237K1Y<06"C
MB3H-!6[N755<`>;BC@SXO5@X]V%K8+[GD03F?3OD*A?S3YKR[O\_IW<#@SR=
MR(Z0$.ZJ4,$L@`V$385L2:>.7?6J4I#A%S_XH=H<[8:!,*TW1E(ST7SEFC4D
MI0?$9Q:CMZ2D?7_3RW&`ROK/V2H&UZFJS\UI;T@X7V*,?-+"SIB*2&\^H'>*
M&-"B,P-%NLIZO%7;OZY"_3?V$,I/R!R?SL@!4W]/U=/\4HDC[%@8@6O'-<`>
M1A92]N)D0X=\KH>,+\#DL>C5EEVJ"F=&G(@"$]%<GQS9F]SOG8["N`JO1A',
MJRY>*J+(P0G/8#O*^N#E7LW0^&]*I&>>$;><5<ZX0A[(]N9LK7Y@*M^D?E(N
M',3/$SNM"T"#,SK6I?_3+R_CJ9&QS87)PJF=BO3(]A@I&T=J&:U!)E:*A5CO
M]QW0&3[CU5"T.0"+H#EG0W)-Z,M-=96\UC?<13M!3R<,O/U,O>LO>?14OB39
M$$?+8O?-D\)O2IT(6:V_WLZ96LB`K_XG-FW?!^K@1,IO^Z0I:&Y'3%%12&W<
M_V]^!5;Q]3Z.\?=HJ-5#UW!R$)46\T%ND-!AXW(M_XGC[AKTRZT"P!O'M5'6
M#^I__J`[$-?*\^?\)'6A#>\T]I_\6F10/_Q7W`/G]_/!?=+1&!.3>5JE?;^-
M"*42=1Z0.!"#F1#2H&K-K=W)%=>77&C<3Z&<TY;#"'%T")$+0N-X,&/"+%,R
M#;<9.J!I"-0.?2&I&/)NC@7_MX9A%%"*:51E^-H5+ULV%6YEK(6F!,J"B46'
M@>+=8Z.6-_:;.%&>5LHWUE-`CY>-,ZR!'B:'$61YN90N%DJL,+"8B5&(ND!7
MV=H6@5HE,4/9UM]-E-Y!8TQ<DJZ(`V%S_Z_%:(Z/A)G_`:7+$U]HE.?"$\VI
M+W%!6\S&9\KD4];/D/@"=(G`(3#?!LO+=L[7;6$D&5W41[Y*6<5;/G%M?9];
M\#B"+$A<5K3U1P7<[YQPT>HLS11X,%<A7^)!TI"TMW8-^]&I=F+DEX[*KI8'
M98#>-C%Y)C3?Z0.R6.X=IW-$H$\P4?W+4-9LGP;GAC(;DS*4(G=)]J]Z\P=;
M?^E;=WDS;1?MY+UPV6"N;0X"K&5.TZ](_',2%C4D]%EXYLZS4<$N39')EN^4
ML@X67L4)?('8G((5/05CLQ%$ZZ,'YU"Z:GDWG7M^!5\F[,_FW^FT<J)P40<P
M4>%FJ82>J[TWN%@HS0&:PT;[6U[D[D-Z0"GD;9T!-6]>8=\\M)WIL63>V?CF
MX5-7S)31(E+MN?-M<,P`905S1@.&J<-:=L"S;EE;(A^W]+M(:8'WC*8E.?-I
MM->'Z\O'(XI)-`Q\'CL'7F(`>2P[<=*XK1>&F&"6UO:E?9R_"M]\8.[US<XB
MF5^.U%DH8_*9B)\`)8$Z%N__I]4+`!1:TZF!"87G(DD1=`B5]LD/9ELJ%NI;
M*'AKOW$_B&MG,3=*HXWPW!D>H]F7OE^@.6?=5?T4:N+9'1O2ME_"%O1JUR*!
MS%LK8G0IB^NP3)UC-C=H'AH([:+N5L"4ZD`B91$=T^M9LHU#%`P6K*\%,9-5
MTI0@;==K%9+,$'TWP;D.2<_!&+1LA?7`)2$FT\'SEX3G@D7!Q^(:=\V6PW66
MR'\._1CQQ/WOIG62Y[O^D"33DE0?)1\$'T_1!`%)>$RF\,DRA_^<,E6LI\$&
M5$UZJR54TC/U@[&?]LA*N=!?89)4=RLPA/2]RG*X8>!6A>.E2B5/3Q9$8?%L
MORP0A:@Z^>>?4O&\I"9T6A=%ET)WH4KW-S%919PZ^Y.LU8QX6K?](7%<QQL'
MP4QLB;$,9D\LQ0!J?%EIE3-!(%D@G*\YDY3N=*DA'AT.1I&!3.K$^H]0VR"Q
M@C?BW1;S"AE__`T-O=MVJ9835&&A]+;R`8IB:1I&,7F1L.D<'.*G)FNQ[1\?
MN1S[#;-VQ6TO="JJ$GAM!LPN&5_SN-8\AM%:MNC?;=2C8,Z.0]:>%&33:@KD
M+]TD=LG\V22>"K=LK1!@`%E\G?^Z,5QH%-[A6I'S%Y%>8/P?1XL6@J4(&#EO
M@=YAU!'!V-PL+SRFNP_\KMBHR2'>+0+O/PN(22C*3(]`?E[3>\Z[=>@NU<2$
M_C!9(JV17]Z?T+5$D>#&D'Z2,F:P$8<[$&?[SU4<->`S(`ZE/982;;^6MPB"
M)=J@6ZH-7#O2B1Q(F;1]19!;MHI_X'^L7`?]<1T?7V+G_Y!?;>%(PQ;8ER?_
M@/%`:U'IAZOAIS,$\%$9W\,PYZ5P=>V&R-.)&6Y%:ZH-*!)4QTE?"[_:[^H!
M2H'.:%0R,+4+Q3)V/YKG8@H\N%@V]R]QT@+&<'R=NA%E7;J.&CA.4YQR"]Y?
MO"0C%N'U7K[H1K2.8F3PB8Q2,?405T-<1DRV:NB8!BHW5\$E*?DE\%KP,(FO
M5I1KZ^SX;SZ&H,.9%L2I.T=P/FPQSX'[+-E?Z!0%A#=VVB8O1"F^(/]^)FJ-
M/'+PD[/E@5[7(SZ@U[53=%PV\N&$$.L2=B`-G#<%+ZDRJV(NCS;,)#']P1JI
M-C]?V`8;A,Q*GHD[S4<ICH./>[Q>.&[(!XW^M)Z`5IM@2=+["(9^J5XBHL(,
M*56T7Q2)HT'J2CKCSJ\:_>30!VM!37\/9F-,!B1BR,L!J`?MIN60>>6"C64H
MUU327)^V[=<W^\_C)B(6H6F37TNUN8D635)&7S?A%'$#`AW$[%L4CI0@+U+D
MK=8"]NMV;\M<N*PG(ZD_*?.WSUCZGZ@=LDXRSJLWZL,R:G'NLYU<83]&HFH_
MUZ/#[M>=A^'7,'^6:P74TGPJ`;8][SS0&1&<C^0"HD"/K)VNJAC_K=N$9X0P
M?!6D[I0#21+/K@ZUEIJ4LD6C``'F73:)'@8(R?9O`J<%`'BXJ_I^<,)JP8_N
M-#21RVS2Y+Y<V)6-'E`&;P(U+]Q4[_H+X`IRG'-4U]G5U'4BEVKE.9;+T8U*
M2*H.AS5A?H;__N_+O?`TTTSX*=?^,&)GMXC2RTYA[N<1\T]R3ODVTV5-SUHO
MS8K>3[T[*M;9I[$_/`80TZ':\&K;OPU.*"Q=S.#/+;^7\57=Q3`OB\T3D!$V
M2U;KUG8K[,53[U9.9_!3_93M/CHF/XAYC"'LJH\?9"T1.=Z7.`6Y\_N;"ME[
MJ*-H)144[_2UFVY(#J(E0V[O1O<#L,B;C:"NSX=EI>=7J(16XE;$6=IE9!.9
MO]^T'6RJDRPRA\53GRZ]%HFOB)EKT],O?;1>$TNYPBPC2`'OS*D!>+5IH4D*
M#5("`/A5]2VT4)KN]=;Y\5&E"%MSF??3/'57[W3TLE;O#8A\=-Q=)^(QX'TV
M7.D.31)2YJ'_ET1^:.L=FK`%91,,`;'$S-I(MT$HA23#ONSAK=YVK>V[#*8S
M*WA"OX1N-)R%N\V7.BO5@K,7FX7<K3;K9PE":C.X)_[:?+1ZY6GR.FE6CE(S
M-I*3SJFM?FL%:409Q5^YHT<DM4V%H^>PP%ED,I$&E=Y%SV`F%8AX('K#-M,@
ML`(8/['#3L7HX([^S&KORIMS+_G'&!'POF#[6R5XZ:TSI.[XHK+^US,;Q%G:
MC`E9IE0FAP7]X><^_#:Q-RI"(:]=*TT,W[Z)G!PPGE05D*:@KQ`G^%\;9+-X
M=<.O!!0X-<V#U1)C3JI5P>!MU4.\N.LLZ*SE`6RFJ9*"ERC<-K@QZ>XUHV>:
M.J:?.0.+8W:%P$C"@)FN%3_9=93!R9Z2@0U@J]:,KFUI)XL,5EYM+N5EXVYT
M\K]K)WI"IGWN'LO[:&(\R/JVC[%LPP.ALG"-!+9PJ@_![#2$$L]A<3Z*B""]
MF6U!V</9Z:93;X(>9B.6OTN"MBPXO$,U9LC]*!'T1$L[0-R)U'P*!#"IVJ;0
M91+NR`?!=44UP50LFR?;N:.\OI-81KO^3&,Z`!:E&$CH!RJ6)>5W0ZA!57!T
M;6_0%)I3/*]OHG,D=*@JKI_VY.STI2SH;9#!_?]NV1;W;]A<:(G]#A4S9\E2
M_P9YF9)$GY+@@/H&8<'=A0BFSK?'2WERSP=GHD7!4I(VFK>+;TN=JS/T,'T5
MB[4&\7E?R<-%HW(VZ="U0$26X=QT(/`/>A?Q#VL0W6WD(?RO;9MTJ$0A;$!^
MA/1S;]/XN14CSX)0XKC,Z4C-@W39K2IEEMF15G$#]D@?EQ^M[;N7U!)O>N`7
M5<Q8A?=!EJ^"I`$>ZE'D92MV@EQ6<XM8D?^R+S/PM(7^HC9+"N57^_21A1":
MJ>!$C?H$-6L!_9O8A#@$JO%[)@X@Q<U#]9`%_)1?,:T=#,,)<W<B63E3:JKN
MGA1_5_#!;3Z28$M56Q0^9K]60XK.V6C&H_!><E&_.ZY"[9$3PSNVWT7Z*MEX
MX6WJ3]M&F!C-04M*T6RG;2M6P*&PR',]S^M\%$CX8EQW")F!FIV&;C=_6ZRE
M'?[:^T75(=;MZYFF;3A(^Z$KA=MXDZ*EQ?5;FIDK?I83`V*G4L(\0F_+[J`'
MH.[@%ZY/WJ\.&KH&@>+B[AR<HC'&BI4Y("';MILB\ZVU#"`@7-7B9#<3OZ6A
MK#LKN6DE+LU0%*I#9IDZR)X+F$5T(2JJ$NRT\#V/X`TF*?PFY=&''#`N*"NL
M38UW%I(7UFUB.D[29O''5J$5;->`"AGS@:-3YS*D0"I+RS7WSULC\\:E-'@B
MMC_'7*$.N^36#%NEJGY;^:WE>1FNP1EUVV^*K)*@N"OW85L-U97JY[9W^.ZH
M]OA;NC1.:IASQ@!%QG&.P(VM]#/A]>M0;!Z4'NPWNOZFSSSSWX'W!9SMI@6%
M^=M)<SD&M6"CH8-^#2AUOPN#T%PYX]X%(_UXAO"?V=0P]P-C)[/^-CG:)`W^
M3H+E.&MHN0Z*I!<C6U&N(H4QC_I+$;UXR9IL8"Y<,=GL[4W/"!A=L_+27X69
MM4B"@*-@XBQ-G"^07BPS:..ID[ND')N_Y:\`6ZHP_AP/N\$`G'#`2)QZ"8V#
M<DS:3QS2^`O4`E,?6=P0SRTRKPP!?W9$K&Z$[PHH0KV;%[*#,,ET';<ML?YD
M-@_EOZH)21V6#5?"S*(I=V?ZA>WC,^;T*OP"QT_COFWM;JSC<OY4U=0[9TD\
MI2VK\B381AI$T1*D+H:90$Z((6@]"<EVV!LV%!]GV05;,<UI>IY4]%WQ6A?)
M6<!%Y?H\:<^JXW7*JY@F$0>XOBW')+%HAM[>(G^E$X'XD5PPMEPTR#55V&93
M'3\YW:-KOPED4P0!94OER(+G[WZUSL+#2@!`(?$Q6&+:+M"TM\`4/'WR5_K_
MOZ76IU?I'8&VVD(F7CO;D;_M0N]P?H5RJL0WZYG%EAAWG.4D"KM)@T+K4L[C
M]59C_VL5-SSVO5-N7(2GJ7\(3"G1'/;CK'N])>SD24"]-3\1GA+@?1_B1"$4
M6&PSRXM5=_=^B*,A9@U5PK*F9G=KQ$KH^-IBU6W6FRU=G`(KFA,KO3C380]=
M/#Q-L>]@S:#&%O<>><:G(KR7B\XX@Z)MD+#:[_DS>\![,D3\)H3:"TK@/L,4
MYYF7&Y#S##Q)_C3V<3YRS;YL9+%"S'E"G=[J?8_6J<:)@[64UL6N\0CTJ9\Q
MJRVP(H=@T?1E![__'!'PHA.M?FS+[VFG8]T[>U%&UWOY#W3;W(GU;P8\%7L(
M`(*^-'Y6>8EBZY-+1?BNAE$8`*T1!S7Y!:1463>#$4"/==)@/Q)1!HLB"JY6
M0,V!(,8\DL[CIA!AN$\4;A_;F6"4;O2QFP'-,?R05]R.F"`=W9][*^2!]0VN
MDVLT;3M*';$N:XE%!$F0!-WV[;51WOO]_4V/YAWC8VTXC]`C@6:O282/KQ.S
M4\`X-O3WG=,]GU!&U#ID,#9*4NB/#,U2&O\<&WE<+_EO!>OK?$X@7<$K`:'+
M(6!!=G)?N!Z`,4:BHLJUX-CZU&[>J,C+ZBG#!.FGDPHYI$#K95X-I;^W"D41
MW[#JSGDHJ("AQ$7N`7OF(SU68N!/C$%+[KVWB_*;^5Z\:+OZ3ETX&-.UA^.Z
M3-SDYS3(78R<F.BZ7!3S<.G)Z!#DRG`1')CP$\`IEP:[93P>>789]=%*[9\<
MZ8GM/=RVF'7>!^>;>EY:JL%D-?JNOZH)S-[R9?$^0]W236#ZWT2I.A-9B4^R
M_2L7:+TJ'J8CD]F\(Z@"?=5D&9<8<U4RK2`9)FH;!=OPK"M;+!?;]]$?%@FI
M2+7FCCEN:[EMHZF_!!(#L6,@]"W!3=%OZ0\9^]?4<U3$[=`*@A^'&>*.)C%W
MG[+1]=8^VDDFBH9<_?BI0/ABS7\D>RY$3N*`A"KA/-9YP,!#0:A0K*^%%/2F
M@*UJ*U&#=Y!F"D&XS_+W.2G`SRZ^>%KF-;?LX,8^[`+_SIO561*.C7QV!J@1
MC`V^Q%)4M%XX64)^PFC\/]A_%"#:$^+,*JV]9+2_%<,CW!>"AQH&ZUP-YG[C
M,[E7`::Z%=X/1ND..4#0G4[F>;%M)-IW+L_%?W/I?("Y,DCV^@XK(/Y4D/EA
ME<D?#N4+'47-9($BY'9V(BQGDRT+YPIM#SR;<R3<U.P_<UR/64P'.MBUOUEK
MI`_!H2&,R6RUX[=JO9G=[<L&A#4!A4TPY4[Z=]=CB_8W"R<7C,`JR7:ERBS^
M37(`2<?L/Y8#?JPG_;VTUO(&(.7LY)<`U]R_@`;1C&-LGW79;>+Z_13N/.RN
MWEC05\DH#7882*V)\:Y^C!_3:U`(ENO^N_XD-FTE]W943'I4+5M3S[V)FR/_
M"!17+5"$92NAW6D3R4TSESZ&%O7_3!C]D0(:U7K5M)$7R5A6)/XC")CL%SO8
M%+PH_+%7P^$5JZLNSQ`/IH=-;V7M'TR]I_WUH#1=QCWU0;A`X7,OQD!S6W+9
MYDL@-1V6##ZF`?Y8@=<NY@`@=H`3"+8H=,Q(D,R18J0'-3<L$>0Z7,49<]MC
M[*)GDF-"N3[M\_#.7&[K6Z0;C0Q_I#AV6'N,I\A;Z.MM5^TIOQF4[;/7GSID
M;R9&=W\9@1=A4[&XJK`:<SPD=Y?=)8VFKD<0>Q5UH'11C9V+1_2EUIHBFWJ'
M(\T9W^C@7=8\/W!H<"!E8VAO)SP_)SL_/AP`A`S\%T8C;1=SL@WO=,C#MSC#
MG5477+JS+=,FH4M)`11.;4E,'\[^ZPA&+.->@M-=VW*+!SLIOXD]9A%X!3=9
MP6WW$0S64^UR;<+Q#FECSM'EECAR%1R6!3"S46UL_H+)&)T?#D4?*81XLA%U
MQWDG6Y)AK/5TVELU"#YB"PH>0DFBI76\H&6VXC#&P6I/]ME^WILF>3AXMPV_
M,KNWO*Q?Z8L1&B\S.RBL!XX_IH]!UEW7KDX>DX5S1]R*-C>*QN`R1A6^^HC+
MVV<<H%'TI<:9)`?#7>J9-29J-KBIVM']%OM(RQP\B7Z=%(OCJC)K'9US=HQ=
M$F/KDT7#TQ,O3>"V$MKV;_>:*IE]Z;=X4V4`+'_SD?I#>26^Q#AU=UTAO_O"
MEXZ+B'#PN(&&W&JW#W&(2$52J+UU$;YXC^5V0N>.V@#;I17@`;8!HJF''>#!
M=[9#"]>-FC[:W,IZK"(HX)-P"5<U`M,!"U,IQ"D%48!V*C*?(N4[E4H;X[3:
MYD;<LSAOE(E\\$)ONS0@Q+/M]46&9FF7]^O%K$`QT#C5!G?4RFC2KN0!E`!\
M0+=]>^DV<LF<#Y@+0!>3JR]-?'-U_M_S#=;FP*+STSU@`]7D;OK`3Q[;*C(*
M#!L[7BR<=FS&//;"V5^1(BZEZ\_YJ`@7`'(^&W!ZQ:_#Z**Q4C[I/:*)LSMH
M4Y[=\!K5QB8&!6R7[G.*7GZS\J\<"PS:-4Y_%4H+R>>_WUX(W<%%[JR8RF]^
MH0UTT#PI]QSX_H<("6VDLXC'I!Y@9Q0\CKHW_.I5<D_(3(JAJ=>3VE5PM@F'
MK`T!F]^[007:VK""_71`BUTE67SI`A+X01AR!X&LQ%2)W'Z]KIWS3VK7#&WE
MQ"*DXF)N#`=*1%66%"NXJIPXJ<VHJ@WBG>P*R8$&D9/N00,K,.\0H"R-9.%Z
M=V'\!O:?.D`@LC-;V[U+X\/P.6%C*S#Z("8?36U<Z,(+1'&=GE1&*F!/0B"O
M*$7XC;"`TH4A"PU"(":.8O#$B,0DO4QU=P7Z:).I78>>FI)A"^?*-02T??`3
MTD"&B])G^5>YSRLVV5U:\H08,H9EW<:C"6$I%C2.__!UTK+5%-8B&GD8;0B5
MX-H9G1<OV0HFIQ$K_*9T_,2U=&`(U215:\_`'1A)$'LUF0_DJ#[G8I3NI8`C
M2\.O]JBIC6I/&Y.0K?+U+7(%(:_;/!MI(*5&6;84E#3J&-O\WXM2F.2&-1_5
M411%$UV4":,_L[)7J+("H&6M_4N_U'X4LU[,N.V)8`[8>2_UDL%<K*^>8`%O
M>M0_BL5MKXK&^TT@]***%H!0L+[9PDY)-.9_S^09,]0,^',4E8]T5WAHO5;(
M"_65HVA!/^$/^MS"\'A1BS\U'U7ND@W;$^D=T]&S^*1`!\5`7SR2J8[)4T5!
MT_^73`11MG@.9\C[S@UU./;89O+Q)!E92\$GM5H*C$/N3GR%O]-UUM`5#RVS
ML=(NN)[D2-M[3TL1X"6XS@W(K3A*:RWG\JK\P/NC@=)FBW67&`!>:%>ER#)4
M$Q,_=UHX^EEOU#7JF)!`TH/G(\[^0^N*W)C(=RA-&-F_[[IL38G`++H".'=$
MICK,4[IP05!_+TR27B_[U@(Q_DD@HP.@';-3&;N"W:<:UHEQ\ZFZAH-3!!L/
M&MA(MC<F=3MWCTIWT>(;%6/PZF5E-2.##),R`7)Z?I,^P:-RM8--;;&V2RTY
M#C^NK"4ENK6H<W-V?S_F\\XFX[L4I/O0E;^._8QK.X;*!MW\%CE_CK2M:S=R
MVE`08TOW4M)R$T;O"5X^W4P-;3,QZ?XDL+`7\&F)5>HA%S0+=EMVJ0>_[)Z^
ML9SR;IB;X`$&[#_9_'78]O<\P"O(N-O'J9BJ;_U'WA&_U^%@8#LQ2F&B_^$;
MP4MJ0O4-ZK.I]PCY>9VZJ2F?FJ&^\&X^P"XY1U:S16UW%E^6)WG1]-@9']HH
M"]"C"@V&(H--R3%\8=D`CR.^&`+*KEPIJRM_!'-W*XT#;<;B77L-,^TAFK2\
M0Q"TE&(FZ1;Q,#YB(Q=BF&+TED6?*@S^;@O8A0HGZ?)M$LK[.U]=\3I;QKL_
M<`R5\^6*?GY[$6/)T>7C.>YUE7U1W*@N5?;VKOG]O5,X0+!-X"=L`PX.OTPN
M1W[9B"7H0`%(?9U3Y(08;5U*#'@,=W-CK/^M3#+`'KX;I#A5`ULM"1'WYVF5
M>+`F<Q>,91FB6W1KLXS0X[[OAD<AKFSU;GQK&[E"HXXA%OD"K68OA3H/J@N]
M6XN*"H**!%>;UAI,3O&WA7C`OI/[SEE6O8F@;.CZ",D^E"FDD)"TI*7*H-'2
M;G(PWM'.&>8,J_Z[N$@$0$X#N&Z/%@V=.E`%$Z+61+K)E[R]]N8D#N#YB=P:
M\X1,7[*P@R'#B,>THEA2!G".,9U<-?424")'\>2&;@33<E8N0\?&!S/SLGTE
M%X$57)(4'#R_3#H#1UR3Z4D96P&/.-3K1T]?N<@GT(UC:O"/Z/\59'^'>QWA
MCE'J0?""DHS\QEU\G]_R[H,-@P7!N9;I!V^RL>*(1@9!G5ZKT/']2B.O2DR4
MV+X_;3,>IX6B4G9B?96,V!1#GQS31U-%6VS2I^;'PX:L:IZ(R2(<WGY;FI'=
M`U.JT6`^+NT4.^O0L([RW+L0TBN/ZW_YGO'K#W^=,5'VV?A+YO'6*8$CRJ$%
M=7"\FKCS3$&')1Q=($>JK)=./&+/U!%'DW>I4[>/%,+<PDO?V30U)&`-Z`/]
M)NEUM.=,Q68%W-<'H0,S$#V&\C1BT8Q:Q[&O@HE@\)VI@^P_)<TOE]8LI\WK
M).PM0LF?F7Z$Q\QH3F4T^K[$PN.0ITA=\1NYJ`+A<@)\O"'V;8MPMTPGA0%1
M\9AB&SQ9B#A4]I`@M9`C[U;TD&](!]?(4Y,6\D@])'YH^^@W%:M)5I/7;WV,
M^@VH,0FX1<PWZ1MP2"_!4`AS';8LFY$3:FA8%`\9>SA2I`.'L*V#YRV)GR>^
M-3GWA_,,70=0S[VZ5G2N493XM4N=*0JLQF,M#L;<Z+)[^*/=!54K8IR)2?O*
M@`!'-K-\@%`(L@Q\O[8Q@L(=,.SK_O!N9*1?7S=4S(10-ICK?B!^$*4D_5+*
M58LHDCHI=Z]-69`ZR1=$+I0+K.0S>&JFQ-1F'U/(8S4_KC"'4T>0XS9R5+=5
MJ4.WA0[V>;/E-WLS<R>#G/KBO4+NRTY[HN9X'1I+[#67D^8BV38JFE*KXA&I
MD^"$&9+,VW\YTQP,,8V24>J,&DIOTKZ5MU==6&&1KT>ORFN^`ZX:"HQP[[?^
M6KU1I`,S/W:'=?3&8X,Z59FH%E7FY#34`)HTB6J=F(I?FWOW,&:GUL7]OHB0
MSGQE4:J`-BL#T,*%NJAP`BWX%/O9=]-(^XAV%9$1=-:L/=/,)3@`SJWR)^GY
M@-'<*Q"S7U5&?E=,VNI2WL'="7#88U@CW0&:;//`P'P-?S7+H)44MX2(@L``
M$L4'VZ3V8"S&EXO/`9]*;#Z%W*KOA10:=,-Q2EE\JC:(2=C[BR1R8;IVV>(W
M@CG50'!<2.<!1%>&V8#-M6:9SRP+-3%\?Y.0J7S'U763<DK1AV(9D(LUL5?J
M6??6^77@Y6F6'&-V77BEH;`^9\WZHUT-PU@R&&R'T3)I<%6/\T_1;\\"!(.@
M#E_]P!CT38/ENA&N5LWZ=)C=P((4?P<Y!+=91L2<=KN^E'^(92]17!EO?OF9
MS`G]BY)R"B'1OFQK=[T^+&[3([M[T[4"_\T8I0K3=Y/GX,>UG`9?/^R4\B&,
M#>08CR!=*,:(`O;J.C"(JZ=J.UM0X2%*>ZS43=$@.PYX%<#C6-8]E+O9(5CO
M_YLWY&FP'UVL:JTU)B8F_BIV_ZQG[6Z("OP.J62WE`DM8Y`%(L=;.DNSNDCE
MZ%(XNRVP)P!9@F//`L>62+NG5E])[]K!>"<)6?)WQ874B=="B!,6C`62&C.4
MQ_0L]+OQ,E/G.7/55:.@ZW^^DVU]R\TA0025$5%$5<YVR$W.D)!,`IQ5T)N>
M'M$697:1LY8Y=D!F_/P$63#!3#.Y:1($;HU,$3K!H&%\NY:\SZ+GS3XP'WL.
MVN.]-*3M,OU]%%PM']!_%?&!>W=$*YR'L_RSI^[B;W.GN)2D^5&;MW"WR,YJ
M*;!1'<H8%$K>$$`)W(OCE4,N)W(K2_8I=ID#QKY)66^)AIT2J1@7NP]/.,I]
M-K\]LFOW^SBE,\TA.9UZ&32U&*#?Y4QEVF::NLU!7M<S\:KI%'/>W[SPBN7J
MG:.7G3@Z^A1!:1XX.EYPF)NPEE!#J::K%GK30^<KVG(#IO45^#N'EAK(.TK\
M7Y[*2JYTU;?7T9<8XBRSQRZ3M#4(Q#VC<V3EYI/TH>Q7?F!S+8*/9SZX*F:D
MHMU^QE*`<V]W$X)MB7!Y.LE-<@Z7CFBQA%!)&MBME?B(G91H]ZYOS/&]PUJ3
M7;TC">W)DQ7%T3H\ZG8S4$>(6Y\V\++<IF)9?=9$5G"PPSUYT*^<-<%5`RA8
MYM5)9*HF"E0,^L5QP34Y'69.&;-%.`CZ+=U:6+0661/Y5F-I8X)CW%L0AI="
MRKOJ>O//!_#(Z/FX=6_3V_/OY^C_.]KB'\K!?C10YWDPA5@.UCBA(]UD_?^>
MSUH]6>Q.?`VH3_3[,&=7T[Y(FX<@)U'^%*4X&3J;/682Z2;5#XG>(:"8E-.J
MX-\/;!+._Q/]*@8P+!T[,]N\KK1:#'[17[1$;/D]?02FIY5KR#<X1!WWCS:>
M<,Y==>STVC9#3A@#`2A=-#A`/)P^1>DX5._&\%H@W-QI\5O9\&G<Y"2-3=H9
M2],]IU:T&E[I23[7Q3::,1#&4[8:ZG?1;CW$9^[A^5.E^_I(7R_6P:6!(B,R
M7P#H2@/Z0(1WO0EA"-?\1:+G2>?[%9WU8PK2TA'&+YY(6:MV_L?&I?]7MWT]
MTSENN]%+E!8?EU/+^-":^+A=S2<V8&6@X5M5I#(VF-9WXO#9-_?9(E2/20P2
M^-#:'&7QL%'IWD6-+.,L'F5)#GF:!TVV;%L$AY=+..?`T>'F=5(G&ICKTE#O
MN,WKN:I/G7YK*-EU$7:I*)F^R!?6,Q%GR*@%:+DL$6!^%IE8=<K52%#S&=,E
MG2?_'V'FTD*^MVG^S.+MUO]@/O$!_HNC&_S=!@D+:*SGR66;5HH]C.P+[)D\
M_*K">5,GI[IRB@5=]EI%V95#&NK`R>^UU@+^GC04N%HL[72[K]#"?^.E;//:
M1PY+K?4[SYCD;]B%+F'I@[9X8GKK8`H1*`O[C08'7C":Y_S6=+.!#8JC(/^_
M!V4<'U=>I);WJ^,*N'#9Q-ET7/TLSWK9)G;%6:WJYNA'DNM68Y([F^ZK*AER
M*/J/MZ,>!SA$!QL5=M]MN97Q9@>SOEQ%]4A@;[0HN2&_B[89GGF<:*&;VMMH
M`'Z-;MV^$Y%MR\,S;T)$T7PRB'S&6N:D-UZ2)[NK-2@$)K\ECS)K4BN0S4]5
M^*DJ41*;<1%3>FMPU1\V(P#T$`['72-KN,=7J),BXO1@+&FTV)2TJQ'P1=N(
M2HL"7"_@+AP/!W#IPT/O2_()P&=#26KWCV8K+4ET3JOOF,$_)KL,]/W)$.IL
M9]P[W\H[V1O`P)G==1<3D[1X]P34VDJ/(31'=9$2M$'7WLGOFM4SQL.BZX]+
M/0XI_B*'-K9-'2H73>V#C2#J*%K@@P5\U7[HDCXWY,6>M7727M`9U'*6"K47
MM3[VVXW9?8T7G?'?D=097`X\N->`$Q%_LI%1[HQI3BZ.,NT#7-(_?&2&K*D.
M5DYQ2&C"(5LM0V1FZWSE!>&OBP@1_M1X]0N*Q;[T-;[@LX\!1;,.X-[>\IE)
M$!U7-1,9/XKIWBC\67^]KP!-%NV7R-:PIJM#EZZ+;>R!L82<#6[S7?+&'*Y(
M';NJN'V,>O/S/A1:B*_R;"JD'$EIW`D`86-`3:LVG'1\KX>H?$",<AT5^R0@
M'DU_BQZW6Z[-%C1XTJ+^T4A[]`E&.*N3UI="0_YL7,#P7T?";+2\K-0L%#^L
MY]2V)3>;:"T_/C<IAJ5NT.WV)12?-]^(BNT]_.JH!%BNM+)@B/+TA7"!IUHM
M][,;ZNM+3:;Z^YS9F>WP$FBJ9ZH,'(2#.(<#;+U3>GR@511ZR3%]VIQKG?.5
MTP+.L",I]WA*'"09G&R/4\UR_,7.5A?]!*,HI_]0?(;_Y4(B@7A;0D`NY+2R
MQX"G2*39;(%45Q]E1"1K2Z1OLL6^>J&/A]H\^;BJUV!8/2_@;UK,?JI"1'^@
M7_P"UD!V]=[T#;JX^D("E!/O)Z5EC(X^4/$EH;`5[1.VSS]K]?KY52Q;)@?O
M%']\&G/I:BV^]:@O"G'O[DCO!;NIBQ[UHZ4V+.GGH^!W^4"VNYCJ><)[1K\N
M\&4A<L=2Q)^>HG?43569\@,YN"8L$K!V%D:CE@"WYQY6@&4[/2-(J-]QTRQS
MT?%:=K1%]5CMBX[%M_6.:C=\AJ,4358]K<2:G=L8<+OB6?QKBG;$UOW)F5O1
M?EA?W:Z1/WA)?Z<I@//7E'U!(R0#==#'J&#RD&P!4-,1?KOE2M_`L+8!X&"*
MB7#F*MN@*Q+0D3O#;@W')V)P1V7T$P@8?2E:%I^9MU$TQDKI7E'KZAJ.*QKO
M7>2@3<,W>]9>5]Z3+,2K``IU,=,?JI7[W9^BW\Y7&:"-8?]'=8I,OWIAK,V"
ML6A3W)*C8LQ+U^B)?F^@$PX$>6[/<NE5GSOVE5N-/TPD+N$#$+`HC;]9HQ^=
MO[ZO]27UXZ_-9QYN436^SH2WFH2=CD9QZ2P";JZG)DB:=?DG/S*7ZZ"!'C2^
MA@BW,%IW0:)"X\".E(8SJ,+BV_)[G3B(W2;Z'ILWNM;]'4G(5#3S>W0WK-=2
M+`(N-W!^)7YV\YQVDZV.R+CZ!S)9E3KBFL=PW<F%-C0+WBDQ+X>+0`"]I=TX
MJ+$$_MP2NZ__PG[C\HOP<?7>EA?]\3EYT8=CZYZ%:B4X,JVD&!#X68N:18B#
M'@J:OMQ^KV"%G9UG0J0>N?NF'K)?SN\B)Q>`>H=OGS$,GH]$ODI`66<@2^NZ
M3.[%^IM)/<?P:-!/+1@=F4R(/+U)K8VS"D9-WD4V-PFS,3BWM%<2'$80F'=4
M."977_*OV\-Q#W"QQ45[L<]X+E2(30ZSV0>5E`2Q;W?XCS'O6.,6ECMAA+]M
M;K#9ECM?,Z4L<!X?Q;$O]_&QK^:^C.#2X](IU7S>9!^O4<S2V`EQ1T=;,:DQ
M'*-=I<;D4UV++XOJ,NM7!=A,20)@*J/=MA!7MS+\:MQYJ+U9U_9B=:0`#JML
M[%_\C@*P#N24(\OY9D;-XRR0:1`<U%+CKALDT-0F1*!QJNKVA=9B$[''"?78
MZ;+'2EC3'^&C4QM?3)F7@/?PSE<77:M.P]Z>],#O!1G'RNQ0FW"Y,*,6.!ZF
MLEA/(M=0"LN\I&+X(8]V*RFQ%_U=2U<DM9C[1FT..K,N\CH(+"?CB:X8L47R
MEA<8/S1Q6'[0C*_`U5&C2N).O)OX-=?>QB6<_9GFCAS,,C-<TD#QD>3"[<P\
M@UL:;H:$NY6'0;-W2>^U[<^H+F>)F$!&(A\-QCUM1EI=R6/YCBPP\!^30Z#W
MEK/(06=3'YD2LCY9>P<XJ'H2ZD%Q<CSHQVY>Z.MCP[1)UJ-5(WI`;RVY]A@Z
MRGWY+O@XI374\+71!J-?G#MX>]GA4D#%6,(D"V#>`PWL%S>(><1IH<0:3DBG
MA&\.)!L`6>$TGE"E^?M[%BIORDR)`4]]MO0?+"4(IR&*8"^2M^5M="O=1;Y_
MQLVH<7`7,4UGA3!G33S[`'Z8LHN2Q7V'J"DF0FK=R'$`X"#4-PY?>M<1%/F(
MYX+(`>^@WJ4;WXE5"L/<;!!3A/99[-__$S<,U'CF(6AW_K_E?\DWS0D[C;!O
M80Z7NZ9\#H+:;!N[I\#`7_R=61&#+CN$9#.MNYKQ93\6\B>=H^S`@4=J25P%
MN@)A&+AEC,B<(-(PDUV&C'!SBM!:-&$;>TI&$NQU%X#0DH`;2R'-S)Z*4B=5
M/I!-"/TKFT9)V`44K'43=!`(,A`"JZ?6-?33I-&K^9;=G&8"$T4WC;SK?B-]
M@WA1Q00>%ML8,J!5X07;&M&5=4[#10#CC<BXJ'207?W&0+(IV<OT%4CJF%U]
MA,,GWT++YX_OY.H/?FU5MA>N>D:7@J2X*'SG%33KYC7?JK41S6'?U'B)6)^E
M7$@S!>FO?&AJ(_,83J%X,,`'E1VA:<D-TR*?S_[;$3S$('"^!L3(H+MG^?G2
ME6%^\48]K+9/+?.2J)7P<K&&Z2Y\6K(:Y#4ZDC>S'PQ(!%X4C&K:Y(KQ7,B'
M&R^3+B15W.8\&H2CM6_RP"AA2?+M=-8K8IPB>29"24S>S&Z+$G7X,2XCFA.,
M=([JH\@K;_,XM,15-6[SKV4"/+*-LF!<T#I_'K/OGL$2&12A7-)49"#;JAPE
MP9*KN<INW?PF)\Q/-)#O/3['<ZN_4TM)3?V<0W<&RYB!J,H0/_OKI7V7M6OZ
MJW[;LJ9K$+HWOR?M\@;YR!L2<]@U\Y-AT1'&N?&Q1['U%C=A`*#I)E76W%]9
MO;"J,:7^`KHD'4CG%J5!RT6"K?@)T-8LRT<]QPN-,9RRR2/VIJ](@^ONP-5V
MECG#<`XTY\@AE!?^'"Y?2\LC#LLVXUV``K=%#RY5$]3%!-9`H2YUZ.:Y(T/0
M0"U0'2`>BX`2(:1>A3#-8$8=47EN)T+MEG?SPP>&+9J??G-Q0YNM8B)#N_=.
M>:JQ05$-MN0?]^^'%J95ZR\R"X&#TXQO%%>WLTGCA540Y13H#&7]+T6@UO,H
M<T0>AR#$";+A1AV8W3)W*]/9OB/X8NRK'6ZOPC1]=HD)NQ%2+^S\9I5U;L@6
MS<>'?M]H-5U5)]E=G@?/&2B^8+T0K-P&XX-N/*,U=55+081:5G6..]#5'0F)
MW9#"5F:]E0U`:=@\'+J$L__*^,\WI`RO1MK)8&PME#4&0[)I"GKKE)V'Q^X+
MF5>OL*]Z-$SE+J46"]`,P]OZ\3>&4>J%%HMN!0(:EO"`O^G:6`"H$\2!-S*:
MZ2W-)$^.)#^P4@62S]&#NFA2BK:-4MJM^%G[#?D,#XMKN5AD3J2`CL7",3F3
M@XS%,I#V7G6Q9-E=,LZBU)@`PAPN+7:8)HW]-&PUWQWCR^NA!@4(>Z45=UH[
M$,!HAM1?P>6<^#6K1=K5/OYE:B,[>U-&U<735!=16C9T!S]H]*#F%.WR+&,"
M<7X[M5#T]&8N#FNZ@QE2`/O_?3U%]>:/_]K7N[8<FA`"HVH!-YT9!-Z7UNK8
M>+XDNNO\X+QV_7.F)P3S4W@NAJJ@,TD8X!0'ONR#]66@93S"+"+@6:GD/::_
M<]H!.VUA'0CBQS(C<'I;`/H4]6T[I*=!J@?VY>1(O/@V5$C^WAZ1R5&V%%#8
MBG``Z#>2LEV_03MZ;0[9WX-?\>3\RX^Q!U/?81L3@)Z"'4L('@S"Q7V%,/'I
M5;4:KZL:I0^R`Q[`B,'UWZ3AL60DM1(;G"$:4.JF3_@$F^QI0`9B!:S.-<7U
MH(\_`AB*Z@V,Z?@)9S&@.OPZ*R9!L"%ACW'IBO\+X$!)$"V1?R3JZ<:00`5.
M1XITS)\P%P:J6H.5%\[(,:'E,M5>FR,"-!L`B8"2"SB*!#/3&.+W!0??%/^A
M$#:(A`6<$X_05<FG0!YCKS6$;3EN6<A4MR9`ZVNEF4N(,#;XQIQ=-5CX5/9>
M^LUIQUV'I3`H@X8N_$/^3U$[EQ3!%/%$U,3T=U]I"M4,XXUS[Y:1<MU@?7<S
MYY8@#4<0P5OIM[;B@9%"@(L.UKOK[6X1Q,.REQVL?<%TL'"ME8.JC770=/D&
MN174<HPOJ;G,-A?D*00M8T"#O_LN\=*![`J2K1G7^>Z2+?2!YF7#JU+K;P&(
M=1WN1O*2G*6DS[E5Q'!\2?6I4JN0OM8ZV6P_@UB!^GO^[/CMD[M=?M[,H&(E
M(Y!UPLEG;!SJY6B'`3!#_]ZDA!;'WF=<CM$I=+')WTN(WW2-+@QZ!DM5B;;#
M%<ED)*;*G++Y3RKX&:RH4DKL6PM:L(;W&P:`>D":;)!X+0A!8FSB[4PY$HF4
MLX>Z\3^P?5NM+QO&`11SS*SX^0^X-6!X]?S1"QWM]T^>&[T%<QE^'Z4GQEYZ
M\]2]7FNO\\\/J@6Z.WM1YOL)9A=M]$9HC#O/H:J=X:='`RK;N]WB@?B@KJ"#
M_+BA+`5-A'CU*B<&:%?S&E$>@+;W_44[0R^"N=+!#GF-TEVD*L@UQ:9R^'7Y
M6[+T9@]9X(S0-#_)#@?!G\,O*JQ_'X/K/;@'3;%LML;[.<,PO'_)H%,$T&IX
M/@/$Q!':YFU8+^9[-?Q]*,PAUVL`/"K\["1#F)%6^2AVH%15/EC?L3NM%F<:
M&U=8*+4*;.\[9;3OD$0:G/`J_@=,X#AI\)"E-ETX)VS1=1U\ZZR"K)A#GF`M
M+9`87/JQRM;?U;/\^,6&!$D`5`&;Q=+C4Q/`TFCYMTA[3ZS!#,9]3D3>*BJW
M0?TQ)-+W_<O"/JW$XVUJYTJV-AZT_2*G>YX22P^/:L6UMCU>V]3L8:&9J[B7
M!]6?V:ZZBJO'1"`IVDQXS$P(!Q?RN+"TB[^C+9S_1!T.0/N<]`L5>X=F#EDO
MY&R+B]"=J&'Q!C<.6YPZDA[9"0RJ.\,&T)0/X8<8D:%B6;;$U6:Q^Q=A($+_
MM+Y>7`&X,LA[G*N^D2)>B5/T`5<U7Q]@"Y#_YK!4D(IO2ARX?.0C%!E,%5++
M2"%=_`CB;7[M2FDROU/O3/#D-+J1AY4,8E2GPT!N,K^!*E=8%VQEEL$WZ,01
MGEP_]:2N#3NE0O7M)KJE]#,Z6@)(FG./_L8Y8U+6@P)K<.TDZ"R,*B<U!*D=
M];[W"Y-7M/)RFMV#0(!RFQJ#8G6?RLTZB[5W$]=689*$B/")LPHL&45+JHA%
M)!.VH+)$Q%,JIG$END+P[Q;G=F/H'AV`40P6?T<&3.\2!FX<A6](<]#X.477
MY![1F[A>OYUCL3)<7V3RRYD9/<.)-@S`!NG$#G%36]7LQ9UMY'AH<)(#:!9>
M[KQZU]0ZO1^E;`G^[CG[F<TN,XPOG/B'S/4+;I8CV6T8G@=SDWM6G/O3(H%:
MOC<\N/5JB7Q^-B)X>CI%1FS-,P>[>ISE/7065+JSW[8KUJUAR<]0]</2WX2#
M0F^/'U39Z;%ND70K;IMVNW#PV":&*%V2$`(AXNO&#WW*4RN]`K^EB=:5<.Y6
M/7+;!39`)^""`<C?2@F)^+"1/\BMLFT&U;:V,Z+=#JP(5I7I\]HPX]6?7/$2
M!IXGP[+ZLF0S(6OHH\U>JQJC]ZTLAS-`'(3<+]F,4`+]>.(9&%U&/:!X(GD`
M;:K*EDH'CKQ"ZH&2Y_^^&:%H?T+VU3H5%[H9['Z1G3\OE+C7!12625EM*B6<
MR'F?D5A/BHM%.@G^HL:7*9*'.RGP%)RL,@/9(,/_TM?LQ(CMC_9QBE$?XG^Y
M)](=Y\_,4IG$7P_+R"9':B%(#XN\T)WQJLU8T*;_7`'68J,=_80#'O)`U9$$
M,F'&0+^=1`((3&IX',BZ8KO&31=]YSY#F^G*'JQY7S&0)R94O?5/!BO!=GGB
MU1#/Q9GE]R2.FI].GXF"$XI0XA08K<,_HP&(HB"WVAB;9+D,F5Y!B2VRU>]P
MI6VZ3%Y#MK22;N4QPEVM52M*"20]2HZ=ANQ:B1^=.)!HK49#._'!#6)1T!+R
MS;'^ZSAV,T5\H@R1E.YEGG$I:"P".T%1%E3Z/;T:FD-F]BE,V/%&WAOV@B.!
M(U/:<T6A8[=A'5R2--/KZ3QJ&@2*I:8325AG,T*.E_'H2NHN;X6J*XVT<5B3
M)O#0A*DC.PI>UM!E4>O?#&SA/KZ/ZW;D1V5^R.#/K9SM?L$UOPP!ET;B?/?U
M5_WOZ\VD^P>"FR/M%_%E+Y/"<'U&A>1T(.JLG9`_`![Q<[0@OUPQ0[Y")MWG
M2^0L8GH5"FU`$)1G.2J2SZ"IT8]5L<JKH5EO@IP<4B=.`S(;POETM,&+9Y3>
MD#]+B1U=,-W;6$G@?\6<.;T$&ORW'\8L`S>P'_>E5)JJ-GRK/75=2OZU:G:/
M'ZF,[1TA6OE$JFX?^)591A>1UI7^P"QS$E#C;%Y;_4G"B>_#Q;HX*Z8^*8K[
MNEB#@Q8_D]$0&0MQ+V.O^XR3E_B5M`O.ZVT_*TW5B/PW!ERP@7Z6ZA.$8C6U
MN>?^&F1&*_4NTZA21#4`?(D=9.PE1NPQ<.V/FO+4Y!94'X/4YSTUN\1@6S09
MG/K))P02#O.:H?X]'>@T"<4*8G\W-+254:OGS>SK/EI+":N6"1['9Q1#5YZL
MT&&-`7!^_Y[R'^MJ"!KK=8[?/,\BP/;O=:(W\C:`FQXIHWW"D3(,:MQL<PUF
MMTCH=LT#)\+>3SA._GBR5`Q78"WC?_=;\C7HA4*=YV[\`L2.;MNJH4J!4R_Q
MTA\?UYMH7XU)72)@+^A'J@]KOT`0@S_^2=CTCMJCTPPF]"9L0YV]]!N`SO6"
M]%(<8B$.DZ_;9/XZ^:50TR?@2PAP^Y`C)<=^^1G[?&,IF)S>%_EJ>R,-"$`I
M`$6;'G#D\X?R"D75.!EFSRJJB!;O-$V0W^P^=FV*2.5`#]?XLG`.ZJ@Z7L[*
MR4>:(7Y9CU'L9U9[&6&3*`?Z.30E9`G._WLU5T_!>,Q#$JA^CQ!HPJ/2_MR[
M\5M5'Q:/&.E4XP,3"SZ;NR-])HWZ#0=#Z`HNRLA=V]ISW8<POAE`F\PR12-J
M?HO\8Z6,'"LO7F0X(_ZV&:DGPYK@7(R$JL%.];)/+XG@T[G.3J^_O9-++>7#
M+OXV4$/U(QB9;*<6`A2FP$V7+')CB8OY*H<48`&AZU#6<O)$C\(&'\'*MUFP
M.XY&U0]9`.^XLJ!3*F//';$+G>#..C$3V4Z<,$)#+&6/R--$2`4]Y%F?E[B1
MAZ-6GM7ZOFG5G]6W[N#7^K_E+DLFE'8<9=!,9Y6)RF>3BEKN,37>.UD7?1,H
M+D*'9HE7Y#J!?&3+^^[.]SM,)_J'[?F1U#RCET?`W`CRR31DN#PVL#J1P="K
M@(IKPLPZ<=C]J<'0%EA<D-"BS"Q@L.[?%%`Y>VN4AJ`7T%#>DS%_VBHDOE_"
M.R@XT)!CE+0;0U.T%D)40KUF@0$`````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S
M+W-K:6YS+V%Q=6$N8V]M<&%C=```````````````````````````````````
M```````````````````````````````````````P,#`W-34@`#`R,S0R-R``
M,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,"`P,C$V-#4`(#4`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-T87(`,#!B=6EL9&5R````````````````````````````````
M`&)R````````````````````````````````````````,#`P,#`P(``P,#`P
M,#`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN<V5A````````````````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,P(#`R,3$U-@`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A
M````````````````````````````````````````````````````````````
M````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#(P,C(Q`"`U````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO
M:'1D;V-S+W-K:6YS+W!L97-K+G-I;'9E<@``````````````````````````
M```````````````````````````````````````````````P,#`W-34@`#`R
M,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,2`P,C$W,3,`
M(#4`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````=7-T87(`,#!B=6EL9&5R````````````````````````
M`````````&)R````````````````````````````````````````,#`P,#`P
M(``P,#`P,#`@````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN865R;P``
M````````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,Q(#`R,C`T-0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:RYV:6]L970`````````````````````````````````````````
M````````````````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#(Q-S$Q`"`U````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S<B]L;V-A;"]P<V$O
M861M:6XO:'1D;V-S+W-K:6YS+VQO;F=H;W)N+F)L86-K````````````````
M```````````````````````````````````````````````````````P,#`W
M-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,2`P
M,C(Q-S,`(#4`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-T87(`,#!B=6EL9&5R````````````````
M`````````````````&)R````````````````````````````````````````
M,#`P,#`P(``P,#`P,#`@````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N8FQU
M90``````````````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,3,Q(#`R,3,V-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]L;VYG:&]R;BYY96QL;W<`````````````````````````````
M````````````````````````````````````````,#`P-S4U(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#(R-#,R`"`U````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S<B]L;V-A
M;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+FYE=RYC;VUP86-T````
M````````````````````````````````````````````````````````````
M```P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S
M-#$S,2`P,C(V-30`(#4`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````=7-T87(`,#!B=6EL9&5R````````
M`````````````````````````&)R````````````````````````````````
M````````,#`P,#`P(``P,#`P,#`@````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE
M<VLX+FYE=P``````````````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,3(W,``@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN
M+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<`````````````````````````````
M````````````````````````````````````````````````,#`P-S4U(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S$@,#(Q,C(W
M`"`U````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L97-K+F)L=64`````
M````````````````````````````````````````````````````````````
M```````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q
M,#4Q-30S-#$S,2`P,C$S,S8`(#4`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-T87(`,#!B=6EL9&5R
M`````````````````````````````````&)R````````````````````````
M````````````````,#`P,#`P(``P,#`P,#`@````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O=VEN>'`N;VQI=F5G<F5E;@``````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,C4W-0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYC;&%S<VEC+G-I;'9E<@``````
M````````````````````````````````````````````````````````,#`P
M-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T,S0Q,S$@
M,#(S,S,S`"`U````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W=I;GAP+G-I
M;'9E<@``````````````````````````````````````````````````````
M```````````````````P,#`W-34@`#`R,S0R-R``,#`W-C0Q(``P,#`P,#`P
M,#`P,"`Q,#4Q-30S-#$S,2`P,C$W-#(`(#4`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````=7-T87(`,#!B
M=6EL9&5R`````````````````````````````````&)R````````````````
M````````````````````````,#`P,#`P(``P,#`P,#`@````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O
M8W,O<VMI;G,O<&QE<VLN;F%T=7)E````````````````````````````````
M`````````````````````````````````````````#`P,#<U-2``,#(S-#(W
M(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,3<P-0`@-0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W1A<@`P,&)U:6QD97(`````````````````````````````
M````8G(````````````````````````````````````````P,#`P,#`@`#`P
M,#`P,"``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYN871U<F4O8W-S````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q,S$@,#(R-#<U`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L
M97-K+FYA='5R92]C<W,O:64N8W-S````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#,V-"`Q,#4Q-30S-#$S,2`P,C,V-C8`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RH@+2TM+2TM+2TM+2!B:6<@
M:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO
M;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*
M?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-
M"@``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YS:6QV97(O
M8W-S````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q,S$@,#(R-3,R`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+W=I;GAP+G-I;'9E<B]C<W,O:64N8W-S````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,#8P-2`Q,#4Q-30S-#$S,2`P,C,W,C$`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RH@+2TM+2TM+2TM
M+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M
M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R
M96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L
M;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[
M#0I]#0H-"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N
M5&%B<R`C=&%B<R!A('L-"F9L;V%T.B!L969T.PT*?0T*(V1A<VAB;V%R9"`C
M<V-R965N5&%B<R`C=&%B<R!L:2![#0IF;&]A=#H@;&5F=#L-"G9E<G1I8V%L
M+6%L:6=N.B!T;W`[#0I]#0H`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYC
M;&%S<VEC+G-I;'9E<B]C<W,`````````````````````````````````````
M````````````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P
M,#`P,#`@,3`U,34T,S0Q,S$@,#(T,3(S`"`U````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````'5S=&%R`#`P
M8G5I;&1E<@````````````````````````````````!B<@``````````````
M`````````````````````````#`P,#`P,"``,#`P,#`P(```````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D
M;V-S+W-K:6YS+W!L97-K+F-L87-S:6,N<VEL=F5R+V-S<R]I92YC<W,`````
M```````````````````````````````````````````P,#`V-#0@`#`R,S0R
M-R``,#`W-C0Q(``P,#`P,#`P,#`P,"`Q,#4Q-30S-#$S,2`P,C4R-S<`(#``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-T87(`,#!B=6EL9&5R````````````````````````````
M`````&)R````````````````````````````````````````,#`P,#`P(``P
M,#`P,#`@````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````=7-R+VQO
M8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N;VQI=F5G<F5E;B]C
M<W,`````````````````````````````````````````````````````````
M`````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U
M-#,T,3,Q(#`R,S,V-0`@-0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W1A<@`P,&)U:6QD97(`````
M````````````````````````````8G(`````````````````````````````
M```````````P,#`P,#`@`#`P,#`P,"``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W
M:6YX<"YO;&EV96=R965N+V-S<R]I92YC<W,`````````````````````````
M````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``
M,#`P,#`P,#`V,#4@,3`U,34T,S0Q,S$@,#(T-34T`"`P````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````'5S
M=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``````
M`````````````````````````````````#`P,#`P,"``,#`P,#`P(```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"\J("TM+2TM+2TM+2T@8FEG
M(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM
M;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@
M+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-
M"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*
M#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@
M(W1A8G,@82![#0IF;&]A=#H@;&5F=#L-"GT-"B-D87-H8F]A<F0@(W-C<F5E
M;E1A8G,@(W1A8G,@;&D@>PT*9FQO870Z(&QE9G0[#0IV97)T:6-A;"UA;&EG
M;CH@=&]P.PT*?0T*````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN8FQU92]C
M<W,`````````````````````````````````````````````````````````
M`````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P
M(#$P-3$U-#,T,3,Q(#`R,C$R-@`@-0``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W1A<@`P,&)U:6QD
M97(`````````````````````````````````8G(`````````````````````
M```````````````````P,#`P,#`@`#`P,#`P,"``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S
M:VEN<R]P;&5S:RYB;'5E+V-S<R]I92YC<W,`````````````````````````
M````````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P
M-S8T,2``,#`P,#`P,#`V,#,@,3`U,34T,S0Q,S$@,#(S,S$S`"`P````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B
M<@```````````````````````````````````````#`P,#`P,"``,#`P,#`P
M(```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````"\J("TM+2TM+2TM
M+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A
M("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R
M;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!
M<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB
M;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P
M.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C<F5E
M;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HC
M9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S('5L('L-"G!A9&1I;F<M8F]T
M=&]M.B`Q<'@[#0I]#0H-"@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N
M;F5W+V-S<P``````````````````````````````````````````````````
M`````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P
M,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,C`Q-P`@-0``````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W1A<@`P
M,&)U:6QD97(`````````````````````````````````8G(`````````````
M```````````````````````````P,#`P,#`@`#`P,#`P,"``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT
M9&]C<R]S:VEN<R]W:6YX<"YN97<O8W-S+VEE+F-S<P``````````````````
M````````````````````````````````````````````,#`P-C0T(``P,C,T
M,C<@`#`P-S8T,2``,#`P,#`P,#`W,3,@,3`U,34T,S0Q,S$@,#(S,C`V`"`P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````
M``````!B<@```````````````````````````````````````#`P,#`P,"``
M,#`P,#`P(```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````"\J("TM
M+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O
M;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]
M#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN
M;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C
M:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@
M(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M8FQO8VL[
M#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S(&QI('L-"F9L;V%T
M.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-"B-D87-H8F]A<F0@
M(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB;W1T;VTZ(#%P>#L-
M"GT-"@``````````````````````````````````````````````````````
M````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O
M<&QE<VLX+FYE=R]C<W,`````````````````````````````````````````
M`````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@
M`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,C`V,``@-0``````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`````
M```````````````````````````````````P,#`P,#`@`#`P,#`P,"``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W(O;&]C86PO<'-A+V%D
M;6EN+VAT9&]C<R]S:VEN<R]P;&5S:S@N;F5W+V-S<R]I92YC<W,`````````
M````````````````````````````````````````````````````,#`P-C0T
M(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,#<@,3`U,34T,S0Q,S$@,#(S
M,C4P`"`P````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````
M``````````````!B<@```````````````````````````````````````#`P
M,#`P,"``,#`P,#`P(```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO
M#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI
M;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P
M86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L
M87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R
M9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H
M8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M
M8FQO8VL[#0I]#0H-"@``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O
M<VMI;G,O=VEN>'`N;F5W+F-O;7!A8W0O8W-S````````````````````````
M`````````````````````````````````````#`P,#<U-2``,#(S-#(W(``P
M,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,S0T-``@-0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````!U<W1A<@`P,&)U:6QD97(`````````````````````````````````
M8G(````````````````````````````````````````P,#`P,#`@`#`P,#`P
M,"``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W(O;&]C86PO
M<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YN97<N8V]M<&%C="]C<W,O
M:64N8W-S````````````````````````````````````````````````````
M,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W,3,@,3`U,34T,S0Q
M,S$@,#(T-C,S`"`P````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````
M``````````````````````!B<@``````````````````````````````````
M`````#`P,#`P,"``,#`P,#`P(```````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM
M+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y
M.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T
M=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@
M(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-
M"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I
M;FQI;F4M8FQO8VL[#0I]#0HC9&%S:&)O87)D("-S8W)E96Y486)S("-T86)S
M(&QI('L-"F9L;V%T.B!L969T.PT*=F5R=&EC86PM86QI9VXZ('1O<#L-"GT-
M"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB
M;W1T;VTZ(#%P>#L-"GT-"@``````````````````````````````````````
M````````````````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H
M=&1O8W,O<VMI;G,O;&]N9VAO<FXN>65L;&]W+V-S<P``````````````````
M`````````````````````````````````````````````#`P,#<U-2``,#(S
M-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,S(R,@`@
M-0``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!U<W1A<@`P,&)U:6QD97(`````````````````````````
M````````8G(````````````````````````````````````````P,#`P,#`@
M`#`P,#`P,"``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W(O
M;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG:&]R;BYY96QL;W<O
M8W-S+VEE+F-S<P``````````````````````````````````````````````
M````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`S-C0@,3`U
M,34T,S0Q,S$@,#(T-#$S`"`P````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``
M``````````````````````````````!B<@``````````````````````````
M`````````````#`P,#`P,"``,#`P,#`P(```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@
M+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D
M:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M
M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A
M;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T
M;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0H`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````=7-R+VQO8V%L+W!S82]A
M9&UI;B]H=&1O8W,O<VMI;G,O=VEN>'`N8FQU92]C<W,`````````````````
M`````````````````````````````````````````````````````#`P,#<U
M-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R
M,C$U-0`@-0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!U<W1A<@`P,&)U:6QD97(`````````````````
M````````````````8G(````````````````````````````````````````P
M,#`P,#`@`#`P,#`P,"``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]W:6YX<"YB;'5E
M+V-S<R]I92YC<W,`````````````````````````````````````````````
M````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`W
M,3,@,3`U,34T,S0Q,S$@,#(S,S0T`"`P````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````'5S=&%R`#`P8G5I
M;&1E<@````````````````````````````````!B<@``````````````````
M`````````````````````#`P,#`P,"``,#`P,#`P(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T
M=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@
M>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E
M82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T
M;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E
M96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K
M=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![
M#0ID:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0HC9&%S:&)O87)D("-S8W)E
M96Y486)S("-T86)S(&QI('L-"F9L;V%T.B!L969T.PT*=F5R=&EC86PM86QI
M9VXZ('1O<#L-"GT-"B-D87-H8F]A<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@
M>PT*<&%D9&EN9RUB;W1T;VTZ(#%P>#L-"GT-"@``````````````````````
M````````````````````````````````````````````````=7-R+VQO8V%L
M+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN8FQA8VLO8W-S````
M````````````````````````````````````````````````````````````
M`#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T
M,3,Q(#`R,C<V,P`@-0``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````!U<W1A<@`P,&)U:6QD97(`````````
M````````````````````````8G(`````````````````````````````````
M```````P,#`P,#`@`#`P,#`P,"``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]L;VYG
M:&]R;BYB;&%C:R]C<W,O:64N8W-S````````````````````````````````
M````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P
M,#`P,#`S-C0@,3`U,34T,S0Q,S$@,#(T,34T`"`P````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````'5S=&%R
M`#`P8G5I;&1E<@````````````````````````````````!B<@``````````
M`````````````````````````````#`P,#`P,"``,#`P,#`P(```````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"\J("TM+2TM+2TM+2T@8FEG(&EC
M;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"
M=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O
M;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A("YC;VUM
M;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-
M"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*?0T*#0H`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-R
M+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE<VLN=FEO;&5T+V-S
M<P``````````````````````````````````````````````````````````
M`````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P,#`P(#$P
M-3$U-#,T,3,Q(#`R,C4P,0`@-0``````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!U<W1A<@`P,&)U:6QD97(`
M````````````````````````````````8G(`````````````````````````
M```````````````P,#`P,#`@`#`P,#`P,"``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN
M<R]P;&5S:RYV:6]L970O8W-S+VEE+F-S<P``````````````````````````
M````````````````````````````````,#`P-C0T(``P,C,T,C<@`#`P-S8T
M,2``,#`P,#`P,#`U,#<@,3`U,34T,S0Q,S$@,#(S-C<Q`"`P````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`'5S=&%R`#`P8G5I;&1E<@````````````````````````````````!B<@``
M`````````````````````````````````````#`P,#`P,"``,#`P,#`P(```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````"\J("TM+2TM+2TM+2T@
M8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!<F5A("YC
M;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN9F]R;4%R
M96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O;'-!<F5A
M("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN92UB;&]C
M:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG.B`P.PT*
M?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A<F0@(W-C<F5E;E1A
M8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M8FQO8VL[#0I]#0H-"@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O;&]N9VAO<FXN
M865R;R]C<W,`````````````````````````````````````````````````
M`````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P,#`P,#`P
M,#`P(#$P-3$U-#,T,3,Q(#`R,C8S-0`@-0``````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!U<W1A<@`P,&)U
M:6QD97(`````````````````````````````````8G(`````````````````
M```````````````````````P,#`P,#`@`#`P,#`P,"``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C
M<R]S:VEN<R]L;VYG:&]R;BYA97)O+V-S<R]I92YC<W,`````````````````
M````````````````````````````````````````,#`P-C0T(``P,C,T,C<@
M`#`P-S8T,2``,#`P,#`P,#`S-C0@,3`U,34T,S0Q,S$@,#(T,#(V`"`P````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````'5S=&%R`#`P8G5I;&1E<@``````````````````````````````
M``!B<@```````````````````````````````````````#`P,#`P,"``,#`P
M,#`P(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````"\J("TM+2TM
M+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN=&]O;'-!
M<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[#0I]#0HN
M9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL#0HN=&]O
M;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ(&EN;&EN
M92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US<&%C:6YG
M.B`P.PT*?0T*#0H`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI;G,O<&QE
M<VLN<VEL=F5R+V-S<P``````````````````````````````````````````
M`````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V-#$@`#`P
M,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,C4P,P`@-0``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!U<W1A
M<@`P,&)U:6QD97(`````````````````````````````````8G(`````````
M```````````````````````````````P,#`P,#`@`#`P,#`P,"``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!U<W(O;&]C86PO<'-A+V%D;6EN
M+VAT9&]C<R]S:VEN<R]P;&5S:RYS:6QV97(O8W-S+VEE+F-S<P``````````
M````````````````````````````````````````````````,#`P-C0T(``P
M,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`U,#<@,3`U,34T,S0Q,S$@,#(S-C<S
M`"`P````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````'5S=&%R`#`P8G5I;&1E<@``````````````````````
M``````````!B<@```````````````````````````````````````#`P,#`P
M,"``,#`P,#`P(```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"\J
M("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I;FQI;F4[
M#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N('-P86XL
M#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I<W!L87DZ
M(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@=V]R9"US
M<&%C:6YG.B`P.PT*?0T*#0HO*B!D97-K=&]P('1A8G,@*B\-"B-D87-H8F]A
M<F0@(W-C<F5E;E1A8G,@(W1A8G,@82![#0ID:7-P;&%Y.B!I;FQI;F4M8FQO
M8VL[#0I]#0H-"@``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````=7-R+VQO8V%L+W!S82]A9&UI;B]H=&1O8W,O<VMI
M;G,O87%U82]C<W,`````````````````````````````````````````````
M`````````````````````````````````#`P,#<U-2``,#(S-#(W(``P,#<V
M-#$@`#`P,#`P,#`P,#`P(#$P-3$U-#,T,3,Q(#`R,3`Q,0`@-0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!U<W1A<@`P,&)U:6QD97(`````````````````````````````````8G(`
M```````````````````````````````````````P,#`P,#`@`#`P,#`P,"``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!U<W(O;&]C86PO<'-A
M+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A+V-S<R]I92YC<W,`````````````
M````````````````````````````````````````````````````````,#`P
M-C0T(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#$Q-C4@,3`U,34T,S0Q,S$@
M,#(R,C`R`"`P````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'5S=&%R`#`P8G5I;&1E<@``````````````
M``````````````````!B<@``````````````````````````````````````
M`#`P,#`P,"``,#`P,#`P(```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"\J("TM+2TM+2TM+2T@8FEG(&EC;VX@8G5T=&]N<R`@+2TM+2TM+2TM
M("HO#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@>PT*("!D:7-P;&%Y.B!I
M;FQI;F4[#0I]#0HN9F]R;4%R96$@+G1O;VQS07)E82`N8V]M;6]N0G5T=&]N
M('-P86XL#0HN=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;B![#0H@(&1I
M<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"BYS8W)E96Y"=71T;VYS('L-"B`@
M=V]R9"US<&%C:6YG.B`P.PT*?0T*#0HO*B`M+2TM+2TM+2TM('-M86QL(&EC
M;VX@8G5T=&]N<R`@+2TM+2TM+2TM("HO#0HN;&ES=$%R96$@+F)U='1O;G,@
M+F-O;6UO;D)U='1O;B!B=71T;VXL('L-"B`@=&5X="UI;F1E;G0Z(#(U<'@[
M#0I]#0HC9&%S:&)O87)D("YD0F]X("YB=71T;VYS("YC;VUM;VY"=71T;VXL
M#0HN8V]N=')O;%9I<VEB:6QI='E4;V]L8F%R("YM:7-C("YC;VUM;VY"=71T
M;VXL#0HN;&ES=$%R96$@+F)U='1O;G,@+F-O;6UO;D)U='1O;BP-"BYR97!O
M<G14;V]L<R`N8V]M;6]N0G5T=&]N+`T*+G5P;&5V96P@+F-O;6UO;D)U='1O
M;B![#0H@(&)A8VMG<F]U;F0M<&]S:71I;VXZ(#`@-G!X.PT*?0T*+G5P;&5V
M96P@+F-O;6UO;D)U='1O;B![#0H@(&UA<F=I;BUL969T.B`U<'@[#0I]#0H-
M"@T*````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````!U<W(O;&]C
M86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]P;&5S:RYS96$O8W-S````````
M````````````````````````````````````````````````````````````
M````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@,3`U,34T
M,S0Q,S`@,#(Q-S0V`"`U````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````'5S=&%R`#`P8G5I;&1E<@``````
M``````````````````````````!B<@``````````````````````````````
M`````````#`P,#`P,"``,#`P,#`P(```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K:6YS+W!L
M97-K+G-E82]C<W,O:64N8W-S````````````````````````````````````
M```````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W-C0Q(``P
M,#`P,#`P,#8P,R`Q,#4Q-30S-#$S,"`P,C,Q,S,`(#``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````=7-T
M87(`,#!B=6EL9&5R`````````````````````````````````&)R````````
M````````````````````````````````,#`P,#`P(``P,#`P,#`@````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````+RH@+2TM+2TM+2TM+2!B:6<@
M:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@+F-O;6UO
M;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M07)E82`N
M=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R96$@+F-O
M;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L;V-K.PT*
M?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[#0I]#0H-
M"B\J(&1E<VMT;W`@=&%B<R`J+PT*(V1A<VAB;V%R9"`C<V-R965N5&%B<R`C
M=&%B<R!A('L-"F1I<W!L87DZ(&EN;&EN92UB;&]C:SL-"GT-"B-D87-H8F]A
M<F0@(W-C<F5E;E1A8G,@(W1A8G,@=6P@>PT*<&%D9&EN9RUB;W1T;VTZ(#%P
M>#L-"GT-"@T*````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!U
M<W(O;&]C86PO<'-A+V%D;6EN+VAT9&]C<R]S:VEN<R]A<75A+F-O;7!A8W0O
M8W-S````````````````````````````````````````````````````````
M````````````,#`P-S4U(``P,C,T,C<@`#`P-S8T,2``,#`P,#`P,#`P,#`@
M,3`U,34T,S0Q,S`@,#(R-#,U`"`U````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'5S=&%R`#`P8G5I;&1E
M<@````````````````````````````````!B<@``````````````````````
M`````````````````#`P,#`P,"``,#`P,#`P(```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````'5S<B]L;V-A;"]P<V$O861M:6XO:'1D;V-S+W-K
M:6YS+V%Q=6$N8V]M<&%C="]C<W,O:64N8W-S````````````````````````
M```````````````````````````````````P,#`V-#0@`#`R,S0R-R``,#`W
M-C0Q(``P,#`P,#`P,3$V,R`Q,#4Q-30S-#$S,"`P,C,V,C0`(#``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````=7-T87(`,#!B=6EL9&5R`````````````````````````````````&)R
M````````````````````````````````````````,#`P,#`P(``P,#`P,#`@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````+RH@+2TM+2TM+2TM
M+2!B:6<@:6-O;B!B=71T;VYS("`M+2TM+2TM+2T@*B\-"BYT;V]L<T%R96$@
M+F-O;6UO;D)U='1O;B![#0H@(&1I<W!L87DZ(&EN;&EN93L-"GT-"BYF;W)M
M07)E82`N=&]O;'-!<F5A("YC;VUM;VY"=71T;VX@<W!A;BP-"BYT;V]L<T%R
M96$@+F-O;6UO;D)U='1O;B!S<&%N('L-"B`@9&ES<&QA>3H@:6YL:6YE+6)L
M;V-K.PT*?0T*+G-C<F5E;D)U='1O;G,@>PT*("!W;W)D+7-P86-I;F<Z(#`[
M#0I]#0H-"B\J("TM+2TM+2TM+2T@<VUA;&P@:6-O;B!B=71T;VYS("`M+2TM
M+2TM+2T@*B\-"BYL:7-T07)E82`N8G5T=&]N<R`N8V]M;6]N0G5T=&]N(&)U
M='1O;BP@>PT*("!T97AT+6EN9&5N=#H@,C5P>#L-"GT-"B-D87-H8F]A<F0@
M+F1";W@@+F)U='1O;G,@+F-O;6UO;D)U='1O;BP-"BYC;VYT<F]L5FES:6)I
M;&ET>51O;VQB87(@+FUI<V,@+F-O;6UO;D)U='1O;BP-"BYL:7-T07)E82`N
M8G5T=&]N<R`N8V]M;6]N0G5T=&]N+`T*+G)E<&]R=%1O;VQS("YC;VUM;VY"
M=71T;VXL#0HN=7!L979E;"`N8V]M;6]N0G5T=&]N('L-"B`@8F%C:V=R;W5N
M9"UP;W-I=&EO;CH@,"`V<'@[#0I]#0HN=7!L979E;"`N8V]M;6]N0G5T=&]N
M('L-"B`@;6%R9VEN+6QE9G0Z(#5P>#L-"GT-"@T*````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
`
end
